(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  44293090,    1152070]*)
(*NotebookOutlinePosition[  44296858,    1152171]*)
(*  CellTagsIndexPosition[  44296773,    1152165]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Rendering Medical Data with MathGL3d", "Section",
  CellTags->"RenderCTData"],

Cell["Load MathGL3d:", "Text",
  CellTags->"RenderCTData"],

Cell[BoxData[
    \(Get["\<MathGL3d`\>"]\)], "Input",
  CellTags->"RenderCTData"],

Cell[BoxData[
    \(Get["\<MathGL3d`OpenGLViewer`\>"]\)], "Input",
  CellTags->"RenderCTData"],

Cell[TextData[{
  "For large volumes of data you do not need to load the data into the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel.  If  ",
  StyleBox["MVContourPlot3D[] ", "Input"],
  "is called with a string, it assumes that the string represents a filename \
with compressed volume data. The volume data format uses a loss less context \
that is a sensitive arithmetic coder and gives better compression results \
than other loss less compression algorithms. The MathGL3d function ",
  StyleBox["MVWriteVolumeData[]", "Input"],
  " saves the data from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for later processing and visualization with MathGL3d. With ",
  StyleBox["MVReadVolumeData[]", "Input"],
  ", the data can be read again by the kernel."
}], "Text",
  CellTags->"RenderCTData"],

Cell[BoxData[
    \(\(MVListContourPlot3D[
        Evaluate@\[IndentingNewLine]ToFileName[$MathGL3dDataDirectory, \
"\<foot.v3d\>"], Contours \[Rule] {96}, MVNewScene \[Rule] True, 
        MVReturnValue \[Rule] None, 
        ViewPoint \[Rule] {1.086, \(-2.00\), 1.0}, 
        ViewCenter \[Rule] {0.42, 0.5, 0.46}, 
        MVDisplayList \[Rule] False];\)\)], "Input",
  CellTags->"RenderCTData"],

Cell[TextData[{
  "Setting ",
  StyleBox["MVRetrunValue->Non", "Input"],
  "e omits the return of the large number of polygons to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". You can paste OpenGL image into the notebook with ",
  StyleBox["MVPasteGraphics", "Input"],
  "."
}], "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MVPasteGraphics[];\)\)], "Input",
  CellTags->"RenderCTData"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00238095 0.0238095 0.00238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
1200 string
400 400 8 [400 0 0 400 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000004D00330000000000006B2E46782F25170000
000000593D7E7C00A3BFBAE5CBC2B34C0000647700B4B900000000000000000000000000
000000000000000009000000000000B399C4AD7058B5744D690000000000000000000000
AB000075000018266A000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003F00000000000000004A00275900331D0000530000
745D9A6C57978900B6B6ADD9C9BAB5B68F659FBA00A3BC7F000000000000000000000000
9A92009FB600000000000000000000A07496A46A76B67B73C98C70C48E5AAE00009D0000
0000007900006E90AF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000001F000043001537001947002958004856005A5100007B5F96
8E7AB08272AE867CB9AD9FCCBB9DAB9C6253000000660000000000000000000000000000
D5C5000001210000000000000000007F4D75AA7786CF9A92D6A788D6B179CCAB63D7C27B
976900000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000003600003F000E57002D682B486C375D6E416F7D57869678A6
A994C19283BA7D73B4A294C5B8A4C2906F885300001D384B000000000000000000813400
FFF9004700000000000000005600005500486D0033B3005AD9B68DE2CA8ED1BF77DCC985
CDBD00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000053070F601211702629742F3B77384E7F486783547AA67EA0AD8EB2
AD95BD9B89BC8377B5988FC6B8AFDABBB7A5BABA6B000000000000000000000000BF9A00
C29000BF824BAB6C288B0000BD8846A900008E4E00985800D0B67CDFCB87AFA552E1D190
DCD28F000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000004F0000620000000000000000000000000000
0000001900002D00006400007700008F463B904B4A91515D976075A3738DB188A4B796B4
B195BAA58EBC8A7BB5978CC3C0BCD7C4C6A50000000000006E0000000000B0A4CDCEB4C3
DBB4A6E4B585C2914BAF8133C9A65DC5A456B49300A28200C2B060E1CD8AB6A554E0CE8C
D3C178C9BA6D8862007D5A00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000074760000B36B00000000000000000000
0000005B0000A00000A7604FAA644FB26F5BB37368B67C7EB5808BB78696BC92A6C09CB5
B696B6AB8EB5917FB59C90C6C7C9D5CED6A5CC9968CE976ED2A16D0000008B86BCBCA5C5
CAA8AAE5BC89CAA155AB8935CAB467CEBB70BFAD5C9E9300BCB665DBC983C6AC60E4CA8A
E1C787C5B86A878C00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000470000470000BAD39900000000000000
000000820000AF0000BA7B6CC38679CB9184D0988CC8918EBD8991B88594BC8FA3CAA1AF
BF99AFB290B1A58FBCA598CBCFD6D2CBCC8DB39745000000EDD49C00008C0000A6A08DBD
E7C2B2F0C999D9B16BB59B46C2B666D2CB82C0B8699C953E000000DCD392CEB46CCCAA61
D9C683C2B667000000000000A5D5EE000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000860000D9ECD0B3D9B6793E0000
7C2D1D954B30B46F4CC5845FD1987ADEAA94D8A496C89291BF8B93BA8694C1919ECEA2AA
C29AADAA7E9AA486ADB70000D7E3CFC2A073C39359B3863FA2782500000000005EB60090
EFC5A7F4D1A3E0BB78BCA14EBCB564CAC67BBBBB6D9A9B46000000D9DEA4CDBF79CEC37B
CCC67CB2A100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000690000AC0000D6B5D200939A005A5300
9C0000B6734DC28456D59D6FE3B18AE6B69BD6A295C69090BB858EC18F99CA9BA3CEA1A8
BE91A2AB809DC196A6DFB4B0DE0000DA00008A5875B1007C8B00596500368E0051F0C1B5
F0C8AAEFCD9DE2C381BFA754B2A854BEC073B1BA6D000000000000D5DFA4CCD492C1CA88
CDCD889F8600000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000FF0000000000FF0000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000510000914370B536698C528C844A79007F0000
A40000BB7748CE935ED9A371DBA580DDA78ECF978BC08989BB858DCD9DA1D7AAACD5AEB8
C7A6BDBAA0C3C4A8C2D8B8C0AA00007A629B95789DB497AD9B009D8D0085DD00AFFDD5C7
FEDDBCFDE2AFE6CB8ABEA6529E892EB0B05FBAB364000000000000CBD797B5CD8FA6C8A6
CAD79DB5AE00846E00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000700000B96B98C663A6B7598B5F9A5E00934D00
995112B57434C68750D09562D0956ED09479C38677C08681CA9798D7A9A8E0B8B8D9BAC8
D3B8CFC7ABC7C0AECFC9B7D1A800009890C49F97C5B5B3DBAB00E1DE00E8FFDEE6FFE8D9
FFF1CDFFE6B4EBD192C6B1619F862A9FA04CA0A559B29E000000008DA70000AD00B4DDC5
BFDBB3C3C67D9C9500000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000009385B99C99C99D9F9699A25CC4A959C39600BA7E00
AA6727B1742CBC7E3DC68753C38359C17E5FC78973D0988BDAA9A2E6BBB1E5BAB4E4BFC3
DFC0CED0B6CDBDB3DCBAB5E1C0C2EAB2BAE8ADB9EDB5CCFFAACFFFB8C8E0EAE9FFF2F4FA
E6E4D1FCEDBDEAD699D5C9809F8C31998A2F91A45DD6D08B246C00A8DBD082BFCCA3D1D6
C0E3C2CBD391999E00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003C00479C00A3A787A7C0A7BAD3BFA8A58B43C6A867D5A065CD915C
C07F48BC8239C18444C5864FC8885ACA8A65D29678DCA790E7B8A8E7B8A7E4B5A6E7BDB8
E9C5C9D8C0D3C7BADBC7BADBEAEFFFD3EAFFB3D2F1B6DEFF8BC4E695CCEFC9EFFFCEECFF
C5D7D0F5F4C7C6CD96CCCE8B9C9A45998F36A4B470D7D8979BA30000000094B5CC9ABFCB
D2DEB1CEDB9FAFBF76000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000FF0000000000000000000000000000
000000000000000000FF0000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000007B0085A40097BB8994E4B5ACFFDFBAC18546D19860DBA66ED69D69
D09262B2772AC08641CB8F53D09461D59A6EDDA682E6B598E9B9A5E5B4A0E6B7A5EABCAD
EDC4BEDFC1CAD9BFD0D5BED4FFFFFFFFFFFFE4FFFFAFDFEF83BFDE62A7CE88C3EE95C9F1
AACCD1E3F2CDACCA9AA7C38795AD63A1A452CACA84958E00A8873BF3CDA4F1CD9FEFCD99
D2CD9098B374A4C3897B6900000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000FF0000000000000000000000000000000000000000
000000000000FF0000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000091CFBB000000000000000000000000
0000000000000000008C62889C677BAC6E6FCC9383E3AA81C07E48BC7846C68456CE8F5D
D19360CB9454BC8438CA9250D39C62DCA675E0AB82E3AF8FE5B39CE7B6A2E9BCAAECC1B2
F1C6BAF4D5C7EFD8D0ECDEDBFFFFFFFFFFFFFDFFFFDDFFF4AADBDB75B6CE6EAFD763A6D1
72ADBD88BFAC90C29991BA838BA860BFCC88DADB9ABCAE00D8B073EECA9AEFCD99C7BF7E
AEB7767AA772C2E7BE828E00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000FF0000FF0000FF0000000000FF0000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000091CFBC000000000000000000000000000000
00000000000045004478405F86434FAB665BC8896ED1936DC9875FBF794CBE7849C88754
D1955ECC9653C7944BC78F4AD79F67DBA372DAA076DCA482DDA589E9B79EF0C3ADF4C8B4
FFD4BFFFEFD2FFFFF1FFFFFFFFFFFFFDFFFFDFFFF0C9F3E0B7E7D692CCD579BADA69B0C6
4B9AAD75B7A785BC9687B680A9C98CD0D998DADFA1CBC077C9A300E2BF83E1C88D99AC60
BDEAE1C9F1D7D5F9CE000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000005E1D3975364DA6635FBA7662C07C5DC58158C07A4EBF784BC27E4DCC8F58
D49B60C9954EC7934AC38C43CB8E56D09363D19369D3966ED39472DEA586EEBDA0FFD4B8
FFE7C7FFFAD7FFFFF4FFFFFFF2FFF6D5FCE5C5F0D9B2E3CDA3D9C36BB1B870B5C86AB2C6
53A0AD6CB3B378B59F97C8A0C3DBA2DBE3A9DBE4A9CAC984ADA14CC8A800ABB06A95A95D
7BB1CBDCFFE7DAFACA000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000550000000000BB7442510000660000000000000000000000000000000000
00000000000000000087000099000000000000000078BBC7000000000000000000000000
48000068191B7A2E308C42439E574FB06A5ABC7861B66E4EB66D45BB7443BF7C42CA8E50
D6A260D3A05CCB964ECA904FCC8E57CA8A59C9865BCA875DCD8C5FD29565D9A06EE2B07C
FFE5AEFFF1C1DCF7D6D0F2D5BDE8CDA7DABF94CBAD85BF9E7EBBA280C1B894D1D87BBED0
70B6D080C2CB98D4D0BDE6CEB9DEB0B1D8A8A6D09FA5CD9BA5B471ABAB59000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D7CFB0
EDCF87670000B50000E5C695D7C989CCA168B290009253006100000000003800002F0000
32000077577D968FAA9000006A00000000002066A5569CBE0000000000002E00003B0000
5800006A1913711F147C2A1A8D3D289B4D35AA5E3FB86F49BD764CC07C48C38345C98E4C
CF9954D5A25ECF9A54CC9450D39862D39567CF8F64D09163D39766D39B63D5A163DEBC7A
E2DB9DDBE8B4DEF0C4DAF5D0B7E1BFB1DBB19ECCA194C8A19BD3B882C1B66FB4B963ACBF
73B7D07EC0D485C6CB8AC7BB73B09468AD997EBCA59ACCA8A4C996A4BC7C000000000000
0000009FD8D5000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000F1FBCC
FFDB99CA9A45D80000F2C597F0D39DEBE0A2CFDA9AC9E400C8EC00000001A3A500866700
887300A7C3DCAFE3F4ACE2EA0000000000000000000000002E00002700003400004E0000
6000006F1B0A7F2C18903F26A25433AE633EBA724AC68257CD8C5DC78451C7874BC38642
C48A42CB964ED39F5AD19B58D39961D99D70D5976CD19167D79B6AD6A267D3A660C4B063
C8C87ED8E1A4E0EAB2CDEABEBADEAFACD3A0A2CE9E9ACA9F78B597327F70004D5400304F
004F6F007392007989005B5E0059620000700000A86CADA893C8AA94C498000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
8B80A66F00005300004A447B555C71677664778652000000000000000000000000FFFFDA
FFE6AAEEBC76D4A051DAA764DEB672BEBE76AAC78ACAF5EAC3F1F8BFF0FFC9FD00D2FF00
D7FFFFCAFFFFC3F5FFC3F4FAC4F3EB0000005900002300001900003400005400005E0000
731C00812C0F8F3C1A9C4B26A95B33B56B3FBF7749C58051CA8756CA8851CA8A4DC68847
C0843CBC8136C68D47CE9653D69F65DAA073DA9F73D99E73D9A26BD9AA69D1AD60B5B15F
C1BE6FD8DD9CD8E2A7C4E0ADB6D69FA7CB929AC48E78AD7D347752659D6D6CAB8B8BC3A5
9DCFAFA2C9A1E9E0ADEDD29C00000000007F00007E579FAE68A7A495BD94827D00000000
00000000000000140C000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000033564A
80A5E46D69964000005B7AA76294A19200009765548C55620000008E9AD4C8C1D6FFE5D3
FFF7C5F7BD84C58344BB7B35BF97498F9E519ECCA5A7DDE1B3E6F6B7E9F9C1F500C0FBFF
B6DFFFCDFFFFCFFFFFD0FFFFDBFDF8E5F8D68300002600004900005A00006500006F1700
7B24008934008F3B11913E149D4C20AA5C2EB76D3DBF7746C5804EC6824CC58247C38242
BF803BBA7C34BA7D35C48744CD8F56D49665D69A6BDDA376E2B079D2B36CC0B362AFB15D
C6C375D6D793CDDA9AC1DAA1B5D093A0C38785AF754A824D5C936175B39589C4ADA3D8C7
CDEECFE2EBBDF2DFAF0000000000000000002666A84C93B97BBAC69BC5A99DAD00000000
000000000000A0A250000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000005B61A85768B3
5D7CC56390D74887C61F5D5988A800CAE500CFD7C3A183940000009CB9E6D8E3ECFFFFE9
D8D1C3B800009700009200007000007094516FB2B085C6D7A4DCF3ACE2F3AFE5F2A9E4F9
9EC1EEA8C7FDC10000E9FFFFF4F8D8EFE4B0BD98008100005700004400005F0000731C00
853000954200A0501EA85A26AC6128B2682DB86F37BE7641C27C48C78250C9874EC88B49
C88B48C38640B7792FBD7F39C58647CC8D55DAA26EE5B381E1BC80C0B767A4AB58B1B15F
CAC87CD2D28BC5CF89BFD596ACC7878DB06E588747558B548DCCC498D7D0A3E2DBC0EEE2
E4FFE6FDFFE3FFFFD7FFE6D3DEB7BD0000000000274D90BE6DB0CC80C2CD8BA200462E00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000290000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000650000000000C197BED4
86BCC574B4BA549F9493CD005400003D0000260000084896789AD3ABD8F8E7FFFFB0CEBE
82A3AF6600003A0000DC0000C50000BB6F3ABB713661AACB81C2E18DCDE790CFE88BC7E5
7BA4DB852E40B10000E80000FAE1AFEBC78ED19D00BD7F00A962008500008E4100924300
924100964500A4561BAE622AB56C31C68547BC773AC58444C68447C8854BC9894DCE9651
CB924CC98F48BD8237BF833AC38540C58644CE9958DDAF71CBB267B6B361ABA955B5B15E
CECA80CECC83BEBF70B9CA869FB77077995258854494C5A3BBF7E3C0FFF9CCFFFFDEFFFF
F1FFF7FFFFFDFFFFFDFFFFFFFCE4F6F1DCE0F1DEC9007E995598C17EBABB86A100635B00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000FF0000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000133C3C0000000000006B2D3E000000000000880000830000
7E0000640000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000079A70000690000E7FFFF
B0E60089CBC3B4E8E00B2C2ABA0000BB0000BC0000000000000000000000A1E2E64E9492
2C759B0000009E0000DA0000C8BFCBBE7B4ABD73350000000000005DAACA54A1C2559CCD
0000006B0000A90000EC0000DDB494A86C529A502C9F5300A154009241009B5000984D00
A55B00AB601DA55A16AA621BB36D29CC8F4FCF9254C78448C78548C68446C78748D7A65F
D4A15BCD964FCE9850C78F45C48A42C78948CD9752D2A75CBEAC5AB4B15EB4A953BBAF5A
CFC87CCBC679BAB664B3BD728AA2565E7E328FB376E3FAC8EFFFFBE8FFFFE9FFFFE4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFF00000005B95C091C4BC9BC6007F5269
9E8361DAF8DC000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000009000004600000000000000000000005B75A29C8891CAA2860FB503
000000007A7A000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000007D0065C7A387C6A36705080E
B1CF00000000000000000000D0CDE2DED0D9ECD4CF000000000000000000FFFF00EBEE00
87C1A098CAA1C0D9B9CADDFFAB0000C396750000000000000000006300006100005F0000
5500006100006B0F00D7A06DD099844700006100005F00005D0000BC98009192009B5000
984B009C4D00A15400A25712A65D15B56F2CBA7436C07A40BD783CB87332B87832CA994D
D6A95FDBAE66D8A861D39E58C99149C98D4BC48C45C49446B5A752B6B05CBAAC57BFB15E
CABD6EC8BF70B9B563A6AF5E7F9343537327DCE5A1FFFFD3FFFFEBF2FFFEEAFFFFE2FFFF
E6FFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFBAB77C00000077A9D68CBDBF7E0000BBA496
A2B100000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000072ACDD450000530000000000000000000000000000007C00000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000040005C40004A770072DA00AF010001ECF400
346B69000000D6BBAE60ACBE000000C7DAF0000000000000000000000000000000E9FF00
0000005300004C0000A600008000005A00005E00006F00007D24008128008329008B0000
990000A70000BC7336A15100852D00852D008B34009F4F00C88E00DAC500A5701FBE8033
8E3D00822D00863400994900994B07994C08A45818AD6028B0642DAC6123A75E19B37F2B
CF9E54DAAA65D8AA63CC924FCA904BC88C47C28E43BA933FB2A952B6A852C0AF5BBEAF5B
C3B25FC3BB6AAFAF5D99A3506C802DB7BB6ED1CD89EBDFA4F4FFDEE1FFEADDFFFCD4FFFF
CCF2FFD5F8FFE5FFFFFFFFFFFFFFFFDDFFFFC2DED2A4D1E982B6D672ABB1CA00A6FF00D0
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020000290000
0000000000000000005AA2CA3883B8590000000000000000000000768050000000000000
0000000000000000005A8D7B00000000000000000000000000000000000000001AA10000
000000000000000000000000000000000000630085710071A80099DF00C10000006675BE
6083CDDCAE8099CDC693D6E36CAFB9669A805F85486DB3AC000000000000000000CAEB00
000000000000000000BE0000A900009E00007800008900009F4C1EA85600AC5F00B57100
D29A00EBBF00E1AF6ED59F5EC78749BD763AC6894AD09C59C29A00C1B967A88433B56C2E
9847244F0000550000A100007A0000A35911A65C17A5581BAB5E26B1682BB772308E4B00
D4A05AD7A160D8A463CA8D4DC48642C2863EBC8D3EB0993FB9AE59B49D44BDAA54BDAD58
BFAF5BBEB866A1A5518D9742647B28BBBC70DCD898E3E7B2E2FAD0CAFBDBD1FEF5CBF2FF
C6E8FFCBEAFFD6F2FFE9FFFFF3FFFFE1FFFFD0FFFFBFF4EA96CEC7609373ECCBAC9AAD6F
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000FF0000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000005E0000000000
915E3D97A76C000000000000000000000000000000000000000000000000000000000000
00C5E7000000FFFFCD85AF7B00000000000000000000000000000000002B000033000023
0000000000006800000000000000000000008600AEFFFFE80000000000006E78C0707BC1
6A8AD10000001D0000B9FFDC80C4A1A3DCD79FD9CB000000000000000000000000000000
0000001A2E450000000000009B0000A30000AB00009D4D17AB601FCC8D47D59D51CF9849
DEB400E9C57FEEC785EAC482E5C27FDDB674E8CD85E5C67CD1BF77B79B45C58843C27C47
8E4442960000AE0000F0D6CCE800008D4A00AD6B1DB7722AB46E29C17F39CC924DC8994B
A06000B87932D4975CCB8B4FBD7939BB7B35AF86329E9439BCB15CA78F32BEA751BAA751
BAAC58B2B15E989D4776842F707E28BEC077D8DFA3D2E6B5BFE4BEBBE5D3C4EAF5C7E9FF
C0DEFFC3DFFFCDE4FFDAFEFFE0FFFFCAFBE9B9E6C9008B7E337351B70076000000000000
4C5B96000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000002C0021000000807C968D9F8B00006800006F0000DB
CBCC93CEBC73000000000000000000000000FFE4E2FAD5DDDFC8DABF00008600004D0000
31000022000000000000000095580091500086000000002F00003000004200000000004A
0000000000658256716800000000000000004700005F0000000000610000000000BE8F9F
E1ACB2FF0000FAB99DC57F3ACCE5B8353845A28FAA000000000000000000735482F4DCAB
F6D6A6F1CA9FEBBE98D500008E0000A50000DA0000AE5F28A3560DAE6B16BC802CCA9444
D3A454E2C073EAC880EFCC8AEAC885DDBB75DDCA7FE3C17FCFA85FB67A28C78D3FD59C5B
D1996ED8CBA6E6FFD7F5FFDEC8E795A09C00B17900AF6C1FB57226B97A2EBB9D48D6B768
D1AC5DCCA051C78B49C37E45C27C42C38042AB7521B3A24CCCB261C6A452AC9237B9A34B
A19B429C9D45878D366C8333899F53A8C488AFD19ABEDDAAECFFD9F0FFFFEAFFFFCCE4FF
98CCE7C7CDE5C9DBD6CBE9C7A1CC00CBE0ACE9ECBAFFFFFFC1C4B2BFC0D8C5A5B1B98C78
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000011353D00460000790000000C346C0000A60000B10000AA
7CACB08DA697000000000000000000000000000000FFDAD9F1DCF2D10000AE00007B0000
770000BBB2D5D3C5C9F3DBBEE4CA00D1BB00A76D0000005100004A00002900004E000053
00000000005F0000000000003B00006400008300006700000000004D00148F005BD200A3
F6C1BAFFDBCAFFE9D0E7C18AD3A05700A29D0000A50000007D5E787E7CB096AADEAEBEBB
F9FBBFF3EFB8C10000D2AB91D0A761C68C4BE20000D0905EBF7939A85C11A70000B37120
B87400C18335CA954DE5BD7BDAA462CE9853C69A54DCA766CC8C4FBE7640C1843DD09A4F
E2B271EFEAA8FAFFD8F1FFC7CCC67AB6A54DA46D00B06E1FA66E1BB3802AA49133DBC174
DAAF67D29B59C8864DC58148C68346C78748B88232A17923CCA75AD0A559A0872ABAA34C
9890349D9D4478832C6E853489AB68A0C58DB9DAA8E6F8CEFFFFDFFFFFFFFEFFFFD8E7FF
538A00D3C1D2CFD4D6B29492D0E6B7DFECBAF5FFEDFFFFFFDCEEF9B9C1D2C5B49F6D8044
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000005A0600793400986100B88F00000000000000
000000896A8F7E404EA36C73C38C83EAB3A1FFCFBCFFD0BBFFD8AEF6FFFFD40000A692B9
8F89C0FFE5D0FFFFD8FFF0B4EEBA82D2A364835E0000187300001D00005D000068000061
0000690000350000502700444B00433A00334100006839667D3C4E995100AA6700B37000
EBC700F9F3C5F8FFD0F8FFD0F6E2AAF1DDA1FAF3B1FFFFD8FFFFF6E8FFFFAAFBFA8CD8E9
B7FFEAE10000690000940000FFDA9DEFC78AFFCEA0FFD5B5FFC79BDDA85EDAB05ECF974A
C27C009E0000923B008F37008E35008C34007E24007E2400822A00862E007F0000BA7E30
D40000E7BB7DE6B878CDB56B000000CE0000B90000C1903BC692008E8323D3C475E0C580
E8BB80E5B17AE2AC75E1AA73E3B174E3B776D1A85BB78632632400AE7C00927919A3983D
978B2F8182277187356F924B9EC289CBE9BDECFFEAFFFFF4FFFFFEFFFFF9FFFFEFEAB600
843D00000000000000000000AEA96BAEC2F3E1D5F9FFEAD5EEDCBEC4DEAA000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
1400003F00005700006F0000590B0A802E139A4700A35B00AB6E00B48200000000000000
9DB1D07772AC9D6871A9777FCA9A93EBBDA7EDBEA6EFBFA5F2BFA4EFC897DFF0FFB199B8
9A90BFAAA1C8FFFFD3FFCFA1E09F6DB971006E1D00001A7600000000006F000064000071
0000750000350000540000413F004D1A00325F00746000766E3D62966172B16F69914400
BB7E00BC8D00FFF8C1FFFFD1FFFFCEFEFFCFFFFFD7F9FFF5EDFFF8DFFFECC8FFDFB0E6D4
98D9DFB07F5BE2B088FFE1B5FFE8B8FDD49AFFD9AAFFDDBBFFCDA1E2B268E4B872E6BB74
D59B55BC7200AE60009D4900933B00A85800A75800913B007F2600CC8E00DFB200DFB987
D3B46CA40000B08955D6D9910000000000006B0000C90000D29659877614D8BC6FE1B977
EABA84EBBC83E9B97FE5B87CE7BE7FE7C481D3BE73C6B05CB49F47885E008A7110A19D44
9D973D717418627B2A88AB6ABBDBAAE5FFDDF1FFFBFDFFFFFFFFFFFFFFFFFFFEEED5AF00
CFAC00FDD9DBFFFFE700000097A252E7D0CEFFFFF3FFFAD8E1E4BF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000046720000007C7EBA
33000073A99758A2B000000000000073B0C089C6A58ECCBA0000000000003600003E0000
620000915563AD7175E9B58DD80000A10000650000780000900000B00000008D00000000
0000000000008C4546A85E4EBE785AD19267E8B278D7AA59BE993D9285262971B84482CA
467FCA3B72C20000000000983548A142499EA18BB5B093B2C49DABC28F95D8A390000000
000000E1AD74FFFFF6320071AC00FFC900FFAFE4E4E3D9E5CAACC4C7BCD5ABAFDDA7AEEA
6566AE00000000009C0000C5D1F8DEDDFAD4E7FAD0ECF8C9EBF4C0CCDFA3BBD695B7D596
AFD295A2CB8F9EC98FA9D5A3AAD8A9A4D6A8A6D6A7A5D4A3B5DDABAED9A5BCDFA9C4E6B2
C7E7B3BADBA4BADEA9B4DBAAA5D3A293C48E84AF6F89AE6796BD7E8BBC887FB98D7EBC98
85C2A08DC08E75AA738DC2958BC19286B9868BBA8385B78190BE858CB4747DA8696A9149
97CAB0BBE8E8A7D4EE859DD47000B68472B0F3C5DFFFEEF3E9CFEBF0F7FFD7F7D8CFECC3
C6E2AF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000FF0000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000046000000000000000000000000009F
0000000000000000000000000000000000000000000000001600003D00004E000059003F
8748599E616AAE7479E9B38CDBA264D09348820000924800620000000000000000000000
0000000000008B4241B66F5BC6845FD49865E1A969D2A150BE9438856F0B0045962456AC
5481CA4C8BCD00004B00007C27328C4300928F75A59B7CA5AD92A2D9DEBAF1EFBDF3DDAF
000000F3E2ADEAF1C0440090C500FFBA00F6E7F2FFD8CDF4E3C4CFD0B7CAB5ACD29A9CD4
1B0F190000000000D4D2FDF0D7FEF1DFFCD8E0F9D2E5F8CCD5EBB8B6D89DAECF90ADD195
9FCA8FA1C788A1CA8EA7D29DA4D3A1A8D9ABA9D8AAACD7A5B6DFAEA9D7A6B1DBACBCE4B7
B2DCACABD8A8A9D6A7A0CF9B95C48D8DBB8191B77382AC6A7AAF7A71AC7C7ABB997BBFA6
7EBD9C83B68088BF918BC29694C89C87BB8980B58164A2745B9E7C629E726D9F63446A1F
8EC6BD00D8E370AACE5065B33900888078BDE9D1F9FFEBFFFFF3FFFFFFFFD6F1CACDE7B5
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000001F7F000068000063000000002600005D
0000003300004100005200000000000000004300283E00004000005600003A00347C3C4F
8F515F9E636EAE767EEAB68FEDB887E3A96F9D0000A8A500B784000000008530007B2800
8739008C413EC17C63D29272D79D73E3B17AEEC480D2A955C09C4090710000008E003794
4E6AB9587FC500005E00006300007460008A8D78B0AD9ED3E2FFF3F4FFEBEAFFD2F0F6C8
F0E0A5ACA656A5B370BBDFC1BC00EC9DC4F70000E3C6B7E2CBA7B9C1939CA88BA7000000
000000000000D6FFFCD2FFFFDBFFFADCFAD5D1F3CCC8EABEB3DBA7A8CF94A3CA8E9EC98F
9FCB92A4CA8BA5CB8DA7CE94B6DDA9AFDCADA5D2A0A7D6A8A7D6A9A4D5AAA6D8B09FD3A9
9DD2A7A2D5AB9ACC9C94C48E97C68F90BD808AB5766AA26B70A9767FBC9790CBAB8EC9A5
8EC39693C18B8ABE8D8FC49689C0927AB17F619D6D5FA4846EB1936CA97E5A8F5400002A
00000000000000003D23358B2E2D828080CAD8D7FFF2EBFFFFFFFFFFFFFFDDF3D26C904D
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000004200000000000000000000003600001C
95657D2800003000004B00009200007D00595C005947005D49006124002CA10066D09C93
D09B90D19A8ED19A8CEAB793F7CB9DF1C088003D00003F00900000235268B06A00862F00
AE6200C88669DA9E79EAB488E3B07DEFC483EECC88D3B864BFA54A9A8A00000094000081
0051A6272F4D0000790000630E004E6600999996D1C2C8FFD6E9FFDEFFFCE4FFE8E3F4BF
C3C2786B813593B687AEE7DF0000000000000000858072B19D7696AF7175CCC7A1000000
0000000068540099CBD6FFFFDBFFEED8F8D2CFF1C9B6E3B8AFD59BA3C8879CC88D9DCB94
A4CE96ADD39AB0D193B8D79ABDDFA7ADD6A09CCE9E97CEA383C09F8BC8A887C6A986C6A8
95CFAC95CEA88FC9A191C49192C49086B4775A945D73AA7496C58F9CD0A59DD4B098D0AC
89BF8E8BBB8587BD8E84BC9073AE8058976765A57D80C0A272B494538F5C000000000000
0000000000000000000C1D78393F928289D2C9D7FFDFF8FFFBFFFCECFFEC9BBE87000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000044003E510058000000000000000000000000A57D96
9872918B668C92573AB70000A99BCA97008F7300874F00694E0022590033000000ECCAC0
FFC3ABFFC0A5FFBFA0FFC8A2FED2A500000021082ECCFEEDD3FFFF92B88CD39F70C17A00
A24F00BB7148CF8C60E7AE7AEEC083F1CD8BEED490D3C070AFA34799943700009F000000
0000890000480022830000321300616400A89FA8E7CDDAFFEDFFFFF6FFFFE2FFE3D2E3A3
00458763A8918BCEBF97D9D2000000000000000000000062000000000000EAF7FFDCF2DE
A0AD83060605C8BFC9D1E0DBDBFCE2D7F6CFC7EDC3B8DFAEAECF8F9CC07E9CC68BA2CC94
B2D9A2BDDEA5B5CD89BED593B4D89F9AC58C64A88557A18763AE9B69B3A179BFA78BCCAE
90CBAA8EC9A490C7998BC29480B68258945F77AD7782B57F90C59693CCA591CBA78AC49C
82BA8C78B2837AB68B68A87E52956B609E6F73B69A6BAF8F48895E000000000000000000
0000000000000000000000002A3D937889D2B8D1FFDBFEFFEBFFF9A2D09E000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000056007A0000003A3772000000B596AE9E0000
7E00005E0000372016000000000000000000000000673758A88096BB99B0F1E5EDF4F8F9
FFF9EBFFF2D0FFF1C7FFF1C5F9EFC3F4E1AC041269D5FFFBD3FFFFAEC2D1785E7278494F
8D4A36BE7144D28D5CDB9C60E2B36EEAD290EADB96CEC170A9A44983822500000000008A
00007400006E001E7F00004F000078626FB8ABBBFFD6F4FFF5FFFFFEFFFFE3FFD5C3D590
5B82428145006C2F00913800670000160000000000000000000000E1EEFFCCEFFFC1EBCE
414635C5C600DFEDD5E5FFD9E5FACADAF6CBCDEBBCC1DDA3A2C27C9ABF7CA1C98CADD59F
BDE0A9CEE8B0B9C77BB6C980A3C88A77A7675DA5927DC4B77BC0AF92D1BA9CD7BB99D3B4
94CCA69BCE9F85BD8D78B4875A98657CB07972A9747EBA9189C39A85C3A17FBE9E78B790
6CA97C68A87E559C784F8F62599A7065AA8B519A7D358060658C47000000000000000000
0000000000000000000000000000826C87D0A7CAFFBBE8FF87BBAC000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF0000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000004400467D008BC200DC4E4B680000280000A07B0000
410000160000CEA2555C99A66EBAC975ADAB000000000000B6ABD2E5E2F8F9FFFFFFFFFF
FFFFFFFFFFFCFFFDDCF8FFDFE6F9D0E6EAB7000000CDFCEAB9EEF57999D2282B7B593961
BA7864C98153CB874CD1924BD1B166E0CE86DFDA93C7BB67A3A046696A0D030D23000000
00000000007F001B7C00004900008E606EB9AEC3FFDEFFFFEDFFFFFCFFFFE3FFC7B3CB87
9C9F45B57400963E006C0000000000000000000000DBDDEAD8E9FFCDE9FFC2F0F2B9DFB6
9D8800D1EA00F7FFE0F9FFD9F1EEADE3ECB4D7ECB4C2D79597B76E97BE7DA6D29DB7DEAC
CBEBBED3EAB1C3D188AFBD6D82A65FA0BA82A3C1A39AD6C6ACE2CCB3E1C1B3E4C4A5D8B1
A5D4A58ABE8A70AC7E65A06D74AA7369A3706EB18C78B7917FBD997ABB9D70B18D61A176
5B9E76549872498F684B8F67539A7A317E642471556294596E944E000000000000000000
0000000000000000000000000000006193C889C6E47DBFC1000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF0000FF0000FF0000000000FF0000FF0000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000006B496F0000007A0065B300AAEC00EF625F5E00000000007C810000
3E0D3C4500004C0000000000000000355D6C202277757AB693A2CFBDD4EED9FCFFE9FFFF
E3FFFFDCFAF7D2F9E9C6FCE1C8F3CDCEEBB900000000000000000000000089638AB88993
E7AE9CF1B286D1904EC68937BDB262D1CE84D2D389C2BC6A9B9B405260004E9000000000
000070000074001B7D00004C0000905E6DBAB6CEFFE0FFFFE8FFFFF1FFF5D2FDBEA3C17F
C07443A855338A0000670000000000000000000000F4FFFFDAFDFFCAEFFFC1EFDDBDDFB0
C0E7C5DEFF00FFFFEBFBFFD6ECF0B7DFE5A8D8E8ABA7C6838FB26A9AC386BCE1B3C7EFD1
D3F0C5D5EAB1BCD49293AA5A7D943FC1A556B6AD80C3EFD9CBEECBCFEFC8BFE6BDB1DCAD
93BE8176AB746CA36C71A66D5E9D6E62A7857ABB9D87C4A07FBC9788C09562A37953966D
4E946E478E6A438C6C2D7B644590774D95746BA4746F9E63000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000034000065000000681A1167262B80575C281F23000000000000460000
643F6D6A375371313B00000000000041005F5500A27591C2B0D2EFB8E5F9BAEDFCB3EAF6
ADE7F0A9E6E993D4CF7EC1B36FB399544B0000000078BAB0126D7B0000000000B3CABAB2
FFE8B9FFDFBAF7E0B0EFE2A5ADB867CDDB9BD7E1A1C1C67A8C8F34435E000000C700004E
00008546450900000000005C0000860000C5D6EDFFF6FFFFFAFFF6EAFFDCBEEFB493B674
A14D008B3700000000000000FFECD9FFFFF0FFFFFDF7FFFFCFF0FFC8F5E6C9F7EBC9F4E1
C4F5EFDDFFF1ECFFEBECFFE3DEF4C2CFE5AEA7C98C8FB8758FB26CBCD596D5EEC1D3F3D0
DAF4C6BCD99E9CC28276994D94B376C59F48BA993CD7C68DE9F8CAD7EEC0C8E4B1A2C486
80AB6B70A46B75A76A5086496DB29383C4AB92CDAF8FC7A18BC09169A6784F9063468D66
307B5B085C5050987D559D825DA2826DAA817BB07F77A56A000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000001D000052000000000000BA8873C5965D0A08090000000000000000003D0047
89009DA892B2C400D29B009E6100477F00BE8A00CE9FB0E5CBFFFFF3FFFFE9FFFABFF1FD
C4F8F3CDFFE4AAE4D096D0B28E9C00837B00328887177073525C2F272E210000BAC3CCE4
E5EBBEE6EAC9DDEBBECEDB9EB2CA87CCE2AAD1E4AABACA8371802977A8000090AF000078
0000892D120300002D00005A0000660000DBEFFFFFF9FFFFE8FFE0CFF9C1A2CF999AB372
B18A4E000000916280AA9EA0CFEBC7F5FFEEF0FFF4E0FFEACDF6DECDF8E3CCF8E8C4F4EE
C0F2F2D5FFF4D3FEEACEF9D8CAF0C3A4CC977EAF7580AF7193BD88CFDB98D6EBB5D8F0BF
C9E8B89BC68B95C28680A057B7DDB9D5E5B1BEB25ED4D498E0EDB6DFEDB6C2D4939BB369
8BB27081B1766E9A575DA18292D1BBA8DEC69ED3AF90C3915E9B694E8E603F82582B724F
76B59378B7966AAC8C67AB8D6FAF8C80B78982AD73809A4F000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000046002363003E7A0000000000800071A26F7FA37183EDCBB0000000000000000069
6D395B9B798FC1ACBEC9B6CBC3A9BAC1A7BBC6ACC3CCA7ADF3BE99FFEBB9FFFFD3FFFFD5
000000000000000000E0FFFDE3F3C8CB9761BD7750BF8981C19CB2A5AFC695CAE79BDADD
95D4BF73AE827CB58BA0D7B898CFA991C79C7CAE7A688C4700006E000066000032102581
00006800001100004200006800409992AEF2DBF6EACCECBEB6D69CA1C483C6DFA3BAE0CF
B0DEFFBBE1FFBEEDFFBAF5E8AFE9D3ABE3D0A7E1C99CDAC797D8CA93D6CD7AC5C260B3B7
5DB0B860B2B55DAEA6009D81006F97000085000055000000A7D7AD7CBA9C529C86000000
0000008FD1D293D5DE88CEDC73BDD497D5CEC2E4BBE2EFC2EEEFB9E7E2A2B0B768DEBB73
D2B66900000049569F949BD44D9A8F377E57438A6573B79F60A68C5DA28460A4857EBB98
9DD2B1B3E2C2B6E3BFC1E5BACBE7B7D6E8B3DEE8B1000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000100006
3700204E003249000039003276007D860085B58692000000000000000000000000000000
91515BDEB39EEAC6B6CEA6A9CA9FA1C89CA2BD8D92C58674D79A7BEDBF9CFEE9B7FEFFC6
000000000000000000E3FFFFEAEDC8F6BF91EEB37DF8D5C4FFF6FFE4ECF7C1E4E3A6DDCD
85BC9072AC807DBFA779BEA87DC0A75D9E79669D6A5F8338003F90000066000058000000
00004800003900002D000050003E9A80A6ECC1E4CABCDEA9A7C987B2D08FA9D3BA98D2E5
97D3F89FD5FF98D6EE94D7D395D6C892D3BF7AC1B26DB9AF61B2AB4CA29D429999389194
368F922F007400000000000000A5B588C9BB00000068A8809FD9C3A7E1CC9DD9C3000000
00000082C6CA68B4D04193BF68B0C1ABE2CFCAEFD6DEF5D2E7F3C3DFE6AC8BA050AF993B
DBBF719971000000000000003B8461337F604A96843D8C7D43907D65AB9486C4AAA0D6BA
B1E2C4B8E5C5BFE8C3CEEFC8D6EFC2E1F2C5D6E8B400B300000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000002B0020
46002D44002C43002D76007988678D8B6C94916888F00000ED0000EB0000000000000000
98534FEBB48EDDA58BC0867F89474E661F2D7123257B2A008332008C3E00DFDDA6E4CD8F
0000000000610000DCF7FFFFFFFFECFFF0C8FFEDAFFFFFDFFFFFF3EDF5EAD2EDD3ABD7AC
74AB7A559E864496903C8F8543907E569B7F669961597B30094A9A004796000045000030
00002200004E000025000048004CA66B99D9B9E4C9ACD7A8AACD90A8D099A2D7B994D1CB
85CBDC7FC8DA7DC7CB7BC5BD74BEAE59A99D4B9F98449992358D8A27817E00003D000064
0000000000000000000000000000005DA58D00000000A09D4399A35FACAC68B4B169B5AD
8ACFCD9AD9E19BDAE68CD2DF85CBD6B0E7E3C6F4E8D3F6DADCF5CCABC78992A352C4AA55
DFCF83C9A6005DA28900000046885F00000061AA9E71B6A88CCBB79AD3BDACE2CEBDE9CD
BAE7CAC4ECCBD1F2CFD0F0CADBF4CBD7F0C6CEE8B6006200000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000027001E320022
47002C4B092558162F66273E75384D844C5EBE8177E20000E00000C60000000000813532
A35946C7805FA45E547F3C496F242D6217245C00003A00003C18009C8A00C5B56ED49D60
C68046CB8249000061F3FFDDFFFBD1FFEDC1FFFECBFFFFDCFFFFDCF5FEDCCCE6B46C9B60
006268006B77227D90378FA14D9E9D65A68467914F000000000000000091000040000020
00003700006200001C0000480065BA72A7D1B0E5C9AAD8AA9EC68AE2EEB2ECFBC3AED3FF
89CFD879C3C273BEB256A697398E84358B81247D75005F6B69B7C973BFCF9CCEEE000000
0000000000000000002E878D3D94953890982C86952480941C789213718B368D9E5EACB5
85CACDA2DDE3B0E6F69AD9E77FC8D889CDDA97D7E1A4DEE2B7E3C786AF6CACB165D9BA6E
E4C980E5CD84000000000000000000796300A8DECFACDEC9B9E7D0C5EFD8CBF3D9D0F5D8
D0F4D5D4F5D3D2F3CFD1F1CAB0D9B4B4DBB2000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000018000017000C2600192200133B0021
4300225E192D6A2535742F3D79323B8000006F00005600000000000000007F2F29A65C4B
C98469BB735DAD6250924642000000934745C78E6AE0BE80000000BFC38EDEC1A8BF8571
A05640B76F44D19256EBC08CFFEDBCFFF0C0FFF2C5FFFFD1FFFFCFE6F7C692B97DACE1C9
B5EDE2A1E8F26FC1D262B2C379BDB372A774000000986900000000000000000078000029
00005C00006900003C000062447DCB73AFCA9CD8C3A4D3A3A8CF99E8F4B5FFFFCFA2D9E3
8CD0C55EAB9A3C907F3E92863085790000000000000000000000FF539FBD00009A0000A6
00000000000000000054A6A353A5A653A6A853A6AA4EA2AE4B9FB7469BB84097B64498BD
509FCB68B2D589CBDF75C1CA00B2C20095B60095B900B8C581C2ABB8B87ED4B775E7C17B
E8CB84E4D38CD0AF5E000000CAA900CCF5E1CEF1D4D7F7D9D6F8DDD8FADDD6F8DBD4F6D8
D5F5D4CBF0D0CBF0CEA5D6B3000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000001E00071A00191F00172F001A3C001E
661F2D702934662030681E298A4140600000460000000000510000A04A22B56539C1764C
CC8D6F8800486F002F000000000000FFBCA0FFD5A4EEC88C0000760000C0CBB2C73A0000
5F0000AB7100DAAC67F2D699FFF0BEFFF3C1FFF5C4FFFFCAF6FCC49FC084DDFDCDEDFFE2
E6FFFBDFFFFFC1FFFF97D7D680BB9D66945697974297882D6D6A0000000000000000002D
00066A00096D00005000008A4389CA62ABCB83C6BC89C29976B59165AE9AC7E1B063AD9C
378978297F72277E7500565B0046487163A4000000DCB68B0000F00000FFA7E0E79FDBD6
84C7BD69B3A35DAB9F5BABA954A7A952A6AD54A8B25BACBE63B2CE61ADD45EA8D7549FD1
53A1CF53A3CD4396AF31888F479992008C9400007F00008500008A83C8E0CBCE8DD8C88A
EBD48FE3DA95D4C87ED4C97DBDAE00E3FFE8F0FFD9EBFFDBE5FEDCDEFCDED1F5D9D5F5D5
C0E9C8BFE9CA94C69F000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000055000040003418001B20001B2C00182A00186C002C
63002C6823336B26388A47506C00003600005D00003C0000750000990000B1612BC07F40
CD8C60A800845200320000009D738AFFCFBCF9C29D14120C000018000062450000850000
BE0000B07000AC8400F1DD9BFCF0BBFFF7C5FFF9C7FFF4BFD4E5ACD1EAB8EDFFD8EDFFE1
E8FFF3DDFFFEC5F9E6A5D5B377AD7DAFA551C2A955938F3500000000000000000000003C
001777000C700047A200007D3B8CBB52A1B363B2A954A18E00635C005762004D5D00595E
00000000000058A6B476BED6BDBA876F60A30000000000380000A40000E278BED481C6CB
84CABF62AF9F63B1AA64B3AE65B4B46EBBC577C0D677C0DB70BBD968B4D65FABD359A7CE
59A9CB59AABA61B0AD6BB6A751A2A0227E9000007D99D9DE8DD0E082C7E28FCEE8CACC8E
E0DA9BC7DDA2CFE2A7C8D99AB0B400DAFFFFE5FFF7DCF3C7D7F3CBD3F3D3CBF1D4BCE7C8
AADBBB84BE9A000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000742800762900
722500651600000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000002800004500003600003E00132000002700002600004900005D1C35
7E40538A4D5E8D53656B3F666900857A008E6500003900005A00007C00009D0000B66C00
C69000D6B30010176D2E3E8E00A1CAC8BAC3D8CAB7E3D3A7D1AD7DBF8852BE7336AF0000
E3B371BF94497C5A00D9CB82F0EAB1FBF7C3F9EEB4E8E9AC6F954FE5EFBBEDFFD6EDFFDF
E9FFE8D8FFD9BEE8C58EC09553884FC2B35FBAA14C84852B5C3500000000000000000000
0000790013761D609E0039820000A0006E7899BC86E2FBDB3944813A5B773D736DCEFFFF
0000000000009A98009EAE00A0C6946D5EA1B19FC300005D00007B0000590000AA4DA1AC
54A49C65B3A96DBAB485CBC686CCCE87CDDA79C2DA6DB8D56BB7D564B2D33C90AD3C91AD
3990A23C939700707B0087880600002D000000000098D8E08CD0E289CCE599D6EDA7D9C3
A7D3A1B0D8A4B2DDB0A8D09A6D904ADFFFFFE2FFDFD1EBBDCFEFCAC6ECCBB9E5C494C9A6
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003D00004C00004E0000530000510000
4F00003E00006700008300008C0000950000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000004D00264C001C2400002700002400006A00005D26474C153D
7D40558F505D906A8D6E487066006C7800754100005400004D00004600005A0000B28600
C2A9006200AE27419200307400AFE400D3E7D1F3E7DFFFDAD6EBEFCED8FFCFBCC3DDB26C
EACC84CCB564A99900B1A955EDD899F3E5ACEAE29EA8B368D9D994E9F3BFDFF8CDE0FFD6
B6EBC8B6E9C969A57F4F8A59E4CC8CCEB96BB0A14D7D8C3A7D5A00000000000000000000
000071115EA4428FA975B7AE96B47D8DA559D1E5B4DEFAF34C89B3000000C2B2CCFFFFF9
FFFFFFFFFF00C1DE00BCD6A86C4200886490A4009E002A7900578B0000B2006E9C0086A2
499EAC6BB8C29BDADAA5E2DF9EDDE095D7E17AC3D55FAEC3378D9B3B8F8C3B8F8B4A9FA4
348C9B18748F0E6B8A0F6C8C247E8F3B92980000000000008CCFE494D4EA0000BF5AA69E
7CBA9D88C8AB8AC6A300A376FFFFFFF7FFF2DEF5CCD3ECBEC3E9C3B2DEB77EB58E000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000004930755F3A6E8E6184B27A83AC6D63AD6A579D5747
9F5D4000007300009ABFA0B8C49392C88C78CB9E68B1DDC9D9CEAC000000000000000000
0000000000000000000000009ED7D4000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000004E1C4541000029000036002781007E815B7F724C74000000
000000925967926B85783F4D6300536B005D4400387400005C00007B00009B0000AEA000
768000006DBA3E6AB72963AD0044A10085BF23007C5B00B50000000000ACD3ECFFE3DAB5
E5D28BC8C000C0C100CFA754E4BD77EFCD90DDCC82647B00BEBC00DFEBB5D3EFC46CB29C
7CBEA66EAF9253916569924F630000CBC277A6A3518C913B957214510000000000000000
0000140075B382C3DAA2C6ACC0C981CED188ABC2B481B3CA68A8B2C3CAF9C1E1E5CDFFE4
C8FEEAB3EAE7B3B373A88B497A507AA07D9F00175B00569E0083B00000000000A158A7CC
66B2D277C1D68DD0DAA4E0DD9FDEDD92D5D585CBC867B2A668AF9668B09956A5994EA0A0
3D939E26819315718B00627B005570007086008895006F005A97687AB083A6D4AD308794
009395008F89004529FFFFF3FFFFEEFFFFD3DCECB8D2E4AEB0D8AA75A978000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000540000524A00758D6D99CCA0AED7A7A3DCAB94C08D61
B27F4100003C00005D000000D8B79DC3CAAC889B000000009D8FA0A0765D000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000002700003F002D2D002F95009F9D00A8A500B09782A6000000
944536954535954A3C833A356A293A47004765005E590000705E85ADA0A2ECE4BF520000
4D420000000000779700635E000000AC8EAC2D0082000000000000C4979DBFE9FFD0D6BF
E0D8929EA200E1E500C69F00D5A300E6B26ED2B1646C6700BBCB89B9D9A4A2D0A670B191
64AA8D70AC8273A0628B9E009AAA59BEC77D9DA756877919A17D22AA731D5D0000000000
0000000081C0A0BCC3CDE5B6D6E5ACC1D397CEE0A7ACD8B9B1E8FF93D5ED72BDCC65B4C0
8ED1DBAEE5DBB5CAA7BBC8AE958C924C1945003F73007FBC00000000000000006C0000BA
579FD068B2D47CC4D89CDBDB8ED2CF8BCFC782C2A57FC0A27CBEA06AAF946FB69F6AB4A1
4D9B8C37836840845B45895F54916280B6878ABD8C518F607CB07EB2DAAED3F4CEDDFFE3
E8FFF8FFFFFFFFFFFFFFFFF8FFFFE1FFFFC7D2E1A6BBD89E6EA16F000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000034000D00000000000000004D0000465B0072AF8AAEC59AAFCE9DA2C68B85A96560
964F48863C00000000000000000000B6D8C90000000000005E4E8F744400560700000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000024003E
2200300000002300003A00004C000008000F947FA8000000000000C100DA000000000000
6B00003B00006900007A23005A00003C0000A97D76405FA97892BFB4CDDACFDAC4D6C993
C900000000000095AE000000000000452F3A380000540000A7676800001F0000C8D6DEB0
DADD97A4AA006700008100009B0000C49900C4A1506C6F0095BD8099C48D8CBD8C87BA89
82B4828ABB888EB06D82A25D678300B9C7808694419F8F329B7316B88631B87E2E6A1E00
000000A192ACD5CDAFB8D29AA2C68E8FC09900000000000091D2D787CCE087CDDF87CCDC
93D4DDACE3E0ACDADDB6E1F3C1EFFF635D67B5936300000000000000000000000000009B
6DACDD79BBD984C9D68BCFCF89CCC189CAB581C1A382C09F85C09985C19D7FBFA070B59B
52946A4987564589615A986B89BE9088BD8F6098668CBB87B3D7A6D2EFC4DAFBD8E4FFED
F6FFFFE8FFFFF9FFFFFFFFFFFFFFDEEEFBCCBAD49971A16C000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
1100236200B80000000000000000000000005D005FA87795BD8FA4CAA8C3CFACBEDDB3B6
0000A9D7A2000000810000308F006CAE7162D9AB8EF3D2AAD1A5710000007D3800770000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
27001E2200005300345900472B00255B43799F7D980000000000000000004600214B0000
54000064000083434EAC6F60A06231944A0000007B0000905797D356244FBDD5E0CDCBBF
8A00006000005300003A00003200002C00004400008A3733D27D7000002700009FDAE5A6
DFE5A5E3DF008600009F0000B80000966100B1A24D5F7B2C98BF839BC48D99BF8392BC83
99C18995BD827FA56469995E517227B6C883747F2AA4A653AC9339B5862EC59342BB8600
000021000082C0B67E8CA9670000000000005C80C86988BBA4DFDA98D7E18ED1E490D1E7
92D2E99DD8F0A0DAEFA8E0F699D5DC8FB69873B8A864AFB154A6BA006392004C89005EA3
5C99D300000000000099D6C895D2B980C2A688C6A78DC9A895CBA193C99E88C096599664
4D824743865D65A1737FB6897CB38486B27898C18EB3D6A1D3EBBBDBF7CFE1FFE3FFFFF5
FFFFFFDCFFFFE9FFFFD2FFFDD4F4DBCAEAC49FC489000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000547D53
00000000000000000000000000000087006AA66E81B7859BCCACCADED3FFD1D5F4BABBD2
C5BBC70000BF0000470000C4FFF5F2FFD8BAFEDFBCF8E0B7DEC08DAD8241A3742E9B6922
844800000000000000000000000000000000000000000000000000000000C8ADB7F6E7C7
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
22002144002754003A4400375F004D664269A97C88C3A0A900000051003F612A4C723D5C
814F6D7F4D6C876086B68882000000100B0646002060003A9B00655093DCB6DAFF9C0000
9300008900007D00000000002E00004F0000000000000000000000800020BE006ED5EBB3
DFECB7EDEFB7DAB97BBA702BCF0000C5904497920081AA6AA0C58AA3C68BA2C07FA6C88E
A3BE7A8DAC676A97586490518FB17097B4718BA760B3BA6FB7A04BB1832AC89445CA9F50
9E7694D8AF8E8A893F000000000000244B5F3F89A7BBE5C7ADE3DA8DCFCF97D6E29BD7EC
88C6E894D2EC93D4E198D8E29CD4C0A8D9B798D2B689C9BF96D5D19FDEE2A1DCE7005891
110A0F00000000000000000080C3AB98D0AD99D1AF9CD1AA99CEA38EC49869A06B5D9054
598F557DAD758BBD8C7BB18176A469A6C88CC6E2AECAE3B0E1F4C7EFFFD8FFFFEAFFFFFD
FFFFFFEFFFFFE7FFFCA7E4E0A0D2B8008B5C000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000004E0043A2009AA67590AA7177AE7C18E2FFFFB9E5FF90BAE4
A1BFE1B5C6E1A99CD9FFFAFFFFF1F3FFEBD1FFE7C3FAE8BEEFE2B1D4C485B2964EC59D5E
9B5C00580000000000000000000000000000000000000000CCC0DFB0A5C9B9B6C9E2EBD7
4A8AB1000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000001D00000000000000001F001A
33001D4B002953003D75000087003E8B005A0000000000006C3B60754B728C688E8D698F
88638A794B6E88536C000000000000000000000000720055FFBCB000000000B400000000
0000000000000000000000000000004D00000000005600009A0000B66900BF005200CEA1
DAF2C9EBF8C6E8DCA3CA9A57E2C07AD6BA6A7B883196BA7BA8C98CABC784B2CC8BB7CD8D
97AD616B914B779E5E73924982AB6E608E52A3BC78C7CE89BFA95AB9933DBA8D37000000
8F83B3CBB39091893384BA91819B009A6B00BDD498B7DCB39AD1B78FCFC7B2E6F383C0E4
73B1E28AC4ED99D1EABBE5DFD0F2CFB8E3C0A4D8B6AAE1D1ABE4E2ADE6EBB2E7F1000000
6A4D618354730000009FD6B6A6D8B2A6D9B3A6D8B29BD0A796CA9E71A66F6F9E60528241
86B27695BB7E8BBC8A82AF7596B877BCD79CD6E9B6DEEEBCE7F2C1FFFFD7FFFFEDFFFFF7
FFFFF5FFFFEFD2FFD697CCB1007948000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000006E007181007B8A577B74364F97523E8B6A0000000076B9B7579F9F
61A1AA000000B8B8FFF6EEFFFFEBF2FFE2CEF9D5B1F1D8ADE7DBA5D6CA88C5BE78E7BB8F
C89075A6644E8A3E209D0000000000000000EDC5BDE4C8CEDDD8FFD3E5EEC8DEE2DFFFEC
A8B0667753008E0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFE2C3FFD0AA000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000002300000000000000002100112E0014
3F001B36000D5E002D57000024000050204E53224F55244F835778977598886889704268
62254166243A92515C000000A2667000000000000084006F000000000000007300000000
000000935F71C19086EEC19B000000000000000000000000C27E51BF8033BD980000A480
DFFFDBEBFFD6F6FFCCDAC483E7D993C3B5615C701AA6C789ADCC8EACCA8ABDD495C5D592
8496457C93458A9E53708E435589528DB172B6CC8CD3DFA2E6EAB3F1F1BBB7963F282E85
788AC9C1CFD5BBA7530000A9456900E4C100CED795D3E9B8D2F0D1DBF3E3DAFFFFA2DDFD
72AFE291CBF0ABDFEBC9F3E1BFE9CBAEDDBA9CCCA2B6EAE1BEF0FABCEFF53C6833000000
000000000000BDDCA4B0DCB0ABDAAFABDBB4A0D3AC95CAA078AD787FAF756E995586B275
A6CC9691B16F86B378A3C07FB2CC8BD7E6B0E3EFBCE5EFBDF2F8C2FFFFD8FFFFEBFFFFEB
FFFFEBF3FFD7BFE8B2006932000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000008F0000F2DCBC
F2E1E7CDA8BA4D35695D5B9A687593000000B58B9DD7B3BEB38366000000A79EC4D0E7FF
000000000000000000F1DBFFFFCBD5FFD5CFF7C8AAEDD4A6E2D69BCABC75DAC58CFFD3BC
CA9194B70075B16C5C9A552CC60000E8C29DEDC6ADEACABDE6E1FFDCEFFFC4EDE598C2DE
6F97005366B07B687A9A0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000A600008D00007D0000CD0000FFEDD4FFFFE9FFFFDBE6E5B2000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000001700001D00001C00003C0026
45002E45003052002D1C00004200003F00003C00003F0C3B713F51AE8E818A6B6E583367
8A5369935E739D718CA984A1B394B3A6819E996D89F5CD93000000000000000000002100
000000000000FDDFC9FFF0C3F7D29A8D4F00000000000000E9B583D5A354987E00000000
F7FFF9FFFFF4F9FFD4E9EDAFD0CF86AFAF5AA2C383ABCB8CA5C789A8CA8EC2DA9FC7DC9F
81810098A04C88913D55800089AB6EB0C482C6D596D9E5ACECF1BEEDF7C1DEDB99000091
C0C5E6BCD5E1CED18D00005C3D7600CFCC00827D00D5D291FFFDCEFFFFF2FFFFFFD8FFFF
A1DCFBA2DAEFA9E1E39AD7CF9AD3BB7DB58D9FD3BBB7EBF10000E3A4D8D455566D000000
000000D7EDBDC9E8B8ACD6A5A7D6AAA1D6B097CA9E85BA8A87B67D81AE71579366A2CD9B
97C18A8EB679A5C586B9CC89CEDB9DE8EFBAEBF0BCEDF1BFFFFFCFFFFFE1FFFFE7FFFFE6
FFFFDFD9F7B983AC71000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000651D229F6041EEDDB2FEFFE3
FFFFFF5E161C92CED1FFEBD5E3DAB6000000CABEEBE6E8FFEBEAFFF0C6BAEBD1D3E5E1D7
E5FFEF9398C0AFB4E5BAA1D3C3A4CAC6B1D6E0BABCC7B372E4D79CBFAF65D0BF80E6D8A4
0800003900009A0000C2AD6FD9DEA9D0F2DC77B5C6F1CEB8EDE8FFC0DAECA2D4BFA5D0E3
6C99CC5A7DBF8591ACD4AFAAA46D00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000A182000000009B0000
E8009DD4007FB99A5FC4B46E8C0000D60000FFFFE8FFFFEDFAFFE3D8E0A7000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000002B00002000000D000035002B4E003B
4A00393A00283600003700003100003900007300198D4828A57135BD99426E467090688A
A27F9CA0819EA58EB0B8ADDDC4C2F6CFE2E7CCEACFD5BF7D000000000000A3757FC9AEAE
F2DCD0FFFFF2FFFFFFFFFFD8FFE8AE000000000000000000F3CA98E0B7667A6B00000000
FFFFFFFFFFFCFFFFD5F9E9AFBFCD856B8739AEC784A7C5839BBE7FABD09AB1D39AC0DDA7
7E73009E953987862C95AB62C7D28DC5D291CFD18CDFECB7ECFFD0E9FDC600001000009A
CBDFE9CEE3C9C7DC9F00006D000069A8C600BCBB9DD8BF70F6E1A4FFFFECFFFFFFFFFFFF
DFFFFFA9E3E398D7CE7ABFB2539B8392CCAE0000CD00008D00009C0000000000FF000000
000000CAE7B6A6D09C91C39192C89E98CC9F90BE8690BD8482AE705B88009ED0A9A3CE9B
7FAE73A4C88DC3DBA0CBD592DCDD9DE9EAB1EBEEB8F0F2C1FFFFD4FFFFDEFFFFE6FFFFE4
E5FFC4AFD19A000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000076313FA25C54AA7345A18F41000000
000000000000880000540000000000000000D7EBFFEAFFFFEEFFFFEDF0F7F1FFFFE6FFFF
FAF7DD8672A8796AAA8477B5AC9ECDDEC5E6F0D8CAE2E6B5DDDBA5D1CE90A1A75D000000
F3CDBAE1C092000000AA7E86C2D39FE3FFE1D9FFEBFFF2CDF0E8BACBDBAE96BB9E000000
0000003566AA5C88C5000000C10000AA00008C3F00732200681700000000000000000000
000000000000000000000000000000000000000000000000000000D1C600968600E4D9CB
F1E9BED8D798A9A65FB5BC74C4D49BD90000EAFFE7F8FFEFE9FFE3D6E8B2000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000003900002300001B00003900315500464B003A
3A00293900004500003A00004600005E002A82404C7D3D3F5C0F1B8E627C8460878E7BA9
A79AC3ABA1C8ABA5CBBDC5F8C0D8FFBFE0FFBFE9F60000E90000910000388B8FA3ABBFC7
D1EBE7E4FFFBE0FCFFDBF0F8D8E2D2F7F3BBF6E3A4E6BD7B000000E6CB7DA28B00000000
FFFFFFFFFFF5FFFDCDF7E7B1B9CE88008D4ABFCF8B9DB56CA3C385B2DBB1C1E6BFBAC98A
8F8100988626847900A5AF60D2D792DBD893D8D38BE5EEB1EDFFE2DCEEB1D3C9810000CD
0000F0CFF3C6B3953B9D73000000A39AB4D9C3B791DBBC6FE2C57BFFFDD3FFFFFEFFFFFF
DBFFE7B6E6D192CCAD7AB89C000000C5D1AB00009A00003B0000640000000000FD0000EC
C0E9CCA5D2A284B8857FC1B988C0A998C5979AC99885AF6F71A061B7D8B39ECEA08AB982
99C188C5E1ABD0E3AAD4DE9EE4E2A4E9E5AAECECB5F4F5C5FFFFD3FFFFDBFFFFE3F4FFCC
C6E3AB000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000005100002B00116F004EA6686EC08C78BE96629572A1C39DBA
D1AABED6ADBCA80000010506C4C4F6CED9FFD6F1FFE7FFFFE3FFFFECFFFFFCFFFFFFFFFF
FFDFCBAA7F9E886DA3A79BCCD4C2E5FFE8F5E4FEE0CBD598CFDFADC8D79EC0CE8FEB00BA
EC00B3E0CD936B5495AA8EA6C99162F2FFF1FFFBDFFFEACBF4E4B8758D44000000E6B5AA
E8B8004779B83A69AD0000765700006900007A29009447319D503B93452F8637216E0000
590000480000440000440000300000240000470000BABBF1D8DBE5DDD8AD3C4000D8F2E1
F4FFDBC8E2A0B1AF67A9D6ACB9E2BBBCE6C6C6F0DCD1F9E9D4FDEBC9E8C9ADBC7A000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003500002100003000104900355C00525F2D54360000
0000003600004B00005200006E000082506B9C7086B08390AF818AB08FA69B7FA29C91C0
A7ACE3B1BBEEAEBFE4A8C9F3A7D7FDA5DDF5A1DFE000B59700000000004C72A7C490D0E0
0000007AC1E293CBF9B6E9FFD2FBFFF0FFF5FDFFD1E6D698EBDC9BE3D78DB29F00A90000
E80000FFFFE1E5DDB7C8DAA77B9B54C8CD82C2CE86A8B467C1C780CAE7C3C9E2BAD2D191
AEA44B9A7E1D766400B3B361DCDB97D7DE9DDADFA0F9F2C0FFF6C7FDF9CAEFE5AB0000DD
000000A9C58AAE943AA58C00000085D2BF91D9BC77DDBE71E4CB83FFEBBBFFF0C3F1F4C8
DAF4CEB8E6C8B3E1C1CFF5DEDEE7C6EAD9AE0000A50000AC0000000000EEA3DEDE9FDACF
9AD6BFA3D0A478B8D681C7D992CDC9A1D7B997C494739953436517FFEFB89FC68EA1C68E
BDDCA7D0E6B0DCE9B1DDE6AAE4E5A9E7E8AFEFEEB9F8F7C6FFFFCFFFFFD8FFFFCFE1F5BA
6D924B000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000007633436E2D462C0014920091D800C0FFFAFFE8FFFF5D346AA88AB4CAB3D8
E4CEEBE8D6F4C3B4E8A69CE0D7ECFFDAF8FFDAFEFFDDFFFFD7FFFFDCFFFFEBFFFFFCF9FF
EFD5E1C4A2BDA28ABCC1B2DCDEFFFFE9FFFFECF7CFB8B37DB9D9A892AA65BD8D9AEFC6B7
EBD5AC0000696862A7A594B6BE8C67FFEED8FFD7CF6E0000000000000000000000000000
D1B100644000000000000000930000995546893B008132008D3F1E95482E9A4D3C92453D
82333076262A6100004800003C000000000050448BA0A8D7D3E5F07D0000D9A590A00000
CC0000E900006E0000000000A2D7BA000000000000C1EDEEC6F1EAB7DFC3909F00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000033000000000000000058004064005065005A3D0045000000
0000005F000062000077496E86648A9B81A5BAA5C2C6AEC6D1BCD5C7B2C4B29EBDAEA9D4
B4C3FAACCFFB9ECEE890CDEC8CD1E480C1BD73B196000000007E98AAA7CA92A7CD000000
0000009BB9E9B7D9FFC7FCFFDDFFFFF5FFFFF6FFECE7F0B6EEF9BDC2CF84A0A100004101
868E00EC00008DBFA388BA8C00CEACBBC173C1C97EB0B25FDDCC81E9DB98F3E6ACF6EAB4
B6B05B9D7C1B7E5F00B0AF5CD6DB98D0DC9C4A1F51000000F5F1BFFBF5C4F6FEC7E6E9A7
CABA6AAC872CD6B767AC8E3391630600009FBFD0C500CA97E7D18BFDE6B0F5D69BE4DBA2
D5EEC2CBEDC6CBE9BFC7F2DFD7E9CD0000000000B20000B90000000000C95AABB68FCFCF
C2E8CB0000002D9EDC576DB4A4E4E9C8FFD5AAC383008500517225BFD08FB0CA8ABDD79D
D0E5B0E1EEBBE2EAB3E3E8AFE2E7ADEAEBB4F2F1BFF9F7C8FFFFCFFFFFD0EEF3BFBED193
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
813C477A384B7C00533800239F82A7CCC6DCCFCBCBD2E1EB0000009B79A3BEA5CAE8D1F0
FEF1FFFDF4FFD3D9FFD0E4FFE3FFFFE2FFFFDFFFFFDBFFFFD1F2FFCCE4FFDBF1FFDBE8FF
C6CBFCB9B7E6A393C6B9A9DFD3CCFDEDFFFFE3E4B9966F5CB2D4A36E355DCB919AFFD8D2
FFDFBA9E98470000819C97D0AC8FB78900004F0000700000000000000000000000FFFFD7
DDD700947F0000000000000000007D000073BC7863C2815FB5724DA962459345308A3B33
82323272273B712B465C00003A004B6E4A820000004A0000BE7F87CD8F92D8A19DFDD2AC
EAC292E10000C80000A900009A4D2E000000000000000000C2EEDCB8E3008B9000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000070008100000000002E531C415D274A62004F44003D000000733B55
79486978486A845C8196799F9B8CB8B2A2C5BEB5DEC9BFEAD3D3FFD0E6FFC4EEFFB7EEFD
AAE7F49DDFEB86CFE175C3D97CC8D371BAB044815500B3B3006A89009CC793B2E0000000
7693D592ADE7BADDFFD2FFFFE8FFFFEBFFFFEDFFFFE9FFD8CCEDAEACC47D93A1001E5300
74A300008F8300736A008360A2B162B0C078ABBC7198A95CDDD390EDE5AAF1F1BEDDDFA2
BDC0709C8628916400ACA34CC5CE8891898C8AB691F2EAB9F5EDB9F7FFCBF6FFDFE1F1AE
C4B565AAA854B49A42B38C349B6D119A690EB5BDCA006F8A00A2A095DCA136C47DDCD390
D3DEA0C8DA9CB1DCB7B8EAD9D0EAD40000000000BE0000006900B09EC5D6ABDFD5C3F4FC
D0F1D7D1E3AC0000002E4298325094E5FFDEABBC71009900869D4FABBF77C4CF8AD0DEA3
E0EAB6E9EFBCE7EBB4E6EAB2E4E9B0EEEEBAF6F4C3FBFBCCFFFFD2FEFECFE9F3C19EB26B
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000651C28722B3486434B9D5D66
BE8E9EA2769458214D5C203FA9767ACEABB4000000000000A17AA0C7ADCEE6CCE9FFEFFF
FFFFFFFFFFFFE5FFFFE5FFFFDDFFFFDCFFFFDBFFFFDCFFFFD1F3FFC2DDFFCFE6FFD1E5FF
C4D1FFC1CCFFB1B5E6B8B6EBCDC9FFD7E2E9A3C699635D4B8D4F6897586FE29DA5FFEADF
E8DCA4CFB876000083979FDB9C9ED6A6A1D5B3B4E6C1C8FFD1DCFFDCD7FFF3ECE6FFFFCF
E0E0A3C0B56B8460009F6F00640000600000B47F46C78670CD8E6EB670559649418C3D3E
8D4043955060743D674C00623C1052000000A00000DFA3A5E1A9A5FFCFB9FFDFC4FFF1CE
FFEABBDCDA9ED9DB9FCF00007200009D5628B7754ACD9600C694009300006F0000A08F00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000008A00576000680000000000365521485A24480000000000009F748C996C84
92637D9266859A7A9DA98FAFB0A1C4BFB4D5C4C4F6CCD1FFD4EBFFD8FFFFC8FBFFB7EEF5
A9E5DD0098AB58AEC000000000000000000000D1C500828C00557A0088B86900B1000000
4776C46F99E0ADCFFFC1F2FFD6FFFFDEFFFFE0FFFAD4FFD2B8DDA39FC282032D06007276
237A72007E642C690093AF67A0B56A9CB56E92AF69B9C987DCE2A9E7EFBCECF9CBCFD693
BDC272CAC87AA6791BAC9439000000000000F6E5B7FAE1B5FCE4BADAC081E4E7A8E3EAA5
A6AB5EBBBF72C7B161C39B47AB7620966207885900B8880036E6B300CB9C00AD94C8B868
D3B57B6A76540000000000000000000000008A00818E4287A000CCD700DFCCF7EDB0E8EF
B6E4D6D2E8B6000000003A8C235297799D86497028679861A4BC74AFC178D2D793E5E7AD
EDEFBBECEDB8E8EBB3E6EAB1E4EAB0ECEDB8F3F5C3FAFDCEF6FED2F1FACECEE1A9005019
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000046000D6C00368C4B58A36674A56773A66873B5797B
8242576F304D591E440000006F0000000000814E729F779ACBB1CFE4D3EFFFFBFFFFFFFF
FFFFFFFFFFFFEAFFFFE6FFFFD4FAFFD2F5FFD3F5FFD1F5FFCAEBFFBEDCFFBED8FFC4DCFF
C4DAFFBAD3FFBFCCFF0000009CBDEDE0CEDEDDB8C7B98EA7B4849EFFD7E0FFEDD8FFFBD7
F3F3C4E9E5B25566B18595D492A0DD99A6E0ADB7E9BECBFFD0E1FFDDE6FFFFFFF9FFFFCD
E7E3A6C2AE65AE9C4ABFA055B98A469C5F00000000000000AE00009D53477D2C2A84342B
9A50479C545485465C4C0000000000990000FFD6CFFFCEC7F1C1BDFFE2CDFFFFDDFFFAC8
E6E7AFD0DDA2D1DFA5D9D89FDDCD93D8B67FD5A974D3A875DEBB83D5B87CC2B870D1D300
896F00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000008800357A003E50004F0000006338636C446E00000000000000006EA077919C7695
956E8E936F93A4809DB493ABC0B0CBCECDECD0D8FFCEE2FFC1E3FFB6E8FFAAE6FF9CDBD0
0000000000004E1F4D000000000000B3AAA3000000008B7F170400000500262E7B000000
0000000079C700B1F0A9D7FFC2F0FFD0FFFFC2F9DEB0E2B89DCB9883B47A00908700988B
00000038784A95BC7F96B672A0BA7395B572A9C788C6DFA7DAF0BFECFFD5E6F7CAC8CE86
B9C173D1CF83DCD68EA17616D2BC72F4DBAAFDD8B1FFD7B6FFDBBFE8AD82DFB06BD9BE74
91A65BCDD08AD6B76CD0AB5BC18F3CA16D139B71158F4D00A36900009CA40086A8C5A985
990000D9C47C0000008500009200847F009DB7B1CDE6F4E8D700E2DAFFE6B8ECED9DDBE2
8FCFD000FDE5007E9C0027683853516F9C617BBAA08AB37AA5BB73B9C881D7DC9AEBECB5
EFEEB9EDECB6E6E9B0E3E7ADE2E7ACE0EAB3E6F2C0E3F7CEDBFBDCE2F3C4AFCC8D000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000003A00005A0000762E3887434C93505798555B9E5D649F5F69A15F6193515A
6A273F000000600000844865844A6A7D476D83517AD9B9D0FFDAE7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF0FFFFDFFFFFCAF0FFC6ECFFC7ECFFC7EBFFC7EBFFB5DBFDAACEF6B0D4FA
B4D5FF80ADE0A3C1FDC9D4FF000000CDD0FAC4B1D4A896C6AB95CAFDEFEEFAFFE2F1FFDA
E6F8D1CEE1B03C53A46D83C88DA2DE99AAE3A9B9ECB9CDFFCBE2FFDEF5FFF5FFF3FFFFFF
F3FACFC9A967A88234C0A359C69E5BC28E51C08651B16D42A85F3BA257399C4E3693442C
8700006A00004F00000000009877A9C6B3CCFFF8F9F8F6FFFFFFFFFFFFFFFFFFDAE7F4C3
CCE0AABCD79CD2E6B2DBE6B7E2E2B2E3D19FE1CE9EE8D49FDACF91D1C6859FA500DDEFCD
D3DAA2000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
2200105E00005100003E000000000000000000000000004300000000005300007D977090
936F949E7EA0B592A9C8B3C7E0DCE5F6FFFFF8FFFFC5EBFFA3D6E993D1D282C6B4360000
00000063375D4F005D000000000000000000000000000000776701000000613D71000000
0000000049970091D189C6F3A3DEF4A7E3E29CDCC28BC7A376B28600AEA20000006CA36E
49855194BE8498C0869DBF7F89AD6BA3C17FC3D99BD7F0BDEBFFDCE5FDD2DFF5C9C2CF8A
C1C77CD5D38BDDDC98B69E45752900EAB78AD99C6DDF9E77F0B197FFCAB8C7AA638B9A48
BCCE8FDAD698EAC785E2C079D5AF63AD8C329B74179B67008546007C3C0000348300A693
006E9A3600005B00007400008E005E927278C1C6C4E5FFD9DBFFE1B6EEE395CAB5000000
FFFFE29B9D72B7C578D3FFFF5F670E98D4CFA4CCA3A5C381B5CB89C6D594D9E0A2E9ECB6
F0F2C0EFEDB7E5E7ADE2E4A7E1E6AADFEBB6E0F0BFE5F6CCD5F2CCBCDAA4A3C07D000000
000000000000000000D4AD74D3AE7A5E0000560000000000000000000000000000130000
5200006F00007E332D8A423F853D3F843C41874046843C408138397D3336640000450000
62274C8B526F9B657FA7738D9462837D4A73EAC9D6FFE6EAFFFFFFFFFFFFFFFFFFFBFFFF
F1FFFFF0FFFFDCFFFBCCF7F5C4ECF7BBE4F9C0E6FEC2E7FFC2E6FFB9DFFCA6CFF2A5CFF2
A3CFEF7DB3DA5996BE498792000000BDC6FCB7B5E8C8BFF3D3C6FEF4FFFBEEFFE3E5FCD2
D6ECC0B0CD9475A1645370B9829CDA91A8E1A1BBEEADC7F7BBD7FFCAE3FFEAFFFFFFFFFF
FFFFEDEECC9DCDA6649F6B24BB8B4BCF9E65D39F6DD39A71CE916FD3987AD2987FBF7D70
A2005C5F002F580051A600C0D6DBFDD2EAFBF1FFFFEBFFFFFFFFFFFFFFFFE3FBDAD3EBBD
B0D094BEE2B4CEF0CADDFADAE7F7D2ECF2C7EBF0C4E3E2AED5DA9DCBCF8C9BA300D9F4DC
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
4700304E00003A000081536F7E547400000000005D0000000000004F0054700070916A8C
A288AAB6A3C2D0B9C9E9DFE1FFFFFBFFFFFFFCFFFFBDF5E283C5B45E9068000000000000
48630028002E0000000000007B00822B211D2B21285B00009200008F5F7C7F6EA1000000
3E75C3007FC20087BF008EBD3C97AC50A4A55AA89900760000CCA778AC7970A6715D955E
8FBB829FC8909AC48D8EB5789CBC79BCCF8CD0DFA1E4F8C6E7FFD8E2FCD5D7EFC0BACC87
C8CE85D6DA95D6D792B8A64FAA7F24955200BF7750C27845A77300E0A86BC3A35A817F26
EFF5C2ECDDA7F0C890E8C384DABB6F955865BA7E70C585609F0000874C008549000098B4
0064B4457EC1036071CB98599F5116AF926ACBDBBA9BD5B29AD8CC93D0C378B087FFDADD
ECC120754F00CAC3890000005B6422DBDFD1C2DA9FABCC8FCBE0A8D8E6AED9E3A7E8F1BD
F0F5C6F7F2C1E9E6ADE0DF9FE4E8AEE3EDB9ECF2C0E3E9B3CBE5B4ABCF9698B56E770000
786300B77A00BD8300B07C00E5C28FC89269A3612F8338127500008D00008E44008D4200
964C3A99504193493D843A357124206000007B2C22710000752826772E375818355A1F46
905B7AA97792AB78909C6887814D74DFB4C2FFFAEAFFFFFFFFFFFFFFFFFFFFFFFFEAFFFF
DBFFF8D0FAEEC8F1E7C9F1F1C0EAF5B7E2F5B3DDF6BCE1FDBCE1FDC5EAFFB3DDF7A8D5F1
A3D3ED90C5E08EC4D48EC1AF6D64A6AFB3E9BABCEFBAB3E5DBD5FFEDE2F0E6EAD1DAECBE
C8DFAB88A76289A9653D60AC6E8DCF86A7E097BBEC9FC1F0ABCBFFB9D5FFDEFFFFFFFFFF
EFF5FBFFEABFEFCB95B27C3C9756009F5B25AC6939B37145B87451C28066CC8E79A65B55
7100425D003BB500A2EB00FFFFFFFFEAFFFFE1FFFFDEFFFFF8FFFFD1FAF4D4F5D9B7D9A6
A2C88FC6ECC9D3F7DAD8FCE5E5FFE8EBFFE1E7F9CFDFEDBBCCD99DC1CC89B2B46A000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000003A001E540049
623158572C5A7D383F83424B0000000200000000000000009D6A7CAD0085BA0092C69CA2
C8B3C6C6C8EAD7E4FBECFFFFFFFFFFFFFFFFEAFFE4AADCBC63B4D190B6B9D1C4AC000000
8900000D00004F00008A003C000000000000000000E20000C70000AD90AC9797C7000000
619FDB56A9D6439BB62B899A177883A0C78DA8D29FA5D6A98DC08F75A973679B6288AF70
A5CC939FC78E9AC2899FBF7DB9CE89D0DC99DCE3A5E5F1BDE2F5C9DCF9D5CEE6B1BAD08E
CCD795D9E2A4D0D28CC2BA67BCA049BF9942B27F00BE744EC07643C88747D09950AB924C
D7B683DBA975E9B984E1BD78D3B5669D728FC29899E6BEA4FD0000C60000925900004192
0055A20059A6005EA70095D178653C9FAA7EAED6A795D0B3A9E3D693D2C0E7C9E0FACBD2
D99684C27900A45D00000000000000F8E3C7A8CA8EB9D7A1D8EDBCCEE2A9D8F2BFE8FFD9
F2FED3FCF8CBE5DB9CDDD693E6E7ADEFEEBCF3F0BEEBE7AEC2BE7292B97D008700A05840
7500001023526B3300743700B5BB9BF4CDB6D49F80B16E49B06B4BB26E56AE6A549E5749
974E438E453E782E32772E35955866A56A77A668709C574EB2726E9E595B632443703250
9D62759F6478945C778C5576CD99A8FFF6E5FFFFFDFFFFFFFFFFFFFFFFFFFBFFFFEBFFFE
DDFFF1D5FAE9CDF5E8C8F0EEBEE9F2B6E0F4AED6F5B3DAF7BBE2FBC8EEFFBDE3FEB6DBFE
AFD8F9BBE8EEC1EDE4C9F2DC8683C6A2A0D5B6B5E6ABA9DDC6C3F0F1D0C7D6DEADDEEFC3
BFD39B8DAB0000004B2D54A25A85C678A3DB83ADE28DB5E79DC0F0ABCAF9C0E3FFE1FFFF
DDEAFFFFF9E2FFE0B2E5BF8ECA9A67B0723E9D56238434009244008F3F009B4C00893800
7E2E31BB8489F1E2E6FFFFFFF9FFFFD8FFFFCFFFFFD0FEFFCDF5F5D1F8ECCFF2D3ADD29C
ABC788CBF2D8CCF4E0D8FFEEE6FFF3E8FFE2E5F9D1D8EAB7C3D89BC6D79AC0C985000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000D0000290000572B56613660
66497C000000000000000000000000000000000000000000BAA2BCCBB1C2D7B8C1DABDC6
D4CFEDD1E2FFDCFFFFECFFFFFCFFFFDAFFFFC2EFCCBDD395000000C5F7E8FFFFDAFFF3D0
FAD6C0E1BAAED9BFA6E3D3ACEDE4B5F9EEC7FDECD4EEDDEDE0D2E7CE0000A5BAE67CADDD
6AA8C754A2AD31887F3D7F549FC890ACD4A0ABD7A89ACA997DAD747CAB7096B672A3C07F
A4C483A3C587A8C989B7CE8BC6D795D8E3A3E4E8ABDAE8B0D5EDBCCAEECBC0DEAABCD699
CCE1A6D9E6ABDAE3A5D2D188CCC06E07000092573386513332131F000000BA792CC38B00
AC5D25BE763CD08F53D4A85F372A25C89A94D2AD97F6D3A2FADEAAEDD896D9C97C8E5600
00006D005AA3005EA4006F8F5A887A77B39485BF969DD5B683C1A9000000C2B0D7AF95BD
8067831A151B022137000000C6D8A8B0D5A1A0C68DC9E9BFE5FBCCDAEFB893AF0EE7FFEA
EAF9E5F6F3D2EADA9CCAC07400BFADF8FFCAF5EAB6EEE4A9A5AA5B6B914AAC0071E7B99C
D9AA80AE7600914C006C26007D3300A674838A494D6C1B00782911792A107A2B0F893D31
853932873C37924943A6635FAE727AA7748CA4718BA26571A3605B924C4D8B4B5D96586A
975769975A6E975A6FBB8191FFE6D9FFFFE7FFFFFCFFFFFFFFFFFFFFFFFFF9FFF4E5FFE4
E1FFE6DEFFE7D7FBEAD2F9EECDF3F7C2E7FEB7D9FEB9DEFBBDE4FDC7ECFFC5E8FFC3E3FF
C7E7FFD3F9F7DDFFEE000000C0CFFFB6BFF6A7B1E49AA5DEB2AFCDC6B3BDE3BB93E1F3C9
AABA799EBF8000005B0000A8608FCC6897D2719FD77DA8DE90B7E89BBFEEA5C7F4BBDCFF
D5EFFFFAF4E8FFFFE6FFFFD0FFE2B6F1C59BDEAA83CF9372C48100CA8872CF9379DEAA86
ECC69BEFDCB4FFFFEBF4FFFADDFFFFC9F6EFBCEBEAB6E6EAB5E5ECC2EDE4C7EDCBA5CB94
B0C887B8DAB4C2EFE2F6FFFFE4FFFFE5FFEEDFF6CDCDE4B0C3D89CC6D89AC8D596776900
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000004B00005F3662724A72603057
0000000000000000002D2C6EE0D9A1000000000000000000D3D3F7DBD4EFE2D3E7E5D9ED
E2ECFFDFFFFFE3FFFFEAFFFFE1FFFFC9FEEBBEE7BFC1D490E3FFC7F7FFFFFFFFFFFFFFFA
FFFFECF6F3DEE7F7D4F2FFD4FEFFD9FFFFE9E2E6DAE2FAFFD4F1FFB0CADD7DBECF6FB9C0
61B4B03B86697DB07DA0C990ADD49CAFD8A6A4D09D8AB98182AD6E87AC68A4BF7ABED18D
A6BF79A8C787BAD494C3D694D4E1A0DCE6A8E7EAAFD1E1A4C4DDA3B7E3C1B9E2BBC1DDA5
CCE3AAD9E5A9DBE6A9D3DE9DCCCB80CAC2742C0000570F04000000000000000000B67827
B371009246008C577281CCD882CCDD00948BE9C195F5DAA0F5E3ABE8DD9AD2CC81A38B00
804C000000490000A8539DCD6DB2C27CBCA68CC29464A47D00FF00FFF6FFC2AED29C7CA8
BAADB10705071E14227DAB8795C89E91C190B8E3BCC3EBCBEAFFD7D7F2C2617C31D7F8FF
E1F1F0F1EFD7FBE9B8C3BB7200C5BBFBFFEDF3FFD6E9E9B48B9B4B5C0040762E00937A00
B79F0000000000008400007FBB7D008F46007B2E007C2E00843600873A1987391B873920
9449338E4332984E3E964C3B974F458D4C5291505F91505F935059843A3E94546395566A
A2687CBF90A1DFB3BEFFE3D6FFFFDFFFFFE8FFFFEEFFFFF4FFFFF7FFFFF9EDFFE9E1FEE0
DFFDE2DFFFE6DDFFEADCFFF4D2F7FFC6E9FFC1E1FFC0E0FFC4E7FFC7EBFFC9E8FFC8E6FF
D1F2FFDEFFFFE2FFEDE1FEE100000096A8E395AFE287A4DB009BCE848DCCA195A4C9E9CA
C9EA00CBD60000008D0000BE6292CE6696D16999D26999D27AA8DD88B3E497BEECADD1FF
C1E2FFEAFFF8FFFFFFFFFFF0FFFFD8FFEFBFFFD3B5FCC5AAF4BFA4F2C1A5E7BE9FF2D2A9
EBD1A2FBF8C7EEF9CDDAF5D4D0F5DEBCEADCA4DCD9A5DCE3A2D9E6B1E2DABDE6C3BCD9A3
B7D396DAC1AEFFFFFFFFFFFFEAFFF2E0FFE8D5F1C4CEE5B1C4D99DCCDCA0C7D392000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000031001157004667375B86008F6B0000000000
00000000000018322E529384000000000000000000000000CACCF8DBDAFFE4DDFBEAF7FF
E8FFFFE6FFFFDCFFFFD1FFFFC7FAFBC0EFD5BEE2B5DBFFD8FDFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFFFFFBFFFFFFFFFFEFFFEFC7E1E0CDFFFFB6EEFF83CCC778BFAD66AC90
80B78896C38DA3CB93B1D39AB0D7A2ACD5A199C38B86AF7096BC7E8EA353ADC5819EB063
AAC17AB4CB88C5DA99D0DE9DD8E4A7E1EAAEDAE3A4CAD895C3D898C8EAC2D0E6B0D1E4AD
CDE3AAD8E4A6D9E5A8D2DFA0CCD691D5D68F00006DDEC77C00000000000095AFA2BD8633
C48A3C000000CBA192D6CDB06FBFD5A36200924F00C69D81E6DCA5E1E1A0DBD894CDBA00
733A0066000000007E438BC574BCD985C7C29DD0A8857300FFFFFCE9CBE4B296BF997EA2
BEBAB100000058A28C6BAE8D7EBB9896CFB3BFEBD0C1EED7CAF2D2D2F4CCA46B3DD4ECFF
EEE8DDFFE6BCF9EBBAC5B56900769F00F6D7EBFFD9B5CC922B780080004AAD6E00C08D79
D1000000000000005B00005D9D593F8C42229F572F984F2591471B8D411A914524914528
984D32893D2C772921833730843931853830873D3D8C464F924D56975056975257A86A73
C895A1EFC5C8FFE0D4FFFFDFFFFFE8FFFFE4FFFFE8FFFFEBFFFFEAF3FFEBE8FFE2DEFADC
E0FCE0DFFEE5DDFFEBE1FFFDDAFFFFC8EDFFC3E2FFBDDFFFC7E8FFCCEDFFC2E2FFCCEBFF
D9FCFFDCFFFFE0FFEBDDFBDED8F3CE7896D483AADE84B6D65F9DC20085AC7880C4000000
5B4B8C4D3C7A3D80AE78A2DA79AADC6798D26394CF5A90CA6499D074A4D98BB5E69FC5F2
AFD3FAD4FFFFFFFFFFFFFFFFFFFFF3FFFFE2FFFFD5FFF9D1FFF5CEFFF3CBFFF1C7F8E9BC
EEE4B1E7EAB8E0EEBEDCEEC2D2EECBD0F4DBBDEAE0B5EBE9ACE5E89FD7D2B7E0C1D5EDC0
EFE7BFF9E0B8FFF4D3F5E9C7EDF6D2E5F5CAD6DBA4D2E2ACD3E3ADD0DFA5C3CD8A9DA457
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000002E0000602D51612F539100837400634B0000000000
0000000000007FB8B00000000000000000000000009891C3BBBBEEDADFFFE1F2FFE8FFFF
E9FFFFE1FFFFD2FFFFC2F8FAB8ECDAB9E8CBCCFFD3E8FFF5FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8FFFFE3FFFFCAFFF9B2ECF4A7ECFF90D8E68ACEC19AD2B07EBA92
95C48FA7CD92A1CA93ACD49EAFD7A2A2CB928CB576A2C689A3C38296AC5F9AB369A0BD78
ADC27AC2D38ECEDD9DD4E09EDDE8ADD9E5A8D2E0A1CAD690D3D996DFEFBCE2EBB6E2EAB2
E0E7ACD7E4A6D7E4A6D3DF9ED8DC9AE3D995E9D893E8D58F000000000000000000BC8933
000000000000D8C39BE3EEB9F9D7D0F3D300E4C400B39C80D3E1A9CDDDA1EFECB4E0CE87
D2A55C9C62000000002870B3579FC79DD5D1BEDB00C9CC00FFFFFAC7A0BB8A6697C1ABB6
F2EBC900000094CAA49BCB9E000089B3E5D3C1EFE06CAC93947AA7A08BB6BF9DAA000000
000000F1F5D0EAE8B1C5BD7100B5C600E7D8D5EFC39EC28738003C0000000A07063B2B25
0000000000008F46007121007021007F31009449009E54339E54338E4128722111843521
91452E954930994E35AD6952C3856DB97A73AB6C6F9E5D66A76973B77C83CC9797E2B1AE
FFCCC2FFE9D2FFFFDEFFFFE8FFFFE4FFFFE1FFFFE2FEFFE3F3FFE0E9FFDDE0FADBE1FBDC
E2FDDFEBFFEBF0FFF6F0FFFFEAFFFFD0FEFFBDE1FFB5DFF6B1DCF9B6DEFFB1D7FFC0E0FF
CDF1FFD6FCFFDBFBF1DBF8D9D5EFC8819DD8A6C7E0BCE4E6C0EAFA001465727FC49482AA
6071B84F579A7399D58EB9E77EACDE6D9BD4689AD25F96CC528DC4548AC6699CD27FAFE0
92BFEAADDCF4DBFFFFFDFFFFFFFFFFFFFFF9FFFFEAFFFFE2FFFFE0FFFFDCFFFFD0F7ECC0
EDE9B6E2E4ACDFE5AEDCE5B0DFEEC1E1F5D0E3FFE3E4FFF9E8FFFDD9FFF5EBFFF6E7FFE2
FDFDCEFFFBCBFFEFC3FFE0BDFDEBC3E5E0AADAD194D7DAA0D7DB9FCED698B9C9876F7925
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000300000000002A002600001450204B
59274D5B00000000002B0000D2AEB50000005C2D57896486A286A4B4A1BFC9C0DCDDE1FA
EFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFFFDAFFECD5F8D7DFFBD6D4F7D8BFF1F0
C0F5FFB9EEFFA8E0F295D4D889CEC459ACB46EB3C07BD9DB9FEFE7D2F8D9CDF6DAC8F4DA
BFEFD6ADE3C99FDABF9DD8BBA4DDC0B1E7D0ADE5CCA6DFC39FD9BBA4D8B1A9DBB3A8DCB8
A1D5AD93C79AAAD8ACB3DCACBEE1AFBED89CBBCC84BAC476ADC580AFCE90B8D293C7DB9C
D7EAB3D9E9AFDEECB5D9E4A6D9DA95E6ECB5F1F6C5EEEDB3EAE6A7ECE9ADECECB2E8EEB6
E5EBB1E5E6A8F5E9B1F7E8B1F8E1A9F7E4AFF5EBBBFAEDBFF6EFBDF1EFB9EEE8ADD4D897
B5CA849B8C2D009AC600B0C1A5D4B8B1D2B2CEECD0E0CB95DBAD69D6A361000000000068
0000C50000DEBEE4BF8E9D00A66E00A46B0000002E00001700007A0018770000BC8FCCD7
AADAD0C3E7C9000000000000000000B8E1C500C3C0270000000000000000000000FFFFF1
FFFFFFF5FFD4C7E7B79AC7924D81438D00B8000000BFCDFFCAC6F1BFA9CA000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFEBFFFFE4FFFFDDFFFFD8FFF7CCF0DAA5E9CA95
EBC996EECF9EEDCE9FEACA9CF2D4A9F9DFB5FAE3BAFFEBC4FFF2CEFFF6D0FFFAD1CEDFB8
A9CEAB99C79F7CBA9F8FCAB7A1D7C3B3E2CBC3EBD1CAEFD6CFF2D9CBEFD4C6ECCC000000
000000C3B5A2CDB99CAF7048415242BFCAF9000000000000BEC9FFAFC0F08DA7DF9AB7E9
B3D0F9CEF2FFDAFEF6DFF9DBDBEEC200000000000082ADDF83A9DF759BD680ACDE95C4EB
ADD7FB96BBEA89A9E185A6DF84A5DF809FDB7D9BD87C9CDA99B6EBAFCBF7C3E5FFC9EFFF
AED6FE9BC3EF96C0EB91C0E88DC1E59ACEEA9AD2E69FD8E2A1DBDDA3DDD8A2DCD89DD8DF
96D1E18DC9E09DCFE8C7EFF5CBFAF5F8FFFFFBFFF5FAFFE0F2FFD1EEF6C9F5F6CCF5FAD1
F9FED4FFFFDCF0FFD9DDF8D6D0F1CDBCE4BBA5D19F8EBF88000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000027001B1400142F002C000000000000000000
602E556D3C6268365A000000613C6C7E608CA28FB2BCAFCFBFB3D6C1BDE6CAD5FFE4FBFF
FFFFFFF6FFFFE7FFFFDCFFFFD3FFFFD0FFF1D1FDDBF0FFF3FFFFFFFFFFEAFFFFD4FFFFF2
F1FFFBE0FFF7BFF9D0D4E0A3F6D5AEFFE9C7FEFFE9FCFFFFF4FFFFC1EFD1BCECD0B8E7C4
B7E7C8C0EDD0C8F0CEC8EDC5C3EBC3B7E9CBADE2C4A3DABAA0D9B89CD7B99CD6B6A6DAB6
BDE0B0CEEABAD1F0C7D5F3CBD9F1C3CDE1A7B2C9849DB973BCD18CC1D490D2DE9DE6F0BA
E8EDB4E4E6A7DCE5A7D7E5A9DDE7ACE5EFBBEFF7C6F2FBCDECF0B8E5E3A4E8E7A9E9ECB2
EDEEB6EEECB4F0F1BDF4FACBEDEEBBE6F5C5EAFED2EAFFD5E3F8C8DBEFBBC3D28FB1CB88
98A4549D9337D4B361DAB86BE3C37B0000007F98BF67B5D767B5D7554F2AE3C089FFE6B5
88C5E489CDCEA6D3ACB2812AAA731E945A00B48150CBB5DBB1BDFC2639913F69B88EBFE0
B5E6DBC7EDD1B9C8849579A7C3AEDEE2BCD4597D7E182222000000000000FAFDFCFFFFF6
D7F3C299C48F3A753EA5D9C87B802F0000009FB8CEE2D4C2000000B9B0E1CDCFFFF0FFFF
FFFFFFF5FFFFF2FFFFF2FFFFF2FFFFF2FFFFF8FFFAFFFFF1FFFFE9FFFFE1FFFFCFF3EDB9
E7E1ABEAE9B6EEEBBCEEEDC0E6EDC3E6F2CAEAF4CBDEF0C7C5E8C593C6A528746068A98F
91C9AEADDEC6C0EBD8C9F1E2CEF3E3D1F5E1D1F3D8D6F6D9DCF9DDDFF9DAEDFCD7F9F7CC
E3CB94BEEDFB00000062006FBE00FFD4DCFFD8DCFFCDE3FFC0E0FFA3D3EF91C1E581ADDE
9CC5EEB4DEF1C9EFECD7F7E2DDF5D1D7EBBCCDD9A03773AF548DC2669ECF6EA5D472AAD6
72A9D66FA2D56E9BD47197D47B99D77B97D67893D37C95D58AA2DEABC2F4BFDBFFFFFFFF
FFFFFFD7E3FFD3EEFFCDF2FFCDFFFFC8FDFAC2F2F1BBECE6AEE4D7AEE4D6A8E0DAA8DEE4
A2D8E88FC5E273A7D67FACDEACD4F4D8FFF8EFFFEEEDFFE4EBFFDBE6F8D3E1F6D0DEF8D3
CCEFCEC1EBCBB6E3C1A9DAB59CD1A99FD1A485B57A363D00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000003000002C00151A000F000000000000000000541D415B2E58
70456C70456E6A426D6A49797D6B9D9E96C0BBBCE1BEBDE5C1BFEAC3C7F7CDE0FFDDFEFF
E1FFFFE5FFFFD7FFFFD4FFFFD1FFFBD4FFE6F3FFFFFFFFFFFFFFFCFFFFE8FFFFD5FFFFD9
FFFFE0F1FFE7E6FFCAD5E9B9EEDEC4F4F7ECF6FFFFF9FFFFDAFFF0B9EACCBBE9C5BAE6C0
CAF1CFD3F7D5CBF1CCC2EAC2B9E5BEB1E2C0A4D9B4A0D7B3A7DEC0B5E5C5BDE9C6D0EEC0
D1EBB9D4EFC1D7F3C8DAF1C0D6EDBBBFDCA4A0C07EB2C983C0D38EC3D590DDE4A6EAF1BB
EFEEB6E9E8AADFE4A5DCDC96E3E5A7EBEEB6F1F3BEF3F9C7EDF4C0E0E1A0E2E6A8E8ECB1
E0E9ADE1EBB1EBF4C1F3F9C9E6F3C1E6F6C5ECFACBEDFFD9E4FACBCDE4ABB3CC89B1CC8B
9FA34BB6B05BD2B563D2AF5ED6B162E6C67F2A7AB38EE6DDB3FFF0C3EED6E3F7CFFFFFDF
FFFFD078C0B973B6BEACDEE7B7832FB37E00956300F4EE00CAD8FF576BBA507DC481C2DF
77BAB2B5B364000000B08CA4DFC1DBFFF7FF00006C6146826C5B9897A8DDDBF4FBE2FFD9
9ECA9A59905771A273ACBE7E74782700000071A3CF000000A3A7DFD1DFFFD6EBFFD5F5FF
DBFFFFE1FFFFE9FFFFEBFFFFF2FFFFF6FFFFF9FFFFFFFFFFFFFFFFFFFFF2FCFFD9EDF1C3
E3E8B6E1EAB9E6EEC0DBEDC1D3EDC5CFEDCBC1E7C500C9AA54967663A79586C1AA9DD3BC
B2E3CDB7E6D3C1ECDEC7F0E2CBF2E3D2F7E6D7FAE6DEFEE3E1FEDFE1FADBF2FFDAFFFFDB
FFEDC2FFEAC0FFFCE3FFFEFFDAF8FFCFE8FFCFE6FFCDEBFFCBEFFF000000705B9C000000
6B9ECEABD6F2BEE6EECEF5E7D4F2D4D6EDC1C8DCA6C6D5990058953073A84689B85595C1
73ACD675A9D8598DC75886C56488CA728FD07391D27693D37D9AD89EB8EDC3DAFFF0FFFF
FFFFFFE7F2FFE2FFFFE9FFFFE6FFFFE0FFFFD6FFF3CAF3E3C0EEDBBDECDDBDEBE6BCE8F1
BCDEF8B8D0FCA0AAE69CB0E6A3C2F0CDFBF2DBFFF2DCFFE8D9F8D7D2F3D0C9EECCB8E6C7
AADEC0A6DAB89CD3B09DD3ADAADAB091C3905F8D4A000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000003200232800172D001929001A300024000000170A5357376B6D4B7A705282
7A6395806DA08976A5988DBAA09CCAACACDDC3C7F6CFDFFFCFF8FFD3FFFFD5FFFFD8FFFF
D9FFFFDCFFFFDFFFF7DCFFEDF5FFFFFFFFFFFFFFFFFFFFFFF7F2F3F5E3D8FFFFCBFFFFD2
F3FFD5EAFDCEE1F8CDD5F9E3CDFBFCCAFFFFC9FEFCC0F1DBC2EFD0CCF2CEC7EEC8C5EDC8
BCEBCCB8E8C8AFE1BEA7DBB6ACDDB4AFDDB4BCE9C8C8F0CED6F7D3DEF9D1E1F7CBE0F5C8
DAF6CED9F2C4D6ECB8C6E4AEB6DAA4ABCD90BDD08DD1DA96D5D991DEDF9BE7E6A8EFF3BD
EDEFB6EAEBB1EFE4A6F0DC9AE8D48DEEE2A2F5F2BDF8F7C6F4F1BEE7E7ACDEDE9CF2ECB4
EBE4A8EBE4A9F0F1BDF6F3BFEDF0BBE7EFB9EAF8C6EEFFD7E9F7C3D4DFA1D1D68FCDC474
C3B865D9C87ABFBC6FCBCC86E5E2A7F4E3ABEECE8FE1B570DFAE69E1AF6D0000620000A6
4C5C934B448E000000B0E2C4A8D8B174A590959F618F822A4E86C62E5CAC86A7DD9ABBB5
A4B978CFA868D4AE8BAB6C500000000000480000ACD5C3E0C7C2F3CAEBDC93C9A5569361
79B2D5AFD8C8C2D8A39EB06E81812F0000009ACFE793A5D8000000D1FDFF98D0EB9DD2E9
AFE2EDB5E8E9BEEFEFCAF8FDD9FFFFE7FFFFF2FFFFF8FFFFF3FFFFEEFFF1DBFED3C2E0B2
B3D7ABA2D0AA6AA78A468B7681BB9D9ACFB4AADDC5B0E1CCB4E5D4BEEAD9CBF2DED7FAE4
DFFFE5E4FFE8E7FFECE4FFEDDAFFEDE1FFEFEAFFF0F1FFF0F5FFEEFFFFF6FEFFFCF7FFFE
FDFFF7FFFFF1F5FFF7DCFFFFCFF7FFB8E5F28CC7D4648F59000000000000000000000000
2B4B924E7EB988BBE0A7D5D4B5E2C6B7E1BEBCE0B6C5DEAEBFD49A00006200008C005A8C
00599B5C91CA6195CC5788C53767AE4572B8537DC1638BCB6D95D379A1DA86AFE39CC0EF
AFCDF9BED8FFCDE3FFE4FFFFEBFFFFE5FFEFE1FFE1DEFBDCDBF9D9DFFFE6D8FFF0CBF3FF
BBDAFFA9B7EAA9BEEEA5C5EEADDAF0B2E2F0C2EEEBC9F2DEBEEACCB2DEB3B2DFB8A6D8B0
9CD1AA9CD4B298D1B18BC7A6006334000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0700002100152C001D3700272B001E27001B34002B0000002D216958427C6E558971598D
836D9C8D7AA79F90B8ABA0C6ABA6CEACABD6C3C6F4DBE2FFEFFFFFFFFFFFFFFFFFF7FFFF
E5FFFFE4FFFFE4FFF9F7FFFAFFFFFFFFFFFFFFFFFFFFFFFFF6F1FEFFFFDEFFFFDAEFFFCF
E4FBCED4F3CAD9F7D0CBF7E8CCFBF0CAFAEDC7F7E5C6F3DBCBF3D2C3EDC9C0EAC5B6E6C4
ADE2C4ADE0BFADDFBAAADBB1B1DFB4C6EDC7D3F5CEDDFAD3E5FDD4DBF5CAD2F0C5D6F5D0
DAF7CFD7F2C4D0EAB5BCE0ACBBD79AB9D192D7E09FD7DC97DBDB95E2DD98EAE3A2EFEBB0
EDEAAFECECB3F2EFB9F5E6ABEDDD9CE7D188E5D088F9ECB8F8ECB7E9DE9CE9DC9AF1E5AA
F1E1A5F0DA9BF2EFBAEFEFB8E5ECB3E5F0BCE8FACDEBFFD9E5F3C0E0E6A8D7D992CFC474
CBB966BEBD6EB8C177C3D79DE1ECBDF6F4C5FFF0BCF4D79CE7C080E7BB7AE5BA77DFB56E
234DA039559FBBE5BFB3DBACABD19945794CB0973D756900006F001950A199BCF4B3C6C4
B2B77ECC9B5FB97959934E4A00004EB98CA6F0D6EDD4D9FFC9EBF18ABE915E9A6943814E
6BAACE83BFD8B1D3B18E9E598D8B3A948A395B2B00ABC1F3C8EBFDD8FFF58CC7D3AADEE0
96CFDE89C6D89CD4E1B1E0F7BAEAFBCCFFFFE3FFFFE7FFFFE5FFF3C4F1CCAEDCB878B089
38836E59977088BE9BA3D5B6B1DEC1B5E2C6BCE8CFC4EEDAC8F1E1CDF6E6DAFEECDFFFEB
E8FFECF6FFEEFEFFF0FFFFEFFFFFEFFFFFEFFFFFF0FCFFF0FEFFF0F6FFF2F4FFF8F0FFF8
EBFFF4E6FFEFE1FFEFD9FFFCCCF5F0C4EDDEB5DFC2BBD098AA00000000007D528468578B
414A7E3879AE5FA0BE7EBFBF89C7BA96CEB8A9DABEA7D4AE92BC8B4B8450004280006494
004E8700599A4E85C05789C53A6BB02656A04A75BB5783C46290CD6B98D37EAADE9EC5EF
99C5ED9CC7F2A8CCFBC1EDFADCFFF9DEFFEDDDFDDFD9F9DAD5F5D5BEF0D9BEEDEDB5DDF1
A8C8F3ADCAF3AFD0F6ADD7F2ACDEEFAADDECB8E7E6C6F1DDBAE7C6B1DEB5A9D8AD9BCEA1
90C9A27DBD9F009A77095100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000200000320013
2F00113E002436001E2800114C00334C00382A001B3B00006F49747956808461888E6D94
9D81A3AB92B2B5A2C0BAACC9C8BFDFD0CCEEE0E0FFEAEDFFF9FDFFFFFFFFFFFFFFFFFFFF
FFFFF4FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9FFFFD0F6DAC0E9C2C4EECC
C2EDCBCDF4CFD7FDD5DCFFE0DFFFE8D8FFE0D1F9D9C6F0D0BAE9C7B4E4C0B2E2BCB0E2C0
B1E5C7ADE1C2A7DCB9B7E4BDBFEBCBC7F3DAE0FFE0D1F7D1B9E5BEB5E5C2BDEDD3C3F1D9
C7EFD0C2E7BDC3E3AFCFE3A9D7DF9EDFDF9BE1E5A4E2E2A1E8E29FECE4A3F0E5A6ECE2A1
EAE4A4F2E8ADF5EBB3F8EEB9F6EBB4EFDB98EEDB9AF7E2A8F6D69BEFD595E8D993E0D18D
F0E5A7E2E1A2E3E7ACDAE5A7D5E5AAD5EAB5DDF6C9E4FFDBE6F4C4E0ECB4D9E1A2C9C97C
B6BC6D7D9F5970B190AEE3D8D4FFECE8FFF3FBFFE2FEFFD1FAF5BFF6EEB7EEDD9FE6CE8A
D5B86BC49C47D1AB5CDDBD72D2B464C2A14B927B1BB894B1FFF7E0003F941A4AA15280C8
8D92ACF4FFE7F6FFE3EBE5C0FAF3DAFFFFFFC8EAFC95CBC04C8B5CE1F1E0ACDED599CFDF
7CB3DA87B8DE9FD2BF9BB5788B95499580300000840000FFF2FFFFFFFFF4FFFFE4F2FFDC
AED3A8BBCB99569AC26BA8D388BEE4A1D3ECABDEE2A5DBCB71AD883E805962A17E75AE87
9BCBA3B5DDB7BCDFB2C9ECCACEF1D4CAEECFCBF0D7D0F6E5D3F9ECD3FAF1D3FBF6E9FFFF
FBFFFFFFFFFFFFFFFFFFFFF9FFFFEEFFFFE7FFFFE2FFFFDFFCFFDEF5FFE3F4FFE6E5FFEF
E4FFE6DBFDE6D9FBE6CDF4E3C6F0DFC2EDDBC1ECE0C6EFE8C2E5FDAFD7F893CCDC8BC8CD
7DC0B8539B8C000000000000000000000000000000000000000000000000000000000000
0000000000000000000061A00063A01D4F993661AB527BC0658BCC6D92D17DA3DC8EB5E6
95C0EB90C1E78EC6E282C1D486C7CB8ACCC283C6BA7ABFB168B2AC52A1AA009BB0009EBC
00A5C500ACCE6DB2C581C2D589C6DE90CCDF94D2D999D4C69FD6B698CCA37DB68983BA8A
C0E3C0000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000002300002F00003500002D00001700000700001B0000
00000000000027000031000035000E3D00183F001D46002C4D00363C00002000001D0000
2F00006B416979588472598B6D598F796395896F9A8F739C997EA3B7A4C0C0AEC6C7B6CB
CDBCCED0BDCED2BECDE0C8CFFFEBE4FFFFF4FFFFFEFFFFFFFFFFFFFFFFFFFFFFF0FFFFF3
FFFFF3FFFFF2FAFFE7E7FFE0DAFBDAD9F9D6D6F7D4CEF5D6CCF4D6BFEDD1B1E7CEAAE4D0
A5E2D49BDCCF93D5C390D1B980C1A48FCAA8A4D9B8C1EDCFD2F7D9D5F8D6D6F8D4D7FCDB
D9FFE1DAFFE3DBFFE3E1FFE0E5FFDCE6FFD9E4FFDAE3FFDCE5FFDCE5FFD9E6FFDBEAFFD8
E6F5C2D6E09FD7F0C0DCF5C9E4F5C6E7F4C3E4F2C0DEF2C2DDF3C4DCF4CBE1F9D3EAFFD7
EFFFD8F3FAD0D6E2ADBFD4939EC386AFD7A29DC992A8CF98AED49EB5D9A3B9DBA3B6DEAD
BAE6BDAFE0BCBDE7BD73985298C3908BC6A900A793A4CDA2BAEDDDABE4E5B6EBE9A1DAE7
60AAC461ACCF348AB100638F0086AA0090AD0091B000A9C5A0DBE7A7D6CFDEFBD4E0F1C2
ACD5A683BAA98CC6B294C49990B777335B10FFFFEEFFFFDFFFFFD4FFF9CFFAF9D1F5FFD8
F7FFDBE2EFBEBBB671DCDDA6E1E6B5D1D89EB2C181C3D7A1E1ECBFEDF6CEF5F8D0F8FFDB
282E260000000000D1DCEFFFEAF6E0DFE0ADCAC38100000064A3C466ABAB579E9E65A49E
99E3EAD6FFFFB5F4EEC2F5E2ADBB77C6CE93A4D9E4B4E4E5CAEAC9B7CB8FB9CF96CCE8BE
D9F3D0DFF9D9E0FCDEE4FFE8ECFFFBF4FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFEEECFFE6E6FFE0DFFBDEE0F8D8DCF3CFCEEBC4B9DCAE92C194
89BB8F68A379000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000004871003642000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
4800004500003400002300003100003300001300002400000000002600001700000E0000
2D00003500103A00194100233F001B40001043001232000C26000028000056264F71466D
7C537888658B79547D764E767F5D8786668F8C6D95A78FB0B9A4BFC2AEC7CAB9CECBBDD3
CBBFD6D6C9DEE2D2E4F5E2EAFFFFEDFFFFF0FFFFF9FFFFFCFFFFFEFFFFF2EEFFF4FFFFF4
FFFFF5E9FFE0E9FFD9E5FDD3DFF8CDD9F5CED3F4CFD1F4D0CDF2CFC9F1D0B5E7CBA8E0C6
99D6BA98D5B998D5BCA3DEC9B5E7CAC9F3D5DCFFE1DFFFDFE0FFDDDEFEDBD9FCDADCFFDE
DEFFE2DDFFE2D7FEE1D6FDE1D4FBDDD3F8D9D2F5CFCFF6DBD4FEDFD9FFE5DEFFE7DCFFD8
DAF6C9D6F0C1DDF4C6E3F7CAE5F7C9DBEDB9D6EFBED2F1C7CEF1CAC8EFCCC1F1DDC2F3E1
C1F0D78AC39C81B989A4D3A5B4DCACADD39BB7D497C7E0A6D0E8B0B2D091A5CE99AAD8AB
9BD0A88CC6A0A8DCC055926DCCD087D9E0A068AC9C7CC6CD74BFCB62B0AF000000000000
0000000000000000CB00009D00008E00608F0074AB1C5CA33377B11C728C0C6250000088
0000880000B9499DAA48947FFFEFEBFFFFF0FFFFEDFFFFE0FFFDCEEEECBCEEEBBAF2F7CC
F1FBD2DEF6D8D1E7BFCBD092D3D599B5BD79BBC889DDE6B4E2EFC4E5F8D4E8FFE1E9FFE3
000000FFFFDB00007B0000EEBCE2D3BEDABFE1E8BBCABD78CBC38000000000000090C8DC
8ECADA86C4D6000000000000BEB069EAE4B100006DB4E3EEB2DECDAFD09EC0DBAAD6EEC6
DDF7D7DFFADDE1FEE2E4FFEEE6FFFEE3FFFFDBFFFFD5FDFFD3FBFFD8FFFFDCFFFFE0FFFF
DCFFFED5FFF0CBF6E5C2EDDDC0EBDBBFEBD9B4E3CD9DD3B78CC5A683BA937CB28600A900
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000526B67000000000000
0000000000002B00003700004300005300005C00005700004400001A00003F00004C0000
5400005C0F1661151E6A20296C263369283B7234487A3E5372354B65253A682639743447
80455A965E6E9E7085A27890976A83976983A27790A37992A47C94AD869CB691A4BD99AA
C19DACC4A0AED7B3B8DDBEC3E6CACFEBD4DEF1DBE6F5DEE9F4DEE8E7E1DCCAEBBECDF2CE
D3FADFD4FCDDDAFFDEE3FFE3E0FFE2DAFFE1D3F8D7CBECBFC6EABFC3EDCBBFECCCB3E4C1
B9E8C5BEEAC6BEE9C5B9E5BFB2E0B6B1E0B8B4E3BDC8F4D2DAFFE4E1FFE7E8FFE6F0FFE4
FFFFE8FFFFEDFFFFCCF2FFEAEBFFE8FFFFD9FFFCCCE7F8C7DBF3C4C2E5B9A3DFC998D6C0
98D8C5A0DECAB0E6D0C2F0D5C6F2D4CDF6DAD0F8DCCBF4D7C0ECCBABDBB1AEE1C2AEE4CB
ACE5CEA7E1C79CD9BF97D5B98FC39295C69596CBA196D3B694D0B17EBE9B7CC2AC82C9BA
85CAB680C3A56FB28E63A57F569971000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000031053C48133F541737642949
5C00423D0038A17087B68FA9C69FB1CFA6B1D4AAB3D3AAB5D5ACB6E2B8B9EDC2B8FBCDBB
FFD9BFFFE1C1FFE3BEFDE6BCF9E9BCF8EBBFFDF3C8FAF0C4F6EEC2ECF1C4E9EEBFC9D295
B3C383C1CD90DDDDA4CCCC8CC2CA8ACAD79ED2DEA9C1D49EBED7A3B6D3A27AA36DB6D0A5
DAFADEE5FFDA560000E4EBC7BFD9AA000000000000000000000000000000000000000000
000000000000000000000000000000000000000000165D915E9BC97EB1E59D9A6D000000
000000000000000000000000000000000000000000000000000000890000DD0000D8A394
B60000490000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000068003C6A00004D00005F0000772D2D894240904945
91402B8E391F89331A832D15812A14812B16812C18802C1B812E1F8531208835228A3623
93412E9343319040308E3D2F89392E7B2D2B8A3D36904A4A904A4B904A4C8E494D8A4953
894851844555915360A3676DA76B71AA7178AE777FB27D86B88790BF95A0BB909DB88C99
B68C9AB98F9CBE939EC199A6C29CA8C5A2B0CAACBAD3B9C6DAC0CBE1C7D0F4D9DEFFEEF0
FFFFF8FFFFF6FFFFF5FFFFF6FFFFF6FFFFF5FFFFF9FBFFDDDDF4C9CFEEC2C8EBC0D4F0C1
DDF3C4E4F6C6DDEFBCC7E1AAC2E3B1C4E6B6C0E5B7BDE4B7BAE5BDC3EBC7D4F4CDE1FFD5
ECFFDEF0FFDFEEFFD5EFFECFF3FFD1F6FFD1FFFFD3FFFFDBFEFFEDF8FFFFEAFFFFD9FFFF
CEFFFCBBEFDDA7E0C7A1DBBDA5D9B2A9D5A3B2D8A5C4ECC7C8F1CFCAF2D1C8F2D6C4F1DA
C2EFD2BCE9C4B8E6C1ACE0BCAAE0BF9BD6B791D0B192CFB096D3B497D4B793D0B18EC9A3
86C09682BB8E80B68476AF7D81C2A173B89F6BB090438C68000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000003D002F2800132B00186900637F50767D4E74580000C1847FD49D90E7B4A0
E1AB92DCA487D1957BC98B79CF9790D5A2A0EABFB8EFC4B5F5CAB3F7D0AFFBD7AFFFE3BD
FFEAC3FFE9BBEED9A5E9D198EBDEA7E6D89EFFEBC2EED9A5DBCB8EBAB66EBCC481C6D398
B1C68991AA6881A86F6E9F6F529170005743000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000066003B7637507F41576E3351
9D687F945254A7665578924F000000C79496E1B3B2ECBBB1E1B5B6DAAFA9DFB0A0D3A300
5B0000000000000000000000D30000D70000CBA36C9A6600920000000062E200C0FFEBD0
E6C9989A5E0098553690474098535A0000007195C7A7D4E5E3D2BADDC18E980000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FED2D2A5C4DBF0EFCF
FFECD1FFFFEEFFFFF7FFF3F6C8C0D3D7C2D3D9B100CD0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
62B2CC62B2CCBCE0E03F00125E0041825775805068834C5E834652894A5183414789403E
8D44409147418B3F377E302B82353090443C9A4E43994A3997453096442E95422C98452F
9E4E39A55743A85C4AAF6756AC6352A35747A2574A9E554D974F4D914B4E8E4B53955660
A56B74AA727AB1797FB27B80B0787DB47D81B98487BF8C8FC29195C19196BF9199BE929C
BC94A1C49DA9CBA5AECFACB4D4B1B8DBB9BEE6C4C8ECCDD1F2D2D4F9D6D6FFE2DFFFF2E6
FFFFECFFFFECFFFFECFFFFEDFFFFECFAFFE0D6FFD2C8F0CDC6EECBCBF3CFDEF5C8E3F8CB
E9FBCDDFF2BFC4E0A8BED89CBEDEA8C5E6B7D4E9B4D6EEBCDDF5C8E6FCD3EDFFDBF4FFE3
F0FFE1EAFFDDE9FFDAE9FFD7EFFED2F4FFD1F9FFCFEFFFD1E5FFD9D6FEDFC8F8EAC4F5E3
BCEED5B3E6C6ACDFBCB0E0BAB4E3BDBCE8C4C3EDCBC5EEC9C5EBC3BEE9C5B2E7CEABE3C8
9DD8BA92CFAE94CFAAA0D8B696D2B098D1AB9BD5B59FDABE9FD9B99FD7B394CEA793C99C
8BBF8F7FB47F85B9869AC79293C798000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
2400132E000F49002C5A00305F1A2F000000824B66BA8C9EDAAEB3F0C2B8FFCFC2FFD8CB
FFCDB9F9C9B7F6C5B4EEC0AEEDBFADF0C2B2F8CABDFED1C4FFE5CEFFE5BEF9DDB0F5D9AA
FFEBBCFFF2C2FFFDCEF2EDBBD7D69ABCBE77E7E9B7CAD69EA7B46EB8C07B96A056ABBA77
769C5F2E6A3E000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000550000
87698993607D000000AD00796E002D5F001E762E3587434C89464F79364467293E824B68
8A5A77000000000000FF00C0FFECE6FFF2F3FFEDEFFFE0E6FFDEE5FFD9E2F1CDD8B388A1
F4CFD7FFFFFFFFFFFFFFFFF6FFFFE1EDEEC0DBD79FDDC090A80000E200A7FFFFE7FFFFEA
000000000000D7E5CF0000000000000000000000007AA8D2006E5BC68374BF7F62C38660
B2714BA965439D57388800005F00005B00007B000080332E70252A793339A36155A30000
5600000000000000000000009C0000E20000E3B58FE4B48FD3C58C637E00B3E2C8BAE8D8
B5ECEAA0DADC94CFC577B2BA0000BF486CACAAB7E9F6D5E0BEAE77000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000018003C
460000720000813E438A403A8A44438A484C5A00005800005C00006F292E844A5A853F41
84352C7F312A7C302C84352D93473D95483C95473A954638A25543A85A44B76E54C37D61
C17C64BD7865BB7969B8776BAA645B9B524B99504A9B5148A45C54AC6760B16D66AE6C69
AD7376AD7377AE767AB47E83BB8588C39091C9999ACC9FA2CDA2A5CA9FA4C89FA7C8A4AE
CAACB9D5B9C3DFC7CFE3CAD2E4CAD1E6CBD2ECD1D7F0D3D8F6D6D9FFDADAFFDDDBFFFFDA
FFFFDDFFFFE0FFFFE2FDFFDDD1FEC9BDE9C3C2ECC8C4EFCFC5F2D7D7FFE5D6FDDDD3F6D5
BCE3B9ABD9ABA9D29EC0E3B3C5EDC7C7E9BBD2E8B1DAF0C0E0F8CEE3FED8E3FFDEE3FFE1
E4FFE3E6FFE1E6FFDFE6FFDDE8FFDAE3FED5CFF1C8BFE9C4B4E8CCB8EDD7BAEFE0B6EBD3
B5E8CBB3E5C4ADDEB7B4E3BEBDEBC9C5F1D4C4F0D3BFE9C3B5E1B7ABDDB7A1D9B6A5DBB8
A9DDB8B5E4BFB8E5BEB5E1B7B3DFB3B7E1B5ADE1BFABDFBCA6DAB5A1D6AF97CB9E8BBD89
84B27894C69575AF81000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000001B0015
4100303300204F002C36001B744166B78FA9D3B3C4E6C3CCF1CAC9EFC5BCEDBFADF8C4AE
F5C4B1F7C7B8F2C5B8F0C2B6EBBDAFECBFB1F1C5AFF8CFB0FBD9B3FFE9C1FFE9C1FFE8BF
F1DEABEEDCA5F7F5C3EFDFABD8D496D1D89DC3D49AB3CB90B7CE93AEC1818CA25D000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
762A1D7C302682372D8A413A97514A955152810044A80078B98494B18197824862AE809A
D9AEBDFFDBDBFFFFEBFFFFECFFFFF5FFFFFFFFFFFFFFFFFFFFFFFFF9E7FFD0CBEDE9CFE8
F7FFFFFFFFFFFFFFF6FFFFEDF5FFDFE6F9CFDAE8C0DBDBB0000000F4D6C5FFECC9430000
000000530000AD0000BB00009E0000000000A6A97200BFA4B5B786D2BB87BB9054000000
D8E7BB010406000000B40000B90000BC7E79BC7F80AC696CA45E63AD6C71000000000000
F6CBCDFFFADDFFFFEAFFFFDDECF2CCF5F4CAF9F4C8FDE6C6FD0000DDB3D0BD97ADA76548
A4C38D6BAFC05B9BBF4875AC0000B70000FC92C0F1B9D2B0000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000002D000074370086000088C7E0000000000000A0A090000000
0000007D808F000000000000000000000000000000000000000000000000000000A06565
B47B76C79187D5A19031357D54508D625E986C69A27572A97273AC7672A8726EA67677AF
6B6DA96061A06F71AC807CAF8F82AE7F6E9D7A66947D68949D86A8A692B2A596B8998FB9
9A92BCB7AAC7C2AEC1CDB1BCD7B5B7D5AEADD0A19BCB948AD5A297D6A59BDDAEA3E3B5AB
E8BCB3EDBDB0F3BFADFECAB6FECBB9FFCEBDF6C7BCEEC2BAE8BFB7E8BFB6FFCABDFFCEBF
FFD0C1FFD5C4FFD7C6FFDBC9FFE2CCFFEFD0FFFCD4FFFFDAFFFFE0FFFFE5FFFFEDFFFFF7
DDFFFFE4FEFFC0E2DAC0E2D5B6E6C6AAD29FA3CD99ADD7A7BDE7C0C0EFD2AEE4C8A4D6AE
A1E1D1B6F3DDCAFFE8D2FFE0D5FAD2CDEDC1C7E9BBD3F5D1DBFFE3E1FFE1E7FFDFE8FFE2
E5FFE6E4FFE6E2FFE0E0FEDADCFCD8D7F9D7C6EFCDBAE7C3B0DDB2A2D2A3AAD7AAB5E3BE
C0ECCBC2EECDC4F0D3CAF4D8C8F0CFBFE9C0B3DEAFB0DBACC0E6B9C0E5B5B8DDA8BBE6BF
C0E7BDC7EABEC4EBC2C0EAC4BBE7BFBAE6C0BDEBCCBCEDD3B7EBD39BD1AF87BD8D8CBB84
98C38A639353000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000050000
1800001A000024000E0B00004000002B00005B00008D0000A96054BA7460BE7961B66E57
B26A55AE6455AF6552B36950BC755BD69A83E4AF8DEFC09CF7CAA7FFD3B1FFDEBBFEDFB6
F8DAADF8D8ADFBDBB2FFE5C1FFE4C3FFE7C1F2E0ACB1AD61C8CA87DDDFA5D0D08FB0B76F
7883334F763300000000000000000000000000000000002E5800683900396D36587A4C74
966A8C7C507A9579A5A7A8CEB3C1DFB1B6DDC1C4F0C2BFECA28EB9EBD5FFFFFFFFFFF4D4
E2F0C8C7E2B8B7D8AE9BC79F6789C3746EAF5500840000008CBFD2AEDCEDC3D3FFF6FFFF
C3EDE7BFEBDDB5E4D6A5DACC97D1C889C7C77BBCC661A5BD579DB36FB4B478B1979CC18F
C8E7C5DBF6DAE5FDDEEAFEDEEBFCD9EBFFE4EBFFEFDDFFF1D2F8F4CFF6F2CEF4EFBFEAEF
AED8EEA0CAEC98C4E7A6D4EBB4E0EB0000007FB0D09ED4D69AD2CF00005700C1E8000000
82A7DC8DAFE000ABDC0098CC6995CE81AADC9EC6ECB3D8F8BEDFFFBDD5FFCEE1FFE6FFFF
FFFFFFFFFFFFFBFFFFF3FFFFEAFFFFE0FFFFD9FFFFD3FFFCCEF6F1CCF5EFCAF4F1C4EEF3
BDE6F8C6ECFFD9F7FFE6F4FFE5ECFF6C4F90B6D0FFDDFFFFCFF5FFE3E3C9E3CD9EFEE2E3
FFFFF8000000A0CFE6CEF7F5D8FDEDDAFADFD5F0CB000000000000005146649E7D009100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000097006E000000
4F346064446A7556789777919C7B939E7B92885E767048665C365B4520492F0C3A150015
6700419D5C53000000000000000000042433000000000000000000D9CCD27C9D9E000000
000078000000000000000000000000DAB6B5E4BCB3F1C0AAE7B9AAE6BBAFE2B09DE3B09A
E6B39BE9B69CF4C3A7FFCDB0FFD1B2FFCBABFAC7A20000003A71BA648ACD7C9EDA7193D3
577DC5416AB7315DAF396AB94D81CB5B8DD36897D96896D86492D66796D96292D75788D0
4676C24D75C06889CB7FA1DC95B8EDAACFFFB9E0FFC5F0FFC9FCFFCBFFFFCCFFFFCCFFFF
CCFFFFCBFFFFC8FAFFC5F4FFC0ECFFD2FFFFF2FFFFFFFFFFFFFFFFFFFFFFF4FFFFEEFFFF
E3FFFFDEFFFAE8FBDCD7FFE3C6FCDEB8E6C0ABD9AFA1D1A4A9CF99BBDAA3C3C9A0C9AD96
AD9292B5C4BEE1FFE1DBFAD1E0F9CAFBFFD3FFFFDCF7FFE6FAFFE5FAFFE0D4FCC0BEE0AE
D2E7AFDEE3A7F8FFD1FCFFE4FFFFF7E1FFE8C1FCD68DCAB37FC3AA71B79A90CEB5A8DCB8
9BD2AB98CB9EADD9ACBBE7C1CAF5D7CDF9EAC7F5E7CCF6DFC9F4D9C4F0D3BEECCCB2DCAC
BBE5BBC3ECC5C8EFC8CCEEC4B9E2B5B7E3BBB9E6C2B0E2BEACE1BEBAEBD0C4F1E3BCE7F7
000000ACD9C8A8D6A9B1DEB4BADFAF759A00000000000000000000000000000000000000
0000000000000000000074B580A7B29AD2C07ABABD0000C4CCEFFF996668ABAC89CDCDC3
BED6E88FC9DB7AB5A10000DA000000864C68AA7485D29FA1EBBD95D89E82BA7148CD8962
DB9D7AE4AC8AE5AF87D99E6FCF8F59CD8E55D49B60D7A063D3A363C49A50D1AE65E2C584
EBD397EBD398E6CD8FE9D397EAD69BDBD18FE6E0A7EEECBBF0EDBCEBE8B6CCC07CD8D091
E5E4AFE4DCA0EBEBBAECF1C1E7E9B5DFD99BD2C883828E3C000000000000000000000000
0000002B592157275560336132004140005CAE8AADB998B8A781A4A480A6B997B5FDCBD4
FFF9FAFFFFFFFFFFE0FFFFECFFFFE2FFF9C9E2D9A3BDCE95A0BB809DB273BDC688CED298
E9E3B6E3CB9FD5D7A7DFF1C9E9FFE6E8FFDEE9F5D0E6EFC5D9DAA3DBD7A100508900BFE1
AAD2EEBDE1F8C8ECFD000000A1BFD0DDFBE2DEF8DDEAFFF9E1FFFFD7FCFFCEF1FFD2F7FF
D3FBFACEFAF7D9FFF5E4FFF3ECFFE7E9F9D2D8E1AEABC081AEC58A55681D366C38000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000006CA7007DB24280B24887B560A3C162A7BB57A1AE008E94000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000090963A869982BDAB9AC5E9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000002700262E0034410058
6A517A6C527B6E547C947D9D99809D90718E7E58756E496B5B375C0000000000003E0035
73004100000057223B000027581A28774D4BAB9B990000007B3E458E5A3EA276374E98B6
000084000000000000000000000000CA9B97D2A199DAA89ADEAEA0E5B7A8E9BBA9ECBDA9
F5C3A8FFC9AAFFD0B1FFD5B7FFD7B8FFD8B8FFD7B20000002366B25983C96F94D46589CD
5C7FC64D72BC325EAF3869B84B7EC85B8CD26594D76290D46696D86C9EDE6296DA558BD2
366FBF3269BA4F87CE6AA7E47CB3E98DC2F198CFF5A3DCFAACE6FEAEE7FFAFE8FFB4EBFF
BAEFFFC1F4FFC5F5FFC0EDFFBBE6FFC2F2FFD2FFFFDCFFFFE2FFFFE9FFFFE2FFFFD5FFFF
C8FFFCA1E2D4A2E1D389D0C76FBCB676BEAD79BCA490C9A867A887D2E2A9000083000071
0000A4FCF8CAF7FFD5F8FDCFF4FFD0FFFFD2FFFFD2F8FFDDF2FFDEEAFFCECDE8B5DCF1BE
E5EFBBEBE7AEF8FFC0EDFFCF00FFD200EDC76CB7A654A5965FAEA181C8B6A1DEC7A4D7AE
98CC9FA0CD9BBDE6BECDF3CFDEFFDDDCFCDCD4F7D9C9F4DCC2F1DABCEDD7BAE6BEC1DFA9
CBE7B5C3EBC3C8EEC5B5E2B9AFDFB6B1E1BDAADEBBA3DAB6AFE1BEB3E5D4B4E6ECAADBFF
00000099D0ABC2EABAC3E8BFB1D0003A5A00000000000000000000000000000000000000
000000000000000000608BB986C0A593CBC378B8CC490000845578F4FFFF340000FFB4AE
ECECC6A1C59A000000000000000000B2757EC3898DD5A18DDFAC7ADCA9A0904F54CF9379
E0A682AF6829C2814AC37E49D29261CD935AC8914ED0A25EDBB874D6BF78CEB96FD7B46D
E5CC8DE9D699E5D495EBDEA4E8DDA3DDD99AE0DEA3E8EBB9E9EEBEE9F5C5D7DDA7B8954A
EAE1AAE9DDA4EADAA0EFE8B7EBE4AEE8DEA4C6C27B798533000000000000000000000000
0000000000006430575F2C5625002B9C769EB390B2AA85A8A880A2AF8CAFD1AEC9FFEAED
FFFFE6FFFFDFFFFFE5FFFFF2FFFFECFFFED3CED39AADBE80A3B97BB7C384CAD398D7DAA3
E1E9BCE0EEC4DBEBC0ECF4CCECFFDBE8FFE2EFFFDEEBF3CAE7E3B3EDDFB1D6B5850095C4
A2CFE9A5D6E5A6D0EA00000092B7D4C9EADDDFFFEDE8FFFCE2FFFDD9FFFECAEFFCBDE8F2
BBE8EAB9E7E8B7E6E7B5E4E7C7EDE5DCFAE3C4DBB1A4B878B3CA903B6E37000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000679B5997C0478FAB408CA23886923E8465528348000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000003600350000000000000000002B19503823584C3C6F635383
73628E7B69918673998A789E7F6A91735D866B517A53345E31003B00000032003D180028
4E0050896784000058000096D8FADCF20000000001004B0088008BB2008B503E3D75B7C5
000000744963945E65B4756AC88C82DA9D8FEEB8A7F5C7B5FECDBBFFD1BEFFD4BFFFD8BF
FFD9B8FFD6B0FFE2BBFFEDC7FFFAD3FFF8D1FFF4CD00005800009E7478B05275BD5A78BE
7AA5DF6086CA3C67B73A6AB94377C35084CC5E91D56695D86A9BDC71A3E170A1E06094D9
4E88D14180CB3D81CB478FD34D9ED75BADDE60B2DF6EBDE67AC6EB86CEF097D9F9AAE4FF
BBEEFFBEEFFFC1F0FFC3F0FFBEEBFFBAE9FFB8EBFFB4ECF991D5D885D3D883D0D500AEAD
00000097D9D49EDFDEA3E1DC96DCDA92D8D39FDCCC9BD0B387C09CC8BF82DAD9D50000A5
0000CDE2F7D7F1F6C5FFFFCDFFFFDAFFFFE2FFFFD6F5FDCBEBF2BCE7EDB6F8EFBAFAEFB9
F5EFB9C7CF979FBB825CAAA057ABB754ACC47AC6DCA7E4EFA6E3F6ACE3E1ADDFC2ABD6A5
A6D2A3C8EEC7E1FFDEF0FFEFECFFE8E8FFE0D2E9B6D9F6CBDAFED6DCFFE3DEFED6E4EBB3
C6DEA9ACDAADACDFBDADE1C1B6E5C3B6E7C8BEE7C1CDF5C9E6FFFFF8FFFFDBFFFFBCFAED
B6D2B2B5C884C8DCA3B2D4A365A278000000000000000000000000000000000000000000
000000000000000000000000000000B6C4E17C7EB50000000000753A6C9D000000000000
8B4144AF6D72B7787CC3898DC98B7AC17854B86D4CB3674DAF624BBE7868CF8F79DCA17F
EBB58DF3C9A3E2B892CC8D56BA8741C6A359D5C17CDCC883B9A251CDC77FD9CF8BD7D08D
D7D695DCD99ADED99ADAD898D9DDA0C8D393CCDA9EDEF0BCE7FCD3DAFADDCFE8C0C7D396
F8E7B7F7DFAFF1D6A1E9D398E5D79BD9D294BFBB71000000000000000000000000000000
6F35538853718051794E00598F6F9C9B759E9C78A0A985A9C6A7C2E0C3D9FFD7E5FFFAF7
FFFFEDFFFEE0FFF0D2FFEDCCFFF7D1E5DEAAB99E58A7B06CBEC98EB9C284CED49BD5DBA6
D3DDAAD5E3B4E1E9C0FFFFE2011A004883A490BAE9DEFFFFE9F1E4E9E5BFDDE2BACFD49B
000000296E9700007B0000F58EC3CA93CBD29AD2D188BAD0BAE3EECFF6F4D5FBF1C3F0E6
B3E3E2BFEAECC6EFF0C7F0F0C5EEEFB6E2D49CC9A275A16C000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000006F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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0000000000000000000000000000000000000000000000000000000000000000001C0000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000170000000000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000000000000000000000000487E812B00001000000000001000000E000000000000001A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00000000000000000000000000000000000006000012000000000000000000000000002B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0000000000000000000000000000000D00000C0000080000000000000000000024000033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0000000000000E00000000000000000000000500000C0000000000000000000061000055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0000001F00000F00000000000000000000001300000000000000000000002B0040000031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1200001800000000001400000000000000000000000000000000000000000E0036000042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0000000000001600000A00000A000000000000000000000000002200000000004211175A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0000002C00000000000000000000000C000800000000000700001300002F00004D0B1C62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26001A00000000000000000000000000000000000000001C00000000000000155F00216B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0000000000000000000000000D000000000000000000001B010127000000002900000052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00000000000000000004000014000000000000000E00002700002C000000003E82004500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12000000001B1E00000D003100002C00001600001500003600003400317500709F8596B2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0000310000431700430C003600002500001D00001900003100001F000084007AAE000000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00003D17104A0900390B003A000031000022000025000032000049324C90005495000000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100B460F053F11004306003900002B00002200002700003B00005A00008C3D61A3000000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120841140A43100B4602003400003C00002C00001E00004F00266E000092305A9E004088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0E0641170E470A054100003F000446000030000047001D6400007826488F355B9E406EAE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0E0E4B001A57000542000048000C4F000032000F5800256C0026711A428A23488E4B71B0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1C236200125100094700005100004E00003D00004B002B7200337B003D8510347D5371AF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172262000A4C0021630C135400004E00005500002B00246C00408600478D13347C5165A3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111B5C071051112164000D50000059001F6500002F0021682B468A28448913317800008C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0013560F1B5C0F266A00004D091B60001A6000002F001D64243D82263B7F002970000075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000E5100276900008500005100004D04165C00003900135B1D357A23347700196200005E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00004E163376203F8200005500003700004C0000320009521C357B122D7400579800226D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00004A2738772D3E7C00006C00004700003600004500004C1A387E0F337B4A6BAA004F93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00005100008600000000005300004E00003F00005500005015387F103F871B468C007BB7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212D6C00407E0000000000002A3B7A00064C00005F00005910377E224E93123E8600579A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1C3173002066003975000000005B9C002D7400005500125D00347B2E589C234B90002F77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1E4183284A8A000F4D003B78001A5C003777000000003177001862000040355293000B58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00518E0071A01D6C8C478DB8002A52006498004F802D3B78003C8200006148599600125A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007CAE004277003F6E23719900000000000035005071628C31173D3D32684F6DA4365D99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0099B90084A6006F9300000072455D0E1A010E0E10000000000000516DA35293C40092C2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003372003F7000000000000000000056200300005800000000397D093E83002D72002E74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000000000000002C610050750000970000AE6EB3BC00280000387B0D3E83004387003378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0000000000001B2B3A002759003258002F5500005A000000002F7400125B104488003C81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000000E9E9BE1C589300639B00296C285D9B235A98003578002E73001F6612151959647A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2B6CA12C669F2E639E2C649F005995004484366BA7005190002C7100256B003274326095
2C657D00000000006C006D91009390000000003F7E6F200200006D000000005A00BDD6E6
87B0BD64A1B7355600FFE1D8F7F4FF000000A0BC9C0039583F253B000000734855000000
000000000000000000070F0000000000000095B39449386C35215750396A52335F000000
0000000000005883BECCC1B9FFE8C6E7F5E2D3FFFDCFFDFBC8F8F9000000590093030000
0301001004021D0803855100AA5F00C79400E4B500F5CD00A6AB72A18531A14F00B06200
AD6B00006400DDD6A9CDF1FFCEF4FFD0F8FFD1FCFFCFFCFFCBF9FFBCE8FFC7FDFFDBFFFF
ECFFFFF1FFFEE8FFFFDDFFFFE1FFFFE5FFFFE7FFFFEEFFFFEFFFFFEAFFFFE7FFFFE1FFFF
D5FADFDCF7D5E4F8D0E2F7D0C9E7BEB7DBAF97C29194BE88A4CA96B2D8ABB8DDB2B8DCAF
A3C99793B77D92B67B94B87E738439C0E0B2B6D49F80AA735791659E0000C4DCD0BDE4BB
8CA7647394534650963A428A272E78313179342B715845807A5C8B6A46766B6C0072864A
789A84FFF1DB006F98005E98462958348A7D188D97000000A6A9D395A4D7849DD55F7FC0
1F0000C7000057849800261300007F006CA2F5F2ECFFFFFFFFFFFFFFF8EDF5C2CE795280
00000000000097515477446B000000000000000000763651733C60A46F87B6899BB58C68
B48E5AD0AA7900000097617DC4A2BC000000000000936B959A70970000003A0A2D98607A
CD988DD9BC9ECBD4A30000000000003C337B51468BF3EAFDF8E7FDCEBDD1C49DB5B4936D
BEAC6253600000000000004B000000000000000000000000000000000000000000000000
0000006A8FC8BEE2FF6FECF5E50000FFFFFFFFFFE1000000967A82000000EEBDA0FFE9C3
FFFFDDDEE7BE9B6900ABA8660000006B414FD4C0B9E1D1AA8573A347003600000000769B
0080A6B7A3B23900482E0097A4CACE000000E5C300F3E9C8D4D59DBDB369BCBD77D7D69A
DDD69CE9D8A3E8D09AE6CB94EECD9FDDBE86D6BF80E1D69BD3C685D4D092A0A960000000
000000000000774A74000000740000D9BFD7C900CF6D0084976583EBC1D1FFFFFFFFFFFF
FFFFE0D8E7BADBF0CBF2FFE6EEFFDCDEEAC1729A64B7CFA2DEFADEDDF8DEF5FFFFFFFFFF
FFFFFFFFFF0000000071A1000000000000000024568DB7D8AFDAD5C8E9CCC3DCAEBFDEB4
DDEEC7E7FBD6F0FFE8EFFFEAEBFFE0D1EDD8D6FFFFC4E9FFC6E9F5D1F7F6D7FFFCE2FFF1
CBE3B600000067529021005C2C5D9A1556862C718FC5EEEC0608117A00006983B50069A4
4B73AE7EB8D294CDDA8DC7D77FBBD089C6D08BC9C485C4B17ABAA45DA084000000000000
000000000000000000435BA4769BCD8FC6D7A2D8CB7DBCA2000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
226299286A9F074381005E9B406DA82C5C9A004280005D9B00387B00327600397B003F86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29629B407EB0306CA300357626599639629F1D5290003B7B003A7C003C7E0F4F8C00619B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5C86BA3972A92F69A004000000438113538E005E960053900B4585004585195C94000000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6497C76198C64D87B93068A1033C7B1D5894205E98195992003678154F8D124E8D000000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2D6B9E5996C25C95C44D85B8235A960842811A5390225B97003F800F4384000054003770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00538C004D820074A8316DA3245A96164F8C0E4986174585004A880035780000005175A3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396CA4005C9500528A2D68A03B76AB2E68A01B55910056921E5A95001A5E005F94004483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396EA53B6EA6376DA518508C336BA4447DB229649C003F7F004A8718528F005590478CB3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164F8A31669F4075AB2D609B1E5490437BB04980B400006E003B7B1A5390093E7F1B5690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22538F2156913569A23466A02658953568A24276AD4979B10000440074AC0C3778285F9A
417BB06BA2CD386DA800307228659F25659E0F538D55508B0000000000000000000000AF
00BBC0A88A910000006242599B8983000000000000000000690000350000710000BC0000
DFF0EBE3F7F90000005C0000000000000000DCB1A7E5C4CAECD7E7000000000000A10085
99009190009C0000008B709A997DA1A489ACB398B4BCA6C0C1B2CDCCC0DAD1C6DFD5CCE4
EFD6E5FFFFFFFFFFE7FFFFE5FFFFDDFFFFD4FFF1BFFADCA2F5D397F1C98CEBBF81E2AD6D
BC792EB0721FC48C41E5AD73DE9F67CE864BBC7B3900B4AD00969200CECCA1BB85D6FFFF
D5FFFFD1FFFFCCFEFFC9FAE9A1DED3B4ECE3BDF2F096D8E788CCE16EB9D454A6BB7AAE88
7FBA9588C3A187BD95000000000000B0CDE9AFE1DE8AC8B070B08F4579435E0000690000
8EC3B7004400AE6C00F5C4CEC8D9F2C0F6FFDBFFFFC4DFB67295556E8C4872AFD43F7EB4
4588B55494BF3A6CAD00307C0000007B9DD44268AD2B509A004792002A7A003E8B001E6E
002C7C5474B790A40097510000000056546FE0FFFFC2E9FF979DD0785A86B992A5C48F8F
A66F3E9649259E533E0000510000460089C600B3EFC6E1FFB6A3C99489BD604077000094
C48F99BC80850000006D82C4000000000000009099EBBBB4E4BCC2DCBDD112001C4A6182
BB9DBCCD9EABDFB2B8E2C8C2C6D8C500000039004723002100000010020827004A22003F
5F3C747856887E57868A5A7EB88EA6BF91A3BC90A7B68BA4B1819AC4909BBD8287B4716E
AD6763994F4B7C2D2967171A67171B75262594483C940000000000000000000000A70000
D3AEBBB88600904B005900000000000000000000000000C2327BA2689FCA9BC4EAA2C6EE
00587A008BA600D0FB8AACE08CB2E47AA8DD5B94CB82A3D6B8D4E4BCE2CBB0E1CBF7FFE2
8FC0AA9200008B000000040883C5D384C0C089BE9394B97F9AB26CB4B46AC3B168D0AE6B
D4A96EE0C087E8C793E9C291E8C391F3DDAEE9C997E0BA85C4A65F485100C100A1650061
AF829CD0A5B4E7BBC4F3C9D5FFDDE7FFF0FDFFFFFDFFFFF7FFFFE7FFFFDAFCEFC9E7E2B7
E3E8BCCCD8A5809655ADAA67DAD49FF3EABEFFF9D6FFF6D4E6DEB1B9C0847CB8BFD6EBFF
FFFFFFFFFFFFEFFFE0EAFFDEC6E7C781934F00000000000000002F004B902B5F9885BDCE
95CDD29AD0D09AD2CCA9DCD2B1E2D6B7E5D8BCE6D0AEDBBD92C8AE7FBBAB27663E000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
20518D2F5F9A386CA42F639D20508E2C5E9A3A6BA54172AB00004D0091C46391C500639B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1E4D8A2F5E993D72A9285E981D4D8B3C6BA53566A1376CA54075AD00006600619900437D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2F5D9800609900689F35659E204E8C2454914677AF4371AA447DB13C76AB0F458400538D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335F9933629C003370004885446EA62C5D982E619B5182B84F7FB55089BB19558F154B89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1E4C883E6CA400477B006EA2678DC05582B73871A6256399326CA25D90C1588FC0084781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1845822B649B326BA10000803A79A65988BB4C84B62D6E9F1C609216598D4984B4679FCA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3C5F9A4A87B33D7DAA3272A20F5684003F770072A67FB2D567A1C54F8FB50000853E79AB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215690558ABB578CBC588FBD4F83B600437E003C760073A68CBFDE70A9CD5590BC000071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2D5D96447FAE598FBE588BBC5170A1003F72005D8D0067980075A64E8BA54880B24577AE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2F57924577AB447AAD4176AB26528E0000009089AE6F73A27A91B970A8CC4180AC3D79AA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677AAB5684B75C8FBE4F84B500000000000082A3C27AADD4468BA6357F9A357F9A216C8D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A3B2D79BA9D29AB3DC86ADD55189B7215B920000855298AB5B9DB963A1C669A4C96DA5CA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0000007E9BC70080AB00A2C775A9CE4E8AB5306C9F4289A9488AB05D97C17EB0D86199C0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000000000000000000000000005A7F3F87A3226B9000668F004F7400567D006288246A8E
3779A50085B400648A31779324707D2873803B85904D949E4790A037819900739100758E
009EA14F939500AEC077B4C500009D00005B6893B2000000000000000000000000010600
00004600004B63008F3E007D40519941519A6B78B78187BE777EB96C69A590A0D4A3BFEE
B0D3FFB2D5FFB4D8FFB6DAFFBADDFFBEDFFFBFE2FFC3E6FFCAEAFFCCE8FFC0E0FFC3E6FF
CBF0FFD2FAFFE7FFFFEAFFFFC9FAFFCFFFFFE1FFFFE0FFFFECFFFFFFFFFFFFFFFFFFFFE9
FFFFE2FFFFD9FFFFCAFFF6C2FFF3C4FFF9CAFFFFD0F1F4C0CBD494ACBE78B3D19CAED6A7
95C392588140007D69000000636197000000000000000000AEA5C6B8DFFFB2DEFFB7DCF3
CEDBE5C0DDE79BD7E673BAC45C8E5E86C8CD9BD8E183C5DD71B7DA000000000000BEE7FF
B8DCC2BFB4D9A492BB5741804730737C90C5A29AC7000000CF9177D29367DDA16FEDC991
D0B66B8A77007F5A81845B7B977598AA8BAC8B6B926C3C5E7D4E6E90627F9D6F88A37893
825C838C688DA290BA9E7589000000A9CDD40000000E354D000000000000000000000000
F2AB9F4095AD6D676F6D8F97FAD0AE0000009E6474000000000000824A64000000000000
00000000000000549C7EB8BBA38FB8696FAF725F915A008357005B9E009DAF8C6C824E70
60284F5E254E642F5969355E5A2E6084659576619B8F85B8A2C2EA6FB0C97A5587C9F8FF
E1FFFF8DAAE27C8FCB57008D000000000000D28E00A07E949E7DA7AAB1C8CEEBFFDCEAFF
AC91BC8682AB00000000000000C50089979C62A3A800391F00000000000065006DAA00AC
8F00DA7F0095804B738C5273C59AA700009BA17B97B1837CC88D59A26C23CAA4619E6F00
9C69009871216A3700643D00000000000000000000003E8C3655A0002E7E00166A002174
00186B0050987FADD799C3EC88A6DF708BCCA1B9ECABD2F4A3D8E79CD7E093D2D896D5D3
A2DCDCB3E6E8B3E5D7C2EDD5C1EDD8CBF3DFB7E1BC638B46FAD5B8F8D4B8FCD6BCFAD7BB
FBD8BDFFE1C5FFE4C7FFE5C6FFE3C3F9E1BEF3E5BDE3E4B7CBD29BA7BF85000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000017578A4586AB4D89B54B88B43879A5276C974283AD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0000000000000000000000000000000000004687AE4080AA508EB75C9CBE34789E1F668F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000000000000000000000000000000000000000000000000195C8B33789A428AA3357D9B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00000000000000000000000000000000000000000000000000000034799F4A90A94188A3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00000000000000000000000000000000000000000000000000000000000000000098CED0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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000021598B6D7196000000000000000000000000
0000004382AD1D648E6BA0C095C5C90000000000006E00004000004F0D28000000000076
004795002C7E0020744968B06C81C1006EB00000940072AC0073AE668ECC5075BD00519E
009ED98BB7E980A8E084ADE47DA8E191C2F19CCDFAA1CFFDA6D0FCA8D1FEA9D2FFACD3FF
C3F1FFD0FFFFD0FFFFCEFFFFD5FFFFE0FFFFDDFFFFDEFFFFE4FFFFF4FFFFF3FFDFE4FFE6
DEFFF1DBFFE8D9F6CEBCE3BE9ACBA4A7BE83A0B4720000006EA0695994650000008BCAE2
7FC2D373BBC473BBBD5795794D948375B7C5649F004872AC7D94B597A7A6A5BE85000000
916180A97C93B40000A200005D00000003080000726D50837892B800000000000030001A
97007CFFE4CBD10000760000000000000000FFDEC9FFE5CBFFE8BAF5DEA8E7D79CC7D192
7D974F83BB9F94A5005158008E80AF9087B88981B48B85B88888BC908FC29390C2908BBD
8982B58E8ABD9394C68D86BA8B7EB19387B8000000000000C79CA37A769AC5BACFB497B4
B590A7B287927300006100007B64987B5D8F9E7A9EB389A3A579978E5F81805680A380A2
C6A1B7AD7F9A925F7D947099AC95BE734E546056425E2D5B4F20505D386E795D928175AA
796A99D9D5FFEAF5FFDFE1FFB4C5E5969ED0A3B0CFCDDBE4BFCBD99700000000006885B5
0000D20000ADB692B1C4929FD3A8B4CF9DA4C99298CD9BA37A00005A00005B009A9500C7
00A391C694A4CF9EA9BF827F000000000000000000000000950000AA6D7B000000090003
000000630072856DA8778CC0B2B6E577466CC1AEACDCCCADDAB77FFCF7CED0CC8DD4C07E
C9B068AEA253919443806B15BDD39B009B000000000000003D00000400003C001F5F0048
4E0000205299245C9D00007D648AC365A3C9004A77007CA775B3D40000DC7EBFCC7FBFC5
D29B77DFB28AE2BC8DDDC18BE9D3A3E9CB9FE3BD92E5C094EFCFA7F0D4ACF1D9AFF4DFB6
F6E0B9FAE3BFFBE7C3F7E9C2ECE3B5D0CB8FAFAF6C44621C000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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71577A000000000000000000000000000000000000000000000000000000000000000000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7B82B06E00007500000000000000000000000000000000000000007BA8CB123F4B000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000B3F7800003977566FB3B29D593F697000A77F0000AB0000
00000000000000000000000000000060293F6A415F000000000000050708020303000000
6E9ABD000000000000000000675E939683A90078A8006DA200529200007D070BC96FAADE
81BFE775BFDF71BBDE6DB8DE55A4CE3081B900589B005FA10087C465A5D977BDE565AEDB
5BA6D74C96CF3387BD5DA6D57FC1E895CFF195D2E095D4CD62A383BBE8FDAEDDC6000000
0000000000000000000000000000003E00004000053200121E00003A001F580044000000
00000085638F0000000000000B649A000000000000940000000000000000000000466352
3700008100000000000000000000002D2F3C000000000000D4EFFF7BB000AEDEC3A2DCD8
A8E4E9C5F6E4D9FDE4DBDEE8A9A8D27B72AFBB7800000000000000000000000049000000
C2B399C7AD6AEBD69F8F97CA7583BC808CC27480B9848EC39EB0DD8699CE5E6DAB6C6CA7
918FBF7D8AC25E71B0677FBB728BC56C83BF6878B56A69A57B85BE818AC07478B37B8BC5
7278B57873AE7672AC65518B76619762518D695A96938EC38686BF746FAB726AA76B70B0
6A73B35461A65868AC595EA2393B85292D77768EC97297CDBBD09BF3FFF3D2ECEA283278
7978B5805C00000081476CAC5969AF0301000000000000489D530000457F225D98007AA3
00788600597B002B6E006896908FADABB7AEC1AACBC2A0BECCA6BAD69D8FD2AD008580BB
00004B000000904D5ECD928ECC927400610049A9C500A8C4000000713860A1687E000000
A07F9B0000419E6988000000000000EDD8F80000930000BCCFEDDBB8A6CDCA00007E659C
000000007F4F000000000000000000002E00002900000000850000B5889CBA8279000000
00000000000000000000000000004D000000BB97A7FFE4CE854C00000000000000D3DEC4
C9C78BDDAA91DFC4959C984EB1B46FC3C88AD4D9A2DEDFAAE7E1B0EBE4B5F1E1B7EFD9AE
FFE9C2FFECC3DBC089989200000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFE3DFFFC6AFD19981000000005C960095C0BB9AB8A28EC09C87B9B98786B57E64CFA273
CD9D71C79568B98955915B00A30000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000514D467A887A9E4B37035832528D53000000664F5F98
B8C3D85C000000000000000000000072008F9900B98388B9A1C1AD3E7FA52D7A9A357E9B
195F570000000000000000000000000000009900A08000746700494D001DB200F78900B0
000000000000000000007597C6BBC3D0CDBC050306000000000000000000000000388B9B
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000130029790087B1908BB64760A84F6DB15675BA5E7FC2547DC13B67B0
5B8ECA87C1EA90CDED84C0E976ACE07EAFE399C8F2A3D1F6AAD5F8A9C8F97F96D28697D3
8FA5DC90B1E59FC5EBAAD5F4B8E8FCC4F3FACFFBF3D8FFEEE0FFEADEFFF4C9FAF2940000
970000E4DEFFA7C8E361A8AECB995BD0915EE7A17BEA0000BDEDD5CBD2DECEFFFFB7F3D3
567D38727FB88A97CB7F9EC9A5CCE1B0D5CE9BB085000000000000420000000000000000
000000D9D2F6CBCEF6798FC34D5C9E4B00559DAEDD5F82BE658EC5436CAB0000007C7898
7E00002D00005800008293B57E8DB66B7EB27CA6D59CC3EABCD1F2B2AFD59C779EBEA4D5
E3E9FFEEFFFFCBF8E76281BE2E539920509517468E3B67AB001B6C4F5DA31F3B8A675D4B
00674F880000930000B00000640000000000AAB5E98991CC000000000000000000602A00
6528004E0000FFC5BDC5866BAA633C170C05000000101635FFE1C9FFD3B9C79099006C85
916E9C874964A8604E0000004A000027020900472C482441CEAAC2E5B9C9FACFDAC090A7
D9FFFF000000E9FFFFD1E2CC00000053816C0000007F7E005F00666C004267335EBFB2C0
008241B0ABD9A67682D9AB850000008B65969C6077CDA5B6000000000000000000AD0083
BE8D9FCDA2B4DDB6CBF7D1E0FCD6E6FFDAE9FFD8E1FFE1E0FFF4E1FFFFE1FFF2CFF7E1B9
E8D5A4D1C388000000DFD099DEDAA5DCD09BDEDCA7E3DDAAECE8BAF3F1C9F4F1CAF4EEC7
F1E5BBE1D39EC2CB93000000000000000000000000000000000000000000000000450040
C0ADCE0000002900006500009B0000BD8D9EDFB0B1ECC0C2F9D0D3000000BEABBE000000
3F00008D4B38000000D1B5CDE7CACC00CCB513030B0000BCB7ECDDFFFFE7FFFFDFFFFFD9
E8F6C89FBFE9E4FFFFFAFFF000000000002A0000000000000000000000007B6497D2A6B3
F1C5BAE4B4ACDDAAA3C58982BA796EAE695C90463F8D423E6900004500000000001D5743
AAB4DDB8C4DB9AB5CF95AED1BDD7FFF2FFFFFFFFF8FFFFE2000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
00000030578C649EC574B6C05BA2AB225C43000000000000000000000000000000000000
0000000000000000000000007900002B0000000000540000480A23000000000000000000
000000000000000000675388000000000000000000000000000000000000000000000000
00295D003F6B845200000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000639F9EBCDBF4000000000000000000C2EAE5000000000000000000009DBB
44839F0000008D44320000770000BAA0C8BC00000000C9DB007C78000000000000000000
0000006831494E000000000045000044000000000093789DA900009E81A398687C733C53
7A4661723A5262385E9981A9B09BBDAC91B28F7CA67D6D9C8477A78C64878A638782638D
A48FB4B193B18A5B7978588599799ECAAFC59C748C824F64854C628A546951214993637D
CC9FA8C18F96AD78847E4862000000684877A6A1CE9D8BB5AA99BDBFA8C7BC919E8A0000
7D0000843F408300006A000076302E905466996073A36A79A86F7EA770829E6B859E6C87
A67691A67792B88CA24A5A95A6AECE00FFFFFFFFFFFFFCDDD7C993A86F80A76E7F9C6378
8F56719059757C72ADC8D4F7BCD7E70000005A74629A729A000000000000865881050D08
1E5333000000A57696000000000000005658FFD6CEFFD9D6F7D2E5C6BCDAD0CDDED8C3BF
DDDDFF0088AD008BB7005D820000E700009B00CFE00000008671A6D9B3C2DFAEA7DEA792
E1AD90DAA484CC916EC2835CA86537A374307D43007B40009B62267800006B0000000000
3A5198273A862D418B29448E000062000059007BB8A797C6B8A4CEBF8E85CBA7B89C85B5
8786BDAFD1F0D7F9F2EBFFDFE8EEC2E8EFC4ECF8D3F2F6D1FAF0C9FFECC7FFE8C4F8DEB9
F3E5BEC1B2799100AEA29DCEA59DCEAAB1DFACB5E2AEBEEBC4DCFFD1F0F4D3F6E9D6F5E0
DEF9DFE3FCE0ECFFEDF3FFFFF4FFFFDEFFFFEAFFFFE6FFFFCCE9FFC5DBFFD4E8FFE5FAFF
D1DDFFD6DCFFFFFFFFFFFFFFFFFFE8EFF2C4EBDDB3E7DFB2D7D2A50000AB3D3178BDDCFE
D7FDFFD1F3DFC5E8C7D4E5BAD2D9A6B2D2A8B3C1BEDDF6C4E6F2C7B6C790838EC700A5CF
BCE7DF30622A0000000000000000000000000000005D9DB490C5D0ADA6BAB0DECFB5DDBC
9FCBA4000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000B9CED27B0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000006A00000000000000007B5800
B5C0000000000000000000006B5F937B72AC000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000503421000000000000
0000000000000000009782AC0000000000000000000000000000000000008D79A2866C97
A58CB0A995B9A391B89686B19187B59B91BB9C93BFA099C4A19AC49D94BFA193BE9D90BB
9D95C19F97C4958EBC8D84B38F81B19382B09387B69990BE9E98C5958FBE8E8BBD9793C3
A195C2988BB99285B59A90BE968EBE998FBE988EBD9992C2A19AC7A39FCC9D95C4A69BC6
A393BE9B87B49986B4AE9BC3BFACCEB8A9CEB1A4CEAB9FCAA99EC9A096C49C92C2ACA3CE
A494C09983B2A691BCA28FBCA390BEAFA9D5B9B3DBA89ECF9978A1A6748CAE7581995760
89444C7A32377B353B97575E89516E8D5978915E7E7B45686C365D763A59813F55540F28
50001A5D00005300005A000099615E009500FFE3D3C38C93A25D5D000000B37273BF817E
007A7B00ACC5CE9D00A77200D8ACB6CA9CACCD9BA3E4B4B0F0C2B8FFD4CAFFD1CDE0B3C1
5F77B49889BCC8B0CEC49DB6C39BB7A7728EBA8CA4B793B5B8A0CAA9A5D6000000100000
000000000000C2A6C3E9C6C3E4BF92E0BD89E0B887D7B07AD2AD73C09F5EBAA4009B8438
8673239A8439000000000000000000001F6C385DA0004D8F00689D000000256399071722
9B000070B5B4569B8D77BABE6DB0C04B91A929768B4C6C00DEC4DCE2CCE5DBC3DDDCC6DE
CEB8D8E2C6DBDED2F8E4E2FFE6F7FFF9FFFFF5FFFFE7FFFFE5FFFFE6FFFBE5FFF5E8FFF3
E7FFF4E7FFF3DBFFF3D6FAF5D0F5F8CFF5F6D0F9FFCAF3FFC9E4FFC8E9FFC7ECE4C4E6C7
8CC6BB88BD9E00000000000000546800AEA900A398A8D5C190BC95000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000B2E6E3
798BA881BAC390848D6C251F9F8A92C7BEAD440000090F443D56819E92B8CBB0BCF9CDC0
00000054000097BADC97C4CF98CDC2000000000000000000000000000000000000000000
000000000000000000000000000000003A00006900A0B0B9BFA994000000000000000000
0000000000000000006B4675000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000003C704F000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000009F8FB79282AE
9686B0AA9FC6B1A5CBB2A9D0A399C2A396BFA095C09F92BD9C8FBC9E95C19F96C29F96C1
0000A70000009890BF9C96C49D98C59F9CCA9B9AC88C89BB8889BC9797C79F9DCA9B98C6
9493C49494C69B9BCBA1A3D1A09FCD9490C18887BB9D9ECDA5A5D39696C88E8DC1989BCC
9194C69594C7A9A4D1A2A1D0AAA7D3B0ABD6A69FCC9D96C59C96C7A59FCDA8A2CFA59ECC
9D97C79C98C99790C3928ABE9794C8948DC18071A8968CBF958DC18779B07C6CA4846B9F
987EACA98EB6B092B7B38EAD986279874D6870335374426B7A4E7A714E80BBA5CB5E5492
002D56004D50005E67FFD7E3FDCACFD9AFC0E1B9CCE0C5DCC4A8C2B4879FB77E88AE6D6E
AA6665A96465BA7F67D2B183946C00CDB9D8B59BBD930000B20000AF6A5AA55D44974E44
88424E71304D6DA2A6BE8CA20000005E00004B00004D00007E0000C7CDFF000000007F9D
00798D5090A13C0013CC007AECCDAADBBA86E9DAA8EADDABDCCE94CCCF93928C3DB1A45C
A0B4726F69008875000000000000000000000000001A488C437CAC3F7DA83470A06DA6C6
007C8000485727767AC3A3BAF8CFD5FFE6F2FFD8E6F9D6E6EED2E5EAD4EFE3D5F7E7DCFF
F0E4FFF6F2FFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFEBFFFDE7FFFFE6FFFAE6FFF6E6FFF4
E3FFF2DEFFEBEDFFEAD7F1CFBCE5D199CEC088C3BB71B1AF5A9EA1347B76000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000820000AC000000ADDEEC82C2C6
619983BACDE5000000000000000000000000000000000000000000000000000000000000
7E0000930000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000002A747C0000000000000000000000000000000000000000000000009786B19C8FB9
B4AED2BDB9DCB1A8CFA8A0C9A59CC69E94BF9E92BDA295BEAC9EC5A89EC7A39DC88781B3
8E8BBC0D4E81A8A6D09695C49895C49C93C09A8FBD9C91BE9F96C39691C18981B38881B4
A69CC7AEA8D2A7A1CD9890C0938EC09790C09B95C59F9BCBA09CCC9A94C49D97C69D95C4
9085B69C98C79EA2D29697C99C97C8ABA1CDABA5D2A7A6D3A5A5D4AAAAD7A4A7D69B9DCE
8783B9968FC29B91C29F97C89790C38F86BA978EC19486B98B7DB28B7EB38079B38887C0
A9A6D5A090C09886B78B72A5785282916A96A28DB8A59AC89EA3D497A6D892BCD68CBEA0
7C979CBABEE7D0CFF9E1DCFFE9D7FAFFFFFDFFFFFFACD2A94B848E0000720000006E7F00
38310014345EA35E00985400B77755AC664FA80000910000964D50934B508E44479A5039
833C47935671955C7A90516D85455FC2A0AC9BA5C68087BA0000002A303D003700000000
000000FFFF00C89F00E0D7A2DCEFC8D1E2B2DAE2B1E8E2AFDFD69DD3CE92A19F54928B3D
89954A6C74006E7E332F00003F00237B3F578F5164B27B86CD9CA0D2A2A4BC848C8E5B78
080000BEA6CAFFFFFFFFFFFFFFE8FFF5DCF6FAE4FFFFF2FFFFEBFFFADFFAFEE6FFFFECFF
FAEEFFF2FCFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFBF3FFF4E9FFF0DFFFEDD3F6E9CBF1E3
C2EBDCABDCCB91C7B16EA98C004021000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000337999000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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00000000000000000000000000000000000000000000000000000000000000000016152B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0000000000000000000000000000000000000000000000000000002B00000000004B0042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00000000000000000000000000000000000000000000000000000000000034103D000000
000020936A86006667000000000000000000000000000000000000000000000000000000
000000000000000000000000003F00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000A791B3D7CEC800CDB200A78F
006326000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000B3ACD1B2ACD2
A29DC8A49FC9ACADD5A9AAD4A6A1CB9F98C5A59BC5A396C1A89EC8ACACD6B7B1D6B5ABD2
AFA6CDA193BEA093BEA59CC7A39AC5A099C6A2A2D0AAADD8A0A2CF8384B89399C9AAACD6
BDBFE4BDBFE5A29CC96C6DA6A091B7AA97B79390BE7C93C6A2BBE5A8A7CE7B65988C7DA8
C0C6E4B5CCEC889FD05478B28EB8D998BDE088A0D2758BC4829CD16681BB7286C19396C8
A9B2DFABADDBA69BC99288BC7A7EB86E64A1817EB78782BA8D87BF9592C77F7BB5908CC1
7E7DB87C7EBA7171AF5A56995A5EA145468D293F88000087313F8A8F92C9A196C7780000
1DF0FF00C8F5190000775682A98786B08D5400005180A2B14A3D80A380A5BB97A2AF6C64
A15A54000000000000782924B47983CBBADAA80000000000000000ABD3ABD5AFC3FFFFFD
FFFFD9FDD3BAEED0CAC19D730000460C0F61D4A1A2C08280B26D689D54519A57669F627C
AF7D9C085C711F6E8600030100000090ACD1B3E4DF91CAAB9FD2B3A5D1A64F7837AAB400
E4B7A4CC967EC89078C88F79C48A75BA7E65BB7F65BC806CD2A187E6C0A2FFD8BFFFDBC8
FFD7C6FFD5C7FFDACDF3CED3FFE2F3FFFFFFFFFFFFFFFBFFFFFDFFFFFAFDFFFFFFFFFFFF
FFFFF5FFFFECFFFFDFF1FFE3E4FDE2D0F0D2A2CDA775AA83659767000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000CBCCB0000000000000000000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00000000000000000000000000000000000000000086B7C9000000A4DAE1000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C3B5D5A797BE
A08BB2AE9ABFBCABCCC6BCDCBEBBDEA8A3CCA09BC89C99C59C9AC7908CB98F7DA9AE8BA8
A588ACCBC5E6C7C7EAB0B3DB8E89B8ADA0C6BAB1D7B9B7DDA2A8D59595C6A19BC8A5A9D5
9895C48C719E948BB80000478481B200332697C1BBA9CEF5738BC07D9DCAA4C8EACBDDFD
CAC0DEC4D3F8ABBDE78193C87C94CA8696CA98A7D79AB1DD8DABDA6E8AC26685BC668CC1
85A1D37A96CC7395CA799ED087A6D76B98C45A91BC007BAF1F3F856C7BB9979CCF928FC4
7870AB5B51935C54956C70AF5F5FA08081BA7969A266000038006F0000005A7DB3000001
52797D000000849DD30000A54F004CA15C60964F4F703B33DBBFD69000006592C4387E8F
000000490000000000604480DBF6E6D8C19ED9A78300886400695D6E2F00987700000061
405EA4BCAAD4787AB6E3BAB2D7A4A4BA8495EAC2D1F2DCC5C1B893A1899C000000000071
00936B00B993000000C7F1FEB1C7E6000000799FCC82BDBA457400C0DFCC965254A2605C
BC8075CC9585CF9781C89370C19064C6966DD2AB7FDFC798EAE3B9E8E1B5DFC999FBD7BF
FFDDCCFFF8E3FFFFF2FFFFFFFFFFFFFFFFF9FFF8E2FFFFF5FFFFFFFFFFFFFFFFFFFFFFF1
F1FFE8E4FCE0DDF8DFCAE6C2B6D4A7A8C897000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000B093B0977EA6
A891B6BBA9CACABCD9CDC1DFB9B0D49C8DB8A497C19F97C49B9CC97989BD7C8CBC8A8DB8
A0A2CCC4CDF4C7C7EB000000000000B79BB8BAB5DABFC2E7A0ABD88C92C59499CA929FCE
6D52819D6D82CBA4B4B6AAC999AFD794BEDF9ABDDFA3B9E090A0D47398C5608FBC445E9C
BED3F6C3DBFCB2C6ED8E9DCF7793C8789CCD86ABD785A9D488B1D874A0CC5281B44372A9
5379B37394C77AA2D1709CCB6290C280ABD38DB9DE75A4CF0000748497CC6C7AB6726BA8
7A73AC6464A56D75B36775B55161A55461A4554E915C498A12004900009E7998CC84B2C8
957C9C000000A2C7E56BA3C000004C8277A1D8B2B6D6C3E0F2CCD50000000E00037F0000
910000D90000EED7B18D7A3C916894000022BFBFB997928AD59C8C7F749C000000009DB2
000000C9C9F44A724F008B49D6A7AFEFBEBCFFE7DDFFC5BAD18B7EEEA895FFDED3000068
00000061000081BAA686BFC3ABD4EFA9C0EAB6CADE00BB00B8DDB4E4B8DAFFF2FFFFD8CE
EFC4B4E3B6A4E3B89EE0B794D4AB80CAA070C3A974C8BB83DADDAEEEEEC9FBF2CFFFF5D4
FFF8DAFFFFE6FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFF7FBFFEB
EBFFE1DFF6D7D5F1D5C0DFB8A9C99988AB74000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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0000000000000000000000000000000000000000000000000000006C0000000000000000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00000000000000000000000000000000000000000000B0B9000000000000000000000000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00000000000000000000000000000000000000000000AFCF006E75000000000000000000
AAD1CD000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000084605E0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000656AA0A29CC5
C0AECBB89EB9A092BA8C84B4A08DB5B7B1D5D0C9E9C0ACC9977492B68899CDA6B5D0B7CD
9A7DA1917195A990B1A395BDA3A6D2B9BCE2C0BFE2B7B3D8918BBC929BC9C4CFF1D0E3FF
B8C8F3A9B6E1BCB4D7BAB4D69597C508110E2E635200000076B0C76CA4C25B8FB85D88BA
739BC988BFD0000000001918000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000004B0035770055982A347E4B468C352D76776CA5C0ABC3D2A881B07464
A87180FFD1C600000061305A000000B5AAD4D1B6C9000000000000000000000000B082A2
C9A9C7D6B2C5D2B59CD1E9C8F5C4A300A6B1443635DEC7D6000000550057FFFFFFE5BCC5
E4B7B8E3B2AEB87980B67472BD7C6BCA927000000081C8E5008B7A30734BB5D2A4000000
92A4AB000000001209DBDDFF75B09C347E6BC6D8FFEFFBFFFFFFFFE9C2C6FED2C6FFFFE7
FFFFE1FFFFEBFFFFEEDFBB93D4B784BFBB81ACC089D0DDAFF5F3CFFCF6D2FFFFDCFFFFE6
FFFFF5FFFFF9FFFFFFFFFFFFFFFFFFFFFFFBFFFFF2FFFFEEFFFFF9FFFFFCF9FFDFE0EBBE
CBD8A5D7E7BCDBE9BF95B17A000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000008E9B95C5CA000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000006D6197
8B83AFA7C0DDB6ABCB81526FCEB6C8B7BACD767DAA2F1249C4AAC5D8C1D8977595956885
A07796B693A9D3B2CBF7E3FFCED9FF7CA1C7829AC798A9D17FB4CB99C7DD76AFC25072A8
756193999FCE000000AABAC066966E0093905394AB68A3B56FABB5008973000000000000
000000637895000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000211339000088414B934B549788A1D55F84BCD8D6F1FF0000
C90000C80000D69D91D59E93FFD7C20000006E4F7C283A8493C0DE94C3E696C2E89DC4EC
B5CBEFBFDCE9AFE0D4C7C69DA8A45E0039005E77B569877B000000000000000000B2A7D1
C38D94A97585A28AB53E0000986E47003300000000A3BEBE536E97000000005E848D85B6
F2FFFFF9FFFFC5FFE18DC6B1A2007EB3777CBA8C94C9B4D0C096AEDBB1B3E3B9B1E5BDAB
DFD2AEE0FFE37692B4F1DBC8C4BC859AAB6DE3E9BFEDF1CBF3F5D1F4FED9FFFFE3FFFFE1
FFFFE8FFFFF1FFFFF5FFFFFAFFFFFFFFFFFFFFFFFFFFFFECF1FFDFDFF6DAD5F1D6C2E2BE
BDD6A8C2DBAE93B37D000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000550000990000
00CB00130002538F77472D13000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000726195000000000000000000000000
0000000000000000000000000000000000000000008D0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000002E7789000000C0B1D7B6ADD6
000000000000C7B1CCFCD9E4CDBCD5ABA4CABBB9DECCD7F5CAE2FBC3D8F1B2B8E0E0BDB8
B8BBC6AAB4CE355792707A00000000ACCEEB95B1DA0092C69C88A3006B7F0088AB97ABCB
E3D4E0CBB18D004200000000000000000000000000000000000000000000000000000000
9093C6000000220303662C35000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000009A0000AFADDB000000
A98DAFA877674E0000A1000000000000000035418C6C85C17EB0D9D2FFFF000000000000
000000BDB2DDBBA09C946237F5D5BFC9C100D19996F6D10000000034220E7D00C2CE9391
0000001D0F00FA000000000092006D000000620000000000000000000000000000D7AFA7
8FB08F000000000000D5DAFFE2ECFFD3D6FFD2C4E5E5F4FFF7FFFFFDFFFFECFFFFD6DDCE
B7E2F6E4E3E6D4C38DD3D4A2B7C68DC8CB94E6ECC0F2FAD5F0EBC4A29C61B6D5D4000000
EBFFFFFFFFFFFFFFFFFFFFE6FFFFEBFFFFE2FBFDD5E3F2CDD8EECAD2E9C2D0E6BDCDDFB0
C4D7A6638446000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000000000000000000057100F540000000111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0000000000000000000000000000000000002D002560546F53456D000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000002F60908497C79D91BB
6B0093B3D0EFA8CAE7B8DBF200BFDA00A7CB86A1CDD2B6CEFFDDDC1792A64C46796488B8
6692A470885C7EA27FC8EFDF9CCDCBF2FFFF45839F005B723A78924E6B47000000000000
646363658800000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000053818BC5746AA45B2B5B0000A8
0000E6A4BDEBA9B49E839159C7CFA1C300008E5E88689CC800009400006B73ADCE67A18D
43004D886090B890AFDAB3AEDAB0A9000000000000A500007B6000000000D69E8AC9F2E3
0000000000000000000000008000E70000003C004A8A783A5A545B0096886DA781000000
000092000000000000B9C3ECC5C8EED0DBFBD5ECFFD3F3FFCBF1FFCBF3F0BFE5CAE9D2B8
CDD9DEA5DADED3EDBFB1B171ABB373C3C990E3E1B4FEFFDDF7FDD5F3F2CE000000855F5F
0A0709F5FFFFFFFFFFFDFFF9F7FFF2EBFFDBDDE6BAD4DFAFD3E2B6D8E9C1DCEFCCDCE7BD
A0B67C000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000048004E6100875A9BAB165141000000000000000000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0000000000000000000000000000000000000000000000000000000000000000001A3C38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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000525E68A300000000008CA57500000000000000000000302A000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000003C00002B0000
450000570000550E0D5600005E00006200006723266F2B2E6D00005F1A1E732F33722E30
6520226D292B79363876333980404A9152589252568B4B5139367F8583BC4169AA92C0E1
96C9E2A1D6E08EC7C5589FA2000000C2826E000000FFFFF9FFFFFAE5C8C9000000BC009A
B00084000000000000FFCCC2FFFFEDFFEBD2FFD9C5FFDBE297C2D2000000610000316A70
7E0000A0000025000000BEEEE2C0D0000000000000000000BA8964AD744DBD9064D6B187
B07F4F9A7336BA965F633900000000008CA600AEC5A8C8B3000000000000D4FDEAFFFFFF
C3EBF1B1DFE8C2EAECCAE9CFD0DFB0DCDAA9F3E2BDFBE5C5FBE4C3FBE5C2FFFFD7FFFFFF
FFFFFFFFFFFAFFF3D8FFE8CAF0E1BAECE5BBEDEEC8EAF1CBFFFFE0F1F0C4D2C6935B6D26
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000000000000000000000000000000000000000002743604F5636000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000006D80AE005846004A00733A00000000000000000000000000000000000000
00000000000000000000000000000000ADBD000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000002100003600001F000049000097929EA8BEA55000004C00006700006D2B35
72323E7B3B4480414A86485088494F82414784444B7B3A43804049814148884850905157
995C5FA46A6F9B5E63995D6593575F9A5D649B5E64985B6100005BC0ACD18B5364A78DA7
00ADCF00CBD6A5DADD86BEA277B7AC000000BFECE9D7F6F6FAFFFFB699C1A07395000000
400040926B6BD9BBAA0000008BC9B8FFFFDCFFFFE9D8D8C5710000260000000000000000
6EA98E71ADB732292B90AFD400769C000000FFF2DDFFFFE9F6FFD3E7CAA8D2AB84B1844F
BF93639F723A916B2D5F3A004934000000000061890000BEEDCFCBEBCCC2D6EAE97FB2C8
CBEFF7D1F6FFDAFFF6D6F7E4DCEAC6F2F1C9F9E9C7FFECCEFCDBBAEAC7A4E5C09DF1CCB7
F9D1C4FFD8CEFFEAD6FFE5C9F0DCB6E6D9ACE3DDB0E4F1C3FDFFE2F8FFDBD0D9AD000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
AFB4B7000000507CA90061879C9CC0CEB2B9B98B00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000004300002B0000
0000004D00006100007738436B2931A8ABD86F2E3665243075364081424D83454E844650
7839457F4049884950803F4475323978353B7A393E7A394290535D9F646FFFFFFFFFFFFF
AF767BA56B739559636A698B8173A7A2676D9C606A9E647290515B00007EFAE1FBDFD6C1
C5CB870091A65BA0A100A59F000000925B6F0000009EAAC5B8AEE2785F99A3A7D8000000
000000CFF9F4E6FFE88BC09500000000000034120AC3B4B294B19F0074670000D1DADCCF
BDDBBD7D9A75CBB1A800005B00CBAC7F74AD0000003F76AAFBFFFFF2FCFFFFF6D7E1BF99
AB7947A778439D783A7D5E00B7915C000000000000000000E1B4B2ECC7C0EEF9DFB9D09C
9AC1DAD1F8FFE2FFFFE2FFF7F2FFE8F7FFDEFFFCD9FFFFDDFFF1D4FFDCC7F5D1B7F0CCB4
F0C9B8FAD1BEFFDBC3F7DFC0EDDEB5D8CD99CCCA93D9E9BFE1F6D7D7F3D9A1C393000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000080686E000000000000000000000000000000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0000000000000000000000000000004B8DB061A2AF000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
756900000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000F1315000000
00000000000072344070313C060A09185B7D327A8E488E99810000590000870000000000
B08FAEBAA8C9BFB2D1BA93A09E0000A80000CE0000D5B5C7C1A0B8B097BCB694B0D3B4C7
D3A9ADB88991B07D87C28E90D0B1C4AE92B6BA9DBBFFFFFFAA9D6BC79388CB988DC99693
C7989FBA858DB27C89B07C8CB68595B18093AA7789AC7889AD78889D6474A9717EA8717F
814860470031581E3D975E70B6808CA36C5E00000000000070A7BF0000003D7653BFD7F4
000000A2A2CF000000000000B37E760000000000000000000303056B2F4B91007FB07B7D
DFB2ACC192947D3F558F51600000D1FFFFFFD4BF00795B00000000AF7258BD8861000000
E6CCA2E1C99CAE9F5FA18444A49D00552D0000000098C3D8B1D1D8E8D4CDEFE1C2000000
96CDE6AFCAEECDDDFFD6F7FFE2FAF4FFF4E4FFE0D8FFDBD7FFDFEEFFFFFFFDFFD8FFFFFC
FFFFEAFFFFE2FFEBC9F2E7C2E6E5BAD0D49FC0CD96D5D5A2BDBE8583A56B000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000CDC6E6CECAEA
D4CDECD8CCE8D8D0EFC0B4D6C0AECFC8B9D8D3C8E6CFCBEEC0B8DCC4C4E6C4C9E9CECDED
D0CCECD5CEEEDDD5F5DCD1F0D5C7E3D2CEEFD6CFEFD9D1EFE3DAFEE5DBFFD7D0F1CBC1E3
D7D0F1E1DDFFDAD7FFC7C3E5C7C4E8CAC5E7C5C2E6BFBFE5C8C7EBD2CAE9CEC0DECBB5D3
CFB5D1D5A8ABD4B1C3BE97AFB992ACC49DB3EDC4CBBB8587A97A8F875C838966929683B1
BB9CB8B9B9BE724F74C49BA9C6D0D59F92A9B17F6CEBB1AEE5A18FB98C68C6AD82009400
F7D3ADD4A3995D5D540000000000A2C9C2DBF5E8DD000000000000BE8EA9FFF2F6FFFCFF
F8F5FF5583970000867298C200698691BABE94B9B510120F00D29FB297BB7A5780F2DBBE
CED19DABA666B29F63C1C999B7CD9C5E5F00000000000000000000274B8897C1E19CC6E4
6B93C35C85BA8CAED9B4D6F7C5E4FFBCDAFEEFFF00E2FFEF36689D8FACDDD2F2FFE3FFFF
DDFFF6DFF9DCD2EECDAFD3AD100D0CA7D6C3A2C294669562000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
080500000000000000000000000000000000000000000000000000000000CEC3E1D0C7E5
D2CAE8D6CDEAD0BED9BEAED0C3B9DBD8CEEAD9D4F3D0CCEECAC6E7CCCFF2C7CEF1C8CDF0
CACCEFCED0F2D6DAFED5D7FBD4D5F7D4D8FDCDD0F3CED1F4D4D3F6D9CFEED3C6E3D2C3E1
D7CFF1DCD4F6DACEEECDBFDDCAC3E5CCC8E9C7C4E8C1C1E6C8C8ECC8CAEEC6C2E5C6B8DA
D3C7E7DDCBE8D0B9D7BAA0C2BB9DBDCEABC0D4ADBBC89BA8AB7E99865F88B3A5D1A5A2D3
D9DAF2EAFEEA596C92415C3AD9B9C59A6B85B1879DCBA300B58C80006C6FC29971000000
FFF4DB000000000000000000E2BBC16C7CAAD9BDD0CDA0A1CB9993C69DB0FFEFF2FFECFF
EDC0CC35395E424A74002647000000E0DBFF000000000000006648A3A0CEA09ABBBBB67F
ABCDA8B4AF78A07D3FA0B278AFCC9A6B7B360000000000000000000000008EBCDB7AAACF
6899C45B89B982AAD4A7CBEAA9D2EA8EBBD7B3E6BD4E8B7089BCB9245D8E75A9C9A2D4D4
AEDED3BCE6DA76AE9267A180A4BF8BB5DAB94A8051000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000A2ADCC
C7C3C8000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D5CFEED4CFEE
D0CEEECAC2E3D7CEECDED6F6D3C8E6CDC5E5D0CCECD6D1F1D7D4F6D4CFF0D5D6FAD9DFFF
D1D3F7C8C4E6CCC8E9090800D4CDEECDCCEEC9CCEECBCDF0D1D2F5DAD5F8DDD6FAD7D4F8
CAC7EABFB8DDC9BDDFD8D4F7DBD7FCDEDDFFCFC9ECCAC5E8C1BCE0C8C0E3CCC9EDC1BDE2
ADA8D3BFBDE3C1C0E6B4B2DCA49DCC9791C39F9BCBAAA2CFA591BC755F965500005A4F8E
A00000A19A8F36564A00000091A0BE0B09169695C29A97C4E3FFFFFFFFFFFFFFFFD1B1C2
BEA500ABC7E3BECEDCCCCFCE967A678D562A00570080798A356D945692AC000000000088
150C0CADADE3D9C6E1AC9CBB7C98C4C3CAE8000000000000000000BDCFFFDDFDE3000000
000025BEC5DA99C2A800003970996B000000000000000000000000000000000000000000
000000000000008EA4007871000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000E8E5FFE4E4FF
DAD7F8D4CEEDCECAEBD0CDED1E4068DDD9FDD6D5F8D2CFF1DDD6F7E0D6F6D5C6E3C7B5D5
CCBAD9DDD2F2E1DBFFD5CCEDCCC6E6CBC7E8D4CEEEDCD6F9D7D8FCD2D6FCCFD2F5C9C7EA
C8C7EAC8CCF0C7CEF1C6CBEFBCC3E9C0BFE4C6BDE0D0C6E8D9D1F3D0CDF0C3C2E7C6C5EA
BCBCE3B1B1DCACAAD7A39DCCA8A8D69D9ACB958EC09B90C1948CC07175B07C7BB4AC96C0
A3BAE05C68A57C80BAB3D2EE7AB1B86E7FB4FFFFFFFDFFFFD6F0FF8CBDD38CB7D2516777
0000000000005A84A0000000DFD0FFDBD6FF000000E7CDC9BDBE9A0000000000008EB4D7
92BFDCD4E8FF000000CCBBDEBDB0D8D8F5FFB2DDEC74AFB4000000C900FEC5ECDD0D0608
83B4C98F65270000002D4B00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000A899B80000C59F9B886C7B48000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000042006B63617E608D9F
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000E2EDFFD3D0F0
D1CEF0D2D3F5D0D3F5CDCDEE000000D4D8FCCCCCEECBCAECC9C9ECCECFF1CECFF0D0D0F1
D6DCFFD5D6FDD1CAEBD5CDEDD7CFEED6CFF1D1CCEDDAD8FDD9D4F8CEC7E9CABFE0D2C8E9
D9D1F2DBD8FDCEC6E9CDC6E7CBC7EABDC0E6B9C1E9C8CFF5CCD2F9CACAF0C3C2E8C4C4E8
C2C2E7B1B0DBAAA6D3B1ADD8B0AFDA989BCD838DC47F8EC59FA6D68691C77A88C0B4CBF6
6D6296544B88788FC5A3B3DF0000000000008A4643C18A72EAB5A1F6C3B8009690003567
000000F6E0C00000000000006D85B7000000000000E9C5C8EDD4C3E8E4C98B5F529DAFD1
000000AB9CC96E86BB7CA7CCD2FEFF212928000000000000BBC4CF000000000000B8CC99
0B0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000C800003059867B0F0000000000000000000000000000C7A7A4D6B589000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000E2E6FFD4CAE7
E0D6F5DDD8FAD3CEEED0CCEDD3D4F8D3D5F8C5C7ECD1D6FACFD8FCCCD5F8D0D5F7CED6F9
CFD5F9C6C7EBC9C5E7D3CCEDDCD5F7DBD5F9DCD8FFDEDEFFD7D3F8C7BFE2CBC7E9D1CFF3
DADAFFD1CDF1C8C1E4CDCBEED5D5FAD2D5FAC5CCF1C4CAEEC2C7ECC1C1E7C6C4E9C5C4E9
BCBBE3AEAFDBA0A2D2AAADDAB2AFDAAAA7D4A0A4D4919CCF7F90C58E9ACD919DCF90A6D7
6C6BA17981B889A6C2445B988B8D9E668E60CBA5B7DFA7A4AC734EC7927D00A4A000ADBA
000000B20000B5C79E000000709EBB8FBEB2BCBDE0FFE0EEFFF0EA000000000000000000
CAA2B7EECADF86B09576333BA2655A0000000000000000009A7D810000000000009FA86C
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000A6B0BA000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000155F62000009000000000000000000000000
000000000000000000000000000000000000000000000000000000000000CAC3E4D2CDEE
DDD7FAD8D4F6DBD5F6DCD9FEDEDFFFDAD5F6D5D5FAD4D8FECFD4F7CECFF1D3D1F2D8D3F3
CAC4E6C4C1E5C1C1E5CFCCEFD8D5F8E2DFFFDFDFFFD7D4FBD2D2F7CBCAEDCDCFF4D1D6FB
D3D5FDCBC7E9CAC7EBD1D3FDD8DFFFCACCF1C4C3E7C8C3E7C6C6E9C5C2E6C5C2E7C3C2E7
BDBBE2B7B4DDA8ABD8A0A6D5A8A8D5AFACD8ACAFDBA5AAD89A9ECF9092C69999CB8F96CA
837AB08384BA000000000000000000D8DDFFFFF2FFFFF9FFFBCFB5CE9E7BE2BB9FFFFFDB
EDE2B0C490718EB997005C500000007793C74672A6B5CCE4C9E4D3000000000000BEABC4
FFE3FFEBE7E4A8C1910000002800002E0000C0C396000000655475000000AFB5C1A3C3A1
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000CCCAEBCED1F3
D7D8FCD2D3F5D4D7FADADEFFD6D6FCD7D3F4D9D8FCD8D8FCD1CEF0CBC7E9C6C1E3D5CAEA
E3D4EFD3CEEEC2C5E9C4C9EFD7DCFFE2E1FFD7DBFFCCC8EBD0D1FBCCD0F4D1D5FBCFD7FE
CACBEFC8C8EBD0D1F7D7DDFFD4D7FFBFBCE2BFBDE2C8C7EBC4C4E8C3C0E4CAC2E4CDC4E6
BEB6DCBDB6DDBDBAE18F9ACD969CCEB0B0DBB1B4DFA6A3D18676A99588BAA196C58C84B9
9E8EBAB4A1C6BAA9CF0000008179AAB9C7EDC3B9EAFFFFFFFFECE2F3CDB9DDB293EFD2BE
D4A395D8A79BE20000A300009BCBC79C96B9A1CBE693C2DBBCE5D47B517C000000864F6A
000000DEFED800CFB9F0ECCE0000008F0000000000E5DDD4000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000021334B0D151E000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FAEEFFEBE2FF
DCDBFFDCDDFFD2D7FDCBC9EBCCBFDFD8D9FED7D7FBD0C8E9CCC0E0CDC4E3CCC8E9CAC7E9
D1CCECDCD0EDD7CFEFD8D2F2D6CCE59A8DBAD9DEFFD1D5F9D5DAFFD7DAFFCACBEFC5CBF0
C8CFF4CAD2F6C9CEF3C2C2E7C0BDE1CACFF4CFDAFFC9D6FAB6BFE7AAB6DFA6B8E2B6C4EA
B3BCE5B3BCE5B2B0DB9E94C4B8B5DEB5B7E19492C5675A968885BCB1B6E1AAAFDB9892C5
766FAA9895C0B3ABC6C9B5BA8300000000000000008E6700BAEFD5170503D7B8C1D0A6A4
DEAFA0E6BBAAE4BF9E9D8500BF9FB9FEE4DBFFFFFCAEA987ABA281D2BBD2A08085000000
7D000080465C682C488D648A0000007E0064000000518391000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
284357000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFF4FFE0D8FB
DED4F4E0D6F6CDC1E0B8ACD3DBDDFFDDE0FFD2D0F6C6BDDFC7BEE1CECCEED0D2F5C9CDF0
C6CAECCCCAECD7CFEFCEC0DFFFE4F3917AAABBB5F4D9DAFFD0D9FACECCEFD1CDF1D2D4FB
D1DAFFC7CDF1C0C5EBBEC7EBC4CDF1CAD7FBCCDAFFC8D1F5BFC3E9BFC9EEBFD2F4ADC1E8
A5B5E09DABD99597C99691C4BFBEE5B1ABD58786BB7070AB99A5D4A2ADDB8F99CD7471AC
8183BA8596CB9CB4D8B9BED68690550000006D5D95B28686000000737500CABEE1DDC3D1
E4BFA6E5C0A1EED1B2DDC500FFEDFFFFFFFFFFFFDBA389895700001E0000000000DBAEA2
A1625C7F0000B9AD705A000093008E9E00A30000006D0088B7D6E1000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000008F556C
000000000000000000000000000000000000000000000000000000000000000000D6CDEB
DCD3F1D9CCEAC5B4D3E4DAFDE2E9FFD9DBFFC6BCDEC5BADCD4D0F6DCE2FFD2D8FFC3CDF1
BCC7EBBFC5EABABDE3ECE5FFFFFFFFD3CCFFF7FFFFFAFFFFD1CDEFCBC9EDDDD9FEDCDAFF
D1D5FDCACBEECAC6EACAD4FBCAD8FDC4D6F9BCCCF3B8C3EAC2C8EDCBD3F9CBD2F6B9C1E9
A9B2DE99A0D19493C69C9ACBAFA8D19B84AD897CAE8694C799B1DD97AAD89298CB6F7CB7
96A8D89EAEDCA9BEE6D0E5E500000084B49A000000770048ECDCAE0000DD000000000000
00D4D2FFECC6FDE5BFE9D2AAD8DBFFDBEEE9EBF1CE000000C7B28691525B000085DACCE6
EDCAD4E2C4D4320059B3A2D0D5D3FFCACC008A85AC7BAABD579387000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D0CFF2
D3D6FAD2DAFFD1D9FFD7E2FFCFD1F4AF9EC5CCC1E9DDDFFFE1EAFFC4C0E9DFC0D0DED9F9
E1EAFFCFD6FFC2CEF2C2CAEDCDD6FBCFD7FAD2D8FCDCCEEED5BFDCD8C2D8D9CDE8D7CFF0
C9B9D8BFA5C5CFD2F8F4FFFFF3FFFFE4FFFFCDE0FC99B7DE99B6DE8FAFD7B3C5EBBBCDF0
A6BDE4889FCF6E82BA4B468015261FA2ACD6CCF1FFC5EEFFACCFE96887BD667AB486A2D1
7D98CA92AED10000006447749B6D83AD727B003B568DA6CBCDB2BD8F6051A46600F7C400
002E6D000000000000351B10000000BF908C985D4C909392000000650000154C1E000000
D6E6FFE4FFFF48353900000000000000CB00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000567898779F8F000000000000000000000000000000008796000000000000000000
000000000000000000000000000000000000000000000000000000000000000000DFE3FF
E2ECFFE8F2FFDEE1FFD2D4FAACA2CB9C93C1DEEBFFDEEFFFDDEDFF9C9DCBD5D0E9F8FFFF
FDFFFFD5CDF2CBCCEDC4C6E9D4D7FFDDDEFFC7C4EAB9A9CEC6A8C4B38087D8B8CBCCB2CD
CBB4D1E3CFE5F3D7E7FBE3FCFAE3FFFFFFFFFFFFFFCAFEFF97BBDE92B9DB7DABCD76A5C8
8EB2D793ADD95679AE4F67A04E639A557BA684B9CB7AB2C36DA5BB3662975B7BB385AAD4
7792C690A8D50000467B78B2AA93BC6D3D68734470009DC9BDC0DDF5D8E9FFFFFEECEBBF
B595A7FFCFB4000000000000000000BF8F9CD09D9DC18F745F6DA7B18594000000000000
0000D6D7C400CDD6D3ABD6D6005C00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000008AB3000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D9DDFF
D9DFFFD2DBFFD2CDF3CDC7EBB7B9DECFDEFFD6E9FFD5EBFFD0D3F78890C1B3CFE6E4F6FF
EADAF7CCB1CED6D4FBCACEF2DCDEFFD9D8FFB9B2D8BAB3DECBBEE7D4ECFFB9B9D8C0A9CA
CCBAD8BFB5D6AE97BDC48E88FF0000FF0000AB00007DB0CB88B5D48DBAD68BB9D572A4C4
538AAF447DA3376E9941789F4F86AB5D93B46BA7B787BECB7EB1CB3F6B9E305B935E88B7
5F6EA996AED900004700000000008771669BB4A9D2BBC8F1C4D1F7D6EDFFFFFFFF000000
000000000000D3EEF1DCDCCAD4A497DAAAA1E0B4B1B57B640000007A7DAA9A7590A36468
CDC8BAD0D2A2A1CBB1609B80000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000CFCAED
DADFFFCFD6FCCAC8EBC7C8EBC3CFF2C1CEF0CDDCFFBFCCEFD3CAE6D9D1F1D6DBF5ACAFD7
B8B4EAF4FFFFF4FFFFC8DEFFCDCAEBCBC2E2C6B5D6D5CDEFDCE0FFD5D7FFB5AED6A49CC9
C0C8EBB4CAEC808BBB000000000000FF00006E0000A1D0C36EA9B57BACCB5191A15594A6
4A8AA0417F9C3C799A4783A34B84A7306F91508EA664A2B05D95AC436BA13E5E9A305D94
005D9C415895000000000000230A00707FBAA1B0E0ACBDE9C6D1F7C9DFFDEEFFFFC4D1B0
6E0000CFB3B4000000AEB9D4D2BDD0CA9AA3C898A5CC9BA00000000000007168A3C7B8C9
DAEDD37E9E6B000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFF0EE000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000DED5EF
E3EAFFD9E0FFC5C8ECD5DDFFC3D3F5C1D4F4C7D4F5B0BBE2BAB5D8D7C2DCD6C1CEC8B9D7
BABEEAEEFFFFEBFFFFD9E5FFC5C7E9A4B0D9B6BFE8DAE5FFD2DDFFCFC6E9B6B3D9B1C4E6
BFDCF5ACD5E784B0CE86B6CFA1D3CEB8E1CCA2C5A28FC5C25F9E9E51929E3377861E6475
006475007381006473003C5A000000477EA277ADC59ACBD59ACDD479B4B9214D8700799D
00406D00007600003D5C66A3020100546BA97291C5A6B7E4C6CDF5C2D3F8CAF0F3DCF5DB
DDE2C0BFB17A0000009CB6CD90A3D0C3B5D4EFFFFFF1FFFFDBEBE0A2CBA4000000A3C6CD
75A987000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000BBD4BDF4EFDD
D8EEFFCCD3F6A391B3000000E1DEFFBFCEEFC6CAEBA6ABD58795C7C8B6D5FFDBE6EDDFF8
DBEBFFE8FFFFDEE6FFD8D9FFC2CFFAC1DDFFA5C6EB87BBCC5F89B18DA4CBAECEE7AACFDE
89BEC876AEC074AAC277AFC081B9C490C4CBCAF1E9004A521B626822696C266C730A515F
195F713074853E818E377B83000000000000000000A8D3DE87BDB9000000000000000000
000000000000000000003378505A9790AED54A75A86289BBB5BFE992C6D2A1D3D500D6D2
B0D5C7C3DAB4D4B994DBDEB994B2C3AFC5E5BFE0F6CBF8FB9CCEBEA56459B8C2A5000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000CDAC00000000000000000000000000FFFFF1
D9F6FFB7C4EA5F79A3B7CDD3E8CCD6FCE4FFDAC0E4B197B79B94BB8B97C9EBDAFBEFF9FF
EEFFFFDBE9FFD9E0FFDBE3FFD1E9FFEBFFFFF8FFFFF1FFFF7BA8C94479A06FA4BE77B0B1
47898A00007D00009F80B5C379B3B4256B68286E70216764004745000000000000000000
000000000000000000000000000000000000000000000000A7CDB1000000000000000000
000000000000000000000000254C887598C58FBCD7387B6F185F76DDEDFFFFF7FFECCCD8
C0A1BE125D63000000BDDBBCA4D2CB87BFCB66A5B45496927AAB965A9680000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000064C60
FFFFFF000707ACACD5B0A2CBB4A4CAAF94B1C9A4C0FFFFFFFFFFFFB8DEFF8EB0D6D9FFFF
E2FFFFCDE2FFC0DBF7C6E5FAB2D9ECAFDBF3ABD5F38BBFD400000037777B518F996CA9AD
62A1A45091933F837F2E726900452100615E000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000386B5B88B5558F809DB900D2EFFFCDECFFC5E7FAC6E3F7
BFE0F595C3BD7CB59E7BB8AD72B0A756999340837300634C000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFB7BAE9000000000000B8B9DEC0CDE4F2FFFFE7FDFDC4E9FDB0D3FD8DB6D581ACCE
9FC7E298C4D585B1CAA9D4DFA3D2D300B2A14D8D9852929A5A999E4C8D9541838D33777E
2B6E64000000000000000000BFCD9E000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000006B878ABECA67A2A921686E67A0B7
7FBAC24A8E7E2E74671D6765000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
EAFAFF7F8CBE607DAE87A2CAA6BFE291B2CD0085A0A4D2DAA4D4D78BB8CC7EB2C678AFBE
609DA05C9B9D47888B0060565494921F636440818B367A8048898E5C9A9A000000000000
000000000000000000000000C4E3DC000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000006572009991000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
3A1A2B7FB3C57BA5C66FA2BD67A1B17AB1BF518BA385BAC972ADB144847C3E807A000055
00000C008D8C25685D357875286D6E006061000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000B7BF8C000000000000000000000000
0000008AB8D093BFD589BBC883BBBB629DAE77ACC369A2B476AFAE6DA69510554D65A19F
0E5453004A45000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000588F95000000000000
0000000000000000005592A167A2AA68A3B04B8B963A7B8400383114595626685D000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000012585F1C644F000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000899FCF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000B200AD000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000240000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000807000000007D4C5B000000000000000000000000
0000000000000000000000007D4C2E000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000B7DCC576A785000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000634B000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000095BDAD000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`002P3ooooo000002h0000000H0C@0c000000000000Jbi607P_9@0G0002
0000000705TmOP1l0:<0_k[U0<_2/`1<0000I7L00;Bi00060000000700002@00000000000;>Ia02]
L5P0]GA=06T00003000000030:/0001e000062IZ04/00000303oool000X0ooooo`00000]00000007
03l000000000000004X09`1I03<07@0005<0000207AMVP0706aGU`290;H0]ZgI0<Vj]@2fSfD0WkX0
0:>lO`040000000309ZB002O]P0000000080000000X0X7BF0:AZMP2fNg<0bHa`0<B>FP2^0000W@00
0000001i0000KY2_B`00000<0?ooo`002P3ooooo000002`0000000P07`0004<05@0g01T0A`0Y05P0
B01F05X0D@0007]OUP80SWZ`00L0PW:^08Il^@2]Wl`0^if[09aRD`000000IP0000@0000000<0eLD0
00018@0000000P000000201oCGD0ZWN60<nJTP3FYhP0e[5i0<b[H`3G`W/0UfT0C@00000<0?ooo`00
2P3ooooo000002`0000000P0=P0003l03P1G02d0J2]806`gG@1^@Fl0OEN609IhYP80ZIC100L0TX>j
07ec]02RU<D0^:C2091_R01C00007CQ;00<0000000<0PC@00?oi001700000P0000002@1F0000E@18
06d0<`2c05X0fKJ=0>;:SP3A_gL0g<V50<fm001=000000`0oooo000:0?ooool00000:`0000002@1C
1`l0H18A070V:@1d;c/0McQ>07m8I`23E7X0YWjP0:f>/P020:fE_@0609^9_023MkD0V8o60;R_fP2k
]jD0^[Y[100000003P2oVP00`Y000;n2B`2[K2P0R`000;f8AP2Y0000STh009QH003@]W`0gl^70:nU
DP3QdI00g=:?C@00000<0?ooo`002P3ooooo00000280000000<0C`00068000000000100000002`0I
0000;@0006@0001g0000SdHk091;BP2ADEd0Uf1e0:=cS@2aR:@0]iJd0080/IFj00D0YHjl08Yk]@2G
S<<0`;cG0<C6Y@020000000D06h000000000/:C=0<jd``3K]:H0i;F50<:AB`2_PC<0bJIM0<FTEP2d
T`00XX800<:`H03QcHX0]ZED0>3>S03C`GP0bKY]08QR001mFP1:000000`0oooo000:0?ooool00000
8P0000000`0007@0MP000;=[00040000000;05/0002P0000Yf1?0:YTC`2bKe/0/g=X0;IlOP2eP8/0
]hJF0;bBYP30W;D00P2fU[H06P2[S[D0TGne09b@aP37bMD0c]JU0<bIJ03>Ufh0dZ5]0000002;Q[`0
_:G50<ZXZP3U_8T0bZ5E0:^9=@3:]6L0c[]`0;n]G02NT`00_;IU0=_9P`36[600i<Z:0>77Q`35^6X0
Qh`0B`00000<0?ooo`002P3ooooo0000028000000P0004L00`000;X0diT0000000020000000;0880
002_0000^W]/0<>6N@3;TH@0d9R<0<RASP2mRI40^8FD0;b?X`3:XJl00P2oVJl06@2bT;40YHnl0:FH
b`3?e]80blb=0;>GA@000000kMBL0000S0000:H0X8fm0>O2/P3`bIT0fK5[0;FKAP32]VH0d/^20<2h
J@2LUCh000000=cCTP3>]6`0c:YQ0=W6P`32]VL00P0000000`2UeNh0000000000017000000`0oooo
000:0?ooool000008`0000004@0008H0003I0>c@/`3I]WT0?P0007`]7@2EBc00]6m<0<F4G`3AV7X0
gZZD0=RTUP38TY40_h^C0;Z6U031TIh0cZ:Z0080`YZ]01T0ZWjJ0:B6[@2g0000en??0<:PL`33TeT0
/hHo0:9h9@000000001N0;H0T03_aJL0m=6S0>2kN02lXDh0_;ET0<[6N`2k^fd0VY]60000003IgZ@0
cKmi0<k3N`3<aW`0/Z4004`00000303oool000X0ooooo`00000R0000000B0000J@000:`0003F0;GB
002CVP00FU<009`0002fLdd0`XAF0=FMK`3S/HX0i[JK0=JRU@36T900^hF>0<6?V@3:Vj<0cZ6X0P2n
TJ804P2[P9d0`IJV0=nd/03N0000fP0008YHM@2a07`0R`1I06D0=P2>0540l<6e0?38ZP3_cId0h/>1
0;nWE02bZ5@0_/1c0;6jK@80000000D0eMnT0<cDTP31bXP0cLf809n6001<000000`0oooo000:0?oo
oc8000000`3o000010000000o`000?l0003o003W0000000C0000D@000940@g2e03IYS01BS8@0BWT0
07l0002T0000^gM80<jCGP3IXg40fjF00=fWSP3?Uh/0`8V90;^5S@3=WJ40ejZ/0=F^^0020<NV_@0B
0;ZP``34Z<80f;S00:X0001jHY/0UGRM0;BG[@2K09d0S@250=d0[`3meLL0o]fl0?gR[`3VbhX0_ZIB
09j9;P2`/5l0^[=T0P0000001P3;eiL0]Lf?0:K8YP3:eid0]Jh008A^04/00000303oool000X0oooo
<`0000001@3o00000000000000000000o`000>P0000001<0001`0000^@1[V<H0HjJg05V;G`2JGP00
Tdd009UA4P2eM3@0aXM@0=2EHP3@UFh0d9Ai0<>6M`30QX40bYNH0=NYZ03P^;P0fK[80080dkS?01X0
aj_70<2^c`39]m40Z00009R@a02OUlD0]K?K0:/0h@3N0>P0omkV0?oXf@3olLd0onJd0>_ATP36/F40
WhHZ09nPC02PYET0/Yh00000002=Y`000:d00;CMa@2ofk<0`lIm09bE04/00000303oool000X0oooo
=00000000`3o000000000?l0003Y0000000C09>5^@2LVLT0WInF09VRG034ZET0`iH00;Yn002ZIbL0
/G@/0;an?@36Qe<0`h=I0<5nG`37RG<0d9R;0=ZYXP3V^k40iKZd0>Bo``020=o0cP0J0=2fc@2m/m`0
^[GQ0<32jP2b^^P0[KW]0;G<o`2Zcol0^<SP0>[Yo`3bm?X0i^CA0?c]_@3ZeYT0eLV009n<<@2IRRl0
TJAM0=K@R`0TK000Z=_@08:oc02SdMH0`>?20<_CT@2IWP1;000000`0oooo000:0?ooobd0000000<0
o`000000000000001@0000000`3o000000000000003V0000000E03`0A`2L0:<0YhNW0<2W^P3C_jP0
YH]30<JXI`3EX6D0cI5L0<1oB02lPST0`HA40<F6C`38R5X0bXYU0=:FN03LYi00ikRX0>NhY`3T]JH0
ikfh0080jLG901X0f<3C0<Njf`37^]/0j^oo0=?Zo`2cd_40]]ko08_4iP2Ec>l0bNoo0<k/o`35em00
mOC70<K=UP3<cX/0W9Y509V?=P2T]700emRG09^S00000000U;G<09Zob`3Bg[40c]^O0:noMT/00000
303oool000X0oooo:`0000020?l000L0000000<0o`000000003o0000i`0000005@1k08D0Y02G0;^9
U03T]J`0omnj0<65AP3AV600fjI^0=JMJ@3@TV80/WLZ0<26@@3;Se<0d9AQ0=FJKP3MYX80i[FH0>Vi
Y@3U]:00i[NU0>Zl[@020>g4_P030=o1bP3I_m00eKkD0080oooo01H0i?oo0:oOk`23_mh0HZO>08S3
kP2EbO40Z/cA0>?bc@2/bYX0Yl>709F]H`2QY580b/Z409F>002XQc/0llfT0?7=W`3_cIT0d/f@09Rc
M02T`hT0NfT0BP00000<0?ooo`002P3ooolY00000080o`00200000001@3o00000000000000000000
o`000=h0000000<0TLnk0000000000001@0000005@2<HXP0W6Mk0:a^K`3<Th<0hjZ10<1nB02lN4H0
aXAF0<j?G@3ATf00biAD0;b4>03:TU00diaR0=bVM@3PZh80hjn?0>FcW03W]Z80jKbZ0>c1/P020?76
^P030?CEa`3_f=00k=kK0080oooo01H0oOoo0=gom02Zfm/0MKK>06j_e`1SY]40LZfm08Ro[02@`YT0
TKZ308^XH02oc8P0f]^J0;b^003H/7<0k/ZJ0>o=V@37_gh0[[Mf07ZWLP32ikh0PXh0BP00000<0?oo
o`002P3ooolX000000030?l000000000000000L000000`3o000010000000o`000?l0003o003L0000
0003097?_0000000000000D0000001H0A@1407Q0G`26@dl0ZfIK0<R9KP3ATfd0bHMO0;miC02nN4T0
b8MD0=6EGP3<UU<0aiA;0<N?BP3GWfL0fj=b0=ZPMP3LY880gJF90>VgWP3``jd0m<Rd0P3oe;l06P3o
km80oooa0?ooo`3oool0oOoo0=ool039ln00]nOF09;<e@1i^]X0JK3604^J[@1e]jL0QKbF08NfP02Y
bH`0d=VH0=[OX@3;`7L0bJ<00>:oP`3Qb8d0VJaP0;gZh@39lML0eOW>B`00000<0?ooo`002P3ooolV
00000080o`00m@0000005P1N7CT0MCI=0:ISG`2jMV80`7aM0<F1F030NTh0_gQ;0<9nC@3<SeP0e9]P
0<VECP37TdX0`ha30<^>EP3@Tf<0dI=Y0=>FKP3CU780gZF60>jmX03oe;P20?oWa`0J0?oje`3ooo@0
oooo0?;omP3Eo>D0aO3I0;;Sc@2SfL<0Jk6h072eb01Z//H0Dj2]06bc/`1h]Il0UlRP0<?KXP3KhjT0
fnBY0<[9Q02]XD`0b:P00:^`JP2EZEd0Nk7;0=coi`3Jn/Y;000000`0oooo000:0?ooob@000000P3o
003e0000000H02P0001K6380JbU008A0B`2/Iel0_7UY0;I_EP2eKDX0^6m80;]dB033P4`0d9EM0=bX
J`3=W5<0ai9:0<V?CP38RE80ahEE0<B1E@34PEL0bhUO0=BHL@3QZh@0lLRP0P3oik`05P3onlh0oooT
0>3oiP2hj=@0[N3909oF_@2Abk40M;NV05nXY@1JYJd0BiV/05NR[P1a]kL0SLZi0;7J]P3Fj[L0amjY
0<oS[02hbhh0Z:YN0:N>0021UTL200000003001gU@000000000004X00000303oool000X0oooo8`00
00000`3o000000000000003N0000000505D000000000^gA20540001V00002@0000001@270000V@00
000000000000N;_700@0000001P0B00006PI6`1j;S00S49309iGC`2`JUX0_7QQ0;I^CP2fKDD0^gA3
0;ml@P3:SU00eZ9P0=>PG03;UTh0bY1?0<b>E`3:RUT0bHIK0<Z7G@3=S5l0dYEU0=VPKP3R/7`20?oU
[P0E0?oa`@3LmmH0d?;E0;gXc@2Wf[l0U<^]08FoWP1n^j80P<6h09CAf01k_]00L;K@0832b`2He=00
_NK>0;WN/02af:P0Y]2O0:G=V`2U]740Zj]I05000000303oool000X0oooo8`0000000`3o00000000
0000003N0000000505D000000000^gA20540001V00002@0000001@270000V@00000000000000N;_7
00@0000001P0B00006PI6`1j;S00S49309iGC`2`JUX0_7QQ0;I^CP2fKDD0^gA30;ml@P3:SU00eZ9P
0=>PG03;UTh0bY1?0<b>E`3:RUT0bHIK0<Z7G@3=S5l0dYEU0=VPKP3R/7`20?oU[P0E0?oa`@3LmmH0
d?;E0;gXc@2Wf[l0U<^]08FoWP1n^j80P<6h09CAf01k_]00L;K@0832b`2He=00_NK>0;WN/02af:P0
Y]2O0:G=V`2U]740Zj]I05000000303oool000X0oooo8@0000020?l00=h0000000T0eln`0>g?Q`1W
0000]@000>G6U@3GbHT0c:5X0;:@002BD`000P1Q00002`000000>00002l0000b0000MeMm09J?ZP2@
0000JP000000000PIZD0EYbn0080000001X0;P0003/0001H0000JQTC074O501l:QX0SCdX09]==@2Z
GSl0^6m90;efC030O4P0`h=50<V>C03?VE@0eJ9N0<nJE03<U500diQR0=>EI`3?Sf@0d95S0=>GIP3C
Vf<0eJ5S0=jlNP80h]^M01D0fnRd0=k`a03JmM00]n6o0;7K/@2Nc:40U<RQ09_C^022`KH0KkBi06>/
_`1c]m00O/3D08G6b`2:ak/0Lk2D06R]V@1n_:D0V/bX0:C9UP2T_7`00`0000000`2Of=D000000000
001:000000`0oooo000:0?oooal000000P3o003P000000090?7kc03ofiT0bYY50=P0003baIL0l=>M
0>_PXP3?fYX0bN@00080b>`000L000010:>U0026I`00R7<00:O3g02_ho@0[>;Z00@0000001`0;P00
02L0000d0000CP000600001_6`X0Ob`H090o9P2RE3<0[V<n0;YbBP36PUL0cHaM0<N4D@37Qd/0`hI2
0<B:@P3;UTh0dimJ0=6KF03CVF40fIe`0=FGK03ATFL0ei]Z0=JRI`3CYV00a;1S0P38b7h05@3HhJ@0
h>Zb0<gZ_P2jgZl0[=>P0:;>WP2JbYl0N;FG039oL000CE@0031?001?K`00Li8007V9001KGP00FF80
001`0000Z01/[JP0TlRZ09C4V01@000000`0oooo000:0?oooad000000P3o003G0000000708^0YP1_
0000D`0004Y4N`1EG740IgIT07N6DP04000000090?oofP3oiZX0k[af0=BPD@3JYf@0g[Ib0;jnMP2Z
ahX0b_GZ0080`o7h02L0_o3o0<Wm003Bo`00eooo0<[oo`33mOl0`oCj0<Ccj`000000F@0002<0000I
0000=00005@0001N0000La`0084/3`2??1X0W4/V0:UK<`2eJcl0_gM90<F0D@3:QeH0bXQA0<Z:C@36
R4L0`8@l0;b1=P36SDL0cYIC0=JOI@3JX7<0fYmc0=VNL`3IXV/0fJYY0=6]H02e/El00P31_Vl05P3H
gI`0f>:W0<CP[@2feYl0Yl^B09[4SP1h[Gd0=7MB06FMK@1/Zh/0Rl>U09g?[`2RbJ40jN2]0>gBW000
0000001o0000OP1GWjh0J:NT09FmU022O@0300000003000D30000000000004T00000303oool000X0
oooo700000000`3o000000000000003F0000000E03=FBP20YN@0KFVF0400001KNZL0HYBQ0980002G
IE@0S5ER0000002>V]@0b<7F0?oUd`3omlD0mkf40<F3A02kNcD0_iM908nND@2Nc:D0YmgQ0080/nKf
02L0]nWi0<7e0030nol0]]oo0<goo`3?ool0d?oo0=_mn03Un=H0P`0002H000190000FP0006D0001_
5`00Nb@008Td002?>a40TChD09e<802ZG2h0]fdm0;mgAP35P4h0aX9<0<F2A`33PT80_h0k0;Yl=02j
OCD0a8M40<f?EP3DUVD0eYY[0=fSMP3R/7T0d[=/0<2cHP2_/Ed00P36`gD03P3Fei<0cMZJ0<7JX@2e
d9<0X<>708F_M@1:PTd0G9=Q07FcU@29a:d0XmS70<g^c`3Rjkd0l]n_0`0000001@0VIZP0C9>i07^j
aP2KaJT0WJd000<0000000<0X:9@000000000000B@00000<0?ooo`002P3ooolJ00000080o`00f000
00005P1KHJP0EfRc05ela@1ST=L0B8O601mMF@28Z000b^D00<oG``2QPi@0000009biiP3Hhn`0oooY
0=SA``2h0000U`000980001`0000L9AA06nb/025a]L20:CLl`0W0:cRl`2_iO80ZNCi09k1kP2Xaod0
`@000>Woo`3dn=P0knB`0;fH00210000E`0004@0001O0000La`008D`002E@P00X50N0:QJ9P2/HBP0
/VP]0;Q_=`2nMT40`Wa80<N2D039Qdh0b8]90<R;B033QT00]gT_0;eo>@35QTL0c8eE0=ZRKP3U/h40
hKb00<2gI`2TZeP0/K5O0080b/Ql01L0d]:;0<G?R@2oeIH0[<N708f`KP1HQdL0EH]D08g<a02Hem00
Xn;K0<3^hP3TonH0oOoS0?ooe`3oi]<0g[Nm0000000002L0CI2n06f`c020`/d0Rj8004H^001>0000
00`0oooo000:0?oooaT0000000<0003o003o00000000_`0000000`0Y000000000000000D0000000H
0000I@000000003109Nne026_<D0M;Bj05BOU02Cc@00E00003d0000V000024RF07RJd`2[f?P0iooo
0;3>_P22Xjl0IP0003X0003L0000a@000;]_>P2kLCH0HJ[;0P21`^409`2=cNL0T<oX08_7i@1kY=/0
QBi00;40003X0000n^6_0>_7SP3AW@00_Gl00:UR00250000ST400993002B@@00UTD00:AF6`2^HRX0
]F`a0<J5A`2lMcX0aHA40<J4A`38QD/0bHU=0<jFD@3;TT`0bHm80;f2=`2oPcX0`hE00<F6A03>VEP0
gJma0<^bI`2f/f40ZjUE0;FaGP020<k:P00<0<k<P`2n_g00^LZ609ngL01gVE80F8E409C5X`2kmn<0
`?oi0<coo`3Nool0lOog0P3oood02@3oool0o>Cf0?7Lh03ag/T007jI05FH`@1n^[/0QZ4006=K001>
000000`0oooo000:0?oooaT0000000@0003o00000000o`000?l0^0000000100C?3`000000000001[
;Ch20000000408P000230000OP0006@001<0000000/0001i0:L0001Y0000iooo0;3V0029bl<0]>SP
00//:P2j0000^`000;`00003000000090:7RiP1>U980;7FK0000002N0000fP000<Rob`2nNdX0_G<e
00<0000002L0GJ[:05BQ`P1EW<d0000006/0002Y0000k0000=fdU02XK580VU0/09mC002QE000TT40
09]@002HC@00YE/00:]P7@2UFQH0ZV8K0;=]:@3<Sdl0ci9D0<N4B037QDP0aXA60<N7B03GYUl0e:5K
0<fFC`3>V500ahm50<B:@P37RDP0cIMB0=:WG02n[5X0];5N0;BYD`2k[eX00P3?b7`02`3;aWT0^[IT
0;>mLP2:XUH0GWhb08ncMP3Sn/P0kook0>Soo`3Yool0i?oo00H0oooo00P0oOo`0000001KUL00TLBl
09_6001oDVT0WX=Q0=[hg4`00000303oool000X0oooo6@0000001@000?l000000000000000000?l0
0;H0000000<0T00004H0000000000P0000001P1KMJ80W8RA0<ZRQP0?]@<00000001jNQ<0000000D0
O@1U0<NSQ`36XfL01@P>0;7?0003000000030=3=hP3Nd=T0k=C?00<0000000P0ool00>_^0027`J00
V<ZQ0<3I^@3:gOl0Z`000<>FM@@0000002L0H`000640001O0000E@000640001[3`00ej1]0=2IQ017
0000H@0005l0001M0000_9P0096B002KD000V4/009a=002QE000XULB0:IM5@2eKb`0^W@f0<1j@02m
N3`0^7<b0;Qh<P3:VDd0eZUO0=^^IP3HZ640diiH0<VAB@39SD/0a8a50<BDAP2eYe80][1L0;Z/E`2o
/Eh00P3:_Fh03@38_g00^KES0:J_GP1oTd<0Dg<W0=cUX@3oom<0ooo[0?;ooP3Zool0h_oo0>Koo`3e
ool0103oool01`2j]g`0000007NYeP2<_Kl0OP000;^TUP2R/@00C@00000<0?ooo`002P3ooolI0000
00030000o`00000000000080000000<00?l0000000000000/`0000000`1b[=d0A@0005<000040000
0003001l0000000000000180000000`0@01L0400BP1g0780fP2_00400@3/m000=6]Y0000003F^jh0
H:bn00000037f_05000000090>Wo00000000D`0004`0002V0000P00005X0001N0000K`000080OB@0
00L0PBP008<Y002;0000V@000:L0002lLcH0XE400080QBd001h0Rc@009m?0038SP00f/D00:E`7`2n
P3<0SSd0088]0026=000VDT009U;1`2IC0P0Y5PH0:eP:02`I2d0[64S0:MN6@2cOb/0ciiD0=ZZI@3H
ZV<0c99?0<Z@B`38S4L0`Xi30;ZC?`2bZE80]ZQB0<2_F`2n[e/20<>bG`0>0<>kJP2_[ed0VJ=@06b0
;@2g^fh0dLf90>_OY03domh0hOoZ0=goo03Dool0c?;o0=Gho`3Uool20?ooo`070=goo`32g]80Y=7Y
08:feP1bZk40bP2V0?l0d01>000000`0oooo000:0?oooaT0000000<0003o0000000000000`000000
0`00o`0000000000002]000000030080000Y000000000080000000<0FZ;:03R3^01I00000`000000
0`1fP5000000000000030000000305Z=N`000000000000D0000000<0000J0:40000000001@000000
3P1S08D0L@1a0:P0V@3O0<40000006Ie_P1PPld0g:j009W=aP2Ce^<0K:ni06JJP01OQDP0KK>/0`00
00002@3:j`000000000000000000_P000:T0002N0000N00008T0000209m<7P0W0:QF002/G`00]G40
0=:J003[_`00hJm^0=FOGP37QdT0_GHj0<J9BP3@W5T0`YX00<6iI`2XQ3<0]F`^09Q7901?0000E@00
0:40001j0000XeTA0:IL5`2UF1/0ZehV0;5X:`2gLS00ST/00=BPFP3GXF00f:AS0<Z=C@34QT80`XHn
0;b=?P2`VCl0^JiI0;BMA02mZU@0_JeH0080_jmK01L0_[QV0:6UD@2=Ud80I7/X0;^lL03Lf9P0hnNb
0>;jd03:nm/0dOke0<_bo`36j?l0bn[o0=Kbo`3Yool0looo0>7oo`3@ool0_oCZ09K>a`1PTg<0k<^/
09Z]K`1>000000`0oooo000:0?oooaP0000000<0003o0000000000001@000002003o0:d0000000@0
GP000000002AGSd0UjM/2P0000001000aNL000000?ooc@25[g/6000000030000:`0003<0000S0080
000000H0J000000000000000000008H0[P3oonP20000000906ih`01`Nl40JX[A0000000M0000^OoL
0834X@2Sg=L0WmW;00H0000000L06Ri5000000000000V`000:<0002[0000WDdG0080Zf0O02L0c8e7
0=FMD@3?V4T0g[@00>W5O`3^ahD0j/B20>G2O`3M]W@0j<f50>G6O03A_gL0]i]50<F8@`32O4L0STA2
09H0002^0000l=K<0>P0002=BP00[F/M0;Mb:P2dKRT0`Gli0<bBC@38VD/0X6000;Qi<P3DUe`0bh]?
0;ei>@2kNcD0[hHb09jD>@2l/E`0Yhlb0;jWD@2jYe400P2j[5P05@2b/Eh0V9e707J4;`1`ORP0_/1g
0=SOX`3Bi[D0_nBn0;_Ud`34j_D0anWo0<3No`33gol0cNCo0=[no`3Pool0b__Y0;WVb@00Rgh0<g=A
0;L0MP020000000304aKUP000000000004/00000303oool000X0oooo600000000`000?l000000000
000700000003003o0000000000000:L0000000H0>P0[06d0B@2c07`0000008AD002lZW8500000008
0?oOi`00000000000000002oQI@00;BT0015H000T7H200000080E@0000d0C0000000001^<`00R4D0
0000D`000000000i02d000000000R01L0:m`H@3;RV@0_9nW00@0000000X0MX;60700001D0000M@00
04l0002RfiP0FXaA08bif02S]kP0_;:10`0000002@3D0000P`0001UNRP0004l0000005h0002?0000
_`000:YR<0020:m]6@0W0;f0;@3BW4d0dYe<0=bkK@3VaWd0jlR20>o=RP3^di00jMF>0>;?Q03T`gd0
fmF?0<ZHAP3<U5D0ahIL0;d00033Yjd0cMgQ0?cof@3Pk:l0ODP00:i`7@2cL2@0]W<Y0;^8>P3@Y5P0
cJUG0<RPC@2dMb/0bHQ=0<B0A@2mMcX0/g4/0:=^002BUSd0aK5N0:nE>`2hWdL0^ZE=0080[JA=01L0
YjQC096F?`1VN280PX`g0<;=S02le9X0/]NV0<SY`@3Iool0e?oo0<7Qo`2Gb=P0_=Wh0<KRo03Al_`0
b_?D0025L02X`HL0Q>W=02ABA@2TL5`0f/>L0=ZlS01>000000`0oooo000:0?oooaP0000000<0003o
000000000000200000000`00o`0000000000002T0000000902`08@000000P7bF08fOR`0006P0001_
0000f`3;c9<0c[ac00@0000000P0onCR0?[Eg@3Ob=X0_`0008H0001=0000<@000280008000000P2E
F0002`2AD000QP000000;`00030000120000000004X000000000I@22EW40J0000080000000d0A`00
05l000000000H@000000002nSil0hJbb0?l0003j^Id0aGlj0<cU^00e>4D0XXnZ00<0000000X0LeB2
0?CLZ`3feZH0lLZO0>^nV03E0000SP000:D0003J0000[UlX0P2SEPd09`2^JaH0_80/0<ZDA03CY5@0
h/1c0>[8P03_c8X0j/R50=fkM@3MbWl0hl5o0<nXG`2fNRP0ahdo0=FLF`3AVFh0f<^V0>Koe`3eomh0
b>NE0:2L002aN@00[f`O0;Eb9P2iNRh0^ie80=JgJ03A[5d0c:1A0<N;B@33OTD0`Wa20<>0@P2[MB40
/j9<0<bbH@36Y580[98g0;VSB`020:6K@P0G09bMA@27SCH0K8<c08VOD`2Xa8P0[m6J0;kMZP3/omT0
l?oo0>[oo`3<i?l0V<cW0<O=i@39fmH0bnW70:7<003;h:`0jNbj0?ooo`31a;80_l3H0<FU/@2iS7P0
CP00000<0?ooo`002P3ooolH000000030000o`000000000000T0000000<00?l0000000000000XP00
00002P004CD0?@160000N@00000033A/0000YP000;40002Z07b//02=YYL5000000090?oJf@3ag?80
d@000:h0001k0000M`000;^be@3CaLT0lm^n0080i<X000T0dK/00:M]00000540001:0000:@0004h0
001C0000000005l00P000000700k0000I00008<0001W0000000004d0502?05/0dP2S0?K1^P3oflX0
onW@0>O1RP3CX5L00::M0000Y@000000OEih07il/02FZ]h0[[jk0?Wk_`3ckkP0`@000=:[T@3@Yf40
aXa;0>80003@T5h20;mi>@0W0:QL4@2W0000/g4P0;Qd0031PcD0bYE=0>FmN`3JY680cYQC0<JJE03L
YfH0c8a?0;if@031Q3d0d9Y?0>:bL@3_jZP0n_oH0?7oa`3<aWX0]ZE=0:A]002`KQl0YVhK0;>0:P2T
TC<0fl5d0=Z_I`3BVeT0b8I=0<F1B036PdH0ahM80;R2<P2QNB<0c:MJ0=2UF@2PQbX0^Z=<0080V90d
01L0WIe407R3;01^QC@0RJ]X0:35S@2ifZP0i_S>0?oog`3oool0o_oo0=SWo`1CRP00dl7B0<oDeP2b
U980d>Jg0=o/^P3eond0oooo0=c^n@2i`M80aKBO06f0A01>000000`0oooo000:0?oooaP0000000<0
003o0000000000002P000002003o0:<0000000<003=P0000000000000P0000004P0Y=3/000000000
001H0000000009MCD@2jNV`0jJNI0?oEaP3okNh0oo3o0>Cco`310000Vhjn0<VaaP3^dM<0onOA0?oh
a080lLnI00L0glB30:jT000006@000180000C`0005l0001D00<0000001d0;00i03@0001?04H0@000
03X0001[0000SP0g0;D0J@3O09d0oM>m0?_Ub@3hn=@0inJ`0>K>V03S/7D0m<b;0?l0003oolh0ioof
06R>]P1ZW/H0nooH0?Kod@2=0000^0000<B]P@3S`Gd0m/NM0?g5WP020>neO`0W0>6UH02nPc00aXLi
0:P0002OCP00YeX009]:2`2OC@00YeX00;1S002dJBd0Ze/R0:YI8P2hLCH0ciYD0=j/IP3ehJT0mMjT
0?;PX03L_G<0`ii=0;N@002lPS40]h4b0:259`2cXTP0gL=j0>6bLP3NYfd0fYiY0=NII@3GW680eimP
0<B>@@2BG@00[7000;n@@@2GNQ/0/im70080Sh0R00d0UiPo059V001iTdL0T;Ij0:gAW`3Jm/h0nooT
0?ook`3ooo00ooo_07Ul00000000:P000080000000L0bl>M0>7hd`3_ool0ooon0>_AcP30d[X0U;=f
04l00000303oool000X0oooo5`0000000`000?l000000000000=00000003003o0000000000000:40
000000@0FPH007Td002HH@00^8l00`0000003`29JXl0OT1>0:=/L`33S8<0j[>Q0?o?_03od;/0omR^
0?Koo`3D0000YY:i08n9`03oiM00oooH0?o`]0020>jjPP0E0=:SI023GP0001Qc00007@0005d0001X
0000H@0006T0000e0000D00W04@0B`1303X0<`110000J3UV07dlCP2ID@00ZVL00;=`003[a`00nO?5
0080n?o@0100m^:Z0?7MX@3jlk40oooH0?oomP3Xool0Z__j08cHj@2gonX0h@0006T0002D0000omZM
0>o7RP3ocZ00omFe0P3oai/02@3MZ5h0f[1N0<nGBP32O000WP00098k002?=`00SSD008`d000207hT
000L088Z0026;P00O`000;Yn<03D0000ik]m0>JhN03=]F/000000<h0002i0000`I0k0<JB002>Pb<0
dlAe0>35P03X^h00iK5j0>:/M@3QZW<0hk5d0>>gMP3AZ5/0]hHb06<T002^O000TWTI0:>H?@80Uh/_
00`0PH8W0767=@1_TT/0W/:90<_Y_@3/onX0oood0?oooP3oooT0ooo_0>Zf0024?@03000000060:jY
J`2^`_<0hMGi0?oZe@3^g;h0a=jZD000000<0?ooo`002P3ooolG000000030000o`000000000000h0
000000<00?l0000000000000VP0000002P0D0000?`0005L0001_0000F@/:080^4`2JA`00Xe/00:]^
002dPP020000000@09fad01gLZ`0WFQa0:UgO`3:VY<0jkfW0>fnYP3__jD0l[nT0>o8U`3Ol?l0/IVh
09Z@_`2ZXLP0oooC0?o?X@80h9m]02L0^G4006hM00006WH000000000K`0006@0001a0000M@0003D0
001D0000@@0o04d06P0b05l0M01P07H0KSeR09IQLP2aKfT0TD@00;]n002lS@00ooS10?ood@3oolh0
o_o?0?ooe`3iooD0kOoh0=ook038oml0/>KD09SIg`2`Oe/0h[280?oQ]@3oj;P0oMBJ0?oIZP3ogK/0
0P3ocJ404`3R/VP0i;Qb0>JkM03EVeD0_7800:iP002MB@00Tc/00:QH002WF000TC/007lV003<SP00
gk800=niQ`3C]6`0Y0000;29E@3FfI400P0000004P1[0000b@000=:FF@27MQ@0f;a_0>6iM`3Z^X@0
jkb30>ViO`3U^7`0ikio0>O4P@3C_W<0a[1L0;BOA`28GP00RW4@0:6MA080WILm00L0LG@H069k:P28
ZfX0^m^Z0>Gog@3aoo/0oOoo0080oooo00/0ook^0=F_003?[000oMWK0?ooi`000000Uj9B0>O@cP3o
oo<0oo[H0>7T_`1A000000`0oooo000:0?oooaL0000000<0003o0000000000003`000002003o09T0
000000`04`0008@0001o0000J`0005@0001P4`00IaP0070O002DA@00KQ`00;J[003ToP030000000>
0=NJL039SWH0aXio0>:]T03S[Hl0i:j>0>:/SP3L/XT0eKBP0;bO^02WV;h0on[90>o5`032V9T20:ER
J`0W0;QcH`3;Q5X0`G/00000000008<00013000000008Gl0000e0000BP0005L08@1D04L0LP1V08d0
GTF507UHQP2MRKD0/9RY0<:XW03=_IT0eM>H0?7DU`3oj[80oooI0?oogP3oo<<0jN:[0=cFY@3;bXX0
]kMh09b^R024alT0M[kO0?ooeP3oom`0ooo:0?oW^@3oi[/0on>m0080n<N=01<0jKMd0>noQ`3a`hT0
lLJ90=bYIP3JXUl0gZYT0=ZW003MZ6<0eIeN0>6Y003GW`00jl<00>O=003VeIh0`lJ00;FjO034aXT0
d=nM008000000180RP000=c<UP3<ZFd0[W`a0=:[H03N/G@0j[R80>flR@3]`8L0h/210>37P`3McXX0
cmNA0<G5N02h[EL0S7`009:18P2NVT4209:=<@0605e/001YQ3H0X/B;0=3gb03moo/0mOoo0P3oool0
303Wool0i>go0>?_o`3ZmOl0oooo0?WogP2P]Vl0_I]?0?o[^03oon/0o_kD01iU@E400000303oool0
00X0oooo5`0000000`000?l000000000000A00000003003o00000000000009D0000000d0=`0006Q5
KP1X0000E@0002D0001T0000Mc@007<V002BDP00XFX00<G6003oj@00om_200<0000000h0eYj30=VL
M03JWGP0fIem0=NJO03DUg`0dYEk0<^?O@34SXH0_Hf?0>VeZ03O][T0[8n`0:j;Z`80gIjT00D0nK2L
0?^fS03SZW80XV<00000N0020000000P028eSP0002X000150000G00o07h0GdjB061?U01PDIH0PWnc
0:^jeP2eb]L0^]KB0<KTbP3GagX0h[1]0?oEXP3onmL0oooG0?o<WP3NVVH0bhU:0;Qj:P2UM1`0O[fM
0:GAZ`0009P0oood0>oog@3Xi/`0mmBd0?oG/`3og[L20?oEY00W0?;2QP3a`XT0m<nF0?CCU@3bdi80
jlZ50>g?R@3Zc8H0k<b60>G4PP3SbXd0kmJL0>SFW`3Zi:`0f^6T0;KASP2UYW00`=ZO0<;LWP000000
]LJ90<CLX`3Ggj`0akb20:f@A`35SD80eIiO0>NcO`3Z`8P0k<>80>37Q`3FcXD0a=>?0<cIUP36cH<0
^KAP09>9;02BOQh0VH@Y0080QX0Q00D0IGXW08JVHP2eejT0hOoT0?goo`030?ooo`030>_io`3Uool0
fOoo0080oooo00D0an6Z07B@A`2]]HD0/<VV0=7^c`1C000000`0oooo000:0?oooaL0000000<0003o
0000000000004P0000000`00o`0000000000002B0000000<054XEP126dd0CCim04XnN`0n00008`00
06]4K023J8h0OUP006ln002<I`00a;800P0000004P1GQ[H0S`2N00`>4P000000cIbH0=6JRP3DUg/0
eIIg0=bNP03[[I40nKbQ0>FUR`3BSWH0_gMP0?k>`03:Z[X0]9Nb0;fI/P80olC500@0onC?0?oI]@3m
cIX0djP00`0000008000BI/0001<0000?`0005D0A`2905e<T@1@@hd0Jf6U08nSb02ghnT0cOog0=;o
l`3:g:/0dj]D0<^NA`3oeZ@0ooGD0?oGa`3iZIT0`Wa]0;n2M`2dRG`0djZ70=joRP3ZeH`000000000
WP32j=`0hMWH0>W6]`3a`JT0om:a0P3oh[D09`3mciX0llR>0?OJX03fgZ00l]fK0?3NW03_gYd0kmfL
0>[KU`3Zgj00jnR/0>CY/03Ihjh0e>Rb0:_<RP2^d980/=BJ0:oDWP2[d9H000000977WP2afZh0d>fn
0<G>UP2]Zf40FE@00;nDB03Y_8D0j<230>K7Q039ah40^<Mo0<3DTP38fIL0b=JB0;NlJ`2EUS`0TW/K
095/3P0207Qf600605Md902G_H@0`>K60<o/i`3Wool0n_oo0P3oool02P3lnol0l>co0=SGoP3<dOT0
jOo[09V/H028/HH0U]2m0:OJ`P1CHP1C000000`0oooo000:0?oooaH0000000<0003o000000000000
500000000`00o`0000000000002@0000000<0000G@0a6e`0;QmU05aKV`0[=hP0<@0005<0N@1_Qkh0
QGVV0:WA/@25RZ80UZ9c0P0000000`1209D08025000000030000000=0=RQP`3PZh/0hJV20>ZbS`3o
b:L0omZm0?oI_P3ob;00m[RR002o_`3=[[`0aJBe0;nL[`020>Fj``0W0?oIeP3oh[X0omnX0>[BSP1n
EP00cmVl0:>gf@00CYd0001C0000?`0004h0002504m2R`1AAi<0OWZk0:>fh`37ool0iOoo0<_ldP2o
^GD0bL>10<2cJ@2fXU00[;6]0;jofP2DTJd0_[_00<WMg02PWYH0em2`0>;V/`3Bj;h0_>K:0:?;/P00
0>80f<cP0=Zg^P3S/Z<0m<J[0080ombe02L0omb[0?oS[`3ehZD0lN>S0>cPW@3^iZD0jnR[0=oTY03C
gI/0hN^f0=[/^03<iK80`NBa0:cDWP2RbXl0Z<nF09c=W@2KbIH0U/>;0:C@X@36l<T0gOoL0=;aa@34
h:/0Rih00;6NA`3OaH<0k=BE0>CAS@37`gd0_LMm0;38PP3:fiX0ambL0<7ETP2^^fd0Tie709=h602C
MAD00P1nJ0001P1NOS<0WlZO0<G_h02ojNL0cnCo0>W/o`80oooo00T0ooGk0??>g03XamL0ln?T0<nH
J`1TSP00SlZ]0:7C/P1aS3h0E000000<0?ooo`002P3ooolF000000030000o`000000000001D00000
0P00o`2@0000000<0000C00a:W<0JFZW000000000300G@2=06d0c@00RL00QhZo002/_P20_/l0ZLf]
0P0000000`1J0;D08@1O000000030000000=0=2<F03SZWL0l/:@0?G6V03kc:<0om^g0?oI_`3oi;l0
>lVi0027Y@2oYKd0]YZf0;bJ/0020<n^_P0P0>K8e03_elH0kMnV0=75MP2RS`00oooo09B]g000Lkl0
001H0000B00005T0001j05E:T`1WHJH0TICB0;S9oP31h^/0bOKE0<7FW027YG`0Z/BG0;O;UP0mRh80
DIbf05ZOf020ao00a_oo08[4d@2?]kD0foKI0=7mhP27ak<20000000505B?SP0RD7P0HP000>C3[03c
d[800P3oh[P09`3oiK00kn6Q0>[QWP3Yhil0hn:O0=oTX`3JiZ`0dNJ[0<CHX03Cl<80_nBf0;?M[`2W
dj00W<^F09g:T`2OcIT0X<nO09c:U@31gZ<0d^Vf0>Wnd`3BnM80anZl0:oEWP2GXDd0c]690>OPY03I
gId0bmVE0:FoN02b`gP0]lj;0<oOX036gIh0]/f909bcJ@2GY540Ui8f09f39@0207iY000A08J_M02^
g<H0_^_Z0;[Zl`2K`Nd0e/co0<jlk03]a=/0cjc60<BN_03@Z;/0jm;;0=O0T`3?^gP0VlbR06fLH@00
QP00E000000<0?ooo`002P3ooolF000000030000o`00000000000:L0000000h0000c06YTX`00SL00
00000000NP2JX=80/03o0<<0o`2cm?l0QLCb076gh@2Ea/@0_<:N0>?0M`8000000140001U0;=cH`2o
O5`0bhED0=NEG@3NXfP0l/6?0?c?XP3of:`0omJZ0?oI^@3ofl00JIZR001?R`00Q:h0/9Jg0;VI/P02
0<^X]00P0>G3`P3ef;`0jmVH0<>kI`2[XdP0f_oZ08FSg`1JOl/0001>0000E@0006X0ASf:069MY01n
N;H0YJKK0<K2i`3FcmD0e]Vg08:hU@1EUXL0R/F^05^VT`1f`//0@YRl03^;_P0RMiT0Aina03ZC[000
RZD00:bP08RjdP2f0?l20000000502YcK02k0000_@000>3>WP3dhkX00P3nkK`09`3lj;80iN6L0>GT
X@3OhZ00eMnM0<_MW@39i:`0`>:_0;SO[`2hhK@0YmN[0:7AX@2NcY/0Vl^F0:;=UP2`f:@0_=nY0<?M
W`37hZX0h?6o0=gdb038l<P0ZMFS06fPH`2W_780cMVF0=7PYP33g:40]=2@0:g3O02Y`g`0^=:C0;gK
XP2ge9D0Z<F109BcK@2O/6<0WJ5<0:NOA`0205QT000@0;CIZ`3<onL0g?oo0;Ceo`1A0;T0[P3F0<V^
c`3DZl<0dKWQ0<BYe`3_h_l0kNoW0>3Z_@32gj`0P;>204YoBUD00000303oool000X0oooo5P000000
0`000?l000000000002X0000000P001SU`00Oj/0000007Ag]`2>V;h0Vl?I09g=m030mol0V/oo08_7
m@1j_N<0ooo@0=;G_02LTId0000O0000>026?CH0UDP^03N6T`3=WIX0chl00>jjP`3odZT0om6V0?K5
U@3d_i400<00001SE000;7/0002>0:EmU`2cPHd20<ZIT`0W0>NoZP3mfK40g/b80;RbFP2VWT80YNCC
07jXi@1VT=L0DWc:0000G`0]9g/0BDbL06mXZ@2CQkX0]joH0=>mcP3_blD0000004nMS@1/]J80Nl6a
09WJfP2ik>/0_?GQ09WId@3[oml01@0000000020V/T00:?P0:o3o`2IYO@0003>0000d@000000o`00
0=@0003OgI/0mO?20080lnjh02L0l>V^0>WXZ03JhZ40cmfL0<OLW02ddiD0[MBL0:SDX@2WejT0Y]JY
0:;BX`2Ocih0X<nL0:?@V@2cf:40_^:_0<WQYP35gZ80c>J`0=;[^`33j;`0X]>W072VKP21YE/0Z/J4
0;kIWP2gfjH0[mFM0:O:R`2Xa800XL:10:C>V@2[e:00W/J:08biO02K_7P0ZL9m08JIB02PZ5L00P1S
K1403`35jlh0h?oo0>3oo`2?0;/0=@1X0880S03kaM00hKW>0=[6k@3]j?l0kO[o0>coo@000000T;Z6
001W>`1F000000`0oooo000:0?oooaH0000000<0003o000000000000Z@0000007`00HXl002ej07Qk
^02@Vkd0OJnY08?:h02_h_l0[]co0:3Bo`2Ab_L0f?oF0;OJb@00000000110000000l0000S`000;5m
Q03IYHl0Z`0005T0003K0000h0000>@0003UZWD008@0001m_`0004L0001Y09eSL@2[JVD00P32Pg00
5P3OZHL0nlnL0=RiKP2gZE00WIHi07>]^`1]X=h0HiCI05V9dP000000;3R@041<X@1GEj<0Y9>m0<FZ
`03J]KT0k[na0?k:Z023ak80Ymc50=KddP3[o^T20?ooo`0?0=Koo`3ooo@0noCE0000002aZm00X;?W
0:^in@1oQ]4000000000N0000:L0h0000=[ba`3YmlT0k_K30080k?6j02L0iNV/0=;OWP38fi/0`=VJ
0;?CU@2Tc900WlfG0:GDY02UeZT0Y=BV0:;BXP2Ue:80ZmJQ0:kFX033hj`0`NFd0<kRYP32gjH0b>Fb
0;WP/@2Ve:D0N[1l07:NG02</Fd0YlbA09o;UP2FaiP0U<JE0:7<U024[g40Skf509W;W02Ic9d0RKV1
092jOP2K`HD0Z<V:08BRF@1oW5000P2?/WX03P35knD0/m;S0:cDk@1^=jP0A01W0>Nba`3oh]h0ilCG
0=kGkP3RnoH0dOOE08R^MP1]WF@0030dE`00000<0?ooo`002P3ooolD00000080003o[00000001P00
AW80000007an^P0c0000LjVG05RR/080000000<0Lk3008W6Y@2>c;X00P0000003@0f0000?P000680
002AEF<0[G5e0>VeS@3H0000X@0006D0001h0000T0000;000000S@000`0000005P2<ADH0Z5i>0;ih
FP2nN5X0dI9W0>RbN03GZUT0_YTm09:59P0YLKP0A8;:04IobP0kL/8000000000V00eB:40@TVN0:6;
]@2`Tk80a9f[0<:?U@3HXi020000000C0>6]M03oooH0<P1a0:`0o`390?l0[nCT0>?Ii@3:[<@0akcE
0:^_g@2W[^X0IFJ^0000000009`000350=7hgP3Mn]@0io[@0>chb@020>_d`00W0<cOX`2keYD0]mFF
0:oBU@2Rbhl0W/V?0:WEX`2Zf:T0Y=JX0:KFY`2Ue:<0]Mf[0:kIY@2lgjT0a>Jb0<OW/`2jfj@0^]jY
0;CKZP2Udj80TlB>08B_K`29[VL0U[en08^lR01o^Hd0O[bH08G2X02=`8h0MJYc08g2U@2;`I80Q[V6
08^jP`25]h40T;j508bdM01mZ6T0JY590080UlZ`00`0^nSX0:ODkP25WM@0L02f08Ab/03caMl0onkc
0>W?j`3`mol0eoOH0<o/``36hZmI000000`0oooo000:0?oooa@000000P000?lQ000000<00?l0QP00
00001@1600000000000000000000002O00P0000000d05P0003d0001>0000F@0o08M8F@2NHFX0[WAi
0>VcS03KXV@0d9=80880002BB000HP0000D0000002/0Rd910;I_F`36Q5l0aXAO0=BHI@3QZFT0dZ5@
0;jD>025K`/004FF02AF[01DPLX0C8_=0000B`0007`09c:<04<0TP2?MJD0VgbU0:fBXP3Ig[X0lNnm
0??M[`000000ln:]0>[a`0140900a@3o0;X0mP3Wl_l0f<gd0>?4c`3@]lX0]JcB09ZLe00K3aT00000
0000e03BoO00eoka0=olf03PnM80iOS<0080eN^h02L0]]RM0:k?T02]dID0WlZ?0:77R02QbXh0Ym:M
0:CCX@2XfJ/0ZMRZ0:cGY@2fgjh0ZMNV0;7K[02li;L0/]b/0:_HZ02YeZL0X<nK09G4S@2=^h40TKMc
08:/JP1j[gX0LJal07ZkV@1k_jH0O[fL08>fP028_i40Rl:F09C8W027^hT0P;F106BRM01KWW`0HYib
06fOH`14JQl00P2>a[d02`00f><0L:[>051U/`0i08P0P7Rm0>WAn@3ojol0oo?o0?ooo`3FlLX0cNNe
05X00000303oool000X0oooo>00000000`00o`000000000000240000000:00007`1o0000J00006<0
000002H0001M0000000c0000@@0005800080000001H0@`0X03h000100000EP0003X0=01l?4l0Se5O
09iSKP2^MWh0j[J?0>fhQ`3SZFl0W@000:RU002gQ000000008D`001k:000QcT008a1?P31O6<0dY9b
0P3GWG<07P3S/GX0k/B00=:YE@30W400T7400000SP00=i@0CVZi05Qoa@0005h0001S0000M01P08X0
SGR`0:fNd`3Roo<0m?o[0>[odP3`m/P0l>2U0:bVEP2U/g00^mo10;`0k02Ma?L0003S0<JghP3;YkT0
`I>L0:R;Y`<0000000H0e_ol0=;oo`3KooX0g?[E0=7cc038j[h20;?KY`0W0:S?U02SbXh0W/V?09o;
TP2TbX/0YL^=0:O>U02fgJT0[mb]0:GBX02WeZP0YmJY0:CEZP2Vf;00Wm>Y09gBY`2ReJ/0V/bL09C4
SP2GaXl0T;f008ZeMP1ZXV/0L:Uf07nlU`2@bj/0S/VU08k3UP2C`H/0R[j=08o4UP29`980N[5o066M
K@1OY8@0K[6C06bYOP1JSe@0000Z00<0000000H0000m02<eR`0^;H80P83:0=SGo`3bjol20?ooo`03
0=gcdP1/T4d0000005T00000303oool000X0oooo>00000000`00o`000000000000240000000R0000
@P00000000000000000003H0000L09EUO@0X0000<00004/0002B0000O@1I05`0F@1705d0B@1Q02@0
;02Q06H0d9bC0=2KT03AVXh0dIZ<0>ZgT`3gbid0lL28000m0000?`00T00002=BJ02`JP00QRl00:iR
0038QVT0fYii0>ZdR080hk1m01L0klB30>k<R03C^6@0_jE:09Z:000009@00021001AYP0W;dd0001i
0000H`0>04h0IP2I09VFd@32b?l0e^Wo0=koo03TonP0hoBo0<?2N01[PCD0TkJ70:kWg`0200000005
0000Q@20L[40WGJF0:maM@3<aj400P0000001`00J5@009W;0=Koo`3Konh0f?SB0<oab@2fhkP00P2_
eI/09@2Sb8L0W<R=09g;U02TcYH0[M>J0;3AT`2heiX0_MnW0:gFX02LcYh0UljS08?0W`2;b:P0QlJY
08K6Z02Ecj`0ULjX08o9X@2Aa940T/B@08JdM`1JU5d0LjYd09K5S`2Ld:D0WMB`09S@[029_hh0Rk^5
08NmSP24_900Ljj005RGI`1UYGd0P<2R07:dU01CSe`01P000000200<7GP0>CnB08:9dP39eol0goSo
0?_oo03/on`0Vkj7F`00000<0?ooo`002P3ooolg00000003003o000000000?l008@0000000<0A00n
0540F00000000`0000007@2UOIH0V7:A08]VS02BEcX0]`000:VKbP2G08l0L`2704l0J@1>0280F@0c
0000003/b/00ol>[0?o0Y@3o_j00olRR0?kBY@0000008@P^0<cnk@3Cool0T[R<0=>OL031NP00XTl0
0;]aB03?S600ijij0080k/2301L0lLf;0>kDT03C`700[j=709VD=`0009l000000000R@0004P002:3
0000<P0C0640I02X09nXi`3=f_l0kOoo0?Koo`3Ron<0d^>S0015Q`1SZ940Rljo09OIdP030000000=
0000HP00000000000>[go`3Ll]h0X:f300H61@38_lT0dN3K0=_lhP3Gm/l0ang30;SO[P020:k?S`0T
09c0OP2LaX/0X/bD0;;IXP2mgZD0]Lf90;kET`2df9l0V/F<06BXQ@1GXHL0HjjK06VcX@1i_jL0Rlb^
093;ZP2>bJ@0T<NI08_2U020]X80F9AO07N]M`22]Gl0T<FF09?<Y@2AbjL0R/BL08:jS01h/X<0N[J;
06RXOP1BUF/0H9i_07>fVP1[[hl0B8UN200000001P0Z?I<0N8WB0;SAo`3Ko_l0jooi0:;@WU`00000
303oool000X0oooo=`0000000`00o`000000003o00250000000905H0NP000000>SMb0000002eUZh0
WP0007h0001N0000=b0F00@0000001D0IcMH0:R0UP2kVK00lNG]0?Chn@3onN/0oo;@0?oaa`3olLD0
nNo30?CQ[0044VT0eOok0=?oo`2^`]40N5ib07Q9C`2=BSH0_W540=:=G03KW6000P3R/fh06@3ZdY00
j]^F0<k1L02YY4T0Ph8U0000000008X0001d0000KP007Wl0001?0000N01RKkP0Zk_o0=Kdo`3eool0
o_oo0>?oe@33eI00Fh920855001/;`00TCP006L0000F00000`0000002`3Qk_l0c>oo0<7[cP11ASD0
aLH00=o]e@3UomT0iO[:0=[fb`3=jk`0`MfS0080X/9l02@0V[ml0:79S02]eIl0_N2Y0<kX/02iag/0
]/V00:?8RP1gYfL0GJFB07g4]`1k`:l0T]6j09cG^`2Idk@0U<bV09_>W`25_Hd0N;B705ZHI@1l/7T0
LZUd07jjT@29`iX0QL>Q07nnWP1h]i00K:Ul06RXOP1EW7P0ChmR05VJL01UZX/0DIYm03F0H01US4L8
000000050000PP1/Qm00Yl[o0;_Xo`27^j`0G@00000<0?ooo`002P3ooolf00000005003o00000000
000000000000o`00P`0000003@1404H0O@2;0<80g01>BfP0000X0000X01k0000@@0001H0003>XUD0
G9VV06jjb@1e[J/00P0000000`2fZm80iN;h0?Woo`020?ooo`0?0?ooo03ooM`0n?oO0>Kid03Vj[L0
00000<gljP2ik_D0NIWB02P[N`1I>F40^WQT0<V1D`3;Qd`0dI9;0080dK5V00H0h<j60=oJT`37^fL0
Xj1606UZ3@033B<20000000?0000O`006g`000190000SP1PK[T0[/?o0=koo`3]ool0o?oo0>?oa`2c
bhL0W9m50;Ed002F?P00K00000<0000000d0fmgZ0=SYo`3=jOl0`_3b0;WO]P2MR000dNX00?Ooh03i
omT0lNj]0>?/]03Gk;@0`]NE0080UkM^02@0Ukim0:KBW@2ggZ`0bn^n0=?Z/@33dHP0[ke]08:VG`2P
^X80Xl6S09[FaP2/h/`0/n710;?Ta02Uf;40YMBU08ZnRP1`[7h0IJ1]07BZL`1YXg00K[6<07RgT@1o
_IT0N[^M072aS@1QXGH0Fiif05BHLP19SfP0BhmW05>JNP0aOV@0975E06:DF@1^U4h900000003066C
b029a^@0OKo105h00000303oool000X0oooo4`0000060000oa`000000`00o`00100000000?l0003o
0000o`200000000<06]9K`000000NP1U0;<0ZP3/0>l0HUmN0000000007`0P@0003h=?0150000C000
0P0000003@0eGF`0829g07Ej]P2CX/l0_MC^0=Wlo`3Yool0hooo0=cjm`3BnNT0a_cQ0<Scc@3>jkT0
100000001P29HhX0^8VC0>N^W03a/XH0dI1>0<J9=`80_K9R01L0dLj40=;CR@32_6X0Vi]0059P001>
T00000000000L00007@001]m0000C0000900GVfj0;K>o`3Pool0j?oo0?7om@3BoKh0Xl5o0<1d@`2X
EC<0RP0006L000030000000=0?Coo`3JoOl0b^oo0<7_g@2mgk00`>O50=ko003oon/0nooF0>c`]`3O
iJP0f>R[0:O6P`0208nbJP0S09[3QP2lhK<0anoA0=?`a@3Ej[40_=BB09>ZFP1mU3l0`JEF0;J]P033
kmT0bnk;0<o_b02oi[d0/Mb]09>nP@1fZg@0K:=/076VK@1NWFh0HZN507ZkW@27a:00OkbG08S0U@1R
XgT0DiI]04jDKP17SVX0@ha/02ekI015T7L0CIEd06^TM01_WV<0J`00000<0?ooo`002P3ooolC0000
00030000o`00000000000080000000<0003o000000000000X00000001`0003@0001U0000001X6Q40
IbH[081GG00X7b<00P00000010160000I3m]06XgD`1a<C/20000000G0440G`1E0:80MI720;3Bk`2h
iOT0^^gl0;?ZmP2]io00ZNKY09?Dc`1n`K<0Kk>I05A;00000000N;Z`019]N`000000002c0<Zj/P3o
j;T0omnj0?OP/03_hZD00P2]^6L05@3=fi/0en6Q0<76NP2<Sc@0@eh00000a`0004h0002504I52@00
0000001L0000QP000<D0e^go0?Koo`3jooH0j_oL0;k_]02C]W@0XDd008/g00020000000@0?o/f@3o
oo00ooom0?Ooo`3?l?l0b?GV0<Wgj`39m>40a?G_0=gol@3/on/0k?oS0=kd`P3?iJh0YlV<08nhM@80
Sk9/02<0_=FF0=G^`@3Clm00f_C60;cIWP2L`X80MYU=09BcMP35WdP0^YTl0=O6S@3Yn<X0enk00<ST
/@2Ra8H0P:][072TJ`1eYfX0D8I906fbT`23a:/0T/f_08o7X@2;`940JJIh04n@H`16SFH0<7]K00QL
D01@V7d0EIf205fRPP1]ZX40Nk1o07NUJP1[000000`0oooo000:0?oooa@000000P000?nT00000007
00007@00058000000000002jR7<0aIIM00X82@030000000M03d0A`2909d0Z9:b0<@0dP2K09h0H@17
07l0_P2:0<h0Wk3U0<_oo`3cool0jOoj0;oao@34n?<0cOoT0:[Td02Fd;80SY`008=k000bR8L05g1c
059L;`0W;R40002j0<?<i03Ujkh0i^[90=g[_P3>fih00P2bbXL09`3<hZX0dNBZ0;[:P`1aP2T0MjP0
002@[`0007P0002902dB0`0002d0001J0000IP000=/0kooo0?Woo`3Xon00coW10:;?V@2J/g80/HY>
0000002AHX00ZYjP0<o[a`3eonh0l?od0>3ojP3=m]h0cOSS0<chj034m>h0`?;b0=Gom03Co^X0c_WH
0<[```2Tc9L0OZme082_L@0209>mR00S0<oKV03FjkD0f?2o0<WX^02KaX/0UL:6082PE`2ggKT0eNFa
0;jbGP3De9P0h>ff0=o]]P32e9<0Vk=Y08^bL021/GH0KYYG05fQPP2BdK/0Z=k609kC[`2@`i40GY]Y
04j>H00oPUP0:g9?07JeT`1h]iH0JZb<06N[S@1_[h`0P;N908:]L`20VTl0J`00000<0?ooo`002P3o
oolF000000030000o`00000000000:40000000H0000a05H0F`1]=U40[GEg0;h0002i00030000000;
0:SSc`000;00002P08idVP2m[l/0`03L0;P0i02d0>T0_`3i0<X0o`3Fk>/00P3oooD01P3jooH0l_o_
0>gogP3GoL80^MfZ0;o>0080000000T0<cHK00/A2@00000000300;cMo`32h<80ank@0;WM[@2XaXH0
0P2ceYd09@38i[D0^=JO09fhL@1SMR40001V0000G@0009<0001k0000I`0004<0001C0000N0000?40
n?oo0>Ooo03Gol/0/]NQ0:[?V03@gkd0c[BJ0;bEU`2NSkP0_/o80>Cok`3MonL0eooX0<OcfP3;mM/0
c?KO0<?bi`2kk^l0_O7e0;O]jP2ajMP0[>7309;7W@1ZY7400P00000209k;ZP0S0=KNW037ik@0`^Jg
09_:UP2KbI80R;Ih09?4X@2mj<l0cnB[0<O?QP3@gYd0gNR]0>?Y[P3:ch@0Q9Y809ZmNP1bSd80Fh<i
06BW]P2Tf]D0Zmbk09c=W@1HUF<0C8aO01eXA`1ZZH40M;28076^R01k^9<0O[bO08g7Y`2DaIT0Y<jM
0;C<T02JYEL0J`00000<0?ooo`002P3ooolG000000030000o`00000000000:00000000D0=`180000
0023A500XEY>09@000050000000B0000P@1K=FP0P6B=0:nO_`340=d0_;GC0;fdeP35_N80cKoP0>GE
`@3oom<0oooS0?ooi03oonD0oooK0=Smb@3=omL0iOS80P0000002@1>0000000006]ST`1SP[H0KYVd
09oGd02NcjL0S[b509c:V`020;CO]00U0;CM/02LaHh0Q:QU0000O@0008@0001H0000O00008h0000c
0000C`0006H0>dJM0:Bfm`3[ool0fOGO0<OW]02G_Wd0]M>G0;kYh035h>`0_kWB0;G7j`3Conl0cOoU
0<?ig@2okmX0^ngC0;g^e`2hk=T0[nOQ09GFf`2=d]X0SM?B08S>`01e^j<0HZJ2001`C@0200000080
_^_H0280_MfY0;WS/`2Nd:80X]2K08W>b@26c]@0W=cN097Dg02Od;h0/mF[0=WRY@3^lK`0i^FW0;g1
LP35_GH0/[ef07fFAP1l^mL0MYVX07>j^`2KcZL0G9Y[04J9G@1LX840LK6=06j]QP1LWg/0O;VE09c@
[@2dhK`0/]^`0;?HZ03>jKL0eNF]K000000<0?ooo`002P3ooolC000000030000o`00000000000080
000000<0003o000000000000W`000000201602<0H`0n07X000000000P01a0:9_O`2SLH<0kL^`0P00
00003@0006T0KCUK09]iS`31[;h0bKK;0<>Y^P31Yk/0aZc30<bW[@3c_YT0on^i0?ood`3oomD00`00
00003@3Pood0ho?80<^GH@2mMe00_hV10<6L/P2U[lH0UL[W09_Jg@2Ee;l0Ljj207beR`2PekP00P2H
cjT09`2Aai`0O:ij06R<A`0006h0001V0000<P0@9H40001X00004@000480001X0010V@2B[_80foKZ
0<c/_P2feY`0XLB30<KOX`2jh<l0/=ko0;_Qo`2nkOl0^_GX0:oYd`2[hm00Yn7909cJa`2Gf<X0TmK=
07[5`P1P/kL0GK2h062b]@1M[ZH009f1001_U`0008D0001E000000020:OG[@0R07bjW01BW8H00000
0000002?dM80TmGN08S>g01c_M@0UmG>0<;T^`3Rkl80k^ni0>ORXP2`]fP0g[]c0=:fJ@000000BEJO
09BKe01=VXl0=giG04>:I@1c]il0H:J<05fRQ01PY8D0O[^H09gB/@2ch/80]^>o0<7U^P3;ikL0e^Rc
0=kX/F`00000303oool000X0oooo4`0000060000oih0000000T0400603L0800g0200CP0b04T0000i
0380MP1m08H0Q@2eQY801@000000302ADE/0g[>N0>[6]P3>YZT0bYnQ0<RLXP2mSI80aHId0=NJN`3]
_i`0o^Vg0?koaP<0000000d0hooo0>[]b03f_i40k[=m0?SEa03om_l0i>cg0<7Th`2VgLd0QKb@07:/
P01m_jL0NKjX0080OL2W0240GIii06JMJP1OPcP003n@0000IP0005P000000000B00003T0000]0000
D000?YX0P:K/0<7TbP2lgZT0YlV70;;@S`2YdkX0V=;U09OCn02OeOl0V=K^09CGd`2Ee/P0T]>o07[1
/P1]^Jl0HK:[04bRW@12VIT0>96D03J?TP0_07@00P0000001000YKD0R<Vk0000001XZ80209oI``0A
0:OQc02MfL<0000000000022a/X0J;C@046C_`1X/<40Zn;?0<[_eP3NmM80io?30=oV[02;X500[iTk
0=^oL@2IL@000P000000400kQ640<gmP04ZFQ00mS7d0@i1m06F[U026a:X0X=Jj0;7Ra02hiLD0_nS3
0<k_b03Fkl80hO;50=KX]000/`1[000000`0oooo000:0?oookL0000000`0:`0P04H0;@1602d0A00/
04<0;@1f07T0R6N=08]/U02AJ8P0l0000>d0003[00020000000L09QCC`3[]8h0gJF;0<26O`29Adh0
IQl]074S9@1k:P00Pc8008`n003OgJH0i<f?000000000640003L0?Ooo`3oon`0oo380?o][`3ooml0
oooc0>gejP3BkM<0ZmN/07B[NP1EWXH0A9J@03b?Q@80@i1n01l0EY]o06JIH@1INc002DZJ0017UP00
04D0000`00008P0004h0000U0000B000C:H0JiWI0;WTb@2/ejP0Z/f@0:S@V@2RekT0U=7;08G;g01o
b=X0OLO;07_5_@1d_Zh0FJVM04^OV014VI80=Hf:02N1OP0003d0001T00D0000000<0GJF=00000000
X9d00P13VJ<08`1O[:`0J;Ba06Ve[@2:cld0V]WQ09_JiP2<d]l0QL_F0;3Wh`36m>P0doKJ0=cec02[
ahT0TZ=B0<BZE@3Och<0bJH005fRR@000000AXQO0000001QZYh0LKJX08c;]`2Jdkd0[>;>0;gYc@2j
ilX0a>c;0=7bc`3@l<X0foC;0=O`aP3>j;H0068006/00000303oool000X0oooo]`000000300[0200
AP0]04H0;@1402`0@`0]07H0N@28Ihd0RfbD095XR03`0000k@000>/00080000001`0V5=?0>^dSP3M
YH/0`8Io08U7CP1V7bd0LB<U07/Z0023<P00S3h00=oMYP3TcHl000000000H@000=`0mooo0?ook03o
l<P0onf_0?oog`3ooo<0kOGZ0=;]d`2[ej`0M:]j05FNQP14UY00?8n50P13T7h07`1FVgl0IYUQ05Uk
<009BYX004NF0000A@000300000R0000CP0002D00018001<YP1[VMT0^NC90:cGZ02ZcI00Z=2I0:;G
^@2DdL/0QL_L07o8fP1mal/0NlFm07Bn[P1IZId0BinH04BITP0eSHX09h5n0000?@0006@01@000000
0`1MYHd00000002PW@0204>IX`0S05n/[01X];40JKF]08[?c@2JfN40Vm[V08cBg`25bmH0/>OS0<Kd
j03Cm]X0g?G<0:_7R@2BXe80a:YE0=o?P`39YP00GJ:900000016R5l00000066ZWP1a]ZP0S<^g09[C
_@2/h/h0_NW=0;[WbP34k</0dO;?0=3`bP3Km</0eo360<kX]P00HP00J`00000<0?ooo`002P3ooonf
0000000R02L07P0b0280A`0/04L0;01;2BD0F1H_06HW?P1e>4d0Q4aN0;j1M`3R0000h0000<H00000
0000PCDb0:=IAP37P5l0Y5iD07llB@1_92d0HQLT05`0000j0000?1P009b:0035]Fh0e9eP0<J0AP3;
PTT0001Q0??og@3onm40ong10?onb`80oooL00L0mOkL0<cV]01/Vf00069X001[M`0ROI00=hnQ0080
CIjM01h0IJJ406NAC`00000000000000T@000400000P0000=`000680000L0000B000IKX0LZOA0;3U
b@2Zf:X0W/J:0>;^/P3/nl<0[]?o08W?f01i`l80Lkjb05JVU`0iSX@0=H^102AmM@00Gf/0JKO907>o
c`2Lc^h40000000502j7S@0mU9D0>92H02b6U@0TP9@00P0LN9804@0CLH/0=XfN05j/]@25b/d0X]gS
0;3VmP2JfNL0OlSH08W=fP2Gen40Y=kR0;OSa`26[f`0[;5U0=VjKP3TbH00iLf400<0000000d0NF<0
0:SNc`2/g/T0^NO@0<G_f03;lmT0d?GH0=3de@3DmM<0d_??0=7abP2`fK@0]=^b06d00000303oool0
00X0oooo/`0000001@0H00005`0<02H06@0R01<0>`0Q0080@`0R00L0GQT]06XU=@1d;cd0NC8k0800
001_0000EP000080000001h0OblY0:ILB`39Q6T0^g=M0:eRD02BAT80000009=7A@37SVX0h;j00000
002o`hh0g/6X0;n5L@2PET00]fm40=6BEP3[`8`0onfl0?o``03ol/D0oooA0?ooc`3VmlH0T[Um0:cQ
b@2ekN80XNSb06o1dP1R//<207Vm/`0307:WM0000000V6T00080000001<0001h0000:@0005`0001Y
0000?0000680A7g;07>_bP2Lf<<0Y=>S0:S?V@3Xm;D0ooo?0:;Ih`2<d<D0GZ^J03b@O`0nTXH0<8Ei
00<0000000@0003o05>O_@0009X0002V0`0000001@1DYZ<0DjFV05>VZ01CYZX0CZ:^0080Bing01l0
AY^h042G]P14V;d0D9o;06Rbe@29bml0ML7:002b`P00UKH009Fi002ha@21`Z/0^;Qn0=BgM@3W`G/0
j<^40>CCS03@[eh000000<ZY003<mN40c_7D0=Ogf@3Fn=d0f?[M0=Khf`3Dm]P0eOGD0<_`d03;l<h0
YMJc06l00000303oool000X0oooo/`0000001@0N00L06P0I01l05`0_01X0?00N0080IQl]00h0L2Td
06HP<01X7RT0RT5006000016000000000540002PBR80]FDi0<5fC03<SFl0R01806l0;`80000001L0
okbP0?oEY03^b8`0001f0000`03;//L0>P0005l0002[L@00fZaW0?;FV@3ol;h0oo?10?oea03oolX0
m_c409o0Q03MoLd0kOoR0>Kon`3Oool0`Ooo09OGeP02082kW@0406JDEP2GUd80UhP]06eZ00800000
0240000]0006JP002Fd0001@0000RP13RLX0HZ_;08?6_029`YT0M[FA06F^VP37hK00HjfL03N9N00Y
Og809gie001FF`00ATP0LF>T0000003L]X/0003`0000o`2Wh>L0Wm_F08C7_@1Y/j<0GJ^O05^[Z@1D
YjT0DZJ]05BX/P1K[;h00P1S//h07P1Q[M@0GZSG05BOd@1CXLl0Dj?=04>F[`0aR8l0AiVB002<U000
07l000250000RP23b>00blj=0=S8RP3[e8l0hmZE0=C8OP3DbGd0_Jh00>?oj03`omT0jooK0>Gng03N
o=h0dOGI0=Gee@30jLP0_nW:09C6Wg000000303oool000X0oooo/@0000001`1E0000@00d01P06`0P
01/0;00H02X0601/02`00P1S02`09`1X8c<0JbHh08Y7D01/0000=P0005d0000l0000M@0009T0002a
HB/0`7m00<f<H02X08@0DP0b0000002MLhX0olnl0?W2W@0D4P`0000H0000HP150000Q@000;h0002`
L000[8@00?7MV`3ll;/0ooO50?oia`3om;l0e>F/0=7Z^03]omP0kOoQ0>Sol`3Mooh0aOWV0:GE/`02
07N]O@030:nUD@32ZED0Thle00<0000000d0000l000GM`00370004NR0000O@0kS;/0DZ6c06>bZ@1D
XHh006=L001GHP00CEd005UN008000000180F:Jd07JneP2m^XL0Kf2S0000000003P0002T0000hP1h
_]@0PLK;08C:_`1R[il0Hk6Z06Bc[P1U];@0K[_507O0eP1g`=/2072kf@0M06RdeP1OZm<0FJO>05VY
b`1IZ[X0HK2]06^fY`1AXZ008Wj@0000O@2IfMh0SM3P08;7hP2?c^P0b/b>0>3JV`37gJ80cn:W0<SI
VP2`]000f_oo0>Gom`3LllL0eo?;0=?cd`3;lM@0_>O80:[K^`24_YX08@000000101d:000MRT0078U
001U5P1<000000`0oooo000:0?ooojl0000000T0:00004D0000f0000?P0C0200000W00009P0004T0
001M73D00P1n@5<09`2:CEh0SE=U06/oIP1Y08D0NP2>06D0000i0000FP0007`0002M0000]V`00<J@
003F/`0041M]02hnSP00XLX0b;[30=S:]`3SdjL0dJem0;n8DP2nLcH0[`000>>cL@2oU4T0O5X00=W;
PP3`j[40noO30?W^]03XjJ`0KiE?0>G_^`3]omH0kOoO0>Woj03HomT0_^S508k0U@0205>8C`040<:c
G`2jXD`0Q8D[05`e00<0000000`0001i000CMP0MH9h003V20000X000KWP0VKb60>;kf`0iA840>U]g
03ecK@3>ool20000000B09ZH002N[P00X<JD06eNX@2aWl<0001M0000N`0005T0002Z04fQ[01DY9`0
IK>Y06fj]025blH0Q/c>08O=fP1i`]X0KKSE0P1[]mD06`1T/]<0?92]03bA[@0iT:80?9>G001`N`00
QhP01P0002d000000000V=SP08c@hP29c>D0VMK]0:OI``2Wdj40/=RT0;;M/02Xd9X0KI1:0=ooo`3R
oml0dN^m0<o_bP36k</0^NG409C9YP0P0000000;03d0001<0000CP0005<0001A0000C`0003h0001W
0000P`0008`0002E0000B000000<0?ooo`002P3ooon`0000000804d09P1<01`0900002L0000T0000
JP0005dVA`1<5Cd207e0E@0W08m@G@2@JXd0KTQ`06H0K01h07D0@@0005@0001=0000AP0005X0002b
QP00`ZT00680[P0W@I80031d002_i000dnL0dO?W0=oofP3Fjnl0c]So0<nl``3M/V`0j/b40<beI02Y
V@00/JUE0>gHV@3ciJ`0j^:N0:RcJ03IfI@0jO>o0=ohc@3PomH0]^_80;KYb@1YYGl0ChYI0080i<b<
00@0c[U[0;2QC@1mS3X0OEX00`000000800007404EjT04:?Z@1e]jh0U[Am08fUF@3AiK@0g_[c04b9
/`000000`[;<0?oon@3oool0ool00<7N002leZP0K48008QTT02T09h002Yi001GR`000;8006jL0026
XP19WZ`0JkS209_JfP2Uh]l0W]gP09GGh@1j`mD0Gjk30P0gSI/02@0kSh`0>hn;04ZOY00dS9/067B?
00i[RP0?K8`097j?03^BV0020000000?08c?i02De>X0002o05ZVWP1l^Yd0R<R[08[6X`00XgH0oooo
0?OolP3NmL`0dnbn0<?Y``2bg[L0O[F>01l000000100BC1e05ljKP2>HH@0/WZ30:a]H`2]JUL0WEM7
09mM@00007<0002J0;nP^034Ti80b8ah0<^NJ02agLT0fLj/1`00000209kGe3`00000303oool000X0
oooo/00000001`1>74D0@@0002T0000f02L0P@1n085KO`1bC7@00`0000009`2BFFL0TV^507PoC@1S
05<0J`1M04@0>01d0000G00007/0002K0000[Z0007J00000KKX0?VZg02US[@00A:4008Fo02<0O01K
0;D000000000[03Ck?l0hmZe0>GBR`38`000`<400<nWE03T_GL0klf@0=g<PP1TN`00_[`00=o[]@3C
kl@0K;:L07bnYP1^[i80Di5U06VBC`0206<000050<_2M`2VXe40S94k09Eb501A00000P0000008000
01@007Fc08;3fP2RaZ`0`<V10<kAR02[`[@0PK?:06RX/P33b_T0`N7U0<goi038o^X0/n[W0;>cL`2X
RdT0NU1j0:1mW`005e/005JN0023/0000000002Q05RWc01V/]80Ml7F08g@fP2Th=d0WmkM09;Ee@25
blP0Ik:V0P1X[iH06@1X/9T0EZFI04jPX00mTih09X6C01EaR`00HW/005E`001`QP00R9D006l005ZG
J01j/8<0Y]B]0327U000TiD008n90015:@3ooo<0ooo^0?ood`3Lk;P0d^B^0;3HZP1eZGP07`000000
4P0005@0001B04X0M@2=KIT0c:2^0=NWX`3LZi@0`8eQ0;9o@@0003`0001M0000003H]id0`lZ/08RK
00000000WHnP0:1fGD@00000303oool000X0oooo/0000000200W0000?`0]02d0;`2E09l0W@2X0:D0
/02GPZH000000P2DACH04P2EACD0UDXl08<j=@1Z:CX0A`1706D0GP1I0000L5j50:fPXP3/i;l0DP00
04e20000000007NG001SGP000000[8j/02d0PP80000001<0a9NM0;oYo`3@e[l0h=RB09jR003Qi@00
aYl00=FS003V/Vh0d[5T06aW002kbhT0^MVT0:;@YP1`/I40I:Z=072/PP1cX680Rih00080VZYI00H0
_/Mm09fWEP27NAT0XGdR0:Yc7@1M00020000000C0021`02P_<<0cNFf0=KU[031diL0c^2W0:cH^@2a
j?l0TmG]07:mc01U]<00S]7K0:kUf`2ebZL0^lR^09F<TP1<6DD003mc001o_0020000000:0000K000
0;X0Eio@06Rbe01la=P0W=_K08kBc`2;clL0P/:U07o0XP80O;jP0100JZnD06nfW`1Z]:40CI^<03N3
J010Q5/0AHUO05BAHP20]XL0R[f<056?H01l/7h0/]Z^0=?dcP3Mon<0j?oh0P3oool01P3oooP0oooQ
0?ooa`3BhJH0^mRN06jQKad0000000d0=00=000000000000001=0000AP1K0780[hZ^0<FJ[`3>WJ80
aX^50:UUH02FCdP0QS`000<0000000H0]]S9000000000000GTj?07A4001F1`13000000`0oooo000:
0?oooj/0000000P0900n0280<00000008`0003X0001<0000200?09AoZ080000000<0`@3J00000000
00000P1[00003P0k0000J@0007XS001J0000?0000:UmMP10GjT0N9:o0;C=fP3?f/@0e/VC0<T00000
000009F^0P0000005`15;cX0>00005@0002WIfP0000O0000b03Fg[00f]fG0:BZ001W0000P@0009/0
0034V@00a:5@06a_002E_H00VLB=08bmS027^XT0P[B208ZkR02>/6d0PZ9M0080Ih<000d0^LN008JD
@@2OSc80Vg<F0;R6<@2hORh0JQh00000002QTZ`0eLf_0;SBVP2RaXh0Sl2I0080000000/0TM;G08O<
h027cMl0QlcL09?Dg@2/hn00[=[M0;KQl`31kol0HeeW0;FCH`04000000090000V`1][=d0NK_I08C9
eP2;cll0RLc108W:]@21`J<0P/2O0080QL2I01L0QL6M07noX01`]I/0DYAZ04V7EP15RF40FYQ[08Vn
T028_Hl0H9QV08bkQ`2cejH0d^o40=[kf03Tond0m_oo0>Soo`3iool0oooo0?oogP3^nl`0^]BI076Q
K00M0000000301408`1R0;P0000000<000000180G@1O0:QgU@2mSj@0bZS30<n/_P3M/kH0002Y0=NR
00000840000`08l0K02^LF80fJ^>0??BZP3AYG40000007dh001g0012000000`0oooo000:0?oooj`0
000000L09`0N0280001C03@0F@1702/09@1K@gT0WgfH00<0000002/0AP0Q04/0001D0000E00006@0
0023@dh0[6mP0:1R<@2DBP00001k0000T01GUm<0ERA?0;gEh03=bkl0RP000600001C0000>P000380
000/0000A00008Xg<`3BOG00000W0000W`3JiJH0gnFU0>?O00260000W`000;P0002FH@00/J9=05mk
;02H_h<0VlB=09VoP`2B_8<0VL6909FmPP1oYF@0JIUN0080DG8W00/0]/R307Ao:P2TYU<0[9<i0;F6
;P35Td80^hH000008@000880`;In08bYI`020000000C05b0b01YR;/0Y=oJ09SGh@2>dN@0T=7W09;B
j@2Mf?00X=[_0:SPmP2IeM`0SkJH07>hZ01T[k40E:Jj001STP00C8T005jS05bId`020000000509WF
b02Ed[T0P<:V08S6Y`2=bJP00P2Ebj405P2CbIh0R<2F05VFI01=PTL0@hIM06FQL`1o]XT0O;>408Jb
N02H`Hh0/mJQ0=?[^`3Kmll0hOoS0?oom@3oool0g?oo0>Woo`3Bood0e?CK0<[Za02Oa8TM00000003
05AmD`000000000000<0000001@0Q`1Z0:I^P@2gQI/0c:c:0=kCo`3AeO@0^[_B0<Fka`000;l00017
0000a03omO80omRj0?kO_03hh;L0g/2=0:f2@@2SM2h0VfTR08A800X0000000<0b:fg0?KWa`000000
=000000<0?ooo`002P3ooon/0000000<02808@1402L0E00j04@0=`1O04d0IT9Y0:UlR033X:T00000
0540?`1Q:T`0LSeL0P21Cfd04@1oCF`0Qf260;J8PP00000040/604H0801P03X0V`1U052Cg02ff_l0
W00009<000290000O@000000000^0000C`0000<0000001<0P00P0;h0KP3Ejk<0gnbg0>g_]`3J^G/0
^W0[0<l00035T4@0Ui80086ZJP2PaHX0XlJ;0:;0O`2Vb8h0Xkij08f/I`1ZUeP0I91A0080Sk5`00X0
UkAa08^WH02c^Vl0]j1;0;63:P38U4D0bYm@09ifU03H[hh0RXTo0P000000500TBel0?hVW0;_Ua`2]
hmX0SLo?09OFhP2Ken`0R<KX09CBk02Ce>40V=SR09cD`02XfKL0V=:f08W9_`2FeM40WmkR0:7Li`00
F9404@X?0`0000001020`j/0V=2]09WA[`2LdJX209W>X`0E08k4V01YX6/0GI1D05V?E@1m[GD0Rkf<
07^aP@1fY6T0Y/R<0<KR[P3:hk00hOC70>oof03oonX0ooom0?ooo`3_ool0iool0:OTh02Pd[P008]L
02<0000001H0CP130:80VP2VMI00ZW5g0:il603Rool0^NGo092ji02Q_n40]LKQ0:VLf@3on_l0oo7c
0?o[d@3oil<0n^Rn0>oR/@3Da8D0/YI>0<FMGP2KG000F0001`0000001@3<`=l0/:G90;Vfb@3RjmL0
BXZa03@00000303oool000X0ooooZ00000002P0M000000000000000O01X0<`0M04/0:@1C03d0M@00
08L0?P2;05X20000000406`kH01eBg80S6R>08eYS`80R6>:00<0ND]^08QCK00000000`000000101b
05D0okb`00000000]0060000000G04d000000000EP0009X0002fJ@00_`1B003>X@3Jl/T0joS60>SL
X`3:VUL0h/1j0=JjJP1kR340U[Yk0:S9S02[ah@0//b;0;O=S@2G[F40Ji5;07NNGP1cTTT00P22Zfh0
9`1PSU80Xkah0<O>R@2oZEX0^I<m0;Z==`000000Sh>c0<^cT02ARC<0Q;ZA086K002JJ`00_MBH0;OL
/`2JdKL0Slo70;;Vl`23`>@0Lk7R08[4k@2IdNX0^nGO0=3bc`2hhl00Y=Rf0:[Qd@2[i>80[NK[0;;W
l@000000JTeQ08=DL`000000WmJf0:KH/P2VfK<0Y]Rb09_@Y`0209K:WP0D076VK`1_WV00DX9108Jb
MP2E^gh0Rkb:08:_M@2F^7L0_=NL0=KY]P3Nk[`0io;10?ooe`3oond0ooog0?oom@3oonl0d_oF09O<
/@00NDPS0000000I06h0L@2107/0RUMk07@fC`2GDSh0RfX00000001f^KL0EinO066QZP000000^;So
0?K^o`3ojo80on;>0?WE/@3af:d0im^U0=K:R035_WP0ik^?0<R@M@2VI4h0RShP09d0000300000009
0>g5_@3Tb<h0gMSo0=?UkP38g^80goo/0:R`IP1gD`00SP0001`0000000<0on;30?o@ZP3od:X04`00
000<0?ooo`002P3ooonW0000000A02<000000000000002404@0^01@0?`0K03H03@1N02d0E`0002@0
001@84h0Db9?05DTC`23EgP0UgFH08QXR@1`@VP00P1R9D40101V93X0TU5L0000002RIW0200000004
08@0K`0000000000001c0080000000<0Tema0<6@QP3^`I/0100000005032OU40_h0c0;fH0000Y800
gooK0>_oeP3fol`0f/B30>OIT`33]F40G70J0:K7R@2]c8h0[<Z:0;gDU@35eI80Q9I507bCA@2:WU<0
L8i30P1ERE807P2=/G80]/b<0=?OXP3Vj[<0lO6k0;NF?`0X;XD0N8[90<7?e@2kYe<0002Y04EY003T
`@00c]NE0=?Y^03Bl=40fo?S0=[oo`2RgOd0LZoR097;l02[gn/0bO?Q0;oYb`2^gKX0W<bR0;KZh@2n
l?X0_>oe03aX<`<0000000H0_MbT0;3L/02[fZl0Zm^d0:3C[02EbZ0207R]N00=07n_M@1^VED0Q[9e
0:K<UP2A/Fl0Q[=h0:?0O`2bc8/0enJ`0>?__03Ukkd0l_S20?oof0030?ooj`030??oe`2oj;8006Tb
01l0000000h0S`000?;L_03bhNL0cJRj04deJ@1MFiX0J7FC0000002eRid0ek>n0;>3IP000000Yik4
0=3Wo`<0000000d0lM_o0?o;e@3oeLl0mlRZ0>gDYP3ReY/0b[ae0=[5S03odk`0bY6D0;L0M@2aK5`0
VUD/0080aP0000/0j<:M0>g6[@3Zb[d0i^7o0=c_o`34kND0V<;N06nG001CI[00NfQj09X0000F0000
00060:H0002=0000O@000<d0003okM@0oooY0P3oom/00`3ViK8000000000000@000000`0oooo000:
0?ooojP0000001005`0001d0000L0000?00V04D0;P150300DP0]01`000120000?`0003`0000o33/0
LCmA0:j>P@2:Jfh0F3=W0P2:DfT01`2CGW<0WG6<0:V4X@2cU;<0YX6N09U]R@3ecI<00`0000001`00
8@0000000000003mglT0oo330?OBVP2=C`000P000000503Y]H<0eJ=D09Qn00000000mooi0?oom03i
om@0jNf_0=3?QP2_[eX0X/>30:_;S02UahT0Z<Z>0<;JW`37g9l0PH4009RPC028TCd0EH000P29Zfh0
7P2`a880a]FF0=WU[03/lKh0kOO10=kKV@000940`<GV0;cEh@3>dHd0001L03ef003?c000PWd00=GB
T@3ooLh0ooob0?ooo`3Hool0XMck0:;Jk`2YhN<0V]O?09[C^`1m]Hd0Wm>k0;O[l@000><0Y=SD05EF
K@80000000L0enfm0<WX^02/eZD0YmJZ0:7F/02GbYh0QKZ:0080QkIm0180PJia05NCIP2RcI/0Ul6:
08jfN@2UaHH0^Lb90<kKW@3XkkX0jo2l0>ga_`3ooll0oooQ0?ooi`3oonH0oooO0=Wg^@23[74N0000
000P06DM8P2OH440k]fb0?koh`3oool0GQHL09;>d@3ojmD0hmZf0000003:_^/0i^So0>_Zo`3`a[X0
jm7C0>GQe`3Uonl0TiS00:ndi@2jXM<0`jC:0<JaeP3P^[`0ak=b0>CGW02o[fD0d;n00>KHY0080000
>@0009X00032[Fl20=WNZ@0<0=3bg01g]LH0lLjh0>gXo`30f^`0X]Bo0:G@h`1/VL`0FWfo08FA[03D
[jX0Y6d0400000002`2QPP00000009/0003X09d0e01o0;VJG`34]6h0S0000=H0003oonP0ooo]0080
n_oS00<0f>2W0000000000004000000<0?ooo`002P3ooonW0000000A02/0000P00003@0003D0:`1>
03/0BP0i03X0:00f0000=`000340000i0000L`0I08e8:02ULCD0_IU206i6L02@J8X00P2ROi`01`2P
PIh0YHj`0;R]g@34`_H0cn;W0<cZc`3E_gd00P0000001`2SMGl0bJj^0?;Ld03ooo80oooo0?oof03o
j:h00`000000503cbYP0h;MV07Y[00000000oooo0?ooo03oomD0nNV_0;o=Q@1[QcT0[/N40:O5P`2K
_Wl0Zm2J0;7CVP30gJL0OW<009jE>@27QR`0UJ]R0P37dXd04@35dY40cm6<0=o/]`3/om00jOg60000
400009X0bmoY0<kSb@37g9l0001]0000J@2XaP00_;^M0=RoL03fhJ@0ooo/0080oooo00/0gooo0:WS
h`2Helh0N[nb05>KP`2Bc:h0003=0000S@0009`000000000o`02000000070<[W]P2Vd9`0TL>A09;8
WP2Hc9l0T;j6092mQ00208:^L00A05^8002Nd:T0XljK07n^L`2Tb8d0`m^P0<_ETP3LgId0jNZa0>_^
^03`l/40oooD0?oogP3oonH0oooT0>Goa02_dIX07P000000101f<Cl0XUaD0:YcA@2QSd430000000J
08P0001D000000000000003Gjol0j_oo0>koo`3]l?L0lOoo0>Koo`3jmmd0QW:X07UZZP24MkD0[9k=
0=k5iP3`f<X0h^Je0=gKY@3AcY00XJMM0000003ccKX0hL2B0000002ZOXH20<;CW`060>?oh@3Ion/0
oo;=0?3X^P3;fjh0U[^N0P000000200eIZX0G8S5000000310000ZP0008`o001c8P00J1L030000000
2`3AaP00UXH00>CIb`3ajKh0f=NH0:VVG`2e_7@0a=BK0=T0003ZonL0n?o_0080jOoS00<0e^Rb0000
000000004000000<0?ooo`002P3ooonV0000000B03T0000S00006`0003T0<@1E04H0B`0j03X0:@0i
0000A@0003X000160000GP0Z0890C01m?Cl0G0lK08iRO024H8L0SW^Y0P2WV/<09`2[XLP0ZjG;0;g5
n030f?l0_n3o0;oYmP000>T0002A0000>02;Sj<0Zko70=7[i`3Too/0h?co0=_`n03Hh]80mo>k0?KS
Y03V_G/000000>K;O@2RR`0000000?ooo`3oooD0oog=0?OW/@2icXP008e:0;o?R`2M]F`0Xl>50;;K
/@31i[l0^/V:08n1002HQRH0Q7T00:F_H0020=;GTP0W0=_HT`3Hdh/0iNja0>gohP3Lk[40dlV10000
c@000?00co?60;>E>`2ML`00002S09Zdf@33]i40fka_0>;5N`3ooM<0ooon0?ooo`3KonL0]^KA09;<
[@1j^9`000000<GAZ`0009X0000k0000I0000000003m0000k030jL`0YM:R08BhQ@1o`KT0R<2Y09S5
U`2JbIP0QJm_0080LJ1Q0100]mRc09k>X02:^H80VL680<GQZ`3@hjX0e=jN0>CRY03YiJX0k>be0?Ce
a@3oom<0oooK0?ooh`3dol`0a^>[70000000901A0000:`0A06l0CP2VJ6h0`8ah0;jFHP2ELZ40`ifj
0=6Z_P3F[K`0Z00000451P34a?H0c]Wo0=Kao`3Wool0hooo0>coo`3lool0oooo0?oOb`2ZOih0R6fS
0:NKc03D`^D0onSe0>Cnh03;eIP0cmn]0<SGWP30cXl0j`2j0>`0/`3PcI<0JeBE0:Z>YP80bI5R01D0
l_oa0?okg`3oj//0m>Bh07F=A0000000i[FZ0>Rh0017NKP0>VV]0000MP1G0000J@0007XY002DAc40
WE0k09=5;`26=b40KP0005T0001800000P140000400`0000900004L0002j^o40f=_U0=gH[@0l@000
f?;Q0?Cof`38hZ00/JmW0:WF[02ih[/0_>K60<K`g03AnNT20=Cmj`030<WXb@2]_7X0000001000000
303oool000X0ooooY@0000004`0e00008@000300401903D0G01B05l]E00f0000000003H0001;0000
DP0006h00022D6/0W7260;23T02_PHX0/8nV09]oXP2LTL000P2W[><09`2a^nh0[[oT0:S9l`2Weod0
YMge0:7Oh000]IL000000000C01bYl@0T=3P0000001j`N80Tl_i0;KYo`3Bnol0l?oe0?god@3VeYP0
jmbK0>?GS@2bW`00Z@000>P0003oon40iMfg0<SJY`1kVe@0b<f20<;>QP2X]6L0`LN00<[W``39h[X0
d]6A0:jTB`2JOQd0MV@00;>cH@020=cKU`0W0=ONW@3Jgj00nO;00?ofa`3mnLX0knF[0000g@000000
ZLF:0:jD>P2US00000250=:oT@3I_7L0gKia0>C;P`3ojk/0oo330?7db03Jm<h0^>K80;?Q`@3?mMh0
g^O60>[I[P000:D0002/000000000>h0XmkN09oJc`2Je[l0Xm2T07RheP21amT0T/g90:7G^@2Ga9@0
LiUC0080@fDG0100onnh09o6SP2QaXh0_MbW0=3V/03LjK40gNJZ0>CUZ@3Wj:l0knji0?SgaP3ooll0
oooH0?ooc`3QmKX0KI9;6P0000009P1f<d<0KRe602`0502B0940f0300?ojo`3Xool0GCAZ0:R:]03:
/mP0i<k[0>SFm033]>P0YYcP0=O/o`3Jn?l0f_ko0=goo`3Gool0g?oo0>_oo`3lnOl0kmGQ0<BR_@2R
R[`0`K;L0=koo`3Yool0k?O?0;RcO@2ifJP0TZYU0;f=VP3_a[L0jmF/0000J@1XHZL0YIBf0P2nS6L0
0`3ok]P0omO?06h000040000000M0=6a001T@00000000000002C0000VEE608Tk0021<P00SClN09E8
;P2JCC`0TTDm088c<01f9RX0H@0004P0000l000000000514R`2PZ=L0dnG`07d0003IYI00X0000<`0
003Y0000KP000000002RekX00P0000001@31kNh0a_7Z0<KajP2ggl<0T9l001400000303oool000X0
ooooY00000001`0c000000000000001H0400I01@06D0FP0m04D00P0000002`1O0000HP0007M9KP26
I8X0Vh6U0;ZU`P36[/H0dKcE0<Nba02bW[d0[ZWD0080]<?j00X0[<ok09k>j02@cN`0S=7T0831_@1c
/IH00000001nV02ZYlX0TZO=0P0000006`2K^NT0]mWo0<Olo`3Mool0mOoo0?Kok03Wl;H0k_Vm0<;?
Q02PX@00044108J>003/0000SKnS08RjS000cZ`0^l5c0<79OP2`/Ul0gLb10>WKV03ciZ`0m^Zd0;J`
F`2MO1/0OUl00;2_G0020=KKV00W0=3LW01:7e4000000?Ga_`3kmL@0m_k70>KYY`3:^VX0[8L/0=Jg
I`2/SS<0TF<60000W`2od<D00<ZG0>OAR`3mi[00mMJK0>CKXP3Ek/80bng60<_Y_`37l]l0enW=0000
00000;80002i000000000<T0FZ^f08o?c`32j</0000002fNg01GKK@0Y>CY0<Soe@2Z`h<008D00080
DG8U00l0_m2?0;3:RP2meid0d>F`0>7^^`3Rj[<0hnR_0>;W[@3Zjk@0l_6o0?Wgb03ooll0ooo@0>kc
_`2ndI<060000002084lA`0W07XhB`1l05<0>00S09n2Y`3<a]`0cl_;0=;Qj`000000VgVS0;jUbP3X
dO00o_7o0?gdo`3CfOl0d>Co0>?oo`3Rool0gooo0=_oo`3Al_l0c>Co0=_ao`3Kj?l0a/_l0;VgiP2S
TlH0^JWO0=?<o@3]ool0hnBi09I_G02be:<0KSEM0<^AVP3of=80omnj09jHA`000840W9O@0080[8ng
00<0R@0004l0001`00000`0000000`3oomL0gML009Ao00020000000I0000O@0007<0_7QS0<:1G`2e
LTd0ZF9509=5<02:>c<0PS8b078W>`1a:dH0G00003X0B`1^BX80000004X0002nOhL0cHnB0=RQW@3m
dZ`0j/:B0>4000380000Z@0009Y=;P0300000080`^kL00<0^><008^@000000004000000<0?ooo`00
2P3ooonS0000000E0700P@000000000^05<L@@1M9dX0HP1?04@0?@000000Lc]E07U8J@1hB6X0Q5b1
09IiW`2KS;P0/Z;50;jegP39_nX0dm?o0=3Vo`34k_l0]nkm0080Z^Od02L0WMo[08K?h@1e`mT0O<SC
076j/014PED00;>c001ZR@00W<L0Tk;P0000001fTmD0TZgW0;[Mo`3Bool0j?oo0>_oo`3]ool0jOoH
0<c][P2/a7d0Tj4001iC001dX`0008n3001cJP00Pf00X[5R0;30N02[_740V:UL0=gCT03]iJX0lO6n
0=gOXP2m`700W8HX095T002/Xd`00P35cXP09`2ARH`0R[JA0?;Z^@3ekKT0moo;0?Kog`3QlJh0a;EU
0:ZXE02dVT80/h`d09]]4@2JJ@h0]Kg:001_RP00XZ00UMbQ03K4O@3Ldi00dmjP0<SJW02ag;L0^>[I
0=3Ze0000000002n0000001Y0;00W/GF0:_Oe@33m?`0d?7G0=7S[0000000;T:H039@U03Uomh0Zkaa
002I000208JMC`0?0:^oM`34chX0d=jS0>3Z]P3Ykk`0in^d0>KZ/P3TjK00k^jj0?Kd``3knl`0oooB
0?knc`3Yll40W[9[01@0000000@0IA`X078[=026@d/0WEeV0P2nSYh01@2RMY@0F25=05`P?`2YMWX0
cZ^d0080000000@0XGZP0<N]cP3Vc>T0onoo0P3oool20>Goo`0H0=goo`3Lool0fooo0=coo`3Alol0
`]go0<oVo`3AiOl0a=7o0<7<o`2a]NH0^;K[0<g9o`3Gh^T0XlJI06=MB`2=CfP0UeQ_0>:MY@3oj]l0
j=bT0<nhMP0008<0UioK0P2LW]H09`2VXMD0/kCV0<78o`3Ag?l0g=Oo0??/iP3ooll0h>2S0<2eJ`24
H000Wfl006@0001P0000]7m60<N6L03=SVh0]W1E09I9@@2<?Ch0SD1309E@H01d?FL0C01R03`@DP00
0000X0000=nSY@3QZJD0olni0?oOa03olLh0onZk0=cJWP3Ifil0c`000780002MERP0]gE:0<fF0002
0<JD000309<0001_0000X8l001000000303oool000X0ooooXP0000001P2:05L0H01X0000000003H0
EB5805XTB080000000h0WgB<09U/Q02BHgd0TVJ509YjW@2YSjl0/:740;nde@34a?H0c=7o0=C[o`3H
ool0b?_o0;O^m@80ZNGM00<009R[05R^`00000000P0000008P00dLD008:<001ENP00R;P0J@2a0000
0017M/@0KiWP0:g?o`31l_l0e_oo0=koo`3PooX0e?oB0;SMX`2O`X800bd6001bMP0SNW8007iT02aY
002C[fL0X;EZ09beKP2B[fT0^LV70=cRZ@3Wkk`0k?W;0<oFT`2m`W80b/Qj0:Ii6`2/U3T30000000D
0?KU]`3jhKD0o>Bj0=[0P@3TijP0hnZU0:J[GP2k_g80ak5Q0<>KA`2[MR00UV8708QI002hR000=^Jc
003;W000[I@0b;QX0=>eN`1ZMU@40000000>08X0P@2>@XL0X03<0=L0g`3<mnd0/>S_0;KTeP3Bj;H0
0000000jS00SDYL0NIf604U`:01WV6420:BlM00?0:o1N03Bei<0iNN]0>g_^`3/kKP0j>^c0>KZ/@3T
j[00k>fh0??e``3joLh0m_kB0?7jcP3>hJT0050I0140000000L0AP0=06`0=P2<BeP0XfId0:EWL`2V
J7<0]GUk0080PT9G00X0Kc1=05TNA0000000K`0000000021CW80WgNJ0<^ac`3Tdnl0oo_o0`3oool0
6P3Zool0i_oo0=Cjo`3BmOl0doGo0=7eo`3:jol0_]co0;kHo`34g?l0a=[o0;[Co`2oc?l0000009bm
k@3Pc]h0gKS70;V>Y`2dQ9h0omOP0?o]f03onmL0lo?40>WU/P1EI[40QIGD0P2BX=d03@2IY^00[KOY
0;k;o`3@hOl0gNKo0?oon@3oold0in>V0<:^I@2^W4X0_j1E0;V:AP2LG`000P000000602^0000WE=7
07d/:P24=2/0VU1709aDE025AU`0C0000000002I0000omK?0?o>a`3a`Kd0on;=0?oog@3on/P0i^N_
0=3MXP3AgjD0fMRO0=g=T`3H]Wl0eJUd0=>XM@80g[^300@0eKQl0<:hL03Ad`00RFl03`00000<0?oo
o`002P3ooonQ0000000608P0=@1j03h0D01?0000001S>6<0K4A^0P0000003`0006h0X7NA09afU@2E
KXh0TfnC0:B0W@2dTj/0`;3;0<k=k03@f?l0c^;o0<7So`2fj?l0Z^Ko09cKd0030000000904hOC@00
000000000;>ZX`00000008]o01L400001@009Rik0080000001/007W7002al02Yeol0`_3o0=3oo`32
nMh0/>:h09g;V023]7X00927002HR`000000>7Q:09FlO`2F]W80X;Yc09FeLP2YahP0a]nW0=[`_`3/
omD0i_O:0<S>QP2i`G<0dLn30=cFSP2QMQH00P3B_7809`3dfjX0oMRa0?oG]P3ofkl0j:f20=n`J`3I
_W@0TJIK0<g@RP3F]f`0d:]K0<6??02QKA<0Vg4E08m=002SJ@0009bT0026Z035ZHD0V@000=W4O000
0000Q@000980Q01o09d0]k7=0>Kdj03G0>80f_oV0;S/k@2Mfn80Slo@003mi@00OY`002MX03QCD@1_
W640NkZP08ZcNP020:FkL`0>0;W8P@3Gg9X0jnbe0>o^^@3]k;H0i^V`0>?W[@3Rij`0h>Zc0>Kb`03S
mlh0fo_L0>;ca02_c8d?0000000:03X0001J0000MRhh08M3C02CD5L0V5EK09iMI02OGfT0XEmQ09=A
FP80JRLo00P0000006000024B6D0Q4YZ07e7K@23DGX0fKW@0?oJi`D0oooo00D0l?oo0=ooo`3:l?l0
a^co0<O/o`020<O[o`0C0;GKo@2Zc_H0/=Cj0;CEo`20[N00Xl7m0<WDo`000000cM3j0<Bae02XU/H0
ZiG:0?g_kP3jon80lOoJ0>Khd@3>hK00?5>T06f3b00208fRgP0K09VZh`2Y^N`0^Lgo0<_Ro`3NmOl0
mOoc0?ooo`3cn/l0bJUW0:R2=030XeT0aYiK0<:>D@30QU40/Fe20:QO>`2REcT0W4hf09=4;0270000
JP0004l000000000V7NY0<Jcc03on?T0n?Ko0080oooo00X0oooJ0>Od``3<h:X0_=NL0=;V/P3Ki[L0
h^:b0>?AW`3QcYh0j=BO0P3Jci40103AaXD0WjD00=g_c@3CfZ8?000000`0oooo000:0?oooj000000
00@08P0@05h0001A0000?P000`0000004@0004<000000000D`0007d0Ug2@09=_U02NOZ00]I:Y0<Rc
a`3Pg>D0m_oo0?Soo`35jol0XmKY09?AdP22a[@0=P000080000000<0HcMM04l0G@00000010000000
0`1gI`400000064mL@020000000K0019U`00TM40RLKc0:?Nm02Whn80W=c208_7X`1f/XH00:jR0000
001/Xfh0BHEA09BnQ02H`8H0WKmo08V]J`2S`Gl0`mVK0=O`_@3[om`0iOgB0=oeb@32chX0`LMl0=GC
R`3Mg9P0]Yi50080MBT002L0j[N:0=VLK@3OWWL0l;6G0?o:^037ZV<0RiY80;c>S`3JeYP0j/N50>;0
N@3E[f<0[H`b09]d5`2KI`00QDH007`l0000=8<00:JC001^VP0f0000F`0007@0002>05h0TW9h0<76
a03UomT0fooQ0;K^h`2Eb[D000000?oohP2KWG80]lEh0=?oo`1OI`h0V=C?0:C<X`2U`h400P2ebhT0
3P36eI@0fN2R0>W/]P3`l/00knfg0>GW[@3Ri:L0hNJZ0=o[]P3Pl;l0iOK<0=Gbc02lfZ@0Xl1m1000
0000103D[G@0djij05h0001F00040000000=01<0001B0000K`0007hc;@2:@Sl0QCdo08@l@@27@4H0
Q3a0084h>@1m<cH0I00004D00002068WC00708]BK`2KIGl0Yg>=09ARP`1mBW<0j/WF0?oVjP030?oo
o`0M0?_oo`3aool0l?oo0=con`3<moD0a>cg0;_Tn@30i_h0`^Oo0<;Vo`2igo`0Y/ob0:G?lP2Scnl0
OK?J05VF_P19Qi8000000;g6o02g]NP0b;oc0=?6oP3doo/0k_oS0>GldP3Fk<00/<fD07FQI01CL;T0
0P22W=X06`2AZ>40XK_^0:g7m`2keol0b^?o0>[oo`3oool0ooo]0>k<W@3=YV@0Wf/T0;^;B`3?WVD0
dim]0=>JL@3>TFl0diQj0=:HO`2oOG00XP1L05l0;`1H0540YP300=KKo@3Bj_/0lOoo0>_oo`020?oo
o`0:0>?kfP3Cjkd0/=2D0;kR]03>l<X0gO[J0>OgdP3/l/L0jo340>?R[P80eMZM00<0bln<09^S003I
m=`04000000<0?ooo`002P3ooonP0000000704L0<01>0000>P00085CK`1nE7@000000000G@020000
000=04l0E01`0700TFZ<0::8ZP2fXl80d;W90>WOh@3ooo/0oooo0?coo`2mmN80PlFd05j@J0020000
0080B6<002L0:00^000000000000N`2202/Q7@0[8BP0F`000980002?Gg`0OfjQ0000000nML<007o2
0027_`00S[d0?9N/052TY@1JZ9T007H0003<Y`1h[7T0L:Ia05fEGP2?^h80WlR@09[4S@2>]GP0W;ai
0;c?S03@gj40i?S60>Oof03Ro=D0eno00;[<Q`38cXD0e]ZE0=KGTP2hYTl00P2ZOb@09`2EDP00_gM@
0<9hA@2WL`00h:Q[0<>SFP21ObH0koG20>cMY`3`b900j<>40=ZkK`2EF6D0^Wi`0<F5H02O0000Qd`0
08E90000V;@006Bd04En`@03H740biQI09mA5P2_TVX0bm^j09_E/P2Jf<`0Tm3307R`Q`3of]d0k<4P
07E?003:`hT0000005]T8P3Kgm40`]ZO0:_<S`020<_PZ00W0=SV[P3IhjL0j?6m0?3eaP3gl/40jNJ]
0>3OW`3Tj:h0hnfi0>cb`03SjK<0bnFd0:_?UP2H]Fh0M`0007QS002gNP00_H<00;1l003U`Xl0b99Y
0:=Q;`23>180M@0008d0002>A000SD8009I<>P2ID440TdTm08@j=@1a9200H00007//8P1a0000MBPV
07L^=`1H63D0FQm60080T5]j00H0ZGNB0:]hT02LJ8L0PDed0=nd`P3on^X40?ooo`080>[oo`3KooP0
d?[^0<Sai`39lO40`>[e0;ORm@2cgOH20;cQo@0C0<GZo`2cgOL0Z=Ga0:?Ck@2@aN00S/CD08k1[`1]
I:H0[k?Y0;Zlk`2j/nD0fmGo0>gRl03Vj]40f^bn0<SOZ`28Yf80RJUU03eP[00206j=c`0W08JWh02G
^n`0Wl7`0:_;o`2ieOl0g_oo0?ooo`3_mO/0onZo0>o;U@2bO3`0UeH009mK9@2/JCT0/g550;QdD@32
P6H0c8ii0:IKE@1a0480G@0k0;D0XP3[0?l0oooo0>[oo`3Qool0g_oo0?Soo`3An_@0e?GI0;OIYP2R
b8l0a^c90=?gfP3Ho>D0iOoX0>_oh@3WnLl0gnfk0080c=VM00<0`Lb90;:dJP0000004000000<0?oo
o`002P3ooonN0000000803X07P1D04T0HS5H05L/FP1m>3l0Pd9;0000000200020000000809eZO02]
08D0^P2B0<JLXP38/lH0a/SZ0=OTn`3/ool20?ooo`060>[oi02Zg;`0HkCA092f^@3Aa:`000000P29
00000`0=0000C`0008X0?0030000000Q0>8000370000[I2/09NGa`000000HIoK05JYeP13VkH0:hVJ
01MhP`2Pahd0Z=:O0:GFZ@2=`8l0MJUc06NKHP28[g00YLbC09o7SP2J`XT0Wkmm0;W>R@3@g9T0g>>U
0>Ga_@3RmLT0g?WE0<kV/@2jd8h0c=NE0=WRY03@dX`0`[YW0080_:190280_iU20;9o002nM4h0`7I3
0<R7A`3@VE00Zi9<0=NfP`3KZGD0jKV40>6mN03C]FH0WG:?0<:HV@3V_Z@0o@000<H0002BF@00046B
001EXP00FJH005jW002Ed@1hIC`0WjYn0:kFY`2Ed;<0ZN?F09?B`03WbN00n/_B0=VFQ032N@00Y5d0
0P0000000`3hhlL0Z<Z>0;WGX@020=S]_00W0<kRZ@3Hl[l0j?oI0?;nd`3ln</0iM^L0=gFT`3Vijd0
knjl0??`_P3[ijh0`[ib09:iO@00Q`00X5Q007D0000@8e80Jc<007@g002e^i/0m<ff0=BOP02aKTT0
/6];0;9^EP2^JU@0WUM909M>@`2>ACh0N2hb07L^=@2EF6H0YFYg0:IXL02LEdh0/W9^09iIF`1S94<0
L39@0080WF9e00H0WfAh09ALM`2<EGH0cIVX0?ofi@3oood30?ooo`0N0?_oo`3[ooh0gOoa0=Gjj@3=
mNP0b?3^0;kYlP2fh?@0[]Ke0;?Jm`2kh_/0b>ko0;gSoP2ffoh0[mSi0;_XkP31kN@0bO;L08J3aP2R
X=D0][GV0:^Yg@36`o00lM370=KN[@3Nkl<0_m>K08f[000004/0;EBR0P1JQLH09`1hXm/0PjgR08fe
i`2M`?00Zl[i0<3So`3Qool0gN[o0?oihP3oh;80iKn>0<ZJI`2`LSh0WEHS08@d002BA000Scl009]<
0029>000ORha0;^4R@3ah^H0oooo0?Woo`3Hool0cooo0=3no`3=mOD0dOS/0<obd`2]dY`0ZlN80<_b
f03<m>00f?o^0>Kol`3Xon80iOWA0=SZ]`020<?HV`030<KGVP30bHD0000001000000303oool000X0
ooooW00000001@0=0000:@0005L[EP1Q=V00ITUl00L000000100^Z:l0<^a`P3G^<40f[g60=C?k@3A
h_l0g?oo0>coo`3lool0f_oo0<;_c02mdiD000000<Ggj03oomX0oo?@0P3je/009`3Q^Zh0fKnV0>?C
[03]i;D0nNk70?g/e03^gNd0h=;W0<h0002U^^H0O:gM06ZXa`1DXZd0<HQo03eoE02Ob900[=BP0:_G
Z02JbYT0OJed07b[L02F]W80Xl1o0:C4P`2SaHL0Z<V90;O>R`36eiD0f>>S0>CXZ`3Jj;00eNfl0<[^
b`30gZX0_=JI0<cQYP3IiZ/0f^>U0=;AR0020<c0KP0W00L0002BEc<0QU4c038C7`000000^WT/0<>;
002/GBD0_WHl0=2?D`3DZ5l0=bXU0<RJU03B[IL0m]>R0?[NZP3]f9H0fLUl08iF000006d005ZS001N
Y000Khl0FXQj07NcU025_iH0WMFf08?1Z@000000`[3G0:nE_@20Ih<06QDK008Q=`000000a]RX0;3E
X@2PaXd0bNVo0080iO_<02L0f^nh09>_3P3WonX0j_WU0?KcdP3ZfY`0b/1d002o[@3holX0mNZf0>kT
Z@2UZU/0Ji5:0:`0L@3W^I`0fJZ00:if002AC000K2H007dc002VM8<0RTU=06`K001h:A40NBX@07X[
3`29?C40QCTb08Ll=`2BBD<0YV=O0:ibNP2WM8`0Y76;0:9UL@2SH5/0TTa=08];G@2FF6X00P2GEfT0
1P2GFVh0UeY_0;^1T@3oi]T0oooW0?ooo0<0oooo01h0nOod0>Goi03QonH0g_oW0=OkjP3BnNh0cO?g
0<;WoP2gfOh0^Mkk0;gTo@37k?l0aNSo0<?So`37iol0doWg0=gokP000000`<oo0;JomP2W/N@0VZGN
0;:_c@36/kd0hk^C0>7cb@2Z^WT0W[n00000F`000:P2062?c00W06RGdP1aWmL0OJSN092gj02K_nh0
YLOd0;_Lo`3Ekol0n_CX0?ooiP3oom00on:f0?75V`3NZX<0ci=b0<B1003:R780ci=i0=jZQP3/aY/0
kmbd0?ooj`3dooX0gOoo0<Wfk`2ljnX0]^KZ0;GUk032kN@0ang;0:G;U02`b8L0^=Zd0<;_hP3fool0
i?oo0>GokP3Om/d0cNB`0080`mRL00<0a]RJ0<SEUP1gJ@004000000<0?ooo`002P3ooonL00000004
04/0001O=V80LTYb060`E`<0000000<0;Ba^0>3IX@0000000P000000403CdoL0fmC_0>;Ci`3UfNd0
h^co0=ooo`3Sool0j_oo0>7oo`39o^/0_^No0<7DT03SolL0mooo0?ooo`3oooX20?ook00W0?KcgP3W
mm@0l_oD0?kof@3oonT0h^KJ0>;jo`3DlOl0/<[M07fnc`1_^L00HKB`03^6J@1m/7d0X<V@0:gDW02_
f:H0Y=2M08ZiP@22[Fh0QjaX0:BoNP2ndHd0Y[mi0:S7Q`2je9@0`mJD0=CQX03LiZP0inZ_0=7QY034
gJ<0]n?10;WR^`31gJD0c>>Z0=WUZ@3KiZT0dmjM0080c<^000<0b/9d02`0001G3`@00`0000008@2f
N2L0/g400996002<Eg80PLcH08;<g@00U8/0jL6E0?GJX03ehj/0j=fJ0=;<P@2SR`00P4`00000B@00
0:P0Dig=06fb`P1l_:H0S<:D06BTO@00o`00ooKo0<:^dP2LO:P0^Zfa00L51`0N5280OJ^709G8WP2A
`I00^>>l0<?[b`020>[oe`0Q0=Ob`P1QO340eoSo0>7al03akmL0nnVh0<>kLP00aK/0noo]0??oeP3Y
jK@0Ri];05`0@01f;P00TgX00;NO0000000000240000O`2kO@00SdH007/^001l;P00Q3H008Lj6@27
>A/0QcTP09A9<`2>@c80V4hn09I<>`2GCdD0SDaB0080TE1O00@0Te1I08@j?P2DE6<0UEIZ0P2RJ7`0
9`2oT:40gk>n0?oSeP3ooml0oooX0?ookP3ooo@0ooog0?oon@3]onT0hOkP0=omhP3OonH0gOoZ0=co
m03Bmol0a^Wo0<7Qo`30h?l0a>Oo0<O[o`39j?l0b>Ko0=7bo`3Nool0h_o]0>7nh@000000UZSS09F_
hP27Y=/009_>08B=c02QUJ@0bNW:0<WZ003;eP00002=0000_P0206:BcP0Q06JFd@1YVM80JIWB07ZX
g@28/n@0Ukk/0:gAo`31h_l0j_oh0?ooo`3ooo00oooH0?o__`3odkD0o<FZ0?BoY03b`JD0ikjO0?;B
Z@3[dJ80noS70>kic@3JmM@0d?GN0;cZg02Tg=T0YMcS0:;IiP2ah]X0_NK30;cIX`2gdiH0f/6^0080
oooo00@0j_ob0>3oj03ElL@0c^Fa0P34fId00`3<g:00am>B0000000@000000`0oooo000:0?oooiX0
000000D0<@0A05L0AP1W=e/0QP2?06/000030000000301Pb;P1BTh@0000000<0000000d0b/ch0=_J
o`3TgO/0j_Oo0>Soo`3Vool0g?oo0=7oo`37n_/0`>oE0;kR]@3KomP0oOoo00H0oooo02H0oOoo0?_o
o`3oool0koo_0<OQh03=ool0]^ko08?<a`1h_jd0IZb@082gR02F`hd0Xl^C0;7CVP2`ej80[=FQ09W3
R`26[g00U[an08jSD`2]aH40W[1S0:[1NP2dbhP0aMZI0=3NW@3Hi:L0hNZ^0=[SY03:f9D0`mRH0<SZ
`P3@i[00dNB]0<gSZP3Hi:H0fNFX0=;OX080c=JA00<0eMJ?0000K@3Nag`00P0000008P2E[j80_HHc
0<B:?0000000bj6B0=K=/01__mD0Xf80099?0036WH40i]bU0>7QX03Kf9@0cKX007<j001V0000001n
04>;a@1d_=T0QLO209g@Z025L`00oool0>W;i02bU[l0VGjR0;jj/@000000F::<06^^S@1n^iP0U/nc
0;o[d031k]L20<[bdP0W0=;dc02TJcd0e>co0>kXg@3oi[`0nN^j0<FeJ@00MYl00?KG0>_of@2ec980
:gP00800BP2]KP00`8ei0=4000000000001K0000G@2MFCl0S48R09mG;`2HCbD0TDLK08e16P2AAB@0
TDDX09Q=<P29?B`0MbTQ08<g<024>C40QCP`08Lm?@2<ATl0TTeF09M@EP2GDUL0Z6Yc0080b9FQ02L0
klG80?oPe03ooml0oooX0?ooi03oonP0ooo[0?oojP3con/0j?oR0=kjg03Po>00gokU0=goj`3Qood0
f_oo0<S]o`33h_l0_Moo0<OXo`3<kOl0`^;o0<c[o`3Io?l0g?oo0>3oj`3Mnmh0f??>07RFe023Z]h0
Q;KF05nM`P00QJ`0N8340000001KBh`0CCaj03f0[P1hX]X00P1iZ]`02@1WV=80HiC?05Z@bP1TVM00
M:CI08^eiP2OaO80[m?j0=Coo`020?ooo`0L0?ool`3oon80oooE0?oid@3omLh0oo?;0?oaa`3hjK`0
k^Ba0>OZ^03Pk[h0g>k20=;^b`3@m=/0_N[P0;G[j@2/iNP0WmOB0;OP`@3EkL00knNo0?WP^03om=<0
mNW70>gfdP3UmLX0e]^T0=;R[080dn>]00<0d=nU0<?=RP2MY5L04000000<0?ooo`002P3ooonI0000
000602h0001P;E40HBmC0940P`1d06<0B`000`0000000`1o^;000000000000020000000=09RA``2k
^nh0f]oo0>7bo`3Xool0jOoo0>7oo`3Bool0`_Sj0;S/fP2ij</0c?oC0>Som@080?ooo`0R0?Soo`3S
ool0b_oi0;;/m02Wk?l0T=SV08[>`@2Jd[00O[ZB09G4S`2WcI80XLZC0:cDWP2_ej80X/^B08beMP2R
aXT0Xl>209J/G`2J/fT0X;eh0:g2NP32dhh0c]fM0=CPWP3Mj:d0fNFX0=;PX@3:eY00dmVF0=o__03R
jkH0h^Zb0>3W[080enBV00H0dmnN0=SLVP3Hg9X0hmVE0>WHT`3XeHl30000000Q0;b9<`0000000000
0=S3V`3Sk[T0nMO@0??C003Ta000/ib00=?QZ@3=gJ40knbd0>3>Q`3BYE`0W6800000000XL;<0Eio7
09gEd@2nf`00bL`00?oonP37X;/0RVJG0<6[]P3bjlT0000009C:Y02Kbih000290;?Ud`31kn00K:bC
0080U7ZW00l0X8^f0;nMZP00000000000?7ed03Zj;40aKea002eaP00imP0eNo309k2Q`0h03`00000
00X71P0k:bD00P0000001@2?AP00LB40070Q001o<@00U4T00080WU@c00l0ST4X078Q4@24=B40TDD^
09E9<02ICSD0[FUB0<>5K@2iNW<0Zfa_09iMIP2WJG<0]gb30<bGU`3R/Jh00P3oc<809`3ojM80oooN
0?ooj03oon@0oooQ0?oohP3non<0looP0>Wog@3Pn]/0hO_L0>;mg`3[on/0l?of0?3oo`3Zool0d?ko
0;gQo`2egoH0/Mci0;KNo`2aeol0`>3o0<gao`3Fo?l0fo_a0=_hf@3EklP0PIgH0:K7h02li>H0`>[j
000DI@1bOl@0U8:Z061a^01?EiX0LiWE08jii`0207j/gP0W06fKe01XV]80GiK<05:=a01DR/H0JIcB
07n_h02B_nX0[Mcd0=_oo`3mool0oooo0?oon@3oonX0oooR0?ooh03oom`0ooo@0?O/`03]jKH0h^B/
0=oU[P3LiK00gnk10>7ed03Son<0i?oi0>Soo@3IooD0joof0>OohP3moLh0oo_;0?o_``3oh;d0oN_3
0>GPZP3JdI@0emZP0080em^O00<0c]JH0;W9Q`1_NBD04000000<0?ooo`002P3ooonG000000090200
000k02h0G31K07=FQ02H07<09@0007X0001hKil0D@000080000001<0SP000:P0002aTJX0ZHn^0:ZL
`P2h]n00bm7o0=Sco`3Qool0iooo0>?oo`3Aool0`?[g0<Gki`2_j=40_okJ0=Goi`3]ooT0nOoo0080
oooo02X0kOoo0>Koo`3Vool0iOoo0=koo`31ooD0VnSO0:3QhP2Kg^D0Q=3M08oEd`2MfL@0V<jU09W9
U`2PbY80U/B>09[9V02QeJh0Z]>N09_2QP2F^WT0Zl^=0;3:QP2P_WT0YlJ50:_3O02hagd0bmRC0=KQ
X@3Gh9l0g>N/0=SX[P3BhjL0bM><0>3OW03Sjk@0lNni0?7]]03]ijX0f]fJ0=kUZ03QhjD20>WPW`07
0>_LVP3[fIH0k=ND0>SBR`3G/F<0/gdW0:Ud6P020000000N0=_LX`000000i^G/0>SXf@3Ffjl00<D0
0;SJZ@2eejD0hn_30?;PYP3U_Wd0bkd009QQ000008@0?X2i082gb03<l]/0gng00>K7S`3DXhH0i<>l
0>CGb03oonT0^=b[0;?JZ@2efZT0_>K70;[Yf`25`J`0_XbB0P3CY;409`3og>d0iL_R000000000000
g_oc0=O__@0000000?[`0=3aaP2Xbi40LYM?03L0>@1g0000W0000;d0003IXX@0000009=8>`2OED00
YEdk0:UR>P2JD@00Ud`009I;8P2SFS<0/fi90<20G@3;SV/0ahUY0<J6JP3FVgl0bXaf0;MiN@2UIW40
^XJH0<REX03GYjd0jK^i0?oHb@020?oYdP0W0?olf@3oon@0oooR0?oogP3oomd0nooK0>gof`3WoMT0
h?WH0=[ff03KmmL0hOoR0>[okP3^ooH0kOoo0>[oo`3Nool0a>gl0;GRlP2Ld>T0WLg[0:37l@2bdoX0
`>?o0=_oo`3Noo40foKD048jP020U/l0^]Wa0<3Lj`2ld?l0036207jDc@2c[[d0]iFM04QZ]01bVm@0
V/G]0080PZgP02L0MJ7I076Te`1XXM80E8o40529`P1LT//0JJ3C07N_f@1o]Mh0X^3m0<[oo`3Nool0
kooo0??oo`3gooL0oooc0?oojP3oomL0mo750>oZ^03Xhj`0i^6Z0>GQZ`3VhZh0jn2f0>kYaP3^k]80
l?SI0??ogP3don00m_WI0?oofP3ooml0oooK0?oke@3ok/d0h/fA0=O2P@3KdY800P3GdY<00`3?d900
]/F002I4000@000000`0oooo000:0?oooiH0000001h0:P0003l0>@1:7Th0Lef@0000000]0000C@00
0:D0003=ool0000003D0002@0000YP000;`0003=[k/0ZI6a0964]@34bnd0coGo0=Woo`3Tool0f_oo
0<Woo`2hmO40`ogZ0<coj@3Von<0oooP0?ooh@3ooo030?ooo`0Z0>Ooo`3Good0eoom0<7dj02_oN40
T=K?0:?Rf`2ZinX0Z^KV0:CSh02Th]P0S/VV08o8W`2BaYT0SL>D09G8V@2Ldjh0X=:X0:G?VP2D^GT0
Y/B20;3<RP2[aGl0Z<F30;G@T02haW`0_<1`0=7MV`3IhJ00f^6P0=STYP3Hijd0d^J]0=_UY`3Shj80
i^N[0?7/]03ck;D0j^6R0=gFSP3Ugid0k>JZ0P3^hjD02@3_gj00kMfK0>kIV03Wc8H0fk1V0<bIB@2c
OBD0PWi>0=WL_@030000000K0<_^j@1:GP00L:Ml0035Y@2McJl0T[n`0>Kcc`3Yg:L0/LnK0:Qc002=
C@0005VW06:Mb@3<n?@0fO7<0>38V`3Fb:P0^lk205nSP@31eY/0c^:Z0;KEV`2cfjh0LZb204fAJ`3R
g>@0Y7MY0080onoU00<0oooo0000002IFVP00P0000008P3Omkd0X7hV0<_id`2K^gT0PJmd06R7>@1E
0580W6Z70>BV[P3od/<0k;^Y0=:LN@2eMD80V4`T0:EL=02_JD40Z64g0:9I;@2QFB/0X5TX0;9]?`2i
Md`0`X5K0<F5I038RFd0aXI`0;QfJP2cLfl0_X5k0=6MW03P/:h0l<C50?oNd`3om=`20?omg00W0?oo
gP3oon00oooP0?kohP3aomh0io_G0=kge03Dl]40eOCG0=;be@3?l]H0fOkR0=[oj`3Too80hooi0=ko
o`3Fool0ao7g0;OUk`2Pe>D0QK?O092giP2Ra_00]=Ok0=goo`3Oonl0foGA0;^K_@36d>/0ango0;[D
n@2<VmL0?52O08J[d030e=`0WI^i02Y=W01HQ/H0P:kO0080RKKU02L0Sk[W08jmi`2A`>P0NJKJ06BB
c`1QU<h0HYg>06VWd@1VY=00JJGA0976i02Xinh0_OSe0<Sjm@3BooT0j_od0?ool`3mon@0l_g>0>k/
_@3`jkP0k=VT0>kMZ`3]fJP0km6W0>o6XP3_a:D0mlfe0?WA_@3ke/@0oo_C0?ooi@3oon<0oooh0?oo
l`3ool40kMfZ0=[2Q03?^W@00P3=`gh00`3;bXH0Rj9J0000000@000000`0oooo000:0?oooiD00000
00P0;0000540001H<600K45W07eVN@1B0000G`0007D00080000001T0Dam7071?NP2=P:h0[00008h0
003W0000fjjl0<2jfP3=j?L0fOoo0>?oo`3Bool0^_oj0;C`i`38onl0g?of0?SomP3ooo80ooo^0?oo
j@3oon@0ooof0?oooP3oood0j_ol0080cOo_02L0ZnGF0:3Lb`2djMD0[nWP0:KUiP2Qh^L0YNCQ09KD
_`28ajH0R/RV08S1U`2?`Hl0XM:U0:SFY`2_fJT0W<:60:C4Q02/b8@0[LR409VhLP2dbhP0bMZJ0<[>
Q@32aWX0en:R0=[SY03FgY`0dMnP0=[VZ@3HjK40h>V]0>KVY`3Xi:@0l>V_0?K/]@3XgYd0hMN?0>;F
S`3/iZT00P3ci:T02@3`i:L0kN:T0>c=S03/bh/0jKmo0=ZYH@31TC/0e][S0=gVa@020000000L04VG
001JT`00Ji00001:NP00[Z0007V504FG/02`h]L0X=S807jfTP24CP00[h0008mT000mOl40XMGU0=;e
f02/^iX0`>3805NDI`2A^XD0en:U0;S@T035hJ`0VL>B0000002=]M<0a^C_0=3oo`80k?oo00<0c9nL
0000Q00000000P000000203LiZ/0a:d00:1m002H/6L0JXm70000002N09L0cJNo0P3oi^H0603@X[/0
Yh2C0:IUE02ICC00Sd0K08Tj5`2>@1/0V4`S09mE:P2NEBP0Xe/_0:]U>02cKTD0^WMB0;YfF030OfL0
aHIb0<R:M`3DW8l0iKFX0?C9_@3oeLX0on_D0?olg080oooN0P3ooml09@3eom<0j_kD0>3ge03El/l0
bng;0:oMa02jiLl0_>SC0;GTc`2YgM40XMSE09_Fd`2Ygn00[>3S0:WNg@2Zg]h0XmON08fkg@1dWmL0
P:KM096diP2cd_X0c>ca0>Ooj@3Mmll0002`0<SQo@3Eool0^mWb08FIeP1AKKL0Ki;=09g4i@24X]D0
KiGB05f>bP1dYmP00P1l/]d09`2:^n<0U/7[09Joj`23Z=l0MIoH06jNeP1_Z=D0MK3H06fYe01RX<h0
L:oC07blf02Fc^80ZMc/0;O/lP3<lo@0jooi0?KokP3]omL0i>o40>Cdb`3gm/D0n?330?WZ^P3ffK80
mL^[0>k2W03Q]Y<0i[nD0>O?WP3doll0oooS0?oolP3oool0ooog0?oog`3mnlX0j^2]0=76Q0020<2c
J@030;2dJ01;KR80000001000000303oool000X0ooooU@0000000`1K;UP0HSYV04lSDP0200000003
06h0001a000000000080000000@0PUn609j>]`2d/mX0a`000P3o00004`3icM40bmSU0=Koo`3Rool0
eooo0;Kik@2bk><0`_Wd0=3oo`3Boo`0mOoo0?ooo`3oooh0oooc0?ookP3oonL0iooY0=3oj02om^80
0P2cj]L09`2kkMP0b??H0<Obf02WiN40X^?R09cOh02=dLH0R<V^08c;[P2>bjT0R;V20:KEY`2fhKL0
_nNl0:C>V02Uc980[Lf?0;;>S@2[aX80[l=i0;o>QP3Cgih0`<n90<;?R@3Hi:D0fnJX0=SPWP3CgY`0
g>FV0>;/]P3Yk;80j^R[0>[WZ@3aj[40m>be0>_TY@3VgY/0h=J>0>_PX0020?KPZP060?CRZ`3^ij/0
jKek0>RiN@3Y^7X0hK9_0P0000000`000:<0`<oX0?ool@040000000G08S1[P39m^d0[>?X08c?i01h
`<D0T/:L09MR001Z;P00VGX000000016RkD0Okbl07F]V@1;Tg@0KIYM0870Y02Ib9`0]m>H0<cW/`2o
fJ40000008S2f@002@h00`0000009`3QjmD0002T0000V@3Ab=P0gMG>0>o/b03Zi000gMH0086HBP3o
onh000000<f/c@3ohO80ooSo0?olo`3gd>P0RVZJ0:Q^LP3=UHD0e9in0;YlC`31PeD0aXMJ0:QR<P2Z
ICH0Z6<c0:MS;`2cLSl0_Ge@0<J7HP3>TW@0eIb40=VRS`3V]ZD0mLVc0?oD_P3oh/X0oo3B0?oofP02
0?oogP0<0?oog`3oomX0f>Zj0<[Y_`2cg;T0W=2c08o9/@2CcK`0VM?309gEaP2BcKl0HjJ=0P000000
0`00M8`0K[;2000000020000000D0000B0000=80NIcG08>TgP2bd?`0bnOf0>3li@3MmLh0002J0;_F
m`34j_P0]mc]07fJdP1VQLP0KY?A08Vgh`2=^n80JjG@05jIbP1PVL`205jLb@0Q06bRdP27/N<0TkOY
09Bgj@29[n<0OJkM07>aeP1e/=P0MjoK07F_f@1h/mT0N;KI07Zif02:`n80Wm?[0:7Fj02]lMl0XN7D
0;;La@2nim80e_[M0??oh@3]n]<0oooD0?oocP3oomP0ooo:0>oS_03`k;l0i_;20>cjb03mom/0oooj
0080oooo00@0ooo/0?7od`3Rjk<0dMJH0P2o`W/00`2?WTh000000000000@000000`0oooo000:0?oo
oi@0000000<0001>06a2J`1A9U@01P0000006`1cCWT0SVnF0:fJ^`35`N40d=;_0>80003o0000ooo]
0?oki03Amo40f_oo0<Gol02_j]L0[NOH0;Saj031n?L0`OOo0<;lo@3Xool0oooo0?ooh@3bonL0h?o/
0<omg@2cjmL0^>cF0;o`e`020;W]f00W0<7af`3<mM`0/nO=0:7PeP2Jg=@0TmSA08O=_02=c[H0TLj^
09?=Y`2VdYl0]]j_0;kX_`2[ejT0Ym:O0;?JY@2bdYD0]/j:0;C;QP2f`gL0`]>=0<;ET@2ecHX0`=FE
0=KWZ`3IiZT0f^6P0=oSXP3Vj:d0k?2k0>o]]@3^jJd0k^^`0?7]]P3_kKH0jNNY0>3KUP3Rg9P0l^N/
0080nMf[00/0nm^[0?[O[03ge9d0l<>80>ZiO@3V]GP0o/nH06iIA00006@0YKk/0<T0eP0300000005
0;g1^03Ch;L0d_7X0<?do`2Wh_H00P000000403L`000O3T005dH001l0000Oi7@001HO`00G6T007A;
07Nl/01o`[X0W]Fe0<;T/`35h:T0000003I:I02Pg=d200000080n_oo00h0iooo0=Coo`000<`0003V
0?ooj@3oom@0h>^i0<cHW01?Mbl0on_30000003Jco80onSk00000080oooo01L0TffD0<BN/@3mi/X0
onZn0?[AX03Y_8`0hK270=:MKP38SeX0bYEM0=BQJ`3:Te`0cYES0=2EJ03?TV`0dYMg0>FcU@3gcK80
omBj0?oL``3oi/X0ono@0?oke0020?ooeP0=0?Wgb`3@jK`0/mRZ08_4YP23_j@0RlJ/09SA^`2Id/@0
VmC;0:;Ib`2FcKD0Q[fI07>=00020000000308n/c@000000oook0080000001<00027082Ge@2<Z^40
]=7i0<k_o@3LmnD0hOKA0=k]_`000?<0]mkf0;GGm@24XM/0KHg>07>KeP2=_><0Z=3R0:RKNP1dX]D0
KIgD0080LIWD00P0MiCD03aZ/@2:/N@0V;[[09:jj02@aNH0QKkP07fgg080MjkJ01d0NkGK082jgP28
`>80S/OT08_8g`27b=H0O/;707Jm^`1k`L40Tm;C0;CVg`3Amn<0kOoX0?ooj`3oonh0ooo/0?oohP3j
omX0joG60>W``@3fnld0oooK0?ook`3oooh0ooo`0?WoiP3Xom80e^Ne0<3FVP020;;4P00307RHCP00
0000000001000000303oool000X0ooooTP0000004@0O02<0000l060bF@1O<5T0001J0000002nVZP0
fl380000001S=Uh0NeMl09=gV`2^VKT0e<oX0>7Qm`3]lOl0o@0000<0oooo0180eOoa0=7ki03=m]`0
a?;O0;W^h`2ck>X0/n_c0;;Yo02gl_l0dooo0<[oo`2kk]00YN;D08O?e@1]_]<0]n[G0<Wdf034l]T2
0<3`fP0W0<KcfP2eil/0Xmc009[Ia02Hf<D0VM[<08W@`P2Fe;P0VM>a0:OEYP2[f:X0/n2h0:CDZ@2Q
d:40[mVY0;?HXP2feYX0^Lj:0;g;PP2aa7/0_m>@0;??S`2cc8X0a=bP0=CX[`3IjK00f^>S0=[MV03X
j:d0lo:n0?3]]@3/j:X0kN^a0>g_^03Zk[L0inV]0=gMV03]hjH0nN>^0080o=bZ00H0oM^Y0?oMZ`3o
hK80nnBa0?GY/@3^diP3000000080000i`00000000000000003Nj;00i^oC055a^P3W_gh20000000?
0000/P3Ej@00e]d008^3002RJP00V@000;:IVP2QYKD0000l0000MP1T/<P0QL;20:cI^`34iKD0c^Re
00<000000140Fhc20000S00007l0001o00D[RP000;80003I0?ool@3ooo<0lOoD0<?P[@2</G00h`3<
0000002UZND0blC[0>c@j0030000000G0>6if03oooP0oooo0?oojP3oold0ooO30?oQ]`3cdZP0jlFE
0>2iP@3N]gh0g:mi0=NSL@3EWfl0gZeo0>JgSP3abZ@0nmVf0?oO_P3oi/P0ong=0?obd03oll`00P3a
m<d03@39i;T0Ul>A06j]T026`j`0Vm6g0:_L``2dhl/0]>C?0;3RdP2Zfl@0X]6_00000036[8L00P00
00000`2SFUP0UWRW08ioY@020000000C0:6]hP28WMT0VK7V0;;Am@3@mol0f_[a0>?kg03Ol<D006ZQ
0:CDk@2L_n`0RZ_Q06f?c`1mY]/0T/?X0;kWo`2acO40SJSQ08:Tg@0207jQf`0W07bJf01IP<<0NZ3K
09Ffj@2Qanl0[]_o09S8k02<_^D0Q;GR08FfhP22^>00QK_Q08k4i@2@b^<0VmGP09;AdP2BdL/0U=;@
093?f02HeMh0V]?P0;o/j03Poo00i?o^0?oon`3ooo00nooR0?Goe@3Xl<00l_?70?oicP3oomT0oooT
0?ooj`3lonH0k_oO0=gfd@31h:l0Y/bC0080PjQV4`00000<0?ooo`002P3ooon>0000000C00<00000
0000000002X09P0001@0D21;05TWC@1K0000000002/0003B[[D0000005`]E`29I8H0XXJT0;BQ_`39
`=`0gN7j0>oio`050?ooo`0B0?Coo`3Jon`0eOSG0=okeP3DmmP0_o7`0<3eo`2ik_l0Z>3b09GDf029
c/@0FJbd06jc`01kfM/0WnoW0=;hf@3=m]X0b?CJ0P2okmH09`2]hlT0WmZo09gH^`2TgL00/NO@0:gU
c02Vgl<0WmVk0:CH/@2Yfk<0Z=bh0:7E[@2CaiX0Z]R/0;?L[02nhJl0_]RL0;_<Q02ja7H0[LF00:o>
T02hdY<0am^L0=OZ/`3IjJl0g^be0=WTYP3IfYD0i^be0?7fa@3^kK<0j^JW0>cY[@3/k;80j>jf0>G[
/@3UiZP0mNVa0?OX/@020?SQZ@0Q0?OT[`3ejk/0n^fo0?K__@3akkT0k^R]0=CHU`2ebX@0Vh`]002J
aP00/<40YMBh0;7B/P3>k=00h<^E0=^]J@3FXf4000000000J0000<D0003N0;kT_`2>W@00YVh00:A[
000002h0000G0000NP0067L0002l08o<e`2Zf]00`nO900<0000000<0^>750033`00W000010000000
2`3ooo40oooo0?Goe037ikL0V/NB04f1@`2=0;P000000;o=o`3:a_40_jW:00<00000103oool04`3o
on/0oooT0?oog@3oomP0ooO<0?3JY@3YbYD0jlVF0>k?WP3]cYl0j/ZL0?;DZ@3igkD0n^>j0?o[a03o
l/h0ooK@0?ojd@3>gkP00P2YcZ/02P2Iail0O;ZO08o:]`2Qel<0/n;;0<?[d@3:kmH0co;I0<__e036
k<`2000000050<>eXP3=^I`0[g18045B@P2ob_T00P0000002@2nbOl0[l3`08fWg`2J]nT0/m3i0<kb
o`3Jo_H0goWK0=_^`P020000000908:]g`23ZMl0MI_F082/gP2Ea>/0[MOk09JkjP29ZN40QJKO0080
Q:GO02L0P9oK07fKf01lW=X0VKK[0:o;m`33iOl0bNoo0:kFoP2K`nl0U/3[0970j02=`ND0V/kZ09[B
iP2Of>80XM_M0:?Mf02Rg=P0WMSO09KAh@2=bN00WLoX0<O_m@3;n_D0n?oo0?_om@3jon00l_oA0>kf
b@3em/`0mO[A0?Wne03oom`0l?oI0=gheP3@lLd0_>Bk0:GAW`2>_hP05@00000<0?ooo`002P3ooon>
0000000701H04`0U02409@0Q02007P0f03D0Dai20000000206H000<0000001h0PUb20;2C[P2lZLD0
_[?E0<_=n@3Ul_l0nOoo0?ooo`3iool0m?oo0?Ooo`3_ool0h?oe0=3ee03NomL0looT0>Kkc`2AbZH0
fOoo0<goo`2ck>40Rlbg0;72U`2e^[80]^OD0;ComP3Hool0bO?E0<Gae030km@20:gSb@0W0:[Qb@2d
i/P0]nK30;SV``2gj/h0[^C80:GM_`2Of;L0WMJe097?/@2Jdk80UlbR0;;JZP2oiKX0bNk90<_Y^P39
gJ40^l^40:^oM02dbhH0_m>?0<OIUP3Hijd0h>bc0=oVY`3Mj:`0f>BV0=SSYP3Sl;`0kOO70>gb_@3Y
iZP0j^JW0>_X[03Yj:`0i^^`0>g//`3fk[P0m_?00080m>Ve02@0kNnn0>cic03cn<`0lOW90>[`_03K
gZ00_<j90000002DQRP0dKES0=2jJ@000000XmSE0;O9]@2mV8@0iLF50=:IF@010@4000000000kP2Q
f^00/>740:ec802PI0l0W6800;9k0028HX`0PX?5000MN`0kK;D0W]SZ0<3/i03?lM<0Pj<00<;FU`2;
EW0209cKg00B09SEeP00000000000>?4a03oonT0oooo0?ooi@39j[D0WlR@0=OV001UKQd0MZK;0;oQ
]`3Ri[l0000009MiYP2RSKL0eMoW1@3oool0303oooH0ooo]0?ooiP3oon40oooJ0??P[03^fZ@0k=RR
0>oO[03bhk<0m^Nj0?KZ`080mNk400D0o_C;0>ogd@3HlLh0_mfg0974X00202E[BP0:08S2Y@2^g/L0
^^OD0;WWe@3:lM`0bnoE0=3be`3Gm]T0g_SI0>Wie@80000001/0_=gY0<_`m@3U`Id0a[?R0:R5/`2]
S[T0_<3j0<CFo`2dc_T0UKKW09jmkP2edod0bnko0=Son03Im]T0f>k30=KW]P000000HYG<07VXf`1j
Z=/0OJcM08Zni027^><0Q;7Q08>Yg`23Y=h00P24Y=h09`1oW=T0NiOF07bIf02E[^L0^<gl0<GSo`3f
ool0fOGo0;cBo`2cc_h0/];k0;?LnP2^h?80ZMcZ0:oSiP2WgmX0Z>7H0:KOf@2Memd0TlkQ08C0g01i
]MP0T;_W0;[[m`3Xool0mOoc0?Goh@3comP0l__A0?7ic`3`o=@0looH0>Oke@3FmM80`^W50;3N]@2Q
djL0Sl>B02i7000E000000`0oooo000:0?ooohd0000000@09`0K01@0500_02`0;`0/0`000000901P
;UD0KCaR06PfFP000000HCa/07iPS02RSk80_:o?0;nceP31_NH0b]Go0>Cko`3oool0m_oo0>Ooo`3L
ool0dooo0=3ol@3AoM/0l?oc0?ooo`3oonX0oooD0?oolP3aoo/0h?og0;oid03Dh:<0m]F^0?oYa`3n
onT0o?oo0?Coo`31km40_>c@0;SWa080]nO802L0`>g@0<S`cP38kLD0`n_30;OYb`2]h/@0XmZj0:3I
^02LekT0W=Jf0:KJ]P2mh;00c^Zj0=7`a`3Ell/0fO730<gQY`2bbH@0WKUc0;cAS031e900d]jM0>K`
^P3XkK@0i>JW0=cUY`3GiJT0gNN/0>G_^`3_mlH0l__=0>c`^03Uhj@0j>NY0>W//P3]k[H0k^bd0?3a
_@3dn//00P3]k[/03P3VmLD0j_kB0>[oe@3Sn<P0fnnk0<?BS`2abhP0V:AD09fC=`3D/f40f[Q[0>?3
N`000000OiRo0P1W]ML05`1ECbX0hl290?oV]@28aN@0RLg>0:KC[02bPBX0ZW<N09AJ002dPE00bkGK
0;6mo00V>I40?fVh08joh02ei]/0angA0;W8Q02ENJL0`jkN0>:le01IOGh0628R00<000000100n_gl
0?oomP3Gll80VLB?03Ye?P2UfLP0Nh0_0000002O^<h0h]C20000002i/>40cLoo0?3oo`3oool0mOoo
103bool04P3hooX0oooa0?ooj@3oon40ooo?0??]^@3WhJ/0j^Vf0>k[_03^kL00i^g30>KbbP3Zm</0
g_370<GXa@2CaZD0:7AP06RYS`80TLV^02L0[Mk60<3[f039lN80c_?S0=7eh@3AlmP0e_KI0=cig@3O
nMX0kOcG0?Wgc03Sbi@0_^gk0000001R06l0_P3o0=CLo`3Hg?l0cN?o0<3Po`2Sdnl0TL7U086]gP2L
aNh0]=ka0<W_k03Gmn80gOGA0=O[_03=fJ00=g>_05B=`P1VW/l0KZGD07:ZeP1bZMH0Kj;E06jKe01a
Um@00P1kVML01P1kUmH0N9?C07bEe@2:X]h0Zl;d0;oKo`80oooo01l0en?o0=?^o`3=l_l0cOoo0<Sm
nP32l_40^ncV0:kTe`2^i=H0Z>3J0:SNi02Rf>P0SlGR07>WeP1o[=h0[=Cd0=Son03_onh0kOoT0>_o
f`3Vn=<0hOK@0=khd`3<klh0`N_;0;KS`@2Yf[D0W=6Y09oAY025]GX0=Sd001D00000303oool000X0
ooooR`0000000`0`0000;00E01X03`040000000V05@M@@1K;UP0L4E/0715KP1Z@Vd0JTUi07e[W@2N
U/00^kcQ0;jmi@31_nX0`lOg0<gPo`3Mo_l0hOoo0>Goo`3Gool0e?oo0=7on`3DonH0looo0?ooo`3o
oo`0oooX0?ooe@3oomT0oooP0?7oi`3VolX0eNVi0>kNa03dmn`0m_oo0?Woo`3Joo00^N[<0;_Ya@2j
i/020<[ac`0W0=?ge@3;lL`0`^[20;WU_P2ah/00Y=Vd0:3G/`2Wg/00]NG50;gYaP3@k/00dN^i0=C_
`@3GllP0f_700=K]^`2og:@0X<1n0;;9P`30dhh0`mF@0=gTYP3ZlK/0knjf0>WXZP3Oi:D0g=bF0>?U
Y`3[k[H0lO>n0??ia`3]m<00h>6P0>;VZ03Xk;40h>V]0>7[/@3[m<40loW90080i_?102L0i_K50>cj
b`3]omT0i?[;0<gTZ`2cc8T0/Lb;09nSB`2f/5/0d[ES0=:_GP3F/F80i/Io02Yj/`2>i]d0/oo`0<?^
eP3Smll0oooO0?ood01h`;T0LkJn0:cNi`2gPbl0/gh009ES003dkP00b]So05M[^P1@OL@0PL;O07Nj
/P2e/f@000000;2<Y03O`M/0ooOo0000K01QAX800P1/FiP05P2GZ=d0foCk0>;of@2NbYX0FI1G076R
L`2/_Wh0M7PW0000001aXll000000:>Wg`3Agol0e^_o0=Geo`3Kool0hOoo0>Woo`3[ool0l_oo0?Ko
o`3iool20?ooo`0?0?oolP3lomT0kO730>?X]P3Qj[T0i^k00=_]`@3CkLD0cng;0<7Wa@00bJX0E9If
06>WU@26`JX0WM>l0080/^?=02L0]nKC0<7/gP37l>80bo;S0=;giP3Gn^H0g_kS0>7ng`3Qn]/0l_oJ
0?oof`3okL80on[00?olh`3oo_l0f_So0<oXo`3?i_l0cN_o0<__o`000000L5^L0000001[W/h0ZmKb
0;kVkP3>mNL0e?;D0=K]`@38g:H0a]FI001HU@0`LjP0AXVh05FE`@1c[=H0MJWH05V=a`1HQ/D00P1T
R<X09P1bSm00Li7B07JCd`1mV]P0W[S]0<?Jo`3`ool0oooo0>Obo`3Rool0jOoo0>Koo`3Pool0e_oc
0<[ch`30k]/0_NcM0;g[iP2lj?40_=kh0;S@o02PZ^H0W;3V0:?2l03=no80foob0=coj03In=L0d_?@
0<W^c02hi/L0Z]k00:KJ^02Ldk00WM>]0:[J/02A`i00Ghe:5P00000<0?ooo`002P3ooon:00000005
03X0000l02008`0=02H05`0000000P0d5U805@116DX0ICUR079;M@1fDgl0MUN507QLR`22LZ@0U9?6
0:^/f`32aNl0a=Wo0<?>o`36dOl0e?_o0=Koo`3Gool0fOoo0=Woo@3Foo<0e_o[0?Coo`020?ooo`0@
0?con@3oomX0ooo;0?ooeP3jomd0kooJ0>[odP3Fl]00hnWL0=_oo`3Nool0h_on0;_/d034kl`0a^k8
0;gX``80c??B02L0ao3@0<3[b02bhKT0[N2k0:OI/02VfK<0/NC40<7]c03AmM80eoG=0=[a`P3El<<0
f?C:0=O^^`3Dj[@0aN>`0:oBV02T`7`0aMJA0<[FT03DgIT0i>R[0>cb_03_k[D0jNRZ0>GQW`3VfYD0
iMfJ0?3]/`3em/<0l_G20>OY[@3PhZ<0f^2N0>g//`3Rij`0iNjg0>kd`@3cmL800P3^ll009`3Wl[h0
k?K40>ooe03Pm/@0b=^L0<G@R@2o`700`KaZ0=72L`3@^VT0fLAh0>3:PP3Yb8<0hKM`001RT000JI@0
J[_=09WUf@000=H0`Lb`04AZK`14Hf40W`0005<0002XZ9/0]8800;bb002ffOl0HhS>05n1]01gX9l0
S[V80=K6PP2bP`00eJH0002CG@000000002<09j7/@020:2A_`090;_6j@3>m?<0V<^T05bFHP1j/900
]<nJ0:RiN@1`LQl0FCP00080000000/0Vk7L0<_Zo`3Bm_l0c_Go0=Cno`3Jool0h?oo0>Goo`3bool0
n?oo0?_oo`020?ooo`0?0?gol`3_omX0fn^m0=KX^03Hjk`0^=Vc09c9Y@29`J40Bi5n002YU02@bkX0
VM;20:OKa`2ehl`0`^cE0080b?3J02L0a>kN0<Sbh`3BnNP0coKW0=GjjP3Non`0jOo[0?3ojP3oooL0
ooon0?ookP3oonL0oooX0?oooP3dool0doWo0<7Wo`2Sd^d0Ul[W09O<e00U30d004^>00000014Lk40
T[kS0:WEjP31j]l0cNo?0<SY`P33hK40amfV0000GP0008d0002X001ARP1MUlP0J9cA06>FcP16N;T0
0P0lJ[002P1KOl@0IXS;07:Cd`1hV]L0T;3V09o0l02ec_`0f^ko0>Oco`3Uo?l20??oo`0I0>coo`3Q
onD0f__O0=Ggg@3Cn^D0eOok0=Koo`3BkOl0`l[o0;O5o@2Q^N`0Zm7`0;WWlP35l?00ao7R0;kZc@2l
iKh0^NK40:oP_@2Oe[<0WMB`09_B[`2XfkL0V<ZL06:IH@0G000000`0oooo000:0?ooohT0000000H0
<P0S02P05`0]01T0:@0J03009000000201L:D`0D05LgJ`1]BgX0L5:207YSU@20KJ00RGJU09R=^P2P
W<X0[:cM0<?7mP3?gol0coSo0=?oo`3Eool0f?oo0=Woo`3Lool0goog0=cok@3eool30?ooo`0@0?Ob
l`3ehmP0ooo;0?oodP3comD0j_g>0>7hc@3EnN<0cO_l0<[oo`39o_`0`?7K0<;_d03<l/h0ank80<G]
b080_>_<02L0^>S80:oQ_P2WfkH0[=fd0:oM]02ljLP0b?3>0=Kgd`3NnM40hOO;0>3eb03Jm/h0fO;4
0=K/^036i:h0]]ZT0:_=T02md8d0dMZF0=GIT@3Ngi/0inJX0>oc_@3]kkH0j^^a0>oTYP3`g9X0j=B=
0>kRXP3el[d0n?O60?Ca_P3Wij`0g]jL0?;/]03[i:P0jnBY0?3a_@3flkl00P3]l;/09`3WkkT0j_S6
0>koe`3Yml<0e=nQ0=7FS`3=a7@0`kQU0=W8NP2o_6l0blb60>GRY`3dhj/0k/j?0>6eL03O[VT0hJm]
0000HP000:H0C5bC04]4SP000000/>;40:SH/@1dYI00UImQ08n2:P1>Q/H0;Ub/08JWg@2J^kD0Y;Uh
0<nXJ03D[X/0Zfa@0000000004P0002/0=G3h0020<O2l`0W0<[[g02CbJD0EY=Q07Vbe@2_f<P0`]RS
09j`KP21PBl0000009[?i`2CYMP000000=7mo`2Hd>/0WM;Y0:oRk@2ej>T0_^o_0<[ho@3Iool0iooo
0?;oo`3hool0looo0>kol@3Ko]<0`^2b0;?GZ`2Rd:X0JZN:04J;MP21^id0V/nd0:[Ma@2`hL`0]>GD
0;kZf@3;l]h0eo[T0080gooU01<0i?oX0>Ook03Tond0f_o]0>7ok`3Zoo00lOo`0?GokP3oooH0o_ol
0?OooP3mooL0oooa0?Gom`3Lool0coOo0;SUlP2<am@0I8mI00@000000100:d^B04in^@28^n00YmGD
0;GRaP2ghKh0_>2f0<GN[P2oe9X0001R0000S000FX`005VK05bAbP1QUL`0EhS50P0gIjh09015L[P0
Dgg106>;b`1]UM<0NJ7J08J_h`2L`>l0[lgi0;kHo`3=hol0i?oo0>_oo`3Uonl0hOoQ0=kkg03KnMT0
gooV0=Sol03;lol0^m[o0:VgjP2Y_^h0YLG^0:gJl02bh_00`^k[0<WbgP2nj/`0/]jc0;;O^02Vf;00
W=6Z09cD/P2HdK40RlNV001S=1P00000303oool000X0ooooR@0000001P0b02<0:00G02d06@0Y01X0
<00T000000805`YC01@0EcM[06e;NP1`DX80NV>E081]X029MZD0V8fj0:2LbP2/[=d0`lOf0<oOo`3?
n?l0dooo0=Goo`3Hool0fOoo0=coo`3OooL0g?o]0?Goo`<0oooo0100mo;c0?GSf03ool/0oooB0??o
e@3ZoLh0hOS=0=Gih`3=no`0b_oo0<Wno030lM/0`^o@0<cbcP37k/P0aNg80P2ljl`09`2hj<P0[n6n
0:OK]P2/gK@0[mfd0;cYb038l<h0e_OC0=kid@3Qml/0h?G80=[fcP3Il/@0e^bh0<KT[P2ffZ@0Zlf@
0;g@S@3AfYH0eMVA0=kOV`3WiZP0ko>m0>g_]P3Zjk40knBV0?3LVP3Xe8d0k^:R0?Gb_@3hmlH0m?6n
0>OW[03NgY`0l^bd0>_TZ03[i:T0l?6m0?Kc_`020>g`^`0W0>O_^@3Zn<H0k_oG0>Wg``3Dgj40dMJ?
0<g4M033^6D0fLQj0;nlK`3;c8H0iN:W0?CSZ`3^cXl0hKE`0=n^J@3Q[fd0001R0000YP1<G9<0BdB>
0000002`h/@0Z=Ra07BUT02EWf40Sh8Z04j6aP0^G:`0QZOM09Zk]@2T^GP0cjQX0=B^R`2[K5000000
0000B0000:`0eL?P0080al;c02L0b^_L09?9Y@1FTf40NK;E0:oHb032f:<0W[1^0861;`000000V/oW
09>Uf0000000dOgo09S@j`2Md^T0[n;]0;GXj@2nknl0b_Sm0=Woo`3Wool0l_oo0?Soo`3cool0k_oa
0=_nd`32h;80/mN[0:;@ZP1ZYhX0AX]f086kW@2Jck@0Z]g50;3Qc02diM@0_^[I0<_bgP3Gn^@00P3O
onD04`3TonP0ioo/0>Cok@3Jond0hOo_0>[ol03aoo00mOo^0?oomP3noo`0moon0?gom`3ooo40mOog
0=coo`3?mol0^>Gb08c7e01TSeT010000000400[Bi80CWji08Rkh02WeM@0]N;60;OQ_P2lh;H0aMj^
0;oDVP000680002<001JS000FI/0G97:066Ec01GR<D203MW[P0T04Eb^01COL40Hh_;06fEd`1iXMX0
QZoS09c0k`2_cOT0_]So0<gSo`3Tool0jooo0>Gok`3Qon40g__L0=_if@3OonH0f?o`0<_co`2kf_l0
ZKOZ0:VnkP2UaNh0[M[`0;;Rl032k^/0bO;N0;kZc02bg[<0/]nh0:KH/02LdJX0W=Bb09SA/@2;ajH0
06<d6000000<0?ooo`002P3ooon70000000800L0000Q01D0;00M03L09`0[01h09`0K03@0:`000002
02dQJ@0<05Q2O01^EHT0LEV=08=]W02=NZL0Wi2h0:^PaP2[Y/h0[:_F0<?6m03Kh_l0kooo0P3oool0
1@3gool0iOoo0>Coo`3TooT0mooj00@0oooo0100m_7n0?oogP3oomX0koo?0>CkcP3DllX0fOO@0<_g
j03<no00b_[]0<Ogi@36lm/0bo?B0<?]b@30j/D0]^K40P2]h/@09`2]h;l0[Mnj0:[K/@2agk@0a^g7
0=?ecP3Mn]<0iOgD0=_ebP3Bl<D0e_G@0=[gc`3Gl/@0d>Ze0;cP[02keiX0^M6B0=OPW`3Gg9L0fm^E
0>;MV03Zhj80kn^`0>gZ[`3/k;<0l^ni0?GVZ`3]gI`0im680>G@R03ik;P0n>bg0>WNW03Yg9X0lNFZ
0?7QY@3`fY/0l^nj0>o_^0020>G//`0W0>G`_03Xn/d0jooI0>Gc`03PiZP0emVB0<o4M03;^FH0_[e^
0;S1M`33eid0hNbm0?Kda@3ol;`0m=NL0>O0P03W^gX0iKYg0=neKP0SCJ00>EFO0;_U_`2cfj`0Zm6I
04EiC02`Ucd0MFT0001_000ID:40VKcd0;?6a02b]gh0c9]O0;UiF@2CCTX0001>0;V<YP3`e^d0e=Wo
0080bN_a02L0R[jA05jJJ@13PDh0Jj[>08>of02adk40SYiI08f;>P2DRST0Fb/00:_1l`38jod0f?oe
08c7d`2Zg^00U/oN08W6f02Le>40/N3g0;[Zn`3<ool0hooo0>Ooo`3Uoo<0a?7<0:kL^01h/8T0>8=^
05VGL028_Y/0XmFf0;7N`@2eh/H0_>S?0<C^fP38lN40cOKV0=[nk03Oon/00P3Xon`00`3fonh0o_o`
0?ook`020?ook`0R0?ool03loo00o_o`0?KolP3dooP0l?oh0>_om03Vonl0hOo_0=Woo03<mO00a>gN
0;GO`P2kd9P0ZP000000001mDX@0J5N;045:OP0hNJh0Gj2n07jo_`29akX0U/jh0:WJ_P2We:h0T[b;
04^4D000@X0006BD001>Q`00FIX0CXG005N9a@80>V^`02<09UJP04Ye^`1GPl@0HY3=06^Hd`1nZ]h0
W/G_09W5k@2Lao80Z<ck0<7]nP3LooT0g_o]0=gmg`3InMX0eOGE0;k`f@2nkNd0]Mga0:S8l`2]b_<0
[m3f0:gGlP2/g^l0Z]g/0;SWiP36lMd0^^O60;7N]@2Yf:d0VljQ0939XP1m_Il009Yg00UA000I0000
00`0oooo000:0?ooohL0000000P09P0=02`05`0g02@0;P0L01/03@1<03@0=P0/00000080HDAi00`0
KeB607EGQ`22II40SG>L09=kY@2[V[`0]j[<0;Rae02g]MX0`/C/0>;Wo`3jool30?ooo`040?oom`3o
onX0ooob0?ooo@D0oooo00l0nooO0>3oc@3Kn<l0cO7;0<kab`3?m=D0coSN0=3ki@3Con`0cOSP0<cd
eP33k/h0_>W50;CUa02ci<000P2ai<D09`2hi/@0[n2j0:_L/`2nj<00aO3B0=Wke`3RomT0d_?:0<CY
_@37klh0cO?D0=7cd03DlLD0aNB^0<;MXP35eY<0c]VG0=cSXP3Jg9L0h=jI0>SQW@3^hj80k>BU0>WV
Z03^k;<0m?6l0?Oa_@3biJT0jmJ@0>OAR@3ihZX0mn6Y0>[FTP3UcH@0k=NF0?7SYP3ZgId0lnff0>KZ
/0020=oY[`0W0>;c`P3Un]00j?oK0>Gc`@3Pij/0fMZD0=?:O038_6X0WjmP09:fM@36jlD0fo?=0>ol
e`3oom@0ooW30?WX/P3bfj40j/Z90>W6P`3AZE/0001n05^VWP1DW8/0cj]K0;F@>02NRB`0JF`00014
V00MCZ80;Uf^08:XhP2jXJ@0gjR:0=jSQ03EV7l0kl2i0?oWm03oo_l0bNOo0080VLbc00h0DHaG0;7Q
l@2NdNT0P;CN07nhfP2Qc;P0W:EM08j>?P2GQSD000200000o`3Qool0oooe0<gbf`80000001L0Q<?D
08W2h`2BaNP0WL[_0;Wbo`3Fool0d?cZ0:oQ`@28_i`0BXeZ04V=KP1`Yg`0W<VM0:cF[P2oilL0`n[=
0<C[cP35jld0c?;L0=;hj@3Go>l0g?oa0>Col@020?;ol`0O0?oom`3oooH0oooa0?ool03oonX0ooo]
0?ook`3monh0lOo^0?Cok`3YooD0i_o^0>3oj`3Lon/0eO_Y0<gdi03=l]l0goWK0=oUc@2bY[L0Zj7<
09JO_@2I_=40TLcJ05NO[@0[NhT06F]e02=dO00nS9@0D9RC07BeW@0400000004001@HP00;R4007Ba
04El^@80?G6b0240:5RR03iZ/@1GPlD0IY?@06bGd`1oZ=d0Ul7/09C1j`2A`>T0UlC[0:KLjP2ain@0
]^OI0;KVdP2hj=80[>3<09[FcP2Gcmh0SL7O08bmhP2Gb><0YMG]09KAg`2Dc^80Um;R0:7Ih02diMH0
/^:n0:KG[`2Ocil0T<JH07bkU00jO4h06`00000<0?ooo`002P3ooon50000000:0200000b01<0;`0A
03h0900f01h0:00A04`0<`1<03P0:P0K03/00080KdUd00`0NEJ008AQR02>KI@0WH6S0:^B/P2eX/00
^Zc90<Rog`3@c>h0h>3o0>[]o`3ioOl30?ooo`030?oom03oooP0oooo00D0oooo0100jOoo0=3ffP30
jL80a>k<0<;]b`3=m<l0eogE0=coh03OonP0f?oP0=7if@36l=00^^W70;CT`02bh[`0/>;00P2aiLL0
9`2]hL80Ymbi0;OT_@2ojl/0ao?J0>3oh03Amm40^NFn0;GU`P2mkM<0`o7I0<O_d032ikd0`n>_0<oS
Z@3Ggih0gmnK0>7UY03RhZ40j>:O0>cTX`3`iJH0k>:Q0>[TY03bj:d0mN^c0?S^^@3fjk@0km^H0>kK
VP3ghZP0m]JK0>oEU@3XfI<0h=6=0?3UY`3RhJ80hnN/0=[UY`020=GUZP0W0=GZ]@3Mm/T0i?oK0>Kd
a03Pk;@0fN6R0<W9O02f_6d0OImI072aT02^hmP0e?o/0>Sol`3kon80o_oA0?[e_`3fk[L0k]fO0>K>
RP3E^6/0a9a70=6[G03M_G80d[AT0<:QB`2BNa/0^9Ba0?ogh000?i@06TZQ05:0b02=TZ`0m?oW0?Ko
h`3[iL00n_?J0?ooo`38j_`0UL_00080C8]L02L0hO7P0:cNe@2Icml0O;?J08NhgP2Od[l0VkEh08^E
B@2EP30000240000o`3bool0oood0?ooi03bom`0[]>X0;_;V@1FV/80JjSC08Rni02Qdn`0ZmkR0:GK
b`1a[HP0?X1I06:QOP1e[XL0Vl^S0;GM]`2lgk80bNc:0<kae03:k/l0bo3G0=3fi@3CnN`0do[a0=?k
mP3Yool00P3kool20?ooo`0G0?oon@3oonh0oooW0?oohP3ooml0o?oN0?Goh`3donH0iOo_0>CoiP3K
oNH0fO_V0<gdh`36l=l0`^gK0<7/h036knP0`^Gm0:oGn02Cc=`0RlS=07g0^01CVh`03@0000008`00
HJ0006>P001SX00MCiT0=V6[059k`01URl`0KI;A07fSg02>]NH0UL3[0931i`2>a^80P/7D08K7b`2:
c<80PlJj07Zo/@1X/Z`0DZ6Z002K/000W[`00:G5002/cP1]//D0PL;E08W6gP2@c=l0U=;I09WDaP2O
e[H0V<bS07ffR@23^XX0`>?001`00000303oool000X0ooooP`000000300J0000=@0L02d04`0`00l0
>00E03T06P0X01L0AP0b04h0>`000000A@0006@00080NDea00`0Pef308APQ`2;JY40XXFV0;RP^P2l
Z<80`;3:0<ZofP3Nf?D0in?o0?;ao`3lool20?ooo`030?oooP3ooo`0oooo00D0oooo0140h?oo0<Ge
k@2hjLh0^>S:0;c^c`3AoML0hOoN0>Ooh`3YonD0h?oP0=OlfP36l<l0^NS70;7R_`2[g[T0XmVf0:KN
`@020:SPaP0W0:GM`@2bhkh0_^[50;g]eP38m^80_^kA0:oQ`02UfK<0Zmbf0;KWb`2nkm/0`ng=0<W[
_P3Ekkl0h_?20=kZ/03KhJ00h>JY0>KXZ@3YijT0knNZ0>oVY`3]hZ00kn:R0?CSYP3gijh0n>^e0?G^
^03bhjD0m>J[0?GX[P3`h:<0k]bK0>[LU`37e9H0f]nQ0=[TYP3Gij`0e>J]0080amfP02L0dnZf0=3`
aP3@m=<0h_G90=oa`03Ai:/0Zkec07nSH000T9800;o:08oBj@31n?h0gooo0??ol03nomh0noo=0?Kf
`@3_jJl0jn>U0>SRXP3</El0eKAV0=k1M`3C]FD0bZaH09^18`3oj>D0ooo_0?ooi@00;Gl005f/06B?
`03Fool0oooo0?Soo`3eonl0`_SG07nnY00oQV000P3Qm=809`3;kM4000000000UP1DV;T0L:S?09>n
bP2@[h00SYQ<07]L00000000003K0;[Qn`3Clo80looX0>[oh@3Wn]40^M6R0;SUl@2<`=l0H9_<06:V
a`1RYJ/0H9n004Z8G@1`ZX40RKbC0:CAZP2fh;d0`^O20<7S^@39jlL0c_3@0=7be`3Cm^40e?[Y0=Cj
k`3Eo?@0eOgi0>Koo`050?ooo`0D0?ook@3oonL0oooQ0?oof`3jo]H0mooJ0?;og@3Yon00hOkR0=_k
h@3Dmn00b_;M0<;]fP2ij=L0/nGJ0:?He029a=00LKJl002BT01>V9DC0000000>00djRP19K[L0G7k3
07BCd`25Yml0Tk[X09S=j02Dc^40Q<GB06bf_01NZZH0CijF02j1N009GeD50000000<001FP@00P:L0
IZ[607BhcP1i_Ld0NKo207_0]@20`:L0M;>>0000002Zg/<08V4X7000000<0?ooo`002P3ooon20000
000=01d0000c01`0<@0M02402`1702T0?P0O02h08`1003H0>`00020000100000L41R07i@LP0208eV
R00;08MOPP29HhP0V7RK0;ZP^@2oZ;l0b[G;0<noe03Kd>H0iM_b0>kTnP3hlOl00`3oool00`3ooo`0
oooo0?ooo`030?ooo`0C0?koo`3Rool0_^kO0;S/f02jk=D0aOGH0=Sog`3ZonH0j?oU0>Koi03Qon00
fokL0<odd`2hj<L0/>:o0:SK]`2MeK80V]Fg0:?M``020:?NaP0W0;3Sa@2kjLH0`Ng>0;k_g02aj=D0
Y^360;OT_`2njKl0c??70=kie03Gm]@0d?CB0=Wec03Ml/80f_2n0=O^^`3DhjL0fNN/0>7XZ`3ZkK@0
ko2j0>g//P3_iZP0lN2Q0?CPX@3ghZL0m>J/0??/]@3bk;D0l>^c0>kY[P3[ijP0dm^M0;cDV02gf9l0
`=NI0<[RZ@3DkKd0cNF^0080]m:E02L0d>Zj09k@[02ii/L0d??E0:gKd02I`iT0090006>cbP24a=l0
T<K/09K7lP2dh_l0d?oo0>Goo`3aoo@0n_oH0?Gnb`3^lKd0k^jh0>ORY@3C`gL0ekQ[0=o0MP3?[5`0
`:MA09J?=03oon/0ooob0?oojP009V`002iQ001>Q000SjX00:o006bi_01d_[40E:6A0:>YH02]Qf@0
0P3Nh;/09P3Vm/l0g>k50=Ski`0SIF/0BH>a09_>g02Qa:`0Z:AH0;j_000008L0OJCI0:kKl`2fiNh0
[n?R0:_Pe@2]glT0[mRc0;SSh`2_fo@0PKcL07Bfa01MXY@0F9I`09K5VP2LbId0Y<jQ0;KM]P36jlT0
a^W50<WY``3Bl<h0e_?B0=Wfe`3Oon80iOo^0>ooo`3gool0o?oo1P3oool04@3oonl0oooW0?ooh@3o
om/0mokE0?7meP3^o]P0ho_H0=_ig03CmMT0c?7F0<O^e@30jm@0[Mo<08g:^`1[[j80BI>501L00000
00/0;DnN05Ia^P1aPlL0PZKN09G6i@2AcMX0QlW<07:k^01AWY40;h1/001><P0800000009000jLP00
GXX0;gfK04^IYP19V9X006iW0:[H^P2SflP007h001h00000303oool000X0ooooOP0000004@0U0000
00000000000Y00h0=`0N03P0000O0000BP0c04/0=P0c02/0>@0e02L06P0D0000?@0006<00028Gh80
T6Z;0080Tff=00/0SVR:0:5oW@2gW;H0`Z[00<Raa@3@_<h0fl[K0>GFiP3]g^h0mNKf0?oooP040?oo
o`0H0?coo`3oool0mOoo0>koo`3[ool0eooo0;[jhP2ej<h0`o7H0<ScfP3@n>00f?oT0=goh`3Qon<0
gooP0=?if@37l=40^nS50:gN^@2Ldjl0Um6]09GA/@2Of[d0YN380P2gjmD09`31kmH0`NkB0<7_e02k
k=80^>_B0<O_c@3Dm/d0gooB0>Wof03Sn]80goWA0=_fc@3GlL<0e^nn0=G]^`3Aj[D0cNJ`0=GW[P3N
j[40i_:n0>oe``3alKX0ln^b0?KV[03egj<0mMfN0>SIUP3XhJ40j^bc0>S//`3OjK40a=NL0:;=UP2[
eJ40[mFO0;?FWP31hk@0bn^l0<GT[`020:c=T@0W09_9V`1d]YH0R/Rc002heP29al80TL2@07VjfP1n
^]h0V<7c09o8m`2UcoX0[MWo0<3]o`3Eool0k?o`0??ogP3`om00lOW80?Ghb@3YiJ/0h=>?0=k6N`3P
`WP0ck1P0:nK@P1mQRh0ooof0?ool@3oonT0m?oT0?3oi`3[onD0gO750<GBU`3Bi;H0fO7=0<cP/02X
[6D0]:eo0080d^Nj00l0cn_30;cFYP2J[6d0002C00<41P2Vd_l0]moB0<2nP03<aXH0001n0000e02R
d>X0^nW[0:[Of026`ZX00P0000005P2Oc^`0]>7Z09?9a01_[id0:a@009G;/P2[djD0[m>R0;[M/P36
j<@0a>S50<;Xa`35j/X0e??D0=_hfP3Onm`0i?oU0>Kok@3^ood0n_oo0?ooo`3olol40?ooo`0A0?oo
nP3oonl0oooV0?ooh03hom/0ko_E0>_idP3WnM<0fo;<0=?bdP33j/X0/Mo20;7Qb02KdKL0P;fS06R/
U`1:T7H05`0000002P29OXH003:604AZ/`1NQlP0OK3H093=g01n`l00J;6V042<L@0>FcT<00000004
0000LP000740001J03AnJ2400000303oool000X0ooooO00000004`0I000040000000000K0000<P0?
03T0600c00007@0004X0001@03l0>00X03807`0i00008P000580001[B7L0Ne^608]ZT02=Ji400P2>
Ji402P2DLI@0/9B`0<6Z`038/LD0cKW;0=>mc@3Sc]`0k]cX0?KSl03nloP50?ooo`0H0?Goo`3/ool0
hOoo0=Koo`38ool0_o;O0<3^d@39lmL0cOKJ0<ogg@3>mmh0`oCW0<Ogj038m^40aO;F0;_Zc@2`h/80
X]Nd093;Y`2?bjP0TLj/0:GL_02bi/X0`NoE0P3:m=`09`3<mn40c_ON0=CkgP3Eo=h0focG0=_id03U
omX0kooR0>oog@3/om@0iOW=0>7fb@3Jl/<0d^bj0=7/^@3CkK/0dn^g0=?Y/@3Nk[X0jOC20>kd`@3a
m<<0moK20?Wc_@3jk;D0l]jQ0>7@QP3MeHd0dn6V0=?Y]P34hJh0VLNA09k=V@2Tdj<0/M^/0:gIZP2o
ikd0`^Nj0;GIY@0209K0QP0W08:lU02_fk@0ZNGL003mo`00gLl0/^G^09O@k`22]nT0IYoH07B[h02U
d_X0/moo0<?ao`3Iool0i?og0>[oi@3^omH0looA0?7ga`3al;d0k^J/0>[OX@3KdI00d[a^09RF@P3o
ooT0oooo0?ooj@3homh0mOoU0?;oj@3ZomL0hO750<OFW@38g[00dNc80<CEWP2``X@0_]:I0080a]n`
00h0dno<0>3bd@3Vdi`0hMc60=g/o`3Fm_l0e>o_0=GN[034_7L0/Z1D0000eP2Tdnh0^nOZ0;[VeP<0
000001H0]^ga0:;Gb@000000XjeZ07:[`02Ve:l0/]JV0;[HY030h;@0_NC00;gWb02nil/0a^c@0=Ce
f@3Jn=d0iooR0?oom03Wond0lOoY0?[[m@3jj_l0ooWo103oool03`3oooH0ooo^0?ooi@3gon00kooK
0>Wje03Umll0g_;:0<oY_`2nh[T0Wm6a09?:[`22_jT0HZF;03=mIP0J00000007000ZO@00Ej<0Bh6j
06>Wa`1[];80EJ2>02mjF@0c000000`0oooo000:0?ooogL0000000D05P0002d0000d00004@0000/0
00020000000A0200000]00X0=00<03D04`0g01d0B00c04d0>P1202/0<`0002H0000_0000Hd=e0699
P01YD8D0O6>B08]_V@2;KIH00P2?L9H02P2TRJX0_JS10<B`aP3;^<X0ckc=0=:mc03QbmP0m]oZ0?oZ
l`3ooo`30?ooo`0J0?oon@3ooo00ooo`0?ool@3ioo/0iOof0=Cnj`3CnM`0d_OH0<oee`3;m=L0c?CI
0;o_e@2ek><0[>SU0:_Uf@2Yh/d0Y=g009OB/@27a:40S/ZV09K@[@2]h<00_N_:0<O_c@3@mM@20=;h
fP0W0=ClhP3FoN<0g?oS0>;ogP3VomL0k?oK0>[og`3Zon00j_oK0>OmdP3[o]40j?c>0=_`_@3Dk[d0
f??70=Wba@3Lkk`0h?2l0>Cc`@3Ull80i_?30>Wgb`3fom00oOk=0?kga@3]ijh0dM:<0;c:Q033gJH0
_^6`09;1S02Ib9@0XLjJ0:oHY02eg:X0/Mjd0;gYa030j;d0Y/nJ0080PkF202L0/]RY0:;I`@2en?l0
0>gm07^fV@2fj>X0RlST06BZf`16TLP0?XO309O8m000f?X0XM[b0:WPm@2^io<0bO;X0>SogP3bom<0
joG30>?[]P3Fhjl0cMfb0=[[^02i_WH0RYQ70?oolP3oonl0oooJ0?_oeP3homd0mOoO0>ooeP3Ljk/0
c=ZQ0=;P[03OklD0c=VS0;k;SP2ndYT00P3EikX03P3Xm]40koSD0?3/_P3[lLd0003T0=Obo`3JkOl0
h^g:0;jfKP32/VX0DGno082ge`2OeM/0`N_K1@0000003P3<j;l0001g08c1a`2MdML0]NGI0;oJY@2i
g;00_>:n0<S/c@34k=40b_3E0=Kfg03QonL0mooi0P3oool00`3om>T0ongo0?ooo`050?ooo`0=0?oo
m@3jonT0looS0>cogP3WnmX0iOSB0=gab@3Bjkl0^mf`0:K@X`28_i/0KZf?03j2H`0M00000005001L
W`13Q;@0F:>]04FAO`0HID<0=000000<0?ooo`002P3ooomd0000000702<0000_0000=@0002d0000G
00001`0001/000020000000B02L0000a0000=@0>03d0600o01d0AP0/04d0=P0l0000800001d0000_
0000Jd5Y07UHQ01bFH/0KEV?07USU@29KiX0Sg>L0P2IOZ<02P2gY<00`:k60<Nfb`3=_<h0d;g>0=:n
c@3Pb<l0on_T0?oom03oooh30?ooo`0J0?ool03ooo<0oooc0?oolP3jonL0iooP0=[kfP3InMH0e_OD
0<keeP3<m=H0_ngA0;7WcP2Zi=00YN;D09_Lc`2CeL<0T=6i0831Y02?bZP0Y=Vh0<7]c`3BmmT0eOSF
0=Khe03Go=/20=Woh@0W0=[oh`3Kon<0hOoP0>Gog03VomT0i?oJ0>?og03Uom`0iOoI0>Kof`3ZomP0
i_G20=KPW`3Gl<00g?G90>CeaP3Wm<<0i?;00=kb`P3Mll@0g?C;0>7id`3ZomL0kooH0??jd03FhZd0
_mBC09k3QP2_ej80WLVB0:S?V02^e9h0]MVS0;WKX`2fgZd0^^Jm0:oP_02mikd0LiQB0080V<>@02L0
RlJY002WT`2TcJ80^^gM0:_Ti@2fjnT0XM[W062Za01Q[<l0=8Za001SS`00QZX0092]002A/000ZLD0
X=_W0:OFc`3Nnm@0h?720:cEYP23^ZT0S<Jb09C4V@2@]gL0<e/@0?ookP3ooml0oooD0?oic`3jnM40
mOoH0?Oof`3Rkkh0^kIa0=cMYP3Qi[D0dMRN0;;1P@33ej400P3Qk;l08P3]m/h0mOS@0?Sof`0X;RH0
00000000d@3Lkol0j_KP0=oP[@3:`h40000006BSa01VZj/0EijN06FTWP2IhnX0e_oo0;GdkP32mN80
[K]g0<K>T`2TfN@0]>CU0<[Zb@2gbhl0^LnF0<cX_P3Ilm00goWI0>3lgP3TonP0k?ok0?Coo`3hool9
0?ooo`0;0?3okP3/onH0i_oP0=okgP3Pn=P0g???0<k[a02ig:h0T/6D08VkS`1XXgT0800000000`00
B74003I20000000e000000`0oooo000:0?ooog00000001l0>`0003L0000n0000@P000300000U0000
700000H0000Y0000000001L000000000;P0002l02P0g01@0@P0O04807P1802P0BP0X03404@0I0000
600004L0001g0000TFV9089RS01kG8P0NEf<07mTTP28KYX0UWfS0080[9Fe00X0_J[40<FcbP3<^ll0
bkkC0<jod`3GaMH0kMOL0?oohP3ooo40oool0P3oool06`3ooo40oooc0?oom@3oooL0ooo]0?Coh03R
o]T0h?cE0=chd03Fmm<0coGE0<G`d@2ok<h0_>cA0;[/e@2Zh//0V=No093A^@25b[P0VM>f0:gP`@3<
m=P0f_gP0=cmg@3Lo=P0g_oN0=[ng`020=gohP0W0=goh`3Kon<0g?oQ0=gogP3Lo]d0fo_I0=_lfP3M
oMX0hooN0>Goh`3VomX0h_S;0=KRY03Jl/<0hO?20>Ofa`3Tl/00h?6m0=Sba@3FllT0d_GD0=Cif`3K
oMl0hOoR0;oO]P2Wc9T0R;Z509k=V`2XdIX0Zm2E0;cKXP34hJX0]]NM0;?FWP2ih[D0[]fe09oE/@2D
d:l0Tkb90080W/FD02L0/MFZ05]h:@2RfL40VMSI09?Eg`2Ng><0Z>?U04nOX@000000BYja0000V@00
]lD00:K2066Ha`00A90006VI02]iX@2Xfl`0PkF@0000A`000;40IK>c07c0/@1TVV<0oooo0?oom@3o
on40oooD0?KaaP3emLX0mooH0?_og03Mg:80`j]U0>KJX03Pfj40_lJ60;O6QP3@gZT00P3Sk/40803[
mm40kocH0?Goi`051PD000000000]P3Gm?l0io[O0>?^`P3Ff9l0cL>10000V00004H0002c08C0e@0H
b=T0M[KD07ni`02:_:0000000>_U]`29^MH0_NW`0<WXb02edYh0b^6_0=C]a@3Jlm00gOOG0=olg@3T
onT0i_om0P3Wool01@3Rool0k?oo0?ooo`3oool0o?oo0080looo00`0jOoo0=kol@3MonT0g?gQ0=Kg
g`3>lm`0a^c@0<;Xa`2WeJl0T<2D07^_P@1YXWAI000000`0oooo000:0?ooofl000000200B00004D0
000d00008`000340000c00004`0002@0000000009P0001L0000>0000;@0003D0400j01T0@@0S03l0
6`100100@`0B0380300V0000:00005HVC`1aAVd0O5=h08QUR`1iE7d0MTif07mMQ`26IXl0S6fE0:N?
/080^JBo02L0`Zk70<ZicP3;_M<0bkoF0=K9gP3Rd^@0mN;Z0?ook@3ooo00oooi0?ooo03oooh0ooob
0>kom03ooo@0oooe0>Woh03YomT0iOgC0=ohc@3ImLh0doC?0=7dd03=l/l0bO7@0;GWb`2Xh<H0VMJj
09SE^@2HeK`0Xmk90;GWbP39lmD0g?oQ0=oog`3Pomd0g_kK0=WlfP3Lomh00P3Non809`3Mon80eokQ
0=Kmh@3Dnmd0doSI0=;ec`3?m]/0e?kO0=Woi@3NonL0g?oH0=[fb@3Fl<40gOC60>?gbP3UmlT0fnfi
0=K__P3BlLL0c_7:0<S_c031lMd0`_?Q0<7`e`2:`i`0PKV90:CCY@2dg:`0[M>K0;ODU`37h:H0d>R`
0;;@T@2UcYT0Z]R[09_@Z02<aZ00Z=c005FBK@020<c@Q`050=WPX01X[9`0O<K=07Bob`1R/:l01000
00002@000</0002M0000SP00H8l007B[01aLX`0cMk4077:<00aRD0020000R00C0000^@19WJX0B9Ao
0?o_j`3ooo00ooo]0?ooh03ooLh0k^bl0>k[^P3bml`0lO_B0=kff03Aikl0bm2B0=?EV@2e_GT0^lR9
0=gV]0020>;_a00<0>Ghe03Xon40jOoS0000003oom/0001k0000kP2lh]<0_]Zo0>7X^`3:_GP0bl>0
0P0000000`2@b=`0S/[J08K4eP020000000D0;j`J@3Zi;40001]0;CSkP2bg/d0[m2N0<3KZP3Fk/H0
gOOG0=ojg@3Qo^80i?o^0>KooP3Sool0fooo0=Gmo`3Cnol0f?oo0=coo`3Pool20=cooP0;0=Gol03;
m^D0`^gM0<3[f`2ojmT0]>?=09gC]`2<aJH0PkZC07bbQP00Z@00FP00000<0?ooo`002P3ooomX0000
000=0000;`000000F`0007h0001^0000H`0003H0000Q0000;P0003/0000n0000=`0001X000030000
000G00D0000F0000=@0004<05P1101l0=00002d000120180AP0I04406`0^0000<@0]04l0B@1[?F<0
OEb608=RS022GhL0MTif07MAN`25GhD0RVF:095^TP2gW[P00P31Zl802@39]LX0c[_>0<jmd03Ea]X0
gm7S0>_JjP3ho>h0oooa0?oom0030?oolP0K0?oom03ooo`0m?o`0?cok03_on00jooG0>Clc@3Mm<H0
eo;60=CaaP3AlLP0a>_40:kQ_`2Qf[/0U=:g0:7H]02Qf;H0[^?80;_^f03:m]h0f_oS0=[nh@3Ho=l0
e_[M0=Kif@3HnML0gOoN0080h?oR02L0f?kP0=Ckh03@n=`0cOKI0<[ac`39klT0c?CI0;o`h034mnH0
c?gT0;O]f@31j;l0bnc20=ghd@3Unm80eNbi0<_V/03:j[/0bN^m0<KZ_02mjL@0]n[C0:KRdP2Cd[d0
Pkb>0:OGZ`2hhkP0]mn^0;WHW@2ofI/0anB^0;gKX`2WahL0ULB@09O;WP1n]hX0XmBb0<ghhP0GJ540
0P33dH`01@2e`WX0JkFX05n_[P1<WY`0DIb700@0000000H0_>7o0:cOn`00e^D0JKC>002H_000FhL2
0000000F08eSR@2TPJH0`ZS40>34f03oeMl0on?R0?o/g`3oon<0oooV0?ooh`3oomh0no[:0>kW]P3^
k[l0ho360=kbc03FikX0cmVP0<7<SP2X/fh0_LZ=0=?S/@80f_3802L0gOOE0=Off@3In=`0f_[X0;OU
f@2i_@00g_l009gAk03FkOl0iO3I0<g6Q@3>bHX0[<Wi0=3ki@00JY`0IjW20<CO001dF`00i=bW07QJ
1@3<_H00ooON0:7Gi@2cf/<0an6b0<_S]039j<80b^c:0=?be03FnN40foo`0=gonP3Jool0d?Wo0<G/
o`2liol0`Noo0<Oao@36lO<00P32lnT02P2jj]d0[N3B0:3Hc`2Sf]00YMc;09O?]P24`:@0RlFY07Na
R@00L01K000000`0oooo000:0?ooofH000000P1I01P09`1e01@0PS8N09=5:`1_0000@P0004/0000h
0000;P0003/000160000@`0001l0000000008`0001h0000900009`0004P000190000=00002d0000n
0000CP0M05H0<01@0380?00a02<06`1@04X0I01M07I=L`28IH/0R66407A9L01bBG40P5Ql08]SQP2>
JH`0[XfW0<2U^P020<Vba@0:0=6lc03B_</0el?C0>3>gP3Yf>T0m_G]0?ool@3ooo@0oooe0?ook`80
ooo/01/0ooog0?ooo`3oooL0o?o/0?;oh03XomP0goW@0=[ca`3CkK`0bnZl0;oU^@2]g;80[=nl09kG
]`2Rek80ZMZ`0;7R`02mkM00aoCM0<oljP3?n^L0coWS0=;ih03Fn]d0f?[K0=WjfP3Jn]T00P3En=T0
9`3An=`0d_[P0=;kh@3>mmP0a^k60<W^aP3>m=D0b?KS0;c`i@2kl>40]NK80;KR]`3>m=40gOgK0>3g
c037hj/0`^6Z0<;R[P32iK@0^n>f0;?R_02[h<80Wm[20979W`2GcJ<0Z]^a0:cL/`2dgk40^]fX0;gP
[02hgJT0ZLnF08fjP@2FaI<0N:ik0;7Q_P33l=H0d_?C0<;GV`020;WBTP0W092SDP0nT8<0GJBB04ZE
O@27akD0a?[[0=goo`3Uool0h?oo0<ooo`2gjMd0Q/W;05>V]P19W[D0000007Y>MP2QNid0[h^[0;JG
]`3F^ll0i<WI0?oIg`3oiMl0ooSO0?ooh@3oon00oooM0?ood`3ik/<0l>Je0>SQ[03Ni[D0gnZk0=k[
_@3FgJ<0[/:30::^J02ibhh0a=^Z0080d>[302L0bnc<0<C[cP1m^:@0`^_[0000003GcP00cLWo0<OC
o`3Nn?l0i_K/0=GIX@3?c8h000230000a`3AnNP0hOoa0<2h002o]P00eK^209ie:@2hY5X000000000
b03Lm]H0c>Nl0;_P^02niLD0eOOP0=SjhP3Lond0hOo_0=kon@3Loo`0^n[[0:oQj@2UfNT0Y=SX0:CI
iP2XgMh00P2QfM00202:b;P0S<Zk08g<b@29b<<0Q<2[07bjW`1c/YH0J:N4G@00000<0?ooo`002P3o
oomT0000000<04/0001k03l0R01<08P0C02A05d0TUEJ06@0000m0000>0000300000Q0000<P000P12
00007@0N000000000300000000005@000440001=0000>`00038000180000E00006H0<P1Y04D0G`12
04D0:P0[01`0@@0b06XcD01kAF00QeMd09AZQ`1gBF/0KT1W081EN02?IHD0SfR:0:R5W`2mW[80ajbm
0080dK[800`0dk_90=FmbP3Nam<0im;O0?[Wj@3oonl0oooc0?oom`3ooo80ooo/0?ooiP3ooo`20?oo
o`0F0?WokP3_on80h_oJ0>7og03Jn=80do770<GV]@2nhK40[=RZ0:3BY`2bh[`0]^>i0;[S^02fh[T0
_n_90<Obe`3=n><0c?WX0<_ijP3>nNH0e?_R0=Slh080f?gP02X0g?oL0<gde03=m=@0d?SJ0=Gni03G
onD0eO[G0=CfcP3Hn=80e_WH0<okiP31lnH0`>oI0<;/b038lL`0eokS0=_kf03IllD0`mjR0;gNY`2n
hJl0^N6b0;KP/`2/gK<0Zmfe0;;Q^@2GcZH0V]:]09WD]P2Rfkl0Zmjk0;?L[02`fZT0YM>Q08bkPP2D
`8P0R;R109o;V02oil40c_KL0<?U_@2WcYT208:ZJ`0=000[002ikNT0[^CQ08?2^@2Zhmh0_?Kd0;7e
oP37ool0eooo07Jh[P1IXI40M45V07Y5IP020000000H09AaVP2KMIT0XGRH0<b[_P3O`<l0k<kJ0?oK
g@3ojmh0oooN0?oog03oomX0oooG0?oodP3lmLT0lNZk0>OQZP3MeY`0i>Rf0=oT[P3?fZ80]l>20:ji
M@2cah/0_]NR0P3Gkl/0102cgK`0K8Y?001VT@00YLX20000000Q0;R@[@3_knX0i?oo0>Kjd`3Ah:h0
dm>G0=7:RP3Ebh`0kooe0?gog@3[j[H0onoI0?oN_03ccYh0WGd^0000002lknD0^N?:0:KAZP00A5T0
09Z[0>Ccd`3Unmd0k?oV0>Sok`3SooD0h_od0<_hj@2fj>40X]WM08K4eP26aM40QlK70080T<g400L0
Tljk08S7]P1m_k`0M;N[06jbW`1c]9`0@HAQ05h00000303oool000X0ooooH`0000000`1C62h0SU1B
0:I[JP020:iiO@090:f4TP2HJ7H0F`0000/0000o0000;@0003X0000_0000=P000080000001`0?@00
0000000W0000A@0?0480000P0000A@0005/I;P1U8C80L2hn070Z>01X9CP0D@0S02`03@1D02/0KBm5
07i1E@2<DfH0OTMS07i=K01]?600NTe_09AYQP2MMY<0XGnM0;ZL/P34ZK/0ckK50P3C^/L09`3C^LH0
fl7<0>?9d`3_emh0oo[V0?ookP3ooo80ooo`0?ooj@3gon<0n?on0?[oo`3hool0l_om0>coi03IomD0
c_K@0=7gf03BmM80an_10;ON[@2hgjh0Z]NY0;WR]P35j[l0c>g20<3V^@33j/80b?3?0<kigP3?onL0
c_o/0<glj`3EoND0fooR0=Woi03FonL0g?oT0=cog`020=Wfd00A0>Gof`3Son40h_oR0>;og03Ln<h0
cnk10=3feP3GonD0dOWO0<cdf@3An=P0fOoQ0=Clh03In=@0e>jm0<?MX@2hgJT00P2lhJl0502`gK00
YmV_0:OI/02Wej/0TlfV08g<[P2`h;d0/N?30:WL]`2WejT0X<nK09K6T@2C_hL0U;n609c5S02_fJ/0
_>W90;k/d`2>b:80IZ=e0P2nl_<09`3=oOP0_o;`0;?YjP2cjN`0Z^?X09OHg@24cM<0Z^[l0366S@1F
8DT0KcUK06dgFP0Q02h0H4Z806U:P`1kEXD0Sf>80;N;W`3K^<80ilG?0?3?f03ogM/0onkL0?ong03o
omD0oogC0?one03oomH0oo_>0?;_`P3Xi:l0iN6Z0>?QZP3JgZD0b]FJ0;W4PP2`^GD0^lZ=0<GHY002
0=?]b@0@0<[=V01o0000N:[G07RTe0000=/0oooP0?_ZaP3PkM00gOoQ0=Cad03IkLH0fn:_0=7BU@3@
d9<0ooo_0?ooi080oooR01D0ooOC0>;GX`2CLB80R0000:NI0000Ded008Mm00000000<GL0^<gG0=3U
g03don<0oOoh0?koo`3/ooL0g?[J0<g`f036l>@0[n7T09gFg@2Ke<h00P2Idl@01@2?c;`0P<2`002^
Y01V[9l007]/06000000303oool000X0ooooHP000000100M0000EbU80;QnM@0000020;b`c`0708mb
S@1`@580CP0003X000000000=@0003T000020000000N03<000000000000002<0001301P0?P0A03@0
001=02`0F1`g05lQ>`1Z:Sh0MS8n06T0<`1801X0@P0K05/I;`1U:D@0Od5C08a@H02HGfd0PT]R07@o
GP20DG40UVj;09UaS`2VPj00]YVb0<2V^`3;/l@0d[[80P3C^LH09`3N`/`0iLWB0>cAe`3ojmd0oooS
0?ook03oonh0oooW0>[oh03ZooD0k_oo0?7oo`3Vool0hOo_0=Gkf@30jlL0_>[;0;o^e02ljLP0/mnd
0:kIZ@2bg:`0`>>c0<c/_@3?k/40c>g00<KY^`3;klL0dOGE0=Soi@3Poo@0hOob0>3ojP3Pon<0fooQ
0=Omh@3Jon<0hOoV0>Gog@020>[ld00W0>koe`3]omd0kOoL0>?lb`3EkKL0`^Rl0<Scd`3>n^80cOWV
0=CniP3LonH0fOoR0=7ig@3Cm=00anRj0;cKXP2eg:X0^n2]0;3IZ02YfJ`0X]FY09o@XP2RdZH0`nc8
0<7Y`P39k<80`^Rm0;WR]`2ScYT0VLRC09O5SP2JaH`0T[f309_6S`2Te[40WMRo08O8[`1JWGL0]ncf
0080__;e00D00<O909kLh02XhnL0=HR=02N0RP030000000O04<0<`1Q9dL0Jc9B0500A@1?;6<0CS=a
05X0I`1oEX40[H:J0=Z`]P3R^[l0k<S<0?WAe@3ohMd0oo;M0?oog03oo]@0ooK>0?ogc`3omld0nOG:
0>k^_`3Ti:h0gMnW0=oPZ@3<dYD0bmRN0;O1O`2f_GT0`lN50<oDV`020=gZ_P0W0?Whc`3oomd0c`00
05In_P2`c?l0kOkM0>[he@30iLT0[MZn0:oBd@3?l>00hoGA0=gZ_03@eIT0`<J601e=U`3;hM00oooX
0?_ogP39c8l0Whe800001000014008V9055mU030hOl0gOoo08>Se03Bln<0jooZ0?Oon`3jool0iooZ
0=kfd03Hm=D0b?3J0;_Yg02Ug=`0NKZ`0080EIb900<007e^000000000000HP00000<0?ooo`002P3o
oomP0000000301D0000V0000>P0000D0000000<0TI?5065BP@0m00001@0000007`0g0000:@0001H0
000W0000BP0004H0601001D0D00]05XM>01M7SL0IRU206/[?`1M03@0=P0E04<09`1J03d0G2=307e3
F@2CFf`0W6If095HJP26CfH0SEYa09]bS@2QO9P0Xh2L0;BG/02nXkX0b;320=6kb`3A_m000P3B_ll0
9`3E`M00mM[P0?oWj@3oonh0ooo_0?ooi`3oonD0mOoL0>Koh03TonP0ioom0>Koo`3Boo80a_CL0;_[
c`2kjLL0_>_=0;SZcP2diLD0[mfd0:kK[P2nhkD0bnZk0<S[_`34jl80a>Rk0<_]`P3Dlld0f_oK0>;o
j`3Woo@0j?oc0>Soj`3Qon<0f?oL0=[oh03PonP0iOo^0>[oj0020?God00W0?Ood`3gomT0k_o;0=Wc
_P31hZl0]>6h0<?ae@35m=h0c?OQ0=?lhP3FoN40d_[N0<kff@30k</0/n6j0;3JZP2eg:X0ZM:M0:;@
X02Wf:`0X=2P0:KAW`3Ekl80fOK>0=Gba`3>l<H0eoK?0;kS]@2Ha8/0Tl><09S5S@2E`HT0R[Ml08G0
VP1i_:00JK:L0025IP00N:<00=c[008007R000<0061Z0000000000001@0000007`1_=E<0NT5M07Lm
F@1T<5L0NDU_03X0<P1R05`0Z7bG0<bV]`3Q_LH0j/G80?38aP3oem<0onOP0?ooi03oomd0ooK?0?og
cP3on<l0oo[A0?CcaP3YjkT0hN>]0=cOY`3IgZH0_/b>0<KDVP2ja880^[]e0=?BU039_GL00P3KeYd2
0000000F0?ood`3ecIh0g/2K0>kfcP3Zom<0f>Fb02]0R`25YL40dOKX0>Ckf@3LjKT0c=BI0;c5Q02B
ZFL0V;W<0>Con@3JlM<0^<Z?0:>lT@35j^D0S5Qm0:^N00<0000000`0EfjP0<;YgP3Oon`0jooa0>[o
j`3Won80gOK@0<g/b`2eh/P0T<V`05nSSP00Q6eW000000`0oooo000:0?oooel0000000<0E@0004d0
000000000P0000001P00QX<00:>f000000000000]m;o05`00080000002<0E00001L0000m0000AP00
02`0000C0000?P0004d0601701T0?00<05H0:`1M6Rh0G1X_06@U?@1U9cl0Fa/e05/0?P1L04@0Eb13
05dWBP28EW00VVYo09a[O`2FHgP0Teme09ETN@2OM8X0YX2K0:b;Y@2cUJh0_J:i0<J]`@3?^LX0d;oB
0=74f@020=?5f@0W0=G6f@3Ye^<0ooSi0?oojP3oomh0oooJ0?oogP3Xom/0iooT0>Coj`3MonL0g?o`
0<Seh02ok]@0^NW<0<3]c@32kLh0_>W80;?T`@2^gKD0]>2f0;oV_02niKX0_>O00;gV_031j;`0cO3:
0=SneP3Uon<0joo^0>kol@3`oo<0joo[0=oog`3Komh0goo[0>Col`3VooT0jOoo0080l?o`02<0l?oQ
0>God03Jn<X0a>Vk0:cL/P2jj<@0_noG0<GcfP3;m]d0cOON0;k^e`2/hld0TmC009GD^P2^g[D0]>2e
0;;L[02@_XL0Xm>T0:oM/`2bg[@0d>bn0=___`3OmLX0c^bo0<CZ`039k/L0_nFi09NmOP2=_8<0S/2>
08>fPP1a[7h0H:J702]jHP0<0000000Q03`0:@1Z<U<0NdAR07HnGP1U04T0A@0P04d0:02P07H0]HBG
0<2I[P3C[kl0i/7:0?;;c@3ndLl0on7I0?ocg@3on=d0oooJ0?okd@3on/l0no[A0?[me@3em<P0jN^j
0=kOY`3GfId0b]2B0;[;S@30cY00`LV80<_7Q@3JeYT0dLF30080gM2E02D0bIUO0?ooe`3ooo00oooC
0>GL]`3[oMH0eno90=o_b032d;<0Qjfh0=oojP3:j<h0]]6f0<C>T02NZV@006Ha0024^P00j_L0]Mg7
086bS@3>mNX0d_So0=Gh003El?l0e=Ko0<nVV01G0000Tk3O0<[amP38lNP0eoob0=?hi`39l=@0_N;1
0:WH]@26_IP0Giei06T00000303oool000X0ooooG`000000101Q00008000069D]P2/_l<20000000M
04]b]0000000000003d0000X00009`0001h0001C0000G00005<0000g00008P0004X0001@0180A@0A
04D02`1K0280GaPU05HA9@1T7Rd0Ib@f060O=01E5c<0GbA205@M@@1I9DX0TF=o09a`R02LLHX00P2J
L8/02`2NM8h0YG^B0:^4V`2]RJ<0]9B[0;^O]@33Z[l0c;G70=?1d@3EamX0g<cM0080j>Om02L0inCi
0?oio`3oool0o?o[0?oog`3nom<0h?[E0>KogP3WonH0h_oW0=[ohP3Bn=X0a_7D0<;^cP36l<l0aNo>
0;gZbP2diLD0[=ff0;7O]`2dhk`0/^6j0;3P^P2bh;L0^>Fn0<C/a@3@n=80gOoL0>SoiP3TooH0hooo
0>Kom03Von00gOgH0>?oh`3XonP0h_oa0>Con`3Qool00P3Hond08@3Cml`0`Nc50;SV`02Wf:d0^>Fn
0<C_d@36l]T0b?GO0;c^f02[hl`0Wmc709KGaP2Fel@0Z^720;;T_`2bhKX0W<ZG09K4SP2Xg;D0^^O3
0<CZ`@38j;P0`^Jm0=;^a02fg[00[]ji0:kM]P2E`X`0QkMm08BjR01k]HH0IJ1]0024H`0>0000000@
06d0G01g@F80KSEE04d=:`0_00h0IP100;1iQ@2dPY40]XVO0<NQ]03M^lH0kLS<0?W>cP3of=80oncG
0?olf080oooH00l0oocB0?ShcP3hn]40m_W@0?Cdb@3Xik@0h=nV0=KEU`2ma800_/V80<oEV@36bXT0
e<f<0=[EV03Jd9800P3OcI<0903Ycid0oooB0?gof`3/n]D0e^g?0;oTa030il`0000009_?`000/iD0
0=K306JVaP2beL80ZLJC001b?0000000031[001[Q017S840R<C30;;Sk03Eo?l0co3o0<[Qo`3:eol0
cLO`0000_P37l?l0[>3J0;WXk@2_hM`0Y=[909[B_@29`ZH0OkVF066LLFX00000303oool000X0oooo
G@0000001@0007/0000004P0001lSgd02P/:00@000000P1>00009`1O00009`0003T0001>0000A`00
0440000W0000=@0004h02`1C00l0B0070500501Q72`0Fa@U05PA8P1a:cL0LRlo06dW=01U8S@0H24i
05dUAP1N:4/0SVB409]bSP2TOID0T6^=09I_SP2NMi<0Y7fF0:^4VP2_RZ40]96W0;bL[`31Y[T0ak33
0=6mcP3IbMT0g/kN0>GCh@020>oVmP0W0?goo`3oool0m?oo0>OokP3ZomX0foO>0=Sme@3Roml0i_oU
0=ooh@3Go=`0c?7>0<K_c@36l=00ao3A0;cYa`2diL@0[Mnk0:_K/`2gi;d0/n:l0:_M]P2^hKh0/nG6
0<C`dP3BmmP0eoKB0>7oe`3OonL0i_og0>?oo`3Poo00h?oK0>WoeP3aom`0jOoK0>;oh@3>onh0`ooZ
0080^OGR01l0[N;;09oH^P2[g;@0/^:l0<G^bP3<m=D0d?WO0<Kbe`2eiLD0Ymjm09oI_@2VglD0[>G>
0:oUb@2ei/L0ZMR[09_8T`2Lc9`0[N700;;Ta02hhkT0Z=Zf0:GI^@2CcZ`0Sl^Y097<Z02=ail0P[V8
07F/N01`[H<0FY]c00h0000002<0C1M106<aFP1R;500GB=6054G?00j03D0F`170;J4U031SiX0b9^W
0<ZNZP3K/[P0hK^o0>[2`P3bal<0omc>0?o`eP3om=80ooS@0?ogcP3fmL`0m_S?0?Kid03jmlh0mOC9
0>SV/`3UhZ`0f]RM0<?4O`3;cXl0d=:D0=KDU@3EdiH0fMRL0=W@TP020>CIX@0=0>[U]@3Qk/H0_Mno
0976[02Ec<<0J9Q_0<OAfP000000YmS608_4[000AX@0076G002AW0060000000@07Bcb@2KdNh0^NOo
0;oSo`3:gol0_/Wg0000b01dV[d0S/c<08K6a@2@c]00R<S506nbW`1VZiX008Um0022HV/00000303o
ool000X0ooooGP000000101h=3P0002h0308000005@20000000604L0000;0000<0000300000e0000
=`000P1500008`1700006@0003D0001<0@h0DPD>04/0301D01/0IB0_06@S=`1I6300LSA707XjBP1b
;cd0K2Hc06LQ<@1V9C`0Jc1=08iRP02JLi00YGfF0:AlU@2KLi00XGRB0:=kU@2XP9T0[hVP0;FAY@2l
VJX0a::a0<V/_03?]lH0f/G@0>7@gP3XeN80k][V0080k]cT02L0e>;;0?7[o`000000f?oR0<gfe03:
ll`0fOoJ0>Koi03Qon00g?oL0=;dcP37jl40ang80<K`d02lj/T0/nC20;WXa`2`h;T0^>Fn0;OT_@2^
g[D0/>6j0;GU`P36lM40f?kR0=goh03RomX0kOoK0?SoiP3goo40j_oe0>Goj`3Zoml0m_oJ0>kod@3Y
oLh0foWA0;3`f`2Uh]<00P2HfLT07P2Adk`0WMNf0:gP_02nk</0boGF0=Klg`3@nM`0`Nk>0;?T`@2Y
g[X0[NC90;3XdP2aill0/NK:0:GL_@2JcZ80Tl>>09c=W`2Rfkd0YMk009SD]P27bJd0N;nZ0836]02:
cKH0Q/JS07^jT`1[Z7X0HIi_03n6G`h0000002@07@0Q04XLCP1I9Dh0DaXo05XQAP1903`0DQm:0:j4
W`2oTZ80bYVR0=6QY@3FZ[00fJne0>6h^`3[`K/0nl^n0?oNb03oj<`0onc:0?o`a`3olLL0nO770?_f
c03omlh0oOG<0?Gcb03/kl40gMjU0<G7Q@2g`h80emBG0<o=S@3CcXh0f=NL0=SJX@3EdI820=kNY`0:
0=OV]`2L_i40^lRA0000002Gak00;@000>_Ma@2eg;d0XLZQ002MR@X0000000D0B8Ze002hf02=^n`0
[];o0<?No`0200000003076f[@1@ViH008F007000000303oool000X0ooooG`0000000`1BJfL00000
000000020000000[02/0000g0000@`0004<0001C0000G00005L0001400006P0003l0001<0000E000
05`?5P1Q5Ah0JR0Y06`V<`1Y:3/0LSA807XnD`1b=D/0IBDj06PV>@1d=4L0P4EJ09INKP2NL8D0XWR@
09MZP`2GJH<0XWN@0:=iTP2TO9@0[HJL0;JAY02mVJX0`If/0<BP[P3G/kP0gKk30>K:c`3[e=h0lM_V
0?GNj@020?CNj00W0>OQg03:jkh0cO;>0=?jg`3Do=d0f_oN0>?oh`3Pon80f_oQ0=?he`3;k;l0a^Zo
0<?]b`2ok<`0/nC10;WXa@2nj/H0_^W50;WU_`2bh;H0/N2h0;CS_@38m=80f_oT0>7oi`3XonH0l?oT
0?ooj03oond0ooo<0?;ojP3[onP0oooI0?olc03Wn<L0fo?40<;U^@2SglT0V=K00080V=S501`0X=k:
0;3Vd032l=D0a_;D0<gffP3@n=`0boCG0<3/b`2[fk40[^720:kTb`2/iLh0Yn7709cI_`2GeKT0Sl>B
09G6U@2Fbj40U]>f09C@/@1n_Y/0O<:/08;9^P25b[H0P<>U06nbSP1SYGl0EYUa40000000900a1C`0
B1<o05@G=`1T:DT0G01203d0>02QL8L0]XnY0<JO/@3?Y[40e:Zc0=>Z]@3E[;H0h[Ri0>g2^03kcK/0
omVo0?oQ`@3ohkh0oNJl0?WY_03hjkl0oO?80?[`a03fk/80k?740>W^_`39dYD0/l>30<7=T03MgJ@0
c<b<0<;:RP3:eih0d]jY0<7DWP80_]NS00P0]]>R07ZSK@2fd:D0f_[N0>GofP1F0000i>_70;oIZPh0
000000@05UfA05jKb@1n/ND0WIY]2P0000000`290000g@000=RSU0020;H0000304T0000000000000
06800000303oool000X0ooooHP000000100n0000@00004<0001=000205/0000W05T0001=0000@@00
03T0000k0000A`000600001_0000LRHY070W;P1g;S@0O3Dm07dlB@1l?e40LSQA06LW?01Y<4/0QTaQ
09=HI`2OHfd0YVYb0:AaP02MK840UfMm0:=fS02QMH`0XGJ>0:ElT`2^QY/0_9JW0<:M[035X:d0aj:^
0=Vb]`3fc/P0mmCD0?SKh03ihN/0n>7Z0080n>3Z02L0mn3Y0=;^`@3Fm]00e_WJ0=Slg03Nomd0eooR
0=KojP3?n^80aNk;0;cS]`2mjLD0_>[:0;KVa02_hKh0^NS40;OU`@2giL80Y=Zj09oG]P2ahK/0_^_9
0=Goh@3NonX0iooZ0?3oj`3iooL0oooo0?oom`3oon80ooc90?oeb03on/X0ooO70=_c`P2jh;00Wm6U
0:SM_02Ygl@00P2^iLh06`2dj=@0aoCL0<_eg03;m=X0ao;G0;o]d@2filL0[]bb0:SH[02Wf[80ZN31
0:_Sb@2Zi=00XmZm09O;W`2=`Hl0T/RL08o>/02Dd:h0SLNO08k7W`2?d;P0Ql^h08G9/P1W[H`0D9Qf
03N3H`0@0000000U02L09P0m03<0A00_068UA01E03H0C`0`0880E`2WLX<0_IBZ0<ZNZ`3@Z;D0djRa
0=J[/`3M/kL0i[^i0??6^`3oe<80on770?oU``3oj<00nnJk0?GT]03eiKH0mng00?K^`@3/kl80hnk1
0>7[^`32e9X0_/b=0=CIX03DfIl0^lV;0:_1Q@2he:80`nBk0;?BW`020;gJZ0080:k>V`1nWf<0/mk1
003Vg@31hlT0UJAW0<GFYP2>/gh;0000000405:K[01FW;/0000009NaS0`0000000@0PSe20:QfB`31
Xi<0PhRA0P2VTIT00`31RXT0U`000000001R000000`0oooo000:0?oooel0000000L0@00004`0001H
0000F@0005H0001H0000G0000080H0X002L0H@0005<0000f0000DP0006H0001g0000O00007`b=@1i
<S/0PC]208M2B029Ae40NcI0070/>`1Z9cX0J2e707`oDP27CV40TUQX09iSKP2QIW40Y6Yd0:5[NP2S
LhL0XgJ:0:=fS02VNi80[HBJ0;RBY033X:l0aZFc0<RX]@3;[KX0oM7=0?och03onN`0ooge0?olo@3/
iMh00P3[i]L06`3^iM/0f_;30=khc`3Jmm80eoSD0=3he`37mmh0aOGQ0;o_eP2di<00[mjh0;CUaP2c
i<@0/>:o0:oQ_@2Wf[D0Y=Na0:CK^`2Me[L0[=nj0;WWa@39m=L0dokT0=Ook@3Oonh0k?om0?Woo`02
0?ooo`0:0?oom03oon<0oooE0?oodP3Nm/<0/MNS09W:V@2/g[L0]NG30;o]c`80`NoD01X0bOCJ0<kf
g03<mMX0ao;F0;OZc`2/hlL0Ymjn0:CH/02QeZd0[Mnj0:oTa`2ai/P0Zn;:09oC[02AaYH0R/:F097<
ZP2Kf;d0UM2`08o8X@2Kdjd0UM6a08S7Y`1RZ8H0CYEb01QS@Q00000002H06@0C03009`0k02h0FQm0
04h?;`1@02`0KR/o09UFG@2[Jfh0_X:20<fNY@3BYZd0dZF]0=JZ/03M/[@0kL:h0?g>_P3og<D0on?7
0?oWa03oj/40nNRl0??V]`3cikP0lNVj0>c/_@3Qj[P0enFb0<kU]P2lcY40b]6D0=WMY@33ci80WkUj
09BiPP2PbYh0[]F[0;OHZP80[LnN00D0NZ5W03^2P000Mgd0051a0:SGg00L0000000608@000120000
FP0007E3001BRX<0BHfI0P091@<010000000ZlfR00862@075b9Q000000`0oooo000:0?oooed00000
00T0@`0005H0001T0000GP0005X0001K0000G@000640001C00000P1B000090150000F`0007<V9@1o
<S00O38c07ld=022>3P0RTA708m<DP2>Be40Pcm7070X<P1V7BX0LRXd07lg?P1l=d<0Q4AA08M>HP2D
Ff/0XVUd0:Q_N@2YLW/0Z7=o0:UiR@2[OY40[86F0;>;WP2jU:H0`Yn_0<JX]`3=/Kl0ckG40=6jb@3o
j^40ooo_0?oon@80oooo02X0in?k0=oYe03OjM@0ennk0=kc`P3Mm/X0fOG=0=;cc@2mkM80]NW@0;;W
c02_iLP0Y]bj0:GK^P2[h<@0[N720:gP_P2VfkL0Vm6]0:3F/P2^gk`0_NO20<K^b`3;lmH0boGL0<oj
i@3Bonh0e?of0=goo`3/ool0l_oo0?ooo`3ooo/0ooo[0?[oh@3Nn<D0[M>L09?3SP2/fk80^^S60<C_
d03<m=H20=;gfP0H0=Cif`3?m]P0b?;D0;[[cP2_iLP0Z^320:CJ^02PeJd0[Mfc0;?S_@2ei/@0/NK8
0:OL^02IdJh0QKb;08K1V@2Cck00U]:d09OB/`2>bZH0S<RU08K4X01RYh80AhiX4P0000009P0a02<0
<P0Q0500?`1A03<0?@0E0600;@2<BDl0_X1j0<N=Q03FXi/0eZFS0=FUYP3@XJP0dZBZ0=V/[`3ebKX0
omNn0?oTa@3oj<@0onO00?cX_@3gikT0l^Rh0>oZ^@3]jk/0iNFa0=[QZP3@gJD0d^Ni0;O0N`3AfJ00
d]^S0:JhM@2D]7L0V;f80;CK]`2igkX0/MN/0P1o[Gh01P2dMW000000003Wl@2KalP009NW00010aT0
000000P0IalX06H0?01H7T40T6Eg0?6^0031Q000SlW00937^`800;jj0P0000000`3Rool0oooo0=S5
eP020000000303D000000000000005/00000303oool000X0ooooF@0000003@1D0000D00004l0001J
0000H`00068;001Q2P00G@0005/0001P0000I00005P0001L00000P1f00008@1o0000QS/i08Hl?023
>cd0PSTk08Lm>`25>SL0Oc8`088h>01`9bh0F0lN05`B801e;ST0STYA08]9D`27A500T51J09QMJP2X
KgT0/gb20;=mQ02bOHH0/Gn:0:n0S`2aQiP0/hbO0;fJZ`34Y;<0bjfk0<nd`@3J_/P0onKO0?oZi002
0?oomP040?oon@3oool0oooo0?7`o`80gOSS02L0eo6k0=S^^`3Im<T0e??;0<[^a@30k</0]n[C0:oW
c`2ai<D0/>6m0:OM`02Xgl80[^;20:[P`@2Tfk/0[]fg0;_W`P3<l<T0eOC=0=Sfd03GmmD0d_SM0<km
i`3;o>h0b?[e0<goo`3Tool0hooo0>Woo`3Zool0jOo/0=;ge@2UdjD0V<F>0:_DX@2mil00ao3@0<oe
e`3Cn=T00P3CmmT05`3;lmD0a?3A0;_Xa02dilP0[n?50:gQ`02`hK`0]nBm0;?R^P2gilH0/nK:0:[Q
``2Ke;40R<:F07Z`O025`Yh0Q<BU08;5[024aZX0PL6O07RhU@1UYh00?hEM0180000002L0<P0L03P0
9`100280CP0b03/08@1c<dH0X5]J0<:5N`3GX8d0gjfM0>:e[`3N/K40f:^]0=BVZP3Q/k<0lLFn0?oD
`P3oh<@0onS60?oW`@3oi[`0nNFh0?;S/P3]hJd0kNJc0>_Z]`3QhJX0c]:C0<_GW@3@h:/0_<b?0<[K
Y036eYd0TZYW09NeN02_c9L0_n6k0:S@Y`1XWG400P2BU5d0102aTgP0=bPR00000000MV/K00000008
06iRW`1kGI00VHbo0?3>i`3ognP0n<FY0=BbSP2LHd0207/b6`0907Zf_P00000000000:C4l0230;l0
L00005d0A`2X0700YFP000P0000000<0R[nS0;O?W@00000070000000101m0000VDhm0:EN@P2DC2<a
000000`0oooo000:0?ooodl0000000<0<7Ua0000000000000`0000004@0W0000@00004l0001H0000
I@0006D9001T1`00H`L00647001P1P00G@@005h6001W4000LA/=07/X701n;B80P34Z0080S40j0240
T4I009A;AP2<@Sl0PCHe08e3@02CBTH0QSXf07TZ9P1b8R40J1/P07/c>@2:B500U5MS09EIIP2ADf40
UUYW0:5WLP2ULGh0[G^70;B5T02dQY80^8VE0;J;V@2gS9X0^9:R0;ZFZ031XK80cK6o0=BjaP3G_LT0
f/7<0?oTh03oooX00P3ooo`0103ooo/0oooo0?ooo`3Zool20>3ogP0W0=Wc_@3Bk;X0e?760<k^a03:
k<40cNo60<C]c02fi/D0^nFm0;KVa02aiLD0/N:m0:oR`@2Zh<80^NO60<S^b03Emll0gooD0>Cld03V
n/h0i?gE0>;og03Son/0i?oj0=koo`3Gool0f?oo0=Woo`3=ool0booc0<Sgi02Idk80T<FG09_8T`2j
hK40a^g80<gde@3@m]H0d_KG0080b_?C01D0a?7D0;WV`02fiKl0^>W90:oS``2ij<H0]^G00:kN]`2b
hl80[N700:SN_02DcZP0Q<2G07jgR027`9H0PknI07RlWP1a_:d0K[Z^06ZaT`1LXG`04P00000203/0
9`0W03D08@0f01d0=`0K04T0?`1T06T0JP110<B9P`3HXI00h:^>0>BdY03V^[@0h;Fc0=FX[P3FZJ`0
j;bc0?W=_@3of/80onC50?oYa`3oi/00oN>i0?SQ]03ahZl0k=nY0>cR[03]i;40g]VO0<C3OP35cHh0
c=VO0;W?UP2hdY`0[/B8096_K`2/`H40//ZB0;7DZ025/h80MZ9]0080Y/JN00<00<c4000000000000
60000000302`0000000000000000<eX0<3Z00000PP2QQZh0i/3@0>6jc`3;Xi40b=:U0:VZZ080Y9Ri
00<0[7V>0:NdV00000000`0000001@1]05/0WUmQ0:EV0026B@006QH^00@0000000@0<bM30700002:
`9l0Xl@0700000001@2U0000fJ2A0<Z<M`2nO640ZF9503400000303oool000X0ooooD`0000004`0Y
0000B`0007D0001g7P00O2<007XP001f7@00M1d:07HO2`1h8@d0N28@080[6022;Q/0PBdJ07l[6@27
=2<0T40`08lo<@2@@CH00P2AACX0802=@CX0QC/j08<i>`1o=SX0OcLl07/d>P1i<SX0NS4h07X`=@21
?DH0Te9J09ePJ02QIW00WfA^0:A/M`2/Mh80]8JD0;R@W`2gSil0]hjN0;ZAX02mU:40_IFS0;fFX`2n
VZT0_ij_0<R[^`3E^lH0g/C>0>gBf@3]e=/0ooK_0P3oooT01@3ooo/0oool0?ooo`3mool0k?oi0080
h_oG02L0eNjm0<c/_P3ClLD0d>k10=Oa``3KllH0b^^m0;WS]`31ik/0^^Fn0;GR^02bh;L0[n;10;oZ
a@3@l//0g?oD0>Kof`3/omX0j_g?0>ood03fom<0mOoL0?Goi03aoo<0jooo0>Goo`3Fool0e?oo0<Ck
lP2ajMT0Y=k609OA[@2Kc9/0ZM6J0;oV_03;lm@0bo?C0<oee@3=mMT00P37lmX0502nj/T0^>Fn0;gZ
aP2hj<L0/^G40:GL^`2Vf[H0XmVd09oG]02NekL0V]>_08G1V`22_940R[n>08FmS`1a/hl0HjjJ05n^
X01S[YD0BYEe4P000000:P0o02`0=00P03@0800W01@0F`1=07L0O01dEHT000000;80N03I09L0f:6=
0=nXQP3Q[I80i;>U0=NWYP3AXZP0fJ^^0>Vl]@3jc[T0omNj0?oP_P3oi/<0on_70?oX_`3dh;00kmnZ
0>_MYP3Xfj<0nNVk0=RlOP2o/6P0`lR70<7?T@2hc940/<V?09>`L@2E]7D0VKAf09>mS`1k[7h0F91W
002WP1/0000000<0L2i008l0000[00000P0000002@0;WWh03VaQ0000S01g0000[0000<Z?P02nPf80
000005Z?V`0208V_f`030<?mo`3E0000000000<0000000@0DP0005L0001S0000Y@290P000000101U
ZjD0C@0006l0002F0002000000030<;Jc`3Xf:@0000001P0000000X0@`0i0;IfJ`3`dK<0o<fe0?Bl
Y03oon<0om_;0>2f/P3P[`00RTH0;P00000<0?ooo`002P3ooom?0000000G06P0?01Z0000C@0005l0
001g;Bd0RD900919A@2A@2/0SSTO08Tc6P23;AD0PBXD084[5P21;1P0P2`K084^7`25<B00R3DR08Xf
8`2C@Bh0Td<a0910<02>?Bl00P29>Bh08P1k;B/0RSdf091:BP2@BT/0T4Y<08i9C@2:BE<0RDQA08A5
E@2ADf00XfM]0:M[L@2ZLGP0[WMo0;9mQP2hQi00_iFP0;^@W@2hS9T0]XbJ0;V?W02nTih0`IVV0<:L
Z035X[00bZbj0=>iaP3J`</0hLO@0?CIgP3ok_00oooh0?oomP3oooD20?oomP030?oom@3oooT0nooM
0080gOC902L0cnk20<S[`03Dl<40gO?40>CfaP3Mkk`0an6Z0<;S/@34i[H0`>Fg0;gT]`2jiKd0`n_7
0=Cdc@3QomD0k?oN0?3og`3^omD0kok?0??od@3fom40oooC0?oof`3nond0n?oo0>[oo`3Iool0c_ol
0;__g@2Wh<L0XM^m0:GI/P2YeJ<0/]RU0<C/a`38lLl0b_;A0<SbeP34lMX00P32km804`2ljL@0^>K1
0:cP_02Zh;l0VmJg097@/@2Bck00U]>d09OD]`2Cd;40S/VS08K0UP22^hh0P;J407J_O@21`Z40LkRO
06^`T013S6P04P000000:@0m02l0:00C02/0600[01P0J@1S07m@MP1mCW@0F0000<64O`3DWI00ikBP
0>6[TP3LY8L0dIEk0<V;N@3?Ui00eJ:P0>Zo^03_a;D0mLZc0?O@[`3kejl0on>m0?oZ``3ojK/0k]VU
0>WAV03[gZL0i]RN0?o[`P3^fJD0fl^>0;ZfKP2la840a]>H0;76R@2AZVP0PJQ_06jOK`1BTG0005M3
01/000000100IP0k07HgD01o@EL0KS=A09eXO`2DDU@0YfIE07RBC`000000aiBF0>6c/P3/^k40hKFf
0=Z_Z@3O/:00dj<00P1K00030000000C0=<0003G0000bj=/09YV002B0000001R0>80`03ojm00i/VH
09YN002HECH0T4M009QCFP000000LIG70:ODi@3Sd[X0gL6>09P0000G0000000;0?kBdP2Ua=/0l>o?
0?o/d@3oonh0ooog0?ocmP38`=<0el;C0=Va003=0000;@00000<0?ooo`002P3ooom=0000000I0>3R
_0000000?`0S06/Z=P1h>TD0Pd56099@D02EDE00TT]708i4?P2AACT0SSl`08@b8`1j9AH0Ob/J08La
6P2:=1d0S3LP08hi8P2>>B<0ScXT094m9P2;=b@0R3HV08dj:@0209I5<`0Q09U:>`2RFe<0Y65M09iJ
F@2IE5D0UUEK09EHH`2HGVX0WV=^0:Q_MP2_MW/0[gEi0;1gN`2eOX80^hF90;n=T02mSI<0^h^D0;V;
U@2hS9P0_96L0<6FW`35WZP0bJF_0=6^^03G^<80gL7;0>;8d03Xc]D0m][M0?ocl03ooo<0ooob0080
oooa0P3ooo00:`3non@0fOc?0=;abP3BlLX0`^[20=?```3Lm<H0hoO90>[ibP3Ej:l0a]bO0<;Q[@37
ikL0anVl0<WZ^`3=kL80foK<0>GoeP3/omd0l_oR0?7of03]om<0l?c=0?;mcP3goll0oOo@0?kog03h
onX0kOoa0=gom@3>oo@0aOOY0;;Vb02Xgl00Z=fh0:[M]P2[g;H0_>O10<?[a037kl/0`Nk@0;_/e02i
j/d00P2gj<P04@2Yg;H0WMB/09OB/02Ie;@0U=2_093=[@2Ad;<0UMBj09OC/`2Fcj/0S<JN08[1U021
^8L0MZii08BfP@2DaiL0OKR>01<0000000<0;00D02/04P0g02D00P1S04T08`1j?e/0PDIP0000002G
0000h;2Z0?2o]@3nbkd0lL6^0>VhX@3V]9d0hJjO0=j/X03X^J`0lLFj0?O:_P3oflD0on300?OG[03k
g[@0oo350?ooe@3ni;00ilN<0>cR[03/hZd0mN^m0>gY^@2LXUH0]kI]0:Z_I`30c8`0W;Qj07RJF@15
PEP0;7=H01/000000180E@0K07dkC@26AEH0QDQN07Y2HP1/AGL0WWBI06/0000B0000RP1V0>bc/@3o
cLT0nL_50?oEcP3jc/`0mL[70>k5a03@XYX207P0000H0;amN02[JFT0aI>20?ooeP3Z0000dL260;FG
NP26000000270=^a_P3oiLT0n=fg0>W3V`2nYjH0[J9U0000003ffmd0V:cN07RQc@3;`LL0l[nZ0<J<
I`2=B@00D@005@000000303?eP00`nG30=;af03LooL0eooo0=3lk`36hNL0[l_c0<39kP39`M`0l<B/
09E/02`00000303oool000X0ooooBP00000206:bc00J0;cPh00o0180GP11089GM@20D6P0PdaN08=6
DP29BU40Pd5708U0?P2=A400TDM108/o=`1n<2/0PSD`0914?02JCT<0VDXi09M5<02FA2h0UD8/09Q5
;`2NCST0YEM30:QLBP2_IeH20:aSDP0O0:=GA`2REdX0WUE=09M?C@2ABdh0ST]C09EFH02UJg@0ZW9j
0;5iO`2bNh00/7Qm0;AmP@2iQ8L0_hb?0<:AU@31TIH0_i6I0;jBW02lU:40a9fY0<^U[P3?[;@0e;6h
0=^i_P3Va<P0k<gA0?;Be03ie]H0on;O0?obiP030?ook0050?ook@3oon`0n_oP0=KodP38l<d00P36
k//09`3;lll0g_G80>?hb`3Ynld0go:o0<CPZ02nf9`0_]jX0<GV]`3DjK@0e^jl0=geb03Vo=<0kOoK
0?Coh`3`on40j_oM0>WofP3YomL0kokB0?Cod@3ioll0kooA0>Gof@3Fo]l0b?SZ0<Ceh`2lk]D0/nK6
0:cO_02`h;X0]>>m0;cXa033kL/0aNk90<G[``2njLD0/^O>0:_Sb00209gH^P0@09;?[P2DcjX0X=Rf
09KB/02HdJ/0VmFe09oJ_P2OfKT0WmNc09C>Y`2CbI`0Rkn?07ndO`25^HH0V/NB09?7V1<0000000@0
900C02h03`1902`0FP0`0P1O6Rl08@000000PT]V0;Z<WP3J[[<0l<:h0?o?`P3of</0olfi0?W9]`3f
aK@0k/2^0>fo[@3``[80n<Zm0?kAa03oiLh0onFn0?WM/03efJX0on^l0?ob`P3ooLh0l^fk0=OFVP2l
_WL0inVg0<[FWP2W]6h0^<1k09JPEP2[^WL0MYaO02iZ?P0F0000000>05D00027JHT0Tf1m0000002]
07T0KP0]05l07P1f;SD0Qd=<08U6C`1i=T@0IbTn089;J02:FWL2000000090?l0`03ok>H0oo;c0?o]
k`3oh>H0omkU0?oIhP3acMP0/hRQ0080m<oG0P3oool02@3oooH0oooQ0>g^`03Keil0gL2@0:P0003R
0:L0oooW0?oojP02000000030=OUc`0000000000008000000180NZSB001^F`36Pg@0_gmR0<>6H02b
LD/0ZFE309eG>0280000G`0005/0001k0000P3<^070U:P1i<cT0Xf5E0:<0001F000300000080W000
0100hP000>>eS`3T]8l0dlF<06=n002ch/P0^^SH0;G/jP2Pf]`0U<o507Nb^P000;l0B6b/0:Zgj@3f
eN00_Zig;000000<0?ooo`002P3ooom90000000M018M>00c0000A`0005lC501[9Rh0QTaH08I@H@1n
Bf40H2M006T/@01c=DH0PSe208Q3A@2<AdP0STE008Ll=`1o<bh0SD0g09U>A02JCdD0VTi109Y;?02K
C3X0XU<n0:iRB`2eK5D0]FeI0;5YF@2hM6H00P2aJed03`2YH580WE9609eBAP2HCTP0Ue1>09mJF@2[
JVT0ZW1f0:mgO@2^Mgh0ZgEm0;1kP@2fPHL0_8^@0<>DVP020<FHWP0F0<>IX@32VZH0`9b[0<ZX]03E
]Kd0fK[00=jo``3R`lH0kLkA0?;Be03je]D0omWG0?oXf03omMd0oooS0?ooiP3oonL0oooX0?WogP3A
ol`0`Nc80;o/bP80a?7B00l0eOgL0>7of@3VomP0g_K:0<_Z^P2ffjH0]]JK0;oR/P37jl40fNR]0>3a
_P3Wn/l0j_oG0>cogP3Zon400P3Von805P3Uon00i?oN0>WofP3`omD0jOcA0=gfc03?l/h0`?7K0<7d
iP2lkmX0^N_?0;KWa`2/gkT0/^6j0;kZaP36l<l0aO3A0<G^c031jL00^>Bk0:gR`P2NfK`209GA/@0?
09G?ZP2Uf[H0Z]fh0:GH/02Vf;00ZN310:GL_@2Vg;P0XMRb09gAY`2BaI@0QkV508RjQ02McI`0TLBD
01<0000000D04@0H02H07`0j02T0?00U0540:0030000000N0;ZCZ`3C[KX0jL2n0?;5]@3od;l0omk<
0?oJb`3oelT0om;60?_=`P3eb;X0llNe0?K:]03jckD0omo30?oZa03oikh0n=j`0?7KZ03^gJL0oooE
0>_`^`3EcY40g]jV0=cW]02mci<0^<Z<0;S5Q02AXEX0Ki=E5P000000502bY:H000000<CdiP000:P0
000/0000000]0000HP0B07@X9@1e:RH0M@0Z06006`1`9BT0Kb8P04<0002:0000b9RX0?oAb03on^<0
ooo/0`3oool0103omol0on_o0>[AjP3SaM`20?3LfP80oooo00d0oood0?ooh`3^nM40imZV0>CBW@00
02D0o`380?ooeP3oom`000000:b9[@3:^Z`0i000008000000180akEo002mQ@0mNj/0ZVQ10<B9H@3E
/H00eZf00=>UP03AVGl0dYV:0:e[JP2iNgd0_X>90;^2R`2fOXX0cIZT0=JPV@2lOGP30000000C0;>4
K`3O_Y40gkjA0>C0TP3Y`iL0jKnI00000000YHX00<Bd06>YW@1SZZ@0LkNa07o1^`23/MH0001V075i
_01TO;l0hMKL0;2jTP0/000000`0oooo000:0?ooodT0000001d0600l04H0001b0000PCi308Y0>P2:
A4<0RTQ<05X0001H0000G00006lY;P24BUX0QCm108@e;01o<BX0O30/08@e;@2CAcd0UDPl09E7>P2E
ASP0XUE30:QJA02gKU@0`geQ0<5lI02mN6D0^gUY0;QgJ`020:YTF`0W09]BB`2ID4X0Ve580:ALE02/
If00/FeV0:i/J@2]LgH0[G=g0:ifNP2dOX<0^hF80<>@T@39VIX0c9nR0<fRY@3:Wj@0b9nW0<RT[P3:
[;T0eKW30=o7c`3Sb]80i<[A0>K;dP3/dML0l=?H0?KFf@3of]X0omgK0?oofP3oomd0oooP0?oohP3m
omd0dOk90;gY``32k<P0a>o?0080aO;G02L0eooU0=Kmg@3Cm]D0_>>i0:_IZ`2YdYh0`>>c0<G]a`37
jK/0d^Ra0=[``03Pn<h0hokH0>?ogP3Son40i?oS0>Koh@3Voml0i_oM0>SofP3So]D0co780;oYa02d
j<`0^>gG0;[_h02fjm<0]NS;0;?Ua02]g[L0]>>n0;g[b@35lM@0a?3C0;oY``2ehKL0Zmfg0:7I]P2U
fkP00P2YgKP03P2ei;l0^>Fn0;GQ]`2cgk<0]n6e0:gQ_`2[gk`0Y]Ze0:7F[`2Gbih0Rkf908BbN02D
aYD0MJn1500000001@0K01D0@@0`03<0801?02`0=P0K0080M45V0100]hnY0=>ca03V`l`0lL[90>o5
_03]_jd0n<B^0?G4/@3gakP0l/Fh0?32]P3[_Jl0k;na0?75[`3hck00nmVc0P3ojL40303oj;l0lMj[
0>kLY@3gmL<0kmn[0=SDUP3Af9d0`mBJ0;?;T02gcY<0[/6108bRGAX000000140MRXM07``9P22=bd0
RT4j09MABP2EDE80P@140:P0N02iQ9@0/H6G0898HP2^P9X0fJjm0?oKf`3oon/0ooo/0?oom@040?oo
o`030?WWo`3@bnd0jLoX0080mooo0240oooo0?oomP3oond0mOoO0>Kic`3Jj<00fm^`0000003de/D0
onc904<000000000D`000:d0002k0000WP000000002VZG800;nT0;FgQP3B^hL0^i1D0000003Hik/0
0@@60000002d0000^@000;anN@2lOh00[6U/0:ANH`2]K7400P000000103fbld0oo[M0?oojP3oomd2
0>cbc00?0?GdbP3im<P0oNK60?d0003M/m00_IN]0:MUB02T`hd0Jjo005^K_`18MJ`0002g0000o02B
`?40^M:`02d00000303oool000X0ooooB@0000007@0D04H0?01B06DjG@1hAEh0LBlh06DD3`000000
L00008<0002ECTP0VEUJ09eSJ@2>BDT0IbDd08Dk>02;?cP0SClh08i0>02??c<0Sch_09A2;`2TE3/0
^Fe?0<n8H`37PF@0_gUS0;E_G@2]IUT0Z65G0080WEIA02L0VEEE0:9OG@2^KFT0]7=_0;IeL02hMg40
/g=^0:m`KP2eN7P0^X610<2:RP39UI80cYfJ0=6SX@3DZZT0djZ[0=2WZP3A[;80dkBl0=FlaP3Pb=00
iLkF0>K?e`3WcmL0j]7I0>kDf`3^eM/0l]OL0?_Jg@3og]h0oo3N0?oog03oomX0oooK0=WoaP2ii;X0
_NNo0<7Za032k/l00P34lm`09`31lmh0`O7H0;;S`P2LdJT0W<jQ0;GN/`3:kl/0b^c10<cZ^03<jKH0
dno00=Sfc@3No]/0h?oP0>7oi03Son80i_oP0>OogP3Vom/0gocD0<C/a02^h;/0XMVh0:GQcP2/i]L0
/NWG0;3WcP2_iLP0[>6o0:oP^@2`h[l0`^oB0<7`e@2jj/X0]n:h0:GH/@2UfK<0[mni0;WW`@020;oZ
a@0=0<?[aP2oiKL0_^:b0;CM[P2ch;H0Z=^d09gAYP2Idk40U<^R08k1SP29^840S;j<06>QM@0E0000
000502h0900S01H0@@0Z04D0<01G04/00P2[O9D07P3:X[80g;W40>O0aP3Q^Kh0gkBa0>Vm/`3X^:80
jKZY0>ViZ@3W]ZP0iKFX0?31/@3ca[@0n]2d0?[D/P3gfJl0n=na0?_U^03kjKd0l^Bb0>cMYP3VfIh0
hm^R0<g@S`33ci40ZKmo0:_8T02WaHd0MIiT02eR:PT000000P1700000`2CFW00[7bC000000070000
000F02d0001g04<0T4eA0:9RI02RHFD0SdY?07T]9P28?2h0Rd0c0917?`2ABdT0V5EI0:m`K`2lPX80
Te]d08aGM@3AWJT0omGJ0?ooo`3ooo`0oooc0?oom080oooo00D0mooo0>Soo`3EhOl0_/Kc0<WNo`02
0>7oo`0W0>Soo`3`oo40jooV0>goi0000000_^[K0?ooo`3oonH0oooH0000002MNIl0]8>I0>?0c03l
cK@0onS90?_K]@3T`Hl000000;OFc@00h/d00>K30=gLZP000000>XJD02YcT`000000I@0008T0002F
C480UDa;08m5B02ED5L0Kdb00000002mUkD0oocZ0?ooo`3oonD0hoOA0080l?oH00l0m?oR0?ooiP3o
ool0o`000?ooo`3Al?l0T/:b0:cMi`2hhO<0V<CS05=[Y@20T/40^oCo09kE/034i[l0;@00000<0?oo
o`002P3ooom90000000M01`0D@0b05/0DcAT060lI`000000GQLQ07H^;P2DBd00X5E40:5HB`2[Jf@0
W5mQ06XaB01m?T/0TDe=08U1@026>cP0RShh0995>P2PDd80[F5:0;Y_DP33N5L0aGYH0<EkF@2oN600
^W=P0;1YFP2YHUL00P2TH5`09`2WIVD0/79`0;]nN@2jOW/0_81l0;YnN`2iOW`0^h610<2:RP32SXl0
aY>D0<jNV`3CYZ<0eJ^Z0=N_[`3I];H0fKBg0=Zj`03N`<D0h/G90>W=d03XcM80ilkC0>S>e03Xc]D0
o]_L0?oTh03ohN40mOcS0?_nh`3oon<0oooP0?Sof`3Ro=00]=ja0;SR]P2mi[`0_>O00;k[c0020:cW
fP0W0:[TeP2Kel00X=Vi0:;E[02[ejT0bNo:0=;dc`3Fm<X0e_?70=7]_P3Dl/P0fO[H0=gogP3Uon@0
iOoV0?Gof`3`omP0i?oJ0=omf032j;`0Zm^a09cAZ02OfKl0V=_@0:3Oc`2_im80/NK<0:WRaP2ah[l0
/>6l0;OWaP30kmD0]^[@0;7S`P2Xfk@0YmZc0;GP]P2ii;/0_NS10080aNg700`0^nJo0;?M[`2YeZH0
Z=R]0:_L]@2Mcj40T/bW09?@/P2EdK40TlVL07n_MP15Rf<E0000000602<05P0_01P0?`0W05<I?`1W
<5@0RUId0P2_Oi007@3AY:`0eJV`0=2U/03@Y[80gkFh0>Zn^P3Y^:P0i;>R0>:^WP3R/:00hk:U0??5
/P3oekh0on?20?oM^03jgK80l]JS0?GR/@3fikP0mN^k0>WQZP3QgJ80e]JH0<G<R`2]_W/0WkYl0:34
S`29/W/0A7Hn00T0000000H0A@0[07`mC01l?D`0^WYf0?Bh]03Y00070000000D06@0C`2LHW80fJb`
095=C`21>T40?P00070R402>ABh0/6iC0=FOS`2EDe@0RDE;07lh?@1]8RL0Q3`h0;EgL@3R/:X0onOL
0?ool`3ooo@20?ook`070??olP3Uoo`0fooo0=Kio`30f_l0^]Go0<STo`020=Kio`0C0>3oo03Io^`0
eOSU0=Gef@000000ZKcC0?ooo03oonX0oooT06eVYP2//nd0gn[o0?oao`3ol]H0ooC@0?WX`03/djD0
Y7@007hf00030000000A07eVS`23FWP0/W=c0<n?OP37S7l0bi650=RMS03AUXX0g:VS0=BPX@1jM[D0
ZZCD0<_<o`3oool0oooe0>7Z_03]j/@00P3^oml0403doo<0oooh0?ooo`3oool0mOoo0>OomP2Md>D0
/=c^0;SIm02R/]/0002@04Y/[P1XVJ`0JJR505FJP@3GW`0/000000`0oooo000:0?ooodT0000000<0
8`1M00000012<6`00P000000602QJg80Zg1_0;AfK@2dLVD0YEeA09E>BP22BUX0QU1S099HH`2=D5T0
QD=<07/c>@2^KfX0]7=X0;McH`33P6X0bhEX0<V0GP37OE/0aGYH0<9hF@2oMeh0^WET0;QdIP80/VeS
02L0^7M_0;n2N`35S8H0`h^70<::Q`33S8X0`hf<0<B@T035Ti@0aiJH0<bMW@3DYjD0fJj[0=Zb/03K
][H0gKZk0>2o`@3T`lD0j<O80>g<c03[c<d0j/c>0>W<c`3YcM40jLgC0>k@e@3oiMl0onoV0?ogj03n
onX0l?oV0>OogP3NnmD0a>Rl0;SQ/`2niKX0_>Fk0;OS^`2]hlT00P2Yhm<09`2]iLl0[nK>0:kR``2`
g[D0`NFh0=KecP3Mn]@0go_D0=Oca`3Fl<80foK@0>;of`3[on@0k_oW0>_oi`3`on40iooP0=goe`38
kLD0ZMNY0:3@X@2cg[@0_^c=0<?`d`32lMT0_>kE0;WZc@2gilH0]nG00;7R_@2hjL`0/^S?0:_Tb@2X
gK/0YM^h0:kO^P2ahKd0]NG00;gYa0020;[V`00:0:WK]02Ne:/0WmB[0:oO]`2YeZL0W/ZE08W2V@29
aZ80S/f`0937W1H0000000L06`0002P0400n0280FP0_07<eC@2EFfl0Z7>70080]h>B01`0`HV?0=:N
WP3R]K40k/:m0?W<bP3od</0j[bc0>NfZ@3T/Il0ikJS0?73[P3od[T0omZo0?oS`@3ogkT0nMZ_0?3B
W`3]e9d0lN6^0>[QZ`3Uhj`0g>2W0=?GVP2o`gh0V:eX09FgO@2:/W`0E8E<1P0000001@0i0000G00_
000000000000KcEC0080X6=V00D0RTU?09YKJ02[d000g>;M0;b=00040000000N02`0<@2@06X0h;>_
05PE;`2QJ7T0VV1/07d0001P0000a8^;0<nGR02lOEl0?`0005`00028@3l0[f]L0<67KP3?V7T0jl6Q
0?o]bP3oom/0oooU0?_oi@3YonL0g_o^0=;hm`3;l_d0aN[o0;CEm`2Ubnl0[MK`0P2ki_@03@3@n_/0
fOog0=7aeP31hKT000000>Koo`3hool0ooo]0000IP1oR<L0Z;SZ0<kPo`3Qj?l00P3oool0503om<l0
onBl0?7AY`3@W`00/g970:aY?`2YJ3P0UeHO06aNSP3G0000lP000>?<`P3`j]X0oOGQ002i[P00Wj<0
00000:>]h@2]]nP0b]?o0P3oool05@3ool/0onS20?oR``3oh/<0om_20?S?]`3Xa:P0jMng0=gA[@3:
^i00JJ;:08VkgP000000b@000000EP0gIFL0I9W108:lV02S``0000000=Fb000[000000`0oooo000:
0?ooodH000000200D@00000000000000000002l0001C0000P4mT0:MmSP2WNHL0YG1i0:YaL`2dLfP0
Zf=D0:1JE02BF6<0PU5[07a:I01f?eL0L3120:edM`33T8h0bI>;0<nGR03CUX40dXm_0=6:I@3?Qf@0
c8AR0<R2I@2oOF/0_Wib0<64NP80_h=l02L0aXf70<N>QP37SXD0aXf60<F=Q`36ShX0ai>A0<VGUP3;
Vi/0cYnO0=>WY@3Q]Jh0iKbd0>Fm]`3T_KT0i/6n0>G2`P3Ua<H0j/W90>_<cP3Zbld0j<W;0>O9c03W
b/h0j<_@0?SCe03oj^00onoW0?odkP3kon`0i_oR0=Che`3=l<L0^n>g0<3V^@31ik`0_^Jk0;kW_P2n
jlX00P30k]009`30k]<0_n_90;gX``36jl40eo?70=_gcP3Mn]@0f_S@0=Kaa03Mm<P0i?oD0>gog@3b
onD0l?oV0>ooiP3Won00g?oE0<obbP2dgk80/=ZY0;?JZP3Ell/0fOO@0=_lfP3En=H0b_;A0<3/c02n
jL@0]nBm0;3R_P2]iLd0Yn360:CL_@2Rf;80Ymfl0:_P`@2]h/<0/^C30;CS`0020:KJ]00:09cC[@2S
f;80^>Bn0;OO/@2Zdih0Tl2707bgS01na:h0M[FC04V:Ga@0000000T0000=00X0000W01<0?`0S04l=
:@24@4l0RDA?09MHIP2XKWd00P2lQXl06`3AWI`0iKFa0>o4^`3^`[P0o<k80>:^[P3KZZL0j;Z^0>bm
Z`3ca[00o=2g0?oI_03oh<40omno0?oJ]`3heJd0l=2N0>gDWP3ZfJ40imZQ0>7NY03IfYh0a]2A0:6f
LP23WUT0S;9h05n>E00600000006060O<`1A02H0=@0@0540<`1h?U/0R4iV0P2305d01P0X00<0RP1R
0:elIP000000eJ2206/00080000001l0001C07`0D@00000000000:MgSP2dRJ@0/8Z[0<V[dP3C/=L0
l]3U0>bn_03a`kD0fZV80;9hA02fM5H0ah]`0=^[R03]bIl0jlVO0?OL/`3omLH0noo?0>Shd@3Ln=`0
e?OU0<oekP34jo<0]=gc0:gGl02Wd^h0YmGZ0080[^3W00D0YM[S0<cil@37jll0Z=Vo0<o?o`020>So
o`060??oj@0007d0O8k<0:Jjj`2ke?h0aNKo0P3oool0603oon<0onk@0?oP``3ecjd0i[fF0=j_R@3C
WGP0/gA700000023000000000:C1`@3>onl0h?oo06/P<0000000LVBR0:Bai@2`_^d0a=Oo0=cko`3o
ool0ooog0?oog`80onOH00H0m/_00>2[Y@3JWiT0kKZ_0=bXS02aLdh3000000060?ogjP3oond0o_?0
0>G5U03<i[h0dNJj0P0000000`2>PP0000000000000X000000`0oooo000:0?oood@000000280000=
02P00000000000000280000k0000F00007P0002PP9X0Y8:J0:EoU@2RMXL0WV]i0:AXJ@2`JU`0YFAQ
09]PJ02;EFL0R5=X09=PLP2HGfX0_8^>0<NKW@3@YJ80d9nG0<jDQP3ATgd0dXm`0=6<K@3AS6/0c8U^
0<>4M@37RW`0bY240P3:Th`09`3;Th/0bi>:0<R?Q`37ShL0bY><0<^HT`3=W9T0cj2N0=:TXP3EZJL0
gK>^0>_1]`3]`kT0kL>k0>c4_@3[aL00jLK30>S6a`3XbL/0jLc@0>W>e03Wb/h0iLK90??=cP3oe]80
on7H0?oeh@3oonX0ooob0??oj03FomP0a>g:0;gV^`2oikd0`^Rn0<CX_033j;`0aN[10<W_b`020<kd
d`0W0=3ee@3?lm00f?K?0=Sec03Hm<`0f?G>0=Sgd`3Fm<d0foG<0>Chc@3[omH0l_oP0?;oh`3aon@0
k?oQ0=ooe@3?lLT0`>Nl0;KO/02ggJX0eNg00>;fbP3Sm/P0g__E0=WhdP3>l/d0aNg80;oY`@2hi;T0
[Mjg0:GPa`2Vgl@0Y]fo09oDZ`2ah[h0/^C20;;Ua@2_hl@0W]Fa0080VM6]00P0[]jh0<;Za02oikd0
[MVY09[7TP23/WT0N;6604Z;HQH0000000T02`0001/04@0f02D0A00[07XjD02=C5`0V5EP0:]/LP2n
PhD00P3>VIP03@3O[JT0kl:j0?33^03]`K@0ejBP0<>9S@3@ViL0gZ^L0>fnY`3gbk40omJh0?oL_@3o
gkl00P3og[d02`3og[X0m]RY0>KAU`3TdiH0h]JI0=SGV@3@eYP0/lB4096ZIP26Y680MimS00H00000
00L0H`0n05LG<P1=3BX0HbQ607PmEP1Q04409@040080B`0N02L0P00_0:P0E@2ZJ5<0HA@@07lh>`2V
I4`0c000000000000280001Q06H0JP2gSZ`0aZ>l0<JZa`3@_=`0h]Cf0?GZo`3ghOl0m=3J0>k;cP3F
Xi/0[faA0;EeC035Rel0dj5b0=nhQP3W`Y@0kM:T0>gL[03YikL0d>:e0;OPa02kj=/0]NCR0:_Mi@2S
eNP0S<CG08g2g02McnD00P1d/<`03P1d//H0Z]kK06JVT02;`ZH0dM[[0>Ooo`3lool0oooo0000OP1X
Pl<0U[KV0:_Bm02ng_l0iooo0P3oool05@3om]X0on_=0?oS`@3mgKX0nmNg0?_B]P3U]Z<0b8]g0;em
KP2i0000Q`000:@0002_Lgd0VG2L091aX`2@Rl<0Z;OZ0;?3lP2jdOP0bn[o0>koo`020?ooo`80oood
00d0oo_o0?oQo`3ofn@0on?W0?o=d03@SIH0olOC0>GVo@3Uinl0ook^0?ooo`3fonL0j_6n00800000
00<050<O0>K`002Z[000:P00000<0?ooo`002P3ooom50000000Q0300000@0000;@0003d0001J0000
OEb309EkW@2LPJ00WGfJ09MaR`2CK8H0T6N10:AbOP2aNW`0XFYc09YSK`2HHW00UV9b0:QdOP2iR8h0
aIVM0=2Y[03>YZP0b9FA0<nJT`3BVHX0eIR20=FFN`3DTgH0e99d0=>CN03BUh@0dYb?0080dYnF02L0
ci^C0<^ESP37T8/0cYVB0=:PV@3CXid0eJNQ0=N[YP3J[j/0gK>_0>Nn]`3]`kX0lLNn0?78`03]aKh0
j/C00>c7a03ic/X0kL_<0>S;d03Xc]@0i/[?0>74b@3nd<X0omW?0?ohe`3oon00oooU0?7oh`3HomP0
`Nc:0;CS_02gi;h0^^K00;gW_`34jKd0b^^m0<o^`P3Ell/00P3Imm409`3KnMD0f_[H0=[jeP3InM@0
eoOB0=Ced03DmM40fOKA0>;hc`3To=80kOoJ0?7ogP3aon00l?oR0=oof@3>llh0_nS00;KQ]@2fgk40
cNbo0>Oic@3WmlX0ioG50=_db@3CllX0d_330<[[_@2ki;L0/Mnd0:kN]P2ejLl0]NO:0;3Q_@2ehkd0
]nFo0;SWa@2fi/@0Y]^h0:GH/`020;ST^`070<S/a038k<<0/]jb09[;V`26^880MjQ_001g000F0000
000:00T0100B0180>`0[03X0601V:4L0P49J09YFG02`LGH0]7Ih0<:6Q080b8b301T0cIB>0=BNVP31
QX@0YF1R0;5]J@30P7<0e9V10=fVR@3[_9/0m/ZX0?oE]P3ofk/0omfl0?oF]03ofKT0omjh0?[S]P3J
e9P0gmNJ0=S?S`3:cH/0_LN50:6iM`1nVU@0Ni]I00D0000000T0>`0Y05<I?@1=3b`0K2m:06`bD01/
;dT0H00004H0:@1I8dX00P1kFH`09`1iEhX0PeMk0:9ZG@2kPEh0aXe`0=JeR03WfZT0fmRS000FG@00
04/0VP3R0>3No`39/]<0b[KG0=>og@3Jd?<0f]7e0=oAk`3H`]`0j]Cb0>_Bj@3O_ll0a8mZ0<ZGI`35
T5/0aiEO0=J/M`3RaI40i=BO0=[EV`2C^8<0XMK609_Dd@2Ecm80TLgA07Vj`@1`//80HJ>m056H[002
04nIX@0V06N[]@1LX:/0RL>c05iQY039g_l0e__i0>Coj@1><DD0001:05Ai^P20/]P0PkSL09_7k02/
gOl0gOoo0?ooo`3oond0ooSL0?o^b`3oj<L0on?40?oOa@3oe<@0j;fn0>Zd]P3_[jh0iJNU0>>//03L
[[T0g;S<0<bkgP2mb?H0^<Oe0;_>nP2ngO`0aNSo0=7oo`3/ool40?ooo`030?[fo`3oool0oooo00@0
oooo00X0iOoo0>7olP3QooL0i?ol0>7hf`3Nh:l0d[io09:1OP3EgJD0^;mn:P00000<0?ooo`002P3o
oom40000000R03L0?@0c0000<@0004h0001J?6`0Je5o08I_V02BOJ<0TgVL08e[R`29Hh80RfN609E^
R@2/Q9@0]8J>0:IePP2IJ7X0V6Qk09AUNP2eQX`0c9jM0<jRX@37VY`0`I2B0;j7Q@38Thd0f:NM0>:a
X@3R[i/0h:VC0=bQQ`3JX8P0fJBC0=FQU080cYV?02L0bY::0<R@RP3=VYD0e:>K0=NVW03HZJ40fZfU
0=fbZP3Q]k00i;be0>[1^P3_aKh0m<[20?;9`P3/a;l0m<W30?o@b03of<d0omC?0?7@d@3Wc]@0hlW?
0=k2b@3W`lD0onO;0?oof03iomD0iOoE0=7jd030k<T0[n6n0:gP_02ci<40^NK20<7Y`03=klH0cno3
0=Kaa@3Qml/00P3Km/d09`3CmM00d_KF0=Oif03Cmm@0coCA0=7ed`3Hn=D0h?WB0>Kld@3UomL0jooM
0>SofP3Xom`0g?oG0<cdd02jiKd0[mb^0;?P]P31j;l0hO[C0=ghc`3LmL`0e^o10<k_a039k<00aNVk
0;_S]@2`g[40ZMZ`0;KVa@2nkM00a>o?0<C]bP2mi[h0^^Jn0;_W``2fi;l0^^G00<K/aP020=3ab006
0=3^``2^f:T0TlNI07nfQP1i[GH0E8U@5P0000002`0900004@0?02X07P0o01l0HP0f07liA`2HDUD0
[Ve]0;QkO02jO7`0`HB10080cI>:01T0bXb20<Z=PP38Shl0`hV<0=ZUX03P[9h0iK6K0>NeV03[_9P0
l<FO0?O=Z03oek@0omZf0?WF[P3cc:<0l]6P0>?BUP3EeIH0fmZN0=SEU`2j_gP0Y[E`08nZIP1kUe40
<64W00@0000000X07`0K04hH?`1<5C`0KSMH07HnG01I04D0LT1U074jF`1lDh00R6VI0P2@MZH09`1e
D880[0JU0?k>^@3fajl0i<6I0;^TH02dZVL000000020]00007h0Rho>0<;3o`31]=/0dL3P0=c8iP3R
d>h0gMGn0>3Jo`3Pgol0i^3o0>GHo`3Kd^h0loG/0>_AY@3G/h@0djj20=:eOP37ZfX0cLZ?09Z[J`1c
ZH<0QlBm08S6b@2HdM@0Um7C09[Ce@2CcMH0Q<3@08?1c`0208G2c`0W08[4d`2Fb^00_>KX05I_/@2R
aNP0`^_W0<;WiP2ni?400000001FT000X<D0KJS?06NHb`1YS//0UZk/0=C6i`3oool0oooc0?omeP3o
mM40onc=0?oMc03oe<`0olo>0?oNf`3oj>P0om_M0?oEg@3eeNT0n^go0>g_o`3@gol0a]So0<3Ko`2j
h?/0]Mkf0;GNn03;ool0iOoo0080l_oo00<0mooo0?3_o`3eool0103oool02`3Yl</0i?oo0<kom`34
lNX0d_[j0=CfhP3Fi[X0f>Bb0<[HW`2fdi`0//>702X00000303oool000X0ooooA00000008P0g03d0
<`000340001>0000FSa/06]AO`26KiP0TWfS09=iW02=Jh/0RF>208]WQP2EKXT0[8BD0;B6SP2VMH80
VFQj09QXN`2DIGX0]HJ<0<bNW@3>XZ40aiZL0<6@TP2nQhD0b9>=0=RWW@3R/J40hZnK0>2YT`3LXHL0
fZ280=VTT`3EXI@20<jIS`0W0<ZBRP38T8X0cIZE0=BSV`3GYY`0f:VQ0=Z]Y@3M/ZX0hKN`0>Bl]@3Z
`KX0klFn0?C:`P3bbL80k<Bo0?C9``3od<P0omS=0?oDc`3ad=40ilkD0>?9c`3N`/T0il?50?oWb`3o
omP0nOoE0>Goe@3An]00`>c90:oQ_P2]h;`0/nC10;WV`P31jL00cNo60<o_``3FlLD0hOO;0080foK=
02L0doG@0=;feP3GnMP0doOD0<odd@3AmM<0f?SE0>3idP3Vo=40iOoG0>_og@3XomX0j?oL0=coe`3<
m=00^^Fm0:oL[P2ch;H0`NRo0>7jd`3Mn<l0g?G<0=K_`@3>kl@0bNc00<GY^`2khkD0/=ja0:WJ/02f
i/D0_^g@0<C_c`34kLX0_NJn0;[V_P2kil<0]^Bo0;[U`036k<H00P3@lLP01P3@k/<0[]RY09?7V@1o
]XH0NJef05B9D1H0000000/02@0001403`0Z01h0?`0O0680=P1o>DL0V59E0:i]K@2hNg`0^Wal0<64
P@020<fCRP0I0<Z<PP3:SH80b8n?0<>9S03JYJ00h:bN0>FaV`3W]IP0jkbH0?35W`3gcJP0omNd0?oJ
]P3ieZh0llbS0?;AX03SdYH0eMFF0=_JWP3HeIL0^[mh0:JeL02?ZVH0NiMA031Q9`040000000:01l0
6`1>63l0C1Dl06hgF01f?U`0F@150790I@1a>U/0O5>008QYV@80T7JV02L0ME220:`6Y@3nc[T0m/N_
0>C1V@2kY600]:YW00000000P;@0001n08^?cP32`ol0`KCK0=70h03Lb>H0h]3^0=gEoP3Pf_l0h=oo
0>KPo`3Uf?l0fm;^0??ek03[dJD0ek>40=>^PP3B]Gh0aj]Z0<g:S`2JZf/0LjV308O4_@28a/T0V=7D
09OAd`2JdmD0TlgF08C0d023`Ll00P25`/l09`2:a=<0U/[P0;cVj01FKk40X/GX0<;[i`32inH0_^Ca
00000000EY000:3506fXc`1WV</0JHk;09J^k03Da^L0oooo0?ool`3ooMH0ooGA0?o/c@3ogL`0omC<
0?o?cP3og]/0onSX0?oKg@3oeMd0mMGY0?[]o`3]kol0d=oo0<KHo`30fol0^^3k0;GNmP2eg_P0booo
0>Goo`020?;oo`030?Ooo`3`kol0mOoo00@0oooo00/0jO3;0>Coo`3>ooL0a?7Z0=;jnP3Dm^80e^Jj
0=ST/P3:f9l0]]>L0;;3Q`0Z000000`0oooo000:0?oood80000002@0>00001`0:00d03l0>QeC04Xc
J01VD800IEV?079YWP28NJH0R7JQ08M`V029K980R6V>09=bT@2NNY@0]I>U0;NBX@2YPI<0Vfn608mP
M`2JKH80`I>G0<ZLV`33Ti@0_8Z>0<>BU036UI<0e:FO0>Bh[P3ga;@0ikNW0>BbW@3R[9@0g:B=0=BJ
Q`3<TH820<J9O00W0<V@Q`3>VI<0dj>M0=NVWP3KZIh0g:^P0=b^Y@3O/jX0ikZ`0>o2]`3dak`0ml_0
0?W<``3fb/80n<g50?oCc03of]40om_C0?oHe03heMH0j/kD0?oNdP3meL`0l/_60?ood@3oom80hOo8
0<kfc@2nj/H0/n:m0:oQ_P2hj<L0_N[70<;[a039k/L0e?C<0<oab@3Cll/0eoC:0080e?;700L0bO3>
0<Wcd`39l]40bo?A0=;geP3Hn]X0gocG0080iOcC01`0iOoL0>?ofP3PoML0f?OD0=3cc`30ikh0[]Z[
0;?O]02mikl0e_OD0=Ohe@3Dm]80d?;<0<KY_`30j;d0_nNk0;GO/P2cg[00Z]Z^0;GQ]`2njLD0`Ng=
0<Sad035jl80_NJk0;cV_@2ii;/0aN_30P3Ell/20=ceb`050:oEY02=`8d0PKZ=07ZaO`1WW6@05P00
0000300?00007@0B01D0000V01H0F1Pg06XW?`25@Dh0XemQ0:aWH`2cL6X0^g]e0<F9Q@80eIjF01P0
cYB>0<Z=Q@36S8/0a8V70=2IU03P[Id0k;fR0>o2X03aaZ40lLRO0?7:X03fcJL0nLja0?G9[P3cb:T0
kLbP0=[?T@3LeiX0f]VM0=;EU`2laH40TjMO08BNF01GP4050000000:04/D?@1>6T<0J3AI07]7J01N
04X0J`1M09mfV@2<H8D0TFjI09n4/080NEJ502L0XWNH0?oWjP3ol>40on7:0?;J/036^7P0_<6508Eh
/@3@h_L0002M0:JZh02MV<h0`ZoD0=G3i03VdNd0k=C[0>[Gn03]lOl0hNSo0=kXo`3Gfol0i?oo0?oo
o`3/lL`0iNBd0>W[_P3BdiX0];Mf0;BoOP1;P4d0SlJ^09G=a`2Hd=T0/^;U0;GUhP2di>00[=kQ0:;F
i02VfNH00P2/gNP06@2XfNT0Z]S/0:gKj000EI/0Tl7L0;;Qh`2ji^@00<340627/`2://H0000005R?
`@1=NKT0EgVl06Z3a02Xa^X0oooo0?ooo03oonL0oooO0?oojP3ooo00ooo^0?oljP3oooL00P3oool0
303on_l0oooo0?ooo`3oool0i?So0=7/o`39kOl0`nOo0;_Tm`2bgO@0^=on0;cUo`80boWo0180f?[o
0=oVo`3/ool0o?oo0?ooo`3lool0oooo0>[oo`3Eo^@0cOCS0<kgk`3?mo@0cO?Y0=;ad`3?j/80W;l0
07:cW@2]dZLZ000000`0oooo000:0?oooc<0000000<0L[Rl00000000000030000000901i0000700_
0340@@1QBg`0LF6B07UaY@1[IYl0LVbR07]bY@1jK9h0MV>B085ZU@2?M9T0W7jL0:V9X@2fVJd0ZXBG
09MZOP28E6/0V6Ef0:j0SP30TYP0`YBH0;Z;T@2aP8/0`9>I0>6k]@3kak`0om?20?;0/@3T]JD0gZZH
0=BJQ`3EVXH0f9j:0<jBP@80c96402L0dIZ@0=NVW@3L[ZD0h;6U0>6aY@3S/jD0h[BX0>Vk[`3a`kD0
n<Rj0?[:_@3kc<00oLk30?oAa`3oelh0omcE0?oPf03og]P0omgI0?[Gf@3Zc=40fl3:0?oWc@3oklX0
ooo=0?_oa`39lK/0_n[50;CR_02Zg;H0^n[:0<;^c`37l<l0`^g:0<O^b`3BmM00c_?@0<gbc`37k<@0
0P3<klL09`2ok<d0`no@0<WbdP3@mmL0f_gL0=gnf`3Ro]P0i?kF0>Cme`3UomX0hooI0=kje@3EmLl0
b^g40;SP/02gh;<0`>Ro0<kbc@3Cm]@0b_?E0<Sad034kLL0^^Jl0;kW_02fh;@0ZMNY0;GO/P2khkH0
`NNl0;kYa032kL/0aNo=0<7Y`@2miKP0_^Ji0<CY_P3HllT0h?S?0>3gc@020<CQ/P0408nmQP20]H40
R/2A05fDGAH0000000d05P0001H03@0900006`0C04T0;@1R7SL0OcM109UCE`2YI680/FaT0;]hJ`3=
SWh0dYJ:0080einE01L0cI680<:3OP35QWd0`X9i0=2ER03P[9T0k;fQ0??7Y@3dbjL0m<fS0?K?Y`3i
dJd0n]Rd0?SF]@3gek00gMZ_0;7@W@3KeIL0dm>D0;o7Q02S]G00RZ5I06J6@0060000000:058OBP1T
<ed0KciV05`ZE@1^?V@0VVj>0:R1XP2=HHH0SV6507=4K080QVJD02L0k=O`0?WMm03ooOl0ooob0?o]
a02XU@00^KA`0=c[o`3mool000000000o`2aUKX0`:_?0<o1h`3bgOd0jmco0?ooo`3nool0k?oo0=G`
o`36hOl0fooo0>[oo`3To>00j?K@0=oEW@2lejP0[Kmo07BCD@2[f;T0^>?90;[Vf@2[g=d0YMWR0:oQ
g`2`hMl0[n3T0:7Eh`2Fc]X00P2Bb]h0502Pd^H0[m[_0:kKk@000000T/GP07fba@2eiMX0]^3i0000
K01;=@00cN[90:g5j@0QE9P0:U>L05eb^@2U`^h0e_oo0?Ooo`3ooo/0oooh2`3oool0203[ool0g_oo
0=Koo`3Bn_l0cO?o0;_Qn`2_e_D0/=Wd0P34k_l04`2mfol0c]Wo0>;do`3cool0i_oo0<Cio`3?ooT0
cOo[0<oehP3Uon/0gOoe0=SonP3GooT0coKO0:;8TP0R@`00W=2e0<WS]@2AXEH0:@00000<0?ooo`00
2P3ooom10000000U08Xo<`000000=`1H06mOT`1hJYX0MVjS07YaY01`JZ40KFVS06m[Y01_II/0L62C
089bX02AOZL0W8R/0:ZE/`2WR:80WWN?09=YP`2AIWh0ZGnA0;R?W02jRY00`iNK0<>HW@2nTYT0fK:`
0>2j]@3obKh0om720>FcZP3EXYT0c9>80<>4N038RW`0cI200=:FQ@020=NOS`0W0=j[W@3T]j`0j;ba
0>Bi[P3Q]Z`0iKR]0>bn/03ca;H0n<Ni0?k;_03ocKl0olo10?o?`03oe<H0om_>0?oReP3ojMl0onKO
0?oTg`3geMP0jLW@0=^nb03M_L<0ooc80?oi`P3Tmkd0/Mb^0;GR^P2^g[D0]NG10;OXb@36l]@0coKH
0;KWb@33k/l0bO;B0<K`d@2hi;d0^nBj0080a>g900H0a>k>0<WbdP3An=P0gOoM0>;og`3Somh30>Co
f@80iOoH01`0f_SA0=;bb`2ni;H0^N2_0;WR]P35k<D0d_GA0<Wbd@2ok]<0`>g=0<7[a`31jL40_>Jj
0:[HZ`2dg[00`>Fh0<KZ_@34jl@0_^[50<7]c031kL/0_nW10;kW_034jK`0d_780>3je03Hm/l0f?;7
0P2QaY000`22/WX0W/N=06BJHP0F0000000>00X0000Q00005P0901T040120000HAhh06lY>`1o=C/0
T4@n0:ELC`2eKeh0`7]Y0<>0K030O6/20;eiJP0F0;=_J@2^JFP0^WI]0<b>O@3V]9H0k;bL0?33X`3c
bJD0m<bU0?C=Y03ecjD0m/nX0?OF[@3hhK@0kNRn0<gQ/02eahX0dLR30<k<RP2/^740Rj5H08FNEPH0
000000/0EP1@06LhH`1eBWH0KCiX05``H02WOil0Z7fJ08IFNP1a=eP0MCeN09YdV`020:J3Z00@0=k7
h@3XdN`0ol_50?ooj`3ol`00oNl005]Y[P2U`nT0a^_o0=[oo`36Zjh0[i6g0=Zoi@3ol?l0lngo0?Go
o`80oooo01D0looo0=Omo`35j_l0]]oe0<Kcl`3Ooo80oooH0<c7S@37eId0TZe^09O5X02hhlX0]N77
0:WKe@2[g^40X=KM0:7GeP2WfmT0ZMcQ0:CIh@2Cc=/00P2>aM`01`2=`]l0ZLo`0;KOk@35kND0elJI
06fU^@2Zgm@00`0000002@3Tll/0^l^B0=cee@000000DgJj08jchP2`jO<0g?oo0>Kon`0<0?ooo`08
0?Coo`3Zool0hOoo0=Ooo`3>lol0`^Ko0;cQoP2jh?/20;GJm`0B0:W5k`2ke?l0e^ko0>Goo`3>ooX0
NKf_08W7_P2jjNH0cOO]0>7ok@3YooX0iOoo0=kom@39k]00IH<000000035jlX0d^Je:P00000<0?oo
o`002P3ooola0000000301Y5GP010`@0000000T000000P1G00009`1i0000WEM:0:UUD`000000I5N=
06aVW@1aK:<0LfnV07]aX`1bK:<0JfZT06]XX`1[Hi`0Kf:G089fYP2DR;<0WHje09N4Z@2@M9L0TW2@
09=`SP2POIL0/8nT0;ZEY02eP8@0`Y6C0=6WYP3L][@0hkfi0>6j]@3R^;80kKB_0<:@UP2fP8D0`hf9
0=2IS@3JXY<0hj^I0>RaWP020>fkZP0W0?;3]03aa;L0k/:g0>Zo]@3U^k80jKjc0?73]P3hakT0oL^l
0?o>_`3od;l0om2m0?o@_03oe/<0omk;0?oVd`3om^D0ooCV0?oSi03Ud=h0elGF0=K1d03og=<0lO70
0=k]^@31gjX0Y=:S0:cJ[`2fi;h0_>_:0:cQ`P2nk<h0_>gC0:cTb@2nkM80_nkB0;;R_P2cgk<0_^O0
0080b?3=02L0c_KH0=Kmh03Pon80i_oS0>OohP3Yon40iooL0>Kof`3WomX0iOoI0>3ke03FmLd0_^Bi
0:oIY`2cgJ`0^nJo0<S_c038l<h0`>g>0<C^c@38l<d0aNc50;oW_02bgk@0/mja0<3V^@39jkl0a^_0
0;gW_`31jlD0`ng;0<7[b030j/<0`>W10<c`bP3KnMD0e_OD0=3cc`2Xd:000P23/GD00`2E_hD0OJU/
0000000E0000000;00/0000O00005@0<0140200e0000HbE505D0;@1/0300R3`l0:AJCP2kMV@00P37
QFl06P37QFh0_GQW0;A]H@2dKF40/F]R0;imLP3NYi@0hjnF0>ZiVP3/_9X0kKnJ0??:X`3ecZD0m]2W
0?C<XP3`ai`0kLNI0>O6S`3LgjX0h^Nc0=;GV`3DcH/0bL=n09nYGP2=XEP0Kha51@00000030125DP0
JcUP07I7L@1[>f@0G2]E09EYR`2R09H0L01N06`hFP2LKhd0]HVP0<BN]080bZRl00P0e;?60>Bb]@3P
^JT0o^G30?oidP3il//000000<[8n`80oooo00@0c:nk092He`3=bol0gLkk0`3oool05P3fool0fooo
0<oho`2/gNT0TlWO0:gOk@3Do_P0ho_J0<3CXP2ZaXl0FX000<?Zd034iLH0U/V[0:;Ea@2bhn80ZMgP
0:;Hg@2Yg=d0[N3Q0;CTiP2Zf^L20:?BjP0D08nlh`2Sc>d0^^7a0<odk0000900oooo0>OonP000000
0`Ql0000003?_Kh0Yhj/0=6h_01S0000D76d072Od@25^]l0_NGe0=7oo`3Tool;0?ooo`080>ooo`3U
ool0gOoo0=Ooo`3@m?l0bnco0<GYo`2hh?P20:cFlP0509k5j`2P^nl0`n;o0=GamP3SnMD00`000000
1P2_gNL0e?ga0>7on`3Vool0g_o_0<o/00<0000000<00=6J000000000000:000000<0?ooo`002P3o
ooll0000000Z07Tc=@2FE540UUAA0;1aJ@2oPg@0bXij0000001_IIX0IfNR075_Y`1cLJT0NG:V075/
Y01bLZ/0J6NS06UTW`1^IYd0P7BU09:6/@2CPj/0QFnI07QNRP21Hh/0VWjN09=lX@2VT:l0/9B/0;B<
V@35YK00dkO00=fk^`3O^[L0g[Nc0=fd[`3CYZ<0_HbA0<ZHU@3GYIT0g:bQ0>B`X@3__:X0n/Rc0P3k
bKL09`3kb[X0nl^m0?K8_03_`kT0jKnf0>g2]`3ea[X0o<^m0?o>`03od/<0omK50?oF``3oglH0onW;
0?o_d@3onMP0oooT0?ojk03jhNP0elkT0=k?h03Td=`0g][A0<GY_P2cfZP0XLfJ0:G@W`2ehKP0_^[7
0;;Ua02Tg;`0/>OA0:KRc@2aj=80`??I0<?^c@36jl80^^6c0<W^b0020=;ig00@0=[oj03Qon<0iooP
0>Soi@3YonX0j?oW0>Oog`3Tom/0h?kI0=cjeP3Em/l0b^g40:WFY`2YeZD0/]f`0;gZb080`Ng<01D0
a_3B0<ode038klX0_nRm0;?O/P2dh;@0`>Jj0<?W^@33j;d0_NNm0<3X_P34jl@0`^_40;oY``2lil00
`>[60<SadP3;lm@0a_3A0:[H/021]7l00P2<^7h00`2C_H8000000000000D0000000@00X0000C0000
6`0>01`0000O0000D`0h05H0=`1G0000R3dm0:QOD`2lMF40`GaV0<J3J`2mN6D0]g5R0;YeI@80_7QY
01D0ahIf0=RMRP3fbJh0ml^]0?S<[03idJd0mmB/0?SEZ`3jeZh0ombf0?oJ]03oek<0m<NJ0=bdMP3D
bXL0iN:Z0=oKWP3Cd8h0_Kig08Z@@@21VU801P000000301E;V80QEQn0680EP1C7dT0OdY[09Y[RP1N
04d0ZP2^0;nT`@2jX<00`jg:0<6P_080cjg200X0_Y2W0?oAc03ok<d0iN>b0>;^a`36f:H0_=BS0;O8
m`000000:@0b0P0000006`24V=@0WIgD0=[Om03kool0f_og0<7/j02]h=`0VM?@08O5c@1k^/`0IJK3
08O4e02=aK`0SKjI07^SJP33i;l0do3@0>7fe@3VnmX0i__K0>3liP3Monl0dOOc0<ccm03<l_80c_Gb
0<C/l@020:gHk`0E0:3;j`2IaNL0[][`0<W^j@0009h0bNoo0=Wio`3Kn]`0001P0<:iV00005P0UI[4
0:bbd@1IK[40DgVf07BPe@28/^40X<[/0;WRn`3Cool0l_oo00L0oooo00/0nOoo0>[oo`3Rool0g_oo
0=WonP3Fo_D0coOl0<O^o`39kOl0a^_o0;;Nm0020:CBk@0>09G2iP2B/>X0^mgo0=3Ym03TiLL006T0
0000003Rm_P0O:kD0;GQj@3Koo/0g_oo0=coj`3;i;H2000000030038W`00SUT0SjT002T00000303o
ool000X0oooo:@000000100]0000M3L008H00028an02000000040:2PT0000000000007f0S`T00000
02X0X6EU0;AkMP2dNgH0ai670=FQT00a=Gd0E52=069NV01/JJ80MG:Y079c[01fLZP0LVjV07Ig[`1[
KJT0H66P06ma[020O:l0Sh:^07m^W@1jIY@0OFRD09f6Z02VT[80YIJh09V?^@2JT[`0]j[70<:^`@3=
/K`0ekFg0=F^[@3@XI/0biB:0=FRU`3FYI/0gJjS0>>eZ`3X_;<0kKf`0?>o[@3nb[H20?k;^@0W0?o>
_@3fak`0k/:j0>Ro]`3X_kH0olZm0?o>_`3od<40omG40?oGaP3oflT0on;<0?o_d03oo=@0oooJ0?oo
h03oonD0ooo]0?oom`3Mool0i?ko0<3RfP30h]D0]^K60:[BW`2ScIT0[MNW0;gW`030km80[^C80:CF
[P2QhM40]_?M0<[oj03Bon00eO[B0<g]`@37jK/0doGA0080fooS02L0hOoQ0>Oog`3Xon80iOoV0>Co
iP3Ron00h?kJ0=clf03GnML0a^o=0;[W``2`gK80X]:S0:[GZP2ehkh0`>c;0<;^c@34l=<0b_CH0<S`
c`2ojL00/mj_0;3K[030i[T0`>Fe0;SMZ02ki[l0`>Nm0<OZ_P34jl80`>[40;_W_`2ji/00_N_<0;c]
d`2gjm<0Vm6_08NmS@2<^h@00P2H`hX00`1STe<000000000000C0000000A00D0000H00006P0002@0
3P0;0000@00002/0001K0000S@000:UPE02jM600_WUQ0;I^E`2bJUD0[VAE0:mUDP2cJE000P2lME/0
5@3FVX<0i:n=0>o0W03gbZL0om>a0?oN^`3ngkH0n=Z]0?SH[@3kfk80onG10?oT``3oil40l^2/0;6]
H@38bXL0gMnU0=3@S`2`]fl0N8<c04mf<`050000000=0000;P1H06P0>@0i06dfF01jC7@0UVZ<07a@
NP2ENJD0YjS>0;?1g`2a]]d0`LC`0<:ok0020::>^@0W0>_Eo`3oool0ooCD0>;`b037h[P0]mR^09_7
W`1WRL<0M6j_05D0Q0000000S;oB0:kLk@33dol0m_oo0<?]i`2ojmd0]NCF0:GJc02GdLP0RLO707^l
aP1QYKd0Eifc06nd]01h/IL0W<6?0<SWa@3Km]X0iOgN0>[ngP3[o=T0jooT0>_ok`3Moo40d_Sd0<of
lP3>m>l0_n[_0080[]S^01L0X<[/09S4i`2Ve>/0]>3[0000001o/=00W]CF09[Bc`0005L00<7X0000
0022Ym`0SJoP002[g000V<`0JIG>086Zg02Na^`0/mSh0;kOo`2meOl0c^7o0>Koo`020?ooo`0>0?_o
o`3cool0j_oo0>3oo`3Iool0dool0<kfl@3<mNl0b_Ca0<C^l`2mi_P0a^co0=Wgo`3Vm?l20>G/o`0>
06a?T02fd?l0gOoo0<oeo`3ShlT0hlfN0?kRh`3oooP000000:3?iP3>moD0f?g]0=[jg`3El</20000
0003001AAP1TWWd0094002T00000303oool000X0oooo:0000000201K0000000000`0000X0000SYD0
09WDg0000000LJZ^1`0000000`0X<Rd00000000000020000000Z0;UoMP2hOWD0^7ie0<jHRP3BVhT0
00000495R@1EE9@0LFbS07IdZ`1aMJl0Lg:Z07AaZ01cLZ/0If^X05ENX@1cNkL0K7>_075^YP1YHY/0
NfnQ09^;/P2XV[d0/JK70;J_c`2WX/P0VIC10::Ka02eZ<D0`:bo0<JR[030UIX0_HZ:0<ZDR`3DX9@0
gk6U0>Bi[`3Y_kH0k/>h0?C5]`3jb;H0olZg0P3odk`04@3odKd0j;jh0>>l]P3U_KD0ikjd0?o<_03o
f/D0omo80?oYc@3om=80ooGC0?oof03oom`0oooO0?oog@3oonD0ooo]0080oooo01@0kOoo0=Coo`39
ool0]NcG0:_M^@2Wd9/0ZlfB0;CN/P2ok</0`?7K0;KM/@30gj00b_K30=GokP3Noo@0gOoN0=Odb03;
jKT0dO330=clf@80h_oL02L0jOoO0>WohP3Ron<0gooR0=kogP3Lo]X0e_OE0<S`c035k//0[^;30:[L
]P2SeJX0Xm>U0;OQ]`36k<D0aNc60<G^c037m=/0aO7F0;o[b02fh[T0/M^Z0<?W^P39j[/0bNRi0;cF
VP2lil40`^[20<3X_`2giKl0^NBj0;KQ]`2diL<0/nO;0;?Yd02Wg/40TLRM09?4T@2E`h`00P1eY6LF
0000000A01/0000C0000=`0J01l02@0X00P09`0006L0002>BUD0YV1M0:eUE`2hKeP0^W=J0;A[DP2c
JeT0/V]O0<>0KP3;RG800P3>SVh0503PZ8@0i:j60>JbR03Y]h/0m<VQ0?oK]@3mfk<0o=Za0?WM[`3j
gK80on[40?occ@3oo]D0h]fR0;bdJP36`g`0f]jT0=3FV02V/6L0JWd^1P0000003@0J0480@`1A07H0
JP2>GWl0TfbD09QjZ02DMJ00ZiBm0=?AmP2ib^X0/[OJ09NUg02]^NX00P22RL@09`3Wlol0n?oo0>Wg
e`35h;@0^mbb07baT02>`ZP0WL2?04N2W`1XZYd0NkZa09JaLP000000M9[209g@e02^hMP0/^?D0:;G
aP2AbkP0QL:b07^l^`1g^<@0Jjfo05RP[@1EViL003800;kK/03Llm@0gOSJ0>Cmg`3Vo^40j?kO0>[o
h03[onP0ioo_0=_ol@3DnNl0cO?^0<G]l@020;GOk`0W09S6i`2Jb>P0X<oX0:SIjP0008D0UL_N09gA
f@2Re>40S/3O08^JdP000000Hi7608Ffg@2:_N400;6[0010M01VS/T0U;_V0:O=lP2ad_L0]M3j0<ON
o`3Clol0g?oo0>7oo`3OooT0gOol0=_oo@3FooL0d?Wb0<[ck`39lnd0`^g[0<C_l037l?H0`NKk0<O/
o`3Am_l0][W_0080/YWD0180ZX2Z0=W_o`3Kool0`O;o0;KDc03@hLh000000?oolP000000P:_H0:7@
i02lj^L0e?WZ0=;be`2ng:`007da001c0000FP0Z000000`0oooo000:0?ooobH0000000L0=00003`0
000L0000=P0003mMW@16KZd0>00000T0000000<0QTl00;@0000000000`000000:P3@V8P0dYZ80=:J
R03DW8T0dib;00000017CI80FF2P07EcZP1kNJl0MGbf07Qm]@1hMJ`0LW6Z06U]Z@1PJJT0Nh:k06Ia
/01EG9l0J6VU07ml/02HT[`0ZZC80;Bad`2k]]@0/J[<0:>NaP2PVlD0Z:;80;:R_P2`Ril0_IFP0<ZO
X03FZJ80g[6X0>:eZ@3V^J`0j[f`0>k0/P3ha[@0olbh0?g:]P80olfh02L0nLJh0>Fl]P3ocl80om31
0?oA`03oel00on?80?o_d03on=@0oooI0?oog`3oonD0oooY0?ooi03oomH0oooN0?ooi`3ooo40oOko
0>;oo`3:ool0]^cG0:_RaP2ReJd0W=6Z0:G=UP2ghkX0`>kB0<cde`3FlLP0kOoC0?KoiP3Uoo<0i?oV
0>?me@3Dk[d0d>^i0=_gc@3Tom/00P3[on809`3_on@0iooT0>7oh@3Romh0h?gJ0=;ed@2mjL@0]nK1
0;KV`@2]h/80Z]be0;7M/02oi[T0c>g10<KX^035j;/0b>k<0<ggg`2nkmL0]NO90;[S]P3:jkl0e?75
0=_eb`3EjkX0`m6?0;g?R`31j/<0^NFl0;CP]P2bgJl0]^:i0;GU``2gjL`0/^K80:?I]@2JbYT0W<VD
08fkQ00G0000000B02T0000N0000<`000000000/0000>P0005/C:@1j<d80TDQ90:MQG@2/I5/0/FQG
0;Q_D`2lMEP0`G]P0<J2JP3DUG/0gJ>50P3RZhH04`3T[hT0i[:;0>ReS03V/hH0ikN70?78V@3cbih0
n]F/0?[P/`3dg:X0m]ZV0??/^03gom/0_[5X0<S5OP3:a7h0dmRJ0<C=R`2MZ5d01`0000003@0/04h0
G01X09=/T`2JK8/0WgFG0:B2Y`2fV[d0eKoJ0>?9c`3A]<X0^ZFn06Il_P2N]>@00P1jU//02`2D`]h0
co7[076XV@2Qbj/0MZAi08S1^@2af[P0U;R40000002Fb/H0[M[>0080000001X0EYNl07fjb@2Ldm00
[^3@0:;D]`2DbJ`0W=;209G?bP22`/80IJRL06>KL@1cYGH0^MV]0>7dd@3QmM80hO[K0>?nhP3Ro^@0
iOoR0>Woh`3[onT0koo/0>Kok03Qon`0g?o`0=Cim@80bNoj02L0[]S`09k:jP2Qc^/0Y]OW0;_Vh`00
0000Sl;I0:oNj@2[f^H0002G06IU000gJjP0HI[708W0d02OdKL00000041U[@1hXMD0U[kY0:G8l02`
c_L0`=go0<oco`3@mOd0dOS_0<ogk`3>m_00cOG`0<cdk03;lnT0b?7X0<Oak@3;m>l0c?Cc0<cbo@33
iOl0_Mko0;OFo`2DU<X00P1oLk804P39fOl0hooo0=Goo`2`hnD0U=3D0:cPg0000000m_oA069SX01j
[]H0V<oP0:gQh`37l^`0`NSA0:[AY@000000UZJP002E02X00000303oool000X0oooo9@0000002@0e
0000;`000480000o0000000006l000210000R`000=l000040000000;08Flg@35ooD0kOoi0>?ni01N
0000]W5M0;]gG`2mNfH0`81]0<:4M03>UH@00P3GX8h09`3HXY00fJBB0000001<EIX0Gfna07N3_@26
S/@0Ohc507J1_@1_Mk<0K7Fb07=i]01`M[80NX6k06Aa/P1IHjH0IFj]07V0^P2DV<L0ZjgC0;>ceP2j
]M@0^[?@0:fWb`2WX/T0Xig60:bP`P2gWK<0a:Nd0=2_]03J]K80gkVd0>Jk/03Y_K40k<2b0?71/@3o
c;P0ol^g0?c9]P020?S7]00W0?73]@3[`;L0j;ni0?oPc03ol]H0ooGC0?oidP3oomL0oooF0?oof`3o
on<0ooo]0?oom03oonH0oooI0?oof03oon80ooo/0>goo`3DonD0]NW?0:_Q``2QfKT0V]Bd09GA/P2O
cI`0^nO30<K_c`3Gm<`0i_cA0>[of`3/on/0jooO0>Sof@3On<X0dNVb0=_b`P3Uo]@0k?oK0080k_oU
02L0kOoS0>GogP3Tom`0iOoJ0=_id`34k<H0^NS70;WU_@34j[h0_NNo0;cV_@39k<00e??80=Kaa03>
j;D0b^Zl0<obd03@n=h0`o7F0<G/a`3<kL00eO330=geb@3HllP0f?;50<WOY@30fil0`NJi0;cR/`2h
h[L0]=j_0;[U_`2ojlX0^^W70;CI[@2Yd9l0Y<jI09[3S01[W6405@000000500V00007P0002X0001;
0000000002d04@0`0000@`0006H0001m:b@0QSH]09mCA`2YGTh0]ViI0<=nHP38Q6H0bHEW0=6AL@3N
Y8@0iJn=0P3X/i004`3Z]i80kKjH0?32V`3^`YL0jKb;0>FjP`3[a8l0lM:O0?KO[`3fhK00j]JM0>ok
d03`n]40l?K=0<g6O`29Ke`0bm2?0;g8Q@1eSdT01`0000003@0002`0Of^Q09E`V@2IJh`0/HFO0;bK
^03@/LP0d:^h0=Z_X02jSY/0a9BD0<>k``27WLd00P1bXm409`3onmH0`m^h07:]TP000000e>ko0>Oo
oP2cfK<0MJ5]0000002SeMd0^NC<0:kOd@2/eM<0000008Rof@2UeM`0[mg20:;A[`2PdK40Y]W609oF
c@29aK<0O;>A096nT02ef:`0g?;=0>SgdP3XmLl0j_WD0>kog`3Zo]l0i?gO0>WohP3conh0loo/0>oo
j`3[onT0i_o_0>3om@020=;im`0W0;kVm@2Sc^`0ZmC`0;WQm034k_80f_SX03icZ02Nc=L0bo;c0000
@P000:00DGnk06>Ib@29_=40`>79031>VP1CMkT0Q:cN096miP2?^nD0U;kX0;KHn03<lOX0d_We0=?j
k`3@mnl0cOK`0<gek`3<m>`0ao7W0<;_i033k^`0`>g/0<C/m036j_l0`n?o0;SFo02W`^l0N8k=0080
OYO>0140^NSo0;[/mP31kMl0]^OH0:WE]`31_8T0`Y]l0:1cM`2Q//X0VLkP08k9fP2Ac=X0XMOJ0;;S
c`000000045R0036[@0[000000`0oooo000:0?ooob@000000140;P0703D03@1F02/0000002@00022
0000`hjB0<nhc03>dnl0WjF808RT_`2Q_n40Y[kO0:S<iP2Ld>H0/^[`0<?hm@02000000060;UfI02o
O6@0a85W0<J6KP3=TWd0eZ2=0P3LZ9@09`3MZIH0gZ^I000]P@11G:P0I7o207N=bP1nT<X0KX?106Yo
_`1RMkX0LWnk07^2^P1oQ;/0N82j06Ee]`1NK:l0HGBf07F6``2=V/l0XjcG0:^]e02b/=80^;7@0:ZN
`@2NTKX0RGZW09b=/P2l[<H0ak;40=:h`P3L_L00h[nm0>S1^@3]`kL0lLBf0?G4]03ob[L0o<Re0?W7
]0020?O6/P060??4]03^`[H0k/>j0?o]d`3oom`0oooM0P3oomh07`3oomX0oooN0?ooj03ooo40ooob
0?ooi@3oomh0oooG0?ood`3`oml0cOoF0;CU``2`h[h0[=nl09SAZ`2Ccjl0ULn/0;SS^`34kld0dOG@
0>;me@3Womh0jooW0>coj03[on00i_oG0=Wc_`38i[80goK90>Koe`3Won400P3YonH09P3]onH0iooO
0>SogP3Qnm80b^k60;_W`P2kj/d0`nc70<c]`@38j[`0anZm0=SebP3Qn/l0h?C60=KY/P3<i[80e_SE
0=Gjg@3?mMD0cNo60<o_`P3Dkl00b^Zl0;OQ^02ohkD0]m^W0;7GX@33ikT0_nW20;[S]`2khKd0bO3e
0<[N^038`Wh0_l=o0;SIX`2Ubi80V<::5@0000005@0a00005`0003@0400o0000<P0003/0000Q0000
@`0006D0001i91@0OBPG08@`7P2=>bH0[V920<5jE@3;QfH0c8UY0<^7I`3=RfX0dY5^0=RKMP020>B`
R00B0>joU@3^`IL0l/VO0?G@Y@3hf:d0n=b_0?CFY@3T`HH0kmZT0?7NZP3ah:/0gnZi0>oid@3GgjX0
alN20<g4P02d/6@0Vk9^200000003@0006`0N6>K05@^I02SN9H0bj>c0<nbb@3@]m40XgbN08mJN02e
Mf<0g:j=0?o^b`3oind00P3khmL02`3oom/000000000002dYKH0oooo0=Gok01:Peh008J306f9/02A
aLh0]>CL0080000001X0;V160000002Bb<h0ZMJg0:cH]02`g;h0_^WA0;;Pb02XeKD0W/RL0;?H[@3E
kld0kooN0?Oog03cnl`0lNk40?OidP3an]D0iOOC0>[D/@3oool0ooom0?_oi03donD0kOo[0>Col080
eOc_02L0^nOT08c0e@2Zd_40]MWf0<7Xl`3Am>h0e_OX07^eb`3>loh0m?Kc0000000_KJ<0EYJo02MZ
V`2>]N40J8W4001`/`1/VLl0NJ[F07nefP1`Ym<0W/W/0:[Ij@3=mO<0dOS`0=Kll@3Eno00dOS]0<_c
j035l><0_>_O0;KVi@2chn/0]n?c0;OOnP32hol0]mOj0:O6l022Ym/00P24]]l03P2;a=T0YMcM0;KW
gP38lM/0`mb]0;^OG`28T8`0^hMZ0000_02di><0S/_D07o0b01^];L0Q/Bf;P00000<0?ooo`002P3o
oolP0000000602<000000000000002h05P0f01<0A00Z0P0000003@1f0000/`000?nm[P3og]X0ak:A
06]oD01b]]<0F:;205BG^@1KY<T0GJK5066Z``1/]<T00P0000001P2jOW<0`8=b0<jAM`3AU7T0fJ68
0>2]U`80h[2J02L0hk6L0>>bWP009G/005^Z05Uk`01WQ/L0K8O605ai_@1PO;l0G7Rm06Im_`1YN[T0
Kgfj06ml^P1XMkP0I7Jh061i_P1eRlT0P9C>09BSe02KY=<0YJG?0:ZVb`2NT;L0SgZU081]W@2[X<<0
^k7=0<Nhc03B_//0h<O@0>G8b`3[bLL0k/W30?;9_`3gbK`0ol^i0?c8]03ia[400P3gaK000`3obkH0
om[30?oXd0030?oogP0Q0?oog`3oon00oooN0?oog@3oonT0oood0?oomP3oonl0oooY0?oohP3Il;/0
eooC0;cYaP33jlD0`N[30;7N]P2Pcj00Slnf0;[WaP3Dn=L0f__H0>3ofP3Ton00j?oX0>[ok03Yon`0
jOoV0>3mc03Dj[@0`NBe0=;cb@3LomX0h_oW0080iOoW02D0j?oV0>Oog`3Tom@0anRi0;CN/P2njl/0
_^kD0<K^b@38k<00a>Ri0<g_``3JnM@0fOS@0=[ca`3<gj<0b=fR0=7ed@3HnMH0foWD0<W_b03>klD0
_nFh0;7M[P2MdJL0VM2Y09gAZ@2ZeJ@0a^[00<7X_`2kgZX0c_7o0=O`o`3JeLP0iN:n0=7QZ031g:80
Rk5b01@0000000D0<`0003d000160000D@0F02h000020000000@01l000190000M@0008Ld8P2<>RL0
TSl/09Q7=@2ODCl0ZV@W0;ifBP38Q5`0cheZ0=6?J`3GVG<0h:Uo0>VhR`80k/>D0180l<NH0?79V`3a
c9d0l]FR0??GY`3egZh0n]nb0?KM[03J^gT0imVO0<k<RP3Cf9d0hnk10<[EVP3BeYP0`[Ua09bRE@1j
UDh80000000=04XcL`1RBHD0O5R60<j[`@3R`<T0bjg40:R</`1lBFh0/hFD0>31WP3Y`i/0nM?:0?oP
g`020?Ghd@0W0<3M]039h[P0N7P00>Oee@31m<l0eO?M0:gJc`000000BWZ/09G;g02]g^@0EeFE09jg
e@2CZZ80omoJ09>h`@2Db[T0/=bk0<3Ua@38k<h0a^[;0;?I/@2bdj@0d>_70>Goh@3ionL0oooU0?oo
e03llL`0n?390?S`c03[i<80j/:O0?ooo`3oooT0oooL0?[oh03_on00h_oW0080eO[/02L0Pkfd0000
001cXm40X<O/0<?Ym@3CnNl0e?OM0=C]b`000000002Q0000B`0SEIT0Iig;08FF^`10JZ/0MZ_F06VO
cP00KZ/0FYJo06j^b`1JVkl0HIg807^dd`2Pdmh0a?7_0<Kbk`3<m^T0aO3P0;cZfP2]hM<0Z=kD09kG
eP2TfNP0W<oV0:?Ak@2gg?T0]MOh0:W>lP2A_NH00P2:^^403P20_=H0YMWS0;WXh`3=lml0XMK70:gQ
gP2Ic>00SL3K07/0002mjmd0[>3B09WCb01i_;d0<g80;P00000<0?ooo`002P3ooolM000000080300
000f0000000005<000000000:`0003X4801553820000000>0000@02T0000g@000?h0002_YiL0?FiM
05ZT^`1<VZl0DInc05:P]`0gR:D0776@01U/P@0@HVX2000000060<FARP3DXI80hk6J0>>`V03S[iH0
jKVR0P3Y^Z<09`3X^J@0i[NS00000000DJ40BW6k05Ina01IO/<0CG:k05Ag_`1FNL40FGc205ah_@1M
M;T0JGZk06Ig^@1]O[h0J87307J?c@1dS/d0Q9[B08^LdP2DWLh0W9c908n:^@2>Pk80V8fh0:VPa@2i
/Ll0akgE0=G8fP3Sdn40iM;M0>OAf@3ZdMD0m]CC0?oJd@3oglh0omc:0?oOa`020?oWaP030?oW`P3o
mm00oooO00@0oooP0P3oon405@3oomX0oooQ0?ooj@3oon`0ooo[0?oojP3oonP0oooV0<ofc030k<X0
b>o90<k_a030gJH0]MJN0=O^^P3Wo]D0gocF0>3me`3ZomX0kooT0>gokP020>_okP070=gohP3?m<<0
`nBc0;[S]`3:ll`0h?oT0>coj0020>Coj`0U0>?oh@3RomH0eo750:oFX`2kiK/0aNg80<O^b037kLL0
`NRl0<?Z`03<lm40coCB0<kccP37j[l0_MfY0<;PZ`3:kL<0d?;<0<cac@36k/X0^>Bm0:cL/@2IcjH0
X]Na0:?G/02RdJ00^Mna0<SY^`3<jKT0e^bj0>Kb`03Qo_l0i?[o0>Off@2jdI<0`=JG05=o?00B0000
0005040000140000M00007IKJ00c00000`0000004@0n0000F00006XB001e7P00PR`D09<o8P2YFcl0
`WaP0<R5IP3:RfH0bHQG0<F1D`3=Rf80eYQ`0>B`P@3[_Hd0klFE0080k/JD0180l<bI0??@W`3ce:<0
lmZV0?;KY`3agZX0omnf0>_6T03F/6h0el^90<6mM03Mh:T0h>bm0=gY]P3NhZ/0e]fR08RHBP1VQSl7
0000000>01<0<01YAgd0DP1R0:F2YP3>[lH0dJ^k0;fK]P27I980Pe^50=bkaP3oon80gkn80>oE/`3i
mmH20<OM/00W0<cU_02Z]000If@009fiQ`0;9200000004>9P@000000001208S0f`2Pd^00BU6@0;cL
nP3Win<0h>OG0;WTe02LdlP0/n3B0<KYc039k<h0`^O50;_L/@3:i;/0h?[D0?Coj03oool0oooi0?oo
i@3olL/0n^Jo0?oU``3fcK80k/VW0>S5V@3in<X0k_?<0>[lf@3Un=D0hOKD0080hOWI02L0j_of0?So
o`25`=`0PJoJ0:kIk@3QooP0dOOQ0;kUaP2cdZ@0PJmn00009P0008/0?Fb]05J6_`0`D9`0Jic=07JY
eP00[=P0H9k405nNa01GUkl0B8Vf04b@]`1c/LP0V];L0:3Gf`2di]d0VM;308_:_02Ug=L0VMCC07k1
_`1]/[/0Di^b06bYc02>_n80YM3`0:?>kP2Xdo400P2PcNd03@2Lc^T0ZMgX0:;JhP2Tf]L0[>3D0:CI
g`2Dan80U<[D000j002Wg]P0W=O<09?@`01bYgP0;`00000<0?ooo`002P3ooolL0000000302T0000g
000000000080000000@0@P0S04HC<0196c/0A`0o0P0000003@000380HP0007d0001f>@00<X>C0000
0011T:@0D9fa05fX^`19UZ<0>hZG029/J`1?P6L00P0000001`34SXH0dinB0>6`W03]_J<0jk^T0>fn
Y`3^`:T00P3[_ZP09`3Y_:P0j;^X0??3Z@00AYP006Re04]f`01EO<<0CWFn05Yna01BNl@0Dgk604ec
_01AK[L0H7Jk065e^@1fQ/<0LX[907JCd@1_S/l0MI7@07jFdP2:V]00RiS>08B:`P22PkX0Shbl0:JR
bP2g/m<0a/;M0=7<j03Meo80h=O_0>;Fj`3Zi?X0on[d0?o`k`3omnP0oooU0?ooh`020?oohP030?oo
gP3oomX0oooT0080oooT0280oooO0?oof03oom/0oooN0?oog03oomX0oooM0?ooh03oom`0ooo40=3W
/P3Dkl<0bo;?0<K`cP38l<`0_>6b0;kOZ`34hJ`0k_k=0>oodP3Zom@0i_oF0?_og03monH0oooZ0?oo
k03don40e_o90;SS^02gh[H0bO390=ooh@3[onD0n?oX0P3YonT01`3Qon00hOgF0<GT/`2aeJ00b>^o
0<W_b`3;l</00P2mi[`06`2mjl/0_>gD0;O[e02dj<l0/nC20;ST^`2miKT0`NW10<7[a`2hi/<0^NK0
0:GI]02VeZT0[=^`0;_T^P2oiKX0cNk30=;]`03Mm<P0i_S<0>khb@3dm/@0eoko0=[jl`3FjKL0WkUd
08J/J@0B0000000J0440003O_KH0`LO>0940001FF980000001T0001J0000IP0006<0001g8000Pbd0
098n7P2QDB/0]fhk0<N5D03DUVX0fj5d0=bRLP3GVV/0eYUX0=RLK03KXW<0i;B10>g5TP3bcY`20?3:
V@0A0?7:VP3`d9`0l]RT0??LZ@3gg:d0onJj0?o_``3jci`0f[1f0;VUEP38_WD0emBE0>GZ^03Qj;D0
h>Ve0=SRZ`1kRS/0200000003P1G06<0001C07iEO`2TQ:X0bk3:0=Fda02eTJd0L4Ig0:^7X03oom`0
ook80?K^_P3jomL0kOC:0P3Gi;@00`3Fi;D0dN2`09B/K`040000000A0<jdW@18FDd0000007babP00
09T0V;K90<k_dP2gh//000000000B02Yg>80^nCF0<SZb034i;`0bNFk0=ccc`3fon000`3oool0303o
oo00oooG0?oac`3ojld0onO80?cWa03ikL@0k^Nj0>WW^03Ulld0g_?@0=G`c080_N?400T0[]g408[@
b@1DVK80=gVU07:[c@2Qd]T0]>;B003;/000/8d00P0000007000;gh0003105Al_01=MkP0FhS206nP
dP21[M`0OZgI08Bfg@2:_]l0P[SJ06n[c@1=SkH0IJO507:e`01j_K@0P/:c07Rl^@1//k00GJNP04nK
U`1FX:L0Ai2Z001WS`0ZKI/0KZK>086ff`2CaND209G8iP0<09_ChP2Me^40WMGP0:KJf`2Sf]/0V]7P
0;`0003V0000K@000000001Z[[<0LK2C<000000<0?ooo`002P3ooolJ0000000402`000000000FDEc
05M0K@80000000T0FP0j05<K<01@6S<0C@0f03D0:P0A0000:@0l0540001kMJD00`0000004@00GX80
06^;001eT@0VNHl07g5m052HX029a/X060000780002j0000fjVJ0>JfXP3b`jT0m/N[0?G6[@3ca:h0
l/B_0080k<2]02<0j[j/0?C5[P3ocK<0oL^/0000O@1>MKd0H8?705]n``1RQl/0DGo804emaP0mJ[L0
?V:`05Ea^@1QN;`0Mh[607ZCc`1gUmD0KXoA06^<c`1eTm80NiGC07bCd01kR/H0N7nk08B7_P2TYm40
];OJ0<?3i03<cO00e=Km0=_Ko`3Oi?l0iOSo0?Koo`040?ooo`80ooon02L0oooh0?oom03oond0oooX
0?ooi`3oom`0ooSA0?oidP3oomH0oooI0?ooeP3oomX0oooL0?oo``3YlkT0f>o00<W_bP2hjL`0_>c>
0;OU_P2egk<0^^6b0<cX]P3^nLH0jo[90>Old03aomX0oooM0?oohP3oonH0oooX0?Soc02igjh0^^Bh
0<Wbb@3Mon<0i_oX0?7oj03oon/00P3donL08`3Pon40e_?70;WKY@39hJP0c>^n0<gac@31jL00ZMV`
0:?L`P2Sglh0Y^;D0:?PcP2Ug/40[^6n0;KT_@2hil80_N[40:cO_02^gkT0Zmbd0:[J[`2ag:l0c>F`
0<W[_`3JmL`0fo310>3a`03Vn</0joK60?3d`@3YmM00d__f0<[^dP2B/Fd0[<R500l0000001h0XP1l
0;L000000000=@000400001h0000NS<i0580001?0000NB//09I8>P2PDCX0ZEX00:1@002HA@00VdTR
09e<802]HBh0_GQ20<R9C`3@T640f9]/0=JHJP3FUfT0fj5b0=VVK@3LZG00hkMm0>_8T03`dYh20?;B
X00A0?;CXP3^dIT0kM:I0>kFW`3ffjH0oo2l0?ooe`3oomX0i?[J0;RPDP37]V/0f<220>WRZ`3RgJD0
hNVe09NRF@1LMRT01`0000003`0X03/0001=0000L`2]PI`0aZFn0<V]a`2WQ:D0NDij07iGN`3Oel`0
oooY0?ooh@3eomD0h^k50>;]`P020=_T/`050=SP[@2]_h@0MiUK0000003BWhT00P000000203XnM<0
/:e]0=K6TP1iYlX0002^07Z`c`2Nd<D0^N330P00000020000?<0^N?R0<?Wd@3;jL80eo3=0>Sog@3i
on`0ooon0P3oool0303ooo40oo[D0?oVbP3ohl@0oo7>0?gabP3ak<40jNZk0>G[_P3AfJ<0_n:l0;3I
]P80UlVX00L0P[jY076_U@14S8l0071n001HH00/MHX003Xe00@0000001`0000J0000Q01;JK00HH;3
06R@bP1aWm80PJWL096gi@2TcNl0YM?^0:GBkP2Hb>P0OkCH07njeP25a<h0S<[108O5[01a]J@0K[BU
06ZaX`1MYYl0CYVU04nF/@1OXKl009:n0015OP15Q;<0PKWK0P2:`]h02@2Gc^80W]GR0:;Hh`2Tf^@0
ZMkP0000001UA`00[LjV09faR`0c000000`0oooo000:0?oooa`0000000d0R65f07D/8P1_0000JP00
05lJ7P1;42@0F00g03d0:@0J00005P0002h0A@1ZEh<0QWZT00D0000000l0M;W?05RR_P1OZLD0NKgD
093>g01@;UD0Ug1n0=fbY`3]`:h0llB_0?S8[`3hb:`0l/6T0?70Y`3``:X00P3[_ZX08`3ca;40om2j
0?oJ`@3oeKL0oln/02UEY@1SPL@0JHO906^@dP1JR<d0AGS3031R/P0^FZ`0@6Bb05Qf_P1ZR<T0NigJ
07ZLf@1eU]H0J8gA06jAd`1aTm<0Li7A07>8a`1`O[h0NhG00:2Ze`2a^>40`<G[0<kAm@3Bf?l0e^;o
0=ggo`3Sool0jooo0080m?oo00<0n_oo0?ooo`3oool00`3oool06@3oooh0oooc0?ooj`3ooml0ooSB
0?o_c03ok/h0oo?B0?oje03oomD0oooF0>caY`3=fi/0_lf80;CVb02XhLT0Y]k30:;I]`2hj<l0a>_>
0=[ab03Zm<00iOS;0>7meP3jon400P3oon<02P3oonH0oooA0;kNY@2kgZX0bO320=[oi@3Xoo@0k_o_
0?Kok03bonX20>Koi00S0=kme`3<jKP0`>2/0;[O[`2mj<D0`>S00;3L/01d^J00U]W;097Gd@2If/l0
Y>3=0;7Ub02ei/D0^NFn0;kX`02jj<D0[n2l0;7O]`2ii/00_>Jo0<KX_03CkK`0eNo00=GcbP3Nkk`0
i?G60>Oic@3]lKh0k_6o0=Seg`36m^d0_>2^0;3AU@22ZFH02`0000008P180000S@0006nNZP3j0;`0
o`3K0?oom`000000RgZ[0:00002[0000002/0000:P1I3b40NB/_09U;?@2aI4L0/fI90;=VBP2aHd<0
/6<m0:eP<`2YGBP0ZfHT0<61A039QeH0chmQ0=2@H03EV6H0h:ai0>:cO03M/W<0gKEd0>K5R03_dY/2
0?GJY`0@0?KP[P3cgZX0k]NN0>W@U03XeYX0nNbg0?ome03Yo=X0dNk80:VkOP31YEP000DI0800003T
diH0emjU0:J/H`L000000100=`16014AG@1fDWl0XWjS0<2S`@3>[L80cZRi08=JQ@21G8T0blkA0?oo
o03oonX0k?cI0>Scb`3Mj[d0eNNk0P3MjK/0603<fjP0Qj1N08BDCP35[Wh0h]_;0?CWj`3Vo?<0i?gK
0=CKZP3Eg:P0001l0;gRl`1PW[/0SL>m06^BI@1[PDh0b<WM0=cTo`2li^D0_^K:0=7^bP3PoMT0jooY
0?KomP@0oooo00/0oooa0?ogc`3ojL<0oo7;0??[`03YikL0j^Ni0=oU/`2kb8`0X<FF09;4W`0207Zc
T@0406>RQ@11RGP0@HYm001^FPP00000018001]/045QZ@1MP<40JHo;07JNe@21Z]`0QJoO09k:j`2[
eo00/M_d0:C@kP2KcN<0RLCE08O7aP20`K<0HjN>06:YVP00Sh050000000404f0^@1nYmP006>I001b
X`80P[WJ00L0U/gR0:3Fi@2/gnT0ZMkT0:SNf@2de:D0FUh003D00000303oool000X0oooo6P000000
401002l0L4YV07PoB02<Bd80VEM7095CC01nBEP0KCU?05HT@00c03D09P0001/0;01[06H0P6F8099o
XP29PJ`30000000@0>koo`00000063Q@0000001Y/L/0H:Zn06]=L02YRIL0g;bk0>k5]P3ea[00nlZa
0?O7/03b`JP0k[^P0>ZhW@80j[RO0280kknV0?W9[`3odkL0om2d0?o>[00007h0?F6]06R7b@1ZSm40
K97B05J1b@0nK;X0:UR[03=O/013L;d0H8[?07^RgP1iW]`0MY[I06F>dP1YTM@0JY;D06V>d@1[Q/T0
JGk107J5``2GYmT0[l7j0<7@o`3>f_l0e^Oo0=K_o`3Iool0h?oo0P3Rool00`3Qool0gooo0>Ooo`06
0?ooo`070?oom`3ooo@0oooi0?oojP3oom@0oooB0?okfP020?oof`0J0<3@RP2ebXD0[LJ309gA[`2M
fKh0W=Fg0:SRdP2ol^`0d_KO0>Cjd@3Sm<@0g_S@0>WogP3oonP0oooV0?ooi@3oonL0iOnn0;_HWP2o
fZ00g_k>0>col@3`ooP0m_od0?GokP3ZonH20>3og@0R0=cea`2]fJh0X]>W0:;L`02XgK`0[]^`07Be
T`2HeL00[>OJ0:cWg02[j=l0]^cK0<7_e@34k/`0_nW00;gX`P2kj<D0_^[70<GW^P3;l</0c_7;0=Oc
b03HllL0do330=7aa`3HmL`0hogF0>Gdc03_k[L0gnfk0<c]a@2nj/T0/mZX0:O<T@/0000000D0`:g1
08^A/0000000d^7@0>cQ[0030000000K0:W@m00hOJ8000210;^EB`000000KRHi0917B@2lLe<0`GUE
0<EoF`3:Qf`0eIMo0=BFMP36Pe@0`Wm80;Yf>@2cKBl0/f/c0;]c@P3:S5@0dIUM0=f^M03Y`XX0k<ZA
0>6kN`3S`800j/V>0080l=:L0100lMVS0?CV]03agZT0kMFM0>gGWP3Oei`0hoG?0=[cc030dIT0]K=b
0=:eN`2n0000dK=`0<ngL02j^700VJ1C1`000000401<:64000000000002dVKl0aJS50;6A/`2=IXl0
TffF0<Vfe03Kj_l0l_oa0>_oi`3^oMP0jo770>;X^@3Njkl20=3P[`0<0:_3RP26WEX0VI560;[2Q`3B
hLl0e>?[0=WmmP3Toml0g_7<0=o_b03QjKd000121P0000002000RI`00>SR0=Cdh03RoN80iOo^0>co
n`3Zool0m?oo0`3oool02P3oon`0oooL0?kjd`3bkL00k>Be0>?R/P3Pj;T0Ykao07VQJP1g[8<204>4
HP03001eGP000000000000X0000000d0=EbS051i^P1QS<L0LIgB08J`g`1n/mT0TLGR0976hP2IbnL0
V/kW09K>h01a][<0D9Z=00/0000000/0UkkW000lP@00W/d009k=08Fof025a=40S<[E08k<d@2>cLT0
RKJ>04ac000e000000`0oooo000:0?oooaX0000000l0FSEI07A=J@2:H7H0UVYk0:5cP02EJGT0OU5V
06<gEP1984H0=Plj02H0=P1X<TP0P`1[09L0S@2MQ:000`0000001`1X/<D0l?oo0=K^k01OZ<P0IJg8
04NCW`1JA6/00`0000001`3/cl/0mLbj0?c</@3caK80j[j^0>JeX03T/IP00P3W]9T09`3/^Yh0m<>U
0?W9ZP3haZL0n<BT0?G5W`0LCj40DGW006^?d020XM`0JhoA059ja00`GJl0<Ef_03e/^P1EQL`0K9SI
07>Lg01_V=T0I8oC06FAeP1TTMD0FhS?05YoaP1YP/D0MHW808bSfP2Q_>h0_MOo0=C/o`3FmOl0eOgo
0=Koo`3Jool0fOoo0=Soo`3Gool0d?oo0<[lo`020<koo`030??oo`3oool0oooo0080oooo01H0n?ko
0?ooo`3oool0ooo^0?ooe`3oon<0oooX0<OZ]P2de9/0ZlfD09^nP@2XdZ<0[MV_0;[Wc@31d<P0a_K/
0=[ohP3Wom<0foC80>;oeP3honD0o?oZ0P3oonT02P3eomP0_N6Z0;gFV@3FiZd0l_oJ0?Gok03iooT0
o?od0?3oj`3Lomh20<?^c@0R0;3M]P26`Y`0W]B_0:KK]`2SeJ/0T<:A0:WL^@2gj]<0_?7Y0;kbkP36
mNP0b_OQ0<Ocf@32kL`0^>6d0;WU_P36l<l0dO?@0=C]_@3@iZl0dO770<kab@37k<@0`N[30<?/b@3B
nMX0coC]0<OTj@000000`^>h0;cS]`2ehKH0Z]>N082YJ@T0000000H003Yh0:bZa02Wc<P0PL?10:3G
g@2mh=L20000000M0000KP2af?/0/]ca0;SVk@3?o?P00000074cDP2WK7/0b96<0>ZgV`3FV7D0`WY@
0=RKO03NY8P0i[2C0>BaO@3BV5h0aXM90<5oA02iLcX0_7Tm0<B4B036TT`0eZm[0>G5Q`3^diX0ilV<
0>G5QP3YbXd00P3Yd9D0403/dIL0l=fW0?3U/@3`hJ`0i]JL0<ZlLP3;c8l0e^Jc0=gdc@3FgZ/0lN2e
0=D00035_gX0b[ed0;2ZG01gR3X60000000A05`bH`1>0680:@1408X0T@2iV[/0_J310:61Z@2[QZP0
ek?50?_co`3oool0o_oo0?ooj03oomH0l>[00>WY_03GiKH00P33f:D0602>ZFX0YkUj0;nhM`3LcYX0
h[fK0>?5^03Qon00iOo_0>3jg03TlL/0hn_00=KEW01n]l`00:>a0=7kj`3hooh0a=oo0<;To`00Eh80
0<k<0=okh`3Pn]h0h_o/0>7oo`80f_go00d0iooo0>Woo`3mool0oooe0?gojP3gomd0l?770=WDW@35
bH`0]<R=08>LF@1iZ7D006]300l0000000/0001<049b/@1@Pk`0DhNn07BWd`1i/]H0N;GA076ab`1`
/LL0JJjk04>@Q`0>00000006000?E`00EGL005Eg001gRP00=d80<0000P0000000`0dPGL000000000
000d000000`0oooo000:0?oooaL000000100U`1^0000001?=600I4AZ07EFN02GMi40W7^C09ikTP28
GWH0L4QV05`fF`1584T0;``j01D05@1W0440WEaC0`000000200493<00000000000000000fLcB07bM
WP000000001h100000001`3J][D0i;bc0?70ZP3W^JX0i[^_0>:`W@3S/9X00P3V/i/08@3Y]Y`0m<>W
0?o=/03odK80ol^[0?[7XP000000>W6j06B:c@1lW]X0LI?C05Mma@11J[L0<Ef_03UZ^@1=PL/0FhgC
06RGf@1XU]P0I9;F06NFf@1RT]L0EhS@04If`P1=ML00J8W;07nQg02E^>d0Z/oo0;WPo`35l?l0bOco
0<_oo`030<coo`030<_oo`38n_l0aOCo0080`>co00<0d_oo0?;oo`3oool00P3oool08P3dool0k_oo
0>?oo`3NooX0j?_L0=Ooh`36o=h0^>K00:_I[`2QdJ@0ZLnI0;_JX`33bJ00bJfF0:fBTP2ea;h0hOoQ
0=_jd@3PnLX0nooC0?oog03gonH0n_oU0?[oh03Do<00_^2^0=;W[`3NhjL0n?oA0?coi03oooL0hOoX
0<7leP2=b[<207o3ZP0Q076gVP2@c[D0Z=bh09_BZ`2Hbih0[MV/0;_W`@3:mML0cOWZ0<Oei`3<m]l0
bOCI0<C`d`2nk<`0/]b/0;_U^`33k<D0b>o80<c^a02ih[D0]n>k0;WV`P2`h[h0[>6n0;[[d034lN<0
_>Og0000002/fLP0Z=JY0;7N]02jgjl0MIX000X0000002D007Be082W/P2Jd/00N[Zm0000a03<kol0
VFIX0:^/R@3=cL<0_]KX08o9f`1j]J40003J00000026C6P0ZWB50=:OX@3[_ID0f9j20;YaB03=RF80
fiej0>B/RP3U[hL0fIi_0<n?F@3=SUD0e9]P0=NPH`3CXf<0a9Y@0=6^I@3RaH@0jm>G0>_CV03VcHl0
jM>G0080j]JK00l0fm6?0>KPY`3^k;/0l>fl0>_X]P3<`7`0f=2A0>GT[`3Tg:00jn^j0>ca`@3WjKD0
gmVK0=;8P`22SS`01@0000004`0[FB40EbME060cH@0b0440@01L0:j:[@2iV;P0Yh6T0:B0YP2iUkD0
oL_D0?oinP3oool0oooP0?ook03oon80ooW90>;IX`2mcYD00P2P^h009P2M/W<0_LJ80<kBV03YhkH0
hl^O0=GGY`3OlLT0jOoV0>SogP3YmM00i^o50=WJX`3Kej400529002oh@2Zd^h0_N7h0<S/o@000000
XKo@0=gkhP3Nn=d0j_oi0>7oo`3Go?l0c_7o0=;go`3CnoX0c_[g0=Wom@3Too<0k?oW0>WidP3HhJh0
Zl210:k5RP1EJ1d0=V`h4@0000002000K:L007fb04:0/P18QkD0H:?106:W^`1GXJh008jD4`000000
1000T9H0>XJI08:mZ`2JaNTh000000`0oooo000:0?oooaH0000000`09`0V02h0=01105P0JU5j06aB
N`1^E7`0U7fM09V0W@2@LHh0OUQe06i9J`1K=e`20000000>03h0=@1c0440000005LR>`0002L0F1XX
07M=B`2[ViT0000007/nA@2>FSh0XWHg04jH]P0008@4000000070<ZKU`3BXIT0fZRJ0=j^X03U]jP0
jK^Y0>bmZ@020?G3Z00W0?o9ZP3od;40omFg0?oG^03of;P0omNb0000000SI[80FH?906nDe01URLd0
G7o604eb_00bGZl0>6Vh04]nb01KS=80IICG06:@e01VU]P0K9kN06:FfP1ERm80=Vno039Y^P1?Qlh0
JZOT07bcj@2=`_40V<oe0:?LnP2/i_h0[^Oo0:oXo`2djol0^^oo0<7do`35mOl0`>go0080^nKo01P0
`_;o0=;oo`3Lool0h_oo0>Woo`3Rool0eOoo0<Soo02Qh]@0X^7C08W@a`1__;H0M[j]07VlY02@bJP0
IjR70=;RZ@0008<0001a0000Y03ln<X0mooE0?Smc`3dom020?oodP0=0?Sog@3bomh0j_o>0<gX]@3L
lKh0iNnk0>_W[P3hol00kOo?003odP00kLL0K;NV05BUUP0205n^X@0Q0878]P2Qg/L0Y=N^09S<W`2P
cI/0_NJn0<gcc`3Nomd0g?cL0=Cgf@39m=`0`_7J0;c]e`2ji[h0`MnY0<_W]@33jl<0b>k50;GR^@2_
gkH0/N6m0:[N^`2Sf[H0[n6n0;?Ue02di^`0Z]_o0000002Id:/0`^Zj0<?X_`2ad000>UX000X00000
00/0H8^i08K0Y@2Cbl<0N;S<04T00024EGP0m?oo03@0003o]:h0k>c60:75VP030000000G0;9eOP33
RHd0eJ6=0=n/NP3LZJ00T4mD0<nCN@3PYX80[fPY0<:1BP33OTT0dY9Q0<fCFP38TDh0d:9N0=^hM03F
_gP0c[U_0=NdK@3Uc8d0jMJI0>GDU@3[gZ@00P3XgJ<03`3MfIX0h=jS0>S[^@3Yk[h0jOG50=OMY`2h
UDX0j^6Z0>WMY03ZfZ00knRg0>_T[P3XgZ@0a/9k07V5<`060000000B06@`E`1O;5H09@0[09afWP2c
T;80ZXFX0:R0XP2_S:l0dJk90?oZk@3oonH0oooO0?ooi@3ooo80ooo/0?ond`3>diX0[Kj00P2S^G/0
9@2g`h@0b]>H0=OJX`3QjK`0h>k40=_[`03/m<`0k?oK0>SohP3_omh0jo?:0>OS/`3]gk40e[F5002E
a02RcnT0YMKU0:K@jP000000T[OD0<WZg@3Oond0j?ol0>;oo@3Iooh0b^ol0;gXlP2kj>X0^NOX0;OV
i`2ei>L0angU0=cjh`34fk40Y;Qh0;?:T00kKSL04`0000001`00Ii/0FIO004N?Z`10S:80>8JB03j4
I@1BPdP0C`00000<0?ooo`002P3ooolA0000000305<>0000000000000080000]01/0=01803lWF01H
@g40KeZ6079NR@1fHX`0TX2S08=^T`1lHHH0MUIi06E4J@199e4000000240900]02T00000058[DP00
0540001e0:FNW030c[P0@Uh004D0D01l05X092@_07@00012T:h01@0000001`3?WYH0h;:V0>JgY`3/
_Zd0lL>b0?[7]03oc[@00P3oe[<09`3og;T0on6n0?oU`P3oj<@0onW50?oV`@2SYFH0000006F1`@1K
PlT0HXC906>6bP1IN/40=f>c03UY^@18NlH0FX[@062>d`1PSM80J9WJ072UhP1WWMh0EXkE03iga@0d
L<00?7c705JKf`1OZ=l0L;OV07k6k@29co40U=Oe09_Ln02MgOT0/>So0;__o`31lol0a??o0<7^o`02
0;_Vo`0W0;OSo`2giol0^>_o0;[co@2iool0]ooo0;Gfn027cLP0IK:W03J?T`1>XjH0Ll6m07K2^P1i
a;L0Mkn/05ROP`3da7H0001]0000K0000<00n_G50?ohaP3ooLT0oooE0?oofP3oolh0n?o=0>WnbP3K
l;d0iO2m0>o__03fjk@0m>^b0=OOY@3=lK@0091m01QiR`0bS8h0Hk:X0080VM[/0240WmcG0:7I^P2P
dJ80UlFA0;KN/P3>mLd0hOoP0>Ooi03WomL0jOK90<ocf02llN<0b?OK0=;ic`3EjK40d>J`0<CZ_P2j
il80/N:o0:kO^@2ZgKP0Z]jl0;3O^@35on00`?oe0;Kco`2/cM<000000?7oeP3ZomH0gOWA086Q000P
41h0200000009`0X>Ph00000000000190000Q[3E0500002:0000U:?J09b;U@31Wf/0S0000>cojP00
0000M3A;09mJD02fJdD0[6=>0<^<Q03<S7T0c8Y^0<>3OP3GX8d0k[bG0?2nV`3IXG<0bHEK0<R2E@3D
V6@0h[Ak0=g0P03:YUX0bZaP0<g2N@3=`gT0elV30>3BT@3UeiT0hmVJ0>KOY0020>;PY00?0=OJV`3D
fih0h>Zh0>oof03Uo]40dno20<?IX@3_hjd0kmfW0>oHXP3agj/0k]nX0>OJX032_WD0HG8000D00000
01<0GRQ>07I0I00g03H0Kdj10:F5[@2ZQj`0[8NZ0;2;Z`35ZlT0omW]0?okmP3oonl0oooP0?ofd`3o
omd0oooO0>[U/P2j^g/0XK=b0080/L:602@0^<>40<gEW03IhJh0g>Nj0=k^a`3Ul/d0h>c30<gU^02@
`Ml0a^Wc0>Klm@3[jL@0onW90?kS_03^g:d0P;OG07J`cP20[MD05A`:0:CDjP2oi^<0eOOQ0=_ol@3K
ooT0coOf0;[VkP2Wfn80]>?W0;OVj02iinT0]NCY0;3Pj031jM/0^]V^08fYJP26Xf8E00000005001;
PP0jPJ40AI6=05^OQ000SG80D000000<0?ooo`002P3oool@0000000403H0=@000000000000000080
:aU@02L0>2=H04`lK`1SDh<0Lf:>07]YT@26LiT0RWRN07mZT@1cGHH0Je5j05<dGP0a03/000000380
?@0H02P0CP1@08UWQ00005P0002F0=Sjg03b00000001001;002808/0/P2;050n?@1e]lD0000007A9
H`2DGVD0]7EZ0<R<PP3JWHl0k[RW0?G7]@3ncK/0om6n0?oD_`3of;l00P3ofKP09`3oe[00on:k0?o]
a`3on]<0ooSA0?odc@0005P0002N07Ah/01BMKd0FWRn07ZUg`1PQ/X0?6Ng03YZ^@13Ml<0D8C<05jA
e@1VUMP0JY_L076Sh@1`XN00H9CI04j8d@11P</0?H7;04N?d`1=W]L0FjgN062bg`1^_NH0N/K[08K>
l02GfOT0Z^Co0;_^o`2nkol0`O3o0<?`o`020;k[o`0W0;[Yo`2hjol0]>ci097Ef025dmP0Pm3E002^
[@000000UmWD09kOgP2ShM`0U]cJ09;Hd`2Og<`0Vm2c08O0W038_h80f]WE0000Y@000<d0h_OG0?7f
a@3oold0oooJ0?oohP3oomH0mOg;0>_b_03WkKH0n>nj0?[_^@3ekkT0alnG09nkPP1LZZ00Ej^g05B/
a01ja]`0YnC_0080Y^?f0200[>?Q0:gO`P2[eZD0Y]:S0<S^a`3Qomh0l?o_0>coj03Xon00d^Vf0=Wf
b`3Jo]H0g?oS0=kneP3Tjk<0a]jY0:cJ[@2/gkd0[N710;KU``2filP0_^O10<geb@3Vool0n?oo0=_o
o`2ln^d0]]:b0;G8Q038g:<0/]BS06FRN0d0000000D0]/CQ07an]@000000001e03Y/W@020000000L
08]1A02_KG80]gQl0<>9S@39RgX0`GQD0;Q]C02cIdd0[f9;0;ihJ03?SgT0g:5o0>^eS@3cbJ<0h[RB
0<b=EP2jQd40aZ=I0=G1O03Lb8<0^J9A0<g7O`3Ich/0em2=0=OFU@3LfIX0g]VJ0=[HV080fMfP00h0
b=>C0<cJWP3Nl;`0iocC0=[jg@3?j<00am>F0?SW]`3ggjl0lMJQ0>WCV03Uei/0fM:D0;nkL@D00000
01@0KcEC08QCL@20DGT0CP1I08m_W02KMIh0W7RP0:V5Z@36Yl80h<?I0?oGi@3on_L0ooo]0?onh03o
l=80ong<0?ogd@3UgZX0^IiH0:N`K080_/V>02<0^L:40<kDV`3EfjH0dmfZ0=GS]03QjL00oooR004J
0018Pj@0T;[Y0=koo`3YlN@0jNFo0=gR^P3?e9/0000002U^U`0007/0003e08k3bP2Cbm80V];A08Rj
d02jhnh0coKd0=Gkl@33l>H0/n?R0;oZk036ko00ao3`0<G^k`2fh]@0W<VR07FQK00G000000030000
K`000000000005400000303oool000X0oooo40000000100@01H000000000000G1Cd2030RFP0D03XW
F`1BAg`0K66A07EWU@2:OJD0RgZP08UfW01jIHh0KEF005/oJP0j04`000000000@@0S03<0>@1;0880
O`1iGGh0001L0000]`3oool30000000@081jYP2ZU:P0aZBY0;^>S02aN700^7QY0<jFQP3T/j@0mlBc
0?o4/03oc[H0om:k0?o?^`3oe<00omW30?oNaP80ombn02L0omNa0?oFZ`3oek80onO00?o`bP3olLX0
001`0000Y01]V]<0FV>U059//`2=_^l0JI;B04ef`@1AO/L0A7O304Ala`1@R=00I9_L07jcjP1n/>P0
KYkM06nPh01OUm/0DY3E04b>e01>UML0I:cR07S0j`23bo00N/?/06nlj01k`nd0RL_d09CBn02Pfod0
ZnCo0;3Uo`2^hol00P2djOl01@2dj_l0Z^Cf0838bP1W^;H006AG008000000200/_o^0<;oo@3?oOh0
b_?M0<;_f03;m]h0eOkQ0<3`c`3:hZd0bn?@0;cTo`2ehOl0a??n0=3ii@3Nll@0mOoC0?ooh03oonH0
kooO0>;fc@3Sk[T0jNfd0??c_`3Zk;H0k?2k08fZL@3o_X`0000004nB`P21_=H0/nO[0:kXm080[^Oi
01P0^no`0:?EZP2ihK80]n>l0=3bb`3RnLh0joob0>SojP3Qom`0^]^S0;kV^032lm<0/^gK0;[ai02j
hL40W<ZH09W>X`2Vg[l0/>C70<7^dP34lM80eNk00?7of03oooD20?ooo`050>Koj`39j/P0_<Mo0;G<
SP1/WF@03`0000008P1eS;`00000000000000000Wf^00:eiQP2jQHd0d9fP0<^DU@34QhL0aHAf0;EZ
D@2C?RH0VDD/0:QH>P2lLTl0cIag0=RlS03Xc9T0mMj]0?Coe03Qool0cJ=M0:nB?P3:]F`0f]>C0;F]
G@2l]V/0fMFD0=KEU03HfY/0g]jR0=cNX@3Gg9l20<gJW@0>0<KHW@3BgJ80i^jm0>;`a03OlLX0fnRi
0>KS[`3okL<0m^2_0?3GX03Xd9<0g=2?0<[9Q@2^]6X40000000E0818H`2CHh80UFZ>07I<NP1J;El0
SfB;0:1gV`2`SJl0aj[60=k2e03bd=h0on3W0?o[j`3okN00ooOM0?o`e03ojl`0ono:0?;V^@2i]G40
[JYS0080`lN90140b<B50=7=TP3EeYl0fmfX0>;V^`3VbZ40ooo]0=WI002[ajl000000<_8d`3hm]80
e^[30<_N/030ahX0/LFA08o1X@020000o`0?0;W]iP23/h`0000005nB``2ObMX0e__a0=Wnj`2eiMH0
SL[608o6e`2Pd>00^nSY09WAb@1c]:<09VaA06`00000303oool000X0oooo3`0000001@0>02P0200P
0000:@0I1cl071EC0080<bIN01@0?BmU05iKT01_IiL0K62@08n5[@1kKYT0LUn:071HPP1PAG40AbYI
0000>@0002D0;00h01d08P1905@0Z7=`061@N@00ChX005MN003YY`<000000100MXBl0:2P``2o]ll0
_ZVf0<ZUX`3K[:80l<Nl0?oAa03oc[h0omO20?oQa`3ofL00om6i0?oC_03oe/00om_30P3oe[d0703o
d[D0nljY0?c<ZP3odJ`0omJc0?oO^`3oj/<0002l0;:@W`3O[j80HI_F08B]h@1jVM<0J8_=06VBe01Y
V=T0ChG=04F1b`1?SM<0JJGQ06fWhP1JTM@0K9oO076Wi01SWml0G9cM06FXh`1m`o0207o5l00907g4
k`1g_nd0L[_[07_3k@1nanh0Q<__08_@l027cNd0P/Wj0080S]?h00/0TMGZ07JnaP1?XIH0000009QL
J@000000Y_;h0>?oo`3bool0ooon0?oog`020?oogP0J0>Sle`3RonH000000=Wfl03Ihnh0/Zo;0<Ca
o`3Ao>/0f?;70>_oe`3Von40gooW0=CliP3Cllh0e^fo0>7a`P3Xm<@0fNVe0;gFX01>P4H0m<6M0?oj
b0000000_l?T0;[EkP2biOP20;K/n`0N0;gak`2Sf;@0]>C20<C_cP3CmM80h__F0>Coi@3Non`0`>Rl
0:cEX02Zgkh0U]S:08gEd@26aZd0R<:N08BnT`2LekX0Zn?;0<CbfP3>n=d0d__K0>Kod@3oom`0ooo[
0?oon@3oool0oooZ0?coe03Nhj<0NY]B2`0000009`1X0000Z@0009<000200000K000068000000000
_IVb0;^H/`2fU;80^iRb0<^R/@3BY:`0bIFK0<B>U@30Ph00aHj>0=VOT@3>SgL0aH5H0=FEJ02]T600
]LJ;04^9HP28^m00Y>;X0=kom03domP0hm:E0>OQY`3Fgj@0_[me0;F^GP3CdXh0e]RG0=[JV`3KfY`0
dmbP0;oDV0020<7KY00>0<gJW@3Lh:H0jnZg0>W/^P3Xj[L0jNZf0?ofbP3ol/P0onNi0?OLZ@3QbH/0
e/^70;NjL02@Y5/30000000F08UPR@2=Fg`0Wfn:09M[S`1]@Fl0K4Qk0:IjV@2eSjd0aJ:k0=Bhc`3N
`]<0hL3<0>g4b`3cb/P0omo@0?oae`3om=@0ooSB0?gecP3akL80[:i[0;6`J`80bLR:0240b[Qg0=6n
P03HbY00hMJS0?OK^03`c:/0jL>M0?ombP2e[:h000000>GA]P3in<l0h^Rk0=KNZ`35ahX0_l^@06Eo
001lWlh0]^Ob0:SPc@1MLg/0=3]i066F`02egN`0`^gT0;CSeP32jmT0^NGM0:kNh`1e/lD0L;>^04>:
M00hNeX0K@00000<0?ooo`002P3oool>000000060000>P0702h0000S01@0@P0P6EH07amP0P0b<g80
401=DXl0I6FK061HR`1eJYL0QWZS07AVT`1IAgP0IDii05<hIP0j7Dh000000000<`0F0240AP1804T0
A`2MKgD200000003000iD`00EPl0000000<0000000l0002;0000fP3D`m00hlC30>k7_`3oeL/0on7F
0?oJb`3of/H0omC00?o@^`3nc;H0omNn0?oK`P3ogL@00P3og<809`3od[L0n<R]0?W:Y@3odj/0ombe
0?oP^P0?000000000000W00008/0lL2_0000002<Wm@0PYoI08:WhP1gYN40J9[K0569d01=Rm40DiGH
06:Rg`15Pl`0G9GI06NPh01]Z^H0IZKS06JZi01h_nd0N<CZ07O4j01i`^d0Lk[[06ffj01]^nL0L/3X
07S6i`1U^=T0GkCF05N`d`0204fW_`0704>MZ@1OYh@0XXDl0<BeW02^NhD0dkRI0?;oi`020?ooo`0H
0?ooo@3oon<0oooE0?oia`3am/X0hooF0>[ecP2Pakd0i<Zo0:f4R`3Zh>00eOWY0=Gdc@38llh0^NgF
0;S^h033m>L0a>o?0<oac@3ImM00e>k30<OU]01XTUD0SZaX0P000000102VUK/0o]kR0>?QfP3Ajmh2
0:GMf`0N09SE_@2Iel80Z^??0;S[eP3;m]l0co_S0=Cok037mMH0[]Z[0:3AX@2/hL<0Y>7D0;3Vd02/
h<40O[V?097@]P2Xhm00aO;J0=[oi@3EonL0gOoU0?goiP3oon`0oooe0?ool@3oonl0oooP0?Glb`3`
l;P0IG801`000000:`0i0000C00009>Sd02CXm00R00M0000001o0000000007LmG@2[Pih0_IR_0<2Q
_@2dU;D0Ugf/0:b;[@30UZ`0b9ZY0<NIZ038VJL0e<Zn0>7Vb`3V^KH0kl>X0>fmT@3M]GX0O8UB09kF
e025_nP0P9:g09jG/`32ZkT0l_c50;f`J034[P00Zj000;fn002o_6l0c/j90=[EU03Ef9P0c=FF0;[?
U02kdYH00P3;hZh03P3Rk;/0jnZg0>gW/`3`j;D0j^B]0>cT[`3onLl0ooC;0?o`aP3li;80kmNO0<k2
NP2PZEd0EW0R0`0000005P1d?f<0TEU`09EMM01nAfH0ISMS09QhXP2WR:l0^iZh0<b[`P3@/<@0cJ_1
0=Nc`P3O^;h0omK:0?oWc`3olM00ooGA0?ogd03em<`0h^Vk0::XI035a8D20=[GW`0P0<^gN038]gL0
f]2G0=NoQP3ZbYl0kMB^0?__aP3onmH0oNc80?;I]@3YkL40lN_00>KR/P3MfZD0alN:0:2ZI`000000
gooZ0=koh`3<lnP0000002EUV01WYKX0?XND06ja^@1`/[80RlG009_Bd02CblT0JJ^P0467KP0UJDM^
000000`0oooo000:0?ooo`h0000000H0001F0000=00002<0701C02LQGP0T9FD2030hNP0?04A<R`1J
G9D0ACad07IXU@1nKYT0IE:106MFQ@1H@W80AbaJ02dBA@000000400X040LA`176Sh0JCQA00800000
00@0049a001RH@00FUh0bYVD0`0000003`000:T000300=[1a`3T`[l0jL>k0?S<`@3odL<0om;20?oL
bP3oglT0omG00?o=]`3oeKh0on350?oUb@020?oWbP0W0?oYc03oi<@0omfc0?oO/`3oh[L0onRm0000
003ojKh0onJj0000I@3P][40hKF/0000/@1US/l0NJ;O06bOgP1dY>40H9CH06JKg01OW=`0F9gL03n0
bP1BT=D0FI_K062Th@1YZND0IZ[T07:kjP1d`>X0M<3Y07G0jP1_^>T0J;7V07Bnj023c>/0OlcU07G5
g@1gam/0P<oI0080]OoZ0240hOoi0?com@3donX0g^GE0<f`^P3U/8l0lLRJ0?ond03oon40oooV0?oo
cP3ok;l0onRd0?[__@3Ym/P0SZ2_06B4/@3RklH0/VIF0=k6_P3Ad;/0b=ni09;E``2GfM40YnCT0;?/
k@2nl>D0b_GK0<K_c`30j<80NZE]07FTK02^`hP00P000000103mcmT0ooCT0?Kfg@3Kn=<20:[Ob00E
0;oKZ`2?e/l0[>OQ0<_jlP39mnH0boSS0<;ae@2Wf[H0OkfI08k;Z`2WhmH0[nWI0;7Xe02Tek40bn>[
0=;^_`3Emm<0h?oS0>Ook`3Foo<0noof0080oooh00L0ooob0?ooj@3oomd0jOkE0>_oc@2L/P00SX00
00H0000000<0A`0004T0000000000P0000009`3>0840Y6T00000001LCXd0]:330=70f`3@^=00_jC3
0:J9/@2NQ;00/i^o0<^]a03I]/D0g[W40>Fl``3homl0nooY0=o3d`2n]=T0k<bH0<J^IP2[gm80/mg`
0:;1mP29LJ00YG>;0;IoN03^j[L0g]RK0<B^002FMP00/j9A0<74O038c8H0dm:?0<oHV@2abX`0XL>8
0<7EVP020>3/^`0=0>cda`3_k;X0k>bj0?C[^@3^hZ/0lN6/0?oY_03ol<X0ooG;0?o/_@3cgjT0^JmP
08B8=0030000000G04HC@P2;E700Vf=g08YCK@26DW80Y7VH0;BD]`2XQZX0_iZd0<^T]`3:X;80b9nb
0>:b_P3ocl/0on?@0?o]d03okl/0oo;<0?KcbP3YkL40f>6_0:6RFP30_G`00P3Sgj`0403Uh:h0bLV;
0=gFWP3Ygjh0imj^0>KX^P3_ll/0lO[E0>_ed`3^o]X0k?oI0?;ic`3]j[/0gmJQ0<71PP1/PCX20000
000<003IdP2YfnP0000002ifR`000000BhnY06fa^P1V[;D0Jjnh06>XY@1JWh/0D9=hL000000<0?oo
o`002P3oool<000000080240>00004@0001;0000=@0004406aQH02XTH@0_:FD203<bL00W04I6PP15
A800Acmh06eSU01jI8d0L5j;05e<O018<V@0=aY:000000000300600b03/SE@0003<0001A07<a<`24
Hh@0SWZO09=mW`2BNIT0aibN0<^KU`33Sh/0`8n>0<ZQX`3E/kP0fkc00>2n_03V_kP0k<>f0?C9_03l
cl80om_:0?o]eP3omm`0onoB0?oXa`3okL/0onc<0080onk>02L0oo7?0?ojd@3ool`0ooo>02DT2@3o
l/D0ono10?oa``3olL80001Q0000]P3R_KX000250000a`1PUmL0HYSJ06^NgP1_X=l0MZCQ07>UhP1Z
X^00G9KI05ZIf`1KWmd0EJ3L05jUh@1VZn<0I[7F06RicP1W^<`0AIjj04bEd`1OY=d0S/oc09gMn02[
j_l0[nko0:oco`2iool00`3@ool09P3Lool0g?oh0=?LkP3EdoL0km7I0?W>_`3ocZh0omRk0?oRb03o
hl00onJg0>[OZ@39eZD0c>Bc04=]/P1_MZL0fMc60>7c`@2od;80QZfJ06FYS`1ka=00/>oo0<Clo`36
m^T0d__O0<C^b`2ij<H0Y=BX04ac;@2iah40Z/jh0000002/Y/P0k>Kg0>[km`38m^80c?7?0P3>ik@0
5034gjh0`^_E0<;gn@32mN`0`O?R0:gSc`2AdKX0I[2I06>_V`27cL80T=KH09SKeP2Rfl00^>2d0=SZ
]03Lm<L0fOcJ0>oojP3eooL0l_oo103oool01P3oooL0j?oM0>Woi@3hoo/0gOl00<oN00L0000002/0
@`000840002`Jcl0/6/o0=:PK`3CVW80ahEV07]g]@2dY</0[I>i0:Z9[02MMih0WGFH0;JH^037/M00
dKkI0=O0eP3VamD0lLgE0?kok@3Se<40aZNk0=:gc03J]h/0000009C9d`2Pb_D0003T07HkF02^IeH0
/W540;Ik<@3MeIH0`j]L0:=o002hZe`0^/^:0<;>S02ocH/0`MBH0;?6Q@2mbhl0fN2X0080k^no00d0
l_C60?;``03_l<00mNfn0?SY^@3gh[<0on:e0?o[`P3ol/L0o_300>_IWP2m/VD0PGX000<0000001L0
LT1X09IUQ@2CGWX0Vf^:0:AjV@2fTk80Yh6T0:N0XP2kU:l0`ibc0;>1U03>XJh0nLO70?oPd`3oj]<0
ono?0?o^bP3ik<<0lNZn0?;]``3IcID0Z:5H0:jWG`020=WLYP0?0<gDV`2V[fX0h=fY0>;Q[`3OhZl0
g^Bc0>CZ_@3NklL0eO7D0=[ni`3/on/0looT0>3bb@3CgZ`0[[Ab00L0000000H0FIJh0000S@0aNIH0
F9nY05bSY01^/:ab000000`0oooo000:0?ooo``0000000P0500l024GDP000400000e0000A00N6e/0
:QmI03P/I@80?SI`02L0D4j8040jM01BCHD0HEbB06AEQ@1LCh80Ac9V03PQE@000000000U02@0?`0Y
44H0000g00009`1aCFd0RG6B09JB]`1nMjD0[Zg@0;2Wa@2jWZh0djVW0<NKW@34WJ@0bjVa0<n_]P3C
/kL0f[Fd0>:j/@3Z_[00lLBg0?oC_`3ohlX0ooCF0?ooi@3oon@0oooO0?oof03oo=<00P3om]007P3o
oM80oooD0?ooe@3oomL0oooC0:6mUP3on<T0ooC6000000000:H0flSA0000000005L0002H04:9c@1?
SM00IiKH07>Lf`1lY>00RkW^07j_j01`Y^<0JJGR06ZXi01WZ>@0IZ[T06bbiP1/^Ml0GkCC07GCh`80
000000L0B8k>09CBm`2Wg_l0]ngo0=3oo`3Rool0k_oo0080n_oo01H0_n_o0;oTo`35i?l0a=Go0<kR
o`3Qiol0on?j0?o]f`3oon00oooT0?obb03ji[H0dmJN09RnS01T/]<0H8C108n@]`00KF/004eJ001b
K@0kRGT0f?oo0P3Jool03`3Gool0f_oT0<Wbc@2iiKh0XLbH08BgP`2_]hL0d/>:0000003=Yj00b<gM
0=_mo`3<ool0aO?M0<;/b@020;kNZP0N0;;J[`2UhmX0ZNO_0:SSe`1_/iT0FZ:308C6[@2KflT0S]C@
07o;e024cMH0XmkB0;o[c@3DkL80f^jl0=Kec`3Son00l_o`0?Ool`3oooh0oooo0?Goo`3fool0nooo
0>coi03Co<d0noof0?Goj`3^omD0j?Jm1P0000000`130000L00_078000020918000F0:QS0039S5d0
`h1T08Mk]@2HP[80VGfY09ekY02QNih0]YZn0<Rhg03Ab>d0clS]0=;6i`3KbN<0l=CT0>S4c`3G[;@0
l]S40?kHc@3mc;l0iKN>04F=[`80000000l0QFFE0;bIS000`I`0dm:Q0<o3O@35YUH0Y90l0::WF02c
dYT0^mJN0;C:RP2idiT0c<j;0=kFU`3YhZX00P3_jKH03@3dl<40moC70?Oba@3llL@0o>Vl0?cR]P3j
gK00n]na0?_U]P3bhJd0i]RK0<NlL`2JR@000P000000601B7dd0Oda`091JM@2QJh<0ZWZB0;>7W`2/
PId0TF210:^0WP2bRjX0]hjX0<jT]03a`lL0om_D0?oOcP3oglT0omo30?OM]@3egkD0ln:f0?WW_`3M
bi<0XiY@0;:UG@80d/jE00l0eM:I0<K4QP3LgZX0hn^m0=gY^`3Mj;/0eNNi0<3M/P3>lMl0ao3`0>7o
k@3<k]00bNFo0<?HZ01XSUH0O`00000<0?ooo`002P3oool<0000000801lKF00X9f@0000j0000=P00
04P0719?03XZH@0l<FX204a5OP0W04e6O`1GEXh0KWBZ071^XP1EBh40A39V03hTEP0/3d8000000000
D00/04<0<AM;0000;P0008`0Wj7909fTb`2JZmH0LGN]09n[e`2]^ml0];780;nMY`3=YZX0bJ>Z0<fZ
[`3@/;H0e[Fh0=fh]03U^k00m/>_0?oB]`3oh[l0oo?=0?oohP3oonH0ooKN0?odf03om]<0ooG<0080
ooS?01d0oooB0?ood`3oom<0ooo?0?oof03oom<0lm:M0?olc@0000000974000000000:d0002M0000
U00009X0:WJk04MmaP1QR/h0O:CP08Nfk028^^l0NJoX072[iP1d/>P0M;;Y07BcjP2<d_h0]ooo0=;o
o`030000000604J:bP1j_^`0SlSf0;7Ro`3Lool0o?oo0`3oool09`3@ool0/M7o0;SEo`30h_l0b?3o
0=;mo`3Xool0oOoo0?ooo@3oond0hooA0<WV^02A`Y80P/>_09OLi02Efmd0Tm[I09_[gP00ooT00?oo
0>3ol`3Dh_40en_o0;Faj03Rg/40d?K>0;[T^02Pcj00Q[Z80>3</03/aih0j/:O0>B[RP3HXfd0cnkX
0=;oo`38noT0`_7H0:KEZP020:C?WP0M07g4/P2:d]00SmKN06FaZ@1g/8<0X]F^09gH_02ThM00V]_/
0:CRl02ZiN/0bOSX0<gcf03@l<X0coCC0=?ieP3PonL0jOo`0>gol03fooL0oooo0=coo`3Gool0d_oc
0<gkd@3oonP0n_oK0?3ocP3Xnkd01P000000100001@0;`100480001j9P020;]f000W0000000`0000
<00008l0002JR;T0X8nn0:jG_`31/MH0e=3e0=?An`3AcoP0bl[e0=?>n03Hc_<0i]C`0=_3fP3M`=00
m_;K0?ooo@3oonl0iooO0=WifP1KWjh0000000400@2JVfT0AU6206U6J`37^GX0/j=A08V@@01oX5h0
^]ZW0:?7SP2`cYD0bm^Q0=?@S03HfYh0i]nV0080kNJa02L0lN^j0?G/^`3mkl@0ono50?o/`@3oiKX0
oN2e0?_Q]03ggjl0kM^S0>?HVP3Je9<0N88^0000000004@0FBUG07<kF`2FFVh0YFUe0:U`OP2VL8<0
T5]i0:UjU03>Y[P0_YJ^0<>M]03S_/X0omGE0?oOe@3oh=@0on;@0?oQa@3ceZ`0lMFX0>oEZ03`fJ`0
gm2H0:BHC@2cYUh00P38/W403P3CdYL0e<nD0=OEV`3Eg:P0dn:b0=?U^02lejH0W/RO0<_bk030jN<0
]nCD0:kMa@00]j00SKB3P000000<0?ooo`002P3oool<0000000802<^L@0g07/0000n0000800005<0
5P14048kM00n>WL204U1N@0704M9Q@1HGYT0002<0000S`0006H0>ai>038A@0020000000803l0AP0`
0400:@i502LBB`1oRKh0`Mko0;SKo`2@`=D20000000D07RVg@22Qk40SVZ60<JOY03D[k40ekJi0=^n
`P3Q`/80mlc60?oGb`3oflD0on300?o_a`3oomh0oooZ0?ooh@3ol=P0on?@0?oRb@3oh/820?oU`@09
0?o_aP3omLD0oo?40?o^`@3oold0oooE0?ood`3on//0ooW;008000000180Ykg]0000l`000>@0003M
021TY`0gJ;<0DXG<07JRg`21/>P0SKoa08>ikP1g/NT0N;?Z07^fk027`?40U<[g0:gZo`3>ool20?oo
o`060>gHeP000000HZCJ07^Qe02@[n80eOoo1@3oool09P2cdOl0^mko0<GYo`3=mol0cO[o0=Goo`3Y
ool0mOoo0>7oj035m<T0P[F608^oU02Uf/40^NkQ0<coo03Mool0k_oo0?ooo`3kool0iOo^0=71bP2o
Y<00SD]D0;fCF@36fj<0[LnH08jlQ@0/H2@0hjai0?3O/@3abk@0g<^Y0=33S@3>m]d0dOki0<KehP2W
fk/0SLFJ0P1JX880701g_L80S]3D08o@_P2Kd:H0XLnN09kE[P2UgL00Z^CF0:3Ml`2fk?`0a?Gk0<Gd
k035lmd0aO3A0<Sab`3Dom`0h?o^0=_on`3PooX0iOob0>com03Rool0iOoo0>7om`3oonl0oooo0??o
m`3Zm^08000000030000?`1nDel0YUT000<0000002H0D@0007/0002E0000W9K:0:>Qe02f/=`0al[f
0<_Ao`3<d?l0blkl0<S=n`3=coh0eM?o0=K?l`3UlOL0inc]0?Cok03oool0o?o`0=kif03<k/X0^=B^
0;RfP@2/XF40=02A05a8Q`1oGh00_k>809^F?`1SOc<0U;^50;3BWP2ecY@0cm^P0=WT[03>fil0e^6X
0>WY]P80m^nn02L0m^bj0?GT/P3oj;d0onRo0?oX`03oi;/0on6g0?_L[`3deJ@0j<nD0=c:Q`2n]V/0
E6HC000000114T@0H2]D08iFL02PIGL0YFUg0:9UL@2`N8@0^XVJ0<VS]P34VJ`0^8VN0<BGZ03cc=40
om[D0?oMdP3ogM<0onSF0?oZcP3ef[00k]RX0>cHYP3ZfJL0h]ZU0:6JC`2dZV<00P2j[fT03@34_gd0
b<Z=0=CDVP34e9`0c^6b0;[EX`27[GD0SL:c0;_Vh@2mj=/00;VX000Q7`00Fe@0P@00000<0?ooo`00
2P3oool;0000000901`0000005`08bY[0000:@0003T03P1;02HOF`18BhP0>SEa0080?c]g00D0ADn>
04iGU@1<DXl0000_038C@P040000000902T0<`0n8540;Q=804U9Q@2K^_<0i?oo0:OOo@1[[J/0Lk2I
0080000001<0OHFd07UIO`2ROI80f[Fd0=nn_P3SaLL0kMGN0?oPhP3ojnD0oo7J0?oed`3oml`0omFc
0?oT``3ockL0om[70?oSd@3oill0on740080omjk00X0omVf0?oL/P3ofZP0omNW0?od_03ooll0ooc;
0?oda`3on<X0oooJ0P0000006@2PZMT0Z[_`02<jI03Zool0AEVP04Z4c01WWmd0Mk;X08:lk`24_O00
Lk7X07B`j@1g/nX0O[S]08_2l`27^>h0Ymoo0<Ooo`3oool0oooS0=jRP@1=C8X0J7J]07f5_02R_>D0
1@3oool04@3Zn?l0aMoo0<W`o`3;m_l0b?Ko0<Kfo`3Cool0dOof0<Soe`2<`IT0W<B?0;3FXP2ki/80
/ngQ0000R02Xk_H0^ooo00<000000180C00008T0002Q0000aP000;NgJ02O^WH0K9]P0<>6>@3H`H<0
i>nn0>3H_02mh//0X/N=0<S[a03Am]X0/=bd09c@Z029/WP205ZGJ`0L08O0ZP2Yg]80Z]fj09_3R@2L
biX0X=>X0:GJ`@2Wg^00Z>3i0;obo`35n?l0`_Gb0<CdgP35l/T0eOSA0>;oh`3KooL0h_oo0>koo`3h
ooD0ooo/0?oom03lool0oooj0?oog`3oool0joWo0>?biPT0000000<0M6jM0000000000000P000000
9P2BT<P0TX_209>FcP2MXMH0VJ?J0;:nl02oc?l0bMGo0<SBo`36c_l0aLoo0<C=o@39c_d0b<Wa0=SQ
o`3cool0oooo0?[on03]onP0i_?40=cbc@3<lml00>L00000001d0:00U6N<0:64V@36_9T0T8de07:M
IP3?ikT0f^o30=GEU`3Kf9/0f^:Y0<[FV03MjKD0l?;20P3on<d09`3ni[/0n=b^0?WJ[@3oh;H0on2h
0?oR^`3oh;P0o]fd0?[K[`3aeJ80dKee0:^XF@000000>P0f03h=?`21CG80VVN40:McRP2[M8H0/GV6
0;f8TP3=WZL0^XnU0:b0W030Tj@0jKZk0?o@bP3ofLh0omS;0?oXe@3ol]X0oo3A0?o[a@3ciKT0jm^X
0>SKZ03FdiX0ZJeV0;FcKP020;JeL0090;c3Q031_gh0c<jB0;K7S033gJl0X<:A052@L`0YMW`007QZ
08D00000303oool000X0oooo30000000200004406@150000:P0C3D/01P1902l0I019A7h0@CM`0P16
@7L04`1=DXd0Cdn:03@fM`0001T0Badn05LU?`1W>E@0GC9B03h0>@0d3ST0AAe603H:<P1`P[h0^NKo
0<Cfo`1nald0KJR>05j@002=NC@00P0000004P1/EH<0UGVG0;jMZP3W`l00j]3E0>gQl`3okOh0ooGd
0?oli@3oomh0oooG0?oU`03ofKD0omo20?oTc`3oiM80onS@0?o]c`80ong800X0onc30?o[`@3ohkL0
m]BP0?cQ[@3ojkX0oo730?oeb03on<X0ooo@0P0000006P2>PJl0Tg^N09V4X`1cHY<0DDnA059m`@1E
UML0IZWR06jbi`1b]>T0Kk7W06n_i`1b/>T0NKG[07J^i`1`Xn00Q;3Y09o2m03Kio@0oooV0?GBa02Z
Rj<0Q6ZF085i[P3<h?D0m_oo0`3oool04@3gool0e^Oo0=Geo`3Iool0cooo0<Gbo`31l_l0__7o0;_^
j@2Wf[L0b]bP0<[PYP30gZH0TMC80000KP000000002S00<0000001<0K2T_0;N@H`3B0000d@000;RY
G@2NZET0Lj=X066:C02fcI80e>Nh0=_cb03>i/@0^MbZ0:c?U@38jKd0coCD0;cZb`2XbY<0ZkQc0080
Z[n801`0Z<fQ0<C[d@2`e:40V<2509g:U`2[f[00b?gZ0<?ko`2ek?l0b?co0<_oo`3Bood0eOo[0=Wl
c`3XomP0o?oZ0?ooo`3oooh0oooi0?ook`3oonL0oooU0?ool@3oon`0oooK0?ono`3]ool0iOOC2@00
0000:`1<Hih0:TjP08F<b@25S<T0SiWC08VGd`27VMD0T:3I09j[h02K[>80//Ge0;_?o`37f?l0cMWo
0<ODo`32dOl0_<_l0;g9n@2nb_l0cN?o0>3oo`3hool0kOof0>Woh`3]nLh0g??>003;0000;`00002Q
0;P0W02cR:H0_:B[0=OEX`2=R2l0c]f^0?3gb`3/l/D0hmJK0=K<R03>di80d]VL0>cZ^@3ojl400P3o
k/L09`3oi;h0o=Z`0?OBYP3gdjL0n]R^0?oT_03oh[X0o^2f0?cO/`3ggk40c[M_092FA0000000E1a3
07U;M023DGH0Wfb80:ahSP2eP900bYRP0<JBVP2gPY00[7R=0;j@X`3Q]k`0nlk;0?oFdP3ofM40omW:
0?oRcP3ojLl0onc;0?k_b@3bj/00k>2_0=kFWP38ahP0YZEM0;>aK0020;_1P@070<C3P`37_G`0Z;5^
09^iO`2Paid0;Fa6001bIP27000000`0oooo000:0?ooo`X0000000X05`000000000N0400000J0000
C00L8V@0001>000ZI`14>6h0@BYK0P1YCWD04`1bHhl0H5:4000000000000FciY06A2J01O=UP0DRM:
040JA0177D@0PTmO08IiW@1cMjX0@T>204Y?S@1f/Yd0N[H0001[002mgm@00P0000004P2cZm00e/SN
0??OiP3Wb<L0k]CK0?;Xo@3mn?l0oooo0?ool`3oonP0oooQ0?oofP3oomL0oooV0?ool`3oonL0oooR
0?oogP80oooH02L0ooo@0?ond03oo/l0o?C40?;QZ`3ik;X0ooG70?ohbP3on/`0ooS:0?oof@0fCiX0
LGF[08REb02?ZM`0S:KK07V6_`1aPKT0LZ3H06^Zh`1QZ>00J;3U06N_i@1X[ND0IJSS05jPgP1NX=l0
Hj?Q06ZYi@1j[NL0T;SZ0<?AfP2UW[T0ZYRh08Ei[02WYm80aMCk0=_no`3bool00P3`ool0403/ool0
j?oo0>Soo`3Vool0i?oo0;kco`2ikOl0]ngc0;C]g`1l/X800;R;0<oPX`36gZ<0X9T0000000130403
0000000D0?oNg03oj]00j>S40=;NY@350000S:1F082SH01LUF00//nD0<;P[P3FllT0cNo60<c^a03<
jKP0]mNP0<7V_02ij<P0bo7B0=SZ^@3WgI`20=GGVP0>0<oS/@2niKh0OK>308^oT@2NcI/0_NO10=Go
nP3Fool0dooo0=3oo`3Hool0h?oo0>Oom03/omD20?oof00<0?ook`3oon`0ooo/0?ook@3oon<0oooK
0?oof@3oom@0oogJ0?ook03`ooh0J7XW2P000000:P0009P0QYGB08JEdP2>X]/0Q9_H07nHeP24WMT0
X;CW0:6ij`2_b?P0]m;o0<;Ho`35f?l0^loo0;oHo`2idol0]M7k0;?Lo`2oh_l0c>oo0>7oo`3/ooD0
jooO0>GmeP3LmM0004@00000RP000=00003:0000j03/ool0d]ZM08N8<@3]i[<0m?300?C/_@3ahJh0
d/Z40<;4N`3RfZ00kMj]0?oQ^`80onK300D0onS80?oQ_03mf[00nmZ_0?SJ[@020?oS^@0P0?kR]`3i
hkD0m>Fd0<g1NP0R01T0JCAJ074jGP1P:e<0RU5[09aTN@2BDf<0YFUg0;Z4T02eOXT0]7b90;Z4T03<
WJL0i;Ni0?;5_@3mc/H0omG:0?oOcP3oim40onS;0?oZaP3ijl<0m^_10??U^03IdYP0al600<ZmO@2V
WE820;NjMP040=KFWP3:bXh0OY/007FRKXX00000303oool000X0oooo100000004018OX40:`000100
00000000400000h000000000000J0000A00003X07B9V01`QI00004/000mA03<OE01;94P206D]?`0A
05d000000000ABYI0000001?<5d0DS1J05@`F01E;540?AQ50000QP0007/0002<0;2=W02IQ:80=R5F
05h0002kXkL0100000003P3kool0l>Wl0>CBg@3dcl/0onO=0>kSm`3flOl0ooOo0?oooP3ooo@0ooo]
0?ook`3oonT0ooom0P3oool01@3ooo@0ooo`0?ooj`3oon/0oooS0080oooM02@0ooo50?7U/03ck[d0
noK80?oib`3on/`0ooS:0?ooc`0GAi`0CV^]07fMe@24[ND0SK?X09k1l`2C[N40Tk[Z09?6l`29aO80
O[o^07>gj@1W[^@0F:3L04jFe`1DV]X0FIoL06:Vh@1;TM@0FYKH07>LcP1oU/h0PY7;07n=`P28YMH0
YLS]0;k_o`3=ool20=koo`0<0>3oo`3Rool0iooo0>Soo`3Wool0fOoo0:cWl@2Zimh0W=O407:CD`00
N4H006AJ0`000000602R0000T6F209YkV`3>cOl0m_7o0>K^eP3>lLh0`>:d03A>NP15Q5L0HIYX0:gB
WP38iK<0cNk30=3_a03DlLD0fO730=7^_`32h:X0X]Ja0:kSb037kLd0fo;90>Whc080^lnE01`0]=^]
07ZgU01//I80QL2J0:_FZ03?m=80eOoo0=Woo`3Fool0eooo0=_oo`3Wool0ooom0?oog03oomP0oooF
0?oof`3oonT0ooof0?oolP3oon/0oooT0?one`3ooLl0ooc?0?ooe03eomT0UZUO2P000000:P0008/0
PY[H08:Jf02?Z^<0PIkL07NFeP1hV]T0VkO[0:?1lP2Wa_D0[Lgn0:k;o`2_b_l0[LWn0;kLo`2ggOl0
/]co0:GFn02Wf?/0^>Co0<cco`3Ooo00hooQ0=?fe@00b`00e^7K0000a@2DZmT0002m02PI003Cool0
^m2Q08J=>@3B^gH0l=^U0?;JY@3bh:`0eM:@0<ZnM@3afZ<0m=>T0?_CZP80on:k02L0onc60?o`bP3o
lLT0o^>g0?WO/03oiKX0o^>g0?[N/03eh:l0kNF`0<g:Q@1X0680P`1j04l0@P1a=U<0S51U08I6F@2b
MWT0^gim0<24P`2oQXX0^7j60;EjP`3?W:00g[2[0>k1/P3lcl00omG40?oScP3ok=<0ong<0?gZ`P3b
i;P0mNg40>kU]P3Eeih0a/>20<c8R@2i[FL00P2i]W800`3BfZH0a=2I04Ae@02;000000`0oooo000:
0?ooo`H0000000<01P000180000000000P0000002@0002/0000R0000BP0R8f@05aQJ0000?P0?34h0
9A580000<@0204D0000N04HQB@000640@B]N04dbH@19;5/0BbeK05<bG00i64H0>2EM04]4O@0008/0
001l0000S01V@V00@bYK08d00027R:l0/:S80;ZR]@2[Nh40i_;o0>Gbo`3LgOP0f<C@0?KBd03okm40
oo7[0?S/o`3om?l0ooco0`3oool00`3ooo40oooo0?ooo`020?ooo`0<0?oon`3oooD0oooe0?oolP3o
onX0oooM0?ooa`3bj;D0l_300?Kfb03nnL/0ooS;0P3oolh07000;hD0:f2_06VMg01jZnD0Pk7X092l
l02Pb_X0Ym7n09k@n`2HcoP0U<gg08g9m01e]nT0G:GN05:Lf@1?V]P0E9kK05RRg@16T]<0<Gg604F;
d@1EV=P0K:?M06^Re`1RWmH0OKoZ09WGn@2Beol20:WVo`0W0<3ho`35o?l0booo0=;omP30nN/0[N_R
093Ed02Si>00S[^J06V3AP00LP00TFD008H000340000CIC>0000002ETK80YkKV0<Oio`34mol0_>oJ
0;?R_`2ZeJ@0001>0021@0000:D0e^^e0=CW/03GjkL0g?;30>7da@3Qll<0d^k00;GAU@2KaI<0Yn7:
0;SXc`36kM00_nK40080YMBZ00/00000001[W000bKX0^>O>0<gbdP3Foo<0f_oo0=_oo`3Lool0gOoo
0=koo`020?ooo`060?ookP3oonH0ooK90?oof03oonH0oool0P3oool01`3oonh0oooV0?cne`3goM00
kOoE0:^oP@1`RCX02P0000006`00;H40TZ[R09:ZhP2D/>H0S:_S07bQg@1fXm/0R[WS096hj`2G_^l0
WlGe09bolP2J_Nl0YLWf0;WPo`2hhol0]N?n0:gLo02Oe?@0Y=Wb0;7Um@2jjnT0^n[K003W00000000
P6fH0000X0020000000=0;7Bf`3Bn>D0_MFR07J6<`2fW4/0jLZ>0>[AU03ZeYX0f/j;0=:iLP3be9l0
n=f/0?cL/0020?oW_@0W0?oY_`3ooml0oooF0?oaaP3oik/0on6h0?[S/`3fgZd0knFa0>3MXP2j_GH0
MD1S04D0=01i06d0Sf6607i9J`2HG6d0_Gmj0;UkNP2cM7L0ZF]d0;IjOP3AVIH0j;Z`0?G8^03hbkL0
m<Ra0?O;/`3og<<0onO:0?o/bP3ljL40l>:c0?;/`@3Vi;80d]>H0<K6QP33ahL0[:m[0080PhDi00<0
_]>R07:G00000000R`00000<0?ooo`002P3oool50000000300d0000<000020000080000000X0000T
0000<`0002d000]602HTH`0H4U40000b01<7A@0003D0>Qi=0P1:<5`07@11:ed0000003/[I018<fH0
B31Q054eI017:e/0>AY:04L[FP1C@780002B0000J@2FHVX0Ld]U050cH@1XU;H0AE6606M^YP2V[]X0
bmKl0<[Fn`3:eOX0am3c0>?;eP3geMH0on_G0?ong`3oo?/0oool00D0oooo00D0ooon0?ooo`3oool0
oooo0?oomP020?ool@0W0?oolP3ooo@0oooO0?olb03cjkX0lo310?[ba03nmlT0oooF0?oofP3oomH0
oooB000hR`14Q<T0KZOR07N^i`1m/nT0SL?a09[@n02SeOd0W]Gk09O@n02=b_@0Pl?a06Z`i@1NYml0
EZ;L04^Je@1=WMH0?Y7=02]n`P0cPlL0AYOC05BTf`1NZ^40Hk7R062ag`1b_^H0GjgO0080IZgT02L0
XmKm0:[RmP2ak_00U=S908_Ed@1L[jh0:8B704FMY01Q]L80D9B>0;n=002WN0001@Ia0000Q0000000
JYSD0000002Zi?l0UM[o003Hd02GelD0W]B_0000@000MhP0003>0000`P3NjK00fN>T0>3]]P3Pl;h0
ho;00=gb`P3>kKl0WkQb0:G;U@2Xg;`0Y^;B09gIa@24`9`00P0000006`2U^:L0[LO20<7bj03Ammd0
fOgJ0=coo`3Sool0hOoo0>?oo`3Tool0g_oo0?ohi@3oon/0oooX0?oE]`3olLD0oooD0?oohP3oooX0
mOof0?ooo`3oonL0aoKa0=[ih@3QnmP0`>6c08N_LP0<0000008009OC01@0U;GY09Nhj`2<]NX0PKOS
07NjfP1n]N80Q;7V096mk@2=^>/0UL7^0:CBl02bhoP0Z>3^09O=k`2SeOL0WM;d09[Bk`2CdMd0TmC>
08k=^P8000000140MjIo00000000000000000?ooj@3VoKd0Z/N?07n:=P2iXE00g/5m0>WBU@3WdiD0
h/j=0=o1O`3]cID0m]ZX0?cP/`020?SU]00W0?gT]@3oolX0oogB0?occ03oj<80omfe0?WP/@3agZL0
jM^Q0>7KWP2TZE`0DQLm07]5J02IK8l0O4mi07E0H`2RJ7T0_Gii0<22O@34RHT0dInR0>Ri]P3od/L0
omW<0?oNcP3og/l0omc:0?oG_`3heKH0on6o0?kZ``3giKX0kMf]0>kW^@3UhJd0d<nB0;bhL`34aHH0
/[Ib0080Mi9>00<0FhmU000000000000R`00000<0?ooo`002P3oool20000000600h0000000000000
00000005000030000P0000002P000640001E0000;@0S54d0:BAP0000@00E04d0000d0000>@000702
05I?Q00M04m<Q0000000<2MT03X^I`1>>Vd0BcAW04<[G`1I>640Jd]`071HP01eI900002C09Vhd01[
[;/000000:Z6T`1GEHh0CV6Z0;?4n`000000`<7Q0<Bnf03>bN00i=;P0?SKh03oiND0ooOZ0?ool03o
oo`01@3oool01@3oooD0oooo0?ooo`3oood0oooa0080ooof02L0oool0?oom`3oon/0oooA0?Kb`03e
kKd0o>o00?oja`3ooll0oooN0?oog@3oomX0oooB001S/01=Tm80HZCN05>He01^/>@0PlG^08o@l`2<
c_00Ol;]07Rmj`1e_>X0OL3^07:ij@1W/N@0F:OK04VMdP11Uld0>Y7:02V0`@0YPL00:8:o02n7`P1K
ZMl0Fj_M05NZf@1?Y=H00P13V=809`1X/Ml0Q/kT07_6a`1I[:D0054h0<GC/@2e`[H00=>f0>_]^`3Z
i@00aKMb0=V_000W:FD0002C0000X@0nO/@009>j002Z^P00_;h00;^h0000003dfn/0omK<0?oV`@00
0<`0jo:n0>3X[@3EhjH0j>ni0>?^^@3Qk[T0eNjo0<CR[`2A[680Tkn>09oH_`20b<800:P0001C0002
000:2`0O09P0002ePG`0dL>^0>Ong03Mon/0h?oo0>Coo`3Vool0jOoo0>[oo`3Mood0i<oK0?o^fP3o
omP0om^k0?oF[P3om;h0oooF0?og`P3oi;00mOoP0>Ooh@3EoNP0cOSX0<cad@2TcY`0b`000?H0002i
Jb/0SeL003X000080000008006FZ01D0N:_P07>Rf@1m/N<0P;[K07Rod`1[U=@0II3A07JTg@21]>H0
SlK/0:;Kk`2;c=h0MkcG07Jfh@29`nX0Um7[09gIi@22a/00FJJE0<bIF02aQ3L00`0000003`3noOT0
nooW0000``2ljLh0OJ]h09VTEP3@^W00g<=n0>_FVP3ScHd0glV60=c0N`3VahT0l=FN0?WP/0020?ON
/00W0?7CX`3mfZd0onG00?o_c@3ohl80omRe0?gT^03bgJT0i=2B0>7FU`2EUdH0KcMJ09QVP`24DWD0
Eb=?08UIO`2aPiX0d9jO0<jHU@3?UY00fJJR0?31^03od/D0om;30?oIb@3ofl`0omO50?oG`@3lf;X0
m]Ja0?GS]`3ch;<0kMNV0>O=V@3Neil0fM6F0<S2P@31_GX0XJUT0080GhY?SP00000<0?ooo`002P3o
ool00`0000007`0000l000030000000>01<00000000000000000000[0400000a01/0A@0_8UX08QMB
0000>P0005@0000A0000J@0009<206I`Z@0B0000U`0000009B5R03T_J`13=Vl0@2aR03DNE01fE7D0
RVZ806]GQ01R@6D0OhJg09jeh@0007D0001?0000V02<SLD0UZ[b0P0000001P2a/=D0];_P0;c=m@39
doT0emWm0>cVo`P0oooo00D0oooh0?oon@3oooP0ooob0?ook0020?oom`0W0?ooo`3oooL0ooo`0?oo
gP3hnLP0noG70?oeaP3mll@0n_720?ood`3oomd0oooG0?ood03on/`0oooA001W[`0[Ol00CI_E066^
gP1Z^N00LL3Q06jmh@1Z]n@0KKOV07Roj`1oa>h0N;o[06nii`1S/N00EZWH04ZOdP0iS//0:Go002R1
_P0KNK406GVV02V5]@0WQKD09HBe008098:g0100:8Fd03:>X`00Z[800=OR003NbP3WeJ@0hL>A002g
U@3]cI/0l]NU0?OR[P3kj`00E8AF00T2000004T0`l`00P0000005@3Mm_l0h>So0>?Po`0R6R40onCB
0?obcP3ClM40jO2m0=cVZ`3Di:X0g^^f0=WZ]@3IiJ/0c>Ne0;[GWP1YS4L0MKRN06V]S`1a0000C000
08D000020;]kN`0L0=NERP3c[iT0oo3:0?ooh@3Von/0d?om0=[oo`3Tool0kOoo0??bo`3Sc>80cKO>
0?W9cP3oelL0on;00?oL/P3oejH0onfl0?oPa03a`Z00k>>g0>7me03Co><0`o7H0;?P^P1<K@00o]gF
0?oRd`80000000H004ii0:eeO@2TGTh0JUD00000001300050000000W0015P`1<R/H000000000001S
WMD0A7Vo04]c_P1LS</0NkOQ0832gP00XJl0AYVc04>E^@1>V/H0I:_D07[0fP1W/[L0jLF@0>KNYP3_
e:<0j/2@08a[00000000eK2L0000000009T000170000O`2W_H00/;Q_0<o<Q`3KbhL0jmZN0>;=S03L
a7l0gL=n0>?9R03af:40n=f^0080o=Z`02L0l/VM0>fkS`3haih0om>/0?oK]@3ofK@0onBi0?;CW`3S
_h40dKif08R90021AV80RDeT06X_D02;EWD0]8VT0=>]_P3M]l00d9fN0<nIU`3MZj00m/Fd0?S:^@3f
bKH0l/>a0??5/`3da[@0m<Va0?S@/`3`bJ@0kLVO0>k=XP3]ejL0j=:N0<[1O`3GdID0b<J70:FPEP1Y
OSD0T000000<0?ooo`002P3oool0100B000060000000000D00060000000:00h0=P0004809bAS02XW
I@0F4U<000170000C`0005T0B52>05aUX080J76Z0180AU:B0000AP0J55L0>S9^03`bKP0g8e/0>b5C
06IIR`1PAg80FSAI05PV@`2SSZ`0MFfO09BLb00003h000250:B]f02of?l2000000060;N]b`3Dd>H0
]lok0;gDo`000?l0j_oo2@3oool0103ooo80ooo]0?ooj@3oonP20?ookP0K0?ool03oond0oooZ0?oo
g03inll0o?_=0?gjc03im/P0nOK60?ood`3oomd0oooF0?ood03om<L0ooS:00000000I:h0A9G?06Ba
g`1ka>X0Ml?W07?1i01W]mX0DJ?505^Zf`1/^>D0LkgX0080LKcW00X0I[CQ05NYf@15V=00=HS903R=
b@19W]00GK3G07;2g`1/_=`0^nko0P1_/>H09`0TL[`0>8k306N`jP2Neol0eNko0=_Ko`3M`/T0dhmS
0>>^N`3[/Wl0k[b70000000T7380j_710>c/^03VhJd0`H400;V>0000eol0d^Go0=GMo`00Df00oo7K
0?onfP3aom<0dnk40=3X]@3Ai[00cnJa0<_T/03?fi/0`=BE0;C=001_Y700TjYc0000002`0000U`00
0<d000020<5kJP0O0>^VR@3od:L0oo730?oea`3eom40o?oP0<kdm02ejOl0c^oo0=75iP2jZ/l0eKoE
0?oDe`3oiMD0ono=0?oX_P3ogjl0n]6W0?o=`P3_^9`0`jMS0=OZ_@3Jmm80a>Jl0:kFY@3Ag<l0iNOA
000oO@00=@00[k<005hXB0030000000405AG001N8P00H@/006T000@0000000X004J6002Nc@25_NL0
097804Ii_`0nIK40O;CM08S9h`00bmH00:nY1@0000001@1U000000000<_4P@2ba:T0RIFi00800000
0100oo?;0?oig@3onND0ooKO0<[`dP2mdID0a/n<0=CHU`3Nfid0jm^P0>_GVP3TcHd0glJ30>K9R`3f
ejD0n]V]0P3lf:l09P3jeJ`0m<VO0?K<X`3dbZ40nM>X0?cL/@3oi;X0lm>P0>JoQ@33ZUd0L3MI0898
I@1e>UT0TEaj0;jBY`3?Zl00f;O:0=bnc`3@YkD0ahn<0=ZTSP3P[IP0ikRT0=n/W03R[9`0iK2N0>Rg
X@3bbJl0lLRZ0>o9Y03ZbY/0i/FD0>K=V03WeZ80`K=]0=?BUP2k`h@0R:1LT@00000<0?ooo`002P3o
ool20000000301H0000:00002P0000<0000000`0000R0000000004804AMJ02<[KP0S;W80015F0000
F00004L0001W049>SP1KJ:D206A_Z@0B04QGV00004`06AEI03TgM`0j;VT09P1=06AAP@1WEhP0I4ej
05lmIP3jdLd0ejV/0<2O/0000740002I0000X@000;T0/M[o0P0000000`3nd<d0g=CV0;GAoP030000
o`X0oooo00<0ooog0?oom@3ooo@00P3ooo403P3oonh0ooo[0?oohP3lom@0nokB0?gnd@3inlh0mOG8
0?_nc@3oomX0oooO0?oof`3ooll0ooC70P0000005`00DZ8008c805NRfP1//nD0Ol?^06>^c018W:`0
C9RC00000000L:d006BX05j/g@1R/=l0K[_U06Jdh@1CY=P0AYWA03jCc@1CY]D0L/3S06^hh@1g_nH0
_O3o0080X=Ko0280FIcR042;cP0oTL`0BioF0:CFo`1ga]H0OLgE09C0Y02_]XP0[jmg0;bWM00VGBP0
oooo0?ood03`mLD0mNF`0?SEW03Wb`00d[d0002W_`37f_l000000?oO``3ZhJh0d>:W0;gW`035j/00
anNh0<7T]P37gZ80aLj60<;BT01gL`00]jIO0`000000:`1h0000ScP00:9<002RC00000000>FUKP3g
d9@0lmJL0?WY[`3oo;h0oooc0<OBn@2__^X0Z:?B0;NYcP3J`mL0nm7E0?oTe@3olM80on;40?oB]P3i
a:/0olf[0?oG[@3I_gT0gMZM0>7Z]@3Kk;/0Jh@b0;gWc`1b[Hl007J/0000o`2mg_l0e0000;d00000
06h0059Y001YE`3FWW80cY/008U8002000001@0000004P0008l005fQ001g_`0hL:h0Ik3@06ffdP1g
_lH0000007]hTP3d`;40onRm0?o6V03kkK00_P000;g0hP00N`00Q6VY0;BfO`<0000000l0ooKl0?om
l03Po>P0d>k70<cPZ`3Bg9h0gn:W0>OSZ@3[g:80jLnB0>2oOP3M_7P0hKmo0>k8TP3ecj000P3ke:`0
9P3ke:d0nM6Y0?S@Y`3gd:D0lLbJ0?KEY@3jgJh0lLnK0?oS]`2eW4`0P4MT08=>K`2LK8X0_96Y0<RL
[P3<Y;H0e;G90=2ie@34YL80`9:M0<R:MP3:S7P0cY:00=RQTP3Y]ZL0om[50?oK`03ofKd0n]jk0?CJ
/P3^eJH0iLbF0>;LY@3RfJ80`[Qd0;JbK02P/6d0KXQ2T@00000<0?ooo`002P3oool00`000000;000
000000020000000?00`020000000000700004`0002l0001=00/LHP0V<gH003R0000CG`0005X0000U
0000J@14Chl0BURH0080DEbK01/0DfRY00`9CP0T8VD0=@1e0280F00[04d0HdMc06I=NP1WCW/0/jG0
0<J`a02HLHP0W86D0000a@000?80003k05`[A`1I;U00VWbH0>Bg^P3oh</0_jAm02PP7`000<l0003]
0000o`35jol02P3oool04P3ooo`0ooog0?oon`3ooo/0oooo0?ool`3noml0o?oE0?goe03mom<0l?cD
0>ogc03jomD0oooN0?ooh@3oon<0oooB0?oaa080000000P004JH0025``1AW]H0Hj_Q07>ji`1ka=80
H[:b0>?Z^P80000000d003Z:0022_`1LZm/0J;GQ07G1i`1`^nD0HjcP05NPfP1<VMD0Ej;J05ZUgP1f
^O<0X=So0080a?;o02L0SlKo06RWi01BV=H0?hk>04RFf`1?Xlh0FZnc062d^@1U^L00J[k6001cM`00
^MP00?k_0?oog`3oomD0joG80>SY]@3GgZ<0/L23000mN02>Hh@0k[Rc0?K;X@36_WH0X<^J0;3M]030
jlD0^nK20<3/a03NolX0cmB>0<gIV`29T@00UP0006X0001]0000000006`?001`6`000P1c9`009`2K
^7T0a:]G0>NlM`3V/g00j[in0?3DTP3df=T0c[?50:fPa@2_UKL0^ZW=0=>kc`3VaL/0omC:0?oJ``3o
eKT0olja0?oK^03oi[`0onRi0>GBTP2TL@00c[P00>?V[01mTCl0NkVQ02UjO`0004L0KjkL001eW@1T
U]00LkRd01l00000Ah0008ND0:>j002o_`00fl@009UG0002074d000908/k001Z0000<@0000000000
07D0002E056DaP0mSjL008VD0080000001`0I7ja0;6_/`3oglP0oooW0?oom03oool0[<B309Y/7`2k
Tf80]i]K0;bIU`2HF`00Se00076Xe02Ic=/0d?_X0<7Xb@3@iKH0gnRd0>_Z]`3fj[T0mmn`0?7@V`3R
^gd0fk1_0=Z_K`3U^800kl>D0P3fcJ<06P3hcjL0n]6[0?O>YP3ecj<0m=:R0>o?V@3dej<0m]RV0??H
Y03ObhX0U5ae0:1ZP`2cPYP0bInb0;9mSP1d:Bh0RdM20:elQ`1_>eh0PSP00:]/I@2mNf40eYme0>>e
S`3_ajL0n=2g0P3ohL<02P3oil<0n^Jn0??Q/`3ZfZH0fM>H0=gHW`3:ahP0Yj]T08RSH@1DJQnA0000
00`0oooo000:0?ooo`030000000/000000000080000000l030080000000000L0000C0000;`0004d0
2aaR02HcMP00>80001=O0000FP0002D0001Y04A?S`1:F9P00P1AG9/06`1CJ:T030U>02@RI@0e07D0
8P1H02/0C@1SAg<0ITej06M>N`2cYL00a[3409QaR02LPI@000350000lP000?/0G2]705T^D02JO9P0
i;Nj0?oPb`2oY7d0:20O0000c`000>d0003o0<G[o`0:0?ooo`0B0?ooo03oooL0oook0?oon`3oool0
oooc0?kog`3lomD0oOoD0?god`3`o=@0koO<0?[oe@3oomh0oooQ0?ooh`3oom80oo740P0000002000
AYP008G3056NeP1SZn40Lk[W07_4dP1R/[80hnZj0P0000003@00>XX008:o05b[f`1X]N40ML7W072k
i@1S[>00Ej3J04bIe@1GX]X0FZGN07Jil`2Pf?l00P34l_l09`2?a_l0J:OT05:HeP0oS/h0B9KK04nS
cP1J[k<0H;Bi06Fi`01Z_/H007=g002if000o^l0oooO0?ooe@3[mLP0j>Ve0=ONX`2a`8<003eh08iS
Q03^^;<0m/^Q0<JnMP2PbiX0/=fd0<3[a@2ki/80`>c40=kobP3?e8h0cMVK08VA002F0000JP0006d0
00000000K0l0070K000207<W000W09^hN@34ZeL0ikag0>JcL03Z_Wh0l=BB0?CHf@3>/lD0[J350:nE
]`2jZLd0dk_?0>K5b`3oe<X0om[30?oE^@3oc[40om^h0?oV_03oj;T0iM:B0:Aa003>^000hnJ/07fA
?`1k^J40:GYo0000A`1_[]`007FM06BFd01c^;@07`000017P000Qi@0XkX00;no003Ka000VEL00080
LC@000T0Rc/006X0000a000000000000M@0009D0DIC603f?Y`00RI@00P000000701TO[40/Jnc0?oO
b03oonL0oood0?ooo`2/a8<0VV`O0;^CHP2gVe/0_9VG09QK002?D000LJSD09W<f`3@nnP0`NS90=3U
]P3Oj;@0jnZg0?KZ^@3ggk00lM2K0>:kO@3K/6l0fZm_0>FhP03_`i@20?K=X`0J0?S?Y`3jdJ/0mljV
0?G?X`3ddZ80klnI0?CGX`3ff:H0lmRT0=o;RP2DG7D0X6Z30;>2V039Wk80/Wf>07@Y;P2;Ad80[Gb7
06lkGP22>000ZfaU0;ekH@3FWgD0hkF?0>o7Y`3hd;L20?oQ``0:0?oW``3ji[h0ln6c0>[JYP3IdiP0
gMRO0<[7R02WZf@0R:=Q05AZ7i400000303oool000X0oooo00<09P0J000000000000100000003@00
01`00000000000005El0025[02@gO00Q@8P000000000B@0003407bQ^05IMV@1?CXL00P0mBXd03P00
00006A5A02`VIP0]9VH02`1804`0I`1F@gD0FdUl09bNaP2Y[mH0Wi_00:n^e@2`[m@0a^Ko0`000000
1@3oooh0WI:f0>;8d`3oj=l0h[V100D000002P3oool00`3ooo/0oool0?ooo`030?ooo`0U0?ooiP3o
on00o_oG0>ohb`3XnM80jOoM0>ooi@3oonT0ooo`0?oom`3oon40ooc;0?o`aP3oo<l003J8001NY@00
I[00>8G606B`g`0m000096N]0;S0a02NQIX006ZG0028^@00[ml00<c`08;;j`1ka>X0MkoZ076gj01R
Y^00G:7N05FMfP1UZ^<0O;k]09oGo`020;?Wo`080;;Wo`2/h_l0Y=cl06R`h@14V<T0>8o403F>W`0m
UiP20000000G001c^@00XnD00>Sj0?ooo`3noo<0hocN0;_R_02Da9`0Slb`0011Q`20I940ol[50?oQ
]P2l/f@0TL:@09WA]02Sg<<0[^G<0<_leP3[on40d^JR0;Bd002mhP000P000000102c0000`IfV0<Ja
/03>e;h200T<1@0W001oA@3@aG40h/9i0>JhMP3V[g00hJ]V0=JHMP36S8T0/hbT0;RG/P2mY<40b[38
0=bja03oc<D0om2m0?oC]@3oi<00oo?80?ooc@3om/<0jNRc0:ik002jS@00e<b508bG@01UD`00_ooo
09K5gP2ff_l00=3o05^4a@00Pk@0Nkk>0000:000;c/0L4lh002P^@0000`0QcT00080TT<000@0SP00
09=84P3<UW80bj1`200000006`1OX[d009VX0034d`3oool0]kBD0:NKE02dLS@0Y5`009KGf@3S^@00
i/400<::000006d0LZkA0:OJf`3:kmH0goC<0>G]^`3ek;`0o^^o0?oP]P3og;<0k/BA0=naM03GY6D0
gJaa0>FcOP020>bmSP0U0>o0U03a`i/0lLFH0??<W@3geZL0lM>N0>g@U`3_d9T0ilf@08Z6<02HGgL0
UUee09YOL`2LGfl0OC]?08I2B`1h=4P0D00006l0002P0000`HIV0>NnU03[bYd0jl>L0?CB[03ed:`0
omfk0?oR`@3oj<D0onK20?GP]@3TeYh0eLZ;0=KBUP2m_gd0Pi1707nKF02B000000`0oooo000:0?oo
o`@0000001003@00000000000000000K00419`00000002T00000DP0G=Gh074290012QP0000000014
020_MP1LGIH0D4Qn0`000000600/5dh0>c5/02XMFP0F04<0>P1`05IFS@1lPjl0Z<?X09BYf029U<<0
TXjk0<GQo`3>ool0000003H0003fonT0oooi0000003Ec>80onc]0?oon00C40l0FT]90::7PP800000
2P3oool00`3oooL0oooj0?ooo`020?ooo`080?oom@3oonX0o_oL0?ClcP3Pl<80gOC=0>Koi@3YooL3
0?ooo`0>0?oon`3oonD0ooo@0?omc`3oo=8000]I001=W000?8l0DXC30=7oo`3Lool0RiW?08NXb02<
_M820000000;093?l`28cNd0PL_X07c3j@1GXMT0?8K:05fQgP1MX]h0LK;X08S5lP2Of?`00P2Feol0
8P2Lfol0TM;a06bgf`1/]^80D:G<056[^P1:QeT0lLJ50=fmM@000000002o002`lP00f?l0cO7o0=cm
o@1YZXX00<fX0038WP2DYm00U;[G0:R6Z@3ol>00omZ/0:>NB@1R/J/0002506RfbP2^i]/0e_oW0=Ok
cP39gj80b^7o0<;6m@3ej^P2000000030;foc`32fmX0b?CO00807CSB02L009M^0>caXP3]f940jl23
0>V_N03MVfX0e8aX0<j5J`31PWd0a8^90<:=U@34WK00cJbo0?o<aP3oglH0omnk0?oQ^03olL80ook9
0?gd_`3WjK40`L000<C3001kSCT0FgLU0??`_`3oool000000:jnk02f`Ol0I5F=0000[00007`0D0l8
00000000HIH0MX_1001TZP1RB0000P32U`000`2LJ000UEX00:5S000:0000000J000YO00009D0h]Ok
0>WAe03/b:P0]7<a0;Uk>P37T4h0f;im0?7R/03G/800`GeG0000a`2Jb^40_nCM0?3of`3Zk;/0o>g0
0?o/`P3ojL80onO10?oV_@3_biH0gkIh0=jcL`3S]7d20>RfQP0U0>VgRP3/^i80j[b80>o9UP3cdj00
jKj<0>NkR03V_hH0hL^;09RC?`2FH7/0[G^B0:YeRP2=DV/0Re5/09IQN`1I<FL0/hf/0<>BSP3@W7H0
^7m80=_4R@3cfjh0n=Vb0?[H]@3dcj`0l<^V0?CAZ`3gfK40nMnf0?3R/`3Seil0f<J80<c3P`2f_W/0
P8m605Ig<`2B000000`0oooo000:0?ooo`<0000000l0100001@000000000000>00009`0002`00000
000nPP00A@00001P03=6R016E8d000000000G`00?7l00P0000020000;P0?03/JB@0m7D`0?biV01d0
@`0^8Ed0I6NN08jTd02Jc?40XLGY0:Zlg`1gS/H0Ngnb0;kWo`1EAF/0McPk00<0000000T0[<7Z0;G7
j03Zj?@0oogn0?ono@3om_H0oo?c0?ojo`3onol02`3oool0303ooo`0oooo0?ooo`3ooo/0ooon0?_o
k@3aomX0i_?80=;X^P3NnM@0iOoZ0?_oo`@0oooo01X0ooon0?ooj03oom`0oooL0?ooh0000000001k
07FCd03Nool0h?oo09njj02Wh?<0000008^hjP1jVmH0000005j]g@1S[ml0Ik7Q06Zbi00dQ<D0C9CD
05^Pg01MYM`0IjkQ076kh`80NLOV00P0P/cV06Ffe@0cT[P0CJ?=05Z[_`1LZ9D0:UlZ0?oc_`800000
01P00035002[f000Z=T00:K807:h/01YWFT0YMFR0=7J^P3Ye]@000000?[?dP3fgll0l^g:0=_oo`2>
bOl0LKW`06:ce`2cj^/0`^oL0;3L_P00f?l0UJcn0:Jfm@35a]`2000000030;_Dm@32kOP0anW00080
UjD001X0HEX00?goc03ookh0lLZF0>2OMP3ITfX0eHaU0<j5I@3;PVX0bXMk0=:CT@3o^K00o/?70?o]
d@3oomH0ono30?o]_P3mk[/0lnni0?3/]P3ZfiT0ak][09BYG01cSSh0fO?[0??R_P80000000H0OGZc
0:bdh@1THI`00P0004TR;01lCW@2000000030:R4<P0O5UT0Z8V_0080fkc:00D0jJVA09AV4`2EG`00
OSH008=400070000000K0000@`00B9H003:30:j]e`3^d<h0ooO90>NQIP2lOD40_hU30<2X003`lm@0
gK^W0<nBQP3KYYD0R[kZ0<WolP3oooP0oooJ0?oY`@3ojL@0onS40?o/a@3ojl80onc20>oEW@3[aXh0
jl2>0080jKV902@0k;f@0?32V@3U]7h0j[f:0>g0TP3W/hH0i;600=jYLP35/fL0WiI20:aoV`2fS:P0
SVNA099WS@2SMID0[W^C091TR@2/SkD0eKC50>[1/@3K`8@0bk=a0??K[`3ig;L0oMVj0?G=[03_aZ<0
kLJN0>_:V`3/d:00imfX0>GMY`3NeI/0_[Qc09jTF`1gQ3Q;0000000403h0001d0000Z0000<:9MD@0
0000303oool000X0oooo01@04P0000006`0N00003@0a0000;00001H0000E0000=P0003@0035e001`
W`25U[80Aal0045IVP1JGI@0000i000CH0008fl001UQ00000080000^01`0000l03HIC00^5Td080Y4
0450O`1cO;80XK3K0:B`f@2X/=H0[:oD096SdP2LW/P0SY00071a001jOJl0OXRk0:O1l02ceOl0ZLki
0:38l@30foT0d^Go0>?^o`3Ri_h0l_co0?goo`3aool0nOoo0`3oool00`3oooh0oooo0?ooo`040?oo
o`0;0?oooP3oooT0oooi0?ooo`3mool0l?o`0>?mf`3DklP0cNBf0=ong03bool01P3oool02`3oooP0
ooo^0?oojP3oon`0oooe0000K@39h_l0bnoo0<clo`2bf_l0dooo0080000000`0J[OJ04^;`P000:<0
@ic9002=``00Um40GZSN05RYfP16V/l0:XFm03F=a@17W//205^bcP0W06JjdP1T^Lh0BJ>e04NDT01;
QeT0]n;?0<kVh@3Yj]T0_kb7000]H000@6T005Q[0000000f0000NLoN0;?hc`3SdkL0ijR60?oT`000
0000?IZ/06Fa[@2=b:h0i?Oo0=?ho`2ai?l0U]Co08oBk@25cll00<Be07Fb_@1JNk40IW6m09>Lc`2f
X[`000000<7Jl@3AmNX0^<h00080S9T001X000000?3EW03U]X@0fYA^0>>SP`3OW7H0eHiY0<j5I`3?
R780cham0?BXV@3ockP0oo3F0?oog03oon00oooI0?ooe@3on/@0o>jj0?;X[P3YgYd0`[QX092WF01H
NRh00;S60<[8]@80000000@0onkf0<g3iP1oRlD0N8:n1@0000002`0[@8d08DNG0:R>X02XSZ00]GaW
0:a]<@2VL`00XFP008@n00141000M`0000P0000001P0002X0>cJh@3oon`0olf]0=ZHLP33Q4/0NdX0
0=Wbk`35^/40W::F08ie9P00<880_^[c0?oooP3oooH0oooH0?o[a@3oi/00on[10?o_a03ol<D0n>Bb
0?GFY@3ccId20?77U`0T0?;9W03ecJ80mLZQ0>k1T@3Y]hX0jkf>0>k2TP3WbI00/Ii;08b0002cQj40
YgZG08QJP02=II00UfN90:=]Q`2MJHD0/H>L0=J/]`3^b[H0dkYl0;jRG03/bId0llj]0?W@]`3cb:d0
k/>U0>ZoV@3V`900gl280=k7SP3RfJ80dLZ;0;ZfL02FTdH0DFTO9P0000000`1a@P0000000000000R
0000000606m=R02jT[40jmc?0?ohd03aiL00lNFo@P00000<0?ooo`002P3oool02`000340001301L0
@`0<03H0000U00007@0001T0000a00007`0008@007Z^0080000000H0002000002`00050001m/000X
M@0005h30000000P0000;@0j8UP09Pe5034[J`19BhT0HVnZ096Xf@2GZmT0VZ_F09bVd02n^]@0Wjk=
0;;6jP2ed_`0YLGe07B?a`1<?Vl0ICYJ06HK5@000000O[[T09;6l@2Udoh0^nSo0<goo`3Oool0j?oo
0?3oo`3hool0o_oo0?ooo`3oooP50?ooo`0;0?ooo@3oonX0ooob0?oolP3iool0l_on0>Goj03Rn=@0
c>Ro0?kfa@3oonT02@3oool05`3ooo40oooP0?oom`000;P00<ke0;OHo`2hh?l0_N?o0<7FcP35bih0
WYEN0000003oonH0ooo]001`[000IJ@006FX002Ie`1CX=@0Cj?=04NQa00XQkD0:HRd0080;hje02L0
=iFi04BO`P1J[/80EYn=09W=[@2Dd]D0Xm?f0:g;c@31bIP0Yl@00<80002c0000600005h0002b0<80
k?oo0>gol`3[d[40j:R00?oBY03nbY`0omf`0>CL/P3Hi_80`^[o0872oP1^^=d0RLgH0:3Ne01J0000
JP0001<E40020P80TYG;0;JM^`39/k<0dM>l0=[ec02miKX00P2H`@003P2h0000c`000=ZGK@3WZX/0
l[^S0?6jW`3a^I/0j[2G0>^`V@3^/9P0olBS0?oV_03oomX0oooM0P3oonD0303oomP0oo;40?_RZP3^
i:X0i^BU0;ZfI@2GZU/0FWDS001:F0000000X5eO0?oUf`D0000000H0QhFP08N3QP3_b<8060<003hH
C010D942024TK0070000001f;P00YFX008A7002GEP00R4D005<d00080000000=0000U@2b`n80oo?o
0?oek@3oom`0o^^f0<fOH`2V0000K@000=RWK`3EYFH0001a0;C8m@020?ooo`090?ool03oom80ooS;
0?[`a`3ol/H0ooC80?oba`3mh[D0o]nd0080omjc02<0omfc0?cG[@3meZl0mLnQ0>k4T@3/bi@0k=6H
0>KCU@35/F<0VH/c0:AWM`2<CVH0RTmZ08aCL02HH7/0YFj50:9YOP36UJ40i[jd0?GG_`3Vdid0glJ;
0>>kR@3[`i`0mLb`0?;8Z`3idK@0lM2/0>W8VP3N_8D0cJa/0=C8R`3KdiP0c/N808Al;@0R00000008
060XB`1G5b`0E000060D002BB`00L`000=OJ[@3;h;`Q0000000902lEH01oFi40`IRe0?gIe`3Son<0
kooU0=Kce@3Me[80kP0004000000303oool000X0oooo01@0000m01L@BP0903T02`0j0000<@000280
000U0000<P0004T0<Tb@001DU@000000001Q0000OP0002`001AR000lQP00>840001P00000080001N
0140001503TSFP0n:El0C4En05EFT@1cO;@0MI7:08VVf@1iNZ`0RXb/08fU^@1iX;T0/=?_0;;Oo`1;
JJX0?5BH000XJ`020000000=07`0002>0000000000000028_>l0VmOo0;Who`3Nool0i_oo0??oo`3o
ool0oook0?oon0020?ooo`050?goo`3oool0oooo0?oomP3oonh00P3coo<01`3/oo00i_o_0>7mg`3U
mLd0`n:g0?ooe03ooo@02@3oool03`3ooo40oooK0?oog`00V<d009Zo003FjP22anH0J[CH07JnbP1`
^;P0EkG00000003oom`0oooS0?ooj`0200000006001DUP00Tl<0C:G:04JPa@0nV[l0@Yc50P0]Q[d0
9`0aRkL0?9Vc04RPY`2?]gl0Nkj^06>e`P1R[]D0V/WH0<cN/0000000Qdh002P0001i0000]ViT0<jE
R@3dglD0oo3C0?ongP3obZ<0l]BS0?[MZ`3oi[@0in:b0;_O_`1CX/P0DJ??07^oj02GdnP0/NKS0;_R
`P2md8l02@X80000002NW<`0dk[;0=_>`@3MhKH0cNFb0:_K]@020>cWZP0M0>_CV@3X0000k]>E0?S`
]03on/L0ooG40?W_c03hnM<0ooC80?oaa@3ol<D0oooB0?oog03oomT0oooP0?ooeP3oi/L0o^Fj0?3T
ZP3YcXd0gnJ[09n]H02=XE006CD[0000002<FgX0aHn=0?oWj03oool0100000001P1:Sil0a=[o0<Bk
cP2MU[@0H6aa06nQ``80003200L000000<FXN`2=F@00WUl008U5002ED000P44000L0000000l07BAb
03MOZ000:Wh000380?gUmP3omnD0o?K50>_V/03_bJP0jk>`0=bZ/P2nV;H0001a0000nP3nool00P3o
ool0203oonH0oooE0?Cmd@3kml/0ooK:0?odb@3okL80ong30P3oj/408`3oiKd0omnh0?oO]@3jfZd0
mM>S0?;IY03Ze9L0h<Z80=O9P`2>R340UEM[08e@I`28Bf@0TEMb09QROP2UL8P0`8^D0=n`[03nf;l0
n>:j0>ONZP3UdYd0j<>D0?3:Y03dc:`0omNh0?oR``3oi/40mNJk0>?BW@3E`HD0Z9I80<o8R03:aHD0
TY570240000000T0Q`0008=`W01F0000Oca>09UCB02]KEL0_89T0=>WNP1gE0001@0000000`1NE2`0
00000000000I0000000;03@6A02SSkL0c]_O001VIP00UZH0G::_08C3a@2Ya;h0/[c009Z<U@38Yid0
?P00000<0?ooo`002P3oool0500@2dH03`Do0140@`0603T0000[00008P0002L0000k0000FP0008`0
?F6S000000007fX004250000C`00;gT003F1001CT`0005`000000P000540400m;VH0=BIP05]@Q@1U
FXd0JVJJ07f7^`24W]<0LiW406=cUP12H7l0BgnC05>CYP2]goD0001[05Ac/`0lI:@20000000E02H0
@@1=0800N@3607H0002JH@00/XD006n]j@2Ke_l0aooo0=koo`3[ool0lOoo0?ooo`3ooo`0ooon0?oo
o`3_ool0j_oo0>Ooo`3Tood0h_oe0080h?o^00L0fooX0=_oj@3Un]P0jO760?oocP3oom`0oook00X0
oooo00@0ooo]0?ohgP00GI0006N90`0000003`0006d0001K0000N`3oon`0oooK0?oohP3oonH00000
0;bS]`2^^]80XM7^0000a`000;40AIo504^Sc0030000000V05ZBZ027[XX0MjYk05nVU`1AXZd0HK;:
06B^e0000000TU5K0:9kS`2aY<<0aJg10=o0a03id/L0lm:f0?gG]`3ogk/0on>m0?Koc`3dnl`0jNRl
0<[JY@2Xak@0Rj_>08G5o`2HeO/0]^[l0;gUf`2kg[/0003C09NE``2U]Fd0Qk3G0:37e02ZeMH0/nC>
0;CVc@3Rkl820?o[/0060?oGW`3`dId0lN^`0?ooe@3oooL0oOoo0P3hool07`3iool0ooon0?kog03o
onX0oooU0?oogP00n@000=X00037[`3cf;40hnB^0<kRZP2heId0Qk1]07^9<P008A00?GAO08M?I03@
VHd0dIR:0>S]o`000000D2Q70000000cEVP0001B0000ZP2d`N`00000001a000hMYl00P1:KKD02@0`
>XL0b[:G0<RMH@2AE000]gPh09eI5`27B@00FRT009Q_00060000000902ATX`00>XX0001l0;[BnP3M
jnP0n_oE0?3W/P3[h/X0kn?R0080000000<0002=0000nP3/ool00P3oool0203fon00n_oH0?Soe03o
omD0oooD0?ood03om//0ooG;0P3olLL08`3ojl<0onS10?oV_@3oh[L0nm^^0?;IY03Wc8l0f[ag0<no
MP2LHGL0Se=]08M;I`2=CVD0UEIY09iPL02fOXX0eZBV0??5]03mf;L0kmNX0>_EY03[cj00k/bQ0?7=
Y`3dcjd0o]fj0?kU_`3kj/40l>:a0>WV]@3Ti[<0Zi]?0<G0O@2k_7T0I78T0200000000`0a0000<T0
00000000Oc]80:m_K@36Rg`0f0000=>iU0000000I0000:80003>X7430000000500410@0000000000
0980002000005P000000300o0000]JNg03YiB`1/[I`0O[k407^kbP1RZ;`0IZ[107N`d024/Md0[lKd
0;[:0080VWh000<09TUL000000000000>@00000<0?ooo`002P3oool0500B244050Y3010;AP0203@0
000l0000;00001h0001?000VKP000980<5ZN0010R0005f8002=Z07bVd`00000004/000170000@`00
000W0P0S75/0300c=WH0>C=`05AIU@1jRKX0PWVV0::/fP2S`nT0NZ_305V=V`0YIFX04V=X0=Soo`80
000000H0002[000000000000001H0000M`1E0:`20000000A07<000000000000000000000dOD0]>;o
0<Sfo`3Dool0i?oo0?Goo`3`ool0hooo0>3oo`3Oool0gOol0=Wol`3FoN`00P3Gonl01P3Hoo80gooX
0>WieP3an<d0nOc>0?oohP`0oooo00@0oooi0?ooj03oomd0oooL0P3oool03`00030000250000EP3o
ool0ooo[0?ooi0000000K`2B0:<0``2[fmH0Sjj908RCC`0005/0000n0020b`02002De`0800000024
_=80Y<bY07F_R`21_j/0S<o?0:;Og02Sf>T20000000M0:K=o`34i_l0e=co0?CYo03oooh0oooY0?3[
b@3il</0fno80=KidP3Cm]<0bMj_0:[=U02[ZhX0e/g/0=;Wo`3;mOl0`O;o0;W^k@000<00002d0000
Q021_>D0N/KH07S7eP1/_]D0Ol[G09_KgP3oolP00P3ol[X02@3olKd0jnfn0=[_`03VonH0jooo0?Ko
o`3cool0jooo0>koo`020>Woo`0D0>oom@3donl0oooX002A0000LP000:P0002JP@00Zh<0Sl6D086f
P@23Yf00IW`X0000001A0380SdI20;9[F@2]I4l0Y5U70000001@9CP20000000605m5P029QK`0_lG^
0:^Ve@2TWL`0001e0P2SMDd02P000000XgZF0:Y^002@F`00_XD00<:AB@2@H000N4`008IV001J@P06
0000000E000?HP0097P009C=0=?]n`3VkmX0mnB`0=CZc0000000[8800;FUEP000:@0Pj;d0<WZo`3/
ool0n_oo0?;om@3_omd0oooR0?ooj03oon@0oooI00@0oooF0280oooA0?omc@3oklL0onBk0?gK/03i
h;40j/bB0=ViM02eZEP0McI@08=5G@2:C6D0Se5X091>H@2WI6/0]G=b0<^>PP3V]Ih0l/bY0>>mSP3Q
^XP0h[R:0>_2V`3`b:<0llfY0?CCZP3eg;80l^2a0>WIX`3Thjl0gMfV0=cKY02i/V/0[;=]7@000000
0`1D02X0O@0009iNI0030000000;09mNIP2hOX00bI:?0<nFQ01[0000ZP000:/0002`OD/0ai]X0<2A
G@0^60400P2SLW/01`3N0000d`000<F;P@3K0;X0>00G0;AeD@2<B`003`00000040320000e0000;nO
J@2ahNP0X0000;7?h02G[Z@0EIb907Ji_P1//<00M[O907Vgc@1d/<`0GXRn08Jeg@2<`mTo000000`0
oooo000:0?ooo`0D00h6@@0G3TL02PE10000?`0014H0000`0000A`007F@0001h02I8S`0eFih0@6j^
01]@UP00UYT0096n08R/W01_S`0006<0000000000482000AGP060356S00iBXd0CFBU076AbP2A]^H0
VkGV0`0000001@0f6b0000000=Sbo`3@g=P0LT9B00<0000000<0Pf/00000N`0000001@0000003P00
[]H00:gD0:kPo`31k_l0`OCo0=3oo`3Jool0f?ol0=?oo03Doo/0eOoj0=GolP3Gond0f?o_0P3HooD0
2@3HooL0h?oY0>Wnf@3`omP0002f0000e03Kool0jOoo0?Koo`0:0?ooo`0D0?ooj`3oon80oooQ0?oo
mP3oool0ooob0?oom`3oool0ooon0?ook`3oon80oooN06T0]`230=<0K8f;08FSP02L/Gd007I?002N
[P00a_l20000TP80000002D0VLBT08;4f@2[hm/0cO_M0<ofh`2XbMT0000007>Pg@2Jc_l0TlGn0=Oo
o`3dool0oooo0?Ooo`3Won00_>C50:gRaP2`iLh0[Mfm0:K=V@2]WUP0g[FU0>_ad@3Soo`0`?Ce0:WV
i030S@00_:U^0:BdW@000000OL?608;;_@2BfMP0P<WK076lh01_^^80h^gK0080ZmKO01h0anWG0=3b
d035lll0food0?3oo`3^ool0k?oo0>;oo`3Oool0cOo_0=Ook`36oo00bOo_0000000I>a/004P00020
0000Fe00P<2T0870V027^H80U[I_00000014024004d0002I002hWYP0001N08RCN`1aYh`200000007
03]AW`2=JY@0[Yc50000001fEf00H01b00007P0202m1T@090000002NLgl0/7QS0:5T002UJb00/gPa
0:9e9029E`00Jcd000P0000001H0021e000GKP3;jol0n^oV0?oW^P3G`Xl0_iI?04dQ002k/VD0:dNJ
05V3cP2QbOl0cOoo0>Soo`3Roo<0jOoU0?coiP3oonX0oooX0?oog`3oon00oooQ0`3oonD08@3oomh0
oooF0?ogb@3oiKX0o^Vl0?7HX@3PaH80[:=A09aOL`2FGGL0RDm]08iBKP2NH740^Wf10<V=P@3LYH`0
j[bO0>o5XP3P/HD0ejMc0=6OJ`3W_Y80klRP0??=Z03^c9l0kLnO0>_CW`3Wdid0hmRQ0=_GWP3:a8<0
]JeU07j>A@0L0000000B03/08`1W8SH0S4M=07lh@@1m>DD0U5UX0;EnS02oR980i;6a0<bKWP2lQHH0
00000?oYn03gf[d0gLFD0>;4U@3I/XD000000P2ULgL02P35T6X0`HQ^07l0@@1J02H0P3dl0<@0N03C
Yg/0_h]Q088o5@24?0070000000F0200?P2D09h0fKS;0=jgaP3^amD0omSA0?oWaP2dVP00Rl6S09?>
a`0lO4h0FIf207:f^02;a]D0S<GI09S9h`2Uanh0U;;P0:c9k`2/e>l0/>3X08VmXch00000303oool0
00X0oooo01@03Pi;000JE`001D800018000<C`00038000mH000UK0009W406T::02=8SP1;LK00DX6n
001<Q@3@c:0000000000G@00O`00001D0000008001]Z00L004Z@045PYP11Jj`0Hh;0086Od`1hT/T0
Oi3800<0000000X0^;kP0<c?e`3Qg/L0LUao07j=]`2L[ll0KU^404@[E`1K@F/0GCeS1@0000003P00
FhX008Zb0:kPo`3:mOl0]NWo0;cdnP32loT0cO[j0=Coo`3MooL0goo`0=cok@3Ionl0eOog0P3Booh0
2@3Joo80hOoW0=;dc`2Zd:L09QlL0000X`000?l0iOoo0??oo`0<0?ooo`0B0?ook03ooml0oooo0?oo
eP3ohl40oooo0?ooo@3oonh0oogR0?oogP1F0=40J9bm08:b/@2I`Zd0[m2Z09JKT02JaN`0003S0P00
/_830000000T09;7k`1`^Z`00=?80033a@00X<0007bj08Jei@20`Nd0NkO[07B]j@3Gool0_OWo0:OP
c`2Ug/P0V=Jl09?HbP2Jf=<0[]gO0;oLcP3>eId0jK^J0>[lbP3Tomh0`O;I0;k/e@2TQ3H0/V@008dd
6@2WFd40YJ2M0=G;[`31hn00[>Wm09CBmP25a^d0RL_Z0P2Kf>@09`2djM/0_^gB0=?oj03Zool0jOoo
0>Ooo`3Tool0e?oh0<Cmj02kl=h0booU09kTi013HV@040XA04LU@@0P2A8005d[09SE`P2=c:X0T<bV
09;2R`21We@0LCUG08ACM02IIf@0VF8P0032j000X;80>hZC0000001jKH/0NT5P09e]Q`2_YM40_[o/
00000028L7H0@01L0000I@0203l0QP0:01/0CP00Qjd009^J0=Nd002CGP00[74Y0:E`8P2AH0d0U640
06hl00L000000P0006/01@0005L0n>?Z0?oG_03MYWX0ahUC00<0000000`0DH37086ai02ahOD0`Nk`
0<_gkP3Ion`0n?ob0?ool`3oond0l_oU0>coh`3aonD20?ooj@0A0?ooi`3oon40oooM0?ood@3om/T0
ooG90?KV/`3PdY<0X:5@09YKJP23@e`0P4IW09IHK@2VK7h0ahnC0>bk[03]_j@00P3ab:D03P3Y^i@0
hkF80=bbN`3T_h/0j/NH0?7=Y@3^cIh0k<fK0>[>VP3VcYL0h/jD0=?8R03Eci<0`KEa7@0000004P1W
05D0WF5a0:icP02VJgP0Wf9a0=:U/03BZKT0omCF0?oOh027_Z00^HZV0?oVo`3oool0oooJ0?KX`03`
f;00;01=0>`0o`80j[f^02L0n=Rl0?ON^01^0800O6^O0;BOVP26N4D0TL6m0;N_/02@FU/0GP000680
002S0000HP0009iHE`2HDEH0QP0004h0001?3cH0Ti380=WAo`3Ygol0o?Ko0?ooo@3oooH0l=h00:?F
`P00QeH0CiJ006Z`[01OYKL0HjFn06FSa@1WW/X0IYS7072Jc02M`NT0^^3d0<?[k`2I_I<00P2]VEP0
0`2CJ2X000000000000i000000`0oooo000:0?ooo`0A01`SHP004U4000U70000D@0004h0000m0000
B`00:g8003=k000mQ@0@=7d0Dg6_07V@]0000000h<:@08=_Q`00<G400P000000:P0003P002Ae000T
M@00AH`0C6f`0000001AMK<0LHW207J0]@1TLZd0Ql6g0000002BVLD0Y;7J0;;1cP36f;`0GdL003L[
H0000000HU5l04T0D`0e0000?@00000000240640>@0b048h<02]0:L0/`2f001JV000]o`0dO_o0<?c
o`2mkol0aOGn0<goo`3Eool0fooo0=7ooP2jjm/0/>KW0<3cn@80c__m00<0d?[e0=[okP3BomH00P00
00000`000?d0003o0000o`020?ooo`030?Coo`3oool0oooo00L0oooo0180ooo_0?ooh03oo]/0ooo]
0?ooj`3ojLT0ooo]0?obg03oonD0oooR0?oog@3oomh0Ol7S09KBg@2]h=X0`noH0?oof@3oomL30000
000W001e[P00OJd008>/03NC[@1P/Kd0?9C1001f/`00CIP008g:07^hiP1^]>80L;KS05NYd@1CZlL0
H[G507k8a`2=dL40T]6d0;;bi`38ool0bO?o0=_Zm03Yhl40jmNV0=gha@3GnM<0doKG0>;ie03Rei`0
fJn50=V_X`2jZK`0d/F]0=[Rd03Am_/0cOoo0;ofo`2Sgod0WMca0080Z>GW01H0^>cL0<goi03Zoo@0
oooo0>CooP3Qool0fOon0=Kok03Ann@0b_SQ0<3`e`2[hll0Dj2F07BbQ`00]JT009^e0:?Pd`2Iek`0
0=Rh09kCZ02Nbi@0FGT00P0000000`2/SHD0]=cc003<e`020000000405QVY@1XBG`0WG>C0=2_`0<0
000000<0GP1g0000R`1B07P00P0f03h02P0[05L00011001k/03H[GT0]8Tk0;J3>@2`OS80V6HD09a[
6P1f@@080000000E0000L`0005h0cLGZ0=Zj`03BVHP0`7MA0:00=0000000JXkB062?d@1ZXMT0Xmc/
0:gSk@2hjnh0_nod0>3onP3jood0hOo]0=[mi03NonH0hOoY0080ooo/0240oooV0?ooh`3oon00oooJ
0?Wog03oon@0ooo30<7<S`21Ve00T4]G08E0D027@Dd0UeEQ0:UXL03<T8H0j[VS0?77Y`3`aj<0l/VU
0>g4V`3X_i40gkf50>K6T@3YbIL0kljR0?3BY@3[biX0i/>A0=niQ@3C/GD0Z9A80=O9SP2n]WD07000
00001P0k04d0F`1@07lmCP1^8al0Y@0006<00080000000@0ooKb000000000000oo3o0P3oool01@3o
on<0n>W30000002A0880L0000080hkj/00L0n@000?com02I[><0076M08nZb`00H3T0C`0000800000
00`0_X=d0=n_V03NZiL0dYb<09aFE`2HE5h0NcI8064M>`1REi`0al7d0>?Zo`3^o_l40?ooo`0>0:00
K`1oZI<0000000000021`l40D9VV03F1U01ATK<0AHZ[021VSP00VlL00<?G0:cGa02P`hd20;k@U@03
0:`000000000000003T00000303oool000X0oooo00`05b9R000:C0008F<031=D0000CP0005D0000[
000TK000@8H004N=01<dO01AIJ<40000000406YaT`2GVkD000000022^08009Nd00T003^605Ii^P00
0000>7^/06=_Z@1WIY`0001G0000a@2GZ=H00P000000102LYL80SK400:Vh000k>G820000000F06`0
001R:D00GRY707]@K01C04`0HC8g0:9eN`2[PY400000001XU`00_?P0f_oo0=goo`3Gool000000<cn
o`3Dool00?Gg0:;OeP20aLd0PLOK09GEi@80Z^;^00<0aOKj0=kon00000000P0000000`3Wool0looo
0?7oo`0<0?ooo`0B0?oonP3ooo00oooU0?oTd`3ohm40onWB0?oof@3oonD0oooX0?oohP3oom`0oooD
0?ooe`3oomh0oooK0?oof03oom`0oooM0`3oomh09`3oolh0?8k704ZLcP00X/h009:j06BdfP1GZML0
08g5001_[@1GWLh0?Y?2002Wg@2;an`0X=_/0;?/j`2Vh]T0TmC509GAb03<j>D0dmcm0=;ko`3Moo/0
k_S<0=KT/P3Bk;d0dOC@0=Smh@3[om/0jOoO0=Ooj`3Ao^H0b?GL0<Cbg@31l_H0_o;o0<Wmo`36nol0
/^_o0:oXm`020;c_j`0E0<Gdh03<oo`0hOoo0??oo@3ZooP0f?og0<gom03EonT0c_cW0:kVc`2ci/P0
TLbZ06>ZQ@00C@00ETHj038D3`00VJ<00>C60:WM]`2Mdj`0QKf=00<0000000<0PX>508[=b`2NdL80
0P0000000`1VG9X0K66O000000020000000503Ll<@000000002=0000B@0o06X00P0o06802`0a=Wd0
001a0000B02kW7l0_8To0;N3>032UT`0YgTY08aK1`2IIAD0NDd000L0000001D0001_0000HP2?V]D0
YZWH0:ZBZ02mRHD0R@270720`@1WT]80M9cK076Uf`2Yg_<0/>K^0;OZlP2lj_T0boWk0=Col03>mn80
dOWT0=Gli`3Cno000P39m?l08@3Ei_l0m??i0=_khP3aonH0ooo]0?ooi`3^n<40RJmb08Q2C`1b:3H0
JQdV07T/<02GCT`0/VaO0<F3J`3FWGl0i[VC0?C:ZP3gcjl0mM:]0>o?XP3OaH/0jm6N0?7EYP3ceJT0
m=^_0>k?X@3Xai@0h<::0>39T02XT4@0^Z1I0:fWG`0A0000000409F_M01D0000HAD005T000H00000
00h0GcMY03X0F`000000]`3E0800002]MXH0bYNL0:MYKP2RJgd0olO70?oae`3oo>H0oooo0?koo`80
oooo00@0oooH0000003Fao`0k]H00P1Z?`03000000080=V_PP2VM`0000000:5TJP2jNF@0[0000;5b
D@2TJCh20000000905X0001f0000Oc<g07L/=P2BT/T0`<Wi0=SYo`3Rnol0k_oo00<0oooo00h0<P0[
0:X0[`3]k?L0oOoB0>coj@2</hD0B3ha04a]U@2og_l0VlCo04aWZP00PK80Vlg?0=3/c080d>2^00<0
KhQ1000000000000>@00000<0?ooo`002P3oool04P0A6e`01a1A014QI0003E00001I000OI@0002l0
025X02]6RP0XA8T04c5h0000S00Q:6D0IV:;0:j?W`3I000000000000Y`L0000000L0<P0005a4K@1G
=5T0001V0000R00LB4H0[m7c00@0000000T0W`0007eAK@1D:4/0Kd=Q079<K`1YBG<0GCMN01<II01C
02D00`000000100D04X0alK[0=ooo`3cool2000000070<Whl`00jN000:jX0:NkgP000000KKWE08c>
iP020:cSm`060<Kom`3Tool0jood0?7``P3jgJ/000000P3oool00`3`ool0oooo0?ooo`0;0?ooo`0A
0?oom@3oh=@0ooo]0?oon`3oond0oood0?oon03oonl0oooS0?okdP3olL/0oooG0?oof`3oomL0oooE
0?oog`3oon800P3oon@09`3oom/0ooG70?ob`P3akkd002mW0:KQkP00eNX00<WV062_e@00KZ8004b8
001DT`1m`^80UmSU002=VP00];T0RLkL09[El@3Gd=`0g]gS0=gmm`3Oool0bNS00;[T_P32jlL0aNk=
0=KojP3Gonl0f?ob0=Kol@3;oN@0_o;G0000002`g>80^ngo0<Kho`3>ool0`?Go0<;do@020<_jk`0?
0<Oei@30n?L0^_Km0<[ol`34o?00`oS`0<[jk`3Con`0[nSA0:7L`@1h_Ih0AYEj0:k@W000M@00JhaW
0080000000@0Xn3<08O;]01l_IP0JZMh0`0000001`3coo00F56B0?ooi`1J0000QfRE09FGa020VM00
0P0000001P0]8TD0000001lK400k:Al0VG2G01D0>`80IP2;00/0VLWN0000IP008WP0_YVJ0=n]O@2o
SD@0YG0Q0;64=02MJaX0SUl00:1k00070000000E000QL`0006400016082DdP2[`_@0a;OF096Ab`1m
RLD0JYKB07NMfP2G_nl0]N3o0<;Zo`3=m?l0boGo0<OcmP3:m^T0dO[U0=3hi@3<mnL0hOoo0080e_oo
0240b_?o0:GHg`30km<0g_o/0=kokP3con80U/BG05F;D01O52@0L2Pj08HnAP2ODd80[6=?0;MaF`2o
O5h0aXEQ0<:6D`3CWFl0hK670>W2U`3`e:D0glZ?0>;=T`3egk<0m]bb0?KM/`3adjL0k<fK0>S@VP3A
_Wd0]J1F0:nRF@1/MBH0300000002P04C3T000000000000b0000A@000>Bf_@3dbLX0^H>00?l00019
00060000000807<b002VI@00TeQ`0;R2S@3I[[L0g[W40=Rc``3ofN040?ooo`070?koo`3oool0oooo
0?oolP0k>H80aKod0?ooo`020>W/000W0000003L`=D0nM3B0?[:0026JP00XV=]0<65N`3FXHd0bHeg
0:QUF@2LF5T0Z6IX0:YWJP2bLW@0YfI`08M4F00005D0IH>o0;;>mP2kg?l0cN_o0<_Zo`3Gool0o?oo
0000003G0=D0`@3b0?Woo`3oool0000004^8]`1LR:/000000<K0o`3IfOl0U939096Le03hh^/0i>_<
0080h^>d00@00@LR0;R^MP000000XHI0>000000<0?ooo`002P3oool03`004eH03a]L00lVJP0004d0
2A]P000JH00002l001eT02@mPP0V>gl002U`0000M@000000>E:=07U`U002000000030000GP000000
00000080000000D0YgV5000000000000J00002D000030000000L06MZT@1oX[D0W]OZ0<koo`000000
d0000:l0002=0000@bEF06E4K@1dDg/0JUZ:04<PC`0C6F@0KP1?06h0001m0000>c9Y0;ZR^`3:co40
i?oo0?goo`3^ool0eOoo00000029Fg80BP/60;S9lP80000000P0Q;KK0;C`o`2dl?l0e?oo0>;oo`3U
ool0j_oO0?goo`<0oooo00<0nOoo0?Ooo`3nool0103oool20?_oo`030?coo`3oool0oooo00/0oooo
00L0ooo/0?oodP3oomL0oooL0?ooe`3oom80oooJ00<0oooR02L0oooP0?oodP3oo]00m?o@0?ooe03k
ol000:_6002WaP00U;D00:k:03BA/`0XQ[00KkgI001[QP00PZd009k005VYc`1V[=`0R:7409O<e`2V
l>P0[o?M0:7L`02Wgl@0Y]g209OC^02ck=D0coo_0=_on`3Don/0coSI0:RZI02O/Ed0b_oj0<_oo@33
m_H0cOoo0<_ko`39n_l00P39nOL09038n>`0T=C<09;Hf@2Qh^X0U=WP0034dP00eMH0/>[D08c@]P15
UWh0I[:N08[=^P2Hail009h001if[0000000V]cK03V?O`1T/I`0CIMe0<VQ/P2nUJP0i[_60=?>W038
[JX0000007H00000HGX0hJfi0>[Gh`0M1QL0000007Ul]`2V^m@0XLNd09ZGb080000000@0IDb608@0
[@240:d0gOoi0P0000002@3odKT0dkF[0=>_KP30YEL0[HPj0<>SF`2@F@00WH/0038000070000000D
000SL00005/0H8;709^kl02gf?l0Y[GZ09RXgP25V=L0RIkI0:G7n@2lhOl0b>ko0<cdo`3@n_l0dOgf
0=;lk036l]h0e?_X0=coo`3Oool20=Ooo`0P0=Cno`3GooT0f_o[0=WooP3Foo@0VLFI05fEGP1KRDH0
TE=W08T0HP2>0580ZEm=0;]fF`39R6L0eY]l0=NNP`2fMDH0]gQ30<J<F@3M]840jm2N0>;?UP3Mb8/0
m^:g0?SO]`3fe[00k<NK0>BmR`3Xd9X0g<V>0<:ZI02LUDP;0000000=02T000190000@00000l00017
01/0IbM30:]hQ@3ldlX0omk?0<VKY`3K^;D0nM:c07aK00020000000:00006`0000000000096[f02=
HHT0Ref20=R^_@3fc=00kLG90?oLhPL0oooo00D0o_oo0?ooo`0g?hT0Y:gP0?ooo`030000000J0:VJ
bP3P^/`0ol800<VM003oomX0oo3A0>_2/P3dc;D0j/6g0<>EX02/N8P0^gj40:e]N00Q5fH0EP0004EK
Y0000:P0J9[;09C1i02mh_X0_^3o0<gbo`38g_l000000:>Qe02nao`20?ooo`80000000P041l[0>7n
k@3E^:D0gKNF0000002`Z]X0omKX0?oPfP80al6700@000000=CS^@33fZD0UZQT>000000<0?ooo`00
2P3oool050003U4002MY0000Q@000540001=00@FG00003T001=K01deNP0S=7L001UR0000GP0VD9L0
4T>;02E<S0000000000o00000000078000000P0Y05l04`2609`0SGNF08i`S@0f0000E00006iRT01g
G7`0MgZF07JE[@27aL`0000001POC`0006L009FO0023Y02M0000Dc]]06Y:M01fHXl00P0000000`0>
@f`0000000L<3@020000000=0<>oh`3<hOl0iOoo0>_oo`3Uool0cOOW034fM@000000TW<j07HN1@00
0000MXG30<C/o`030=Koo`040=[oo`3Oool0iooo0?Goo`<0oooo00<0o?oo0?Goo`3kool0103oool0
1@3nool0looo0?;oo`3aool0oOoo00/0oooo00P0oooO0?oogP3oon00oooR0?oog03oom@0oooA0?oo
g@80oooK02L0oooJ0?ooc`3Ul<00k_kE0?cof`3kom80nOW80<6iKP3@cX`0_K9T01ik/000T<D0EjCH
03^?`P0KN:P03FnJ01IgXP0IM:`08gZf03nJ^P11Vj`0AZ2[05R```2BeL<0QLc207c3`P2XhoT0^??h
0<_ol@3IoM`0g_WC0=kie03Uoml0hOoo0=[oo`3?ooX0boco0<?go`2ll_`00P2llNl07@2@d<00IkN[
03jGT`1SXH/007FZ001hY@00Xk@0CZ6>03R<M01<Whl0Fj^O06^j[`1>YJT008jS0021W000R9l008nP
02F3R@38_>40]JS>0<6YaP3G]/P0oooo09^LE@2IH78005mb001;@P2QJh@0Xg:?00@0000000H042T/
0000001:0000R0000451S02CTLP20=;Ag@0<0<gE]@000000035l0=BO002d/`00e/V70;F]I02XXEP0
d:ER0<:BB`1^AP00Y8T0200000004`0003d0>fVc07jSgP2L_O80]Lgn0:6ci`2JY=`0VZ?L0;K?o`33
i_l0b>oo0<_do`39m_l0`o;_0;k]g029bld0]^SP0=?on@33nol00P3Bo?l0803Iool0g_oZ0;CQ_`3R
ool0__7o05^>D01aXfP0VP1B06`0=P170000OP0009M9;`2^IT80bXiS0>2ZS@3NZI80h:f<0=>QL@2n
RTl0_XY<0<^XIP3G_7h0fL220?cU_P3kf[X0n=2f0>c2W@3R^hP0bkMd0>_M[03D_X40TXm02P000000
3P1R0000HbE104H0800l0000Ic1E09MQNP3?X[40l<cA0?O;^P3olmD0]i6W0;>5T@3>W8<0XG4k0P00
00002P0002H0>`1;09VGb`1jU/40Hd1g0;ND]@3cc=D0omcN0?oLg03on^D50?ooo`070?goo`3`ool0
m_oo0?Goo`0O=840Jgo00=OYo`020=O;o`0K0000002fUK@0omSA0?o@`03/ZY80onh00:ZV[P3Fck`0
051;09jG[01175L0Veeb07D0001a9P00000009RFc@1kS</0HH;104mm^@1YW<d0VlKY0;?Gn02geo/0
Y<3]0:>`h02Q^N@0]]?d0080oooo0P0000001`3Iool0cOoi0<[iiP3;gl40ZjcN0:RQe@3B^=h00`00
00000`3;m>h0boCE0:O>X00i000000`0oooo000:0?ooo`0@0000CP0F<gH083n20000E@0003L0001<
0000<P002E8073Ek018]M000EiP0029]01a@UP0SEi`00cZ2001FV@<0000001H05@1>04`0TP1<0980
F@2V071i[@1G=V<0FP0007>@b@1[Skh0KgnJ07BM[@1oa/h0ak=m0000000lCGP0000c0000H`00BG<0
000005Y8O01IBGl0Ed^30P0000004P0P04800000002GT@2NU/`0a;gP0<gMo`3EoOl0fooo0=Soo`3D
ooX0?2]Q0000^0000000S74007>6b@000?l0f>_o0=_no`80g_oo00L0d_oo0<coo`3Cool0g_oo0>So
o`3cool0oOoo0080oooo00<0nOoo0?ooo`3oool00`3oool20?Soo`060?Koo`3eool0m?oo0?Coo`3c
ool0mooo2P3oool01P3ooo`0oooV0?oog03oomD0oog>0?ood080oooE02L0oooC0>WX[P3Rk[d0i_[C
0>[jd`3^nLl0gNB_0;VoN035dI80_[Y_0;BYF@2l_G@0001e05Z[``1=Xk80Yj5A0;:jL`2_^W@0001F
0000LP0SP;80?9>m06>cb@2:dm@0O<K@06njh027c>d0Vmgb0:o]j@34km80]^K80;[ZgP3Jood0kooo
0>;oo`3Foo`0_o?_0;K^k`2`jo400P2;c/803`1R/9d0HkJa07Bo^P2<bKh0?9Bd002T]`1FZJH00928
02^7Q`0INGl005YQ09:Jd@1INkX0NVNI0:>IaP03000000060;JN`P2c[mT0`LGf0=W;i@3omM<0Sh`l
0P0000001P09000005M<00000016HH40VJk?06fN_`80000000D0e`000?l0002`0000HUVJ06QMV`02
002KY00=001]UP008WL0039h0000002NL@0008YQ092bV03S]h00h[Ek0=NXJP2NNP00aZD004400008
0000000B0000>000Nl40PZWT0:Jik@2QZn40TIKA0<K6nP3=hol0c_So0<Wdo`33l?l0]>WW0:WRe02>
d<P0P<O>08c?g03:n>l0XM[f0P39mOl0803BnO`0ank?09S</@2Pf>T0UMCQ07:UJ`0hKS40000005X0
001b0000NBH00993802QFB/0/70f0<N;G@3LYhH0l<JX0>BkR`3C[W40d:i]0<nfL`3F^GX0dZi`0>Nn
TP3Z_9T0l/N[0?GF/`3afZ`0b;Mc0>OGX`30^gh0V8Df2P0000006`1Q:4`0<P0K04L0=@1nCgH0U6^@
0;nJ]P3/cn`0e:FZ0:UXFP2JE480TE=K08I0A@2gPET0e:=m0=2TMP000000:`1B08UTS02kV:T0XgNI
0;^H^03W_Lh0on?X0?oonP3ooo`0oooj0?ook`020?oomP090?Kon03Yood0g_oo0=_oo`3EoOh0d?Wf
00000000GZ@0Vj;F0080`ZoB02H0^i6Z0>n_]03of]@0omOC0?O6b03DWiP0P00006@000260000`HbJ
0;V2S`2QJGT0PP000:000033TZP0c[gX0;S3o`2>Y]d0KYG>07>PdP2@^N<0XLS^0:K:l@2K_^T0V;gX
09S7hP24`L4000000;ZVd02[X<@0Q;c;09oGf@2]hMl000000=coo`2daOX0W:?H09NZa@<0000000<0
X]KS0;oXg029^8@0>@00000<0?ooo`002P3oool03`0004X09cQg02dnO00006`000170000=P0004D0
001<01XhOP0?<g/0BV^Z001?T`0008407eZN01YAU`040000000<0480PP1Y0<40J@31002>b000IZT0
=D>706V5`@1iY=D0KZ[C06ZY``1X]Kh0hn[:0P000000200h?T/0E0<00340002f[l`0000004`iL000
054005An0P000000300/06D00000000000000000e?_o0<3eo`00l?l00>go0:gVj@21Z000]mW<0;[1
_P80000000@0MXK60;K2o@3Kool0g_on0P3Cood02@37n?/0_nkk0<Cho`3:ool0eooo0>Coo`3^ool0
n?oo0?Ooo`020?7oo`<0oooo00D0nool0?coo`3lool0nooo0?goo`050?ooo`030?koo`3oool0oooo
00<0oooo00T0oOoo0?ooo`3oool0oooo0?ool03oon<0oooK0?ood03oom400P3oomd09`3nol<0i^J^
0>?V[`3Ul<80i_WA0>3cb034fZD0c=BH0=3IWP39b880[ZQG0;VgK02i`GX0_/J20;jnM`2UWdh0Y:]O
0;O7Q`30`g`0^kU_001KX000PZ`0BZ>g03^DT`3^_k80Bj3>06Fdg01ma^P0U=KQ07o7]@2RhNX0_oKo
0<gooP3Tool0hOoo0<[ol`2/j>40PLNn05j/V@0202R8YP0L03BBYP1?Z;T0CZNg04VR[P0XQHX006m/
06D0000f0000000009l0001jEh00000007eGO`2WTlT0]K?d09^GbP2>R;h0VYg@09N=`02_[]X0`<[l
0<CJo`3Xhm40[:5P0000002HKh40QgnO03Q@H0@0000000L0IP1E0<?3e@38a=T0e<7?0;NM^`2;LjL0
O5^>0080VXUH00d0003J00h20@1MCh<0000009AR0000;BH000000:6MT`3;T5h0aY=?0:jIB02RKAl0
/W/c00P000000180000W0000@`00P/H0P:CO08JQf`20SLd0/l7e0<_Zo`3Fool0]o3e09GEfP2=d<X0
P/W2093Cc`2Mg=h0UmKQ08C6h@2<bNP20:GMk`0P0;_[k@2Se;L0FIMc0834Z`1a[800[h^c06hM701n
<CD0J`0006h06P2K03@0/W0n0;61C02lQdT0`HI?0;]lBP3J[7d0k/jP0>G<U03G`800bkUe0=_8R`3R
cY@0il2C0>k4W`3`bJH0m=^`0>cMZ`39^gL0blR=09RgN`1YLB090000000?06DXAP0f01l0FP1909=R
P`2PLi<0[hb`0=o0eP3F]m00IBeB06@XBP2iTJ40WF0m09]F=@2MH3<0Ufh00080000000P0H01e0000
001HCXd0XHVf0;BF^P3oemP0ooo`0?ook080oooo00`0oooi0?ool@3eon@0i?oY0=Wnk`3CnOD0c_Kh
0<G]lP2jh>h0KW2/000SL@1UJjl20:NIb00S0=6cd03oe=d0onk`0?oLg03icm/0j<KH0=ZPVP3VZj/0
l/7;0=FbbP35ZL`0]I[40;:Lb@31[mL0bkSR0=K<o`3=fol0]/[k09Rii`24Zm`0Q:cL09>ji@2I_^T0
W<3Z0:;7k02^fnL0YL>Y09ZXKP000000_JgF0=k3g@3]bML0omgZ0?ofo`3oool00`0000001@2>aJ`0
001D0000E0000=d0ZmC403X00000303oool000X0oooo0100001A0000QP000000001C0000CP0003l0
001E0000D00E>7l043n701]6S000NkL0001M0000UP2;D5@0UfQc0`0000003@1^MZl0N8_207R;`P00
Vm8006Z/0012S@1jY<h0T/WX001i00000000n`000:40003JjL`00P0000002P2ZW[D000000<Jdb01^
:P<0000X0000F@00Bg40;01d05`0/02D0=`2000000090:[Mo`2GeOT00<GI002kc000[[X0000004Pa
HP000000E4Ah0080000000@0NHK20;_NiP3Goo@0c_g^0P34mNP0202mk^H0]>7b0:WCo@2khol0ao7o
0=Coo`3Nool0iooo0`3]ool00`3oool0l_oo0?_oo`030?ooo`030?goo`3oool0oooo00l0oooo00@0
oooX0?oofP3oom<0oooG0P3oom`09`3golH0j^Vb0>;MWP3UjK@0j?G:0=C]`039i[P0gN^j0=OQZP31
bHP0YjUJ0:VjM@2e_gT0^<9n0<G:Q`2RXU<0Vk5`0;oAU@32b8D0]KI]0:B/HP00>8P0QKcV0:flfP3B
`M00?YS204^OcP1N[lh0K;W609WQn@32ool0b_oo0<;foP3Gool0eook0:o]g@1e_[8008mk002F/002
03BAZ@0I01EdO`00IGl007:8001DEP0mOJh09RQQ05`000000000>00006P000000000VHN]0:b7Y@3>
h?l0b]_o0<7>o`2Y]>D0RY?;09jOd@2f`Ol0c^Go0;cMo02df]00U8Dk08]I9`040000000:0880K@1[
D5L0QP2E0;75k02D]lL0OJfb08F^e01WJ9`0ITe]05T00080SdPT00h0]8E3002:N@000000000008b>
J00009L0000006dgB`2gSUD0^h]108ea6@2SOb/0XVT008Ic00L000000180001@0000DP00=8@0Bgc1
06jIe`1[Sm00RjoP0;3Ul@00Jg4009VU06Zg_P1maLL0T=?C09_Jg@2Hen00RL_O08?3g`24`^@209?;
k00P0=O`jP2?]Wl0TL2<08S6Y@1UXgD0JP0008<0L01@03h0MBPW09M>>P2lN500[FTf09QV003C`h80
eZAa0;b0C02bMC`0cZIX0=VlOP3I`H80`:mW0=O9RP3/f:H0mMJ]0?SI/03gf[00jMRT0>3AU`38^G@0
clf>0;2[HP1<Ga0700000080Ea/n02L0?P0_06LgH`2HIXD0Yg>90;24W`2gRj00kLO=05ToM`1mD7X0
OV^J0;R<S`3P]kD0k/Vh0>_6YP3B/h40HcH00000002fZ=00N8[0000VLP2ERKl0ZHff0?ooo`3oooX0
ooo/0?ooo03oooL0k_oW0<Ode02fhm00]NCG0<G^iP35k^`0b?3a0<K^l@2Zd>X005VJ0;BnkP0fAY00
0P24RLX09`37bO`0oO_o0?ooo`3onOl0n>3o0>_Em@3og?<0onKo0?oUo`3[f?X0dlSn0<>ii`39aOD0
aloo0=?Mo`3Jiol0hNko0<cMo`2gc?/0YKk[08:Yf`2D]nD0X/;/0:o9l`2ie_/0b^kh0=WomP3Sool0
kool0?GNc@3B]iX0^YbI0?o]m@3oooX0[JJn0000002R_XX0ZlcE0=kkgP020>G[d0030:6Zf`2Xc[P0
000003T00000303oool000X0oooo00h08Be/0010OP000000000002XkNP001T`0001O0000F@0@=gh0
8TjC018nQP00EiX0001T0;f>TP@0000001D0J7B_07Ao]P1jQkh0NXNn08JJc`00OKX0042>05nFa`00
05H0000e000gHP3ik=00fm2N0<kUc03=gK`0001M09faeP2T[000WG^C07X0HP1m=Rh00P0000000`1;
0;T0DP330580aP020000000907Nnc@00[Jl0=BAI0000001D@WD0E3m`02H0?@0X04l0?RIG00800000
00@0W;?E0=[omP3Gonl0d?_X0P37ln803@2lln`0Qkc[0<SWo`2liol0aoGo0;;Ko`3?nOl0f?oo0>;o
o`3Wool0j?oo0>_oo`3eool05`3oool00`3ooml0oooM0?ooh@020?oog@0W0?Oob`3]jkL0j=fP0>SZ
]@3Sk[h0bn6/0=[Y]P3Mk/00gNjo0;C5QP2J/Vl0Z/200:nmN@2b`h80^<jD07N8?@2/`hD0aMRO0<?A
T`2/^GD0X:aS0000A@0005<0Mi_B076lh`1M[=T0E:CE06Vah@1_/=D0Um?o0=Koo`3Aool0c?oo0<Cg
n`2Ad<8009^3000oBP0`=FD0002c0080002S00D0^H1n000000000000000007A800030000000K07`0
0000000000000000001lV/00O:S;08>ih`1=QkD0QYSC07B<b`2W^^P0[lgo0;;No`2We^@0S/:N0:6M
W@24LXh0000001h03@3;U000N@0306T0;P1BIdD0TGBI08IYT@0d<4d000000080o`3o00H0MUYo09aN
0027D@00Qe4002XK:P2JHWH20000000:0740P0000000002J0740JP2ZNDD0_Ie>07mX3`2XQc@0[88c
079/00P000000140000_0000GP00H:40:7NT03V?W`0lTYh008RE002F_026a]T0SLk<093@d@29bmd0
PlSH09WFiP2Ug>l0ZN3/000000020=35h`0O0:O8[P2?`8l0Ojid052DK00KBTL0HZR`02XOJ`2XOHd0
bH]/0;mlC`31Oe@0]75109eH7P3EYW40cYA/0;imD`35S5P0_9A=0=FjNP3L`X@0b:iX0=:nP03fi;L0
ono:0?o/a`3ojL80jMZV0=[:S@3@_7X0bkik0:jXG@070000000I05`0HP1Z?f`0JSm/05P_I01`C800
R66=0;F8X@2^NXh0/7V10?;:]`000200V0310:6Pc0000000o=_R0?;QbP3_h[/0hmVX0<J]L`22OK<0
a=Oo0<CVo`000000002W0?odo`020?ooo`0?0?ooj@3`on<0c_3E0:CF^`2CbkD0U/no0:;Hd@2PeMD0
ZM_R0<;[lP2gi>`0/]W_05]l]P35cN/0000o0080D72a02L0X;ch0=Ofo`3jool0nOoo0>?go`3Ef_l0
i?7o0?ojo`3oool0noKo0=kRo`3>eOl0d=[o0<gKo`3?hOl0d^[o0=_^o`3Di_l0a][o0;C?n@2D^>@0
S[3Q0:2kj02nao80c>Go0=_oo`3Xool0l_oo0?Woo`3dool0fOS[0=7Xo`2OcNX0Oj?>061/XP2^fk`0
h<SL0>cWeP3oonP00P21JZH00`2Z_LH000000000000i000000`0oooo000:0?ooo`0=01`aL`0086H0
03Ue00000000Fi`002ed0000E@004Ud003Ak02iHW00SBi0002mg0000B0060000000305ma[`000000
00000080000001T0SHd00000J0000000f]2R000VJ03ao]0000000;gF]P3=EIT0c:fm0000h`2[`000
A34001h0<01=0000G`0006H0002`W:P0Z:NP0000001YLE@0000004lhJ012:EX0SW^A0080000000X0
LcT000000000000000000;FF[`39a^l0fooi0=SolP3Eo^X0d_SR0P3Honl03P38ooL0joOo0=?ao`2l
jol0Z=?o08:Vk02`dol0b>oo0=Coo`3Oool0h?oo0>Goo`3/ool0nOoo103oool00`3nool0oooo0?oo
o`0<0?ooo`060?coo`3oool0oooo0?ook03lonT0m_oR0P3eon009@3[nm80j>o00>[PZ03[j[H0f^B]
0=?OY@3Rik00enZj0<oT/P2N]gD0W;=`0:g6R@2]`Gl0[<>50:W<U`1mTdX0//Z?0<?KY@32f:00Xkam
0:6^I`2Z^GD0002808:MF@00Gid0G:GJ066VgP1XY^00LJKQ09C2o`3>j?l0a?co0;ocl@1m^Z<0T/6f
06^Z]`27_^<0100000006030RY40000000000000000006JJ001YX@1aF8H0]:;70:V?]@2^TkL0]9/0
06aC00000000dk6l04:=Q`2G0000QHk708NBbP2C^LH0R;k807ZncP36m_l0dOSo0:fdd080000000X0
]02I0<FI002fM`00QSL00915002M06@0OD5G07]0@@0000000@H@0P0000004@2YK000PeH008=F0004
0B40001Z0000=P000580V02V09jOd`0006P0V02U0<>OKP2jYUL0RgXT0:N6=02kXE@0L5`000P00000
0140000f0000IP1`ZmD0V=CY06fd``2Dd=h00:W3002T_01LZ<<0Ik;:08?5g@2<c=h0RlkG07g2d@25
a=h0UM?R0;nQaP020<>X`P0O08c7Z@1`[H80f?oR0;6KR@0000009WUl0<ZT^P26Q;h0g[B?0>JfR`3I
XGh0_7IO0:EM>022>P00XEP^0;moF@38Vf00Z9A80<blN03D`7h0bk5]0;JFC@3aeZX0o=jh0?oQ_P3f
g;80kMbZ0>?@U`3H`X<0a;A^0;:[H@060000000[0000@01/C880LU>:079CRP1R@g`0M4n20:5mY@2_
TKL0X7jV0<JMY@3V^j40R01Y0<80/02oX[/000000?W`g@3`ll`0mokH0>[W_03Ea98000000;WOo`3o
ool0000a0000/@3ej_l0oooo0?oom03oon00iOOE0;GJ]02khL00ZMNk09K?`P26`l80OKc408W3d`2L
dMl0Z=SW0:cEk@1QPk`009[<0;3Mg0020>Goj`0S05b<`P2Pc_H0cO7o0=Woo`3Hn_l0^]7n0<SQo`3Q
o?l0oooo0>koo`3Tl_l0d]go0<oQo`3?h?l0cn7o0<cUo`3BjOl0c>Co0<cYo`2kgOd0YLW^07VMe01n
W]H0Y[WW0<cbo`3/ool0lOoo0?Ooo`3oool0m?oo0>?oo`3EmoP0X<[]09C6h02>]/`00`0000001`21
H9D0S<W308c9``2Xf<<00>00002I0000Q`00>000000<0?ooo`002P3oool03P0N@H<0:4Z:000?C@00
>gP001YL000gM`000000035g000HHP000400=E:C000;F000048000160`0000000`0c70X000000000
00050000000404=fVP2dgn0004Z=0000A@<0000000l0<6R00380D`0004X0000l0000;P2C0000V000
09h0002S0000000005=6LP000000j;L00<80002^00000P000000302b^il0_7H00?nk000g02D0R@1l
0<jhc@3OgOl0i_7o0=_oo@3JooX0fOo]0=Wni080iOoh00d0h_oo0>Gho`3]ool0Z0000000001BL;D0
/LOh0<O`o`3@o_l0f_oo0=coo`3Pool0iOoo00<0oooo00<0oOoo0?Koo`3kool03`3oool20?Koo`03
0?7ol`3VonP0h_oS0080hOoQ02@0g__J0=Scc03Ek;l0dnNd0=KS[03Jhj/0f>Ne0<kW]`2dbH`0X;n4
0;?;T02ebXd0XkUf09jmPP2E]W/0QYQ?0;SEX@2lf:D0ZlVA09^eM@2P/Vd0XKEb08JDB@1XQd@0Iba6
06ldCP00Q<L008G:05>;d028/NX0/M?b0;S[i@2@b;40_=bk0;_5^@0F=DX300000080/WQ^00`0]XJG
0:AcRP2?FG<0]8>B001^V000=X00GFZ]092?`P2LT;h0WI?209F<_P3A/@020000000E08T0001LG9h0
00400628W`1hGI<0CdJ;0000002aVKX0`:j^0;?0X@000000QTm]0:d0Y@2m0;L0/7`00880BP1G02H0
/6QO0:eUB@2ZHc<0GBM:00<000000140_XD008eX002=J0002P<S07i>N01c?U/0dY^O0>K4c`3@^mL0
UhVe0;<0[@3I^940/K9/0;jcIP2`PSD0TG/U081o00080000000A05T0>0006W<0`^go0;[Zm02Xg^80
EJ6d003IiP2>cM`0V]CW07RjeP2Dd]l0W][Q097BdP1R[[l0AiNj05jYaP00U:<00P1d_L407`1HXY80
000006mC003Nil40Oj1Y0<JK[P2hSZP0:EFH0000002Xa9`0WH:B09A?E@2eKed0]W=8099F002KH1d0
]YiF0:BREP3:b8H0dLb<0=?9RP3Kc8h0bj5T0>[1U@3gd:d0m=R^0?;M[P3NcY<0e/B30;ZZHP2XW500
1P000000:`1F05d0Peb906h0MP1^07H0Bb=J08iXTP2iV;P0Z8BX09mhW@3A/L/0fkFm0;bN]`2bX/L0
R86e0<[@e`3]n=@0d^>g0>[gdP3]klT0000003E0R@2>[=H0coKn06]GU@2IV<h0d>gk0?ooo`3jonl0
iogH0<KR^02_eZd0W<ZU09G:/@2Yflh0^>KS0:SKg`2Gc]X0P;c?08[2e`2A`=l0Nj7C04e^/01_Xl00
0P3En>X07000000006>:04R=[@1RX/<0U<W_0:?=m@2ZcOh0b^So0<kgo`3El_l0h>oo0=OSo`3@hol0
c>;o0<WQo`38i?l0a>?o0<CTo`30iOl0/mgb0:_El023[MX0J8g908:Xf@2Ve_@0a?oo0=_oo`3Wool2
0?ooo`090?Coo`3Hoo@0^N?W08VmgP1nUgP0PG@g0:UjG@3;^KD0Zjbe0080/nCD00<0SlR]001L0000
0000>@00000<0?ooo`002P3oool03P00DHh0076P01e/S017SKP002YB001TV000Ch00;C]h000lPP00
0640B5VF000BFP0004T0=@000P0000001000JP0000000000000Z00020>>RQ0<0000000l0OIZj08Yb
000003/0<G<0000jF03Id;d0000005T0;@2808D0LEf500009@25?cT0[VUD0<V6J@2nXHh00P000000
1@00J9d0Y;6n0?WgfP00a;00HiRE0080000000`004l00027O`00:740F`1e0:`0b`3Fg?l0k?oo0>go
o`3Nool0e?o`0=_oi`3Moo420=Woo`080=Ooo`3On?l0oooo0:80001o0000WP000=c]o`3Eool20=co
o`0:0=Woo`3Nool0hOoo0?goo`3oool0o_oo0>koo`3dool0n?oo0?koo`h0oooo00D0lOoo0>coo`3V
oo80hOoT0=onh0020=kmgP0W0=SedP3InLl0d>Zi0<_PZP38fj<0bnRl0;WM/`39g:@0]M6K0:;7T`2h
ci@0[l9o09>_K`2F_8D0U[^408ZQG02ZbY80]mJR0:o;T@2E[fd0XKj20::dL@1dPcD0K3ED07U2GP1o
Cfl0MDQ]0000K00cMl00JjSQ08G4g`1`]j/0E9I_0;_2ZP2n[:H0a9ZX06]=O`3ofM00mKR>0080_8E[
02L0^hjP0:]jT02/Nhl0bifV0022U`00B7<0000006Aa/@2@U/d0Si3708^1]P3C^M40o=800>[0002g
RP006AT`000P1`0_0000N`0008U`X`1X0000RDUN0700000D0000K01T091IL`2LHWD0TdEC06/V?`1U
03@0X01]0:5TM@2bJEh0Yf1I09MBE021Eh@0W7n[08IYV`2EL9X00P2gSgD010000000E4nA002[d`00
]/T20000000908]DIP0007h0Q0100000002]Xe<0XXHb0968=@1KK@00MFd000H000000180000k03@0
=P0::H00000007Bkb@0`QYT0AiV`05c2e01<Vkd0JJo@08o9j@1NY<d0hOoX0;[de`2TgM<0Q<Jn002S
W`00IcX203:1K00O09YNH`17I@0000280:[9``000000XGRL0;jJ]P2105400000003800000000L2Pj
0:9LC@2nPDh0YG@Z08eJ002MSSl0ZZYO0<k;RP3<cXh0dM:E0>OPZ`3O`8`0iK^=0>o7X03K]7h0i=6I
0=oBU`3DaH<0bK]g0:FEB0060000000[05hcI@1T;E00V@1l09T0O02^09T0[HRZ0:T0W`2C08`0o<3@
0?ooo@39d>00WkSB055mX01FJZP0]=?X0<kZe03Jl<d0h_?>0:g<e0000000<TRA0:oBh`35ko80001X
09JNi@3Qool0j_oo0=Ooh`2ff[L0SKjE07Z_Q`2E`i`0`nSB0;[WfP2giM`0[=kM08g7d01l^LT0M[?8
06bXaP00G9L006n]062=``0209BmfP0W0<KMiP000000=7>R03b0Y`0gOJ<0<GNO04N6/@29^><0Y<oi
0;OFo`3Agol0dN7o0=K^o`3@k_l0c>_o0<OYo`32iOh0^^7g0;;Pk`2/gNX0XmCW06bKcP1IR/00Ghk5
07nef02Ic>80XM_V09_Ij035n?h0cOok003:]02_j/l0FIVi07Rdc`2>`Md0[lk40;2`N@3@fjd0c>_7
0080ZmVe00<0AGPn000000000000>@00000<0?ooo`002P3oool01000O:h0049g000oKP0SLIT20000
000<03D0D01aHX`0<ALm03dbJ01?KJ@0=UfI000iO@0a05X0002L00000000I@000P070P00000200D4
2@0<003Xo`00[]h000000:^ef@2^SP00/6T00<>400000000l>S?00000034Vh40]IVX0P0000006@23
N7L0ZZ:C0;WB`@0]0440oooW00000000OJT0Y]7O002ja@1>=F@0AC=W05U4L`0]008008X005=6N`00
0000OP340;;>o`3@j_l0n_oo0?Goo`3Rool0]N[I0;SbjP3:ood00P3Bool0503;mol0eoKo0?Coo`3b
n_l0jnGj0>cPmP3Xnol0hooo0>3oo`3Mool0f_oo0=_oo`3Mool0dooo0=koo`3[ool0k?oo0>[oo`3`
ool0l_oo1P3oool00`3oooh0oool0?ooo`040?ooo`060?Soo`3eool0kOok0>?oi`3Pon40gOcM0P3M
o]X09`3Romh0g?o=0=C]`02bbXh0//nI0:;9VP1j[X00b^Be08nZL02=YF80ZL6109bjO@26ZF`0U;^5
09:fO@2N_7l0_=:G0;_?T`2O^7L0TKAj0:_7S@2N/6`0:dX007A7K@2;G7X0O4a/04lK@P0l2SD0:@0k
001CRP00Ri`0NG=R0=gQb@3?bmL0X7nA08]KN@37YKH0i/>m0>g5Y@020=2HM00Q09iYN`2[M840/GR2
0;Z0Q02kOgh007]X0000002<O:H0SX:d08Yi[@2GOJX0c:c20>_6c03G[KH0e:^d0000AP000000A000
07X0002BMJ<0a9QD07l000190000L@2F08L0S028E7@0O3aE07PeBP2<CF80XVAc09]IIP2MEeh0QT9A
0080000000@0TfV>0:jA]@1_EHh0QfRJ0P26Hh`03@2EZ5d0000000000000MiL000000;:Tc@1U;d40
G`0/0000002T/YD0bl1i0;^XF`2BTd801`0000004`0001L000190000?@0D=H/0546B01QTV`1EY;`0
IK7805VUa01>V<80EYG907^QfP2cfNd0e?oQ0:7L/@0Y_[<00:nS0=K_i@1oZHT00P3Yi_H07`3om?L0
on6l0?ocb@000000_>K@09ehV`1;:Uh0SP2B0600<@000000E3=`088f=`2`JE00aXMG0<B=DP2DJ1P0
P6h00;J[HP3>aH<0g=bS0=cEVP3]i[H0mn[00?gR_03ihkX0kn>b0=G8R@3TfJ80f<F50<BbK02CRcd0
1P000000:`1204T0[Y2b0:IjU`2VNYL0UEig08UIO03`0=40o`3H0?ooo`3ooo40/n7F0;OTd@2Ue>D0
00000:[Bj032h=H0f^o;0=__c02c_9@000000000?`31k>l0b^go0000>@32fOl0e_;o0<kjh`2LbjT0
QKVD09G7Y02Obj@0d^oA0=;aeP32j]<0Y]W;093;a@2Bc<`0U/gG09?5h@1fZm00B8F]02E/T01_V<`0
0P2A/=h0102]^^H0SGZb09>c/@0SKXl20000000Q0;oEf`0007<0F8Zn08ZagP2bc_/0_mWo0=[ko`3F
o?l0b_3o0;gVm`2fho00ZmkV0:CJh02UfN<0TL?Q08:ef`1JU[l0Ci>e04jD/@1EW[80H:Re062X]01X
[[X00<6m08O4^`1c];H0Vm3O09oCi01FZKl0GjJT08g7[P32j<T0`>K20080TL:F?000000<0?ooo`00
2P3oool01`00VKT008BV001_T`000000LTEM00hJ0@0>3Q000P0000002@1AKJ<0DY?4002B`P00O:`0
02Ya0000GP000000?RXA00@;5`0200000080[jO700L0aKBa0=_1V`00>gh000000;j[^`3=VH80[6lj
0080000000<0001P06iA000c:@/00P0000006@000;l0003>03<0>`000000/8^900000014=6L0ASAX
05A1LP000000<25004llK`13<VL0D4V004Y2N`000000003S0:79l02jhol0h_oo0=?oo`000000Z^;D
0;[`iP3<o_T00P39mOl01`000000_P000<o`o`3?jol0b][k0=SVo`3Lnol00P3Hool0303Iool0fooo
0=coo`3Mool0hooo0>[oo`3/ool0iooo0>?io`3UmOl0iOOo0>ono`80oooo00<0oool0?oomP3oool0
2@3oool0103ooo/0m?o[0>_ohP3Tomd20>Woi`0W0>Woi@3Rom/0cn^n0:k7RP2:]7l0ULJN0=K^`@3?
k<@0]]JZ0:BnOP2O`X/0PZU_07fNGP2F^H00TKAi0;K=TP37fZ80]LN808FRH@2E^X@0]]2H09b_JP1P
?6`0NTa_08YDK01>5S/0DALi05`0D00e44L0Rc]K06Y`002_dZP0img:0=[7eP2aR9d0^I:Y0;>=Y@2S
I6d0h:nB0080^89n00`0Ue]/0;^;V@2cMgd0[FYZ0:iZI@2_JF0000000:1cS@2@KiT0S6jL08MXU`36
Wjh20=^_/@0B0=Z^/00008@0H`0007X0002A0000SFbJ0000000k0000LU5e0000V`2N0;00001J05TN
AP2RKHH0[G:10:EVL`25@eL0NCE<100000000`2lW[`0F42107IRTP06000000090;F=Y`000000WZfL
09jcO0000000d]:i0=o<S@2ZVd`0CT0000P000000180001>0000EP0007X09ERS02mf[01M[;d0IK39
06>[cP1HWl/0>XR^001bS`00H8h008JD03^7I@0=0000_N3o08Rn^`31f//20?7Ol`0O0?;dh03oonP0
oooV07UnZ02C^K@0ASiE06>:/031VZL0000009T0H@2UH5`0`XA`0=NLNP3<Tf<0^H93099b9@2FTdD0
^JYP0;ZYG`3NfJ00iMVQ0>OIXP3fj[h0oNS00?k[a03Tf:80f<b=0>7EVP3Uf:00`ZmX069Z6@050000
00030000C02aVl@0[02f0080>dLe02L0SGfe0=oMo`3I//00on?J0?oZaP3bk<d0d?3D0=[ojP3Pool0
gO[o002:[036k><0eO?N0=OXaP3<eJH0000004eUXP1hZ]40U;3D07=`Y`3:jOD0f?__0;KM_@2IaI/0
VlRN0:oG[`2nhl00b>[;0<?Wb02Gbk40Y][>0:SLe@2Vf]/0ZmW[09o>i`2DaN40T/GO08Fme01i][T0
0P000</09`2<V=40//?/0:kIf@1SYID0Z=G@0<3ZhP3El^00a^Fn02`50000MJl0Q:_K0:[?k`33kol0
^NWf0:WMi02Qen80WmGP0:GJh`2Rf>80X=GS09c?i@2=`ml0KJk706JZ`01PY;d0HJFm06R[`P27`mD0
XMOO0;KXi@36lN/0_^[_0;;Qk@2ah>/0S/[D0:7If@2Vg<d0[Mk50;;O^`0n000000`0oooo000:0?oo
o`03000cLP00?g0000000080000000X0ER030000F000000003Um00TnP`00;G8002id0000I0000000
O9:_0`0000001@1h@UD00000000000000000b=G/00<0000000`0_Y>L0=2MU@3G]J40000009^R]P00
0000002`0000[000Lih000340=[8_038Yg@20000000E02TFB`14<VD0@2eR04`mLP19?740@Q@i04`^
FP1H?f`0DCe^05NR]00d7U<000340000h`2/dol0_>Wo0;7Xl`2/k^@0YN3E0:oUeP2mkN<0ao?d0080
[NCi01D000000?l0002H0000O`000;00002R0000RdX006dL003Fool0fooo0=koo`3Oool0h?oo0>Go
o`3[ool0j_oo0>Goo`3Pkol0g^oo0=g]o`3LkOl00P3oool00`3oonH0oooi0?ooo`080?ooo`050?oo
o@3oooD0o_oU0>kme03]omX00P3Tomd09`3TonH0i?oT0<kZ_02W_h00]M2I0<cT/P36gZT0a^Nn0;7A
WP2I^7/0Qk5i09JeMP2H]WP0VKf50:_7S034fjH0`]RR0::mP@00Pfd00;^D0;O;T02;WeT0EC]a05P`
G`1;5C`0CAPn06ldD01V=E/0@Aa@05=Z000003/0i?o_0000^P0009l0002308ULO`28G840iZna0>Ja
^0020>jl^P0D0>[0cP2lYl80/i>V0;62U032RXl0^7b00:i^L@2YJW00X6Qi095ZT02:KI`0b::a0=^`
/`3M/Jl0h;6]0000002CM:00WWnX09EeX@27K9h20000000A08Y;D@2OOYL0001?0480C@2>EgD0ZGjM
09m`SP1h@FH0JRa>091SPP3C]<00fkJm0=Z`]0000000^I^h01<<3`2>V:P00P00`[<600000006071P
FP1`GQP000000?goo`3XfJ00ZIe<2@0000004P0006H0@Q4005=UYP00JjX007NG03V9[@0lS;@0E:34
06RbaP1Y]Kd0@iB=062ROP3<TG40/Vl00680002Pf/L0hooo0=S9hP80jMkK01l0dlnN0?oob03oom00
F9V[0;S:T@3:`hL0k=710=Z_R01I=fd0n/O30?o;^P3R^iP0j>O;0=K<Y`3Keih0W95308NRG@2YXED0
_k1W0<VjMP3XgJL0jmbW0?CS]@3ljl80ono70>[JY03RdYP0hM:H0>OGX035/fd0DEX000D0000000<0
BcEe06I=QP1I06<00P1Q07P09`3>^N00dlK/0=>ab03Uc//0e[jG0=g5V@3Ug;T0l?KG0?koj@2gi?h0
0;?R001VV00cM8l0MK2U05jNXP16QZP0<FVF035^UP1?Q[H0UYW:0=[mm`33jll0/mBW0;K@V`2ke:H0
`nC00<KV`P2Xe[L0U/NU0:WI``2]g]<0/N7M0;;Pi@2dgnl0[=O^0:KDjP2Kcn40UL_M09W>g@0209_C
d`0W051o[P1`[Kd0Fif908k6`@20]/l0WloR0;_Pe02eej/0[]J^09JiP`1hY]@0R[kM09[Af`2OemX0
VmCL09G>fP2CcMX0VM7M09[Ag`2Hcml0U<cL08g7f@22`=80RlGI08>meP1_[//0NicB09o4j@30i?X0
eOoo0<OciP2mj^@0/n?Y09_Dg02GdMX0T/o?08S7_01i^Z@0FYUe03h00000303oool000X0oooo0P00
00002`00;640051e0000U`000:h0K[>l000X0000>7/03Cj30013Q`00<gP000mI00H0000000X0HGfj
09:fk`2B]^l0]MKe0000001o0000^GeW0=fjV`2dUWL0`M6i0P000000101V00000U200000000GCWl3
0000000801@<DP0h74/0;XFW02j5Y`1?>FT0D3Y[030C@P0i5d<20000000=04lXC`0m6DD0@RAD09RW
d@2W`N/0]m_o0;CUo`2If^X0V][Q0:kVh@2nl>L0a?Gf0<GdoP020000000=0=b^W03oomh0mOoo0>go
o`3Tool0f@000<bn0035X000_H800=coo`3Qool0hooo0>Goo`020>Soo`0@0>Ooo`3SnOl0hOGo0=oe
o`3Nm?l0h?_o0?Koo`3oool0ooog0?oom@3kool0o?oo0?Woo`3jool0o?oo0?koo`<0oooo00D0ooog
0?ooj`3^om/0joW?0=gdbP020=[mf00W0=[nh@3KnmP0a=n]09ZcL@2`cYP0//jF0;CFY02YdJ40/<fE
08:TI@2B/W@0WkUh09J`L02SaXl0]]:L0<3JYP2kfZL0T;Aj002PR@3FhJ/0/lF607nEC018?7`0AC9`
03LOGP1[B7H0N4U^05haF`1h?EH0000803ln003Pj]8000310000O`000640Md]a09mkW0000000hNW[
0080lN7^00l0imC/0<?1iP2YWlX0ZI:j0;JF/02]QIh0[G^>0;V4T@2dO8L0Z7F:09YkX`38[/l0cZ[0
0<:DX`31T9d00`0000004`1XEI40Wh^h000000000000YXf]0;ZVaP000000@`0_0:1VO02SLhl0MdUe
07i;LP2bU[<0c];c0;6hd@2[X[00UUmW09ACF@0C00P0200000000`3Ccol0_Zc40<fCS00200000003
0?koo`3gon/0bl^;00X0000000d003Mo000CHP00^MP0ooko001CO@00JHL004EN001dRP00NP00BhiT
0000001UIb/0QV1@0080000002<0LU40003Ch`2/Qjl0[8N_0:eYC@2GOUP0`/JG0=KI^@3ofm00mn7o
0?7Pi`3^cJD0ViO60?oLhP3oo^@0^JIY08>hWP2Sg<l0bMfd08JKE@1^R3d0^k=[0<JiL`30[F@0imBN
0>oO[@3fh[H0nN:h0?[R^P3ZfJ<0glR=0=[6Q`3Xe9l0h<V>04eA00040000000406A2N@1WDXh0H2]D
05L0BP80SVJ<00L0cJJo0:5hW01A7T/0on_b0>khi02kbj005`l10080000001h0//oI0=VXR@34eM`0
S/;>06n][@1b/9l0MJZ2086/NP18Pjd0JjJl0000a02Jb]<0Ulk60;SH[P35hkT0amZY0<7M/P2kgk/0
/M>U0:oG/03>l=P0g?o^0=gok`3AmO80_NGd0;OOlP2egnl0Zm[Y09K<fP2:aM0208C1a00V0870`000
PYL0^^SQ0<K_i@2Sd]d0P[c>072c]@2RdkX0c>c=0;GDZ@2S_880KZG708g:d02Ccm@0WMGM0:CIi02S
f>@0Y=ST09oFh02Jdmd0S<WA07jobP1e]LT0MkC?07bce@1dW=40MiSA09Bfh`2ggoD0`>c_0;WXfP2E
dLD0S<[;08W7d@2=b]80RLS3072cW000E00o000000`0oooo000:0?ooo`80000000X06b/j000WF@00
<UP002mE0000FP00000002md000BF`0@A8P003b110000000102CT[00SIFl08fOc@1`VM8206BDaP0K
07ZNY`2AYhT0SUaV0;d0001P000000000>;Kl`3Yi_l0000000TL;P0C?fL07V:P00/0000]5DH0R9>g
0797G`179eL0<Q<o048TD@1;0000GceT040J@`0g6DL0G3]T05P_DP1:7T80ERU;0080000000T0N@2f
0;;No02`iOT0X=kV09oNjP2ajN`0aOG]0<_jmP3?oOX00`0000003@3QXG80oooV0?7ooP3aool0j>km
0=^f/P30Y000`IL00=JQ0035OP00P@0008h0003Pool00P3Qool02`3Qnol0hO[o0>3ko`3Onol0goko
0=_mo`3Rool0kooo0?[oo`3Yoo00j?oo0080jOoo00/0lOoo0?Coo`3jool0o?oo0?goo`3oool0ooob
0?SohP3Nmm40iOK>0=gcb`020>Oid00W0=7de@3@l<T0ZlZD08ncM`2RaY00/]NX0;;J[`30h[D0[lbC
09>_K@2_aHH0VkEe096[J02`d9X0/LbC0:k?VP2J`H`0M:9]003>W037diT0YkYh03i@000m>h40=Bib
03H/L01LCX`0GCIU050OBP1hBVl0000005UD;@3MbkD000390000T`2aQYP0[X>H0:b1V0000000IQHC
0080U[GQ01H0[l;[09Z_h@2BX=H0VIG60:2;]02TQZ/0ZXJV0;:;Y@2_P9D0[GB40:1dTP3>d?l0e=Go
0<jok038ZL80HP1H07e4I020AF<0[gIm0;6@V@1mNZ00BTn@0P0000003@1L03`0V5Y]0:IZN@2HFfh0
OTef0<7Jk03iool0`No^08>^Z@0nRXH0>f`n0000001B00001`0000002@1ZNEd0000007EEO`2PHF/0
00000000=@3;ool0aN3F0=;?TP0:0000000A01X00000E9H0029`05D000000000fln/0=K=S03E0840
ol6o0000001QQdX0d;gL0<J^dP2hY<T0ZXV_0:V;]@2/Qjl00P00?fl07P2DV9<0]gE?08_1[02Xf>@0
`KG>0<fdh@3oool0oooE0000=@2ka?00kmCZ09jLJP1<SWX0VM350:G>/P1oT`00Uie?0<>oN@3:_WT0
b[Yd0=g0Q@3/d9l0m]fb0?SO]03dgk80jMZT0>KLY@3LaXT0h]>H0;noOP@0000000D0L4f1075@Q000
0000PU5c0:9aR@020=Zd``0W09QYRP2>FW`0omk_0?oom@3`onP0]kX008=:002EMc<0on?>0?o^dP3m
j<T0mnBo0:7B`P00WhP0DI>J08Bl]P2]dj/000000;J:U`0000004f9b001XN`2Bb/D0Y<ng0:?7V@2c
dZ<0`Mjc0;_J[`3Cl<d0i_oX0>Sol03Soo00fO__0<W]m`31i_H0_NGa0;kXj`2ehnD0Z=_M0080T/c=
02@0L[6o001[U`36l>L0c_CX0;KQg`2iinD0]NGM0000001<O7h0X/n[0000001XYLH0OKc<09C>f@2H
d>00YMKY0:kNk02ahN/0X]WN09C?c`1k_K`0GjJ]05BL[@0lQ:@0BXfb04V2/`1>N[L0QjkK0:gIk@2]
g=@0XMBe09[A^`2;bLD0LKFl062WY000>b=1000000`0oooo000:0?ooo`0>0000003YjKh075RC001S
V`00:F`0:5fK02=JV000=GP002ic000OIP0B5AT0FFAj0000000008030000000306>Fa@0009@0PKGT
0080LJ[L01/0Njg50000002GQ:00aKNj0;R]/`3I/[40000000085`00000002aY001RP@00Pf40SZ=V
03/RD`000900KciA02X=>`1;;e`0000008=Z:019Ab00?ai;048/G`0k95H0@1]40000001T00000P00
00002@1n0=00Rj_;0<_JcP2lk>T0^O3d0<_jm@3=no<0f?ob048000040000000O06<0001Y0000TP00
09e:002[GP00]Fh00;mm002G@P00NQd008DY002B=`00WVl00;R<003Fn?l0e_Go0=Wjo`3Inol0f?go
0=Woo`3;l_l0a_Go0=Goo`3Xool0j?og0=koo`3Oool0hooo0>Soo`3]ool0m?oo0?[oo`020?ooo`05
0?Soo`3Pon/0g?KD0=odc@3Vn=400P3Un=009033il40^=b_08niQ02H_hL0[m>R0;[N/P2lgZl0/m>P
0:C2R02E]7D0_]6F09JbL@2R_H80]mFQ0:o=U`2H`Y00HIU[0:6DQ`00eJ<0X;Ed08ZZK01<CY80>T27
02h^MP0e<GL0BSj002`9@`1/AW<0N51k0000:02ZT500NioB0000F`000800XGfC000N=@80000002X0
R5M[000R6P008QX0Bg1409FYgP1dSLX0LfZT08M^WP2FOZ/008Za001gX000HhD0m=G30>G2^P3DY[`0
n>Co0?;@iP2/RZX0JSaY07U0H@22AV40`XIl0<jDQ02KMX@0J4ed03@0001R0000Odaa0:]kUP2VLh`0
YWB70:n9V03eool008@0001[G`040000EP0006X0001m0000MP000000000W00060000000904eGX01K
IJh0Z8Z/0000000009d0002B0<OEb@37/G00Mfh000X00000010002ea081=K`2eYlD0bLGC04`0003o
omd0oooj08Qf>P000000cIZM0>72dP3WaLh0l=cI07nb002]ZI40oooj0P3d/Ih07P0jK8h0cI^C0000
EP2Y_N<0Qh2g0;jN]`00000006VA001cW@0009d008Nk0;gA[`1HLK00//OA0>3ceP000000];5W0<O1
O@3AcHd0e<N60>72Q`3R`hT0k=6N0?GJ[P3^fjX0j=fV0>CLY03IdYD0h=RN0:B/I0@0000000D0L4Mh
00000038[m00b/c[09jG`P0205hbI@0W0:V0Y03U^]@0oooi0?oolP3Jk<40fNk90>?hd`3_on`0inFn
0;[J^01?RFH0003N0=;bg@3Sn=X0koo_0>_ok03don/0oOl004mf[`000000;UVJ03EUX01[W:h0TlJl
0;oN^@2mejD0`=^/0<OP]03Wn]L0k?oX0>gokP3Won`0e?OY0<;Yl@31i_P0`NOd0<C/kP35k^/0c?;Y
0080Y=>k0`0000007P2IclT0003;0;OTh`39lNP004f5001HD02ogkH008h00000002Fan<0XMKS09c@
i02TeNT0Y=OV0:OKh`2AcLL0NK^[06V^X@1QZJ80B9>I0000000BDXT0CHZg035FV@1nZ]P0Y=?R0;3R
d@2PeK/0NKFB03EnJ4@00000303oool000X0oooo01@0:fbQ02aVW`0^Hih0;6BO001IU@00A8@0=V^W
001AT000;74002E[000bM00bH9D0;6Em0000000006`006fA002CT000000003mn06lP0P80001]00h0
0000001J002me^H0Qk2m06BQ]`0eEP00on7H0?Odo`000000X;bL000iF00o9C/0000007=8E@@00000
00P01`l0000000000000UK>D04ThK00e8EL0D3UZ058cG`<0000000X0F8>n0<c1^@3oj<H0ioGR0=?o
o@3?oO/0b?Si0000001I09<00`000P030@009`0@10807@P308EA002ZG`00ai@00>Be003ec@00YZ]b
0:65<@2QC`00/6800:e[0000I000gMJY0<gao`3>m?l0d?So0=7lo`3?o?l0boWo0;cXo`37oOl0fooo
0>coo`3aooh0j?oo0=goo`3Qool0iOoo0>Ooo`3^ool0kooo0>[oo`3Wool0hOoo0=Gjg`3LmmD0i?S@
0>;gd0020<WW_P0W0;OK[`2G`Y40U;j80:C:UP2bf:/0^=fb0;SL[`2SbIL0TkMm09:fN`2D^7h0Lh@i
0<3P/P2fe9l0P:Yc05NAI@2N0000a=c@0;gT^`2<Yf@0LiAC04I@UP0j@XX09bih034aN@0d:g40F4F0
07YLR`1ZAWH0Jf`007:6BP1hVX@0oo7K001_V000GYP0ARUH03B:O@0HSIL000000080YZWC00X0UJCG
08BMe@1OOl007`000<L0001GQ9P002HC0000O`00K:80mO;/0P3oool00`3on>d0mL;>07UBP0020000
000309MAE01gA6/000000080000000X0MSIA07<lH02TKhL0]XVK0;F<J02dSUX0d:Yi0000002GHGd0
a::l0P0000001@2CJiD0VW2G0000000j2Rd0V61j0080cIR=00l0fKbN0<_DX`000000000003`cN`1A
AX/0ln[m0?SWo@3>_M40a9fe0;BCK@2n[680Df000000000004/02@0000003`1ZSlP0_^;o06o/m@3U
0000oooo0?ooh@000000UWZ20000003^_J00onW30?oog@3Nikh0VfT00:^XIP020000000N06]1C`3D
`;T0hM6Z08EcX`1703H00000001fV`00P:H0]j>b03T0B00^09L0Y<[>0000003U``00lnW80=CEW@2m
/fT0_;eg0=OFVP3MeY`0jMRS0>S@VP3Vbi@0k/fO0=fnQP3F_h00hMJK0=?6Q@3Dd980X:UP0`000000
1P1gBW@0000007@0003I_mL0b@3?06d0Q080UfF300h0jl7A0?ooo`3oool0oooP0=SW^P3Kl</0l_oV
0>kog03Nj/40LYYT0;O?XP3Nn]h0gOSN0?Goo`80oooo00<0ool00000001aX@000P0000004P0095H0
SKOH0:oJe@38jL`0`mb^0;oN]03Mk/L0io_F0?3oj03_onX0jooP0=7]f03Fool0a>Wo0<KYm@3AmoH0
eool0>;ol@80bn>f01D0000006MBT00Q05`0;5fJ01EFQP0/LHl0aNk/00H84@1j0000JH>e001YY01;
Ljh0O[SB09C=fP2=amL0Ok_@08W6d02;bL@0QLBa07ZjY01MX8@01@0000001@13Fj@0MY_=08o6e`2R
f</0OKbR04H00000303oool000X0oooo01@08V:I02QZW`07@h4005jK041]Z00/G9X004:0001MV`00
>7/0039f000iN`00?hH004AY0000000007h0002S00000000M@00HEhg001<Q080001g00d000000:QV
H02Hd^T0P;W60;?000000000F00004L0001K0000Y7Eo09QUL01hDg80S`0000X0000000@0IiIe03l_
I@0f7U<0C2E>0`0000002@2B^L00oocI0;kXh000jnl0000002P0001S0000C00M07403`02048B1`0W
04lF2@1W=Rh0/6P006XI002]Y@00bLH007ndS02OcJH0[Jai0<Z9B`38V580dJmZ0=6l003SonD00000
0<W^o`3;lol0dOgo0<kko`35lOl0b?Wo0=[oo`3[ool0l_oo0?Woo`3aool0i_oo0>7oo`3Rool0hOoo
0>Coo`3Mool0f?oo0=;oo`3Co>l0eo[O0>3he03NmLl0e_;;0080[MF/02D0V/RJ08bkRP2QbIH0ZljI
0;?M]@2dgKD0ZmBY09C0S`2:/7H0S[N006ZHH@27]hd0]mZ[09JmQ`1>QUL0I0000:/0003Iool0]=jd
08:PG`1:GjD0@5:J03E0RP0S:WD09Bmj01XII@0Z:G<0=S5g04UCF`1iQSh0Q9f60?oMhP3ocL`00:^i
002_/@0^C8T0EhNR00@0000000T0/7>70=:cc`2;R:/0i^7A001400000000040e0=kDjP3IdN`00P00
00000`3Kd<D0cJ^d0;fA[@030000000>00P0001hBW@0VUYT09I=C`2:AeT0KbDe09aLJ`2fOhh0_8fG
0;F9GP28DT40R4U80996@P2lOWT30000000508MMRP2aRjX0C`0f09<0LP3:UhT00P2bW7803@3>`gX0
000000000000000001EH04LXJ000YK8009k5061cZ@3FYK@0V[Vl0:jmP@1eR@002`0000003`0005l0
I@0000000000en<0on?B0>>kX`3AX7D0gKR30<J@G@3GX7`0i;NG0<nSR02]N680GP0005L000020000
000N0000:@300;/0C@000000002INfP0c:]e0>?7WP000000d/7H0>W8`03?/9P0Yh5R0;5kC0000000
il@00>T0002KSch0/KUb0=_HW03Vfj<0l>Fd0?7Q/P3beZP0kLJM0=njQ`3A/G00h=2D0>?AU`35_7L0
EfXL0P0000001`1eAW4000000=:QX`3P][D0eJN[09l0P`21Egl00P3Wa=L0903okn/0oooo0?ooo`3o
omH0g>Ni0>3^`@3gom/0koG=0;W8T`27X680_mjg0:gH^P00RJD0o_oo0?ooo`3oond0oooE0?oia`1f
X;l0T@00018N8P0mLXh0001b0;;Qf@2ag/H0^^2o0<WW``3LlLd0h?WI0>koj`3eoo40n_oU0?Wok@3h
ool0e^c^0=Ooo`<0h_oo0P3VonD20000000B0=KVo`0/0940D96^06V[]`1b];8009jP02DkPP0XDhl0
05Z50014F@00KY40GZBf06Z_^`1EW;00C9FY06B[[@1PYiT0AhIN1P000000100eEid0EHbh07Ni[`1W
[9I7000000`0oooo000:0?ooo`0D02URV`10O[00<6bS000eMP0VFIH0>F:O01eBT000>g/003Yl000l
OP0?Ch`0066K000SGP0000000@000000001e]=<005/002MMJP0004D20000000306XM001100000000
00<0000000@0NP0006h0000[0000L@00100000001`1LT`0000000?Goo`3og<40Y7El05LdF`1ZI9H0
0P0000001000=@00>R9D030FBP0d03<20000000305RBa@1<W[0000000080000000D06P000880001i
0000=P0C05/0900207X]<P0W080_001j;`00W4P008m0002C]`00JjjB0;GWd02EdLH0`<N]0=FPL`2`
TdL0^J]O002M003:e<L0aJJ50;IU;`3ITU/0n[N:0?oH]`3og[D0nn6]0>Koo`3`ool0mOoo0?coo`3o
ool0oool0>ooo`3Oool0g_oo0=?oo`3;oo`0c?_j0=3nnP3CoO40f_cP0=gie`3Elm00^^2h0080U<JL
02<0SKf=0:KBY`2aeZD0VLFF0;gLZ@2PdZl0TlFL08>cP02:/GT0Kj1[0:G<W@39iKP0[]BU0528E`1h
00@0W@000>7onP3ConX0/mRZ06V9AP1HK:l0@e>K02PiQ@0M;7T002Id000XM00Y;gX0Ee>E09:0O@1X
MBd0/kao08f@a02]W<00YjO80;F^`0060000000P0?2[Z`3omNP00000001H003Q]8T0/iJ70<noeP3Q
f_h0bj_40:^D^@000000f>7_07AKOP2_TkH0[H0009ME001Y0000FBEC08]KO`2SJGX0OD5N091@I02S
HF/0]G=c0;EgOP2^MG/0PDY[05`L@@24@500a8R60<fPRP2SN9/20000000508AAM`2iQ9H0^XVM09AK
L`1l;bT00P2HFP000`000000001B002_/@07000000030000AP0005h0UK1]00`0000000h0^9Nf0<NI
R@2d000000000600002HC`00a8]F0;YiE`2`J000K1T0064000230000FP0000000080QP0j01d0X@00
000000000000i`380:L0d@3^k<00j/jN0000003Wool0kooo0>Soo`3Fo_@0b^oP0<Kb001E?@00TGd0
091m:@2n]g80h=BJ0>_LYP3]gj/0mn2a0?oR_`3leK80kLjO0=c4R039/Vd0g<B70:fSF00200000008
0751J`1h07<0/kSL09:2]`2WOYd0N3mO07Q?OP3I`=d40?ooo`0U0?ool@3Tk/H0e^>e0?7hcP3iom/0
kOWE08ZNG`2P_XT0X<FG00000024Q6L0onko0?o[k@3oon/0oooa0?ooo`0aBXl0Y/3Z0:bag0000000
02`V03U_X@2@_KH0_nC40<c[bP3Akm00foSM0>[ol`3nool0oool0?oofP3ghkl0m_o/0?Coo`3Yool0
iOoo0=koo`020=;ol@0:0=SWf@3@cL<0TlWA06:S]P0hOYT0M;;606f_/P1?RV0000000032iP<00000
00H009Re06^[`P2Kd]d0MKO406:VW@0_KT1B000000`0oooo000:0?ooo`0D05b6^P0iLZT0;fVP00@0
0000@h404e>>001NUP00Di002dF50015Q@0IG9@00000000DF000JdD00000088k000eNJ/0?7R]055o
^000:W450000000;04D00000000000000000001C0000C00003@0001?0000YUd00000000l00000`00
00002P3a_kT0MU5`05D]DP1LR;/000000<fYW@2/O@00000f00000022HGX20000000:0>KGW@1UUgd0
TWbO0000000P0000D`000440001D0000OS<k08Hl@P80TdmF01T0WfMa09YWN`3DRfL0`GL009eG002k
`:D0_:bF09]VD02hKeP0L1<006P00000O00005X00=O:bP2mRGH0[5La0=6?E`3b^H<0omFZ0?oS]`3j
0000jOoo0>ooo`3fool0nOoo0080oooo00`0ooo[0=goo`3Hool0boWe0<coo`3?oo/0dook0=Ool03M
oN40cO;B0;cS_@2Mc9l208nnS`0R0:OCZ@2_f:d0WLbQ08k2V01f]iP0N[ZK08JlTP2B_8X0P:I[08Zh
QP30g:`0/lV=05n1IP000900002n0>3hdP3KnmX0b^[309NgO01TQT<0I7Jf04IFW@0V@8`08Sj;00h[
N`008G008AmZ07Y_Z03AYi80Jd000;jgMP2;Ulh000310000[P80000000<0kmSj0>oHn02LE0000P30
TId09@2jb<X00:;009bL_000T`0000000<oTe`3?i_l00:oQ001jU@00FW4000000661HP2_U[/0`J[8
099aU`1g@fH0BQI707=4L@2QMID0UgVW07A0J02YPj@0^Y>Y0<VNZ`38Z/40/9:c06TXB@1^?fX0ejBS
0=2UU02f[8<0W7>J0000001eBGT0Y7ZJ0<fT]03?WZ@00P0000020:ikN`030<Vc000008`005j;00<0
000000<0VU0Z08Ln000000000P0000000`000;@000000000000;0000000>03EWY@36/<T008Mh0<6`
V02aQEl0Y6P/08L0002EAbP0QCD00000E@2D0000[Hjb09YWO@2E08X20=h0j@050=D0002^0000oooV
0<7Fg`38fol00P0000001@3X0?l0j?oo0=koo`000000Z^3>0080000001T0<fD005I@002OQC@0`:@0
0>K?UP3/dil0hlZA0?oN]@3oe;<0o]Ne0>OAX@3;bXX0fL>50=2iM`2PV4`0000007H0H@20C6l0G@1J
0000001lJj@0SFjM09EhZ02mYlh0oNCo00<0oooo01@0ooog0?ooi@3Ljl80fn[00>omg03^on00cnJo
06N5@`2X`hl0VP00099=>P3O[Kd0oncb0?ook@3oonX0oooY0<KJ]00iF9`0TZcK03:4@`<0000000H0
]=WL0<OXc02mhL00e?SI0>SolP3Yool30?ooo`060?Wof@3`on40j?oo0>Koo`3Rool0dog_0P33kMd0
1`31j]T0/m^m07FcW@1JWI4006QY001KB@00G@000P0000002P00=WX0052905BB/@000000KT5P0427
X@1=TZL0AHj?04bAM`1BQDaB000000`0oooo000:0?ooo`0>06BGa`1QV<H0CHNi031XX@03?7/07ERD
021NV00IFI8003Ih01E?S@0BCXd0000000/0000nP;820000000401]IUP0XI9l007Jb0000@P800000
01@0?@1B0:h0[`32bjD0[ZET0;fTI@00<500H00005`0000j0000U00009L0002L0000ZP000000001K
1`00Mb@007TV001]6@00C01703D09P80000000P0[k@007]d000W02P0TXfa0:2R^@000000hO7E0>3S
^@80000000L0@`1B01h000000000H0000880002CCUH0VUEJ0080Zg9j02L0_92J0=:WYP3ob[H0om>k
0?oD^03ofKT0_gAH0:MLD@2MDDh0YEUB0:aPE@32N5d0V0000000003`0000kP000>jhR03MY6<0n]6N
0?oW^P3j0000O0000>Coo`3Yool0iOoo0>;oo`3/ooD0jOob0=Ool03Ao?40e_oo0=Soo`3Fool0f_oj
0=goj`3AmML0]^C30:OAX`2J`H`00P2NbIX06@2[f:l0Wm2X08FkT@1g]I<0R/^h09O?/`2Obid0V/6<
07:JGP2MbZ00`n>h0;cAU`22/X`0003j0?WolP3Yo=40fNo60;GFY`25ZFh0IX>o07>5`@0e@HX094NB
01]1S00?<h800P0006<0301FBHH0]I>P0>BmW@2m0000Mi6e0000eP0008`0001608UfZ`35]n40eLKZ
079UW@80UDm=00X0`HQZ0000003X]J00oooc0<^e/02=0000/P0006800000<gD0Xh:U0P0000004`2e
V;/0^Z310;:H_@1C;F@0Gcic08i_W02ROZ<0UFZ@06a1L@2mX/80ek>m0=jma@3;]]00M6VR03L/M@2B
NZ/0kLW;0>W:[@2]a9X010000000102lRi/0a[OK08R]e@00cJX20037ZP0<0=OL/@3A[WP0TfjD08=@
LP00>dh0WEQ>0:QP@@2HC2X0AcY106@000000000EiUn3`000000300009l0K@00001dN`2]MSD0[GM5
0:1QA@000680002`0:>Sd@2][m`0bLC/0<g=mP80f=Go00T0g]_o0=o5g@3`c=L0bYbO0<ioJ03^XXL0
om>o0?oPb03ak/h00`0000006`2;0000003T0000W`2=^`00Pf`00;2;0035UeP0f:me0=J_L`3X_i<0
l<RR0?K>[03Sci/0fLfA0>GAV03=]W80_Z]R0840J02?FGL0QUAg0000001f07@0OF:H09j3/02lZ<h0
eLW^0?CRo`020?oko`0<0?ooo`3oonl0oooQ0=gV^@3Mj;d0i?KC0=G`cP2Rbj80Vj]Z0>?Q]`2G0000
nNgo0P3oool04@3cool0jOoV0>Soh`3LnMl0^>7808>^e030iOH0d^Ko0<2`gP20V/`0^N7T0;7Ma@32
n=L0n?oo0?goo`3iool0mOoo0080oooo00H0l_oC0>Wfd@3Lo_40eooa0<[hi`36k^420=7fj`050<c_
f030g[@0LJ=d06^ZU`23^IX01@000000200ID8d0<7FL03MmX00`JI<0?7nO05:HX`1LXih0EYjID`00
000<0?ooo`002P3oool03@0]Jih0FIK205bEa01=QKP08eZF00Q2P@0JDi008U^G000oP00?@h@0001D
000gL02XM3l00P0000001@0009<0X8l0031RX@11M;0003Ij008002EY01407`1k09O9b@2D/h/0KYUj
06:=R01eL7/0Jd9R04h/CP1fHGl0W6A]0:9OE02HE@008AH^095]8P1l:@00QC8008Lc00020000000=
04H0@P2C]iT0_`0008P0001B000000000;7>l02oh_L000000=;hk0000000:P0^0680T00200000005
091DIP2CG740V65e0:ieOP2hPHL00P39X:L07P3J];`0nl[50?oMa`3oiLD0onG20?o_aP3on//0WTT^
09Y>C@2PEU<0cHIi0?noY@3[]H<0_Y=90>cJ]`3]f;L0002/0>F_M03CVU@0mmZU0?KQZ`3<0000f_oo
0=Ooo`3Bool0dOoo0=gon`3FooL0f_o`0=ooo`80hooo00L0h?oo0=komP3Lon<0b^k;0;[O]@2]dZ<0
VKMi0080Xl^J02L0ULFH07f_O`1g/X/0SlRY0:GJ`02gi<H0ZmBY08RbN`25Zg40[mbi0;cR_@32gZh0
00000?ooo`3oon00kog;0=_Z^`2M_hL0E7P004=b/@0LEYL0:UBG03=UY`0KD9L05D>>0000D@000680
B5RD0:Rgb`3?dLH0XZ1^05ZBSP1d]Kh0Ei2P0000@02=Qkh0W9K70:bVd@0g65D00P2MSYX02P2TTU80
Wg6>08=WTP000><0003J05D0F@2G0;l0K000024<4000<gl20000000B0;6C]@2aUKT0GDF0071SW`1m
N[L0SH2e099^VP2MMI/0ZHBW0<VX`03/_:d0dk>n0;^Xa`1mMJl0?4RA092Jc@2i]>80<7=B10000000
1@34W[D0`YZc0>:i/`00^id0085X0080X=K^00/0kOCo0=SAcP2^UTd0LSE@0;AlQ`36S8@0aHMc0;A^
E02GNeL0TdHS08]0000@0000000<0000UP2AWJX0[99P0000002Z0000000009bXf`2M/>@0XkKV0:Re
hP2^`^`0//Gb0P3:col09`3DeOl0j^Oo0?ooo`3oool0ooKZ0?ojg03oo]L0oooL0?3oh`000000/LSe
0=7oo`3[ool0oooo0000001KTET0VHH00;^ZG`37W5/0ejmd0=NYLP3KZGX0jK^E0>o2Z038YWT0ckQi
0>[BW03IaXT0U8Th09MROP25DgD0J4f509E/QP1hAF/0TffH0;RE]P3=]M80flOU0?SLmP020?ooo`0:
0?oomP3oon@0oO_>0=oT]03Jh;00fN_30;?EZ`1mUUD0]K]n0?;Ua@80oooo0140g_oo0>Soo`3^ool0
ioo_0>[hf@3TmmP0d=b^06bOb02gh^@0_^;b0:c9j01OU;`0000006f=]@3oool0o?oo0?Som0020?oo
o`080?Koo`3hool0k_oG0>;]a03Il]D0bo3M0<K^h@39l>P20<S`jP040<W/eP2I_Xh0000008:eU0L0
000000<006n@076T00000000E`00000<0?ooo`002P3oool03@00Dh`004f2001dZ00aKJ<095ZF01I?
S00>BHH05dF5001:R000=GP00000055eX`2M[Ih00P0000001@0cJ:D095bJ00e6R02hRiL000000080
01YR01P0000g06BR^01ZVGD0001_001DM@00PKH004^0001JV`1NIId0000008<0001X0000J@000<2c
002YLCL0XU<00:1@:`2VFC`0F00G07f4EP2<^kP0HXjn0:X0002700020000000609cLk`2Ff>800000
0000;@1_09h0HP2Q0P0000001@2@I840UVR309]/Q034Uj00fJnc0080jKjo02L0n/g<0?oNdP3oj]00
ooK>0?ojcP3oom40oog:0;jNCP2FG@00ZF<00=FE003caiH0imVW0=CKXP3=h/L0002l0000S03Ra;H0
aima0;F?>P3C]fh0`9A40;j=001J<@00dOoo0=Coo`3Gool0hoob0>cokP3/ool0j?oo0>?oo`3LonH0
enk10=;/``3=kl/0`^W60:c@X02J_XH00P2:]X809`1a[HP0MJf3082kU`2Wf;P0^^S>0;3N_P2Fai`0
KJ5_082iUP1k^Il0@HES0000003>ool0gooo0>;oi`3AkLd0Y/FF07ZOHP1LOCX0XLC_08Fbh@1?Q;h0
<FBV03I^[@05=h<002ej0000MP00OkX0P[WN0;?Ik@3<FVH0U@000?oSh02O[MH00000061MWP1eKZL0
VhRa04`OBP02001kJ`0W0:AdS`2MIWX0X72;0:R0WP3oooL0002V06^0002BS00006BZ000QM0000000
WWRM08mKNP2TKX40MfbW09:4]P27QKh0IG2e06eGSP1oIiT0[hj`0<JR^03S`l`0fK6h0;n:S`2PNiX0
BVN_0000002YZML0RP0009=DJ`2LH7L0[7^E0<>L/`3;YKX0_:6c0<3F``000000O7800080GP1/00d0
NDYa0038f0080000^XVK0<nMX03>UY<0_Gee0:eVF@39Z640WE8j08a05`0=0440N`000100000000X0
WJUh021CV@000000000008Vcf`2>[><0Vl3]09O0j`2C_NX0TkKX0P2U__000`2ca?L0eN_o0>Kno`02
0?ooo`030?ool@3oomh0k_[?0080000001d0^^?l0=[oo`3hool0[jkA0>Gle01VI`00W9500;6[G`3B
_7d0gLN;0>3BV03QfjT0m]Zh0?WMa03A`H<0[hm50=g3Q`3B_gh0Y9U:09m]RP1mCWL0WXjn08h0Y@1P
<f<0/86J0<VR^@3H^Lh0kLgS0?oYnP020?ooo`0L0?oon03oon80koC60>;R/P3OgJ/0c]NU0:[3S@2O
[Fd0eLjH0>;BW`3_nml0e_Co0>;oo`3cool0jooo0?ook`3oomT0m_3:0>;M[P2k/G40TLCL0:OFi`2/
fNP0M[?004b?P`3[_<d0oood0?oon`80oooo00T0oOoo0>_oo`3Woo`0iokK0=?Q/03LmMP0fOCH0=?a
f02njMh00P2ii]h00`2fgl<0000007NEG@09000000030000A@1mZ`00000005H00000303oool000X0
oooo00`0>FbT001LU@00DXX0;FRP03]fZ`0^J:006eFA001FTP0NFYD001YN001OU000A8<200000006
021LV00VGY`0>FnZ025IV00AC8d06e>C0P00;G<04P00?h<0<G^V000YK`1N@bh0001N000fM@00BWl0
000m00L=5P000000DP0008L0002l0000bImT0;1/@02?@BL0RS/[09d00080000000L0]ZnJ02YHGP1D
P/40Vk_W00000000//X00:c10080000000X0001N07^5_P000000MU=m091ZR`2GLI40W7FB0:9lV03?
/;`0iL?:0P3gd]H09`3ogMT0onWH0?oee`3oomH0oooB0?ood@3/hZP0g<N40<6G002LI@00c:EJ0<Ri
L03CdI40_;EX0;ZZ00000900001]0000aP3Cbk00]JmW0;JSE@3?/VD0eKEZ0=?oo`3Gool0fooo0>?o
o`3^oo80kOo]0>Woo`3Uool0lOoo0?;oo`3Ik<00_lJ90<3CXP2hhl00XLZJ09ZnQP0206^GG00R0000
0000WhD0LkFW0;gXbP2ch/P0V/jZ05fEI01HVWL0FJ6:07B[P@1cVf00/>Ge0;SZm037m?D0^nWH0:OE
[`1kXF<0KIQO0<kFl02]fO80PKGQ05N7`@0KA8d07TNA010oRP0AB90002QX0018R`000;X008no0<7>
gP3cakX0ZWD00;2VcP80000000<0N5V7001`0000=0000P2eMeH0102[K6T0Sd]D09]UL@3jj/X20?oo
o`0Q0000Y`2RR@00097<000JK@1QJj`0LFBO089BN03Q^;`0`:Bk0;RR`@2CT/@0D7Rh03I9S01kLJ/0
[i6e0;bK^P3>^=X0h<o]0<JWa02[OYX0KTIe06l0001g0000VfF10:]lV02`PYh0]hbV0=6_a@36YL40
000000E0>P011`H000000080GcMZ00h0GBM?06HbF`0A0000`I6N0<2;U@2fNX40[V]Z0:5JEP2OEU00
U4Lf09E8;013Uid0K@0004D000l0000000X0001K03=JX@0000000000076^e02@/NH0XLO_0971j01m
]]l0LjCG0P1iX]X01`2I_Nh0_=oo0<[`o`3DoOl0hooo0>Woo03Wom`00P0000000`2aZ<`0g>oo0:BG
_P020000000I0>Koi@1oQ@00U9E40;B]H@3Lei`0a<>00>;OY`3lkl@0oo[@0?oof03jkkP0e;]j0=6i
MP3@_G/0X9Q90:AdT@2SN9T0W7:G0340>@2cSjl0e;C:0=jkb`3/b=D0nmSY0?ofo`020?ooo`0W0?oo
mP3ooml0hNJg0>?T]@3IeIl0]:e^0:ViN`2la8T0hn2a0>_Q]0000000h>WC0?Woo`3oool0iooo0?ko
o`3oon@0m?[?0?o/`03GZWH0YgTn0000aP2`f]`0_nG800000037c_l0iOom0??om@3doo/0looo0>_o
o@3Koo80d?OZ0;cWd`35j/l0gOKI0>3ed`3Lm]T0dnC20080XmK400<0000007b/OP0^E@00HP00000<
0?ooo`002P3oool0500iKZD0>fjV03M]Y@0HD8`0<f^T04Am/P0YI9`003mo001:Q`0HDXl005F@04N<
/`1=U;L008J/001@S00JEY<09F2L031YY00OF9L05E6@0P00;G804000;78004>6000RJ00006/0UdH0
0000SP00HYD0F`0007TW001P0000R`0/0;d0D@3:Re/0VeH008<0001k00020000000906MdU@2<QX/0
00000000001[]=D0FZc50000J`00060040000080000000X0001a000000000000TV^<09akW@2RPZ40
Z8j_0;2M_@3F`mD0l=?L0P3og=`0403oi]d0oo7L0?ojf`3oomX0ookA0?onc`3gjk@0kMZM0=no003>
YP00]h/g0<ZgJ`36_7<0bN6c0=Nj000006P20000000E0<SE002_`X@0TZ=N0:FaLP2d^W/0f?oo0=go
o`3Sool0k_oo0?Won`3_onh0h_oo0>Woo`3cool0c>Si0=K[d@2^Zf00[=2Q09S:X@2HaIL0S;J10080
000002L006ag0000002Ab[`0`n_>09cA/P1[XW@006EC002AP`1Z[980MZAa0000002[g_P0YmWY0:WL
fP2_hm00PjMZ08jdN`1ZVLT0a>Wo07fjc01UYLT0AgVe0000R@14I:T0@Ff`0115SP0JDiP003J10018
T@00=Wl0IX:i0<Zb^@2mR`00K4D00:n;YP000000>T<0000]000000000P2<?`001`1m;P00W5M30<69
HP3ScYh0k_WF0>ooo`0003D00`0000006@2XVK`0UJ3=002McP2k]=D0c;[C0:S6e@1VZ/P0=gbd00]7
T00007@0Y7nK0=:[^@3A^MX0d<Ok0<o?o`24NKl010060:Y/NP2XLh/0[WbD0;>5X02dS:T0^JC:0>;>
j02<LJ000`0000004P0Y04d0?AUE03dIE@1G:5X0UVZ?0:MgU02UKhH0YFf10:Q_O`2_LGL0Xf5W0:EP
G`2/IUl0[FIA0;9/C@2CBAl0LbP005l000l0000000T0CVjb0000000000000000086RfP2^doH0_^On
09G8j@1gZmX00P1JS//09`1jYmd0/=Sn0;oYo`33k?l0`O3g0<CajP3>m]/0HU800000003oiNT0oooo
0>7Bi@37^o00oooo0<;V^`1nSCh0Wi]:0;N]H@3FbHT0b[n00?3LZ`3oil40oo3;0?ohc`3`h:l0g<jB
0<jhM03<^WH0V9930;J8X02fSjd0:00/07]:K@3>[/D0ekW>0>2ocP3bbm@0omcR0?o`k@020?ook@0W
0?ooj@3oomX0j^c20>[T]`3Sg:X0TH0g0;>oP@30`XD0kN[10??[a03[dk80h/2L0?gok`3oool0foGo
0?goo`3oonh0mOoE0?oohP3ojk`0hL>;0000R@00e=P00=OU002>`02df>T0eocd0=kom03Roo<0h?o_
0=OiiP3AmN@0b_3P0<?[e@2hhl/0b>gG0<[_fP3>l=L0/L6B0080MZQl00<0IJ6106JLL0000000HP00
000<0?ooo`002P3oool0500FChX0<FJO041eZ`0]H9/07UB@04=k/019P;@0001^000kN`0JDi002Cio
01]FT01QXLH0D8^j001JU`00AX@065NC01UIU00THI`07URG0P0=B8T01@000000000c0000NP00/iT0
d;000080000000L0Jb@009mM00000000000007H00031QTX0W74000<0000000<0U6H0000000000000
100000003`0007h0000002003@1]0980FV:T06Yi^@1^BWD0TFf@09]kWP2WRj/0[iRg0;FTa032]M80
elWM0>C@h0020?oKh00?0?oek03oon40oooP0?oog03oom@0ooK70?CNY03Yb8H0i/1l0>2dKP3@TTX0
^Xdl0<[4QP3Df:d0j/000080000001H0ReH00:o=V@2@]7X0095o002WP@000000eooo0=_oo`3Fool0
gooo0=Goi@35o><0d_oa0<Sdo`38k?l0bNOo0=?ZhP3Hk;/0S/6F08_6YP27`Z40MjQf0P040P@20000
000U0;[[f02NeK/0M[290=kFjP0^IY/0HYNK002]00000000Qgne09:Wf@2QbN`0c?oo0;;H]@23YVP0
NYME06>Pb013SJX0AY6[03b8Z@0WGid07DF?0000Y@1NP<00B76d021CVP00>XL002]i000PL@00=X@0
DfBO07bGa`2e_`00NTmc0000001/FV00JeB;0=cKg@020:N>XP0W07U7J02LG5l0]7EF08ZMO`1[XI`0
UTa109ieT00007T0V:KI0;Vbh@2oaMd0[loL001RO@0009l0oooo08I1B`39VJ<0ZhBP0000_01b0000
HD=g0>Vn_`3Xc>00hm?g0=_Do`1P>VX0[5m:0;J1TP33SYT0a9:R0<RK[@2e[KH0^LO?06T0EP0g02d0
001Q02h0>`0M03T0<@1B0080=Q9>0100NU>108QNR02HJ8P0/7R90;R4U02iR9/0]8BI0:UbQ@2gO8@0
_Gei0;ekKP2`JUD0TD<W07LU001S3`00E0001`0000000`1b0000KP0005/00004000000090012Q`00
JjX00:3H00000000S/T00<GV002me02ggOl0X/Ca0080PjgQ02L0KIkF0:7>lP2haO<0^mGR0;cWdP30
jL`0oooX0?oogP000000l/Jo0?ooo@2S_<h0jo7o0:OVd023[gT0QiY=0:ZSE@2oZf40c[Qd0>6mQ@3I
[WD0jl:B0?OG[03gg[40m>Rj0=o=T`3C^7L0b;9/07]m:P34V:`0Vg>I00000031V;00ek;10=ZibP3W
aM40nmGL0?oOgP3om>400P3onml03`3oomX0oo[=0>o]a@3Wi;H0imn`0;c<Y033b8`0f]VU0>[X_03n
m<l0o>k90?;M/`3FfJD0`Lo80=Cao`020?ooo`80oooX01@0e?C=06j1?@0000000000001?MP0kC``0
Kio90;7KiP37lNd0c?GX0<cag`2ii]P0aNgL0;gYf02mj=<0Z][509S;[@2Hc/H0Wm7806ZLMP809W1Q
I@00000<0?ooo`002P3oool0500RDhl08EJA03EYXP0dIZ009URE03EXXP12MZd0BGVa0000A000M:`0
33Mh02QOVP11Nk00Jj;=03Q]Z000<780:6FO02EUWP0?Dhd0EE2;100000001P000:l00;_00:R:T@00
0000HT9I09^9P`<0000000P0J@0003D0001a0000_0000=o`j`3SmoT0000005`00080000000<0g;6W
0>G4bP3/enL00P0000003@2Q08D0V@2A0900W0000000Rg2J09UmX@2TRJ`0/iRd0;bV`031//d0c<3J
0=76g`3Ec>@00P3_e^D09P3oool0oooW0?ooi@3oomd0oooD0?oa_`3jg:80mM>G0?79S03[_h40hZe]
0;ai;P2`LQl0a8a10>F]L`3NWfL0cXI;0;ak>@00]:d009JB003>c02Q^hD0e_oo0=Goo`3Aool0c?ko
0<Wjj@2Qg]<0]>cS0;gbl02Ff>L0R<cQ06jie01DY[/0NZj807njU@28`j40QkfE0`0000009`2`cNT0
[n7N08[8/01`/8l0AGU305h0001Y0000S/>g0014002^K000mLC>0<SIlP30m_l0fooo0<CO]P1bUED0
KXa807:_e00oO[@0AHRe05BD_`0jK:d0031l0000001kWM@0@VR]02]@VP00Ai8002Yj000nR`007Vh0
02al05Ad]`2@Y000Ue400000001FE6l0h?oo0<;Yo`0209NMd00C07QJQP2iTZD0a8n?0:I_?P2FBBD0
WU<n0000D@0004H008W6002ck`36hOl0]Z?909B9_@1P@7L0002D0<B?V@2lP8D0000006f2a0020000
000B002@V@3[^k@0i;c20=bmd@0B01`0BV620;^M_03=WZ/0gk:h0>;8`P36f<D0000003T0A`0S0240
00000102200W04X08P0o0P1O?7@04`1hEXP0OUN608YJOP2hSZH0_i6S0;b@Y`2fRj@0/H6J0<B@V`2m
PXL0]75^0:eWH`2ICd/0O2dY06LG6P1W5a/0MBHU09A8?02D00000`0000001@2W0000djjk0;R6002@
B`00F@0000<0000000T00032039kXP1XWlX0VlCZ0:;6kP00F7X008^V003@n`2:[>000P2</^@09`1j
Z=d0FiC;08:SeP2he>@0_>;;0;3Qb`3gon80Sl2Z0980002;000000@808?5d`24`<00RKjC09BiO`2J
/V`0];AZ0<>aJ03@[V/0e:U^0>30Q`3Xai<0jL:A0>S3T@3cgJh0jLVG0>2jQ@34YUl0B5400<40X@1U
0640[h:L0=2U]03W^l@0llWE0?oMi`3ol?d0ooom0?oom`020?ooi`0?0?oofP3lklT0in:g0>?X_03<
f:D0P9IE0:fZI`3Je9l0lnZn0?oieP3om]@0i]ja0;W0Q01l^;l0e^_o0080oooo00@0kooP0>[ogP36
ilL0PI=?0P0000003`0002l004^@02]OV025_Lh0ULgB09[@d02Jd/`0ZMcB0;7ReP2giMP0_>K@0:kK
_@2Bb:h0Ok^[02MV?P1X000000`0oooo000:0?ooo`0D021AS@0_GiX0>6bT02mSW@0PD8h0;5jJ03Y[
Y@11LZ/0001=002Aa01STLD006>K05F?_`0fLZT0@G>]01iBT@00C8X0;6fS02a_Y00BFHl2000oN`80
000000<0Fig5001bU@0000000P0000003`2X]jl00000001<P000=fl003ao06H0002F0000_`000>P0
00000000F00f000lDP00N6d00;B80=G9WP020000000403L0:P2M08D0]hN?0;N4S@80000000T0UXB^
09^6[@2TTKD0/ifk0;j[aP35^MD0d/WT0=C<i`3Fcn/00P3klol20?ooo`0U0?ooi`3oomd0oooD0?oh
a`3ok[T0onB^0?K?U03`a8P0k[b30>>]KP3AV4l0Xf800=fQI03LXVL0dZ5P09Ak=01`J`000<2m0<Vj
T`34]h8000000=7oo`36n?l0`O;]0;SZe`2fj]l0]nc[0;3Xk@2Jf]/0QLc=08?;b@1f_K00JZR108W1
W02<`YX0Wl6;07i`00030000000E093<^01c]9H0Hiid05Ek?00005`00000002G003eo]<0oo?C0?oh
i`3oool0gooo0=_oo03DklP0>GYA031YYP00FhT0?hFb04:2]P0lNk80;V:S00<0000000h0LikC02M7
TP0W?h/0035o01HkR@00?X/0011S03YGW`1i8cT0`Y400000002T``00dOoo0;C1o`80KF:N01X0O6jW
0;RP`034Wjh0aY6C0<2j002N^P00002R09eLIP000000072Y0;GTk@2cW<00OG6/04/aL@1lHXd0Pfek
0=>fd@2SIG<0HUbM08nBbP2ZW<<0aKOH000iH@00Kh40ISid01hX=@80000000/0/iVh06UH0000^@00
000003P0A00b03@08`0[05P`I00b04H08`0o03T0I@0206I=R00M07QEQP22Eh80Uf^;0<2DY`000000
]H6E0:ajTP2WMHl0ZWN>0:Y`P@2/KWT0[6Y_09aIHP2ACeh0TU9T09IDH@3>YkL0`i6A09iB?@2^IEH0
PcLi06XJ7P1Z0000G00005T0000006X000150;MeD@1X0000100000001P0fLZX0FYC506^Qd000F9P0
05fP03Uc/P80LjOH00H0NJgN05R?b01BQkd0/mK_097=d`00O`030000000K02T>6P1RZ[00M[KF0:GH
j02Ze;h0WlF@0;38RP37bHP0b/9m0=^nP@3D]7@0hL>;0>FnS@3X_Hh0iKV70>6kQ@3S^XH0jLFC0<:N
F032Tj80OP1a00004@3I/[h0k/C<0?oKh03oi>X0oo[o00<0oooo0P3oonh05@3oomd0ko;;0=OT]@3H
iKL0/LB;0;37T02`]gP0hMFS0>cI[@3fi/00o?GB0>3V_02RXEh0bmom0;OMm03GooT0h_o`0<CTcP3E
l]T0b>:i04mc=`040000000<001OU`0jOJ00DYJ[07^i`P27`l80Lk>Z06RYYP1`/;00Ql:j08NnX`1j
]IT0E8iUJ@00000<0?ooo`002P3oool0500PDHd0;enJ03Q/Y00_Hid0852>02aNVP0jJjD0@G:[0000
C@00TL@0Hi75001SV`1ESkl0=W:Y045c[@0NDY4004b:02a]X`0/Kj@04UV?0P00?g/20000000305^M
a@00LYD000000080000000l0Z;N_00000000C80003M_000lO`1V0000UP000;l0003X0000000005P0
=P00?58007Q]002dR03EbIh00P000000100g02X0W@250;N7S`2gQ8d20000000909J4[P2KQZd0Y96e
0;>M^`2nZlH0aKWE0=;9i03Dc>L0e/o[0080no?o0P3oool09@3oonL0oooM0?ooe03on<L0onji0?oT
[P3fci@0l<B80>jlP`3S[Fh0dIQ?0:=R003MXF@0g:9W0=:QH02DNc@0L6/00030_@39^Y<0a;N20000
003Aool0a_So0<7bk@2hj]L0]^[O0;O/j`2`j>d0V][K08G<c@23blT0M[f`06ZXP@29`I`0S<:J09o1
R`1nL0000`0000005@2@c;P0LkBF06>NM01ENc`0001L00000000U`00mOkC0?ocd`3on>L0oooo0=oo
o`3Koo`0e>o803UjD@0`JJH005^903n5/P12P[H0?7^b02iRX`030000000>07>Nd`0WAi809cn;000a
O`0F>hT003j;000@H`0jEil0NB<i0<:A00000000Y<<00=7oo`2d`Ol206eRWP0J07a^Y`2hX<00a9n^
0<JAT`30^P00W[X00000XP2MG6H00000001`Z@2ei>d0/ic007ea[01;<G40O6:=08=]N`3C]]40XfEc
069LW@2?T/X0ZYc30<Fgf000>F4006n106HnM00N:3D20000000;0;>I^01YF0000;T00000000h04@0
<P0d02<0:`1H<6@0<P1602<0?`0i06D00P1VCHP07@1hEHH0PUN209M[R`30U:L000000;F1U@2/NY80
YgF?0:YgSP2ZL840[6ii0:aZK`2LFF80TDmN099BI02FE640cZNg0<>AT@2NDSd0[VEF08<g>@1Z6Qh0
JP0005`0001I0000001Z0000A@2gME40J00000@0000000H0=W:Z05ZDa@1[XM0005RH001MX00iLk82
07>Wf00607V]gP1HSlP0DXNm0;?Fk`2AcM<007l00`0000006`0Y3QX0HZZ`07JfeP2Uf>P0Z]Bn09o5
T02`b8X0alV80<[2O@3K_X40e;Ad0>73R`3U_Xd0j;f>0>FiQ`3Q^hD0hkZ60>W5T`32WUP0`Y>R07h0
L@000140fK:n0>k4c03ofn00onCZ0?ojo`030?ooo`80ooo^01D0oooM0>obb`3Gi;D0f>Fg0;74R`2`
ai00/;Mh0>7EX`3/fJd0m^K00?cedP3Pi[`0XZ5N0<_Oo@2ggO@0eooi0>;ol034i<h0eO;I0<SR^@1?
LcL0100000003000GiL0>WfP05:FZ`1k^L80Ql?207>cZP1XZJH0L;2`08O2^P27_Z<0N[FI05B>IFT0
0000303oool000X0oooo01@07Tf:02mNV@0mLZT0:5jH01e=R`0lJjD0=FJQ03M/Y@10MJd0001V001Q
V@00@gd008Ve04ek[`0oH9d0Bgnf049j/000M:X007JP029]VP806VBE00D004Ul001OS`0kPj`00000
0=VnQ`040000000<001jW`00Mi/005n8000bL`2Y_]D0e_Sb0?coo`00LIT0001Y002Y_`2bg]L00;Vi
0P000000400h03@0@@0l0:Jbf@2bY[l0000006eIS@2ARKP0THFd09J:]P2TUK`0]:;20;n`c@3Hc^X0
h=Wf0>;Qo`3SjOl50?ooo`0A0?ooj03ooml0oooD0?ooc03ojK@0n=>I0?75RP3a`XX0nLRD0>jmO`3P
ZP00X5P00<V=0039XP00K7/_0>6aY03_aKd00P0000004@2WK@00bo_o0;[_lP2kk=/0_^kJ0<3`iP2n
l>`0/NSN0:SSeP2OgM<0UmS?07ZdSP2<`i`0T/b^09WA]P27^Y40I8T00080000000<0Pl:Z07nkVP25
_IP00`0000008@2aRi00hkbS0>?hdP3olMD0oo[Y0>Goo`3>ool0_OO^08JXL@1L000004b?000fOP00
F9H0762I02U[X`0OEiT05D2:000YM@00K:P008G0020iQ00/AI0004VD00haP00J=X@002Ae000bP@1Y
0000G`000000003HcmL0joOo07ab]@0204IKX@0H07F7``2[V/D0ZhRV0:n0U@3@Yk@0WHNc0;f;UP1n
AUl0Ue1D0:a_N030V:d0Y8fg071a[`1CFIX08BE@0;bmo`2na?l0000007=ISP2XX=00b/?Z0<c9o032
_nL0c<3P0P0000000`00EF`0061N01X830020000000803T0;P0i03L0;011050YGP1204/0<`0g0400
E`1D09D20000MP0@0000IP2LL9@0[hBO0:akU02/Mh/0[7B80:miS@2aPi/0`Z2k0<>K/P2nSj40^7n=
0:Q^P02VK7l0]hBF0<JDX080000001D0AP0009UGH034T9T0/X^S08]2@`20;A/0NRD;08Ti0025>@00
iKVH0<ZJJ@2IG@00PcX009]D9P2IDal0@WNc06>Ib`1SU</0Gh_7051j^`00Ljd00P13Q;/0901KV</0
JZc@056N]@2?aN00O;Fg0;3D_P38l^h00000001EO`00DGD007NP07beg@2[fnh0^>CG0;[DW03GhJT0
i=fU0>[CW@3WaY00f;Ui0=bgOP3HY7P0eiid0=>NJ`3?WF@0gK=l0>[8UP3D^7L0RG@007mRGP0b9RD0
i<SK0?oGg03oh=d0onSX0?oem0<0oooo0P3oonT04`3aom/0i_390=_U]`3Eh[80X[9c0;G8S`3:eIl0
h]f[0>WS]P3`kL@0i>o80<CIZP1oXFd0Vl_Z086jcP2=aL/0Q/2h09C7`@2jglT01`0000002P00Cgd0
0:G105fQV01QYI/0G:6H04VAS00jPhh0CYFI05VMT018R6YZ000000`0oooo000:0?ooo`0D02mMV000
H9T006RO03EUWP0PCX`095BA04Ig[`13LJX0A7fa03afZ`0?AH@005>=01eSU000HY0005VE05>5_01<
P;L0@GN_05bGa01g/MH205:@d00D01aQU`0]Lj@06FFD015PRP0;BXP005ZB05BLU00aN6T007RX001>
O`00TK00B9Bd02eiYP000000e]C?09Z6K`0`P8h0000:0000C`0PIjP20000000403/0@@1=8Tl0VXf`
0:bR`@80000000/0SXo108^8_02;Q;L0THRg0:>G`02fYlP0cL7O0>7KnP3Th_l0in_o0>[eo`020?Go
o`@0oooo02<0oooZ0?oog@3oom40ooRg0?oTZ@3cci@0mLZF0?kAX@3oeP00m/<00>R`001N0000[G@0
071b00000000K@0009P0003RZ@00_iP007]O0030kn80c_GK0<;`g@32l^L0]^_M0:cVg`2gjMD0^NS?
08k4W@2AaYl0Rl:K09;=[`1k^9L0DI1X0000000206B^YP0W076dXP25aK00P;F=00005`000000/HRT
0?o@_03Kej/0dO;A0=cdg@3Jn^/0b?GZ0;KZh@2kkMh0IIMR04D0000TL:h0039l02YSXP0YJ:<09fJQ
01mDU`0;?8D033f700i=S`0MDiL004RB03AGW`0oGjL05CJ4000/N`0P?H`003B10014S`26T<80P`00
0?ocfP3oiol0PZ?[0080>EZS00d0NWnk0033g02NZ:80^l:X0<6J/000000051TH0=B_]`3ga/40omc:
0?[>d037]]<0RYW@0080000000L0g_oo00000000H000`j6f0=[<jP3Meol0g]go0080000000l0GRaM
085LR`34d?X0a_oI08F4000:0000:P0L05H0D01404T0<P1603XAB00/0380@P1;07YJR`2;LY/00P00
06D08@000840WgZP09M^U@2RMI@0[H6K0;Z<W`30Ujh0d[350<nie@2mZ/d0Zi6f0:=^R02RIWP0[W^C
0:o4^`2Z]<X002A=08H0=P1J06<0]YBH0000001H?gd0Vh4008Mk002VGP00^G=@0;QfC01]0000c/FW
0<n/Q@2MH`00Sd`0071_00020000000405f>a`1LQ<<0HXO603aNY`8003Yi02D007nU04bJ[@1MZZT0
FI]n08bYLP3HmMd0b_?V0;KXg`1i^J/0000006h000000;80R;oI0<3]i`3DhJ`0h>2X0?3X^@3ch;00
gkj30=bjOP3W_Hl0jKNI0>ZiU`3S/hT0d9eT0<B@DP3I[G@0dk=b0:>@001?FiP0a:c<0<jV^@3Xa=40
om7@0?oJeP3ojN80ooo]0080oooe0P3oon803`3fom/0i>c10>3W^03EgZ`0XZEQ0<kGX`3Qhk@0hn:c
0>?W^P3Jj/40`mfa07bKG@1j/iX0FYZ401aUH@0<00000006001GQP0iPY00N[Nl07bhY`1>ThL0?8En
K@00000<0?ooo`002P3oool03@0cGiT0<f:L000cL000B8D0A6jV02aMV00^HI/0DH:h04mo]@1@RK/0
6EF?01E;R@0YHY/00P00E9001@1=Q;T0Gig504:0[`1?Sk`0Ah^a0080I9o700d0GY[704f<_018RKT0
;g6U00];R00BDHh0:g6U04F<]`0eOjX005>4001JS000GH<005Ac0080000000<0001G00MKLP00KH40
0P0000004`0:01`0=@1406M0J@2UP9P0/hbO05ADU@1^Ij00QXFi08N<`@21PKP0Pgfc08f4]P2OU;h0
^k3C0=gIn@3OgOl0h^7o0>CZo`3Ym?l00P3_ool40?ooo`0S0?oonP3oon/0oooM0?ooe`3oom40oo?5
0?GHX@3oh:d0on6d0?c@Y`3ga9h0jKfJ0>6nRP3J_W/0WTP00<9i003OX@00gJH009e_001UDP00bO?T
0<K`f02ok]`0_>kT0;;YiP2]in@0_>cF09S<Y`2Caj00VLbT08o4W01SVV/0C85=000=802^0?l00`00
00009P1h^Z<008eY000000000000iL740=GC]`2[eZ`0_^W>0<?`gP2lknX0[NKV09G?``2IbJT0AVl`
0000/@1GN;L003j602]UXP0[J:@065ZE01a7T00EA8`02d2701eHV@0@C90002]g029:U00`EIh08TVD
000cPP0_BiL002in01FP2@1jVJd0mP000?oU^P3onMH0]KW;0P0`Ej005@00@Hh009Jn0;^@0035TgP0
00000:R2V`24EWP06R4O0?oog03oomd0o][>0=2ec@2ZXlh0WhFX0000=P000=/000000<fcc03F^L`0
eKkG0=k8i@030000000308ENS@0K01`0jooo00<0000000T040dA00000028Fgd0>01302`0<`0_0440
Ne9o09e`SP0000000P1P?g@0702POjL0VGNQ0:f<[`2eUKH0_J?50=6fcP3OaM/0hlWM0=Bof@2kZLh0
RHc60;FP^@3ff[h0/]Nd0<3Hf`2A`n<003me0:<0T`000000ak360?SJd@2gTjl0J7JF002AY`00O7d0
[9Qo0<VaT`3GZGX2000000090=2CM039Rel0LRh00:40001l>`00<fNW04Ye]P1AMKP0A5nW0080>eRR
00T002=d001W[`1^JFh0]iiK0<7B]P3Mm]H0eO;K08a9001XY;800`0000006`1=RL00/n;Y0=7`f`3Z
mlX0m_;70?WZ_`3ii;T0i/bD0>C4R`3dbZ<0omZh0?S@[03V`Hd0eJY_0<VIFP2iVDl0ZIP00<BO^@2m
Tj`0cZ:]0>[3`P3jclL0omcB0?oOdP3okMP0oocN0?oogP020?ooeP0=0?OldP3Yj;d0hNBe0=;O[@32
cID0b/:90>3GY03MfZL0e^>f0=3V_02S`I80QkRB07N[Q@21000000`0oooo000:0?ooo`0D01i<R00n
K:@004Mk001^XP1WSL00EH:g03QaYP0UHiT0<VbR05f@`@1HSl0024N1001i[@00HiX003If001@Q`1=
SKP007BP03IeZ@0XL9X201YXS@0A052:_@0gO:/0BXbj04B5]@0HFi<07VFG000oL`0TKi`0>8FX02im
V`0GJ8T005V0001;L`00AVT01UYl01EVR000IHh00P000000500;0280000J03`FB@1V?6D0VgFA0000
0016C980J6VV09:Md@1mP[`0Ng^e07Yf[`29PK@0WYC00<g:k03Mfol0gmoo0>7So`3Vj_l0j?Co0P3/
o_l00`3jool0oooo0?ooo`020?ooo`0R0?oom@3oonH0oooN0?ooe`3ookl0ooVk0?oY]`3oiKP0ooc6
0?ooe03om<<0hM^/0<ZcL01W0000D`000=/0003IW600/G00099B002Zh]d0X]W309SGb@2Og]P0Yn?K
0;7YgP2Ne;P0T<JP09;6W`2Jc:D0ZLnP06VCEP1SS50002aC09H00080000000<0?B8^0000f@20ZHD0
0P0000008P3MglX0Z=J_0:;F]`2[h</0ZnCL0;W/jP2]g]00S;fM06fLI`00QKD0003L002KcP00N[40
:FFQ03Qg[P00OjH004=c02EIW00008l04E2A01QLU`0@D94003J202]PY00]Di`001IX01@iQ`0M>8L0
Igfm03YFT033c=40cP000>_<W@3ffKT208`0000E000UM`00J:40UWL008A60026=`00[Gj>09n@Y`2m
ckP0ooo_0?ook03oomd0dL;;0:BF``000000P@2X0=7/o`2efOl0[<7W0;RTb033XKT0SX^n00800000
0100[j7B0<g=o`3Nkol0enoo0000002PW@00_jP0089bE0000000;@0/03L0>P0c2D40Ecij0650N01Z
@700A2YY0P21KZH0901oII`0UG:N0;6@/`2lWkl0c:g70=BkdP3M`mL0f[[;0=FfbP2ZVL80PHC009V^
h@3S^;@0Wfm70?WMd`3=dNH0TJoL0000001X0000000007EER`32_lP0IINU00000000EVl0000001aO
O`3ookD0f[Mn07/g000k0000_H1B0<>AE`2EG`00Zh`001T00080000000`008VD04>=X@13SJ40BXVf
0000OP1^V/`0_lnl0;BNH@3Xn=D0j_3>09=F0033Q@030000000K03Q[[`1k[=80`n_N0>koh03bnLd0
nno60?W[`@3_h:h0k=FP0?7BX03olll0onS30?SM/`3/ci/0dkQi0<6]I02IR3H0M3QE0<>?W@3``;l0
omG80?oKc`3og<l0omg<0?oZd`3ommX0oocJ0080oo_D00`0jnZo0=gQ/03?f:@0b]ZW0;k<U037bi<0
gMZY0=GGXP31_X00[L2807NYO`24]Y62000000`0oooo000:0?ooo`0D01Q5PP0[I9/0<V^Q0000P00j
NJH0FHRk04b4]P0]KYl0762B01IIS@19Q;@0Iio:029QUP00Ag`005Z>001;N@00D7D004iV031mV`00
SKX2002:/00@0026Y@0@GHT0:G6P00mKRP0RJI/0=WfZ035mX`0OKIH006N<001hU@0VMY@06FV?00M<
QP0?GHd0062@001OS@<0000001@03@0a0000=01474h0KDA/07eCM`1/0000000007V0^025QKX0NGN^
07QbZ@1eKZL0QWZ/0;FaeP3Ad?80gmgo0>;Ro`3^iol0n_3o0?cio`80mooo00<0m?oo0?ooo`3oool0
0P3oool08P3oooD0ooo_0?ooiP3oon<0oooT0?ooh03oolh0oo_80?ood`3oomd0oooF0>3`a@3B]gT0
]P000?L0003kfJX0kL2;0<:7002IE000Tdl00:[Te`2cjMh0[nSU0:_ViP2Gell0R<Ra07niT`26`J40
U<Z]0:77V`1jYF`0Fghk04L0002H00020000000>0000mP0TKFD0HhU]09>WP02gbi`0/^3109C:Z02H
d[/0Y=kB0<Wfk03@nNT0eocU07FKGP0oKC43000000030017I000BeL0000000<00000010004]c001I
PP0006X007nT0019Q@00=X4006^`000jQ@009gL002Ae0358T`000000L7Fd0:VSU`3E`h/0gkZ[0P2Y
O8l01@1GKJ0003n607]LR`1hCWT0YWF>0080000000@0_=Vd0?ook`3om=000P410`0000006@1U04T0
c]:`0<6k`P2DTKl0Sg:R0;fCZ02PKSL0001<0000002lb_80gOCo0<_^o`000000b>Oo0=7?i@3Ffl/0
DAU003<0:`134T<0CbML0:B7<`1PBH@0BBe[060lL@1K@Gh00P1K<fL03`23G8/0VgBL0;F?[@34W[H0
aj>j0<NS^@39Wk00b9JO0=>W/03>]]00[ZcK0;c?n`34]L`0E`000340000200000008001Z0000J`00
ARI?0000003Tc_80HGNj0000F0000<`20000000<0020/@0QB[<000200;1/001Y0000Y6/00=2Z002V
R@000000000NEP00?X80;4^G0P0ZAi@09`0bC9P0<F:T0000@@1jZjh000000>k`a@3ei[/0on>n0<fJ
I0000000C`0i04L0C0000000F8K50;;gk@3food0n_o/0?kndP3kl/T0mo340?KY^`3dh;40onW:0?oW
a03oi;`0k=RT0=_?T@38_7D0Y9]<0>k1a@3oeMP0on7J0?oUeP3oi=P0onGE0?oWd@3okm<0ooOD0?oh
e0020?Sbb`0;0>gT^03DfJ@0_lbB0;oAVP2hbiD0dMn_0=gX_03OgZd0b/bC04j4E`1;RF/0P`00000<
0?ooo`002P3oool0500lGiX0BXNc03emZP0bLZ803eJ4000oM`00LZH0Ok;E06NQa@1?SkD0002503ii
Z`1NUL<0:FJK001EQP0KIY00;7NJ03f7X`0QJi@0:66J0P0XIYd04@00HhP0:gNK001^U`00DH806fBE
02acX`0iQJP0?hZ[03j:ZP0aOYl0:gRL025^UP00Bgl005:40000000A04L03P0>00<0000001<08P19
03/0@@1M04d0H`0004D0001OGid0SGj/08McX@1oJIP0NF>E079UW@2MU/40`/7S0=3?m03MgOl0jNKo
0?o]oP3olol0oo[o0080oooo00H0nOoo0?ooo`3oool0oooo0?oolP3oonX20?ooi`0O0?ooi@3oon@0
oooL0?ood`3oom80oooI0?oofP3YomH0jNg20?CGX@3kgJP0o`000?o/_03lgJ`0eZ`00:f9002ZTc`0
SfD00;g_j`2fjo40]NWN0:cPaP2>ajH0QKnM0878`02`hmD0KYiX06ZLJ02U0000D9:20000000204]P
D00>0000000009@006>D06Rb^02Acl00U<^]08g9[`2Nf/d0a??[0;O[iP2PgMX0000004Mg?`00=P0?
0000000:001?T`00CHl002Yh000`OP0006h0000n059JX@2V];H0i<>K0?38[`80fJZR00@0UZ2g000c
NP1_Ei40MUbA0P0000004`2:H00000000000002jMU00eIYd00000000048000240=NjR03K[8D0_XnA
08i]V@2EKiT0a9fb0=B[^0000000U`000<oMgP3;lOl00P000000302U_Nh0YmWB050H@00i03H0BQU8
04hTF@1[Ag/0IT5f04@LE01A;VP0OP1k04`0C@80HS5O00l0UfjE0;:4WP2dPIH0_HjR0;nCZ@2iRId0
]7f;0;UlO`38SXd0^YN[0:1KG`1A6DL0IbmF05HLA@2KJhL00P0000000`00E`0002l00?ooo`030000
000<0000]@000<8000000?o]k`3Z]@0000000000L@0006@0[78d07]4000a0000HRP00`000000:P00
=X406Sj;01XnR`0aE9h0BFnc03aY[0003f@003X00>KMZ`3]eJ<0nmJ`0<40O`1G07H0R`2T075RX`15
HJX0EGNm09_>j03cool0oOoi0?oof`3nom@0noK=0?ogbP3ol<@0ono<0?o_b@3mk<@0hMfU0=?;R@36
_GL0ZjYN0>>od`3oeml0onCS0?oYh@3ohmP0onCB0?o_d`3ol=40onc:0?[P^P80m^c500T0kN:e0<[<
T@30b8`0]/J;0;cBW`34hKT0^MZe0:2mUP1VT6P0Q@00000<0?ooo`002P3oool0500QEY00EHZk05N<
_01HSkd0Ch>f0013OP00?7H007>V08bogP1`ZLd0EI2l0000L@0mNJX0G9Jo04><Y@14RjX0<7JQ03ao
[000LjD006FL0P0ED8P04@0aN9h0>8:P01MVRP00Jhl007VI0028YP00Jh/007JE001jT`00A60004AO
0018K00IJ8d01P@;000_L`0R06h000100080000001@0;@0l02`0A`0T01P0C@0W03L000000000PgR[
08AeYP1lJ9T0Men@07IRU@2=R;X0_<3T0<;6k`3=doh0fn3o0>?Ro`3cjol0oOSo0?[oo`80mooo00H0
mOoo0?ooo`3oool0ooon0?ooj03oonL20?ooiP0M0?ooi@3oon40oooG0?ooc`3oom00oOoL0?7og`3T
omd0l_o<0?ooe`3hl;X0oog=0?kea@3lj[P0hmnV0<75002_XDh0/J9>0:CPi`2`in@0ZN7=0:OL`@25
^i@0NKVS06Vi`@1n]Xd0FiI[09^1Z01>0000100000004P000=l0003V0000kP2>cm<0PL>d08o;]P2N
fL`0_NoU0<Cdl02Ng=h0R<g=08VKE00000006`000000001K0000T00008X000L0000000D04@000000
00000000000002/0000200000007000JI@0005/0001Z0000UP2ebP00ejB0002a_P020>NcW@050000
00000480F4N908]hY`33W9d0100000007P1HP9X09cU207i4G`3?`]80gKc4001`0038S7X0[VMP09]K
J@2ZNiL0g[:l0?K6`@1G00009`000?7oi`1R8cl0GbM;0;^XGP000000EA]005<0?`1?6TH0Fc1Q06Tm
JP1L;Uh0@0m204lLC01`07T0>`0c07T0R@80Zj380180SFVF09]gWP2_PI`0^hVM0;V4U@2TLH`0_HbL
0;9hQ02_L7D0^7j6095KMP1mB6d0SfVD0:^E`02HOJh0W7FL06mF000201P30?ooo`0300000028P8h0
00000080000000X0UZkP0=SKh@2MSh80UeLi00000000VYd0X7l00:Qo001[0000A@000`0000020000
QP0W02Y>V01?MkT0Bfnc000SM00004d0VZoQ0<o8cP3]bIX0ikn/086@b023VmH0N8g<07J;c01?J;<0
R:oQ0=Koo`3eool0m?oW0?7le03mo]D0oooN0?oof@3on=00ooG<0?CaaP3UjKH0gMfS0<K7Q01nP2d0
g[2j0?[9b03oeld0omoF0?oUe`3okmT0oo?E0?obdP3om<l0onFn0080m=^e00P0jnBf0<?4Q`2GS000
ZkYk0:S4S`2IaZ00KjV902=S?XH00000303oool000X0oooo01@0;EfF04Ao[P1ISkh0F8^l055`X@00
?g8005f=001WV000MJH0CX^U04R0/P15Mjh0001n02M`UP1;T[00CI:b04>7/00[KYl0:F^N000ZI`80
:FVI0100<gbI02QaLP0VLXX06VR<00]JP@0WLiL0065l001fU000RZd04f>501UYQP0;G7L006Eo01]Z
OP000000<P2D0`000000500m04@000000540:`0m01/0@00o05@dI`27NZ`0OFfP071LT@1eH980NFNK
0;2fh02nao80a<km0<_Go`3@fol0e=oo0=o]o`3Znol0k?oo0P3`ool01P3eool0oooo0?ooo`3oooT0
oooT0?ooiP80oooU00P0oooV0?oog@3oom<0ooo>0?okb@3dom80j_oH0?Ooh`80oooW01D0oooN0?So
d`3dm/L0j^^i0<oNY02i`W`0/:eN08kBf02De]D0X=g>09kH``2Jd[D0FHM>05^WV01T[j40>H1P04f?
K023PKT0IDYl03D0000000000P29Lj009`39f>h0_^G_0:OPh01j`;@0TmCA0:;NfP2mj<l0_>[O097B
e01oalX0Ol2_03QgCP00000000100000HP0006L0_gUV0<5i002GE000@`0004T000140000<0000380
00140000C0000000001;0000>`0004<0001G0000DP0004D000015Ed0001Y000FJP2U/`0000000023
Y`020000000L0?oYj02]0000001Z07N1_@2W]=P0[k7100000021Q[l0EWVk06QG001@<@00<T/006NC
/02?WlT0/IRn08]aUP2CBE00We]T0;QiOP3od//0000005/0001`000000hT06P]CP1[<E00RfAJ05/Q
A080000000T0LD5[06LlJ`143ch0BaQ605DWF01Q@7P0>00o06l0L@2n0?l00P2jeol0102>LZ<0XXRc
0;6C]`2mVkD20<BO]`0:0;NB/@2/OIT0_X^G0<JFX`2>Dfh0TVRA0:9mXP2OQ;80NUjD001LM@800000
01<0OL7C000000000000][n?096G[P0^:C40QDIB07maS@000000002L02eFQ`2HO9l0^XER0000001m
JP00]HU80:=^:01`0000VE`000@0000002L032im03iKY016G:@002n00000C01DR<80U<;Q0<K1/`00
0000SWV>0:FR_P27XM`0MXS9065c^`1oW=L0^Nci0>coo`3Yon`0j_oI0?Coh`3monl0ooo]0?kogP3f
oMD0g>^n0=_Z^`3EhZd0b=RM07Qm:`3Q/jh0m/^m0?oGb@3of</0on?>0?o/e03olM<0oo_G0?oog@3o
omP00P3onM801P3il<`0dL6908Ya002GZf`0RJee05JAJhP00000303oool000X0oooo01@0;eNB04Eg
Z`14NZd0@GJ[02IBSP000000T8V^06mcXP1jTKT0L:S<0460[00mNJX0Ah>b03UmYP0gOj@0<WZQ03R1
Y00`Mj0005j@001KT`80?HF[00d0PL3?062V/P1;U:H0AHj[035kX00VLYL0@8^Q0028V000HWP003aI
001MN`0]NHd086j:0080000001P004E^000000000000?@0k0000001403D0G@1?05`0F01_08/0QGfa
08EgZP1jJil0L5jE07IRUP2OWld0^lSd0;k=o033e?l0a]Oo0<OHo`3<gol0eNgo0=oko`3Rool20>So
o`050>koo`3iool0oooo0?ool@3oomh00P3oonD0803oon/0oooa0?ooiP3oomP0oooB0?[lb`3bm/H0
ko_=0?oohP3oonX0oooS0?oof`3/o/l0ioK70=SY]P31fJ40[Kaf0:RiL`000000UMKV08k?`029bK40
EI=Y03N;P@0mSX40@Xmi00`D<P006Uh0001a03l000000000M0000P3DeoH09`3<j^h0]NSL06J/U`2b
inH0a^KQ0<_^dP2[dZl0MjEn08JmY011RG<0C8YV0000000009X0001j0000FP2bM7D0cHY]0<j<0030
P000HR/003h000140000@P000580001C0000A`0:05/0901V8RP0G1DI05hF5`1W7QX0JAlF06DJ4P1O
0000001P000SM@39in40`X]F001FT002003oo`060??oo`3Oj/`0001R05QZZP1UW;@000/00P000000
0`10NZ`0Dh4008nJ0002000000070::0Y`3O/Z/0Jdn606loJ`31RY00fJ>G0?[9/P030000000@05Af
?P000000ND5P06dbD@1E7480I2aC08AEN`1R<f00@0ho050OC`1J:5H0GBYE0440>`1N<F00YXR_0000
008007>M00h009fj002hc@00YLL0]kK;0:BB_02eUkX0]:370<NNYP3FY9l0^hbQ09=VS02VOIh0^IBa
0:f@]P80000001H09QDM0?ooo`3oo>l0000006N__`1jI6/0@hNB01h0;0000000QD=J0:f6Y`2//l`0
N9j60;J<UP38UGX0a8aB08a<00000000]GHo0:Y^001B7P00Zhh00`0000009`049GH0=U:M03E6T`19
EZ40001J0000EP1AR[l0Z;?=0<Jc_`3HY9L0ckk70;cLo`22Tm40Kgo308VSg02beo@0eOof0>GojP3W
o=P0kooR0?Oom03oonl0oooS0>Kle03:ikX0b^Ni0<WQ[@2ncXl0O8e10>o4]03oe<40om[70?oC`@3o
fLD0on7:0?oYb`3omm<0oooL0?[nb`020=o?W@050>3BW`3Vgk00a]>]09:EF`0cLDP0R@00000<0?oo
o`002P3oool0101WNZ/0EXBg05b?_P1?Q;D20000000308:S`P1j[M@0AX^V0080=GnJ00T08Fb=001@
N000DG@076V701ANQP0>EX@09FnD02agU`2EG1l00P2LUh/03`00F7P0:7F:02QfS00]NY00:7J>02Yh
S`0/NY00<GjB03j9V@0dP8d09gF1039nUP000000IV2C04a?R`020000000F03D0<`000000000006@0
L`1cEhH0NUb908Un[`1fL:L0M6NN081cY`1eIY`0THfo0;c>o02lcol0_=;o0<7Ho`2leOl0`M_o0<KR
o`3>kOl0do;o0=Keo`80f_ko02L0gooo0>?oo`3lool0oooo0?ooj`3oonl0oooo0?goo`3moo/0ooo]
0?ooh`3oomT0mok>0?GY]03ooL80oooL0?ooiP3ooml0oooF0>Oib@3@jK/0X<^Q09_3S`2dd9D0W[00
08oEg@29c//0PLJf06RXQP19TgP0EZBE0029LP1FO3l0QdI8000eLP0<2A00000007e//03GiOl00P3>
h^l02P2ok^40P;RY08_:f`2:_]X0YlSQ09YgN@000000[L6907^XOP0@5B020000000K0>??_@000<h0
0:^D08I0C02^K6<0gjR>0;=n=`2dOc00F1`c04`:701@3al0D@hL060O;01X9S<0LC0m06TW<@1]:S<0
MC<l07<^<P1U7Ad0H1PI068J6`000540?5NM001HP@3Z/G/0m/2O0080000000X0^NOV06e7LP000<d0
[L_n002R0000W@00j;no0000000ZNY`0<7^/0`0000001`0i0000=`000000002CJH`0g[2]0?oL_03o
jkl01@0000003@1`>Ed0GRM>06hgF`2;F7T0LT9[04DDA01864T0F2ME04/D?`1@04L0FRIC0:9jW@2l
ZLh00`0000008@00G6l006J0002i`@000000O7:/001iWP00N9l007fA0:IbN@2QIWH0/Yfe09:a_02e
^/L0000007PcA@2EGG40F2QD0?OjoP2/W[T0Zg:@0?2[^@3XZK/04deH09S>g`2TNYX0/WR60=f_/000
0000iKBR0>ZhX03/^id0i;B=0;9l>0020000000400004P2hT000iMVV0=ZlP`80000002L00bMf0000
O`0X>8P0@UBP000SMP0005H0002:07bLe@2a`^T0/mSS0:oPk02XcOL0Mho>06Af_02?YMd0_N;o0=;k
n`3Ronl0i?kM0>Woj03oonP0oooU0<[^c@3Gl/X0dNk70=3/`P30fjD0[/R<0>^n[03gc[T0om_70?oP
c`3og=00onKD0?oUaP3fh;X0mnFm0?o^b03ooo000P3ojlD00`3JcYP0bljF05^2002;000000`0oooo
000:0?ooo`0@0:>be`2KZM80V[?L08J]e@1ARKL08E^B0000Q@1BV:/0Fifi06>QaP1YY<T0KJG:07bV
d`0iKZ@0FiC107B[d@<000000140A8fW03EoW`0eOil0:WBI025]S@0TLXX08g2402AaO`0dOhh0?8JA
035lQP0UK9D09W6D02miVP00];`0000003HW4`020000000G00008@0Q02L0=RMX04<iN01SGIL0O7>X
08UgY02CRkX0NGJ_06AGTP1aI9`0PWZ_0;[@o`2kdol0_=Go0;cGo`2kf_l0^M_o0;[No`30iOl0a^So
0<SZo`3;kOl00P3>l_l08`3@n?l0dooo0=coo`3Kool0fOoo0>?oo`3hool0kooo0?ooo`3ooo/0oooV
0?oog@3oom80n>^d0?o_/@3oolT0ooo?0?ooc@3oolh0ho6m0:7?YP2gdYL0]M>K0;WGX@2O_7`0S=;M
07_3`01MY8d0HJJ;02MlM00oS7X0GiM^08MIM02ZWkh0i/32008000000200d_?o0<gdo`35k^/0aNk[
08>gU026`L40IJ7105>:`@1kW]40Ofb=06X0:`0n0000>Re400000036[/P000000>N`TP2E/Hh0065?
09MJE`3HYGh0nlnR0?gDZ@2KNbH0N5/004P03`1I4aX0HQl/06H0001A0000BP0006`T8`80000000T0
SVT007=0001D2@`0H0000000L0000;<000000?ofeP3bh]000`000000201aAg40i>7o0>Gko`3Pool0
0<@00>Vk/P00000000400P0000002@1SHWL0EFQo0<coo`000000]hnZ002GZ@3H`<<0ooGF0?ooh`04
0000000?07T0001]0000Li^k08I?K@20BFT0DaU1050JA01H9E80@11204dNC`1T>f/0SfbF0;NSa03o
ooD0^L[@0080:e<001<0_HRB0:1WOP2QIg/000000?:QT`2@EE/0MeF10=>eb@1=0000300002D0001=
0000ZV]a06`0001M0000G@0a08E0DP2?0000f@0000D0000000l0ZIEe07I4LP37T9P0000007T00024
0000X@000=bSP@3@WFP0[Whf09EM002dSP00Y94005<e002mW5T00`0000009P000640:C^;03=8UP00
07H0001Q0000D@13Kk<0U;WN0:oPk`2^foH0V[o/07BCdP1MLkX0Z]3f0;;Kn@32k?T0g?ob0>?ojP3Z
omh0f?o/0>ooiP3>jk`0a>S30=_hfP3Ij[X0Z<B605f;C@3dbk80nmNk0?oJ`03oflP0onSB0?odf@3o
oM/0onW40?OS_03hi;h0ooo[0P3ol<X00`3:f:<0RjIZ06>9002;000000`0oooo000:0?ooo`0D0000
001nVlL0082[002Ra`1eZLh0CXZe031/W`12RJT0B8Z`05fG`@1n/=P0HIW006^NbP11N:`0D8Vi05ZH
_`23_MT0Bi2K02]fP@0GIWL202MdRP0;001iUP00RJ<008bR04F>X011R9D008:K03f3W01TY:@09Taj
05jM^@11Q8H00P0000006P2jTU@000000000000002`0>`1L03T0K`0fBI@0HFb]0824^`2DS[`0THVi
07Ed[P1CAhH0MW:Y0:Fjj@2fdol0^=Go0;SGo`2jf_l0_]go0;cPo`2ihol0`^Oo0<SXo`33i?l0a^Oo
0P3=lOl07@3AnOl0d_oo0=7oo`3?ool0dOog0=[oo`3Sool0mOoo0?ooo`3oooP0oooZ0?oog`3oomH0
ooBl0?[W/03okKl0ooC60?okc03ln<@0f]fM0;gCUP35gjX0`]n]0:_BX@2A/gD0Q<cH04FET@00Q8X0
00190080000000P09F<g0:N/e`2`anh0emCQ0?oOiP3ggnD0a=KW09CBl@80T[nQ01/0NkNN09CCgP1f
_=T0082m001_]019DIP0000003i9>02nWkT0WgNF08U`W@21IY00a8ij09<000000000bIIj0>ViP@3o
ejP0oMVY0=VmN01;42T0I2a206dZ<P2BMYh0WHVa099VM`1c=T<00P000000202OKH00RVVB09AcUP16
0000Reic00031`00BI<0/Jk=0P0000020:ZMU`0>0000002^VlX0m<oU0?oal`3Wh/`0`kil04=lY`00
B7h0nmVc09MLK@31Qgd0Yj33079eYP0hB5D20000000G001ON`2jf^40Ym3?0=[ih`1T@WL0VG:<0:^6
VP1Y03L0E@0Z0<69HP1d?V80O4EW05/N@@1I7dH0F25;05<TE@1O@GT0MUjE08]bY02;SKH0T:W:0?oo
o@3Dn>L00P3oool04`35X[`0[G^C0940M`000000N@0009iG002[NI80T6nM08M2E037eol0e/oo0;^E
[P1lBFh0VP0007`0002AGX400000061^P000M9P01@0000003`1BOg`0NDEa09d000000000DR=60700
0023<@00[6X00<ZJ0031Xed0NU@00;>7001bE@00Q6L00:6200040000000U03eDX00cBiP003:30000
G@0066/001a/05B=`02Zf^T0/MWg0:C2l`1nU=<0Jgo508:[f`2Fb^T0Y]W]0;S/i@2bj=/0]>CL0;[X
k`2Wf<<0Xm>Z0=;de`3Jn]h0c^Rn09FdL`15Ga00oMNn0?OC]P3gdkL0omNn0?oSb@3okm00ooCB0?oY
aP3jhkl0ln6j0?;Z`P020=kR]0030;C8S`1FNSX0000008/00000303oool000X0oooo100000004000
FWl0?hNS029[T000IXl004md001FO@00HXP096Z>03MiY@00QK@006B:035gT`0TL7d0:7>003^5T01=
U9h204N@X00:03N1V@00Li4007F>002NX@1?TiD00:k007Nda@0009d0001K06RC/P@0000001T00@H0
0000AP0004/0H`2?03h0O@10DIT0@E6J06]h]`21Qkh0Mgji06aYY@2@X=@0Xko^0;3Co`2beOl0]=So
0;KJo`2jgOl0_]oo0;oRo`33i_l0b^[o0<cXo`30h?l0`nKo0080bo3o00P0d_[o0>Ooo`3Zool0bO[o
0<ooo`3Qool0h?oo0>coo`80oooo0180oooY0?oohP3oomT0ooo:0?of`P3oll@0ooW:0?ood03am<00
bmBD0:bnN02cdI`0[]JW09G3TP1HPD0007eY0000001SHIL3000000080:jUaP2hgol0/]ko0;OLl`3>
fnD0`=gW09_GiP1c^/@205b>GP0408K8c@2Kf>40PlGM076gfP8000000240_^Oo0;SL`P2o]=T0Y9:k
05M1P017<7<0O9350::Ja`000000ci5g0=:CI`3MXFl0kLVA0=2fJ`2:M`00OeZ108AKN`2GMIP0ZX^/
08][TP1/?5h0ODi^091RO`2MKhP0XgRC089LP`2<J8d0XY2j09ieR@000000ZLgD0000000>=Dd01@00
00001`3bZil0@9F]06eWK`1]SiL0n]2^0000002NI7@00P0000000`22BV@00000000000020000000F
001DW01n^;/0Xhnh06U_[`1bGi40FP2305L0F`2N09d0[ha/089>L01P:4l0GRE>06@_F@1Y=Eh0FRiP
08AUU@1fHI/0ShFh0:;2jP1_/<T0NUF70<Who`80hOoo00<0SJ[R07b?b`1G08d00P000000203BSP00
X7jD09imY`2Z/LP0c^_o0=cZo`2/TK`0QX:[0P0000001000a@00RINL06:SZ000>Al20000000B06D0
K@2Z0:`0S`3J07l0U@20Bg<0S59c0<FJY`0009/0XG^G0;63O038SET0XV`S0<ZTH@2NK`00W6T009Qa
8@1Z=`00I3d0100000009@00?X`0=UFP000^OP005VX0025d000HJ`00D9P0OjgG09W3k028Y]l0L8_<
0:6ik02[d_@0XmSW09cGh02Cd]P0U]GC0:;Lg02ci^P0/nGG0<;]e@31kMP0bo?O0;OQ_01SRdH0n]Fh
0?SD^03le[`0n]Nk0?_H_@3ohLD0onC70?oUaP3ohl<0nN6n0??U_@3Si;L00P3;dY/00`2W_hD00000
0000002;000000`0oooo000:0?ooo`D0000000l05eN:04F6Z`1=RKD0BhRd03QiY@0WK9L0@X>]076/
b@1EV[80BI2[0429XP0bOY80:WJ;03AoT@0/N8T00P0ULH@0200dOi<09g6?03Z1X@1<Sk<0AXRa04R;
[`1>Tjh0>H:?0`000000701A0000N00007Q>G@0007H0001I0000E@00HiX004R705UMW@0oCiP0Ae>J
06j1_`1VLk@0I5jK08BTfP2L_^d0ZM7m0;CKo`2eg?l0[]So0;3Jo`2fg_l0^mWo0<3Ko`36gOl0cnCo
0<OOo`3:iol20=7bo`0H0>Coo`3oool0ooo]0?koo`3Rool0n_oo0<_^o`3Rool0o?oo0?ooo`3oon40
oooS0?ooh@3oomD0ook=0?kjbP3lo/l0mOc<0>K`_@2``X00T:]W0:?>W@2<_Xl0KJ=a0P0000003@2b
PX/0000008j<G`000480]IZO08:W^P2LcNd0^>;o0:cSn02Ie^40SM3H076k_`1DX9@00P1DY:h03@0j
RZT0T=7P07_0g@1g_]L000000:;Lg01g]JX0L:J=00000025OkD0bJ2=0<^5G01eJ:@00`0000005@34
NUP0aW]:0<ZHE`33YeP0M5H008I]VP2AMj00XXN[091^U01T?f`0SVnF099aUP2KNI`0Y7nO09EZRP2G
Ki00YhZ/0::@^02PQjd000000?G``00400000005000Z00000000OC4h0957A01o00000P0000000`3o
o]<0o_oG09=EHP030000000J071>QP000000Rf><09=o[01iMJd0N7IX002iQ01PE900DWVl0340P`1e
JZL0aLGY09fIP`1K9Dd0HBiJ06PhI01[>fL0JSIO08aIN@2FKY@0LTAX0:B;W@000000080004ZCY@2[
goH209O<k00W076VdP1CSKh0F8_20000_@3me]P0c;H004MeY`2;S;<0000006NZ]`2SV^00HC5P07Ye
[P1GCI40000006Z:`01BOYL007n?0000001SGUh0=5nO08b4]@073000001[09nRe@2>M:80U7BM06f;
E0000000^ZK40=2aZP3X_8d0g[5o0:9c0038VUT0c9UM099]702;BP00GTL000@0000002D002Ed03AU
Z@0RC9H0001X000LKP00;h0006Za062>bP29]^D0PZCM06^Bd01dW]H0TLSS0:GMi02Mf=l0W]WM0:CN
h02[h^D0[N?O0:oTd`2]h/h0X][507fnYP1i]iD0DH=50??=[`3kf;/0omW00?gL_`3ngL00on;50?oW
b03oj<T0onO60??R^P3Oe:00f]ZV0080_;en00<0M99C000000000000R`00000<0?ooo`002P3oool6
0000000>04J7[P10P:X0D8jg05bL_P0dN9h07fJ?04Z8/`1=KP00;GV@03b5U@13RiP0BI2K03AnT`0N
Jh0203j7U`070020U000FGP006VC03f5XP2OKfT0Pd@K02`000040000000L02hkO@1LEX<000000000
B@0009h0001[001;RP00FXh0LVZP06e`[00a@Hh0EW2f05eYZP000000II7?09:ljP2Rd?/0/=co0;;L
o`2Zf?l0X]Kl0;K6lP2``O<0[l;l0<SDo`3DgOl0e>Co0=CZo`80h?Wo0P3oool09@3ooo`0oooo0?oo
o`3oool0a=Go0>?oo`3bool0oooo0?ookP3oon<0oooY0?oofP3kom80mooE0?Cnc`3Vm/H0fNZg09F`
K@20YVL0Q[V707N[N01OTU/0000004H0002Y000000000:Fo^`3Kon/0U;>G0000001`[M80Q<GK07[3
c`0iS8T0AXif046>P@1S/;000P1<WJX00`0aPZd000000;nCW0020000000R0>gAiP00000000000000
001GF9h0YK380;^_/P3idZ/0ooo>0?oY_03[^i40dY=V0<b>E@3GYf<0/YM40;RR001dHP00T7bX09b7
/01jG8P0KE:209V9]@2IPZ/0VH:/09EkY02DMI`0/8n]0;nL]02bSZT0Vh:Z06E2L`0007d000000;69
P`8009800280aXb=0<VDV`2dOHd0aJ700=;=m@3]ho80oo[V0?o`c03`mM00OcY006/U<P1X8B/0I1dY
06l[>`23LJP008Rd085VW02VNYX0V7AA099SQ027EgX0MD5U0000002:TL`0//OZ09^l]@1Q;5D0M41V
0751J`1Q<V00HbY@07XgC@1_9cH0RChi0P0000000`2OcN00XMGU08g4e00203YgHP0404TgD@35]mh0
0000029ZL0<0000000H0WhNb0:RKb0000000FR=A0:5_RP1nGh420000000H001]000G3R<0>BE30000
000b9ch0aL2k0083000J;0000000096Te`1SG:00ejV`0000001gHIL0nmBb0?oO]`3ojKl0fkMl0<JP
F`3Bd000`k0007eF002dUd/0R6/00P1;?`030000000T0017R`0ODIL0001D000]O`0>>hP0002g06VE
c`25/^80Q:oQ076Re`1ASL80O[kE09;@fP2IeM/0Zn;U09oJg`2ciNd0]NKX0=3mf`2fi[l0TLNQ062U
P`1?U6l0kLNT0>k7Z03cc[00o]g00?oP`P3oh<<0onC60?o[b`3ok<`0on[80?SX`P3Ufj/0b/N<0P2D
XEj>000000`0oooo000:0?ooo`P0000000`06Eb;03=hVP12RZ<0=GfK03n6Y00hP:40>7nQ03AmV@0o
Qi`0FIbO06VZ/`1KWjd202ihQ`0703AmR00iOh80;gA_0000002;PHl0M5Y408H00003000000030>:j
S00007/0FHc00080000001P0NigC001KZ0006g40S7>K08^2/@21RL40RlCX002RdP00Jk0006jg04V1
aP1h[^<0VLcf0:3BnP2Xeoh0Zlof0:VhhP2`]=d0Y[3N0;70l@3Bfol0e]go0=OTo`3Hjol20>[oo`80
oooo02D0oooi0?ool`3oonh0oooZ0=CYo`3Tool0k?oo0?ooo`3oooP0oooX0?ook@3hon<0l?oG0>cn
dP3Yml/0f>o00<;P[`2:[6/0Vk5[07n]M@1[WVT0EgL`0;VV^03:`;T0[JN:0000002/kMT0SX1`062`
_00FKYD09G^M04JG]P1T/L/0K[2U04bFQ@1c^[H0N/;30080M;Vf0P0000009@1[0000/03A0<;3h`38
bnP0^mOe09WAl@00000007bY001LV000TJX000000?oon03ooml0on770?GFY`3H]Gd0g;ah0;VKB@1c
L@00MF<0091o[028MJ@0N6BE09J9]P2SV/D0S7f^08en[P2>NjT0UH:^0:B>]P2_TK00WWNE07Q?M`1n
HHl0Ug^U09ZFE036[Y400P1YWM40803O]L80cZJe0=ZkfP3gl?l0jooo0>ooo`3dool0iNRn08a8CP1X
9cX0IQ`R070S801n<c40YF5L001UYP00S<00O6bX08ak/@2_V;T0`YJ<07a:KP000000CS`G05j2^@2?
_]h0GRUC06P`EP1T//H0HRQ<060_G01=4c/0MdI^0`000000101kBP00i<2o0?oYi03oi]P20<NaPP0A
00000025LEP0]Y2^0<JFYP2TR[H0_ZG808UdQ027P9`0X9jk0000001^EH/0G`000:Z</@1jFe/0^ZQc
0016000P23h00P000000101TD7@000000000000007d20000000>07ZeaP2WeKl0000009RKcP3Fck00
i^;90000d03`aI80d/J507aW003AeY`0_JaR09Un:`2/TdP205hj00@0000002<0001R0000G@0WAI@0
9DRF0000001IS<D0L:KE07^_g01`ZMD0M;3D06b^c01m`<`0O/7:0873c@29b]@0V=CP0<kik03]on00
VLbN06FSN@1ATfX0iLJI0>oAZP3gg;P0nn2n0?oUa03oi<D0on?50?WP_03oiL@0onS60?gWa03`i;T0
iN6b0<_AV@02075f:Xh00000303oool000X0oooo2@0000002`0dNIl0BY2Y0468X`0iPY/0<WbG03f5
XP00H7P0D9F[05FIZ01IWJH0NYEn0080MhEE02L0HYF102EC;`000000000005alZ@1RPi`000P[0<BG
L@00000002Y2000e;P00^KT0000003Ig]`00ZM`0082h000RM`0mJK4002j2001V[000Ym@00;gI003C
g@000;X0001L001e^`1^YMh0U/[d0:KIo02Xe_/0S:SM09JSe@2Y[=P0XJcN0<;Fo`3<g?l0c]co0<oQ
o`3Bhol00P3Gj?l09`3jool0oooo0?oomP3ooo00oooY0?ooo`3JmOl0h_oo0>_oo`3dool0mOoo0>co
k03Yonl0i_o^0>3oiP3Qn]D0f_760<CW^P2/eJH0T:aZ09neL01hWf00KYaQ00000000MZ<0^NW[076P
S`0n0000N00007Jl/`1//jL0Gjo105ZY]P1>WZl0P;nh09;8Z`00/`00RlkF0;;2``020000000W07>1
S@1<K4L0`0000=Koo`2mjOl0Y<K/096bg@000000oooo00000000E8`0001S0000Z`3on?D0h]7L0>WM
cP3oolT0l>>/0=oAS`35/V@0T8hl06eM001iKj@0QG^^08Z3]@2LUlD0Uhnn08EfZ02>P[80RWn`09>>
_`2SV<@0SgRS07]OSP2AMZ40T8:d099[:@2YZiP0lLVW0080KiG70280olkF0=c;jP3oool0j]oV0>;g
o`3:ool0Q<SL0;CL^`26EG<0ITEd09^3[@2kWkh0l?oo0<fIVP008W<008_408j0]P25NK<0Y:[G096?
aP2LQid0a;Ah07e=M01eAFd0GB]H04@0=@1U:DX0IBM7050B=@1jDGh0000006@kK@000000YgaA0P00
00000`3ob[d0om340?NcY0020000000:09:V``000000fJfm0000002aOGX0cLoS0=WJ000510@0:QXR
09YLK`80000000<0CP0006T00024Q/000`0000005@1@@5H0J00S07Q@P`2CXMH0fmWo0000001B06D0
@db:08QKR@23HUd0001S0:nO00000<T0002d0000X03E^h<0YYE70<Z/J@2lX5P0MfD00:2LC@02065>
00H000000240002;02]8U`0QAI@09VZR0465]@1MW/T0H:?604^F[`1:V:/0AYNT04^I[P1EXk80EZ>a
04ZD[03>f]P0k_oo03N1H`00XP00i]f]0>_FZ@3^eJ/0m=Vb0?SK^@3mhL00onC50?kS`@3oi/@0o^?1
0?SR_03ghK/0hm^Y0<_CW02a`hP0T000000<0?ooo`002P3oool;0000000909S>d01<TZH0=7fE03In
U`0nQIl0C92]002Q_`1?T;<0[=?80080LZ>C00X0C6/0000000000000NWNM05miY026/<@0XLoD09S0
c026/ll0CHN60P0000006`1;JZ00001h001a/`00HZ<000QG0018UP1@L;D003N8001ZX000U/<00:g9
003fiP2H_m<0042?06FLf@2=`Nl0Ym_l09:hi`1hTm00RiW@09nSd`2b`o`0_m_o0<;Ko`35fol0bM_o
0<_Ko`020<oKo`050>Ooo`3oool0oooo0?ook@3oool00P3Nool0803Rool0j_oo0>koo`3Oood0f?o^
0=[ol@3Konl0f_kO0=_dc@2oi[h0YmN^00000028[Fl0Qj=N07NYMP1hOk40GHC4001>P000Mh/0DYZ3
06:]XP0bNfD0FJ2D07No`@1AXkH0AIVZ03fCW`0eS9<0BIbV042A[01;SKD0UP000P0072009`27/m40
Wm^k09f2002^a;D0Qkg<09>^e`14000000000?ooo`1I1`00bGeZ07UXV`2i/=H0003<0=cKi@3oon@0
oooM0?G]_03TfYh0YJQP07in002VKBD0Mg:Y08^7^@2<Rkh0SHc0089k[`24MjT0V8^j0:JLaP2RVLD0
THRh07UZW`2<OJh0WH^f09b?_@3H^/X0Y:kI0?W?g00209BmgP0W0=>kf@3fhnl0oooo0?ob/@2^YVP0
PJbJ05nY[0000000R6jN07mVU`2UTKX0]jC90;^S`@2SQZT0SU5S0026`P2PU<D0V9350::[fP2B/>80
8QXQ03h_?`1c@V/0G2M@03H0:@1I7T@0HRE705`M?`2GEfL0R5=b0000000h04X0c<Nm0<3C[@000000
cNoT0>kGdP0006l0001K0080Q@1H01H0V@2?0<NXa@36Z<80^hJA0<jV]P3WdP00hJbG08U<001bAfD0
000003@09@3B08d0m/6X0;BaT@000000Si;70:Eb@P1105@0000003aj@@000000PiC=0P0000003`2S
09`0000008iYVP0X6d/0001X091^000003d0002S0>_4]@3[c9d0a:YQ0;B3?P2iVU00V8/h07ak9`02
06>100H000000240001B0294TP0[Dih004R=0000P@0VLi`0EJ2f06^a`@1i^M80EYc007Vid`1//[l0
MKZj07^n]P3]l?l0I:jR05fUT03A^gl0jm6S0??C[`3fdk@0lM2/0?;A[@3de:l0oN2n0?oWa@3ok/d0
o^?10?GN^03`hKD0g=RR0<C9S02FZfX0T000000<0?ooo`002P3oool?000000050468X00DGX80:FfE
04j</`10OZX00P2RXHP02@0E7P00000005RCS@000000R[_L06fTa`20^]D0FY>O04]oL`030000000K
04e4M000000003f<001=UP005fP003b;04]//`00000008Jg001FR000^lh00;C:07nWc`1?MKd006jc
08Bbi`2Oa?00TJgR07bOfP23WmL0VK3P0:_Co`2`eOl0]=Go0;OFo`2heol0_MOo0080`]Ko0P3[ool0
0`3XooL0i_oo0>Coo`030>7oo`090>Ooo`3/ooX0h?oV0=[ol@3Koo@0f_oO0=WecP2hhl00YM2T0080
00000100OjQ[07jUI@1eYg<0PZoI03V0XP1;V:P0@iJF04NHU@11Thh0=8N?02AjWP0cRIT0A9N[03>:
W`00c00003d00`000000101c0000E@0005D0001f00050000000Q05T000000000[01Z0;<000240000
d[[>0<k0gP000000lm[B0?okcP3oolD0mNbf0=OHV`1/RDD0QHdl09n30026PkL0S8Jh08j7^@24O;00
NGB[08N1]@2KU<<0W9G309RB`P1oLjL0SHNj09^Ha`2KT/40UXVh09>6]`000000^YR[0080000002L0
N7:/03N=X`3ohMh0]hQk0;EnI@2UM5H0UhZj08ak[@1nHiH0UWJN0;6I_02`V;d0XXB[08IVT`25EGL0
08;1002Rd0000000Fc9;081JM`2INIP0TVnC091`X@1<0400D@1<06DaF`1/@W00R5Ul08QBLP27DG80
QE1a07Jhc`1IX9l0H9Ui0=ooo`3<no`0cmcT0;2N^@0001h00P1hFYl0602aQjD0_hnQ0<:EY`3<WJT0
bYJN0=NY[P3IZJL0Y@000:oB^@0K02l0L01m0?oPg@00[h@0b0000000000:3a808S0c0000001k?`00
A`000:j;W@0K0000UDY00:YRDP80000000d0TV>5081SS`0005h0002U0>Vk003Q]YX0l]g90>?GWP2i
Y5T0aIiK0:Z@@02BSC/000000080WHI002L0NP00000000000000000001d0000B00009@000000O`0a
HJD0@g^e02Y^X`00JI`0EJ2h001oX029a=h0MkSD0830e`26alX0X][L00000000H3/0jLFL0>G:VP3K
a8`0bIaX0=R]O`3W`9L0kl^V0?;A[03_dJT0mM^e0?_R_P3ojLL0ong;0?[[a@3_ik`0e<nF0;jlO02:
UDl0T000000<0?ooo`002P3ooolB00000003025IR`1]LIH0000000D0000000@0@h:]01eTSP1[X<00
ULG90P0000007@1^0000@00004l=:0000000001f0017U@00;7h0021d04UX/01/PL4006j`0000U000
LZ`007>^06J>c01@MKd0056N002Nf@2;]nT0P:SP08B]i01mZ>40TL;a09c=nP2Qcod0Y]3l0:SAoP2Y
d_l0[=?o0080`o7o0P3@ool09@3>ool0eOoo0>3oo`3Mool0g_oo0>Coo`3dool0looO0>CoiP3Noo40
fooX0=WfcP2lhkh0V/^T0:NnP`2P]780000006jPJ@1IU6D0000008_:hP1o`]<0Lk_407>k_@1GUGT0
CIB307Fga@1TW`00B7:/07fD]@2GYjH0YKj50000002AHH00ZGbC0;@0002R00000P1M000010000`P0
001b06e@P`1hT[P20000000503006P2G07`0onC;0=40001f00000P000000603og/T0onG;0?oX^P3e
gZP0imNL0<OATP1mUdl0Pk^O09BU001AF000SX2_0927^029PK@0RhFh08R8_02@Sl80Ti32092;_@29
P[D0SXZm09>DaP2=Q[X0Rgja09>7^08000000P37W:<09`1jMYX0aK[?0;BG]02eT:L0/XNB07<0001Q
0000NfBH07]MS`2NNYh0/hVS0:EiU`2>Gh40P5J00:>0XP36XKL0[GnJ099OO@2DL9T0[9Fn07=>E01P
ET80GReK04lPD01M>6h0NEfB085eZP1iJYT0fMGo0>[eo`3OhOl0]<GU09JNd02S/<l0cM_T0;o;f@2G
0000000006R5]@020000dP0?0000[@2fT[40a9:O0=>X]03?WJ@0bI:H0<fKX`1j0000FP0005/0VP2E
0<L00:>A0<JDY03?WZT0_h9o00@0000001@0U@000:Y]N`0000002@030000001S0780QFfX07N<`02b
]^D0MdI/0<6^[03Lc:d0f[Mo0?cgcP3@c8d0e<1n0<V`J02^XU<0TIA3081[5@80_M>K02L009/00000
00000000?@0000@0000l01l0G`1804h0000PDYT095bM0000O@1TR/<0IJ?9001:M`00O:L0MK?D0000
g01n_l`0Oko50=:KM`3O/XX0h[b=0=g1R`3Ydj<0jL^O0>>mTP3U`9@0klnW0?3D[03afJl0m=nf0?KP
^@3jhkl0nnO30?OY`P3/hkD0d<^?0:n_K014HQ`0T000000<0?ooo`002P3ooolB0000000709n@Z01K
FH/00000000000000P<0000000e5>P020000000R02E_T00MI8<000000000001Z@600FP0005@0002^
10d0O@000000IP00@i806DJF0000M000AiD006fc0769aP1>LKH0002@001;V000K[L006F`001AW`00
Nkl0KjoS066Lf@1MTm@0L:CO07fcj02:`_00UL_e09g>m`2Eb?@0Ul_f09c@n080YM[g0200[nGf0;[_
n@36oOl0e?oo0=goo`3Hool0g?oo0?Koo`3oool0oooT0=kojP3Jon/0fOSC0=S^_`2@cK80W/nY0:c@
X02E_XX0AH=C05:<F`1jZW<0002k09C>j`2Ed>@0UM?N07^/T010N5X0Lj6k0<Wmo`21WD00<5`005d0
0080000000D0CP0009YkY@39_nP0a/KZ0<l0000207X000040000N00006d0TG2F0:j5X08000000240
7e5W09L0003d0000VP0006d0001b0000o`000?oD`03oh/X0on:l0?oM[@3HcY00/kmj04l0002]h=00
Um770<6J002:SL40TY?609F@`02FTL40S8g008nCaP2CULL0Ti31096>`02FTL80ShVk085j/02;P[D0
UXk00000000006X00P36]8P09`2h[jd0ZJ_B002Yf@2aZmL0]ZOD0<bhhP2`WZl0V8=E07mZWP2CNjP0
UgJN08INR02:HHP0ZXNY06En002YPZ40TfB509M[SP000000@ci@0000JP1J=Vd0GcQ/05P`I@23K9l0
Sgn_096Td000PkH006B>07BPgP2GXlh0000006MBS@2R09H0/WR108UYU00i<D80PVZO07EG00020000
P@0@0000I02WUL00aj_90;fDZP2`PYL0`XZD0<:;UP2HNIl0SeQi091JN`2_O9H0^hJI0<BAX031RiP0
^Gb60:e[LP<0000001@0cZJm0:ijT`2>EWP0;`000600002cX=@0HFjS05F;^`00]>0007RJ0030f03C
il`0gmn`0>_eaP3Jf9/0e/V60<R[H`2g_7@0W9Q909F0;080TJ]Z0P000000901700002`0003L03`1>
0000000008<0F@00000004nE0:nkd00007l005aX001BF@00D1X0002;0000001`?4l0`hMP0<N@H`3J
[Wl0g;N40=NkPP3O`hh0ilFI0>k<Y@3WaiT0jm2R0>cCYP3^eJT0lMZ`0?CK]03fgKP0mn6l0??T^P3Y
gZh0f<nG0:j]JI400000303oool000X0oooo4P0000001`00064003e9091>?`2@CSl005N70000000U
8b/00`0000001@1D@6H0000006]OP`1WXkd007]^00<0000001T000@e02E9U`0gGJP043^=000LL@00
BYP0=VVb0560a00dKKD075VW00mDX@00FJL0042B01aPZ017T//0G9gH05VDe01RVmT0LjgT08>ok@2?
b_<0U/ge08?0k@25`^h0V=7e0080UmCb00h0XMob0:gVoP2ik?l0b?Wo0=Coo`3@ool0a?So0>Goo`3o
ooP0oooY0=Wok@3Gn]/0e_C>0=G^`0<0000001H0H9QV03ER901gXVL0049W0000:02@b>/0TL_T07^/
Y@1PUWT0055Q08VJc`35cOl0]YBa02`0000[@1h0000007h0002]0000gOgo0=Kao`3@kOl0/]g60P00
00009@2k0:X0001X0000Y`33W[@0000008J[P02J_K40V@000<N6O@2[0000OP000740H`3W0:40lkRI
0?nnU`3oeJ/0n^2`0=GGV`2GVT/0c_CN0<cfj03;mQd0Ug@008B9_P2CV//0PHFk08^<`02=S/80S934
08jAa020P;L0RHVn09J?`02;Ok40Q7fc096?`@2>RKd0100000003@2ESl40THVk001RY02`Ym<0a[g_
0=kDo`2i]N<0JE^F07]e[`2:OK40QW6S08Q_X@2RS;H00P0000000`1iG@004`80000000020000000=
0000]P1S@7L0?A=;03l0002/Xll0YIk90<kom@2ENJL0e^7i0=nl_00O0000b/3E0?00000200000004
08j6^`3IXhl0000004DeMP80002E01X0001G05al/P0@3^D0HfRZ0;f=V@34S9@0^h>@0:2Ia`1W09P0
<P1A0:YmWP2[N9@0/GV<0;1dP@2[K7P0X6Ii0:MgN02bTI0000000000S@1V:e<0Sej605HWH02PKi80
jNGo08nhQ0<0000000X0DXS106fK]02G^kX0go?80=oGV`3Zf:80`L>009fVFP2ATD80`K5X0P000000
1@2@O`0000000480000_0000=@0000<0000000P0LDQf0:5WNP19RjL008^60<ZDLP00WV40YF8j0:mi
AP80000001@0UGV?0<nRKP3C[7@0eK9j0=JhO`3L^hH0h[b?0>_9X03Yd:00kMJY0?3I[P3afJl0l]Za
0?CM]@3fg;L0lmbe0>kN/@3VfjT0dlbB0;2aKI400000303oool000X0oooo4@0000000`000440001R
03Y:J@0207U7C@0:065eW`001`/000000000001<H940Zj>k07YaU`009eh0N:_908Bm]PD0000001P0
04fH04EU[@11Hj`002j1000OM000B9L0=7Jk02A_]00HGjP07V6[01]T[000GJP004jJ01U_[@0_O;`0
Bi3?04V:c01]Zn40Okk/08_9l@2?cO<0T<kc08g<l@2CdO<208oBk`0O09OFl`2Ufod0/^?o0;o^o`3;
o?l0^noo0:7Qo`2Vi?X0`_OQ0;gaj`35mnX0a_?N0<O^d037j;`0>DHg082gRP1RUEh0Ii]U06Ij;`1>
Pd`00000001gZ@000>D0N[75062KV@15QFd0H39@06M=NP1i0000;CDZ06<0N@02000000060?Soo`3S
ool0f_oo0=Koo`3Lool000000P2PJ@000`1g;P00G@0006L000030000000Q09H0002aIf<0UdM40000
001B04T0S@280>cSe@2mSe80/WDY0;fFB@3Fe9D0_KYh0<O6PP2fWTd0`mQA09EV002<P000VJCD096M
c`1iQKh0Q8k308R>``2IW/l0QXZn07Ui/P24PKL0PWnf089i[P2GTl@0Ui_=08R8_P000000:@d_0080
000000h0RHJl08Mn/`2:OK40WI_=0<C3o@3Tgol0^:V_089cZ@22OKD0OGVd085g/02=O[80Whnm07QK
S@<0000000@00:>n003Kk`1@7D/0HcY^0P000000401=000000000000003oooP0oN[/0=:Y^`2OOJD0
IfRV01T@4`1[Zk/0OJh00700001a0000^GAE0;mnJ@0000020;AgOP030>>/Y03onM<0@PT000800000
00`0fJjc0>C3a@3>_=T0[@3H07<0M`2VM980YW2<0:9[Q@2XL880QFBB0;anQ02fWg`30000000706lg
H@1nCGX0M4Ql0:eiT@2m/8P0aJii04eML0030000000907^Ze031k>P0g?_P0>kjc`3Cej`0/<F<08jN
D@1fPC00^/:10080I5d002H0d[Qm0000000e0000000006D0M@000000D`1A06M6O`2dSZl0dKcX0>7?
l`3;Z/00aIeh002:NP3?ZZ@0XXaC09J5>`3Ob;40hKRB0>70SP3G]7d0dJed0=BeO03J/X00g[B60>S6
V@3Wd9h0jM>S0?7P]@3chKP0ln2g0?KS_03fh[/0k^2c0>SP/@3Og:L0emBL09JO09400000303oool0
00X0oooo4@0000000`2bZ/T008jd0021WP02002=S0<0000000L0001C02UMU@1dXl`0QJC=05EDR@00
I9D008^100D0000001P004jH04UTZ`18IJ`043>4000NL`00@I8007Jk03f5``0^N;X04URS01iX[P0O
J[009GBd001d]P00JJ`02efS029_]014SLX0IJ_M0833k025b>h0Rlk_08c?l02:cO0208[;l00C093=
l`2Bbo<0YMWo0;KUo`2mk?l0X=gk08?=h`25d>H0VMc[0:KUk02YinP0ZnOR0:_QcP2[f[D0O[V@06RJ
H@1VVVD0?8AS031`A00206f[_`0B00000000Q9P0MeAf079BN@1iH8X0KeN203h0002CB400:RTV0000
003oo`00oooo0=ooo`26`o@0[mco0<cgo`3Zool0h?oc0P0000001`1803l0B00a04/06@0l?H80Ni_F
0023`@0n82000P000000701d;CP0C01f0=[oo`3oool0noo]0?oM^`3T^`00_ZYT0:J4=`2oVe@0W90m
00000017H:`0LGd009BQd`1kR<00PHo507V6_`20Q[d0Ri35081j[`21O;80PWjd0864^`28Rl00Vj3A
09BKcP23RL4200000080PH2h02L0PWfd08Al/`000000002P07b:d@2LS[P0U78m08b2]P2<QK/0QH2h
085j/`2?PKD0Sgja06U9OP2nV8X0000009Y^T02AGG/0JSAJ0750JP1V@7@0F3Yd085OSP2oZ/`0H31I
0:f9U03:l_L000000<g2jP3Qg?l0b^7o09]h002OS000jOoo0?l0002P0000bKJM0=ZSR`3U/ZT00P3G
[[H0103of=<0ooCN04l0000N>A`20000000D0000D`000:L0A01;09l0RP2PKXh000000;Z4S02QNYD0
O5nC0:1`R@1a:cT0A`0006l0002>?cP0RT]Q07PnH01a?Vd0[XV90=??W02D00020000000;001UZ01E
Q[h0UlCS09kHf02Qf/h0ZM[309[<Y@28ZV/0TJ]U0000002P^gT00P1eP0009P3:Y6X0900008X0002G
JX/0O7B_02P0D`1R<F80OEJ50<>GZ`3QdO@0mOoo0:j`j01VDX`0001F001iY039YH@0WgDb0:^EL`33
UfH0jLfN0=g2S03@/gL0e;Mm0=fkR03G/7d0fkn90>;>V@3Td9`0jmRY0?;S^@3dikh0m^_40?K^a`3]
i;L0i^2`0=_HXP3BcYD0A600T@00000<0?ooo`002P3oool00`1aEgX000000000000>00000003040>
:`1gFgh0?0000080[:n4100000002@0007@0BWb`05Ym]01MLJP008Jg0000002hVZ`00;o20000:`02
0000000H0000N@0oGjL0CFF[01/gQ`007g<003Z<001c^P00Tlh0BY3;035i_004EY`04F6V01AQZ00I
JJ/007^d001RU000EXT06W:[02Af]P1=VLh0K[KR07>ki01f`^40M/7R0P1^]n804P1c^ND0M;GT08S4
k`2JdO`0T]WK09KKh02Jg^@0Wn7Y09oPkP2FfnT0UmcU09KJe02HdkL0PKJ805JBI01[UEP05fYE04><
K@L0000000h0400002h0001T0000VgR301/E5`3akM@0o?oD0;cW_00lS8l0<W:Y08Rci`3Do_l0n_oo
0=cdd@<0000001<0:@1Y03L0;`1HIj@0Egno001^[0000000^M7E0:ZZYP2gj_@0003R0;koo`35ool0
cOoo0>_ahP3oklh0jL`009eL3@2/NBl0PGl[00800000014008A709NVeP29U/X0OXNo06Ue/@1aN;<0
OHBl07El]@1nOkL0QXVo08^Cb02<U//0Si[>092Ld027TlX0Oh[308bK_P0207ao^P060822^P25PkX0
Ph:j07aj]000C@00NGNb0P0000007`2;Qkh0Pgng07E]Z@1gJjD0KEbF06Q>Q@27L:<0000007YEQ@1i
B700NTM]07Y>N@1cAg40ICib08YfX03?d^L0Cb<_081H8P000000^;WN0<Jjj@3onol0oooo0;WZo`2_
e_<0hOOo0000002bYlh0_;n90=kB_03Vd=l00P3VdoD06P3okOl0ono]0?o0Y0082``01Q8K0000002k
Y840>P00089<L@2LI880UfF90000002j0800`XZ;0:9/P@1_Fi/0CP0008E2F02eLVd0900d0640;`1_
<4/0K^=[0=BSL00G:RX008/0100000002@1[[<X0=8RG06>^]`1o`[L0S<NW09BnR0000000]]o607nU
IP0208>V000U09Il002O0000_P000<jLXP21KZ807`0o09QVR@2KLi/0d9nS0>gNjP3oool0L38l09EF
>03Hm_L0V[CP0>C[l@3oool00000099V8`3J^h@0gKj90=JgOP3I`HP0hlFC0>G:V03G`HL0i=6M0>;=
V@3TcYX0k=RZ0?;P]P3hk<@0mN[20>kU^03Xh[80e/fC0;VfLP2B000000`0oooo000:0?ooo`0307^2
/01^0000M@0000H0000000<0NjS;018oB`0000001P0000001P2NMhH0V`000580001B0000PF=g0=:Q
PP<000000280B3=L08fI_`00YlP00:fi0000003Bf?80_=3P0000000H63P000000000A00009l0BUfT
02DlR@009GH003Z<03Ub^@1CU<l0GjCI056Id@0lQl@07fn_001DV@00L:l0:7^d056S]`1k_ll00;_`
07B/oP0=?iH0A9C;05^Ze`1EZlX0DZ?>0P1EX=D04@1AWM<0Ej7F06FYg@1n_N/0SMGF09CJg02el?00
Z>O]0:CTk`2Kg^T0Rm;K08S<_P1TVfP0>9F]05BJS`1GXh/0DYj500L0000000l07`00040000000000
00000:nfM`000000ck400940001SWWd0gkc:051NY020WMH0^KSN0<KCa`2FR8d00P000380100003@0
2SA[000000001@030000000P002C^000Uk4000000000Q01RZ]00L:?M0000002E`LX00860002N001V
J3T0U6hI075c7@0000000:BN07NBF@2@Xm@0TYoA08ZAaP1mPKT0M7fg07V5_P1aPK/0Lh>m08NCb@29
U//0RIS=08JDb`27UL/0PXo707An^@2QfNT206mi]P0N07b1^`1lO;D00017086SdP1eMK40Ngfh07n7
`@1gO;P0PhFn07il]@1^Ij@0MfjY06EMW01/H9d0Pg6V07][X`1jIih0O5N707MAP01mCWH0HRI70<R`
a03HjMl0000004i_S03ThNP0ck360<BW`@2KNjD0om;I0P0000001`2Oan`0000000000037/K80Y=;3
0:O9iP36e?l00P3Wj_l06`3_hol0jlkI0=6IU000?d<06aa105P000000000I00008]HO02HMjD0TfZF
0000GP000000VXIY045[O000000001iM06M6O`2ZS:T0f[c40<BP/`2ZOYP0Zjmj0;o6[P3?lM0002T0
0:ikU`040000000808C3dP2Nf]<0T]7009G?]02@aZ<0000004iSAP00IRl204MQ0009095i002hRIh0
U5MZ08Q6E@0jDfH0000j06a=R02?GXD0d9nP0080000001X0ESAN0?o7]03LWWl0clcj001fZ`3Ujoh0
f;FJ081M003:/W80gkj90=BiOP3I`HP0g[f90>7>V@3GaX`0i]JS0>SFY@3ZeZL0j=FS0>_IZ@3ciKX0
l^Jk0>oU^03]hkH0i=VV09ZLER@0000000<0QfLT000000000000J`00000<0?ooo`002P3ooolB0000
00080:bO^`2jWJh000000000002aS9H0=`0000000012FC43000000030;?;e`2Hb/00000000<00000
01X0K@0000000000000002i^001>T`0`@H`002Yh02E8U`13OL00F9SB06FYg01MXmT0E9WB04bCcP0j
P<407Ff^001MX`15Tl80Gj350;3Io`3=mOl0X=Co000]O000Q:l00:WA07Jjj080KK3R0100IjON072[
hP1[ZMd0T<WV0:[Sj`36o?D0a_ch0;K`l`2Yinl0TMKX08;:e`1`[I/0QkZC03nJXP1CYJ/0;giV0P00
00001P2NS[/0000005ADU@0U0000000006P00080000000d0on2m0000001lREL0[9WA0000001Q0000
]KfU0:f<Y01cRLL0Q97<0000`P31X;P000000080002402L000220<Z6K02kLV<0]jBd0=;1a@3dc[H0
n/^R001bJ000ZYT00=c50<Oag`29b<h0>7Za03Ac^@1LSLl0HiWE06>Qd`1NSg`0T7XT07>3<P000000
ZMgB08>Kc`1^R<40Kh>l06Ue/@1kPKX0P8_2086Fb`1gSlL0JHBo07VCbP27W=40PiK<08NEc02JY=D0
SYO<06Yd/@1VJJL00P1fNK@05P1/KJX0JfbZ0000Q@1V[LL0S8o608nDbP23SLH0LGVg07Qm^@1/KZ`0
If>R07Mb[P1XI:@0F5NI06mTX@1eLJd0IEbK069=R01fGI<0JdUn07m=KP2OKVH20000000?00PI1@2]
RZT0U7FN06lmIP29M:L0Ig>`00l?U02>0000O00006h0003=UYL0`hZ:0;YnO000JY0008Zj0080V[cZ
00@0_m;g07]EO`0Z0000F`000P0000004@1a0000T5Ic0:9WO@2RK8H0001d06@0M`28V7@0Chin0=?O
o`00I@0000000018P`2Ua/X0MI^h07nCa02oX;P0eJZd0080000000<0a92O0;:;[@0000000P000000
2@3=kP00Z^;B04Ma0023b<D0W=O?0<Wch02oc@00U8000:6n00020820=0090<:[KP2aRZX0]8^R0>Zn
YP00Vk80001908QbZ@2]S[H0`Y>V0080000001X0LE1Z0?JcT`000000_;c_0000002cL5<0jMGB0;nV
I`39[g40h;f:0;NMF@3E^Gl0g;j70=[;T@3Eb8`0h=RQ0>KP/03[gk40kMj_0>WFY@3]fZ`0k]j`0>[J
Z`3PfjL0c]BM06j5@I800000303oool000X0oooo4P0000001P2`^]d0002S05i8L`1NB7<0ZHZJ0012
K`80000000<0Z8^T0>c7c@0000000`0000007@0K3@d0000009T0003U0000000006L0002j]KH00000
0>S?l`00<G`09eZS052:b@1RX]T0JZWM06:TfP1TY=/0IJ7J05FHd`0kPL808VZ`01MLY`12P;`0ZlOo
0<[[o`3Dool0f_oo07F_h@00HI/006VW0080CiSB00h0L:_R07Z_iP00S[l0Q/CT0:?Ok000knd0Xn?U
09?Hh000N7l005MR08W=h02Pf]P0^>O@04ZAL0<0000000L0WHjk09j?^`00000000000280000>0000
V@000080000000`0h=f`07bcV029Y:T0SL7g0039o`00mol0X<c^0;>M000YRJ<0001i0000YP1WEI<5
0000000U0=fZY`3DXZH0dZne00@:403OZhT0dYAS0000002fh;`0b?3C0:kEe`1lXML0BEjX072Bd@1j
YMd0Pj_J072LdP1jPB`0XLSG07NaTP3Mh[D0000007F<a01TOKP0FVn]06Ym^01iRl<0R:;E08FNdP1d
SLH0IX:m07:9``1cR<80N8S108RAa`29Rl00NX2j075_ZP0207Mh/`0M07=d/01dN[H0LWbi08JAb027
TLP0R9?;08:;a@1gO[/0LgJc06MXZ01SHZ<0LG6_06a/ZP1HFYh0Kfn^06m`[`17AXd0FE:E06=NWP1O
CXX000000:@0/@39[K@000000:QoV@1M@@00DdZ1092G]P00Wk/00P0000002014IJP0FU6906ILUP2O
000000000>2k``3V^[D0diZ70P00QKX06P0l01d0M`1A08h0L`2PJH80W5EN09P0002A0000^@000;Ag
OP2^M7l0002K07Ek=P2J]mH0l=7S0<Jdf02dVKH000000010IP37_nP0W@000=Nje@2Q000000000;bW
a`3AZ;<0i;oC0P0000002`30gk@0RV400;3J002cd@00P0000:[I`P38lM/0_^_F0=Soo`000000YM>]
0080_Kj800d005H00<B]d02YW000;dl00=ZnR`1Y?W80WXo209=n/P2NNZH0XfYj0;YoO@3>UH@0Z79:
0080000001D0^X>70=RSPP32SEh000000<V]LP3N]8H0cjic0<b/K`3JaXh0dlF80=C7RP3Gc980j>2`
0>gS]P3_hkP0k]nb0>gFZ@3_f:h0j=ZZ0=SGX@2DZ6D07@000000103NgKl000@60000002OZfh80000
000308a5@@29@P00K`0006L00000303oool000X0oooo3@0000001`2k[<80WIo200000013I9/0Mhfi
0:W1i02M`]l00P0003X0202HQi@0T59B099>?P1gE@00TYNo0<?6hP3ij/X0e/Re0`000000702^]mX0
//;S0;2jg02`Y;l0`ZZb0;2TSP000000oooo0;V3F@000000041g001aY00lR;`0FH[C06JMf@1f[^80
E9cB042:a@0]NKT04EnV02EX/01iZ=/0U/[V09OPj02PhOD0TlW^002Fd`000:<2001=S`0=001m^000
T<H006FB002_c@2?en800<kH0033c029bkh00:B50<O^c`2MeKP0DY9X02ajGP070000000402@0000S
0000?P000:<00080000000`0TKJ4066=a`2D]]40X8:E0<2PP0000000V`000=gMZ@3?_JH007NJ0000
P02FL9H6000000040?Jo/`2e`Jd0TJNl00TI9P80000001h0[=R`0:O@`02G_MH0N93>05aEVP1nRlH0
Tk3T0:6_h02=WmP0000007l0S02/bI40h^>`07Ab0020T<H0PI;806Ik]P1QNKD0LXg408FRe@2:X]D0
Q9W?07B:``1[P;/0MHBn06ei]@1`N[L0NX2i07R2_@1FH:8206Qc/P0W07^4_@1hQL00Nhc507R:a@1f
R<<0OXo907^6`@1/L[40JVRW06IQW`1WIJ@0N7Re06a][01KGj80KGBd07Ek^P1:Bi80F5fQ05YPY@0g
>H<05P1K08<0/022IiX0`[2C05MP002;]]D0P9cA07RTc`00_/`040P00000001cT<`0000006UEI@1>
G8H0TgJ<0000002:BE4000000080J3]/00@0TW2K0:N6ZP2IKI00N4=Z0P0000008@1a0000U4Hf0;Uf
KP0009T0002l08m^W`2_ZND0W69g08I3D@1f:2l0Xfem0;6F_P2h]^@0UKcQ07Ui[P000000]JkH0<;J
jP3TimD0nOoa00/:4@000000Y/F?08il00000000h_oa0<cX_030il@0_ngF0:oSdP2?b[400:L00:3>
aP02003=VP0S000j0000`@000<`00000001]0000OTif09BDY@0007@000000:1jX@000000YW:709UL
K0000000ZF1?0>k6Y03^bZ@0klnV0:@0002a^8d0ciia0;R?D02jW5T0d/Z?0<k7R@3=ahP0f]>K0>OJ
Z@3^g[80n>_40?S/a@3hj<40i]FT0>3GXP31aHL0700000004@0^0000VP000=7hj`38m=X0R:Ul0<;V
cP2f/P004aXS065b00000000RTUO0;]kPP2`KV`0a8R40=NSV`3JYY@0c9Yb0080^HYD00<0Y78k0:Ig
?@000000HP00000<0?ooo`002P3oool>0000000604f8[015OZT0;5nD02ljK`2?]m`0003E0P000580
0`2DRjh0V86C0;>UV@03000000030;kPlP2Wb/P000000080000000H0NZ;?082`f`000000LhJi0;Fj
d@2WZ9H20000000D05HlK@0000000000001^W@00Gj<04ak005VDdP1j/^@0L;;P05jYe`1?W/`0<HVf
001HV`00KZd0=8Rk04NFaP00[]l0NKSV07Rbh`0oR<@2001n_@0<001PX@00R[/009o405^`b`1a_=H0
0=7O0:GRiP2ikN40BhQL0;kWcP2>`i`08GIV1@000000100]00009`000280000a00030000000>0:`0
001m[hH00;S?001HX02JZMP0?4QZ0000003odjd0jKf80000003Q09h00;K30000P@14SH860000000<
0=g:iP1lR]L0FJ:N0000V@0007@000290;gYa@30i]/0]MWk06=QXP1aKjP0QJ;A0P0000005P3BWH40
00000<`0/02l/F`0gmZQ08:Cb01oS<<0PH_206Yh/`1]O[T0NiO=08BNd@1eRL40KWRc07V7`@1fQKh0
Kgnk07J1_01eQL00NX[407F3_@1XLk42079l^00W06Y`[P1ZQl80LhW407V:a01iQL00Mgfh07Me/01N
EiH0FeNG06AETP1bJJD0NGNc079`[P1UHZ80KgFd06ic/`1AEI/0GfV/06=Z[@0k@X`061aZ05`0ZP1f
0<80][B00<_e0023YK/0IbDo09RLc`0003X0001i05A6P`1[O;X0QV5Y06/0001n<00007B^001Z/@27
Qkd00;_D00800;_200<009FS0000000000000P0000001`3]onP0oooo0?l0oP3V/j80jM>a0000_@00
09h00P000000102kMfl0_gaR0<F9JP1^TZ<3000000040;:C]033_MD0]M[_0>_on@80000000`0[mk2
0000002igP00l_oo0>;oo`0c>R`0OKbh07Vi[P000000HJ::0:NW002UdJh2003CY`07000O0000Q@00
DQPm0<>j_`2:E7<0aI:L086:00030000000I0000V`0008X00000000000310000g`000>[<WP3kj;h0
dl<00<B/Q`3KZiL0eZIi0:JAA`34`X80cLjB0<o@U@3MfjD0hMZU0>OQ/@3^hkH0mnFn0?o_b@3YfJD0
dKn30;foO`0M0000000502UbN@00000000000<NJ[@36Sg`0100000001`3on_l0omSS0=f_/@2]LWD0
Yf=C0;n7I`3H[X800P3;XVl00`2]NT@0ZWm20;2;C@1R000000`0oooo000:0?oooa00000000@02cmh
0000>@1gEVl0/k:M0P1I?fT00`1`0:L0O`000:/0000500000008060Y?`1Z@El00000000000051`P0
0P<30000001^V[d30000000D06MNT`2FPjT007RX001]XP00DY80001m00L;b@1_Z]h0PKoW07Fog`1a
^mh0KKSN05FTcP0`PKT005RK001OX@00Ql@0IJGI07Nmi@1U[]/205^Ve`0:04bFc`0cQkd0GJKE07o1
j02Eco40UM;P09GDc@1RXh<0^nSm0:kMaPH0000000H0?P0004001@0b01807P0003X07`1H04@20000
000408ESS`000000000000]TVP80000000L0U000000000000000000004ISDP0g0000P@0000@00000
00h0;Bll000000000000e>oo07^`002^g/<0X]cH0:STj@35m^@0fOgT0=_Nj02YZ=80Ng:_0;]h00<0
000001H0001900000032/iT0ajeZ0>_FW`2?UlX0MH>l082<`P1dP;T0Q8k309j`g@26VLh0GVf[06a/
Y`2ASkl0OH[205ia/01WOk/0LX_506b3_`1XN;D0JVVU0P1kQKh09`21R/00M7Rc07^;a@1bN;D0N7>^
07Ib[01UDH/0MV6G069AS@1YFYH0Thk308J6_`1dKj/0LVZW06]`/01ZLk<0E66V05QX[01IGZ80>C^5
02T]M`1fS/T0LYO=0;_@V`3coo<0d^cZ02PbN01iN;D0P5`00000P@17K:`0FFV_00<1000000000018
09eC0000AGl08UfH001jX`02001hQP0J001IN`00:fh006RF092?[@2[]jh0`J[;0<:P_P3<Y[X0eYf?
0=:]0025P;/0001;0000002@CEh0cI:>0<bBM000H@00BJW5002Xa0000000LCQP0:5XOP000000X7nK
0000@@2NJHP2000000090>gHn00009<0002l0<o]f`2hY/d0bP0007iUW000000007m?00@0000000H0
02h0000Y00000000Q@000;F8W02jPWT5000000050000C@000000^iNW0?oTcP25C0000P0000004@3C
g/@0bLN;0=fZT@3Oa9D0W9Q>0;6dK`33b8X0e=VR0=kOZP3WhK00jnBe0?7Q]`3_fJh0onW20?o/``3K
`8T0V9800240000000`0on?O0?o6[`3AVH400000001LUP00UL00^iZh0::>`02LQkT0^HN60;EnI03?
XW<20<fML@040<NEJ02iRED0TE/00:<006400000303oool000X0oooo40000000100A41<000000000
002DQJH208YXN@0303`0PP1>0000001]00@0000000H0L6>D06egY000FI00DFnE06NQ/01eZi/20000
000H03Z2X`0F0000000005ILSP1DL:H0RiW900000000DYL005fS0000PP00CI<007Na05bXe01e_ml0
P/WU07o4iP1^]N00JJgM056Dc`0009d003N604Uo`P1EY[l0PLOK0P16W<402@14N[80@Wo404J<bP1L
X/T0QLKG07g2_P1SZi<0[n?d0:cNfP060000000;03H0400n00X0AP0@01L000190000>00Q0000001=
:F40HTV309=o[02cYL/0100000002@2if@00X/h0055b00000000_8Ef0:5A;02h0000000004a7S002
08^Bb00W0:jhhP39d_l0do7o09RZI01ITV@0PKjV0:gWf038n^L0fOoe0?;If@1C00002SiB0?oeo`3o
l=h0000007FSN`000000j?oJ00000036h<L0U6`F08>@a@2:SL40PI7708BFb`1aP[`0QI?90:6ag@23
U//0IWJc001/X@00W;d0XJ3<06Il^01eS<H0K8k6069o^`000:80HfVW0080RI7700l0Uhbk08Z<`@23
S/D0NF:F07EYX`1]IZ80ITn806eHTP1WFYP0R82f09jLcP2;T<P0IVb/07IYY@23Nk<00P1^M;<05P1=
HJL0?DjG034cOP0b>880SZ3D08IaN`2hQeL0gMfZ0<o;`01OCgl0E5ZQ08V6_@20T<@0KIc?035`Y`2?
]:D000000000G03CVgD0ikbA000U=P3E^M4206`jI@0B07A3KP000000The<0;JCL@1WIZP0Vi310;JF
]`2`OYL0/VaW09eB001^6P00MBh00:5VNP2hP8h0b96J0=6HR@3E/;X0b[?S0P0000004`1h;dD0_HB6
0000002`[Zh000000:AdU02MeKD000010;W6l`3:_n4000110<nY``000000CP0007EGS`1MAhP0P5R6
04LZ002:/[l00P2MKX`20000000508QJQP2eRZT0ZgRC07`0001T00000`0000001P1QI`00DE550000
003;UK@0ooGQ0?oG[@8000000140W<kV0<WJ_@02:`00cLJ:09JTG@2g_h00]k=_0=[IX`3TfjP0i]JV
0?;W_@3kh/00m]Ze0>oCZP3gj<40l?7:06eR000L0000000A0;BRLP000000VH:d0=[:kP3Jh_l0ooWo
0>[Yo`3Zam40g[VK0<V`OP000000el;V0=_Eo`2WVLX0cKOC0=R`X@3IZh<00P3CYgT01P3>X740d:Qg
0:Ec?@1e?@00^H]D08mJ8El00000303oool000X0oooo4`00000040000:d00000000000000;h00000
00Tb:P1RNj80TI^g00000000OZ/0LG^]09JLaP2@WLL0>GFT04N2T@1DRW@30000000G04@000000000
EhZn04n<^P00000007f`0000N@00Mk<00936001d/P00CXh006BK07Jnh02Ae>/0Rlg[066[f@1k`>L0
IZWK046<``0008H005>@002[]@00^kd00P00N:<02@19MKd0E93<05RPd`1:Vkh0Kkbm08O<dP2Ad<P0
U=2l09O@/0040000000J000080000000@P000000001P0000M@1H07dkD@2GD5@0000005e:QP1eJJ@0
VYC50:f`g02W/N00UJGK06em_`2C/>80Vl`007JZ000N>@0008[30029002hMfL0Vdhh0000001PJZX2
09jci@0W0:K4k033hol0a>Oo0:2hO@1eH0d0000002DP203AoO40bO7k0<K<i@3he=d0/`000>Scm`3o
ooH0[KZL0<CZ]@3Von00[Mk409o<X02DUeX0[JII075n^0000000RI[=08^Re0000000014@08:Ic@1i
S<<0I7Re001ES@2nX[l0i]3S08bLd01kU/d0OYO>05Mf/`0006X0BF:S0080CebL02L0V8Vg0<:gf01`
OKL0000007Yf[`1^Lk00AT^?06MFT@1VGih0Ogjh0:6Se024SLL0GV^]04eCV02:PkX0RgV^08V9`@1N
Jjd0<Sn:02HaOP0^?HT0GGJg03/ZKP3O_/@0X9:Y0;JNN`2YNH80=@0/02X0>02ManH0LZW808:Vf@1P
O[d0001Y0000]P3Q_l@0ikH008E:002SUed00P0000006@28aK@0Z7AW0000001cGID0Qg2Q085GP@2P
Sl00WW>?0:m_N@2gN7X0]7R40;V1T@3DYK<0gZni0=JOW`3BUY80/@1e09d0M@000000ZVej0?K?b03;
bZl0[=:/0000002PNZ<00P000000302aUUh0I9k006VD`@2BZlP0LG6V0000002lQi407a@P06]/WP10
;g00M`230:R5[0<000000280L3]X095PQP1g=4/0UEM_06`0002U0000000009=HL`2`KW@0LSP00000
001]AgT0nL;B0?ogi@3ofkD0PEL003QMX@23Pj`0akF_0<^eN`2YZV<0QYiI0<WHX`34dYT0hN:`0>gS
]P3^e:T0kM:X0?[U`03hkLP0lng50>WS]@3Tk<80^:m/6`0000004P0fKS`000000000002ANJh0h]Sj
0>Koo`3Lm_l0gOko0>_/o`3OfLP00000003Fe03Onol03^Jo0000M02UR[H0hkB^0=V/Q`80aI5U00H0
_h]M0<NLK@3>XgD0`Y9S06<]002RMCUO000000`0oooo000:0?oooa<0000000P0XKg8000000000000
002>0000003AYh@0oobd001H0080000000<0L9750000002acMl01@000000601KDXP0JfNL07^G``2:
]]80T/gL001gS000000003Ac001QVP00H9X004n?001SX`00G9D007n_001LU@1i_n00E:;B05bYe01E
YL/0=8be03:8^0000;800:_5001ZJP8006nc00P0FhK506FQd`1X/m/0C:?103RAYP1CX:00JJfI06b]
S@H0000001<07P00000000000000G49m05HcIP1R=f@05`000000001OHZH0M7Zh09VXf@2[`>`0Z<7`
09Rai@1iT/l0S;KQ08[9f@1[0000VP0000@0000002/0S8k50000002I_^d0VKk]09k?m@2Xf>X0/^7N
09o8V`1CQE@0[:A]0;FSGP37joP0^Mko0:6Ye0000000]<ci0=?ooP3bool0NL6Q0000002JfLh0SLNY
0000002]_800NYaI06]n^022U/X0QYIh09:`g@0H4A0002P/06jUQP1gUL/0Gh2k01l<4@000000<f^I
08^Se@1oWm<0S:_K07J@b01TE3H0002D0080AF^W02<0SIO30:F]d0000000000008F8`01`R<4004n>
04Y6Q`1`RKh000230000PP2aQil0NG>Y04aKX@1dKZ/0M7Rd08F<aP2;P;H0=d6:02a6T@0gEYl0?ejV
04EEW03IdMl0o`000780001Z6Q<0bLRm0<Coo`1]]Kl0B8bJ0;3:n0000000002U06R7`P020000000E
04<J001I0000S@0008d0002aVEd0AEM=001;N000Kid0`[3M0;>MeP2L[]X0IHG20<:_bP3R_L`0f:nn
0=^a_`3ab=<0fZj^0=6GU035QH80/`1/0080000000D0jNOo0<SM_`000@00aFN?04mBV`030000000<
0<l?002F3`00SD800;^60026Mf000000091^U@1fMi40EXRG0000000Z07T0PXj^0`0000008P1R:580
PDMY09]UQ02YM8`0[W^E0:YgU024EH40SEb20;9kSP1o>Td0MCaQ0<>J]@3od=L0on?I0?O=/`2oS`00
0000000SJ`000000e<V>09JOF02>ZVT0]=J]0;oJ/P3VjKX0lNVo0?C[`P3/hkL0iN2`0?Cbc03cll/0
i>Bd0=WQ[`2Z[`0D0000000309j2I`000000000000<0000001<0a/;C0:bP[0000000Tf=g0=2mh@3k
ool0k?oo0=cmo`3BlOl0bNo`0=;hiP00000008BU0?GQi`000000002E0;^Pa03lc/<0i;>I0080aXa/
00L0^GaH09]I002TICd0ZFQ409aL<P1L7`00Q4H005h00000303oool000X0oooo4@0000000`1L05P0
Q@1[09j9OP02000m0007000X000l6Rh0000008^4L02QKFd00000051<=P02000000030;Vk[@000000
00000080000000D0>P1e04D0T@1KLjd0Uk?D0<7[l@030000000A03`@5@1852800000001DP`00@fX0
082g001[V@00EX8004an001ZX`00VL80BZ7103jH/@0eTJ@09h>B0000>P00Ql<00P00O;d01`00LKL0
0@830023`000Q[H008^T02MnN`0kQf`01@0000006`1;NHh06000000BGP000000PFRB05Y@S`0k:F`0
DT:0000fN`000000?EZV061n`02J`>h0W<?a09_3l@2J_>h0QZWQ09G:k`2^g?l0cN[o0>C/o`2g/>80
Whbg07ULT027PkX0VZGH09flk@020:O>m00@0:kOn`21aLd0Sm300;SYf@2Ea;D0g_KN0;[CW`2SEDd0
O@0008H000000000kooo0=3oo`000000/n2n0;7Ui080000000T0]=oi0:>kO@0I<`00Kh>l0000002I
^><0TZoM0000T`0003`00`0000002@2jh]<0Ab<b04AdZ01aUL/0NikB08^Xf@1RNKD0EgFc02aKVP02
001LV`0S02e=S01RS;/000000000003<i?l0`O3o002dg@2V0000`Yj]0000O`2eS:H0f;C30<:Ya@2C
U<D0<5JI05Yi]01oV/X0G6j]07f?b00^DYX0:TjG03eVZP0/DIX0QHo50??Zj@2eYP00XX0f0>?[a`3A
o^d0SEh006D0001Y000000000000X`16Ij/00P0000000`1]JZL0V6Mi000000020000000V08F6L`00
@Vd004Ag05eRZ@2kcOd0RKWI002L[02W^Mh0SiO10;72i030e>T0fO?h04I]P@000000U`000<2H/000
d[D0LXan08YYV`20U<X0lnZo04RAT00Q8a/0V:cL0:_>d@2^f;P0M@0007X0001D03L0JP1Z0000002<
03d0PeUo05<0002kVEl0H@1e05H0Y`1mQ;`30000000R07Y3J`2^QJD0_YVi0;jK_@2fSZl0XG:F06hm
K02FIh`0TU9X0;AoT`31TJH0h[c80?W?e`3oe=<0nL_20?o?]`3SZX<0`h]J07li001G6`00KX0e0;:n
P@2LbZh0l=bg0>oV_@3_k<40koC>0>gabP3XklD0lO?<0?7bbP3XkL80f>:a09>SH`/0000000<0LCA=
0:Z8W`2QZh/01@000000100009P0Xig=0:]jT`1F8@02000000060:NTb@00Sk4000010000001cDHL0
oo;Z0P3oool01`3Yool000000000003?m><0002M0=oMb`2nfl`00P0000000`1UMKD0YjC00>Je[002
0>2`X0080=b]TP3<U7D0_X0008Y20024>QX0Qd0006h[001/9`1M000000`0oooo000:0?oooa400000
00<0<P0c09<0Q02dQhL00`0000001P1D0000>@0009X0003Bc<40djT00<Fb00P0000000@0C02b03=T
X02>/ML003h01P0000000`27Xkd0T[_I06>S_`030000000302@0002<@2P000000080000000<0CJ2d
0931]`3FiKP00P0000001000G9X0B6nh04n=a@1DW<l20000000301h@;@000000000000@0000001X0
001N000000000000TGnW05=GVP14Bhh0DenT061j_P1INl0053^=05^7aP2A`^d0T<G/08>lj020^>L0
S;WZ09g9l02`h?P0_NOo0<KJo`2KXmX0Ti;5085m]@2EZ=d0Y;g]0:o?m`80^^7n01/0^ncm0:7Mg035
ln@0_o3d0;_]m`2]flT0Q@00060000180000YkOI09[7jP2Ke>T0OK^Q0;bIIP32kLd0^>KK0;3Pk02X
f>@0VL6/08b/J`1dP[/0QIK;07D0Y`3EhOl0f=GA0<jiSP1BEY<01@0000001`2N[N@0PJ3G076EbP28
XMD0GGZg02d0000000000P0R6@T08@006fL0Y6AB001<I`0007@0XYAa07Nd^P000000TP0006AAR`2<
M:00b<GN0=K:h@3:a^@0/IRj05IKTP1/UM`0Mj_?07Nbe000@gh0A72^021?UP0^G:4094VD01T`O`2S
0000FU510:Z1>`2Y^8@0SUij0;1`0000000006FD02MHS`0600000080QdH000@0A1X009E?A`000000
0@010P0000008@10PFT0Tl3V08o3i@2=KVd004]a0017>@2SFU80[fI;0000002LWm@0/ZG8002=L000
0000jMb`0000003idlD0_85a0000001QKJP0000008T0002l/L<0000009L0V`2V0<h0NEQL0880M@2<
E6/0T@0004l09@0004d0000009QiU0030000000R09=PQ@38YL40/9Bl09^1/@2O0:40M01Y05`0B`2O
KXl0`YVd0=Zda@3[`l/0nm7J0?oHh@3oeML0on?F0?o_e03of[H0j<JJ0>6lS02LL2d0OI170=WBV03L
_HX0hLBB0>CEX@3Uh:l0kOOB0>[ec`3]k/@0ko360>k^``3Th[00en:`05md:PT0000001H0N01f0:D0
XP1_;D80[iNg02d0001:0000I`000;L0002XQ6/0ZJI/0000B`1gHY/0S`0006/0001<0000002J0000
/`00Ag<000X[0000J@2ET;80oooO0P3oool01@3lool0]kSO0?7XkP3om=@0bL6700<0000000@0/ZA/
07n6`@000000k<740P3ba[h02@3_a[80g:^H0=2GP`36RGl0[VYF08Hl9@1L0000L2T005`H00040000
00060=<0003H^m80aJ:h0?ong03nm/`0l=VeDP00000<0?ooo`002P3oool@000000040000D@1=AWX0
R7ZN04/g0`80F39B00D0SE<00000IP1?GiP0^<?H05`00003000000080780S`2I0;T0PhRi0:71[@0n
OjD0;GZJ03EnV`0IGeL50000000609T0X02007@0I`1904d07@2b0?L0R@2`0`0000001000MIL0a[_3
0=3=_0050`H40000000303R;V`000000000000d0000001X0000C000YN@00Qk40T8^f04MPZ01?KK40
EWFj05io`P1DOL40>fN`05^>bP27`NX0T<g]08C0j@1f[>00OZoS09W8lP2SdOH0Z]Gh0:W8n@1oU]80
QYOC08nUg02@/ND0WlG[0:[Em080^>Sl01X0a??j0<okl`3Honh0h?oZ0=kom039n_80U00009L0003T
g_l0YlSS066X[P3;VE/0d95N0>NQN`3Z0000_NgE0<_BgP3>ool0]o?C05Im>01bOkP0RYO;07nNb@2U
c>40/=G>09^`Q@80000000/0@P0000000000000000000=WBmP3;c_H0NHo304eLWP1;05D0WJkM05n2
_P0206F>a@0S04=/Z`000000O7RH07h0000]0000F00008:C]@1nSKH0Jgjb07bVe@2L`nX0_=7b0;:_
e@2LMih0_ZCE0>?Yo`3^ool0boSW06:1_P0^DiT0852E01M6SP0kIj/001]/04mMX`0O>hX0Iee;001W
C`280000T`000;00001T000000000:Zej@29TL`00`000000:P1P:P00IBP006DX001>0000olFm0<F6
J`2ZHc`05``50000000@5SD0on790?oC^@37T9T006b5095^W027BF@0Z61>0000001:00009`890017
;0189440cZ[20>Fib@3jcmX0`92W0=Woo`000000jOoo0=7Rc0000000Dh5/0000001oOP00G`1V06`0
@P1W<eh0_k;00022@@2`ZmT0YWJ20=V[Q@80000000<0RfFF09aPM`3=YKH00`000000702]08<0_XfO
0<fR]03M]//0mm7P0?cFiP3of^T0omSQ0?oQh03om>40oooQ0?obc`3ghKT0j=FT0=73R0000000gm2I
0=kJY@3Ld9/0g]bW0>?MZP3/j;X0lo790?CabP3dk/L0lNFk0>7CWP32bi<90000000O04D0@030[Lh0
000002T0001U0000V`000;f=WP3O/;40k<320?W@d`000000_Z^n0000000o0000SD/h0000003A]Ld0
il[<003<]@0C0`/0002l0;O/g@3oonL0oooO0?oof@3Xm/P0WkoY0>Coo`3joo0000000000:P040000
000G07]TU`3BY[<0lLFj0?75^P3T]:`0gJZS0<F9PP2jNFh0[VUL0916?`2=@Sh0J@0004D000000000
7EM30:Zdg@2ha=/0V[G?09F^d@2meol0l_oo0?oon03oon80DP00000<0?ooo`002P3ooolA00000003
02@SG`10?78000000080D2Q;00h0JcI=05i@P@1EH9T0000006IGQ@1oEW00DP1:0000001i0;@0NP34
086GaP2:^[/0M;>f0022P0@0000000P0MCPj01441P00000000000;Fih02k0>l0T02/0;h0o`@00000
00<004Ad002a`@000000200000000`2<QK8000000000000;0000000I0000X00006@0056M04Um`019
O/00A7Bh05^8b@1>OL40?6be05N@b`1h^^80O[oU07^ji01g/>40Ji[G08flj`2Rc_H0Y/oh09c5lP1n
X=/0O9KC08f^hP29]NL0R[oW0:7IkP020:[TkP0=0:WTi@3FgMT0doka0=cok@3Ton<0d?oo0=3ho`3V
lol0`=_O07foZP3Ch:h0f<Z>0:Z_P@020000000=09P0003Wj>@0j_oo07VYKP2a/m00j/Rg08F@a@2H
ZmX000000:6^f`1OHih0RiC707jcZ0030000000804aZ0033b[X0hloR09bKa`1WK:P0UYc>0;:lj02Y
_^/2082Qe00303MSXP00OK80GYJo0080000001d0E@0006VTa@00Z<h005b2001dW`00Gfl005IP08>5
^P2WS[T0n>ko0>Cjo`3jool0m?oc0:6hg@1WLK40J82m02M=UP00@HX0001S02TnR`0Q0000If^P0;F/
R`3;aXl0U@000<P00031fkh030l006@Q00040000000O05IY000S:`008b/005l0V`3>0=`0dk^m0>Jd
V@36Q600I`000000003ockd0l/2`0=fTP`2GFVh0MeJ=08/0002TGDH0_91U0000001NPHD008Ih0:Mo
Y@2_PZ80`YF_0=Rdb0000000Z=ob0000001eaN40LJZI02l]?@020000000706EBD02GH`00I5Yb0;n]
J03TfKl0]HI;09fDb00200000080R6ZN0280QFFK000000000000cj_108e_X`2]S[`0c9j`0>:kb@3X
a]H0m=?X0?oWo`3oiOl0onoo0?obo`3oooL0ooof0?ooh`3omm40m^Vn0=gNZ03OhZd000000<baL`3F
e9X0f=ZR0>7X^P3Xj[d0kng30?GZ`P3ik<H0n^G00??N]@3Ob980SHe4200000002@0g000000000000
001M<V@0RFfH0;VZc`31[=D0aYfc0?C>dP020??=d@040:^Y_@00000000000=H00080000001D0^k?J
0?Omo`3gMhD0]I][07F4_`000000nO3Y0?oonP3Xn/d0[/JA072?b@3Sool0oooo0000001COgP01@82
0;^:K`0S8A`000000:n;[`3T^[d00P3O[ZL05@36RhT0Z6EU09A<C@1j;S00HaDQ0000001C00008000
0=Z`Z03Uhml000000;7Qm`2Hd=h0U/oJ07Zfb`1@SkP0T<oG0;7[i@39jn<0n>OF0>^dV`1@000000`0
oooo000:0?oooa80000000L001al0000000003P0000h0000001hIi@0JW6V0080000000L0CcYX02P0
=0010`40O03F07bdeP21_]L009^000H0000000L08`T=0000000004/0000Y0;S7hP2odo<0a]ko01H0
000000<0D0000000000000001P000000600004X001QX02eW[P14Ol00?7^l02UZ[@0kO[/0=gjj04RC
a@1IXll0GZGA06:Te01IUll0KZ;K07n_i02Vd_T0XLce096mk@20ZN40M9OE08Rdi`22^NT0R/?[0:CL
l`80WmcV01/0V<g@0=W7b@3?no@0goSM0>?cd033m^X0/n[Y0:[Sg@2Gdkd0/Mk10=O^b02dd9/08fY3
0:>iNP3Qj^T0e/cW0<3FaP2;_8d0aNGU0;gAl@3JhnH0dnkU09FNc`2;V9l0000006d0TP1fP;X01000
0000201GTKX0Oj:l0:jkh02NXm40Ti7209:KcP2^_>P0_LS_0P0=00007P1QS<4004Yo0000001@SKX0
000003mn[@1aZM40IYS9001QWP0008T0Okfl07^gb000Vl800526001/QP00F7L0096d02eaXP000000
30hJ09nXg01FM[@06TR@0000KP00<H0093f;06Qn^P2jQE<0oljF0?ooh@80000000@0J02O08F@000i
B0007Q<P0P000000203Xool000000000000008/0002[0000f@3B]<@0dInC0`0000003P3og]d0olg9
05/K@P1kBG@000000:^:Q02[SDh0Yfeg0000001P4B00O2`/0;EZFP00EUH006eY0P0000003`2g_<l0
/]C=09WEc020a<D0V`290:MdT@000000cjg000000035b8D0P45;0:5M>`2=K9H0000007URV`0208]a
Y00<02dPJ02QR[@0]J;80:n8Z`2TPjh0e/So0>gJo`3bfO@0mM_i0?o[o`3oo_l0ooOo103oool04P3o
on/0ooG=0>gX^@3ShZh0g>Ng0;2]L@000000bL:30=SHX03Ni;80ing30?7_aP3ik/L0onc60?WP_03`
e:`0hLfG09VBB@P0000000T0GT1c099kZ@1jGY@0LeZD0;foi@000000?d1?0<nab`3:XkX00`000000
6P1L7Cl0h@3^0?ooo`3oool0hLgT09>Kc`3Xn?l0oooo0>;fe@2RR:l000000?ooj03oonl0e>W00:Zd
M@000000[]co0>ooo`3Lak`000000?obg`3oon00hlfH0;NV_0000000^hfV0P34Sih00`2FEV`0TDmS
08m;GP040000000403=gD03>e/40mL;G0:QZIP80000000X0SLCH09g9i023[MP0KJ?<0934gP2UbN00
[I?10?oQc03TdjP0Sg@/CP00000<0?ooo`002P3oool>000000060>k/o`2nWJ400000062J]0000000
001Q0P008E802`00OK<0NWna08>4]@00QX8005YH01d0I00I07`08UR<06bMc020]]/0Rl?Q00@00000
00T0JP000000L`000000<iSQ0000H`0005d0001G01PO=031h?D08P0000005P00;W@0;fjb03=k]P0R
LZP09WV/03F6]`0YO;0097F]031l]P12R<80@87004N2a01[W]T0S;c[09W8lP28^>X0N:WQ06VFe@1l
/>@0SLSU09_GjP2KdnX209k9j`0W0:fddP3V_/<0omk20?o/_03Aikh0^>[E0;S/gP2ik^H0^N_L0=Cf
g`2[ekT0R;Z;06NXU@3IfJh0dM780<GKl@2ai<`0>WM405^=[P0[LF/0_>;I0;j/c0000000I6nH096E
U@1GJP00000001dF3P1MLk00000009Rlh`1/VLP0KI[;08NZf01UO;D0CE^K09RRe02j_nL0A`000080
clod0280XKKR05B9^`0iKjL0CXZh04V1]01BRk`0H9o305ZE`@1;OKH08UZE001hU01@VZ00<WfD00A9
O`0QJ8h0066G000jLP00JYX000000;:ei@2/`N`0Mig?049][P00?HL002Ab000bP01BLkL0Zj6`0?o9
Z@3om]d0b9jX06IiUP1YY;/0AXR00`0000007@2?[]d000000?ooo`3oool0001J0000=@0008T0c;kG
0<o3_00000003`/90000002iV;00cI^D09Q`U`2]Vl<0]/;/07>VZ@2VNYT0NCeI04h;9`1b=4h0Udm:
0:R9I@1l_:L00=@008I^M0000000M2l00080000000`008BK001YK`00000000000;W6Y@00000002Qe
05A7P@2:OZh0/gY60000001jHYX20000000802`;D01WIJL0W8Vi0;>?]031Z=00h=oo0>?Ho`3`fo`4
0?ooo`0F0?_oo`3Zool0o_oo0?coo`3oool0mOoG0=gW]`3Ji;80^MJX0;CG]@1oP`00Z8i50<JnO`3O
gjd0k?;80?ooeP3oom/0oooM0?oje03kk/H0h]bY09JID@L0000000l0>3Z007^6`01FEgD0002D09am
Z@3;`nh0l?oo0000002bU[`0NdP00:Md00000000M00005PaI@3Qo_l00`3oool04P1cNKH0oooo0?So
o`00E9H00<3_0??ij@3[nmP0h??>0=c/``3Fhk@0000007F<a`2S[mh0T7b_0;g7lP3emOl0oooo0>_M
a`80000001X0Z6f20:9SM`2RHgL0WEme08H0E`0000003`T;0000003oo^`0n_C90<OKY`000000YYJf
0:RJ]P3Wd=`0oooo0?;omP2/cO40/];j09k:l01bV/H0KhJn0>:j[`3Zf[d0f^Be08nWHdh00000303o
ool000X0oooo3P0000001P3^k?l0_YfQ0000001PV[@000000000H@80025B00/007fc07Yo/@23Q;D0
08J2001JF00M06@06@1l029HS01/WL`0P;KK08_3h@040000000906X0000007<0000003>Hh@0006<0
001M0000E`0H7c@0`N3e0280000001H002id02m^/P0cNkH08W:X02Ii[00eQ[L0:Gb`02Ae[@0`O;H0
@XS20421`017P/@0JikI08blj`2Ib?80R;SZ07RYh@1YU]D0O;3T08g8i@2KenX0Vm?Z0P2NbN/09`2]
]=80i[k30?oN`P3ok;`0dNNn0;SZe@2hk=h0^NkV0;W[g03Dm]l0ZmNi08RjR`1WZ9D0fMV^0=7Ab035
fo40/NC<03YgA01KSJh0:g5[0;cRf@2n[<`0000006A_V02AUID0EfX00000000M5Ph0GG>`0000002H
_><0K9W806fJb`27Z]P0IGbe04eKV`2HX]@0^[oW04L000020<o?m00R0:6fhP1DRK/0>FnW04j:^019
PK@0DX^l062O``1JUL40Bgff029JU@00N9@0D9ZP039mU004BGl08FR>001QU`00>W8006ZJ0000002b
]ND0[<7/07NMc`12KJh003f7000TLP00<X00DW>g0:^Q/03obJT0ooKM0<RNZ01VNIH0JJBk04J8P0<0
000001d0SjkM0000003oool0oooo0000FP0003D000290<bne`3?`k`0000000l;2@000000^IR`0<fK
U02HL9L0[I_30;K2k01cYZT0YWZI07TmF@1>2bL0LSA>09M?BP2XRFD0O;bW003D0026KW@0000007@_
00020000000<0024V`00JFl000000000002iaZD00000000XM@1DAh40RWj^0;=jAP000000NV:J0P00
0000200/2e00IfFW09b9^@2cSk@0`JS@0>3Oo`3Sf?l0l=_l103oool05P3kool0j_oo0?koo`3lool0
oooo0?Goe`3MikL0f^Bb0;WFZ02dekD0Oh<00:R>A@36_Wl0gmn]0>cbb03oomH0oooK0?oog@3on]@0
nnk60>;LZ@2FVE470000000?03PjP01kQ/00EUMe0000U02LOJT0bl?^0?3oo`000000/YJl07]8002W
M000000007@0001H<FD0hOko00<0oooo0180LgVf0?ooo`3hool005BF0030k`3cnNT0jo_H0>3ccP3L
k<<0e^>d0000001eS<L0XjoN091l[`2mao80mOGo0?ooo`3[gLL20000000J0:Q]PP2RHgL0XV=g09eO
M@2605L0000000l92`000000ook/0?[db@37fjL000000:JF]P2XV[H0im3L0?ooo`3booH0[<ga0;;B
nP2Nb_00LY[606n6_P3R^Zl0j]Zm0=[T]@2?Yf=>000000`0oooo000:0?ooo`h0000000D0W;OM09=i
V0000480V[7K09njfP0300000004000]C`00K8l07VYi0015@080000000D05E=k000000000000LjK7
086h_P030000000509X0dP2BW<<0Q9:a00005`0004L00P0000000`0gLZ/0PZ7;0;ONl`0U0000000C
000NB000CgD007nS001BSP0JHZD0:7:`02Yg/P0_Ok@0;WJd04F2``1WWmL0P[WW086ii`1OX<h0IYkH
06jZf@1o`mT0NkoE06^Wd00205Z?bP0W07BFdP31]=00ooO@0<gIZ02UfKT0]>WE0;CZg`2/i=P0_>gN
0:3Ib01o`:T0PLFo0:GPh030i=40U;>E09o?d00fO5<095bB07^d_P29PEd004a706l0003QhOl0JHbW
04d0R`39g?l0Z;kf07:Ib011H:00Mhk50;G>o`2Q`NT0Q:oI06fNc014LJ/09T66082Mb`2D[m/0U:cI
0080eOoo00`0`?oo09WCl`00IGh005am019MQ00JHXX0:gBA03>0T@003Ql0;ffQ04>9X000LVD60000
000E0000QP000000V<3W08jkh@1JR<80BGNf000cO@001U80;5:K07VC`03oon@0jkj40825J@0ZHeh0
Z:390000002oPGH000000;JV^01_?5<0GjW30080GJVm0P00000010000140c<KP0<kCaP3@eZP30000
000A050V7P000000dM[o0;[Fh020[XT0JRi>06`cE`000000`iJV0;f;L`35W6D0`hMS0<B9I`26/IX0
KZO806d^002XJ0000P000000101C03L000000<GTbP2a0002000000050012R`3nf:X0eJ1i0000001h
GYP00P1S>W402015;g@0Uj;H09j_hP2d`_00bMGo0=?Go`3Ohol0kNGo0`3oool05`3lool0kOoo0=_o
o`3Cnol0eooo0>Soo`3NmmT0`=je0000001m^:00JYn?04Yd=`2UTdX0`:U[0=K5S03`gJl0onW60?oo
g03oomX0o_[D0?7^``3<h;40PY]H00L0000000l0001V0000001WS[`0002Z095gY@37g?l0PJVE0000
002_Ul40X92`0<GAd@1bME@000T:0000003Tm_l00`3oool05@1ZM;@0k?oo0=g/i03Id9h008:_0=7f
mP3con`0ho760<oT]`2kd9`0W;Qm05]f]P2?Z=/0UZ;E0;G6l`3DhOl0kO7o0=^_R@2HGbX0000009ME
I@0209=@HP0309AGL`000000^jSA008000000140/m;T0;kT`02g/:80000006>G]P2<`]H0[=[[0;?R
l02dh=d0Zm6[0;WOo`3?nol0WmKZ06UDTP2kdn<0anK10;KGY`1?000000`0oooo000:0?ooo`l00000
00@0002T0000002W]mT0/<kH1@0000000`00<3/00000000000020000000305P000000000;FbE0080
000000P0C5>607:UdP2=^N800<?U01hP80208200001J0000L`<0000000<0V5iU0000000Z3B@04000
00000`0JIWh000000000000A0000000B0000E@2<X=<007NN001:T`00LK40EIS=06V]f`0ZKZl05eZR
03il_P1;T<@0GJC<04BC^@1:V/40C:6f062[d@0WOZ@009330P00HZX04@1?Rkl0NJ[<0<gLa@2;aJ80
W=S10:cVf@2GelT0PLFe04jMS`2F/Hh008Z:02PN3`00^[<00;Ja002UV018TW<0H82g0080000001@0
H9Zm08fgg02T/mP0`<c^0:Feh@0006h0UK7L0:W6k02S^><0FF2M05AWYP2EX]<0gO_o09g8k`2:^md0
JYk7025<SP1AQ[80LJ7=07^/e@80L:[000<0EYVF0000000000004P0000004P0WLYD0:FjM03E]ZP00
@8T0039l000_O019LkD0]<cL0<O5U03Pool0`lWo0:^Ob`2jU@00O4000>Zj[02TXL`000000<N6K@80
GUhY0`0000006P30`^<0b]K<0<_@h`2g]H8081XH02L1<`2JC3D00000003Qo`00jnH0000008EHPP1h
B78000000029U`30em80^7UD0;]mE`2mOe`0_h1P0000002_UWX0[:MT0<64J`0002`0CP1C0P000000
201_000000000000000004X0001A03h0I@1P06l0K@1g0P23IYX0201cIjH0XK7S08n[g`2I/n@0[/3f
0<C;o03Ae?l0joWo0`3oool05P3bool0hooo0=KooP39lOL0a>cn0;OTj@2Le<D0M[2=0?o[l@23Vkl0
001Y0;FVH02OUDT0]iaN0<fLKP3H^H@0l=BY0?odbP3on]80lOC=0>GX^`38ej48000000060<2^WP3E
bKD000000000002?0;h0]/?U0P0000007`2jZ7<0000000000000GgT002m?0000A0000?l0lOoo0?oo
o`3`ool0RY360:^ei03XjN80Z7U90=BI[022/Ll0c__S0=O`d02eej`0Wkf50:W3SP22K3D0J8[4092W
g02EXmT0^lOb0<Jll`3XbM@0g[2S0;n0K@2CBCh00P1R02800`000000RXNn000bB@020000000A0:c8
fP3EooD0h_o]0<jea`2n`LH0Ig2R03iYY01e[<h0/>7T07>2001bQ/00XZ[O09Qm[`1D?hH0YLC00;7N
_02TbYP0C`00000<0?ooo`002P3oool?00000005002La`0008D000000=3G`P0000000P3]fm`00`3]
d[800000000000030000000300<0001N00000P4J00<0000000L0002K04f>]P1=SK0007^O0011L02Q
MWP0CT@000@0000000<0cifF08n/SP0000002P0000000`1<:e0000000000000H0000000A01<hR@1Z
Kjd0DUjR001`[@1TY]H0CXc502aW[@0UHZX06E^P07F^f`1KY/H0V]7O09g:gP2=^>@0Mk3L06j]g01g
]N<00P00IjL09@00M[T0HJS206>Y[`21a[h0WmkC09GGb@22aJl0IJJ20?7HYP3L^h00YXm70>cGX`2n
cZ/0Rlo304fDM@21Ym<0FW^d06ZC``1jV/P0A6:L04ag[`1jXM40TZgL0:Jhh`1HFiP0OYk@09>^g02U
/ml0HWZg07=`ZP2/f^P0l?oo0:3BlP1l]Z`006UE00000000IG805@0000000`1IVjT0000000000004
0000000?0000>000A8h001EW04ab]P1COkl0`ncT08MhJ@2E_>40HGZh0024_`2SQ:00Re]<0000003K
XY40ci>800<0000001/0=@0d00000000P;P0Xk750?K6]`3[c:`0000005deJ@0/03/0C`1^002GZ`00
0000PeV408aYUP1GPY<0000000L61`3=TgX0aX]W0;]mEP2iNEH0_7]N0;EcE@27/IL0m^KL0?ooj000
01T00P0000000`00<`00000000000002000000040000G@0005@0?`1g07L0UP80X8Ri0240]l?a0:bn
k02B/N<0Qj[N08^ZgP2]`>d0`M?m0=3Zo`3HmOl0mOoo0=coo`3DooD0U<Z`0;7Uh`2TfN80Okno07jm
Y`000000lLcK0?oZg`32cZD0A0000;>YH@2dZ600f[V30?K8[02cXEl0g/ZD0?3G[03fh[X0mnJn0?3N
/`32_7`01P0000020;VG/@0W0=JZ[`2gQID000000000000l03`0_KGE09:ESP000000JH>e0<2]aP00
0000`j2]0000000004D0P`320>3oo`3eool0V;gA051OXP2UXM80_Z6n0;25W@3Ib=00c]SJ0000002`
gL00d_?D0;_BW`3oomh0bNC703UPXP1aSlT0SikF09bPe@2g`>P0dm[o0>CHmP3J/</0MP0000800000
0140KHO206J6_`006Cd007f@000nB000UjT0Q[cG08:ecP2HdLT0Wm3O09Bmi012IjP0IiO90:WHgP2c
iMX0XMW806J[Z002000000030;CTfP2]gKd0S[Z704l00000303oool000X0oooo3`0000000`00QJD0
07AH0000000200000080m/RY0P000000100J010000000000000]00040000000508QAG`0]93X00000
02]K000>GFD00P0000000`0ZHP00:Tl00000000?0000000304hG>@00000004<001T0000001406Cf=
04IX[@0Z>8<002Eg000kQP00>gH005^L001Y/@0`KK80:G2/08c<i`2@b>L0U<7Y0:2nk`2A]nT0P;7T
0;3Jo`020:_Ho`0R07JUfP18S[/0J[W709KEa`2Pg]00SM;507fmW`2R_9D0g/n@0<nUHP2@RT00W:MO
07j>B01AUg/0cMWo0;S>lP1lU<P0JhW009bVe01jO;00HGVb06B<`01eT/L0SZSH0000002K^n@0QJ[H
09F`g026Xm<0FG>]05FB[`1BUYl0VLo;002cZR00000000D0001G001CU`13IJ`0I8g608bhZ@030000
0006001IV000EIH0LF210;F:S@000000A@0o0P2HU/X03`2kU:40fJNY0<jR]@3;X;@0_kNj05L0=P1C
5cP0KTIf05/fK00f0580PFZP0::Jb00[0480Pdmc0<^ee@020000000>03dh@03OYIT0kK>F0=RUPP38
SV/0`hIW0<F7KP2iMeh0[6I=09Q?=@00000004]F001gGP1T00050000000304Dc1@0Y07@0S97:0080
^/3/00`0`M?m0;O>n@2Vao80X/K]06^Jc`1dX=@0YLS_0;CIm`2jh?L0aO7c0;k/i@2_g/`20000000C
07jef@2Gc]H000000000003odLL0onG40;G2Q024JP00]ZeV0;>TF`2o[fd0fm2N0;nfM03Pe9l0jm6T
0>gAY@3/cj80fKn90<FcLP050000000908h0_@3=`N40cL7Q0;b]a0000000A24Y0;F4T03G/;l0^i/0
0080000001l0PkNc0000001C@fd0dL3>0000000003L0j@3o0=Soo`3Nool0XL7U001;T02Q/n80/l[`
09Rdg03oool0eooJ00000000KWl0]]J_0=GV_@3:cYD0a>>n0=3bf`0cFYd0FVJZ0:>_g`2bb?00aMco
0<6kjP2LQKX0BP000080FGnl00@0DH2h06NOb02Wen@0jooo0P3oool04016QJT0?hV;0:2EbP1h[L`0
LIo@05^9`@1hZ]<0WLoS0;KUi@1TO@00_@000=;FhP2ee>P0R<K009?8Y`1?QDe?000000`0oooo000:
0?oooa00000000@0PFB<06]NPP000000>P000P0P00000`180000PhAX0000000:0000000300<68P00
0000000000L0000000D00CE4000000000000000003`VB@0S0000000A02MDW`0VFjD0:UfV0019U000
A9806VJT001IU`00BYL00:KM06RNeP1fZmh0Nk_Q08;0i02A_n/0/=;o0=K^o`3Jl?l00P2le_l03P2A
[><0I9??08?8cP2@ckT0Sm?:08c@`01QZj40S[b^0<cH[P1bVe/0I9EU09O2W`1iV6P0[lC[0`000000
4P1`N;40KfZP0962[`2/]?40Z/Ko076@aP1aUl@0VXnh0:k8i`00T[D0JYS805>8]P0fLId0EYN[0000
001:0000000000/bF080000000<0[gMO03`0000000006`0000003@00@h408D>@08Zbf`0000001`/P
0;9^EP2oPF`0gjbE0=j[W@000940QY^?0<L0002307000P2C0;800`2LT/H0WY^o000000020000000M
08BB``2ePX/0Jd9b02D0>`1I>740Vh6]0<2W``1604l0_j1G07iQTP000000[jkC0000003oe<D0on[@
0?o<Z`000000eYn30<jCN`37RGH0@P0002X000000000002104YnA01U5@00PCT=0840001L00000`00
00009@0004d0WZCI0;Vok02i_n`0`mSo0<?Oo`2nh?l0[=Gc08^jh@1NTlL0NJWE0:7Aj`2YfnT0ZMoP
0:[Pe`3KgkH0d>CZ0<GQn`2OcnL0`ngU0<W`f@2DXP00oo;10?ooe@2^_h40S8l00;^eK`2j[6H0^:YT
0<o9S@3Sci`0l]J]0?KG]03cdjd0km2W0=nlRP3>]WX01@0000000`360=h0_/CW0;k4i`0300000007
0;ZZd03Mc_l0000l0000]@00VJL00;Fl04aK00020000000K00004P38l_l0aOGo0<C_o`2dhN0009F2
08:EDP2?/]d0ULCO08Rod@1g][00?VDV0000003>h;h0/n3M0>3^c@3<f:@0XK^60;oM_03Fn>L005VP
09figP2jeOD0^M7g08J5`P1mNKL0Ngfi0080K93801D0K9W<066Fa@1^Z<L0YN?P0<CokP3VlOl0c=7b
075ZX@2lZld0a^3o09[0k01/WL`0ChFi07Nbd@2JclT0_M^j0=ON``3Gj=T0`^cZ09oD_P1ZXW@0D000
000<0?ooo`002P3oool>000000060000I@0N05P00=Gh0:SGiP2;`]00IJB_0P1R00000`1`0000O`32
0000000;00000003024QFP000000000000@0000000H0E`0000000000000004V6002Ra@1CS8`20000
00030;JVH`000000000001h00000018007Zl03Ma]00dN;D05EVM01aNX`0=CYL09Fb]02Q^[`00=7/0
08o608Jmi@21]n<0K:WJ07:hg01Z[]D0>gVg09o;o`2[col209g4k00>07K2e01j^M`0OlC4066^X01X
]:<0fN:`07n]e01o`lX0^^7;03f:N@1f_;D0SlBn03a8DP32eOP20000000:09>Ib@1YL:X0DUVE0:Ba
fP00iol0bmWo08^Jc@2C_</0;fb1030000<0000000D0NDAJ09YTK`29C5@0BPH003<0000204400003
02@000130000A@000080D00000P0FA8F05TB4P160000F@0005hF501N0000F00004l00080B`0000D0
CP<00000000d0000?@0003P0000<0000000<0000G`000000000007>F_@000000PS4H0>;5W`000000
]Waf0<T0001j0000e9nY0P3=Z[h00`2S]Kd0IiBQ045nS002000000060020WP00OX80000005l0I@1n
F8P0LTMc0P0000001`3Ob>@0k>Go0:21V`16M[80iKjU0?oieP3oon000`0000003016F000dIJ:0440
002oYIl0`NK407FXM01`80l0LbD007@X000n0000S48007/00080000002L0000d07bBb`2Z`NT0Z/7Y
0<WZo`2lhOh0Y=3a09o>j`2Pc^`0PkSM06VUc@1a/<l0RlKJ0:CJh@2kjN40g?SM0=_iiP3>mO@0_N[`
0;SWi@30k=`0]m00002MM000d:40FY9X0::[I02k^WL0a;Qe0;VVH03@/WH0fKN10=niRP3Za9d0jlNO
0>o>Y`3M^8L0^j=P06P0002D00000P000000102oY<H0[hbX0<V_[P39[jh20000000U04h]J024KY`0
`Kco0000N`33j/L005990024R@2<EP00I2<k071AR02AX[D0Zm_J07^g`02;`M<0KjjW08R^NP2CVUT0
000008VccP2ki^40ZmRo0<O;V@000000K8/00<WVo`00j00009L009:QG`37gk/0hOo/0=cnk@00@G40
K:3306B9_P1^N[/0XZOK08fUfP02092ee`0D07:Wb01JVKT0J:O4052IY@1HVk<0K:K407V^cP0hLJ80
KI7409c5jP2Ye?00VLSU05^J_@1>UJd0Fj:T08C2/@2Tf]/0[=oJ09WCa01h]YUA000000`0oooo000:
0?ooo`d0000000L0R;ZU02D720000000G8Zg07Zab`21_<P000000080CXba00<0CY:]000000000000
3P0000000`0G@hP006FL001@Q00206P0000400000000=WX006VG001hMQ`0000000<0_;:b00000000
00001@0000004P3ogm`005BH0420_00^NK405F2N0017S000EZ40?7Ji03Y`]@00N:d00;kM0033i000
Wm<0H:SB07RlgP2@d>X005JE06nceP80GJk402L0GJnl06BeaP1[^;`0JKJd0;oPaP3Qjl00^lg^0:OJ
gP0QIS`0HZW607jih@2[fO`0dN_F0=_oo`2I`Ml0LZ;;05Eg[P1GLJd0Fgbc06VI_P00[;P0A7mV07Hk
<`00Y00005/004@02P0n0000GAXQ06/Y<P1Z9bd0B`H<04L33@1901H0FAHR068N901V8RL0GQTP05PD
7P1D4Ah00P1J5R401P1R7RL0Ib@_068O:@1S7B@0J2<Y06dW:`80KBHW01@0Ib4W06808`1`:c<0L2`f
05dH901Z9Bl0IQlU05hF6`1S6a`0J1lN06TO6`1X0000GP0005l0001V71T0J`0006dS001O4`00E000
04P000<0000000P0J9Z>0000003gkL@0[FM50:ekP`2]QJP0Xgh00<b]0080ikl000<00;ZW06fUN@00
00000`0000004@00an@0ono`0?ool03onM`0UDiA0:<000250000k=go0?Gao`000000X0000?oSdP3o
jl/0omc80?oCc01W0000L9d00080000000/0^P2i0>;oj`22]880X5eU09mJEP2FBc`0PSH007Xb001S
0000GQ4006LL00030000008009bn0240Y=GT0:OHh`2ReNH0U/cQ09_=j022^mX0JZS;06:Ta@28a=X0
TlkC09cEb02Uf/`0XMWE09C>fP25aL/0U=3?0;?Th000000009YN002[U@2^cY`0]<>40<g4Q`3<_7`0
^JAN0=>jO@3M^8D0f:al0>2cR@3S]hl0jlFO0>>mT02oVEl00`0000000`33/=80Sf^G0000000206/0
00080000002=D6H0Odie08QFN02MMid0c=Oc0=?Wd@3;d0020000000M0:F4Z02gc<l0HIam00000000
@W`00:bn086eZ03@eZ@0_LZB07eQ001WS[`0fooo0<WO^@000000hooo0?_oo`2ad=L009T008UXS@2i
/hX0iN>i0>knf03Unml0hoo[0=Sjj`00:D`004Z90027_P2:/Md00P2Ca]h0502?bm80Nkc4076d_P1e
]/@0I:Nj056E/019SJd0@HNU02iiU00HJ7`03Eid01MTPP1:T:d0GJ2i05^O^@1k^lX0QLG508_:_P1d
]I/005X0D@00000<0?ooo`002P3oool<0000000706EEG@1lZ9/000000000000hO@008V:@04aoO@0:
0000000504/0001P0000MP000000000007D01@0000001@0005d004n>000oO@0003X0000?02T00000
0140O[Bk001SX019Sl@07VfU001BR`00<H4005BP04]d^P19LKP004J?000mN@00Zm@0CIO906F[e000
X;l009Jj03F<[P0203bA/@0I05>U]@16VK/0I[;;09WHf@2fhll0N[:P08k9a`00DFX006Ql03MoV`1g
U/X0[OKo0>?oo`2Td>H0XM?I06n[/P0SKH40002D05^=/`1ZXk40000000aIL`1U9S<0F1TX0000I`02
0000000<05hO;P2gZ/h0EQ@P06DR:P1S8Rh0G1d]05`L;01N7Bd0M34j06l/=01_;c/0LcA40P1b<d80
9`1c=4<0KBdk070`?`1i>DD0OCe8084oB01k>D40MS8h07Lc>P21?TD0O3Y5074`@01g>Dd0MCM<07<c
A01l?4X0QdI@08U7C`27AD`0P3]008A0A@29ADT0PC/n074Y9`1M4Q80F@h:05/A4P1b:BX0LBT00000
0029_`00PkP00032S03efK80i;6A0000002IM8L0VF/002Q300020;:Zd`0405]WY@1^Ih/0PgJC0?SU
k0800000024008ji0000002I[L<000000=n`Z@3Q`JH0000007e0H@0L9aL0BP2@0;VUb`0004@0onOI
0?oHc`3`aLL0Vg2K0;^E/`000000]:K50<ook02?ai`0TVB90:ilUP2_Lgd0YfM/09A;B02>A2/0BP@0
08Dj001m<000HQ/005X0001g;@00100000003P1<TZ/00:GD0015GP1OX[<000000<GAg@3Oa<T0H7<]
0?g_]@1RHBl0`;1n035oRP00CUl004=E0P000000401TX[H0a>cH0<[Q]P3=diT0h]FP0=>jOP2nWed0
dk=i0>2jR`3O/XT0gk680>>hS`3O[XT0gk280=J/O@2VSTL20000000309N3/P000000/9o<00804@lC
00`0000006Q1L@2[T[P0aKgV0;^md`31h^D0aNSA0<_`hP36k>D0_]CM0=knm02Fck@30000000:08B6
_02H`M/0hn2b0=_DX@3lklT000000<3_o03gooh000000?ocm0<0000000/0b=2j0<GDZ03CdIh0iNk7
0>_jf03/on00i__M0<K_i@2chND004Z0002Zd@020035c@0C08S7a`1]/KL008B@0429V`1GVk80NKG>
08Zef`2?_m`0N[S905^Q/P1>Tjl0>GbT03UhYP1>S;H0FIbj06V^_@1[/K00HZRI0020D`1B000000`0
oooo000:0?ooo`h0000000@0YI>/000000000000FGIC300000000`0T01d0000000Xn9@0300000003
04HS<000000000000080000000<003Eg0000AP1XUhh0:`0000003`3kool0TJkF04/0002[00000362
05ei_01SP/<007bl0000X@000<h0XLG^0:kIm@00i?L0TLoY002]d@0206ffe@0W07Vmf@1FYkl0JKK;
08cBe000RWP0Uk7R0:?7k`0iOgT0FGfd06b@`@2;O:/0PXg80=Ooo`000000IZ>X0000001S:T00HBU1
00800000000009mk06<S<@1D5BT0IRXk00000027WJd0]lNm050B:02gZ/h0JR`n06<R;`1J6RX0Kc52
07LiB01d=dT0LcI70853DP23AeP0McY;0080LSI901l0Kc9507LiB@1o@Dl0PD9?08=3C`1i>TT0McI2
08E4C@2<Be80R4M@08E5D029BeT0RE1T07Y1FP23BV40UUe]09EHI02=Ced0S4aH09MHH@2HFF<0OCa;
07<b@`2=CEP0UeMO09]KG`2ACU<0OcTo08@oA024?T0005ac0080000000H0D`0L0?oQ^`2HTg800000
0=32e@3hjm420?oogP0W0;WJf`1PU/80R:_Y0?ooo`2[/XL0VVV8001LQP0G2`P0omc10?oRe@00j<`0
0=fe06/mJ02_Phl0000004EMW`2NS;T0002F0?l00000H@00IA4009]<002oOgH0i;Bb0;G5_`1m_JH0
Oe9o0:j@^02`T;H0^hnY09YRN@2ACED0WEA:09YA<`1j;`00H0l006hO001M7`00PCl90080C0001@00
00007`1?A8H0@e6F0017SP00hOl0@7=10;O6W02kPV@0Xh=708eU3`37an40b>Ga08^he@0008H0EWjc
0<SWfP3Mjkh0in^n0>oX_03YejH0fL690=2_M@3L]XH0iK^B0>>lS`3ZaY`0jL:J0>>fT@3:XF`0UHLl
0000002k/m/00P000000302i^^`0EP1^05H0KP27LjT0Xj[F0;cGn`3?m?l0bo7/0<;[iP2hiMl0[]kB
0:;Dd0<0000000d0JP000000002`RJP0[:WF0?ooo`3^o=h0bkZ10>kO/`3oomX0S;CI0=Con@3gonh0
YkZf00<0000000/0fNo90=3R]03BgJ`0hN_10>cgd`3Tl/`0eNg;0<c^e`30j^40Z=[O0:cJd0030000
000@02QXU@000:T0Njjh001H001AJk00QI_B00AD@01EWj00Eifa05^K^`1GV;X0>W^W03MiX`1:TJT0
BIBK02=cJU@00000303oool000X0oooo3P0000001P2STjT000000000000B6A<09P0002<000@00000
00L0[W5N0000001G0000A`1J0000?P0006d0B02900D0000000<0;GnC0000000000000`0000000`2=
]=@000000000000C0000000300/0=@0`06<0000001D0000000h0gKVb05X0003?000000000760`01m
Tll009kG002Pa@000;P0Q[KS09?:jP00a><00000001`U08007RM00`0DjBi05n`^@2EO:00071g0:B]
e`32e_l0BB<c07j8P01QLZ80:ER?08YTTP22KZ@206H/?`0802YaN@1_=dd0Hbe6058K>01Q00000000
06TaA`1K8S/206heB`0?064W?@1O8cX0L3M>07U3F`1f@E/0EP0h05dK:01m?DP0KBhn06LW=`1/;3/0
PdID08]@H01l@EH0PDMK0080S5EZ02L0PTYQ07TnD`1j?Dd0Ocm;08=4DP28BeX0UeaZ09III02CEV80
U5QU09IHH@2<Ced0NcmC08]CJ@2LIGT0UUmc099IKP2DFfd0XFMe09mRK@2@DV00SU=W09]SMP2RJGT0
WfEb09AGI02?Df@0RdUD08a9DP29A4X0RD=508Ho@`000000I@1j0::cZ@35SX/0FC9T08A5E`36lOd0
0P2EF6T09`20A5d0000003Q6A01:RZT0U66007e6I`1]=5L0D@0h04<0>01705<0099d05nFQ@3HYJd0
^9=o0000001mLZd0Vg>?0=gJi@00000001d009Mb003Y`[L0i/>I0:bbS`2eQj00VfnD0:J2Z02mWKl0
[9O308=VV`1`>5h0SDMD0:5JEP2[I540Yf1009eG;02=AQP0M38006T^000208H0000W05/J00150000
00000000000006`0IVjY051FV`0hD9L0;dB>0000O01_PJ80aZ^n0>S9W`28KB`0l_oN0>Ooj@3Koo@0
LXbk0000XP2fcM`0j_;90>g[_`3ekL@0kN>d0>;CW@3B^gl0fkf60>?0T03Q^XX0i/2E0>NoU`3ab:H0
ekN30=;0fP3@^MH0MV:I0<o4i`2QT[h0C21F0080Ne^:00T0]:cI0;70g`2fgNL0[]kJ08o8_@15R7L0
_>GV0;_4W@1<6d/00P000000703Wd<l0d<WM0<_0gP3ceo/0b=Gh0=3Wi`3Ehl@0fn6h0>OR[`3oom<0
EhJg08^ne02?c[/0LHI30:_4SP3Djl/0`=6N0>?`bP3Dik`0fNRm0>GabP3YmM00ho7:0=_X_P3Gkll0
e??L0<3YfP2Sel`208g6^@030;??/@0`Li`0=GRN0080000000T0Bg2^06b`Y`1j_;P009RL001IK@00
JiP0Iio700200000>@00E`00000<0?ooo`002P3oool>0000000607nS/`000000?P00050000220000
9T5I0P0000001@0n0000W`00000000000000Q@0000h0000000<0Keal06]cGP000000:P0000003P2b
RZ00oooo0?ooo`2>X9H00000001XV`00Q[l00<S_003OmP00T8l0M9;506bVf000/MX008ZO0P000002
0=kUo`0W09R/eP2CW/H0WZ?60:6QbP2/^n80]MCa07N[^000LY40GUf807ae/`00X`00IRm60000001e
?U80JS=;05@J<`1H8C/0Hbe806TaB@1T:d40GB<i06@]A`1W;D<0J2m805LK<`20BEd0Nd1B06P`B`14
02`0LSmM06h`?`1/;C`0GQh^08=2AP2RIVX0V5iY08QAIP2@FFh0OCm<0080LcYA01P0HB@j05LE9P1Y
9P00V5aT08mBGP2;D5l0VV9c09QNK02CF6D0T5=O08U<F`22@e<0UU]Z09iWNP2II7T0VfMo09]WOP2O
K880WVUo09QOL`2QJW`0Yg620:9/O`2OJ7/209QOLP0=09]QM02EFVd0Re1U0:9WM@2QHFT0UeAK08i;
E0000000WemW09ACG`2>K9`0VUma09MLKP0208M9G`0W08M:HP1m?TX0Se9106d0001Q0480A@0G064R
@@1T9dD0IcQU095US02?JID0RDmY0:AUK@2HE000cIB402T0000_0000E`0000000000;V<0BX2K08^n
a`00JU<0aYZ^0;R>[02lWKl0_Ifn0;jN_`2^V<@0H49o05ddJP2KKI00[fm`0;E`H@2cKU80Yf4k09aF
:P2DD1l0P4L00080T@0002@0QP0007<^001N000000000000601oV/d0G6j`03]GW@00080004b@0000
0000U;00IIB50:SDYP3co]P0l?oQ0?Ooi`1SDY00003F0>_oo`3ionT0n_oF0?SbbP3]ikX0h=NP0>?A
W03^eZT0nMjh0?7EZ`3[bYl0k<VP0?_L^03NbI80OWX[0:80[P2nYLT20000000Z09MhY03<`>H0c<3V
0=7Lo`39hO/0_^OR0:SIb02Ve;L000000>D0003F0000`IZi0=X0o`33hol0]=Gb0;GAl`3=f?X0l?3o
0>Koo`3Qool0h?o_0>[oj03WjkP0ooo^0000001VW;00X=6f0:2fNP2nahd0ko;<0=72R03olLT0h^:e
0>CT]`3Wllh0joGA0>[bbP3Qi[T0gNk60=Oad@27/8H000000P24_L<01P2VelD0X/RU0000QP0009X0
SZ>b0<35[0<0000000@006n]0;bL^`13PY/0ZK]oF000000<0?ooo`002P3oool>000000060400002<
Ig/0RI:_06@0C@3Rc=X0TY^n0P0U0000101k08L008J/002:Y@00[;X<0000000504/QC@0000000000
00000000EdT00P0000000`00>7<0JW2J09nY[0050000000305>AX01DCT@0000001`0000000`0YP00
00000000G6/0000000dAL`29/Ll0076=001GJP0oK000/]kL09K5dP2Q_N020000000409jWd@1/N:X0
00000<oTo`80bmoo00H0UkoP06nPaP00PjL006^50023W`1`VYT2000000050:bKTP2Ud//0Ic5906di
6`3VmmX00P000000601R:3`0Ea/^054G;`1A0000FALM070dA01Y<DP0HP0004D0001Y0000<P000640
001<01h0EAX_08A<GP1`?EX0JS9=08mCG`2dOH40Y00007L0000Q0000O0000;X000802QTF02L0G@0l
0<VQ^P2f09H0O@1705dE0028B000Z6a/09AHIP2IGg00UEUW099BG02KGFD0V5eY09=HJ02HG6L0W6Ij
09]WOP2LJH80YG>:0:elT@2_PIH0XFj609eYP02PJh00WfUm0:A_Q02SK840VV=k0:=[O`2RK8400000
09mVN@2[LX00PT950:IUB0000000XFAa09IIJP2?DfT00P2HHGT09`2DGGP0Jdf10:000034Ti`0nMgF
06`jI01b@fh0OU=o08ELR020E840OUF408QRS`23C@00M3<0080o0028MYT0Vh2:0;ZDK@00^Gl0/J76
06f<T@17P6D0f:^d0<fP/@35ZlX0`:C70;bH^031X<00^:?;04HcN01fFi@0SVVE0:ASKP2VI600_7UR
0;moGP2gMe00VeLX09QJ000207U0000W09US9@25F@00T54008]H001eCP00001D06Ah^01CJ:/08SF1
0000L00008L0000006jX^`3Dool0n?o[0?obeP2RL980Rf^N0000003?nol0hOo[0?[oh03emLh0knZn
0>[N[P3XeJ80j]BT0?KS^@3hi;d0m]nf0>K<V@3XdZ00e/Z@061/00000000WHfm07QPU`2CT/@0ZK3J
0080a][o02L0eO;o0<k`mP35k=d0^nC>0<_T_`3Pl<d0m_kW0?oom`3dlOh0g?co0=7ao`2ng_P0[<g^
0:76j02hh?80aN_g0=;go@3UooT0kOo^0?7og@3^ll@00<c20000YP00`KL0^]>T0>;S]P3[h;@0Q:=Y
0?Kib`3^ikd0d]BO0>CabP3_n=D0i^Zo0=kU^03OkL@0hng507Ic002FX0000P3Cmnl0302oi]00N:Ik
00000000Gh80CH^J0000]000/P0007d0001@C`003eL0[;CK08[6^ET00000303oool000X0oooo3@00
00001`1FD8@0YJ_;09Zod01HIiX0V:OA0<_AlP000;d00P3J0>/00`2B0:/004aX0000000800000003
05D000000000000000T0000000<002QT03AZS`21]<<0900000003000LI000;KC0971]@000000W/cQ
0:O:hP000000Ij2>0000002meNX0000008b[_P80000000@0E8R]08:9]@2B`=d0Vl?T0P2L`n@03@2U
akl0R;V/09C:dP1WYKP0Ci6T03m200000000;A/:0000001`?5@0H2Y40??ngP3coml00P000000602S
0000RffC0000002=CT`0VF5/05/N<@1Q0000R6nJ08iNJ02<0000ISQK07mCL`2MMH`0XWV?07eCM`1e
Bg80NeAi0<6HZ@2XN8X0EBA906TbC02SN8l0ek>o0<VOZ`80R01M00P0M01J09M[RP1D03L0O01R09m]
O`35UZ40TeMR09YLG`@0000001/0V00000000027A4P0R4M:095CF`2GH7@0YFem0:MaP@2OIg/0Ueme
09YSN@2LIgl0Y7::0:IcR@2QK8@0Wf^409]VO`2II7`0Vg>>04<000000000]YJR0=^eUP000000XfQg
09mTM@2YLXH00P2FGWH00`28CV/000000:^B``020000000R08AIQ@2FKiP0VgRR081KR`1bAG@0Sg:Q
08Y`X021D@00X6n>0;R1T@1HN[D0^?7/0>[ohP00X640l<OD0=Nid03O_</0g;Zo002O[`00HhD005Eo
0:nKa@3:a>H0Z[GQ000lO@000000FbmR091EJ`32PGD0ahQ`0<R:I`33QE`0]gI=0:MV=@80Q4d002L0
MSX008aC502SN@00Rd`007L00000000002if06Ed]00c@X`0002:02E;T@0005d006NU003oo`3amo`0
m/K60;V6W`2gT[H0002:0000003Gool0kooV0>kke@3]l<L0kNk40>_X_03Vg:/0k^6b0?W[a03ok<P0
n^>m0>g?X`2dU5<0D01/0::Mc`2HQkT0PXJo09fbh02^`>X00P32fOh04@3DmOl0co?]0<W^gP3;kM<0
d_3B0>Ooi03^ool0l?oo0=Gho03En?h0d?7n0<CRo02fdoH0^M_d0<3Yo`2jgO@0d^Wo0080oooo01@0
n_oQ0?Ckf03]kLP0bM[A0000R@3Ll]P0knc50740S`3booH0jocI0>;/a`2obHl0gn_00>_je`3Um<h0
eN>e0>;]``3=ej@0UJY/0<3Q0080doGQ00h0Z=>`0000000000000000000OA`00000003@0001B0035
WjD0`;o10000@`3EcIl0d=6S002105L00000303oool000X0oooo3@0000001@0`Eh`0I9k507Bf`01K
XZ/08Ua300/0000000D0N@0002/000000000E00004P:8`060000000306MCR0000000000000H00000
00<002UM000oJ`24DP00900000000`1SWih0_=_d00000002000000090<;Zi@000000000000000000
WK/0A8>O0000002=A380001g0080002j00@0X<Rl00000000bM/007ah100000007`1X<DT0CP000000
00150000A0000000002CN9d0Z@0009j1X`2HJ7`0LcaC07Y6H@1b>U80HSQN09V1Z@2`Vkd0[96b08ml
YP1mKI`0Q7NW08aTQ`2:HhL0PV>=0:B?]02aTk40RU]i07QHQ@2INIh0bZo509adS022Cf@00P25C680
9`2:E6T0DB5909=SO@3<WjP0`HnF0:ehQ01nB680000006Q8M`2VXLh0WH^e0:ZI_@2oZ<L0_96N08X0
001m0000Q3m008<0001Z0000MS0^091DIP2IH7<0XfYi0:Q_OP2WL880WV^509i/Q`2VMY40YWNB0;R<
XP1:FYD0YZk>003oo`3oool0oocM0=O9T`2XKh00Yfio09aSN00208mFL@07091IM@1lLZd0b=Cg0;cG
i`000000FWAR09YbVP020000000508IHP@053@P07U<c0000002UMYH00P0000005`00EUP0omK>0?oI
eP3gd^D0a[cJ0=3=gP3H`kl0gMgo0028[@00RkL005f20000i`0009/00<oP00000026LJH0fK?20=n^
Y`3NYi80hJf@0=ZTQ03<TFh0`X=L0080Z6Dg02L0Xg@`07e3001k@000Vf8V07P0001[0000000003YA
V00W>XH0;D6;02U4SP000680001I001k^02WUlH0^:C>0;n>Q@3;YkP0W8Fe08N6_@2_dO00eoWb0>_o
g`3Xk/80j>o40>chd`3bm]40n_390?o/a`3oj<@0n=ji0??U_P31/WT0T@2^0::McP2UWLh0Z[7O0:be
hP2^_^/00P34g?l04@3Al?@0doKY0=Keh03NnMl0hocP0>cok@3cool0m?oo0=koo`3Zool0i_oo0<cY
o`35fol0e>So0>Gjo`3AgOl0e]co0080oooo01@0oooX0>oba03[gK<0imnb0=OBY@000:/0?C5h0;gL
oP3GoOl0dO?O0<GXa`3DiKX0d]VV0;;BZ02c`Kh0gOK40>Kba`2fai00Phk7002Uc`80_>OO00<0<68Z
0000000000000`0000001P1MWK@0T<G@0:fV^P2`g/l0]Mfl09o;Y5T00000303oool000X0oooo3@00
0000100004`0IJJj05NGU013OgT;0000000907L0001e0000LP0000000000F8l0Fdml08IjTP0c0000
IhMN00H0000000<0>`0006]A000000000`0000000`00C7H004Uc0721000S000000070=S^f@000000
000000`000000000OXN^0:bVWP02000000040;c?^02g^i<00000082e_08000000P27EbT80000000O
0780001aB6`0NeAg08ANO`2HM900TGBJ07E8J@2OMi<0UVn>07E?M@1iF7h0R6VA07iMQ`2LPJL0Y8fb
0;VS`P2aUKD0YiFk08AaX01jJY/0LUR808ecWP2HPZ`0THBc09^5[P20HH`0T7bZ0:ZF_02RRJl0RFJ=
08mYRP020:R1W00W0:1hUP27Hh/0X86T0;nI[`30Tj40/8FM07@nG02CJX`0TXVh09^JbP2GQkD0[ZG>
09bEa@2IPjh0Od]D09EKH@1h0000eJNN0:l0001n0000SDQ607/d=023@Dh0YFeo0:=YM`2[Lh80/Wj@
0;23W02dRJ<0^HjV00000000C8<00:o;003_m`000>/0W`000:D0002PJ7d0WFN00080UV>20`000000
0`1]/[T00000000000030000000N0?[Dk@0000006P0005/000000000aiNQ0>:l^@3ab[L0o=Fm0?gB
_P3cjOl0aMOo09[6f@2^`mL0f<K/0000002b^^H0anGo0;cNn@2]anh0/MOV08]j/@2VTk`0UY?;0>Jn
c@3oh<T0omk10??=/@3S/IH0ej620P3<VF/09`1lD`00XW0008]@4@23B`00SDTN0<:=I026IP0003N1
02XoRP0^@Xd0EVRZ0000L@008W0003R20:^biP36b_L0/l7P0;bX`@2eZMD0cMOo0?coo`3hool0looi
0>W_a@3Uk/80j__F0>gog03aomX0mO_H0??cc`3cn=<0jOO=09[;[P2bW<D0YjCD0:NQd@2b/]l0[[7O
0=?So`020=Kao`080=WjoP3Oo^T0gocT0>;mhP3UonD0j_o_0>comP3dool20?ooo`0M0?Soo`3Rool0
a=Ol0<3An03QiOl0fm;k0=;Oo`3[ool0oooo0?gon`3honD0mOOC0=;EX@39cYL0f=b]0000002@Zl80
`^cP0<7Ze@34ilT0fo3@0=OV^`28ZXX0[/O:0>goi03@fZ/0X;Ij0:B>/P39ioL00P0006MU000000`0
oooo000:0?ooo``0000000@0:bLQ0?kOdP00EH@009b/1P0000001`1dAVL0000004X]<03:Th40^jn:
0000000007800`0000001@00JJ00JHfo09c1g@2dgN40Q:=j00@0000000@0a[Fb0000002H0000ShP0
0`0000000`2TRk`0<Rhm02T10P0U0000000309^KX`000000000000<0000000<005Ed003>c@2^dL80
1`0000000`2>]Z<0GI^K000000040000000P09@0002?IhH0SFfB09]mWP2TS:l0TgZS07YLQP2@M9`0
XXBV0:R<[`2SS[D0U8Jb089]V`2ANZD0Zi_10:NJ``2TSkH0[Hj^0:^9Y`29JY<0OfJD08UgYP2RT[/0
ZiW009b9/`23IY40SgRT09:0[P2@P[80PV^J091kZ@2KS;P20:bG^`0W08YaWP2ANJH0[9[20;fVaP2c
SjX0UfV509aZPP2jU:d0^I2X09EbV030Xl00aK3?0;:Uc02<N:L0WXB]09QnZ@25EG40S5Ua0812D02N
L8l0_XnO0=h0002UJ400UE1308Y<G@2iQ8l0^XF@0;9mS@2XN9<0Xg:?09eXPP2VMY40YGB>0000I@00
06T0W<oY0=Kol`38gZL0WVb80080R5=c00<0RDm[07XoG@1j@F<0100000000`1`<dd0@Y:M0>bh`003
0000000;0>6ja03ZjNH0kooo0?;oi`3Yekl0ekFY0>c?[@3`0:<04D1G0>k6bP2hUK800P0000003@0:
0000Z=[K09[8h01aHD80YWnL0;:C[`2IUlh0/J780?ool@3oonH0onO<0>o3[P3U]IX00P3M/h@09`3@
/gL0YGD00:Ea=02EHb00T5`K0;ZZI`2AU00002Yd02DnR0072Q<0NhO300h0H00:8g4000QH0:Nnj`2k
d?h0XLG/0:nmi02S/=l0Z];o0?Koo`3oool0oooc0?ocd@3comL0hoG@0>KogP3YonH0jooX0>goi@3U
nm40^/jF0:BJbP2fZM<0[jOE0:ZVe@2f/]h0^K[/0<7Dm0020=Gfo`090=[no`3Lo>`0hOoX0>?oi@3U
onP0i_o]0>GolP3RooX0f_ok0080oooo01`0n?oo0=CUo`32c_P0c=Ko0>?oo`3Uool0f_[o0?ooo`3m
ool0mOoV0>gkeP3Ji[/0dmFQ0<G8SP00ZFh0OJS>0:KCcP30j]X0bO7W0=Geh@3Lm=D0dnJk0>;kdP2a
d[l0VL2C09:SI@2@Tdd0_<Vb0P00T01U000000`0oooo000:0?ooo``0000000<0d55I0;00001ZS7h0
1@00000207UGO004085RR000000000000:VON`80000000P0Mgf[09^_e`00[M@0JZG=06bXc0000000
>gnZ07Vb^0H0000000<0LUJ30:BJZ@000000600000000`1lS[T000000000000@000000030:[0XP00
000000000080000000<0L[[@09G9``2if;D00P0000000`17?P000000000000080000000R0;:L_P2`
W;T0Z8j_0:B:[P2IP:L0YY>i0::=/`23KIX0P6nM09V:]02bX/H0]ZC50:2=]@25LIl0QgFS09j>]`2e
ZLl0X96l08QiZ029KiX0T6nE09=dV@2DOZX0W8fi09F6]02COZT0R6ZE09=jY02HQ;00XY:m09Z=^`22
Nk00Ui2o0:2HaP80RWj`02L0RWJU0:>B_02_Y<d0[Z7908mm[@2>NjX0WXZd0;2J_@2KNZ00[Hnb0;nQ
_`2eRj@0Zh2L0:=oX@2SSKL0TgVU099hYP2VTK/0^:750<BYaP30WkX0[GF10<F?R@3O[YP0^gid0=:T
Z`2dP900[GJ70:YdR02XMH`0[WfD0:MhU02EIHD0Uf>00:9^Q`000=T001T009UJJP20@5H00P1_;dX0
6023@eT0QdYR07e0G01i@V<0JS1C054C=`1E6Cl0MC=<08<oD@2Z0000Ac0P0000003>c?P00:>W0:?[
h00000000:>L07L0002506T0`m_X0=oOk`3md=X0aYR_09imZ@80000000D0QVME0;9mTP0000000000
0<CAn`02000000060>o4_`3ooo80oo7F0=jXVP3T/9d0i[JJ0P3G[G`09`3;ZV`0^8a<0:Ac<P2<H1P0
Vf`Y089C3@1iG`00JD/0000ZL@0005L0@eRO00P0D@0O;g`002mm001>RP1aV/d0TkcU09Zli`27XMP0
TkOU0<OHo`3oool0oncN0=CR^02eg/00an[=0=gheP3UonT0jOo[0>_oj03]on00V[9f0:fJaP2o/=P0
^ZWB0;RYd`30]=/0fNCo0=kjo`020=ChoP0B0=Kjm`3Ino40goo/0>;oj03TonH0i_oZ0>Won`3Zool0
k?oo0>koo`3eool0ho_o0=SIo`2ob_80a]of0<_Ro`3Hool0dmgo0P3oool04`3lom/0jo;=0>?Z_`3;
cIH0^L640:>QH@000000U/[<0;SVfP2mjN00`N[K0;GQb@2Tb:@0I:Ja08:iY@2D_Y00OJ=d092VK@00
NdP0I`00000<0?ooo`002P3oool=0000000506@00000000000000000=`0W03800P0000020000G003
0000cP2`_[P0000000<0000000D0001o0426Z`0cP9d007>H0025XP090000000304]fS`0000000000
00<0000000<0IWJa000000000000:P0000000`00078000000000000=0000000;08io[P2JUl80RWj/
09Z5[@2VS[80ZY>f09J0Z02AP:d0U8jl09V@_02TV<400P2FPjd05@2BNjD0UhVe0:RMa@2ZVL00UGfV
08EdY02;NjT0TGj[09R3[P2OQjl0V8B_08eiYP2<M:00WHbh0::C_P2VV<80XY6k08ak[02>PK40Wi?1
09b@_P0208f0/P0W09jFa02[XL/0Z9g80:>G``2HRKL0Xi[80:>OcP2JULH0Uh:^0:RD_@2`W/D0[92e
0:R;/@2`UKT0ZXfc09j7/P2GS;h0WY2o09j@_P2]Ukh0V6jA0;n6R035Rh00aHYe0;aoL@2aLg40YFQb
0:=ZO@2QK8@0[7V?0:mlTP2SL8T0TEim09QWQ`2IHW`0V5Y[08];GP1`;TH0MSE;0080SDiR01d0Se1S
0810EP1T9440EPlV06lX>`1f=e40Ld1V09>2T`1YOFd0`^WA0000003X`/P0i;o80>6ja03M/KL0dYnP
0<R>R@3@V8/0ikV_0>?4d@000000nP000<00002n]mh0b;gP0=:cb`000000ZIjb0;ZS[00400000006
0>oE_03NdkT0k>3T0=VZ/03N[J00h:j@0P3EYGP06`34V5d0^X]>0:j2@02hRdh0TfDO09e[:@1`?000
L4`00000000006@003f70000PP0oCiL0001j02QHVP0oN:d0Kj??07j/f@1nY]T0R[?P0:2ni`3Cc^40
`/:U07Ni/P2;b<`0]>CZ0?ooo`020?coh`0:0>3oj03Qo=l0RjAX0;f[d@31/mT0^:cE0;fegP3Eeol0
iooo0?;oo`80hooo02D0g_ok0=com03Noo40iOo_0?ool`3ion80o?oo0?ooo`3kool0lOoo0>Koo`3M
mOl0eN?o0<;<m@3oool0f?gl0<[XoP32`>D0oooo0?ool`3onM@0k>k60>WZ`@3GeZ<0`Kb00;JcM000
0000002a06BQ]@28`l800;RY03]oH`1f/jd0U<_106BRQ@0nPg00>GaR06T00000303oool000X0oooo
3@0000001`150000PJ^;09fn[`0003D0001307VA_`0000000P1o000010000=/0HYZ10000003VfJ`2
0000000304M`U`000000000003L0000000<010T3000000000000100000001@2;^Kd0000000000000
0000ICd000`000000240MFfO081hZ@2AOj/0VXF]0:J@]02TRJh0]:7409f;]@2?OZ/0UH:]09^9/`2F
R;@0UXZg09R9]@2JRkH0UWjW0:>7ZP2KQZl0X9:m08IiZ`2@P[40Uh6[08UbX02BOj`0VXVe0:FJa@2T
VlL0WiG209:0[P2COjd0VXVf0:6D`@2IR;H00P2JRKD09`2PTKd0WHZf0:B@^P2OTl40XYO40:ZSc`2`
Y/l0W9;109N=_`2UW<T0Yig:0:NF`02_V/80X8Vd0:B<]P2iXlL0]:O?09F=`028QK/0RG^_06mFS028
LJ00dZbg0?K>b@1h;Ah0]GM]0;f2O`2iP8D0]XFJ0;:4W@2UMI40VVR609Y[S02FIHL0QeAg08A=J`22
AV40QDa[09=KMP0208U@J`0B07<fD`1M84<0JcMO07a0GP28Cfh0RUf305aVK00VJTh0`N_o0?ogf`00
0000hkc20=jh`P3O]l00h[c60=ng`@3FZ;80fjRQ0P000000103>Xj/0aJ[90=3Dn03Fd>X200000005
09]kZ@29/9X0/ic20:ZH``2@00000`0000001@1m]L`0045^0:2G_P3V^;80j[fV0080ikbH02L0d:M_
0<2>E@36UEd0XF/00;B8002=G1H0X7D0075N0021C`0000000000H`0NBXd000240000PP13Nk40@Gf`
03mh[@19O[D0OJSH0569^`1n[mL0Q/?205jMN02AcLX0Q/?B0<[_o`3oool0ooo`0>O_c`3=l=d0a>[@
0;SP^P30^>00^k;J0;Zhi03=cOX0fn[o0>;oo`3/ool00P3Uool01P3Vood0hOoe0>;olP3Noo80gOo_
0>ooj0<0oooo0140nooo0>7oo`3Gkol0cmgo0<GKo`3Wool0coKd0:S=h@1QP[/0`/OH0?clf`3ooM@0
l>g60>[W_03Kej@0b<F<08bRJ01d000000`0oooo000:0?oooa40000000<0001Z01ENQ00000000P0F
FXP00`0XK6h000000000000<0000000300007@000000000000T0000000<0B4`d000000000000;000
00000`0V0000000003@V:@0;0000000Q09b4ZP2=PZl0R7RV09Z8/@2ST;L0YHfb0::;/02DN9h0W86W
0:></P2WUK`0VX^f09V;]`2BQ;40Sh2^08eo[P2WUkl0Z9W209B4/@2:O:`0Qg^/08akZ`2IR[L0UXRf
09jB_`2YV/<0X9C009J7]@2DPZl0W8bh0:6B_@2GQkD0UX:`0080UhBa02L0U8:a0:JD_P2gY/`0[j7:
09nD`@2QTKh0WHVd09f:]`2MTl80Zj;>0:NOc@2RV<H0[J3:0:RE`02`W<<0[i_20:FD`02^Ukl0WHfl
07AYX`1iKJD0Ui;50=KBn@3^eNH0il350>:d/03CXjH0a8nF0;j=W@2eRJ80YgbM0:5iWP2KLYL0RU^1
07a7K023CW40PDUZ08eCK@2>EWD00P1iA6T01`1_<eD0K3]V08=NS@1i>eL0SeI`0::K``1ARfH00P00
00005@0]NVT000000>6d]03M/KD0hKW00=fb]`3J[kL0fK6o0=FX/03?VYX0bXn10=^USP3P^jh0km;A
0=c1c01F?g`000000=>^``3F^M@000000<>Yb`02000000070:g8h0000000000000000000CY<0_92L
0>JhW`020>RnU`0W0=fnR035WEl0cIiX0<nOL01oB`00/Ha609mf;`23IaH0HDD006Yi;`000000039k
024mR00007<0001m001?Q@0YGi`0=g>V04b2^02Ka>P0N[7006:RQ021`;H0RLO=07ZicP1m^m@009:F
0<K4XP14RVl066E;0=31h`38_n@0`[cT0<W4j`3De?l0g>Oo0=oko`3Tool0h_oo0080j?oo01T0joom
0>SomP3Uoo<0h?oc0>;om03Wool0looo0>goo`3Zool0k?oo0=ooo`3?i?l0`MKo0;?Fi`2/fLh0YmSD
0;CMjP1fWlX0HW>[0?oom03oon40kO7<0>GX_@3@e:00W:UZ07D00000303oool000X0oooo7P000000
0`021@T00000000000030000000307/e000/7@00000000@0000000<0HGP0000000000000:0000000
0`1@QG/000000000000=00000080Qk731@0000008P2aV;T0X8:S08]_U`2=O:T0TZ3o09j?^02GQK00
VhRa09F3[P2RT[X0Zi_30:VH_`2UUKd0VHbh09B9]P2ERkT0WIK209fE`P2JR[H0TGf[08mn[@2>P[80
UXnn09RB`@2AR;T0XiW40:RKa@2NSk`0TXBd09V9]P2OSkX0W8Zf08mm[@2AOjh209b;^00W0:2E`@2^
Y<h0/:7:0:bI`P2UTkd0V8Fc09n8/`2/Ukh0[Io90:nTcP2UV/P0WIG509bFaP2RT/00/:;;0;:Sb`2T
S[T0Y8bg09J0[P2BP[@0WYg>0;boj@3:dol0bk?D0=BX]03DYJT0`8ZA0;InQP2_MH00Y6am09MQN@2<
EgH0LceP07]4IP2>Fg`0ODIX07m3H@26BF@0Pd=K0080Jb]600H0KBa606P0?P1=0000@00005H0001o
JFl60000000K09YYO02TJfH0Nc@00=V/]@3EZ[L0cinZ0>>e^03/_[@0olRi0=^NUP38SX`00000030a
O`3L_=00h[k?0=foe@2gT[<0^YBc0;ND]P1oX<d00;K906i?R02TU00052PW0000002]MHP0c9J70080
g;2000T0j/JJ0=R]NP3BYFl0eZ]h0:f:AP29GP00ZHY108Ag9`1F>0000P0000006@0025H0846:000m
Q`0007P08EfE035WXP0cLZ8008nd0027/P2o[LX0Ql;004fCR00ZN780A8jL06JZ_P1QZ;@0DifF000n
003Lb><0fLWW0<g2i035^Mh0blCZ0=KFo`3^lol00P3oool06`3dool0jOoo0>Woo`3Zood0joog0>go
m03YooD0jOog0=koo@3Nool0gOoo0=koo`3Uool0gOoo0<oUo`3Ej_l0e_Km0;_Ug025`LL0P;O604>0
X@00/Ml0lood0>;hg03Plm<0f^c70<;GZ@1f000000`0oooo000:0?ooo`P0000000<0^LkB07/00000
00005P0000001@1Z000000000000001kF000]L0000<0000000<0JenC07]b[0000000<`0000000`1@
=2400000000000030000000309N2[0000000000000D000000280SGVR08I/U`2US;00ZIFi0:>A^02F
Q[40THNe09^A^`2LTkl0X9W40:6Ja02MU;l0XI>n09f@^`2MUL40WiO409F>_02=Q;<0Sh6a09>2/02C
QkH0VI2n09jHa@2ESkh0SX^m09NC``2QUL80V8^i09:5]@2JT;h0UXjn09V?_P2HS[d0VI;20P2QV/L0
9`2SWl`0WIG40:JKaP2STkh0VhNd09V6]02^Vl<0_jc>0;RYcP2aY<h0Zio:0:VNb@2PU/@0W9;20:bS
cP2TU<00VH>b0:JA_02RSk`0Xi2n0:nYe@2i/m/0Z9k?09UhX@2VM8`0[WF109UGH029A4`0NS8g07/e
>`2GEeh0RE5^08eIN02AGWh0NdEX06`fG@1f>UT0PCmE05@?:00205006P0S05d0001C0000FP0009UQ
GP00U@00on?C0<><T`2RGEd000000;=bL`2oPGh007Yk002/a@3>W@00Yg800=R/]P3:W:`0cI^S0>Bd
/03``[P0omC:0?oAc@3P/l40GgNd09R9_038/<h0a9ff0<>K]`2WLXh0^XbT0;NC]@2hX<X0ZJGF0000
000@00000P0000003@32Y/<0jLK30>BoTP3T_i80h;f90>2hQ`3G/7X0dZec0<2OGP2jY000Vh@h08Ic
8`2JQ3T00`0000006`007f`0>5fP001=S`00J9d0000002ESV@075b80V`00072e]01FVhd0MkZn06f`
`01;TJT0:GJ;04a/003Na=`0h/cU0=_3g@3La]h0c[SH0>;6f`3Nd_P0i>;o0>Kgo`3iool0mOoo0>Oo
o`020>Goo`0A0>Kon`3UooD0j?oc0>Oom03Woo<0fooc0=Kjm@3@mOP0coGf0=3io`3:lol0bNCo0<SY
o`37k>@0a>K708c6^`28_Ih00P0000001@00E6P00:jY002SV02XeL40T;bE07H00000303oool000X0
oooo3@0000000`2E]LT000000000000>000000030=SNo`00000004Io00D0000000H0000:0000@P00
08T0V`2Y06h0001a00110000000R07i[VP2@P:`0YIFk0:69[P2QRk40ZYNl0:fRb@2RVlH0WiW50:FO
b@2NU<00W96m09nC_P2PUl<0XY_609R?_02BR;L0THJe08f5]P2BRk`0WIS609nJb02NUL<0U8bk09B>
_P2GTl<0Thfn09J<_02GT;l0VIC309REa@2CTL<0Ui7209JCa080VY[:02L0W9_;09NB``2HT<00Vi;1
09nB`02SVlP0Yj3=0;:Xd@2bYLd0/JK?0:nTc`2ZX</0ZI_60:6Ha`2WWl`0T8:d0:6A`02YW<T0Wi2o
0:NC_`2dY/l0ZiNo07aLS02?K9L0XWRG08YDKP1n@eh0WFIl0:=ME`2/JF00Y6I[08a>G`1lAFH0NDE[
07<oI`1S;UL0GR9704@0:P1X04D00P1L03T07`1L9U40FQe20;REY`2[Yhl0aIZ?0<b;T02XJ7<0/75g
0;QjN`32Q7d0ahei0<>AJ@00<bT0W6D00<FFY@3G[:H0Z86609>2/`1`ESL0dIV40>RfY03KZj40a9BN
08UYV@2:JY/0[HFV09eXQ`2SKhd0]8NS0=Vic`3F^M400P0000000`2I0000Q4US0;^I^0020000000=
0>3?f03ddjh0m=>^0>c;W@3WaID0h;n90=NgOP32XF00]Zm[08Yi:P25MBD0The003a000020000000K
0019SP00CHl0=VZU031ZX00007h005bD000lJ`00JG@0CiZH05ZRY01Y[[d0Fj6a06N/X@1IVh@08580
0=o7h03F`^00dl;Q0=Fog@3Ia^<0h=Ko0>OWo`3Ykol0j?oo0?Goo`3Vool0i?on0080hool0140h_oi
0>3ol`3Poo40hOo`0>;ok03Oo^X0f?WZ0<W_k`2ninh0]N3Z0;?MjP25_lL0FIjQ08_4c02<`kH0W/ZX
01D75@1m000000`0oooo000:0?ooo`d0000000<0MhJ30000000000000P0000000`0j00008`000000
00060000000404@0002i^]h0_L_?0;GMkPT0000000H0000[000000000000Zk:n0>SF_P1YK`0^0000
000308ZNN@000000000000/0000002D0?6jC000000000000UHJa09b?^P2JS;H0WX^c0:nPa@2dYl/0
[ZC;0:>G`02OU/40XiS209fA_@2LTKh0XYK20:^Pb02MSk/0]`000964/`2ISk`0UHjm09JC``2OW/`0
TY;308n8^@2PV<@0YIk909FB``2DT/80THjo09RFa`2OX<h0XZGB09ZNcP2>SL00W9_:0080VYc=02L0
UIO908b<`02AT/D0UiO90:2Ib02UXLl0XJ7@0:ZWe02c[mT0[JSC0:>LbP2NTl<0Y9O50:RLb@2UWlh0
VY720:2OcP2JULH0SXJj09nD``2YVL@0T7RW07]QU02FR;T0SWRZ085UV@27HXl0Yh:V0:b0U`28AdX0
RD4l08a<F@29C680MSQD05TK?P1P:e@0G@1>0780L02FNJ800P1Y;4l0902?HH@0bk;80;G1aP3ga[<0
bIFO0;B2U`3<YKT0bYf/0<6:TP36RX@0^7EZ0:USF@2YHeh0]WA`0=FoZ@000000RHFf0<bV^@2iNWT0
]75S0:USB`2hN6L0^7f50;N;Z01jAFh00000091@I@2PH6`0`h^<0=V^]P0006/0ZZNf0000000S3Q40
^XfR0=G0iP80000000`0glW>0?3>Z@3`cZT0j/VK0>cAXP3VbYL0glVC0<6RH02?SCl0^jIQ08Mg9`25
PS<40000000J00`kO`13Mjl0=72R03EfX`1RVl80082U06FZ]01c]kh0IZbe04B>Q@00ED/0aiFZ0?oL
jP3ae>L0j];Y0=c7hP3Ibn/0g/oa0>WVo`3_mol0k__o0>koo`3dool0l_oo0>;oo`3RooT20>;om`0?
0>?om`3Too@0i?oc0>Gol`3Wonh0j?oX0=cki`3;knP0^>CU0:CGe`2;aLX0WmCC09S?c`27`L/0Q[jg
07l00000303oool000X0oooo2`0000002@2bi^<0NH^X086j``2@Q8d0K2DO09n:TP37_Zd0A00000T?
A00203eFP@0809jB^03;/;`0nLg00000001D0000Uk[L09O4c`2HcL8<00000004000j0000J@00X;2i
0;nYU0H0000000<0JdIe0000000000009@0000000`0lL4l000000000000>0000000R09n?]`2BPZh0
UXJ`0:ZOaP2aYL/0/ZW@0:>I`P2SU[l0X9G009nB_@2LSk`0WYG109nF`P2OU/40002W0000002HT;l0
W9K409fHa@2OW<X0Vi[808b9^`28RK`0UiO709nMbP2KV<H0U9?409BDaP2KVl/0XJ?A0:2Oc@2DT<40
R8Nk09fNc@80YJGC02L0UYK808j=`@2HVl`0TIC609FDa`2YY=40XZ7@0:ZWd`2`ZmH0YYo<09fFa@2L
U/L0YIo=0:RRc`2UW/`0WIO709bHb@2GT<<0TXZn09NDb02DSL40P76X09J<_`2ESL40QgV`07a/Y024
Jil0V7j/0:V>]P2`T[L0/hj]09QRN@27CFP0L3=C07A2J`1jCWX0LDj00;^Ub`1NE9800P00;EH09`00
CE0005iW0?oGh`3mb/l0fJo00>6ic03PaM`0a:S20;B7W`2gOXP0[Ve^0:YVI@2YI6D0^WmW0=:aP`2D
K000cKWH0;FK_@2C0000/P000:mZFP2UGD@0Udi408Q2CP1a<4d0KJ:V0;j<XP000000GP0004/0001=
0000OP000<O=o`00000007nM001iS@1@T:40?00C0<`0NP020>c=ZP0:0=^jQP3YfZP0j]f[0=c>U03<
ci<0TX`m0;6TG02P]780KfT008Qe00@0000001<06TR<04=l[00oOJP0=72P06fVaP00O80004QG02Mf
NP33XkX0n<oE0?oVlP3of>H0nMKV0>kBi@3Ze>l0hmGg0>OLo`3`i?l0m_;o00@0oooo0140l?oo0>_o
o@3Wool0iooo0>KonP3VooH0i_od0>?olP3Non/0kOoZ0=Oac`2liM40VLk008S3^`1a/Jl0FYjQ03Ak
MP21000000`0oooo000:0?ooo``0000000P0TkSA000000000000Pk?E08Fhe@2Rc]D0G@0004X000<0
000000D0`L[G05IfQ`00000054Y]01iXOP0A0000000308U7B01gBR80000003d000000280W8^d09R7
/02TUkl0]JkC0;Rbe`2^Y/d0YYg50::H`P2QU;l0X9:m0:BJa02QVlH0WIW509>;^P2HRkL000000:JS
cP2JVLL0XIg90:JQc02VX</0T8Zk08b<_`2ATl@0UI7109J<^`2CQkH0VYC40:FSd02LV/T0UY7109B<
_02HTl<0Xj7>0P2TX<d09`2ETL@0UY?509nNcP2=RK`0SHg10:BVe02`[=H0[jK@0:RPc02VWL/0X9W8
0:FRd@2SX=00YZGC0:RUd`2SVlX0VI7309F;_P2HT<<0WIC609>8^`2APkH0WIO908Ii/026NK40Ng6/
08Al/`2`Y]40^;3I0:ZMbP2JP:h0SFNC08=MRP1nE880P5nA08=]Y02LT;l0XHjl06eMV@0208NISP0W
0:nXd`2l[]H0gmCk0?;Hl@3olo@0l=[I0=35iP2cYll0PgRR08IGN02bLGH0^7Uk0;UiL@2jNUl00000
09MH001D0000K00006D0002QG5h0/6]O0:]UEP2PETT0OCQ807TgD028Af00RdYR07D0A`1g00000000
09]eWP000000GF1J0:SMj`000000LYS909AE002;A280eKjH0080ko3500X0iNRh0=kJY03WgZ/0fm6F
0<70O@2NVTh0YIY?09:TGP1GD`00HfL00P0000005@0V0000NS]@08E5E@0MFi00F9Ri000?5@00mOl0
AHVU0:P0MP3_0=d0oooo0?oho`3/fod0kMOb0?oQn`3oj?l0mmgh0>cKoP3_iol0j^_o0?ofo`040?oo
o`0>0?Soo@3aoo`0j?ok0>Son`3WooL0hOod0>7olP3Ho^/0bnoQ0;ORd@2Wel40QK^N05FGP`0aNW>4
000000`0oooo000:0?oooa<0000000P000220000[0000:`000000:gNk022`/H0HIV30;[=i@X00000
00<0OP0009<000000000>`0000000`0ZM7`00000000000070000000R09N6/@2LSkT0]:kB0;fig02a
Z<l0Z:390:FLaP2NU;l0WY:m0::E_P2/W/D0Z9k70:>Mb027PK<0SX^l00e>P@2XY]00UYG409REa02L
Tl00VXnm09bA_P2OU/<0UY7108V1/`28PK@0YYc70:jXdP2WXLd0V93009>>`02GT<00ViG509nKb`80
X9c<02L0VYC409fGaP2MUL@0T8Ff09bHa`2NX]80UYO909bGb02[XLd0ZjGB0:NVd`2UYM@0ZZ[G0:BW
eP2KWLh0Qh>i09J?`P2KTL80WiO809N@``2?Q[X0Uhk109B6^@2;OK80Rgjc081i/`28Ql00ZJKE0:2@
`02HQ[L0Rg:U07QBPP2AJYH0XXfh0:FJb02NXm@0UjKH09:leP2<_Z000P1lUi`08P2j_^L0d<oi0>7L
o`3YeoX0ooom0?ooo`2/dZT0BhB>0000LP000000KWl003Pa000D=5h0Xeh009QD002gMeD0[6I?0:P0
002A0000UTe@09=;D02>A4L0VU0i08<lA`2CEW40UEaj091AK@25AEl0`Z2/09^UaP20QkX0000002X`
?@00=`02000000030?oo0038W`00h=NR0080g>o801D0dN:b0=[R/@3XhZl0gmJM0=?>TP2QWe@0TX/m
08VEBP1/M000KWhc02l0000o02<0NcmG08mAI02bNhH0cIbP0=:RY02lQ8`0SU]h00P0002nY/X00P3o
ool02P3oj?l0mMcf0?[To`3ol_l0on_o0?[OnP3ni_l0onco0?[^o`3bo?l40?ooo`0<0?kon`3coo@0
jOo`0>Wol03Oond0doKY0<_ah`32jm`0Zmc;0977/@1^ZH`0040QQP00000<0?ooo`002P3oool=0000
000302PN0P000000000000@000000P2VRj`00`2?XHP000000000000;0000000409MLJ02XIU`0Xf<o
014:3aL0000000<004=Q000000000000:`0000008P2OT;T0ZjC;0<?3i02d/=D0Yig60:bSb`2LTkl0
Uhbi09R<^@2SUl00/:;80;6TbP2XW/L0V8fj09^Jb02ZZM<0YZ3:09NA`02AS[l0UXnn0:6Lb@2FT/80
Uhfl09^B_`29Q[T0RHg009jSd02VYm<0W9g<09bLc02KW<`0TXk009ZGa`2SW/`20:2Lb`0W09FDaP2E
TL<0Sgf]09R4/@2fZm80[J_G09:Ca@2EU/T0XZ7@0:j`g02//Md0Vj;C0:2Xf02^]N00Rhc208>3^`2?
S/<0U93409BDb@25Ql00RXNn096@aP2=R;h0R7nf08=g[`2DSL<0TI?909fLc`28Nk80Sgb`06]<Q01b
D8D0WWbV0;RD/P3B/<@0Xk?E07^TZP1o^Zl0K:JB00800<gK01h009:b08ZOe02V/>X0kmSe0>O7e@3O
^lT0f;h00?7K^P3Dcm<0]l;/0000T00IFP00000007DZ001V7`00G@l005<0001b0000UE4V0;=_G`30
QH00c9VP0;AdN@30Q8T08@0000000023@4l0gJfG0;jeX@2Yd]<30000000604H`>0000000a=_T0?oo
o`3Hij/00;`00P0000007`3Bl]@0i_GC0?Ogc03Jci@0^KUe09jOE02@VDh0TIM<05U`000/00/0A00O
06@S>`27AeH0a8fA0=JVY@3I[:l0bin_0;Z=Z035YlX0/Z_F0?GSo`3onOl0ooO`0?oKj03beNX0oNCo
0?o[o`3/fol0j]Od0?obo`3oo_l00`3oool01@3nool0oooo0?ooo`3moo@0k?o[0080h?kV00H0eoWT
0<__g@2nim@0W]6m07JaV00aM5N8000000`0oooo000:0?ooo`X0000000D0<gVI0000000000004aDC
0;?Cb@0500000080PfbG3P0000000`2LLh/0^H>80<F<T0020000000309<0000W0000000004400000
01T0]ZW=0;fhf`2i/mL0[jO=0:VPb@2WVl@0VX^g09^?^`2IT[h0ViS60:bRbP2aY/`0Yig70:2E`@2W
XL`0Z:?=09nB_@2JS[/0Ti7209RHa`2PXm00SY3208n?`@2JVl/0X:WF0080TIo@00L0VJ3@09^Nc`2G
Vl`0SY3408^3]`2HV<T0ZZC?0080WIO702L0Ti;508f;_`1eN[<0YX>W0<6kg`30_>80YJGC096Hc02Q
ZMP0][oX0:nghP2RXM00[Z_G09bKb`26PKT0S8o608J:`@2@TlP0WYg?08nCb@26Rl<0P8O108F7`01l
N[H0QX>k09RGc02EU<T0PGni07ab[@24Mjl0HE2=08a^WP2cTkL0aJ6j0;^BZ@2l[<d0S[^D0:F5WP3o
i=l00P00eL800`00S6d0R8^D06mf[`020000000J0:ekT@2dP@00m]fl0>k@b@2jY<L008Zo0000F@3G
X[X0dJ?00;fTb`3Reo<0onoL08M40021?@00Xf4e0:]]EP1L<eT0^7Ul06<0Q000TH@0Ib0j00000036
W6X0SHY?0;k@[P2h[;`30000000504H000000=P0003o0<;L/P2>X5`00P000000702cgN@0goK]0>[j
g@3BeJ80Z[5[0:F^IP1nT4H0N8@f0000001D01d0JB@b08a7B@2VIUl0^gmc0<J>R`3@Vi@0gZbV0?oE
f`3`g_l0e<gl0<Voj`3Ud>h0lLkL0>_;f@3ed]d0omg/0?gLk`3`enl80?ooo`030?Soo`3^onT0foKJ
0080goWO00@0eoGM0<_]eP2Mc:d0O[FERP00000<0?ooo`002P3oool>0000000306`0000000000000
00l0000000H0B`000000002>Q6400000002R/P00cL<4000000030<D0000000000000040000000280
`KKF0;^be02dZ</0[9k40:^NaP2PT[/0WY6l0:NOb02^Y/d0XYg909FC`P2ZX//0Xig80:2Ja`2UXL`0
VYO409NB`P2[[ML0WZ7?09nVe02OZ=H0RHk208V@a02SYm@0XjSF09RQd02<UlX0RiG809VOd02FVld0
PhNm08V4^02QXLl0THNi0P2/WLL09`2QUl@0QHZo06ao^03@kO/0`<o_0:ngh02KYMD0TIc?09f/f`2^
^>80XZKE09:?``2YWLP0Y:3>09jQdP2IV/d0RH_208bCb@2EUl/0S97708jDbP27Rl<0OH>m071g]@2:
S<@0T9C:08n?aP27P;P0MW2]06=MWP1LEIL0O6>I0:5nY`2GHX40W7^80000003AWHH0jMGC0>nh^`02
0=RUTP80000001d0KfJN00000026Gh`0YFf>0>fk`02fP5<0^XVM0;^;W@2i[6H0c8n<0>g80000d?H0
0:[F0:oGbP2_d;P0c<^/0=ZcSP2:?`00QCP008Xl9`0K?Eh03E9006lX?`2kPi00k[bc0?;0Y02eMeL0
I00005<00002000000060:9eT`2G0840;P0d0000_02bfl0000000P2I`^4070000000aN_l0=7dj`35
i<40U:m]09F[IP1hTDP0AVPQ0000001]9cD0Lb`e08a6@`2RHE@0/WAU0;UlL@2nPWD0a8Yj0=RRV036
TIh0XgNJ0;bH]03J^/d0k<SG0?7=e`3leM`0onCW0?oTk@3okoh20?ooo`030?goo`3oool0oooo0080
oooo00@0m_oo0>ooo`3^onP0g_OG0P3Pn=X0103JlmL0[]B_08BfT00PFBV:000000`0oooo000:0?oo
o`h0000000D0P:6h0000000000000000002PI00;0000000507Y0D@1_00000000031fL`00E0001@00
000010063AD0000004Z?/P1:Ujd4000000030?GJe`3Od[H0000003X000000280blGS0;:XcP2^XlX0
/J?80;2QaP2QU;h0XIS30:ZTc@2[Xl/0XIO20:JQb`2]Y/h0Y9o:09nMb`2SX/h0Vi[809nPc@2Z[ML0
XJKC09jTdP2LW/d0QXRk08^Eb02W[]X0Y:?@0:>Sd@2IWLh0TI_=08nIc02AUlT0O8>j08B9_P2CV//0
QW^`0P2d/m/09`2`]Mh0ZkWR09JZf01/Sl40RZOC09j/fP2UY]<0VI7009ZYfP2KZ=P0R8Fk07]k]P2]
ZmD0/k?N0:Z]f`2>T<H0RY3708bHcP27T<L0SI7709>Fb`2=SlD0QhNo07Qn^@1lPkh0QXc508Z:`@1o
NK<0LVbZ07A^Z`1ADIH0ETV;07eSV01O06<0000005I:R`2>L`00k]CQ0=bfb@020:QdR00A0<fO[02m
SZ00Sg2M09IjZP2EL9/0f;?C0?oio`3h`l00O2l004D00000Mf40M5]E0?oKfP1L8aX007fR0:GId`00
=FT00`0000003@2AB`00FP/009I<;`2TGU/0]GIk0=BJT`3KXY@0dYF40;=^H02YI680VUIP0;V1S@3K
d?P00`0000000`27Q000fmc?0?CJi`020<C6h00I06M_Y000Vl80IZFQ07^^O`2M_hH0O9aI076@BP22
Y6T0K`0008m:BP2LFUL0`HMf0<VBNP2lP6T0^7aX0=FRUP30Q7L0XEmB07P_9@3=Wj80j/?:0?kHi03o
k_l0omg]0?o[o@090?ooo`050?7onP3^ooT0j_od0>_ojP3To=h00P3Jl]800`2mgKT0Pk>903=/@02;
000000`0oooo000:0?ooo`/0000000D05QD[000000000000000006l0000200000003001RLP000000
000000P0000000<0001a001GO01WBVH03@0000000`00b]l0]`000000000F0000000303R6UP0cPID0
000002@000000280/:W@0;2Xc`2]YLd0Y9[30:NJ`P2_Y<X0/jkE0:^UcP2SV/D0XYW40:BMb02XX//0
[:C<0:JUd@2VZ=<0YJOC0:V/e`2/[ML0XZ;>09BDa02CSKh0YZ;>0::UdP2EUlL0UHjn0:VPb`2YZ=@0
VZ3A096Jc@23Rl00PHJl07^:`@1fOkP0S9310P2hbo009`2jbo00XJKD0:Z]f02AUlT0K8Nn07Z3^@2L
V<H0[JOB0:^li`2M[]`0QY?:07n=a@2N[=/0][cU0:>SdP2;S<80WZ;C09NOd@26RL40RHk608b<a01n
N;80S8Ro08N1^@21PK/0RX[208J0^@1]JjX0MW:^07]i]@1IEIP0?D><05]EV00W05T0000004E@V018
06@0CP1K0=Jji@020;VRc`0W0>KEmP2nV[<0RUn607=5L`2jUkH0dL?d0?S`o`3>Z/d0IF1T0:ALA@2J
DCD0TWnW0?oG003mb;/0f9jI0;UmPP2THVP0001<0000Y@000000NSl00:5a002oSGd0M2X009=;002^
VLP0YEe:0;1[F02dKf<0]g=]0<R<QP3BWI<0gLKA0;cJn03Ej^<0hno>0;h0g@3]eZd0lkBU00<00000
01L0Y[[A0<[bh@2hgkT0U;Ae06B=CP0gH1d0S;F20:ETE02hNV/0b8mn0=BQS03N[iP0iKZR0>:eY03L
[:40g:bW0>^m/`3hcl@0llW20?oQgP3oo_l0oooo0?o/o`090?ooo`060>Som@3YooP0j?oj0>?ok`3K
n>00b^_>0P31i<D00`1]WW4000000000002;000000`0oooo000:0?ooo`T0000000<0:`000000001;
04800P0000000`26BU@09@L8000000090000000500P000000000000000000000DgP0CP0000008P2a
Zm40[:K>0:FNb02OU/40Yj?<0;6]e02f/MH0Z9o809jD`@2SW<L0Y9[60:RUc`2c[=80]:kE0:FRcP2R
XLd0Xio;0:NOb@2RVLD0V97009^C`@2[[MP0U9G507mo]02KV<H0^[?H0<2lh02g^^80TIS;07Qn]@2I
V<P0VJ7@07^8_`24Wll20:g7k@0W0;kHn02@TL80Vi2n0:FQcP2K[=X0EgB`059JU`2kc>h0_=Kf09Z^
g028VLh0Oi?:07nDb`2FX=40UhVj0:NMbP2/Z]L0XZ?C08N5_022QKh0Lf^V08Mo]P2BR;d0QWN^092;
`@26PKT0TXJl08Ak]01bL[00MWNc06IRX`1=DiT0@TVA028[M`0Q:WL0?TZC06I[[01@0000f>So0080
iO_o01<0cmco09f0Z@0005H0U0000=2d``000000V@0006E3M`2>FF/0gmjn0;MdG02SFd<000000<J6
O`2QGfH0RTYR08i=GP000800001S008000000180h[_@0?^mY@3HXgl0`XEe0000002^J4h0]j5n0;NT
Q@3;SH<0aHAd0<>3L02T`n@0X=7O0000_@000;@0Qi:6071[NP000`430000000H0<?SjP2Xf/40ZmF]
08>GF02N^h40c/2K00000033R740bI5i0<bEOP3@Vh<0cIMl0=JTR@3AW8T0f:JF0=n`Y03kdL00oMG4
0?O?`03og]80oo_g0?o_o`3onol0oogo0P3oool0103on_d0ooom0?ooo@3oooD20?ooo`060?[ok@3a
oo40iooa0=gli02khL80Z]Jg0P1eZH:>000000`0oooo000:0?ooo`X0000000D0=10m000000000200
TfZ6001VI`0>00000003000o00000000000000d0000000D0Yi6c0=O>b000cK800:N?001S9P0k0000
000R0;>/d@2b[=80XYg80:BOb@2/[MD0ZJ[D0:JQb`2OV<D0YI_50:>F`@2XW/P0[:cF0;NaeP2eZm80
[jK=0:6C_P2PTkh0YIc70:>Ja@2PVLH0XZ;@0:Z]f02PX/l0PhBh09>Ib@2Z[=H0_KoT0;foi@2RW<T0
K6fV0:2A]`2ZUkL0Ti2n07bCaP80X[_U02L0Z:O>07]UV02<OJP0`<KT0;G<k028Wm00E7Rb08jhf@2H
_N00R:3B07F;a022W=40IX6k07:6`@2CU/P0ZK;O0:^]f`2VVlT0TXRl07Yn^01^I:40PGjg08N2^P2=
Qkl0UI;707mk]@2@S<40OWfh07an^P1aLJl0FUJI05YNX@15AXd0:Cn80000Q`0a?hX0Si;90:6Fa`1h
00000P0Ml?l03000b?D06@0007MFPP2YQhH0/8eD0000D@20X[40BSf00:>0Y@2kUj80[faT0:5JE080
000000@0N2TT0;AiP`3;^]X0Z0000P0000004`2[dj/0eJo30?ooo@3oomT0oM>j0>k@bP31WG<00016
00`?H@3DXJ80`8:00;9]J02ME540VUMV09mRO02_OI`025aa01m^QP000`400P000000602@[=40/nCO
097:Z`2Od[<0YM6V04mh=`2Z]000i;NT0<bFOP38T7P0b8mi0<B:M@2jOVD0^gmU0;b0K03BXHL0i/2R
0?oH_`3oflP0omO60?oEa`3of/d0llkC0?oRl`80oooo00<0oo_o0?omo`3on_d00P3oool0203oooD0
ooo/0?oog`3aon<0i?gR0=3`dP2RcJL0MJZ30P1UUfN>000000`0oooo000:0?ooo``0000000<0001b
00000029Ji000`0000001`3@`j80000003LSC@0g8dd0OI5k00000002B6X05@000000103;gn8008fB
0017AP00J5@^0000000304B8W0000000000000X0000001h0]ZgA0;J_e02YY<d0[:SA0;2]e02UXld0
Wig:09^Jb02FTl80XZ3;0;fgf`2c[]D0WYW60:FG`02[W<@0Xi6k0:fUc@2`[MD0Yio:0:jUcP2c[mL0
ZJSD09bJb@2AU<H0R9G80:B^fP2g_^D0YjC@08Al/023Kj020000000[0:N2W02JW[X0PI33086@``1X
@V/00000082WY034j?00]]C]0:2jh`1SOKL0Mi[;0:Flh`25ULX0MXW309BYfP1kTLP0=4F;082Fb`2A
YMH0RYW=08bAaP2KZMT0QYS?06UVY022T/T0IW:_08R:`P2>Rl<0Ngji08>BbP1eNkP0Lg>a06UTX`1N
Di@0GUFF04I5R`1?Fih0001Y0000O@000000Sfj=07h000020000000<001@U@3?h[X00<O_0=SFe`3K
gK<0c>C/0;_Yo`00000008Bk08MGL02cMGL0dijJ0P0000006@1FP4<0c9BI0;EmR@23T<80/8V^0000
000K>8800`4301bJb`3oool0oooX0??ca02iN6l0eij<0<:5I`2;R[/0_J:i0;R<V02bV;T0^oKJ08Y=
F0000000RG^f09J[f@1hX6`00P3_ool06@1o/mD0Y]G:0:kF[P1][Y40EXeI04n7J`21W@00Y9g609aL
F02PGTd0Xf1@0:ARCP2[JU<0/gAK0;f2IP2oQfL0f;B80?[E^03oim@0oo3N0?oLd03jd<P0m<W00?oU
f@3oo_P01P3oool0203ooo/0oooc0?ooi@3Ulm40e^k<0;OK]@1mZGT0IYQYT000000<0?ooo`002P3o
ool8000000030<_</000000000000080000000<0SgJN000000000000G@0000008P31]ML0^:oC0:FG
_`2YV/80/:360:jSb@2XZ=80VY_9096A`@2JVlP0/ZcC0:RLa@2NQjl0Xhfe09N5/P2RT[`0`L3T0:JV
d@2LUlD0[JC<0;Rbf02a[mL0Z:WE0:2Mb`28S<00YK3K0;6fgP2BR;P0000004DmN`1fP;40]LWO0?g`
`02WWZH207n=`00W079ST02L/M`0^=Oc0;W4gP2R_NH0W;;N082=``24V/d0T9_>08fAaP27Ul`0Vk;P
07>>a@1cSLD0PZ3B07^IcP1SP;/0LH[2092ZfP21WM40P9W=08FYf010IZD0O8_507Yn^P2HV/h0Ti;8
07=d/@1PH:80FTj@06mYY`1OE9D0SH2e09nIbP2BU//0001d0000A@000000Of5I0080=Q`0014006VV
09N=S`00V/h0]KcE0<R[]@38h_l0kNSo0?SEi`0lA8/0Vk3B0<40/`38bJh00;nF04j?Y000_]00jMNm
0:U[>@020000000@0:2KL@2`h<l0?6FQ01]5S016O:l0[LoO0<SWl@3NZI/0d9VC0<62N@1XPKl0EH>^
07ND^@2H[]d0^/WV0000]P80000001h0Y@000=Coo@3Cooh0doon0::ia@2Jc;H0002406fXP02_[[d0
_n8009][K@000000M00009mKB02WId`0^GiN0<B=K@3CYX80fkF?0=NgT03D^XP0f[V=0?oJ_`3oi=@0
omgI0?oJf03ohMT0on7D0?oUeP3ol^`40?ooo`080?ooo@3hoo40kOoY0=ohg@3Dk//0`=fd0:C9V`1o
XVVA000000`0oooo000:0?ooo`L0000000<0Q[O90000002Tf^40H`0000008P33]MD0YiNn0:2;/P2^
V[l0_:_<0<Jlg02n^mh0Z:?<0:2Kb02LVLD0W9[7092<^@2?OJT0[X^X0:F8[03;aNH0alOZ0;2cf`2>
RKP0[J360;Zae`2i]md0XZSE09FEaP2QVlP0YJWE09REa02<LIh0U8^h0000A`24PK8003<V09O1^`2Y
c_D207>;`00W07fMbP2Tb>X0bmgm0<[0gP34doP0ZkgW086Cb01lU<X0QYK:09RWe`2J/Md0SJ_J06j:
`P1VQK`0IXc108FQd`1jU/`0LiG:07VNd027Y]L0JiS405ZA_000Njl07cn506ak^@2GW<l0TXo407Q`
Z`1KDI<0G5BE06a`[`1OGj00P86j07UYXP1V0000>01_0000001JOK<000010080DWUm02L0000008BM
d`000:D0C`1<0:5LH02FCdl0L3/c0=^oeP2@0000II;403QnS`000000B@000000001PA800foKV0=S1
WP3IYh<008QT001YG@1^;`00V7L00000H@10GZ@0_:[D07Qj]P3S^[80ejBT0;Z4U@3Z`]40l]c50<6h
T`2QRI`000000000L@00Tf/00;VC00000037lOh00P2aanH05P000000NIo<08:m^P15M000`=o<09IB
E02RH5`0_81e0<bEQ@3?Uh40b9=`0<6@I036UVd0dZ]o0=o7V03ZhkT0j>6e0=o9V@3kekl0omg<0?oh
h`3ooo820?ooo`030?oon@3on>80oooe00<0oooo00L0oooa0?7oj03To>00gOSO0<[V`P2fe:L0Z<RG
09800000303oool000X0ooooK@0000004@2`Tk00UgjV0:RA]P2kZLX0b[cI0<g1g`2i/=@0W8fh0:BG
`@2OUl@0Vic907V9_@1lS;`0RXfh0:2Rc034cO@0alO[0080000000l0]i^h0;ZefP2o`^L0X:_H08bB
a@2DVLX0TYo>06eBP@2MKH80bjBd0;JZb@2I[mL0U;kO09Zmg`2S^N000P2@X=@09`1cV<D0H8nl04AN
W02ndoH0`m_l0;;6k@2>WLl0Mi?807RLc@26ZmL0QJWD08Raf01dX<`0DX6d04=bZ@1CNK<0LiC707ZR
d@1`W</0HY32082[d`2=^Mh0MJC?0000M024Ul`0K7Zf079[Z01jLj`0I6BU06ee/`1WMKD0DF6U05AQ
Y01ECY40G4V:0180B@0009h0NIS<08Bbb00209ElW00W0000002RanD0Jj?00000C022Mj40f;:f0=K3
h03bc=D0000000h00`1o0000T@000=T0003^ek40SGXl095XU0000280_kni09NBRP3EW8`0OgBL0000
0000WK8000000<W9m01:LTl008]90=JW[`3__[`0onOM0?o5^P3ARgh0kZRE0?oNd`0006P000000640
0021^ZH0Q[o30080ZmC_01H0ZL3Z0;K:gP00^`00^=fd0>BhfP3ol_l0omS>0>o4]03S]Z@0hkRN0>2g
U03DZh00bZ1`0<>YM038^h<0f]f^0>k^b@3kl/l0ooGD0?ohfP3oonH0ooog1@3oool02P3ooo/0oooo
0?oom`3kon/0jooQ0=ofe`3ElMD0`=nh0:W9V@28ZgBB000000`0oooo000:0?ooo`h0000000<0K`00
0000000000003@0000000`0QLi4000000000000:0000000306D_B0000000000003l0000001`0Xhnd
09j7[P2l[/l0`[SI0<Jng@3;_md0/Z760:2B_P2_X/T0/ZW@0:j`f02L[=L0PIg<07BGa`23XLl0YkgY
0000001a@TD0FVi^0;K<k030co80a]Ch0;6li@1nT/H0M9K707nLc@000:40/8ZR0P000000103>_kX0
Nj[?072A``2S/]l20<CEo`0W0;CBm01nW/`0JH_007fRb@2]eNd0VKSR09VYf@2a`>T0S:kG08>Xe01[
UlD0K:3606bSa@1>RZl0<VjL03ifYP14Oj/0Ah>Z04V5[013PZL0>GbN03AeW@00QkL004R401LmPP0k
JJ80Nh6l079n^P1JKk00JG^j06ek^P1@H:@0DEZO03hnQP1?A8T05`1A05Ae]@1YW;00II]c0080ZI=j
02L0JHc30:GFiP2jd;P0VWFP0:AaS@2IVL40THBi0?oIg03hgOH0f<_Z05ml002SK700g;:D0;NoU`1a
ChL0[8bb0=BX/03BVGd0cI9c0=BLQP3LZXd0j[nW0?CM``27J9D00>@00>6f_03IZk<0hKJo0?o?d@22
0000N`000;1aN02UGe`0Jf<00=Ski`000000Ujji002`XP1f>2000`0000005@3oj]P0[8D009eWO03Z
]<40ooko0?oZiP3oem00mlg40?G?^`3`cZl0j<^T0=FcP`2iYFX0/;Qj0<oEX@3al/d0ooWE0?oogP3o
oml0oooV0?ooj@050?ooo`0:0?ool@3oooP0ooo_0?;oj@3Tmm<0eng80<?T`P2ffK00Wl2=041[0980
0000303oool000X0oooo2@0000002P1/00000000000000000000Zg800=6]P0010080000009<00032
ZX@:0000000404VF[P0dQIh0000001eC?PX0000000<0ETl0058g00000000?`0000008P21NZ/0/:_B
0<S6j033`N<0]K3F0;f_c`2WT[T0YIBl0;>Qa03;_MX0a/;Q0;^if`2TZ=80WkGN086Nc@1oVl/0W:_H
07^7_00007P0003]0;S>l02lco<0Yk;N0:NZe@2a^^40ZkoW0:Boi@000;<0BHNW06nV_`1^UkD0OYS2
076=`P1[T<820:G3jP0C0:c;k02=ZmP0IH2h09:dgP2`cNl0PjSE07fLc01^Sl00amGo0;?<m@2A`=H0
KZZo06fY`@0000007VYe001>I`00FKl005QW001KD`040000000@000YF00008<06EN80000M01`S/80
AVVY05=/[@1ZM[H0GF^]04=:T@17Bi80@TJ>01`0FP2I/;l0DHBP00000080ZgN302L000000428WP00
0000W8k109A[U@2/R:l000000?oEi03h`LT0dZFb0;V>[@25O`00eJio0000001gI9l0Zi6h0;^Qa03^
a<d0bXiY0<fIL03P_Hl0oooN09X0U@2ca<P0jKV]0=JPW`3HYj`0gJf_07=PH`00GFD0?@/N08mOOP2M
I`00bjP00;NL0037ZI<004dg00Q7P@3<UGT00P000000602:F0000:800:Ro003E0000iKFc0?oKeP3o
c<P0olk;0?S?b03lf<<0l=Nc0>oM]03OcId0XJ][0:^mPP3NhK80mO;=0?oofP3oon80oo[Q0?onh@3o
nM`0oooU0?ook`<0oooo00T0ooom0?ook03oon80kOoN0=gbd@3?il00`n2h0;_GZP2:ZW<0T`00000<
0?ooo`002P3oool90000000:06`00000000000000000002[LP00dJf000400P000000T`000<:ZQ0X0
000000@0BIJ^03B5WP0000007E<n2P0000000`1FC`00DSL00000000o0000000R085jZ`2`Zm80b<KX
0<?1h`2e/=H0_Jo?0:NB^@2UU;`0/j740<^mfP36`^40^kWK0:BXdP2O]Mh0PIk=07nKb`2LZmP0NhNl
0000N0000>d0^<k`0;c?l`2W/]h0Yj[E0;6jh@2[_nL0Y;oU0000/`19QjL0KjJo06jG]@1nV<80LHg2
06^@`P80YL?Z01<0[<_/08f[f01UP;P0T[CN0;3=k`23Z=D0OIc<06j?`037eOl0/lce0970eP1^Z[l0
KJW10000000NJWD004iW001I_`00F6L005]C00@00000010002UH0000P`0IEhP0001d072>`P16JJT0
Dfb]06Yf]P1MJjd0@dZA04M;TP12AXh0701J09V`_`1AQ:0000000P2[Mh<09`000000@8RN0000002L
S/40U6^E0:b8[`000000omGT0?S1b@3BYK80^Hj]08Eo003E[Wl0000007MTW`2[TKP0^j740>k4c@3:
SVT0cIU`0>2mS`3oomh0VP2E0;?4b03Y^Jd0eZ2O0=RW[03M[Jl0Lf1S001MI@0m2ah0Semn09eW003;
Z000]i`00<NYT`00CCL024N10<bEN@020000000H08YH0000XP00Z;l00=D0003U]K<0om_F0?o<b03o
c//0n<o80?cH``3`ek<0kmfd0=o=W@2QZf/0Zkf20=kQ/P3el/d0oooJ0?oohP3on^40ookQ0?oig03o
onD0ooo_0`3oool02@3oood0ooo/0?oohP3]omh0gO;A0<oW`033h;P0^mNZ08ZZL`2C000000`0oooo
000:0?ooo`L0000000<00;2i0000000000000P0000000`33ZZH0G6eK000000020000000304l00000
0000000002H0000000<0>@00000000000000<00000008P27RKX0[ZcD0<?2i036`N80/K7H0:6@^@2T
RZl0ZY>h0:jE]`3<]Ll0aZW00<^ab031/<`0aLKV09FD`01nQk/0XZKB09VPc`2;Vl`0[[gT0;[9k@2[
^>00Vj;A0;6]eP2m_n<0a=?l0;K6k02R]=d0X;kO09Ngf`2L[mP0U8fm08bIb000000209FogP0<09_0
h`20YM40IXNm09:ggP2RbNT0OZk@05::/@0bKY@02EEL0000000bO8L0<gj63@0000003P004bl00000
0000WP0oLZ/08E2@02]=T01BJjd0=Cf604Y:T00i>X<0IW>d07ICP`2NIDL0X69F0P0000009`2fP9@0
U:000000000007P0WG2F0;RK_`2i[940cnCo0<Ngh@2gRjP0[h6P0000001hV@00000003lk?0000900
002Z0:^`_P3/_lD0V=3E0>konP000000]@310?35^@3Y^k40g:VW0<R=S`37S7/0ahaX0:iaM`00@Wd0
UG^[0=7/f02VdLD000000=Vkc`3ofm80]9nW028000020;80a00C0;2/002<`j/0oooo0?oojP3oh]40
iKR`0=n^Y`3od/00onOA0?ooe@3Ze:H0jmfb0=kFY02AZF/0`M:P0>SX_@3mmm<0oooN0?ooi`020?oo
l0050?ook03oonT0oooV0?ooj`3oooX00P3oool01`3oooH0o_GA0>_/`P3Bh[H0c^Bk0=;U^`2mdj40
U000000<0?ooo`002P3oool700000003002_c`00KWD000000080000000<0Z]7=000000000000:`00
00000`00Q600GP000000000`0000000R06EZX02RW<D0`:k;0;RN^@2PT[X0S8Bd0:2=]@2g/MD0d<WY
0<2/b@2GM980]XRI0<fV]@3@]ld0VWfQ095aU@2YT;40XiFm0:>VdP2i_>80`;oR0;Ncf02ARk`0TY_9
0<C?l@3@hol0^<Sc0:Vfh@2l]=L0^[CF09FGa@084@h0;V=B00000080M[3700L0K:C205^?^01MR;X0
Li_908Rod000000001TH01H0000000X0001;000eM`00EIP0:SAn04]6S00e;GH0MfbU0<2[``3BZ840
/7AT0P2XLH001P3odLH00000064`FP000000]J[D0=6fb@@0000001d0/8:R0<VYa`3F//D0d[FL0=7Y
b03ea:<00:Ja04@f=@3NamH0000005D0E`3oool0iKc50>Bg^03S/Zh0^7V00;IdLP2mO6/0bY9`0000
0021b>D008]j031cB`2edZ@0000009:TZ`00000001890=_Mo`0207F`W00E03AnJ`36f?l0ko_o0?oo
o`3Y`/H0o];60?ooi`3oon40ooo[0?ookP3O^i<0e;N40;nkP@2/`8T0d=f_0?Gcc`3lm]80oooL0?oo
iP3oooD0oooi00<0oooo00/0oook0?oolP3oonh0oooi0?ooo03ioml0h>^n0<_HY@3Gik`0fnVo09Fa
NP2D000000`0oooo000:0?oooc@0000000<0E@0007/0001WEXT00P0000000`0X000000000000000a
0000000R02<ZJ@2UUK/0aJc60:bB]02_Wl<0SiG20;NZc`2/]m`0Y[OL069IS@2jT:<0bZ:a0=2V/02Y
MXH0OTe]0:5eT@2lUJ/0a;CI0:BYe@2]]]l0Z[3H0;RdfP2]ZM80X[cO0<3Nm`35gO`0`]Ci08nPd@24
QKP0_;W408AeYP20WLD0Xj[300000080LZnk00D0C92J031eR00gLYh0000004R6LP0J00000008000a
L@0U6F<0G5NK03LQIP1jN;00Oho80<Vf[`3omm/20??8b0030?o;^@2oOVL0]GA`00@0000000@0W[gW
0:fegP2b_><0]kH0100000000`3Sb9L00;/008:;a@030000000:0>cho`3VaML0gKG10000002VS[L0
RDA<09<00000S000001P002FS`80000000H0E4X00:Mk000iP:8090P30:C@i01JWHL205RAH@0E0:RN
a@32c?l0f>ko0>WMnP3Wc^@0onCV0?oon`3com/0loof0=gUg03M^l80b:=_06^5@P3Hh;40in_30?Cc
cP3gm<l0oooN0?ooh`3ooo40oooj00@0oooo00T0oook0?ooh`3oon`0nOoX0>[oi@3Bh;80b=NU0<cN
/02hd9l0U@00000<0?ooo`002P3ooolc00000003002>V`2EaLX0000003P000000240KF6G08^3[`2W
`=d0]Z_;085BK`3>]/P0]k[=07ImZP0_4TT0a:[50=S1f02GMID0UFR50:1gUP2fTjT0dk;;0?OSo`3>
fOl0O:7708:Ja`2HZM40OkC;09W7g@1f[l80D7:X07EQT`2IWlh000000:Zj`01VUVh009>@05>DZ`1X
XkD00P1_ZkD01@00RG<00000000000000000HgRE01X0000000P08A<i0000R011Bi<0BeBG08RQe@1O
Q;`0f=Ka0?l00080b@0001<0b0000=JMT@3EWY<0omO20000001^Cg`0:3Z409?0gP2D`nH0U/;X09g4
k02ebnl0_mcY0:oPe037aYd0Z:AN000i001NMkD0JHMk00<000000140/ZOA0<>=U02YMHD0XXZe03h0
002HKTL003<00000002S_[h0DfjG00000000GX@0SHFf0?;oo`3iool0aOoQ08g6/@020:80OP0G0;=g
O02jS9@0bKC@0<2F[P3K/K<0hkVa0>FmZ`3OdZh0h?oS07JB]03aflP0a;b509Z[K@3SjKl0kO7;0??e
d@3do]T0oooS0?ooh@3oonP0oooa0?oom@3oooX00`3oool0203oon`0lOoO0=offP3ElMH0`^:n0;gF
Z032fjh0Tk=mU@00000<0?ooo`002P3ooolc000000030019A`000000000003L0000001405@i>06eB
L02JZ=<0S:WD03TgK`2^P8h0hKRe0000000h2340QFnJ0?ooo`3okO00RHBe0;>ni02?W</0J6ZN07mP
O0020000000;06fT``1HS[D0@GVS06FQ^@2CaML0Yl[T0000LP0623/0001e00000023^k400`000000
101iXlH0bnc`0<_/l02kf[h20000000303EcF`000000000001X0000000L0001/041EW00mBi<0U9k?
09^UcP2<S<@000000080/;J;00D0Zg9E0>Zo[@3[000007ZO001[PP020000000909O6g@25_Z`0GiVk
07NYe@2Vd^P0a>c/09fn[`2UbJ80cKZB00800:H001D0I7e^000000000000M`1c001HW@00GHD0^H>5
0:jB]`1K0000QGRX0?33g0000000]`000000000008D0j_Wo0;BM_P3KooL0_NkH076c[`0hN5P00P2j
U:/08P3M[[@0f:V]0;b7R034V:/0h[Jd0=f[W`3KZID0g@000=kQ^P2SZl<0000004f0C`2EW5X0i>Nm
0>gbc@3^mLd0k_oR0?Goo`3oooD0ooo_0?ookP3oooD0ooon0?oon@3ooo<0ooo]0?goi`3TmM00f^o=
0=3Zb030gkD0^MR/0;7AX`1`U5^E000000`0oooo000:0?ooo`l0000000<02`L3000000000000G000
0000602GJWL0RehY07AnP0000000dJJ_0<ZOZ`2GKXP0OF6:0;fnjP3Ghol0hMch08jB``3Xe]H0Z/WW
09VYe@1JIIP0WhT009k>a`2D_]D0OJK=07N@_P1dUkd0Q:_=07fOc@80000000<0002d000000000000
0`00000010000440K:Jg06bV]`00TI8P0000000603E6SP1BEY/0NgRa02h0002TUlH0cm[T0P0o0000
5P000000@3Db00000000000006JK05YNX`1SIjL0Q[C?07bf[@00R[`0FibW0000000411l0Hh:D0;oD
c03[e;D0dm8007:K001fU[h0@H2=0000001c08`2000000040000NP1X00000000038000<0000000<0
Z9NC000000000000100000006P1mIIX0e<ki0=C>n@3Ye>`0g<;H0=>ie03TaM`0moGo0?oSg@3S`J00
i>[>0=gB]03Zj/80a]^`0:2kQ@2SYfL0iNVn0>ked03Ddih0hOOF0=WkmP3nool0oooo0?ook03oonH0
oooX0P3oonh0203oon@0l?oM0>3acP3Ek<L0cNFl0<_R]`31g;00RjafUP00000<0?ooo`002P3oool:
0000000605D0002I00000</001<00P1CSgL0AbdC:00000000`1bHID000000000000:0000000308d0
00000000000002<0000000@0;WN900000030/ML0]ZgF0P0000006@37/L`0o=WT0<fle@2[Y<X0^kWN
0<cGm@3:h_/0`mSa0;:hh03P_KP0^;_60:ZdcP0eEi80L7X00000002/c^/0UK7J002BaP2LR:<006]o
0028Z`2GZl/0hmCP0<^aS@00@P002P000000102@TlH0000002830`1V;3DM0000000309X0002_[M/0
00000080ZHf_00<0Z7MW04h0002Q00000P000000100e@H`0K8G107j`f@3Bool30000000B0;fbg@2k
X9`0U68g0?GE_`39`@00dIVF0?KA00000000=28>07d0`P3>Ti40000001d?003j000000000980K@00
0000HP00100000001@3G[jL0Sk2?000000000000eM[o0080h^co01@0dmKo0=;4i@3Um?l0mooo0?go
o`3/ool0e]g>0;ORmP3ThnH0e<>=0=?DXP2gaXd0b<^D0>K/`03bn]D0l>_40::LH@2feM@000000>_o
o`80oooo00/0oooV0?ooj`3oon80nogE0>?bc@3Hk/X0d^W20=3V_@3=gk00a=NV06>4AP2F000000`0
oooo000:0?ooo`T0000000D0Ea0?05@000000A40004<09K<a`0F000000<0FJ>o4@0000000`1bHIH0
000000000002000000808W27;@0000007@00V[d0^;gX0;F^e00V0300W:790<cCk`3Nh_D0b=[g0;;3
j02U^^40k][^0>SOk`2m_MP0OGBT0:FK^02jPGl0M`0006igK00000000dd006bR_0000000FXJd03a^
S`00@3d0041=02=RQ00i1P00_]?l02/0000000@0WZ[L08En/`1eG98000000P2EX]@00`2M0000d@00
09h000030000000A06jFb`1o]mH0MjoE0;kko`2nkO@0000004P0H@2YQ:P0cjJh0>S5[@3Oh000_7aV
0;ao00005bd09aT:08O2[`2lQF400P0000001P310000S000000000000000W`2507H0U080000000H0
?8F907n]U000?a/00000092;`039c?L20=;@n`0D0=7:kP3Fe_l0j?oo0?Ooo`3^ool0gOgk0<GNi000
0000][J@0=S<VP37_hH0];n20<?8S`3GhK80nooT0?KmdP2k/g/0U5]f0:UdD`0000020?ooo`0:0?oo
k@3oonL0m?oM0>;/a03?i[d0an>l0<gX``3Cj/@0dN6c0;k>VYL00000303oool000X0oooo1P000000
0`0]02D0H5A_05=5K@1S0000000I02mPT024UlL0WI6k06/0T`2cd>l0Z<[W0;SKlP00_mX00:O;08JQ
c@3B]/h0omgL01NBYP1<AWT0I8Rh06JBY01`R5`0OZ9o0<S_g`2LcL/0l_oo04F3W`00Fg80>WRB04i[
A`020000000306ASH`1UR000000002T0000000D0001C086;a@1dJZ@0Fb]K0000Z0020000iP0@0:Bm
j`2Y]9h0Pi5I0<O?X@330000SUj806RLb00009@0001[07>]cP1WXHd0@`1=08QPT02hT:l0f[>^0=Z`
Z@80000000D0Y@0007]P00000000eYj:0<Wbh`04000000090800i`000000?01:08Yh>P1JE5/009J8
06fWP@000000002B0080000002<0^L?/0<G8kP35b>h0d=_k0=G/o`3Clol0bo7o0<_cl02oiLX0jM:h
0<gIgP2Uf]h0dnfo0;6aL@2[/g<0`lV@0>?Q]03nomd0mogE0??bcP000000QEmO00X72@3eool0oooo
0?gon@3goo80jooK0=gV^P3Dgjl0dn:f0=SY`@3Lkl`0g>Nm0:2fO02G000000`0oooo000:0?ooo`D0
000000@0B01>0640Q`1JVj/05U510`0000000`02;3l00@`A0:6KU`1N0000000E0022[P1@OJ`0V;kO
0;CBl02WamL007Qa001>FP00D8@0GXBd05Z;/@00_;L004iI02iXQ@1LT[@0QJK<09_3h02mfM<0d^cC
002NR0000000U/OF00L000000P0008l00`36ek006CDd0000000U000000050000A`15DiX0CdR<07ej
]@2J^NH00P000?T00`2gcOh0d>[O05jDK0020000000O06P0003og^/0omC:0?G9a`1RVP0000000880
T@2?MjT0fKWD0>S1f`2nX9P0/XZX00000038UJ@0T5Q;03`00036RGL00@0009:[001OO000Tde:08X0
dP2_d>X0J01m07f[N029XVD000000?oGa03U/YL0001d0000^`020000000H0:RjiP2ebo<0]L_c0;WI
mP2mhoL0_nS_003;b@00Ge<00;Nb0;CTeP3Yooh0lOoo0>Woh@37dYd0]KMi0<_>U`3]gK<0nNW50?oa
c`3om=<0onc?07eNM00T6b40ooKM0P3oool0203noo00l_oT0>Kab03Xk<<0f^2`0>;X_@3[klT0`/nM
V000000<0?ooo`002P3oool;0000000301Xl>0000000;G5a060000000100U<Fi0000001hTl80b>?o
02YE0038f_d0000005^=[`1b[[`009VW066F^01RVk@0O[?305JES`1UUGT0Pjnl9P0000000`0@4U80
0000000000090000000802P0001G4AL0<W^B000000000:00;C5l06Ui]02;/=l206BJ`P030<WMo`00
000000000080000000L0/`0008d0003og]/000000000S02YPZD0PWjf0080000000<0ckW409:EG02H
HG/00`0000004`2cOF/0LP000000001GQ@000000000]MP00P;T0VLGM002_XP2:V:@0CHYP0000003`
g]l0/0000:L0001FS;<000000;oJb@0006d00P0005P00`000340002B000000020000000J003[k02l
ho00/moZ0=Oom`3Fon<0]<ZJ0;fnP03MgZd0jnFk0?SbcP3ommD0ooSG0?oojP3oolX0kkJR0?oHaP3o
on`0ooo`0?goi@3ao=X0kOKB0>S_b03Hf:H0h]Z/0>CN/@2Z]WbH000000`0oooo000:0?oooad00000
00<08WF;000000000000C`0000003`1OV:h0=fb@0:C2^P1[TY@0?WfG0:K;iP000000RK[B041nV@0^
Kh/002j@03j0S@000000`>2m041mR00500000003081]W`000000000002@0000000h0:00002@0001>
1`00D00004P000170000DP`B05@=2`1H0000K`0^04Q5S01GGJ<0G7^h086]f080R;_L00`0R/K<0<[M
eP3oo?@0ckO107N3X02F]LP0/L^n0?ook@0000009TIS0<NS]02bYjl20000000I0:F>/03od/80okjS
0000001f0000YJ[K03>1Q@2bMDh09P000840002M0000@00008F/W0000000fMgo04IUTP29FFX0YFIH
09EF002<C2`0PChP099E;P2>GP00G0000000?@020000c`0O0<kooP00oOl0NjR209F?[@2nfmh0i?oc
0000002QcN@0Xm7S0;_Th02id:X0`<N=0=7@VP3^k<D0n>c90?g_cP3ommD0oooZ0?ooo`3oooL0oooj
0?oWc03njLT0nNo;0?;ed@3Zlll0h^k70>CT^03Uej/0`kIm07n>B@2H000000`0oooo000:0?ooog00
000000@0DUiX0:<000000000S:Ee0`0000000`00<2X000000000000T0000000J03`0000[0000A@00
05L0001E3Pd0EP0005h0001R0000Ib<V06l[;P1]0000GaXN07<_<`1b;S00IB0R06dY:`1i=SP0MS<i
0810BP2ADUP0TU9F08];D@0i=Wl0QH>l045YZP2B`>4209K9hP0<0:7Fh02>alD0F9nR00000032PVh0
00000?oon@3oooX0iLS90000002l09X0/0240P0000003P3oc<80ooo]0?o[dP3ofLD0om_R09O2dP00
0000H@00035ZL01n0000X00002D00000_^h0h/3@0`000000202jRF@0[GA=0;f@I03F/HL0/7m?09Yc
=P2jUUl0HcT00P0000000`00S:H00:k50:S8/`020000000=0=CmjP3oool0`n_a0;7Oj032j^`0b^W?
0=3O/03LfZT0ln:m0?_Ua@3ki<<0nnG20?ooe`020?ooo`0;0?oonP3olmP0onS:0?3Q^P3/iK/0kNk8
0>[ab`3oon00lO340=;6T`1KKBH0V000000<0?ooo`002P3oool80000000302M3H01?ESH0000006H0
000000@0KH2^001HAP00BP00LcX02`0000000`00[Kd000000000000C0000000R0240000f00007`00
04T0002GTYh0Z;jU0500001<0000I`0006d[=@1b<Sh0Nc]40811BP26B500R4U?0891A`24A4/0NcY3
0810B@21@DP0R4Q@091AE`2IG5l0Y6Y_09]NH`2IGFD0TeMO09YMI02KGV@0V5]Q0000F`30[=40Re=T
0:N=Y`800:g?01D00<_F0:GJg@26_Z80MkN/0000002ok>T0eoKf0?[oo`2fVL40X7>E000000100400
TV][0=VkZP000000RlVh0?oog03oonT0f=S50740000V00000P000000401^ZHh0LJfg038Y:`2@[m@0
07JL0000003ol]d0oooY0?Kod`3WbZP0dZ^40;64C`2oTf<0Wg8j095[;@1O>P0204Td000N00000000
HHT0002n0>g?b`3[c<80e^[Y07nbb03;koL0dOKo0=[omP3Fmn@0g>[60?;ab@3ijLL0onc>0?cK^P3Z
aj@0iL2M0?7<]`3idL@0omS>0?oZeP3oiLT0l=bf0>KI[03SgK00i?730?gohP3hom/0d=V]V@00000<
0?ooo`002P3ooom_000000070:nd]`000000D7bY001QQ`2LW<00c[:i0;V;000L0000000H04<0000[
0000000004d0001Q0000McQ306/Y<@2XZmP0Kbhf06DT<01e=T00PD9=08=5CP24AU00N3U507m0B@28
BE00P3m407Db>@1h=C/0NSTn07Xi@P2@Ded0WfA_0P3oool0302_MW/0YF]c09EIH`1ZJH/0PG>W0:9W
K@2LH6X0WVAb091AF`0007h0n^7k0=oF`@80aL^700X0096V05^PX@00YIl00000099KK`000000WZ[5
0;R^hP1hGiT0XjOH0P0000000`3?nO@0i_oX08_0U@020000000F03@B2P33];80U;6O001dI`000=40
f]c?0;gK_@1mVWD0bk6X0000F`00bj`0OgB]0000000oMZX0nooo0?;lo`3om]L0hKnI0:]iA`2WN4<0
WGPj07eN0080]i5L0`0000006`3Q];80k<O00>kig`2id9`0V/7J0=7ho`3Rool0h_og0?;oj03gomh0
oocI0?oog@3olM@0omc70?GA]`3`c;@0l<Vh0?[A_P3ofl<0mmo00>gN]@3HcIT0c<ZC0=WY_`3Qm]L0
eo?I0:73T`2I000000`0oooo000:0?ooo`H0000000<0P6Q^000000000000100000000`0005P0Kg2B
09g0e`0R00000003095o[0000000000000@0000000<04C980000000000008`0000000`0lGh/0SP00
0000000B000000040000_@2;/mH0[=D006VVYA<0000000@0251>03d0001=2Q80FaXS0P1c=3d09`2F
S;X0JRXf06PW<03Db`00000006TV:`1U8RL0FQHJ05<0001K0000EP0006/X;00CFUl0Kbdd06XW<01R
7R@0E10J054<5@1e<CD0M30_0:IZJ02XJfT000000<nd_@2/TgL00000086:W`2TJFl0X6I_0;^/d@2/
M7l0Zg9k0:Q_N02VK7D0XVQc09QMJ@000740]<CV0?Soo`020=_o``0;0:CIe`00QGL009f>00@=2P1Y
SjL0:S9007>Ob000GHl004][001BL000F8<00P000000303olol0mM;T0:A/K@2:RH<004I10;00002I
FUh0000000008`1E0000P`000;6]S0D0000000T0100h0<39003kkol0ooo^0?;@[`3N^i<0[H1;085X
8`22F`000P25KBX20000000<0;cSe03LaJ<0mooD0=[K[@000000TKOG0;SRl@3Jool0kooo0?_ol03c
on<0k_of0P3oool03P3oh//0nMJm0??>]`3ojm@0oooV0?oZc@3_g[X0jn>i0=KBWP30`HH0f>Fg0>Ci
fP3=jl/0PZI`V@00000<0?ooo`002P3oool50000000304^=/01QXZl000000300000000<0DSeH0000
00000000B@0000000`2BaLX0MY>f000000030000000306PW<02RRkD0000000@000000100?U1j0000
001J0000KEd0099cVP2_OWH0A@0005@0001e<@00>00008I9DP1g>d/0^iZd09i]NP2DH5<0OP000P1>
00000`0]00000000000000020000000@0<;Re`2ADT/0/GQe0;=jN02hPhX0^8>=0;R4SP2`NXL0Z7>4
0:afQ02WL7d0WfIe0:9XMP0008D0Jj?;04f3O@8075DX00H0R/W707Zk`P1L0000000003aeWP1?R904
0000000M0024]@0000000=_P002d^`00SXd0@`000:F<[02>T;L0RUUK07mWQ00003X0000008l0002[
L7H0/7=a0000002LJ88000000<V[0037U@00Th=O06Y50022V<@0OUjC0=>UZ03fgK`0flRG08io>P2/
SE000P2AMP003`1`FP00000007N@^`3hoo<0ioOF0=kO/`000;40c_Oo0;g?l03=h?l0jooo0?Koo@3e
oml0ooGQ0?oko`020?ooo`0=0?obd03gg/40ono@0?ook03ol]80l>No0>OS^03Gej@0aLN>0=?@V`3G
g;00[<VJ041K5@2I000000`0oooo000:0?ooodX0000000<0MFT0000000000000>00000002P0?4aD0
0000000000000000LSA0070a?0062PT065]m039jSP18SYT20840000W05T00027000000000;2?[P2j
Z<T0_k;A0;ZCX02N0000Z0000<h0003E]LL0`J2h0;2G_02fU;00dkC70=>Y[@2hRI40/7f70<:>T03@
/L@0[Y:f0;ZM^`3oool0ZYe[0<NCR03;V8d0bIJC0<NHW`2jQHd0/Wb90;1lS02fQID0/H2C0:YgR@2/
N8T0[GR809eTM02YLGh0Z75o0080PDQP00D0A`0a05PN?@2GGW00]X2<0:=/GP0200000006072W_`00
0000?GIC0;oGm0000000XZ;?0P000000602cOWH000000000000000000`<506/_B`2A07l0/7]m0=nb
[031TY@0OCmE08mAH0000=40oooo0=Bo001iF`0000000:mbF02mR64000000>K<XP3QbI`0[YmO0:64
A080Y9d001d0EBd00000002H`mP0/M7H0>SDc@3_hL80000009K=iP2_b^h0cMgo0=Kgo`3Rn_@0ooCT
0?oPf03ofmL0omo^0?ooo`3momP0oool0?oojP3oon80on_90?;W`P3ViKX0d=BO0<3=UP3EeJ80_Kj5
08>UJ`2J000000`0oooo000:0?ooodX0000000<0I8X00000000000001`0000000`0P000000000000
000O0000000306RR/0000000000000l0000000@0KBhl05@000000000_96R0P000000902R0000^i:W
0;^BY`2kTZH0_YBW0;V=W`2nX[d0`[;@0;N^dP2jYlL0a:o;0=?3gP3Jaml0gLGH0=:hc`30Z/T0_Jg@
0<nie@3F_M<0cJc00<^X^`3C[[d0`hj00:R2WP3gcm80i[N`0>2dX@2nRG<0VUY:09aME@2IFU`0TEAQ
0;N1R02oSIX0_8nQ0;N9W@80/hFK00@0[G^@09mZP@2EGG80GA/_0P1F52d02`1^;dH0S59X00000000
0000EP000000000B0000gnKZ0<[UkP3fk_L0l_oo00<0000000h0GSIV0=K:j03@];l0`@0005/00000
0000CBU40880^@2h[/D0b9jZ0:I^O`1O9d@0J@000?oogP<0000000P0SUA909ALC`3=XGL0bjUi0=>l
R03D/h<0`Zme0;>KG@80T8Y50140UHl0000000000000R8Vg0>[B_`3hj/<0R00002M9R02;X]D0`m_k
0;[QlP35j_`0f]cb0>;9d@3L_kH0l^750?ooi@020?ooo`0:0?omk03jdKl0m]:`0=_;U`3Lf:H0`/fF
0<GGY@3DhK<0XKAh05Mj>YX00000303oool000X0ooooA`0000000`2aTJ<00000001XI00O00000003
00<0001/?D80000000H0000000<0ZLG7082UU0000000400000002P3</l`000000000002B0000/000
0:AfS@2fSjL0_IR_0<6N]@34X;L20<JQ]@0W0;FB[@31V[00cJJe0=6]_@3G^Ld0`jk<0<Jjf`3<`^40
dlSV0=K7hP3>_=P0d;[D0<Zfd`3<_]`0e<SV0=?7i038]mL0`j_:0=>kdP3M_m80g[o>0=k0dP32U9X0
[WIg0:QeR03M`=80jm?X0=njb032SI007P400:ehMP2dQ8d0]HNL0;B9XP2dR:40YWVE099SPP1C6ch0
HBQ80080LcI>0100CaDh06@lIP1ZAG000000001T003FcZ0000000?oGeP3of=`0:@0009aPK`000000
^X5k0000003R`LX0c<KQ0P0000005@3l0000d/G>0=oNi`2[/kD0OXNm08UcX@1nJ9/0O76Y08j?`@2N
ZmL0/]3`09nUb02JGeP0ckF00;^FM@3IaiT0l/bY0?73XP3B/h<0^J]_0=;1R`0207QU7@0L07n5@@00
00000000065ZY`3>cld0f/^R07IGR@0lBHl0PYoA0:oEhP32j?40bn_o09g1i`2A[ll0_=kR0>gol03j
onD0onO@0?oQf`3ojn80onoL0?oP`P3Nc9`0`Kf20:ZnQ03=gJl0^M2M08FKFY/00000303oool000X0
oooo@P0000001000ZMl00<cm002Tb@21GF8T0000000402=APP0C7Cl000000:b;Z1L0000000X0aJo;
0=:of03;[lL0eK[?0<jcbP35[<H0c[[E0<:Za`31Z/P0aJc90P34YKh09`30WkT0b:Jm0=Fc`P3?Z[/0
cjk20=>fb`3GaMh0e<GQ0=;2g@3D`mh0c[kK0<NlgP3:_ml0dLWY0=O@l@3@aND0a<;V0<;1i@3Bc_00
gm?c0=_<j02cV[l0]Y^n0=Jka@3ZbLX0g/3@0=g8g`3hf>/0k=K_08e]002KITd0aYJR0;>0SP2kSJ00
ZGbE091QP01>6d@0NDQ/07=5KP0207Q<M`0?07EBPP2GTL<0RJ6c03@bL02E]hX0oooo0=KC[02EKcH0
000009aOJP2NLHh0Q01i0?o^e03oonL0oo7L0080000000H0lO;o0?Coo`00ool0`mJl0;^_W02KVlh2
0000000>002QXP00MFP0[giU07`k9P2WM000l]bi0=oBX`2l[W<000000>S1c@3beKH0hMFX0:VfO03=
dZ420:B^L`0L06]_9P00000000000000002_bnT0amCd09^TfP1LKZh0P:3A0;GFn@3Am?l0eO?o0<g]
o`30hOL07DP008O1c@30eNL0ong`0?ooo`3oood0oooT0?_hd@3Qh;L0ViaI0:BlPP3DgJ`0`mBR07F?
CY/00000303oool000X0ooooF@0000000`2o^@0000000000000Y0000000:0<6^c039^=H0f<_V0=W9
h`3Ea^80clCS0<Zkf@3;^mT0aKKF0<Bif@80`K?E02L0`;;D0<bog@3ObMl0i/gN0>C;g@3PamT0fL7D
0=:nf@3<]<h0f/OQ0=S6h03HbNT0f]7d0=C?l03Bc>h0e<[Z0=7>mP36b>l0cLkc0<c8jP3<aNL0al7T
0;jlhP3>a>00g/[O0>76f@3L_Lh0g;6`0=Za]03>Y@00FP000640001j0000d@0006X0001L0000EbUG
07I;M`2HMZ000P28GhP03@3:a_/0cN;l0;SQeP2Xbk@0SH1>0:K4b@32WIX0VfY109aNG@2NHg00]N2a
0:>/_@00/j<00P000000603V`LL0000000000000cMd00::V05YnQ@2>QkX0WKKQ09NegP00000004aQ
0<[Kk@3Di=`0`[ZN0;ZYQ`3[j<<0hN2d0000002lX<80Z9ni0<fgPP2T[Fh0[kYo0<SN/`80XJid01`0
M7D]00000000000000000664]@2^b_00Z<CZ05Me/@1bUlL0[mGb0=Sjo`3Mn_l0g_Wo0>?oo`3Zo`00
FGbf09fbh03oo?l0oooo0?oon`3oon<0h?OF0<cU_@1cR4D0X/jh0=OT^02N^HH0EGTiV`00000<0?oo
o`002P3ooon50000000:0<g6iP3>b^X0e<g/0=S<j03Hd>l0`;CF0<2^c`38^MP0dlSV0<o;kP80`;SL
02L0a<CV0<C9j@3>cNd0d<c/0=G>kP3MeOD0g=7`0=G7h`3Bc^l0e/o_0=WAk`3Sf_h0iM_o0=O@l@3;
`N<0em3a0>7Mo`3Jeol0al?U0<O4j03:aNL0aL;V0;noi@38an/0d/[Y0<k0gP3;]M<0ckGA0=FXZ`3D
/L<0_YN_0;VB[034WK<0kLC;0;^5Q`2YNXl0Qeb308UVTP2FPk400P2kW;P04P2i^Kh0LTmd0<BKZ@36
d=D0Wi:Y0;5oK03[/Jh0iJ6?0;V<J036[H8009@00?OC[@3DXiT0GEeD000000000:80bL;K0?GXg@80
000001<0_XjY0?obmP3oo?l0n?Go05F3U`0008H0LYS2001YQP2A^[h0U;Ve010B3`00dYl0/YNk07YG
P03bfkh0c]6M0:^VIP2bWf<0`LVI0080]lfL01/0GUl0000000000000000002M;R02G`N40W<KT06^C
``1LQKX0S:kI0;CFm`35i?l0_=[n0>oo003Ronl0=VRM08n/g@3Bl_l0hooo0=gomP3OnM`0d^k=0:oC
[@0@3@`0YmK30:;2U01VUF80W000000<0?ooo`002P3ooomk0000000300P500000000000000L00000
00X0c/?Q0=37i@3Bb^P0e/gZ0=2nf@2n[]00`kWK0=S>jP3Ie?<0d<c^0P3:a^L09`3<co80alka0<S=
l03:c>l0c]3b0=KJoP3Eeo/0e=Gg0=CHo@3=d?<0c]7d0=CCmP3Icnh0dlKS0=;3h@3Gco40g=Cf0=[>
kP3=_md0b/?U0<c8j@37a>P0`L7V0<S8k038b^h0a/;U0<JhfP3CanL0gL_X0=2ie`2jX<80^ifm0<j[
`03D[K/0b9^X0:]nV@26GhP0/jGA0:FRd`020=WJlP0<0>[njP1IK980@E`j0=Via@2JJhD0/HNM0<^S
002eS80006a_0<:IL@000000ooCK0`0000003P3R^l40K7bZ0=Vmd03=X:40biVC0<JM/03oko80onco
0>g0c00e>Eh0@TYd000VA`000000h=_o0P0000002000ITP0Xj3>0:2J^`2k]Wl0ZlfX0;B_N02POCl0
X;9h0P2_c9X00`1[NcH00000000000020000000E08jlf`1jZ/l0J9W405^9^@22Z]@0Yl_Z0:WBjP2>
^mL0/nJm04j;L029_;T095f>07FYb@2Re=@0[]kC0;cVfP1f[Y80Ij600:BoR`2ef[T0BX1A09d00000
303oool000X0oooo:00000000`2ce[T000000000000N0000000305<000000000000000/0000000<0
1b8W0000000000007@0000000`1iLi<0000000000003000000030000A`000000000000D000000P3G
bnL0203Db><0b<CT0<S0h03<a^L0b<[/0<g>k`3DdO80e<k^0P3Dco009`3HfOh0d=3c0<W9j`3;co40
d=Om0=7Fn`3?dOD0e=Sl0=;CmP3>cO00clc^0<c7j@39`nH0c/OW0=gAk`3Pf_l0f=?i0<g5i`38^md0
e<SV0=O<j@3?bN/0a/GY0<S8j`32`NH0_kgS0<>lh@3Dc_00e<[^0<2Yb`2^UK/0[YJn0<JT_P3<X[80
_HjO09aYP`35WkH0e=So0:Zci0020;K?k080000000X0YH>O0;^CY`3J^lh0im?X06]A000000000015
0000002PGdT0YfMB0`000000603O][X0hL?G0:NQb`3C`mH0elKC0>O<g`3PaMX0cIfY0?W0a`3da<h0
fKW90024T@1LHH`0aMKP0;k?X`2ad^P0Z:WI096`d`0007T0Vjf20975^@3<hl/0e]BU075e0080W[b7
00<0K7@^0000000000000`0000004`1ES[<0IYO104Z0[@0UEhl0NJo;08>hd01n][H0Hj260<CZe@31
jMP0QkO3002=YP1OXZD004Q?04J=V018SHP0KjB207RbV@11O580WP00000<0?ooo`002P3ooom90000
000404`0000000000000075QM2/0000000<0/;:b0000000000001`0000003@2PVg8000000000003J
d_80dLOU0=WBl`3@c>d0bLCU0<o=k`3=d?80c<o`0<k>k`3?c^l00P3Ed_@09`3Heo/0bLCW0=;?l@3G
fOl0e]_o0=3Am03Aco40dMCg0=3>l03>bNX0b/CU0<g7j@39a^T0b<W/0=KGn`3Mg_l0fMGl0<RmgP36
^mh0cL?T0=SAl`3IdoD0cl[]0<c8j`3:a^T0]k7I0;Zgg`3=b>/0_JoD0;6OaP2dX/P0/J;<0;RQ``2_
SJ`0YgVE0<>EY@1806L0[9W30;Rl_P0209W7d00W08fjd`27WlT000000:elG@3aool0n_oo0=33iP2h
SjP0`HVI0;b0N@3oonT0^HAO0;b7I`3GYIT0g:jK0000003om?l0HXFj09Fcg03:boH0jooo0>Soo`3L
c^/0oooV0?WHjP3Nbn406P0004F1SP2]_M/000000;?@kP2@W/h000000022V@00G840QKk408F`_031
i<l0Mh400080XK^500<0IWXg0000000000000`0000004P0MBhD0GHjk06bLa@1KTKL0=7BE04F7W`1G
VY/0EYBB07B`YP1EVJ40F9R[06RT]`2:`lT0SlS406^/Z@1n^k@0KjjL02a[A9l00000303oool000X0
oooo>P0000000`2j]H@00000000000130000000304@fJ@00000000000080000000X0clWY0=cEm03H
eOD0dL[[0=;;jP3HeOD0eM?c0<[5iP3:anT0e=3a0P3GeOP09`3Cco00clk`0=KHo`3Jgol0eM?e0<c8
j03GdO80e<k_0<K0h`37`N<0clWY0=S@l03Dd_D0cLkb0<oCn03?c_@0bl?V0<^lg@3;_]h0d<[/0=[G
o`3EdOH0cLSZ0<[4iP32]]X0`k_O0<W:k@2k]=/0Zic70;>^f02k]=/0[JC@09bDa02PS[T0]Yk00<2R
_@29JY<0I3EO01l0000206D0000P0;[7g`2b/]<0000008nA_01dX<T0`<oo085OS03GbNl0oooo0?oX
l@00J`00<RQ=0=NZS@33S7L0eJBB0;V6J0000000I`0002UOT@1aV<40]>7o08c3k02c`>H0g]7`0=cB
l@2L0000a<400=d0dP3Rool00000079ER@2hV[d200000005001WUP00Fi80002`08^eZ@1/P4H00P2;
Zg@00`0mFAH00000000000040000000@0000R@00Y<H0RK[F076]_`0mQH<003i6001:E000FFD0?hJ<
01YSMP00HG0006Q]001SKP00KGL007Qd001XBj000000303oool000X0ooooKP0000000`2R[L`0al?8
0000000D0000000:0=G?kP3Dcnh0d<k^0<[2h`3Gc^`0g]Kf0=?8iP3=aND0d<c/0=KAl@80emCf02L0
e<o`0=GFnP3Igol0dM?g0<S4iP3<b>T02@P00=C=kP3=c>h0bLc^0<_=l03Ad_D0f]Gh0=gFnP3Ge?P0
b/OZ0;nhg@39_Ml0f=Cg0=_Go03NgOl0clW/0<[5j031_>00b<3S0<c9k@31_N80[JSC0;nmh`31`>H0
];;L0:BMc02GTL<0Wi_;0:ZRc`2UTK`0MEnF05D0001JChh00P2P0000202QVXl0=UI:0000002AX;h0
2`TF09JE`P2JUl@0hooo0P3oool04`3A/L80_ZD00:_7h`2nc]`0c<o>09IjI`2=ERX005L0081iRP0e
KI@0EY:/0000000008P05@`<0:f]h`3Ia^40[9bk07bHa033b^P00`0000001`2mcol0gOgS00000000
02D0_/GJ09W2Z00003T00P1`VF/900000003002>Y000N74000000:/00000303oool000X0oooo=P00
00000`010@8000000000000;000000030<>a002RX000000002L0000000<0Q:ff0000000000000P00
00000`2WZ@0000000000000?0000000:0=?6hP3Ib>40eL_Y0<K0hP3@b^X0f<gY0=S<i`3EcNX0dlo_
0=K@l080em?d02L0fMGh0=[Lo`3Eeod0c<OY0<W5i`2VU<80d]Ch0=?Bm@3Ad?<0d];e0<_<kP36b^h0
al_^0=3@m03Dd_@0b<CW0;^hgP31`NL0e]Gj0=kMo`3FdoP0dL[/0<O1i032_^<0b<KZ0<W6j`2o^]l0
_;WQ0;fmi02i]ml0ZjCA0:BJb02ZXm00XZ7@09bIb`2BPK@0NFRP08MfZ01VHIh00P1lSL@07P000000
CCal09NHc02H][H000000<Zki@2^^=d0X[cV0=[_o`3oool0cM7f09^M003:Y`0033eH0000VP2E[ML0
A10501PO2`3ooo40i_cf00X=3P3;WY@0000004DN00000000FiF^08mo[@000000/IW20;nI00<00000
00H0i03o0>Kff`1oQP00anWT0<nMT`00LWRi000000`0oooo000:0?ooocD0000000<0SP0000000000
0000300000000`1iGgP000000000000n0000000:0<RjfP3Le?<0hMSj0=C<k00C3A<0e<cZ0=K<j@3E
cN`0d/o`0=G@l@80f]Gf02L0g]_o0=gKo`3Cc>h0cL7Q0<k5iP3DeOT0eMGj0=7<kP3Cc^l0dlk`0=??
lP3<co<0b<kb0<[?l`3>d?<0`l?X0<C7j`31b>`0b<oc0=CEnP3GdO80e<SW0<jog`39`><0a/K[0;nj
h032_n<0_[kT0;Rhh02a[]T0Y9k<0:JPc@2XWLX0YIW709^<_02=P;D0L6NR09F:^`20O;D00P2?W]00
7`1dMK00LV^V09VXe0000000h=<00>KRo`31eOL0[<o[08ZdeP2^]ml0_mof0=?oo`39i>P0oMCH0000
003]kol00?800000003:Wil0d;bI0000002[Vkl0Y@000;O0g@2CMfd0/:UX07YCPP2/VLH0[Ig90865
V`1XM5d00P0000001P3Po?l0X<@00:S6g@00SV`000000000[KT00000303oool000X0ooooQ@000000
2P3XiOl0i>Co0=[Gn03Dc^d0c/[[0=3=k@0N@6P0gMWm0=KEn03Bco420=gFm`0W0>3FmP3Ea^<0akGE
0<bjf@3Md_80hM_o0=G<k@3<a^H0blOX0=C>kP3Le_T0emSl0=;Fo03?d_D0bLOZ0<S7jP38c?00alka
0<K;k`2l`nT0`;oT0<Jmh03@a^P0fM7c0=3=l033`^L0a/GZ0;blh`2a/M`0[:[G0:>Mc02XZ=H0WI[;
09F>`02KT<40U8c0075e/01lNk@0[9K00080Xk[P00/0G6RU07b0^P2cd^h0N[6h06io]03oool0oOoo
0=K`o`2<_M<0S;OB055WM`020000000705Z4X0000000gm3o0=_Fo`000000ilg90;fnVP020000000A
08jde`2B_m`0e>So0000003<^mh0_K3H0=Seo`2bgN`0M:nd000000390?h0aNcM00d62023]<T0SfDW
0000000]B`00^@00000<0?ooo`002P3ooom80000000301l0000l0000000002@0000000<0UW^W0000
000000002@0000000`0II600000000000007000000050>oao`3Kgol0d]7c0=3=k@3=c^l00P000000
0`3If_l0eM?e0<g9jP020=C=kP0W0=O@l03Db^P0dLSY0=gLo`3Ogol0fM?g0=G<j`3Fd?80emCh0=CB
m@3KeoX0fmWo0=KCn03?bNX0cLOY0<k:k03=d?D0c/od0<G4j02o`^L0]kKN0;ZjhP3?d?<0eMOm0=;@
m036aNX0`l?X0<?2j02g]n00ZJKD0:FRd@2QY=@0SI?708j=`@2;S<00TiC808F:`@1SLZl0b]go0080
b]?i00<0=4^=08:Ba`2jcO000`0000002P3WfN/0hmCO000000000000<Ci7089cUP0o?U006P1307L0
R02iU:l20000000;0:Bl``2Ob:/000000000002Iamd0W/CG08FUb`37bol0[:[H0=_co`3FoOl00`00
00001P2^aL0008Q`000000000000D00005d00;X00000303oool000X0oooo00D000000:RI^0000<D0
Wi^806akB012000000030480J`1SHGh0H8fO03/0000000X0h^go0=?@l03Ac_00d]?e0=3Cm@3=cNh0
00000=CHo03<c>h0bl[/0P39bN`09`3>co40c/o`0=3@l@3Fg?l0eMKm0=7:j`3EcNd0elo^0=K?l@3A
c>d0f]Sm0=WDn03>anT0b[oP0=;8j@3IdO80fmSm0<k6j@3=a^L0blOZ0;g0iP2i`NT0b<oe0<cBn@3:
b_00`l;X0<C4j032`^L0/K3K0:ZVd`2a[MP0/:oJ09RKc@23SL@0Ohk509nVeP26TLL0NXS00;C;mP02
06eRUP0305A;R01hSlD0Xk?O0080000000P0RTI30<6:LP3Z]J40m/>h002FT000=FL000000?KP`080
000000h0KHFg000000000000jLG80>gD``3Xi<T0RemB09f_d@000000Zic906j6^`1lYl`0d_ko024Y
:080000000D0^lC?000000000000^<bI00/0002l000000`0oooo000:0?ooo`05000000000<P0000`
05V6N`0?0000100000000`37Yj@0e[F90000001i0000000:0>;Vo`3Db^L0h=Ke0=gHnP3Cc^h0d<c]
0=?Dn03CeOP0aLO/0=7FnP80cmSl02L0c=Gh0=3Em`3>e_T0cmGi0<K7j`39aNL0dlc]0=cEm`3KeOT0
g=So0=kNo`3GdoP0akoR0<_7j@3Aco<0f][o0=7=l@38`N@0cL_^0=GEnP3BeOX0aLca0<C:kP32an`0
`L7W0<K4j@35a>T0_;_S0:j_f`2PX]80ZZgJ0;:_fP2ZYm@0X:CD096Lc`1oT<D0SY[=096Mc`2@Y]L0
0P1/Jj40501iPKP0RJK204AKV02;SIh0IXiP0<^U]`3OYj@0[7=>0<NBO@00Y:000:fj0000002b0000
]LNN0000001`W[/0Skjb0;bmh03oh>h0oo3Z0`0000001@3:X[L0k/[O08J`U@1f<c/0XVEJ00<00000
00@0VWf1000000000000WjQ/_@00000<0?ooo`002P3oool9000000030:J`^P000000000006T00000
00<05EmR00002@0000003@0000002P3:`n@0d/g^0=gGnP3He?H0fmGf0=cIoP3Ngol0f]Gf0=GEnP3D
f?h20<oDm`0W0<k?l@3CdO80f=?c0<[4iP34`ND0`L7U0<o<k`3HeOP0h]oo0=oOo`3Ge?/0d];g0<_:
k@3=co@0dMKk0=?Eo@3;anT0b/O[0=7Co@3Hgol0b/ca0<C3i`38`nL0a/KY0<G2iP35`^L0`l;W0;fk
hP2g]=d0Z:_H0:2Ve@2XZ=D0[jcH0:b_f`2UZ]P0VYk?092BaP2IVL/0SiK:0080PgZ`01@0PhBj0000
0000000000000=SMo`3ol_l0ooWo0?_?]@3>WW/0h[^O0?oof`3]h[00a91a08jiU`00G500000007NC
a`16LZH0]LcT0<WTd`80000000d0_Z_40?oSo`3[in@0Z<6A0000000X0000;P000<33UP000000IEAe
0000002_]L40Xl>Q0;d00000303oool000X0ooooMP0000000`00004000000000000<0000000:0<c:
j`3>dO<0emSl0=;Cm@3DeoX0f]ko0=KFo03Gdo@0fMSl0=SHo080dLk`02L0blOY0<K1h`3Eb^X0hmC_
0=?>kP32aNT0a<W_0=OLo`3RhOl0em_o0<c8j`3@dO/0c=3d0=7En`3?eoh0b/__0<S8j`3@dOL0emgo
0=CGo`2o_>80_kgR0<S7j`34a>P0`l3T0<[2i03=a>H0_[KL0;ffg@2m^^40Si[=09JLcP2`/=/0/KCO
0:JSd@26MZT0UHRj0:6Fa@2<Q;T00P2NS[X07`2dXLH0^ZW?00000021NJX0^LO]0<>ijP3oool0oncR
0??=^@3M/Y<0km:n0=BSU@3HYi/0hP000:<0002KblL0W9Ji0:7;iP2C`]/0_>GD07]AO0000000QTmZ
0000003No]P00<ni0?3/cP000000S`000000003UgM@0`@00000<0?ooo`002P3ooom100000003095R
=@1[OG@0000003<0000000<0ooo`0000000000002`0000002P3FdoD0e=Ok0=;Ho03Beo`0d]_o0=7F
o03>bNX0eM?e0=_Jo`3EdO<20<k7i`0W0<[2hP37`>40c/CU0=k@k@3QcnP0dlSU0<o?lP3;dOH0em_o
0=?=l03>b^`0f=co0>3Zo`3=e_/0a<O[0<G7j`3:co<0dMSo0=;Go`3Ad?@0^KCK0<75j`36c?40`/[^
0;>cg02l_n@0_l?X0<30iP31`>D0b/GY0:fQc@2KU/P0YJKE0:f/f026NJl0Of^P0:>Ga02/Z=<0Vi;5
0080N7:]01@0_9fh0000000000000000002hg`00UP00`7iZ0=NKP`3oj=@0hKJP0=6OQP3AW940gk6V
0>S1[@2cU@0000000=6ob`3Nool0d_;o0<KPo`<0000000<0NDAV08]IN`0000001P0000000`1OQYH0
00000000002m000000`0oooo000:0?ooofD0000000<08C=;00dE7P0=5Ah07@0000002P3jk_l0jn;o
0=cKo`3LgOl0d]Om0<_9j`3<_ml0f=Wn0=OGn`3@b>T20<c0h00K0<g4h`3<b>T0b/OY0=7<k03Ld>d0
elo_0=SBlP3Fc>D0VXfj0=WNo`3AeOT0eM[o0=OJo`3:bnl0aL_`0<S?m03:d_H0bLkc0<;2i`30_N40
b/od0<oJo`39e_X0][oW0:Zfg`2V^>80]/CZ0080/kcU00X0/[3K09jDa02h]Mh0]KOQ09BBa@1WFYH0
R8Fl0;6fh@2Z[m/0V9;50P1fKjX0102HUL00/j_60<Ve^P2300020000000I08iW002jkmD05`D30=Nh
`@3@YZ@0gZnP0>JkZP3T_ih0WHD00;nO^@3ni=/0oool0:jYQ`2[XX40d[_B0:20Q@000000O@000816
G01X;4P0SFB:0000001n06@000000563T@31000000`0oooo000:0?ooof80000000<0:4=G00000000
0000800000002P3om?l0h=Sk0=kDm03Pe_H0cL7P0;R/d`3KgOl0gN3o0=;@mP36_Ml20<Nnh@0W0<k<
kP3@d_D0bLg`0<K:k03<b^`0elo_0<k0g`3oi?<0TGZZ0;^em03If_l0d=Wj0<k<k`3AcO40d]Ck0=7J
o`37cO40`<G[0;k7j`34cO40b]Ok0<cJo`38dOD0_l?Y0;o9kP2od_@0[L7X0:Feh02MZmT0UIO909JA
a02o_^D0/J_E08N6^`1`L:/0VJGD0::]f`2?VLd0M76/0080PH>j0200QIK;09bdf02i_]H0QY1E0000
001]GID0/XJ60000001cM@00b[kQ0=g3d@3T_jH0iL2Q0>kA/P3Ma@00ongo0?ooo`3oom/0XhV905L0
000N000000000=^^XP2QHU`0O`000;V]L01J0000T`2>09h0X`000000K@280;OFhL000000303oool0
00X0ooooNP0000000`2?EF`0000000000009000000090=K=j`3Ldo40fLcZ0<Fdd`3Tf_d0h^Wo0=WK
o`36_=h0aK[L0080e=3f02L0g>;o0=;Ho`33cO40_<O[0;o5jP2j_N<0k>Go0?ooo`3Cc?l0mooo0?[o
o`3AcNl0blW]0=gIoP3Lf_l0dMGm0<[;kP3:a^X0b]Ck0<[Ho@34e_T0_<cc0;S3jP32b>d0bm?i0<_B
mP2i`NT0ZK;N09VPd@2DTlH0W9[;0:nXd@2KQ:d0RGb^08JDa`2I/Md0Uj[H09:Hb`1_O;L00P2FZ=P0
2@2N[]`0ZKkV0=3Ui@000000Q;BJ0000001g04P0k=b^0000g@020000000E003DdP3ok<H0oNFo0>WB
ZP3Hfol0fnkY0>_acP000000ak:6095BF`0008D0f/cV0>g:e03Ra=@0<P1I0;>Rd03Edol0b/`008Z5
[01kZ[d0Ei>70<000000303oool000X0ooooNP0000000`2?EF`0000000000009000000090=K=j`3L
do40fLcZ0<Fdd`3Tf_d0h^Wo0=WKo`36_=h0aK[L0080e=3f02L0g>;o0=;Ho`33cO40_<O[0;o5jP2j
_N<0k>Go0?ooo`3Cc?l0mooo0?[oo`3AcNl0blW]0=gIoP3Lf_l0dMGm0<[;kP3:a^X0b]Ck0<[Ho@34
e_T0_<cc0;S3jP32b>d0bm?i0<_BmP2i`NT0ZK;N09VPd@2DTlH0W9[;0:nXd@2KQ:d0RGb^08JDa`2I
/Md0Uj[H09:Hb`1_O;L00P2FZ=P02@2N[]`0ZKkV0=3Ui@000000Q;BJ0000001g04P0k=b^0000g@02
0000000E003DdP3ok<H0oNFo0>WBZP3Hfol0fnkY0>_acP000000ak:6095BF`0008D0f/cV0>g:e03R
a=@0<P1I0;>Rd03Edol0b/`008Z5[01kZ[d0Ei>70<000000303oool000X0oooo@@0000000`2?0000
00000000000f0000000307NKO0000000000000T0000000T0clWX0=GAl@3Bbn/0d/k^0>;[o`3Mi_l0
b<;^0;f]d03>aN/00P3LfOl09`3Pg_l0f/kZ0<o=k@33an/0][oU0;_9k03;fol0l?oo0<[Wo`3<g_l0
h^Go0=SIo`3<d?@0d]Wo0=OLo`3Cd?H0b/?T0=_@l03FgOl0cn7o0;_?l@2abN/0YKOP0;70i`2``NX0
_/K/0<C<l02V/mh0U:;B07^1^0147500:DTk0;6C]@3@ao40_=go09flh@1hSl@0QiO;07bAa`0207B;
`P0706Ee/@2lcO80000008]6BP2HL3X0000003`0@`03000000050<Jg/@00i_/0oooM0?odc03oomh0
0P0000003@00a;/0O50C04D0001`:P00gJfN0;o:mP3Nh?l0i>oo06d0WP2S/nD0cn[o0:o90000T`00
`P00000<0?ooo`002P3ooon6000000090=3?lP3Ce_X0d][o0=7Io`3Gh_l0cm7d0:nNa@3<`NT0gMoo
0080hN[o02L0a<3Y0=o0d03NfOT0hN[o0<oFo`32c_80`/[]0<gFn`3?eoX0d]Sl0=c>kP3E_m`0f<;H
0=W=j03Gco00bKWH0;nUa@3?d_P0m?oo0??oo`3Tool0cN3l09VggP2I]]h0SjoG0;?5j`2kcO00Y[gT
08ROc`1^P[X0BdJ001DV7`2R[=H0c?7o0<G^o`2/cnT0J8Nm06Ij]026X]400P1mV<X0302B[]400000
06A7M02KKH<0[G9k000kEP2=Y//0cK:m08mPD@2TIP00ml@0000^K@80000000`0=A/@0000002oT8`0
V5e<092CTP000000I@0001E<7P000000e^Ko0>Coo`18=CT200000003003;0000000000000<400000
303oool000X0ooooL00000000`1FN9P0Min?00000004000000030027UP000000000000`0000000T0
gn?o0>;/o`3Xl_l0g^7o0=;DnP2/X//0W9?10=k[o`3Nkol00P3MkOl0502LWL/0eM3Y0?Soo`3mool0
eLgb0<_<k@34a^T0e=Oo0=gNo`37a>X0^JW>0<JXa02cP8L0f;S;0<bbc@3;]=40hloU0??Gi`3kho`0
n^?o0P3oool04@3:o_l0Uk_N09:if`1mZld0MZG808jbe`2C[MT0EWV^04mWX01>HiX0EG^V08Bib`1j
//<0KJFk03IRU`1KNk<0QJ[D0080Mi;600d0T:SE0000AP1kN;80ZY>l06dmJ01cA70009g90;g0g@3e
f>T0ooon0>c[_`2eUJL0olnd00<0000000D0_hnL0=2MW@31Sg@0GffW0;65U002000000050000eP3G
a000cMKC0:_FeP00G000a000000<0?ooo`002P3ooomg00000003002:/`000000000000`0000000T0
fMgo0=WOo`3Bfol0d/gc0<g7j`2g^Mh0cmko0=KYo`3Ejol00P3@doL04`28T<40/loV0>Cfo`3Zf_L0
c;7>0=KDn`3:c_80g=ko0=WHo`2i/]P0^[?N0<^ni`3Dk?l0^KWH0<2YbP3<^]P0_kGF0:jG_@34SXP0
0P3o00004P2[0000OK3;08Ree02=^]H0RkWE07:Ta01CRZl0A7fS03M^V@11N9l0ChJ[05fC]01[YkL0
Qkk;07jab`0oJih0<5^C05j8]`80GfjY00X0UZkI0000A`0000000027075VV`2dZM80^lSa0<CAm`3F
kOl0oooo0`0000003P3Ck_40g=c:0=BTU`3JZZ40h;Ba0;EkI0000000NWfZ09YeT02SI6P0cLRj0=3B
XP2Qbk40H9^0a@00000<0?ooo`002P3ooon6000000090<o:k@3Jgol0cmKl0<[8j`37b>/0`lob0<7>
l03=g?l0_lc_0080dl[V00@0fM7a0=KKm@2/[mL0^;CZ0P3dool03038g_l0cL[[0<_2hP36]MH0eLg_
0=cPo`3Eeol0]JkF0:BLb@30b>/0]<[/082;^`80000001<0o`0006h0002Qd<<0KZVe07^/b`1ATJ40
EIBV04Z:X011Oi`0?7VJ04N3X`1;Q:L0<6nA052>YP1TX[00GIF/04=[X@0nGYX0<5fD008005fL01<0
@ERE0000000000008`X0071o^P2Q/>00[;gY0<KAm`39god0k_oo0<CA/01^0000ck>d0000002^^M@0
d[g@0<ZJX`38V:D0c9^P0080000000@0LFRS0<Nhb@3JkM<0OYi[a`00000<0?ooo`002P3ooom00000
00030?o`kP000000000004<0000000T0g]G_0>?Zo`3Ih?l0aLS/0=GMo`33doD0`MCd0<ODm@2`^n80
0P2j]MP09`3G`]`0e/7>0<Rie`2j_^X0k_oo0>_oo`3IiOl0aLOY0:B`f@2f_nP0f^Go0=;Mo`3?a^T0
][?I0;74iP2og?D0[=GW08B`cP26]/l0XM?>0;SQc02RaJ80SlG205nNWP1ATYh0<gN601iTM@00I7D0
07>1001TL`00?5X0000004MnXP1g[LD0V/_E09[=e01i];T08Df7001iW@020010K@0H0000MP0003d0
G6JS0081001DJjT0LY750:Jgi036cOD0`]?h0<[`l`3LmM/0gN;00;naNP000000W;K=092Sd033]M@0
kooo0?7oo`3Kjn00X/^T0000002Sa/d0MJV7b000000<0?ooo`002P3ooon50000000:0;_D_@3dkmd0
f>ko0<cCmP2STK<000000>7No`2oc^l0a/[[0:J[e@80QiG701l0b;KE0?oKiP3]goP0fn_o0>Soo`3N
i_l0f=Wo0<;?nP31gOl0YLK[08Nkc01ORK40SJC;0:k>i`2Zcmh0RKk807J^`01dZ/80Mjo0086ia02@
a</0b_7Y001:DP0KHVP08VU/02I/L`0:DEl06Ema031dQ@0nPHh0=g^300<0000000<0Z=?N08Nm^@00
00001P0000005000<gP0D5ZG092^e@1:MJP0HXVk0;Foj@2Ba]80XM?E003FdP2`eLL0`mZd0=BiU03K
g[T0U;;30:o5i@2oh?H0boSk09c>_P2UI5T0^<:UbP00000<0?ooo`002P3ooon1000000030<f/0000
000000000080000000T0oooa0=Wfo`2ga>X0GgVS0;O=d`3Xc=H0o>Co0=[0i02aUkL00P2KU;/0602;
UlT0jm[k0>oio`3^ool0fnWo0=WPo`3Khol0dNWo0>_oo`3hool0lOoo07^Xb@14NJ00KjBn07N`/@17
RHX0001m0000W`20]L<0NK>d02E[J00XKW008FMT0017A@/0000000<0Ylfa0000000000001P000000
4P0UC8P0MIS508nle`0hNfl065mf0=g]o`3omol0k<cH0<2Q_P0BGF<000000;gK_02Td//0Qko;06JU
]01DUY80NZ^F05ZFP</00000303oool000X0ooooQP0000002006C600oooo00071`2/[=D0/:;;0;BT
bP2_U;40bJC00`3oool05@2hg_l0S[3F0=Woo`3Rool0cN;o0<3Km`36iOX0/]W/0:oKl`2[eO<0RkoD
0000000gMg/0DHnI06bY[@1RXJ@0D96C03n3O`0^LVT004DQ001QGP0G0000000@000hJ`1KR;D0EHn0
09fi003Bkol0cNco0<GWnP36hoL0_n3e09G3_@1l]Ih0NkR]07:`Y`1FVI<0@8=c001SC<d00000303o
ool000X0ooooQ`000000203oool0]k[Y000000000000^;WN0<3=i03bool0iogm0P34jOd0402`dod0
SKKE086/cP2Oan80V<CE08FabP2Ye=l0Xm;C002bX@1=SIP0DY:J05ZIWP1<SID0@H>=03=gOP0[KV@3
000000030;o=WP000000000001T0000000T006^708ZnbP1WXZT08FQ^06NP]`1o^/80BXin02idI`0M
IfD0d@00000<0?ooo`002P3ooon7000000080>[jo`1oS;h0H7f^08NRbP2V_n80TK;=0025X02Td]X2
0:CDe`0=08^hc01n//H0N:nn062MX01LVid0AhR;001PEP1DU9807f=T0421R`0fNX00B8V>05bJVP06
000000030<CSg0000000000001/0000000<006Eb002IT@000000e@00000<0?ooo`002P3ooon70000
000803XJ:`1o/lD0NjG606nR_@1WXK40N[6o056;X`25^/T207:]/@0904B4O00nP7X0001E00003000
SH`09FQM03EhM@0XKFh0061Q0?l000000@00000<0?ooo`002P3ooon2000000030;NoS00000000000
00<0000000L0R[S@09>oe@29^lP0Pk^k06:M[P1g[<<0JJ:d0080MZn^00D0KJJE011EC@1UXIl03UAC
001:A@3o000000D00000303oool000X0ooooQ00000000`1HSiD00000000000030000000505FBX@1W
XZX0J:>`04^;UP0jNh@00P00>3400`0DFEH09VQM0000003o000000L00000303oool000X0ooooR`00
00000`0BF5l076A?0000003o000000d00000303oool000X0ooooJ@0000000`29Wll000000000000[
000000030?ooo`00000000000?l000000@00000<0?ooo`002P3ooooo000009/00000303oool000X0
ooooS@0000000`2b0:d000000000003o000000/00000303oool000X0ooooA@0000000`0T00000000
0000003o000005<00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<
0?ooo`002P3ooooo000009/00000303oool000X0ooooP00000000`081`00000007e<F`0800000003
07e<;P00000000000?l000003@00000<0?ooo`002P3ooooo000009/00000303oool000X0ooooR000
00000`2gg<D0MZN50000003o000001000000303oool000X0ooooo`00002K000000`0oooo000:0?oo
ool00000V`00000<0?ooo`002P3ooonL00000003001SB`00000000000?/00000303oool000X0oooo
o`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/00000303oool0
00X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/00000
303oool000X0ooooO`0000000`2E_Jd000000000003o000001T00000303oool000X0ooooo`00002K
000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/00000303oool000X0oooo
o`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/00000303oool0
00X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/00000
303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo0000
09/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3o
oooo000009/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?oo
o`002P3ooooo000009/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00
000<0?ooo`002P3ooooo000009/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool0
0000V`00000<0?ooo`002P3ooooo000009/00000303oool000X0ooooo`00002K000000`0oooo000:
0?ooool00000V`00000<0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{78.625, 308}, {622, 392.625}} -> {-153.971, 708.927, \
1.46487, 1.46487}},
  CellTags->"RenderCTData"]
}, Open  ]],

Cell[TextData[{
  "If you want to have the polygons of this surface in the ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "k",
  "ernel, you can use ",
  StyleBox["MVGetGraphics3D[]", "Input"],
  "."
}], "Text",
  CellTags->"RenderCTData"],

Cell[BoxData[
    \(\(foot = MVGetGraphics3D[];\)\)], "Input",
  CellTags->"RenderCTData"],

Cell["The number of polygons is quite large.", "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((poly = Cases[foot, _Polygon, Infinity])\) // Length\)], "Input",
  CellTags->"RenderCTData"],

Cell[BoxData[
    \(309392\)], "Output",
  CellTags->"RenderCTData"]
}, Open  ]],

Cell[TextData[{
  "MathGL3d can rotate the image in real time, but ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is a bit slower."
}], "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        Graphics3D[{EdgeForm[], poly}, 
          ViewPoint \[Rule] {1.086, \(-2.00\), 1.0}]];\)\)], "Input",
  CellTags->"RenderCTData"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0255 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0568432 1.19468 -1.86537e-016 1.19468 [
[ 0 0 0 0 ]
[ 1 1.0255 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0869 .22952 m
0 .90341 L
s
0 .90341 m
.42701 1.0255 L
s
.42701 1.0255 m
.44086 .49942 L
s
.44086 .49942 m
.0869 .22952 L
s
.69882 0 m
.93564 .37358 L
s
.93564 .37358 m
1 .96995 L
s
1 .96995 m
.73687 .79033 L
s
.73687 .79033 m
.69882 0 L
s
.0869 .22952 m
0 .90341 L
s
0 .90341 m
.73687 .79033 L
s
.73687 .79033 m
.69882 0 L
s
.69882 0 m
.0869 .22952 L
s
.44086 .49942 m
.93564 .37358 L
s
.93564 .37358 m
1 .96995 L
s
1 .96995 m
.42701 1.0255 L
s
.42701 1.0255 m
.44086 .49942 L
s
0 0 m
1 0 L
1 1.0255 L
0 1.0255 L
closepath
clip
newpath
.513 .625 .899 r
.4059 .83004 m .40783 .83006 L .40621 .83052 L F
.535 .371 .606 r
.40783 .83006 m .40597 .83268 L .40621 .83052 L F
.138 .669 .864 r
.40482 .82978 m .4059 .83004 L .40464 .82966 L F
.40482 .82978 m .40783 .83006 L .4059 .83004 L F
.535 .371 .606 r
.40783 .83006 m .40778 .83265 L .40597 .83268 L F
.225 0 0 r
.40597 .83268 m .40778 .83265 L .40581 .83274 L F
.55 .703 .941 r
.40581 .83274 m .40778 .83265 L .4056 .83251 L F
.637 .455 .62 r
.4056 .83251 m .40783 .83006 L .40482 .82978 L F
.4056 .83251 m .40778 .83265 L .40783 .83006 L F
.829 .412 .251 r
.40783 .83006 m .41095 .83256 L .40778 .83265 L F
.154 0 0 r
.41095 .83256 m .40988 .8327 L .40778 .83265 L F
.829 .412 .251 r
.40783 .83006 m .40988 .8327 L .41095 .83256 L F
.40988 .8327 m .41013 .83301 L .41095 .83256 L F
.154 0 0 r
.41095 .83256 m .40999 .8327 L .40988 .8327 L F
.602 .427 .616 r
.40778 .83265 m .41013 .83301 L .40988 .8327 L F
.154 0 0 r
.40999 .8327 m .40947 .83278 L .40778 .83265 L F
.602 .427 .616 r
.40778 .83265 m .40988 .8327 L .40783 .83006 L F
0 0 0 r
.41095 .83256 m .4122 .83245 L .41227 .83175 L F
.41095 .83256 m .41013 .83301 L .4122 .83245 L F
.4122 .83245 m .41095 .83256 L .41227 .83175 L F
.609 .768 .956 r
.4122 .83245 m .41013 .83301 L .41018 .83269 L F
0 0 0 r
.41175 .83249 m .40968 .83275 L .41095 .83256 L F
.4122 .83245 m .41018 .83269 L .41175 .83249 L F
.41018 .83269 m .40968 .83275 L .41175 .83249 L F
.719 .867 .951 r
.41042 .83113 m .41018 .83269 L .40947 .83278 L F
.41018 .83269 m .41013 .83301 L .40947 .83278 L F
.609 .768 .956 r
.4122 .83245 m .41018 .83269 L .41042 .83113 L F
0 0 0 r
.4122 .83245 m .40947 .83278 L .40968 .83275 L F
.637 .455 .62 r
.4056 .83251 m .40482 .82978 L .40462 .83032 L F
.675 .196 .107 r
.40448 .82974 m .40482 .82978 L .40464 .82966 L F
.11 .619 .896 r
.40947 .83278 m .41013 .83301 L .40778 .83265 L F
.803 .641 .682 r
.40462 .83032 m .40482 .82978 L .40448 .82974 L F
.221 0 .294 r
.41227 .83175 m .4122 .83245 L .41362 .83139 L F
.41362 .83139 m .4122 .83245 L .41227 .83175 L F
.719 .867 .951 r
.41042 .83113 m .40947 .83278 L .4122 .83245 L F
.689 .785 .924 r
.41362 .83139 m .4122 .83245 L .41042 .83113 L F
.41362 .83139 m .4122 .83245 L .41042 .83113 L F
.57 .384 .591 r
.42393 .83129 m .42624 .83113 L .42609 .82874 L F
.42393 .83129 m .42624 .83113 L .42609 .82874 L F
.636 .812 .967 r
.43494 .83258 m .43813 .83283 L .43712 .83194 L F
.43712 .83194 m .43813 .83283 L .43494 .83258 L F
.382 .697 .983 r
.43889 .83196 m .43813 .83283 L .43712 .83194 L F
.43712 .83194 m .43813 .83283 L .43889 .83196 L F
.513 .611 .888 r
.39821 .83118 m .39992 .83121 L .39848 .8316 L F
.2 .055 .449 r
.39992 .83121 m .39861 .83395 L .39848 .8316 L F
.504 .626 .904 r
.40013 .83113 m .39821 .83118 L .39698 .82985 L F
.40013 .83113 m .39992 .83121 L .39821 .83118 L F
.636 .553 .744 r
.4078 .85825 m .40757 .85616 L .40913 .85709 L F
.517 .789 .994 r
.41038 .85649 m .40913 .85709 L .40757 .85616 L F
.707 .322 .317 r
.40913 .85709 m .41087 .85887 L .4078 .85825 L F
.371 .325 .677 r
.41038 .85649 m .41087 .85887 L .40913 .85709 L F
.41038 .85649 m .41087 .85887 L .40913 .85709 L F
.2 .055 .449 r
.39992 .83121 m .39953 .83352 L .39861 .83395 L F
0 0 .007 r
.39861 .83395 m .39953 .83352 L .39809 .83493 L F
.601 .522 .737 r
.40508 .85767 m .40382 .85919 L .4037 .85826 L F
.40598 .85729 m .40519 .85798 L .40508 .85767 L F
.40519 .85798 m .40382 .85919 L .40508 .85767 L F
.40598 .85729 m .40584 .85875 L .40382 .85919 L F
.6 .472 .678 r
.40584 .85875 m .40409 .8616 L .40382 .85919 L F
.32 0 .115 r
.40272 .86102 m .40556 .85895 L .40275 .85873 L F
.40556 .85895 m .40584 .85875 L .40548 .85875 L F
.40556 .85895 m .40548 .85875 L .40275 .85873 L F
.758 .662 .756 r
.40275 .85873 m .40598 .85729 L .4037 .85826 L F
.521 .529 .805 r
.40478 .8641 m .40522 .86413 L .40483 .86422 L F
.348 .015 .251 r
.40483 .86422 m .40522 .86413 L .40478 .86435 L F
.348 .184 .512 r
.40003 .83297 m .39992 .83121 L .40013 .83113 L F
.40003 .83297 m .39953 .83352 L .39992 .83121 L F
.524 .521 .795 r
.4066 .8638 m .40478 .8641 L .40409 .8616 L F
.4066 .8638 m .40522 .86413 L .40478 .8641 L F
.624 .43 .599 r
.4066 .8638 m .40478 .86435 L .40522 .86413 L F
.4066 .8638 m .40425 .86628 L .40478 .86435 L F
.504 .626 .904 r
.40013 .83113 m .39698 .82985 L .39901 .82987 L F
.665 .708 .88 r
.40214 .83068 m .40013 .83113 L .39901 .82987 L F
.595 .387 .569 r
.40013 .83113 m .40206 .83319 L .40003 .83297 L F
.604 .388 .561 r
.40214 .83068 m .40206 .83319 L .40013 .83113 L F
.6 .472 .678 r
.40584 .85875 m .40617 .8611 L .40409 .8616 L F
.524 .521 .795 r
.4066 .8638 m .40409 .8616 L .40617 .8611 L F
.575 .668 .902 r
.3977 .82782 m .39698 .82985 L .39574 .8285 L F
.3977 .82782 m .39901 .82987 L .39698 .82985 L F
.495 .265 .496 r
.40003 .83297 m .39809 .83493 L .39953 .83352 L F
.40003 .83297 m .39769 .83584 L .39809 .83493 L F
.679 .682 .846 r
.4037 .82896 m .40516 .831 L .40214 .83068 L F
.704 .471 .569 r
.40524 .83269 m .40214 .83068 L .40516 .831 L F
.635 .667 .863 r
.40732 .83079 m .40516 .831 L .4037 .82896 L F
.61 .383 .548 r
.40732 .83079 m .40524 .83269 L .40516 .831 L F
.758 .662 .756 r
.40275 .85873 m .40584 .85875 L .40598 .85729 L F
.32 0 .115 r
.40272 .86102 m .40436 .86085 L .40584 .85875 L F
.636 .553 .744 r
.40598 .85729 m .40584 .85875 L .4078 .85825 L F
.608 .473 .671 r
.4078 .85825 m .40617 .8611 L .40584 .85875 L F
.273 0 .041 r
.40436 .86085 m .4078 .85825 L .40584 .85875 L F
.636 .553 .744 r
.4078 .85825 m .40584 .85875 L .40598 .85729 L F
.665 .708 .88 r
.40214 .83068 m .39901 .82987 L .40091 .82858 L F
.702 .721 .865 r
.4037 .82896 m .40214 .83068 L .40091 .82858 L F
.704 .471 .569 r
.40524 .83269 m .40206 .83319 L .40214 .83068 L F
.517 .789 .994 r
.41038 .85649 m .40757 .85616 L .41005 .85572 L F
.434 .653 .951 r
.4116 .85568 m .41038 .85649 L .41005 .85572 L F
.931 .731 .611 r
.4116 .85568 m .41087 .85887 L .41038 .85649 L F
.636 .553 .744 r
.40598 .85729 m .4078 .85825 L .40757 .85616 L F
.4078 .85825 m .40598 .85729 L .40757 .85616 L F
.608 .473 .671 r
.4078 .85825 m .40836 .86146 L .40617 .8611 L F
.625 .511 .704 r
.40836 .86146 m .4066 .8638 L .40617 .8611 L F
.495 .265 .496 r
.40003 .83297 m .39988 .83577 L .39769 .83584 L F
.59 .343 .51 r
.40206 .83319 m .39988 .83577 L .40003 .83297 L F
.236 .214 .629 r
.40949 .86052 m .4078 .85825 L .41087 .85887 L F
.931 .731 .611 r
.4116 .85568 m .41294 .85855 L .41087 .85887 L F
.76 .39 .353 r
.41278 .86089 m .40949 .86052 L .41087 .85887 L F
.588 .415 .614 r
.41294 .85855 m .41278 .86089 L .41099 .859 L F
.688 .5 .628 r
.41567 .86077 m .41294 .85855 L .41497 .85806 L F
.41567 .86077 m .41278 .86089 L .41294 .85855 L F
.185 0 0 r
.41136 .85966 m .41492 .85808 L .41294 .85855 L F
.41492 .85808 m .41497 .85806 L .41294 .85855 L F
.588 .415 .614 r
.41294 .85855 m .41099 .859 L .41087 .85887 L F
0 0 0 r
.4078 .85825 m .41005 .85572 L .40757 .85616 L F
.635 .667 .863 r
.40732 .83079 m .4037 .82896 L .4059 .82884 L F
.682 .492 .624 r
.40732 .83079 m .40721 .83348 L .40524 .83269 L F
.669 .704 .873 r
.40937 .8302 m .40732 .83079 L .4059 .82884 L F
.753 .553 .626 r
.41046 .83337 m .40732 .83079 L .40937 .8302 L F
.41046 .83337 m .40721 .83348 L .40732 .83079 L F
.669 .711 .879 r
.40091 .82858 m .39901 .82987 L .3977 .82782 L F
.273 0 .041 r
.40436 .86085 m .40569 .86079 L .4078 .85825 L F
0 0 0 r
.4078 .85825 m .40859 .8578 L .41005 .85572 L F
.691 .317 .334 r
.4078 .85825 m .40949 .86052 L .40859 .8578 L F
.236 .214 .629 r
.40949 .86052 m .40836 .86146 L .4078 .85825 L F
.691 .317 .334 r
.4078 .85825 m .40569 .86079 L .40949 .86052 L F
.624 .43 .599 r
.4066 .8638 m .40664 .86613 L .40425 .86628 L F
.625 .511 .704 r
.40836 .86146 m .40873 .86363 L .4066 .8638 L F
.626 .441 .611 r
.40873 .86363 m .40664 .86613 L .4066 .8638 L F
.569 .094 .089 r
.41046 .83337 m .4084 .8345 L .40721 .83348 L F
.584 .473 .693 r
.41206 .831 m .41046 .83337 L .40937 .8302 L F
.41206 .831 m .41255 .83342 L .41046 .83337 L F
.48 0 .037 r
.41255 .83342 m .4084 .8345 L .41046 .83337 L F
.657 .513 .676 r
.39988 .83577 m .39734 .83798 L .39769 .83584 L F
.647 .45 .603 r
.40664 .86613 m .4041 .86853 L .40425 .86628 L F
.572 .169 .239 r
.40524 .83269 m .40403 .83348 L .40206 .83319 L F
.63 .189 .182 r
.40721 .83348 m .40403 .83348 L .40524 .83269 L F
.669 .704 .873 r
.40937 .8302 m .4059 .82884 L .40783 .82848 L F
.635 .731 .918 r
.4117 .82957 m .40937 .8302 L .40783 .82848 L F
.63 .619 .821 r
.4117 .82957 m .41206 .831 L .40937 .8302 L F
.702 .721 .865 r
.4037 .82896 m .40091 .82858 L .40283 .82801 L F
.55 .735 .962 r
.4049 .82773 m .4037 .82896 L .40283 .82801 L F
.4049 .82773 m .4059 .82884 L .4037 .82896 L F
.609 .607 .823 r
.40949 .86052 m .40873 .86363 L .40836 .86146 L F
.931 .731 .611 r
.4116 .85568 m .41159 .85865 L .41294 .85855 L F
.885 .555 .419 r
.41159 .85865 m .41136 .85966 L .41294 .85855 L F
.634 .569 .764 r
.41497 .85806 m .41294 .85855 L .41476 .85611 L F
.41497 .85806 m .41294 .85855 L .41476 .85611 L F
.65 .497 .663 r
.40859 .8578 m .4116 .85568 L .41005 .85572 L F
.626 .441 .611 r
.40873 .86363 m .40875 .86598 L .40664 .86613 L F
.609 .607 .823 r
.40949 .86052 m .41081 .86346 L .40873 .86363 L F
.498 .288 .525 r
.41081 .86346 m .40875 .86598 L .40873 .86363 L F
.59 .343 .51 r
.40206 .83319 m .40189 .83557 L .39988 .83577 L F
.573 .328 .507 r
.40376 .83517 m .40206 .83319 L .40403 .83348 L F
.40376 .83517 m .40189 .83557 L .40206 .83319 L F
.463 .507 .818 r
.41334 .82964 m .41206 .831 L .4117 .82957 L F
.576 .468 .694 r
.41454 .83305 m .41206 .831 L .41334 .82964 L F
.41454 .83305 m .41255 .83342 L .41206 .831 L F
.645 .744 .921 r
.3951 .8278 m .3977 .82782 L .39574 .8285 L F
.63 .189 .182 r
.40721 .83348 m .40613 .83499 L .40403 .83348 L F
.554 .103 .136 r
.4084 .8345 m .40613 .83499 L .40721 .83348 L F
.281 0 .009 r
.40231 .8615 m .40436 .86085 L .40272 .86102 L F
.647 .45 .603 r
.40664 .86613 m .40648 .86797 L .4041 .86853 L F
.569 .347 .539 r
.40875 .86598 m .40648 .86797 L .40664 .86613 L F
.48 0 .037 r
.41255 .83342 m .41131 .83489 L .4084 .8345 L F
.296 0 0 r
.41311 .83447 m .41255 .83342 L .41454 .83305 L F
.41311 .83447 m .41131 .83489 L .41255 .83342 L F
.669 .711 .879 r
.40091 .82858 m .3977 .82782 L .39969 .82728 L F
.641 .736 .918 r
.40283 .82801 m .40091 .82858 L .39969 .82728 L F
.332 .757 .974 r
.4193 .85566 m .42001 .85588 L .41848 .85573 L F
.41859 .85564 m .41848 .85573 L .41701 .85559 L F
.4193 .85566 m .41848 .85573 L .41859 .85564 L F
0 0 0 r
.41859 .85564 m .41923 .85456 L .41701 .85559 L F
.332 .757 .974 r
.41767 .85515 m .41863 .85545 L .41701 .85559 L F
.41863 .85545 m .4193 .85566 L .41727 .8556 L F
.41863 .85545 m .41727 .8556 L .41701 .85559 L F
.707 .538 .657 r
.42007 .85824 m .41806 .8565 L .42001 .85588 L F
.41806 .8565 m .41701 .85559 L .41848 .85573 L F
.41806 .8565 m .41848 .85573 L .42001 .85588 L F
.651 .506 .673 r
.41701 .85559 m .41757 .85736 L .41497 .85806 L F
.41757 .85736 m .4179 .85842 L .417 .85831 L F
.41757 .85736 m .417 .85831 L .41497 .85806 L F
.707 .538 .657 r
.42007 .85824 m .41757 .85736 L .41806 .8565 L F
.583 .488 .712 r
.41765 .86046 m .41497 .85806 L .4179 .85842 L F
.41765 .86046 m .41567 .86077 L .41546 .85995 L F
.4162 .85916 m .41546 .85995 L .41497 .85806 L F
.41765 .86046 m .41546 .85995 L .4162 .85916 L F
.59 .656 .883 r
.41703 .85827 m .4179 .85842 L .41497 .85806 L F
.602 .391 .567 r
.41547 .86006 m .418 .85733 L .41718 .85812 L F
.41695 .85837 m .41718 .85812 L .41707 .85823 L F
.41547 .86006 m .41718 .85812 L .41695 .85837 L F
.41697 .85834 m .41707 .85823 L .41703 .85827 L F
.41547 .86006 m .41707 .85823 L .41697 .85834 L F
.707 .538 .657 r
.42007 .85824 m .4179 .85842 L .41764 .85761 L F
.4178 .85745 m .41764 .85761 L .41757 .85736 L F
.42007 .85824 m .41764 .85761 L .4178 .85745 L F
.41806 .8565 m .41757 .85736 L .41701 .85559 L F
0 0 0 r
.41747 .85753 m .41885 .85542 L .4186 .85563 L F
.41703 .85827 m .41719 .85802 L .41747 .85753 L F
.41719 .85802 m .41885 .85542 L .41747 .85753 L F
.41837 .85602 m .4186 .85563 L .41859 .85564 L F
.41703 .85827 m .4186 .85563 L .41837 .85602 L F
.41745 .85762 m .418 .85733 L .41885 .85542 L F
.41703 .85827 m .41716 .85815 L .41745 .85762 L F
.41716 .85815 m .418 .85733 L .41745 .85762 L F
.459 .881 .778 r
.42044 .85382 m .41923 .85456 L .42059 .85467 L F
.42044 .85382 m .4211 .85472 L .42192 .85479 L F
.127 .381 .837 r
.42172 .85556 m .4217 .85563 L .42044 .85382 L F
.489 .579 .872 r
.42059 .85467 m .4217 .85563 L .42079 .85576 L F
.42044 .85382 m .42105 .8547 L .42059 .85467 L F
.42105 .8547 m .4217 .85563 L .42059 .85467 L F
.42027 .85466 m .42079 .85576 L .42001 .85588 L F
.42044 .85382 m .42059 .85467 L .42027 .85466 L F
.42059 .85467 m .42079 .85576 L .42027 .85466 L F
.373 .025 .24 r
.42059 .85467 m .42171 .85497 L .4211 .85472 L F
.41923 .85456 m .42027 .85466 L .42029 .85465 L F
.41923 .85456 m .41891 .85528 L .41934 .85503 L F
.363 .809 .951 r
.41767 .85515 m .41701 .85559 L .41923 .85456 L F
.489 .579 .872 r
.4203 .85448 m .41934 .85503 L .41767 .85515 L F
0 0 0 r
.41859 .85564 m .41877 .85549 L .41923 .85456 L F
.489 .579 .872 r
.41934 .85503 m .42001 .85588 L .41863 .85545 L F
.42027 .85466 m .42001 .85588 L .41934 .85503 L F
.472 .381 .671 r
.4217 .85563 m .42206 .85791 L .42001 .85588 L F
.549 .387 .614 r
.42206 .85791 m .42007 .85824 L .42001 .85588 L F
.373 .025 .24 r
.41966 .85463 m .41971 .85658 L .42171 .85497 L F
.41971 .85658 m .41971 .85667 L .41985 .85655 L F
.41971 .85658 m .41985 .85655 L .42171 .85497 L F
.489 .579 .872 r
.4203 .85448 m .42027 .85466 L .41934 .85503 L F
.373 .025 .24 r
.41925 .85461 m .41934 .85503 L .41966 .85463 L F
.41934 .85503 m .41971 .85667 L .41966 .8549 L F
.41934 .85503 m .41966 .8549 L .41966 .85463 L F
0 0 0 r
.41877 .85549 m .41891 .85528 L .41923 .85456 L F
.373 .025 .24 r
.41923 .85456 m .41966 .85463 L .42027 .85466 L F
.42029 .85465 m .42027 .85466 L .42059 .85467 L F
.41966 .85463 m .42171 .85497 L .42059 .85467 L F
.41923 .85456 m .41925 .85461 L .41966 .85463 L F
.459 .881 .778 r
.42044 .85382 m .41767 .85515 L .41923 .85456 L F
.489 .579 .872 r
.42044 .85382 m .4203 .85448 L .41767 .85515 L F
.127 .381 .837 r
.42195 .85507 m .42172 .85556 L .4213 .85499 L F
.42171 .85497 m .4213 .85499 L .4211 .85472 L F
.42195 .85507 m .4213 .85499 L .42171 .85497 L F
.723 .481 .559 r
.42171 .85497 m .42201 .85496 L .42192 .85479 L F
.41985 .85655 m .42201 .85496 L .42171 .85497 L F
.41971 .85667 m .41992 .85651 L .41985 .85655 L F
.41992 .85651 m .42201 .85496 L .41985 .85655 L F
0 0 .256 r
.42214 .85699 m .4217 .85563 L .42201 .85496 L F
.42214 .85699 m .42206 .85791 L .4217 .85563 L F
.723 .481 .559 r
.41971 .85667 m .42214 .85699 L .42201 .85496 L F
.749 .738 .842 r
.42073 .85609 m .41826 .85399 L .4205 .85378 L F
.42075 .85631 m .42059 .85616 L .42073 .85609 L F
.42059 .85616 m .41826 .85399 L .42073 .85609 L F
.42076 .85637 m .42071 .85633 L .42075 .85631 L F
.42071 .85633 m .41826 .85399 L .42075 .85631 L F
0 0 0 r
.41877 .85549 m .41885 .85542 L .41891 .85528 L F
.489 .579 .872 r
.41898 .85518 m .41863 .85545 L .41846 .8554 L F
.41934 .85503 m .41891 .85528 L .41898 .85518 L F
.41891 .85528 m .41863 .85545 L .41898 .85518 L F
.41934 .85503 m .41846 .8554 L .41767 .85515 L F
.373 .025 .24 r
.4211 .85472 m .42171 .85497 L .42192 .85479 L F
.127 .381 .837 r
.42201 .85496 m .42195 .85507 L .42044 .85382 L F
.42195 .85507 m .4211 .85472 L .42044 .85382 L F
.459 .881 .778 r
.42044 .85382 m .42059 .85467 L .4211 .85472 L F
.373 .025 .24 r
.41934 .85503 m .41885 .85542 L .41942 .85536 L F
.41891 .85528 m .41885 .85542 L .41934 .85503 L F
.41942 .85536 m .418 .85733 L .41971 .85667 L F
.41885 .85542 m .418 .85733 L .41942 .85536 L F
0 0 0 r
.41703 .85827 m .41859 .85564 L .41701 .85559 L F
.185 0 0 r
.41136 .85966 m .41347 .85935 L .41497 .85806 L F
.646 .499 .669 r
.41701 .85559 m .41497 .85806 L .41476 .85611 L F
.41701 .85559 m .41703 .85827 L .41497 .85806 L F
.674 .246 .222 r
.41347 .85935 m .41703 .85827 L .41497 .85806 L F
.651 .506 .673 r
.41701 .85559 m .41497 .85806 L .41476 .85611 L F
.794 .694 .754 r
.41278 .86089 m .41081 .86346 L .40949 .86052 L F
.618 .439 .619 r
.41278 .86089 m .41288 .86332 L .41081 .86346 L F
.637 .455 .619 r
.41542 .86294 m .41278 .86089 L .41567 .86077 L F
.41542 .86294 m .41288 .86332 L .41278 .86089 L F
.609 .365 .523 r
.40648 .86797 m .40378 .87071 L .4041 .86853 L F
.562 .912 .966 r
.41701 .85559 m .41476 .85611 L .41639 .85533 L F
.41701 .85559 m .41476 .85611 L .41639 .85533 L F
.363 .809 .951 r
.41767 .85515 m .41639 .85533 L .41701 .85559 L F
.332 .757 .974 r
.41767 .85515 m .41701 .85559 L .41639 .85533 L F
.587 .751 .956 r
.40783 .82848 m .4059 .82884 L .4049 .82773 L F
.635 .731 .918 r
.4117 .82957 m .40783 .82848 L .41 .82819 L F
.409 .606 .929 r
.41202 .8279 m .4117 .82957 L .41 .82819 L F
.41202 .8279 m .41334 .82964 L .4117 .82957 L F
.587 .383 .572 r
.41765 .86046 m .41542 .86294 L .41567 .86077 L F
.498 .288 .525 r
.41081 .86346 m .4106 .86561 L .40875 .86598 L F
.6 .375 .547 r
.41254 .86524 m .41081 .86346 L .41288 .86332 L F
.41254 .86524 m .4106 .86561 L .41081 .86346 L F
.657 .513 .676 r
.39988 .83577 m .39981 .83817 L .39734 .83798 L F
.67 .558 .719 r
.39981 .83817 m .39784 .8405 L .39734 .83798 L F
.541 .271 .454 r
.40403 .83348 m .40613 .83499 L .40376 .83517 L F
.65 .497 .663 r
.40859 .8578 m .41159 .85865 L .4116 .85568 L F
.554 .405 .633 r
.40859 .8578 m .41136 .85966 L .41159 .85865 L F
.40859 .8578 m .40949 .86052 L .41136 .85966 L F
.662 .72 .892 r
.39654 .82643 m .3951 .8278 L .3945 .82702 L F
.39654 .82643 m .3977 .82782 L .3951 .8278 L F
.569 .347 .539 r
.40875 .86598 m .40852 .86803 L .40648 .86797 L F
.578 .355 .541 r
.40875 .86598 m .41054 .86793 L .40852 .86803 L F
.518 .349 .592 r
.4106 .86561 m .41054 .86793 L .40875 .86598 L F
.67 .558 .719 r
.39981 .83817 m .39813 .84048 L .39784 .8405 L F
.669 .537 .695 r
.39784 .8405 m .39813 .84048 L .39788 .84076 L F
.654 .523 .691 r
.39979 .84004 m .39839 .84304 L .39788 .84076 L F
.39979 .84004 m .40104 .8431 L .39839 .84304 L F
.632 .468 .642 r
.40104 .8431 m .39865 .84545 L .39839 .84304 L F
.654 .523 .691 r
.39979 .84004 m .39788 .84076 L .39813 .84048 L F
.628 .708 .904 r
.39969 .82728 m .3977 .82782 L .39654 .82643 L F
.705 .607 .744 r
.39979 .84004 m .39813 .84048 L .39981 .83817 L F
.609 .365 .523 r
.40648 .86797 m .40653 .87071 L .40378 .87071 L F
.58 .35 .531 r
.40852 .86803 m .40653 .87071 L .40648 .86797 L F
.669 .606 .776 r
.40187 .83773 m .39979 .84004 L .39981 .83817 L F
.40187 .83773 m .40293 .84047 L .39979 .84004 L F
.645 .518 .694 r
.40301 .84274 m .39979 .84004 L .40293 .84047 L F
.40301 .84274 m .40104 .8431 L .39979 .84004 L F
.613 .476 .671 r
.40187 .83773 m .39988 .83577 L .40189 .83557 L F
.40187 .83773 m .39981 .83817 L .39988 .83577 L F
.628 .872 .988 r
.40295 .86009 m .40231 .8615 L .40101 .86205 L F
.40295 .86009 m .40436 .86085 L .40231 .8615 L F
.674 .246 .222 r
.41347 .85935 m .41547 .86006 L .41703 .85827 L F
.59 .751 .954 r
.40166 .82686 m .40283 .82801 L .39969 .82728 L F
.563 .699 .932 r
.40365 .8264 m .40283 .82801 L .40166 .82686 L F
.40365 .8264 m .4049 .82773 L .40283 .82801 L F
.581 .342 .52 r
.42007 .85824 m .41765 .86046 L .4179 .85842 L F
.42007 .85824 m .41976 .86041 L .41765 .86046 L F
.589 .35 .522 r
.42193 .86011 m .42007 .85824 L .42206 .85791 L F
.42193 .86011 m .41976 .86041 L .42007 .85824 L F
.597 .56 .783 r
.41651 .83255 m .41454 .83305 L .41334 .82964 L F
.466 .002 .067 r
.4164 .83361 m .41454 .83305 L .41651 .83255 L F
.4164 .83361 m .41311 .83447 L .41454 .83305 L F
.607 .573 .789 r
.40499 .8402 m .40293 .84047 L .40187 .83773 L F
.588 .431 .636 r
.40499 .8402 m .40301 .84274 L .40293 .84047 L F
.632 .468 .642 r
.40104 .8431 m .40096 .84534 L .39865 .84545 L F
.652 .506 .672 r
.40096 .84534 m .39886 .84784 L .39865 .84545 L F
.659 .426 .556 r
.41568 .86463 m .41288 .86332 L .41542 .86294 L F
.41568 .86463 m .41254 .86524 L .41288 .86332 L F
.633 .468 .642 r
.40301 .84274 m .40096 .84534 L .40104 .8431 L F
.564 .889 .988 r
.39511 .82603 m .3945 .82702 L .39323 .82616 L F
.39511 .82603 m .39654 .82643 L .3945 .82702 L F
.587 .751 .956 r
.40783 .82848 m .4049 .82773 L .40685 .82698 L F
.589 .661 .888 r
.40894 .8265 m .40783 .82848 L .40685 .82698 L F
.40894 .8265 m .41 .82819 L .40783 .82848 L F
.587 .448 .659 r
.40387 .83726 m .40189 .83557 L .40376 .83517 L F
.40387 .83726 m .40187 .83773 L .40189 .83557 L F
.587 .383 .572 r
.41765 .86046 m .4178 .86286 L .41542 .86294 L F
.685 .515 .651 r
.41976 .86041 m .4178 .86286 L .41765 .86046 L F
.384 .442 .797 r
.40548 .8597 m .40436 .86085 L .40295 .86009 L F
.40548 .8597 m .40569 .86079 L .40436 .86085 L F
.628 .708 .904 r
.39969 .82728 m .39654 .82643 L .39853 .82606 L F
.597 .725 .933 r
.40166 .82686 m .39969 .82728 L .39853 .82606 L F
.652 .506 .672 r
.40096 .84534 m .39929 .84782 L .39886 .84784 L F
.65 .489 .653 r
.39886 .84784 m .39929 .84782 L .39891 .84844 L F
.68 .534 .68 r
.40306 .845 m .40096 .84534 L .40301 .84274 L F
.652 .519 .688 r
.40517 .8423 m .40301 .84274 L .40499 .8402 L F
.646 .507 .679 r
.40579 .84459 m .40301 .84274 L .40517 .8423 L F
.40579 .84459 m .40306 .845 L .40301 .84274 L F
.674 .536 .688 r
.40111 .84755 m .39929 .84782 L .40096 .84534 L F
.647 .485 .651 r
.40111 .84755 m .39891 .84844 L .39929 .84782 L F
.615 .428 .606 r
.40653 .87071 m .40379 .87303 L .40378 .87071 L F
.597 .43 .627 r
.4178 .86286 m .41568 .86463 L .41542 .86294 L F
.617 .492 .687 r
.40326 .84728 m .40096 .84534 L .40306 .845 L F
.40326 .84728 m .40111 .84755 L .40096 .84534 L F
.58 .35 .531 r
.40852 .86803 m .4086 .87039 L .40653 .87071 L F
.614 .375 .532 r
.41044 .87015 m .40852 .86803 L .41054 .86793 L F
.41044 .87015 m .4086 .87039 L .40852 .86803 L F
.647 .485 .651 r
.40111 .84755 m .39913 .85026 L .39891 .84844 L F
.129 .677 .772 r
.40569 .86079 m .40753 .86059 L .40949 .86052 L F
.316 .804 .868 r
.40949 .86052 m .41013 .86004 L .41136 .85966 L F
.40949 .86052 m .40753 .86059 L .41013 .86004 L F
.66 .488 .64 r
.41254 .86524 m .41054 .86793 L .4106 .86561 L F
.607 .573 .789 r
.40499 .8402 m .40187 .83773 L .40387 .83726 L F
.536 .632 .893 r
.41404 .82752 m .41334 .82964 L .41202 .8279 L F
.41404 .82752 m .41518 .82948 L .41334 .82964 L F
.597 .56 .783 r
.41651 .83255 m .41334 .82964 L .41518 .82948 L F
.61 .423 .604 r
.40579 .84459 m .40326 .84728 L .40306 .845 L F
.647 .485 .651 r
.40111 .84755 m .40202 .85097 L .39913 .85026 L F
.62 .47 .656 r
.40362 .85056 m .40111 .84755 L .40326 .84728 L F
.40362 .85056 m .40202 .85097 L .40111 .84755 L F
.639 .585 .778 r
.40711 .83983 m .40499 .8402 L .40387 .83726 L F
.63 .502 .688 r
.40729 .84185 m .40499 .8402 L .40711 .83983 L F
.40729 .84185 m .40517 .8423 L .40499 .8402 L F
.43 .833 .977 r
.39853 .82606 m .39654 .82643 L .39511 .82603 L F
.578 .418 .629 r
.40613 .83499 m .40387 .83726 L .40376 .83517 L F
.672 .736 .899 r
.40685 .82698 m .4049 .82773 L .40365 .8264 L F
.641 .486 .657 r
.40202 .85097 m .39937 .85268 L .39913 .85026 L F
.922 .87 .77 r
.42193 .86011 m .42206 .85791 L .42384 .85985 L F
.525 .339 .571 r
.42206 .85791 m .42384 .85985 L .42193 .86011 L F
.922 .87 .77 r
.42196 .85956 m .42214 .85699 L .42206 .85791 L F
.42193 .86011 m .42196 .85963 L .42196 .85956 L F
.42196 .85963 m .42214 .85699 L .42196 .85956 L F
.42193 .86011 m .42167 .86005 L .42214 .85699 L F
.42167 .86005 m .42057 .85982 L .42157 .85802 L F
.42167 .86005 m .42157 .85802 L .42214 .85699 L F
.23 .325 .755 r
.42236 .85553 m .42386 .8579 L .4215 .85674 L F
.42146 .856 m .4215 .85674 L .42076 .85637 L F
.42236 .85553 m .4215 .85674 L .42146 .856 L F
.304 0 0 r
.42057 .85982 m .42384 .85985 L .42193 .86011 L F
.42196 .85984 m .4225 .86006 L .42384 .85985 L F
.42057 .85982 m .42195 .85999 L .42196 .85984 L F
.42195 .85999 m .4225 .86006 L .42196 .85984 L F
.554 .556 .811 r
.41832 .83205 m .41651 .83255 L .41518 .82948 L F
.57 .371 .572 r
.41832 .83205 m .4164 .83361 L .41651 .83255 L F
.684 .472 .594 r
.4084 .8345 m .40596 .83661 L .40613 .83499 L F
.4084 .8345 m .40896 .83776 L .40596 .83661 L F
.591 .409 .605 r
.41104 .83714 m .4084 .8345 L .41131 .83489 L F
.41104 .83714 m .40896 .83776 L .4084 .8345 L F
.599 .458 .661 r
.40729 .84185 m .40579 .84459 L .40517 .8423 L F
.66 .488 .64 r
.41254 .86524 m .41281 .86808 L .41054 .86793 L F
.605 .397 .572 r
.41568 .86463 m .41281 .86808 L .41254 .86524 L F
.685 .515 .651 r
.41976 .86041 m .41985 .86277 L .4178 .86286 L F
.393 .824 .96 r
.41976 .86041 m .42057 .85982 L .42193 .86011 L F
.41976 .86041 m .42057 .85982 L .42193 .86011 L F
.654 .511 .676 r
.42193 .86011 m .41985 .86277 L .41976 .86041 L F
.605 .397 .572 r
.41568 .86463 m .41644 .8682 L .41281 .86808 L F
.597 .43 .627 r
.4178 .86286 m .41766 .86507 L .41568 .86463 L F
.608 .398 .572 r
.41759 .86741 m .41568 .86463 L .41766 .86507 L F
.41759 .86741 m .41644 .8682 L .41568 .86463 L F
.56 .7 .934 r
.41077 .8265 m .41 .82819 L .40894 .8265 L F
.41077 .8265 m .41202 .8279 L .41 .82819 L F
.641 .486 .657 r
.40202 .85097 m .40197 .85296 L .39937 .85268 L F
.671 .472 .608 r
.40198 .85486 m .39937 .85268 L .40197 .85296 L F
.40198 .85486 m .39967 .85511 L .39937 .85268 L F
.597 .725 .933 r
.40166 .82686 m .39853 .82606 L .40054 .82579 L F
.613 .757 .948 r
.40365 .8264 m .40166 .82686 L .40054 .82579 L F
.579 .008 0 r
.42192 .85479 m .42201 .85496 L .42044 .85382 L F
.61 .423 .604 r
.40579 .84459 m .40664 .84772 L .40326 .84728 L F
.599 .458 .661 r
.40729 .84185 m .4081 .84494 L .40579 .84459 L F
.628 .434 .6 r
.40813 .84726 m .40579 .84459 L .4081 .84494 L F
.40813 .84726 m .40664 .84772 L .40579 .84459 L F
.615 .428 .606 r
.40653 .87071 m .40631 .87221 L .40379 .87303 L F
.558 .298 .479 r
.40379 .87303 m .40332 .87506 L .40315 .87498 L F
.40379 .87303 m .40523 .87504 L .40332 .87506 L F
.40379 .87303 m .40631 .87221 L .40523 .87504 L F
.639 .585 .778 r
.40711 .83983 m .40387 .83726 L .40596 .83661 L F
.603 .537 .753 r
.4091 .83948 m .40711 .83983 L .40596 .83661 L F
.598 .485 .696 r
.4091 .83948 m .40729 .84185 L .40711 .83983 L F
.603 .356 .515 r
.41281 .86808 m .41044 .87015 L .41054 .86793 L F
.633 .518 .705 r
.40198 .85486 m .40042 .85774 L .39993 .85619 L F
.40198 .85486 m .4029 .85772 L .40042 .85774 L F
.664 .501 .653 r
.4029 .85772 m .40043 .86005 L .40042 .85774 L F
.686 .585 .737 r
.40596 .83661 m .40387 .83726 L .40613 .83499 L F
.586 .392 .586 r
.4086 .87039 m .40631 .87221 L .40653 .87071 L F
.246 .754 .874 r
.41136 .85966 m .41214 .8593 L .41347 .85935 L F
.29 .778 .709 r
.41136 .85966 m .41013 .86004 L .41214 .8593 L F
.573 .439 .66 r
.40625 .84982 m .40326 .84728 L .40664 .84772 L F
.40625 .84982 m .40362 .85056 L .40326 .84728 L F
.605 .391 .565 r
.41985 .86277 m .41766 .86507 L .4178 .86286 L F
.598 .485 .696 r
.4091 .83948 m .41004 .84275 L .40729 .84185 L F
.624 .485 .672 r
.41004 .84275 m .4081 .84494 L .40729 .84185 L F
.672 .736 .899 r
.40685 .82698 m .40365 .8264 L .40565 .82587 L F
.612 .762 .951 r
.40894 .8265 m .40685 .82698 L .40565 .82587 L F
.68 .567 .721 r
.39967 .85511 m .40108 .85507 L .39993 .85619 L F
.633 .518 .705 r
.40198 .85486 m .39993 .85619 L .40108 .85507 L F
.603 .537 .753 r
.4091 .83948 m .40596 .83661 L .40896 .83776 L F
.65 .493 .658 r
.40397 .85237 m .40202 .85097 L .40362 .85056 L F
.40397 .85237 m .40197 .85296 L .40202 .85097 L F
.605 .391 .565 r
.41985 .86277 m .41974 .86498 L .41766 .86507 L F
.654 .511 .676 r
.42193 .86011 m .42246 .86268 L .41985 .86277 L F
.638 .417 .566 r
.42246 .86268 m .41974 .86498 L .41985 .86277 L F
.671 .472 .608 r
.40198 .85486 m .40108 .85507 L .39967 .85511 L F
.43 .833 .977 r
.39853 .82606 m .39511 .82603 L .3971 .82552 L F
.442 .807 .995 r
.39903 .82518 m .39853 .82606 L .3971 .82552 L F
.39903 .82518 m .40054 .82579 L .39853 .82606 L F
.696 .708 .857 r
.4175 .82871 m .41518 .82948 L .41404 .82752 L F
.68 .618 .78 r
.4175 .82871 m .41785 .83026 L .41518 .82948 L F
.554 .556 .811 r
.41832 .83205 m .41518 .82948 L .41785 .83026 L F
.569 .544 .788 r
.4193 .82855 m .41785 .83026 L .4175 .82871 L F
.641 .572 .761 r
.4193 .82855 m .41832 .83205 L .41785 .83026 L F
.504 .411 .683 r
.42394 .86197 m .42193 .86011 L .42384 .85985 L F
.42394 .86197 m .42246 .86268 L .42193 .86011 L F
.603 .356 .515 r
.41281 .86808 m .41252 .87006 L .41044 .87015 L F
.626 .376 .52 r
.41559 .8695 m .41281 .86808 L .41644 .8682 L F
.41559 .8695 m .41252 .87006 L .41281 .86808 L F
.511 .48 .759 r
.40727 .85919 m .40569 .86079 L .40502 .85746 L F
0 0 .203 r
.40502 .85746 m .40569 .86079 L .40548 .8597 L F
.52 .495 .768 r
.40727 .85919 m .40753 .86059 L .40569 .86079 L F
.43 .757 .995 r
.39392 .82527 m .39323 .82616 L .39197 .82541 L F
.39392 .82527 m .39511 .82603 L .39323 .82616 L F
.671 .565 .726 r
.40397 .85237 m .40198 .85486 L .40197 .85296 L F
.664 .554 .72 r
.40397 .85237 m .40484 .85529 L .40198 .85486 L F
.665 .536 .698 r
.40502 .85746 m .40198 .85486 L .40484 .85529 L F
.40502 .85746 m .4029 .85772 L .40198 .85486 L F
.586 .392 .586 r
.4086 .87039 m .4083 .87226 L .40631 .87221 L F
.579 .342 .52 r
.40631 .87221 m .40741 .87498 L .40523 .87504 L F
.40631 .87221 m .4083 .87226 L .40741 .87498 L F
.672 .448 .573 r
.4164 .83361 m .41302 .8366 L .41311 .83447 L F
.4164 .83361 m .41639 .83725 L .41302 .8366 L F
.57 .371 .572 r
.41832 .83205 m .41816 .83429 L .4164 .83361 L F
.611 .399 .57 r
.41819 .8367 m .4164 .83361 L .41816 .83429 L F
.41819 .8367 m .41639 .83725 L .4164 .83361 L F
.664 .576 .747 r
.40043 .86005 m .40295 .86009 L .40101 .86205 L F
.628 .429 .594 r
.41974 .86498 m .41759 .86741 L .41766 .86507 L F
.604 .395 .571 r
.41044 .87015 m .4083 .87226 L .4086 .87039 L F
.625 .496 .685 r
.40603 .85195 m .40362 .85056 L .40625 .84982 L F
.40603 .85195 m .40397 .85237 L .40362 .85056 L F
.641 .572 .761 r
.4193 .82855 m .42041 .83224 L .41832 .83205 L F
.564 .366 .571 r
.41832 .83205 m .42025 .83408 L .41816 .83429 L F
.643 .365 .483 r
.42041 .83224 m .42025 .83408 L .41832 .83205 L F
.664 .501 .653 r
.4029 .85772 m .40295 .86009 L .40043 .86005 L F
.72 .545 .652 r
.40548 .8597 m .4029 .85772 L .40502 .85746 L F
.40548 .8597 m .40295 .86009 L .4029 .85772 L F
.613 .757 .948 r
.40365 .8264 m .40054 .82579 L .40246 .8254 L F
.611 .779 .961 r
.40565 .82587 m .40365 .8264 L .40246 .8254 L F
.638 .417 .566 r
.42246 .86268 m .42185 .86469 L .41974 .86498 L F
.657 .52 .686 r
.42394 .86197 m .42185 .86469 L .42246 .86268 L F
.737 .725 .84 r
.43094 .8293 m .42755 .82912 L .42943 .82717 L F
.701 .321 .325 r
.43094 .8293 m .42948 .83112 L .42755 .82912 L F
.561 .657 .9 r
.43263 .82809 m .43094 .8293 L .42943 .82717 L F
.592 .345 .511 r
.43263 .82809 m .42948 .83112 L .43094 .8293 L F
.696 .708 .857 r
.4175 .82871 m .41404 .82752 L .41599 .82693 L F
.551 .662 .91 r
.41799 .82643 m .4175 .82871 L .41599 .82693 L F
.41799 .82643 m .4193 .82855 L .4175 .82871 L F
.631 .531 .723 r
.41104 .83714 m .4091 .83948 L .40896 .83776 L F
.637 .539 .727 r
.4112 .83911 m .4091 .83948 L .41104 .83714 L F
.628 .504 .692 r
.41217 .84225 m .4091 .83948 L .4112 .83911 L F
.41217 .84225 m .41004 .84275 L .4091 .83948 L F
.591 .713 .928 r
.41404 .82752 m .41202 .8279 L .41077 .8265 L F
.641 .541 .725 r
.40695 .85488 m .40484 .85529 L .40397 .85237 L F
.601 .486 .694 r
.40709 .85718 m .40484 .85529 L .40695 .85488 L F
.40709 .85718 m .40502 .85746 L .40484 .85529 L F
.624 .485 .672 r
.41004 .84275 m .41004 .84472 L .4081 .84494 L F
.674 .488 .627 r
.41011 .84696 m .4081 .84494 L .41004 .84472 L F
.41011 .84696 m .40813 .84726 L .4081 .84494 L F
.641 .541 .725 r
.40695 .85488 m .40397 .85237 L .40603 .85195 L F
.612 .762 .951 r
.40894 .8265 m .40565 .82587 L .40772 .8255 L F
.442 .662 .955 r
.40964 .82528 m .40894 .8265 L .40772 .8255 L F
.40964 .82528 m .41077 .8265 L .40894 .8265 L F
.511 .48 .759 r
.40727 .85919 m .40502 .85746 L .40709 .85718 L F
.604 .395 .571 r
.41044 .87015 m .41033 .87212 L .4083 .87226 L F
.579 .374 .567 r
.41044 .87015 m .41236 .87217 L .41033 .87212 L F
.608 .374 .537 r
.41044 .87015 m .41252 .87006 L .41236 .87217 L F
.638 .475 .645 r
.41311 .83447 m .41104 .83714 L .41131 .83489 L F
.655 .58 .759 r
.42247 .82966 m .42041 .83224 L .4193 .82855 L F
.689 .631 .786 r
.4227 .83125 m .42041 .83224 L .42247 .82966 L F
.627 .351 .481 r
.42249 .83358 m .42041 .83224 L .4227 .83125 L F
.42249 .83358 m .42025 .83408 L .42041 .83224 L F
.639 .497 .674 r
.41211 .84433 m .41004 .84275 L .41217 .84225 L F
.41211 .84433 m .41004 .84472 L .41004 .84275 L F
.501 .832 .999 r
.40246 .8254 m .40054 .82579 L .39903 .82518 L F
.628 .429 .594 r
.41974 .86498 m .41969 .86727 L .41759 .86741 L F
.685 .498 .628 r
.42185 .86469 m .41969 .86727 L .41974 .86498 L F
.579 .335 .511 r
.41033 .87212 m .40741 .87498 L .4083 .87226 L F
.646 .47 .631 r
.40797 .8495 m .40664 .84772 L .40813 .84726 L F
.40797 .8495 m .40625 .84982 L .40664 .84772 L F
.648 .515 .688 r
.41302 .8366 m .4112 .83911 L .41104 .83714 L F
.41302 .8366 m .41423 .84004 L .4112 .83911 L F
.679 .532 .678 r
.41417 .84178 m .4112 .83911 L .41423 .84004 L F
.41417 .84178 m .41217 .84225 L .4112 .83911 L F
.645 .547 .729 r
.40909 .8546 m .40695 .85488 L .40603 .85195 L F
.635 .488 .666 r
.40909 .8546 m .40709 .85718 L .40695 .85488 L F
.6 .457 .659 r
.42616 .86135 m .42384 .85985 L .42528 .86032 L F
.42616 .86135 m .42394 .86197 L .42384 .85985 L F
.167 .679 .897 r
.4225 .86006 m .42528 .86032 L .42384 .85985 L F
.687 .543 .685 r
.41302 .8366 m .41104 .83714 L .41311 .83447 L F
.639 .5 .676 r
.41211 .84433 m .41011 .84696 L .41004 .84472 L F
.565 .842 .997 r
.39584 .82487 m .39511 .82603 L .39392 .82527 L F
.39584 .82487 m .3971 .82552 L .39511 .82603 L F
.359 .62 .951 r
.41435 .85873 m .41347 .85935 L .41214 .8593 L F
.41435 .85873 m .41547 .86006 L .41347 .85935 L F
.67 .578 .743 r
.40797 .8495 m .40603 .85195 L .40625 .84982 L F
.653 .555 .731 r
.40829 .85165 m .40603 .85195 L .40797 .8495 L F
.645 .547 .729 r
.40909 .8546 m .40603 .85195 L .40829 .85165 L F
.745 .663 .769 r
.42646 .8262 m .42755 .82912 L .42425 .82876 L F
.599 .316 .459 r
.42755 .82912 m .42498 .83099 L .42425 .82876 L F
.42755 .82912 m .42733 .83106 L .42498 .83099 L F
.684 .631 .79 r
.42943 .82717 m .42755 .82912 L .42646 .8262 L F
.624 .338 .463 r
.42755 .82912 m .42948 .83112 L .42733 .83106 L F
.725 .508 .596 r
.418 .85733 m .41748 .86008 L .42057 .85982 L F
.34 0 0 r
.4165 .85993 m .41949 .86013 L .41985 .86003 L F
.41843 .85988 m .41985 .86003 L .42057 .85982 L F
.602 .391 .567 r
.41547 .86006 m .41748 .86008 L .41754 .85978 L F
.34 0 0 r
.4165 .85993 m .42057 .85982 L .41748 .86008 L F
.4165 .85993 m .41985 .86003 L .41843 .85988 L F
.602 .391 .567 r
.41588 .85961 m .41754 .85978 L .418 .85733 L F
.41547 .86006 m .41754 .85978 L .41588 .85961 L F
.725 .508 .596 r
.418 .85733 m .42057 .85982 L .41971 .85667 L F
.608 .5 .705 r
.42425 .82876 m .4227 .83125 L .42247 .82966 L F
.42425 .82876 m .42498 .83099 L .4227 .83125 L F
.568 .362 .561 r
.42462 .83324 m .4227 .83125 L .42498 .83099 L F
.42462 .83324 m .42249 .83358 L .4227 .83125 L F
.677 .499 .639 r
.41011 .84696 m .40797 .8495 L .40813 .84726 L F
.611 .779 .961 r
.40565 .82587 m .40246 .8254 L .40452 .82501 L F
.545 .786 .988 r
.40772 .8255 m .40565 .82587 L .40452 .82501 L F
.724 .805 .915 r
.42444 .82666 m .42123 .82659 L .42322 .82556 L F
.714 .619 .749 r
.42425 .82876 m .42123 .82659 L .42444 .82666 L F
.599 .77 .961 r
.42646 .8262 m .42444 .82666 L .42322 .82556 L F
.745 .663 .769 r
.42646 .8262 m .42425 .82876 L .42444 .82666 L F
.579 .313 .478 r
.40315 .87498 m .40332 .87506 L .40313 .87507 L F
.648 .516 .688 r
.41613 .83933 m .41302 .8366 L .41639 .83725 L F
.41613 .83933 m .41423 .84004 L .41302 .8366 L F
.685 .498 .628 r
.42185 .86469 m .42262 .86628 L .41969 .86727 L F
.657 .52 .686 r
.42394 .86197 m .4248 .86456 L .42185 .86469 L F
.618 .428 .602 r
.4248 .86456 m .42262 .86628 L .42185 .86469 L F
.629 .434 .6 r
.42018 .83625 m .41816 .83429 L .42025 .83408 L F
.42018 .83625 m .41819 .8367 L .41816 .83429 L F
.639 .404 .547 r
.41559 .8695 m .41236 .87217 L .41252 .87006 L F
.6 .375 .548 r
.40332 .87506 m .40287 .87729 L .40313 .87507 L F
.627 .569 .77 r
.41013 .86004 m .40753 .86059 L .40727 .85919 L F
.628 .432 .597 r
.41759 .86741 m .41559 .8695 L .41644 .8682 L F
.681 .506 .642 r
.4101 .84928 m .40797 .8495 L .41011 .84696 L F
.638 .498 .675 r
.41241 .84667 m .41011 .84696 L .41211 .84433 L F
.675 .528 .678 r
.41241 .84667 m .4101 .84928 L .41011 .84696 L F
.628 .432 .597 r
.41759 .86741 m .4177 .8694 L .41559 .8695 L F
.65 .464 .618 r
.41969 .86727 m .4177 .8694 L .41759 .86741 L F
.741 .746 .856 r
.42123 .82659 m .4193 .82855 L .41799 .82643 L F
.649 .585 .77 r
.42123 .82659 m .42247 .82966 L .4193 .82855 L F
.6 .375 .548 r
.40332 .87506 m .40484 .87712 L .40287 .87729 L F
.625 .383 .531 r
.40332 .87506 m .40505 .87715 L .40484 .87712 L F
.40332 .87506 m .40523 .87504 L .40505 .87715 L F
.591 .713 .928 r
.41404 .82752 m .41077 .8265 L .41274 .82625 L F
.633 .749 .932 r
.41599 .82693 m .41404 .82752 L .41274 .82625 L F
.633 .485 .664 r
.40912 .85691 m .40709 .85718 L .40909 .8546 L F
.655 .529 .698 r
.40912 .85691 m .40727 .85919 L .40709 .85718 L F
.624 .508 .702 r
.42616 .86135 m .4248 .86456 L .42394 .86197 L F
.683 .546 .692 r
.41417 .84178 m .41211 .84433 L .41217 .84225 L F
.642 .488 .659 r
.41425 .84415 m .41211 .84433 L .41417 .84178 L F
.582 .419 .626 r
.41425 .84415 m .41241 .84667 L .41211 .84433 L F
.579 .335 .511 r
.41033 .87212 m .41143 .8745 L .40741 .87498 L F
.574 .341 .525 r
.41033 .87212 m .41242 .87382 L .41143 .8745 L F
.41033 .87212 m .41236 .87217 L .41242 .87382 L F
.663 .552 .72 r
.41136 .85432 m .40909 .8546 L .40829 .85165 L F
.65 .496 .661 r
.41136 .85432 m .40912 .85691 L .40909 .8546 L F
.651 .524 .695 r
.4101 .84928 m .40829 .85165 L .40797 .8495 L F
.4101 .84928 m .41107 .85215 L .40829 .85165 L F
.663 .552 .72 r
.41136 .85432 m .40829 .85165 L .41107 .85215 L F
.662 .556 .724 r
.41613 .83933 m .41417 .84178 L .41423 .84004 L F
.657 .548 .72 r
.4164 .84142 m .41417 .84178 L .41613 .83933 L F
.632 .472 .647 r
.4164 .84142 m .41425 .84415 L .41417 .84178 L F
.656 .762 .928 r
.41624 .8583 m .41547 .86006 L .41435 .85873 L F
.294 .337 .736 r
.41624 .8583 m .4165 .85993 L .41547 .86006 L F
.182 .697 .89 r
.4165 .85993 m .41748 .86008 L .41547 .86006 L F
.639 .404 .547 r
.41559 .8695 m .41443 .87231 L .41236 .87217 L F
.618 .381 .537 r
.41737 .87106 m .41559 .8695 L .4177 .8694 L F
.41737 .87106 m .41443 .87231 L .41559 .8695 L F
.655 .529 .698 r
.40912 .85691 m .41013 .86004 L .40727 .85919 L F
.322 .725 .98 r
.4999 .86402 m .49898 .86454 L .49778 .86472 L F
.4999 .86402 m .50123 .86484 L .49898 .86454 L F
.804 .383 .245 r
.49898 .86454 m .49836 .86613 L .49778 .86472 L F
.49898 .86454 m .50102 .8669 L .49836 .86613 L F
.678 .424 .531 r
.49898 .86454 m .50123 .86484 L .50102 .8669 L F
.721 .576 .692 r
.41971 .85667 m .42057 .85982 L .42214 .85699 L F
.714 .619 .749 r
.42425 .82876 m .42247 .82966 L .42123 .82659 L F
.749 .738 .842 r
.42076 .85637 m .41971 .85667 L .41826 .85399 L F
.278 0 .012 r
.42027 .8576 m .41971 .85667 L .42076 .85637 L F
.23 .325 .755 r
.42236 .85553 m .42076 .85637 L .4205 .85378 L F
.654 .458 .606 r
.42386 .8579 m .42027 .8576 L .42076 .85637 L F
.547 .306 .502 r
.42262 .86628 m .41968 .86967 L .41969 .86727 L F
.42262 .86628 m .42158 .86944 L .41968 .86967 L F
.596 .379 .557 r
.42679 .8668 m .42887 .86669 L .42886 .86675 L F
.428 .062 .239 r
.4272 .86687 m .42679 .8668 L .42782 .86678 L F
.596 .379 .557 r
.42708 .86708 m .42886 .86675 L .42873 .8687 L F
.634 .392 .535 r
.42782 .86678 m .42708 .86708 L .42488 .86721 L F
.596 .379 .557 r
.42679 .8668 m .42782 .86678 L .42708 .86708 L F
.428 .062 .239 r
.42782 .86678 m .42679 .8668 L .42798 .86675 L F
.596 .379 .557 r
.42679 .8668 m .42708 .86708 L .42798 .86675 L F
.42782 .86678 m .42886 .86675 L .42708 .86708 L F
.42708 .86708 m .42873 .8687 L .42798 .86675 L F
.634 .392 .535 r
.42708 .86708 m .42459 .8681 L .42463 .86797 L F
.42708 .86708 m .42463 .86797 L .42488 .86721 L F
.42798 .86675 m .42353 .87144 L .42459 .8681 L F
.42798 .86675 m .42459 .8681 L .42782 .86678 L F
.428 .062 .239 r
.42488 .86721 m .42679 .8668 L .4272 .86687 L F
.42488 .86721 m .4254 .86738 L .42679 .8668 L F
.636 .439 .599 r
.42679 .8668 m .4254 .86738 L .42522 .86654 L F
.42679 .8668 m .42522 .86654 L .4248 .86456 L F
.618 .428 .602 r
.4248 .86456 m .4254 .86738 L .42262 .86628 L F
.684 .446 .556 r
.42488 .86721 m .42262 .86628 L .4254 .86738 L F
.42488 .86721 m .42158 .86944 L .42262 .86628 L F
.442 .771 .997 r
.39219 .82422 m .39197 .82541 L .39068 .82505 L F
.39219 .82422 m .39392 .82527 L .39197 .82541 L F
.789 .753 .82 r
.41971 .85667 m .41617 .85671 L .41826 .85399 L F
.454 .017 .117 r
.41971 .85667 m .41624 .8583 L .41617 .85671 L F
.41971 .85667 m .41861 .85813 L .41624 .8583 L F
.278 0 .012 r
.42027 .8576 m .41861 .85813 L .41971 .85667 L F
.722 .646 .772 r
.51092 .82413 m .51223 .82606 L .50891 .82647 L F
.652 .35 .446 r
.50891 .82647 m .51223 .82606 L .51116 .82799 L F
.633 .569 .765 r
.51338 .82321 m .51223 .82606 L .51092 .82413 L F
.51338 .82321 m .51402 .82624 L .51223 .82606 L F
.601 .217 .287 r
.51223 .82606 m .51282 .82768 L .51116 .82799 L F
.51223 .82606 m .51402 .82624 L .51282 .82768 L F
.624 .508 .702 r
.42616 .86135 m .42668 .86467 L .4248 .86456 L F
.636 .439 .599 r
.42679 .8668 m .4248 .86456 L .42668 .86467 L F
.627 .398 .551 r
.40523 .87504 m .40718 .87731 L .40505 .87715 L F
.40523 .87504 m .40741 .87498 L .40718 .87731 L F
.553 .707 .942 r
.4116 .82501 m .41077 .8265 L .40964 .82528 L F
.4116 .82501 m .41274 .82625 L .41077 .8265 L F
.501 .832 .999 r
.40246 .8254 m .39903 .82518 L .40116 .82451 L F
.529 .81 .997 r
.4031 .8241 m .40246 .8254 L .40116 .82451 L F
.4031 .8241 m .40452 .82501 L .40246 .8254 L F
.65 .464 .618 r
.41969 .86727 m .41968 .86967 L .4177 .8694 L F
.65 .503 .67 r
.41819 .8367 m .41613 .83933 L .41639 .83725 L F
.675 .528 .678 r
.41241 .84667 m .41298 .84958 L .4101 .84928 L F
.695 .548 .683 r
.41319 .8516 m .4101 .84928 L .41298 .84958 L F
.41319 .8516 m .41107 .85215 L .4101 .84928 L F
.582 .419 .626 r
.41425 .84415 m .41431 .84647 L .41241 .84667 L F
.628 .497 .684 r
.41512 .84923 m .41241 .84667 L .41431 .84647 L F
.41512 .84923 m .41298 .84958 L .41241 .84667 L F
0 0 0 r
.42057 .85982 m .42176 .85976 L .4225 .86006 L F
.42057 .85982 m .41949 .86013 L .42176 .85976 L F
.774 .629 .7 r
.50869 .82434 m .50891 .82647 L .50574 .82618 L F
.692 .268 .235 r
.50574 .82618 m .50891 .82647 L .50764 .82761 L F
.655 .541 .714 r
.51092 .82413 m .50891 .82647 L .50869 .82434 L F
.415 0 0 r
.50891 .82647 m .50979 .8271 L .50764 .82761 L F
.50891 .82647 m .51116 .82799 L .50979 .8271 L F
.65 .496 .661 r
.41136 .85432 m .41175 .85736 L .40912 .85691 L F
.665 .534 .696 r
.41214 .8593 m .40912 .85691 L .41175 .85736 L F
.41214 .8593 m .41013 .86004 L .40912 .85691 L F
.716 .611 .738 r
.50831 .82351 m .50869 .82434 L .50583 .82388 L F
.774 .629 .7 r
.50869 .82434 m .50574 .82618 L .50583 .82388 L F
.648 .689 .875 r
.51021 .823 m .50869 .82434 L .50831 .82351 L F
.51021 .823 m .51092 .82413 L .50869 .82434 L F
.867 .895 .852 r
.50297 .86209 m .50123 .86484 L .4999 .86402 L F
.604 .512 .723 r
.50297 .86209 m .50357 .86483 L .50123 .86484 L F
.575 .295 .454 r
.50123 .86484 m .5031 .86661 L .50102 .8669 L F
.50123 .86484 m .50357 .86483 L .5031 .86661 L F
.684 .631 .79 r
.42943 .82717 m .42646 .8262 L .4284 .82589 L F
.588 .698 .918 r
.4315 .82677 m .42943 .82717 L .4284 .82589 L F
.561 .657 .9 r
.43263 .82809 m .42943 .82717 L .4315 .82677 L F
.503 .818 1 r
.39903 .82518 m .3971 .82552 L .39584 .82487 L F
.708 .601 .734 r
.41319 .8516 m .41136 .85432 L .41107 .85215 L F
.601 .459 .66 r
.41318 .85369 m .41136 .85432 L .41319 .8516 L F
.603 .463 .663 r
.41414 .85696 m .41136 .85432 L .41318 .85369 L F
.41414 .85696 m .41175 .85736 L .41136 .85432 L F
.564 .319 .502 r
.42733 .83106 m .42462 .83324 L .42498 .83099 L F
.632 .472 .647 r
.4164 .84142 m .41703 .84432 L .41425 .84415 L F
.661 .509 .666 r
.41703 .84432 m .41431 .84647 L .41425 .84415 L F
.632 .512 .698 r
.41818 .83882 m .4164 .84142 L .41613 .83933 L F
.41818 .83882 m .41919 .84172 L .4164 .84142 L F
.658 .488 .643 r
.41919 .84402 m .4164 .84142 L .41919 .84172 L F
.41919 .84402 m .41703 .84432 L .4164 .84142 L F
.715 .731 .864 r
.50657 .82112 m .50831 .82351 L .50583 .82388 L F
.581 .686 .913 r
.50857 .82081 m .50831 .82351 L .50657 .82112 L F
.50857 .82081 m .51021 .823 L .50831 .82351 L F
.599 .77 .961 r
.42646 .8262 m .42322 .82556 L .42517 .82519 L F
.527 .769 .986 r
.42715 .82492 m .42646 .8262 L .42517 .82519 L F
.42715 .82492 m .4284 .82589 L .42646 .8262 L F
.648 .5 .668 r
.41818 .83882 m .41613 .83933 L .41819 .8367 L F
.849 .922 .531 r
.5113 .85396 m .51131 .85444 L .50953 .85735 L F
.767 .479 .498 r
.50953 .85735 m .51131 .85444 L .51143 .85878 L F
0 .222 .742 r
.51342 .85591 m .51131 .85444 L .5113 .85396 L F
.405 .198 .482 r
.51196 .85617 m .51131 .85444 L .51234 .85516 L F
.325 0 0 r
.51006 .85794 m .51192 .85663 L .50953 .85735 L F
.51192 .85663 m .51207 .85653 L .51179 .85662 L F
.51192 .85663 m .51179 .85662 L .50953 .85735 L F
.405 .198 .482 r
.51179 .85662 m .51136 .85628 L .51196 .85617 L F
0 0 0 r
.51342 .85591 m .51207 .85653 L .51192 .85663 L F
.459 .401 .705 r
.51196 .85617 m .51207 .85653 L .51342 .85591 L F
.771 .585 .647 r
.51179 .85662 m .51207 .85653 L .51196 .85617 L F
.405 .198 .482 r
.5114 .85768 m .51234 .85516 L .51342 .85591 L F
.767 .479 .498 r
.50964 .85791 m .51143 .85878 L .50988 .85908 L F
.50953 .85735 m .51004 .85773 L .50964 .85791 L F
.51004 .85773 m .51143 .85878 L .50964 .85791 L F
0 0 0 r
.51342 .85591 m .51192 .85663 L .51092 .85734 L F
.51146 .8571 m .51092 .85734 L .51006 .85794 L F
.51342 .85591 m .51092 .85734 L .51146 .8571 L F
.405 .198 .482 r
.51176 .85671 m .51137 .85657 L .51179 .85662 L F
.5114 .85768 m .51138 .85689 L .51176 .85671 L F
.51138 .85689 m .51137 .85657 L .51176 .85671 L F
.51137 .85657 m .51136 .85628 L .51179 .85662 L F
.51136 .85628 m .51131 .85444 L .51196 .85617 L F
.459 .401 .705 r
.5113 .85396 m .51196 .85617 L .51342 .85591 L F
.771 .585 .647 r
.50953 .85735 m .51179 .85662 L .5113 .85396 L F
.51179 .85662 m .51196 .85617 L .5113 .85396 L F
.405 .198 .482 r
.51143 .85878 m .5114 .85768 L .51342 .85591 L F
.748 .668 .773 r
.50451 .8214 m .50583 .82388 L .50259 .82364 L F
.762 .563 .628 r
.50583 .82388 m .50258 .82593 L .50259 .82364 L F
.50583 .82388 m .50574 .82618 L .50258 .82593 L F
.715 .731 .864 r
.50657 .82112 m .50583 .82388 L .50451 .8214 L F
.646 .364 .478 r
.4177 .8694 m .41953 .87122 L .41737 .87106 L F
.4177 .8694 m .41968 .86967 L .41953 .87122 L F
.815 .607 .62 r
.43311 .85695 m .42991 .85933 L .43227 .85717 L F
.43311 .85695 m .43312 .85934 L .42991 .85933 L F
.434 .844 .968 r
.43311 .85695 m .43377 .85626 L .43532 .85659 L F
.52 .912 .796 r
.43311 .85695 m .43227 .85717 L .43377 .85626 L F
.659 .5 .657 r
.43532 .85659 m .43312 .85934 L .43311 .85695 L F
.672 .502 .647 r
.42249 .83358 m .42018 .83625 L .42025 .83408 L F
.677 .539 .69 r
.42018 .83625 m .41818 .83882 L .41819 .8367 L F
.633 .749 .932 r
.41599 .82693 m .41274 .82625 L .41477 .82559 L F
.61 .726 .928 r
.41799 .82643 m .41599 .82693 L .41477 .82559 L F
.555 .621 .873 r
.42772 .86012 m .42616 .86135 L .42528 .86032 L F
.42772 .86012 m .42809 .86122 L .42616 .86135 L F
.552 .453 .696 r
.42809 .86122 m .42668 .86467 L .42616 .86135 L F
.545 .786 .988 r
.40772 .8255 m .40452 .82501 L .40646 .82475 L F
.479 .784 .998 r
.40827 .82451 m .40772 .8255 L .40646 .82475 L F
.40827 .82451 m .40964 .82528 L .40772 .8255 L F
.101 .189 .67 r
.51503 .82554 m .51402 .82624 L .51338 .82321 L F
0 0 0 r
.51282 .82768 m .51402 .82624 L .51503 .82554 L F
.672 .502 .647 r
.42249 .83358 m .42307 .83652 L .42018 .83625 L F
.637 .501 .681 r
.42462 .83324 m .42307 .83652 L .42249 .83358 L F
.633 .525 .714 r
.41512 .84923 m .41319 .8516 L .41298 .84958 L F
.639 .533 .718 r
.41512 .84923 m .41536 .85152 L .41319 .8516 L F
.634 .484 .661 r
.41536 .85152 m .41318 .85369 L .41319 .8516 L F
.741 .746 .856 r
.42123 .82659 m .41799 .82643 L .41992 .82553 L F
.723 .795 .909 r
.42322 .82556 m .42123 .82659 L .41992 .82553 L F
.592 .345 .511 r
.43263 .82809 m .43169 .83093 L .42948 .83112 L F
.639 .645 .84 r
.43349 .82621 m .43263 .82809 L .4315 .82677 L F
.43349 .82621 m .43489 .82874 L .43263 .82809 L F
.579 .331 .505 r
.43371 .83047 m .43263 .82809 L .43489 .82874 L F
.43371 .83047 m .43169 .83093 L .43263 .82809 L F
.59 .37 .551 r
.40741 .87498 m .4092 .87643 L .40718 .87731 L F
.40741 .87498 m .41143 .8745 L .4092 .87643 L F
.624 .348 .479 r
.42488 .86721 m .42353 .87144 L .42158 .86944 L F
.442 .493 .816 r
.43537 .82594 m .43489 .82874 L .43349 .82621 L F
.43537 .82594 m .43644 .82819 L .43489 .82874 L F
.65 .456 .608 r
.43644 .82819 m .43371 .83047 L .43489 .82874 L F
.552 .453 .696 r
.42809 .86122 m .42889 .86456 L .42668 .86467 L F
.612 .475 .671 r
.42889 .86456 m .42679 .8668 L .42668 .86467 L F
.711 .735 .87 r
.51195 .82113 m .51092 .82413 L .51021 .823 L F
.51195 .82113 m .51338 .82321 L .51092 .82413 L F
.648 .387 .51 r
.40484 .87712 m .4026 .8795 L .40287 .87729 L F
.593 .356 .526 r
.41236 .87217 m .41426 .87413 L .41242 .87382 L F
.631 .354 .48 r
.41236 .87217 m .41443 .87231 L .41426 .87413 L F
.677 .539 .69 r
.42018 .83625 m .42106 .8393 L .41818 .83882 L F
.693 .545 .681 r
.42131 .84144 m .41818 .83882 L .42106 .8393 L F
.42131 .84144 m .41919 .84172 L .41818 .83882 L F
.63 .531 .724 r
.41435 .85873 m .41214 .8593 L .41175 .85736 L F
.631 .512 .699 r
.42327 .83891 m .42018 .83625 L .42307 .83652 L F
.42327 .83891 m .42106 .8393 L .42018 .83625 L F
.63 .531 .724 r
.41435 .85873 m .41175 .85736 L .41414 .85696 L F
.634 .484 .661 r
.41536 .85152 m .41609 .85441 L .41318 .85369 L F
.719 .531 .634 r
.41617 .85671 m .41318 .85369 L .41609 .85441 L F
.41617 .85671 m .41414 .85696 L .41318 .85369 L F
.55 .317 .514 r
.41968 .86967 m .4215 .87135 L .41953 .87122 L F
.41968 .86967 m .42158 .86944 L .4215 .87135 L F
.661 .509 .666 r
.41703 .84432 m .41713 .84661 L .41431 .84647 L F
.653 .531 .703 r
.41714 .84877 m .41431 .84647 L .41713 .84661 L F
.41714 .84877 m .41512 .84923 L .41431 .84647 L F
.659 .5 .657 r
.43532 .85659 m .43596 .85921 L .43312 .85934 L F
.598 .223 .302 r
.43377 .85626 m .43694 .85523 L .43532 .85659 L F
.599 .572 .795 r
.43694 .85523 m .43772 .85685 L .43532 .85659 L F
.567 .442 .669 r
.43791 .85833 m .43532 .85659 L .43772 .85685 L F
.43791 .85833 m .43596 .85921 L .43532 .85659 L F
.439 .836 .98 r
.39398 .82431 m .39392 .82527 L .39219 .82422 L F
.39398 .82431 m .39584 .82487 L .39392 .82527 L F
.847 .708 .71 r
.50145 .82083 m .50259 .82364 L .4995 .82388 L F
.805 .765 .816 r
.4995 .82388 m .49905 .82576 L .49831 .82303 L F
.4995 .82388 m .49831 .82303 L .49843 .82315 L F
.753 .549 .62 r
.50077 .82473 m .49905 .82576 L .4995 .82388 L F
.805 .765 .816 r
.4995 .82388 m .49843 .82315 L .50032 .82497 L F
.753 .549 .62 r
.50259 .82364 m .50077 .82473 L .4995 .82388 L F
.50259 .82364 m .50061 .82566 L .49905 .82576 L F
.50259 .82364 m .50258 .82593 L .50061 .82566 L F
.746 .665 .771 r
.50451 .8214 m .50259 .82364 L .50145 .82083 L F
.564 .319 .502 r
.42733 .83106 m .42654 .83321 L .42462 .83324 L F
.619 .366 .513 r
.42948 .83112 m .42654 .83321 L .42733 .83106 L F
.748 .538 .61 r
.50574 .82618 m .50248 .82844 L .50258 .82593 L F
.50574 .82618 m .5059 .82856 L .50248 .82844 L F
.692 .268 .235 r
.50574 .82618 m .50764 .82761 L .5059 .82856 L F
.723 .795 .909 r
.42322 .82556 m .41992 .82553 L .42201 .82465 L F
.547 .78 .985 r
.42517 .82519 m .42322 .82556 L .42201 .82465 L F
.97 .779 .59 r
.5061 .85969 m .50723 .85922 L .5071 .857 L F
.5061 .85969 m .50723 .85922 L .5071 .857 L F
.43 .858 .73 r
.50652 .85943 m .50723 .85922 L .5061 .85969 L F
.646 .453 .609 r
.50723 .85922 m .50516 .86166 L .5061 .85969 L F
.50723 .85922 m .50736 .86161 L .50516 .86166 L F
.587 .609 .841 r
.50953 .85735 m .50723 .85922 L .5071 .857 L F
0 0 .471 r
.5071 .857 m .50723 .85922 L .50817 .85849 L F
.439 .862 .731 r
.50817 .85849 m .50723 .85922 L .50652 .85943 L F
.587 .609 .841 r
.50953 .85735 m .50988 .85908 L .50723 .85922 L F
.572 .351 .542 r
.50723 .85922 m .50979 .86144 L .50736 .86161 L F
.50723 .85922 m .50988 .85908 L .50979 .86144 L F
.428 .604 .92 r
.51499 .82322 m .51338 .82321 L .51195 .82113 L F
.101 .189 .67 r
.51503 .82554 m .51338 .82321 L .51499 .82322 L F
.608 .483 .685 r
.41714 .84877 m .41536 .85152 L .41512 .84923 L F
.41714 .84877 m .41794 .85185 L .41536 .85152 L F
.655 .497 .658 r
.41826 .85399 m .41536 .85152 L .41794 .85185 L F
.41826 .85399 m .41609 .85441 L .41536 .85152 L F
.464 .782 .998 r
.40646 .82475 m .40452 .82501 L .4031 .8241 L F
.652 .744 .917 r
.41477 .82559 m .41274 .82625 L .4116 .82501 L F
.691 .536 .671 r
.42131 .84144 m .41919 .84402 L .41919 .84172 L F
.687 .529 .666 r
.41928 .84622 m .41703 .84432 L .41919 .84402 L F
.41928 .84622 m .41713 .84661 L .41703 .84432 L F
.539 .403 .645 r
.50516 .86166 m .50357 .86483 L .50297 .86209 L F
.50516 .86166 m .50545 .86426 L .50357 .86483 L F
.485 .265 .505 r
.50357 .86483 m .5052 .86643 L .5031 .86661 L F
.50357 .86483 m .50545 .86426 L .5052 .86643 L F
.718 .645 .776 r
.43301 .8615 m .42991 .85933 L .43312 .85934 L F
.659 .462 .606 r
.43534 .86121 m .43312 .85934 L .43596 .85921 L F
.43534 .86121 m .43301 .8615 L .43312 .85934 L F
.623 .51 .704 r
.42335 .84102 m .42106 .8393 L .42327 .83891 L F
.42335 .84102 m .42131 .84144 L .42106 .8393 L F
0 0 .471 r
.5071 .857 m .50817 .85849 L .50953 .85735 L F
.867 .895 .852 r
.50297 .86209 m .4999 .86402 L .50204 .86177 L F
.588 .86 .995 r
.50391 .86101 m .50516 .86166 L .50297 .86209 L F
.617 .908 .983 r
.50391 .86101 m .50297 .86209 L .50204 .86177 L F
.462 .69 .965 r
.42329 .85865 m .4225 .86006 L .42176 .85976 L F
.42329 .85865 m .42494 .86015 L .4225 .86006 L F
.167 .679 .897 r
.4225 .86006 m .42494 .86015 L .42528 .86032 L F
.503 .818 1 r
.39903 .82518 m .39584 .82487 L .39778 .82437 L F
.604 .835 .987 r
.40116 .82451 m .39903 .82518 L .39778 .82437 L F
.688 .531 .668 r
.42122 .8437 m .41919 .84402 L .42131 .84144 L F
.662 .537 .701 r
.42335 .84102 m .42122 .8437 L .42131 .84144 L F
.588 .698 .918 r
.4315 .82677 m .4284 .82589 L .43039 .82541 L F
.655 .699 .879 r
.43349 .82621 m .4315 .82677 L .43039 .82541 L F
.637 .501 .681 r
.42462 .83324 m .42515 .83634 L .42307 .83652 L F
.679 .514 .654 r
.42537 .83848 m .42307 .83652 L .42515 .83634 L F
.42537 .83848 m .42327 .83891 L .42307 .83652 L F
.639 .392 .528 r
.41737 .87106 m .41426 .87413 L .41443 .87231 L F
.279 .762 .923 r
.42494 .86015 m .42772 .86012 L .42528 .86032 L F
.648 .387 .51 r
.40484 .87712 m .40515 .87894 L .4026 .8795 L F
.40484 .87712 m .40505 .87715 L .40515 .87894 L F
.714 .714 .849 r
.50395 .82037 m .50451 .8214 L .50145 .82083 L F
.58 .647 .881 r
.50591 .82013 m .50451 .8214 L .50395 .82037 L F
.50591 .82013 m .50657 .82112 L .50451 .8214 L F
.764 .269 .046 r
.49618 .86438 m .49778 .86472 L .4972 .86563 L F
.548 .874 .993 r
.4999 .86402 m .49778 .86472 L .49618 .86438 L F
.844 .386 .103 r
.4972 .86563 m .49778 .86472 L .49836 .86613 L F
.639 .392 .528 r
.41737 .87106 m .41638 .87418 L .41426 .87413 L F
.601 .353 .513 r
.41953 .87122 m .41638 .87418 L .41737 .87106 L F
.73 .231 .044 r
.43694 .85523 m .44039 .85675 L .43772 .85685 L F
.731 .495 .57 r
.44039 .85675 m .43791 .85833 L .43772 .85685 L F
.44039 .85675 m .44023 .85904 L .43791 .85833 L F
.73 .231 .044 r
.43694 .85523 m .43844 .8564 L .44039 .85675 L F
.598 .223 .302 r
.43377 .85626 m .43647 .85623 L .43694 .85523 L F
.719 .356 .36 r
.43647 .85623 m .43991 .85754 L .43694 .85523 L F
.669 .785 .935 r
.43854 .85562 m .43723 .85601 L .4345 .85491 L F
.43723 .85601 m .43647 .85623 L .43511 .85532 L F
.43723 .85601 m .43511 .85532 L .4345 .85491 L F
.73 .231 .044 r
.43844 .8564 m .43991 .85754 L .44024 .85699 L F
.43844 .8564 m .44024 .85699 L .44039 .85675 L F
0 0 0 r
.44039 .85675 m .44134 .85566 L .44252 .85502 L F
.642 .678 .869 r
.4425 .85504 m .44294 .85663 L .44039 .85675 L F
.44252 .85502 m .44253 .85506 L .4425 .85504 L F
.44253 .85506 m .44294 .85663 L .4425 .85504 L F
.663 .436 .565 r
.4429 .85739 m .44039 .85675 L .44294 .85663 L F
.4429 .85739 m .44023 .85904 L .44039 .85675 L F
.621 .53 .729 r
.44436 .85369 m .44294 .85663 L .44252 .85502 L F
.44436 .85369 m .44532 .85648 L .44294 .85663 L F
.614 .456 .645 r
.44532 .85648 m .4429 .85739 L .44294 .85663 L F
.587 .307 .459 r
.4429 .85739 m .4425 .86118 L .44023 .85904 L F
.614 .456 .645 r
.44532 .85648 m .44535 .85861 L .4429 .85739 L F
.692 .4 .475 r
.4456 .86006 m .4429 .85739 L .44535 .85861 L F
.4456 .86006 m .4425 .86118 L .4429 .85739 L F
.803 .405 .299 r
.44134 .85566 m .44298 .85776 L .44455 .85604 L F
.44442 .85598 m .44455 .85604 L .44459 .856 L F
.44134 .85566 m .44455 .85604 L .44442 .85598 L F
0 0 0 r
.44039 .85675 m .43991 .85754 L .44134 .85566 L F
.579 .459 .68 r
.42654 .83321 m .42515 .83634 L .42462 .83324 L F
.597 .348 .51 r
.40515 .87894 m .40505 .87715 L .40694 .87906 L F
.634 .345 .461 r
.40505 .87715 m .40718 .87731 L .40694 .87906 L F
.61 .726 .928 r
.41799 .82643 m .41477 .82559 L .41673 .82519 L F
.699 .764 .902 r
.41992 .82553 m .41799 .82643 L .41673 .82519 L F
.595 .795 .976 r
.43039 .82541 m .4284 .82589 L .42715 .82492 L F
.653 .521 .69 r
.42102 .84578 m .41919 .84402 L .42122 .8437 L F
.42102 .84578 m .41928 .84622 L .41919 .84402 L F
.612 .475 .671 r
.42889 .86456 m .42887 .86669 L .42679 .8668 L F
.443 .242 .511 r
.43647 .85623 m .43295 .85799 L .43377 .85626 L F
.62 .641 .849 r
.43295 .85799 m .43791 .85833 L .43647 .85623 L F
.487 .295 .545 r
.43761 .86021 m .43596 .85921 L .43791 .85833 L F
.43761 .86021 m .43534 .86121 L .43596 .85921 L F
.375 0 .058 r
.43372 .86071 m .43791 .85833 L .43295 .85799 L F
.443 .242 .511 r
.43647 .85623 m .43593 .85867 L .43295 .85799 L F
.512 .234 .429 r
.43593 .85867 m .43372 .86071 L .43295 .85799 L F
.62 .641 .849 r
.43295 .85799 m .43647 .85623 L .43377 .85626 L F
.64 .614 .807 r
.41861 .85813 m .4165 .85993 L .41624 .8583 L F
.41861 .85813 m .41949 .86013 L .4165 .85993 L F
.531 .762 .982 r
.41055 .82407 m .40964 .82528 L .40827 .82451 L F
.41055 .82407 m .4116 .82501 L .40964 .82528 L F
.693 .556 .695 r
.41928 .84622 m .41714 .84877 L .41713 .84661 L F
.734 .621 .733 r
.41617 .85671 m .41435 .85873 L .41414 .85696 L F
.656 .762 .928 r
.41624 .8583 m .41435 .85873 L .41617 .85671 L F
.698 .731 .876 r
.51195 .82113 m .51021 .823 L .50857 .82081 L F
.672 .574 .736 r
.41826 .85399 m .41617 .85671 L .41609 .85441 L F
.637 .604 .8 r
.42991 .85933 m .42809 .86122 L .42772 .86012 L F
.42991 .85933 m .43092 .86173 L .42809 .86122 L F
.637 .508 .689 r
.43091 .86409 m .42809 .86122 L .43092 .86173 L F
.43091 .86409 m .42889 .86456 L .42809 .86122 L F
.43 .858 .73 r
.50652 .85943 m .5061 .85969 L .50516 .86166 L F
.50652 .85943 m .50516 .86166 L .50391 .86101 L F
.546 .409 .645 r
.50742 .86386 m .50516 .86166 L .50736 .86161 L F
.50742 .86386 m .50545 .86426 L .50516 .86166 L F
.662 .537 .701 r
.42335 .84102 m .42413 .84381 L .42122 .8437 L F
.644 .465 .626 r
.42413 .84381 m .42102 .84578 L .42122 .8437 L F
.815 .41 .283 r
.49836 .86613 m .50102 .8669 L .50003 .86821 L F
.457 .103 .277 r
.50102 .8669 m .50188 .86822 L .50003 .86821 L F
.50102 .8669 m .5031 .86661 L .50188 .86822 L F
.619 .366 .513 r
.42948 .83112 m .42928 .83336 L .42654 .83321 L F
.644 .387 .516 r
.43145 .8331 m .42928 .83336 L .42948 .83112 L F
.605 .39 .564 r
.43169 .83093 m .43145 .8331 L .42948 .83112 L F
.666 .517 .673 r
.41908 .84797 m .41714 .84877 L .41928 .84622 L F
.638 .502 .68 r
.42015 .85157 m .41714 .84877 L .41908 .84797 L F
.42015 .85157 m .41794 .85185 L .41714 .84877 L F
.623 .466 .648 r
.42102 .84578 m .41908 .84797 L .41928 .84622 L F
.591 .35 .52 r
.42158 .86944 m .42353 .87144 L .4215 .87135 L F
.69 .555 .697 r
.42537 .83848 m .42335 .84102 L .42327 .83891 L F
.623 .466 .648 r
.42102 .84578 m .42214 .84873 L .41908 .84797 L F
.644 .491 .662 r
.42228 .85109 m .41908 .84797 L .42214 .84873 L F
.42228 .85109 m .42015 .85157 L .41908 .84797 L F
.596 .675 .896 r
.51116 .82799 m .51202 .8255 L .50979 .8271 L F
.51116 .82799 m .51282 .82768 L .51202 .8255 L F
.759 .562 .63 r
.50258 .82593 m .5006 .82781 L .50061 .82566 L F
.50258 .82593 m .50248 .82844 L .5006 .82781 L F
.579 .459 .68 r
.42654 .83321 m .42723 .83618 L .42515 .83634 L F
.58 .475 .699 r
.42723 .83618 m .42537 .83848 L .42515 .83634 L F
.589 .362 .54 r
.41242 .87382 m .4092 .87643 L .41143 .8745 L F
.41242 .87382 m .41374 .87665 L .4092 .87643 L F
.593 .366 .541 r
.41242 .87382 m .4145 .87617 L .41374 .87665 L F
.41242 .87382 m .41426 .87413 L .4145 .87617 L F
.653 .503 .667 r
.42535 .84032 m .42335 .84102 L .42537 .83848 L F
.625 .495 .684 r
.42535 .84032 m .42413 .84381 L .42335 .84102 L F
.651 .409 .54 r
.4092 .87643 m .40694 .87906 L .40718 .87731 L F
.652 .744 .917 r
.41477 .82559 m .4116 .82501 L .41356 .8246 L F
.576 .768 .97 r
.41673 .82519 m .41477 .82559 L .41356 .8246 L F
.634 .392 .535 r
.42798 .86675 m .42569 .87163 L .42353 .87144 L F
.611 .367 .523 r
.42893 .87039 m .42798 .86675 L .42873 .8687 L F
.42893 .87039 m .42569 .87163 L .42798 .86675 L F
.658 .586 .763 r
.42723 .83618 m .42791 .83839 L .42537 .83848 L F
.626 .454 .629 r
.42791 .83839 m .42535 .84032 L .42537 .83848 L F
.561 .756 .969 r
.39425 .84123 m .3947 .83992 L .39402 .8405 L F
.39425 .84123 m .39658 .84107 L .3947 .83992 L F
.69 .567 .711 r
.39444 .84362 m .39658 .84107 L .39425 .84123 L F
.516 .828 1 r
.50248 .82844 m .5059 .82856 L .50459 .8279 L F
.697 .884 .967 r
.50459 .8279 m .5059 .82856 L .50764 .82761 L F
.627 .712 .908 r
.43246 .82489 m .43349 .82621 L .43039 .82541 L F
.551 .667 .914 r
.4344 .82463 m .43349 .82621 L .43246 .82489 L F
.4344 .82463 m .43537 .82594 L .43349 .82621 L F
.718 .645 .776 r
.43301 .8615 m .43092 .86173 L .42991 .85933 L F
.707 .537 .657 r
.43301 .8615 m .43091 .86409 L .43092 .86173 L F
.687 .51 .641 r
.43301 .8615 m .43316 .86381 L .43091 .86409 L F
.616 .423 .598 r
.43534 .86121 m .43316 .86381 L .43301 .8615 L F
.633 .493 .673 r
.43091 .86409 m .42887 .86669 L .42889 .86456 L F
.644 .465 .626 r
.42413 .84381 m .42428 .8462 L .42102 .84578 L F
.656 .483 .638 r
.42433 .84852 m .42102 .84578 L .42428 .8462 L F
.42433 .84852 m .42214 .84873 L .42102 .84578 L F
.583 .357 .539 r
.40515 .87894 m .40231 .88171 L .4026 .8795 L F
.065 0 0 r
.39018 .82559 m .39219 .82422 L .39068 .82505 L F
.511 .31 .543 r
.50742 .86386 m .50736 .86161 L .50979 .86144 L F
0 0 .102 r
.50042 .82313 m .50145 .82083 L .4995 .82388 L F
.50077 .82282 m .50145 .82083 L .50042 .82313 L F
.939 .652 .471 r
.50016 .82041 m .50145 .82083 L .50075 .82285 L F
.176 .71 .74 r
.50227 .82059 m .50145 .82083 L .50016 .82041 L F
.939 .652 .471 r
.50016 .82041 m .50145 .82083 L .50075 .82285 L F
.445 .36 .666 r
.50227 .82059 m .50016 .82041 L .50186 .82185 L F
.50226 .82149 m .50186 .82185 L .50225 .82218 L F
.50227 .82059 m .50186 .82185 L .50226 .82149 L F
0 0 .102 r
.50075 .82285 m .50077 .82282 L .50042 .82313 L F
.176 .71 .74 r
.50227 .82059 m .50395 .82037 L .50145 .82083 L F
0 0 0 r
.3947 .83992 m .39274 .84009 L .39402 .8405 L F
.594 .81 .982 r
.41867 .82468 m .41992 .82553 L .41673 .82519 L F
.688 .835 .954 r
.42201 .82465 m .41992 .82553 L .41867 .82468 L F
.566 .574 .821 r
.42176 .85976 m .41949 .86013 L .41861 .85813 L F
.625 .495 .684 r
.42535 .84032 m .42628 .84368 L .42413 .84381 L F
.676 .489 .626 r
.42643 .84591 m .42413 .84381 L .42628 .84368 L F
.42643 .84591 m .42428 .8462 L .42413 .84381 L F
.368 .8 .966 r
.50397 .81947 m .50395 .82037 L .50227 .82059 L F
.50397 .81947 m .50591 .82013 L .50395 .82037 L F
.716 .635 .767 r
.4205 .85378 m .41826 .85399 L .42015 .85157 L F
.529 .419 .674 r
.42228 .85109 m .4205 .85378 L .42015 .85157 L F
.42228 .85109 m .42236 .85553 L .4205 .85378 L F
.642 .528 .709 r
.42015 .85157 m .41826 .85399 L .41794 .85185 L F
.493 .861 .986 r
.39778 .82437 m .39584 .82487 L .39398 .82431 L F
.547 .78 .985 r
.42517 .82519 m .42201 .82465 L .42404 .82428 L F
.48 .796 .999 r
.42587 .82422 m .42517 .82519 L .42404 .82428 L F
.42587 .82422 m .42715 .82492 L .42517 .82519 L F
.726 .521 .614 r
.5006 .82781 m .49905 .82576 L .50061 .82566 L F
.64 .586 .778 r
.39634 .85137 m .39805 .84908 L .39624 .85101 L F
.39634 .85137 m .39887 .85144 L .39805 .84908 L F
.559 .352 .556 r
.39649 .85375 m .39887 .85144 L .39634 .85137 L F
.651 .409 .54 r
.4092 .87643 m .40907 .8793 L .40694 .87906 L F
.591 .359 .533 r
.41251 .87747 m .4092 .87643 L .41374 .87665 L F
.41251 .87747 m .40907 .8793 L .4092 .87643 L F
.671 .644 .814 r
.39624 .85101 m .39712 .84798 L .39532 .84862 L F
.39624 .85101 m .39805 .84908 L .39712 .84798 L F
.626 .454 .629 r
.42791 .83839 m .42819 .84118 L .42535 .84032 L F
.621 .493 .685 r
.42842 .84337 m .42535 .84032 L .42819 .84118 L F
.42842 .84337 m .42628 .84368 L .42535 .84032 L F
.601 .353 .513 r
.41953 .87122 m .41869 .87419 L .41638 .87418 L F
.586 .315 .473 r
.41953 .87122 m .42152 .87311 L .41869 .87419 L F
.41953 .87122 m .4215 .87135 L .42152 .87311 L F
.56 .349 .551 r
.42873 .8687 m .42887 .86669 L .43078 .86862 L F
.619 .473 .662 r
.43091 .86409 m .43093 .86661 L .42887 .86669 L F
.596 .348 .511 r
.42887 .86669 m .43093 .86661 L .43078 .86862 L F
.604 .835 .987 r
.40116 .82451 m .39778 .82437 L .39958 .82386 L F
.499 .825 1 r
.4031 .8241 m .40116 .82451 L .39958 .82386 L F
.506 .284 .511 r
.5052 .86643 m .50545 .86426 L .50742 .86386 L F
.616 .423 .598 r
.43534 .86121 m .43618 .8632 L .43316 .86381 L F
.629 .496 .682 r
.43761 .86021 m .43618 .8632 L .43534 .86121 L F
.421 .229 .513 r
.50979 .86144 m .50988 .85908 L .51143 .85878 L F
.799 .761 .818 r
.49831 .82303 m .49905 .82576 L .4962 .82534 L F
.824 .6 .599 r
.49905 .82576 m .49615 .82766 L .4962 .82534 L F
.49905 .82576 m .49912 .82835 L .49615 .82766 L F
.726 .521 .614 r
.5006 .82781 m .49912 .82835 L .49905 .82576 L F
.703 .532 .653 r
.43371 .83047 m .43145 .8331 L .43169 .83093 L F
.556 .358 .567 r
.51838 .84083 m .51855 .8386 L .52047 .84065 L F
.51838 .84083 m .51855 .8386 L .52047 .84065 L F
.605 .475 .678 r
.42935 .83573 m .42654 .83321 L .42928 .83336 L F
.42935 .83573 m .42723 .83618 L .42654 .83321 L F
.464 .782 .998 r
.40646 .82475 m .4031 .8241 L .40473 .82366 L F
.491 .786 .997 r
.40712 .82362 m .40646 .82475 L .40473 .82366 L F
.40712 .82362 m .40827 .82451 L .40646 .82475 L F
.279 .762 .923 r
.42494 .86015 m .4264 .85994 L .42772 .86012 L F
.529 .878 .986 r
.42772 .86012 m .42906 .85926 L .42991 .85933 L F
.42772 .86012 m .4264 .85994 L .42906 .85926 L F
.595 .795 .976 r
.43039 .82541 m .42715 .82492 L .42905 .82446 L F
.606 .802 .975 r
.43246 .82489 m .43039 .82541 L .42905 .82446 L F
.572 .643 .883 r
.50857 .82081 m .50657 .82112 L .50591 .82013 L F
.744 .647 .753 r
.42433 .84852 m .4267 .85117 L .42228 .85109 L F
.644 .511 .687 r
.42718 .85355 m .42228 .85109 L .4267 .85117 L F
.396 .543 .885 r
.42757 .85097 m .4267 .85117 L .42433 .84852 L F
.513 .276 .492 r
.42749 .85326 m .4267 .85117 L .42757 .85097 L F
.42749 .85326 m .42718 .85355 L .4267 .85117 L F
.615 .56 .77 r
.42951 .83699 m .42791 .83839 L .42723 .83618 L F
.631 .501 .685 r
.42951 .83699 m .42819 .84118 L .42791 .83839 L F
.478 .593 .89 r
.42528 .85812 m .42494 .86015 L .42329 .85865 L F
.42528 .85812 m .4264 .85994 L .42494 .86015 L F
.428 .604 .92 r
.51499 .82322 m .51195 .82113 L .51416 .82033 L F
.995 .752 .419 r
.51439 .82363 m .51503 .82554 L .51499 .82322 L F
.602 .566 .786 r
.51587 .82014 m .51499 .82322 L .51416 .82033 L F
.51587 .82014 m .51708 .82293 L .51499 .82322 L F
.403 .818 .974 r
.51499 .82322 m .51708 .82293 L .51608 .82253 L F
.51499 .82322 m .51608 .82253 L .51439 .82363 L F
.622 .435 .608 r
.43316 .86381 m .43093 .86661 L .43091 .86409 L F
.65 .456 .608 r
.43644 .82819 m .43663 .8306 L .43371 .83047 L F
.618 .615 .825 r
.4374 .82564 m .43644 .82819 L .43537 .82594 L F
.4374 .82564 m .43865 .82822 L .43644 .82819 L F
.688 .525 .66 r
.43865 .82822 m .43663 .8306 L .43644 .82819 L F
.69 .567 .711 r
.39444 .84362 m .39699 .8435 L .39658 .84107 L F
.599 .471 .677 r
.39507 .84754 m .39574 .84384 L .39394 .84572 L F
.672 .412 .519 r
.39394 .84572 m .39602 .84355 L .39444 .84362 L F
.599 .471 .677 r
.39574 .84384 m .39575 .84378 L .39394 .84572 L F
.39507 .84754 m .39712 .84798 L .39577 .84385 L F
.672 .412 .519 r
.39574 .84384 m .39699 .8435 L .39602 .84355 L F
.599 .471 .677 r
.39574 .84384 m .39577 .84385 L .39575 .84378 L F
.39507 .84754 m .39577 .84385 L .39574 .84384 L F
.579 .459 .681 r
.39797 .84505 m .39712 .84798 L .39907 .84568 L F
.672 .412 .519 r
.39619 .84408 m .39622 .84406 L .39577 .84385 L F
.39622 .84406 m .39699 .8435 L .39574 .84384 L F
.39619 .84408 m .39575 .84378 L .39699 .8435 L F
.579 .459 .681 r
.39575 .84378 m .39577 .84385 L .39619 .84408 L F
.39577 .84385 m .39712 .84798 L .39797 .84505 L F
.672 .412 .519 r
.39394 .84572 m .39619 .84408 L .39574 .84384 L F
.39619 .84408 m .39577 .84385 L .39574 .84384 L F
.39394 .84572 m .39575 .84378 L .39619 .84408 L F
.579 .459 .681 r
.39575 .84378 m .39619 .84408 L .39797 .84505 L F
.557 .801 .99 r
.41229 .82374 m .4116 .82501 L .41055 .82407 L F
.41229 .82374 m .41356 .8246 L .4116 .82501 L F
.867 .925 .863 r
.43227 .85717 m .42991 .85933 L .42943 .85813 L F
.712 .98 .908 r
.43227 .85717 m .43285 .85591 L .43377 .85626 L F
.43227 .85717 m .42943 .85813 L .43285 .85591 L F
.812 .428 .327 r
.44252 .85502 m .44459 .856 L .44436 .85369 L F
.44252 .85502 m .44134 .85566 L .44459 .856 L F
.668 .556 .719 r
.44743 .85625 m .44436 .85369 L .44653 .85327 L F
.44743 .85625 m .44532 .85648 L .44497 .85546 L F
.44551 .85465 m .44497 .85546 L .44436 .85369 L F
.44743 .85625 m .44497 .85546 L .44551 .85465 L F
0 0 0 r
.44484 .85564 m .44547 .85561 L .44653 .85327 L F
.44459 .856 m .44461 .85599 L .44484 .85564 L F
.44461 .85599 m .44547 .85561 L .44484 .85564 L F
.44459 .856 m .44653 .85327 L .44436 .85369 L F
.515 .258 .463 r
.44298 .85776 m .44547 .85561 L .44459 .856 L F
.622 .435 .608 r
.43316 .86381 m .43324 .8665 L .43093 .86661 L F
.574 .371 .568 r
.43618 .8632 m .43324 .8665 L .43316 .86381 L F
.548 .874 .993 r
.4999 .86402 m .49618 .86438 L .49787 .86233 L F
.835 .998 .831 r
.50121 .86181 m .4999 .86402 L .49787 .86233 L F
.50121 .86181 m .50204 .86177 L .4999 .86402 L F
.375 0 .058 r
.43372 .86071 m .4357 .8605 L .43791 .85833 L F
.179 0 .051 r
.43791 .85833 m .43991 .85754 L .43647 .85623 L F
.43791 .85833 m .43899 .85835 L .43991 .85754 L F
.69 .235 .165 r
.43791 .85833 m .44023 .85904 L .4393 .8598 L F
.65 .251 .275 r
.43791 .85833 m .4393 .8598 L .43899 .85835 L F
.69 .235 .165 r
.43791 .85833 m .4393 .8598 L .43761 .86021 L F
.65 .251 .275 r
.43791 .85833 m .4357 .8605 L .4393 .8598 L F
.77 .506 .535 r
.5006 .82781 m .50248 .82844 L .50251 .83045 L F
.516 .828 1 r
.50248 .82844 m .50459 .8279 L .50251 .83045 L F
.672 .123 0 r
.44023 .85904 m .44093 .86034 L .4393 .8598 L F
.44023 .85904 m .4425 .86118 L .44093 .86034 L F
.967 .704 .481 r
.43899 .85835 m .44023 .85904 L .4393 .8598 L F
.526 .219 .39 r
.5031 .86661 m .50442 .86771 L .50188 .86822 L F
.5031 .86661 m .5052 .86643 L .50442 .86771 L F
.772 .775 .855 r
.51202 .8255 m .51282 .82768 L .51503 .82554 L F
.628 .561 .76 r
.39699 .8435 m .39845 .8406 L .39658 .84107 L F
.39699 .8435 m .39917 .84337 L .39845 .8406 L F
.639 .418 .567 r
.39575 .84378 m .39917 .84337 L .39699 .8435 L F
.573 .759 .966 r
.3947 .83992 m .39658 .84107 L .39845 .8406 L F
.658 .492 .648 r
.44743 .85625 m .44535 .85861 L .44532 .85648 L F
.583 .357 .539 r
.40515 .87894 m .40495 .88077 L .40231 .88171 L F
.575 .334 .514 r
.40694 .87906 m .40495 .88077 L .40515 .87894 L F
.697 .884 .967 r
.50459 .8279 m .50764 .82761 L .50674 .82613 L F
.647 .724 .905 r
.50764 .82761 m .50864 .82516 L .50674 .82613 L F
.50764 .82761 m .50979 .8271 L .50864 .82516 L F
.62 .49 .682 r
.42842 .84337 m .42643 .84591 L .42628 .84368 L F
.559 .352 .556 r
.39649 .85375 m .39842 .85347 L .39887 .85144 L F
.654 .57 .748 r
.39924 .85615 m .39649 .85375 L .39667 .85615 L F
.39924 .85615 m .39842 .85347 L .39649 .85375 L F
.576 .549 .787 r
.39805 .84908 m .39887 .85144 L .40078 .85076 L F
.653 .52 .69 r
.39842 .85347 m .40078 .85076 L .39887 .85144 L F
.688 .835 .954 r
.42201 .82465 m .41867 .82468 L .42065 .82406 L F
.493 .82 1 r
.42404 .82428 m .42201 .82465 L .42065 .82406 L F
.952 .93 .741 r
.42991 .85933 m .42906 .85926 L .42943 .85813 L F
.703 .532 .653 r
.43371 .83047 m .43428 .83312 L .43145 .8331 L F
.599 .421 .613 r
.43663 .8306 m .43428 .83312 L .43371 .83047 L F
.629 .392 .539 r
.41426 .87413 m .41622 .87629 L .4145 .87617 L F
.639 .392 .528 r
.41638 .87418 m .41622 .87629 L .41426 .87413 L F
.566 .574 .821 r
.42176 .85976 m .41861 .85813 L .42027 .8576 L F
.639 .418 .567 r
.39575 .84378 m .39907 .84568 L .39917 .84337 L F
.451 .884 .86 r
.50391 .86101 m .50204 .86177 L .50121 .86181 L F
.586 .504 .728 r
.39532 .84862 m .39712 .84798 L .39507 .84754 L F
.615 .56 .77 r
.42951 .83699 m .42723 .83618 L .42935 .83573 L F
.671 .399 .501 r
.49932 .83022 m .49912 .82835 L .5006 .82781 L F
.77 .506 .535 r
.5006 .82781 m .50251 .83045 L .50142 .82764 L F
.5006 .82781 m .50142 .82764 L .49932 .83022 L F
.682 .517 .656 r
.42643 .84591 m .42433 .84852 L .42428 .8462 L F
.576 .768 .97 r
.41673 .82519 m .41356 .8246 L .41568 .82407 L F
.615 .743 .937 r
.41867 .82468 m .41673 .82519 L .41568 .82407 L F
.61 .38 .543 r
.43093 .86661 m .43291 .86873 L .43078 .86862 L F
.43093 .86661 m .43324 .8665 L .43291 .86873 L F
.664 .529 .69 r
.42433 .84852 m .42228 .85109 L .42214 .84873 L F
.732 .667 .787 r
.51086 .81861 m .51195 .82113 L .50857 .82081 L F
.738 .699 .815 r
.51263 .8177 m .51195 .82113 L .51086 .81861 L F
.51263 .8177 m .51416 .82033 L .51195 .82113 L F
.555 .619 .871 r
.51587 .82014 m .51416 .82033 L .51263 .8177 L F
.652 .517 .686 r
.42945 .84886 m .42964 .85069 L .42757 .85097 L F
.42945 .84886 m .42757 .85097 L .42876 .84983 L F
.692 .531 .664 r
.42643 .84591 m .42876 .84983 L .42433 .84852 L F
.666 .554 .719 r
.42861 .84568 m .42643 .84591 L .42842 .84337 L F
.665 .522 .679 r
.42945 .84886 m .42643 .84591 L .42861 .84568 L F
.42945 .84886 m .42876 .84983 L .42643 .84591 L F
.065 0 0 r
.39018 .82559 m .39145 .82533 L .39219 .82422 L F
.193 .722 .824 r
.38936 .82558 m .39145 .82533 L .39018 .82559 L F
.762 .941 .941 r
.50765 .8183 m .50591 .82013 L .50397 .81947 L F
.572 .643 .883 r
.50857 .82081 m .50591 .82013 L .50765 .8183 L F
.673 .513 .661 r
.44743 .85625 m .44753 .85873 L .44535 .85861 L F
.646 .58 .766 r
.44962 .85598 m .44743 .85625 L .44653 .85327 L F
.657 .515 .678 r
.44962 .85598 m .44753 .85873 L .44743 .85625 L F
.583 .308 .465 r
.4215 .87135 m .42353 .87325 L .42152 .87311 L F
.4215 .87135 m .42353 .87144 L .42353 .87325 L F
.805 .765 .816 r
.4995 .82388 m .50032 .82497 L .50075 .82285 L F
.57 .63 .872 r
.43648 .82424 m .43537 .82594 L .4344 .82463 L F
.43648 .82424 m .4374 .82564 L .43537 .82594 L F
.644 .511 .687 r
.42718 .85355 m .42236 .85553 L .42228 .85109 L F
.493 .861 .986 r
.39778 .82437 m .39398 .82431 L .39651 .82423 L F
.2 0 0 r
.39651 .82423 m .39958 .82386 L .39778 .82437 L F
.677 .512 .655 r
.43145 .8331 m .42935 .83573 L .42928 .83336 L F
.688 .525 .66 r
.43865 .82822 m .43874 .83077 L .43663 .8306 L F
.667 .639 .812 r
.4408 .82772 m .43865 .82822 L .4374 .82564 L F
.622 .466 .649 r
.4408 .82772 m .43874 .83077 L .43865 .82822 L F
.771 .648 .726 r
.51587 .82014 m .5186 .82081 L .51708 .82293 L F
.361 0 0 r
.51777 .8208 m .5186 .82081 L .51587 .82014 L F
.544 .343 .558 r
.51708 .82293 m .5186 .82081 L .51913 .82261 L F
.583 .945 .87 r
.52006 .8195 m .5186 .82081 L .51777 .8208 L F
.126 .096 .551 r
.51913 .82261 m .5186 .82081 L .52006 .8195 L F
.563 .827 .995 r
.42905 .82446 m .42715 .82492 L .42587 .82422 L F
.818 .508 .467 r
.49615 .82766 m .49912 .82835 L .49932 .83022 L F
.606 .802 .975 r
.43246 .82489 m .42905 .82446 L .43087 .82362 L F
.542 .743 .969 r
.43299 .82333 m .43246 .82489 L .43087 .82362 L F
.43299 .82333 m .4344 .82463 L .43246 .82489 L F
.838 .693 .702 r
.49576 .86041 m .49618 .86438 L .49398 .86333 L F
.763 .259 .004 r
.49398 .86333 m .49618 .86438 L .4972 .86563 L F
.686 .583 .735 r
.49787 .86233 m .49618 .86438 L .49576 .86041 L F
.676 .42 .527 r
.44535 .85861 m .44738 .86083 L .4456 .86006 L F
.665 .421 .542 r
.44753 .85873 m .44738 .86083 L .44535 .85861 L F
.763 .669 .759 r
.51743 .85079 m .51856 .85366 L .51537 .85337 L F
.729 .367 .364 r
.51537 .85337 m .51856 .85366 L .51761 .85538 L F
.592 .582 .811 r
.51947 .8505 m .51856 .85366 L .51743 .85079 L F
.51947 .8505 m .52064 .85351 L .51856 .85366 L F
.441 .016 .136 r
.51856 .85366 m .51969 .85506 L .51761 .85538 L F
.51856 .85366 m .52064 .85351 L .51969 .85506 L F
.766 .66 .745 r
.49203 .85872 m .49559 .85871 L .49359 .86143 L F
.539 .03 0 r
.49222 .85901 m .49559 .85871 L .49203 .85872 L F
.637 .477 .65 r
.49559 .85871 m .49576 .86041 L .49359 .86143 L F
.583 .69 .915 r
.49661 .85645 m .49559 .85871 L .49222 .85901 L F
.49661 .85645 m .49865 .85889 L .49559 .85871 L F
.62 .635 .844 r
.49559 .85871 m .49865 .85889 L .49675 .85906 L F
.741 .578 .673 r
.49675 .85906 m .49576 .86041 L .49559 .85871 L F
.611 .372 .53 r
.40495 .88077 m .40181 .88384 L .40231 .88171 L F
.75 .25 0 r
.49836 .86613 m .49914 .86764 L .4972 .86563 L F
.985 .89 .643 r
.49876 .86744 m .49914 .86764 L .49746 .86963 L F
.75 .25 0 r
.49836 .86613 m .49986 .868 L .49914 .86764 L F
.77 .638 .716 r
.49753 .86521 m .49914 .86764 L .49948 .86623 L F
.985 .89 .643 r
.49948 .86623 m .49914 .86764 L .49876 .86744 L F
.75 .25 0 r
.49986 .868 m .50003 .86821 L .49914 .86764 L F
.572 .315 .488 r
.41869 .87419 m .41622 .87629 L .41638 .87418 L F
.517 .845 .998 r
.40878 .82342 m .40827 .82451 L .40712 .82362 L F
.40878 .82342 m .41055 .82407 L .40827 .82451 L F
.959 .628 .336 r
.49203 .85872 m .49359 .86143 L .49239 .86065 L F
.49203 .85872 m .49359 .86143 L .49239 .86065 L F
.95 .601 .297 r
.49239 .86065 m .49359 .86143 L .49398 .86333 L F
.838 .693 .702 r
.49576 .86041 m .49398 .86333 L .49359 .86143 L F
.597 .368 .539 r
.43078 .86862 m .42893 .87039 L .42873 .8687 L F
.325 0 0 r
.51006 .85794 m .50953 .85735 L .50817 .85849 L F
.654 .57 .748 r
.39924 .85615 m .39932 .85614 L .39842 .85347 L F
.534 .34 .565 r
.39723 .8587 m .39924 .85615 L .39667 .85615 L F
.39723 .8587 m .3992 .85842 L .39924 .85615 L F
.637 .424 .578 r
.39924 .85615 m .3992 .85842 L .39932 .85614 L F
.741 .578 .673 r
.49675 .85906 m .49787 .86233 L .49576 .86041 L F
.555 .679 .921 r
.49982 .85812 m .49865 .85889 L .49661 .85645 L F
.579 .744 .955 r
.49675 .85906 m .49865 .85889 L .49982 .85812 L F
.409 .388 .725 r
.49982 .86033 m .49675 .85906 L .49982 .85812 L F
.956 .708 .523 r
.49851 .85996 m .49982 .86033 L .49982 .85812 L F
.49851 .85996 m .4994 .85872 L .50057 .85724 L F
.4994 .85872 m .49982 .85812 L .50035 .8575 L F
.4994 .85872 m .50035 .8575 L .50057 .85724 L F
.409 .388 .725 r
.49982 .86033 m .49787 .86233 L .49748 .86118 L F
.49855 .8598 m .49748 .86118 L .49675 .85906 L F
.49982 .86033 m .49748 .86118 L .49855 .8598 L F
.557 .44 .675 r
.39726 .85891 m .3992 .85842 L .39723 .8587 L F
.631 .501 .685 r
.42951 .83699 m .43035 .84092 L .42819 .84118 L F
.633 .511 .696 r
.43035 .84092 m .42842 .84337 L .42819 .84118 L F
.396 .543 .885 r
.42757 .85097 m .42433 .84852 L .42876 .84983 L F
.574 .371 .568 r
.43618 .8632 m .43517 .86616 L .43324 .8665 L F
.629 .496 .682 r
.43761 .86021 m .43796 .86356 L .43618 .8632 L F
.638 .437 .595 r
.43809 .86586 m .43618 .8632 L .43796 .86356 L F
.43809 .86586 m .43517 .86616 L .43618 .8632 L F
.708 .652 .792 r
.39712 .84798 m .39805 .84908 L .40022 .84847 L F
.576 .549 .787 r
.39805 .84908 m .40078 .85076 L .40022 .84847 L F
.609 .544 .757 r
.39842 .85347 m .39932 .85614 L .40137 .85588 L F
.656 .484 .639 r
.3992 .85842 m .40137 .85588 L .39932 .85614 L F
.443 .242 .511 r
.43647 .85623 m .43377 .85626 L .43285 .85591 L F
.506 .284 .511 r
.5052 .86643 m .50742 .86386 L .50724 .86635 L F
.511 .31 .543 r
.50742 .86386 m .50979 .86144 L .50912 .86334 L F
.403 .22 .516 r
.50724 .86635 m .50742 .86386 L .50912 .86334 L F
.702 .549 .676 r
.43146 .83527 m .42935 .83573 L .43145 .8331 L F
.654 .462 .612 r
.43428 .83312 m .43146 .83527 L .43145 .8331 L F
.613 .48 .676 r
.39732 .86106 m .3992 .85842 L .39726 .85891 L F
.654 .458 .606 r
.42386 .8579 m .42329 .85865 L .42027 .8576 L F
.599 .538 .757 r
.42329 .85865 m .42176 .85976 L .42027 .8576 L F
.499 .825 1 r
.4031 .8241 m .39958 .82386 L .40167 .82384 L F
.445 .85 .969 r
.40473 .82366 m .4031 .8241 L .40167 .82384 L F
.79 .728 .795 r
.51202 .8255 m .51503 .82554 L .51439 .82363 L F
.618 .555 .761 r
.39845 .8406 m .39917 .84337 L .40125 .843 L F
.754 .618 .708 r
.39907 .84568 m .40125 .843 L .39917 .84337 L F
.651 .516 .686 r
.43058 .84294 m .42861 .84568 L .42842 .84337 L F
.43058 .84294 m .4317 .84594 L .42861 .84568 L F
.604 .486 .692 r
.43153 .84818 m .42861 .84568 L .4317 .84594 L F
.43153 .84818 m .42945 .84886 L .42861 .84568 L F
.654 .462 .612 r
.43428 .83312 m .43432 .83553 L .43146 .83527 L F
.599 .421 .613 r
.43663 .8306 m .4363 .83296 L .43428 .83312 L F
.605 .423 .609 r
.43636 .83531 m .43428 .83312 L .4363 .83296 L F
.43636 .83531 m .43432 .83553 L .43428 .83312 L F
.402 .817 .974 r
.51708 .82293 m .51913 .82261 L .51608 .82253 L F
.641 .492 .664 r
.43146 .83527 m .42951 .83699 L .42935 .83573 L F
.43146 .83527 m .43228 .8383 L .42951 .83699 L F
.644 .509 .684 r
.43248 .84045 m .42951 .83699 L .43228 .8383 L F
.43248 .84045 m .43035 .84092 L .42951 .83699 L F
.473 .191 .404 r
.43874 .83077 m .4363 .83296 L .43663 .8306 L F
.7 .608 .75 r
.43058 .84294 m .42842 .84337 L .43035 .84092 L F
.708 .751 .886 r
.50864 .82516 m .50979 .8271 L .51202 .8255 L F
.575 .334 .514 r
.40694 .87906 m .40706 .88101 L .40495 .88077 L F
.595 .349 .515 r
.40694 .87906 m .40879 .88095 L .40706 .88101 L F
.642 .345 .452 r
.40694 .87906 m .40907 .8793 L .40879 .88095 L F
.563 .472 .71 r
.42571 .85672 m .42236 .85553 L .42718 .85355 L F
.42571 .85672 m .42386 .8579 L .42236 .85553 L F
.614 .815 .977 r
.4142 .82298 m .41356 .8246 L .41229 .82374 L F
.4142 .82298 m .41568 .82407 L .41356 .8246 L F
.599 .504 .718 r
.4393 .8598 m .43796 .86356 L .43761 .86021 L F
.708 .652 .791 r
.39712 .84798 m .40022 .84847 L .39907 .84568 L F
.744 .669 .777 r
.39907 .84568 m .40022 .84847 L .4022 .84594 L F
.67 .56 .721 r
.4022 .84594 m .40022 .84847 L .40255 .84803 L F
.604 .337 .485 r
.40022 .84847 m .40215 .85017 L .40255 .84803 L F
.412 .348 .675 r
.40022 .84847 m .40078 .85076 L .40215 .85017 L F
.752 .705 .807 r
.51086 .81861 m .50857 .82081 L .50765 .8183 L F
.657 .515 .678 r
.44962 .85598 m .44957 .85861 L .44753 .85873 L F
.661 .433 .563 r
.44957 .85861 m .44738 .86083 L .44753 .85873 L F
.495 .147 .307 r
.5052 .86643 m .50627 .86727 L .50442 .86771 L F
.5052 .86643 m .50724 .86635 L .50627 .86727 L F
.633 .433 .594 r
.42964 .85069 m .42749 .85326 L .42757 .85097 L F
.646 .559 .742 r
.43248 .84045 m .43058 .84294 L .43035 .84092 L F
.43248 .84045 m .43361 .84366 L .43058 .84294 L F
.68 .531 .676 r
.43365 .84562 m .43058 .84294 L .43361 .84366 L F
.43365 .84562 m .4317 .84594 L .43058 .84294 L F
.611 .402 .574 r
.43517 .86616 m .43291 .86873 L .43324 .8665 L F
.612 .717 .92 r
.49982 .86033 m .50121 .86181 L .49787 .86233 L F
.451 .884 .86 r
.50391 .86101 m .50121 .86181 L .5029 .86084 L F
.581 .94 .808 r
.50473 .86009 m .50391 .86101 L .5029 .86084 L F
.50473 .86009 m .50652 .85943 L .50391 .86101 L F
.291 0 .09 r
.39219 .82422 m .39331 .82477 L .39398 .82431 L F
.39219 .82422 m .39145 .82533 L .39331 .82477 L F
.636 .488 .665 r
.43443 .83799 m .43146 .83527 L .43432 .83553 L F
.43443 .83799 m .43228 .8383 L .43146 .83527 L F
.473 .191 .404 r
.43874 .83077 m .43839 .83261 L .4363 .83296 L F
.577 .283 .433 r
.44064 .83237 m .43839 .83261 L .43874 .83077 L F
.622 .466 .649 r
.4408 .82772 m .44105 .83082 L .43874 .83077 L F
.589 .279 .411 r
.44105 .83082 m .44064 .83237 L .43874 .83077 L F
.646 .58 .766 r
.44962 .85598 m .44653 .85327 L .44639 .85481 L F
.162 0 0 r
.44639 .85481 m .45178 .85549 L .44962 .85598 L F
.44639 .85481 m .45033 .85538 L .45178 .85549 L F
.38 0 0 r
.44717 .85518 m .45033 .85538 L .44639 .85481 L F
.325 0 .228 r
.44653 .85327 m .44717 .85518 L .44639 .85481 L F
.44653 .85327 m .44547 .85561 L .44717 .85518 L F
.643 .515 .693 r
.45178 .85549 m .44957 .85861 L .44962 .85598 L F
.653 .52 .69 r
.39842 .85347 m .40089 .85361 L .40078 .85076 L F
.609 .544 .757 r
.39842 .85347 m .40137 .85588 L .40089 .85361 L F
.421 .229 .513 r
.50979 .86144 m .51143 .85878 L .51084 .86074 L F
0 0 .184 r
.50912 .86334 m .50979 .86144 L .51084 .86074 L F
.667 .639 .812 r
.4408 .82772 m .4374 .82564 L .43954 .82522 L F
.642 .656 .849 r
.44264 .82742 m .4408 .82772 L .43954 .82522 L F
.623 .466 .649 r
.44322 .82997 m .4408 .82772 L .44264 .82742 L F
.44322 .82997 m .44105 .83082 L .4408 .82772 L F
.779 .789 .861 r
.4345 .85491 m .43647 .85623 L .43285 .85591 L F
.569 .359 .556 r
.43953 .85812 m .43647 .85623 L .43854 .85562 L F
.745 .983 .755 r
.43991 .85754 m .43899 .85835 L .43914 .8579 L F
.569 .359 .556 r
.43953 .85812 m .43916 .85818 L .43914 .8579 L F
.43916 .85789 m .43914 .8579 L .43914 .85788 L F
.43953 .85812 m .43914 .8579 L .43916 .85789 L F
.745 .983 .755 r
.43991 .85754 m .43914 .8579 L .43957 .85748 L F
0 0 .296 r
.4393 .85744 m .43953 .85812 L .43936 .85769 L F
.4393 .85744 m .43936 .85769 L .43854 .85562 L F
.745 .983 .755 r
.43957 .85748 m .43936 .85769 L .4393 .85744 L F
.43936 .85769 m .43914 .8579 L .4393 .85744 L F
0 0 .369 r
.43914 .8579 m .4393 .85827 L .4393 .85744 L F
.43899 .85835 m .43917 .8583 L .43914 .8579 L F
.43917 .8583 m .4393 .85827 L .43914 .8579 L F
.569 .359 .556 r
.43914 .85788 m .43593 .85867 L .43647 .85623 L F
.43916 .85818 m .43593 .85867 L .43914 .85788 L F
.547 .242 .402 r
.51084 .86074 m .51143 .85878 L .51316 .86066 L F
.405 .198 .482 r
.51143 .85878 m .51342 .85591 L .51354 .85855 L F
.524 .241 .427 r
.51143 .85878 m .51354 .85855 L .51316 .86066 L F
.47 .885 .771 r
.50817 .85849 m .50652 .85943 L .50473 .86009 L F
0 0 0 r
.51342 .85591 m .51006 .85794 L .51243 .85607 L F
.6 .457 .659 r
.51537 .85337 m .51556 .8557 L .51342 .85591 L F
0 0 0 r
.51537 .85337 m .51342 .85591 L .51426 .85527 L F
.427 .869 .819 r
.51426 .85527 m .51342 .85591 L .51243 .85607 L F
.551 .364 .581 r
.51556 .8557 m .51354 .85855 L .51342 .85591 L F
.652 .677 .86 r
.42906 .85926 m .4264 .85994 L .42528 .85812 L F
.611 .372 .53 r
.40495 .88077 m .40388 .88395 L .40181 .88384 L F
.576 .332 .51 r
.40388 .88395 m .40507 .88152 L .4057 .88592 L F
.605 .421 .607 r
.40879 .88095 m .40507 .88152 L .40706 .88101 L F
.40879 .88095 m .41033 .88346 L .40507 .88152 L F
.631 .347 .468 r
.40507 .88152 m .40773 .88581 L .4057 .88592 L F
.40507 .88152 m .41033 .88346 L .40784 .88571 L F
.40663 .88403 m .40784 .88571 L .40773 .88581 L F
.40507 .88152 m .40784 .88571 L .40663 .88403 L F
.576 .332 .51 r
.40388 .88395 m .40507 .88152 L .4057 .88592 L F
.561 .316 .501 r
.40706 .88101 m .40507 .88152 L .40388 .88395 L F
.40706 .88101 m .4055 .88246 L .40495 .88077 L F
.4055 .88246 m .40388 .88395 L .40474 .88141 L F
.4055 .88246 m .40474 .88141 L .40495 .88077 L F
.452 .36 .661 r
.50016 .82041 m .50075 .82285 L .50225 .82218 L F
.602 .48 .686 r
.43153 .84818 m .42964 .85069 L .42945 .84886 L F
.615 .743 .937 r
.41867 .82468 m .41568 .82407 L .41735 .82334 L F
.645 .775 .943 r
.42065 .82406 m .41867 .82468 L .41735 .82334 L F
.369 .745 .989 r
.3947 .83992 m .39845 .8406 L .39672 .83964 L F
.564 .83 .995 r
.39672 .83964 m .39845 .8406 L .39989 .84002 L F
.618 .555 .761 r
.39845 .8406 m .40125 .843 L .39989 .84002 L F
.493 .82 1 r
.42404 .82428 m .42065 .82406 L .42282 .82363 L F
.434 .721 .985 r
.42474 .82342 m .42404 .82428 L .42282 .82363 L F
.42474 .82342 m .42587 .82422 L .42404 .82428 L F
.709 .679 .818 r
.44471 .82515 m .44602 .82777 L .44264 .82742 L F
.586 .302 .452 r
.44602 .82777 m .44322 .82997 L .44264 .82742 L F
.44602 .82777 m .44558 .83011 L .44322 .82997 L F
.635 .644 .842 r
.44819 .82737 m .44602 .82777 L .44471 .82515 L F
.58 .297 .45 r
.44788 .82972 m .44602 .82777 L .44819 .82737 L F
.44788 .82972 m .44558 .83011 L .44602 .82777 L F
.647 .643 .833 r
.5014 .82534 m .50225 .82218 L .50032 .82497 L F
.5014 .82534 m .50362 .82485 L .50225 .82218 L F
.976 .722 .483 r
.50032 .82497 m .50142 .82764 L .5014 .82534 L F
.77 .65 .729 r
.50142 .82764 m .50362 .82485 L .5014 .82534 L F
.765 .676 .764 r
.50142 .82764 m .50251 .83045 L .50459 .8279 L F
.591 .447 .654 r
.40255 .84803 m .40443 .84563 L .4022 .84594 L F
.40255 .84803 m .40506 .84921 L .40443 .84563 L F
.638 .368 .493 r
.40255 .84803 m .40381 .84974 L .40506 .84921 L F
.40255 .84803 m .40215 .85017 L .40381 .84974 L F
.988 .894 .582 r
.4962 .82534 m .49498 .82708 L .49564 .82511 L F
.969 .742 .541 r
.4962 .82534 m .49615 .82766 L .49498 .82708 L F
.824 1 .806 r
.49831 .82303 m .4962 .82534 L .49717 .82391 L F
.834 .996 .843 r
.4962 .82534 m .49564 .82511 L .49717 .82391 L F
.988 .894 .582 r
.4962 .82534 m .49498 .82708 L .49564 .82511 L F
.818 .508 .467 r
.49615 .82766 m .49932 .83022 L .49713 .83013 L F
.184 .091 .508 r
.4962 .82534 m .4963 .82804 L .49717 .82391 L F
.4962 .82534 m .49615 .82766 L .4963 .82804 L F
.599 .504 .718 r
.4393 .8598 m .44007 .86351 L .43796 .86356 L F
.59 .399 .591 r
.43796 .86356 m .44007 .86351 L .43809 .86586 L F
.661 .433 .563 r
.44957 .85861 m .44937 .86112 L .44738 .86083 L F
.643 .515 .693 r
.45178 .85549 m .45254 .85855 L .44957 .85861 L F
.729 .572 .678 r
.45254 .85855 m .44937 .86112 L .44957 .85861 L F
.591 .314 .465 r
.42353 .87325 m .42353 .87144 L .42544 .87314 L F
.618 .306 .419 r
.42353 .87144 m .42569 .87163 L .42544 .87314 L F
.754 .618 .708 r
.39907 .84568 m .4022 .84594 L .40125 .843 L F
.674 .574 .734 r
.40125 .843 m .4022 .84594 L .40443 .84563 L F
.77 .65 .729 r
.50142 .82764 m .50459 .8279 L .50362 .82485 L F
.659 .588 .764 r
.50362 .82485 m .50459 .8279 L .50674 .82613 L F
.392 .315 .65 r
.40078 .85076 m .40178 .85215 L .40215 .85017 L F
.40078 .85076 m .40089 .85361 L .40178 .85215 L F
.518 .233 .422 r
.40879 .88095 m .40907 .8793 L .41251 .87747 L F
.526 .53 .803 r
.51263 .8177 m .51352 .8147 L .51472 .81722 L F
.51263 .8177 m .51319 .8179 L .51322 .81762 L F
.51263 .8177 m .51322 .81762 L .51352 .8147 L F
.512 .407 .672 r
.51321 .81757 m .51317 .81763 L .51263 .8177 L F
.707 .667 .808 r
.51309 .81774 m .51319 .8179 L .513 .81787 L F
.555 .619 .871 r
.51444 .81906 m .51263 .8177 L .51295 .81796 L F
.51444 .81906 m .51295 .81796 L .51481 .8195 L F
.512 .407 .672 r
.51473 .81742 m .51481 .8195 L .5129 .81792 L F
.51322 .81762 m .5129 .81792 L .51263 .8177 L F
.658 .65 .831 r
.51322 .81762 m .51319 .8179 L .51309 .81774 L F
.512 .407 .672 r
.51473 .81742 m .5129 .81792 L .51322 .81762 L F
.658 .65 .831 r
.51352 .8147 m .51322 .81762 L .51051 .81392 L F
.512 .407 .672 r
.51472 .81722 m .51481 .8195 L .51263 .8177 L F
.658 .65 .831 r
.51322 .81762 m .51309 .81774 L .51051 .81392 L F
.707 .667 .808 r
.51051 .81392 m .51309 .81774 L .51278 .81783 L F
.706 .736 .874 r
.50961 .81734 m .51263 .8177 L .51086 .81861 L F
.593 .082 .005 r
.50961 .81734 m .51319 .8179 L .51263 .8177 L F
.707 .667 .808 r
.51309 .81774 m .513 .81787 L .51278 .81783 L F
.512 .407 .672 r
.51472 .81722 m .51473 .81742 L .51317 .81763 L F
.51472 .81722 m .51317 .81763 L .51321 .81757 L F
.707 .667 .808 r
.51002 .8158 m .51278 .81783 L .50961 .81734 L F
.51051 .81392 m .51278 .81783 L .51002 .8158 L F
.555 .619 .871 r
.51587 .82014 m .51444 .81906 L .51481 .8195 L F
.454 .435 .748 r
.51693 .81694 m .51587 .82014 L .51481 .8195 L F
.51693 .81694 m .51777 .8208 L .51587 .82014 L F
.752 .705 .807 r
.51086 .81861 m .50765 .8183 L .50961 .81734 L F
.693 .518 .646 r
.42971 .85319 m .42749 .85326 L .42964 .85069 L F
.581 .451 .669 r
.43153 .84818 m .43158 .8504 L .42964 .85069 L F
.608 .451 .643 r
.43196 .85282 m .42964 .85069 L .43158 .8504 L F
.43196 .85282 m .42971 .85319 L .42964 .85069 L F
.613 .48 .676 r
.39732 .86106 m .39954 .86082 L .3992 .85842 L F
.604 .422 .609 r
.39731 .86338 m .39954 .86082 L .39732 .86106 L F
.309 0 0 r
.39274 .84009 m .39452 .83995 L .39241 .84043 L F
0 0 0 r
.3947 .83992 m .39452 .83995 L .39274 .84009 L F
.572 .315 .488 r
.41869 .87419 m .41826 .87613 L .41622 .87629 L F
.61 .376 .538 r
.42152 .87311 m .41826 .87613 L .41869 .87419 L F
.672 .498 .641 r
.43365 .84562 m .43153 .84818 L .4317 .84594 L F
0 0 0 r
.51627 .85253 m .51743 .85079 L .51537 .85337 L F
.729 .367 .364 r
.51537 .85337 m .51761 .85538 L .51556 .8557 L F
0 0 0 r
.51627 .85253 m .51537 .85337 L .51426 .85527 L F
.563 .827 .995 r
.42905 .82446 m .42587 .82422 L .42785 .82373 L F
.661 .843 .97 r
.43087 .82362 m .42905 .82446 L .42785 .82373 L F
.538 .377 .61 r
.43839 .83261 m .43636 .83531 L .4363 .83296 L F
.603 .383 .555 r
.4145 .87617 m .41251 .87747 L .41374 .87665 L F
.4145 .87617 m .41398 .8777 L .41251 .87747 L F
.624 .357 .493 r
.4145 .87617 m .41626 .87803 L .41398 .8777 L F
.4145 .87617 m .41622 .87629 L .41626 .87803 L F
.565 .342 .535 r
.42528 .85812 m .42386 .8579 L .42571 .85672 L F
.42528 .85812 m .42329 .85865 L .42386 .8579 L F
.466 .807 .999 r
.41077 .82304 m .41055 .82407 L .40878 .82342 L F
.41077 .82304 m .41229 .82374 L .41055 .82407 L F
.963 .631 .285 r
.49101 .85762 m .49203 .85872 L .49239 .86065 L F
.634 .152 0 r
.49222 .85901 m .49203 .85872 L .49101 .85762 L F
.767 .675 .761 r
.52272 .85072 m .52064 .85351 L .51947 .8505 L F
.606 .447 .641 r
.52272 .85072 m .523 .85352 L .52064 .85351 L F
.38 .758 .991 r
.52064 .85351 m .523 .85352 L .52159 .85269 L F
.773 .553 .601 r
.51627 .85253 m .52053 .85389 L .51947 .8505 L F
.52053 .85389 m .5207 .85395 L .52063 .85375 L F
.52053 .85389 m .52063 .85375 L .51947 .8505 L F
.38 .758 .991 r
.52064 .85351 m .52109 .85312 L .52063 .85375 L F
.374 .334 .685 r
.51947 .8505 m .52063 .85375 L .52159 .85269 L F
.52063 .85375 m .5207 .85395 L .52159 .85269 L F
.773 .55 .596 r
.51969 .85506 m .5207 .85395 L .52053 .85389 L F
.38 .758 .991 r
.52018 .85425 m .52063 .85376 L .5197 .85505 L F
.52063 .85376 m .52053 .85389 L .5197 .85505 L F
.773 .55 .596 r
.51969 .85506 m .52053 .85389 L .51627 .85253 L F
.38 .758 .991 r
.52063 .85376 m .52063 .85375 L .52053 .85389 L F
.52064 .85351 m .52063 .85375 L .52018 .85425 L F
.5197 .85505 m .52159 .85269 L .51969 .85506 L F
.52109 .85312 m .52159 .85269 L .5197 .85505 L F
.507 .301 .535 r
.44149 .85498 m .44122 .85553 L .43854 .85562 L F
.44122 .85553 m .44108 .85583 L .44059 .85627 L F
0 0 .296 r
.4393 .85744 m .43854 .85562 L .44061 .85628 L F
0 .195 .714 r
.44061 .85628 m .44042 .85646 L .4393 .85744 L F
.745 .983 .755 r
.43954 .85748 m .44042 .85646 L .44134 .85566 L F
0 0 .296 r
.4393 .85744 m .44061 .85628 L .44083 .85635 L F
.507 .301 .535 r
.44108 .85583 m .44061 .85628 L .44059 .85627 L F
0 .195 .714 r
.44156 .85537 m .44061 .85628 L .4393 .85744 L F
.44185 .85501 m .44156 .85537 L .4412 .8557 L F
.44156 .85537 m .44134 .85566 L .44042 .85646 L F
0 0 .048 r
.44185 .85501 m .44083 .85635 L .44108 .85583 L F
.44185 .85501 m .44108 .85583 L .44149 .85498 L F
0 .195 .714 r
.44185 .85501 m .4412 .8557 L .4393 .85744 L F
.507 .301 .535 r
.44108 .85583 m .44083 .85635 L .44061 .85628 L F
.44122 .85553 m .44059 .85627 L .43854 .85562 L F
.745 .983 .755 r
.43991 .85754 m .43954 .85748 L .44134 .85566 L F
.43954 .85748 m .4393 .85744 L .44042 .85646 L F
.656 .484 .639 r
.3992 .85842 m .40148 .85836 L .40137 .85588 L F
.597 .506 .722 r
.40089 .85361 m .40137 .85588 L .40328 .85359 L F
.655 .592 .772 r
.40137 .85588 m .40375 .85577 L .40328 .85359 L F
.669 .507 .656 r
.40148 .85836 m .40375 .85577 L .40137 .85588 L F
.518 .233 .422 r
.40879 .88095 m .41251 .87747 L .41083 .88087 L F
.614 .351 .496 r
.41398 .8777 m .41083 .88087 L .41251 .87747 L F
.717 .64 .771 r
.39989 .84002 m .40125 .843 L .40307 .84046 L F
.604 .483 .688 r
.40307 .84046 m .40125 .843 L .40319 .8425 L F
.674 .574 .734 r
.40125 .843 m .40443 .84563 L .40319 .8425 L F
.687 .383 .455 r
.49717 .82391 m .50032 .82497 L .49831 .82303 L F
.597 .506 .722 r
.40089 .85361 m .40328 .85359 L .40178 .85215 L F
.773 .553 .601 r
.51627 .85253 m .51947 .8505 L .51743 .85079 L F
.64 .556 .744 r
.43566 .8431 m .43361 .84366 L .43248 .84045 L F
.628 .509 .698 r
.43566 .8431 m .43365 .84562 L .43361 .84366 L F
.642 .656 .849 r
.44264 .82742 m .43954 .82522 L .44257 .82558 L F
.64 .566 .756 r
.44471 .82515 m .44264 .82742 L .44257 .82558 L F
.649 .539 .717 r
.44446 .86282 m .4425 .86118 L .4456 .86006 L F
.602 .319 .461 r
.44738 .86083 m .44446 .86282 L .4456 .86006 L F
.669 .785 .935 r
.43854 .85562 m .435 .85333 L .43676 .85261 L F
.43854 .85562 m .4345 .85491 L .435 .85333 L F
.507 .301 .535 r
.44149 .85498 m .43854 .85562 L .43676 .85261 L F
.598 .764 .959 r
.43648 .82424 m .4344 .82463 L .43299 .82333 L F
.619 .652 .861 r
.43954 .82522 m .4374 .82564 L .43648 .82424 L F
.664 .487 .635 r
.4337 .84794 m .43153 .84818 L .43365 .84562 L F
.647 .536 .714 r
.43584 .84538 m .43365 .84562 L .43566 .8431 L F
.627 .458 .633 r
.43586 .8477 m .43365 .84562 L .43584 .84538 L F
.43586 .8477 m .4337 .84794 L .43365 .84562 L F
.618 .459 .644 r
.43655 .83755 m .43432 .83553 L .43636 .83531 L F
.43655 .83755 m .43443 .83799 L .43432 .83553 L F
.583 .804 .984 r
.41735 .82334 m .41568 .82407 L .4142 .82298 L F
.739 .492 .555 r
.50003 .86821 m .50188 .86822 L .50228 .8709 L F
.614 .354 .5 r
.50188 .86822 m .50442 .87068 L .50228 .8709 L F
.50188 .86822 m .50442 .86771 L .50442 .87068 L F
.705 .617 .756 r
.40319 .8425 m .40443 .84563 L .40624 .84299 L F
.593 .465 .676 r
.40443 .84563 m .40664 .84537 L .40624 .84299 L F
.715 .531 .639 r
.40443 .84563 m .40738 .8482 L .40664 .84537 L F
.40443 .84563 m .40506 .84921 L .40738 .8482 L F
.734 .762 .875 r
.49834 .81496 m .49838 .81546 L .49634 .81465 L F
.813 .501 .461 r
.49838 .81546 m .49638 .81615 L .49634 .81465 L F
.49838 .81546 m .49902 .81693 L .49638 .81615 L F
.533 .45 .707 r
.50095 .81484 m .49838 .81546 L .49834 .81496 L F
.50095 .81484 m .50098 .81577 L .49838 .81546 L F
.634 .567 .761 r
.50098 .81577 m .49902 .81693 L .49838 .81546 L F
.767 .675 .761 r
.52272 .85072 m .51947 .8505 L .52159 .85269 L F
.534 .394 .637 r
.52489 .85289 m .523 .85352 L .52272 .85072 L F
.74 .363 .339 r
.52159 .85269 m .52489 .85289 L .52272 .85072 L F
.2 0 0 r
.39651 .82423 m .39849 .82422 L .39958 .82386 L F
0 0 0 r
.39849 .82422 m .40167 .82384 L .39958 .82386 L F
.597 .368 .539 r
.43078 .86862 m .43068 .87063 L .42893 .87039 L F
.589 .361 .538 r
.43078 .86862 m .43269 .87056 L .43068 .87063 L F
.629 .358 .488 r
.43078 .86862 m .43291 .86873 L .43269 .87056 L F
.641 .518 .698 r
.43443 .83799 m .43248 .84045 L .43228 .8383 L F
.327 .804 .906 r
.45033 .85538 m .45395 .85516 L .45178 .85549 L F
.697 .6 .744 r
.45395 .85516 m .45254 .85855 L .45178 .85549 L F
.369 .745 .989 r
.3947 .83992 m .39672 .83964 L .39452 .83995 L F
.611 .402 .574 r
.43517 .86616 m .43501 .86872 L .43291 .86873 L F
.624 .407 .567 r
.43809 .86586 m .43501 .86872 L .43517 .86616 L F
.817 .749 .787 r
.46059 .82258 m .45745 .82282 L .45958 .82146 L F
.46059 .82258 m .45844 .82516 L .45745 .82282 L F
.585 .398 .595 r
.46059 .82258 m .46062 .82514 L .45844 .82516 L F
0 .461 .753 r
.45958 .82146 m .46258 .82232 L .46059 .82258 L F
.327 .196 .545 r
.46199 .82375 m .46059 .82258 L .46258 .82232 L F
.46199 .82375 m .46062 .82514 L .46059 .82258 L F
.156 .694 .826 r
.38806 .82537 m .39145 .82533 L .38936 .82558 L F
.668 .486 .63 r
.46406 .85066 m .46444 .85349 L .462 .85278 L F
.46406 .85066 m .46444 .85349 L .462 .85278 L F
.479 .351 .629 r
.46406 .85066 m .46599 .8527 L .46603 .85042 L F
.46406 .85066 m .46444 .85349 L .46599 .8527 L F
.46406 .85066 m .46599 .8527 L .46603 .85042 L F
.46406 .85066 m .46444 .85349 L .46599 .8527 L F
.65 .338 .43 r
.44372 .83199 m .44105 .83082 L .44322 .82997 L F
.44372 .83199 m .44064 .83237 L .44105 .83082 L F
.578 .455 .676 r
.3992 .85842 m .4013 .86013 L .40148 .85836 L F
.3992 .85842 m .39954 .86082 L .4013 .86013 L F
.773 .704 .787 r
.51608 .82253 m .51913 .82261 L .51777 .8208 L F
.126 .096 .551 r
.51913 .82261 m .52006 .8195 L .51777 .8208 L F
.796 .742 .803 r
.51202 .8255 m .51439 .82363 L .51303 .82186 L F
.671 .709 .877 r
.51303 .82186 m .51439 .82363 L .51608 .82253 L F
.67 .558 .72 r
.43467 .84011 m .43248 .84045 L .43443 .83799 L F
.64 .556 .744 r
.43566 .8431 m .43248 .84045 L .43467 .84011 L F
.804 .743 .796 r
.45844 .82516 m .45527 .82483 L .45745 .82282 L F
.655 .154 .047 r
.45844 .82516 m .45738 .82556 L .45527 .82483 L F
0 0 0 r
.46062 .82514 m .45738 .82556 L .45844 .82516 L F
.445 .85 .969 r
.40473 .82366 m .40167 .82384 L .40375 .82337 L F
.103 .656 .802 r
.40571 .82351 m .40473 .82366 L .40375 .82337 L F
.40571 .82351 m .40712 .82362 L .40473 .82366 L F
.331 .11 .42 r
.50225 .82218 m .50075 .82285 L .50032 .82497 L F
.608 .421 .602 r
.42743 .85572 m .42718 .85355 L .42749 .85326 L F
.716 .508 .607 r
.42954 .85536 m .42749 .85326 L .42971 .85319 L F
.42954 .85536 m .42743 .85572 L .42749 .85326 L F
.65 .395 .52 r
.42893 .87039 m .42544 .87314 L .42569 .87163 L F
.608 .421 .602 r
.42743 .85572 m .42571 .85672 L .42718 .85355 L F
.551 .595 .851 r
.50225 .82218 m .50362 .82485 L .50547 .82465 L F
.659 .588 .764 r
.50362 .82485 m .50674 .82613 L .50547 .82465 L F
.551 .364 .581 r
.51556 .8557 m .51558 .85817 L .51354 .85855 L F
.569 .398 .611 r
.51761 .85538 m .51558 .85817 L .51556 .8557 L F
.769 .671 .755 r
.50367 .84 m .50481 .84294 L .50151 .84276 L F
.773 .567 .621 r
.50151 .84276 m .50481 .84294 L .50443 .84558 L F
.521 .537 .813 r
.50705 .84234 m .50481 .84294 L .50367 .84 L F
.443 .267 .547 r
.50443 .84558 m .50481 .84294 L .50705 .84234 L F
.525 .241 .426 r
.43914 .85818 m .4357 .8605 L .43593 .85867 L F
.43953 .85812 m .43919 .85834 L .43914 .85818 L F
.43919 .85834 m .4357 .8605 L .43914 .85818 L F
0 0 .369 r
.43899 .85835 m .43914 .85903 L .43923 .85859 L F
.43918 .8583 m .43919 .85834 L .4393 .85827 L F
.43919 .85834 m .4393 .85865 L .4393 .85865 L F
.525 .241 .426 r
.43953 .85812 m .43925 .8585 L .43919 .85834 L F
0 0 .369 r
.43919 .85834 m .4393 .85865 L .4393 .85827 L F
.217 0 0 r
.4357 .8605 m .43781 .86043 L .4393 .8598 L F
.525 .241 .426 r
.43919 .85834 m .43781 .86043 L .4357 .8605 L F
0 0 .369 r
.43899 .85835 m .4393 .85865 L .43918 .8583 L F
.525 .241 .426 r
.43925 .8585 m .43781 .86043 L .43919 .85834 L F
.779 .94 .592 r
.4393 .85827 m .43781 .86043 L .43925 .8585 L F
.4393 .85827 m .43925 .8585 L .43953 .85812 L F
0 0 .369 r
.43923 .85859 m .4393 .8598 L .4393 .85865 L F
.43914 .85903 m .4393 .8598 L .43923 .85859 L F
.673 .759 .915 r
.40518 .84004 m .40847 .84043 L .4074 .8392 L F
.751 .627 .723 r
.40518 .84004 m .40624 .84299 L .40847 .84043 L F
.663 .494 .646 r
.40624 .84299 m .40863 .84306 L .40847 .84043 L F
.489 .642 .924 r
.40847 .84043 m .4091 .83913 L .4074 .8392 L F
.40847 .84043 m .41024 .84016 L .4091 .83913 L F
.657 .49 .646 r
.40847 .84043 m .4111 .84268 L .41024 .84016 L F
.40847 .84043 m .40863 .84306 L .4111 .84268 L F
.514 .255 .46 r
.50442 .86771 m .50628 .87039 L .50442 .87068 L F
.50442 .86771 m .50627 .86727 L .50628 .87039 L F
.635 .644 .842 r
.44819 .82737 m .44471 .82515 L .44676 .82463 L F
.751 .69 .793 r
.45058 .82492 m .44819 .82737 L .44676 .82463 L F
.555 .382 .601 r
.45058 .82492 m .45008 .82727 L .44819 .82737 L F
.658 .387 .499 r
.45002 .82923 m .44819 .82737 L .45008 .82727 L F
.45002 .82923 m .44788 .82972 L .44819 .82737 L F
.61 .376 .538 r
.42152 .87311 m .42043 .87616 L .41826 .87613 L F
.597 .363 .532 r
.42278 .87488 m .42152 .87311 L .42353 .87325 L F
.42278 .87488 m .42043 .87616 L .42152 .87311 L F
.754 .664 .762 r
.50864 .82516 m .51202 .8255 L .51077 .82276 L F
.796 .742 .803 r
.51202 .8255 m .51303 .82186 L .51077 .82276 L F
.722 .692 .821 r
.44167 .82442 m .44257 .82558 L .43954 .82522 L F
.647 .67 .857 r
.44471 .82515 m .44257 .82558 L .44167 .82442 L F
.732 .643 .76 r
.45704 .85786 m .45453 .85835 L .4567 .85563 L F
.68 .437 .547 r
.45458 .86046 m .45704 .85786 L .45659 .86028 L F
.45458 .86046 m .45453 .85835 L .45704 .85786 L F
.502 .439 .718 r
.45868 .85542 m .45704 .85786 L .4567 .85563 L F
.45868 .85542 m .4591 .8578 L .45704 .85786 L F
.73 .564 .666 r
.4591 .8578 m .45659 .86028 L .45704 .85786 L F
.95 .601 .297 r
.49239 .86065 m .49398 .86333 L .49291 .863 L F
.767 .282 0 r
.49398 .86333 m .49461 .86481 L .49291 .863 L F
.763 .259 .004 r
.49398 .86333 m .4972 .86563 L .49552 .86553 L F
.191 .717 .855 r
.49432 .86472 m .49461 .86481 L .49627 .86464 L F
.76 .246 0 r
.49291 .863 m .49388 .86404 L .49415 .86473 L F
.49388 .86404 m .49461 .86481 L .49415 .86473 L F
.661 .449 .587 r
.49415 .86473 m .4959 .86671 L .49292 .8674 L F
.424 .004 .135 r
.4938 .86679 m .49465 .86605 L .49415 .86473 L F
.191 .717 .855 r
.49415 .86473 m .49461 .86481 L .49432 .86472 L F
.767 .282 0 r
.49398 .86333 m .49513 .86498 L .49461 .86481 L F
.49513 .86498 m .49552 .86553 L .49461 .86481 L F
.472 .841 .99 r
.49552 .86553 m .49627 .86464 L .49461 .86481 L F
.378 .824 .943 r
.49552 .86553 m .4972 .86563 L .49753 .86521 L F
.49552 .86553 m .4972 .86563 L .49753 .86521 L F
.472 .841 .99 r
.49552 .86553 m .49753 .86521 L .49627 .86464 L F
.661 .449 .587 r
.49415 .86473 m .49627 .86464 L .4959 .86671 L F
.424 .004 .135 r
.49465 .86605 m .49675 .8642 L .49415 .86473 L F
.681 .549 .698 r
.43196 .85282 m .42954 .85536 L .42971 .85319 L F
.409 .228 .522 r
.5089 .86509 m .50724 .86635 L .50912 .86334 L F
0 0 0 r
.50627 .86727 m .50724 .86635 L .5089 .86509 L F
.645 .775 .943 r
.42065 .82406 m .41735 .82334 L .41937 .82299 L F
.591 .797 .978 r
.42282 .82363 m .42065 .82406 L .41937 .82299 L F
.633 .469 .642 r
.4337 .84794 m .43158 .8504 L .43153 .84818 L F
.833 .65 .655 r
.50003 .86821 m .49683 .87076 L .49914 .86764 L F
.50003 .86821 m .49984 .87102 L .49683 .87076 L F
.739 .492 .555 r
.50003 .86821 m .50228 .8709 L .49984 .87102 L F
.711 .625 .76 r
.42743 .85572 m .42906 .85926 L .42528 .85812 L F
.684 .613 .77 r
.42943 .85813 m .42906 .85926 L .42743 .85572 L F
.978 .689 .399 r
.49615 .82766 m .49532 .82923 L .49498 .82708 L F
.49615 .82766 m .49692 .83037 L .49532 .82923 L F
.739 .588 .686 r
.49713 .83013 m .49692 .83037 L .49615 .82766 L F
.798 .395 .288 r
.49532 .82923 m .49615 .82766 L .49498 .82708 L F
.49532 .82923 m .4963 .82804 L .49615 .82766 L F
.579 .322 .491 r
.41626 .87803 m .41622 .87629 L .41805 .8781 L F
.574 .322 .497 r
.41622 .87629 m .41826 .87613 L .41805 .8781 L F
.669 .507 .656 r
.40148 .85836 m .40419 .85826 L .40375 .85577 L F
.636 .52 .705 r
.40375 .85577 m .40547 .85293 L .40328 .85359 L F
.40375 .85577 m .40644 .85587 L .40547 .85293 L F
.684 .517 .654 r
.40375 .85577 m .40646 .8581 L .40644 .85587 L F
.40375 .85577 m .40419 .85826 L .40646 .8581 L F
.633 .231 .264 r
.49713 .83013 m .49932 .83022 L .49792 .83186 L F
.622 .871 .524 r
.49889 .83064 m .49932 .83022 L .50142 .82764 L F
.668 .886 .525 r
.49792 .83186 m .49932 .83022 L .49889 .83064 L F
.729 .572 .678 r
.45254 .85855 m .4527 .86098 L .44937 .86112 L F
.697 .6 .744 r
.45395 .85516 m .45453 .85835 L .45254 .85855 L F
.691 .543 .68 r
.45254 .85855 m .45453 .85835 L .4527 .86098 L F
.52 .274 .483 r
.51354 .85855 m .51529 .86017 L .51316 .86066 L F
.51354 .85855 m .51558 .85817 L .51529 .86017 L F
0 0 0 r
.39452 .83995 m .3914 .84115 L .39241 .84043 L F
.65 .395 .52 r
.42893 .87039 m .42752 .87351 L .42544 .87314 L F
.625 .367 .507 r
.43024 .87202 m .42893 .87039 L .43068 .87063 L F
.43024 .87202 m .42752 .87351 L .42893 .87039 L F
.576 .353 .54 r
.49713 .83013 m .49693 .83227 L .49692 .83037 L F
.633 .231 .264 r
.49713 .83013 m .49792 .83186 L .49693 .83227 L F
.644 .137 .029 r
.49805 .816 m .49834 .81496 L .49634 .81465 L F
.527 .699 .948 r
.49902 .81226 m .49834 .81496 L .49805 .816 L F
.49902 .81226 m .50095 .81484 L .49834 .81496 L F
.512 .234 .429 r
.43593 .85867 m .4357 .8605 L .43372 .86071 L F
.692 .899 .54 r
.49746 .86963 m .49914 .86764 L .49683 .87076 L F
.985 .89 .643 r
.49954 .8676 m .49746 .86963 L .49964 .86965 L F
.49948 .86623 m .49896 .8671 L .49954 .8676 L F
0 .211 .736 r
.4972 .86563 m .49914 .86764 L .49856 .86677 L F
.985 .89 .643 r
.49896 .8671 m .49746 .86963 L .49954 .8676 L F
0 .211 .736 r
.49721 .86561 m .49856 .86677 L .49753 .86521 L F
.4972 .86563 m .49856 .86677 L .49721 .86561 L F
.922 .974 .76 r
.4393 .8598 m .43781 .86043 L .4393 .85827 L F
.669 .65 .823 r
.44093 .86034 m .44007 .86351 L .4393 .8598 L F
.76 .501 .542 r
.49692 .83037 m .49318 .83205 L .49532 .82923 L F
.49692 .83037 m .49693 .83227 L .49318 .83205 L F
.495 .293 .534 r
.4527 .86098 m .45453 .85835 L .45458 .86046 L F
.4527 .86098 m .45453 .85835 L .45458 .86046 L F
.708 .607 .742 r
.4567 .85563 m .45453 .85835 L .45395 .85516 L F
.673 .71 .875 r
.39989 .84002 m .40307 .84046 L .40221 .83953 L F
.668 .708 .878 r
.40221 .83953 m .40307 .84046 L .40518 .84004 L F
.709 .606 .739 r
.40319 .8425 m .40518 .84004 L .40307 .84046 L F
.47 .885 .771 r
.50817 .85849 m .50473 .86009 L .50695 .86019 L F
.273 0 .05 r
.51006 .85794 m .50817 .85849 L .50695 .86019 L F
.634 .495 .675 r
.43767 .84271 m .43584 .84538 L .43566 .8431 L F
.43767 .84271 m .43911 .84583 L .43584 .84538 L F
.663 .51 .667 r
.43911 .84583 m .43586 .8477 L .43584 .84538 L F
.651 .555 .733 r
.43655 .83755 m .43467 .84011 L .43443 .83799 L F
.43655 .83755 m .43784 .84084 L .43467 .84011 L F
.687 .564 .71 r
.43767 .84271 m .43467 .84011 L .43784 .84084 L F
.43767 .84271 m .43566 .8431 L .43467 .84011 L F
.689 .538 .677 r
.44007 .86351 m .44027 .8661 L .43809 .86586 L F
.669 .65 .823 r
.44093 .86034 m .44225 .86313 L .44007 .86351 L F
.599 .443 .641 r
.44225 .86313 m .44027 .8661 L .44007 .86351 L F
.604 .422 .609 r
.39731 .86338 m .39926 .86307 L .39954 .86082 L F
.621 .468 .653 r
.39926 .86307 m .4013 .86013 L .39954 .86082 L F
.691 .681 .836 r
.50783 .82557 m .50791 .82505 L .50547 .82465 L F
.727 .602 .717 r
.50547 .82465 m .50864 .82516 L .5075 .82523 L F
.77 .755 .839 r
.50631 .82184 m .5075 .82523 L .508 .82438 L F
.50838 .82181 m .508 .82438 L .50955 .82179 L F
.50631 .82184 m .508 .82438 L .50838 .82181 L F
.691 .681 .836 r
.50674 .82613 m .50783 .82557 L .50547 .82465 L F
.50783 .82557 m .50864 .82516 L .50791 .82505 L F
.607 .349 .499 r
.40181 .88384 m .40165 .88602 L .4015 .88593 L F
.40181 .88384 m .40355 .88591 L .40165 .88602 L F
.40181 .88384 m .40388 .88395 L .40355 .88591 L F
.709 .606 .739 r
.40319 .8425 m .40624 .84299 L .40518 .84004 L F
.646 .376 .495 r
.40624 .84299 m .40818 .84503 L .40863 .84306 L F
.444 .361 .669 r
.40664 .84537 m .40818 .84503 L .40624 .84299 L F
.719 .533 .638 r
.40381 .84974 m .40738 .8482 L .40506 .84921 L F
.40381 .84974 m .40743 .8504 L .40738 .8482 L F
.653 .572 .751 r
.40664 .84537 m .40738 .8482 L .40955 .84772 L F
.612 .448 .636 r
.40738 .8482 m .40952 .85005 L .40955 .84772 L F
.40738 .8482 m .40743 .8504 L .40952 .85005 L F
.682 .739 .894 r
.5029 .86084 m .50121 .86181 L .49982 .86033 L F
.614 .351 .496 r
.41398 .8777 m .4129 .88095 L .41083 .88087 L F
.598 .335 .489 r
.41736 .87959 m .41398 .8777 L .41626 .87803 L F
.41736 .87959 m .4129 .88095 L .41398 .8777 L F
.602 .319 .461 r
.44738 .86083 m .44745 .86286 L .44446 .86282 L F
.632 .343 .461 r
.44738 .86083 m .44933 .86283 L .44745 .86286 L F
.651 .34 .433 r
.44738 .86083 m .44937 .86112 L .44933 .86283 L F
.695 .515 .64 r
.4013 .86013 m .40419 .85826 L .40148 .85836 L F
.571 .293 .455 r
.43501 .86872 m .43269 .87056 L .43291 .86873 L F
.67 .133 0 r
.47094 .82248 m .46996 .82261 L .46823 .82166 L F
.46823 .82166 m .46996 .82261 L .47094 .82248 L F
.373 .84 .822 r
.47094 .82248 m .46996 .82261 L .47206 .82189 L F
.507 .229 .428 r
.47206 .82189 m .46996 .82261 L .47094 .82248 L F
.719 .655 .785 r
.4963 .82804 m .50142 .82764 L .50032 .82497 L F
.622 .871 .524 r
.49889 .83064 m .50142 .82764 L .4963 .82804 L F
.639 .462 .626 r
.39725 .86567 m .39926 .86307 L .39731 .86338 L F
.762 .941 .941 r
.50765 .8183 m .50397 .81947 L .50613 .81919 L F
.737 .892 .95 r
.50626 .81776 m .50765 .8183 L .50613 .81919 L F
.50626 .81776 m .50961 .81734 L .50765 .8183 L F
.633 .469 .642 r
.4337 .84794 m .43371 .85031 L .43158 .8504 L F
.672 .527 .679 r
.43586 .8477 m .43371 .85031 L .4337 .84794 L F
.55 .424 .661 r
.51115 .86291 m .50912 .86334 L .51084 .86074 L F
.519 .323 .554 r
.5089 .86509 m .50912 .86334 L .51115 .86291 L F
.662 .525 .686 r
.43371 .85031 m .43196 .85282 L .43158 .8504 L F
.663 .518 .677 r
.44558 .83011 m .44372 .83199 L .44322 .82997 L F
.624 .407 .567 r
.43809 .86586 m .43833 .86769 L .43501 .86872 L F
.619 .403 .567 r
.43809 .86586 m .44001 .86789 L .43833 .86769 L F
.682 .4 .489 r
.43809 .86586 m .44027 .8661 L .44001 .86789 L F
.659 .31 .369 r
.44937 .86112 m .4527 .86098 L .45164 .86263 L F
.333 0 .168 r
.45164 .86263 m .4527 .86098 L .45458 .86046 L F
.538 .377 .61 r
.43839 .83261 m .43838 .83515 L .43636 .83531 L F
.544 .408 .646 r
.43838 .83515 m .43655 .83755 L .43636 .83531 L F
.634 .152 0 r
.49222 .85901 m .49101 .85762 L .49333 .85627 L F
0 0 0 r
.4953 .85732 m .49661 .85645 L .49222 .85901 L F
.4953 .85732 m .49222 .85901 L .49333 .85627 L F
.684 .613 .77 r
.42943 .85813 m .42743 .85572 L .42954 .85536 L F
.676 .568 .725 r
.43285 .85591 m .42943 .85813 L .42954 .85536 L F
.697 .603 .747 r
.42743 .85572 m .42528 .85812 L .42571 .85672 L F
.708 .62 .757 r
.4397 .84008 m .43767 .84271 L .43784 .84084 L F
.635 .515 .7 r
.4397 .84008 m .4413 .84415 L .43767 .84271 L F
.673 .513 .66 r
.44078 .84528 m .43767 .84271 L .4413 .84415 L F
.44078 .84528 m .43911 .84583 L .43767 .84271 L F
.617 .788 .964 r
.42785 .82373 m .42587 .82422 L .42474 .82342 L F
.724 .745 .869 r
.44899 .82364 m .45058 .82492 L .44676 .82463 L F
.348 .509 .875 r
.45064 .82355 m .45058 .82492 L .44899 .82364 L F
.45064 .82355 m .45231 .82535 L .45058 .82492 L F
.656 .59 .769 r
.45231 .82535 m .45008 .82727 L .45058 .82492 L F
.598 .764 .959 r
.43648 .82424 m .43299 .82333 L .43512 .82288 L F
.586 .753 .957 r
.43717 .82237 m .43648 .82424 L .43512 .82288 L F
.43717 .82237 m .43843 .82385 L .43648 .82424 L F
.619 .652 .861 r
.43954 .82522 m .43648 .82424 L .43843 .82385 L F
.564 .83 .995 r
.39672 .83964 m .39989 .84002 L .39856 .83953 L F
.638 .901 .984 r
.40086 .83865 m .39989 .84002 L .40221 .83953 L F
.40086 .83865 m .39856 .83953 L .39989 .84002 L F
.647 .518 .691 r
.4963 .82804 m .50032 .82497 L .49717 .82391 L F
.812 1 .832 r
.49717 .82391 m .49564 .82511 L .49587 .82392 L F
.582 .85 .995 r
.52159 .85269 m .523 .85352 L .52489 .85289 L F
.661 .843 .97 r
.43087 .82362 m .42785 .82373 L .42973 .82287 L F
.518 .784 .993 r
.43199 .82252 m .43087 .82362 L .42973 .82287 L F
.43199 .82252 m .43299 .82333 L .43087 .82362 L F
.798 .395 .288 r
.49532 .82923 m .49889 .83064 L .4963 .82804 L F
0 .195 .714 r
.44185 .85501 m .44298 .85776 L .44134 .85566 L F
.599 .443 .641 r
.44225 .86313 m .44241 .86581 L .44027 .8661 L F
.647 .422 .564 r
.44241 .86581 m .44001 .86789 L .44027 .8661 L F
.723 .696 .824 r
.44167 .82442 m .43954 .82522 L .43843 .82385 L F
.477 0 .011 r
.39398 .82431 m .39331 .82477 L .39651 .82423 L F
.76 .314 .193 r
.49902 .81693 m .49806 .81731 L .49638 .81615 L F
.634 .567 .761 r
.50098 .81577 m .50125 .81738 L .49902 .81693 L F
0 .518 .783 r
.49902 .81693 m .50009 .81702 L .49806 .81731 L F
.49902 .81693 m .50125 .81738 L .50009 .81702 L F
.703 .594 .732 r
.40178 .85215 m .40547 .85293 L .40381 .84974 L F
.71 .575 .701 r
.40178 .85215 m .40328 .85359 L .40547 .85293 L F
.705 .595 .731 r
.40381 .84974 m .40547 .85293 L .40743 .8504 L F
.609 .46 .654 r
.40743 .8504 m .40547 .85293 L .40743 .85239 L F
.719 .566 .681 r
.40547 .85293 m .40857 .85552 L .40743 .85239 L F
.40547 .85293 m .40644 .85587 L .40857 .85552 L F
.586 .735 .946 r
.45615 .85456 m .4567 .85563 L .45395 .85516 L F
.466 .777 .998 r
.45762 .85465 m .4567 .85563 L .45615 .85456 L F
.45762 .85465 m .45868 .85542 L .4567 .85563 L F
.724 .626 .749 r
.40215 .85017 m .40178 .85215 L .40381 .84974 L F
.821 .544 .519 r
.49683 .87076 m .49984 .87102 L .49981 .8731 L F
.633 .414 .567 r
.49984 .87102 m .50224 .87324 L .49981 .8731 L F
.49984 .87102 m .50228 .8709 L .50224 .87324 L F
.815 .735 .776 r
.50806 .81641 m .50961 .81734 L .50626 .81776 L F
.707 .667 .808 r
.51051 .81392 m .50961 .81734 L .50806 .81641 L F
.681 .549 .698 r
.43196 .85282 m .43285 .85591 L .42954 .85536 L F
.653 .572 .751 r
.40664 .84537 m .40955 .84772 L .40818 .84503 L F
.695 .515 .64 r
.4013 .86013 m .40422 .86056 L .40419 .85826 L F
.682 .504 .64 r
.40419 .85826 m .40422 .86056 L .40646 .8581 L F
.846 .723 .727 r
.4425 .86118 m .44225 .86313 L .44093 .86034 L F
.649 .539 .717 r
.44446 .86282 m .44225 .86313 L .4425 .86118 L F
.607 .434 .622 r
.44446 .86282 m .44241 .86581 L .44225 .86313 L F
.668 .708 .878 r
.40221 .83953 m .40518 .84004 L .40463 .83912 L F
.672 .742 .903 r
.40463 .83912 m .40518 .84004 L .4074 .8392 L F
.521 .258 .457 r
.40863 .84306 m .4102 .84467 L .4111 .84268 L F
.40863 .84306 m .40818 .84503 L .4102 .84467 L F
.327 .804 .906 r
.45033 .85538 m .45241 .855 L .45395 .85516 L F
.969 .754 .56 r
.45395 .85516 m .45139 .85196 L .45615 .85456 L F
.45395 .85516 m .45241 .855 L .45139 .85196 L F
.647 .67 .857 r
.44471 .82515 m .44167 .82442 L .44362 .82385 L F
.646 .688 .875 r
.44676 .82463 m .44471 .82515 L .44362 .82385 L F
.659 .31 .369 r
.44937 .86112 m .45164 .86263 L .44933 .86283 L F
.724 .594 .71 r
.40644 .85587 m .40646 .8581 L .40857 .85552 L F
.649 .486 .648 r
.40646 .8581 m .40875 .85802 L .40857 .85552 L F
.715 .614 .744 r
.40743 .85239 m .40857 .85552 L .41054 .85291 L F
.656 .531 .699 r
.40857 .85552 m .41094 .8554 L .41054 .85291 L F
.62 .443 .621 r
.40875 .85802 m .41094 .8554 L .40857 .85552 L F
.61 .859 .99 r
.4142 .82298 m .41229 .82374 L .41077 .82304 L F
.274 0 0 r
.39331 .82477 m .39533 .82476 L .39651 .82423 L F
0 0 0 r
.39533 .82476 m .39849 .82422 L .39651 .82423 L F
.156 .694 .826 r
.38806 .82537 m .39016 .82523 L .39145 .82533 L F
.37 .83 .913 r
.39145 .82533 m .39213 .82478 L .39331 .82477 L F
.39145 .82533 m .39016 .82523 L .39213 .82478 L F
.723 .696 .824 r
.44167 .82442 m .43843 .82385 L .44048 .82299 L F
.627 .756 .94 r
.44362 .82385 m .44167 .82442 L .44048 .82299 L F
.963 .631 .285 r
.49101 .85762 m .49239 .86065 L .49013 .85969 L F
.864 .497 .351 r
.49013 .85969 m .49239 .86065 L .49145 .86229 L F
.926 .594 .391 r
.49145 .86229 m .49239 .86065 L .49291 .863 L F
.945 .687 .515 r
.46803 .85493 m .46955 .85314 L .46903 .85498 L F
.969 .725 .512 r
.46903 .85498 m .46955 .85314 L .46828 .85372 L F
.46903 .85498 m .46955 .85314 L .46828 .85372 L F
.595 .422 .618 r
.44056 .83482 m .43839 .83261 L .44064 .83237 L F
.44056 .83482 m .43838 .83515 L .43839 .83261 L F
.679 .66 .824 r
.40818 .84503 m .40955 .84772 L .41103 .84548 L F
.629 .592 .793 r
.41103 .84548 m .40955 .84772 L .41161 .84736 L F
.624 .448 .625 r
.40955 .84772 m .41173 .84968 L .41161 .84736 L F
.40955 .84772 m .40952 .85005 L .41173 .84968 L F
.662 .525 .686 r
.43371 .85031 m .435 .85333 L .43196 .85282 L F
.692 .556 .695 r
.4345 .85491 m .43196 .85282 L .435 .85333 L F
.4345 .85491 m .43285 .85591 L .43196 .85282 L F
.667 .482 .626 r
.40422 .86056 m .40649 .86048 L .40646 .8581 L F
.619 .426 .599 r
.40649 .86048 m .40875 .85802 L .40646 .8581 L F
.209 .73 .856 r
.40878 .82342 m .40712 .82362 L .40571 .82351 L F
.693 .577 .72 r
.4397 .84008 m .43784 .84084 L .43655 .83755 L F
.555 .679 .921 r
.49982 .85812 m .49661 .85645 L .49828 .85614 L F
.204 .49 .899 r
.50057 .85724 m .49982 .85812 L .49828 .85614 L F
0 0 0 r
.39849 .82422 m .40049 .82404 L .40167 .82384 L F
.15 .689 .713 r
.40167 .82384 m .40244 .82366 L .40375 .82337 L F
.40167 .82384 m .40049 .82404 L .40244 .82366 L F
0 0 0 r
.50627 .86727 m .5089 .86509 L .50853 .86806 L F
.462 .216 .453 r
.50628 .87039 m .50627 .86727 L .50853 .86806 L F
.83 .802 .825 r
.50864 .82516 m .50955 .82179 L .5075 .82523 L F
.50864 .82516 m .51077 .82276 L .50955 .82179 L F
.715 .614 .744 r
.40743 .85239 m .40952 .85005 L .40743 .8504 L F
.671 .709 .877 r
.51303 .82186 m .51608 .82253 L .51503 .822 L F
.857 .903 .865 r
.51608 .82253 m .51657 .82034 L .51503 .822 L F
.51608 .82253 m .51777 .8208 L .51657 .82034 L F
0 0 0 r
.46062 .82514 m .45975 .82526 L .45738 .82556 L F
.714 .986 .829 r
.46125 .82396 m .46062 .82514 L .46199 .82375 L F
.46125 .82396 m .45975 .82526 L .46062 .82514 L F
.596 .313 .458 r
.41826 .87613 m .42009 .87796 L .41805 .8781 L F
.41826 .87613 m .42043 .87616 L .42009 .87796 L F
.817 .675 .706 r
.49693 .83227 m .49763 .83558 L .49462 .83394 L F
.862 .515 .393 r
.49462 .83394 m .49763 .83558 L .49605 .83675 L F
.548 .5 .754 r
.49931 .83482 m .49763 .83558 L .49693 .83227 L F
0 0 0 r
.49605 .83675 m .49763 .83558 L .49931 .83482 L F
0 .461 .753 r
.45958 .82146 m .4611 .82184 L .46258 .82232 L F
.428 .808 .991 r
.46258 .82232 m .4611 .82184 L .46466 .82205 L F
.493 .185 .372 r
.46466 .82205 m .46199 .82375 L .46258 .82232 L F
.591 .797 .978 r
.42282 .82363 m .41937 .82299 L .42138 .8227 L F
.506 .784 .995 r
.42345 .8223 m .42282 .82363 L .42138 .8227 L F
.42345 .8223 m .42474 .82342 L .42282 .82363 L F
.866 .609 .548 r
.49634 .81465 m .49443 .8145 L .49476 .81429 L F
.49506 .81455 m .49638 .81615 L .49443 .8145 L F
.49634 .81465 m .49637 .81583 L .49506 .81455 L F
.49637 .81583 m .49638 .81615 L .49506 .81455 L F
.644 .137 .029 r
.49805 .816 m .49634 .81465 L .49476 .81429 L F
.341 .54 .903 r
.49593 .81364 m .49805 .816 L .49483 .81433 L F
.49478 .81428 m .49483 .81433 L .49476 .81429 L F
.49593 .81364 m .49483 .81433 L .49478 .81428 L F
.672 .527 .679 r
.43586 .8477 m .43676 .85055 L .43371 .85031 L F
.672 .53 .682 r
.43676 .85055 m .435 .85333 L .43371 .85031 L F
.663 .51 .667 r
.43911 .84583 m .43885 .84788 L .43586 .8477 L F
.662 .521 .681 r
.43885 .84788 m .43676 .85055 L .43586 .8477 L F
0 0 0 r
.39452 .83995 m .39365 .84035 L .3914 .84115 L F
.39672 .83964 m .3953 .83984 L .39452 .83995 L F
.3953 .83984 m .39365 .84035 L .39452 .83995 L F
.639 .538 .723 r
.43867 .83706 m .43655 .83755 L .43838 .83515 L F
.693 .577 .72 r
.4397 .84008 m .43655 .83755 L .43867 .83706 L F
.646 .686 .874 r
.50547 .82465 m .5075 .82523 L .50631 .82184 L F
.341 .32 .689 r
.41073 .88263 m .40879 .88095 L .41083 .88087 L F
.41073 .88263 m .41033 .88346 L .40879 .88095 L F
.639 .462 .626 r
.39725 .86567 m .39953 .86566 L .39926 .86307 L F
.621 .468 .653 r
.39926 .86307 m .40243 .86326 L .4013 .86013 L F
.611 .441 .627 r
.39926 .86307 m .40162 .86525 L .40243 .86326 L F
.39926 .86307 m .39953 .86566 L .40162 .86525 L F
.573 .331 .51 r
.43269 .87056 m .43024 .87202 L .43068 .87063 L F
.731 .657 .776 r
.41249 .85083 m .41592 .85294 L .41456 .85012 L F
.41249 .85083 m .41406 .85322 L .41592 .85294 L F
.714 .539 .65 r
.41406 .85322 m .41359 .85537 L .41592 .85294 L F
.657 .452 .595 r
.41359 .85537 m .41586 .85529 L .41592 .85294 L F
.581 .543 .777 r
.41592 .85294 m .41673 .84971 L .41456 .85012 L F
.41592 .85294 m .41801 .85266 L .41673 .84971 L F
.56 .378 .592 r
.41586 .85529 m .41801 .85266 L .41592 .85294 L F
.638 .56 .75 r
.52006 .8195 m .51777 .8208 L .51693 .81694 L F
.716 .911 .963 r
.51657 .82034 m .51777 .8208 L .52006 .8195 L F
.674 .596 .76 r
.44173 .83786 m .4397 .84008 L .43867 .83706 L F
.686 .615 .771 r
.44215 .8398 m .4397 .84008 L .44173 .83786 L F
.648 .522 .696 r
.44294 .84291 m .4397 .84008 L .44215 .8398 L F
.44294 .84291 m .4413 .84415 L .4397 .84008 L F
.805 .671 .716 r
.5003 .83983 m .50151 .84276 L .49856 .84186 L F
.827 .55 .519 r
.49856 .84186 m .50151 .84276 L .5017 .84495 L F
.755 .649 .745 r
.50367 .84 m .50151 .84276 L .5003 .83983 L F
.773 .567 .621 r
.50151 .84276 m .50443 .84558 L .5017 .84495 L F
.602 .352 .512 r
.42353 .87325 m .42575 .87556 L .42278 .87488 L F
.42353 .87325 m .42544 .87314 L .42575 .87556 L F
.34 .776 .967 r
.40463 .83912 m .40086 .83865 L .40221 .83953 L F
.723 .8 .912 r
.51077 .82276 m .51303 .82186 L .50955 .82179 L F
.255 .742 .922 r
.50238 .83968 m .50367 .84 L .5003 .83983 L F
.50238 .83968 m .50367 .84 L .5003 .83983 L F
.243 .735 .918 r
.50592 .83989 m .50367 .84 L .50238 .83968 L F
.521 .537 .813 r
.50705 .84234 m .50367 .84 L .50592 .83989 L F
.576 .332 .51 r
.40388 .88395 m .4057 .88592 L .40355 .88591 L F
.768 .657 .741 r
.44086 .84737 m .44019 .8504 L .43871 .8501 L F
.544 .512 .77 r
.44278 .85305 m .43871 .8501 L .44019 .8504 L F
.59 .442 .648 r
.44426 .84867 m .44019 .8504 L .44086 .84737 L F
.44426 .84867 m .44396 .85041 L .44019 .8504 L F
.682 .425 .527 r
.44395 .85241 m .44019 .8504 L .44396 .85041 L F
.44395 .85241 m .44278 .85305 L .44019 .8504 L F
.796 .423 .349 r
.5017 .84495 m .50443 .84558 L .50272 .84636 L F
.189 0 0 r
.50272 .84636 m .50443 .84558 L .50689 .84538 L F
.443 .267 .547 r
.50443 .84558 m .50705 .84234 L .50689 .84538 L F
.571 .293 .455 r
.43501 .86872 m .43471 .8705 L .43269 .87056 L F
.7 .493 .605 r
.43833 .86769 m .43471 .8705 L .43501 .86872 L F
.616 .487 .682 r
.51316 .86066 m .51115 .86291 L .51084 .86074 L F
.715 .614 .744 r
.40743 .85239 m .41054 .85291 L .40952 .85005 L F
.647 .577 .763 r
.40952 .85005 m .41054 .85291 L .41249 .85083 L F
.687 .643 .8 r
.41054 .85291 m .41406 .85322 L .41249 .85083 L F
.664 .489 .638 r
.41094 .8554 m .41406 .85322 L .41054 .85291 L F
.688 .503 .632 r
.4013 .86013 m .4042 .8628 L .40422 .86056 L F
.4013 .86013 m .40243 .86326 L .4042 .8628 L F
.677 .603 .765 r
.4111 .84268 m .41239 .83973 L .41024 .84016 L F
.4111 .84268 m .41347 .84262 L .41239 .83973 L F
.747 .51 .573 r
.4102 .84467 m .41347 .84262 L .4111 .84268 L F
.656 .59 .769 r
.45231 .82535 m .453 .82747 L .45008 .82727 L F
.703 .557 .685 r
.453 .82747 m .45002 .82923 L .45008 .82727 L F
.578 .519 .753 r
.50226 .81447 m .50125 .81738 L .50098 .81577 L F
.50226 .81447 m .50329 .81782 L .50125 .81738 L F
.303 .647 .969 r
.50125 .81738 m .50188 .8165 L .50009 .81702 L F
.50125 .81738 m .50329 .81782 L .50188 .8165 L F
0 .536 .82 r
.50329 .81782 m .50392 .81799 L .50125 .81738 L F
.50329 .81782 m .50392 .81799 L .50125 .81738 L F
.664 .489 .638 r
.41094 .8554 m .41359 .85537 L .41406 .85322 L F
.569 .398 .611 r
.51761 .85538 m .51772 .8579 L .51558 .85817 L F
.542 .302 .502 r
.51558 .85817 m .51738 .85994 L .51529 .86017 L F
.51558 .85817 m .51772 .8579 L .51738 .85994 L F
.682 .739 .894 r
.5029 .86084 m .49982 .86033 L .50153 .86213 L F
0 0 0 r
.50473 .86009 m .5029 .86084 L .50153 .86213 L F
.519 .323 .554 r
.5089 .86509 m .51115 .86291 L .51091 .86362 L F
.426 .184 .442 r
.50853 .86806 m .5089 .86509 L .51091 .86362 L F
.551 .595 .851 r
.50225 .82218 m .50547 .82465 L .5042 .82215 L F
.646 .686 .874 r
.50547 .82465 m .50631 .82184 L .5042 .82215 L F
.583 .804 .984 r
.41735 .82334 m .4142 .82298 L .4162 .82262 L F
.538 .808 .996 r
.41937 .82299 m .41735 .82334 L .4162 .82262 L F
.543 .341 .557 r
.50224 .87324 m .50228 .8709 L .50442 .87068 L F
.62 .443 .621 r
.40875 .85802 m .41169 .8579 L .41094 .8554 L F
.668 .471 .608 r
.41094 .8554 m .41351 .85765 L .41359 .85537 L F
.41094 .8554 m .41169 .8579 L .41351 .85765 L F
.607 .434 .622 r
.44446 .86282 m .44519 .86549 L .44241 .86581 L F
.63 .447 .617 r
.44722 .86518 m .44446 .86282 L .44745 .86286 L F
.44722 .86518 m .44519 .86549 L .44446 .86282 L F
.677 .523 .669 r
.44078 .84528 m .43885 .84788 L .43911 .84583 L F
.742 .622 .726 r
.43676 .85261 m .435 .85333 L .43676 .85055 L F
.691 .573 .717 r
.43871 .8501 m .43676 .85261 L .43676 .85055 L F
.43871 .8501 m .44149 .85498 L .43676 .85261 L F
.517 .358 .605 r
.51965 .85732 m .51761 .85538 L .51969 .85506 L F
.51965 .85732 m .51772 .8579 L .51761 .85538 L F
.474 .788 .999 r
.49451 .8247 m .49564 .82511 L .49404 .82495 L F
.82 .627 .642 r
.49564 .82511 m .49178 .82682 L .49199 .82473 L F
.766 .637 .718 r
.49249 .82398 m .49414 .82418 L .4927 .82139 L F
.549 .809 .994 r
.49587 .82392 m .49579 .82437 L .49249 .82398 L F
.49579 .82437 m .49564 .82511 L .49249 .82398 L F
.766 .637 .718 r
.49249 .82398 m .4945 .82487 L .49414 .82418 L F
0 0 0 r
.4945 .82487 m .49261 .82632 L .49556 .82415 L F
.49548 .82419 m .49556 .82415 L .49587 .82392 L F
.4945 .82487 m .49556 .82415 L .49548 .82419 L F
.474 .788 .999 r
.49249 .82398 m .49451 .8247 L .49199 .82473 L F
.49451 .8247 m .49404 .82495 L .49199 .82473 L F
.82 .627 .642 r
.49564 .82511 m .49261 .82632 L .49178 .82682 L F
.49564 .82511 m .49498 .82708 L .49261 .82632 L F
.49261 .82632 m .49564 .82511 L .49587 .82392 L F
.49261 .82632 m .49498 .82708 L .49564 .82511 L F
.686 .478 .599 r
.44264 .83429 m .44064 .83237 L .44372 .83199 L F
.663 .518 .677 r
.44558 .83011 m .4457 .83232 L .44372 .83199 L F
.702 .502 .615 r
.4457 .83232 m .44264 .83429 L .44372 .83199 L F
.626 .527 .721 r
.44379 .83715 m .44215 .8398 L .44173 .83786 L F
.44379 .83715 m .44494 .84041 L .44215 .8398 L F
.678 .521 .666 r
.44493 .84232 m .44215 .8398 L .44494 .84041 L F
.44493 .84232 m .44294 .84291 L .44215 .8398 L F
.617 .788 .964 r
.42785 .82373 m .42474 .82342 L .42683 .82266 L F
.666 .826 .96 r
.42973 .82287 m .42785 .82373 L .42683 .82266 L F
.644 .45 .606 r
.39718 .86797 m .39953 .86566 L .39725 .86567 L F
.273 0 .05 r
.51006 .85794 m .50695 .86019 L .50922 .86016 L F
0 0 0 r
.51151 .85743 m .51243 .85607 L .51006 .85794 L F
.059 0 .115 r
.51151 .85743 m .51006 .85794 L .50922 .86016 L F
.63 .424 .585 r
.4042 .8628 m .40649 .86048 L .40422 .86056 L F
.731 .6 .71 r
.44086 .84737 m .43885 .84788 L .44078 .84528 L F
.768 .657 .741 r
.44086 .84737 m .43871 .8501 L .43885 .84788 L F
.628 .495 .681 r
.44288 .84488 m .44086 .84737 L .44078 .84528 L F
.44288 .84488 m .44426 .84867 L .44086 .84737 L F
.619 .426 .599 r
.40649 .86048 m .40862 .86045 L .40875 .85802 L F
.621 .428 .6 r
.40875 .85802 m .41134 .86008 L .41169 .8579 L F
.40875 .85802 m .40862 .86045 L .41134 .86008 L F
.523 .392 .644 r
.50225 .82218 m .50397 .81947 L .50227 .82059 L F
.667 .56 .725 r
.44288 .84488 m .44078 .84528 L .4413 .84415 L F
.759 .747 .841 r
.50955 .82179 m .51303 .82186 L .51198 .81974 L F
.446 .581 .895 r
.51198 .81974 m .51303 .82186 L .51503 .822 L F
.523 .392 .644 r
.50225 .82218 m .5042 .82215 L .50397 .81947 L F
.747 .51 .573 r
.4102 .84467 m .41341 .84504 L .41347 .84262 L F
.593 .485 .701 r
.41347 .84262 m .41529 .84002 L .41239 .83973 L F
.41347 .84262 m .41551 .84235 L .41529 .84002 L F
.654 .433 .571 r
.41347 .84262 m .41545 .84458 L .41551 .84235 L F
.41347 .84262 m .41341 .84504 L .41545 .84458 L F
.583 .417 .622 r
.44788 .82972 m .4457 .83232 L .44558 .83011 L F
.967 .833 .657 r
.49001 .85772 m .49101 .85762 L .49013 .85969 L F
.569 .937 .901 r
.49333 .85627 m .49101 .85762 L .49001 .85772 L F
.769 .575 .636 r
.49318 .83205 m .49693 .83227 L .49462 .83394 L F
.548 .5 .754 r
.49931 .83482 m .49693 .83227 L .49792 .83186 L F
.647 .422 .564 r
.44241 .86581 m .44215 .86814 L .44001 .86789 L F
.594 .378 .557 r
.44519 .86549 m .44215 .86814 L .44241 .86581 L F
.701 .576 .712 r
.43871 .8501 m .43676 .85055 L .43885 .84788 L F
.686 .478 .599 r
.44264 .83429 m .44056 .83482 L .44064 .83237 L F
.7 .493 .605 r
.43833 .86769 m .44018 .87053 L .43471 .8705 L F
0 0 .478 r
.43983 .86993 m .43833 .86769 L .44001 .86789 L F
.43983 .86993 m .44018 .87053 L .43833 .86769 L F
.544 .512 .77 r
.44278 .85305 m .44149 .85498 L .43871 .8501 L F
0 0 .048 r
.44185 .85501 m .44149 .85498 L .44278 .85305 L F
.815 .769 .809 r
.45745 .82282 m .45399 .82424 L .45617 .82211 L F
.45745 .82282 m .45527 .82483 L .45399 .82424 L F
.782 .849 .901 r
.45958 .82146 m .45745 .82282 L .45617 .82211 L F
.646 .688 .875 r
.44676 .82463 m .44362 .82385 L .4456 .82337 L F
.717 .711 .844 r
.44899 .82364 m .44676 .82463 L .4456 .82337 L F
.548 .462 .71 r
.50226 .81447 m .50098 .81577 L .50095 .81484 L F
.64 .775 .945 r
.44048 .82299 m .43843 .82385 L .43717 .82237 L F
.166 0 0 r
.51426 .85527 m .51243 .85607 L .51151 .85743 L F
.581 .608 .844 r
.50101 .81108 m .50095 .81484 L .49902 .81226 L F
.50101 .81108 m .50226 .81447 L .50095 .81484 L F
.672 .742 .903 r
.40463 .83912 m .4074 .8392 L .40602 .83794 L F
.574 .648 .885 r
.4074 .8392 m .40789 .83671 L .40602 .83794 L F
.4074 .8392 m .4091 .83913 L .40789 .83671 L F
.667 .56 .725 r
.44288 .84488 m .4413 .84415 L .44294 .84291 L F
.705 .719 .86 r
.51562 .81477 m .51472 .81722 L .51352 .8147 L F
.51562 .81477 m .51693 .81694 L .51472 .81722 L F
.703 .557 .686 r
.51472 .81722 m .51693 .81694 L .51481 .8195 L F
.591 .364 .54 r
.41805 .8781 m .41736 .87959 L .41626 .87803 L F
.609 .517 .725 r
.39819 .87072 m .4004 .87058 L .39815 .87054 L F
.565 .287 .453 r
.39979 .87229 m .39819 .87072 L .39814 .87091 L F
.39979 .87229 m .4004 .87058 L .39819 .87072 L F
.333 0 .168 r
.45164 .86263 m .45458 .86046 L .45442 .8625 L F
.65 .37 .482 r
.45458 .86046 m .45656 .86249 L .45442 .8625 L F
.583 .373 .562 r
.45659 .86028 m .45656 .86249 L .45458 .86046 L F
.616 .487 .682 r
.51316 .86066 m .51338 .86295 L .51115 .86291 L F
.595 .329 .483 r
.51115 .86291 m .51267 .86397 L .51091 .86362 L F
.51115 .86291 m .51338 .86295 L .51267 .86397 L F
.609 .516 .723 r
.39815 .87054 m .39958 .86707 L .39718 .86797 L F
.39815 .87054 m .4004 .87058 L .39958 .86707 L F
.798 .751 .81 r
.51888 .81435 m .51693 .81694 L .51562 .81477 L F
.641 .518 .698 r
.51888 .81435 m .51887 .81678 L .51693 .81694 L F
.638 .56 .75 r
.52006 .8195 m .51693 .81694 L .51887 .81678 L F
.647 .577 .763 r
.40952 .85005 m .41249 .85083 L .41173 .84968 L F
.568 .352 .546 r
.4015 .88593 m .40165 .88602 L .40149 .88604 L F
.674 .691 .858 r
.4091 .83913 m .41024 .84016 L .41239 .83973 L F
.618 .541 .745 r
.41161 .84736 m .41341 .84504 L .41103 .84548 L F
.41161 .84736 m .4142 .84792 L .41341 .84504 L F
.682 .555 .704 r
.41173 .84968 m .4142 .84792 L .41161 .84736 L F
.67 .602 .771 r
.44056 .83482 m .43867 .83706 L .43838 .83515 L F
.44056 .83482 m .44173 .83786 L .43867 .83706 L F
.644 .329 .424 r
.42544 .87314 m .42743 .87512 L .42575 .87556 L F
.42544 .87314 m .42752 .87351 L .42743 .87512 L F
.873 .706 .671 r
.45527 .82483 m .45523 .82716 L .45399 .82424 L F
.683 .547 .694 r
.45738 .82556 m .45523 .82716 L .45527 .82483 L F
.703 .557 .685 r
.453 .82747 m .45296 .82961 L .45002 .82923 L F
.7 .615 .758 r
.45523 .82716 m .453 .82747 L .45231 .82535 L F
.512 .292 .516 r
.45523 .82716 m .45296 .82961 L .453 .82747 L F
.63 .424 .585 r
.4042 .8628 m .40643 .86279 L .40649 .86048 L F
.561 .336 .531 r
.40643 .86279 m .40862 .86045 L .40649 .86048 L F
.577 .796 .982 r
.43398 .82196 m .43299 .82333 L .43199 .82252 L F
.43398 .82196 m .43512 .82288 L .43299 .82333 L F
.579 .336 .513 r
.40165 .88602 m .40115 .88824 L .40149 .88604 L F
.676 .301 0 r
.49058 .82187 m .49199 .82473 L .49168 .8242 L F
.789 .535 .554 r
.49199 .82473 m .4885 .82623 L .49168 .8242 L F
.49199 .82473 m .49178 .82682 L .4885 .82623 L F
.799 .584 .61 r
.49168 .8242 m .49199 .82473 L .49058 .82187 L F
.49168 .8242 m .49249 .82398 L .49199 .82473 L F
.606 .425 .611 r
.41351 .85765 m .41567 .85751 L .41359 .85537 L F
.651 .424 .562 r
.41359 .85537 m .41567 .85751 L .41586 .85529 L F
.642 .398 .533 r
.42278 .87488 m .42009 .87796 L .42043 .87616 L F
.702 .502 .615 r
.4457 .83232 m .4458 .8347 L .44264 .83429 L F
.583 .417 .622 r
.44788 .82972 m .44788 .83213 L .4457 .83232 L F
.581 .409 .613 r
.44788 .83213 m .4458 .8347 L .4457 .83232 L F
.148 0 0 r
.49828 .85614 m .49661 .85645 L .4953 .85732 L F
.34 .776 .967 r
.40463 .83912 m .40293 .8384 L .40086 .83865 L F
.624 .27 .35 r
.40789 .83671 m .40678 .8373 L .40602 .83794 L F
.40678 .8373 m .40469 .83841 L .40602 .83794 L F
.226 0 0 r
.40602 .83794 m .40293 .8384 L .40462 .83911 L F
.40602 .83794 m .40462 .83911 L .40463 .83912 L F
.704 .931 .613 r
.52159 .85269 m .5207 .85395 L .51969 .85506 L F
.73 .564 .666 r
.4591 .8578 m .45981 .86029 L .45659 .86028 L F
.598 .559 .781 r
.46048 .85547 m .4591 .8578 L .45868 .85542 L F
.46048 .85547 m .46172 .85817 L .4591 .8578 L F
.678 .589 .749 r
.46172 .85817 m .45981 .86029 L .4591 .8578 L F
.627 .756 .94 r
.44362 .82385 m .44048 .82299 L .44231 .82247 L F
.62 .796 .966 r
.44444 .82201 m .44362 .82385 L .44231 .82247 L F
.44444 .82201 m .4456 .82337 L .44362 .82385 L F
.779 .94 .592 r
.4393 .85827 m .43953 .85812 L .4393 .85744 L F
.579 .336 .513 r
.40165 .88602 m .40327 .88798 L .40115 .88824 L F
.40165 .88602 m .40355 .88591 L .40327 .88798 L F
.642 .398 .533 r
.42278 .87488 m .42217 .87807 L .42009 .87796 L F
.601 .359 .522 r
.42533 .87654 m .42278 .87488 L .42575 .87556 L F
.42533 .87654 m .42217 .87807 L .42278 .87488 L F
.202 .722 .868 r
.39679 .8723 m .39979 .87229 L .39814 .87091 L F
.782 .849 .901 r
.45958 .82146 m .45617 .82211 L .45805 .82122 L F
.155 .573 .932 r
.46011 .82094 m .45958 .82146 L .45805 .82122 L F
.46011 .82094 m .4611 .82184 L .45958 .82146 L F
.495 0 0 r
.49638 .81615 m .49681 .81659 L .49443 .8145 L F
.49638 .81615 m .49806 .81731 L .49681 .81659 L F
.02 .591 .759 r
.45967 .85539 m .45868 .85542 L .45762 .85465 L F
.45967 .85539 m .46048 .85547 L .45868 .85542 L F
.71 .522 .634 r
.45002 .82923 m .44788 .83213 L .44788 .82972 L F
.45002 .82923 m .45089 .83233 L .44788 .83213 L F
.62 .405 .568 r
.45296 .82961 m .45089 .83233 L .45002 .82923 L F
.595 .315 .463 r
.43024 .87202 m .42939 .87516 L .42752 .87351 L F
.573 .331 .51 r
.43269 .87056 m .43298 .87205 L .43024 .87202 L F
.629 .38 .522 r
.43298 .87205 m .42939 .87516 L .43024 .87202 L F
.7 .615 .758 r
.45523 .82716 m .45231 .82535 L .45399 .82424 L F
.512 .292 .516 r
.45523 .82716 m .45505 .82939 L .45296 .82961 L F
.473 .207 .429 r
.45738 .82556 m .45688 .8277 L .45523 .82716 L F
.403 .341 .673 r
.45688 .8277 m .45714 .82913 L .45523 .82716 L F
.591 .358 .532 r
.45714 .82913 m .45505 .82939 L .45523 .82716 L F
.697 .584 .725 r
.44493 .84232 m .44288 .84488 L .44294 .84291 L F
.647 .511 .684 r
.44493 .84232 m .44612 .8459 L .44288 .84488 L F
.654 .509 .674 r
.44608 .84759 m .44288 .84488 L .44612 .8459 L F
.44608 .84759 m .44426 .84867 L .44288 .84488 L F
.813 .715 .757 r
.51198 .81974 m .51481 .8195 L .51404 .81775 L F
.446 .581 .895 r
.51198 .81974 m .51503 .822 L .51481 .8195 L F
.227 .386 .814 r
.51404 .81775 m .51481 .8195 L .51582 .81857 L F
.835 .808 .825 r
.51503 .822 m .51582 .81857 L .51481 .8195 L F
.307 .775 .938 r
.49902 .83964 m .5003 .83983 L .49763 .83972 L F
.879 .81 .778 r
.49902 .83964 m .5003 .83983 L .49856 .84186 L F
.241 .737 .911 r
.50238 .83968 m .5003 .83983 L .49902 .83964 L F
.655 .569 .746 r
.50527 .81431 m .50392 .81799 L .50329 .81782 L F
.50527 .81431 m .50626 .81776 L .50392 .81799 L F
.372 .81 .958 r
.50392 .81799 m .50538 .81764 L .50329 .81782 L F
.50392 .81799 m .50626 .81776 L .50538 .81764 L F
.588 .357 .533 r
.43269 .87056 m .4347 .8725 L .43298 .87205 L F
.43269 .87056 m .43471 .8705 L .4347 .8725 L F
.699 .617 .762 r
.44379 .83715 m .44173 .83786 L .44056 .83482 L F
.32 .807 .861 r
.39331 .82477 m .39399 .82432 L .39533 .82476 L F
.39331 .82477 m .39213 .82478 L .39399 .82432 L F
.783 .998 .826 r
.44185 .85501 m .4393 .85744 L .44083 .85635 L F
.426 .184 .442 r
.50853 .86806 m .51091 .86362 L .51061 .86777 L F
.56 .275 .44 r
.51091 .86362 m .51238 .8672 L .51061 .86777 L F
.51091 .86362 m .51267 .86397 L .51238 .8672 L F
.62 .405 .568 r
.45296 .82961 m .45292 .83203 L .45089 .83233 L F
.604 .435 .626 r
.45505 .82939 m .45292 .83203 L .45296 .82961 L F
.692 .148 0 r
.50153 .86213 m .49982 .86033 L .49851 .85996 L F
.03 0 0 r
.39856 .83953 m .3953 .83984 L .39672 .83964 L F
.589 .798 .979 r
.42546 .82167 m .42474 .82342 L .42345 .8223 L F
.42546 .82167 m .42683 .82266 L .42474 .82342 L F
.816 .738 .778 r
.50725 .81385 m .50806 .81641 L .50626 .81776 L F
.766 .712 .802 r
.51051 .81392 m .50806 .81641 L .50725 .81385 L F
.717 .711 .844 r
.44899 .82364 m .4456 .82337 L .44767 .82232 L F
.576 .72 .941 r
.44961 .82159 m .44899 .82364 L .44767 .82232 L F
.44961 .82159 m .45064 .82355 L .44899 .82364 L F
.494 .227 .437 r
.4595 .82695 m .45738 .82556 L .45975 .82526 L F
.4595 .82695 m .45688 .8277 L .45738 .82556 L F
.644 .45 .606 r
.39718 .86797 m .39958 .86707 L .39953 .86566 L F
.519 .293 .511 r
.39958 .86707 m .40162 .86525 L .39953 .86566 L F
.789 .649 .708 r
.44395 .85241 m .44547 .85561 L .44185 .85501 L F
.515 .258 .463 r
.44547 .85561 m .44298 .85776 L .44185 .85501 L F
.44547 .85561 m .44498 .85746 L .44298 .85776 L F
.44298 .85776 m .44498 .85746 L .44547 .85561 L F
.519 .523 .8 r
.44717 .85518 m .44547 .85561 L .44395 .85241 L F
.403 .154 .419 r
.44717 .85518 m .44498 .85746 L .44547 .85561 L F
.44717 .85518 m .44498 .85746 L .44547 .85561 L F
.26 .765 .746 r
.40375 .82337 m .40451 .82305 L .40571 .82351 L F
.40375 .82337 m .40244 .82366 L .40451 .82305 L F
.348 0 0 r
.52006 .8195 m .5209 .82057 L .51882 .81995 L F
.095 .506 .904 r
.51984 .81997 m .51882 .81995 L .5209 .82057 L F
.716 .911 .963 r
.51822 .81994 m .52006 .8195 L .51882 .81995 L F
.095 .506 .904 r
.51748 .81863 m .51882 .81995 L .51984 .81997 L F
.716 .911 .963 r
.51657 .82034 m .51822 .81994 L .51882 .81995 L F
.582 .44 .654 r
.52198 .81686 m .52006 .8195 L .51887 .81678 L F
.52198 .81686 m .52216 .81925 L .52006 .8195 L F
.348 0 0 r
.52006 .8195 m .52216 .81925 L .5209 .82057 L F
.032 .452 .875 r
.46854 .82132 m .46996 .82261 L .46823 .82166 L F
.46854 .82132 m .46996 .82261 L .46823 .82166 L F
0 0 0 r
.39533 .82476 m .39731 .82445 L .39849 .82422 L F
.16 .696 .711 r
.39849 .82422 m .39928 .82403 L .40049 .82404 L F
.39849 .82422 m .39731 .82445 L .39928 .82403 L F
.77 .638 .716 r
.49753 .86521 m .49948 .86623 L .50023 .86487 L F
.241 .232 .648 r
.50023 .86487 m .49948 .86623 L .5018 .86692 L F
.323 .081 .384 r
.5018 .86692 m .49948 .86623 L .49964 .86965 L F
.574 .322 .497 r
.41073 .88263 m .41083 .88087 L .41273 .88268 L F
.606 .318 .453 r
.41083 .88087 m .4129 .88095 L .41273 .88268 L F
.837 .66 .663 r
.50535 .84225 m .50705 .84234 L .50592 .83989 L F
.752 .448 .47 r
.50559 .84437 m .50705 .84234 L .50535 .84225 L F
.602 .43 .621 r
.50705 .84234 m .50878 .84462 L .50689 .84538 L F
.752 .448 .47 r
.50559 .84437 m .50878 .84462 L .50705 .84234 L F
.269 0 0 r
.38711 .82628 m .38806 .82537 L .38672 .82625 L F
.38711 .82628 m .39016 .82523 L .38806 .82537 L F
.607 .384 .551 r
.49516 .8399 m .49763 .83972 L .49739 .84225 L F
.928 .682 .545 r
.49763 .83972 m .49739 .84225 L .49516 .8399 L F
.61 .859 .99 r
.4142 .82298 m .41077 .82304 L .41294 .82229 L F
.466 .832 .993 r
.41495 .82211 m .4142 .82298 L .41294 .82229 L F
.41495 .82211 m .4162 .82262 L .4142 .82298 L F
.755 .647 .742 r
.4611 .82184 m .46199 .82375 L .46466 .82205 L F
.8 .722 .779 r
.51644 .81248 m .51888 .81435 L .51562 .81477 L F
.684 .311 .332 r
.51562 .81477 m .51888 .81435 L .51809 .81619 L F
.798 .751 .81 r
.51888 .81435 m .51562 .81477 L .51809 .81619 L F
.376 .639 .958 r
.51983 .81342 m .51888 .81435 L .51644 .81248 L F
.479 .807 1 r
.51983 .81342 m .52095 .81406 L .51888 .81435 L F
.68 .609 .769 r
.52095 .81406 m .51887 .81678 L .51888 .81435 L F
.674 .691 .858 r
.4091 .83913 m .41239 .83973 L .4109 .83865 L F
.656 .75 .919 r
.4109 .83865 m .41239 .83973 L .41464 .83923 L F
.662 .654 .831 r
.41239 .83973 m .41529 .84002 L .41464 .83923 L F
.56 .378 .592 r
.41586 .85529 m .41796 .8551 L .41801 .85266 L F
.424 .231 .513 r
.41586 .85529 m .4174 .85674 L .41796 .8551 L F
.41586 .85529 m .41567 .85751 L .4174 .85674 L F
.677 .565 .72 r
.44691 .83977 m .44493 .84232 L .44494 .84041 L F
.649 .524 .698 r
.44691 .83977 m .44717 .84205 L .44493 .84232 L F
.646 .511 .684 r
.44809 .84523 m .44493 .84232 L .44717 .84205 L F
.44809 .84523 m .44612 .8459 L .44493 .84232 L F
.699 .617 .762 r
.44379 .83715 m .44056 .83482 L .44264 .83429 L F
.69 .594 .743 r
.4458 .8347 m .44379 .83715 L .44264 .83429 L F
.666 .558 .723 r
.4458 .8347 m .44698 .83791 L .44379 .83715 L F
.674 .553 .709 r
.44691 .83977 m .44379 .83715 L .44698 .83791 L F
.44691 .83977 m .44494 .84041 L .44379 .83715 L F
.56 .864 .996 r
.47324 .85468 m .47454 .85526 L .47155 .85535 L F
.757 .529 .587 r
.47155 .85535 m .47454 .85526 L .47441 .85753 L F
.451 .818 .994 r
.47641 .8549 m .47454 .85526 L .47324 .85468 L F
.504 .315 .557 r
.47441 .85753 m .47454 .85526 L .47641 .8549 L F
.719 .483 .568 r
.45981 .86029 m .45656 .86249 L .45659 .86028 L F
.45981 .86029 m .45967 .86204 L .45656 .86249 L F
.678 .589 .749 r
.46172 .85817 m .46211 .86059 L .45981 .86029 L F
.628 .404 .559 r
.45981 .86029 m .46179 .86238 L .45967 .86204 L F
.685 .4 .485 r
.45981 .86029 m .46211 .86059 L .46179 .86238 L F
.68 .58 .736 r
.50527 .81431 m .50329 .81782 L .50226 .81447 L F
.456 .765 .996 r
.50329 .81782 m .50387 .81656 L .50188 .8165 L F
.50329 .81782 m .50538 .81764 L .50387 .81656 L F
.747 .707 .814 r
.49889 .85009 m .50057 .85267 L .49738 .85244 L F
.694 .289 .275 r
.49738 .85244 m .50057 .85267 L .49887 .85376 L F
.862 .456 0 r
.50004 .85239 m .50057 .85267 L .49889 .85009 L F
.875 .994 .785 r
.49887 .85376 m .50057 .85267 L .50004 .85239 L F
.209 .73 .856 r
.40878 .82342 m .40571 .82351 L .40764 .82331 L F
.518 .835 .999 r
.40966 .82242 m .40878 .82342 L .40764 .82331 L F
.40966 .82242 m .41077 .82304 L .40878 .82342 L F
.674 .583 .745 r
.41173 .84968 m .41249 .85083 L .41456 .85012 L F
.68 .609 .769 r
.52095 .81406 m .52198 .81686 L .51887 .81678 L F
.193 .641 .945 r
.45558 .85395 m .45615 .85456 L .45139 .85196 L F
.45558 .85395 m .45762 .85465 L .45615 .85456 L F
.791 .694 .757 r
.45615 .85456 m .45241 .855 L .45139 .85196 L F
.808 .59 .606 r
.49792 .83186 m .49889 .83064 L .49532 .82923 L F
.413 .126 .365 r
.40162 .86525 m .4042 .8628 L .40243 .86326 L F
.40162 .86525 m .40322 .8652 L .4042 .8628 L F
.644 .362 .476 r
.4042 .8628 m .40322 .8652 L .40609 .8648 L F
.618 .363 .509 r
.4042 .8628 m .40609 .8648 L .40643 .86279 L F
.67 .61 .78 r
.45399 .82424 m .45231 .82535 L .45064 .82355 L F
.583 .428 .637 r
.5042 .82215 m .50613 .81919 L .50397 .81947 L F
.571 .361 .558 r
.44001 .86789 m .44189 .86984 L .43983 .86993 L F
.64 .359 .477 r
.44001 .86789 m .44215 .86814 L .44189 .86984 L F
.821 .544 .519 r
.49683 .87076 m .49981 .8731 L .49659 .87302 L F
.726 .504 .589 r
.49659 .87302 m .49981 .8731 L .4997 .87531 L F
.609 .404 .579 r
.49981 .8731 m .50186 .87526 L .4997 .87531 L F
.66 .403 .521 r
.49981 .8731 m .50224 .87324 L .50186 .87526 L F
.083 0 0 r
.49476 .81429 m .49603 .81431 L .49593 .81364 L F
.49476 .81429 m .49443 .8145 L .49603 .81431 L F
.537 .428 .677 r
.51504 .8621 m .51316 .86066 L .51529 .86017 L F
.51504 .8621 m .51338 .86295 L .51316 .86066 L F
.425 .317 .628 r
.41801 .85266 m .41958 .85017 L .41673 .84971 L F
.41801 .85266 m .41963 .85223 L .41958 .85017 L F
.474 .308 .576 r
.41801 .85266 m .41967 .8546 L .41963 .85223 L F
.41801 .85266 m .41796 .8551 L .41967 .8546 L F
.189 0 0 r
.39365 .84035 m .39011 .84055 L .3914 .84115 L F
.538 .808 .996 r
.41937 .82299 m .4162 .82262 L .41822 .82216 L F
.524 .773 .988 r
.42014 .82177 m .41937 .82299 L .41822 .82216 L F
.42014 .82177 m .42138 .8227 L .41937 .82299 L F
0 0 0 r
.50473 .86009 m .50153 .86213 L .50373 .86218 L F
.555 .209 .336 r
.50591 .86226 m .50473 .86009 L .50373 .86218 L F
.50591 .86226 m .50695 .86019 L .50473 .86009 L F
.548 .5 .754 r
.49931 .83482 m .49792 .83186 L .49781 .83371 L F
0 0 0 r
.49605 .83675 m .49931 .83482 L .49781 .83371 L F
.682 .555 .704 r
.41173 .84968 m .41456 .85012 L .4142 .84792 L F
.679 .66 .824 r
.40818 .84503 m .41103 .84548 L .4102 .84467 L F
.66 .757 .922 r
.4102 .84467 m .41103 .84548 L .41341 .84504 L F
.619 .308 .422 r
.42752 .87351 m .42939 .87516 L .42743 .87512 L F
.669 .51 .661 r
.51965 .85732 m .51738 .85994 L .51772 .8579 L F
.671 .495 .638 r
.44933 .86283 m .44722 .86518 L .44745 .86286 L F
.67 .638 .81 r
.51267 .81233 m .51352 .8147 L .51051 .81392 L F
.562 .543 .791 r
.51458 .81148 m .51352 .8147 L .51267 .81233 L F
.51458 .81148 m .51562 .81477 L .51352 .8147 L F
.696 .662 .813 r
.41464 .83923 m .41529 .84002 L .41756 .83975 L F
.69 .558 .7 r
.41529 .84002 m .41551 .84235 L .41756 .83975 L F
.744 .764 .87 r
.51051 .81392 m .50725 .81385 L .50953 .81183 L F
.719 .753 .879 r
.51267 .81233 m .51051 .81392 L .50953 .81183 L F
.666 .826 .96 r
.42973 .82287 m .42683 .82266 L .42866 .82212 L F
.523 .796 .995 r
.4307 .82167 m .42973 .82287 L .42866 .82212 L F
.4307 .82167 m .43199 .82252 L .42973 .82287 L F
.76 .246 0 r
.49291 .863 m .49415 .86473 L .49145 .86229 L F
.654 .572 .751 r
.46371 .85768 m .46211 .86059 L .46172 .85817 L F
.46371 .85768 m .46492 .85986 L .46211 .86059 L F
.583 .35 .529 r
.46211 .86059 m .4638 .86256 L .46179 .86238 L F
.46211 .86059 m .46492 .85986 L .4638 .86256 L F
.816 .738 .778 r
.50725 .81385 m .50626 .81776 L .50527 .81431 L F
.603 .663 .881 r
.40789 .83671 m .4091 .83913 L .4109 .83865 L F
.966 .678 .435 r
.4611 .82184 m .46125 .82396 L .46199 .82375 L F
.624 .435 .606 r
.41169 .8579 m .41313 .85969 L .41351 .85765 L F
.41169 .8579 m .41134 .86008 L .41313 .85969 L F
.684 .549 .695 r
.41756 .83975 m .41551 .84235 L .41765 .842 L F
.681 .519 .659 r
.41545 .84458 m .41765 .842 L .41551 .84235 L F
.561 .336 .531 r
.40643 .86279 m .40849 .86255 L .40862 .86045 L F
.573 .326 .503 r
.40849 .86255 m .41134 .86008 L .40862 .86045 L F
.47 .797 .999 r
.49681 .81659 m .49806 .81731 L .50009 .81702 L F
.845 .669 .664 r
.50273 .84216 m .50592 .83989 L .50238 .83968 L F
.50273 .84216 m .50535 .84225 L .50592 .83989 L F
.628 .617 .82 r
.52298 .81387 m .52198 .81686 L .52095 .81406 L F
.52298 .81387 m .52411 .81654 L .52198 .81686 L F
.61 .461 .655 r
.52411 .81654 m .52216 .81925 L .52198 .81686 L F
.591 .364 .54 r
.41805 .8781 m .41796 .88012 L .41736 .87959 L F
.576 .353 .541 r
.41805 .8781 m .41997 .88006 L .41796 .88012 L F
.41805 .8781 m .42009 .87796 L .41997 .88006 L F
.661 .685 .862 r
.50301 .81072 m .50226 .81447 L .50101 .81108 L F
.50301 .81072 m .50438 .81435 L .50226 .81447 L F
.287 .77 .919 r
.50438 .81435 m .50527 .81431 L .50226 .81447 L F
.296 0 .266 r
.51267 .86397 m .51338 .86295 L .51504 .8621 L F
.827 .55 .519 r
.49856 .84186 m .5017 .84495 L .50197 .84333 L F
.419 .526 .86 r
.50197 .84333 m .5017 .84495 L .50255 .84392 L F
.261 .293 .706 r
.5017 .84495 m .50272 .84636 L .50255 .84392 L F
.542 .388 .622 r
.50272 .84636 m .50147 .84728 L .5017 .84495 L F
.696 .662 .813 r
.41464 .83923 m .41756 .83975 L .41589 .8385 L F
.758 .713 .811 r
.41589 .8385 m .41756 .83975 L .41921 .83742 L F
.664 .578 .749 r
.41921 .83742 m .41756 .83975 L .41996 .83945 L F
.636 .496 .674 r
.41765 .842 m .41996 .83945 L .41756 .83975 L F
.594 .378 .557 r
.44519 .86549 m .44397 .86807 L .44215 .86814 L F
.638 .427 .58 r
.44704 .86691 m .44519 .86549 L .44722 .86518 L F
.44704 .86691 m .44397 .86807 L .44519 .86549 L F
.675 .781 .929 r
.47206 .82189 m .46996 .82261 L .46854 .82132 L F
.771 .524 .561 r
.47143 .82384 m .46854 .82132 L .46996 .82261 L F
.507 .229 .428 r
.47206 .82189 m .47143 .82384 L .46996 .82261 L F
.543 .341 .557 r
.50224 .87324 m .50442 .87068 L .50427 .87278 L F
.483 .268 .511 r
.50427 .87278 m .50442 .87068 L .50628 .87039 L F
.659 .566 .739 r
.41341 .84504 m .4142 .84792 L .41651 .84748 L F
.653 .535 .707 r
.4142 .84792 m .41456 .85012 L .41651 .84748 L F
.676 .56 .716 r
.44896 .83731 m .44691 .83977 L .44698 .83791 L F
.694 .587 .731 r
.4507 .83962 m .44691 .83977 L .44896 .83731 L F
.648 .472 .632 r
.4507 .83962 m .44717 .84205 L .44691 .83977 L F
.928 .682 .545 r
.49763 .83972 m .49856 .84186 L .49739 .84225 L F
.879 .81 .778 r
.49902 .83964 m .49856 .84186 L .49932 .84116 L F
.928 .682 .545 r
.49739 .84225 m .49856 .84186 L .49763 .83972 L F
.359 .531 .889 r
.49856 .84186 m .50197 .84333 L .49932 .84116 L F
.573 .939 .83 r
.49739 .84225 m .49856 .84186 L .49932 .84116 L F
.615 .827 .982 r
.44902 .85453 m .45033 .85538 L .44717 .85518 L F
.44902 .85453 m .45033 .85538 L .44717 .85518 L F
.541 .801 .993 r
.44902 .85453 m .45241 .855 L .45033 .85538 L F
.516 .455 .726 r
.39958 .86707 m .4004 .87058 L .40209 .87012 L F
.392 .118 .374 r
.40209 .87012 m .4004 .87058 L .39979 .87229 L F
.906 .76 .689 r
.49683 .87076 m .49542 .87031 L .49746 .86963 L F
.49683 .87076 m .49659 .87302 L .49542 .87031 L F
.967 .833 .657 r
.49001 .85772 m .49013 .85969 L .49003 .85963 L F
.88 .497 .307 r
.49013 .85969 m .49019 .86213 L .49003 .85963 L F
.49013 .85969 m .49145 .86229 L .49019 .86213 L F
.764 .695 .786 r
.49176 .82909 m .49318 .83205 L .49109 .83218 L F
.753 .542 .609 r
.49109 .83218 m .49318 .83205 L .49086 .83433 L F
.774 .575 .63 r
.49318 .83205 m .49462 .83394 L .49086 .83433 L F
.777 .559 .604 r
.49247 .83186 m .49318 .83205 L .49176 .82909 L F
.49247 .83186 m .49532 .82923 L .49318 .83205 L F
.761 .709 .803 r
.49542 .87031 m .49659 .87302 L .49344 .87285 L F
.772 .549 .596 r
.49344 .87285 m .49659 .87302 L .49655 .87545 L F
.726 .504 .589 r
.49659 .87302 m .4997 .87531 L .49655 .87545 L F
.519 .293 .511 r
.39958 .86707 m .40172 .86705 L .40162 .86525 L F
.516 .455 .726 r
.39958 .86707 m .40209 .87012 L .40172 .86705 L F
.628 .799 .965 r
.44767 .82232 m .4456 .82337 L .44444 .82201 L F
.671 .77 .925 r
.45306 .82207 m .45064 .82355 L .44961 .82159 L F
.67 .61 .78 r
.45399 .82424 m .45064 .82355 L .45306 .82207 L F
.432 .148 .379 r
.41313 .85969 m .41567 .85751 L .41351 .85765 L F
.704 .607 .745 r
.41651 .84748 m .41456 .85012 L .41673 .84971 L F
.712 .592 .721 r
.44788 .83213 m .44875 .83497 L .4458 .8347 L F
.677 .564 .72 r
.44896 .83731 m .4458 .8347 L .44875 .83497 L F
.633 .483 .661 r
.45089 .83233 m .44875 .83497 L .44788 .83213 L F
.45089 .83233 m .45094 .83482 L .44875 .83497 L F
.635 .498 .678 r
.45094 .83482 m .44896 .83731 L .44875 .83497 L F
.529 .293 .501 r
.40327 .88798 m .40355 .88591 L .40534 .88753 L F
.578 .285 .435 r
.40355 .88591 m .4057 .88592 L .40534 .88753 L F
.479 .238 .47 r
.50186 .87526 m .50224 .87324 L .50427 .87278 L F
.681 .519 .659 r
.41545 .84458 m .41841 .845 L .41765 .842 L F
.636 .496 .674 r
.41765 .842 m .42035 .84225 L .41996 .83945 L F
.622 .482 .67 r
.41765 .842 m .4206 .84461 L .42035 .84225 L F
.41765 .842 m .41841 .845 L .4206 .84461 L F
.677 .564 .72 r
.44896 .83731 m .44698 .83791 L .4458 .8347 L F
.679 .92 .973 r
.49627 .86464 m .49753 .86521 L .49941 .86388 L F
.613 .672 .883 r
.49753 .86521 m .50023 .86487 L .49941 .86388 L F
.773 .55 .596 r
.51969 .85506 m .51627 .85253 L .5163 .85475 L F
.72 .33 .31 r
.51835 .85672 m .51969 .85506 L .5163 .85475 L F
.969 .732 .523 r
.51835 .85672 m .51965 .85732 L .51969 .85506 L F
.671 .495 .638 r
.44933 .86283 m .44932 .86522 L .44722 .86518 L F
.628 .42 .581 r
.45164 .86263 m .44932 .86522 L .44933 .86283 L F
.166 0 0 r
.51426 .85527 m .51151 .85743 L .51311 .85689 L F
.311 0 .068 r
.5163 .85475 m .51426 .85527 L .51311 .85689 L F
0 0 0 r
.51627 .85253 m .51426 .85527 L .5163 .85475 L F
.081 .64 .779 r
.46595 .85499 m .46903 .85498 L .46803 .85493 L F
.46595 .85499 m .46903 .85498 L .46803 .85493 L F
.62 .665 .872 r
.46828 .85372 m .47155 .85535 L .46903 .85498 L F
.253 .461 .868 r
.46828 .85372 m .46903 .85498 L .46999 .8544 L F
.56 .864 .996 r
.47324 .85468 m .47155 .85535 L .46828 .85372 L F
.419 .857 .926 r
.46803 .85493 m .46903 .85498 L .46999 .8544 L F
.371 .729 .989 r
.46903 .85498 m .47155 .85535 L .46999 .8544 L F
.419 .857 .926 r
.46999 .8544 m .46903 .85498 L .46803 .85493 L F
.33 .099 .405 r
.40172 .86705 m .40322 .8652 L .40162 .86525 L F
.616 .466 .655 r
.44592 .84977 m .44426 .84867 L .44608 .84759 L F
.44592 .84977 m .44396 .85041 L .44426 .84867 L F
.77 .755 .839 r
.50631 .82184 m .50955 .82179 L .50845 .8213 L F
.811 .927 .911 r
.50845 .8213 m .50955 .82179 L .51198 .81974 L F
.876 .991 .809 r
.40773 .88581 m .41033 .88346 L .41073 .88263 L F
.788 .648 .707 r
.44395 .85241 m .44185 .85501 L .44278 .85305 L F
.642 .545 .729 r
.44592 .84977 m .44395 .85241 L .44396 .85041 L F
.637 .538 .725 r
.44623 .85195 m .44395 .85241 L .44592 .84977 L F
.519 .523 .8 r
.44717 .85518 m .44395 .85241 L .44623 .85195 L F
.648 .472 .632 r
.4507 .83962 m .45028 .84278 L .44717 .84205 L F
.672 .526 .678 r
.45007 .84454 m .44717 .84205 L .45028 .84278 L F
.45007 .84454 m .44809 .84523 L .44717 .84205 L F
.687 .322 .349 r
.49086 .83433 m .49462 .83394 L .49333 .83483 L F
0 0 .531 r
.49462 .83394 m .49605 .83675 L .49482 .83371 L F
.487 .86 .634 r
.49333 .83483 m .49462 .83394 L .49482 .83371 L F
.635 .52 .707 r
.41673 .84971 m .41872 .84714 L .41651 .84748 L F
.41673 .84971 m .41958 .85017 L .41872 .84714 L F
.327 .394 .779 r
.49443 .8145 m .49681 .81659 L .49603 .81431 L F
.628 .42 .581 r
.45164 .86263 m .45146 .86517 L .44932 .86522 L F
.661 .47 .615 r
.45442 .8625 m .45146 .86517 L .45164 .86263 L F
.631 .378 .516 r
.41736 .87959 m .41273 .88268 L .4129 .88095 L F
.687 .424 .519 r
.43471 .8705 m .43677 .87305 L .4347 .8725 L F
.43471 .8705 m .44018 .87053 L .43677 .87305 L F
.554 .31 .5 r
.51529 .86017 m .51763 .86173 L .51504 .8621 L F
.51529 .86017 m .51738 .85994 L .51763 .86173 L F
.656 .75 .919 r
.4109 .83865 m .41464 .83923 L .41332 .83747 L F
.664 .764 .925 r
.41332 .83747 m .41464 .83923 L .41589 .8385 L F
.595 .777 .967 r
.43592 .82132 m .43512 .82288 L .43398 .82196 L F
.43592 .82132 m .43717 .82237 L .43512 .82288 L F
.879 .971 .844 r
.51198 .81974 m .51404 .81775 L .51319 .81734 L F
0 .283 .649 r
.51319 .81734 m .51404 .81775 L .51582 .81857 L F
.863 .775 .763 r
.43677 .87305 m .44018 .87053 L .43983 .86993 L F
.709 .562 .685 r
.44812 .84693 m .44612 .8459 L .44809 .84523 L F
.44812 .84693 m .44608 .84759 L .44612 .8459 L F
.681 .574 .728 r
.45111 .83681 m .4507 .83962 L .44896 .83731 L F
.45111 .83681 m .45213 .83969 L .4507 .83962 L F
.661 .484 .634 r
.45209 .84201 m .4507 .83962 L .45213 .83969 L F
.45209 .84201 m .45028 .84278 L .4507 .83962 L F
.633 .483 .661 r
.45303 .83428 m .45089 .83233 L .45292 .83203 L F
.45303 .83428 m .45094 .83482 L .45089 .83233 L F
.657 .588 .766 r
.46371 .85768 m .46172 .85817 L .46048 .85547 L F
.567 .272 .428 r
.44215 .86814 m .44394 .86975 L .44189 .86984 L F
.44215 .86814 m .44397 .86807 L .44394 .86975 L F
.71 .712 .85 r
.50614 .81111 m .50438 .81435 L .50301 .81072 L F
.656 .753 .921 r
.50725 .81385 m .50438 .81435 L .50614 .81111 L F
.50725 .81385 m .50527 .81431 L .50438 .81435 L F
.659 .566 .739 r
.41341 .84504 m .41651 .84748 L .41545 .84458 L F
.763 .722 .814 r
.45617 .82211 m .45399 .82424 L .45306 .82207 L F
.64 .775 .945 r
.44048 .82299 m .43717 .82237 L .43913 .82182 L F
.59 .772 .966 r
.44231 .82247 m .44048 .82299 L .43913 .82182 L F
.683 .502 .634 r
.44812 .84693 m .44592 .84977 L .44608 .84759 L F
.44812 .84693 m .44806 .84953 L .44592 .84977 L F
.699 .611 .755 r
.45007 .84454 m .44812 .84693 L .44809 .84523 L F
.627 .507 .696 r
.45007 .84454 m .45167 .84809 L .44812 .84693 L F
.661 .505 .663 r
.45167 .84809 m .44806 .84953 L .44812 .84693 L F
.603 .377 .546 r
.40609 .8648 m .40849 .86255 L .40643 .86279 L F
.622 .396 .554 r
.49739 .84225 m .49902 .83964 L .49763 .83972 L F
.928 .682 .545 r
.49739 .84225 m .49763 .83972 L .49902 .83964 L F
.189 0 0 r
.39365 .84035 m .39181 .84069 L .39011 .84055 L F
0 0 0 r
.3953 .83984 m .39181 .84069 L .39365 .84035 L F
.583 .428 .637 r
.5042 .82215 m .50631 .82184 L .50613 .81919 L F
.298 0 0 r
.39856 .83953 m .39755 .83995 L .3953 .83984 L F
0 0 0 r
.40086 .83865 m .3995 .8394 L .39856 .83953 L F
.3995 .8394 m .39755 .83995 L .39856 .83953 L F
.68 .553 .705 r
.41545 .84458 m .41872 .84714 L .41841 .845 L F
.41545 .84458 m .41651 .84748 L .41872 .84714 L F
.684 .576 .727 r
.45419 .83947 m .45213 .83969 L .45111 .83681 L F
.68 .489 .622 r
.45442 .84182 m .45213 .83969 L .45419 .83947 L F
.45442 .84182 m .45209 .84201 L .45213 .83969 L F
.694 .582 .726 r
.45111 .83681 m .44896 .83731 L .45094 .83482 L F
.148 0 0 r
.49828 .85614 m .4953 .85732 L .49831 .85771 L F
.617 .369 .519 r
.49831 .85771 m .50057 .85724 L .49828 .85614 L F
.519 .79 .995 r
.46206 .82063 m .4611 .82184 L .46011 .82094 L F
.567 .557 .803 r
.46544 .82119 m .46672 .82335 L .46279 .823 L F
.46544 .82119 m .46279 .823 L .46381 .82249 L F
.609 .395 .567 r
.46381 .82249 m .4611 .82184 L .46206 .82063 L F
.749 .513 .573 r
.46279 .823 m .46124 .82626 L .46125 .82396 L F
.46279 .823 m .4641 .82699 L .46124 .82626 L F
.612 .438 .622 r
.46667 .82649 m .46279 .823 L .46672 .82335 L F
.46667 .82649 m .4641 .82699 L .46279 .823 L F
0 0 0 r
.46381 .82249 m .46125 .82396 L .46279 .823 L F
.609 .395 .567 r
.46381 .82249 m .46125 .82396 L .4611 .82184 L F
.587 .535 .764 r
.41921 .83742 m .41996 .83945 L .42187 .83901 L F
.614 .501 .701 r
.42035 .84225 m .42187 .83901 L .41996 .83945 L F
.581 .818 .989 r
.46999 .8544 m .47155 .85535 L .47324 .85468 L F
.757 .529 .587 r
.47155 .85535 m .47441 .85753 L .47324 .85468 L F
.189 0 0 r
.50272 .84636 m .50689 .84538 L .50559 .84437 L F
.7 .78 .914 r
.50689 .84538 m .50878 .84462 L .50559 .84437 L F
.899 .731 .665 r
.49488 .86016 m .49644 .86012 L .4953 .85732 L F
.811 .418 .31 r
.49516 .86161 m .49644 .86012 L .49488 .86016 L F
.588 .494 .715 r
.49644 .86012 m .49831 .85771 L .4953 .85732 L F
.49644 .86012 m .49851 .85996 L .49831 .85771 L F
.419 0 .099 r
.49733 .86155 m .49644 .86012 L .49516 .86161 L F
.49733 .86155 m .49851 .85996 L .49644 .86012 L F
.658 .406 .527 r
.44722 .86518 m .44919 .86721 L .44704 .86691 L F
.44722 .86518 m .44932 .86522 L .44919 .86721 L F
.247 0 0 r
.52216 .81925 m .52305 .81988 L .5209 .82057 L F
.52216 .81925 m .52429 .81906 L .52305 .81988 L F
.582 .425 .634 r
.52411 .81654 m .52429 .81906 L .52216 .81925 L F
.743 .65 .758 r
.49631 .84949 m .49738 .85244 L .49429 .85231 L F
.754 .53 .593 r
.49738 .85244 m .49428 .85499 L .49429 .85231 L F
.49738 .85244 m .49746 .8549 L .49428 .85499 L F
.685 .619 .777 r
.49889 .85009 m .49738 .85244 L .49631 .84949 L F
.694 .289 .275 r
.49738 .85244 m .49887 .85376 L .49746 .8549 L F
.505 .824 1 r
.48869 .83118 m .49056 .83219 L .48785 .83205 L F
.351 .785 .967 r
.49056 .83219 m .49109 .83218 L .48785 .83205 L F
.898 .874 .805 r
.49176 .82909 m .49056 .83219 L .48869 .83118 L F
.764 .695 .786 r
.49176 .82909 m .49109 .83218 L .49056 .83219 L F
.527 .868 .991 r
.39533 .82476 m .39592 .82378 L .39731 .82445 L F
.39533 .82476 m .39399 .82432 L .39592 .82378 L F
.399 .459 .806 r
.50613 .81919 m .50766 .81856 L .50538 .81764 L F
.621 .565 .77 r
.50631 .82184 m .50766 .81856 L .50613 .81919 L F
.657 .558 .732 r
.45303 .83428 m .45111 .83681 L .45094 .83482 L F
.45303 .83428 m .45408 .83759 L .45111 .83681 L F
.684 .576 .727 r
.45419 .83947 m .45111 .83681 L .45408 .83759 L F
.835 .808 .825 r
.51503 .822 m .51657 .82034 L .51582 .81857 L F
.502 .848 .995 r
.41822 .82216 m .4162 .82262 L .41495 .82211 L F
.179 .676 .916 r
.49178 .82682 m .49084 .8264 L .4885 .82623 L F
.975 .869 .668 r
.49168 .8242 m .49178 .82682 L .49261 .82632 L F
.49168 .8242 m .49084 .8264 L .49178 .82682 L F
.618 .873 .99 r
.41294 .82229 m .41077 .82304 L .40966 .82242 L F
.59 .791 .976 r
.51657 .82034 m .51748 .81863 L .51582 .81857 L F
.51657 .82034 m .51882 .81995 L .51748 .81863 L F
.678 .473 .602 r
.49109 .83218 m .48768 .83437 L .48785 .83205 L F
.49109 .83218 m .49086 .83433 L .48768 .83437 L F
.331 .813 .875 r
.40049 .82404 m .40123 .82357 L .40244 .82366 L F
.40049 .82404 m .39928 .82403 L .40123 .82357 L F
.829 .55 .517 r
.50559 .84437 m .50535 .84225 L .50273 .84216 L F
.65 .628 .814 r
.46558 .85766 m .46492 .85986 L .46371 .85768 L F
.46558 .85766 m .46677 .85997 L .46492 .85986 L F
.559 .284 .455 r
.46677 .85997 m .4638 .86256 L .46492 .85986 L F
.269 0 0 r
.38711 .82628 m .38871 .82614 L .39016 .82523 L F
.133 0 0 r
.39016 .82523 m .39066 .82573 L .39213 .82478 L F
.39016 .82523 m .38871 .82614 L .39066 .82573 L F
.662 .589 .764 r
.45624 .83698 m .45419 .83947 L .45408 .83759 L F
.657 .583 .76 r
.45624 .83698 m .45728 .83969 L .45419 .83947 L F
.666 .487 .633 r
.45728 .83969 m .45442 .84182 L .45419 .83947 L F
.296 0 .266 r
.51267 .86397 m .51504 .8621 L .51423 .86364 L F
.465 .197 .422 r
.51238 .8672 m .51267 .86397 L .51423 .86364 L F
.689 .397 .476 r
.45656 .86249 m .45967 .86204 L .45848 .86466 L F
.626 .357 .49 r
.45967 .86204 m .46183 .8642 L .45848 .86466 L F
.45967 .86204 m .46179 .86238 L .46183 .8642 L F
.526 .213 .38 r
.40115 .88824 m .40217 .89032 L .40042 .89029 L F
.40115 .88824 m .40327 .88798 L .40217 .89032 L F
.631 .378 .516 r
.41736 .87959 m .41482 .88284 L .41273 .88268 L F
.618 .358 .502 r
.41736 .87959 m .4167 .88292 L .41482 .88284 L F
.41736 .87959 m .41796 .88012 L .4167 .88292 L F
.808 .59 .606 r
.49792 .83186 m .49532 .82923 L .49534 .83173 L F
.775 .583 .64 r
.49482 .83371 m .49792 .83186 L .49534 .83173 L F
.49482 .83371 m .49781 .83371 L .49792 .83186 L F
.629 .38 .522 r
.43298 .87205 m .43166 .87524 L .42939 .87516 L F
.603 .352 .51 r
.43529 .87399 m .43298 .87205 L .4347 .8725 L F
.43529 .87399 m .43166 .87524 L .43298 .87205 L F
.415 .776 .995 r
.51983 .81342 m .52298 .81387 L .52095 .81406 L F
.573 .326 .503 r
.40849 .86255 m .41029 .86246 L .41134 .86008 L F
.59 .344 .512 r
.41134 .86008 m .41298 .86178 L .41313 .85969 L F
.41134 .86008 m .41029 .86246 L .41298 .86178 L F
.192 .702 .896 r
.40451 .82305 m .40764 .82331 L .40571 .82351 L F
.675 .781 .929 r
.47206 .82189 m .46854 .82132 L .4704 .82074 L F
.567 .765 .972 r
.47389 .82138 m .47206 .82189 L .4704 .82074 L F
.419 .146 .39 r
.47389 .82138 m .47143 .82384 L .47206 .82189 L F
.758 .713 .811 r
.41589 .8385 m .41921 .83742 L .41853 .83635 L F
.541 .675 .925 r
.41853 .83635 m .41921 .83742 L .42042 .83615 L F
.529 .655 .916 r
.41921 .83742 m .42166 .83733 L .42042 .83615 L F
.587 .535 .764 r
.41921 .83742 m .42187 .83901 L .42166 .83733 L F
.687 .444 .548 r
.50273 .84216 m .49902 .83964 L .49932 .84116 L F
.50273 .84216 m .50238 .83968 L .49902 .83964 L F
.604 .435 .626 r
.45505 .82939 m .45504 .83176 L .45292 .83203 L F
.61 .458 .651 r
.45504 .83176 m .45303 .83428 L .45292 .83203 L F
.736 .686 .803 r
.49223 .8682 m .49327 .87046 L .4903 .87003 L F
.855 .666 .646 r
.49327 .87046 m .49069 .87243 L .4903 .87003 L F
.49327 .87046 m .49344 .87285 L .49069 .87243 L F
.594 .639 .865 r
.4946 .86833 m .49327 .87046 L .49223 .8682 L F
.4946 .86833 m .49542 .87031 L .49327 .87046 L F
.599 .472 .678 r
.49542 .87031 m .49344 .87285 L .49327 .87046 L F
.381 .097 .351 r
.41796 .8551 m .4174 .85674 L .41967 .8546 L F
.53 .172 .305 r
.50824 .86121 m .50695 .86019 L .50591 .86226 L F
.50824 .86121 m .50922 .86016 L .50695 .86019 L F
.767 .678 .764 r
.47324 .85468 m .47441 .85753 L .47641 .8549 L F
.504 .547 .834 r
.52594 .81654 m .52411 .81654 L .52298 .81387 L F
.518 .433 .699 r
.52594 .81654 m .52649 .81894 L .52411 .81654 L F
.602 .441 .635 r
.52411 .81654 m .52649 .81894 L .52429 .81906 L F
.707 .443 .523 r
.49655 .87545 m .4997 .87531 L .49851 .87776 L F
.59 .32 .476 r
.4997 .87531 m .50093 .87692 L .49851 .87776 L F
.4997 .87531 m .50186 .87526 L .50093 .87692 L F
.395 .579 .914 r
.46179 .85444 m .46048 .85547 L .45967 .85539 L F
.46179 .85444 m .46337 .85648 L .46048 .85547 L F
.657 .588 .766 r
.46371 .85768 m .46048 .85547 L .46337 .85648 L F
.763 .722 .814 r
.45617 .82211 m .45306 .82207 L .45482 .82101 L F
.697 .783 .917 r
.45805 .82122 m .45617 .82211 L .45482 .82101 L F
.863 .775 .763 r
.43677 .87305 m .43983 .86993 L .43953 .87042 L F
.564 .332 .523 r
.43983 .86993 m .44244 .87166 L .43953 .87042 L F
.43983 .86993 m .44189 .86984 L .44244 .87166 L F
.811 .927 .911 r
.50845 .8213 m .51198 .81974 L .51086 .81914 L F
.879 .971 .844 r
.51198 .81974 m .51319 .81734 L .51086 .81914 L F
.583 .418 .623 r
.45708 .83136 m .45505 .82939 L .45714 .82913 L F
.45708 .83136 m .45504 .83176 L .45505 .82939 L F
.631 .523 .713 r
.41841 .845 m .41872 .84714 L .4206 .84461 L F
.569 .937 .901 r
.49333 .85627 m .49001 .85772 L .49234 .85758 L F
.599 .355 .519 r
.49224 .85925 m .49001 .85772 L .49003 .85963 L F
.49224 .85925 m .49234 .85758 L .49001 .85772 L F
.635 .53 .717 r
.4206 .84461 m .41872 .84714 L .42086 .84672 L F
.626 .515 .708 r
.41872 .84714 m .42172 .84976 L .42086 .84672 L F
.41872 .84714 m .41958 .85017 L .42172 .84976 L F
.147 .365 .82 r
.46455 .85697 m .46371 .85768 L .46337 .85648 L F
.366 .741 .989 r
.46455 .85697 m .46558 .85766 L .46371 .85768 L F
.975 .869 .668 r
.49168 .8242 m .49261 .82632 L .4945 .82487 L F
.614 .368 .522 r
.44932 .86522 m .45129 .86723 L .44919 .86721 L F
.617 .368 .518 r
.44932 .86522 m .45146 .86517 L .45129 .86723 L F
.532 .799 .995 r
.42223 .82151 m .42138 .8227 L .42014 .82177 L F
.42223 .82151 m .42345 .8223 L .42138 .8227 L F
.656 .523 .69 r
.44806 .84953 m .44623 .85195 L .44592 .84977 L F
.44806 .84953 m .45035 .85364 L .44623 .85195 L F
.576 .494 .725 r
.44902 .85453 m .44623 .85195 L .45035 .85364 L F
.44902 .85453 m .44717 .85518 L .44623 .85195 L F
.587 .363 .543 r
.42009 .87796 m .42201 .87997 L .41997 .88006 L F
.635 .361 .485 r
.42217 .87807 m .42201 .87997 L .42009 .87796 L F
.432 .148 .379 r
.41313 .85969 m .41512 .8594 L .41567 .85751 L F
.598 .394 .576 r
.41512 .8594 m .4174 .85674 L .41567 .85751 L F
.702 .677 .823 r
.50953 .81183 m .50725 .81385 L .50614 .81111 L F
.317 0 .047 r
.48916 .85554 m .49006 .85481 L .48795 .85634 L F
.76 .699 .794 r
.49062 .85213 m .49006 .85481 L .48916 .85554 L F
.49062 .85213 m .49237 .85252 L .49006 .85481 L F
.69 .578 .724 r
.49237 .85252 m .49213 .85567 L .49006 .85481 L F
.072 .533 .9 r
.49006 .85481 m .49213 .85567 L .4909 .85467 L F
.49006 .85481 m .4909 .85467 L .48795 .85634 L F
.707 .601 .736 r
.45209 .84201 m .45007 .84454 L .45028 .84278 L F
.66 .533 .698 r
.45235 .84429 m .45007 .84454 L .45209 .84201 L F
.659 .522 .685 r
.45319 .84736 m .45007 .84454 L .45235 .84429 L F
.45319 .84736 m .45167 .84809 L .45007 .84454 L F
.719 .753 .879 r
.51267 .81233 m .50953 .81183 L .5114 .81086 L F
.654 .715 .893 r
.51458 .81148 m .51267 .81233 L .5114 .81086 L F
.305 .484 .871 r
.50538 .81764 m .50603 .81591 L .50387 .81656 L F
.50538 .81764 m .50766 .81856 L .50603 .81591 L F
.876 .991 .809 r
.40773 .88581 m .41073 .88263 L .41235 .8864 L F
.406 .309 .632 r
.41281 .88525 m .41073 .88263 L .41273 .88268 L F
.625 .388 .538 r
.41467 .88469 m .41349 .88583 L .41281 .88525 L F
.619 .28 .374 r
.40773 .88581 m .41235 .8864 L .40943 .88758 L F
.625 .388 .538 r
.41349 .88583 m .41152 .88774 L .41281 .88525 L F
.406 .309 .632 r
.41281 .88525 m .41235 .8864 L .41131 .88398 L F
.41281 .88525 m .41131 .88398 L .41073 .88263 L F
.559 .284 .455 r
.46677 .85997 m .46742 .86018 L .4638 .86256 L F
.459 .529 .842 r
.46817 .85884 m .46677 .85997 L .46558 .85766 L F
.358 .388 .755 r
.46817 .85884 m .46742 .86018 L .46677 .85997 L F
.603 .663 .881 r
.40908 .83748 m .4109 .83865 L .40909 .83768 L F
.194 0 0 r
.41065 .83804 m .40912 .83835 L .40909 .83768 L F
.40912 .83835 m .40801 .83858 L .40909 .83768 L F
.603 .663 .881 r
.40789 .83671 m .40908 .83748 L .40909 .83768 L F
.65 .809 .96 r
.40909 .83768 m .4109 .83865 L .41332 .83747 L F
.614 .501 .701 r
.42035 .84225 m .42262 .84207 L .42187 .83901 L F
.609 .46 .655 r
.42035 .84225 m .4206 .84461 L .42262 .84207 L F
.661 .47 .615 r
.45442 .8625 m .4542 .86449 L .45146 .86517 L F
.66 .413 .535 r
.45442 .8625 m .45642 .86452 L .4542 .86449 L F
.45442 .8625 m .45656 .86249 L .45642 .86452 L F
.547 .249 .412 r
.4057 .88592 m .40735 .88747 L .40534 .88753 L F
.4057 .88592 m .40773 .88581 L .40735 .88747 L F
.68 .457 .576 r
.49234 .85758 m .4953 .85732 L .49333 .85627 L F
.633 .361 .489 r
.43953 .87042 m .43662 .87448 L .43677 .87305 L F
.43953 .87042 m .43861 .87462 L .43662 .87448 L F
.702 .507 .622 r
.44244 .87166 m .43861 .87462 L .43953 .87042 L F
.548 .277 .457 r
.46124 .82626 m .45975 .82526 L .46125 .82396 L F
.46124 .82626 m .4595 .82695 L .45975 .82526 L F
.738 .686 .801 r
.47835 .84193 m .47941 .84463 L .47611 .84461 L F
.781 .567 .611 r
.47941 .84463 m .47615 .84667 L .47611 .84461 L F
.47941 .84463 m .47929 .84693 L .47615 .84667 L F
.648 .623 .811 r
.48041 .8413 m .47941 .84463 L .47835 .84193 L F
.48041 .8413 m .48164 .84434 L .47941 .84463 L F
.68 .516 .657 r
.48164 .84434 m .47929 .84693 L .47941 .84463 L F
.611 .805 .974 r
.42866 .82212 m .42683 .82266 L .42546 .82167 L F
.799 .584 .61 r
.49168 .8242 m .4945 .82487 L .49249 .82398 L F
.676 .692 .858 r
.49249 .82398 m .4945 .82487 L .49587 .82392 L F
.537 .444 .697 r
.49428 .85499 m .49213 .85567 L .49237 .85252 L F
.565 .829 .995 r
.4909 .85467 m .49213 .85567 L .49428 .85499 L F
.755 .552 .622 r
.48893 .86777 m .48703 .86993 L .48928 .86686 L F
.48893 .86777 m .4903 .87003 L .48703 .86993 L F
.536 .572 .839 r
.49138 .86692 m .48893 .86777 L .48928 .86686 L F
.637 .516 .699 r
.49223 .8682 m .48893 .86777 L .49138 .86692 L F
.49223 .8682 m .4903 .87003 L .48893 .86777 L F
.73 .642 .761 r
.51644 .81248 m .51562 .81477 L .51458 .81148 L F
.777 .559 .604 r
.49247 .83186 m .49534 .83173 L .49532 .82923 L F
.732 .676 .796 r
.49902 .81226 m .49805 .816 L .49593 .81364 L F
.658 .407 .528 r
.44704 .86691 m .44394 .86975 L .44397 .86807 L F
.658 .502 .66 r
.41958 .85017 m .42186 .85208 L .42172 .84976 L F
.41958 .85017 m .41963 .85223 L .42186 .85208 L F
.586 .819 .988 r
.43398 .82196 m .43199 .82252 L .4307 .82167 L F
.852 .598 .553 r
.49069 .87243 m .49344 .87285 L .49336 .87504 L F
.772 .549 .596 r
.49344 .87285 m .49655 .87545 L .49336 .87504 L F
.669 .51 .661 r
.51965 .85732 m .51985 .86018 L .51738 .85994 L F
0 .401 .742 r
.521 .85775 m .51965 .85732 L .51835 .85672 L F
.611 .577 .791 r
.521 .85775 m .51985 .86018 L .51965 .85732 L F
.782 .734 .809 r
.48755 .82153 m .4843 .82117 L .48638 .81888 L F
.81 .664 .702 r
.48755 .82153 m .48415 .82304 L .4843 .82117 L F
.48755 .82153 m .4855 .82425 L .48415 .82304 L F
.737 .556 .648 r
.48755 .82153 m .48898 .82434 L .4855 .82425 L F
.782 .734 .809 r
.4895 .81891 m .48755 .82153 L .48638 .81888 L F
.697 .606 .751 r
.4895 .81891 m .49058 .82187 L .48755 .82153 L F
.058 0 .18 r
.49058 .82187 m .48898 .82434 L .48755 .82153 L F
.51 0 0 r
.46999 .8544 m .47324 .85468 L .46828 .85372 L F
.655 .839 .971 r
.49278 .85159 m .49429 .85231 L .49237 .85252 L F
.537 .444 .697 r
.49428 .85499 m .49237 .85252 L .49429 .85231 L F
.85 .823 .822 r
.49631 .84949 m .49429 .85231 L .49278 .85159 L F
.502 .276 .503 r
.51423 .86364 m .51504 .8621 L .51763 .86173 L F
.693 .637 .789 r
.50255 .84392 m .50272 .84636 L .50559 .84437 L F
.654 .556 .732 r
.45624 .83698 m .45408 .83759 L .45303 .83428 L F
.661 .505 .663 r
.45167 .84809 m .45133 .84978 L .44806 .84953 L F
.605 .503 .711 r
.45112 .85205 m .44806 .84953 L .45133 .84978 L F
.45112 .85205 m .45035 .85364 L .44806 .84953 L F
.058 0 .18 r
.49058 .82187 m .48953 .8242 L .48898 .82434 L F
.73 .202 0 r
.4895 .81891 m .4927 .82139 L .49058 .82187 L F
0 0 .067 r
.49171 .82116 m .49058 .82187 L .4927 .82139 L F
.49171 .82116 m .48953 .8242 L .49058 .82187 L F
.664 .764 .925 r
.41332 .83747 m .41589 .8385 L .41514 .83655 L F
.772 .798 .874 r
.41514 .83655 m .41589 .8385 L .41853 .83635 L F
.788 .727 .796 r
.45112 .85205 m .44902 .85453 L .45035 .85364 L F
.754 .67 .769 r
.45112 .85205 m .45241 .855 L .44902 .85453 L F
.697 .644 .792 r
.45139 .85196 m .45241 .855 L .45112 .85205 L F
.574 .386 .588 r
.41298 .86178 m .41512 .8594 L .41313 .85969 L F
.682 .642 .803 r
.49092 .83906 m .49225 .8423 L .49005 .84189 L F
.72 .459 .531 r
.49005 .84189 m .49225 .8423 L .49191 .84421 L F
.537 .561 .827 r
.49447 .84202 m .49225 .8423 L .49092 .83906 L F
.316 .777 .945 r
.49476 .84211 m .49225 .8423 L .49447 .84202 L F
.57 .32 .497 r
.49191 .84421 m .49225 .8423 L .49476 .84211 L F
.779 .486 .492 r
.49336 .87504 m .49655 .87545 L .49665 .87752 L F
.707 .443 .523 r
.49655 .87545 m .49851 .87776 L .49665 .87752 L F
.505 .824 1 r
.48869 .83118 m .48785 .83205 L .48649 .83142 L F
.882 .727 .684 r
.48785 .83205 m .48768 .83437 L .48649 .83142 L F
.749 .713 .818 r
.48889 .83986 m .49005 .84189 L .48683 .84211 L F
.667 .453 .585 r
.49005 .84189 m .48686 .84437 L .48683 .84211 L F
.49005 .84189 m .49056 .8447 L .48686 .84437 L F
.682 .642 .803 r
.49092 .83906 m .49005 .84189 L .48889 .83986 L F
.644 .318 .405 r
.48686 .84437 m .49056 .8447 L .48834 .84567 L F
.074 .263 .752 r
.49005 .84189 m .48904 .84505 L .49056 .8447 L F
.49005 .84189 m .49191 .84421 L .49097 .84171 L F
.49005 .84189 m .49097 .84171 L .48904 .84505 L F
.47 .797 .999 r
.49681 .81659 m .50009 .81702 L .49893 .81654 L F
.531 .865 .994 r
.49893 .81654 m .50009 .81702 L .50188 .8165 L F
.588 .376 .561 r
.42743 .87512 m .42533 .87654 L .42575 .87556 L F
.794 .75 .813 r
.48415 .85513 m .48482 .85739 L .48078 .85597 L F
.858 .566 .491 r
.48078 .85597 m .48482 .85739 L .48399 .85962 L F
.58 .623 .859 r
.48677 .85696 m .48482 .85739 L .48415 .85513 L F
.428 .108 .32 r
.48399 .85962 m .48482 .85739 L .48677 .85696 L F
.723 .256 0 r
.49941 .86388 m .50023 .86487 L .50016 .86531 L F
.241 .232 .648 r
.50023 .86487 m .5018 .86692 L .50016 .86531 L F
.172 0 0 r
.40293 .8384 m .3995 .8394 L .40086 .83865 L F
.778 .64 .709 r
.49605 .83675 m .49781 .83371 L .49482 .83371 L F
.666 .487 .633 r
.45728 .83969 m .45728 .84187 L .45442 .84182 L F
.655 .582 .76 r
.4593 .83938 m .45728 .83969 L .45624 .83698 L F
.664 .486 .633 r
.4594 .84165 m .45728 .83969 L .4593 .83938 L F
.4594 .84165 m .45728 .84187 L .45728 .83969 L F
.658 .382 .49 r
.51738 .85994 m .51943 .86208 L .51763 .86173 L F
.66 .381 .486 r
.51738 .85994 m .51985 .86018 L .51943 .86208 L F
.658 .407 .528 r
.44704 .86691 m .44607 .86981 L .44394 .86975 L F
.624 .384 .533 r
.44919 .86721 m .44607 .86981 L .44704 .86691 L F
.311 0 .068 r
.5163 .85475 m .51311 .85689 L .51513 .85671 L F
.684 .35 .403 r
.51513 .85671 m .51835 .85672 L .5163 .85475 L F
.462 .216 .453 r
.50628 .87039 m .50853 .86806 L .50809 .86984 L F
.481 .206 .419 r
.50809 .86984 m .50853 .86806 L .51061 .86777 L F
.638 .479 .652 r
.45442 .84182 m .45235 .84429 L .45209 .84201 L F
.643 .398 .533 r
.45656 .86249 m .45848 .86466 L .45642 .86452 L F
.706 .651 .793 r
.48649 .83142 m .48768 .83437 L .48565 .83381 L F
.964 .708 .501 r
.48768 .83437 m .48451 .83634 L .48565 .83381 L F
.48768 .83437 m .48651 .83469 L .48451 .83634 L F
.48768 .83437 m .48761 .83655 L .48651 .83469 L F
.64 .323 .419 r
.48768 .83437 m .48964 .83624 L .48761 .83655 L F
.48768 .83437 m .49086 .83433 L .49039 .83506 L F
.48768 .83437 m .49039 .83506 L .48882 .83546 L F
.582 .529 .761 r
.48721 .83587 m .4883 .83308 L .48651 .83469 L F
.48761 .83655 m .48777 .83572 L .48721 .83587 L F
.48777 .83572 m .4883 .83308 L .48721 .83587 L F
.64 .323 .419 r
.48882 .83546 m .49039 .83506 L .48964 .83624 L F
.607 .784 .966 r
.49278 .85159 m .49237 .85252 L .49062 .85213 L F
.578 .352 .536 r
.41796 .88012 m .41996 .88238 L .4167 .88292 L F
.41796 .88012 m .41997 .88006 L .41996 .88238 L F
.693 .576 .719 r
.45504 .83176 m .45612 .83458 L .45303 .83428 L F
.654 .556 .732 r
.45624 .83698 m .45303 .83428 L .45612 .83458 L F
.557 .418 .648 r
.4595 .82695 m .45714 .82913 L .45688 .8277 L F
.491 .482 .774 r
.45827 .8516 m .45762 .85465 L .45558 .85395 L F
.45827 .8516 m .45967 .85539 L .45762 .85465 L F
.603 .377 .546 r
.40609 .8648 m .40826 .86468 L .40849 .86255 L F
.524 .282 .49 r
.40826 .86468 m .41029 .86246 L .40849 .86255 L F
.616 .784 .962 r
.43913 .82182 m .43717 .82237 L .43592 .82132 L F
0 0 0 r
.3953 .83984 m .39415 .84022 L .39181 .84069 L F
.135 0 0 r
.39755 .83995 m .39415 .84022 L .3953 .83984 L F
.638 .479 .652 r
.45442 .84182 m .45553 .84525 L .45235 .84429 L F
.655 .52 .687 r
.45522 .84678 m .45235 .84429 L .45553 .84525 L F
.45522 .84678 m .45319 .84736 L .45235 .84429 L F
.621 .565 .77 r
.50631 .82184 m .50845 .8213 L .50766 .81856 L F
.483 .268 .511 r
.50427 .87278 m .50628 .87039 L .50571 .87227 L F
.393 .124 .383 r
.50571 .87227 m .50628 .87039 L .50809 .86984 L F
.627 .448 .621 r
.45728 .84187 m .45553 .84525 L .45442 .84182 L F
.612 .361 .513 r
.42533 .87654 m .42201 .87997 L .42217 .87807 L F
.85 .823 .822 r
.49631 .84949 m .49278 .85159 L .49545 .85145 L F
.431 .073 .255 r
.49616 .85098 m .49631 .84949 L .49545 .85145 L F
.594 .696 .913 r
.4987 .84903 m .49889 .85009 L .49631 .84949 L F
.431 .073 .255 r
.49616 .85098 m .4987 .84903 L .49631 .84949 L F
.479 .238 .47 r
.50186 .87526 m .50427 .87278 L .50395 .87503 L F
.352 .16 .475 r
.50395 .87503 m .50427 .87278 L .50571 .87227 L F
.933 .558 .259 r
.49881 .85172 m .49889 .85009 L .4987 .84903 L F
.49881 .85172 m .50004 .85239 L .49889 .85009 L F
.548 .185 .304 r
.39877 .87215 m .40209 .87012 L .39979 .87229 L F
.39877 .87215 m .4008 .87233 L .40209 .87012 L F
.512 .477 .755 r
.40209 .87012 m .40295 .8669 L .40172 .86705 L F
.40209 .87012 m .40413 .86972 L .40295 .8669 L F
.574 .214 .319 r
.40209 .87012 m .40376 .87161 L .40413 .86972 L F
.40209 .87012 m .4008 .87233 L .40376 .87161 L F
.226 0 0 r
.40602 .83794 m .40469 .83841 L .40293 .8384 L F
.623 .371 .515 r
.45146 .86517 m .45323 .8671 L .45129 .86723 L F
.45146 .86517 m .4542 .86449 L .45323 .8671 L F
.661 .489 .642 r
.41963 .85223 m .4216 .85447 L .42186 .85208 L F
.41963 .85223 m .41967 .8546 L .4216 .85447 L F
.677 .603 .765 r
.45708 .83136 m .45612 .83458 L .45504 .83176 L F
.45708 .83136 m .45826 .83436 L .45612 .83458 L F
.67 .532 .687 r
.45826 .83436 m .45624 .83698 L .45612 .83458 L F
.721 .396 .429 r
.48703 .86993 m .4903 .87003 L .4889 .87208 L F
.821 .53 .497 r
.4889 .87208 m .4903 .87003 L .49069 .87243 L F
.202 .722 .868 r
.39679 .8723 m .39877 .87215 L .39979 .87229 L F
.616 .349 .49 r
.46183 .8642 m .46179 .86238 L .46371 .86436 L F
.634 .348 .467 r
.46179 .86238 m .4638 .86256 L .46371 .86436 L F
.612 .361 .513 r
.42533 .87654 m .42413 .88002 L .42201 .87997 L F
.588 .376 .561 r
.42743 .87512 m .42735 .87714 L .42533 .87654 L F
.614 .371 .526 r
.42735 .87714 m .42413 .88002 L .42533 .87654 L F
.59 .772 .966 r
.44231 .82247 m .43913 .82182 L .44112 .82138 L F
.578 .784 .977 r
.44317 .82101 m .44231 .82247 L .44112 .82138 L F
.44317 .82101 m .44444 .82201 L .44231 .82247 L F
.608 .348 .498 r
.46742 .86018 m .46371 .86436 L .4638 .86256 L F
.46742 .86018 m .46577 .86419 L .46371 .86436 L F
.358 .388 .755 r
.46817 .85884 m .46905 .86229 L .46742 .86018 L F
.756 .484 .521 r
.46742 .86018 m .46912 .86447 L .46577 .86419 L F
.46742 .86018 m .46905 .86229 L .46912 .86447 L F
.73 .642 .761 r
.51644 .81248 m .51458 .81148 L .51695 .81081 L F
.575 .57 .811 r
.5187 .81056 m .51644 .81248 L .51695 .81081 L F
.5187 .81056 m .51983 .81342 L .51644 .81248 L F
.686 .567 .715 r
.42086 .84672 m .42286 .84433 L .4206 .84461 L F
.42086 .84672 m .42371 .84729 L .42286 .84433 L F
.694 .551 .689 r
.42086 .84672 m .42388 .84946 L .42371 .84729 L F
.42086 .84672 m .42172 .84976 L .42388 .84946 L F
.557 .418 .648 r
.4595 .82695 m .45915 .82884 L .45714 .82913 L F
.73 .629 .746 r
.45915 .82884 m .45708 .83136 L .45714 .82913 L F
.436 .808 .994 r
.48987 .84678 m .4931 .84703 L .49188 .84649 L F
.48987 .84678 m .4931 .84703 L .49188 .84649 L F
.697 .783 .917 r
.45805 .82122 m .45482 .82101 L .4569 .82021 L F
.575 .701 .928 r
.45878 .8197 m .45805 .82122 L .4569 .82021 L F
.45878 .8197 m .46011 .82094 L .45805 .82122 L F
.751 .618 .711 r
.48478 .83471 m .48565 .83381 L .48272 .83389 L F
.706 .651 .793 r
.48509 .83411 m .48565 .83381 L .48478 .83471 L F
.73 .475 .541 r
.48272 .83389 m .48565 .83381 L .48509 .83411 L F
.775 .711 .792 r
.48649 .83142 m .48509 .83411 L .48287 .83133 L F
.48509 .83411 m .48478 .83471 L .48449 .8342 L F
.73 .475 .541 r
.48272 .83389 m .48509 .83411 L .48449 .8342 L F
.775 .711 .792 r
.48509 .83411 m .48449 .8342 L .48287 .83133 L F
.73 .475 .541 r
.48449 .8342 m .48509 .83411 L .48481 .83426 L F
.681 .675 .838 r
.48449 .8342 m .48478 .83471 L .48272 .83389 L F
.73 .475 .541 r
.48272 .83389 m .48481 .83426 L .4835 .83496 L F
.681 .675 .838 r
.48287 .83133 m .48449 .8342 L .48272 .83389 L F
.706 .651 .793 r
.48649 .83142 m .48565 .83381 L .48509 .83411 L F
.73 .475 .541 r
.4835 .83496 m .48565 .83381 L .48451 .83634 L F
.734 .623 .735 r
.45831 .83626 m .45624 .83698 L .45826 .83436 L F
.655 .582 .76 r
.4593 .83938 m .45624 .83698 L .45831 .83626 L F
.681 .567 .719 r
.46032 .83371 m .45831 .83626 L .45826 .83436 L F
.46032 .83371 m .46141 .83676 L .45831 .83626 L F
.611 .51 .715 r
.4614 .83906 m .45831 .83626 L .46141 .83676 L F
.4614 .83906 m .4593 .83938 L .45831 .83626 L F
.686 .569 .718 r
.42262 .84207 m .4206 .84461 L .42286 .84433 L F
.573 .698 .926 r
.49086 .83433 m .49333 .83483 L .49153 .83341 L F
0 0 0 r
.48964 .83624 m .49086 .83433 L .49153 .83341 L F
.523 .277 .484 r
.40327 .88798 m .40487 .88974 L .40217 .89032 L F
.40327 .88798 m .40534 .88753 L .40487 .88974 L F
.674 .559 .716 r
.49831 .85771 m .49851 .85996 L .50057 .85724 L F
.805 .433 .351 r
.49733 .86155 m .5003 .86232 L .49851 .85996 L F
.692 .148 0 r
.50153 .86213 m .49851 .85996 L .5003 .86232 L F
.696 .54 .671 r
.45317 .84935 m .45167 .84809 L .45319 .84736 L F
.45317 .84935 m .45133 .84978 L .45167 .84809 L F
.634 .596 .793 r
.42166 .83733 m .42187 .83901 L .42403 .83855 L F
.684 .545 .69 r
.42187 .83901 m .42482 .84169 L .42403 .83855 L F
.42187 .83901 m .42262 .84207 L .42482 .84169 L F
.575 .066 .005 r
.52305 .81988 m .52429 .81906 L .52618 .82009 L F
.545 .222 .371 r
.52429 .81906 m .52649 .81894 L .52618 .82009 L F
.33 .099 .405 r
.40172 .86705 m .40295 .8669 L .40322 .8652 L F
.713 .602 .73 r
.4885 .82623 m .4855 .82425 L .48898 .82434 L F
0 0 .107 r
.48913 .82514 m .48898 .82434 L .48953 .8242 L F
.48913 .82514 m .4885 .82623 L .48898 .82434 L F
.618 .873 .99 r
.41294 .82229 m .40966 .82242 L .41138 .8221 L F
.189 .716 .849 r
.41358 .822 m .41294 .82229 L .41138 .8221 L F
.41358 .822 m .41495 .82211 L .41294 .82229 L F
.811 .709 .753 r
.48475 .84696 m .48577 .84967 L .48577 .84907 L F
.817 .711 .749 r
.48475 .84696 m .48577 .84907 L .48559 .8491 L F
.766 .688 .777 r
.48576 .84954 m .48577 .84967 L .48556 .84909 L F
.48559 .8491 m .48556 .84909 L .48475 .84696 L F
.48576 .84954 m .48556 .84909 L .48559 .8491 L F
.803 .613 .644 r
.48315 .84947 m .48559 .8491 L .48281 .85168 L F
.48559 .8491 m .48577 .84907 L .4857 .84914 L F
.766 .688 .777 r
.4854 .84704 m .48576 .84954 L .48475 .84696 L F
.803 .613 .644 r
.48559 .8491 m .4857 .84914 L .48281 .85168 L F
.817 .711 .749 r
.48475 .84696 m .48559 .8491 L .48315 .84947 L F
.828 .641 .65 r
.48577 .84967 m .4857 .84914 L .48577 .84907 L F
.766 .688 .777 r
.48769 .84733 m .48577 .84967 L .4854 .84704 L F
.828 .641 .65 r
.48577 .84967 m .48281 .85168 L .4857 .84914 L F
.48577 .84967 m .48588 .85194 L .48281 .85168 L F
.675 .549 .704 r
.48769 .84733 m .48847 .84967 L .48577 .84967 L F
.669 .472 .609 r
.48577 .84967 m .4881 .85178 L .48588 .85194 L F
.48577 .84967 m .48847 .84967 L .4881 .85178 L F
.494 .176 .355 r
.50186 .87526 m .50363 .87585 L .50093 .87692 L F
.50186 .87526 m .50395 .87503 L .50363 .87585 L F
.743 .716 .826 r
.47516 .84174 m .47611 .84461 L .47299 .84407 L F
.783 .514 .53 r
.47299 .84407 m .47611 .84461 L .47615 .84667 L F
.762 .727 .819 r
.47835 .84193 m .47611 .84461 L .47516 .84174 L F
.599 .344 .503 r
.4347 .8725 m .43662 .87448 L .43529 .87399 L F
.668 .336 .402 r
.4347 .8725 m .43677 .87305 L .43662 .87448 L F
.768 .602 .673 r
.49224 .85925 m .4953 .85732 L .49234 .85758 L F
.639 .391 .527 r
.42743 .87512 m .42926 .87716 L .42735 .87714 L F
.42743 .87512 m .42939 .87516 L .42926 .87716 L F
.718 .97 .724 r
.39213 .82478 m .39257 .82372 L .39399 .82432 L F
.39213 .82478 m .39066 .82573 L .39257 .82372 L F
.898 .874 .805 r
.49176 .82909 m .48869 .83118 L .49247 .83186 L F
.059 0 .115 r
.51151 .85743 m .50922 .86016 L .51105 .8596 L F
.378 .153 .442 r
.51311 .85689 m .51151 .85743 L .51105 .8596 L F
.68 .516 .657 r
.48164 .84434 m .48189 .84663 L .47929 .84693 L F
.726 .663 .788 r
.48351 .84175 m .48164 .84434 L .48041 .8413 L F
.654 .561 .737 r
.48351 .84175 m .48499 .84461 L .48164 .84434 L F
.657 .496 .654 r
.48499 .84461 m .48189 .84663 L .48164 .84434 L F
.465 .197 .422 r
.51238 .8672 m .51423 .86364 L .51425 .8667 L F
.502 .276 .503 r
.51423 .86364 m .51763 .86173 L .51671 .86459 L F
.492 .208 .41 r
.51425 .8667 m .51423 .86364 L .51671 .86459 L F
.611 .577 .791 r
.521 .85775 m .52229 .8596 L .51985 .86018 L F
.533 .306 .516 r
.51985 .86018 m .52177 .86217 L .51943 .86208 L F
.51985 .86018 m .52229 .8596 L .52177 .86217 L F
.502 .848 .995 r
.41822 .82216 m .41495 .82211 L .41698 .8216 L F
.483 .834 .996 r
.42014 .82177 m .41822 .82216 L .41698 .8216 L F
.398 .825 .963 r
.49428 .85499 m .49746 .8549 L .49631 .85458 L F
.754 .988 .897 r
.49801 .85361 m .49746 .8549 L .49887 .85376 L F
.699 .94 .962 r
.49631 .85458 m .49746 .8549 L .49801 .85361 L F
.709 .835 .942 r
.4895 .81891 m .48638 .81888 L .48946 .81783 L F
0 0 .42 r
.48946 .81783 m .48974 .81837 L .4895 .81891 L F
.73 .202 0 r
.4895 .81891 m .49171 .82116 L .4927 .82139 L F
.675 .14 0 r
.49028 .82014 m .4895 .81891 L .48974 .81837 L F
.49028 .82014 m .49171 .82116 L .4895 .81891 L F
.596 .381 .56 r
.4542 .86449 m .45621 .8669 L .45323 .8671 L F
.4542 .86449 m .45642 .86452 L .45621 .8669 L F
.768 .602 .673 r
.49224 .85925 m .49488 .86016 L .4953 .85732 L F
.447 .872 .931 r
.40244 .82366 m .40318 .82298 L .40451 .82305 L F
.40244 .82366 m .40123 .82357 L .40318 .82298 L F
0 .162 .699 r
.49537 .86941 m .49542 .87031 L .4946 .86833 L F
.627 .835 .98 r
.49746 .86963 m .49542 .87031 L .49537 .86941 L F
.49746 .86963 m .49542 .87031 L .49537 .86941 L F
.73 .72 .841 r
.49153 .83341 m .49333 .83483 L .49482 .83371 L F
.994 .785 .412 r
.49158 .81626 m .49099 .81642 L .49118 .81341 L F
.88 .974 .666 r
.49158 .81626 m .48974 .81837 L .49099 .81642 L F
.029 .119 .624 r
.49244 .81536 m .49158 .81626 L .49118 .81341 L F
0 0 0 r
.49244 .81536 m .48974 .81837 L .49158 .81626 L F
.406 .489 .832 r
.49145 .86229 m .49415 .86473 L .49202 .86144 L F
.728 .939 .955 r
.49019 .86213 m .49145 .86229 L .49202 .86144 L F
.331 .775 .962 r
.39592 .82378 m .39928 .82403 L .39731 .82445 L F
.682 .57 .723 r
.4614 .83906 m .4594 .84165 L .4593 .83938 L F
.652 .547 .722 r
.42286 .84433 m .42371 .84729 L .42586 .84679 L F
.666 .546 .709 r
.42388 .84946 m .42586 .84679 L .42371 .84729 L F
.713 .602 .73 r
.4885 .82623 m .4854 .82675 L .4855 .82425 L F
.382 .167 .459 r
.48681 .82751 m .4854 .82675 L .4885 .82623 L F
.728 .98 .914 r
.48913 .82514 m .4885 .82623 L .49168 .8242 L F
.488 .687 .955 r
.4885 .82623 m .49084 .8264 L .48913 .82514 L F
.736 .974 .723 r
.48913 .82514 m .48681 .82751 L .4885 .82623 L F
.648 .514 .687 r
.42286 .84433 m .42482 .84169 L .42262 .84207 L F
.42286 .84433 m .42569 .84476 L .42482 .84169 L F
.652 .547 .722 r
.42286 .84433 m .42586 .84679 L .42569 .84476 L F
.632 .126 .028 r
.39181 .84069 m .3888 .8407 L .39011 .84055 L F
.79 .675 .737 r
.48341 .82643 m .48055 .8265 L .48217 .8239 L F
.612 .324 .456 r
.48341 .82643 m .48022 .8286 L .48055 .8265 L F
.48341 .82643 m .48272 .82886 L .48022 .8286 L F
.738 .655 .767 r
.4855 .82425 m .48341 .82643 L .48217 .8239 L F
.717 .429 .489 r
.48535 .82866 m .48272 .82886 L .48363 .82668 L F
.207 0 .237 r
.48419 .82819 m .48272 .82886 L .48535 .82866 L F
.48419 .82819 m .48213 .83026 L .48272 .82886 L F
.48213 .83026 m .48195 .83044 L .48272 .82886 L F
.717 .429 .489 r
.48363 .82668 m .48272 .82886 L .48341 .82643 L F
.699 .59 .73 r
.4855 .82425 m .4854 .82675 L .48341 .82643 L F
.709 .43 .5 r
.4854 .82675 m .48535 .82866 L .48341 .82643 L F
.192 .702 .896 r
.40451 .82305 m .40642 .82302 L .40764 .82331 L F
.645 .923 .976 r
.40764 .82331 m .40849 .82207 L .40966 .82242 L F
.40764 .82331 m .40642 .82302 L .40849 .82207 L F
.692 .448 .549 r
.40295 .8669 m .40609 .8648 L .40322 .8652 L F
.729 .629 .747 r
.46039 .83179 m .45826 .83436 L .45708 .83136 L F
.7 .584 .722 r
.46032 .83371 m .45826 .83436 L .46039 .83179 L F
.671 .77 .925 r
.45306 .82207 m .44961 .82159 L .45163 .8209 L F
.729 .785 .897 r
.45482 .82101 m .45306 .82207 L .45163 .8209 L F
.695 .561 .698 r
.42172 .84976 m .42186 .85208 L .42388 .84946 L F
.382 .167 .459 r
.48681 .82751 m .48535 .82866 L .4854 .82675 L F
.628 .799 .965 r
.44767 .82232 m .44444 .82201 L .44647 .82134 L F
.653 .803 .955 r
.44961 .82159 m .44767 .82232 L .44647 .82134 L F
.267 0 .091 r
.51105 .8596 m .50922 .86016 L .50824 .86121 L F
.691 .523 .654 r
.45317 .84935 m .45112 .85205 L .45133 .84978 L F
.66 .538 .704 r
.45522 .84678 m .45317 .84935 L .45319 .84736 L F
.682 .73 .887 r
.46544 .82119 m .46381 .82249 L .46206 .82063 L F
.689 .519 .652 r
.45318 .85143 m .45112 .85205 L .45317 .84935 L F
.64 .509 .687 r
.45522 .84678 m .45761 .85156 L .45317 .84935 L F
.658 .524 .689 r
.45761 .85156 m .45318 .85143 L .45317 .84935 L F
.71 .694 .832 r
.47627 .86011 m .47758 .86238 L .47431 .86213 L F
.689 .464 .576 r
.47577 .86322 m .47745 .86451 L .47753 .86653 L F
.731 .483 .553 r
.47431 .86213 m .47745 .86451 L .47577 .86322 L F
.47431 .86213 m .47758 .86238 L .47745 .86451 L F
.57 .792 .983 r
.47846 .86095 m .47758 .86238 L .47627 .86011 L F
.47846 .86095 m .47968 .86197 L .47758 .86238 L F
.68 .513 .653 r
.47968 .86197 m .47745 .86451 L .47758 .86238 L F
.644 .318 .405 r
.48686 .84437 m .48834 .84567 L .48769 .84733 L F
0 .107 .629 r
.48686 .84437 m .48769 .84733 L .48793 .84664 L F
.766 .688 .777 r
.48769 .84733 m .48475 .84696 L .48793 .84664 L F
0 0 .331 r
.48827 .84881 m .48847 .84967 L .48769 .84733 L F
.48853 .84948 m .48849 .84959 L .48827 .84881 L F
.48849 .84959 m .48847 .84967 L .48827 .84881 L F
.835 .437 .291 r
.48736 .84913 m .48853 .84948 L .4878 .84759 L F
.565 .304 .479 r
.48769 .84733 m .48987 .84678 L .48853 .84948 L F
.835 .437 .291 r
.48736 .84913 m .48769 .84733 L .48834 .84567 L F
.658 .453 .594 r
.48686 .84437 m .48793 .84664 L .48475 .84696 L F
.97 .81 .627 r
.48736 .84913 m .48785 .84738 L .48709 .84525 L F
.48785 .84738 m .48834 .84567 L .48725 .84531 L F
.48785 .84738 m .48725 .84531 L .48709 .84525 L F
.568 .362 .56 r
.44189 .86984 m .44389 .87189 L .44244 .87166 L F
.44189 .86984 m .44394 .86975 L .44389 .87189 L F
.682 .579 .734 r
.46354 .83447 m .46141 .83676 L .46032 .83371 L F
.46354 .83447 m .46359 .83665 L .46141 .83676 L F
.662 .481 .629 r
.46344 .83858 m .46141 .83676 L .46359 .83665 L F
.46344 .83858 m .4614 .83906 L .46141 .83676 L F
.692 .448 .549 r
.40295 .8669 m .40627 .86748 L .40609 .8648 L F
.733 .551 .646 r
.40627 .86748 m .40826 .86468 L .40609 .8648 L F
.743 .614 .714 r
.48569 .83903 m .48683 .84211 L .48351 .84175 L F
.747 .599 .693 r
.48683 .84211 m .48499 .84461 L .48351 .84175 L F
.48683 .84211 m .48686 .84437 L .48499 .84461 L F
.664 .572 .742 r
.48889 .83986 m .48683 .84211 L .48569 .83903 L F
.624 .27 .35 r
.40789 .83671 m .40654 .83889 L .40469 .83841 L F
.687 .344 .389 r
.40909 .83768 m .40654 .83889 L .40789 .83671 L F
.619 .28 .374 r
.40773 .88581 m .40943 .88758 L .40735 .88747 L F
.615 .449 .634 r
.42388 .84946 m .42186 .85208 L .42378 .85182 L F
.685 .552 .697 r
.4216 .85447 m .42378 .85182 L .42186 .85208 L F
.68 .535 .682 r
.46274 .83115 m .46032 .83371 L .46039 .83179 L F
.46274 .83115 m .46354 .83447 L .46032 .83371 L F
.666 .546 .709 r
.42388 .84946 m .4269 .84983 L .42586 .84679 L F
.726 .606 .723 r
.42378 .85182 m .4269 .84983 L .42388 .84946 L F
.627 .448 .621 r
.45728 .84187 m .4573 .84435 L .45553 .84525 L F
.662 .477 .623 r
.4594 .84165 m .4573 .84435 L .45728 .84187 L F
.728 .627 .745 r
.46274 .83115 m .46039 .83179 L .4624 .82936 L F
.6 .54 .759 r
.4648 .83068 m .46274 .83115 L .4624 .82936 L F
.696 .594 .738 r
.4648 .83068 m .46354 .83447 L .46274 .83115 L F
.743 .726 .836 r
.48853 .84948 m .49062 .85213 L .4881 .85178 L F
.774 .655 .732 r
.49062 .85213 m .48916 .85554 L .4881 .85178 L F
.262 .771 .791 r
.48975 .85217 m .49062 .85213 L .48853 .84948 L F
.48975 .85217 m .49278 .85159 L .49062 .85213 L F
.644 .885 .984 r
.41707 .83578 m .41514 .83655 L .41853 .83635 L F
.464 .77 .996 r
.41853 .83635 m .41934 .83534 L .41707 .83578 L F
.41853 .83635 m .42042 .83615 L .41934 .83534 L F
0 .371 .819 r
.48712 .86504 m .48928 .86686 L .48894 .86619 L F
.646 .522 .698 r
.48712 .86504 m .48894 .86619 L .48877 .86629 L F
.117 0 0 r
.48869 .86621 m .48876 .86628 L .48712 .86504 L F
.48876 .86628 m .48928 .86686 L .48751 .86537 L F
.602 .433 .625 r
.48659 .86751 m .48877 .86629 L .48568 .86952 L F
.48877 .86629 m .48894 .86619 L .48881 .86632 L F
.48877 .86629 m .48881 .86632 L .48568 .86952 L F
.117 0 0 r
.48876 .86628 m .48876 .86628 L .48712 .86504 L F
.48876 .86628 m .48751 .86537 L .48712 .86504 L F
.646 .522 .698 r
.48712 .86504 m .48877 .86629 L .48659 .86751 L F
.894 .989 .761 r
.48881 .86632 m .48703 .86993 L .48568 .86952 L F
.48894 .86619 m .48886 .86636 L .48881 .86632 L F
.48886 .86636 m .48703 .86993 L .48881 .86632 L F
.117 0 0 r
.48879 .86627 m .48886 .86636 L .48869 .86621 L F
.48886 .86636 m .48928 .86686 L .48869 .86621 L F
.894 .989 .761 r
.48891 .86626 m .48928 .86686 L .48886 .86636 L F
.48894 .86619 m .48897 .86625 L .48891 .86626 L F
.48897 .86625 m .48928 .86686 L .48891 .86626 L F
.117 0 0 r
.48981 .86704 m .48928 .86686 L .48879 .86627 L F
.894 .989 .761 r
.48886 .86636 m .48928 .86686 L .48703 .86993 L F
.711 .179 0 r
.48812 .86644 m .48981 .86704 L .48879 .86627 L F
.48807 .86638 m .48879 .86627 L .48712 .86504 L F
.48812 .86644 m .48879 .86627 L .48807 .86638 L F
.117 0 0 r
.48981 .86704 m .49138 .86692 L .48928 .86686 L F
.626 .348 .477 r
.41273 .88268 m .41467 .88469 L .41281 .88525 L F
.41273 .88268 m .41482 .88284 L .41467 .88469 L F
.764 .464 .477 r
.47615 .84667 m .47929 .84693 L .47914 .84917 L F
.758 .537 .598 r
.48189 .84663 m .47914 .84917 L .47929 .84693 L F
.611 .805 .974 r
.42866 .82212 m .42546 .82167 L .42737 .82109 L F
.569 .78 .978 r
.4307 .82167 m .42866 .82212 L .42737 .82109 L F
.715 .622 .752 r
.4881 .85178 m .48916 .85554 L .4871 .85488 L F
.757 .507 .554 r
.4871 .85488 m .48916 .85554 L .48795 .85634 L F
.69 .468 .581 r
.49902 .81226 m .50091 .8133 L .50101 .81108 L F
.247 .733 .926 r
.49977 .81044 m .50301 .81072 L .50101 .81108 L F
.504 .504 .789 r
.50091 .8133 m .49977 .81044 L .50101 .81108 L F
.284 .535 .914 r
.46655 .85668 m .46558 .85766 L .46455 .85697 L F
.46655 .85668 m .46817 .85884 L .46558 .85766 L F
.818 .616 .629 r
.48588 .85194 m .48254 .85414 L .48281 .85168 L F
.48588 .85194 m .48666 .85408 L .48254 .85414 L F
.756 .587 .667 r
.48588 .85194 m .4871 .85488 L .48666 .85408 L F
.715 .622 .752 r
.4881 .85178 m .4871 .85488 L .48588 .85194 L F
.766 .721 .81 r
.46854 .82132 m .46544 .82119 L .46714 .82032 L F
.64 .425 .575 r
.46854 .82132 m .46672 .82335 L .46544 .82119 L F
.46854 .82132 m .46874 .82385 L .46672 .82335 L F
.661 .723 .895 r
.4704 .82074 m .46854 .82132 L .46714 .82032 L F
.771 .524 .561 r
.47143 .82384 m .46874 .82385 L .46854 .82132 L F
.743 .726 .836 r
.48853 .84948 m .4881 .85178 L .48847 .84967 L F
.891 .877 .815 r
.49887 .85376 m .50004 .85239 L .49881 .85172 L F
.676 .697 .862 r
.51345 .8103 m .51458 .81148 L .5114 .81086 L F
.55 .906 .968 r
.51774 .81029 m .51458 .81148 L .51345 .8103 L F
.51774 .81029 m .51695 .81081 L .51458 .81148 L F
.437 .039 .185 r
.49627 .86464 m .49843 .86432 L .49723 .86619 L F
.585 .738 .949 r
.49851 .86469 m .49843 .86432 L .49801 .86407 L F
.49938 .86578 m .49723 .86619 L .49843 .86432 L F
.49938 .86578 m .49843 .86432 L .49851 .86469 L F
.679 .92 .973 r
.49627 .86464 m .49839 .86413 L .49843 .86432 L F
.49839 .86413 m .49941 .86388 L .49843 .86432 L F
.658 .179 .104 r
.49843 .86432 m .49941 .86388 L .50016 .86531 L F
.829 .55 .517 r
.50559 .84437 m .50273 .84216 L .50255 .84392 L F
.676 .751 .908 r
.52195 .81277 m .52298 .81387 L .51983 .81342 L F
.636 .748 .929 r
.52403 .81227 m .52298 .81387 L .52195 .81277 L F
.52403 .81227 m .52509 .81336 L .52298 .81387 L F
.504 .547 .834 r
.52594 .81654 m .52298 .81387 L .52509 .81336 L F
.658 .453 .594 r
.48686 .84437 m .48475 .84696 L .48499 .84461 L F
.416 .722 .988 r
.49292 .8674 m .49208 .86798 L .49138 .86692 L F
.424 .004 .135 r
.4938 .86679 m .49415 .86473 L .49292 .8674 L F
.417 0 0 r
.49292 .8674 m .49138 .86692 L .48981 .86704 L F
.49292 .8674 m .48981 .86704 L .48977 .86904 L F
.428 .85 .701 r
.49374 .86683 m .49292 .8674 L .48977 .86904 L F
.4938 .86679 m .49292 .8674 L .49374 .86683 L F
.416 .722 .988 r
.49292 .8674 m .49223 .8682 L .49208 .86798 L F
.49292 .8674 m .4946 .86833 L .49223 .8682 L F
.702 .677 .823 r
.50953 .81183 m .50614 .81111 L .50822 .81056 L F
.729 .715 .837 r
.5114 .81086 m .50953 .81183 L .50822 .81056 L F
.73 .629 .746 r
.45915 .82884 m .46039 .83179 L .45708 .83136 L F
.729 .628 .746 r
.4624 .82936 m .46039 .83179 L .45915 .82884 L F
.567 .765 .972 r
.47389 .82138 m .4704 .82074 L .47262 .82036 L F
.549 .319 .518 r
.47389 .82138 m .47356 .82366 L .47143 .82384 L F
.413 .429 .767 r
.47499 .8187 m .47389 .82138 L .47262 .82036 L F
.47499 .8187 m .47572 .82155 L .47389 .82138 L F
.423 .395 .723 r
.47572 .82155 m .47595 .82322 L .47389 .82138 L F
.63 .391 .537 r
.47595 .82322 m .47356 .82366 L .47389 .82138 L F
.47595 .82322 m .47356 .82366 L .47389 .82138 L F
.419 .526 .86 r
.50197 .84333 m .50255 .84392 L .50273 .84216 L F
.681 .58 .736 r
.42403 .83855 m .42482 .84169 L .42673 .83912 L F
.643 .527 .707 r
.42482 .84169 m .42735 .84151 L .42673 .83912 L F
.664 .524 .683 r
.42482 .84169 m .42778 .84425 L .42735 .84151 L F
.42482 .84169 m .42569 .84476 L .42778 .84425 L F
.761 .618 .701 r
.49153 .83341 m .49534 .83173 L .49247 .83186 L F
.49153 .83341 m .49482 .83371 L .49534 .83173 L F
.738 .655 .767 r
.4855 .82425 m .48217 .8239 L .48415 .82304 L F
.662 .581 .754 r
.49932 .84116 m .50197 .84333 L .50273 .84216 L F
.622 .83 .98 r
.42546 .82167 m .42345 .8223 L .42223 .82151 L F
.858 .694 .678 r
.48913 .82514 m .49084 .8264 L .49168 .8242 L F
.718 .367 .382 r
.48953 .8242 m .48913 .82514 L .49168 .8242 L F
.602 .36 .523 r
.42939 .87516 m .43137 .87724 L .42926 .87716 L F
.625 .359 .495 r
.43166 .87524 m .43137 .87724 L .42939 .87516 L F
.486 .698 .962 r
.49681 .81659 m .49768 .8153 L .49603 .81431 L F
.49681 .81659 m .49893 .81654 L .49768 .8153 L F
.695 .59 .734 r
.46555 .83383 m .46359 .83665 L .46354 .83447 L F
.664 .546 .711 r
.46555 .83383 m .46675 .83685 L .46359 .83665 L F
.703 .555 .684 r
.46675 .83685 m .46344 .83858 L .46359 .83665 L F
.524 .282 .49 r
.40826 .86468 m .41022 .86435 L .41029 .86246 L F
.628 .393 .542 r
.41022 .86435 m .41298 .86178 L .41029 .86246 L F
.576 .36 .551 r
.4174 .85674 m .41969 .85709 L .41967 .8546 L F
.674 .439 .556 r
.41967 .8546 m .42161 .85636 L .4216 .85447 L F
.41967 .8546 m .41969 .85709 L .42161 .85636 L F
.643 .632 .825 r
.45683 .85267 m .45558 .85395 L .45139 .85196 L F
.785 .981 .905 r
.45827 .8516 m .45558 .85395 L .45683 .85267 L F
.722 .607 .728 r
.4812 .83152 m .48272 .83389 L .48197 .83378 L F
.585 .335 .504 r
.48272 .83389 m .47934 .83649 L .48197 .83378 L F
.48272 .83389 m .48238 .83662 L .47934 .83649 L F
.681 .675 .838 r
.48287 .83133 m .48272 .83389 L .4812 .83152 L F
.577 .297 .454 r
.47934 .83649 m .48238 .83662 L .48075 .83794 L F
.865 .828 .81 r
.48153 .83704 m .48238 .83662 L .48272 .83568 L F
.48075 .83794 m .48238 .83662 L .48153 .83704 L F
.741 .476 .529 r
.48272 .83389 m .48409 .83576 L .48238 .83662 L F
.48409 .83576 m .48451 .83634 L .48238 .83662 L F
.784 .676 .744 r
.4626 .84227 m .46249 .8444 L .46103 .84483 L F
.779 .65 .72 r
.46249 .8444 m .46043 .8468 L .46103 .84483 L F
.589 .374 .557 r
.46249 .8444 m .46252 .84657 L .46043 .8468 L F
.704 .606 .745 r
.46458 .84158 m .46249 .8444 L .4626 .84227 L F
.674 .564 .723 r
.466 .84325 m .46249 .8444 L .46458 .84158 L F
.665 .473 .615 r
.466 .84325 m .46252 .84657 L .46249 .8444 L F
.802 .788 .839 r
.48254 .85414 m .48666 .85408 L .48415 .85513 L F
.58 .623 .859 r
.48677 .85696 m .48666 .85408 L .4871 .85488 L F
.48677 .85696 m .48415 .85513 L .48666 .85408 L F
.616 .806 .973 r
.42042 .83615 m .42363 .83653 L .42219 .83559 L F
.75 .704 .808 r
.42042 .83615 m .42166 .83733 L .42363 .83653 L F
.634 .596 .793 r
.42166 .83733 m .42403 .83855 L .42363 .83653 L F
.604 .802 .976 r
.42219 .83559 m .42363 .83653 L .42629 .83644 L F
.7 .613 .757 r
.42363 .83653 m .42662 .83676 L .42629 .83644 L F
.695 .535 .665 r
.42403 .83855 m .42662 .83676 L .42363 .83653 L F
.758 .537 .598 r
.48189 .84663 m .48315 .84947 L .47914 .84917 L F
.657 .496 .654 r
.48499 .84461 m .48475 .84696 L .48189 .84663 L F
.817 .711 .749 r
.48475 .84696 m .48315 .84947 L .48189 .84663 L F
.757 .507 .554 r
.4871 .85488 m .48795 .85634 L .48677 .85696 L F
.59 .339 .504 r
.52845 .81755 m .52649 .81894 L .5288 .8183 L F
.456 .14 .341 r
.52755 .81856 m .52649 .81894 L .52845 .81755 L F
.52618 .82009 m .52649 .81894 L .52755 .81856 L F
.67 .842 .966 r
.52749 .81858 m .52649 .81894 L .5263 .81884 L F
.426 .246 .533 r
.52841 .81837 m .53047 .82061 L .52827 .82072 L F
.52845 .81755 m .52889 .81821 L .52856 .81832 L F
.424 .265 .56 r
.52845 .81755 m .5288 .8183 L .53042 .8178 L F
.432 .848 .962 r
.53042 .8178 m .52903 .81823 L .52901 .81822 L F
.426 .246 .533 r
.52891 .81825 m .53042 .8178 L .53047 .82061 L F
.52845 .81755 m .53042 .8178 L .52891 .81825 L F
.432 .848 .962 r
.53042 .8178 m .52901 .81822 L .52783 .81786 L F
.52903 .81823 m .5288 .8183 L .52877 .81828 L F
.426 .246 .533 r
.52845 .81755 m .52856 .81832 L .52841 .81835 L F
.432 .848 .962 r
.52903 .81823 m .52877 .81828 L .52783 .81786 L F
.426 .246 .533 r
.52841 .81835 m .52856 .81832 L .52841 .81837 L F
.52889 .81821 m .53047 .82061 L .52841 .81837 L F
.67 .842 .966 r
.52826 .81842 m .52649 .81894 L .52749 .81858 L F
.5288 .8183 m .52744 .81868 L .52826 .81842 L F
.52744 .81868 m .52649 .81894 L .52826 .81842 L F
.456 .14 .341 r
.52755 .81856 m .52845 .81755 L .52841 .81837 L F
.67 .842 .966 r
.52874 .81829 m .5263 .81884 L .52483 .81804 L F
.5288 .8183 m .5263 .81884 L .52874 .81829 L F
.456 .14 .341 r
.52618 .82009 m .52755 .81856 L .52827 .82072 L F
.52755 .81856 m .52841 .81837 L .52827 .82072 L F
.695 .535 .665 r
.42403 .83855 m .42673 .83912 L .42662 .83676 L F
.675 .612 .777 r
.42629 .83644 m .42662 .83676 L .42888 .83652 L F
.665 .511 .666 r
.42662 .83676 m .42673 .83912 L .42888 .83652 L F
0 0 0 r
.48434 .84095 m .48569 .83903 L .48351 .84175 L F
.664 .572 .742 r
.48889 .83986 m .48569 .83903 L .48744 .83915 L F
.741 .521 .595 r
.48434 .84095 m .48744 .83915 L .48569 .83903 L F
.586 .819 .988 r
.43398 .82196 m .4307 .82167 L .43269 .82113 L F
.619 .828 .981 r
.43592 .82132 m .43398 .82196 L .43269 .82113 L F
.797 .646 .694 r
.4812 .83152 m .48197 .83378 L .47782 .83372 L F
.795 .687 .746 r
.48197 .83378 m .47934 .83649 L .47782 .83372 L F
.39 .409 .76 r
.52786 .81593 m .52594 .81654 L .52509 .81336 L F
.076 0 0 r
.52483 .81804 m .52594 .81654 L .52786 .81593 L F
.722 .56 .67 r
.4594 .84165 m .46103 .84483 L .4573 .84435 L F
.682 .57 .723 r
.4614 .83906 m .4626 .84227 L .4594 .84165 L F
.784 .676 .744 r
.4626 .84227 m .46103 .84483 L .4594 .84165 L F
.775 .392 .33 r
.49516 .86161 m .49488 .86016 L .49224 .85925 L F
.694 .6 .747 r
.4573 .84435 m .45522 .84678 L .45553 .84525 L F
.667 .559 .724 r
.4573 .84435 m .45918 .84778 L .45522 .84678 L F
.599 .436 .631 r
.45918 .84778 m .45761 .85156 L .45522 .84678 L F
.585 .355 .534 r
.41997 .88006 m .42178 .8821 L .41996 .88238 L F
.41997 .88006 m .42201 .87997 L .42178 .8821 L F
.769 .381 .32 r
.48703 .86993 m .486 .8717 L .48568 .86952 L F
.48703 .86993 m .4889 .87208 L .486 .8717 L F
.891 .877 .815 r
.49887 .85376 m .49881 .85172 L .49801 .85361 L F
.283 .758 .935 r
.39572 .87203 m .39877 .87215 L .39679 .8723 L F
.352 .259 .609 r
.46434 .8543 m .46337 .85648 L .46179 .85444 L F
.46434 .8543 m .46455 .85697 L .46337 .85648 L F
.604 .802 .976 r
.42219 .83559 m .42629 .83644 L .42403 .8348 L F
.642 .794 .955 r
.42403 .8348 m .42629 .83644 L .42768 .8359 L F
.675 .612 .777 r
.42629 .83644 m .42888 .83652 L .42768 .8359 L F
.57 .32 .497 r
.49191 .84421 m .49476 .84211 L .49447 .84202 L F
.74 .652 .762 r
.47376 .86015 m .47431 .86213 L .47133 .86192 L F
.765 .562 .623 r
.47431 .86213 m .4726 .86468 L .47133 .86192 L F
.47431 .86213 m .47429 .86475 L .4726 .86468 L F
.731 .534 .625 r
.47431 .86213 m .47577 .86322 L .47429 .86475 L F
.71 .694 .832 r
.47627 .86011 m .47431 .86213 L .47376 .86015 L F
.731 .622 .737 r
.46124 .82626 m .4624 .82936 L .45915 .82884 L F
.709 .611 .745 r
.4644 .82874 m .4624 .82936 L .46124 .82626 L F
.6 .54 .759 r
.4648 .83068 m .4624 .82936 L .4644 .82874 L F
.405 0 0 r
.38662 .82631 m .38711 .82628 L .38672 .82625 L F
.494 .679 .948 r
.5187 .81056 m .51695 .81081 L .51774 .81029 L F
.531 .865 .994 r
.49893 .81654 m .50188 .8165 L .5009 .8158 L F
.46 .672 .956 r
.50188 .8165 m .50292 .8153 L .5009 .8158 L F
.50188 .8165 m .50387 .81656 L .50292 .8153 L F
.726 .606 .723 r
.42378 .85182 m .42696 .85195 L .4269 .84983 L F
.727 .571 .679 r
.42378 .85182 m .42489 .85443 L .42696 .85195 L F
.69 .517 .648 r
.42489 .85443 m .42674 .85476 L .42696 .85195 L F
.704 .589 .724 r
.4269 .84983 m .42696 .85195 L .429 .84934 L F
.65 .511 .681 r
.42696 .85195 m .42911 .85187 L .429 .84934 L F
.615 .435 .616 r
.42674 .85476 m .42911 .85187 L .42696 .85195 L F
.624 .384 .533 r
.44919 .86721 m .44942 .86912 L .44607 .86981 L F
.615 .373 .528 r
.44919 .86721 m .45122 .86926 L .44942 .86912 L F
.44919 .86721 m .45129 .86723 L .45122 .86926 L F
.677 .576 .735 r
.42569 .84476 m .42586 .84679 L .42778 .84425 L F
.652 .541 .715 r
.42778 .84425 m .42586 .84679 L .42801 .84639 L F
.699 .564 .699 r
.42586 .84679 m .429 .84934 L .42801 .84639 L F
.42586 .84679 m .4269 .84983 L .429 .84934 L F
.598 .394 .576 r
.41512 .8594 m .41776 .85924 L .4174 .85674 L F
.722 .48 .56 r
.4174 .85674 m .41961 .85921 L .41969 .85709 L F
.4174 .85674 m .41776 .85924 L .41961 .85921 L F
.793 .794 .852 r
.50845 .8213 m .50931 .81811 L .50766 .81856 L F
.50845 .8213 m .51086 .81914 L .50931 .81811 L F
.697 .644 .792 r
.45139 .85196 m .45112 .85205 L .45318 .85143 L F
.658 .524 .689 r
.45761 .85156 m .45683 .85267 L .45318 .85143 L F
.643 .632 .825 r
.45683 .85267 m .45139 .85196 L .45318 .85143 L F
.616 .784 .962 r
.43913 .82182 m .43592 .82132 L .43793 .8207 L F
.593 .759 .958 r
.44112 .82138 m .43913 .82182 L .43793 .8207 L F
.652 .788 .947 r
.51059 .80983 m .5114 .81086 L .50822 .81056 L F
.668 .794 .942 r
.51345 .8103 m .5114 .81086 L .51059 .80983 L F
.74 .63 .737 r
.47482 .82866 m .47168 .82619 L .47381 .82549 L F
.47482 .82866 m .47296 .82894 L .47168 .82619 L F
.707 .518 .63 r
.47482 .82866 m .47282 .83124 L .47296 .82894 L F
.47482 .82866 m .47603 .83144 L .47282 .83124 L F
.686 .638 .796 r
.47698 .82623 m .47482 .82866 L .47381 .82549 L F
.659 .595 .772 r
.47698 .82623 m .47808 .82914 L .47482 .82866 L F
.759 .626 .713 r
.47808 .82914 m .47603 .83144 L .47482 .82866 L F
.709 .611 .745 r
.4644 .82874 m .46124 .82626 L .4641 .82699 L F
.638 .547 .735 r
.46667 .82649 m .4644 .82874 L .4641 .82699 L F
.707 .664 .804 r
.46822 .82816 m .4644 .82874 L .46667 .82649 L F
.58 .332 .505 r
.46822 .82816 m .4648 .83068 L .4644 .82874 L F
.732 .676 .796 r
.49902 .81226 m .49593 .81364 L .49775 .81361 L F
.496 .209 .408 r
.49603 .81431 m .49775 .81361 L .49593 .81364 L F
.696 .594 .738 r
.4648 .83068 m .46555 .83383 L .46354 .83447 L F
.852 .598 .553 r
.49069 .87243 m .49336 .87504 L .49082 .87409 L F
.84 .568 .526 r
.49082 .87409 m .49336 .87504 L .49176 .87674 L F
.814 .525 .5 r
.49176 .87674 m .49336 .87504 L .49374 .87745 L F
.779 .486 .492 r
.49336 .87504 m .49665 .87752 L .49374 .87745 L F
.711 .6 .731 r
.46985 .82708 m .4695 .82891 L .46822 .82816 L F
.722 .481 .562 r
.4695 .82891 m .46671 .83053 L .46822 .82816 L F
.4695 .82891 m .4695 .83089 L .46671 .83053 L F
.635 .526 .713 r
.47168 .82619 m .4695 .82891 L .46985 .82708 L F
.691 .608 .759 r
.47168 .82619 m .47296 .82894 L .4695 .82891 L F
.733 .55 .644 r
.47296 .82894 m .4695 .83089 L .4695 .82891 L F
.663 .599 .773 r
.47168 .82619 m .46874 .82385 L .47143 .82384 L F
.571 .417 .633 r
.47356 .82366 m .47168 .82619 L .47143 .82384 L F
.739 .577 .673 r
.49019 .86213 m .49224 .85925 L .49003 .85963 L F
.428 .108 .32 r
.48399 .85962 m .48677 .85696 L .48593 .85885 L F
.332 .781 .625 r
.48677 .85696 m .4863 .85923 L .48593 .85885 L F
.48677 .85696 m .48795 .85634 L .48791 .85636 L F
.48677 .85696 m .48791 .85636 L .4863 .85923 L F
.781 .644 .71 r
.47711 .83888 m .47835 .84193 L .47516 .84174 L F
.682 .679 .841 r
.47921 .83816 m .47835 .84193 L .47711 .83888 L F
.47921 .83816 m .48041 .8413 L .47835 .84193 L F
.727 .787 .9 r
.45482 .82101 m .45163 .8209 L .45343 .81992 L F
.703 .783 .914 r
.4569 .82021 m .45482 .82101 L .45343 .81992 L F
.625 .379 .525 r
.47429 .86475 m .47577 .86322 L .47414 .86694 L F
.689 .464 .576 r
.47577 .86322 m .47753 .86653 L .47414 .86694 L F
.732 .647 .764 r
.48234 .83887 m .48351 .84175 L .48041 .8413 L F
.175 .315 .768 r
.48434 .84095 m .48351 .84175 L .48234 .83887 L F
.243 .753 .867 r
.3854 .82631 m .38711 .82628 L .38662 .82631 L F
.685 .552 .697 r
.4216 .85447 m .42489 .85443 L .42378 .85182 L F
.693 .495 .615 r
.42161 .85636 m .42489 .85443 L .4216 .85447 L F
.726 .626 .747 r
.48022 .8286 m .4812 .83152 L .4779 .8314 L F
.797 .646 .694 r
.4812 .83152 m .47782 .83372 L .4779 .8314 L F
.132 .251 .721 r
.48195 .83044 m .4812 .83152 L .48022 .8286 L F
.745 .496 .554 r
.48016 .8332 m .48287 .83133 L .4812 .83152 L F
.48016 .8332 m .4812 .83152 L .48195 .83044 L F
.58 .332 .505 r
.46822 .82816 m .46671 .83053 L .4648 .83068 L F
.711 .6 .731 r
.46985 .82708 m .46822 .82816 L .46667 .82649 L F
0 .283 .649 r
.51319 .81734 m .51582 .81857 L .51493 .81633 L F
.468 .239 .483 r
.51748 .81863 m .51809 .81619 L .51582 .81857 L F
.829 .804 .828 r
.51582 .81857 m .51694 .81489 L .51493 .81633 L F
.51582 .81857 m .51809 .81619 L .51694 .81489 L F
.658 .57 .744 r
.42801 .84639 m .429 .84934 L .43117 .8487 L F
.67 .544 .702 r
.42911 .85187 m .43117 .8487 L .429 .84934 L F
.775 .711 .792 r
.48649 .83142 m .48287 .83133 L .48504 .83243 L F
.711 .584 .712 r
.48504 .83243 m .48869 .83118 L .48649 .83142 L F
.582 .529 .761 r
.48761 .83655 m .48964 .83624 L .4883 .83308 L F
.664 .628 .803 r
.49415 .86473 m .49516 .86161 L .49202 .86144 L F
.49415 .86473 m .49675 .8642 L .49516 .86161 L F
.695 .577 .719 r
.46458 .84158 m .4626 .84227 L .4614 .83906 L F
.69 .468 .581 r
.49902 .81226 m .49775 .81361 L .50091 .8133 L F
.736 .395 .405 r
.50048 .86412 m .50153 .86213 L .5003 .86232 L F
.649 .333 .422 r
.50076 .86476 m .50153 .86213 L .50048 .86412 L F
.50076 .86476 m .50373 .86218 L .50153 .86213 L F
.656 .512 .676 r
.46124 .82626 m .45915 .82884 L .4595 .82695 L F
.869 .664 .624 r
.49271 .85342 m .49428 .85499 L .49278 .85159 L F
.565 .829 .995 r
.4909 .85467 m .49428 .85499 L .49271 .85342 L F
.559 .527 .776 r
.49278 .85159 m .49428 .85499 L .49631 .85458 L F
.709 .713 .851 r
.50513 .81043 m .50614 .81111 L .50301 .81072 L F
.673 .713 .879 r
.50822 .81056 m .50614 .81111 L .50513 .81043 L F
.243 .753 .867 r
.3854 .82631 m .38871 .82614 L .38711 .82628 L F
.636 .47 .641 r
.42888 .83652 m .42673 .83912 L .42904 .83886 L F
.447 .538 .857 r
.42888 .83652 m .42945 .8341 L .42768 .8359 L F
.42888 .83652 m .43053 .83635 L .42945 .8341 L F
.446 .395 .707 r
.42888 .83652 m .43091 .83858 L .43053 .83635 L F
.556 .409 .637 r
.42904 .83886 m .43091 .83858 L .42888 .83652 L F
.677 .599 .761 r
.47108 .85997 m .46905 .86229 L .46817 .85884 L F
.69 .62 .773 r
.47108 .85997 m .47133 .86192 L .46905 .86229 L F
.74 .534 .615 r
.47133 .86192 m .46912 .86447 L .46905 .86229 L F
.628 .55 .748 r
.46777 .83188 m .46555 .83383 L .4648 .83068 L F
.66 .608 .785 r
.46777 .83188 m .46869 .83443 L .46555 .83383 L F
.713 .571 .693 r
.46876 .83641 m .46555 .83383 L .46869 .83443 L F
.46876 .83641 m .46675 .83685 L .46555 .83383 L F
.438 .668 .96 r
.51694 .81489 m .51809 .81619 L .51898 .815 L F
0 0 .088 r
.51898 .815 m .51809 .81619 L .51748 .81863 L F
.75 .646 .745 r
.46874 .82385 m .46985 .82708 L .46667 .82649 L F
.663 .599 .773 r
.47168 .82619 m .46985 .82708 L .46874 .82385 L F
.563 .294 .467 r
.41467 .88469 m .41482 .88284 L .41666 .88455 L F
.597 .288 .416 r
.41482 .88284 m .4167 .88292 L .41666 .88455 L F
.551 .29 .474 r
.40534 .88753 m .40689 .88965 L .40487 .88974 L F
.40534 .88753 m .40735 .88747 L .40689 .88965 L F
.31 0 .015 r
.48928 .84052 m .49092 .83906 L .48889 .83986 L F
.886 .631 .548 r
.48928 .84052 m .49097 .84171 L .49092 .83906 L F
.537 .561 .827 r
.49447 .84202 m .49092 .83906 L .49097 .84171 L F
.761 .7 .794 r
.49191 .84421 m .49447 .84202 L .49097 .84171 L F
.733 .55 .644 r
.47296 .82894 m .47282 .83124 L .4695 .83089 L F
.728 .582 .692 r
.46043 .8468 m .4573 .84435 L .46103 .84483 L F
.481 .206 .419 r
.50809 .86984 m .51061 .86777 L .5098 .86933 L F
.339 .012 .256 r
.5098 .86933 m .51061 .86777 L .51238 .8672 L F
.629 .471 .649 r
.46874 .82385 m .46667 .82649 L .46672 .82335 L F
.93 .695 .562 r
.49118 .81341 m .48925 .81515 L .48912 .81293 L F
.49118 .81341 m .49099 .81642 L .48925 .81515 L F
.893 .682 .61 r
.48951 .8107 m .48912 .81293 L .49118 .81341 L F
.772 .518 .551 r
.48912 .81293 m .49244 .81536 L .49118 .81341 L F
.695 .577 .719 r
.46458 .84158 m .4614 .83906 L .46344 .83858 L F
.59 .494 .714 r
.42673 .83912 m .42936 .84101 L .42904 .83886 L F
.42673 .83912 m .42735 .84151 L .42936 .84101 L F
.733 .551 .646 r
.40627 .86748 m .40817 .86689 L .40826 .86468 L F
.686 .58 .731 r
.40817 .86689 m .41022 .86435 L .40826 .86468 L F
.632 .802 .964 r
.44647 .82134 m .44444 .82201 L .44317 .82101 L F
.703 .414 .483 r
.48729 .81095 m .48402 .8129 L .48578 .81036 L F
.48729 .81095 m .48706 .81309 L .48402 .8129 L F
.662 .239 .23 r
.48578 .81036 m .48951 .8107 L .48729 .81095 L F
.653 .369 .477 r
.48912 .81293 m .48729 .81095 L .48951 .8107 L F
.48912 .81293 m .48706 .81309 L .48729 .81095 L F
.711 .562 .684 r
.46876 .83641 m .46663 .83904 L .46675 .83685 L F
.71 .561 .684 r
.46876 .83641 m .47014 .83943 L .46663 .83904 L F
.698 .596 .738 r
.47073 .83385 m .46876 .83641 L .46869 .83443 L F
.66 .541 .709 r
.47121 .83615 m .46876 .83641 L .47073 .83385 L F
.73 .569 .673 r
.47197 .83904 m .46876 .83641 L .47121 .83615 L F
.47197 .83904 m .47014 .83943 L .46876 .83641 L F
.58 .666 .897 r
.46086 .81873 m .46011 .82094 L .45878 .8197 L F
.46086 .81873 m .46206 .82063 L .46011 .82094 L F
.86 .711 .696 r
.48309 .81832 m .4843 .82117 L .48269 .82041 L F
.806 .725 .775 r
.4843 .82117 m .48124 .82142 L .48269 .82041 L F
.4843 .82117 m .48217 .8239 L .48124 .82142 L F
.69 .548 .688 r
.48415 .82304 m .48217 .8239 L .4843 .82117 L F
.742 .664 .773 r
.48638 .81888 m .4843 .82117 L .48309 .81832 L F
.135 0 0 r
.39755 .83995 m .39586 .84025 L .39415 .84022 L F
.137 0 0 r
.3995 .8394 m .39586 .84025 L .39755 .83995 L F
.31 0 .015 r
.48928 .84052 m .48889 .83986 L .48744 .83915 L F
.65 .809 .96 r
.40909 .83768 m .41332 .83747 L .412 .83709 L F
.298 0 0 r
.41514 .83655 m .412 .83709 L .41332 .83747 L F
.715 .625 .756 r
.4721 .84095 m .47299 .84407 L .47006 .8436 L F
.728 .575 .682 r
.47299 .84407 m .4709 .84669 L .47006 .8436 L F
.702 .537 .661 r
.47327 .84638 m .4709 .84669 L .47299 .84407 L F
.675 .601 .765 r
.47516 .84174 m .47299 .84407 L .4721 .84095 L F
.783 .514 .53 r
.47299 .84407 m .47615 .84667 L .47327 .84638 L F
.728 .582 .692 r
.46043 .8468 m .45918 .84778 L .4573 .84435 L F
.747 .591 .683 r
.46043 .8468 m .45883 .84967 L .45918 .84778 L F
.46043 .8468 m .46041 .84895 L .45883 .84967 L F
.686 .589 .742 r
.46252 .84657 m .46041 .84895 L .46043 .8468 L F
.661 .723 .895 r
.4704 .82074 m .46714 .82032 L .46957 .81878 L F
.675 .737 .897 r
.47262 .82036 m .4704 .82074 L .46957 .81878 L F
.698 .583 .723 r
.46663 .83904 m .46458 .84158 L .46344 .83858 L F
.689 .57 .716 r
.46692 .84111 m .46458 .84158 L .46663 .83904 L F
.654 .527 .696 r
.46692 .84111 m .466 .84325 L .46458 .84158 L F
.734 .586 .69 r
.47197 .83904 m .46977 .84164 L .47014 .83943 L F
.65 .464 .619 r
.4721 .84095 m .46977 .84164 L .47197 .83904 L F
.628 .557 .756 r
.47366 .83673 m .47197 .83904 L .47121 .83615 L F
.657 .598 .777 r
.47366 .83673 m .4751 .83906 L .47197 .83904 L F
.651 .465 .619 r
.47459 .84 m .47197 .83904 L .4751 .83906 L F
.47459 .84 m .4721 .84095 L .47197 .83904 L F
.641 .384 .514 r
.45642 .86452 m .45843 .86671 L .45621 .8669 L F
.45642 .86452 m .45848 .86466 L .45843 .86671 L F
.651 .33 .416 r
.48834 .84567 m .49056 .8447 L .48904 .84505 L F
.715 .484 .574 r
.49881 .85172 m .4987 .84903 L .49616 .85098 L F
.742 .695 .806 r
.48124 .82142 m .48217 .8239 L .47901 .82353 L F
.761 .634 .72 r
.48217 .8239 m .48055 .8265 L .47901 .82353 L F
.703 .555 .684 r
.46675 .83685 m .46663 .83904 L .46344 .83858 L F
.758 .388 .354 r
.49622 .87118 m .49746 .86963 L .49537 .86941 L F
.412 0 0 r
.49804 .87078 m .49746 .86963 L .49622 .87118 L F
.49804 .87078 m .49964 .86965 L .49746 .86963 L F
.289 .77 .923 r
.40318 .82298 m .40642 .82302 L .40451 .82305 L F
.675 .713 .877 r
.52055 .81054 m .51983 .81342 L .5187 .81056 L F
.52055 .81054 m .52195 .81277 L .51983 .81342 L F
.628 .393 .542 r
.41022 .86435 m .41247 .86416 L .41298 .86178 L F
.574 .386 .588 r
.41298 .86178 m .41515 .86201 L .41512 .8594 L F
.659 .478 .628 r
.41247 .86416 m .41515 .86201 L .41298 .86178 L F
.815 .821 .854 r
.51086 .81914 m .51319 .81734 L .51051 .8155 L F
.658 .809 .956 r
.51051 .8155 m .51319 .81734 L .51493 .81633 L F
.622 .294 .395 r
.5055 .86388 m .50373 .86218 L .50076 .86476 L F
.603 .299 .426 r
.5055 .86388 m .50591 .86226 L .50373 .86218 L F
.47 .299 .567 r
.50566 .87436 m .50395 .87503 L .50571 .87227 L F
.325 .015 .276 r
.50363 .87585 m .50395 .87503 L .50566 .87436 L F
.665 .473 .615 r
.466 .84325 m .46467 .84662 L .46252 .84657 L F
.654 .527 .696 r
.46692 .84111 m .46782 .84428 L .466 .84325 L F
.76 .58 .653 r
.46779 .84622 m .466 .84325 L .46782 .84428 L F
.46779 .84622 m .46467 .84662 L .466 .84325 L F
.577 .307 .471 r
.43529 .87399 m .43137 .87724 L .43166 .87524 L F
.61 .42 .6 r
.41515 .86201 m .41776 .85924 L .41512 .8594 L F
.605 .548 .764 r
.46179 .85444 m .45967 .85539 L .45827 .8516 L F
.723 .438 .494 r
.49665 .87752 m .49851 .87776 L .49875 .87991 L F
.569 .263 .41 r
.49851 .87776 m .50068 .87943 L .49875 .87991 L F
.49851 .87776 m .50093 .87692 L .50068 .87943 L F
.496 .209 .408 r
.49603 .81431 m .49768 .8153 L .49775 .81361 L F
.569 .047 0 r
.49603 .81431 m .49768 .8153 L .49447 .81504 L F
.49447 .81504 m .49768 .8153 L .49603 .81431 L F
.653 .803 .955 r
.44961 .82159 m .44647 .82134 L .44843 .82033 L F
.666 .742 .907 r
.45163 .8209 m .44961 .82159 L .44843 .82033 L F
.657 .536 .704 r
.42735 .84151 m .42997 .84391 L .42936 .84101 L F
.42735 .84151 m .42778 .84425 L .42997 .84391 L F
.966 .644 .334 r
.47782 .83372 m .47899 .83586 L .4784 .83549 L F
.952 .652 .432 r
.47782 .83372 m .4784 .83549 L .47667 .83491 L F
.832 .916 .892 r
.47711 .8347 m .4784 .83549 L .48016 .8332 L F
.47667 .83491 m .4784 .83549 L .47711 .8347 L F
.966 .644 .334 r
.47899 .83586 m .47934 .83649 L .4784 .83549 L F
.85 .819 .818 r
.4784 .83549 m .47934 .83649 L .47711 .83888 L F
.31 .028 .312 r
.47711 .83888 m .47934 .83649 L .47921 .83816 L F
.577 .297 .454 r
.47934 .83649 m .48075 .83794 L .47921 .83816 L F
.31 .028 .312 r
.47711 .83888 m .47934 .83649 L .47921 .83816 L F
.506 .241 .447 r
.50093 .87692 m .50289 .87927 L .50068 .87943 L F
.50093 .87692 m .50363 .87585 L .50289 .87927 L F
.614 .371 .526 r
.42735 .87714 m .42629 .88007 L .42413 .88002 L F
.596 .345 .507 r
.42735 .87714 m .42894 .87982 L .42629 .88007 L F
.42735 .87714 m .42926 .87716 L .42894 .87982 L F
.693 .495 .615 r
.42161 .85636 m .42477 .85689 L .42489 .85443 L F
.663 .47 .613 r
.42489 .85443 m .42702 .85641 L .42674 .85476 L F
.42489 .85443 m .42477 .85689 L .42702 .85641 L F
.097 .652 .796 r
.40849 .82207 m .41138 .8221 L .40966 .82242 L F
.815 .821 .854 r
.51086 .81914 m .51051 .8155 L .50931 .81811 L F
.516 .219 .4 r
.40042 .89029 m .40181 .89212 L .40004 .89104 L F
.40042 .89029 m .40217 .89032 L .40181 .89212 L F
.759 .626 .713 r
.47808 .82914 m .4779 .8314 L .47603 .83144 L F
.747 .517 .583 r
.47603 .83144 m .4779 .8314 L .47782 .83372 L F
.726 .626 .747 r
.48022 .8286 m .4779 .8314 L .47808 .82914 L F
.74 .534 .615 r
.47133 .86192 m .4726 .86468 L .46912 .86447 L F
.74 .652 .762 r
.47376 .86015 m .47133 .86192 L .47108 .85997 L F
.483 .834 .996 r
.42014 .82177 m .41698 .8216 L .41885 .82093 L F
.467 .791 .999 r
.42091 .8208 m .42014 .82177 L .41885 .82093 L F
.42091 .8208 m .42223 .82151 L .42014 .82177 L F
.615 .435 .616 r
.42674 .85476 m .42843 .85497 L .42911 .85187 L F
.67 .544 .702 r
.42911 .85187 m .43212 .85192 L .43117 .8487 L F
.702 .521 .64 r
.42911 .85187 m .43211 .85419 L .43212 .85192 L F
.42911 .85187 m .42843 .85497 L .43211 .85419 L F
.743 .757 .864 r
.48625 .82313 m .48953 .8242 L .48859 .82126 L F
.713 .177 0 r
.48625 .82313 m .48913 .82514 L .48953 .8242 L F
.793 .783 .844 r
.48859 .82126 m .48953 .8242 L .49171 .82116 L F
.437 .039 .185 r
.49627 .86464 m .49723 .86619 L .4959 .86671 L F
.792 .79 .85 r
.48254 .85414 m .48415 .85513 L .48078 .85597 L F
.655 .54 .712 r
.42801 .84639 m .42997 .84391 L .42778 .84425 L F
.42801 .84639 m .43101 .84693 L .42997 .84391 L F
.658 .57 .744 r
.42801 .84639 m .43117 .8487 L .43101 .84693 L F
.723 .761 .883 r
.48795 .85634 m .48858 .8541 L .48791 .85636 L F
.48795 .85634 m .4909 .85467 L .48858 .8541 L F
.692 .613 .763 r
.48022 .8286 m .47808 .82914 L .47698 .82623 L F
.599 .436 .631 r
.45918 .84778 m .45883 .84967 L .45761 .85156 L F
.654 .339 .428 r
.51763 .86173 m .51873 .86434 L .51671 .86459 L F
.51763 .86173 m .51943 .86208 L .51873 .86434 L F
.354 .623 .954 r
.52647 .81333 m .52509 .81336 L .52403 .81227 L F
.42 .414 .747 r
.52647 .81333 m .52786 .81593 L .52509 .81336 L F
.739 .577 .673 r
.49019 .86213 m .49202 .86144 L .49224 .85925 L F
.775 .392 .33 r
.49516 .86161 m .49224 .85925 L .49202 .86144 L F
.409 .848 .933 r
.41698 .8216 m .41495 .82211 L .41358 .822 L F
.47 .521 .828 r
.52369 .85907 m .52229 .8596 L .521 .85775 L F
.306 .103 .432 r
.52177 .86217 m .52229 .8596 L .52369 .85907 L F
.74 .652 .762 r
.47376 .86015 m .47108 .85997 L .4731 .85929 L F
.509 .792 .996 r
.47531 .8593 m .47376 .86015 L .4731 .85929 L F
.47531 .8593 m .47627 .86011 L .47376 .86015 L F
.691 .545 .683 r
.47014 .83943 m .46692 .84111 L .46663 .83904 L F
.47014 .83943 m .46977 .84164 L .46692 .84111 L F
.69 .548 .688 r
.46977 .84164 m .46782 .84428 L .46692 .84111 L F
.445 .191 .434 r
.50571 .87227 m .50809 .86984 L .5077 .8719 L F
.4 .152 .419 r
.5077 .8719 m .50809 .86984 L .5098 .86933 L F
.412 0 .044 r
.40293 .8384 m .40076 .83992 L .3995 .8394 L F
.193 0 0 r
.40276 .83939 m .40293 .8384 L .40469 .83841 L F
.40276 .83939 m .40076 .83992 L .40293 .8384 L F
.68 .513 .653 r
.47968 .86197 m .47981 .86445 L .47745 .86451 L F
.858 .566 .491 r
.48078 .85597 m .48399 .85962 L .4802 .86166 L F
.727 .556 .66 r
.48061 .85682 m .4772 .85827 L .47735 .8565 L F
.907 .79 .309 r
.48078 .85597 m .48032 .85975 L .48049 .85805 L F
.48078 .85597 m .48046 .85911 L .48054 .85797 L F
.48078 .85597 m .48037 .85895 L .48078 .85684 L F
.727 .556 .66 r
.48078 .85684 m .4806 .85691 L .48061 .85682 L F
.4806 .85691 m .4772 .85827 L .48061 .85682 L F
.907 .79 .309 r
.48054 .85797 m .4802 .86166 L .48032 .85975 L F
.48046 .85911 m .4802 .86166 L .48054 .85797 L F
.48049 .85805 m .48032 .85975 L .48037 .85895 L F
.792 .79 .85 r
.48254 .85414 m .48078 .85597 L .48078 .85684 L F
.699 .553 .686 r
.48064 .85661 m .48254 .85414 L .48078 .85684 L F
.47909 .85412 m .48089 .85413 L .48064 .85661 L F
.48089 .85413 m .48254 .85414 L .48064 .85661 L F
.266 .637 .964 r
.48115 .86194 m .47968 .86197 L .47846 .86095 L F
.722 .704 .832 r
.48115 .86194 m .47981 .86445 L .47968 .86197 L F
.762 .632 .717 r
.45883 .84967 m .46041 .84895 L .45827 .8516 L F
.72 .569 .683 r
.46041 .84895 m .46399 .85291 L .45827 .8516 L F
.686 .589 .742 r
.46252 .84657 m .4641 .84944 L .46041 .84895 L F
.51 .529 .812 r
.46357 .85159 m .46041 .84895 L .4641 .84944 L F
.46357 .85159 m .46399 .85291 L .46041 .84895 L F
.331 .775 .962 r
.39592 .82378 m .3979 .82362 L .39928 .82403 L F
.256 0 0 r
.3979 .82362 m .40123 .82357 L .39928 .82403 L F
.743 .624 .727 r
.47006 .8436 m .46782 .84428 L .46977 .84164 L F
.695 .556 .692 r
.47006 .8436 m .46779 .84622 L .46782 .84428 L F
.47006 .8436 m .4709 .84669 L .46779 .84622 L F
.715 .625 .756 r
.4721 .84095 m .47006 .8436 L .46977 .84164 L F
.668 .794 .942 r
.51345 .8103 m .51059 .80983 L .51235 .80951 L F
.493 .792 .998 r
.51434 .80894 m .51345 .8103 L .51235 .80951 L F
.51434 .80894 m .51774 .81029 L .51345 .8103 L F
.637 .887 .986 r
.39399 .82432 m .39458 .82303 L .39592 .82378 L F
.39399 .82432 m .39257 .82372 L .39458 .82303 L F
.706 .633 .772 r
.47073 .83385 m .46869 .83443 L .46777 .83188 L F
.662 .427 .553 r
.44394 .86975 m .44598 .87206 L .44389 .87189 L F
.44394 .86975 m .44607 .86981 L .44598 .87206 L F
.753 .561 .636 r
.49665 .87752 m .49328 .87995 L .49374 .87745 L F
.49665 .87752 m .49656 .87977 L .49328 .87995 L F
.723 .438 .494 r
.49665 .87752 m .49875 .87991 L .49656 .87977 L F
.742 .627 .732 r
.47901 .82353 m .48055 .8265 L .47698 .82623 L F
.692 .613 .763 r
.48022 .8286 m .47698 .82623 L .48055 .8265 L F
.517 .6 .876 r
.50603 .81591 m .50766 .81856 L .50931 .81811 L F
.67 .842 .966 r
.5288 .8183 m .52685 .81817 L .52783 .81786 L F
.086 0 .256 r
.52834 .8177 m .52783 .81786 L .5271 .81987 L F
.432 .848 .962 r
.53042 .8178 m .52783 .81786 L .52889 .81675 L F
.086 0 .256 r
.52889 .81675 m .52783 .81786 L .52834 .8177 L F
.67 .842 .966 r
.52685 .81817 m .52483 .81804 L .52783 .81786 L F
.771 .673 .755 r
.46779 .84622 m .46567 .84864 L .46467 .84662 L F
.666 .509 .663 r
.46779 .84622 m .46861 .84914 L .46567 .84864 L F
.607 .395 .568 r
.4709 .84669 m .46861 .84914 L .46779 .84622 L F
0 0 0 r
.40909 .83768 m .40801 .83858 L .40654 .83889 L F
.191 0 0 r
.412 .83709 m .41065 .83804 L .40909 .83768 L F
.628 .55 .748 r
.46777 .83188 m .4648 .83068 L .46671 .83053 L F
.779 .539 .572 r
.48097 .84091 m .48234 .83887 L .48041 .8413 L F
.48097 .84091 m .48041 .8413 L .47921 .83816 L F
.757 .691 .788 r
.46714 .82032 m .46387 .81984 L .46615 .8182 L F
.46714 .82032 m .46544 .82119 L .46387 .81984 L F
.658 .73 .903 r
.46957 .81878 m .46714 .82032 L .46615 .8182 L F
.703 .783 .914 r
.4569 .82021 m .45343 .81992 L .45567 .81899 L F
.613 .791 .967 r
.45878 .8197 m .4569 .82021 L .45567 .81899 L F
.722 .704 .832 r
.48115 .86194 m .48263 .86461 L .47981 .86445 L F
.742 .519 .592 r
.47981 .86445 m .48263 .86461 L .48257 .86693 L F
.587 .831 .991 r
.48357 .86322 m .48263 .86461 L .48115 .86194 L F
.48357 .86322 m .48487 .86402 L .48263 .86461 L F
.714 .587 .711 r
.48487 .86402 m .48257 .86693 L .48263 .86461 L F
.609 .406 .582 r
.42674 .85476 m .42836 .85551 L .42843 .85497 L F
.42674 .85476 m .42702 .85641 L .42836 .85551 L F
.742 .627 .731 r
.47711 .83888 m .47366 .83673 L .47697 .83832 L F
.47711 .83888 m .4751 .83906 L .47366 .83673 L F
.755 .607 .693 r
.47711 .83888 m .47459 .84 L .4751 .83906 L F
.47711 .83888 m .47516 .84174 L .47459 .84 L F
.735 .5 .573 r
.47559 .84041 m .4759 .84022 L .47697 .83832 L F
.85 .819 .818 r
.47808 .83635 m .47711 .83888 L .47697 .83832 L F
.735 .5 .573 r
.4759 .84022 m .47921 .83816 L .47697 .83832 L F
.85 .819 .818 r
.4784 .83549 m .47808 .83635 L .47697 .83832 L F
.69 .51 .638 r
.4909 .85467 m .49278 .85159 L .48975 .85217 L F
.4909 .85467 m .49271 .85342 L .49278 .85159 L F
.559 .527 .776 r
.49278 .85159 m .49631 .85458 L .49545 .85145 L F
.742 .664 .774 r
.48498 .81593 m .48638 .81888 L .48309 .81832 L F
.703 .647 .791 r
.48946 .81783 m .48638 .81888 L .48498 .81593 L F
.628 .402 .556 r
.45129 .86723 m .4532 .86929 L .45122 .86926 L F
.45129 .86723 m .45323 .8671 L .4532 .86929 L F
.91 .949 .813 r
.48795 .84435 m .48904 .84505 L .49097 .84171 L F
.931 .94 .781 r
.48834 .84567 m .48904 .84505 L .48795 .84435 L F
.675 .737 .897 r
.47262 .82036 m .46957 .81878 L .47142 .81779 L F
.656 .696 .875 r
.47499 .8187 m .47262 .82036 L .47142 .81779 L F
.642 .794 .955 r
.42403 .8348 m .42768 .8359 L .42651 .83411 L F
.677 .828 .956 r
.42651 .83411 m .42768 .8359 L .42945 .8341 L F
.728 .605 .72 r
.46567 .84864 m .46252 .84657 L .46467 .84662 L F
.46567 .84864 m .4641 .84944 L .46252 .84657 L F
.689 .52 .653 r
.46593 .8514 m .4641 .84944 L .46567 .84864 L F
.624 .432 .602 r
.46861 .84914 m .46593 .8514 L .46567 .84864 L F
.622 .83 .98 r
.42546 .82167 m .42223 .82151 L .4242 .82089 L F
.619 .829 .981 r
.42737 .82109 m .42546 .82167 L .4242 .82089 L F
.358 0 .087 r
.50712 .86311 m .50824 .86121 L .50591 .86226 L F
.267 0 .091 r
.51105 .8596 m .50824 .86121 L .50986 .86128 L F
.2 0 .008 r
.50986 .86128 m .50824 .86121 L .50712 .86311 L F
.766 .598 .669 r
.47615 .84667 m .47338 .84917 L .47327 .84638 L F
.47615 .84667 m .47662 .84932 L .47338 .84917 L F
.764 .464 .477 r
.47615 .84667 m .47914 .84917 L .47662 .84932 L F
.487 .313 .57 r
.50566 .87436 m .50571 .87227 L .5077 .8719 L F
.756 .657 .752 r
.4883 .83308 m .49153 .83341 L .49247 .83186 L F
.763 .617 .698 r
.4883 .83308 m .48964 .83624 L .49153 .83341 L F
.706 .633 .772 r
.47073 .83385 m .46777 .83188 L .4695 .83089 L F
.726 .618 .737 r
.47282 .83124 m .47073 .83385 L .4695 .83089 L F
.598 .436 .633 r
.47282 .83124 m .47285 .83353 L .47073 .83385 L F
.637 .541 .729 r
.47285 .83353 m .47121 .83615 L .47073 .83385 L F
.717 .692 .825 r
.46387 .81984 m .46544 .82119 L .46206 .82063 L F
.577 .307 .471 r
.43529 .87399 m .43343 .87713 L .43137 .87724 L F
.619 .356 .497 r
.43655 .87616 m .43529 .87399 L .43662 .87448 L F
.43655 .87616 m .43343 .87713 L .43529 .87399 L F
.605 .548 .764 r
.46179 .85444 m .45827 .8516 L .46399 .85291 L F
.815 .707 .746 r
.46357 .85159 m .46179 .85444 L .46399 .85291 L F
.712 .624 .757 r
.43101 .84693 m .43117 .8487 L .43305 .84638 L F
.635 .511 .695 r
.43305 .84638 m .43117 .8487 L .43338 .84828 L F
.693 .557 .696 r
.43117 .8487 m .43429 .85158 L .43338 .84828 L F
.43117 .8487 m .43212 .85192 L .43429 .85158 L F
.132 .251 .721 r
.48195 .83044 m .48022 .8286 L .48272 .82886 L F
.677 .43 .54 r
.45848 .86466 m .46183 .8642 L .46066 .86681 L F
.623 .401 .56 r
.46183 .8642 m .46391 .86655 L .46066 .86681 L F
.46183 .8642 m .46371 .86436 L .46391 .86655 L F
.549 .324 .526 r
.42178 .8821 m .42201 .87997 L .42394 .88181 L F
.602 .318 .458 r
.42201 .87997 m .42413 .88002 L .42394 .88181 L F
.673 .713 .879 r
.50822 .81056 m .50513 .81043 L .50662 .80838 L F
.636 .077 0 r
.50662 .80838 m .51059 .80983 L .50822 .81056 L F
.752 .564 .641 r
.48315 .84947 m .47932 .85151 L .47914 .84917 L F
.48315 .84947 m .48281 .85168 L .47932 .85151 L F
.724 .519 .614 r
.47327 .84638 m .47086 .84883 L .4709 .84669 L F
.47327 .84638 m .47338 .84917 L .47086 .84883 L F
.235 0 .028 r
.51294 .85898 m .51105 .8596 L .50986 .86128 L F
.378 .153 .442 r
.51311 .85689 m .51105 .8596 L .51294 .85898 L F
.637 .541 .729 r
.47285 .83353 m .47366 .83673 L .47121 .83615 L F
.689 .52 .653 r
.46593 .8514 m .46357 .85159 L .4641 .84944 L F
.769 .544 .594 r
.49768 .8153 m .50091 .8133 L .49775 .81361 L F
.49768 .8153 m .5009 .8158 L .50091 .8133 L F
.247 .733 .926 r
.50131 .81058 m .50178 .81037 L .50301 .81072 L F
.49977 .81044 m .50178 .81037 L .50131 .81058 L F
.066 .313 .796 r
.50178 .81037 m .50389 .81212 L .50263 .80999 L F
.872 .921 .857 r
.50301 .81072 m .50178 .81037 L .50364 .808 L F
.066 .313 .796 r
.50178 .81037 m .50263 .80999 L .5023 .80944 L F
.504 .504 .789 r
.50091 .8133 m .50178 .81037 L .49977 .81044 L F
.50091 .8133 m .50259 .81304 L .50178 .81037 L F
0 0 .357 r
.50091 .8133 m .50176 .81466 L .50259 .81304 L F
.673 .879 .975 r
.50176 .81466 m .50292 .8153 L .50505 .81453 L F
.667 .271 .287 r
.50412 .8149 m .50221 .81518 L .50176 .81466 L F
0 0 .357 r
.50091 .81367 m .5009 .8158 L .50176 .81466 L F
.667 .271 .287 r
.50221 .81518 m .50028 .81546 L .50176 .81466 L F
0 0 .357 r
.50091 .8133 m .50091 .81367 L .50176 .81466 L F
.607 .395 .568 r
.4709 .84669 m .47086 .84883 L .46861 .84914 L F
.606 .83 .986 r
.41934 .83534 m .42042 .83615 L .42219 .83559 L F
.569 .78 .978 r
.4307 .82167 m .42737 .82109 L .42939 .82097 L F
.576 .837 .994 r
.43269 .82113 m .4307 .82167 L .42939 .82097 L F
.893 .651 .566 r
.49069 .87243 m .48916 .87423 L .4889 .87208 L F
.49069 .87243 m .49082 .87409 L .48916 .87423 L F
.872 .921 .857 r
.50301 .81072 m .50364 .808 L .50513 .81043 L F
0 .054 .618 r
.49556 .86897 m .4946 .86833 L .49292 .8674 L F
.49556 .86897 m .49537 .86941 L .4946 .86833 L F
.556 .686 .926 r
.50662 .80838 m .50513 .81043 L .50364 .808 L F
.614 .405 .574 r
.5152 .85915 m .51311 .85689 L .51294 .85898 L F
.5152 .85915 m .51513 .85671 L .51311 .85689 L F
.178 .377 .822 r
.49516 .86161 m .49675 .8642 L .49801 .86407 L F
.048 0 0 r
.49801 .86407 m .49675 .8642 L .4938 .86679 L F
0 .401 .742 r
.521 .85775 m .51835 .85672 L .52133 .85823 L F
.602 .044 0 r
.52194 .85881 m .521 .85775 L .52133 .85823 L F
.52194 .85881 m .52369 .85907 L .521 .85775 L F
.766 .588 .657 r
.4726 .86468 m .47429 .86475 L .47224 .86641 L F
.625 .379 .525 r
.47429 .86475 m .47414 .86694 L .47224 .86641 L F
.756 .657 .752 r
.4883 .83308 m .49247 .83186 L .48869 .83118 L F
.654 .529 .698 r
.47381 .82549 m .47168 .82619 L .47356 .82366 L F
.701 .582 .719 r
.45827 .8516 m .45683 .85267 L .45761 .85156 L F
.67 .553 .713 r
.40413 .86972 m .40627 .86748 L .40295 .8669 L F
.40413 .86972 m .40606 .86964 L .40627 .86748 L F
.632 .395 .54 r
.40376 .87161 m .40606 .86964 L .40413 .86972 L F
.619 .828 .981 r
.43592 .82132 m .43269 .82113 L .43468 .82054 L F
.626 .833 .98 r
.43793 .8207 m .43592 .82132 L .43468 .82054 L F
.677 .43 .54 r
.45848 .86466 m .46066 .86681 L .45843 .86671 L F
.671 .457 .586 r
.47745 .86451 m .47944 .86688 L .47753 .86653 L F
.47745 .86451 m .47981 .86445 L .47944 .86688 L F
.757 .631 .721 r
.40606 .86964 m .40817 .86689 L .40627 .86748 L F
.667 .501 .651 r
.40606 .86964 m .40863 .86974 L .40817 .86689 L F
.686 .58 .731 r
.40817 .86689 m .41103 .86681 L .41022 .86435 L F
.595 .452 .657 r
.40817 .86689 m .41071 .86909 L .41103 .86681 L F
.40817 .86689 m .40863 .86974 L .41071 .86909 L F
.806 .693 .74 r
.49843 .86432 m .5003 .86232 L .49733 .86155 L F
.688 .592 .743 r
.42936 .84101 m .43091 .83858 L .42904 .83886 L F
.633 .404 .553 r
.44942 .86912 m .44598 .87206 L .44607 .86981 L F
.701 .453 .547 r
.47282 .83124 m .47503 .83347 L .47285 .83353 L F
.47282 .83124 m .47603 .83144 L .47503 .83347 L F
.747 .517 .583 r
.47603 .83144 m .47782 .83372 L .47503 .83347 L F
.701 .582 .719 r
.45827 .8516 m .45761 .85156 L .45883 .84967 L F
.606 .335 .479 r
.4167 .88292 m .41881 .885 L .41666 .88455 L F
.4167 .88292 m .41996 .88238 L .41881 .885 L F
.762 .632 .716 r
.46434 .8543 m .46179 .85444 L .46357 .85159 L F
.607 .539 .752 r
.46658 .85398 m .46434 .8543 L .46357 .85159 L F
.498 .323 .574 r
.46658 .85398 m .46455 .85697 L .46434 .8543 L F
.424 .499 .832 r
.36759 .74137 m .36777 .74142 L .36764 .74149 L F
.009 0 .002 r
.36764 .74149 m .36777 .74142 L .36758 .74159 L F
.691 .548 .686 r
.43212 .85192 m .43211 .85419 L .43429 .85158 L F
.759 .516 .566 r
.47338 .84917 m .47662 .84932 L .47631 .85141 L F
.713 .546 .661 r
.47914 .84917 m .47631 .85141 L .47662 .84932 L F
.422 .613 .929 r
.46989 .85889 m .46817 .85884 L .46655 .85668 L F
.677 .599 .761 r
.47108 .85997 m .46817 .85884 L .46989 .85889 L F
.313 .603 .949 r
.36631 .74006 m .36777 .74142 L .36759 .74137 L F
.552 .2 .325 r
.51943 .86208 m .52099 .86406 L .51873 .86434 L F
.51943 .86208 m .52177 .86217 L .52099 .86406 L F
.688 .593 .744 r
.42936 .84101 m .42997 .84391 L .43191 .84135 L F
.644 .531 .71 r
.43191 .84135 m .42997 .84391 L .43209 .8435 L F
.698 .563 .699 r
.42997 .84391 m .43305 .84638 L .43209 .8435 L F
.42997 .84391 m .43101 .84693 L .43305 .84638 L F
.624 .749 .937 r
.52254 .81049 m .52195 .81277 L .52055 .81054 L F
.52254 .81049 m .52403 .81227 L .52195 .81277 L F
.779 .539 .572 r
.48097 .84091 m .48296 .84047 L .48234 .83887 L F
.496 .395 .67 r
.48234 .83887 m .48296 .84047 L .48434 .84095 L F
.575 .538 .776 r
.49172 .87703 m .4913 .87989 L .4913 .87734 L F
.49176 .87674 m .49328 .87995 L .4913 .87989 L F
.401 0 0 r
.4913 .87989 m .49328 .87995 L .49231 .88111 L F
.4913 .87989 m .49231 .88111 L .4913 .87734 L F
.78 .475 .472 r
.4893 .87884 m .4913 .87734 L .49231 .88111 L F
.48916 .87873 m .4913 .87734 L .4893 .87884 L F
.575 .538 .776 r
.49176 .87674 m .49172 .87703 L .4913 .87734 L F
.593 .759 .958 r
.44112 .82138 m .43793 .8207 L .43993 .82038 L F
.556 .77 .978 r
.44317 .82101 m .44112 .82138 L .43993 .82038 L F
.464 .478 .789 r
.4772 .85827 m .47627 .86011 L .47531 .8593 L F
.4772 .85827 m .47846 .86095 L .47627 .86011 L F
.681 .766 .915 r
.46989 .85889 m .4731 .85929 L .47108 .85997 L F
.692 .548 .686 r
.41961 .85921 m .42161 .85636 L .41969 .85709 L F
.41961 .85921 m .42275 .85937 L .42161 .85636 L F
.686 .545 .688 r
.42161 .85636 m .42275 .85937 L .42477 .85689 L F
.675 .601 .765 r
.47516 .84174 m .4721 .84095 L .47459 .84 L F
.703 .647 .791 r
.48946 .81783 m .48498 .81593 L .48717 .81773 L F
.711 .217 .07 r
.48717 .81773 m .48974 .81837 L .48946 .81783 L F
.819 .776 .813 r
.40943 .88758 m .41235 .8864 L .41281 .88525 L F
.68 .53 .676 r
.43429 .85158 m .43211 .85419 L .43457 .85375 L F
.677 .578 .736 r
.43338 .84828 m .43429 .85158 L .43625 .84905 L F
.631 .512 .699 r
.43625 .84905 m .43429 .85158 L .43642 .85134 L F
.616 .476 .669 r
.43457 .85375 m .43642 .85134 L .43429 .85158 L F
.298 0 0 r
.41514 .83655 m .4134 .83731 L .412 .83709 L F
.019 0 0 r
.41529 .83691 m .41514 .83655 L .41707 .83578 L F
.41529 .83691 m .4134 .83731 L .41514 .83655 L F
.693 .375 .434 r
.51749 .85908 m .51835 .85672 L .51513 .85671 L F
.625 .25 .312 r
.51917 .85886 m .51835 .85672 L .51749 .85908 L F
.51917 .85886 m .52133 .85823 L .51835 .85672 L F
.542 .928 .848 r
.36777 .74142 m .36623 .74183 L .36758 .74159 L F
.664 .765 .925 r
.49768 .8153 m .49893 .81654 L .5009 .8158 L F
.763 .932 .941 r
.48419 .82819 m .48535 .82866 L .48681 .82751 L F
.34 0 .134 r
.39568 .87435 m .39877 .87215 L .39572 .87203 L F
.39568 .87435 m .39753 .87395 L .39877 .87215 L F
.526 .136 .243 r
.39753 .87395 m .4008 .87233 L .39877 .87215 L F
.358 0 .087 r
.50712 .86311 m .50591 .86226 L .5055 .86388 L F
.243 .753 .867 r
.3854 .82631 m .38751 .82604 L .38871 .82614 L F
.478 .886 .938 r
.38871 .82614 m .38939 .82541 L .39066 .82573 L F
.38871 .82614 m .38751 .82604 L .38939 .82541 L F
.702 .507 .622 r
.44244 .87166 m .44291 .87489 L .43861 .87462 L F
.5 .366 .629 r
.44476 .87417 m .44244 .87166 L .44389 .87189 L F
.44476 .87417 m .44291 .87489 L .44244 .87166 L F
.742 .519 .592 r
.47981 .86445 m .48257 .86693 L .47944 .86688 L F
.313 .603 .949 r
.36631 .74006 m .36857 .74061 L .36777 .74142 L F
.542 .928 .848 r
.36777 .74142 m .36857 .74061 L .36623 .74183 L F
.792 .722 .787 r
.48272 .83568 m .48451 .83634 L .48326 .8336 L F
.783 .731 .804 r
.48238 .83662 m .48451 .83634 L .48272 .83568 L F
.705 .599 .735 r
.48451 .83634 m .48504 .83243 L .48326 .8336 L F
.48451 .83634 m .48651 .83469 L .48504 .83243 L F
.681 .474 .599 r
.45621 .8669 m .4532 .86929 L .45323 .8671 L F
.633 .534 .724 r
.41103 .86681 m .41247 .86416 L .41022 .86435 L F
.41103 .86681 m .41326 .86675 L .41247 .86416 L F
.59 .291 .429 r
.4124 .8687 m .41103 .86681 L .41071 .86909 L F
.4124 .8687 m .41326 .86675 L .41103 .86681 L F
.708 .52 .633 r
.42836 .85551 m .43211 .85419 L .42843 .85497 L F
.42836 .85551 m .43205 .85654 L .43211 .85419 L F
.671 .492 .634 r
.43205 .85654 m .43457 .85375 L .43211 .85419 L F
.632 .395 .54 r
.40376 .87161 m .40594 .87176 L .40606 .86964 L F
.655 .411 .539 r
.40594 .87176 m .40863 .86974 L .40606 .86964 L F
.635 .759 .938 r
.47787 .82305 m .47901 .82353 L .47595 .82322 L F
.73 .61 .723 r
.47901 .82353 m .47698 .82623 L .47595 .82322 L F
.76 .73 .824 r
.48124 .82142 m .47901 .82353 L .47787 .82305 L F
.709 .599 .731 r
.47595 .82322 m .47381 .82549 L .47356 .82366 L F
.625 .761 .944 r
.4504 .81978 m .45163 .8209 L .44843 .82033 L F
.727 .787 .9 r
.45343 .81992 m .45163 .8209 L .4504 .81978 L F
.709 .599 .731 r
.47595 .82322 m .47698 .82623 L .47381 .82549 L F
.757 .539 .602 r
.41776 .85924 m .41948 .86133 L .41961 .85921 L F
.769 .571 .63 r
.41948 .86133 m .42057 .86206 L .41961 .85921 L F
.677 .522 .668 r
.41961 .85921 m .4227 .8617 L .42275 .85937 L F
.41961 .85921 m .42057 .86206 L .4227 .8617 L F
.595 .32 .471 r
.42926 .87716 m .4315 .87948 L .42894 .87982 L F
.42926 .87716 m .43137 .87724 L .4315 .87948 L F
.688 .59 .741 r
.43209 .8435 m .43305 .84638 L .43511 .84396 L F
.678 .575 .732 r
.43305 .84638 m .43618 .84684 L .43511 .84396 L F
.689 .555 .697 r
.43338 .84828 m .43618 .84684 L .43305 .84638 L F
.137 0 0 r
.3995 .8394 m .39788 .84008 L .39586 .84025 L F
.102 .658 .76 r
.40076 .83992 m .39788 .84008 L .3995 .8394 L F
.634 .758 .937 r
.50292 .8153 m .50387 .81656 L .50603 .81591 L F
.719 .581 .7 r
.4695 .83089 m .46777 .83188 L .46671 .83053 L F
.607 .539 .752 r
.46658 .85398 m .46357 .85159 L .46593 .8514 L F
.598 .154 .167 r
.49328 .87995 m .49656 .87977 L .49563 .88114 L F
.503 .052 .113 r
.49656 .87977 m .49739 .88136 L .49563 .88114 L F
.49656 .87977 m .49875 .87991 L .49739 .88136 L F
.632 .802 .964 r
.44647 .82134 m .44317 .82101 L .44517 .82041 L F
.727 .826 .926 r
.44843 .82033 m .44647 .82134 L .44517 .82041 L F
.718 .54 .648 r
.4726 .86468 m .46887 .86666 L .46912 .86447 L F
.4726 .86468 m .47224 .86641 L .46887 .86666 L F
.624 .432 .602 r
.46861 .84914 m .46847 .8516 L .46593 .8514 L F
.598 .364 .533 r
.46861 .84914 m .47092 .8513 L .46847 .8516 L F
.46861 .84914 m .47086 .84883 L .47092 .8513 L F
.632 .126 .028 r
.39181 .84069 m .39045 .8409 L .3888 .8407 L F
.39181 .84069 m .39085 .84103 L .39045 .8409 L F
.209 0 0 r
.39415 .84022 m .39085 .84103 L .39181 .84069 L F
.662 .239 .23 r
.48578 .81036 m .48916 .81156 L .48951 .8107 L F
.512 .584 .865 r
.48703 .80795 m .48915 .81121 L .48578 .81036 L F
.762 .956 .935 r
.48912 .81165 m .48912 .81293 L .48951 .8107 L F
.4889 .8122 m .48906 .81274 L .48912 .81165 L F
.48906 .81274 m .48912 .81293 L .48912 .81165 L F
.48915 .81129 m .48916 .81156 L .48951 .8107 L F
.662 .239 .23 r
.48916 .81156 m .48945 .81167 L .48951 .8107 L F
0 0 .044 r
.48951 .8107 m .49064 .80808 L .49132 .81022 L F
.48951 .8107 m .48945 .81167 L .48964 .81109 L F
.762 .956 .935 r
.49064 .81067 m .48951 .8107 L .49132 .81022 L F
.4897 .81128 m .48964 .81109 L .49064 .81067 L F
.48964 .81109 m .48951 .8107 L .49064 .81067 L F
0 0 .044 r
.48951 .8107 m .48964 .81109 L .49064 .80808 L F
.745 .678 .786 r
.49064 .80808 m .48964 .81109 L .48915 .81121 L F
.48964 .81109 m .48945 .81167 L .4892 .81128 L F
.512 .584 .865 r
.48915 .81129 m .48945 .81167 L .48916 .81156 L F
.4892 .81128 m .48945 .81167 L .48915 .81129 L F
.762 .956 .935 r
.4888 .81187 m .48916 .81156 L .48915 .81129 L F
.4888 .81187 m .48915 .81129 L .4897 .81128 L F
.48915 .81129 m .48951 .8107 L .48967 .81118 L F
.48915 .81129 m .48967 .81118 L .4897 .81128 L F
.512 .584 .865 r
.48915 .81121 m .4892 .81128 L .48915 .81129 L F
.745 .678 .786 r
.48964 .81109 m .4892 .81128 L .48915 .81121 L F
.48933 .80803 m .48915 .81121 L .48703 .80795 L F
.49064 .80808 m .48915 .81121 L .48933 .80803 L F
.512 .584 .865 r
.48915 .81121 m .48916 .81156 L .48578 .81036 L F
.762 .956 .935 r
.4888 .81187 m .4889 .8122 L .48916 .81156 L F
0 0 .446 r
.49622 .87118 m .49537 .86941 L .49556 .86897 L F
.325 .015 .276 r
.50363 .87585 m .50566 .87436 L .50514 .87836 L F
.533 .265 .456 r
.50289 .87927 m .50363 .87585 L .50514 .87836 L F
.586 .288 .43 r
.40735 .88747 m .40895 .88941 L .40689 .88965 L F
.40735 .88747 m .40943 .88758 L .40895 .88941 L F
.735 .824 .92 r
.51728 .80974 m .51774 .81029 L .51434 .80894 L F
.494 .679 .948 r
.5187 .81056 m .51774 .81029 L .51728 .80974 L F
.715 .587 .712 r
.42477 .85689 m .42275 .85937 L .42493 .85921 L F
.685 .512 .647 r
.42275 .85937 m .42486 .86105 L .42493 .85921 L F
.639 .498 .675 r
.42493 .85921 m .42702 .85641 L .42477 .85689 L F
.42493 .85921 m .42794 .85934 L .42702 .85641 L F
.669 .515 .667 r
.42486 .86105 m .42794 .85934 L .42493 .85921 L F
.706 .599 .734 r
.48504 .83243 m .48651 .83469 L .4883 .83308 L F
.931 .94 .781 r
.48834 .84567 m .48795 .84435 L .48709 .84525 L F
.095 .506 .904 r
.51748 .81863 m .5209 .82057 L .51972 .81839 L F
.641 .684 .875 r
.5209 .82057 m .52184 .81794 L .51972 .81839 L F
.5209 .82057 m .52305 .81988 L .52184 .81794 L F
.595 .844 .481 r
.50036 .86863 m .5018 .86692 L .49964 .86965 L F
.632 .929 .672 r
.50036 .86863 m .49964 .86965 L .49804 .87078 L F
.633 .404 .553 r
.44942 .86912 m .44806 .87192 L .44598 .87206 L F
.631 .411 .565 r
.45122 .86926 m .44806 .87192 L .44942 .86912 L F
.621 .484 .673 r
.46847 .8516 m .46658 .85398 L .46593 .8514 L F
.671 .492 .634 r
.43205 .85654 m .43512 .85685 L .43457 .85375 L F
.616 .476 .669 r
.43457 .85375 m .43742 .85387 L .43642 .85134 L F
.596 .441 .641 r
.43457 .85375 m .43705 .85645 L .43742 .85387 L F
.43457 .85375 m .43512 .85685 L .43705 .85645 L F
.724 .727 .852 r
.46387 .81984 m .46206 .82063 L .46086 .81873 L F
.689 .555 .697 r
.43338 .84828 m .43625 .84905 L .43618 .84684 L F
.928 .568 .319 r
.50016 .86531 m .5018 .86692 L .50093 .86723 L F
.414 .85 .731 r
.50093 .86723 m .5018 .86692 L .50259 .86637 L F
0 0 0 r
.50259 .86637 m .5018 .86692 L .50036 .86863 L F
.685 .512 .647 r
.42275 .85937 m .4227 .8617 L .42486 .86105 L F
.765 .671 .758 r
.48309 .81832 m .47998 .81813 L .48203 .81557 L F
.745 .628 .73 r
.48269 .82041 m .47998 .81813 L .48309 .81832 L F
.737 .657 .771 r
.48498 .81593 m .48309 .81832 L .48203 .81557 L F
.819 .558 .544 r
.49082 .87409 m .48898 .87655 L .48916 .87423 L F
.49082 .87409 m .49176 .87674 L .48898 .87655 L F
.806 .693 .74 r
.49843 .86432 m .49733 .86155 L .49801 .86407 L F
.928 .568 .319 r
.50016 .86531 m .50093 .86723 L .49843 .86432 L F
.518 .404 .663 r
.49843 .86432 m .50093 .86723 L .50048 .86412 L F
.546 .259 .43 r
.40004 .89104 m .40181 .89212 L .39965 .89233 L F
.486 .503 .8 r
.52058 .80978 m .5187 .81056 L .51728 .80974 L F
.52058 .80978 m .52055 .81054 L .5187 .81056 L F
.741 .521 .595 r
.48434 .84095 m .49002 .84121 L .48744 .83915 L F
0 .212 .695 r
.48744 .83915 m .49002 .84121 L .48928 .84052 L F
.729 .546 .644 r
.46577 .86419 m .46391 .86655 L .46371 .86436 L F
.788 .695 .763 r
.48858 .8541 m .4909 .85467 L .48975 .85217 L F
.693 .375 .434 r
.51749 .85908 m .51513 .85671 L .5152 .85915 L F
.604 .328 .471 r
.4802 .86166 m .48399 .85962 L .48358 .86143 L F
.523 .212 .381 r
.48399 .85962 m .48415 .86146 L .48358 .86143 L F
.48399 .85962 m .48593 .85885 L .48415 .86146 L F
.61 .42 .6 r
.41515 .86201 m .41777 .86202 L .41776 .85924 L F
.757 .539 .602 r
.41776 .85924 m .41777 .86202 L .41948 .86133 L F
.688 .592 .743 r
.42936 .84101 m .43191 .84135 L .43091 .83858 L F
.428 .405 .731 r
.47551 .83606 m .47366 .83673 L .47285 .83353 L F
.465 .53 .839 r
.47551 .83606 m .47697 .83832 L .47426 .83702 L F
.847 .659 .649 r
.47461 .83766 m .47697 .83832 L .47551 .83606 L F
0 0 .071 r
.47551 .83606 m .47461 .83766 L .47622 .83552 L F
.47551 .83606 m .47622 .83552 L .47667 .83491 L F
.465 .53 .839 r
.47551 .83606 m .47426 .83702 L .47366 .83673 L F
0 .054 .618 r
.49556 .86897 m .49292 .8674 L .4959 .86671 L F
.023 0 .209 r
.49556 .86897 m .4959 .86671 L .49723 .86619 L F
.696 .515 .638 r
.48281 .85168 m .47909 .85412 L .47932 .85151 L F
.48281 .85168 m .48254 .85414 L .47909 .85412 L F
.577 .339 .519 r
.41996 .88238 m .42142 .88393 L .41881 .885 L F
.41996 .88238 m .42178 .8821 L .42142 .88393 L F
.819 .776 .813 r
.40943 .88758 m .41281 .88525 L .41152 .88774 L F
.599 .303 .438 r
.42413 .88002 m .4259 .88178 L .42394 .88181 L F
.42413 .88002 m .42629 .88007 L .4259 .88178 L F
.745 .496 .554 r
.48016 .8332 m .48326 .8336 L .48287 .83133 L F
.749 .499 .553 r
.48326 .8336 m .48504 .83243 L .48287 .83133 L F
.672 .577 .74 r
.47787 .82305 m .47595 .82322 L .47572 .82155 L F
.575 .066 .005 r
.52305 .81988 m .52618 .82009 L .52483 .81804 L F
.024 .299 .791 r
.52483 .81804 m .52618 .82009 L .5271 .81987 L F
.095 .549 .91 r
.52618 .82009 m .52827 .82072 L .5271 .81987 L F
.161 .7 .74 r
.52504 .82024 m .52618 .82009 L .5271 .81987 L F
.711 .592 .721 r
.43511 .84396 m .43829 .8464 L .43704 .84335 L F
.43511 .84396 m .43618 .84684 L .43829 .8464 L F
.706 .568 .697 r
.43618 .84684 m .43625 .84905 L .43829 .8464 L F
.68 .531 .677 r
.43829 .8464 m .43625 .84905 L .43852 .84876 L F
.643 .567 .754 r
.43704 .84335 m .43829 .8464 L .44046 .84601 L F
.64 .508 .686 r
.43852 .84876 m .44046 .84601 L .43829 .8464 L F
.711 .584 .712 r
.48504 .83243 m .4883 .83308 L .48869 .83118 L F
.613 .791 .967 r
.45878 .8197 m .45567 .81899 L .45775 .81846 L F
.637 .807 .964 r
.46086 .81873 m .45878 .8197 L .45775 .81846 L F
.097 .652 .796 r
.40887 .82207 m .41042 .82201 L .41138 .8221 L F
.093 0 0 r
.41042 .82201 m .40915 .82233 L .412 .82195 L F
.156 .693 .833 r
.41042 .82201 m .41244 .82189 L .41358 .822 L F
.093 0 0 r
.41042 .82201 m .412 .82195 L .41244 .82189 L F
.097 .652 .796 r
.40849 .82207 m .41042 .82201 L .40887 .82207 L F
.156 .693 .833 r
.41042 .82201 m .41358 .822 L .41138 .8221 L F
.093 .625 .868 r
.39458 .82303 m .3979 .82362 L .39592 .82378 L F
.428 .405 .731 r
.47551 .83606 m .47285 .83353 L .47503 .83347 L F
.625 .537 .734 r
.49545 .85145 m .49631 .85458 L .49801 .85361 L F
.71 .538 .654 r
.42702 .85641 m .43 .85905 L .42836 .85551 L F
.42702 .85641 m .42794 .85934 L .43 .85905 L F
.422 .12 .346 r
.5098 .86933 m .51238 .8672 L .51172 .8689 L F
.407 .105 .338 r
.51172 .8689 m .51238 .8672 L .51425 .8667 L F
.694 .567 .708 r
.43209 .8435 m .4343 .84108 L .43191 .84135 L F
.43209 .8435 m .43511 .84396 L .4343 .84108 L F
.619 .829 .981 r
.42737 .82109 m .4242 .82089 L .42619 .82032 L F
.441 .753 .994 r
.42815 .82014 m .42737 .82109 L .42619 .82032 L F
.42815 .82014 m .42939 .82097 L .42737 .82109 L F
.681 .588 .746 r
.43091 .83858 m .43191 .84135 L .43387 .83901 L F
.7 .617 .761 r
.43387 .83901 m .43191 .84135 L .4343 .84108 L F
.289 .77 .923 r
.40318 .82298 m .40517 .82276 L .40642 .82302 L F
.012 0 0 r
.40517 .82276 m .40849 .82207 L .40642 .82302 L F
.207 0 .16 r
.48415 .86146 m .48593 .85885 L .4863 .85923 L F
.769 .571 .631 r
.49657 .80778 m .49338 .80735 L .49544 .80667 L F
.35 0 0 r
.49657 .80778 m .49331 .8086 L .49544 .80874 L F
.769 .571 .631 r
.49657 .80778 m .49544 .80874 L .49476 .80828 L F
.35 0 0 r
.49657 .80778 m .49357 .80861 L .49331 .8086 L F
.742 .589 .685 r
.49476 .80828 m .49331 .8086 L .49338 .80735 L F
.49544 .80874 m .49331 .8086 L .49476 .80828 L F
.35 0 0 r
.49476 .80828 m .49557 .80867 L .49357 .80861 L F
.49657 .80778 m .49642 .80791 L .49476 .80828 L F
.49642 .80791 m .49557 .80867 L .49476 .80828 L F
.769 .571 .631 r
.49657 .80778 m .49476 .80828 L .49338 .80735 L F
.686 .784 .926 r
.49877 .80704 m .49657 .80778 L .49544 .80667 L F
.9 .913 .823 r
.49657 .80778 m .49452 .8105 L .49544 .80874 L F
.458 0 0 r
.49657 .80778 m .49752 .8086 L .49557 .80867 L F
.49657 .80778 m .49884 .80885 L .49752 .8086 L F
.673 .639 .807 r
.49877 .80704 m .49937 .8082 L .49657 .80778 L F
.685 .335 .377 r
.49937 .8082 m .49884 .80885 L .49657 .80778 L F
.714 .587 .711 r
.48487 .86402 m .48659 .86751 L .48257 .86693 L F
.792 .656 .712 r
.48659 .86751 m .48272 .86908 L .48257 .86693 L F
.48659 .86751 m .48568 .86952 L .48272 .86908 L F
.646 .522 .698 r
.48712 .86504 m .48659 .86751 L .48487 .86402 L F
.709 .379 .417 r
.4866 .84281 m .49002 .84121 L .48434 .84095 L F
.873 .77 .746 r
.48928 .84052 m .49002 .84121 L .4866 .84281 L F
.91 .949 .813 r
.48795 .84435 m .49097 .84171 L .48928 .84052 L F
.571 .241 .372 r
.40217 .89032 m .40393 .8919 L .40181 .89212 L F
.40217 .89032 m .40487 .88974 L .40393 .8919 L F
.745 .628 .73 r
.48269 .82041 m .48124 .82142 L .47998 .81813 L F
.655 .411 .539 r
.40594 .87176 m .40818 .87186 L .40863 .86974 L F
.58 .361 .547 r
.40818 .87186 m .41071 .86909 L .40863 .86974 L F
.63 .347 .47 r
.43662 .87448 m .43856 .87623 L .43655 .87616 L F
.43662 .87448 m .43861 .87462 L .43856 .87623 L F
.659 .478 .628 r
.41247 .86416 m .41574 .86481 L .41515 .86201 L F
.757 .648 .741 r
.41574 .86481 m .41777 .86202 L .41515 .86201 L F
.409 .848 .933 r
.41698 .8216 m .41358 .822 L .41545 .82132 L F
.598 .901 .986 r
.41885 .82093 m .41698 .8216 L .41545 .82132 L F
.698 .549 .68 r
.42836 .85551 m .43 .85905 L .43205 .85654 L F
.681 .474 .599 r
.45621 .8669 m .45617 .86916 L .4532 .86929 L F
.612 .422 .6 r
.45843 .86671 m .45617 .86916 L .45621 .8669 L F
.256 0 0 r
.3979 .82362 m .39944 .82393 L .40123 .82357 L F
.274 .776 .761 r
.40123 .82357 m .40208 .8232 L .40318 .82298 L F
.40123 .82357 m .39944 .82393 L .40208 .8232 L F
.625 .537 .734 r
.49545 .85145 m .49801 .85361 L .49616 .85098 L F
.705 .53 .649 r
.49801 .85361 m .49881 .85172 L .49616 .85098 L F
.738 .434 .466 r
.48323 .84312 m .48296 .84047 L .48097 .84091 L F
.718 .49 .579 r
.48323 .84312 m .48434 .84095 L .48296 .84047 L F
.666 .527 .685 r
.43642 .85134 m .43852 .84876 L .43625 .84905 L F
.729 .669 .791 r
.49544 .80874 m .49452 .8105 L .49331 .8086 L F
.719 .729 .859 r
.47208 .85788 m .4731 .85929 L .46989 .85889 L F
.549 .511 .766 r
.47405 .85601 m .4731 .85929 L .47208 .85788 L F
.47405 .85601 m .47531 .8593 L .4731 .85929 L F
.793 .783 .844 r
.48859 .82126 m .49171 .82116 L .49028 .82014 L F
.498 .323 .574 r
.46658 .85398 m .46655 .85668 L .46455 .85697 L F
.952 .652 .432 r
.47782 .83372 m .47551 .83606 L .47503 .83347 L F
.47782 .83372 m .47667 .83491 L .47551 .83606 L F
.724 .727 .852 r
.46387 .81984 m .46086 .81873 L .46315 .8183 L F
.73 .824 .923 r
.46615 .8182 m .46387 .81984 L .46315 .8183 L F
.487 .313 .57 r
.50566 .87436 m .5077 .8719 L .5075 .87393 L F
.465 .23 .473 r
.50514 .87836 m .50566 .87436 L .5075 .87393 L F
.646 .522 .698 r
.48712 .86504 m .48487 .86402 L .48676 .86398 L F
.711 .179 0 r
.48812 .86644 m .48712 .86504 L .48676 .86398 L F
.615 .845 .987 r
.4242 .82089 m .42223 .82151 L .42091 .8208 L F
.636 .077 0 r
.50662 .80838 m .50965 .80992 L .51059 .80983 L F
.619 .959 .854 r
.51059 .80983 m .51152 .80868 L .51235 .80951 L F
.51059 .80983 m .50965 .80992 L .51152 .80868 L F
.227 0 0 r
.40537 .83889 m .40469 .83841 L .40654 .83889 L F
.40537 .83889 m .40276 .83939 L .40469 .83841 L F
.869 .768 .748 r
.49099 .81642 m .48974 .81837 L .48925 .81515 L F
.607 .619 .837 r
.50079 .80581 m .49937 .8082 L .49877 .80704 L F
.50079 .80581 m .50149 .80792 L .49937 .8082 L F
.663 .461 .6 r
.50149 .80792 m .49884 .80885 L .49937 .8082 L F
.645 .544 .726 r
.4343 .84108 m .43602 .83841 L .43387 .83901 L F
.4343 .84108 m .43707 .84159 L .43602 .83841 L F
.647 .539 .718 r
.4343 .84108 m .43511 .84396 L .43707 .84159 L F
.791 .635 .688 r
.49374 .87745 m .49328 .87995 L .49176 .87674 L F
0 0 .088 r
.51898 .815 m .51748 .81863 L .51972 .81839 L F
.713 .546 .661 r
.47914 .84917 m .47932 .85151 L .47631 .85141 L F
.731 .613 .727 r
.42064 .86428 m .42337 .86383 L .4227 .8617 L F
.522 .077 .133 r
.42302 .86816 m .42039 .86705 L .41961 .86828 L F
.508 0 0 r
.42223 .8679 m .42039 .86705 L .42302 .86816 L F
.411 .265 .571 r
.42064 .86428 m .42223 .8679 L .42337 .86383 L F
.627 .498 .686 r
.42337 .86383 m .42486 .86105 L .4227 .8617 L F
.42337 .86383 m .42566 .86413 L .42486 .86105 L F
.748 .516 .579 r
.42223 .8679 m .42566 .86413 L .42337 .86383 L F
.362 .732 .988 r
.48676 .86398 m .48487 .86402 L .48357 .86322 L F
.636 .83 .975 r
.43793 .8207 m .43468 .82054 L .4367 .81986 L F
.517 .791 .995 r
.43873 .81956 m .43793 .8207 L .4367 .81986 L F
.43873 .81956 m .43993 .82038 L .43793 .8207 L F
.666 .527 .685 r
.43642 .85134 m .43928 .85154 L .43852 .84876 L F
.638 .488 .663 r
.43642 .85134 m .4392 .85367 L .43928 .85154 L F
.43642 .85134 m .43742 .85387 L .4392 .85367 L F
.652 .586 .768 r
.47797 .82074 m .47572 .82155 L .47499 .8187 L F
.672 .577 .74 r
.47787 .82305 m .47572 .82155 L .47797 .82074 L F
.727 .787 .9 r
.45343 .81992 m .4504 .81978 L .45229 .81911 L F
.655 .846 .973 r
.45567 .81899 m .45343 .81992 L .45229 .81911 L F
.606 .83 .986 r
.41934 .83534 m .42219 .83559 L .42089 .83495 L F
.636 .873 .986 r
.42089 .83495 m .42219 .83559 L .42403 .8348 L F
.706 .627 .766 r
.43707 .84159 m .43511 .84396 L .43704 .84335 L F
.678 .387 .473 r
.46887 .86666 m .47224 .86641 L .47095 .86918 L F
.661 .355 .443 r
.47224 .86641 m .47438 .86858 L .47095 .86918 L F
.47224 .86641 m .47414 .86694 L .47438 .86858 L F
.732 .481 .549 r
.47944 .86688 m .48257 .86693 L .48272 .86908 L F
.617 .376 .53 r
.44389 .87189 m .44588 .87398 L .44476 .87417 L F
.641 .375 .501 r
.44389 .87189 m .44598 .87206 L .44588 .87398 L F
.751 .631 .727 r
.47998 .81813 m .48124 .82142 L .47797 .82074 L F
.76 .73 .824 r
.48124 .82142 m .47787 .82305 L .47797 .82074 L F
.658 .809 .956 r
.51051 .8155 m .51493 .81633 L .51343 .81515 L F
.773 .767 .847 r
.51493 .81633 m .51694 .81489 L .51343 .81515 L F
.739 .587 .685 r
.4173 .86393 m .42057 .86206 L .41948 .86133 L F
.4173 .86393 m .42064 .86428 L .42057 .86206 L F
.681 .54 .687 r
.42057 .86206 m .42064 .86428 L .4227 .8617 L F
.811 .527 .507 r
.486 .8717 m .4889 .87208 L .48916 .87423 L F
.178 .377 .822 r
.49516 .86161 m .49801 .86407 L .49733 .86155 L F
.713 .177 0 r
.48625 .82313 m .48825 .82509 L .48913 .82514 L F
.813 .759 .802 r
.48622 .8254 m .48913 .82514 L .48825 .82509 L F
.48622 .8254 m .48681 .82751 L .48913 .82514 L F
.75 .601 .691 r
.46912 .86447 m .46544 .86677 L .46577 .86419 L F
.46912 .86447 m .46887 .86666 L .46544 .86677 L F
.576 .837 .994 r
.43269 .82113 m .42939 .82097 L .43144 .8206 L F
.582 .865 .995 r
.43468 .82054 m .43269 .82113 L .43144 .8206 L F
.66 .57 .743 r
.41326 .86675 m .41574 .86481 L .41247 .86416 L F
.53 .271 .468 r
.40487 .88974 m .40624 .89206 L .40393 .8919 L F
.40487 .88974 m .40689 .88965 L .40624 .89206 L F
.744 .631 .734 r
.48402 .8129 m .48498 .81593 L .48203 .81557 L F
.497 .324 .576 r
.48706 .81309 m .48498 .81593 L .48402 .8129 L F
.48706 .81309 m .48709 .81549 L .48498 .81593 L F
.526 .422 .68 r
.48709 .81549 m .48717 .81773 L .48498 .81593 L F
.66 .57 .743 r
.41326 .86675 m .41532 .86644 L .41574 .86481 L F
.678 .386 .471 r
.4124 .8687 m .41525 .86889 L .41326 .86675 L F
.618 .389 .547 r
.41525 .86889 m .41532 .86644 L .41326 .86675 L F
.306 0 0 r
.3888 .8407 m .39045 .8409 L .38813 .84088 L F
.723 .496 .582 r
.47338 .84917 m .47321 .85129 L .47086 .84883 L F
.759 .516 .566 r
.47338 .84917 m .47631 .85141 L .47321 .85129 L F
.863 .773 .761 r
.48578 .81036 m .4826 .81208 L .48449 .80948 L F
.48578 .81036 m .48402 .8129 L .4826 .81208 L F
.512 .584 .865 r
.48703 .80795 m .48578 .81036 L .48449 .80948 L F
.759 .547 .609 r
.48652 .85115 m .48853 .84948 L .48736 .84913 L F
.48652 .85115 m .48975 .85217 L .48853 .84948 L F
.729 .824 .923 r
.44843 .82033 m .44517 .82041 L .4473 .81933 L F
.595 .837 .99 r
.44926 .81899 m .44843 .82033 L .4473 .81933 L F
.44926 .81899 m .4504 .81978 L .44843 .82033 L F
.64 .508 .686 r
.43852 .84876 m .44154 .84922 L .44046 .84601 L F
.638 .51 .69 r
.43852 .84876 m .44134 .85122 L .44154 .84922 L F
.43852 .84876 m .43928 .85154 L .44134 .85122 L F
0 0 0 r
.41934 .83534 m .41825 .83568 L .41707 .83578 L F
.41825 .83568 m .41529 .83691 L .41707 .83578 L F
.968 .82 .643 r
.48311 .87149 m .48355 .87057 L .48257 .87371 L F
.793 .513 .514 r
.48393 .87004 m .48568 .86952 L .486 .8717 L F
.48272 .86908 m .48443 .86933 L .48393 .87004 L F
.48443 .86933 m .48568 .86952 L .48393 .87004 L F
.48272 .86908 m .486 .8717 L .48416 .86928 L F
.968 .82 .643 r
.48355 .87057 m .48416 .86928 L .48385 .87015 L F
.48355 .87057 m .48385 .87015 L .48257 .87371 L F
.657 .49 .646 r
.43 .85905 m .43296 .86034 L .43205 .85654 L F
.602 .413 .598 r
.43296 .86034 m .43512 .85685 L .43205 .85654 L F
.813 .707 .748 r
.41777 .86202 m .4173 .86393 L .41948 .86133 L F
.598 .259 .367 r
.4008 .87233 m .40274 .87387 L .40376 .87161 L F
.7 .414 .488 r
.40274 .87387 m .40594 .87176 L .40376 .87161 L F
.763 .932 .941 r
.48419 .82819 m .48681 .82751 L .48622 .8254 L F
.658 .56 .733 r
.43704 .84335 m .43917 .84096 L .43707 .84159 L F
.43704 .84335 m .44028 .84403 L .43917 .84096 L F
.643 .567 .754 r
.43704 .84335 m .44046 .84601 L .44028 .84403 L F
.354 .623 .954 r
.52647 .81333 m .52403 .81227 L .5265 .81229 L F
.296 0 0 r
.52576 .81288 m .5265 .81229 L .52403 .81227 L F
.812 .49 .446 r
.52488 .81421 m .52579 .81313 L .5255 .81309 L F
.52579 .81313 m .5265 .81229 L .52576 .81288 L F
.52579 .81313 m .52576 .81288 L .5255 .81309 L F
.296 0 0 r
.52574 .81276 m .52403 .81227 L .52254 .81049 L F
.52608 .813 m .5265 .81229 L .52576 .81288 L F
.52608 .813 m .52576 .81288 L .52574 .81276 L F
.52576 .81288 m .52403 .81227 L .52574 .81276 L F
.427 .443 .774 r
.52394 .80892 m .52584 .81253 L .52254 .81049 L F
.812 .49 .446 r
.52566 .81296 m .5265 .81229 L .52594 .81235 L F
.641 .545 .73 r
.5265 .8113 m .52584 .81253 L .52394 .80892 L F
.812 .49 .446 r
.52584 .81253 m .52594 .81235 L .52591 .81235 L F
.52566 .81296 m .52594 .81235 L .52584 .81253 L F
.52591 .81235 m .52601 .81234 L .5265 .8113 L F
.52601 .81234 m .5265 .81229 L .5265 .8113 L F
0 0 0 r
.5265 .8113 m .52788 .80833 L .5286 .81152 L F
.369 .389 .75 r
.52874 .81509 m .52647 .81333 L .5265 .81229 L F
.818 .81 .323 r
.5265 .8113 m .5265 .81229 L .52608 .813 L F
.369 .389 .75 r
.52874 .81509 m .52786 .81593 L .52647 .81333 L F
.52874 .81509 m .52793 .81408 L .52797 .81412 L F
.52793 .81408 m .5265 .81229 L .52797 .81412 L F
0 0 0 r
.52841 .81464 m .52797 .81412 L .52706 .81597 L F
.484 .542 .84 r
.52797 .81412 m .53091 .81445 L .52874 .81509 L F
0 0 0 r
.52886 .8142 m .52797 .81412 L .52841 .81464 L F
.812 .49 .446 r
.52488 .81421 m .52797 .81412 L .5265 .81229 L F
.641 .545 .73 r
.5265 .8113 m .52608 .813 L .52584 .81253 L F
0 0 0 r
.5265 .8113 m .52609 .81258 L .52634 .812 L F
.5265 .8113 m .52634 .812 L .52776 .80862 L F
.5265 .8113 m .52776 .80862 L .52788 .80833 L F
.427 .443 .774 r
.52584 .81253 m .52574 .81276 L .52254 .81049 L F
.91 .98 .715 r
.52472 .81357 m .52489 .81418 L .52592 .81234 L F
.52583 .81216 m .52592 .81234 L .5265 .8113 L F
.52472 .81357 m .52592 .81234 L .52583 .81216 L F
.812 .49 .446 r
.5255 .81309 m .52566 .81296 L .52591 .81235 L F
.91 .98 .715 r
.52472 .81357 m .52583 .81216 L .52579 .81314 L F
.52583 .81216 m .5265 .8113 L .52589 .81224 L F
.641 .545 .73 r
.5265 .8113 m .52394 .80892 L .52589 .81224 L F
.5265 .8113 m .52589 .81224 L .52609 .81258 L F
.91 .98 .715 r
.52589 .81224 m .5265 .8113 L .52619 .8121 L F
.88 .83 .794 r
.52631 .81197 m .52593 .81228 L .52475 .81009 L F
.91 .98 .715 r
.52589 .81224 m .52619 .8121 L .52597 .81234 L F
.88 .83 .794 r
.52634 .812 m .52609 .81258 L .52593 .81228 L F
.756 .563 .636 r
.52612 .81295 m .52579 .81314 L .5265 .8113 L F
.88 .83 .794 r
.52634 .812 m .52619 .8121 L .52631 .81197 L F
.52619 .8121 m .52593 .81228 L .52631 .81197 L F
.91 .98 .715 r
.52597 .81234 m .52619 .8121 L .52605 .81246 L F
0 0 .408 r
.52597 .81234 m .52609 .81258 L .52589 .81224 L F
.427 .443 .774 r
.52584 .81253 m .52608 .813 L .52574 .81276 L F
.91 .98 .715 r
.52583 .81216 m .52605 .81246 L .52579 .81314 L F
0 0 .408 r
.52565 .81176 m .52597 .81234 L .5258 .81208 L F
.52597 .81234 m .52589 .81224 L .5258 .81208 L F
.488 .808 1 r
.52459 .81309 m .52472 .81357 L .52579 .81314 L F
.52246 .81299 m .52472 .81357 L .52459 .81309 L F
.91 .98 .715 r
.52472 .81357 m .52488 .81421 L .52489 .81418 L F
0 0 .408 r
.52475 .81009 m .52565 .81176 L .52394 .80892 L F
.52565 .81176 m .5258 .81208 L .52394 .80892 L F
.88 .83 .794 r
.52788 .80833 m .52634 .812 L .52475 .81009 L F
.756 .563 .636 r
.5286 .81152 m .52612 .81295 L .52634 .812 L F
.52724 .81138 m .52634 .812 L .5265 .8113 L F
.5286 .81152 m .52634 .812 L .52724 .81138 L F
.621 .484 .673 r
.46847 .8516 m .46872 .85382 L .46658 .85398 L F
.597 .403 .589 r
.46872 .8563 m .46658 .85398 L .46872 .85382 L F
.46872 .8563 m .46655 .85668 L .46658 .85398 L F
.625 .388 .538 r
.41467 .88469 m .41443 .88675 L .41152 .88774 L F
.585 .357 .536 r
.41666 .88455 m .41443 .88675 L .41467 .88469 L F
.554 .842 .998 r
.50176 .81466 m .5009 .8158 L .50292 .8153 L F
.582 .613 .848 r
.43053 .83635 m .43171 .83374 L .42945 .8341 L F
.43053 .83635 m .43288 .83614 L .43171 .83374 L F
.583 .491 .716 r
.43053 .83635 m .43091 .83858 L .43288 .83614 L F
.85 .819 .818 r
.4784 .83549 m .47697 .83832 L .47921 .83816 L F
.473 .363 .648 r
.48016 .8332 m .4784 .83549 L .47975 .83515 L F
.742 .641 .748 r
.47921 .83816 m .47975 .83515 L .4784 .83549 L F
.4 .152 .419 r
.5077 .8719 m .5098 .86933 L .50957 .87143 L F
.496 .3 .543 r
.50957 .87143 m .5098 .86933 L .51172 .8689 L F
.729 .546 .644 r
.46577 .86419 m .46544 .86677 L .46391 .86655 L F
.67 .617 .787 r
.43091 .83858 m .43387 .83901 L .43288 .83614 L F
.682 .395 .481 r
.47414 .86694 m .47753 .86653 L .47611 .86899 L F
.709 .428 .497 r
.47753 .86653 m .47938 .86895 L .47611 .86899 L F
.68 .425 .529 r
.47753 .86653 m .47944 .86688 L .47938 .86895 L F
.756 .49 .53 r
.47086 .84883 m .47321 .85129 L .47092 .8513 L F
.736 .615 .724 r
.41854 .86677 m .42064 .86428 L .4173 .86393 L F
.618 .443 .623 r
.41854 .86677 m .42039 .86705 L .42064 .86428 L F
.411 .265 .571 r
.42064 .86428 m .42039 .86705 L .42223 .8679 L F
.235 0 .028 r
.51294 .85898 m .50986 .86128 L .51194 .86095 L F
.594 .248 .353 r
.51486 .86058 m .51294 .85898 L .51194 .86095 L F
.51486 .86058 m .5152 .85915 L .51294 .85898 L F
.702 .383 .433 r
.46544 .86677 m .46887 .86666 L .46939 .86857 L F
.708 .386 .431 r
.46887 .86666 m .47095 .86918 L .46939 .86857 L F
.532 .88 .986 r
.51343 .81515 m .51694 .81489 L .51535 .81455 L F
.336 .702 .983 r
.51694 .81489 m .51737 .81413 L .51535 .81455 L F
.51694 .81489 m .51898 .815 L .51737 .81413 L F
.669 .515 .667 r
.42486 .86105 m .42794 .86156 L .42794 .85934 L F
.585 .404 .603 r
.42566 .86413 m .42794 .86156 L .42486 .86105 L F
.652 .586 .768 r
.47797 .82074 m .47659 .81742 L .47777 .81813 L F
.668 .626 .798 r
.47879 .81531 m .47777 .81813 L .47659 .81742 L F
.47879 .81531 m .47998 .81813 L .47777 .81813 L F
.673 .518 .667 r
.47998 .81813 m .47797 .82074 L .47777 .81813 L F
.562 .296 .471 r
.4315 .87948 m .43137 .87724 L .43321 .87898 L F
.573 .295 .456 r
.43137 .87724 m .43343 .87713 L .43321 .87898 L F
.81 .679 .72 r
.47932 .85151 m .47909 .85412 L .47799 .8542 L F
.772 .573 .629 r
.47909 .85412 m .47735 .8565 L .47799 .8542 L F
.47909 .85412 m .48078 .85684 L .47735 .8565 L F
.593 .095 .042 r
.49231 .88111 m .49328 .87995 L .49563 .88114 L F
.721 .608 .731 r
.41532 .86644 m .41854 .86677 L .4173 .86393 L F
.729 .486 .56 r
.41525 .86889 m .41854 .86677 L .41532 .86644 L F
.41525 .86889 m .41808 .8676 L .41854 .86677 L F
.56 .117 .154 r
.41961 .86828 m .41854 .86677 L .41808 .8676 L F
.41961 .86828 m .42039 .86705 L .41854 .86677 L F
.338 0 .227 r
.52099 .86406 m .52177 .86217 L .52366 .86149 L F
.306 .103 .432 r
.52177 .86217 m .52369 .85907 L .52366 .86149 L F
.631 .411 .565 r
.45122 .86926 m .4517 .87136 L .44806 .87192 L F
.699 .454 .548 r
.45122 .86926 m .45318 .87178 L .4517 .87136 L F
.658 .449 .589 r
.4532 .86929 m .45318 .87178 L .45122 .86926 L F
.713 .55 .667 r
.42794 .85934 m .42794 .86156 L .43 .85905 L F
.708 .544 .664 r
.42794 .86156 m .43041 .86174 L .43 .85905 L F
.642 .498 .672 r
.43 .85905 m .4329 .86069 L .43296 .86034 L F
.43 .85905 m .43041 .86174 L .4329 .86069 L F
.209 0 0 r
.39415 .84022 m .39282 .84083 L .39085 .84103 L F
.362 0 0 r
.39586 .84025 m .39282 .84083 L .39415 .84022 L F
.544 .793 .99 r
.4802 .86166 m .48233 .8606 L .48037 .85895 L F
.4802 .86166 m .48358 .86143 L .48233 .8606 L F
.549 .322 .524 r
.42178 .8821 m .4241 .88381 L .42142 .88393 L F
.42178 .8821 m .42394 .88181 L .4241 .88381 L F
.432 .848 .962 r
.53042 .8178 m .52889 .81675 L .52874 .81509 L F
.499 .674 .943 r
.53213 .81617 m .53042 .8178 L .52874 .81509 L F
0 .079 .612 r
.5321 .8138 m .53237 .81501 L .53213 .81617 L F
.593 .317 .466 r
.53042 .8178 m .53301 .81803 L .53242 .81998 L F
.561 .712 .942 r
.53466 .81743 m .53301 .81803 L .53213 .81617 L F
.343 .081 .364 r
.53242 .81998 m .53301 .81803 L .53466 .81743 L F
.561 .712 .942 r
.53466 .81743 m .53213 .81617 L .53322 .81888 L F
0 .274 .747 r
.53392 .8187 m .53615 .81994 L .53357 .81878 L F
.593 .317 .466 r
.53042 .8178 m .53242 .81998 L .53047 .82061 L F
.737 .947 .949 r
.53135 .81959 m .53317 .81896 L .53304 .81854 L F
.343 .081 .364 r
.53242 .81998 m .53466 .81743 L .53392 .8187 L F
.737 .947 .949 r
.53317 .81896 m .53392 .8187 L .53329 .81858 L F
0 .079 .612 r
.53313 .81848 m .53321 .81883 L .53303 .81841 L F
.53321 .81883 m .53321 .81884 L .53303 .81841 L F
.737 .947 .949 r
.53317 .81896 m .53329 .81858 L .53304 .81854 L F
0 .079 .612 r
.53321 .81883 m .53322 .81888 L .53321 .81884 L F
.67 .603 .771 r
.53566 .81628 m .53322 .81888 L .5321 .8138 L F
0 .274 .747 r
.53329 .81858 m .53357 .81878 L .53304 .81854 L F
.53392 .8187 m .53357 .81878 L .53329 .81858 L F
0 .079 .612 r
.53237 .81501 m .53313 .81848 L .53213 .81617 L F
.499 .674 .943 r
.53213 .81617 m .53301 .81803 L .53176 .81792 L F
0 .079 .612 r
.53313 .81848 m .53303 .81841 L .53213 .81617 L F
.499 .674 .943 r
.53213 .81617 m .53176 .81792 L .53042 .8178 L F
.811 .679 .719 r
.47321 .85129 m .4743 .85409 L .47082 .85359 L F
.76 .512 .558 r
.4743 .85409 m .47091 .85543 L .47082 .85359 L F
.4743 .85409 m .47405 .85601 L .47091 .85543 L F
.754 .653 .75 r
.47631 .85141 m .4743 .85409 L .47321 .85129 L F
.593 .428 .627 r
.47631 .85141 m .47621 .85375 L .4743 .85409 L F
.714 .552 .668 r
.47621 .85375 m .47405 .85601 L .4743 .85409 L F
.517 .6 .876 r
.50603 .81591 m .50931 .81811 L .50839 .81691 L F
.75 .761 .861 r
.50839 .81691 m .50931 .81811 L .51051 .8155 L F
.582 .806 .984 r
.48629 .85323 m .48254 .85414 L .48249 .85328 L F
.556 .77 .978 r
.44317 .82101 m .43993 .82038 L .44193 .82012 L F
.622 .811 .972 r
.44517 .82041 m .44317 .82101 L .44193 .82012 L F
.589 .314 .467 r
.43856 .87623 m .43861 .87462 L .44055 .8764 L F
.655 .293 .345 r
.43861 .87462 m .44291 .87489 L .44055 .8764 L F
.744 .605 .703 r
.48717 .81773 m .49028 .82014 L .48974 .81837 L F
.767 .702 .791 r
.48925 .81515 m .48974 .81837 L .49244 .81536 L F
.526 .136 .243 r
.39753 .87395 m .39968 .8739 L .4008 .87233 L F
.621 .243 .305 r
.39968 .8739 m .40274 .87387 L .4008 .87233 L F
.753 .607 .696 r
.47932 .85151 m .47621 .85375 L .47631 .85141 L F
.47932 .85151 m .47799 .8542 L .47621 .85375 L F
.76 .689 .783 r
.47975 .83515 m .48272 .83568 L .48326 .8336 L F
.773 .656 .734 r
.48075 .83794 m .48272 .83568 L .47975 .83515 L F
.522 .228 .409 r
.40895 .88941 m .40943 .88758 L .41119 .88871 L F
.561 .191 .296 r
.40943 .88758 m .41152 .88774 L .41119 .88871 L F
.871 .565 .466 r
.52228 .86091 m .52369 .85907 L .52194 .85881 L F
.606 .542 .757 r
.52554 .85993 m .52366 .86149 L .52369 .85907 L F
.546 .144 .232 r
.52554 .85993 m .52369 .85907 L .52228 .86091 L F
.686 .784 .926 r
.49877 .80704 m .49544 .80667 L .49733 .80608 L F
.665 .829 .962 r
.50079 .80581 m .49877 .80704 L .49733 .80608 L F
.237 0 0 r
.49739 .88136 m .49875 .87991 L .50068 .87943 L F
.708 .605 .739 r
.44028 .84403 m .44046 .84601 L .44245 .84351 L F
.639 .505 .683 r
.44245 .84351 m .44046 .84601 L .44265 .84575 L F
.686 .533 .673 r
.44046 .84601 m .44344 .84864 L .44265 .84575 L F
.44046 .84601 m .44154 .84922 L .44344 .84864 L F
.704 .636 .778 r
.43288 .83614 m .43387 .83901 L .43602 .83841 L F
.673 .452 .576 r
.42894 .87982 m .4259 .88178 L .42629 .88007 L F
.307 .782 .924 r
.39015 .825 m .39135 .82499 L .39134 .825 L F
.5 .121 .252 r
.39134 .825 m .39348 .82498 L .39458 .82303 L F
.307 .782 .924 r
.39135 .82499 m .39348 .82498 L .39134 .825 L F
.519 .822 .494 r
.39133 .82502 m .39134 .825 L .39257 .82372 L F
.39066 .82573 m .39134 .825 L .39133 .82502 L F
.441 .843 .975 r
.39066 .82573 m .38939 .82541 L .39134 .825 L F
.725 .598 .713 r
.44022 .83321 m .44334 .83566 L .44214 .83287 L F
.44022 .83321 m .44138 .83616 L .44334 .83566 L F
.694 .537 .669 r
.44112 .8383 m .44334 .83566 L .44138 .83616 L F
.44112 .8383 m .44428 .83879 L .44334 .83566 L F
.645 .641 .832 r
.44214 .83287 m .44334 .83566 L .44511 .83376 L F
.622 .605 .812 r
.44334 .83566 m .44544 .83573 L .44511 .83376 L F
.667 .521 .677 r
.44334 .83566 m .44648 .8384 L .44544 .83573 L F
.44334 .83566 m .44428 .83879 L .44648 .8384 L F
.697 .722 .869 r
.50292 .8153 m .50603 .81591 L .50505 .81453 L F
.508 .641 .915 r
.50505 .81453 m .50603 .81591 L .50822 .81556 L F
.511 .52 .802 r
.50603 .81591 m .50839 .81691 L .50822 .81556 L F
.55 .852 .539 r
.48917 .81145 m .48899 .81162 L .4883 .81242 L F
.894 .887 .818 r
.4883 .81242 m .48706 .81309 L .48777 .81304 L F
.4883 .81242 m .48777 .81304 L .48912 .81293 L F
.4883 .81242 m .48709 .81549 L .48706 .81309 L F
.55 .852 .539 r
.48899 .81162 m .48628 .81438 L .4883 .81242 L F
.735 .824 .92 r
.51728 .80974 m .51434 .80894 L .51629 .80911 L F
.416 .759 .995 r
.51861 .80848 m .51728 .80974 L .51629 .80911 L F
.51861 .80848 m .52058 .80978 L .51728 .80974 L F
.559 .347 .55 r
.5077 .8719 m .50932 .87328 L .5075 .87393 L F
.5077 .8719 m .50957 .87143 L .50932 .87328 L F
.619 .44 .618 r
.4392 .85367 m .44134 .85122 L .43928 .85154 L F
.298 .367 .765 r
.50178 .81037 m .50259 .81304 L .50389 .81212 L F
0 0 0 r
.50259 .81304 m .50176 .81466 L .50389 .81212 L F
.407 .015 .18 r
.49972 .81498 m .50176 .81466 L .50259 .81304 L F
.376 0 0 r
.4134 .83731 m .41065 .83804 L .412 .83709 L F
0 0 0 r
.44055 .8764 m .44291 .87489 L .44476 .87417 L F
.492 .208 .41 r
.51425 .8667 m .51671 .86459 L .51637 .86654 L F
.51 .251 .458 r
.51637 .86654 m .51671 .86459 L .51873 .86434 L F
.732 .481 .549 r
.47944 .86688 m .48272 .86908 L .47938 .86895 L F
.45 .865 .952 r
.38408 .82641 m .38751 .82604 L .3854 .82631 L F
.68 .445 .559 r
.44806 .87192 m .44588 .87398 L .44598 .87206 L F
.552 .425 .662 r
.47092 .8513 m .46872 .85382 L .46847 .8516 L F
.77 .684 .768 r
.41574 .86481 m .41532 .86644 L .4173 .86393 L F
.762 .956 .935 r
.4888 .81187 m .4883 .81242 L .48912 .81293 L F
.984 .704 .347 r
.4883 .81242 m .48925 .81515 L .48912 .81293 L F
.772 .518 .551 r
.48912 .81293 m .48925 .81515 L .49244 .81536 L F
.857 .703 .69 r
.48502 .8225 m .48622 .8254 L .48625 .82313 L F
.783 .889 .921 r
.48502 .8225 m .48625 .82313 L .48859 .82126 L F
.626 .088 0 r
.487 .82421 m .48625 .82313 L .48622 .8254 L F
.487 .82421 m .48825 .82509 L .48625 .82313 L F
.767 .674 .76 r
.48203 .81557 m .47998 .81813 L .47879 .81531 L F
.866 .925 .864 r
.52305 .81988 m .52392 .81733 L .52184 .81794 L F
.52305 .81988 m .52483 .81804 L .52392 .81733 L F
.727 .556 .66 r
.48078 .85684 m .48037 .85895 L .4772 .85827 L F
.722 .596 .715 r
.43805 .83584 m .44138 .83616 L .44022 .83321 L F
.697 .585 .725 r
.43805 .83584 m .44112 .8383 L .44138 .83616 L F
.709 .389 .433 r
.47414 .86694 m .47611 .86899 L .47438 .86858 L F
.682 .565 .717 r
.43602 .83841 m .43707 .84159 L .43917 .84096 L F
.764 .686 .776 r
.48048 .81469 m .48203 .81557 L .47879 .81531 L F
.776 .68 .757 r
.48402 .8129 m .48203 .81557 L .48048 .81469 L F
.48402 .8129 m .48048 .81469 L .4826 .81208 L F
.076 0 0 r
.52483 .81804 m .52786 .81593 L .52783 .81786 L F
.448 .793 .998 r
.52483 .81804 m .52783 .81786 L .52392 .81733 L F
.024 .299 .791 r
.52483 .81804 m .5271 .81987 L .52783 .81786 L F
.602 .413 .598 r
.43296 .86034 m .43532 .8595 L .43512 .85685 L F
.633 .436 .598 r
.43512 .85685 m .43711 .8588 L .43705 .85645 L F
.43512 .85685 m .43532 .8595 L .43711 .8588 L F
.598 .901 .986 r
.41885 .82093 m .41545 .82132 L .41751 .8214 L F
.086 .645 .755 r
.41941 .82082 m .41885 .82093 L .41751 .8214 L F
.41941 .82082 m .42091 .8208 L .41885 .82093 L F
.704 .636 .778 r
.43288 .83614 m .43602 .83841 L .43482 .83534 L F
.723 .615 .737 r
.43482 .83534 m .43602 .83841 L .43805 .83584 L F
.705 .588 .723 r
.43602 .83841 m .43915 .83874 L .43805 .83584 L F
.682 .565 .717 r
.43602 .83841 m .43917 .84096 L .43915 .83874 L F
.656 .696 .875 r
.47499 .8187 m .47142 .81779 L .47339 .81712 L F
.759 .692 .787 r
.47659 .81742 m .47499 .8187 L .47339 .81712 L F
.652 .586 .768 r
.47797 .82074 m .47499 .8187 L .47659 .81742 L F
.697 .585 .725 r
.43805 .83584 m .43915 .83874 L .44112 .8383 L F
.688 .544 .684 r
.43915 .83874 m .43917 .84096 L .44112 .8383 L F
.658 .73 .903 r
.46957 .81878 m .46615 .8182 L .46826 .81776 L F
.739 .795 .897 r
.47142 .81779 m .46957 .81878 L .46826 .81776 L F
.799 .766 .822 r
.49331 .8086 m .49217 .80666 L .49338 .80735 L F
.629 .863 .986 r
.49544 .80667 m .49338 .80735 L .49217 .80666 L F
.757 .648 .741 r
.41574 .86481 m .4173 .86393 L .41777 .86202 L F
.612 .422 .6 r
.45843 .86671 m .45836 .86903 L .45617 .86916 L F
.7 .468 .569 r
.45843 .86671 m .46034 .86895 L .45836 .86903 L F
.45843 .86671 m .46066 .86681 L .46034 .86895 L F
.58 .361 .547 r
.40818 .87186 m .41047 .87183 L .41071 .86909 L F
.526 .331 .559 r
.41047 .87183 m .4124 .8687 L .41071 .86909 L F
.686 .476 .597 r
.46391 .86655 m .46034 .86895 L .46066 .86681 L F
.674 .439 .557 r
.4532 .86929 m .45616 .8713 L .45318 .87178 L F
.4532 .86929 m .45617 .86916 L .45616 .8713 L F
.828 .647 .658 r
.48898 .87655 m .49176 .87674 L .4913 .87734 L F
.422 .613 .929 r
.46989 .85889 m .46655 .85668 L .46872 .8563 L F
.699 .653 .8 r
.47091 .85543 m .46989 .85889 L .46872 .8563 L F
.47091 .85543 m .47208 .85788 L .46989 .85889 L F
.012 0 0 r
.40517 .82276 m .40716 .82247 L .40849 .82207 L F
.086 0 0 r
.40716 .82247 m .41042 .82201 L .40849 .82207 L F
.584 .414 .618 r
.43742 .85387 m .43915 .85608 L .4392 .85367 L F
.43742 .85387 m .43705 .85645 L .43915 .85608 L F
.742 .641 .748 r
.47921 .83816 m .48075 .83794 L .47975 .83515 L F
.824 .604 .604 r
.47921 .83816 m .48097 .84091 L .48075 .83794 L F
.779 .539 .572 r
.48097 .84091 m .47921 .83816 L .48075 .83794 L F
.738 .737 .85 r
.47555 .81522 m .47659 .81742 L .47339 .81712 L F
.748 .741 .846 r
.47879 .81531 m .47659 .81742 L .47555 .81522 L F
.704 .585 .719 r
.43917 .84096 m .44028 .84403 L .44245 .84351 L F
.748 .516 .579 r
.42223 .8679 m .42569 .86596 L .42566 .86413 L F
.585 .404 .603 r
.42566 .86413 m .4278 .86393 L .42794 .86156 L F
.637 .467 .636 r
.42569 .86596 m .4278 .86393 L .42566 .86413 L F
0 0 0 r
.47973 .86207 m .47999 .8617 L .48116 .8601 L F
.887 .522 .346 r
.48048 .86325 m .47999 .8617 L .47903 .86302 L F
.48048 .86325 m .47999 .8617 L .47903 .86302 L F
0 0 0 r
.47903 .86302 m .47999 .8617 L .47973 .86207 L F
.266 .637 .964 r
.48115 .86194 m .4801 .86155 L .47999 .8617 L F
.4801 .86155 m .47846 .86095 L .47999 .8617 L F
.874 .515 .365 r
.48048 .86325 m .48115 .86194 L .47999 .8617 L F
.686 .278 .267 r
.48048 .86325 m .48357 .86322 L .48115 .86194 L F
.825 .75 .781 r
.4865 .8534 m .48858 .8541 L .48975 .85217 L F
.861 .684 .661 r
.48791 .85636 m .48858 .8541 L .4865 .8534 L F
.686 .54 .683 r
.44112 .8383 m .43917 .84096 L .44096 .83996 L F
.703 .578 .712 r
.44096 .83996 m .44428 .83879 L .44112 .8383 L F
.704 .585 .719 r
.43917 .84096 m .44245 .84351 L .44096 .83996 L F
.701 .582 .719 r
.44096 .83996 m .44245 .84351 L .44442 .84095 L F
.611 .456 .648 r
.44442 .84095 m .44245 .84351 L .44453 .84312 L F
.664 .55 .716 r
.44265 .84575 m .44453 .84312 L .44245 .84351 L F
.212 .694 .932 r
.40654 .83889 m .40738 .83844 L .40537 .83889 L F
.40654 .83889 m .40801 .83858 L .40738 .83844 L F
.7 .414 .488 r
.40274 .87387 m .40571 .87368 L .40594 .87176 L F
.682 .398 .485 r
.40571 .87368 m .40795 .87394 L .40594 .87176 L F
.652 .399 .524 r
.40594 .87176 m .40795 .87394 L .40818 .87186 L F
.726 .658 .782 r
.43694 .83295 m .43824 .83375 L .44022 .83321 L F
.43694 .83295 m .44022 .83321 L .43995 .83343 L F
.709 .576 .704 r
.43824 .83375 m .43805 .83584 L .44022 .83321 L F
.64 .896 .569 r
.44116 .83194 m .44022 .83321 L .44214 .83287 L F
.44116 .83194 m .43995 .83343 L .44022 .83321 L F
.799 .766 .822 r
.49331 .8086 m .49064 .80808 L .49217 .80666 L F
.49331 .8086 m .49132 .81022 L .49064 .80808 L F
0 0 0 r
.49231 .80985 m .49132 .81022 L .49331 .8086 L F
.308 0 0 r
.49557 .80867 m .49441 .80938 L .49331 .8086 L F
.245 0 0 r
.49441 .80938 m .49231 .80985 L .49331 .8086 L F
.762 .574 .643 r
.47799 .8542 m .47735 .8565 L .47621 .85375 L F
.719 .66 .791 r
.43483 .83333 m .43824 .83375 L .43694 .83295 L F
.728 .594 .705 r
.43482 .83534 m .43824 .83375 L .43483 .83333 L F
.43482 .83534 m .43805 .83584 L .43824 .83375 L F
0 0 0 r
.49231 .80985 m .4888 .81187 L .49132 .81022 L F
.613 .361 .512 r
.4278 .86393 m .43041 .86174 L .42794 .86156 L F
.142 .037 .465 r
.52874 .81509 m .52783 .81786 L .52786 .81593 L F
.615 .845 .987 r
.4242 .82089 m .42091 .8208 L .42287 .82044 L F
.129 .677 .793 r
.42287 .82044 m .42619 .82032 L .4242 .82089 L F
.613 .361 .512 r
.4278 .86393 m .42998 .86374 L .43041 .86174 L F
.609 .357 .51 r
.43041 .86174 m .43218 .86357 L .4329 .86069 L F
.43041 .86174 m .42998 .86374 L .43218 .86357 L F
.591 .386 .572 r
.40181 .89212 m .39946 .8946 L .39965 .89233 L F
.825 .75 .781 r
.4865 .8534 m .48975 .85217 L .48652 .85115 L F
.596 .247 .347 r
.41525 .86889 m .41759 .86925 L .41808 .8676 L F
.548 .346 .558 r
.41759 .86925 m .41961 .86828 L .41808 .8676 L F
.713 .603 .732 r
.4772 .85827 m .48037 .85895 L .47846 .86095 L F
.57 .388 .595 r
.48037 .85895 m .47999 .8617 L .47846 .86095 L F
.651 .45 .599 r
.45836 .86903 m .45616 .8713 L .45617 .86916 L F
.066 .624 .802 r
.49884 .80885 m .49946 .80867 L .49752 .8086 L F
.663 .461 .6 r
.50149 .80792 m .50125 .80896 L .49884 .80885 L F
.066 .624 .802 r
.49884 .80885 m .50125 .80896 L .49946 .80867 L F
.202 .726 .724 r
.40318 .82298 m .40385 .82276 L .40517 .82276 L F
.40318 .82298 m .40208 .8232 L .40385 .82276 L F
.58 .624 .86 r
.50299 .80647 m .50149 .80792 L .50079 .80581 L F
.50299 .80647 m .50364 .808 L .50149 .80792 L F
.609 .48 .679 r
.50364 .808 m .50178 .81037 L .50149 .80792 L F
.851 .653 .634 r
.50149 .80792 m .50178 .81037 L .50125 .80896 L F
.609 .48 .679 r
.50364 .808 m .50178 .81037 L .50149 .80792 L F
.851 .653 .634 r
.50149 .80792 m .50178 .81037 L .50125 .80896 L F
.552 .425 .662 r
.47092 .8513 m .47082 .85359 L .46872 .85382 L F
.535 .347 .572 r
.47082 .85359 m .46872 .8563 L .46872 .85382 L F
.824 .604 .604 r
.47921 .83816 m .47825 .84066 L .48097 .84091 L F
.826 .629 .637 r
.47825 .84066 m .4792 .84312 L .48097 .84091 L F
.738 .434 .466 r
.48323 .84312 m .48097 .84091 L .4792 .84312 L F
.622 .472 .657 r
.39559 .87665 m .39753 .87395 L .39568 .87435 L F
.727 .474 .544 r
.46391 .86655 m .46544 .86677 L .46564 .869 L F
.702 .383 .433 r
.46544 .86677 m .46939 .86857 L .46564 .869 L F
.735 .5 .573 r
.47559 .84041 m .47825 .84066 L .47921 .83816 L F
.703 .578 .712 r
.44096 .83996 m .44442 .84095 L .44428 .83879 L F
.093 .625 .868 r
.39458 .82303 m .39653 .8232 L .3979 .82362 L F
.675 .236 .2 r
.39653 .8232 m .39944 .82393 L .3979 .82362 L F
.221 .728 .895 r
.52827 .82072 m .52937 .82034 L .5271 .81987 L F
.52827 .82072 m .53047 .82061 L .52937 .82034 L F
.252 0 0 r
.41244 .82189 m .41545 .82132 L .41358 .822 L F
.487 0 0 r
.36552 .7404 m .36857 .74061 L .36631 .74006 L F
.674 .556 .713 r
.44428 .83879 m .44442 .84095 L .44648 .8384 L F
.681 .566 .719 r
.44442 .84095 m .44688 .84097 L .44648 .8384 L F
.699 .542 .671 r
.44453 .84312 m .44688 .84097 L .44442 .84095 L F
.68 .445 .559 r
.44806 .87192 m .44793 .87425 L .44588 .87398 L F
.657 .448 .589 r
.4517 .87136 m .44793 .87425 L .44806 .87192 L F
.582 .865 .995 r
.43468 .82054 m .43144 .8206 L .43345 .82014 L F
.435 .829 .983 r
.43468 .82054 m .43545 .81979 L .4367 .81986 L F
.43468 .82054 m .43345 .82014 L .43545 .81979 L F
.598 .473 .681 r
.44154 .84922 m .44345 .85097 L .44344 .84864 L F
.44154 .84922 m .44134 .85122 L .44345 .85097 L F
.104 .648 .838 r
.49447 .81504 m .49684 .81518 L .49768 .8153 L F
.727 .362 .359 r
.49768 .8153 m .49657 .81722 L .49447 .81504 L F
.187 0 0 r
.49684 .81518 m .49972 .81498 L .49768 .8153 L F
.326 0 .137 r
.49853 .81667 m .49768 .8153 L .49972 .81498 L F
.49853 .81667 m .49657 .81722 L .49768 .8153 L F
.53 .189 .334 r
.517 .86046 m .5152 .85915 L .51486 .86058 L F
.534 .186 .324 r
.517 .86046 m .51749 .85908 L .5152 .85915 L F
.585 .357 .536 r
.41666 .88455 m .41623 .88663 L .41443 .88675 L F
.635 .266 .327 r
.41666 .88455 m .41861 .88596 L .41623 .88663 L F
.41666 .88455 m .41881 .885 L .41861 .88596 L F
.873 .77 .746 r
.48928 .84052 m .4866 .84281 L .48795 .84435 L F
.565 .933 .803 r
.41984 .83462 m .41934 .83534 L .42089 .83495 L F
.41984 .83462 m .41825 .83568 L .41934 .83534 L F
.97 .81 .627 r
.48736 .84913 m .48709 .84525 L .48537 .84823 L F
.826 .694 .719 r
.48537 .84823 m .48652 .85115 L .48736 .84913 L F
.686 .476 .597 r
.46391 .86655 m .464 .86881 L .46034 .86895 L F
.671 .464 .597 r
.46391 .86655 m .46564 .869 L .464 .86881 L F
.503 .071 .152 r
.50405 .86539 m .5055 .86388 L .50076 .86476 L F
0 0 0 r
.50712 .86311 m .5055 .86388 L .50668 .86337 L F
.50668 .86337 m .5055 .86388 L .50405 .86539 L F
.76 .689 .783 r
.47975 .83515 m .48326 .8336 L .48016 .8332 L F
0 0 .307 r
.48116 .8601 m .48037 .85895 L .48233 .8606 L F
.48116 .8601 m .47999 .8617 L .48037 .85895 L F
.664 .55 .716 r
.44265 .84575 m .44547 .84618 L .44453 .84312 L F
.628 .527 .72 r
.44265 .84575 m .44563 .84833 L .44547 .84618 L F
.44265 .84575 m .44344 .84864 L .44563 .84833 L F
.593 .887 .991 r
.45107 .81859 m .4504 .81978 L .44926 .81899 L F
.45107 .81859 m .45229 .81911 L .4504 .81978 L F
.636 .873 .986 r
.42089 .83495 m .42403 .8348 L .42284 .83455 L F
.403 .852 .91 r
.42403 .8348 m .42485 .83417 L .42284 .83455 L F
.42403 .8348 m .42651 .83411 L .42485 .83417 L F
.478 .833 .995 r
.43015 .8201 m .42939 .82097 L .42815 .82014 L F
.43015 .8201 m .43144 .8206 L .42939 .82097 L F
.828 .647 .658 r
.48898 .87655 m .4913 .87734 L .48916 .87873 L F
.618 .344 .479 r
.43655 .87616 m .43321 .87898 L .43343 .87713 L F
.619 .44 .618 r
.4392 .85367 m .44139 .85355 L .44134 .85122 L F
.587 .414 .615 r
.44134 .85122 m .44139 .85355 L .44345 .85097 L F
.718 .49 .579 r
.48323 .84312 m .48438 .84317 L .48434 .84095 L F
.709 .379 .417 r
.4866 .84281 m .48434 .84095 L .48438 .84317 L F
.558 .358 .566 r
.44345 .85097 m .44563 .84833 L .44344 .84864 L F
.407 .105 .338 r
.51172 .8689 m .51425 .8667 L .51376 .86842 L F
.532 .239 .415 r
.51425 .8667 m .51598 .86804 L .51376 .86842 L F
.51425 .8667 m .51637 .86654 L .51598 .86804 L F
.749 .781 .878 r
.47142 .81779 m .46826 .81776 L .47006 .81676 L F
.68 .773 .921 r
.47339 .81712 m .47142 .81779 L .47006 .81676 L F
.379 .726 .99 r
.43873 .81956 m .44069 .81956 L .43993 .82038 L F
.434 .804 .994 r
.43993 .82038 m .44069 .81956 L .44193 .82012 L F
.617 .594 .805 r
.44544 .83573 m .44733 .8333 L .44511 .83376 L F
.44544 .83573 m .44838 .83599 L .44733 .8333 L F
.635 .523 .71 r
.44544 .83573 m .44648 .8384 L .44838 .83599 L F
.655 .846 .973 r
.45567 .81899 m .45229 .81911 L .45441 .8184 L F
.558 .848 .998 r
.45655 .81785 m .45567 .81899 L .45441 .8184 L F
.45655 .81785 m .45775 .81846 L .45567 .81899 L F
.618 .344 .479 r
.43655 .87616 m .43533 .879 L .43321 .87898 L F
.598 .322 .47 r
.43856 .87623 m .43533 .879 L .43655 .87616 L F
.743 .5 .562 r
.48272 .86908 m .48416 .86928 L .48311 .87149 L F
.781 .596 .65 r
.486 .8717 m .48257 .87371 L .48416 .86928 L F
.765 .699 .79 r
.43171 .83374 m .43482 .83534 L .43483 .83333 L F
.43171 .83374 m .43288 .83614 L .43482 .83534 L F
.73 .824 .923 r
.46615 .8182 m .46315 .8183 L .46498 .81738 L F
.56 .806 .991 r
.46826 .81776 m .46615 .8182 L .46498 .81738 L F
.731 .667 .787 r
.47405 .85601 m .47208 .85788 L .47091 .85543 L F
.714 .552 .668 r
.47621 .85375 m .47735 .8565 L .47405 .85601 L F
.5 .121 .252 r
.39134 .825 m .39458 .82303 L .39257 .82372 L F
.465 .23 .473 r
.50514 .87836 m .5075 .87393 L .50748 .87672 L F
.475 .247 .487 r
.50748 .87672 m .5075 .87393 L .50932 .87328 L F
.623 .422 .588 r
.4392 .85367 m .44132 .85584 L .44139 .85355 L F
.4392 .85367 m .43915 .85608 L .44132 .85584 L F
.95 .701 .526 r
.49938 .86578 m .50093 .86723 L .50048 .86412 L F
.414 .85 .731 r
.50093 .86723 m .50076 .86476 L .50048 .86412 L F
.776 .616 .681 r
.47321 .85129 m .47082 .85359 L .47092 .8513 L F
.741 .647 .756 r
.47735 .8565 m .4772 .85827 L .47531 .8593 L F
.883 .532 .378 r
.4891 .86889 m .48981 .86704 L .48812 .86644 L F
0 0 0 r
.48819 .86946 m .4891 .86889 L .48748 .8698 L F
.978 .692 .41 r
.48977 .86904 m .48978 .86845 L .4891 .86889 L F
.48977 .86904 m .4891 .86889 L .49094 .86816 L F
0 0 0 r
.49094 .86816 m .4891 .86889 L .48819 .86946 L F
.978 .692 .41 r
.48978 .86845 m .48981 .86704 L .4891 .86889 L F
.51 .276 .495 r
.40818 .87186 m .4099 .87361 L .41047 .87183 L F
.40818 .87186 m .40795 .87394 L .4099 .87361 L F
.135 0 0 r
.39085 .84103 m .38813 .84088 L .39045 .8409 L F
.153 .59 .932 r
.48233 .8606 m .48358 .86143 L .48415 .86146 L F
.921 .901 .789 r
.47913 .83278 m .48195 .83044 L .48082 .82959 L F
.47913 .83278 m .48016 .8332 L .48195 .83044 L F
.825 .838 .859 r
.48082 .82959 m .48195 .83044 L .48419 .82819 L F
.658 .853 .975 r
.43363 .83274 m .43694 .83295 L .43555 .8323 L F
.43363 .83274 m .43483 .83333 L .43694 .83295 L F
.445 .702 .976 r
.43694 .83295 m .43787 .83144 L .43555 .8323 L F
.43694 .83295 m .43995 .83343 L .43787 .83144 L F
.54 .562 .826 r
.52235 .80933 m .52055 .81054 L .52058 .80978 L F
.52235 .80933 m .52254 .81049 L .52055 .81054 L F
0 .091 .633 r
.50178 .81037 m .5023 .80944 L .50125 .80896 L F
.699 .542 .671 r
.44453 .84312 m .44764 .84353 L .44688 .84097 L F
.671 .543 .701 r
.44688 .84097 m .4488 .83803 L .44648 .8384 L F
.44688 .84097 m .44961 .84101 L .4488 .83803 L F
.67 .525 .678 r
.44688 .84097 m .44764 .84353 L .44961 .84101 L F
.744 .605 .703 r
.48717 .81773 m .48743 .82031 L .49028 .82014 L F
.745 .622 .723 r
.48743 .82031 m .48859 .82126 L .49028 .82014 L F
.496 .3 .543 r
.50957 .87143 m .51172 .8689 L .51118 .87098 L F
.49 .287 .531 r
.50932 .87328 m .50957 .87143 L .51118 .87098 L F
.637 .807 .964 r
.46086 .81873 m .45775 .81846 L .45978 .81794 L F
.575 .797 .983 r
.46182 .81737 m .46086 .81873 L .45978 .81794 L F
.46182 .81737 m .46315 .8183 L .46086 .81873 L F
.765 .699 .79 r
.43171 .83374 m .43483 .83333 L .43363 .83274 L F
.557 .326 .521 r
.40689 .88965 m .40868 .89155 L .40624 .89206 L F
.40689 .88965 m .40895 .88941 L .40868 .89155 L F
.651 .521 .692 r
.4329 .86069 m .43532 .8595 L .43296 .86034 L F
.706 .596 .731 r
.47735 .8565 m .47531 .8593 L .47405 .85601 L F
.848 .649 .632 r
.47461 .83766 m .47559 .84041 L .47697 .83832 L F
.135 0 0 r
.39085 .84103 m .38773 .84303 L .38813 .84088 L F
.39085 .84103 m .38939 .84259 L .38773 .84303 L F
.379 0 .049 r
.39282 .84083 m .38939 .84259 L .39085 .84103 L F
.783 .675 .745 r
.48341 .8509 m .48652 .85115 L .48537 .84823 L F
.756 .533 .593 r
.48629 .85323 m .48652 .85115 L .48341 .8509 L F
.48629 .85323 m .4865 .8534 L .48652 .85115 L F
.305 0 0 r
.50125 .80896 m .5023 .80944 L .49946 .80867 L F
0 .456 .719 r
.48542 .86363 m .48676 .86398 L .48357 .86322 L F
.888 .463 .161 r
.48683 .86574 m .48676 .86398 L .48542 .86363 L F
.48683 .86574 m .48812 .86644 L .48676 .86398 L F
.488 .126 .278 r
.41152 .88774 m .41325 .88867 L .41119 .88871 L F
.41152 .88774 m .41443 .88675 L .41325 .88867 L F
.743 .5 .562 r
.47938 .86895 m .48272 .86908 L .48311 .87149 L F
.622 .811 .972 r
.44517 .82041 m .44193 .82012 L .44393 .81967 L F
.729 .863 .944 r
.4473 .81933 m .44517 .82041 L .44393 .81967 L F
.885 .84 .796 r
.48474 .85838 m .4863 .85923 L .48791 .85636 L F
.881 .842 .802 r
.48415 .86146 m .4863 .85923 L .48474 .85838 L F
.7 .619 .762 r
.44838 .83599 m .44648 .8384 L .4488 .83803 L F
.414 .85 .731 r
.50093 .86723 m .50259 .86637 L .50076 .86476 L F
.503 .071 .152 r
.50405 .86539 m .50076 .86476 L .50259 .86637 L F
.777 .808 .878 r
.48048 .81469 m .47744 .81439 L .4797 .81232 L F
.48048 .81469 m .47879 .81531 L .47744 .81439 L F
.813 .814 .851 r
.4826 .81208 m .48048 .81469 L .4797 .81232 L F
.651 .521 .692 r
.4329 .86069 m .43514 .86108 L .43532 .8595 L F
.618 .396 .558 r
.4329 .86069 m .43494 .86317 L .43514 .86108 L F
.4329 .86069 m .43218 .86357 L .43494 .86317 L F
.337 .336 .711 r
.51898 .815 m .51972 .81839 L .52088 .81675 L F
.638 .753 .932 r
.51972 .81839 m .52184 .81794 L .52088 .81675 L F
.673 .452 .576 r
.42894 .87982 m .42821 .88203 L .4259 .88178 L F
.605 .381 .55 r
.43117 .88137 m .42894 .87982 L .4315 .87948 L F
.43117 .88137 m .42821 .88203 L .42894 .87982 L F
.584 .428 .636 r
.43705 .85645 m .43923 .85845 L .43915 .85608 L F
.43705 .85645 m .43711 .8588 L .43923 .85845 L F
.601 .365 .531 r
.42394 .88181 m .42588 .88379 L .4241 .88381 L F
.42394 .88181 m .4259 .88178 L .42588 .88379 L F
.558 .812 .993 r
.51434 .80894 m .51235 .80951 L .51152 .80868 L F
.338 0 .227 r
.52099 .86406 m .52366 .86149 L .5236 .86319 L F
.651 .095 0 r
.52228 .86091 m .52366 .86149 L .52468 .86276 L F
.539 .48 .739 r
.52459 .86259 m .52452 .86264 L .52228 .86091 L F
.52452 .86264 m .5236 .86319 L .52228 .86091 L F
.651 .095 0 r
.52228 .86091 m .52468 .86276 L .5247 .86279 L F
.52228 .86091 m .5247 .86279 L .5247 .86267 L F
.606 .542 .757 r
.52554 .85993 m .52597 .86156 L .52366 .86149 L F
.501 .062 .135 r
.52366 .86149 m .52597 .86156 L .5247 .86279 L F
.651 .095 0 r
.52228 .86091 m .5247 .86267 L .52462 .86113 L F
.539 .48 .739 r
.52491 .8624 m .52459 .86259 L .52228 .86091 L F
.783 .889 .921 r
.48502 .8225 m .48859 .82126 L .48743 .82031 L F
.677 .828 .956 r
.42651 .83411 m .42945 .8341 L .4283 .8333 L F
.515 .792 .996 r
.42945 .8341 m .43041 .8331 L .4283 .8333 L F
.42945 .8341 m .43171 .83374 L .43041 .8331 L F
.955 .782 .628 r
.49496 .87152 m .49622 .87118 L .49556 .86897 L F
0 0 0 r
.49804 .87078 m .49622 .87118 L .49496 .87152 L F
.654 .582 .763 r
.4488 .83803 m .45051 .8355 L .44838 .83599 L F
.4488 .83803 m .45156 .83845 L .45051 .8355 L F
.678 .547 .699 r
.4488 .83803 m .45181 .84054 L .45156 .83845 L F
.4488 .83803 m .44961 .84101 L .45181 .84054 L F
.539 .211 .36 r
.41443 .88675 m .41533 .88887 L .41325 .88867 L F
.41443 .88675 m .41623 .88663 L .41533 .88887 L F
.629 .863 .986 r
.49544 .80667 m .49217 .80666 L .49419 .8061 L F
.516 .85 .997 r
.49544 .80667 m .49618 .80562 L .49733 .80608 L F
.49544 .80667 m .49419 .8061 L .49618 .80562 L F
.525 .291 .502 r
.51172 .8689 m .51363 .8712 L .51118 .87098 L F
.51172 .8689 m .51376 .86842 L .51363 .8712 L F
.237 0 0 r
.49739 .88136 m .50068 .87943 L .50051 .88117 L F
.576 .309 .475 r
.50051 .88117 m .50068 .87943 L .50254 .88116 L F
.57 .31 .483 r
.50068 .87943 m .50289 .87927 L .50254 .88116 L F
.695 .568 .708 r
.44453 .84312 m .44547 .84618 L .44764 .84353 L F
.811 .527 .507 r
.486 .8717 m .48916 .87423 L .48579 .87401 L F
.75 .55 .624 r
.48916 .87423 m .48566 .87655 L .48579 .87401 L F
.48916 .87423 m .48898 .87655 L .48566 .87655 L F
.496 .812 1 r
.51029 .81486 m .51343 .81515 L .51228 .81449 L F
.758 .653 .745 r
.51029 .81486 m .51051 .8155 L .51343 .81515 L F
.474 .879 .95 r
.5144 .81435 m .51343 .81515 L .51535 .81455 L F
.412 .773 .995 r
.51228 .81449 m .51343 .81515 L .5144 .81435 L F
.532 .199 .349 r
.41881 .885 m .42142 .88393 L .42054 .88616 L F
.523 .208 .375 r
.42142 .88393 m .4226 .88626 L .42054 .88616 L F
.42142 .88393 m .4241 .88381 L .4226 .88626 L F
.832 .916 .892 r
.47667 .83491 m .48016 .8332 L .47913 .83278 L F
.841 .678 .681 r
.48621 .85536 m .48791 .85636 L .4865 .8534 L F
.885 .84 .796 r
.48474 .85838 m .48791 .85636 L .48621 .85536 L F
.681 .547 .696 r
.44764 .84353 m .44547 .84618 L .44773 .84572 L F
.576 .391 .594 r
.44563 .84833 m .44773 .84572 L .44547 .84618 L F
.717 .593 .716 r
.44764 .84353 m .44997 .84349 L .44961 .84101 L F
.591 .385 .569 r
.44773 .84572 m .44997 .84349 L .44764 .84353 L F
.44773 .84572 m .44987 .84573 L .44997 .84349 L F
.6 .462 .666 r
.44997 .84349 m .45181 .84054 L .44961 .84101 L F
.44997 .84349 m .4522 .8433 L .45181 .84054 L F
.661 .491 .643 r
.44987 .84573 m .4522 .8433 L .44997 .84349 L F
.134 .59 .924 r
.51737 .81413 m .51898 .815 L .52041 .81506 L F
.285 .328 .731 r
.51898 .815 m .52088 .81675 L .52041 .81506 L F
.857 .703 .69 r
.48502 .8225 m .48349 .82535 L .48622 .8254 L F
.837 .776 .793 r
.48272 .82728 m .48622 .8254 L .48349 .82535 L F
.48272 .82728 m .48419 .82819 L .48622 .8254 L F
.532 .778 .988 r
.487 .82421 m .48825 .82509 L .48622 .8254 L F
.48622 .8254 m .48825 .82509 L .487 .82421 L F
.45 .865 .952 r
.38408 .82641 m .38623 .82585 L .38751 .82604 L F
.485 .881 .958 r
.38751 .82604 m .38808 .82529 L .38939 .82541 L F
.38751 .82604 m .38623 .82585 L .38808 .82529 L F
.781 .596 .65 r
.486 .8717 m .48579 .87401 L .48257 .87371 L F
.894 .887 .818 r
.4883 .81242 m .48635 .81518 L .48709 .81549 L F
.825 .838 .859 r
.48082 .82959 m .48419 .82819 L .48272 .82728 L F
.748 .741 .846 r
.47879 .81531 m .47555 .81522 L .47744 .81439 L F
.651 .45 .599 r
.45836 .86903 m .45833 .87126 L .45616 .8713 L F
.656 .45 .592 r
.46034 .86895 m .45833 .87126 L .45836 .86903 L F
.657 .448 .589 r
.4517 .87136 m .45255 .87444 L .44793 .87425 L F
.702 .407 .473 r
.4517 .87136 m .45312 .87357 L .45255 .87444 L F
.4517 .87136 m .45318 .87178 L .45312 .87357 L F
.734 .684 .803 r
.50822 .81556 m .50839 .81691 L .51029 .81486 L F
.75 .761 .861 r
.50839 .81691 m .51051 .8155 L .51029 .81486 L F
.68 .773 .921 r
.47339 .81712 m .47006 .81676 L .47254 .81541 L F
.761 .79 .877 r
.47555 .81522 m .47339 .81712 L .47254 .81541 L F
.547 .186 .306 r
.41861 .88596 m .41881 .885 L .42054 .88616 L F
.717 .42 .474 r
.42302 .86816 m .42569 .86596 L .42223 .8679 L F
.42302 .86816 m .42435 .8684 L .42569 .86596 L F
.637 .467 .636 r
.42569 .86596 m .42784 .86626 L .4278 .86393 L F
.629 .319 .427 r
.4272 .86791 m .42569 .86596 L .42435 .8684 L F
.4272 .86791 m .42784 .86626 L .42569 .86596 L F
.564 .365 .57 r
.42784 .86626 m .42998 .86374 L .4278 .86393 L F
.51 .251 .458 r
.51637 .86654 m .51873 .86434 L .51829 .86608 L F
.53 .264 .455 r
.51873 .86434 m .5203 .86591 L .51829 .86608 L F
.51873 .86434 m .52099 .86406 L .5203 .86591 L F
.673 .879 .975 r
.50176 .81466 m .50505 .81453 L .50412 .8149 L F
.707 .17 0 r
.50598 .81354 m .50389 .81212 L .50505 .81453 L F
0 .204 .729 r
.50389 .81212 m .50459 .81281 L .50456 .81352 L F
0 0 0 r
.50077 .8152 m .49972 .81498 L .5011 .81477 L F
.213 0 0 r
.49861 .81521 m .50116 .81477 L .49972 .81498 L F
0 0 0 r
.50111 .81501 m .5011 .81477 L .50176 .81466 L F
.213 0 0 r
.50116 .81477 m .50176 .81466 L .5011 .81477 L F
.50116 .81477 m .5011 .81477 L .49972 .81498 L F
.123 .399 .85 r
.50493 .81198 m .5023 .80944 L .50389 .81212 L F
.707 .17 0 r
.50598 .81354 m .50561 .8138 L .50459 .81281 L F
.50493 .81283 m .50459 .81281 L .50389 .81212 L F
.50598 .81354 m .50459 .81281 L .50493 .81283 L F
0 0 0 r
.5008 .81518 m .5011 .81477 L .50111 .81501 L F
.50077 .8152 m .50078 .81518 L .5008 .81518 L F
.50078 .81518 m .5011 .81477 L .5008 .81518 L F
.501 .188 .368 r
.50064 .81516 m .50092 .81517 L .50093 .81515 L F
0 0 0 r
.5001 .81531 m .49972 .81498 L .50077 .8152 L F
.213 0 0 r
.49865 .81521 m .50064 .81516 L .50176 .81466 L F
.49861 .81521 m .50064 .81516 L .49865 .81521 L F
.501 .188 .368 r
.50064 .81516 m .50389 .81212 L .50176 .81466 L F
.455 .616 .919 r
.50174 .81344 m .50109 .81514 L .50064 .81516 L F
.501 .188 .368 r
.50092 .81517 m .50112 .81514 L .50389 .81212 L F
.455 .616 .919 r
.50109 .81514 m .50109 .81515 L .50064 .81516 L F
.501 .188 .368 r
.50133 .81451 m .50119 .8149 L .50389 .81212 L F
.50092 .81517 m .50108 .81518 L .50112 .81514 L F
.455 .616 .919 r
.50109 .81515 m .50108 .81518 L .50092 .81517 L F
.50109 .81515 m .50092 .81517 L .50064 .81516 L F
.806 .988 .883 r
.503 .81269 m .50108 .81518 L .50174 .81344 L F
.364 .308 .661 r
.50389 .81212 m .50561 .8138 L .50493 .81198 L F
.123 .399 .85 r
.50493 .81198 m .50518 .81139 L .5023 .80944 L F
0 0 0 r
.50389 .81212 m .50518 .81139 L .50561 .8138 L F
.50389 .81212 m .50145 .81477 L .50518 .81139 L F
.806 .988 .883 r
.50464 .81171 m .50359 .81273 L .503 .81269 L F
0 0 0 r
.50145 .81477 m .50112 .81514 L .50151 .81477 L F
.50112 .81514 m .50108 .81518 L .50112 .81514 L F
.806 .988 .883 r
.50359 .81273 m .50108 .81518 L .503 .81269 L F
0 0 0 r
.50145 .81477 m .50151 .81477 L .50518 .81139 L F
.50112 .81514 m .50112 .81514 L .50518 .81139 L F
.50028 .81546 m .5001 .81531 L .50077 .8152 L F
.806 .988 .883 r
.50518 .81139 m .50463 .81189 L .50464 .81171 L F
.50463 .81189 m .50108 .81518 L .50464 .81171 L F
0 .204 .729 r
.50456 .81352 m .50561 .8138 L .50505 .81453 L F
.50459 .81281 m .50561 .8138 L .50456 .81352 L F
.549 .914 .735 r
.50561 .8138 m .50412 .8149 L .50505 .81453 L F
.508 .641 .915 r
.50505 .81453 m .50822 .81556 L .50598 .81354 L F
.362 0 0 r
.39586 .84025 m .39489 .84081 L .39282 .84083 L F
.253 0 0 r
.39788 .84008 m .39489 .84081 L .39586 .84025 L F
.792 .64 .693 r
.48717 .81773 m .48546 .82033 L .48743 .82031 L F
.783 .889 .921 r
.48502 .8225 m .48743 .82031 L .48546 .82033 L F
.471 .826 .996 r
.52053 .80861 m .52058 .80978 L .51861 .80848 L F
.52053 .80861 m .52235 .80933 L .52058 .80978 L F
.102 .658 .76 r
.40076 .83992 m .39984 .83993 L .39788 .84008 L F
.423 .867 .887 r
.40172 .83929 m .40076 .83992 L .40276 .83939 L F
.40172 .83929 m .39984 .83993 L .40076 .83992 L F
.129 .677 .793 r
.42287 .82044 m .42496 .82029 L .42619 .82032 L F
.33 .8 .923 r
.42496 .82029 m .42815 .82014 L .42619 .82032 L F
.834 .724 .743 r
.48635 .81518 m .48496 .81781 L .48717 .81773 L F
.839 .71 .721 r
.48392 .81969 m .48717 .81773 L .48496 .81781 L F
.48392 .81969 m .48546 .82033 L .48717 .81773 L F
.726 .449 .506 r
.51917 .85886 m .52194 .85881 L .52133 .85823 L F
.591 .386 .572 r
.40181 .89212 m .40167 .89441 L .39946 .8946 L F
.592 .386 .571 r
.40181 .89212 m .40374 .89416 L .40167 .89441 L F
.40181 .89212 m .40393 .8919 L .40374 .89416 L F
.5 .577 .864 r
.50497 .80641 m .50364 .808 L .50299 .80647 L F
.552 .655 .904 r
.50497 .80641 m .50559 .80777 L .50364 .808 L F
.556 .686 .926 r
.50662 .80838 m .50364 .808 L .50559 .80777 L F
.273 0 0 r
.52392 .81733 m .52783 .81786 L .52603 .81775 L F
.43 .329 .639 r
.52889 .81675 m .52783 .81786 L .52874 .81509 L F
.775 .929 .935 r
.52603 .81775 m .52783 .81786 L .52889 .81675 L F
.576 .391 .594 r
.44563 .84833 m .44769 .84809 L .44773 .84572 L F
.616 .424 .599 r
.44773 .84572 m .44986 .8474 L .44987 .84573 L F
.44773 .84572 m .44769 .84809 L .44986 .8474 L F
.696 .659 .81 r
.36623 .74183 m .36857 .74061 L .36552 .7404 L F
.357 0 .173 r
.39458 .82303 m .39535 .82451 L .39653 .8232 L F
.39458 .82303 m .39348 .82498 L .39535 .82451 L F
.558 .358 .566 r
.44345 .85097 m .44548 .85071 L .44563 .84833 L F
.638 .426 .579 r
.44563 .84833 m .44763 .85051 L .44769 .84809 L F
.44563 .84833 m .44548 .85071 L .44763 .85051 L F
.585 .738 .949 r
.49938 .86578 m .50093 .86723 L .49723 .86619 L F
.49723 .86619 m .50093 .86723 L .49938 .86578 L F
0 0 0 r
.44055 .8764 m .44476 .87417 L .44382 .87633 L F
.617 .379 .533 r
.44476 .87417 m .446 .87612 L .44382 .87633 L F
.44476 .87417 m .44588 .87398 L .446 .87612 L F
.672 .634 .804 r
.43789 .85966 m .44042 .86127 L .43923 .85845 L F
.488 .284 .529 r
.43789 .85966 m .43913 .86236 L .44042 .86127 L F
.492 .534 .828 r
.43923 .85845 m .44042 .86127 L .44162 .86031 L F
.516 .18 .337 r
.43913 .86236 m .44162 .86031 L .44042 .86127 L F
.676 .544 .697 r
.43532 .8595 m .43514 .86108 L .43711 .8588 L F
.562 .292 .463 r
.45312 .87357 m .45318 .87178 L .45512 .87345 L F
.596 .282 .407 r
.45318 .87178 m .45616 .8713 L .45512 .87345 L F
.048 0 0 r
.49801 .86407 m .4938 .86679 L .49723 .86619 L F
.542 .333 .546 r
.49938 .86578 m .49801 .86407 L .49723 .86619 L F
0 0 0 r
.42152 .82075 m .42091 .8208 L .41941 .82082 L F
.42152 .82075 m .42287 .82044 L .42091 .8208 L F
.656 .45 .592 r
.46034 .86895 m .46034 .8716 L .45833 .87126 L F
.681 .453 .569 r
.46034 .86895 m .46384 .87042 L .46034 .8716 L F
.46034 .86895 m .464 .86881 L .46384 .87042 L F
.598 .322 .47 r
.43856 .87623 m .43741 .87895 L .43533 .879 L F
.587 .31 .464 r
.44055 .8764 m .43741 .87895 L .43856 .87623 L F
.128 .677 .771 r
.43545 .81979 m .43873 .81956 L .4367 .81986 L F
.729 .863 .944 r
.4473 .81933 m .44393 .81967 L .44589 .8187 L F
.489 .804 1 r
.44792 .81828 m .4473 .81933 L .44589 .8187 L F
.44792 .81828 m .44926 .81899 L .4473 .81933 L F
.471 .264 .517 r
.44139 .85355 m .44323 .85331 L .44345 .85097 L F
.629 .433 .598 r
.44139 .85355 m .44352 .85559 L .44323 .85331 L F
.44139 .85355 m .44132 .85584 L .44352 .85559 L F
.526 .331 .559 r
.41047 .87183 m .41245 .87157 L .4124 .8687 L F
.624 .408 .568 r
.4124 .8687 m .4146 .87064 L .41525 .86889 L F
.4124 .8687 m .41245 .87157 L .4146 .87064 L F
.646 .386 .512 r
.43494 .86317 m .43703 .86316 L .43514 .86108 L F
.66 .521 .683 r
.43711 .8588 m .43514 .86108 L .43789 .85966 L F
.594 .385 .567 r
.43514 .86108 m .43703 .86316 L .43789 .85966 L F
.752 .64 .737 r
.47184 .83576 m .47551 .83606 L .47335 .83483 L F
.47184 .83576 m .47461 .83766 L .47551 .83606 L F
.689 .761 .906 r
.47335 .83483 m .47551 .83606 L .47667 .83491 L F
0 0 .071 r
.47551 .83606 m .47461 .83766 L .47667 .83491 L F
.086 0 0 r
.40716 .82247 m .40915 .82233 L .41042 .82201 L F
.252 0 0 r
.41244 .82189 m .4144 .82186 L .41545 .82132 L F
.296 0 0 r
.41545 .82132 m .4144 .82186 L .41751 .8214 L F
.547 .013 0 r
.49126 .81477 m .49353 .81541 L .49447 .81504 L F
.215 0 0 r
.49379 .81551 m .49353 .81541 L .49126 .81477 L F
.381 0 0 r
.49447 .81504 m .49379 .81551 L .49126 .81477 L F
.672 .141 0 r
.4947 .8154 m .49657 .81722 L .49532 .8164 L F
.49447 .81504 m .49479 .81536 L .4947 .8154 L F
.49479 .81536 m .49657 .81722 L .4947 .8154 L F
.233 0 0 r
.49427 .81545 m .49447 .81504 L .49353 .81541 L F
.672 .141 0 r
.49447 .81504 m .49414 .81571 L .49379 .81551 L F
.67 .483 .624 r
.49379 .81551 m .49441 .81552 L .49427 .81545 L F
.531 .286 .49 r
.49532 .8164 m .49731 .81624 L .49735 .81565 L F
.672 .141 0 r
.49447 .81504 m .4947 .8154 L .49427 .81545 L F
.233 0 0 r
.49776 .81563 m .49447 .81504 L .49427 .81545 L F
.49776 .81563 m .49684 .81518 L .49447 .81504 L F
.187 0 0 r
.49684 .81518 m .49861 .81521 L .49972 .81498 L F
.329 .7 .981 r
.49744 .81428 m .49861 .81521 L .49684 .81518 L F
.49744 .81428 m .49684 .81518 L .49776 .81563 L F
.67 .483 .624 r
.4945 .81548 m .49776 .81563 L .49455 .81546 L F
.49611 .81558 m .49776 .81563 L .4945 .81548 L F
.672 .141 0 r
.49427 .81545 m .49532 .8164 L .49414 .81571 L F
.4947 .8154 m .49532 .8164 L .49427 .81545 L F
.67 .483 .624 r
.49379 .81551 m .49532 .8164 L .49776 .81563 L F
.531 .286 .49 r
.49532 .8164 m .49744 .81428 L .49776 .81563 L F
.49614 .81558 m .49735 .81565 L .49744 .81428 L F
.49532 .8164 m .49735 .81565 L .49614 .81558 L F
.67 .483 .624 r
.49441 .81552 m .49611 .81558 L .4945 .81548 L F
.49441 .81552 m .49455 .81546 L .49427 .81545 L F
.49379 .81551 m .49427 .81545 L .49353 .81541 L F
.635 .528 .715 r
.45156 .83845 m .45181 .84054 L .45366 .83801 L F
.656 .557 .731 r
.45181 .84054 m .45488 .84086 L .45366 .83801 L F
.674 .524 .674 r
.4522 .8433 m .45488 .84086 L .45181 .84054 L F
.622 .472 .657 r
.39559 .87665 m .39803 .8769 L .39753 .87395 L F
.606 .304 .43 r
.39532 .87747 m .39803 .8769 L .39559 .87665 L F
.571 .879 .993 r
.45441 .8184 m .45229 .81911 L .45107 .81859 L F
.541 .26 .439 r
.51917 .86059 m .51749 .85908 L .517 .86046 L F
.51917 .86059 m .51917 .85886 L .51749 .85908 L F
.644 .577 .765 r
.45051 .8355 m .45156 .83845 L .45366 .83801 L F
.781 .68 .752 r
.48437 .84549 m .48709 .84525 L .4866 .84281 L F
.78 .654 .723 r
.48437 .84549 m .48537 .84823 L .48709 .84525 L F
.76 .666 .759 r
.48709 .84525 m .48795 .84435 L .4866 .84281 L F
.634 .761 .94 r
.44116 .83194 m .44214 .83287 L .44434 .83243 L F
.645 .641 .832 r
.44214 .83287 m .44511 .83376 L .44434 .83243 L F
.665 .621 .795 r
.44733 .8333 m .44838 .83599 L .45051 .8355 L F
.564 .343 .538 r
.44345 .85097 m .44323 .85331 L .44536 .85299 L F
.554 .343 .549 r
.44345 .85097 m .44536 .85299 L .44548 .85071 L F
.721 .474 .553 r
.47611 .86899 m .47938 .86895 L .47957 .87119 L F
.743 .5 .562 r
.47938 .86895 m .48311 .87149 L .47957 .87119 L F
.023 0 0 r
.40385 .82276 m .40716 .82247 L .40517 .82276 L F
.534 .208 .361 r
.39946 .8946 m .40074 .89672 L .39875 .89667 L F
.39946 .8946 m .40167 .89441 L .40074 .89672 L F
.628 .631 .834 r
.44511 .83376 m .44733 .8333 L .44434 .83243 L F
0 0 0 r
.50872 .86254 m .50986 .86128 L .50712 .86311 L F
.736 .294 .202 r
.51185 .86321 m .50986 .86128 L .50872 .86254 L F
.555 .356 .567 r
.51185 .86321 m .51194 .86095 L .50986 .86128 L F
.665 .393 .499 r
.464 .86881 m .46568 .87085 L .46384 .87042 L F
.464 .86881 m .46564 .869 L .46568 .87085 L F
.748 .814 .904 r
.43787 .83144 m .43995 .83343 L .44116 .83194 L F
.672 .634 .804 r
.43789 .85966 m .43923 .85845 L .43711 .8588 L F
.579 .181 .253 r
.41625 .87016 m .41525 .86889 L .4146 .87064 L F
.41625 .87016 m .41759 .86925 L .41525 .86889 L F
.689 .284 .273 r
.48242 .86508 m .48357 .86322 L .48048 .86325 L F
.563 .212 .332 r
.48436 .86529 m .48357 .86322 L .48242 .86508 L F
.48436 .86529 m .48542 .86363 L .48357 .86322 L F
.665 .829 .962 r
.50079 .80581 m .49733 .80608 L .49967 .80468 L F
.526 .607 .877 r
.50156 .80406 m .50079 .80581 L .49967 .80468 L F
.50156 .80406 m .50299 .80647 L .50079 .80581 L F
.255 .752 .904 r
.43015 .8201 m .43345 .82014 L .43144 .8206 L F
.495 .885 .96 r
.52937 .82034 m .53047 .82061 L .53242 .81998 L F
.64 .395 .533 r
.44588 .87398 m .44779 .87618 L .446 .87612 L F
.675 .396 .491 r
.44588 .87398 m .44793 .87425 L .44779 .87618 L F
.153 .59 .932 r
.48233 .8606 m .48415 .86146 L .48474 .85838 L F
.731 .467 .528 r
.52228 .86091 m .52194 .85881 L .51917 .85886 L F
.552 .846 .998 r
.45978 .81794 m .45775 .81846 L .45655 .81785 L F
.531 .409 .658 r
.39753 .87395 m .3998 .87633 L .39968 .8739 L F
.39753 .87395 m .39803 .8769 L .3998 .87633 L F
0 0 0 r
.50028 .81546 m .49853 .81667 L .49972 .81498 L F
.52184 .81794 m .52392 .81733 L .52407 .8173 L F
.52184 .81794 m .52332 .81751 L .52245 .81724 L F
.52112 .81705 m .52245 .81724 L .52088 .81675 L F
.52184 .81794 m .52245 .81724 L .52112 .81705 L F
.476 .39 .68 r
.5225 .81422 m .52245 .81724 L .52475 .81687 L F
.52245 .81724 m .52245 .81763 L .52326 .81736 L F
.52245 .81724 m .52326 .81736 L .52475 .81687 L F
.576 .473 .7 r
.52088 .81675 m .52245 .81763 L .52245 .81724 L F
.52088 .81675 m .52245 .81724 L .5225 .81422 L F
.263 0 .185 r
.52475 .81687 m .52326 .81736 L .52407 .8173 L F
0 0 0 r
.52332 .81751 m .52407 .8173 L .52292 .81739 L F
.263 0 .185 r
.52326 .81736 m .52245 .81763 L .52407 .8173 L F
0 0 0 r
.52292 .81739 m .52407 .8173 L .52088 .81675 L F
.447 .161 .384 r
.51598 .86804 m .51637 .86654 L .51829 .86608 L F
.694 .561 .7 r
.47091 .85543 m .46872 .8563 L .47082 .85359 L F
.809 .824 .863 r
.4826 .81208 m .4797 .81232 L .48207 .81016 L F
.873 .855 .82 r
.48449 .80948 m .4826 .81208 L .48207 .81016 L F
.631 .389 .533 r
.4259 .88178 m .42797 .88408 L .42588 .88379 L F
.666 .389 .491 r
.4259 .88178 m .42821 .88203 L .42797 .88408 L F
.26 .76 .892 r
.42284 .83455 m .41984 .83462 L .42089 .83495 L F
.853 .641 .615 r
.48579 .87401 m .48312 .8758 L .48257 .87371 L F
.48579 .87401 m .48566 .87655 L .48312 .8758 L F
.626 .338 .461 r
.45616 .8713 m .45708 .87354 L .45512 .87345 L F
.45616 .8713 m .45833 .87126 L .45708 .87354 L F
.498 .21 .407 r
.41623 .88663 m .41745 .88891 L .41533 .88887 L F
.41623 .88663 m .41861 .88596 L .41745 .88891 L F
.661 .374 .474 r
.46564 .869 m .46939 .86857 L .46764 .87098 L F
.708 .354 .374 r
.46939 .86857 m .47144 .87074 L .46764 .87098 L F
.46939 .86857 m .47095 .86918 L .47144 .87074 L F
.475 .247 .487 r
.50748 .87672 m .50932 .87328 L .50919 .87614 L F
.49 .287 .531 r
.50932 .87328 m .51118 .87098 L .5115 .87384 L F
.463 .215 .452 r
.50919 .87614 m .50932 .87328 L .5115 .87384 L F
.77 .578 .638 r
.48148 .84558 m .48438 .84317 L .48323 .84312 L F
.48148 .84558 m .48437 .84549 L .48438 .84317 L F
.781 .68 .752 r
.48437 .84549 m .4866 .84281 L .48438 .84317 L F
.566 .318 .5 r
.40895 .88941 m .41085 .89146 L .40868 .89155 L F
.40895 .88941 m .41119 .88871 L .41085 .89146 L F
.382 .806 .97 r
.44069 .81956 m .44393 .81967 L .44193 .82012 L F
.564 .365 .57 r
.42784 .86626 m .42988 .86607 L .42998 .86374 L F
.598 .38 .555 r
.42988 .86607 m .43218 .86357 L .42998 .86374 L F
.87 .79 .769 r
.48026 .85285 m .48249 .85328 L .48341 .8509 L F
.847 .46 .315 r
.4833 .85546 m .48249 .85328 L .48026 .85285 L F
.703 .59 .727 r
.48249 .85328 m .48629 .85323 L .48341 .8509 L F
.668 .372 .462 r
.4833 .85546 m .48629 .85323 L .48249 .85328 L F
.679 .77 .919 r
.46693 .81665 m .46826 .81776 L .46498 .81738 L F
.749 .78 .878 r
.47006 .81676 m .46826 .81776 L .46693 .81665 L F
.873 .855 .82 r
.48449 .80948 m .48207 .81016 L .48358 .80889 L F
.538 .866 .994 r
.48449 .80948 m .48505 .8081 L .48703 .80795 L F
.48449 .80948 m .48358 .80889 L .48505 .8081 L F
.698 .83 .946 r
.46498 .81738 m .46315 .8183 L .46182 .81737 L F
.45 .116 .307 r
.41177 .87304 m .41047 .87183 L .4099 .87361 L F
.41177 .87304 m .41245 .87157 L .41047 .87183 L F
.833 .678 .69 r
.48246 .84843 m .48537 .84823 L .48437 .84549 L F
.831 .753 .778 r
.48341 .8509 m .48537 .84823 L .48246 .84843 L F
.604 .934 .955 r
.42485 .83417 m .42651 .83411 L .4283 .8333 L F
.479 .261 .503 r
.5115 .87384 m .51118 .87098 L .51363 .8712 L F
.488 .284 .529 r
.43789 .85966 m .43703 .86316 L .43913 .86236 L F
.83 .668 .681 r
.4833 .85546 m .4865 .8534 L .48629 .85323 L F
.633 .463 .635 r
.43915 .85608 m .43923 .85845 L .44132 .85584 L F
.708 .475 .57 r
.47926 .84532 m .48323 .84312 L .4792 .84312 L F
.47926 .84532 m .48148 .84558 L .48323 .84312 L F
.742 .762 .869 r
.50822 .81556 m .51029 .81486 L .50745 .81327 L F
.50822 .81556 m .50745 .81327 L .50733 .8133 L F
.499 .811 1 r
.51029 .81486 m .51129 .81378 L .50729 .81317 L F
.742 .762 .869 r
.50822 .81556 m .50729 .81317 L .50598 .81354 L F
.006 0 0 r
.5081 .81328 m .50561 .8138 L .50577 .81369 L F
.5067 .81346 m .50577 .81369 L .50598 .81354 L F
.5081 .81328 m .50577 .81369 L .5067 .81346 L F
.742 .762 .869 r
.50733 .8133 m .50745 .81327 L .50729 .81317 L F
.499 .811 1 r
.51029 .81486 m .51228 .81449 L .51129 .81378 L F
.83 .668 .681 r
.4833 .85546 m .48621 .85536 L .4865 .8534 L F
.854 .597 .548 r
.48898 .87655 m .48734 .87869 L .48566 .87655 L F
.48898 .87655 m .48916 .87873 L .48734 .87869 L F
.663 .386 .492 r
.47095 .86918 m .47438 .86858 L .47286 .87105 L F
.713 .446 .52 r
.47438 .86858 m .47614 .87101 L .47286 .87105 L F
.47438 .86858 m .47611 .86899 L .47614 .87101 L F
.661 .374 .474 r
.46564 .869 m .46764 .87098 L .46568 .87085 L F
.379 0 .049 r
.39282 .84083 m .3914 .84239 L .38939 .84259 L F
.293 0 0 r
.39337 .842 m .39282 .84083 L .39489 .84081 L F
.39337 .842 m .3914 .84239 L .39282 .84083 L F
.559 .512 .759 r
.5278 .86091 m .52597 .86156 L .52554 .85993 L F
.103 0 0 r
.5247 .86279 m .52597 .86156 L .5278 .86091 L F
.889 .718 .663 r
.50927 .82486 m .5104 .82775 L .50798 .82645 L F
.567 0 0 r
.50798 .82645 m .5104 .82775 L .50965 .82751 L F
.978 .68 .331 r
.50965 .82751 m .5104 .82775 L .50927 .82486 L F
.645 .375 .495 r
.44793 .87425 m .45112 .87564 L .44779 .87618 L F
.44793 .87425 m .45255 .87444 L .45112 .87564 L F
.499 .167 .334 r
.42875 .86869 m .42784 .86626 L .4272 .86791 L F
.42875 .86869 m .42988 .86607 L .42784 .86626 L F
.605 .397 .572 r
.4315 .87948 m .43299 .88114 L .43117 .88137 L F
.4315 .87948 m .43321 .87898 L .43299 .88114 L F
.533 .265 .456 r
.50289 .87927 m .50514 .87836 L .50497 .87908 L F
.528 .246 .431 r
.50289 .87927 m .50455 .88078 L .50254 .88116 L F
.50289 .87927 m .50497 .87908 L .50455 .88078 L F
.376 0 0 r
.4134 .83731 m .41294 .83795 L .41065 .83804 L F
0 0 0 r
.41425 .83698 m .4134 .83731 L .41529 .83691 L F
.41425 .83698 m .41294 .83795 L .4134 .83731 L F
.488 .565 .86 r
.53091 .81445 m .53213 .81617 L .52874 .81509 L F
.721 .474 .553 r
.47611 .86899 m .47957 .87119 L .47614 .87101 L F
.834 .632 .631 r
.47747 .84296 m .47825 .84066 L .47559 .84041 L F
.47747 .84296 m .4792 .84312 L .47825 .84066 L F
.763 .659 .747 r
.51131 .82223 m .51247 .82516 L .50927 .82486 L F
.978 .68 .331 r
.50965 .82751 m .50927 .82486 L .51247 .82516 L F
.50965 .82751 m .51247 .82516 L .51158 .82511 L F
.134 .282 .751 r
.51337 .82426 m .51247 .82516 L .51131 .82223 L F
.543 .925 .91 r
.51158 .82511 m .51247 .82516 L .51337 .82426 L F
.778 .73 .808 r
.4804 .85057 m .48341 .8509 L .48246 .84843 L F
.87 .79 .769 r
.48026 .85285 m .48341 .8509 L .4804 .85057 L F
.691 .458 .566 r
.47567 .84507 m .4792 .84312 L .47747 .84296 L F
.47567 .84507 m .47926 .84532 L .4792 .84312 L F
.45 .623 .926 r
.50782 .80775 m .50662 .80838 L .50559 .80777 L F
.50782 .80775 m .50965 .80992 L .50662 .80838 L F
.71 .447 .525 r
.40497 .8764 m .40571 .87368 L .40274 .87387 L F
.634 .227 .256 r
.40655 .87562 m .40571 .87368 L .40497 .8764 L F
.40655 .87562 m .40795 .87394 L .40571 .87368 L F
.531 .285 .488 r
.51376 .86842 m .51542 .871 L .51363 .8712 L F
.51376 .86842 m .51598 .86804 L .51542 .871 L F
0 0 .36 r
.48608 .82157 m .48502 .8225 L .48546 .82033 L F
.232 .443 .86 r
.48392 .81969 m .48528 .82162 L .48515 .82062 L F
0 0 .36 r
.48515 .82062 m .48546 .82033 L .48392 .81969 L F
.48588 .82117 m .48559 .82059 L .48515 .82062 L F
.48559 .82059 m .48546 .82033 L .48515 .82062 L F
.811 .638 .667 r
.48075 .81943 m .48528 .82162 L .48392 .81969 L F
.48075 .81943 m .48187 .8221 L .48528 .82162 L F
.265 0 0 r
.48187 .8221 m .48336 .82223 L .48528 .82162 L F
.954 .942 .725 r
.48528 .82162 m .48336 .82223 L .48406 .8207 L F
.232 .443 .86 r
.48392 .81969 m .48515 .82062 L .48492 .81883 L F
0 0 .36 r
.48608 .82157 m .48588 .82117 L .48392 .81969 L F
.232 .443 .86 r
.48392 .81969 m .48492 .81883 L .48477 .81878 L F
.163 .343 .798 r
.48477 .81878 m .4849 .81907 L .48392 .81969 L F
.954 .942 .725 r
.48515 .82062 m .485 .82063 L .48492 .81883 L F
.485 .82063 m .48489 .81889 L .48492 .81883 L F
.163 .343 .798 r
.4849 .81907 m .48608 .82157 L .485 .82063 L F
.4849 .81907 m .485 .82063 L .48392 .81969 L F
.954 .942 .725 r
.485 .82063 m .48406 .8207 L .48489 .81889 L F
.48528 .82162 m .48406 .8207 L .48515 .82062 L F
.562 .289 .459 r
.43117 .88137 m .42797 .88408 L .42821 .88203 L F
.665 .621 .795 r
.44733 .8333 m .45051 .8355 L .44939 .83251 L F
.641 .591 .783 r
.44939 .83251 m .45051 .8355 L .45258 .83511 L F
.644 .577 .765 r
.45051 .8355 m .45366 .83801 L .45258 .83511 L F
.661 .491 .643 r
.44987 .84573 m .45301 .84582 L .4522 .8433 L F
.674 .524 .674 r
.4522 .8433 m .45485 .8432 L .45488 .84086 L F
.728 .527 .62 r
.4522 .8433 m .45493 .84537 L .45485 .8432 L F
.4522 .8433 m .45301 .84582 L .45493 .84537 L F
.711 .584 .711 r
.45366 .83801 m .45692 .84054 L .45575 .83768 L F
.45366 .83801 m .45488 .84086 L .45692 .84054 L F
.705 .55 .675 r
.45488 .84086 m .45485 .8432 L .45692 .84054 L F
.687 .525 .661 r
.45692 .84054 m .45485 .8432 L .45708 .84281 L F
.677 .654 .82 r
.45692 .84054 m .4579 .83728 L .45575 .83768 L F
.45692 .84054 m .45938 .84046 L .4579 .83728 L F
.667 .498 .647 r
.45708 .84281 m .45938 .84046 L .45692 .84054 L F
.745 .678 .786 r
.49064 .80808 m .48703 .80795 L .48916 .80755 L F
.819 .845 .868 r
.49217 .80666 m .49064 .80808 L .48916 .80755 L F
.71 .932 .962 r
.49967 .80468 m .49733 .80608 L .49618 .80562 L F
0 0 0 r
.49618 .80849 m .49557 .80867 L .49752 .8086 L F
.49618 .80849 m .49441 .80938 L .49557 .80867 L F
.473 .512 .818 r
.52394 .80892 m .52254 .81049 L .52235 .80933 L F
.696 .719 .867 r
.51152 .80868 m .50965 .80992 L .50782 .80775 L F
0 0 0 r
.48392 .82471 m .48349 .82535 L .48502 .8225 L F
.678 .337 .39 r
.487 .82421 m .48502 .8225 L .48608 .82157 L F
.487 .82421 m .48392 .82471 L .48502 .8225 L F
.749 .78 .878 r
.47006 .81676 m .46693 .81665 L .46919 .81545 L F
.707 .824 .937 r
.47254 .81541 m .47006 .81676 L .46919 .81545 L F
.5 .308 .552 r
.40374 .89416 m .40393 .8919 L .40564 .89372 L F
.632 .308 .405 r
.40393 .8919 m .40624 .89206 L .40564 .89372 L F
.725 .364 .365 r
.47095 .86918 m .47286 .87105 L .47144 .87074 L F
.979 .816 .61 r
.49496 .87152 m .49556 .86897 L .49443 .8685 L F
.918 .913 .798 r
.49443 .8685 m .49556 .86897 L .49723 .86619 L F
.686 .224 .148 r
.52706 .81597 m .52797 .81412 L .52488 .81421 L F
0 .516 .711 r
.52886 .8142 m .53091 .81445 L .52797 .81412 L F
.761 .79 .877 r
.47555 .81522 m .47254 .81541 L .47436 .8144 L F
.696 .844 .954 r
.47744 .81439 m .47555 .81522 L .47436 .8144 L F
.209 .735 .823 r
.38808 .82529 m .39134 .825 L .38939 .82541 L F
.56 .918 .956 r
.51608 .81368 m .51535 .81455 L .51737 .81413 L F
.51608 .81368 m .5144 .81435 L .51535 .81455 L F
.546 .144 .232 r
.52554 .85993 m .52228 .86091 L .52462 .86113 L F
.672 .333 .391 r
.52462 .86113 m .5278 .86091 L .52554 .85993 L F
0 0 0 r
.50259 .86637 m .50036 .86863 L .50235 .86843 L F
.447 .334 .632 r
.50405 .86539 m .50259 .86637 L .50452 .86816 L F
.575 .331 .509 r
.50452 .86816 m .50259 .86637 L .50235 .86843 L F
.50452 .86816 m .50259 .86637 L .50235 .86843 L F
.648 .332 .423 r
.45833 .87126 m .46022 .87323 L .45708 .87354 L F
.45833 .87126 m .46034 .8716 L .46022 .87323 L F
.715 .326 .312 r
.49231 .88111 m .49563 .88114 L .49404 .8828 L F
.545 .172 .284 r
.49563 .88114 m .49617 .8834 L .49404 .8828 L F
.49563 .88114 m .49739 .88136 L .49617 .8834 L F
.83 .67 .684 r
.48474 .85838 m .48621 .85536 L .4833 .85546 L F
.607 .56 .775 r
.45258 .83511 m .45366 .83801 L .45575 .83768 L F
.775 .598 .66 r
.48311 .87149 m .47946 .87336 L .47957 .87119 L F
.48311 .87149 m .48257 .87371 L .47946 .87336 L F
.731 .467 .528 r
.52228 .86091 m .51917 .85886 L .51917 .86059 L F
.634 .761 .94 r
.44116 .83194 m .44434 .83243 L .4431 .83142 L F
.566 .787 .982 r
.44434 .83243 m .44517 .83096 L .4431 .83142 L F
.44434 .83243 m .44638 .83204 L .44517 .83096 L F
.605 .646 .865 r
.44434 .83243 m .44733 .8333 L .44638 .83204 L F
.437 .866 .931 r
.40363 .83875 m .40276 .83939 L .40537 .83889 L F
.40363 .83875 m .40172 .83929 L .40276 .83939 L F
.918 .913 .798 r
.49443 .8685 m .49723 .86619 L .4938 .86679 L F
.505 .768 .99 r
.49034 .82457 m .48825 .82509 L .487 .82421 L F
.672 .314 .358 r
.49034 .82457 m .487 .82421 L .48825 .82509 L F
.332 0 .05 r
.4099 .87361 m .40795 .87394 L .40655 .87562 L F
.764 .831 .904 r
.43041 .8331 m .43171 .83374 L .43363 .83274 L F
.698 .565 .701 r
.44986 .8474 m .45301 .84582 L .44987 .84573 L F
0 0 0 r
.50872 .86254 m .50712 .86311 L .50668 .86337 L F
0 .32 .772 r
.39617 .87762 m .39532 .87747 L .3942 .87843 L F
.606 .304 .43 r
.39532 .87747 m .39725 .87858 L .39803 .8769 L F
0 .32 .772 r
.39617 .87762 m .39725 .87858 L .39532 .87747 L F
0 0 0 r
.49804 .87078 m .49496 .87152 L .49708 .87259 L F
.315 .024 .3 r
.49887 .87134 m .50036 .86863 L .49804 .87078 L F
.388 0 .157 r
.49887 .87134 m .49804 .87078 L .49708 .87259 L F
.819 .845 .868 r
.49217 .80666 m .48916 .80755 L .49119 .80685 L F
.319 .805 .777 r
.49217 .80666 m .49311 .80619 L .49419 .8061 L F
.49217 .80666 m .49119 .80685 L .49311 .80619 L F
.667 .498 .647 r
.45708 .84281 m .46002 .8429 L .45938 .84046 L F
.707 .668 .809 r
.4579 .83728 m .45938 .84046 L .46092 .83773 L F
.64 .582 .773 r
.45938 .84046 m .4622 .84055 L .46092 .83773 L F
.671 .501 .646 r
.45938 .84046 m .46212 .84278 L .4622 .84055 L F
.45938 .84046 m .46002 .8429 L .46212 .84278 L F
.466 .652 .94 r
.50267 .80446 m .50299 .80647 L .50156 .80406 L F
.50267 .80446 m .50497 .80641 L .50299 .80647 L F
.775 .929 .935 r
.52603 .81775 m .52889 .81675 L .5271 .81987 L F
.707 .565 .692 r
.44763 .85051 m .44986 .8474 L .44769 .84809 L F
.558 .812 .993 r
.51434 .80894 m .51152 .80868 L .51329 .80832 L F
.389 .711 .986 r
.51546 .80828 m .51434 .80894 L .51329 .80832 L F
.51546 .80828 m .51629 .80911 L .51434 .80894 L F
.621 .356 .494 r
.43321 .87898 m .4352 .88097 L .43299 .88114 L F
.43321 .87898 m .43533 .879 L .4352 .88097 L F
.727 .591 .703 r
.47461 .83766 m .47263 .84043 L .47559 .84041 L F
.753 .534 .599 r
.4727 .84291 m .47559 .84041 L .47263 .84043 L F
.4727 .84291 m .47592 .8431 L .47559 .84041 L F
.738 .523 .602 r
.47592 .8431 m .47747 .84296 L .47559 .84041 L F
.553 .338 .542 r
.41119 .88871 m .41291 .89114 L .41085 .89146 L F
.41119 .88871 m .41325 .88867 L .41291 .89114 L F
0 0 0 r
.49282 .86771 m .4938 .86679 L .49285 .86733 L F
.49162 .86824 m .49285 .86733 L .48977 .86904 L F
.49282 .86771 m .49285 .86733 L .49162 .86824 L F
.742 .344 .298 r
.48992 .86949 m .49094 .86816 L .48937 .8693 L F
.49047 .86968 m .49071 .86891 L .48992 .86949 L F
.49071 .86891 m .49094 .86816 L .48992 .86949 L F
0 0 0 r
.49282 .86771 m .48977 .86904 L .49094 .86816 L F
.587 .31 .464 r
.44055 .8764 m .44196 .87848 L .43741 .87895 L F
.606 .315 .449 r
.44055 .8764 m .44273 .87807 L .44196 .87848 L F
.633 .297 .384 r
.44055 .8764 m .44382 .87633 L .44273 .87807 L F
.653 .466 .619 r
.5236 .86319 m .5203 .86591 L .52099 .86406 L F
.685 .498 .627 r
.49887 .87134 m .50235 .86843 L .50036 .86863 L F
.598 .38 .555 r
.42988 .86607 m .43211 .86603 L .43218 .86357 L F
.539 .287 .481 r
.43211 .86603 m .43494 .86317 L .43218 .86357 L F
.752 .64 .737 r
.47184 .83576 m .47319 .83857 L .47461 .83766 L F
.734 .6 .708 r
.47319 .83857 m .47263 .84043 L .47461 .83766 L F
0 0 0 r
.38773 .84303 m .38939 .84259 L .3874 .84319 L F
.767 .649 .731 r
.39725 .87858 m .3998 .87633 L .39803 .8769 L F
0 0 0 r
.42342 .8204 m .42287 .82044 L .42152 .82075 L F
.42342 .8204 m .42496 .82029 L .42287 .82044 L F
.832 .514 .451 r
.48629 .86781 m .48812 .86644 L .48683 .86574 L F
.48629 .86781 m .4891 .86889 L .48812 .86644 L F
.94 .964 .697 r
.48479 .81647 m .48496 .81781 L .48635 .81518 L F
.875 .906 .848 r
.48547 .81389 m .48628 .81438 L .48917 .81145 L F
0 .387 .812 r
.48607 .81412 m .48628 .81438 L .48547 .81389 L F
.822 .974 .67 r
.48628 .81438 m .48662 .8148 L .4883 .81242 L F
0 .387 .812 r
.48787 .81483 m .48628 .81438 L .48607 .81412 L F
.822 .974 .67 r
.48628 .81438 m .48635 .81518 L .48662 .8148 L F
.816 .979 .691 r
.48628 .81438 m .48479 .81647 L .48635 .81518 L F
.699 .482 .591 r
.39968 .8739 m .40255 .87604 L .40274 .87387 L F
.39968 .8739 m .3998 .87633 L .40255 .87604 L F
.649 .493 .659 r
.45493 .84537 m .45708 .84281 L .45485 .8432 L F
0 0 0 r
.38275 .82666 m .38623 .82585 L .38408 .82641 L F
.772 .589 .652 r
.48246 .84843 m .48437 .84549 L .48148 .84558 L F
.764 .831 .904 r
.43041 .8331 m .43363 .83274 L .43231 .83267 L F
.056 0 0 r
.43555 .8323 m .43231 .83267 L .43363 .83274 L F
.421 .152 .398 r
.50514 .87836 m .50689 .87855 L .50497 .87908 L F
.50514 .87836 m .50748 .87672 L .50689 .87855 L F
.689 .541 .681 r
.43923 .85845 m .44151 .85847 L .44132 .85584 L F
.648 .51 .681 r
.44132 .85584 m .4446 .85815 L .44352 .85559 L F
.44132 .85584 m .44151 .85847 L .4446 .85815 L F
.515 .01 0 r
.52392 .81733 m .52603 .81775 L .52483 .8187 L F
.52392 .81733 m .52483 .8187 L .52407 .8173 L F
.685 .434 .537 r
.51436 .86337 m .51486 .86058 L .51194 .86095 L F
.567 .297 .467 r
.51623 .86283 m .51486 .86058 L .51436 .86337 L F
.51623 .86283 m .517 .86046 L .51486 .86058 L F
.536 .827 .491 r
.48917 .81145 m .4883 .81242 L .4888 .81187 L F
.458 .054 .185 r
.40167 .89441 m .40245 .89591 L .40074 .89672 L F
.40167 .89441 m .40374 .89416 L .40245 .89591 L F
.57 .238 .366 r
.4241 .88381 m .42465 .88621 L .4226 .88626 L F
.4241 .88381 m .42588 .88379 L .42465 .88621 L F
.33 .8 .923 r
.42496 .82029 m .42694 .81996 L .42815 .82014 L F
.14 .677 .846 r
.42694 .81996 m .43015 .8201 L .42815 .82014 L F
.71 .447 .525 r
.40497 .8764 m .40274 .87387 L .40255 .87604 L F
.81 .755 .802 r
.40738 .83844 m .41065 .83804 L .40941 .83786 L F
.40738 .83844 m .40801 .83858 L .41065 .83804 L F
.561 .919 .954 r
.41123 .83709 m .41065 .83804 L .41294 .83795 L F
.41123 .83709 m .40941 .83786 L .41065 .83804 L F
.179 0 0 r
.39788 .84008 m .39697 .84057 L .39489 .84081 L F
.095 .653 .753 r
.39984 .83993 m .39872 .83995 L .39788 .84008 L F
0 0 0 r
.39872 .83995 m .39697 .84057 L .39788 .84008 L F
.952 .747 .589 r
.47974 .82716 m .47912 .83078 L .48082 .82959 L F
.628 .783 .334 r
.47969 .83173 m .48082 .82959 L .47912 .83078 L F
.47969 .83173 m .47913 .83278 L .48082 .82959 L F
.778 .705 .782 r
.47974 .82716 m .48082 .82959 L .48272 .82728 L F
.785 .617 .671 r
.46831 .83499 m .47196 .83777 L .47184 .83576 L F
.46831 .83499 m .46993 .83827 L .47196 .83777 L F
.802 .699 .752 r
.46993 .83827 m .46968 .84047 L .47196 .83777 L F
.629 .585 .786 r
.47196 .83777 m .47319 .83857 L .47184 .83576 L F
.729 .595 .707 r
.46968 .84047 m .47319 .83857 L .47196 .83777 L F
.704 .679 .823 r
.44638 .83204 m .44733 .8333 L .44939 .83251 L F
.587 .278 .412 r
.46034 .8716 m .46384 .87042 L .46238 .87315 L F
.608 .377 .541 r
.46384 .87042 m .46635 .87299 L .46238 .87315 L F
.46384 .87042 m .46568 .87085 L .46635 .87299 L F
.751 .614 .706 r
.45301 .84582 m .45274 .84801 L .45493 .84537 L F
.69 .522 .655 r
.45274 .84801 m .45498 .84788 L .45493 .84537 L F
.649 .493 .659 r
.45493 .84537 m .458 .84572 L .45708 .84281 L F
.688 .563 .708 r
.45498 .84788 m .458 .84572 L .45493 .84537 L F
.637 .487 .662 r
.45708 .84281 m .45998 .84524 L .46002 .8429 L F
.45708 .84281 m .458 .84572 L .45998 .84524 L F
.382 .727 .99 r
.5067 .80709 m .50559 .80777 L .50497 .80641 L F
.5067 .80709 m .50782 .80775 L .50559 .80777 L F
.775 .929 .935 r
.52603 .81775 m .5271 .81987 L .52803 .81902 L F
.322 .609 .951 r
.5271 .81987 m .52937 .82034 L .52803 .81902 L F
.729 .595 .707 r
.46968 .84047 m .47263 .84043 L .47319 .83857 L F
.678 .332 .382 r
.49739 .88136 m .50051 .88117 L .4994 .88329 L F
.55 .219 .361 r
.50051 .88117 m .50163 .8835 L .4994 .88329 L F
.50051 .88117 m .50254 .88116 L .50163 .8835 L F
.874 .453 .211 r
.49443 .8685 m .4938 .86679 L .49282 .86771 L F
.556 .852 .532 r
.53566 .81628 m .53466 .81743 L .53322 .81888 L F
.217 .342 .777 r
.53566 .81628 m .53695 .81957 L .53466 .81743 L F
.69 .37 .429 r
.53466 .81743 m .53695 .81957 L .53392 .8187 L F
.676 .446 .564 r
.44548 .85071 m .44775 .85252 L .44763 .85051 L F
.44548 .85071 m .44536 .85299 L .44775 .85252 L F
.45 0 .072 r
.39857 .82453 m .40208 .8232 L .39944 .82393 L F
.39857 .82453 m .4007 .82459 L .40208 .8232 L F
.16 0 0 r
.40208 .8232 m .40258 .82399 L .40385 .82276 L F
.40208 .8232 m .40091 .82437 L .40258 .82399 L F
.17 .708 .793 r
.40128 .82391 m .404 .82366 L .40258 .82399 L F
.252 0 0 r
.40385 .82276 m .40258 .82399 L .40456 .82361 L F
.17 .708 .793 r
.404 .82366 m .40456 .82361 L .40258 .82399 L F
.16 0 0 r
.40091 .82437 m .4007 .82459 L .40258 .82399 L F
.492 .534 .828 r
.43923 .85845 m .44162 .86031 L .44151 .85847 L F
.128 .677 .771 r
.43545 .81979 m .43747 .81959 L .43873 .81956 L F
.119 .669 .802 r
.43747 .81959 m .44069 .81956 L .43873 .81956 L F
.604 .934 .955 r
.42485 .83417 m .4283 .8333 L .42656 .83383 L F
.068 0 0 r
.4283 .8333 m .42912 .83349 L .42656 .83383 L F
.4283 .8333 m .43041 .8331 L .42912 .83349 L F
.58 .275 .415 r
.44382 .87633 m .44454 .87856 L .44273 .87807 L F
.44382 .87633 m .446 .87612 L .44454 .87856 L F
.841 .493 .395 r
.48312 .8758 m .48566 .87655 L .48448 .87827 L F
.769 .394 .345 r
.48566 .87655 m .48734 .87869 L .48448 .87827 L F
.826 .918 .898 r
.48116 .8601 m .48233 .8606 L .48474 .85838 L F
.515 .167 .316 r
.40624 .89206 m .40775 .8935 L .40564 .89372 L F
.40624 .89206 m .40868 .89155 L .40775 .8935 L F
.712 .467 .554 r
.4695 .84248 m .47263 .84043 L .46968 .84047 L F
.4695 .84248 m .4727 .84291 L .47263 .84043 L F
.698 .83 .946 r
.46498 .81738 m .46182 .81737 L .46368 .81635 L F
.678 .799 .939 r
.46693 .81665 m .46498 .81738 L .46368 .81635 L F
.255 .752 .904 r
.43015 .8201 m .43223 .81992 L .43345 .82014 L F
.386 .828 .945 r
.43345 .82014 m .43421 .81953 L .43545 .81979 L F
.43345 .82014 m .43223 .81992 L .43421 .81953 L F
.689 .761 .906 r
.47335 .83483 m .47667 .83491 L .47558 .834 L F
.775 .996 .861 r
.47667 .83491 m .47808 .83291 L .47558 .834 L F
.47667 .83491 m .47913 .83278 L .47808 .83291 L F
.685 .434 .537 r
.51436 .86337 m .51194 .86095 L .51185 .86321 L F
.682 .328 .368 r
.41625 .87016 m .41927 .87093 L .41759 .86925 L F
.548 .346 .558 r
.41759 .86925 m .41927 .87093 L .41961 .86828 L F
.52 .814 .999 r
.4501 .81789 m .44926 .81899 L .44792 .81828 L F
.4501 .81789 m .45107 .81859 L .44926 .81899 L F
.76 .753 .846 r
.48168 .82516 m .47974 .82716 L .48272 .82728 L F
.83 .779 .804 r
.48168 .82516 m .48272 .82728 L .48349 .82535 L F
.571 .879 .993 r
.45441 .8184 m .45107 .81859 L .45318 .81791 L F
.538 .86 .996 r
.45528 .81734 m .45441 .8184 L .45318 .81791 L F
.45528 .81734 m .45655 .81785 L .45441 .8184 L F
.1 0 0 r
.40915 .82233 m .41118 .82221 L .41244 .82189 L F
.104 .659 .729 r
.41118 .82221 m .4144 .82186 L .41244 .82189 L F
.568 .276 .432 r
.41861 .88596 m .4196 .88886 L .41745 .88891 L F
.41861 .88596 m .42054 .88616 L .4196 .88886 L F
.023 0 0 r
.40385 .82276 m .40597 .82264 L .40716 .82247 L F
.147 .691 .773 r
.40597 .82264 m .40915 .82233 L .40716 .82247 L F
.926 .964 .662 r
.48396 .81882 m .48496 .81781 L .48479 .81647 L F
.48396 .81882 m .48392 .81969 L .48496 .81781 L F
.585 .279 .415 r
.46022 .87323 m .46034 .8716 L .46238 .87315 L F
.552 .846 .998 r
.45978 .81794 m .45655 .81785 L .45862 .81738 L F
.56 .859 .997 r
.46182 .81737 m .45978 .81794 L .45862 .81738 L F
.404 .842 .941 r
.40594 .83822 m .40537 .83889 L .40738 .83844 L F
.40594 .83822 m .40363 .83875 L .40537 .83889 L F
.67 .262 .264 r
.39653 .8232 m .39535 .82451 L .39857 .82453 L F
.675 .236 .2 r
.39653 .8232 m .39857 .82453 L .39944 .82393 L F
.495 .885 .96 r
.52937 .82034 m .53242 .81998 L .53135 .81959 L F
.737 .947 .949 r
.53135 .81959 m .53242 .81998 L .53392 .8187 L F
.796 .748 .809 r
.46557 .8322 m .46826 .83269 L .46738 .83051 L F
.833 .617 .61 r
.46557 .8322 m .46831 .83499 L .46826 .83269 L F
.608 .581 .798 r
.46826 .83269 m .46919 .82952 L .46738 .83051 L F
.46826 .83269 m .47037 .8324 L .46919 .82952 L F
.716 .606 .733 r
.46831 .83499 m .47037 .8324 L .46826 .83269 L F
.641 .591 .783 r
.44939 .83251 m .45258 .83511 L .45141 .83211 L F
.662 .649 .827 r
.45258 .83511 m .45334 .83162 L .45141 .83211 L F
.607 .56 .775 r
.45258 .83511 m .45575 .83768 L .45564 .8354 L F
.422 0 0 r
.45564 .8354 m .45603 .83546 L .45258 .83511 L F
.601 .587 .809 r
.45661 .83242 m .45564 .8354 L .45787 .83512 L F
.45661 .83242 m .45603 .83546 L .45564 .8354 L F
.682 .54 .686 r
.45564 .8354 m .45575 .83768 L .45787 .83512 L F
.662 .649 .827 r
.45258 .83511 m .45603 .83546 L .45334 .83162 L F
.427 .806 .992 r
.52394 .80892 m .52235 .80933 L .52053 .80861 L F
.562 .289 .459 r
.43117 .88137 m .42998 .88404 L .42797 .88408 L F
.599 .328 .477 r
.43327 .88284 m .43117 .88137 L .43299 .88114 L F
.43327 .88284 m .42998 .88404 L .43117 .88137 L F
.515 .279 .495 r
.44162 .86031 m .4446 .85815 L .44151 .85847 L F
.736 .373 .363 r
.47946 .87336 m .48257 .87371 L .48135 .87555 L F
.85 .525 .438 r
.48135 .87555 m .48257 .87371 L .48312 .8758 L F
.766 .77 .855 r
.47744 .81439 m .47436 .8144 L .4761 .81348 L F
.772 .769 .85 r
.4797 .81232 m .47744 .81439 L .4761 .81348 L F
.707 .565 .692 r
.44763 .85051 m .45067 .85057 L .44986 .8474 L F
.698 .565 .701 r
.44986 .8474 m .45274 .84801 L .45301 .84582 L F
.7 .56 .694 r
.44986 .8474 m .45067 .85057 L .45274 .84801 L F
.382 .806 .97 r
.44069 .81956 m .44271 .81928 L .44393 .81967 L F
.516 .916 .863 r
.44393 .81967 m .44472 .81888 L .44589 .8187 L F
.445 .838 .981 r
.44393 .81967 m .44271 .81928 L .44472 .81888 L F
.287 .787 .827 r
.48703 .80795 m .48879 .80747 L .48916 .80755 L F
.48703 .80795 m .48505 .8081 L .48879 .80747 L F
.716 .196 0 r
.48242 .86508 m .48048 .86325 L .47903 .86302 L F
.748 .814 .904 r
.43787 .83144 m .44116 .83194 L .43956 .83143 L F
.341 .802 .937 r
.4431 .83142 m .43956 .83143 L .44116 .83194 L F
.892 .951 .837 r
.45112 .87564 m .45255 .87444 L .45312 .87357 L F
.397 0 0 r
.51994 .81442 m .51608 .81368 L .51737 .81413 L F
.134 .59 .924 r
.51737 .81413 m .52041 .81506 L .51994 .81442 L F
.368 0 0 r
.4144 .82186 m .4164 .822 L .41751 .8214 L F
.373 .001 .196 r
.41941 .82082 m .41751 .8214 L .41952 .8209 L F
.259 0 0 r
.4164 .822 m .41952 .8209 L .41751 .8214 L F
.704 .679 .823 r
.44638 .83204 m .44939 .83251 L .44872 .83156 L F
.59 .734 .943 r
.44872 .83156 m .44939 .83251 L .45141 .83211 L F
.447 .161 .384 r
.51598 .86804 m .51829 .86608 L .51841 .86772 L F
.566 .318 .5 r
.51829 .86608 m .52017 .86774 L .51841 .86772 L F
.51829 .86608 m .5203 .86591 L .52017 .86774 L F
.581 .401 .603 r
.50927 .82486 m .51158 .82511 L .51131 .82223 L F
.639 .497 .673 r
.5134 .8197 m .51358 .82254 L .51131 .82223 L F
0 0 0 r
.5134 .8197 m .51131 .82223 L .51211 .82162 L F
.134 .282 .751 r
.51337 .82426 m .51131 .82223 L .51358 .82254 L F
.282 .696 .971 r
.51131 .82223 m .51358 .82254 L .51211 .82162 L F
.517 .354 .599 r
.51131 .82223 m .51337 .82426 L .51211 .82162 L F
.51131 .82223 m .51158 .82511 L .51337 .82426 L F
.763 .451 .458 r
.48436 .86529 m .48683 .86574 L .48542 .86363 L F
.742 .644 .752 r
.46779 .84025 m .46968 .84047 L .46993 .83827 L F
.731 .502 .581 r
.46779 .84025 m .4695 .84248 L .46968 .84047 L F
.945 .844 .712 r
.5081 .82431 m .50927 .82486 L .50798 .82645 L F
.883 .891 .832 r
.50846 .82675 m .50927 .82486 L .5081 .82431 L F
.50846 .82675 m .51158 .82511 L .50927 .82486 L F
.367 .709 .986 r
.49963 .81433 m .49861 .81521 L .49744 .81428 L F
.49963 .81433 m .50064 .81516 L .49861 .81521 L F
.615 .351 .494 r
.43533 .879 m .43726 .88097 L .4352 .88097 L F
.605 .351 .506 r
.43533 .879 m .43741 .87895 L .43726 .88097 L F
.768 .562 .62 r
.47957 .87119 m .47618 .87321 L .47614 .87101 L F
.47957 .87119 m .47946 .87336 L .47618 .87321 L F
.635 .919 .637 r
.39391 .84134 m .39489 .84081 L .39697 .84057 L F
.39391 .84134 m .39337 .842 L .39489 .84081 L F
.708 .573 .7 r
.45274 .84801 m .45067 .85057 L .4535 .8503 L F
.626 .478 .662 r
.4535 .8503 m .45498 .84788 L .45274 .84801 L F
.637 .545 .734 r
.44352 .85559 m .44536 .85299 L .44323 .85331 L F
.564 .933 .917 r
.41665 .83589 m .41529 .83691 L .41825 .83568 L F
0 0 0 r
.41984 .83462 m .41665 .83589 L .41825 .83568 L F
.54 .208 .354 r
.43141 .86756 m .42988 .86607 L .42875 .86869 L F
.55 .207 .339 r
.43141 .86756 m .43211 .86603 L .42988 .86607 L F
.834 .518 .455 r
.48734 .87869 m .48916 .87873 L .48774 .88065 L F
.809 .482 .436 r
.48916 .87873 m .49066 .8814 L .48774 .88065 L F
.78 .475 .472 r
.48916 .87873 m .49231 .88111 L .49066 .8814 L F
.374 .108 .377 r
.50689 .87855 m .50748 .87672 L .50919 .87614 L F
.671 .473 .608 r
.45067 .85057 m .45275 .8524 L .4535 .8503 L F
.626 .478 .662 r
.4535 .8503 m .45581 .85066 L .45498 .84788 L F
.722 .589 .707 r
.45275 .8524 m .45581 .85066 L .4535 .8503 L F
.637 .545 .734 r
.44352 .85559 m .44672 .85621 L .44536 .85299 L F
.689 .533 .669 r
.44352 .85559 m .44652 .8581 L .44672 .85621 L F
.44352 .85559 m .4446 .85815 L .44652 .8581 L F
.26 .76 .892 r
.42284 .83455 m .42183 .83438 L .41984 .83462 L F
0 0 0 r
.42485 .83417 m .42183 .83438 L .42284 .83455 L F
.696 .719 .867 r
.51152 .80868 m .50782 .80775 L .51026 .80802 L F
.497 0 0 r
.51026 .80802 m .51329 .80832 L .51152 .80868 L F
.701 .498 .61 r
.44775 .85252 m .45067 .85057 L .44763 .85051 L F
.44775 .85252 m .45061 .85291 L .45067 .85057 L F
.671 .473 .608 r
.45067 .85057 m .45061 .85291 L .45275 .8524 L F
.667 .483 .626 r
.46002 .8429 m .46212 .84511 L .46212 .84278 L F
.46002 .8429 m .45998 .84524 L .46212 .84511 L F
.666 .65 .825 r
.45334 .83162 m .45603 .83546 L .45661 .83242 L F
.408 .137 .388 r
.50455 .88078 m .50497 .87908 L .50689 .87855 L F
.631 .689 .886 r
.3874 .84319 m .38939 .84259 L .38709 .84275 L F
.713 .616 .748 r
.46092 .83773 m .4622 .84055 L .46426 .84021 L F
.702 .552 .68 r
.4622 .84055 m .46212 .84278 L .46426 .84021 L F
.713 .616 .748 r
.46092 .83773 m .46426 .84021 L .46307 .83718 L F
.641 .465 .629 r
.46426 .84021 m .46212 .84278 L .4645 .84259 L F
.745 .665 .772 r
.46307 .83718 m .46426 .84021 L .46624 .83758 L F
.693 .588 .733 r
.46426 .84021 m .46779 .84025 L .46624 .83758 L F
.642 .418 .563 r
.4645 .84259 m .46779 .84025 L .46426 .84021 L F
.539 .287 .481 r
.43211 .86603 m .43426 .86585 L .43494 .86317 L F
.45 .204 .448 r
.43494 .86317 m .43603 .86523 L .43703 .86316 L F
.43494 .86317 m .43426 .86585 L .43603 .86523 L F
.688 .563 .708 r
.45498 .84788 m .45794 .84794 L .458 .84572 L F
.673 .505 .651 r
.45498 .84788 m .45795 .85026 L .45794 .84794 L F
.45498 .84788 m .45581 .85066 L .45795 .85026 L F
.623 .342 .471 r
.41177 .87304 m .4146 .87064 L .41245 .87157 L F
.498 .735 .978 r
.51228 .81449 m .51322 .81337 L .51129 .81378 L F
.51228 .81449 m .5144 .81435 L .51322 .81337 L F
.006 0 0 r
.5081 .81328 m .50598 .81354 L .50729 .81317 L F
.979 .816 .61 r
.49496 .87152 m .49443 .8685 L .49279 .87114 L F
.764 .321 .2 r
.4951 .87216 m .49496 .87152 L .49279 .87114 L F
.569 .184 .272 r
.49708 .87259 m .49496 .87152 L .4951 .87216 L F
.767 .649 .731 r
.39725 .87858 m .40051 .87882 L .3998 .87633 L F
.56 .532 .78 r
.39839 .87554 m .39921 .87854 L .39725 .87858 L F
.991 .736 .418 r
.39834 .87747 m .39921 .87854 L .39839 .87554 L F
.812 .516 .488 r
.39834 .87747 m .3992 .87831 L .39921 .87854 L F
.196 .707 .894 r
.39921 .87854 m .40051 .87882 L .39922 .87872 L F
0 .029 .587 r
.3998 .87633 m .40051 .87882 L .40099 .87845 L F
.289 .765 .93 r
.40099 .87845 m .40051 .87882 L .39921 .87854 L F
.40099 .87845 m .39921 .87854 L .4011 .88017 L F
.812 .516 .488 r
.3992 .87831 m .4011 .88017 L .39921 .87854 L F
.196 .707 .894 r
.39921 .87854 m .39922 .87872 L .39725 .87858 L F
.534 .863 .586 r
.4902 .81049 m .4888 .81187 L .49231 .80985 L F
.4902 .81049 m .48917 .81145 L .4888 .81187 L F
.721 .335 .316 r
.52122 .86262 m .52228 .86091 L .51917 .86059 L F
.732 .523 .61 r
.52467 .86207 m .5278 .86091 L .52462 .86113 L F
.5247 .86279 m .52561 .86224 L .52467 .86207 L F
.52561 .86224 m .5278 .86091 L .52467 .86207 L F
.697 .305 .302 r
.52122 .86262 m .52491 .8624 L .52416 .86197 L F
.52188 .86155 m .52416 .86197 L .52228 .86091 L F
.52122 .86262 m .52416 .86197 L .52188 .86155 L F
.599 .217 .291 r
.42588 .88379 m .42654 .8861 L .42465 .88621 L F
.42588 .88379 m .42797 .88408 L .42654 .8861 L F
.766 .646 .728 r
.4727 .84291 m .47567 .84507 L .47592 .8431 L F
.4727 .84291 m .474 .84569 L .47567 .84507 L F
.772 .667 .747 r
.474 .84569 m .47388 .84764 L .47567 .84507 L F
.672 .527 .679 r
.47388 .84764 m .47702 .84788 L .47567 .84507 L F
.691 .458 .566 r
.47567 .84507 m .47747 .84296 L .47592 .8431 L F
.607 .411 .591 r
.47702 .84788 m .47926 .84532 L .47567 .84507 L F
.564 .933 .917 r
.41665 .83589 m .41425 .83698 L .41529 .83691 L F
.892 .951 .837 r
.45112 .87564 m .45312 .87357 L .45332 .87547 L F
.589 .394 .586 r
.45312 .87357 m .45507 .8757 L .45332 .87547 L F
.45312 .87357 m .45512 .87345 L .45507 .8757 L F
.516 .18 .337 r
.43913 .86236 m .44116 .86244 L .44162 .86031 L F
.515 .279 .495 r
.44162 .86031 m .44343 .86064 L .4446 .85815 L F
.733 .506 .584 r
.44116 .86244 m .44343 .86064 L .44162 .86031 L F
.593 .416 .611 r
.45787 .83512 m .45575 .83768 L .4579 .83728 L F
.587 .563 .794 r
.45787 .83512 m .45877 .83196 L .45661 .83242 L F
.45787 .83512 m .45992 .83481 L .45877 .83196 L F
.725 .626 .747 r
.4579 .83728 m .45992 .83481 L .45787 .83512 L F
.734 .614 .724 r
.47037 .8324 m .47335 .83483 L .47251 .83191 L F
.47037 .8324 m .47184 .83576 L .47335 .83483 L F
.589 .561 .79 r
.47251 .83191 m .47335 .83483 L .47558 .834 L F
.696 .982 .873 r
.47808 .83291 m .47913 .83278 L .47969 .83173 L F
.77 .722 .808 r
.51217 .81783 m .5134 .8197 L .51029 .81915 L F
0 0 0 r
.5134 .8197 m .51211 .82162 L .51029 .81915 L F
0 .07 .624 r
.51217 .81783 m .51321 .81892 L .5134 .8197 L F
.977 .754 .535 r
.51211 .82162 m .5134 .8197 L .51321 .81892 L F
.51211 .82162 m .51358 .82254 L .5134 .8197 L F
.804 .695 .744 r
.4705 .84756 m .47388 .84764 L .474 .84569 L F
.786 .5 .503 r
.47354 .85043 m .47077 .84989 L .47223 .84895 L F
.47354 .85043 m .47388 .84764 L .471 .84757 L F
.47354 .85043 m .47223 .84895 L .47231 .8489 L F
.664 .588 .761 r
.47077 .84989 m .47354 .85043 L .47231 .8489 L F
.786 .5 .503 r
.47354 .85043 m .471 .84757 L .4705 .84756 L F
.646 .321 .408 r
.47573 .84989 m .47388 .84764 L .47354 .85043 L F
.47573 .84989 m .47702 .84788 L .47388 .84764 L F
.71 .932 .962 r
.49967 .80468 m .49618 .80562 L .49876 .80424 L F
.584 .894 .988 r
.50156 .80406 m .49967 .80468 L .49876 .80424 L F
.536 .307 .515 r
.51598 .86804 m .51797 .87012 L .51542 .871 L F
.51598 .86804 m .51841 .86772 L .51797 .87012 L F
.62 .308 .421 r
.446 .87612 m .44677 .87859 L .44454 .87856 L F
.446 .87612 m .44779 .87618 L .44677 .87859 L F
.533 .264 .452 r
.40868 .89155 m .41009 .89369 L .40775 .8935 L F
.40868 .89155 m .41085 .89146 L .41009 .89369 L F
.685 .329 .366 r
.49617 .8834 m .49739 .88136 L .4994 .88329 L F
.651 .817 .963 r
.48396 .81882 m .48075 .81943 L .48392 .81969 L F
.209 .735 .823 r
.38808 .82529 m .39015 .825 L .39134 .825 L F
.826 .918 .898 r
.48116 .8601 m .48474 .85838 L .48344 .85791 L F
.83 .67 .684 r
.48474 .85838 m .4833 .85546 L .48344 .85791 L F
.623 .342 .471 r
.41177 .87304 m .41389 .87323 L .4146 .87064 L F
.665 .441 .57 r
.41389 .87323 m .41625 .87016 L .4146 .87064 L F
.011 .583 .759 r
.51546 .80828 m .51861 .80848 L .51629 .80911 L F
.83 .779 .804 r
.48168 .82516 m .48349 .82535 L .48392 .82471 L F
.241 .757 .824 r
.40077 .83958 m .39984 .83993 L .40172 .83929 L F
.40077 .83958 m .39872 .83995 L .39984 .83993 L F
.707 .824 .937 r
.47254 .81541 m .46919 .81545 L .47127 .81472 L F
.714 .874 .956 r
.47436 .8144 m .47254 .81541 L .47127 .81472 L F
.716 .606 .733 r
.46831 .83499 m .47184 .83576 L .47037 .8324 L F
.576 .473 .7 r
.52088 .81675 m .5225 .81422 L .52041 .81506 L F
.439 .505 .83 r
.52407 .8173 m .52245 .81763 L .52088 .81675 L F
.308 0 .09 r
.40245 .89591 m .40374 .89416 L .40564 .89372 L F
.6 .801 .977 r
.44517 .83096 m .44638 .83204 L .44872 .83156 L F
.642 .418 .563 r
.4645 .84259 m .46737 .84262 L .46779 .84025 L F
.742 .644 .752 r
.46779 .84025 m .46993 .83827 L .46624 .83758 L F
.731 .502 .581 r
.46779 .84025 m .46737 .84262 L .4695 .84248 L F
.397 0 0 r
.51994 .81442 m .52044 .8151 L .51608 .81368 L F
.623 .498 .69 r
.51994 .81442 m .52041 .81506 L .5225 .81422 L F
.51994 .81442 m .5225 .81422 L .52213 .8147 L F
0 0 .222 r
.52085 .81387 m .51994 .81442 L .52213 .8147 L F
.486 .8 1 r
.5225 .81422 m .52488 .81421 L .52472 .81357 L F
.476 .39 .68 r
.52446 .81421 m .52475 .81687 L .52488 .81421 L F
.5225 .81422 m .52277 .81453 L .52446 .81421 L F
.52277 .81453 m .52475 .81687 L .52446 .81421 L F
.486 .8 1 r
.5225 .81422 m .52472 .81357 L .52219 .81463 L F
.52219 .81463 m .52472 .81357 L .52213 .8147 L F
.573 .887 .99 r
.52169 .81363 m .52211 .81466 L .52472 .81357 L F
.52211 .81466 m .52213 .8147 L .52232 .81462 L F
.52211 .81466 m .52232 .81462 L .52472 .81357 L F
.52052 .81366 m .52085 .81387 L .52169 .81363 L F
.52085 .81387 m .52213 .8147 L .52169 .81363 L F
.572 .36 .554 r
.52205 .81353 m .52256 .81406 L .52172 .81397 L F
.573 .887 .99 r
.52052 .81366 m .52472 .81357 L .52246 .81299 L F
.572 .36 .554 r
.52246 .81299 m .5225 .8134 L .52205 .81353 L F
.5225 .8134 m .52256 .81406 L .52205 .81353 L F
.52172 .81397 m .52272 .81564 L .52047 .81564 L F
.52256 .81406 m .52272 .81564 L .52172 .81397 L F
0 0 .222 r
.52052 .81366 m .52039 .81383 L .52085 .81387 L F
.52039 .81383 m .51994 .81442 L .52085 .81387 L F
.52052 .81366 m .52044 .8151 L .51994 .81442 L F
.685 .527 .666 r
.46212 .84511 m .4645 .84259 L .46212 .84278 L F
.643 .522 .7 r
.45794 .84794 m .45998 .84524 L .458 .84572 L F
.45794 .84794 m .46008 .84765 L .45998 .84524 L F
.686 .534 .675 r
.45795 .85026 m .46008 .84765 L .45794 .84794 L F
.716 .59 .714 r
.46624 .83758 m .46993 .83827 L .46831 .83499 L F
.607 .411 .591 r
.47702 .84788 m .47863 .84821 L .47926 .84532 L F
.666 .284 .314 r
.48154 .84654 m .48148 .84558 L .47926 .84532 L F
.263 .48 .881 r
.47991 .84452 m .48154 .84654 L .47926 .84532 L F
.027 0 .337 r
.47926 .84532 m .48028 .84652 L .47991 .84452 L F
.47926 .84532 m .47863 .84821 L .48028 .84652 L F
.678 .799 .939 r
.46693 .81665 m .46368 .81635 L .46532 .81543 L F
.701 .8 .926 r
.46919 .81545 m .46693 .81665 L .46532 .81543 L F
.522 .077 .133 r
.42302 .86816 m .41961 .86828 L .42128 .86815 L F
.704 .601 .739 r
.41927 .87093 m .42128 .86815 L .41961 .86828 L F
.802 .675 .724 r
.47699 .85066 m .4804 .85057 L .47863 .84821 L F
.731 .543 .637 r
.47692 .85278 m .4804 .85057 L .47699 .85066 L F
.47692 .85278 m .48026 .85285 L .4804 .85057 L F
.742 .665 .775 r
.47863 .84821 m .4804 .85057 L .48246 .84843 L F
.633 .076 0 r
.48095 .84689 m .48121 .84694 L .48154 .84654 L F
.48121 .84694 m .48222 .84714 L .48154 .84654 L F
.772 .589 .652 r
.48246 .84843 m .48173 .84631 L .48154 .84654 L F
.48173 .84631 m .48148 .84558 L .48154 .84654 L F
.269 .776 .807 r
.49419 .8061 m .49509 .8057 L .49618 .80562 L F
.49419 .8061 m .49311 .80619 L .49509 .8057 L F
.62 .338 .469 r
.51937 .86244 m .517 .86046 L .51623 .86283 L F
.51937 .86244 m .51917 .86059 L .517 .86046 L F
.35 .807 .939 r
.42562 .81972 m .42496 .82029 L .42342 .8204 L F
.42562 .81972 m .42694 .81996 L .42496 .82029 L F
.57 .344 .534 r
.4352 .88097 m .43327 .88284 L .43299 .88114 L F
.332 0 .05 r
.4099 .87361 m .40655 .87562 L .40913 .8759 L F
.355 .035 .278 r
.41177 .87304 m .4099 .87361 L .40913 .8759 L F
.539 .251 .425 r
.43603 .86523 m .43913 .86236 L .43703 .86316 L F
.628 .699 .897 r
.38709 .84275 m .38911 .84176 L .38614 .84158 L F
.38709 .84275 m .38939 .84259 L .38911 .84176 L F
0 0 0 r
.38275 .82666 m .38468 .82632 L .38623 .82585 L F
.251 0 0 r
.38468 .82632 m .38808 .82529 L .38623 .82585 L F
0 .029 .587 r
.3998 .87633 m .40099 .87845 L .40255 .87604 L F
.599 .296 .427 r
.40255 .87604 m .40411 .87782 L .40497 .8764 L F
.40255 .87604 m .40099 .87845 L .40411 .87782 L F
.448 .119 .315 r
.50163 .8835 m .50254 .88116 L .50455 .88078 L F
.667 .41 .523 r
.46568 .87085 m .46763 .87312 L .46635 .87299 L F
.65 .41 .542 r
.46568 .87085 m .46764 .87098 L .46763 .87312 L F
.772 .769 .85 r
.4797 .81232 m .4761 .81348 L .47849 .81164 L F
.823 .867 .879 r
.48207 .81016 m .4797 .81232 L .47849 .81164 L F
.653 .466 .619 r
.5236 .86319 m .52336 .86556 L .5203 .86591 L F
.565 .389 .602 r
.52519 .86513 m .5236 .86319 L .52491 .8624 L F
.52519 .86513 m .52336 .86556 L .5236 .86319 L F
.833 .617 .61 r
.46557 .8322 m .46531 .83499 L .46831 .83499 L F
.827 .769 .797 r
.46533 .83653 m .46831 .83499 L .46531 .83499 L F
.46533 .83653 m .46624 .83758 L .46831 .83499 L F
.694 .744 .89 r
.46307 .83718 m .46624 .83758 L .46533 .83653 L F
.739 .635 .743 r
.47053 .8453 m .474 .84569 L .4727 .84291 L F
.804 .695 .744 r
.4705 .84756 m .474 .84569 L .47053 .8453 L F
.542 .895 .672 r
.50508 .8644 m .50668 .86337 L .50447 .86506 L F
.50445 .865 m .50447 .86506 L .50405 .86539 L F
.50508 .8644 m .50447 .86506 L .50445 .865 L F
0 0 .365 r
.50438 .86479 m .50448 .86504 L .50548 .86679 L F
.542 .895 .672 r
.50508 .8644 m .50405 .86539 L .50448 .86504 L F
.7 .976 .914 r
.50508 .8644 m .50448 .86504 L .50412 .86432 L F
0 0 .365 r
.50412 .86432 m .50443 .86494 L .50438 .86479 L F
.50443 .86494 m .50448 .86504 L .50438 .86479 L F
.503 .373 .636 r
.50405 .86539 m .50548 .86679 L .50448 .86504 L F
.50405 .86539 m .50595 .86785 L .50548 .86679 L F
.50405 .86539 m .50452 .86816 L .50595 .86785 L F
.712 .499 .6 r
.4446 .85815 m .44647 .86046 L .44652 .8581 L F
.4446 .85815 m .44343 .86064 L .44647 .86046 L F
.056 0 0 r
.43555 .8323 m .43467 .83251 L .43231 .83267 L F
.443 .878 .888 r
.43787 .83144 m .43642 .83162 L .43555 .8323 L F
.454 .881 .791 r
.43642 .83162 m .43467 .83251 L .43555 .8323 L F
.721 .491 .576 r
.47286 .87105 m .47614 .87101 L .47618 .87321 L F
.481 .898 .828 r
.49324 .80906 m .49231 .80985 L .49441 .80938 L F
.49324 .80906 m .4902 .81049 L .49231 .80985 L F
.61 .345 .491 r
.41325 .88867 m .41492 .89078 L .41291 .89114 L F
.41325 .88867 m .41533 .88887 L .41492 .89078 L F
.628 .143 .082 r
.52483 .8187 m .52603 .81775 L .52803 .81902 L F
.712 .33 .323 r
.49066 .8814 m .49231 .88111 L .4913 .88264 L F
.721 .322 .291 r
.49231 .88111 m .49287 .88341 L .4913 .88264 L F
.49231 .88111 m .49404 .8828 L .49287 .88341 L F
.974 .697 .44 r
.51358 .82254 m .51337 .82426 L .51211 .82162 L F
.138 0 .326 r
.51486 .82232 m .51337 .82426 L .51358 .82254 L F
.59 .277 .407 r
.44677 .87859 m .44779 .87618 L .4498 .87762 L F
.602 .267 .374 r
.44779 .87618 m .45112 .87564 L .4498 .87762 L F
.596 .337 .495 r
.43741 .87895 m .43942 .88095 L .43726 .88097 L F
.43741 .87895 m .44196 .87848 L .43942 .88095 L F
0 0 0 r
.50872 .86254 m .50668 .86337 L .50508 .8644 L F
.725 .626 .747 r
.4579 .83728 m .46092 .83773 L .45992 .83481 L F
.657 .588 .767 r
.45992 .83481 m .46092 .83773 L .46307 .83718 L F
0 .079 .612 r
.5321 .8138 m .53213 .81617 L .53091 .81445 L F
.958 .72 .535 r
.47666 .85526 m .47801 .85569 L .47692 .85278 L F
.11 .257 .735 r
.47692 .85278 m .47801 .85569 L .47893 .85474 L F
.942 .691 .528 r
.47893 .85474 m .48024 .85533 L .48026 .85285 L F
0 0 0 r
.47978 .85385 m .47976 .85389 L .47893 .85474 L F
.448 .793 .998 r
.47893 .85474 m .47802 .85569 L .48024 .85533 L F
.956 .691 .494 r
.47801 .85781 m .47801 .85569 L .47666 .85526 L F
.497 .307 .553 r
.48024 .85533 m .47801 .85569 L .47801 .85781 L F
0 0 0 r
.47976 .85389 m .4777 .85644 L .47893 .85474 L F
.448 .793 .998 r
.47893 .85474 m .47801 .85569 L .47802 .85569 L F
.58 .823 .991 r
.49532 .8164 m .49657 .81722 L .49853 .81667 L F
.398 0 .029 r
.39875 .89667 m .40074 .89672 L .39855 .89687 L F
.471 .816 .998 r
.50452 .86816 m .50772 .8684 L .50595 .86785 L F
.737 .414 .434 r
.50658 .87047 m .50772 .8684 L .50452 .86816 L F
.469 .806 .999 r
.50772 .8684 m .50616 .86703 L .50595 .86785 L F
.50772 .8684 m .50977 .86811 L .50616 .86703 L F
.476 .151 .336 r
.50888 .87096 m .50772 .8684 L .50658 .87047 L F
.50888 .87096 m .50977 .86811 L .50772 .8684 L F
.607 .413 .592 r
.47699 .85066 m .47702 .84788 L .47573 .84989 L F
.47699 .85066 m .47863 .84821 L .47702 .84788 L F
.548 .203 .335 r
.45112 .87564 m .45181 .87776 L .4498 .87762 L F
.45112 .87564 m .45332 .87547 L .45181 .87776 L F
.722 .613 .736 r
.44672 .85621 m .44652 .8581 L .44856 .85549 L F
.675 .544 .698 r
.44856 .85549 m .44652 .8581 L .44876 .85768 L F
.69 .501 .626 r
.44652 .8581 m .44983 .86028 L .44876 .85768 L F
.44652 .8581 m .44647 .86046 L .44983 .86028 L F
.685 .498 .627 r
.49887 .87134 m .50245 .87079 L .50235 .86843 L F
.603 .434 .625 r
.50245 .87079 m .50452 .86816 L .50235 .86843 L F
.541 .352 .574 r
.42435 .8684 m .42646 .87034 L .4272 .86791 L F
.472 .177 .382 r
.4272 .86791 m .42844 .87003 L .42875 .86869 L F
.4272 .86791 m .42646 .87034 L .42844 .87003 L F
.505 .891 .958 r
.49808 .80798 m .49752 .8086 L .49946 .80867 L F
.49808 .80798 m .49618 .80849 L .49752 .8086 L F
.727 .571 .678 r
.48047 .84875 m .47845 .85014 L .48056 .84976 L F
.742 .665 .775 r
.47863 .84821 m .48246 .84843 L .48144 .84882 L F
.47863 .84821 m .48144 .84882 L .48125 .8488 L F
.48125 .8488 m .48144 .84882 L .48139 .84883 L F
.357 .376 .744 r
.48028 .84652 m .47863 .84821 L .48094 .84873 L F
.48077 .84756 m .48094 .84873 L .48139 .84883 L F
.48028 .84652 m .48094 .84873 L .48077 .84756 L F
.727 .571 .678 r
.48028 .84652 m .4792 .84866 L .48047 .84875 L F
.4792 .84866 m .47845 .85014 L .48047 .84875 L F
.357 .376 .744 r
.48028 .84652 m .48056 .84976 L .47845 .85014 L F
.48028 .84652 m .48139 .84883 L .48056 .84976 L F
.563 .449 .681 r
.48028 .84652 m .48056 .84976 L .48072 .84709 L F
.687 .433 .533 r
.47845 .85014 m .47977 .85151 L .48056 .84976 L F
.47845 .85014 m .47977 .85151 L .48056 .84976 L F
.959 .794 .635 r
.48056 .84976 m .47977 .85151 L .48071 .84711 L F
.48071 .84713 m .48071 .84711 L .48072 .84709 L F
.48056 .84976 m .48071 .84711 L .48071 .84713 L F
.772 .589 .652 r
.48246 .84843 m .48154 .84654 L .48222 .84714 L F
.968 .902 .54 r
.48139 .84883 m .48246 .84843 L .48222 .84714 L F
.718 .638 .768 r
.46919 .82952 m .47037 .8324 L .47235 .82987 L F
.678 .579 .737 r
.47235 .82987 m .47037 .8324 L .47251 .83191 L F
.14 .677 .846 r
.42694 .81996 m .429 .81992 L .43015 .8201 L F
.271 .758 .916 r
.4311 .81965 m .43015 .8201 L .429 .81992 L F
.4311 .81965 m .43223 .81992 L .43015 .8201 L F
.252 0 0 r
.40385 .82276 m .40456 .82361 L .40597 .82264 L F
.509 .848 .996 r
.45862 .81738 m .45655 .81785 L .45528 .81734 L F
.201 0 0 r
.41952 .8209 m .42152 .82075 L .41941 .82082 L F
.179 .706 .858 r
.43421 .81953 m .43747 .81959 L .43545 .81979 L F
.231 .749 .762 r
.44589 .8187 m .44672 .81839 L .44792 .81828 L F
.44589 .8187 m .44472 .81888 L .44672 .81839 L F
.741 .427 .45 r
.47618 .87321 m .47946 .87336 L .47807 .87548 L F
.703 .379 .425 r
.47946 .87336 m .48135 .87555 L .47807 .87548 L F
.696 .85 .956 r
.41123 .83709 m .41294 .83795 L .41425 .83698 L F
.56 .859 .997 r
.46182 .81737 m .45862 .81738 L .46058 .81664 L F
.729 .868 .946 r
.46368 .81635 m .46182 .81737 L .46058 .81664 L F
.533 0 0 r
.42128 .86815 m .42435 .8684 L .42302 .86816 L F
.692 .467 .577 r
.42235 .87035 m .42435 .8684 L .42128 .86815 L F
.42235 .87035 m .42447 .87063 L .42435 .8684 L F
.541 .352 .574 r
.42435 .8684 m .42447 .87063 L .42646 .87034 L F
.562 .252 .4 r
.42054 .88616 m .42162 .88859 L .4196 .88886 L F
.42054 .88616 m .4226 .88626 L .42162 .88859 L F
0 0 0 r
.42912 .83349 m .43041 .8331 L .43231 .83267 L F
.528 .287 .493 r
.52017 .86774 m .5203 .86591 L .52224 .86739 L F
.585 .261 .387 r
.5203 .86591 m .52336 .86556 L .52224 .86739 L F
.526 .145 .262 r
.48879 .80747 m .49119 .80685 L .48916 .80755 L F
.764 .548 .605 r
.47675 .82905 m .47974 .82716 L .47856 .82732 L F
.47675 .82905 m .47912 .83078 L .47974 .82716 L F
.345 .823 .825 r
.48081 .82663 m .47974 .82716 L .48168 .82516 L F
.48081 .82663 m .47856 .82732 L .47974 .82716 L F
.736 .294 .202 r
.51185 .86321 m .50872 .86254 L .50981 .86275 L F
.875 .607 .53 r
.51202 .86536 m .51185 .86321 L .50981 .86275 L F
.644 .376 .498 r
.51391 .86528 m .51185 .86321 L .51202 .86536 L F
.51391 .86528 m .51436 .86337 L .51185 .86321 L F
.675 .547 .701 r
.45998 .84524 m .46008 .84765 L .46212 .84511 L F
.711 .581 .707 r
.44536 .85299 m .44856 .85549 L .44775 .85252 L F
.694 .569 .709 r
.44775 .85252 m .44856 .85549 L .45061 .85291 L F
.711 .581 .707 r
.44536 .85299 m .44672 .85621 L .44856 .85549 L F
.693 .567 .708 r
.44856 .85549 m .45161 .85572 L .45061 .85291 L F
.653 .482 .64 r
.44876 .85768 m .45161 .85572 L .44856 .85549 L F
.512 .139 .269 r
.42797 .88408 m .42984 .88483 L .42654 .8861 L F
.42797 .88408 m .42998 .88404 L .42984 .88483 L F
.147 .691 .773 r
.40597 .82264 m .40806 .82237 L .40915 .82233 L F
.318 .807 .846 r
.40915 .82233 m .40993 .82188 L .41118 .82221 L F
.40915 .82233 m .40806 .82237 L .40993 .82188 L F
.722 .589 .707 r
.45275 .8524 m .45595 .85289 L .45581 .85066 L F
.727 .561 .667 r
.45275 .8524 m .45379 .85537 L .45595 .85289 L F
.676 .487 .622 r
.45379 .85537 m .45595 .85522 L .45595 .85289 L F
.685 .561 .709 r
.45581 .85066 m .45595 .85289 L .45795 .85026 L F
.642 .501 .675 r
.45795 .85026 m .45595 .85289 L .45817 .85265 L F
.638 .456 .62 r
.45595 .85289 m .45828 .85501 L .45817 .85265 L F
.45595 .85289 m .45595 .85522 L .45828 .85501 L F
.527 .891 .974 r
.4519 .81766 m .45107 .81859 L .4501 .81789 L F
.4519 .81766 m .45318 .81791 L .45107 .81859 L F
.119 .669 .802 r
.43764 .81958 m .43948 .81948 L .44069 .81956 L F
.033 0 0 r
.43809 .8198 m .44135 .81938 L .43948 .81948 L F
0 0 0 r
.43948 .81948 m .44271 .81928 L .44069 .81956 L F
.033 0 0 r
.44135 .81938 m .44155 .81936 L .43948 .81948 L F
.119 .669 .802 r
.43747 .81959 m .43948 .81948 L .43764 .81958 L F
.005 .416 .857 r
.50267 .80446 m .50549 .80599 L .50497 .80641 L F
.034 .463 .878 r
.50549 .80599 m .5067 .80709 L .50497 .80641 L F
.501 .175 .346 r
.43359 .8675 m .43211 .86603 L .43141 .86756 L F
.43359 .8675 m .43426 .86585 L .43211 .86603 L F
.823 .867 .879 r
.48207 .81016 m .47849 .81164 L .48037 .81019 L F
.641 .938 .964 r
.48207 .81016 m .48274 .80918 L .48358 .80889 L F
.48207 .81016 m .48037 .81019 L .48274 .80918 L F
.685 .527 .666 r
.46212 .84511 m .46517 .84562 L .4645 .84259 L F
.637 .496 .674 r
.4645 .84259 m .46727 .84496 L .46737 .84262 L F
.4645 .84259 m .46517 .84562 L .46727 .84496 L F
.686 .534 .675 r
.45795 .85026 m .46143 .85057 L .46008 .84765 L F
.688 .566 .712 r
.46008 .84765 m .46334 .84807 L .46212 .84511 L F
.724 .551 .656 r
.46008 .84765 m .46324 .85025 L .46334 .84807 L F
.46008 .84765 m .46143 .85057 L .46324 .85025 L F
.693 .463 .57 r
.47144 .87074 m .46763 .87312 L .46764 .87098 L F
.584 .894 .988 r
.50156 .80406 m .49876 .80424 L .50042 .80338 L F
.674 .13 0 r
.50042 .80338 m .50267 .80446 L .50156 .80406 L F
.744 .489 .546 r
.47144 .87074 m .47286 .87105 L .47279 .87319 L F
.721 .491 .576 r
.47286 .87105 m .47618 .87321 L .47279 .87319 L F
.59 .734 .943 r
.44872 .83156 m .45141 .83211 L .45048 .83115 L F
.599 .775 .965 r
.45048 .83115 m .45141 .83211 L .45334 .83162 L F
.653 .482 .64 r
.44876 .85768 m .45162 .85815 L .45161 .85572 L F
.639 .489 .663 r
.44983 .86028 m .45162 .85815 L .44876 .85768 L F
.104 .659 .729 r
.41118 .82221 m .41319 .82197 L .4144 .82186 L F
.45 .835 .986 r
.41319 .82197 m .4164 .822 L .4144 .82186 L F
.815 .423 .311 r
.48748 .8698 m .4891 .86889 L .48629 .86781 L F
.847 .46 .315 r
.4833 .85546 m .48026 .85285 L .48024 .85533 L F
.789 .546 .569 r
.48344 .85791 m .4833 .85546 L .48024 .85533 L F
.497 0 0 r
.51026 .80802 m .51204 .80863 L .51329 .80832 L F
.143 0 0 r
.51329 .80832 m .51204 .80863 L .51546 .80828 L F
0 0 0 r
.42485 .83417 m .42382 .83424 L .42183 .83438 L F
.043 0 0 r
.42656 .83383 m .42382 .83424 L .42485 .83417 L F
.661 .55 .718 r
.45061 .85291 m .45379 .85537 L .45275 .8524 L F
.45061 .85291 m .45161 .85572 L .45379 .85537 L F
.667 .271 .287 r
.50412 .8149 m .50274 .81644 L .50028 .81546 L F
.503 .077 .164 r
.50454 .81624 m .50412 .8149 L .50561 .8138 L F
.50454 .81624 m .50274 .81644 L .50412 .8149 L F
.683 .445 .555 r
.45512 .87345 m .45711 .8759 L .45507 .8757 L F
.45512 .87345 m .45708 .87354 L .45711 .8759 L F
0 0 0 r
.41984 .83462 m .41852 .83525 L .41665 .83589 L F
.485 .052 .14 r
.42183 .83438 m .41852 .83525 L .41984 .83462 L F
.259 0 0 r
.4164 .822 m .41843 .82173 L .41952 .8209 L F
.201 0 0 r
.41952 .8209 m .42039 .82129 L .42152 .82075 L F
.162 0 0 r
.41952 .8209 m .41843 .82173 L .42039 .82129 L F
.624 .459 .638 r
.45161 .85572 m .45375 .85778 L .45379 .85537 L F
.45161 .85572 m .45162 .85815 L .45375 .85778 L F
.64 .527 .709 r
.47251 .83191 m .47457 .82949 L .47235 .82987 L F
.47251 .83191 m .47573 .83326 L .47457 .82949 L F
.589 .561 .79 r
.47251 .83191 m .47558 .834 L .47573 .83326 L F
.714 .874 .956 r
.47436 .8144 m .47127 .81472 L .47317 .81383 L F
.77 .904 .934 r
.4761 .81348 m .47436 .8144 L .47317 .81383 L F
.533 .725 .962 r
.38939 .84259 m .39096 .84145 L .38911 .84176 L F
.38939 .84259 m .3914 .84239 L .39096 .84145 L F
.56 .532 .78 r
.39839 .87554 m .39725 .87858 L .39617 .87762 L F
.421 .706 .982 r
.50884 .80706 m .50782 .80775 L .5067 .80709 L F
.50884 .80706 m .51026 .80802 L .50782 .80775 L F
.11 .257 .735 r
.47692 .85278 m .47893 .85474 L .48026 .85285 L F
.661 .302 .352 r
.487 .82421 m .48594 .82651 L .48392 .82471 L F
.746 .67 .777 r
.4892 .82188 m .487 .82421 L .48608 .82157 L F
.672 .314 .358 r
.48925 .82628 m .48594 .82651 L .487 .82421 L F
.505 .768 .99 r
.49034 .82457 m .487 .82421 L .4892 .82188 L F
.672 .314 .358 r
.49034 .82457 m .48925 .82628 L .487 .82421 L F
.789 .629 .682 r
.48075 .81943 m .48034 .82246 L .48187 .8221 L F
.641 .266 .318 r
.48034 .82246 m .48063 .82293 L .48187 .8221 L F
.265 0 0 r
.48187 .8221 m .48063 .82293 L .48336 .82223 L F
.651 .361 .466 r
.51937 .86244 m .52122 .86262 L .51917 .86059 L F
.693 .463 .57 r
.47144 .87074 m .47247 .87337 L .46763 .87312 L F
.744 .489 .546 r
.47144 .87074 m .47279 .87319 L .47247 .87337 L F
.654 .474 .627 r
.45817 .85265 m .46143 .85057 L .45795 .85026 L F
.715 .579 .701 r
.46212 .84511 m .46534 .84753 L .46517 .84562 L F
.46212 .84511 m .46334 .84807 L .46534 .84753 L F
.715 .58 .702 r
.46334 .84807 m .46324 .85025 L .46534 .84753 L F
.664 .507 .662 r
.46324 .85025 m .46544 .85015 L .46534 .84753 L F
.663 .583 .756 r
.46517 .84562 m .46534 .84753 L .46727 .84496 L F
.667 .59 .759 r
.46534 .84753 m .46839 .84795 L .46727 .84496 L F
.696 .547 .68 r
.46544 .85015 m .46839 .84795 L .46534 .84753 L F
.685 .326 .36 r
.53392 .8187 m .53695 .81957 L .53657 .8205 L F
0 .274 .747 r
.53392 .8187 m .53657 .8205 L .53615 .81994 L F
.369 0 0 r
.39855 .89687 m .39902 .898 L .3972 .89835 L F
.39855 .89687 m .40074 .89672 L .39902 .898 L F
.77 .904 .934 r
.4761 .81348 m .47317 .81383 L .47499 .81258 L F
.759 .893 .938 r
.47849 .81164 m .4761 .81348 L .47499 .81258 L F
.769 .613 .686 r
.46727 .84496 m .47053 .8453 L .4695 .84248 L F
.655 .478 .632 r
.46839 .84795 m .47053 .8453 L .46727 .84496 L F
.46839 .84795 m .4705 .84756 L .47053 .8453 L F
.706 .582 .713 r
.4695 .84248 m .47053 .8453 L .4727 .84291 L F
.665 .441 .57 r
.41389 .87323 m .41653 .87293 L .41625 .87016 L F
.682 .325 .363 r
.41899 .8724 m .41625 .87016 L .41653 .87293 L F
.41899 .8724 m .41927 .87093 L .41625 .87016 L F
.657 .754 .922 r
.52803 .81902 m .52937 .82034 L .53135 .81959 L F
.671 .718 .885 r
.49126 .823 m .49034 .82457 L .4892 .82188 L F
.49126 .823 m .49234 .82438 L .49034 .82457 L F
.875 .767 .739 r
.49234 .82438 m .48925 .82628 L .49034 .82457 L F
.419 .844 .955 r
.40833 .83778 m .40738 .83844 L .40941 .83786 L F
.40833 .83778 m .40594 .83822 L .40738 .83844 L F
.461 0 0 r
.5023 .80944 m .50111 .80931 L .49946 .80867 L F
.566 0 0 r
.5023 .80944 m .50381 .81088 L .50156 .80957 L F
.50156 .80936 m .50156 .80957 L .50111 .80931 L F
0 .259 .69 r
.50111 .80931 m .5013 .80942 L .50169 .80956 L F
.5013 .80942 m .50381 .81088 L .50169 .80956 L F
.879 .924 .85 r
.50381 .81088 m .50156 .81231 L .50169 .80956 L F
.50156 .81231 m .50064 .8129 L .50169 .80956 L F
.328 0 .115 r
.50169 .80956 m .50236 .81114 L .50269 .80992 L F
.50169 .80956 m .50269 .80992 L .50287 .80922 L F
0 0 0 r
.50156 .80998 m .50064 .8129 L .50157 .81018 L F
.618 .762 .948 r
.5012 .81193 m .49911 .81239 L .49827 .81118 L F
.003 0 0 r
.50159 .81204 m .5012 .81193 L .49991 .81191 L F
.50169 .81205 m .5012 .81193 L .50159 .81204 L F
0 0 0 r
.50157 .81018 m .50099 .81187 L .5012 .81193 L F
.50099 .81187 m .50064 .8129 L .5012 .81193 L F
.50169 .80956 m .50156 .80998 L .50157 .81018 L F
.566 0 0 r
.5023 .80944 m .50156 .80957 L .50156 .80936 L F
.5023 .80944 m .50518 .81139 L .50381 .81088 L F
.555 .309 .498 r
.40411 .87782 m .40655 .87562 L .40497 .8764 L F
.647 .407 .542 r
.45708 .87354 m .46004 .87554 L .45711 .8759 L F
.45708 .87354 m .46022 .87323 L .46004 .87554 L F
.341 .802 .937 r
.4431 .83142 m .44167 .8311 L .43956 .83143 L F
.081 .642 .751 r
.44517 .83096 m .44167 .8311 L .4431 .83142 L F
.479 .261 .503 r
.5115 .87384 m .51363 .8712 L .5133 .87328 L F
.508 .269 .487 r
.5133 .87328 m .51363 .8712 L .51542 .871 L F
.744 .573 .663 r
.46737 .84262 m .46727 .84496 L .4695 .84248 L F
.6 .801 .977 r
.44517 .83096 m .44872 .83156 L .44718 .8307 L F
.289 .746 .954 r
.45048 .83115 m .44718 .8307 L .44872 .83156 L F
.883 .891 .832 r
.50846 .82675 m .50965 .82751 L .51158 .82511 L F
.809 .401 .277 r
.50798 .82645 m .50965 .82751 L .508 .82822 L F
.971 .812 .628 r
.508 .82822 m .50965 .82751 L .50846 .82675 L F
.696 .513 .636 r
.46143 .85057 m .46325 .85261 L .46324 .85025 L F
.656 .466 .615 r
.46324 .85025 m .46542 .85239 L .46544 .85015 L F
.46324 .85025 m .46325 .85261 L .46542 .85239 L F
.657 .588 .767 r
.45992 .83481 m .46307 .83718 L .46165 .83449 L F
.691 .68 .834 r
.46165 .83449 m .46307 .83718 L .46533 .83653 L F
0 0 0 r
.48358 .80889 m .48474 .80847 L .48505 .8081 L F
.246 .746 .678 r
.48358 .80889 m .48274 .80918 L .48474 .80847 L F
.764 .321 .2 r
.4951 .87216 m .49279 .87114 L .49214 .87152 L F
.813 .509 .475 r
.49415 .87357 m .4951 .87216 L .49214 .87152 L F
.538 .077 .107 r
.49614 .87339 m .4951 .87216 L .49415 .87357 L F
.49614 .87339 m .49708 .87259 L .4951 .87216 L F
.444 .291 .578 r
.45992 .83481 m .46176 .83205 L .45877 .83196 L F
.45992 .83481 m .46165 .83449 L .46176 .83205 L F
.22 .73 .684 r
.40264 .83899 m .40172 .83929 L .40363 .83875 L F
.40264 .83899 m .40077 .83958 L .40172 .83929 L F
0 .511 .731 r
.51129 .81378 m .5081 .81328 L .50729 .81317 L F
.766 .606 .681 r
.47951 .82209 m .48075 .81943 L .47932 .81872 L F
.47951 .82209 m .48034 .82246 L .48075 .81943 L F
.643 .828 .971 r
.47932 .81872 m .48075 .81943 L .48396 .81882 L F
.463 .215 .452 r
.50919 .87614 m .5115 .87384 L .5108 .8755 L F
.372 .073 .323 r
.5108 .8755 m .5115 .87384 L .5133 .87328 L F
.38 0 0 r
.39872 .83995 m .39391 .84134 L .39697 .84057 L F
.692 .694 .848 r
.46919 .82952 m .47235 .82987 L .47139 .82785 L F
.678 .687 .852 r
.47139 .82785 m .47235 .82987 L .47457 .82949 L F
.945 .844 .712 r
.5081 .82431 m .50798 .82645 L .50846 .82675 L F
.809 .401 .277 r
.50798 .82645 m .508 .82822 L .50846 .82675 L F
.663 .792 .943 r
.51322 .81337 m .5144 .81435 L .51608 .81368 L F
.446 .109 .299 r
.52224 .86739 m .52336 .86556 L .52519 .86513 L F
.307 .782 .924 r
.39015 .825 m .39194 .82473 L .39348 .82498 L F
.104 .659 .756 r
.39194 .82473 m .39535 .82451 L .39348 .82498 L F
.82 .664 .689 r
.4639 .82966 m .46557 .8322 L .46738 .83051 L F
.4639 .82966 m .46433 .83255 L .46557 .8322 L F
.898 .679 .597 r
.46391 .83426 m .46557 .8322 L .46433 .83255 L F
.46391 .83426 m .46531 .83499 L .46557 .8322 L F
.607 .299 .422 r
.45332 .87547 m .45384 .87821 L .45181 .87776 L F
.45332 .87547 m .45507 .8757 L .45384 .87821 L F
.531 .896 .97 r
.5321 .8138 m .53091 .81445 L .52886 .8142 L F
.875 .767 .739 r
.49234 .82438 m .49048 .82675 L .48925 .82628 L F
.756 .572 .648 r
.49234 .82438 m .49231 .82729 L .49048 .82675 L F
.528 .692 .943 r
.49375 .82291 m .49234 .82438 L .49126 .823 L F
.49375 .82291 m .4942 .82404 L .49234 .82438 L F
.344 .236 .585 r
.4936 .82573 m .49234 .82438 L .4942 .82404 L F
.557 .858 .547 r
.49515 .82298 m .49258 .82562 L .49375 .82448 L F
.413 .615 .933 r
.49515 .82298 m .4942 .82404 L .49375 .82291 L F
.557 .858 .547 r
.49484 .82332 m .49375 .82448 L .4942 .82404 L F
.49515 .82298 m .49375 .82448 L .49484 .82332 L F
.344 .236 .585 r
.4936 .82573 m .49231 .82729 L .49232 .82599 L F
.49309 .82518 m .49232 .82599 L .49234 .82438 L F
.4936 .82573 m .49232 .82599 L .49309 .82518 L F
.772 .562 .614 r
.48629 .86781 m .48683 .86574 L .48436 .86529 L F
.251 0 0 r
.38468 .82632 m .38667 .82616 L .38808 .82529 L F
.26 0 0 r
.38667 .82616 m .39015 .825 L .38808 .82529 L F
.752 .475 .512 r
.48312 .8758 m .4812 .87806 L .48135 .87555 L F
.48312 .8758 m .48448 .87827 L .4812 .87806 L F
.82 .664 .689 r
.4639 .82966 m .46738 .83051 L .46663 .82949 L F
.719 .655 .785 r
.46663 .82949 m .46738 .83051 L .46919 .82952 L F
.701 .8 .926 r
.46919 .81545 m .46532 .81543 L .46794 .81461 L F
.63 .863 .986 r
.46995 .81409 m .46919 .81545 L .46794 .81461 L F
.46995 .81409 m .47127 .81472 L .46919 .81545 L F
.507 .25 .459 r
.41492 .89078 m .41533 .88887 L .41699 .89047 L F
.564 .243 .383 r
.41533 .88887 m .41745 .88891 L .41699 .89047 L F
.388 0 .157 r
.49887 .87134 m .49708 .87259 L .49919 .87263 L F
.551 .162 .258 r
.50129 .87271 m .49887 .87134 L .49919 .87263 L F
.50129 .87271 m .50245 .87079 L .49887 .87134 L F
.534 .316 .53 r
.51614 .86538 m .51436 .86337 L .51391 .86528 L F
.51614 .86538 m .51623 .86283 L .51436 .86337 L F
.29 .747 .953 r
.48608 .82157 m .48787 .82145 L .4892 .82188 L F
.48608 .82157 m .48787 .82145 L .4892 .82188 L F
.342 0 0 r
.49004 .82235 m .4892 .82188 L .48787 .82145 L F
.49004 .82235 m .49126 .823 L .4892 .82188 L F
.725 .871 .949 r
.46368 .81635 m .46058 .81664 L .46253 .81558 L F
.688 .863 .965 r
.46532 .81543 m .46368 .81635 L .46253 .81558 L F
.374 .108 .377 r
.50689 .87855 m .50919 .87614 L .50859 .87804 L F
.334 .076 .366 r
.50859 .87804 m .50919 .87614 L .5108 .8755 L F
.561 .246 .392 r
.41085 .89146 m .4121 .89335 L .41009 .89369 L F
.41085 .89146 m .41291 .89114 L .4121 .89335 L F
.654 .474 .627 r
.45817 .85265 m .46108 .85269 L .46143 .85057 L F
.696 .513 .636 r
.46143 .85057 m .46108 .85269 L .46325 .85261 L F
.659 .48 .631 r
.45828 .85501 m .46108 .85269 L .45817 .85265 L F
.714 .674 .81 r
.47382 .85222 m .47692 .85278 L .47573 .84989 L F
.722 .488 .571 r
.47485 .8546 m .47692 .85278 L .47382 .85222 L F
.47485 .8546 m .47666 .85526 L .47692 .85278 L F
.84 .73 .743 r
.47573 .84989 m .47692 .85278 L .47699 .85066 L F
.388 .849 .85 r
.49618 .80562 m .49699 .80504 L .49876 .80424 L F
.49618 .80562 m .49509 .8057 L .49699 .80504 L F
.711 .498 .598 r
.44343 .86064 m .44432 .8625 L .44647 .86046 L F
.732 .529 .618 r
.44432 .8625 m .44649 .86312 L .44647 .86046 L F
.677 .476 .606 r
.44649 .86312 m .44983 .86028 L .44647 .86046 L F
.485 .113 .257 r
.50336 .87276 m .50245 .87079 L .50129 .87271 L F
.50336 .87276 m .50457 .87065 L .50245 .87079 L F
.577 .399 .603 r
.50245 .87079 m .50457 .87065 L .50452 .86816 L F
.573 .89 .619 r
.46342 .82689 m .46073 .82932 L .46076 .82704 L F
.728 .59 .701 r
.46073 .82932 m .46342 .82689 L .46076 .82704 L F
.696 .547 .68 r
.46544 .85015 m .46841 .85011 L .46839 .84795 L F
.666 .523 .68 r
.46839 .84795 m .46841 .85011 L .4705 .84756 L F
.689 .497 .623 r
.45379 .85537 m .45598 .85735 L .45595 .85522 L F
.45379 .85537 m .45375 .85778 L .45598 .85735 L F
.737 .414 .434 r
.50658 .87047 m .50452 .86816 L .50457 .87065 L F
.427 .806 .992 r
.52394 .80892 m .52053 .80861 L .52286 .80802 L F
.193 .606 .946 r
.52286 .80802 m .52474 .80832 L .52394 .80892 L F
0 0 .408 r
.52475 .81009 m .52394 .80892 L .52474 .80832 L F
.778 .685 .76 r
.51029 .81915 m .50698 .81924 L .50837 .81788 L F
.754 .581 .662 r
.51029 .81915 m .50718 .82173 L .50698 .81924 L F
.51029 .81915 m .51175 .8217 L .50718 .82173 L F
.757 .692 .789 r
.51217 .81783 m .51029 .81915 L .50837 .81788 L F
0 .135 .679 r
.51211 .82162 m .51175 .8217 L .51029 .81915 L F
.092 .648 .79 r
.39611 .82452 m .3973 .82445 L .39857 .82453 L F
0 0 0 r
.39574 .82475 m .39862 .82438 L .3973 .82445 L F
.27 .754 .924 r
.3973 .82445 m .39938 .82428 L .4007 .82459 L F
0 0 0 r
.39862 .82438 m .39938 .82428 L .3973 .82445 L F
.092 .648 .79 r
.39535 .82451 m .3973 .82445 L .39611 .82452 L F
.27 .754 .924 r
.3973 .82445 m .4007 .82459 L .39857 .82453 L F
.382 .077 .318 r
.51797 .87012 m .51956 .86815 L .51882 .87177 L F
.39 .143 .414 r
.52155 .86998 m .51956 .86815 L .52017 .86774 L F
.452 .137 .34 r
.51882 .87177 m .51945 .86869 L .52155 .86998 L F
.51945 .86869 m .51956 .86815 L .51986 .86842 L F
.51945 .86869 m .51986 .86842 L .52155 .86998 L F
.222 0 .188 r
.52017 .86774 m .51956 .86815 L .51902 .86883 L F
.52017 .86774 m .51902 .86883 L .51797 .87012 L F
.52017 .86774 m .51908 .86893 L .51841 .86772 L F
.51908 .86893 m .51797 .87012 L .51807 .86959 L F
.51908 .86893 m .51807 .86959 L .51841 .86772 L F
.437 .176 .418 r
.50455 .88078 m .50689 .87855 L .50653 .87999 L F
.393 .136 .401 r
.50653 .87999 m .50689 .87855 L .50859 .87804 L F
.547 .326 .531 r
.52706 .81597 m .52488 .81421 L .52475 .81687 L F
.797 .493 .475 r
.48448 .87827 m .48734 .87869 L .48774 .88065 L F
.877 .818 .787 r
.49047 .86968 m .49443 .8685 L .49282 .86771 L F
.49047 .86968 m .49279 .87114 L .49443 .8685 L F
.757 .692 .789 r
.51217 .81783 m .50837 .81788 L .51081 .81792 L F
.669 .126 0 r
.51155 .81794 m .51217 .81783 L .51081 .81792 L F
.51155 .81794 m .51321 .81892 L .51217 .81783 L F
.308 0 .09 r
.40245 .89591 m .40564 .89372 L .40464 .89524 L F
.426 .02 .165 r
.40564 .89372 m .40648 .89522 L .40464 .89524 L F
.40564 .89372 m .40775 .8935 L .40648 .89522 L F
.615 .384 .543 r
.46022 .87323 m .46228 .87533 L .46004 .87554 L F
.46022 .87323 m .46238 .87315 L .46228 .87533 L F
.657 .621 .802 r
.47558 .834 m .47808 .83291 L .47573 .83326 L F
.894 .943 .835 r
.46882 .85467 m .46957 .8553 L .47163 .85271 L F
.787 .563 .598 r
.46882 .85467 m .4715 .85723 L .46957 .8553 L F
.644 .493 .664 r
.46957 .8553 m .47166 .8554 L .47163 .85271 L F
.627 .351 .48 r
.46957 .8553 m .4715 .85723 L .47166 .8554 L F
.562 .065 .033 r
.52359 .86322 m .52491 .8624 L .52122 .86262 L F
.592 .522 .746 r
.52652 .86248 m .52519 .86513 L .52492 .86245 L F
.52652 .86248 m .52492 .86245 L .52491 .8624 L F
.52652 .86248 m .52702 .8649 L .52519 .86513 L F
.44 .418 .738 r
.52908 .86515 m .52702 .8649 L .52652 .86248 L F
.52908 .86515 m .52705 .86304 L .5286 .86241 L F
.52705 .86304 m .52652 .86248 L .5286 .86241 L F
.689 .756 .903 r
.53173 .86098 m .5307 .86216 L .5286 .86241 L F
.499 .41 .686 r
.53084 .86467 m .5286 .86241 L .5307 .86216 L F
.53084 .86467 m .52908 .86515 L .5286 .86241 L F
.791 .634 .687 r
.52766 .86346 m .53092 .86147 L .5286 .86241 L F
.53092 .86147 m .53173 .86098 L .5286 .86241 L F
.18 0 0 r
.52796 .86251 m .52652 .86248 L .52557 .86288 L F
.5286 .86241 m .52652 .86248 L .52796 .86251 L F
.275 0 0 r
.52652 .86248 m .52491 .8624 L .52359 .86322 L F
.564 .566 .814 r
.36591 .74928 m .36829 .74957 L .36615 .74986 L F
.562 .326 .516 r
.36829 .74957 m .36585 .75066 L .36615 .74986 L F
.57 .344 .534 r
.4352 .88097 m .43497 .88315 L .43327 .88284 L F
.618 .363 .509 r
.4352 .88097 m .43699 .88292 L .43497 .88315 L F
.4352 .88097 m .43726 .88097 L .43699 .88292 L F
.526 .145 .262 r
.48879 .80747 m .48936 .80952 L .49119 .80685 L F
.807 .695 .742 r
.49198 .80642 m .48844 .80703 L .49106 .80644 L F
0 .489 .849 r
.49106 .80644 m .49116 .80649 L .49198 .80642 L F
0 0 0 r
.49119 .80685 m .49198 .80642 L .49259 .80637 L F
.49119 .80685 m .48936 .80952 L .49198 .80642 L F
.48505 .8081 m .48644 .80763 L .48879 .80747 L F
.746 .418 0 r
.48844 .80703 m .48879 .80747 L .48644 .80763 L F
.48844 .80703 m .48936 .80952 L .48879 .80747 L F
.807 .695 .742 r
.49198 .80642 m .48936 .80952 L .48844 .80703 L F
0 .489 .849 r
.49116 .80649 m .49405 .80777 L .49198 .80642 L F
0 0 0 r
.49259 .80637 m .49198 .80642 L .49311 .80619 L F
.677 .476 .606 r
.44649 .86312 m .44982 .86287 L .44983 .86028 L F
.639 .489 .663 r
.44983 .86028 m .45168 .86038 L .45162 .85815 L F
.637 .443 .604 r
.44983 .86028 m .44982 .86287 L .45168 .86038 L F
.671 .461 .591 r
.46542 .85239 m .46841 .85011 L .46544 .85015 L F
0 0 0 r
.42912 .83349 m .43231 .83267 L .4306 .83321 L F
.28 0 0 r
.43467 .83251 m .4306 .83321 L .43231 .83267 L F
.525 .822 .999 r
.46662 .82833 m .46663 .82949 L .46919 .82952 L F
.752 .869 .933 r
.46662 .82833 m .46919 .82952 L .47139 .82785 L F
.161 .689 .866 r
.42764 .81966 m .42694 .81996 L .42562 .81972 L F
.42764 .81966 m .429 .81992 L .42694 .81996 L F
.448 .119 .315 r
.50163 .8835 m .50455 .88078 L .50375 .88319 L F
.384 .079 .32 r
.50375 .88319 m .50455 .88078 L .50653 .87999 L F
.412 .032 .205 r
.48245 .82626 m .48168 .82516 L .48392 .82471 L F
.48245 .82626 m .48081 .82663 L .48168 .82516 L F
.945 .727 .578 r
.49214 .87152 m .49279 .87114 L .49047 .86968 L F
.662 .306 .359 r
.41899 .8724 m .4211 .87271 L .41927 .87093 L F
.704 .601 .739 r
.41927 .87093 m .42235 .87035 L .42128 .86815 L F
.617 .318 .441 r
.41927 .87093 m .4211 .87271 L .42235 .87035 L F
.784 .656 .721 r
.46848 .85241 m .47163 .85271 L .47077 .84989 L F
.894 .943 .835 r
.46882 .85467 m .47163 .85271 L .46848 .85241 L F
.664 .588 .761 r
.47077 .84989 m .47163 .85271 L .47354 .85043 L F
.691 .63 .783 r
.47354 .85043 m .47163 .85271 L .47382 .85222 L F
.654 .501 .664 r
.47163 .85271 m .47485 .8546 L .47382 .85222 L F
.47163 .85271 m .47166 .8554 L .47485 .8546 L F
0 .32 .772 r
.39617 .87762 m .3942 .87843 L .39458 .87826 L F
0 0 0 r
.39397 .87857 m .39458 .87826 L .3942 .87843 L F
.691 .68 .834 r
.46165 .83449 m .46533 .83653 L .46391 .83426 L F
.827 .77 .798 r
.46391 .83426 m .46533 .83653 L .46531 .83499 L F
.493 .26 .489 r
.50914 .82169 m .50718 .82173 L .51175 .8217 L F
.403 .843 .938 r
.51109 .8212 m .51175 .8217 L .51211 .82162 L F
.51109 .8212 m .50914 .82169 L .51175 .8217 L F
.078 .63 .824 r
.38911 .84176 m .38484 .84132 L .38614 .84158 L F
.455 .616 .919 r
.50174 .81344 m .50064 .81516 L .49963 .81433 L F
.695 .552 .688 r
.45598 .85735 m .45828 .85501 L .45595 .85522 L F
.77 .35 .252 r
.48774 .88065 m .49066 .8814 L .4913 .88264 L F
.678 .687 .852 r
.47139 .82785 m .47457 .82949 L .47306 .82724 L F
.639 .671 .864 r
.47306 .82724 m .47457 .82949 L .47675 .82905 L F
.65 .544 .721 r
.47573 .83326 m .47675 .82905 L .47457 .82949 L F
.539 .251 .425 r
.43603 .86523 m .43811 .86495 L .43913 .86236 L F
.677 .46 .584 r
.43811 .86495 m .44116 .86244 L .43913 .86236 L F
.107 0 0 r
.47743 .82311 m .48034 .82246 L .47951 .82209 L F
.47743 .82311 m .48063 .82293 L .48034 .82246 L F
.733 .506 .584 r
.44116 .86244 m .44432 .8625 L .44343 .86064 L F
.446 .489 .81 r
.5381 .81887 m .53695 .81957 L .53566 .81628 L F
.004 0 .055 r
.53657 .8205 m .53695 .81957 L .5381 .81887 L F
.624 .926 .972 r
.49517 .80818 m .49441 .80938 L .49618 .80849 L F
.49517 .80818 m .49324 .80906 L .49441 .80938 L F
.722 .435 .492 r
.47279 .87319 m .47618 .87321 L .47656 .87521 L F
.712 .429 .494 r
.47618 .87321 m .47807 .87548 L .47656 .87521 L F
.63 .482 .663 r
.45162 .85815 m .45168 .86038 L .45375 .85778 L F
.671 .461 .591 r
.46542 .85239 m .46848 .85241 L .46841 .85011 L F
.655 .507 .671 r
.4705 .84756 m .46841 .85011 L .47077 .84989 L F
.784 .656 .721 r
.46848 .85241 m .47077 .84989 L .46841 .85011 L F
.405 0 .126 r
.48479 .81647 m .48152 .81835 L .48396 .81882 L F
.48479 .81647 m .48371 .8181 L .48152 .81835 L F
.431 .802 .994 r
.48152 .81835 m .48371 .8181 L .48265 .81752 L F
0 0 0 r
.48265 .81752 m .48256 .81762 L .48152 .81835 L F
.643 .828 .971 r
.48096 .81875 m .48396 .81882 L .48152 .81835 L F
0 0 0 r
.48256 .81762 m .48005 .82038 L .48152 .81835 L F
.643 .828 .971 r
.47932 .81872 m .48096 .81875 L .48152 .81835 L F
.612 .325 .458 r
.44196 .87848 m .44273 .87807 L .44142 .88084 L F
.643 .296 .368 r
.44273 .87807 m .44465 .87991 L .44142 .88084 L F
.44273 .87807 m .44454 .87856 L .44465 .87991 L F
.107 .659 .702 r
.44672 .81839 m .4501 .81789 L .44792 .81828 L F
.692 .48 .596 r
.42439 .87301 m .42235 .87035 L .4211 .87271 L F
.42439 .87301 m .42447 .87063 L .42235 .87035 L F
.811 .652 .685 r
.47821 .85999 m .48116 .8601 L .48004 .85763 L F
.803 .72 .773 r
.47903 .86302 m .48116 .8601 L .47821 .85999 L F
.699 .605 .748 r
.48004 .85763 m .48116 .8601 L .48344 .85791 L F
.58 .823 .991 r
.49532 .8164 m .49853 .81667 L .49731 .81624 L F
.554 .306 .494 r
.49744 .81428 m .49731 .81624 L .49963 .81433 L F
.456 0 .046 r
.50012 .81557 m .49731 .81624 L .49853 .81667 L F
.50004 .81552 m .49731 .81624 L .50012 .81557 L F
.50028 .81546 m .50004 .81552 L .50012 .81557 L F
.50022 .81547 m .49942 .81633 L .49731 .81624 L F
.50028 .81546 m .49942 .81633 L .50022 .81547 L F
.99 .777 .522 r
.49942 .81633 m .49831 .81771 L .49829 .81752 L F
.577 .34 .52 r
.49731 .81624 m .49812 .81627 L .49803 .81565 L F
.49875 .81505 m .49942 .81633 L .49963 .81433 L F
.99 .777 .522 r
.49942 .81633 m .49829 .81752 L .49767 .813 L F
.993 .756 .46 r
.49963 .81433 m .49954 .81517 L .49767 .813 L F
.49954 .81517 m .49942 .81633 L .49839 .81438 L F
.49954 .81517 m .49839 .81438 L .49767 .813 L F
.611 .842 .987 r
.50616 .86703 m .50977 .86811 L .51126 .8673 L F
.192 0 .22 r
.51126 .8673 m .50977 .86811 L .50888 .87096 L F
.011 .583 .759 r
.51546 .80828 m .51732 .80836 L .51861 .80848 L F
0 .562 .741 r
.51732 .80836 m .52053 .80861 L .51861 .80848 L F
.803 .72 .773 r
.47903 .86302 m .47821 .85999 L .47953 .86255 L F
.716 .196 0 r
.48242 .86508 m .47903 .86302 L .48092 .86517 L F
0 .164 .704 r
.47953 .86255 m .48092 .86517 L .47903 .86302 L F
.288 .687 .973 r
.36649 .74864 m .36591 .74928 L .36506 .74931 L F
.36649 .74864 m .36829 .74957 L .36591 .74928 L F
.786 .5 .503 r
.47354 .85043 m .4705 .84756 L .47077 .84989 L F
.52 .196 .358 r
.4226 .88626 m .42426 .88793 L .42162 .88859 L F
.4226 .88626 m .42465 .88621 L .42426 .88793 L F
.517 .143 .27 r
.42984 .88483 m .42998 .88404 L .4319 .88495 L F
.509 .164 .318 r
.4319 .88495 m .42998 .88404 L .43327 .88284 L F
.736 .595 .699 r
.46342 .82689 m .4639 .82966 L .46663 .82949 L F
.46342 .82689 m .46663 .82949 L .46473 .82838 L F
.57 .174 .252 r
.46662 .82833 m .46473 .82838 L .46663 .82949 L F
.355 .035 .278 r
.41177 .87304 m .40913 .8759 L .41059 .87511 L F
.566 .149 .21 r
.41256 .8748 m .41177 .87304 L .41059 .87511 L F
.41256 .8748 m .41389 .87323 L .41177 .87304 L F
.956 .691 .494 r
.47775 .85731 m .47666 .85526 L .47703 .85812 L F
.789 .924 .549 r
.47624 .85899 m .47703 .85812 L .4777 .85644 L F
.741 .681 .793 r
.47479 .85981 m .47821 .85999 L .47703 .85812 L F
0 0 0 r
.47479 .85981 m .47703 .85812 L .47611 .85923 L F
.789 .924 .549 r
.47611 .85923 m .47703 .85812 L .47624 .85899 L F
.956 .691 .494 r
.47801 .85781 m .47775 .85731 L .47703 .85812 L F
.961 .658 .411 r
.47703 .85812 m .47821 .85999 L .47801 .85781 L F
.666 .547 .71 r
.47801 .85781 m .48004 .85763 L .48024 .85533 L F
.811 .652 .685 r
.47821 .85999 m .48004 .85763 L .47801 .85781 L F
.509 .848 .996 r
.45862 .81738 m .45528 .81734 L .45734 .81693 L F
.558 .876 .993 r
.45862 .81738 m .45944 .81633 L .46058 .81664 L F
.45862 .81738 m .45734 .81693 L .45944 .81633 L F
.392 .83 .95 r
.43421 .81953 m .43223 .81992 L .4311 .81965 L F
0 0 0 r
.40597 .82264 m .40644 .82298 L .40806 .82237 L F
.40597 .82264 m .40456 .82361 L .40644 .82298 L F
.605 .288 .406 r
.43497 .88315 m .4319 .88495 L .43327 .88284 L F
.94 .59 .327 r
.47991 .84452 m .48028 .84652 L .47867 .84406 L F
.711 .54 .655 r
.48028 .84652 m .48053 .84619 L .47867 .84406 L F
.633 .076 0 r
.48081 .84656 m .48154 .84654 L .47991 .84452 L F
.456 .835 .988 r
.47991 .84452 m .47867 .84406 L .48211 .84412 L F
.633 .076 0 r
.48095 .84689 m .48102 .84685 L .48081 .84656 L F
.48095 .84689 m .47991 .84452 L .48211 .84412 L F
.711 .54 .655 r
.48053 .84619 m .48211 .84412 L .47898 .84407 L F
.48053 .84619 m .47898 .84407 L .47867 .84406 L F
.633 .076 0 r
.48102 .84685 m .48154 .84654 L .48081 .84656 L F
.085 0 0 r
.50076 .82924 m .50397 .82951 L .50273 .82942 L F
.50076 .82924 m .50397 .82951 L .50273 .82942 L F
.401 .811 .608 r
.50488 .82889 m .50397 .82951 L .50273 .82942 L F
.50488 .82889 m .50673 .82771 L .50397 .82951 L F
.306 .718 .976 r
.50397 .82951 m .50488 .82889 L .50273 .82942 L F
.582 .41 .614 r
.50673 .82771 m .50626 .82962 L .50397 .82951 L F
.306 .718 .976 r
.50397 .82951 m .50626 .82962 L .50488 .82889 L F
.179 .706 .858 r
.43421 .81953 m .43611 .81942 L .43747 .81959 L F
.316 0 0 r
.43611 .81942 m .43948 .81948 L .43747 .81959 L F
.078 .63 .824 r
.38911 .84176 m .38684 .84139 L .38484 .84132 L F
.3 .776 .927 r
.39096 .84145 m .38684 .84139 L .38911 .84176 L F
.766 .606 .681 r
.47951 .82209 m .47932 .81872 L .47746 .82219 L F
.74 .79 .893 r
.47951 .82209 m .47746 .82219 L .47753 .82205 L F
.735 .388 .392 r
.47753 .82205 m .47743 .82311 L .47951 .82209 L F
.557 .917 .736 r
.47753 .82205 m .47746 .82219 L .47756 .82199 L F
.728 .236 .071 r
.47746 .82219 m .47421 .82116 L .47609 .82202 L F
.74 .79 .893 r
.4769 .82204 m .47746 .82219 L .47609 .82202 L F
.47753 .82205 m .47746 .82219 L .4769 .82204 L F
.728 .236 .071 r
.47746 .82219 m .47726 .82227 L .4769 .82204 L F
.557 .917 .736 r
.47749 .82214 m .47726 .82227 L .47746 .82219 L F
.735 .388 .392 r
.4769 .82204 m .47738 .82235 L .47753 .82205 L F
.47609 .82202 m .47675 .82257 L .4772 .82231 L F
.728 .236 .071 r
.47726 .82227 m .4761 .82278 L .4769 .82204 L F
.47746 .82219 m .4745 .82141 L .47421 .82116 L F
.576 .454 .676 r
.47675 .82257 m .47543 .82394 L .47743 .82311 L F
.47609 .82202 m .47562 .82339 L .47675 .82257 L F
.47562 .82339 m .47543 .82394 L .47675 .82257 L F
.735 .388 .392 r
.47609 .82202 m .47738 .82235 L .4769 .82204 L F
.557 .917 .736 r
.47804 .82135 m .47612 .82278 L .47699 .82239 L F
.47743 .82207 m .47699 .82239 L .47726 .82227 L F
.47804 .82135 m .47699 .82239 L .47743 .82207 L F
.47804 .82135 m .47726 .82227 L .47749 .82214 L F
.666 .658 .833 r
.47641 .82256 m .47804 .82135 L .47812 .82203 L F
.47592 .82271 m .47804 .82135 L .47641 .82256 L F
.557 .917 .736 r
.47804 .82135 m .4761 .82278 L .47612 .82278 L F
.735 .388 .392 r
.4772 .82231 m .47713 .82287 L .47738 .82235 L F
.47675 .82257 m .47713 .82287 L .4772 .82231 L F
.787 .684 .751 r
.47421 .82116 m .47543 .82394 L .47609 .82202 L F
.728 .236 .071 r
.4769 .82204 m .4761 .82278 L .4745 .82141 L F
.735 .388 .392 r
.47713 .82287 m .47743 .82311 L .47753 .82205 L F
.557 .917 .736 r
.47881 .81978 m .47753 .82205 L .47932 .81872 L F
.47753 .82205 m .47756 .82199 L .47932 .81872 L F
.47804 .82135 m .47746 .82219 L .47881 .81978 L F
.485 .873 .97 r
.45528 .81734 m .45318 .81791 L .4519 .81766 L F
.256 0 0 r
.38257 .82682 m .38468 .82632 L .38275 .82666 L F
.696 .85 .956 r
.41123 .83709 m .41425 .83698 L .41324 .83663 L F
.47 0 .029 r
.41665 .83589 m .41324 .83663 L .41425 .83698 L F
.17 .707 .753 r
.43841 .83127 m .43787 .83144 L .43956 .83143 L F
.43841 .83127 m .43642 .83162 L .43787 .83144 L F
.656 .66 .842 r
.45334 .83162 m .45661 .83242 L .45573 .83056 L F
.71 .686 .825 r
.45573 .83056 m .45661 .83242 L .45877 .83196 L F
.439 .072 .243 r
.41291 .89114 m .4138 .89284 L .4121 .89335 L F
.41291 .89114 m .41492 .89078 L .4138 .89284 L F
.65 .544 .721 r
.47573 .83326 m .47808 .83291 L .47675 .82905 L F
.714 .674 .81 r
.47382 .85222 m .47573 .84989 L .47354 .85043 L F
.612 .325 .458 r
.44196 .87848 m .44142 .88084 L .43942 .88095 L F
0 .466 .829 r
.49946 .80867 m .50004 .80858 L .49808 .80798 L F
0 .449 .827 r
.49946 .80867 m .50111 .80931 L .50004 .80858 L F
.599 .775 .965 r
.45048 .83115 m .45334 .83162 L .45217 .83086 L F
.674 .854 .968 r
.45217 .83086 m .45334 .83162 L .45573 .83056 L F
.542 .356 .578 r
.42646 .87034 m .42447 .87063 L .42439 .87301 L F
.875 .607 .53 r
.51202 .86536 m .50981 .86275 L .5103 .86475 L F
.625 .407 .566 r
.5103 .86475 m .50981 .86275 L .50872 .86254 L F
0 0 0 r
.50872 .86254 m .50768 .86307 L .50764 .86291 L F
.50768 .86307 m .50508 .8644 L .50764 .86291 L F
.239 .74 .9 r
.50758 .86267 m .50764 .86291 L .50658 .86265 L F
.625 .407 .566 r
.5103 .86475 m .50872 .86254 L .50764 .86291 L F
.239 .74 .9 r
.50971 .86272 m .50764 .86291 L .50758 .86267 L F
.625 .407 .566 r
.5103 .86475 m .50764 .86291 L .50971 .86272 L F
.944 .689 .224 r
.50978 .8633 m .5103 .86475 L .50971 .86272 L F
.611 .842 .987 r
.50616 .86703 m .51066 .86575 L .5103 .86475 L F
0 0 0 r
.50616 .86703 m .5103 .86475 L .50999 .8651 L F
.5099 .86515 m .50999 .8651 L .50998 .86511 L F
.50616 .86703 m .50999 .8651 L .5099 .86515 L F
.611 .842 .987 r
.50616 .86703 m .51126 .8673 L .51202 .86536 L F
0 0 0 r
.50616 .86703 m .50998 .86511 L .50748 .86707 L F
.82 .932 .905 r
.50685 .86684 m .50856 .86466 L .50635 .86666 L F
.50748 .86707 m .50782 .8663 L .50685 .86684 L F
.50782 .8663 m .50856 .86466 L .50685 .86684 L F
.944 .689 .224 r
.50998 .86511 m .5103 .86475 L .50978 .8633 L F
.611 .842 .987 r
.51066 .86575 m .51202 .86536 L .5103 .86475 L F
.51 .156 .303 r
.51328 .86729 m .51202 .86536 L .51126 .8673 L F
.51328 .86729 m .51391 .86528 L .51202 .86536 L F
.097 .65 .805 r
.40993 .82188 m .41319 .82197 L .41118 .82221 L F
.795 .562 .584 r
.48283 .86755 m .48436 .86529 L .48242 .86508 L F
.48283 .86755 m .48629 .86781 L .48436 .86529 L F
0 0 0 r
.43948 .81948 m .44155 .81936 L .44271 .81928 L F
.116 .665 .709 r
.44155 .81936 m .44472 .81888 L .44271 .81928 L F
.664 .449 .583 r
.43359 .8675 m .43603 .86523 L .43426 .86585 L F
0 .459 .824 r
.51088 .80793 m .51026 .80802 L .50884 .80706 L F
.51088 .80793 m .51204 .80863 L .51026 .80802 L F
.668 .298 .335 r
.48392 .82471 m .48594 .82651 L .48245 .82626 L F
.705 .606 .743 r
.45877 .83196 m .46176 .83205 L .46073 .82932 L F
.724 .615 .736 r
.46073 .82932 m .46176 .83205 L .4639 .82966 L F
.6 .42 .609 r
.46165 .83449 m .46391 .83426 L .46176 .83205 L F
.705 .585 .719 r
.46176 .83205 m .46433 .83255 L .4639 .82966 L F
.715 .41 .46 r
.46176 .83205 m .46391 .83426 L .46433 .83255 L F
.71 .686 .825 r
.45573 .83056 m .45877 .83196 L .45809 .83036 L F
.823 .789 .821 r
.45809 .83036 m .45877 .83196 L .46073 .82932 L F
.348 .819 .9 r
.40995 .83743 m .40941 .83786 L .41123 .83709 L F
.40995 .83743 m .40833 .83778 L .40941 .83786 L F
.653 .503 .666 r
.47354 .85043 m .47573 .84989 L .47231 .8489 L F
.47231 .8489 m .47573 .84989 L .47354 .85043 L F
.623 .316 .43 r
.45384 .87821 m .45507 .8757 L .45702 .87755 L F
.628 .315 .421 r
.45507 .8757 m .45711 .8759 L .45702 .87755 L F
.753 .636 .731 r
.52803 .81902 m .53135 .81959 L .53193 .81444 L F
.289 .654 .97 r
.53192 .81715 m .53377 .81651 L .53253 .81598 L F
.729 .76 .877 r
.53154 .81788 m .53192 .81715 L .53193 .81444 L F
.99 .735 .372 r
.53114 .81539 m .53193 .81444 L .53192 .81715 L F
.289 .654 .97 r
.53192 .81715 m .53253 .81598 L .53114 .81539 L F
.729 .76 .877 r
.53135 .81959 m .53192 .81715 L .53154 .81788 L F
.53135 .81959 m .53304 .81854 L .53192 .81715 L F
.659 .48 .631 r
.45828 .85501 m .46101 .8552 L .46108 .85269 L F
.658 .48 .631 r
.46108 .85269 m .46312 .85474 L .46325 .85261 L F
.46108 .85269 m .46101 .8552 L .46312 .85474 L F
0 0 0 r
.49094 .86816 m .48748 .8698 L .48937 .8693 L F
.877 .818 .787 r
.49047 .86968 m .49282 .86771 L .49094 .86816 L F
.712 .255 .165 r
.49231 .82729 m .49166 .82792 L .49048 .82675 L F
.618 .883 .554 r
.4936 .82573 m .49166 .82792 L .49231 .82729 L F
.194 0 0 r
.42039 .82129 m .42342 .8204 L .42152 .82075 L F
.17 0 .229 r
.50675 .81487 m .50561 .8138 L .5081 .81328 L F
.50675 .81487 m .50454 .81624 L .50561 .8138 L F
.663 .792 .943 r
.51322 .81337 m .51608 .81368 L .51495 .81289 L F
.776 .619 .685 r
.51654 .81261 m .51898 .81288 L .51844 .8136 L F
.206 .557 .934 r
.51608 .81368 m .51799 .81344 L .51495 .81289 L F
.51799 .81344 m .51775 .81336 L .51495 .81289 L F
.51608 .81368 m .52044 .8151 L .51909 .81412 L F
.776 .619 .685 r
.51799 .81344 m .51844 .8136 L .51838 .81368 L F
.762 .631 .716 r
.51936 .8142 m .51838 .81368 L .51898 .81288 L F
.746 .708 .816 r
.51813 .81342 m .51878 .81389 L .52052 .81366 L F
.51878 .81389 m .52044 .8151 L .52052 .81366 L F
.762 .631 .716 r
.52052 .81366 m .51936 .8142 L .51925 .81383 L F
.52052 .81366 m .51925 .81383 L .51898 .81288 L F
.206 .557 .934 r
.51838 .81368 m .51909 .81412 L .51878 .81389 L F
.51608 .81368 m .51909 .81412 L .51799 .81344 L F
.762 .631 .716 r
.51936 .8142 m .51725 .8152 L .51838 .81368 L F
.206 .557 .934 r
.51799 .81344 m .51838 .81368 L .51813 .81342 L F
.51838 .81368 m .51878 .81389 L .51813 .81342 L F
.416 .631 .943 r
.51495 .81289 m .51775 .81336 L .51654 .81261 L F
.776 .619 .685 r
.51654 .81261 m .51844 .8136 L .51664 .81299 L F
.416 .631 .943 r
.51775 .81336 m .51813 .81342 L .51654 .81261 L F
.776 .619 .685 r
.51664 .81299 m .51775 .81336 L .51725 .8152 L F
.51775 .81336 m .51799 .81344 L .51796 .8135 L F
.51775 .81336 m .51796 .8135 L .51725 .8152 L F
.51799 .81344 m .51838 .81368 L .51725 .8152 L F
.206 .557 .934 r
.51799 .81344 m .51813 .81342 L .51775 .81336 L F
.4 .206 .499 r
.39278 .8802 m .39458 .87826 L .39397 .87857 L F
.683 .492 .621 r
.46312 .85474 m .46542 .85239 L .46325 .85261 L F
.521 .522 .797 r
.48686 .81852 m .48608 .82157 L .48477 .81878 L F
.48686 .81852 m .48787 .82145 L .48608 .82157 L F
.768 .626 .703 r
.44982 .86287 m .45156 .86293 L .45168 .86038 L F
.675 .546 .699 r
.45168 .86038 m .45378 .8598 L .45375 .85778 L F
.705 .572 .702 r
.45168 .86038 m .45487 .86285 L .45378 .8598 L F
.45168 .86038 m .45156 .86293 L .45487 .86285 L F
.689 .439 .539 r
.46238 .87315 m .46635 .87299 L .46426 .8755 L F
.67 .436 .557 r
.46635 .87299 m .46764 .87524 L .46426 .8755 L F
.46635 .87299 m .46763 .87312 L .46764 .87524 L F
.417 .175 .438 r
.47166 .8554 m .47311 .85662 L .47485 .8546 L F
.47166 .8554 m .4715 .85723 L .47311 .85662 L F
.573 .89 .619 r
.46342 .82689 m .46152 .82839 L .46073 .82932 L F
.728 .59 .701 r
.46073 .82932 m .4639 .82966 L .46342 .82689 L F
.641 .202 .191 r
.46473 .82838 m .46342 .82689 L .46481 .82641 L F
.46473 .82838 m .46152 .82839 L .46342 .82689 L F
.736 .595 .699 r
.46342 .82689 m .46473 .82838 L .46481 .82641 L F
0 0 0 r
.39902 .898 m .40074 .89672 L .40245 .89591 L F
.319 0 0 r
.51204 .80863 m .5142 .80874 L .51546 .80828 L F
.333 0 0 r
.5142 .80874 m .51732 .80836 L .51546 .80828 L F
.569 .747 .961 r
.39096 .84145 m .3914 .84239 L .39337 .842 L F
.446 .109 .299 r
.52224 .86739 m .52519 .86513 L .52435 .86687 L F
.472 .116 .281 r
.52519 .86513 m .52643 .86662 L .52435 .86687 L F
.52519 .86513 m .52702 .8649 L .52643 .86662 L F
.35 0 0 r
.40594 .83822 m .40264 .83899 L .40363 .83875 L F
.45 .835 .986 r
.41319 .82197 m .41513 .82157 L .4164 .822 L F
.451 .824 .992 r
.41513 .82157 m .41843 .82173 L .4164 .822 L F
.722 .48 .559 r
.44942 .8648 m .45156 .86293 L .44982 .86287 L F
.44942 .8648 m .45169 .86514 L .45156 .86293 L F
.707 .468 .561 r
.45156 .86293 m .4548 .86506 L .45487 .86285 L F
.45156 .86293 m .45169 .86514 L .4548 .86506 L F
.532 .287 .49 r
.43699 .88292 m .43726 .88097 L .43895 .88268 L F
.576 .285 .437 r
.43726 .88097 m .43942 .88095 L .43895 .88268 L F
.789 .546 .569 r
.48344 .85791 m .48024 .85533 L .48004 .85763 L F
.39 .143 .414 r
.52155 .86998 m .52017 .86774 L .52224 .86739 L F
.684 .577 .729 r
.45378 .8598 m .45487 .86285 L .45702 .86051 L F
.677 .565 .722 r
.45487 .86285 m .45701 .86269 L .45702 .86051 L F
.658 .448 .587 r
.4548 .86506 m .45701 .86269 L .45487 .86285 L F
.485 .052 .14 r
.42183 .83438 m .42035 .83602 L .41852 .83525 L F
.285 0 .003 r
.42215 .83567 m .42183 .83438 L .42382 .83424 L F
.42215 .83567 m .42035 .83602 L .42183 .83438 L F
.772 .374 .299 r
.62311 .74979 m .62202 .75122 L .62008 .74911 L F
.665 .151 .006 r
.62008 .74911 m .62283 .75035 L .62311 .74979 L F
0 0 0 r
.62311 .74979 m .62505 .74902 L .62439 .74868 L F
.538 .241 .411 r
.62249 .75071 m .62436 .75107 L .62202 .75122 L F
0 0 0 r
.62311 .74979 m .62283 .75035 L .62389 .74971 L F
.62311 .74979 m .62389 .74971 L .62461 .7492 L F
.538 .241 .411 r
.62439 .74868 m .62439 .74936 L .62389 .74971 L F
.62439 .74868 m .62389 .74971 L .62323 .74993 L F
0 0 0 r
.62461 .7492 m .62439 .74936 L .62505 .74902 L F
.538 .241 .411 r
.62439 .74936 m .62436 .75107 L .62249 .75071 L F
0 0 0 r
.62439 .74936 m .62389 .74971 L .62474 .74921 L F
.62439 .74936 m .62474 .74921 L .62505 .74902 L F
.271 .108 .468 r
.62439 .74868 m .62505 .74902 L .62622 .74826 L F
.584 .735 .947 r
.62622 .74826 m .62505 .74902 L .62497 .74899 L F
.24 .018 .362 r
.62622 .74826 m .62547 .7487 L .62439 .74868 L F
.62593 .7487 m .62439 .74936 L .62439 .74868 L F
.584 .735 .947 r
.62622 .74826 m .62497 .74899 L .62307 .74818 L F
.24 .018 .362 r
.62622 .74826 m .62593 .7487 L .62547 .7487 L F
.62593 .7487 m .62436 .75107 L .62439 .74936 L F
.538 .241 .411 r
.62439 .74868 m .62323 .74993 L .62311 .74979 L F
.62323 .74993 m .62202 .75122 L .62248 .75062 L F
.62323 .74993 m .62248 .75062 L .62311 .74979 L F
.701 .715 .859 r
.62505 .74902 m .62389 .74971 L .6236 .74958 L F
.62431 .74893 m .6236 .74958 L .62123 .74854 L F
.62505 .74902 m .6236 .74958 L .62431 .74893 L F
.62389 .74971 m .62283 .75035 L .62263 .75012 L F
.62389 .74971 m .62263 .75012 L .62123 .74854 L F
.538 .241 .411 r
.62323 .74993 m .62389 .74971 L .62249 .75071 L F
.689 .439 .539 r
.46238 .87315 m .46426 .8755 L .46228 .87533 L F
.589 .514 .738 r
.51486 .82232 m .51556 .82441 L .51337 .82426 L F
0 0 .162 r
.51486 .82232 m .51337 .82426 L .51453 .8243 L F
0 .554 .728 r
.51337 .82426 m .51556 .82441 L .51453 .8243 L F
0 .511 .731 r
.51129 .81378 m .50991 .81354 L .5081 .81328 L F
.459 .858 .97 r
.51322 .81337 m .50991 .81354 L .51129 .81378 L F
.695 .552 .688 r
.45598 .85735 m .45897 .85771 L .45828 .85501 L F
.658 .53 .696 r
.45828 .85501 m .45897 .85771 L .46101 .8552 L F
.603 .32 .46 r
.51826 .86517 m .51623 .86283 L .51614 .86538 L F
.51826 .86517 m .51937 .86244 L .51623 .86283 L F
.221 0 0 r
.38141 .82734 m .38468 .82632 L .38257 .82682 L F
.682 .874 .971 r
.47317 .81383 m .47127 .81472 L .46995 .81409 L F
.789 .52 .531 r
.48111 .86733 m .48242 .86508 L .48092 .86517 L F
.48111 .86733 m .48283 .86755 L .48242 .86508 L F
.388 0 .05 r
.49699 .80504 m .50042 .80338 L .49876 .80424 L F
.531 .187 .329 r
.41745 .88891 m .41911 .89026 L .41699 .89047 L F
.41745 .88891 m .4196 .88886 L .41911 .89026 L F
.784 .498 .503 r
.48434 .87006 m .48629 .86781 L .48283 .86755 L F
.72 .408 .449 r
.48748 .8698 m .48629 .86781 L .48434 .87006 L F
.508 .269 .487 r
.5133 .87328 m .51542 .871 L .515 .87268 L F
.49 .181 .369 r
.51542 .871 m .51699 .87233 L .515 .87268 L F
.51542 .871 m .51797 .87012 L .51699 .87233 L F
.694 .55 .687 r
.45378 .8598 m .45598 .85735 L .45375 .85778 L F
.45378 .8598 m .45702 .86051 L .45598 .85735 L F
.698 .556 .689 r
.45702 .86051 m .45897 .85771 L .45598 .85735 L F
.589 .928 .957 r
.39617 .87762 m .39458 .87826 L .39468 .87754 L F
.4 .206 .499 r
.39278 .8802 m .39468 .87754 L .39458 .87826 L F
.748 .478 .524 r
.47247 .87337 m .47279 .87319 L .47293 .87528 L F
.722 .435 .492 r
.47279 .87319 m .47656 .87521 L .47293 .87528 L F
.692 .457 .563 r
.46763 .87312 m .46957 .87568 L .46764 .87524 L F
.46763 .87312 m .47247 .87337 L .46957 .87568 L F
.759 .893 .938 r
.47849 .81164 m .47499 .81258 L .47751 .81154 L F
.308 .799 .782 r
.47973 .81078 m .47944 .81096 L .47751 .81137 L F
.037 0 0 r
.48037 .81019 m .47944 .81096 L .48136 .81034 L F
.308 .799 .782 r
.48136 .81034 m .47944 .81096 L .47973 .81078 L F
0 0 0 r
.47901 .81124 m .47944 .81096 L .48037 .81019 L F
.47849 .81164 m .47944 .81096 L .47901 .81124 L F
.44 .871 .919 r
.47751 .81154 m .47944 .81096 L .47849 .81164 L F
.788 .355 .221 r
.49166 .82792 m .48925 .82628 L .49048 .82675 L F
.688 .863 .965 r
.46532 .81543 m .46253 .81558 L .46439 .81503 L F
.569 .9 .982 r
.46794 .81461 m .46532 .81543 L .46439 .81503 L F
.104 .659 .756 r
.39194 .82473 m .394 .82456 L .39535 .82451 L F
.21 0 0 r
.394 .82456 m .3973 .82445 L .39535 .82451 L F
.107 0 0 r
.47743 .82311 m .47942 .82313 L .48063 .82293 L F
.576 .143 .183 r
.47942 .82313 m .48336 .82223 L .48063 .82293 L F
.363 .436 .802 r
.36585 .75066 m .36649 .74864 L .36506 .74931 L F
.562 .326 .516 r
.36829 .74957 m .36776 .75161 L .36585 .75066 L F
.363 .436 .802 r
.36585 .75066 m .36776 .75161 L .36649 .74864 L F
.735 .403 .418 r
.44627 .86467 m .44649 .86312 L .44432 .8625 L F
.752 .537 .604 r
.44627 .86467 m .44982 .86287 L .44649 .86312 L F
.26 0 0 r
.38667 .82616 m .38868 .82595 L .39015 .825 L F
.155 0 0 r
.39015 .825 m .39065 .82557 L .39194 .82473 L F
.39015 .825 m .38868 .82595 L .39065 .82557 L F
.683 .492 .621 r
.46312 .85474 m .46673 .85474 L .46542 .85239 L F
.66 .469 .615 r
.46673 .85474 m .46848 .85241 L .46542 .85239 L F
.641 .231 .251 r
.49617 .8834 m .4994 .88329 L .49818 .88485 L F
.538 .09 .134 r
.4994 .88329 m .50026 .88498 L .49818 .88485 L F
.4994 .88329 m .50163 .8835 L .50026 .88498 L F
.823 .789 .821 r
.45809 .83036 m .46073 .82932 L .45992 .82938 L F
.574 .941 .87 r
.46152 .82839 m .45992 .82938 L .46073 .82932 L F
.59 .256 .372 r
.44465 .87991 m .44454 .87856 L .4464 .88002 L F
.588 .257 .375 r
.44454 .87856 m .44677 .87859 L .4464 .88002 L F
.631 .19 .183 r
.49404 .8828 m .49617 .8834 L .49287 .88341 L F
.081 .642 .751 r
.44517 .83096 m .44366 .83098 L .44167 .8311 L F
.024 0 0 r
.44718 .8307 m .44366 .83098 L .44517 .83096 L F
.555 .309 .498 r
.40411 .87782 m .40627 .87783 L .40655 .87562 L F
.595 .344 .507 r
.40627 .87783 m .40838 .87767 L .40655 .87562 L F
.63 .345 .467 r
.40655 .87562 m .40838 .87767 L .40913 .8759 L F
.982 .745 .503 r
.48479 .81647 m .48477 .81878 L .48371 .8181 L F
.658 .547 .717 r
.48628 .81438 m .48726 .81652 L .48479 .81647 L F
.558 .318 .507 r
.48726 .81652 m .48477 .81878 L .48479 .81647 L F
.362 0 0 r
.49814 .87322 m .49708 .87259 L .49614 .87339 L F
.49814 .87322 m .49919 .87263 L .49708 .87259 L F
.639 .671 .864 r
.47306 .82724 m .47675 .82905 L .47577 .82769 L F
.805 .839 .876 r
.47577 .82769 m .47675 .82905 L .47856 .82732 L F
.633 .535 .725 r
.47675 .82905 m .47969 .83173 L .47912 .83078 L F
.47675 .82905 m .47808 .83291 L .47969 .83173 L F
.658 .448 .587 r
.4548 .86506 m .457 .86535 L .45701 .86269 L F
.667 .534 .693 r
.45701 .86269 m .45904 .85982 L .45702 .86051 L F
.45701 .86269 m .46019 .86246 L .45904 .85982 L F
.654 .444 .587 r
.45701 .86269 m .46001 .86392 L .46019 .86246 L F
.45701 .86269 m .457 .86535 L .46001 .86392 L F
.726 .467 .535 r
.44116 .86244 m .44319 .86429 L .44432 .8625 L F
.681 .411 .507 r
.44319 .86429 m .44627 .86467 L .44432 .8625 L F
.188 .705 .885 r
.50789 .80674 m .5067 .80709 L .50549 .80599 L F
.50789 .80674 m .50884 .80706 L .5067 .80709 L F
.698 .556 .689 r
.45702 .86051 m .45904 .85982 L .45897 .85771 L F
.66 .532 .698 r
.46101 .8552 m .45897 .85771 L .46114 .8574 L F
.658 .523 .688 r
.45904 .85982 m .46114 .8574 L .45897 .85771 L F
.38 0 0 r
.39872 .83995 m .39811 .84124 L .39391 .84134 L F
.138 0 0 r
.39947 .84067 m .39872 .83995 L .40077 .83958 L F
.39947 .84067 m .39811 .84124 L .39872 .83995 L F
.679 .324 .366 r
.50656 .87256 m .50457 .87065 L .50336 .87276 L F
.584 .346 .522 r
.50656 .87256 m .50658 .87047 L .50457 .87065 L F
0 0 0 r
.50698 .81924 m .50807 .81884 L .50837 .81788 L F
.459 .054 .182 r
.50807 .81884 m .51081 .81792 L .50837 .81788 L F
.702 .314 .31 r
.41256 .8748 m .41583 .87515 L .41389 .87323 L F
.631 .337 .453 r
.41389 .87323 m .41583 .87515 L .41653 .87293 L F
.796 .789 .846 r
.52706 .81597 m .53193 .81444 L .52886 .8142 L F
.787 .692 .76 r
.52803 .81902 m .53193 .81444 L .52706 .81597 L F
.647 .144 .04 r
.52886 .8142 m .53193 .81444 L .53114 .81539 L F
.674 .13 0 r
.50042 .80338 m .5025 .80504 L .50267 .80446 L F
.616 .063 0 r
.5025 .80504 m .50549 .80599 L .50267 .80446 L F
.748 .478 .524 r
.47247 .87337 m .47293 .87528 L .46957 .87568 L F
.875 .906 .848 r
.48547 .81389 m .48917 .81145 L .48816 .8115 L F
.788 .928 .927 r
.48947 .80976 m .48917 .81145 L .4902 .81049 L F
.875 .987 .826 r
.48947 .80976 m .48816 .8115 L .48917 .81145 L F
.155 .682 .869 r
.42458 .81363 m .42703 .81364 L .42783 .81387 L F
.42783 .81387 m .42703 .81364 L .42458 .81363 L F
.289 .746 .954 r
.45048 .83115 m .44921 .83062 L .44718 .8307 L F
0 .561 .74 r
.45217 .83086 m .44921 .83062 L .45048 .83115 L F
.244 .553 .931 r
.50548 .86679 m .50595 .86785 L .50616 .86703 L F
.432 .266 .555 r
.508 .82822 m .50626 .82962 L .50673 .82771 L F
.502 .039 .086 r
.508 .82822 m .50673 .82771 L .50488 .82889 L F
.43 .634 .941 r
.53192 .81715 m .53304 .81854 L .53455 .8176 L F
.369 .493 .853 r
.53304 .81854 m .53615 .81994 L .53455 .8176 L F
.601 .295 .423 r
.45711 .8759 m .45905 .87764 L .45702 .87755 L F
.45711 .8759 m .46004 .87554 L .45905 .87764 L F
.71 .607 .74 r
.50529 .81988 m .50592 .81928 L .50698 .81924 L F
.875 .699 .66 r
.50698 .81924 m .50718 .82173 L .50529 .81988 L F
.3 .794 .857 r
.50592 .81928 m .50807 .81884 L .50698 .81924 L F
.678 .401 .495 r
.51821 .8098 m .51892 .80932 L .51926 .80882 L F
.447 0 0 r
.51946 .80853 m .51926 .80882 L .52053 .80861 L F
.608 .952 .907 r
.52053 .80861 m .51926 .80882 L .52162 .80747 L F
.678 .401 .495 r
.51892 .80932 m .52162 .80747 L .51926 .80882 L F
.447 0 0 r
.51732 .80836 m .51926 .80882 L .51946 .80853 L F
.555 .86 .997 r
.52162 .80747 m .52286 .80802 L .52053 .80861 L F
.372 .073 .323 r
.5108 .8755 m .5133 .87328 L .51263 .87501 L F
.359 .081 .349 r
.51263 .87501 m .5133 .87328 L .515 .87268 L F
.275 .736 .951 r
.49228 .82232 m .49126 .823 L .49004 .82235 L F
.49228 .82232 m .49375 .82291 L .49126 .823 L F
.414 .835 .964 r
.4007 .82459 m .40128 .82391 L .40258 .82399 L F
.4007 .82459 m .39938 .82428 L .40128 .82391 L F
.919 .656 .522 r
.50718 .82173 m .50694 .82373 L .50529 .81988 L F
.493 .26 .489 r
.50914 .82169 m .50694 .82373 L .50718 .82173 L F
.658 .523 .688 r
.45904 .85982 m .46194 .86062 L .46114 .8574 L F
.657 .53 .698 r
.46019 .86246 m .46194 .86062 L .45904 .85982 L F
.752 .537 .604 r
.44627 .86467 m .44942 .8648 L .44982 .86287 L F
.67 .401 .505 r
.4011 .88017 m .40411 .87782 L .40099 .87845 L F
.62 .24 .301 r
.49198 .80642 m .49509 .8057 L .49311 .80619 L F
.508 .215 .403 r
.41583 .87515 m .41899 .8724 L .41653 .87293 L F
.56 .106 .131 r
.40775 .8935 m .40846 .89513 L .40648 .89522 L F
.40775 .8935 m .41009 .89369 L .40846 .89513 L F
.273 0 0 r
.47581 .85499 m .47485 .8546 L .47311 .85662 L F
.47581 .85499 m .47666 .85526 L .47485 .8546 L F
.384 .079 .32 r
.50375 .88319 m .50653 .87999 L .50538 .88251 L F
.393 .136 .401 r
.50653 .87999 m .50859 .87804 L .50831 .87943 L F
.375 .032 .249 r
.50538 .88251 m .50653 .87999 L .50831 .87943 L F
.945 .727 .578 r
.49214 .87152 m .49047 .86968 L .49148 .87257 L F
.762 .255 0 r
.49298 .87313 m .49214 .87152 L .49148 .87257 L F
.49298 .87313 m .49415 .87357 L .49214 .87152 L F
.47 0 .029 r
.41665 .83589 m .41544 .8368 L .41324 .83663 L F
.201 0 0 r
.41741 .83637 m .41665 .83589 L .41852 .83525 L F
.41741 .83637 m .41544 .8368 L .41665 .83589 L F
.649 .958 .935 r
.46253 .81558 m .46058 .81664 L .46135 .81552 L F
.613 .917 .978 r
.46058 .81664 m .45944 .81633 L .46135 .81552 L F
.125 0 0 r
.44167 .8311 m .43841 .83127 L .43956 .83143 L F
.929 .923 .784 r
.49699 .80504 m .49618 .80849 L .49808 .80798 L F
.49699 .80504 m .49517 .80818 L .49618 .80849 L F
.033 0 .148 r
.47061 .82786 m .47034 .82826 L .46956 .82817 L F
.47034 .82826 m .46915 .83003 L .46956 .82817 L F
.752 .869 .933 r
.46662 .82833 m .46895 .8281 L .46956 .82817 L F
.46895 .8281 m .47139 .82785 L .46956 .82817 L F
.783 .991 .886 r
.47196 .82654 m .47139 .82785 L .47306 .82724 L F
.47196 .82654 m .46956 .82817 L .47139 .82785 L F
.947 .79 .654 r
.49258 .82562 m .4936 .82573 L .4942 .82404 L F
.67 .603 .771 r
.53566 .81628 m .5321 .8138 L .53398 .81386 L F
.4 .572 .906 r
.53728 .81608 m .53566 .81628 L .53398 .81386 L F
.394 .343 .682 r
.53777 .81821 m .53566 .81628 L .53728 .81608 L F
.401 0 0 r
.53657 .8205 m .53865 .82132 L .53727 .82102 L F
.606 .456 .652 r
.5381 .81887 m .53865 .82132 L .53657 .8205 L F
.85 .559 .024 r
.53777 .81821 m .53865 .82132 L .5381 .81887 L F
.558 .547 .799 r
.5405 .82081 m .53865 .82132 L .53777 .81821 L F
.5405 .82081 m .53836 .81878 L .53892 .81847 L F
.53836 .81878 m .53777 .81821 L .53892 .81847 L F
0 0 .201 r
.53939 .81822 m .53892 .81847 L .53995 .81695 L F
.438 .588 .904 r
.54176 .81965 m .5405 .82081 L .53892 .81847 L F
.693 .321 .337 r
.53891 .81931 m .54176 .81965 L .53892 .81847 L F
0 0 .201 r
.53891 .81931 m .53892 .81847 L .53939 .81822 L F
.282 .118 .474 r
.53866 .81888 m .53777 .81821 L .53727 .82102 L F
.53892 .81847 m .53777 .81821 L .53866 .81888 L F
.446 .489 .81 r
.5381 .81887 m .5368 .8175 L .53777 .81821 L F
.5368 .8175 m .53566 .81628 L .53777 .81821 L F
.703 .294 .267 r
.53777 .81821 m .53566 .81628 L .53455 .8176 L F
.28 0 0 r
.43467 .83251 m .43278 .8337 L .4306 .83321 L F
.647 .931 .662 r
.43379 .83286 m .43467 .83251 L .43642 .83162 L F
.43379 .83286 m .43278 .8337 L .43467 .83251 L F
.619 .346 .483 r
.43054 .87025 m .43141 .86756 L .42875 .86869 L F
.567 .345 .538 r
.43357 .86942 m .43141 .86756 L .43054 .87025 L F
.43357 .86942 m .43359 .8675 L .43141 .86756 L F
.585 .039 0 r
.50028 .81546 m .5014 .81697 L .49942 .81633 L F
.50028 .81546 m .50274 .81644 L .5014 .81697 L F
.376 0 .064 r
.39468 .87754 m .39839 .87554 L .39617 .87762 L F
.493 .627 .91 r
.50076 .82924 m .50273 .82942 L .50305 .82853 L F
.50305 .82853 m .50273 .82942 L .50076 .82924 L F
.162 0 0 r
.52483 .8187 m .52803 .81902 L .52725 .81902 L F
.787 .692 .76 r
.52803 .81902 m .52706 .81597 L .52895 .81806 L F
.575 .941 .878 r
.52725 .81902 m .52803 .81902 L .52895 .81806 L F
.656 .53 .698 r
.46101 .8552 m .46356 .85714 L .46312 .85474 L F
.46101 .8552 m .46114 .8574 L .46356 .85714 L F
.66 .469 .615 r
.46673 .85474 m .46882 .85467 L .46848 .85241 L F
.485 0 .017 r
.42035 .83602 m .41741 .83637 L .41852 .83525 L F
.107 .659 .702 r
.44672 .81839 m .44875 .81809 L .4501 .81789 L F
.32 0 0 r
.44875 .81809 m .4519 .81766 L .4501 .81789 L F
.322 .785 .94 r
.42958 .81933 m .429 .81992 L .42764 .81966 L F
.42958 .81933 m .4311 .81965 L .429 .81992 L F
.022 .097 .603 r
.47978 .85385 m .47893 .85474 L .47847 .85169 L F
.376 .236 .56 r
.47847 .85169 m .47866 .85447 L .47978 .85385 L F
.47866 .85447 m .47869 .85492 L .47941 .85421 L F
.47866 .85447 m .47941 .85421 L .47978 .85385 L F
.413 .844 .947 r
.47648 .8552 m .47893 .85474 L .47666 .85526 L F
.47581 .85499 m .47751 .85485 L .47648 .8552 L F
.47751 .85485 m .47893 .85474 L .47648 .8552 L F
.731 .397 .414 r
.4812 .87806 m .48448 .87827 L .48317 .8802 L F
.767 .443 .438 r
.48317 .8802 m .48448 .87827 L .4851 .88019 L F
.797 .493 .475 r
.48448 .87827 m .48774 .88065 L .4851 .88019 L F
.776 .574 .626 r
.48135 .87555 m .47804 .87773 L .47807 .87548 L F
.48135 .87555 m .4812 .87806 L .47804 .87773 L F
.616 .235 .297 r
.52019 .86452 m .51937 .86244 L .51826 .86517 L F
.52019 .86452 m .52122 .86262 L .51937 .86244 L F
.491 .273 .51 r
.50859 .87804 m .5108 .8755 L .51045 .87767 L F
.478 .262 .506 r
.51045 .87767 m .5108 .8755 L .51263 .87501 L F
0 .259 .69 r
.50111 .80931 m .50169 .80956 L .50004 .80858 L F
.408 .466 .808 r
.48713 .81278 m .48787 .81483 L .48547 .81389 L F
.894 .913 .829 r
.48843 .81202 m .48787 .81483 L .48713 .81278 L F
.48843 .81202 m .48699 .81401 L .48787 .81483 L F
.48699 .81401 m .4865 .81468 L .48787 .81483 L F
0 .387 .812 r
.48787 .81483 m .48921 .81594 L .48886 .81575 L F
.48787 .81483 m .48886 .81575 L .48628 .81438 L F
.572 .505 .741 r
.48921 .81594 m .48726 .81652 L .48628 .81438 L F
.426 .058 .235 r
.4138 .89284 m .41492 .89078 L .41699 .89047 L F
.67 .401 .505 r
.4011 .88017 m .40323 .88049 L .40411 .87782 L F
.641 .371 .495 r
.40411 .87782 m .40625 .87994 L .40627 .87783 L F
.40411 .87782 m .40323 .88049 L .40625 .87994 L F
.037 0 0 r
.48037 .81019 m .48136 .81034 L .48274 .80918 L F
.491 .272 .509 r
.50831 .87943 m .50859 .87804 L .51045 .87767 L F
.392 .83 .95 r
.43421 .81953 m .4311 .81965 L .43276 .8191 L F
.071 .634 .743 r
.43488 .81943 m .43421 .81953 L .43276 .8191 L F
.43488 .81943 m .43611 .81942 L .43421 .81953 L F
.921 .706 .594 r
.36649 .74864 m .36776 .75161 L .36829 .74957 L F
.529 .295 .504 r
.36829 .74957 m .36976 .75133 L .36776 .75161 L F
.36829 .74957 m .36976 .75133 L .36776 .75161 L F
.485 .873 .97 r
.45528 .81734 m .4519 .81766 L .45389 .81725 L F
.26 .769 .833 r
.45587 .81698 m .45528 .81734 L .45389 .81725 L F
.45587 .81698 m .45734 .81693 L .45528 .81734 L F
.253 0 0 r
.51322 .81337 m .51203 .81367 L .50991 .81354 L F
.36 .241 .579 r
.51495 .81289 m .51203 .81367 L .51322 .81337 L F
.511 .212 .395 r
.42465 .88621 m .42626 .88767 L .42426 .88793 L F
.42465 .88621 m .42654 .8861 L .42626 .88767 L F
.512 .089 .175 r
.51494 .86709 m .51391 .86528 L .51328 .86729 L F
.51494 .86709 m .51614 .86538 L .51391 .86528 L F
.603 .461 .661 r
.46194 .86062 m .46356 .85714 L .46114 .8574 L F
.279 0 .142 r
.48005 .82038 m .47932 .81872 L .48152 .81835 L F
.48005 .82038 m .47804 .82135 L .47932 .81872 L F
.605 .288 .406 r
.43497 .88315 m .43385 .88543 L .4319 .88495 L F
.56 .246 .393 r
.43699 .88292 m .43385 .88543 L .43497 .88315 L F
.491 .478 .771 r
.47573 .84989 m .47847 .85169 L .47845 .85014 L F
.388 0 .05 r
.49699 .80504 m .49924 .80482 L .50042 .80338 L F
.299 0 0 r
.49924 .80482 m .5025 .80504 L .50042 .80338 L F
.376 0 .064 r
.39468 .87754 m .39723 .87722 L .39839 .87554 L F
.976 .711 .463 r
.39839 .87554 m .39723 .87722 L .39834 .87747 L F
.54 .185 .315 r
.44677 .87859 m .4498 .87762 L .44848 .87991 L F
.554 .236 .384 r
.4498 .87762 m .45063 .88023 L .44848 .87991 L F
.4498 .87762 m .45181 .87776 L .45063 .88023 L F
.677 .46 .584 r
.43811 .86495 m .44119 .86543 L .44116 .86244 L F
.697 .476 .584 r
.44119 .86543 m .44319 .86429 L .44116 .86244 L F
.762 .674 .765 r
.47216 .82369 m .47543 .82394 L .47421 .82116 L F
.159 0 0 r
.47216 .82369 m .47458 .82397 L .47543 .82394 L F
.634 .888 .987 r
.47743 .82311 m .47543 .82394 L .47592 .82271 L F
.767 .997 .846 r
.47543 .82394 m .47458 .82397 L .47592 .82271 L F
.043 0 0 r
.42656 .83383 m .42585 .83403 L .42382 .83424 L F
0 0 0 r
.42781 .83359 m .42656 .83383 L .42912 .83349 L F
.42781 .83359 m .42585 .83403 L .42656 .83383 L F
.558 .318 .507 r
.48726 .81652 m .48686 .81852 L .48477 .81878 L F
.602 .412 .597 r
.48921 .81594 m .48686 .81852 L .48726 .81652 L F
.382 .077 .318 r
.51797 .87012 m .51882 .87177 L .51699 .87233 L F
.516 .078 .146 r
.41324 .83663 m .40995 .83743 L .41123 .83709 L F
.805 .839 .876 r
.47577 .82769 m .47856 .82732 L .47712 .82775 L F
.423 .065 .251 r
.48081 .82663 m .48055 .82768 L .47856 .82732 L F
0 0 0 r
.47935 .82729 m .47856 .82732 L .48055 .82768 L F
.47935 .82729 m .47712 .82775 L .47856 .82732 L F
.531 .896 .97 r
.5321 .8138 m .52886 .8142 L .5312 .81364 L F
.533 .905 .958 r
.53343 .813 m .5321 .8138 L .5312 .81364 L F
.446 .543 .861 r
.53398 .81386 m .5321 .8138 L .53343 .813 L F
.657 .53 .698 r
.46019 .86246 m .46214 .86252 L .46194 .86062 L F
.65 .429 .57 r
.46196 .86453 m .46019 .86246 L .46001 .86392 L F
.46196 .86453 m .46214 .86252 L .46019 .86246 L F
.263 0 .185 r
.52475 .81687 m .52407 .8173 L .52483 .8187 L F
.316 0 0 r
.43611 .81942 m .43809 .8198 L .43948 .81948 L F
.82 .515 .473 r
.4851 .88019 m .48774 .88065 L .48804 .88251 L F
.77 .35 .252 r
.48774 .88065 m .48952 .88323 L .48804 .88251 L F
.48774 .88065 m .4913 .88264 L .48952 .88323 L F
.674 .854 .968 r
.45217 .83086 m .45573 .83056 L .45457 .83032 L F
.006 .583 .719 r
.45809 .83036 m .45457 .83032 L .45573 .83056 L F
.401 0 0 r
.53657 .8205 m .53727 .82102 L .53615 .81994 L F
.745 .882 .942 r
.50488 .82889 m .50626 .82962 L .508 .82822 L F
.614 .366 .518 r
.46004 .87554 m .46218 .87757 L .45905 .87764 L F
.46004 .87554 m .46228 .87533 L .46218 .87757 L F
.518 .205 .376 r
.43942 .88095 m .4411 .88252 L .43895 .88268 L F
.43942 .88095 m .44142 .88084 L .4411 .88252 L F
.745 .423 .439 r
.42318 .87511 m .42439 .87301 L .4211 .87271 L F
.42 .063 .25 r
.42637 .87264 m .42439 .87301 L .42318 .87511 L F
.542 .356 .578 r
.42646 .87034 m .42439 .87301 L .42637 .87264 L F
.448 .094 .271 r
.52643 .86662 m .52702 .8649 L .52908 .86515 L F
.619 .346 .483 r
.43054 .87025 m .42875 .86869 L .42844 .87003 L F
.568 .208 .319 r
.42654 .8861 m .42984 .88483 L .42847 .8872 L F
.524 .166 .301 r
.42984 .88483 m .4305 .8873 L .42847 .8872 L F
.42984 .88483 m .4319 .88495 L .4305 .8873 L F
.631 .441 .606 r
.46356 .85714 m .46673 .85474 L .46312 .85474 L F
.221 0 0 r
.38141 .82734 m .38348 .82702 L .38468 .82632 L F
.321 0 0 r
.38348 .82702 m .38667 .82616 L .38468 .82632 L F
.116 .665 .709 r
.44155 .81936 m .44356 .81905 L .44472 .81888 L F
.111 0 0 r
.44356 .81905 m .44672 .81839 L .44472 .81888 L F
.915 .671 .555 r
.48139 .84883 m .48222 .84714 L .48095 .84689 L F
.194 0 0 r
.42039 .82129 m .42243 .82104 L .42342 .8204 L F
.056 0 0 r
.42342 .8204 m .4244 .82056 L .42562 .81972 L F
.42342 .8204 m .42243 .82104 L .4244 .82056 L F
.664 .449 .583 r
.43359 .8675 m .43587 .86752 L .43603 .86523 L F
.692 .534 .668 r
.43587 .86752 m .43811 .86495 L .43603 .86523 L F
.02 0 0 r
.40806 .82237 m .40853 .82261 L .40993 .82188 L F
.40806 .82237 m .40644 .82298 L .40853 .82261 L F
.682 .874 .971 r
.47317 .81383 m .46995 .81409 L .47205 .81355 L F
.722 .983 .904 r
.47499 .81258 m .47317 .81383 L .47387 .81252 L F
.678 .941 .964 r
.47317 .81383 m .47205 .81355 L .47387 .81252 L F
.531 .345 .574 r
.42844 .87003 m .42646 .87034 L .42637 .87264 L F
.037 .495 .884 r
.49808 .80798 m .49895 .80768 L .49699 .80504 L F
.49808 .80798 m .50004 .80858 L .49895 .80768 L F
0 0 0 r
.39902 .898 m .40245 .89591 L .40113 .89788 L F
.227 0 0 r
.40113 .89788 m .40245 .89591 L .40464 .89524 L F
.54 .185 .315 r
.44677 .87859 m .44848 .87991 L .4464 .88002 L F
.289 .763 .935 r
.49614 .87339 m .49415 .87357 L .49298 .87313 L F
.097 .65 .805 r
.40997 .82188 m .4116 .82182 L .41319 .82197 L F
.356 0 .009 r
.41055 .82288 m .41301 .82178 L .4116 .82182 L F
.313 .795 .904 r
.41319 .82197 m .4116 .82182 L .41365 .82149 L F
.356 0 .009 r
.41301 .82178 m .41365 .82149 L .4116 .82182 L F
.097 .65 .805 r
.40993 .82188 m .4116 .82182 L .40997 .82188 L F
.313 .795 .904 r
.41319 .82197 m .41365 .82149 L .41513 .82157 L F
.27 0 0 r
.40846 .89513 m .41009 .89369 L .4121 .89335 L F
.702 .903 .968 r
.48947 .80976 m .4902 .81049 L .49324 .80906 L F
.616 .161 .15 r
.49287 .88341 m .49617 .8834 L .49505 .88471 L F
.652 .205 .176 r
.49505 .88471 m .49617 .8834 L .49818 .88485 L F
.926 .939 .585 r
.51233 .81979 m .51321 .81892 L .51155 .81794 L F
.51233 .81979 m .51211 .82162 L .51321 .81892 L F
.569 .9 .982 r
.46794 .81461 m .46439 .81503 L .46615 .81451 L F
.41 .851 .929 r
.46995 .81409 m .46794 .81461 L .46615 .81451 L F
.579 .417 .626 r
.52483 .8187 m .52706 .81597 L .52475 .81687 L F
.589 .134 .139 r
.52231 .86448 m .52122 .86262 L .52019 .86452 L F
.52231 .86448 m .52359 .86322 L .52122 .86262 L F
.83 .569 .545 r
.47446 .86187 m .47821 .85999 L .47479 .85981 L F
.47446 .86187 m .47888 .86187 L .47821 .85999 L F
0 .052 .589 r
.47821 .85999 m .47888 .86187 L .47953 .86255 L F
.806 .988 .883 r
.50518 .81139 m .50174 .81344 L .50381 .81088 L F
.384 0 .002 r
.51556 .82441 m .5164 .82561 L .51453 .8243 L F
.51556 .82441 m .51785 .82422 L .5164 .82561 L F
.782 .548 .582 r
.5164 .82293 m .51884 .82165 L .51801 .82232 L F
.51884 .82165 m .51993 .82108 L .51801 .82232 L F
.603 .512 .724 r
.51801 .82232 m .51556 .82441 L .51554 .82433 L F
.51801 .82232 m .51554 .82433 L .51486 .82232 L F
.51801 .82232 m .51785 .82422 L .51556 .82441 L F
.439 .133 .347 r
.52155 .86998 m .52224 .86739 L .52435 .86687 L F
.595 .156 .176 r
.50026 .88498 m .50163 .8835 L .50342 .88481 L F
.516 .219 .4 r
.50163 .8835 m .50375 .88319 L .50342 .88481 L F
.366 .663 .971 r
.47306 .82724 m .4738 .82625 L .47196 .82654 L F
.47306 .82724 m .47577 .82769 L .4738 .82625 L F
.573 .263 .405 r
.45165 .86748 m .4548 .86506 L .45169 .86514 L F
.45165 .86748 m .4539 .86742 L .4548 .86506 L F
.605 .295 .419 r
.4539 .86742 m .45658 .86677 L .4548 .86506 L F
.635 .288 .365 r
.45658 .86677 m .457 .86535 L .4548 .86506 L F
.542 .253 .425 r
.40913 .8759 m .41049 .8774 L .41059 .87511 L F
.40913 .8759 m .40838 .87767 L .41049 .8774 L F
.192 0 .22 r
.51126 .8673 m .50888 .87096 L .51086 .87009 L F
.373 .12 .396 r
.51328 .86729 m .51126 .8673 L .51086 .87009 L F
.98 .692 .387 r
.48 .86684 m .48111 .86733 L .48092 .86517 L F
.214 .441 .864 r
.48216 .86452 m .48092 .86517 L .47953 .86255 L F
0 0 0 r
.48 .86684 m .48092 .86517 L .48216 .86452 L F
.525 .299 .515 r
.50888 .87096 m .50658 .87047 L .50656 .87256 L F
.51 .048 .092 r
.5081 .81328 m .50877 .81484 L .50675 .81487 L F
.5081 .81328 m .50991 .81354 L .50877 .81484 L F
0 0 .162 r
.51486 .82232 m .51453 .8243 L .51361 .82198 L F
.354 0 0 r
.5164 .82293 m .51486 .82232 L .51361 .82198 L F
.5164 .82293 m .51801 .82232 L .51486 .82232 L F
.527 .234 .412 r
.4196 .88886 m .42124 .89033 L .41911 .89026 L F
.4196 .88886 m .42162 .88859 L .42124 .89033 L F
.686 .298 .306 r
.4913 .88264 m .49287 .88341 L .48952 .88323 L F
.569 .747 .961 r
.39096 .84145 m .39337 .842 L .39211 .84133 L F
0 0 .371 r
.39391 .84134 m .39432 .84158 L .39337 .842 L F
.264 .694 .965 r
.39337 .842 m .39432 .84158 L .39211 .84133 L F
.39337 .842 m .39432 .84158 L .39211 .84133 L F
.451 .824 .992 r
.41513 .82157 m .41708 .82123 L .41843 .82173 L F
.216 .728 .882 r
.41708 .82123 m .42039 .82129 L .41843 .82173 L F
.86 .937 .871 r
.51233 .81979 m .51109 .8212 L .51211 .82162 L F
.164 0 0 r
.42585 .83403 m .42215 .83567 L .42382 .83424 L F
0 0 0 r
.48505 .8081 m .48474 .80847 L .48644 .80763 L F
.603 .461 .661 r
.46194 .86062 m .4641 .86027 L .46356 .85714 L F
.618 .507 .705 r
.46214 .86252 m .4641 .86027 L .46194 .86062 L F
0 .547 .71 r
.5131 .80868 m .51204 .80863 L .51088 .80793 L F
.5131 .80868 m .5142 .80874 L .51204 .80863 L F
.712 .447 .522 r
.47293 .87528 m .47656 .87521 L .47478 .87771 L F
.715 .477 .563 r
.47656 .87521 m .47804 .87773 L .47478 .87771 L F
.47656 .87521 m .47807 .87548 L .47804 .87773 L F
.275 0 0 r
.52652 .86248 m .52359 .86322 L .52557 .86288 L F
.35 0 0 r
.40594 .83822 m .40471 .83889 L .40264 .83899 L F
.476 .028 .107 r
.40833 .83778 m .40471 .83889 L .40594 .83822 L F
.569 .392 .602 r
.37611 .73896 m .37619 .74146 L .37404 .74156 L F
.37611 .73896 m .37619 .74146 L .37404 .74156 L F
.765 .315 .18 r
.48717 .81966 m .48477 .81878 L .48492 .81883 L F
.48717 .81966 m .48371 .8181 L .48477 .81878 L F
.631 .441 .606 r
.46356 .85714 m .46632 .85738 L .46673 .85474 L F
.623 .432 .604 r
.46673 .85474 m .46845 .85706 L .46882 .85467 L F
.46673 .85474 m .46632 .85738 L .46845 .85706 L F
.067 0 0 r
.46135 .81552 m .46439 .81503 L .46253 .81558 L F
.618 .507 .705 r
.46214 .86252 m .46437 .86246 L .4641 .86027 L F
.577 .284 .433 r
.46387 .86405 m .46214 .86252 L .46196 .86453 L F
.46387 .86405 m .46437 .86246 L .46214 .86252 L F
.602 .46 .662 r
.46356 .85714 m .46616 .85969 L .46632 .85738 L F
.46356 .85714 m .4641 .86027 L .46616 .85969 L F
0 0 .1 r
.4823 .82356 m .48161 .82575 L .48228 .82422 L F
.576 .143 .183 r
.48232 .82247 m .4823 .82356 L .48336 .82223 L F
.71 .889 .506 r
.48336 .82223 m .4823 .82356 L .48329 .82193 L F
0 0 .1 r
.4823 .82356 m .48228 .82422 L .48329 .82193 L F
.576 .143 .183 r
.47942 .82313 m .4823 .82356 L .48232 .82247 L F
.71 .889 .506 r
.48336 .82223 m .48329 .82193 L .48492 .81883 L F
.417 .74 .992 r
.42532 .81268 m .42703 .81364 L .42458 .81363 L F
.42532 .81268 m .42703 .81364 L .42458 .81363 L F
0 0 0 r
.48274 .80918 m .48324 .80948 L .48474 .80847 L F
.48274 .80918 m .48136 .81034 L .48324 .80948 L F
.719 .964 .941 r
.50658 .86265 m .50508 .8644 L .50412 .86432 L F
.50658 .86265 m .50764 .86291 L .50508 .8644 L F
.153 .28 .742 r
.48882 .82043 m .48787 .82145 L .48686 .81852 L F
.276 .473 .871 r
.48882 .82043 m .49004 .82235 L .48787 .82145 L F
.493 .07 .165 r
.50004 .87437 m .49919 .87263 L .49814 .87322 L F
.50004 .87437 m .50129 .87271 L .49919 .87263 L F
.722 .48 .559 r
.44942 .8648 m .45165 .86748 L .45169 .86514 L F
.318 0 .211 r
.48492 .81883 m .48588 .82037 L .48717 .81966 L F
.48492 .81883 m .48329 .82193 L .48588 .82037 L F
.434 0 0 r
.50789 .80674 m .51088 .80793 L .50884 .80706 L F
.884 .949 .593 r
.49258 .82562 m .49166 .82792 L .4936 .82573 L F
.006 .583 .719 r
.45809 .83036 m .45628 .83033 L .45457 .83032 L F
.505 .032 .065 r
.45992 .82938 m .45628 .83033 L .45809 .83036 L F
.348 .817 .744 r
.47592 .81204 m .47499 .81258 L .47387 .81252 L F
.47592 .81204 m .47751 .81154 L .47499 .81258 L F
.333 0 0 r
.5142 .80874 m .51629 .80882 L .51732 .80836 L F
.572 .076 .037 r
.51629 .80882 m .51926 .80882 L .51732 .80836 L F
.666 .326 .388 r
.40264 .83899 m .39947 .84067 L .40077 .83958 L F
.993 .756 .46 r
.49963 .81433 m .50064 .8129 L .50174 .81344 L F
.49963 .81433 m .49767 .813 L .50064 .8129 L F
.592 .49 .707 r
.62202 .75122 m .62436 .75107 L .62378 .74977 L F
.701 .715 .859 r
.62505 .74902 m .62123 .74854 L .62307 .74818 L F
.592 .49 .707 r
.62265 .7494 m .62378 .74977 L .62307 .74818 L F
.392 .595 .927 r
.62075 .74878 m .62283 .75035 L .62008 .74911 L F
.62172 .7491 m .62283 .75035 L .62075 .74878 L F
.592 .49 .707 r
.62202 .75122 m .62378 .74977 L .62265 .7494 L F
.392 .595 .927 r
.62123 .74854 m .62172 .7491 L .62075 .74878 L F
.298 .345 .743 r
.62008 .74911 m .62202 .75122 L .62123 .74854 L F
.595 .317 .464 r
.44629 .86731 m .44942 .8648 L .44627 .86467 L F
.44629 .86731 m .44835 .8672 L .44942 .8648 L F
.741 .479 .535 r
.44835 .8672 m .45165 .86748 L .44942 .8648 L F
.66 .404 .522 r
.46228 .87533 m .46433 .87746 L .46218 .87757 L F
.675 .402 .501 r
.46228 .87533 m .46426 .8755 L .46433 .87746 L F
.321 .808 .851 r
.42982 .83308 m .42912 .83349 L .4306 .83321 L F
.42982 .83308 m .42781 .83359 L .42912 .83349 L F
.673 .382 .472 r
.46426 .8755 m .46764 .87524 L .46632 .87776 L F
.676 .386 .473 r
.46764 .87524 m .46961 .87739 L .46632 .87776 L F
.694 .383 .445 r
.46764 .87524 m .46957 .87568 L .46961 .87739 L F
.56 .246 .393 r
.43699 .88292 m .43589 .88557 L .43385 .88543 L F
.624 .354 .49 r
.43895 .88268 m .43589 .88557 L .43699 .88292 L F
.116 0 0 r
.48925 .82628 m .48825 .82648 L .48594 .82651 L F
.586 .946 .855 r
.48988 .82554 m .48825 .82648 L .48925 .82628 L F
.788 .355 .221 r
.49166 .82792 m .4911 .82845 L .48925 .82628 L F
.093 .248 .732 r
.48925 .82628 m .4911 .82845 L .48988 .82554 L F
.05 .573 .87 r
.52162 .80747 m .52474 .80832 L .52286 .80802 L F
.483 .143 .313 r
.46001 .86392 m .45658 .86677 L .45878 .86684 L F
.46001 .86392 m .457 .86535 L .45658 .86677 L F
.645 .293 .36 r
.46089 .86667 m .46001 .86392 L .45878 .86684 L F
.46089 .86667 m .46196 .86453 L .46001 .86392 L F
.21 0 0 r
.394 .82456 m .39574 .82475 L .3973 .82445 L F
.756 .563 .636 r
.5286 .81152 m .52886 .8142 L .52579 .81314 L F
.564 .494 .734 r
.53067 .81058 m .5286 .81152 L .52788 .80833 L F
.53067 .81058 m .53067 .81149 L .5286 .81152 L F
.665 .554 .72 r
.53067 .81149 m .52886 .8142 L .5286 .81152 L F
.579 .417 .626 r
.52483 .8187 m .52725 .81902 L .52706 .81597 L F
.375 .032 .249 r
.50538 .88251 m .50831 .87943 L .50705 .88196 L F
.491 .272 .509 r
.50831 .87943 m .51045 .87767 L .51013 .88021 L F
.4 .043 .239 r
.50705 .88196 m .50831 .87943 L .51013 .88021 L F
.508 .215 .403 r
.41583 .87515 m .41785 .87488 L .41899 .8724 L F
.682 .401 .489 r
.42094 .87475 m .41899 .8724 L .41785 .87488 L F
.42094 .87475 m .4211 .87271 L .41899 .8724 L F
.372 0 0 r
.39065 .82557 m .394 .82456 L .39194 .82473 L F
.607 .123 .08 r
.39096 .84145 m .38882 .84198 L .38684 .84139 L F
.473 .008 .067 r
.39211 .84133 m .38882 .84198 L .39096 .84145 L F
.757 .444 .456 r
.47804 .87773 m .4812 .87806 L .47991 .88019 L F
.721 .399 .434 r
.4812 .87806 m .48317 .8802 L .47991 .88019 L F
.787 .563 .598 r
.46882 .85467 m .46845 .85706 L .4715 .85723 L F
.466 .091 .242 r
.46835 .85937 m .4715 .85723 L .46845 .85706 L F
.46835 .85937 m .47045 .85914 L .4715 .85723 L F
.502 .183 .359 r
.47045 .85914 m .47311 .85662 L .4715 .85723 L F
0 0 0 r
.43841 .83127 m .43379 .83286 L .43642 .83162 L F
.731 .486 .558 r
.48101 .86988 m .48283 .86755 L .48111 .86733 L F
.48101 .86988 m .48434 .87006 L .48283 .86755 L F
.667 .404 .514 r
.48245 .82626 m .48055 .82768 L .48081 .82663 L F
.502 .548 .836 r
.37547 .79282 m .37472 .79485 L .37397 .79276 L F
.37547 .79282 m .37676 .79517 L .37472 .79485 L F
.544 .466 .717 r
.37472 .79485 m .37676 .79517 L .37485 .79549 L F
.462 .184 .405 r
.37485 .79549 m .37676 .79517 L .37467 .79613 L F
.673 .382 .472 r
.46426 .8755 m .46632 .87776 L .46433 .87746 L F
.62 .24 .301 r
.49198 .80642 m .49405 .80777 L .49509 .8057 L F
.974 .717 .48 r
.49509 .8057 m .49517 .80818 L .49699 .80504 L F
.49509 .8057 m .49405 .80777 L .49517 .80818 L F
.682 .449 .562 r
.46957 .87568 m .47293 .87528 L .47295 .87731 L F
.675 .443 .562 r
.47293 .87528 m .47478 .87771 L .47295 .87731 L F
.146 0 0 r
.42562 .81972 m .42639 .82017 L .42764 .81966 L F
.42562 .81972 m .4244 .82056 L .42639 .82017 L F
.88 .83 .794 r
.52788 .80833 m .52475 .81009 L .5267 .80775 L F
.436 .803 .995 r
.5267 .80775 m .5288 .8075 L .52788 .80833 L F
.213 .429 .855 r
.5288 .8075 m .53067 .81058 L .52788 .80833 L F
.463 .06 .19 r
.38484 .84132 m .38684 .84139 L .38459 .84167 L F
.656 .453 .597 r
.50454 .81624 m .50344 .82055 L .50274 .81644 L F
0 0 .269 r
.50274 .81644 m .50344 .82055 L .50319 .81705 L F
.50274 .81644 m .50319 .81705 L .5014 .81697 L F
.682 .449 .562 r
.46957 .87568 m .47295 .87731 L .46961 .87739 L F
.12 .67 .74 r
.45457 .83032 m .45094 .83073 L .45217 .83086 L F
.26 0 0 r
.45297 .83047 m .45159 .83075 L .45094 .83073 L F
0 .561 .74 r
.45217 .83086 m .45094 .83073 L .45027 .8307 L F
.26 0 0 r
.45159 .83075 m .44984 .83111 L .45094 .83073 L F
0 .561 .74 r
.45027 .8307 m .45094 .83073 L .44921 .83062 L F
.672 .439 .56 r
.43357 .86942 m .43587 .86752 L .43359 .8675 L F
.612 .752 .945 r
.61582 .75909 m .61381 .75969 L .61283 .75857 L F
.61582 .75909 m .61381 .75969 L .61283 .75857 L F
.565 .39 .603 r
.47216 .82369 m .47458 .82397 L .47421 .82116 L F
.786 .673 .739 r
.44119 .86543 m .44114 .86749 L .44319 .86429 L F
.682 .53 .674 r
.44114 .86749 m .44404 .86734 L .44319 .86429 L F
.66 .496 .652 r
.44404 .86734 m .44627 .86467 L .44319 .86429 L F
.821 .533 .502 r
.4764 .86374 m .47888 .86187 L .47446 .86187 L F
.519 .097 .18 r
.47953 .86255 m .47888 .86187 L .4764 .86374 L F
.392 0 .103 r
.51826 .86517 m .51614 .86538 L .51494 .86709 L F
.991 .794 .541 r
.48278 .84115 m .48382 .84203 L .48306 .84075 L F
.48278 .84115 m .48382 .84203 L .48306 .84075 L F
.585 .728 .942 r
.50305 .82853 m .50273 .82942 L .50488 .82889 L F
.50488 .82889 m .50273 .82942 L .50305 .82853 L F
.024 0 0 r
.44718 .8307 m .44568 .83088 L .44366 .83098 L F
.369 0 0 r
.44921 .83062 m .44568 .83088 L .44718 .8307 L F
.038 0 .178 r
.47446 .86187 m .47479 .85981 L .47611 .85923 L F
.692 .534 .668 r
.43587 .86752 m .43887 .86742 L .43811 .86495 L F
.731 .627 .742 r
.43887 .86742 m .44119 .86543 L .43811 .86495 L F
.745 .423 .439 r
.42318 .87511 m .4211 .87271 L .42094 .87475 L F
.711 .54 .655 r
.48028 .84652 m .48095 .84689 L .48211 .84412 L F
.884 .949 .593 r
.49258 .82562 m .4911 .82845 L .49166 .82792 L F
.473 .678 .955 r
.47812 .82203 m .47743 .82311 L .47592 .82271 L F
.47812 .82203 m .47942 .82313 L .47743 .82311 L F
.125 0 0 r
.44167 .8311 m .44038 .83128 L .43841 .83127 L F
.02 0 0 r
.44366 .83098 m .44038 .83128 L .44167 .8311 L F
.383 .844 .88 r
.45944 .81633 m .45734 .81693 L .45587 .81698 L F
.755 .816 .901 r
.47664 .84436 m .47343 .84427 L .47582 .84327 L F
.47582 .84327 m .47343 .84427 L .47664 .84436 L F
.13 .474 .896 r
.47582 .84327 m .47697 .84367 L .47664 .84436 L F
.429 .816 .988 r
.47664 .84436 m .47697 .84367 L .47867 .84406 L F
.13 .474 .896 r
.47664 .84436 m .47697 .84367 L .47582 .84327 L F
.429 .816 .988 r
.47664 .84436 m .47697 .84367 L .47867 .84406 L F
.516 .078 .146 r
.41324 .83663 m .4118 .83823 L .40995 .83743 L F
.355 0 0 r
.41544 .8368 m .4118 .83823 L .41324 .83663 L F
.534 .383 .622 r
.52706 .81597 m .52725 .81902 L .52895 .81806 L F
.545 .242 .404 r
.42626 .88767 m .42654 .8861 L .42847 .8872 L F
.939 .611 .385 r
.50489 .81926 m .50592 .81928 L .50375 .82118 L F
.71 .607 .74 r
.50529 .81988 m .50375 .82118 L .50592 .81928 L F
.846 .638 .621 r
.50529 .81988 m .50511 .82207 L .50375 .82118 L F
.50529 .81988 m .50694 .82373 L .50511 .82207 L F
.99 .824 .445 r
.50511 .82207 m .50496 .82009 L .50375 .82118 L F
.50511 .82207 m .50435 .82226 L .50489 .81926 L F
.185 0 0 r
.50647 .81987 m .50477 .82069 L .50661 .82002 L F
.50592 .81928 m .5053 .82004 L .50647 .81987 L F
.5053 .82004 m .50477 .82069 L .50647 .81987 L F
.99 .824 .445 r
.50496 .82009 m .50489 .81926 L .50435 .82018 L F
.50496 .82009 m .50435 .82018 L .50375 .82118 L F
.484 .243 .474 r
.51263 .87501 m .515 .87268 L .51458 .87484 L F
.508 .265 .482 r
.51458 .87484 m .515 .87268 L .51699 .87233 L F
.241 0 0 r
.3972 .89835 m .39902 .898 L .39714 .8984 L F
0 .509 .704 r
.43488 .81943 m .43809 .8198 L .43611 .81942 L F
.702 .903 .968 r
.48947 .80976 m .49324 .80906 L .492 .80857 L F
.655 .902 .981 r
.492 .80857 m .49324 .80906 L .49517 .80818 L F
.616 .302 .416 r
.45063 .88023 m .45181 .87776 L .45374 .87945 L F
.654 .284 .331 r
.45181 .87776 m .45384 .87821 L .45374 .87945 L F
.785 .658 .722 r
.47847 .85169 m .47893 .85474 L .47581 .85499 L F
.757 .374 .329 r
.47701 .85735 m .4777 .85644 L .47633 .85542 L F
.776 .906 .512 r
.4777 .85644 m .47703 .85812 L .47884 .85491 L F
.789 .924 .549 r
.47611 .85923 m .4777 .85644 L .47717 .85851 L F
0 0 0 r
.47717 .85851 m .4777 .85644 L .47736 .85835 L F
.757 .374 .329 r
.47736 .85835 m .4777 .85644 L .47701 .85735 L F
.776 .906 .512 r
.4777 .85644 m .47884 .85491 L .47893 .85474 L F
.281 0 0 r
.48688 .87018 m .48748 .8698 L .48434 .87006 L F
.554 .885 .626 r
.48802 .86915 m .48748 .8698 L .48688 .87018 L F
0 0 .06 r
.48802 .86915 m .48688 .87018 L .4859 .87204 L F
.48784 .86953 m .4859 .87204 L .48696 .87138 L F
.45 .868 .946 r
.48802 .86915 m .48907 .86938 L .48748 .8698 L F
0 0 .06 r
.48802 .86915 m .48771 .86956 L .48784 .86953 L F
.48771 .86956 m .4859 .87204 L .48784 .86953 L F
.119 .569 .919 r
.4888 .86883 m .48923 .86917 L .48661 .86882 L F
.45 .868 .946 r
.48802 .86915 m .48937 .8693 L .48907 .86938 L F
0 .555 .737 r
.49067 .86935 m .48937 .8693 L .48802 .86915 L F
.923 .586 .13 r
.49068 .87138 m .49047 .86968 L .48937 .8693 L F
.041 .146 .648 r
.49068 .87138 m .48937 .8693 L .49067 .86935 L F
.33 0 0 r
.48984 .86972 m .49067 .86935 L .48802 .86915 L F
.992 .807 .554 r
.48925 .87014 m .49067 .86935 L .48935 .86994 L F
.33 0 0 r
.49003 .86978 m .49067 .86935 L .48984 .86972 L F
.48976 .8697 m .48802 .86915 L .4871 .86896 L F
.49003 .86978 m .48984 .86972 L .48976 .8697 L F
.48984 .86972 m .48802 .86915 L .48976 .8697 L F
.992 .807 .554 r
.48949 .86964 m .49067 .86935 L .49033 .86791 L F
.48935 .86994 m .48984 .86972 L .48949 .86964 L F
.48984 .86972 m .49067 .86935 L .48949 .86964 L F
.923 .586 .13 r
.49068 .87138 m .49148 .87257 L .49047 .86968 L F
.041 .146 .648 r
.49068 .87138 m .49067 .86935 L .48828 .87226 L F
.831 .99 .728 r
.48828 .87226 m .49055 .8695 L .48925 .87014 L F
.49055 .8695 m .49067 .86935 L .48925 .87014 L F
.48828 .87226 m .48925 .87014 L .48696 .87138 L F
.482 0 0 r
.48925 .87014 m .49142 .87056 L .48868 .87042 L F
.558 .934 .887 r
.48802 .87039 m .48696 .87138 L .48925 .87014 L F
.482 0 0 r
.48925 .87014 m .48868 .87042 L .48802 .87039 L F
.992 .807 .554 r
.48925 .87014 m .48955 .86953 L .49142 .87056 L F
.996 .779 .425 r
.49033 .86791 m .49067 .86935 L .49003 .86978 L F
.49033 .86791 m .49003 .86978 L .49045 .86937 L F
.992 .807 .554 r
.49049 .86981 m .49045 .86937 L .4912 .87002 L F
.49045 .86937 m .49033 .86791 L .49087 .86922 L F
.49045 .86937 m .49087 .86922 L .4912 .87002 L F
.28 .137 .501 r
.49142 .87056 m .49033 .86791 L .4917 .86816 L F
.996 .779 .425 r
.49033 .86791 m .49045 .86937 L .4917 .86816 L F
.798 .889 .91 r
.49045 .86937 m .49003 .86978 L .4898 .8696 L F
.992 .807 .554 r
.48955 .86953 m .49033 .86791 L .49049 .86981 L F
.798 .889 .91 r
.4917 .86816 m .49045 .86937 L .4888 .86883 L F
.49045 .86937 m .4898 .8696 L .4888 .86883 L F
.992 .807 .554 r
.48955 .86953 m .4912 .87002 L .49142 .87056 L F
.119 .569 .919 r
.48876 .86929 m .49003 .86978 L .48852 .86935 L F
.48923 .86917 m .4898 .8696 L .48876 .86929 L F
.4898 .8696 m .49003 .86978 L .48876 .86929 L F
0 0 .06 r
.48802 .86915 m .48696 .87138 L .48661 .86882 L F
.33 0 0 r
.4871 .86896 m .48802 .86915 L .48661 .86882 L F
.119 .569 .919 r
.48923 .86917 m .48852 .86935 L .48661 .86882 L F
.728 .262 .143 r
.47421 .82116 m .4761 .82278 L .47592 .82271 L F
.52 .358 .602 r
.47592 .82271 m .47458 .82397 L .47421 .82116 L F
.63 .175 .154 r
.48952 .88323 m .49287 .88341 L .49176 .8847 L F
.616 .159 .144 r
.49176 .8847 m .49287 .88341 L .49505 .88471 L F
.484 0 0 r
.53865 .82132 m .53891 .82157 L .53727 .82102 L F
.831 .669 .126 r
.53891 .82157 m .53903 .82332 L .53898 .82164 L F
.484 0 0 r
.53865 .82132 m .5392 .82184 L .53891 .82157 L F
.508 .369 .626 r
.5405 .82081 m .54067 .82322 L .53865 .82132 L F
.831 .669 .126 r
.53891 .82157 m .53898 .82164 L .53891 .81931 L F
.613 .534 .742 r
.54218 .82083 m .54067 .82322 L .5405 .82081 L F
.409 .537 .875 r
.54218 .82083 m .5405 .82081 L .54176 .81965 L F
.324 .303 .681 r
.53891 .81931 m .54092 .82183 L .54176 .81965 L F
.542 .651 .905 r
.54199 .81715 m .54176 .81965 L .54037 .82035 L F
.324 .303 .681 r
.53891 .81931 m .53898 .82164 L .53992 .82173 L F
.53891 .81931 m .53992 .82173 L .54019 .82091 L F
.542 .651 .905 r
.54096 .81853 m .54037 .82035 L .53919 .82095 L F
.54096 .81853 m .53919 .82095 L .53921 .82086 L F
.324 .303 .681 r
.54019 .82091 m .53992 .82173 L .54092 .82183 L F
.733 .779 .889 r
.53919 .82096 m .54092 .82183 L .53904 .82159 L F
.892 .595 .478 r
.53911 .82099 m .53919 .82095 L .54092 .82183 L F
.53919 .82095 m .54176 .81965 L .54092 .82183 L F
.542 .651 .905 r
.54199 .81715 m .54037 .82035 L .54096 .81853 L F
.431 .403 .727 r
.54391 .81953 m .54218 .82083 L .54176 .81965 L F
.542 .651 .905 r
.54199 .81715 m .54391 .81953 L .54176 .81965 L F
.809 .676 .716 r
.54096 .81852 m .54384 .81965 L .54199 .81715 L F
.53922 .82084 m .54104 .82037 L .54096 .81852 L F
.54104 .82037 m .54384 .81965 L .54096 .81852 L F
.53925 .82085 m .54384 .81965 L .53922 .82084 L F
.53942 .8209 m .54384 .81965 L .53921 .82086 L F
.613 .534 .742 r
.54218 .82083 m .54285 .82332 L .54067 .82322 L F
.767 .922 .939 r
.54177 .81889 m .54384 .81965 L .53945 .8209 L F
.54177 .81889 m .53969 .82068 L .5393 .82052 L F
.54108 .82128 m .5399 .821 L .5393 .82052 L F
.733 .779 .889 r
.53922 .82086 m .54092 .82183 L .53919 .82096 L F
.5393 .82052 m .53904 .82159 L .53928 .82052 L F
.831 .669 .126 r
.53891 .82157 m .53891 .81931 L .53727 .82102 L F
.733 .779 .889 r
.53928 .82052 m .53904 .82159 L .53724 .82136 L F
.542 .651 .905 r
.53921 .82086 m .53919 .82095 L .53911 .82099 L F
.809 .676 .716 r
.53911 .82099 m .53942 .8209 L .53921 .82086 L F
.53921 .82086 m .53925 .82085 L .53922 .82084 L F
.733 .779 .889 r
.5393 .82052 m .5396 .82076 L .53922 .82086 L F
.767 .922 .939 r
.5396 .82076 m .53945 .8209 L .53942 .8209 L F
.733 .779 .889 r
.5396 .82076 m .5399 .821 L .53942 .8209 L F
.5396 .82076 m .53942 .8209 L .53922 .82086 L F
.767 .922 .939 r
.54177 .81889 m .5396 .82076 L .53911 .82099 L F
.5396 .82076 m .53942 .8209 L .53911 .82099 L F
.54177 .81889 m .54108 .82128 L .53969 .82068 L F
.54177 .81889 m .54163 .82215 L .54111 .82191 L F
.54108 .82128 m .54111 .82191 L .54092 .82183 L F
.54177 .81889 m .54111 .82191 L .54108 .82128 L F
.54108 .82128 m .54092 .82183 L .5399 .821 L F
.733 .779 .889 r
.5399 .821 m .54092 .82183 L .53922 .82086 L F
.324 .303 .681 r
.53898 .82164 m .53903 .82332 L .53952 .82294 L F
.53898 .82164 m .53952 .82294 L .53931 .82195 L F
.976 .719 .478 r
.53952 .82294 m .54067 .82322 L .53987 .82469 L F
.53946 .82208 m .54067 .82322 L .53952 .82294 L F
.53931 .82195 m .53987 .82469 L .53966 .82507 L F
.484 0 0 r
.5392 .82184 m .54067 .82322 L .53931 .82195 L F
.236 .155 .557 r
.54092 .82183 m .53952 .82294 L .53966 .82507 L F
.53952 .82294 m .53903 .82332 L .53966 .82507 L F
.976 .719 .478 r
.53931 .82195 m .53946 .82208 L .53952 .82294 L F
.53891 .82157 m .53931 .82195 L .53966 .82507 L F
.324 .303 .681 r
.53931 .82195 m .53952 .82294 L .53998 .82257 L F
.484 0 0 r
.5392 .82184 m .53931 .82195 L .53898 .82164 L F
.324 .303 .681 r
.53898 .82164 m .53998 .82257 L .54092 .82183 L F
.484 0 0 r
.53898 .82164 m .53931 .82195 L .53891 .82157 L F
.426 .058 .235 r
.4138 .89284 m .41699 .89047 L .41572 .89243 L F
.469 .092 .241 r
.41699 .89047 m .41781 .89229 L .41572 .89243 L F
.41699 .89047 m .41911 .89026 L .41781 .89229 L F
.478 .262 .506 r
.51045 .87767 m .51263 .87501 L .51225 .87731 L F
.492 .272 .509 r
.51225 .87731 m .51263 .87501 L .51458 .87484 L F
.751 .664 .765 r
.50511 .82207 m .50694 .82373 L .50914 .82169 L F
.657 .479 .631 r
.40625 .87994 m .40838 .87767 L .40627 .87783 L F
.555 .226 .367 r
.44142 .88084 m .44316 .88228 L .4411 .88252 L F
.44142 .88084 m .44465 .87991 L .44316 .88228 L F
.319 .132 .463 r
.50675 .81487 m .50344 .82055 L .50454 .81624 L F
.32 0 0 r
.44875 .81809 m .45079 .81818 L .4519 .81766 L F
.337 0 0 r
.45079 .81818 m .45389 .81725 L .4519 .81766 L F
.29 0 0 r
.39714 .8984 m .39796 .89944 L .39584 .89986 L F
.39714 .8984 m .39902 .898 L .39796 .89944 L F
.476 .028 .107 r
.40833 .83778 m .40705 .83878 L .40471 .83889 L F
.394 0 .036 r
.4105 .83826 m .40833 .83778 L .40995 .83743 L F
.4105 .83826 m .40705 .83878 L .40833 .83778 L F
.731 .627 .742 r
.43887 .86742 m .44114 .86749 L .44119 .86543 L F
.726 .495 .577 r
.44111 .86989 m .44114 .86749 L .43887 .86742 L F
.652 .423 .559 r
.44111 .86989 m .44404 .86734 L .44114 .86749 L F
.289 .654 .97 r
.53192 .81715 m .53455 .8176 L .53377 .81651 L F
.443 0 0 r
.42958 .81933 m .43276 .8191 L .4311 .81965 L F
.434 .153 .386 r
.51013 .88021 m .51045 .87767 L .51225 .87731 L F
.033 0 0 r
.43809 .8198 m .4401 .81965 L .44155 .81936 L F
.113 0 0 r
.4401 .81965 m .44356 .81905 L .44155 .81936 L F
.602 .412 .597 r
.48921 .81594 m .48903 .81842 L .48686 .81852 L F
0 .161 .701 r
.48986 .81551 m .48921 .81594 L .48787 .81483 L F
.691 .463 .572 r
.48921 .81594 m .49188 .81809 L .48903 .81842 L F
.624 .355 .49 r
.49097 .81819 m .48884 .82025 L .48903 .81842 L F
.49188 .81809 m .49126 .81852 L .49097 .81819 L F
.49126 .81852 m .48884 .82025 L .49097 .81819 L F
.691 .463 .572 r
.48921 .81594 m .49126 .81852 L .49188 .81809 L F
.624 .355 .49 r
.49068 .81894 m .48882 .82043 L .48884 .82025 L F
.49188 .81809 m .49081 .8189 L .49068 .81894 L F
.49081 .8189 m .48882 .82043 L .49068 .81894 L F
.691 .463 .572 r
.49126 .81852 m .49147 .81879 L .49188 .81809 L F
.624 .355 .49 r
.49081 .8189 m .49072 .82047 L .48882 .82043 L F
0 .161 .701 r
.49144 .81873 m .49147 .81879 L .49127 .81853 L F
.49128 .81854 m .49127 .81853 L .49126 .81852 L F
.49144 .81873 m .49127 .81853 L .49128 .81854 L F
.624 .355 .49 r
.49188 .81809 m .4916 .81866 L .49144 .81871 L F
.49128 .81854 m .49144 .81871 L .49081 .8189 L F
.49188 .81809 m .49144 .81871 L .49128 .81854 L F
0 0 0 r
.49188 .81809 m .49359 .81575 L .49411 .81809 L F
.49188 .81809 m .49147 .81879 L .49359 .81575 L F
.738 .713 .828 r
.49155 .81868 m .49153 .81871 L .49152 .81869 L F
.49153 .81871 m .49147 .81879 L .49144 .81873 L F
.624 .355 .49 r
.4916 .81866 m .49072 .82047 L .49081 .8189 L F
.738 .713 .828 r
.49359 .81575 m .49155 .81868 L .48986 .81551 L F
.49155 .81868 m .49152 .81869 L .48986 .81551 L F
.49153 .81871 m .49144 .81873 L .48986 .81551 L F
0 .161 .701 r
.48986 .81551 m .49144 .81873 L .48921 .81594 L F
.49144 .81873 m .49126 .81852 L .48921 .81594 L F
.474 .131 .303 r
.42162 .88859 m .42312 .8898 L .42124 .89033 L F
.42162 .88859 m .42426 .88793 L .42312 .8898 L F
.42 .063 .25 r
.42637 .87264 m .42318 .87511 L .42623 .87449 L F
.595 .372 .547 r
.42623 .87449 m .42832 .87476 L .42637 .87264 L F
.56 .383 .599 r
.42637 .87264 m .4284 .87236 L .42844 .87003 L F
.556 .369 .583 r
.42637 .87264 m .42832 .87476 L .4284 .87236 L F
.919 .615 .135 r
.3982 .8795 m .39834 .87747 L .39723 .87722 L F
.3982 .8795 m .39881 .88056 L .39834 .87747 L F
.812 .516 .488 r
.39834 .87747 m .39881 .88056 L .4011 .88017 L F
.111 0 0 r
.44356 .81905 m .44566 .81881 L .44672 .81839 L F
.098 0 0 r
.44566 .81881 m .44875 .81809 L .44672 .81839 L F
.751 .664 .765 r
.50511 .82207 m .50914 .82169 L .50802 .82127 L F
.459 .851 .978 r
.50802 .82127 m .50914 .82169 L .51109 .8212 L F
.551 .423 .659 r
.46437 .86246 m .46616 .85969 L .4641 .86027 L F
.502 .039 .086 r
.508 .82822 m .50488 .82889 L .50691 .8283 L F
.745 .882 .942 r
.50488 .82889 m .508 .82822 L .50691 .8283 L F
.281 .016 .323 r
.50342 .88481 m .50375 .88319 L .50538 .88251 L F
.514 .329 .568 r
.51785 .82422 m .51993 .82108 L .51801 .82232 L F
.51785 .82422 m .51991 .82352 L .51993 .82108 L F
.782 .548 .582 r
.5164 .82293 m .51991 .82352 L .51993 .82108 L F
.46 .286 .558 r
.51993 .82108 m .51991 .82352 L .52161 .82071 L F
.52161 .82071 m .51991 .82352 L .51993 .82108 L F
.672 .439 .56 r
.43357 .86942 m .43571 .86972 L .43587 .86752 L F
.716 .511 .611 r
.43571 .86972 m .43887 .86742 L .43587 .86752 L F
.321 0 0 r
.38348 .82702 m .38521 .82721 L .38667 .82616 L F
.351 0 0 r
.38521 .82721 m .38868 .82595 L .38667 .82616 L F
.47 .004 .064 r
.5164 .82561 m .51785 .82422 L .51939 .82496 L F
.416 .123 .357 r
.51785 .82422 m .51991 .82352 L .51939 .82496 L F
.939 .611 .385 r
.50489 .81926 m .50477 .82069 L .50592 .81928 L F
.185 0 0 r
.50592 .81928 m .50661 .82002 L .50807 .81884 L F
.66 .496 .652 r
.44404 .86734 m .44629 .86731 L .44627 .86467 L F
.551 .423 .659 r
.46437 .86246 m .4663 .86212 L .46616 .85969 L F
.456 .144 .347 r
.46574 .86325 m .46437 .86246 L .46387 .86405 L F
.46574 .86325 m .4663 .86212 L .46437 .86246 L F
.588 .25 .364 r
.44465 .87991 m .44537 .88217 L .44316 .88228 L F
.44465 .87991 m .4464 .88002 L .44537 .88217 L F
.41 .851 .929 r
.46995 .81409 m .46615 .81451 L .46872 .81385 L F
.399 .833 .952 r
.46995 .81409 m .47089 .81344 L .47205 .81355 L F
.46995 .81409 m .46872 .81385 L .47089 .81344 L F
.579 .158 .207 r
.51203 .81367 m .50877 .81484 L .50991 .81354 L F
.597 .223 .304 r
.4319 .88495 m .43253 .88738 L .4305 .8873 L F
.4319 .88495 m .43385 .88543 L .43253 .88738 L F
.27 0 0 r
.40846 .89513 m .4121 .89335 L .4104 .89472 L F
.06 0 0 r
.4104 .89472 m .4121 .89335 L .4138 .89284 L F
.391 .518 .866 r
.3735 .79191 m .37547 .79282 L .37397 .79276 L F
.153 .28 .742 r
.48882 .82043 m .48686 .81852 L .48903 .81842 L F
.253 0 0 r
.52557 .86288 m .52359 .86322 L .52231 .86448 L F
.546 .352 .569 r
.51361 .82198 m .51453 .8243 L .5164 .82293 L F
.639 .4 .541 r
.43048 .87206 m .42844 .87003 L .4284 .87236 L F
.43048 .87206 m .43054 .87025 L .42844 .87003 L F
.514 .055 .1 r
.40853 .82261 m .4116 .82182 L .40993 .82188 L F
.632 .463 .636 r
.46616 .85969 m .46845 .85706 L .46632 .85738 L F
.144 .617 .924 r
.50436 .80536 m .50549 .80599 L .5025 .80504 L F
0 .466 .818 r
.50708 .80625 m .50549 .80599 L .50436 .80536 L F
.50708 .80625 m .50789 .80674 L .50549 .80599 L F
.156 .659 .908 r
.49228 .82232 m .49375 .82291 L .49515 .82298 L F
.443 0 0 r
.41365 .82149 m .41708 .82123 L .41513 .82157 L F
.496 .116 .249 r
.48594 .82651 m .48263 .82857 L .48245 .82626 L F
.48594 .82651 m .48497 .8284 L .48263 .82857 L F
.275 0 .137 r
.4868 .82783 m .48594 .82651 L .48825 .82648 L F
.4868 .82783 m .48497 .8284 L .48594 .82651 L F
.701 .793 .922 r
.37467 .79613 m .37382 .79473 L .37336 .79534 L F
.37467 .79613 m .37676 .79517 L .37382 .79473 L F
.289 .763 .935 r
.49614 .87339 m .49298 .87313 L .49481 .87205 L F
.191 0 0 r
.49708 .87393 m .49614 .87339 L .49481 .87205 L F
.49708 .87393 m .49814 .87322 L .49614 .87339 L F
.291 .663 .972 r
.52579 .81314 m .52886 .8142 L .52781 .8134 L F
.665 .554 .72 r
.53067 .81149 m .5312 .81364 L .52886 .8142 L F
.224 .479 .889 r
.52886 .8142 m .5299 .81374 L .52781 .8134 L F
.52886 .8142 m .53114 .81539 L .5299 .81374 L F
.216 .728 .882 r
.41708 .82123 m .41913 .82109 L .42039 .82129 L F
.173 .706 .839 r
.41913 .82109 m .42243 .82104 L .42039 .82129 L F
.716 .511 .611 r
.43571 .86972 m .43877 .86962 L .43887 .86742 L F
.726 .495 .577 r
.44111 .86989 m .43887 .86742 L .43877 .86962 L F
.404 0 .134 r
.38684 .84139 m .38344 .84338 L .38459 .84167 L F
.652 .423 .559 r
.44111 .86989 m .44393 .86904 L .44404 .86734 L F
.647 .413 .551 r
.44611 .86937 m .44404 .86734 L .44393 .86904 L F
.44611 .86937 m .44629 .86731 L .44404 .86734 L F
.164 0 0 r
.42585 .83403 m .42243 .83614 L .42215 .83567 L F
.507 .077 .157 r
.42781 .83359 m .42282 .83595 L .42585 .83403 L F
.42282 .83595 m .4227 .83597 L .42585 .83403 L F
.42781 .83359 m .42458 .83654 L .42393 .83642 L F
.42781 .83359 m .42393 .83642 L .4244 .83564 L F
.42781 .83359 m .42331 .83629 L .42282 .83595 L F
.42331 .83629 m .4233 .8363 L .42329 .83629 L F
.42331 .83629 m .42329 .83629 L .42282 .83595 L F
.42282 .83595 m .4233 .8363 L .42243 .83614 L F
.42282 .83595 m .42243 .83614 L .4227 .83597 L F
.023 0 0 r
.42215 .83567 m .42357 .83535 L .42126 .83568 L F
.42215 .83567 m .42243 .83614 L .42357 .83535 L F
.56 .287 .458 r
.42357 .83535 m .42329 .83629 L .42126 .83568 L F
.42329 .83629 m .42283 .8378 L .42155 .83608 L F
.42329 .83629 m .42155 .83608 L .42126 .83568 L F
.507 .077 .157 r
.4244 .83564 m .42393 .83642 L .4233 .8363 L F
.397 .132 .391 r
.424 .83578 m .42353 .83612 L .42341 .83587 L F
.4253 .83482 m .42457 .83569 L .42357 .83535 L F
.42457 .83569 m .42341 .83587 L .42357 .83535 L F
.535 .342 .566 r
.42243 .83614 m .4233 .8363 L .4253 .83482 L F
.4233 .8363 m .42458 .83654 L .4253 .83482 L F
.397 .132 .391 r
.42457 .83569 m .42378 .83665 L .42353 .83612 L F
.42457 .83569 m .42353 .83612 L .424 .83578 L F
0 0 0 r
.42402 .83678 m .42336 .83735 L .4253 .83482 L F
.42336 .83735 m .42283 .8378 L .42378 .83665 L F
.42336 .83735 m .42378 .83665 L .4253 .83482 L F
.397 .132 .391 r
.42378 .83665 m .42283 .8378 L .42329 .83629 L F
.42378 .83665 m .42329 .83629 L .42341 .83587 L F
.554 .177 .281 r
.45384 .87821 m .45702 .87755 L .4558 .87949 L F
.591 .249 .36 r
.45702 .87755 m .45796 .87994 L .4558 .87949 L F
.45702 .87755 m .45905 .87764 L .45796 .87994 L F
.82 .515 .473 r
.4851 .88019 m .48804 .88251 L .48635 .88296 L F
.676 .271 .27 r
.48635 .88296 m .48804 .88251 L .48666 .88399 L F
.712 .318 .299 r
.48666 .88399 m .48804 .88251 L .48968 .88429 L F
.731 .308 .244 r
.48804 .88251 m .48952 .88323 L .48968 .88429 L F
.779 .564 .608 r
.47767 .86946 m .48111 .86733 L .48 .86684 L F
.47767 .86946 m .48101 .86988 L .48111 .86733 L F
.106 0 0 r
.48474 .80847 m .48517 .80905 L .48644 .80763 L F
.48474 .80847 m .48324 .80948 L .48517 .80905 L F
.439 .133 .347 r
.52155 .86998 m .52435 .86687 L .52325 .86922 L F
.435 .039 .188 r
.52435 .86687 m .5251 .86865 L .52325 .86922 L F
.52435 .86687 m .52643 .86662 L .5251 .86865 L F
.108 .656 .82 r
.5131 .80868 m .51629 .80882 L .5142 .80874 L F
.505 .032 .065 r
.45992 .82938 m .45832 .83065 L .45628 .83033 L F
0 0 0 r
.45985 .82972 m .45992 .82938 L .46152 .82839 L F
.45985 .82972 m .45832 .83065 L .45992 .82938 L F
.619 .417 .587 r
.47581 .85499 m .47869 .85492 L .47847 .85169 L F
.399 .402 .746 r
.47847 .85169 m .47977 .85151 L .47845 .85014 L F
.376 .236 .56 r
.47847 .85169 m .47978 .85385 L .47977 .85151 L F
.399 .402 .746 r
.47847 .85169 m .47977 .85151 L .47845 .85014 L F
.022 .097 .603 r
.47978 .85385 m .47847 .85169 L .47977 .85151 L F
.218 .075 .463 r
.37284 .74976 m .37183 .74871 L .37465 .74822 L F
.477 0 .041 r
.37396 .74885 m .37447 .74888 L .37465 .74822 L F
0 0 0 r
.37574 .74792 m .37447 .74888 L .37465 .74822 L F
.477 0 .041 r
.37183 .74871 m .37396 .74885 L .37465 .74822 L F
.4 .723 .989 r
.37279 .74765 m .37426 .74873 L .37183 .74871 L F
.37426 .74873 m .37447 .74888 L .37396 .74885 L F
.37426 .74873 m .37396 .74885 L .37183 .74871 L F
.339 .176 .509 r
.37574 .74792 m .37447 .74888 L .37467 .74844 L F
0 0 0 r
.37574 .74792 m .37475 .7484 L .37465 .74822 L F
.339 .176 .509 r
.37574 .74792 m .37467 .74844 L .37588 .74574 L F
0 0 0 r
.37574 .74792 m .37478 .74845 L .37475 .7484 L F
.678 .831 .957 r
.37574 .74792 m .37447 .74888 L .37426 .74873 L F
0 0 0 r
.37481 .74851 m .37396 .74885 L .37465 .74822 L F
.678 .831 .957 r
.37574 .74792 m .37426 .74873 L .37279 .74765 L F
0 0 0 r
.37574 .74792 m .37481 .74851 L .37478 .74845 L F
.37481 .74851 m .37323 .74951 L .37396 .74885 L F
.37323 .74951 m .37284 .74976 L .37465 .74822 L F
.667 .404 .514 r
.48245 .82626 m .48263 .82857 L .48055 .82768 L F
.36 .001 .213 r
.46387 .86405 m .46196 .86453 L .46089 .86667 L F
0 0 0 r
.38006 .82793 m .38348 .82702 L .38141 .82734 L F
.563 .449 .681 r
.48028 .84652 m .48072 .84709 L .48095 .84689 L F
.572 .076 .037 r
.51632 .80882 m .51821 .8098 L .51926 .80882 L F
.678 .401 .495 r
.51821 .8098 m .52032 .81151 L .52162 .80747 L F
.52032 .81151 m .52059 .81172 L .52069 .81133 L F
.52032 .81151 m .52069 .81133 L .52162 .80747 L F
.893 .794 .744 r
.52117 .81119 m .52171 .81318 L .52319 .80991 L F
.52076 .81165 m .52171 .81318 L .52117 .81119 L F
.52047 .81197 m .52081 .8123 L .52076 .81165 L F
.52081 .8123 m .52171 .81318 L .52076 .81165 L F
.737 .682 .798 r
.5206 .80939 m .52059 .81172 L .51891 .80867 L F
.427 .86 .746 r
.52171 .81318 m .52406 .8108 L .52319 .80991 L F
.52406 .8108 m .52475 .81009 L .52319 .80991 L F
.576 .302 .464 r
.52162 .80747 m .52268 .80939 L .52319 .80991 L F
.52268 .80939 m .52331 .81054 L .52319 .80991 L F
.52069 .81133 m .52076 .81165 L .52322 .81058 L F
.52069 .81133 m .52059 .81172 L .52076 .81165 L F
.52162 .80747 m .52069 .81133 L .52117 .81118 L F
.893 .794 .744 r
.52117 .81118 m .52178 .8108 L .52185 .81098 L F
.52117 .81118 m .52185 .81098 L .52186 .81098 L F
.52117 .81119 m .52117 .81118 L .52186 .81098 L F
.52178 .8108 m .52319 .80991 L .52297 .81022 L F
.52178 .8108 m .52297 .81022 L .52256 .81081 L F
.52189 .81105 m .52256 .81081 L .52208 .81151 L F
.52178 .8108 m .52256 .81081 L .52189 .81105 L F
.576 .302 .464 r
.52271 .80944 m .52117 .81118 L .52331 .81054 L F
.52162 .80747 m .52117 .81118 L .52271 .80944 L F
.042 0 0 r
.52403 .81042 m .52208 .81151 L .52256 .81081 L F
.737 .682 .798 r
.52318 .81043 m .51891 .80867 L .52045 .80804 L F
.52331 .81054 m .52311 .81046 L .52318 .81043 L F
.042 0 0 r
.52311 .81046 m .52265 .81069 L .52319 .80991 L F
.737 .682 .798 r
.52311 .81046 m .51891 .80867 L .52318 .81043 L F
0 0 .104 r
.52319 .80991 m .52331 .81054 L .52345 .81023 L F
.042 0 0 r
.52359 .81015 m .52346 .81024 L .52345 .81023 L F
.52358 .81015 m .52345 .81023 L .52319 .80991 L F
.52359 .81015 m .52345 .81023 L .52358 .81015 L F
.832 .454 .337 r
.52162 .80747 m .52475 .81009 L .52474 .80832 L F
.52162 .80747 m .52319 .80991 L .52475 .81009 L F
.812 .349 .124 r
.5267 .80775 m .52532 .80752 L .52454 .80652 L F
.52452 .80601 m .52454 .80652 L .5235 .8052 L F
.5267 .80775 m .52454 .80652 L .52452 .80601 L F
0 0 .104 r
.52319 .80991 m .52498 .80695 L .52481 .80951 L F
.52335 .80965 m .52345 .81023 L .52457 .80784 L F
.52456 .80764 m .52457 .80784 L .52498 .80695 L F
.52335 .80965 m .52457 .80784 L .52456 .80764 L F
.52319 .80991 m .52323 .80996 L .52335 .80965 L F
.042 0 0 r
.52403 .81042 m .52319 .80991 L .52481 .80951 L F
0 0 .104 r
.52323 .80996 m .52345 .81023 L .52335 .80965 L F
.812 .349 .124 r
.5267 .80775 m .5235 .8052 L .52558 .80477 L F
.556 .374 .589 r
.52516 .80486 m .52532 .80752 L .52558 .80477 L F
.5235 .8052 m .52454 .80652 L .52516 .80486 L F
.52454 .80652 m .52532 .80752 L .52516 .80486 L F
.799 .735 .793 r
.52498 .80695 m .52345 .81023 L .52045 .80804 L F
.52345 .81023 m .52331 .81054 L .52318 .81043 L F
.042 0 0 r
.52346 .81024 m .52311 .81046 L .52319 .80991 L F
.799 .735 .793 r
.52345 .81023 m .52318 .81043 L .52045 .80804 L F
.042 0 0 r
.52311 .81046 m .52256 .81081 L .52265 .81069 L F
.737 .682 .798 r
.52331 .81054 m .52322 .81058 L .52305 .8105 L F
.52331 .81054 m .52305 .8105 L .52311 .81046 L F
.042 0 0 r
.52403 .81042 m .52256 .81081 L .52359 .81015 L F
.737 .682 .798 r
.52311 .81046 m .52305 .8105 L .5206 .80939 L F
.52322 .81058 m .52076 .81165 L .52075 .81145 L F
.576 .302 .464 r
.52069 .81133 m .52322 .81058 L .52331 .81054 L F
.737 .682 .798 r
.52322 .81058 m .52075 .81145 L .5206 .80939 L F
.52076 .81165 m .52059 .81172 L .5206 .80939 L F
.893 .794 .744 r
.52026 .81176 m .52047 .81197 L .52117 .81119 L F
.52026 .81176 m .52117 .81119 L .52208 .81151 L F
.52117 .81119 m .52186 .81098 L .52208 .81151 L F
.188 .388 .829 r
.51891 .80867 m .52007 .81077 L .51821 .8098 L F
.52007 .81077 m .52059 .81172 L .51821 .8098 L F
.572 .076 .037 r
.51629 .80882 m .51821 .8098 L .51632 .80882 L F
0 0 0 r
.48713 .81278 m .48547 .81389 L .48816 .8115 L F
.227 0 0 r
.40113 .89788 m .40464 .89524 L .40302 .89739 L F
.478 .067 .182 r
.40464 .89524 m .40495 .89715 L .40302 .89739 L F
.40464 .89524 m .40648 .89522 L .40495 .89715 L F
.508 .102 .205 r
.50232 .87455 m .50129 .87271 L .50004 .87437 L F
.50232 .87455 m .50336 .87276 L .50129 .87271 L F
.554 .177 .281 r
.45384 .87821 m .4558 .87949 L .45374 .87945 L F
.284 .783 .771 r
.47751 .81137 m .47751 .81154 L .47592 .81204 L F
.47751 .81137 m .47944 .81096 L .47751 .81154 L F
.809 .535 .524 r
.4851 .88019 m .48329 .88221 L .48317 .8802 L F
.4851 .88019 m .48635 .88296 L .48329 .88221 L F
.609 .414 .593 r
.51725 .8152 m .5154 .81599 L .51495 .81289 L F
.36 .241 .579 r
.51495 .81289 m .5154 .81599 L .51564 .81525 L F
.51495 .81289 m .51564 .81525 L .51203 .81367 L F
.609 .414 .593 r
.51725 .8152 m .51495 .81289 L .51654 .81261 L F
.601 .417 .604 r
.41049 .8774 m .41256 .8748 L .41059 .87511 L F
.915 .671 .555 r
.48139 .84883 m .48095 .84689 L .48072 .84709 L F
.732 .341 .308 r
.39881 .88056 m .39944 .88105 L .4011 .88017 L F
.316 0 0 r
.39944 .88105 m .40289 .88135 L .4011 .88017 L F
.588 .124 .121 r
.4011 .88017 m .40289 .88135 L .40323 .88049 L F
.346 .622 .954 r
.47577 .82769 m .4767 .82722 L .4738 .82625 L F
.47577 .82769 m .47712 .82775 L .4767 .82722 L F
.067 0 0 r
.46135 .81552 m .4634 .81533 L .46439 .81503 L F
0 0 0 r
.46439 .81503 m .46542 .81492 L .46615 .81451 L F
.46439 .81503 m .4634 .81533 L .46542 .81492 L F
.372 0 0 r
.39065 .82557 m .39268 .82555 L .394 .82456 L F
.385 0 0 r
.39268 .82555 m .39574 .82475 L .394 .82456 L F
.208 0 0 r
.39631 .84104 m .39391 .84134 L .39811 .84124 L F
.39631 .84104 m .39432 .84158 L .39391 .84134 L F
.054 .591 .854 r
.50548 .86679 m .50635 .86666 L .50412 .86432 L F
.50548 .86679 m .50748 .86707 L .50635 .86666 L F
.244 .553 .931 r
.50548 .86679 m .50616 .86703 L .50748 .86707 L F
.624 .354 .49 r
.43895 .88268 m .43818 .88575 L .43589 .88557 L F
.627 .404 .559 r
.4411 .88252 m .43818 .88575 L .43895 .88268 L F
.724 .421 .466 r
.47478 .87771 m .47804 .87773 L .47853 .87964 L F
.757 .444 .456 r
.47804 .87773 m .47991 .88019 L .47853 .87964 L F
.666 .326 .388 r
.40264 .83899 m .40154 .84135 L .39947 .84067 L F
.66 .319 .386 r
.40452 .84083 m .40154 .84135 L .40264 .83899 L F
.591 .332 .493 r
.40471 .83889 m .40452 .84083 L .40264 .83899 L F
.605 .617 .836 r
.53343 .813 m .53605 .81377 L .53398 .81386 L F
.4 .572 .906 r
.53728 .81608 m .53398 .81386 L .53605 .81377 L F
.171 .344 .795 r
.4306 .83321 m .43187 .83289 L .42982 .83308 L F
.4306 .83321 m .43278 .8337 L .43187 .83289 L F
.63 .175 .154 r
.48952 .88323 m .49176 .8847 L .48968 .88429 L F
.51 .011 .007 r
.50505 .87354 m .50656 .87256 L .50336 .87276 L F
0 0 0 r
.50831 .87185 m .50656 .87256 L .50505 .87354 L F
.525 .299 .515 r
.50888 .87096 m .50656 .87256 L .50831 .87185 L F
.144 .491 .904 r
.49298 .87313 m .49148 .87257 L .49068 .87138 L F
.18 0 0 r
.5286 .86241 m .52557 .86288 L .52766 .86346 L F
.657 .479 .631 r
.40625 .87994 m .40841 .88004 L .40838 .87767 L F
.597 .431 .627 r
.40838 .87767 m .40841 .88004 L .41049 .8774 L F
.657 .682 .862 r
.53806 .81384 m .53728 .81608 L .53605 .81377 L F
.53806 .81384 m .53935 .81553 L .53728 .81608 L F
.735 .496 .567 r
.53935 .81553 m .53638 .81756 L .53728 .81608 L F
.723 .376 .39 r
.41481 .87692 m .41583 .87515 L .41256 .8748 L F
.488 .166 .346 r
.41811 .87604 m .41583 .87515 L .41481 .87692 L F
.41811 .87604 m .41785 .87488 L .41583 .87515 L F
.565 0 0 r
.3723 .79198 m .37547 .79282 L .3735 .79191 L F
.4 .206 .499 r
.39278 .8802 m .3936 .87999 L .39468 .87754 L F
.359 .106 .387 r
.39258 .88098 m .3936 .87999 L .39278 .8802 L F
.5 .308 .551 r
.52461 .81491 m .52246 .81299 L .52579 .81314 L F
.182 .646 .937 r
.52579 .81314 m .52781 .8134 L .527 .81278 L F
.52579 .81314 m .527 .81278 L .52461 .81491 L F
.765 .315 .18 r
.48717 .81966 m .48588 .82037 L .48371 .8181 L F
.915 .671 .555 r
.48139 .84883 m .48072 .84709 L .48056 .84976 L F
.959 .794 .635 r
.48056 .84976 m .47977 .85151 L .48072 .84709 L F
.554 .541 .795 r
.53293 .86178 m .5307 .86216 L .53173 .86098 L F
.498 .288 .525 r
.53084 .86467 m .5307 .86216 L .53293 .86178 L F
0 .167 .705 r
.53455 .8176 m .53615 .81994 L .53727 .82102 L F
.684 .566 .716 r
.53343 .813 m .5312 .81364 L .53067 .81149 L F
.339 0 0 r
.46473 .82838 m .46605 .82891 L .46344 .82851 L F
.644 .132 .013 r
.46605 .82891 m .46475 .82862 L .46344 .82851 L F
.171 0 0 r
.46473 .82838 m .46344 .82851 L .46204 .82838 L F
.644 .132 .013 r
.46475 .82862 m .46194 .828 L .46344 .82851 L F
.171 0 0 r
.46204 .82838 m .46344 .82851 L .46152 .82839 L F
.339 0 0 r
.46473 .82838 m .46681 .82867 L .46605 .82891 L F
.57 .174 .252 r
.46662 .82833 m .46681 .82867 L .46473 .82838 L F
.951 .706 .53 r
.50592 .84065 m .50753 .83929 L .50594 .83836 L F
.597 .823 .986 r
.50916 .83862 m .50753 .83929 L .50594 .83836 L F
.50916 .83862 m .50753 .83929 L .50594 .83836 L F
.951 .706 .53 r
.50592 .84065 m .50753 .83929 L .50594 .83836 L F
0 0 0 r
.48843 .81202 m .48816 .8115 L .48947 .80976 L F
.48843 .81202 m .48713 .81278 L .48816 .8115 L F
.17 .708 .793 r
.40128 .82391 m .40336 .82364 L .40456 .82361 L F
.28 .782 .843 r
.40456 .82361 m .40527 .82324 L .40644 .82298 L F
.40456 .82361 m .40336 .82364 L .40527 .82324 L F
.612 .382 .544 r
.44611 .86937 m .44835 .8672 L .44629 .86731 L F
.459 .054 .182 r
.50807 .81884 m .51027 .81859 L .51081 .81792 L F
.497 .095 .208 r
.51081 .81792 m .51027 .81859 L .51155 .81794 L F
.383 .844 .88 r
.45944 .81633 m .45587 .81698 L .4579 .81658 L F
.448 .882 .845 r
.46135 .81552 m .45944 .81633 L .4579 .81658 L F
.491 .434 .72 r
.53235 .80984 m .53067 .81149 L .53067 .81058 L F
.684 .566 .716 r
.53343 .813 m .53067 .81149 L .53235 .80984 L F
.502 .183 .359 r
.47045 .85914 m .47259 .85902 L .47311 .85662 L F
.401 .08 .302 r
.47581 .85499 m .47311 .85662 L .47633 .85542 L F
.323 .029 .301 r
.47311 .85662 m .47421 .85833 L .47633 .85542 L F
.47311 .85662 m .47259 .85902 L .47421 .85833 L F
0 0 0 r
.43841 .83127 m .43559 .83249 L .43379 .83286 L F
.494 0 .006 r
.44038 .83128 m .43559 .83249 L .43841 .83127 L F
.709 .355 .374 r
.45044 .86954 m .45165 .86748 L .44835 .8672 L F
.632 .265 .329 r
.45346 .86908 m .45165 .86748 L .45044 .86954 L F
.58 .284 .431 r
.45346 .86908 m .4539 .86742 L .45165 .86748 L F
.525 .205 .368 r
.4464 .88002 m .44744 .88209 L .44537 .88217 L F
.4464 .88002 m .44848 .87991 L .44744 .88209 L F
.219 0 0 r
.50028 .81719 m .49942 .81633 L .5014 .81697 L F
.50028 .81719 m .49831 .81771 L .49942 .81633 L F
.516 .064 .116 r
.40995 .83743 m .4118 .83823 L .4105 .83826 L F
.632 .463 .636 r
.46616 .85969 m .46835 .85937 L .46845 .85706 L F
.714 .97 .731 r
.50661 .82002 m .50511 .82207 L .50802 .82127 L F
.50661 .82002 m .50435 .82226 L .50511 .82207 L F
.683 .303 .32 r
.49895 .80768 m .49795 .80925 L .49459 .80731 L F
.717 .411 .459 r
.49699 .80504 m .49895 .80768 L .49459 .80731 L F
.49699 .80504 m .4969 .80513 L .49803 .80502 L F
.4969 .80513 m .49459 .80731 L .49803 .80502 L F
.681 .979 .87 r
.49803 .80502 m .49459 .80731 L .49519 .80645 L F
0 0 0 r
.49866 .80496 m .49803 .80502 L .49592 .8059 L F
.299 0 0 r
.49924 .80482 m .50119 .80514 L .5025 .80504 L F
.34 0 0 r
.49924 .80482 m .49803 .80502 L .50119 .80514 L F
.54 .841 .999 r
.50119 .80514 m .49803 .80502 L .50009 .80447 L F
0 0 0 r
.50009 .80447 m .49803 .80502 L .49866 .80496 L F
.746 .577 .665 r
.49795 .80925 m .49519 .80645 L .49459 .80731 L F
0 0 .181 r
.49405 .80777 m .4946 .80772 L .49519 .80645 L F
0 .489 .849 r
.49106 .80644 m .49425 .8076 L .49405 .80777 L F
.49425 .8076 m .4946 .80772 L .49405 .80777 L F
.659 .506 .666 r
.49501 .80668 m .49431 .80756 L .49405 .80777 L F
.655 .902 .981 r
.49352 .80839 m .49517 .80818 L .49405 .80777 L F
.659 .506 .666 r
.49431 .80756 m .49284 .80939 L .49405 .80777 L F
.521 .127 .234 r
.49106 .80644 m .49377 .80766 L .49421 .80769 L F
.659 .506 .666 r
.49423 .80765 m .4952 .80933 L .49284 .80939 L F
.521 .127 .234 r
.49425 .8076 m .49423 .80765 L .4946 .80772 L F
.49423 .80765 m .49441 .80771 L .4946 .80772 L F
.659 .506 .666 r
.49519 .80645 m .49519 .80799 L .49423 .80765 L F
.49519 .80799 m .4952 .80933 L .49423 .80765 L F
.521 .127 .234 r
.49423 .80765 m .49421 .80769 L .49441 .80771 L F
.49106 .80644 m .49421 .80769 L .49425 .8076 L F
.659 .506 .666 r
.49519 .80645 m .49501 .80668 L .49431 .80748 L F
.49431 .80747 m .49431 .80748 L .49405 .80777 L F
.49519 .80645 m .49431 .80748 L .49431 .80747 L F
.655 .902 .981 r
.492 .80857 m .49352 .80839 L .49405 .80777 L F
.571 .303 .471 r
.43048 .87206 m .43357 .86942 L .43054 .87025 L F
0 0 0 r
.49699 .80504 m .49803 .80502 L .49924 .80482 L F
.39574 .82475 m .39794 .82449 L .39938 .82428 L F
.501 0 0 r
.39794 .82449 m .40128 .82391 L .39938 .82428 L F
.639 .49 .665 r
.46616 .85969 m .4663 .86212 L .46835 .85937 L F
.724 .425 .472 r
.40289 .88135 m .40625 .87994 L .40323 .88049 L F
.709 .404 .46 r
.46961 .87739 m .47295 .87731 L .47158 .87968 L F
.67 .344 .413 r
.47295 .87731 m .47512 .87942 L .47158 .87968 L F
.47295 .87731 m .47478 .87771 L .47512 .87942 L F
.507 .15 .295 r
.42426 .88793 m .42516 .8896 L .42312 .8898 L F
.42426 .88793 m .42626 .88767 L .42516 .8896 L F
.786 .601 .651 r
.5267 .80775 m .53067 .81058 L .5288 .8075 L F
.5267 .80775 m .52705 .81076 L .53067 .81058 L F
.503 .077 .164 r
.527 .81278 m .53067 .81058 L .52705 .81076 L F
.527 .81278 m .52869 .81244 L .53067 .81058 L F
.539 .892 .978 r
.53235 .80984 m .53067 .81058 L .53088 .80953 L F
0 0 0 r
.53067 .81058 m .53082 .81155 L .53088 .80953 L F
.53067 .81058 m .52869 .81244 L .53082 .81155 L F
.355 0 0 r
.41544 .8368 m .4139 .83805 L .4118 .83823 L F
.213 0 0 r
.41577 .83769 m .41544 .8368 L .41741 .83637 L F
.41577 .83769 m .4139 .83805 L .41544 .8368 L F
.707 .383 .427 r
.48369 .87229 m .48434 .87006 L .48101 .86988 L F
.552 .235 .385 r
.4859 .87204 m .48434 .87006 L .48369 .87229 L F
.4859 .87204 m .48688 .87018 L .48434 .87006 L F
.302 0 0 r
.50661 .82002 m .50992 .82042 L .50807 .81884 L F
.561 .29 .463 r
.50807 .81884 m .50992 .82042 L .51027 .81859 L F
.775 .742 .823 r
.49228 .82232 m .48988 .82554 L .49258 .82562 L F
.793 .651 .706 r
.48988 .82554 m .4911 .82845 L .49258 .82562 L F
.784 .748 .82 r
.49228 .82232 m .49258 .82562 L .49515 .82298 L F
.724 .425 .472 r
.40289 .88135 m .4051 .8823 L .40625 .87994 L F
.638 .351 .466 r
.4079 .88161 m .40625 .87994 L .4051 .8823 L F
.4079 .88161 m .40841 .88004 L .40625 .87994 L F
.286 .777 .716 r
.52052 .81366 m .52246 .81299 L .52171 .81318 L F
.782 .647 .714 r
.52246 .81299 m .52047 .81564 L .52052 .81366 L F
.286 .777 .716 r
.52052 .81366 m .52246 .81299 L .52171 .81318 L F
.427 .86 .746 r
.52171 .81318 m .52246 .81299 L .52351 .81227 L F
.52351 .81227 m .52246 .81299 L .52171 .81318 L F
.5 .308 .551 r
.52461 .81491 m .52272 .81564 L .52246 .81299 L F
0 .247 .682 r
.50169 .80956 m .49895 .80768 L .50004 .80858 L F
.50169 .80956 m .50229 .80975 L .49895 .80768 L F
0 0 0 r
.50287 .80922 m .50229 .80975 L .50169 .80956 L F
.328 0 .115 r
.50169 .80956 m .5012 .81193 L .50236 .81114 L F
.589 .625 .855 r
.53417 .80961 m .53343 .813 L .53235 .80984 L F
.53417 .80961 m .53596 .81279 L .53343 .813 L F
.588 .627 .858 r
.53596 .81279 m .53605 .81377 L .53343 .813 L F
.49 .033 .094 r
.41911 .89026 m .41963 .89188 L .41781 .89229 L F
.41911 .89026 m .42124 .89033 L .41963 .89188 L F
.792 .674 .734 r
.37382 .79473 m .37676 .79517 L .37547 .79282 L F
.634 .296 .382 r
.45796 .87994 m .45905 .87764 L .4611 .87935 L F
.636 .295 .378 r
.45905 .87764 m .46218 .87757 L .4611 .87935 L F
.532 .053 .064 r
.44366 .83098 m .44323 .83277 L .44038 .83128 L F
.15 0 0 r
.44422 .83203 m .44366 .83098 L .44568 .83088 L F
.271 0 0 r
.44772 .83104 m .44632 .83189 L .44422 .83203 L F
.121 .671 .79 r
.44632 .83189 m .44497 .83194 L .44422 .83203 L F
.15 0 0 r
.44422 .83203 m .44339 .83212 L .44366 .83098 L F
.121 .671 .79 r
.44497 .83194 m .44317 .832 L .44422 .83203 L F
.15 0 0 r
.44422 .83203 m .44323 .83277 L .44339 .83212 L F
.544 .164 .271 r
.46956 .82817 m .46681 .82867 L .46662 .82833 L F
.571 .303 .471 r
.43048 .87206 m .43238 .87207 L .43357 .86942 L F
.669 .406 .513 r
.4357 .87142 m .43357 .86942 L .43238 .87207 L F
.4357 .87142 m .43571 .86972 L .43357 .86942 L F
.879 .924 .85 r
.50381 .81088 m .50174 .81344 L .50064 .8129 L F
.443 0 0 r
.42958 .81933 m .43163 .81971 L .43276 .8191 L F
.28 0 0 r
.43163 .81971 m .43488 .81943 L .43276 .8191 L F
.448 .094 .271 r
.52643 .86662 m .52908 .86515 L .52829 .86651 L F
.323 0 .234 r
.52829 .86651 m .52908 .86515 L .53084 .86467 L F
0 .167 .705 r
.53455 .8176 m .53727 .82102 L .53777 .81821 L F
.735 .496 .567 r
.53935 .81553 m .53892 .81847 L .53638 .81756 L F
.282 .118 .474 r
.53892 .81847 m .53727 .82102 L .53891 .81931 L F
.736 .358 .335 r
.53638 .81756 m .53892 .81847 L .53891 .81931 L F
.278 .465 .864 r
.53638 .81756 m .53891 .81931 L .53766 .81721 L F
.53638 .81756 m .53766 .81721 L .53738 .81674 L F
.292 .716 .971 r
.53455 .8176 m .53552 .81779 L .53638 .81756 L F
.53552 .81779 m .53777 .81821 L .53638 .81756 L F
.246 0 0 r
.50119 .80514 m .50436 .80536 L .5025 .80504 L F
.508 .265 .482 r
.51458 .87484 m .51699 .87233 L .5162 .87397 L F
.433 .169 .413 r
.5162 .87397 m .51699 .87233 L .51882 .87177 L F
.392 0 .103 r
.51826 .86517 m .51494 .86709 L .51685 .86681 L F
.19 0 0 r
.52019 .86452 m .51826 .86517 L .51685 .86681 L F
.692 .454 .558 r
.47633 .85542 m .47869 .85492 L .47581 .85499 L F
.432 .24 .518 r
.39468 .87754 m .3936 .87999 L .39443 .87986 L F
.39468 .87754 m .39443 .87986 L .39339 .87701 L F
.111 0 0 r
.39339 .87701 m .39723 .87722 L .39468 .87754 L F
.519 .319 .548 r
.37183 .74871 m .37065 .74923 L .37021 .74866 L F
.37183 .74871 m .36976 .75133 L .3717 .75089 L F
.3717 .75089 m .36976 .75133 L .37183 .74871 L F
.37183 .74871 m .3717 .75089 L .37065 .74923 L F
.4 .723 .989 r
.37279 .74765 m .37183 .74871 L .37021 .74866 L F
.218 .075 .463 r
.37284 .74976 m .3717 .75089 L .37183 .74871 L F
.396 .07 .292 r
.50831 .87185 m .51086 .87009 L .50888 .87096 L F
.313 0 .011 r
.39796 .89944 m .39902 .898 L .40113 .89788 L F
.228 0 0 r
.50691 .8283 m .51015 .82861 L .50907 .82864 L F
.50691 .8283 m .51015 .82861 L .50907 .82864 L F
.266 .771 .859 r
.51118 .8282 m .51015 .82861 L .50907 .82864 L F
.51118 .8282 m .51218 .82825 L .51015 .82861 L F
.51118 .8282 m .51015 .82861 L .50907 .82864 L F
.51118 .8282 m .51218 .82825 L .51015 .82861 L F
.369 0 0 r
.44921 .83062 m .44772 .83104 L .44568 .83088 L F
.309 0 0 r
.45094 .83073 m .44772 .83104 L .44921 .83062 L F
.442 .666 .957 r
.48047 .82228 m .47942 .82313 L .47812 .82203 L F
.631 .37 .504 r
.47942 .82313 m .48161 .82575 L .4823 .82356 L F
.231 .279 .707 r
.48047 .82228 m .48161 .82575 L .47942 .82313 L F
.113 0 0 r
.4401 .81965 m .44211 .81951 L .44356 .81905 L F
.002 0 0 r
.44356 .81905 m .4441 .8192 L .44566 .81881 L F
.44356 .81905 m .44211 .81951 L .4441 .8192 L F
.404 0 .134 r
.38684 .84139 m .38542 .84318 L .38344 .84338 L F
.607 .196 .239 r
.38882 .84198 m .38542 .84318 L .38684 .84139 L F
.558 .361 .569 r
.42832 .87476 m .43048 .87206 L .4284 .87236 L F
.662 .413 .533 r
.46218 .87757 m .46396 .87909 L .4611 .87935 L F
.46218 .87757 m .46433 .87746 L .46396 .87909 L F
.839 .702 .169 r
.51226 .8177 m .51155 .81794 L .51027 .81859 L F
.51226 .8177 m .51233 .81979 L .51155 .81794 L F
.644 .493 .664 r
.48619 .85432 m .48864 .85373 L .48826 .85172 L F
.736 .625 .735 r
.48864 .85373 m .48611 .85671 L .48619 .85432 L F
.48864 .85373 m .48947 .85695 L .48611 .85671 L F
.193 .115 .533 r
.48619 .85432 m .48761 .85591 L .48864 .85373 L F
.48619 .85432 m .48611 .85671 L .48761 .85591 L F
.644 .493 .664 r
.48619 .85432 m .48864 .85373 L .48826 .85172 L F
.579 .158 .207 r
.51203 .81367 m .51078 .81517 L .50877 .81484 L F
.712 .319 .303 r
.51564 .81525 m .51078 .81517 L .51203 .81367 L F
.58 .197 .281 r
.42486 .87656 m .42623 .87449 L .42318 .87511 L F
.549 .14 .219 r
.42702 .87649 m .42623 .87449 L .42486 .87656 L F
.42702 .87649 m .42832 .87476 L .42623 .87449 L F
.463 .878 .938 r
.47205 .81355 m .47296 .81281 L .47387 .81252 L F
.47205 .81355 m .47089 .81344 L .47296 .81281 L F
.684 .304 .321 r
.48611 .85671 m .48947 .85695 L .48841 .85887 L F
.471 .456 .759 r
.49062 .85611 m .48947 .85695 L .48864 .85373 L F
0 0 0 r
.48841 .85887 m .48947 .85695 L .49062 .85611 L F
.692 .41 .491 r
.43783 .87221 m .43877 .86962 L .43571 .86972 L F
.649 .364 .474 r
.43783 .87221 m .44065 .87141 L .43877 .86962 L F
.68 .355 .418 r
.44065 .87141 m .44111 .86989 L .43877 .86962 L F
.12 .67 .74 r
.45457 .83032 m .45297 .83047 L .45094 .83073 L F
.08 0 0 r
.45628 .83033 m .45297 .83047 L .45457 .83032 L F
0 0 0 r
.38006 .82793 m .38205 .82748 L .38348 .82702 L F
.501 0 0 r
.38205 .82748 m .38521 .82721 L .38348 .82702 L F
.098 0 0 r
.44566 .81881 m .44767 .81853 L .44875 .81809 L F
.083 0 0 r
.44875 .81809 m .44956 .81828 L .45079 .81818 L F
.44875 .81809 m .44767 .81853 L .44956 .81828 L F
.473 .008 .067 r
.39211 .84133 m .39092 .8426 L .38882 .84198 L F
.662 .265 .283 r
.39402 .8425 m .39211 .84133 L .39432 .84158 L F
.39402 .8425 m .39092 .8426 L .39211 .84133 L F
.559 .801 .989 r
.46891 .82643 m .47196 .82654 L .47233 .82586 L F
.716 .534 .642 r
.46891 .82643 m .46956 .82817 L .47196 .82654 L F
.668 .862 .47 r
.47233 .82586 m .47196 .82654 L .47241 .82566 L F
.471 .792 .999 r
.47196 .82654 m .4738 .82625 L .47241 .82566 L F
.216 0 .033 r
.492 .80857 m .491 .81002 L .48947 .80976 L F
.216 0 .114 r
.491 .81002 m .48843 .81202 L .48947 .80976 L F
.528 .138 .246 r
.43385 .88543 m .43468 .88744 L .43253 .88738 L F
.43385 .88543 m .43589 .88557 L .43468 .88744 L F
.592 .49 .707 r
.62202 .75122 m .62307 .74818 L .62123 .74854 L F
.351 0 0 r
.38521 .82721 m .38721 .82712 L .38868 .82595 L F
.447 .004 .101 r
.38721 .82712 m .39065 .82557 L .38868 .82595 L F
.334 0 0 r
.42639 .82017 m .42958 .81933 L .42764 .81966 L F
.456 .366 .665 r
.48826 .85172 m .48864 .85373 L .4903 .85371 L F
.4903 .85371 m .48864 .85373 L .48826 .85172 L F
.434 0 0 r
.50789 .80674 m .50965 .80759 L .51088 .80793 L F
0 .419 .753 r
.51168 .80805 m .51088 .80793 L .50965 .80759 L F
.51168 .80805 m .5131 .80868 L .51088 .80793 L F
.087 0 0 r
.42035 .83602 m .41942 .83627 L .41741 .83637 L F
.245 .76 .822 r
.42215 .83567 m .42126 .83568 L .42035 .83602 L F
.25 .755 .718 r
.42126 .83568 m .41942 .83627 L .42035 .83602 L F
.784 .629 .689 r
.49411 .81809 m .49072 .82047 L .49188 .81809 L F
.739 .39 .39 r
.47478 .87771 m .47664 .87997 L .47512 .87942 L F
.724 .421 .466 r
.47478 .87771 m .47853 .87964 L .47664 .87997 L F
.585 .277 .414 r
.44287 .87157 m .44111 .86989 L .44065 .87141 L F
.44287 .87157 m .44393 .86904 L .44111 .86989 L F
.619 .261 .34 r
.44496 .87143 m .44393 .86904 L .44287 .87157 L F
.44496 .87143 m .44611 .86937 L .44393 .86904 L F
.429 0 .031 r
.46724 .86346 m .4663 .86212 L .46574 .86325 L F
.46724 .86346 m .46855 .8621 L .4663 .86212 L F
.588 .423 .625 r
.4663 .86212 m .46855 .8621 L .46835 .85937 L F
.504 .527 .813 r
.49072 .82047 m .49004 .82235 L .48882 .82043 L F
.49072 .82047 m .49228 .82232 L .49004 .82235 L F
.49072 .82047 m .49228 .82232 L .49004 .82235 L F
.556 .312 .502 r
.46396 .87909 m .46433 .87746 L .46645 .87915 L F
.631 .276 .351 r
.46433 .87746 m .46632 .87776 L .46645 .87915 L F
.459 .851 .978 r
.50802 .82127 m .51109 .8212 L .50992 .82042 L F
.843 .878 .866 r
.50992 .82042 m .51109 .8212 L .51233 .81979 L F
.239 .74 .9 r
.50971 .86272 m .50658 .86265 L .50837 .86159 L F
.967 .711 .496 r
.50856 .86466 m .50971 .86272 L .50837 .86159 L F
.50856 .86466 m .50998 .86511 L .50971 .86272 L F
.741 .352 .315 r
.51841 .82509 m .51991 .82352 L .5164 .82293 L F
.971 .752 .55 r
.51939 .82496 m .51991 .82352 L .51841 .82509 L F
.499 .551 .841 r
.48055 .82768 m .48161 .82575 L .47935 .82729 L F
.48055 .82768 m .48263 .82857 L .48161 .82575 L F
.601 .417 .604 r
.41049 .8774 m .41266 .87711 L .41256 .8748 L F
.723 .376 .39 r
.41481 .87692 m .41256 .8748 L .41266 .87711 L F
.516 .214 .393 r
.47233 .82586 m .47061 .82786 L .46891 .82643 L F
.188 .234 .679 r
.46891 .82643 m .47061 .82786 L .46956 .82817 L F
.648 .408 .541 r
.40705 .83878 m .40452 .84083 L .40471 .83889 L F
.595 .341 .503 r
.39231 .88236 m .39427 .88221 L .39258 .88098 L F
.588 .385 .574 r
.39427 .88221 m .3936 .87999 L .39258 .88098 L F
.39427 .88221 m .3936 .87999 L .39258 .88098 L F
.434 .153 .386 r
.51013 .88021 m .51225 .87731 L .51147 .87918 L F
.492 .272 .509 r
.51225 .87731 m .51458 .87484 L .51425 .87725 L F
.305 0 .209 r
.51147 .87918 m .51225 .87731 L .51425 .87725 L F
.722 .193 0 r
.48371 .8181 m .4844 .81957 L .48265 .81752 L F
.48371 .8181 m .48588 .82037 L .4844 .81957 L F
.612 .382 .544 r
.44611 .86937 m .44831 .86947 L .44835 .8672 L F
.709 .355 .374 r
.45044 .86954 m .44835 .8672 L .44831 .86947 L F
.443 0 0 r
.41365 .82149 m .41559 .82206 L .41708 .82123 L F
.518 .045 .07 r
.41559 .82206 m .41913 .82109 L .41708 .82123 L F
.419 0 .083 r
.40648 .89522 m .40689 .89682 L .40495 .89715 L F
.40648 .89522 m .40846 .89513 L .40689 .89682 L F
.337 0 0 r
.45079 .81818 m .45293 .81803 L .45389 .81725 L F
.133 0 0 r
.45389 .81725 m .45486 .81752 L .45587 .81698 L F
.45389 .81725 m .45293 .81803 L .45486 .81752 L F
.627 .49 .676 r
.53806 .81384 m .54073 .8143 L .53935 .81553 L F
.54015 .81534 m .54122 .8161 L .54073 .8143 L F
0 0 .258 r
.54049 .81513 m .54021 .81523 L .54073 .8143 L F
.54021 .81523 m .53935 .81553 L .54073 .8143 L F
.627 .49 .676 r
.53806 .81384 m .54015 .81534 L .54073 .8143 L F
.232 .238 .66 r
.54073 .8143 m .54122 .8161 L .54208 .81456 L F
.488 .558 .854 r
.54208 .81456 m .54122 .8161 L .54065 .81511 L F
.286 .046 .363 r
.54148 .81479 m .54073 .8143 L .54208 .81456 L F
.54049 .81513 m .54073 .8143 L .54173 .81496 L F
.488 .558 .854 r
.54208 .81456 m .54065 .81511 L .53901 .81226 L F
.286 .046 .363 r
.54173 .81496 m .54148 .81479 L .54208 .81456 L F
.363 .49 .853 r
.54049 .81513 m .54122 .8161 L .54015 .81534 L F
.54065 .81511 m .54122 .8161 L .54049 .81513 L F
.286 .046 .363 r
.53995 .81695 m .54049 .81513 L .54173 .81496 L F
.363 .49 .853 r
.54061 .81505 m .54065 .81511 L .54049 .81513 L F
.53901 .81226 m .54061 .81505 L .53806 .81384 L F
.54061 .81505 m .54015 .81534 L .53806 .81384 L F
0 0 .258 r
.53995 .81695 m .53945 .81577 L .54049 .81513 L F
.53945 .81577 m .53935 .81553 L .54049 .81513 L F
.53995 .81695 m .53892 .81847 L .53935 .81553 L F
.66 .22 .195 r
.49505 .88471 m .49818 .88485 L .49697 .88552 L F
.471 .005 .065 r
.49818 .88485 m .49901 .8863 L .49697 .88552 L F
.49818 .88485 m .50026 .88498 L .49901 .8863 L F
.772 .496 .517 r
.48104 .87192 m .48101 .86988 L .47767 .86946 L F
.707 .383 .427 r
.48369 .87229 m .48101 .86988 L .48104 .87192 L F
.505 .099 .204 r
.50505 .87354 m .50336 .87276 L .50232 .87455 L F
.397 0 .053 r
.52643 .86662 m .52707 .8682 L .5251 .86865 L F
.52643 .86662 m .52829 .86651 L .52707 .8682 L F
.74 .462 .509 r
.47991 .88019 m .48317 .8802 L .48329 .88221 L F
.692 .41 .491 r
.43783 .87221 m .43571 .86972 L .4357 .87142 L F
.173 .706 .839 r
.42042 .82107 m .42121 .82093 L .42243 .82104 L F
.337 0 0 r
.41967 .82142 m .42207 .82078 L .42121 .82093 L F
.371 .83 .915 r
.42243 .82104 m .42121 .82093 L .42327 .82046 L F
.337 0 0 r
.42207 .82078 m .42327 .82046 L .42121 .82093 L F
.173 .706 .839 r
.41913 .82109 m .42121 .82093 L .42042 .82107 L F
.371 .83 .915 r
.42243 .82104 m .42327 .82046 L .4244 .82056 L F
.505 .561 .847 r
.53764 .81217 m .53605 .81377 L .53596 .81279 L F
.531 .605 .872 r
.53764 .81217 m .53806 .81384 L .53605 .81377 L F
.525 .097 .171 r
.40913 .88187 m .40841 .88004 L .4079 .88161 L F
.40913 .88187 m .41062 .88019 L .40841 .88004 L F
.607 .444 .635 r
.40841 .88004 m .41062 .88019 L .41049 .8774 L F
.609 .079 0 r
.50004 .87437 m .49814 .87322 L .49708 .87393 L F
.302 0 .211 r
.51458 .87484 m .51537 .87641 L .51425 .87725 L F
.51458 .87484 m .5162 .87397 L .51537 .87641 L F
.108 .656 .82 r
.5131 .80868 m .51581 .80863 L .51629 .80882 L F
0 .315 .744 r
.51715 .80899 m .51629 .80882 L .51581 .80863 L F
.51715 .80899 m .51821 .8098 L .51629 .80882 L F
.733 .616 .728 r
.46855 .8621 m .47045 .85914 L .46835 .85937 L F
0 0 0 r
.42865 .83367 m .42781 .83359 L .42982 .83308 L F
.42865 .83367 m .42458 .83654 L .42781 .83359 L F
.749 .743 .847 r
.47582 .84327 m .47343 .84427 L .4721 .8433 L F
.47582 .84327 m .47343 .84427 L .4721 .8433 L F
.771 .837 .902 r
.49614 .81585 m .49359 .81575 L .49546 .81472 L F
.52 .294 .512 r
.49614 .81585 m .49411 .81809 L .49359 .81575 L F
.49614 .81585 m .49615 .8178 L .49411 .81809 L F
.587 .753 .957 r
.4975 .81429 m .49614 .81585 L .49546 .81472 L F
.618 .553 .759 r
.4975 .81429 m .49615 .8178 L .49614 .81585 L F
.253 0 0 r
.52557 .86288 m .52231 .86448 L .52422 .86395 L F
.467 0 .012 r
.52766 .86346 m .52557 .86288 L .52422 .86395 L F
.519 .097 .18 r
.47953 .86255 m .4764 .86374 L .47871 .86362 L F
.214 .441 .864 r
.48216 .86452 m .47953 .86255 L .48209 .86183 L F
.419 .013 .161 r
.48149 .8631 m .47953 .86255 L .47871 .86362 L F
.48149 .8631 m .48209 .86183 L .47953 .86255 L F
.359 .703 .984 r
.53377 .81651 m .53455 .8176 L .53638 .81756 L F
.762 .657 .746 r
.51725 .8152 m .51847 .81823 L .5152 .81804 L F
.328 0 0 r
.51847 .81823 m .51749 .81843 L .5152 .81804 L F
.757 .655 .749 r
.52047 .81564 m .51847 .81823 L .51725 .8152 L F
0 0 0 r
.52047 .81564 m .51956 .81778 L .51847 .81823 L F
.292 .787 .763 r
.51847 .81823 m .51956 .81778 L .51749 .81843 L F
.501 .101 .214 r
.48517 .80905 m .48844 .80703 L .48644 .80763 L F
.544 .396 .629 r
.41049 .8774 m .41262 .87984 L .41266 .87711 L F
.41049 .8774 m .41062 .88019 L .41262 .87984 L F
.649 .317 .396 r
.46632 .87776 m .46961 .87739 L .46827 .87962 L F
.721 .403 .44 r
.46961 .87739 m .47158 .87968 L .46827 .87962 L F
.454 .317 .605 r
.3936 .87999 m .39452 .88225 L .39443 .87986 L F
.588 .385 .574 r
.39427 .88221 m .39452 .88225 L .3936 .87999 L F
.39427 .88221 m .39452 .88225 L .3936 .87999 L F
.762 .631 .716 r
.52052 .81366 m .52047 .81564 L .51725 .8152 L F
.442 .054 .207 r
.52272 .81564 m .51956 .81778 L .52047 .81564 L F
.753 .687 .788 r
.46941 .86452 m .47237 .86278 L .47125 .86213 L F
.641 .522 .703 r
.46941 .86452 m .47168 .86511 L .47152 .86397 L F
.563 .304 .482 r
.47206 .86383 m .47237 .86278 L .47069 .86377 L F
.47105 .86409 m .47069 .86377 L .46941 .86452 L F
.47206 .86383 m .47069 .86377 L .47105 .86409 L F
.641 .522 .703 r
.46941 .86452 m .47152 .86397 L .47125 .86213 L F
.099 .269 .75 r
.47178 .86475 m .47168 .86511 L .47144 .86444 L F
.656 .275 .311 r
.47132 .86626 m .47168 .86511 L .46941 .86452 L F
.88 .528 .377 r
.47132 .86626 m .47168 .86511 L .47114 .86518 L F
.563 .304 .482 r
.47114 .86518 m .47206 .86383 L .47097 .86412 L F
.47132 .86626 m .47097 .86412 L .46941 .86452 L F
.733 .616 .728 r
.46855 .8621 m .47125 .86213 L .47045 .85914 L F
.501 .827 .999 r
.47042 .8616 m .47125 .86213 L .46855 .8621 L F
.099 .269 .75 r
.47218 .86334 m .47178 .86475 L .47042 .8616 L F
.563 .304 .482 r
.47178 .86475 m .47206 .86383 L .47114 .86518 L F
.099 .269 .75 r
.47178 .86475 m .47144 .86444 L .47042 .8616 L F
.786 .981 .905 r
.47048 .86527 m .47114 .86518 L .47218 .86334 L F
.47114 .86518 m .47168 .86511 L .47178 .86475 L F
.47114 .86518 m .47178 .86475 L .47218 .86334 L F
.88 .528 .377 r
.47132 .86626 m .47168 .86511 L .47048 .86527 L F
.563 .304 .482 r
.47132 .86626 m .47178 .86475 L .47114 .86518 L F
.88 .528 .377 r
.47132 .86626 m .47114 .86518 L .47048 .86527 L F
.517 .574 .852 r
.47237 .86278 m .4735 .86205 L .47125 .86213 L F
.47237 .86278 m .47472 .86447 L .4735 .86205 L F
.795 .488 .469 r
.4736 .86607 m .47237 .86278 L .47132 .86626 L F
.4736 .86607 m .47472 .86447 L .47237 .86278 L F
.611 .312 .438 r
.45346 .86908 m .45658 .86677 L .4539 .86742 L F
.45346 .86908 m .45571 .86931 L .45658 .86677 L F
.504 .169 .333 r
.45571 .86931 m .45878 .86684 L .45658 .86677 L F
0 0 0 r
.48835 .82667 m .48825 .82648 L .48988 .82554 L F
.48835 .82667 m .4868 .82783 L .48825 .82648 L F
.501 .151 .305 r
.42626 .88767 m .4272 .88959 L .42516 .8896 L F
.42626 .88767 m .42847 .8872 L .4272 .88959 L F
.691 .326 .351 r
.42261 .87646 m .42318 .87511 L .42094 .87475 L F
.58 .197 .281 r
.42486 .87656 m .42318 .87511 L .42261 .87646 L F
.746 .708 .816 r
.51813 .81342 m .52052 .81366 L .51898 .81288 L F
.66 .339 .418 r
.42094 .87475 m .41785 .87488 L .41973 .87686 L F
.391 0 0 r
.41973 .87686 m .42261 .87646 L .42094 .87475 L F
0 0 0 r
.50537 .86371 m .50658 .86265 L .50412 .86432 L F
.226 .312 .743 r
.50412 .86432 m .50635 .86666 L .50537 .86371 L F
.06 0 0 r
.4104 .89472 m .4138 .89284 L .41251 .89419 L F
.237 0 0 r
.41251 .89419 m .4138 .89284 L .41572 .89243 L F
.773 .521 .554 r
.51813 .81342 m .51898 .81288 L .51654 .81261 L F
.373 .12 .396 r
.51328 .86729 m .51086 .87009 L .51292 .86957 L F
.458 .247 .504 r
.51494 .86709 m .51328 .86729 L .51292 .86957 L F
.753 .321 .224 r
.48329 .88221 m .48635 .88296 L .48666 .88399 L F
.6 .397 .578 r
.48409 .85922 m .4862 .85925 L .48611 .85671 L F
.48409 .85922 m .4862 .85925 L .48611 .85671 L F
.524 .338 .571 r
.48611 .85671 m .48841 .85887 L .48761 .85591 L F
.48611 .85671 m .4862 .85925 L .48841 .85887 L F
.684 .304 .321 r
.48611 .85671 m .48841 .85887 L .4862 .85925 L F
.36 .001 .213 r
.46387 .86405 m .46089 .86667 L .46308 .86647 L F
.389 .084 .323 r
.46387 .86405 m .46489 .86604 L .46574 .86325 L F
.46387 .86405 m .46308 .86647 L .46489 .86604 L F
.448 .882 .845 r
.46135 .81552 m .4579 .81658 L .45977 .81591 L F
.28 0 0 r
.45977 .81591 m .4634 .81533 L .46135 .81552 L F
.843 .878 .866 r
.50992 .82042 m .51233 .81979 L .51212 .82019 L F
.839 .702 .169 r
.51226 .8177 m .51212 .82019 L .51233 .81979 L F
.443 0 0 r
.46681 .82867 m .46742 .82933 L .46605 .82891 L F
.46681 .82867 m .46915 .83003 L .46742 .82933 L F
.565 .205 .316 r
.46956 .82817 m .46915 .83003 L .46681 .82867 L F
.514 .055 .1 r
.40853 .82261 m .41055 .82288 L .4116 .82182 L F
.784 .629 .689 r
.49411 .81809 m .49239 .82085 L .49072 .82047 L F
.747 .579 .666 r
.49411 .81809 m .49417 .82117 L .49239 .82085 L F
.727 .562 .668 r
.49777 .82098 m .49411 .81809 L .49615 .8178 L F
.49777 .82098 m .49417 .82117 L .49411 .81809 L F
.471 .456 .759 r
.49062 .85611 m .48864 .85373 L .4903 .85371 L F
.394 .044 .248 r
.4903 .85371 m .48864 .85373 L .48761 .85591 L F
.739 .683 .796 r
.4735 .86205 m .47472 .86447 L .47446 .86187 L F
.182 0 .065 r
.4764 .86374 m .47472 .86447 L .4736 .86607 L F
.57 .556 .799 r
.47446 .86187 m .47472 .86447 L .4764 .86374 L F
.196 .68 .928 r
.46152 .82839 m .46194 .828 L .45985 .82972 L F
.46152 .82839 m .46344 .82851 L .46194 .828 L F
.059 0 .183 r
.418 .87745 m .41811 .87604 L .41667 .87935 L F
.41892 .87614 m .41811 .87604 L .418 .87745 L F
.723 .319 .282 r
.41973 .87686 m .41817 .87522 L .41811 .87604 L F
.41817 .87522 m .41785 .87488 L .41811 .87604 L F
.849 .792 .796 r
.50319 .81705 m .50344 .82055 L .50675 .81487 L F
.666 .658 .833 r
.47592 .82271 m .4761 .82278 L .47804 .82135 L F
.399 .578 .912 r
.5299 .81374 m .53114 .81539 L .53227 .81424 L F
.317 .445 .833 r
.53227 .81424 m .53114 .81539 L .53377 .81651 L F
.532 .328 .55 r
.50342 .88481 m .50538 .88251 L .50499 .88481 L F
.468 .272 .53 r
.50499 .88481 m .50538 .88251 L .50705 .88196 L F
.82 .932 .905 r
.50748 .86707 m .50998 .86511 L .50856 .86466 L F
.33 0 .212 r
.51016 .87129 m .51086 .87009 L .50831 .87185 L F
.395 .047 .252 r
.51292 .86957 m .51086 .87009 L .51016 .87129 L F
.166 0 0 r
.41963 .89188 m .42124 .89033 L .42312 .8898 L F
.67 .518 .67 r
.52475 .81009 m .52705 .81076 L .5267 .80775 L F
.587 .557 .788 r
.52766 .80429 m .5267 .80775 L .52558 .80477 L F
.52766 .80429 m .5288 .8075 L .5267 .80775 L F
.233 0 0 r
.5267 .80775 m .5278 .8083 L .52532 .80752 L F
.5267 .80775 m .5288 .8075 L .5278 .8083 L F
.582 .266 .398 r
.44744 .88209 m .44848 .87991 L .45021 .88162 L F
.617 .259 .342 r
.44848 .87991 m .45063 .88023 L .45021 .88162 L F
0 .509 .704 r
.43488 .81943 m .43693 .81967 L .43809 .8198 L F
.006 0 0 r
.43693 .81967 m .4401 .81965 L .43809 .8198 L F
.651 .78 .943 r
.4767 .82722 m .47712 .82775 L .47935 .82729 L F
.839 .702 .169 r
.51226 .8177 m .51027 .81859 L .50992 .82042 L F
.623 .21 .239 r
.50026 .88498 m .50342 .88481 L .50212 .88552 L F
.374 0 0 r
.50212 .88552 m .50342 .88481 L .50499 .88481 L F
.494 0 .006 r
.44038 .83128 m .43993 .83275 L .43559 .83249 L F
.402 0 0 r
.44038 .83128 m .44127 .83195 L .43993 .83275 L F
.44038 .83128 m .44323 .83277 L .44127 .83195 L F
.601 .187 .229 r
.49395 .82176 m .49671 .8212 L .49628 .82154 L F
.554 .859 .552 r
.49669 .82103 m .49594 .82181 L .49628 .82154 L F
.26 0 0 r
.49628 .82154 m .49573 .82204 L .49395 .82176 L F
.554 .859 .552 r
.49594 .82181 m .49573 .82204 L .49628 .82154 L F
.601 .187 .229 r
.49671 .8212 m .49777 .82098 L .49628 .82154 L F
.49395 .82176 m .49417 .82117 L .49777 .82098 L F
.832 .446 0 r
.49615 .8178 m .49717 .82041 L .49777 .82098 L F
.894 .987 .79 r
.49717 .82041 m .49628 .82154 L .49777 .82098 L F
.662 .524 .685 r
.62307 .74818 m .62436 .75107 L .62622 .74826 L F
.501 0 0 r
.39794 .82449 m .39988 .82484 L .40128 .82391 L F
.155 0 0 r
.40128 .82391 m .40191 .82445 L .40336 .82364 L F
.40128 .82391 m .39988 .82484 L .40191 .82445 L F
.649 .317 .396 r
.46632 .87776 m .46827 .87962 L .46645 .87915 L F
.144 .491 .904 r
.49298 .87313 m .49128 .87344 L .49107 .87364 L F
.325 0 .217 r
.49379 .87416 m .49298 .87313 L .49107 .87364 L F
.433 .054 .218 r
.49379 .87416 m .49107 .87364 L .49251 .87537 L F
.49327 .87519 m .49251 .87537 L .49292 .87586 L F
.49379 .87416 m .49251 .87537 L .49327 .87519 L F
.647 .307 .382 r
.49708 .87393 m .49481 .87205 L .49379 .87416 L F
.487 0 .023 r
.49557 .8748 m .49708 .87393 L .49379 .87416 L F
.433 .054 .218 r
.49379 .87416 m .49292 .87586 L .49249 .87502 L F
.487 0 .023 r
.49557 .8748 m .49379 .87416 L .49249 .87502 L F
.643 .758 .932 r
.49392 .8735 m .49542 .87468 L .49249 .87502 L F
.49542 .87468 m .49557 .8748 L .49462 .87486 L F
.49542 .87468 m .49462 .87486 L .49249 .87502 L F
.306 .037 .331 r
.49292 .87586 m .49107 .87364 L .49128 .87344 L F
.744 .597 .693 r
.37316 .7947 m .37547 .79282 L .3723 .79198 L F
.37316 .7947 m .37382 .79473 L .37547 .79282 L F
.595 .594 .82 r
.37659 .79296 m .37804 .79294 L .37991 .79211 L F
.381 .021 .223 r
.37719 .79323 m .37659 .79296 L .37681 .7929 L F
.63 .744 .93 r
.37991 .79211 m .37804 .79294 L .37782 .79273 L F
.381 .021 .223 r
.37782 .79273 m .37681 .7929 L .37991 .79211 L F
.63 .744 .93 r
.37991 .79211 m .37782 .79273 L .37614 .79115 L F
.381 .021 .223 r
.37878 .79257 m .37782 .79273 L .37991 .79211 L F
.522 .706 .954 r
.37782 .79273 m .37804 .79294 L .3769 .79288 L F
.381 .021 .223 r
.37719 .79323 m .37681 .7929 L .37878 .79257 L F
.522 .706 .954 r
.37614 .79115 m .37782 .79273 L .37547 .79282 L F
.37782 .79273 m .3769 .79288 L .37547 .79282 L F
.583 .637 .87 r
.37547 .79282 m .37804 .79294 L .37659 .79296 L F
.418 0 0 r
.37547 .79282 m .37659 .79296 L .37719 .79323 L F
.368 .528 .884 r
.37547 .79282 m .37719 .79323 L .37614 .79115 L F
.523 .287 .499 r
.37547 .79282 m .37382 .79473 L .37719 .79323 L F
.427 .86 .746 r
.52171 .81318 m .52351 .81227 L .52475 .81009 L F
.693 .383 .445 r
.52351 .81227 m .527 .81278 L .52475 .81009 L F
.692 .383 .447 r
.527 .81278 m .52705 .81076 L .52475 .81009 L F
.607 .196 .239 r
.38882 .84198 m .38752 .84374 L .38542 .84318 L F
.482 .059 .159 r
.39092 .8426 m .38752 .84374 L .38882 .84198 L F
0 0 0 r
.46615 .81451 m .46736 .81423 L .46872 .81385 L F
.46615 .81451 m .46542 .81492 L .46736 .81423 L F
.577 .466 .691 r
.48377 .86159 m .48216 .86452 L .48209 .86183 L F
.31 0 .112 r
.48377 .86159 m .48209 .86183 L .48149 .8631 L F
0 0 0 r
.50831 .87185 m .50505 .87354 L .50694 .87322 L F
.142 0 0 r
.51016 .87129 m .50831 .87185 L .50694 .87322 L F
.225 0 0 r
.41942 .83627 m .41577 .83769 L .41741 .83637 L F
.746 .751 .857 r
.48796 .87349 m .49128 .87344 L .49011 .87294 L F
.758 .537 .597 r
.48935 .87502 m .49128 .87344 L .48796 .87349 L F
.144 .491 .904 r
.49298 .87313 m .49011 .87294 L .49128 .87344 L F
.306 .037 .331 r
.49292 .87586 m .49128 .87344 L .48935 .87502 L F
.192 0 0 r
.40527 .82324 m .40853 .82261 L .40644 .82298 L F
.791 .634 .687 r
.52766 .86346 m .53084 .86467 L .53173 .86098 L F
.554 .541 .795 r
.53293 .86178 m .53173 .86098 L .53204 .86129 L F
0 0 .007 r
.53173 .86098 m .53145 .86338 L .53204 .86129 L F
.53173 .86098 m .53084 .86467 L .53145 .86338 L F
.627 .404 .559 r
.4411 .88252 m .44077 .88481 L .43818 .88575 L F
.59 .357 .531 r
.4411 .88252 m .44302 .88439 L .44077 .88481 L F
.4411 .88252 m .44316 .88228 L .44302 .88439 L F
.577 .403 .609 r
.51453 .8243 m .5164 .82561 L .5164 .82293 L F
.449 .632 .932 r
.52781 .8134 m .52869 .81244 L .527 .81278 L F
.52781 .8134 m .5299 .81374 L .52869 .81244 L F
.692 .454 .558 r
.47633 .85542 m .4777 .85644 L .47869 .85492 L F
0 0 0 r
.47869 .85492 m .4777 .85644 L .47978 .85385 L F
.648 .408 .541 r
.40705 .83878 m .40686 .84115 L .40452 .84083 L F
.454 .154 .366 r
.4105 .83826 m .40686 .84115 L .40705 .83878 L F
.559 .178 .277 r
.44712 .87135 m .44611 .86937 L .44496 .87143 L F
.44712 .87135 m .44831 .86947 L .44611 .86937 L F
.144 .491 .904 r
.49298 .87313 m .49068 .87138 L .49011 .87294 L F
.325 0 .217 r
.49379 .87416 m .49481 .87205 L .49298 .87313 L F
.971 .811 .625 r
.56713 .82505 m .5682 .82574 L .56694 .82853 L F
.56694 .82853 m .5682 .82574 L .56713 .82505 L F
.558 .361 .569 r
.42832 .87476 m .43043 .87479 L .43048 .87206 L F
.579 .344 .523 r
.43236 .87419 m .43048 .87206 L .43043 .87479 L F
.43236 .87419 m .43238 .87207 L .43048 .87206 L F
.796 .627 .672 r
.5154 .81599 m .51226 .8177 L .51564 .81525 L F
.5154 .81599 m .5152 .81804 L .51226 .8177 L F
.642 .488 .659 r
.51725 .8152 m .5152 .81804 L .5154 .81599 L F
.473 .075 .203 r
.53966 .82507 m .54067 .82322 L .54241 .82411 L F
.49 .023 .072 r
.54067 .82322 m .54285 .82332 L .54241 .82411 L F
.298 0 .152 r
.51882 .87177 m .52155 .86998 L .5206 .87194 L F
.204 0 .107 r
.5206 .87194 m .52155 .86998 L .52325 .86922 L F
.433 .169 .413 r
.5162 .87397 m .51882 .87177 L .51787 .87382 L F
.159 0 .151 r
.51537 .87641 m .5162 .87397 L .51787 .87382 L F
0 0 .029 r
.49228 .82232 m .49075 .82514 L .48988 .82554 L F
.575 .08 .042 r
.49217 .82709 m .48988 .82554 L .49075 .82514 L F
.49217 .82709 m .48835 .82667 L .48988 .82554 L F
.985 .727 .453 r
.47045 .85914 m .47125 .86213 L .47042 .8616 L F
.439 0 .053 r
.47125 .86213 m .47218 .86334 L .47042 .8616 L F
.47125 .86213 m .4735 .86205 L .47218 .86334 L F
.271 0 0 r
.44772 .83104 m .44422 .83203 L .44568 .83088 L F
.237 0 .045 r
.49284 .80939 m .492 .80857 L .49405 .80777 L F
.49284 .80939 m .491 .81002 L .492 .80857 L F
.278 .782 .824 r
.47387 .81252 m .47486 .8121 L .47592 .81204 L F
.278 .768 .696 r
.47387 .81252 m .47296 .81281 L .47486 .8121 L F
.481 .125 .285 r
.39432 .84158 m .3958 .84264 L .39402 .8425 L F
.442 .145 .364 r
.39631 .84104 m .3958 .84264 L .39432 .84158 L F
.475 .851 .624 r
.51564 .81525 m .51322 .81691 L .51078 .81517 L F
.51564 .81525 m .51226 .8177 L .51322 .81691 L F
0 0 .132 r
.50489 .81926 m .50435 .82226 L .50477 .82069 L F
.19 0 0 r
.52019 .86452 m .51685 .86681 L .51885 .86693 L F
.411 0 .03 r
.52097 .86583 m .52019 .86452 L .51885 .86693 L F
.52097 .86583 m .52231 .86448 L .52019 .86452 L F
.315 .8 .756 r
.44566 .81881 m .44616 .81846 L .44767 .81853 L F
.44566 .81881 m .4441 .8192 L .44616 .81846 L F
.203 .712 .898 r
.39692 .88219 m .39785 .88249 L .39452 .88225 L F
.448 .212 .463 r
.39692 .88219 m .39839 .88353 L .39811 .88208 L F
.942 .938 .761 r
.39692 .88219 m .39785 .88249 L .39881 .88056 L F
.576 .435 .653 r
.39881 .88056 m .39785 .88249 L .39944 .88105 L F
.805 .976 .901 r
.39944 .88105 m .39785 .88249 L .39692 .88219 L F
.942 .938 .761 r
.39692 .88219 m .39881 .88056 L .3982 .8795 L F
.805 .976 .901 r
.39944 .88105 m .39692 .88219 L .3982 .8795 L F
.448 .212 .463 r
.39692 .88219 m .39811 .88208 L .39791 .88101 L F
.203 .712 .898 r
.39692 .88219 m .39785 .88249 L .39549 .88232 L F
.39692 .88219 m .39549 .88232 L .39452 .88225 L F
.536 .18 .311 r
.42847 .8872 m .42933 .88964 L .4272 .88959 L F
.42847 .8872 m .4305 .8873 L .42933 .88964 L F
.511 .586 .866 r
.53764 .81217 m .53596 .81279 L .53417 .80961 L F
0 0 .553 r
.48161 .82575 m .48263 .82857 L .48321 .82846 L F
.373 .791 .977 r
.48263 .82857 m .48497 .8284 L .48288 .82786 L F
.795 .33 0 r
.48161 .82575 m .48286 .82786 L .48172 .82672 L F
.373 .791 .977 r
.48279 .82787 m .48286 .82786 L .4828 .82784 L F
.48286 .82786 m .48284 .82785 L .4828 .82784 L F
.48263 .82857 m .48288 .82786 L .48279 .82787 L F
.48263 .82857 m .4828 .82784 L .48321 .82846 L F
.963 .636 .335 r
.4828 .82784 m .48231 .8293 L .48172 .82672 L F
.4828 .82784 m .48172 .82672 L .48321 .82846 L F
.216 0 .084 r
.48282 .82785 m .48231 .8293 L .4828 .82784 L F
.795 .33 0 r
.48286 .82786 m .48321 .82846 L .48287 .82806 L F
.48286 .82786 m .48287 .82806 L .48282 .82783 L F
.591 .362 .538 r
.48286 .82786 m .48321 .82846 L .48332 .82783 L F
.216 0 .084 r
.48425 .8284 m .48308 .82894 L .48282 .82785 L F
.48308 .82894 m .48231 .8293 L .48282 .82785 L F
.795 .33 0 r
.48282 .82783 m .48287 .82806 L .48249 .82762 L F
.48286 .82786 m .48249 .82762 L .48172 .82672 L F
.591 .362 .538 r
.48161 .82575 m .48286 .82786 L .48376 .82523 L F
.373 .791 .977 r
.48286 .82786 m .48288 .82786 L .48284 .82785 L F
.591 .362 .538 r
.48286 .82786 m .48332 .82783 L .48376 .82523 L F
.702 .292 .266 r
.49239 .82085 m .49417 .82117 L .49395 .82176 L F
.246 0 0 r
.502 .80519 m .50305 .80541 L .50436 .80536 L F
.367 0 0 r
.5054 .80604 m .50436 .80536 L .50305 .80541 L F
.713 .202 .01 r
.50197 .8043 m .50488 .80578 L .50305 .80541 L F
.50488 .80578 m .5054 .80604 L .50305 .80541 L F
.246 0 0 r
.50119 .80514 m .50305 .80541 L .502 .80519 L F
.367 0 0 r
.5054 .80604 m .50708 .80625 L .50436 .80536 L F
0 .289 .666 r
.50845 .80696 m .50789 .80674 L .50708 .80625 L F
.50845 .80696 m .50965 .80759 L .50789 .80674 L F
.441 0 .084 r
.42904 .87621 m .42832 .87476 L .42702 .87649 L F
.42904 .87621 m .43043 .87479 L .42832 .87476 L F
0 0 0 r
.50837 .86159 m .50658 .86265 L .50537 .86371 L F
.258 0 0 r
.45094 .83073 m .44984 .83111 L .44772 .83104 L F
.761 .425 .416 r
.47853 .87964 m .47991 .88019 L .48011 .88183 L F
.74 .462 .509 r
.47991 .88019 m .48329 .88221 L .48011 .88183 L F
.498 .288 .525 r
.53084 .86467 m .53293 .86178 L .53275 .86416 L F
.901 .954 .824 r
.5348 .85905 m .53293 .86178 L .53204 .86129 L F
.538 .386 .623 r
.53494 .8615 m .53293 .86178 L .5348 .85905 L F
.516 .302 .528 r
.53275 .86416 m .53293 .86178 L .53494 .8615 L F
.742 .63 .735 r
.37336 .79534 m .37382 .79473 L .37316 .7947 L F
.3 0 .174 r
.51787 .87382 m .51882 .87177 L .5206 .87194 L F
.849 .792 .796 r
.50319 .81705 m .50669 .81491 L .50559 .81557 L F
.386 0 0 r
.50559 .81557 m .50424 .817 L .5034 .81688 L F
.50559 .81557 m .5022 .81664 L .50319 .81705 L F
.50559 .81557 m .5034 .81688 L .5022 .81664 L F
.03 0 0 r
.5063 .81606 m .50424 .817 L .50559 .81557 L F
.386 0 0 r
.50424 .817 m .50406 .81702 L .5034 .81688 L F
.379 .191 .495 r
.50574 .81685 m .50336 .81708 L .50273 .81608 L F
.03 0 0 r
.5063 .81606 m .5042 .81704 L .50424 .817 L F
.379 .191 .495 r
.5063 .81606 m .50574 .81685 L .50499 .81666 L F
.5063 .81606 m .50499 .81666 L .50273 .81608 L F
.50574 .81685 m .50441 .81875 L .50336 .81708 L F
.386 0 0 r
.50424 .817 m .5042 .81704 L .50406 .81702 L F
.849 .792 .796 r
.50669 .81491 m .50675 .81487 L .50559 .81557 L F
.122 0 0 r
.50877 .81484 m .50559 .81557 L .50675 .81487 L F
.662 .965 .776 r
.37236 .74987 m .3717 .75089 L .37284 .74976 L F
.24 .481 .887 r
.37065 .74923 m .3717 .75089 L .37236 .74987 L F
.757 .374 .329 r
.47736 .85835 m .47633 .85542 L .47421 .85833 L F
.694 .318 .33 r
.47664 .87997 m .47853 .87964 L .47717 .8814 L F
.776 .424 .389 r
.47853 .87964 m .48011 .88183 L .47717 .8814 L F
.528 .137 .243 r
.45063 .88023 m .45374 .87945 L .45199 .8814 L F
.48 .037 .119 r
.45374 .87945 m .45362 .88092 L .45199 .8814 L F
.45374 .87945 m .4558 .87949 L .45362 .88092 L F
.596 .213 .287 r
.43468 .88744 m .43589 .88557 L .43772 .88674 L F
.59 .222 .311 r
.43589 .88557 m .43818 .88575 L .43772 .88674 L F
.569 .495 .732 r
.48005 .82038 m .47812 .82203 L .47804 .82135 L F
.48005 .82038 m .48047 .82228 L .47812 .82203 L F
.521 .341 .577 r
.41266 .87711 m .41448 .87943 L .41481 .87692 L F
.41266 .87711 m .41262 .87984 L .41448 .87943 L F
.55 .549 .805 r
.39443 .87986 m .39583 .87721 L .39339 .87701 L F
.39443 .87986 m .3967 .87976 L .39583 .87721 L F
.558 .406 .63 r
.39452 .88225 m .3967 .87976 L .39443 .87986 L F
.504 .169 .333 r
.45571 .86931 m .45786 .86913 L .45878 .86684 L F
.497 .14 .291 r
.45965 .8688 m .45878 .86684 L .45786 .86913 L F
.45965 .8688 m .46089 .86667 L .45878 .86684 L F
0 0 0 r
.47089 .81344 m .46872 .81385 L .46736 .81423 L F
.648 .221 .218 r
.49176 .8847 m .49505 .88471 L .4939 .88608 L F
.641 .152 .075 r
.49505 .88471 m .49584 .88647 L .4939 .88608 L F
.49505 .88471 m .49697 .88552 L .49584 .88647 L F
.073 .635 .736 r
.45177 .81807 m .45079 .81818 L .44956 .81828 L F
.45177 .81807 m .45293 .81803 L .45079 .81818 L F
.501 .101 .214 r
.48517 .80905 m .48727 .80906 L .48844 .80703 L F
.265 0 .054 r
.48727 .80906 m .49106 .80644 L .48844 .80703 L F
.496 .224 .432 r
.39202 .8846 m .39427 .88221 L .39231 .88236 L F
.321 0 .03 r
.41262 .87984 m .41062 .88019 L .40913 .88187 L F
.447 .004 .101 r
.38721 .82712 m .38925 .82714 L .39065 .82557 L F
.554 .153 .237 r
.38925 .82714 m .39268 .82555 L .39065 .82557 L F
.489 .811 1 r
.37588 .74574 m .37653 .74469 L .37792 .74539 L F
.37588 .74574 m .37653 .74469 L .37792 .74539 L F
.556 .009 0 r
.51226 .8177 m .5152 .81804 L .51318 .81878 L F
.632 .149 .086 r
.51749 .81843 m .51433 .81869 L .5152 .81804 L F
.51749 .81843 m .51609 .81927 L .51318 .81878 L F
.583 .529 .761 r
.51598 .81891 m .51731 .81589 L .51517 .81627 L F
.51609 .81927 m .51621 .81894 L .51598 .81891 L F
.51621 .81894 m .51731 .81589 L .51598 .81891 L F
.632 .149 .086 r
.51433 .81869 m .51318 .81878 L .51367 .8186 L F
.51433 .81869 m .51367 .8186 L .5152 .81804 L F
.651 .78 .943 r
.4767 .82722 m .47935 .82729 L .47825 .82655 L F
.725 .899 .958 r
.47825 .82655 m .47935 .82729 L .48161 .82575 L F
.144 0 0 r
.47042 .8616 m .46855 .8621 L .46724 .86346 L F
.111 0 0 r
.39339 .87701 m .39583 .87721 L .39723 .87722 L F
.553 .334 .538 r
.3967 .87976 m .39723 .87722 L .39583 .87721 L F
.3967 .87976 m .3982 .8795 L .39723 .87722 L F
.308 .799 .782 r
.48136 .81034 m .47751 .81137 L .48013 .81028 L F
.272 0 0 r
.48013 .81028 m .48324 .80948 L .48136 .81034 L F
.387 0 0 r
.45628 .83033 m .45514 .83074 L .45297 .83047 L F
0 .491 .715 r
.45628 .83033 m .45832 .83065 L .45746 .83049 L F
.45628 .83033 m .45746 .83049 L .45514 .83074 L F
.662 .51 .666 r
.46489 .86604 m .46724 .86346 L .46574 .86325 L F
.6 .155 .165 r
.4611 .87935 m .46396 .87909 L .46308 .87991 L F
.394 0 0 r
.46396 .87909 m .46531 .88046 L .46308 .87991 L F
.46396 .87909 m .46645 .87915 L .46531 .88046 L F
0 .419 .764 r
.48843 .81485 m .48787 .81483 L .4865 .81468 L F
.48843 .81485 m .48986 .81551 L .48787 .81483 L F
.595 .027 0 r
.4767 .82722 m .47241 .82566 L .4738 .82625 L F
.298 0 0 r
.40689 .89682 m .40846 .89513 L .4104 .89472 L F
.543 .006 0 r
.50026 .88498 m .50111 .88629 L .49901 .8863 L F
.50026 .88498 m .50212 .88552 L .50111 .88629 L F
.537 .371 .604 r
.5164 .82293 m .5164 .82561 L .51841 .82509 L F
.985 .727 .453 r
.47045 .85914 m .47042 .8616 L .47259 .85902 L F
.11 0 0 r
.52829 .86651 m .53084 .86467 L .52982 .86636 L F
.089 0 0 r
.52707 .8682 m .52829 .86651 L .52982 .86636 L F
.038 0 .178 r
.47446 .86187 m .47611 .85923 L .47567 .86174 L F
.122 0 .373 r
.47567 .86174 m .47611 .85923 L .47717 .85851 L F
.892 .793 .744 r
.4759 .86917 m .47767 .86946 L .47645 .86696 L F
.902 .632 .519 r
.47773 .8718 m .47767 .86946 L .4759 .86917 L F
.793 .763 .826 r
.47645 .86696 m .47767 .86946 L .48 .86684 L F
.772 .496 .517 r
.48104 .87192 m .47767 .86946 L .47773 .8718 L F
.712 .318 .299 r
.48666 .88399 m .48968 .88429 L .48849 .88477 L F
.552 .058 .037 r
.48968 .88429 m .49176 .8847 L .48849 .88477 L F
.518 .045 .07 r
.41559 .82206 m .4178 .82223 L .41913 .82109 L F
0 0 0 r
.41913 .82109 m .41967 .82142 L .42121 .82093 L F
.41913 .82109 m .4178 .82223 L .41967 .82142 L F
.334 0 0 r
.42639 .82017 m .42841 .82011 L .42958 .81933 L F
.497 .003 .013 r
.42958 .81933 m .42841 .82011 L .43163 .81971 L F
.792 .58 .614 r
.49239 .82085 m .49228 .82232 L .49072 .82047 L F
.627 .435 .603 r
.49395 .82176 m .49228 .82232 L .49239 .82085 L F
.091 0 0 r
.45587 .81698 m .45683 .81715 L .4579 .81658 L F
.45587 .81698 m .45486 .81752 L .45683 .81715 L F
.435 .867 .924 r
.4244 .82056 m .4251 .8199 L .42639 .82017 L F
.4244 .82056 m .42327 .82046 L .4251 .8199 L F
.809 .449 .375 r
.52982 .86636 m .53084 .86467 L .52766 .86346 L F
.674 .828 .396 r
.53145 .86338 m .53084 .86467 L .52982 .86636 L F
.299 0 .089 r
.52982 .86636 m .53084 .86467 L .53275 .86416 L F
.28 .762 .923 r
.53235 .80984 m .53088 .80953 L .53417 .80961 L F
.385 0 0 r
.39268 .82555 m .39469 .82553 L .39574 .82475 L F
.288 0 0 r
.39574 .82475 m .39469 .82553 L .39794 .82449 L F
.528 .137 .243 r
.45063 .88023 m .45199 .8814 L .45021 .88162 L F
.249 0 0 r
.43187 .83289 m .42865 .83367 L .42982 .83308 L F
.679 .771 .92 r
.50734 .82011 m .50802 .82127 L .50992 .82042 L F
.302 0 0 r
.50661 .82002 m .50861 .82043 L .50992 .82042 L F
.679 .771 .92 r
.50661 .82002 m .50992 .82042 L .50861 .82043 L F
.488 .144 .309 r
.50861 .82043 m .51226 .8177 L .50992 .82042 L F
.441 0 0 r
.51212 .82019 m .50861 .82043 L .50992 .82042 L F
.51212 .82019 m .51068 .82104 L .50861 .82043 L F
.934 .968 .7 r
.51075 .82097 m .51068 .82104 L .51072 .82103 L F
.51183 .81966 m .51072 .82103 L .51212 .82019 L F
.482 .128 .289 r
.51141 .82018 m .51068 .82104 L .51161 .82016 L F
.50861 .82043 m .51068 .82104 L .51141 .82018 L F
.934 .968 .7 r
.51165 .81934 m .51068 .82104 L .51075 .82097 L F
.488 .144 .309 r
.50861 .82043 m .51141 .82018 L .51196 .81884 L F
.51141 .82018 m .5117 .81983 L .51196 .81884 L F
.934 .968 .7 r
.51165 .81934 m .51072 .82103 L .51183 .81966 L F
.488 .144 .309 r
.51141 .82018 m .51161 .82016 L .5117 .81983 L F
.51002 .81937 m .51196 .81884 L .51226 .8177 L F
.50861 .82043 m .51196 .81884 L .51002 .81937 L F
.679 .771 .92 r
.50661 .82002 m .50686 .82024 L .50734 .82011 L F
.50686 .82024 m .50802 .82127 L .50734 .82011 L F
.513 .364 .615 r
.49083 .8224 m .48866 .82309 L .48882 .82043 L F
0 0 .358 r
.48917 .82246 m .48866 .82309 L .48882 .82043 L F
.682 .346 .4 r
.48882 .82043 m .48917 .82246 L .49083 .8224 L F
.717 .777 .9 r
.39631 .84104 m .39811 .84124 L .39947 .84067 L F
0 0 0 r
.48841 .85887 m .49062 .85611 L .48931 .85669 L F
0 0 .409 r
.49098 .85485 m .49062 .85611 L .4903 .85371 L F
.759 .992 .792 r
.48931 .85669 m .49062 .85611 L .49098 .85485 L F
.363 .49 .853 r
.53901 .81226 m .53806 .81384 L .53764 .81217 L F
.712 .866 .954 r
.48796 .87349 m .49011 .87294 L .48828 .87226 L F
.886 .804 .763 r
.48828 .87226 m .49011 .87294 L .49068 .87138 L F
.356 0 .009 r
.41055 .82288 m .41258 .82265 L .41365 .82149 L F
.482 .028 .095 r
.41365 .82149 m .41258 .82265 L .41559 .82206 L F
.595 .027 0 r
.4767 .82722 m .47494 .82718 L .47241 .82566 L F
.435 0 0 r
.47825 .82655 m .47494 .82718 L .4767 .82722 L F
.41 0 0 r
.51168 .80805 m .51581 .80863 L .5131 .80868 L F
.622 .384 .535 r
.44316 .88228 m .44517 .88439 L .44302 .88439 L F
.608 .384 .551 r
.44316 .88228 m .44537 .88217 L .44517 .88439 L F
.442 .054 .207 r
.52272 .81564 m .52182 .81747 L .51956 .81778 L F
.139 0 .06 r
.52346 .81661 m .52272 .81564 L .52461 .81491 L F
.52346 .81661 m .52182 .81747 L .52272 .81564 L F
.853 .816 .812 r
.48 .86684 m .48216 .86452 L .48149 .8631 L F
.577 .466 .691 r
.48377 .86159 m .48447 .86426 L .48216 .86452 L F
.534 .288 .489 r
.48216 .86452 m .48447 .86426 L .48399 .86616 L F
0 .198 .728 r
.48149 .8631 m .48216 .86452 L .48399 .86616 L F
.901 .954 .824 r
.5348 .85905 m .53204 .86129 L .53266 .86069 L F
.532 .382 .622 r
.53696 .86114 m .5348 .85905 L .53683 .85876 L F
.53598 .86019 m .53494 .8615 L .5348 .85905 L F
.53696 .86114 m .53502 .86148 L .53598 .86019 L F
.53502 .86148 m .53494 .8615 L .53598 .86019 L F
.506 .295 .526 r
.53475 .86367 m .53494 .8615 L .53696 .86114 L F
.173 .099 .526 r
.53828 .86082 m .53696 .86114 L .53683 .85876 L F
0 0 0 r
.53578 .86249 m .53696 .86114 L .5363 .8621 L F
.5363 .8621 m .53696 .86114 L .53653 .86185 L F
.344 0 .041 r
.53683 .85876 m .53266 .86069 L .53661 .8619 L F
.53679 .8617 m .53661 .8619 L .53679 .86196 L F
.53683 .85876 m .53661 .8619 L .53679 .8617 L F
.021 0 0 r
.53577 .86313 m .5363 .86225 L .53828 .86082 L F
.53679 .8617 m .53739 .86104 L .53828 .86082 L F
.173 .099 .526 r
.53828 .86082 m .53796 .86037 L .53712 .86151 L F
.53828 .86082 m .53712 .86151 L .53679 .86196 L F
.657 .697 .875 r
.53828 .86082 m .53679 .86196 L .5367 .86186 L F
.021 0 0 r
.53657 .86195 m .53696 .86114 L .53739 .86104 L F
.463 .631 .927 r
.53665 .86182 m .5367 .86186 L .53657 .86189 L F
.5367 .86186 m .53679 .86196 L .53661 .8619 L F
.5367 .86186 m .53661 .8619 L .53657 .86189 L F
.021 0 0 r
.53703 .86172 m .53679 .8617 L .53828 .86082 L F
.5363 .86225 m .53661 .8619 L .53703 .86172 L F
.173 .099 .526 r
.53796 .86037 m .53681 .86157 L .53679 .86196 L F
.021 0 0 r
.53661 .8619 m .53679 .8617 L .53703 .86172 L F
.53642 .86205 m .53696 .86114 L .53657 .86195 L F
.173 .099 .526 r
.53796 .86037 m .53693 .8589 L .53681 .86157 L F
.53693 .8589 m .53683 .85904 L .53679 .86196 L F
.657 .697 .875 r
.53828 .86082 m .5367 .86186 L .53491 .86006 L F
.021 0 0 r
.5363 .86225 m .53642 .86205 L .53657 .86195 L F
.463 .631 .927 r
.53491 .86006 m .53665 .86182 L .53266 .86069 L F
.53665 .86182 m .53657 .86189 L .53266 .86069 L F
0 0 0 r
.53475 .86367 m .53578 .86249 L .5363 .8621 L F
.53482 .86364 m .53653 .86185 L .53577 .86313 L F
.53475 .86367 m .53653 .86185 L .53482 .86364 L F
.173 .099 .526 r
.53693 .8589 m .53683 .85876 L .53683 .85904 L F
.344 0 .041 r
.53683 .85876 m .5348 .85905 L .53266 .86069 L F
.47 .004 .064 r
.5164 .82561 m .51939 .82496 L .51841 .82509 L F
.28 0 0 r
.43163 .81971 m .43367 .81981 L .43488 .81943 L F
.356 0 0 r
.43488 .81943 m .43367 .81981 L .43693 .81967 L F
.618 .293 .398 r
.4344 .87391 m .4357 .87142 L .43238 .87207 L F
.669 .243 .225 r
.43643 .87362 m .4357 .87142 L .4344 .87391 L F
.43643 .87362 m .43783 .87221 L .4357 .87142 L F
.237 0 0 r
.40109 .88156 m .40364 .88152 L .39944 .88105 L F
.316 0 0 r
.39944 .88105 m .40364 .88152 L .40289 .88135 L F
.237 0 0 r
.40109 .88156 m .39944 .88105 L .3982 .8795 L F
.545 .846 .998 r
.52766 .80429 m .52558 .80477 L .52642 .80367 L F
.94 .786 .323 r
.52558 .80477 m .52532 .80752 L .52498 .80695 L F
.52558 .80477 m .52498 .80695 L .52642 .80367 L F
.862 .876 .847 r
.65844 .75011 m .65641 .75063 L .65843 .74854 L F
.601 .335 .486 r
.65844 .75011 m .65591 .75278 L .65641 .75063 L F
.65844 .75011 m .65839 .75257 L .65591 .75278 L F
.555 .468 .711 r
.6604 .74746 m .65933 .74881 L .65844 .75011 L F
.493 .297 .542 r
.65931 .74888 m .66058 .7523 L .65839 .75257 L F
.65933 .74881 m .65934 .74885 L .65931 .74888 L F
.65934 .74885 m .66058 .7523 L .65931 .74888 L F
.555 .468 .711 r
.6604 .74746 m .65943 .74878 L .65843 .74854 L F
.65943 .74878 m .65844 .75011 L .65844 .74968 L F
.65943 .74878 m .65844 .74968 L .65843 .74854 L F
.493 .297 .542 r
.65933 .74881 m .65839 .75257 L .65844 .75011 L F
.28 0 0 r
.45977 .81591 m .46195 .8161 L .4634 .81533 L F
.172 0 0 r
.46195 .8161 m .46542 .81492 L .4634 .81533 L F
0 0 0 r
.47241 .82566 m .47061 .82786 L .47233 .82586 L F
.50705 .88196 m .51013 .88021 L .50839 .88142 L F
.468 .844 .611 r
.50839 .88142 m .51013 .88021 L .51147 .87918 L F
.836 .392 .172 r
.49331 .82699 m .49411 .82961 L .49217 .82709 L F
.28 .065 .399 r
.49476 .82751 m .49411 .82961 L .49331 .82699 L F
.315 0 0 r
.49217 .82709 m .49476 .82751 L .49331 .82699 L F
.712 .866 .954 r
.48796 .87349 m .48828 .87226 L .48628 .87419 L F
.775 .277 0 r
.48822 .87439 m .48796 .87349 L .48628 .87419 L F
.48822 .87439 m .48935 .87502 L .48796 .87349 L F
.527 .143 .255 r
.44933 .87123 m .44831 .86947 L .44712 .87135 L F
.44933 .87123 m .45044 .86954 L .44831 .86947 L F
.398 0 0 r
.4051 .8823 m .40719 .88229 L .4079 .88161 L F
.226 0 0 r
.4079 .88161 m .40719 .88229 L .40913 .88187 L F
.167 0 0 r
.39584 .89986 m .3969 .90013 L .39552 .90013 L F
.39584 .89986 m .39796 .89944 L .3969 .90013 L F
.739 .683 .796 r
.4735 .86205 m .47446 .86187 L .47567 .86174 L F
.403 .398 .74 r
.54392 .82248 m .54285 .82332 L .54218 .82083 L F
0 0 0 r
.54241 .82411 m .54285 .82332 L .54392 .82248 L F
.717 .777 .9 r
.39631 .84104 m .39947 .84067 L .39803 .84049 L F
.431 0 0 r
.39947 .84067 m .40154 .84135 L .39803 .84049 L F
.374 0 0 r
.50212 .88552 m .50499 .88481 L .50431 .88552 L F
.468 .272 .53 r
.50499 .88481 m .50705 .88196 L .50636 .88375 L F
0 0 0 r
.50431 .88552 m .50499 .88481 L .50636 .88375 L F
.354 .827 .88 r
.40312 .84091 m .40154 .84135 L .40452 .84083 L F
.317 0 0 r
.40686 .84115 m .40312 .84091 L .40452 .84083 L F
.618 .553 .759 r
.4975 .81429 m .49831 .81771 L .49615 .8178 L F
0 0 0 r
.50837 .86159 m .50537 .86371 L .5076 .86334 L F
.949 .672 .479 r
.50856 .86466 m .50837 .86159 L .5076 .86334 L F
.509 .51 .793 r
.53096 .80716 m .5288 .8075 L .52766 .80429 L F
.505 .092 .19 r
.53096 .80716 m .5278 .8083 L .5288 .8075 L F
.618 .293 .398 r
.4344 .87391 m .43238 .87207 L .43236 .87419 L F
.711 .348 .359 r
.47979 .87392 m .48104 .87192 L .47773 .8718 L F
.684 .315 .342 r
.48304 .87375 m .48104 .87192 L .47979 .87392 L F
.648 .332 .424 r
.48304 .87375 m .48369 .87229 L .48104 .87192 L F
.237 0 0 r
.41251 .89419 m .41572 .89243 L .41437 .89415 L F
.429 0 .091 r
.41572 .89243 m .4165 .89386 L .41437 .89415 L F
.41572 .89243 m .41781 .89229 L .4165 .89386 L F
.006 0 0 r
.43693 .81967 m .43894 .81966 L .4401 .81965 L F
.085 0 0 r
.43894 .81966 m .44211 .81951 L .4401 .81965 L F
.677 .221 .162 r
.48011 .88183 m .48329 .88221 L .48228 .88333 L F
.676 .22 .162 r
.48228 .88333 m .48329 .88221 L .48563 .88381 L F
.753 .321 .224 r
.48329 .88221 m .48666 .88399 L .48563 .88381 L F
.202 .73 .813 r
.4735 .86205 m .47442 .86176 L .47218 .86334 L F
.4735 .86205 m .47567 .86174 L .47442 .86176 L F
.454 .154 .366 r
.4105 .83826 m .40884 .84087 L .40686 .84115 L F
.244 0 .222 r
.41054 .83991 m .4105 .83826 L .4118 .83823 L F
.41054 .83991 m .40884 .84087 L .4105 .83826 L F
.182 0 .065 r
.4764 .86374 m .4736 .86607 L .47645 .86696 L F
.612 .426 .606 r
.47645 .86696 m .47871 .86362 L .4764 .86374 L F
.395 .047 .252 r
.51292 .86957 m .51016 .87129 L .51183 .87169 L F
.105 0 .07 r
.51448 .86871 m .51292 .86957 L .51183 .87169 L F
.458 .247 .504 r
.51494 .86709 m .51292 .86957 L .51448 .86871 L F
.527 .09 .153 r
.40191 .82445 m .40527 .82324 L .40336 .82364 L F
0 0 .029 r
.50636 .88375 m .50705 .88196 L .50839 .88142 L F
.53 .341 .569 r
.48177 .85352 m .4797 .85612 L .47978 .85385 L F
.48177 .85352 m .4797 .85612 L .47978 .85385 L F
.437 .056 .218 r
.38344 .84338 m .38542 .84318 L .38338 .84348 L F
.496 .224 .432 r
.39202 .8846 m .39452 .88225 L .39427 .88221 L F
.477 .322 .591 r
.61535 .76024 m .61711 .75914 L .6149 .75923 L F
.61535 .76024 m .61729 .76019 L .61711 .75914 L F
.456 .205 .443 r
.61535 .76024 m .61483 .76289 L .61729 .76019 L F
.477 .322 .591 r
.61711 .75914 m .61535 .76024 L .6149 .75923 L F
.61711 .75914 m .61729 .76019 L .61535 .76024 L F
.456 .205 .443 r
.61535 .76024 m .61483 .76289 L .61729 .76019 L F
.793 .763 .826 r
.47645 .86696 m .48 .86684 L .47884 .86641 L F
.853 .816 .812 r
.48 .86684 m .48149 .8631 L .47884 .86641 L F
.096 0 0 r
.37997 .82799 m .38205 .82748 L .38006 .82793 L F
.182 .564 .935 r
.40416 .88133 m .4051 .8823 L .40289 .88135 L F
.40416 .88133 m .40289 .88135 L .40364 .88152 L F
.408 .01 .17 r
.43818 .88575 m .43981 .88628 L .43772 .88674 L F
.43818 .88575 m .44077 .88481 L .43981 .88628 L F
.166 0 0 r
.41963 .89188 m .42312 .8898 L .42166 .89156 L F
.395 0 .078 r
.42312 .8898 m .42362 .89131 L .42166 .89156 L F
.42312 .8898 m .42516 .8896 L .42362 .89131 L F
.38 0 0 r
.49895 .80768 m .50019 .80847 L .49795 .80925 L F
.607 .824 .428 r
.50086 .80744 m .50015 .80846 L .50019 .80847 L F
.583 .81 .416 r
.50019 .80847 m .49827 .81118 L .49795 .80925 L F
.607 .824 .428 r
.50015 .80846 m .49875 .81049 L .50019 .80847 L F
.38 0 0 r
.49895 .80768 m .50023 .80848 L .50019 .80847 L F
.50023 .80848 m .50229 .80975 L .50019 .80847 L F
.184 0 0 r
.44984 .83111 m .44632 .83189 L .44772 .83104 L F
.91 .949 .813 r
.56694 .82853 m .56608 .83048 L .56498 .83052 L F
.736 .211 0 r
.56608 .83048 m .56695 .83215 L .56498 .83052 L F
.56608 .83048 m .56816 .83268 L .56695 .83215 L F
.647 .61 .798 r
.56694 .82853 m .56826 .83085 L .56608 .83048 L F
.679 .387 .472 r
.56826 .83085 m .56816 .83268 L .56608 .83048 L F
.917 .768 .284 r
.49039 .82009 m .4902 .82152 L .49072 .82047 L F
.422 .853 .94 r
.49072 .82047 m .49086 .81979 L .49039 .82009 L F
.717 .794 .316 r
.49072 .82047 m .4902 .82152 L .49086 .81979 L F
.681 .472 .596 r
.49395 .82176 m .49075 .82514 L .49228 .82232 L F
.482 .21 .425 r
.51685 .86681 m .51494 .86709 L .51448 .86871 L F
.359 .703 .984 r
.53377 .81651 m .53638 .81756 L .53543 .81757 L F
.514 .914 .891 r
.53543 .81757 m .53638 .81756 L .53738 .81674 L F
.363 0 0 r
.43985 .8721 m .44065 .87141 L .43783 .87221 L F
.243 0 0 r
.44186 .87176 m .44065 .87141 L .43985 .8721 L F
.44186 .87176 m .44287 .87157 L .44065 .87141 L F
.431 .403 .727 r
.54391 .81953 m .54392 .82248 L .54218 .82083 L F
.313 0 .011 r
.39796 .89944 m .40113 .89788 L .39973 .8995 L F
.41 .002 .152 r
.40113 .89788 m .40161 .89918 L .39973 .8995 L F
.40113 .89788 m .40302 .89739 L .40161 .89918 L F
.324 .661 .973 r
.50197 .8043 m .50119 .80514 L .50009 .80447 L F
.50197 .8043 m .50305 .80541 L .50119 .80514 L F
.738 .713 .828 r
.49359 .81575 m .48986 .81551 L .49181 .81465 L F
.764 .786 .871 r
.49546 .81472 m .49359 .81575 L .49181 .81465 L F
.192 0 0 r
.40527 .82324 m .40733 .82307 L .40853 .82261 L F
.382 0 0 r
.40733 .82307 m .41055 .82288 L .40853 .82261 L F
.696 .695 .845 r
.57005 .8286 m .57175 .83107 L .56826 .83085 L F
0 0 .213 r
.56901 .83157 m .56826 .83085 L .57175 .83107 L F
.448 .586 .898 r
.57295 .83005 m .57175 .83107 L .57005 .8286 L F
.57295 .83005 m .57005 .8286 L .57183 .83061 L F
.591 .948 .876 r
.57195 .83055 m .57175 .83107 L .57295 .83005 L F
.448 .586 .898 r
.57295 .83005 m .57183 .83061 L .57213 .83095 L F
.591 .948 .876 r
.57201 .83042 m .57195 .83055 L .57295 .83005 L F
.57199 .83043 m .57195 .83055 L .57201 .83042 L F
.557 .769 .977 r
.57391 .82896 m .57213 .83095 L .57197 .83045 L F
.57375 .8289 m .57197 .83045 L .57108 .82786 L F
.57391 .82896 m .57197 .83045 L .57375 .8289 L F
.591 .948 .876 r
.57199 .83042 m .57199 .83043 L .57201 .83042 L F
.2 .37 .809 r
.57108 .82786 m .57197 .83045 L .57005 .8286 L F
.57197 .83045 m .57213 .83095 L .57183 .83061 L F
.57197 .83045 m .57183 .83061 L .57005 .8286 L F
.591 .948 .876 r
.56901 .83157 m .57134 .83115 L .57199 .83042 L F
.57134 .83115 m .57175 .83107 L .57199 .83042 L F
0 .491 .831 r
.49292 .87586 m .48935 .87502 L .48842 .8745 L F
.49292 .87586 m .48842 .8745 L .48887 .87459 L F
.49292 .87586 m .48822 .87439 L .49043 .87467 L F
.332 0 0 r
.49127 .87538 m .49082 .875 L .48902 .87536 L F
.49082 .875 m .49043 .87467 L .49007 .87484 L F
.49082 .875 m .49007 .87484 L .48902 .87536 L F
0 .491 .831 r
.48887 .87459 m .48842 .8745 L .48822 .87439 L F
.266 0 0 r
.53227 .81424 m .52875 .81427 L .5299 .81374 L F
.355 .829 .852 r
.47592 .81204 m .47681 .81152 L .47751 .81137 L F
.47592 .81204 m .47486 .8121 L .47681 .81152 L F
.496 .224 .432 r
.39202 .8846 m .39473 .88341 L .39452 .88225 L F
.558 .406 .63 r
.39452 .88225 m .39692 .88219 L .3967 .87976 L F
.604 .378 .546 r
.39473 .88341 m .39692 .88219 L .39452 .88225 L F
.617 .329 .459 r
.38542 .84318 m .38241 .8454 L .38338 .84348 L F
.448 .034 .16 r
.4139 .83805 m .41054 .83991 L .4118 .83823 L F
.503 .109 .226 r
.37868 .82921 m .38205 .82748 L .37997 .82799 L F
.52 .852 .997 r
.4828 .82784 m .48497 .8284 L .4868 .82783 L F
.722 .787 .903 r
.48329 .82193 m .48047 .82228 L .48149 .82125 L F
.736 .586 .687 r
.48329 .82193 m .48161 .82575 L .48047 .82228 L F
.624 .456 .635 r
.48329 .82193 m .48161 .82575 L .48376 .82523 L F
.48329 .82193 m .48161 .82575 L .48376 .82523 L F
.754 .777 .872 r
.48588 .82037 m .48329 .82193 L .48149 .82125 L F
.142 0 0 r
.51016 .87129 m .50694 .87322 L .50895 .87276 L F
.352 0 .049 r
.51183 .87169 m .51016 .87129 L .50895 .87276 L F
.549 .033 0 r
.4558 .87949 m .45666 .88089 L .45362 .88092 L F
.4558 .87949 m .45796 .87994 L .45666 .88089 L F
.579 .164 .219 r
.45214 .87079 m .45346 .86908 L .45044 .86954 L F
.56 .141 .202 r
.45435 .87101 m .45346 .86908 L .45214 .87079 L F
.45435 .87101 m .45571 .86931 L .45346 .86908 L F
.441 .053 .206 r
.44077 .88481 m .44181 .88619 L .43981 .88628 L F
.44077 .88481 m .44302 .88439 L .44181 .88619 L F
.585 .112 .1 r
.48849 .88477 m .49176 .8847 L .49055 .88588 L F
.652 .194 .152 r
.49055 .88588 m .49176 .8847 L .4939 .88608 L F
.605 .337 .483 r
.41667 .87935 m .41481 .87692 L .41448 .87943 L F
.41667 .87935 m .41811 .87604 L .41481 .87692 L F
.357 .067 .328 r
.39803 .84049 m .3958 .84264 L .39631 .84104 L F
.764 .786 .871 r
.49546 .81472 m .49181 .81465 L .49428 .81281 L F
.74 .79 .892 r
.49769 .8123 m .49546 .81472 L .49428 .81281 L F
.587 .753 .957 r
.4975 .81429 m .49546 .81472 L .49769 .8123 L F
.555 .851 .998 r
.48917 .82246 m .48866 .82309 L .49083 .8224 L F
.519 .11 .204 r
.4305 .8873 m .4313 .88924 L .42933 .88964 L F
.4305 .8873 m .43253 .88738 L .4313 .88924 L F
.501 0 0 r
.49584 .88647 m .49697 .88552 L .49901 .8863 L F
.244 .506 .903 r
.5022 .81664 m .5042 .81704 L .50273 .81608 L F
.752 .584 .668 r
.50273 .81608 m .50254 .81636 L .5022 .81664 L F
.50254 .81636 m .50112 .81857 L .5022 .81664 L F
.261 .768 .763 r
.5022 .81664 m .5014 .81697 L .50177 .81698 L F
.5022 .81664 m .50177 .81698 L .50319 .81705 L F
.5022 .81664 m .50028 .81719 L .5014 .81697 L F
.233 0 0 r
.50111 .88629 m .50212 .88552 L .50431 .88552 L F
.709 .368 .398 r
.43187 .83289 m .43278 .8337 L .43379 .83286 L F
.43187 .83289 m .43379 .83286 L .43423 .83327 L F
.249 0 .234 r
.43587 .83238 m .43379 .83286 L .43559 .83249 L F
.43587 .83238 m .43423 .83327 L .43379 .83286 L F
.501 0 0 r
.38205 .82748 m .38405 .82782 L .38521 .82721 L F
.291 0 0 r
.38521 .82721 m .38405 .82782 L .38721 .82712 L F
.602 .209 .271 r
.47158 .87968 m .47512 .87942 L .47359 .88121 L F
.731 .337 .305 r
.47512 .87942 m .47551 .88154 L .47359 .88121 L F
.47512 .87942 m .47717 .8814 L .47551 .88154 L F
.47512 .87942 m .47664 .87997 L .47717 .8814 L F
.211 .734 .838 r
.44956 .81828 m .44767 .81853 L .44616 .81846 L F
.501 .331 .582 r
.37065 .74923 m .37279 .74765 L .37021 .74866 L F
.122 0 0 r
.50877 .81484 m .50766 .81532 L .50559 .81557 L F
.632 .187 .176 r
.51078 .81517 m .50766 .81532 L .50877 .81484 L F
.834 .801 .82 r
.65843 .74854 m .65641 .75063 L .65807 .75051 L F
0 0 .382 r
.65641 .75063 m .65717 .75181 L .65807 .75051 L F
0 0 .355 r
.65831 .74922 m .65807 .75051 L .65912 .74909 L F
.48 .29 .545 r
.66251 .7496 m .66058 .7523 L .65933 .74881 L F
0 0 0 r
.65807 .75051 m .65717 .75181 L .65912 .74909 L F
.826 .977 .681 r
.65912 .74909 m .65717 .75181 L .65752 .74987 L F
.764 .44 .438 r
.65752 .74987 m .65984 .74897 L .65912 .74909 L F
.466 .332 .614 r
.66224 .74719 m .66251 .7496 L .65933 .74881 L F
.764 .44 .438 r
.65984 .74897 m .6606 .74867 L .65912 .74909 L F
0 0 .355 r
.65843 .74854 m .65831 .74922 L .65912 .74909 L F
.196 0 0 r
.52422 .86395 m .52231 .86448 L .52097 .86583 L F
.225 0 0 r
.41942 .83627 m .41726 .83786 L .41577 .83769 L F
.101 0 0 r
.42018 .83679 m .41942 .83627 L .42126 .83568 L F
.42018 .83679 m .41726 .83786 L .41942 .83627 L F
.628 .283 .367 r
.46281 .86827 m .46089 .86667 L .45965 .8688 L F
.562 .309 .491 r
.46281 .86827 m .46308 .86647 L .46089 .86667 L F
.878 .788 .295 r
.49767 .813 m .49911 .81239 L .50064 .8129 L F
.543 .85 .998 r
.5012 .81193 m .50064 .8129 L .49911 .81239 L F
.468 0 0 r
.48666 .88399 m .48849 .88477 L .48563 .88381 L F
.204 0 .107 r
.5206 .87194 m .52325 .86922 L .52235 .87137 L F
.328 0 .21 r
.52235 .87137 m .52325 .86922 L .5251 .86865 L F
.681 .472 .596 r
.49395 .82176 m .49417 .82648 L .49075 .82514 L F
.089 .024 .482 r
.49534 .82373 m .49395 .82176 L .49573 .82204 L F
.674 .714 .879 r
.49157 .82154 m .49514 .82197 L .49402 .81971 L F
.49514 .82197 m .49573 .82204 L .49535 .82153 L F
.49514 .82197 m .49535 .82153 L .49402 .81971 L F
.089 .024 .482 r
.49534 .82373 m .49417 .82648 L .49406 .82417 L F
.49471 .82284 m .49406 .82417 L .49395 .82176 L F
.49534 .82373 m .49406 .82417 L .49471 .82284 L F
.801 .728 .784 r
.49669 .84819 m .49685 .85017 L .49446 .85071 L F
0 0 .192 r
.49485 .85183 m .49446 .85071 L .49685 .85017 L F
0 0 .113 r
.49696 .85079 m .49685 .85017 L .49669 .84819 L F
.332 0 0 r
.49485 .85183 m .49685 .85017 L .49696 .85079 L F
.444 .124 .327 r
.37719 .79323 m .37991 .79211 L .37614 .79115 L F
.37719 .79323 m .37892 .79277 L .37991 .79211 L F
.381 .021 .223 r
.37719 .79323 m .37991 .79211 L .37892 .79277 L F
.394 .044 .248 r
.4903 .85371 m .48761 .85591 L .48956 .85523 L F
.324 0 .211 r
.49098 .85485 m .4903 .85371 L .48956 .85523 L F
0 0 0 r
.47089 .81344 m .46736 .81423 L .46938 .81382 L F
.239 .748 .719 r
.47296 .81281 m .47089 .81344 L .46938 .81382 L F
.696 .695 .845 r
.57005 .8286 m .56826 .83085 L .56694 .82853 L F
0 0 .213 r
.56901 .83157 m .56816 .83268 L .56826 .83085 L F
.26 0 0 r
.45297 .83047 m .45189 .831 L .44984 .83111 L F
.463 0 0 r
.45514 .83074 m .45189 .831 L .45297 .83047 L F
.467 .001 .062 r
.45796 .87994 m .4611 .87935 L .45947 .8807 L F
.51 0 0 r
.4611 .87935 m .46178 .88055 L .45947 .8807 L F
.4611 .87935 m .46308 .87991 L .46178 .88055 L F
.274 0 0 r
.50845 .80696 m .51168 .80805 L .50965 .80759 L F
.609 .385 .552 r
.44744 .88209 m .44517 .88439 L .44537 .88217 L F
.466 .332 .614 r
.66224 .74719 m .65933 .74881 L .6604 .74746 L F
0 .162 .655 r
.40545 .88231 m .4051 .8823 L .40416 .88133 L F
.2 0 0 r
.40517 .88285 m .40719 .88229 L .4051 .8823 L F
.40517 .88285 m .4051 .8823 L .40545 .88231 L F
.554 .153 .237 r
.38925 .82714 m .39137 .82739 L .39268 .82555 L F
.359 0 .055 r
.39137 .82739 m .39469 .82553 L .39268 .82555 L F
.201 0 0 r
.43236 .87419 m .43043 .87479 L .42904 .87621 L F
.662 .265 .283 r
.39402 .8425 m .39287 .84358 L .39092 .8426 L F
.223 0 0 r
.3958 .84264 m .39287 .84358 L .39402 .8425 L F
.639 .204 .199 r
.46827 .87962 m .47158 .87968 L .47034 .88116 L F
.623 .185 .188 r
.47034 .88116 m .47158 .87968 L .47359 .88121 L F
.226 0 0 r
.43781 .87301 m .43783 .87221 L .43643 .87362 L F
.43781 .87301 m .43985 .8721 L .43783 .87221 L F
.298 0 0 r
.40689 .89682 m .4104 .89472 L .40896 .8967 L F
.265 0 0 r
.40896 .8967 m .4104 .89472 L .41251 .89419 L F
.31 0 .112 r
.48377 .86159 m .48149 .8631 L .48285 .86324 L F
.497 .415 .694 r
.48607 .86355 m .48447 .86426 L .48377 .86159 L F
.727 .347 .33 r
.48285 .86324 m .48607 .86355 L .48377 .86159 L F
.993 .862 .521 r
.37279 .74765 m .37284 .74976 L .37574 .74792 L F
.238 0 0 r
.4579 .81658 m .45983 .81641 L .45977 .81591 L F
.382 0 .099 r
.45983 .81641 m .46195 .8161 L .45977 .81591 L F
.193 .723 .755 r
.45177 .81807 m .45486 .81752 L .45293 .81803 L F
.235 .753 .802 r
.49369 .8507 m .49446 .85071 L .49235 .85112 L F
.778 .564 .61 r
.49446 .85071 m .49234 .85246 L .49235 .85112 L F
.235 .753 .802 r
.49369 .8507 m .49235 .85112 L .49234 .85246 L F
.572 .371 .57 r
.48265 .81752 m .48262 .82048 L .48005 .82038 L F
.562 .362 .568 r
.4844 .81957 m .48262 .82048 L .48265 .81752 L F
.272 0 0 r
.48013 .81028 m .4822 .81013 L .48324 .80948 L F
.189 0 0 r
.4822 .81013 m .48517 .80905 L .48324 .80948 L F
.516 .302 .528 r
.53275 .86416 m .53494 .8615 L .53475 .86367 L F
.356 0 .043 r
.40302 .89739 m .4039 .89844 L .40161 .89918 L F
.40302 .89739 m .40495 .89715 L .4039 .89844 L F
0 .423 .836 r
.41892 .87614 m .41973 .87686 L .41811 .87604 L F
.179 0 0 r
.39552 .90013 m .3969 .90013 L .39449 .90123 L F
.772 .618 .688 r
.48304 .87375 m .4859 .87204 L .48369 .87229 L F
.518 .503 .779 r
.36598 .758 m .36508 .76081 L .36417 .75834 L F
.36598 .758 m .36678 .76028 L .36508 .76081 L F
.618 .49 .684 r
.36678 .76028 m .36498 .76306 L .36508 .76081 L F
.317 0 0 r
.40686 .84115 m .40525 .84132 L .40312 .84091 L F
.289 .787 .856 r
.40884 .84087 m .40525 .84132 L .40686 .84115 L F
.712 .262 .182 r
.49876 .87548 m .50004 .87437 L .49708 .87393 L F
.244 0 0 r
.50065 .87483 m .50004 .87437 L .49876 .87548 L F
.50065 .87483 m .50232 .87455 L .50004 .87437 L F
.014 0 .406 r
.51322 .81691 m .51226 .8177 L .51318 .81878 L F
.882 .787 .295 r
.51226 .8177 m .51161 .82016 L .51165 .81934 L F
.51226 .8177 m .51165 .81934 L .51212 .82019 L F
.321 0 .03 r
.41262 .87984 m .40913 .88187 L .41131 .88158 L F
.314 0 .075 r
.41448 .87943 m .41262 .87984 L .41131 .88158 L F
.738 .759 .87 r
.52288 .8338 m .52383 .8358 L .52064 .8358 L F
.098 .653 .791 r
.52064 .8358 m .52383 .8358 L .52267 .83572 L F
.279 .488 .882 r
.52483 .83483 m .52383 .8358 L .52288 .8338 L F
.544 .918 .94 r
.52267 .83572 m .52383 .8358 L .52483 .83483 L F
.72 .962 .943 r
.4591 .82917 m .45832 .83065 L .45985 .82972 L F
.744 .986 .899 r
.45746 .83049 m .45832 .83065 L .4591 .82917 L F
.542 .477 .732 r
.48149 .82125 m .48047 .82228 L .48005 .82038 L F
0 0 .449 r
.53966 .82507 m .53903 .82332 L .53891 .82157 L F
.183 .702 .881 r
.4251 .8199 m .42841 .82011 L .42639 .82017 L F
.188 .388 .829 r
.51891 .80867 m .51821 .8098 L .51715 .80899 L F
.683 .192 .077 r
.40154 .84135 m .39981 .84193 L .39803 .84049 L F
.227 0 0 r
.40312 .84091 m .39981 .84193 L .40154 .84135 L F
.391 0 0 r
.41973 .87686 m .42172 .87692 L .42156 .87661 L F
.637 .077 0 r
.42202 .8775 m .42172 .87692 L .42029 .87637 L F
.42369 .87859 m .42172 .87692 L .42202 .8775 L F
.391 0 0 r
.42156 .87661 m .42172 .87692 L .42261 .87646 L F
.448 0 0 r
.42261 .87646 m .42172 .87692 L .42486 .87656 L F
.754 .777 .872 r
.48588 .82037 m .48149 .82125 L .4844 .81957 L F
.542 .477 .732 r
.48149 .82125 m .48005 .82038 L .48262 .82048 L F
.636 .462 .63 r
.47042 .8616 m .47259 .86258 L .47259 .85902 L F
.478 .335 .608 r
.47259 .85902 m .47442 .86176 L .47421 .85833 L F
.47259 .85902 m .47259 .86258 L .47442 .86176 L F
.558 .124 .172 r
.52618 .86427 m .52766 .86346 L .52422 .86395 L F
.71 .452 .533 r
.52861 .86695 m .52766 .86346 L .52618 .86427 L F
.52861 .86695 m .52982 .86636 L .52766 .86346 L F
.255 0 0 r
.51956 .81778 m .51609 .81927 L .51749 .81843 L F
.644 .132 .013 r
.46605 .82891 m .46433 .82946 L .46194 .828 L F
.542 .079 .103 r
.46742 .82933 m .46433 .82946 L .46605 .82891 L F
.619 .459 .643 r
.66211 .74269 m .66436 .74267 L .66419 .74008 L F
.284 .037 .353 r
.66414 .74168 m .66419 .74008 L .66211 .74269 L F
.577 .692 .92 r
.66414 .74168 m .66436 .74267 L .66211 .74269 L F
.299 0 .089 r
.52982 .86636 m .53275 .86416 L .53154 .86574 L F
.288 0 .023 r
.53154 .86574 m .53275 .86416 L .53475 .86367 L F
.426 0 .071 r
.39469 .82553 m .39624 .82614 L .39794 .82449 L F
.359 0 0 r
.39624 .82614 m .39988 .82484 L .39794 .82449 L F
.98 .908 .659 r
.49662 .8192 m .49717 .82041 L .49831 .81771 L F
.828 .683 .702 r
.49767 .813 m .49831 .81771 L .4975 .81429 L F
0 0 0 r
.49901 .81735 m .49831 .81771 L .50028 .81719 L F
.49901 .81735 m .49662 .8192 L .49831 .81771 L F
.118 .286 .759 r
.52208 .81151 m .52171 .81318 L .52026 .81176 L F
.427 .86 .746 r
.52351 .81227 m .52171 .81318 L .5232 .81436 L F
.118 .286 .759 r
.52208 .81151 m .5232 .81436 L .52171 .81318 L F
.505 .099 .204 r
.50505 .87354 m .50232 .87455 L .50436 .8743 L F
.241 0 0 r
.50694 .87322 m .50505 .87354 L .50436 .8743 L F
.725 .899 .958 r
.47825 .82655 m .48161 .82575 L .48024 .82536 L F
.647 .811 .962 r
.48088 .82509 m .48161 .82575 L .48376 .82523 L F
.48088 .82509 m .48161 .82575 L .48376 .82523 L F
.795 .33 0 r
.48161 .82575 m .48172 .82672 L .48024 .82536 L F
.16 0 0 r
.42841 .82011 m .43048 .82005 L .43163 .81971 L F
.159 .699 .795 r
.43048 .82005 m .43367 .81981 L .43163 .81971 L F
.37 .081 .338 r
.39158 .88679 m .39473 .88341 L .39202 .8846 L F
.578 .42 .631 r
.3967 .87976 m .39692 .88219 L .3982 .8795 L F
.461 .753 .993 r
.52869 .80323 m .52766 .80429 L .52642 .80367 L F
.52869 .80323 m .52977 .80412 L .52766 .80429 L F
.509 .51 .793 r
.53096 .80716 m .52766 .80429 L .52977 .80412 L F
.917 .753 .664 r
.57407 .79663 m .57462 .79937 L .57362 .79953 L F
.829 .466 .368 r
.57408 .80118 m .57462 .79937 L .57362 .79953 L F
.983 .717 .444 r
.57667 .79583 m .576 .79628 L .57693 .79542 L F
.524 .362 .603 r
.576 .79628 m .57616 .79857 L .57407 .79663 L F
.296 .338 .736 r
.57616 .79857 m .57443 .79844 L .57513 .79762 L F
.983 .717 .444 r
.57515 .79819 m .57616 .79857 L .576 .79628 L F
.57515 .79819 m .57569 .79697 L .57667 .79583 L F
.57569 .79697 m .576 .79628 L .57667 .79583 L F
.296 .338 .736 r
.57616 .79857 m .57462 .79937 L .57443 .79844 L F
.57513 .79762 m .57443 .79844 L .57407 .79663 L F
0 0 .077 r
.57408 .80118 m .57462 .79937 L .57616 .79857 L F
.238 0 0 r
.4579 .81658 m .45683 .81715 L .45983 .81641 L F
.993 .862 .521 r
.37279 .74765 m .37236 .74987 L .37284 .74976 L F
.507 .745 .981 r
.66503 .74161 m .66432 .74211 L .66419 .74008 L F
.31 .683 .977 r
.66414 .74168 m .66503 .74161 L .66518 .74151 L F
.566 .428 .652 r
.6685 .73935 m .66668 .7424 L .66518 .74151 L F
.66668 .7424 m .66658 .74257 L .66518 .74151 L F
.31 .683 .977 r
.66503 .74161 m .66531 .74158 L .66518 .74151 L F
.66531 .74158 m .66571 .74155 L .66518 .74151 L F
.507 .745 .981 r
.66514 .74145 m .66503 .74161 L .66419 .74008 L F
.66503 .74161 m .66436 .74267 L .66432 .74211 L F
.66532 .74161 m .66658 .74257 L .66436 .74267 L F
.059 0 .452 r
.66436 .74267 m .66571 .74155 L .66535 .74158 L F
.66436 .74267 m .66535 .74158 L .66503 .74161 L F
.507 .745 .981 r
.66518 .74151 m .66532 .74161 L .66436 .74267 L F
.66518 .74151 m .66436 .74267 L .66514 .74145 L F
.059 0 .452 r
.66436 .74267 m .66503 .74161 L .66414 .74168 L F
.31 .683 .977 r
.66414 .74168 m .66518 .74151 L .66419 .74008 L F
.249 0 0 r
.43187 .83289 m .42967 .83394 L .42865 .83367 L F
.158 0 0 r
.43423 .83327 m .42967 .83394 L .43187 .83289 L F
.427 .86 .746 r
.52351 .81227 m .5232 .81436 L .52461 .81491 L F
.139 0 .06 r
.52346 .81661 m .52461 .81491 L .5232 .81436 L F
.688 .601 .753 r
.52351 .81227 m .52461 .81491 L .527 .81278 L F
.991 .75 .468 r
.52717 .82952 m .52799 .8304 L .52722 .83263 L F
.432 .767 .997 r
.52892 .82951 m .52799 .8304 L .52717 .82952 L F
.52892 .82951 m .53012 .83032 L .52799 .8304 L F
.456 .028 .135 r
.52799 .8304 m .52901 .83194 L .52722 .83263 L F
.52799 .8304 m .53012 .83032 L .52901 .83194 L F
.501 .331 .582 r
.37065 .74923 m .37236 .74987 L .37279 .74765 L F
.902 .632 .519 r
.47773 .8718 m .4759 .86917 L .47644 .87136 L F
0 .146 .688 r
.4793 .87289 m .47773 .8718 L .47644 .87136 L F
.4793 .87289 m .47979 .87392 L .47773 .8718 L F
.561 .18 .276 r
.45214 .87079 m .45044 .86954 L .44933 .87123 L F
.176 0 0 r
.5278 .8083 m .52481 .80951 L .52532 .80752 L F
.941 .789 .327 r
.52532 .80752 m .52481 .80951 L .52498 .80695 L F
.57 .041 0 r
.46645 .87915 m .46741 .88048 L .46531 .88046 L F
.46645 .87915 m .46827 .87962 L .46741 .88048 L F
.71 .483 .579 r
.4736 .8691 m .4736 .86607 L .47132 .86626 L F
.794 .687 .746 r
.4736 .8691 m .47645 .86696 L .4736 .86607 L F
0 0 0 r
.47658 .86073 m .47567 .86174 L .47717 .85851 L F
.573 .935 .924 r
.47442 .86176 m .47567 .86174 L .47658 .86073 L F
.638 .495 .672 r
.50477 .82069 m .50435 .82226 L .50661 .82002 L F
0 0 0 r
.43367 .81981 m .4357 .81973 L .43693 .81967 L F
.271 .765 .899 r
.4357 .81973 m .43894 .81966 L .43693 .81967 L F
.113 .665 .778 r
.44373 .87142 m .44287 .87157 L .44186 .87176 L F
.44373 .87142 m .44496 .87143 L .44287 .87157 L F
.144 0 0 r
.47042 .8616 m .46724 .86346 L .4692 .86208 L F
.686 .326 .358 r
.47218 .86334 m .47259 .86258 L .47042 .8616 L F
.74 .274 .14 r
.47218 .86334 m .47042 .8616 L .4692 .86208 L F
.686 .326 .358 r
.47218 .86334 m .47259 .86258 L .47042 .8616 L F
.472 0 0 r
.45666 .88089 m .45796 .87994 L .45947 .8807 L F
.23 0 0 r
.4165 .89386 m .41781 .89229 L .41963 .89188 L F
.468 .844 .611 r
.50839 .88142 m .51147 .87918 L .50985 .88122 L F
0 0 0 r
.51147 .87918 m .51425 .87725 L .51276 .87872 L F
.50985 .88122 m .51147 .87918 L .51276 .87872 L F
.266 .771 .858 r
.40416 .88133 m .40364 .88152 L .40109 .88156 L F
.172 0 0 r
.46195 .8161 m .46399 .8158 L .46542 .81492 L F
0 0 0 r
.46542 .81492 m .46641 .81478 L .46736 .81423 L F
.46542 .81492 m .46399 .8158 L .46641 .81478 L F
.361 .129 .421 r
.48399 .86616 m .48447 .86426 L .48607 .86355 L F
.689 .602 .754 r
.50537 .86371 m .50635 .86666 L .50856 .86466 L F
.527 .09 .153 r
.40191 .82445 m .40394 .82471 L .40527 .82324 L F
.396 0 .062 r
.40527 .82324 m .40697 .82363 L .40733 .82307 L F
.40527 .82324 m .40394 .82471 L .40697 .82363 L F
.294 0 0 r
.53012 .83032 m .53327 .83035 L .53215 .83057 L F
.53215 .83057 m .53327 .83035 L .53012 .83032 L F
.545 .929 .863 r
.53388 .82958 m .53327 .83035 L .53215 .83057 L F
.53388 .82958 m .53327 .83035 L .53215 .83057 L F
.511 .586 .866 r
.53764 .81217 m .53417 .80961 L .53579 .80987 L F
.317 .533 .905 r
.53901 .81226 m .53764 .81217 L .53579 .80987 L F
.672 .863 .972 r
.49181 .81465 m .48986 .81551 L .48843 .81485 L F
.738 .319 .255 r
.47717 .8814 m .48011 .88183 L .47861 .88221 L F
.677 .221 .162 r
.47861 .88221 m .48011 .88183 L .48228 .88333 L F
0 0 0 r
.47241 .82566 m .47178 .82725 L .47061 .82786 L F
.649 .265 .303 r
.47494 .82718 m .47178 .82725 L .47241 .82566 L F
.266 0 0 r
.46194 .828 m .4591 .82917 L .45985 .82972 L F
.681 .979 .87 r
.49803 .80502 m .49519 .80645 L .49592 .8059 L F
.145 .577 .929 r
.42029 .87637 m .41973 .87686 L .41892 .87614 L F
.25 .716 .946 r
.42029 .87637 m .42172 .87692 L .41973 .87686 L F
.694 .307 .31 r
.53088 .80953 m .53304 .81145 L .53417 .80961 L F
.861 .745 .733 r
.53343 .80699 m .53269 .80945 L .53417 .80961 L F
0 0 0 r
.53417 .80961 m .535 .80944 L .53551 .80982 L F
.099 0 .152 r
.535 .80944 m .53304 .81145 L .53429 .8109 L F
0 0 0 r
.535 .80944 m .53518 .81034 L .53446 .80905 L F
.535 .80944 m .53446 .80905 L .53388 .80799 L F
.53551 .80982 m .535 .80944 L .53579 .80987 L F
.53417 .80961 m .53304 .81145 L .535 .80944 L F
.766 .984 .905 r
.46832 .86645 m .47048 .86527 L .46869 .86521 L F
.761 .577 .648 r
.46832 .86645 m .47132 .86626 L .47048 .86527 L F
.785 .985 .898 r
.46869 .86521 m .47048 .86527 L .47218 .86334 L F
.413 0 .093 r
.45633 .87084 m .45571 .86931 L .45435 .87101 L F
.45633 .87084 m .45786 .86913 L .45571 .86931 L F
.265 0 .054 r
.48727 .80906 m .48891 .80901 L .49106 .80644 L F
.521 .127 .234 r
.49106 .80644 m .48891 .80901 L .49377 .80766 L F
0 0 0 r
.51276 .87872 m .51425 .87725 L .51537 .87641 L F
.658 .429 .562 r
.46824 .86882 m .47132 .86626 L .46832 .86645 L F
.46824 .86882 m .47136 .86859 L .47132 .86626 L F
.71 .483 .579 r
.4736 .8691 m .47132 .86626 L .47136 .86859 L F
.03 0 0 r
.5063 .81606 m .50559 .81557 L .50766 .81532 L F
.52 .091 .167 r
.44302 .88439 m .44384 .88603 L .44181 .88619 L F
.44302 .88439 m .44517 .88439 L .44384 .88603 L F
.57 .393 .602 r
.48177 .85352 m .4818 .85596 L .4797 .85612 L F
.4797 .85612 m .4818 .85596 L .48177 .85352 L F
0 0 0 r
.37991 .79211 m .37892 .79277 L .38143 .79129 L F
.37991 .79211 m .37892 .79277 L .38143 .79129 L F
.632 .187 .176 r
.51078 .81517 m .51089 .81687 L .50766 .81532 L F
.063 .605 .847 r
.51517 .81627 m .51377 .81585 L .51219 .8157 L F
.113 0 0 r
.51219 .8157 m .51377 .81585 L .5125 .81576 L F
.115 0 .179 r
.51219 .8157 m .51127 .81552 L .51322 .81691 L F
.51219 .8157 m .51078 .81517 L .51127 .81552 L F
.51219 .8157 m .51089 .81687 L .51078 .81517 L F
.354 0 0 r
.50766 .81532 m .51089 .81687 L .50848 .81583 L F
.739 .784 .889 r
.50848 .81583 m .51219 .8157 L .51032 .81562 L F
.113 0 0 r
.51219 .8157 m .5125 .81576 L .51032 .81562 L F
.971 .811 .625 r
.56713 .82505 m .56694 .82853 L .5667 .82741 L F
.91 .949 .813 r
.56694 .82853 m .56498 .83052 L .5667 .82741 L F
.971 .811 .625 r
.56694 .82853 m .56713 .82505 L .5667 .82741 L F
.546 .742 .967 r
.56894 .82753 m .56694 .82853 L .5667 .82741 L F
.56894 .82753 m .57005 .8286 L .56694 .82853 L F
.741 .272 .133 r
.48563 .88381 m .48849 .88477 L .48751 .88572 L F
.58 .073 .012 r
.48751 .88572 m .48849 .88477 L .49055 .88588 L F
.085 0 0 r
.43894 .81966 m .44097 .81966 L .44211 .81951 L F
.13 .677 .724 r
.44211 .81951 m .44097 .81966 L .4441 .8192 L F
.448 .034 .16 r
.4139 .83805 m .41256 .83985 L .41054 .83991 L F
.418 .021 .176 r
.41577 .83769 m .41256 .83985 L .4139 .83805 L F
.609 .385 .552 r
.44744 .88209 m .44758 .88432 L .44517 .88439 L F
.584 .269 .401 r
.44744 .88209 m .44927 .88398 L .44758 .88432 L F
.44744 .88209 m .45021 .88162 L .44927 .88398 L F
.858 .687 .669 r
.56713 .82505 m .56435 .82704 L .56595 .82475 L F
.56713 .82505 m .5667 .82741 L .56435 .82704 L F
.077 0 .409 r
.56833 .82658 m .5667 .82741 L .56713 .82505 L F
.56833 .82658 m .56713 .82505 L .56637 .82486 L F
.56833 .82658 m .56637 .82486 L .5667 .82533 L F
.5667 .82533 m .56637 .82486 L .56595 .82475 L F
.56833 .82658 m .56595 .82475 L .56803 .82425 L F
0 0 .425 r
.56904 .82565 m .56833 .82658 L .56803 .82425 L F
.56904 .82565 m .56803 .82425 L .56753 .82649 L F
.56762 .82662 m .56753 .82649 L .56748 .82672 L F
.56904 .82565 m .56753 .82649 L .56762 .82662 L F
.39 0 0 r
.42516 .8896 m .42546 .89105 L .42362 .89131 L F
.42516 .8896 m .4272 .88959 L .42546 .89105 L F
.521 0 0 r
.5054 .80604 m .50845 .80696 L .50708 .80625 L F
.677 .505 .646 r
.47061 .82786 m .47111 .83058 L .46915 .83003 L F
.738 .631 .74 r
.47494 .82718 m .47303 .82987 L .47178 .82725 L F
.886 .88 .823 r
.4733 .82798 m .47494 .82718 L .4742 .82728 L F
.29 .393 .796 r
.47178 .82725 m .47261 .82898 L .47061 .82786 L F
.47261 .82898 m .47237 .82932 L .47061 .82786 L F
.543 .415 .656 r
.47303 .82987 m .47111 .83058 L .47061 .82786 L F
.886 .88 .823 r
.47176 .8292 m .47301 .82841 L .4733 .82798 L F
.47301 .82841 m .47494 .82718 L .4733 .82798 L F
.29 .393 .796 r
.47261 .82898 m .47303 .82987 L .47237 .82932 L F
.772 .618 .688 r
.48304 .87375 m .48628 .87419 L .4859 .87204 L F
.638 .528 .712 r
.4859 .87204 m .48828 .87226 L .48696 .87138 L F
.4859 .87204 m .48628 .87419 L .48828 .87226 L F
.382 0 0 r
.40733 .82307 m .40905 .82357 L .41055 .82288 L F
.393 0 0 r
.40905 .82357 m .41258 .82265 L .41055 .82288 L F
.467 .019 .102 r
.43253 .88738 m .43328 .88893 L .4313 .88924 L F
.43253 .88738 m .43468 .88744 L .43328 .88893 L F
.46 .31 .59 r
.61729 .76019 m .61904 .75993 L .61711 .75914 L F
.61711 .75914 m .61904 .75993 L .61729 .76019 L F
.617 .329 .459 r
.38542 .84318 m .38527 .84498 L .38241 .8454 L F
.59 .307 .455 r
.38542 .84318 m .38713 .84486 L .38527 .84498 L F
.623 .302 .407 r
.38752 .84374 m .38713 .84486 L .38542 .84318 L F
.445 .807 .996 r
.48249 .85268 m .48391 .85331 L .48177 .85352 L F
.541 .37 .599 r
.4838 .85557 m .48177 .85352 L .48391 .85331 L F
.4838 .85557 m .4818 .85596 L .48177 .85352 L F
0 0 .308 r
.48177 .85352 m .48243 .85512 L .48249 .85268 L F
.48177 .85352 m .4818 .85596 L .48243 .85512 L F
0 .495 .702 r
.48501 .87402 m .48628 .87419 L .48304 .87375 L F
0 .539 .738 r
.48822 .87439 m .48628 .87419 L .48501 .87402 L F
.612 .426 .606 r
.47645 .86696 m .47884 .86641 L .47871 .86362 L F
.678 .477 .607 r
.47884 .86641 m .48149 .8631 L .47871 .86362 L F
0 0 .355 r
.65843 .74854 m .65912 .74909 L .6604 .74746 L F
0 0 0 r
.6604 .74746 m .66156 .74716 L .66224 .74719 L F
.6604 .74746 m .65912 .74909 L .66156 .74716 L F
.516 .774 .99 r
.36479 .75709 m .36417 .75834 L .36283 .75801 L F
.36479 .75709 m .36598 .758 L .36417 .75834 L F
.183 .71 .706 r
.47751 .81137 m .47879 .81103 L .48013 .81028 L F
.47751 .81137 m .47681 .81152 L .47879 .81103 L F
.503 .109 .226 r
.37868 .82921 m .38064 .82943 L .38205 .82748 L F
.451 .014 .115 r
.38064 .82943 m .38405 .82782 L .38205 .82748 L F
.65 .135 .002 r
.46741 .88048 m .46827 .87962 L .47034 .88116 L F
.836 .603 .587 r
.65591 .75278 m .65608 .75533 L .65299 .75391 L F
.65591 .75278 m .65299 .75391 L .65424 .75384 L F
0 0 .382 r
.65641 .75063 m .65591 .75278 L .65717 .75181 L F
.455 .847 .64 r
.65591 .75278 m .65424 .75384 L .65717 .75181 L F
.561 .352 .555 r
.65839 .75257 m .65608 .75533 L .65591 .75278 L F
.836 .998 .784 r
.49669 .84819 m .49369 .8507 L .49487 .84757 L F
.304 .737 .969 r
.49875 .8481 m .49669 .84819 L .49487 .84757 L F
0 0 .113 r
.49696 .85079 m .49669 .84819 L .49875 .8481 L F
.304 .737 .969 r
.49875 .8481 m .49487 .84757 L .49641 .84643 L F
.601 .343 .499 r
.49641 .84707 m .49731 .84966 L .49667 .84699 L F
.49487 .84757 m .49571 .84829 L .49641 .84707 L F
.836 .998 .784 r
.49669 .84819 m .49446 .85071 L .49433 .85071 L F
.49669 .84819 m .49433 .85071 L .49493 .84966 L F
.601 .343 .499 r
.49571 .84829 m .49731 .84966 L .49641 .84707 L F
.836 .998 .784 r
.49493 .84966 m .49433 .85071 L .49369 .8507 L F
0 .198 .728 r
.48149 .8631 m .48399 .86616 L .48285 .86324 L F
.47 .152 .344 r
.3893 .84432 m .38752 .84374 L .39092 .8426 L F
.299 0 0 r
.39287 .84358 m .3893 .84432 L .39092 .8426 L F
.878 .788 .295 r
.49767 .813 m .49769 .8123 L .49911 .81239 L F
.49767 .813 m .4975 .81429 L .49769 .8123 L F
.41 0 0 r
.39796 .89944 m .39973 .8995 L .3969 .90013 L F
.132 0 0 r
.56668 .79929 m .56966 .79725 L .56822 .79915 L F
.069 0 0 r
.56813 .79909 m .56966 .79725 L .56668 .79929 L F
.943 .729 .259 r
.56668 .79929 m .56669 .80157 L .5663 .80144 L F
.723 .755 .878 r
.56822 .79915 m .56669 .80157 L .56668 .79929 L F
.943 .729 .259 r
.56668 .79929 m .5663 .80144 L .56813 .79909 L F
.239 .748 .719 r
.47296 .81281 m .46938 .81382 L .47144 .81338 L F
.419 0 .017 r
.47144 .81338 m .47486 .8121 L .47296 .81281 L F
.778 .564 .61 r
.49446 .85071 m .49444 .85354 L .49234 .85246 L F
0 0 .192 r
.49485 .85183 m .49444 .85354 L .49446 .85071 L F
.441 .204 .457 r
.46489 .86604 m .46308 .86647 L .46281 .86827 L F
.482 .21 .425 r
.51685 .86681 m .51448 .86871 L .5165 .86833 L F
.523 .217 .39 r
.51885 .86693 m .51685 .86681 L .5165 .86833 L F
.65 .361 .468 r
.52875 .81427 m .52869 .81244 L .527 .81278 L F
.327 .12 .437 r
.53082 .81155 m .52869 .81244 L .52875 .81427 L F
.347 .82 .769 r
.47717 .85851 m .47736 .85835 L .47847 .85789 L F
0 0 .135 r
.47847 .85789 m .47658 .86073 L .47717 .85851 L F
.184 0 0 r
.44984 .83111 m .44841 .83177 L .44632 .83189 L F
.344 0 0 r
.45189 .831 m .44841 .83177 L .44984 .83111 L F
.819 .784 .82 r
.5745 .81063 m .57556 .81199 L .57384 .81251 L F
.609 .223 .286 r
.57384 .81251 m .57556 .81199 L .57416 .81305 L F
.6 .717 .927 r
.57691 .81144 m .57556 .81199 L .5745 .81063 L F
.002 0 0 r
.57416 .81305 m .57556 .81199 L .57691 .81144 L F
.318 0 0 r
.46178 .88055 m .46308 .87991 L .46531 .88046 L F
.729 .693 .816 r
.53738 .81674 m .53891 .81931 L .53995 .81695 L F
.794 .975 .688 r
.57022 .79585 m .57121 .79517 L .56966 .79725 L F
.772 .931 .572 r
.57022 .79585 m .56966 .79725 L .56813 .79909 L F
.71 .629 .765 r
.57121 .79517 m .57196 .79687 L .56966 .79725 L F
.801 .576 .597 r
.57196 .79687 m .56822 .79915 L .56966 .79725 L F
.304 .469 .859 r
.53377 .81651 m .53383 .81496 L .53227 .81424 L F
.53377 .81651 m .53543 .81757 L .53383 .81496 L F
.723 .755 .878 r
.56822 .79915 m .56988 .80184 L .56669 .80157 L F
.318 .541 .911 r
.57097 .80099 m .56988 .80184 L .56822 .79915 L F
.479 .852 .986 r
.56891 .80146 m .56988 .80184 L .57097 .80099 L F
.226 0 0 r
.57045 .80126 m .56891 .80146 L .57097 .80099 L F
.315 .764 .958 r
.56748 .80164 m .56988 .80184 L .56891 .80146 L F
.226 0 0 r
.5677 .80273 m .56891 .80146 L .57045 .80126 L F
.315 .764 .958 r
.56669 .80157 m .56748 .80164 L .56891 .80146 L F
.578 .509 .741 r
.48761 .85591 m .48841 .85887 L .48931 .85669 L F
.688 .165 0 r
.42283 .8378 m .42018 .83679 L .42126 .83568 L F
.196 0 0 r
.52422 .86395 m .52097 .86583 L .52316 .86608 L F
.554 .113 .157 r
.52563 .8658 m .52422 .86395 L .52316 .86608 L F
.52563 .8658 m .52618 .86427 L .52422 .86395 L F
.433 0 .003 r
.38405 .82782 m .38602 .82787 L .38721 .82712 L F
.455 0 .06 r
.38602 .82787 m .38925 .82714 L .38721 .82712 L F
.653 .298 .357 r
.42486 .87656 m .42172 .87692 L .42369 .87859 L F
.526 .162 .291 r
.42568 .87859 m .42486 .87656 L .42369 .87859 L F
.42568 .87859 m .42702 .87649 L .42486 .87656 L F
.801 .576 .597 r
.57196 .79687 m .57195 .79917 L .56822 .79915 L F
.698 .7 .848 r
.57321 .79436 m .57196 .79687 L .57121 .79517 L F
.57321 .79436 m .57407 .79663 L .57196 .79687 L F
.769 .607 .677 r
.57407 .79663 m .57195 .79917 L .57196 .79687 L F
.948 .67 .477 r
.49017 .84311 m .49042 .84559 L .48894 .8441 L F
0 0 .45 r
.4912 .84433 m .49042 .84559 L .49017 .84311 L F
.4912 .84433 m .49017 .84311 L .48894 .8441 L F
.105 0 .07 r
.51448 .86871 m .51183 .87169 L .51372 .87126 L F
.421 .126 .357 r
.5165 .86833 m .51448 .86871 L .51372 .87126 L F
.794 .687 .746 r
.4736 .8691 m .4759 .86917 L .47645 .86696 L F
.776 .487 .497 r
.47644 .87136 m .4759 .86917 L .4736 .8691 L F
.201 0 0 r
.43236 .87419 m .42904 .87621 L .43109 .87601 L F
.444 .078 .248 r
.43321 .8761 m .43236 .87419 L .43109 .87601 L F
.43321 .8761 m .4344 .87391 L .43236 .87419 L F
.366 .188 .502 r
.3982 .8795 m .39692 .88219 L .39791 .88101 L F
.556 .36 .57 r
.39791 .88101 m .40109 .88156 L .3982 .8795 L F
0 0 0 r
.52288 .8338 m .52064 .8358 L .52249 .83433 L F
.53 .587 .856 r
.52249 .83433 m .52064 .8358 L .52267 .83572 L F
.729 .841 .934 r
.4844 .81957 m .48149 .82125 L .48262 .82048 L F
.506 .163 .321 r
.45021 .88162 m .4512 .88364 L .44927 .88398 L F
.45021 .88162 m .45199 .8814 L .4512 .88364 L F
.769 .607 .677 r
.57407 .79663 m .57362 .79953 L .57195 .79917 L F
.558 .518 .767 r
.57498 .79244 m .57407 .79663 L .57321 .79436 L F
.57498 .79244 m .576 .79628 L .57407 .79663 L F
.134 0 .121 r
.54241 .82411 m .54392 .82248 L .54428 .82366 L F
.288 .284 .68 r
.54569 .82157 m .54392 .82248 L .54391 .81953 L F
.029 0 .144 r
.54428 .82366 m .54392 .82248 L .54569 .82157 L F
.5 .053 .12 r
.43468 .88744 m .43772 .88674 L .43623 .88834 L F
.277 0 0 r
.43623 .88834 m .43772 .88674 L .43981 .88628 L F
.445 .01 .116 r
.66658 .74257 m .66563 .74404 L .66436 .74267 L F
.566 .428 .652 r
.6685 .73935 m .66905 .7419 L .66658 .74257 L F
.655 .364 .465 r
.66699 .74359 m .66846 .74354 L .66642 .7439 L F
.6677 .74318 m .66846 .74354 L .6663 .74362 L F
.66793 .74322 m .66846 .74354 L .6673 .74299 L F
.6663 .74362 m .66699 .74359 L .66563 .74404 L F
.66699 .74359 m .66642 .7439 L .66563 .74404 L F
.73 .623 .738 r
.66563 .74404 m .66642 .7439 L .66667 .74341 L F
.655 .364 .465 r
.66639 .74356 m .66563 .74404 L .66572 .7439 L F
.66639 .74356 m .66572 .7439 L .66658 .74257 L F
.73 .623 .738 r
.66563 .74404 m .66667 .74341 L .66617 .74339 L F
.655 .364 .465 r
.6673 .74299 m .6677 .74318 L .6663 .74362 L F
.389 0 .024 r
.66738 .74344 m .66777 .74316 L .66602 .74332 L F
.73 .623 .738 r
.66563 .74404 m .66617 .74339 L .66566 .74314 L F
.389 0 .024 r
.66617 .74339 m .66602 .74332 L .66549 .74337 L F
.655 .364 .465 r
.66742 .74292 m .66639 .74356 L .66648 .74308 L F
.389 0 .024 r
.66738 .74344 m .66602 .74332 L .66617 .74339 L F
.547 .222 .369 r
.66757 .74169 m .6685 .73935 L .66518 .74151 L F
.66757 .74169 m .66518 .74151 L .66571 .74155 L F
.73 .623 .738 r
.66566 .74314 m .66757 .74169 L .66571 .74155 L F
.666 .74331 m .66757 .74169 L .66566 .74314 L F
.786 .742 .812 r
.66584 .74304 m .66625 .74306 L .66757 .74169 L F
.655 .364 .465 r
.66905 .7419 m .66742 .74292 L .66658 .74257 L F
.66742 .74292 m .66648 .74308 L .66658 .74257 L F
.786 .742 .812 r
.66625 .74306 m .66734 .74309 L .66757 .74169 L F
.73 .623 .738 r
.66617 .74339 m .66757 .74169 L .666 .74331 L F
.271 0 0 r
.66787 .74312 m .66776 .74334 L .66799 .74324 L F
.66785 .7431 m .66783 .74314 L .66787 .74312 L F
.389 0 .024 r
.66777 .74316 m .66783 .74314 L .66785 .7431 L F
.66777 .74316 m .66785 .7431 L .66766 .74313 L F
.66777 .74316 m .66766 .74313 L .66548 .74337 L F
.655 .364 .465 r
.66742 .74292 m .66773 .7431 L .6673 .74299 L F
.66773 .7431 m .66793 .74322 L .66766 .74313 L F
.66773 .7431 m .66766 .74313 L .6673 .74299 L F
.786 .742 .812 r
.66773 .7431 m .66785 .7431 L .66784 .74306 L F
.524 .564 .838 r
.66791 .74309 m .66785 .7431 L .66792 .74309 L F
.655 .364 .465 r
.66854 .7433 m .66846 .74354 L .66782 .74316 L F
.271 0 0 r
.66785 .7431 m .66787 .74312 L .66792 .74309 L F
.655 .364 .465 r
.66792 .74309 m .66782 .74316 L .66742 .74292 L F
.66854 .7433 m .66782 .74316 L .66792 .74309 L F
.327 .042 .319 r
.67073 .74123 m .66846 .74354 L .66905 .7419 L F
.655 .364 .465 r
.66905 .7419 m .66854 .7433 L .66742 .74292 L F
.524 .564 .838 r
.66757 .74169 m .6678 .74285 L .66839 .74275 L F
.489 .378 .653 r
.67073 .74123 m .66905 .7419 L .6685 .73935 L F
.746 .629 .73 r
.66757 .74169 m .66851 .74291 L .67073 .74123 L F
.66825 .7431 m .66967 .7423 L .67073 .74123 L F
.524 .564 .838 r
.66757 .74169 m .66839 .74275 L .66967 .74254 L F
.6678 .74285 m .66785 .7431 L .66967 .74254 L F
.746 .629 .73 r
.66757 .74169 m .66825 .7431 L .66851 .74291 L F
.524 .564 .838 r
.66967 .74254 m .6685 .7429 L .66988 .74262 L F
.6685 .7429 m .66791 .74309 L .66853 .74294 L F
.746 .629 .73 r
.66853 .74294 m .66876 .74323 L .66967 .7423 L F
.524 .564 .838 r
.6685 .7429 m .66853 .74294 L .66988 .74262 L F
.746 .629 .73 r
.66825 .7431 m .66846 .74354 L .66876 .74323 L F
.66825 .7431 m .66876 .74323 L .66853 .74294 L F
.559 .533 .782 r
.66988 .74262 m .67058 .74316 L .66846 .74354 L F
.568 .292 .458 r
.67034 .7451 m .66846 .74354 L .67058 .74316 L F
.67034 .7451 m .66793 .74562 L .66846 .74354 L F
.271 0 0 r
.66853 .74294 m .66915 .74445 L .66988 .74262 L F
.786 .742 .812 r
.66734 .74309 m .66773 .7431 L .6678 .74285 L F
.66773 .7431 m .66784 .74306 L .6678 .74285 L F
.66734 .74309 m .6678 .74285 L .66757 .74169 L F
.73 .623 .738 r
.66667 .74341 m .66817 .74315 L .66757 .74169 L F
.66817 .74315 m .66826 .74313 L .66825 .7431 L F
.271 0 0 r
.66792 .74309 m .66804 .74322 L .66853 .74294 L F
.73 .623 .738 r
.66817 .74315 m .66825 .7431 L .66757 .74169 L F
.6675 .74345 m .66826 .74313 L .66667 .74341 L F
.059 0 .452 r
.66436 .74267 m .66556 .74396 L .66571 .74155 L F
.389 0 .024 r
.66549 .74337 m .66548 .74337 L .66541 .74337 L F
.66777 .74316 m .66548 .74337 L .66549 .74337 L F
.786 .742 .812 r
.66575 .74334 m .66785 .7431 L .66584 .74304 L F
.73 .623 .738 r
.66617 .74339 m .66667 .74341 L .66757 .74169 L F
.786 .742 .812 r
.66541 .74337 m .66575 .74334 L .66584 .74304 L F
.059 0 .452 r
.66556 .74396 m .66564 .74367 L .66571 .74155 L F
.732 .623 .737 r
.66757 .74169 m .66825 .7431 L .66541 .74337 L F
.73 .623 .738 r
.66799 .74324 m .66846 .74354 L .66826 .74313 L F
.389 0 .024 r
.66738 .74344 m .66783 .74314 L .66777 .74316 L F
.73 .623 .738 r
.66642 .7439 m .66694 .74381 L .66784 .74332 L F
.271 0 0 r
.66783 .74314 m .66773 .74335 L .66787 .74312 L F
.324 .07 .366 r
.66846 .74354 m .66637 .74611 L .66571 .74422 L F
.66846 .74354 m .66571 .74422 L .66674 .74378 L F
.73 .623 .738 r
.66642 .7439 m .66784 .74332 L .66773 .74335 L F
.66694 .74381 m .66846 .74354 L .66799 .74324 L F
.66642 .7439 m .6675 .74345 L .66667 .74341 L F
.324 .07 .366 r
.66846 .74354 m .66561 .74393 L .66727 .74347 L F
.271 0 0 r
.66773 .74335 m .66691 .74505 L .66777 .74333 L F
.66773 .74335 m .66777 .74333 L .66787 .74312 L F
.324 .07 .366 r
.66674 .74378 m .66571 .74422 L .66561 .74393 L F
.059 0 .452 r
.66556 .74396 m .66563 .74404 L .66564 .74367 L F
.324 .07 .366 r
.66727 .74347 m .66561 .74393 L .66541 .74337 L F
.389 0 .024 r
.66738 .74344 m .66743 .74343 L .66738 .74344 L F
.73 .605 .718 r
.66481 .74415 m .66637 .74611 L .66331 .74609 L F
.66541 .74337 m .66561 .74393 L .66481 .74415 L F
.66561 .74393 m .66637 .74611 L .66481 .74415 L F
.73 .623 .738 r
.66773 .74335 m .66784 .74332 L .66799 .74324 L F
.271 0 0 r
.66787 .74312 m .66799 .74324 L .66792 .74309 L F
.66799 .74324 m .66804 .74322 L .66792 .74309 L F
.66804 .74322 m .66804 .74322 L .66825 .7431 L F
.732 .623 .737 r
.66825 .7431 m .66784 .74332 L .66541 .74337 L F
.66784 .74332 m .66754 .74349 L .66727 .74347 L F
.389 0 .024 r
.66738 .74345 m .66743 .74343 L .66738 .74344 L F
.66742 .74344 m .66743 .74343 L .66738 .74345 L F
.66743 .74343 m .66743 .74343 L .66738 .74344 L F
.66743 .74343 m .66783 .74314 L .66738 .74344 L F
.66738 .74344 m .66549 .74337 L .66541 .74337 L F
.732 .623 .737 r
.66784 .74332 m .66727 .74347 L .66541 .74337 L F
.389 0 .024 r
.66735 .74346 m .66742 .74344 L .66738 .74345 L F
.66489 .74524 m .6674 .74345 L .66735 .74346 L F
.6674 .74345 m .66743 .74343 L .66735 .74346 L F
.324 .07 .366 r
.66846 .74354 m .66793 .74562 L .66637 .74611 L F
.271 0 0 r
.66799 .74324 m .66915 .74445 L .66804 .74322 L F
.732 .623 .737 r
.66799 .74324 m .66846 .74354 L .66754 .74349 L F
.271 0 0 r
.66799 .74324 m .66691 .74505 L .66915 .74445 L F
.732 .623 .737 r
.66825 .7431 m .66826 .74313 L .66799 .74324 L F
.66826 .74313 m .66846 .74354 L .66799 .74324 L F
.271 0 0 r
.66804 .74322 m .66804 .74322 L .66825 .7431 L F
.559 .533 .782 r
.66988 .74262 m .66846 .74354 L .66825 .7431 L F
.271 0 0 r
.66824 .74311 m .66825 .7431 L .66853 .74294 L F
.524 .564 .838 r
.66791 .74309 m .66792 .74309 L .66988 .74262 L F
.559 .533 .782 r
.66988 .74262 m .66825 .7431 L .66757 .74169 L F
.271 0 0 r
.66804 .74322 m .66825 .7431 L .66824 .74311 L F
.66804 .74322 m .66915 .74445 L .66853 .74294 L F
.389 0 .024 r
.66489 .74524 m .66738 .74344 L .66541 .74337 L F
.271 0 0 r
.66776 .74334 m .66691 .74505 L .66799 .74324 L F
.389 0 .024 r
.66489 .74524 m .66691 .74505 L .66783 .74314 L F
.37 .081 .338 r
.39158 .88679 m .3932 .8867 L .39473 .88341 L F
.604 .378 .546 r
.39473 .88341 m .39613 .88403 L .39692 .88219 L F
.699 .457 .553 r
.3932 .8867 m .39613 .88403 L .39473 .88341 L F
.689 .602 .754 r
.50537 .86371 m .50856 .86466 L .5076 .86334 L F
.275 0 0 r
.46915 .83003 m .46982 .83036 L .46742 .82933 L F
.46915 .83003 m .47111 .83058 L .46982 .83036 L F
.359 0 .055 r
.39137 .82739 m .39336 .8271 L .39469 .82553 L F
.373 0 .024 r
.39336 .8271 m .39624 .82614 L .39469 .82553 L F
.829 .678 .695 r
.4253 .83482 m .42458 .83654 L .42865 .83367 L F
.4253 .83482 m .42865 .83367 L .42741 .83464 L F
.193 0 0 r
.42928 .83432 m .42865 .83367 L .42967 .83394 L F
.42928 .83432 m .42741 .83464 L .42865 .83367 L F
.211 .734 .838 r
.44956 .81828 m .44616 .81846 L .44835 .81834 L F
.527 .014 0 r
.44835 .81834 m .45177 .81807 L .44956 .81828 L F
.463 0 0 r
.45514 .83074 m .45482 .83201 L .45189 .831 L F
.006 0 0 r
.45607 .83109 m .45514 .83074 L .45746 .83049 L F
.45607 .83109 m .45482 .83201 L .45514 .83074 L F
.448 .212 .463 r
.39692 .88219 m .39613 .88403 L .39839 .88353 L F
.578 .509 .741 r
.48761 .85591 m .48931 .85669 L .48956 .85523 L F
.39 .842 .918 r
.48559 .82773 m .4868 .82783 L .48771 .82723 L F
.415 0 0 r
.48771 .82723 m .48655 .82762 L .48559 .82773 L F
.52 .852 .997 r
.48458 .82784 m .4868 .82783 L .48559 .82773 L F
.415 0 0 r
.48655 .82762 m .48425 .8284 L .48559 .82773 L F
.52 .852 .997 r
.4828 .82784 m .48458 .82784 L .48559 .82773 L F
0 0 0 r
.48771 .82723 m .4868 .82783 L .48835 .82667 L F
.50436 .8743 m .50232 .87455 L .50065 .87483 L F
.618 .49 .684 r
.36678 .76028 m .36722 .76272 L .36498 .76306 L F
.516 .289 .509 r
.36722 .76272 m .36487 .76531 L .36498 .76306 L F
.333 0 0 r
.51823 .81892 m .52002 .81905 L .51816 .81895 L F
.52182 .81747 m .52002 .81905 L .51823 .81892 L F
.647 .423 .564 r
.52272 .81846 m .52229 .8206 L .52002 .81905 L F
.4 .466 .813 r
.52002 .81905 m .52229 .8206 L .52172 .81917 L F
.335 0 0 r
.52272 .81846 m .52002 .81905 L .52182 .81747 L F
.4 .466 .813 r
.52002 .81905 m .52172 .81917 L .52114 .81771 L F
.447 .282 .563 r
.51816 .81895 m .52002 .81905 L .52004 .81886 L F
.255 0 0 r
.51956 .81778 m .51816 .81895 L .51667 .81902 L F
.333 0 0 r
.52182 .81747 m .51816 .81895 L .51956 .81778 L F
.447 .282 .563 r
.51816 .81895 m .52004 .81886 L .52038 .81614 L F
.255 0 0 r
.51667 .81902 m .51816 .81895 L .51609 .81927 L F
0 0 0 r
.491 .81002 m .48961 .81173 L .48843 .81202 L F
.427 .003 .13 r
.49235 .81119 m .491 .81002 L .49284 .80939 L F
.228 .24 .665 r
.49278 .8132 m .49113 .81452 L .4918 .81224 L F
.672 .863 .972 r
.49181 .81465 m .48843 .81485 L .49113 .81452 L F
.655 .246 .257 r
.48699 .81441 m .49113 .81452 L .48843 .81485 L F
.48699 .81441 m .48915 .81582 L .49113 .81452 L F
.918 .971 .78 r
.49113 .81452 m .48915 .81582 L .49056 .81355 L F
.228 .24 .665 r
.4918 .81224 m .48961 .81173 L .491 .81146 L F
.49147 .81259 m .48961 .81173 L .4918 .81224 L F
.49255 .81214 m .491 .81146 L .49235 .81119 L F
.49278 .8132 m .49206 .81249 L .49255 .81214 L F
.49206 .81249 m .491 .81146 L .49255 .81214 L F
.49147 .81259 m .49219 .81093 L .48961 .81173 L F
.918 .971 .78 r
.4918 .81224 m .49147 .81259 L .49219 .81093 L F
.228 .24 .665 r
.49278 .8132 m .49147 .81259 L .4918 .81224 L F
.49278 .8132 m .4918 .81224 L .49191 .81187 L F
.4925 .81213 m .49191 .81187 L .49219 .81093 L F
.49278 .8132 m .49191 .81187 L .4925 .81213 L F
.49278 .8132 m .49219 .81093 L .49147 .81259 L F
.918 .971 .78 r
.49147 .81259 m .49056 .81355 L .49219 .81093 L F
.841 .789 .801 r
.49219 .81093 m .49056 .81355 L .48921 .81293 L F
.49056 .81355 m .48915 .81582 L .48918 .81454 L F
.49056 .81355 m .48918 .81454 L .48921 .81293 L F
.918 .971 .78 r
.49113 .81452 m .49056 .81355 L .4918 .81224 L F
.427 .003 .13 r
.49235 .81119 m .491 .81146 L .491 .81002 L F
.491 .81146 m .48961 .81173 L .49015 .81108 L F
.491 .81146 m .49015 .81108 L .491 .81002 L F
.841 .793 .804 r
.61303 .76776 m .61104 .76808 L .61286 .76603 L F
.602 .378 .549 r
.61303 .76776 m .6108 .7705 L .61104 .76808 L F
.61303 .76776 m .6133 .77038 L .61089 .7705 L F
.579 .42 .63 r
.61302 .77223 m .6108 .7705 L .6133 .77038 L F
.61302 .77223 m .61104 .77292 L .6108 .7705 L F
0 0 .451 r
.61119 .7723 m .61222 .77197 L .61189 .76936 L F
.61104 .77292 m .61126 .77274 L .61119 .7723 L F
.61126 .77274 m .61222 .77197 L .61119 .7723 L F
.602 .378 .549 r
.61088 .77041 m .61089 .7705 L .6108 .7705 L F
.61303 .76776 m .61089 .7705 L .61088 .77041 L F
.501 .368 .632 r
.61507 .76521 m .61303 .76776 L .61286 .76603 L F
.61507 .76521 m .61499 .76765 L .61303 .76776 L F
.529 .326 .548 r
.61495 .76983 m .61303 .76776 L .61499 .76765 L F
.61495 .76983 m .6133 .77038 L .61303 .76776 L F
0 0 0 r
.40913 .88187 m .40719 .88229 L .40517 .88285 L F
.193 .723 .755 r
.45177 .81807 m .45377 .81766 L .45486 .81752 L F
0 0 0 r
.45377 .81766 m .45683 .81715 L .45486 .81752 L F
.544 .188 .315 r
.48843 .81202 m .48531 .81408 L .4865 .81468 L F
0 .519 .794 r
.48531 .81408 m .48843 .81485 L .4865 .81468 L F
.847 .736 .741 r
.56435 .82704 m .5667 .82741 L .56498 .83052 L F
.36 .649 .965 r
.56894 .82753 m .5667 .82741 L .56833 .82658 L F
.562 .339 .535 r
.39803 .84049 m .39767 .84271 L .3958 .84264 L F
.126 0 0 r
.39981 .84193 m .39767 .84271 L .39803 .84049 L F
.316 0 .019 r
.4039 .89844 m .40495 .89715 L .40689 .89682 L F
.328 0 .21 r
.52235 .87137 m .5251 .86865 L .52408 .87053 L F
.3 0 .132 r
.52408 .87053 m .5251 .86865 L .52707 .8682 L F
.648 .515 .688 r
.49417 .82648 m .49217 .82709 L .49075 .82514 L F
.554 .859 .552 r
.49669 .82103 m .49628 .82154 L .49717 .82041 L F
.49669 .82103 m .49717 .82041 L .49662 .8192 L F
.41 0 0 r
.51168 .80805 m .51387 .80866 L .51581 .80863 L F
.401 0 0 r
.51387 .80866 m .51715 .80899 L .51581 .80863 L F
.205 .003 .369 r
.53266 .86069 m .53204 .86129 L .53145 .86338 L F
.265 0 0 r
.40896 .8967 m .41251 .89419 L .41073 .89627 L F
.417 .003 .143 r
.41073 .89627 m .41251 .89419 L .41437 .89415 L F
.257 0 0 r
.47879 .81103 m .4822 .81013 L .48013 .81028 L F
.067 0 0 r
.44186 .87176 m .43985 .8721 L .43802 .87292 L F
.44186 .87176 m .43802 .87292 L .43815 .8729 L F
.43815 .8729 m .43802 .87292 L .43781 .87301 L F
.44186 .87176 m .43781 .87301 L .44063 .87106 L F
.507 .806 .999 r
.44373 .87142 m .44186 .87176 L .44063 .87106 L F
.44373 .87142 m .44063 .87106 L .44246 .8703 L F
.291 0 .193 r
.44246 .8703 m .44063 .87106 L .43984 .87272 L F
.43994 .87271 m .43984 .87272 L .43977 .87287 L F
.44246 .8703 m .43984 .87272 L .43994 .87271 L F
.847 .507 .41 r
.47896 .829 m .47771 .82792 L .47707 .82731 L F
.435 0 0 r
.4766 .82687 m .47707 .82731 L .47494 .82718 L F
.42 .725 .988 r
.47494 .82718 m .47707 .82731 L .47568 .82615 L F
.847 .507 .41 r
.47771 .82792 m .47568 .82615 L .47707 .82731 L F
.435 0 0 r
.47825 .82655 m .47707 .82731 L .4766 .82687 L F
.018 0 0 r
.48068 .82584 m .47825 .82655 L .48024 .82536 L F
.48068 .82584 m .47707 .82731 L .47825 .82655 L F
.612 .197 .23 r
.44384 .88603 m .44517 .88439 L .44687 .88564 L F
.567 .239 .371 r
.44517 .88439 m .44758 .88432 L .44687 .88564 L F
.314 0 .075 r
.41448 .87943 m .41131 .88158 L .41323 .88115 L F
.394 0 .023 r
.4151 .88074 m .41448 .87943 L .41323 .88115 L F
.4151 .88074 m .41667 .87935 L .41448 .87943 L F
.158 0 0 r
.43423 .83327 m .43387 .83364 L .42967 .83394 L F
.216 0 0 r
.43587 .83238 m .43387 .83364 L .43423 .83327 L F
.183 .702 .881 r
.4251 .8199 m .4269 .81985 L .42841 .82011 L F
.296 0 0 r
.4269 .81985 m .43048 .82005 L .42841 .82011 L F
.505 .092 .19 r
.53096 .80716 m .52974 .80843 L .5278 .8083 L F
.974 .894 .683 r
.53343 .80699 m .52974 .80843 L .53096 .80716 L F
.452 0 .037 r
.53233 .80756 m .53343 .80699 L .53096 .80716 L F
.53258 .80717 m .53096 .80716 L .52977 .80412 L F
.974 .894 .683 r
.53272 .80753 m .53257 .80924 L .53258 .80763 L F
.53343 .80699 m .53297 .80818 L .53272 .80753 L F
.53297 .80818 m .53257 .80924 L .53272 .80753 L F
0 .201 .729 r
.53027 .80367 m .5324 .80671 L .52977 .80412 L F
.974 .894 .683 r
.53257 .80744 m .53185 .80804 L .53118 .80816 L F
.452 0 .037 r
.53258 .80763 m .53343 .80699 L .53233 .80756 L F
.974 .894 .683 r
.53343 .80699 m .5327 .80748 L .53257 .80744 L F
.5327 .80748 m .53185 .80804 L .53257 .80744 L F
.53195 .80757 m .53118 .80816 L .52974 .80843 L F
.53343 .80699 m .53233 .80756 L .53195 .80757 L F
.53233 .80756 m .53118 .80816 L .53195 .80757 L F
.452 0 .037 r
.53258 .80756 m .53096 .80716 L .53258 .80717 L F
.974 .894 .683 r
.5333 .80686 m .53343 .80699 L .53434 .80596 L F
.53258 .80756 m .53343 .80699 L .53328 .80684 L F
.452 0 .037 r
.53258 .80763 m .53252 .80762 L .53258 .80756 L F
.974 .894 .683 r
.53185 .80804 m .53269 .80945 L .53317 .80787 L F
.53185 .80804 m .53317 .80787 L .53343 .80699 L F
.53343 .80699 m .53269 .80945 L .53257 .80924 L F
.53258 .80763 m .53257 .80924 L .53191 .80813 L F
.048 0 0 r
.53388 .80799 m .53086 .80816 L .53185 .80804 L F
.188 .72 .765 r
.53185 .80804 m .53058 .80818 L .52974 .80843 L F
.048 0 0 r
.53086 .80816 m .53058 .80818 L .53185 .80804 L F
.452 0 .037 r
.53317 .80781 m .53343 .80699 L .53258 .80763 L F
0 0 0 r
.53434 .80596 m .53343 .80699 L .53317 .80781 L F
.663 .613 .788 r
.53434 .80596 m .53317 .80781 L .53281 .80729 L F
.53434 .80596 m .53281 .80729 L .53027 .80367 L F
.974 .894 .683 r
.53328 .80684 m .5333 .80686 L .53434 .80596 L F
.452 0 .037 r
.53252 .80762 m .53233 .80756 L .53258 .80756 L F
.974 .894 .683 r
.53185 .80804 m .53258 .80756 L .53328 .80684 L F
.452 0 .037 r
.53233 .80756 m .53096 .80716 L .53258 .80756 L F
0 .201 .729 r
.5324 .80671 m .533 .80758 L .53258 .80717 L F
.533 .80758 m .53317 .80781 L .53293 .80755 L F
.974 .894 .683 r
.53343 .80699 m .53191 .80813 L .53185 .80804 L F
0 .201 .729 r
.533 .80758 m .53293 .80755 L .53258 .80717 L F
.5324 .80671 m .53258 .80717 L .52977 .80412 L F
.452 0 .037 r
.53317 .80781 m .53258 .80763 L .53258 .80717 L F
.15 0 0 r
.41258 .82265 m .41453 .82246 L .41559 .82206 L F
.093 0 0 r
.41453 .82246 m .4178 .82223 L .41559 .82206 L F
.337 0 0 r
.41967 .82142 m .42178 .82138 L .42327 .82046 L F
.536 .125 .209 r
.42178 .82138 m .4251 .8199 L .42327 .82046 L F
.266 0 0 r
.46194 .828 m .46114 .82915 L .4591 .82917 L F
.37 0 0 r
.46312 .82895 m .46194 .828 L .46433 .82946 L F
.46312 .82895 m .46114 .82915 L .46194 .828 L F
.227 0 0 r
.40312 .84091 m .40191 .84173 L .39981 .84193 L F
.304 0 0 r
.40525 .84132 m .40191 .84173 L .40312 .84091 L F
.359 0 0 r
.39624 .82614 m .39841 .82603 L .39988 .82484 L F
.444 0 .089 r
.39841 .82603 m .40191 .82445 L .39988 .82484 L F
.194 0 .098 r
.47442 .86176 m .47259 .86258 L .47218 .86334 L F
.189 0 0 r
.4822 .81013 m .48379 .81035 L .48517 .80905 L F
.24 0 0 r
.48379 .81035 m .48727 .80906 L .48517 .80905 L F
.479 .019 .083 r
.45683 .81715 m .45903 .8173 L .45983 .81641 L F
.315 0 0 r
.45903 .8173 m .46195 .8161 L .45983 .81641 L F
.552 .154 .241 r
.53383 .81496 m .53082 .81623 L .53057 .81439 L F
0 0 .254 r
.53082 .81623 m .53124 .81473 L .53057 .81439 L F
.266 0 0 r
.53227 .81424 m .53057 .81439 L .53032 .81426 L F
.552 .154 .241 r
.53383 .81496 m .53057 .81439 L .53227 .81424 L F
0 0 .254 r
.53124 .81473 m .53174 .81298 L .53057 .81439 L F
.266 0 0 r
.53032 .81426 m .53057 .81439 L .52875 .81427 L F
.544 .188 .315 r
.48843 .81202 m .48699 .81441 L .48531 .81408 L F
0 0 0 r
.48961 .81173 m .48699 .81441 L .48843 .81202 L F
.438 .64 .942 r
.53112 .82945 m .53012 .83032 L .52892 .82951 L F
.53112 .82945 m .53215 .83057 L .53012 .83032 L F
.53012 .83032 m .52892 .82951 L .52901 .83194 L F
.53012 .83032 m .53112 .82945 L .52892 .82951 L F
.53012 .83032 m .53215 .83057 L .53112 .82945 L F
.288 0 .023 r
.53154 .86574 m .53475 .86367 L .53375 .86377 L F
.35 .827 .83 r
.53375 .86377 m .53475 .86367 L .53577 .86313 L F
.559 .933 .903 r
.49181 .81465 m .49278 .8132 L .49428 .81281 L F
.49181 .81465 m .49113 .81452 L .49278 .8132 L F
.597 .46 .666 r
.61104 .77292 m .60859 .77072 L .6108 .7705 L F
.61104 .77292 m .60837 .77346 L .60859 .77072 L F
.61104 .77292 m .60859 .77072 L .6108 .7705 L F
.61104 .77292 m .60837 .77346 L .60859 .77072 L F
.699 .278 .244 r
.49876 .87548 m .49708 .87393 L .49557 .8748 L F
.223 0 0 r
.3958 .84264 m .39476 .84333 L .39287 .84358 L F
.582 .177 .24 r
.39767 .84271 m .39476 .84333 L .3958 .84264 L F
0 0 0 r
.57321 .79436 m .57121 .79517 L .57022 .79585 L F
.812 .743 .787 r
.46598 .86887 m .46832 .86645 L .46716 .86536 L F
.712 .567 .689 r
.46598 .86887 m .46824 .86882 L .46832 .86645 L F
.766 .984 .905 r
.46832 .86645 m .46724 .86346 L .46716 .86536 L F
.46832 .86645 m .46869 .86521 L .46724 .86346 L F
.2 .37 .809 r
.57108 .82786 m .57005 .8286 L .56894 .82753 L F
.473 .075 .203 r
.53966 .82507 m .54241 .82411 L .54123 .82414 L F
.134 0 .121 r
.54241 .82411 m .54428 .82366 L .54123 .82414 L F
.607 .045 0 r
.44666 .87274 m .44496 .87143 L .44373 .87142 L F
.541 .187 .316 r
.44666 .87274 m .44712 .87135 L .44496 .87143 L F
.481 .753 .99 r
.50019 .80847 m .50229 .80975 L .50287 .80922 L F
.486 .892 .935 r
.46982 .83036 m .47111 .83058 L .47303 .82987 L F
.97 .66 .366 r
.48554 .86847 m .48661 .86882 L .48696 .87138 L F
.119 .569 .919 r
.4888 .86883 m .48661 .86882 L .48554 .86847 L F
.561 .352 .555 r
.65839 .75257 m .65858 .75497 L .65608 .75533 L F
.446 .15 .368 r
.65839 .75257 m .65991 .75395 L .65858 .75497 L F
.65839 .75257 m .66058 .7523 L .65991 .75395 L F
0 0 .404 r
.47421 .85833 m .47519 .85995 L .47736 .85835 L F
.47421 .85833 m .47442 .86176 L .47519 .85995 L F
.289 .787 .856 r
.40884 .84087 m .40771 .84083 L .40525 .84132 L F
.623 .955 .919 r
.40934 .8399 m .40884 .84087 L .41054 .83991 L F
.40934 .8399 m .40771 .84083 L .40884 .84087 L F
.159 .699 .795 r
.43048 .82005 m .43245 .81982 L .43367 .81981 L F
.179 .711 .836 r
.43245 .81982 m .4357 .81973 L .43367 .81981 L F
.274 0 0 r
.50845 .80696 m .51083 .80782 L .51168 .80805 L F
.23 0 0 r
.51083 .80782 m .51387 .80866 L .51168 .80805 L F
.764 .426 .414 r
.57195 .79917 m .57362 .79953 L .57408 .80118 L F
.241 0 0 r
.50694 .87322 m .50436 .8743 L .50636 .87382 L F
.164 0 0 r
.50895 .87276 m .50694 .87322 L .50636 .87382 L F
.605 .348 .501 r
.53082 .81155 m .53304 .81145 L .53088 .80953 L F
.42 0 .066 r
.40697 .82363 m .40905 .82357 L .40733 .82307 L F
.43 0 .07 r
.46641 .81478 m .46938 .81382 L .46736 .81423 L F
.74 .79 .892 r
.49769 .8123 m .49428 .81281 L .49563 .81159 L F
.558 .734 .958 r
.49827 .81118 m .49769 .8123 L .49563 .81159 L F
.556 .731 .957 r
.49827 .81118 m .49911 .81239 L .49769 .8123 L F
.57 .555 .799 r
.36799 .75797 m .36678 .76028 L .36598 .758 L F
.36799 .75797 m .36884 .76001 L .36678 .76028 L F
.63 .538 .732 r
.36884 .76001 m .36722 .76272 L .36678 .76028 L F
.076 .52 .901 r
.52869 .80323 m .53027 .80367 L .52977 .80412 L F
.671 .514 .664 r
.39839 .88353 m .40109 .88156 L .39791 .88101 L F
.554 .329 .528 r
.46609 .87138 m .46824 .86882 L .46598 .86887 L F
.46609 .87138 m .46817 .87123 L .46824 .86882 L F
.634 .35 .47 r
.47026 .87115 m .46824 .86882 L .46817 .87123 L F
.47026 .87115 m .47136 .86859 L .46824 .86882 L F
.575 .08 .042 r
.49217 .82709 m .49058 .82746 L .48835 .82667 L F
.648 .515 .688 r
.49417 .82648 m .49476 .82751 L .49217 .82709 L F
.788 .346 .198 r
.49058 .82746 m .49376 .83006 L .49017 .82909 L F
1 .813 .507 r
.49072 .83157 m .49144 .83145 L .49277 .83136 L F
.49144 .83145 m .49336 .83111 L .49277 .83136 L F
.799 .447 .39 r
.49444 .8309 m .49423 .83096 L .49411 .82961 L F
.49423 .83096 m .49329 .83069 L .49411 .82961 L F
1 .813 .507 r
.49072 .83157 m .49034 .82984 L .49329 .83069 L F
.4929 .83119 m .49329 .83069 L .49423 .83096 L F
.49072 .83157 m .49329 .83069 L .4929 .83119 L F
0 0 0 r
.49394 .82983 m .49329 .83069 L .4939 .82988 L F
1 .813 .507 r
.49336 .83111 m .49423 .83096 L .49277 .83136 L F
.799 .447 .39 r
.49423 .83096 m .49277 .83136 L .49329 .83069 L F
0 0 0 r
.49329 .83069 m .49277 .83136 L .4933 .83068 L F
.49329 .83069 m .4933 .83068 L .4939 .82988 L F
.49336 .83059 m .49277 .83136 L .49291 .83118 L F
.4939 .82988 m .4933 .83068 L .49336 .83059 L F
.4933 .83068 m .49277 .83136 L .49336 .83059 L F
1 .813 .507 r
.49423 .83096 m .49338 .83057 L .49475 .83087 L F
.49338 .83057 m .49017 .82909 L .49352 .83039 L F
.49338 .83057 m .49352 .83039 L .49475 .83087 L F
.836 .391 .169 r
.49462 .83068 m .49411 .82961 L .49475 .83087 L F
.459 .241 .495 r
.49484 .83096 m .49475 .8308 L .49565 .83015 L F
.49475 .8308 m .49411 .82961 L .49536 .83005 L F
.49475 .8308 m .49536 .83005 L .49565 .83015 L F
.212 .443 .865 r
.49565 .83015 m .49411 .82961 L .49486 .82865 L F
0 .026 .558 r
.49475 .8308 m .49411 .82961 L .49486 .82865 L F
.49475 .83087 m .49411 .82961 L .49475 .8308 L F
.459 .241 .495 r
.49454 .83126 m .49411 .82961 L .49462 .83068 L F
.836 .391 .169 r
.49399 .82976 m .49462 .83068 L .49376 .83006 L F
.49462 .83068 m .49475 .83087 L .49466 .8308 L F
.49462 .83068 m .49466 .8308 L .49376 .83006 L F
.459 .241 .495 r
.49475 .83105 m .49462 .83068 L .49478 .83101 L F
.49454 .83126 m .49462 .83068 L .49475 .83105 L F
.869 .856 .826 r
.49475 .8308 m .49468 .83088 L .49475 .83087 L F
.459 .241 .495 r
.49478 .83101 m .49411 .82961 L .49484 .83096 L F
.836 .391 .169 r
.49399 .82976 m .49411 .82961 L .49462 .83068 L F
1 .813 .507 r
.49329 .83069 m .49338 .83057 L .49423 .83096 L F
.799 .447 .39 r
.49454 .83126 m .49277 .83136 L .49444 .8309 L F
1 .813 .507 r
.49423 .83096 m .49475 .83087 L .49277 .83136 L F
.788 .346 .198 r
.49376 .83006 m .49475 .83087 L .49352 .83039 L F
.869 .856 .826 r
.49486 .82865 m .49277 .83136 L .49468 .83088 L F
.49486 .82865 m .49468 .83088 L .49475 .8308 L F
.836 .391 .169 r
.49217 .82709 m .49411 .82961 L .49399 .82976 L F
0 0 0 r
.49414 .82957 m .49399 .82976 L .49472 .82882 L F
.49399 .82976 m .49339 .83055 L .49365 .83022 L F
.49399 .82976 m .49365 .83022 L .49472 .82882 L F
.49472 .82882 m .49291 .83118 L .49486 .82865 L F
.49339 .83055 m .49291 .83118 L .49472 .82882 L F
1 .813 .507 r
.49034 .82984 m .49017 .82909 L .49338 .83057 L F
.49034 .82984 m .49338 .83057 L .49329 .83069 L F
.923 .975 .716 r
.4923 .83094 m .49168 .83184 L .49277 .83136 L F
.623 .205 .228 r
.49277 .83136 m .49093 .83292 L .48913 .83251 L F
.923 .975 .716 r
.49168 .83184 m .49093 .83292 L .49277 .83136 L F
0 .124 .669 r
.49454 .83126 m .49509 .83127 L .49277 .83136 L F
.923 .975 .716 r
.49483 .83124 m .49277 .83136 L .49509 .83127 L F
.4923 .83094 m .49277 .83136 L .49483 .83124 L F
0 0 0 r
.49411 .82961 m .49291 .83118 L .49414 .82957 L F
.788 .346 .198 r
.49376 .83006 m .49352 .83039 L .49017 .82909 L F
0 0 0 r
.49411 .82961 m .49394 .82983 L .4939 .82988 L F
.836 .391 .169 r
.49217 .82709 m .49399 .82976 L .49058 .82746 L F
.49399 .82976 m .49376 .83006 L .49058 .82746 L F
.87 .877 .839 r
.48607 .85061 m .48391 .85331 L .48249 .85268 L F
.587 .423 .626 r
.48607 .85061 m .48618 .85325 L .48391 .85331 L F
.432 .248 .529 r
.48522 .85442 m .48391 .85331 L .48618 .85325 L F
.48522 .85442 m .4838 .85557 L .48391 .85331 L F
.643 .277 .335 r
.5022 .81664 m .49901 .81735 L .50028 .81719 L F
.271 .765 .899 r
.4357 .81973 m .43773 .81948 L .43894 .81966 L F
.409 .81 .983 r
.43773 .81948 m .44097 .81966 L .43894 .81966 L F
.564 .864 .996 r
.56695 .83215 m .56816 .83268 L .56901 .83157 L F
.947 .955 .73 r
.5745 .81063 m .57384 .81251 L .57383 .81131 L F
0 0 .504 r
.57383 .81131 m .57384 .81251 L .57416 .81305 L F
.847 .736 .741 r
.56435 .82704 m .56498 .83052 L .56505 .82944 L F
.009 .286 .784 r
.56505 .82944 m .56498 .83052 L .56695 .83215 L F
.691 .519 .649 r
.61483 .76289 m .61286 .76603 L .61507 .76521 L F
.61483 .76289 m .61286 .76603 L .61507 .76521 L F
.551 .416 .65 r
.61708 .76478 m .61507 .76521 L .61483 .76289 L F
.61708 .76478 m .61507 .76521 L .61483 .76289 L F
.521 .093 .169 r
.45933 .87013 m .45786 .86913 L .45633 .87084 L F
.463 .141 .333 r
.45933 .87013 m .45965 .8688 L .45786 .86913 L F
.899 .697 .621 r
.46485 .86787 m .46598 .86887 L .46489 .86604 L F
.96 .739 .56 r
.46478 .87107 m .46598 .86887 L .46485 .86787 L F
.46478 .87107 m .46609 .87138 L .46598 .86887 L F
.812 .743 .787 r
.46598 .86887 m .46716 .86536 L .46489 .86604 L F
.41 0 0 r
.48218 .87473 m .48304 .87375 L .47979 .87392 L F
.522 .099 .178 r
.48392 .87554 m .48304 .87375 L .48218 .87473 L F
.48392 .87554 m .48501 .87402 L .48304 .87375 L F
.3 0 .174 r
.51787 .87382 m .5206 .87194 L .51935 .8732 L F
.242 0 .064 r
.51935 .8732 m .5206 .87194 L .52235 .87137 L F
.538 0 0 r
.48835 .82667 m .49058 .82746 L .48771 .82723 L F
.676 .22 .162 r
.48228 .88333 m .48563 .88381 L .48398 .88418 L F
.73 .293 .213 r
.48398 .88418 m .48563 .88381 L .48751 .88572 L F
.577 .343 .525 r
.60654 .77559 m .60876 .77532 L .60837 .77346 L F
.60837 .77346 m .60876 .77532 L .60654 .77559 L F
.582 .346 .524 r
.61073 .77484 m .60837 .77346 L .61104 .77292 L F
0 0 .439 r
.60837 .77346 m .60961 .77414 L .61104 .77292 L F
.582 .346 .524 r
.61073 .77484 m .60876 .77532 L .60837 .77346 L F
0 0 .439 r
.60837 .77346 m .60876 .77532 L .60961 .77414 L F
.46 .83 .992 r
.48243 .85512 m .4818 .85596 L .4838 .85557 L F
.746 .797 .894 r
.56589 .81825 m .56801 .81969 L .56488 .8193 L F
.773 .398 .346 r
.56488 .8193 m .56801 .81969 L .56663 .821 L F
.586 .465 .682 r
.57054 .81878 m .56801 .81969 L .56589 .81825 L F
.57054 .81878 m .57044 .81977 L .56801 .81969 L F
.56801 .81969 m .57044 .81977 L .57054 .81878 L F
.56801 .81969 m .57054 .81878 L .56663 .821 L F
.046 0 0 r
.44097 .81966 m .44305 .81947 L .4441 .8192 L F
0 0 0 r
.4441 .8192 m .44505 .81907 L .44616 .81846 L F
.44305 .81947 m .44505 .81907 L .4441 .8192 L F
.47 .152 .344 r
.3893 .84432 m .38713 .84486 L .38752 .84374 L F
.535 .342 .566 r
.42243 .83614 m .4253 .83482 L .42357 .83535 L F
.358 0 0 r
.4272 .88959 m .42758 .89069 L .42546 .89105 L F
.4272 .88959 m .42933 .88964 L .42758 .89069 L F
.549 .317 .515 r
.45199 .8814 m .45332 .88421 L .4512 .88364 L F
.45199 .8814 m .45362 .88092 L .45332 .88421 L F
.236 .155 .557 r
.54092 .82183 m .53966 .82507 L .54123 .82414 L F
.451 .014 .115 r
.38064 .82943 m .3827 .82938 L .38405 .82782 L F
.412 0 .05 r
.3827 .82938 m .38602 .82787 L .38405 .82782 L F
.768 .677 .762 r
.48285 .86324 m .48399 .86616 L .48607 .86355 L F
.205 .003 .369 r
.53266 .86069 m .53145 .86338 L .53375 .86377 L F
.546 .38 .608 r
.53266 .86069 m .53577 .86313 L .53491 .86006 L F
.53266 .86069 m .53375 .86377 L .53577 .86313 L F
.778 .434 .403 r
.65608 .75533 m .65354 .75669 L .65299 .75391 L F
.65608 .75533 m .65581 .75677 L .65354 .75669 L F
.554 .221 .358 r
.65608 .75533 m .65788 .75668 L .65581 .75677 L F
.522 .237 .424 r
.65858 .75497 m .65788 .75668 L .65608 .75533 L F
.393 0 0 r
.40905 .82357 m .41113 .82364 L .41258 .82265 L F
.503 .049 .105 r
.41113 .82364 m .41453 .82246 L .41258 .82265 L F
.418 .021 .176 r
.41577 .83769 m .41458 .83961 L .41256 .83985 L F
.256 .201 .601 r
.41577 .83769 m .41726 .83786 L .41706 .83766 L F
.39 0 .16 r
.41659 .83926 m .41577 .83769 L .41706 .83766 L F
.41659 .83926 m .41458 .83961 L .41577 .83769 L F
.499 .055 .125 r
.43328 .88893 m .43468 .88744 L .43623 .88834 L F
0 0 0 r
.50009 .80447 m .49592 .8059 L .49906 .80458 L F
.553 .082 .09 r
.49906 .80458 m .50197 .8043 L .50009 .80447 L F
0 0 0 r
.49377 .80766 m .49519 .80645 L .4946 .80772 L F
.498 .386 .657 r
.48956 .85523 m .48931 .85669 L .49098 .85485 L F
.87 .877 .839 r
.48607 .85061 m .48249 .85268 L .48495 .85055 L F
.543 .921 .929 r
.48607 .85061 m .48495 .85055 L .4871 .84968 L F
.168 .269 .725 r
.4871 .84968 m .48798 .85269 L .48607 .85061 L F
.483 .342 .614 r
.48798 .85269 m .48618 .85325 L .48607 .85061 L F
0 0 0 r
.51537 .87641 m .51787 .87382 L .51682 .87571 L F
.17 0 .057 r
.51682 .87571 m .51787 .87382 L .51935 .8732 L F
.193 0 0 r
.3969 .90013 m .39973 .8995 L .39869 .9 L F
.099 0 0 r
.39869 .9 m .39973 .8995 L .40161 .89918 L F
0 .053 .586 r
.52709 .8649 m .52861 .86695 L .52618 .86427 L F
.52709 .8649 m .52618 .86427 L .52563 .8658 L F
.23 0 0 r
.4165 .89386 m .41963 .89188 L .4184 .89373 L F
.349 0 .045 r
.41963 .89188 m .4211 .89245 L .4184 .89373 L F
.41963 .89188 m .42166 .89156 L .4211 .89245 L F
.53 .294 .502 r
.42874 .87816 m .42702 .87649 L .42568 .87859 L F
.42874 .87816 m .42904 .87621 L .42702 .87649 L F
.509 .744 .979 r
.43559 .83249 m .43788 .83205 L .43587 .83238 L F
.43559 .83249 m .43993 .83275 L .43788 .83205 L F
.651 .1 0 r
.47717 .8814 m .47755 .88245 L .47551 .88154 L F
.47717 .8814 m .47861 .88221 L .47755 .88245 L F
.786 .306 .089 r
.47807 .8326 m .47685 .83316 L .47644 .83268 L F
.247 0 0 r
.47857 .8325 m .47807 .8326 L .47908 .83254 L F
.47606 .8323 m .47807 .8326 L .47857 .8325 L F
.4793 .83256 m .47807 .8326 L .47606 .8323 L F
.47606 .8323 m .47807 .8326 L .4793 .83256 L F
.83 .417 .26 r
.47503 .83103 m .47807 .8326 L .47606 .8323 L F
.786 .306 .089 r
.47807 .8326 m .47503 .83103 L .47606 .8323 L F
.83 .417 .26 r
.47503 .83103 m .47547 .83158 L .47557 .83162 L F
.569 .368 .569 r
.47565 .83164 m .47616 .83245 L .4755 .83176 L F
.83 .417 .26 r
.47675 .83192 m .47565 .83164 L .47741 .83226 L F
.47565 .83164 m .47565 .83164 L .47741 .83226 L F
.47503 .83103 m .47557 .83162 L .47675 .83192 L F
.47741 .83226 m .47549 .8316 L .47807 .8326 L F
.47547 .83158 m .47549 .8316 L .47741 .83226 L F
.47549 .8316 m .47616 .83245 L .47655 .83248 L F
.569 .368 .569 r
.47565 .83164 m .4755 .83176 L .47557 .83162 L F
.83 .417 .26 r
.47549 .8316 m .47655 .83248 L .47807 .8326 L F
.569 .368 .569 r
.47571 .83159 m .47616 .83245 L .47565 .83164 L F
.83 .417 .26 r
.47565 .83164 m .47557 .83162 L .47565 .83164 L F
.786 .306 .089 r
.47538 .83121 m .47644 .83268 L .47503 .83103 L F
.569 .368 .569 r
.47896 .829 m .47571 .83159 L .47719 .82869 L F
.47571 .83159 m .47565 .83164 L .47568 .83158 L F
.47571 .83159 m .47568 .83158 L .47719 .82869 L F
.788 .922 .927 r
.47807 .8326 m .47616 .83245 L .47638 .83232 L F
.786 .306 .089 r
.47807 .8326 m .47638 .83232 L .47571 .83159 L F
.687 .53 .668 r
.47638 .83232 m .47616 .83245 L .47631 .83227 L F
.786 .306 .089 r
.47638 .83232 m .47635 .83232 L .47631 .83227 L F
.47638 .83232 m .47631 .83227 L .47571 .83159 L F
.47807 .8326 m .47571 .83159 L .47675 .83192 L F
.687 .53 .668 r
.47834 .83117 m .47638 .83232 L .47896 .829 L F
.786 .306 .089 r
.47675 .83192 m .47571 .83159 L .47538 .83121 L F
.687 .53 .668 r
.47638 .83232 m .47631 .83227 L .47896 .829 L F
.788 .922 .927 r
.47807 .8326 m .47638 .83232 L .47834 .83117 L F
.786 .306 .089 r
.47807 .8326 m .47666 .83267 L .47635 .83232 L F
.569 .368 .569 r
.47631 .83227 m .47616 .83245 L .47571 .83159 L F
.786 .306 .089 r
.47666 .83267 m .47644 .83268 L .47538 .83121 L F
.569 .368 .569 r
.47896 .829 m .47631 .83227 L .47571 .83159 L F
.47565 .83164 m .47557 .83162 L .47719 .82869 L F
.773 .784 .862 r
.47719 .82869 m .47557 .83162 L .47453 .82795 L F
.47557 .83162 m .4755 .83176 L .47547 .83158 L F
.102 .268 .748 r
.4755 .83176 m .47616 .83245 L .47547 .83158 L F
.4755 .83176 m .47547 .83158 L .47503 .83103 L F
.773 .784 .862 r
.47547 .83158 m .4755 .83176 L .47545 .83158 L F
.102 .268 .748 r
.4755 .83176 m .47503 .83103 L .47295 .83211 L F
.727 .45 .507 r
.47336 .8319 m .47438 .83174 L .47503 .83103 L F
.47438 .83174 m .47539 .83148 L .47503 .83103 L F
.886 .88 .823 r
.47176 .8292 m .47303 .82987 L .47494 .82718 L F
.764 .52 .565 r
.47261 .83111 m .47295 .83211 L .47503 .83103 L F
.486 .892 .935 r
.46982 .83036 m .47303 .82987 L .47176 .8292 L F
.785 .501 .506 r
.47176 .8292 m .47295 .83211 L .47173 .83114 L F
.764 .52 .565 r
.47173 .83114 m .47295 .83211 L .47261 .83111 L F
.274 .243 .642 r
.47261 .83111 m .47295 .83211 L .47226 .83041 L F
.742 .443 .475 r
.47261 .83111 m .47354 .83364 L .47173 .83114 L F
.801 .691 .743 r
.4755 .83176 m .47295 .83211 L .47532 .8315 L F
.727 .45 .507 r
.47295 .83211 m .47616 .83245 L .47547 .83158 L F
.47295 .83211 m .47547 .83158 L .47336 .8319 L F
.678 .366 .438 r
.47685 .83316 m .47354 .83364 L .47473 .83156 L F
.47532 .83137 m .47473 .83156 L .47503 .83103 L F
.727 .45 .507 r
.47532 .8315 m .47547 .83158 L .47539 .83148 L F
.47438 .83174 m .47545 .83158 L .47532 .8315 L F
.47545 .83158 m .47547 .83158 L .47532 .8315 L F
.801 .691 .743 r
.47545 .83158 m .47527 .83143 L .47545 .83157 L F
.4755 .83176 m .47532 .8315 L .47545 .83158 L F
.47532 .8315 m .47527 .83143 L .47545 .83158 L F
.773 .784 .862 r
.47547 .83158 m .47545 .83158 L .47545 .83157 L F
.678 .366 .438 r
.47685 .83316 m .47473 .83156 L .47532 .83137 L F
.801 .691 .743 r
.47465 .83158 m .47295 .83211 L .47296 .83179 L F
.47532 .8315 m .47331 .83202 L .47465 .83158 L F
.47331 .83202 m .47295 .83211 L .47465 .83158 L F
.742 .443 .475 r
.47503 .83103 m .47473 .83156 L .47261 .83111 L F
.47473 .83156 m .47296 .83179 L .47261 .83111 L F
.801 .691 .743 r
.47531 .83148 m .47296 .83179 L .47308 .8282 L F
.47532 .8315 m .47296 .83179 L .47531 .83148 L F
.742 .443 .475 r
.47473 .83156 m .47373 .8333 L .47296 .83179 L F
.47373 .8333 m .47354 .83364 L .47261 .83111 L F
.274 .243 .642 r
.47193 .82907 m .47261 .83111 L .47176 .8292 L F
.47261 .83111 m .47226 .83041 L .47176 .8292 L F
.47308 .8282 m .47295 .83211 L .47193 .82907 L F
.773 .784 .862 r
.47557 .83162 m .47545 .83157 L .47453 .82795 L F
.801 .691 .743 r
.47545 .83157 m .47308 .8282 L .47453 .82795 L F
.47527 .83143 m .47308 .8282 L .47545 .83157 L F
.899 .977 .687 r
.47834 .83117 m .47714 .83278 L .47807 .8326 L F
.47714 .83278 m .47685 .83316 L .47807 .8326 L F
.247 0 0 r
.47908 .83254 m .47807 .8326 L .4793 .83256 L F
.519 .911 .925 r
.4793 .83256 m .47807 .8326 L .48019 .8317 L F
.4793 .83256 m .47807 .8326 L .48019 .8317 L F
.382 0 0 r
.56669 .80157 m .5677 .80273 L .5663 .80144 L F
.56669 .80157 m .56891 .80146 L .5677 .80273 L F
.354 0 0 r
.50766 .81532 m .50848 .81583 L .5063 .81606 L F
.685 .705 .862 r
.56806 .80973 m .56917 .81211 L .5674 .81027 L F
.243 .438 .853 r
.56939 .81104 m .56917 .81211 L .56843 .81051 L F
.399 .602 .929 r
.5674 .81027 m .56917 .81211 L .56939 .81104 L F
.619 .091 0 r
.5674 .81027 m .56939 .81104 L .56664 .81092 L F
.399 .602 .929 r
.56939 .81104 m .56917 .81211 L .56989 .81124 L F
.619 .091 0 r
.56939 .81104 m .56989 .81124 L .56971 .81122 L F
.446 .832 .986 r
.56971 .81122 m .56989 .81124 L .56999 .81102 L F
.243 .438 .853 r
.56999 .81102 m .56917 .81211 L .56929 .81154 L F
.56999 .81102 m .56929 .81154 L .56947 .81067 L F
.619 .091 0 r
.56939 .81104 m .56971 .81122 L .56664 .81092 L F
.446 .832 .986 r
.56664 .81092 m .56971 .81122 L .56999 .81102 L F
.243 .438 .853 r
.56947 .81067 m .56939 .81104 L .56806 .80973 L F
.56939 .81104 m .56843 .81051 L .56806 .80973 L F
.642 .966 .832 r
.56989 .81124 m .56917 .81211 L .56999 .81102 L F
.253 0 0 r
.39105 .8873 m .3932 .8867 L .39158 .88679 L F
.233 0 0 r
.50111 .88629 m .50431 .88552 L .50303 .88546 L F
.806 .984 .892 r
.50431 .88552 m .50529 .88369 L .50303 .88546 L F
.50431 .88552 m .50636 .88375 L .50529 .88369 L F
.408 .588 .916 r
.54506 .81858 m .54391 .81953 L .54199 .81715 L F
.229 .267 .694 r
.54569 .82157 m .54391 .81953 L .54506 .81858 L F
.608 .214 .27 r
.53687 .81547 m .53383 .81496 L .53538 .81505 L F
.694 .73 .878 r
.53543 .81757 m .53738 .81674 L .53571 .81532 L F
.53539 .81533 m .53571 .81532 L .53538 .81505 L F
.53543 .81757 m .53571 .81532 L .53539 .81533 L F
.58 .705 .928 r
.53658 .8154 m .53738 .81674 L .53932 .81619 L F
.608 .214 .27 r
.53626 .81537 m .53571 .81532 L .53592 .81531 L F
.58 .705 .928 r
.53538 .81505 m .53571 .81532 L .53658 .8154 L F
.53571 .81532 m .53738 .81674 L .53658 .8154 L F
.608 .214 .27 r
.53687 .81547 m .53539 .81533 L .53571 .81532 L F
.53687 .81547 m .53571 .81532 L .53626 .81537 L F
.53687 .81547 m .53643 .81559 L .53539 .81533 L F
.53592 .81531 m .53539 .81533 L .53383 .81496 L F
.694 .73 .878 r
.53543 .81757 m .53539 .81533 L .53383 .81496 L F
.608 .214 .27 r
.53643 .81559 m .53302 .81647 L .53383 .81496 L F
.694 .73 .878 r
.53539 .81533 m .53538 .81505 L .53383 .81496 L F
.652 .194 .152 r
.49055 .88588 m .4939 .88608 L .49257 .88654 L F
.468 0 0 r
.4939 .88608 m .49584 .88647 L .49257 .88654 L F
.419 0 .017 r
.47144 .81338 m .4735 .81338 L .47486 .8121 L F
.494 .094 .21 r
.4735 .81338 m .47681 .81152 L .47486 .8121 L F
.76 .417 .404 r
.40109 .88156 m .40241 .88337 L .40416 .88133 L F
.605 .218 .283 r
.40416 .88133 m .40517 .88285 L .40545 .88231 L F
.40416 .88133 m .40241 .88337 L .40517 .88285 L F
.516 .289 .509 r
.36722 .76272 m .36681 .76474 L .36487 .76531 L F
.63 .538 .732 r
.36884 .76001 m .36932 .76245 L .36722 .76272 L F
.47 .19 .406 r
.36932 .76245 m .36681 .76474 L .36722 .76272 L F
.6 .717 .927 r
.57691 .81144 m .5745 .81063 L .5763 .81006 L F
.002 0 0 r
.57416 .81305 m .57691 .81144 L .57646 .81237 L F
.627 .555 .755 r
.57837 .80887 m .57691 .81144 L .5763 .81006 L F
.57837 .80887 m .57864 .81126 L .57691 .81144 L F
.453 .026 .137 r
.57691 .81144 m .5787 .81202 L .57646 .81237 L F
.57691 .81144 m .57864 .81126 L .5787 .81202 L F
.344 0 0 r
.45189 .831 m .45056 .83178 L .44841 .83177 L F
0 .359 .67 r
.45189 .831 m .4525 .83121 L .45056 .83178 L F
.45189 .831 m .45482 .83201 L .4525 .83121 L F
.757 .274 .091 r
.49234 .85246 m .49444 .85354 L .49303 .85415 L F
.873 .991 .739 r
.49303 .85415 m .49444 .85354 L .49485 .85183 L F
.318 .541 .911 r
.57097 .80099 m .56822 .79915 L .57195 .79917 L F
.764 .426 .414 r
.57195 .79917 m .57408 .80118 L .57301 .79897 L F
.57195 .79917 m .57301 .79897 L .57097 .80099 L F
.477 .799 1 r
.65214 .75175 m .65278 .75247 L .64968 .75211 L F
.7 .405 .473 r
.65278 .75247 m .65033 .75282 L .64968 .75211 L F
.65278 .75247 m .65299 .75391 L .65033 .75282 L F
.571 .808 .988 r
.65358 .75295 m .65278 .75247 L .65214 .75175 L F
.65358 .75295 m .65299 .75391 L .65278 .75247 L F
.093 0 0 r
.41453 .82246 m .41665 .82242 L .4178 .82223 L F
.26 0 0 r
.41665 .82242 m .41967 .82142 L .4178 .82223 L F
.699 .457 .553 r
.3932 .8867 m .39628 .88612 L .39613 .88403 L F
.694 .591 .736 r
.39628 .88612 m .39839 .88353 L .39613 .88403 L F
.721 .404 .442 r
.4734 .87063 m .4736 .8691 L .47136 .86859 L F
.776 .487 .497 r
.47644 .87136 m .4736 .8691 L .4734 .87063 L F
.721 .404 .442 r
.4734 .87063 m .47136 .86859 L .47026 .87115 L F
.44 .7 .976 r
.36671 .75684 m .36598 .758 L .36479 .75709 L F
.36671 .75684 m .36799 .75797 L .36598 .758 L F
0 0 .466 r
.61104 .76808 m .6108 .7705 L .61189 .76936 L F
0 0 .451 r
.61104 .77292 m .61189 .76936 L .6108 .7705 L F
.555 .809 .993 r
.53738 .81674 m .53995 .81695 L .53932 .81619 L F
.854 .915 .873 r
.53932 .81619 m .54015 .81672 L .54208 .81456 L F
.53932 .81619 m .54208 .81456 L .54136 .81641 L F
.221 .667 .952 r
.53932 .81619 m .54136 .81641 L .53834 .81557 L F
.53932 .81619 m .53834 .81557 L .53827 .81555 L F
.854 .915 .873 r
.53932 .81619 m .53995 .81695 L .54015 .81672 L F
.259 0 0 r
.5054 .80604 m .50722 .80663 L .50845 .80696 L F
0 .406 .717 r
.50722 .80663 m .51083 .80782 L .50845 .80696 L F
0 .539 .738 r
.48822 .87439 m .48501 .87402 L .48721 .87523 L F
.395 0 0 r
.48902 .87536 m .48822 .87439 L .48721 .87523 L F
.48902 .87536 m .49043 .87467 L .48822 .87439 L F
.299 0 0 r
.39287 .84358 m .3913 .84434 L .3893 .84432 L F
.545 .104 .152 r
.39476 .84333 m .3913 .84434 L .39287 .84358 L F
.75 .711 .816 r
.42283 .8378 m .42437 .84025 L .4211 .83999 L F
.205 0 0 r
.42437 .84025 m .42322 .84028 L .4211 .83999 L F
.573 .689 .92 r
.42424 .83789 m .42437 .84025 L .42283 .8378 L F
.42424 .83789 m .42638 .83995 L .42437 .84025 L F
.356 .828 .872 r
.42515 .83971 m .42437 .84025 L .42638 .83995 L F
.42515 .83971 m .42322 .84028 L .42437 .84025 L F
.435 .424 .748 r
.49635 .82667 m .49417 .82648 L .49534 .82373 L F
.49635 .82667 m .49476 .82751 L .49417 .82648 L F
.383 .016 .212 r
.52707 .8682 m .52982 .86636 L .52916 .86758 L F
.829 .756 .782 r
.53145 .86338 m .52982 .86636 L .52861 .86695 L F
.264 0 .148 r
.52916 .86758 m .52982 .86636 L .53154 .86574 L F
.351 .015 .248 r
.44687 .88564 m .44758 .88432 L .44927 .88398 L F
.771 .611 .681 r
.44127 .83195 m .44323 .83277 L .44422 .83203 L F
.44127 .83195 m .44422 .83203 L .44317 .832 L F
.433 .067 .242 r
.43643 .87362 m .4344 .87391 L .43321 .8761 L F
.591 .948 .876 r
.56901 .83157 m .57295 .83005 L .57213 .83095 L F
.857 .995 .761 r
.5259 .83034 m .52717 .82952 L .52477 .83239 L F
.991 .75 .468 r
.52717 .82952 m .52722 .83263 L .52477 .83239 L F
.304 0 0 r
.52892 .82951 m .52717 .82952 L .5259 .83034 L F
.455 0 .06 r
.38602 .82787 m .3877 .82852 L .38925 .82714 L F
.107 0 0 r
.3877 .82852 m .39137 .82739 L .38925 .82714 L F
.532 .15 .263 r
.38527 .84498 m .38201 .84608 L .38241 .8454 L F
.277 0 0 r
.43623 .88834 m .43981 .88628 L .43831 .88799 L F
.395 0 .042 r
.43981 .88628 m .44036 .88772 L .43831 .88799 L F
.43981 .88628 m .44181 .88619 L .44036 .88772 L F
.967 .756 .566 r
.5718 .78857 m .56965 .78962 L .57072 .78576 L F
.497 .113 .242 r
.5718 .78857 m .56862 .79056 L .56965 .78962 L F
.5718 .78857 m .57096 .79039 L .56862 .79056 L F
0 0 .289 r
.56862 .79056 m .56954 .79021 L .56992 .78829 L F
.497 .113 .242 r
.56965 .78962 m .56862 .79056 L .56956 .78967 L F
.974 .793 .597 r
.5718 .78857 m .56965 .78962 L .56999 .78816 L F
.967 .756 .566 r
.56965 .78962 m .56956 .78967 L .56982 .78881 L F
.974 .793 .597 r
.56965 .78962 m .56956 .78967 L .56999 .78816 L F
0 0 .289 r
.56992 .78829 m .56993 .78844 L .56999 .78816 L F
.56993 .78844 m .56999 .78931 L .56999 .78816 L F
.56999 .78931 m .57004 .79002 L .57002 .78929 L F
.56999 .78931 m .57002 .78929 L .56999 .78816 L F
.56954 .79021 m .57004 .79002 L .56992 .78829 L F
.967 .756 .566 r
.56965 .78962 m .56982 .78881 L .57072 .78576 L F
.263 .013 .334 r
.57388 .78596 m .5718 .78857 L .57072 .78576 L F
.57388 .78596 m .57362 .78834 L .5718 .78857 L F
.252 0 .126 r
.57323 .78951 m .5718 .78857 L .57362 .78834 L F
.57323 .78951 m .57096 .79039 L .5718 .78857 L F
0 0 0 r
.51276 .87872 m .51537 .87641 L .51461 .87821 L F
0 0 .023 r
.51461 .87821 m .51537 .87641 L .51682 .87571 L F
0 0 0 r
.52357 .83371 m .52288 .8338 L .52249 .83433 L F
.279 .488 .882 r
.52483 .83483 m .52288 .8338 L .52477 .83239 L F
0 0 0 r
.52357 .83371 m .52477 .83239 L .52288 .8338 L F
.042 0 0 r
.46707 .87146 m .46609 .87138 L .46478 .87107 L F
.46707 .87146 m .46817 .87123 L .46609 .87138 L F
.504 .156 .311 r
.5012 .81193 m .50369 .81178 L .50236 .81114 L F
.361 .304 .658 r
.50236 .81114 m .50369 .81178 L .50287 .80922 L F
.501 0 0 r
.49584 .88647 m .49901 .8863 L .49797 .88666 L F
.223 0 0 r
.49901 .8863 m .50111 .88629 L .49797 .88666 L F
.939 .697 .545 r
.48894 .8441 m .49042 .84559 L .48882 .84715 L F
.697 .926 .603 r
.48882 .84715 m .49042 .84559 L .4912 .84433 L F
0 0 0 r
.40913 .88187 m .40517 .88285 L .40769 .88236 L F
.228 0 0 r
.40963 .88259 m .40913 .88187 L .40769 .88236 L F
.40963 .88259 m .41131 .88158 L .40913 .88187 L F
.523 .217 .39 r
.51885 .86693 m .5165 .86833 L .51864 .8675 L F
.186 0 .035 r
.52097 .86583 m .51885 .86693 L .51864 .8675 L F
.743 .221 0 r
.49563 .81159 m .49284 .80939 L .4952 .80933 L F
.49563 .81159 m .49432 .81113 L .49284 .80939 L F
.954 .943 .629 r
.49428 .81281 m .49432 .81113 L .49563 .81159 L F
.748 .652 .754 r
.49795 .80925 m .49563 .81159 L .4952 .80933 L F
.558 .734 .958 r
.49827 .81118 m .49563 .81159 L .49795 .80925 L F
.391 .595 .927 r
.53693 .80867 m .53579 .80987 L .535 .80944 L F
.53693 .80867 m .53905 .81113 L .53579 .80987 L F
.317 .533 .905 r
.53901 .81226 m .53579 .80987 L .53905 .81113 L F
.536 .35 .575 r
.36681 .76474 m .36479 .76758 L .36487 .76531 L F
.467 .432 .736 r
.36064 .74609 m .36238 .74673 L .36092 .74723 L F
.517 .411 .673 r
.36252 .74671 m .36092 .74723 L .36238 .74673 L F
.36252 .74671 m .361 .74957 L .36092 .74723 L F
.693 .289 .276 r
.48024 .82536 m .48172 .82672 L .48068 .82584 L F
.335 0 0 r
.52272 .81846 m .52182 .81747 L .52346 .81661 L F
.954 .943 .629 r
.49428 .81281 m .49278 .8132 L .49432 .81113 L F
.565 .16 .234 r
.46162 .87 m .46281 .86827 L .45965 .8688 L F
.64 .477 .647 r
.46281 .86827 m .46485 .86787 L .46489 .86604 L F
.619 .408 .574 r
.46478 .87107 m .46281 .86827 L .46162 .87 L F
.46478 .87107 m .46485 .86787 L .46281 .86827 L F
.64 .477 .647 r
.46281 .86827 m .46485 .86787 L .46489 .86604 L F
.755 .771 .866 r
.57388 .78596 m .57072 .78576 L .57206 .78563 L F
.59 .616 .846 r
.57497 .78308 m .57388 .78596 L .57206 .78563 L F
.57497 .78308 m .57598 .78562 L .57388 .78596 L F
.125 0 .292 r
.57491 .78727 m .57388 .78596 L .57598 .78562 L F
.57491 .78727 m .57362 .78834 L .57388 .78596 L F
.746 .577 .665 r
.49795 .80925 m .4952 .80933 L .49519 .80645 L F
.691 .425 .516 r
.44666 .87274 m .44933 .87123 L .44712 .87135 L F
.417 .499 .835 r
.54034 .81083 m .53901 .81226 L .53905 .81113 L F
.188 .16 .593 r
.54333 .81358 m .54208 .81456 L .54266 .81456 L F
.469 .535 .842 r
.54333 .81358 m .54266 .81456 L .54252 .81434 L F
0 0 0 r
.54301 .81388 m .54208 .81456 L .54333 .81358 L F
.469 .535 .842 r
.54333 .81358 m .54252 .81434 L .54034 .81083 L F
0 0 0 r
.54325 .8137 m .54301 .81388 L .54333 .81358 L F
.427 .514 .845 r
.54252 .81434 m .54266 .81456 L .54242 .81442 L F
.488 .558 .854 r
.54208 .81456 m .53901 .81226 L .54242 .81442 L F
.54208 .81456 m .54242 .81442 L .54266 .81456 L F
0 0 0 r
.54136 .81641 m .542 .81478 L .54242 .81442 L F
.54289 .81421 m .54242 .81442 L .54325 .8137 L F
.54136 .81641 m .54242 .81442 L .54289 .81421 L F
.542 .81478 m .54208 .81456 L .54325 .8137 L F
.427 .514 .845 r
.54034 .81083 m .54252 .81434 L .53901 .81226 L F
.54252 .81434 m .54242 .81442 L .53901 .81226 L F
.293 0 0 r
.51387 .80866 m .51585 .80903 L .51715 .80899 L F
.469 .871 .961 r
.51585 .80903 m .51891 .80867 L .51715 .80899 L F
.547 .152 .246 r
.61174 .76711 m .61507 .76521 L .61286 .76603 L F
.642 .9 .578 r
.61286 .76603 m .61104 .76808 L .61174 .76711 L F
.547 .152 .246 r
.61174 .76711 m .61449 .76703 L .61507 .76521 L F
.632 .518 .707 r
.61708 .76478 m .61499 .76765 L .61507 .76521 L F
.147 0 .104 r
.61507 .76521 m .61596 .76636 L .61708 .76478 L F
.61507 .76521 m .61449 .76703 L .61596 .76636 L F
.892 .734 .678 r
.52244 .81379 m .52346 .81661 L .5232 .81436 L F
.97 .667 .277 r
.52208 .81151 m .52244 .81379 L .5232 .81436 L F
.662 .51 .666 r
.46489 .86604 m .46716 .86536 L .46724 .86346 L F
.517 .317 .548 r
.4692 .86208 m .46724 .86346 L .46869 .86521 L F
.344 .411 .787 r
.36142 .74365 m .36064 .74609 L .35946 .74419 L F
.36142 .74365 m .36238 .74673 L .36064 .74609 L F
0 0 0 r
.49377 .80766 m .49473 .80784 L .49519 .80645 L F
.341 0 0 r
.49519 .80645 m .49657 .80762 L .49592 .8059 L F
.49519 .80645 m .49473 .80784 L .49657 .80762 L F
0 0 0 r
.45377 .81766 m .45533 .81742 L .45683 .81715 L F
.342 0 0 r
.45533 .81742 m .45903 .8173 L .45683 .81715 L F
.564 .864 .996 r
.56695 .83215 m .56901 .83157 L .56906 .83256 L F
.539 .454 .707 r
.56887 .83185 m .57042 .82872 L .56806 .82884 L F
.636 .184 .162 r
.56901 .83157 m .57182 .83307 L .56906 .83256 L F
.539 .454 .707 r
.56906 .83256 m .56928 .83194 L .56887 .83185 L F
.636 .184 .162 r
.56901 .83157 m .57213 .83095 L .5719 .83254 L F
.56901 .83157 m .5719 .83254 L .57002 .83211 L F
.539 .454 .707 r
.56928 .83194 m .57042 .82872 L .56887 .83185 L F
.636 .184 .162 r
.57002 .83211 m .5719 .83254 L .57182 .83307 L F
.509 .251 .46 r
.57213 .83095 m .57516 .83041 L .57413 .8296 L F
.352 .023 .261 r
.5741 .8304 m .57213 .83095 L .57413 .8296 L F
.557 .769 .977 r
.5741 .8304 m .57516 .83041 L .57213 .83095 L F
.371 .037 .263 r
.5741 .8304 m .57413 .8296 L .57556 .83002 L F
.557 .769 .977 r
.57494 .83016 m .57496 .83018 L .5741 .8304 L F
.57496 .83018 m .57516 .83041 L .5741 .8304 L F
.442 .267 .547 r
.57413 .8296 m .57516 .83041 L .5768 .82934 L F
.696 .827 .946 r
.5768 .82934 m .57516 .83041 L .57496 .83018 L F
.371 .037 .263 r
.5754 .82997 m .57413 .8296 L .5768 .82934 L F
.696 .827 .946 r
.5768 .82934 m .57496 .83018 L .57391 .82896 L F
.371 .037 .263 r
.57556 .83002 m .5754 .82997 L .5768 .82934 L F
.57409 .83082 m .5741 .8304 L .57556 .83002 L F
.352 .023 .261 r
.57409 .83082 m .57213 .83095 L .5741 .8304 L F
.557 .769 .977 r
.57391 .82896 m .57494 .83016 L .57213 .83095 L F
.309 0 .107 r
.57182 .83307 m .57213 .83095 L .57409 .83082 L F
.467 0 0 r
.47755 .88245 m .47861 .88221 L .48096 .8832 L F
.677 .221 .162 r
.47861 .88221 m .48228 .88333 L .48096 .8832 L F
.235 .753 .802 r
.49369 .8507 m .49234 .85246 L .49302 .8512 L F
.537 .28 .473 r
.49369 .8507 m .49306 .85202 L .49516 .85194 L F
.757 .274 .091 r
.49234 .85246 m .49303 .85415 L .49302 .85171 L F
.49298 .85128 m .49302 .85171 L .49302 .8512 L F
.737 .486 .55 r
.49302 .8512 m .49303 .85415 L .49263 .85291 L F
.537 .28 .473 r
.49306 .85202 m .49263 .85291 L .49313 .85272 L F
.49306 .85202 m .49313 .85272 L .49516 .85194 L F
.757 .274 .091 r
.49234 .85246 m .49302 .85171 L .49298 .85128 L F
.674 .315 .357 r
.49432 .81113 m .49235 .81119 L .49284 .80939 L F
.871 .973 .85 r
.50529 .88369 m .50636 .88375 L .50839 .88142 L F
0 0 0 r
.49486 .82865 m .49476 .82751 L .49635 .82667 L F
.49486 .82865 m .49411 .82961 L .49476 .82751 L F
.257 0 0 r
.47879 .81103 m .4809 .81089 L .4822 .81013 L F
.111 0 0 r
.4809 .81089 m .48379 .81035 L .4822 .81013 L F
.048 .165 .665 r
.57693 .79542 m .576 .79628 L .57498 .79244 L F
0 0 .279 r
.49086 .81979 m .4902 .82152 L .49039 .82009 L F
0 0 0 r
.39449 .90123 m .39388 .90149 L .39336 .90166 L F
.39449 .90123 m .39511 .90116 L .39388 .90149 L F
.39449 .90123 m .3969 .90013 L .39511 .90116 L F
.603 .953 .865 r
.66331 .74609 m .66224 .74719 L .66156 .74716 L F
.345 .245 .595 r
.66393 .74841 m .66224 .74719 L .66331 .74609 L F
.66393 .74841 m .66251 .7496 L .66224 .74719 L F
.829 .756 .782 r
.53145 .86338 m .52861 .86695 L .53115 .86617 L F
0 0 0 r
.53154 .86574 m .53375 .86377 L .53272 .86506 L F
.534 .085 .132 r
.53272 .86506 m .53116 .86604 L .53115 .86617 L F
.483 .728 .979 r
.53103 .86613 m .52861 .86695 L .52709 .8649 L F
.53115 .86617 m .53078 .86628 L .53103 .86613 L F
.53078 .86628 m .52861 .86695 L .53103 .86613 L F
.725 .84 .935 r
.53272 .86506 m .53115 .86617 L .53106 .86612 L F
0 0 0 r
.53111 .86609 m .53082 .86626 L .53272 .86506 L F
.53081 .86626 m .53082 .86626 L .53164 .86576 L F
.53082 .86626 m .53154 .86574 L .53272 .86506 L F
.534 .085 .132 r
.53272 .86506 m .53145 .86338 L .53116 .86604 L F
.725 .84 .935 r
.53272 .86506 m .53201 .86551 L .53227 .86503 L F
.606 .353 .506 r
.5303 .86664 m .53272 .86506 L .53181 .86636 L F
.53008 .86679 m .53181 .86636 L .53021 .86666 L F
.53008 .86679 m .53021 .86666 L .52909 .86687 L F
.264 0 .148 r
.52916 .86758 m .5297 .86716 L .53008 .86679 L F
.5297 .86716 m .53056 .8665 L .53008 .86679 L F
.53056 .8665 m .53154 .86574 L .53087 .86622 L F
.53056 .8665 m .53087 .86622 L .53008 .86679 L F
.483 .728 .979 r
.53102 .86609 m .52709 .8649 L .52882 .86482 L F
0 0 0 r
.53008 .86679 m .53081 .86626 L .53103 .86613 L F
.53137 .86594 m .53103 .86613 L .53164 .86576 L F
.53008 .86679 m .53103 .86613 L .53137 .86594 L F
.483 .728 .979 r
.53106 .86612 m .53099 .86612 L .53102 .86609 L F
.53115 .86617 m .53103 .86613 L .53106 .86612 L F
.53103 .86613 m .53099 .86612 L .53106 .86612 L F
.53099 .86612 m .52709 .8649 L .53102 .86609 L F
.534 .085 .132 r
.53272 .86506 m .53375 .86377 L .53145 .86338 L F
.86 .7 .683 r
.53229 .865 m .53272 .86506 L .53256 .86423 L F
.53181 .86636 m .53272 .86506 L .53229 .865 L F
.725 .84 .935 r
.53272 .86506 m .52882 .86482 L .52957 .86463 L F
.711 .184 0 r
.53073 .86417 m .53256 .86423 L .53018 .8637 L F
.725 .84 .935 r
.53272 .86506 m .52957 .86463 L .53104 .86424 L F
.53272 .86506 m .53104 .86424 L .53188 .86445 L F
.86 .7 .683 r
.53181 .86636 m .5323 .86496 L .53261 .86576 L F
.5323 .86496 m .53257 .86447 L .53261 .86576 L F
.725 .84 .935 r
.53227 .86503 m .53106 .86612 L .52882 .86482 L F
.53201 .86551 m .53106 .86612 L .53227 .86503 L F
0 0 0 r
.53164 .86576 m .53111 .86609 L .53272 .86506 L F
.612 .552 .763 r
.53018 .8637 m .53145 .86414 L .53104 .86424 L F
.53018 .8637 m .53104 .86424 L .52882 .86482 L F
.711 .184 0 r
.53261 .86576 m .53259 .86522 L .53073 .86417 L F
.53259 .86522 m .53257 .86462 L .53104 .86424 L F
.53259 .86522 m .53104 .86424 L .53073 .86417 L F
.995 .754 .44 r
.53256 .86423 m .53272 .86506 L .53241 .86483 L F
.86 .7 .683 r
.53244 .8647 m .53256 .86423 L .53257 .86447 L F
.5323 .86496 m .53256 .86423 L .53244 .8647 L F
.711 .184 0 r
.53188 .86445 m .53256 .86423 L .53073 .86417 L F
.995 .754 .44 r
.53256 .86423 m .53241 .86483 L .53188 .86445 L F
.711 .184 0 r
.53257 .86462 m .53256 .86423 L .53188 .86445 L F
.995 .754 .44 r
.53256 .86423 m .53188 .86445 L .53145 .86414 L F
.725 .84 .935 r
.53188 .86445 m .53104 .86424 L .53145 .86414 L F
.216 0 .084 r
.48425 .8284 m .4828 .82784 L .48559 .82773 L F
.536 .125 .209 r
.42178 .82138 m .4239 .82158 L .4251 .8199 L F
.336 0 .038 r
.4239 .82158 m .4269 .81985 L .4251 .8199 L F
.714 .363 .381 r
.57837 .80887 m .5813 .80902 L .58088 .81123 L F
.142 0 0 r
.58131 .80908 m .5813 .80902 L .57837 .80887 L F
.11 0 .213 r
.58088 .81123 m .5813 .80902 L .58295 .80846 L F
0 0 0 r
.58295 .80846 m .5813 .80902 L .58131 .80908 L F
.591 .394 .582 r
.60876 .77532 m .60871 .7776 L .60654 .77559 L F
.60876 .77532 m .60871 .7776 L .60654 .77559 L F
.535 .226 .39 r
.45362 .88092 m .45554 .88363 L .45332 .88421 L F
.45362 .88092 m .45666 .88089 L .45554 .88363 L F
.24 0 0 r
.48379 .81035 m .48566 .81021 L .48727 .80906 L F
.542 .101 .151 r
.48566 .81021 m .48891 .80901 L .48727 .80906 L F
.35 .821 .898 r
.50206 .87418 m .50273 .87438 L .50065 .87483 L F
.191 0 0 r
.50228 .87425 m .50273 .87438 L .50206 .87418 L F
0 0 0 r
.50308 .87448 m .50065 .87483 L .50273 .87438 L F
.191 0 0 r
.50386 .87475 m .50273 .87438 L .50228 .87425 L F
0 0 0 r
.50436 .8743 m .50308 .87448 L .50273 .87438 L F
.305 .798 .848 r
.50636 .87382 m .50436 .8743 L .50273 .87438 L F
.652 .678 .862 r
.52249 .83433 m .52267 .83572 L .52483 .83483 L F
.779 .94 .592 r
.49731 .84966 m .49696 .85079 L .49875 .8481 L F
.404 .693 .979 r
.4994 .84705 m .49875 .8481 L .49641 .84643 L F
.644 .884 .536 r
.49731 .84966 m .49875 .8481 L .4994 .84705 L F
.316 0 .019 r
.4039 .89844 m .40689 .89682 L .40568 .89824 L F
.319 0 .039 r
.40568 .89824 m .40689 .89682 L .40896 .8967 L F
.176 0 0 r
.5278 .8083 m .52677 .80911 L .52481 .80951 L F
.445 0 .005 r
.52974 .80843 m .52677 .80911 L .5278 .8083 L F
.491 .462 .753 r
.51713 .86147 m .51754 .8639 L .51906 .86352 L F
0 .006 .553 r
.51713 .86147 m .51754 .8639 L .51807 .86327 L F
.425 .242 .528 r
.51823 .86433 m .51754 .8639 L .51906 .86352 L F
.068 .3 .785 r
.51807 .86327 m .51754 .8639 L .51823 .86433 L F
.76 .996 .842 r
.49485 .85183 m .49696 .85079 L .49731 .84966 L F
.527 .014 0 r
.44835 .81834 m .4503 .81881 L .45177 .81807 L F
.376 0 0 r
.4503 .81881 m .45377 .81766 L .45177 .81807 L F
.532 .15 .263 r
.38527 .84498 m .38428 .84699 L .38201 .84608 L F
.69 .374 .435 r
.38713 .84486 m .38428 .84699 L .38527 .84498 L F
.315 0 0 r
.45903 .8173 m .46106 .81697 L .46195 .8161 L F
.357 0 .025 r
.46106 .81697 m .46399 .8158 L .46195 .8161 L F
.829 .894 .473 r
.52642 .80367 m .52526 .80554 L .52524 .80301 L F
.706 .913 .966 r
.52498 .80695 m .52344 .80654 L .52526 .80554 L F
0 0 0 r
.52526 .80554 m .52465 .80613 L .52481 .80601 L F
.829 .894 .473 r
.52588 .80489 m .52498 .80695 L .52526 .80554 L F
0 0 0 r
.52526 .80554 m .52481 .80601 L .52639 .80481 L F
.829 .894 .473 r
.52642 .80367 m .52588 .80489 L .52526 .80554 L F
.52 .828 1 r
.52747 .80257 m .52642 .80367 L .52524 .80301 L F
.52747 .80257 m .52869 .80323 L .52642 .80367 L F
.97 .665 .385 r
.39364 .791 m .39518 .79372 L .39412 .79344 L F
.39364 .791 m .39518 .79372 L .39412 .79344 L F
.74 .274 .14 r
.47218 .86334 m .4692 .86208 L .47155 .8617 L F
.785 .985 .898 r
.46869 .86521 m .47218 .86334 L .47157 .86373 L F
.224 .37 .8 r
.47326 .86247 m .47218 .86334 L .47155 .8617 L F
.464 .843 .614 r
.47157 .86373 m .47218 .86334 L .47326 .86247 L F
.195 0 .012 r
.5763 .81006 m .5745 .81063 L .57383 .81131 L F
.513 .143 .274 r
.37842 .82964 m .38064 .82943 L .37868 .82921 L F
.582 .177 .24 r
.39767 .84271 m .39651 .8443 L .39476 .84333 L F
.126 0 0 r
.39981 .84193 m .39874 .84292 L .39767 .84271 L F
.508 .255 .466 r
.39874 .84292 m .39651 .8443 L .39767 .84271 L F
.444 0 .089 r
.39841 .82603 m .4004 .82602 L .40191 .82445 L F
.301 0 0 r
.4004 .82602 m .40394 .82471 L .40191 .82445 L F
.059 0 .183 r
.41892 .87614 m .41667 .87935 L .4182 .87838 L F
.538 .333 .55 r
.4182 .87838 m .42029 .87637 L .41892 .87614 L F
0 0 .466 r
.61104 .76808 m .61189 .76936 L .61174 .76711 L F
.308 0 0 r
.51041 .87322 m .51183 .87169 L .50895 .87276 L F
.252 0 0 r
.51372 .87126 m .51183 .87169 L .51041 .87322 L F
.877 .839 .804 r
.47519 .85995 m .47847 .85789 L .47736 .85835 L F
.216 0 0 r
.43587 .83238 m .43452 .83368 L .43387 .83364 L F
.361 0 .023 r
.43788 .83205 m .43452 .83368 L .43587 .83238 L F
.421 .126 .357 r
.5165 .86833 m .51372 .87126 L .51585 .87103 L F
.469 .198 .419 r
.51864 .8675 m .5165 .86833 L .51585 .87103 L F
.296 0 0 r
.4269 .81985 m .429 .82028 L .43048 .82005 L F
.231 0 0 r
.429 .82028 m .43245 .81982 L .43048 .82005 L F
0 .519 .794 r
.48531 .81408 m .48699 .81441 L .48843 .81485 L F
.642 .116 0 r
.4755 .8721 m .47644 .87136 L .4734 .87063 L F
.643 .117 0 r
.4755 .8721 m .4793 .87289 L .47644 .87136 L F
0 0 0 r
.4182 .87838 m .41667 .87935 L .4151 .88074 L F
.692 .333 .362 r
.45852 .83081 m .45746 .83049 L .4591 .82917 L F
.45852 .83081 m .45607 .83109 L .45746 .83049 L F
.804 .61 .639 r
.65033 .75282 m .64937 .75492 L .64968 .75211 L F
.271 .029 .351 r
.65033 .75282 m .64952 .75631 L .64937 .75492 L F
.58 .239 .357 r
.65299 .75391 m .64952 .75631 L .65033 .75282 L F
.714 .363 .381 r
.57837 .80887 m .58088 .81123 L .57864 .81126 L F
.321 0 .144 r
.5787 .81202 m .57864 .81126 L .58088 .81123 L F
.417 .003 .143 r
.41073 .89627 m .41437 .89415 L .41255 .89581 L F
.36 0 .037 r
.41437 .89415 m .41342 .89559 L .41255 .89581 L F
.41437 .89415 m .4165 .89386 L .41342 .89559 L F
.063 .605 .847 r
.51517 .81627 m .51219 .8157 L .51322 .81691 L F
.726 .625 .745 r
.51318 .81878 m .51517 .81627 L .51322 .81691 L F
.133 0 0 r
.3969 .90013 m .39703 .90059 L .39511 .90116 L F
.3969 .90013 m .39869 .9 L .39703 .90059 L F
.709 .372 .405 r
.50031 .8238 m .49776 .82448 L .49816 .82203 L F
.50031 .8238 m .49776 .82448 L .49816 .82203 L F
.729 .348 .327 r
.52332 .83274 m .52477 .83239 L .52357 .83371 L F
.857 .995 .761 r
.5259 .83034 m .52477 .83239 L .52332 .83274 L F
.956 .719 .541 r
.52357 .83371 m .52483 .83483 L .52477 .83239 L F
.642 .464 .627 r
.52477 .83239 m .52722 .83263 L .52483 .83483 L F
.335 0 0 r
.52477 .83239 m .52573 .83306 L .52357 .83371 L F
.52477 .83239 m .52722 .83263 L .52573 .83306 L F
.648 .724 .905 r
.53388 .82958 m .53215 .83057 L .53112 .82945 L F
.53388 .82958 m .53215 .83057 L .53112 .82945 L F
.498 .369 .635 r
.53432 .83189 m .53215 .83057 L .53388 .82958 L F
.53388 .82958 m .53215 .83057 L .53432 .83189 L F
.871 .973 .85 r
.50529 .88369 m .50839 .88142 L .50733 .88264 L F
.19 0 0 r
.50733 .88264 m .50839 .88142 L .50985 .88122 L F
.69 .75 .897 r
.57416 .81305 m .57594 .81079 L .57383 .81131 L F
.57416 .81305 m .57646 .81237 L .57594 .81079 L F
.662 .34 .418 r
.66757 .74169 m .67073 .74123 L .6685 .73935 L F
.548 0 0 r
.48228 .88333 m .48398 .88418 L .48096 .8832 L F
.645 .527 .705 r
.52875 .81427 m .53057 .81439 L .53082 .81155 L F
.634 .359 .484 r
.53057 .81439 m .53082 .81623 L .52875 .81427 L F
.53057 .81439 m .53082 .81623 L .52875 .81427 L F
0 0 .489 r
.48041 .87425 m .47979 .87392 L .4793 .87289 L F
.256 0 0 r
.48218 .87473 m .47979 .87392 L .48041 .87425 L F
.565 .16 .234 r
.46162 .87 m .45965 .8688 L .45933 .87013 L F
.335 .815 .879 r
.4112 .83945 m .41054 .83991 L .41256 .83985 L F
.4112 .83945 m .40934 .8399 L .41054 .83991 L F
.643 .277 .335 r
.5022 .81664 m .50112 .81857 L .49901 .81735 L F
.47 .19 .406 r
.36932 .76245 m .36893 .76444 L .36681 .76474 L F
.619 .531 .733 r
.37155 .76201 m .36932 .76245 L .36884 .76001 L F
.546 .258 .429 r
.36932 .76245 m .37082 .76421 L .36893 .76444 L F
.533 .257 .442 r
.37155 .76201 m .37082 .76421 L .36932 .76245 L F
.179 .711 .836 r
.43245 .81982 m .43443 .81964 L .4357 .81973 L F
0 0 0 r
.43443 .81964 m .43773 .81948 L .4357 .81973 L F
.43 0 .07 r
.46641 .81478 m .46813 .81538 L .46938 .81382 L F
.629 .293 .384 r
.46813 .81538 m .47144 .81338 L .46938 .81382 L F
.726 .272 0 r
.54199 .81715 m .54384 .81965 L .54136 .81641 L F
.711 .979 .912 r
.54013 .81892 m .54177 .81889 L .53972 .81914 L F
.957 .659 .428 r
.54136 .81641 m .54324 .81887 L .54177 .81889 L F
0 0 .468 r
.54136 .81641 m .54177 .81889 L .54251 .81758 L F
.711 .979 .912 r
.54251 .81758 m .54177 .81889 L .54013 .81892 L F
.957 .659 .428 r
.54324 .81887 m .54384 .81965 L .54177 .81889 L F
.995 .825 .462 r
.64937 .75492 m .64875 .75381 L .64968 .75211 L F
0 0 0 r
.64968 .75211 m .65113 .75162 L .65214 .75175 L F
.64968 .75211 m .64875 .75381 L .65113 .75162 L F
.57321 .79436 m .57022 .79585 L .57225 .79395 L F
.862 .964 .866 r
.57498 .79244 m .57321 .79436 L .57225 .79395 L F
.296 0 .191 r
.48522 .85442 m .48618 .85325 L .48798 .85269 L F
.618 .762 .948 r
.5012 .81193 m .49827 .81118 L .49991 .81191 L F
0 0 .543 r
.50287 .80922 m .50369 .81178 L .50413 .81039 L F
.50287 .80922 m .50413 .81039 L .50207 .80849 L F
.003 0 0 r
.50169 .81205 m .50337 .81182 L .5012 .81193 L F
.50337 .81182 m .50369 .81178 L .50342 .8118 L F
.50337 .81182 m .50342 .8118 L .5012 .81193 L F
.796 .998 .847 r
.50413 .81039 m .50369 .81178 L .50169 .81205 L F
.313 .345 .734 r
.50207 .80849 m .50413 .81039 L .50321 .80787 L F
.635 .264 .323 r
.50103 .81189 m .50413 .81039 L .50169 .81205 L F
.50103 .81189 m .50292 .81233 L .50413 .81039 L F
.667 .833 .411 r
.50413 .81039 m .50315 .81196 L .50469 .80922 L F
.50315 .81196 m .50292 .81233 L .50312 .81198 L F
.50315 .81196 m .50312 .81198 L .50469 .80922 L F
.164 0 0 r
.50895 .87276 m .50636 .87382 L .50835 .87334 L F
.308 0 0 r
.51041 .87322 m .50895 .87276 L .50835 .87334 L F
.799 .735 .793 r
.52498 .80695 m .52045 .80804 L .52344 .80654 L F
.675 .824 .955 r
.62452 .75979 m .62116 .75957 L .62334 .75867 L F
.69 .392 .465 r
.62452 .75979 m .62123 .76184 L .62116 .75957 L F
.62452 .75979 m .62429 .7622 L .62123 .76184 L F
.473 .757 .992 r
.62546 .75862 m .62452 .75979 L .62334 .75867 L F
.62526 .75887 m .62646 .75951 L .62452 .75979 L F
.634 .343 .458 r
.62653 .76177 m .62429 .7622 L .62452 .75979 L F
.504 .349 .604 r
.62646 .75951 m .62653 .76177 L .62452 .75979 L F
.645 .393 .523 r
.62372 .75878 m .62289 .76199 L .62593 .75947 L F
.62334 .75867 m .62333 .75876 L .62372 .75878 L F
.62333 .75876 m .62289 .76199 L .62372 .75878 L F
.473 .757 .992 r
.62546 .75862 m .62577 .75889 L .62526 .75887 L F
.62577 .75889 m .62646 .75951 L .62526 .75887 L F
.632 .518 .707 r
.61708 .76478 m .61815 .76759 L .61499 .76765 L F
.645 .445 .598 r
.61799 .76944 m .61499 .76765 L .61815 .76759 L F
.61799 .76944 m .61495 .76983 L .61499 .76765 L F
.42 .725 .988 r
.47494 .82718 m .47568 .82615 L .4742 .82728 L F
.687 .854 .963 r
.47519 .85995 m .47442 .86176 L .47658 .86073 L F
.412 0 .05 r
.3827 .82938 m .38478 .8293 L .38602 .82787 L F
.455 0 .079 r
.38602 .82787 m .38478 .8293 L .3877 .82852 L F
.281 0 0 r
.44505 .81907 m .44835 .81834 L .44616 .81846 L F
.92 .964 .787 r
.56492 .82491 m .56595 .82475 L .56435 .82704 L F
.434 .099 .296 r
.56748 .82672 m .56595 .82475 L .56492 .82491 L F
.56748 .82672 m .56803 .82425 L .56595 .82475 L F
.572 .567 .81 r
.36984 .75766 m .36884 .76001 L .36799 .75797 L F
.36984 .75766 m .37077 .75991 L .36884 .76001 L F
.619 .531 .733 r
.37155 .76201 m .36884 .76001 L .37077 .75991 L F
.409 .81 .983 r
.43773 .81948 m .43968 .8192 L .44097 .81966 L F
.2 .708 .899 r
.43968 .8192 m .44305 .81947 L .44097 .81966 L F
.419 0 0 r
.47421 .88281 m .47221 .88164 L .47438 .8829 L F
.47066 .88093 m .47221 .88164 L .47421 .88281 L F
.592 .126 .117 r
.47034 .88116 m .47143 .88118 L .47221 .88164 L F
.47143 .88118 m .47359 .88121 L .47221 .88164 L F
.594 .14 .142 r
.47359 .88121 m .47438 .8829 L .47221 .88164 L F
.47359 .88121 m .47551 .88154 L .47438 .8829 L F
0 0 0 r
.61104 .77292 m .60961 .77414 L .61222 .77197 L F
.616 .437 .617 r
.61302 .77223 m .61073 .77484 L .61104 .77292 L F
.3 0 .132 r
.52408 .87053 m .52707 .8682 L .52596 .86988 L F
.34 0 .132 r
.52707 .8682 m .52863 .86849 L .52596 .86988 L F
.52707 .8682 m .52916 .86758 L .52863 .86849 L F
.514 .122 .235 r
.40394 .82471 m .40611 .82472 L .40697 .82363 L F
.369 0 .06 r
.40611 .82472 m .40905 .82357 L .40697 .82363 L F
.624 .323 .441 r
.48068 .82584 m .47896 .829 L .47707 .82731 L F
.746 .509 .572 r
.48172 .82672 m .47896 .829 L .48068 .82584 L F
.519 .096 .177 r
.48721 .87523 m .48501 .87402 L .48392 .87554 L F
.623 .383 .534 r
.4692 .86208 m .47157 .86373 L .47155 .8617 L F
.602 .394 .572 r
.46869 .86521 m .47157 .86373 L .4692 .86208 L F
.428 0 0 r
.48522 .85442 m .48243 .85512 L .4838 .85557 L F
.748 .693 .799 r
.43788 .83205 m .43993 .83275 L .44127 .83195 L F
.35 .423 .797 r
.51903 .86278 m .51906 .86352 L .51713 .86147 L F
.665 .335 .405 r
.51807 .86327 m .51903 .86278 L .51713 .86147 L F
.304 0 0 r
.40525 .84132 m .40391 .84184 L .40191 .84173 L F
0 0 0 r
.40587 .84142 m .40525 .84132 L .40771 .84083 L F
.40587 .84142 m .40391 .84184 L .40525 .84132 L F
.589 .415 .614 r
.61495 .76983 m .61302 .77223 L .6133 .77038 L F
.503 .049 .105 r
.41113 .82364 m .41324 .82382 L .41453 .82246 L F
.302 0 0 r
.41453 .82246 m .41523 .82348 L .41665 .82242 L F
.41453 .82246 m .41324 .82382 L .41523 .82348 L F
.551 .507 .76 r
.36168 .75314 m .36399 .75394 L .36215 .75475 L F
.656 .57 .746 r
.36399 .75394 m .36242 .75718 L .36215 .75475 L F
.163 .679 .891 r
.5682 .81804 m .56931 .81839 L .56589 .81825 L F
.56931 .81839 m .57054 .81878 L .56812 .8185 L F
.56931 .81839 m .56812 .8185 L .56589 .81825 L F
.823 .957 .901 r
.56663 .821 m .57054 .81878 L .5682 .81804 L F
.191 0 .138 r
.5697 .81984 m .57054 .81837 L .5708 .81825 L F
.57152 .81818 m .5708 .81825 L .57217 .81759 L F
.5697 .81984 m .5708 .81825 L .57152 .81818 L F
.352 .17 .489 r
.49487 .84757 m .49369 .8507 L .49516 .85009 L F
.329 .227 .584 r
.49641 .84643 m .49487 .84757 L .49667 .84699 L F
.601 .343 .499 r
.49487 .84757 m .49516 .85009 L .49731 .84966 L F
.188 0 0 r
.51935 .8732 m .52235 .87137 L .52109 .87317 L F
.084 0 0 r
.52109 .87317 m .52235 .87137 L .52408 .87053 L F
.321 0 0 r
.42166 .89156 m .42291 .89224 L .4211 .89245 L F
.42166 .89156 m .42362 .89131 L .42291 .89224 L F
.115 0 0 r
.42758 .89069 m .42933 .88964 L .4313 .88924 L F
.55 .302 .493 r
.43073 .87795 m .42904 .87621 L .42874 .87816 L F
.43073 .87795 m .43109 .87601 L .42904 .87621 L F
.517 .411 .673 r
.36252 .74671 m .36274 .74876 L .361 .74957 L F
.576 .487 .717 r
.36274 .74876 m .36139 .75207 L .361 .74957 L F
.526 .027 .013 r
.44127 .83195 m .43997 .83245 L .43788 .83205 L F
.258 0 0 r
.44317 .832 m .43997 .83245 L .44127 .83195 L F
.235 .519 .913 r
.48605 .86907 m .48631 .86981 L .48802 .87039 L F
.97 .66 .366 r
.48554 .86847 m .48658 .87059 L .48631 .86981 L F
.888 .46 .144 r
.48554 .86847 m .48631 .86981 L .48444 .86799 L F
.235 .519 .913 r
.48444 .86799 m .48631 .86981 L .48605 .86907 L F
.97 .66 .366 r
.48658 .87059 m .48696 .87138 L .48631 .86981 L F
.312 .509 .888 r
.48631 .86981 m .48696 .87138 L .48802 .87039 L F
.48631 .86981 m .48696 .87138 L .48802 .87039 L F
.691 .425 .516 r
.44666 .87274 m .44905 .87335 L .44933 .87123 L F
.522 .203 .368 r
.44905 .87335 m .45214 .87079 L .44933 .87123 L F
.099 0 0 r
.39869 .9 m .40161 .89918 L .40086 .89961 L F
.26 .762 .721 r
.40161 .89918 m .4039 .89844 L .40258 .8988 L F
0 0 0 r
.40086 .89961 m .40161 .89918 L .40258 .8988 L F
.062 0 .181 r
.65991 .75395 m .65788 .75668 L .65858 .75497 L F
.481 .753 .99 r
.50019 .80847 m .50287 .80922 L .50207 .80849 L F
.92 .964 .787 r
.56492 .82491 m .56435 .82704 L .5636 .82618 L F
.938 .576 .185 r
.56435 .82704 m .56433 .82915 L .5636 .82618 L F
.999 .843 .538 r
.56433 .82915 m .56411 .83088 L .56318 .83003 L F
.449 .759 .995 r
.56368 .82965 m .56433 .82915 L .56318 .83003 L F
.938 .576 .185 r
.56485 .82874 m .56505 .82944 L .56433 .82915 L F
.75 .717 .821 r
.56433 .82915 m .56806 .82884 L .56748 .82672 L F
.102 0 0 r
.56433 .82915 m .56806 .82884 L .56666 .82907 L F
.449 .759 .995 r
.56576 .82808 m .56666 .82907 L .56433 .82915 L F
.56576 .82808 m .56433 .82915 L .56368 .82965 L F
.938 .576 .185 r
.56435 .82704 m .56485 .82874 L .56433 .82915 L F
.494 .094 .21 r
.4735 .81338 m .47562 .81336 L .47681 .81152 L F
.3 0 .098 r
.47681 .81152 m .47756 .81284 L .47879 .81103 L F
.47681 .81152 m .47562 .81336 L .47756 .81284 L F
.807 .745 .795 r
.57611 .78813 m .57731 .7908 L .57424 .79057 L F
.983 .725 .332 r
.57498 .79244 m .57424 .79057 L .57731 .7908 L F
.447 .148 .364 r
.57731 .7908 m .57692 .79291 L .57498 .79244 L F
.664 .342 .419 r
.57987 .79296 m .57763 .79108 L .57926 .79048 L F
.57763 .79108 m .57731 .7908 L .57926 .79048 L F
.944 .627 .404 r
.58061 .78999 m .57926 .79048 L .58066 .78992 L F
.664 .342 .419 r
.57987 .79296 m .57686 .79328 L .57731 .7908 L F
.944 .627 .404 r
.5789 .79245 m .57987 .79296 L .57926 .79048 L F
.5789 .79245 m .57926 .79048 L .58061 .78999 L F
.546 .803 .993 r
.57604 .79245 m .57789 .79269 L .57902 .79213 L F
.57789 .79269 m .57987 .79296 L .57928 .79238 L F
.514 .505 .784 r
.57604 .79245 m .57713 .79326 L .57987 .79296 L F
.447 .378 .687 r
.57905 .79445 m .57686 .79328 L .57987 .79296 L F
.515 .506 .785 r
.57693 .79542 m .57972 .79745 L .57899 .79531 L F
.447 .378 .687 r
.57868 .79512 m .57784 .79451 L .57905 .79445 L F
.57799 .79469 m .57784 .79451 L .57868 .79512 L F
.515 .506 .785 r
.57808 .79474 m .57899 .79531 L .57867 .79439 L F
.57693 .79542 m .57899 .79531 L .57808 .79474 L F
.447 .378 .687 r
.57854 .79537 m .57799 .79469 L .57868 .79512 L F
.57784 .79451 m .57686 .79328 L .57905 .79445 L F
.716 .467 .548 r
.58427 .79025 m .58427 .79264 L .57963 .79248 L F
.57948 .79221 m .57963 .79248 L .5794 .79247 L F
0 .285 .745 r
.5794 .79247 m .57962 .79236 L .57928 .79238 L F
.607 .445 .636 r
.58292 .79259 m .58044 .79323 L .5794 .79247 L F
0 .285 .745 r
.57978 .79275 m .57977 .79272 L .5794 .79247 L F
.57977 .79272 m .57962 .79236 L .5794 .79247 L F
.716 .467 .548 r
.5792 .79233 m .5794 .79247 L .5789 .79245 L F
.57948 .79221 m .5794 .79247 L .5792 .79233 L F
.58427 .79025 m .57963 .79248 L .57948 .79221 L F
0 .285 .745 r
.57987 .79296 m .57978 .79275 L .57928 .79238 L F
.607 .445 .636 r
.5794 .79247 m .58044 .79323 L .5789 .79245 L F
.58251 .79428 m .58178 .79432 L .58002 .79317 L F
.087 0 0 r
.57987 .79296 m .58003 .7932 L .57978 .79275 L F
.514 .505 .784 r
.57713 .79326 m .57915 .79382 L .57987 .79296 L F
.771 .6 .667 r
.5789 .79245 m .5787 .79405 L .57987 .79296 L F
.5787 .79405 m .57854 .79537 L .57987 .79296 L F
.087 0 0 r
.57987 .79296 m .57915 .79382 L .58002 .79319 L F
.57915 .79382 m .57893 .79408 L .57988 .79331 L F
.57915 .79382 m .57988 .79331 L .58002 .79319 L F
.607 .445 .636 r
.58241 .79473 m .58107 .79435 L .57988 .79331 L F
.58004 .79319 m .57988 .79331 L .5789 .79245 L F
.58241 .79473 m .57988 .79331 L .58004 .79319 L F
.514 .505 .784 r
.579 .79378 m .57884 .79407 L .57915 .79382 L F
.57884 .79407 m .57893 .79408 L .57915 .79382 L F
.771 .6 .667 r
.5789 .79245 m .58107 .79435 L .5787 .79405 L F
.58107 .79435 m .58225 .79539 L .5787 .79405 L F
.087 0 0 r
.58002 .79319 m .57867 .79439 L .58033 .79365 L F
.57893 .79408 m .57867 .79439 L .58002 .79319 L F
.771 .6 .667 r
.57868 .79429 m .58225 .79539 L .57907 .79537 L F
.57885 .79499 m .57907 .79537 L .57895 .79537 L F
.57868 .79429 m .57907 .79537 L .57885 .79499 L F
.57888 .79412 m .58225 .79539 L .57868 .79429 L F
.345 .009 .243 r
.58225 .79539 m .57972 .79745 L .57854 .79537 L F
.58225 .79539 m .58159 .79705 L .57972 .79745 L F
.509 .494 .775 r
.57983 .79676 m .58159 .79705 L .58033 .79365 L F
.57972 .79745 m .58016 .79735 L .57983 .79676 L F
.58016 .79735 m .58159 .79705 L .57983 .79676 L F
.57908 .79557 m .58033 .79365 L .57867 .79439 L F
.57972 .79745 m .57983 .79676 L .57908 .79557 L F
.57983 .79676 m .58033 .79365 L .57908 .79557 L F
.771 .6 .667 r
.57861 .79483 m .57895 .79537 L .57854 .79537 L F
.57868 .79429 m .57895 .79537 L .57861 .79483 L F
.5787 .79405 m .57888 .79412 L .57868 .79429 L F
.514 .505 .784 r
.57884 .79407 m .57867 .79439 L .57893 .79408 L F
.57713 .79326 m .57849 .79426 L .579 .79378 L F
.57849 .79426 m .57867 .79439 L .579 .79378 L F
.607 .445 .636 r
.5799 .79295 m .58002 .79317 L .5789 .79245 L F
.58251 .79428 m .58002 .79317 L .5799 .79295 L F
.087 0 0 r
.57978 .79275 m .58011 .79331 L .57977 .79272 L F
.58003 .7932 m .58011 .79331 L .57978 .79275 L F
.57977 .79272 m .58033 .79365 L .57962 .79236 L F
.58011 .79331 m .58033 .79365 L .57977 .79272 L F
0 .285 .745 r
.57928 .79238 m .57962 .79236 L .57902 .79213 L F
.607 .445 .636 r
.58292 .79259 m .58251 .79428 L .58044 .79323 L F
.58251 .79428 m .58241 .79473 L .58178 .79432 L F
.58241 .79473 m .58225 .79539 L .58107 .79435 L F
.58427 .79264 m .58425 .79267 L .58292 .79259 L F
.58425 .79267 m .58225 .79539 L .58292 .79259 L F
.546 .803 .993 r
.57927 .79238 m .57928 .79238 L .57928 .79238 L F
.57789 .79269 m .57928 .79238 L .57927 .79238 L F
.57789 .79269 m .57928 .79238 L .57902 .79213 L F
.447 .148 .364 r
.57692 .79291 m .57686 .79328 L .57632 .79305 L F
.57692 .79291 m .57632 .79305 L .57498 .79244 L F
.555 .62 .871 r
.57926 .79048 m .57731 .7908 L .57611 .78813 L F
.65 .636 .823 r
.36242 .75718 m .36479 .75709 L .36283 .75801 L F
.6 .146 .145 r
.44632 .83189 m .44523 .83325 L .44317 .832 L F
.603 .222 .293 r
.44841 .83177 m .44523 .83325 L .44632 .83189 L F
.729 .476 .545 r
.49157 .82154 m .49534 .82373 L .49573 .82204 L F
.632 .698 .893 r
.49402 .81971 m .49573 .82204 L .49669 .82103 L F
.082 0 .302 r
.49669 .82103 m .49534 .82373 L .49573 .82204 L F
.49573 .82204 m .49534 .82373 L .49669 .82103 L F
.742 .23 0 r
.54428 .82366 m .54092 .82183 L .54123 .82414 L F
.69 .374 .435 r
.38713 .84486 m .38596 .8472 L .38428 .84699 L F
.649 .388 .512 r
.3893 .84432 m .38596 .8472 L .38713 .84486 L F
.522 .203 .368 r
.44905 .87335 m .45127 .87318 L .45214 .87079 L F
.556 .135 .199 r
.45307 .87263 m .45214 .87079 L .45127 .87318 L F
.45307 .87263 m .45435 .87101 L .45214 .87079 L F
0 0 0 r
.42283 .8378 m .4211 .83999 L .42221 .83895 L F
.513 .585 .865 r
.4211 .83999 m .42322 .84028 L .42221 .83895 L F
0 0 0 r
.42283 .8378 m .4211 .83999 L .42221 .83895 L F
.58 .073 .012 r
.48751 .88572 m .49055 .88588 L .48928 .88648 L F
.622 .168 .152 r
.49055 .88588 m .49257 .88654 L .48928 .88648 L F
.186 0 .035 r
.52097 .86583 m .51864 .8675 L .51985 .86781 L F
.558 .182 .283 r
.52199 .86774 m .52097 .86583 L .51985 .86781 L F
.52199 .86774 m .52316 .86608 L .52097 .86583 L F
.862 .964 .866 r
.57498 .79244 m .57225 .79395 L .57426 .79293 L F
.983 .725 .332 r
.57498 .79244 m .57426 .79293 L .57424 .79057 L F
.048 .165 .665 r
.57693 .79542 m .57498 .79244 L .57686 .79328 L F
.239 .751 .734 r
.39131 .88714 m .39105 .8873 L .38971 .8879 L F
.39131 .88714 m .3932 .8867 L .39105 .8873 L F
.858 .868 .846 r
.57714 .80813 m .57837 .80887 L .5763 .81006 L F
.451 .753 .994 r
.57936 .80757 m .57837 .80887 L .57714 .80813 L F
.57936 .80757 m .58131 .80908 L .57837 .80887 L F
.553 .082 .09 r
.49906 .80458 m .50105 .80552 L .50197 .8043 L F
.718 .273 .193 r
.50105 .80552 m .50402 .80595 L .50197 .8043 L F
.713 .202 .01 r
.50197 .8043 m .50402 .80595 L .5054 .80604 L F
.472 0 0 r
.45666 .88089 m .45947 .8807 L .45863 .8813 L F
.353 0 0 r
.45947 .8807 m .46076 .88126 L .45863 .8813 L F
.45947 .8807 m .46178 .88055 L .46076 .88126 L F
.59 .048 0 r
.50402 .80595 m .50722 .80663 L .5054 .80604 L F
.463 0 0 r
.49257 .88654 m .49584 .88647 L .49447 .88725 L F
.346 0 0 r
.49584 .88647 m .49551 .88717 L .49447 .88725 L F
.49584 .88647 m .49797 .88666 L .49551 .88717 L F
.377 0 0 r
.37912 .83074 m .37842 .82964 L .37728 .83079 L F
.37912 .83074 m .38064 .82943 L .37842 .82964 L F
0 0 .407 r
.53082 .81155 m .53057 .81439 L .53174 .81298 L F
.576 .679 .91 r
.57594 .81079 m .57646 .81237 L .5787 .81202 L F
.532 .144 .251 r
.38201 .84608 m .38428 .84699 L .38123 .84724 L F
.121 0 .242 r
.66192 .75141 m .66058 .7523 L .66251 .7496 L F
.462 .261 .52 r
.66192 .75141 m .65991 .75395 L .66058 .7523 L F
.293 0 .095 r
.42594 .8362 m .4253 .83482 L .42741 .83464 L F
.42594 .8362 m .42402 .83678 L .4253 .83482 L F
.17 0 .057 r
.51682 .87571 m .51935 .8732 L .51832 .87519 L F
.202 0 .07 r
.51832 .87519 m .51935 .8732 L .52109 .87317 L F
.5 .049 .111 r
.57042 .82872 m .57108 .82786 L .56894 .82753 L F
.57019 .82849 m .56894 .82753 L .56833 .82658 L F
.57042 .82872 m .57031 .82863 L .57019 .82849 L F
.57031 .82863 m .56894 .82753 L .57019 .82849 L F
.57042 .82872 m .56833 .82658 L .56806 .82884 L F
0 0 .2 r
.56806 .82884 m .56833 .82658 L .56904 .82565 L F
.56806 .82884 m .56873 .82667 L .56748 .82672 L F
.56873 .82667 m .56904 .82565 L .56831 .82615 L F
.56873 .82667 m .56831 .82615 L .56748 .82672 L F
.107 0 0 r
.3877 .82852 m .38994 .82816 L .39137 .82739 L F
.525 .062 .097 r
.38994 .82816 m .39336 .8271 L .39137 .82739 L F
.565 .493 .733 r
.36348 .75217 m .36168 .75314 L .36139 .75207 L F
.36348 .75217 m .36399 .75394 L .36168 .75314 L F
.5 .464 .748 r
.57203 .80836 m .57065 .80901 L .56928 .8076 L F
.551 .37 .589 r
.57203 .80836 m .57196 .80846 L .56928 .8076 L F
.462 .884 .912 r
.56963 .80926 m .57065 .80901 L .56902 .80947 L F
.243 .438 .853 r
.56999 .81102 m .56806 .80973 L .57065 .80901 L F
.56999 .81102 m .57065 .80901 L .56963 .80926 L F
.551 .37 .589 r
.57196 .80846 m .56999 .81102 L .56963 .80926 L F
.243 .438 .853 r
.56963 .80926 m .57065 .80901 L .56928 .8076 L F
.51 .906 .928 r
.57203 .80836 m .57065 .80901 L .57019 .80906 L F
.551 .37 .589 r
.57186 .80842 m .56963 .80926 L .56928 .8076 L F
.57019 .80906 m .56963 .80926 L .57186 .80842 L F
.51 .906 .928 r
.57203 .80836 m .57019 .80906 L .56885 .80921 L F
.551 .37 .589 r
.57196 .80846 m .57019 .80906 L .57186 .80842 L F
.462 .884 .912 r
.5683 .80957 m .56963 .80926 L .56806 .80973 L F
.56963 .80926 m .56902 .80947 L .56806 .80973 L F
.56885 .80921 m .57065 .80901 L .5683 .80957 L F
.16 0 0 r
.41175 .88233 m .41131 .88158 L .40963 .88259 L F
.41175 .88233 m .41323 .88115 L .41131 .88158 L F
.536 .35 .575 r
.36681 .76474 m .36688 .76702 L .36479 .76758 L F
.549 .377 .6 r
.36893 .76444 m .36688 .76702 L .36681 .76474 L F
0 0 .407 r
.53082 .81155 m .53174 .81298 L .53304 .81145 L F
.583 .884 .992 r
.57206 .78563 m .57072 .78576 L .57212 .78463 L F
.688 .676 .833 r
.57497 .78308 m .57224 .78547 L .57191 .78271 L F
.57224 .78547 m .57206 .78563 L .57204 .78525 L F
.57224 .78547 m .57204 .78525 L .57191 .78271 L F
0 0 .154 r
.57191 .78271 m .57203 .78499 L .57212 .78463 L F
.57203 .78499 m .57206 .78563 L .57212 .78463 L F
0 .134 .669 r
.57212 .78463 m .57242 .78433 L .57224 .78418 L F
.664 .425 .548 r
.57191 .78271 m .57212 .78463 L .5695 .7826 L F
0 .134 .669 r
.57212 .78463 m .57224 .78418 L .57146 .78352 L F
0 .305 .795 r
.5695 .7826 m .56985 .78287 L .56967 .78268 L F
.181 0 0 r
.56858 .78322 m .57016 .78298 L .5695 .7826 L F
.57016 .78298 m .57191 .78271 L .5695 .7826 L F
0 .305 .795 r
.56974 .78274 m .57212 .78463 L .57163 .7838 L F
.56985 .78287 m .57212 .78463 L .56967 .78268 L F
.181 0 0 r
.56858 .78322 m .57045 .78304 L .57016 .78298 L F
0 .305 .795 r
.56967 .78268 m .56974 .78274 L .57038 .78303 L F
.56967 .78268 m .57038 .78303 L .57045 .78304 L F
.5695 .7826 m .57045 .78304 L .56858 .78322 L F
.57045 .78304 m .57038 .78303 L .57146 .78352 L F
.56974 .78274 m .57163 .7838 L .57146 .78352 L F
.57045 .78304 m .57146 .78352 L .56858 .78322 L F
.181 0 0 r
.56858 .78322 m .57085 .78314 L .57045 .78304 L F
.56858 .78322 m .57077 .78318 L .57085 .78314 L F
.57016 .78298 m .57085 .78314 L .57191 .78271 L F
.813 .751 .795 r
.57301 .79897 m .57408 .80118 L .57616 .79857 L F
0 0 0 r
.49592 .8059 m .49774 .80552 L .49906 .80458 L F
.526 .042 .051 r
.49592 .8059 m .49763 .80758 L .49774 .80552 L F
.49592 .8059 m .49657 .80762 L .49763 .80758 L F
.23 0 0 r
.51083 .80782 m .51266 .80836 L .51387 .80866 L F
0 .465 .702 r
.51456 .80878 m .51387 .80866 L .51266 .80836 L F
.51456 .80878 m .51585 .80903 L .51387 .80866 L F
.55 .345 .555 r
.40464 .7907 m .40202 .79251 L .40238 .79141 L F
.40464 .7907 m .40445 .79296 L .40301 .79269 L F
.40464 .79071 m .40301 .79269 L .40202 .79251 L F
.40464 .7907 m .40301 .79269 L .40464 .79071 L F
.534 .426 .678 r
.40445 .79296 m .40282 .79399 L .40202 .79251 L F
.331 .332 .71 r
.40202 .79251 m .40282 .79399 L .40238 .79141 L F
.752 .629 .724 r
.40238 .79141 m .40267 .79311 L .39916 .79311 L F
.40267 .79311 m .40282 .79399 L .40209 .79381 L F
.40267 .79311 m .40209 .79381 L .39916 .79311 L F
.694 .72 .869 r
.42585 .83718 m .42638 .83995 L .42424 .83789 L F
.965 .866 .69 r
.42585 .83718 m .42515 .83971 L .42638 .83995 L F
.35 0 .154 r
.52677 .80911 m .52403 .81042 L .52481 .80951 L F
.726 .625 .745 r
.51318 .81878 m .51609 .81927 L .51517 .81627 L F
.583 .529 .761 r
.51609 .81927 m .51816 .81895 L .51731 .81589 L F
.643 .455 .614 r
.61073 .77484 m .60871 .7776 L .60876 .77532 L F
.994 .762 .4 r
.60876 .77532 m .60796 .77682 L .60961 .77414 L F
.60876 .77532 m .60871 .7776 L .60796 .77682 L F
.554 .358 .57 r
.36688 .76702 m .36459 .76979 L .36479 .76758 L F
.673 .22 .169 r
.49058 .82746 m .49017 .82909 L .48771 .82723 L F
.552 .154 .241 r
.53383 .81496 m .53302 .81647 L .53082 .81623 L F
.576 .487 .717 r
.36274 .74876 m .36348 .75217 L .36139 .75207 L F
.45 .263 .534 r
.66393 .74841 m .66192 .75141 L .66251 .7496 L F
.963 .72 .522 r
.3877 .79858 m .38643 .79815 L .38657 .79572 L F
.578 .616 .854 r
.3877 .79858 m .3898 .79842 L .38806 .7963 L F
.436 .479 .806 r
.38806 .7963 m .3877 .79858 L .38657 .79572 L F
.578 .616 .854 r
.38806 .7963 m .3898 .79842 L .3877 .79858 L F
.884 .899 .835 r
.38806 .7963 m .38643 .79815 L .3877 .79858 L F
.125 0 0 r
.46898 .8715 m .46817 .87123 L .46707 .87146 L F
.46898 .8715 m .47026 .87115 L .46817 .87123 L F
.324 .797 .709 r
.49987 .88641 m .49999 .88641 L .50198 .88556 L F
0 0 0 r
.49551 .88717 m .49999 .88641 L .49678 .88765 L F
.324 .797 .709 r
.49678 .88765 m .49999 .88641 L .49987 .88641 L F
.1 .654 .716 r
.49797 .88666 m .50013 .8864 L .49999 .88641 L F
.50013 .8864 m .50111 .88629 L .49999 .88641 L F
.473 .895 .859 r
.50111 .88629 m .50303 .88546 L .50198 .88556 L F
.471 .894 .872 r
.49999 .88641 m .50111 .88629 L .50198 .88556 L F
0 0 0 r
.57622 .79688 m .57515 .79819 L .5765 .79609 L F
.57622 .79688 m .5765 .79609 L .57693 .79542 L F
.553 .819 .456 r
.57606 .79707 m .57515 .79819 L .57622 .79688 L F
.813 .751 .795 r
.57301 .79897 m .57469 .79876 L .57515 .79819 L F
.177 0 0 r
.57301 .79897 m .57515 .79819 L .57407 .79949 L F
.553 .819 .456 r
.57407 .79949 m .57515 .79819 L .57606 .79707 L F
.813 .751 .795 r
.57469 .79876 m .57616 .79857 L .57515 .79819 L F
.553 .819 .456 r
.57407 .79949 m .57622 .79688 L .57702 .7995 L F
0 0 .514 r
.57585 .79788 m .57622 .79688 L .57511 .79774 L F
.178 .247 .697 r
.57797 .79915 m .57702 .7995 L .57622 .79688 L F
0 0 .514 r
.5774 .79817 m .57797 .79915 L .57734 .79833 L F
.5774 .79817 m .57734 .79833 L .57622 .79688 L F
.453 .725 .984 r
.57847 .79733 m .5774 .79817 L .57602 .79716 L F
.468 .854 .645 r
.57747 .79801 m .5774 .79817 L .57847 .79733 L F
.177 0 0 r
.57301 .79897 m .57358 .79924 L .57167 .7978 L F
.57358 .79924 m .57407 .79949 L .57349 .79908 L F
.57358 .79924 m .57349 .79908 L .57167 .7978 L F
.682 .464 .584 r
.57408 .79876 m .5713 .79528 L .57167 .7978 L F
.57408 .79876 m .574 .79502 L .5713 .79528 L F
.586 .388 .579 r
.57408 .79876 m .57622 .79688 L .574 .79502 L F
.569 .374 .578 r
.57167 .7978 m .57407 .79949 L .57408 .79876 L F
.525 .861 .589 r
.57511 .79774 m .57408 .79876 L .5734 .79891 L F
.57333 .79877 m .5734 .79891 L .5729 .79902 L F
.57511 .79774 m .5734 .79891 L .57333 .79877 L F
.659 .285 .325 r
.57407 .79949 m .57702 .7995 L .5759 .80057 L F
.563 0 0 r
.57407 .79949 m .5759 .80057 L .57293 .79947 L F
.778 .9 .928 r
.5759 .80057 m .5774 .79817 L .57293 .79947 L F
.052 0 0 r
.57293 .79947 m .5774 .79817 L .57576 .79917 L F
.468 .854 .645 r
.57576 .79917 m .5774 .79817 L .57747 .79801 L F
0 0 .514 r
.5774 .79817 m .57622 .79688 L .57585 .79788 L F
.433 .067 .242 r
.43643 .87362 m .43321 .8761 L .43531 .87574 L F
.142 0 .097 r
.43781 .87301 m .43643 .87362 L .43531 .87574 L F
.26 0 0 r
.41665 .82242 m .41869 .82211 L .41967 .82142 L F
.387 0 0 r
.41869 .82211 m .42178 .82138 L .41967 .82142 L F
.561 .102 .12 r
.47438 .8829 m .47551 .88154 L .47755 .88245 L F
.542 .079 .103 r
.46742 .82933 m .46638 .82981 L .46433 .82946 L F
0 .308 .656 r
.46742 .82933 m .46801 .82957 L .46638 .82981 L F
.46742 .82933 m .46982 .83036 L .46801 .82957 L F
.061 0 0 r
.39522 .88646 m .39628 .88612 L .3932 .8867 L F
.694 .591 .736 r
.39628 .88612 m .39856 .88586 L .39839 .88353 L F
.486 .897 .796 r
.39705 .88549 m .39628 .88612 L .39522 .88646 L F
.451 .845 .978 r
.39705 .88549 m .39856 .88586 L .39628 .88612 L F
.545 .104 .152 r
.39476 .84333 m .39328 .84456 L .3913 .84434 L F
.587 .156 .189 r
.39651 .8443 m .39328 .84456 L .39476 .84333 L F
.439 .24 .512 r
.47155 .8617 m .47157 .86373 L .47326 .86247 L F
.347 .223 .565 r
.53012 .83044 m .52901 .83194 L .52892 .82951 L F
.53012 .83044 m .52892 .82951 L .52853 .83207 L F
.307 .791 .731 r
.52751 .83245 m .52722 .83263 L .52878 .83203 L F
.52863 .83207 m .52878 .83203 L .52901 .83194 L F
.52751 .83245 m .52878 .83203 L .52863 .83207 L F
.726 .21 0 r
.52541 .8316 m .52785 .83228 L .5259 .83034 L F
.307 .791 .731 r
.52573 .83306 m .52644 .83285 L .52751 .83245 L F
.52644 .83285 m .52722 .83263 L .52751 .83245 L F
.52573 .83306 m .52863 .83207 L .5278 .83362 L F
.52863 .83207 m .52901 .83194 L .52877 .83228 L F
.52863 .83207 m .52877 .83228 L .5278 .83362 L F
.726 .21 0 r
.52785 .83228 m .52847 .83246 L .52816 .8322 L F
.52785 .83228 m .52816 .8322 L .5259 .83034 L F
.347 .223 .565 r
.52891 .83193 m .52853 .83207 L .52847 .83246 L F
.53012 .83044 m .52853 .83207 L .52891 .83193 L F
.58 .239 .357 r
.65299 .75391 m .65205 .75637 L .64952 .75631 L F
.571 .808 .988 r
.65358 .75295 m .65424 .75384 L .65299 .75391 L F
.882 .581 .473 r
.65299 .75391 m .65354 .75669 L .65205 .75637 L F
.549 .369 .589 r
.46114 .82915 m .45852 .83081 L .4591 .82917 L F
.372 0 .021 r
.44181 .88619 m .44242 .88745 L .44036 .88772 L F
.44181 .88619 m .44384 .88603 L .44242 .88745 L F
.195 0 .012 r
.5763 .81006 m .57383 .81131 L .57594 .81079 L F
.417 .683 .972 r
.53988 .80984 m .53905 .81113 L .53693 .80867 L F
.53988 .80984 m .54034 .81083 L .53905 .81113 L F
.047 0 0 r
.40059 .84217 m .39981 .84193 L .40191 .84173 L F
.40059 .84217 m .39874 .84292 L .39981 .84193 L F
.652 .651 .836 r
.5781 .78532 m .57598 .78562 L .57497 .78308 L F
.951 .666 .462 r
.57598 .78562 m .57611 .78813 L .57491 .78727 L F
.673 .439 .558 r
.57856 .78748 m .57598 .78562 L .5781 .78532 L F
.57856 .78748 m .57611 .78813 L .57598 .78562 L F
0 0 0 r
.56589 .81825 m .56488 .8193 L .56583 .81883 L F
.093 .323 .799 r
.56488 .8193 m .56663 .821 L .56583 .81883 L F
.577 .036 0 r
.53724 .82136 m .54092 .82183 L .53951 .82261 L F
.759 .321 .211 r
.54163 .82215 m .53951 .82261 L .54092 .82183 L F
.892 .595 .478 r
.53911 .82099 m .54092 .82183 L .54163 .82215 L F
.742 .23 0 r
.54428 .82366 m .54163 .82215 L .54092 .82183 L F
.527 .739 .972 r
.36984 .75766 m .36799 .75797 L .36671 .75684 L F
0 0 0 r
.56806 .80973 m .5674 .81027 L .56664 .81092 L F
.707 .605 .741 r
.4902 .82152 m .49157 .82154 L .49086 .81979 L F
.586 .363 .544 r
.4895 .82434 m .49157 .82154 L .4902 .82152 L F
.4895 .82434 m .49163 .82445 L .49157 .82154 L F
.674 .714 .879 r
.49157 .82154 m .49402 .81971 L .49086 .81979 L F
.729 .476 .545 r
.49157 .82154 m .49163 .82445 L .49534 .82373 L F
.65 .135 .002 r
.46741 .88048 m .47034 .88116 L .46924 .88056 L F
.018 .543 .858 r
.47034 .88116 m .47066 .88093 L .46924 .88056 L F
.47034 .88116 m .47221 .88164 L .47066 .88093 L F
0 0 0 r
.49086 .81979 m .49058 .82138 L .4902 .82152 L F
.933 .768 .653 r
.48855 .82212 m .4895 .82434 L .4902 .82152 L F
.48855 .82212 m .4902 .82152 L .49058 .82138 L F
.656 .57 .746 r
.36399 .75394 m .36479 .75709 L .36242 .75718 L F
.652 .678 .862 r
.52249 .83433 m .52483 .83483 L .52357 .83371 L F
.83 .912 .893 r
.50624 .86322 m .50692 .86376 L .50401 .86524 L F
.613 .292 .403 r
.50401 .86524 m .50692 .86376 L .50617 .86706 L F
0 .383 .794 r
.5076 .86385 m .50692 .86376 L .50624 .86322 L F
0 0 .15 r
.50701 .86496 m .50692 .86376 L .50746 .86383 L F
.50617 .86706 m .50638 .86614 L .50701 .86496 L F
.50638 .86614 m .50692 .86376 L .50701 .86496 L F
.5074 .86429 m .50746 .86383 L .5076 .86385 L F
0 .383 .794 r
.5076 .86385 m .50624 .86322 L .50741 .8642 L F
.5076 .86385 m .50741 .8642 L .50834 .86497 L F
0 0 .15 r
.50617 .86706 m .50746 .86383 L .5074 .86429 L F
.50617 .86706 m .5074 .86429 L .50834 .86497 L F
.5074 .86429 m .5076 .86385 L .50834 .86497 L F
.697 .317 .325 r
.50484 .86505 m .50732 .86499 L .50649 .86364 L F
.50612 .86337 m .50649 .86364 L .50624 .86322 L F
.50484 .86505 m .50649 .86364 L .50612 .86337 L F
.50732 .86499 m .50834 .86497 L .50741 .8642 L F
.50732 .86499 m .50741 .8642 L .50624 .86322 L F
.862 .426 .172 r
.49186 .87478 m .49249 .87502 L .49292 .87586 L F
.643 .758 .932 r
.49392 .8735 m .49249 .87502 L .49186 .87478 L F
.376 0 0 r
.4503 .81881 m .45244 .81875 L .45377 .81766 L F
.231 0 0 r
.45244 .81875 m .45533 .81742 L .45377 .81766 L F
.342 0 0 r
.45533 .81742 m .45758 .81787 L .45903 .8173 L F
.517 .037 .056 r
.45758 .81787 m .46106 .81697 L .45903 .8173 L F
.469 .198 .419 r
.51864 .8675 m .51585 .87103 L .51784 .87049 L F
.276 .024 .338 r
.51985 .86781 m .51864 .8675 L .51784 .87049 L F
.863 .915 .864 r
.51807 .86327 m .51823 .86433 L .51903 .86278 L F
.743 .746 .855 r
.51903 .86278 m .51823 .86433 L .51906 .86352 L F
.668 .571 .737 r
.39839 .88353 m .39856 .88586 L .40044 .88363 L F
.231 0 0 r
.40053 .88644 m .39856 .88586 L .39705 .88549 L F
.52 .362 .607 r
.40044 .88363 m .39856 .88586 L .40053 .88644 L F
.699 .278 .244 r
.49876 .87548 m .49557 .8748 L .49773 .87502 L F
.598 .894 .989 r
.4997 .87438 m .49876 .87548 L .49773 .87502 L F
.4997 .87438 m .50065 .87483 L .49876 .87548 L F
.284 0 0 r
.43387 .83364 m .42928 .83432 L .42967 .83394 L F
.641 .518 .698 r
.6194 .76439 m .61708 .76478 L .61908 .76218 L F
.685 .546 .691 r
.62021 .76735 m .61737 .76501 L .6194 .76439 L F
.61737 .76501 m .61708 .76478 L .6194 .76439 L F
.62021 .76735 m .61815 .76759 L .61708 .76478 L F
.704 .585 .72 r
.62227 .76474 m .62021 .76735 L .6194 .76439 L F
.654 .527 .697 r
.61908 .76218 m .6194 .76439 L .62108 .76349 L F
.61908 .76218 m .62108 .76349 L .62123 .76184 L F
.694 .622 .772 r
.62123 .76184 m .62098 .76458 L .6194 .76439 L F
.654 .527 .697 r
.62108 .76349 m .6194 .76439 L .62143 .76372 L F
.694 .622 .772 r
.62108 .76349 m .62227 .76474 L .62098 .76458 L F
.62123 .76184 m .62171 .76316 L .62108 .76349 L F
.62171 .76316 m .62227 .76474 L .62108 .76349 L F
.654 .527 .697 r
.62108 .76349 m .62143 .76372 L .62123 .76184 L F
.303 0 0 r
.61807 .7659 m .62132 .7638 L .6194 .76439 L F
.62132 .7638 m .62143 .76372 L .6194 .76439 L F
.291 0 0 r
.61708 .76478 m .61807 .7659 L .6194 .76439 L F
.61708 .76478 m .61596 .76636 L .61807 .7659 L F
.641 .518 .698 r
.6194 .76439 m .61708 .76478 L .61908 .76218 L F
.64 .895 .985 r
.52343 .81228 m .52208 .81151 L .52403 .81042 L F
.52343 .81228 m .52244 .81379 L .52208 .81151 L F
.775 .895 .928 r
.65717 .75181 m .65424 .75384 L .65358 .75295 L F
.469 .871 .961 r
.51585 .80903 m .51799 .80843 L .51891 .80867 L F
.521 .908 .937 r
.51891 .80867 m .51995 .80779 L .52045 .80804 L F
.512 .891 .965 r
.51891 .80867 m .51799 .80843 L .51995 .80779 L F
.892 .734 .678 r
.52244 .81379 m .52177 .81703 L .52346 .81661 L F
.335 0 0 r
.52272 .81846 m .52346 .81661 L .52177 .81703 L F
.305 .798 .848 r
.50636 .87382 m .50273 .87438 L .50546 .87393 L F
.231 .749 .767 r
.50835 .87334 m .50636 .87382 L .50546 .87393 L F
.209 0 0 r
.52974 .80843 m .52895 .80895 L .52677 .80911 L F
0 0 0 r
.53058 .80818 m .52895 .80895 L .52974 .80843 L F
.336 0 .038 r
.4239 .82158 m .4259 .82124 L .4269 .81985 L F
.265 0 0 r
.4259 .82124 m .429 .82028 L .4269 .81985 L F
.764 .363 .292 r
.46638 .82981 m .46312 .82895 L .46433 .82946 L F
.623 .374 .52 r
.49302 .8512 m .49263 .85291 L .49369 .8507 L F
.76 .996 .842 r
.49485 .85183 m .49731 .84966 L .49516 .85194 L F
.41 .296 .613 r
.49369 .8507 m .49516 .85194 L .49516 .85009 L F
.862 .426 .172 r
.49186 .87478 m .49292 .87586 L .49133 .8751 L F
.49186 .87478 m .49133 .8751 L .49043 .87467 L F
0 0 0 r
.49352 .87378 m .49186 .87478 L .49127 .87538 L F
.49373 .87363 m .49186 .87478 L .49352 .87378 L F
.49381 .87357 m .49186 .87478 L .49373 .87363 L F
.49392 .8735 m .49127 .87538 L .49317 .87488 L F
.925 .579 .359 r
.4924 .87346 m .49288 .87435 L .49195 .8708 L F
.49288 .87435 m .49317 .87488 L .49298 .87426 L F
.49288 .87435 m .49298 .87426 L .49195 .8708 L F
0 0 0 r
.49392 .8735 m .49381 .87357 L .49373 .87363 L F
.332 0 0 r
.49127 .87538 m .49186 .87478 L .49043 .87467 L F
.244 0 0 r
.46399 .8158 m .46507 .81625 L .46641 .81478 L F
.43 0 .071 r
.46641 .81478 m .46507 .81625 L .46813 .81538 L F
.534 .49 .753 r
.37249 .75967 m .37155 .76201 L .37077 .75991 L F
.37249 .75967 m .37339 .76172 L .37155 .76201 L F
.451 .177 .406 r
.37339 .76172 m .37082 .76421 L .37155 .76201 L F
.786 .784 .284 r
.57072 .78576 m .56956 .78967 L .56999 .78816 L F
.594 .467 .677 r
.56999 .78816 m .57212 .78463 L .57072 .78576 L F
.984 .745 .494 r
.48894 .8441 m .48486 .84502 L .48806 .84441 L F
.695 .708 .858 r
.48356 .84481 m .48806 .84441 L .48486 .84502 L F
.693 .714 .865 r
.4857 .84314 m .48798 .84436 L .48356 .84481 L F
.48798 .84436 m .48806 .84441 L .48754 .84446 L F
.755 .696 .796 r
.48894 .8441 m .48806 .84441 L .48798 .84436 L F
.984 .745 .494 r
.48894 .8441 m .48885 .84418 L .48798 .84436 L F
.48894 .8441 m .48798 .84436 L .48505 .84498 L F
.755 .696 .796 r
.48894 .8441 m .48798 .84436 L .4857 .84314 L F
.693 .714 .865 r
.48798 .84436 m .48754 .84446 L .48356 .84481 L F
.984 .745 .494 r
.48505 .84498 m .48787 .84502 L .48486 .84502 L F
.48885 .84418 m .48787 .84502 L .48505 .84498 L F
.574 .771 .972 r
.48356 .84481 m .48486 .84502 L .48447 .84376 L F
.683 .979 .862 r
.4857 .84314 m .48356 .84481 L .48447 .84376 L F
.375 .627 .951 r
.48486 .84502 m .48787 .84502 L .48447 .84376 L F
.932 .881 .761 r
.51161 .82016 m .51068 .82104 L .51165 .81934 L F
.301 0 0 r
.4004 .82602 m .40248 .82585 L .40394 .82471 L F
.5 .029 .069 r
.40248 .82585 m .40611 .82472 L .40394 .82471 L F
.612 .197 .23 r
.44384 .88603 m .44687 .88564 L .44586 .88607 L F
.549 .302 .493 r
.44687 .88564 m .44871 .88454 L .44586 .88607 L F
.44687 .88564 m .44927 .88398 L .44871 .88454 L F
.304 0 0 r
.52892 .82951 m .5259 .83034 L .52847 .83246 L F
.493 .228 .44 r
.44871 .88454 m .44927 .88398 L .4512 .88364 L F
.341 .074 .356 r
.64952 .75631 m .6476 .75703 L .64937 .75492 L F
.883 .573 .063 r
.64937 .75492 m .64952 .75631 L .64875 .75381 L F
.189 .527 .921 r
.52953 .80263 m .52869 .80323 L .52747 .80257 L F
.52953 .80263 m .53027 .80367 L .52869 .80323 L F
.357 0 .025 r
.46106 .81697 m .46312 .81673 L .46399 .8158 L F
.244 0 0 r
.46399 .8158 m .46312 .81673 L .46507 .81625 L F
0 0 0 r
.50985 .88122 m .51276 .87872 L .51126 .88014 L F
.16 0 0 r
.51126 .88014 m .51276 .87872 L .51461 .87821 L F
.572 .52 .758 r
.35938 .74389 m .36142 .74365 L .35946 .74419 L F
.252 0 0 r
.51372 .87126 m .51041 .87322 L .51252 .8729 L F
.371 0 .068 r
.51585 .87103 m .51372 .87126 L .51252 .8729 L F
.632 .698 .893 r
.49402 .81971 m .49662 .8192 L .49601 .81886 L F
.49402 .81971 m .49669 .82103 L .49662 .8192 L F
0 0 0 r
.49901 .81735 m .49787 .81865 L .49662 .8192 L F
.337 .792 .947 r
.49662 .8192 m .49787 .81865 L .49601 .81886 L F
.619 .944 .946 r
.35883 .74387 m .36142 .74365 L .35938 .74389 L F
.44 0 0 r
.47208 .87167 m .4734 .87063 L .47026 .87115 L F
.643 .19 .162 r
.4755 .8721 m .4734 .87063 L .47208 .87167 L F
.373 0 0 r
.4165 .89386 m .41663 .89472 L .41342 .89559 L F
.4165 .89386 m .4184 .89373 L .41663 .89472 L F
.437 .055 .214 r
.49267 .82101 m .49086 .81979 L .49402 .81971 L F
.49267 .82101 m .49058 .82138 L .49086 .81979 L F
.806 .525 .513 r
.65581 .75677 m .65515 .75914 L .65354 .75669 L F
.583 .299 .451 r
.65788 .75668 m .65515 .75914 L .65581 .75677 L F
.616 .437 .617 r
.61302 .77223 m .6132 .7749 L .61073 .77484 L F
.589 .415 .614 r
.61495 .76983 m .61532 .77194 L .61302 .77223 L F
.581 .411 .615 r
.61597 .77436 m .61302 .77223 L .61532 .77194 L F
.61597 .77436 m .6132 .7749 L .61302 .77223 L F
.231 0 0 r
.429 .82028 m .43116 .82032 L .43245 .81982 L F
.566 .098 .102 r
.43116 .82032 m .43443 .81964 L .43245 .81982 L F
.361 0 .023 r
.43788 .83205 m .43669 .83347 L .43452 .83368 L F
.429 0 0 r
.43997 .83245 m .43669 .83347 L .43788 .83205 L F
.373 0 .024 r
.39336 .8271 m .39534 .82696 L .39624 .82614 L F
.421 0 .061 r
.39624 .82614 m .39534 .82696 L .39841 .82603 L F
.583 .81 .416 r
.50019 .80847 m .49875 .81049 L .49827 .81118 L F
.133 .481 .899 r
.49875 .81049 m .49991 .81191 L .49827 .81118 L F
.218 .352 .787 r
.44455 .87018 m .44373 .87142 L .44246 .8703 L F
.607 .045 0 r
.44666 .87274 m .44373 .87142 L .44568 .8729 L F
.218 .352 .787 r
.44455 .87018 m .44568 .8729 L .44373 .87142 L F
.782 .393 .317 r
.48096 .8832 m .48398 .88418 L .48284 .88566 L F
.79 .403 .323 r
.48284 .88566 m .48398 .88418 L .48456 .88556 L F
.73 .293 .213 r
.48398 .88418 m .48751 .88572 L .48456 .88556 L F
.54 .794 .991 r
.58295 .80846 m .58131 .80908 L .57936 .80757 L F
.428 0 0 r
.48522 .85442 m .48499 .85521 L .48243 .85512 L F
.073 0 0 r
.48798 .85269 m .48669 .85438 L .48522 .85442 L F
.071 0 0 r
.48669 .85438 m .48499 .85521 L .48522 .85442 L F
.574 .346 .533 r
.61799 .76944 m .61532 .77194 L .61495 .76983 L F
.48 .061 .167 r
.44586 .88607 m .44871 .88454 L .44808 .8861 L F
.493 .228 .44 r
.44871 .88454 m .4512 .88364 L .45001 .88545 L F
.279 0 .088 r
.44808 .8861 m .44871 .88454 L .45001 .88545 L F
.744 .666 .774 r
.40326 .78774 m .40464 .7907 L .40133 .79043 L F
.751 .628 .723 r
.40133 .79043 m .40464 .7907 L .40238 .79141 L F
.963 .637 .264 r
.40377 .79031 m .40464 .7907 L .40326 .78774 L F
.917 .678 .561 r
.40316 .79176 m .40464 .7907 L .40377 .79031 L F
.40316 .79176 m .40445 .79296 L .40464 .7907 L F
.877 .839 .804 r
.47519 .85995 m .47658 .86073 L .47847 .85789 L F
.006 0 0 r
.39522 .88646 m .3932 .8867 L .39131 .88714 L F
.671 .514 .664 r
.39839 .88353 m .40044 .88363 L .40109 .88156 L F
.344 .411 .787 r
.36142 .74365 m .36252 .74671 L .36238 .74673 L F
.608 .396 .568 r
.62021 .76735 m .61799 .76944 L .61815 .76759 L F
.009 .286 .784 r
.56505 .82944 m .56695 .83215 L .5655 .83142 L F
.927 .679 .542 r
.5655 .83142 m .56695 .83215 L .56581 .83346 L F
.117 .592 .915 r
.5655 .83142 m .56695 .83215 L .56906 .83256 L F
.695 .324 .341 r
.56695 .83215 m .56981 .83344 L .56912 .83345 L F
.744 .609 .708 r
.57018 .83478 m .56733 .83475 L .56981 .83344 L F
.768 .625 .702 r
.56581 .83346 m .56981 .83344 L .56733 .83475 L F
.848 .673 .664 r
.56906 .83256 m .57018 .83478 L .56981 .83344 L F
.691 .616 .768 r
.57238 .83428 m .57018 .83478 L .56955 .83353 L F
.57174 .83395 m .56955 .83353 L .56906 .83256 L F
.57238 .83428 m .56955 .83353 L .57174 .83395 L F
.695 .324 .341 r
.5663 .83291 m .56912 .83345 L .56581 .83346 L F
.56695 .83215 m .56912 .83345 L .5663 .83291 L F
.117 .592 .915 r
.5655 .83142 m .56695 .83215 L .56906 .83256 L F
.143 .575 .928 r
.35352 .72252 m .3541 .72265 L .35485 .72346 L F
.727 .915 .958 r
.35485 .72346 m .3541 .72265 L .3535 .72301 L F
.643 .455 .614 r
.61073 .77484 m .61119 .77772 L .60871 .7776 L F
.555 .358 .569 r
.6132 .7749 m .61119 .77772 L .61073 .77484 L F
.688 .165 0 r
.42283 .8378 m .42262 .83812 L .42018 .83679 L F
.711 .838 .398 r
.42283 .8378 m .42221 .83895 L .42262 .83812 L F
0 0 0 r
.42402 .83678 m .42262 .83812 L .42283 .8378 L F
.645 .488 .655 r
.42221 .83895 m .42424 .83789 L .42283 .8378 L F
.654 .222 .211 r
.50112 .81857 m .49787 .81865 L .49901 .81735 L F
0 .56 .769 r
.49663 .8748 m .49557 .8748 L .49392 .8735 L F
.49663 .8748 m .49773 .87502 L .49557 .8748 L F
.544 .383 .613 r
.40044 .88363 m .40241 .88337 L .40109 .88156 L F
.40044 .88363 m .40241 .88337 L .40109 .88156 L F
0 0 0 r
.52863 .86849 m .52916 .86758 L .53008 .86679 L F
.41 0 0 r
.41458 .83961 m .4112 .83945 L .41256 .83985 L F
.559 .587 .838 r
.54388 .81558 m .54199 .81715 L .54136 .81641 L F
.54388 .81558 m .54365 .81692 L .54199 .81715 L F
.408 .588 .916 r
.54506 .81858 m .54199 .81715 L .54365 .81692 L F
.429 .834 .976 r
.51731 .81589 m .51377 .81585 L .51517 .81627 L F
.511 .594 .874 r
.52223 .82968 m .52332 .83274 L .52243 .83165 L F
.857 .437 .227 r
.52332 .83274 m .52025 .83191 L .52243 .83165 L F
.52332 .83274 m .52266 .83395 L .52025 .83191 L F
.52332 .83274 m .52357 .83371 L .52266 .83395 L F
.772 .746 .829 r
.5259 .83034 m .52332 .83274 L .52223 .82968 L F
.755 .696 .796 r
.48894 .8441 m .4857 .84314 L .48699 .84327 L F
.984 .745 .494 r
.48894 .8441 m .48882 .84715 L .48787 .84502 L F
.215 .683 .942 r
.48986 .84366 m .48894 .8441 L .48699 .84327 L F
.48986 .84366 m .4912 .84433 L .48894 .8441 L F
.462 .884 .912 r
.56885 .80921 m .56806 .80973 L .56664 .81092 L F
0 0 0 r
.4182 .87838 m .4151 .88074 L .41713 .88058 L F
.538 .333 .55 r
.4182 .87838 m .42165 .87811 L .42029 .87637 L F
.348 0 .213 r
.4182 .87838 m .41907 .87997 L .42165 .87811 L F
.4182 .87838 m .41713 .88058 L .41907 .87997 L F
0 0 0 r
.39869 .9 m .39893 .90008 L .39703 .90059 L F
.39869 .9 m .40086 .89961 L .39893 .90008 L F
.637 .077 0 r
.42369 .87859 m .42029 .87637 L .42209 .8781 L F
.919 .634 .486 r
.42234 .8804 m .42369 .87859 L .42209 .8781 L F
.472 .025 .106 r
.42434 .88021 m .42369 .87859 L .42234 .8804 L F
.42434 .88021 m .42568 .87859 L .42369 .87859 L F
.258 0 0 r
.44317 .832 m .44174 .83246 L .43997 .83245 L F
.393 0 0 r
.44523 .83325 m .44174 .83246 L .44317 .832 L F
.431 .746 .993 r
.39916 .79311 m .40282 .79399 L .40116 .79292 L F
.695 .835 .95 r
.40116 .79292 m .40282 .79399 L .40445 .79296 L F
.912 .971 .793 r
.56813 .79909 m .5663 .80144 L .56728 .80008 L F
0 0 0 r
.56813 .79909 m .56847 .79952 L .56986 .79827 L F
.56813 .79909 m .56728 .80008 L .56847 .79952 L F
.772 .931 .572 r
.57022 .79585 m .56813 .79909 L .56986 .79827 L F
.593 .301 .442 r
.53174 .81298 m .53429 .8109 L .53304 .81145 L F
0 0 0 r
.43443 .81964 m .43662 .81955 L .43773 .81948 L F
.405 0 0 r
.43662 .81955 m .43968 .8192 L .43773 .81948 L F
.443 .711 .98 r
.50019 .80847 m .50207 .80849 L .50086 .80744 L F
.50019 .80847 m .50207 .80849 L .50086 .80744 L F
.39 0 0 r
.38118 .83063 m .38064 .82943 L .37912 .83074 L F
.38118 .83063 m .3827 .82938 L .38064 .82943 L F
.327 0 0 r
.4547 .87223 m .45435 .87101 L .45307 .87263 L F
.4547 .87223 m .45633 .87084 L .45435 .87101 L F
.58 .705 .928 r
.53538 .81505 m .53932 .81619 L .53827 .81555 L F
.788 .922 .927 r
.47807 .8326 m .47834 .83117 L .48019 .8317 L F
.899 .977 .687 r
.47834 .83117 m .47807 .8326 L .48019 .8317 L F
.74 .729 .842 r
.6476 .75703 m .64449 .75717 L .64669 .75482 L F
.667 .299 .338 r
.6476 .75703 m .64667 .75883 L .64449 .75717 L F
.558 .63 .879 r
.64952 .75631 m .6476 .75703 L .64669 .75482 L F
.683 .465 .584 r
.64952 .75631 m .64667 .75883 L .6476 .75703 L F
.575 .572 .812 r
.37188 .75734 m .37077 .75991 L .36984 .75766 L F
.37188 .75734 m .37249 .75967 L .37077 .75991 L F
.848 .998 .787 r
.50031 .8238 m .50266 .82088 L .50224 .82131 L F
.753 .662 .761 r
.50441 .81875 m .5045 .819 L .50224 .82131 L F
.848 .998 .787 r
.50266 .82088 m .50351 .81983 L .50224 .82131 L F
.746 .651 .755 r
.50441 .81875 m .50224 .82131 L .50112 .81857 L F
.733 .645 .761 r
.50112 .81857 m .50224 .82131 L .50351 .81983 L F
.848 .998 .787 r
.50266 .82088 m .49953 .82376 L .50351 .81983 L F
.7 .403 .47 r
.5055 .82166 m .50284 .8219 L .50228 .82134 L F
.5023 .82132 m .50228 .82134 L .50224 .82131 L F
.5055 .82166 m .50228 .82134 L .5023 .82132 L F
.848 .998 .787 r
.50031 .8238 m .50022 .8238 L .5023 .82132 L F
.50265 .8209 m .5023 .82132 L .50266 .82088 L F
.50031 .8238 m .5023 .82132 L .50265 .8209 L F
.753 .662 .761 r
.50266 .82088 m .5023 .82132 L .50224 .82131 L F
.848 .998 .787 r
.50022 .8238 m .49953 .82376 L .50266 .82088 L F
.753 .662 .761 r
.5045 .819 m .5055 .82166 L .5023 .82132 L F
.5045 .819 m .5023 .82132 L .50266 .82088 L F
.7 .403 .47 r
.5055 .82166 m .50578 .82337 L .50284 .8219 L F
.184 .317 .766 r
.50651 .8207 m .5055 .82166 L .50441 .81875 L F
.17 .292 .747 r
.50651 .8207 m .50751 .8239 L .5055 .82166 L F
.686 .394 .473 r
.5055 .82166 m .50751 .8239 L .50578 .82337 L F
.657 .517 .681 r
.48249 .85268 m .48616 .85395 L .48495 .85055 L F
.545 .198 .33 r
.48243 .85512 m .48616 .85395 L .48249 .85268 L F
.036 0 0 r
.40258 .8988 m .4039 .89844 L .40568 .89824 L F
.545 .561 .821 r
.48802 .87039 m .48862 .86922 L .48682 .86914 L F
.785 .934 .929 r
.49051 .8675 m .48817 .86832 L .48747 .86609 L F
.48817 .86832 m .48737 .86859 L .48744 .86683 L F
.48817 .86832 m .48744 .86683 L .48747 .86609 L F
.798 .889 .91 r
.4917 .86816 m .4888 .86883 L .49051 .8675 L F
.785 .934 .929 r
.49051 .8675 m .4888 .86883 L .48715 .86867 L F
.545 .561 .821 r
.48862 .86922 m .49035 .87044 L .48942 .86765 L F
.48802 .87039 m .48921 .87042 L .48862 .86922 L F
.48921 .87042 m .49035 .87044 L .48862 .86922 L F
.48862 .86922 m .48942 .86765 L .48758 .8687 L F
.48862 .86922 m .48758 .8687 L .48682 .86914 L F
.785 .934 .929 r
.48737 .86859 m .48736 .8686 L .48736 .86859 L F
.48737 .86859 m .48736 .86859 L .48747 .86609 L F
.089 0 0 r
.48709 .86866 m .4888 .86883 L .48554 .86847 L F
.689 .741 .891 r
.48675 .86855 m .48709 .86866 L .48672 .86851 L F
.48645 .86845 m .48758 .8687 L .48683 .86834 L F
.785 .934 .929 r
.48736 .8686 m .48717 .8685 L .48747 .86609 L F
.689 .741 .891 r
.48575 .86714 m .48645 .86845 L .48697 .86831 L F
.879 .741 .706 r
.48747 .86609 m .48717 .8685 L .48575 .86714 L F
.689 .741 .891 r
.48575 .86714 m .48697 .86831 L .48942 .86765 L F
.48672 .86851 m .48709 .86866 L .48758 .8687 L F
.879 .741 .706 r
.48717 .8685 m .48715 .86867 L .48575 .86714 L F
0 .507 .83 r
.48715 .86867 m .48674 .86854 L .48575 .86714 L F
.28 .503 .893 r
.48444 .86799 m .48575 .86714 L .48334 .86745 L F
.089 0 0 r
.487 .86863 m .48554 .86847 L .48444 .86799 L F
.28 .503 .893 r
.48444 .86799 m .48632 .8684 L .48575 .86714 L F
0 .507 .83 r
.48632 .8684 m .48444 .86799 L .48334 .86745 L F
.48715 .86867 m .48444 .86799 L .48632 .8684 L F
.28 .503 .893 r
.48444 .86799 m .48661 .86904 L .48632 .8684 L F
.48661 .86904 m .48682 .86914 L .48575 .86714 L F
0 .507 .83 r
.48674 .86854 m .48632 .8684 L .48575 .86714 L F
.48632 .8684 m .48334 .86745 L .48575 .86714 L F
.689 .741 .891 r
.48645 .86845 m .48675 .86855 L .48672 .86851 L F
.48709 .86866 m .48745 .86878 L .48757 .86871 L F
.48709 .86866 m .48757 .86871 L .48758 .8687 L F
.089 0 0 r
.48715 .86867 m .48729 .86868 L .48709 .86866 L F
.48729 .86868 m .4888 .86883 L .48709 .86866 L F
.785 .934 .929 r
.48736 .8686 m .48715 .86867 L .48717 .8685 L F
.689 .741 .891 r
.48683 .86834 m .48758 .8687 L .48942 .86765 L F
.089 0 0 r
.48709 .86866 m .48554 .86847 L .487 .86863 L F
.689 .741 .891 r
.48645 .86845 m .48682 .86914 L .48745 .86878 L F
.089 0 0 r
.48715 .86867 m .48709 .86866 L .487 .86863 L F
.554 .526 .779 r
.36568 .75374 m .36479 .75709 L .36399 .75394 L F
.36568 .75374 m .36671 .75684 L .36479 .75709 L F
.668 .282 .306 r
.56873 .78277 m .56606 .78347 L .56609 .78298 L F
.458 0 .015 r
.56609 .78298 m .5695 .7826 L .56873 .78277 L F
.374 0 0 r
.5695 .7826 m .56718 .78319 L .56873 .78277 L F
.56718 .78319 m .56694 .78324 L .56873 .78277 L F
.56734 .78315 m .56858 .78322 L .56606 .78347 L F
.5695 .7826 m .56858 .78322 L .56734 .78315 L F
.455 .578 .888 r
.56858 .78322 m .57146 .78352 L .57134 .78337 L F
.458 0 .015 r
.56653 .78293 m .56858 .78322 L .5695 .7826 L F
.56609 .78298 m .56858 .78322 L .56653 .78293 L F
.916 .979 .729 r
.57191 .78271 m .57077 .78318 L .57292 .77937 L F
.527 .492 .76 r
.56927 .77991 m .57077 .78318 L .56858 .78322 L F
.56951 .77879 m .56988 .78006 L .56927 .77991 L F
.56988 .78006 m .57077 .78318 L .56927 .77991 L F
.711 .604 .736 r
.57292 .77937 m .57077 .78318 L .56951 .77879 L F
.57233 .78067 m .56948 .78117 L .57223 .7809 L F
.57292 .77937 m .57104 .78035 L .57233 .78067 L F
.57104 .78035 m .56948 .78117 L .57233 .78067 L F
.455 .578 .888 r
.56858 .78322 m .57134 .78337 L .56948 .78117 L F
.481 .635 .922 r
.56748 .78138 m .5684 .78292 L .56609 .78298 L F
.5684 .78292 m .56858 .78322 L .5675 .78312 L F
.5684 .78292 m .5675 .78312 L .56609 .78298 L F
.374 0 0 r
.56718 .78319 m .56606 .78347 L .56694 .78324 L F
.652 .651 .836 r
.5781 .78532 m .57497 .78308 L .57711 .78233 L F
.677 .625 .79 r
.58001 .78285 m .5781 .78532 L .57711 .78233 L F
.594 .506 .725 r
.58001 .78285 m .58074 .78522 L .5781 .78532 L F
.465 .258 .513 r
.58074 .78522 m .57856 .78748 L .5781 .78532 L F
.608 .396 .568 r
.62021 .76735 m .62018 .76949 L .61799 .76944 L F
.694 .622 .772 r
.62123 .76184 m .6194 .76439 L .61908 .76218 L F
.555 .353 .561 r
.62021 .76735 m .62241 .76925 L .62018 .76949 L F
.623 .471 .655 r
.62227 .76474 m .62251 .76725 L .62021 .76735 L F
.598 .345 .503 r
.62251 .76725 m .62241 .76925 L .62021 .76735 L F
.536 .021 0 r
.48928 .88648 m .49257 .88654 L .49064 .88804 L F
.47 0 0 r
.49064 .88804 m .49257 .88654 L .49447 .88725 L F
0 0 0 r
.57225 .79395 m .57022 .79585 L .5713 .79528 L F
.164 .171 .62 r
.5713 .79528 m .57022 .79585 L .57167 .7978 L F
.454 .254 .517 r
.57022 .79585 m .56986 .79827 L .57167 .7978 L F
.554 .086 .098 r
.49906 .80458 m .49774 .80552 L .50105 .80552 L F
.474 .036 .125 r
.43184 .87769 m .43109 .87601 L .43073 .87795 L F
.43184 .87769 m .43321 .8761 L .43109 .87601 L F
.649 .388 .512 r
.3893 .84432 m .38827 .84741 L .38596 .8472 L F
.574 .323 .499 r
.3913 .84434 m .38827 .84741 L .3893 .84432 L F
.631 .587 .786 r
.36465 .74631 m .36252 .74671 L .36142 .74365 L F
.586 .445 .656 r
.36465 .74631 m .36274 .74876 L .36252 .74671 L F
.629 .293 .384 r
.46813 .81538 m .47033 .81578 L .47144 .81338 L F
.463 .103 .268 r
.47033 .81578 m .4735 .81338 L .47144 .81338 L F
.603 .231 .31 r
.45666 .88089 m .4575 .88345 L .45554 .88363 L F
.45666 .88089 m .45863 .8813 L .4575 .88345 L F
.746 .509 .572 r
.48172 .82672 m .48231 .8293 L .47896 .829 L F
.706 .352 .373 r
.42165 .87811 m .42209 .8781 L .42029 .87637 L F
.223 0 0 r
.42291 .89224 m .42362 .89131 L .42546 .89105 L F
.2 .708 .899 r
.43968 .8192 m .44163 .81916 L .44305 .81947 L F
.144 0 0 r
.44163 .81916 m .44505 .81907 L .44305 .81947 L F
.753 .404 .393 r
.48456 .88556 m .48751 .88572 L .48589 .88635 L F
.645 .147 .053 r
.48751 .88572 m .48823 .88755 L .48589 .88635 L F
.48751 .88572 m .48928 .88648 L .48823 .88755 L F
.369 0 .06 r
.40611 .82472 m .40768 .82523 L .40905 .82357 L F
.532 .114 .193 r
.40768 .82523 m .41113 .82364 L .40905 .82357 L F
0 0 0 r
.40791 .84088 m .40771 .84083 L .40934 .8399 L F
.40791 .84088 m .40587 .84142 L .40771 .84083 L F
.426 0 .074 r
.48748 .81056 m .49377 .80766 L .48891 .80901 L F
.436 .205 .464 r
.48757 .8108 m .48905 .81211 L .48959 .81076 L F
.426 0 .074 r
.48753 .81054 m .48869 .81054 L .49377 .80766 L F
.48925 .81042 m .49043 .81055 L .49103 .81003 L F
.478 .034 .117 r
.49377 .80766 m .49072 .8103 L .49203 .80982 L F
.49072 .8103 m .49043 .81055 L .49078 .81039 L F
.49072 .8103 m .49078 .81039 L .49203 .80982 L F
.095 0 0 r
.49219 .81093 m .48921 .81293 L .48961 .81173 L F
.659 .304 .359 r
.49203 .80982 m .49043 .81055 L .4898 .81022 L F
0 0 .425 r
.49201 .80981 m .49203 .80982 L .4917 .80988 L F
.49145 .80964 m .49093 .8109 L .49203 .80982 L F
.49093 .8109 m .49028 .81251 L .49203 .80982 L F
.683 .338 .384 r
.49432 .81113 m .49278 .8132 L .49235 .81119 L F
.717 .58 .699 r
.49028 .81251 m .49339 .81256 L .49203 .80982 L F
0 0 .425 r
.49101 .8107 m .49124 .81232 L .49028 .81251 L F
.49145 .80964 m .49133 .81114 L .49101 .8107 L F
.49133 .81114 m .49124 .81232 L .49101 .8107 L F
.49145 .80964 m .4898 .81022 L .48959 .81076 L F
.48998 .81115 m .48959 .81076 L .48905 .81211 L F
.426 0 .074 r
.48869 .81054 m .49103 .81003 L .49377 .80766 L F
0 0 .425 r
.49145 .80964 m .49201 .80981 L .4898 .81022 L F
.426 0 .074 r
.48869 .81054 m .48938 .81054 L .48925 .81042 L F
.48938 .81054 m .49043 .81055 L .48925 .81042 L F
.48748 .81056 m .48772 .81056 L .48753 .81054 L F
.48772 .81056 m .49043 .81055 L .48753 .81054 L F
.561 .44 .672 r
.4898 .81022 m .49043 .81055 L .48748 .81056 L F
0 0 .425 r
.49145 .80964 m .48959 .81076 L .48998 .81115 L F
.49201 .80981 m .4917 .80988 L .4898 .81022 L F
.436 .205 .464 r
.48826 .81062 m .48959 .81076 L .4898 .81022 L F
.48757 .8108 m .48959 .81076 L .48826 .81062 L F
.478 .034 .117 r
.49377 .80766 m .49203 .80982 L .49473 .80784 L F
.689 .325 .352 r
.63897 .75432 m .63813 .75613 L .63593 .75423 L F
.815 .848 .388 r
.63913 .75349 m .63864 .75479 L .63897 .75432 L F
.6387 .75469 m .63813 .75613 L .63897 .75432 L F
.622 .358 .496 r
.6387 .75469 m .63813 .75613 L .63919 .75477 L F
.63593 .75423 m .63813 .75613 L .6387 .75469 L F
.815 .848 .388 r
.63864 .75479 m .63813 .75613 L .6387 .75469 L F
.454 0 0 r
.63593 .75423 m .6387 .75469 L .63897 .75432 L F
.6387 .75469 m .63919 .75477 L .63897 .75432 L F
.585 .762 .963 r
.63913 .75349 m .64166 .75424 L .63897 .75432 L F
.653 .477 .634 r
.64166 .75424 m .64128 .75635 L .63897 .75432 L F
.249 .421 .837 r
.63897 .75432 m .64128 .75635 L .63913 .75349 L F
0 0 .251 r
.63897 .75432 m .63919 .75477 L .63913 .75349 L F
.355 .142 .446 r
.62123 .76184 m .62334 .75867 L .62116 .75957 L F
.226 0 0 r
.5677 .80273 m .57097 .80099 L .56985 .80269 L F
.678 .955 .713 r
.5716 .79993 m .57097 .80099 L .57301 .79897 L F
.621 .816 .402 r
.56985 .80269 m .57097 .80099 L .5716 .79993 L F
0 .406 .717 r
.50722 .80663 m .5097 .8074 L .51083 .80782 L F
.465 0 0 r
.5097 .8074 m .51266 .80836 L .51083 .80782 L F
.858 .868 .846 r
.57714 .80813 m .5763 .81006 L .57594 .81079 L F
.115 0 0 r
.42758 .89069 m .4313 .88924 L .42971 .89043 L F
.259 0 0 r
.4313 .88924 m .43175 .89019 L .42971 .89043 L F
.4313 .88924 m .43328 .88893 L .43175 .89019 L F
.446 .819 .569 r
.50303 .88546 m .50394 .88473 L .50198 .88556 L F
.50303 .88546 m .50529 .88369 L .50394 .88473 L F
.53 .369 .608 r
.40044 .88363 m .40239 .88592 L .40241 .88337 L F
.40044 .88363 m .40053 .88644 L .40239 .88592 L F
.631 .54 .733 r
.62429 .7622 m .62227 .76474 L .62123 .76184 L F
.62429 .7622 m .62449 .76445 L .62227 .76474 L F
.619 .468 .655 r
.62462 .76688 m .62227 .76474 L .62449 .76445 L F
.62462 .76688 m .62251 .76725 L .62227 .76474 L F
.544 .166 .274 r
.52481 .86714 m .52316 .86608 L .52199 .86774 L F
.515 .196 .365 r
.52481 .86714 m .52563 .8658 L .52316 .86608 L F
.163 .679 .891 r
.5682 .81804 m .56589 .81825 L .56583 .81883 L F
.566 .361 .561 r
.38657 .79572 m .38806 .7963 L .38872 .79545 L F
.38657 .79572 m .38643 .79815 L .38806 .7963 L F
.436 .479 .806 r
.38806 .7963 m .38657 .79572 L .38872 .79545 L F
.752 .629 .724 r
.40238 .79141 m .39916 .79311 L .40133 .79043 L F
0 0 .289 r
.56862 .79056 m .56999 .78816 L .56956 .78967 L F
.347 0 0 r
.56862 .79056 m .56975 .79048 L .56974 .79098 L F
.56975 .79048 m .57096 .79039 L .56974 .79098 L F
0 0 0 r
.56974 .79098 m .57096 .79039 L .57323 .78951 L F
0 0 .085 r
.57173 .78926 m .56974 .79098 L .57323 .78951 L F
.57173 .78926 m .56964 .79188 L .56974 .79098 L F
0 0 0 r
.56974 .79098 m .56964 .79188 L .56973 .79147 L F
.56974 .79098 m .56973 .79147 L .57004 .79002 L F
.56974 .79098 m .57004 .79002 L .56862 .79056 L F
.576 .205 .301 r
.42928 .83432 m .42594 .8362 L .42741 .83464 L F
.59 .048 0 r
.50402 .80595 m .50646 .80737 L .50722 .80663 L F
.592 .092 .034 r
.50646 .80737 m .5097 .8074 L .50722 .80663 L F
.675 .961 .94 r
.65214 .75175 m .65113 .75162 L .65302 .75061 L F
.267 .365 .779 r
.65302 .75061 m .65358 .75295 L .65214 .75175 L F
.544 .222 .372 r
.41706 .83766 m .41726 .83786 L .42018 .83679 L F
.417 .101 .319 r
.41859 .83874 m .41706 .83766 L .42018 .83679 L F
.41859 .83874 m .41659 .83926 L .41706 .83766 L F
.068 .197 .691 r
.48884 .85206 m .48798 .85269 L .4871 .84968 L F
0 0 0 r
.48884 .85206 m .48669 .85438 L .48798 .85269 L F
.406 0 .021 r
.41523 .82348 m .41869 .82211 L .41665 .82242 L F
.657 .697 .875 r
.53828 .86082 m .53491 .86006 L .53707 .85985 L F
.021 0 0 r
.53577 .86313 m .53828 .86082 L .53777 .86255 L F
.594 .742 .947 r
.53986 .85993 m .53828 .86082 L .53707 .85985 L F
.221 0 .296 r
.53777 .86255 m .53828 .86082 L .53986 .85993 L F
.281 0 0 r
.44505 .81907 m .44707 .81894 L .44835 .81834 L F
.548 .059 .047 r
.44835 .81834 m .44707 .81894 L .4503 .81881 L F
.553 .118 .168 r
.49163 .82445 m .49417 .82557 L .49534 .82373 L F
.668 .636 .809 r
.49776 .82448 m .49635 .82667 L .49534 .82373 L F
.84 .62 .605 r
.49417 .82557 m .49679 .82436 L .49534 .82373 L F
.668 .636 .809 r
.49776 .82448 m .49534 .82373 L .49679 .82436 L F
.432 .874 .859 r
.50031 .8238 m .49776 .82448 L .49953 .82376 L F
.611 .433 .617 r
.50031 .8238 m .4981 .82692 L .49776 .82448 L F
.50031 .8238 m .50062 .82695 L .4981 .82692 L F
.736 .661 .776 r
.50284 .8219 m .50031 .8238 L .50224 .82131 L F
.556 .37 .585 r
.50284 .8219 m .50062 .82695 L .50031 .8238 L F
.525 .062 .097 r
.38994 .82816 m .39188 .82844 L .39336 .8271 L F
.408 0 .037 r
.39188 .82844 m .39534 .82696 L .39336 .8271 L F
.548 .001 0 r
.4476 .87396 m .44905 .87335 L .44666 .87274 L F
.44688 .87357 m .44666 .87274 L .44568 .8729 L F
.4476 .87396 m .44669 .87277 L .44688 .87357 L F
.44669 .87277 m .44666 .87274 L .44688 .87357 L F
.445 .277 .558 r
.4476 .87396 m .44568 .8729 L .44741 .87269 L F
.941 .625 .409 r
.4469 .87464 m .4476 .87396 L .44741 .87269 L F
.44708 .87435 m .44741 .87269 L .44837 .87229 L F
.4469 .87464 m .44703 .87414 L .44708 .87435 L F
.44703 .87414 m .44741 .87269 L .44708 .87435 L F
.084 0 0 r
.52109 .87317 m .52408 .87053 L .52301 .8725 L F
.319 0 .148 r
.52301 .8725 m .52408 .87053 L .52596 .86988 L F
.447 .398 .71 r
.48495 .85055 m .48743 .85308 L .4871 .84968 L F
.48495 .85055 m .48616 .85395 L .48743 .85308 L F
.973 .814 .397 r
.49088 .86984 m .4917 .86816 L .49051 .8675 L F
.49088 .86984 m .49142 .87056 L .4917 .86816 L F
.562 .799 .988 r
.62546 .75862 m .62865 .75915 L .62646 .75951 L F
.618 .457 .642 r
.62865 .75915 m .62653 .76177 L .62646 .75951 L F
.176 .627 .939 r
.53827 .81555 m .53687 .81547 L .53538 .81505 L F
0 0 0 r
.49551 .88717 m .49797 .88666 L .49999 .88641 L F
.362 0 0 r
.47208 .87167 m .47026 .87115 L .46898 .8715 L F
.561 .605 .854 r
.42221 .83895 m .42322 .84028 L .42515 .83971 L F
0 0 0 r
.48921 .81293 m .48699 .81441 L .48961 .81173 L F
.487 .283 .528 r
.56728 .80008 m .5663 .80144 L .5677 .80273 L F
.661 .65 .828 r
.5677 .80273 m .56847 .79952 L .56728 .80008 L F
.35 .821 .898 r
.50206 .87418 m .50065 .87483 L .4997 .87438 L F
.321 0 .097 r
.47879 .81103 m .47963 .81231 L .4809 .81089 L F
.47879 .81103 m .47756 .81284 L .47963 .81231 L F
.603 .222 .293 r
.44841 .83177 m .4471 .83361 L .44523 .83325 L F
.287 0 .092 r
.44923 .83293 m .44841 .83177 L .45056 .83178 L F
.44923 .83293 m .4471 .83361 L .44841 .83177 L F
.231 0 0 r
.45244 .81875 m .45446 .81841 L .45533 .81742 L F
0 0 0 r
.45446 .81841 m .45758 .81787 L .45533 .81742 L F
.417 0 0 r
.53482 .81703 m .53302 .81647 L .53687 .81547 L F
.58 .171 .231 r
.53827 .81555 m .53482 .81703 L .53687 .81547 L F
.586 .445 .656 r
.36465 .74631 m .3649 .74843 L .36274 .74876 L F
.564 .479 .717 r
.36529 .75163 m .36274 .74876 L .3649 .74843 L F
.36529 .75163 m .36348 .75217 L .36274 .74876 L F
.938 .768 .646 r
.48807 .82408 m .4895 .82434 L .48855 .82212 L F
.521 0 0 r
.48807 .82408 m .49163 .82445 L .4895 .82434 L F
.574 .346 .533 r
.61799 .76944 m .61814 .772 L .61532 .77194 L F
.603 .368 .533 r
.62033 .77164 m .61799 .76944 L .62018 .76949 L F
.62033 .77164 m .61814 .772 L .61799 .76944 L F
.68 .51 .65 r
.54569 .82157 m .546 .82462 L .54428 .82366 L F
.499 .458 .743 r
.54734 .8214 m .54569 .82157 L .54506 .81858 L F
.562 .424 .65 r
.54823 .82378 m .54569 .82157 L .54734 .8214 L F
.54823 .82378 m .546 .82462 L .54569 .82157 L F
.775 .895 .928 r
.65717 .75181 m .65358 .75295 L .65651 .75172 L F
.796 .999 .824 r
.65717 .75181 m .65651 .75172 L .65752 .74987 L F
.415 0 0 r
.48771 .82723 m .48632 .82843 L .48425 .8284 L F
.655 .107 0 r
.48771 .82723 m .48826 .82849 L .48632 .82843 L F
.48771 .82723 m .49017 .82909 L .48826 .82849 L F
.774 .732 .814 r
.49565 .83015 m .49564 .83195 L .49454 .83126 L F
.687 .145 0 r
.49564 .83195 m .49669 .83342 L .49454 .83126 L F
.083 .142 .626 r
.49565 .83015 m .49675 .83188 L .49564 .83195 L F
.071 0 .445 r
.49675 .83188 m .49669 .83342 L .49564 .83195 L F
.627 .271 .347 r
.42761 .88026 m .42874 .87816 L .42568 .87859 L F
.398 0 .097 r
.42939 .87955 m .42874 .87816 L .42761 .88026 L F
.42939 .87955 m .43073 .87795 L .42874 .87816 L F
.479 .028 .101 r
.45633 .87084 m .45864 .87096 L .45933 .87013 L F
.325 0 0 r
.46055 .87063 m .45933 .87013 L .45864 .87096 L F
.46055 .87063 m .46162 .87 L .45933 .87013 L F
.511 .594 .874 r
.52223 .82968 m .52243 .83165 L .52025 .83191 L F
.739 .784 .889 r
.50848 .81583 m .51089 .81687 L .51219 .8157 L F
.578 .369 .561 r
.61092 .77949 m .60874 .77978 L .60871 .7776 L F
0 0 .386 r
.60871 .7776 m .60874 .77978 L .60972 .77889 L F
.60973 .77872 m .60972 .77889 L .60981 .7788 L F
.60871 .7776 m .60972 .77889 L .60973 .77872 L F
.578 .369 .561 r
.61092 .77949 m .60871 .7776 L .61119 .77772 L F
.665 .499 .65 r
.60989 .77701 m .61106 .77882 L .61073 .77354 L F
.60947 .77844 m .61073 .77354 L .60961 .77414 L F
.60946 .77876 m .60952 .7785 L .60947 .77844 L F
.60952 .7785 m .61073 .77354 L .60947 .77844 L F
0 0 .386 r
.60871 .7776 m .60973 .77872 L .60919 .77814 L F
.60806 .77692 m .60919 .77814 L .60796 .77682 L F
.60871 .7776 m .60919 .77814 L .60806 .77692 L F
.665 .499 .65 r
.60946 .77876 m .60973 .77872 L .60952 .7785 L F
0 0 .386 r
.60973 .77872 m .60981 .7788 L .60943 .7784 L F
.544 .369 .594 r
.60796 .77682 m .60946 .77876 L .60947 .77844 L F
0 0 .386 r
.60973 .77872 m .60955 .77852 L .60796 .77682 L F
.544 .369 .594 r
.60796 .77682 m .60947 .77844 L .60961 .77414 L F
0 0 .386 r
.60955 .77852 m .60943 .7784 L .60796 .77682 L F
.665 .499 .65 r
.60946 .77876 m .60973 .77877 L .60973 .77872 L F
.60952 .7785 m .60973 .77872 L .60989 .77701 L F
.60973 .77877 m .61106 .77882 L .60989 .77701 L F
.77 .647 .727 r
.58217 .82918 m .58295 .83188 L .57976 .83162 L F
.231 0 0 r
.58295 .83188 m .5822 .83197 L .57976 .83162 L F
.127 .23 .701 r
.58398 .83099 m .58295 .83188 L .58217 .82918 L F
.52 .916 .832 r
.58398 .83099 m .5822 .83197 L .58295 .83188 L F
.555 .62 .871 r
.57926 .79048 m .57611 .78813 L .57856 .78748 L F
.614 .593 .806 r
.58039 .78732 m .57926 .79048 L .57856 .78748 L F
.58039 .78732 m .58066 .78992 L .57926 .79048 L F
.057 0 0 r
.65912 .74909 m .6606 .74867 L .66156 .74716 L F
.801 .475 .436 r
.47736 .875 m .4793 .87289 L .4755 .8721 L F
.413 0 .128 r
.48041 .87425 m .4793 .87289 L .47736 .875 L F
0 .574 .71 r
.46531 .88046 m .46741 .88048 L .46589 .88047 L F
.061 0 0 r
.46741 .88048 m .46924 .88056 L .46589 .88047 L F
.487 .396 .678 r
.36529 .75163 m .36399 .75394 L .36348 .75217 L F
.36529 .75163 m .36568 .75374 L .36399 .75394 L F
.554 .358 .57 r
.36688 .76702 m .36705 .7695 L .36459 .76979 L F
.549 .377 .6 r
.36893 .76444 m .36885 .76701 L .36688 .76702 L F
.57 .37 .571 r
.3686 .76891 m .36688 .76702 L .36885 .76701 L F
.3686 .76891 m .36705 .7695 L .36688 .76702 L F
.387 0 0 r
.41869 .82211 m .42027 .82254 L .42178 .82138 L F
.276 0 0 r
.42027 .82254 m .4239 .82158 L .42178 .82138 L F
.668 .636 .809 r
.49776 .82448 m .4981 .82692 L .49635 .82667 L F
.84 .62 .605 r
.49417 .82557 m .49623 .82696 L .49679 .82436 L F
.492 0 0 r
.49635 .82667 m .4981 .82692 L .49703 .82724 L F
.55 .013 0 r
.49851 .82794 m .4981 .82692 L .50004 .82811 L F
.45 .35 .65 r
.49724 .82734 m .4973 .82769 L .49747 .82745 L F
.55 .013 0 r
.49668 .82735 m .49703 .82724 L .49724 .82734 L F
.84 .62 .605 r
.49678 .82734 m .49679 .82734 L .49724 .82732 L F
.49679 .82734 m .4973 .82769 L .49724 .82734 L F
.49679 .82734 m .49724 .82734 L .49724 .82732 L F
.492 0 0 r
.49635 .82667 m .4959 .82738 L .49486 .82865 L F
.4959 .82738 m .49582 .82751 L .49548 .82794 L F
.695 .972 .923 r
.49502 .82784 m .49679 .82734 L .49658 .82738 L F
.49495 .82766 m .49658 .82738 L .49493 .82762 L F
.49502 .82784 m .49658 .82738 L .49495 .82766 L F
.492 0 0 r
.4959 .82738 m .49668 .82735 L .49658 .82738 L F
.49582 .82751 m .49658 .82738 L .49575 .82763 L F
.4959 .82738 m .49658 .82738 L .49582 .82751 L F
.49582 .82751 m .49575 .82763 L .49567 .82772 L F
.49582 .82751 m .49567 .82772 L .49548 .82794 L F
.695 .972 .923 r
.49572 .82764 m .4973 .82769 L .49679 .82734 L F
.492 0 0 r
.4959 .82738 m .49548 .82794 L .49486 .82865 L F
.695 .972 .923 r
.49502 .82784 m .49486 .82865 L .49567 .82772 L F
.49502 .82784 m .49567 .82772 L .49572 .82764 L F
.49502 .82784 m .49567 .82772 L .49575 .82763 L F
.49502 .82784 m .49561 .8278 L .49567 .82772 L F
.49561 .8278 m .4973 .82769 L .49572 .82764 L F
.55 .013 0 r
.49658 .82738 m .49668 .82735 L .49671 .82736 L F
.492 0 0 r
.49635 .82667 m .49668 .82735 L .4959 .82738 L F
.695 .972 .923 r
.49493 .82762 m .49679 .82734 L .49417 .82557 L F
.55 .013 0 r
.49575 .82763 m .49658 .82738 L .49699 .8275 L F
.49703 .82724 m .4981 .82692 L .49851 .82794 L F
.45 .35 .65 r
.49724 .82732 m .49724 .82734 L .49749 .82741 L F
.49724 .82734 m .49747 .82745 L .49749 .82741 L F
.49679 .82436 m .49724 .82732 L .49883 .82552 L F
.49724 .82732 m .49749 .82741 L .49883 .82552 L F
.492 0 0 r
.49654 .82705 m .49703 .82724 L .49668 .82735 L F
.49635 .82667 m .49703 .82724 L .49654 .82705 L F
.84 .62 .605 r
.49623 .82696 m .49678 .82734 L .49703 .82592 L F
.49678 .82734 m .49724 .82732 L .49703 .82592 L F
.734 .58 .683 r
.49575 .82763 m .49883 .82552 L .49747 .82745 L F
.49575 .82763 m .49747 .82745 L .4973 .82769 L F
.695 .972 .923 r
.49502 .82784 m .49575 .82763 L .4973 .82769 L F
.55 .013 0 r
.49575 .82763 m .49699 .8275 L .49851 .82794 L F
.49658 .82738 m .49671 .82736 L .49851 .82794 L F
.49668 .82735 m .49724 .82734 L .49851 .82794 L F
.84 .62 .605 r
.49623 .82696 m .49703 .82592 L .49679 .82436 L F
.447 .282 .563 r
.51816 .81895 m .52038 .81614 L .51731 .81589 L F
.747 .66 .764 r
.38806 .7963 m .3898 .79842 L .38872 .79545 L F
.772 .746 .829 r
.5259 .83034 m .52223 .82968 L .52444 .83152 L F
.726 .21 0 r
.52541 .8316 m .5259 .83034 L .52444 .83152 L F
.502 .085 .181 r
.41175 .88233 m .4151 .88074 L .41323 .88115 L F
.576 .679 .91 r
.57594 .81079 m .5787 .81202 L .57717 .81114 L F
.487 .895 .922 r
.5787 .81202 m .57999 .81102 L .57717 .81114 L F
.5787 .81202 m .58088 .81123 L .57999 .81102 L F
.284 0 .064 r
.52677 .80911 m .52613 .81053 L .52403 .81042 L F
.636 .402 .546 r
.52613 .81053 m .52343 .81228 L .52403 .81042 L F
.619 .408 .574 r
.46478 .87107 m .46162 .87 L .46348 .87062 L F
.086 .6 .886 r
.46567 .87079 m .46478 .87107 L .46348 .87062 L F
.46567 .87079 m .46707 .87146 L .46478 .87107 L F
.234 .747 .733 r
.51703 .80864 m .51585 .80903 L .51456 .80878 L F
.51703 .80864 m .51799 .80843 L .51585 .80903 L F
0 0 0 r
.535 .80944 m .53388 .80799 L .53693 .80867 L F
.535 .80944 m .53429 .8109 L .53518 .81034 L F
.319 0 .039 r
.40568 .89824 m .40896 .8967 L .40774 .89768 L F
.369 0 .032 r
.40896 .8967 m .40956 .89725 L .40774 .89768 L F
.40896 .8967 m .41073 .89627 L .40956 .89725 L F
.19 0 0 r
.50733 .88264 m .50985 .88122 L .50948 .88196 L F
0 0 0 r
.50948 .88196 m .50985 .88122 L .51126 .88014 L F
.549 .823 .997 r
.5762 .80314 m .57939 .80341 L .57869 .80265 L F
.5762 .80314 m .57939 .80341 L .57869 .80265 L F
.318 0 0 r
.46178 .88055 m .46531 .88046 L .46395 .88049 L F
0 .574 .71 r
.46531 .88046 m .46589 .88047 L .46395 .88049 L F
.556 .37 .585 r
.50284 .8219 m .50251 .82642 L .50062 .82695 L F
.64 .442 .599 r
.50524 .82513 m .50284 .8219 L .50578 .82337 L F
.50524 .82513 m .50251 .82642 L .50284 .8219 L F
.569 .353 .547 r
.36705 .7695 m .36428 .77195 L .36459 .76979 L F
.668 .969 .913 r
.52045 .80804 m .52223 .8065 L .52344 .80654 L F
.52045 .80804 m .51995 .80779 L .52223 .8065 L F
.583 .299 .451 r
.65788 .75668 m .65777 .75894 L .65515 .75914 L F
.359 .143 .444 r
.65991 .75395 m .65944 .75576 L .65788 .75668 L F
.463 .24 .489 r
.65944 .75576 m .65777 .75894 L .65788 .75668 L F
.484 .262 .5 r
.40133 .79043 m .39916 .79311 L .40116 .79292 L F
.499 .336 .59 r
.40133 .79043 m .40377 .79031 L .40326 .78774 L F
.601 .359 .522 r
.40133 .79043 m .40316 .79176 L .40377 .79031 L F
.40133 .79043 m .40116 .79292 L .40316 .79176 L F
.517 .037 .056 r
.45758 .81787 m .45969 .81816 L .46106 .81697 L F
.21 0 0 r
.46106 .81697 m .4617 .81776 L .46312 .81673 L F
.46106 .81697 m .45969 .81816 L .4617 .81776 L F
.522 .116 .212 r
.4981 .82692 m .50062 .82695 L .50004 .82811 L F
.604 .214 .277 r
.43387 .83364 m .43079 .83592 L .42928 .83432 L F
.453 .041 .167 r
.43452 .83368 m .43079 .83592 L .43387 .83364 L F
.764 .363 .292 r
.46638 .82981 m .46508 .83097 L .46312 .82895 L F
.481 .263 .505 r
.46761 .82834 m .46638 .82981 L .46801 .82957 L F
.46761 .82834 m .46508 .83097 L .46638 .82981 L F
.915 .61 .454 r
.56505 .82944 m .56411 .83088 L .56433 .82915 L F
.56505 .82944 m .5655 .83142 L .56411 .83088 L F
.374 .396 .755 r
.48921 .81293 m .48915 .81582 L .48699 .81441 L F
.309 0 .107 r
.57182 .83307 m .57409 .83082 L .57224 .83052 L F
.745 .801 .898 r
.57409 .83082 m .57391 .82896 L .57224 .83052 L F
.57409 .83082 m .5768 .82934 L .57391 .82896 L F
0 0 0 r
.39336 .90166 m .39388 .90149 L .39316 .90181 L F
.389 0 0 r
.44384 .88603 m .44452 .88716 L .44242 .88745 L F
.44384 .88603 m .44586 .88607 L .44452 .88716 L F
.312 0 0 r
.40391 .84184 m .40059 .84217 L .40191 .84173 L F
.5 .056 .126 r
.43328 .88893 m .43623 .88834 L .43551 .88914 L F
.341 0 .022 r
.43623 .88834 m .43751 .88886 L .43551 .88914 L F
.43623 .88834 m .43831 .88799 L .43751 .88886 L F
.348 0 .223 r
.43977 .87287 m .44063 .87106 L .43781 .87301 L F
.683 .702 .862 r
.64165 .75527 m .64449 .75717 L .64128 .75635 L F
.053 0 0 r
.64449 .75717 m .6422 .75859 L .64128 .75635 L F
.64449 .75717 m .64349 .75833 L .6422 .75859 L F
.723 .699 .827 r
.64669 .75482 m .64449 .75717 L .64165 .75527 L F
.696 .23 .141 r
.64449 .75717 m .64667 .75883 L .64349 .75833 L F
.64449 .75717 m .64667 .75883 L .64349 .75833 L F
.692 .333 .362 r
.45852 .83081 m .45772 .83198 L .45607 .83109 L F
.549 .369 .589 r
.46114 .82915 m .46061 .83102 L .45852 .83081 L F
.416 .025 .187 r
.45954 .83221 m .45852 .83081 L .46061 .83102 L F
.45954 .83221 m .45772 .83198 L .45852 .83081 L F
.583 .493 .718 r
.53491 .86006 m .53777 .86255 L .53707 .85985 L F
.53491 .86006 m .53577 .86313 L .53777 .86255 L F
.447 0 .072 r
.46178 .88055 m .46395 .88049 L .46076 .88126 L F
0 0 0 r
.52526 .80554 m .52747 .80257 L .52524 .80301 L F
.303 0 0 r
.61807 .7659 m .62023 .76556 L .62143 .76372 L F
0 0 .256 r
.62143 .76372 m .62289 .76199 L .62123 .76184 L F
.62143 .76372 m .62262 .76364 L .62289 .76199 L F
.579 .307 .469 r
.62023 .76556 m .62262 .76364 L .62143 .76372 L F
.101 0 0 r
.5274 .81012 m .52677 .80911 L .52895 .80895 L F
.5274 .81012 m .52613 .81053 L .52677 .80911 L F
.5 .029 .069 r
.40248 .82585 m .40461 .82603 L .40611 .82472 L F
.392 0 .004 r
.40461 .82603 m .40768 .82523 L .40611 .82472 L F
.824 .531 .494 r
.42221 .83895 m .42018 .83679 L .42262 .83812 L F
.42221 .83895 m .41859 .83874 L .42018 .83679 L F
.597 .143 .144 r
.57162 .82896 m .57108 .82786 L .57042 .82872 L F
.57162 .82896 m .57391 .82896 L .57108 .82786 L F
.823 .957 .901 r
.56663 .821 m .5682 .81804 L .56583 .81883 L F
.334 .787 .643 r
.50529 .88369 m .50733 .88264 L .50629 .88316 L F
0 0 0 r
.50394 .88473 m .50529 .88369 L .50629 .88316 L F
.5278 .83362 m .52901 .83194 L .53012 .83044 L F
.88 .691 .642 r
.50279 .86235 m .50401 .86524 L .50131 .86345 L F
.902 .543 .349 r
.50131 .86345 m .50401 .86524 L .503 .86565 L F
.71 .622 .758 r
.50279 .86235 m .50624 .86322 L .50401 .86524 L F
.692 .196 .062 r
.503 .86565 m .50401 .86524 L .50617 .86706 L F
.683 .702 .862 r
.64165 .75527 m .64128 .75635 L .64166 .75424 L F
.546 .552 .812 r
.63913 .75349 m .64165 .75527 L .64166 .75424 L F
.502 .211 .404 r
.40239 .88592 m .40517 .88285 L .40241 .88337 L F
.40239 .88592 m .40442 .88577 L .40517 .88285 L F
.393 0 .111 r
.40517 .88285 m .40703 .88331 L .40769 .88236 L F
.774 .682 .762 r
.40442 .88577 m .40703 .88331 L .40517 .88285 L F
.619 .944 .946 r
.35883 .74387 m .36001 .74285 L .36142 .74365 L F
.35883 .74387 m .35922 .74325 L .36001 .74285 L F
.526 .846 .998 r
.35803 .74354 m .35922 .74325 L .35883 .74387 L F
.498 .552 .842 r
.54691 .81834 m .54506 .81858 L .54365 .81692 L F
.499 .458 .743 r
.54734 .8214 m .54506 .81858 L .54691 .81834 L F
.768 .48 .498 r
.47173 .83114 m .46982 .83036 L .47176 .8292 L F
.47173 .83114 m .46801 .82957 L .46982 .83036 L F
.741 .577 .672 r
.52038 .81614 m .52244 .81379 L .52124 .81329 L F
.52038 .81614 m .52177 .81703 L .52244 .81379 L F
.64 .895 .985 r
.52343 .81228 m .52124 .81329 L .52244 .81379 L F
.542 .101 .151 r
.48566 .81021 m .48748 .81056 L .48891 .80901 L F
0 0 0 r
.4184 .89373 m .4211 .89245 L .41941 .89341 L F
.41663 .89472 m .4184 .89373 L .41941 .89341 L F
.561 .386 .602 r
.37064 .76645 m .36893 .76444 L .37082 .76421 L F
.37064 .76645 m .36885 .76701 L .36893 .76444 L F
.447 .03 .154 r
.4498 .87504 m .44905 .87335 L .4476 .87396 L F
.4498 .87504 m .45127 .87318 L .44905 .87335 L F
.715 .611 .74 r
.57238 .83428 m .57311 .8367 L .57045 .83707 L F
.354 .163 .477 r
.57458 .8388 m .57314 .83941 L .57311 .8367 L F
.524 .585 .858 r
.57371 .83811 m .57314 .83941 L .57458 .8388 L F
.788 .504 .507 r
.57311 .8367 m .57085 .83782 L .57045 .83707 L F
.57311 .8367 m .57314 .83941 L .57021 .83814 L F
.524 .585 .858 r
.57149 .83633 m .57237 .83797 L .57371 .83811 L F
.57237 .83797 m .57314 .83941 L .57371 .83811 L F
.788 .504 .507 r
.57085 .83782 m .57021 .83814 L .57029 .83776 L F
.57085 .83782 m .57029 .83776 L .57045 .83707 L F
.354 .163 .477 r
.57458 .8388 m .57311 .8367 L .57325 .83638 L F
.524 .585 .858 r
.57149 .83633 m .57443 .83868 L .57325 .83638 L F
.57443 .83868 m .57458 .8388 L .57325 .83638 L F
0 0 .534 r
.57325 .83638 m .57311 .8367 L .57268 .83527 L F
.57325 .83638 m .57268 .83527 L .57238 .83428 L F
.742 .305 .214 r
.54428 .82366 m .546 .82462 L .54457 .82567 L F
.759 .321 .211 r
.54187 .82236 m .54452 .82466 L .54134 .82344 L F
.54452 .82466 m .54454 .8248 L .54134 .82344 L F
.742 .305 .214 r
.54428 .82366 m .54454 .82487 L .54452 .82466 L F
.54454 .82487 m .54458 .82507 L .54454 .8248 L F
.54454 .82487 m .54454 .8248 L .54452 .82466 L F
.742 .23 0 r
.54428 .82366 m .54452 .82466 L .54163 .82215 L F
.751 .585 .67 r
.54134 .82344 m .54454 .8248 L .54455 .82475 L F
.742 .23 0 r
.54428 .82366 m .54479 .82483 L .54452 .82466 L F
.54479 .82483 m .54483 .82492 L .54474 .82485 L F
.54479 .82483 m .54474 .82485 L .54452 .82466 L F
0 0 .35 r
.54462 .82328 m .54483 .82492 L .54428 .82366 L F
.742 .305 .214 r
.54428 .82366 m .54459 .82492 L .54462 .82328 L F
.751 .585 .67 r
.5423 .82339 m .54455 .82475 L .54462 .82328 L F
.996 .769 .428 r
.54462 .82328 m .54387 .82291 L .54134 .82344 L F
.54462 .82328 m .54459 .82492 L .54387 .82291 L F
.742 .305 .214 r
.54428 .82366 m .54457 .82567 L .54458 .82507 L F
.996 .769 .428 r
.54459 .82492 m .54457 .82567 L .5444 .825 L F
.751 .585 .67 r
.54134 .82344 m .54455 .82475 L .5423 .82339 L F
.742 .305 .214 r
.54452 .82466 m .54458 .82507 L .54459 .82492 L F
.996 .769 .428 r
.54459 .82492 m .5444 .825 L .54387 .82291 L F
.759 .321 .211 r
.54452 .82466 m .54483 .82492 L .54454 .8248 L F
.751 .585 .67 r
.54454 .8248 m .54483 .82492 L .54462 .82328 L F
.283 0 .003 r
.54068 .82476 m .54134 .82344 L .54387 .82291 L F
.54038 .82494 m .54134 .82344 L .54068 .82476 L F
.759 .321 .211 r
.54163 .82215 m .54187 .82236 L .54134 .82344 L F
.02 0 0 r
.41073 .89627 m .41255 .89581 L .41207 .89618 L F
0 0 0 r
.41327 .89582 m .41207 .89618 L .41394 .89563 L F
.064 0 0 r
.40956 .89725 m .41019 .89672 L .41207 .89618 L F
.538 .921 .92 r
.40815 .89729 m .40956 .89725 L .41207 .89618 L F
0 0 0 r
.4101 .89676 m .41207 .89618 L .41327 .89582 L F
.064 0 0 r
.41019 .89672 m .41073 .89627 L .41207 .89618 L F
.429 0 0 r
.43997 .83245 m .43862 .83357 L .43669 .83347 L F
.427 0 0 r
.44174 .83246 m .43862 .83357 L .43997 .83245 L F
.432 0 0 r
.4512 .88364 m .45332 .88421 L .45328 .88448 L F
0 0 0 r
.45328 .88448 m .45332 .88421 L .45554 .88363 L F
.462 .261 .52 r
.66192 .75141 m .66214 .75285 L .65991 .75395 L F
.444 .223 .483 r
.66214 .75285 m .65944 .75576 L .65991 .75395 L F
.231 .749 .767 r
.50835 .87334 m .50546 .87393 L .50755 .87334 L F
.054 .621 .721 r
.50943 .87325 m .50835 .87334 L .50755 .87334 L F
.50943 .87325 m .51041 .87322 L .50835 .87334 L F
.479 .161 .349 r
.6606 .74867 m .66331 .74609 L .66156 .74716 L F
.527 .739 .972 r
.36984 .75766 m .36671 .75684 L .36866 .75654 L F
.547 .729 .959 r
.37056 .75616 m .36984 .75766 L .36866 .75654 L F
.37056 .75616 m .37188 .75734 L .36984 .75766 L F
.579 .402 .606 r
.61814 .772 m .61597 .77436 L .61532 .77194 L F
.744 .609 .708 r
.57018 .83478 m .57045 .83707 L .56736 .83722 L F
.57 .115 .132 r
.56736 .83722 m .57045 .83707 L .57021 .83814 L F
.681 .564 .716 r
.57238 .83428 m .57045 .83707 L .57018 .83478 L F
.83 .803 .825 r
.58463 .82685 m .58217 .82918 L .58199 .82906 L F
.58349 .82729 m .58199 .82906 L .58082 .82833 L F
.58463 .82685 m .58199 .82906 L .58349 .82729 L F
.515 .277 .492 r
.58411 .82896 m .58217 .82918 L .58426 .8272 L F
.58411 .82896 m .58426 .8272 L .58463 .82685 L F
.699 .811 .935 r
.58082 .82833 m .58217 .82918 L .57873 .82883 L F
.572 .498 .733 r
.57976 .83162 m .58082 .82833 L .58217 .82918 L F
.127 .23 .701 r
.58398 .83099 m .58217 .82918 L .58411 .82896 L F
.591 .509 .73 r
.58082 .82833 m .58394 .83096 L .58411 .82896 L F
.58394 .83096 m .58398 .83099 L .58411 .82896 L F
.83 .803 .825 r
.58463 .82685 m .58082 .82833 L .58411 .82896 L F
.515 .277 .492 r
.58411 .82896 m .58463 .82685 L .58422 .82567 L F
.501 .27 .495 r
.58646 .82884 m .58411 .82896 L .58527 .82683 L F
.385 .215 .524 r
.58646 .82884 m .58527 .82683 L .58664 .82595 L F
.239 0 .306 r
.58637 .82627 m .58527 .82683 L .58411 .82896 L F
.58664 .82595 m .58641 .8261 L .58637 .82627 L F
.58641 .8261 m .58527 .82683 L .58637 .82627 L F
.385 .158 .442 r
.58637 .82627 m .58463 .82685 L .58411 .82896 L F
.58664 .82595 m .58639 .82606 L .58637 .82627 L F
.58639 .82606 m .58463 .82685 L .58637 .82627 L F
.239 0 .306 r
.58664 .82595 m .58411 .82896 L .58419 .82646 L F
.56 .548 .797 r
.58422 .82567 m .58463 .82685 L .58639 .82606 L F
.58632 .82591 m .58639 .82606 L .58664 .82595 L F
.58422 .82567 m .58639 .82606 L .58632 .82591 L F
.239 0 .306 r
.58632 .82591 m .58419 .82646 L .58481 .82574 L F
.58664 .82595 m .58634 .82601 L .58632 .82591 L F
.58634 .82601 m .58419 .82646 L .58632 .82591 L F
.385 .158 .442 r
.58637 .82627 m .58411 .82896 L .5847 .82833 L F
.58616 .82654 m .5847 .82833 L .58505 .82797 L F
.58637 .82627 m .5847 .82833 L .58616 .82654 L F
.385 .215 .524 r
.58616 .82654 m .58664 .82595 L .58598 .82507 L F
.58646 .82884 m .58664 .82595 L .58616 .82654 L F
.96 .684 .469 r
.5859 .82849 m .58622 .82698 L .58598 .82507 L F
.385 .158 .442 r
.58664 .82595 m .58637 .82627 L .58505 .82797 L F
.96 .684 .469 r
.58505 .82797 m .5859 .82849 L .58594 .82683 L F
.58505 .82797 m .58594 .82683 L .58598 .82515 L F
.58596 .82512 m .58598 .82515 L .58598 .82507 L F
.58505 .82797 m .58598 .82515 L .58596 .82512 L F
.5859 .82849 m .58646 .82884 L .58622 .82698 L F
.239 0 .306 r
.58481 .82574 m .58419 .82646 L .58422 .82567 L F
.421 0 .061 r
.39534 .82696 m .39738 .82693 L .39841 .82603 L F
.346 0 0 r
.39738 .82693 m .4004 .82602 L .39841 .82603 L F
.665 .245 .238 r
.42761 .88026 m .42568 .87859 L .42434 .88021 L F
.555 .358 .569 r
.6132 .7749 m .61343 .77729 L .61119 .77772 L F
.521 .306 .528 r
.61597 .77436 m .61343 .77729 L .6132 .7749 L F
.467 0 0 r
.47755 .88245 m .48096 .8832 L .47966 .88306 L F
.589 .126 0 r
.48096 .8832 m .48202 .88465 L .47966 .88306 L F
0 .473 .862 r
.48284 .88566 m .48338 .88538 L .48202 .88465 L F
.55 0 0 r
.48238 .88516 m .48202 .88465 L .48338 .88538 L F
.48046 .88474 m .48202 .88465 L .48238 .88516 L F
.589 .126 0 r
.48096 .8832 m .48124 .88356 L .48202 .88465 L F
.48124 .88356 m .48284 .88566 L .48202 .88465 L F
.974 .894 .683 r
.53185 .80804 m .53434 .80596 L .53388 .80799 L F
.559 .155 .231 r
.45001 .88545 m .4512 .88364 L .45328 .88448 L F
.65 .429 .569 r
.62462 .76688 m .62241 .76925 L .62251 .76725 L F
.465 .258 .513 r
.58074 .78522 m .58039 .78732 L .57856 .78748 L F
.744 .609 .708 r
.57018 .83478 m .56736 .83722 L .56733 .83475 L F
.862 .847 .827 r
.57611 .78813 m .57424 .79057 L .57323 .78951 L F
0 0 .332 r
.57424 .79057 m .57496 .79188 L .57323 .78951 L F
.57424 .79057 m .57426 .79293 L .57496 .79188 L F
.83 .742 .767 r
.48787 .84502 m .4912 .84433 L .48986 .84366 L F
.48787 .84502 m .48882 .84715 L .4912 .84433 L F
.512 .278 .496 r
.61189 .76936 m .61449 .76703 L .61174 .76711 L F
.631 .587 .786 r
.36465 .74631 m .36142 .74365 L .36286 .744 L F
.556 .773 .979 r
.36534 .7448 m .36465 .74631 L .36286 .744 L F
.36534 .7448 m .36671 .74599 L .36465 .74631 L F
.514 .356 .604 r
.36671 .74599 m .3649 .74843 L .36465 .74631 L F
.536 .021 0 r
.48823 .88755 m .48928 .88648 L .49064 .88804 L F
.978 .734 .499 r
.58579 .78685 m .58659 .78779 L .58618 .78995 L F
.466 .683 .96 r
.58791 .78688 m .58659 .78779 L .58579 .78685 L F
.024 0 .27 r
.58618 .78995 m .58659 .78779 L .58791 .78688 L F
.142 0 .097 r
.43781 .87301 m .43531 .87574 L .43745 .87564 L F
.764 .636 .719 r
.43745 .87564 m .43977 .87287 L .43781 .87301 L F
.951 .648 .211 r
.56609 .78298 m .56606 .78347 L .56528 .78186 L F
.481 .635 .922 r
.56748 .78138 m .56609 .78298 L .56528 .78186 L F
0 0 .254 r
.53082 .81623 m .53155 .81567 L .53174 .81298 L F
.252 .687 .961 r
.53082 .81623 m .53302 .81647 L .53155 .81567 L F
.668 .178 .075 r
.42221 .83895 m .42075 .84025 L .41859 .83874 L F
.039 0 .226 r
.42402 .83678 m .42221 .83895 L .42262 .83812 L F
.42402 .83678 m .42364 .8384 L .42221 .83895 L F
.645 .488 .655 r
.42221 .83895 m .42515 .83971 L .42424 .83789 L F
.596 .27 .389 r
.42364 .8384 m .42075 .84025 L .42221 .83895 L F
.752 .584 .668 r
.50273 .81608 m .50441 .81875 L .50112 .81857 L F
.669 .531 .687 r
.50273 .81608 m .5042 .81704 L .5063 .81606 L F
.545 .198 .33 r
.48243 .85512 m .48499 .85521 L .48616 .85395 L F
.14 0 .004 r
.48616 .85395 m .48669 .85438 L .48743 .85308 L F
.48616 .85395 m .48499 .85521 L .48669 .85438 L F
.45 .263 .534 r
.66393 .74841 m .66412 .75078 L .66192 .75141 L F
.566 .42 .642 r
.66412 .75078 m .66214 .75285 L .66192 .75141 L F
.61 .122 .07 r
.51731 .81589 m .51378 .8162 L .51377 .81585 L F
.659 .615 .794 r
.51731 .81589 m .52038 .81614 L .51911 .81408 L F
.633 .572 .768 r
.51911 .81408 m .5194 .81637 L .51731 .81589 L F
.473 0 0 r
.5194 .81637 m .51378 .8162 L .51731 .81589 L F
0 0 0 r
.57714 .80813 m .57594 .81079 L .57657 .81047 L F
0 .443 .854 r
.57657 .81047 m .57594 .81079 L .57717 .81114 L F
.478 .786 .998 r
.36203 .7426 m .36142 .74365 L .36001 .74285 L F
.291 .553 .924 r
.36203 .7426 m .36286 .744 L .36142 .74365 L F
.695 .687 .838 r
.58356 .78794 m .58427 .79025 L .58066 .78992 L F
.716 .467 .548 r
.58427 .79025 m .5789 .79245 L .58066 .78992 L F
.978 .734 .499 r
.58579 .78685 m .58427 .79025 L .58356 .78794 L F
.58579 .78685 m .58618 .78995 L .58427 .79025 L F
.566 .4 .616 r
.58618 .78995 m .58427 .79264 L .58427 .79025 L F
.714 .603 .73 r
.62653 .76177 m .62449 .76445 L .62429 .7622 L F
.661 .527 .689 r
.62653 .76177 m .62671 .76431 L .62449 .76445 L F
.594 .448 .653 r
.62687 .76644 m .62449 .76445 L .62671 .76431 L F
.62687 .76644 m .62462 .76688 L .62449 .76445 L F
.688 .676 .833 r
.57497 .78308 m .57191 .78271 L .57342 .78215 L F
.725 .706 .832 r
.57711 .78233 m .57497 .78308 L .57342 .78215 L F
.443 0 .082 r
.4112 .83945 m .40791 .84088 L .40934 .8399 L F
0 0 0 r
.47308 .8282 m .47176 .8292 L .4742 .82728 L F
.678 .955 .713 r
.5716 .79993 m .57301 .79897 L .57167 .7978 L F
.873 .991 .739 r
.49303 .85415 m .49485 .85183 L .49516 .85194 L F
.6 .411 .598 r
.49263 .85291 m .49303 .85415 L .49516 .85194 L F
.566 .098 .102 r
.43116 .82032 m .43316 .82075 L .43443 .81964 L F
.414 0 .014 r
.43316 .82075 m .43662 .81955 L .43443 .81964 L F
.379 .191 .495 r
.5063 .81606 m .50571 .81883 L .50441 .81875 L F
.371 .355 .711 r
.50571 .81883 m .50651 .8207 L .50441 .81875 L F
.462 .56 .869 r
.54534 .81574 m .54365 .81692 L .54388 .81558 L F
.54534 .81574 m .54691 .81834 L .54365 .81692 L F
.387 0 0 r
.38325 .83064 m .3827 .82938 L .38118 .83063 L F
.38325 .83064 m .38478 .8293 L .3827 .82938 L F
.502 .119 .246 r
.45863 .8813 m .45952 .88343 L .4575 .88345 L F
.45863 .8813 m .46076 .88126 L .45952 .88343 L F
.611 .595 .81 r
.37442 .75823 m .37249 .75967 L .37188 .75734 L F
.505 .444 .722 r
.37442 .75823 m .37339 .76172 L .37249 .75967 L F
.862 .847 .827 r
.57611 .78813 m .57362 .78834 L .57491 .78727 L F
.57611 .78813 m .57323 .78951 L .57362 .78834 L F
.453 .181 .409 r
.37296 .7637 m .37082 .76421 L .37339 .76172 L F
.505 .444 .722 r
.37442 .75823 m .37513 .7614 L .37339 .76172 L F
.565 .343 .537 r
.37513 .7614 m .37296 .7637 L .37339 .76172 L F
.513 .295 .52 r
.39316 .90181 m .39435 .90176 L .39182 .90248 L F
.39316 .90181 m .39511 .90116 L .39435 .90176 L F
.39316 .90181 m .39388 .90149 L .39511 .90116 L F
0 .546 .793 r
.50103 .81189 m .49991 .81191 L .49875 .81049 L F
.50103 .81189 m .50147 .81203 L .49991 .81191 L F
.512 .051 .096 r
.49809 .8123 m .49953 .81278 L .50103 .81189 L F
.915 .963 .797 r
.50103 .81189 m .49953 .81278 L .50028 .81166 L F
.512 .051 .096 r
.49809 .8123 m .50103 .81189 L .49875 .81049 L F
.915 .963 .797 r
.50103 .81189 m .50028 .81166 L .50186 .80932 L F
0 .546 .793 r
.50103 .81189 m .50169 .81205 L .50147 .81203 L F
.046 0 .094 r
.51461 .87821 m .51682 .87571 L .51604 .87789 L F
.222 0 .169 r
.51604 .87789 m .51682 .87571 L .51832 .87519 L F
.457 .718 .98 r
.50086 .80744 m .50402 .80595 L .50105 .80552 L F
.50086 .80744 m .50321 .80787 L .50402 .80595 L F
.569 .246 .381 r
.50402 .80595 m .50321 .80787 L .50646 .80737 L F
.16 0 0 r
.51126 .88014 m .51461 .87821 L .51383 .87908 L F
0 0 0 r
.51383 .87908 m .51461 .87821 L .51604 .87789 L F
.647 .135 .013 r
.50351 .81983 m .49787 .81865 L .50112 .81857 L F
.50351 .81983 m .50003 .82006 L .49787 .81865 L F
.759 .399 .373 r
.49988 .8214 m .49674 .822 L .49655 .82046 L F
.692 .946 .667 r
.50313 .82018 m .50008 .82304 L .50005 .82133 L F
.50313 .82018 m .50005 .82133 L .50003 .82006 L F
.50351 .81983 m .49953 .82376 L .50008 .82304 L F
.468 .407 .706 r
.50237 .82051 m .5004 .82155 L .50003 .82006 L F
.50237 .82051 m .50204 .82169 L .5004 .82155 L F
.483 .462 .758 r
.50003 .82006 m .50005 .82133 L .50204 .82169 L F
.759 .399 .373 r
.5004 .82155 m .50025 .8215 L .50003 .82006 L F
.50025 .8215 m .49655 .82046 L .50003 .82006 L F
.483 .462 .758 r
.50005 .82133 m .50008 .82304 L .50045 .82279 L F
.50036 .82159 m .50045 .82279 L .50117 .82229 L F
.50027 .82159 m .50045 .82279 L .50036 .82159 L F
.50005 .82133 m .50007 .82138 L .50025 .8215 L F
.50007 .82138 m .50045 .82279 L .50026 .82152 L F
.50007 .82138 m .50026 .82152 L .50025 .8215 L F
.50025 .8215 m .50027 .82159 L .50036 .82159 L F
.617 .783 .961 r
.49953 .82376 m .49776 .82448 L .49679 .82436 L F
.45 .35 .65 r
.49679 .82436 m .49883 .82552 L .49953 .82376 L F
.722 .323 .293 r
.50032 .82156 m .49869 .82411 L .49674 .822 L F
.5004 .82155 m .50037 .82159 L .50032 .82156 L F
.50037 .82159 m .49869 .82411 L .50032 .82156 L F
.523 .119 .216 r
.50204 .82169 m .50037 .82159 L .5004 .82155 L F
.759 .399 .373 r
.5004 .82155 m .50032 .82156 L .50025 .8215 L F
.483 .462 .758 r
.50005 .82133 m .50117 .82229 L .50204 .82169 L F
.523 .119 .216 r
.50204 .82169 m .49869 .82411 L .50037 .82159 L F
.759 .399 .373 r
.50025 .8215 m .49901 .82172 L .49988 .8214 L F
.50032 .82156 m .49901 .82172 L .50025 .8215 L F
.49901 .82172 m .49674 .822 L .49988 .8214 L F
.692 .946 .667 r
.50351 .81983 m .50313 .82018 L .50003 .82006 L F
.455 .11 .291 r
.38428 .84699 m .38071 .84937 L .38123 .84724 L F
.171 0 0 r
.41941 .89341 m .4211 .89245 L .42291 .89224 L F
.496 .347 .609 r
.4871 .84968 m .48743 .85308 L .48884 .85206 L F
.371 0 .068 r
.51585 .87103 m .51252 .8729 L .51436 .87201 L F
.054 0 0 r
.51784 .87049 m .51585 .87103 L .51436 .87201 L F
.695 .835 .95 r
.40116 .79292 m .40445 .79296 L .40316 .79176 L F
.767 .922 .939 r
.54177 .81889 m .53911 .82099 L .54163 .82215 L F
.676 .869 .972 r
.57221 .78784 m .57362 .78834 L .57491 .78727 L F
.667 .943 .681 r
.56343 .82592 m .56492 .82491 L .5636 .82618 L F
.298 .391 .789 r
.56582 .82308 m .56492 .82491 L .56343 .82592 L F
.56582 .82308 m .56748 .82672 L .56492 .82491 L F
.355 .142 .446 r
.62123 .76184 m .62289 .76199 L .62334 .75867 L F
.645 .393 .523 r
.62334 .75867 m .62593 .75947 L .62546 .75862 L F
.453 .872 .939 r
.4997 .87438 m .49773 .87502 L .49663 .8748 L F
.41 0 0 r
.41458 .83961 m .41343 .83989 L .4112 .83945 L F
.443 0 0 r
.41659 .83926 m .41343 .83989 L .41458 .83961 L F
.671 .383 .476 r
.49667 .84699 m .4994 .84705 L .49641 .84643 L F
.457 .718 .98 r
.50086 .80744 m .50207 .80849 L .50321 .80787 L F
.758 .52 .572 r
.65354 .75669 m .65194 .75849 L .65205 .75637 L F
.65354 .75669 m .65515 .75914 L .65194 .75849 L F
.035 .232 .734 r
.53485 .80487 m .53579 .80806 L .53434 .80596 L F
0 .177 .694 r
.53434 .80596 m .535 .80604 L .53485 .80487 L F
.663 .613 .788 r
.53434 .80596 m .53027 .80367 L .535 .80604 L F
.727 .503 .587 r
.53434 .80596 m .53579 .80806 L .53388 .80799 L F
.53434 .80596 m .53579 .80806 L .53388 .80799 L F
0 0 0 r
.539 .82071 m .5393 .82052 L .53724 .82136 L F
.346 .367 .74 r
.539 .82071 m .53724 .82136 L .53951 .82261 L F
.42 0 0 r
.45635 .87232 m .45633 .87084 L .4547 .87223 L F
.45635 .87232 m .45864 .87096 L .45633 .87084 L F
.387 0 0 r
.43328 .88893 m .43383 .88995 L .43175 .89019 L F
.43328 .88893 m .43551 .88914 L .43383 .88995 L F
.201 0 .037 r
.47568 .82615 m .47308 .8282 L .4742 .82728 L F
.57 .331 .515 r
.61343 .77729 m .61092 .77949 L .61119 .77772 L F
.217 0 0 r
.52223 .8065 m .52526 .80554 L .52344 .80654 L F
.73 .694 .816 r
.57711 .78233 m .57342 .78215 L .57589 .77954 L F
.691 .675 .829 r
.57897 .78036 m .57711 .78233 L .57589 .77954 L F
.669 .638 .81 r
.57897 .78036 m .58001 .78285 L .57711 .78233 L F
.639 .691 .883 r
.50511 .86059 m .50624 .86322 L .50279 .86235 L F
0 .193 .722 r
.50604 .86196 m .50624 .86322 L .50511 .86059 L F
.697 .317 .325 r
.50484 .86505 m .50624 .86322 L .50604 .86196 L F
.691 .616 .768 r
.57238 .83428 m .56906 .83256 L .57186 .83367 L F
.897 .565 .41 r
.57149 .83633 m .57238 .83428 L .57186 .83367 L F
.57149 .83633 m .57325 .83638 L .57238 .83428 L F
.405 0 0 r
.43662 .81955 m .43829 .82003 L .43968 .8192 L F
.421 0 0 r
.43829 .82003 m .44163 .81916 L .43968 .8192 L F
.916 .979 .729 r
.57191 .78271 m .57292 .77937 L .57342 .78215 L F
.532 .114 .193 r
.40768 .82523 m .40971 .82535 L .41113 .82364 L F
.387 0 .013 r
.40971 .82535 m .41324 .82382 L .41113 .82364 L F
.546 .333 .542 r
.66637 .74611 m .66393 .74841 L .66331 .74609 L F
.66637 .74611 m .66605 .74804 L .66393 .74841 L F
.506 .284 .511 r
.66605 .74804 m .66412 .75078 L .66393 .74841 L F
.147 .478 .897 r
.54113 .81025 m .54034 .81083 L .53988 .80984 L F
.269 .686 .968 r
.54113 .81025 m .54215 .81091 L .54034 .81083 L F
.469 .535 .842 r
.54333 .81358 m .54034 .81083 L .54215 .81091 L F
.638 .166 .116 r
.54457 .82567 m .546 .82462 L .54769 .82609 L F
.476 .233 .466 r
.54769 .82609 m .546 .82462 L .54823 .82378 L F
.661 .532 .696 r
.48447 .84376 m .48699 .84327 L .4857 .84314 L F
.618 .457 .642 r
.62865 .75915 m .62879 .76132 L .62653 .76177 L F
.65 .518 .689 r
.62931 .7634 m .62653 .76177 L .62879 .76132 L F
.62931 .7634 m .62671 .76431 L .62653 .76177 L F
.749 .465 0 r
.5636 .82618 m .56433 .82915 L .56343 .82592 L F
.513 .359 .608 r
.66793 .74562 m .66605 .74804 L .66637 .74611 L F
.481 .899 .863 r
.39893 .90008 m .40086 .89961 L .40258 .8988 L F
.463 .103 .268 r
.47033 .81578 m .47239 .81557 L .4735 .81338 L F
.506 .141 .28 r
.47239 .81557 m .47562 .81336 L .4735 .81338 L F
.144 0 0 r
.44163 .81916 m .44397 .81923 L .44505 .81907 L F
.188 0 0 r
.44397 .81923 m .44707 .81894 L .44505 .81907 L F
0 .124 .669 r
.49454 .83126 m .49669 .83342 L .49509 .83127 L F
.615 .475 .668 r
.42424 .83789 m .42515 .83971 L .42585 .83718 L F
.305 0 .203 r
.57936 .80757 m .57714 .80813 L .57877 .80833 L F
.901 .729 .66 r
.57883 .80835 m .57936 .80757 L .57877 .80833 L F
.305 0 .203 r
.57936 .80757 m .57877 .80833 L .57883 .80834 L F
.57 .644 .884 r
.57499 .80547 m .5786 .80816 L .57486 .80763 L F
.901 .729 .66 r
.57797 .80815 m .57845 .80795 L .57779 .80728 L F
.331 .577 .931 r
.57779 .80728 m .57883 .80834 L .5786 .80816 L F
0 0 0 r
.57882 .80635 m .57779 .80728 L .57922 .80583 L F
.331 .577 .931 r
.57779 .80728 m .5786 .80816 L .57762 .80744 L F
.57 .644 .884 r
.5786 .80816 m .5787 .80831 L .57486 .80763 L F
0 .524 .771 r
.5787 .80831 m .57714 .80813 L .57486 .80763 L F
.57877 .80833 m .57714 .80813 L .5787 .80831 L F
.901 .729 .66 r
.57877 .80833 m .57936 .80757 L .57841 .80796 L F
.57845 .80795 m .57936 .80757 L .57802 .80732 L F
.57845 .80795 m .57802 .80732 L .57779 .80728 L F
.305 0 .203 r
.57936 .80757 m .57883 .80834 L .57779 .80728 L F
.901 .729 .66 r
.5782 .80928 m .57779 .80728 L .57657 .81047 L F
0 0 0 r
.577 .80875 m .57779 .80728 L .57882 .80635 L F
.331 .577 .931 r
.57779 .80728 m .57762 .80744 L .57499 .80547 L F
.901 .729 .66 r
.57874 .80832 m .57841 .80796 L .57797 .80815 L F
.57877 .80833 m .57841 .80796 L .57874 .80832 L F
.57 .644 .884 r
.5786 .80816 m .57883 .80834 L .5787 .80831 L F
.901 .729 .66 r
.5782 .80928 m .57883 .80835 L .57797 .80815 L F
0 .524 .771 r
.57883 .80834 m .57877 .80833 L .5787 .80831 L F
0 0 0 r
.57714 .80813 m .57657 .81047 L .57486 .80763 L F
.399 0 .086 r
.4525 .83121 m .44923 .83293 L .45056 .83178 L F
.976 .725 .488 r
.5756 .83684 m .57577 .83927 L .57458 .8388 L F
.582 .422 .63 r
.57577 .83927 m .57792 .83875 L .5756 .83684 L F
.674 .124 0 r
.57665 .83841 m .5756 .83684 L .57458 .8388 L F
.57665 .83841 m .57792 .83875 L .5756 .83684 L F
.036 0 0 r
.40258 .8988 m .40568 .89824 L .40447 .89814 L F
.424 .863 .913 r
.40568 .89824 m .40654 .89761 L .40447 .89814 L F
.40568 .89824 m .40774 .89768 L .40654 .89761 L F
.446 .832 .986 r
.56664 .81092 m .56999 .81102 L .56889 .81079 L F
.51 .906 .928 r
.57203 .80836 m .57017 .81007 L .56999 .81102 L F
.65 .955 .941 r
.56889 .81079 m .56999 .81102 L .57017 .81007 L F
.624 .614 .82 r
.58182 .78228 m .58001 .78285 L .57897 .78036 L F
.569 .424 .645 r
.58182 .78228 m .58229 .7846 L .58001 .78285 L F
.474 .433 .732 r
.58229 .7846 m .58074 .78522 L .58001 .78285 L F
.041 .607 .772 r
.48802 .87039 m .49142 .87056 L .49035 .87044 L F
.816 .984 .885 r
.49035 .87044 m .49142 .87056 L .49088 .86984 L F
0 0 .379 r
.4924 .87346 m .49195 .8708 L .4921 .87116 L F
.281 .16 .531 r
.4924 .87346 m .49142 .87056 L .4921 .87116 L F
.674 .639 .806 r
.58356 .78794 m .58066 .78992 L .58039 .78732 L F
.659 .479 .629 r
.62241 .76925 m .62033 .77164 L .62018 .76949 L F
.68 .704 .866 r
.39959 .88475 m .40053 .88644 L .39705 .88549 L F
.599 .666 .886 r
.40239 .88592 m .40053 .88644 L .39959 .88475 L F
.541 .198 .336 r
.49601 .81886 m .49267 .82101 L .49402 .81971 L F
.65 .489 .653 r
.49516 .85009 m .49516 .85194 L .49731 .84966 L F
.191 0 0 r
.50386 .87475 m .50546 .87393 L .50273 .87438 L F
.006 0 0 r
.39522 .88646 m .39131 .88714 L .39385 .88565 L F
.715 .861 .951 r
.39705 .88549 m .39522 .88646 L .39385 .88565 L F
.406 0 .021 r
.41523 .82348 m .4173 .8234 L .41869 .82211 L F
.393 0 .012 r
.41869 .82211 m .4173 .8234 L .42027 .82254 L F
.774 .538 .578 r
.64128 .75635 m .6422 .75859 L .63924 .75871 L F
.298 0 .185 r
.63924 .75871 m .64018 .75845 L .64128 .75635 L F
.546 .552 .812 r
.63913 .75349 m .64128 .75635 L .64165 .75527 L F
.683 .446 .558 r
.64018 .75845 m .64165 .75527 L .64128 .75635 L F
.453 .013 .11 r
.43461 .87687 m .43321 .8761 L .43184 .87769 L F
.432 .046 .204 r
.43461 .87687 m .43531 .87574 L .43321 .8761 L F
.231 .742 .71 r
.52266 .83395 m .52357 .83371 L .52573 .83306 L F
.574 .323 .499 r
.3913 .84434 m .39128 .84729 L .38827 .84741 L F
.606 .349 .502 r
.39309 .84643 m .3913 .84434 L .39328 .84456 L F
.39309 .84643 m .39128 .84729 L .3913 .84434 L F
.766 .57 .633 r
.62593 .75947 m .62865 .75915 L .62546 .75862 L F
.62593 .75947 m .62879 .76132 L .62865 .75915 L F
.66 .519 .681 r
.63105 .75861 m .62879 .76132 L .62865 .75915 L F
.682 .551 .699 r
.63105 .75861 m .62879 .76132 L .62865 .75915 L F
.528 0 0 r
.53827 .81555 m .54136 .81641 L .54027 .81644 L F
0 0 .468 r
.54136 .81641 m .54251 .81758 L .54027 .81644 L F
0 0 0 r
.54136 .81641 m .54333 .81358 L .54388 .81558 L F
.319 0 .148 r
.52301 .8725 m .52596 .86988 L .52476 .87171 L F
.304 0 .118 r
.52596 .86988 m .52863 .86849 L .5274 .87071 L F
.321 0 .069 r
.52476 .87171 m .52596 .86988 L .5274 .87071 L F
.783 .997 .799 r
.54706 .82869 m .54706 .82924 L .54753 .8283 L F
.084 .485 .896 r
.5313 .80342 m .53027 .80367 L .52953 .80263 L F
.5313 .80342 m .535 .80604 L .53027 .80367 L F
.747 .639 .74 r
.56733 .83475 m .56736 .83722 L .56548 .83643 L F
.801 .507 .492 r
.56548 .83643 m .56736 .83722 L .56709 .83897 L F
.57 .115 .132 r
.56736 .83722 m .56879 .83891 L .56709 .83897 L F
.56736 .83722 m .57021 .83814 L .56879 .83891 L F
.548 .332 .539 r
.58208 .7867 m .58074 .78522 L .58229 .7846 L F
.58208 .7867 m .58039 .78732 L .58074 .78522 L F
.699 .546 .676 r
.5713 .79528 m .57426 .79293 L .57225 .79395 L F
.562 .525 .771 r
.36766 .75337 m .36671 .75684 L .36568 .75374 L F
.36766 .75337 m .36866 .75654 L .36671 .75684 L F
.51 .906 .928 r
.57203 .80836 m .56885 .80921 L .57017 .81007 L F
.017 0 .385 r
.52038 .81614 m .52272 .81846 L .52177 .81703 L F
.759 .321 .211 r
.54163 .82215 m .54134 .82344 L .53951 .82261 L F
0 0 0 r
.54144 .82393 m .54134 .82344 L .54038 .82494 L F
.525 0 0 r
.53951 .82261 m .54134 .82344 L .54144 .82393 L F
.53951 .82261 m .54144 .82393 L .54004 .82003 L F
0 0 0 r
.54177 .81889 m .5393 .82052 L .53904 .82069 L F
.54177 .81889 m .53904 .82069 L .53914 .82062 L F
.53914 .82062 m .53904 .82069 L .539 .82071 L F
.54177 .81889 m .539 .82071 L .53972 .81914 L F
.525 0 0 r
.53965 .82029 m .54004 .82003 L .53972 .81914 L F
.53951 .82261 m .54004 .82003 L .53965 .82029 L F
.256 0 0 r
.44707 .81894 m .44862 .81928 L .4503 .81881 L F
.298 0 0 r
.44862 .81928 m .45244 .81875 L .4503 .81881 L F
0 .131 .666 r
.57102 .79898 m .5716 .79993 L .56986 .79827 L F
.57102 .79898 m .56986 .79827 L .56847 .79952 L F
.124 0 .114 r
.52709 .8649 m .52563 .8658 L .52481 .86714 L F
.087 0 0 r
.47896 .829 m .48231 .8293 L .48117 .82922 L F
.569 .928 .941 r
.48117 .82922 m .48231 .8293 L .48425 .8284 L F
.372 .84 .841 r
.50733 .88264 m .50813 .88211 L .50629 .88316 L F
.50733 .88264 m .50948 .88196 L .50813 .88211 L F
.3 0 0 r
.38478 .8293 m .38685 .82915 L .3877 .82852 L F
.215 0 0 r
.3877 .82852 m .38863 .82883 L .38994 .82816 L F
.3877 .82852 m .38685 .82915 L .38863 .82883 L F
.972 .735 .519 r
.40122 .88485 m .40239 .88592 L .40241 .88337 L F
.543 0 0 r
.48456 .88556 m .48646 .88707 L .48284 .88566 L F
.48456 .88556 m .48589 .88635 L .48646 .88707 L F
.363 .468 .833 r
.54477 .81245 m .54333 .81358 L .54215 .81091 L F
.422 .335 .653 r
.54534 .81574 m .54333 .81358 L .54477 .81245 L F
.54534 .81574 m .54388 .81558 L .54333 .81358 L F
.514 .356 .604 r
.36671 .74599 m .36665 .74811 L .3649 .74843 L F
.538 .444 .696 r
.36665 .74811 m .36529 .75163 L .3649 .74843 L F
.576 .205 .301 r
.42928 .83432 m .42785 .83648 L .42594 .8362 L F
.586 .216 .307 r
.43079 .83592 m .42785 .83648 L .42928 .83432 L F
.741 .577 .672 r
.52038 .81614 m .52124 .81329 L .51911 .81408 L F
.017 0 .385 r
.52038 .81614 m .52114 .81771 L .52272 .81846 L F
.52038 .81614 m .52002 .81905 L .52114 .81771 L F
.52038 .81614 m .52002 .81905 L .52114 .81771 L F
.483 .065 .171 r
.47963 .81231 m .48296 .8106 L .4809 .81089 L F
.111 0 0 r
.4809 .81089 m .48296 .8106 L .48379 .81035 L F
.883 .945 .848 r
.50153 .86107 m .50279 .86235 L .50077 .86223 L F
.932 .901 .772 r
.50077 .86223 m .50279 .86235 L .50131 .86345 L F
.708 .914 .966 r
.50511 .86059 m .50279 .86235 L .50153 .86107 L F
.613 .417 .592 r
.62931 .7634 m .62687 .76644 L .62671 .76431 L F
.804 .359 .186 r
.49509 .83127 m .49565 .83015 L .49486 .82865 L F
.49509 .83127 m .49675 .83188 L .49565 .83015 L F
.572 .498 .733 r
.57976 .83162 m .5822 .83197 L .58082 .82833 L F
.117 .592 .915 r
.5655 .83142 m .56906 .83256 L .56806 .82884 L F
.5655 .83142 m .56906 .83256 L .56832 .83224 L F
.539 .454 .707 r
.56906 .83256 m .57182 .83307 L .57042 .82872 L F
0 .337 .677 r
.57054 .83311 m .56906 .83256 L .56832 .83224 L F
.517 .353 .598 r
.57054 .83311 m .56832 .83224 L .57035 .83131 L F
.977 .78 .572 r
.5697 .83275 m .57054 .83311 L .56972 .83267 L F
0 .337 .677 r
.57054 .83311 m .57149 .83352 L .56906 .83256 L F
.977 .78 .572 r
.56917 .83489 m .57054 .83311 L .5697 .83275 L F
0 .337 .677 r
.57054 .83311 m .57186 .83367 L .57149 .83352 L F
.521 0 0 r
.48807 .82408 m .49034 .82514 L .49163 .82445 L F
.256 0 0 r
.49034 .82514 m .49417 .82557 L .49163 .82445 L F
.555 .427 .66 r
.52025 .83191 m .52277 .83247 L .52223 .82968 L F
.559 .417 .644 r
.52025 .83191 m .52266 .83395 L .52277 .83247 L F
.431 .771 .997 r
.63301 .75829 m .63398 .7591 L .63105 .75861 L F
.764 .264 .023 r
.62593 .75947 m .62767 .76144 L .62879 .76132 L F
.682 .551 .699 r
.63105 .75861 m .63161 .76145 L .62879 .76132 L F
.66 .519 .681 r
.63105 .75861 m .63169 .76025 L .62879 .76132 L F
.505 .046 .097 r
.62767 .76144 m .63169 .76025 L .63101 .7605 L F
.62834 .76137 m .63101 .7605 L .62879 .76132 L F
.62767 .76144 m .63101 .7605 L .62834 .76137 L F
.603 .366 .531 r
.63398 .7591 m .63334 .75974 L .63105 .75861 L F
.63334 .75974 m .63161 .76145 L .6314 .76037 L F
.63334 .75974 m .6314 .76037 L .63105 .75861 L F
.63398 .7591 m .63388 .76126 L .63161 .76145 L F
.793 .576 .606 r
.63301 .75829 m .63598 .75648 L .63398 .7591 L F
.599 .448 .649 r
.63598 .75648 m .63642 .75871 L .63398 .7591 L F
.638 .438 .596 r
.63642 .75871 m .63388 .76126 L .63398 .7591 L F
.577 .126 .144 r
.46235 .87185 m .46162 .87 L .46055 .87063 L F
.46235 .87185 m .46348 .87062 L .46162 .87 L F
0 0 .044 r
.66331 .74609 m .66489 .74524 L .66541 .74337 L F
.473 0 0 r
.5194 .81637 m .51985 .81767 L .51378 .8162 L F
0 .022 .56 r
.52029 .81494 m .5194 .81637 L .51911 .81408 L F
0 0 .065 r
.5201 .81725 m .5194 .81637 L .52029 .81494 L F
.5201 .81725 m .51985 .81767 L .5194 .81637 L F
.465 0 0 r
.5097 .8074 m .51125 .80809 L .51266 .80836 L F
.675 .201 .117 r
.51125 .80809 m .51456 .80878 L .51266 .80836 L F
.335 .817 .842 r
.53008 .86679 m .53181 .86636 L .52909 .86687 L F
0 0 0 r
.52854 .86904 m .52863 .86849 L .53008 .86679 L F
.5274 .87071 m .5279 .86982 L .52854 .86904 L F
.5279 .86982 m .52863 .86849 L .52854 .86904 L F
.5274 .87071 m .53008 .86679 L .52909 .86687 L F
.299 0 0 r
.52909 .86687 m .53181 .86636 L .53138 .86705 L F
.485 .405 .691 r
.52882 .86482 m .52909 .86687 L .53026 .86697 L F
.53069 .86645 m .53026 .86697 L .53138 .86705 L F
.52882 .86482 m .53026 .86697 L .53069 .86645 L F
.877 .991 .808 r
.57999 .81102 m .58088 .81123 L .58142 .80925 L F
.11 0 .213 r
.58088 .81123 m .58295 .80846 L .58142 .80925 L F
.458 .06 .197 r
.39651 .8443 m .39309 .84643 L .39328 .84456 L F
.39651 .8443 m .39491 .84643 L .39309 .84643 L F
.328 0 .077 r
.39841 .84413 m .39491 .84643 L .39651 .8443 L F
.508 .255 .466 r
.39874 .84292 m .39841 .84413 L .39651 .8443 L F
.388 0 0 r
.46589 .88047 m .46924 .88056 L .46786 .88081 L F
.427 0 0 r
.46786 .88081 m .46924 .88056 L .47066 .88093 L F
.276 0 0 r
.42027 .82254 m .42247 .82247 L .4239 .82158 L F
.546 .105 .153 r
.42247 .82247 m .4259 .82124 L .4239 .82158 L F
.507 .32 .561 r
.37296 .7637 m .37064 .76645 L .37082 .76421 L F
0 0 0 r
.43184 .87769 m .43073 .87795 L .42939 .87955 L F
.408 0 .037 r
.39188 .82844 m .39395 .82835 L .39534 .82696 L F
.339 0 0 r
.39395 .82835 m .39738 .82693 L .39534 .82696 L F
.768 .962 .658 r
.60874 .77978 m .60667 .78245 L .60671 .78195 L F
.375 .22 .539 r
.60667 .78245 m .60669 .78467 L .60833 .78381 L F
.60833 .78381 m .60669 .78467 L .60667 .78245 L F
.60667 .78245 m .60833 .78381 L .60723 .78348 L F
.60667 .78245 m .60723 .78348 L .60671 .78195 L F
.629 .482 .663 r
.60874 .77978 m .6089 .78254 L .60667 .78245 L F
.375 .22 .539 r
.60833 .78381 m .60667 .78245 L .6089 .78254 L F
.54 .794 .991 r
.58295 .80846 m .57936 .80757 L .58158 .80774 L F
.97 .78 .591 r
.58142 .80925 m .58295 .80846 L .58158 .80774 L F
.579 .375 .568 r
.50856 .81806 m .5063 .81606 L .50848 .81583 L F
.50856 .81806 m .50571 .81883 L .5063 .81606 L F
.479 .161 .349 r
.6606 .74867 m .66319 .74834 L .66331 .74609 L F
.046 0 .268 r
.66433 .7473 m .66331 .74609 L .66319 .74834 L F
.66433 .7473 m .66489 .74524 L .66331 .74609 L F
.841 .544 .487 r
.51666 .82571 m .51775 .82667 L .51927 .82642 L F
.353 .828 .847 r
.51927 .82642 m .51775 .82667 L .51804 .82658 L F
.51927 .82642 m .51804 .82658 L .5207 .82576 L F
.792 .369 .242 r
.51743 .82666 m .51927 .82642 L .51815 .82755 L F
.51666 .82571 m .51927 .82642 L .51804 .82658 L F
.597 .607 .832 r
.51804 .82658 m .51775 .82667 L .51764 .82634 L F
.792 .369 .242 r
.51764 .82634 m .51804 .82658 L .51803 .82658 L F
.51666 .82571 m .51804 .82658 L .51764 .82634 L F
.597 .607 .832 r
.5207 .82576 m .51804 .82658 L .51667 .82322 L F
.51804 .82658 m .51764 .82634 L .51667 .82322 L F
.579 .595 .833 r
.51667 .82322 m .51764 .82634 L .51666 .82571 L F
.51764 .82634 m .51775 .82667 L .51666 .82571 L F
.792 .369 .242 r
.51666 .82571 m .51803 .82658 L .51743 .82666 L F
0 0 0 r
.51815 .82755 m .51927 .82642 L .5207 .82576 L F
.65 .429 .569 r
.62462 .76688 m .62458 .76922 L .62241 .76925 L F
.612 .398 .566 r
.62752 .76821 m .62462 .76688 L .62687 .76644 L F
.62752 .76821 m .62458 .76922 L .62462 .76688 L F
.544 .292 .484 r
.46312 .82895 m .46061 .83102 L .46114 .82915 L F
.499 .07 .157 r
.46076 .88126 m .46395 .88049 L .46251 .88201 L F
.45 .003 .095 r
.46395 .88049 m .4645 .88193 L .46251 .88201 L F
.46395 .88049 m .46589 .88047 L .4645 .88193 L F
.512 .278 .496 r
.61189 .76936 m .61412 .76922 L .61449 .76703 L F
.528 .347 .579 r
.61189 .76936 m .61222 .77197 L .61412 .76922 L F
.765 .661 .748 r
.4525 .83121 m .45482 .83201 L .45607 .83109 L F
.4525 .83121 m .45607 .83109 L .45449 .83133 L F
.683 .203 .103 r
.45607 .83109 m .45772 .83198 L .45449 .83133 L F
.662 .386 .493 r
.50251 .82642 m .50004 .82811 L .50062 .82695 L F
.32 .111 .431 r
.61449 .76703 m .61412 .76922 L .61596 .76636 L F
.807 .94 .915 r
.48799 .83239 m .49006 .83211 L .48791 .83247 L F
.617 .114 .034 r
.48973 .83215 m .49006 .83211 L .49072 .83157 L F
1 .813 .507 r
.49072 .83157 m .49006 .83211 L .49017 .82909 L F
.847 .672 .665 r
.49017 .82909 m .49006 .83211 L .48826 .82849 L F
.259 .384 .8 r
.48826 .82849 m .49006 .83211 L .49063 .82986 L F
.792 .548 .569 r
.48826 .82849 m .48931 .83125 L .48511 .83017 L F
.421 .356 .679 r
.49063 .82986 m .48931 .83125 L .48826 .82849 L F
.668 .662 .835 r
.48791 .83247 m .48511 .83017 L .48931 .83125 L F
.668 .955 .724 r
.49063 .82986 m .48791 .83247 L .48931 .83125 L F
.807 .94 .915 r
.49063 .82986 m .49006 .83211 L .48799 .83239 L F
.617 .114 .034 r
.48913 .83251 m .49006 .83211 L .48973 .83215 L F
.623 .205 .228 r
.49277 .83136 m .48913 .83251 L .49072 .83157 L F
.362 0 0 r
.47697 .88322 m .47644 .8829 L .47856 .88402 L F
.561 .102 .12 r
.47438 .8829 m .47605 .88266 L .47644 .8829 L F
.303 .736 .969 r
.47438 .8829 m .47644 .8829 L .47522 .88234 L F
.362 0 0 r
.47522 .88234 m .47644 .8829 L .47697 .88322 L F
.561 .102 .12 r
.47605 .88266 m .47755 .88245 L .47644 .8829 L F
.505 0 0 r
.47755 .88245 m .47966 .88306 L .47644 .8829 L F
.676 .538 .69 r
.53707 .85985 m .53777 .86255 L .53986 .85993 L F
.538 .444 .696 r
.36665 .74811 m .36752 .75138 L .36529 .75163 L F
.56 .446 .68 r
.36766 .75337 m .36529 .75163 L .36752 .75138 L F
.36766 .75337 m .36568 .75374 L .36529 .75163 L F
.869 .64 .591 r
.5655 .83142 m .56328 .83342 L .56411 .83088 L F
.5655 .83142 m .56581 .83346 L .56328 .83342 L F
.56 .387 .604 r
.56806 .82884 m .56832 .83224 L .5655 .83142 L F
.695 .566 .705 r
.49667 .84699 m .49731 .84966 L .4994 .84705 L F
.587 .288 .428 r
.50751 .8239 m .50524 .82513 L .50578 .82337 L F
.377 0 .093 r
.43831 .88799 m .43964 .88865 L .43751 .88886 L F
.43831 .88799 m .44036 .88772 L .43964 .88865 L F
.661 .642 .821 r
.65651 .75172 m .65358 .75295 L .65302 .75061 L F
0 0 0 r
.40769 .88236 m .40835 .88227 L .40963 .88259 L F
.40769 .88236 m .40703 .88331 L .40835 .88227 L F
.79 .589 .629 r
.63919 .75477 m .63813 .75613 L .63913 .75349 L F
.929 .622 .44 r
.49245 .8716 m .49392 .8735 L .49279 .87347 L F
.917 .586 .4 r
.4924 .87346 m .49279 .87347 L .49317 .87488 L F
.49279 .87347 m .49392 .8735 L .49317 .87488 L F
.611 .41 .585 r
.49285 .87382 m .49279 .87347 L .49195 .8708 L F
.49279 .87347 m .49237 .8712 L .49211 .87095 L F
.49279 .87347 m .49211 .87095 L .49195 .8708 L F
.105 .378 .838 r
.49407 .8728 m .49392 .8735 L .49245 .8716 L F
.611 .41 .585 r
.49246 .87161 m .49407 .8728 L .49237 .8712 L F
.105 .378 .838 r
.49407 .8728 m .49245 .8716 L .4921 .87116 L F
.611 .41 .585 r
.49317 .87488 m .49407 .8728 L .49246 .87161 L F
.49317 .87488 m .49237 .8712 L .49285 .87382 L F
.929 .622 .44 r
.4921 .87116 m .49245 .8716 L .4924 .87346 L F
.49245 .8716 m .49279 .87347 L .4924 .87346 L F
.778 .851 .401 r
.49317 .87488 m .49392 .8735 L .49407 .8728 L F
.632 .219 .243 r
.49317 .87488 m .49663 .8748 L .49392 .8735 L F
.728 .644 .764 r
.53579 .80806 m .53693 .80867 L .53388 .80799 L F
.549 .672 .919 r
.53856 .80732 m .53693 .80867 L .53579 .80806 L F
.48 .541 .841 r
.53856 .80732 m .53988 .80984 L .53693 .80867 L F
.292 .786 .757 r
.51995 .80779 m .51799 .80843 L .51703 .80864 L F
.465 .798 .999 r
.58036 .79791 m .5826 .7977 L .58159 .79705 L F
.58036 .79791 m .5826 .7977 L .58159 .79705 L F
.261 0 0 r
.37667 .8312 m .37912 .83074 L .37728 .83079 L F
.421 0 .06 r
.4617 .81776 m .46507 .81625 L .46312 .81673 L F
.743 .63 .735 r
.56581 .83346 m .56733 .83475 L .56548 .83643 L F
.558 .63 .879 r
.64952 .75631 m .64669 .75482 L .64875 .75381 L F
.683 .465 .584 r
.64952 .75631 m .65 .75858 L .64667 .75883 L F
.746 .612 .71 r
.65205 .75637 m .65 .75858 L .64952 .75631 L F
0 0 0 r
.41255 .89581 m .41394 .89563 L .41207 .89618 L F
.41255 .89581 m .41342 .89559 L .41394 .89563 L F
.632 .714 .906 r
.56606 .78347 m .56748 .78138 L .56528 .78186 L F
.56606 .78347 m .56858 .78322 L .56748 .78138 L F
.51 .314 .551 r
.37064 .76645 m .3686 .76891 L .36885 .76701 L F
.453 .041 .167 r
.43452 .83368 m .43334 .83582 L .43079 .83592 L F
.518 .107 .2 r
.43533 .83559 m .43452 .83368 L .43669 .83347 L F
.43533 .83559 m .43334 .83582 L .43452 .83368 L F
.768 .962 .658 r
.60874 .77978 m .60671 .78195 L .60822 .77964 L F
.549 .931 .876 r
.60874 .77978 m .60822 .77964 L .60981 .7788 L F
.534 .408 .656 r
.61104 .78191 m .60874 .77978 L .61092 .77949 L F
.61104 .78191 m .6089 .78254 L .60874 .77978 L F
.49 0 0 r
.48646 .88707 m .48589 .88635 L .48823 .88755 L F
.544 .292 .484 r
.46312 .82895 m .46309 .83119 L .46061 .83102 L F
.678 .401 .494 r
.46508 .83097 m .46309 .83119 L .46312 .82895 L F
.793 .576 .606 r
.63301 .75829 m .63642 .75871 L .63598 .75648 L F
.357 .286 .638 r
.63642 .75871 m .63855 .75911 L .63598 .75648 L F
.63642 .75871 m .63855 .75911 L .63598 .75648 L F
.347 .223 .565 r
.53012 .83044 m .52847 .83246 L .52985 .82861 L F
0 0 0 r
.5278 .83362 m .53012 .83044 L .53017 .83171 L F
.224 .324 .757 r
.52985 .82861 m .53198 .83066 L .53012 .83044 L F
.274 0 .284 r
.53198 .83066 m .53017 .83171 L .53012 .83044 L F
.502 .085 .181 r
.41175 .88233 m .41373 .88252 L .4151 .88074 L F
0 0 0 r
.4151 .88074 m .41538 .88154 L .41713 .88058 L F
.4151 .88074 m .41373 .88252 L .41538 .88154 L F
.512 .017 .019 r
.40391 .84184 m .40311 .84273 L .40059 .84217 L F
.377 0 0 r
.40594 .84388 m .40391 .84184 L .40587 .84142 L F
.40594 .84388 m .40311 .84273 L .40391 .84184 L F
.723 .699 .827 r
.64669 .75482 m .64165 .75527 L .64551 .75608 L F
0 0 0 r
.64669 .75482 m .6473 .75458 L .64875 .75381 L F
.64669 .75482 m .64551 .75608 L .6473 .75458 L F
.455 .11 .291 r
.38428 .84699 m .38264 .84909 L .38071 .84937 L F
.714 .425 .486 r
.38585 .84904 m .38428 .84699 L .38596 .8472 L F
.38585 .84904 m .38264 .84909 L .38428 .84699 L F
.59 .927 .96 r
.39025 .88695 m .38971 .8879 L .38839 .88789 L F
.39025 .88695 m .39131 .88714 L .38971 .8879 L F
.203 .681 .934 r
.46898 .8715 m .46707 .87146 L .46567 .87079 L F
.594 .467 .677 r
.56999 .78816 m .57221 .78784 L .57212 .78463 L F
.464 .166 .374 r
.56999 .78816 m .57173 .78926 L .57221 .78784 L F
.56999 .78816 m .57004 .79002 L .57173 .78926 L F
.743 .63 .735 r
.56581 .83346 m .56548 .83643 L .56387 .83641 L F
.844 .507 .417 r
.56548 .83643 m .56536 .83872 L .56387 .83641 L F
.56548 .83643 m .56709 .83897 L .56536 .83872 L F
.994 .872 .554 r
.48747 .82287 m .48807 .82408 L .48855 .82212 L F
.635 .261 .318 r
.49058 .82138 m .48747 .82287 L .48855 .82212 L F
.291 0 .193 r
.44246 .8703 m .43977 .87287 L .44163 .87271 L F
.496 .135 .283 r
.44366 .87227 m .44246 .8703 L .44163 .87271 L F
.44366 .87227 m .44455 .87018 L .44246 .8703 L F
.463 .24 .489 r
.65944 .75576 m .65982 .75839 L .65777 .75894 L F
.444 .223 .483 r
.66214 .75285 m .66187 .75586 L .65944 .75576 L F
.411 .186 .459 r
.66187 .75586 m .65982 .75839 L .65944 .75576 L F
.36 0 0 r
.44586 .88607 m .44657 .88703 L .44452 .88716 L F
.44586 .88607 m .44808 .8861 L .44657 .88703 L F
.643 .802 .959 r
.5588 .79906 m .55928 .80028 L .55604 .79998 L F
.762 .653 .741 r
.55928 .80028 m .55711 .80301 L .55604 .79998 L F
.639 .473 .642 r
.55928 .80028 m .55977 .80279 L .55711 .80301 L F
.527 .729 .966 r
.55995 .7995 m .56137 .80004 L .55987 .80022 L F
.364 .288 .636 r
.56109 .80246 m .55928 .80028 L .56137 .80004 L F
.743 .681 .79 r
.55973 .79899 m .56137 .80004 L .5588 .79906 L F
.845 .606 .578 r
.55973 .79899 m .56109 .80246 L .56137 .80004 L F
.07 .27 .759 r
.5612 .79858 m .56231 .80121 L .55998 .7992 L F
.56002 .79891 m .55998 .7992 L .55973 .79899 L F
.5612 .79858 m .55998 .7992 L .56002 .79891 L F
.527 .729 .966 r
.5588 .79906 m .55995 .7995 L .55928 .80028 L F
.55995 .7995 m .55987 .80022 L .55928 .80028 L F
.364 .288 .636 r
.56109 .80246 m .55977 .80279 L .55928 .80028 L F
.78 .787 .859 r
.57589 .77954 m .57342 .78215 L .57292 .77937 L F
.591 .292 .429 r
.38827 .84741 m .38585 .84904 L .38596 .8472 L F
.223 0 .009 r
.45307 .87263 m .45127 .87318 L .4498 .87504 L F
.452 .202 .444 r
.40059 .84217 m .39841 .84413 L .39874 .84292 L F
.265 0 0 r
.4259 .82124 m .42789 .821 L .429 .82028 L F
.397 0 0 r
.429 .82028 m .42789 .821 L .43116 .82032 L F
.189 .227 .67 r
.54861 .82049 m .54734 .8214 L .54691 .81834 L F
.269 .29 .698 r
.5492 .82321 m .54734 .8214 L .54861 .82049 L F
.5492 .82321 m .54823 .82378 L .54734 .8214 L F
0 0 0 r
.52526 .80554 m .52639 .80481 L .52747 .80257 L F
.152 0 .095 r
.52747 .80257 m .52806 .8033 L .52953 .80263 L F
.52747 .80257 m .52639 .80481 L .52806 .8033 L F
.415 .507 .844 r
.35465 .72782 m .3549 .72789 L .35473 .72799 L F
0 0 0 r
.35473 .72799 m .3549 .72789 L .35464 .72803 L F
.569 .353 .547 r
.36705 .7695 m .36631 .77125 L .36428 .77195 L F
.516 .297 .52 r
.36875 .77072 m .36705 .7695 L .3686 .76891 L F
.36875 .77072 m .36631 .77125 L .36705 .7695 L F
.369 0 0 r
.35314 .72257 m .3541 .72265 L .35352 .72252 L F
.476 .515 .818 r
.44741 .87269 m .44568 .8729 L .44455 .87018 L F
.593 .301 .442 r
.53174 .81298 m .53414 .81304 L .53429 .8109 L F
.333 .092 .391 r
.53429 .8109 m .53573 .81228 L .53518 .81034 L F
.53429 .8109 m .53414 .81304 L .53573 .81228 L F
.757 .254 .014 r
.49195 .8708 m .49407 .8728 L .4921 .87116 L F
.346 0 0 r
.39738 .82693 m .39899 .82729 L .4004 .82602 L F
.431 0 .051 r
.39899 .82729 m .40248 .82585 L .4004 .82602 L F
.223 0 0 r
.42291 .89224 m .42546 .89105 L .4248 .89204 L F
.378 0 .063 r
.42546 .89105 m .42637 .89188 L .4248 .89204 L F
.42546 .89105 m .42758 .89069 L .42637 .89188 L F
.427 0 0 r
.44174 .83246 m .44075 .83354 L .43862 .83357 L F
.509 .029 .052 r
.44398 .83322 m .44075 .83354 L .44174 .83246 L F
.393 0 0 r
.44523 .83325 m .44398 .83322 L .44174 .83246 L F
.614 .441 .625 r
.63161 .76145 m .62931 .7634 L .62879 .76132 L F
.217 0 0 r
.52223 .8065 m .52465 .80613 L .52526 .80554 L F
.759 .652 .744 r
.574 .79502 m .57693 .79542 L .57604 .79245 L F
.717 .319 .293 r
.57622 .79688 m .57693 .79542 L .574 .79502 L F
.447 .378 .687 r
.57799 .79468 m .57693 .79542 L .57686 .79328 L F
.57854 .79537 m .57693 .79542 L .57799 .79468 L F
.514 .505 .784 r
.57854 .7943 m .57693 .79542 L .57867 .79439 L F
.57604 .79245 m .57693 .79542 L .57854 .7943 L F
.439 .502 .827 r
.57693 .79542 m .57972 .79745 L .57854 .79537 L F
.088 0 0 r
.48296 .8106 m .48566 .81021 L .48379 .81035 L F
.771 .523 .56 r
.41907 .87997 m .42209 .8781 L .42165 .87811 L F
.41907 .87997 m .42234 .8804 L .42209 .8781 L F
.327 .811 .862 r
.40774 .89768 m .40815 .89729 L .40654 .89761 L F
.40774 .89768 m .40956 .89725 L .40815 .89729 L F
.928 .721 .602 r
.55604 .79998 m .55711 .80301 L .55588 .80312 L F
.876 .535 .401 r
.55588 .80312 m .55711 .80301 L .55604 .80464 L F
.892 .56 .412 r
.55604 .80464 m .55711 .80301 L .5572 .80473 L F
.74 .551 .639 r
.55977 .80279 m .5572 .80473 L .55711 .80301 L F
.152 .653 .909 r
.36534 .7448 m .36873 .7455 L .36671 .74599 L F
.603 .429 .619 r
.36889 .7477 m .36671 .74599 L .36873 .7455 L F
.36889 .7477 m .36665 .74811 L .36671 .74599 L F
.72 .562 .675 r
.51293 .82127 m .50948 .82377 L .51179 .82102 L F
.51293 .82127 m .51288 .82373 L .50948 .82377 L F
.626 .893 .987 r
.51537 .82061 m .51293 .82127 L .51382 .82013 L F
.637 .909 .982 r
.51293 .82127 m .51179 .82102 L .51382 .82013 L F
.622 .454 .634 r
.51537 .82061 m .51288 .82373 L .51293 .82127 L F
0 .408 .69 r
.35411 .72766 m .3549 .72789 L .35465 .72782 L F
.168 .706 .775 r
.51252 .8729 m .51041 .87322 L .50943 .87325 L F
.395 .08 .309 r
.36631 .77125 m .36365 .77396 L .36428 .77195 L F
.708 .643 .782 r
.48293 .87254 m .48392 .87554 L .48218 .87473 L F
0 0 .508 r
.48423 .87504 m .48392 .87554 L .48293 .87254 L F
.519 .096 .177 r
.48721 .87523 m .48392 .87554 L .48614 .87542 L F
.636 .403 .547 r
.48585 .87788 m .48614 .87542 L .48392 .87554 L F
0 .192 .716 r
.48549 .87638 m .48392 .87554 L .48423 .87504 L F
.48549 .87638 m .48585 .87788 L .48392 .87554 L F
.546 .605 .864 r
.53856 .80732 m .53579 .80806 L .53485 .80487 L F
.126 0 0 r
.5295 .80951 m .52895 .80895 L .53058 .80818 L F
.5295 .80951 m .5274 .81012 L .52895 .80895 L F
.276 .024 .338 r
.51985 .86781 m .51784 .87049 L .51972 .86978 L F
.596 .331 .485 r
.52197 .86977 m .51985 .86781 L .51972 .86978 L F
.52197 .86977 m .52199 .86774 L .51985 .86781 L F
.728 .344 .323 r
.65194 .75849 m .65515 .75914 L .65487 .76041 L F
.502 .131 .268 r
.65515 .75914 m .65701 .76022 L .65487 .76041 L F
.51 .119 .235 r
.65515 .75914 m .65777 .75894 L .65701 .76022 L F
.614 .057 0 r
.53482 .81703 m .53155 .81567 L .53302 .81647 L F
.613 .417 .592 r
.62931 .7634 m .62976 .76625 L .62687 .76644 L F
.614 .441 .625 r
.63161 .76145 m .6317 .76377 L .62931 .7634 L F
.626 .425 .591 r
.63197 .76602 m .62931 .7634 L .6317 .76377 L F
.63197 .76602 m .62976 .76625 L .62931 .7634 L F
.768 .808 .885 r
.39591 .8844 m .39705 .88549 L .39385 .88565 L F
.657 .841 .971 r
.39789 .8839 m .39705 .88549 L .39591 .8844 L F
.39789 .8839 m .39959 .88475 L .39705 .88549 L F
.078 0 0 r
.41342 .89559 m .416 .89536 L .41394 .89563 L F
.41342 .89559 m .41663 .89472 L .416 .89536 L F
.49 .193 .388 r
.56889 .81079 m .56885 .80921 L .56664 .81092 L F
.386 .117 .378 r
.57017 .81007 m .56885 .80921 L .56889 .81079 L F
.541 .198 .336 r
.49601 .81886 m .49482 .82098 L .49267 .82101 L F
.391 .042 .249 r
.49655 .82046 m .49601 .81886 L .49787 .81865 L F
.49655 .82046 m .49482 .82098 L .49601 .81886 L F
.847 .507 .41 r
.47896 .829 m .47719 .82869 L .47568 .82615 L F
.8 .807 .319 r
.47896 .829 m .47829 .8307 L .47834 .83117 L F
.101 0 .043 r
.47989 .83004 m .47896 .829 L .48117 .82922 L F
.47989 .83004 m .47829 .8307 L .47896 .829 L F
.604 .639 .859 r
.35797 .74344 m .35922 .74325 L .35803 .74354 L F
.208 .724 .688 r
.39511 .90116 m .39703 .90059 L .39604 .90087 L F
0 0 0 r
.39435 .90176 m .39511 .90116 L .39604 .90087 L F
.976 .719 .48 r
.57577 .83927 m .57564 .84142 L .57458 .8388 L F
.689 .521 .655 r
.57792 .83875 m .57564 .84142 L .57577 .83927 L F
.715 .838 .94 r
.35464 .72803 m .3549 .72789 L .35411 .72766 L F
.527 .816 .999 r
.37238 .7562 m .37188 .75734 L .37056 .75616 L F
.37238 .7562 m .37378 .75699 L .37188 .75734 L F
.611 .595 .81 r
.37442 .75823 m .37188 .75734 L .37378 .75699 L F
.521 .306 .528 r
.61597 .77436 m .61533 .77691 L .61343 .77729 L F
.579 .402 .606 r
.61814 .772 m .61796 .774 L .61597 .77436 L F
.581 .363 .549 r
.61748 .77598 m .61597 .77436 L .61796 .774 L F
.61748 .77598 m .61533 .77691 L .61597 .77436 L F
.587 .288 .428 r
.50751 .8239 m .50737 .82536 L .50524 .82513 L F
.563 .18 .274 r
.50651 .8207 m .50878 .82141 L .50829 .82108 L F
.636 .704 .896 r
.50821 .82137 m .50751 .8239 L .50651 .8207 L F
.50821 .82137 m .50948 .82377 L .50751 .8239 L F
.563 .18 .274 r
.50651 .8207 m .5085 .82149 L .50878 .82141 L F
.636 .704 .896 r
.50829 .82108 m .50841 .82136 L .50821 .82137 L F
.50841 .82136 m .50948 .82377 L .50821 .82137 L F
.563 .18 .274 r
.50821 .82137 m .50502 .82241 L .5085 .82149 L F
.50651 .8207 m .50584 .82147 L .50821 .82137 L F
.50584 .82147 m .50502 .82241 L .50821 .82137 L F
.636 .704 .896 r
.50829 .82108 m .50821 .82137 L .50651 .8207 L F
.64 .334 .436 r
.50751 .8239 m .50961 .82574 L .50737 .82536 L F
.615 .342 .481 r
.50948 .82377 m .50961 .82574 L .50751 .8239 L F
0 .022 .56 r
.52029 .81494 m .51911 .81408 L .52124 .81329 L F
.661 .532 .696 r
.48447 .84376 m .48787 .84502 L .48699 .84327 L F
.477 .042 .133 r
.46309 .83119 m .45954 .83221 L .46061 .83102 L F
.492 .109 .24 r
.45952 .88343 m .46076 .88126 L .46251 .88201 L F
.474 .419 .715 r
.63105 .75861 m .63356 .75944 L .63301 .75829 L F
.63105 .75861 m .63169 .76025 L .63356 .75944 L F
.443 0 .082 r
.4112 .83945 m .40992 .84089 L .40791 .84088 L F
.462 0 .023 r
.41343 .83989 m .40992 .84089 L .4112 .83945 L F
0 0 0 r
.50755 .87334 m .50546 .87393 L .50386 .87475 L F
.586 .452 .665 r
.36001 .74285 m .35797 .74344 L .35701 .74065 L F
.36001 .74285 m .35922 .74325 L .35797 .74344 L F
.763 .493 .526 r
.6422 .75859 m .6414 .76092 L .64014 .75963 L F
.64192 .7586 m .64014 .75963 L .63924 .75871 L F
.6422 .75859 m .64014 .75963 L .64192 .7586 L F
.521 .487 .76 r
.63924 .75871 m .6414 .76092 L .64018 .75845 L F
.689 .566 .711 r
.64018 .75845 m .63965 .75991 L .63855 .75911 L F
.63965 .75991 m .63926 .76101 L .63899 .76029 L F
.63965 .75991 m .63899 .76029 L .63855 .75911 L F
.664 .519 .676 r
.64349 .75833 m .6414 .76092 L .6422 .75859 L F
.235 .519 .913 r
.48444 .86799 m .48802 .87039 L .48682 .86914 L F
.913 .656 .535 r
.56666 .82907 m .56832 .83224 L .56806 .82884 L F
.713 .747 .879 r
.3535 .72301 m .3541 .72265 L .35314 .72257 L F
.811 .992 .872 r
.50813 .88211 m .50948 .88196 L .51126 .88014 L F
.358 0 0 r
.38528 .83052 m .38478 .8293 L .38325 .83064 L F
.38528 .83052 m .38685 .82915 L .38478 .8293 L F
.869 .763 .743 r
.56328 .83342 m .56581 .83346 L .56387 .83641 L F
.624 .614 .82 r
.58182 .78228 m .57897 .78036 L .5815 .77975 L F
.426 .458 .79 r
.58346 .78143 m .58182 .78228 L .5815 .77975 L F
.603 .447 .642 r
.58442 .78412 m .58182 .78228 L .58346 .78143 L F
.58442 .78412 m .58229 .7846 L .58182 .78228 L F
.58 .171 .231 r
.53827 .81555 m .53696 .81746 L .53482 .81703 L F
.636 .185 .163 r
.53827 .81555 m .53916 .81732 L .53696 .81746 L F
.53827 .81555 m .54027 .81644 L .53916 .81732 L F
.566 .42 .642 r
.66412 .75078 m .66373 .75151 L .66214 .75285 L F
.47 .245 .49 r
.66382 .75538 m .66214 .75285 L .66373 .75151 L F
.66382 .75538 m .66187 .75586 L .66214 .75285 L F
.387 0 .013 r
.40971 .82535 m .4118 .82523 L .41324 .82382 L F
.525 .123 .221 r
.4118 .82523 m .41523 .82348 L .41324 .82382 L F
.683 .446 .558 r
.64018 .75845 m .64349 .75833 L .64165 .75527 L F
0 0 0 r
.64349 .75833 m .64551 .75608 L .64165 .75527 L F
.501 .27 .495 r
.58411 .82896 m .58646 .82884 L .58505 .82797 L F
.58411 .82896 m .58398 .83099 L .58646 .82884 L F
.58646 .82884 m .58398 .83099 L .58411 .82896 L F
.648 .385 .508 r
.62289 .76199 m .62618 .76144 L .62593 .75947 L F
.742 .218 0 r
.6279 .76192 m .62593 .75947 L .62618 .76144 L F
.6279 .76192 m .62767 .76144 L .62593 .75947 L F
.384 0 0 r
.53388 .80799 m .53278 .80842 L .53058 .80818 L F
0 0 .57 r
.53388 .80799 m .53518 .81034 L .53519 .80933 L F
.53388 .80799 m .53519 .80933 L .53278 .80842 L F
.52 .824 1 r
.51749 .8643 m .51667 .86542 L .51887 .86497 L F
.51749 .8643 m .51667 .86542 L .51887 .86497 L F
.416 .855 .752 r
.51609 .87114 m .51436 .87201 L .51534 .87135 L F
.28 0 0 r
.51536 .87135 m .51609 .87114 L .51534 .87135 L F
.054 0 0 r
.5169 .8709 m .51436 .87201 L .51609 .87114 L F
.28 0 0 r
.51745 .8716 m .51609 .87114 L .51536 .87135 L F
.054 0 0 r
.51784 .87049 m .5169 .8709 L .51609 .87114 L F
.258 .751 .671 r
.51972 .86978 m .51784 .87049 L .51609 .87114 L F
.188 0 0 r
.44397 .81923 m .44585 .81935 L .44707 .81894 L F
.486 0 0 r
.44585 .81935 m .44862 .81928 L .44707 .81894 L F
.593 .407 .599 r
.63388 .76126 m .6317 .76377 L .63161 .76145 L F
.414 0 .014 r
.43316 .82075 m .43524 .82072 L .43662 .81955 L F
.431 0 .027 r
.43662 .81955 m .43524 .82072 L .43829 .82003 L F
.443 0 0 r
.41659 .83926 m .41557 .84038 L .41343 .83989 L F
.707 .406 .465 r
.41859 .83874 m .41557 .84038 L .41659 .83926 L F
.622 .454 .634 r
.51537 .82061 m .51563 .82356 L .51288 .82373 L F
0 0 .367 r
.51554 .82068 m .51537 .82061 L .51382 .82013 L F
.51554 .82068 m .51667 .82322 L .51537 .82061 L F
.284 .204 .586 r
.51667 .82322 m .51563 .82356 L .51537 .82061 L F
.846 .998 .81 r
.64875 .75381 m .65015 .75134 L .65113 .75162 L F
.64875 .75381 m .6483 .75342 L .65015 .75134 L F
.878 .993 .771 r
.64875 .75381 m .6473 .75458 L .6483 .75342 L F
.506 .141 .28 r
.47239 .81557 m .47456 .81552 L .47562 .81336 L F
.446 .105 .293 r
.47456 .81552 m .47756 .81284 L .47562 .81336 L F
.592 .414 .609 r
.62003 .77353 m .61814 .772 L .62033 .77164 L F
.62003 .77353 m .61796 .774 L .61814 .772 L F
.439 .026 .157 r
.4366 .87655 m .43531 .87574 L .43461 .87687 L F
.4366 .87655 m .43745 .87564 L .43531 .87574 L F
.201 0 .037 r
.47568 .82615 m .47453 .82795 L .47308 .8282 L F
.844 .507 .416 r
.47568 .82615 m .47719 .82869 L .47453 .82795 L F
.757 .608 .693 r
.58579 .78685 m .58229 .7846 L .58442 .78412 L F
.58579 .78685 m .58208 .7867 L .58229 .7846 L F
.754 .651 .747 r
.58579 .78685 m .58356 .78794 L .58208 .7867 L F
.551 .513 .766 r
.58746 .78482 m .58579 .78685 L .58442 .78412 L F
.58746 .78482 m .58791 .78688 L .58579 .78685 L F
.57 .331 .515 r
.61343 .77729 m .61321 .77924 L .61092 .77949 L F
.522 .29 .504 r
.61524 .7788 m .61343 .77729 L .61533 .77691 L F
.61524 .7788 m .61321 .77924 L .61343 .77729 L F
.506 .284 .511 r
.66605 .74804 m .6662 .75045 L .66412 .75078 L F
.513 .359 .608 r
.66793 .74562 m .66798 .74766 L .66605 .74804 L F
.543 .337 .552 r
.66798 .74766 m .6662 .75045 L .66605 .74804 L F
.31 0 .147 r
.60833 .78381 m .6089 .78254 L .61104 .78191 L F
.33 .536 .903 r
.36379 .74274 m .36286 .744 L .36203 .7426 L F
.36379 .74274 m .36534 .7448 L .36286 .744 L F
.643 .19 .162 r
.4755 .8721 m .47208 .87167 L .47436 .87138 L F
.81 .322 0 r
.47473 .87215 m .4755 .8721 L .47436 .87138 L F
.87 .45 .215 r
.47597 .87463 m .4755 .8721 L .47473 .87215 L F
.47597 .87463 m .47736 .875 L .4755 .8721 L F
.491 .103 .232 r
.51288 .82373 m .50961 .82574 L .50948 .82377 L F
.51288 .82373 m .5118 .82571 L .50961 .82574 L F
.712 .343 .349 r
.51288 .82373 m .51487 .82581 L .5118 .82571 L F
.602 .361 .524 r
.51563 .82356 m .51487 .82581 L .51288 .82373 L F
.708 .643 .782 r
.48293 .87254 m .48218 .87473 L .48041 .87425 L F
.479 .05 .147 r
.46507 .81625 m .46672 .81699 L .46813 .81538 L F
.296 0 0 r
.46672 .81699 m .47033 .81578 L .46813 .81538 L F
.627 .656 .859 r
.6716 .7428 m .67282 .74296 L .6715 .74308 L F
.481 .211 .426 r
.67282 .74296 m .67034 .7451 L .67058 .74316 L F
.67282 .74296 m .6726 .74471 L .67034 .7451 L F
.542 .349 .568 r
.67289 .74293 m .67287 .74302 L .67282 .74296 L F
.67287 .74302 m .6726 .74471 L .67281 .74302 L F
.67287 .74302 m .67281 .74302 L .67282 .74296 L F
.67301 .74297 m .6726 .74471 L .67289 .74293 L F
.67348 .74336 m .6726 .74471 L .67304 .74285 L F
.6737 .74302 m .67478 .74455 L .6726 .74471 L F
.67394 .74265 m .67434 .74289 L .6737 .74302 L F
.67422 .74245 m .67434 .74289 L .67394 .74265 L F
.67434 .74289 m .67478 .74455 L .6737 .74302 L F
.498 .379 .649 r
.67652 .74168 m .67478 .74455 L .67422 .74245 L F
.161 0 0 r
.67424 .74243 m .67424 .74244 L .67456 .74225 L F
.498 .379 .649 r
.67476 .74213 m .67456 .74225 L .67418 .74229 L F
.67456 .74225 m .67421 .74243 L .67418 .74229 L F
.544 .582 .844 r
.67327 .74293 m .6733 .74297 L .67456 .74225 L F
.542 .349 .568 r
.67408 .74244 m .67422 .74245 L .67394 .74265 L F
.67418 .74229 m .67421 .74243 L .67408 .74244 L F
.521 .547 .823 r
.67376 .74082 m .67418 .74229 L .67282 .74296 L F
.544 .582 .844 r
.67299 .74247 m .67327 .74293 L .6742 .74243 L F
.542 .349 .568 r
.67421 .74243 m .67422 .74245 L .67408 .74244 L F
.521 .547 .823 r
.67376 .74082 m .67282 .74296 L .67215 .74113 L F
.466 .51 .82 r
.67376 .74082 m .67456 .74171 L .67418 .74229 L F
.67491 .74118 m .6748 .74212 L .67418 .74229 L F
.544 .582 .844 r
.67215 .74113 m .67482 .742 L .67376 .74082 L F
.67482 .742 m .67494 .74204 L .67376 .74082 L F
.461 .513 .826 r
.67494 .74204 m .67652 .74168 L .67376 .74082 L F
.466 .51 .82 r
.67376 .74082 m .67491 .74118 L .67456 .74171 L F
.544 .582 .844 r
.67482 .742 m .67481 .74206 L .67494 .74204 L F
.466 .51 .82 r
.67491 .74118 m .67652 .74168 L .6748 .74212 L F
.544 .582 .844 r
.67215 .74113 m .67299 .74247 L .67481 .74206 L F
.67215 .74113 m .67481 .74206 L .67482 .742 L F
.67299 .74247 m .6742 .74243 L .67494 .74204 L F
.67327 .74293 m .67456 .74225 L .67494 .74204 L F
.498 .379 .649 r
.67456 .74225 m .67422 .74245 L .67421 .74243 L F
.67652 .74168 m .67422 .74245 L .67476 .74213 L F
.161 0 0 r
.67456 .74225 m .67335 .74394 L .67494 .74204 L F
.67424 .74244 m .67335 .74394 L .67456 .74225 L F
.542 .349 .568 r
.67418 .74229 m .67394 .74265 L .67304 .74285 L F
.67394 .74265 m .67348 .74336 L .67323 .74307 L F
.161 0 0 r
.6733 .74297 m .6733 .74302 L .67424 .74243 L F
.6733 .74302 m .67394 .74265 L .67424 .74243 L F
.6733 .74297 m .67322 .74302 L .6733 .74302 L F
.312 0 0 r
.67318 .74301 m .67322 .74302 L .6733 .74297 L F
.67318 .74301 m .6733 .74297 L .67312 .74295 L F
.542 .349 .568 r
.67394 .74265 m .67323 .74307 L .67304 .74285 L F
.161 0 0 r
.6733 .74302 m .67331 .7431 L .67394 .74265 L F
.67331 .7431 m .67335 .74394 L .67424 .74243 L F
.67331 .7431 m .67132 .74435 L .67335 .74394 L F
.6733 .74302 m .67313 .74314 L .67331 .7431 L F
.67313 .74314 m .67132 .74435 L .67331 .7431 L F
.67322 .74302 m .67132 .74435 L .6733 .74302 L F
.312 0 0 r
.66915 .74445 m .67132 .74435 L .67322 .74302 L F
.66915 .74445 m .67322 .74302 L .67318 .74301 L F
.542 .349 .568 r
.67304 .74285 m .67301 .74297 L .67289 .74293 L F
.312 0 0 r
.66915 .74445 m .67318 .74301 L .6716 .7428 L F
.627 .656 .859 r
.67277 .74282 m .67282 .74296 L .6716 .7428 L F
.312 0 0 r
.67318 .74301 m .67312 .74295 L .6716 .7428 L F
.67088 .74278 m .6716 .7428 L .66988 .74262 L F
.571 .595 .838 r
.66988 .74262 m .6716 .7428 L .67215 .74113 L F
.627 .656 .859 r
.67215 .74113 m .67088 .74278 L .66988 .74262 L F
.67088 .74278 m .67058 .74316 L .66988 .74262 L F
.312 0 0 r
.66983 .74276 m .67088 .74278 L .66988 .74262 L F
.66915 .74445 m .6716 .7428 L .66983 .74276 L F
.627 .656 .859 r
.67215 .74113 m .67277 .74282 L .6716 .7428 L F
.67215 .74113 m .6715 .74308 L .67058 .74316 L F
.571 .595 .838 r
.6716 .7428 m .6733 .74297 L .67215 .74113 L F
.352 0 .087 r
.46022 .87256 m .45864 .87096 L .45635 .87232 L F
.46022 .87256 m .46055 .87063 L .45864 .87096 L F
0 0 .187 r
.47829 .8307 m .47685 .83316 L .47834 .83117 L F
.421 0 0 r
.43829 .82003 m .44041 .82012 L .44163 .81916 L F
.342 0 0 r
.44041 .82012 m .44397 .81923 L .44163 .81916 L F
.631 .404 .555 r
.50848 .81583 m .51071 .81799 L .50856 .81806 L F
.617 .405 .572 r
.51032 .81562 m .51071 .81799 L .50848 .81583 L F
.506 .393 .66 r
.52223 .82968 m .52277 .83247 L .52444 .83152 L F
.676 .417 .523 r
.48614 .87542 m .48902 .87536 L .48721 .87523 L F
.049 0 .281 r
.54769 .82609 m .54823 .82378 L .5492 .82321 L F
.121 0 0 r
.43551 .88914 m .43584 .88965 L .43383 .88995 L F
.43551 .88914 m .43751 .88886 L .43584 .88965 L F
.387 .057 .28 r
.51832 .87519 m .52109 .87317 L .52032 .87533 L F
.372 .044 .274 r
.52032 .87533 m .52109 .87317 L .52301 .8725 L F
.591 .292 .429 r
.38827 .84741 m .38785 .84935 L .38585 .84904 L F
.726 .421 .463 r
.39112 .8492 m .38827 .84741 L .39128 .84729 L F
.39112 .8492 m .38785 .84935 L .38827 .84741 L F
.505 .046 .097 r
.62767 .76144 m .62978 .76223 L .63169 .76025 L F
.577 .234 .351 r
.62978 .76223 m .63356 .75944 L .63169 .76025 L F
.696 .67 .82 r
.57819 .77861 m .57897 .78036 L .57589 .77954 L F
.635 .672 .868 r
.5799 .77838 m .57897 .78036 L .57819 .77861 L F
.5799 .77838 m .5815 .77975 L .57897 .78036 L F
.275 .455 .857 r
.54792 .81729 m .54691 .81834 L .54534 .81574 L F
.119 .204 .678 r
.54861 .82049 m .54691 .81834 L .54792 .81729 L F
.527 .492 .76 r
.56951 .77879 m .56858 .78322 L .56737 .77919 L F
.455 .578 .888 r
.56858 .78322 m .56948 .78117 L .56748 .78138 L F
.481 .899 .863 r
.39893 .90008 m .40258 .8988 L .40143 .89912 L F
.287 .78 .732 r
.40143 .89912 m .40258 .8988 L .40447 .89814 L F
.592 .092 .034 r
.50646 .80737 m .50829 .80788 L .5097 .8074 L F
.617 .126 .064 r
.50829 .80788 m .51125 .80809 L .5097 .8074 L F
.96 .684 .469 r
.58505 .82797 m .58598 .82507 L .58664 .82595 L F
.599 .666 .886 r
.40239 .88592 m .39959 .88475 L .40122 .88485 L F
.231 .597 .95 r
.40303 .8852 m .40239 .88592 L .40122 .88485 L F
.363 .773 .981 r
.40303 .8852 m .40442 .88577 L .40239 .88592 L F
.51 .314 .551 r
.37064 .76645 m .37052 .76881 L .3686 .76891 L F
.531 .289 .494 r
.3704 .77019 m .3686 .76891 L .37052 .76881 L F
.3704 .77019 m .36875 .77072 L .3686 .76891 L F
.699 .546 .676 r
.5713 .79528 m .574 .79502 L .57426 .79293 L F
.666 .515 .67 r
.57426 .79293 m .57604 .79245 L .57496 .79188 L F
.57426 .79293 m .574 .79502 L .57604 .79245 L F
.728 .52 .609 r
.48585 .87788 m .48902 .87536 L .48614 .87542 L F
.758 .49 .528 r
.49774 .80552 m .50086 .80744 L .50105 .80552 L F
.049 .578 .864 r
.4565 .83145 m .45954 .83221 L .45857 .83147 L F
.069 0 0 r
.45857 .83147 m .45832 .83153 L .4565 .83145 L F
.191 .678 .926 r
.45463 .83136 m .45772 .83198 L .4565 .83145 L F
.049 .578 .864 r
.4565 .83145 m .45772 .83198 L .45954 .83221 L F
.069 0 0 r
.45832 .83153 m .45522 .83219 L .4565 .83145 L F
.191 .678 .926 r
.45449 .83133 m .45463 .83136 L .4565 .83145 L F
0 0 .434 r
.57359 .7865 m .57242 .78433 L .57212 .78463 L F
.713 .562 .681 r
.57212 .78463 m .57221 .78784 L .57491 .78727 L F
.57212 .78463 m .57491 .78727 L .57359 .7865 L F
.659 .479 .629 r
.62241 .76925 m .62249 .77162 L .62033 .77164 L F
.525 .297 .511 r
.62458 .76922 m .62249 .77162 L .62241 .76925 L F
.693 .956 .95 r
.65302 .75061 m .65113 .75162 L .65015 .75134 L F
.831 .742 .766 r
.59059 .83619 m .58961 .8336 L .59043 .83389 L F
.873 .988 .825 r
.59043 .83389 m .59183 .83101 L .59249 .83119 L F
.59043 .83389 m .58961 .8336 L .59183 .83101 L F
.616 .468 .657 r
.59249 .83119 m .59293 .83382 L .59043 .83389 L F
.543 .323 .531 r
.59293 .83382 m .59059 .83619 L .59043 .83389 L F
.2 0 .215 r
.48743 .85308 m .48669 .85438 L .48884 .85206 L F
.816 .611 .625 r
.63356 .75944 m .63642 .75871 L .63301 .75829 L F
.638 .438 .596 r
.63642 .75871 m .63604 .76081 L .63388 .76126 L F
.816 .611 .625 r
.63356 .75944 m .63604 .76081 L .63642 .75871 L F
0 0 0 r
.63604 .76081 m .63855 .75911 L .63642 .75871 L F
.625 .667 .87 r
.63855 .75911 m .63604 .76081 L .63642 .75871 L F
.453 .872 .939 r
.4997 .87438 m .49663 .8748 L .49885 .87543 L F
.409 0 .139 r
.50206 .87418 m .4997 .87438 L .49885 .87543 L F
.661 .65 .828 r
.5677 .80273 m .56985 .80269 L .56847 .79952 L F
.485 .003 .037 r
.56741 .80451 m .5677 .80273 L .56774 .8054 L F
.632 .447 .615 r
.56985 .80269 m .56774 .8054 L .5677 .80273 L F
.485 .003 .037 r
.56741 .80451 m .56985 .80269 L .5677 .80273 L F
.994 .843 .487 r
.48747 .82287 m .48713 .82543 L .48807 .82408 L F
.215 .737 .835 r
.48713 .82543 m .49034 .82514 L .48807 .82408 L F
.662 .386 .493 r
.50251 .82642 m .50224 .82834 L .50004 .82811 L F
.551 .28 .459 r
.50524 .82513 m .50224 .82834 L .50251 .82642 L F
.674 .639 .806 r
.58356 .78794 m .58039 .78732 L .58208 .7867 L F
.298 0 0 r
.44862 .81928 m .45092 .81934 L .45244 .81875 L F
.353 0 0 r
.45092 .81934 m .45446 .81841 L .45244 .81875 L F
.607 .445 .636 r
.58427 .79264 m .58454 .7949 L .58225 .79539 L F
.548 .45 .695 r
.58458 .79724 m .58225 .79539 L .58454 .7949 L F
.58458 .79724 m .5826 .7977 L .58225 .79539 L F
.34 0 .115 r
.51377 .81585 m .51071 .81799 L .51032 .81562 L F
.51377 .81585 m .51269 .8176 L .51071 .81799 L F
.288 0 .087 r
.51464 .81705 m .51269 .8176 L .51377 .81585 L F
.023 .544 .862 r
.51378 .8162 m .51985 .81767 L .51682 .81661 L F
.51378 .8162 m .51682 .81661 L .51464 .81705 L F
.288 0 .087 r
.51464 .81705 m .51377 .81585 L .51378 .8162 L F
.777 .775 .85 r
.51179 .82102 m .50948 .82377 L .50829 .82108 L F
.569 .928 .941 r
.48117 .82922 m .48425 .8284 L .48313 .82888 L F
.619 .212 .25 r
.48632 .82843 m .48313 .82888 L .48425 .8284 L F
.296 0 0 r
.44523 .83325 m .4471 .83361 L .44398 .83322 L F
.856 .828 .819 r
.42594 .8362 m .42364 .8384 L .42402 .83678 L F
.567 .365 .566 r
.62976 .76625 m .62752 .76821 L .62687 .76644 L F
.538 .542 .807 r
.37586 .75671 m .37442 .75823 L .37378 .75699 L F
.37586 .75671 m .37647 .75906 L .37442 .75823 L F
.54 .436 .685 r
.37647 .75906 m .37513 .7614 L .37442 .75823 L F
.863 .78 .768 r
.52985 .82861 m .52847 .83246 L .52541 .8316 L F
.565 .343 .537 r
.37513 .7614 m .37493 .76336 L .37296 .7637 L F
.54 .436 .685 r
.37647 .75906 m .37695 .76101 L .37513 .7614 L F
.536 .339 .56 r
.37695 .76101 m .37493 .76336 L .37513 .7614 L F
.426 0 0 r
.46589 .88047 m .46676 .88139 L .4645 .88193 L F
.46589 .88047 m .46786 .88081 L .46676 .88139 L F
.615 .511 .713 r
.48699 .84327 m .48787 .84502 L .48986 .84366 L F
.728 .52 .609 r
.48585 .87788 m .48916 .87775 L .48902 .87536 L F
.568 .397 .61 r
.48902 .87536 m .48916 .87775 L .49127 .87538 L F
.399 0 .086 r
.4525 .83121 m .45116 .83277 L .44923 .83293 L F
.282 0 0 r
.45449 .83133 m .45116 .83277 L .4525 .83121 L F
.507 .32 .561 r
.37296 .7637 m .37272 .76598 L .37064 .76645 L F
.527 .339 .569 r
.37272 .76598 m .37052 .76881 L .37064 .76645 L F
.566 .4 .616 r
.58618 .78995 m .58639 .79245 L .58427 .79264 L F
.68 .569 .724 r
.58639 .79245 m .58454 .7949 L .58427 .79264 L F
.483 .065 .171 r
.47963 .81231 m .48173 .81232 L .48296 .8106 L F
0 0 0 r
.48296 .8106 m .4839 .81067 L .48501 .81037 L F
.48296 .8106 m .48173 .81232 L .4839 .81067 L F
.088 0 0 r
.48296 .8106 m .48501 .81037 L .48566 .81021 L F
.746 .612 .71 r
.65205 .75637 m .65194 .75849 L .65 .75858 L F
.734 .481 .546 r
.65194 .75849 m .64867 .76093 L .65 .75858 L F
.65194 .75849 m .65206 .76104 L .64867 .76093 L F
.728 .344 .323 r
.65194 .75849 m .65487 .76041 L .65206 .76104 L F
.758 .49 .528 r
.49774 .80552 m .49763 .80758 L .50086 .80744 L F
.768 .48 .498 r
.47173 .83114 m .46883 .83101 L .46801 .82957 L F
.761 .456 .468 r
.47173 .83114 m .47043 .83336 L .46883 .83101 L F
.752 .443 .462 r
.47173 .83114 m .47354 .83364 L .47043 .83336 L F
.591 .509 .73 r
.58082 .82833 m .5822 .83197 L .58398 .83099 L F
.58 .535 .77 r
.37056 .75616 m .36866 .75654 L .36766 .75337 L F
.777 .292 .073 r
.48942 .86765 m .49051 .8675 L .48747 .86609 L F
.658 .629 .809 r
.48942 .86765 m .49088 .86984 L .49051 .8675 L F
.47 0 0 r
.49064 .88804 m .49447 .88725 L .49328 .88732 L F
.176 .71 .827 r
.49447 .88725 m .49534 .88701 L .49328 .88732 L F
.49447 .88725 m .49551 .88717 L .49534 .88701 L F
.395 .08 .309 r
.36631 .77125 m .36548 .77357 L .36365 .77396 L F
.444 .126 .33 r
.36744 .77318 m .36631 .77125 L .36875 .77072 L F
.36744 .77318 m .36548 .77357 L .36631 .77125 L F
.551 .28 .459 r
.50518 .82538 m .5045 .82819 L .50502 .82537 L F
.774 .75 .232 r
.50477 .82661 m .5045 .82819 L .50524 .82513 L F
.501 0 0 r
.50708 .8255 m .50799 .82647 L .50477 .82661 L F
.50737 .82536 m .50746 .82552 L .50708 .8255 L F
.50746 .82552 m .50799 .82647 L .50708 .8255 L F
.551 .28 .459 r
.50502 .82537 m .5045 .82819 L .50224 .82834 L F
.50524 .82513 m .50518 .82538 L .50502 .82537 L F
.774 .75 .232 r
.50477 .82661 m .50524 .82513 L .50737 .82536 L F
.171 0 0 r
.41941 .89341 m .42291 .89224 L .42128 .89289 L F
.208 0 0 r
.42291 .89224 m .42334 .89279 L .42128 .89289 L F
.42291 .89224 m .4248 .89204 L .42334 .89279 L F
.324 .797 .709 r
.49678 .88765 m .50198 .88556 L .50111 .88593 L F
0 0 0 r
.5031 .88528 m .50198 .88556 L .50394 .88473 L F
.50111 .88593 m .50198 .88556 L .5031 .88528 L F
.74 .551 .639 r
.55977 .80279 m .5596 .80525 L .5572 .80473 L F
.539 .378 .611 r
.56169 .8043 m .55977 .80279 L .56109 .80246 L F
.56169 .8043 m .5596 .80525 L .55977 .80279 L F
.613 .907 .984 r
.40963 .88259 m .41069 .88141 L .41175 .88233 L F
.40963 .88259 m .40835 .88227 L .41069 .88141 L F
.409 .145 .4 r
.52658 .86681 m .52709 .8649 L .52481 .86714 L F
.356 .097 .378 r
.52882 .86482 m .52709 .8649 L .52658 .86681 L F
.362 0 0 r
.47208 .87167 m .46898 .8715 L .47096 .87184 L F
0 0 0 r
.47096 .87184 m .47436 .87138 L .47208 .87167 L F
.427 0 0 r
.46786 .88081 m .47066 .88093 L .46993 .88171 L F
.433 0 0 r
.47066 .88093 m .47199 .88188 L .46993 .88171 L F
.47066 .88093 m .47318 .88243 L .47199 .88188 L F
.419 0 0 r
.47066 .88093 m .47438 .8829 L .47318 .88243 L F
.774 .682 .762 r
.40442 .88577 m .40761 .88566 L .40703 .88331 L F
.527 .865 .993 r
.40637 .88521 m .40761 .88566 L .40442 .88577 L F
.963 .773 .599 r
.40703 .88331 m .40761 .88566 L .40637 .88521 L F
.546 .105 .153 r
.42247 .82247 m .42451 .82271 L .4259 .82124 L F
.513 .108 .21 r
.42451 .82271 m .42789 .821 L .4259 .82124 L F
.638 .507 .686 r
.36945 .75076 m .36665 .74811 L .36889 .7477 L F
.36945 .75076 m .36752 .75138 L .36665 .74811 L F
.753 .575 .655 r
.57042 .82872 m .57224 .83052 L .57162 .82896 L F
.57042 .82872 m .57182 .83307 L .57224 .83052 L F
.741 .654 .764 r
.57224 .83052 m .57391 .82896 L .57162 .82896 L F
.569 .393 .603 r
.61311 .78153 m .61092 .77949 L .61321 .77924 L F
.61311 .78153 m .61104 .78191 L .61092 .77949 L F
.531 .076 .116 r
.38994 .82816 m .38863 .82883 L .39188 .82844 L F
.44 .218 .48 r
.57323 .78951 m .57491 .78727 L .57221 .78784 L F
.57323 .78951 m .57439 .78963 L .57491 .78727 L F
.589 .64 .869 r
.57491 .78727 m .57625 .78455 L .57359 .7865 L F
.57491 .78727 m .57701 .78693 L .57625 .78455 L F
.182 0 .174 r
.57439 .78963 m .57701 .78693 L .57491 .78727 L F
.473 .823 .997 r
.57496 .79188 m .57604 .79245 L .57902 .79213 L F
.198 .647 .946 r
.40122 .88485 m .39959 .88475 L .39789 .8839 L F
.222 0 .169 r
.51604 .87789 m .51832 .87519 L .51717 .877 L F
.37 0 .174 r
.51717 .877 m .51832 .87519 L .52032 .87533 L F
.942 .731 .588 r
.52114 .81771 m .52229 .8206 L .52272 .81846 L F
.061 .416 .864 r
.54329 .81081 m .54215 .81091 L .54113 .81025 L F
.54329 .81081 m .54477 .81245 L .54215 .81091 L F
.982 .746 .504 r
.58159 .79705 m .5826 .7977 L .58134 .79922 L F
.244 0 0 r
.58134 .79922 m .5826 .7977 L .58458 .79724 L F
.292 .786 .757 r
.51995 .80779 m .51703 .80864 L .51834 .80918 L F
0 0 0 r
.51995 .80779 m .52121 .80743 L .52223 .8065 L F
.51834 .80918 m .52121 .80743 L .51995 .80779 L F
.339 0 0 r
.39395 .82835 m .39595 .82819 L .39738 .82693 L F
.345 0 0 r
.39595 .82819 m .39899 .82729 L .39738 .82693 L F
0 0 0 r
.416 .89536 m .41663 .89472 L .41941 .89341 L F
.49 .07 .17 r
.52327 .86891 m .52481 .86714 L .52199 .86774 L F
.253 0 .006 r
.52658 .86681 m .52481 .86714 L .52327 .86891 L F
.726 .989 .872 r
.59249 .83119 m .59341 .82968 L .5942 .82964 L F
.59249 .83119 m .59183 .83101 L .59341 .82968 L F
.613 .676 .886 r
.5942 .82964 m .59506 .83115 L .59249 .83119 L F
.54 .415 .659 r
.59493 .83337 m .59249 .83119 L .59506 .83115 L F
.59493 .83337 m .59293 .83382 L .59249 .83119 L F
.328 0 .077 r
.39841 .84413 m .39714 .84613 L .39491 .84643 L F
.392 .122 .38 r
.40023 .84344 m .39841 .84413 L .40059 .84217 L F
.4 0 .116 r
.39917 .84569 m .39841 .84413 L .40023 .84344 L F
.39917 .84569 m .39714 .84613 L .39841 .84413 L F
.49 .07 .17 r
.52327 .86891 m .52199 .86774 L .52197 .86977 L F
.836 .709 .724 r
.55604 .79998 m .55334 .79979 L .55499 .79706 L F
.906 .7 .613 r
.55604 .79998 m .55372 .80215 L .55334 .79979 L F
.55604 .79998 m .55588 .80312 L .55372 .80215 L F
.63 .604 .804 r
.5588 .79906 m .55604 .79998 L .55499 .79706 L F
.675 .201 .117 r
.51125 .80809 m .51356 .80972 L .51456 .80878 L F
.476 .008 .064 r
.51356 .80972 m .51703 .80864 L .51456 .80878 L F
.024 0 .27 r
.58618 .78995 m .58791 .78688 L .58839 .78751 L F
.589 .603 .834 r
.58839 .78751 m .58856 .79224 L .58639 .79245 L F
.64 .644 .838 r
.59074 .79173 m .58856 .79224 L .58839 .78751 L F
.58972 .78913 m .58839 .78751 L .58955 .78869 L F
.59074 .79173 m .589 .7886 L .58972 .78913 L F
.589 .7886 m .58839 .78751 L .58972 .78913 L F
.589 .603 .834 r
.5882 .78772 m .58639 .79245 L .58618 .78995 L F
.58822 .78793 m .58639 .79245 L .5882 .78772 L F
.65 .822 .966 r
.58548 .78785 m .58696 .78851 L .58852 .78825 L F
.58827 .78807 m .58852 .78825 L .58916 .78814 L F
.58548 .78785 m .58852 .78825 L .58827 .78807 L F
.575 .405 .613 r
.58832 .78907 m .58892 .79047 L .58916 .78814 L F
.5868 .79075 m .58845 .79054 L .58832 .78907 L F
.58845 .79054 m .58892 .79047 L .58832 .78907 L F
.589 .603 .834 r
.58839 .78751 m .58822 .78793 L .5882 .78772 L F
.624 .621 .827 r
.35681 .74025 m .35907 .73981 L .35701 .74065 L F
.586 .452 .665 r
.36001 .74285 m .35701 .74065 L .35907 .73981 L F
.635 .261 .318 r
.49058 .82138 m .4895 .82305 L .48747 .82287 L F
.551 .206 .336 r
.49267 .82101 m .4895 .82305 L .49058 .82138 L F
.346 0 0 r
.42758 .89069 m .42857 .89159 L .42637 .89188 L F
.42758 .89069 m .42971 .89043 L .42857 .89159 L F
.94 .597 .347 r
.50517 .81987 m .50651 .8207 L .50571 .81883 L F
.442 .042 .184 r
.50856 .81806 m .50517 .81987 L .50571 .81883 L F
.519 .349 .59 r
.6662 .75045 m .66373 .75151 L .66412 .75078 L F
.6662 .75045 m .66637 .75306 L .66373 .75151 L F
.513 .261 .469 r
.66637 .75306 m .66382 .75538 L .66373 .75151 L F
.764 .636 .719 r
.43745 .87564 m .44034 .87527 L .43977 .87287 L F
0 0 0 r
.43992 .87493 m .43941 .87519 L .43783 .87671 L F
.986 .739 .473 r
.43977 .87287 m .44034 .87527 L .43941 .87519 L F
0 0 0 r
.4408 .87418 m .43941 .87519 L .43992 .87493 L F
.307 .797 .874 r
.43941 .87519 m .44034 .87527 L .4389 .87545 L F
.43941 .87519 m .4389 .87545 L .43745 .87564 L F
.404 0 .025 r
.46567 .87079 m .46348 .87062 L .46235 .87185 L F
.231 .742 .71 r
.52266 .83395 m .52573 .83306 L .52444 .83152 L F
0 .437 .73 r
.52573 .83306 m .52664 .83324 L .52444 .83152 L F
.52573 .83306 m .5278 .83362 L .52664 .83324 L F
.375 0 0 r
.53018 .8637 m .53256 .86423 L .53145 .86414 L F
.225 0 .182 r
.61222 .77197 m .60961 .77414 L .61073 .77354 L F
.314 .755 .965 r
.47318 .88243 m .47438 .8829 L .47522 .88234 L F
.433 .346 .658 r
.57323 .78951 m .57496 .79188 L .57439 .78963 L F
.632 .447 .615 r
.56985 .80269 m .56994 .80569 L .56774 .8054 L F
.621 .816 .402 r
.56985 .80269 m .5716 .79993 L .57119 .80285 L F
.204 .372 .809 r
.56847 .79952 m .56985 .80269 L .57119 .80285 L F
.64 .584 .775 r
.57119 .80285 m .56994 .80569 L .56985 .80269 L F
.232 0 0 r
.57119 .80285 m .56985 .80269 L .56741 .80451 L F
0 0 .314 r
.46883 .83101 m .46761 .82834 L .46801 .82957 L F
.599 .268 .381 r
.64667 .75883 m .64379 .7607 L .64349 .75833 L F
.64667 .75883 m .64679 .76048 L .64379 .7607 L F
.73 .37 .368 r
.64667 .75883 m .64867 .76093 L .64679 .76048 L F
.661 .387 .494 r
.65 .75858 m .64867 .76093 L .64667 .75883 L F
.672 .633 .803 r
.65501 .74829 m .65651 .75172 L .65302 .75061 L F
.379 .467 .825 r
.65752 .74987 m .65651 .75172 L .65501 .74829 L F
.633 .41 .561 r
.38264 .84909 m .38053 .84996 L .38071 .84937 L F
.715 .961 .944 r
.39385 .88565 m .39131 .88714 L .39025 .88695 L F
.297 0 .116 r
.65777 .75894 m .65982 .75839 L .65701 .76022 L F
.547 .278 .46 r
.62249 .77162 m .62003 .77353 L .62033 .77164 L F
.898 .665 .578 r
.49793 .83383 m .49921 .83657 L .49748 .83644 L F
.533 0 0 r
.49748 .83644 m .49921 .83657 L .49779 .83673 L F
.351 .733 .986 r
.50013 .83581 m .49921 .83657 L .49793 .83383 L F
.50013 .83581 m .50159 .83677 L .49921 .83657 L F
.141 .375 .829 r
.49921 .83657 m .50013 .83581 L .49779 .83673 L F
.62 .314 .43 r
.50159 .83677 m .50205 .83849 L .49921 .83657 L F
.141 .375 .829 r
.49921 .83657 m .50205 .83849 L .50013 .83581 L F
.352 0 0 r
.44036 .88772 m .44162 .8883 L .43964 .88865 L F
.44036 .88772 m .44242 .88745 L .44162 .8883 L F
.876 .588 .496 r
.49421 .83016 m .49486 .82865 L .49502 .82784 L F
.49421 .83016 m .49509 .83127 L .49486 .82865 L F
.796 .758 .818 r
.57492 .77818 m .57589 .77954 L .57292 .77937 L F
.709 .733 .87 r
.57819 .77861 m .57589 .77954 L .57492 .77818 L F
.553 .742 .964 r
.56461 .81781 m .56583 .81883 L .56258 .81811 L F
.625 .766 .947 r
.5682 .81804 m .56583 .81883 L .56461 .81781 L F
.5682 .81804 m .56583 .81883 L .56461 .81781 L F
.576 .293 .451 r
.40311 .84273 m .40023 .84344 L .40059 .84217 L F
.466 .35 .637 r
.60796 .77682 m .60981 .7788 L .60946 .77876 L F
.856 .828 .819 r
.42594 .8362 m .4246 .8389 L .42364 .8384 L F
.283 0 .238 r
.42444 .83967 m .42364 .8384 L .4246 .8389 L F
0 0 0 r
.42785 .83648 m .4246 .8389 L .42594 .8362 L F
.42785 .83648 m .42662 .83833 L .4246 .8389 L F
.433 .084 .272 r
.42662 .83833 m .42444 .83967 L .4246 .8389 L F
.479 0 0 r
.44522 .87145 m .44455 .87018 L .44366 .87227 L F
.476 .515 .818 r
.44741 .87269 m .44455 .87018 L .4471 .87062 L F
.479 0 0 r
.44522 .87145 m .4471 .87062 L .44455 .87018 L F
.525 .297 .511 r
.62458 .76922 m .6246 .77125 L .62249 .77162 L F
.549 .293 .48 r
.62752 .76821 m .6246 .77125 L .62458 .76922 L F
.421 0 .06 r
.4617 .81776 m .46377 .81769 L .46507 .81625 L F
.482 .03 .101 r
.46507 .81625 m .46377 .81769 L .46672 .81699 L F
.684 .768 .915 r
.49914 .84039 m .50035 .84156 L .4971 .84116 L F
.794 .592 .627 r
.50035 .84156 m .49721 .8439 L .4971 .84116 L F
.50035 .84156 m .50033 .84414 L .49775 .84394 L F
.50035 .84156 m .49775 .84394 L .49772 .84352 L F
.636 .441 .602 r
.49755 .84099 m .49901 .84289 L .49914 .84039 L F
.4971 .84116 m .4976 .84161 L .49755 .84099 L F
.4976 .84161 m .49901 .84289 L .49755 .84099 L F
.794 .592 .627 r
.49772 .84352 m .49775 .84394 L .49721 .8439 L F
.319 .613 .954 r
.49914 .84039 m .50122 .8407 L .50035 .84156 L F
.692 .33 .356 r
.49901 .84289 m .50035 .84156 L .50122 .8407 L F
.548 .39 .619 r
.50272 .84349 m .50033 .84414 L .50035 .84156 L F
.692 .33 .356 r
.49901 .84289 m .50272 .84349 L .50035 .84156 L F
0 0 0 r
.45446 .81841 m .45642 .81815 L .45758 .81787 L F
.384 0 0 r
.45758 .81787 m .45642 .81815 L .45969 .81816 L F
.993 .751 .45 r
.65302 .75061 m .65199 .75029 L .65272 .74868 L F
0 0 0 r
.65375 .7485 m .65427 .74759 L .65501 .74829 L F
.672 .633 .803 r
.65501 .74829 m .65302 .75061 L .65272 .74868 L F
.874 .883 .839 r
.65686 .74576 m .65501 .74829 L .65427 .74759 L F
.65686 .74576 m .65427 .74759 L .65615 .74465 L F
0 0 0 r
.65427 .74759 m .65354 .74945 L .65534 .74568 L F
.656 .845 .442 r
.65615 .74465 m .65427 .74759 L .65541 .74554 L F
0 0 0 r
.65427 .74759 m .65534 .74568 L .65541 .74554 L F
.65272 .74868 m .65427 .74759 L .65375 .7485 L F
.65272 .74868 m .65199 .75029 L .65427 .74759 L F
.675 .659 .827 r
.57021 .83814 m .57314 .83941 L .57149 .83633 L F
.79 .486 .476 r
.57021 .83814 m .57314 .83941 L .57248 .84093 L F
.57021 .83814 m .57314 .83941 L .57248 .84093 L F
.21 0 .195 r
.57458 .8388 m .57314 .83941 L .57248 .84093 L F
.57458 .8388 m .57314 .83941 L .57248 .84093 L F
.395 .044 .247 r
.52343 .81228 m .52029 .81494 L .52124 .81329 L F
.449 .209 .456 r
.67034 .7451 m .66798 .74766 L .66793 .74562 L F
.433 .867 .916 r
.39703 .90059 m .39769 .89993 L .39604 .90087 L F
.39703 .90059 m .39893 .90008 L .39769 .89993 L F
.77 .607 .677 r
.5633 .79515 m .56014 .79745 L .56225 .79455 L F
.5633 .79515 m .56349 .79756 L .56014 .79745 L F
.651 .393 .517 r
.56407 .79509 m .56408 .79562 L .56395 .79569 L F
.56458 .79579 m .56561 .79496 L .56415 .79508 L F
.56525 .7961 m .56561 .79496 L .56458 .79579 L F
.856 .592 .538 r
.56415 .7956 m .56406 .7957 L .56408 .79556 L F
.56415 .7956 m .56413 .79559 L .56408 .79562 L F
.651 .393 .517 r
.56407 .79509 m .56521 .795 L .56408 .79562 L F
0 .403 .808 r
.56414 .79558 m .56421 .79562 L .56415 .7956 L F
.651 .393 .517 r
.56401 .79574 m .56561 .79496 L .56509 .79663 L F
.343 0 .143 r
.56421 .79562 m .56415 .79566 L .56415 .7956 L F
.517 .416 .679 r
.56395 .79569 m .56338 .79618 L .5633 .79515 L F
.779 .537 .569 r
.56225 .79455 m .56351 .79541 L .5633 .79515 L F
.56366 .79558 m .56395 .79569 L .5633 .79515 L F
.856 .592 .538 r
.56408 .79556 m .56395 .7957 L .56225 .79455 L F
.56395 .7957 m .5626 .79725 L .56225 .79455 L F
.779 .537 .569 r
.56225 .79455 m .56352 .79542 L .56351 .79541 L F
.25 .745 .911 r
.56014 .79745 m .56281 .79753 L .5626 .79725 L F
.56281 .79753 m .56349 .79756 L .5626 .79725 L F
.517 .416 .679 r
.56394 .79588 m .56342 .79671 L .56338 .79618 L F
.56408 .7958 m .56338 .79618 L .56395 .79569 L F
.856 .592 .538 r
.56403 .79573 m .5626 .79725 L .564 .79564 L F
.477 .057 .163 r
.56403 .79573 m .56306 .7967 L .5626 .79725 L F
.56404 .79571 m .5612 .79858 L .56403 .79573 L F
.517 .416 .679 r
.56406 .79581 m .56349 .79756 L .56342 .79671 L F
.56406 .79581 m .56342 .79671 L .56394 .79588 L F
.56407 .79584 m .56349 .79756 L .56406 .79581 L F
.56509 .79663 m .56458 .79693 L .56408 .7958 L F
.779 .537 .569 r
.56427 .79603 m .56389 .79631 L .56509 .79663 L F
.56389 .79631 m .5626 .79725 L .56292 .79717 L F
.517 .416 .679 r
.56458 .79693 m .56349 .79756 L .56408 .7958 L F
.779 .537 .569 r
.56389 .79631 m .56292 .79717 L .56509 .79663 L F
.651 .393 .517 r
.56509 .79663 m .56432 .79537 L .56404 .79577 L F
.856 .592 .538 r
.56415 .7956 m .56408 .79562 L .56414 .79558 L F
.651 .393 .517 r
.56432 .79537 m .56415 .79508 L .56406 .7957 L F
.477 .057 .163 r
.56415 .7956 m .56408 .79567 L .56406 .7957 L F
.56415 .7956 m .56415 .79566 L .56408 .79567 L F
.651 .393 .517 r
.56432 .79537 m .56406 .7957 L .56404 .79577 L F
.56395 .79569 m .5644 .79549 L .56415 .79566 L F
.56396 .7957 m .56415 .79566 L .56401 .79574 L F
.56404 .79577 m .56415 .79508 L .5633 .79515 L F
.856 .592 .538 r
.56406 .7957 m .56403 .79573 L .56408 .79556 L F
.477 .057 .163 r
.56406 .7957 m .56404 .79571 L .56403 .79573 L F
.56408 .79567 m .56404 .79571 L .56406 .7957 L F
.496 .24 .456 r
.56509 .79663 m .56561 .79496 L .56764 .79473 L F
.56509 .79663 m .56561 .79496 L .56764 .79473 L F
.626 .943 .952 r
.56292 .79717 m .56349 .79756 L .56509 .79663 L F
.5626 .79725 m .56267 .79728 L .56292 .79717 L F
.56267 .79728 m .56349 .79756 L .56292 .79717 L F
.343 0 .143 r
.56772 .79672 m .56383 .79848 L .56403 .7967 L F
.56501 .79628 m .56403 .7967 L .56409 .79613 L F
.56772 .79672 m .56403 .7967 L .56501 .79628 L F
.779 .537 .569 r
.56366 .79558 m .56423 .796 L .56395 .79569 L F
.56423 .796 m .56509 .79663 L .56401 .79574 L F
.477 .057 .163 r
.564 .79575 m .56403 .79616 L .56308 .79667 L F
.517 .416 .679 r
.56408 .7958 m .56407 .79584 L .56406 .79581 L F
.779 .537 .569 r
.56412 .79587 m .56401 .79574 L .56396 .7957 L F
.477 .057 .163 r
.56408 .79567 m .56407 .79581 L .564 .79575 L F
.56407 .79581 m .56403 .79616 L .564 .79575 L F
.779 .537 .569 r
.56308 .79667 m .5626 .79725 L .56427 .79603 L F
.477 .057 .163 r
.56415 .79566 m .56383 .79848 L .56408 .79567 L F
.779 .537 .569 r
.56423 .796 m .56412 .79587 L .56395 .79569 L F
.56412 .79587 m .56396 .7957 L .56395 .79569 L F
.343 0 .143 r
.5645 .79576 m .56423 .796 L .56415 .79566 L F
.56423 .796 m .56409 .79613 L .56412 .79587 L F
.56423 .796 m .56412 .79587 L .56415 .79566 L F
.651 .393 .517 r
.56509 .79663 m .56525 .7961 L .56458 .79579 L F
.343 0 .143 r
.56772 .79672 m .56409 .79613 L .5645 .79576 L F
.779 .537 .569 r
.56225 .79455 m .56245 .7961 L .56285 .79593 L F
.646 .866 .493 r
.56225 .79455 m .56199 .79491 L .5607 .79648 L F
.776 .684 .762 r
.56004 .7956 m .55917 .79669 L .55665 .7955 L F
.118 0 0 r
.5588 .79906 m .55988 .79927 L .55973 .79899 L F
0 .313 .784 r
.55678 .79726 m .55988 .79927 L .5588 .79906 L F
.538 0 0 r
.55786 .79834 m .55988 .79927 L .55678 .79726 L F
.776 .684 .762 r
.55917 .79669 m .55786 .79834 L .55743 .79733 L F
.55917 .79669 m .55743 .79733 L .55665 .7955 L F
.646 .866 .493 r
.56199 .79491 m .56027 .79727 L .5607 .79648 L F
.56027 .79727 m .56014 .79745 L .5607 .79648 L F
.892 .595 .477 r
.5626 .79725 m .5607 .79648 L .56014 .79745 L F
.686 .807 .94 r
.5612 .79858 m .55786 .79834 L .55978 .79785 L F
.905 .603 .462 r
.5607 .79648 m .5612 .79858 L .5598 .79786 L F
.892 .595 .477 r
.5626 .79725 m .5612 .79858 L .5607 .79648 L F
.905 .603 .462 r
.5607 .79648 m .55979 .79787 L .55971 .7977 L F
.68 .539 .686 r
.55921 .79671 m .55839 .7977 L .55917 .79669 L F
.55839 .7977 m .55786 .79834 L .55837 .79769 L F
.55839 .7977 m .55837 .79769 L .55917 .79669 L F
.55978 .79785 m .55786 .79834 L .55921 .79671 L F
.905 .603 .462 r
.5607 .79648 m .56012 .79719 L .55941 .79709 L F
.5607 .79648 m .55941 .79709 L .5592 .79668 L F
.572 .937 .912 r
.5607 .79648 m .55921 .79668 L .56094 .79605 L F
.68 .539 .686 r
.56162 .79738 m .55921 .79671 L .56051 .79613 L F
.55921 .79671 m .55917 .79669 L .5592 .79668 L F
.572 .937 .912 r
.55921 .79668 m .55779 .79687 L .56042 .79618 L F
.56045 .79623 m .56042 .79618 L .56094 .79605 L F
.55921 .79668 m .56042 .79618 L .56045 .79623 L F
.68 .539 .686 r
.56099 .79754 m .55978 .79785 L .55947 .79722 L F
.56099 .79754 m .55947 .79722 L .55921 .79671 L F
.56162 .79738 m .56099 .79754 L .55921 .79671 L F
.905 .603 .462 r
.55971 .7977 m .55979 .79787 L .55963 .79779 L F
.436 .744 .993 r
.55779 .79687 m .55979 .79787 L .56135 .79762 L F
.686 .807 .94 r
.56147 .7978 m .56126 .79747 L .56162 .79738 L F
.436 .744 .993 r
.56116 .79733 m .56135 .79762 L .5622 .79748 L F
.55779 .79687 m .56135 .79762 L .56116 .79733 L F
.68 .539 .686 r
.56051 .79613 m .55917 .79669 L .56004 .7956 L F
.572 .937 .912 r
.56102 .79591 m .56037 .7961 L .56119 .79559 L F
.56037 .7961 m .55779 .79687 L .56026 .79594 L F
.56037 .7961 m .56026 .79594 L .56119 .79559 L F
.73 .789 .899 r
.56004 .7956 m .55809 .79494 L .55964 .79502 L F
.55809 .79494 m .55597 .79422 L .55956 .795 L F
.55809 .79494 m .55956 .795 L .55964 .79502 L F
.968 .729 .524 r
.55982 .79527 m .56013 .79575 L .56004 .7956 L F
.56013 .79575 m .56034 .79606 L .56004 .7956 L F
.55964 .79502 m .5598 .79526 L .5599 .79541 L F
.55964 .79502 m .5599 .79541 L .55982 .79527 L F
.572 .937 .912 r
.56041 .79617 m .56037 .7961 L .56102 .79591 L F
.56094 .79605 m .5603 .79621 L .56102 .79591 L F
.856 .592 .538 r
.56285 .79593 m .56225 .79455 L .5607 .79648 L F
.572 .937 .912 r
.56142 .79587 m .56119 .79559 L .56216 .79523 L F
.5607 .79648 m .561 .79594 L .56142 .79587 L F
.561 .79594 m .56119 .79559 L .56142 .79587 L F
.856 .592 .538 r
.56389 .79567 m .56225 .79455 L .56285 .79593 L F
.779 .537 .569 r
.56225 .79455 m .56285 .79593 L .56366 .79558 L F
.856 .592 .538 r
.56386 .79566 m .5607 .79648 L .56251 .79517 L F
.572 .937 .912 r
.5607 .79648 m .56142 .79587 L .56206 .7955 L F
.856 .592 .538 r
.56285 .79593 m .5607 .79648 L .56291 .7959 L F
.706 .247 .16 r
.56004 .7956 m .5622 .79748 L .56162 .79738 L F
.56077 .79624 m .561 .79691 L .5622 .79748 L F
.56053 .79603 m .56067 .7963 L .56077 .79624 L F
.56067 .7963 m .561 .79691 L .56077 .79624 L F
.572 .937 .912 r
.56206 .7955 m .56216 .79523 L .5633 .7946 L F
.56142 .79587 m .56216 .79523 L .56206 .7955 L F
.686 .807 .94 r
.5612 .79858 m .55978 .79785 L .56126 .79747 L F
.5612 .79858 m .56126 .79747 L .56147 .7978 L F
0 0 .453 r
.5622 .79748 m .5612 .79858 L .56162 .79738 L F
.436 .744 .993 r
.55979 .79787 m .56163 .7981 L .5622 .79748 L F
.706 .247 .16 r
.56034 .79606 m .56153 .7979 L .56053 .79603 L F
.968 .729 .524 r
.56061 .79649 m .56067 .79657 L .56057 .79643 L F
.436 .744 .993 r
.56083 .79683 m .5622 .79748 L .56026 .79594 L F
.56116 .79733 m .5622 .79748 L .56083 .79683 L F
.706 .247 .16 r
.561 .79691 m .56153 .7979 L .5622 .79748 L F
.56004 .7956 m .56034 .79606 L .56053 .79603 L F
.436 .744 .993 r
.56026 .79594 m .5622 .79748 L .56216 .79523 L F
.572 .937 .912 r
.5603 .79621 m .55779 .79687 L .56037 .7961 L F
.5603 .79621 m .56037 .7961 L .56041 .79617 L F
.68 .539 .686 r
.55921 .79671 m .5592 .79668 L .56051 .79613 L F
.905 .603 .462 r
.5592 .79668 m .55941 .79709 L .55779 .79687 L F
.436 .744 .993 r
.55779 .79687 m .56116 .79733 L .56026 .79594 L F
.968 .729 .524 r
.5599 .79541 m .56061 .79649 L .56013 .79575 L F
.56061 .79649 m .56057 .79643 L .56013 .79575 L F
.5599 .79541 m .56013 .79575 L .55982 .79527 L F
.905 .603 .462 r
.5598 .79786 m .5612 .79858 L .55979 .79787 L F
.436 .744 .993 r
.55979 .79787 m .5612 .79858 L .56163 .7981 L F
.07 .27 .759 r
.5612 .79858 m .55973 .79899 L .55988 .79927 L F
.686 .807 .94 r
.5612 .79858 m .55988 .79927 L .55786 .79834 L F
.73 .789 .899 r
.56004 .7956 m .55665 .7955 L .55597 .79422 L F
.63 .604 .804 r
.5588 .79906 m .55499 .79706 L .55678 .79726 L F
.538 0 0 r
.55786 .79834 m .55678 .79726 L .55576 .79645 L F
.134 .306 .773 r
.55665 .7955 m .55786 .79834 L .55576 .79645 L F
.713 .532 .643 r
.55665 .79369 m .55964 .79502 L .55597 .79422 L F
.55665 .79369 m .55661 .79606 L .55964 .79502 L F
.742 .621 .724 r
.55661 .79606 m .55996 .79623 L .55964 .79502 L F
.74 .637 .746 r
.55966 .79528 m .55996 .79623 L .55993 .79623 L F
.55966 .79528 m .55993 .79623 L .55661 .79606 L F
.55902 .79327 m .55966 .79528 L .55661 .79606 L F
.968 .729 .524 r
.55966 .79528 m .55989 .79882 L .56055 .79845 L F
.55996 .79623 m .56055 .79845 L .56065 .79839 L F
.55966 .79528 m .56055 .79845 L .55996 .79623 L F
.55966 .79528 m .56065 .79839 L .56153 .7979 L F
.742 .621 .724 r
.55996 .79623 m .56 .79624 L .55964 .79502 L F
.968 .729 .524 r
.55964 .79502 m .55966 .79528 L .5602 .79604 L F
.74 .637 .746 r
.55907 .79321 m .56 .79624 L .55996 .79623 L F
.55907 .79321 m .55996 .79623 L .55902 .79327 L F
.968 .729 .524 r
.5599 .79541 m .56056 .79642 L .56067 .79657 L F
.5598 .79526 m .56153 .7979 L .5599 .79541 L F
.698 .92 .587 r
.56049 .79526 m .55868 .79755 L .56 .79624 L F
.55868 .79755 m .55859 .79767 L .55968 .79656 L F
.55868 .79755 m .55968 .79656 L .56 .79624 L F
.968 .729 .524 r
.56027 .79598 m .5602 .79604 L .56153 .7979 L F
.55964 .79502 m .5602 .79604 L .56027 .79598 L F
.468 .776 .997 r
.56049 .79526 m .56 .79624 L .55962 .795 L F
.56033 .79503 m .55962 .795 L .55907 .79321 L F
.56049 .79526 m .55962 .795 L .56033 .79503 L F
.968 .729 .524 r
.56013 .79575 m .56067 .79657 L .56034 .79606 L F
.56056 .79642 m .56153 .7979 L .56107 .7972 L F
.56056 .79642 m .56107 .7972 L .56067 .79657 L F
.856 .592 .538 r
.56401 .79563 m .56285 .79593 L .56404 .79561 L F
.779 .537 .569 r
.56366 .79558 m .5626 .79725 L .56387 .79574 L F
.856 .592 .538 r
.56285 .79593 m .56291 .7959 L .56404 .79561 L F
.779 .537 .569 r
.56245 .7961 m .5626 .79725 L .56366 .79558 L F
.477 .057 .163 r
.56306 .7967 m .56256 .79721 L .5626 .79725 L F
.56256 .79721 m .5612 .79858 L .5626 .79725 L F
.56308 .79667 m .56383 .79848 L .5612 .79858 L F
.56403 .79616 m .56383 .79848 L .56308 .79667 L F
.779 .537 .569 r
.56387 .79574 m .56308 .79667 L .56427 .79603 L F
.651 .393 .517 r
.56395 .79569 m .56415 .79566 L .56396 .7957 L F
.56521 .795 m .56561 .79496 L .56395 .79569 L F
.856 .592 .538 r
.56403 .79573 m .564 .79564 L .56408 .79556 L F
.651 .393 .517 r
.5644 .79549 m .56561 .79496 L .56401 .79574 L F
.343 0 .143 r
.56772 .79672 m .56415 .79566 L .56421 .79562 L F
0 .403 .808 r
.5633 .7946 m .56772 .79672 L .56421 .79562 L F
.651 .393 .517 r
.5633 .79515 m .56407 .79509 L .56395 .79569 L F
0 .403 .808 r
.5633 .7946 m .56421 .79562 L .56414 .79558 L F
.856 .592 .538 r
.56408 .79562 m .56394 .79548 L .56401 .79563 L F
.56408 .79556 m .56394 .79548 L .56408 .79562 L F
.56408 .79562 m .56401 .79563 L .56414 .79558 L F
.56401 .79563 m .56404 .79561 L .56414 .79558 L F
.56401 .79563 m .56225 .79455 L .56389 .79567 L F
.56394 .79548 m .56225 .79455 L .56401 .79563 L F
.779 .537 .569 r
.56225 .79455 m .56366 .79558 L .56352 .79542 L F
.856 .592 .538 r
.56414 .79558 m .56386 .79566 L .5633 .7946 L F
.56386 .79566 m .56251 .79517 L .5633 .7946 L F
.545 .353 .571 r
.37518 .76525 m .37296 .7637 L .37493 .76336 L F
.37518 .76525 m .37272 .76598 L .37296 .7637 L F
.693 .956 .95 r
.65302 .75061 m .65015 .75134 L .65199 .75029 L F
0 0 0 r
.56433 .82915 m .56576 .82808 L .56343 .82592 L F
.56433 .82915 m .56748 .82672 L .56576 .82808 L F
.627 .268 .342 r
.50003 .82006 m .49655 .82046 L .49787 .81865 L F
.784 .674 .743 r
.49763 .80758 m .49875 .81049 L .50086 .80744 L F
.559 .155 .231 r
.45001 .88545 m .45328 .88448 L .45196 .8848 L F
.22 0 0 r
.45196 .8848 m .45328 .88448 L .45482 .88456 L F
0 0 0 r
.45328 .88448 m .45554 .88363 L .45482 .88456 L F
.40791 .84088 m .40594 .84388 L .40587 .84142 L F
.624 .631 .837 r
.35757 .73724 m .35681 .74025 L .3559 .73778 L F
.35757 .73724 m .35907 .73981 L .35681 .74025 L F
.417 .041 .216 r
.45482 .88456 m .45554 .88363 L .4575 .88345 L F
.747 .815 .906 r
.56099 .7778 m .56222 .77897 L .55934 .77848 L F
.596 .044 0 r
.56222 .77897 m .55983 .77915 L .55934 .77848 L F
.562 .714 .943 r
.5632 .77694 m .56222 .77897 L .56099 .7778 L F
.5632 .77694 m .56431 .77866 L .56222 .77897 L F
.574 .083 .051 r
.56273 .7789 m .55983 .77915 L .56222 .77897 L F
.56289 .77881 m .55983 .77915 L .56273 .7789 L F
.56289 .77881 m .56369 .77946 L .55983 .77915 L F
.56431 .77866 m .56289 .77881 L .56273 .7789 L F
.56431 .77866 m .56369 .77946 L .56289 .77881 L F
0 0 .08 r
.56737 .77919 m .56748 .78138 L .56747 .78035 L F
.56737 .77919 m .56747 .78035 L .56431 .77866 L F
.659 .154 .034 r
.56747 .78035 m .56369 .77946 L .56431 .77866 L F
.53 .635 .899 r
.56747 .78035 m .56748 .78138 L .56948 .78117 L F
.711 .604 .736 r
.57292 .77937 m .56951 .77879 L .56948 .78117 L F
.99 .758 .38 r
.56883 .77897 m .56948 .78117 L .56951 .77879 L F
.243 .212 .623 r
.57146 .78352 m .57223 .7809 L .56948 .78117 L F
.802 .877 .446 r
.56727 .7799 m .56747 .78035 L .56883 .77897 L F
.53 .635 .899 r
.56747 .78035 m .56948 .78117 L .56883 .77897 L F
.792 .644 .698 r
.57051 .78084 m .56731 .78244 L .56727 .7799 L F
0 0 .425 r
.5673 .78212 m .56747 .78239 L .56727 .7799 L F
.56731 .78244 m .56747 .78239 L .5673 .78212 L F
.56747 .78239 m .56747 .78239 L .5673 .78212 L F
.659 .154 .034 r
.56606 .78002 m .5665 .78164 L .56369 .77946 L F
.56747 .78035 m .56679 .78125 L .56606 .78002 L F
.56679 .78125 m .5665 .78164 L .56606 .78002 L F
.572 .396 .604 r
.56609 .78139 m .56731 .78244 L .56518 .78253 L F
.659 .154 .034 r
.5665 .78164 m .56556 .78108 L .56369 .77946 L F
.572 .396 .604 r
.56727 .7799 m .56731 .78244 L .56699 .78245 L F
.566 .7815 m .56699 .78245 L .56518 .78253 L F
.56727 .7799 m .56639 .78188 L .566 .7815 L F
.802 .877 .446 r
.56727 .7799 m .5665 .78164 L .56747 .78035 L F
.572 .396 .604 r
.56727 .7799 m .5673 .78212 L .56609 .78139 L F
.802 .877 .446 r
.56727 .7799 m .56638 .78179 L .5665 .78164 L F
.572 .396 .604 r
.56727 .7799 m .56699 .78245 L .56639 .78188 L F
.672 .151 0 r
.56638 .78179 m .56566 .78105 L .56484 .78039 L F
.56556 .78108 m .56484 .78039 L .56369 .77946 L F
.56638 .78179 m .56484 .78039 L .56556 .78108 L F
.659 .154 .034 r
.5665 .78164 m .56638 .78179 L .56556 .78108 L F
.572 .396 .604 r
.5673 .78212 m .56731 .78244 L .56609 .78139 L F
.672 .151 0 r
.56566 .78105 m .56329 .77861 L .56369 .77946 L F
.522 .915 .914 r
.56099 .7778 m .56167 .77693 L .5632 .77694 L F
.672 .151 0 r
.56329 .77861 m .56167 .77693 L .56309 .77871 L F
.56329 .77861 m .56309 .77871 L .56369 .77946 L F
.527 .3 .513 r
.62003 .77353 m .61748 .77598 L .61796 .774 L F
.593 .407 .599 r
.63388 .76126 m .6341 .76365 L .6317 .76377 L F
.72 .547 .656 r
.63604 .76081 m .6341 .76365 L .63388 .76126 L F
.811 .992 .872 r
.50813 .88211 m .51126 .88014 L .51086 .88067 L F
.36 .825 .751 r
.51126 .88014 m .51383 .87908 L .51235 .87955 L F
0 0 0 r
.51086 .88067 m .51126 .88014 L .51235 .87955 L F
.473 .066 .186 r
.37775 .83254 m .37667 .8312 L .37588 .83242 L F
.37775 .83254 m .37912 .83074 L .37667 .8312 L F
.615 .153 0 r
.50155 .86377 m .503 .86565 L .50168 .864 L F
.575 .684 .915 r
.50168 .864 m .503 .86565 L .50484 .86505 L F
.228 0 0 r
.50168 .864 m .50252 .86463 L .50201 .86457 L F
.50168 .864 m .50201 .86457 L .50036 .86439 L F
.615 .153 0 r
.50131 .86345 m .50155 .86377 L .50168 .864 L F
.692 .196 .062 r
.503 .86565 m .50617 .86706 L .50484 .86505 L F
.863 .78 .768 r
.52985 .82861 m .52541 .8316 L .52848 .83234 L F
.717 .183 0 r
.53121 .83067 m .52985 .82861 L .52851 .83225 L F
.53121 .83067 m .53198 .83066 L .52985 .82861 L F
.702 .808 .931 r
.53286 .82971 m .53121 .83067 L .52971 .82955 L F
.53287 .82971 m .53121 .83067 L .53286 .82971 L F
.717 .183 0 r
.53121 .83067 m .52851 .83225 L .52848 .83234 L F
.867 .618 .56 r
.56536 .83872 m .56709 .83897 L .56712 .84125 L F
.642 .494 .667 r
.56879 .83891 m .56712 .84125 L .56709 .83897 L F
.869 .763 .743 r
.56328 .83342 m .56387 .83641 L .56331 .83527 L F
.661 .221 0 r
.56387 .83641 m .56465 .83785 L .56331 .83527 L F
.56387 .83641 m .56536 .83872 L .56465 .83785 L F
0 0 0 r
.41907 .87997 m .41713 .88058 L .41538 .88154 L F
.584 .586 .821 r
.57717 .81114 m .5782 .80928 L .57657 .81047 L F
.57717 .81114 m .57999 .81102 L .5782 .80928 L F
.689 .521 .655 r
.57792 .83875 m .57902 .84161 L .57564 .84142 L F
.111 .647 .858 r
.57665 .83841 m .57973 .83878 L .57792 .83875 L F
.739 .546 .632 r
.58095 .84141 m .57792 .83875 L .57973 .83878 L F
.58095 .84141 m .57902 .84161 L .57792 .83875 L F
.246 .508 .904 r
.49551 .88717 m .49733 .88673 L .49534 .88701 L F
.49551 .88717 m .49678 .88765 L .49733 .88673 L F
.565 .052 0 r
.47644 .8829 m .47966 .88306 L .47856 .88402 L F
.672 .155 0 r
.47966 .88306 m .48046 .88474 L .47856 .88402 L F
.47966 .88306 m .48202 .88465 L .48046 .88474 L F
.932 .901 .772 r
.50077 .86223 m .50131 .86345 L .50168 .864 L F
.548 .187 .307 r
.43862 .83357 m .43533 .83559 L .43669 .83347 L F
.57 .644 .884 r
.57499 .80547 m .57486 .80763 L .57248 .8076 L F
.94 .623 .41 r
.57125 .8074 m .57248 .8076 L .57254 .80794 L F
.5723 .809 m .57254 .80794 L .57287 .80987 L F
.57125 .8074 m .57254 .80794 L .5723 .809 L F
.067 .12 .609 r
.57119 .81064 m .57167 .80969 L .57216 .80956 L F
.57205 .81003 m .57216 .80956 L .57304 .80934 L F
.57119 .81064 m .57216 .80956 L .57205 .81003 L F
.94 .623 .41 r
.57125 .8074 m .5726 .80945 L .57304 .80934 L F
.743 .445 .478 r
.57486 .80763 m .57287 .80987 L .57254 .80794 L F
.94 .623 .41 r
.5726 .80945 m .57287 .80987 L .57304 .80934 L F
0 .259 .768 r
.57304 .80934 m .57287 .80987 L .57343 .80924 L F
0 0 0 r
.57343 .80924 m .57304 .80934 L .57343 .80924 L F
.57181 .81099 m .57304 .80934 L .57343 .80924 L F
.067 .12 .609 r
.57181 .81099 m .57119 .81064 L .57304 .80934 L F
.57119 .81064 m .57017 .81007 L .57167 .80969 L F
.743 .445 .478 r
.57271 .8076 m .57254 .80794 L .57248 .8076 L F
.57486 .80763 m .57254 .80794 L .57271 .8076 L F
.57486 .80763 m .57657 .81047 L .57287 .80987 L F
0 0 0 r
.44657 .88703 m .44808 .8861 L .45001 .88545 L F
.761 .628 .713 r
.50793 .85192 m .50889 .85416 L .50658 .85381 L F
.757 .452 .468 r
.50658 .85381 m .50889 .85416 L .50745 .85517 L F
.675 .61 .776 r
.51078 .85374 m .50889 .85416 L .50793 .85192 L F
.51078 .85374 m .5111 .85444 L .50889 .85416 L F
.563 .065 .03 r
.50889 .85416 m .50961 .85512 L .50745 .85517 L F
.50889 .85416 m .5111 .85444 L .50961 .85512 L F
.485 .778 .996 r
.37443 .75579 m .37378 .75699 L .37238 .7562 L F
.37443 .75579 m .37586 .75671 L .37378 .75699 L F
.594 .41 .603 r
.6341 .76365 m .63197 .76602 L .6317 .76377 L F
.572 .598 .841 r
.36075 .73995 m .36001 .74285 L .35907 .73981 L F
.36075 .73995 m .36203 .7426 L .36001 .74285 L F
.638 .305 .391 r
.48501 .81037 m .48748 .81056 L .48566 .81021 L F
0 .473 .862 r
.48284 .88566 m .48646 .88707 L .48338 .88538 L F
.421 .166 .419 r
.49953 .82376 m .50219 .82385 L .50008 .82304 L F
.49953 .82376 m .49883 .82552 L .50219 .82385 L F
0 0 0 r
.48178 .87368 m .48293 .87254 L .48091 .87391 L F
.826 .428 .296 r
.48423 .87504 m .48293 .87254 L .48178 .87368 L F
.25 .479 .883 r
.48238 .87353 m .48178 .87368 L .48017 .87159 L F
.48336 .87439 m .48178 .87368 L .48238 .87353 L F
0 0 0 r
.48178 .87368 m .48091 .87391 L .48041 .87425 L F
.791 .954 .622 r
.61412 .76922 m .61222 .77197 L .61358 .76992 L F
.387 .152 .432 r
.61073 .77354 m .61358 .76992 L .61222 .77197 L F
.431 0 .051 r
.39899 .82729 m .40102 .82723 L .40248 .82585 L F
.189 0 0 r
.40102 .82723 m .40461 .82603 L .40248 .82585 L F
0 0 0 r
.52223 .8065 m .523 .80662 L .52465 .80613 L F
.52223 .8065 m .52121 .80743 L .523 .80662 L F
.986 .739 .473 r
.43977 .87287 m .4408 .87418 L .44163 .87271 L F
.43977 .87287 m .43941 .87519 L .4408 .87418 L F
.38 0 0 r
.42789 .821 m .42987 .821 L .43116 .82032 L F
.517 .023 .023 r
.42987 .821 m .43316 .82075 L .43116 .82032 L F
.923 .754 .655 r
.56039 .81024 m .56146 .81304 L .55999 .81294 L F
.918 .672 .552 r
.56146 .81304 m .56152 .81537 L .55999 .81294 L F
.56 .582 .833 r
.56323 .81272 m .56146 .81304 L .56039 .81024 L F
.52 .36 .604 r
.5635 .81508 m .56146 .81304 L .56323 .81272 L F
.53 .36 .596 r
.5635 .81508 m .56152 .81537 L .56146 .81304 L F
.296 0 0 r
.46672 .81699 m .46889 .8168 L .47033 .81578 L F
.163 0 0 r
.46889 .8168 m .47239 .81557 L .47033 .81578 L F
.31 .1 .423 r
.61596 .76636 m .61412 .76922 L .61534 .76848 L F
.443 .243 .513 r
.61358 .76992 m .61534 .76848 L .61412 .76922 L F
.598 .68 .898 r
.53485 .80487 m .535 .80604 L .5313 .80342 L F
.485 .354 .626 r
.52277 .83247 m .52266 .83395 L .52444 .83152 L F
.517 .192 .354 r
.65714 .75164 m .65848 .75021 L .65751 .75049 L F
.764 .44 .438 r
.65752 .74987 m .65922 .75009 L .6606 .74867 L F
.65922 .75009 m .66028 .75022 L .66035 .7499 L F
.65922 .75009 m .66035 .7499 L .6606 .74867 L F
.774 .67 .748 r
.65995 .74803 m .66028 .75022 L .65752 .74987 L F
.517 .192 .354 r
.65848 .75021 m .6595 .74911 L .65774 .75033 L F
.65848 .75021 m .65774 .75033 L .65751 .75049 L F
.376 .085 .337 r
.6606 .74867 m .66232 .74944 L .66319 .74834 L F
.6606 .74867 m .66028 .75022 L .66232 .74944 L F
.957 .682 .475 r
.49648 .80924 m .49777 .80988 L .49763 .80758 L F
0 .062 .62 r
.49675 .80928 m .49777 .80988 L .49648 .80924 L F
.983 .707 .418 r
.49763 .80758 m .49777 .80988 L .49873 .81045 L F
.49763 .80758 m .49777 .80988 L .49875 .81049 L F
0 .062 .62 r
.49846 .80954 m .49777 .80988 L .49675 .80928 L F
.983 .707 .418 r
.49873 .81045 m .49777 .80988 L .49875 .81049 L F
.405 0 0 r
.52806 .8033 m .5313 .80342 L .52953 .80263 L F
.223 0 .009 r
.45307 .87263 m .4498 .87504 L .45166 .87496 L F
.286 0 .186 r
.4547 .87223 m .45307 .87263 L .45166 .87496 L F
.491 .034 .093 r
.53278 .80842 m .5295 .80951 L .53058 .80818 L F
.152 .653 .909 r
.36534 .7448 m .36717 .74493 L .36873 .7455 L F
.391 .637 .953 r
.36926 .74422 m .36873 .7455 L .36717 .74493 L F
.36926 .74422 m .37031 .7454 L .36873 .7455 L F
.583 .532 .764 r
.37031 .7454 m .36889 .7477 L .36873 .7455 L F
.168 .706 .775 r
.51252 .8729 m .50943 .87325 L .51126 .87247 L F
.642 .911 .981 r
.51436 .87201 m .51252 .8729 L .51126 .87247 L F
.781 .684 .757 r
.50617 .86706 m .50834 .86497 L .50484 .86505 L F
.531 .443 .701 r
.36952 .75305 m .36766 .75337 L .36752 .75138 L F
.58 .535 .77 r
.37056 .75616 m .36766 .75337 L .36952 .75305 L F
.531 .443 .701 r
.36952 .75305 m .36752 .75138 L .36945 .75076 L F
.371 .156 .452 r
.61596 .76636 m .61757 .76826 L .61807 .7659 L F
.61596 .76636 m .61534 .76848 L .61757 .76826 L F
.898 .665 .578 r
.49793 .83383 m .49748 .83644 L .49669 .83342 L F
.502 0 0 r
.4961 .83343 m .49793 .83383 L .49669 .83342 L F
.854 .634 .604 r
.49675 .83188 m .49793 .83383 L .49669 .83342 L F
.845 .538 .004 r
.49669 .83342 m .49686 .83491 L .4961 .83343 L F
.49669 .83342 m .49748 .83644 L .49686 .83491 L F
.679 .2 .106 r
.49686 .83491 m .49793 .83383 L .4961 .83343 L F
.49686 .83491 m .50013 .83581 L .49793 .83383 L F
.562 .793 .986 r
.56644 .8044 m .56774 .8054 L .56459 .80488 L F
.751 .396 .381 r
.56459 .80488 m .56774 .8054 L .56699 .80751 L F
.485 .003 .037 r
.56741 .80451 m .56774 .8054 L .56644 .8044 L F
.894 .761 .707 r
.56771 .80904 m .56956 .80921 L .56743 .80948 L F
.737 .381 .376 r
.56699 .80751 m .56774 .8054 L .56984 .80815 L F
.56699 .80751 m .56984 .80815 L .56952 .80828 L F
.56759 .80772 m .56952 .80828 L .56937 .80834 L F
.56699 .80751 m .56952 .80828 L .56759 .80772 L F
.63 .374 .511 r
.56774 .8054 m .56994 .80569 L .57019 .80841 L F
.702 .616 .757 r
.57023 .80849 m .56956 .80921 L .56952 .80828 L F
.63 .374 .511 r
.57006 .80844 m .57019 .80841 L .57022 .80864 L F
.56774 .8054 m .57019 .80841 L .57006 .80844 L F
.953 .832 .686 r
.57261 .80544 m .57046 .80832 L .56994 .80569 L F
.702 .616 .757 r
.57036 .80835 m .57033 .80838 L .57033 .80836 L F
.57033 .80838 m .57023 .80849 L .5702 .80841 L F
.953 .832 .686 r
.57046 .80832 m .57042 .80836 L .57036 .80835 L F
.592 .447 .653 r
.57125 .8074 m .57246 .80872 L .57036 .80835 L F
.953 .832 .686 r
.57042 .80836 m .57125 .8074 L .57022 .80864 L F
.57261 .80544 m .57125 .8074 L .57042 .80836 L F
.592 .447 .653 r
.57036 .80835 m .57042 .80837 L .56956 .80921 L F
.57042 .80837 m .57304 .80934 L .5697 .80922 L F
.57042 .80837 m .5697 .80922 L .56956 .80921 L F
.57246 .80872 m .57304 .80934 L .57036 .80835 L F
.953 .832 .686 r
.57036 .80835 m .57022 .80864 L .57019 .80841 L F
.57042 .80836 m .57022 .80864 L .57036 .80835 L F
.57046 .80832 m .57019 .80841 L .56994 .80569 L F
.702 .616 .757 r
.57125 .8074 m .57036 .80835 L .56941 .80623 L F
.57036 .80835 m .57033 .80836 L .56941 .80623 L F
.57033 .80838 m .5702 .80841 L .56941 .80623 L F
.57023 .80849 m .56952 .80828 L .56941 .80623 L F
.737 .381 .376 r
.56699 .80751 m .56937 .80834 L .56941 .80623 L F
.894 .761 .707 r
.56941 .80623 m .56952 .80828 L .56937 .80834 L F
.737 .381 .376 r
.56937 .80834 m .56984 .80815 L .57022 .80864 L F
.56937 .80834 m .57022 .80864 L .56941 .80623 L F
.894 .761 .707 r
.56941 .80623 m .56937 .80834 L .56771 .80904 L F
.56952 .80828 m .56956 .80921 L .56771 .80904 L F
.303 .439 .833 r
.54113 .81025 m .53988 .80984 L .53856 .80732 L F
.579 .595 .833 r
.51667 .82322 m .51666 .82571 L .51487 .82581 L F
.79 .371 .253 r
.51666 .82571 m .51681 .8278 L .51487 .82581 L F
.51666 .82571 m .51815 .82755 L .51681 .8278 L F
.043 .6 .814 r
.42112 .88013 m .42234 .8804 L .41907 .87997 L F
.431 .786 .997 r
.42309 .87954 m .42234 .8804 L .42112 .88013 L F
.42309 .87954 m .42434 .88021 L .42234 .8804 L F
.121 .286 .759 r
.51216 .85385 m .5111 .85444 L .51078 .85374 L F
.357 .809 .681 r
.50961 .85512 m .5111 .85444 L .51216 .85385 L F
.579 .595 .833 r
.51667 .82322 m .51487 .82581 L .51563 .82356 L F
.859 .774 .766 r
.54769 .82609 m .54753 .8283 L .54706 .82869 L F
.623 .349 .482 r
.54706 .82869 m .54753 .8283 L .54809 .83071 L F
.466 .429 .733 r
.55002 .82786 m .54753 .8283 L .54767 .82626 L F
.55002 .82786 m .54767 .82626 L .54786 .82622 L F
.809 .8 .307 r
.54701 .82806 m .54706 .82869 L .54769 .82609 L F
.465 0 0 r
.54769 .82609 m .54786 .82622 L .54835 .82662 L F
.544 .423 .665 r
.54928 .82562 m .55002 .82786 L .54769 .82609 L F
.377 .042 .265 r
.54835 .82662 m .54769 .82609 L .54928 .82562 L F
.466 .429 .733 r
.54786 .82622 m .54767 .82626 L .54769 .82609 L F
.377 .042 .265 r
.54701 .82806 m .54769 .82609 L .54835 .82662 L F
.54701 .82806 m .54835 .82662 L .54907 .82721 L F
.465 0 0 r
.54769 .82609 m .54835 .82662 L .54907 .82721 L F
.54786 .82622 m .5494 .82739 L .54907 .82721 L F
.377 .042 .265 r
.54835 .82662 m .54895 .82598 L .54907 .82721 L F
.633 .752 .934 r
.54878 .82706 m .54907 .82721 L .54907 .82707 L F
.725 .383 .399 r
.54457 .82567 m .54769 .82609 L .54701 .82806 L F
.465 0 0 r
.54769 .82609 m .54907 .82721 L .54701 .82806 L F
.766 .265 .022 r
.54457 .82567 m .54701 .82806 L .54451 .82685 L F
.633 .752 .934 r
.54451 .82685 m .54907 .82721 L .54878 .82706 L F
.465 0 0 r
.5494 .82739 m .55002 .82786 L .54907 .82721 L F
.377 .042 .265 r
.54895 .82598 m .54928 .82562 L .54924 .82591 L F
.54895 .82598 m .54924 .82591 L .54907 .82721 L F
.414 .22 .506 r
.54809 .83071 m .54753 .8283 L .55002 .82786 L F
.993 .873 .598 r
.56318 .83003 m .56411 .83088 L .56328 .83342 L F
.496 .249 .47 r
.53155 .81567 m .53414 .81304 L .53174 .81298 L F
.972 .756 .554 r
.56258 .81811 m .56242 .82079 L .5613 .8198 L F
.993 .877 .595 r
.56191 .81771 m .56258 .81811 L .5613 .8198 L F
.555 .384 .604 r
.56461 .81781 m .56242 .82079 L .56258 .81811 L F
.392 .812 .972 r
.56191 .81771 m .56461 .81781 L .56258 .81811 L F
0 .053 .606 r
.50321 .80787 m .50469 .80922 L .50646 .80737 L F
.50321 .80787 m .50413 .81039 L .50469 .80922 L F
.945 .744 .6 r
.50517 .81987 m .50502 .82241 L .50651 .8207 L F
.547 .278 .46 r
.62249 .77162 m .6222 .77336 L .62003 .77353 L F
.539 .29 .486 r
.6246 .77125 m .6222 .77336 L .62249 .77162 L F
.462 0 .023 r
.41343 .83989 m .41189 .84105 L .40992 .84089 L F
.448 0 .012 r
.41557 .84038 m .41189 .84105 L .41343 .83989 L F
.627 .451 .625 r
.58077 .80951 m .57936 .80757 L .5782 .80928 L F
.58077 .80951 m .58158 .80774 L .57936 .80757 L F
0 0 .434 r
.57359 .7865 m .57354 .78613 L .57242 .78433 L F
.697 .38 .436 r
.57625 .78455 m .57354 .78613 L .57359 .7865 L F
.525 .123 .221 r
.4118 .82523 m .4139 .82533 L .41523 .82348 L F
.518 .128 .241 r
.4139 .82533 m .4173 .8234 L .41523 .82348 L F
.68 .569 .724 r
.58639 .79245 m .58678 .79477 L .58454 .7949 L F
.66 .434 .566 r
.58454 .7949 m .58683 .79701 L .58458 .79724 L F
.58454 .7949 m .58678 .79477 L .58683 .79701 L F
.363 0 0 r
.4471 .83361 m .44598 .83371 L .44398 .83322 L F
0 0 0 r
.44923 .83293 m .44801 .83349 L .4471 .83361 L F
.09 .647 .721 r
.44801 .83349 m .44598 .83371 L .4471 .83361 L F
0 0 0 r
.6351 .76069 m .63413 .76202 L .63507 .76121 L F
.624 .06 0 r
.63513 .76031 m .6351 .76069 L .63604 .76081 L F
0 0 0 r
.6351 .76069 m .63673 .75975 L .63738 .76027 L F
.6351 .76069 m .63507 .76121 L .63673 .75975 L F
.624 .06 0 r
.63356 .75944 m .6351 .76069 L .63513 .76031 L F
.72 .547 .656 r
.63604 .76081 m .63615 .76368 L .6341 .76365 L F
.625 .667 .87 r
.63855 .75911 m .63926 .76101 L .63604 .76081 L F
0 0 0 r
.63604 .76081 m .63738 .76027 L .63855 .75911 L F
.289 .786 .867 r
.6351 .76069 m .63738 .76027 L .63604 .76081 L F
.663 .502 .656 r
.63926 .76101 m .63615 .76368 L .63604 .76081 L F
.785 .382 .289 r
.4909 .85197 m .48831 .85099 L .48884 .85206 L F
.48831 .85099 m .48811 .85091 L .48816 .85099 L F
.48831 .85099 m .48816 .85099 L .48884 .85206 L F
.24 .732 .919 r
.48903 .85173 m .4909 .85197 L .48884 .85206 L F
.785 .382 .289 r
.4909 .85197 m .48903 .85173 L .48811 .85091 L F
.24 .732 .919 r
.4891 .85161 m .4909 .85197 L .48903 .85173 L F
.785 .382 .289 r
.4909 .85197 m .49013 .85271 L .48903 .85173 L F
.24 .732 .919 r
.48903 .85173 m .48884 .85206 L .48811 .85091 L F
.785 .382 .289 r
.49013 .85271 m .4896 .85323 L .48811 .85091 L F
.24 .732 .919 r
.4891 .85161 m .48903 .85173 L .48811 .85091 L F
.881 .851 .81 r
.4929 .84885 m .4909 .85197 L .4891 .85161 L F
.55 .387 .613 r
.4929 .84885 m .49316 .85149 L .4909 .85197 L F
.029 0 0 r
.49125 .85261 m .4909 .85197 L .49316 .85149 L F
.931 .965 .758 r
.49315 .85044 m .49125 .85261 L .49316 .85149 L F
.881 .851 .81 r
.49238 .85087 m .4891 .85161 L .49223 .85137 L F
.49238 .85087 m .49223 .85137 L .49226 .85135 L F
0 0 .15 r
.49314 .84952 m .49316 .85149 L .4929 .84885 L F
.931 .965 .758 r
.49163 .85199 m .49125 .85261 L .49315 .85044 L F
.485 .34 .609 r
.49223 .85137 m .49125 .85261 L .49225 .85137 L F
.029 0 0 r
.49125 .85261 m .4896 .85323 L .4909 .85197 L F
.485 .34 .609 r
.4891 .85161 m .49125 .85261 L .49223 .85137 L F
.931 .965 .758 r
.49314 .84952 m .49163 .85199 L .49223 .85137 L F
.49315 .85023 m .49223 .85137 L .49315 .85044 L F
.49314 .84952 m .49223 .85137 L .49315 .85023 L F
.881 .851 .81 r
.49226 .85135 m .49223 .85137 L .49225 .85137 L F
.4929 .84885 m .49003 .85094 L .49238 .85087 L F
.49003 .85094 m .4891 .85161 L .49238 .85087 L F
.887 .836 .79 r
.50668 .85128 m .50793 .85192 L .50658 .85381 L F
.782 .868 .912 r
.51006 .85022 m .50793 .85192 L .50668 .85128 L F
.666 .587 .757 r
.51006 .85022 m .51078 .85374 L .50793 .85192 L F
.773 .729 .812 r
.58216 .77617 m .58336 .77868 L .5815 .77975 L F
.426 .458 .79 r
.58346 .78143 m .5815 .77975 L .58336 .77868 L F
.779 .732 .809 r
.58527 .77646 m .58336 .77868 L .58216 .77617 L F
.623 .488 .677 r
.58527 .77646 m .58571 .77917 L .58336 .77868 L F
.605 .401 .578 r
.58571 .77917 m .58346 .78143 L .58336 .77868 L F
.625 .301 .403 r
.58095 .84141 m .57775 .84355 L .57902 .84161 L F
.58095 .84141 m .57995 .84362 L .57775 .84355 L F
.673 .65 .82 r
.58261 .83957 m .58095 .84141 L .57973 .83878 L F
.674 .356 .427 r
.58095 .84141 m .58307 .8435 L .57995 .84362 L F
.702 .699 .845 r
.58299 .84085 m .58095 .84141 L .58261 .83957 L F
.611 .367 .523 r
.58299 .84085 m .58307 .8435 L .58095 .84141 L F
.481 .052 .147 r
.38528 .83052 m .38863 .82883 L .38685 .82915 L F
.579 .349 .532 r
.61748 .77598 m .61524 .7788 L .61533 .77691 L F
.886 .672 .609 r
.5596 .80525 m .56035 .80779 L .55882 .80759 L F
.861 .534 .431 r
.55882 .80759 m .56035 .80779 L .55931 .8096 L F
.684 .611 .768 r
.56169 .8043 m .56035 .80779 L .5596 .80525 L F
.56169 .8043 m .56287 .80775 L .56035 .80779 L F
.969 .715 .497 r
.56035 .80779 m .56039 .81024 L .55931 .8096 L F
.78 .635 .7 r
.56287 .80775 m .56039 .81024 L .56035 .80779 L F
.549 .293 .48 r
.62752 .76821 m .62679 .77104 L .6246 .77125 L F
.567 .365 .566 r
.62976 .76625 m .62953 .76824 L .62752 .76821 L F
.601 .361 .525 r
.62953 .76824 m .62679 .77104 L .62752 .76821 L F
.586 .262 .388 r
.38585 .84904 m .38249 .85133 L .38264 .84909 L F
.38585 .84904 m .38494 .85126 L .38249 .85133 L F
.206 0 .205 r
.38642 .8507 m .38585 .84904 L .38785 .84935 L F
.38642 .8507 m .38494 .85126 L .38585 .84904 L F
.473 .071 .197 r
.37981 .83253 m .37912 .83074 L .37775 .83254 L F
.37981 .83253 m .38118 .83063 L .37912 .83074 L F
.709 .733 .87 r
.57819 .77861 m .57492 .77818 L .57687 .77621 L F
.585 .6 .833 r
.5791 .77644 m .57819 .77861 L .57687 .77621 L F
.5791 .77644 m .5799 .77838 L .57819 .77861 L F
.886 .672 .609 r
.5596 .80525 m .55882 .80759 L .5572 .80473 L F
.598 .344 .502 r
.38053 .84996 m .38222 .85135 L .38022 .85151 L F
.633 .41 .561 r
.38264 .84909 m .38222 .85135 L .38053 .84996 L F
.303 0 0 r
.4266 .8805 m .42761 .88026 L .42434 .88021 L F
.304 .787 .714 r
.42939 .87955 m .42761 .88026 L .42859 .8798 L F
.305 .793 .751 r
.42859 .8798 m .42761 .88026 L .4266 .8805 L F
.494 .9 .918 r
.39893 .90008 m .3998 .89914 L .39769 .89993 L F
.39893 .90008 m .40143 .89912 L .3998 .89914 L F
.535 .54 .807 r
.37816 .75769 m .37647 .75906 L .37586 .75671 L F
.458 .392 .695 r
.37816 .75769 m .37695 .76101 L .37647 .75906 L F
.543 .323 .531 r
.59293 .83382 m .59272 .83591 L .59059 .83619 L F
.521 .315 .541 r
.59493 .83337 m .59272 .83591 L .59293 .83382 L F
0 0 0 r
.50755 .87334 m .50386 .87475 L .50596 .87504 L F
.425 0 .105 r
.5083 .87465 m .50755 .87334 L .50596 .87504 L F
.5083 .87465 m .50943 .87325 L .50755 .87334 L F
.528 .493 .761 r
.51225 .8513 m .51078 .85374 L .51006 .85022 L F
.121 .286 .759 r
.51216 .85385 m .51078 .85374 L .51225 .8513 L F
.675 .659 .827 r
.57021 .83814 m .57149 .83633 L .56879 .83891 L F
.256 .413 .828 r
.35623 .73455 m .35564 .73607 L .35483 .73494 L F
.35623 .73455 m .35757 .73724 L .35564 .73607 L F
.475 .393 .684 r
.35564 .73607 m .35757 .73724 L .3559 .73778 L F
.033 0 0 r
.40544 .89822 m .40343 .89862 L .40447 .89814 L F
.294 .789 .867 r
.405 .89826 m .40343 .89862 L .40544 .89822 L F
.287 .78 .732 r
.40194 .89895 m .40447 .89814 L .40343 .89862 L F
.294 .789 .867 r
.40061 .89868 m .40343 .89862 L .405 .89826 L F
.287 .78 .732 r
.40143 .89912 m .40194 .89895 L .40343 .89862 L F
.029 0 0 r
.40654 .89761 m .40544 .89822 L .40447 .89814 L F
0 0 0 r
.53138 .86705 m .53181 .86636 L .53261 .86576 L F
.962 .754 .577 r
.57149 .83633 m .57186 .83367 L .57054 .83311 L F
.715 .961 .944 r
.39385 .88565 m .39025 .88695 L .39286 .88554 L F
.768 .929 .939 r
.39591 .8844 m .39385 .88565 L .39395 .88416 L F
.853 .98 .863 r
.39385 .88565 m .39286 .88554 L .39395 .88416 L F
.294 0 0 r
.39112 .8492 m .38975 .84949 L .38785 .84935 L F
.437 .242 .516 r
.39309 .84643 m .39112 .8492 L .39128 .84729 L F
.39309 .84643 m .39331 .84896 L .39112 .8492 L F
.581 .228 .335 r
.39331 .84896 m .38975 .84949 L .39112 .8492 L F
.62 .159 .135 r
.46235 .87185 m .46055 .87063 L .46022 .87256 L F
.779 .678 .752 r
.57458 .8388 m .57564 .84142 L .57248 .84093 L F
.665 .385 .486 r
.57564 .84142 m .57242 .84367 L .57248 .84093 L F
.57564 .84142 m .57584 .84352 L .57242 .84367 L F
.67 .389 .486 r
.57564 .84142 m .57775 .84355 L .57584 .84352 L F
.672 .388 .483 r
.57564 .84142 m .57902 .84161 L .57775 .84355 L F
.856 .636 .604 r
.49509 .83127 m .49669 .83342 L .49675 .83188 L F
.773 .729 .812 r
.58216 .77617 m .5815 .77975 L .5799 .77838 L F
.482 .809 1 r
.51749 .8643 m .51887 .86497 L .51965 .86399 L F
.51965 .86399 m .51887 .86497 L .51749 .8643 L F
.649 .776 .941 r
.5446 .83011 m .54809 .83071 L .54572 .83104 L F
0 0 .419 r
.5473 .82877 m .54706 .82869 L .54809 .83071 L F
.54701 .82806 m .54702 .82814 L .5473 .82877 L F
.54702 .82814 m .54706 .82869 L .5473 .82877 L F
.54701 .82806 m .5473 .82877 L .5446 .83011 L F
.5473 .82877 m .54809 .83071 L .54684 .8305 L F
.5473 .82877 m .54684 .8305 L .5446 .83011 L F
.402 .834 .953 r
.54572 .83104 m .54791 .83074 L .54809 .83051 L F
.54791 .83074 m .54809 .83071 L .54809 .83051 L F
.414 .22 .506 r
.54809 .83071 m .55002 .82786 L .54929 .82993 L F
.402 .834 .953 r
.54809 .83051 m .54809 .83071 L .54874 .83037 L F
0 0 0 r
.54878 .83037 m .54809 .83071 L .54929 .82993 L F
.552 .464 .708 r
.54781 .83103 m .54641 .83359 L .5475 .83125 L F
0 0 0 r
.54763 .83116 m .54809 .83071 L .54878 .83037 L F
.54874 .83037 m .54809 .83071 L .54763 .83116 L F
.552 .464 .708 r
.5483 .83098 m .54641 .83359 L .54809 .83051 L F
0 0 0 r
.54631 .83243 m .54763 .83116 L .54878 .83037 L F
.552 .464 .708 r
.54874 .83037 m .54871 .83041 L .54809 .83051 L F
.54871 .83041 m .5483 .83098 L .5482 .83076 L F
.54871 .83041 m .5482 .83076 L .54809 .83051 L F
0 0 0 r
.54874 .83037 m .54763 .83116 L .54631 .83243 L F
.552 .464 .708 r
.5475 .83125 m .54641 .83359 L .54621 .83286 L F
.54809 .83051 m .54781 .83103 L .5475 .83125 L F
.54676 .83081 m .54621 .83286 L .54572 .83104 L F
.54809 .83051 m .54621 .83286 L .54676 .83081 L F
.565 .652 .894 r
.5942 .82964 m .59707 .83076 L .59506 .83115 L F
.484 .278 .524 r
.59707 .83076 m .59493 .83337 L .59506 .83115 L F
.707 .406 .465 r
.41859 .83874 m .41744 .84114 L .41557 .84038 L F
.615 .303 .418 r
.42075 .84025 m .41744 .84114 L .41859 .83874 L F
.608 .149 .138 r
.54027 .81644 m .54251 .81758 L .53916 .81732 L F
.583 .532 .764 r
.37031 .7454 m .37102 .74736 L .36889 .7477 L F
.542 .437 .684 r
.37102 .74736 m .36945 .75076 L .36889 .7477 L F
.103 0 0 r
.43751 .88886 m .43787 .88925 L .43584 .88965 L F
.43751 .88886 m .43964 .88865 L .43787 .88925 L F
.666 .216 .173 r
.50829 .80788 m .51034 .80938 L .51125 .80809 L F
.674 .225 .177 r
.51034 .80938 m .51356 .80972 L .51125 .80809 L F
.387 .152 .432 r
.61073 .77354 m .6136 .77308 L .61358 .76992 L F
.443 .243 .513 r
.61358 .76992 m .61454 .76963 L .61534 .76848 L F
.345 .109 .407 r
.6136 .77308 m .61454 .76963 L .61358 .76992 L F
.203 .681 .934 r
.46898 .8715 m .46567 .87079 L .46734 .87068 L F
.486 .532 .83 r
.46978 .86927 m .46898 .8715 L .46734 .87068 L F
.46978 .86927 m .47096 .87184 L .46898 .8715 L F
.372 .044 .274 r
.52032 .87533 m .52301 .8725 L .52219 .87469 L F
.245 0 .189 r
.52219 .87469 m .52301 .8725 L .52476 .87171 L F
.685 .731 .885 r
.56612 .77678 m .56737 .77919 L .56431 .77866 L F
.597 .687 .905 r
.56951 .77879 m .56737 .77919 L .56612 .77678 L F
.963 .773 .599 r
.40703 .88331 m .40637 .88521 L .40835 .88227 L F
.648 .385 .508 r
.62289 .76199 m .62262 .76364 L .62618 .76144 L F
.606 .398 .574 r
.63197 .76794 m .62976 .76625 L .63197 .76602 L F
.63197 .76794 m .62953 .76824 L .62976 .76625 L F
.204 .372 .809 r
.56847 .79952 m .5716 .79993 L .57102 .79898 L F
.56847 .79952 m .57119 .80285 L .5716 .79993 L F
.395 .663 .966 r
.5729 .79902 m .5716 .79993 L .57102 .79898 L F
.342 0 0 r
.44041 .82012 m .44252 .82009 L .44397 .81923 L F
.368 0 0 r
.44252 .82009 m .44585 .81935 L .44397 .81923 L F
.634 .579 .775 r
.56904 .82565 m .56748 .82672 L .56582 .82308 L F
.56904 .82565 m .56582 .82308 L .5686 .82331 L F
.56904 .82565 m .5686 .82331 L .56736 .82512 L F
0 0 0 r
.56685 .82727 m .56748 .82672 L .56904 .82565 L F
.56576 .82808 m .56655 .82746 L .56685 .82727 L F
.56655 .82746 m .56748 .82672 L .56685 .82727 L F
.56576 .82808 m .56904 .82565 L .56736 .82512 L F
.112 .016 .456 r
.56803 .82655 m .56736 .82512 L .56906 .82416 L F
.56753 .82772 m .56748 .82689 L .56803 .82655 L F
.56748 .82689 m .56736 .82512 L .56803 .82655 L F
.446 .105 .293 r
.47456 .81552 m .47672 .81516 L .47756 .81284 L F
.221 0 .195 r
.47756 .81284 m .47838 .81422 L .47963 .81231 L F
.47756 .81284 m .47672 .81516 L .47838 .81422 L F
.708 .914 .966 r
.50511 .86059 m .50153 .86107 L .50366 .85926 L F
.906 .497 .181 r
.50492 .86139 m .50511 .86059 L .50366 .85926 L F
.50492 .86139 m .50604 .86196 L .50511 .86059 L F
.307 .797 .874 r
.43941 .87519 m .43745 .87564 L .4366 .87655 L F
.972 .747 .538 r
.48789 .87959 m .48916 .87775 L .48585 .87788 L F
.638 .496 .673 r
.48916 .87775 m .4915 .87762 L .49127 .87538 L F
.616 .378 .534 r
.49116 .87976 m .4915 .87762 L .48916 .87775 L F
.537 .378 .613 r
.48916 .87775 m .48912 .88022 L .49116 .87976 L F
.412 .613 .932 r
.491 .87807 m .4884 .87802 L .48693 .87532 L F
.4884 .87802 m .48834 .87802 L .48817 .8777 L F
.4884 .87802 m .48817 .8777 L .48693 .87532 L F
.972 .747 .538 r
.48789 .87959 m .48912 .88022 L .48914 .87906 L F
.48869 .87843 m .48914 .87906 L .48916 .87775 L F
.48789 .87959 m .48914 .87906 L .48869 .87843 L F
.392 0 .004 r
.40461 .82603 m .40668 .82596 L .40768 .82523 L F
.501 .044 .1 r
.40768 .82523 m .40668 .82596 L .40971 .82535 L F
.449 .209 .456 r
.67034 .7451 m .67013 .74737 L .66798 .74766 L F
.56 .333 .528 r
.6726 .74471 m .67013 .74737 L .67034 .7451 L F
.258 .751 .671 r
.51972 .86978 m .51609 .87114 L .51875 .87109 L F
.516 .127 .242 r
.52079 .87174 m .51972 .86978 L .51875 .87109 L F
.52079 .87174 m .52197 .86977 L .51972 .86978 L F
.523 .724 .965 r
.46303 .83355 m .46309 .83119 L .46508 .83097 L F
.594 .398 .586 r
.46508 .83097 m .46515 .83352 L .46303 .83355 L F
.481 .263 .505 r
.46761 .82834 m .46714 .83086 L .46508 .83097 L F
.717 .495 .588 r
.46822 .83311 m .46508 .83097 L .46714 .83086 L F
.46822 .83311 m .46515 .83352 L .46508 .83097 L F
.831 .742 .766 r
.59059 .83619 m .58773 .83609 L .58961 .8336 L F
.831 .735 .759 r
.59059 .83619 m .58699 .83769 L .58773 .83609 L F
.59059 .83619 m .58847 .83879 L .58699 .83769 L F
.644 .451 .607 r
.59059 .83619 m .59071 .83878 L .58847 .83879 L F
.515 .352 .598 r
.5928 .83833 m .59059 .83619 L .59272 .83591 L F
.5928 .83833 m .59071 .83878 L .59059 .83619 L F
.282 0 0 r
.45449 .83133 m .45318 .83251 L .45116 .83277 L F
.254 0 0 r
.45522 .83219 m .45449 .83133 L .4565 .83145 L F
.45522 .83219 m .45318 .83251 L .45449 .83133 L F
.646 .865 .982 r
.50369 .83596 m .50159 .83677 L .50013 .83581 L F
.773 .408 .364 r
.50447 .83865 m .50159 .83677 L .50369 .83596 L F
.50447 .83865 m .50205 .83849 L .50159 .83677 L F
.513 .486 .764 r
.58894 .78376 m .58791 .78688 L .58746 .78482 L F
.58894 .78376 m .58973 .78648 L .58791 .78688 L F
.96 .719 .53 r
.58973 .78648 m .58839 .78751 L .58791 .78688 L F
.589 .506 .729 r
.58856 .79224 m .58678 .79477 L .58639 .79245 L F
.618 .545 .751 r
.58856 .79224 m .589 .79478 L .58678 .79477 L F
.597 .331 .484 r
.58678 .79477 m .58895 .79657 L .58683 .79701 L F
.58678 .79477 m .589 .79478 L .58895 .79657 L F
.948 .832 .697 r
.50484 .86505 m .50604 .86196 L .50492 .86139 L F
0 .094 .61 r
.44837 .87229 m .44741 .87269 L .4471 .87062 L F
.78 .635 .7 r
.56287 .80775 m .56179 .81091 L .56039 .81024 L F
.722 .631 .756 r
.56459 .80488 m .56287 .80775 L .56169 .8043 L F
.467 .313 .589 r
.56467 .80766 m .56287 .80775 L .56459 .80488 L F
.354 .187 .512 r
.56323 .80944 m .56287 .80775 L .56467 .80766 L F
.56323 .80944 m .56179 .81091 L .56287 .80775 L F
.521 .213 .386 r
.62245 .76553 m .62618 .76144 L .62262 .76364 L F
.62245 .76553 m .62464 .76531 L .62618 .76144 L F
.478 .178 .377 r
.62464 .76531 m .6279 .76192 L .62618 .76144 L F
.605 .56 .777 r
.57035 .83131 m .56832 .83224 L .56666 .82907 L F
.659 .801 .951 r
.49063 .82986 m .49006 .83211 L .4923 .83094 L F
.539 0 0 r
.47412 .87345 m .47292 .87239 L .47146 .87147 L F
.47487 .874 m .47292 .87239 L .47412 .87345 L F
.586 .142 .162 r
.47292 .87239 m .47436 .87138 L .47212 .87169 L F
.47292 .87239 m .47212 .87169 L .47096 .87184 L F
.907 .498 .152 r
.47487 .874 m .47436 .87138 L .47292 .87239 L F
.47487 .874 m .47473 .87215 L .47436 .87138 L F
.903 .495 .204 r
.5572 .80473 m .55756 .80708 L .55604 .80464 L F
.5572 .80473 m .55882 .80759 L .55756 .80708 L F
.364 .27 .613 r
.61073 .77354 m .61372 .77562 L .6136 .77308 L F
.61073 .77354 m .61106 .77882 L .61372 .77562 L F
.887 .836 .79 r
.50668 .85128 m .50658 .85381 L .50585 .85196 L F
.799 .332 0 r
.50658 .85381 m .50657 .85452 L .50585 .85196 L F
.50658 .85381 m .50745 .85517 L .50657 .85452 L F
.409 0 0 r
.38863 .82883 m .39035 .82941 L .39188 .82844 L F
.175 0 0 r
.39035 .82941 m .39395 .82835 L .39188 .82844 L F
.353 0 0 r
.45092 .81934 m .45305 .81935 L .45446 .81841 L F
.513 .064 .12 r
.45305 .81935 m .45642 .81815 L .45446 .81841 L F
.524 0 0 r
.46676 .88139 m .46786 .88081 L .46993 .88171 L F
.341 0 0 r
.42971 .89043 m .43029 .89145 L .42857 .89159 L F
.42971 .89043 m .43175 .89019 L .43029 .89145 L F
.473 .823 .997 r
.57496 .79188 m .57902 .79213 L .5772 .7908 L F
0 .231 .745 r
.57902 .79213 m .57898 .79129 L .5772 .7908 L F
.57902 .79213 m .57962 .79236 L .57898 .79129 L F
.155 0 0 r
.42334 .89279 m .4248 .89204 L .42637 .89188 L F
.619 .212 .25 r
.48632 .82843 m .48511 .83017 L .48313 .82888 L F
.792 .548 .569 r
.48826 .82849 m .48511 .83017 L .48632 .82843 L F
.613 .447 .633 r
.61524 .7788 m .61311 .78153 L .61321 .77924 L F
.648 .62 .809 r
.58531 .83892 m .58299 .84085 L .58261 .83957 L F
.58531 .83892 m .58618 .84132 L .58299 .84085 L F
.652 .376 .489 r
.58618 .84132 m .58307 .8435 L .58299 .84085 L F
.655 .4 .523 r
.39524 .8486 m .39309 .84643 L .39491 .84643 L F
.39524 .8486 m .39331 .84896 L .39309 .84643 L F
.543 .337 .552 r
.66798 .74766 m .66825 .75022 L .6662 .75045 L F
.527 .326 .551 r
.67054 .74968 m .66798 .74766 L .67013 .74737 L F
.67054 .74968 m .66825 .75022 L .66798 .74766 L F
.742 .409 .417 r
.48313 .82888 m .47989 .83004 L .48117 .82922 L F
.501 0 0 r
.50737 .82536 m .50961 .82574 L .50799 .82647 L F
.902 .557 .381 r
.55372 .80215 m .55588 .80312 L .55604 .80464 L F
.777 .775 .85 r
.51179 .82102 m .50829 .82108 L .51051 .82241 L F
.572 .233 .356 r
.51051 .82241 m .51382 .82013 L .51179 .82102 L F
.551 .206 .336 r
.49267 .82101 m .49204 .82295 L .4895 .82305 L F
.458 .118 .3 r
.49439 .82208 m .49204 .82295 L .49267 .82101 L F
.494 .081 .187 r
.49482 .82098 m .49439 .82208 L .49267 .82101 L F
.541 .096 .143 r
.47685 .83316 m .47656 .83447 L .47354 .83364 L F
0 0 .187 r
.47829 .8307 m .47771 .83282 L .47685 .83316 L F
0 0 0 r
.47771 .83282 m .47656 .83447 L .47685 .83316 L F
.547 .855 .997 r
.40637 .88521 m .40442 .88577 L .40303 .8852 L F
0 0 .314 r
.46883 .83101 m .46923 .828 L .46761 .82834 L F
.46883 .83101 m .46932 .83041 L .46923 .828 L F
.616 .427 .604 r
.46883 .83101 m .46714 .83086 L .46932 .83041 L F
.46883 .83101 m .46822 .83311 L .46714 .83086 L F
.46883 .83101 m .47043 .83336 L .46822 .83311 L F
.521 .114 .209 r
.4173 .8234 m .41899 .82448 L .42027 .82254 L F
.598 .249 .349 r
.41899 .82448 m .42247 .82247 L .42027 .82254 L F
.542 .437 .684 r
.37102 .74736 m .3713 .75057 L .36945 .75076 L F
.628 .498 .685 r
.3713 .75057 m .36952 .75305 L .36945 .75076 L F
0 .147 .691 r
.48575 .81038 m .48501 .81037 L .4839 .81067 L F
.648 .367 .481 r
.48501 .81037 m .48763 .81324 L .48757 .8108 L F
0 .147 .691 r
.48575 .81038 m .48763 .81324 L .48501 .81037 L F
.638 .305 .391 r
.48501 .81037 m .48757 .8108 L .48748 .81056 L F
0 0 0 r
.50394 .88473 m .50493 .88448 L .5031 .88528 L F
.50394 .88473 m .50629 .88316 L .50493 .88448 L F
.634 .351 .471 r
.61104 .78191 m .60723 .78348 L .60833 .78381 L F
.61104 .78191 m .61084 .78381 L .60723 .78348 L F
.615 .334 .468 r
.61104 .78191 m .61311 .78372 L .61084 .78381 L F
.555 .347 .553 r
.61311 .78153 m .61311 .78372 L .61104 .78191 L F
.477 .042 .133 r
.46309 .83119 m .46241 .83195 L .45954 .83221 L F
.523 .724 .965 r
.46303 .83355 m .46241 .83195 L .46309 .83119 L F
.636 .402 .546 r
.52613 .81053 m .52527 .81261 L .52343 .81228 L F
.666 .434 .56 r
.52814 .81249 m .52613 .81053 L .5274 .81012 L F
.52814 .81249 m .52527 .81261 L .52613 .81053 L F
.379 .843 .863 r
.39182 .90248 m .39239 .90198 L .3905 .90256 L F
.39182 .90248 m .39435 .90176 L .39239 .90198 L F
.969 .932 .644 r
.56892 .81493 m .56893 .81637 L .5682 .81804 L F
.718 .537 .645 r
.56893 .81637 m .57054 .81837 L .5682 .81804 L F
.507 .513 .797 r
.57105 .81451 m .56893 .81637 L .56892 .81493 L F
.57105 .81451 m .57217 .81759 L .56893 .81637 L F
.533 .496 .761 r
.57217 .81759 m .57054 .81837 L .56893 .81637 L F
.452 .472 .789 r
.3717 .75477 m .37056 .75616 L .36952 .75305 L F
.479 .511 .813 r
.3717 .75477 m .37238 .7562 L .37056 .75616 L F
.765 .75 .839 r
.49721 .8439 m .50033 .84414 L .49901 .84289 L F
.611 .718 .922 r
.49901 .84289 m .50033 .84414 L .50272 .84349 L F
.527 .3 .513 r
.62003 .77353 m .61952 .77607 L .61748 .77598 L F
.587 .367 .548 r
.6222 .77336 m .61952 .77607 L .62003 .77353 L F
.518 .85 .997 r
.39581 .88313 m .39591 .8844 L .39395 .88416 L F
.39581 .88313 m .39789 .8839 L .39591 .8844 L F
.658 .629 .809 r
.48942 .86765 m .49035 .87044 L .49088 .86984 L F
.734 .58 .683 r
.49575 .82763 m .49932 .82884 L .49928 .82855 L F
.745 .428 .447 r
.50004 .82811 m .49973 .82867 L .49928 .82855 L F
.49905 .828 m .49928 .82855 L .49575 .82763 L F
.50004 .82811 m .49928 .82855 L .49905 .828 L F
.002 .05 .558 r
.49883 .82552 m .49928 .82855 L .50027 .82792 L F
.49928 .82855 m .49932 .82884 L .49937 .82879 L F
.49928 .82855 m .49937 .82879 L .50027 .82792 L F
.734 .58 .683 r
.49575 .82763 m .49928 .82855 L .49883 .82552 L F
.757 .416 .406 r
.49932 .82884 m .49888 .8302 L .49575 .82763 L F
.745 .428 .447 r
.49973 .82867 m .49888 .8302 L .49575 .82763 L F
.425 0 .119 r
.50224 .82834 m .49973 .82972 L .50004 .82811 L F
.034 0 .117 r
.49934 .82881 m .50077 .82909 L .50027 .82792 L F
.49932 .82884 m .49936 .82885 L .49934 .82881 L F
.425 0 .119 r
.49973 .82972 m .49948 .82912 L .50004 .82811 L F
.034 0 .117 r
.49936 .82885 m .50077 .82909 L .49934 .82881 L F
.425 0 .119 r
.49973 .82972 m .49888 .8302 L .49948 .82912 L F
.658 .603 .781 r
.58659 .78363 m .58442 .78412 L .58346 .78143 L F
.659 .611 .79 r
.58659 .78363 m .58746 .78482 L .58442 .78412 L F
.539 .315 .523 r
.46932 .83041 m .46761 .82834 L .46923 .828 L F
.46932 .83041 m .46714 .83086 L .46761 .82834 L F
.525 0 0 r
.53951 .82261 m .53972 .81914 L .539 .82071 L F
.536 .339 .56 r
.37695 .76101 m .37695 .76311 L .37493 .76336 L F
.557 .354 .561 r
.37695 .76311 m .37518 .76525 L .37493 .76336 L F
.538 .921 .92 r
.40815 .89729 m .41207 .89618 L .4101 .89676 L F
.442 .042 .184 r
.50856 .81806 m .50728 .8198 L .50517 .81987 L F
.304 0 .096 r
.50931 .81911 m .50856 .81806 L .51071 .81799 L F
.50931 .81911 m .50728 .8198 L .50856 .81806 L F
.311 0 0 r
.44162 .8883 m .44242 .88745 L .44452 .88716 L F
.513 .108 .21 r
.42451 .82271 m .42666 .82276 L .42789 .821 L F
.466 .053 .172 r
.42666 .82276 m .42987 .821 L .42789 .821 L F
.757 .769 .862 r
.58444 .77432 m .58527 .77646 L .58216 .77617 L F
.633 .605 .804 r
.58628 .77296 m .58527 .77646 L .58444 .77432 L F
.58628 .77296 m .58758 .776 L .58527 .77646 L F
.674 .559 .716 r
.58758 .776 m .58571 .77917 L .58527 .77646 L F
.458 .392 .695 r
.37816 .75769 m .37876 .76094 L .37695 .76101 L F
.581 .451 .667 r
.37876 .76094 m .37695 .76311 L .37695 .76101 L F
.713 .424 .486 r
.49672 .87612 m .49663 .8748 L .49317 .87488 L F
.643 .371 .492 r
.49672 .87612 m .49846 .87682 L .49663 .8748 L F
.689 .367 .426 r
.49846 .87682 m .49885 .87543 L .49663 .8748 L F
.571 .39 .598 r
.49501 .84393 m .49721 .8439 L .4971 .84116 L F
.49501 .84393 m .49721 .8439 L .4971 .84116 L F
.636 .441 .602 r
.4971 .84116 m .49721 .8439 L .49901 .84289 L F
.524 .86 .589 r
.502 .86061 m .50366 .85926 L .50153 .86107 L F
.855 .427 .204 r
.50302 .86097 m .50366 .85926 L .502 .86061 L F
.50302 .86097 m .50492 .86139 L .50366 .85926 L F
.579 .349 .532 r
.61748 .77598 m .61743 .7786 L .61524 .7788 L F
.602 .405 .588 r
.61952 .77607 m .61743 .7786 L .61748 .77598 L F
.327 .683 .979 r
.41255 .88163 m .41175 .88233 L .41069 .88141 L F
.41255 .88163 m .41373 .88252 L .41175 .88233 L F
0 0 .235 r
.53825 .83127 m .53801 .83071 L .53838 .83095 L F
.097 0 .187 r
.53728 .83298 m .53801 .83071 L .53825 .83127 L F
0 0 .14 r
.53728 .83298 m .53801 .83071 L .53838 .83095 L F
.638 .525 .709 r
.49127 .87538 m .49317 .87488 L .4924 .87346 L F
.592 .386 .57 r
.49324 .87714 m .49317 .87488 L .49127 .87538 L F
.494 .39 .666 r
.49127 .87538 m .4915 .87762 L .49324 .87714 L F
.592 .386 .57 r
.49324 .87714 m .49317 .87488 L .49127 .87538 L F
.182 0 .174 r
.57439 .78963 m .57642 .78892 L .57701 .78693 L F
.585 .637 .869 r
.57625 .78455 m .57701 .78693 L .57798 .78572 L F
0 0 .008 r
.57701 .78693 m .57709 .78816 L .57798 .78572 L F
.57701 .78693 m .57642 .78892 L .57709 .78816 L F
0 0 .514 r
.54477 .81245 m .54604 .81562 L .54534 .81574 L F
0 .314 .768 r
.54706 .81643 m .54534 .81574 L .54604 .81562 L F
.54706 .81643 m .54792 .81729 L .54534 .81574 L F
.281 .309 .713 r
.56231 .80121 m .56109 .80246 L .55973 .79899 L F
.527 .339 .569 r
.37272 .76598 m .3725 .76847 L .37052 .76881 L F
.519 .31 .535 r
.37262 .76969 m .37052 .76881 L .3725 .76847 L F
.37262 .76969 m .3704 .77019 L .37052 .76881 L F
.049 .232 .73 r
.52221 .81919 m .52229 .8206 L .52114 .81771 L F
.095 .65 .791 r
.45642 .81815 m .45833 .81808 L .45969 .81816 L F
.357 0 0 r
.45833 .81808 m .4617 .81776 L .45969 .81816 L F
.928 .868 .759 r
.55499 .79706 m .55244 .79907 L .55377 .79641 L F
.55499 .79706 m .55334 .79979 L .55244 .79907 L F
.242 .642 .961 r
.55576 .79645 m .55499 .79706 L .55377 .79641 L F
.55576 .79645 m .55678 .79726 L .55499 .79706 L F
.461 0 .03 r
.50469 .80922 m .50829 .80788 L .50646 .80737 L F
0 0 0 r
.60671 .78195 m .60665 .78207 L .60822 .77964 L F
.913 .552 .103 r
.60671 .78195 m .60723 .78348 L .60665 .78207 L F
.477 .839 .585 r
.52874 .8328 m .5278 .83362 L .53017 .83171 L F
0 0 0 r
.52874 .8328 m .53017 .83171 L .53198 .83066 L F
.523 .724 .965 r
.46303 .83355 m .46406 .83223 L .46241 .83195 L F
.46303 .83355 m .46515 .83352 L .46406 .83223 L F
.229 0 0 r
.36365 .77396 m .36548 .77357 L .36348 .77415 L F
.448 .436 .753 r
.36002 .7366 m .35907 .73981 L .35757 .73724 L F
.36002 .7366 m .36075 .73995 L .35907 .73981 L F
0 0 0 r
.51383 .87908 m .51433 .87886 L .51235 .87955 L F
.51383 .87908 m .51604 .87789 L .51433 .87886 L F
.476 .008 .064 r
.51356 .80972 m .51566 .80985 L .51703 .80864 L F
.41 0 .014 r
.51703 .80864 m .51566 .80985 L .51834 .80918 L F
.633 .41 .561 r
.38264 .84909 m .38249 .85133 L .38222 .85135 L F
.377 0 0 r
.40594 .84388 m .40453 .84341 L .40311 .84273 L F
0 0 0 r
.40791 .84088 m .40648 .84342 L .40594 .84388 L F
.292 .747 .955 r
.40594 .84388 m .40648 .84342 L .40453 .84341 L F
.483 .107 .249 r
.50043 .87643 m .50206 .87418 L .49885 .87543 L F
.589 .114 .094 r
.50232 .87594 m .50206 .87418 L .50043 .87643 L F
.50232 .87594 m .50386 .87475 L .50206 .87418 L F
.663 .502 .656 r
.63926 .76101 m .63938 .76318 L .63615 .76368 L F
.689 .566 .711 r
.64018 .75845 m .6414 .76092 L .63926 .76101 L F
.657 .477 .63 r
.6414 .76092 m .63938 .76318 L .63926 .76101 L F
.525 .327 .555 r
.37518 .76525 m .3725 .76847 L .37272 .76598 L F
.596 .392 .575 r
.63615 .76368 m .63419 .76621 L .6341 .76365 L F
.63615 .76368 m .63655 .76593 L .63419 .76621 L F
.577 .379 .576 r
.6386 .76534 m .63615 .76368 L .63938 .76318 L F
.6386 .76534 m .63655 .76593 L .63615 .76368 L F
.459 .847 .982 r
.52664 .83324 m .5278 .83362 L .52874 .8328 L F
.64 .584 .775 r
.57119 .80285 m .57261 .80544 L .56994 .80569 L F
.517 .023 .023 r
.42987 .821 m .43175 .82187 L .43316 .82075 L F
.464 0 .03 r
.43175 .82187 m .43524 .82072 L .43316 .82075 L F
.816 .53 .504 r
.48549 .87638 m .48789 .87959 L .48585 .87788 L F
.189 0 0 r
.40102 .82723 m .40304 .82695 L .40461 .82603 L F
.089 0 0 r
.40461 .82603 m .40509 .82653 L .40668 .82596 L F
.40461 .82603 m .40304 .82695 L .40509 .82653 L F
.453 .013 .11 r
.43461 .87687 m .43184 .87769 L .43374 .87735 L F
.329 0 0 r
.436 .87736 m .43461 .87687 L .43374 .87735 L F
.436 .87736 m .4366 .87655 L .43461 .87687 L F
.049 0 .281 r
.54769 .82609 m .5492 .82321 L .54928 .82562 L F
.566 .204 .313 r
.4013 .8454 m .40023 .84344 L .40311 .84273 L F
.4013 .8454 m .39917 .84569 L .40023 .84344 L F
0 0 0 r
.416 .89536 m .41941 .89341 L .41786 .89485 L F
.164 0 0 r
.41786 .89485 m .41941 .89341 L .42128 .89289 L F
.244 0 0 r
.58134 .79922 m .58458 .79724 L .58463 .79902 L F
.67 .371 .458 r
.58458 .79724 m .58672 .79925 L .58463 .79902 L F
.591 .385 .57 r
.58458 .79724 m .58683 .79701 L .58672 .79925 L F
.56 .582 .833 r
.56323 .81272 m .56039 .81024 L .56179 .81091 L F
.367 .445 .809 r
.5648 .81183 m .56179 .81091 L .56323 .80944 L F
.5648 .81183 m .56323 .81272 L .56179 .81091 L F
.705 .807 .928 r
.57017 .81007 m .56889 .81079 L .56956 .80921 L F
.419 .1 .316 r
.36937 .77274 m .36875 .77072 L .3704 .77019 L F
.36937 .77274 m .36744 .77318 L .36875 .77072 L F
.615 .534 .739 r
.50219 .82385 m .50204 .82169 L .50008 .82304 L F
.56 .577 .828 r
.58894 .78376 m .58746 .78482 L .58659 .78363 L F
.629 .571 .77 r
.35897 .75294 m .36058 .75113 L .3582 .75047 L F
.35897 .75294 m .36123 .75288 L .36058 .75113 L F
.63 .52 .71 r
.35902 .75319 m .36123 .75288 L .35897 .75294 L F
0 0 0 r
.50493 .88448 m .50629 .88316 L .50813 .88211 L F
.432 .873 .828 r
.49678 .88765 m .49941 .88629 L .49733 .88673 L F
.49678 .88765 m .50111 .88593 L .49941 .88629 L F
0 0 0 r
.64349 .75833 m .64487 .75756 L .64551 .75608 L F
.727 .989 .872 r
.64551 .75608 m .6462 .7548 L .6473 .75458 L F
0 0 0 r
.64551 .75608 m .64487 .75756 L .6462 .7548 L F
.113 .665 .79 r
.4777 .8748 m .47736 .875 L .47597 .87463 L F
.413 0 .128 r
.48041 .87425 m .47736 .875 L .47954 .87487 L F
.113 .665 .79 r
.4777 .8748 m .47954 .87487 L .47736 .875 L F
.589 .442 .649 r
.35933 .75565 m .36123 .75288 L .35902 .75319 L F
.548 .187 .307 r
.43862 .83357 m .43758 .83562 L .43533 .83559 L F
.425 .023 .172 r
.44075 .83354 m .43758 .83562 L .43862 .83357 L F
.56 .189 .294 r
.65206 .76104 m .65487 .76041 L .65419 .76233 L F
.526 .186 .335 r
.65487 .76041 m .6564 .76239 L .65419 .76233 L F
.65487 .76041 m .65701 .76022 L .6564 .76239 L F
0 0 0 r
.63855 .75911 m .63915 .75873 L .64018 .75845 L F
0 .522 .777 r
.64201 .75859 m .64018 .75845 L .63915 .75873 L F
.32 0 0 r
.64018 .75845 m .64312 .7589 L .64349 .75833 L F
0 .522 .777 r
.64201 .75859 m .64312 .7589 L .64018 .75845 L F
.65 .477 .637 r
.58077 .80951 m .58142 .80925 L .58158 .80774 L F
.369 .602 .938 r
.56753 .82772 m .56666 .82907 L .56576 .82808 L F
.56753 .82772 m .57048 .83039 L .56666 .82907 L F
.605 .56 .777 r
.57035 .83131 m .56666 .82907 L .57048 .83039 L F
.673 .525 .675 r
.6341 .76365 m .63419 .76621 L .63197 .76602 L F
0 .213 .738 r
.55999 .81294 m .56152 .81537 L .56127 .8143 L F
.619 .395 .555 r
.63197 .76602 m .63409 .76803 L .63197 .76794 L F
.663 .388 .493 r
.63419 .76621 m .63409 .76803 L .63197 .76602 L F
.652 .376 .489 r
.58618 .84132 m .58563 .8438 L .58307 .8435 L F
.775 .688 .768 r
.58847 .83879 m .58618 .84132 L .58531 .83892 L F
.481 .169 .359 r
.58854 .84106 m .58563 .8438 L .58618 .84132 L F
.639 .475 .645 r
.58854 .84106 m .58618 .84132 L .58847 .83879 L F
.775 .688 .768 r
.58847 .83879 m .58531 .83892 L .58699 .83769 L F
.464 .338 .623 r
.59016 .84047 m .58854 .84106 L .58847 .83879 L F
.62 .337 .467 r
.59071 .83878 m .59016 .84047 L .58847 .83879 L F
.464 .338 .623 r
.59016 .84047 m .58854 .84106 L .58847 .83879 L F
.581 .44 .654 r
.57536 .79003 m .5772 .7908 L .57642 .78892 L F
.57439 .78963 m .57496 .79188 L .5772 .7908 L F
.963 .751 .57 r
.5772 .7908 m .576 .79124 L .57642 .78892 L F
0 0 .311 r
.57642 .78892 m .576 .79124 L .57706 .78825 L F
.57642 .78892 m .57706 .78825 L .57709 .78816 L F
.581 .44 .654 r
.57439 .78963 m .57536 .79003 L .57642 .78892 L F
.726 .665 .789 r
.49657 .80762 m .49454 .80811 L .49763 .80758 L F
.957 .682 .475 r
.49648 .80924 m .49763 .80758 L .49454 .80811 L F
0 0 0 r
.44657 .88703 m .45001 .88545 L .44855 .88691 L F
.156 0 0 r
.44855 .88691 m .45001 .88545 L .45196 .8848 L F
.782 .868 .912 r
.51006 .85022 m .50668 .85128 L .50925 .85012 L F
.614 .066 0 r
.51049 .85112 m .51006 .85022 L .50925 .85012 L F
.51049 .85112 m .51225 .8513 L .51006 .85022 L F
.657 .477 .63 r
.6414 .76092 m .6415 .76344 L .63938 .76318 L F
.664 .519 .676 r
.64349 .75833 m .64379 .7607 L .6414 .76092 L F
.627 .436 .605 r
.64379 .7607 m .6415 .76344 L .6414 .76092 L F
.287 .709 .971 r
.56402 .80424 m .56459 .80488 L .56169 .8043 L F
.501 .848 .995 r
.56644 .8044 m .56459 .80488 L .56402 .80424 L F
.751 .396 .381 r
.56459 .80488 m .56699 .80751 L .56467 .80766 L F
.655 .344 .433 r
.40999 .84292 m .40791 .84088 L .40992 .84089 L F
.40999 .84292 m .40648 .84342 L .40791 .84088 L F
.22 0 0 r
.45196 .8848 m .45482 .88456 L .45398 .88474 L F
0 0 0 r
.45482 .88456 m .45602 .88436 L .45398 .88474 L F
.45482 .88456 m .4575 .88345 L .45602 .88436 L F
.867 .618 .56 r
.56536 .83872 m .56712 .84125 L .56571 .84077 L F
.764 .368 .304 r
.56925 .84325 m .5713 .84552 L .57092 .84544 L F
.56904 .84356 m .57092 .84544 L .56818 .84485 L F
.56925 .84325 m .57092 .84544 L .56904 .84356 L F
.184 0 0 r
.56904 .84396 m .56925 .84325 L .56904 .84356 L F
.56904 .84396 m .56904 .84356 L .56818 .84485 L F
.742 .268 .119 r
.56654 .84105 m .56904 .84396 L .56571 .84077 L F
.56712 .84125 m .56805 .84257 L .56654 .84105 L F
.56805 .84257 m .56904 .84396 L .56654 .84105 L F
.56712 .84125 m .56925 .84325 L .56904 .84396 L F
.642 .494 .667 r
.56879 .83891 m .5699 .84079 L .56712 .84125 L F
.604 .364 .525 r
.56712 .84125 m .5699 .84079 L .56925 .84325 L F
.425 0 .119 r
.50224 .82834 m .50101 .83001 L .49888 .8302 L F
0 0 0 r
.50359 .82765 m .50224 .82834 L .5045 .82819 L F
.50359 .82765 m .50101 .83001 L .50224 .82834 L F
.496 .249 .47 r
.53155 .81567 m .53389 .81603 L .53414 .81304 L F
.38 .154 .442 r
.53414 .81304 m .53577 .81385 L .53573 .81228 L F
.53414 .81304 m .53389 .81603 L .53577 .81385 L F
.488 .901 .824 r
.38839 .88789 m .38911 .8872 L .39025 .88695 L F
.399 .817 .972 r
.38708 .88752 m .38911 .8872 L .38839 .88789 L F
.561 .44 .672 r
.4898 .81022 m .48748 .81056 L .48757 .8108 L F
.706 .391 .441 r
.5682 .81804 m .57054 .81837 L .5697 .81984 L F
.596 .27 .389 r
.42364 .8384 m .42266 .84072 L .42075 .84025 L F
.283 0 .238 r
.42444 .83967 m .42266 .84072 L .42364 .8384 L F
.713 .784 .908 r
.56612 .77678 m .56431 .77866 L .5632 .77694 L F
0 0 0 r
.41907 .87997 m .41538 .88154 L .41806 .88062 L F
.169 0 0 r
.42012 .88024 m .41907 .87997 L .41806 .88062 L F
.42012 .88024 m .42112 .88013 L .41907 .87997 L F
.718 .623 .75 r
.65686 .74576 m .65735 .74806 L .65501 .74829 L F
.379 .467 .825 r
.65752 .74987 m .65501 .74829 L .65735 .74806 L F
.586 .495 .719 r
.65926 .74521 m .65735 .74806 L .65686 .74576 L F
.65926 .74521 m .65995 .74803 L .65735 .74806 L F
.774 .67 .748 r
.65995 .74803 m .65752 .74987 L .65735 .74806 L F
.594 .402 .59 r
.64312 .7589 m .64487 .75756 L .64349 .75833 L F
.494 .303 .55 r
.66825 .75022 m .66637 .75306 L .6662 .75045 L F
.72 .984 .897 r
.57492 .77818 m .57292 .77937 L .57367 .77821 L F
.986 .778 .54 r
.57492 .77818 m .57377 .77588 L .57687 .77621 L F
.57492 .77818 m .57367 .77821 L .57377 .77588 L F
.693 .514 .641 r
.49473 .80784 m .49454 .80811 L .49657 .80762 L F
.482 .163 .348 r
.49203 .80982 m .49454 .80811 L .49473 .80784 L F
.481 .052 .147 r
.38528 .83052 m .38821 .82963 L .38863 .82883 L F
.393 0 0 r
.38922 .82982 m .38863 .82883 L .38821 .82963 L F
.38922 .82982 m .39035 .82941 L .38863 .82883 L F
.711 .267 .195 r
.50447 .83865 m .50316 .83914 L .50205 .83849 L F
.483 .462 .759 r
.50588 .83758 m .50447 .83865 L .50369 .83596 L F
.046 0 0 r
.50526 .83885 m .50447 .83865 L .50588 .83758 L F
.50526 .83885 m .50316 .83914 L .50447 .83865 L F
.286 .023 .328 r
.60665 .78207 m .60981 .7788 L .60822 .77964 L F
.395 .044 .247 r
.52343 .81228 m .52184 .81557 L .52029 .81494 L F
.285 0 .19 r
.52529 .81285 m .52343 .81228 L .52527 .81261 L F
.52529 .81285 m .52184 .81557 L .52343 .81228 L F
.505 .321 .564 r
.56483 .82037 m .56242 .82079 L .56461 .81781 L F
.774 .266 0 r
.56242 .82079 m .56382 .82285 L .5613 .8198 L F
.56382 .82285 m .56374 .82282 L .5613 .8198 L F
0 .021 .574 r
.5614 .81992 m .56374 .82282 L .56308 .82162 L F
.963 .91 .551 r
.56422 .82272 m .56414 .82298 L .56407 .82295 L F
.56391 .82318 m .56359 .82489 L .56289 .8247 L F
.56407 .82295 m .56397 .82332 L .56391 .82318 L F
.56398 .82308 m .56289 .8247 L .56408 .82323 L F
.774 .266 0 r
.56242 .82079 m .56422 .82272 L .56408 .82323 L F
0 .021 .574 r
.56374 .82282 m .56351 .82232 L .56308 .82162 L F
.774 .266 0 r
.56382 .82285 m .56408 .82323 L .56374 .82282 L F
0 .021 .574 r
.56374 .82282 m .56408 .82323 L .56351 .82232 L F
.95 .852 .71 r
.56308 .82162 m .56408 .82323 L .56289 .8247 L F
.56308 .82162 m .56289 .8247 L .56243 .82367 L F
.347 .109 .404 r
.56363 .82219 m .56308 .82162 L .56243 .82367 L F
.531 .416 .668 r
.56483 .82037 m .56422 .82272 L .56242 .82079 L F
.347 .109 .404 r
.56461 .821 m .56308 .82162 L .56363 .82219 L F
0 .021 .574 r
.5613 .8198 m .5614 .81992 L .56308 .82162 L F
.963 .91 .551 r
.56397 .82332 m .56359 .82489 L .56391 .82318 L F
.56414 .82298 m .56359 .82489 L .56407 .82295 L F
.429 .212 .481 r
.49324 .87714 m .4915 .87762 L .49116 .87976 L F
.474 .58 .88 r
.36586 .74261 m .36534 .7448 L .36379 .74274 L F
.36586 .74261 m .36717 .74493 L .36534 .7448 L F
.969 .932 .644 r
.56892 .81493 m .5682 .81804 L .5668 .8176 L F
.584 .563 .797 r
.5697 .81984 m .5668 .8176 L .5682 .81804 L F
.827 .855 .868 r
.56879 .83891 m .57024 .83554 L .56777 .83849 L F
.56879 .83891 m .57149 .83633 L .57024 .83554 L F
.751 .236 0 r
.56889 .83975 m .56879 .83891 L .56777 .83849 L F
.39 .389 .738 r
.56879 .83891 m .57033 .84061 L .5699 .84079 L F
.786 .606 .656 r
.5715 .84163 m .57143 .84354 L .57088 .84208 L F
.57248 .84093 m .57201 .84208 L .5715 .84163 L F
.57201 .84208 m .57143 .84354 L .5715 .84163 L F
.57248 .84093 m .57157 .84198 L .57123 .84189 L F
.57248 .84093 m .56925 .84325 L .5699 .84079 L F
.038 0 0 r
.57138 .84184 m .57144 .84179 L .57123 .84189 L F
.57144 .84179 m .57248 .84093 L .57145 .84172 L F
.57144 .84179 m .57145 .84172 L .57123 .84189 L F
.786 .606 .656 r
.57144 .84179 m .5699 .84079 L .57138 .84184 L F
.57248 .84093 m .57074 .84084 L .57144 .84179 L F
.57074 .84084 m .5699 .84079 L .57144 .84179 L F
.39 .389 .738 r
.57033 .84061 m .57144 .84183 L .57058 .84127 L F
.57033 .84061 m .57058 .84127 L .5699 .84079 L F
.751 .236 0 r
.56889 .83975 m .57143 .84186 L .57033 .84061 L F
.786 .606 .656 r
.57248 .84093 m .57138 .84184 L .57157 .84198 L F
.39 .389 .738 r
.57144 .84183 m .57157 .84198 L .57138 .84184 L F
.751 .236 0 r
.57143 .84186 m .57157 .84198 L .57144 .84183 L F
.57143 .84186 m .57144 .84183 L .57033 .84061 L F
.39 .389 .738 r
.57144 .84183 m .57138 .84184 L .57058 .84127 L F
.786 .606 .656 r
.57123 .84189 m .57157 .84198 L .57065 .84232 L F
.77 .651 .731 r
.57065 .84232 m .57157 .84198 L .57143 .84186 L F
.038 0 0 r
.57118 .84201 m .57138 .84184 L .57065 .84232 L F
.57138 .84184 m .57123 .84189 L .57065 .84232 L F
.77 .651 .731 r
.57065 .84232 m .57143 .84186 L .56889 .83975 L F
.038 0 0 r
.57103 .84213 m .57118 .84201 L .57065 .84232 L F
.786 .606 .656 r
.57248 .84093 m .57242 .84367 L .57143 .84354 L F
.038 0 0 r
.57386 .84071 m .57248 .84093 L .57103 .84213 L F
.751 .236 0 r
.56884 .83931 m .57033 .84061 L .56879 .83891 L F
.56889 .83975 m .57033 .84061 L .56884 .83931 L F
.786 .606 .656 r
.57088 .84208 m .57143 .84354 L .56925 .84325 L F
.002 .05 .558 r
.49883 .82552 m .50027 .82792 L .50219 .82385 L F
.436 .871 .789 r
.52465 .80613 m .5249 .80568 L .52639 .80481 L F
.52465 .80613 m .523 .80662 L .5249 .80568 L F
.637 .818 .97 r
.44878 .8693 m .4471 .87062 L .44732 .86893 L F
.879 .99 .808 r
.44732 .86893 m .4471 .87062 L .44522 .87145 L F
0 .094 .61 r
.44837 .87229 m .4471 .87062 L .44878 .8693 L F
.693 .417 .5 r
.65188 .76227 m .64867 .76093 L .65206 .76104 L F
.541 .215 .366 r
.65188 .76227 m .65206 .76104 L .65419 .76233 L F
.605 .401 .578 r
.58571 .77917 m .58569 .78117 L .58346 .78143 L F
.674 .559 .716 r
.58758 .776 m .58873 .77908 L .58571 .77917 L F
.743 .599 .696 r
.58873 .77908 m .58569 .78117 L .58571 .77917 L F
.483 .107 .249 r
.50043 .87643 m .49885 .87543 L .49846 .87682 L F
.482 .163 .348 r
.49203 .80982 m .49442 .80957 L .49454 .80811 L F
.957 .682 .475 r
.49648 .80924 m .49454 .80811 L .49442 .80957 L F
.485 .442 .734 r
.36309 .73927 m .36203 .7426 L .36075 .73995 L F
.36309 .73927 m .36379 .74274 L .36203 .7426 L F
.163 0 0 r
.46889 .8168 m .47092 .81649 L .47239 .81557 L F
.132 0 0 r
.47239 .81557 m .47306 .81609 L .47456 .81552 L F
.47239 .81557 m .47092 .81649 L .47306 .81609 L F
.859 .754 .746 r
.56483 .82037 m .56582 .82308 L .56422 .82272 L F
.843 .783 .794 r
.56422 .82272 m .56582 .82308 L .56343 .82592 L F
.783 .721 .795 r
.56783 .82063 m .56582 .82308 L .56483 .82037 L F
.633 .493 .674 r
.56783 .82063 m .5686 .82331 L .56582 .82308 L F
.611 .448 .637 r
.57004 .79002 m .56964 .79188 L .57173 .78926 L F
.546 .605 .864 r
.53721 .80643 m .53485 .80487 L .53755 .8065 L F
.49 0 0 r
.53615 .80596 m .53755 .8065 L .53485 .80487 L F
0 .379 .705 r
.53615 .80596 m .53772 .80654 L .53755 .8065 L F
.53772 .80654 m .53866 .80688 L .53755 .8065 L F
.546 .605 .864 r
.53856 .80732 m .53721 .80643 L .53755 .8065 L F
0 .473 .853 r
.53755 .8065 m .53866 .80688 L .53856 .80732 L F
0 .294 .765 r
.53866 .80688 m .53958 .80786 L .53856 .80732 L F
.303 .439 .833 r
.54113 .81025 m .53856 .80732 L .53958 .80786 L F
.464 .188 .409 r
.36548 .77357 m .36299 .77596 L .36348 .77415 L F
.642 .911 .981 r
.51436 .87201 m .51126 .87247 L .51335 .87196 L F
.413 .859 .902 r
.51534 .87135 m .51436 .87201 L .51335 .87196 L F
.345 .109 .407 r
.6136 .77308 m .61519 .77264 L .61454 .76963 L F
.16 0 .278 r
.61534 .76848 m .61454 .76963 L .61661 .76967 L F
.165 .004 .403 r
.61454 .76963 m .61519 .77264 L .61661 .76967 L F
.256 0 0 r
.49208 .82534 m .49234 .82543 L .49417 .82557 L F
.455 .01 .1 r
.49348 .82584 m .49234 .82543 L .49368 .82419 L F
.834 .534 .482 r
.49234 .82543 m .49502 .82784 L .49417 .82557 L F
.455 .01 .1 r
.49339 .82658 m .49234 .82543 L .49348 .82584 L F
.256 0 0 r
.49034 .82514 m .49234 .82543 L .49208 .82534 L F
.253 0 .006 r
.52658 .86681 m .52327 .86891 L .52634 .86754 L F
.356 .097 .378 r
.52882 .86482 m .52658 .86681 L .52909 .86687 L F
.719 .476 .557 r
.52634 .86754 m .52909 .86687 L .52658 .86681 L F
.953 .832 .686 r
.57261 .80544 m .57248 .8076 L .57125 .8074 L F
.653 .572 .752 r
.57499 .80547 m .57248 .8076 L .57261 .80544 L F
.16 0 .278 r
.61534 .76848 m .61661 .76967 L .61757 .76826 L F
.577 .234 .351 r
.62978 .76223 m .63198 .7624 L .63356 .75944 L F
.317 0 .003 r
.63198 .7624 m .6351 .76069 L .63356 .75944 L F
.54 .903 .708 r
.51433 .87886 m .51604 .87789 L .51717 .877 L F
.399 .04 .235 r
.65701 .76022 m .65982 .75839 L .65902 .75993 L F
.359 .077 .342 r
.65982 .75839 m .66122 .75952 L .65902 .75993 L F
.65982 .75839 m .66162 .75783 L .66122 .75952 L F
.411 .186 .459 r
.66187 .75586 m .66162 .75783 L .65982 .75839 L F
.549 .501 .754 r
.5648 .81183 m .5635 .81508 L .56323 .81272 L F
.533 .068 .096 r
.44398 .83322 m .44241 .83461 L .44075 .83354 L F
.247 0 0 r
.44598 .83371 m .44241 .83461 L .44398 .83322 L F
0 0 0 r
.51159 .81792 m .51071 .81799 L .51269 .8176 L F
.51159 .81792 m .50931 .81911 L .51071 .81799 L F
.518 .128 .241 r
.4139 .82533 m .41605 .82537 L .4173 .8234 L F
.514 .124 .239 r
.4173 .8234 m .41605 .82537 L .41899 .82448 L F
.717 .67 .803 r
.5791 .77644 m .58216 .77617 L .5799 .77838 L F
.598 .24 .332 r
.43079 .83592 m .42994 .83786 L .42785 .83648 L F
.732 .521 .607 r
.43334 .83582 m .42994 .83786 L .43079 .83592 L F
.491 .034 .093 r
.53278 .80842 m .53184 .80945 L .5295 .80951 L F
.579 .133 .155 r
.53519 .80933 m .53184 .80945 L .53278 .80842 L F
.576 .937 .922 r
.39239 .90198 m .39435 .90176 L .39604 .90087 L F
.527 .018 0 r
.45602 .88436 m .4575 .88345 L .45899 .8843 L F
.491 .116 .255 r
.4575 .88345 m .45952 .88343 L .45899 .8843 L F
.327 .36 .743 r
.55061 .82219 m .54908 .82265 L .54955 .82129 L F
.363 .364 .726 r
.55061 .82219 m .54861 .82049 L .55018 .81908 L F
.691 .605 .755 r
.5497 .82218 m .55061 .82219 L .55018 .81908 L F
0 0 .357 r
.55106 .8208 m .5497 .82218 L .55005 .81987 L F
.55027 .81926 m .55005 .81987 L .55018 .81908 L F
.55106 .8208 m .55005 .81987 L .55027 .81926 L F
.327 .36 .743 r
.55061 .82219 m .5492 .82321 L .54908 .82265 L F
.54955 .82129 m .54908 .82265 L .54861 .82049 L F
0 0 .465 r
.5503 .82488 m .5492 .82321 L .55061 .82219 L F
.5503 .82488 m .54928 .82562 L .5492 .82321 L F
.879 .741 .706 r
.48747 .86609 m .48575 .86714 L .48762 .86566 L F
.207 .442 .866 r
.48762 .86566 m .48942 .86765 L .48747 .86609 L F
.561 .135 .189 r
.46822 .83311 m .46677 .83452 L .46515 .83352 L F
.224 .733 .682 r
.47043 .83336 m .46677 .83452 L .46822 .83311 L F
0 0 .375 r
.53518 .81034 m .53573 .81228 L .53519 .80933 L F
.51 .834 .999 r
.49116 .87976 m .48912 .88022 L .48789 .87959 L F
.694 .778 .916 r
.47043 .83336 m .47354 .83364 L .47277 .83242 L F
.376 .608 .939 r
.47277 .83242 m .47354 .83364 L .47446 .83256 L F
.34 .553 .913 r
.47354 .83364 m .47656 .83447 L .47446 .83256 L F
.658 .603 .781 r
.58659 .78363 m .58346 .78143 L .58569 .78117 L F
.732 .658 .776 r
.58852 .78142 m .58659 .78363 L .58569 .78117 L F
.56 .577 .828 r
.58894 .78376 m .58659 .78363 L .58852 .78142 L F
.225 0 0 r
.50961 .82574 m .51054 .82632 L .50799 .82647 L F
.50961 .82574 m .5118 .82571 L .51054 .82632 L F
.103 0 0 r
.40758 .89782 m .40654 .89761 L .40815 .89729 L F
.40758 .89782 m .40544 .89822 L .40654 .89761 L F
.351 .672 .976 r
.42509 .87931 m .42434 .88021 L .42309 .87954 L F
.42509 .87931 m .4266 .8805 L .42434 .88021 L F
.465 .232 .475 r
.66382 .75538 m .66162 .75783 L .66187 .75586 L F
.408 .089 .31 r
.61757 .76826 m .62023 .76556 L .61807 .7659 L F
.334 .568 .924 r
.37649 .75542 m .37586 .75671 L .37443 .75579 L F
.37649 .75542 m .37816 .75769 L .37586 .75671 L F
.598 .68 .898 r
.53485 .80487 m .5313 .80342 L .53369 .80422 L F
.49 0 0 r
.53615 .80596 m .53485 .80487 L .53369 .80422 L F
.282 0 0 r
.40668 .82596 m .40854 .8259 L .40971 .82535 L F
.269 0 0 r
.40854 .8259 m .4118 .82523 L .40971 .82535 L F
.344 0 0 r
.38159 .83158 m .38118 .83063 L .37981 .83253 L F
.38159 .83158 m .38325 .83064 L .38118 .83063 L F
.037 .587 .831 r
.5256 .83148 m .52541 .8316 L .52444 .83152 L F
.146 .367 .823 r
.52444 .83152 m .52634 .8322 L .5256 .83148 L F
.52444 .83152 m .52664 .83324 L .52634 .8322 L F
.782 .678 .748 r
.5635 .81508 m .56461 .81781 L .56191 .81771 L F
.584 .611 .845 r
.56619 .8152 m .56461 .81781 L .5635 .81508 L F
.56619 .8152 m .5668 .8176 L .56461 .81781 L F
.56 .361 .568 r
.56461 .81781 m .5668 .8176 L .56483 .82037 L F
.198 .647 .946 r
.40122 .88485 m .39789 .8839 L .3999 .88344 L F
.302 .589 .943 r
.40303 .8852 m .40122 .88485 L .3999 .88344 L F
.713 .424 .486 r
.49672 .87612 m .49317 .87488 L .49324 .87714 L F
.536 .076 .109 r
.38965 .85044 m .38785 .84935 L .38975 .84949 L F
.38965 .85044 m .38642 .8507 L .38785 .84935 L F
.364 .57 .918 r
.35435 .73428 m .35532 .73449 L .35483 .73494 L F
.256 .413 .828 r
.35623 .73455 m .35483 .73494 L .35532 .73449 L F
.726 .601 .717 r
.5782 .80928 m .57999 .81102 L .58077 .80951 L F
.877 .991 .808 r
.57999 .81102 m .58142 .80925 L .58077 .80951 L F
.993 .873 .598 r
.56318 .83003 m .56328 .83342 L .56282 .8325 L F
.979 .759 .345 r
.56328 .83342 m .56277 .83438 L .56282 .8325 L F
.56328 .83342 m .56331 .83527 L .56277 .83438 L F
.538 .489 .75 r
.59127 .79402 m .589 .79478 L .58856 .79224 L F
.421 .191 .457 r
.58895 .79657 m .589 .79478 L .59127 .79402 L F
.575 .684 .915 r
.50168 .864 m .50484 .86505 L .50379 .86374 L F
.948 .832 .697 r
.50484 .86505 m .50492 .86139 L .50379 .86374 L F
.119 0 .107 r
.57458 .8388 m .57248 .84093 L .57386 .84071 L F
.412 .046 .231 r
.57665 .83841 m .57458 .8388 L .57386 .84071 L F
.716 .313 .284 r
.44839 .87665 m .4476 .87396 L .4469 .87464 L F
.44839 .87665 m .4498 .87504 L .4476 .87396 L F
.539 .29 .486 r
.6246 .77125 m .62433 .77317 L .6222 .77336 L F
.51 .242 .444 r
.62679 .77104 m .62433 .77317 L .6246 .77125 L F
.752 .684 .785 r
.59085 .77684 m .59101 .77833 L .58873 .77908 L F
.578 .377 .572 r
.59101 .77833 m .58852 .78142 L .58873 .77908 L F
.59101 .77833 m .59099 .7811 L .58852 .78142 L F
.622 .517 .713 r
.5927 .77596 m .59101 .77833 L .59085 .77684 L F
.5927 .77596 m .5934 .77856 L .59101 .77833 L F
.578 .376 .572 r
.59307 .78072 m .59101 .77833 L .5934 .77856 L F
.59307 .78072 m .59099 .7811 L .59101 .77833 L F
.912 .599 .116 r
.56465 .83785 m .56536 .83872 L .56571 .84077 L F
.636 .301 .387 r
.63938 .76318 m .64176 .76509 L .6386 .76534 L F
.63938 .76318 m .6415 .76344 L .64176 .76509 L F
.436 .205 .464 r
.48757 .8108 m .48763 .81324 L .48905 .81211 L F
.616 .56 .768 r
.3582 .75047 m .36048 .75004 L .35776 .7495 L F
.3582 .75047 m .36058 .75113 L .36048 .75004 L F
.286 .023 .328 r
.60665 .78207 m .60957 .78096 L .60981 .7788 L F
.258 .325 .742 r
.60665 .78207 m .60939 .78277 L .60957 .78096 L F
.60665 .78207 m .60723 .78348 L .60939 .78277 L F
.62 .382 .535 r
.63655 .76593 m .63409 .76803 L .63419 .76621 L F
.589 .442 .649 r
.35933 .75565 m .36126 .75497 L .36123 .75288 L F
.644 .524 .703 r
.35966 .75812 m .36126 .75497 L .35933 .75565 L F
.372 .451 .813 r
.56231 .80121 m .56402 .80424 L .56109 .80246 L F
.287 .709 .971 r
.56402 .80424 m .56169 .8043 L .56109 .80246 L F
.663 .446 .58 r
.60563 .78624 m .6079 .78579 L .60723 .78348 L F
.60563 .78624 m .6079 .78579 L .60723 .78348 L F
.644 .431 .579 r
.60723 .78348 m .61082 .78595 L .6079 .78579 L F
.60723 .78348 m .61084 .78381 L .61082 .78595 L F
.093 .103 .577 r
.60723 .78348 m .60945 .78522 L .60939 .78277 L F
.60723 .78348 m .6079 .78579 L .60945 .78522 L F
.393 .254 .571 r
.57223 .7809 m .57367 .77821 L .57292 .77937 L F
.133 0 0 r
.51126 .87247 m .50943 .87325 L .5083 .87465 L F
.465 .007 .08 r
.43524 .82072 m .43698 .82138 L .43829 .82003 L F
.472 .012 .078 r
.43698 .82138 m .44041 .82012 L .43829 .82003 L F
.601 .361 .525 r
.62953 .76824 m .62897 .77082 L .62679 .77104 L F
.57 .321 .5 r
.63197 .76794 m .62897 .77082 L .62953 .76824 L F
.511 .369 .624 r
.49914 .84039 m .49901 .84289 L .50122 .8407 L F
.93 .762 .652 r
.56039 .81024 m .55847 .81084 L .55931 .8096 L F
.56039 .81024 m .55999 .81294 L .55847 .81084 L F
.357 0 .064 r
.45952 .88343 m .46251 .88201 L .46085 .88375 L F
.166 0 0 r
.46251 .88201 m .46353 .88231 L .46085 .88375 L F
.46251 .88201 m .4645 .88193 L .46353 .88231 L F
0 0 .091 r
.49888 .8302 m .49878 .83106 L .49932 .82884 L F
.523 .124 .226 r
.50005 .83161 m .49888 .8302 L .50101 .83001 L F
.50005 .83161 m .49786 .83216 L .49837 .83117 L F
.49955 .831 m .49837 .83117 L .49888 .8302 L F
.50005 .83161 m .49837 .83117 L .49955 .831 L F
.134 0 .125 r
.49888 .8302 m .49629 .83273 L .49878 .83106 L F
0 0 0 r
.49888 .8302 m .49837 .83117 L .49629 .83273 L F
.49837 .83117 m .49786 .83216 L .49629 .83273 L F
.675 .751 .908 r
.49878 .83106 m .49869 .83113 L .49857 .83102 L F
.49866 .83095 m .49857 .83102 L .49658 .82916 L F
.49878 .83106 m .49857 .83102 L .49866 .83095 L F
.49869 .83113 m .49629 .83273 L .49639 .83146 L F
.49869 .83113 m .49639 .83146 L .49658 .82916 L F
.034 0 .117 r
.49932 .82884 m .49878 .83106 L .50077 .82909 L F
.614 .057 0 r
.53415 .81675 m .53405 .81718 L .53155 .81567 L F
.53482 .81703 m .53405 .81718 L .53415 .81675 L F
.941 .689 .526 r
.53405 .81718 m .53393 .81966 L .53273 .81907 L F
.53405 .81718 m .53273 .81907 L .53391 .81782 L F
.766 .526 .57 r
.53747 .81929 m .53405 .81718 L .53696 .81746 L F
.53747 .81929 m .53393 .81966 L .53405 .81718 L F
.941 .689 .526 r
.53405 .81718 m .53391 .81782 L .535 .81665 L F
.473 .411 .707 r
.53155 .81567 m .53405 .81718 L .53389 .81603 L F
.286 .774 .907 r
.45954 .83221 m .46224 .83169 L .45857 .83147 L F
.45954 .83221 m .46241 .83195 L .46224 .83169 L F
.461 0 .03 r
.50469 .80922 m .50709 .80911 L .50829 .80788 L F
.666 .217 .177 r
.50829 .80788 m .50709 .80911 L .51034 .80938 L F
.091 .435 .875 r
.5452 .81172 m .54477 .81245 L .54329 .81081 L F
0 0 .378 r
.54563 .81397 m .54477 .81245 L .5452 .81172 L F
.54563 .81397 m .54604 .81562 L .54477 .81245 L F
.646 .865 .982 r
.50369 .83596 m .50013 .83581 L .50215 .8352 L F
.554 .855 .997 r
.50554 .83545 m .50369 .83596 L .50215 .8352 L F
.483 .462 .759 r
.50588 .83758 m .50369 .83596 L .50554 .83545 L F
.725 .508 .596 r
.40453 .84341 m .4013 .8454 L .40311 .84273 L F
0 0 0 r
.52327 .86891 m .52197 .86977 L .52079 .87174 L F
.627 .436 .605 r
.64379 .7607 m .64381 .7634 L .6415 .76344 L F
.637 .444 .605 r
.64657 .76268 m .64379 .7607 L .64679 .76048 L F
.64657 .76268 m .64381 .7634 L .64379 .7607 L F
0 0 .558 r
.54387 .82291 m .54457 .82567 L .54501 .82493 L F
.766 .265 .022 r
.54457 .82567 m .54451 .82685 L .54501 .82493 L F
.628 .498 .685 r
.3713 .75057 m .37175 .75277 L .36952 .75305 L F
.452 .472 .789 r
.3717 .75477 m .36952 .75305 L .37175 .75277 L F
.631 .486 .667 r
.38022 .85151 m .38222 .85135 L .38041 .85319 L F
.965 .649 .367 r
.55334 .79979 m .55266 .80151 L .55244 .79907 L F
.55334 .79979 m .55372 .80215 L .55266 .80151 L F
.507 .062 .127 r
.6279 .76192 m .62978 .76223 L .62767 .76144 L F
.651 .761 .93 r
.56955 .79767 m .57102 .79898 L .56847 .79952 L F
.444 .047 .191 r
.56847 .79952 m .57102 .79898 L .56936 .80081 L F
.56847 .79952 m .56936 .80081 L .56915 .79837 L F
.787 .566 .6 r
.56915 .79837 m .56936 .80081 L .56767 .80095 L F
.651 .761 .93 r
.56939 .79795 m .56847 .79952 L .56915 .79837 L F
.787 .566 .6 r
.56915 .79837 m .56767 .80095 L .56685 .80102 L F
.651 .761 .93 r
.56955 .79767 m .56939 .79795 L .56915 .79837 L F
.251 0 0 r
.45116 .83277 m .44801 .83349 L .44923 .83293 L F
.843 .783 .794 r
.5637 .82483 m .56343 .82592 L .56359 .82489 L F
0 .056 .555 r
.56343 .82592 m .56484 .82715 L .56359 .82489 L F
.795 .329 0 r
.5632 .82509 m .56359 .82489 L .56484 .82715 L F
.56289 .8247 m .56359 .82489 L .5632 .82509 L F
.843 .783 .794 r
.56422 .82272 m .5637 .82483 L .56359 .82489 L F
0 .056 .555 r
.56343 .82592 m .56576 .82808 L .56484 .82715 L F
.747 .993 .86 r
.43033 .878 m .43184 .87769 L .42939 .87955 L F
.695 .735 .882 r
.43198 .87599 m .43175 .87774 L .42923 .87653 L F
0 0 0 r
.43374 .87735 m .43121 .87783 L .43174 .87786 L F
.43121 .87783 m .43033 .878 L .43174 .87786 L F
.43374 .87735 m .43184 .87769 L .43034 .878 L F
.43374 .87735 m .43034 .878 L .43038 .87799 L F
.295 0 0 r
.43431 .87807 m .43374 .87735 L .43174 .87786 L F
.43431 .87807 m .436 .87736 L .43374 .87735 L F
.446 .525 .845 r
.43428 .87801 m .43174 .87786 L .43326 .87577 L F
.43431 .87807 m .43174 .87786 L .43428 .87801 L F
.695 .735 .882 r
.43175 .87774 m .43174 .87786 L .43157 .87777 L F
.43175 .87774 m .43157 .87777 L .42923 .87653 L F
0 0 0 r
.43038 .87799 m .43034 .878 L .43033 .878 L F
.747 .993 .86 r
.43033 .878 m .42939 .87955 L .42859 .8798 L F
.794 .68 .738 r
.5668 .8176 m .56783 .82063 L .56483 .82037 L F
.584 .563 .797 r
.5697 .81984 m .56783 .82063 L .5668 .8176 L F
.504 .359 .618 r
.5696 .82177 m .56783 .82063 L .5697 .81984 L F
.443 .377 .688 r
.5696 .82177 m .5686 .82331 L .56783 .82063 L F
.673 .65 .82 r
.58261 .83957 m .57973 .83878 L .58133 .83938 L F
.374 .838 .884 r
.58436 .83888 m .58261 .83957 L .58133 .83938 L F
.58436 .83888 m .58531 .83892 L .58261 .83957 L F
.755 .603 .689 r
.4923 .83094 m .49509 .83127 L .49421 .83016 L F
.263 0 0 r
.49064 .88804 m .49328 .88732 L .49253 .88781 L F
.201 0 0 r
.49328 .88732 m .49458 .88755 L .49253 .88781 L F
.49328 .88732 m .49534 .88701 L .49458 .88755 L F
.452 .753 .994 r
.50745 .85517 m .50903 .85415 L .50657 .85452 L F
.50745 .85517 m .50961 .85512 L .50903 .85415 L F
.184 .344 .791 r
.50077 .86223 m .50168 .864 L .501 .86188 L F
.785 .735 .806 r
.501 .86188 m .50168 .864 L .49836 .86411 L F
.375 0 0 r
.49836 .86411 m .50168 .864 L .50036 .86439 L F
.228 0 0 r
.50168 .864 m .50379 .86374 L .50252 .86463 L F
.095 0 0 r
.5118 .82571 m .51487 .82581 L .51389 .82584 L F
0 .064 .598 r
.51487 .82581 m .51596 .82663 L .51389 .82584 L F
.51487 .82581 m .51681 .8278 L .51596 .82663 L F
.771 .658 .738 r
.4408 .87418 m .44366 .87227 L .44163 .87271 L F
0 0 0 r
.43787 .88925 m .43964 .88865 L .44162 .8883 L F
.597 .687 .905 r
.56951 .77879 m .56612 .77678 L .56838 .77603 L F
.214 .349 .785 r
.57052 .77764 m .56951 .77879 L .56838 .77603 L F
.99 .758 .38 r
.56883 .77897 m .56951 .77879 L .57052 .77764 L F
.962 .754 .577 r
.57149 .83633 m .57054 .83311 L .57024 .83554 L F
.602 .234 .316 r
.42994 .83786 m .42662 .83833 L .42785 .83648 L F
.779 .527 .555 r
.4923 .81449 m .49585 .81265 L .49339 .81256 L F
.4923 .81449 m .49556 .81499 L .49585 .81265 L F
.828 .983 .699 r
.49777 .80988 m .49542 .8125 L .49585 .81265 L F
.583 .362 .546 r
.49542 .8125 m .49431 .81245 L .49585 .81265 L F
.532 .391 .635 r
.49585 .81265 m .49809 .8123 L .49777 .80988 L F
.497 .274 .506 r
.49585 .81265 m .49761 .81443 L .49809 .8123 L F
.49585 .81265 m .49556 .81499 L .49761 .81443 L F
.243 .212 .623 r
.57146 .78352 m .57242 .78433 L .57223 .7809 L F
0 0 0 r
.66232 .74944 m .66433 .7473 L .66319 .74834 L F
.589 .274 .403 r
.49655 .82046 m .49439 .82208 L .49482 .82098 L F
.572 .233 .356 r
.51051 .82241 m .51297 .82246 L .51382 .82013 L F
.19 0 .191 r
.51382 .82013 m .51449 .82165 L .51554 .82068 L F
.51382 .82013 m .51297 .82246 L .51449 .82165 L F
.742 .409 .417 r
.48313 .82888 m .4819 .83078 L .47989 .83004 L F
.602 .24 .328 r
.48511 .83017 m .4819 .83078 L .48313 .82888 L F
.025 .309 .799 r
.54182 .80967 m .54113 .81025 L .53958 .80786 L F
.189 .584 .941 r
.54182 .80967 m .54329 .81081 L .54113 .81025 L F
0 0 0 r
.48178 .87368 m .48041 .87425 L .47954 .87487 L F
.368 .832 .898 r
.40143 .89912 m .40061 .89868 L .3998 .89914 L F
.40143 .89912 m .40343 .89862 L .40061 .89868 L F
.913 .907 .803 r
.6483 .75342 m .64729 .75257 L .65015 .75134 L F
.6483 .75342 m .64726 .75276 L .64729 .75257 L F
.949 .925 .747 r
.6473 .75458 m .64726 .75276 L .6483 .75342 L F
.73 .441 .489 r
.57017 .81007 m .56802 .8123 L .56956 .80921 L F
0 0 .17 r
.57166 .81309 m .57063 .81312 L .57181 .81099 L F
.585 .466 .684 r
.57117 .81225 m .57105 .81451 L .56892 .81493 L F
.642 .514 .692 r
.57039 .81313 m .57105 .81451 L .57117 .81225 L F
0 0 .17 r
.57063 .81312 m .57039 .81313 L .57073 .81262 L F
.73 .441 .489 r
.5709 .81168 m .57117 .81225 L .57079 .81226 L F
.067 .12 .609 r
.57181 .81099 m .57117 .81225 L .57017 .81007 L F
.585 .466 .684 r
.57117 .81225 m .56892 .81493 L .56802 .8123 L F
.642 .514 .692 r
.57039 .81313 m .57117 .81225 L .57181 .81099 L F
0 0 .17 r
.57063 .81312 m .57073 .81262 L .57181 .81099 L F
.73 .441 .489 r
.57017 .81007 m .5709 .81168 L .56802 .8123 L F
.5709 .81168 m .57079 .81226 L .56802 .8123 L F
.486 .702 .965 r
.57304 .80934 m .57017 .81007 L .56956 .80921 L F
.656 .696 .875 r
.65778 .74406 m .65686 .74576 L .65615 .74465 L F
.65778 .74406 m .65926 .74521 L .65686 .74576 L F
.347 0 0 r
.53482 .81703 m .53696 .81746 L .53405 .81718 L F
.684 .631 .791 r
.58963 .77365 m .58758 .776 L .58628 .77296 L F
.659 .594 .77 r
.58963 .77365 m .59085 .77684 L .58758 .776 L F
.678 .561 .715 r
.59085 .77684 m .58873 .77908 L .58758 .776 L F
.525 .861 .589 r
.57511 .79774 m .57622 .79688 L .57408 .79876 L F
.6 .542 .761 r
.37235 .74695 m .37102 .74736 L .37031 .7454 L F
.504 .389 .656 r
.37235 .74695 m .3713 .75057 L .37102 .74736 L F
.446 .168 .396 r
.5928 .83833 m .59016 .84047 L .59071 .83878 L F
.476 .16 .351 r
.37262 .76969 m .36937 .77274 L .3704 .77019 L F
0 0 .15 r
.61182 .7783 m .61372 .77562 L .61106 .77882 L F
.582 .732 .946 r
.61182 .7783 m .61106 .77882 L .60946 .77876 L F
.61182 .7783 m .60946 .77876 L .60981 .7788 L F
.737 .377 .369 r
.54501 .82493 m .5467 .82297 L .54387 .82291 L F
.06 0 0 r
.54387 .82291 m .5467 .82297 L .54639 .823 L F
.531 .905 .731 r
.54639 .823 m .5467 .82297 L .54767 .82206 L F
0 0 0 r
.54767 .82206 m .5467 .82297 L .54501 .82493 L F
.743 .599 .696 r
.58873 .77908 m .58852 .78142 L .58569 .78117 L F
0 0 0 r
.5759 .80057 m .57702 .7995 L .57797 .79915 L F
.151 0 .021 r
.47963 .81231 m .48076 .8126 L .48173 .81232 L F
.47963 .81231 m .47838 .81422 L .48076 .8126 L F
.799 .807 .858 r
.49063 .82986 m .49421 .83016 L .49254 .82753 L F
.49063 .82986 m .4923 .83094 L .49421 .83016 L F
.822 .77 .804 r
.49254 .82753 m .49421 .83016 L .49502 .82784 L F
.787 .673 .739 r
.39524 .8486 m .39633 .85147 L .39355 .85014 L F
.781 .305 .102 r
.39633 .85147 m .39537 .85167 L .39355 .85014 L F
.024 .044 .541 r
.39701 .84834 m .39633 .85147 L .39524 .8486 L F
.39701 .84834 m .3973 .85131 L .39633 .85147 L F
0 0 0 r
.3973 .85131 m .39537 .85167 L .39633 .85147 L F
.613 .447 .633 r
.61524 .7788 m .6155 .78128 L .61311 .78153 L F
.596 .378 .556 r
.6155 .78128 m .61311 .78372 L .61311 .78153 L F
.586 .062 0 r
.57866 .83945 m .57973 .83878 L .57665 .83841 L F
.357 0 0 r
.58062 .83934 m .57973 .83878 L .57866 .83945 L F
.58062 .83934 m .58133 .83938 L .57973 .83878 L F
.481 .169 .359 r
.58854 .84106 m .58754 .84355 L .58563 .8438 L F
.506 .193 .371 r
.59 .84258 m .58854 .84106 L .59016 .84047 L F
.59 .84258 m .58754 .84355 L .58854 .84106 L F
.53 .348 .579 r
.61743 .7786 m .6155 .78128 L .61524 .7788 L F
.521 .315 .541 r
.59493 .83337 m .59486 .83572 L .59272 .83591 L F
.525 .331 .561 r
.59486 .83572 m .5928 .83833 L .59272 .83591 L F
.175 0 0 r
.39035 .82941 m .39232 .82919 L .39395 .82835 L F
.001 0 0 r
.39395 .82835 m .3943 .82869 L .39595 .82819 L F
.39395 .82835 m .39232 .82919 L .3943 .82869 L F
.484 .278 .524 r
.59707 .83076 m .59687 .83302 L .59493 .83337 L F
.487 .288 .535 r
.59687 .83302 m .59486 .83572 L .59493 .83337 L F
.404 0 .025 r
.46567 .87079 m .46235 .87185 L .46448 .87193 L F
.287 0 0 r
.46567 .87079 m .4665 .87151 L .46734 .87068 L F
.46567 .87079 m .46448 .87193 L .4665 .87151 L F
.496 .486 .775 r
.58033 .79365 m .58159 .79705 L .58336 .79651 L F
.393 .191 .482 r
.58336 .79651 m .58159 .79705 L .58134 .79922 L F
.905 .89 .806 r
.40835 .88227 m .40515 .88475 L .40721 .88245 L F
.40835 .88227 m .40637 .88521 L .40515 .88475 L F
.289 .778 .714 r
.40835 .88227 m .4092 .88188 L .41069 .88141 L F
.279 .781 .782 r
.40835 .88227 m .40721 .88245 L .4092 .88188 L F
.46 .66 .948 r
.59564 .82907 m .5942 .82964 L .59341 .82968 L F
.59564 .82907 m .59707 .83076 L .5942 .82964 L F
0 .01 .583 r
.49779 .83673 m .49748 .83644 L .49686 .83491 L F
.685 .778 .921 r
.49484 .83574 m .49748 .83644 L .49686 .83491 L F
0 .01 .583 r
.49686 .83491 m .49748 .83644 L .49779 .83673 L F
.286 0 .186 r
.4547 .87223 m .45166 .87496 L .45492 .87449 L F
.544 .396 .631 r
.4547 .87223 m .45691 .87413 L .45635 .87232 L F
.4547 .87223 m .45492 .87449 L .45691 .87413 L F
.593 .551 .776 r
.36058 .75113 m .36123 .75288 L .36331 .75244 L F
.649 .54 .717 r
.36126 .75497 m .36331 .75244 L .36123 .75288 L F
.587 .367 .548 r
.6222 .77336 m .6223 .77574 L .61952 .77607 L F
.57 .354 .547 r
.62435 .77525 m .6222 .77336 L .62433 .77317 L F
.62435 .77525 m .6223 .77574 L .6222 .77336 L F
.524 .53 .804 r
.57432 .80434 m .57261 .80544 L .57119 .80285 L F
.653 .572 .752 r
.57499 .80547 m .57261 .80544 L .57432 .80434 L F
.49 0 0 r
.48646 .88707 m .48823 .88755 L .4871 .88716 L F
.145 .65 .904 r
.48823 .88755 m .49025 .88784 L .4871 .88716 L F
.536 .021 0 r
.48823 .88755 m .49064 .88804 L .49025 .88784 L F
0 0 .15 r
.49314 .84952 m .4929 .84885 L .49225 .85137 L F
.475 .889 .782 r
.65015 .75134 m .65143 .75042 L .65199 .75029 L F
.65015 .75134 m .64729 .75257 L .64964 .75135 L F
.949 .925 .747 r
.6473 .75458 m .6462 .7548 L .64726 .75276 L F
.74 .5 .566 r
.64604 .75426 m .64726 .75276 L .6462 .7548 L F
.752 .757 .857 r
.64729 .75257 m .64726 .75276 L .6484 .75127 L F
.72 .702 .833 r
.65143 .75042 m .64729 .75257 L .6484 .75127 L F
.74 .5 .566 r
.64604 .75426 m .64906 .75515 L .64851 .75187 L F
.64759 .75229 m .64851 .75187 L .6484 .75127 L F
.64604 .75426 m .6484 .75127 L .64726 .75276 L F
.64604 .75426 m .64851 .75187 L .64759 .75229 L F
.475 .889 .782 r
.65102 .75072 m .64964 .75135 L .65143 .75042 L F
.65015 .75134 m .64964 .75135 L .65102 .75072 L F
.579 .307 .469 r
.62023 .76556 m .62245 .76553 L .62262 .76364 L F
.201 .126 .543 r
.49339 .81256 m .49442 .80957 L .49203 .80982 L F
.115 .174 .647 r
.57118 .82994 m .57035 .83131 L .57048 .83039 L F
.984 .701 .371 r
.56972 .83267 m .57035 .83131 L .57118 .82994 L F
.56972 .83267 m .57054 .83311 L .57035 .83131 L F
.396 .657 .963 r
.46406 .83223 m .46515 .83352 L .46593 .83232 L F
.141 .308 .773 r
.46515 .83352 m .46677 .83452 L .46593 .83232 L F
.553 .704 .94 r
.59792 .83 m .59707 .83076 L .59564 .82907 L F
.109 0 .4 r
.59792 .83 m .59687 .83302 L .59707 .83076 L F
.285 0 0 r
.43175 .89019 m .43236 .8909 L .43029 .89145 L F
.43175 .89019 m .43383 .88995 L .43236 .8909 L F
.513 .064 .12 r
.45305 .81935 m .45514 .81958 L .45642 .81815 L F
.253 0 0 r
.45642 .81815 m .45714 .81912 L .45833 .81808 L F
.45642 .81815 m .45514 .81958 L .45714 .81912 L F
.568 .322 .504 r
.66433 .7473 m .66691 .74505 L .66489 .74524 L F
.595 .442 .644 r
.59099 .7811 m .58894 .78376 L .58852 .78142 L F
.538 .489 .75 r
.59127 .79402 m .58856 .79224 L .59074 .79173 L F
.547 .855 .997 r
.40637 .88521 m .40303 .8852 L .40515 .88475 L F
.475 .851 .985 r
.55934 .77848 m .55973 .77778 L .56099 .7778 L F
.55934 .77848 m .55774 .77827 L .55973 .77778 L F
0 0 .447 r
.55934 .77848 m .55973 .77778 L .55774 .77827 L F
.55934 .77848 m .55983 .77915 L .55973 .77778 L F
.674 .347 .412 r
.49028 .81251 m .4923 .81449 L .49339 .81256 L F
.201 .126 .543 r
.49339 .81256 m .49431 .81245 L .49442 .80957 L F
.668 .399 .504 r
.64867 .76093 m .64657 .76268 L .64679 .76048 L F
.64867 .76093 m .64891 .76285 L .64657 .76268 L F
.693 .417 .5 r
.65188 .76227 m .64891 .76285 L .64867 .76093 L F
.644 .524 .703 r
.35966 .75812 m .36196 .75802 L .36126 .75497 L F
.517 .292 .512 r
.35971 .76046 m .36196 .75802 L .35966 .75812 L F
.437 .025 .157 r
.37543 .83301 m .37775 .83254 L .37588 .83242 L F
.466 .053 .172 r
.42666 .82276 m .42873 .82263 L .42987 .821 L F
.513 .103 .201 r
.42987 .821 m .42873 .82263 L .43175 .82187 L F
.485 .405 .691 r
.52882 .86482 m .53138 .86705 L .53018 .8637 L F
.836 .762 .781 r
.48511 .83017 m .48593 .8335 L .48482 .83343 L F
.773 .848 .908 r
.48482 .83343 m .48593 .8335 L .48638 .83298 L F
.592 .364 .539 r
.48638 .83298 m .48418 .83566 L .48482 .83343 L F
.773 .848 .908 r
.48638 .83298 m .48593 .8335 L .48719 .83275 L F
.043 0 0 r
.48719 .83275 m .48593 .8335 L .48661 .83315 L F
.528 .267 .463 r
.48913 .83251 m .48628 .83575 L .48719 .83275 L F
.043 0 0 r
.48719 .83275 m .48661 .83315 L .48791 .83247 L F
.592 .364 .539 r
.48719 .83275 m .48671 .83322 L .48661 .83315 L F
.48719 .83275 m .48661 .83315 L .48638 .83298 L F
.48671 .83322 m .48418 .83566 L .48638 .83298 L F
.668 .662 .835 r
.48728 .83195 m .48638 .83298 L .48511 .83017 L F
.48638 .83298 m .48593 .8335 L .48568 .83247 L F
.48638 .83298 m .48568 .83247 L .48511 .83017 L F
.48791 .83247 m .48593 .8335 L .48728 .83195 L F
.452 .306 .591 r
.39714 .84613 m .39524 .8486 L .39491 .84643 L F
.936 .579 .313 r
.55756 .80708 m .55882 .80759 L .55931 .8096 L F
.05 .615 .773 r
.36048 .75004 m .35712 .74993 L .35776 .7495 L F
0 0 0 r
.50493 .88448 m .50813 .88211 L .50674 .88354 L F
.50922 .88153 m .51086 .88067 L .5091 .88166 L F
.535 .901 .707 r
.5091 .88166 m .51086 .88067 L .51235 .87955 L F
.5091 .88166 m .51235 .87955 L .51092 .88054 L F
.425 .841 .67 r
.51006 .88098 m .5091 .88166 L .51092 .88054 L F
0 0 0 r
.50899 .88177 m .5091 .88166 L .51006 .88098 L F
.50674 .88354 m .50813 .88211 L .5091 .88166 L F
.457 .825 .57 r
.50674 .88354 m .5091 .88166 L .50789 .88259 L F
0 0 0 r
.50789 .88259 m .5091 .88166 L .50899 .88177 L F
.50813 .88211 m .50922 .88153 L .5091 .88166 L F
.798 .704 .761 r
.57581 .77332 m .57687 .77621 L .57377 .77588 L F
.726 .668 .793 r
.57581 .77332 m .57878 .77377 L .57687 .77621 L F
.658 .568 .742 r
.57878 .77377 m .5791 .77644 L .57687 .77621 L F
.285 0 .19 r
.52529 .81285 m .52527 .81261 L .52567 .81441 L F
.688 .433 .531 r
.52814 .81249 m .52567 .81441 L .52527 .81261 L F
.524 .402 .655 r
.38235 .85361 m .38041 .85319 L .38222 .85135 L F
.38235 .85361 m .38212 .85367 L .38041 .85319 L F
.514 .42 .686 r
.38041 .85319 m .38212 .85367 L .38053 .85399 L F
.524 .402 .655 r
.38235 .85361 m .38041 .85319 L .38222 .85135 L F
.38235 .85361 m .38212 .85367 L .38041 .85319 L F
.487 .838 .996 r
.3999 .88344 m .39789 .8839 L .39581 .88313 L F
.597 .607 .832 r
.5207 .82576 m .51667 .82322 L .51884 .82526 L F
0 0 0 r
.51815 .82755 m .5207 .82576 L .51939 .8271 L F
.865 .778 .763 r
.51939 .8271 m .5207 .82576 L .51884 .82526 L F
.405 0 0 r
.52806 .8033 m .53043 .80391 L .5313 .80342 L F
.52 0 0 r
.53043 .80391 m .53369 .80422 L .5313 .80342 L F
0 .087 .645 r
.47146 .87147 m .47096 .87184 L .46978 .86927 L F
.091 .56 .907 r
.47146 .87147 m .47292 .87239 L .47096 .87184 L F
.245 0 .189 r
.5227 .8741 m .52476 .87171 L .52359 .87373 L F
.293 0 .137 r
.52359 .87373 m .52476 .87171 L .52631 .87202 L F
.321 0 .069 r
.52476 .87171 m .5274 .87071 L .52667 .8712 L F
.807 .865 .891 r
.52359 .87373 m .52631 .87202 L .525 .87115 L F
.52359 .87373 m .525 .87115 L .52296 .87152 L F
.293 0 .098 r
.52631 .87202 m .52476 .87171 L .52667 .8712 L F
.306 .381 .776 r
.52531 .87373 m .52296 .87152 L .525 .87115 L F
.375 .084 .338 r
.52684 .87052 m .525 .87115 L .5243 .87209 L F
.306 .381 .776 r
.52478 .87323 m .52359 .87373 L .52306 .87188 L F
.52478 .87323 m .52306 .87188 L .52339 .87193 L F
.245 0 .189 r
.52219 .87469 m .5227 .8741 L .52359 .87373 L F
.375 .084 .338 r
.52503 .87221 m .5243 .87209 L .52228 .87476 L F
.52684 .87052 m .5243 .87209 L .52503 .87221 L F
.306 .381 .776 r
.52339 .87193 m .52306 .87188 L .52296 .87152 L F
.52531 .87373 m .52359 .87373 L .52478 .87323 L F
.425 .023 .172 r
.44075 .83354 m .43944 .83553 L .43758 .83562 L F
.396 0 .051 r
.44241 .83461 m .43944 .83553 L .44075 .83354 L F
.386 .848 .833 r
.51815 .82755 m .51939 .8271 L .51681 .8278 L F
.658 .501 .659 r
.58895 .79657 m .58672 .79925 L .58683 .79701 L F
.342 .759 .978 r
.47199 .88188 m .47318 .88243 L .47522 .88234 L F
.537 .709 .95 r
.37128 .74397 m .37031 .7454 L .36926 .74422 L F
.505 .664 .934 r
.37128 .74397 m .37214 .74522 L .37031 .7454 L F
.6 .542 .761 r
.37235 .74695 m .37031 .7454 L .37214 .74522 L F
.382 0 0 r
.47462 .87489 m .47487 .874 L .47367 .87523 L F
.907 .498 .152 r
.47487 .874 m .47597 .87463 L .47516 .87301 L F
.08 .578 .894 r
.4777 .8748 m .47597 .87463 L .47487 .874 L F
.4777 .8748 m .47487 .874 L .47722 .87397 L F
.382 0 0 r
.47722 .87397 m .47487 .874 L .47462 .87489 L F
.907 .498 .152 r
.47487 .874 m .47516 .87301 L .47473 .87215 L F
.522 .915 .914 r
.56099 .7778 m .55973 .77778 L .56167 .77693 L F
.833 .363 .003 r
.52114 .81771 m .52221 .81919 L .5201 .81725 L F
.413 .415 .752 r
.52266 .81774 m .52351 .81946 L .52114 .81771 L F
.487 .413 .699 r
.52114 .81771 m .52351 .81946 L .52221 .81919 L F
0 0 0 r
.4101 .89676 m .41383 .89566 L .41283 .89595 L F
.4116 .89632 m .41283 .89595 L .41472 .89555 L F
.215 .729 .695 r
.4101 .89676 m .41283 .89595 L .41101 .89646 L F
0 0 0 r
.41101 .89646 m .41283 .89595 L .4116 .89632 L F
.41383 .89566 m .41394 .89563 L .41283 .89595 L F
.41394 .89563 m .41472 .89555 L .41283 .89595 L F
.41394 .89563 m .416 .89536 L .41472 .89555 L F
.517 .192 .354 r
.65714 .75164 m .66028 .75022 L .6595 .74911 L F
.65714 .75164 m .6579 .75189 L .65846 .75104 L F
.514 .211 .39 r
.65734 .7529 m .65983 .75253 L .65714 .75164 L F
0 0 .307 r
.65714 .75164 m .65751 .75049 L .65734 .7529 L F
.932 .743 .625 r
.65731 .75281 m .65751 .75049 L .65617 .74982 L F
.65734 .7529 m .65735 .75274 L .65731 .75281 L F
.65735 .75274 m .65751 .75049 L .65731 .75281 L F
.517 .192 .354 r
.65846 .75104 m .65983 .75253 L .66028 .75022 L F
.6579 .75189 m .65983 .75253 L .65846 .75104 L F
.481 .892 .924 r
.66028 .75022 m .66173 .74922 L .66232 .74944 L F
.3 .006 .288 r
.66028 .75022 m .66162 .75169 L .66173 .74922 L F
.66028 .75022 m .65983 .75253 L .66162 .75169 L F
.644 .388 .517 r
.65902 .75993 m .6564 .76239 L .65701 .76022 L F
.308 .798 .776 r
.49941 .88629 m .50111 .88593 L .5031 .88528 L F
.335 .448 .828 r
.51817 .82275 m .51667 .82322 L .51554 .82068 L F
.755 .354 .294 r
.51633 .82379 m .51884 .82526 L .51667 .82322 L F
.5158 .82466 m .51756 .82501 L .51633 .82379 L F
.51756 .82501 m .51884 .82526 L .51633 .82379 L F
.762 .375 .322 r
.51829 .82574 m .51884 .82526 L .5158 .82466 L F
0 .093 .622 r
.51875 .82566 m .51829 .82574 L .5168 .82376 L F
.51829 .82574 m .51829 .82574 L .51827 .82571 L F
.51829 .82574 m .51827 .82571 L .5168 .82376 L F
.755 .354 .294 r
.5158 .82466 m .51667 .82322 L .51817 .82275 L F
.504 .389 .656 r
.37235 .74695 m .37295 .75059 L .3713 .75057 L F
.565 .489 .729 r
.37295 .75059 m .37175 .75277 L .3713 .75057 L F
.56 .333 .528 r
.6726 .74471 m .67249 .74736 L .67013 .74737 L F
.498 .267 .493 r
.67478 .74455 m .67249 .74736 L .6726 .74471 L F
.619 .289 .39 r
.6415 .76344 m .64367 .76507 L .64176 .76509 L F
.597 .303 .44 r
.64381 .7634 m .64367 .76507 L .6415 .76344 L F
.39 .073 .302 r
.38053 .85399 m .38212 .85367 L .38036 .85441 L F
.583 .223 .323 r
.49531 .87748 m .49672 .87612 L .49324 .87714 L F
.626 .139 .077 r
.49766 .87747 m .49672 .87612 L .49531 .87748 L F
.49766 .87747 m .49846 .87682 L .49672 .87612 L F
.557 .354 .561 r
.37695 .76311 m .37684 .7654 L .37518 .76525 L F
.581 .451 .667 r
.37876 .76094 m .37896 .7629 L .37695 .76311 L F
.56 .355 .56 r
.37896 .7629 m .37684 .7654 L .37695 .76311 L F
.318 0 0 r
.5045 .87535 m .50386 .87475 L .50232 .87594 L F
.5045 .87535 m .50596 .87504 L .50386 .87475 L F
.801 .671 .72 r
.60563 .78624 m .60662 .789 L .60492 .788 L F
.618 .461 .646 r
.60492 .788 m .60561 .78961 L .60562 .78926 L F
.863 .526 .413 r
.60569 .78939 m .60662 .789 L .6061 .79012 L F
.566 .544 .789 r
.60857 .78846 m .60662 .789 L .60625 .78798 L F
.60696 .78724 m .60625 .78798 L .60563 .78624 L F
.60857 .78846 m .60625 .78798 L .60696 .78724 L F
.60857 .78846 m .60563 .78624 L .6079 .78579 L F
.637 .407 .552 r
.6079 .78579 m .61071 .7884 L .60857 .78846 L F
.6079 .78579 m .61082 .78595 L .61071 .7884 L F
0 0 .093 r
.60945 .78522 m .6086 .78553 L .60744 .78791 L F
.6086 .78553 m .6079 .78579 L .60777 .7864 L F
.6086 .78553 m .60777 .7864 L .60744 .78791 L F
.32 0 .159 r
.60574 .79089 m .60662 .789 L .60857 .78846 L F
.667 .607 .779 r
.60574 .79089 m .60744 .78791 L .6057 .78954 L F
.60574 .79089 m .6057 .78954 L .60561 .78961 L F
.863 .526 .413 r
.60562 .78926 m .60569 .78924 L .60569 .78939 L F
.60569 .78924 m .60662 .789 L .60569 .78939 L F
.60492 .788 m .60533 .78825 L .60562 .78926 L F
.60533 .78825 m .60662 .789 L .60562 .78926 L F
.266 .177 .565 r
.60563 .78624 m .60562 .78926 L .60744 .78791 L F
.60562 .78926 m .60561 .78961 L .6057 .78954 L F
.60562 .78926 m .6057 .78954 L .60744 .78791 L F
.618 .461 .646 r
.60492 .788 m .60562 .78926 L .60563 .78624 L F
.932 .562 .282 r
.60574 .79089 m .60561 .78961 L .60492 .788 L F
.863 .526 .413 r
.60492 .788 m .6061 .79012 L .60574 .79089 L F
.059 .268 .76 r
.49124 .81232 m .4923 .81449 L .49028 .81251 L F
0 0 0 r
.5274 .87071 m .52909 .86687 L .5296 .86965 L F
.299 0 0 r
.52909 .86687 m .53138 .86705 L .5296 .86965 L F
.619 .057 0 r
.52723 .86876 m .52997 .86936 L .52634 .86754 L F
.52997 .86936 m .53004 .86938 L .52994 .86933 L F
.52997 .86936 m .52994 .86933 L .52634 .86754 L F
.176 0 .368 r
.53097 .86861 m .52997 .86937 L .53138 .86705 L F
.52997 .86937 m .52992 .8694 L .52996 .86935 L F
.52997 .86937 m .52996 .86935 L .53138 .86705 L F
.52992 .8694 m .5296 .86965 L .52999 .86908 L F
.719 .476 .557 r
.52994 .86933 m .53004 .86938 L .52997 .86919 L F
.176 0 .368 r
.52992 .8694 m .52999 .86908 L .53138 .86705 L F
.719 .476 .557 r
.52634 .86754 m .52994 .86933 L .52909 .86687 L F
.52994 .86933 m .52997 .86919 L .52909 .86687 L F
.27 .237 .636 r
.52909 .86687 m .5309 .86716 L .53138 .86705 L F
.52909 .86687 m .53004 .86938 L .5309 .86716 L F
.689 .741 .891 r
.48575 .86714 m .48942 .86765 L .48762 .86566 L F
.15 0 0 r
.43783 .87671 m .4366 .87655 L .436 .87736 L F
.43783 .87671 m .43941 .87519 L .4366 .87655 L F
.383 .396 .75 r
.55018 .81908 m .54861 .82049 L .54792 .81729 L F
0 0 0 r
.52639 .80481 m .52728 .80454 L .52806 .8033 L F
.475 .021 .092 r
.52806 .8033 m .52728 .80454 L .53043 .80391 L F
.959 .619 .275 r
.55847 .81084 m .55999 .81294 L .55916 .81282 L F
.518 .028 0 r
.55999 .81294 m .5609 .81391 L .55916 .81282 L F
.55999 .81294 m .56127 .8143 L .5609 .81391 L F
.954 .607 .257 r
.54907 .82721 m .55002 .82786 L .54928 .82562 L F
0 0 .068 r
.54907 .82721 m .54928 .82562 L .5503 .82488 L F
.155 0 0 r
.42334 .89279 m .42637 .89188 L .42538 .89249 L F
.134 0 0 r
.42538 .89249 m .42637 .89188 L .42857 .89159 L F
.273 0 0 r
.35352 .73427 m .35532 .73449 L .35435 .73428 L F
.331 .577 .931 r
.57779 .80728 m .57499 .80547 L .57754 .80538 L F
.803 .857 .406 r
.577 .80875 m .57657 .81047 L .57737 .80837 L F
0 0 0 r
.57651 .80925 m .577 .80875 L .57851 .80858 L F
.288 .721 .968 r
.5744 .80958 m .57287 .80987 L .57532 .8099 L F
.57343 .80924 m .57292 .80982 L .5744 .80958 L F
.57292 .80982 m .57287 .80987 L .5744 .80958 L F
.755 .844 .918 r
.57343 .80924 m .57532 .8099 L .577 .80875 L F
0 0 0 r
.57446 .80993 m .57568 .80937 L .57651 .80925 L F
.57568 .80937 m .577 .80875 L .57653 .80923 L F
.761 .911 .941 r
.57532 .8099 m .57657 .81047 L .577 .80875 L F
0 0 0 r
.57568 .80937 m .57653 .80923 L .57651 .80925 L F
.803 .857 .406 r
.577 .80875 m .57737 .80837 L .57779 .80728 L F
.386 .499 .851 r
.57922 .80583 m .57779 .80728 L .57754 .80538 L F
.563 0 0 r
.57407 .79949 m .57293 .79947 L .5729 .79902 L F
.268 .009 .323 r
.60981 .7788 m .61114 .78021 L .61182 .7783 L F
.60981 .7788 m .60957 .78096 L .61114 .78021 L F
.598 .249 .349 r
.41899 .82448 m .42115 .82468 L .42247 .82247 L F
.417 0 .136 r
.42115 .82468 m .42451 .82271 L .42247 .82247 L F
.592 .364 .539 r
.48719 .83275 m .48628 .83575 L .48418 .83566 L F
.043 0 0 r
.48719 .83275 m .48791 .83247 L .48913 .83251 L F
.357 0 0 r
.45833 .81808 m .46031 .8185 L .4617 .81776 L F
.406 0 0 r
.46031 .8185 m .46377 .81769 L .4617 .81776 L F
.486 0 0 r
.44585 .81935 m .44776 .81974 L .44862 .81928 L F
.254 0 0 r
.44776 .81974 m .45092 .81934 L .44862 .81928 L F
.566 .937 .842 r
.39025 .88695 m .39091 .88612 L .39286 .88554 L F
.39025 .88695 m .38911 .8872 L .39091 .88612 L F
.311 0 0 r
.44162 .8883 m .44452 .88716 L .44352 .88792 L F
.318 0 0 r
.44452 .88716 m .44555 .88773 L .44352 .88792 L F
.44452 .88716 m .44657 .88703 L .44555 .88773 L F
.717 .63 .759 r
.59143 .77288 m .59085 .77684 L .58963 .77365 L F
.59143 .77288 m .5927 .77596 L .59085 .77684 L F
.668 .27 0 r
.56277 .83438 m .56331 .83527 L .56465 .83785 L F
0 0 0 r
.50153 .86107 m .50077 .86223 L .501 .86188 L F
.464 0 .03 r
.43175 .82187 m .43384 .82198 L .43524 .82072 L F
.505 .047 .098 r
.43384 .82198 m .43698 .82138 L .43524 .82072 L F
.469 .648 .937 r
.48693 .87532 m .48834 .87802 L .48549 .87638 L F
.816 .53 .504 r
.48549 .87638 m .48834 .87802 L .48789 .87959 L F
.453 .166 .387 r
.48789 .87959 m .48834 .87802 L .491 .87807 L F
.325 .682 .978 r
.41451 .8818 m .41373 .88252 L .41255 .88163 L F
.503 .903 .785 r
.41538 .88154 m .41373 .88252 L .41451 .8818 L F
.525 .327 .555 r
.37518 .76525 m .37468 .76832 L .3725 .76847 L F
.536 .337 .558 r
.37468 .76832 m .37262 .76969 L .3725 .76847 L F
.266 .717 .958 r
.57287 .80987 m .57657 .81047 L .57532 .8099 L F
.785 .607 .659 r
.48396 .82497 m .48713 .82543 L .48747 .82287 L F
.48396 .82497 m .48747 .82287 L .48601 .82474 L F
.729 .375 .38 r
.48747 .82287 m .49 .82506 L .48601 .82474 L F
.672 .409 .515 r
.4895 .82305 m .49 .82506 L .48747 .82287 L F
.546 .281 .465 r
.5054 .82503 m .50878 .82141 L .50502 .82241 L F
.5054 .82503 m .5077 .82484 L .50878 .82141 L F
0 .294 .739 r
.50878 .82141 m .51051 .82241 L .50829 .82108 L F
.717 .517 .619 r
.5077 .82484 m .51051 .82241 L .50878 .82141 L F
0 0 0 r
.58773 .83609 m .58857 .83527 L .58961 .8336 L F
.59183 .83101 m .58961 .8336 L .5911 .83255 L F
.317 0 .135 r
.58961 .8336 m .59055 .83486 L .5911 .83255 L F
.58961 .8336 m .58857 .83527 L .59055 .83486 L F
.742 .759 .866 r
.39176 .74525 m .38841 .74518 L .39051 .74326 L F
.084 .641 .79 r
.39176 .74525 m .39009 .74511 L .38841 .74518 L F
.831 .785 .809 r
.39411 .74248 m .39176 .74525 L .39051 .74326 L F
.229 .661 .956 r
.3926 .74567 m .39009 .74511 L .39176 .74525 L F
.577 .392 .595 r
.39411 .74248 m .39384 .74501 L .39176 .74525 L F
.206 0 0 r
.39384 .74501 m .3926 .74567 L .39176 .74525 L F
.507 .476 .757 r
.36048 .75004 m .36058 .75113 L .36212 .74942 L F
.593 .551 .776 r
.36058 .75113 m .36331 .75244 L .36212 .74942 L F
.756 .986 .901 r
.58699 .83769 m .58531 .83892 L .58436 .83888 L F
.831 .785 .809 r
.39411 .74248 m .39051 .74326 L .39244 .74226 L F
.639 .304 .389 r
.39244 .74226 m .3945 .74267 L .39411 .74248 L F
.582 .602 .838 r
.3945 .74267 m .39384 .74501 L .39411 .74248 L F
.274 0 0 r
.40509 .82653 m .40854 .8259 L .40668 .82596 L F
.483 .462 .758 r
.50003 .82006 m .50204 .82169 L .50237 .82051 L F
0 0 0 r
.56413 .80838 m .56323 .80944 L .56467 .80766 L F
.234 .255 .678 r
.56413 .80838 m .5648 .81183 L .56323 .80944 L F
.589 .391 .581 r
.50585 .85196 m .50657 .85452 L .50668 .85128 L F
.57 .136 .176 r
.45154 .87609 m .4498 .87504 L .44839 .87665 L F
.54 .19 .324 r
.45154 .87609 m .45166 .87496 L .4498 .87504 L F
.37 0 .174 r
.51717 .877 m .52032 .87533 L .51934 .87646 L F
.22 0 .051 r
.51934 .87646 m .52032 .87533 L .52219 .87469 L F
.745 .643 .747 r
.59483 .77329 m .5927 .77596 L .59143 .77288 L F
.693 .566 .706 r
.59483 .77329 m .59568 .77602 L .5927 .77596 L F
.548 .352 .567 r
.59568 .77602 m .5934 .77856 L .5927 .77596 L F
.902 .557 .381 r
.55372 .80215 m .55604 .80464 L .55504 .80399 L F
.821 .353 0 r
.55604 .80464 m .55645 .8063 L .55504 .80399 L F
.55604 .80464 m .55756 .80708 L .55645 .8063 L F
.554 .353 .563 r
.37655 .76768 m .37518 .76525 L .37684 .7654 L F
.37655 .76768 m .37468 .76832 L .37518 .76525 L F
.688 .433 .531 r
.52814 .81249 m .52751 .81491 L .52567 .81441 L F
.581 .492 .719 r
.5295 .80951 m .52814 .81249 L .5274 .81012 L F
.5295 .80951 m .52999 .81231 L .52814 .81249 L F
.628 .373 .512 r
.53016 .81429 m .52814 .81249 L .52999 .81231 L F
.53016 .81429 m .52751 .81491 L .52814 .81249 L F
.96 .719 .53 r
.58973 .78648 m .58955 .78869 L .58839 .78751 L F
.627 .558 .757 r
.5914 .78566 m .58973 .78648 L .58894 .78376 L F
.75 .606 .699 r
.5914 .78566 m .58955 .78869 L .58973 .78648 L F
.637 .425 .58 r
.38249 .85133 m .38235 .85361 L .38222 .85135 L F
.652 .852 .459 r
.56736 .82512 m .5686 .82331 L .5696 .82177 L F
.717 .668 .8 r
.58098 .77337 m .58216 .77617 L .5791 .77644 L F
.711 .665 .803 r
.58444 .77432 m .58216 .77617 L .58098 .77337 L F
.152 .213 .673 r
.49063 .82986 m .49093 .83292 L .4923 .83094 L F
.752 .569 .648 r
.50204 .82169 m .50517 .81987 L .50403 .81943 L F
.50204 .82169 m .50502 .82241 L .50517 .81987 L F
0 .547 .746 r
.50728 .8198 m .50403 .81943 L .50517 .81987 L F
0 0 0 r
.52874 .8328 m .53198 .83066 L .53121 .83067 L F
.573 .941 .864 r
.53287 .82971 m .53198 .83066 L .53121 .83067 L F
.53287 .82971 m .53198 .83066 L .53121 .83067 L F
0 0 0 r
.50925 .85012 m .50668 .85128 L .50785 .85088 L F
.242 .112 .497 r
.50668 .85128 m .50817 .85277 L .50785 .85088 L F
.50668 .85128 m .50657 .85452 L .50817 .85277 L F
.762 .59 .665 r
.54572 .83104 m .5425 .83301 L .5446 .83011 L F
.54572 .83104 m .54641 .83359 L .5425 .83301 L F
.369 0 .111 r
.5249 .80568 m .52728 .80454 L .52639 .80481 L F
.639 .632 .827 r
.36002 .7366 m .35757 .73724 L .35623 .73455 L F
.47 .225 .461 r
.53532 .83354 m .53838 .83095 L .53728 .83298 L F
0 0 .14 r
.53728 .83298 m .53838 .83095 L .53532 .83354 L F
.156 0 0 r
.44855 .88691 m .45196 .8848 L .45042 .88633 L F
.303 0 0 r
.45196 .8848 m .45254 .88574 L .45042 .88633 L F
.45196 .8848 m .45398 .88474 L .45254 .88574 L F
.124 .588 .92 r
.46241 .83195 m .46315 .8315 L .46224 .83169 L F
.46241 .83195 m .46406 .83223 L .46315 .8315 L F
.506 .243 .45 r
.38494 .85126 m .38235 .85361 L .38249 .85133 L F
.608 .533 .744 r
.58033 .79365 m .58264 .79359 L .57962 .79236 L F
.58033 .79365 m .58304 .7944 L .58264 .79359 L F
.496 .486 .775 r
.58033 .79365 m .58336 .79651 L .58304 .7944 L F
.699 .221 .111 r
.4871 .88716 m .49025 .88784 L .48908 .88871 L F
.362 0 0 r
.49025 .88784 m .49098 .88888 L .48908 .88871 L F
.263 0 0 r
.49064 .88804 m .49253 .88781 L .49025 .88784 L F
.362 0 0 r
.49025 .88784 m .49253 .88781 L .49098 .88888 L F
.927 .947 .786 r
.50359 .82765 m .5045 .82819 L .50477 .82661 L F
.362 .164 .471 r
.47989 .83004 m .47771 .83282 L .47829 .8307 L F
.164 0 0 r
.41786 .89485 m .42128 .89289 L .4197 .8941 L F
.295 0 0 r
.42128 .89289 m .4215 .89378 L .4197 .8941 L F
.42128 .89289 m .42334 .89279 L .4215 .89378 L F
.699 .22 .11 r
.44189 .87618 m .44438 .87503 L .4408 .87418 L F
.771 .658 .738 r
.4408 .87418 m .44438 .87503 L .44366 .87227 L F
.521 .502 .776 r
.44366 .87227 m .44438 .87503 L .44522 .87145 L F
.712 .718 .192 r
.44522 .87145 m .44438 .87503 L .44461 .87387 L F
.726 .984 .781 r
.44461 .87387 m .44438 .87503 L .44189 .87618 L F
.748 .377 .351 r
.56925 .84325 m .57242 .84367 L .5713 .84552 L F
.731 .357 .341 r
.57242 .84367 m .57455 .84587 L .5713 .84552 L F
.662 .377 .477 r
.57242 .84367 m .57584 .84352 L .57455 .84587 L F
.58 .367 .556 r
.41189 .84105 m .40999 .84292 L .40992 .84089 L F
.649 .54 .717 r
.36126 .75497 m .36477 .75612 L .36331 .75244 L F
.409 .125 .368 r
.36196 .75802 m .36477 .75612 L .36126 .75497 L F
0 0 0 r
.59183 .83101 m .59166 .83184 L .59341 .82968 L F
.59183 .83101 m .5911 .83255 L .59166 .83184 L F
.215 .737 .835 r
.48713 .82543 m .49 .82506 L .49034 .82514 L F
.737 .401 .412 r
.4892 .82722 m .49034 .82514 L .49 .82506 L F
.4892 .82722 m .49254 .82753 L .49034 .82514 L F
.673 .412 .518 r
.49034 .82514 m .49254 .82753 L .49234 .82543 L F
.05 .507 .89 r
.48338 .88538 m .48646 .88707 L .4871 .88716 L F
.607 .949 .92 r
.48178 .87368 m .47954 .87487 L .47894 .8746 L F
.495 .897 .931 r
.47894 .8746 m .47954 .87487 L .4777 .8748 L F
.224 .733 .682 r
.47043 .83336 m .4688 .83387 L .46677 .83452 L F
.344 0 0 r
.47277 .83242 m .4688 .83387 L .47043 .83336 L F
0 0 0 r
.5274 .87071 m .5296 .86965 L .52667 .8712 L F
.232 0 0 r
.57119 .80285 m .56741 .80451 L .57104 .80253 L F
.412 .549 .883 r
.57289 .80187 m .57119 .80285 L .57104 .80253 L F
.57289 .80187 m .57432 .80434 L .57119 .80285 L F
.396 .662 .966 r
.5729 .79902 m .57102 .79898 L .56955 .79767 L F
.426 .027 .177 r
.56936 .80081 m .57102 .79898 L .5729 .79902 L F
.728 .69 .814 r
.59382 .77062 m .59483 .77329 L .59143 .77288 L F
.744 .698 .808 r
.59696 .77093 m .59483 .77329 L .59382 .77062 L F
.666 .572 .739 r
.59696 .77093 m .59716 .77294 L .59483 .77329 L F
.617 .494 .69 r
.59716 .77294 m .59568 .77602 L .59483 .77329 L F
.565 .489 .729 r
.37295 .75059 m .37377 .75231 L .37175 .75277 L F
.571 .442 .666 r
.37377 .75231 m .3717 .75477 L .37175 .75277 L F
.548 .352 .567 r
.59568 .77602 m .59561 .77852 L .5934 .77856 L F
.655 .48 .636 r
.59561 .77852 m .59307 .78072 L .5934 .77856 L F
.602 .405 .588 r
.61952 .77607 m .61966 .77854 L .61743 .7786 L F
.596 .401 .588 r
.6217 .77703 m .61952 .77607 L .6223 .77574 L F
.6217 .77703 m .61966 .77854 L .61952 .77607 L F
.345 0 0 r
.39595 .82819 m .398 .82803 L .39899 .82729 L F
.413 0 .01 r
.39899 .82729 m .398 .82803 L .40102 .82723 L F
.717 .668 .8 r
.58098 .77337 m .5791 .77644 L .57878 .77377 L F
.464 .188 .409 r
.36548 .77357 m .36494 .77559 L .36299 .77596 L F
.502 .223 .423 r
.367 .77519 m .36548 .77357 L .36744 .77318 L F
.367 .77519 m .36494 .77559 L .36548 .77357 L F
.399 0 .01 r
.56467 .80766 m .56562 .80853 L .56413 .80838 L F
.56467 .80766 m .56699 .80751 L .56562 .80853 L F
.57 .321 .5 r
.63197 .76794 m .63116 .77068 L .62897 .77082 L F
.595 .346 .509 r
.63445 .7695 m .63197 .76794 L .63409 .76803 L F
.63445 .7695 m .63116 .77068 L .63197 .76794 L F
0 0 0 r
.40916 .89695 m .40815 .89729 L .4101 .89676 L F
.40916 .89695 m .40758 .89782 L .40815 .89729 L F
.575 .563 .803 r
.37443 .75579 m .37238 .7562 L .3717 .75477 L F
.28 0 0 r
.51745 .8716 m .51875 .87109 L .51609 .87114 L F
.785 .572 .611 r
.49809 .8123 m .49542 .8125 L .49777 .80988 L F
0 .062 .62 r
.49846 .80954 m .49953 .81278 L .49777 .80988 L F
.496 .701 .961 r
.57636 .80415 m .57754 .80538 L .57499 .80547 L F
.57636 .80415 m .57499 .80547 L .5741 .80652 L F
.585 .637 .869 r
.57625 .78455 m .57798 .78572 L .57833 .78368 L F
.382 .031 .24 r
.57729 .78559 m .57625 .78455 L .57833 .78368 L F
.57729 .78559 m .57833 .78368 L .57762 .78313 L F
.918 .967 .788 r
.57909 .78056 m .57833 .78368 L .57896 .78238 L F
.57909 .78056 m .57762 .78313 L .57833 .78368 L F
.512 .563 .844 r
.57833 .78368 m .58083 .78374 L .57896 .78238 L F
.179 0 .178 r
.57798 .78572 m .58083 .78374 L .57833 .78368 L F
.62 .382 .535 r
.63655 .76593 m .63625 .76813 L .63409 .76803 L F
.778 .641 .71 r
.6386 .76534 m .63625 .76813 L .63655 .76593 L F
.862 .537 .433 r
.51088 .85313 m .51225 .8513 L .51049 .85112 L F
.964 .721 .521 r
.51216 .85385 m .51225 .8513 L .51088 .85313 L F
.617 .494 .69 r
.59716 .77294 m .59788 .7758 L .59568 .77602 L F
.583 .373 .562 r
.59788 .7758 m .59561 .77852 L .59568 .77602 L F
.179 0 .178 r
.57798 .78572 m .57987 .7852 L .58083 .78374 L F
.196 0 .223 r
.57798 .78572 m .57709 .78816 L .57987 .7852 L F
.67 .388 .484 r
.57584 .84352 m .57767 .84524 L .57455 .84587 L F
.57584 .84352 m .57775 .84355 L .57767 .84524 L F
.494 .303 .55 r
.66825 .75022 m .66815 .75261 L .66637 .75306 L F
.551 .361 .576 r
.67054 .74968 m .66815 .75261 L .66825 .75022 L F
.756 .376 .334 r
.56402 .80424 m .56574 .80638 L .56644 .8044 L F
.119 .219 .694 r
.56755 .80363 m .56741 .80451 L .56644 .8044 L F
0 0 0 r
.56644 .8044 m .56574 .80638 L .56755 .80363 L F
.588 .699 .92 r
.38022 .75721 m .37816 .75769 L .37649 .75542 L F
.573 .476 .706 r
.38022 .75721 m .37876 .76094 L .37816 .75769 L F
.537 .55 .816 r
.37414 .74534 m .37235 .74695 L .37214 .74522 L F
.37414 .74534 m .37501 .74666 L .37235 .74695 L F
.461 .359 .653 r
.37483 .74925 m .37235 .74695 L .37501 .74666 L F
.37483 .74925 m .37295 .75059 L .37235 .74695 L F
.296 0 0 r
.47306 .81609 m .47672 .81516 L .47456 .81552 L F
.83 .756 .781 r
.56802 .8123 m .56892 .81493 L .56619 .8152 L F
.83 .762 .788 r
.56619 .8152 m .56892 .81493 L .5668 .8176 L F
.817 .705 .741 r
.49204 .82295 m .49 .82506 L .4895 .82305 L F
.9 .98 .699 r
.5635 .81508 m .56175 .81679 L .56127 .8143 L F
.5635 .81508 m .56191 .81771 L .56175 .81679 L F
.549 .501 .754 r
.5648 .81183 m .56619 .8152 L .5635 .81508 L F
.528 .267 .463 r
.48913 .83251 m .48833 .8356 L .48628 .83575 L F
.687 .421 .515 r
.49184 .83454 m .48913 .83251 L .49093 .83292 L F
.49184 .83454 m .48833 .8356 L .48913 .83251 L F
.606 .183 .214 r
.38975 .84949 m .39171 .85073 L .38965 .85044 L F
.581 .228 .335 r
.39331 .84896 m .39171 .85073 L .38975 .84949 L F
.764 .695 .785 r
.661 .7427 m .65926 .74521 L .65778 .74406 L F
.698 .6 .743 r
.661 .7427 m .66186 .74518 L .65926 .74521 L F
.31 .09 .41 r
.66186 .74518 m .65995 .74803 L .65926 .74521 L F
.907 .867 .428 r
.56175 .81679 m .56191 .81771 L .5613 .8198 L F
.54 .903 .708 r
.51433 .87886 m .51717 .877 L .51612 .87812 L F
.242 0 0 r
.51612 .87812 m .51717 .877 L .51934 .87646 L F
.756 .986 .901 r
.58699 .83769 m .58436 .83888 L .58634 .83806 L F
0 0 .241 r
.58773 .83609 m .58699 .83769 L .5883 .83731 L F
0 0 0 r
.58699 .83769 m .58634 .83806 L .5883 .83731 L F
.513 .261 .469 r
.66637 .75306 m .66596 .75503 L .66382 .75538 L F
.468 .224 .46 r
.66815 .75261 m .66596 .75503 L .66637 .75306 L F
.384 0 0 r
.46377 .81769 m .46594 .81768 L .46672 .81699 L F
.066 0 0 r
.46594 .81768 m .46889 .8168 L .46672 .81699 L F
.588 .339 .506 r
.38235 .85361 m .38036 .85441 L .38212 .85367 L F
.38235 .85361 m .37972 .85601 L .38036 .85441 L F
.05 .615 .773 r
.36048 .75004 m .35899 .74992 L .35712 .74993 L F
.533 .909 .948 r
.36045 .74931 m .36048 .75004 L .36212 .74942 L F
.36045 .74931 m .35899 .74992 L .36048 .75004 L F
.472 .012 .078 r
.43698 .82138 m .43902 .82149 L .44041 .82012 L F
.29 0 0 r
.43902 .82149 m .44252 .82009 L .44041 .82012 L F
.07 0 0 r
.38337 .83094 m .38325 .83064 L .38159 .83158 L F
.38337 .83094 m .38528 .83052 L .38325 .83064 L F
.451 .609 .915 r
.57962 .79236 m .58154 .79121 L .57898 .79129 L F
.57962 .79236 m .58264 .79359 L .58154 .79121 L F
.747 .425 .438 r
.5425 .83301 m .54641 .83359 L .5456 .83479 L F
0 0 0 r
.5456 .83479 m .54641 .83359 L .54874 .83037 L F
.655 .375 .483 r
.57775 .84355 m .57991 .84571 L .57767 .84524 L F
.644 .376 .498 r
.57775 .84355 m .57995 .84362 L .57991 .84571 L F
.517 .292 .512 r
.35971 .76046 m .36163 .76029 L .36196 .75802 L F
.409 .125 .368 r
.36196 .75802 m .36371 .75765 L .36477 .75612 L F
.5 .295 .533 r
.36163 .76029 m .36371 .75765 L .36196 .75802 L F
.376 .841 .868 r
.42189 .8796 m .42112 .88013 L .42012 .88024 L F
.42189 .8796 m .42309 .87954 L .42112 .88013 L F
.807 .528 .517 r
.66691 .74505 m .67013 .74737 L .66915 .74445 L F
.66691 .74505 m .6668 .74701 L .67013 .74737 L F
.151 0 0 r
.6668 .74701 m .66942 .7474 L .67013 .74737 L F
0 0 .204 r
.67013 .74737 m .67132 .74435 L .66915 .74445 L F
.67013 .74737 m .67114 .74628 L .67132 .74435 L F
.566 .927 .763 r
.67013 .74737 m .66942 .7474 L .67114 .74628 L F
.467 .322 .599 r
.67239 .74924 m .67013 .74737 L .67249 .74736 L F
.67239 .74924 m .67054 .74968 L .67013 .74737 L F
.371 .273 .613 r
.48811 .85091 m .4896 .85323 L .4891 .85161 L F
0 0 .241 r
.58773 .83609 m .5883 .83731 L .58857 .83527 L F
.834 .534 .482 r
.49234 .82543 m .49254 .82753 L .49502 .82784 L F
0 0 0 r
.63855 .75911 m .63738 .76027 L .63915 .75873 L F
.576 .937 .922 r
.39239 .90198 m .39604 .90087 L .39484 .90081 L F
.634 .953 .937 r
.39661 .89985 m .39604 .90087 L .39769 .89993 L F
.634 .952 .937 r
.39484 .90081 m .39604 .90087 L .39661 .89985 L F
.634 .408 .558 r
.61084 .78381 m .61304 .78587 L .61082 .78595 L F
.61084 .78381 m .61311 .78372 L .61304 .78587 L F
.826 .428 .296 r
.48423 .87504 m .48178 .87368 L .48336 .87439 L F
.158 .612 .933 r
.48693 .87532 m .48423 .87504 L .48336 .87439 L F
.469 .648 .937 r
.48693 .87532 m .48549 .87638 L .48423 .87504 L F
.269 0 0 r
.40854 .8259 m .41014 .82611 L .4118 .82523 L F
.019 0 0 r
.41014 .82611 m .4139 .82533 L .4118 .82523 L F
.31 .09 .41 r
.66186 .74518 m .66152 .74711 L .65995 .74803 L F
.227 0 .278 r
.65995 .74803 m .66152 .74711 L .6595 .74911 L F
.664 .3 .344 r
.51681 .8278 m .51939 .8271 L .51901 .82954 L F
0 0 .355 r
.51972 .82757 m .51939 .8271 L .51884 .82526 L F
0 0 .104 r
.51901 .82954 m .51939 .8271 L .51972 .82757 L F
.51 .242 .444 r
.62679 .77104 m .62647 .7729 L .62433 .77317 L F
.627 .347 .474 r
.62679 .77104 m .6289 .77289 L .62647 .7729 L F
.599 .354 .517 r
.62897 .77082 m .6289 .77289 L .62679 .77104 L F
.601 .545 .764 r
.661 .7427 m .66461 .74474 L .66186 .74518 L F
.598 .523 .741 r
.66186 .74518 m .66433 .7473 L .66152 .74711 L F
.66186 .74518 m .66461 .74474 L .66433 .7473 L F
.589 .274 .403 r
.49655 .82046 m .49674 .822 L .49439 .82208 L F
.357 0 .064 r
.45952 .88343 m .46085 .88375 L .45899 .8843 L F
.133 0 0 r
.51126 .87247 m .5083 .87465 L .51003 .87379 L F
0 0 0 r
.51257 .87219 m .51126 .87247 L .51003 .87379 L F
.51257 .87219 m .51335 .87196 L .51126 .87247 L F
.393 .223 .529 r
.53932 .83254 m .53825 .83127 L .53838 .83095 L F
.097 0 .187 r
.53728 .83298 m .53825 .83127 L .53932 .83254 L F
.393 .223 .529 r
.53932 .83254 m .53838 .83095 L .53728 .83298 L F
.533 .631 .894 r
.48799 .86186 m .48768 .86434 L .48684 .86371 L F
.48799 .86186 m .49007 .86462 L .48768 .86434 L F
.459 0 0 r
.48768 .86434 m .48827 .86556 L .48684 .86371 L F
.48768 .86434 m .49007 .86462 L .48827 .86556 L F
.524 .86 .589 r
.502 .86061 m .50153 .86107 L .501 .86188 L F
.594 .21 .284 r
.4537 .87642 m .45492 .87449 L .45166 .87496 L F
.375 0 .156 r
.45691 .87413 m .45492 .87449 L .4537 .87642 L F
.166 0 0 r
.5118 .82571 m .51352 .82609 L .51054 .82632 L F
.5118 .82571 m .51389 .82584 L .51352 .82609 L F
.554 .855 .997 r
.50554 .83545 m .50215 .8352 L .50434 .8354 L F
.589 .846 .993 r
.50836 .83464 m .50554 .83545 L .50674 .83428 L F
.266 .771 .862 r
.50554 .83545 m .50657 .83504 L .50674 .83428 L F
.50554 .83545 m .50434 .8354 L .50657 .83504 L F
.611 .503 .706 r
.50836 .83464 m .50588 .83758 L .50554 .83545 L F
.504 .349 .604 r
.41392 .84272 m .41189 .84105 L .41557 .84038 L F
.403 0 .021 r
.41744 .84114 m .41392 .84272 L .41557 .84038 L F
.368 0 0 r
.44252 .82009 m .44452 .82007 L .44585 .81935 L F
.519 .038 .053 r
.44585 .81935 m .44452 .82007 L .44776 .81974 L F
.578 .253 .382 r
.67335 .74394 m .67652 .74168 L .67494 .74204 L F
.596 .378 .556 r
.6155 .78128 m .61551 .78366 L .61311 .78372 L F
.53 .348 .579 r
.61743 .7786 m .61759 .78098 L .6155 .78128 L F
.473 .258 .506 r
.61759 .78098 m .61551 .78366 L .6155 .78128 L F
.247 0 0 r
.44598 .83371 m .44469 .83447 L .44241 .83461 L F
.429 0 0 r
.44801 .83349 m .44469 .83447 L .44598 .83371 L F
.962 .718 .275 r
.53519 .80933 m .53573 .81228 L .535 .81126 L F
0 0 .206 r
.53577 .81385 m .535 .81126 L .53573 .81228 L F
.656 .845 .442 r
.65615 .74465 m .65541 .74554 L .65532 .74409 L F
.878 .959 .851 r
.65819 .74224 m .65615 .74465 L .6558 .74442 L F
.65819 .74224 m .6558 .74442 L .65651 .74333 L F
.567 .399 .614 r
.65819 .74224 m .65778 .74406 L .65615 .74465 L F
.764 .695 .785 r
.661 .7427 m .65819 .74224 L .66035 .74187 L F
.661 .7427 m .65778 .74406 L .65819 .74224 L F
.878 .959 .851 r
.65819 .74224 m .65532 .74409 L .65727 .74162 L F
.485 .822 .999 r
.65727 .74162 m .66035 .74187 L .65819 .74224 L F
.137 0 .129 r
.65778 .74406 m .66035 .74187 L .6576 .74165 L F
.65735 .74203 m .6576 .74165 L .65727 .74162 L F
.65778 .74406 m .6576 .74165 L .65735 .74203 L F
.878 .959 .851 r
.65651 .74333 m .6558 .74442 L .65532 .74409 L F
.65 .669 .855 r
.36926 .74422 m .36717 .74493 L .36586 .74261 L F
.996 .822 .555 r
.58463 .79902 m .58466 .80171 L .58349 .80189 L F
.675 .567 .726 r
.58672 .79925 m .58466 .80171 L .58463 .79902 L F
.745 .232 0 r
.58349 .80189 m .58466 .80171 L .58679 .80398 L F
.626 .496 .684 r
.58672 .79925 m .58662 .8022 L .58466 .80171 L F
.938 .573 .274 r
.58662 .8022 m .58679 .80398 L .58466 .80171 L F
.288 .665 .972 r
.52754 .83123 m .52848 .83234 L .52541 .8316 L F
.587 .621 .854 r
.5256 .83148 m .52634 .8322 L .52578 .83146 L F
.5256 .83148 m .52578 .83146 L .52426 .82947 L F
.488 .581 .874 r
.52718 .83127 m .52634 .8322 L .52773 .83161 L F
.511 .587 .868 r
.52754 .83123 m .52638 .83138 L .52426 .82947 L F
.488 .581 .874 r
.52426 .82947 m .52578 .83146 L .52638 .83138 L F
.511 .587 .868 r
.52638 .83138 m .5256 .83148 L .52426 .82947 L F
.488 .581 .874 r
.52426 .82947 m .52638 .83138 L .52718 .83127 L F
.288 .665 .972 r
.52754 .83123 m .52704 .83131 L .52578 .83146 L F
.52754 .83123 m .52578 .83146 L .52638 .83138 L F
.52704 .83131 m .52541 .8316 L .5256 .83148 L F
.488 .581 .874 r
.52578 .83146 m .52634 .8322 L .52718 .83127 L F
.288 .665 .972 r
.52638 .83138 m .52578 .83146 L .5256 .83148 L F
.395 .103 .348 r
.5697 .81984 m .57217 .81759 L .57153 .8192 L F
0 .097 .644 r
.57259 .81647 m .57217 .81759 L .57105 .81451 L F
.67 .757 .269 r
.57153 .8192 m .57217 .81759 L .57259 .81647 L F
.672 .588 .753 r
.36309 .73927 m .36075 .73995 L .36002 .7366 L F
.408 .089 .31 r
.61757 .76826 m .61971 .76783 L .62023 .76556 L F
0 0 .142 r
.62023 .76556 m .62071 .76606 L .62245 .76553 L F
.62071 .76606 m .62083 .76618 L .62117 .76604 L F
.62071 .76606 m .62117 .76604 L .62245 .76553 L F
.62083 .76618 m .6213 .76613 L .62245 .76553 L F
.628 .949 .941 r
.62148 .76603 m .62464 .76531 L .62245 .76553 L F
.62095 .76631 m .62216 .76595 L .62148 .76603 L F
0 0 .142 r
.62083 .76618 m .62095 .76631 L .6213 .76613 L F
.62023 .76556 m .61971 .76783 L .62095 .76631 L F
.777 .48 .484 r
.61815 .76446 m .62208 .76597 L .62095 .76631 L F
.62208 .76597 m .62234 .76607 L .62095 .76631 L F
.628 .949 .941 r
.62095 .76631 m .62238 .76592 L .62216 .76595 L F
.62228 .76594 m .6224 .7659 L .62148 .76603 L F
.6224 .7659 m .62464 .76531 L .62215 .76588 L F
.6224 .7659 m .62215 .76588 L .62148 .76603 L F
.62248 .76589 m .62464 .76531 L .62228 .76594 L F
.62243 .76591 m .62388 .76494 L .62464 .76531 L F
.293 .103 .444 r
.625 .76285 m .62388 .76494 L .62269 .76573 L F
.625 .76285 m .62255 .76592 L .62247 .76591 L F
.735 .609 .717 r
.62037 .7618 m .62228 .76594 L .61815 .76446 L F
.62228 .76594 m .62217 .76596 L .61815 .76446 L F
.628 .949 .941 r
.62238 .76592 m .62248 .76589 L .62228 .76594 L F
.293 .103 .444 r
.625 .76285 m .62252 .76585 L .62037 .7618 L F
.62252 .76585 m .62247 .76591 L .62246 .76588 L F
.62252 .76585 m .62246 .76588 L .62037 .7618 L F
.628 .949 .941 r
.62238 .76592 m .62252 .76585 L .62243 .76591 L F
.293 .103 .444 r
.62247 .76591 m .62236 .76592 L .62037 .7618 L F
.6224 .766 m .62231 .76601 L .62037 .7618 L F
.735 .609 .717 r
.62231 .76601 m .6222 .76602 L .61815 .76446 L F
.628 .949 .941 r
.62095 .76631 m .62388 .76494 L .62252 .76585 L F
.62095 .76631 m .62252 .76585 L .62238 .76592 L F
.293 .103 .444 r
.62269 .76573 m .62388 .76494 L .62255 .76592 L F
.62247 .76591 m .62255 .76592 L .62234 .76607 L F
.735 .609 .717 r
.62228 .76594 m .62231 .76601 L .62217 .76596 L F
.293 .103 .444 r
.62247 .76591 m .6224 .766 L .62236 .76592 L F
.6224 .766 m .62234 .76607 L .62231 .76601 L F
.735 .609 .717 r
.62231 .76601 m .62234 .76607 L .6222 .76602 L F
.51 .834 .999 r
.49116 .87976 m .48789 .87959 L .49015 .87941 L F
.464 .612 .911 r
.49139 .87613 m .49106 .87797 L .49114 .87597 L F
.894 .944 .835 r
.49324 .87714 m .49138 .87948 L .49138 .87851 L F
.49324 .87714 m .49015 .87941 L .49106 .87797 L F
.273 0 0 r
.49366 .8776 m .49324 .87714 L .49106 .87797 L F
.464 .612 .911 r
.49366 .8776 m .49138 .87793 L .49139 .87613 L F
.49138 .87793 m .49106 .87797 L .49139 .87613 L F
.894 .944 .835 r
.49138 .87851 m .49116 .87976 L .49015 .87941 L F
.49138 .87948 m .49116 .87976 L .49138 .87851 L F
.595 .442 .644 r
.59099 .7811 m .59102 .7837 L .58894 .78376 L F
.627 .558 .757 r
.5914 .78566 m .58894 .78376 L .59102 .7837 L F
.851 .605 .568 r
.39355 .85014 m .39331 .84896 L .39524 .8486 L F
.39355 .85014 m .39171 .85073 L .39331 .84896 L F
.501 .5 .788 r
.50205 .83849 m .50215 .8352 L .50013 .83581 L F
.50205 .83849 m .50316 .83914 L .50215 .8352 L F
.452 .306 .591 r
.39714 .84613 m .39701 .84834 L .39524 .8486 L F
.822 .91 .508 r
.50397 .86253 m .50492 .86139 L .50302 .86097 L F
.50397 .86253 m .50379 .86374 L .50492 .86139 L F
.817 .705 .741 r
.49204 .82295 m .49234 .82543 L .49 .82506 L F
.751 .318 .223 r
.49234 .82543 m .49163 .82705 L .49 .82506 L F
.253 .286 .702 r
.49368 .82419 m .49234 .82543 L .49204 .82295 L F
.455 .01 .1 r
.49339 .82658 m .49163 .82705 L .49234 .82543 L F
.285 .775 .712 r
.41069 .88141 m .41126 .88112 L .41255 .88163 L F
.41069 .88141 m .4092 .88188 L .41126 .88112 L F
.827 .978 .683 r
.50252 .86463 m .50379 .86374 L .50397 .86253 L F
.373 .834 .905 r
.4645 .88193 m .46676 .88139 L .46548 .88133 L F
.38 .827 .706 r
.46353 .88231 m .4645 .88193 L .46548 .88133 L F
.412 .046 .231 r
.57665 .83841 m .57386 .84071 L .5756 .84005 L F
.597 .185 .232 r
.57866 .83945 m .57665 .83841 L .5756 .84005 L F
.573 .476 .706 r
.38022 .75721 m .38109 .76062 L .37876 .76094 L F
.556 .424 .656 r
.38109 .76062 m .37896 .7629 L .37876 .76094 L F
.526 .302 .517 r
.61966 .77854 m .61759 .78098 L .61743 .7786 L F
.735 .895 .952 r
.56838 .77603 m .56551 .77634 L .56713 .7752 L F
.56838 .77603 m .56612 .77678 L .56551 .77634 L F
.13 0 0 r
.56857 .77607 m .56838 .77603 L .56713 .7752 L F
.214 .349 .785 r
.57052 .77764 m .56838 .77603 L .57087 .77647 L F
.13 0 0 r
.56857 .77607 m .57087 .77647 L .56838 .77603 L F
0 0 0 r
.51365 .81739 m .51269 .8176 L .51464 .81705 L F
.51365 .81739 m .51159 .81792 L .51269 .8176 L F
.915 .963 .797 r
.50103 .81189 m .50186 .80932 L .50292 .81233 L F
.723 .578 .692 r
.54251 .81758 m .53972 .81914 L .53916 .81732 L F
.677 .39 .479 r
.58307 .8435 m .57991 .84571 L .57995 .84362 L F
.58307 .8435 m .58304 .8453 L .57991 .84571 L F
.626 .348 .477 r
.58307 .8435 m .58524 .84547 L .58304 .8453 L F
.646 .342 .442 r
.58563 .8438 m .58524 .84547 L .58307 .8435 L F
.307 .573 .934 r
.57118 .82994 m .57048 .83039 L .56753 .82772 L F
.426 0 .024 r
.45116 .83277 m .44963 .83407 L .44801 .83349 L F
.411 0 .06 r
.45318 .83251 m .44963 .83407 L .45116 .83277 L F
.977 .78 .572 r
.56917 .83489 m .57024 .83554 L .57054 .83311 L F
.585 .467 .685 r
.3599 .76268 m .36163 .76029 L .35971 .76046 L F
.703 .894 .966 r
.50903 .85415 m .50961 .85512 L .51216 .85385 L F
.615 .571 .782 r
.5928 .79121 m .59074 .79173 L .58955 .78869 L F
0 0 .502 r
.5919 .79305 m .59074 .79173 L .5928 .79121 L F
.5919 .79305 m .59127 .79402 L .59074 .79173 L F
.725 .67 .796 r
.57581 .77332 m .57813 .77131 L .57878 .77377 L F
.623 .556 .758 r
.57984 .77021 m .57878 .77377 L .57813 .77131 L F
.57984 .77021 m .58098 .77337 L .57878 .77377 L F
.634 .764 .941 r
.42694 .87895 m .4266 .8805 L .42509 .87931 L F
.42694 .87895 m .42859 .8798 L .4266 .8805 L F
.836 .762 .781 r
.48511 .83017 m .48482 .83343 L .4838 .83312 L F
.944 .835 .706 r
.48418 .83566 m .4838 .83312 L .48482 .83343 L F
.522 .887 .976 r
.48289 .83541 m .48127 .83602 L .48418 .83566 L F
.48289 .83541 m .48127 .83602 L .48418 .83566 L F
.944 .835 .706 r
.48418 .83566 m .48289 .83541 L .4838 .83312 L F
.035 .601 .78 r
.48418 .83566 m .48492 .83558 L .48289 .83541 L F
.48418 .83566 m .48628 .83575 L .48492 .83558 L F
.464 .612 .911 r
.49366 .8776 m .49114 .87597 L .49287 .87773 L F
.23 .739 .886 r
.49298 .87771 m .49366 .8776 L .49287 .87773 L F
.273 0 0 r
.49366 .8776 m .49488 .87741 L .49324 .87714 L F
.23 .739 .886 r
.49482 .87726 m .49366 .8776 L .49298 .87771 L F
.273 0 0 r
.49366 .8776 m .49531 .87748 L .49488 .87741 L F
0 0 .018 r
.65199 .75029 m .65354 .74945 L .65427 .74759 L F
.38 .833 .738 r
.65143 .75042 m .65354 .74945 L .65199 .75029 L F
.657 .409 .533 r
.64657 .76268 m .64367 .76507 L .64381 .7634 L F
.266 .177 .565 r
.60563 .78624 m .60744 .78791 L .6079 .78579 L F
.177 0 0 r
.49458 .88755 m .49534 .88701 L .49733 .88673 L F
.697 .38 .436 r
.57625 .78455 m .57523 .78618 L .57354 .78613 L F
.382 .031 .24 r
.57729 .78559 m .57523 .78618 L .57625 .78455 L F
.568 .322 .504 r
.66433 .7473 m .6668 .74701 L .66691 .74505 L F
0 .126 .602 r
.54816 .81737 m .54792 .81729 L .54706 .81643 L F
.54816 .81737 m .55018 .81908 L .54792 .81729 L F
.571 .442 .666 r
.37377 .75231 m .37401 .75443 L .3717 .75477 L F
.575 .563 .803 r
.37443 .75579 m .3717 .75477 L .37401 .75443 L F
.767 .581 .646 r
.48491 .81719 m .48787 .81578 L .48682 .81449 L F
.48491 .81719 m .48821 .81767 L .48787 .81578 L F
.695 .694 .846 r
.48682 .81449 m .48787 .81578 L .48954 .8147 L F
.585 .458 .674 r
.48787 .81578 m .48821 .81767 L .48954 .8147 L F
.42 .788 .994 r
.48396 .82497 m .48713 .82543 L .48601 .82474 L F
.564 .332 .522 r
.49 .82506 m .48713 .82543 L .48601 .82474 L F
.49 .82506 m .4892 .82722 L .48713 .82543 L F
.48713 .82543 m .4892 .82722 L .49 .82506 L F
.711 .184 0 r
.53261 .86576 m .53018 .8637 L .53138 .86705 L F
.38 0 .007 r
.42075 .84025 m .4191 .8415 L .41744 .84114 L F
.11 0 0 r
.42266 .84072 m .4191 .8415 L .42075 .84025 L F
.283 0 .009 r
.52542 .86883 m .52634 .86754 L .52327 .86891 L F
.619 .057 0 r
.52723 .86876 m .52634 .86754 L .52542 .86883 L F
.777 .608 .67 r
.53916 .81732 m .53747 .81929 L .53696 .81746 L F
.853 .976 .866 r
.39395 .88416 m .39286 .88554 L .39091 .88612 L F
.616 .502 .701 r
.59914 .77039 m .59716 .77294 L .59696 .77093 L F
.59914 .77039 m .59999 .77334 L .59716 .77294 L F
.581 .443 .658 r
.59999 .77334 m .59788 .7758 L .59716 .77294 L F
.356 .095 .374 r
.66382 .75538 m .66345 .75708 L .66162 .75783 L F
.408 .098 .324 r
.66596 .75503 m .66345 .75708 L .66382 .75538 L F
.732 .521 .607 r
.43334 .83582 m .43295 .83795 L .42994 .83786 L F
.599 .367 .536 r
.43533 .83559 m .43295 .83795 L .43334 .83582 L F
.819 .69 .723 r
.52221 .81919 m .51817 .8201 L .5201 .81725 L F
.651 .404 .532 r
.52221 .81919 m .51817 .82275 L .51817 .8201 L F
.52221 .81919 m .5226 .82244 L .51817 .82275 L F
.681 .474 .6 r
.52351 .81946 m .5226 .82244 L .52221 .81919 L F
.75 .606 .699 r
.5914 .78566 m .59281 .78898 L .58955 .78869 L F
.615 .571 .782 r
.5928 .79121 m .58955 .78869 L .59281 .78898 L F
.572 .415 .63 r
.59482 .78634 m .59281 .78898 L .5914 .78566 L F
.59482 .78634 m .59492 .78858 L .59281 .78898 L F
.431 .283 .579 r
.59453 .79072 m .59281 .78898 L .59492 .78858 L F
.59453 .79072 m .5928 .79121 L .59281 .78898 L F
.62 .159 .135 r
.46235 .87185 m .46022 .87256 L .46134 .87207 L F
.946 .685 .508 r
.46235 .87185 m .46134 .87207 L .46105 .87365 L F
.152 0 0 r
.46335 .87214 m .46235 .87185 L .46105 .87365 L F
.46335 .87214 m .46448 .87193 L .46235 .87185 L F
0 0 0 r
.48173 .81232 m .4829 .812 L .4839 .81067 L F
.48173 .81232 m .48076 .8126 L .4829 .812 L F
.689 .621 .775 r
.58848 .77069 m .58963 .77365 L .58628 .77296 L F
.708 .631 .769 r
.59143 .77288 m .58963 .77365 L .58848 .77069 L F
.685 .666 .826 r
.49686 .83491 m .49779 .83673 L .50013 .83581 L F
.981 .836 .627 r
.54929 .82993 m .55002 .82786 L .54907 .82721 L F
.303 .716 .975 r
.54907 .82721 m .55002 .82786 L .55098 .82733 L F
0 0 0 r
.43787 .88925 m .44162 .8883 L .43995 .88904 L F
.078 0 0 r
.44162 .8883 m .44197 .88876 L .43995 .88904 L F
.44162 .8883 m .44352 .88792 L .44197 .88876 L F
.794 .777 .837 r
.58628 .77296 m .58316 .77294 L .58546 .77061 L F
.8 .763 .819 r
.58628 .77296 m .58444 .77432 L .58316 .77294 L F
.769 .764 .848 r
.58848 .77069 m .58628 .77296 L .58546 .77061 L F
.145 .651 .904 r
.35325 .73394 m .35532 .73449 L .35352 .73427 L F
.35325 .73394 m .35623 .73455 L .35532 .73449 L F
.478 .178 .377 r
.62464 .76531 m .62687 .76492 L .6279 .76192 L F
0 0 0 r
.6279 .76192 m .6279 .76311 L .62978 .76223 L F
.6279 .76192 m .62687 .76492 L .6279 .76311 L F
.532 0 0 r
.51034 .80938 m .51222 .81042 L .51356 .80972 L F
.612 .137 .103 r
.51222 .81042 m .51566 .80985 L .51356 .80972 L F
.549 .51 .765 r
.36473 .73905 m .36379 .74274 L .36309 .73927 L F
.36473 .73905 m .36586 .74261 L .36379 .74274 L F
.474 0 0 r
.57898 .79129 m .576 .79124 L .5772 .7908 L F
.996 .822 .555 r
.58463 .79902 m .58349 .80189 L .58134 .79922 L F
.595 .21 .282 r
.65105 .76425 m .64891 .76285 L .65188 .76227 L F
.489 .096 .221 r
.65419 .76233 m .65105 .76425 L .65188 .76227 L F
.158 0 0 r
.43383 .88995 m .435 .89017 L .43236 .8909 L F
.43383 .88995 m .43584 .88965 L .435 .89017 L F
0 .342 .74 r
.52029 .81494 m .52089 .81519 L .52068 .81483 L F
.52089 .81519 m .52139 .81528 L .52068 .81483 L F
.969 .758 .565 r
.52068 .81483 m .52137 .81537 L .52029 .81494 L F
.52137 .81537 m .52268 .81638 L .52071 .81519 L F
.52137 .81537 m .52071 .81519 L .52029 .81494 L F
.843 .898 .876 r
.52068 .81483 m .52184 .81557 L .52529 .81285 L F
0 0 0 r
.52158 .81532 m .5221 .81549 L .52202 .81554 L F
.969 .758 .565 r
.52068 .81483 m .52103 .81608 L .52268 .81638 L F
0 0 0 r
.52152 .8154 m .52202 .81554 L .52103 .81608 L F
.52158 .81532 m .52202 .81554 L .52152 .8154 L F
.843 .898 .876 r
.52068 .81483 m .52529 .81285 L .52299 .81336 L F
0 0 0 r
.52299 .81336 m .52213 .81543 L .52158 .81532 L F
.52213 .81543 m .5221 .81549 L .52158 .81532 L F
0 .342 .74 r
.52089 .81519 m .52184 .81557 L .52139 .81528 L F
.741 .608 .709 r
.50204 .82169 m .50312 .82535 L .50502 .82241 L F
.639 .473 .642 r
.50502 .82241 m .50312 .82535 L .5054 .82503 L F
.828 .917 .896 r
.49953 .81278 m .49761 .81443 L .50144 .81248 L F
.571 .404 .617 r
.49761 .81443 m .49986 .81672 L .50144 .81248 L F
.372 .16 .458 r
.49986 .81672 m .50202 .81377 L .50144 .81248 L F
.569 .06 .002 r
.50144 .81248 m .50202 .81377 L .49953 .81278 L F
.357 0 0 r
.38738 .83041 m .38821 .82963 L .38528 .83052 L F
.113 0 0 r
.38922 .82982 m .38821 .82963 L .38738 .83041 L F
.408 .196 .476 r
.66162 .75783 m .66304 .75874 L .66122 .75952 L F
.66162 .75783 m .66345 .75708 L .66304 .75874 L F
.417 0 .136 r
.42115 .82468 m .42321 .82447 L .42451 .82271 L F
.429 0 .097 r
.42321 .82447 m .42666 .82276 L .42451 .82271 L F
.507 .288 .516 r
.36494 .77559 m .36268 .77814 L .36299 .77596 L F
.777 .608 .67 r
.53916 .81732 m .53972 .81914 L .53747 .81929 L F
.524 0 0 r
.46676 .88139 m .46993 .88171 L .46878 .88147 L F
.038 .597 .809 r
.46993 .88171 m .47199 .88188 L .46878 .88147 L F
.611 .503 .706 r
.50836 .83464 m .50785 .83673 L .50588 .83758 L F
.304 0 .107 r
.50717 .83842 m .50588 .83758 L .50785 .83673 L F
.50717 .83842 m .50526 .83885 L .50588 .83758 L F
.917 .761 .274 r
.56926 .82183 m .5696 .82177 L .56968 .82023 L F
.56959 .82036 m .56968 .82023 L .5697 .81984 L F
.56926 .82183 m .56968 .82023 L .56959 .82036 L F
.56926 .82183 m .5697 .81984 L .57153 .8192 L F
.56926 .82183 m .57138 .81937 L .57114 .81966 L F
.57138 .81937 m .57153 .8192 L .57114 .81966 L F
0 0 0 r
.57074 .82015 m .57114 .81966 L .57284 .81886 L F
.863 .996 .788 r
.56926 .82183 m .57114 .81966 L .56864 .82142 L F
.354 .282 .636 r
.56857 .82154 m .56779 .82133 L .56913 .82058 L F
.863 .996 .788 r
.56926 .82183 m .56857 .82154 L .56779 .82133 L F
0 0 .129 r
.56906 .82416 m .56736 .82512 L .5696 .82177 L F
.916 .774 .29 r
.56906 .82416 m .5696 .82177 L .56926 .82183 L F
0 0 .092 r
.5694 .82354 m .56906 .82416 L .56926 .82183 L F
.5694 .82354 m .56926 .82183 L .56779 .82133 L F
.354 .282 .636 r
.5683 .82202 m .56779 .82133 L .56857 .82154 L F
.863 .996 .788 r
.56857 .82154 m .56851 .82152 L .56779 .82133 L F
.56857 .82154 m .56864 .82142 L .56851 .82152 L F
.56926 .82183 m .56864 .82142 L .56857 .82154 L F
0 0 0 r
.56889 .82128 m .57114 .81966 L .57074 .82015 L F
.56871 .82139 m .56895 .82121 L .56889 .82128 L F
.56851 .82152 m .56864 .82142 L .56871 .82139 L F
.56864 .82142 m .56895 .82121 L .56871 .82139 L F
.56897 .82141 m .57284 .81886 L .57198 .82074 L F
.56892 .82138 m .57284 .81886 L .56897 .82141 L F
.56871 .82139 m .57284 .81886 L .56882 .82145 L F
.56895 .82121 m .57114 .81966 L .56889 .82128 L F
.56882 .82145 m .56892 .82138 L .56897 .82141 L F
.354 .282 .636 r
.5683 .82202 m .56913 .82058 L .56943 .82041 L F
0 0 0 r
.56851 .82152 m .56871 .82139 L .56882 .82145 L F
.354 .282 .636 r
.56876 .82142 m .56873 .8214 L .56875 .82138 L F
.5689 .82131 m .56875 .82138 L .56943 .82041 L F
.665 .673 .848 r
.56851 .82152 m .56882 .82145 L .56943 .82041 L F
.56882 .82145 m .57198 .82074 L .56943 .82041 L F
.354 .282 .636 r
.56942 .82108 m .5689 .82131 L .56943 .82041 L F
.648 .231 .239 r
.56943 .82041 m .57115 .82228 L .57071 .82259 L F
.56942 .82172 m .57071 .82259 L .5694 .82354 L F
.56943 .82041 m .57071 .82259 L .56942 .82172 L F
.354 .282 .636 r
.5694 .82354 m .5683 .82202 L .56873 .8214 L F
.5694 .82354 m .56873 .8214 L .56876 .82142 L F
.5694 .82354 m .56875 .82138 L .56942 .82108 L F
.478 .563 .863 r
.6625 .7416 m .661 .7427 L .66035 .74187 L F
.6625 .7416 m .66461 .74474 L .661 .7427 L F
.158 0 0 r
.50043 .87643 m .49846 .87682 L .49766 .87747 L F
.254 0 0 r
.44776 .81974 m .44982 .81974 L .45092 .81934 L F
.266 0 0 r
.45092 .81934 m .44982 .81974 L .45305 .81935 L F
.175 0 0 r
.37665 .83313 m .37543 .83301 L .37448 .83378 L F
.37665 .83313 m .37775 .83254 L .37543 .83301 L F
.594 .21 .284 r
.4537 .87642 m .45166 .87496 L .45154 .87609 L F
0 0 0 r
.3943 .82869 m .398 .82803 L .39595 .82819 L F
.283 0 .003 r
.54038 .82494 m .54387 .82291 L .54178 .82383 L F
.501 .734 .977 r
.54387 .82291 m .54468 .82158 L .54272 .82229 L F
.54387 .82291 m .54639 .823 L .54468 .82158 L F
.927 .877 .766 r
.54178 .82383 m .54387 .82291 L .54272 .82229 L F
.706 .532 .65 r
.59395 .78347 m .59099 .7811 L .59307 .78072 L F
.59395 .78347 m .59102 .7837 L .59099 .7811 L F
.55 .57 .827 r
.36331 .75244 m .36382 .7491 L .36212 .74942 L F
.36331 .75244 m .36512 .75206 L .36382 .7491 L F
.397 .4 .746 r
.36331 .75244 m .36467 .75406 L .36512 .75206 L F
.36331 .75244 m .36477 .75612 L .36467 .75406 L F
.2 0 0 r
.4839 .81067 m .48479 .81142 L .48575 .81038 L F
.4839 .81067 m .4829 .812 L .48479 .81142 L F
.712 .335 .334 r
.52148 .84831 m .52459 .84846 L .52355 .85032 L F
.253 0 0 r
.52426 .8486 m .52459 .84846 L .52148 .84831 L F
.363 .807 .66 r
.52574 .8478 m .52459 .84846 L .52426 .8486 L F
0 0 0 r
.52355 .85032 m .52459 .84846 L .52574 .8478 L F
.778 .641 .71 r
.6386 .76534 m .63897 .76629 L .63625 .76813 L F
.609 .336 .478 r
.63625 .76813 m .63897 .76629 L .63854 .77 L F
.602 .367 .533 r
.6386 .76534 m .64081 .76578 L .63897 .76629 L F
.542 .304 .503 r
.64081 .76578 m .63854 .77 L .63897 .76629 L F
.711 .665 .803 r
.58444 .77432 m .58098 .77337 L .58316 .77294 L F
0 0 0 r
.52327 .86891 m .52079 .87174 L .52296 .87152 L F
.373 .106 .374 r
.52542 .86883 m .52327 .86891 L .52296 .87152 L F
.302 .589 .943 r
.40303 .8852 m .3999 .88344 L .40198 .88368 L F
.601 .713 .923 r
.40374 .88349 m .40303 .8852 L .40198 .88368 L F
.40374 .88349 m .40515 .88475 L .40303 .8852 L F
.713 .784 .908 r
.56612 .77678 m .5632 .77694 L .56551 .77634 L F
.715 .639 .772 r
.59395 .78347 m .5914 .78566 L .59102 .7837 L F
.688 .59 .741 r
.59395 .78347 m .59482 .78634 L .5914 .78566 L F
.506 .243 .45 r
.38494 .85126 m .38435 .85332 L .38235 .85361 L F
.275 .032 .352 r
.38642 .8507 m .38435 .85332 L .38494 .85126 L F
.542 .343 .561 r
.62647 .7729 m .62435 .77525 L .62433 .77317 L F
.949 .616 .359 r
.53972 .81914 m .53939 .8203 L .53747 .81929 L F
.54002 .81997 m .54144 .82393 L .53939 .8203 L F
.649 .583 .767 r
.53939 .8203 m .54144 .82393 L .54272 .82229 L F
.53939 .8203 m .54272 .82229 L .54105 .81958 L F
.656 .165 .072 r
.53747 .81929 m .53939 .8203 L .53718 .82142 L F
.895 .903 .824 r
.53718 .82142 m .53976 .8195 L .53845 .8191 L F
.379 0 0 r
.53845 .8191 m .53976 .8195 L .54057 .81987 L F
.116 .333 .801 r
.54105 .81958 m .54272 .82229 L .54303 .82136 L F
.379 0 0 r
.54051 .81993 m .54057 .81987 L .54218 .82061 L F
.949 .616 .359 r
.53972 .81914 m .54002 .81997 L .53939 .8203 L F
0 0 0 r
.53799 .82103 m .53939 .8203 L .54068 .81974 L F
.53799 .82103 m .54068 .81974 L .54065 .81976 L F
.53718 .82142 m .53939 .8203 L .53799 .82103 L F
.53718 .82142 m .54065 .81976 L .53976 .8195 L F
.54065 .81976 m .54068 .81974 L .54105 .81958 L F
.54065 .81976 m .54105 .81958 L .53976 .8195 L F
.379 0 0 r
.53854 .81913 m .54057 .81987 L .54051 .81993 L F
.53845 .8191 m .53859 .81915 L .53854 .81913 L F
.53859 .81915 m .54057 .81987 L .53854 .81913 L F
.83 .356 .018 r
.55372 .80215 m .55384 .80343 L .55266 .80151 L F
.55372 .80215 m .55504 .80399 L .55384 .80343 L F
.037 0 0 r
.46848 .87052 m .46978 .86927 L .46734 .87068 L F
0 .087 .645 r
.47146 .87147 m .46978 .86927 L .47179 .86899 L F
.29 0 0 r
.47179 .86899 m .46978 .86927 L .46848 .87052 L F
0 0 0 r
.5083 .87465 m .50596 .87504 L .5045 .87535 L F
.346 .626 .957 r
.49962 .86321 m .50036 .86439 L .50252 .86463 L F
.49962 .86321 m .50161 .86419 L .50082 .86438 L F
.50161 .86419 m .50252 .86463 L .50082 .86438 L F
0 .048 .601 r
.49993 .86312 m .49962 .86321 L .50082 .86438 L F
0 0 0 r
.49962 .86321 m .501 .86188 L .49933 .86329 L F
.502 .86061 m .501 .86188 L .50175 .86114 L F
.501 .823 .516 r
.50175 .86114 m .501 .86188 L .49962 .86321 L F
.731 .844 .934 r
.49561 .8606 m .49415 .86318 L .49275 .86176 L F
0 0 .349 r
.49434 .86397 m .49415 .86318 L .49561 .8606 L F
.854 .928 .876 r
.49878 .86221 m .50175 .86114 L .49962 .86321 L F
.747 .429 .445 r
.49897 .86208 m .49881 .86219 L .49484 .86281 L F
.854 .928 .876 r
.49875 .86217 m .49894 .8621 L .49878 .86221 L F
.277 0 0 r
.49484 .86281 m .49877 .8622 L .49735 .86273 L F
.49877 .8622 m .4991 .86215 L .49887 .86222 L F
.49877 .8622 m .49887 .86222 L .49735 .86273 L F
.854 .928 .876 r
.49934 .86235 m .49878 .86221 L .49944 .8624 L F
.49894 .8621 m .50175 .86114 L .49878 .86221 L F
.747 .429 .445 r
.49897 .86208 m .4991 .86215 L .49881 .86219 L F
.49489 .86012 m .49905 .86205 L .49897 .86208 L F
.49483 .8601 m .4949 .86013 L .49489 .86012 L F
.4949 .86013 m .49905 .86205 L .49489 .86012 L F
.854 .928 .876 r
.49898 .86181 m .49978 .86176 L .49875 .86217 L F
.747 .429 .445 r
.49483 .8601 m .49812 .86032 L .49905 .86205 L F
.872 .441 .17 r
.49908 .86181 m .49854 .86192 L .49897 .85956 L F
.49905 .86205 m .49812 .86032 L .49854 .86192 L F
.854 .928 .876 r
.49854 .86192 m .49897 .86183 L .49886 .862 L F
.747 .429 .445 r
.49711 .86119 m .49897 .86208 L .49867 .86214 L F
.854 .928 .876 r
.49854 .86192 m .49886 .862 L .49875 .86217 L F
.747 .429 .445 r
.49897 .86208 m .49905 .86205 L .4991 .86215 L F
.872 .441 .17 r
.4991 .86215 m .49905 .86205 L .49854 .86192 L F
.4991 .86215 m .49854 .86192 L .49908 .86181 L F
.854 .928 .876 r
.49854 .86192 m .49898 .86181 L .49897 .86183 L F
.872 .441 .17 r
.4991 .86215 m .49908 .86181 L .49898 .86181 L F
.49873 .86189 m .49898 .86181 L .49865 .86183 L F
.4991 .86215 m .49898 .86181 L .49873 .86189 L F
.854 .928 .876 r
.50076 .86138 m .50175 .86114 L .49875 .86217 L F
.707 .286 .244 r
.50191 .86262 m .5018 .86161 L .49867 .86191 L F
.4986 .86193 m .49867 .86191 L .49854 .86192 L F
.872 .441 .17 r
.4991 .86215 m .49803 .8614 L .49887 .86222 L F
.707 .286 .244 r
.50191 .86262 m .49867 .86191 L .4986 .86193 L F
.5018 .86161 m .50175 .86114 L .50076 .86138 L F
.854 .928 .876 r
.49898 .86181 m .50076 .86138 L .49978 .86176 L F
.707 .286 .244 r
.5018 .86161 m .50076 .86138 L .49854 .86192 L F
.627 .823 .976 r
.4971 .8594 m .49812 .86032 L .49483 .8601 L F
.887 .471 .06 r
.49854 .86192 m .49812 .86032 L .4971 .8594 L F
.49854 .86192 m .4971 .8594 L .49897 .85956 L F
.872 .441 .17 r
.49865 .86183 m .49897 .85956 L .49803 .8614 L F
.49908 .86181 m .49897 .85956 L .49865 .86183 L F
.854 .928 .876 r
.49854 .86192 m .49878 .8622 L .49887 .86222 L F
.49854 .86192 m .49887 .86222 L .49857 .86194 L F
.747 .429 .445 r
.49711 .86119 m .49867 .86214 L .49484 .86281 L F
.872 .441 .17 r
.49887 .86222 m .49803 .8614 L .49735 .86273 L F
.854 .928 .876 r
.49857 .86194 m .49887 .86222 L .49934 .86235 L F
.49878 .8622 m .49878 .86221 L .49934 .86235 L F
.49878 .86221 m .49962 .86321 L .49949 .86264 L F
.49878 .86221 m .49949 .86264 L .49944 .8624 L F
.752 .849 .923 r
.49275 .86176 m .49415 .86318 L .49205 .86412 L F
.486 .158 .335 r
.49205 .86412 m .49415 .86318 L .49434 .86397 L F
.841 .839 .843 r
.49272 .86307 m .49434 .86397 L .49535 .8613 L F
.49508 .86106 m .49535 .8613 L .49561 .8606 L F
.49272 .86307 m .49535 .8613 L .49508 .86106 L F
.49272 .86307 m .49561 .8606 L .49484 .86281 L F
.592 .353 .523 r
.49484 .86281 m .49561 .8606 L .49275 .86176 L F
.49484 .86281 m .49275 .86176 L .49272 .86307 L F
.582 .4 .601 r
.49272 .86307 m .49484 .86281 L .49483 .8601 L F
.592 .353 .523 r
.49484 .86281 m .49272 .86307 L .49483 .8601 L F
.321 0 .105 r
.49431 .86093 m .49454 .86056 L .49484 .86281 L F
.49454 .86056 m .49483 .8601 L .49483 .86084 L F
.49454 .86056 m .49483 .86084 L .49484 .86281 L F
.747 .429 .445 r
.49483 .8601 m .49711 .86119 L .49484 .86281 L F
.895 .926 .833 r
.502 .86369 m .50252 .86463 L .50397 .86253 L F
.50082 .86438 m .50187 .86454 L .502 .86369 L F
.50187 .86454 m .50252 .86463 L .502 .86369 L F
.707 .286 .244 r
.50266 .86199 m .50175 .86114 L .50191 .86262 L F
.5022 .86225 m .49854 .86192 L .50208 .86219 L F
.895 .926 .833 r
.50082 .86438 m .50397 .86253 L .50375 .863 L F
.707 .286 .244 r
.50375 .863 m .50266 .86199 L .50191 .86262 L F
.50375 .863 m .50214 .86267 L .5022 .86225 L F
.50214 .86267 m .49854 .86192 L .5022 .86225 L F
0 .048 .601 r
.49944 .8624 m .49962 .86321 L .49993 .86312 L F
.399 .661 .965 r
.49962 .86321 m .50036 .86439 L .49836 .86411 L F
0 .048 .601 r
.49944 .8624 m .50082 .86438 L .5001 .86492 L F
.757 .691 .788 r
.50082 .86438 m .50176 .86274 L .50041 .86449 L F
.50176 .86274 m .50208 .86219 L .50155 .86292 L F
.50176 .86274 m .50155 .86292 L .50041 .86449 L F
.50082 .86438 m .50041 .86449 L .5001 .86492 L F
0 0 0 r
.49962 .86321 m .49933 .86329 L .49836 .86411 L F
.476 .16 .351 r
.37262 .76969 m .37137 .77243 L .36937 .77274 L F
.536 .337 .558 r
.37468 .76832 m .37426 .7693 L .37262 .76969 L F
.456 .14 .341 r
.37334 .77206 m .37262 .76969 L .37426 .7693 L F
.37334 .77206 m .37137 .77243 L .37262 .76969 L F
.708 .631 .769 r
.59143 .77288 m .58848 .77069 L .59046 .76992 L F
.694 .628 .778 r
.59382 .77062 m .59143 .77288 L .59046 .76992 L F
0 0 .15 r
.61182 .7783 m .6131 .77752 L .61372 .77562 L F
0 0 0 r
.61182 .7783 m .61114 .78021 L .6131 .77752 L F
.308 .798 .776 r
.49941 .88629 m .5031 .88528 L .50145 .88578 L F
.379 .837 .766 r
.50145 .88578 m .5031 .88528 L .50493 .88448 L F
.56 .355 .56 r
.37896 .7629 m .37885 .76506 L .37684 .7654 L F
.556 .424 .656 r
.38109 .76062 m .38095 .76257 L .37896 .7629 L F
.546 .344 .557 r
.38084 .76466 m .37896 .7629 L .38095 .76257 L F
.38084 .76466 m .37885 .76506 L .37896 .7629 L F
.735 .307 .234 r
.39537 .85167 m .39171 .85073 L .39355 .85014 L F
.615 .534 .739 r
.50219 .82385 m .50312 .82535 L .50204 .82169 L F
.671 .412 .521 r
.50027 .82792 m .50312 .82535 L .50219 .82385 L F
.403 0 .021 r
.41744 .84114 m .41609 .8426 L .41392 .84272 L F
.219 0 0 r
.41796 .84213 m .41744 .84114 L .4191 .8415 L F
.41796 .84213 m .41609 .8426 L .41744 .84114 L F
.658 .501 .659 r
.58895 .79657 m .58896 .7989 L .58672 .79925 L F
.421 .191 .457 r
.58895 .79657 m .59127 .79402 L .59118 .79593 L F
.231 .158 .564 r
.59061 .798 m .58895 .79657 L .59118 .79593 L F
.59061 .798 m .58896 .7989 L .58895 .79657 L F
.745 .695 .804 r
.59606 .76839 m .59696 .77093 L .59382 .77062 L F
.673 .625 .792 r
.59789 .76738 m .59696 .77093 L .59606 .76839 L F
.59789 .76738 m .59914 .77039 L .59696 .77093 L F
.162 0 0 r
.51834 .80918 m .52003 .80903 L .52121 .80743 L F
.047 0 0 r
.52121 .80743 m .52171 .80821 L .523 .80662 L F
.52121 .80743 m .52003 .80903 L .52171 .80821 L F
.152 .213 .673 r
.49063 .82986 m .49237 .83242 L .49093 .83292 L F
.385 .468 .822 r
.49237 .83242 m .49184 .83454 L .49093 .83292 L F
.344 0 0 r
.47277 .83242 m .47145 .83333 L .4688 .83387 L F
.566 .164 .24 r
.47446 .83256 m .47145 .83333 L .47277 .83242 L F
.894 .759 .705 r
.56743 .80948 m .56956 .80921 L .56802 .8123 L F
.599 .367 .536 r
.43533 .83559 m .43506 .83775 L .43295 .83795 L F
.503 .283 .513 r
.43693 .8373 m .43506 .83775 L .43533 .83559 L F
.579 .284 .432 r
.43758 .83562 m .43693 .8373 L .43533 .83559 L F
.574 .291 .448 r
.61311 .78372 m .615 .78536 L .61304 .78587 L F
.61311 .78372 m .61551 .78366 L .615 .78536 L F
.503 .184 .359 r
.52667 .8712 m .5296 .86965 L .52887 .8709 L F
0 0 0 r
.52887 .8709 m .5296 .86965 L .53097 .86861 L F
.503 .299 .537 r
.56576 .82808 m .56736 .82512 L .56753 .82772 L F
.609 .323 .458 r
.63409 .76803 m .63639 .76974 L .63445 .7695 L F
.63409 .76803 m .63625 .76813 L .63639 .76974 L F
0 .24 .749 r
.54105 .8085 m .53958 .80786 L .53866 .80688 L F
.54105 .8085 m .54182 .80967 L .53958 .80786 L F
.615 .603 .815 r
.58481 .81481 m .58595 .81151 L .58694 .81219 L F
.628 .465 .642 r
.58694 .81219 m .58717 .81487 L .58481 .81481 L F
.568 .731 .951 r
.58781 .8099 m .58694 .81219 L .58595 .81151 L F
.58781 .8099 m .58911 .81187 L .58694 .81219 L F
.551 .407 .639 r
.5893 .81425 m .58694 .81219 L .58911 .81187 L F
.5893 .81425 m .58717 .81487 L .58694 .81219 L F
.332 .783 .954 r
.58165 .81467 m .58481 .81481 L .58384 .81444 L F
.58165 .81467 m .58481 .81481 L .58384 .81444 L F
.615 .603 .815 r
.58481 .81481 m .58717 .81487 L .58595 .81151 L F
.615 .363 .512 r
.58481 .81481 m .58717 .81487 L .58695 .81678 L F
.491 .255 .484 r
.58695 .81678 m .58717 .81487 L .5893 .81425 L F
.58695 .81678 m .5893 .81425 L .58916 .81668 L F
.988 .779 .386 r
.58764 .81463 m .58695 .81678 L .58916 .81668 L F
.58661 .81324 m .58674 .81461 L .58764 .81463 L F
.224 .715 .922 r
.58481 .81481 m .58717 .81487 L .58483 .81457 L F
.615 .363 .512 r
.58481 .81481 m .58717 .81487 L .58695 .81678 L F
.988 .779 .386 r
.58661 .81324 m .58717 .81487 L .58695 .81678 L F
.58674 .81461 m .58695 .81678 L .58764 .81463 L F
.224 .715 .922 r
.58414 .81455 m .58483 .81457 L .58384 .81444 L F
.58481 .81481 m .58483 .81457 L .58414 .81455 L F
.912 .599 .116 r
.56465 .83785 m .56571 .84077 L .56489 .84012 L F
.785 .31 .104 r
.56571 .84077 m .56517 .84203 L .56489 .84012 L F
.56571 .84077 m .56904 .84396 L .56517 .84203 L F
.526 0 0 r
.49184 .83454 m .49484 .83574 L .4938 .83561 L F
.49184 .83454 m .49484 .83574 L .4938 .83561 L F
.56 .415 .641 r
.49566 .83467 m .49484 .83574 L .49686 .83491 L F
.56 .924 .941 r
.4938 .83561 m .49484 .83574 L .49686 .83491 L F
.56 .415 .641 r
.49566 .83467 m .4938 .83561 L .49484 .83574 L F
.273 .777 .788 r
.41472 .89555 m .416 .89536 L .41786 .89485 L F
.335 .043 .313 r
.36477 .75612 m .36564 .75685 L .36467 .75406 L F
.36477 .75612 m .36371 .75765 L .36564 .75685 L F
.672 .588 .753 r
.36309 .73927 m .36002 .7366 L .36075 .73572 L F
.425 .724 .988 r
.36347 .73805 m .36309 .73927 L .36075 .73572 L F
.36347 .73805 m .36473 .73905 L .36309 .73927 L F
.602 .367 .533 r
.6386 .76534 m .64176 .76509 L .64081 .76578 L F
.133 .655 .883 r
.48617 .81737 m .48702 .8173 L .48821 .81767 L F
.534 .083 .127 r
.48569 .81799 m .4879 .81723 L .48702 .8173 L F
.479 .857 .983 r
.48821 .81767 m .48902 .81684 L .48954 .8147 L F
.48821 .81767 m .48702 .8173 L .48902 .81684 L F
.534 .083 .127 r
.4879 .81723 m .48902 .81684 L .48702 .8173 L F
.133 .655 .883 r
.48491 .81719 m .48702 .8173 L .48617 .81737 L F
.646 .513 .687 r
.58956 .80137 m .58672 .79925 L .58896 .7989 L F
.58956 .80137 m .58662 .8022 L .58672 .79925 L F
.256 .764 .755 r
.59341 .82968 m .59448 .82928 L .59465 .82934 L F
0 0 0 r
.59341 .82968 m .59166 .83184 L .59448 .82928 L F
.705 .973 .752 r
.59448 .82928 m .59166 .83184 L .5916 .83152 L F
.59448 .82928 m .5916 .83152 L .59288 .83085 L F
.661 .904 .575 r
.59448 .82928 m .59288 .83085 L .59427 .82921 L F
.59448 .82928 m .59427 .82921 L .59553 .82772 L F
.256 .764 .755 r
.59465 .82934 m .59448 .82928 L .59564 .82907 L F
.215 .729 .695 r
.4101 .89676 m .41101 .89646 L .40916 .89695 L F
.612 .527 .735 r
.59605 .78278 m .59482 .78634 L .59395 .78347 L F
.59605 .78278 m .59684 .78598 L .59482 .78634 L F
.517 .372 .623 r
.59692 .78803 m .59482 .78634 L .59684 .78598 L F
.59692 .78803 m .59492 .78858 L .59482 .78634 L F
0 .377 .805 r
.5452 .81172 m .54329 .81081 L .54182 .80967 L F
.671 .412 .521 r
.50027 .82792 m .50359 .82765 L .50312 .82535 L F
.927 .947 .786 r
.50359 .82765 m .5054 .82503 L .50312 .82535 L F
.526 .88 .983 r
.3905 .90256 m .39111 .90166 L .38919 .90223 L F
.3905 .90256 m .39239 .90198 L .39111 .90166 L F
.376 .073 .318 r
.5928 .83833 m .59218 .83989 L .59016 .84047 L F
.117 0 .202 r
.5942 .83748 m .5928 .83833 L .59486 .83572 L F
.483 .281 .529 r
.5942 .83748 m .59218 .83989 L .5928 .83833 L F
.582 .602 .838 r
.39433 .74328 m .39589 .74486 L .39384 .74501 L F
.3949 .74329 m .39589 .74486 L .39433 .74328 L F
.383 0 0 r
.39589 .74486 m .3926 .74567 L .39384 .74501 L F
.39589 .74486 m .39378 .74605 L .3926 .74567 L F
.719 .488 .575 r
.3945 .74267 m .39707 .74245 L .39589 .74486 L F
.3945 .74267 m .3962 .74348 L .39707 .74245 L F
.573 .267 .411 r
.39707 .74245 m .39427 .74577 L .39589 .74486 L F
.719 .488 .575 r
.3962 .74348 m .39837 .74452 L .39707 .74245 L F
.573 .267 .411 r
.39723 .74337 m .39735 .74406 L .39626 .74334 L F
.39735 .74406 m .39771 .74619 L .39638 .74358 L F
.344 0 0 r
.39625 .74351 m .39652 .74364 L .3962 .74348 L F
.39652 .74364 m .39837 .74452 L .39632 .74354 L F
.39652 .74364 m .39632 .74354 L .3962 .74348 L F
.358 .357 .722 r
.39707 .74245 m .39837 .74452 L .40012 .74378 L F
.454 .832 .989 r
.40012 .74378 m .39837 .74452 L .39767 .74422 L F
.499 .218 .418 r
.40012 .74378 m .39838 .74409 L .39707 .74245 L F
.344 0 0 r
.39771 .74424 m .39837 .74452 L .39625 .74351 L F
.499 .218 .418 r
.39901 .74489 m .39735 .74406 L .39707 .74245 L F
.344 0 0 r
.39683 .74385 m .39771 .74424 L .39625 .74351 L F
.807 .618 .646 r
.40012 .74378 m .40204 .74398 L .40131 .74244 L F
.718 .482 .567 r
.40131 .74244 m .40137 .74385 L .40012 .74378 L F
.539 .5 .761 r
.40204 .74398 m .40409 .74349 L .40131 .74244 L F
.225 0 .114 r
.40298 .74307 m .40264 .74328 L .40131 .74244 L F
.536 .772 .985 r
.40214 .74357 m .40204 .74398 L .40167 .74385 L F
.40214 .74357 m .40409 .74349 L .40204 .74398 L F
.225 0 .114 r
.40358 .74387 m .40137 .74385 L .40136 .74361 L F
.40305 .74353 m .40136 .74361 L .40131 .74244 L F
.40358 .74387 m .40136 .74361 L .40305 .74353 L F
.40409 .74349 m .40264 .74328 L .40298 .74307 L F
.536 .772 .985 r
.40245 .74219 m .40409 .74349 L .40214 .74357 L F
.40245 .74219 m .40214 .74357 L .40065 .74351 L F
.40214 .74357 m .40167 .74385 L .40065 .74351 L F
.225 0 .114 r
.40409 .74349 m .40358 .74387 L .40264 .74328 L F
.215 .716 .909 r
.40167 .74385 m .40172 .74387 L .40137 .74385 L F
.225 0 .114 r
.40358 .74387 m .40144 .74548 L .40137 .74385 L F
.215 .716 .909 r
.40172 .74387 m .40204 .74398 L .40012 .74378 L F
.718 .482 .567 r
.40137 .74385 m .4014 .74459 L .40012 .74378 L F
.4014 .74459 m .40143 .74526 L .40095 .74473 L F
.4014 .74459 m .40095 .74473 L .40012 .74378 L F
.215 .716 .909 r
.40021 .74373 m .40167 .74385 L .40012 .74378 L F
.40065 .74351 m .40113 .74367 L .40021 .74373 L F
.40113 .74367 m .40167 .74385 L .40021 .74373 L F
.40167 .74385 m .40137 .74385 L .40012 .74378 L F
.718 .482 .567 r
.40143 .74526 m .40112 .74507 L .40012 .74378 L F
.511 .439 .711 r
.40012 .74378 m .40144 .74548 L .39969 .74585 L F
.59 .46 .671 r
.40012 .74378 m .40144 .74548 L .4007 .74488 L F
.77 .873 .923 r
.40065 .74351 m .40069 .74481 L .40245 .74219 L F
.40069 .74481 m .4007 .74488 L .40076 .74479 L F
.40069 .74481 m .40076 .74479 L .40245 .74219 L F
.718 .482 .567 r
.40143 .74526 m .40144 .74548 L .40112 .74507 L F
.286 .263 .658 r
.40144 .74548 m .40201 .74362 L .4007 .74488 L F
.40201 .74362 m .40245 .74219 L .4015 .74365 L F
.40201 .74362 m .4015 .74365 L .4007 .74488 L F
.359 .538 .895 r
.39997 .74332 m .40065 .74478 L .40065 .74351 L F
.40065 .74478 m .4007 .74488 L .40069 .74481 L F
.40065 .74478 m .40069 .74481 L .40065 .74351 L F
.215 .716 .909 r
.40065 .74351 m .40012 .74378 L .39833 .74286 L F
.359 .538 .895 r
.39833 .74286 m .3993 .74369 L .39997 .74332 L F
.858 .781 .774 r
.39969 .74585 m .39771 .74619 L .39967 .74423 L F
.39993 .7447 m .39967 .74423 L .40012 .74378 L F
.39969 .74585 m .39967 .74423 L .39993 .7447 L F
.454 .832 .989 r
.39911 .7438 m .39767 .74422 L .39683 .74385 L F
.40012 .74378 m .39869 .74404 L .39911 .7438 L F
.39869 .74404 m .39767 .74422 L .39911 .7438 L F
.499 .218 .418 r
.40012 .74378 m .39901 .74489 L .39838 .74409 L F
.39901 .74489 m .39771 .74619 L .39735 .74406 L F
.573 .267 .411 r
.3962 .74348 m .39378 .74605 L .39427 .74577 L F
.39615 .74346 m .39378 .74605 L .3962 .74348 L F
.39615 .74346 m .39771 .74619 L .39378 .74605 L F
.344 0 0 r
.39625 .74351 m .3962 .74348 L .39615 .74346 L F
.573 .267 .411 r
.39626 .74334 m .39638 .74358 L .39615 .74346 L F
.39638 .74358 m .39771 .74619 L .39615 .74346 L F
.344 0 0 r
.39683 .74385 m .39625 .74351 L .39567 .74326 L F
.39625 .74351 m .39615 .74346 L .39567 .74326 L F
.454 .832 .989 r
.40012 .74378 m .39683 .74385 L .39833 .74286 L F
.69 .484 .603 r
.39625 .74549 m .40012 .74378 L .39833 .74286 L F
.39625 .74549 m .39771 .74619 L .39967 .74423 L F
.39943 .74408 m .39967 .74423 L .40012 .74378 L F
.39625 .74549 m .39967 .74423 L .39943 .74408 L F
.59 .46 .671 r
.40012 .74378 m .4007 .74488 L .39833 .74286 L F
.359 .538 .895 r
.39937 .74366 m .40056 .74475 L .39997 .74332 L F
.40056 .74475 m .4007 .74488 L .40067 .74482 L F
.40056 .74475 m .40067 .74482 L .39997 .74332 L F
.3993 .74369 m .39945 .74382 L .39937 .74366 L F
.39945 .74382 m .4007 .74488 L .39937 .74366 L F
.573 .267 .411 r
.39735 .74406 m .39638 .74358 L .39626 .74334 L F
.344 0 0 r
.39567 .74326 m .3962 .74348 L .3945 .74267 L F
.573 .267 .411 r
.39707 .74245 m .39615 .74346 L .3962 .74348 L F
.39707 .74245 m .39723 .74337 L .39626 .74334 L F
.582 .602 .838 r
.3945 .74267 m .3949 .74329 L .39433 .74328 L F
.833 .539 0 r
.5609 .81391 m .56127 .8143 L .56175 .81679 L F
.317 0 .003 r
.63198 .7624 m .63413 .76202 L .6351 .76069 L F
.393 .191 .482 r
.58336 .79651 m .58134 .79922 L .58261 .79949 L F
0 .092 .649 r
.58134 .79922 m .58282 .80028 L .58261 .79949 L F
.58134 .79922 m .58349 .80189 L .58282 .80028 L F
0 0 0 r
.51554 .82068 m .51736 .81964 L .51817 .8201 L F
.335 .448 .828 r
.51817 .82275 m .51554 .82068 L .51817 .8201 L F
0 0 0 r
.51554 .82068 m .51449 .82165 L .51736 .81964 L F
.41538 .88154 m .41642 .88135 L .41806 .88062 L F
.41538 .88154 m .41451 .8818 L .41642 .88135 L F
.492 .035 .093 r
.45714 .81912 m .46031 .8185 L .45833 .81808 L F
.497 .273 .504 r
.49809 .8123 m .49761 .81443 L .49953 .81278 L F
.284 0 0 r
.49953 .81278 m .49542 .8125 L .49809 .8123 L F
.406 0 0 r
.46031 .8185 m .46239 .81864 L .46377 .81769 L F
.506 .029 .058 r
.46239 .81864 m .46594 .81768 L .46377 .81769 L F
.069 0 0 r
.45857 .83147 m .45734 .83194 L .45522 .83219 L F
.484 0 0 r
.46224 .83169 m .45734 .83194 L .45857 .83147 L F
.657 .409 .533 r
.64657 .76268 m .64585 .76537 L .64367 .76507 L F
.603 .356 .515 r
.6487 .76454 m .64657 .76268 L .64891 .76285 L F
.6487 .76454 m .64585 .76537 L .64657 .76268 L F
.75 .746 .848 r
.55377 .79641 m .55046 .7965 L .55249 .79449 L F
.907 .829 .757 r
.55377 .79641 m .55113 .79828 L .55046 .7965 L F
.55377 .79641 m .55244 .79907 L .55113 .79828 L F
.51 .626 .901 r
.55521 .79489 m .55377 .79641 L .55249 .79449 L F
.55521 .79489 m .55576 .79645 L .55377 .79641 L F
.948 .684 .502 r
.52454 .82129 m .52371 .82255 L .52351 .81946 L F
.745 .227 0 r
.52454 .82129 m .52537 .82201 L .52499 .82221 L F
.52537 .82201 m .52632 .82282 L .52499 .82221 L F
.632 .458 .63 r
.52779 .82058 m .52632 .82282 L .52454 .82129 L F
.448 .069 .225 r
.52454 .82129 m .52499 .82221 L .52627 .82108 L F
.674 .272 0 r
.52351 .81946 m .52499 .82221 L .52454 .82129 L F
.488 .086 .203 r
.52499 .82221 m .52371 .82255 L .52454 .82129 L F
.368 0 .041 r
.52627 .82108 m .52779 .82058 L .52668 .82083 L F
.52627 .82108 m .52668 .82083 L .52454 .82129 L F
.851 .655 .637 r
.52441 .81943 m .52492 .8219 L .52627 .82108 L F
.52492 .8219 m .52499 .82221 L .52627 .82108 L F
.382 .347 .695 r
.52441 .81943 m .52499 .82221 L .52351 .81946 L F
0 0 .454 r
.52531 .8202 m .52499 .82221 L .52441 .81943 L F
.52536 .82024 m .52535 .82034 L .52531 .8202 L F
.52535 .82034 m .52499 .82221 L .52531 .8202 L F
.382 .342 .689 r
.52461 .81641 m .52351 .81946 L .52266 .81774 L F
.681 .474 .6 r
.52351 .81946 m .52371 .82255 L .5226 .82244 L F
.382 .342 .689 r
.52461 .81641 m .52441 .81943 L .52351 .81946 L F
.295 .266 .655 r
.52644 .81852 m .52441 .81943 L .52461 .81641 L F
.678 .433 .543 r
.52317 .82038 m .52506 .8193 L .52273 .81847 L F
.52506 .8193 m .52644 .81852 L .52484 .8185 L F
.52506 .8193 m .52484 .8185 L .52273 .81847 L F
.853 .957 .613 r
.52536 .82024 m .52403 .8227 L .52499 .82221 L F
.109 0 0 r
.52499 .82221 m .52343 .82381 L .52307 .82339 L F
.853 .957 .613 r
.52403 .8227 m .52343 .82381 L .52499 .82221 L F
.226 0 .314 r
.59629 .83477 m .59486 .83572 L .59687 .83302 L F
.45 .218 .47 r
.59629 .83477 m .5942 .83748 L .59486 .83572 L F
.562 .814 .993 r
.58307 .83795 m .58133 .83938 L .58062 .83934 L F
.58307 .83795 m .58436 .83888 L .58133 .83938 L F
.907 .867 .428 r
.56175 .81679 m .5613 .8198 L .56206 .81983 L F
0 .021 .574 r
.5613 .8198 m .56308 .82162 L .56206 .81983 L F
.536 .462 .719 r
.53185 .81174 m .52999 .81231 L .5295 .80951 L F
.538 .364 .593 r
.53188 .81377 m .52999 .81231 L .53185 .81174 L F
.53188 .81377 m .53016 .81429 L .52999 .81231 L F
.221 0 0 r
.47199 .88188 m .47522 .88234 L .47395 .88225 L F
0 .293 .661 r
.47522 .88234 m .4757 .88253 L .47395 .88225 L F
.47522 .88234 m .47766 .88347 L .4757 .88253 L F
.362 0 0 r
.47522 .88234 m .47856 .88402 L .47766 .88347 L F
.725 .508 .596 r
.40453 .84341 m .40543 .84797 L .4013 .8454 L F
.397 .291 .616 r
.40639 .84541 m .40453 .84341 L .40648 .84342 L F
.40639 .84541 m .40543 .84797 L .40453 .84341 L F
.244 .321 .744 r
.50215 .8352 m .50316 .83914 L .50419 .8372 L F
.472 .608 .905 r
.50419 .8372 m .50316 .83914 L .50526 .83885 L F
.45 0 0 r
.4923 .81449 m .49466 .81526 L .49556 .81499 L F
.762 .304 .161 r
.49466 .81634 m .49556 .81499 L .49466 .81526 L F
.49466 .81634 m .49772 .81715 L .49556 .81499 L F
.537 .378 .613 r
.49556 .81499 m .49772 .81715 L .49761 .81443 L F
.456 .802 .998 r
.48017 .87159 m .47838 .87194 L .47911 .87098 L F
.583 .373 .562 r
.59788 .7758 m .59805 .77841 L .59561 .77852 L F
.581 .443 .658 r
.59999 .77334 m .6001 .7756 L .59788 .7758 L F
.642 .418 .563 r
.60025 .77794 m .59788 .7758 L .6001 .7756 L F
.60025 .77794 m .59805 .77841 L .59788 .7758 L F
.336 .198 .541 r
.59833 .83202 m .59687 .83302 L .59792 .83 L F
.335 .12 .432 r
.59833 .83202 m .59629 .83477 L .59687 .83302 L F
.277 .032 .352 r
.39051 .74326 m .38841 .74518 L .39005 .74436 L F
.372 .206 .523 r
.38841 .74518 m .39009 .74511 L .39005 .74436 L F
.492 .285 .526 r
.59218 .83989 m .59 .84258 L .59016 .84047 L F
.546 .296 .488 r
.63116 .77068 m .6289 .77289 L .62897 .77082 L F
.536 .462 .719 r
.53185 .81174 m .5295 .80951 L .53184 .80945 L F
0 .064 .621 r
.57253 .81572 m .57039 .81313 L .57166 .81309 L F
0 .098 .644 r
.57259 .81647 m .57039 .81313 L .57253 .81572 L F
.57259 .81647 m .57105 .81451 L .57039 .81313 L F
.347 .005 .236 r
.35899 .74992 m .35634 .75186 L .35712 .74993 L F
.585 .467 .685 r
.3599 .76268 m .36199 .76256 L .36163 .76029 L F
.58 .429 .641 r
.35991 .76288 m .36199 .76256 L .3599 .76268 L F
.487 .838 .996 r
.3999 .88344 m .39581 .88313 L .39853 .88277 L F
.322 .699 .981 r
.40038 .88262 m .3999 .88344 L .39853 .88277 L F
.40038 .88262 m .40198 .88368 L .3999 .88344 L F
.808 .801 .845 r
.58154 .79121 m .58264 .79359 L .58457 .79103 L F
.601 .5 .711 r
.58304 .7944 m .58457 .79103 L .58264 .79359 L F
.639 .632 .827 r
.36002 .7366 m .35623 .73455 L .35814 .73431 L F
.402 .372 .711 r
.36075 .73572 m .36002 .7366 L .36005 .73484 L F
.706 .436 .513 r
.36214 .73467 m .36075 .73572 L .36005 .73484 L F
.291 .335 .735 r
.36005 .73484 m .36075 .73572 L .36085 .7346 L F
.965 .926 .704 r
.36085 .7346 m .36075 .73572 L .36106 .73464 L F
.36085 .7346 m .36106 .73464 L .36209 .73098 L F
.892 .83 .779 r
.36209 .73098 m .36106 .73464 L .36214 .73467 L F
.297 .786 .897 r
.36148 .73472 m .36106 .73464 L .36214 .73467 L F
.892 .83 .779 r
.36106 .73464 m .36075 .73572 L .36214 .73467 L F
.297 .786 .897 r
.36106 .73464 m .36085 .7346 L .36214 .73467 L F
.36005 .73484 m .36085 .7346 L .36148 .73472 L F
0 0 .129 r
.36086 .73511 m .36075 .73572 L .36085 .7346 L F
.518 .623 .895 r
.36086 .73511 m .36002 .7366 L .35814 .73431 L F
.751 .925 .947 r
.36075 .73572 m .36002 .7366 L .36086 .73511 L F
.786 .804 .867 r
.57684 .77025 m .57581 .77332 L .5742 .77325 L F
.585 .836 .992 r
.5742 .77325 m .57581 .77332 L .57271 .77307 L F
.782 .678 .749 r
.57581 .77332 m .57377 .77588 L .57271 .77307 L F
.786 .804 .867 r
.57684 .77025 m .57813 .77131 L .57581 .77332 L F
.219 0 0 r
.398 .82803 m .40006 .82782 L .40102 .82723 L F
.105 0 0 r
.40102 .82723 m .40201 .82741 L .40304 .82695 L F
.40102 .82723 m .40006 .82782 L .40201 .82741 L F
0 0 .151 r
.59118 .79593 m .59127 .79402 L .5919 .79305 L F
.503 .638 .915 r
.52634 .8322 m .52664 .83324 L .52773 .83161 L F
.591 .759 .959 r
.52664 .83324 m .52874 .8328 L .52773 .83161 L F
.601 .5 .711 r
.58304 .7944 m .58515 .79405 L .58457 .79103 L F
.58 .455 .675 r
.58336 .79651 m .58515 .79405 L .58304 .7944 L F
.503 .184 .359 r
.52667 .8712 m .52887 .8709 L .52631 .87202 L F
.76 .657 .748 r
.66152 .74711 m .66433 .7473 L .66232 .74944 L F
.617 .6 .811 r
.66574 .74413 m .66433 .7473 L .66461 .74474 L F
.66574 .74413 m .6668 .74701 L .66433 .7473 L F
.508 .288 .515 r
.37885 .76506 m .37655 .76768 L .37684 .7654 L F
.28 0 0 r
.44657 .88703 m .44778 .8875 L .44555 .88773 L F
.44657 .88703 m .44855 .88691 L .44778 .8875 L F
.429 0 0 r
.44801 .83349 m .44666 .83459 L .44469 .83447 L F
.44963 .83407 m .44666 .83459 L .44801 .83349 L F
.726 .84 .935 r
.49373 .80959 m .49145 .80964 L .49205 .80932 L F
.795 .62 .665 r
.49431 .81245 m .49145 .80964 L .49442 .80957 L F
.49431 .81245 m .49124 .81232 L .49145 .80964 L F
.591 .037 0 r
.49093 .81039 m .49253 .8109 L .49183 .80929 L F
.267 0 .031 r
.49179 .8092 m .49324 .80868 L .49145 .80964 L F
.591 .037 0 r
.49174 .80927 m .49183 .80929 L .49179 .8092 L F
.49093 .81039 m .49183 .80929 L .49174 .80927 L F
.726 .84 .935 r
.49442 .80957 m .49373 .80959 L .49324 .80868 L F
.49373 .80959 m .49205 .80932 L .49324 .80868 L F
.51 .798 .998 r
.49648 .80859 m .49442 .80957 L .49324 .80868 L F
.49648 .80859 m .49648 .80924 L .49442 .80957 L F
.86 .852 .833 r
.57271 .77307 m .57087 .77647 L .56857 .77607 L F
.707 .641 .78 r
.57377 .77588 m .57087 .77647 L .57271 .77307 L F
.776 .586 .642 r
.57377 .77588 m .57052 .77764 L .57087 .77647 L F
.719 .902 .961 r
.53121 .83067 m .52848 .83234 L .52754 .83123 L F
.44 .128 .339 r
.58754 .84355 m .58524 .84547 L .58563 .8438 L F
.938 .573 .274 r
.58662 .8022 m .58785 .80438 L .58679 .80398 L F
.19 .33 .776 r
.58889 .80344 m .58785 .80438 L .58662 .8022 L F
.502 .866 .986 r
.58679 .80398 m .58785 .80438 L .58889 .80344 L F
.473 .298 .562 r
.36009 .76528 m .36199 .76256 L .35991 .76288 L F
.274 0 0 r
.40509 .82653 m .40711 .82655 L .40854 .8259 L F
0 0 0 r
.40711 .82655 m .41014 .82611 L .40854 .8259 L F
.404 0 0 r
.6595 .74911 m .65617 .74982 L .65751 .75049 L F
.607 .949 .92 r
.48178 .87368 m .47894 .8746 L .48017 .87159 L F
.648 .896 .565 r
.56852 .83727 m .56777 .83849 L .57024 .83554 L F
0 .073 .623 r
.56919 .83954 m .56777 .83849 L .56852 .83727 L F
.56919 .83954 m .56889 .83975 L .56777 .83849 L F
.954 .826 .39 r
.56318 .83003 m .56242 .8321 L .56288 .82984 L F
.56318 .83003 m .56282 .8325 L .56242 .8321 L F
.804 .869 .896 r
.56484 .82715 m .56318 .83003 L .56288 .82984 L F
.56484 .82715 m .56576 .82808 L .56318 .83003 L F
.393 .254 .571 r
.57223 .7809 m .57372 .78052 L .57367 .77821 L F
.013 .031 .531 r
.57223 .7809 m .57314 .78193 L .57372 .78052 L F
.57223 .7809 m .57242 .78433 L .57314 .78193 L F
.963 .658 .247 r
.66232 .74944 m .66173 .74922 L .66152 .74711 L F
.498 .267 .493 r
.67478 .74455 m .67457 .74717 L .67249 .74736 L F
.498 .379 .649 r
.67652 .74168 m .67721 .74413 L .67478 .74455 L F
.558 .367 .578 r
.67721 .74413 m .67457 .74717 L .67478 .74455 L F
.833 .783 .804 r
.65532 .74409 m .65778 .74406 L .65727 .74162 L F
.822 .442 .334 r
.65541 .74554 m .65778 .74406 L .65532 .74409 L F
.65541 .74554 m .65747 .7464 L .65778 .74406 L F
.137 0 .129 r
.65778 .74406 m .65974 .74366 L .66035 .74187 L F
.521 .31 .534 r
.65747 .7464 m .65974 .74366 L .65778 .74406 L F
.19 .33 .776 r
.58889 .80344 m .58662 .8022 L .58956 .80137 L F
.253 .286 .702 r
.49368 .82419 m .49204 .82295 L .49439 .82208 L F
.418 .683 .972 r
.37306 .74427 m .37214 .74522 L .37128 .74397 L F
.37306 .74427 m .37414 .74534 L .37214 .74522 L F
.632 .442 .608 r
.41189 .84105 m .41211 .84329 L .40999 .84292 L F
.504 .349 .604 r
.41392 .84272 m .41211 .84329 L .41189 .84105 L F
.737 .68 .795 r
.50469 .80922 m .50292 .81233 L .50186 .80932 L F
.523 .119 .216 r
.50204 .82169 m .501 .82397 L .49869 .82411 L F
0 0 0 r
.50403 .81943 m .50204 .82169 L .50237 .82051 L F
.50403 .81943 m .50314 .82157 L .50204 .82169 L F
.50314 .82157 m .501 .82397 L .50204 .82169 L F
.752 .569 .648 r
.50204 .82169 m .50403 .81943 L .50237 .82051 L F
0 0 0 r
.51235 .87955 m .51348 .87925 L .51092 .88054 L F
.51235 .87955 m .51433 .87886 L .51348 .87925 L F
.517 .198 .366 r
.53519 .80933 m .53185 .81174 L .53184 .80945 L F
.53519 .80933 m .5342 .81151 L .53185 .81174 L F
.555 .238 .386 r
.535 .81126 m .5342 .81151 L .53519 .80933 L F
.427 .419 .748 r
.37531 .7521 m .37295 .75059 L .37483 .74925 L F
.37531 .7521 m .37377 .75231 L .37295 .75059 L F
.811 .47 .411 r
.56562 .80853 m .56699 .80751 L .56743 .80948 L F
.962 .811 .647 r
.56574 .80638 m .56699 .80751 L .56562 .80853 L F
.894 .761 .707 r
.56941 .80623 m .56743 .80948 L .56699 .80751 L F
.32 0 .159 r
.60574 .79089 m .60857 .78846 L .60794 .7907 L F
.46 .176 .395 r
.60794 .7907 m .60857 .78846 L .61071 .7884 L F
.553 .704 .94 r
.59792 .83 m .59564 .82907 L .59773 .82738 L F
.231 .279 .707 r
.59773 .82738 m .59978 .82965 L .59792 .83 L F
.568 .574 .819 r
.59978 .82965 m .59833 .83202 L .59792 .83 L F
0 0 0 r
.41806 .88062 m .41824 .88055 L .42012 .88024 L F
.41806 .88062 m .41642 .88135 L .41824 .88055 L F
.218 0 0 r
.49098 .88888 m .49253 .88781 L .49458 .88755 L F
.542 .319 .526 r
.62435 .77525 m .6217 .77703 L .6223 .77574 L F
.463 .888 .818 r
.38572 .8885 m .38911 .8872 L .38708 .88752 L F
.917 .848 .76 r
.36214 .73467 m .36085 .7346 L .36209 .73098 L F
.646 .334 .43 r
.51566 .80985 m .51756 .80975 L .51834 .80918 L F
.151 0 0 r
.51834 .80918 m .51756 .80975 L .52003 .80903 L F
.404 0 0 r
.6595 .74911 m .65867 .7499 L .65617 .74982 L F
.453 .251 .515 r
.66152 .74711 m .66173 .74922 L .6595 .74911 L F
.852 .654 .633 r
.66173 .74922 m .65867 .7499 L .6595 .74911 L F
.582 .841 .485 r
.49254 .82753 m .49093 .82945 L .49063 .82986 L F
.643 .505 .68 r
.49339 .82658 m .49494 .83128 L .49093 .82945 L F
.584 .467 .686 r
.4945 .83174 m .49093 .82945 L .49494 .83128 L F
.617 .491 .686 r
.49658 .82916 m .49494 .83128 L .49339 .82658 L F
.71 .929 .602 r
.49658 .82916 m .4945 .83174 L .49494 .83128 L F
.33 .758 .972 r
.49629 .83273 m .4945 .83174 L .49658 .82916 L F
.49629 .83273 m .49786 .83216 L .4945 .83174 L F
.857 .416 .159 r
.57242 .78433 m .57354 .78613 L .57251 .7859 L F
.57242 .78433 m .57251 .7859 L .57314 .78193 L F
.936 .579 .313 r
.55756 .80708 m .55931 .8096 L .55839 .80894 L F
.59 .805 .4 r
.55828 .81111 m .55931 .8096 L .55847 .81084 L F
.993 .775 .505 r
.55839 .80894 m .55931 .8096 L .55828 .81111 L F
.567 .6 .846 r
.45791 .87095 m .46022 .87256 L .45635 .87232 L F
.584 .534 .764 r
.45691 .87413 m .45791 .87095 L .45635 .87232 L F
.75 .565 .646 r
.50925 .85012 m .51049 .85112 L .5108 .84855 L F
.776 .586 .642 r
.57377 .77588 m .57367 .77821 L .57052 .77764 L F
0 0 0 r
.5446 .83011 m .5425 .83301 L .54372 .83196 L F
.747 .425 .438 r
.5425 .83301 m .5456 .83479 L .54268 .8347 L F
.642 .56 .747 r
.54268 .8347 m .54372 .83196 L .5425 .83301 L F
.174 0 0 r
.4215 .89378 m .42334 .89279 L .42538 .89249 L F
.588 .339 .506 r
.38235 .85361 m .38205 .8559 L .37972 .85601 L F
.595 .344 .507 r
.38421 .85562 m .38235 .85361 L .38435 .85332 L F
.38421 .85562 m .38205 .8559 L .38235 .85361 L F
.722 .608 .73 r
.57022 .80864 m .57125 .8074 L .56941 .80623 L F
.495 .898 .929 r
.39661 .89985 m .39769 .89993 L .3998 .89914 L F
.066 0 0 r
.46594 .81768 m .46787 .8173 L .46889 .8168 L F
.353 0 0 r
.46787 .8173 m .47092 .81649 L .46889 .8168 L F
.853 .976 .866 r
.39395 .88416 m .39091 .88612 L .39334 .88434 L F
.473 .881 .739 r
.39395 .88416 m .3953 .88316 L .39581 .88313 L F
.39395 .88416 m .39334 .88434 L .3953 .88316 L F
.869 .492 .009 r
.55266 .80151 m .55113 .79828 L .55244 .79907 L F
.958 .779 .619 r
.44635 .87686 m .4469 .87464 L .44512 .87621 L F
0 0 .026 r
.44756 .87406 m .4469 .87464 L .44837 .87229 L F
0 0 0 r
.44512 .87621 m .4469 .87464 L .44756 .87406 L F
.716 .313 .284 r
.44839 .87665 m .4469 .87464 L .44635 .87686 L F
.822 .859 .874 r
.5309 .86716 m .53004 .86938 L .52723 .86876 L F
.644 .388 .517 r
.65902 .75993 m .65878 .76241 L .6564 .76239 L F
.552 .325 .525 r
.66122 .75952 m .65878 .76241 L .65902 .75993 L F
.155 0 0 r
.45254 .88574 m .45398 .88474 L .45602 .88436 L F
.628 .818 .973 r
.44732 .86893 m .45058 .86917 L .44878 .8693 L F
.696 .482 .595 r
.44878 .8693 m .45058 .86917 L .45058 .87162 L F
.44878 .8693 m .45058 .87162 L .44837 .87229 L F
.769 .543 .591 r
.45058 .87162 m .45058 .86917 L .44732 .86893 L F
.063 .625 .776 r
.37753 .83235 m .37775 .83254 L .37665 .83313 L F
.37753 .83235 m .37981 .83253 L .37775 .83254 L F
.695 .694 .846 r
.48682 .81449 m .48954 .8147 L .49008 .81466 L F
.572 .248 .38 r
.48954 .8147 m .4923 .81449 L .49008 .81466 L F
.48954 .8147 m .49158 .81578 L .4923 .81449 L F
.5 .115 .241 r
.48902 .81684 m .49158 .81578 L .48954 .8147 L F
.557 .253 .408 r
.6487 .76454 m .64891 .76285 L .65105 .76425 L F
.58 .455 .675 r
.58336 .79651 m .58555 .79622 L .58515 .79405 L F
.553 .343 .55 r
.58557 .79846 m .58336 .79651 L .58261 .79949 L F
.58557 .79846 m .58555 .79622 L .58336 .79651 L F
.543 .307 .507 r
.36937 .77274 m .367 .77519 L .36744 .77318 L F
.019 0 0 r
.41014 .82611 m .41254 .82577 L .4139 .82533 L F
.112 0 0 r
.41254 .82577 m .41605 .82537 L .4139 .82533 L F
.648 .567 .749 r
.59604 .78105 m .59395 .78347 L .59307 .78072 L F
.59604 .78105 m .59605 .78278 L .59395 .78347 L F
.29 0 0 r
.43902 .82149 m .44118 .82126 L .44252 .82009 L F
.582 .157 .201 r
.44118 .82126 m .44452 .82007 L .44252 .82009 L F
.05 .507 .89 r
.48338 .88538 m .4871 .88716 L .48596 .88665 L F
.579 .013 0 r
.48596 .88665 m .4871 .88716 L .48908 .88871 L F
.65 .669 .855 r
.36926 .74422 m .36586 .74261 L .36782 .74201 L F
.56 .627 .875 r
.36983 .74164 m .36926 .74422 L .36782 .74201 L F
.36983 .74164 m .37128 .74397 L .36926 .74422 L F
0 0 0 r
.4408 .87418 m .43783 .87671 L .43988 .87655 L F
.699 .22 .11 r
.44189 .87618 m .4408 .87418 L .43988 .87655 L F
.558 .555 .807 r
.59061 .798 m .58956 .80137 L .58896 .7989 L F
0 0 0 r
.51534 .87135 m .51335 .87196 L .51257 .87219 L F
.489 .892 .938 r
.5632 .77694 m .56409 .77616 L .56551 .77634 L F
.5632 .77694 m .56167 .77693 L .56409 .77616 L F
.778 .9 .928 r
.5759 .80057 m .57797 .79915 L .5774 .79817 L F
.709 .916 .965 r
.35298 .73409 m .35325 .73394 L .35352 .73427 L F
.123 .673 .755 r
.42509 .87931 m .42309 .87954 L .42189 .8796 L F
.708 .642 .781 r
.60118 .76795 m .59914 .77039 L .59789 .76738 L F
.638 .537 .723 r
.60133 .76995 m .59914 .77039 L .60118 .76795 L F
.651 .524 .695 r
.60219 .77298 m .59914 .77039 L .60133 .76995 L F
.60219 .77298 m .59999 .77334 L .59914 .77039 L F
.598 .218 .294 r
.40999 .84292 m .40856 .84488 L .40648 .84342 L F
.637 .275 .341 r
.41211 .84329 m .40856 .84488 L .40999 .84292 L F
.52 .25 .446 r
.53817 .82522 m .54038 .82494 L .54144 .82393 L F
0 0 0 r
.54144 .82393 m .54038 .82494 L .53817 .82522 L F
.526 .302 .517 r
.61966 .77854 m .61979 .78068 L .61759 .78098 L F
.479 .267 .513 r
.62168 .78015 m .61966 .77854 L .6217 .77703 L F
.62168 .78015 m .61979 .78068 L .61966 .77854 L F
.356 0 0 r
.53043 .80391 m .53242 .80433 L .53369 .80422 L F
.516 0 0 r
.53242 .80433 m .53615 .80596 L .53369 .80422 L F
.768 .657 .74 r
.35515 .73133 m .35623 .73455 L .35325 .73394 L F
.562 .638 .884 r
.35735 .7325 m .35623 .73455 L .35515 .73133 L F
.35735 .7325 m .35814 .73431 L .35623 .73455 L F
.521 .405 .662 r
.37563 .75393 m .37377 .75231 L .37531 .7521 L F
.37563 .75393 m .37401 .75443 L .37377 .75231 L F
.618 .553 .759 r
.58316 .77294 m .58098 .77337 L .57984 .77021 L F
0 0 .332 r
.52567 .81441 m .52573 .81401 L .52529 .81285 L F
.616 .122 .056 r
.52567 .81441 m .52751 .81491 L .52623 .8159 L F
.71 .496 .596 r
.52623 .8159 m .52573 .81401 L .52567 .81441 L F
.382 .792 .981 r
.47771 .83282 m .47701 .83232 L .47446 .83256 L F
.769 .647 .728 r
.47446 .83256 m .47656 .83447 L .47771 .83282 L F
.362 .164 .471 r
.47989 .83004 m .47957 .83228 L .47771 .83282 L F
.648 .896 .565 r
.56852 .83727 m .57024 .83554 L .56917 .83489 L F
.543 .345 .562 r
.37658 .76839 m .37468 .76832 L .37655 .76768 L F
.37658 .76839 m .37426 .7693 L .37468 .76832 L F
.588 .812 .985 r
.4818 .83443 m .48127 .83602 L .48289 .83541 L F
.48289 .83541 m .48127 .83602 L .4818 .83443 L F
.093 0 0 r
.51934 .87646 m .52219 .87469 L .52083 .87635 L F
0 0 0 r
.52083 .87635 m .52219 .87469 L .52359 .87373 L F
.136 .679 .818 r
.38517 .83023 m .38528 .83052 L .38337 .83094 L F
.38517 .83023 m .38738 .83041 L .38528 .83052 L F
0 .547 .746 r
.50728 .8198 m .50603 .81962 L .50403 .81943 L F
.67 .942 .962 r
.5083 .81838 m .50728 .8198 L .50931 .81911 L F
.5083 .81838 m .50603 .81962 L .50728 .8198 L F
.799 .564 .582 r
.59988 .76255 m .59681 .76009 L .59893 .7597 L F
.59988 .76255 m .59687 .76239 L .59681 .76009 L F
.8 .69 .742 r
.59988 .76255 m .59795 .76527 L .59687 .76239 L F
.691 .532 .667 r
.59992 .76474 m .59795 .76527 L .59988 .76255 L F
.679 .649 .813 r
.60205 .76094 m .59988 .76255 L .59893 .7597 L F
.676 .643 .81 r
.60205 .76094 m .60273 .76274 L .59988 .76255 L F
.678 .505 .645 r
.60273 .76274 m .59992 .76474 L .59988 .76255 L F
.597 .658 .881 r
.49205 .86412 m .49007 .86462 L .48799 .86186 L F
.013 0 0 r
.48827 .86556 m .49007 .86462 L .49205 .86412 L F
.582 .566 .802 r
.37563 .75393 m .37443 .75579 L .37401 .75443 L F
.37563 .75393 m .37649 .75542 L .37443 .75579 L F
.703 .894 .966 r
.50903 .85415 m .51216 .85385 L .51088 .85313 L F
0 .486 .857 r
.47856 .88402 m .4793 .88396 L .47766 .88347 L F
.47856 .88402 m .48046 .88474 L .4793 .88396 L F
.576 .072 .021 r
.51745 .8716 m .52079 .87174 L .51875 .87109 L F
.588 .699 .92 r
.38022 .75721 m .37649 .75542 L .37848 .75486 L F
.432 .614 .927 r
.38118 .75604 m .38022 .75721 L .37848 .75486 L F
.38118 .75604 m .38188 .75715 L .38022 .75721 L F
.636 .515 .699 r
.38295 .75995 m .38022 .75721 L .38188 .75715 L F
.38295 .75995 m .38109 .76062 L .38022 .75721 L F
.453 .166 .387 r
.48789 .87959 m .491 .87807 L .48878 .87871 L F
.435 .777 .997 r
.48878 .87871 m .49015 .87941 L .48789 .87959 L F
.612 .378 .538 r
.61082 .78595 m .61266 .7879 L .61071 .7884 L F
.61082 .78595 m .61304 .78587 L .61266 .7879 L F
.296 0 0 r
.47306 .81609 m .47507 .81604 L .47672 .81516 L F
.332 0 .019 r
.47507 .81604 m .47838 .81422 L .47672 .81516 L F
.401 .007 .172 r
.59403 .79268 m .5928 .79121 L .59453 .79072 L F
.59403 .79268 m .5919 .79305 L .5928 .79121 L F
.686 .705 .862 r
.55983 .77915 m .56369 .77946 L .56167 .77693 L F
.503 .299 .537 r
.56576 .82808 m .56753 .82772 L .56484 .82715 L F
.535 .778 .987 r
.56753 .82772 m .56576 .82808 L .56484 .82715 L F
.655 .48 .636 r
.59561 .77852 m .59604 .78105 L .59307 .78072 L F
.679 .497 .632 r
.59812 .78053 m .59561 .77852 L .59805 .77841 L F
.59812 .78053 m .59604 .78105 L .59561 .77852 L F
.242 0 0 r
.51612 .87812 m .51934 .87646 L .51894 .87712 L F
.078 0 0 r
.51894 .87712 m .51934 .87646 L .52083 .87635 L F
.99 .74 .375 r
.54395 .82739 m .5446 .83011 L .54391 .83015 L F
0 0 0 r
.5446 .83011 m .54372 .83196 L .54391 .83015 L F
.54655 .82861 m .54701 .82806 L .5446 .83011 L F
.54655 .82861 m .5446 .83011 L .54395 .82739 L F
.651 .473 .631 r
.39909 .84799 m .39714 .84613 L .39917 .84569 L F
.39909 .84799 m .39701 .84834 L .39714 .84613 L F
.468 .224 .46 r
.66815 .75261 m .66802 .75447 L .66596 .75503 L F
.551 .361 .576 r
.67054 .74968 m .67053 .75235 L .66815 .75261 L F
.391 .162 .443 r
.66995 .75382 m .66815 .75261 L .67053 .75235 L F
.66995 .75382 m .66802 .75447 L .66815 .75261 L F
.793 .681 .741 r
.58736 .76768 m .58848 .77069 L .58546 .77061 L F
.702 .636 .78 r
.59046 .76992 m .58848 .77069 L .58736 .76768 L F
.519 .36 .605 r
.67239 .74924 m .67053 .75235 L .67054 .74968 L F
.541 .022 0 r
.48833 .8356 m .48492 .83558 L .48628 .83575 L F
.927 .947 .786 r
.50359 .82765 m .50477 .82661 L .5054 .82503 L F
.645 .553 .736 r
.50477 .82661 m .5077 .82484 L .5054 .82503 L F
.717 .796 .913 r
.57121 .7724 m .5742 .77325 L .57271 .77307 L F
.57121 .7724 m .57376 .77078 L .5742 .77325 L F
.602 .92 .973 r
.57376 .77078 m .57684 .77025 L .5742 .77325 L F
.03 .25 .752 r
.56442 .80333 m .56402 .80424 L .56231 .80121 L F
0 .184 .704 r
.56442 .80333 m .56574 .80638 L .56402 .80424 L F
0 0 0 r
.48682 .81449 m .48554 .81719 L .48491 .81719 L F
.703 .611 .751 r
.48682 .81449 m .49008 .81466 L .48905 .81211 L F
.026 0 .082 r
.48905 .81211 m .48805 .81439 L .48682 .81449 L F
.023 0 .053 r
.48805 .81439 m .48554 .81719 L .48682 .81449 L F
.472 .582 .884 r
.57636 .80415 m .57432 .80434 L .57289 .80187 L F
.449 .255 .523 r
.5741 .80652 m .57432 .80434 L .57636 .80415 L F
.653 .585 .766 r
.48905 .81211 m .49008 .81466 L .4923 .81449 L F
.633 .752 .934 r
.54451 .82685 m .54701 .82806 L .54907 .82721 L F
.532 .037 .025 r
.54831 .82866 m .54701 .82806 L .54655 .82861 L F
.892 .784 .735 r
.54831 .82866 m .54907 .82721 L .54701 .82806 L F
.134 0 0 r
.42538 .89249 m .42857 .89159 L .42727 .89182 L F
.181 .712 .836 r
.42857 .89159 m .42923 .89136 L .42727 .89182 L F
.42857 .89159 m .43029 .89145 L .42923 .89136 L F
0 0 .111 r
.53405 .81718 m .53577 .81385 L .53389 .81603 L F
.53405 .81718 m .535 .81665 L .53577 .81385 L F
0 0 .162 r
.6136 .77308 m .61383 .7741 L .61519 .77264 L F
.6136 .77308 m .61372 .77562 L .61383 .7741 L F
.77 .651 .731 r
.57041 .84197 m .56889 .83975 L .57009 .84171 L F
0 0 .514 r
.57009 .84171 m .56889 .83975 L .56919 .83954 L F
.57009 .84171 m .56919 .83954 L .56915 .84181 L F
.611 .956 .86 r
.56983 .84149 m .57009 .84171 L .56915 .84181 L F
.57195 .84051 m .57009 .84171 L .56983 .84149 L F
.77 .651 .731 r
.57065 .84232 m .57041 .84197 L .57009 .84171 L F
.695 .944 .96 r
.57195 .84051 m .57065 .84232 L .57009 .84171 L F
.57195 .84051 m .57386 .84071 L .57065 .84232 L F
0 .553 .708 r
.46676 .88139 m .46878 .88147 L .46548 .88133 L F
.55 .455 .701 r
.51 .83469 m .50785 .83673 L .50836 .83464 L F
.51 .83469 m .51056 .83731 L .50785 .83673 L F
.579 .194 .276 r
.51056 .83731 m .50717 .83842 L .50785 .83673 L F
.717 .679 .813 r
.52268 .81638 m .52266 .81774 L .5201 .81725 L F
.511 .506 .787 r
.52461 .81641 m .52266 .81774 L .52268 .81638 L F
.717 .517 .619 r
.5077 .82484 m .51107 .82606 L .51051 .82241 L F
.506 .32 .562 r
.51107 .82606 m .51297 .82246 L .51051 .82241 L F
.706 .401 .457 r
.43295 .83795 m .43201 .84031 L .42994 .83786 L F
.438 .125 .336 r
.4339 .83993 m .43295 .83795 L .43506 .83775 L F
.4339 .83993 m .43201 .84031 L .43295 .83795 L F
.533 0 0 r
.48216 .88515 m .48311 .88613 L .48205 .88519 L F
.097 .565 .909 r
.4793 .88396 m .48216 .88515 L .48093 .88419 L F
.533 0 0 r
.48216 .88515 m .48205 .88519 L .48093 .88419 L F
.55 0 0 r
.48046 .88474 m .48222 .88512 L .48216 .88515 L F
.48222 .88512 m .48338 .88538 L .48216 .88515 L F
.593 .045 0 r
.48338 .88538 m .48432 .88662 L .48216 .88515 L F
.48338 .88538 m .48596 .88665 L .48432 .88662 L F
.542 .319 .526 r
.62435 .77525 m .62435 .77682 L .6217 .77703 L F
.551 .304 .495 r
.62435 .77682 m .62168 .78015 L .6217 .77703 L F
.705 .357 .385 r
.53747 .81929 m .53548 .82134 L .53393 .81966 L F
.656 .165 .072 r
.53747 .81929 m .53718 .82142 L .53548 .82134 L F
.037 .607 .747 r
.49613 .87739 m .49531 .87748 L .49366 .8776 L F
.49613 .87739 m .49766 .87747 L .49531 .87748 L F
.68 .603 .763 r
.48905 .81211 m .48763 .81324 L .48575 .81038 L F
.611 .116 .053 r
.49431 .81245 m .49318 .81356 L .49124 .81232 L F
.583 .362 .546 r
.49542 .8125 m .49621 .81357 L .49431 .81245 L F
.284 0 0 r
.49953 .81278 m .49621 .81357 L .49542 .8125 L F
0 0 0 r
.49534 .8119 m .49431 .81245 L .49621 .81357 L F
.49534 .8119 m .49318 .81356 L .49431 .81245 L F
.865 .538 .431 r
.51829 .82574 m .51972 .82757 L .51884 .82526 L F
.488 0 0 r
.44452 .82007 m .44637 .82083 L .44776 .81974 L F
.489 .018 .062 r
.44637 .82083 m .44982 .81974 L .44776 .81974 L F
.037 0 0 r
.46848 .87052 m .46734 .87068 L .4665 .87151 L F
.375 0 .156 r
.45691 .87413 m .4537 .87642 L .45577 .87628 L F
.584 .534 .764 r
.45691 .87413 m .45897 .87387 L .45791 .87095 L F
.436 .053 .213 r
.45781 .8759 m .45691 .87413 L .45577 .87628 L F
.45781 .8759 m .45897 .87387 L .45691 .87413 L F
.932 .743 .625 r
.65734 .7529 m .65617 .74982 L .6547 .75224 L F
.456 .062 .204 r
.65435 .75477 m .65734 .7529 L .6547 .75224 L F
.65435 .75477 m .65678 .75459 L .65734 .7529 L F
.226 0 .122 r
.65734 .7529 m .65867 .75379 L .65983 .75253 L F
.65734 .7529 m .65678 .75459 L .65867 .75379 L F
.645 .553 .736 r
.50477 .82661 m .50799 .82647 L .5077 .82484 L F
.678 .505 .645 r
.60273 .76274 m .60325 .76531 L .59992 .76474 L F
.62 .552 .756 r
.60424 .75966 m .60273 .76274 L .60205 .76094 L F
.60424 .75966 m .60535 .76264 L .60273 .76274 L F
.653 .489 .649 r
.60534 .76475 m .60273 .76274 L .60535 .76264 L F
.60534 .76475 m .60325 .76531 L .60273 .76274 L F
.287 .777 .714 r
.45744 .88467 m .45815 .88447 L .46008 .88376 L F
.305 0 0 r
.45602 .88436 m .45815 .88447 L .4563 .88507 L F
.287 .777 .714 r
.4563 .88507 m .45815 .88447 L .45744 .88467 L F
.185 0 0 r
.45602 .88436 m .45877 .8843 L .45815 .88447 L F
.45877 .8843 m .45899 .8843 L .45815 .88447 L F
.344 .823 .841 r
.46008 .88376 m .45899 .8843 L .46085 .88375 L F
.337 .814 .771 r
.45815 .88447 m .45899 .8843 L .46008 .88376 L F
.582 .608 .844 r
.50657 .85452 m .50903 .85415 L .50817 .85277 L F
.746 .757 .861 r
.43033 .878 m .42859 .8798 L .42694 .87895 L F
0 0 0 r
.67457 .74717 m .67239 .74924 L .67249 .74736 L F
.62 .331 .457 r
.63625 .76813 m .63854 .77 L .63639 .76974 L F
.5 .168 .335 r
.49674 .822 m .49368 .82419 L .49439 .82208 L F
.67 .792 .939 r
.54468 .82158 m .54639 .823 L .54767 .82206 L F
.528 0 0 r
.50709 .80911 m .5095 .81011 L .51034 .80938 L F
.284 0 0 r
.5095 .81011 m .51222 .81042 L .51034 .80938 L F
.294 .789 .867 r
.40061 .89868 m .40544 .89822 L .40398 .89792 L F
.398 .829 .957 r
.40398 .89792 m .40544 .89822 L .40758 .89782 L F
.735 .307 .234 r
.39537 .85167 m .39363 .85268 L .39171 .85073 L F
.371 0 0 r
.3973 .85131 m .39363 .85268 L .39537 .85167 L F
.411 0 .06 r
.45318 .83251 m .4514 .83443 L .44963 .83407 L F
.415 0 .1 r
.45522 .83219 m .4514 .83443 L .45318 .83251 L F
.779 .804 .873 r
.57684 .77025 m .57984 .77021 L .57813 .77131 L F
.479 .364 .645 r
.51681 .8278 m .51829 .82574 L .51596 .82663 L F
.51681 .8278 m .51901 .82954 L .51829 .82574 L F
0 0 0 r
.59692 .78803 m .59453 .79072 L .59492 .78858 L F
.56 .924 .941 r
.4938 .83561 m .49686 .83491 L .49566 .83467 L F
.367 .671 .974 r
.46406 .83223 m .46555 .83145 L .46315 .8315 L F
.46406 .83223 m .46593 .83232 L .46555 .83145 L F
.587 .787 .975 r
.66705 .74263 m .66574 .74413 L .66495 .74279 L F
0 0 0 r
.66394 .74316 m .66633 .74275 L .66495 .74279 L F
.66633 .74275 m .66705 .74263 L .66495 .74279 L F
.51 .652 .922 r
.66495 .74279 m .66461 .74474 L .66333 .74284 L F
.66495 .74279 m .66333 .74284 L .6625 .7416 L F
.66495 .74279 m .66574 .74413 L .66461 .74474 L F
.701 .614 .756 r
.5926 .76752 m .59382 .77062 L .59046 .76992 L F
.698 .612 .757 r
.59606 .76839 m .59382 .77062 L .5926 .76752 L F
.621 .474 .661 r
.60234 .77531 m .59999 .77334 L .60219 .77298 L F
.60234 .77531 m .6001 .7756 L .59999 .77334 L F
.612 .137 .103 r
.51222 .81042 m .51444 .81098 L .51566 .80985 L F
.444 0 0 r
.51444 .81098 m .51756 .80975 L .51566 .80985 L F
.429 0 .097 r
.42321 .82447 m .42528 .82437 L .42666 .82276 L F
.493 .059 .141 r
.42666 .82276 m .42528 .82437 L .42835 .82365 L F
.481 .086 .214 r
.42666 .82276 m .42835 .82365 L .42873 .82263 L F
.399 .089 .32 r
.37527 .77151 m .37426 .7693 L .37658 .76839 L F
.37527 .77151 m .37334 .77206 L .37426 .7693 L F
0 0 .304 r
.58595 .81151 m .58717 .81487 L .58661 .81324 L F
.396 .662 .966 r
.5729 .79902 m .56955 .79767 L .57222 .79785 L F
.426 .027 .177 r
.56936 .80081 m .57229 .79932 L .57159 .79982 L F
.595 .636 .862 r
.57289 .80187 m .56936 .80081 L .57159 .79982 L F
.998 .783 .439 r
.57084 .80035 m .57159 .79982 L .57089 .79791 L F
.57083 .80089 m .57159 .79982 L .57084 .80035 L F
.426 .027 .177 r
.57229 .79932 m .5729 .79902 L .57159 .79982 L F
.665 .27 .287 r
.57222 .79785 m .57511 .79774 L .5729 .79902 L F
.224 0 0 r
.5729 .79902 m .57293 .79947 L .57497 .79892 L F
.5729 .79902 m .57497 .79892 L .57159 .79982 L F
.11 0 0 r
.42266 .84072 m .42164 .84121 L .4191 .8415 L F
.617 .253 .33 r
.42444 .83967 m .42164 .84121 L .42266 .84072 L F
.54 .263 .445 r
.40856 .84488 m .40639 .84541 L .40648 .84342 L F
.496 .368 .636 r
.36467 .75406 m .36704 .7518 L .36512 .75206 L F
.36467 .75406 m .36681 .754 L .36704 .7518 L F
.558 .43 .662 r
.36564 .75685 m .36681 .754 L .36467 .75406 L F
.892 .784 .735 r
.54831 .82866 m .54929 .82993 L .54907 .82721 L F
0 0 0 r
.54631 .83243 m .54929 .82993 L .54831 .82866 L F
.473 .298 .562 r
.36009 .76528 m .36187 .76487 L .36199 .76256 L F
.453 .243 .503 r
.36161 .76698 m .36009 .76528 L .35974 .76743 L F
.36161 .76698 m .36187 .76487 L .36009 .76528 L F
.424 .868 .817 r
.59564 .82907 m .59532 .82899 L .59773 .82738 L F
.59564 .82907 m .59448 .82928 L .59532 .82899 L F
.545 .129 .203 r
.51682 .81661 m .51365 .81739 L .51464 .81705 L F
.604 .629 .849 r
.52308 .84752 m .52426 .8486 L .52148 .84831 L F
.496 .365 .632 r
.52148 .84831 m .52355 .85032 L .52308 .84752 L F
.783 .795 .862 r
.57636 .80415 m .57934 .80415 L .57754 .80538 L F
.527 .281 .486 r
.57754 .80538 m .57934 .80415 L .57922 .80583 L F
.473 .258 .506 r
.61759 .78098 m .61747 .78313 L .61551 .78366 L F
.474 .258 .506 r
.61943 .78255 m .61759 .78098 L .61979 .78068 L F
.61943 .78255 m .61747 .78313 L .61759 .78098 L F
.772 .542 .586 r
.59681 .76009 m .59367 .76208 L .59552 .7591 L F
.59681 .76009 m .59687 .76239 L .59367 .76208 L F
.57 .769 .973 r
.59893 .7597 m .59681 .76009 L .59552 .7591 L F
.483 .559 .857 r
.57896 .78238 m .58128 .78006 L .57909 .78056 L F
.57896 .78238 m .58269 .78276 L .58128 .78006 L F
.57896 .78238 m .58083 .78374 L .58269 .78276 L F
.156 .693 .708 r
.4665 .87151 m .46448 .87193 L .46335 .87214 L F
.5 .295 .533 r
.36163 .76029 m .36367 .75992 L .36371 .75765 L F
.591 .368 .546 r
.36371 .75765 m .36584 .75945 L .36564 .75685 L F
.36371 .75765 m .36367 .75992 L .36584 .75945 L F
.171 0 0 r
.39131 .8297 m .39035 .82941 L .38922 .82982 L F
.39131 .8297 m .39232 .82919 L .39035 .82941 L F
.963 .657 .401 r
.5511 .83979 m .55226 .84044 L .55239 .84317 L F
.5511 .83979 m .55239 .84317 L .55233 .84308 L F
.726 .697 .822 r
.55239 .84317 m .5528 .84377 L .5543 .84252 L F
.616 .368 .519 r
.55239 .84317 m .5543 .84252 L .55239 .84325 L F
.55226 .84044 m .5543 .84252 L .55239 .84317 L F
.963 .657 .401 r
.5511 .83979 m .55233 .84308 L .55167 .84202 L F
.726 .697 .822 r
.55167 .84212 m .55233 .84308 L .55175 .84214 L F
.963 .657 .401 r
.55233 .84308 m .55239 .84325 L .55167 .84202 L F
.726 .697 .822 r
.55175 .84214 m .55239 .84317 L .5543 .84252 L F
.55233 .84308 m .55239 .84317 L .55175 .84214 L F
.55167 .84202 m .55167 .84212 L .5543 .84252 L F
.55167 .84212 m .55166 .84471 L .5528 .84377 L F
.963 .657 .401 r
.55233 .84308 m .55239 .84317 L .55239 .84325 L F
.101 .588 .906 r
.55291 .84006 m .55226 .84044 L .5511 .83979 L F
.732 .336 .301 r
.55167 .84202 m .5543 .84252 L .55226 .84044 L F
.55167 .84202 m .55226 .84044 L .55291 .84006 L F
.444 0 0 r
.51444 .81098 m .51649 .81109 L .51756 .80975 L F
.752 .525 .588 r
.51649 .81109 m .52003 .80903 L .51756 .80975 L F
.426 0 0 r
.50302 .86097 m .502 .86061 L .50175 .86114 L F
.209 0 0 r
.52623 .8159 m .52751 .81491 L .53016 .81429 L F
.387 .199 .501 r
.52829 .82032 m .52779 .82058 L .52627 .82108 L F
.52829 .82032 m .52839 .82212 L .52779 .82058 L F
.441 .226 .49 r
.52839 .82212 m .52632 .82282 L .52779 .82058 L F
.686 .705 .862 r
.55983 .77915 m .56167 .77693 L .55973 .77778 L F
.728 .655 .776 r
.59687 .76239 m .59795 .76527 L .59458 .76483 L F
.692 .572 .715 r
.59789 .76738 m .59458 .76483 L .59795 .76527 L F
.731 .569 .672 r
.59992 .76474 m .59789 .76738 L .59795 .76527 L F
.702 .636 .78 r
.59046 .76992 m .58736 .76768 L .58925 .76719 L F
.706 .622 .76 r
.5926 .76752 m .59046 .76992 L .58925 .76719 L F
.556 .447 .684 r
.36163 .76029 m .36395 .76216 L .36367 .75992 L F
.36163 .76029 m .36199 .76256 L .36395 .76216 L F
.83 .404 .226 r
.48554 .81719 m .48702 .8173 L .48491 .81719 L F
.167 .673 .905 r
.50674 .83428 m .51 .83469 L .50836 .83464 L F
.851 .734 .734 r
.48511 .83017 m .48185 .83217 L .4819 .83078 L F
.48511 .83017 m .4838 .83312 L .48185 .83217 L F
.696 .623 .771 r
.58215 .76804 m .58312 .77066 L .57984 .77021 L F
.618 .553 .759 r
.58316 .77294 m .57984 .77021 L .58312 .77066 L F
.605 .471 .672 r
.58529 .76748 m .58312 .77066 L .58215 .76804 L F
.58529 .76748 m .58546 .77061 L .58312 .77066 L F
.603 .453 .65 r
.58546 .77061 m .58316 .77294 L .58312 .77066 L F
.485 .34 .609 r
.4891 .85161 m .4896 .85323 L .49125 .85261 L F
.091 0 0 r
.435 .89017 m .43584 .88965 L .43787 .88925 L F
.559 .427 .657 r
.38292 .76221 m .38109 .76062 L .38295 .75995 L F
.38292 .76221 m .38095 .76257 L .38109 .76062 L F
.408 .098 .324 r
.66596 .75503 m .66549 .75645 L .66345 .75708 L F
.472 .185 .395 r
.66802 .75447 m .66549 .75645 L .66596 .75503 L F
.206 0 0 r
.44197 .88876 m .44352 .88792 L .44555 .88773 L F
.49 .195 .392 r
.43944 .83553 m .43693 .8373 L .43758 .83562 L F
0 0 0 r
.43783 .87671 m .436 .87736 L .43431 .87807 L F
.731 .569 .672 r
.59992 .76474 m .60118 .76795 L .59789 .76738 L F
.671 .54 .696 r
.60325 .76531 m .60118 .76795 L .59992 .76474 L F
.008 .113 .626 r
.59771 .78391 m .59684 .78598 L .59605 .78278 L F
.572 .586 .828 r
.59771 .78391 m .59692 .78803 L .59684 .78598 L F
.785 .793 .859 r
.57837 .7693 m .57984 .77021 L .57684 .77025 L F
.782 .794 .862 r
.58215 .76804 m .57984 .77021 L .57837 .7693 L F
.921 .812 .721 r
.56915 .79837 m .56856 .79579 L .56955 .79767 L F
.56915 .79837 m .5668 .79875 L .56856 .79579 L F
.787 .566 .6 r
.56915 .79837 m .56685 .80102 L .5668 .79875 L F
0 0 .206 r
.53577 .81385 m .5358 .81393 L .535 .81126 L F
0 0 0 r
.53577 .81385 m .535 .81665 L .5358 .81393 L F
.295 .783 .902 r
.36382 .7491 m .36045 .74931 L .36212 .74942 L F
.217 0 0 r
.44982 .81974 m .45186 .81972 L .45305 .81935 L F
.494 0 0 r
.45186 .81972 m .45514 .81958 L .45305 .81935 L F
.553 .321 .517 r
.49 .82506 m .49163 .82705 L .4892 .82722 L F
.591 .232 .328 r
.49184 .83454 m .49053 .83727 L .48833 .8356 L F
.49053 .83727 m .49032 .83741 L .48833 .8356 L F
.461 .254 .511 r
.48833 .8356 m .49032 .83741 L .49075 .83646 L F
.858 .714 .702 r
.49055 .83727 m .49033 .83739 L .49075 .83646 L F
.49008 .83909 m .48778 .83901 L .49055 .83727 L F
.591 .232 .328 r
.49053 .83727 m .49043 .8375 L .49032 .83741 L F
.461 .254 .511 r
.49032 .83741 m .49043 .8375 L .49075 .83646 L F
.858 .714 .702 r
.49033 .83739 m .48751 .839 L .49075 .83646 L F
.48778 .83901 m .48751 .839 L .49055 .83727 L F
.385 .468 .822 r
.49237 .83242 m .4938 .83561 L .49184 .83454 L F
.433 .072 .25 r
.49234 .83678 m .49184 .83454 L .4938 .83561 L F
.49234 .83678 m .49043 .8375 L .49184 .83454 L F
.687 .482 .603 r
.5503 .82488 m .55061 .82219 L .5497 .82218 L F
0 .094 .609 r
.55151 .82353 m .5497 .82218 L .55106 .8208 L F
.687 .482 .603 r
.5503 .82488 m .5497 .82218 L .55151 .82353 L F
.613 .261 .349 r
.57455 .84587 m .57767 .84524 L .57672 .84738 L F
.629 .229 .266 r
.57767 .84524 m .57879 .84746 L .57672 .84738 L F
.57767 .84524 m .57991 .84571 L .57879 .84746 L F
.879 .99 .808 r
.44732 .86893 m .44522 .87145 L .44837 .87229 L F
0 0 0 r
.44795 .87177 m .44756 .87189 L .44605 .87322 L F
.769 .543 .591 r
.45058 .87162 m .44732 .86893 L .44837 .87229 L F
.722 .912 .96 r
.44915 .87084 m .44837 .87229 L .44756 .87189 L F
0 0 0 r
.44915 .87084 m .44756 .87189 L .44795 .87177 L F
.095 .601 .895 r
.44756 .87189 m .44837 .87229 L .44725 .87199 L F
.44756 .87189 m .44725 .87199 L .44522 .87145 L F
.965 .829 .659 r
.44756 .87189 m .44756 .87406 L .44837 .87229 L F
.769 .543 .591 r
.45058 .87162 m .44837 .87229 L .44915 .87084 L F
.437 .071 .244 r
.44837 .87229 m .44962 .87354 L .44756 .87406 L F
.44837 .87229 m .45058 .87162 L .44962 .87354 L F
.558 .555 .807 r
.59061 .798 m .59145 .80132 L .58956 .80137 L F
.705 .467 .562 r
.59145 .80132 m .58889 .80344 L .58956 .80137 L F
.426 .149 .389 r
.61551 .78366 m .61747 .78313 L .615 .78536 L F
.353 0 .178 r
.61661 .76967 m .61971 .76783 L .61757 .76826 L F
.745 .701 .81 r
.51682 .81661 m .51985 .81767 L .5201 .81725 L F
.146 .649 .907 r
.41126 .88112 m .41451 .8818 L .41255 .88163 L F
.651 .396 .521 r
.52499 .82221 m .52829 .82032 L .52627 .82108 L F
0 0 0 r
.3943 .82869 m .39632 .82839 L .398 .82803 L F
.117 0 0 r
.39632 .82839 m .40006 .82782 L .398 .82803 L F
.743 .361 .33 r
.57367 .77821 m .5726 .77999 L .57052 .77764 L F
.614 .942 .746 r
.57476 .777 m .57367 .77821 L .5758 .7778 L F
.57476 .777 m .57353 .77802 L .57367 .77821 L F
.81 .882 .453 r
.57353 .77802 m .5726 .77999 L .57367 .77821 L F
.591 .418 .616 r
.57372 .78052 m .5758 .7778 L .57367 .77821 L F
.778 .802 .872 r
.57835 .80334 m .57934 .80415 L .57636 .80415 L F
.53 .781 .99 r
.58125 .80292 m .57934 .80415 L .57835 .80334 L F
.58125 .80292 m .58165 .80386 L .57934 .80415 L F
.604 .346 .5 r
.57922 .80583 m .57934 .80415 L .5814 .80601 L F
.562 .353 .554 r
.57934 .80415 m .58165 .80386 L .5814 .80601 L F
.877 .929 .853 r
.40603 .8821 m .40515 .88475 L .40374 .88349 L F
.40603 .8821 m .40721 .88245 L .40515 .88475 L F
.35 0 0 r
.46878 .88147 m .47199 .88188 L .4707 .88194 L F
.274 0 0 r
.47199 .88188 m .4727 .88227 L .4707 .88194 L F
.47199 .88188 m .47395 .88225 L .4727 .88227 L F
.316 0 .117 r
.65974 .74366 m .6625 .7416 L .66035 .74187 L F
.813 .787 .828 r
.58321 .78988 m .58154 .79121 L .58457 .79103 L F
.782 .788 .858 r
.58321 .78988 m .58457 .79103 L .58696 .78851 L F
.617 .507 .706 r
.58457 .79103 m .5868 .79075 L .58696 .78851 L F
.56 .471 .712 r
.58457 .79103 m .58732 .79279 L .5868 .79075 L F
.58457 .79103 m .58515 .79405 L .58732 .79279 L F
.177 0 0 r
.49458 .88755 m .49733 .88673 L .49655 .88717 L F
.04 0 0 r
.49733 .88673 m .49857 .88672 L .49655 .88717 L F
.49733 .88673 m .49941 .88629 L .49857 .88672 L F
.489 .096 .221 r
.65419 .76233 m .65337 .76407 L .65105 .76425 L F
.606 .334 .479 r
.65419 .76233 m .65659 .764 L .65337 .76407 L F
.65419 .76233 m .6564 .76239 L .65659 .764 L F
.689 .265 .234 r
.54268 .8347 m .5456 .83479 L .54519 .83559 L F
.08 0 .204 r
.54686 .83459 m .5456 .83479 L .54874 .83037 L F
.03 0 0 r
.54519 .83559 m .5456 .83479 L .54686 .83459 L F
.67 .757 .269 r
.57153 .8192 m .57259 .81647 L .57114 .81966 L F
.534 .557 .825 r
.57125 .79605 m .56955 .79767 L .56856 .79579 L F
.57125 .79605 m .57222 .79785 L .56955 .79767 L F
.963 .726 .532 r
.55046 .7965 m .54922 .79626 L .5488 .79387 L F
.737 .72 .835 r
.55249 .79449 m .55046 .7965 L .5488 .79387 L F
.896 .483 .202 r
.55113 .79828 m .54922 .79626 L .55046 .7965 L F
.573 .939 .897 r
.50402 .88446 m .50674 .88354 L .50578 .88347 L F
0 0 0 r
.50564 .88355 m .50402 .88446 L .50578 .88347 L F
.379 .837 .766 r
.50216 .88552 m .50493 .88448 L .50402 .88446 L F
0 0 0 r
.5023 .8855 m .50402 .88446 L .50564 .88355 L F
.379 .837 .766 r
.50145 .88578 m .50216 .88552 L .50402 .88446 L F
.573 .939 .897 r
.50402 .88446 m .50493 .88448 L .50674 .88354 L F
0 0 .082 r
.56282 .8325 m .56277 .83438 L .56293 .83415 L F
.56282 .8325 m .56293 .83415 L .56242 .8321 L F
.728 .417 .454 r
.43039 .83953 m .42662 .83833 L .42994 .83786 L F
.67 .401 .506 r
.42994 .83786 m .43201 .84031 L .43039 .83953 L F
.71 .584 .713 r
.56802 .8123 m .56619 .8152 L .5648 .81183 L F
.158 0 0 r
.50043 .87643 m .49766 .87747 L .49983 .87711 L F
.057 0 0 r
.50232 .87594 m .50043 .87643 L .50173 .87642 L F
.069 0 0 r
.50173 .87642 m .50043 .87643 L .49983 .87711 L F
.562 .918 .957 r
.6279 .76311 m .63198 .7624 L .62978 .76223 L F
.447 .763 .996 r
.40374 .88349 m .40198 .88368 L .40038 .88262 L F
.724 .574 .685 r
.50785 .85088 m .51049 .85112 L .50925 .85012 L F
.715 .437 .503 r
.51088 .85313 m .51049 .85112 L .50785 .85088 L F
.209 0 0 r
.52623 .8159 m .53016 .81429 L .52915 .81563 L F
.019 0 0 r
.53197 .81387 m .53016 .81429 L .53188 .81377 L F
.53127 .81427 m .53016 .81429 L .53197 .81387 L F
.53123 .81427 m .52915 .81563 L .53016 .81429 L F
.53228 .81425 m .53102 .81481 L .53123 .81427 L F
.53102 .81481 m .52915 .81563 L .53123 .81427 L F
.738 .262 .118 r
.53349 .81597 m .53311 .81614 L .53093 .81503 L F
.527 .857 .996 r
.52851 .81513 m .52915 .81563 L .53102 .81481 L F
.738 .262 .118 r
.53032 .81471 m .53027 .81469 L .53228 .81425 L F
.53032 .81471 m .5303 .81471 L .53027 .81469 L F
.527 .857 .996 r
.53056 .81462 m .53102 .81481 L .53228 .81425 L F
.019 0 0 r
.53228 .81425 m .53127 .81427 L .53197 .81387 L F
.57 .615 .858 r
.5303 .81471 m .53217 .81411 L .53132 .81224 L F
.527 .857 .996 r
.53023 .8147 m .5303 .81471 L .53056 .81462 L F
.5303 .81471 m .53102 .81481 L .53056 .81462 L F
.57 .615 .858 r
.53027 .81469 m .5303 .81471 L .53132 .81224 L F
.793 .499 .49 r
.53027 .81469 m .52691 .81309 L .52781 .81522 L F
.527 .857 .996 r
.52781 .81522 m .5302 .8147 L .53027 .81469 L F
.52781 .81522 m .53033 .8149 L .53023 .8147 L F
.793 .499 .49 r
.53027 .81469 m .53025 .81471 L .5302 .8147 L F
.527 .857 .996 r
.5302 .8147 m .53023 .8147 L .53023 .8147 L F
.52781 .81522 m .53023 .8147 L .5302 .8147 L F
.52781 .81522 m .52795 .81526 L .52851 .81513 L F
.52795 .81526 m .52915 .81563 L .52851 .81513 L F
.517 .373 .624 r
.52573 .81401 m .52781 .81522 L .52691 .81309 L F
.485 .314 .574 r
.52781 .81522 m .52623 .8159 L .52915 .81563 L F
.793 .499 .49 r
.5302 .8147 m .52762 .81672 L .52732 .81519 L F
.53025 .81471 m .52762 .81672 L .5302 .8147 L F
.53027 .81469 m .52732 .81519 L .52691 .81309 L F
.527 .857 .996 r
.5302 .8147 m .53025 .81469 L .53027 .81469 L F
.53033 .8149 m .53102 .81481 L .53025 .8147 L F
.738 .262 .118 r
.53293 .81574 m .53032 .81471 L .53225 .81426 L F
.53293 .81574 m .53225 .81426 L .53228 .81425 L F
.53349 .81597 m .53293 .81574 L .53228 .81425 L F
.53096 .81496 m .53093 .81503 L .5303 .81471 L F
.53096 .81496 m .5303 .81471 L .53032 .81471 L F
.53349 .81597 m .53093 .81503 L .53096 .81496 L F
.57 .615 .858 r
.5303 .81471 m .53311 .81614 L .53224 .81424 L F
.53056 .81462 m .53224 .81424 L .53217 .81411 L F
.527 .857 .996 r
.53056 .81462 m .53228 .81425 L .53027 .81469 L F
.57 .615 .858 r
.5303 .81471 m .53224 .81424 L .53056 .81462 L F
.527 .857 .996 r
.53025 .81469 m .53056 .81462 L .53027 .81469 L F
.57 .615 .858 r
.53025 .8147 m .53025 .81469 L .52818 .81604 L F
.53025 .81469 m .52993 .81393 L .52923 .81477 L F
.53025 .81469 m .52923 .81477 L .52818 .81604 L F
.527 .857 .996 r
.53033 .8149 m .53025 .8147 L .53023 .8147 L F
.57 .615 .858 r
.53027 .81469 m .53132 .81224 L .52993 .81393 L F
.53027 .81469 m .52993 .81393 L .53025 .8147 L F
.737 .664 .779 r
.52941 .81715 m .52802 .81627 L .52762 .81672 L F
.71 .496 .596 r
.52623 .8159 m .52622 .81615 L .52573 .81401 L F
.485 .314 .574 r
.52781 .81522 m .52622 .81615 L .52623 .8159 L F
.517 .373 .624 r
.52573 .81401 m .52622 .81615 L .52781 .81522 L F
.823 .519 .475 r
.52691 .81309 m .52762 .81672 L .52597 .81498 L F
.737 .664 .779 r
.52802 .81627 m .52597 .81498 L .52762 .81672 L F
.52802 .81627 m .52578 .81623 L .52597 .81498 L F
.65 .674 .86 r
.52814 .81667 m .52941 .81715 L .52762 .81672 L F
.53148 .81638 m .52941 .81715 L .52814 .81667 L F
.57 .615 .858 r
.52948 .8153 m .52861 .81579 L .52762 .81672 L F
.52861 .81579 m .52828 .81598 L .52802 .81627 L F
.52861 .81579 m .52802 .81627 L .52762 .81672 L F
.028 0 .081 r
.53061 .81426 m .52782 .81656 L .53132 .81224 L F
.52782 .81656 m .52762 .81672 L .52793 .81635 L F
.57 .615 .858 r
.52828 .81598 m .52818 .81604 L .52762 .81672 L F
.028 0 .081 r
.52782 .81656 m .52793 .81635 L .53132 .81224 L F
.737 .664 .779 r
.52782 .81655 m .52753 .81667 L .52772 .81652 L F
.52941 .81715 m .52773 .81672 L .52782 .81655 L F
.52773 .81672 m .52753 .81667 L .52782 .81655 L F
.52941 .81714 m .52772 .81652 L .52802 .81627 L F
.65 .674 .86 r
.53148 .81638 m .52814 .81667 L .53061 .81426 L F
.52814 .81667 m .52762 .81672 L .52782 .81656 L F
.57 .615 .858 r
.53027 .81469 m .52818 .81604 L .52948 .8153 L F
.65 .674 .86 r
.52814 .81667 m .52782 .81656 L .53061 .81426 L F
.737 .664 .779 r
.52941 .81715 m .52814 .81667 L .52941 .81714 L F
.52814 .81667 m .52772 .81652 L .52941 .81714 L F
.52753 .81667 m .52578 .81623 L .52802 .81627 L F
.639 .109 0 r
.57762 .78313 m .57944 .78481 L .57729 .78559 L F
.57944 .78481 m .57987 .7852 L .57865 .78538 L F
.57944 .78481 m .57865 .78538 L .57729 .78559 L F
.57762 .78313 m .57945 .78511 L .57987 .7852 L F
.704 .493 .6 r
.57945 .78511 m .58269 .78276 L .58107 .78361 L F
.58063 .78393 m .58107 .78361 L .58083 .78374 L F
.57945 .78511 m .58083 .78374 L .57987 .7852 L F
.57945 .78511 m .58107 .78361 L .58063 .78393 L F
.762 .662 .752 r
.56936 .80081 m .57104 .80253 L .56741 .80451 L F
.595 .636 .862 r
.57289 .80187 m .57104 .80253 L .56936 .80081 L F
.505 .874 .981 r
.4092 .88188 m .40721 .88245 L .40603 .8821 L F
.889 .466 .084 r
.55645 .8063 m .55756 .80708 L .55839 .80894 L F
.542 .343 .561 r
.62647 .7729 m .62648 .77497 L .62435 .77525 L F
.553 .342 .548 r
.62648 .77497 m .62435 .77682 L .62435 .77525 L F
.842 .546 .489 r
.51596 .82663 m .51352 .82609 L .51389 .82584 L F
.606 .323 .462 r
.64367 .76507 m .64081 .76578 L .64176 .76509 L F
.866 .515 .011 r
.55847 .81084 m .55916 .81282 L .55828 .81111 L F
.71 .617 .751 r
.59812 .78053 m .59605 .78278 L .59604 .78105 L F
.631 .494 .678 r
.59812 .78053 m .59747 .78306 L .59605 .78278 L F
.008 .113 .626 r
.59771 .78391 m .59605 .78278 L .59747 .78306 L F
.507 .288 .516 r
.36494 .77559 m .36456 .77773 L .36268 .77814 L F
.502 .268 .491 r
.367 .77519 m .36456 .77773 L .36494 .77559 L F
.71 .584 .713 r
.56802 .8123 m .5648 .81183 L .56638 .81137 L F
.894 .759 .705 r
.56743 .80948 m .56802 .8123 L .56638 .81137 L F
.807 .681 .725 r
.35457 .73146 m .35272 .73386 L .35166 .73282 L F
.35457 .73146 m .35348 .732 L .35515 .73133 L F
.35457 .73146 m .35166 .73282 L .35348 .732 L F
.35457 .73146 m .35325 .73394 L .35272 .73386 L F
.768 .657 .74 r
.35515 .73133 m .35325 .73394 L .35457 .73146 L F
.647 .946 .956 r
.39239 .90198 m .39324 .90078 L .39111 .90166 L F
.39239 .90198 m .39484 .90081 L .39324 .90078 L F
.546 .296 .488 r
.63116 .77068 m .63111 .77262 L .6289 .77289 L F
.578 .317 .484 r
.63445 .7695 m .63111 .77262 L .63116 .77068 L F
.387 0 .039 r
.41605 .82537 m .41761 .82592 L .41899 .82448 L F
.441 0 .015 r
.41761 .82592 m .42115 .82468 L .41899 .82448 L F
.611 .627 .843 r
.56383 .79848 m .56231 .80121 L .5612 .79858 L F
.56383 .79848 m .56457 .8009 L .56231 .80121 L F
.03 .25 .752 r
.56442 .80333 m .56231 .80121 L .56457 .8009 L F
.684 .603 .759 r
.58555 .79622 m .58732 .79279 L .58515 .79405 L F
.68 .603 .763 r
.48905 .81211 m .48615 .81059 L .48907 .81184 L F
.48615 .81059 m .48622 .81058 L .48907 .81184 L F
.48615 .81059 m .48575 .81038 L .48622 .81058 L F
.418 .815 .984 r
.48479 .81142 m .48907 .81184 L .48575 .81038 L F
.16 0 0 r
.48679 .8111 m .49179 .8092 L .48907 .81184 L F
.48679 .8111 m .48884 .81077 L .48955 .81039 L F
.48849 .81045 m .48955 .81039 L .49179 .8092 L F
.48679 .8111 m .48955 .81039 L .48849 .81045 L F
.844 .989 .857 r
.49145 .80964 m .48905 .81211 L .48907 .81184 L F
.653 .585 .766 r
.48905 .81211 m .4923 .81449 L .49124 .81232 L F
.706 .375 .414 r
.49224 .81394 m .48905 .81211 L .49124 .81232 L F
.49224 .81394 m .48805 .81439 L .48905 .81211 L F
.597 .54 .761 r
.36782 .74201 m .36586 .74261 L .36473 .73905 L F
.929 .9 .776 r
.5201 .81725 m .51736 .81964 L .51682 .81661 L F
.5201 .81725 m .51817 .8201 L .51736 .81964 L F
.122 0 0 r
.46913 .87155 m .47064 .87037 L .46901 .8716 L F
.29 0 0 r
.47172 .86953 m .47064 .87037 L .47146 .87147 L F
.48 .707 .969 r
.47321 .87059 m .47146 .87147 L .47064 .87037 L F
.122 0 0 r
.47195 .87052 m .47064 .87037 L .46913 .87155 L F
.29 0 0 r
.47179 .86899 m .47064 .87037 L .47172 .86953 L F
.47179 .86899 m .46848 .87052 L .47064 .87037 L F
0 .134 .66 r
.49093 .82945 m .49237 .83242 L .49063 .82986 L F
.628 .352 .481 r
.62647 .7729 m .62879 .7747 L .62648 .77497 L F
.62647 .7729 m .6289 .77289 L .62879 .7747 L F
.688 .268 .243 r
.47145 .83333 m .47029 .8335 L .4688 .83387 L F
.47029 .8335 m .46823 .83381 L .4688 .83387 L F
.519 0 0 r
.4688 .83387 m .46593 .83232 L .46671 .83439 L F
.4688 .83387 m .46671 .83439 L .46677 .83452 L F
.581 .781 .974 r
.52499 .82221 m .52632 .82282 L .52839 .82212 L F
.649 .524 .698 r
.60334 .7674 m .60133 .76995 L .60118 .76795 L F
.60334 .7674 m .60428 .77042 L .60133 .76995 L F
.618 .49 .684 r
.60428 .77042 m .60219 .77298 L .60133 .76995 L F
.508 .288 .515 r
.37885 .76506 m .37823 .76742 L .37655 .76768 L F
.481 .241 .473 r
.38084 .76466 m .37823 .76742 L .37885 .76506 L F
.08 0 .204 r
.54686 .83459 m .54874 .83037 L .54631 .83243 L F
.526 .332 .56 r
.38292 .76221 m .38084 .76466 L .38095 .76257 L F
.288 .092 .431 r
.6462 .7548 m .64487 .75756 L .64661 .75667 L F
.6462 .7548 m .64661 .75667 L .64604 .75426 L F
0 0 .486 r
.56293 .83415 m .56277 .83438 L .56445 .83716 L F
.668 .27 0 r
.56277 .83438 m .56465 .83785 L .56445 .83716 L F
.546 .476 .728 r
.56638 .81137 m .5648 .81183 L .56413 .80838 L F
.543 .171 .286 r
.49158 .81578 m .49466 .81526 L .4923 .81449 L F
.654 .491 .651 r
.38205 .8559 m .3797 .85836 L .37972 .85601 L F
.396 .633 .95 r
.5905 .8116 m .58911 .81187 L .58781 .8099 L F
.37 .312 .661 r
.59104 .81386 m .58911 .81187 L .5905 .8116 L F
.455 .324 .612 r
.59104 .81386 m .5893 .81425 L .58911 .81187 L F
.072 .632 .78 r
.57898 .79129 m .57826 .79121 L .576 .79124 L F
.529 .92 .9 r
.58031 .79024 m .57898 .79129 L .58154 .79121 L F
.58031 .79024 m .57826 .79121 L .57898 .79129 L F
.659 .782 .939 r
.57899 .77815 m .57828 .77697 L .5758 .7778 L F
.737 .532 .615 r
.5758 .7778 m .57909 .78056 L .57899 .77815 L F
.629 .418 .577 r
.57899 .77815 m .58128 .78006 L .57907 .77788 L F
.57899 .77815 m .57907 .77788 L .57975 .77863 L F
.379 0 .034 r
.57907 .77788 m .57909 .77793 L .57975 .77863 L F
.629 .418 .577 r
.57899 .77815 m .57909 .78056 L .58128 .78006 L F
.602 .667 .885 r
.58128 .78006 m .58208 .77716 L .57907 .77788 L F
.04 0 .014 r
.58077 .77762 m .57933 .77873 L .57907 .77788 L F
0 0 .527 r
.57899 .77815 m .57975 .77863 L .57909 .77793 L F
.57861 .77752 m .57909 .77793 L .57847 .77729 L F
.57899 .77815 m .57908 .77794 L .57861 .77752 L F
.737 .532 .615 r
.5758 .7778 m .57592 .78059 L .57909 .78056 L F
.379 0 .034 r
.57904 .77788 m .57682 .77916 L .57678 .77757 L F
.57907 .77788 m .57905 .7779 L .57904 .77788 L F
.57905 .7779 m .57682 .77916 L .57904 .77788 L F
0 0 .527 r
.57908 .77794 m .57909 .77793 L .57906 .77791 L F
.57908 .77794 m .57906 .77791 L .57861 .77752 L F
.04 0 .014 r
.57933 .77873 m .57901 .77898 L .57907 .77792 L F
.57909 .77793 m .57907 .77792 L .57907 .77788 L F
.379 0 .034 r
.57907 .77788 m .57901 .77898 L .57682 .77916 L F
.57907 .77788 m .57904 .77788 L .57909 .77793 L F
0 0 .527 r
.57847 .77729 m .57975 .77863 L .57828 .77697 L F
.552 .081 .091 r
.57828 .77697 m .57929 .77811 L .57678 .77757 L F
.04 0 .014 r
.57924 .77845 m .57907 .77792 L .57909 .77793 L F
.57924 .77845 m .57907 .77792 L .57924 .77845 L F
.379 0 .034 r
.57904 .77788 m .57678 .77757 L .57975 .77863 L F
.552 .081 .091 r
.57929 .77811 m .57975 .77863 L .57924 .77845 L F
.57929 .77811 m .57924 .77845 L .57678 .77757 L F
.04 0 .014 r
.57933 .77873 m .57924 .77845 L .57924 .77845 L F
.793 .774 .836 r
.58939 .76504 m .58641 .76493 L .58789 .76403 L F
.814 .708 .748 r
.58939 .76504 m .58736 .76768 L .58641 .76493 L F
.705 .543 .666 r
.58925 .76719 m .58736 .76768 L .58939 .76504 L F
.682 .775 .922 r
.59135 .76454 m .58939 .76504 L .58789 .76403 L F
.677 .604 .767 r
.59135 .76454 m .59336 .76591 L .58939 .76504 L F
.714 .579 .702 r
.59336 .76591 m .58925 .76719 L .58939 .76504 L F
.237 0 0 r
.523 .80662 m .52379 .80765 L .5249 .80568 L F
.523 .80662 m .52171 .80821 L .52379 .80765 L F
.298 .4 .799 r
.66803 .74627 m .6668 .74701 L .66574 .74413 L F
.374 .574 .917 r
.66803 .74627 m .66942 .7474 L .6668 .74701 L F
.768 .973 .921 r
.63915 .75873 m .63738 .76027 L .63673 .75975 L F
.425 .128 .356 r
.39005 .74436 m .39244 .74226 L .39051 .74326 L F
.276 .759 .659 r
.51433 .87886 m .51612 .87812 L .51533 .87844 L F
0 0 0 r
.51348 .87925 m .51433 .87886 L .51533 .87844 L F
.693 .54 .675 r
.4013 .8454 m .39909 .84799 L .39917 .84569 L F
.222 .404 .832 r
.54563 .81397 m .54706 .81643 L .54604 .81562 L F
.542 .304 .503 r
.64081 .76578 m .64074 .76971 L .63854 .77 L F
.606 .323 .462 r
.64367 .76507 m .64404 .7667 L .64081 .76578 L F
.52 .237 .425 r
.64404 .7667 m .64074 .76971 L .64081 .76578 L F
.427 .112 .325 r
.36456 .77773 m .36196 .78012 L .36268 .77814 L F
.372 .119 .394 r
.48897 .87406 m .49141 .87129 L .49104 .8736 L F
.48897 .87406 m .49141 .87129 L .49104 .8736 L F
.277 .716 .964 r
.49179 .8706 m .49141 .87129 L .49301 .87119 L F
.404 .145 .404 r
.49104 .8736 m .49141 .87129 L .49301 .87119 L F
0 0 0 r
.49179 .8706 m .49141 .87129 L .49104 .8736 L F
.594 .921 .969 r
.56551 .77634 m .56671 .77523 L .56713 .7752 L F
.56551 .77634 m .56409 .77616 L .56671 .77523 L F
.36 .779 .977 r
.49254 .82753 m .49163 .82705 L .4892 .82722 L F
.583 .416 .621 r
.36187 .76487 m .36395 .76216 L .36199 .76256 L F
.586 .778 .971 r
.36409 .74973 m .36918 .75131 L .36721 .74932 L F
.407 0 .029 r
.36409 .74973 m .36721 .74932 L .3662 .75001 L F
.36409 .74973 m .3662 .75001 L .36406 .74968 L F
.301 0 0 r
.36382 .7491 m .36024 .7511 L .36045 .74931 L F
.36382 .7491 m .36223 .75074 L .36024 .7511 L F
.514 0 0 r
.36382 .7491 m .36227 .74941 L .36223 .75074 L F
.36382 .7491 m .36409 .74973 L .36227 .74941 L F
.407 0 .029 r
.36409 .74973 m .36406 .74968 L .36227 .74941 L F
.52 .756 .982 r
.36414 .74982 m .36409 .74973 L .36382 .7491 L F
.36512 .75206 m .36409 .74973 L .36414 .74982 L F
.36512 .75206 m .36704 .7518 L .36409 .74973 L F
.36 0 .069 r
.52631 .87202 m .52887 .8709 L .52843 .87175 L F
0 0 0 r
.52887 .8709 m .53097 .86861 L .53088 .86886 L F
.52887 .8709 m .53041 .86934 L .52947 .87088 L F
.53041 .86934 m .53088 .86886 L .53043 .8695 L F
.53041 .86934 m .53043 .8695 L .52947 .87088 L F
.716 .248 .139 r
.5292 .87084 m .53045 .86963 L .52723 .86876 L F
.53045 .86963 m .53056 .86953 L .53043 .8695 L F
.53045 .86963 m .53043 .8695 L .52723 .86876 L F
.822 .859 .874 r
.5309 .86716 m .52723 .86876 L .53043 .8695 L F
.53059 .86927 m .53043 .8695 L .53056 .86953 L F
.5309 .86716 m .53043 .8695 L .53059 .86927 L F
0 0 0 r
.52947 .87088 m .53088 .86886 L .53019 .87084 L F
.096 0 0 r
.52843 .87175 m .52887 .8709 L .53019 .87084 L F
.652 .417 .551 r
.48185 .83217 m .47957 .83228 L .47989 .83004 L F
.742 .404 .41 r
.4819 .83078 m .48185 .83217 L .47989 .83004 L F
.809 .83 .867 r
.52773 .83161 m .52874 .8328 L .53121 .83067 L F
.315 .792 .709 r
.50664 .87514 m .50622 .8751 L .50583 .87574 L F
0 0 0 r
.5083 .87465 m .50598 .87508 L .50622 .8751 L F
.507 .912 .868 r
.51003 .87379 m .5083 .87465 L .50622 .8751 L F
.315 .792 .709 r
.5075 .8745 m .50622 .8751 L .50664 .87514 L F
0 0 0 r
.50598 .87508 m .5045 .87535 L .50622 .8751 L F
.44968 .88682 m .44855 .88691 L .45042 .88633 L F
.44778 .8875 m .44855 .88691 L .44968 .88682 L F
.617 .454 .639 r
.60234 .77531 m .60025 .77794 L .6001 .7756 L F
.273 .777 .788 r
.41472 .89555 m .41786 .89485 L .417 .89532 L F
0 0 0 r
.41886 .89457 m .41786 .89485 L .4197 .8941 L F
.417 .89532 m .41786 .89485 L .41886 .89457 L F
.715 .437 .503 r
.51088 .85313 m .50785 .85088 L .50817 .85277 L F
.948 .842 .705 r
.4838 .83312 m .4818 .83443 L .48185 .83217 L F
.4838 .83312 m .48289 .83541 L .4818 .83443 L F
.637 .275 .341 r
.41211 .84329 m .41057 .8454 L .40856 .84488 L F
.497 .115 .246 r
.41379 .84441 m .41211 .84329 L .41392 .84272 L F
.41379 .84441 m .41057 .8454 L .41211 .84329 L F
.67 .833 .962 r
.58504 .83711 m .58436 .83888 L .58307 .83795 L F
.58504 .83711 m .58634 .83806 L .58436 .83888 L F
.443 .508 .83 r
.37414 .74534 m .37641 .74634 L .37501 .74666 L F
.56 .455 .692 r
.37641 .74634 m .37483 .74925 L .37501 .74666 L F
.848 .407 .169 r
.55504 .80399 m .5552 .80604 L .55384 .80343 L F
.55504 .80399 m .55645 .8063 L .5552 .80604 L F
.675 .544 .698 r
.60325 .76531 m .60334 .7674 L .60118 .76795 L F
.241 0 0 r
.40201 .82741 m .40509 .82653 L .40304 .82695 L F
.265 .373 .788 r
.3624 .73539 m .36075 .73572 L .36086 .73511 L F
.3624 .73539 m .36347 .73805 L .36075 .73572 L F
.546 .476 .728 r
.56638 .81137 m .56413 .80838 L .56562 .80853 L F
.626 .269 .345 r
.57991 .84571 m .58304 .8453 L .58202 .84725 L F
.58 .187 .262 r
.58304 .8453 m .58416 .84733 L .58202 .84725 L F
.58304 .8453 m .58524 .84547 L .58416 .84733 L F
.606 .45 .644 r
.38856 .85268 m .38642 .8507 L .38965 .85044 L F
.659 .389 .5 r
.39171 .85073 m .38856 .85268 L .38965 .85044 L F
.536 .373 .607 r
.39909 .84799 m .3973 .85131 L .39701 .84834 L F
.491 .268 .502 r
.61266 .7879 m .61304 .78587 L .615 .78536 L F
.555 0 0 r
.64201 .75859 m .64465 .75988 L .64312 .7589 L F
.594 .402 .59 r
.64312 .7589 m .64465 .75988 L .64487 .75756 L F
.578 .253 .382 r
.67335 .74394 m .67571 .744 L .67652 .74168 L F
.911 .961 .638 r
.67849 .74133 m .67721 .74413 L .67652 .74168 L F
.555 .276 .446 r
.67571 .744 m .67849 .74133 L .67652 .74168 L F
.516 .305 .532 r
.37789 .76812 m .37655 .76768 L .37823 .76742 L F
.37789 .76812 m .37658 .76839 L .37655 .76768 L F
.433 .084 .272 r
.42662 .83833 m .42682 .83934 L .42444 .83967 L F
.728 .417 .454 r
.43039 .83953 m .42682 .83934 L .42662 .83833 L F
.506 .029 .058 r
.46239 .81864 m .46454 .81887 L .46594 .81768 L F
.355 0 0 r
.46454 .81887 m .46787 .8173 L .46594 .81768 L F
.618 .49 .684 r
.60428 .77042 m .60442 .77268 L .60219 .77298 L F
.61 .449 .638 r
.60442 .77268 m .60234 .77531 L .60219 .77298 L F
.564 .797 .987 r
.54184 .85997 m .54302 .86106 L .54376 .85972 L F
.54376 .85972 m .54302 .86106 L .54184 .85997 L F
.097 .565 .909 r
.4793 .88396 m .48046 .88474 L .48216 .88515 L F
.737 .68 .795 r
.50469 .80922 m .50186 .80932 L .50372 .80934 L F
.309 0 0 r
.50372 .80934 m .50709 .80911 L .50469 .80922 L F
.473 .246 .489 r
.66549 .75645 m .66304 .75874 L .66345 .75708 L F
.44 .128 .339 r
.58754 .84355 m .58728 .84502 L .58524 .84547 L F
.439 .104 .299 r
.59 .84258 m .58728 .84502 L .58754 .84355 L F
.412 .613 .932 r
.491 .87807 m .48693 .87532 L .48897 .87406 L F
.451 .055 .196 r
.48766 .87582 m .48897 .87406 L .48693 .87532 L F
.925 .828 .732 r
.49104 .8736 m .491 .87807 L .48897 .87406 L F
.24 0 .059 r
.49104 .8736 m .48897 .87406 L .48766 .87582 L F
.651 .396 .521 r
.52499 .82221 m .52839 .82212 L .52829 .82032 L F
.753 .475 .512 r
.52839 .82212 m .52925 .82229 L .52829 .82032 L F
.716 .461 .54 r
.53177 .82131 m .52925 .82229 L .52829 .82032 L F
.53177 .82131 m .53035 .82091 L .52965 .82182 L F
.583 .046 0 r
.52839 .82212 m .53067 .82335 L .52925 .82229 L F
.593 .197 .262 r
.53177 .82131 m .53067 .82335 L .52967 .82236 L F
.191 .103 .519 r
.53067 .82335 m .52947 .82216 L .52925 .82229 L F
.81 .876 .895 r
.53177 .82131 m .52925 .82229 L .52954 .82203 L F
.593 .197 .262 r
.53177 .82131 m .52924 .82258 L .52954 .82203 L F
.53177 .82131 m .52954 .82203 L .52965 .82182 L F
.81 .876 .895 r
.53177 .82131 m .52954 .82203 L .53273 .81907 L F
.191 .103 .519 r
.53067 .82335 m .53151 .82094 L .52947 .82216 L F
.593 .197 .262 r
.52967 .82236 m .53067 .82335 L .52924 .82258 L F
0 0 0 r
.52954 .82203 m .52938 .82217 L .5295 .8221 L F
.52938 .82217 m .52925 .82229 L .52932 .82225 L F
.593 .197 .262 r
.52965 .82182 m .52924 .82258 L .52839 .82212 L F
0 0 0 r
.53273 .81907 m .52954 .82203 L .53151 .82094 L F
.52954 .82203 m .5295 .8221 L .53151 .82094 L F
.52938 .82217 m .52932 .82225 L .53151 .82094 L F
.716 .461 .54 r
.52965 .82182 m .52829 .82032 L .52839 .82212 L F
.53035 .82091 m .52829 .82032 L .52965 .82182 L F
.679 .964 .747 r
.56978 .77769 m .56883 .77897 L .57052 .77764 L F
.56978 .77769 m .56727 .7799 L .56883 .77897 L F
0 0 0 r
.54144 .82393 m .54178 .82383 L .54272 .82229 L F
.54144 .82393 m .54038 .82494 L .54178 .82383 L F
0 .344 .781 r
.35559 .73119 m .35515 .73133 L .35348 .732 L F
.35559 .73119 m .35735 .7325 L .35515 .73133 L F
.86 .852 .833 r
.57271 .77307 m .56857 .77607 L .57121 .7724 L F
.433 .787 .997 r
.44839 .87665 m .44635 .87686 L .44512 .87621 L F
.571 .404 .617 r
.49761 .81443 m .49772 .81715 L .49986 .81672 L F
.144 .452 .883 r
.50077 .82909 m .50101 .83001 L .50359 .82765 L F
.50077 .82909 m .50199 .82947 L .50101 .83001 L F
.648 .611 .799 r
.50199 .82947 m .50005 .83161 L .50101 .83001 L F
.244 .321 .744 r
.50215 .8352 m .50419 .8372 L .50434 .8354 L F
.102 .413 .862 r
.49648 .80859 m .49711 .80856 L .49648 .80924 L F
.247 .628 .959 r
.49711 .80856 m .49846 .80954 L .49648 .80924 L F
.715 .8 .917 r
.35272 .73386 m .35325 .73394 L .35298 .73409 L F
.095 .643 .83 r
.52268 .81638 m .52103 .81608 L .52461 .81641 L F
.191 .398 .836 r
.55665 .7955 m .55576 .79645 L .55521 .79489 L F
.511 .183 .347 r
.43693 .8373 m .4339 .83993 L .43506 .83775 L F
.606 .244 .33 r
.42835 .82365 m .43175 .82187 L .42873 .82263 L F
.42835 .82365 m .43049 .82398 L .43175 .82187 L F
.466 .067 .198 r
.43049 .82398 m .43384 .82198 L .43175 .82187 L F
.51 .89 .964 r
.5756 .84005 m .57386 .84071 L .57195 .84051 L F
.425 .128 .356 r
.39005 .74436 m .392 .74408 L .39244 .74226 L F
.607 .294 .414 r
.392 .74408 m .39371 .74444 L .39244 .74226 L F
.639 .304 .389 r
.39244 .74226 m .39371 .74444 L .3945 .74267 L F
.713 .582 .707 r
.59458 .76483 m .59606 .76839 L .5926 .76752 L F
.692 .572 .715 r
.59789 .76738 m .59606 .76839 L .59458 .76483 L F
.606 .323 .462 r
.64367 .76507 m .64589 .76678 L .64404 .7667 L F
.64 .302 .383 r
.64367 .76507 m .64585 .76537 L .64589 .76678 L F
.557 .111 .148 r
.44605 .87322 m .44522 .87145 L .44461 .87387 L F
.44605 .87322 m .44756 .87189 L .44522 .87145 L F
.5 .168 .335 r
.49674 .822 m .49545 .82419 L .49368 .82419 L F
.655 .34 .428 r
.49869 .82411 m .49545 .82419 L .49674 .822 L F
0 0 .096 r
.56465 .83785 m .56489 .84012 L .56485 .83944 L F
.56465 .83785 m .56485 .83944 L .56445 .83716 L F
.238 .108 .493 r
.54501 .82493 m .54395 .82739 L .54451 .82685 L F
0 0 0 r
.54655 .82861 m .54395 .82739 L .54451 .82685 L F
.218 .079 .468 r
.54451 .82685 m .54395 .82739 L .54391 .83015 L F
.693 .54 .675 r
.4013 .8454 m .40258 .849 L .39909 .84799 L F
.505 .836 .999 r
.40625 .84756 m .40434 .84795 L .40543 .84797 L F
.435 .25 .529 r
.40625 .84756 m .40502 .84949 L .40434 .84795 L F
.40502 .84949 m .4045 .8503 L .40434 .84795 L F
.646 .515 .689 r
.40434 .84795 m .4013 .8454 L .40393 .84704 L F
.40434 .84795 m .40393 .84704 L .40543 .84797 L F
.40434 .84795 m .40258 .849 L .4013 .8454 L F
.714 .579 .702 r
.59336 .76591 m .5926 .76752 L .58925 .76719 L F
.716 .593 .717 r
.59458 .76483 m .59336 .76591 L .59135 .76454 L F
.694 .556 .693 r
.59458 .76483 m .5926 .76752 L .59336 .76591 L F
.732 .359 .344 r
.5713 .84552 m .57455 .84587 L .57342 .84769 L F
.63 .239 .284 r
.57342 .84769 m .57455 .84587 L .57672 .84738 L F
.716 .593 .717 r
.59458 .76483 m .59135 .76454 L .59367 .76208 L F
.754 .699 .8 r
.59687 .76239 m .59458 .76483 L .59367 .76208 L F
.411 .854 .92 r
.43029 .89145 m .43094 .89086 L .42923 .89136 L F
.43029 .89145 m .43236 .8909 L .43094 .89086 L F
.734 .705 .824 r
.58529 .76748 m .58215 .76804 L .58394 .76715 L F
.664 .629 .805 r
.58641 .76493 m .58529 .76748 L .58394 .76715 L F
.58641 .76493 m .58736 .76768 L .58529 .76748 L F
.685 .533 .674 r
.58736 .76768 m .58546 .77061 L .58529 .76748 L F
.463 .888 .818 r
.38572 .8885 m .38818 .88738 L .38911 .8872 L F
.585 .946 .863 r
.39091 .88612 m .38911 .8872 L .38979 .88633 L F
.591 .947 .839 r
.38911 .8872 m .38818 .88738 L .38979 .88633 L F
.453 0 0 r
.51159 .81792 m .5083 .81838 L .50931 .81911 L F
.571 .802 .987 r
.64354 .75664 m .64487 .75756 L .64661 .75667 L F
.584 .481 .703 r
.64465 .75988 m .64661 .75667 L .64487 .75756 L F
.471 .108 .268 r
.50526 .82122 m .50403 .81943 L .50603 .81962 L F
.50526 .82122 m .50314 .82157 L .50403 .81943 L F
.732 .206 0 r
.59892 .82939 m .59773 .82738 L .59532 .82899 L F
.59892 .82939 m .59978 .82965 L .59773 .82738 L F
.606 .569 .786 r
.38497 .75957 m .38295 .75995 L .38188 .75715 L F
.514 .326 .563 r
.38497 .75957 m .38292 .76221 L .38295 .75995 L F
.112 0 0 r
.41254 .82577 m .41481 .8257 L .41605 .82537 L F
.551 .027 0 r
.41481 .8257 m .41761 .82592 L .41605 .82537 L F
.925 .828 .732 r
.49104 .8736 m .49106 .87797 L .491 .87807 L F
.868 .967 .644 r
.491 .87807 m .49106 .87797 L .49015 .87941 L F
0 0 .106 r
.49114 .87597 m .49106 .87797 L .49105 .87521 L F
.754 .238 0 r
.49132 .87757 m .49114 .87597 L .48973 .87818 L F
.49168 .87744 m .49114 .87597 L .49132 .87757 L F
0 0 .106 r
.49114 .87597 m .49105 .87521 L .49104 .8736 L F
.844 .989 .857 r
.49145 .80964 m .48907 .81184 L .49179 .8092 L F
.682 .558 .708 r
.60534 .76475 m .60334 .7674 L .60325 .76531 L F
.065 .35 .823 r
.55828 .81111 m .55916 .81282 L .5609 .81391 L F
.578 .317 .484 r
.63445 .7695 m .63323 .77246 L .63111 .77262 L F
.601 .341 .495 r
.63581 .7707 m .63445 .7695 L .63639 .76974 L F
.63581 .7707 m .63323 .77246 L .63445 .7695 L F
.484 0 0 r
.46224 .83169 m .45936 .83221 L .45734 .83194 L F
.148 .688 .712 r
.46315 .8315 m .45936 .83221 L .46224 .83169 L F
.765 .56 .621 r
.40307 .85082 m .39909 .84799 L .40258 .849 L F
.40307 .85082 m .39906 .85112 L .39909 .84799 L F
.776 .669 .746 r
.40307 .85082 m .40052 .85363 L .39906 .85112 L F
.559 .345 .547 r
.40052 .85363 m .40285 .85337 L .40307 .85082 L F
.694 .62 .769 r
.40434 .84795 m .40307 .85082 L .40258 .849 L F
.383 .269 .599 r
.4045 .8503 m .40307 .85082 L .40434 .84795 L F
.217 .063 .447 r
.404 .85251 m .40307 .85082 L .4045 .8503 L F
.363 .144 .443 r
.40581 .85151 m .404 .85251 L .4045 .8503 L F
.619 .31 .425 r
.40581 .85151 m .40508 .8517 L .404 .85251 L F
.217 .063 .447 r
.404 .85251 m .40285 .85337 L .40307 .85082 L F
.619 .31 .425 r
.40508 .8517 m .40279 .85234 L .404 .85251 L F
.217 .063 .447 r
.404 .85251 m .40285 .85337 L .40285 .85337 L F
.46 .252 .51 r
.5342 .81151 m .53188 .81377 L .53185 .81174 L F
.391 .831 .699 r
.38159 .83158 m .37981 .83253 L .38068 .83197 L F
.371 .832 .908 r
.38068 .83197 m .37981 .83253 L .37753 .83235 L F
.566 .164 .24 r
.47446 .83256 m .47317 .83439 L .47145 .83333 L F
.559 .363 .571 r
.47701 .83232 m .47647 .83456 L .47446 .83256 L F
.711 .335 .335 r
.47647 .83456 m .47317 .83439 L .47446 .83256 L F
.45 .218 .47 r
.59629 .83477 m .5963 .83744 L .5942 .83748 L F
.335 .12 .432 r
.59833 .83202 m .59833 .83436 L .59629 .83477 L F
.477 .296 .556 r
.59833 .83436 m .5963 .83744 L .59629 .83477 L F
.412 .002 .15 r
.52728 .80454 m .5295 .80447 L .53043 .80391 L F
.386 0 0 r
.5295 .80447 m .53242 .80433 L .53043 .80391 L F
.868 .967 .644 r
.491 .87807 m .49015 .87941 L .48878 .87871 L F
.582 .157 .201 r
.44118 .82126 m .44329 .82169 L .44452 .82007 L F
.492 .058 .143 r
.44452 .82007 m .44329 .82169 L .44637 .82083 L F
.688 .58 .729 r
.60025 .77794 m .59812 .78053 L .59805 .77841 L F
.643 .515 .691 r
.60025 .77794 m .60049 .78052 L .59812 .78053 L F
.267 0 .251 r
.60049 .78052 m .59747 .78306 L .59812 .78053 L F
.614 .456 .644 r
.38642 .8507 m .38653 .85312 L .38435 .85332 L F
.632 .42 .577 r
.38635 .8554 m .38435 .85332 L .38653 .85312 L F
.38635 .8554 m .38421 .85562 L .38435 .85332 L F
.591 .037 0 r
.49093 .81039 m .49179 .8092 L .48884 .81077 L F
.267 0 .031 r
.49179 .8092 m .49253 .8109 L .49324 .80868 L F
.685 .586 .739 r
.51567 .86644 m .51639 .86852 L .51467 .86841 L F
0 0 0 r
.51534 .87135 m .51372 .87184 L .51475 .8716 L F
.027 0 0 r
.51475 .8716 m .51257 .87219 L .51126 .87293 L F
.51475 .8716 m .51126 .87293 L .51239 .87253 L F
.438 .846 .664 r
.51096 .87309 m .51257 .87219 L .51003 .87379 L F
.027 0 0 r
.51475 .8716 m .51096 .87309 L .51411 .8723 L F
.688 .48 .6 r
.51467 .86841 m .51639 .86852 L .51468 .87173 L F
.338 0 .103 r
.51447 .87213 m .51475 .8716 L .51411 .8723 L F
.688 .48 .6 r
.51448 .8718 m .51468 .87173 L .51447 .87213 L F
.51467 .86841 m .51468 .87173 L .51448 .8718 L F
.027 0 0 r
.51239 .87253 m .51126 .87293 L .51096 .87309 L F
.688 .48 .6 r
.51467 .86841 m .51449 .8717 L .5156 .86805 L F
.51449 .8717 m .51447 .87213 L .51459 .87169 L F
.51449 .8717 m .51459 .87169 L .5156 .86805 L F
0 0 0 r
.51372 .87184 m .51257 .87219 L .51413 .87177 L F
.51372 .87184 m .51413 .87177 L .51475 .8716 L F
.41 0 0 r
.51447 .87213 m .51534 .87135 L .51475 .8716 L F
.51447 .87213 m .51745 .8716 L .51534 .87135 L F
.57 .136 .176 r
.45154 .87609 m .44839 .87665 L .45042 .87624 L F
.31 0 0 r
.45042 .87624 m .4537 .87642 L .45154 .87609 L F
.391 .518 .866 r
.37515 .74389 m .37414 .74534 L .37306 .74427 L F
.37515 .74389 m .37641 .74634 L .37414 .74534 L F
.495 .898 .929 r
.39661 .89985 m .3998 .89914 L .39836 .89901 L F
.425 .855 .942 r
.39836 .89901 m .3998 .89914 L .40061 .89868 L F
.525 .335 .565 r
.47817 .87249 m .47911 .87098 L .47793 .8726 L F
.891 .789 .742 r
.48017 .87159 m .47726 .87395 L .47812 .87256 L F
.48017 .87159 m .47894 .8746 L .47722 .87397 L F
.832 .841 .853 r
.47722 .87397 m .47894 .8746 L .4777 .8748 L F
.397 .034 .227 r
.48057 .87329 m .47804 .87263 L .47777 .87488 L F
.525 .335 .565 r
.47817 .87249 m .47793 .8726 L .47814 .87252 L F
.494 .297 .541 r
.47793 .8726 m .47911 .87098 L .47814 .87252 L F
.47793 .8726 m .47814 .87252 L .47722 .87397 L F
.525 .335 .565 r
.47814 .87252 m .47793 .8726 L .47804 .87263 L F
.397 .034 .227 r
.47804 .87263 m .47793 .8726 L .47792 .87274 L F
.47804 .87263 m .47792 .87274 L .47777 .87488 L F
.891 .789 .742 r
.47824 .87245 m .47812 .87256 L .47817 .87249 L F
.48017 .87159 m .47812 .87256 L .47824 .87245 L F
.47935 .87112 m .47817 .87249 L .47911 .87098 L F
.48017 .87159 m .47817 .87249 L .47935 .87112 L F
.076 .369 .836 r
.48103 .87112 m .48291 .87365 L .48017 .87159 L F
.25 .479 .883 r
.48336 .87439 m .48261 .87373 L .48291 .87365 L F
.48261 .87373 m .48017 .87159 L .48291 .87365 L F
.876 .812 .783 r
.48369 .87267 m .48334 .87353 L .48291 .87365 L F
.158 .612 .933 r
.48693 .87532 m .48336 .87439 L .48563 .87628 L F
0 .182 .698 r
.48456 .87524 m .48336 .87439 L .48291 .87365 L F
.48563 .87628 m .48488 .87565 L .48456 .87524 L F
.48488 .87565 m .48336 .87439 L .48456 .87524 L F
.876 .812 .783 r
.48415 .87547 m .48419 .87557 L .48207 .87663 L F
.478 .045 .138 r
.48207 .87663 m .48419 .87557 L .48414 .87568 L F
0 .182 .698 r
.48563 .87628 m .48473 .87541 L .48414 .87568 L F
.48392 .87645 m .48414 .87568 L .48207 .87663 L F
.48563 .87628 m .48414 .87568 L .48392 .87645 L F
.562 .412 .635 r
.48345 .87883 m .48373 .8785 L .48207 .87663 L F
.48373 .8785 m .48563 .87628 L .48392 .87645 L F
.48373 .8785 m .48392 .87645 L .48207 .87663 L F
.478 .045 .138 r
.48207 .87663 m .48325 .87609 L .48294 .87813 L F
.48391 .87578 m .48414 .87568 L .48395 .87605 L F
.924 .847 .402 r
.48414 .87568 m .48419 .87557 L .48418 .87553 L F
0 .182 .698 r
.48473 .87541 m .48456 .87524 L .48417 .87546 L F
.48419 .87566 m .48417 .87546 L .48207 .87663 L F
.48456 .87524 m .48291 .87365 L .48207 .87663 L F
.876 .812 .783 r
.48401 .87454 m .48419 .87557 L .4833 .87363 L F
.81 .586 .027 r
.48418 .87553 m .48419 .87557 L .48417 .87546 L F
0 .182 .698 r
.48473 .87541 m .48417 .87546 L .48419 .87566 L F
.876 .812 .783 r
.48369 .87267 m .48401 .87454 L .4833 .87363 L F
.81 .586 .027 r
.4836 .87375 m .48418 .87553 L .48369 .87267 L F
.48418 .87553 m .48417 .87546 L .48369 .87267 L F
.876 .812 .783 r
.4833 .87363 m .48415 .87547 L .48207 .87663 L F
.924 .847 .402 r
.48294 .87813 m .48395 .87605 L .4836 .87375 L F
.48395 .87605 m .48414 .87568 L .48403 .87528 L F
.48395 .87605 m .48403 .87528 L .4836 .87375 L F
.48414 .87568 m .48418 .87553 L .4836 .87375 L F
.876 .812 .783 r
.48334 .87353 m .48207 .87663 L .48291 .87365 L F
.525 .335 .565 r
.48103 .87112 m .47817 .87249 L .48057 .87329 L F
.47817 .87249 m .47804 .87263 L .48057 .87329 L F
.076 .369 .836 r
.48103 .87112 m .48017 .87159 L .47911 .87098 L F
.525 .335 .565 r
.48103 .87112 m .47911 .87098 L .47817 .87249 L F
.891 .789 .742 r
.47726 .87395 m .47722 .87397 L .47911 .87098 L F
.155 0 0 r
.45254 .88574 m .45602 .88436 L .45424 .88559 L F
.305 0 0 r
.45602 .88436 m .4563 .88507 L .45424 .88559 L F
.218 0 0 r
.49098 .88888 m .49458 .88755 L .49303 .88855 L F
.128 0 0 r
.49303 .88855 m .49458 .88755 L .49655 .88717 L F
.505 .047 .098 r
.43384 .82198 m .43591 .82216 L .43698 .82138 L F
.467 .002 .064 r
.43698 .82138 m .43591 .82216 L .43902 .82149 L F
.77 .989 .893 r
.62464 .76531 m .62546 .76379 L .62687 .76492 L F
.62464 .76531 m .62388 .76494 L .62546 .76379 L F
.684 .603 .759 r
.58555 .79622 m .5879 .79621 L .58732 .79279 L F
.62 .362 .505 r
.58557 .79846 m .5879 .79621 L .58555 .79622 L F
.771 .55 .6 r
.45791 .87095 m .46134 .87207 L .46022 .87256 L F
.776 .497 .513 r
.46105 .87365 m .46134 .87207 L .45791 .87095 L F
0 .322 .79 r
.5678 .77508 m .56713 .7752 L .56671 .77523 L F
.5678 .77508 m .56857 .77607 L .56713 .7752 L F
.316 .704 .98 r
.45169 .87121 m .45058 .87162 L .44915 .87084 L F
0 0 0 r
.44962 .87354 m .45058 .87162 L .45169 .87121 L F
.682 .558 .708 r
.60534 .76475 m .60638 .76773 L .60334 .7674 L F
.652 .526 .697 r
.60651 .77006 m .60334 .7674 L .60638 .76773 L F
.60651 .77006 m .60428 .77042 L .60334 .7674 L F
.679 .649 .813 r
.60205 .76094 m .59893 .7597 L .60108 .75867 L F
.692 .616 .767 r
.60424 .75966 m .60205 .76094 L .60108 .75867 L F
.353 0 0 r
.46787 .8173 m .46999 .81719 L .47092 .81649 L F
.297 0 0 r
.46999 .81719 m .47306 .81609 L .47092 .81649 L F
.174 0 0 r
.4215 .89378 m .42538 .89249 L .42355 .89312 L F
.241 .742 .675 r
.42355 .89312 m .42538 .89249 L .42727 .89182 L F
.682 .775 .922 r
.59135 .76454 m .58789 .76403 L .59059 .76201 L F
.755 .773 .868 r
.59367 .76208 m .59135 .76454 L .59059 .76201 L F
.719 .902 .961 r
.53121 .83067 m .52754 .83123 L .52971 .82955 L F
.809 .83 .867 r
.52773 .83161 m .53121 .83067 L .52971 .82955 L F
.702 .808 .931 r
.52971 .82955 m .53121 .83067 L .53287 .82971 L F
.53287 .82971 m .53121 .83067 L .52971 .82955 L F
.494 .851 .599 r
.5168 .82376 m .5158 .82466 L .51817 .82275 L F
.51 .069 .136 r
.5226 .82244 m .52035 .82379 L .51817 .82275 L F
.739 .958 .664 r
.5187 .82142 m .51817 .82275 L .52035 .82379 L F
.5187 .82142 m .5168 .82376 L .51817 .82275 L F
.506 .32 .562 r
.51107 .82606 m .5124 .82585 L .51297 .82246 L F
.299 .137 .486 r
.51297 .82246 m .51484 .82236 L .51449 .82165 L F
.51297 .82246 m .5124 .82585 L .51484 .82236 L F
.681 .332 .377 r
.57523 .78618 m .57528 .78759 L .57354 .78613 L F
.065 .588 .873 r
.57709 .78816 m .57523 .78618 L .57729 .78559 L F
0 0 0 r
.57591 .78702 m .57436 .7889 L .57528 .78759 L F
.57436 .7889 m .57377 .78962 L .57528 .78759 L F
.065 .588 .873 r
.57583 .78682 m .57528 .78759 L .57523 .78618 L F
.57709 .78816 m .57528 .78759 L .57583 .78682 L F
.678 .189 .081 r
.51054 .82632 m .5077 .82484 L .50799 .82647 L F
.752 .694 .796 r
.59953 .78396 m .60345 .78491 L .59935 .78417 L F
.267 0 .251 r
.60049 .78052 m .60062 .78301 L .59747 .78306 L F
.60062 .78301 m .6003 .78329 L .59747 .78306 L F
.535 .405 .65 r
.6003 .78329 m .59959 .78346 L .59747 .78306 L F
.752 .694 .796 r
.602 .78182 m .60345 .78491 L .5999 .78405 L F
.60062 .78301 m .5999 .78405 L .59953 .78396 L F
.602 .78182 m .5999 .78405 L .60062 .78301 L F
.60167 .7815 m .602 .78182 L .6003 .78329 L F
.60178 .78136 m .60183 .78145 L .60167 .7815 L F
.60183 .78145 m .602 .78182 L .60167 .7815 L F
.686 .669 .828 r
.60412 .7812 m .60345 .78491 L .60178 .78136 L F
.606 .444 .635 r
.60151 .78156 m .60381 .78319 L .60361 .78166 L F
.057 0 .229 r
.60177 .78135 m .60062 .78301 L .60049 .78052 L F
.60178 .78136 m .60156 .78167 L .60177 .78135 L F
.60156 .78167 m .60062 .78301 L .60177 .78135 L F
.256 .052 .4 r
.60229 .77753 m .60321 .78081 L .60049 .78052 L F
.057 0 .229 r
.60178 .78136 m .60177 .78135 L .60321 .78081 L F
.60177 .78135 m .60049 .78052 L .60311 .7808 L F
.60177 .78135 m .60311 .7808 L .60321 .78081 L F
.722 .627 .751 r
.60188 .77989 m .60138 .78151 L .60293 .77959 L F
.60138 .78151 m .60137 .78155 L .60141 .7815 L F
.60138 .78151 m .60141 .7815 L .60293 .77959 L F
.278 .064 .399 r
.60445 .77914 m .60408 .77963 L .60258 .77857 L F
.60408 .77963 m .60321 .78081 L .60312 .7805 L F
.60408 .77963 m .60312 .7805 L .60258 .77857 L F
.386 0 0 r
.60772 .77982 m .60336 .77846 L .60739 .7774 L F
.60772 .77982 m .60455 .77917 L .60336 .77846 L F
.278 .064 .399 r
.60372 .78019 m .60321 .78081 L .60445 .77914 L F
.649 .533 .708 r
.60349 .77889 m .60355 .78028 L .60365 .7802 L F
.60425 .77948 m .60411 .78019 L .60448 .77966 L F
.60411 .78019 m .60438 .77995 L .60448 .77966 L F
.278 .064 .399 r
.60449 .77915 m .60372 .78019 L .60445 .77914 L F
.60383 .78005 m .60372 .78019 L .60449 .77915 L F
.649 .533 .708 r
.60349 .77889 m .60366 .78027 L .60425 .77948 L F
.678 .582 .741 r
.60357 .78067 m .60412 .7812 L .60287 .78128 L F
.60438 .77995 m .60427 .78046 L .60357 .78067 L F
.60427 .78046 m .60412 .7812 L .60357 .78067 L F
.669 .548 .708 r
.60272 .78162 m .60361 .78166 L .60357 .78067 L F
.60334 .78073 m .60357 .78067 L .60356 .78042 L F
.60272 .78162 m .60357 .78067 L .60334 .78073 L F
.649 .533 .708 r
.60366 .78027 m .60384 .78163 L .60425 .77948 L F
.60425 .77948 m .60448 .77966 L .60448 .77947 L F
.678 .582 .741 r
.60455 .77917 m .60448 .77947 L .6044 .77928 L F
.649 .533 .708 r
.60442 .77932 m .60448 .77947 L .60449 .77926 L F
.60425 .77948 m .60448 .77947 L .60442 .77932 L F
.278 .064 .399 r
.60455 .77917 m .60383 .78005 L .60449 .77915 L F
.678 .582 .741 r
.60323 .78046 m .60178 .78136 L .60266 .78102 L F
.60372 .78019 m .60266 .78102 L .60321 .78081 L F
.60383 .78005 m .60355 .78028 L .60372 .78019 L F
.60355 .78028 m .60266 .78102 L .60372 .78019 L F
.669 .548 .708 r
.60294 .78085 m .60356 .78042 L .60355 .78028 L F
.60301 .78058 m .60355 .78028 L .60349 .77889 L F
.678 .582 .741 r
.60455 .77917 m .60266 .78102 L .60383 .78005 L F
.669 .548 .708 r
.60294 .78085 m .60355 .78028 L .60301 .78058 L F
.60334 .78073 m .60356 .78042 L .60294 .78085 L F
.678 .582 .741 r
.60246 .78099 m .60287 .78128 L .60178 .78136 L F
.60438 .77995 m .60357 .78067 L .60246 .78099 L F
.60357 .78067 m .60287 .78128 L .60246 .78099 L F
.669 .548 .708 r
.60137 .78155 m .60272 .78162 L .60294 .78085 L F
.678 .582 .741 r
.60212 .78109 m .60178 .78136 L .60323 .78046 L F
.669 .548 .708 r
.60219 .78107 m .60294 .78085 L .60301 .78058 L F
.678 .582 .741 r
.60212 .78109 m .60214 .78108 L .60178 .78136 L F
.669 .548 .708 r
.60137 .78155 m .60294 .78085 L .60219 .78107 L F
.60272 .78162 m .60334 .78073 L .60294 .78085 L F
.678 .582 .741 r
.60455 .77917 m .60212 .78109 L .60323 .78046 L F
.6044 .77928 m .6044 .77935 L .60214 .78108 L F
.669 .548 .708 r
.60142 .78148 m .60301 .78058 L .60349 .77889 L F
.678 .582 .741 r
.6044 .77928 m .60214 .78108 L .60212 .78109 L F
.669 .548 .708 r
.60137 .78155 m .60301 .78058 L .60142 .78148 L F
.678 .582 .741 r
.6044 .77935 m .60438 .77995 L .60363 .78036 L F
.6044 .77935 m .60363 .78036 L .60178 .78136 L F
.60448 .77947 m .60438 .77995 L .6044 .77928 L F
.649 .533 .708 r
.60411 .78019 m .60384 .78163 L .60438 .77995 L F
.60365 .7802 m .60361 .78166 L .60384 .78163 L F
.60355 .78028 m .60361 .78166 L .60365 .7802 L F
.828 .667 .683 r
.60772 .77982 m .60443 .78108 L .60452 .77951 L F
.60443 .78108 m .60412 .7812 L .60448 .77947 L F
.60443 .78108 m .60448 .77947 L .60455 .77917 L F
.686 .669 .828 r
.60412 .7812 m .60569 .78461 L .60345 .78491 L F
.828 .667 .683 r
.60772 .77982 m .60787 .78213 L .60412 .7812 L F
.589 .392 .582 r
.60787 .78213 m .60569 .78461 L .60412 .7812 L F
.649 .533 .708 r
.60448 .77966 m .60384 .78163 L .60654 .78126 L F
.828 .667 .683 r
.60463 .77918 m .60452 .77951 L .60455 .77917 L F
.60772 .77982 m .60452 .77951 L .60463 .77918 L F
.649 .533 .708 r
.60449 .77926 m .60654 .78126 L .60523 .7786 L F
.60448 .77966 m .60654 .78126 L .60449 .77926 L F
.60523 .7786 m .60654 .78126 L .60561 .77853 L F
.339 .247 .602 r
.60336 .77846 m .603 .77736 L .60445 .77496 L F
.68 .495 .629 r
.60743 .77511 m .60336 .77846 L .60445 .77496 L F
.60743 .77511 m .60739 .7774 L .60336 .77846 L F
.278 .064 .399 r
.60454 .77916 m .60229 .77753 L .60336 .77846 L F
.60455 .77917 m .60454 .77916 L .60454 .77916 L F
.60454 .77916 m .60229 .77753 L .60454 .77916 L F
.60281 .77791 m .60258 .77857 L .60229 .77753 L F
.60455 .77917 m .60258 .77857 L .60281 .77791 L F
.655 .506 .67 r
.60234 .77531 m .60229 .77753 L .60025 .77794 L F
.256 .052 .4 r
.60229 .77753 m .60049 .78052 L .60025 .77794 L F
.339 .247 .602 r
.60336 .77846 m .60229 .77753 L .60234 .77531 L F
.675 .526 .674 r
.60039 .77614 m .60349 .77889 L .60308 .77751 L F
.60188 .77616 m .60308 .77751 L .60268 .77616 L F
.60039 .77614 m .60308 .77751 L .60188 .77616 L F
.649 .533 .708 r
.60349 .77889 m .60425 .77948 L .60523 .7786 L F
.339 .247 .602 r
.603 .77736 m .60234 .77531 L .6038 .77507 L F
.603 .77736 m .6038 .77507 L .60445 .77496 L F
.722 .627 .751 r
.60332 .779 m .60293 .77959 L .60349 .77889 L F
.60188 .77989 m .60293 .77959 L .60332 .779 L F
.606 .444 .635 r
.60137 .78155 m .60142 .78158 L .60151 .78156 L F
.752 .694 .796 r
.60178 .78136 m .6003 .78329 L .6002 .78333 L F
.60069 .78262 m .6002 .78333 L .60002 .7834 L F
.60178 .78136 m .6002 .78333 L .60069 .78262 L F
.669 .64 .811 r
.60314 .78643 m .59935 .78417 L .60345 .78491 L F
.521 .381 .631 r
.60109 .78204 m .59973 .78434 L .59981 .78431 L F
.60137 .78155 m .60101 .78216 L .60109 .78204 L F
.60077 .78257 m .59973 .78434 L .60078 .78256 L F
.057 0 .229 r
.60168 .7815 m .60121 .78232 L .60062 .78301 L F
.60178 .78136 m .60165 .78158 L .60168 .7815 L F
.60165 .78158 m .60064 .78332 L .60168 .7815 L F
.752 .694 .796 r
.60178 .78136 m .60069 .78262 L .60126 .78224 L F
.057 0 .229 r
.60121 .78232 m .60063 .78315 L .60062 .78301 L F
.521 .381 .631 r
.60137 .78155 m .60038 .78329 L .60142 .78203 L F
.60038 .78329 m .59981 .78431 L .60063 .78315 L F
.267 0 .251 r
.60062 .78301 m .60063 .78315 L .6003 .78329 L F
.60063 .78315 m .60038 .7833 L .6003 .78329 L F
.521 .381 .631 r
.60038 .78329 m .60063 .78315 L .60142 .78203 L F
.267 0 .251 r
.60063 .78315 m .60064 .78332 L .60038 .7833 L F
.521 .381 .631 r
.60142 .78203 m .59981 .78431 L .60158 .78366 L F
.057 0 .229 r
.60121 .78232 m .60064 .78332 L .60063 .78315 L F
.752 .694 .796 r
.60002 .7834 m .6003 .78329 L .59953 .78396 L F
.60002 .7834 m .59935 .78417 L .59952 .78406 L F
.535 .405 .65 r
.59959 .78346 m .59771 .78391 L .59766 .78372 L F
.59959 .78346 m .59766 .78372 L .59747 .78306 L F
.5998 .78349 m .59771 .78391 L .6003 .78329 L F
.59982 .78348 m .59935 .78417 L .59771 .78391 L F
.698 .601 .745 r
.59956 .78401 m .59973 .78434 L .60033 .78331 L F
.60008 .78339 m .60033 .78331 L .60077 .78257 L F
.59956 .78401 m .60033 .78331 L .60008 .78339 L F
.535 .405 .65 r
.60008 .78339 m .5998 .78349 L .60002 .7834 L F
.752 .694 .796 r
.60009 .78339 m .59956 .78401 L .60064 .78332 L F
.535 .405 .65 r
.60064 .78332 m .59982 .78348 L .60008 .78339 L F
.59982 .78348 m .5998 .78349 L .60008 .78339 L F
.695 .6 .746 r
.59926 .78436 m .59973 .78434 L .59956 .78401 L F
.752 .694 .796 r
.59956 .78401 m .59952 .78406 L .59952 .78406 L F
.59956 .78401 m .59952 .78406 L .60064 .78332 L F
.60002 .7834 m .59952 .78406 L .60009 .78339 L F
.535 .405 .65 r
.60064 .78332 m .59952 .78406 L .59982 .78348 L F
.59952 .78406 m .59935 .78417 L .59982 .78348 L F
.698 .601 .745 r
.60086 .7815 m .59956 .78401 L .60137 .78155 L F
.59811 .78122 m .59955 .784 L .60086 .7815 L F
.59955 .784 m .59956 .78401 L .60086 .7815 L F
.59956 .78401 m .60077 .78257 L .60137 .78155 L F
.572 .586 .828 r
.59771 .78391 m .59893 .78774 L .59692 .78803 L F
.535 .562 .829 r
.60116 .78738 m .59893 .78774 L .59771 .78391 L F
.60116 .78738 m .59771 .78391 L .59927 .78415 L F
.59938 .78422 m .59927 .78415 L .59935 .78417 L F
.60116 .78738 m .59927 .78415 L .59938 .78422 L F
.669 .64 .811 r
.60314 .78643 m .60116 .78738 L .59935 .78417 L F
.645 .485 .651 r
.59718 .78445 m .59935 .78632 L .59971 .78441 L F
.5996 .78435 m .59971 .78441 L .59973 .78434 L F
.59718 .78445 m .59971 .78441 L .5996 .78435 L F
.695 .6 .746 r
.59718 .78445 m .59926 .78436 L .59811 .78122 L F
.59926 .78436 m .59956 .78401 L .59811 .78122 L F
.535 .405 .65 r
.60064 .78332 m .60002 .7834 L .6003 .78329 L F
.752 .694 .796 r
.60126 .78224 m .60002 .7834 L .60064 .78332 L F
.60069 .78262 m .60002 .7834 L .60126 .78224 L F
.521 .381 .631 r
.60101 .78216 m .60077 .78257 L .60109 .78204 L F
.60077 .78257 m .60078 .78256 L .60109 .78204 L F
.606 .444 .635 r
.60142 .78158 m .60161 .78171 L .60151 .78156 L F
.60161 .78171 m .60381 .78319 L .60163 .78164 L F
.60161 .78171 m .60163 .78164 L .60151 .78156 L F
0 0 .166 r
.5714 .82933 m .57096 .82943 L .57172 .82851 L F
.917 .849 .402 r
.57036 .83195 m .57118 .82994 L .57096 .82943 L F
0 0 .166 r
.57036 .83195 m .57096 .82943 L .5714 .82933 L F
.307 .573 .934 r
.57118 .82994 m .57051 .82953 L .57096 .82943 L F
.57051 .82953 m .56753 .82772 L .57096 .82943 L F
0 0 0 r
.57036 .83195 m .56972 .83267 L .57118 .82994 L F
.826 .708 .175 r
.60957 .78096 m .60939 .78277 L .60926 .7823 L F
.60957 .78096 m .60926 .7823 L .61114 .78021 L F
.81 .876 .895 r
.53177 .82131 m .53273 .81907 L .53393 .81966 L F
.857 .71 .699 r
.5343 .82235 m .53067 .82335 L .53177 .82131 L F
.644 .511 .686 r
.53393 .81966 m .5343 .82235 L .53177 .82131 L F
.762 .662 .752 r
.56936 .80081 m .56741 .80451 L .56755 .80363 L F
.371 0 0 r
.3973 .85131 m .39557 .85269 L .39363 .85268 L F
.536 .373 .607 r
.39909 .84799 m .39906 .85112 L .3973 .85131 L F
.824 .98 .689 r
.39774 .84975 m .3973 .85131 L .39906 .85112 L F
.39774 .84975 m .39557 .85269 L .3973 .85131 L F
.284 0 0 r
.49953 .81278 m .49989 .81354 L .49621 .81357 L F
.783 .693 .764 r
.50186 .80932 m .49953 .81278 L .49846 .80954 L F
0 0 .299 r
.49975 .81325 m .49953 .81278 L .50202 .81377 L F
.49975 .81325 m .49989 .81354 L .49953 .81278 L F
.624 .905 .984 r
.56167 .77693 m .55973 .77778 L .56047 .77666 L F
.56047 .77666 m .55973 .77778 L .56167 .77693 L F
.571 .622 .864 r
.52574 .8478 m .52426 .8486 L .52308 .84752 L F
.552 .325 .525 r
.66122 .75952 m .66121 .76224 L .65878 .76241 L F
.446 .212 .464 r
.66304 .75874 m .66121 .76224 L .66122 .75952 L F
.363 .692 .982 r
.36347 .73805 m .36537 .73813 L .36473 .73905 L F
.414 .757 .995 r
.36537 .73813 m .36661 .73884 L .36473 .73905 L F
.597 .54 .761 r
.36782 .74201 m .36473 .73905 L .36661 .73884 L F
.645 .246 .275 r
.57991 .84571 m .58202 .84725 L .57879 .84746 L F
0 0 0 r
.46085 .88375 m .46217 .8831 L .46008 .88376 L F
.46085 .88375 m .46353 .88231 L .46217 .8831 L F
.506 .738 .978 r
.39101 .85981 m .39408 .86086 L .39309 .85978 L F
.39309 .85978 m .39408 .86086 L .39101 .85981 L F
.189 .552 .931 r
.39408 .86086 m .39471 .8602 L .39309 .85978 L F
.39408 .86086 m .39471 .8602 L .39309 .85978 L F
.782 .794 .862 r
.58215 .76804 m .57837 .7693 L .58099 .76716 L F
.755 .847 .92 r
.58394 .76715 m .58215 .76804 L .58099 .76716 L F
.606 .45 .644 r
.38856 .85268 m .38653 .85312 L .38642 .8507 L F
.492 .285 .526 r
.59218 .83989 m .59198 .84232 L .59 .84258 L F
.483 .281 .529 r
.5942 .83748 m .59397 .83971 L .59218 .83989 L F
.386 .197 .498 r
.59393 .84211 m .59218 .83989 L .59397 .83971 L F
.59393 .84211 m .59198 .84232 L .59218 .83989 L F
0 0 .183 r
.5741 .80652 m .57304 .80934 L .57343 .80924 L F
.5741 .80652 m .57304 .80934 L .57343 .80924 L F
.439 .104 .299 r
.59 .84258 m .58935 .84461 L .58728 .84502 L F
.445 .117 .315 r
.59198 .84232 m .58935 .84461 L .59 .84258 L F
.383 0 0 r
.57823 .84007 m .57866 .83945 L .5756 .84005 L F
.335 .776 .963 r
.57963 .83892 m .57866 .83945 L .57823 .84007 L F
.57963 .83892 m .58062 .83934 L .57866 .83945 L F
.257 .442 .852 r
.35888 .73302 m .35814 .73431 L .35735 .7325 L F
.413 .644 .952 r
.35888 .73302 m .36086 .73511 L .35814 .73431 L F
.543 .307 .507 r
.36937 .77274 m .36901 .77489 L .367 .77519 L F
.514 .28 .498 r
.37098 .77453 m .36937 .77274 L .37137 .77243 L F
.37098 .77453 m .36901 .77489 L .36937 .77274 L F
.232 0 0 r
.51959 .87186 m .52079 .87174 L .51745 .8716 L F
.112 0 0 r
.52072 .87219 m .52079 .87174 L .51959 .87186 L F
.52072 .87219 m .52296 .87152 L .52079 .87174 L F
0 .222 .697 r
.55026 .81883 m .55018 .81908 L .54816 .81737 L F
0 0 .357 r
.55106 .8208 m .55018 .81908 L .55026 .81883 L F
.395 .853 .844 r
.42189 .8796 m .42012 .88024 L .41824 .88055 L F
.69 .59 .739 r
.6074 .76219 m .60535 .76264 L .60424 .75966 L F
.68 .546 .695 r
.6074 .76219 m .60534 .76475 L .60535 .76264 L F
.617 .253 .33 r
.42444 .83967 m .42322 .84199 L .42164 .84121 L F
.204 .73 .826 r
.42682 .83934 m .42531 .83937 L .42444 .83967 L F
.59 .224 .316 r
.42651 .84166 m .42444 .83967 L .42531 .83937 L F
.42651 .84166 m .42322 .84199 L .42444 .83967 L F
.546 .294 .486 r
.6289 .77289 m .63103 .77449 L .62879 .7747 L F
.6289 .77289 m .63111 .77262 L .63103 .77449 L F
.701 .734 .877 r
.42923 .87653 m .43174 .87786 L .43033 .878 L F
.395 .453 .803 r
.43326 .87577 m .43174 .87786 L .43198 .87599 L F
.448 .217 .47 r
.59055 .83486 m .58857 .83527 L .5883 .83731 L F
.123 .673 .755 r
.42509 .87931 m .42189 .8796 L .42409 .87924 L F
.674 .784 .932 r
.42694 .87895 m .42509 .87931 L .42528 .8776 L F
.906 .965 .812 r
.42528 .8776 m .42509 .87931 L .42409 .87924 L F
.785 .744 .816 r
.64977 .74425 m .64672 .74421 L .64893 .74305 L F
.67 .582 .747 r
.64987 .74578 m .64672 .74421 L .64977 .74425 L F
.754 .736 .836 r
.65109 .7433 m .64977 .74425 L .64893 .74305 L F
.667 .37 .46 r
.64977 .74425 m .65197 .74634 L .64987 .74578 L F
.657 .528 .695 r
.65109 .7433 m .65177 .74425 L .64977 .74425 L F
.636 .377 .509 r
.65177 .74425 m .65197 .74634 L .64977 .74425 L F
.448 .497 .817 r
.37179 .74122 m .37128 .74397 L .36983 .74164 L F
.37179 .74122 m .37306 .74427 L .37128 .74397 L F
.746 .757 .861 r
.43033 .878 m .42694 .87895 L .42923 .87653 L F
.418 .815 .984 r
.48479 .81142 m .48679 .8111 L .48907 .81184 L F
.711 .744 .878 r
.3642 .72891 m .36595 .73148 L .36255 .73074 L F
.793 .547 .565 r
.36595 .73148 m .36307 .7349 L .36255 .73074 L F
0 0 .346 r
.36651 .72795 m .36595 .73148 L .3642 .72891 L F
.36651 .72795 m .36665 .73058 L .36595 .73148 L F
.57 .833 .476 r
.36665 .73058 m .36307 .7349 L .36595 .73148 L F
.597 .658 .881 r
.49205 .86412 m .48799 .86186 L .4907 .86342 L F
.013 0 0 r
.48827 .86556 m .49205 .86412 L .4907 .86342 L F
.809 .908 .908 r
.49275 .86176 m .49205 .86412 L .4907 .86342 L F
.429 .761 .996 r
.49205 .86412 m .49272 .86307 L .4907 .86342 L F
.49205 .86412 m .49434 .86397 L .49272 .86307 L F
.373 .769 .986 r
.49205 .86412 m .49434 .86397 L .4907 .86342 L F
.678 .189 .081 r
.51054 .82632 m .51107 .82606 L .5077 .82484 L F
.659 .389 .5 r
.39171 .85073 m .39145 .85286 L .38856 .85268 L F
.614 .349 .492 r
.39363 .85268 m .39145 .85286 L .39171 .85073 L F
.783 .693 .764 r
.50186 .80932 m .49846 .80954 L .50063 .80904 L F
.55 .008 0 r
.50063 .80904 m .50372 .80934 L .50186 .80932 L F
.309 0 0 r
.50372 .80934 m .50583 .80947 L .50709 .80911 L F
.323 0 0 r
.50583 .80947 m .5095 .81011 L .50709 .80911 L F
.956 .862 .706 r
.5727 .78821 m .57354 .78613 L .57528 .78759 L F
.5727 .78821 m .57251 .7859 L .57354 .78613 L F
.638 .591 .785 r
.37848 .75486 m .37649 .75542 L .37563 .75393 L F
.62 .362 .505 r
.58557 .79846 m .58778 .79828 L .5879 .79621 L F
.671 .594 .761 r
.58732 .79279 m .5879 .79621 L .58983 .79586 L F
.666 .75 .913 r
.58983 .79586 m .5879 .79621 L .59118 .79593 L F
.669 .416 .53 r
.59118 .79593 m .58778 .79828 L .5879 .79621 L F
.396 0 .051 r
.44241 .83461 m .44135 .83537 L .43944 .83553 L F
.422 0 .074 r
.44469 .83447 m .44135 .83537 L .44241 .83461 L F
.112 .016 .456 r
.56753 .82772 m .56906 .82416 L .56916 .8263 L F
.437 .498 .824 r
.56916 .8263 m .57096 .82943 L .56753 .82772 L F
.332 0 .019 r
.47507 .81604 m .47707 .81574 L .47838 .81422 L F
0 0 0 r
.48076 .8126 m .47838 .81422 L .47996 .81332 L F
.141 0 0 r
.47838 .81422 m .47892 .8151 L .47996 .81332 L F
.47838 .81422 m .47707 .81574 L .47892 .8151 L F
.586 .654 .884 r
.40052 .85363 m .40086 .85128 L .39906 .85112 L F
.40052 .85363 m .40285 .85337 L .40086 .85128 L F
.538 .278 .469 r
.40052 .85363 m .40218 .85521 L .40285 .85337 L F
.40285 .85337 m .40218 .85521 L .40052 .85363 L F
0 0 .214 r
.48799 .86186 m .48684 .86371 L .4875 .86336 L F
.181 .227 .674 r
.4875 .86336 m .48684 .86371 L .48827 .86556 L F
.493 .317 .57 r
.48684 .86371 m .48659 .86615 L .48827 .86556 L F
.766 .329 .213 r
.48492 .83558 m .4818 .83443 L .48289 .83541 L F
.541 .022 0 r
.48833 .8356 m .48766 .83674 L .48492 .83558 L F
.461 .254 .511 r
.48833 .8356 m .49075 .83646 L .48766 .83674 L F
.238 .738 .669 r
.51612 .87812 m .51739 .87767 L .51533 .87844 L F
.51612 .87812 m .51894 .87712 L .51739 .87767 L F
.402 .005 .169 r
.52531 .87373 m .52631 .87202 L .52843 .87175 L F
.475 .162 .355 r
.37789 .76812 m .37527 .77151 L .37658 .76839 L F
.675 .384 .472 r
.6564 .76239 m .65879 .76457 L .65659 .764 L F
.645 .393 .523 r
.65878 .76241 m .65879 .76457 L .6564 .76239 L F
.452 .873 .935 r
.38922 .82982 m .38738 .83041 L .38517 .83023 L F
.688 .556 .701 r
.6074 .76219 m .60837 .76521 L .60534 .76475 L F
.668 .551 .712 r
.60862 .76744 m .60534 .76475 L .60837 .76521 L F
.60862 .76744 m .60638 .76773 L .60534 .76475 L F
.576 .293 .45 r
.50434 .8354 m .50642 .83688 L .50657 .83504 L F
.50434 .8354 m .50419 .8372 L .50642 .83688 L F
.684 .639 .799 r
.53225 .86578 m .53097 .86861 L .5309 .86716 L F
.53225 .86578 m .53243 .86792 L .53097 .86861 L F
.358 .005 .222 r
.53097 .86861 m .53283 .86884 L .53019 .87084 L F
.53097 .86861 m .53243 .86792 L .53283 .86884 L F
0 0 .095 r
.56917 .83489 m .56972 .83267 L .57036 .83195 L F
.72 .702 .833 r
.65143 .75042 m .6484 .75127 L .65003 .751 L F
.601 .406 .589 r
.6484 .75127 m .65166 .75475 L .65003 .751 L F
.6484 .75127 m .64906 .75515 L .65166 .75475 L F
.762 .375 .322 r
.51829 .82574 m .5158 .82466 L .51596 .82663 L F
.821 .851 .87 r
.5168 .82376 m .51829 .82574 L .51596 .82663 L F
.454 .014 .112 r
.51596 .82663 m .51829 .82574 L .51664 .82787 L F
.77 .558 .612 r
.51901 .82954 m .51972 .82757 L .51829 .82574 L F
0 0 0 r
.51664 .82787 m .51829 .82574 L .51875 .82566 L F
.144 .452 .883 r
.50077 .82909 m .50359 .82765 L .50027 .82792 L F
.568 .574 .819 r
.59978 .82965 m .59993 .83117 L .59833 .83202 L F
.401 .184 .467 r
.59993 .83117 m .59833 .83436 L .59833 .83202 L F
.657 .948 .955 r
.39324 .90078 m .39484 .90081 L .39661 .89985 L F
.776 .497 .513 r
.46105 .87365 m .45791 .87095 L .45897 .87387 L F
.248 0 0 r
.4595 .87458 m .45897 .87387 L .45781 .8759 L F
.4595 .87458 m .46105 .87365 L .45897 .87387 L F
.58 .487 .714 r
.39009 .74511 m .392 .74408 L .39005 .74436 L F
.489 .018 .062 r
.44637 .82083 m .44848 .82103 L .44982 .81974 L F
.529 .097 .164 r
.44848 .82103 m .45186 .81972 L .44982 .81974 L F
.565 .903 .978 r
.37496 .83272 m .37448 .83378 L .37313 .83401 L F
.37496 .83272 m .37665 .83313 L .37448 .83378 L F
.375 .147 .435 r
.5963 .83744 m .59397 .83971 L .5942 .83748 L F
.771 .925 .557 r
.65983 .75253 m .66045 .75116 L .66162 .75169 L F
.65983 .75253 m .65867 .75379 L .66045 .75116 L F
.709 .632 .769 r
.60639 .75697 m .60754 .76006 L .60424 .75966 L F
.69 .59 .739 r
.6074 .76219 m .60424 .75966 L .60754 .76006 L F
.721 .638 .765 r
.60953 .75951 m .60754 .76006 L .60639 .75697 L F
.701 .566 .699 r
.60953 .75951 m .6074 .76219 L .60754 .76006 L F
.44 0 0 r
.53615 .80596 m .53755 .80662 L .53866 .80688 L F
0 .222 .686 r
.54014 .80768 m .53866 .80688 L .53755 .80662 L F
.54014 .80768 m .54105 .8085 L .53866 .80688 L F
.755 .847 .92 r
.58394 .76715 m .58099 .76716 L .58274 .76609 L F
.782 .824 .885 r
.58641 .76493 m .58394 .76715 L .58274 .76609 L F
.575 .405 .613 r
.5868 .79075 m .58916 .78814 L .58696 .78851 L F
.551 .399 .628 r
.58732 .79279 m .58892 .79047 L .5868 .79075 L F
.721 .638 .765 r
.60953 .75951 m .60639 .75697 L .60836 .75671 L F
.701 .566 .699 r
.60953 .75951 m .61047 .76242 L .6074 .76219 L F
.702 .647 .792 r
.61173 .75697 m .60953 .75951 L .60836 .75671 L F
.668 .594 .763 r
.61173 .75697 m .61253 .75985 L .60953 .75951 L F
.634 .528 .716 r
.61275 .76218 m .60953 .75951 L .61253 .75985 L F
.61275 .76218 m .61047 .76242 L .60953 .75951 L F
.457 .825 .57 r
.50674 .88354 m .50789 .88259 L .50578 .88347 L F
.778 .672 .746 r
.64266 .74701 m .64225 .74942 L .63915 .74881 L F
.793 .618 .665 r
.64225 .74942 m .64046 .75193 L .63915 .74881 L F
.693 .48 .594 r
.64243 .75183 m .64046 .75193 L .64225 .74942 L F
.604 .431 .62 r
.64465 .74675 m .64225 .74942 L .64266 .74701 L F
.64465 .74675 m .6451 .74917 L .64225 .74942 L F
.669 .515 .666 r
.6451 .74917 m .64243 .75183 L .64225 .74942 L F
.665 .27 .287 r
.57222 .79785 m .57497 .79892 L .57511 .79774 L F
.292 .647 .968 r
.57602 .79716 m .5774 .79817 L .57511 .79774 L F
.57602 .79716 m .57511 .79774 L .57497 .79892 L F
0 0 0 r
.49941 .88629 m .50051 .88616 L .49857 .88672 L F
.49941 .88629 m .50145 .88578 L .50051 .88616 L F
.441 0 .015 r
.41761 .82592 m .4197 .82597 L .42115 .82468 L F
.432 0 .058 r
.4197 .82597 m .42321 .82447 L .42115 .82468 L F
.65 .515 .685 r
.60651 .77006 m .60442 .77268 L .60428 .77042 L F
.659 .5 .658 r
.60862 .76744 m .60651 .77006 L .60638 .76773 L F
.801 .653 .699 r
.56936 .80081 m .56755 .80363 L .56685 .80102 L F
.684 .848 .432 r
.57808 .78209 m .57762 .78313 L .57909 .78056 L F
0 .167 .697 r
.57808 .78209 m .57945 .78511 L .57762 .78313 L F
.83 .511 .45 r
.51596 .82663 m .5146 .82866 L .51412 .82678 L F
.454 .014 .112 r
.51596 .82663 m .51664 .82787 L .5146 .82866 L F
.595 .368 .542 r
.51412 .82678 m .51664 .82787 L .51687 .82725 L F
.51673 .82608 m .51687 .82725 L .51736 .82591 L F
.821 .851 .87 r
.51649 .82404 m .51596 .82663 L .5158 .82466 L F
.51656 .82459 m .51596 .82663 L .51649 .82404 L F
.595 .368 .542 r
.51412 .82678 m .51687 .82725 L .51673 .82608 L F
.821 .851 .87 r
.5168 .82376 m .51656 .82459 L .51649 .82404 L F
.398 .829 .957 r
.40398 .89792 m .40758 .89782 L .40609 .89747 L F
.637 .918 .979 r
.40609 .89747 m .40758 .89782 L .40916 .89695 L F
.639 .529 .713 r
.61067 .7648 m .6074 .76219 L .61047 .76242 L F
.61067 .7648 m .60837 .76521 L .6074 .76219 L F
0 .476 .833 r
.4757 .88253 m .47766 .88347 L .4793 .88396 L F
0 .377 .805 r
.5452 .81172 m .54182 .80967 L .54445 .81098 L F
.042 .227 .728 r
.54445 .81098 m .54563 .81397 L .5452 .81172 L F
0 .213 .737 r
.54753 .81586 m .54706 .81643 L .54563 .81397 L F
0 .257 .767 r
.54753 .81586 m .54816 .81737 L .54706 .81643 L F
.541 .225 .382 r
.64589 .76678 m .64585 .76537 L .6487 .76454 L F
.369 0 .111 r
.5249 .80568 m .52574 .80584 L .52728 .80454 L F
.412 .002 .15 r
.52728 .80454 m .52574 .80584 L .5295 .80447 L F
.594 .374 .552 r
.57052 .77764 m .5726 .77999 L .57353 .77802 L F
.177 0 0 r
.57052 .77764 m .57353 .77802 L .56978 .77769 L F
.57052 .77764 m .57353 .77802 L .56978 .77769 L F
.453 0 0 r
.51159 .81792 m .51029 .81871 L .5083 .81838 L F
.335 0 0 r
.51365 .81739 m .51029 .81871 L .51159 .81792 L F
0 0 0 r
.52083 .87635 m .52359 .87373 L .52265 .87567 L F
.258 0 .119 r
.52265 .87567 m .52359 .87373 L .52531 .87373 L F
.612 .132 .088 r
.46548 .88133 m .46878 .88147 L .46738 .88208 L F
.448 0 0 r
.46878 .88147 m .46953 .88244 L .46738 .88208 L F
.46878 .88147 m .4707 .88194 L .46953 .88244 L F
.869 .492 .009 r
.55266 .80151 m .55205 .80101 L .55113 .79828 L F
.743 .289 0 r
.55266 .80151 m .55384 .80343 L .55205 .80101 L F
.777 .684 .761 r
.54468 .82158 m .54767 .82206 L .54501 .82493 L F
.737 .72 .835 r
.55249 .79449 m .5488 .79387 L .55133 .794 L F
.199 .662 .941 r
.55371 .79417 m .55249 .79449 L .55133 .794 L F
.55371 .79417 m .55521 .79489 L .55249 .79449 L F
.755 .844 .918 r
.57343 .80924 m .577 .80875 L .57446 .80993 L F
.15 0 .265 r
.57851 .80858 m .577 .80875 L .57922 .80583 L F
.674 .784 .932 r
.42694 .87895 m .42528 .8776 L .42591 .87608 L F
.714 .69 .826 r
.42923 .87653 m .42694 .87895 L .42591 .87608 L F
.708 .746 .239 r
.54907 .82707 m .54907 .82721 L .54902 .82723 L F
.325 0 0 r
.54907 .82721 m .5496 .82793 L .54902 .82723 L F
.54907 .82721 m .55098 .82733 L .5496 .82793 L F
.754 .736 .836 r
.65109 .7433 m .64893 .74305 L .6506 .74193 L F
.583 .142 .168 r
.6506 .74193 m .65447 .74176 L .65109 .7433 L F
.705 .699 .841 r
.65447 .74176 m .65177 .74425 L .65109 .7433 L F
.424 .094 .3 r
.58524 .84547 m .58646 .8474 L .58416 .84733 L F
.58524 .84547 m .58728 .84502 L .58646 .8474 L F
.57 .769 .973 r
.59893 .7597 m .59552 .7591 L .59855 .75709 L F
.763 .738 .83 r
.60135 .7576 m .59893 .7597 L .59855 .75709 L F
.719 .648 .778 r
.60108 .75867 m .59893 .7597 L .60135 .7576 L F
.519 .36 .605 r
.67239 .74924 m .67255 .7517 L .67053 .75235 L F
.547 .273 .452 r
.67255 .7517 m .66995 .75382 L .67053 .75235 L F
.283 0 .039 r
.48076 .8126 m .48219 .81261 L .4829 .812 L F
.48076 .8126 m .47996 .81332 L .48219 .81261 L F
.415 0 .1 r
.45522 .83219 m .45404 .83418 L .4514 .83443 L F
.463 .027 .125 r
.45605 .83382 m .45522 .83219 L .45734 .83194 L F
.45605 .83382 m .45404 .83418 L .45522 .83219 L F
.595 .883 .992 r
.49008 .83909 m .48942 .84023 L .49154 .8396 L F
.49008 .83909 m .48942 .84023 L .49154 .8396 L F
.782 .788 .858 r
.58321 .78988 m .58696 .78851 L .58548 .78785 L F
.74 .674 .786 r
.60303 .7564 m .60393 .75777 L .60135 .7576 L F
.718 .577 .696 r
.60393 .75777 m .60108 .75867 L .60135 .7576 L F
.60393 .75777 m .60424 .75966 L .60108 .75867 L F
.663 .649 .825 r
.60639 .75697 m .60393 .75777 L .60303 .7564 L F
.63 .516 .706 r
.60639 .75697 m .60424 .75966 L .60393 .75777 L F
.215 .702 .927 r
.64118 .74619 m .64465 .74675 L .64266 .74701 L F
.083 .212 .7 r
.64465 .74675 m .64555 .74561 L .64672 .74421 L F
.64555 .74561 m .64561 .74552 L .64567 .74546 L F
.64555 .74561 m .64567 .74546 L .64672 .74421 L F
.595 .593 .819 r
.64241 .74295 m .64527 .74595 L .64118 .74619 L F
.652 .576 .757 r
.64805 .74618 m .64465 .74675 L .64672 .74421 L F
.083 .212 .7 r
.64465 .74675 m .64571 .74642 L .64561 .74552 L F
.595 .593 .819 r
.64527 .74595 m .64571 .74642 L .64492 .74638 L F
.64527 .74595 m .64492 .74638 L .64118 .74619 L F
.215 .702 .927 r
.64118 .74619 m .64571 .74642 L .64465 .74675 L F
.491 .355 .623 r
.64712 .7486 m .64465 .74675 L .64805 .74618 L F
.64712 .7486 m .6451 .74917 L .64465 .74675 L F
.358 .821 .918 r
.49318 .81356 m .49224 .81394 L .49124 .81232 L F
.591 .418 .616 r
.57372 .78052 m .57592 .78059 L .5758 .7778 L F
.579 .324 .495 r
.57314 .78193 m .57592 .78059 L .57372 .78052 L F
0 0 0 r
.5758 .7778 m .57678 .77757 L .57476 .777 L F
.5758 .7778 m .57828 .77697 L .57678 .77757 L F
.663 .393 .501 r
.65003 .751 m .65354 .74945 L .65143 .75042 L F
.413 .071 .274 r
.51352 .82609 m .51107 .82606 L .51054 .82632 L F
.51352 .82609 m .5124 .82585 L .51107 .82606 L F
.819 .449 .354 r
.5727 .78821 m .57151 .78994 L .57172 .78864 L F
.956 .862 .706 r
.5727 .78821 m .57172 .78864 L .57251 .7859 L F
.418 0 .106 r
.57377 .78962 m .5727 .78821 L .57528 .78759 L F
.57377 .78962 m .57151 .78994 L .5727 .78821 L F
.623 .456 .635 r
.61275 .76218 m .61067 .7648 L .61047 .76242 L F
0 0 0 r
.3943 .82869 m .39232 .82919 L .39131 .8297 L F
0 0 .178 r
.5911 .83255 m .59055 .83486 L .59166 .83184 L F
0 0 0 r
.44512 .87621 m .44756 .87406 L .44716 .87592 L F
.289 0 .261 r
.44716 .87592 m .44756 .87406 L .44962 .87354 L F
.667 .607 .779 r
.60574 .79089 m .60794 .7907 L .60744 .78791 L F
.556 .07 0 r
.60574 .79089 m .60628 .79149 L .60685 .79221 L F
.60628 .79149 m .60764 .79305 L .60685 .79221 L F
.976 .916 .667 r
.60685 .79221 m .60764 .79305 L .6062 .79555 L F
0 0 .28 r
.6072 .79265 m .60685 .79221 L .60692 .79453 L F
.647 .445 .595 r
.60574 .79089 m .60764 .79305 L .60794 .7907 L F
0 0 .28 r
.60741 .79125 m .60685 .79221 L .6072 .79265 L F
.556 .07 0 r
.60574 .79089 m .60685 .79221 L .60794 .7907 L F
.655 .511 .675 r
.60442 .77268 m .60445 .77496 L .60234 .77531 L F
.562 .918 .957 r
.6279 .76311 m .63126 .76207 L .63198 .7624 L F
.375 .819 .948 r
.63198 .7624 m .63126 .76207 L .63413 .76202 L F
.705 .699 .841 r
.65447 .74176 m .65532 .74409 L .65177 .74425 L F
.575 .332 .511 r
.65541 .74554 m .65177 .74425 L .65532 .74409 L F
.818 .755 .793 r
.65727 .74162 m .65532 .74409 L .65447 .74176 L F
0 0 .048 r
.65727 .74162 m .65696 .74256 L .65532 .74409 L F
.65696 .74256 m .65662 .74359 L .6559 .74387 L F
.65696 .74256 m .6559 .74387 L .65532 .74409 L F
.331 .501 .876 r
.65739 .73926 m .65879 .741 L .65727 .74162 L F
.65757 .74186 m .65727 .74162 L .65757 .74188 L F
.65739 .73926 m .65728 .74145 L .65752 .74112 L F
.65752 .74112 m .65727 .74162 L .65757 .74186 L F
.65728 .74145 m .65727 .74162 L .65752 .74112 L F
.513 .159 .304 r
.65504 .74063 m .65739 .73926 L .65756 .74181 L F
.785 .692 .761 r
.65504 .74063 m .65769 .74089 L .65765 .74049 L F
.65769 .74089 m .65879 .741 L .6579 .7406 L F
.65769 .74089 m .6579 .7406 L .65765 .74049 L F
.013 0 .074 r
.65806 .7413 m .65757 .74186 L .65727 .74162 L F
.513 .159 .304 r
.65753 .74186 m .65756 .74181 L .65757 .74186 L F
.65756 .74187 m .65757 .74186 L .65757 .74188 L F
.013 0 .074 r
.65787 .74211 m .65662 .74359 L .6571 .74213 L F
.65757 .74187 m .6571 .74213 L .65727 .74162 L F
.346 0 0 r
.65757 .74188 m .65727 .74162 L .65447 .74176 L F
.532 .803 .995 r
.65756 .74187 m .65757 .74188 L .65755 .74188 L F
.013 0 .074 r
.65787 .74211 m .6571 .74213 L .65757 .74187 L F
.532 .803 .995 r
.65753 .74186 m .65756 .74187 L .6575 .74188 L F
.65756 .74187 m .65755 .74188 L .6575 .74188 L F
.513 .159 .304 r
.65753 .74186 m .65757 .74186 L .65756 .74187 L F
.013 0 .074 r
.65879 .741 m .65787 .74211 L .65757 .74186 L F
.65879 .741 m .65757 .74186 L .65806 .7413 L F
.513 .159 .304 r
.65504 .74063 m .65756 .74181 L .65753 .74186 L F
.532 .803 .995 r
.65504 .74063 m .65753 .74186 L .65447 .74176 L F
.65753 .74186 m .6575 .74188 L .65447 .74176 L F
0 0 .048 r
.65662 .74245 m .65662 .74359 L .65532 .74409 L F
.65727 .74162 m .6571 .74213 L .65662 .74245 L F
.6571 .74213 m .65662 .74359 L .65662 .74245 L F
.903 .917 .82 r
.65662 .74359 m .65541 .74554 L .65532 .74409 L F
.669 .416 .53 r
.59118 .79593 m .59061 .798 L .58778 .79828 L F
0 0 .151 r
.59118 .79593 m .5919 .79305 L .58983 .79586 L F
.713 .461 .543 r
.59118 .79593 m .59328 .79809 L .59061 .798 L F
.59118 .79593 m .59328 .79809 L .59061 .798 L F
.494 0 0 r
.45186 .81972 m .45377 .82051 L .45514 .81958 L F
.594 .193 .252 r
.45377 .82051 m .45714 .81912 L .45514 .81958 L F
.46 .252 .51 r
.5342 .81151 m .53421 .81379 L .53188 .81377 L F
.943 .749 .611 r
.53421 .81379 m .53228 .81425 L .53188 .81377 L F
.917 .869 .777 r
.65361 .75146 m .65617 .74982 L .65486 .7496 L F
.65361 .75146 m .6547 .75224 L .65617 .74982 L F
.12 .052 .498 r
.65747 .7464 m .65718 .74973 L .65873 .74792 L F
.691 .283 .268 r
.65867 .7499 m .65689 .74976 L .65627 .74982 L F
.65627 .74982 m .65486 .7496 L .65617 .74982 L F
.65689 .74976 m .65486 .7496 L .65627 .74982 L F
.65867 .7499 m .6575 .75105 L .65486 .7496 L F
.12 .052 .498 r
.65718 .74973 m .65715 .75008 L .65742 .74971 L F
.65718 .74973 m .65742 .74971 L .65873 .74792 L F
.46 .229 .476 r
.67132 .74435 m .67316 .74591 L .67335 .74394 L F
.67132 .74435 m .67114 .74628 L .67213 .7461 L F
.67132 .74435 m .67213 .7461 L .67251 .74536 L F
.67251 .74536 m .67213 .7461 L .67316 .74591 L F
.536 .583 .849 r
.67316 .74591 m .67114 .74628 L .66972 .74374 L F
.579 .303 .462 r
.66812 .7505 m .67205 .7463 L .66805 .74823 L F
.67045 .74864 m .67085 .74835 L .67088 .74829 L F
.002 0 .44 r
.67092 .7483 m .67088 .74829 L .67092 .74829 L F
.579 .303 .462 r
.66812 .7505 m .67088 .74829 L .67029 .74818 L F
.002 0 .44 r
.6693 .74946 m .67088 .74829 L .67092 .7483 L F
.685 .428 .527 r
.67088 .74829 m .67092 .74829 L .67205 .7463 L F
.606 .308 .437 r
.67093 .74829 m .67092 .7483 L .67092 .74829 L F
.579 .303 .462 r
.66961 .75046 m .67045 .75043 L .67104 .74891 L F
.67092 .74823 m .67104 .74891 L .67205 .7463 L F
.109 .003 .441 r
.67093 .74829 m .67092 .74829 L .67093 .74828 L F
.579 .303 .462 r
.66961 .75046 m .67104 .74891 L .67092 .74823 L F
.67029 .74818 m .67088 .74829 L .67205 .7463 L F
.685 .428 .527 r
.66805 .74823 m .67088 .74829 L .67205 .7463 L F
.536 .583 .849 r
.67316 .74591 m .67142 .74481 L .67218 .74518 L F
.67142 .74481 m .66972 .74374 L .67218 .74518 L F
.642 .55 .735 r
.67358 .74373 m .67292 .74553 L .67218 .74518 L F
.472 .323 .597 r
.67205 .7463 m .67316 .74591 L .67218 .74518 L F
.642 .55 .735 r
.67292 .74553 m .67227 .7473 L .67218 .74518 L F
.472 .323 .597 r
.67177 .7468 m .67218 .74518 L .67092 .74829 L F
.67205 .7463 m .67206 .74624 L .67177 .7468 L F
.67206 .74624 m .67218 .74518 L .67177 .7468 L F
.606 .308 .437 r
.67227 .7473 m .6693 .74946 L .67084 .74835 L F
.67097 .74826 m .67084 .74835 L .67092 .7483 L F
.412 .027 .196 r
.67142 .74793 m .67248 .74716 L .67205 .7463 L F
.109 .003 .441 r
.67227 .7473 m .67099 .74825 L .67218 .74518 L F
.606 .308 .437 r
.67227 .7473 m .67084 .74835 L .67097 .74826 L F
0 0 0 r
.67457 .74717 m .67391 .74868 L .67239 .74924 L F
.173 .192 .64 r
.67239 .74924 m .67391 .74868 L .67378 .74823 L F
.67295 .74684 m .67378 .74823 L .67316 .74591 L F
.67239 .74924 m .67378 .74823 L .67295 .74684 L F
.566 .579 .826 r
.67649 .74973 m .67419 .74891 L .67636 .74812 L F
.67419 .74891 m .67315 .74853 L .67391 .74843 L F
.67419 .74891 m .67391 .74843 L .67636 .74812 L F
.173 .192 .64 r
.67239 .74924 m .67316 .74591 L .67315 .74853 L F
.412 .027 .196 r
.67104 .74891 m .67315 .74853 L .67248 .74716 L F
.67104 .74891 m .67248 .74716 L .67142 .74793 L F
.67045 .75043 m .67113 .74996 L .67104 .74891 L F
.67113 .74996 m .67315 .74853 L .67104 .74891 L F
.109 .003 .441 r
.67099 .74825 m .67093 .74829 L .67098 .74817 L F
.67099 .74825 m .67098 .74817 L .67218 .74518 L F
.67093 .74829 m .67093 .74828 L .67218 .74518 L F
.606 .308 .437 r
.67227 .7473 m .67092 .7483 L .67093 .74829 L F
.579 .303 .462 r
.66812 .7505 m .66961 .75046 L .67085 .74835 L F
.66812 .7505 m .67085 .74835 L .67045 .74864 L F
.002 0 .44 r
.6693 .74946 m .66805 .74823 L .67088 .74829 L F
.065 .588 .873 r
.57709 .78816 m .57722 .78791 L .57528 .78759 L F
.972 .925 .677 r
.57709 .78816 m .57628 .78907 L .57722 .78791 L F
.57709 .78816 m .576 .79124 L .57628 .78907 L F
.764 .677 .767 r
.57987 .7852 m .57709 .78816 L .57729 .78559 L F
.608 .482 .683 r
.59104 .81386 m .58916 .81668 L .5893 .81425 L F
0 0 0 r
.46217 .8831 m .46353 .88231 L .46548 .88133 L F
.621 .451 .631 r
.52355 .85032 m .52574 .8478 L .52308 .84752 L F
.56 .455 .692 r
.37641 .74634 m .37681 .75022 L .37483 .74925 L F
.595 .508 .726 r
.37681 .75022 m .37531 .7521 L .37483 .74925 L F
.552 .547 .802 r
.576 .79124 m .57826 .79121 L .57628 .78907 L F
0 0 0 r
.49804 .87751 m .49766 .87747 L .49613 .87739 L F
.49804 .87751 m .49983 .87711 L .49766 .87747 L F
0 0 .454 r
.52536 .82024 m .52441 .81943 L .52644 .81852 L F
.156 .693 .708 r
.4665 .87151 m .46335 .87214 L .46526 .87107 L F
.662 .918 .976 r
.46848 .87052 m .4665 .87151 L .46526 .87107 L F
0 0 0 r
.43783 .87671 m .43431 .87807 L .43627 .87738 L F
.043 0 0 r
.4389 .87678 m .43783 .87671 L .43627 .87738 L F
.4389 .87678 m .43988 .87655 L .43783 .87671 L F
.411 .343 .671 r
.53548 .82134 m .5343 .82235 L .53393 .81966 L F
.777 .684 .761 r
.54468 .82158 m .54501 .82493 L .54472 .82459 L F
.292 .721 .969 r
.54451 .82685 m .54472 .82459 L .54501 .82493 L F
.917 .865 .428 r
.61372 .77562 m .6131 .77752 L .61383 .7741 L F
.654 .491 .651 r
.38205 .8559 m .38211 .85825 L .3797 .85836 L F
.568 .389 .599 r
.38421 .85562 m .38211 .85825 L .38205 .8559 L F
.344 0 0 r
.39683 .74385 m .3945 .74267 L .39371 .74444 L F
.615 .48 .674 r
.61067 .7648 m .60862 .76744 L .60837 .76521 L F
.739 .396 .401 r
.49253 .8109 m .49648 .80859 L .49324 .80868 L F
.639 .59 .783 r
.3776 .75183 m .37563 .75393 L .37531 .7521 L F
.3776 .75183 m .37848 .75486 L .37563 .75393 L F
.705 .467 .562 r
.59145 .80132 m .59232 .80335 L .58889 .80344 L F
.329 .397 .78 r
.59268 .79945 m .59145 .80132 L .59061 .798 L F
.652 .628 .813 r
.59268 .79945 m .59232 .80335 L .59145 .80132 L F
.46 .176 .395 r
.60794 .7907 m .61071 .7884 L .61042 .79049 L F
.603 .378 .547 r
.61071 .7884 m .61254 .79038 L .61042 .79049 L F
.61071 .7884 m .61266 .7879 L .61254 .79038 L F
.583 .5 .727 r
.49163 .82705 m .49093 .82945 L .4892 .82722 L F
.73 .405 .43 r
.52371 .82255 m .52035 .82379 L .5226 .82244 L F
.969 .799 .371 r
.5814 .80601 m .58165 .80386 L .58125 .80292 L F
.214 .733 .858 r
.38216 .86062 m .3797 .85836 L .38211 .85825 L F
.38216 .86062 m .3799 .8608 L .3797 .85836 L F
.06 0 0 r
.50657 .83504 m .51 .83469 L .50674 .83428 L F
.50657 .83504 m .50887 .83492 L .51 .83469 L F
.647 .601 .788 r
.51166 .83443 m .51056 .83731 L .51 .83469 L F
0 0 0 r
.51 .83469 m .50887 .83492 L .51166 .83443 L F
.648 .511 .683 r
.60651 .77006 m .60645 .77224 L .60442 .77268 L F
.632 .485 .664 r
.60645 .77224 m .60445 .77496 L .60442 .77268 L F
.655 .654 .837 r
.5668 .79875 m .56457 .8009 L .56383 .79848 L F
.602 .563 .783 r
.5668 .79875 m .56685 .80102 L .56457 .8009 L F
.756 .628 .718 r
.56685 .80102 m .56442 .80333 L .56457 .8009 L F
.614 .879 .99 r
.54303 .82136 m .54272 .82229 L .54468 .82158 L F
.74 .761 .87 r
.50077 .82909 m .49878 .83106 L .49658 .82916 L F
0 .409 .842 r
.54383 .81021 m .54182 .80967 L .54105 .8085 L F
.54383 .81021 m .54445 .81098 L .54182 .80967 L F
.692 .653 .807 r
.50817 .85277 m .50903 .85415 L .51088 .85313 L F
0 0 0 r
.5309 .86716 m .53101 .86763 L .53225 .86578 L F
.5309 .86716 m .53056 .86953 L .53101 .86763 L F
.505 .836 .999 r
.40625 .84756 m .40543 .84797 L .40639 .84541 L F
.637 .824 .972 r
.5883 .83731 m .58634 .83806 L .58504 .83711 L F
.671 .594 .761 r
.58732 .79279 m .58983 .79586 L .58869 .79225 L F
.639 .593 .787 r
.58869 .79225 m .58983 .79586 L .5919 .79305 L F
.526 .299 .513 r
.62168 .78015 m .61943 .78255 L .61979 .78068 L F
.575 .332 .511 r
.65541 .74554 m .65197 .74634 L .65177 .74425 L F
.347 .005 .236 r
.35899 .74992 m .35814 .75167 L .35649 .75179 L F
.405 .607 .93 r
.35649 .75179 m .35814 .75167 L .35778 .75128 L F
.347 .005 .236 r
.35899 .74992 m .35649 .75179 L .35637 .75184 L F
.405 .607 .93 r
.35649 .75179 m .35778 .75128 L .35696 .75036 L F
.347 .005 .236 r
.35637 .75184 m .35649 .75179 L .35634 .75186 L F
.511 .167 .321 r
.36024 .7511 m .35899 .74992 L .36045 .74931 L F
.36024 .7511 m .35814 .75167 L .35899 .74992 L F
.502 .268 .491 r
.367 .77519 m .36639 .77838 L .36456 .77773 L F
.542 .303 .504 r
.36861 .77709 m .367 .77519 L .36901 .77489 L F
.36861 .77709 m .36639 .77838 L .367 .77519 L F
.641 .741 .922 r
.49381 .83899 m .49473 .84018 L .49154 .8396 L F
.564 .022 0 r
.49473 .84018 m .49278 .84084 L .49154 .8396 L F
.372 .609 .941 r
.49592 .83944 m .49473 .84018 L .49381 .83899 L F
.72 .464 .539 r
.49592 .83944 m .49278 .84084 L .49473 .84018 L F
.481 .241 .473 r
.38084 .76466 m .38084 .76698 L .37823 .76742 L F
.526 .332 .56 r
.38292 .76221 m .3828 .76423 L .38084 .76466 L F
.52 .271 .478 r
.38324 .76526 m .38084 .76466 L .3828 .76423 L F
.38324 .76526 m .38084 .76698 L .38084 .76466 L F
.206 0 0 r
.44197 .88876 m .44555 .88773 L .4438 .88826 L F
.021 0 0 r
.44555 .88773 m .44587 .88793 L .4438 .88826 L F
.44555 .88773 m .44778 .8875 L .44587 .88793 L F
.614 .176 .185 r
.3953 .88316 m .39853 .88277 L .39581 .88313 L F
.505 .874 .981 r
.4092 .88188 m .40603 .8821 L .40788 .88143 L F
.546 .905 .967 r
.41126 .88112 m .4092 .88188 L .40986 .88097 L F
.5 .853 .992 r
.40986 .88097 m .4092 .88188 L .40788 .88143 L F
.091 0 0 r
.435 .89017 m .43787 .88925 L .43689 .88958 L F
.138 .685 .779 r
.43787 .88925 m .43884 .88905 L .43689 .88958 L F
.43787 .88925 m .43995 .88904 L .43884 .88905 L F
.595 .513 .733 r
.5939 .79207 m .59526 .78909 L .59335 .7896 L F
.59403 .79268 m .59441 .79157 L .5939 .79207 L F
.597 .533 .753 r
.59555 .79047 m .59403 .79268 L .59453 .79072 L F
.595 .513 .733 r
.59403 .79268 m .59619 .79232 L .59563 .79039 L F
0 0 0 r
.59566 .79036 m .59566 .79037 L .59554 .79048 L F
.59566 .79037 m .59555 .79047 L .59554 .79048 L F
.59566 .79036 m .59554 .79048 L .59453 .79072 L F
.595 .513 .733 r
.59555 .79047 m .59563 .79039 L .59563 .79036 L F
.59403 .79268 m .59563 .79039 L .59555 .79047 L F
0 0 0 r
.59566 .79037 m .59561 .79046 L .59555 .79047 L F
.597 .533 .753 r
.59561 .79046 m .59403 .79268 L .59555 .79047 L F
0 0 0 r
.59692 .78803 m .59566 .79036 L .59453 .79072 L F
.595 .513 .733 r
.59403 .79268 m .59563 .79036 L .59526 .78909 L F
.59441 .79157 m .59526 .78909 L .5939 .79207 L F
.655 .273 .31 r
.59891 .7899 m .59692 .78803 L .59893 .78774 L F
.59891 .7899 m .59583 .79042 L .59692 .78803 L F
.59583 .79042 m .59581 .79042 L .59582 .79042 L F
.59583 .79042 m .59582 .79042 L .59692 .78803 L F
.485 .181 .374 r
.59891 .7899 m .59832 .79198 L .59619 .79232 L F
.581 .504 .732 r
.59619 .79232 m .59832 .79198 L .5981 .79125 L F
.59619 .79232 m .59581 .79042 L .59562 .79036 L F
.485 .181 .374 r
.59581 .79042 m .59619 .79232 L .59561 .79046 L F
.59891 .7899 m .59619 .79232 L .59581 .79042 L F
.581 .504 .732 r
.59619 .79232 m .59677 .79077 L .59581 .79042 L F
.59677 .79077 m .5981 .79125 L .59743 .78904 L F
.59619 .79232 m .5981 .79125 L .59677 .79077 L F
.655 .273 .31 r
.59581 .79042 m .59566 .79037 L .59692 .78803 L F
.581 .504 .732 r
.59562 .79036 m .59743 .78904 L .59526 .78909 L F
.59677 .79077 m .59743 .78904 L .59562 .79036 L F
.655 .273 .31 r
.59581 .79042 m .59561 .79046 L .59566 .79037 L F
.783 .398 0 r
.52529 .81285 m .52513 .81308 L .52299 .81336 L F
.52529 .81285 m .52573 .81401 L .52513 .81308 L F
0 0 .411 r
.55135 .82686 m .5503 .82488 L .55151 .82353 L F
.55135 .82686 m .55098 .82733 L .5503 .82488 L F
.669 .175 .066 r
.56216 .79523 m .56772 .79672 L .5633 .7946 L F
0 0 0 r
.54655 .82861 m .54451 .82685 L .54391 .83015 L F
.292 .721 .969 r
.54451 .82685 m .54675 .8263 L .54472 .82459 L F
.54451 .82685 m .54907 .82707 L .54675 .8263 L F
.738 .555 .645 r
.54391 .83015 m .54655 .82861 L .54451 .82685 L F
.551 .304 .495 r
.62435 .77682 m .62385 .77986 L .62168 .78015 L F
.553 .342 .548 r
.62648 .77497 m .62652 .77669 L .62435 .77682 L F
.579 .344 .524 r
.62652 .77669 m .62385 .77986 L .62435 .77682 L F
.421 .608 .926 r
.3827 .75593 m .38188 .75715 L .38118 .75604 L F
.488 .7 .963 r
.3827 .75593 m .38384 .75698 L .38188 .75715 L F
.606 .569 .786 r
.38497 .75957 m .38188 .75715 L .38384 .75698 L F
.65 .822 .966 r
.58548 .78785 m .58916 .78814 L .5876 .7853 L F
.459 .441 .751 r
.58916 .78814 m .58973 .78463 L .5876 .7853 L F
.58916 .78814 m .59076 .78782 L .58973 .78463 L F
.543 .377 .606 r
.58916 .78814 m .59104 .79 L .59076 .78782 L F
.58916 .78814 m .58892 .79047 L .59104 .79 L F
.588 .521 .747 r
.36882 .73819 m .36782 .74201 L .36661 .73884 L F
.36882 .73819 m .36983 .74164 L .36782 .74201 L F
.545 .129 .203 r
.51682 .81661 m .51584 .81822 L .51365 .81739 L F
.942 .644 .444 r
.51682 .81661 m .51736 .81964 L .51584 .81822 L F
.829 .942 .581 r
.53101 .86763 m .53056 .86953 L .5292 .87084 L F
.744 .618 .719 r
.56743 .80948 m .56638 .81137 L .56562 .80853 L F
.553 .649 .898 r
.50419 .8372 m .50526 .83885 L .50717 .83842 L F
.833 .539 0 r
.5609 .81391 m .56175 .81679 L .5612 .81623 L F
.955 .69 .241 r
.56175 .81679 m .56206 .81983 L .5612 .81623 L F
.693 .67 .823 r
.55167 .84202 m .55166 .84471 L .55239 .84325 L F
.767 .765 .851 r
.55239 .84325 m .55166 .84471 L .55014 .84538 L F
.55239 .84325 m .55166 .84471 L .55014 .84538 L F
.742 .733 .843 r
.5543 .84252 m .55166 .84471 L .55239 .84325 L F
.418 .093 .305 r
.43944 .83553 m .43895 .83702 L .43693 .8373 L F
.476 .147 .329 r
.44104 .83666 m .43944 .83553 L .44135 .83537 L F
.44104 .83666 m .43895 .83702 L .43944 .83553 L F
.446 .212 .464 r
.66304 .75874 m .66314 .76168 L .66121 .76224 L F
.473 .246 .489 r
.66549 .75645 m .66554 .7591 L .66304 .75874 L F
.516 .288 .507 r
.66554 .7591 m .66314 .76168 L .66304 .75874 L F
.615 .156 .14 r
.53225 .86578 m .53355 .86729 L .53243 .86792 L F
0 0 .323 r
.53283 .86884 m .53243 .86792 L .53355 .86729 L F
.109 0 0 r
.52499 .82221 m .52307 .82339 L .52371 .82255 L F
.558 .367 .578 r
.67721 .74413 m .67707 .74671 L .67457 .74717 L F
.474 .028 .108 r
.67636 .74812 m .67457 .74717 L .67707 .74671 L F
.67636 .74812 m .67391 .74868 L .67457 .74717 L F
.778 .672 .746 r
.64266 .74701 m .63915 .74881 L .64118 .74619 L F
.316 0 .117 r
.65974 .74366 m .66176 .74318 L .6625 .7416 L F
.204 0 0 r
.66176 .74318 m .66495 .74279 L .6625 .7416 L F
.539 0 0 r
.47487 .874 m .47146 .87147 L .47213 .87317 L F
.283 .196 .577 r
.47213 .87317 m .47146 .87147 L .47321 .87059 L F
.472 .185 .395 r
.66802 .75447 m .66779 .75605 L .66549 .75645 L F
.576 .381 .58 r
.66995 .75382 m .66779 .75605 L .66802 .75447 L F
0 0 0 r
.3978 .8285 m .39823 .8283 L .39732 .82867 L F
.117 0 0 r
.39892 .82799 m .39823 .8283 L .40006 .82782 L F
.295 .786 .741 r
.40006 .82782 m .39823 .8283 L .40004 .82765 L F
0 0 0 r
.40004 .82765 m .39823 .8283 L .3978 .8285 L F
.117 0 0 r
.39632 .82839 m .39823 .8283 L .39892 .82799 L F
.295 .786 .741 r
.40006 .82782 m .40004 .82765 L .40201 .82741 L F
0 .202 .72 r
.67315 .74853 m .67421 .751 L .67239 .74924 L F
.415 .282 .59 r
.67239 .74924 m .67421 .751 L .67255 .7517 L F
.647 .581 .767 r
.61487 .75954 m .61253 .75985 L .61173 .75697 L F
.646 .496 .665 r
.61496 .76185 m .61253 .75985 L .61487 .75954 L F
.61496 .76185 m .61275 .76218 L .61253 .75985 L F
.911 .961 .638 r
.67849 .74133 m .67689 .7438 L .67721 .74413 L F
.073 0 .427 r
.67784 .74592 m .67707 .74671 L .67721 .74413 L F
.67784 .74592 m .67721 .74413 L .67689 .7438 L F
.877 .613 .089 r
.46593 .83232 m .46566 .83312 L .46555 .83145 L F
0 .5 .765 r
.46823 .83381 m .4658 .8332 L .46593 .83232 L F
.631 .306 .402 r
.46652 .83364 m .4657 .83375 L .46566 .83312 L F
0 .5 .765 r
.4658 .8332 m .46564 .83316 L .46566 .83312 L F
.4658 .8332 m .46566 .83312 L .46593 .83232 L F
.46823 .83381 m .46735 .83352 L .4658 .8332 L F
.631 .306 .402 r
.46652 .83364 m .46566 .83312 L .46555 .83145 L F
0 .5 .765 r
.4658 .8332 m .46735 .83352 L .46564 .83316 L F
.631 .306 .402 r
.46735 .83352 m .46652 .83364 L .46638 .83332 L F
.46735 .83352 m .46638 .83332 L .46555 .83145 L F
.4657 .83375 m .46361 .83404 L .46555 .83145 L F
.877 .613 .089 r
.46566 .83312 m .46564 .83316 L .46555 .83145 L F
.519 0 0 r
.4688 .83387 m .46823 .83381 L .46593 .83232 L F
.73 .405 .43 r
.52371 .82255 m .52307 .82339 L .52035 .82379 L F
.83 .404 .226 r
.48554 .81719 m .48569 .81799 L .48702 .8173 L F
.642 .56 .747 r
.54268 .8347 m .54519 .83559 L .54372 .83196 L F
.428 .153 .393 r
.66121 .76224 m .65879 .76457 L .65878 .76241 L F
0 0 0 r
.58781 .8099 m .58595 .81151 L .5874 .81034 L F
.274 .283 .687 r
.58595 .81151 m .58795 .81427 L .5874 .81034 L F
.58595 .81151 m .58661 .81324 L .58795 .81427 L F
.583 .416 .621 r
.36187 .76487 m .36399 .7647 L .36395 .76216 L F
.506 .159 .314 r
.36331 .7663 m .36187 .76487 L .36161 .76698 L F
.36331 .7663 m .36399 .7647 L .36187 .76487 L F
.672 .518 .668 r
.60862 .76958 m .60651 .77006 L .60862 .76744 L F
.615 .48 .674 r
.61067 .7648 m .61079 .76702 L .60862 .76744 L F
.641 .51 .688 r
.61079 .76702 m .60862 .76958 L .60862 .76744 L F
.563 .866 .996 r
.38919 .90223 m .38984 .90115 L .38788 .90178 L F
.38919 .90223 m .39111 .90166 L .38984 .90115 L F
.265 .1 .461 r
.35634 .75186 m .35649 .75179 L .35623 .75296 L F
.713 .56 .679 r
.54631 .83243 m .54831 .82866 L .54655 .82861 L F
.255 0 0 r
.41301 .88156 m .41451 .8818 L .41126 .88112 L F
.434 .844 .968 r
.41642 .88135 m .41451 .8818 L .41301 .88156 L F
.453 .243 .503 r
.36161 .76698 m .35974 .76743 L .36107 .76716 L F
.437 .139 .36 r
.35968 .76762 m .36107 .76716 L .35974 .76743 L F
.514 .326 .563 r
.38497 .75957 m .38496 .76181 L .38292 .76221 L F
.536 .353 .58 r
.38496 .76181 m .3828 .76423 L .38292 .76221 L F
.768 .973 .921 r
.63915 .75873 m .63673 .75975 L .63823 .75674 L F
.599 .601 .826 r
.64069 .75647 m .63915 .75873 L .63823 .75674 L F
.64069 .75647 m .64201 .75859 L .63915 .75873 L F
.472 .582 .884 r
.57636 .80415 m .57289 .80187 L .57293 .79947 L F
.096 .069 .534 r
.57411 .80121 m .57293 .79947 L .57289 .80187 L F
.052 0 0 r
.57293 .79947 m .57576 .79917 L .57497 .79892 L F
0 .255 .758 r
.5765 .8019 m .57716 .80293 L .57548 .80156 L F
.5751 .80095 m .57548 .80156 L .57293 .79947 L F
.5765 .8019 m .57548 .80156 L .5751 .80095 L F
.689 .953 .953 r
.57716 .80293 m .57636 .80415 L .57293 .79947 L F
.284 .41 .814 r
.57716 .80293 m .57636 .80415 L .57293 .79947 L F
0 .255 .758 r
.5765 .8019 m .57293 .79947 L .57411 .80121 L F
.417 .525 .859 r
.57433 .79969 m .57411 .80121 L .57302 .80028 L F
.57466 .79954 m .57451 .79998 L .57433 .79969 L F
.57451 .79998 m .57411 .80121 L .57433 .79969 L F
.817 .444 0 r
.57677 .80249 m .57716 .80293 L .5765 .8019 L F
.689 .953 .953 r
.57716 .80293 m .57773 .80359 L .57636 .80415 L F
.817 .444 0 r
.57782 .80483 m .57716 .80293 L .57677 .80249 L F
.689 .953 .953 r
.57716 .80293 m .57835 .80334 L .57773 .80359 L F
.329 .789 .942 r
.58125 .80292 m .57835 .80334 L .57716 .80293 L F
.615 .156 .14 r
.53435 .86643 m .5354 .8658 L .53225 .86578 L F
.53225 .86578 m .5354 .8658 L .53435 .86643 L F
.804 .411 .31 r
.47367 .87523 m .47487 .874 L .47213 .87317 L F
.57 .353 .546 r
.62879 .7747 m .62652 .77669 L .62648 .77497 L F
.453 .618 .921 r
.49621 .81357 m .49714 .81148 L .49534 .8119 L F
.49621 .81357 m .49981 .81354 L .49714 .81148 L F
.49981 .81354 m .49979 .81347 L .49714 .81148 L F
.576 .645 .882 r
.49714 .81148 m .49989 .81354 L .49975 .81325 L F
.49714 .81148 m .49975 .81325 L .49915 .8125 L F
.981 .751 .517 r
.49971 .8132 m .49869 .81466 L .49915 .8125 L F
.49975 .81325 m .49974 .81328 L .49971 .8132 L F
.49974 .81328 m .49869 .81466 L .49971 .8132 L F
.453 .618 .921 r
.49981 .81354 m .49989 .81354 L .49979 .81347 L F
.479 .314 .579 r
.36395 .76216 m .36584 .75945 L .36367 .75992 L F
.727 .597 .711 r
.38856 .85268 m .38635 .8554 L .38653 .85312 L F
.595 .508 .726 r
.37681 .75022 m .3776 .75183 L .37531 .7521 L F
.514 .087 .167 r
.42164 .84121 m .41796 .84213 L .4191 .8415 L F
.447 .763 .996 r
.40374 .88349 m .40038 .88262 L .40241 .88195 L F
.727 .887 .954 r
.40457 .88147 m .40374 .88349 L .40241 .88195 L F
.40457 .88147 m .40603 .8821 L .40374 .88349 L F
0 .53 .775 r
.47395 .88225 m .47497 .88229 L .4727 .88227 L F
.47395 .88225 m .4757 .88253 L .47497 .88229 L F
.58 .487 .714 r
.39009 .74511 m .3927 .74549 L .392 .74408 L F
.229 .661 .956 r
.3926 .74567 m .3927 .74549 L .39009 .74511 L F
.541 .225 .382 r
.64589 .76678 m .6487 .76454 L .64803 .76669 L F
.451 .104 .285 r
.65105 .76425 m .64803 .76669 L .6487 .76454 L F
.736 .58 .68 r
.54372 .83196 m .54655 .82861 L .54391 .83015 L F
.54372 .83196 m .54631 .83243 L .54655 .82861 L F
.847 .397 0 r
.50375 .863 m .50302 .86097 L .50175 .86114 L F
.50375 .863 m .50397 .86253 L .50302 .86097 L F
0 0 .075 r
.56484 .82715 m .56288 .82984 L .56421 .82923 L F
.015 0 .3 r
.56421 .82923 m .56288 .82984 L .56242 .8321 L F
.558 .43 .662 r
.36564 .75685 m .36805 .75681 L .36681 .754 L F
.657 .496 .654 r
.36564 .75685 m .36818 .75905 L .36805 .75681 L F
.36564 .75685 m .36584 .75945 L .36818 .75905 L F
.466 .067 .198 r
.43049 .82398 m .43257 .82385 L .43384 .82198 L F
.523 .119 .216 r
.43257 .82385 m .43591 .82216 L .43384 .82198 L F
.688 .268 .243 r
.47145 .83333 m .46997 .83449 L .46823 .83381 L F
.58 .128 .143 r
.47317 .83439 m .46997 .83449 L .47145 .83333 L F
.424 .147 .387 r
.615 .78536 m .61747 .78313 L .61703 .78485 L F
.422 .146 .386 r
.61703 .78485 m .61747 .78313 L .61943 .78255 L F
.755 .552 .622 r
.49466 .81634 m .49602 .81797 L .49772 .81715 L F
0 0 0 r
.49772 .81715 m .49602 .81797 L .49858 .81684 L F
.49772 .81715 m .49866 .81681 L .49986 .81672 L F
.49866 .81681 m .49877 .81679 L .49986 .81672 L F
.755 .472 .504 r
.50001 .81658 m .49816 .81705 L .49866 .81681 L F
0 0 0 r
.49866 .81681 m .49858 .81684 L .4987 .81679 L F
.49772 .81715 m .49858 .81684 L .49866 .81681 L F
.55 .437 .678 r
.49639 .82099 m .4986 .81697 L .49602 .81797 L F
.4986 .81697 m .4987 .81679 L .49858 .81684 L F
.4986 .81697 m .49858 .81684 L .49602 .81797 L F
.755 .472 .504 r
.50001 .81658 m .50053 .81793 L .49894 .81709 L F
.775 .642 .714 r
.4987 .81679 m .49888 .81706 L .50053 .81793 L F
.49888 .81706 m .5015 .82084 L .50053 .81793 L F
.49888 .81706 m .49819 .82111 L .5015 .82084 L F
.755 .472 .504 r
.50001 .81658 m .49899 .81706 L .4986 .81694 L F
.49899 .81706 m .49862 .81705 L .4986 .81694 L F
.775 .642 .714 r
.4987 .81679 m .49867 .81706 L .49888 .81706 L F
.49867 .81706 m .49819 .82111 L .49888 .81706 L F
.755 .472 .504 r
.49899 .81706 m .49864 .81723 L .49862 .81705 L F
.49894 .81709 m .50053 .81793 L .49864 .81723 L F
.4986 .81694 m .49864 .81723 L .49816 .81705 L F
.49866 .81681 m .49816 .81705 L .49787 .81694 L F
.55 .437 .678 r
.49639 .82099 m .49819 .82111 L .4987 .81679 L F
.755 .472 .504 r
.49787 .81694 m .50053 .81793 L .49713 .81735 L F
.372 .16 .458 r
.49986 .81672 m .50167 .81631 L .50202 .81377 L F
.782 .485 .485 r
.49933 .81669 m .49976 .8159 L .50167 .81631 L F
.755 .472 .504 r
.49976 .8159 m .49933 .81669 L .49787 .81694 L F
.782 .485 .485 r
.4987 .81679 m .49976 .8159 L .49933 .81669 L F
.755 .472 .504 r
.49976 .8159 m .50001 .81658 L .49933 .81669 L F
0 0 0 r
.49866 .81681 m .4987 .81679 L .49877 .81679 L F
.972 .826 .641 r
.65319 .7536 m .6547 .75224 L .65361 .75146 L F
.65319 .7536 m .65435 .75477 L .6547 .75224 L F
.096 .069 .534 r
.57411 .80121 m .57289 .80187 L .57159 .79982 L F
.578 .229 .341 r
.57922 .80583 m .58052 .80822 L .57851 .80858 L F
.57922 .80583 m .5814 .80601 L .58052 .80822 L F
.427 .112 .325 r
.36456 .77773 m .36362 .77977 L .36196 .78012 L F
.36456 .77773 m .36383 .77972 L .36362 .77977 L F
.569 .279 .436 r
.36639 .77838 m .36383 .77972 L .36456 .77773 L F
.428 .843 .965 r
.37753 .83235 m .37665 .83313 L .37496 .83272 L F
.842 .56 .511 r
.56517 .84203 m .56904 .84396 L .56818 .84485 L F
.587 .787 .975 r
.66705 .74263 m .66851 .74387 L .66574 .74413 L F
.298 .4 .799 r
.66803 .74627 m .66574 .74413 L .66851 .74387 L F
.923 .963 .783 r
.39091 .88612 m .39187 .88328 L .39334 .88434 L F
.39091 .88612 m .38979 .88633 L .39187 .88328 L F
.816 .681 .714 r
.61383 .7741 m .61375 .7718 L .61519 .77264 L F
.843 .782 .793 r
.61661 .76967 m .61519 .77264 L .61375 .7718 L F
.857 .71 .699 r
.5343 .82235 m .53388 .82383 L .53067 .82335 L F
0 0 .175 r
.53548 .82134 m .53388 .82383 L .5343 .82235 L F
.586 .778 .971 r
.36409 .74973 m .36704 .7518 L .36918 .75131 L F
.662 .57 .741 r
.36681 .754 m .36918 .75131 L .36704 .7518 L F
0 0 0 r
.41101 .89646 m .41472 .89555 L .41302 .8957 L F
.188 .718 .83 r
.41472 .89555 m .41519 .89522 L .41302 .8957 L F
.41472 .89555 m .417 .89532 L .41519 .89522 L F
.377 0 .102 r
.43236 .8909 m .43384 .89148 L .43094 .89086 L F
.43236 .8909 m .435 .89017 L .43384 .89148 L F
.601 .244 .336 r
.63639 .76974 m .63833 .77088 L .63581 .7707 L F
.63639 .76974 m .63854 .77 L .63833 .77088 L F
.579 .194 .276 r
.51056 .83731 m .5095 .83883 L .50717 .83842 L F
.647 .601 .788 r
.51166 .83443 m .51269 .83737 L .51056 .83731 L F
.527 .115 .203 r
.51269 .83737 m .5095 .83883 L .51056 .83731 L F
.631 .66 .86 r
.38084 .76698 m .37789 .76812 L .37823 .76742 L F
.643 .613 .805 r
.49566 .83467 m .4938 .83561 L .49237 .83242 L F
.17 0 0 r
.49419 .8364 m .49234 .83678 L .4938 .83561 L F
0 .403 .837 r
.49396 .83645 m .49419 .8364 L .49313 .83629 L F
.17 0 0 r
.49419 .8364 m .49456 .83633 L .49544 .83716 L F
.56 .415 .641 r
.49566 .83467 m .49544 .83716 L .4938 .83561 L F
.609 .458 .652 r
.49785 .83676 m .49544 .83716 L .49566 .83467 L F
.606 .075 0 r
.49419 .8364 m .49667 .83764 L .49785 .83676 L F
.49419 .8364 m .49667 .83764 L .49785 .83676 L F
0 .403 .837 r
.49578 .83681 m .49667 .83764 L .49419 .8364 L F
.49578 .83681 m .49419 .8364 L .49396 .83645 L F
.17 0 0 r
.49419 .8364 m .4938 .83561 L .49456 .83633 L F
.66 .512 .672 r
.60862 .76958 m .60645 .77224 L .60651 .77006 L F
0 0 .135 r
.56485 .83944 m .56489 .84012 L .56517 .84203 L F
.507 .912 .868 r
.51003 .87379 m .50622 .8751 L .50913 .87393 L F
.447 .88 .821 r
.51096 .87309 m .51003 .87379 L .50913 .87393 L F
.355 0 0 r
.46454 .81887 m .46665 .81862 L .46787 .8173 L F
.33 0 0 r
.46665 .81862 m .46999 .81719 L .46787 .8173 L F
0 0 .257 r
.60744 .78791 m .60794 .7907 L .60791 .78942 L F
.873 .902 .488 r
.60791 .78942 m .60794 .7907 L .60685 .79221 L F
.64 .419 .567 r
.61042 .79049 m .60764 .79305 L .60794 .7907 L F
0 0 0 r
.44968 .88682 m .45042 .88633 L .45254 .88574 L F
.745 .232 0 r
.58349 .80189 m .58679 .80398 L .58566 .80315 L F
.783 .574 .616 r
.58566 .80315 m .58845 .80578 L .58679 .80398 L F
.502 .866 .986 r
.58679 .80398 m .58889 .80344 L .58845 .80578 L F
.479 .314 .579 r
.36395 .76216 m .36577 .76181 L .36584 .75945 L F
.566 .402 .619 r
.36395 .76216 m .36607 .76432 L .36577 .76181 L F
.36395 .76216 m .36399 .7647 L .36607 .76432 L F
.793 .333 .148 r
.64359 .7607 m .64465 .75988 L .64201 .75859 L F
.339 0 .011 r
.64589 .76091 m .64465 .75988 L .64359 .7607 L F
.64589 .76091 m .64698 .75952 L .64465 .75988 L F
.584 .481 .703 r
.64465 .75988 m .64698 .75952 L .64661 .75667 L F
.403 .009 .174 r
.52379 .80765 m .52574 .80584 L .5249 .80568 L F
.632 .485 .664 r
.60645 .77224 m .60743 .77511 L .60445 .77496 L F
.896 .483 .202 r
.55113 .79828 m .54986 .79774 L .54922 .79626 L F
.925 .537 .203 r
.55113 .79828 m .55102 .80038 L .54986 .79774 L F
.55113 .79828 m .55205 .80101 L .55102 .80038 L F
.705 .607 .744 r
.38946 .85564 m .39028 .85844 L .38746 .85818 L F
.709 .549 .67 r
.39101 .85981 m .38746 .85818 L .39028 .85844 L F
.596 .56 .784 r
.39148 .85539 m .39028 .85844 L .38946 .85564 L F
.39148 .85539 m .39253 .85847 L .39028 .85844 L F
.603 .502 .712 r
.39253 .85847 m .39101 .85981 L .39028 .85844 L F
.191 .714 .693 r
.5035 .87561 m .5045 .87535 L .50232 .87594 L F
.5035 .87561 m .50232 .87594 L .50173 .87642 L F
.555 .554 .808 r
.38576 .75648 m .38497 .75957 L .38384 .75698 L F
.38576 .75648 m .3869 .75931 L .38497 .75957 L F
.624 .468 .651 r
.3869 .75931 m .38496 .76181 L .38497 .75957 L F
.782 .424 .38 r
.56818 .84485 m .5713 .84552 L .57022 .84733 L F
.73 .36 .35 r
.5713 .84552 m .57342 .84769 L .57022 .84733 L F
.728 .417 .454 r
.43039 .83953 m .42864 .8406 L .42682 .83934 L F
.621 .25 .319 r
.43039 .83953 m .42861 .8415 L .42864 .8406 L F
.604 .196 .242 r
.43201 .84031 m .42861 .8415 L .43039 .83953 L F
.344 .385 .761 r
.36129 .73163 m .36086 .73511 L .35888 .73302 L F
.36129 .73163 m .3624 .73539 L .36086 .73511 L F
.782 .566 .607 r
.38746 .85818 m .38421 .85562 L .38635 .8554 L F
.38746 .85818 m .38417 .85797 L .38421 .85562 L F
.784 .633 .693 r
.38746 .85818 m .38546 .86077 L .38417 .85797 L F
.752 .584 .668 r
.38746 .85818 m .3875 .86086 L .38546 .86077 L F
.722 .632 .757 r
.38946 .85564 m .38746 .85818 L .38635 .8554 L F
.709 .549 .67 r
.39101 .85981 m .3875 .86086 L .38746 .85818 L F
.614 .176 .185 r
.3953 .88316 m .39729 .8838 L .39853 .88277 L F
0 0 0 r
.39853 .88277 m .39875 .88316 L .40038 .88262 L F
.39853 .88277 m .39729 .8838 L .39875 .88316 L F
.602 .92 .973 r
.57376 .77078 m .57599 .76989 L .57684 .77025 L F
.785 .943 .928 r
.5772 .76872 m .57837 .7693 L .57684 .77025 L F
.818 .969 .9 r
.57599 .76989 m .5772 .76872 L .57684 .77025 L F
.499 .581 .868 r
.35856 .76918 m .36107 .76716 L .35968 .76762 L F
.373 .106 .374 r
.52542 .86883 m .52296 .87152 L .525 .87115 L F
.524 .234 .415 r
.52684 .87052 m .52542 .86883 L .525 .87115 L F
.52684 .87052 m .52723 .86876 L .52542 .86883 L F
.492 .035 .093 r
.45714 .81912 m .45923 .81927 L .46031 .8185 L F
.484 .024 .085 r
.46031 .8185 m .45923 .81927 L .46239 .81864 L F
.579 .013 0 r
.48596 .88665 m .48908 .88871 L .48822 .88846 L F
.045 .599 .822 r
.48822 .88846 m .48908 .88871 L .49098 .88888 L F
.763 .738 .83 r
.60135 .7576 m .59855 .75709 L .59983 .75625 L F
.769 .745 .831 r
.60303 .7564 m .60135 .7576 L .59983 .75625 L F
.787 .943 .927 r
.58099 .76716 m .57837 .7693 L .5772 .76872 L F
.405 .607 .93 r
.35649 .75179 m .35495 .75094 L .35595 .75166 L F
.35649 .75179 m .35696 .75036 L .35495 .75094 L F
.858 .67 .647 r
.35623 .75296 m .35649 .75179 L .35595 .75166 L F
.556 .36 .571 r
.35717 .75391 m .35649 .75179 L .35623 .75296 L F
.35717 .75391 m .35822 .75382 L .35649 .75179 L F
.35717 .75391 m .35649 .75179 L .35623 .75296 L F
.35717 .75391 m .35822 .75382 L .35649 .75179 L F
.933 .955 .769 r
.49225 .85137 m .49125 .85261 L .49314 .84952 L F
0 0 0 r
.49288 .85041 m .49225 .85137 L .49314 .84952 L F
.639 .23 .252 r
.57592 .78059 m .57808 .78209 L .57909 .78056 L F
0 0 .411 r
.65554 .75326 m .65435 .75477 L .65319 .7536 L F
.65554 .75326 m .65502 .75479 L .65435 .75477 L F
.016 0 0 r
.65502 .75479 m .65678 .75459 L .65435 .75477 L F
.511 .183 .347 r
.43693 .8373 m .4361 .83972 L .4339 .83993 L F
.423 .099 .31 r
.4381 .83928 m .43693 .8373 L .43895 .83702 L F
.4381 .83928 m .4361 .83972 L .43693 .8373 L F
.491 .268 .502 r
.61266 .7879 m .615 .78536 L .61467 .78751 L F
.461 .234 .482 r
.61467 .78751 m .615 .78536 L .61703 .78485 L F
.699 .935 .964 r
.58307 .83795 m .58062 .83934 L .57963 .83892 L F
.451 .055 .196 r
.48766 .87582 m .48693 .87532 L .48563 .87628 L F
.503 .389 .657 r
.38021 .75124 m .37848 .75486 L .3776 .75183 L F
.38021 .75124 m .38014 .75448 L .37848 .75486 L F
.538 .567 .831 r
.38014 .75448 m .38118 .75604 L .37848 .75486 L F
.526 .297 .509 r
.66779 .75605 m .66554 .7591 L .66549 .75645 L F
.889 .466 .084 r
.55645 .8063 m .55839 .80894 L .55714 .80822 L F
0 0 .108 r
.55839 .80894 m .55828 .81111 L .55857 .81056 L F
.55839 .80894 m .55857 .81056 L .55714 .80822 L F
.568 .291 .455 r
.41609 .8426 m .41379 .84441 L .41392 .84272 L F
.634 .399 .545 r
.4875 .86336 m .4907 .86342 L .48799 .86186 L F
.784 .733 .806 r
.61814 .76637 m .61971 .76783 L .61661 .76967 L F
.704 .727 .868 r
.62095 .76631 m .61971 .76783 L .61814 .76637 L F
.487 .283 .527 r
.61254 .79038 m .61266 .7879 L .61467 .78751 L F
.551 .399 .628 r
.58732 .79279 m .58869 .79225 L .58892 .79047 L F
.913 .918 .807 r
.57121 .7724 m .5678 .77508 L .5706 .77194 L F
.57121 .7724 m .56857 .77607 L .5678 .77508 L F
.526 .911 .769 r
.57128 .77185 m .57121 .7724 L .5706 .77194 L F
.57128 .77185 m .57376 .77078 L .57121 .7724 L F
.847 .753 .759 r
.59552 .7591 m .59293 .75966 L .59426 .75844 L F
.59552 .7591 m .59367 .76208 L .59293 .75966 L F
.751 .885 .94 r
.59855 .75709 m .59552 .7591 L .59426 .75844 L F
.433 .787 .997 r
.44839 .87665 m .44512 .87621 L .44716 .87592 L F
.506 .834 .999 r
.44919 .87567 m .44839 .87665 L .44716 .87592 L F
.44919 .87567 m .45042 .87624 L .44839 .87665 L F
.795 .329 0 r
.56289 .8247 m .56484 .82715 L .56354 .8266 L F
.945 .638 .424 r
.56354 .8266 m .56484 .82715 L .56421 .82923 L F
.56354 .8266 m .56484 .82715 L .56421 .82923 L F
.241 0 0 r
.40323 .82706 m .40397 .82717 L .40509 .82653 L F
.764 .336 .234 r
.40241 .82655 m .40534 .82736 L .40397 .82717 L F
.311 0 0 r
.40397 .82717 m .40564 .82744 L .40711 .82655 L F
.764 .336 .234 r
.40534 .82736 m .40564 .82744 L .40397 .82717 L F
.241 0 0 r
.40201 .82741 m .40397 .82717 L .40323 .82706 L F
.311 0 0 r
.40397 .82717 m .40711 .82655 L .40509 .82653 L F
.16 .408 .851 r
.58282 .80028 m .58349 .80189 L .58566 .80315 L F
.475 .162 .355 r
.37789 .76812 m .37727 .77116 L .37527 .77151 L F
.631 .66 .86 r
.38084 .76698 m .37963 .7684 L .37789 .76812 L F
.392 .009 .188 r
.37963 .7684 m .37727 .77116 L .37789 .76812 L F
.5 .115 .241 r
.48902 .81684 m .49135 .81719 L .49039 .81628 L F
.656 .326 .402 r
.49127 .81764 m .49337 .81662 L .49158 .81578 L F
.49127 .81764 m .49312 .81817 L .49337 .81662 L F
.533 0 0 r
.48805 .81439 m .49192 .81773 L .4892 .81553 L F
.49192 .81773 m .49198 .81778 L .49194 .81775 L F
.49192 .81773 m .49194 .81775 L .4892 .81553 L F
.5 .115 .241 r
.48902 .81684 m .49127 .81764 L .49135 .81719 L F
.49039 .81628 m .49135 .81719 L .49158 .81578 L F
.543 .171 .286 r
.49158 .81578 m .49337 .81662 L .49466 .81526 L F
.557 .146 .217 r
.43591 .82216 m .43772 .8233 L .43902 .82149 L F
.535 .159 .275 r
.43772 .8233 m .44118 .82126 L .43902 .82149 L F
.852 .654 .633 r
.66173 .74922 m .66045 .75116 L .65867 .7499 L F
.66173 .74922 m .66162 .75169 L .66045 .75116 L F
.66 .512 .672 r
.60862 .76958 m .6096 .77249 L .60645 .77224 L F
.637 .488 .663 r
.60963 .77473 m .60645 .77224 L .6096 .77249 L F
.60963 .77473 m .60743 .77511 L .60645 .77224 L F
.723 .417 .461 r
.49224 .81394 m .49198 .81778 L .48805 .81439 L F
.358 .821 .918 r
.49318 .81356 m .49238 .81337 L .49224 .81394 L F
0 0 0 r
.49238 .81337 m .49198 .81778 L .49224 .81394 L F
.69 .466 .578 r
.47957 .83228 m .47647 .83456 L .47701 .83232 L F
.47957 .83228 m .47956 .83476 L .47647 .83456 L F
.672 .451 .577 r
.4818 .83443 m .47957 .83228 L .48185 .83217 L F
.4818 .83443 m .47956 .83476 L .47957 .83228 L F
.386 0 0 r
.5295 .80447 m .53167 .80506 L .53242 .80433 L F
.594 .047 0 r
.53167 .80506 m .53464 .80559 L .53242 .80433 L F
.516 0 0 r
.53242 .80433 m .53464 .80559 L .53615 .80596 L F
.807 .575 .588 r
.535 .81126 m .53421 .81379 L .5342 .81151 L F
.662 .108 0 r
.48596 .88665 m .48685 .88809 L .48432 .88662 L F
.48596 .88665 m .48822 .88846 L .48685 .88809 L F
.533 0 0 r
.48216 .88515 m .48432 .88662 L .48311 .88613 L F
.745 .579 .67 r
.53109 .82539 m .53175 .82537 L .53271 .82827 L F
.783 .356 .238 r
.53388 .82383 m .53374 .82426 L .53067 .82335 L F
.53374 .82426 m .53316 .82611 L .5317 .82449 L F
.53374 .82426 m .5317 .82449 L .53067 .82335 L F
.53316 .82611 m .53295 .826 L .53067 .82335 L F
.745 .579 .67 r
.53175 .82537 m .53379 .82644 L .53271 .82827 L F
.783 .356 .238 r
.53316 .82611 m .53313 .8262 L .53295 .826 L F
0 0 .197 r
.53388 .82383 m .53448 .82527 L .53313 .8262 L F
.745 .579 .67 r
.53264 .82534 m .53448 .82527 L .53295 .826 L F
.739 .537 .619 r
.53313 .8262 m .53448 .82527 L .53264 .82534 L F
.173 .279 .733 r
.53067 .82335 m .53295 .826 L .53264 .82534 L F
.745 .579 .67 r
.53175 .82537 m .53264 .82534 L .53295 .826 L F
.739 .537 .619 r
.53313 .8262 m .53264 .82534 L .53109 .82539 L F
.173 .279 .733 r
.53156 .82339 m .53264 .82534 L .53175 .8234 L F
.53067 .82335 m .53264 .82534 L .53156 .82339 L F
.53175 .8234 m .53313 .8262 L .53181 .8234 L F
.53295 .826 m .53313 .8262 L .53175 .8234 L F
.745 .579 .67 r
.53295 .826 m .53448 .82527 L .53379 .82644 L F
.865 .929 .866 r
.53045 .82292 m .53181 .8234 L .53055 .82462 L F
.5298 .8247 m .53055 .82462 L .52945 .82569 L F
.53045 .82292 m .53055 .82462 L .5298 .8247 L F
.143 0 0 r
.53548 .82134 m .53718 .82142 L .53603 .82175 L F
.53548 .82134 m .53543 .82193 L .5348 .82089 L F
.364 .054 .299 r
.53559 .82169 m .53548 .82134 L .5348 .82089 L F
.53686 .82297 m .53523 .82337 L .53548 .82134 L F
.5361 .82221 m .53548 .82134 L .53559 .82169 L F
.895 .903 .824 r
.53718 .82142 m .53598 .82141 L .53602 .82169 L F
.076 .295 .779 r
.53628 .82151 m .53639 .8218 L .53601 .82158 L F
.805 .654 .695 r
.53562 .8182 m .5355 .82059 L .53845 .8191 L F
.076 .295 .779 r
.53595 .82137 m .53601 .82158 L .5348 .82089 L F
.143 0 0 r
.53545 .82167 m .53559 .82169 L .53543 .82193 L F
.53548 .82134 m .53603 .82175 L .53545 .82167 L F
.076 .295 .779 r
.53639 .8218 m .53609 .82176 L .53603 .82172 L F
.53601 .82158 m .53603 .82172 L .5348 .82089 L F
.895 .903 .824 r
.53718 .82142 m .53602 .82169 L .53603 .82175 L F
.076 .295 .779 r
.53639 .8218 m .53603 .82172 L .53601 .82158 L F
.364 .054 .299 r
.53641 .82244 m .53548 .82134 L .5361 .82221 L F
.076 .295 .779 r
.53648 .82203 m .53604 .82215 L .5348 .82089 L F
.143 0 0 r
.53559 .82169 m .53603 .82175 L .53565 .82186 L F
.895 .903 .824 r
.53603 .82175 m .53557 .8218 L .53565 .82186 L F
.53602 .82169 m .53557 .8218 L .53603 .82175 L F
.076 .295 .779 r
.53479 .82227 m .5348 .82089 L .53364 .82287 L F
.805 .654 .695 r
.53595 .82137 m .53543 .82193 L .53598 .82141 L F
.53544 .82177 m .53543 .82193 L .53595 .82137 L F
.5355 .82059 m .53598 .82141 L .53845 .8191 L F
.076 .295 .779 r
.53597 .82138 m .53598 .82141 L .53595 .82137 L F
.53598 .82141 m .53601 .82158 L .53595 .82137 L F
.53628 .82151 m .53601 .82158 L .53597 .82138 L F
.895 .903 .824 r
.53602 .82169 m .53598 .82141 L .53557 .8218 L F
.143 0 0 r
.53559 .82169 m .53565 .82186 L .53543 .82193 L F
.895 .903 .824 r
.53565 .82186 m .53557 .8218 L .53543 .82193 L F
0 0 .175 r
.53548 .82134 m .53536 .82233 L .53473 .8225 L F
.076 .295 .779 r
.53628 .82151 m .53595 .82137 L .53479 .82227 L F
0 0 .437 r
.5348 .82089 m .53543 .82193 L .53544 .82177 L F
.076 .295 .779 r
.53595 .82137 m .5348 .82089 L .53544 .82177 L F
0 0 .437 r
.5348 .82089 m .53544 .82177 L .53562 .8182 L F
.076 .295 .779 r
.53544 .82177 m .5348 .82089 L .53479 .82227 L F
.805 .654 .695 r
.5355 .82059 m .53544 .82177 L .53595 .82137 L F
.895 .903 .824 r
.53718 .82142 m .53845 .8191 L .53598 .82141 L F
.364 .054 .299 r
.53686 .82297 m .53641 .82244 L .5361 .82221 L F
.076 .295 .779 r
.53639 .8218 m .53648 .82203 L .53609 .82176 L F
.53648 .82203 m .53686 .82297 L .53604 .82215 L F
0 0 .175 r
.53473 .8225 m .53523 .82337 L .53388 .82383 L F
.53536 .82233 m .53523 .82337 L .53473 .8225 L F
0 0 .197 r
.53388 .82383 m .53523 .82337 L .53448 .82527 L F
.072 .629 .799 r
.45245 .87627 m .4537 .87642 L .45042 .87624 L F
.291 .76 .941 r
.45448 .87591 m .4537 .87642 L .45245 .87627 L F
.45448 .87591 m .45577 .87628 L .4537 .87642 L F
.568 .389 .599 r
.38421 .85562 m .38417 .85797 L .38211 .85825 L F
.575 .417 .63 r
.38417 .85797 m .38216 .86062 L .38211 .85825 L F
0 0 .095 r
.56917 .83489 m .57036 .83195 L .56898 .83431 L F
.91 .839 .383 r
.56852 .83727 m .56917 .83489 L .56898 .83431 L F
.359 .124 .416 r
.3926 .74567 m .3942 .74583 L .3927 .74549 L F
.3926 .74567 m .39378 .74605 L .3942 .74583 L F
.65 .822 .397 r
.56856 .79579 m .5668 .79875 L .56748 .7975 L F
.855 .65 .113 r
.56856 .79579 m .56811 .79283 L .57063 .79382 L F
.56856 .79579 m .56834 .79554 L .56811 .79283 L F
.866 .898 .48 r
.56856 .79579 m .56748 .7975 L .56834 .79554 L F
.646 .558 .742 r
.57063 .79382 m .57125 .79605 L .56856 .79579 L F
.641 .51 .688 r
.61079 .76702 m .61163 .77004 L .60862 .76958 L F
.653 .517 .686 r
.61163 .77004 m .6096 .77249 L .60862 .76958 L F
0 0 0 r
.42076 .894 m .4197 .8941 L .4215 .89378 L F
.42076 .894 m .41886 .89457 L .4197 .8941 L F
.466 .291 .559 r
.49545 .82419 m .49339 .82658 L .49368 .82419 L F
0 0 0 r
.40711 .82655 m .40915 .82628 L .41014 .82611 L F
.067 0 0 r
.40915 .82628 m .41254 .82577 L .41014 .82611 L F
.64 .419 .567 r
.61042 .79049 m .6106 .79262 L .60764 .79305 L F
.564 .385 .598 r
.61254 .79038 m .6106 .79262 L .61042 .79049 L F
.662 .57 .741 r
.36681 .754 m .36999 .75437 L .36918 .75131 L F
.685 .49 .617 r
.36681 .754 m .37002 .75655 L .36999 .75437 L F
.36681 .754 m .36805 .75681 L .37002 .75655 L F
.241 .742 .675 r
.42355 .89312 m .42727 .89182 L .4265 .89246 L F
0 0 0 r
.42727 .89182 m .42837 .89181 L .4265 .89246 L F
.42727 .89182 m .42923 .89136 L .42837 .89181 L F
.55 .008 0 r
.50063 .80904 m .50335 .81048 L .50372 .80934 L F
.693 .253 .201 r
.50335 .81048 m .50583 .80947 L .50372 .80934 L F
.769 .745 .831 r
.60303 .7564 m .59983 .75625 L .60222 .75413 L F
.764 .757 .847 r
.60531 .7542 m .60303 .7564 L .60222 .75413 L F
.663 .649 .825 r
.60639 .75697 m .60303 .7564 L .60531 .7542 L F
.807 .575 .588 r
.535 .81126 m .5358 .81393 L .53421 .81379 L F
.299 0 0 r
.51839 .87225 m .51745 .8716 L .51447 .87213 L F
.51839 .87225 m .51959 .87186 L .51745 .8716 L F
.825 .822 .846 r
.58031 .79024 m .58321 .78988 L .58256 .78791 L F
.58031 .79024 m .58154 .79121 L .58321 .78988 L F
.777 .806 .877 r
.58256 .78791 m .58321 .78988 L .58548 .78785 L F
.657 .948 .955 r
.39324 .90078 m .39661 .89985 L .39555 .8998 L F
.606 .922 .972 r
.39718 .89879 m .39661 .89985 L .39836 .89901 L F
.655 .964 .922 r
.39555 .8998 m .39661 .89985 L .39718 .89879 L F
.845 .901 .876 r
.49154 .8396 m .49234 .83678 L .49381 .83899 L F
.49154 .8396 m .49008 .83909 L .49234 .83678 L F
.583 .02 0 r
.49154 .8396 m .49184 .84053 L .49008 .83909 L F
.49154 .8396 m .49278 .84084 L .49184 .84053 L F
.696 .795 .926 r
.3953 .88316 m .39334 .88434 L .39187 .88328 L F
.548 .328 .533 r
.3896 .86291 m .3875 .86086 L .39101 .85981 L F
.603 .502 .712 r
.39253 .85847 m .39309 .85978 L .39101 .85981 L F
.456 .155 .365 r
.39143 .86254 m .39101 .85981 L .39309 .85978 L F
.39143 .86254 m .3896 .86291 L .39101 .85981 L F
0 0 0 r
.57181 .81099 m .57343 .80924 L .57314 .81077 L F
.037 0 .23 r
.57166 .81309 m .57181 .81099 L .57314 .81077 L F
.509 .868 .987 r
.56167 .77693 m .56333 .77583 L .56409 .77616 L F
.56167 .77693 m .56047 .77666 L .56333 .77583 L F
.302 .375 .771 r
.56333 .77583 m .56167 .77693 L .56047 .77666 L F
.672 .151 0 r
.56638 .78179 m .56629 .78187 L .56167 .77693 L F
.302 .375 .771 r
.56333 .77583 m .56629 .78187 L .56167 .77693 L F
.56167 .77693 m .56629 .78187 L .56333 .77583 L F
.56167 .77693 m .56629 .78187 L .56333 .77583 L F
.514 0 0 r
.57089 .79791 m .57222 .79785 L .57125 .79605 L F
.57089 .79791 m .57497 .79892 L .57222 .79785 L F
.394 .25 .564 r
.57284 .81886 m .57114 .81966 L .57259 .81647 L F
.753 .644 .74 r
.56755 .80363 m .56574 .80638 L .56442 .80333 L F
.643 .505 .68 r
.49339 .82658 m .49093 .82945 L .49163 .82705 L F
.584 .467 .686 r
.4945 .83174 m .49237 .83242 L .49093 .82945 L F
.819 .909 .901 r
.58641 .76493 m .58755 .76233 L .58789 .76403 L F
.749 .862 .931 r
.59059 .76201 m .58789 .76403 L .58755 .76233 L F
.179 0 .071 r
.50821 .81936 m .50603 .81962 L .5083 .81838 L F
.50821 .81936 m .50526 .82122 L .50603 .81962 L F
0 0 0 r
.50145 .88578 m .5023 .8855 L .50051 .88616 L F
.50145 .88578 m .50402 .88446 L .5023 .8855 L F
.214 .733 .858 r
.38216 .86062 m .38174 .86065 L .3799 .8608 L F
.594 .394 .58 r
.38174 .86065 m .37983 .86314 L .3799 .8608 L F
.681 .536 .682 r
.61291 .7645 m .61067 .7648 L .61275 .76218 L F
.66 .528 .692 r
.61496 .76185 m .61291 .7645 L .61275 .76218 L F
.555 .276 .446 r
.67571 .744 m .67689 .7438 L .67849 .74133 L F
.488 .581 .874 r
.52426 .82947 m .52773 .83161 L .52754 .83123 L F
.395 .853 .844 r
.42189 .8796 m .41824 .88055 L .42031 .87936 L F
.356 .808 .944 r
.42409 .87924 m .42189 .8796 L .42031 .87936 L F
.739 .691 .805 r
.60786 .75214 m .60837 .75456 L .60531 .7542 L F
.687 .611 .766 r
.60836 .75671 m .60531 .7542 L .60837 .75456 L F
.631 .62 .821 r
.61059 .7541 m .60837 .75456 L .60786 .75214 L F
.708 .623 .759 r
.61059 .7541 m .60836 .75671 L .60837 .75456 L F
.51 .89 .964 r
.5756 .84005 m .57405 .84024 L .57451 .84027 L F
.06 .438 .875 r
.57555 .84033 m .57451 .84027 L .57343 .83885 L F
.365 0 0 r
.57649 .84099 m .5756 .84005 L .57451 .84027 L F
.06 .438 .875 r
.57649 .84099 m .57451 .84027 L .57555 .84033 L F
.51 .89 .964 r
.57405 .84024 m .57195 .84051 L .57451 .84027 L F
.365 0 0 r
.57649 .84099 m .57823 .84007 L .5756 .84005 L F
.756 .628 .718 r
.56685 .80102 m .56755 .80363 L .56442 .80333 L F
.304 .784 .701 r
.51739 .87767 m .51894 .87712 L .52083 .87635 L F
.631 .62 .821 r
.61059 .7541 m .60927 .75078 L .61061 .75168 L F
.638 .777 .947 r
.61271 .75131 m .61061 .75168 L .60927 .75078 L F
.744 .61 .709 r
.61271 .75131 m .61059 .7541 L .61061 .75168 L F
.429 0 0 r
.44963 .83407 m .4486 .8347 L .44666 .83459 L F
.381 0 0 r
.4514 .83443 m .4486 .8347 L .44963 .83407 L F
0 0 0 r
.38337 .83094 m .38159 .83158 L .38068 .83197 L F
.571 .315 .489 r
.63103 .77449 m .63111 .77262 L .63323 .77432 L F
.577 .312 .479 r
.63111 .77262 m .63323 .77246 L .63323 .77432 L F
.648 .506 .675 r
.61299 .76666 m .61067 .7648 L .61291 .7645 L F
.61299 .76666 m .61079 .76702 L .61067 .7648 L F
0 0 0 r
.525 .87115 m .52296 .87152 L .52072 .87219 L F
.297 0 0 r
.46999 .81719 m .47165 .81744 L .47306 .81609 L F
.425 0 .03 r
.47165 .81744 m .47507 .81604 L .47306 .81609 L F
.801 .379 .244 r
.40086 .85128 m .39774 .84975 L .39906 .85112 L F
.759 .96 .934 r
.64893 .74305 m .64672 .74421 L .64778 .74257 L F
.989 .733 .435 r
.64893 .74305 m .64778 .74257 L .64783 .74083 L F
.472 .859 .977 r
.64893 .74305 m .64995 .74205 L .6506 .74193 L F
.64893 .74305 m .64778 .74257 L .64995 .74205 L F
.392 .009 .188 r
.37963 .7684 m .37936 .7708 L .37727 .77116 L F
.345 .107 .403 r
.38324 .76526 m .37963 .7684 L .38084 .76698 L F
.38324 .76526 m .38202 .7691 L .37963 .7684 L F
.535 .223 .385 r
.38202 .7691 m .37936 .7708 L .37963 .7684 L F
.572 .522 .761 r
.54372 .83196 m .54519 .83559 L .54686 .83459 L F
.687 .611 .766 r
.60836 .75671 m .60639 .75697 L .60531 .7542 L F
.988 .779 .386 r
.58661 .81324 m .58916 .81668 L .58795 .81427 L F
.493 .248 .471 r
.37334 .77206 m .37098 .77453 L .37137 .77243 L F
.842 .546 .489 r
.51596 .82663 m .51412 .82678 L .51352 .82609 L F
.572 .522 .761 r
.54372 .83196 m .54686 .83459 L .54631 .83243 L F
.742 .78 .884 r
.6279 .76311 m .62687 .76492 L .62546 .76379 L F
.663 .393 .501 r
.65003 .751 m .65361 .75146 L .65354 .74945 L F
.444 .445 .765 r
.65354 .74945 m .65197 .74634 L .65541 .74554 L F
.65354 .74945 m .65457 .74623 L .65197 .74634 L F
.65354 .74945 m .65486 .7496 L .65457 .74623 L F
.472 .247 .49 r
.65354 .74945 m .65361 .75146 L .65486 .7496 L F
.765 .727 .817 r
.58842 .77775 m .58651 .78007 L .59002 .78005 L F
.708 .345 .358 r
.58651 .78007 m .58858 .78211 L .59002 .78005 L F
.506 .522 .807 r
.59002 .78005 m .59063 .77706 L .58842 .77775 L F
.59002 .78005 m .59194 .77979 L .59063 .77706 L F
.763 .565 .63 r
.58858 .78211 m .59194 .77979 L .59002 .78005 L F
.782 .824 .885 r
.58641 .76493 m .58274 .76609 L .58533 .76432 L F
.819 .909 .901 r
.58641 .76493 m .58533 .76432 L .58755 .76233 L F
.128 0 0 r
.49303 .88855 m .49655 .88717 L .49501 .88821 L F
.108 0 0 r
.49501 .88821 m .49655 .88717 L .49857 .88672 L F
.682 .937 .966 r
.62234 .76607 m .62388 .76494 L .62095 .76631 L F
.281 .17 .545 r
.40729 .84678 m .40639 .84541 L .40856 .84488 L F
.40729 .84678 m .40625 .84756 L .40639 .84541 L F
.781 .473 .468 r
.52103 .81608 m .52273 .81847 L .52461 .81641 L F
.431 .272 .563 r
.52623 .8159 m .52622 .81615 L .52461 .81641 L F
.445 .327 .624 r
.52461 .81641 m .52622 .81615 L .52573 .81401 L F
.295 .266 .655 r
.52644 .81852 m .52461 .81641 L .52622 .81615 L F
.715 .501 .599 r
.52273 .81847 m .52622 .81615 L .52461 .81641 L F
.933 .718 .237 r
.60939 .78277 m .60895 .783 L .60926 .7823 L F
.60939 .78277 m .60945 .78522 L .60895 .783 L F
.485 .071 .179 r
.44469 .83447 m .4432 .83623 L .44135 .83537 L F
.368 0 .014 r
.44666 .83459 m .4432 .83623 L .44469 .83447 L F
.527 .115 .203 r
.51269 .83737 m .5116 .83906 L .5095 .83883 L F
.421 .74 .992 r
.51348 .8372 m .51374 .83685 L .51373 .83685 L F
.1 .247 .729 r
.51166 .83443 m .51363 .8368 L .51269 .83737 L F
.524 .239 .423 r
.50887 .83492 m .51057 .83613 L .51166 .83443 L F
.592 .508 .729 r
.51057 .83155 m .51183 .83423 L .5115 .83469 L F
.753 .242 0 r
.51201 .83514 m .51243 .83535 L .51166 .83443 L F
.51209 .8353 m .51243 .83535 L .51201 .83514 L F
.51258 .83629 m .51166 .83443 L .51215 .83376 L F
.592 .508 .729 r
.51183 .83423 m .51203 .83464 L .51152 .83469 L F
0 0 0 r
.51166 .83443 m .51108 .83534 L .51152 .83469 L F
.364 .389 .753 r
.51215 .83376 m .51203 .83464 L .51183 .83423 L F
0 0 0 r
.51191 .83409 m .51165 .83448 L .51205 .83389 L F
.51165 .83448 m .51183 .83423 L .51205 .83389 L F
.364 .389 .753 r
.51215 .83376 m .51183 .83423 L .51057 .83155 L F
0 0 0 r
.51165 .83448 m .51152 .83469 L .51183 .83423 L F
.51166 .83443 m .51152 .83469 L .51191 .83409 L F
.524 .239 .423 r
.51057 .83613 m .50887 .83492 L .51152 .83469 L F
.51057 .83613 m .51152 .83469 L .51203 .83464 L F
.592 .508 .729 r
.51183 .83423 m .51152 .83469 L .5115 .83469 L F
0 0 0 r
.51205 .83389 m .51057 .83613 L .51215 .83376 L F
.51108 .83534 m .51057 .83613 L .51205 .83389 L F
.915 .9 .796 r
.51215 .83376 m .51143 .83484 L .51203 .83464 L F
.51143 .83484 m .51057 .83613 L .5117 .83498 L F
.51143 .83484 m .5117 .83498 L .51203 .83464 L F
.753 .242 0 r
.51209 .8353 m .51363 .8368 L .51243 .83535 L F
.51345 .83671 m .51363 .8368 L .51209 .8353 L F
.51258 .83629 m .51309 .83633 L .51209 .8353 L F
.758 .493 .532 r
.51565 .83598 m .51377 .83617 L .51215 .83376 L F
.51377 .83617 m .51258 .83629 L .51251 .83588 L F
.51377 .83617 m .51251 .83588 L .51215 .83376 L F
.765 .717 .808 r
.51668 .83714 m .51602 .83719 L .51565 .83598 L F
.421 .74 .992 r
.51348 .8372 m .51565 .83713 L .51554 .837 L F
.51348 .8372 m .51554 .837 L .51472 .83667 L F
.765 .717 .808 r
.51602 .83719 m .51407 .83733 L .51481 .8367 L F
.51602 .83719 m .51554 .837 L .51565 .83598 L F
.51554 .837 m .51503 .83651 L .51565 .83598 L F
.51668 .83714 m .51582 .83818 L .51574 .83753 L F
.51668 .83714 m .51435 .8381 L .51555 .83731 L F
.689 .597 .748 r
.51699 .839 m .5148 .8394 L .51668 .83714 L F
.771 .534 .576 r
.51699 .839 m .51495 .84186 L .5148 .8394 L F
.51699 .839 m .51698 .84141 L .51495 .84186 L F
.624 .411 .572 r
.51941 .83901 m .51698 .84141 L .51699 .839 L F
.531 .273 .468 r
.5157 .83721 m .51572 .84078 L .51771 .8403 L F
.51565 .83713 m .51565 .83724 L .5157 .83721 L F
.51565 .83724 m .51572 .84078 L .5157 .83721 L F
.765 .717 .808 r
.51555 .83731 m .51435 .8381 L .51555 .83731 L F
.51435 .8381 m .51435 .8381 L .51555 .83731 L F
.541 .28 .469 r
.51555 .83731 m .51565 .83724 L .51565 .83713 L F
.765 .717 .808 r
.5157 .83721 m .51555 .83731 L .51569 .83721 L F
.51668 .83714 m .51555 .83731 L .5157 .83721 L F
.51574 .83753 m .5148 .8394 L .51435 .8381 L F
.51582 .83818 m .5148 .8394 L .51574 .83753 L F
.541 .28 .469 r
.51355 .83863 m .51565 .83713 L .51355 .8372 L F
.51348 .83725 m .51355 .8372 L .51348 .8372 L F
.51355 .83863 m .51355 .8372 L .51348 .83725 L F
.741 .705 .817 r
.51333 .83862 m .5148 .8394 L .51236 .83914 L F
.51435 .8381 m .51443 .83833 L .51355 .83856 L F
.51443 .83833 m .5148 .8394 L .51333 .83862 L F
.699 .291 .269 r
.5148 .8394 m .51365 .84077 L .5116 .83906 L F
.541 .28 .469 r
.51365 .84077 m .51546 .83747 L .51355 .83863 L F
.51546 .83747 m .51555 .83731 L .51435 .8381 L F
.51546 .83747 m .51435 .8381 L .51355 .83863 L F
.741 .705 .817 r
.51434 .83807 m .51435 .8381 L .51333 .83862 L F
.51435 .8381 m .51355 .83856 L .51333 .83862 L F
.632 .342 .461 r
.5116 .83906 m .51365 .84077 L .51355 .83856 L F
.5116 .83906 m .51355 .83856 L .51348 .83725 L F
.06 0 0 r
.51407 .83733 m .51206 .83835 L .51335 .83735 L F
.632 .342 .461 r
.5116 .83906 m .51348 .83725 L .51348 .8372 L F
.06 0 0 r
.51265 .83805 m .5116 .83906 L .51206 .83835 L F
.51407 .83733 m .5116 .83906 L .51265 .83805 L F
.51335 .83735 m .51206 .83835 L .51269 .83737 L F
.741 .705 .817 r
.51407 .83733 m .51434 .83807 L .5116 .83906 L F
.51434 .83807 m .51236 .83914 L .5116 .83906 L F
0 0 .355 r
.5148 .8394 m .51495 .84186 L .51572 .84078 L F
.5148 .8394 m .51572 .84078 L .51365 .84077 L F
.541 .28 .469 r
.51365 .84077 m .51572 .84078 L .51565 .83736 L F
.51555 .83742 m .51565 .83736 L .51565 .83724 L F
.51365 .84077 m .51565 .83736 L .51555 .83742 L F
.51365 .84077 m .51565 .83724 L .51555 .83731 L F
.634 .569 .764 r
.5191 .83677 m .51699 .839 L .51668 .83714 L F
.5191 .83677 m .51941 .83901 L .51699 .839 L F
.531 .273 .468 r
.51569 .83714 m .51771 .8403 L .5171 .83756 L F
.51565 .83713 m .5157 .83721 L .51569 .83714 L F
.5157 .83721 m .51771 .8403 L .51569 .83714 L F
.541 .28 .469 r
.51555 .83731 m .51565 .83713 L .51355 .83863 L F
.765 .717 .808 r
.51569 .83721 m .51435 .8381 L .51407 .83733 L F
.753 .242 0 r
.51258 .83629 m .51345 .83671 L .51309 .83633 L F
.421 .74 .992 r
.51337 .83709 m .51401 .83635 L .51258 .83629 L F
.771 .805 .88 r
.51377 .83617 m .51381 .83634 L .51258 .83629 L F
.421 .74 .992 r
.51401 .83635 m .5145 .83578 L .51258 .83629 L F
.753 .242 0 r
.51258 .83629 m .51407 .83733 L .51363 .8368 L F
.421 .74 .992 r
.51348 .8372 m .5145 .83578 L .51337 .83709 L F
.771 .805 .88 r
.51381 .83634 m .51407 .83733 L .51258 .83629 L F
.421 .74 .992 r
.51409 .83635 m .51457 .83576 L .5145 .83578 L F
.51373 .83685 m .51412 .83635 L .51409 .83635 L F
.771 .805 .88 r
.51565 .83598 m .51517 .8364 L .51377 .83617 L F
.421 .74 .992 r
.51412 .83635 m .51457 .83576 L .51409 .83635 L F
.771 .805 .88 r
.51517 .8364 m .51481 .8367 L .51412 .83635 L F
.51517 .8364 m .51412 .83635 L .51377 .83617 L F
.421 .74 .992 r
.51348 .8372 m .51473 .83666 L .51412 .83635 L F
.51374 .83685 m .51412 .83635 L .51373 .83685 L F
.51412 .83635 m .51457 .83576 L .51412 .83635 L F
.51412 .83635 m .51412 .83635 L .51373 .83685 L F
.771 .805 .88 r
.51481 .8367 m .51407 .83733 L .51381 .83634 L F
.51412 .83635 m .51381 .83634 L .51377 .83617 L F
.51481 .8367 m .51381 .83634 L .51412 .83635 L F
.421 .74 .992 r
.51412 .83635 m .51514 .83649 L .51419 .83627 L F
.51473 .83666 m .51514 .83649 L .51412 .83635 L F
0 .289 .764 r
.51457 .83576 m .51554 .837 L .5171 .83756 L F
.51554 .837 m .51565 .83713 L .5157 .83714 L F
.51554 .837 m .5157 .83714 L .5171 .83756 L F
.765 .717 .808 r
.51554 .837 m .51481 .8367 L .51503 .83651 L F
.421 .74 .992 r
.51472 .83667 m .51554 .837 L .51514 .83649 L F
.51419 .83627 m .51514 .83649 L .51457 .83576 L F
.311 .802 .836 r
.51195 .83623 m .51258 .83629 L .51457 .83576 L F
.145 0 0 r
.51057 .83613 m .51258 .83629 L .51105 .83639 L F
.311 .802 .836 r
.51105 .83639 m .51258 .83629 L .51195 .83623 L F
.592 .508 .729 r
.50985 .83298 m .5115 .83469 L .50887 .83492 L F
.51057 .83155 m .5115 .83469 L .50985 .83298 L F
.1 .247 .729 r
.51363 .8368 m .51407 .83733 L .51315 .83736 L F
.51363 .8368 m .51315 .83736 L .51269 .83737 L F
.809 .747 .795 r
.50777 .83109 m .5033 .83447 L .50327 .83193 L F
.966 .647 .266 r
.50695 .82954 m .50777 .83109 L .50497 .82997 L F
.50695 .82954 m .50796 .83169 L .50777 .83109 L F
.556 .612 .864 r
.50923 .82971 m .50796 .83169 L .50728 .83025 L F
.006 0 0 r
.50923 .82971 m .5081 .83048 L .50985 .82954 L F
.50923 .82971 m .50999 .82947 L .51149 .82916 L F
.50923 .82971 m .50985 .82954 L .50999 .82947 L F
.556 .612 .864 r
.50923 .82971 m .50728 .83025 L .50708 .8298 L F
.507 .82955 m .50708 .8298 L .50695 .82954 L F
.50923 .82971 m .50708 .8298 L .507 .82955 L F
.809 .747 .795 r
.5075 .83129 m .50657 .83504 L .5033 .83447 L F
.50777 .83109 m .5076 .83164 L .5075 .83129 L F
.5076 .83164 m .50657 .83504 L .5075 .83129 L F
.067 0 0 r
.50657 .83504 m .50419 .8372 L .5033 .83447 L F
.553 .649 .898 r
.50419 .8372 m .50717 .83842 L .50642 .83688 L F
0 0 0 r
.50642 .83688 m .5057 .837 L .50419 .8372 L F
.533 .578 .846 r
.50717 .83842 m .50833 .83657 L .50642 .83688 L F
.461 0 0 r
.50833 .83657 m .50712 .83749 L .5057 .837 L F
.967 .892 .701 r
.5064 .83707 m .5057 .837 L .50712 .83749 L F
.067 0 0 r
.50657 .83504 m .5057 .837 L .50453 .83689 L F
.967 .892 .701 r
.50477 .83613 m .5057 .837 L .5064 .83707 L F
.067 0 0 r
.50453 .83689 m .5057 .837 L .50419 .8372 L F
.548 .467 .716 r
.50796 .83169 m .50657 .83504 L .50777 .83109 L F
.50796 .83169 m .50887 .83492 L .50657 .83504 L F
.41 .131 .375 r
.50642 .83688 m .50887 .83492 L .50657 .83504 L F
.50642 .83688 m .50833 .83657 L .50887 .83492 L F
.605 .18 .208 r
.50833 .83657 m .50657 .83504 L .50887 .83492 L F
.50833 .83657 m .5057 .837 L .50657 .83504 L F
.548 .469 .718 r
.50777 .83109 m .50887 .83492 L .50657 .83504 L F
.479 .88 .721 r
.5496 .82793 m .55098 .82733 L .55135 .82686 L F
.317 0 0 r
.53783 .80679 m .53615 .80596 L .53464 .80559 L F
.53783 .80679 m .53755 .80662 L .53615 .80596 L F
.602 .667 .885 r
.58128 .78006 m .58345 .77973 L .58208 .77716 L F
.649 .538 .716 r
.58269 .78276 m .58345 .77973 L .58128 .78006 L F
.843 .782 .793 r
.61661 .76967 m .61375 .7718 L .61565 .76915 L F
.784 .733 .806 r
.61814 .76637 m .61661 .76967 L .61565 .76915 L F
.306 0 .081 r
.48219 .81261 m .48479 .81142 L .4829 .812 L F
.67 .582 .747 r
.64987 .74578 m .64805 .74618 L .64672 .74421 L F
0 0 0 r
.64987 .74578 m .64712 .7486 L .64805 .74618 L F
.782 .534 .562 r
.51615 .84726 m .51751 .84517 L .51445 .84747 L F
.59 .294 .435 r
.51633 .84726 m .51751 .84517 L .51615 .84726 L F
.759 .495 .534 r
.51551 .84872 m .51633 .84726 L .51657 .84999 L F
.51633 .84726 m .51751 .84517 L .51702 .84771 L F
.51633 .84726 m .51702 .84771 L .51657 .84999 L F
.535 .283 .48 r
.51657 .84999 m .51751 .84517 L .51901 .84723 L F
.59 .294 .435 r
.51901 .84723 m .51751 .84517 L .51633 .84726 L F
.51901 .84723 m .51633 .84726 L .51803 .84433 L F
.51633 .84726 m .51615 .84726 L .5162 .84717 L F
.759 .495 .534 r
.51511 .84698 m .51751 .84517 L .5161 .84715 L F
.717 .692 .825 r
.51803 .84433 m .5162 .84717 L .51479 .8439 L F
.5162 .84717 m .51615 .84726 L .5161 .84715 L F
.5162 .84717 m .5161 .84715 L .51479 .8439 L F
.759 .495 .534 r
.5161 .84715 m .51751 .84517 L .51643 .84709 L F
.51445 .84747 m .51511 .84698 L .5161 .84715 L F
.811 .736 .782 r
.5161 .84715 m .51615 .84726 L .51445 .84747 L F
.759 .495 .534 r
.51445 .84747 m .51643 .84709 L .51551 .84872 L F
.811 .736 .782 r
.51479 .8439 m .5161 .84715 L .51445 .84747 L F
.59 .294 .435 r
.51633 .84726 m .5162 .84717 L .51803 .84433 L F
.662 .418 .54 r
.3875 .86086 m .38528 .86277 L .38546 .86077 L F
.3875 .86086 m .38753 .86336 L .38528 .86277 L F
.548 .328 .533 r
.3896 .86291 m .38753 .86336 L .3875 .86086 L F
.657 .566 .741 r
.58869 .79225 m .59104 .79 L .58892 .79047 L F
.708 .623 .759 r
.61059 .7541 m .61173 .75697 L .60836 .75671 L F
.738 .637 .748 r
.61379 .75453 m .61173 .75697 L .61059 .7541 L F
.71 .594 .725 r
.61373 .75659 m .61173 .75697 L .61379 .75453 L F
.647 .581 .767 r
.61487 .75954 m .61173 .75697 L .61373 .75659 L F
.678 .567 .723 r
.61586 .75389 m .61373 .75659 L .61379 .75453 L F
.61586 .75389 m .61695 .75686 L .61373 .75659 L F
.679 .562 .716 r
.61695 .75686 m .61487 .75954 L .61373 .75659 L F
.677 .342 .4 r
.49466 .81526 m .49337 .81662 L .49466 .81634 L F
.773 .63 .702 r
.57314 .78193 m .57051 .78084 L .5726 .77999 L F
.57314 .78193 m .57067 .78314 L .57051 .78084 L F
.922 .826 .367 r
.57314 .78193 m .57058 .78406 L .57067 .78314 L F
.57314 .78193 m .5723 .7844 L .57058 .78406 L F
.57314 .78193 m .57251 .7859 L .5723 .7844 L F
.763 .857 .92 r
.57471 .7795 m .57314 .78193 L .5726 .77999 L F
.57471 .7795 m .57592 .78059 L .57314 .78193 L F
.727 .597 .711 r
.38856 .85268 m .38946 .85564 L .38635 .8554 L F
.541 .395 .632 r
.39145 .85286 m .38946 .85564 L .38856 .85268 L F
.39145 .85286 m .39148 .85539 L .38946 .85564 L F
.246 0 .205 r
.46335 .87214 m .46105 .87365 L .46286 .87278 L F
0 0 0 r
.46286 .87278 m .46105 .87365 L .4595 .87458 L F
.49179 .8706 m .49104 .8736 L .49301 .87119 L F
.697 .588 .73 r
.617 .75923 m .61487 .75954 L .61695 .75686 L F
.679 .525 .669 r
.617 .75923 m .61496 .76185 L .61487 .75954 L F
.778 .718 .796 r
.59367 .76208 m .59059 .76201 L .59293 .75966 L F
.689 .562 .707 r
.51352 .82609 m .51484 .82236 L .5124 .82585 L F
.476 0 0 r
.54105 .81958 m .54218 .82061 L .53976 .8195 L F
.54105 .81958 m .54303 .82136 L .54218 .82061 L F
.69 .474 .588 r
.58538 .80079 m .58557 .79846 L .58261 .79949 L F
.631 .4 .55 r
.58767 .80057 m .58557 .79846 L .58538 .80079 L F
.58767 .80057 m .58778 .79828 L .58557 .79846 L F
.452 .873 .935 r
.38922 .82982 m .38517 .83023 L .38792 .83001 L F
.165 0 0 r
.38926 .83038 m .38922 .82982 L .38792 .83001 L F
.38926 .83038 m .39131 .8297 L .38922 .82982 L F
.464 .359 .65 r
.5511 .83979 m .55167 .84202 L .55291 .84006 L F
.732 .336 .301 r
.55167 .84202 m .55291 .84006 L .5511 .83979 L F
.084 0 .253 r
.36255 .73074 m .36339 .73066 L .3642 .72891 L F
.114 .065 .519 r
.36255 .73074 m .36307 .7349 L .36339 .73066 L F
.458 .079 .232 r
.47892 .8151 m .48219 .81261 L .47996 .81332 L F
.634 .441 .604 r
.36584 .75945 m .36806 .76156 L .36818 .75905 L F
.36584 .75945 m .36577 .76181 L .36806 .76156 L F
0 0 0 r
.46217 .8831 m .46548 .88133 L .46411 .88308 L F
.559 .009 0 r
.46548 .88133 m .46622 .88256 L .46411 .88308 L F
.46548 .88133 m .46738 .88208 L .46622 .88256 L F
.115 .408 .858 r
.55597 .79422 m .55521 .79489 L .55371 .79417 L F
.55597 .79422 m .55665 .7955 L .55521 .79489 L F
.021 .378 .843 r
.40086 .85128 m .40285 .85337 L .40279 .85234 L F
.634 .921 .977 r
.40279 .85234 m .40285 .85337 L .404 .85251 L F
.071 0 .228 r
.40285 .85337 m .40218 .85521 L .404 .85251 L F
.634 .921 .977 r
.404 .85251 m .40285 .85337 L .40279 .85234 L F
.071 0 .228 r
.40285 .85337 m .40218 .85521 L .404 .85251 L F
.634 .921 .977 r
.40279 .85234 m .40285 .85337 L .404 .85251 L F
.042 .227 .728 r
.54445 .81098 m .54632 .81307 L .54563 .81397 L F
.064 .261 .753 r
.54632 .81307 m .54753 .81586 L .54563 .81397 L F
.563 .571 .819 r
.37709 .74312 m .37641 .74634 L .37515 .74389 L F
.37709 .74312 m .37835 .74603 L .37641 .74634 L F
.557 .453 .692 r
.37874 .74828 m .37641 .74634 L .37835 .74603 L F
.37874 .74828 m .37681 .75022 L .37641 .74634 L F
.66 .528 .692 r
.61496 .76185 m .61607 .76467 L .61291 .7645 L F
.666 .5 .65 r
.61607 .76467 m .61299 .76666 L .61291 .7645 L F
.774 .682 .762 r
.58429 .78269 m .58638 .78383 L .58651 .78007 L F
.735 .469 .526 r
.58435 .78492 m .58638 .78383 L .58429 .78269 L F
.58435 .78492 m .5876 .7853 L .58638 .78383 L F
.39 .357 .701 r
.58651 .78007 m .58638 .78383 L .58858 .78211 L F
.646 .463 .621 r
.58638 .78383 m .58973 .78463 L .58858 .78211 L F
.58638 .78383 m .5876 .7853 L .58973 .78463 L F
.313 0 0 r
.49711 .80856 m .50063 .80904 L .49846 .80954 L F
.432 0 .058 r
.4197 .82597 m .42181 .82592 L .42321 .82447 L F
.443 0 .085 r
.42181 .82592 m .42528 .82437 L .42321 .82447 L F
.232 0 .001 r
.43384 .89148 m .435 .89017 L .43689 .88958 L F
.589 .322 .48 r
.63323 .77432 m .63581 .7707 L .63535 .77385 L F
.63323 .77432 m .63323 .77246 L .63581 .7707 L F
.538 .23 .394 r
.63833 .77088 m .63535 .77385 L .63581 .7707 L F
.529 .097 .164 r
.44848 .82103 m .45061 .82118 L .45186 .81972 L F
.506 .071 .147 r
.45186 .81972 m .45061 .82118 L .45377 .82051 L F
.953 .665 .222 r
.49314 .84952 m .49288 .85041 L .49249 .84741 L F
.125 0 .241 r
.49545 .84752 m .49314 .84952 L .49249 .84741 L F
.49545 .84752 m .49463 .84945 L .49314 .84952 L F
.091 0 0 r
.49463 .84945 m .49288 .85041 L .49314 .84952 L F
.669 .515 .666 r
.6451 .74917 m .64564 .75341 L .64243 .75183 L F
.278 .231 .624 r
.64682 .75085 m .6451 .74917 L .64712 .7486 L F
.6462 .75024 m .64564 .75341 L .6451 .74917 L F
.775 .536 .574 r
.64361 .75052 m .64633 .74903 L .64539 .74844 L F
.64633 .74903 m .64712 .7486 L .64639 .74853 L F
.64633 .74903 m .64639 .74853 L .64539 .74844 L F
.278 .231 .624 r
.64682 .75085 m .64591 .75282 L .6462 .75024 L F
.64591 .75282 m .64564 .75341 L .6462 .75024 L F
.748 .628 .726 r
.63427 .75109 m .63504 .75427 L .63174 .75392 L F
.721 .524 .623 r
.63511 .75644 m .63174 .75392 L .63504 .75427 L F
.712 .606 .736 r
.63713 .7515 m .63504 .75427 L .63427 .75109 L F
.685 .566 .715 r
.63713 .7515 m .63865 .75456 L .63504 .75427 L F
.751 .592 .68 r
.63865 .75456 m .63511 .75644 L .63504 .75427 L F
.519 .892 .699 r
.51449 .82165 m .51483 .82117 L .51643 .82029 L F
.284 .488 .881 r
.51484 .82236 m .51483 .8214 L .51449 .82165 L F
.689 .562 .707 r
.51352 .82609 m .51412 .82678 L .51484 .82236 L F
.592 .246 .353 r
.51487 .8215 m .51433 .82481 L .51218 .82322 L F
.739 .678 .792 r
.51619 .82128 m .51621 .82136 L .51865 .82148 L F
.51621 .82136 m .5168 .82376 L .51824 .82199 L F
.51621 .82136 m .51824 .82199 L .51865 .82148 L F
.592 .246 .353 r
.51551 .82109 m .5154 .82144 L .51487 .8215 L F
.796 .591 .625 r
.51551 .82109 m .51487 .8215 L .51486 .82144 L F
.739 .678 .792 r
.51483 .82117 m .51509 .82151 L .51618 .82126 L F
.51563 .82139 m .5168 .82376 L .51618 .82126 L F
.51509 .82151 m .51547 .82201 L .51563 .82141 L F
.626 .503 .693 r
.51484 .82236 m .51412 .82678 L .51736 .82591 L F
.284 .488 .881 r
.51486 .82237 m .5168 .82376 L .51547 .82201 L F
.626 .503 .693 r
.51484 .82236 m .51736 .82591 L .5168 .82376 L F
.643 .298 .371 r
.51684 .82474 m .51578 .82184 L .51705 .82202 L F
.51578 .82184 m .51563 .82141 L .51614 .82163 L F
.51578 .82184 m .51614 .82163 L .51705 .82202 L F
.284 .488 .881 r
.51484 .82236 m .51486 .82237 L .51507 .82148 L F
.51486 .82237 m .51547 .82201 L .51509 .82151 L F
.51486 .82237 m .51509 .82151 L .51506 .8215 L F
.592 .246 .353 r
.51509 .82151 m .51516 .82219 L .5149 .82156 L F
.739 .678 .792 r
.51509 .82151 m .51563 .82141 L .5154 .82144 L F
.592 .246 .353 r
.5154 .82144 m .51534 .82162 L .51509 .82151 L F
.51534 .82162 m .51516 .82219 L .51509 .82151 L F
.284 .488 .881 r
.51484 .82236 m .51506 .8215 L .51483 .8214 L F
.592 .246 .353 r
.51502 .82148 m .5149 .82156 L .51487 .8215 L F
.5154 .82144 m .51509 .82151 L .51502 .82148 L F
.51509 .82151 m .5149 .82156 L .51502 .82148 L F
.796 .591 .625 r
.51551 .82109 m .51491 .82142 L .51509 .82103 L F
.284 .488 .881 r
.51483 .8214 m .51493 .82144 L .51483 .82136 L F
.51493 .82144 m .51488 .82139 L .51483 .82136 L F
.51483 .8214 m .51483 .82134 L .51481 .82136 L F
.51483 .8214 m .51481 .82136 L .51449 .82165 L F
.51483 .82134 m .5148 .82121 L .51449 .82165 L F
.796 .591 .625 r
.51491 .82142 m .5122 .82288 L .51474 .82125 L F
.51491 .82142 m .51474 .82125 L .51509 .82103 L F
.284 .488 .881 r
.51493 .82144 m .51507 .82148 L .51488 .82139 L F
.51506 .8215 m .51507 .82148 L .51483 .8214 L F
.51506 .8215 m .51509 .82151 L .51507 .82148 L F
.51483 .82136 m .51507 .82148 L .51483 .82117 L F
.643 .298 .371 r
.51684 .82474 m .51433 .82481 L .51534 .82162 L F
.51551 .8217 m .51534 .82162 L .5154 .82144 L F
.51684 .82474 m .51534 .82162 L .51551 .8217 L F
.51563 .82141 m .5154 .82144 L .51551 .82109 L F
.739 .678 .792 r
.51547 .82201 m .5168 .82376 L .51563 .82139 L F
.643 .298 .371 r
.51684 .82474 m .5154 .82144 L .51563 .82141 L F
.739 .678 .792 r
.5154 .82144 m .51563 .82141 L .51563 .82139 L F
.399 0 0 r
.51732 .82191 m .51587 .82126 L .51567 .82124 L F
.643 .298 .371 r
.51563 .82141 m .51551 .82109 L .51567 .82124 L F
.399 0 0 r
.51598 .82151 m .51567 .82124 L .51483 .82117 L F
.51732 .82191 m .51567 .82124 L .51598 .82151 L F
.51587 .82126 m .51551 .82109 L .51483 .82117 L F
.643 .298 .371 r
.51567 .82124 m .51551 .82109 L .51568 .8212 L F
.739 .678 .792 r
.51598 .82151 m .5187 .82142 L .51732 .82191 L F
.643 .298 .371 r
.51563 .82141 m .51568 .82123 L .51607 .8216 L F
.739 .678 .792 r
.51483 .82117 m .51568 .82123 L .51598 .82151 L F
.5158 .82123 m .51639 .8215 L .51598 .82151 L F
.399 0 0 r
.51732 .82191 m .51568 .8212 L .5158 .82123 L F
.51732 .82191 m .5158 .82123 L .51587 .82126 L F
.739 .678 .792 r
.51568 .82123 m .5158 .82123 L .51598 .82151 L F
.51618 .82126 m .51619 .82128 L .5187 .82142 L F
.51619 .82128 m .51865 .82148 L .5187 .82142 L F
.5158 .82123 m .5187 .82142 L .51639 .8215 L F
.643 .298 .371 r
.51607 .8216 m .51568 .8212 L .51705 .82202 L F
.51568 .82123 m .51568 .8212 L .51607 .8216 L F
.399 0 0 r
.51732 .82191 m .51705 .82202 L .51568 .8212 L F
.51587 .82126 m .51568 .8212 L .51551 .82109 L F
.592 .246 .353 r
.51516 .82219 m .51433 .82481 L .51487 .8215 L F
.284 .488 .881 r
.51483 .82134 m .51483 .82117 L .5148 .82121 L F
.796 .591 .625 r
.51486 .82144 m .51218 .82322 L .5122 .82288 L F
.51487 .8215 m .51218 .82322 L .51486 .82144 L F
.51509 .82103 m .5122 .82288 L .51231 .8206 L F
.519 .892 .699 r
.51643 .82029 m .51509 .82103 L .51736 .81964 L F
.51509 .82103 m .51483 .82117 L .51551 .82076 L F
.51509 .82103 m .51551 .82076 L .51736 .81964 L F
.796 .591 .625 r
.51551 .82109 m .51509 .82103 L .51483 .82117 L F
.51509 .82103 m .51231 .8206 L .51483 .82117 L F
.727 .59 .702 r
.63915 .74881 m .64046 .75193 L .63713 .7515 L F
.727 .584 .694 r
.64069 .75424 m .63713 .7515 L .64046 .75193 L F
.671 .395 .495 r
.64243 .75183 m .64193 .75352 L .64046 .75193 L F
.448 .375 .682 r
.64193 .75352 m .64069 .75424 L .64046 .75193 L F
.51 .236 .436 r
.64495 .75179 m .64243 .75183 L .64564 .75341 L F
.64495 .75179 m .64193 .75352 L .64243 .75183 L F
.215 .353 .788 r
.57682 .77916 m .57592 .78059 L .57471 .7795 L F
.57682 .77916 m .57808 .78209 L .57592 .78059 L F
.335 0 0 r
.51365 .81739 m .51248 .81844 L .51029 .81871 L F
.537 .063 .078 r
.51584 .81822 m .51248 .81844 L .51365 .81739 L F
.756 .654 .749 r
.62211 .75944 m .62029 .75955 L .62221 .75685 L F
.661 .495 .649 r
.62211 .75944 m .62037 .7618 L .62029 .75955 L F
.62211 .75944 m .625 .76285 L .62037 .7618 L F
.694 .59 .735 r
.62443 .75643 m .62211 .75944 L .62221 .75685 L F
.62443 .75643 m .62565 .75938 L .62211 .75944 L F
.667 .496 .644 r
.62563 .76171 m .62211 .75944 L .62565 .75938 L F
.62563 .76171 m .625 .76285 L .62211 .75944 L F
.662 .918 .976 r
.4671 .87076 m .46526 .87107 L .46741 .87043 L F
.324 0 .105 r
.46741 .87043 m .46526 .87107 L .46406 .87284 L F
.055 .268 .761 r
.46794 .86984 m .46741 .87043 L .46622 .8712 L F
.4681 .86971 m .46741 .87043 L .46794 .86984 L F
.662 .918 .976 r
.46848 .87052 m .4671 .87076 L .46741 .87043 L F
.161 .698 .826 r
.46741 .87043 m .47064 .87037 L .46848 .87052 L F
.766 .329 .213 r
.48492 .83558 m .48381 .83654 L .4818 .83443 L F
.55 .055 .032 r
.48492 .83558 m .48766 .83674 L .48381 .83654 L F
.679 .525 .669 r
.617 .75923 m .61822 .76222 L .61496 .76185 L F
.678 .566 .721 r
.61908 .75654 m .617 .75923 L .61695 .75686 L F
.61908 .75654 m .62029 .75955 L .617 .75923 L F
.734 .551 .645 r
.62037 .7618 m .617 .75923 L .62029 .75955 L F
.62037 .7618 m .61822 .76222 L .617 .75923 L F
.576 .912 .972 r
.52722 .84684 m .52574 .8478 L .52647 .84678 L F
.698 .96 .945 r
.59532 .82899 m .59448 .82928 L .59553 .82772 L F
.381 .608 .938 r
.59806 .82804 m .59532 .82899 L .59553 .82772 L F
.59806 .82804 m .59892 .82939 L .59532 .82899 L F
.318 .671 .975 r
.66908 .74292 m .66851 .74387 L .66705 .74263 L F
.66908 .74292 m .66972 .74374 L .66851 .74387 L F
.728 .67 .793 r
.66972 .74374 m .66803 .74627 L .66851 .74387 L F
.751 .632 .728 r
.64561 .74552 m .64778 .74257 L .64672 .74421 L F
.744 .61 .709 r
.61271 .75131 m .61379 .75453 L .61059 .7541 L F
.68 .575 .731 r
.61586 .75389 m .61379 .75453 L .61271 .75131 L F
.466 .291 .559 r
.49545 .82419 m .49565 .82599 L .49339 .82658 L F
.617 .491 .686 r
.49658 .82916 m .49339 .82658 L .49565 .82599 L F
.632 .505 .69 r
.61397 .76969 m .61079 .76702 L .61299 .76666 L F
.61397 .76969 m .61163 .77004 L .61079 .76702 L F
.742 .689 .801 r
.63816 .74596 m .63915 .74881 L .63617 .74863 L F
.754 .629 .722 r
.63915 .74881 m .63713 .7515 L .63617 .74863 L F
.781 .709 .784 r
.64118 .74619 m .63915 .74881 L .63816 .74596 L F
.396 .633 .95 r
.5905 .8116 m .58781 .8099 L .59004 .80862 L F
.517 .464 .737 r
.59242 .81133 m .5905 .8116 L .59004 .80862 L F
.124 .147 .612 r
.59194 .81325 m .5905 .8116 L .59242 .81133 L F
.59194 .81325 m .59104 .81386 L .5905 .8116 L F
.731 .649 .768 r
.49746 .83464 m .49566 .83467 L .49786 .83216 L F
.778 .403 .346 r
.49566 .83467 m .49785 .83676 L .49746 .83464 L F
.731 .649 .768 r
.49746 .83464 m .49566 .83467 L .49786 .83216 L F
.609 .458 .652 r
.49785 .83676 m .49566 .83467 L .49746 .83464 L F
.692 .581 .727 r
.50005 .83161 m .49746 .83464 L .49786 .83216 L F
.50005 .83161 m .50371 .83694 L .49746 .83464 L F
.643 .613 .805 r
.49566 .83467 m .49237 .83242 L .4944 .83411 L F
.854 .889 .862 r
.49666 .83284 m .49566 .83467 L .4944 .83411 L F
.49786 .83216 m .49673 .83344 L .49666 .83284 L F
.49673 .83344 m .49566 .83467 L .49666 .83284 L F
.06 .612 .825 r
.4945 .83174 m .49786 .83216 L .49654 .83191 L F
.211 .395 .827 r
.49655 .83191 m .49746 .83464 L .49874 .8334 L F
.49654 .83191 m .49655 .83193 L .49655 .83191 L F
.49655 .83193 m .49746 .83464 L .49655 .83191 L F
.349 .79 .961 r
.50371 .83694 m .49785 .83676 L .49746 .83464 L F
.079 .085 .562 r
.49785 .83676 m .49874 .8334 L .49746 .83464 L F
.725 .699 .825 r
.55291 .84006 m .5543 .84252 L .55167 .84202 L F
.739 .36 .333 r
.55167 .84202 m .5543 .84252 L .55319 .84427 L F
.913 .744 .659 r
.55291 .8428 m .5543 .84252 L .55291 .84006 L F
.827 .474 .388 r
.55319 .84427 m .5543 .84252 L .55291 .8428 L F
.739 .348 .31 r
.66045 .75116 m .6575 .75105 L .65867 .7499 L F
.451 .104 .285 r
.65105 .76425 m .65019 .76634 L .64803 .76669 L F
.481 .117 .27 r
.65337 .76407 m .65019 .76634 L .65105 .76425 L F
.871 .62 .557 r
.54303 .82136 m .54468 .82158 L .54334 .82328 L F
.786 .491 .49 r
.54334 .82328 m .54468 .82158 L .54472 .82459 L F
.52 .237 .425 r
.64404 .7667 m .64295 .76937 L .64074 .76971 L F
.466 .137 .323 r
.64589 .76678 m .64295 .76937 L .64404 .7667 L F
.402 .005 .169 r
.52531 .87373 m .52843 .87175 L .52705 .87304 L F
0 0 0 r
.52705 .87304 m .52843 .87175 L .53019 .87084 L F
.375 .147 .435 r
.5963 .83744 m .59604 .8394 L .59397 .83971 L F
.374 .143 .431 r
.59397 .83971 m .59604 .8394 L .59393 .84211 L F
.649 .551 .73 r
.49695 .8531 m .49488 .8555 L .4958 .85491 L F
.619 .492 .686 r
.4958 .85491 m .49705 .85562 L .49488 .8555 L F
.365 .2 .52 r
.49695 .8531 m .4958 .85491 L .49586 .8549 L F
.498 .65 .926 r
.49705 .85562 m .49586 .8549 L .4958 .85491 L F
.618 .506 .703 r
.49586 .8549 m .49705 .85562 L .49547 .85554 L F
.49695 .8531 m .49705 .85562 L .49586 .8549 L F
.65 .531 .705 r
.49975 .85525 m .49705 .85562 L .49705 .85551 L F
.49811 .85399 m .49705 .85551 L .49695 .8531 L F
.49975 .85525 m .49705 .85551 L .49811 .85399 L F
.49975 .85525 m .49695 .8531 L .49907 .85256 L F
.3 .764 .946 r
.49907 .85256 m .50011 .85198 L .50167 .85248 L F
.378 .183 .485 r
.50167 .85248 m .49975 .85525 L .49907 .85256 L F
.652 .625 .81 r
.49814 .85449 m .50011 .85198 L .49914 .85252 L F
.49897 .85275 m .49914 .85252 L .49907 .85256 L F
.49814 .85449 m .49914 .85252 L .49897 .85275 L F
.498 .65 .926 r
.49705 .85562 m .49814 .85449 L .49586 .8549 L F
.365 .2 .52 r
.49695 .8531 m .49586 .8549 L .49814 .85449 L F
.618 .506 .703 r
.49695 .8531 m .49547 .85554 L .49488 .8555 L F
.07 .35 .823 r
.55026 .81883 m .54816 .81737 L .54753 .81586 L F
.608 .482 .683 r
.59104 .81386 m .59139 .81668 L .58916 .81668 L F
.455 .56 .873 r
.58795 .81427 m .58916 .81668 L .59084 .81561 L F
.376 0 0 r
.58916 .81668 m .59139 .81668 L .591 .8171 L F
.355 .35 .716 r
.59084 .81561 m .58916 .81668 L .591 .8171 L F
.719 .828 .933 r
.38645 .88635 m .38572 .8885 L .38446 .88673 L F
.38645 .88635 m .38818 .88738 L .38572 .8885 L F
.545 .236 .395 r
.67316 .74591 m .67571 .744 L .67335 .74394 L F
.872 .674 .633 r
.5488 .79387 m .54717 .79376 L .54893 .7926 L F
.5488 .79387 m .54922 .79626 L .54717 .79376 L F
.423 .418 .749 r
.55037 .79246 m .5488 .79387 L .54893 .7926 L F
.586 .705 .925 r
.55037 .79246 m .55133 .794 L .5488 .79387 L F
.732 .661 .78 r
.52754 .83123 m .52773 .83161 L .52971 .82955 L F
.727 .584 .694 r
.64069 .75424 m .63865 .75456 L .63713 .7515 L F
.621 .41 .575 r
.64069 .75424 m .63823 .75674 L .63865 .75456 L F
.64069 .75424 m .64069 .75647 L .63823 .75674 L F
.357 .202 .529 r
.64193 .75352 m .64069 .75647 L .64069 .75424 L F
.733 .643 .758 r
.63076 .74853 m .63182 .75157 L .62858 .75126 L F
.731 .571 .675 r
.63174 .75392 m .62858 .75126 L .63182 .75157 L F
.684 .616 .774 r
.63419 .7493 m .63182 .75157 L .63076 .74853 L F
.691 .628 .781 r
.63427 .75109 m .63182 .75157 L .63419 .7493 L F
.748 .628 .726 r
.63427 .75109 m .63174 .75392 L .63182 .75157 L F
0 .151 .692 r
.57322 .81621 m .57259 .81647 L .57253 .81572 L F
.192 .106 .523 r
.57429 .81795 m .57259 .81647 L .57322 .81621 L F
.57429 .81795 m .57284 .81886 L .57259 .81647 L F
.384 .81 .968 r
.43995 .88904 m .44197 .88876 L .4408 .88839 L F
.429 .869 .893 r
.43884 .88905 m .43995 .88904 L .4408 .88839 L F
.454 .201 .44 r
.37098 .77453 m .36861 .77709 L .36901 .77489 L F
.752 .525 .588 r
.51649 .81109 m .51896 .8127 L .52003 .80903 L F
.248 .035 .382 r
.52003 .80903 m .52134 .81044 L .52171 .80821 L F
.52003 .80903 m .51896 .8127 L .52134 .81044 L F
.445 .117 .315 r
.59198 .84232 m .59139 .84419 L .58935 .84461 L F
.33 .013 .269 r
.59393 .84211 m .59139 .84419 L .59198 .84232 L F
.47 .117 .286 r
.4432 .83623 m .44104 .83666 L .44135 .83537 L F
0 0 0 r
.3943 .82869 m .39131 .8297 L .39333 .82933 L F
.132 0 0 r
.3953 .8289 m .3943 .82869 L .39333 .82933 L F
.3953 .8289 m .39632 .82839 L .3943 .82869 L F
.915 .98 .738 r
.53116 .87002 m .53283 .86884 L .53292 .86864 L F
.5328 .86814 m .53292 .86864 L .53355 .86729 L F
.53116 .87002 m .53292 .86864 L .5328 .86814 L F
.53116 .87002 m .53355 .86729 L .53335 .86775 L F
.619 .17 .161 r
.53335 .86775 m .53225 .86578 L .53101 .86763 L F
.444 .749 .993 r
.53196 .86671 m .53257 .86717 L .53101 .86763 L F
.53257 .86717 m .53335 .86775 L .5327 .86771 L F
.53257 .86717 m .5327 .86771 L .53101 .86763 L F
.615 .156 .14 r
.53225 .86578 m .53435 .86643 L .53355 .86729 L F
0 0 0 r
.53355 .86729 m .53435 .86643 L .53335 .86775 L F
.619 .17 .161 r
.53335 .86775 m .53435 .86643 L .53225 .86578 L F
.637 .918 .979 r
.40609 .89747 m .40916 .89695 L .40799 .89672 L F
.458 .863 .963 r
.40996 .8962 m .40916 .89695 L .41101 .89646 L F
.40996 .8962 m .40799 .89672 L .40916 .89695 L F
.34 .817 .783 r
.50173 .87642 m .49983 .87711 L .49804 .87751 L F
.67 .318 .368 r
.45936 .83221 m .45605 .83382 L .45734 .83194 L F
.739 .396 .401 r
.49253 .8109 m .49367 .81103 L .49648 .80859 L F
0 0 0 r
.49648 .80859 m .49581 .80937 L .49711 .80856 L F
.49581 .80916 m .49367 .81103 L .49581 .80937 L F
.834 .856 .862 r
.49581 .80937 m .49367 .81103 L .49298 .81007 L F
.295 0 0 r
.49496 .8094 m .49581 .80956 L .49581 .80937 L F
.826 .452 .345 r
.49915 .8125 m .49581 .80937 L .49714 .81148 L F
.49915 .8125 m .49756 .81223 L .49581 .80937 L F
.295 0 0 r
.49581 .80956 m .4982 .81 L .49581 .80937 L F
0 0 0 r
.49648 .80859 m .49581 .80916 L .49581 .80937 L F
.488 .158 .333 r
.63854 .77 m .64092 .77085 L .63833 .77088 L F
.63854 .77 m .64074 .76971 L .64092 .77085 L F
.594 .193 .252 r
.45377 .82051 m .45588 .8209 L .45714 .81912 L F
.505 .086 .18 r
.45588 .8209 m .45923 .81927 L .45714 .81912 L F
.45 .126 .324 r
.58728 .84502 m .58855 .84698 L .58646 .8474 L F
.58728 .84502 m .58935 .84461 L .58855 .84698 L F
.795 .71 .77 r
.63413 .76202 m .63126 .76207 L .63302 .75906 L F
.74 .683 .796 r
.63673 .75975 m .63413 .76202 L .63302 .75906 L F
.499 .581 .868 r
.35856 .76918 m .36161 .76698 L .36107 .76716 L F
.699 .712 .859 r
.42833 .87531 m .42923 .87653 L .42591 .87608 L F
.697 .711 .859 r
.43198 .87599 m .42923 .87653 L .42833 .87531 L F
.678 .85 .965 r
.36882 .73819 m .36661 .73884 L .36537 .73813 L F
.243 .446 .86 r
.35771 .73103 m .35735 .7325 L .35559 .73119 L F
.35771 .73103 m .35888 .73302 L .35735 .7325 L F
.603 .533 .748 r
.36918 .75131 m .36999 .75437 L .37203 .75393 L F
.573 .415 .628 r
.36999 .75437 m .37002 .75655 L .37203 .75393 L F
0 0 0 r
.50622 .8751 m .5045 .87535 L .5035 .87561 L F
.435 .25 .529 r
.40625 .84756 m .40694 .85002 L .4045 .8503 L F
.363 .144 .443 r
.40581 .85151 m .4045 .8503 L .40694 .85002 L F
.604 .196 .242 r
.43201 .84031 m .43066 .84206 L .42861 .8415 L F
.302 0 .046 r
.43266 .84159 m .43201 .84031 L .4339 .83993 L F
.43266 .84159 m .43066 .84206 L .43201 .84031 L F
.688 .855 .962 r
.35219 .73116 m .35166 .73282 L .35036 .7312 L F
.35219 .73116 m .35348 .732 L .35166 .73282 L F
0 0 0 r
.51092 .88054 m .51198 .88016 L .51006 .88098 L F
.51092 .88054 m .51348 .87925 L .51198 .88016 L F
.609 .241 .32 r
.46315 .8315 m .46135 .83377 L .45936 .83221 L F
.624 .297 .397 r
.46555 .83145 m .46135 .83377 L .46315 .8315 L F
.401 .184 .467 r
.59993 .83117 m .60003 .83401 L .59833 .83436 L F
.359 .41 .778 r
.59978 .82965 m .60199 .83133 L .59993 .83117 L F
.387 .174 .464 r
.60199 .83133 m .60003 .83401 L .59993 .83117 L F
.728 .396 0 r
.56243 .82367 m .56289 .8247 L .56354 .8266 L F
.745 .271 .12 r
.42682 .83934 m .42864 .8406 L .42531 .83937 L F
0 0 0 r
.61114 .78021 m .60926 .7823 L .60999 .7818 L F
.87 .88 .841 r
.61114 .78021 m .61202 .77684 L .6131 .77752 L F
.61114 .78021 m .6099 .77997 L .61202 .77684 L F
.915 .594 .423 r
.61114 .78021 m .60999 .7818 L .6099 .77997 L F
0 .514 .83 r
.41182 .88099 m .41126 .88112 L .40986 .88097 L F
.41182 .88099 m .41301 .88156 L .41126 .88112 L F
.637 .824 .972 r
.5883 .83731 m .58504 .83711 L .58742 .83706 L F
.856 .994 .828 r
.58883 .83555 m .5883 .83731 L .58742 .83706 L F
.58883 .83555 m .59055 .83486 L .5883 .83731 L F
.722 .558 .668 r
.61815 .76446 m .61496 .76185 L .61822 .76222 L F
.61815 .76446 m .61607 .76467 L .61496 .76185 L F
.707 .586 .718 r
.62773 .75699 m .6279 .75949 L .62565 .75938 L F
.689 .485 .606 r
.62786 .7615 m .62565 .75938 L .6279 .75949 L F
.629 .482 .663 r
.63004 .75605 m .6279 .75949 L .62773 .75699 L F
.63004 .75605 m .63129 .75963 L .6279 .75949 L F
.695 .561 .699 r
.63129 .75963 m .62786 .7615 L .6279 .75949 L F
.716 .601 .727 r
.62773 .75699 m .62565 .75938 L .62443 .75643 L F
.689 .485 .606 r
.62786 .7615 m .62563 .76171 L .62565 .75938 L F
.534 .083 .127 r
.48569 .81799 m .4878 .81822 L .48902 .81684 L F
.622 .267 .347 r
.4878 .81822 m .49127 .81764 L .48902 .81684 L F
0 0 0 r
.64712 .7486 m .64959 .74672 L .64924 .74661 L F
.64712 .7486 m .64924 .74661 L .64859 .74712 L F
.65098 .74547 m .64987 .74578 L .65197 .74634 L F
.64835 .74734 m .64859 .74712 L .64712 .7486 L F
.64987 .74578 m .64889 .7468 L .64835 .74734 L F
.64889 .7468 m .64859 .74712 L .64835 .74734 L F
.6506 .74558 m .64954 .74638 L .64987 .74578 L F
.64954 .74638 m .64889 .7468 L .64987 .74578 L F
.584 .55 .783 r
.6494 .74629 m .64947 .74643 L .65059 .74511 L F
.64947 .74643 m .64959 .74672 L .64997 .74611 L F
.64947 .74643 m .64997 .74611 L .65059 .74511 L F
0 0 0 r
.64954 .74638 m .64859 .74712 L .64889 .7468 L F
.65098 .74547 m .64859 .74712 L .64954 .74638 L F
.65098 .74547 m .64954 .74638 L .6506 .74558 L F
.584 .55 .783 r
.65059 .74511 m .64997 .74611 L .65098 .74547 L F
.64997 .74611 m .64959 .74672 L .65098 .74547 L F
.64778 .74257 m .6494 .74629 L .65059 .74511 L F
.751 .632 .728 r
.64561 .74552 m .64924 .74661 L .64778 .74257 L F
.64924 .74661 m .64959 .74672 L .64947 .74643 L F
.64924 .74661 m .64947 .74643 L .64778 .74257 L F
0 0 0 r
.65098 .74547 m .64715 .74861 L .64845 .74726 L F
.64883 .74695 m .64845 .74726 L .64859 .74712 L F
.65098 .74547 m .64845 .74726 L .64883 .74695 L F
.64859 .74712 m .64924 .74661 L .64912 .74658 L F
.64712 .7486 m .64912 .74658 L .64561 .74552 L F
.64859 .74712 m .64715 .74861 L .64712 .7486 L F
.709 .632 .769 r
.37874 .74828 m .3776 .75183 L .37681 .75022 L F
.547 .273 .452 r
.67255 .7517 m .6722 .75349 L .66995 .75382 L F
.31 .066 .373 r
.67421 .751 m .6722 .75349 L .67255 .7517 L F
.657 .566 .741 r
.58869 .79225 m .5919 .79305 L .59104 .79 L F
.653 .517 .686 r
.61163 .77004 m .61182 .77221 L .6096 .77249 L F
.619 .433 .609 r
.61182 .77221 m .60963 .77473 L .6096 .77249 L F
.58 .589 .826 r
.37379 .74102 m .37306 .74427 L .37179 .74122 L F
.37379 .74102 m .37515 .74389 L .37306 .74427 L F
.581 .499 .727 r
.37158 .73797 m .36983 .74164 L .36882 .73819 L F
.37158 .73797 m .37179 .74122 L .36983 .74164 L F
.969 .799 .371 r
.5814 .80601 m .58125 .80292 L .58393 .80561 L F
.5814 .80601 m .58393 .80561 L .58328 .8057 L F
.326 0 .229 r
.58052 .80822 m .5814 .80601 L .58328 .8057 L F
.267 0 0 r
.4707 .88194 m .47157 .88241 L .46953 .88244 L F
.4707 .88194 m .4727 .88227 L .47157 .88241 L F
.663 .292 .332 r
.59268 .79945 m .59328 .79809 L .59061 .798 L F
.329 .397 .78 r
.59268 .79945 m .59061 .798 L .59328 .79809 L F
.407 .036 .217 r
.59527 .79781 m .59328 .79809 L .59268 .79945 L F
.732 .545 .639 r
.59527 .79781 m .59268 .79945 L .59328 .79809 L F
.855 .41 .001 r
.54717 .79376 m .54922 .79626 L .54886 .79677 L F
.873 .452 .026 r
.54922 .79626 m .54986 .79774 L .54886 .79677 L F
0 0 0 r
.44189 .87618 m .43988 .87655 L .4389 .87678 L F
.437 .159 .392 r
.36196 .78012 m .36362 .77977 L .36184 .78054 L F
.501 .004 .007 r
.58889 .80344 m .59232 .80335 L .59033 .80423 L F
.652 .628 .813 r
.59268 .79945 m .59449 .80391 L .59232 .80335 L F
.613 .102 .01 r
.59232 .80335 m .59247 .80472 L .59033 .80423 L F
.59232 .80335 m .59449 .80391 L .59247 .80472 L F
.577 .906 .979 r
.40061 .89868 m .40398 .89792 L .40275 .89762 L F
.493 .844 .995 r
.40398 .89792 m .40482 .89697 L .40275 .89762 L F
.40398 .89792 m .40609 .89747 L .40482 .89697 L F
.751 .634 .73 r
.62037 .7618 m .61815 .76446 L .61822 .76222 L F
.638 .777 .947 r
.61271 .75131 m .60927 .75078 L .61163 .7487 L F
.634 .646 .844 r
.61468 .75076 m .61271 .75131 L .61163 .7487 L F
.68 .575 .731 r
.61586 .75389 m .61271 .75131 L .61468 .75076 L F
.513 .468 .743 r
.57249 .79327 m .57125 .79605 L .57063 .79382 L F
.57249 .79327 m .57316 .79551 L .57125 .79605 L F
.514 0 0 r
.57089 .79791 m .57125 .79605 L .57316 .79551 L F
.688 .573 .72 r
.61908 .75654 m .61695 .75686 L .61586 .75389 L F
.452 .107 .289 r
.36607 .76432 m .36399 .7647 L .36331 .7663 L F
0 0 0 r
.59166 .83184 m .5909 .83392 L .59128 .83351 L F
.466 .868 .696 r
.59162 .83315 m .59128 .83351 L .59068 .83375 L F
0 0 0 r
.59166 .83184 m .59128 .83351 L .5916 .83152 L F
0 0 .267 r
.5916 .83152 m .59128 .83351 L .59236 .83267 L F
.466 .868 .696 r
.59236 .83267 m .59128 .83351 L .59162 .83315 L F
0 0 0 r
.5909 .83392 m .59055 .83486 L .59128 .83351 L F
.738 .992 .836 r
.59128 .83351 m .59055 .83486 L .58883 .83555 L F
.647 .891 .984 r
.38984 .90115 m .39111 .90166 L .39324 .90078 L F
.523 .119 .216 r
.43257 .82385 m .43466 .82398 L .43591 .82216 L F
.554 .152 .235 r
.43591 .82216 m .43466 .82398 L .43772 .8233 L F
0 0 .093 r
.60945 .78522 m .60744 .78791 L .60923 .78747 L F
0 0 .257 r
.60744 .78791 m .60791 .78942 L .60923 .78747 L F
.961 .713 .515 r
.4944 .83411 m .49419 .8364 L .49566 .83467 L F
.778 .403 .346 r
.49566 .83467 m .49419 .8364 L .49785 .83676 L F
.8 .769 .824 r
.51395 .86623 m .51467 .86841 L .51272 .86836 L F
.657 .183 .115 r
.51272 .86836 m .51467 .86841 L .51373 .8692 L F
.685 .586 .739 r
.51567 .86644 m .51467 .86841 L .51424 .86709 L F
.688 .48 .6 r
.51467 .86841 m .5156 .86805 L .51373 .8692 L F
.512 .266 .479 r
.5156 .86805 m .51304 .86832 L .51373 .8692 L F
.51304 .86832 m .51272 .86836 L .51287 .86849 L F
.51304 .86832 m .51287 .86849 L .51373 .8692 L F
.685 .586 .739 r
.51497 .86635 m .51424 .86709 L .51395 .86623 L F
.51567 .86644 m .51424 .86709 L .51497 .86635 L F
.349 .79 .961 r
.50371 .83694 m .50101 .8367 L .49785 .83676 L F
.398 .468 .816 r
.5033 .83447 m .50371 .83694 L .50005 .83161 L F
.799 .755 .813 r
.5033 .83447 m .50101 .8367 L .50371 .83694 L F
.279 0 .167 r
.57314 .81077 m .57343 .80924 L .57446 .80993 L F
.708 .601 .734 r
.38417 .85797 m .38546 .86077 L .38216 .86062 L F
.737 .506 .579 r
.38528 .86277 m .38216 .86062 L .38546 .86077 L F
.74 .761 .87 r
.50077 .82909 m .49658 .82916 L .49865 .82884 L F
.322 .362 .748 r
.50111 .8262 m .50077 .82909 L .49865 .82884 L F
.50111 .8262 m .50199 .82947 L .50077 .82909 L F
.712 .607 .738 r
.63617 .74863 m .63713 .7515 L .63427 .75109 L F
.57 .353 .546 r
.62879 .7747 m .62877 .77643 L .62652 .77669 L F
.566 .344 .538 r
.63103 .77449 m .62877 .77643 L .62879 .7747 L F
.594 .394 .58 r
.38174 .86065 m .38201 .86292 L .37983 .86314 L F
.673 .45 .575 r
.38216 .86062 m .38201 .86292 L .38174 .86065 L F
.536 .353 .58 r
.38496 .76181 m .38494 .76392 L .3828 .76423 L F
.543 .314 .518 r
.38448 .76574 m .3828 .76423 L .38494 .76392 L F
.38448 .76574 m .38324 .76526 L .3828 .76423 L F
.548 .06 .05 r
.65659 .764 m .6554 .76449 L .65337 .76407 L F
.358 0 0 r
.65879 .76457 m .6554 .76449 L .65659 .764 L F
.764 .748 .838 r
.64118 .74619 m .63816 .74596 L .64045 .74352 L F
.595 .593 .819 r
.64241 .74295 m .64118 .74619 L .64045 .74352 L F
.722 .616 .739 r
.63004 .75605 m .62654 .75386 L .63002 .7546 L F
.63004 .75605 m .62773 .75699 L .62654 .75386 L F
.77 .704 .79 r
.63174 .75392 m .63004 .75605 L .63002 .7546 L F
.625 .487 .674 r
.63174 .75392 m .63334 .75692 L .63004 .75605 L F
.648 .492 .658 r
.63302 .75906 m .63004 .75605 L .63334 .75692 L F
.63302 .75906 m .63129 .75963 L .63004 .75605 L F
0 .205 .731 r
.55857 .81056 m .55828 .81111 L .56054 .81319 L F
.065 .35 .823 r
.55828 .81111 m .5609 .81391 L .56054 .81319 L F
.93 .547 .224 r
.55645 .8063 m .55604 .8076 L .5552 .80604 L F
.55645 .8063 m .55714 .80822 L .55604 .8076 L F
.69 .474 .588 r
.58538 .80079 m .58261 .79949 L .58282 .80028 L F
.751 .592 .68 r
.63865 .75456 m .63823 .75674 L .63511 .75644 L F
.737 .506 .579 r
.38528 .86277 m .38201 .86292 L .38216 .86062 L F
.609 .864 .991 r
.40788 .88143 m .40603 .8821 L .40457 .88147 L F
.706 .614 .751 r
.36805 .75681 m .36818 .75905 L .37002 .75655 L F
.519 .361 .607 r
.36818 .75905 m .37007 .75887 L .37002 .75655 L F
.549 .379 .604 r
.36806 .76156 m .37007 .75887 L .36818 .75905 L F
.713 .611 .742 r
.62654 .75386 m .62773 .75699 L .62443 .75643 L F
.132 .308 .775 r
.38225 .87475 m .3834 .87577 L .3829 .87622 L F
.144 .048 .478 r
.3834 .87577 m .38264 .87849 L .3829 .87622 L F
.683 .61 .768 r
.61802 .75158 m .61586 .75389 L .61468 .75076 L F
.674 .594 .759 r
.61802 .75158 m .61907 .75446 L .61586 .75389 L F
.688 .573 .72 r
.61908 .75654 m .61586 .75389 L .61907 .75446 L F
.67 .387 .484 r
.4084 .84981 m .40625 .84756 L .40729 .84678 L F
.4084 .84981 m .40694 .85002 L .40625 .84756 L F
.052 0 .108 r
.60116 .78738 m .59891 .7899 L .59893 .78774 L F
.618 .551 .757 r
.57628 .78907 m .57919 .78712 L .57722 .78791 L F
.57628 .78907 m .58031 .79024 L .57919 .78712 L F
.611 .56 .773 r
.57628 .78907 m .57826 .79121 L .58031 .79024 L F
.782 .485 .485 r
.4987 .81679 m .50167 .81631 L .49986 .81672 L F
.676 .29 .307 r
.52307 .82339 m .5218 .82583 L .52035 .82379 L F
.5218 .82583 m .52171 .82582 L .52035 .82379 L F
0 0 0 r
.52343 .82381 m .52188 .82575 L .52307 .82339 L F
.52188 .82575 m .5218 .82583 L .52307 .82339 L F
.649 .285 .34 r
.52265 .82434 m .5218 .82582 L .52035 .82379 L F
.706 .554 .68 r
.52284 .82586 m .52138 .82576 L .52246 .82574 L F
.52171 .82582 m .52134 .82576 L .52284 .82586 L F
.681 .412 .509 r
.52411 .8257 m .52176 .82589 L .52188 .82575 L F
.52411 .8257 m .52188 .82575 L .52343 .82381 L F
.706 .554 .68 r
.52246 .82574 m .52134 .82576 L .5212 .82533 L F
.649 .285 .34 r
.5218 .82582 m .52171 .82582 L .52035 .82379 L F
.706 .554 .68 r
.52138 .82576 m .52134 .82576 L .52246 .82574 L F
.52372 .82615 m .52171 .82582 L .52284 .82586 L F
.52372 .82615 m .52205 .82812 L .52134 .82576 L F
.676 .29 .307 r
.5218 .82583 m .52176 .82589 L .52171 .82582 L F
.649 .285 .34 r
.5218 .82582 m .52176 .82589 L .52171 .82582 L F
0 0 0 r
.52188 .82575 m .52176 .82589 L .5218 .82583 L F
.706 .554 .68 r
.52411 .8257 m .52372 .82615 L .52203 .8256 L F
.52218 .82545 m .52203 .8256 L .5212 .82533 L F
.52411 .8257 m .52203 .8256 L .52218 .82545 L F
.579 .344 .524 r
.62652 .77669 m .62608 .7798 L .62385 .77986 L F
.525 .282 .488 r
.62877 .77643 m .62608 .7798 L .62652 .77669 L F
.563 .364 .569 r
.60963 .77473 m .60739 .7774 L .60743 .77511 L F
.446 .44 .759 r
.38173 .75307 m .38118 .75604 L .38014 .75448 L F
.38173 .75307 m .3827 .75593 L .38118 .75604 L F
.644 .501 .674 r
.48827 .86556 m .4907 .86342 L .4875 .86336 L F
0 .021 .572 r
.55384 .80343 m .55366 .80296 L .55205 .80101 L F
.866 .427 .031 r
.55384 .80343 m .55425 .80552 L .55366 .80296 L F
.55384 .80343 m .5552 .80604 L .55425 .80552 L F
.516 .915 .882 r
.40201 .82741 m .40241 .82655 L .40397 .82717 L F
.40201 .82741 m .40004 .82765 L .40241 .82655 L F
.608 .556 .771 r
.5956 .79994 m .59449 .80391 L .59268 .79945 L F
.5956 .79994 m .59697 .80338 L .59449 .80391 L F
.654 .157 .055 r
.59247 .80472 m .59449 .80391 L .59637 .80535 L F
.528 .281 .484 r
.59449 .80391 m .59697 .80338 L .59637 .80535 L F
.512 .383 .641 r
.3927 .74549 m .39371 .74444 L .392 .74408 L F
.24 0 .059 r
.49104 .8736 m .48766 .87582 L .49114 .87597 L F
.675 .437 .554 r
.58767 .80057 m .59061 .798 L .58778 .79828 L F
.709 .632 .769 r
.37874 .74828 m .38021 .75124 L .3776 .75183 L F
.575 .494 .726 r
.39364 .85464 m .39253 .85847 L .39148 .85539 L F
.39364 .85464 m .39474 .85823 L .39253 .85847 L F
.497 .369 .635 r
.39474 .85823 m .39309 .85978 L .39253 .85847 L F
.956 .854 .7 r
.61383 .7741 m .6131 .77752 L .61202 .77684 L F
.308 .507 .888 r
.48369 .87267 m .48291 .87365 L .48103 .87112 L F
.956 .673 .458 r
.58845 .80578 m .59004 .80862 L .58878 .80822 L F
.824 .923 .901 r
.58878 .80822 m .59004 .80862 L .58781 .8099 L F
.598 .587 .812 r
.59033 .80423 m .59004 .80862 L .58845 .80578 L F
.59033 .80423 m .59219 .80827 L .59004 .80862 L F
.517 .464 .737 r
.59242 .81133 m .59004 .80862 L .59219 .80827 L F
.712 .607 .738 r
.63617 .74863 m .63427 .75109 L .63419 .7493 L F
0 .476 .833 r
.4757 .88253 m .4793 .88396 L .47819 .88316 L F
.119 .568 .919 r
.47819 .88316 m .4793 .88396 L .47989 .88356 L F
.154 .621 .929 r
.47989 .88356 m .4793 .88396 L .48093 .88419 L F
.526 .299 .513 r
.62168 .78015 m .62158 .78222 L .61943 .78255 L F
.577 .352 .537 r
.62385 .77986 m .62158 .78222 L .62168 .78015 L F
.797 .572 .597 r
.60764 .79305 m .60798 .79541 L .6062 .79555 L F
.635 .401 .547 r
.60764 .79305 m .61023 .79517 L .60798 .79541 L F
.60764 .79305 m .6106 .79262 L .61023 .79517 L F
.735 .703 .82 r
.56978 .77769 m .57353 .77802 L .57152 .7764 L F
.69 .702 .855 r
.57152 .7764 m .57353 .77802 L .57476 .777 L F
.525 .299 .514 r
.57353 .77802 m .5726 .77999 L .57471 .7795 L F
.703 .578 .712 r
.62221 .75685 m .62029 .75955 L .61908 .75654 L F
.714 .539 .652 r
.61814 .76637 m .61607 .76467 L .61815 .76446 L F
.777 .48 .484 r
.61815 .76446 m .62095 .76631 L .61814 .76637 L F
.956 .635 .223 r
.5156 .86805 m .51639 .86852 L .51567 .86644 L F
.967 .934 .684 r
.51447 .87213 m .51639 .86852 L .5156 .86805 L F
0 0 0 r
.57591 .78702 m .57528 .78759 L .57722 .78791 L F
.876 .618 .092 r
.5609 .81391 m .5612 .81623 L .56054 .81319 L F
.387 .31 .647 r
.47658 .86523 m .47515 .86546 L .47475 .86321 L F
.47658 .86523 m .47515 .86546 L .47475 .86321 L F
.697 .711 .859 r
.43198 .87599 m .42833 .87531 L .42984 .87487 L F
.382 .665 .97 r
.43288 .87511 m .43198 .87599 L .42984 .87487 L F
.43288 .87511 m .43326 .87577 L .43198 .87599 L F
.778 .532 .563 r
.53712 .82686 m .53397 .82895 L .53608 .82653 L F
.53712 .82686 m .53704 .82908 L .53397 .82895 L F
.519 .712 .959 r
.53762 .82519 m .53712 .82686 L .53608 .82653 L F
.53762 .82519 m .53969 .82697 L .53712 .82686 L F
.594 .301 .441 r
.53712 .82686 m .53907 .8288 L .53704 .82908 L F
.53712 .82686 m .53969 .82697 L .53907 .8288 L F
.77 .742 .827 r
.60531 .7542 m .60222 .75413 L .60386 .753 L F
.762 .743 .835 r
.60786 .75214 m .60531 .7542 L .60386 .753 L F
0 0 0 r
.67636 .74812 m .67707 .74671 L .67784 .74592 L F
.44915 .87084 m .44605 .87322 L .44817 .87301 L F
.594 .16 .186 r
.44908 .87252 m .44915 .87084 L .44817 .87301 L F
.44908 .87252 m .45169 .87121 L .44915 .87084 L F
0 .439 .718 r
.47497 .88229 m .4757 .88253 L .47819 .88316 L F
.675 .437 .554 r
.58767 .80057 m .59021 .80036 L .59061 .798 L F
.663 .292 .332 r
.59268 .79945 m .59061 .798 L .59021 .80036 L F
.33 0 0 r
.46665 .81862 m .46878 .81837 L .46999 .81719 L F
.298 0 0 r
.46999 .81719 m .47072 .81806 L .47165 .81744 L F
.46999 .81719 m .46878 .81837 L .47072 .81806 L F
.341 .819 .787 r
.44587 .88793 m .44778 .8875 L .44968 .88682 L F
0 .04 .592 r
.5612 .81623 m .56206 .81983 L .56255 .81838 L F
.48 .398 .686 r
.56206 .81983 m .56461 .821 L .56293 .81837 L F
.56206 .81983 m .56308 .82162 L .56461 .821 L F
.719 .602 .725 r
.56293 .81837 m .56243 .82367 L .56137 .82308 L F
.56293 .81837 m .56461 .821 L .56243 .82367 L F
0 0 .079 r
.56298 .81995 m .56293 .81837 L .56137 .82308 L F
.866 .418 .075 r
.56255 .81838 m .56293 .81837 L .56298 .81995 L F
.56255 .81838 m .56298 .81995 L .56271 .81779 L F
.56255 .81838 m .56271 .81779 L .56264 .81726 L F
.48 .398 .686 r
.56206 .81983 m .56226 .8195 L .56255 .81838 L F
.56226 .8195 m .56293 .81837 L .56255 .81838 L F
.434 .844 .968 r
.41642 .88135 m .41301 .88156 L .41535 .8815 L F
.47 .894 .864 r
.41824 .88055 m .41642 .88135 L .41535 .8815 L F
.521 .909 .934 r
.41519 .89522 m .417 .89532 L .41886 .89457 L F
.906 .785 .717 r
.5358 .81393 m .53349 .81597 L .53421 .81379 L F
.5358 .81393 m .535 .81665 L .53349 .81597 L F
.692 .581 .727 r
.62122 .75394 m .61908 .75654 L .61907 .75446 L F
.7 .594 .734 r
.62122 .75394 m .62221 .75685 L .61908 .75654 L F
.425 .855 .942 r
.39836 .89901 m .40061 .89868 L .40015 .89847 L F
.577 .906 .979 r
.40061 .89868 m .40275 .89762 L .40015 .89847 L F
.733 .635 .75 r
.67114 .74628 m .66942 .7474 L .66803 .74627 L F
.81 .672 .711 r
.58435 .78492 m .58256 .78791 L .58548 .78785 L F
.772 .691 .774 r
.58566 .80315 m .58889 .80344 L .58767 .80057 L F
.783 .574 .616 r
.58566 .80315 m .58889 .80344 L .58845 .80578 L F
.73 .634 .752 r
.58435 .78492 m .58548 .78785 L .5876 .7853 L F
.258 .396 .812 r
.58767 .80057 m .58889 .80344 L .58989 .80333 L F
.501 .004 .007 r
.58889 .80344 m .59033 .80423 L .58845 .80578 L F
.216 .054 .434 r
.58845 .80578 m .58889 .80344 L .58989 .80333 L F
.838 .673 .678 r
.56954 .7903 m .57063 .79382 L .56811 .79283 L F
.41 .421 .76 r
.57229 .79229 m .57063 .79382 L .56954 .7903 L F
.561 .68 .919 r
.57229 .79229 m .57249 .79327 L .57063 .79382 L F
0 0 .418 r
.56382 .83591 m .56445 .83716 L .56417 .83627 L F
.952 .65 .213 r
.56445 .83716 m .56393 .83874 L .56417 .83627 L F
.867 .747 .235 r
.56381 .83814 m .56417 .83627 L .56399 .83811 L F
.56381 .83814 m .56399 .83811 L .56393 .83874 L F
.803 .867 .425 r
.56358 .83817 m .56381 .83814 L .56337 .83862 L F
0 0 .034 r
.56445 .83655 m .56417 .83627 L .56381 .83814 L F
.803 .867 .425 r
.56511 .83492 m .56381 .83814 L .56358 .83817 L F
0 0 .034 r
.56511 .83492 m .56417 .83627 L .56445 .83655 L F
0 0 .418 r
.56293 .83415 m .56382 .83591 L .56417 .83627 L F
.952 .65 .213 r
.56445 .83716 m .56485 .83944 L .56393 .83874 L F
.728 .67 .793 r
.66972 .74374 m .67114 .74628 L .66803 .74627 L F
.685 .579 .731 r
.64661 .75667 m .64906 .75515 L .64604 .75426 L F
.64661 .75667 m .64893 .75659 L .64906 .75515 L F
.67 .449 .576 r
.64661 .75667 m .6489 .75861 L .64893 .75659 L F
.559 .463 .702 r
.64661 .75667 m .64698 .75952 L .6489 .75861 L F
.716 .248 .139 r
.5292 .87084 m .52723 .86876 L .52684 .87052 L F
0 0 .003 r
.57251 .7859 m .57249 .787 L .5723 .7844 L F
.57251 .7859 m .57172 .78864 L .57249 .787 L F
.693 .592 .738 r
.61397 .76969 m .61182 .77221 L .61163 .77004 L F
.568 .291 .455 r
.41609 .8426 m .41587 .84442 L .41379 .84441 L F
.618 .334 .465 r
.41609 .8426 m .41794 .84447 L .41587 .84442 L F
.528 .337 .566 r
.41796 .84213 m .41794 .84447 L .41609 .8426 L F
.646 .479 .643 r
.39364 .85464 m .39145 .85286 L .39363 .85268 L F
.39364 .85464 m .39148 .85539 L .39145 .85286 L F
.381 .844 .87 r
.4215 .89378 m .42232 .89321 L .42076 .894 L F
.4215 .89378 m .42355 .89312 L .42232 .89321 L F
.484 .667 .944 r
.36918 .75131 m .3697 .74979 L .36721 .74932 L F
.36918 .75131 m .37082 .751 L .3697 .74979 L F
.603 .533 .748 r
.36918 .75131 m .37203 .75393 L .37082 .751 L F
.397 .683 .976 r
.52513 .81308 m .52573 .81401 L .52691 .81309 L F
.559 .148 .217 r
.45923 .81927 m .46108 .82038 L .46239 .81864 L F
.542 .124 .198 r
.46108 .82038 m .46454 .81887 L .46239 .81864 L F
.482 .52 .82 r
.38167 .75073 m .38021 .75124 L .37874 .74828 L F
.459 .353 .647 r
.38173 .75307 m .38021 .75124 L .38167 .75073 L F
.38173 .75307 m .38014 .75448 L .38021 .75124 L F
.71 .6 .731 r
.62443 .75643 m .62221 .75685 L .62122 .75394 L F
.648 .611 .799 r
.50199 .82947 m .50327 .83193 L .50005 .83161 L F
.398 .468 .816 r
.5033 .83447 m .50005 .83161 L .50327 .83193 L F
.678 .85 .965 r
.36882 .73819 m .36537 .73813 L .36754 .73528 L F
.718 .662 .793 r
.37066 .7358 m .36882 .73819 L .36754 .73528 L F
.611 .507 .711 r
.37066 .7358 m .37158 .73797 L .36882 .73819 L F
.914 .523 .125 r
.64069 .75647 m .6414 .75858 L .64201 .75859 L F
.819 .558 .545 r
.6414 .75858 m .64359 .7607 L .64201 .75859 L F
.707 .742 .879 r
.57159 .79982 m .57497 .79892 L .57089 .79791 L F
0 .33 .768 r
.57302 .80028 m .57411 .80121 L .57217 .80014 L F
.57302 .80028 m .57217 .80014 L .57159 .79982 L F
0 0 0 r
.57345 .80036 m .57302 .80028 L .57205 .8013 L F
.57466 .79954 m .57302 .80028 L .57345 .80036 L F
0 .33 .768 r
.57302 .80028 m .57159 .79982 L .57083 .80089 L F
.617 .33 .459 r
.41057 .8454 m .40729 .84678 L .40856 .84488 L F
.71 .6 .731 r
.62443 .75643 m .62122 .75394 L .62443 .75442 L F
.708 .604 .738 r
.62654 .75386 m .62443 .75643 L .62443 .75442 L F
.394 .061 .278 r
.57172 .78864 m .57151 .78994 L .56954 .7903 L F
.408 .198 .48 r
.5713 .78872 m .57249 .787 L .57172 .78864 L F
.284 0 0 r
.5095 .81011 m .51127 .81044 L .51222 .81042 L F
.416 0 0 r
.51127 .81044 m .51444 .81098 L .51222 .81042 L F
0 0 .137 r
.47777 .87488 m .47793 .8726 L .47722 .87397 L F
.704 .493 .6 r
.57945 .78511 m .58302 .78508 L .58269 .78276 L F
.649 .538 .716 r
.58269 .78276 m .58429 .78269 L .58345 .77973 L F
.747 .523 .591 r
.58269 .78276 m .58435 .78492 L .58429 .78269 L F
.58269 .78276 m .58302 .78508 L .58435 .78492 L F
.428 .153 .393 r
.66121 .76224 m .66079 .76395 L .65879 .76457 L F
.253 0 .323 r
.66272 .76285 m .66121 .76224 L .66314 .76168 L F
.66272 .76285 m .66079 .76395 L .66121 .76224 L F
.467 .017 .097 r
.42528 .82437 m .42733 .82442 L .42835 .82365 L F
.264 0 0 r
.42733 .82442 m .43049 .82398 L .42835 .82365 L F
.787 .943 .927 r
.58099 .76716 m .5772 .76872 L .57987 .76645 L F
.784 .891 .921 r
.58274 .76609 m .58099 .76716 L .57987 .76645 L F
.666 .5 .65 r
.61607 .76467 m .61604 .76707 L .61299 .76666 L F
.709 .538 .655 r
.61565 .76915 m .61299 .76666 L .61604 .76707 L F
.61565 .76915 m .61397 .76969 L .61299 .76666 L F
0 .398 .792 r
.56612 .7757 m .56721 .77598 L .56716 .77575 L F
.56612 .7757 m .56676 .77384 L .56671 .77523 L F
.56612 .7757 m .56716 .77575 L .56676 .77384 L F
.346 .806 .936 r
.56547 .77567 m .56612 .7757 L .56671 .77523 L F
.56409 .77616 m .56612 .7757 L .56547 .77567 L F
.56409 .77616 m .56333 .77583 L .56612 .7757 L F
.772 .701 .785 r
.5033 .83447 m .50419 .8372 L .50101 .8367 L F
.731 .312 .252 r
.50419 .8372 m .50274 .83816 L .50101 .8367 L F
0 0 0 r
.5057 .837 m .50274 .83816 L .50419 .8372 L F
.5057 .837 m .50274 .83816 L .50419 .8372 L F
.699 .935 .964 r
.58307 .83795 m .57963 .83892 L .58224 .8375 L F
.697 .825 .944 r
.5841 .83609 m .58307 .83795 L .58224 .8375 L F
.5841 .83609 m .58504 .83711 L .58307 .83795 L F
.499 .581 .868 r
.35924 .76869 m .36009 .76843 L .36161 .76698 L F
.608 .299 .42 r
.36009 .76843 m .36331 .7663 L .36161 .76698 L F
.36009 .76843 m .36228 .76852 L .36331 .7663 L F
.076 .043 .512 r
.36098 .76539 m .36127 .76806 L .36009 .76843 L F
.36127 .76806 m .36127 .76811 L .36009 .76843 L F
.499 .581 .868 r
.35856 .76918 m .36009 .76843 L .35924 .76869 L F
0 0 0 r
.52574 .80584 m .52814 .80518 L .5295 .80447 L F
.398 0 0 r
.5295 .80447 m .52814 .80518 L .53167 .80506 L F
.497 .369 .635 r
.39474 .85823 m .39471 .8602 L .39309 .85978 L F
.592 .286 .419 r
.39471 .8602 m .39143 .86254 L .39309 .85978 L F
0 .554 .745 r
.66786 .72274 m .66869 .72286 L .66553 .72254 L F
.66553 .72254 m .66869 .72286 L .66786 .72274 L F
.48 .891 .926 r
.67018 .72191 m .66869 .72286 L .66786 .72274 L F
.67018 .72191 m .66869 .72286 L .66786 .72274 L F
.165 0 0 r
.40564 .82744 m .40915 .82628 L .40711 .82655 L F
.868 .661 .62 r
.4945 .83174 m .4944 .83411 L .49237 .83242 L F
.695 .724 .872 r
.48064 .8776 m .48345 .87883 L .48207 .87663 L F
.8 .362 .206 r
.48203 .87893 m .48345 .87883 L .48064 .8776 L F
.562 .412 .635 r
.48345 .87883 m .48553 .87865 L .48563 .87628 L F
.102 0 0 r
.48471 .87898 m .48345 .87883 L .48203 .87893 L F
.48471 .87898 m .48553 .87865 L .48345 .87883 L F
.836 .579 .55 r
.50202 .81377 m .49976 .8159 L .49975 .81325 L F
.50202 .81377 m .50167 .81631 L .49976 .8159 L F
.797 .743 .803 r
.49544 .83716 m .49381 .83899 L .49234 .83678 L F
.372 .609 .941 r
.49592 .83944 m .49381 .83899 L .49544 .83716 L F
.631 .62 .821 r
.61059 .7541 m .60786 .75214 L .60927 .75078 L F
.679 .947 .958 r
.56426 .79722 m .56383 .79848 L .56772 .79672 L F
.655 .654 .837 r
.5668 .79875 m .56383 .79848 L .56556 .799 L F
.223 .469 .882 r
.56426 .79722 m .56556 .799 L .56383 .79848 L F
.605 .745 .943 r
.38576 .75648 m .38384 .75698 L .3827 .75593 L F
.714 .539 .652 r
.61814 .76637 m .61604 .76707 L .61607 .76467 L F
.624 .468 .651 r
.3869 .75931 m .38713 .76163 L .38496 .76181 L F
.559 .339 .537 r
.38713 .76163 m .38494 .76392 L .38496 .76181 L F
.044 0 0 r
.6489 .75861 m .64698 .75952 L .64589 .76091 L F
.746 .638 .741 r
.62866 .74919 m .62858 .75126 L .62527 .75072 L F
.75 .623 .718 r
.62858 .75126 m .62654 .75386 L .62527 .75072 L F
.709 .561 .685 r
.62858 .75126 m .63002 .7546 L .62654 .75386 L F
.711 .608 .741 r
.63076 .74853 m .62858 .75126 L .62866 .74919 L F
.731 .571 .675 r
.63174 .75392 m .63002 .7546 L .62858 .75126 L F
.281 .72 .965 r
.45245 .87627 m .45042 .87624 L .44919 .87567 L F
.533 .578 .846 r
.50717 .83842 m .5095 .83883 L .50833 .83657 L F
0 0 .428 r
.56324 .83101 m .5644 .83283 L .56347 .8309 L F
.015 0 .3 r
.56421 .82923 m .56303 .83112 L .56324 .83101 L F
.067 .096 .582 r
.56354 .8266 m .56421 .82923 L .5643 .82765 L F
.881 .874 .435 r
.5643 .82765 m .56324 .83101 L .56319 .83032 L F
0 0 .428 r
.56324 .83101 m .56347 .8309 L .56319 .83032 L F
.015 0 .3 r
.56303 .83112 m .56242 .8321 L .56324 .83101 L F
0 0 .404 r
.56242 .8321 m .56335 .83377 L .56324 .83101 L F
.56242 .8321 m .56293 .83415 L .56335 .83377 L F
.403 .009 .174 r
.52379 .80765 m .52551 .8074 L .52574 .80584 L F
.198 0 .133 r
.52574 .80584 m .52551 .8074 L .52814 .80518 L F
0 0 0 r
.51198 .88016 m .51348 .87925 L .51533 .87844 L F
.903 .726 .652 r
.51736 .81964 m .51483 .82117 L .51584 .81822 L F
.515 .524 .803 r
.36411 .73506 m .36347 .73805 L .3624 .73539 L F
.36411 .73506 m .36537 .73813 L .36347 .73805 L F
.592 .818 .986 r
.40115 .88128 m .40038 .88262 L .39875 .88316 L F
.40115 .88128 m .40241 .88195 L .40038 .88262 L F
.519 .293 .512 r
.36383 .77972 m .36184 .78054 L .36362 .77977 L F
.36383 .77972 m .36154 .78225 L .36184 .78054 L F
.721 .524 .623 r
.63511 .75644 m .63334 .75692 L .63174 .75392 L F
.583 .142 .168 r
.6506 .74193 m .65351 .74315 L .65447 .74176 L F
.673 .848 .437 r
.65447 .74176 m .65351 .74315 L .65504 .74063 L F
.747 .625 .725 r
.63823 .75674 m .63673 .75975 L .63511 .75644 L F
.542 .818 .997 r
.63937 .75564 m .64069 .75647 L .63823 .75674 L F
.422 .146 .386 r
.61703 .78485 m .61943 .78255 L .61955 .7844 L F
.538 .338 .557 r
.61943 .78255 m .62146 .78429 L .61955 .7844 L F
.61943 .78255 m .62158 .78222 L .62146 .78429 L F
.243 .753 .737 r
.43016 .89101 m .42923 .89136 L .43094 .89086 L F
0 0 0 r
.42837 .89181 m .42923 .89136 L .43016 .89101 L F
.697 .607 .752 r
.62122 .75394 m .61907 .75446 L .61802 .75158 L F
.512 .383 .641 r
.3927 .74549 m .3942 .74583 L .39371 .74444 L F
.533 .427 .68 r
.59358 .81598 m .59139 .81668 L .59104 .81386 L F
.46 0 0 r
.59255 .81514 m .59104 .81386 L .59084 .81561 L F
.59186 .81455 m .59358 .81598 L .59104 .81386 L F
.59255 .81514 m .59329 .81574 L .59186 .81455 L F
.59329 .81574 m .59358 .81598 L .59186 .81455 L F
.647 .542 .722 r
.58933 .81008 m .58995 .81297 L .59194 .81325 L F
0 0 0 r
.59041 .81512 m .59104 .81386 L .59194 .81325 L F
.647 .542 .722 r
.58995 .81297 m .59041 .81512 L .59127 .81406 L F
.58995 .81297 m .59127 .81406 L .59194 .81325 L F
.766 .423 .405 r
.59084 .81561 m .59104 .81386 L .59041 .81512 L F
.792 .644 .698 r
.57051 .78084 m .57067 .78314 L .56731 .78244 L F
.723 .286 .211 r
.57058 .78406 m .56731 .78244 L .57067 .78314 L F
.685 .586 .739 r
.51567 .86644 m .51395 .86623 L .51595 .86529 L F
.956 .635 .223 r
.5156 .86805 m .51567 .86644 L .51595 .86529 L F
.525 .823 .491 r
.535 .81665 m .53273 .81907 L .53386 .81785 L F
.689 .581 .728 r
.53151 .82094 m .53386 .81785 L .53273 .81907 L F
.762 .631 .716 r
.63511 .75644 m .63673 .75975 L .63302 .75906 L F
.93 .627 .447 r
.535 .81665 m .53386 .81785 L .53349 .81597 L F
.535 .81665 m .53386 .81785 L .53349 .81597 L F
.067 0 0 r
.40915 .82628 m .41122 .82609 L .41254 .82577 L F
.541 .072 .091 r
.41122 .82609 m .41481 .8257 L .41254 .82577 L F
.816 .681 .714 r
.61383 .7741 m .61192 .77451 L .61375 .7718 L F
.956 .854 .7 r
.61383 .7741 m .61202 .77684 L .61192 .77451 L F
.168 .707 .785 r
.54184 .85997 m .54376 .85972 L .54063 .86003 L F
.54063 .86003 m .54376 .85972 L .54184 .85997 L F
.54184 .85997 m .54376 .85972 L .54063 .86003 L F
.792 .644 .698 r
.57051 .78084 m .56727 .7799 L .56747 .78239 L F
0 0 0 r
.57051 .78084 m .57214 .78021 L .5726 .77999 L F
.57051 .78084 m .56747 .78239 L .57214 .78021 L F
.745 .262 .094 r
.55037 .79246 m .55371 .79417 L .55133 .794 L F
.842 .56 .511 r
.56517 .84203 m .56818 .84485 L .56725 .84446 L F
.818 .532 .505 r
.56725 .84446 m .56818 .84485 L .56705 .84737 L F
.736 .433 .468 r
.56818 .84485 m .57022 .84733 L .56705 .84737 L F
.058 .007 .477 r
.57036 .82508 m .56906 .82416 L .5694 .82354 L F
.57036 .82508 m .56916 .8263 L .56906 .82416 L F
.704 .318 .314 r
.47647 .83456 m .47522 .8363 L .47317 .83439 L F
.661 .265 .285 r
.47892 .83623 m .47522 .8363 L .47647 .83456 L F
.648 .288 .347 r
.47956 .83476 m .47892 .83623 L .47647 .83456 L F
.784 .891 .921 r
.58274 .76609 m .57987 .76645 L .58169 .76529 L F
.745 .916 .95 r
.58533 .76432 m .58274 .76609 L .58169 .76529 L F
.756 .656 .751 r
.63617 .74863 m .63295 .74614 L .63502 .74576 L F
.63617 .74863 m .63419 .7493 L .63295 .74614 L F
.71 .641 .779 r
.63816 .74596 m .63617 .74863 L .63502 .74576 L F
.552 .563 .819 r
.38732 .75608 m .3869 .75931 L .38576 .75648 L F
.38732 .75608 m .38891 .75895 L .3869 .75931 L F
.515 .388 .645 r
.38896 .76117 m .3869 .75931 L .38891 .75895 L F
.38896 .76117 m .38713 .76163 L .3869 .75931 L F
.855 .895 .473 r
.42591 .87608 m .42528 .8776 L .4247 .87816 L F
.241 .747 .701 r
.42694 .87571 m .42833 .87531 L .42591 .87608 L F
0 0 0 r
.42591 .87608 m .4247 .87816 L .42694 .87571 L F
.557 .327 .523 r
.38201 .86292 m .3796 .86541 L .37983 .86314 L F
.283 .196 .577 r
.47213 .87317 m .47321 .87059 L .47296 .87284 L F
.15 .254 .717 r
.47296 .87284 m .47367 .87523 L .47213 .87317 L F
.65 .549 .727 r
.64906 .75515 m .64893 .75659 L .65148 .75594 L F
.413 .142 .39 r
.6489 .75861 m .65148 .75594 L .64893 .75659 L F
.619 .433 .609 r
.61182 .77221 m .61192 .77451 L .60963 .77473 L F
.693 .592 .738 r
.61397 .76969 m .61375 .7718 L .61182 .77221 L F
.661 .466 .61 r
.61375 .7718 m .61192 .77451 L .61182 .77221 L F
.466 .137 .323 r
.64589 .76678 m .64509 .76904 L .64295 .76937 L F
.415 .047 .228 r
.64803 .76669 m .64509 .76904 L .64589 .76678 L F
.797 .743 .803 r
.49544 .83716 m .49234 .83678 L .49419 .8364 L F
.601 .411 .597 r
.49829 .83906 m .49544 .83716 L .49785 .83676 L F
.49829 .83906 m .49592 .83944 L .49544 .83716 L F
0 0 0 r
.55291 .84006 m .55181 .8418 L .55259 .84112 L F
.38 .791 .98 r
.553 .84076 m .55259 .84112 L .55117 .84058 L F
.926 .756 .274 r
.55259 .84112 m .55291 .8428 L .55291 .84163 L F
.55259 .84112 m .55291 .84163 L .55291 .84006 L F
.38 .791 .98 r
.55232 .84069 m .55259 .84112 L .5544 .8409 L F
.55117 .84058 m .55259 .84112 L .55232 .84069 L F
.5544 .8409 m .55259 .84112 L .553 .84076 L F
0 0 0 r
.55181 .8418 m .55167 .84202 L .55259 .84112 L F
.533 .683 .934 r
.55259 .84112 m .55291 .8428 L .5544 .8409 L F
.55259 .84112 m .55291 .8428 L .5544 .8409 L F
0 0 .135 r
.55259 .84112 m .55291 .8428 L .55319 .84427 L F
.038 .141 .644 r
.55259 .84112 m .55167 .84202 L .55319 .84427 L F
.514 .087 .167 r
.42164 .84121 m .42019 .84214 L .41796 .84213 L F
.621 .23 .281 r
.42322 .84199 m .42019 .84214 L .42164 .84121 L F
.751 .885 .94 r
.59855 .75709 m .59426 .75844 L .59797 .75624 L F
.787 .901 .922 r
.59983 .75625 m .59855 .75709 L .59797 .75624 L F
.521 .31 .534 r
.65747 .7464 m .6596 .74597 L .65974 .74366 L F
.516 .318 .55 r
.6596 .74597 m .66176 .74318 L .65974 .74366 L F
.045 .599 .822 r
.48822 .88846 m .49098 .88888 L .48986 .88921 L F
0 0 0 r
.48986 .88921 m .49098 .88888 L .49303 .88855 L F
.035 0 .038 r
.50939 .81857 m .5083 .81838 L .51029 .81871 L F
.50939 .81857 m .50821 .81936 L .5083 .81838 L F
.714 .827 .935 r
.38979 .88633 m .38818 .88738 L .38645 .88635 L F
.368 0 .014 r
.44666 .83459 m .44548 .83603 L .4432 .83623 L F
.453 0 .048 r
.4486 .8347 m .44548 .83603 L .44666 .83459 L F
.649 .499 .665 r
.65003 .751 m .65319 .7536 L .65361 .75146 L F
.65003 .751 m .65166 .75475 L .65319 .7536 L F
.693 .253 .201 r
.50335 .81048 m .50477 .81068 L .50583 .80947 L F
.477 .005 .054 r
.50583 .80947 m .50477 .81068 L .50807 .81008 L F
.323 0 0 r
.50583 .80947 m .50807 .81008 L .5095 .81011 L F
.304 .784 .701 r
.51739 .87767 m .52083 .87635 L .51939 .87758 L F
0 0 0 r
.51939 .87758 m .52083 .87635 L .52265 .87567 L F
.702 .48 .584 r
.49869 .82411 m .49565 .82599 L .49545 .82419 L F
.762 .732 .825 r
.49249 .84741 m .48924 .84728 L .49144 .84491 L F
.791 .541 .559 r
.49249 .84741 m .48941 .84943 L .48924 .84728 L F
.49249 .84741 m .49288 .85041 L .48941 .84943 L F
.765 .733 .823 r
.49456 .84495 m .49249 .84741 L .49144 .84491 L F
.6 .478 .686 r
.49456 .84495 m .49545 .84752 L .49249 .84741 L F
.204 0 0 r
.66176 .74318 m .66394 .74316 L .66495 .74279 L F
.42 .831 .973 r
.45781 .8759 m .45577 .87628 L .45448 .87591 L F
.589 .524 .75 r
.59104 .79 m .5919 .79305 L .59403 .79268 L F
.555 .904 .972 r
.65867 .75379 m .65678 .75459 L .65502 .75479 L F
.642 .899 .984 r
.57476 .76933 m .57376 .77078 L .57128 .77185 L F
.57476 .76933 m .57599 .76989 L .57376 .77078 L F
.535 .159 .275 r
.43772 .8233 m .43988 .82333 L .44118 .82126 L F
.383 0 .04 r
.43988 .82333 m .44329 .82169 L .44118 .82126 L F
.382 0 0 r
.47722 .87397 m .47367 .87523 L .47574 .87502 L F
0 0 .137 r
.47777 .87488 m .47722 .87397 L .47574 .87502 L F
.46 .864 .963 r
.39904 .89829 m .39836 .89901 L .40015 .89847 L F
.39904 .89829 m .39718 .89879 L .39836 .89901 L F
.287 .777 .714 r
.4563 .88507 m .46008 .88376 L .45909 .88423 L F
0 0 0 r
.45909 .88423 m .46008 .88376 L .46217 .8831 L F
.629 .638 .84 r
.64495 .75179 m .64564 .75341 L .64682 .75085 L F
.771 .625 .698 r
.48553 .87865 m .48878 .87871 L .48766 .87582 L F
.067 .629 .777 r
.48764 .87862 m .48878 .87871 L .48553 .87865 L F
.045 .193 .695 r
.48766 .87582 m .48878 .87871 L .48973 .87818 L F
.34 .815 .897 r
.48973 .87818 m .48878 .87871 L .48764 .87862 L F
.851 .811 .81 r
.54893 .7926 m .54588 .79302 L .54712 .79254 L F
.54893 .7926 m .54717 .79376 L .54588 .79302 L F
.14 .684 .813 r
.54893 .7926 m .54712 .79254 L .55037 .79246 L F
.696 .795 .926 r
.3953 .88316 m .39187 .88328 L .39442 .8824 L F
.263 0 0 r
.39587 .88342 m .3953 .88316 L .39442 .8824 L F
.39587 .88342 m .39729 .8838 L .3953 .88316 L F
.313 0 0 r
.49711 .80856 m .49916 .80901 L .50063 .80904 L F
.471 0 0 r
.50155 .80991 m .50063 .80904 L .49916 .80901 L F
.50155 .80991 m .50335 .81048 L .50063 .80904 L F
.702 .607 .747 r
.62334 .75142 m .62443 .75442 L .62122 .75394 L F
.709 .611 .745 r
.62654 .75386 m .62443 .75442 L .62334 .75142 L F
.425 0 .03 r
.47165 .81744 m .47357 .81746 L .47507 .81604 L F
.139 0 0 r
.47507 .81604 m .47624 .81622 L .47707 .81574 L F
.47507 .81604 m .47357 .81746 L .47624 .81622 L F
.67 .318 .368 r
.45936 .83221 m .45921 .8339 L .45605 .83382 L F
.593 .252 .36 r
.46135 .83377 m .45921 .8339 L .45936 .83221 L F
.584 .429 .637 r
.37203 .75393 m .37002 .75655 L .37211 .75622 L F
.506 .314 .554 r
.37007 .75887 m .37211 .75622 L .37002 .75655 L F
.477 .296 .556 r
.59833 .83436 m .59827 .83696 L .5963 .83744 L F
.399 .167 .443 r
.59775 .83882 m .5963 .83744 L .59827 .83696 L F
.59775 .83882 m .59604 .8394 L .5963 .83744 L F
.431 .751 .994 r
.65197 .74634 m .65457 .74623 L .65098 .74547 L F
.697 .607 .752 r
.62122 .75394 m .61802 .75158 L .62012 .75081 L F
.708 .616 .752 r
.62334 .75142 m .62122 .75394 L .62012 .75081 L F
.702 .48 .584 r
.49869 .82411 m .49896 .82688 L .49565 .82599 L F
.632 .429 .589 r
.50111 .8262 m .49869 .82411 L .501 .82397 L F
.50111 .8262 m .49896 .82688 L .49869 .82411 L F
0 .357 .685 r
.53783 .80679 m .53947 .80742 L .53755 .80662 L F
.128 .628 .906 r
.5357 .80635 m .53885 .80717 L .53783 .80679 L F
.5357 .80635 m .53765 .80663 L .53885 .80717 L F
.473 0 0 r
.53815 .80696 m .53885 .80717 L .53765 .80663 L F
.54002 .80815 m .53891 .80722 L .53815 .80696 L F
.53891 .80722 m .53885 .80717 L .53815 .80696 L F
0 .357 .685 r
.53947 .80742 m .54014 .80768 L .53977 .80753 L F
.53947 .80742 m .53977 .80753 L .53755 .80662 L F
.767 .674 .761 r
.36651 .72795 m .36309 .72761 L .36517 .72498 L F
.694 .657 .809 r
.36339 .73066 m .36651 .72795 L .3642 .72891 L F
.36339 .73066 m .36309 .72761 L .36651 .72795 L F
.971 .709 .478 r
.36517 .72498 m .36506 .72745 L .36651 .72795 L F
.97 .703 .47 r
.36506 .72745 m .36665 .73058 L .36651 .72795 L F
0 0 0 r
.44968 .88682 m .45254 .88574 L .45145 .886 L F
.005 0 0 r
.45254 .88574 m .4535 .88574 L .45145 .886 L F
.45254 .88574 m .45424 .88559 L .4535 .88574 L F
.358 0 0 r
.65879 .76457 m .65783 .76502 L .6554 .76449 L F
.087 0 0 r
.65879 .76457 m .65973 .76501 L .65783 .76502 L F
.65879 .76457 m .66079 .76395 L .65973 .76501 L F
.628 .543 .739 r
.58973 .78463 m .59076 .78782 L .59296 .78746 L F
.602 .483 .69 r
.59076 .78782 m .59335 .7896 L .59296 .78746 L F
.59076 .78782 m .59104 .79 L .59335 .7896 L F
.17 0 .015 r
.46406 .87284 m .46335 .87214 L .46286 .87278 L F
.46406 .87284 m .46526 .87107 L .46335 .87214 L F
.971 .776 .346 r
.60895 .783 m .60945 .78522 L .60923 .78747 L F
.709 .611 .745 r
.62654 .75386 m .62334 .75142 L .62527 .75072 L F
.222 .379 .809 r
.57172 .82851 m .57096 .82943 L .56916 .8263 L F
.875 .947 .857 r
.57602 .79716 m .57497 .79892 L .5748 .79673 L F
0 .066 .625 r
.5748 .79673 m .57497 .79892 L .57576 .79917 L F
.8 .753 .81 r
.58208 .77716 m .58345 .77973 L .58537 .77704 L F
.697 .6 .743 r
.58345 .77973 m .58651 .78007 L .58537 .77704 L F
.703 .571 .703 r
.58345 .77973 m .58429 .78269 L .58651 .78007 L F
.553 .096 .122 r
.57342 .84769 m .57672 .84738 L .57571 .84873 L F
.498 .062 .142 r
.57672 .84738 m .57775 .84904 L .57571 .84873 L F
.57672 .84738 m .57879 .84746 L .57775 .84904 L F
.365 .2 .52 r
.49695 .8531 m .49814 .85449 L .49907 .85256 L F
.458 .079 .232 r
.47892 .8151 m .48102 .81487 L .48219 .81261 L F
.306 0 .081 r
.48219 .81261 m .48365 .81316 L .48479 .81142 L F
.295 0 .148 r
.48219 .81261 m .48102 .81487 L .48365 .81316 L F
.564 .385 .598 r
.61254 .79038 m .61252 .79213 L .6106 .79262 L F
.544 .331 .542 r
.6106 .79262 m .61176 .79481 L .61023 .79517 L F
.6106 .79262 m .61252 .79213 L .61176 .79481 L F
.717 .43 .49 r
.38528 .86277 m .3841 .86505 L .38201 .86292 L F
.618 .317 .437 r
.38699 .86487 m .38528 .86277 L .38753 .86336 L F
.38699 .86487 m .3841 .86505 L .38528 .86277 L F
.779 .984 .903 r
.56748 .7975 m .5668 .79875 L .56556 .799 L F
.65 .549 .727 r
.64906 .75515 m .65148 .75594 L .65166 .75475 L F
.616 .943 .748 r
.57963 .83892 m .57823 .84007 L .57649 .84099 L F
.538 .423 .671 r
.36577 .76181 m .36795 .76382 L .36806 .76156 L F
.36577 .76181 m .36607 .76432 L .36795 .76382 L F
.737 .632 .742 r
.61565 .76915 m .61375 .7718 L .61397 .76969 L F
.655 .847 .974 r
.35559 .73119 m .35348 .732 L .35219 .73116 L F
.505 .12 .243 r
.49975 .85525 m .49916 .85572 L .49705 .85562 L F
.498 .65 .926 r
.49705 .85562 m .49916 .85572 L .49814 .85449 L F
.493 .248 .471 r
.37334 .77206 m .3729 .77419 L .37098 .77453 L F
.475 .237 .473 r
.37527 .77151 m .3729 .77419 L .37334 .77206 L F
.699 .4 .466 r
.4818 .83443 m .47892 .83623 L .47956 .83476 L F
.787 .901 .922 r
.59983 .75625 m .59797 .75624 L .59867 .75553 L F
.81 .891 .902 r
.60222 .75413 m .59983 .75625 L .59867 .75553 L F
.69 .544 .682 r
.65486 .7496 m .65747 .7464 L .65541 .74554 L F
.65486 .7496 m .65715 .75008 L .65747 .7464 L F
.12 .052 .498 r
.65747 .7464 m .65873 .74792 L .6596 .74597 L F
.526 .297 .509 r
.66779 .75605 m .66746 .75866 L .66554 .7591 L F
.576 .381 .58 r
.66995 .75382 m .66987 .75605 L .66779 .75605 L F
.553 .313 .506 r
.66987 .75605 m .66746 .75866 L .66779 .75605 L F
.764 .65 .736 r
.62743 .74819 m .62866 .74919 L .62558 .74887 L F
.746 .638 .741 r
.62866 .74919 m .62527 .75072 L .62558 .74887 L F
.721 .656 .784 r
.63076 .74853 m .62866 .74919 L .62743 .74819 L F
.505 .28 .506 r
.6722 .75349 m .66987 .75605 L .66995 .75382 L F
.738 .617 .724 r
.61814 .76637 m .61565 .76915 L .61604 .76707 L F
.824 .923 .901 r
.58878 .80822 m .58781 .8099 L .5874 .81034 L F
.58878 .80822 m .5874 .81034 L .58933 .81008 L F
.624 .527 .724 r
.58795 .81427 m .58933 .81008 L .5874 .81034 L F
0 0 0 r
.525 .87115 m .52072 .87219 L .52228 .87476 L F
.712 .286 .235 r
.38121 .87554 m .3834 .87577 L .38225 .87475 L F
.678 .589 .749 r
.58537 .77704 m .58651 .78007 L .58842 .77775 L F
.461 .234 .482 r
.61467 .78751 m .61703 .78485 L .61684 .78667 L F
.541 .333 .546 r
.61703 .78485 m .61922 .78667 L .61684 .78667 L F
.61703 .78485 m .61955 .7844 L .61922 .78667 L F
0 .238 .675 r
.54289 .80948 m .54105 .8085 L .54014 .80768 L F
.54289 .80948 m .54383 .81021 L .54105 .8085 L F
.563 .364 .569 r
.60963 .77473 m .60974 .77731 L .60739 .7774 L F
.646 .428 .573 r
.61202 .77684 m .60963 .77473 L .61192 .77451 L F
.61202 .77684 m .60974 .77731 L .60963 .77473 L F
0 0 .412 r
.58443 .78219 m .58639 .77841 L .58756 .77904 L F
.58 .534 .768 r
.58756 .77904 m .58858 .78211 L .58443 .78219 L F
0 0 .412 r
.58443 .78219 m .58642 .78069 L .58639 .77841 L F
.367 .685 .98 r
.58443 .78219 m .58803 .7818 L .58642 .78069 L F
.242 .729 .925 r
.58858 .78211 m .58803 .7818 L .58443 .78219 L F
.356 .808 .944 r
.42249 .87929 m .42031 .87936 L .4228 .87901 L F
0 0 0 r
.42031 .87936 m .42097 .87954 L .4228 .87901 L F
.424 .866 .8 r
.4231 .87875 m .4228 .87901 L .42097 .87954 L F
.898 .915 .826 r
.42528 .8776 m .42409 .87924 L .4228 .87901 L F
.42528 .8776 m .4228 .87901 L .4247 .87816 L F
.424 .866 .8 r
.4247 .87816 m .4228 .87901 L .4231 .87875 L F
.356 .808 .944 r
.42409 .87924 m .42249 .87929 L .4228 .87901 L F
.762 .743 .835 r
.60786 .75214 m .60386 .753 L .60646 .75118 L F
.818 .821 .851 r
.60927 .75078 m .60786 .75214 L .60646 .75118 L F
.487 .283 .527 r
.61254 .79038 m .61467 .78751 L .61411 .79028 L F
.517 .325 .559 r
.61688 .78938 m .61467 .78751 L .61684 .78667 L F
.61688 .78938 m .61411 .79028 L .61467 .78751 L F
.726 .984 .781 r
.44461 .87387 m .44189 .87618 L .44388 .87568 L F
.245 0 .283 r
.44605 .87322 m .44461 .87387 L .44388 .87568 L F
.721 .656 .784 r
.63076 .74853 m .62743 .74819 L .62969 .74582 L F
.724 .688 .815 r
.63295 .74614 m .63076 .74853 L .62969 .74582 L F
.682 .619 .778 r
.63295 .74614 m .63419 .7493 L .63076 .74853 L F
.699 .4 .466 r
.4818 .83443 m .48041 .83671 L .47892 .83623 L F
.679 .376 .454 r
.48381 .83654 m .48041 .83671 L .4818 .83443 L F
.847 .665 .127 r
.56617 .77926 m .56638 .78179 L .56727 .7799 L F
.82 .648 .669 r
.56954 .7903 m .56635 .7923 L .56844 .78967 L F
.56954 .7903 m .56811 .79283 L .56635 .7923 L F
.833 .904 .888 r
.56617 .77926 m .56727 .7799 L .56978 .77769 L F
.541 .623 .882 r
.5713 .78872 m .56954 .7903 L .56844 .78967 L F
.5713 .78872 m .57151 .78994 L .56954 .7903 L F
.41 .421 .76 r
.57229 .79229 m .56954 .7903 L .57151 .78994 L F
.308 0 0 r
.52072 .87219 m .51959 .87186 L .51839 .87225 L F
.69 .565 .709 r
.42861 .8415 m .42531 .83937 L .42864 .8406 L F
.481 .117 .27 r
.65337 .76407 m .6524 .76615 L .65019 .76634 L F
.576 .129 .152 r
.65337 .76407 m .65455 .76587 L .6524 .76615 L F
.65337 .76407 m .6554 .76449 L .65455 .76587 L F
.634 .469 .642 r
.39614 .8542 m .39363 .85268 L .39557 .85269 L F
.39614 .8542 m .39364 .85464 L .39363 .85268 L F
.628 .627 .83 r
.43627 .87738 m .43431 .87807 L .43326 .87577 L F
0 0 0 r
.48707 .81566 m .48554 .81719 L .48805 .81439 L F
.533 0 0 r
.48805 .81439 m .4892 .81553 L .48707 .81566 L F
.519 .025 .022 r
.57879 .84746 m .58202 .84725 L .58106 .84842 L F
.442 0 .013 r
.58202 .84725 m .58304 .84857 L .58106 .84842 L F
.58202 .84725 m .58416 .84733 L .58304 .84857 L F
.545 .236 .395 r
.67316 .74591 m .67548 .74554 L .67571 .744 L F
.781 .552 .589 r
.67548 .74554 m .67689 .7438 L .67571 .744 L F
.937 .869 .746 r
.66045 .75116 m .65807 .75258 L .6575 .75105 L F
.66045 .75116 m .65867 .75379 L .65854 .75353 L F
.66045 .75116 m .65854 .75353 L .65851 .75231 L F
.635 .576 .771 r
.65958 .75021 m .65988 .75296 L .66211 .75221 L F
.65957 .75022 m .65988 .75296 L .65958 .75021 L F
.65892 .74969 m .6593 .75096 L .65957 .7502 L F
.6593 .75096 m .65988 .75296 L .65957 .7502 L F
.047 0 .059 r
.6575 .75105 m .65956 .75023 L .6593 .75096 L F
.65956 .75023 m .65959 .75022 L .6593 .75096 L F
.65959 .75022 m .66034 .74992 L .6598 .75046 L F
.65959 .75022 m .6598 .75046 L .6593 .75096 L F
.65887 .75098 m .65988 .75296 L .6593 .75096 L F
.6575 .75105 m .65849 .75184 L .65846 .75076 L F
.6575 .75105 m .65846 .75076 L .65844 .75015 L F
.6575 .75105 m .65918 .75055 L .65956 .75023 L F
.65849 .75184 m .65988 .75296 L .65872 .75068 L F
.65846 .75076 m .65872 .75068 L .65844 .75015 L F
.65849 .75184 m .65872 .75068 L .65846 .75076 L F
.6575 .75105 m .65807 .75258 L .65988 .75296 L F
.6575 .75105 m .65946 .75095 L .65807 .75258 L F
.538 .323 .535 r
.6575 .75105 m .65807 .75258 L .65554 .75326 L F
.047 0 .059 r
.65732 .75208 m .65718 .75294 L .65932 .75051 L F
.65918 .75055 m .65932 .75051 L .65956 .75023 L F
.65732 .75208 m .65932 .75051 L .65918 .75055 L F
.6575 .75105 m .65732 .75208 L .65918 .75055 L F
.65887 .75098 m .6593 .75096 L .65892 .74969 L F
.65956 .75023 m .65718 .75294 L .65973 .7505 L F
.65959 .75022 m .65971 .75047 L .66034 .74992 L F
.65956 .75023 m .65973 .7505 L .65959 .75022 L F
.635 .576 .771 r
.65892 .74969 m .65957 .7502 L .65959 .75022 L F
.65957 .7502 m .65957 .75022 L .65958 .75021 L F
.65892 .74969 m .65959 .75022 L .65971 .75047 L F
.65892 .74969 m .65971 .75047 L .66078 .74921 L F
.413 .02 .181 r
.66021 .75081 m .65985 .7505 L .65807 .75258 L F
.65988 .75296 m .66021 .75081 L .65807 .75258 L F
.635 .576 .771 r
.66002 .75069 m .66211 .75221 L .66083 .75158 L F
.65957 .7502 m .66092 .75127 L .66002 .75069 L F
.66092 .75127 m .66211 .75221 L .66002 .75069 L F
.047 0 .059 r
.65844 .75015 m .65887 .75098 L .65892 .74969 L F
.524 .088 .154 r
.65434 .75257 m .6575 .75105 L .65554 .75326 L F
.65434 .75257 m .65718 .75294 L .6575 .75105 L F
.787 .774 .841 r
.65553 .75157 m .65718 .75294 L .65973 .7505 L F
.635 .576 .771 r
.65964 .75033 m .65959 .75022 L .65984 .7505 L F
.66006 .75019 m .66083 .75157 L .66079 .7496 L F
.65971 .75047 m .65964 .75033 L .65993 .75063 L F
.65971 .75047 m .65978 .75053 L .66006 .75019 L F
.65971 .75047 m .65993 .75063 L .65978 .75053 L F
.413 .02 .181 r
.66021 .75081 m .66034 .74992 L .65985 .7505 L F
.66021 .75081 m .65978 .75053 L .66034 .74992 L F
.047 0 .059 r
.6593 .75096 m .66034 .74992 L .65946 .75095 L F
.413 .02 .181 r
.65978 .75053 m .66001 .75026 L .66034 .74992 L F
.66001 .75026 m .66006 .75019 L .66034 .74992 L F
.65988 .75296 m .65973 .7505 L .66021 .75081 L F
.635 .576 .771 r
.65978 .75053 m .65993 .75063 L .66083 .75157 L F
.65964 .75033 m .65984 .7505 L .66002 .75069 L F
.65993 .75064 m .66002 .75069 L .66083 .75157 L F
.65964 .75033 m .66002 .75069 L .65993 .75064 L F
.787 .774 .841 r
.65553 .75157 m .65718 .75294 L .65973 .7505 L F
.047 0 .059 r
.65971 .75047 m .65973 .7505 L .66006 .75019 L F
.65971 .75047 m .66006 .75019 L .66034 .74992 L F
.787 .774 .841 r
.65935 .75026 m .65973 .7505 L .66034 .74992 L F
.686 .328 .363 r
.65486 .7496 m .6575 .75105 L .65715 .75008 L F
.059 .005 .474 r
.65715 .75008 m .6575 .75105 L .65892 .74969 L F
.787 .774 .841 r
.65553 .75157 m .65973 .7505 L .65935 .75026 L F
.635 .576 .771 r
.65957 .7502 m .66083 .75158 L .66083 .75157 L F
.65978 .75053 m .66083 .75157 L .66006 .75019 L F
.413 .02 .181 r
.65978 .75053 m .65973 .7505 L .66006 .75019 L F
.787 .774 .841 r
.65935 .75026 m .65973 .7505 L .66034 .74992 L F
.65553 .75157 m .65973 .7505 L .65935 .75026 L F
.937 .869 .746 r
.65851 .75231 m .65854 .75353 L .65807 .75258 L F
.706 .7 .842 r
.65867 .75379 m .65554 .75326 L .65807 .75258 L F
.344 .583 .932 r
.65807 .75258 m .65988 .75296 L .65867 .75379 L F
.413 .02 .181 r
.65988 .75296 m .65718 .75294 L .65973 .7505 L F
.635 .576 .771 r
.65971 .75047 m .66079 .7496 L .66078 .74921 L F
.358 0 0 r
.44329 .82169 m .44532 .82158 L .44637 .82083 L F
.574 .154 .207 r
.44532 .82158 m .44848 .82103 L .44637 .82083 L F
.632 .446 .613 r
.47261 .86814 m .47523 .86844 L .47515 .86546 L F
.088 0 .093 r
.47412 .86783 m .47515 .86546 L .47261 .86814 L F
.476 .325 .596 r
.47697 .8676 m .47515 .86546 L .47658 .86523 L F
.098 0 0 r
.47658 .86523 m .47515 .86546 L .47537 .86584 L F
.476 .325 .596 r
.47697 .8676 m .47523 .86844 L .47515 .86546 L F
0 0 0 r
.47537 .86584 m .47515 .86546 L .47412 .86783 L F
.627 .536 .732 r
.6062 .79555 m .60594 .79778 L .60372 .79808 L F
.64 .462 .626 r
.60594 .79778 m .60376 .80038 L .60372 .79808 L F
.383 0 .024 r
.60422 .79928 m .60372 .79808 L .60376 .80038 L F
.60422 .79928 m .60594 .79778 L .60372 .79808 L F
.627 .536 .732 r
.6062 .79555 m .60594 .79778 L .60372 .79808 L F
.048 0 0 r
.591 .8171 m .59139 .81668 L .59358 .81598 L F
.679 .947 .958 r
.56426 .79722 m .56772 .79672 L .56216 .79523 L F
.361 .044 .285 r
.43998 .83859 m .43895 .83702 L .44104 .83666 L F
.43998 .83859 m .4381 .83928 L .43895 .83702 L F
.428 .257 .546 r
.59995 .83629 m .59833 .83436 L .60003 .83401 L F
.59995 .83629 m .59827 .83696 L .59833 .83436 L F
.108 0 0 r
.49501 .88821 m .49857 .88672 L .49715 .88744 L F
0 0 0 r
.49715 .88744 m .49857 .88672 L .50051 .88616 L F
.872 .552 .441 r
.56517 .84203 m .56725 .84446 L .56447 .84412 L F
.885 .774 .734 r
.56447 .84412 m .56725 .84446 L .56497 .84711 L F
.818 .532 .505 r
.56725 .84446 m .56705 .84737 L .56497 .84711 L F
.612 .136 .101 r
.46901 .8716 m .47064 .87037 L .46741 .87043 L F
.48 .707 .969 r
.47321 .87059 m .47064 .87037 L .47261 .86814 L F
.122 0 .185 r
.47261 .86814 m .47064 .87037 L .47195 .87052 L F
.443 0 .085 r
.42181 .82592 m .42389 .82591 L .42528 .82437 L F
.406 0 .026 r
.42389 .82591 m .42733 .82442 L .42528 .82437 L F
.268 .398 .809 r
.60102 .82882 m .59978 .82965 L .59892 .82939 L F
.60102 .82882 m .60199 .83133 L .59978 .82965 L F
.711 .538 .653 r
.48553 .87865 m .48766 .87582 L .48563 .87628 L F
.045 .193 .695 r
.48766 .87582 m .48973 .87818 L .49114 .87597 L F
.726 .725 .849 r
.58858 .78211 m .58973 .78463 L .59186 .78243 L F
.631 .563 .76 r
.58973 .78463 m .59262 .78574 L .59186 .78243 L F
.628 .543 .739 r
.58973 .78463 m .59296 .78746 L .59262 .78574 L F
.278 0 .065 r
.48479 .81142 m .48557 .81259 L .48679 .8111 L F
.48479 .81142 m .48365 .81316 L .48557 .81259 L F
.16 .408 .851 r
.58282 .80028 m .58566 .80315 L .58538 .80079 L F
.622 .472 .658 r
.58538 .80079 m .58566 .80315 L .58767 .80057 L F
.55 .381 .605 r
.61411 .79028 m .61252 .79213 L .61254 .79038 L F
0 .03 .576 r
.54564 .81203 m .54445 .81098 L .54383 .81021 L F
.54564 .81203 m .54632 .81307 L .54445 .81098 L F
.577 .732 .949 r
.39231 .82813 m .39131 .8297 L .38926 .83038 L F
.39231 .82813 m .39333 .82933 L .39131 .8297 L F
.69 .544 .682 r
.65486 .7496 m .65541 .74554 L .65457 .74623 L F
.332 0 0 r
.46622 .88256 m .46738 .88208 L .46953 .88244 L F
.589 .524 .75 r
.59104 .79 m .59403 .79268 L .59335 .7896 L F
.749 .862 .931 r
.59059 .76201 m .58755 .76233 L .58945 .76127 L F
.847 .877 .862 r
.59293 .75966 m .59059 .76201 L .58945 .76127 L F
.747 .653 .756 r
.50497 .82997 m .50327 .83193 L .50199 .82947 L F
.71 .593 .724 r
.50777 .83109 m .50327 .83193 L .50497 .82997 L F
.23 .739 .886 r
.49482 .87726 m .49613 .87739 L .49366 .8776 L F
.274 0 0 r
.50807 .81008 m .51127 .81044 L .5095 .81011 L F
0 0 .135 r
.56485 .83944 m .56517 .84203 L .56421 .84173 L F
.872 .552 .441 r
.56517 .84203 m .56447 .84412 L .56421 .84173 L F
.696 .278 .249 r
.45131 .87303 m .45332 .87457 L .45173 .8741 L F
.405 .179 .455 r
.44919 .87567 m .44962 .87354 L .45131 .87303 L F
.867 .856 .828 r
.44919 .87567 m .45131 .87303 L .44946 .87343 L F
.696 .278 .249 r
.45131 .87303 m .45173 .8741 L .44946 .87343 L F
0 0 0 r
.44962 .87354 m .45093 .87206 L .45131 .87303 L F
.45093 .87206 m .45169 .87121 L .45131 .87303 L F
.734 .887 .489 r
.45352 .86803 m .45169 .87121 L .45217 .86991 L F
.731 .991 .842 r
.45217 .86991 m .45169 .87121 L .44908 .87252 L F
.511 .374 .631 r
.45384 .87075 m .45169 .87121 L .45352 .86803 L F
.438 .171 .41 r
.45131 .87303 m .45169 .87121 L .45384 .87075 L F
.556 .612 .864 r
.50923 .82971 m .51057 .83155 L .50796 .83169 L F
.592 .508 .729 r
.51057 .83155 m .50887 .83492 L .50796 .83169 L F
.733 .631 .745 r
.60974 .77731 m .60772 .77982 L .60739 .7774 L F
.425 .686 .972 r
.56676 .77384 m .5678 .77508 L .56671 .77523 L F
.232 0 .001 r
.43384 .89148 m .43689 .88958 L .4358 .88955 L F
.357 .828 .879 r
.4358 .88955 m .43689 .88958 L .43884 .88905 L F
.634 .646 .844 r
.61468 .75076 m .61163 .7487 L .61478 .74936 L F
.647 .564 .747 r
.61697 .74866 m .61468 .75076 L .61478 .74936 L F
.678 .618 .78 r
.61697 .74866 m .61802 .75158 L .61468 .75076 L F
.629 .116 .01 r
.51127 .81044 m .5129 .81169 L .51444 .81098 L F
.218 0 0 r
.5129 .81169 m .51649 .81109 L .51444 .81098 L F
.812 .837 .869 r
.60927 .75078 m .60646 .75118 L .60801 .74987 L F
.794 .838 .885 r
.61163 .7487 m .60927 .75078 L .60801 .74987 L F
.07 .463 .886 r
.65171 .74178 m .65351 .74315 L .6506 .74193 L F
.65171 .74178 m .6506 .74193 L .64995 .74205 L F
.634 .598 .795 r
.37082 .751 m .37203 .75393 L .37423 .75354 L F
.562 .386 .601 r
.37211 .75622 m .37423 .75354 L .37203 .75393 L F
.472 .323 .597 r
.67205 .7463 m .67315 .74853 L .67316 .74591 L F
.439 .838 .978 r
.4408 .88839 m .44197 .88876 L .4438 .88826 L F
0 0 0 r
.50622 .8751 m .5035 .87561 L .50583 .87574 L F
.315 .792 .709 r
.5075 .8745 m .50913 .87393 L .50622 .8751 L F
.505 .086 .18 r
.45588 .8209 m .45801 .82095 L .45923 .81927 L F
.56 .147 .215 r
.45923 .81927 m .45801 .82095 L .46108 .82038 L F
0 0 0 r
.5023 .8855 m .50578 .88347 L .50523 .88394 L F
.443 .879 .845 r
.50671 .88277 m .50578 .88347 L .50789 .88259 L F
0 0 0 r
.50523 .88394 m .50578 .88347 L .50671 .88277 L F
.42984 .87487 m .42833 .87531 L .42694 .87571 L F
.69 .702 .855 r
.57152 .7764 m .57476 .777 L .57415 .77585 L F
.352 .61 .947 r
.57476 .777 m .57528 .77591 L .57415 .77585 L F
.979 .738 .502 r
.57476 .777 m .57361 .77886 L .57528 .77591 L F
.57476 .777 m .57471 .7795 L .57361 .77886 L F
.493 .203 .401 r
.57678 .77757 m .57471 .7795 L .57476 .777 L F
.706 .58 .711 r
.62546 .76379 m .625 .76285 L .62563 .76171 L F
.719 .585 .704 r
.62786 .7615 m .62546 .76379 L .62563 .76171 L F
.698 .628 .775 r
.62012 .75081 m .61802 .75158 L .61697 .74866 L F
0 0 0 r
.52705 .87304 m .53019 .87084 L .5292 .87084 L F
.473 .846 .609 r
.53019 .87084 m .53283 .86884 L .53116 .87002 L F
.499 .906 .899 r
.5292 .87084 m .53019 .87084 L .53116 .87002 L F
.545 .565 .826 r
.379 .74297 m .37835 .74603 L .37709 .74312 L F
.379 .74297 m .38026 .74575 L .37835 .74603 L F
.589 .481 .699 r
.38065 .74793 m .37835 .74603 L .38026 .74575 L F
.38065 .74793 m .37874 .74828 L .37835 .74603 L F
.769 .615 .688 r
.58241 .78579 m .58435 .78492 L .58302 .78508 L F
.58241 .78579 m .58256 .78791 L .58435 .78492 L F
.867 .536 .423 r
.49337 .81662 m .49482 .81848 L .49466 .81634 L F
.755 .552 .622 r
.49466 .81634 m .49482 .81848 L .49602 .81797 L F
.369 .755 .988 r
.58613 .83639 m .58504 .83711 L .5841 .83609 L F
.58613 .83639 m .58742 .83706 L .58504 .83711 L F
.747 .653 .756 r
.50497 .82997 m .50199 .82947 L .50396 .82867 L F
.486 .848 .991 r
.50601 .82915 m .50497 .82997 L .50396 .82867 L F
.50601 .82915 m .50695 .82954 L .50497 .82997 L F
.34 .817 .783 r
.50173 .87642 m .49883 .87727 L .50032 .8774 L F
0 0 0 r
.5035 .87561 m .50173 .87642 L .50032 .8774 L F
.5035 .87561 m .50032 .8774 L .50237 .87772 L F
.1 .614 .889 r
.49941 .87697 m .50155 .87751 L .50032 .8774 L F
.50155 .87751 m .50237 .87772 L .50032 .8774 L F
.34 .817 .783 r
.49883 .87727 m .49804 .87751 L .50032 .8774 L F
.551 .027 0 r
.41481 .8257 m .41651 .82629 L .41761 .82592 L F
.297 0 0 r
.41761 .82592 m .41651 .82629 L .4197 .82597 L F
.719 .585 .704 r
.62786 .7615 m .6279 .76311 L .62546 .76379 L F
.695 .561 .699 r
.63129 .75963 m .63126 .76207 L .62786 .7615 L F
.694 .565 .705 r
.62786 .7615 m .63126 .76207 L .6279 .76311 L F
.647 .891 .984 r
.38984 .90115 m .39324 .90078 L .39194 .90048 L F
.641 .923 .976 r
.39194 .90048 m .39324 .90078 L .39555 .8998 L F
.56 .225 .358 r
.41379 .84441 m .41265 .84697 L .41057 .8454 L F
.605 .273 .38 r
.41411 .84636 m .41379 .84441 L .41587 .84442 L F
.41411 .84636 m .41265 .84697 L .41379 .84441 L F
.809 .908 .908 r
.49275 .86176 m .4907 .86342 L .49272 .86307 L F
.91 .839 .383 r
.56852 .83727 m .56898 .83431 L .57086 .83673 L F
.705 .87 .959 r
.57024 .83781 m .56852 .83727 L .57086 .83673 L F
.57024 .83781 m .56919 .83954 L .56852 .83727 L F
.572 .419 .635 r
.3942 .74583 m .39683 .74385 L .39371 .74444 L F
.585 .905 .652 r
.5726 .77999 m .57361 .77886 L .57471 .7795 L F
.5726 .77999 m .57214 .78021 L .57361 .77886 L F
.943 .749 .611 r
.53421 .81379 m .53349 .81597 L .53228 .81425 L F
.458 .575 .884 r
.37988 .86692 m .38215 .86785 L .38064 .8682 L F
.449 .189 .427 r
.38215 .86785 m .38019 .87038 L .38064 .8682 L F
.745 .606 .703 r
.63511 .75644 m .63302 .75906 L .63334 .75692 L F
.73 .438 .485 r
.57955 .80557 m .58125 .80292 L .57716 .80293 L F
.46 .653 .943 r
.58435 .80484 m .58357 .80547 L .58393 .80561 L F
.58357 .80547 m .58328 .8057 L .58393 .80561 L F
.217 .166 .583 r
.58491 .80686 m .58381 .80608 L .58435 .80484 L F
.58381 .80608 m .58328 .8057 L .58352 .80551 L F
.326 0 .229 r
.58052 .80822 m .58328 .8057 L .58352 .80671 L F
.622 .169 .155 r
.5822 .80736 m .58378 .80577 L .57955 .80557 L F
.58378 .80577 m .58393 .80561 L .58362 .80561 L F
.217 .166 .583 r
.58372 .80586 m .58352 .80551 L .58362 .80561 L F
.58381 .80608 m .58371 .80588 L .58372 .80586 L F
.58371 .80588 m .58352 .80551 L .58372 .80586 L F
.716 .921 .577 r
.58435 .80484 m .58393 .80561 L .58378 .80577 L F
.622 .169 .155 r
.58378 .80577 m .58362 .80561 L .57955 .80557 L F
.217 .166 .583 r
.58381 .80608 m .58357 .80547 L .58435 .80484 L F
.58362 .80561 m .58352 .80551 L .58357 .80547 L F
.739 .45 .491 r
.57955 .80557 m .58393 .80561 L .5804 .80424 L F
.217 .166 .583 r
.58491 .80686 m .58352 .80671 L .58328 .8057 L F
.716 .921 .577 r
.58435 .80484 m .58378 .80577 L .5822 .80736 L F
.739 .45 .491 r
.5804 .80424 m .58357 .80547 L .58125 .80292 L F
.58357 .80547 m .58393 .80561 L .58342 .8051 L F
.58357 .80547 m .58342 .8051 L .58125 .80292 L F
.605 .53 .744 r
.48707 .81566 m .48569 .81799 L .48554 .81719 L F
.454 .201 .44 r
.37098 .77453 m .37042 .77727 L .36861 .77709 L F
.467 .206 .434 r
.3729 .77419 m .37042 .77727 L .37098 .77453 L F
.507 .205 .389 r
.64074 .76971 m .64258 .77079 L .64092 .77085 L F
.64074 .76971 m .64295 .76937 L .64258 .77079 L F
.54 .923 .913 r
.66677 .75003 m .66523 .74992 L .66378 .75122 L F
.633 .464 .636 r
.66677 .75003 m .66656 .75145 L .66378 .75122 L F
.587 .21 .295 r
.66573 .75238 m .66656 .75145 L .66378 .75122 L F
.561 .317 .504 r
.66496 .75264 m .66734 .7525 L .66739 .75239 L F
.66659 .75186 m .66739 .75239 L .66798 .75119 L F
.66496 .75264 m .66739 .75239 L .66659 .75186 L F
.996 .856 .578 r
.66458 .75051 m .66573 .75238 L .66378 .75122 L F
.66523 .74992 m .66547 .7511 L .66458 .75051 L F
.66547 .7511 m .66573 .75238 L .66458 .75051 L F
.624 .297 .397 r
.46555 .83145 m .46361 .83404 L .46135 .83377 L F
.631 .306 .402 r
.46735 .83352 m .46555 .83145 L .46564 .83316 L F
.801 .379 .244 r
.40086 .85128 m .39938 .85174 L .39774 .84975 L F
.597 .076 0 r
.40086 .85128 m .40279 .85234 L .39938 .85174 L F
.569 .279 .436 r
.36639 .77838 m .36607 .77961 L .36383 .77972 L F
.415 .138 .381 r
.36789 .77911 m .36639 .77838 L .36861 .77709 L F
.36789 .77911 m .36607 .77961 L .36639 .77838 L F
.289 0 .261 r
.44716 .87592 m .44962 .87354 L .44919 .87567 L F
.615 .408 .577 r
.60798 .79541 m .60594 .79778 L .6062 .79555 L F
.60798 .79541 m .6082 .79765 L .60594 .79778 L F
.561 .367 .575 r
.60798 .79541 m .61027 .79743 L .6082 .79765 L F
.60798 .79541 m .61023 .79517 L .61027 .79743 L F
.245 .226 .639 r
.47449 .87021 m .47261 .86814 L .47523 .86844 L F
.47449 .87021 m .47321 .87059 L .47261 .86814 L F
.11 0 .18 r
.47412 .86783 m .47261 .86814 L .47195 .87052 L F
.847 .877 .862 r
.59293 .75966 m .58945 .76127 L .59199 .75925 L F
.826 .954 .899 r
.59426 .75844 m .59293 .75966 L .59199 .75925 L F
.833 .904 .888 r
.56617 .77926 m .56978 .77769 L .56828 .77671 L F
.779 .827 .89 r
.56828 .77671 m .56978 .77769 L .57152 .7764 L F
0 0 0 r
.46286 .87278 m .4595 .87458 L .46224 .87362 L F
.091 0 0 r
.46406 .87284 m .46286 .87278 L .46224 .87362 L F
.728 .634 .754 r
.62527 .75072 m .62224 .74841 L .62558 .74887 L F
.62527 .75072 m .62334 .75142 L .62224 .74841 L F
.059 .005 .474 r
.65715 .75008 m .65892 .74969 L .65873 .74792 L F
.506 .881 .974 r
.41186 .89562 m .41101 .89646 L .41302 .8957 L F
.41186 .89562 m .40996 .8962 L .41101 .89646 L F
.566 .344 .538 r
.63103 .77449 m .6307 .77617 L .62877 .77643 L F
.503 .237 .444 r
.63323 .77432 m .6307 .77617 L .63103 .77449 L F
.432 .756 .995 r
.4138 .88049 m .41301 .88156 L .41182 .88099 L F
.4138 .88049 m .41535 .8815 L .41301 .88156 L F
.712 .688 .826 r
.57149 .83869 m .57195 .84051 L .56919 .83954 L F
.611 .956 .86 r
.57195 .84051 m .56915 .84181 L .56919 .83954 L F
.48 .535 .836 r
.57343 .83885 m .57195 .84051 L .57149 .83869 L F
.64 .793 .956 r
.57343 .83885 m .57451 .84027 L .57195 .84051 L F
.914 .848 .765 r
.63937 .75564 m .64069 .75647 L .64193 .75352 L F
.923 .533 .213 r
.6401 .75771 m .64069 .75647 L .63937 .75564 L F
.6401 .75771 m .6414 .75858 L .64069 .75647 L F
.696 .719 .867 r
.35696 .75036 m .35814 .75167 L .36024 .7511 L F
0 0 0 r
.38337 .83094 m .38068 .83197 L .38193 .83075 L F
.512 .89 .966 r
.38517 .83023 m .38337 .83094 L .38193 .83075 L F
.228 .221 .643 r
.37273 .73901 m .37179 .74122 L .37158 .73797 L F
.543 .583 .845 r
.37379 .74102 m .37179 .74122 L .37273 .73901 L F
.559 .339 .537 r
.38713 .76163 m .38685 .76368 L .38494 .76392 L F
.49 .278 .519 r
.38874 .76316 m .38713 .76163 L .38896 .76117 L F
.38874 .76316 m .38685 .76368 L .38713 .76163 L F
.617 .33 .459 r
.41057 .8454 m .41047 .84785 L .40729 .84678 L F
.515 .247 .446 r
.41265 .84697 m .41047 .84785 L .41057 .8454 L F
.686 .786 .926 r
.6332 .75791 m .63529 .75898 L .63436 .75749 L F
.878 .494 .306 r
.6332 .75791 m .63411 .76037 L .63529 .75898 L F
.126 .119 .578 r
.63529 .75898 m .6362 .75506 L .63436 .75749 L F
.63529 .75898 m .63663 .75794 L .6362 .75506 L F
.646 .438 .587 r
.63411 .76037 m .63663 .75794 L .63529 .75898 L F
.482 .221 .442 r
.38448 .76574 m .38202 .7691 L .38324 .76526 L F
.117 0 0 r
.37183 .8327 m .37496 .83272 L .37313 .83401 L F
.461 .152 .355 r
.58935 .84461 m .59088 .8467 L .58855 .84698 L F
.58935 .84461 m .59139 .84419 L .59088 .8467 L F
.452 .107 .289 r
.36607 .76432 m .36331 .7663 L .36567 .76638 L F
.468 .233 .474 r
.36795 .76382 m .36607 .76432 L .36567 .76638 L F
.794 .719 .781 r
.51991 .81353 m .52068 .81483 L .52299 .81336 L F
.9 .737 .67 r
.51991 .81353 m .52103 .81608 L .52068 .81483 L F
0 0 0 r
.52299 .81336 m .52103 .81608 L .51991 .81353 L F
.378 0 .189 r
.52513 .81308 m .5221 .81549 L .52299 .81336 L F
.705 .622 .762 r
.62224 .74841 m .62334 .75142 L .62012 .75081 L F
.663 .534 .698 r
.63302 .75906 m .63126 .76207 L .63129 .75963 L F
.765 .272 .05 r
.54675 .8263 m .54907 .82707 L .54902 .82723 L F
.609 .864 .991 r
.40788 .88143 m .40457 .88147 L .40652 .88095 L F
.513 .85 .996 r
.40986 .88097 m .40788 .88143 L .40652 .88095 L F
.706 .58 .711 r
.62546 .76379 m .62388 .76494 L .625 .76285 L F
.561 .767 .975 r
.36953 .73482 m .37066 .7358 L .36754 .73528 L F
.643 .796 .956 r
.37281 .73525 m .37066 .7358 L .36953 .73482 L F
.738 .256 0 r
.37129 .73726 m .37066 .7358 L .36953 .73482 L F
0 .067 .62 r
.37066 .7358 m .37217 .73807 L .37158 .73797 L F
.738 .256 0 r
.37129 .73726 m .37217 .73807 L .37066 .7358 L F
.566 .327 .512 r
.37281 .73525 m .37217 .73807 L .37066 .7358 L F
.524 .239 .423 r
.51057 .83613 m .50833 .83657 L .50887 .83492 L F
.50887 .83492 m .50833 .83657 L .51057 .83613 L F
.264 0 0 r
.42733 .82442 m .42908 .82469 L .43049 .82398 L F
.278 0 0 r
.42908 .82469 m .43257 .82385 L .43049 .82398 L F
.688 .457 .567 r
.5156 .86805 m .51395 .86623 L .51272 .86836 L F
.626 .892 .987 r
.40482 .89697 m .40609 .89747 L .40799 .89672 L F
.388 .848 .819 r
.49168 .87744 m .48866 .87835 L .49064 .8777 L F
0 0 0 r
.49097 .87762 m .49168 .87744 L .49064 .8777 L F
.754 .238 0 r
.49168 .87744 m .49287 .87773 L .49239 .87725 L F
.463 .855 .976 r
.49482 .87726 m .49168 .87744 L .4936 .8767 L F
0 0 0 r
.49272 .8772 m .49168 .87744 L .49097 .87762 L F
.754 .238 0 r
.49168 .87744 m .49239 .87725 L .49114 .87597 L F
.525 .282 .488 r
.62877 .77643 m .6283 .77955 L .62608 .7798 L F
.506 .25 .46 r
.6307 .77617 m .6283 .77955 L .62877 .77643 L F
.231 0 0 r
.35696 .75036 m .35362 .74997 L .35495 .75094 L F
.241 0 .003 r
.43461 .84097 m .4339 .83993 L .4361 .83972 L F
.43461 .84097 m .43266 .84159 L .4339 .83993 L F
0 0 .519 r
.56335 .83377 m .56293 .83415 L .56417 .83627 L F
.759 .633 .721 r
.62743 .74819 m .62433 .74583 L .62643 .74512 L F
.62743 .74819 m .62558 .74887 L .62433 .74583 L F
.685 .637 .796 r
.62969 .74582 m .62743 .74819 L .62643 .74512 L F
.482 .52 .82 r
.38167 .75073 m .37874 .74828 L .38065 .74793 L F
.807 .641 .676 r
.58167 .77438 m .58537 .77704 L .58423 .77416 L F
.58167 .77438 m .58208 .77716 L .58537 .77704 L F
.684 .621 .78 r
.58423 .77416 m .58537 .77704 L .58712 .77467 L F
.671 .602 .77 r
.58537 .77704 m .58842 .77775 L .58712 .77467 L F
.758 .28 0 r
.52156 .81751 m .52273 .81847 L .52103 .81608 L F
.52156 .81751 m .52103 .81608 L .5221 .81549 L F
.413 .142 .39 r
.6489 .75861 m .65096 .75777 L .65148 .75594 L F
.736 .666 .781 r
.65166 .75475 m .65148 .75594 L .65319 .7536 L F
.393 .211 .511 r
.65148 .75594 m .653 .7557 L .65319 .7536 L F
0 0 .192 r
.65148 .75594 m .65239 .75691 L .653 .7557 L F
.65148 .75594 m .65096 .75777 L .65239 .75691 L F
.577 .352 .537 r
.62385 .77986 m .62383 .78201 L .62158 .78222 L F
.465 .197 .422 r
.62608 .7798 m .62383 .78201 L .62385 .77986 L F
0 0 0 r
.44189 .87618 m .4389 .87678 L .44063 .87649 L F
.176 .704 .691 r
.44388 .87568 m .44189 .87618 L .44063 .87649 L F
.781 .552 .589 r
.67548 .74554 m .67784 .74592 L .67689 .7438 L F
.552 .887 .987 r
.38788 .90178 m .38856 .90079 L .38657 .90141 L F
.38788 .90178 m .38984 .90115 L .38856 .90079 L F
.538 .23 .394 r
.63833 .77088 m .63756 .7737 L .63535 .77385 L F
.511 .206 .385 r
.64092 .77085 m .63756 .7737 L .63833 .77088 L F
.194 0 0 r
.39732 .82867 m .39632 .82839 L .3953 .8289 L F
.39732 .82867 m .39823 .8283 L .39632 .82839 L F
.631 .748 .932 r
.54108 .8263 m .53969 .82697 L .53762 .82519 L F
.326 .045 .325 r
.53907 .8288 m .53969 .82697 L .54108 .8263 L F
.74 .724 .836 r
.39064 .88104 m .39187 .88328 L .38842 .88318 L F
.76 .635 .723 r
.39187 .88328 m .38979 .88633 L .38842 .88318 L F
.635 .677 .873 r
.39442 .8824 m .39187 .88328 L .39064 .88104 L F
.711 .659 .797 r
.61357 .7477 m .61478 .74936 L .61163 .7487 L F
.666 .646 .82 r
.61697 .74866 m .61478 .74936 L .61357 .7477 L F
.068 0 0 r
.47157 .88241 m .4727 .88227 L .47497 .88229 L F
0 0 .028 r
.50209 .82334 m .501 .82397 L .50314 .82157 L F
.237 .129 .522 r
.50209 .82334 m .50111 .8262 L .501 .82397 L F
.542 .124 .198 r
.46108 .82038 m .46323 .82057 L .46454 .81887 L F
.53 .11 .19 r
.46454 .81887 m .46623 .82002 L .46665 .81862 L F
.46454 .81887 m .46323 .82057 L .46623 .82002 L F
.56 .411 .635 r
.49896 .82688 m .49658 .82916 L .49565 .82599 L F
.49896 .82688 m .49865 .82884 L .49658 .82916 L F
.921 .966 .782 r
.49367 .81103 m .49318 .81356 L .49534 .8119 L F
.49367 .81103 m .49238 .81337 L .49318 .81356 L F
0 0 0 r
.57198 .82074 m .57284 .81886 L .57429 .81795 L F
.733 .639 .755 r
.63835 .75292 m .64036 .7539 L .6384 .75069 L F
.914 .848 .765 r
.64035 .75399 m .64193 .75352 L .64075 .7533 L F
.6403 .75408 m .64017 .75498 L .64035 .754 L F
.63937 .75564 m .63988 .75522 L .6403 .75406 L F
.738 .566 .66 r
.64029 .75409 m .63937 .75564 L .6406 .75402 L F
.6362 .75506 m .63937 .75564 L .64029 .75409 L F
.914 .848 .765 r
.6403 .75406 m .6403 .75408 L .64035 .75399 L F
.6403 .75408 m .64035 .754 L .64035 .75399 L F
.63988 .75522 m .64017 .75498 L .6403 .75406 L F
.738 .566 .66 r
.6362 .75506 m .64029 .75409 L .63835 .75292 L F
.914 .848 .765 r
.64017 .75498 m .64193 .75352 L .64035 .75399 L F
.738 .566 .66 r
.64029 .75409 m .6406 .75402 L .6403 .75406 L F
.743 .574 .664 r
.6406 .75402 m .63937 .75564 L .6403 .75406 L F
.6406 .75402 m .6403 .75406 L .64075 .7533 L F
.738 .566 .66 r
.6403 .75406 m .6406 .75402 L .64036 .7539 L F
.64029 .75409 m .64036 .7539 L .63835 .75292 L F
.733 .639 .755 r
.64036 .7539 m .6406 .75402 L .6404 .75371 L F
.64036 .7539 m .6404 .75371 L .6384 .75069 L F
.82 .893 .895 r
.64361 .75052 m .64193 .75352 L .64495 .75179 L F
.64361 .75052 m .64075 .7533 L .64193 .75352 L F
.435 0 0 r
.48311 .88613 m .48432 .88662 L .48685 .88809 L F
.521 .909 .934 r
.41519 .89522 m .41886 .89457 L .41731 .89597 L F
0 0 0 r
.4196 .89411 m .41886 .89457 L .42076 .894 L F
.4196 .89411 m .41731 .89597 L .41886 .89457 L F
.433 .862 .937 r
.56333 .77583 m .56241 .7758 L .56047 .77666 L F
.56333 .77583 m .56241 .7758 L .56047 .77666 L F
.549 .379 .604 r
.36806 .76156 m .37009 .76124 L .37007 .75887 L F
.513 .323 .561 r
.36806 .76156 m .36981 .76344 L .37009 .76124 L F
.36806 .76156 m .36795 .76382 L .36981 .76344 L F
.708 .449 .531 r
.49482 .81848 m .49639 .82099 L .49602 .81797 L F
.763 .565 .63 r
.58858 .78211 m .59186 .78243 L .59194 .77979 L F
.692 .615 .765 r
.59063 .77706 m .59194 .77979 L .59395 .77966 L F
.682 .497 .63 r
.59194 .77979 m .59186 .78243 L .59395 .77966 L F
.595 .368 .542 r
.51412 .82678 m .5146 .82866 L .51664 .82787 L F
.405 .117 .358 r
.52171 .80821 m .52294 .81003 L .52379 .80765 L F
.52171 .80821 m .52134 .81044 L .52294 .81003 L F
.715 .501 .599 r
.52273 .81847 m .52644 .81852 L .52622 .81615 L F
.531 .564 .834 r
.36286 .73221 m .3624 .73539 L .36129 .73163 L F
.7 .571 .706 r
.36339 .73066 m .36307 .7349 L .36665 .73058 L F
.531 .564 .834 r
.36286 .73221 m .36411 .73506 L .3624 .73539 L F
.645 .622 .812 r
.37709 .74312 m .37515 .74389 L .37379 .74102 L F
.085 0 0 r
.51407 .83733 m .5116 .83906 L .51348 .8372 L F
.779 .547 .585 r
.58845 .80578 m .58564 .80789 L .58803 .80555 L F
.58845 .80578 m .58878 .80822 L .58564 .80789 L F
.216 .054 .434 r
.58845 .80578 m .58989 .80333 L .59033 .80423 L F
.706 .983 .891 r
.59033 .80423 m .58845 .80578 L .58803 .80555 L F
.896 .495 .241 r
.54986 .79774 m .54963 .79969 L .54886 .79677 L F
.54986 .79774 m .55102 .80038 L .54963 .79969 L F
.593 .619 .848 r
.59247 .80472 m .59219 .80827 L .59064 .8049 L F
.59247 .80472 m .59436 .80796 L .59219 .80827 L F
.77 .691 .775 r
.59637 .80535 m .59436 .80796 L .59247 .80472 L F
.727 .58 .689 r
.59198 .80684 m .59455 .80451 L .59247 .80472 L F
.59455 .80451 m .59477 .80431 L .59247 .80472 L F
.593 .619 .848 r
.59247 .80472 m .59064 .8049 L .59033 .80423 L F
.563 .453 .687 r
.59436 .80796 m .59242 .81133 L .59219 .80827 L F
.698 .628 .775 r
.62012 .75081 m .61697 .74866 L .619 .74745 L F
.687 .594 .746 r
.62224 .74841 m .62012 .75081 L .619 .74745 L F
.821 .342 .03 r
.55205 .80101 m .55209 .80225 L .55102 .80038 L F
.55205 .80101 m .55366 .80296 L .55209 .80225 L F
.615 .517 .721 r
.39667 .85756 m .39364 .85464 L .39614 .8542 L F
.39667 .85756 m .39474 .85823 L .39364 .85464 L F
.47 .894 .864 r
.41824 .88055 m .41535 .8815 L .41737 .88102 L F
.056 0 0 r
.41824 .88055 m .41949 .88054 L .42031 .87936 L F
.03 0 0 r
.41824 .88055 m .41737 .88102 L .41949 .88054 L F
.993 .868 .534 r
.56393 .83874 m .56485 .83944 L .56421 .84173 L F
.799 .572 .594 r
.54303 .82136 m .54005 .82319 L .54218 .82061 L F
.54303 .82136 m .54334 .82328 L .54005 .82319 L F
.697 .595 .737 r
.57919 .78712 m .58031 .79024 L .58256 .78791 L F
.618 .839 .984 r
.50527 .84935 m .50715 .85014 L .50421 .85023 L F
.777 .561 .606 r
.50715 .85014 m .50344 .85203 L .50421 .85023 L F
.50715 .85014 m .50664 .8521 L .50344 .85203 L F
.917 .719 .62 r
.50527 .84935 m .50664 .8521 L .50715 .85014 L F
.886 .46 .162 r
.54717 .79376 m .54705 .79537 L .54588 .79302 L F
.54717 .79376 m .54886 .79677 L .54705 .79537 L F
.765 .733 .823 r
.49456 .84495 m .49144 .84491 L .49398 .84364 L F
.877 .693 .649 r
.49236 .84591 m .49409 .844 L .49398 .84364 L F
.488 .536 .832 r
.49518 .84279 m .49456 .84495 L .49278 .84084 L F
.877 .693 .649 r
.49409 .844 m .49518 .84279 L .49398 .84364 L F
.694 .341 0 r
.49278 .84084 m .49393 .8435 L .49398 .84364 L F
.49393 .8435 m .49456 .84495 L .49398 .84364 L F
.937 .763 .641 r
.49518 .84279 m .49542 .84662 L .49456 .84495 L F
0 0 .514 r
.49542 .84662 m .49545 .84752 L .49456 .84495 L F
.862 .623 .576 r
.38284 .82543 m .38529 .8269 L .38458 .82873 L F
.771 .264 0 r
.38328 .82611 m .38529 .8269 L .38284 .82543 L F
.38366 .82639 m .38529 .8269 L .38328 .82611 L F
.604 .89 .99 r
.38673 .82613 m .38529 .8269 L .38395 .82648 L F
.38673 .82613 m .38395 .82648 L .3842 .82635 L F
.38673 .82613 m .38366 .82639 L .38392 .82629 L F
.25 0 .302 r
.38458 .82873 m .38529 .8269 L .38673 .82613 L F
.604 .89 .99 r
.38673 .82613 m .38342 .82632 L .38536 .82552 L F
.25 0 .302 r
.38458 .82873 m .38673 .82613 L .38687 .82871 L F
.485 .343 .613 r
.38863 .82826 m .38687 .82871 L .38673 .82613 L F
.54 .57 .834 r
.3855 .82564 m .38687 .82871 L .38863 .82826 L F
.38536 .82552 m .38543 .82567 L .3855 .82564 L F
.38543 .82567 m .38687 .82871 L .3855 .82564 L F
.604 .89 .99 r
.3842 .82635 m .38395 .82648 L .38366 .82639 L F
.38392 .82629 m .38366 .82639 L .38342 .82632 L F
.61 .607 .823 r
.38492 .82734 m .38687 .82871 L .38543 .82567 L F
.38531 .82572 m .38543 .82567 L .38536 .82552 L F
.38492 .82734 m .38543 .82567 L .38531 .82572 L F
.38458 .82873 m .38674 .82871 L .38492 .82734 L F
.38674 .82871 m .38687 .82871 L .38492 .82734 L F
.771 .264 0 r
.38342 .82632 m .38366 .82639 L .38328 .82611 L F
.631 .209 0 r
.55714 .80822 m .558 .80971 L .55604 .8076 L F
.55714 .80822 m .55857 .81056 L .558 .80971 L F
.704 .659 .802 r
.63715 .74313 m .63816 .74596 L .63502 .74576 L F
.719 .667 .798 r
.64045 .74352 m .63816 .74596 L .63715 .74313 L F
0 0 .455 r
.56243 .82367 m .56354 .8266 L .56405 .82691 L F
0 0 .504 r
.56405 .82691 m .56354 .8266 L .5643 .82765 L F
.04 0 .014 r
.58077 .77762 m .57907 .77788 L .58208 .77716 L F
.424 .45 .783 r
.59785 .80264 m .59697 .80338 L .5956 .79994 L F
.031 0 .244 r
.59637 .80535 m .59697 .80338 L .59785 .80264 L F
.378 .183 .485 r
.50167 .85248 m .50138 .85518 L .49975 .85525 L F
.273 0 .025 r
.49975 .85525 m .50138 .85518 L .49916 .85572 L F
.931 .738 .62 r
.5015 .82084 m .50209 .82334 L .50314 .82157 L F
.612 .31 .434 r
.50314 .82157 m .50491 .82329 L .50209 .82334 L F
.559 .317 .505 r
.50526 .82122 m .50491 .82329 L .50314 .82157 L F
.493 .203 .401 r
.57678 .77757 m .57682 .77916 L .57471 .7795 L F
.581 .058 0 r
.57022 .84733 m .57342 .84769 L .57253 .8486 L F
.537 .009 0 r
.57253 .8486 m .57342 .84769 L .57571 .84873 L F
.756 .683 .781 r
.64661 .73772 m .64783 .74083 L .64445 .74048 L F
.329 .778 .956 r
.64778 .74257 m .64445 .74048 L .64783 .74083 L F
.625 .532 .729 r
.64963 .73803 m .64783 .74083 L .64661 .73772 L F
.64963 .73803 m .65003 .74099 L .64783 .74083 L F
.541 .33 .542 r
.64995 .74205 m .64783 .74083 L .65003 .74099 L F
.64995 .74205 m .64778 .74257 L .64783 .74083 L F
.732 .545 .639 r
.59527 .79781 m .5956 .79994 L .59268 .79945 L F
.407 .036 .217 r
.59527 .79781 m .59268 .79945 L .59412 .79945 L F
.477 .847 .989 r
.59619 .79684 m .5975 .79737 L .59527 .79781 L F
0 0 0 r
.59619 .79684 m .59527 .79781 L .59412 .79945 L F
.538 .379 .613 r
.5975 .79737 m .5956 .79994 L .59527 .79781 L F
.537 .297 .498 r
.42019 .84214 m .41794 .84447 L .41796 .84213 L F
.557 .327 .523 r
.38201 .86292 m .38186 .86531 L .3796 .86541 L F
.685 .436 .54 r
.3841 .86505 m .38186 .86531 L .38201 .86292 L F
.592 .562 .79 r
.39378 .74605 m .39625 .74549 L .3942 .74583 L F
.39378 .74605 m .39771 .74619 L .39625 .74549 L F
.7 .547 .676 r
.57945 .78511 m .58241 .78579 L .58302 .78508 L F
.525 .574 .847 r
.64561 .74552 m .64571 .74642 L .64241 .74295 L F
.87 .704 .674 r
.64561 .74552 m .64539 .74844 L .64712 .7486 L F
.775 .536 .574 r
.64361 .75052 m .64682 .75085 L .64712 .7486 L F
0 0 0 r
.64712 .7486 m .64715 .74861 L .64959 .74672 L F
.576 .234 .352 r
.38753 .86336 m .38915 .86478 L .38699 .86487 L F
.517 .248 .446 r
.3896 .86291 m .38915 .86478 L .38753 .86336 L F
.519 .293 .512 r
.36383 .77972 m .36353 .78183 L .36154 .78225 L F
.493 .218 .425 r
.36607 .77961 m .36353 .78183 L .36383 .77972 L F
.341 .819 .787 r
.44587 .88793 m .44968 .88682 L .44792 .88747 L F
.36 .82 .721 r
.44792 .88747 m .44968 .88682 L .45145 .886 L F
.563 .453 .687 r
.59436 .80796 m .59487 .81071 L .59242 .81133 L F
.633 .453 .622 r
.59487 .81071 m .59194 .81325 L .59242 .81133 L F
.261 .67 .967 r
.43094 .89086 m .43179 .89022 L .43016 .89101 L F
.43094 .89086 m .43384 .89148 L .43179 .89022 L F
.512 .303 .533 r
.3864 .76535 m .38494 .76392 L .38685 .76368 L F
.3864 .76535 m .38448 .76574 L .38494 .76392 L F
.692 .615 .765 r
.59063 .77706 m .59395 .77966 L .5927 .77649 L F
.693 .512 .638 r
.59395 .77966 m .59186 .78243 L .59416 .78199 L F
.731 .643 .761 r
.5927 .77649 m .59395 .77966 L .59598 .777 L F
.617 .48 .673 r
.59395 .77966 m .59633 .77944 L .59598 .777 L F
.591 .423 .622 r
.59416 .78199 m .59633 .77944 L .59395 .77966 L F
.688 .457 .567 r
.5156 .86805 m .51595 .86529 L .51395 .86623 L F
.963 .715 .275 r
.56054 .81319 m .5612 .81623 L .56065 .81529 L F
0 0 .393 r
.56065 .81529 m .5612 .81623 L .56255 .81838 L F
.258 0 .119 r
.52265 .87567 m .52531 .87373 L .52463 .87524 L F
.261 0 .216 r
.52463 .87524 m .52531 .87373 L .52705 .87304 L F
.452 .144 .352 r
.36986 .77874 m .36861 .77709 L .37042 .77727 L F
.36986 .77874 m .36789 .77911 L .36861 .77709 L F
.079 .085 .562 r
.49785 .83676 m .49909 .83646 L .49874 .8334 L F
.452 .14 .345 r
.50101 .8367 m .49829 .83906 L .49785 .83676 L F
.639 .347 .46 r
.49667 .83764 m .49909 .83646 L .49785 .83676 L F
.826 .954 .899 r
.59426 .75844 m .59199 .75925 L .59342 .75798 L F
.751 .963 .935 r
.59426 .75844 m .59703 .75564 L .59797 .75624 L F
.59426 .75844 m .59342 .75798 L .59703 .75564 L F
.674 .604 .769 r
.58712 .77467 m .58842 .77775 L .59063 .77706 L F
.31 .4 .793 r
.57036 .82508 m .57172 .82851 L .56916 .8263 L F
.868 .661 .62 r
.4945 .83174 m .49268 .83391 L .4944 .83411 L F
.375 .016 .221 r
.49632 .83303 m .4945 .83174 L .49654 .83191 L F
.49632 .83303 m .49268 .83391 L .4945 .83174 L F
.81 .891 .902 r
.60222 .75413 m .59867 .75553 L .60119 .75355 L F
.804 .911 .913 r
.60222 .75413 m .60274 .75228 L .60386 .753 L F
.60222 .75413 m .60119 .75355 L .60274 .75228 L F
.69 .687 .842 r
.38504 .75525 m .38576 .75648 L .3827 .75593 L F
.518 .512 .789 r
.38652 .75311 m .38576 .75648 L .38504 .75525 L F
.38652 .75311 m .38732 .75608 L .38576 .75648 L F
.537 .375 .61 r
.39667 .85756 m .39471 .8602 L .39474 .85823 L F
.228 .221 .643 r
.37273 .73901 m .37158 .73797 L .37217 .73807 L F
.602 .574 .794 r
.52035 .82379 m .52092 .82078 L .5187 .82142 L F
.52035 .82379 m .52265 .82434 L .52092 .82078 L F
.634 .559 .752 r
.59296 .78746 m .59501 .78524 L .59262 .78574 L F
.59296 .78746 m .59552 .78732 L .59501 .78524 L F
.582 .455 .672 r
.59296 .78746 m .59526 .78909 L .59552 .78732 L F
.59296 .78746 m .59335 .7896 L .59526 .78909 L F
.802 .707 .76 r
.53397 .82895 m .53495 .8317 L .53229 .83087 L F
.693 .17 0 r
.53229 .83087 m .53495 .8317 L .53428 .83245 L F
.657 .631 .812 r
.53686 .83054 m .53495 .8317 L .53397 .82895 L F
0 0 0 r
.53428 .83245 m .53495 .8317 L .53686 .83054 L F
.9 .693 .613 r
.57781 .78426 m .57945 .78511 L .57808 .78209 L F
.57781 .78426 m .57945 .78511 L .57808 .78209 L F
.887 .724 .673 r
.57781 .78426 m .57919 .78712 L .57945 .78511 L F
.7 .547 .676 r
.57945 .78511 m .57919 .78712 L .58241 .78579 L F
.771 .336 .218 r
.46823 .83381 m .46694 .83489 L .46735 .83352 L F
.46823 .83381 m .46979 .83582 L .46694 .83489 L F
.698 .347 .378 r
.46997 .83449 m .46979 .83582 L .46823 .83381 L F
.559 .484 .728 r
.38436 .88629 m .38645 .88635 L .38446 .88673 L F
.696 .719 .867 r
.35696 .75036 m .36024 .7511 L .359 .75007 L F
.546 .775 .983 r
.36024 .7511 m .36087 .74979 L .359 .75007 L F
.36024 .7511 m .36223 .75074 L .36087 .74979 L F
.541 .573 .836 r
.38578 .88391 m .38436 .88629 L .3832 .88465 L F
.38578 .88391 m .38645 .88635 L .38436 .88629 L F
.867 .536 .423 r
.49337 .81662 m .49312 .81817 L .49482 .81848 L F
.595 .481 .694 r
.59262 .78574 m .59416 .78199 L .59186 .78243 L F
.59262 .78574 m .59501 .78524 L .59416 .78199 L F
.731 .825 .923 r
.57591 .78702 m .57722 .78791 L .57919 .78712 L F
.589 .189 .252 r
.47317 .83439 m .46979 .83582 L .46997 .83449 L F
.47317 .83439 m .472 .83613 L .46979 .83582 L F
.701 .32 .323 r
.47522 .8363 m .472 .83613 L .47317 .83439 L F
.453 0 .048 r
.4486 .8347 m .44734 .83604 L .44548 .83603 L F
.621 .173 .166 r
.4486 .8347 m .45076 .83633 L .44734 .83604 L F
.582 .215 .311 r
.4514 .83443 m .45076 .83633 L .4486 .8347 L F
0 0 0 r
.56967 .83351 m .56898 .83431 L .57036 .83195 L F
0 0 .166 r
.57036 .83195 m .57172 .82851 L .57155 .83121 L F
0 0 0 r
.56967 .83351 m .57036 .83195 L .57155 .83121 L F
0 .144 .673 r
.57322 .81621 m .57253 .81572 L .57166 .81309 L F
.955 .683 .481 r
.38842 .88318 m .38979 .88633 L .38847 .88578 L F
.714 .827 .935 r
.38979 .88633 m .38645 .88635 L .38847 .88578 L F
.718 .961 .943 r
.57476 .76933 m .5772 .76872 L .57599 .76989 L F
.506 .314 .554 r
.37007 .75887 m .37194 .75849 L .37211 .75622 L F
.523 .359 .6 r
.37007 .75887 m .37191 .76074 L .37194 .75849 L F
.37007 .75887 m .37009 .76124 L .37191 .76074 L F
.86 .719 .705 r
.49075 .83646 m .48584 .8383 L .48766 .83674 L F
.49075 .83646 m .48751 .839 L .48584 .8383 L F
.858 .714 .702 r
.49008 .83909 m .49075 .83646 L .49043 .8375 L F
.473 .798 .999 r
.49367 .81103 m .49534 .8119 L .49714 .81148 L F
.872 .854 .822 r
.49367 .81103 m .49238 .81337 L .49534 .8119 L F
.144 .048 .478 r
.3834 .87577 m .3834 .87809 L .38264 .87849 L F
0 0 .05 r
.38264 .87849 m .3834 .87809 L .38205 .87979 L F
.415 .047 .228 r
.64803 .76669 m .64722 .76867 L .64509 .76904 L F
.397 .019 .2 r
.65019 .76634 m .64722 .76867 L .64803 .76669 L F
0 0 0 r
.51198 .88016 m .51533 .87844 L .51398 .87948 L F
.51644 .87825 m .51533 .87844 L .51739 .87767 L F
.51398 .87948 m .51533 .87844 L .51644 .87825 L F
.779 .827 .89 r
.56828 .77671 m .57152 .7764 L .5704 .77572 L F
.131 .672 .835 r
.57415 .77585 m .5704 .77572 L .57152 .7764 L F
.371 .828 .735 r
.51096 .87309 m .50913 .87393 L .5075 .8745 L F
.288 .427 .829 r
.67128 .74294 m .66972 .74374 L .66908 .74292 L F
.67128 .74294 m .67218 .74518 L .66972 .74374 L F
.616 .943 .748 r
.57874 .83951 m .57649 .84099 L .57823 .84069 L F
.472 .786 .999 r
.57823 .84069 m .57649 .84099 L .57582 .8403 L F
.636 .176 .143 r
.57712 .84166 m .57823 .84069 L .578 .84142 L F
.472 .786 .999 r
.57823 .84069 m .57582 .8403 L .57792 .84138 L F
.57823 .84069 m .57792 .84138 L .578 .84142 L F
.616 .943 .748 r
.57963 .83892 m .57874 .83951 L .57823 .84069 L F
0 0 0 r
.58076 .83842 m .58224 .8375 L .57963 .83892 L F
.58076 .83842 m .57963 .83892 L .57823 .84069 L F
.516 .288 .507 r
.66554 .7591 m .66527 .76119 L .66314 .76168 L F
.565 .348 .544 r
.66746 .75866 m .66527 .76119 L .66554 .7591 L F
.744 .657 .764 r
.63502 .74576 m .63168 .74336 L .63392 .74276 L F
.63502 .74576 m .63295 .74614 L .63168 .74336 L F
.734 .706 .824 r
.63715 .74313 m .63502 .74576 L .63392 .74276 L F
.624 .527 .724 r
.58795 .81427 m .59041 .81512 L .58933 .81008 L F
.455 .56 .873 r
.58795 .81427 m .59084 .81561 L .59041 .81512 L F
.653 .9 .982 r
.37917 .83146 m .38068 .83197 L .37753 .83235 L F
.694 .908 .971 r
.38193 .83075 m .38068 .83197 L .37917 .83146 L F
.733 .805 .909 r
.52325 .83294 m .52456 .83451 L .52115 .83396 L F
.82 .545 .522 r
.52115 .83396 m .52456 .83451 L .52436 .83653 L F
.8 .821 .868 r
.52672 .83212 m .52456 .83451 L .52325 .83294 L F
.586 .466 .683 r
.52672 .83212 m .52672 .83416 L .52456 .83451 L F
.539 .299 .5 r
.52456 .83451 m .52649 .83632 L .52436 .83653 L F
.52456 .83451 m .52672 .83416 L .52649 .83632 L F
.165 0 0 r
.407 .82699 m .40774 .82717 L .40915 .82628 L F
0 .47 .779 r
.40649 .82674 m .40818 .82728 L .40774 .82717 L F
.639 .238 .266 r
.40774 .82717 m .40984 .82781 L .41122 .82609 L F
0 .47 .779 r
.40818 .82728 m .40984 .82781 L .40774 .82717 L F
.165 0 0 r
.40564 .82744 m .40774 .82717 L .407 .82699 L F
.639 .238 .266 r
.40774 .82717 m .41122 .82609 L .40915 .82628 L F
.666 .798 .945 r
.64361 .75052 m .64495 .75179 L .64682 .75085 L F
.738 .703 .818 r
.36129 .73163 m .35982 .7307 L .36083 .73071 L F
0 .269 .774 r
.36184 .73074 m .36083 .73071 L .35982 .7307 L F
.36184 .73074 m .36286 .73221 L .36083 .73071 L F
.407 .336 .665 r
.36083 .73071 m .36286 .73221 L .36129 .73163 L F
.758 .907 .942 r
.60646 .75118 m .60386 .753 L .60274 .75228 L F
.657 .631 .812 r
.53686 .83054 m .53397 .82895 L .53704 .82908 L F
.502 .292 .527 r
.53686 .83054 m .53704 .82908 L .53907 .8288 L F
.706 .7 .842 r
.65867 .75379 m .65502 .75479 L .65554 .75326 L F
0 .075 .569 r
.48093 .88419 m .48219 .88522 L .47989 .88356 L F
.48093 .88419 m .48311 .88613 L .48219 .88522 L F
.531 .046 .051 r
.49581 .80937 m .49916 .80901 L .49711 .80856 L F
.268 .117 .483 r
.56943 .82041 m .56779 .82133 L .56851 .82152 L F
.039 .608 .745 r
.48626 .87858 m .48553 .87865 L .48471 .87898 L F
.48626 .87858 m .48764 .87862 L .48553 .87865 L F
.415 0 0 r
.48822 .88846 m .48986 .88921 L .48685 .88809 L F
.383 0 .04 r
.43988 .82333 m .44193 .82313 L .44329 .82169 L F
.568 .178 .262 r
.44193 .82313 m .44532 .82158 L .44329 .82169 L F
.55 .538 .794 r
.5095 .83883 m .51057 .83613 L .50833 .83657 L F
.5095 .83883 m .5116 .83906 L .51057 .83613 L F
.55 .381 .605 r
.61411 .79028 m .61448 .79165 L .61252 .79213 L F
.531 .326 .547 r
.61252 .79213 m .61495 .79455 L .61176 .79481 L F
.61252 .79213 m .61448 .79165 L .61495 .79455 L F
.723 .616 .738 r
.62433 .74583 m .62558 .74887 L .62224 .74841 L F
.601 .461 .663 r
.40144 .74548 m .39956 .74818 L .39969 .74585 L F
.40144 .74548 m .39956 .74818 L .39969 .74585 L F
.838 .611 .596 r
.39969 .74585 m .39956 .74818 L .39771 .74619 L F
.562 .386 .601 r
.37211 .75622 m .37416 .75589 L .37423 .75354 L F
.622 .447 .625 r
.37194 .75849 m .37416 .75589 L .37211 .75622 L F
.079 .062 .536 r
.45463 .87 m .45384 .87075 L .45352 .86803 L F
.658 .273 .305 r
.45463 .87 m .45352 .86803 L .45217 .86991 L F
.452 .14 .345 r
.50101 .8367 m .50021 .83914 L .49829 .83906 L F
.242 0 .255 r
.50204 .83823 m .50101 .8367 L .50274 .83816 L F
.50167 .83799 m .50101 .8367 L .50204 .83823 L F
.50167 .83799 m .50021 .83914 L .50101 .8367 L F
.5018 .83825 m .50054 .83896 L .50167 .83799 L F
.50054 .83896 m .50021 .83914 L .50167 .83799 L F
.664 .573 .743 r
.49913 .83637 m .50226 .83749 L .50071 .83313 L F
.50226 .83749 m .50332 .83787 L .50284 .837 L F
.50226 .83749 m .50284 .837 L .50071 .83313 L F
.49909 .83646 m .49946 .83658 L .49913 .83637 L F
.259 0 0 r
.5057 .837 m .50274 .83795 L .50274 .83816 L F
.50274 .83795 m .5018 .83825 L .50204 .83823 L F
.50274 .83795 m .50204 .83823 L .50274 .83816 L F
.664 .573 .743 r
.49946 .83658 m .50312 .8378 L .49913 .83637 L F
.259 0 0 r
.50274 .83795 m .50389 .83806 L .5018 .83825 L F
.734 .445 .489 r
.50329 .83786 m .5018 .83825 L .50332 .83787 L F
.242 0 .255 r
.5018 .83825 m .50167 .83799 L .50204 .83823 L F
.734 .445 .489 r
.49909 .83646 m .5018 .83825 L .50329 .83786 L F
.259 0 0 r
.5057 .837 m .50501 .8374 L .50274 .83795 L F
.50501 .8374 m .50462 .83763 L .50329 .83786 L F
.50501 .8374 m .50329 .83786 L .50274 .83795 L F
.664 .573 .743 r
.50329 .83786 m .50332 .83787 L .50329 .83786 L F
.259 0 0 r
.50462 .83763 m .50389 .83806 L .50274 .83795 L F
.664 .573 .743 r
.50312 .8378 m .50329 .83786 L .50312 .8378 L F
.50329 .83786 m .50329 .83786 L .50312 .8378 L F
.50312 .8378 m .50312 .8378 L .49913 .83637 L F
.64 .462 .626 r
.60594 .79778 m .60588 .79996 L .60376 .80038 L F
.991 .878 .55 r
.6062 .79555 m .60594 .79778 L .60528 .79733 L F
.954 .951 .699 r
.60528 .79733 m .60594 .79778 L .60422 .79928 L F
.642 .475 .643 r
.6082 .79765 m .60588 .79996 L .60594 .79778 L F
.202 .725 .718 r
.4535 .88574 m .45424 .88559 L .4563 .88507 L F
.044 0 0 r
.6489 .75861 m .64589 .76091 L .64789 .7602 L F
0 0 0 r
.64789 .7602 m .65096 .75777 L .6489 .75861 L F
.847 .665 .127 r
.56617 .77926 m .56629 .78187 L .56638 .78179 L F
.525 .09 .157 r
.57775 .84904 m .57879 .84746 L .58106 .84842 L F
.739 .742 .854 r
.36754 .73528 m .36411 .73506 L .36645 .73379 L F
.769 .656 .738 r
.36754 .73528 m .36537 .73813 L .36411 .73506 L F
.58 .682 .911 r
.36953 .73482 m .36754 .73528 L .36645 .73379 L F
.043 .165 .667 r
.57086 .83673 m .56898 .83431 L .56967 .83351 L F
.258 .396 .812 r
.58767 .80057 m .58989 .80333 L .59021 .80036 L F
.415 .268 .571 r
.66677 .75003 m .66656 .75145 L .66812 .7505 L F
.323 0 0 r
.66677 .75003 m .66812 .7505 L .66523 .74992 L F
.417 .266 .567 r
.66677 .75003 m .66812 .7505 L .66805 .74823 L F
.484 .248 .481 r
.36353 .78183 m .36123 .78444 L .36154 .78225 L F
.697 .595 .737 r
.57919 .78712 m .58256 .78791 L .58241 .78579 L F
.387 .846 .888 r
.42355 .89312 m .4265 .89246 L .42331 .89271 L F
.438 .872 .907 r
.42331 .89271 m .4265 .89246 L .42837 .89181 L F
.505 .28 .506 r
.6722 .75349 m .67191 .75548 L .66987 .75605 L F
.565 .386 .598 r
.67421 .751 m .67433 .7531 L .6722 .75349 L F
.448 .186 .423 r
.67433 .7531 m .67191 .75548 L .6722 .75349 L F
.575 .905 .663 r
.64959 .74672 m .64715 .74861 L .65098 .74547 L F
.655 .847 .974 r
.35559 .73119 m .35219 .73116 L .35437 .73022 L F
.491 .703 .964 r
.35614 .7296 m .35559 .73119 L .35437 .73022 L F
.35614 .7296 m .35771 .73103 L .35559 .73119 L F
.713 .653 .788 r
.53907 .8288 m .54035 .83202 L .53686 .83054 L F
.595 .589 .816 r
.54248 .8316 m .54035 .83202 L .53907 .8288 L F
.424 .837 .969 r
.53916 .83168 m .54035 .83202 L .54248 .8316 L F
.53916 .83168 m .54248 .8316 L .54152 .8329 L F
.53916 .83168 m .54152 .8329 L .54145 .83299 L F
.431 0 0 r
.53686 .83054 m .53745 .8308 L .53916 .83168 L F
.53745 .8308 m .54035 .83202 L .53916 .83168 L F
0 0 0 r
.48169 .87709 m .48064 .8776 L .48207 .87663 L F
.235 .39 .815 r
.48169 .87709 m .48203 .87893 L .48064 .8776 L F
.743 .715 .826 r
.61804 .74361 m .619 .74579 L .61574 .74542 L F
.767 .647 .728 r
.619 .74579 m .61697 .74866 L .61574 .74542 L F
.704 .556 .684 r
.619 .74745 m .61697 .74866 L .619 .74579 L F
.771 .728 .813 r
.62102 .74329 m .619 .74579 L .61804 .74361 L F
.65 .542 .719 r
.62084 .74504 m .619 .74579 L .62102 .74329 L F
.694 .584 .728 r
.62084 .74504 m .619 .74745 L .619 .74579 L F
.618 .492 .686 r
.41058 .84953 m .40729 .84678 L .41047 .84785 L F
.41058 .84953 m .4084 .84981 L .40729 .84678 L F
.57 .893 .987 r
.39875 .88316 m .39729 .8838 L .39587 .88342 L F
.721 .263 .163 r
.53167 .80506 m .5333 .80592 L .53464 .80559 L F
.389 0 0 r
.5357 .80635 m .53464 .80559 L .5333 .80592 L F
.5357 .80635 m .53783 .80679 L .53464 .80559 L F
.794 .838 .885 r
.61163 .7487 m .60801 .74987 L .61054 .74788 L F
.748 .865 .934 r
.61357 .7477 m .61163 .7487 L .61054 .74788 L F
.903 .917 .82 r
.65662 .74359 m .65457 .74623 L .65541 .74554 L F
.052 0 .108 r
.60116 .78738 m .6005 .7893 L .59891 .7899 L F
.543 .184 .309 r
.60256 .78901 m .60047 .78938 L .60116 .78738 L F
.669 .523 .677 r
.59935 .78632 m .60154 .78815 L .60247 .78689 L F
.543 .184 .309 r
.60256 .78901 m .60116 .78738 L .60314 .78643 L F
.669 .523 .677 r
.60154 .78815 m .60256 .78901 L .60248 .78711 L F
.60154 .78815 m .60248 .78711 L .60247 .78689 L F
.052 0 .108 r
.6005 .7893 m .60047 .78938 L .60041 .7894 L F
.6005 .7893 m .60041 .7894 L .59891 .7899 L F
.569 .437 .661 r
.60047 .78938 m .59832 .79198 L .59891 .7899 L F
.57 .326 .508 r
.62158 .78222 m .62345 .78385 L .62146 .78429 L F
.62158 .78222 m .62383 .78201 L .62345 .78385 L F
.532 .604 .871 r
.35117 .72906 m .35036 .7312 L .34905 .72972 L F
.35117 .72906 m .35219 .73116 L .35036 .7312 L F
.715 .187 0 r
.54675 .8263 m .54902 .82723 L .5496 .82793 L F
.842 .953 .887 r
.57811 .79511 m .57602 .79716 L .5748 .79673 L F
.453 .725 .984 r
.57847 .79733 m .57602 .79716 L .57811 .79511 L F
0 0 0 r
.45909 .88423 m .46217 .8831 L .46115 .88382 L F
.233 0 0 r
.46217 .8831 m .46318 .88352 L .46115 .88382 L F
.46217 .8831 m .46411 .88308 L .46318 .88352 L F
.541 .072 .091 r
.41122 .82609 m .41306 .82648 L .41481 .8257 L F
.591 .141 .15 r
.41481 .8257 m .41306 .82648 L .41651 .82629 L F
.463 0 .011 r
.6554 .76449 m .65686 .76581 L .65455 .76587 L F
.6554 .76449 m .65783 .76502 L .65686 .76581 L F
.58 .378 .572 r
.5622 .79748 m .56426 .79722 L .56216 .79523 L F
.573 .405 .616 r
.48731 .84784 m .48802 .84711 L .48856 .84683 L F
.992 .782 .405 r
.48912 .84656 m .48856 .84683 L .48884 .84484 L F
.269 .06 .4 r
.49015 .84427 m .48856 .84683 L .48884 .84484 L F
.387 .735 .991 r
.48699 .84376 m .48884 .84484 L .48611 .8446 L F
.633 .371 .503 r
.48884 .84484 m .48856 .84683 L .48611 .8446 L F
.521 .792 .995 r
.49015 .84427 m .48884 .84484 L .48699 .84376 L F
.759 .653 .745 r
.48699 .84376 m .48856 .84683 L .49015 .84427 L F
.573 .405 .616 r
.48802 .84711 m .48921 .84589 L .48856 .84683 L F
.992 .782 .405 r
.48924 .84728 m .48856 .84683 L .48912 .84656 L F
.967 .679 .263 r
.48924 .84728 m .48941 .84943 L .48856 .84683 L F
.923 .972 .766 r
.48924 .84728 m .49015 .84427 L .49144 .84491 L F
.48924 .84728 m .48856 .84683 L .49015 .84427 L F
.967 .679 .263 r
.48924 .84728 m .48941 .84943 L .48856 .84683 L F
0 0 0 r
.48986 .88921 m .49303 .88855 L .4921 .88909 L F
.109 0 0 r
.4921 .88909 m .49303 .88855 L .49501 .88821 L F
.891 .917 .835 r
.56998 .79734 m .57316 .79551 L .57161 .79505 L F
.56998 .79734 m .57089 .79791 L .57316 .79551 L F
0 .092 .622 r
.57368 .79488 m .57316 .79551 L .57249 .79327 L F
.495 .874 .975 r
.57161 .79505 m .57316 .79551 L .57368 .79488 L F
.554 .289 .468 r
.59228 .80207 m .59021 .80036 L .58989 .80333 L F
.59228 .80207 m .59268 .79945 L .59021 .80036 L F
.733 .631 .745 r
.60974 .77731 m .6099 .77997 L .60772 .77982 L F
.737 .598 .702 r
.6099 .77997 m .60787 .78213 L .60772 .77982 L F
.506 .266 .485 r
.6099 .77997 m .60999 .7818 L .60787 .78213 L F
.69 .598 .748 r
.61202 .77684 m .6099 .77997 L .60974 .77731 L F
.597 .533 .753 r
.59561 .79046 m .59619 .79232 L .59403 .79268 L F
.572 .419 .635 r
.3942 .74583 m .39625 .74549 L .39683 .74385 L F
.646 .576 .762 r
.50396 .82867 m .50199 .82947 L .50111 .8262 L F
.476 .114 .271 r
.45268 .83592 m .4514 .83443 L .45404 .83418 L F
.45268 .83592 m .45076 .83633 L .4514 .83443 L F
.731 .825 .923 r
.57591 .78702 m .57919 .78712 L .57781 .78426 L F
.757 .459 .48 r
.49298 .82056 m .49482 .81848 L .49312 .81817 L F
.49298 .82056 m .49639 .82099 L .49482 .81848 L F
.745 .916 .95 r
.58533 .76432 m .58169 .76529 L .58424 .76364 L F
.819 .904 .9 r
.58755 .76233 m .58533 .76432 L .58424 .76364 L F
.42 .831 .973 r
.45781 .8759 m .45448 .87591 L .45656 .87551 L F
.7 .982 .886 r
.4595 .87458 m .45781 .8759 L .45849 .87473 L F
.631 .913 .981 r
.45849 .87473 m .45781 .8759 L .45656 .87551 L F
.41 .825 .972 r
.50167 .85248 m .50202 .84909 L .50421 .85023 L F
.343 .053 .319 r
.50344 .85203 m .50167 .85248 L .50421 .85023 L F
.41 .825 .972 r
.50167 .85248 m .50344 .85203 L .50202 .84909 L F
.50167 .85248 m .50011 .85198 L .50344 .85203 L F
.442 .236 .504 r
.50302 .85412 m .50167 .85248 L .50344 .85203 L F
.50302 .85412 m .50138 .85518 L .50167 .85248 L F
.569 .914 .968 r
.39904 .89829 m .40015 .89847 L .40275 .89762 L F
.387 .846 .888 r
.42355 .89312 m .42331 .89271 L .42232 .89321 L F
.72 .464 .539 r
.49592 .83944 m .49558 .84162 L .49278 .84084 L F
.506 .236 .438 r
.49829 .83906 m .49558 .84162 L .49592 .83944 L F
.608 .32 .454 r
.66527 .76119 m .66272 .76285 L .66314 .76168 L F
.566 .579 .826 r
.67649 .74973 m .67421 .751 L .67315 .74853 L F
.502 .374 .638 r
.67649 .74973 m .67433 .7531 L .67421 .751 L F
.338 0 .103 r
.51447 .87213 m .51411 .8723 L .51609 .87244 L F
.564 .374 .582 r
.51609 .87244 m .51839 .87225 L .51447 .87213 L F
.51609 .87244 m .51839 .87225 L .51447 .87213 L F
.472 .267 .519 r
.36517 .72498 m .36506 .72745 L .36309 .72761 L F
.694 .657 .809 r
.36339 .73066 m .36506 .72745 L .36309 .72761 L F
.281 .72 .965 r
.45245 .87627 m .44919 .87567 L .45125 .87559 L F
.497 .813 1 r
.45448 .87591 m .45245 .87627 L .45125 .87559 L F
.57 .033 0 r
.51029 .81871 m .51099 .8196 L .50939 .81857 L F
.51029 .81871 m .51231 .8206 L .51099 .8196 L F
.581 .357 .54 r
.51248 .81844 m .51231 .8206 L .51029 .81871 L F
.634 .598 .795 r
.37082 .751 m .37423 .75354 L .37271 .75077 L F
.509 .549 .833 r
.37423 .75354 m .37463 .75049 L .37271 .75077 L F
.37423 .75354 m .37595 .75324 L .37463 .75049 L F
.541 .369 .597 r
.37423 .75354 m .37614 .7555 L .37595 .75324 L F
.37423 .75354 m .37416 .75589 L .37614 .7555 L F
.621 .273 .36 r
.51305 .87463 m .51411 .8723 L .51096 .87309 L F
.481 .025 .09 r
.51482 .87388 m .51411 .8723 L .51305 .87463 L F
.51482 .87388 m .51609 .87244 L .51411 .8723 L F
.625 .826 .978 r
.40457 .88147 m .40241 .88195 L .40115 .88128 L F
.738 .703 .818 r
.36129 .73163 m .35888 .73302 L .35771 .73103 L F
.308 .507 .888 r
.48369 .87267 m .48103 .87112 L .48322 .87036 L F
.77 .552 .603 r
.48057 .87329 m .48322 .87036 L .48103 .87112 L F
.506 .836 .999 r
.65434 .75257 m .65554 .75326 L .65319 .7536 L F
.256 .194 .593 r
.653 .7557 m .65434 .75257 L .65319 .7536 L F
.737 .654 .767 r
.63168 .74336 m .63295 .74614 L .62969 .74582 L F
.553 .313 .506 r
.66987 .75605 m .66982 .75864 L .66746 .75866 L F
.491 .26 .491 r
.67191 .75548 m .66982 .75864 L .66987 .75605 L F
.056 .186 .684 r
.57229 .79229 m .57368 .79488 L .57249 .79327 L F
.628 .627 .83 r
.43627 .87738 m .43326 .87577 L .43564 .87676 L F
.399 .848 .914 r
.43724 .8767 m .43627 .87738 L .43564 .87676 L F
.43724 .8767 m .4389 .87678 L .43627 .87738 L F
0 0 0 r
.42031 .87936 m .41949 .88054 L .42097 .87954 L F
.694 .657 .809 r
.36339 .73066 m .36665 .73058 L .36506 .72745 L F
.6 .514 .728 r
.38186 .86531 m .37988 .86692 L .3796 .86541 L F
.407 0 .112 r
.47624 .81622 m .47892 .8151 L .47707 .81574 L F
.51 .437 .71 r
.47449 .87021 m .47296 .87284 L .47321 .87059 L F
.67 .572 .737 r
.38504 .75525 m .3827 .75593 L .38173 .75307 L F
.641 .923 .976 r
.39194 .90048 m .39555 .8998 L .39392 .89995 L F
.66 .963 .927 r
.39392 .89995 m .39555 .8998 L .39718 .89879 L F
.694 .584 .728 r
.62084 .74504 m .62224 .74841 L .619 .74745 L F
.723 .286 .211 r
.57058 .78406 m .56951 .78443 L .56731 .78244 L F
.059 .285 .774 r
.56731 .78244 m .56951 .78443 L .56747 .78239 L F
.76 .342 .258 r
.49008 .83909 m .48906 .8402 L .48751 .839 L F
.671 .553 .713 r
.49234 .83678 m .49008 .83909 L .49043 .8375 L F
.267 .743 .936 r
.49184 .84053 m .48906 .8402 L .49008 .83909 L F
.218 0 0 r
.5129 .81169 m .51624 .81158 L .51649 .81109 L F
0 .218 .629 r
.51763 .81172 m .51649 .81109 L .51624 .81158 L F
.51763 .81172 m .51794 .81194 L .51649 .81109 L F
.055 .608 .822 r
.51639 .81144 m .51742 .81157 L .51763 .81172 L F
.51742 .81157 m .51949 .81185 L .51763 .81172 L F
0 .218 .629 r
.51763 .81172 m .51882 .81245 L .51794 .81194 L F
0 .274 .717 r
.51649 .81109 m .51882 .81245 L .51896 .8127 L F
.592 .286 .419 r
.39471 .8602 m .39322 .86247 L .39143 .86254 L F
.537 .375 .61 r
.39667 .85756 m .39671 .85989 L .39471 .8602 L F
.649 .354 .458 r
.39664 .86223 m .39471 .8602 L .39671 .85989 L F
.39664 .86223 m .39322 .86247 L .39471 .8602 L F
.707 .69 .831 r
.5927 .77649 m .59598 .777 L .59499 .77439 L F
.645 .592 .781 r
.59598 .777 m .59718 .77364 L .59499 .77439 L F
.59598 .777 m .59819 .7765 L .59718 .77364 L F
.548 .392 .622 r
.59633 .77944 m .59819 .7765 L .59598 .777 L F
.611 .821 .981 r
.50527 .84935 m .50421 .85023 L .50202 .84909 L F
.13 .315 .782 r
.48611 .8446 m .48856 .84683 L .48699 .84376 L F
.652 .479 .637 r
.67784 .74592 m .67872 .74811 L .67636 .74812 L F
.928 .549 .161 r
.67781 .74743 m .67784 .74592 L .67548 .74554 L F
.67781 .74743 m .67872 .74811 L .67784 .74592 L F
.499 .581 .868 r
.35856 .76918 m .3599 .76874 L .36009 .76843 L F
.104 0 0 r
.35822 .76959 m .3599 .76874 L .35856 .76918 L F
0 .036 .602 r
.56834 .79554 m .56635 .7923 L .56811 .79283 L F
.743 .687 .797 r
.56847 .79497 m .56998 .79734 L .57161 .79505 L F
0 0 0 r
.5694 .79508 m .56911 .79522 L .56847 .79497 L F
0 .036 .602 r
.56834 .79554 m .56847 .79497 L .56784 .79472 L F
.562 .616 .863 r
.56748 .7975 m .56847 .79497 L .56834 .79554 L F
.56748 .7975 m .56998 .79734 L .56847 .79497 L F
0 0 0 r
.56911 .79522 m .56743 .79606 L .56847 .79497 L F
0 .036 .602 r
.56784 .79472 m .56847 .79497 L .56635 .7923 L F
.535 .192 .333 r
.4432 .83623 m .43998 .83859 L .44104 .83666 L F
.567 .934 .917 r
.57717 .80902 m .57851 .80858 L .57731 .80854 L F
.264 0 0 r
.57851 .80858 m .57934 .8095 L .57731 .80854 L F
.045 .432 .87 r
.57743 .80813 m .57731 .80854 L .57934 .8095 L F
.57615 .8072 m .57731 .80854 L .57743 .80813 L F
.567 .934 .917 r
.57446 .80993 m .57717 .80902 L .57731 .80854 L F
.264 0 0 r
.57851 .80858 m .58052 .80822 L .57934 .8095 L F
.415 .2 .476 r
.42167 .84359 m .42019 .84214 L .42322 .84199 L F
.342 0 0 r
.42485 .84315 m .42167 .84359 L .42322 .84199 L F
.549 .14 .218 r
.42651 .84166 m .42485 .84315 L .42322 .84199 L F
.472 .814 .999 r
.37281 .73525 m .37341 .73426 L .37478 .73491 L F
.37281 .73525 m .37341 .73426 L .37478 .73491 L F
.726 .543 .643 r
.67316 .74591 m .67391 .74868 L .67636 .74812 L F
.67316 .74591 m .67636 .74812 L .67315 .74853 L F
.1 .029 .482 r
.67316 .74591 m .67454 .74712 L .67548 .74554 L F
.67316 .74591 m .67315 .74853 L .67454 .74712 L F
.406 0 .026 r
.42389 .82591 m .42601 .82585 L .42733 .82442 L F
.263 0 0 r
.42733 .82442 m .42802 .82543 L .42908 .82469 L F
.42733 .82442 m .42601 .82585 L .42802 .82543 L F
.785 .692 .761 r
.65504 .74063 m .65662 .74359 L .65879 .741 L F
.626 .622 .827 r
.65739 .73926 m .66026 .73984 L .65879 .741 L F
.679 .952 .953 r
.66026 .73984 m .65765 .74049 L .65879 .741 L F
.554 .351 .56 r
.61852 .78735 m .61684 .78667 L .61922 .78667 L F
.61852 .78735 m .61688 .78938 L .61684 .78667 L F
.574 .154 .207 r
.44532 .82158 m .44724 .82271 L .44848 .82103 L F
.605 .189 .227 r
.44848 .82103 m .4504 .82241 L .45061 .82118 L F
.44848 .82103 m .44724 .82271 L .4504 .82241 L F
.547 .388 .617 r
.61688 .78938 m .61448 .79165 L .61411 .79028 L F
.82 .69 .721 r
.60588 .79996 m .60394 .80232 L .60376 .80038 L F
0 0 .307 r
.60422 .79928 m .60376 .80038 L .60394 .80232 L F
.42 0 0 r
.58416 .84733 m .58518 .84851 L .58304 .84857 L F
.58416 .84733 m .58646 .8474 L .58518 .84851 L F
.512 .695 .952 r
.37082 .751 m .3716 .7498 L .3697 .74979 L F
.37082 .751 m .37271 .75077 L .3716 .7498 L F
.705 .87 .959 r
.57024 .83781 m .57149 .83869 L .56919 .83954 L F
.705 .589 .724 r
.62433 .74583 m .62224 .74841 L .62084 .74504 L F
.953 .912 .544 r
.49542 .84662 m .49463 .84945 L .49545 .84752 L F
.666 .646 .82 r
.61697 .74866 m .61357 .7477 L .61574 .74542 L F
.764 .697 .787 r
.54675 .8263 m .54768 .82898 L .54454 .82868 L F
.7 .28 .245 r
.54462 .8288 m .54768 .82898 L .54668 .83173 L F
.54666 .83173 m .54668 .83173 L .54667 .83174 L F
.54462 .8288 m .54668 .83173 L .54666 .83173 L F
0 0 0 r
.54668 .83172 m .54768 .82898 L .54865 .82808 L F
.54667 .83174 m .54668 .83173 L .54668 .83172 L F
.54668 .83173 m .54768 .82898 L .54668 .83172 L F
.664 .275 .298 r
.54332 .83044 m .54454 .82868 L .54667 .83174 L F
.911 .94 .578 r
.54669 .8317 m .54865 .82808 L .54805 .82836 L F
.54667 .83174 m .54668 .83172 L .54669 .8317 L F
.54668 .83172 m .54865 .82808 L .54669 .8317 L F
.7 .28 .245 r
.5447 .82869 m .54768 .82898 L .54462 .8288 L F
.664 .275 .298 r
.54332 .83044 m .54667 .83174 L .54566 .82877 L F
.715 .187 0 r
.54675 .8263 m .54865 .82808 L .54768 .82898 L F
.911 .94 .578 r
.54667 .83174 m .54805 .82836 L .54566 .82877 L F
.602 .65 .87 r
.54696 .83051 m .54631 .83162 L .54479 .82983 L F
.54748 .83068 m .5468 .83123 L .54696 .83051 L F
.5468 .83123 m .54631 .83162 L .54696 .83051 L F
.54776 .83076 m .54713 .83114 L .54748 .83068 L F
.54713 .83114 m .54631 .83162 L .54748 .83068 L F
.54631 .83162 m .54551 .83209 L .54526 .83129 L F
.54631 .83162 m .54526 .83129 L .54479 .82983 L F
0 0 0 r
.54479 .82983 m .54358 .83033 L .54566 .82877 L F
.54358 .83033 m .54332 .83044 L .54368 .83019 L F
.54358 .83033 m .54368 .83019 L .54566 .82877 L F
.7 .28 .245 r
.54454 .82868 m .5447 .82869 L .54462 .8288 L F
0 0 0 r
.51939 .87758 m .52265 .87567 L .52121 .87715 L F
.271 0 0 r
.52121 .87715 m .52265 .87567 L .52463 .87524 L F
0 .192 .714 r
.54632 .81307 m .54828 .81537 L .54753 .81586 L F
.07 .35 .823 r
.55026 .81883 m .54753 .81586 L .54948 .81806 L F
0 .195 .716 r
.54828 .81537 m .54948 .81806 L .54753 .81586 L F
.6 .514 .728 r
.38186 .86531 m .38215 .86785 L .37988 .86692 L F
.448 0 0 r
.50807 .81008 m .50998 .8106 L .51127 .81044 L F
.49 0 0 r
.50998 .8106 m .5129 .81169 L .51127 .81044 L F
.674 .604 .769 r
.58712 .77467 m .59063 .77706 L .58941 .77602 L F
.686 .763 .91 r
.58941 .77602 m .59063 .77706 L .5927 .77649 L F
.944 .637 .426 r
.58941 .77602 m .58988 .77883 L .59063 .77706 L F
.516 .318 .55 r
.6596 .74597 m .66168 .74542 L .66176 .74318 L F
.573 .364 .559 r
.66168 .74542 m .66394 .74316 L .66176 .74318 L F
.617 .593 .804 r
.39078 .75838 m .38891 .75895 L .38732 .75608 L F
.495 .333 .59 r
.39078 .75838 m .38896 .76117 L .38891 .75895 L F
.191 .103 .519 r
.53067 .82335 m .53181 .8234 L .53151 .82094 L F
.579 .685 .913 r
.49916 .85572 m .50138 .85518 L .49814 .85449 L F
.491 .469 .76 r
.38345 .75065 m .38167 .75073 L .38065 .74793 L F
.611 .558 .77 r
.38345 .75065 m .38173 .75307 L .38167 .75073 L F
.538 .379 .613 r
.5975 .79737 m .59771 .79975 L .5956 .79994 L F
.424 .45 .783 r
.59785 .80264 m .5956 .79994 L .59771 .79975 L F
.401 .351 .687 r
.5168 .82376 m .51736 .82591 L .51875 .82566 L F
0 0 0 r
.50789 .88259 m .50872 .88208 L .50671 .88277 L F
.50789 .88259 m .51006 .88098 L .50872 .88208 L F
.66191 .76369 m .66079 .76395 L .66272 .76285 L F
.65973 .76501 m .66079 .76395 L .66191 .76369 L F
.69 .565 .709 r
.42861 .8415 m .42651 .84166 L .42531 .83937 L F
.422 .692 .975 r
.43431 .87483 m .43326 .87577 L .43288 .87511 L F
.317 .507 .885 r
.43431 .87483 m .43564 .87676 L .43326 .87577 L F
.536 .497 .76 r
.39785 .85382 m .39614 .8542 L .39557 .85269 L F
.6 .514 .729 r
.39785 .85382 m .39667 .85756 L .39614 .8542 L F
.877 .483 .023 r
.54948 .81806 m .55106 .8208 L .55026 .81883 L F
.445 .111 .305 r
.6596 .74597 m .66223 .74641 L .66168 .74542 L F
.6596 .74597 m .65873 .74792 L .66223 .74641 L F
.718 .961 .943 r
.57476 .76933 m .57654 .76826 L .5772 .76872 L F
.808 .98 .896 r
.5772 .76872 m .57902 .76617 L .57987 .76645 L F
.5772 .76872 m .57654 .76826 L .57902 .76617 L F
.555 .185 .295 r
.60345 .78491 m .60464 .78627 L .60314 .78643 L F
.60345 .78491 m .60569 .78461 L .60464 .78627 L F
.645 .826 .97 r
.38308 .87471 m .3834 .87577 L .38121 .87554 L F
.209 .098 .5 r
.38369 .87785 m .3834 .87577 L .38308 .87471 L F
.38369 .87785 m .3834 .87809 L .3834 .87577 L F
.321 0 .105 r
.49431 .86093 m .4971 .8594 L .49483 .8601 L F
0 0 0 r
.66812 .7505 m .66656 .75145 L .66573 .75238 L F
.475 .237 .473 r
.37527 .77151 m .37481 .77381 L .3729 .77419 L F
.5 .251 .468 r
.37727 .77116 m .37481 .77381 L .37527 .77151 L F
.976 .916 .667 r
.60685 .79221 m .6062 .79555 L .60692 .79453 L F
.991 .878 .55 r
.6062 .79555 m .60528 .79733 L .60692 .79453 L F
.667 .453 .585 r
.47697 .8676 m .47449 .87021 L .47523 .86844 L F
0 0 .052 r
.51991 .81353 m .52134 .81044 L .51896 .8127 L F
.586 .736 .947 r
.3953 .8289 m .39333 .82933 L .39231 .82813 L F
.801 .697 .75 r
.65351 .74315 m .65662 .74359 L .65504 .74063 L F
.799 .703 .759 r
.65351 .74315 m .65457 .74623 L .65662 .74359 L F
.748 .865 .934 r
.61357 .7477 m .61054 .74788 L .61308 .74599 L F
.821 .848 .868 r
.61574 .74542 m .61357 .7477 L .61308 .74599 L F
.77 .857 .915 r
.43179 .89022 m .43384 .89148 L .4358 .88955 L F
.486 0 0 r
.41651 .82629 m .41864 .82658 L .4197 .82597 L F
.248 0 0 r
.41864 .82658 m .42181 .82592 L .4197 .82597 L F
.672 .421 .532 r
.41794 .84447 m .41411 .84636 L .41587 .84442 L F
.505 .306 .544 r
.39758 .85207 m .39557 .85269 L .39774 .84975 L F
.583 .377 .567 r
.39206 .82375 m .39424 .82352 L .39407 .82578 L F
.39407 .82578 m .39424 .82352 L .39206 .82375 L F
.62 .404 .566 r
.39938 .85174 m .39758 .85207 L .39774 .84975 L F
.503 .237 .444 r
.63323 .77432 m .63288 .77579 L .6307 .77617 L F
.494 .236 .452 r
.63535 .77385 m .63288 .77579 L .63323 .77432 L F
.589 .392 .582 r
.60787 .78213 m .60784 .78446 L .60569 .78461 L F
.612 .41 .584 r
.60895 .783 m .60787 .78213 L .60926 .7823 L F
.60895 .783 m .60784 .78446 L .60787 .78213 L F
0 0 0 r
.49715 .88744 m .50051 .88616 L .49788 .88705 L F
.266 .76 .69 r
.49788 .88705 m .50051 .88616 L .5023 .8855 L F
.487 .051 .136 r
.42861 .8415 m .42485 .84315 L .42651 .84166 L F
.73 .438 .485 r
.57955 .80557 m .57716 .80293 L .57782 .80483 L F
.769 .566 .624 r
.51584 .81822 m .51231 .8206 L .51248 .81844 L F
.51584 .81822 m .51483 .82117 L .51231 .8206 L F
.8 .705 .759 r
.54334 .82328 m .54108 .8263 L .54005 .82319 L F
.636 .468 .638 r
.54334 .82328 m .54354 .82658 L .54108 .8263 L F
.68 .49 .622 r
.54472 .82459 m .54354 .82658 L .54334 .82328 L F
.506 .25 .46 r
.6307 .77617 m .63049 .77919 L .6283 .77955 L F
.492 .233 .448 r
.63288 .77579 m .63049 .77919 L .6307 .77617 L F
.651 .177 .114 r
.50601 .82915 m .50923 .82971 L .50695 .82954 L F
.611 .558 .77 r
.38345 .75065 m .38445 .75357 L .38173 .75307 L F
.67 .572 .737 r
.38504 .75525 m .38173 .75307 L .38445 .75357 L F
.772 .623 .695 r
.50753 .85735 m .50829 .86003 L .5058 .85983 L F
.744 .416 .427 r
.5058 .85983 m .50829 .86003 L .50755 .86226 L F
.538 .368 .599 r
.51042 .85761 m .50829 .86003 L .50753 .85735 L F
.51042 .85761 m .51031 .85989 L .50829 .86003 L F
.433 .043 .198 r
.50829 .86003 m .50926 .86125 L .50755 .86226 L F
.50829 .86003 m .51031 .85989 L .50926 .86125 L F
.844 .389 0 r
.5552 .80604 m .55604 .8076 L .55425 .80552 L F
.66 .503 .661 r
.50111 .8262 m .49865 .82884 L .49896 .82688 L F
.573 .938 .817 r
.52728 .87038 m .52637 .87111 L .52456 .87175 L F
.298 .675 .974 r
.52809 .86997 m .5292 .87084 L .52684 .87052 L F
.52809 .86997 m .52684 .87052 L .52637 .87111 L F
.573 .938 .817 r
.52809 .86997 m .52637 .87111 L .52728 .87038 L F
.375 .084 .338 r
.52684 .87052 m .52517 .87208 L .52637 .87111 L F
.52517 .87208 m .52228 .87476 L .52637 .87111 L F
.856 .85 .836 r
.5706 .77194 m .5678 .77508 L .56676 .77384 L F
.626 .892 .987 r
.40482 .89697 m .40799 .89672 L .40668 .89604 L F
.562 .838 .997 r
.40668 .89604 m .40799 .89672 L .40996 .8962 L F
.536 .497 .76 r
.39785 .85382 m .39557 .85269 L .39758 .85207 L F
.636 .635 .832 r
.38847 .88578 m .38679 .8826 L .38842 .88318 L F
.804 .87 .896 r
.39064 .88104 m .38842 .88318 L .38679 .8826 L F
.738 .703 .818 r
.36129 .73163 m .35771 .73103 L .35982 .7307 L F
.745 .262 .094 r
.55037 .79246 m .55248 .79446 L .55371 .79417 L F
.194 0 0 r
.55371 .79417 m .55248 .79446 L .55597 .79422 L F
.598 .367 .536 r
.61955 .7844 m .62086 .78621 L .61922 .78667 L F
.61955 .7844 m .62146 .78429 L .62086 .78621 L F
.388 0 .096 r
.48557 .81259 m .48884 .81077 L .48679 .8111 L F
.856 .85 .836 r
.5706 .77194 m .56676 .77384 L .56884 .77279 L F
.408 .857 .797 r
.56884 .77279 m .57128 .77185 L .5706 .77194 L F
.591 .423 .622 r
.59416 .78199 m .59648 .78185 L .59633 .77944 L F
.633 .505 .689 r
.59416 .78199 m .59718 .78445 L .59648 .78185 L F
.59416 .78199 m .59501 .78524 L .59718 .78445 L F
.735 .796 .901 r
.58083 .7743 m .58423 .77416 L .58294 .77289 L F
.58083 .7743 m .58167 .77438 L .58423 .77416 L F
.304 .735 .97 r
.58423 .77416 m .58365 .77312 L .58294 .77289 L F
.51 .444 .718 r
.58712 .77467 m .58844 .77121 L .58749 .77447 L F
.58719 .77447 m .58747 .77444 L .58844 .77121 L F
.863 .822 .806 r
.58365 .77312 m .58747 .77446 L .58844 .77121 L F
.58747 .77446 m .58749 .77447 L .58844 .77121 L F
.51 .444 .718 r
.58747 .77444 m .58901 .77427 L .58844 .77121 L F
.304 .735 .97 r
.58742 .77446 m .58749 .77447 L .58747 .77446 L F
.51 .444 .718 r
.58712 .77467 m .58829 .77443 L .58719 .77447 L F
.58829 .77443 m .58901 .77427 L .58719 .77447 L F
.304 .735 .97 r
.58423 .77416 m .58742 .77446 L .58365 .77312 L F
.58742 .77446 m .58747 .77446 L .58365 .77312 L F
.627 .692 .891 r
.58423 .77416 m .58712 .77467 L .58749 .77447 L F
.589 .506 .729 r
.65172 .73776 m .65003 .74099 L .64963 .73803 L F
.577 .491 .722 r
.65172 .73776 m .65219 .74052 L .65007 .74093 L F
.553 .786 .986 r
.65173 .73914 m .65219 .74052 L .65172 .73776 L F
.65173 .73914 m .654 .74016 L .65219 .74052 L F
.654 .74016 m .65504 .74063 L .65219 .74052 L F
.577 .491 .722 r
.65007 .74093 m .65219 .74052 L .65003 .74099 L F
.507 .223 .418 r
.64995 .74205 m .65219 .74052 L .65003 .74099 L F
.689 .62 .773 r
.62323 .74282 m .62433 .74583 L .62084 .74504 L F
.692 .622 .773 r
.62643 .74512 m .62433 .74583 L .62323 .74282 L F
.537 .297 .498 r
.42019 .84214 m .42013 .84448 L .41794 .84447 L F
.415 .2 .476 r
.42167 .84359 m .42013 .84448 L .42019 .84214 L F
.462 .129 .314 r
.64295 .76937 m .64466 .77029 L .64258 .77079 L F
.64295 .76937 m .64509 .76904 L .64466 .77029 L F
.842 .953 .887 r
.57811 .79511 m .5748 .79673 L .57702 .79449 L F
.698 .277 .242 r
.57711 .79666 m .57811 .79511 L .57702 .79449 L F
.518 .407 .667 r
.58054 .79684 m .57847 .79733 L .57811 .79511 L F
.698 .277 .242 r
.57711 .79666 m .58054 .79684 L .57811 .79511 L F
.645 .622 .812 r
.37709 .74312 m .37379 .74102 L .37582 .74047 L F
.535 .553 .82 r
.37778 .74004 m .37709 .74312 L .37582 .74047 L F
.37778 .74004 m .379 .74297 L .37709 .74312 L F
.357 .828 .879 r
.4358 .88955 m .43884 .88905 L .4376 .88886 L F
.512 .893 .961 r
.4376 .88886 m .43884 .88905 L .4408 .88839 L F
.562 .48 .72 r
.38229 .74533 m .38065 .74793 L .38026 .74575 L F
.38229 .74533 m .38322 .749 L .38065 .74793 L F
.491 .469 .76 r
.38345 .75065 m .38065 .74793 L .38322 .749 L F
.689 .62 .773 r
.62323 .74282 m .62084 .74504 L .62102 .74329 L F
.642 .108 0 r
.49288 .85041 m .49056 .85028 L .48941 .84943 L F
.698 .923 .968 r
.49346 .84893 m .49288 .85041 L .49463 .84945 L F
.49346 .84893 m .49056 .85028 L .49288 .85041 L F
.201 0 0 r
.67872 .74811 m .67649 .74973 L .67636 .74812 L F
.572 .558 .8 r
.52092 .82078 m .52265 .82434 L .52343 .82381 L F
.902 .503 .089 r
.52306 .82434 m .52265 .82434 L .5212 .82533 L F
.52306 .82434 m .52343 .82381 L .52265 .82434 L F
.533 .175 .305 r
.36228 .76852 m .36567 .76638 L .36331 .7663 L F
.521 .5 .774 r
.58712 .77467 m .58941 .77602 L .58901 .77427 L F
.54 .469 .725 r
.59228 .80207 m .59033 .80423 L .58989 .80333 L F
0 0 .44 r
.49268 .83391 m .49234 .83678 L .4944 .83411 L F
.349 .096 .382 r
.59995 .83629 m .59775 .83882 L .59827 .83696 L F
.548 .886 .987 r
.38856 .90079 m .38984 .90115 L .39194 .90048 L F
.575 .571 .811 r
.47487 .87257 m .47367 .87523 L .47296 .87284 L F
.47487 .87257 m .47574 .87502 L .47367 .87523 L F
.224 .009 .363 r
.59412 .79945 m .59268 .79945 L .59228 .80207 L F
.464 0 0 r
.38648 .83089 m .38792 .83001 L .38517 .83023 L F
.345 0 0 r
.38926 .83038 m .38792 .83001 L .38648 .83089 L F
.787 .592 .637 r
.50302 .85412 m .50664 .8521 L .5044 .85499 L F
.641 .493 .666 r
.50664 .8521 m .50708 .85485 L .5044 .85499 L F
.181 0 0 r
.50622 .85507 m .50302 .85412 L .5044 .85499 L F
.686 .616 .772 r
.50961 .85507 m .50753 .85735 L .50708 .85485 L F
.786 .682 .749 r
.50708 .85485 m .50431 .85718 L .5044 .85499 L F
.181 0 0 r
.50854 .85516 m .50375 .85426 L .50622 .85507 L F
.50375 .85426 m .50302 .85412 L .50622 .85507 L F
.786 .682 .749 r
.50666 .85521 m .50753 .85735 L .50431 .85718 L F
.50708 .85485 m .50718 .85538 L .50666 .85521 L F
.50718 .85538 m .50753 .85735 L .50666 .85521 L F
.79 .65 .707 r
.50431 .85718 m .50753 .85735 L .5058 .85983 L F
.671 .593 .759 r
.50961 .85507 m .51042 .85761 L .50753 .85735 L F
.835 .957 .618 r
.60782 .78893 m .60923 .78747 L .60791 .78942 L F
.966 .771 .332 r
.60895 .783 m .60923 .78747 L .60868 .78699 L F
.951 .946 .633 r
.60868 .78699 m .60923 .78747 L .60782 .78893 L F
.721 .852 .944 r
.50138 .85518 m .5044 .85499 L .50302 .85412 L F
.181 0 0 r
.50854 .85516 m .5044 .85499 L .50431 .85718 L F
0 0 0 r
.66394 .74316 m .66593 .74286 L .66705 .74263 L F
.323 0 0 r
.66593 .74286 m .66908 .74292 L .66705 .74263 L F
.487 .051 .136 r
.42861 .8415 m .42711 .84323 L .42485 .84315 L F
.523 .064 .105 r
.43066 .84206 m .42711 .84323 L .42861 .8415 L F
.77 .552 .603 r
.48057 .87329 m .48369 .87267 L .48322 .87036 L F
.467 .353 .64 r
.48443 .87011 m .48322 .87036 L .48392 .86882 L F
.608 .35 .501 r
.48392 .86882 m .48645 .86976 L .4851 .86996 L F
.48645 .86976 m .48748 .87015 L .4862 .87004 L F
.48645 .86976 m .4862 .87004 L .4851 .86996 L F
.48392 .86882 m .48603 .86956 L .48603 .86961 L F
.48476 .87093 m .48534 .87116 L .48504 .87163 L F
.555 .115 .158 r
.48476 .87093 m .48603 .87068 L .48326 .87037 L F
.48534 .87116 m .48326 .87037 L .48322 .87036 L F
.546 .658 .909 r
.48322 .87036 m .48326 .87037 L .48443 .87011 L F
.467 .353 .64 r
.48476 .87093 m .48322 .87036 L .48443 .87011 L F
.48504 .87163 m .48322 .87036 L .48476 .87093 L F
.48481 .87198 m .48322 .87036 L .48504 .87163 L F
.555 .115 .158 r
.48356 .87239 m .48322 .87036 L .48369 .87267 L F
.467 .353 .64 r
.48481 .87198 m .48369 .87267 L .48322 .87036 L F
.48543 .87262 m .48442 .87265 L .48481 .87198 L F
.48442 .87265 m .48369 .87267 L .48481 .87198 L F
.555 .115 .158 r
.48356 .87239 m .48534 .87116 L .48496 .87101 L F
.48356 .87239 m .48464 .87089 L .48322 .87036 L F
.48535 .87115 m .48603 .87068 L .48476 .87093 L F
.608 .35 .501 r
.48443 .87011 m .48554 .87086 L .48534 .87116 L F
.555 .115 .158 r
.48534 .87116 m .48535 .87115 L .48476 .87093 L F
.546 .658 .909 r
.48326 .87037 m .48603 .87068 L .48443 .87011 L F
.608 .35 .501 r
.48443 .87011 m .48534 .87116 L .48476 .87093 L F
.48573 .87056 m .48748 .87015 L .48732 .87207 L F
.546 .658 .909 r
.48443 .87011 m .48603 .87068 L .48601 .87003 L F
.48443 .87011 m .48601 .87003 L .48513 .86996 L F
.608 .35 .501 r
.4851 .86996 m .4862 .87004 L .48573 .87056 L F
.792 .659 .107 r
.48601 .87003 m .48603 .87068 L .48599 .87027 L F
.608 .35 .501 r
.4862 .87004 m .48748 .87015 L .48573 .87056 L F
.546 .658 .909 r
.48513 .86996 m .48601 .87003 L .486 .86977 L F
.608 .35 .501 r
.4851 .86996 m .48573 .87056 L .48443 .87011 L F
.893 .988 .776 r
.48599 .87027 m .48603 .87068 L .48534 .87116 L F
.48599 .87027 m .48534 .87116 L .48573 .87056 L F
.608 .35 .501 r
.48573 .87056 m .48732 .87207 L .48554 .87086 L F
.48573 .87056 m .48554 .87086 L .48443 .87011 L F
.893 .988 .776 r
.48599 .87017 m .48583 .87041 L .48582 .87042 L F
.48597 .87018 m .48582 .87042 L .48356 .87239 L F
.48599 .87017 m .48582 .87042 L .48597 .87018 L F
.608 .35 .501 r
.48392 .86882 m .4851 .86996 L .48443 .87011 L F
.599 .379 .554 r
.48771 .8677 m .48748 .87006 L .48392 .86882 L F
.546 .658 .909 r
.48322 .87036 m .486 .86977 L .48598 .86921 L F
.893 .988 .776 r
.48591 .86914 m .48597 .87001 L .48356 .87239 L F
.48597 .87001 m .48599 .87017 L .48576 .87038 L F
.48597 .87001 m .48576 .87038 L .48356 .87239 L F
.48599 .87017 m .48599 .87027 L .48583 .87041 L F
.467 .353 .64 r
.48543 .87262 m .48481 .87198 L .48504 .87163 L F
.893 .988 .776 r
.48573 .87056 m .48534 .87116 L .48493 .87144 L F
.608 .35 .501 r
.48504 .87163 m .48732 .87207 L .48543 .87262 L F
.48554 .87086 m .48732 .87207 L .48504 .87163 L F
.893 .988 .776 r
.48599 .87027 m .48493 .87144 L .48356 .87239 L F
.792 .659 .107 r
.48598 .86921 m .48601 .87003 L .48591 .86914 L F
.48601 .87003 m .48599 .87027 L .48591 .86914 L F
.608 .35 .501 r
.48603 .86961 m .48748 .87006 L .48748 .87015 L F
.48603 .86956 m .48748 .87006 L .48603 .86961 L F
.397 .243 .553 r
.48392 .86882 m .48322 .87036 L .48598 .86921 L F
.6 .939 .754 r
.46622 .8712 m .46406 .87284 L .4647 .87197 L F
.467 .244 .491 r
.46519 .87187 m .46622 .8712 L .4647 .87197 L F
.324 0 .105 r
.46723 .87055 m .46406 .87284 L .46622 .8712 L F
.467 .244 .491 r
.468 .8713 m .46622 .8712 L .46519 .87187 L F
.324 0 .105 r
.46741 .87043 m .46723 .87055 L .46622 .8712 L F
.716 .297 .252 r
.47024 .87253 m .47035 .87232 L .468 .8713 L F
.47035 .87232 m .47088 .87133 L .46927 .87131 L F
.055 .268 .761 r
.46785 .86997 m .46901 .8716 L .46741 .87043 L F
.46854 .87062 m .46901 .8716 L .46785 .86997 L F
.4681 .86971 m .46854 .87062 L .46785 .86997 L F
.448 .848 .975 r
.468 .8713 m .46901 .8716 L .4681 .86971 L F
.468 .8713 m .47088 .87133 L .46901 .8716 L F
.716 .297 .252 r
.47035 .87232 m .46927 .87131 L .468 .8713 L F
.278 0 0 r
.42908 .82469 m .43133 .8246 L .43257 .82385 L F
.442 0 0 r
.43133 .8246 m .43466 .82398 L .43257 .82385 L F
.722 .663 .792 r
.65098 .74547 m .65457 .74623 L .65351 .74315 L F
.402 .108 .348 r
.59393 .84211 m .59317 .84347 L .59139 .84419 L F
.286 .039 .354 r
.59393 .84211 m .59604 .8394 L .59542 .84121 L F
.356 .061 .32 r
.59522 .84384 m .59393 .84211 L .59542 .84121 L F
.59522 .84384 m .59317 .84347 L .59393 .84211 L F
.81 .604 .624 r
.5679 .79928 m .57089 .79791 L .56998 .79734 L F
.5679 .79928 m .57083 .80089 L .57089 .79791 L F
.395 0 0 r
.50413 .87662 m .5035 .87561 L .50237 .87772 L F
.50413 .87662 m .50583 .87574 L .5035 .87561 L F
.513 .85 .996 r
.40986 .88097 m .40652 .88095 L .40886 .88099 L F
.345 .715 .985 r
.41065 .88021 m .40986 .88097 L .40886 .88099 L F
.41065 .88021 m .41182 .88099 L .40986 .88097 L F
.343 .081 .364 r
.59775 .83882 m .59542 .84121 L .59604 .8394 L F
.465 .197 .422 r
.62608 .7798 m .62587 .78153 L .62383 .78201 L F
.42 .111 .334 r
.6283 .77955 m .62587 .78153 L .62608 .7798 L F
0 .439 .718 r
.47497 .88229 m .47819 .88316 L .47707 .88248 L F
.05 .547 .884 r
.47707 .88248 m .47819 .88316 L .47989 .88356 L F
.792 .611 .656 r
.64965 .7297 m .65076 .73006 L .64785 .73003 L F
.715 .595 .721 r
.65074 .7322 m .64785 .73003 L .65076 .73006 L F
.761 .67 .761 r
.6528 .72767 m .65076 .73006 L .64965 .7297 L F
.595 .405 .593 r
.65076 .73006 m .65296 .73205 L .65074 .7322 L F
.671 .531 .685 r
.6528 .72767 m .65358 .73021 L .65076 .73006 L F
.659 .393 .507 r
.65358 .73021 m .65296 .73205 L .65076 .73006 L F
.518 .113 .212 r
.4381 .83928 m .43461 .84097 L .4361 .83972 L F
.261 .668 .966 r
.57343 .83885 m .57149 .83869 L .57024 .83781 L F
.73 .634 .751 r
.63913 .74064 m .64045 .74352 L .63715 .74313 L F
.684 .613 .77 r
.64241 .74295 m .64045 .74352 L .63913 .74064 L F
.378 0 .189 r
.52513 .81308 m .52403 .81513 L .5221 .81549 L F
.537 .191 .329 r
.52691 .81309 m .52403 .81513 L .52513 .81308 L F
.616 .267 .356 r
.45061 .82118 m .45251 .82277 L .45377 .82051 L F
.509 .113 .225 r
.45251 .82277 m .45588 .8209 L .45377 .82051 L F
.482 .221 .442 r
.38448 .76574 m .38388 .76876 L .38202 .7691 L F
.522 .269 .473 r
.3864 .76535 m .38388 .76876 L .38448 .76574 L F
0 0 .44 r
.49268 .83391 m .49313 .83629 L .49234 .83678 L F
.947 .742 .594 r
.57651 .78331 m .57808 .78209 L .57721 .78155 L F
.57651 .78331 m .57781 .78426 L .57808 .78209 L F
.915 .939 .807 r
.57901 .77898 m .57808 .78209 L .57682 .77916 L F
.57901 .77898 m .57721 .78155 L .57808 .78209 L F
.767 .69 .778 r
.5015 .82084 m .50526 .82122 L .50367 .81822 L F
.757 .431 .433 r
.5015 .82084 m .50379 .82204 L .50526 .82122 L F
.077 .307 .789 r
.50367 .81822 m .50526 .82122 L .50582 .82005 L F
.7 .982 .816 r
.50526 .82122 m .50379 .82204 L .50582 .82005 L F
.688 .521 .656 r
.50821 .81936 m .50491 .82329 L .50526 .82122 L F
.441 .005 .113 r
.60569 .78461 m .60676 .78606 L .60464 .78627 L F
.60569 .78461 m .60784 .78446 L .60676 .78606 L F
.631 .748 .932 r
.54108 .8263 m .53762 .82519 L .54005 .82319 L F
.326 .045 .325 r
.53907 .8288 m .54108 .8263 L .54144 .82834 L F
.736 .596 .7 r
.54354 .82658 m .54144 .82834 L .54108 .8263 L F
.6 .514 .729 r
.39785 .85382 m .39867 .85735 L .39667 .85756 L F
.584 .413 .616 r
.39867 .85735 m .39671 .85989 L .39667 .85756 L F
.568 .367 .568 r
.61176 .79481 m .61027 .79743 L .61023 .79517 L F
.417 .525 .859 r
.57466 .79954 m .5765 .8019 L .57411 .80121 L F
.493 .218 .425 r
.36607 .77961 m .36551 .78152 L .36353 .78183 L F
.476 .202 .418 r
.36746 .78115 m .36607 .77961 L .36789 .77911 L F
.36746 .78115 m .36551 .78152 L .36607 .77961 L F
.518 .483 .757 r
.59501 .78524 m .59552 .78732 L .59722 .78675 L F
.584 .47 .689 r
.59526 .78909 m .59722 .78675 L .59552 .78732 L F
.35 .02 .257 r
.59139 .84419 m .59256 .84584 L .59088 .8467 L F
.59139 .84419 m .59317 .84347 L .59256 .84584 L F
.64 .611 .805 r
.38652 .75311 m .38504 .75525 L .38445 .75357 L F
.428 0 0 r
.54712 .79254 m .5496 .79294 L .55037 .79246 L F
0 .058 .568 r
.55146 .79336 m .55037 .79246 L .5496 .79294 L F
.55146 .79336 m .55248 .79446 L .55037 .79246 L F
.595 .329 .483 r
.4084 .84981 m .40581 .85151 L .40694 .85002 L F
.4084 .84981 m .40845 .85148 L .40581 .85151 L F
.662 .381 .484 r
.4084 .84981 m .4101 .85167 L .40845 .85148 L F
.593 .381 .563 r
.41058 .84953 m .4101 .85167 L .4084 .84981 L F
.548 .392 .622 r
.59633 .77944 m .59829 .77909 L .59819 .7765 L F
.573 .409 .621 r
.59633 .77944 m .59811 .78122 L .59829 .77909 L F
.59633 .77944 m .59648 .78185 L .59811 .78122 L F
.474 0 0 r
.56705 .84737 m .57022 .84733 L .56985 .84827 L F
.574 .035 0 r
.56985 .84827 m .57022 .84733 L .57253 .8486 L F
.614 .469 .661 r
.57377 .78962 m .57229 .79229 L .57151 .78994 L F
.467 .206 .434 r
.3729 .77419 m .37218 .77693 L .37042 .77727 L F
.542 .302 .502 r
.37481 .77381 m .37218 .77693 L .3729 .77419 L F
.405 .811 .981 r
.47642 .84139 m .4731 .84124 L .47421 .84173 L F
.47642 .84139 m .4731 .84124 L .47421 .84173 L F
.811 .736 .782 r
.51479 .8439 m .51445 .84747 L .51286 .84662 L F
.759 .495 .534 r
.51445 .84747 m .51657 .84999 L .51381 .84966 L F
0 0 .116 r
.51445 .84747 m .51381 .84966 L .51465 .84857 L F
.51445 .84747 m .51465 .84857 L .51286 .84662 L F
.418 .71 .984 r
.49885 .87719 m .49613 .87739 L .49482 .87726 L F
.49885 .87719 m .49804 .87751 L .49613 .87739 L F
0 0 .267 r
.5916 .83152 m .59236 .83267 L .59288 .83085 L F
.584 .238 .35 r
.46623 .82002 m .46844 .82013 L .46665 .81862 L F
.533 .255 .439 r
.46665 .81862 m .46844 .82013 L .46878 .81837 L F
.771 .728 .813 r
.62102 .74329 m .61804 .74361 L .61984 .74211 L F
.65 .724 .902 r
.62323 .74282 m .62102 .74329 L .61984 .74211 L F
.231 0 0 r
.35696 .75036 m .35673 .75037 L .35362 .74997 L F
.588 .946 .887 r
.35839 .74925 m .35696 .75036 L .359 .75007 L F
.35839 .74925 m .35673 .75037 L .35696 .75036 L F
.819 .904 .9 r
.58755 .76233 m .58424 .76364 L .5854 .76249 L F
.735 .933 .954 r
.58755 .76233 m .58842 .76073 L .58945 .76127 L F
.58755 .76233 m .5854 .76249 L .58842 .76073 L F
.569 .914 .968 r
.39904 .89829 m .40275 .89762 L .40078 .89774 L F
.484 .891 .933 r
.40376 .8968 m .40275 .89762 L .40482 .89697 L F
.40376 .8968 m .40078 .89774 L .40275 .89762 L F
.612 .344 .486 r
.37093 .83575 m .37234 .83274 L .37102 .83344 L F
.117 0 0 r
.37183 .8327 m .37246 .83274 L .37371 .83271 L F
.37246 .83274 m .37273 .83275 L .37371 .83271 L F
.3738 .83278 m .37462 .83285 L .37428 .8328 L F
.24 .58 .944 r
.37251 .83238 m .37419 .83281 L .37462 .83285 L F
.37419 .83281 m .37578 .83322 L .37462 .83285 L F
.58 .324 .494 r
.37419 .83281 m .37575 .83562 L .37578 .83322 L F
.117 0 0 r
.37273 .83275 m .37275 .83275 L .3738 .83278 L F
.37275 .83275 m .37419 .83281 L .3738 .83278 L F
.37273 .83275 m .37428 .8328 L .37371 .83271 L F
.58 .324 .494 r
.37251 .83238 m .37288 .83276 L .37419 .83281 L F
.37288 .83276 m .37575 .83562 L .37419 .83281 L F
.37288 .83276 m .37351 .83608 L .37575 .83562 L F
.117 0 0 r
.37275 .83275 m .3728 .83275 L .37288 .83276 L F
.58 .324 .494 r
.37251 .83238 m .3728 .83275 L .37288 .83276 L F
.117 0 0 r
.37288 .83276 m .37462 .83285 L .37419 .83281 L F
.3728 .83275 m .37462 .83285 L .37288 .83276 L F
.52 .314 .541 r
.37251 .83238 m .37462 .83285 L .3728 .83275 L F
.37251 .83238 m .3728 .83275 L .37183 .8327 L F
.58 .324 .494 r
.37251 .83238 m .3726 .83275 L .3728 .83275 L F
.3726 .83275 m .37351 .83608 L .37288 .83276 L F
.612 .344 .486 r
.37093 .83575 m .37351 .83608 L .3726 .83275 L F
.37234 .83274 m .3726 .83275 L .37251 .83238 L F
.37093 .83575 m .3726 .83275 L .37234 .83274 L F
.37234 .83274 m .37251 .83238 L .37199 .83274 L F
.37234 .83274 m .37199 .83274 L .37102 .83344 L F
.117 0 0 r
.37371 .83271 m .37462 .83285 L .37496 .83272 L F
.617 .196 .221 r
.37462 .83285 m .37701 .83244 L .37496 .83272 L F
.428 .843 .965 r
.37753 .83235 m .37496 .83272 L .37701 .83244 L F
.761 .67 .761 r
.6528 .72767 m .64965 .7297 L .65178 .7265 L F
.646 .667 .856 r
.65396 .72479 m .6528 .72767 L .65178 .7265 L F
.65396 .72479 m .65518 .72727 L .6528 .72767 L F
.599 .383 .559 r
.6528 .72767 m .65518 .72727 L .65454 .72921 L F
.428 .385 .708 r
.6528 .72767 m .65454 .72921 L .65358 .73021 L F
.599 .383 .559 r
.6528 .72767 m .65518 .72727 L .65454 .72921 L F
.675 .165 .023 r
.49874 .8334 m .49632 .83303 L .49654 .83191 L F
.599 .379 .554 r
.48771 .8677 m .48392 .86882 L .48598 .86921 L F
.547 .822 .997 r
.41589 .88018 m .41535 .8815 L .4138 .88049 L F
.41589 .88018 m .41737 .88102 L .41535 .8815 L F
.777 .685 .762 r
.50344 .85203 m .50664 .8521 L .50527 .84935 L F
.787 .592 .637 r
.50302 .85412 m .50708 .85485 L .50664 .8521 L F
.495 .391 .666 r
.50664 .8521 m .50708 .85485 L .509 .85426 L F
.50664 .8521 m .50708 .85485 L .509 .85426 L F
.493 .251 .475 r
.38871 .76477 m .38685 .76368 L .38874 .76316 L F
.38871 .76477 m .3864 .76535 L .38685 .76368 L F
.82 .69 .721 r
.60588 .79996 m .60537 .80138 L .60394 .80232 L F
.642 .475 .643 r
.6082 .79765 m .60889 .79967 L .60588 .79996 L F
.623 .447 .623 r
.60889 .79967 m .60537 .80138 L .60588 .79996 L F
.002 0 .44 r
.6693 .74946 m .66812 .7505 L .66805 .74823 L F
.176 .704 .691 r
.44388 .87568 m .44063 .87649 L .44232 .8767 L F
0 0 0 r
.4447 .87495 m .44605 .87322 L .44388 .87568 L F
.487 .862 .641 r
.4447 .87495 m .44388 .87568 L .44232 .8767 L F
.707 .962 .706 r
.58883 .83555 m .58742 .83706 L .58822 .83577 L F
.598 .853 .992 r
.58822 .83577 m .58742 .83706 L .58613 .83639 L F
.678 .433 .543 r
.52317 .82038 m .52536 .82024 L .52644 .81852 L F
.706 .708 .85 r
.64937 .7369 m .64963 .73803 L .64661 .73772 L F
.539 .767 .981 r
.65153 .73691 m .64963 .73803 L .64937 .7369 L F
.65153 .73691 m .65172 .73776 L .64963 .73803 L F
.605 .53 .744 r
.48707 .81566 m .4878 .81822 L .48569 .81799 L F
.336 0 0 r
.44675 .87436 m .44605 .87322 L .4447 .87495 L F
.44675 .87436 m .44817 .87301 L .44605 .87322 L F
.532 .283 .484 r
.39143 .86254 m .38915 .86478 L .3896 .86291 L F
.749 .887 .942 r
.591 .8171 m .59255 .81514 L .59084 .81561 L F
.591 .8171 m .59358 .81598 L .59255 .81514 L F
.536 .39 .631 r
.61027 .79743 m .60889 .79967 L .6082 .79765 L F
.752 .667 .767 r
.6434 .73728 m .64445 .74048 L .64259 .74082 L F
.747 .62 .719 r
.64445 .74048 m .64241 .74295 L .64259 .74082 L F
.504 .284 .513 r
.6445 .74233 m .64241 .74295 L .64445 .74048 L F
.6445 .74233 m .64241 .74295 L .64445 .74048 L F
.742 .662 .771 r
.64661 .73772 m .64445 .74048 L .6434 .73728 L F
.329 .778 .956 r
.64778 .74257 m .6445 .74233 L .64445 .74048 L F
.643 .565 .752 r
.51664 .82787 m .51875 .82566 L .51736 .82591 L F
.617 .416 .588 r
.51736 .82591 m .5146 .82866 L .51664 .82787 L F
.885 .774 .734 r
.56447 .84412 m .56497 .84711 L .56475 .84573 L F
.19 0 0 r
.56497 .84711 m .5666 .84732 L .56652 .84751 L F
.5666 .84732 m .56705 .84737 L .56652 .84751 L F
.493 0 0 r
.56652 .84751 m .56681 .84807 L .56646 .84768 L F
.19 0 0 r
.56497 .84711 m .56652 .84751 L .56475 .84573 L F
.493 0 0 r
.56652 .84751 m .56646 .84768 L .56472 .84577 L F
.64 .949 .948 r
.57214 .78021 m .56747 .78239 L .57111 .78034 L F
.56 .405 .629 r
.56747 .78239 m .57061 .78247 L .57111 .78034 L F
.886 .99 .792 r
.57139 .78066 m .57047 .78168 L .57061 .78247 L F
.56 .405 .629 r
.56747 .78239 m .57077 .78339 L .57061 .78247 L F
.682 .351 .408 r
.57111 .78034 m .57061 .78247 L .56792 .7818 L F
.469 .066 .192 r
.56944 .78282 m .56792 .7818 L .57061 .78247 L F
.886 .99 .792 r
.57047 .78168 m .56944 .78282 L .57061 .78247 L F
.56 .405 .629 r
.57077 .78339 m .57159 .78364 L .57061 .78247 L F
.56747 .78239 m .56951 .78443 L .57159 .78364 L F
.712 .668 .806 r
.51251 .83151 m .50923 .82971 L .51149 .82916 L F
.51251 .83151 m .51057 .83155 L .50923 .82971 L F
.364 .389 .753 r
.51215 .83376 m .51057 .83155 L .51251 .83151 L F
.817 .769 .808 r
.5146 .82866 m .51251 .83151 L .51149 .82916 L F
.644 .512 .688 r
.51482 .83108 m .51251 .83151 L .5146 .82866 L F
.724 .576 .688 r
.51482 .83108 m .51215 .83376 L .51251 .83151 L F
.625 .826 .978 r
.40457 .88147 m .40115 .88128 L .40314 .88101 L F
.36 .831 .876 r
.40583 .88089 m .40457 .88147 L .40314 .88101 L F
.40583 .88089 m .40652 .88095 L .40457 .88147 L F
.787 .92 .927 r
.58225 .83621 m .58224 .8375 L .58076 .83842 L F
.58225 .83621 m .5841 .83609 L .58224 .8375 L F
.757 .582 .66 r
.52834 .84648 m .52976 .84709 L .52647 .84678 L F
.704 .529 .649 r
.52976 .84709 m .52773 .84901 L .52647 .84678 L F
.52976 .84709 m .5298 .84974 L .52773 .84901 L F
.574 .331 .51 r
.52976 .84709 m .53204 .84687 L .53119 .84918 L F
.52976 .84709 m .53204 .84687 L .53119 .84918 L F
0 0 .092 r
.53119 .84918 m .53204 .84687 L .53305 .84634 L F
.325 0 0 r
.53211 .8474 m .52976 .84709 L .52834 .84648 L F
.53211 .8474 m .53204 .84687 L .52976 .84709 L F
.387 .277 .605 r
.53119 .84918 m .5298 .84974 L .52976 .84709 L F
.686 .763 .91 r
.58941 .77602 m .5927 .77649 L .59093 .77542 L F
.753 .786 .88 r
.59093 .77542 m .5927 .77649 L .59499 .77439 L F
.489 .79 .998 r
.59255 .81514 m .59358 .81598 L .59465 .81531 L F
.237 .129 .522 r
.50209 .82334 m .50203 .8263 L .50111 .8262 L F
.646 .576 .762 r
.50396 .82867 m .50111 .8262 L .50286 .82784 L F
.202 .289 .731 r
.50203 .8263 m .50286 .82784 L .50111 .8262 L F
.429 0 0 r
.58564 .80789 m .58878 .80822 L .5882 .8086 L F
.205 .423 .852 r
.58878 .80822 m .58999 .80735 L .5882 .8086 L F
.58878 .80822 m .5913 .80982 L .58999 .80735 L F
.471 .429 .73 r
.58878 .80822 m .58933 .81008 L .5913 .80982 L F
.193 .721 .84 r
.56612 .7757 m .56241 .7758 L .56333 .77583 L F
.252 .758 .877 r
.56241 .7758 m .56394 .77552 L .56612 .7757 L F
.193 .721 .84 r
.56612 .7757 m .56241 .7758 L .56333 .77583 L F
.712 .582 .708 r
.56333 .77583 m .56617 .77926 L .56612 .7757 L F
0 .398 .792 r
.56612 .7757 m .56828 .77671 L .56721 .77598 L F
.647 .5 .67 r
.56612 .7757 m .56617 .77926 L .56828 .77671 L F
.689 .63 .785 r
.62864 .7429 m .62969 .74582 L .62643 .74512 L F
.739 .657 .768 r
.63168 .74336 m .62969 .74582 L .62864 .7429 L F
.615 .548 .755 r
.59939 .795 m .59859 .79587 L .59619 .79232 L F
0 .192 .722 r
.59619 .79232 m .59859 .79587 L .59816 .79421 L F
.881 .914 .845 r
.59816 .79421 m .59859 .79587 L .59619 .79684 L F
.854 .93 .876 r
.59939 .795 m .59619 .79684 L .59859 .79587 L F
.59939 .795 m .5975 .79737 L .59619 .79684 L F
.571 .457 .685 r
.59939 .795 m .59961 .7972 L .5975 .79737 L F
.539 .304 .506 r
.5975 .79737 m .59944 .79939 L .59771 .79975 L F
.5975 .79737 m .59961 .7972 L .59944 .79939 L F
.603 .597 .818 r
.38229 .74533 m .38026 .74575 L .379 .74297 L F
.977 .885 .67 r
.5643 .82765 m .56421 .82923 L .56324 .83101 L F
.468 .233 .474 r
.36795 .76382 m .36567 .76638 L .36774 .76614 L F
.525 .322 .547 r
.36795 .76382 m .36972 .76576 L .36981 .76344 L F
.36795 .76382 m .36774 .76614 L .36972 .76576 L F
.059 0 0 r
.43926 .87711 m .4389 .87678 L .43724 .8767 L F
.43926 .87711 m .44063 .87649 L .4389 .87678 L F
0 0 0 r
.53428 .83245 m .53686 .83054 L .53589 .83327 L F
.587 .029 0 r
.53686 .83054 m .538 .83202 L .53589 .83327 L F
.53686 .83054 m .53916 .83168 L .538 .83202 L F
.513 .899 .736 r
.53484 .8149 m .53311 .81614 L .53349 .81597 L F
.134 .104 .556 r
.53349 .81597 m .53472 .81646 L .53484 .8149 L F
.53349 .81597 m .53386 .81785 L .53472 .81646 L F
.478 .045 .138 r
.48207 .87663 m .48294 .87813 L .48169 .87709 L F
0 0 .463 r
.38284 .82543 m .38458 .82873 L .38342 .82632 L F
.771 .264 0 r
.38342 .82632 m .38284 .82543 L .38134 .82654 L F
0 0 .463 r
.38284 .82543 m .38342 .82632 L .38134 .82654 L F
.365 .094 .362 r
.50961 .85507 m .51213 .8521 L .51178 .85408 L F
.50961 .85507 m .51213 .8521 L .51178 .85408 L F
.476 .289 .547 r
.51382 .85188 m .51213 .8521 L .51381 .84966 L F
.432 .15 .383 r
.51382 .85188 m .51213 .8521 L .51178 .85408 L F
.476 .289 .547 r
.51382 .85188 m .51213 .8521 L .51381 .84966 L F
.432 .15 .383 r
.51382 .85188 m .51213 .8521 L .51178 .85408 L F
.476 .289 .547 r
.51381 .84966 m .51213 .8521 L .51382 .85188 L F
.607 .436 .624 r
.36981 .76344 m .37191 .76074 L .37009 .76124 L F
0 0 0 r
.50872 .88208 m .51006 .88098 L .51198 .88016 L F
.647 .542 .722 r
.58933 .81008 m .59194 .81325 L .5913 .80982 L F
0 0 .544 r
.55181 .82307 m .55151 .82353 L .55106 .8208 L F
.114 .031 .475 r
.55285 .82513 m .55151 .82353 L .55181 .82307 L F
.55285 .82513 m .55135 .82686 L .55151 .82353 L F
.662 .281 .313 r
.49015 .84427 m .49398 .84364 L .49144 .84491 L F
.336 .708 .983 r
.50286 .82784 m .50487 .82792 L .50396 .82867 L F
.269 .594 .949 r
.50487 .82792 m .50601 .82915 L .50396 .82867 L F
.426 .222 .498 r
.59621 .80776 m .59436 .80796 L .59637 .80535 L F
.59621 .80776 m .59436 .80796 L .59637 .80535 L F
.584 .467 .686 r
.59721 .81003 m .59436 .80796 L .59621 .80776 L F
.59721 .81003 m .59487 .81071 L .59436 .80796 L F
.757 .691 .788 r
.50082 .86438 m .50375 .863 L .50208 .86219 L F
.535 .283 .48 r
.51657 .84999 m .51901 .84723 L .51908 .84904 L F
.685 .579 .731 r
.52098 .84499 m .51901 .84723 L .51803 .84433 L F
.52098 .84499 m .52146 .84736 L .51901 .84723 L F
.674 .41 .513 r
.51901 .84723 m .51787 .84915 L .51908 .84904 L F
.51901 .84723 m .52146 .84736 L .52124 .84921 L F
.51901 .84723 m .52124 .84921 L .51997 .84661 L F
.51901 .84723 m .51997 .84661 L .51787 .84915 L F
.981 .751 .517 r
.49975 .81325 m .49976 .8159 L .49869 .81466 L F
.665 .971 .902 r
.58169 .76529 m .57987 .76645 L .58079 .7652 L F
.646 .949 .951 r
.57987 .76645 m .57902 .76617 L .58079 .7652 L F
.692 .622 .773 r
.62643 .74512 m .62323 .74282 L .62526 .74212 L F
.702 .652 .797 r
.62864 .7429 m .62643 .74512 L .62526 .74212 L F
.329 .778 .956 r
.64778 .74257 m .6467 .74215 L .6445 .74233 L F
.648 .926 .974 r
.64876 .74126 m .64778 .74257 L .64995 .74205 L F
.64876 .74126 m .6467 .74215 L .64778 .74257 L F
.584 .55 .783 r
.64778 .74257 m .65098 .74547 L .64995 .74205 L F
.68 .49 .622 r
.54472 .82459 m .54675 .8263 L .54354 .82658 L F
0 0 .052 r
.51991 .81353 m .52064 .81283 L .52134 .81044 L F
.294 .613 .956 r
.51882 .81245 m .52064 .81283 L .51991 .81353 L F
.699 .448 .54 r
.60394 .80232 m .60537 .80138 L .60589 .8048 L F
.623 .447 .623 r
.60889 .79967 m .60842 .80239 L .60537 .80138 L F
.636 .413 .562 r
.60537 .80138 m .6089 .80408 L .60589 .8048 L F
.60537 .80138 m .60842 .80239 L .6089 .80408 L F
.901 .556 .38 r
.55366 .80296 m .55204 .80338 L .55209 .80225 L F
.55366 .80296 m .55425 .80552 L .55204 .80338 L F
.8 .821 .868 r
.52672 .83212 m .52325 .83294 L .52528 .83263 L F
.026 .172 .681 r
.52794 .83268 m .52812 .83349 L .52672 .83212 L F
.273 .212 .604 r
.52812 .83349 m .52672 .83416 L .52672 .83212 L F
.026 .172 .681 r
.52794 .83268 m .52672 .83212 L .52528 .83263 L F
.338 .735 .983 r
.48294 .87813 m .48203 .87893 L .48169 .87709 L F
.48294 .87813 m .48471 .87898 L .48203 .87893 L F
.495 .333 .59 r
.39078 .75838 m .39089 .76068 L .38896 .76117 L F
.52 .337 .573 r
.39089 .76068 m .38874 .76316 L .38896 .76117 L F
.875 .435 .077 r
.56137 .82308 m .56243 .82367 L .56405 .82691 L F
.77 .412 .378 r
.56426 .79722 m .56748 .7975 L .56556 .799 L F
.371 .828 .735 r
.51096 .87309 m .5075 .8745 L .50975 .87421 L F
.663 .203 .15 r
.51305 .87463 m .51096 .87309 L .50975 .87421 L F
.786 .926 .928 r
.59797 .75624 m .5977 .75498 L .59867 .75553 L F
.59797 .75624 m .59703 .75564 L .5977 .75498 L F
.613 .721 .922 r
.51565 .83598 m .5191 .83677 L .51668 .83714 L F
.624 .624 .83 r
.37273 .73901 m .37582 .74047 L .37379 .74102 L F
.565 .348 .544 r
.66746 .75866 m .66761 .76107 L .66527 .76119 L F
.45 .263 .534 r
.66946 .76031 m .66746 .75866 L .66982 .75864 L F
.66946 .76031 m .66761 .76107 L .66746 .75866 L F
.202 .725 .718 r
.4535 .88574 m .4563 .88507 L .45547 .88524 L F
0 0 0 r
.4563 .88507 m .4575 .88488 L .45547 .88524 L F
.4563 .88507 m .45909 .88423 L .4575 .88488 L F
.378 .828 .713 r
.42169 .89343 m .42076 .894 L .42232 .89321 L F
.379 .843 .844 r
.42169 .89343 m .4196 .89411 L .42076 .894 L F
.246 .385 .806 r
.5227 .87253 m .52228 .87476 L .52091 .87251 L F
.801 .923 .918 r
.52637 .87111 m .52228 .87476 L .5227 .87253 L F
.22 0 .1 r
.52371 .87254 m .5227 .87253 L .52148 .87459 L F
.52456 .87175 m .5227 .87253 L .52371 .87254 L F
.246 .385 .806 r
.5227 .87253 m .52091 .87251 L .52072 .87219 L F
.764 .929 .572 r
.57185 .81219 m .57166 .81309 L .57314 .81077 L F
.752 .407 0 r
.57197 .81448 m .57166 .81309 L .57185 .81219 L F
0 .144 .673 r
.57322 .81621 m .57166 .81309 L .57296 .81666 L F
.965 .72 .283 r
.57145 .81338 m .57197 .81448 L .57185 .81219 L F
.57141 .8135 m .57197 .81448 L .57145 .81338 L F
.752 .407 0 r
.57197 .81448 m .57296 .81666 L .57281 .81627 L F
.57197 .81448 m .57281 .81627 L .57166 .81309 L F
.438 .171 .41 r
.45131 .87303 m .45384 .87075 L .45303 .87279 L F
0 0 0 r
.45303 .87279 m .45384 .87075 L .45463 .87 L F
.993 .868 .534 r
.56393 .83874 m .56421 .84173 L .56363 .84113 L F
.86 .617 .082 r
.56421 .84173 m .56407 .84348 L .56363 .84113 L F
.56421 .84173 m .56447 .84412 L .56407 .84348 L F
.36 .82 .721 r
.44792 .88747 m .45145 .886 L .45015 .88698 L F
.077 0 0 r
.45145 .886 m .45267 .88606 L .45015 .88698 L F
.45145 .886 m .4535 .88574 L .45267 .88606 L F
.549 .567 .826 r
.44946 .87343 m .45125 .87559 L .44919 .87567 L F
.849 .408 0 r
.55857 .81056 m .56054 .81319 L .55959 .81247 L F
.768 .588 .018 r
.56054 .81319 m .56053 .81498 L .55959 .81247 L F
.56054 .81319 m .56065 .81529 L .56053 .81498 L F
.513 .159 .304 r
.65504 .74063 m .65765 .74049 L .65739 .73926 L F
.679 .952 .953 r
.65765 .74049 m .66026 .73984 L .65739 .73926 L F
.635 .677 .873 r
.39442 .8824 m .39064 .88104 L .39285 .88021 L F
.255 .375 .793 r
.39459 .88042 m .39442 .8824 L .39285 .88021 L F
.39459 .88042 m .39587 .88342 L .39442 .8824 L F
.43 .445 .774 r
.51234 .85723 m .51042 .85761 L .50961 .85507 L F
0 0 .038 r
.51057 .85762 m .51042 .85761 L .51234 .85723 L F
.51057 .85762 m .51031 .85989 L .51042 .85761 L F
.067 0 .187 r
.60199 .83133 m .60169 .83317 L .60003 .83401 L F
.191 .063 .466 r
.60169 .83317 m .59995 .83629 L .60003 .83401 L F
.633 .326 .433 r
.51381 .84966 m .5159 .85158 L .51382 .85188 L F
.51381 .84966 m .51657 .84999 L .5159 .85158 L F
.583 .553 .787 r
.51382 .85188 m .51465 .84857 L .51381 .84966 L F
.874 .81 .783 r
.51947 .82 m .52273 .81847 L .52156 .81751 L F
.51947 .82 m .52092 .82078 L .52273 .81847 L F
.653 .463 .614 r
.52273 .81847 m .52092 .82078 L .52317 .82038 L F
.684 .613 .77 r
.64241 .74295 m .63913 .74064 L .64259 .74082 L F
.926 .657 .509 r
.64121 .74433 m .64251 .74522 L .64241 .74295 L F
.525 .574 .847 r
.64561 .74552 m .64241 .74295 L .64251 .74522 L F
.926 .657 .509 r
.64121 .74433 m .64241 .74295 L .6445 .74233 L F
.506 .236 .438 r
.49829 .83906 m .49765 .84131 L .49558 .84162 L F
.464 .196 .422 r
.50021 .83914 m .49765 .84131 L .49829 .83906 L F
.533 .175 .305 r
.36228 .76852 m .36487 .76837 L .36567 .76638 L F
.129 0 .124 r
.36567 .76638 m .36626 .76766 L .36774 .76614 L F
.36567 .76638 m .36487 .76837 L .36626 .76766 L F
.459 .097 .262 r
.58052 .80822 m .58352 .80671 L .58291 .80807 L F
.099 .468 .891 r
.58352 .80671 m .58564 .80789 L .58491 .80686 L F
.23 0 .152 r
.58291 .80807 m .58352 .80671 L .58491 .80686 L F
.62 .563 .768 r
.59819 .7765 m .60009 .77438 L .59718 .77364 L F
.59819 .7765 m .60039 .77614 L .60009 .77438 L F
.664 .52 .678 r
.59829 .77909 m .60039 .77614 L .59819 .7765 L F
.64 .388 .522 r
.52294 .81003 m .52551 .8074 L .52379 .80765 L F
.77 .747 .832 r
.52772 .84353 m .52834 .84648 L .52647 .84678 L F
.46 .51 .823 r
.52969 .84324 m .52834 .84648 L .52772 .84353 L F
.52969 .84324 m .53211 .8474 L .52834 .84648 L F
.434 .388 .709 r
.45303 .87279 m .45332 .87457 L .45131 .87303 L F
.518 .483 .757 r
.59501 .78524 m .59722 .78675 L .59718 .78445 L F
.789 .631 .686 r
.64232 .74735 m .64561 .74552 L .64251 .74522 L F
.64232 .74735 m .64539 .74844 L .64561 .74552 L F
.798 .999 .841 r
.51947 .82 m .5187 .82142 L .52092 .82078 L F
.51947 .82 m .51732 .82191 L .5187 .82142 L F
.172 0 .389 r
.52649 .83632 m .52672 .83416 L .52812 .83349 L F
.672 .421 .532 r
.41794 .84447 m .4175 .84642 L .41411 .84636 L F
.519 .266 .47 r
.42013 .84448 m .4175 .84642 L .41794 .84447 L F
.702 .29 .263 r
.67454 .74712 m .67781 .74743 L .67548 .74554 L F
.468 .854 .645 r
.57576 .79917 m .57847 .79733 L .57816 .79969 L F
.458 .232 .483 r
.58054 .79684 m .57816 .79969 L .57847 .79733 L F
.738 .9 .951 r
.64965 .7297 m .64682 .72951 L .64832 .72794 L F
.64965 .7297 m .64785 .73003 L .64682 .72951 L F
.87 .908 .855 r
.65178 .7265 m .64965 .7297 L .64832 .72794 L F
.527 .736 .97 r
.54272 .8574 m .54529 .85756 L .54453 .85623 L F
.638 .361 .483 r
.54272 .8574 m .54529 .85756 L .54482 .85943 L F
.353 .349 .715 r
.54272 .8574 m .54482 .85943 L .54453 .85623 L F
.704 .863 .957 r
.35823 .76815 m .35822 .76959 L .35686 .76939 L F
.35823 .76815 m .3599 .76874 L .35822 .76959 L F
.318 .061 .357 r
.60464 .78627 m .60256 .78901 L .60314 .78643 L F
.821 .848 .868 r
.61574 .74542 m .61308 .74599 L .61468 .74473 L F
.801 .903 .913 r
.61804 .74361 m .61574 .74542 L .61468 .74473 L F
.6 .793 .973 r
.36087 .74979 m .36223 .75074 L .36227 .74941 L F
.522 .004 0 r
.57058 .78406 m .5723 .7844 L .56951 .78443 L F
.758 .907 .942 r
.60646 .75118 m .60274 .75228 L .60549 .75071 L F
.812 .981 .892 r
.60801 .74987 m .60646 .75118 L .60714 .7495 L F
.77 .939 .937 r
.60646 .75118 m .60549 .75071 L .60714 .7495 L F
.65 .502 .669 r
.39683 .74385 m .39625 .74549 L .39833 .74286 L F
.48 .233 .461 r
.62383 .78201 m .62524 .7834 L .62345 .78385 L F
.62383 .78201 m .62587 .78153 L .62524 .7834 L F
.547 .388 .617 r
.61688 .78938 m .61544 .79148 L .61448 .79165 L F
.522 .306 .527 r
.61448 .79165 m .61694 .79425 L .61495 .79455 L F
.61448 .79165 m .61544 .79148 L .61694 .79425 L F
.512 .89 .966 r
.38517 .83023 m .38193 .83075 L .38458 .82873 L F
.464 0 0 r
.38648 .83089 m .38517 .83023 L .38458 .82873 L F
.664 .292 .33 r
.48766 .83674 m .48584 .8383 L .48381 .83654 L F
.601 .461 .663 r
.40144 .74548 m .40196 .74802 L .39956 .74818 L F
.504 .251 .465 r
.40196 .74802 m .39939 .75033 L .39956 .74818 L F
.601 .461 .663 r
.40144 .74548 m .40196 .74802 L .39956 .74818 L F
.504 .251 .465 r
.40196 .74802 m .39939 .75033 L .39956 .74818 L F
0 0 0 r
.42984 .87487 m .42694 .87571 L .42871 .875 L F
.093 0 0 r
.43087 .87501 m .42984 .87487 L .42871 .875 L F
.43087 .87501 m .43288 .87511 L .42984 .87487 L F
.953 .673 .227 r
.47642 .86561 m .47697 .8676 L .47658 .86523 L F
.47616 .86625 m .47676 .86725 L .47642 .86561 L F
.47676 .86725 m .47697 .8676 L .47642 .86561 L F
.47616 .86625 m .47645 .86556 L .47773 .86521 L F
.191 0 0 r
.47773 .86521 m .47658 .86523 L .47537 .86584 L F
.47773 .86521 m .47641 .86556 L .4775 .862 L F
.47641 .86556 m .47537 .86584 L .47617 .86439 L F
.47641 .86556 m .47617 .86439 L .4775 .862 L F
.439 .838 .978 r
.4408 .88839 m .4438 .88826 L .44292 .88852 L F
.137 .682 .731 r
.4438 .88826 m .44491 .88805 L .44292 .88852 L F
.4438 .88826 m .44587 .88793 L .44491 .88805 L F
.742 .557 .644 r
.51851 .83352 m .51565 .83598 L .51584 .83391 L F
.51745 .83444 m .5191 .83677 L .51565 .83598 L F
.51851 .83352 m .51879 .83508 L .51745 .83444 L F
.51879 .83508 m .5191 .83677 L .51745 .83444 L F
.643 .491 .662 r
.52115 .83396 m .5191 .83677 L .51851 .83352 L F
.664 .345 .423 r
.51584 .83391 m .52003 .83412 L .51851 .83352 L F
.643 .491 .662 r
.52115 .83396 m .51894 .83359 L .51919 .83351 L F
.227 .517 .913 r
.51991 .83327 m .52003 .83412 L .51919 .83351 L F
.643 .565 .752 r
.5192 .82801 m .51944 .82802 L .51938 .82783 L F
.517 .373 .624 r
.51928 .82804 m .51943 .8287 L .51755 .83231 L F
.51943 .8287 m .52029 .83232 L .51988 .83232 L F
.51943 .8287 m .51988 .83232 L .51887 .83231 L F
.83 .597 .586 r
.51936 .82806 m .51941 .82847 L .51944 .82802 L F
.517 .373 .624 r
.5194 .82808 m .52029 .83232 L .51928 .82804 L F
0 0 .296 r
.51944 .82802 m .51941 .82847 L .51946 .82807 L F
.517 .373 .624 r
.51999 .82722 m .52029 .83232 L .51944 .82831 L F
0 0 .296 r
.51944 .82802 m .51946 .82807 L .51947 .82799 L F
.61 .499 .702 r
.5212 .82533 m .52205 .82812 L .51994 .8264 L F
0 0 0 r
.52024 .82679 m .52043 .82717 L .5212 .82533 L F
.517 .373 .624 r
.51999 .82722 m .51944 .82831 L .51947 .82799 L F
0 0 0 r
.51944 .82802 m .51947 .82799 L .52024 .82679 L F
.51947 .82799 m .51998 .82721 L .52024 .82679 L F
.577 .419 .63 r
.52195 .83074 m .51998 .82721 L .52017 .82691 L F
0 0 0 r
.51998 .82721 m .52014 .82698 L .52017 .82691 L F
.51998 .82721 m .52017 .82691 L .52024 .82679 L F
.577 .419 .63 r
.52195 .83074 m .52029 .83232 L .51998 .82721 L F
0 0 0 r
.51944 .82802 m .52021 .82667 L .51938 .82783 L F
.577 .419 .63 r
.52011 .82677 m .51994 .8264 L .52047 .82683 L F
0 0 0 r
.52021 .82667 m .52096 .82536 L .51997 .82691 L F
.52021 .82667 m .51997 .82691 L .51938 .82783 L F
.51944 .82802 m .52024 .82679 L .52015 .82678 L F
.577 .419 .63 r
.52017 .82691 m .51998 .82721 L .51997 .82691 L F
.52011 .82677 m .51997 .82691 L .51994 .8264 L F
.52017 .82691 m .51997 .82691 L .52011 .82677 L F
.517 .373 .624 r
.51997 .82723 m .51947 .82799 L .51949 .82772 L F
.51999 .82722 m .51947 .82799 L .51997 .82723 L F
0 0 0 r
.51947 .82799 m .51964 .82785 L .52014 .82698 L F
.51964 .82785 m .52043 .82717 L .52024 .82679 L F
.577 .419 .63 r
.52195 .83074 m .52017 .82691 L .52205 .82812 L F
.52017 .82691 m .52011 .82677 L .52021 .82684 L F
.52017 .82691 m .52021 .82684 L .52205 .82812 L F
.52011 .82677 m .52047 .82683 L .52205 .82812 L F
0 0 0 r
.52015 .82678 m .5212 .82533 L .52096 .82536 L F
.52024 .82679 m .5212 .82533 L .52015 .82678 L F
.517 .373 .624 r
.51994 .8264 m .51999 .82722 L .51935 .82786 L F
0 0 0 r
.51664 .82787 m .51875 .82566 L .51994 .8264 L F
.83 .597 .586 r
.51928 .82804 m .5192 .82801 L .51664 .82787 L F
.643 .565 .752 r
.51664 .82787 m .5192 .82801 L .51917 .82786 L F
.517 .373 .624 r
.51994 .8264 m .51935 .82786 L .51664 .82787 L F
.643 .565 .752 r
.51664 .82787 m .51917 .82786 L .51875 .82566 L F
.5192 .82801 m .51938 .82783 L .51875 .82566 L F
.517 .373 .624 r
.51935 .82786 m .51928 .82804 L .51664 .82787 L F
.51928 .82804 m .51755 .83231 L .51664 .82787 L F
.83 .597 .586 r
.51936 .82806 m .51928 .82804 L .51664 .82787 L F
.61 .499 .702 r
.5212 .82533 m .51994 .8264 L .51875 .82566 L F
0 0 0 r
.51938 .82783 m .52096 .82536 L .51875 .82566 L F
.517 .373 .624 r
.51949 .82772 m .51944 .82831 L .51935 .82787 L F
.51938 .82783 m .51935 .82787 L .51935 .82786 L F
.51949 .82772 m .51935 .82787 L .51938 .82783 L F
0 0 .296 r
.51947 .82799 m .52034 .82954 L .52043 .82717 L F
.51946 .82807 m .52034 .82954 L .51947 .82799 L F
.51946 .82807 m .51925 .83079 L .52034 .82954 L F
.51941 .82847 m .51925 .83079 L .51946 .82807 L F
.517 .373 .624 r
.51935 .82885 m .51887 .83231 L .51755 .83231 L F
.51943 .8287 m .51887 .83231 L .51935 .82885 L F
.659 .522 .686 r
.51664 .82787 m .51755 .83231 L .51482 .83108 L F
.83 .597 .586 r
.51551 .83011 m .51925 .83079 L .51941 .82847 L F
.51551 .83011 m .51941 .82847 L .51936 .82806 L F
.51551 .83011 m .51936 .82806 L .51664 .82787 L F
.51936 .82806 m .51944 .82802 L .5192 .82801 L F
.517 .373 .624 r
.51935 .82786 m .5194 .82808 L .51928 .82804 L F
.697 .585 .726 r
.51866 .83178 m .52034 .82954 L .51925 .83079 L F
.227 .517 .913 r
.51991 .83327 m .51755 .83231 L .52029 .83232 L F
.697 .585 .726 r
.51804 .8328 m .5191 .8313 L .51866 .83178 L F
.5191 .8313 m .52034 .82954 L .51866 .83178 L F
.227 .517 .913 r
.51991 .83327 m .51919 .83351 L .51792 .83258 L F
.518 .83249 m .51792 .83258 L .51755 .83231 L F
.51991 .83327 m .51792 .83258 L .518 .83249 L F
.643 .491 .662 r
.51919 .83351 m .51851 .83352 L .51893 .83345 L F
.51894 .83359 m .51851 .83352 L .51919 .83351 L F
.52114 .83395 m .51893 .83345 L .51991 .83327 L F
.52115 .83396 m .51893 .83345 L .52114 .83395 L F
.688 .607 .76 r
.51755 .83231 m .51919 .83351 L .51741 .83252 L F
.51919 .83351 m .52003 .83412 L .51893 .83345 L F
.51919 .83351 m .51893 .83345 L .51741 .83252 L F
.284 .569 .935 r
.51893 .83345 m .52003 .83412 L .51991 .83327 L F
.51851 .83352 m .52003 .83412 L .51893 .83345 L F
.688 .607 .76 r
.51741 .83252 m .52003 .83412 L .51639 .83394 L F
.51601 .83375 m .51639 .83394 L .51584 .83391 L F
.51755 .83231 m .51639 .83394 L .51601 .83375 L F
.397 .019 .2 r
.65019 .76634 m .64943 .76824 L .64722 .76867 L F
.229 0 .13 r
.65137 .76736 m .65019 .76634 L .6524 .76615 L F
.65137 .76736 m .64943 .76824 L .65019 .76634 L F
.622 .447 .625 r
.37194 .75849 m .3741 .75829 L .37416 .75589 L F
.621 .483 .673 r
.3741 .75829 m .37614 .7555 L .37416 .75589 L F
.618 .531 .733 r
.52352 .84447 m .52146 .84736 L .52098 .84499 L F
.52352 .84447 m .52308 .84703 L .52146 .84736 L F
.541 .278 .466 r
.52146 .84736 m .52332 .84896 L .52124 .84921 L F
.52146 .84736 m .52308 .84703 L .52326 .84847 L F
.52146 .84736 m .52326 .84847 L .52289 .84859 L F
.58 .585 .822 r
.5212 .84912 m .52211 .84607 L .51997 .84661 L F
.52124 .84921 m .52127 .8491 L .5212 .84912 L F
.52127 .8491 m .52211 .84607 L .5212 .84912 L F
.541 .278 .466 r
.52289 .84859 m .52326 .84847 L .52332 .84896 L F
.722 .63 .754 r
.64161 .73837 m .64259 .74082 L .63913 .74064 L F
.752 .667 .767 r
.6434 .73728 m .64259 .74082 L .64161 .73837 L F
.715 .661 .796 r
.36645 .73379 m .36411 .73506 L .36286 .73221 L F
0 0 .184 r
.65358 .73021 m .65454 .72921 L .65296 .73205 L F
.546 .12 .185 r
.40984 .82781 m .41306 .82648 L .41122 .82609 L F
0 0 0 r
.50862 .8367 m .50833 .83657 L .51057 .83613 L F
.50862 .8367 m .50712 .83749 L .50833 .83657 L F
.531 .046 .051 r
.49581 .80937 m .4982 .81 L .49916 .80901 L F
.547 .065 .062 r
.49916 .80901 m .4982 .81 L .50155 .80991 L F
.751 .664 .765 r
.63606 .74017 m .63715 .74313 L .63392 .74276 L F
.749 .663 .766 r
.63913 .74064 m .63715 .74313 L .63606 .74017 L F
.972 .713 .483 r
.59621 .80776 m .59637 .80535 L .59513 .80688 L F
.371 .19 .501 r
.59815 .80516 m .59637 .80535 L .59785 .80264 L F
.214 0 0 r
.59513 .80688 m .59637 .80535 L .59815 .80516 L F
.133 .077 .522 r
.60319 .82814 m .60199 .83133 L .60102 .82882 L F
.60319 .82814 m .6034 .83059 L .60199 .83133 L F
.145 0 .31 r
.6034 .83059 m .60169 .83317 L .60199 .83133 L F
.486 .879 .963 r
.41484 .89488 m .41302 .8957 L .41519 .89522 L F
.41484 .89488 m .41186 .89562 L .41302 .8957 L F
.66 .963 .927 r
.39392 .89995 m .39718 .89879 L .39609 .8987 L F
.393 .845 .911 r
.39609 .8987 m .39718 .89879 L .39904 .89829 L F
.448 .186 .423 r
.67433 .7531 m .67413 .75541 L .67191 .75548 L F
.502 .374 .638 r
.67649 .74973 m .67604 .75226 L .67433 .7531 L F
.461 .225 .468 r
.67604 .75226 m .67413 .75541 L .67433 .7531 L F
.568 .178 .262 r
.44193 .82313 m .44414 .82324 L .44532 .82158 L F
.565 .175 .261 r
.44532 .82158 m .44414 .82324 L .44724 .82271 L F
.819 .558 .545 r
.6414 .75858 m .64218 .76062 L .64359 .7607 L F
.507 .212 .401 r
.64078 .7635 m .64359 .7607 L .64218 .76062 L F
.64078 .7635 m .64296 .76323 L .64359 .7607 L F
.441 .152 .377 r
.64359 .7607 m .6451 .76275 L .64589 .76091 L F
.64359 .7607 m .64296 .76323 L .6451 .76275 L F
.201 0 0 r
.67872 .74811 m .67772 .74975 L .67649 .74973 L F
.993 .754 .464 r
.67781 .74743 m .67772 .74975 L .67872 .74811 L F
.622 .267 .347 r
.4878 .81822 m .48991 .81858 L .49127 .81764 L F
.655 .316 .386 r
.49127 .81764 m .48991 .81858 L .49312 .81817 L F
.817 .769 .808 r
.5146 .82866 m .51149 .82916 L .51364 .82865 L F
.67 .264 .268 r
.51364 .82865 m .51664 .82787 L .5146 .82866 L F
.659 .522 .686 r
.51664 .82787 m .51482 .83108 L .5146 .82866 L F
.449 .189 .427 r
.38215 .86785 m .38164 .86993 L .38019 .87038 L F
.132 0 .006 r
.38019 .87038 m .38164 .86993 L .37971 .87108 L F
.88 .87 .823 r
.53271 .82827 m .53397 .82895 L .53229 .83087 L F
.797 .727 .787 r
.53448 .82527 m .53397 .82895 L .53271 .82827 L F
.53448 .82527 m .53608 .82653 L .53397 .82895 L F
.535 .192 .333 r
.4432 .83623 m .44203 .83863 L .43998 .83859 L F
.597 .258 .365 r
.44509 .83813 m .4432 .83623 L .44548 .83603 L F
.44509 .83813 m .44203 .83863 L .4432 .83623 L F
.498 0 0 r
.48685 .88809 m .48986 .88921 L .48882 .88908 L F
.258 .745 .922 r
.48986 .88921 m .49066 .88873 L .48882 .88908 L F
.48986 .88921 m .4921 .88909 L .49066 .88873 L F
.342 0 0 r
.43466 .82398 m .43671 .82438 L .43772 .8233 L F
.54 .075 .098 r
.43671 .82438 m .43988 .82333 L .43772 .8233 L F
.718 .693 .825 r
.51977 .84161 m .52052 .84432 L .51803 .84433 L F
.727 .541 .64 r
.52052 .84432 m .52098 .84499 L .51803 .84433 L F
.649 .65 .838 r
.52202 .84175 m .52052 .84432 L .51977 .84161 L F
.635 .607 .805 r
.52202 .84175 m .52098 .84499 L .52052 .84432 L F
.827 .659 .674 r
.6384 .75069 m .64075 .7533 L .64036 .74998 L F
.6384 .75069 m .6406 .75402 L .64075 .7533 L F
.7 .633 .779 r
.64036 .74998 m .64075 .7533 L .64361 .75052 L F
.51 .437 .71 r
.47449 .87021 m .47487 .87257 L .47296 .87284 L F
.77 .901 .934 r
.57228 .83513 m .57334 .83656 L .57086 .83673 L F
.976 .72 .477 r
.57171 .83679 m .57334 .83656 L .57169 .83673 L F
.261 .668 .966 r
.57343 .83885 m .57193 .83761 L .57334 .83656 L F
.57193 .83761 m .57105 .83688 L .57171 .83679 L F
.57193 .83761 m .57171 .83679 L .57334 .83656 L F
.976 .72 .477 r
.57179 .83705 m .57334 .83656 L .57171 .83679 L F
.261 .668 .966 r
.57196 .83772 m .57024 .83781 L .57081 .83683 L F
.57343 .83885 m .57214 .83843 L .57196 .83772 L F
.57214 .83843 m .57024 .83781 L .57196 .83772 L F
.57343 .83885 m .57081 .83683 L .57105 .83688 L F
.976 .72 .477 r
.57222 .8384 m .57289 .8373 L .57179 .83705 L F
0 0 .264 r
.57171 .83679 m .57169 .83673 L .57169 .83672 L F
.777 .904 .929 r
.57169 .83673 m .57334 .83656 L .5717 .8367 L F
.261 .668 .966 r
.57105 .83688 m .57091 .83677 L .57334 .83656 L F
.57091 .83677 m .57086 .83673 L .57334 .83656 L F
.777 .904 .929 r
.5717 .8367 m .57334 .83656 L .57228 .83513 L F
0 0 .264 r
.57222 .8384 m .57179 .83705 L .57168 .83627 L F
.57179 .83705 m .57171 .83679 L .5717 .83671 L F
.57179 .83705 m .5717 .83671 L .57168 .83627 L F
.976 .72 .477 r
.57289 .8373 m .57334 .83656 L .57179 .83705 L F
.261 .668 .966 r
.57105 .83688 m .57081 .83683 L .57086 .83673 L F
.774 .875 .448 r
.57168 .83627 m .57169 .83673 L .57228 .83513 L F
0 0 .264 r
.57171 .83679 m .57169 .83672 L .57168 .83627 L F
.976 .72 .477 r
.57222 .8384 m .57343 .83885 L .57334 .83656 L F
.636 .635 .832 r
.38847 .88578 m .38645 .88635 L .38578 .88391 L F
.622 .263 .34 r
.4504 .82241 m .45251 .82277 L .45061 .82118 L F
.745 .524 0 r
.58172 .77523 m .58167 .77438 L .58083 .7743 L F
.58172 .77523 m .58208 .77716 L .58167 .77438 L F
.484 .248 .481 r
.36353 .78183 m .36322 .78402 L .36123 .78444 L F
.537 .295 .496 r
.36518 .78365 m .36353 .78183 L .36551 .78152 L F
.36518 .78365 m .36322 .78402 L .36353 .78183 L F
.662 .281 .313 r
.49015 .84427 m .49236 .84591 L .49398 .84364 L F
.595 .546 .769 r
.49518 .84279 m .49398 .84364 L .49278 .84084 L F
0 0 0 r
.49518 .84279 m .49428 .84364 L .49398 .84364 L F
.631 .926 .973 r
.46077 .87323 m .4595 .87458 L .45849 .87473 L F
.46077 .87323 m .46224 .87362 L .4595 .87458 L F
.6 .411 .597 r
.37191 .76074 m .3741 .75829 L .37194 .75849 L F
.706 .983 .891 r
.59033 .80423 m .58803 .80555 L .58999 .80735 L F
.54 .469 .725 r
.59228 .80207 m .59247 .80472 L .59033 .80423 L F
.578 .274 .417 r
.59198 .80684 m .59033 .80423 L .58999 .80735 L F
.59198 .80684 m .59247 .80472 L .59033 .80423 L F
.54 .469 .725 r
.59033 .80423 m .59247 .80472 L .59228 .80207 L F
.725 .732 .857 r
.53762 .82519 m .53608 .82653 L .53448 .82527 L F
.653 .9 .982 r
.37917 .83146 m .37753 .83235 L .37701 .83244 L F
.444 .807 .995 r
.38536 .82552 m .38886 .82588 L .38673 .82613 L F
.485 .343 .613 r
.38863 .82826 m .38673 .82613 L .38886 .82588 L F
.707 .627 .766 r
.51057 .83613 m .5116 .83906 L .51407 .83733 L F
.736 .664 .778 r
.63082 .74206 m .63168 .74336 L .62864 .7429 L F
.658 .638 .818 r
.63392 .74276 m .63168 .74336 L .63082 .74206 L F
0 0 .267 r
.64205 .76021 m .64218 .76062 L .6414 .75858 L F
.64205 .76021 m .6414 .75858 L .6401 .75771 L F
.615 .548 .755 r
.59939 .795 m .59619 .79232 L .59832 .79198 L F
0 .192 .722 r
.59619 .79232 m .59816 .79421 L .59832 .79198 L F
.297 0 0 r
.51739 .87767 m .51939 .87758 L .51644 .87825 L F
.008 .526 .858 r
.67747 .7299 m .67737 .72959 L .67508 .72885 L F
.834 .387 .164 r
.67508 .72885 m .67747 .7299 L .67653 .73059 L F
.765 .949 .621 r
.67747 .7299 m .67737 .72959 L .67653 .73059 L F
.512 .28 .5 r
.62146 .78429 m .6232 .78568 L .62086 .78621 L F
.62146 .78429 m .62345 .78385 L .6232 .78568 L F
.412 .027 .196 r
.67045 .75043 m .67262 .75013 L .67315 .74853 L F
.539 .376 .608 r
.67262 .75013 m .67454 .74712 L .67315 .74853 L F
.438 .872 .907 r
.42331 .89271 m .42837 .89181 L .42701 .89159 L F
.581 .92 .965 r
.42701 .89159 m .42837 .89181 L .43016 .89101 L F
.254 .25 .662 r
.59945 .80072 m .59785 .80264 L .59771 .79975 L F
.063 0 .442 r
.59815 .80516 m .59785 .80264 L .59945 .80072 L F
.751 .974 .924 r
.60801 .74987 m .6098 .74768 L .61054 .74788 L F
.60801 .74987 m .60714 .7495 L .6098 .74768 L F
.403 .435 .78 r
.38878 .75493 m .38732 .75608 L .38652 .75311 L F
.598 .837 .99 r
.388 .75548 m .38732 .75608 L .38878 .75493 L F
.617 .593 .804 r
.39078 .75838 m .38732 .75608 L .388 .75548 L F
.272 0 0 r
.51699 .87343 m .51609 .87244 L .51482 .87388 L F
.51699 .87343 m .51839 .87225 L .51609 .87244 L F
.693 .738 .886 r
.64699 .73683 m .64661 .73772 L .6434 .73728 L F
.707 .755 .89 r
.64937 .7369 m .64661 .73772 L .64699 .73683 L F
.308 0 0 r
.52072 .87219 m .51839 .87225 L .52056 .87287 L F
.246 .385 .806 r
.5227 .87253 m .52072 .87219 L .52056 .87287 L F
.79 .65 .707 r
.50431 .85718 m .5058 .85983 L .50618 .85946 L F
0 .06 .625 r
.5058 .85983 m .50755 .86226 L .50618 .85946 L F
.449 .189 .427 r
.38215 .86785 m .38174 .86991 L .38164 .86993 L F
.721 .602 .723 r
.3841 .86505 m .38215 .86785 L .38186 .86531 L F
.582 .416 .623 r
.38421 .8675 m .38215 .86785 L .3841 .86505 L F
.644 .367 .485 r
.38395 .86966 m .38215 .86785 L .38421 .8675 L F
.38395 .86966 m .38174 .86991 L .38215 .86785 L F
.607 .362 .519 r
.38447 .83066 m .38458 .82873 L .38193 .83075 L F
.61 .607 .823 r
.38458 .82873 m .38536 .82552 L .38342 .82632 L F
.603 .368 .533 r
.38648 .83089 m .38687 .82871 L .38458 .82873 L F
.616 .369 .521 r
.38447 .83066 m .38648 .83089 L .38458 .82873 L F
.603 .368 .533 r
.38648 .83089 m .38687 .82871 L .38458 .82873 L F
.595 .589 .816 r
.54248 .8316 m .53907 .8288 L .54144 .82834 L F
.373 .404 .764 r
.54144 .82834 m .54248 .8316 L .54345 .83114 L F
.732 .287 .194 r
.54248 .8316 m .54476 .83356 L .54145 .83299 L F
.365 .382 .745 r
.54345 .83114 m .54476 .83356 L .54248 .8316 L F
.568 .367 .568 r
.61176 .79481 m .61276 .79712 L .61027 .79743 L F
.537 .32 .533 r
.61176 .79481 m .61493 .79669 L .61276 .79712 L F
.61176 .79481 m .61495 .79455 L .61493 .79669 L F
.875 .64 .58 r
.52647 .84678 m .52773 .84901 L .52654 .84967 L F
.517 0 0 r
.52773 .84901 m .52928 .85008 L .52654 .84967 L F
.52773 .84901 m .5298 .84974 L .52928 .85008 L F
.225 0 .114 r
.40409 .74349 m .40267 .74545 L .40144 .74548 L F
.626 .804 .968 r
.40583 .74272 m .40409 .74349 L .40245 .74219 L F
.21 0 .103 r
.40583 .74272 m .40267 .74545 L .40409 .74349 L F
.934 .957 .765 r
.58077 .77762 m .58208 .77716 L .58172 .77523 L F
.128 0 0 r
.45909 .88423 m .45956 .88477 L .4575 .88488 L F
.45909 .88423 m .46115 .88382 L .45956 .88477 L F
0 0 0 r
.64789 .7602 m .65055 .75845 L .65096 .75777 L F
.65096 .75777 m .65055 .75845 L .65239 .75691 L F
.817 .741 .78 r
.48521 .85486 m .48281 .85478 L .48416 .85254 L F
.767 .4 .361 r
.48521 .85486 m .48318 .85652 L .48281 .85478 L F
.164 .365 .816 r
.48599 .85389 m .48521 .85486 L .48416 .85254 L F
.594 .899 .623 r
.48599 .85389 m .48318 .85652 L .48521 .85486 L F
.77 .412 .378 r
.56426 .79722 m .5679 .79928 L .56748 .7975 L F
0 0 0 r
.56844 .78967 m .56635 .7923 L .56739 .7914 L F
.768 .356 .269 r
.56635 .7923 m .56847 .79497 L .56568 .79401 L F
.56635 .7923 m .56568 .79401 L .56739 .7914 L F
.549 .335 .543 r
.56748 .7975 m .5679 .79928 L .56998 .79734 L F
.584 .47 .689 r
.59526 .78909 m .59743 .78904 L .59722 .78675 L F
.619 .31 .425 r
.40581 .85151 m .40493 .85408 L .40279 .85234 L F
.733 .514 .595 r
.40845 .85148 m .40493 .85408 L .40581 .85151 L F
.388 .845 .899 r
.6002 .82871 m .59892 .82939 L .59806 .82804 L F
.6002 .82871 m .60102 .82882 L .59892 .82939 L F
.639 .708 .896 r
.59194 .81325 m .5945 .81296 L .5945 .81296 L F
0 0 0 r
.5945 .81296 m .5945 .81296 L .5945 .81296 L F
.226 .456 .872 r
.5945 .81296 m .5945 .81296 L .5945 .81296 L F
.391 0 0 r
.5945 .81296 m .5945 .81296 L .59194 .81325 L F
.633 .453 .622 r
.59504 .81289 m .59504 .8129 L .59194 .81325 L F
.59504 .8129 m .59505 .81294 L .59194 .81325 L F
.723 .531 .63 r
.59505 .81294 m .59255 .81514 L .59194 .81325 L F
.391 0 0 r
.59337 .81444 m .5945 .81296 L .59194 .81325 L F
.63 .491 .674 r
.59721 .81003 m .59505 .81294 L .59487 .81071 L F
0 0 0 r
.59552 .81169 m .5945 .81296 L .59337 .81444 L F
.5945 .81296 m .5945 .81296 L .59337 .81444 L F
.633 .453 .622 r
.59487 .81071 m .595 .81232 L .5945 .81296 L F
.595 .81232 m .59504 .81289 L .5945 .81296 L F
.595 .81232 m .5945 .81296 L .5945 .81296 L F
.59324 .81212 m .5945 .81296 L .59194 .81325 L F
.59487 .81071 m .5945 .81296 L .59324 .81212 L F
.226 .456 .872 r
.59303 .8101 m .5945 .81296 L .59552 .81169 L F
.5945 .81296 m .5945 .81296 L .59552 .81169 L F
.639 .708 .896 r
.59194 .81325 m .5945 .81296 L .59303 .8101 L F
.527 .033 .027 r
.41306 .82648 m .41511 .82734 L .41651 .82629 L F
.248 0 0 r
.41511 .82734 m .41864 .82658 L .41651 .82629 L F
.639 .708 .896 r
.59194 .81325 m .59303 .8101 L .5913 .80982 L F
.391 0 0 r
.59337 .81444 m .59194 .81325 L .59255 .81514 L F
.687 .601 .754 r
.64995 .74205 m .65098 .74547 L .65351 .74315 L F
.572 .558 .8 r
.52092 .82078 m .52343 .82381 L .52317 .82038 L F
.902 .503 .089 r
.52306 .82434 m .52411 .8257 L .52343 .82381 L F
.704 .604 .742 r
.52317 .82038 m .52343 .82381 L .52536 .82024 L F
.731 .457 .513 r
.47892 .83623 m .47723 .83883 L .47522 .8363 L F
.683 .396 .481 r
.48051 .83856 m .47723 .83883 L .47892 .83623 L F
.699 .399 .464 r
.48041 .83671 m .48051 .83856 L .47892 .83623 L F
.966 .771 .332 r
.60895 .783 m .60868 .78699 L .60784 .78446 L F
.647 .666 .854 r
.35437 .73022 m .35219 .73116 L .35117 .72906 L F
.758 .653 .746 r
.52224 .83569 m .5191 .83677 L .52115 .83396 L F
.603 .546 .764 r
.52198 .83839 m .5191 .83677 L .52224 .83569 L F
.82 .545 .522 r
.52115 .83396 m .52436 .83653 L .52224 .83569 L F
.728 .447 .501 r
.52224 .83569 m .52389 .83836 L .52198 .83839 L F
.52224 .83569 m .52436 .83653 L .52389 .83836 L F
.799 .94 .92 r
.60119 .75355 m .59867 .75553 L .5977 .75498 L F
.57 .893 .987 r
.39875 .88316 m .39587 .88342 L .39792 .88294 L F
.875 .979 .84 r
.39875 .88316 m .4 .88049 L .40115 .88128 L F
.39875 .88316 m .39792 .88294 L .4 .88049 L F
.185 .716 .736 r
.48866 .87835 m .48764 .87862 L .48626 .87858 L F
.48866 .87835 m .48973 .87818 L .48764 .87862 L F
0 .357 .685 r
.53783 .80679 m .53885 .80717 L .54014 .80768 L F
.538 0 0 r
.54126 .80883 m .54014 .80768 L .53885 .80717 L F
.54126 .80883 m .54289 .80948 L .54014 .80768 L F
.463 .855 .976 r
.49482 .87726 m .49287 .87773 L .49168 .87744 L F
.675 .38 .466 r
.4838 .83826 m .48041 .83671 L .48381 .83654 L F
.612 .318 .446 r
.48381 .83654 m .48584 .8383 L .4838 .83826 L F
.543 .565 .827 r
.39218 .75688 m .39078 .75838 L .388 .75548 L F
.39218 .75688 m .3927 .75819 L .39078 .75838 L F
.593 .444 .649 r
.3927 .75819 m .39089 .76068 L .39078 .75838 L F
.511 .206 .385 r
.64092 .77085 m .63977 .77345 L .63756 .7737 L F
.426 .088 .288 r
.64258 .77079 m .63977 .77345 L .64092 .77085 L F
.635 .607 .805 r
.52202 .84175 m .52352 .84447 L .52098 .84499 L F
.789 .631 .686 r
.64232 .74735 m .64361 .75052 L .64539 .74844 L F
.689 .581 .728 r
.53151 .82094 m .5348 .82089 L .53386 .81785 L F
.464 .294 .564 r
.53151 .82094 m .53364 .82287 L .5348 .82089 L F
.53151 .82094 m .53181 .8234 L .53364 .82287 L F
.624 .411 .572 r
.51941 .83901 m .51977 .84161 L .51698 .84141 L F
.603 .546 .764 r
.52198 .83839 m .51941 .83901 L .5191 .83677 L F
.344 .114 .414 r
.52198 .83839 m .51977 .84161 L .51941 .83901 L F
.645 .826 .97 r
.38308 .87471 m .38121 .87554 L .38161 .87531 L F
0 0 0 r
.38087 .87584 m .38161 .87531 L .38121 .87554 L F
.63 .682 .88 r
.38383 .88247 m .3832 .88465 L .38205 .883 L F
.38383 .88247 m .38578 .88391 L .3832 .88465 L F
.177 .701 .868 r
.35673 .75037 m .35301 .7502 L .35362 .74997 L F
.629 .931 .969 r
.35623 .74911 m .35456 .75002 L .35673 .75037 L F
.262 0 0 r
.35578 .74983 m .35456 .75002 L .35623 .74911 L F
.177 .701 .868 r
.35673 .75037 m .35456 .75002 L .35328 .75021 L F
.262 0 0 r
.35501 .75106 m .35456 .75002 L .35578 .74983 L F
.177 .701 .868 r
.35328 .75021 m .35456 .75002 L .35301 .7502 L F
.629 .931 .969 r
.35623 .74911 m .35673 .75037 L .35839 .74925 L F
.131 .672 .835 r
.57415 .77585 m .57253 .77566 L .5704 .77572 L F
.233 .729 .913 r
.57528 .77591 m .57253 .77566 L .57415 .77585 L F
.611 .402 .574 r
.38699 .86487 m .38421 .8675 L .3841 .86505 L F
.567 .151 .211 r
.50477 .81068 m .50682 .81213 L .50807 .81008 L F
.609 .202 .246 r
.50682 .81213 m .50998 .8106 L .50807 .81008 L F
.572 .462 .69 r
.48771 .8677 m .48976 .86723 L .48727 .86711 L F
.207 .692 .929 r
.4882 .86662 m .48727 .86711 L .48771 .8677 L F
.4882 .86662 m .48976 .86723 L .48727 .86711 L F
0 0 0 r
.46411 .88308 m .46622 .88256 L .46511 .88298 L F
.46318 .88352 m .46411 .88308 L .46511 .88298 L F
.181 0 0 r
.50854 .85516 m .50708 .85485 L .50302 .85412 L F
.686 .616 .772 r
.50961 .85507 m .50708 .85485 L .509 .85426 L F
.461 .298 .573 r
.509 .85426 m .50708 .85485 L .50854 .85516 L F
.58 .682 .911 r
.36953 .73482 m .36645 .73379 L .36845 .73358 L F
.317 .482 .865 r
.37028 .73352 m .36953 .73482 L .36845 .73358 L F
.37028 .73352 m .37078 .73489 L .36953 .73482 L F
.363 .294 .645 r
.37078 .73489 m .37129 .73726 L .36953 .73482 L F
.712 .582 .708 r
.56333 .77583 m .56629 .78187 L .56617 .77926 L F
.608 .32 .454 r
.66527 .76119 m .66503 .7628 L .66272 .76285 L F
.312 0 .162 r
.66761 .76107 m .66503 .7628 L .66527 .76119 L F
.332 0 0 r
.46622 .88256 m .46953 .88244 L .46832 .88236 L F
.024 .597 .722 r
.46953 .88244 m .47034 .88241 L .46832 .88236 L F
.46953 .88244 m .47157 .88241 L .47034 .88241 L F
.772 .927 .937 r
.58945 .76127 m .59009 .75949 L .59199 .75925 L F
.58945 .76127 m .58842 .76073 L .59009 .75949 L F
.256 .194 .593 r
.653 .7557 m .65503 .75449 L .65434 .75257 L F
0 0 0 r
.65239 .75691 m .65503 .75449 L .653 .7557 L F
.497 .813 1 r
.45448 .87591 m .45125 .87559 L .45332 .87457 L F
.59 .716 .931 r
.45332 .87457 m .45656 .87551 L .45448 .87591 L F
.468 0 0 r
.5622 .79748 m .56325 .79866 L .56426 .79722 L F
.5622 .79748 m .56153 .7979 L .56325 .79866 L F
.147 0 0 r
.56844 .78967 m .56984 .78975 L .5713 .78872 L F
.56844 .78967 m .56739 .7914 L .56984 .78975 L F
.926 .973 .751 r
.58988 .77883 m .58858 .78211 L .58756 .77904 L F
.58988 .77883 m .58803 .7818 L .58858 .78211 L F
.52 .314 .541 r
.37251 .83238 m .37183 .8327 L .37102 .83344 L F
.608 .93 .705 r
.59068 .83375 m .58883 .83555 L .58822 .83577 L F
.59068 .83375 m .59128 .83351 L .58883 .83555 L F
.831 .701 .72 r
.63094 .75549 m .6305 .75821 L .6332 .75791 L F
.784 .49 .489 r
.6305 .75821 m .631 .75995 L .6332 .75791 L F
.657 .587 .765 r
.6332 .75791 m .63505 .75655 L .63094 .75549 L F
.6332 .75791 m .63436 .75749 L .63505 .75655 L F
.746 .432 .451 r
.631 .75995 m .63411 .76037 L .6332 .75791 L F
.523 .326 .554 r
.39407 .82578 m .39424 .82352 L .39624 .82316 L F
.39407 .82578 m .39424 .82352 L .39624 .82316 L F
.866 .837 .816 r
.5832 .8343 m .5841 .83609 L .58225 .83621 L F
.405 .603 .928 r
.58613 .83639 m .5841 .83609 L .5832 .8343 L F
.656 .281 .323 r
.45921 .8339 m .45791 .83537 L .45605 .83382 L F
.38 0 .029 r
.46135 .83377 m .45791 .83537 L .45921 .8339 L F
.724 .576 .688 r
.51482 .83108 m .51584 .83391 L .51215 .83376 L F
.688 .607 .76 r
.51755 .83231 m .51584 .83391 L .51482 .83108 L F
.491 .26 .491 r
.67191 .75548 m .67191 .7583 L .66982 .75864 L F
.5 .286 .52 r
.67413 .75541 m .67191 .7583 L .67191 .75548 L F
.347 0 .105 r
.54588 .79302 m .5462 .79401 L .54712 .79254 L F
.763 .343 0 r
.54588 .79302 m .54705 .79537 L .5462 .79401 L F
.634 .571 .766 r
.38652 .75311 m .38445 .75357 L .38345 .75065 L F
.432 0 .047 r
.47165 .81744 m .47072 .81806 L .47357 .81746 L F
.736 .596 .7 r
.54354 .82658 m .54454 .82868 L .54144 .82834 L F
.373 .404 .764 r
.54144 .82834 m .54332 .83044 L .54454 .82868 L F
.693 .578 .722 r
.54675 .8263 m .54454 .82868 L .54354 .82658 L F
.745 .673 .78 r
.63801 .73768 m .63913 .74064 L .63606 .74017 L F
.746 .673 .78 r
.64161 .73837 m .63913 .74064 L .63801 .73768 L F
.21 0 0 r
.58518 .84851 m .58646 .8474 L .58855 .84698 L F
.88 .87 .823 r
.53271 .82827 m .53229 .83087 L .53088 .83044 L F
0 .183 .685 r
.53229 .83087 m .53292 .83105 L .53088 .83044 L F
.53229 .83087 m .53365 .83196 L .53292 .83105 L F
.792 .834 .884 r
.53292 .83105 m .53456 .83042 L .5319 .83003 L F
.85 .756 .759 r
.5319 .83003 m .53456 .83042 L .53218 .83137 L F
.532 .65 .91 r
.53456 .83042 m .53527 .82825 L .53278 .83076 L F
.272 .272 .677 r
.53218 .83134 m .53088 .83044 L .53292 .83105 L F
.565 .571 .818 r
.5319 .83003 m .53217 .83134 L .53218 .83133 L F
.272 .272 .677 r
.53215 .83136 m .53212 .83133 L .53218 .83134 L F
.53212 .83133 m .53088 .83044 L .53218 .83134 L F
.5312 .83174 m .53117 .83158 L .53215 .83136 L F
.792 .834 .884 r
.53218 .83134 m .5319 .83003 L .5312 .83174 L F
.53292 .83105 m .5319 .83003 L .53218 .83134 L F
.565 .571 .818 r
.5319 .83003 m .53218 .83133 L .53388 .82873 L F
.53217 .83134 m .53218 .83137 L .53219 .83135 L F
.53217 .83134 m .53219 .83135 L .53388 .82873 L F
.272 .272 .677 r
.53117 .83158 m .53088 .83044 L .53215 .83136 L F
.532 .65 .91 r
.53299 .83105 m .53278 .83076 L .5322 .83134 L F
.53231 .83132 m .5322 .83134 L .53218 .83137 L F
.53299 .83105 m .5322 .83134 L .53231 .83132 L F
.53456 .83042 m .53278 .83076 L .53299 .83105 L F
0 .183 .685 r
.53365 .83196 m .53428 .83245 L .53322 .83136 L F
.53365 .83196 m .53322 .83136 L .53292 .83105 L F
.068 0 0 r
.47157 .88241 m .47497 .88229 L .47363 .88238 L F
.098 0 0 r
.47497 .88229 m .47567 .88241 L .47363 .88238 L F
.47497 .88229 m .47707 .88248 L .47567 .88241 L F
.727 .942 .954 r
.57256 .81008 m .57314 .81077 L .57493 .80961 L F
.986 .901 .598 r
.57185 .81219 m .57314 .81077 L .57256 .81008 L F
.279 0 .167 r
.57314 .81077 m .57446 .80993 L .57493 .80961 L F
.109 0 0 r
.4921 .88909 m .49501 .88821 L .49421 .88881 L F
.248 .746 .678 r
.4961 .88781 m .49501 .88821 L .49715 .88744 L F
0 0 0 r
.49421 .88881 m .49501 .88821 L .4961 .88781 L F
.416 .042 .219 r
.45482 .83553 m .45404 .83418 L .45605 .83382 L F
.45482 .83553 m .45268 .83592 L .45404 .83418 L F
.715 .187 0 r
.54675 .8263 m .5496 .82793 L .54865 .82808 L F
.605 .451 .647 r
.55135 .82686 m .5523 .82868 L .5496 .82793 L F
.623 .266 .344 r
.5496 .82793 m .54864 .83069 L .54865 .82808 L F
.5496 .82793 m .55147 .83027 L .54864 .83069 L F
.5496 .82793 m .5523 .82868 L .55147 .83027 L F
.65 .724 .902 r
.62323 .74282 m .61984 .74211 L .6223 .7405 L F
.66 .66 .84 r
.62526 .74212 m .62323 .74282 L .6223 .7405 L F
.804 .87 .896 r
.39064 .88104 m .38679 .8826 L .38935 .88053 L F
.608 .927 .968 r
.39285 .88021 m .39064 .88104 L .39136 .88003 L F
.544 .848 .998 r
.39136 .88003 m .39064 .88104 L .38935 .88053 L F
.743 .624 .726 r
.51698 .84141 m .51803 .84433 L .51479 .8439 L F
.718 .693 .825 r
.51977 .84161 m .51803 .84433 L .51698 .84141 L F
0 0 0 r
.52463 .87524 m .52705 .87304 L .52577 .87471 L F
.177 0 .211 r
.52878 .87212 m .52705 .87304 L .5292 .87084 L F
0 0 0 r
.52577 .87471 m .52705 .87304 L .52878 .87212 L F
.914 .976 .698 r
.57176 .79177 m .57229 .79229 L .57377 .78962 L F
.742 .231 0 r
.5727 .79358 m .57229 .79229 L .57176 .79177 L F
.056 .186 .684 r
.57358 .79469 m .57387 .79431 L .57368 .79488 L F
.57229 .79229 m .57387 .79431 L .57358 .79469 L F
.478 .796 .999 r
.57387 .79431 m .57539 .79336 L .57455 .79343 L F
.742 .231 0 r
.5727 .79358 m .57387 .79431 L .57379 .79422 L F
.5727 .79358 m .57379 .79422 L .57229 .79229 L F
.88 .446 .092 r
.5716 .79296 m .5727 .79358 L .57176 .79177 L F
.446 .801 .997 r
.5716 .79296 m .57164 .79296 L .5727 .79358 L F
.57164 .79296 m .57539 .79336 L .5727 .79358 L F
.478 .796 .999 r
.57387 .79431 m .57455 .79343 L .5727 .79358 L F
.65 .503 .67 r
.49431 .86093 m .49897 .85956 L .4971 .8594 L F
0 0 0 r
.52928 .85008 m .5298 .84974 L .53119 .84918 L F
.314 0 0 r
.58052 .80822 m .58146 .80917 L .57934 .8095 L F
.58052 .80822 m .58291 .80807 L .58146 .80917 L F
.431 0 0 r
.48222 .87411 m .48369 .87267 L .48057 .87329 L F
.708 .913 .563 r
.48356 .87239 m .48369 .87267 L .48222 .87411 L F
.81 .586 .027 r
.48376 .87365 m .48369 .87267 L .48543 .87262 L F
.621 .199 .22 r
.4836 .87375 m .48543 .87262 L .48443 .87454 L F
.676 .668 .834 r
.48414 .87383 m .48468 .87145 L .48356 .87239 L F
.48443 .87454 m .48447 .87398 L .48414 .87383 L F
.48447 .87398 m .48468 .87145 L .48414 .87383 L F
.81 .586 .027 r
.4836 .87375 m .48362 .87359 L .48376 .87365 L F
.48362 .87359 m .48369 .87267 L .48376 .87365 L F
.679 .952 .953 r
.65765 .74049 m .65951 .73946 L .66026 .73984 L F
.66026 .73984 m .65951 .73946 L .65765 .74049 L F
.585 .91 .977 r
.46406 .87284 m .46224 .87362 L .46077 .87323 L F
.536 .269 .458 r
.36322 .78402 m .36052 .78644 L .36123 .78444 L F
.286 .263 .658 r
.40144 .74548 m .40267 .74545 L .40245 .74219 L F
.46 .367 .664 r
.40144 .74548 m .40196 .74802 L .40349 .74734 L F
.40349 .74734 m .40196 .74802 L .40144 .74548 L F
.40349 .74734 m .40196 .74802 L .40144 .74548 L F
.67 .264 .268 r
.51364 .82865 m .51551 .83011 L .51664 .82787 L F
.642 .802 .96 r
.51178 .85408 m .50961 .85507 L .509 .85426 L F
.43 .445 .774 r
.51234 .85723 m .50961 .85507 L .51178 .85408 L F
.519 .322 .553 r
.38369 .87785 m .38205 .87979 L .3834 .87809 L F
.38369 .87785 m .38182 .88054 L .38205 .87979 L F
.755 .272 0 r
.54289 .80948 m .54332 .81018 L .54383 .81021 L F
.682 .144 0 r
.54439 .81138 m .54383 .81021 L .54332 .81018 L F
.54439 .81138 m .54564 .81203 L .54383 .81021 L F
.584 .407 .608 r
.50511 .82559 m .50209 .82334 L .50491 .82329 L F
.50511 .82559 m .50203 .8263 L .50209 .82334 L F
0 0 0 r
.56967 .83351 m .57155 .83121 L .57085 .83312 L F
.634 .615 .814 r
.57318 .82816 m .57155 .83121 L .57172 .82851 L F
.57318 .82816 m .57432 .83104 L .57155 .83121 L F
.467 .023 .11 r
.57155 .83121 m .57325 .83257 L .57085 .83312 L F
.57155 .83121 m .57432 .83104 L .57325 .83257 L F
.248 0 0 r
.41864 .82658 m .42071 .82647 L .42181 .82592 L F
.033 0 0 r
.42071 .82647 m .42389 .82591 L .42181 .82592 L F
0 0 0 r
.60791 .78942 m .60741 .79125 L .60782 .78893 L F
.60791 .78942 m .60685 .79221 L .60741 .79125 L F
.391 .12 .378 r
.66367 .7447 m .66394 .74316 L .66168 .74542 L F
.504 .226 .425 r
.66584 .74445 m .66394 .74316 L .66367 .7447 L F
.66584 .74445 m .66593 .74286 L .66394 .74316 L F
.552 .324 .523 r
.65396 .72479 m .65609 .72644 L .65518 .72727 L F
0 0 0 r
.65518 .72727 m .65461 .72922 L .65454 .72921 L F
.65518 .72727 m .65609 .72644 L .65461 .72922 L F
.715 .661 .796 r
.36645 .73379 m .36286 .73221 L .36483 .73183 L F
.485 .701 .965 r
.36673 .732 m .36645 .73379 L .36483 .73183 L F
.36673 .732 m .36845 .73358 L .36645 .73379 L F
.536 .39 .631 r
.61027 .79743 m .60977 .79978 L .60889 .79967 L F
.513 .345 .591 r
.61087 .802 m .60889 .79967 L .60977 .79978 L F
.61087 .802 m .60842 .80239 L .60889 .79967 L F
0 0 .543 r
.5516 .82121 m .55207 .82214 L .55124 .82089 L F
0 0 .405 r
.55129 .82098 m .55106 .8208 L .54948 .81806 L F
0 0 .543 r
.55097 .82038 m .55124 .82089 L .55038 .81961 L F
.5516 .82121 m .55124 .82089 L .55097 .82038 L F
0 0 .405 r
.55129 .82099 m .55129 .82099 L .55129 .82098 L F
.55129 .82099 m .55106 .8208 L .55129 .82098 L F
0 0 .462 r
.55207 .82214 m .55106 .8208 L .55129 .82099 L F
.55207 .82214 m .55181 .82307 L .55106 .8208 L F
.5 .251 .468 r
.37727 .77116 m .37687 .77347 L .37481 .77381 L F
.532 .279 .477 r
.3789 .77309 m .37727 .77116 L .37936 .7708 L F
.3789 .77309 m .37687 .77347 L .37727 .77116 L F
.685 .875 .97 r
.56721 .77598 m .56828 .77671 L .5704 .77572 L F
.03 .327 .811 r
.55213 .8338 m .55331 .83583 L .55092 .83386 L F
.645 .406 .543 r
.55092 .83386 m .55331 .83583 L .55083 .83612 L F
.674 .461 .589 r
.54994 .83649 m .55083 .83612 L .55007 .83617 L F
.54994 .83649 m .55007 .83617 L .54776 .83634 L F
.758 .568 .639 r
.55007 .83617 m .5498 .83642 L .54776 .83634 L F
.641 .666 .859 r
.54992 .83642 m .54994 .83649 L .54776 .83634 L F
.03 .327 .811 r
.54999 .83642 m .55007 .83617 L .54994 .83649 L F
.758 .568 .639 r
.54987 .8368 m .54769 .83836 L .54979 .83643 L F
.54999 .83642 m .54979 .83643 L .55007 .83617 L F
.676 .687 .853 r
.54999 .83642 m .54994 .83649 L .54992 .83642 L F
.758 .568 .639 r
.54987 .8368 m .54979 .83643 L .54999 .83642 L F
.03 .327 .811 r
.55213 .8338 m .55105 .83386 L .55007 .83617 L F
.55213 .8338 m .55007 .83617 L .54999 .83642 L F
.55105 .83386 m .55092 .83386 L .54994 .83649 L F
.676 .687 .853 r
.55213 .8338 m .54999 .83642 L .54865 .83275 L F
.54999 .83642 m .54992 .83642 L .54865 .83275 L F
.641 .666 .859 r
.54865 .83275 m .54992 .83642 L .54776 .83634 L F
.758 .568 .639 r
.5498 .83642 m .54769 .83836 L .54776 .83634 L F
.55083 .83612 m .54987 .8368 L .55007 .83617 L F
.326 0 0 r
.5462 .79401 m .5496 .79294 L .54712 .79254 L F
.62 .56 .765 r
.4125 .84904 m .41058 .84953 L .41047 .84785 L F
.708 .565 .691 r
.4125 .84904 m .4101 .85167 L .41058 .84953 L F
.724 .631 .754 r
.52554 .84382 m .52647 .84678 L .52308 .84703 L F
.786 .567 .604 r
.52647 .84678 m .52332 .84896 L .52308 .84703 L F
.52647 .84678 m .52654 .84967 L .52332 .84896 L F
.77 .747 .832 r
.52772 .84353 m .52647 .84678 L .52554 .84382 L F
.801 .702 .755 r
.57467 .78592 m .57781 .78426 L .57651 .78331 L F
.57467 .78592 m .57591 .78702 L .57781 .78426 L F
.803 .892 .907 r
.37478 .73491 m .37546 .7325 L .37676 .73456 L F
.37478 .73491 m .37341 .73426 L .37546 .7325 L F
.726 .197 0 r
.3769 .73697 m .37341 .73426 L .37478 .73491 L F
.55 .408 .641 r
.37676 .73456 m .3769 .73697 L .37478 .73491 L F
.688 .521 .656 r
.50821 .81936 m .5074 .82323 L .50491 .82329 L F
0 0 0 r
.50939 .81857 m .5079 .81967 L .50821 .81936 L F
.633 .468 .641 r
.51077 .8229 m .5074 .82323 L .50741 .82316 L F
.50985 .82163 m .50741 .82316 L .50821 .81936 L F
.51077 .8229 m .50741 .82316 L .50985 .82163 L F
.51077 .8229 m .50999 .82182 L .50914 .82081 L F
.50999 .82182 m .50821 .81936 L .50914 .82081 L F
.73 .232 0 r
.5079 .81967 m .50914 .82081 L .50821 .81936 L F
.764 .778 .865 r
.50818 .81966 m .50914 .82081 L .5079 .81967 L F
.51099 .8196 m .50914 .82081 L .50818 .81966 L F
.714 .52 .626 r
.51194 .82032 m .50914 .82081 L .51099 .8196 L F
.51231 .8206 m .5114 .82066 L .51194 .82032 L F
.5114 .82066 m .50914 .82081 L .51194 .82032 L F
.663 .52 .679 r
.39883 .85953 m .39671 .85989 L .39867 .85735 L F
.725 .515 .606 r
.4 .8623 m .39671 .85989 L .39883 .85953 L F
.4 .8623 m .39664 .86223 L .39671 .85989 L F
.473 .798 .999 r
.49367 .81103 m .49714 .81148 L .49581 .80937 L F
.758 .493 .532 r
.51565 .83598 m .51215 .83376 L .51584 .83391 L F
.664 .154 0 r
.54728 .81457 m .54632 .81307 L .54564 .81203 L F
.54728 .81457 m .54828 .81537 L .54632 .81307 L F
.407 0 .112 r
.47624 .81622 m .47777 .81682 L .47892 .8151 L F
.444 .027 .152 r
.47777 .81682 m .48102 .81487 L .47892 .8151 L F
.881 .481 .266 r
.57277 .8174 m .57322 .81621 L .57296 .81666 L F
.57277 .8174 m .57429 .81795 L .57322 .81621 L F
.329 0 0 r
.52436 .83653 m .52496 .83755 L .52389 .83836 L F
.52436 .83653 m .52649 .83632 L .52496 .83755 L F
.914 .976 .698 r
.57176 .79177 m .57377 .78962 L .57267 .78899 L F
.877 .898 .843 r
.57267 .78899 m .57377 .78962 L .57591 .78702 L F
0 .423 .717 r
.35614 .7296 m .35982 .7307 L .35771 .73103 L F
.586 .736 .947 r
.3953 .8289 m .39231 .82813 L .3939 .82805 L F
.473 .783 .998 r
.3939 .82805 m .39732 .82867 L .3953 .8289 L F
.58 .53 .763 r
.49484 .86281 m .49735 .86273 L .49431 .86093 L F
.652 .625 .81 r
.49814 .85449 m .50138 .85518 L .50011 .85198 L F
0 0 .504 r
.56405 .82691 m .5643 .82765 L .56425 .82744 L F
.881 .874 .435 r
.5643 .82765 m .56319 .83032 L .56425 .82744 L F
.509 .113 .225 r
.45251 .82277 m .45464 .82278 L .45588 .8209 L F
.526 .133 .239 r
.45464 .82278 m .45801 .82095 L .45588 .8209 L F
.663 .616 .791 r
.49278 .84084 m .49436 .83874 L .49184 .84053 L F
.49278 .84084 m .49558 .84162 L .49436 .83874 L F
.697 .452 .55 r
.40279 .85234 m .39938 .85323 L .39938 .85174 L F
.40279 .85234 m .40259 .85456 L .39938 .85323 L F
.557 .332 .528 r
.40493 .85408 m .40259 .85456 L .40279 .85234 L F
.64 .261 .31 r
.52814 .80518 m .52944 .80793 L .53167 .80506 L F
.23 0 .035 r
.53167 .80506 m .53305 .80583 L .5333 .80592 L F
.53167 .80506 m .52944 .80793 L .53305 .80583 L F
.645 .962 .917 r
.58206 .77278 m .58083 .7743 L .58294 .77289 L F
0 0 .438 r
.58172 .77523 m .58083 .7743 L .58206 .77278 L F
0 0 .437 r
.5348 .82089 m .53562 .8182 L .53386 .81785 L F
.747 .99 .884 r
.58169 .76529 m .58337 .76321 L .58424 .76364 L F
.58169 .76529 m .58079 .7652 L .58337 .76321 L F
.602 .835 .988 r
.40668 .89604 m .40996 .8962 L .40871 .89549 L F
.596 .833 .989 r
.40871 .89549 m .40996 .8962 L .41186 .89562 L F
.667 .271 .286 r
.45791 .83537 m .45482 .83553 L .45605 .83382 L F
.695 .6 .746 r
.59718 .78445 m .59811 .78122 L .59648 .78185 L F
0 0 .307 r
.60422 .79928 m .60394 .80232 L .60266 .80207 L F
.77 .447 .439 r
.60394 .80232 m .60271 .8044 L .60266 .80207 L F
.60394 .80232 m .60589 .8048 L .60271 .8044 L F
.567 .934 .917 r
.57446 .80993 m .57731 .80854 L .57493 .80961 L F
.675 .38 .466 r
.4838 .83826 m .48051 .83856 L .48041 .83671 L F
.874 .522 .38 r
.60784 .78446 m .60868 .78699 L .60676 .78606 L F
.535 .442 .696 r
.39938 .85323 m .39867 .85735 L .39785 .85382 L F
.39938 .85323 m .40092 .85785 L .39867 .85735 L F
.644 .611 .801 r
.40092 .85785 m .39883 .85953 L .39867 .85735 L F
.792 .659 .107 r
.48598 .86921 m .48591 .86914 L .48771 .8677 L F
.696 .945 .659 r
.4882 .86662 m .48771 .8677 L .48591 .86914 L F
.745 .62 .72 r
.48976 .86723 m .48748 .87006 L .48771 .8677 L F
.715 .595 .721 r
.65074 .7322 m .64774 .73289 L .64785 .73003 L F
.572 .221 .335 r
.6476 .73405 m .65074 .7322 L .64961 .73363 L F
.6476 .73405 m .64774 .73289 L .65074 .7322 L F
.23 .738 .888 r
.65074 .7322 m .6522 .7321 L .65235 .73182 L F
.6522 .7321 m .65296 .73205 L .65235 .73182 L F
0 0 0 r
.65454 .72921 m .65235 .73182 L .65296 .73205 L F
.65454 .72921 m .65461 .72922 L .65235 .73182 L F
.387 .022 .218 r
.65355 .73051 m .65247 .7316 L .65235 .73182 L F
0 0 0 r
.64961 .73363 m .65235 .73182 L .65124 .73284 L F
.387 .022 .218 r
.65247 .7316 m .65124 .73284 L .65235 .73182 L F
.23 .738 .888 r
.65074 .7322 m .65235 .73182 L .64961 .73363 L F
.271 0 0 r
.52121 .87715 m .52463 .87524 L .52398 .87577 L F
0 0 0 r
.52398 .87577 m .52463 .87524 L .52577 .87471 L F
.826 .423 .282 r
.56963 .80176 m .57083 .80089 L .56798 .79932 L F
.56963 .80176 m .56798 .79932 L .56794 .79934 L F
.56794 .79934 m .56798 .79932 L .5679 .79928 L F
0 0 .565 r
.56858 .79969 m .56963 .80176 L .5679 .79928 L F
.18 0 0 r
.56755 .80017 m .56858 .79969 L .56678 .79969 L F
.56646 .79979 m .56678 .79969 L .56619 .79969 L F
.56755 .80017 m .56678 .79969 L .56646 .79979 L F
.066 0 0 r
.57302 .80028 m .57083 .80089 L .56963 .80176 L F
.707 .755 .89 r
.64937 .7369 m .64699 .73683 L .6476 .73405 L F
.222 .69 .943 r
.64877 .73619 m .64913 .73652 L .6476 .73405 L F
.677 .733 .225 r
.64961 .73363 m .64877 .73619 L .6476 .73405 L F
.898 .759 .699 r
.64852 .73594 m .64877 .73619 L .64888 .73583 L F
.714 .67 .805 r
.6476 .73405 m .64699 .73683 L .64542 .7349 L F
.898 .759 .699 r
.64671 .7365 m .64877 .73619 L .64852 .73594 L F
.222 .69 .943 r
.64877 .73619 m .64937 .7369 L .64913 .73652 L F
.64877 .73619 m .65153 .73691 L .64937 .7369 L F
.801 .903 .913 r
.61804 .74361 m .61468 .74473 L .61699 .74279 L F
.813 .881 .894 r
.61984 .74211 m .61804 .74361 L .61699 .74279 L F
.401 .4 .743 r
.48931 .81733 m .4878 .81822 L .48707 .81566 L F
.636 .356 .476 r
.4878 .81822 m .48984 .8202 L .48991 .81858 L F
.375 .346 .699 r
.48931 .81733 m .48984 .8202 L .4878 .81822 L F
.946 .852 .718 r
.49346 .84893 m .49463 .84945 L .49542 .84662 L F
.266 .76 .69 r
.49788 .88705 m .5023 .8855 L .50201 .88599 L F
.471 .884 .759 r
.5023 .8855 m .50523 .88394 L .50305 .88486 L F
0 0 0 r
.50201 .88599 m .5023 .8855 L .50305 .88486 L F
.512 .893 .961 r
.4376 .88886 m .4408 .88839 L .43956 .88838 L F
.067 .619 .824 r
.4408 .88839 m .44158 .88825 L .43956 .88838 L F
.4408 .88839 m .44292 .88852 L .44158 .88825 L F
.553 .333 .535 r
.66223 .74641 m .66367 .7447 L .66168 .74542 L F
.682 .34 .391 r
.49944 .8624 m .50208 .86219 L .49854 .86192 L F
.75 .565 .645 r
.5001 .86492 m .50208 .86219 L .49944 .8624 L F
.494 .322 .576 r
.61905 .7914 m .61544 .79148 L .61688 .78938 L F
.49 .293 .54 r
.61694 .79425 m .61544 .79148 L .61905 .7914 L F
.645 .485 .651 r
.59718 .78445 m .59722 .78675 L .59935 .78632 L F
.875 .732 .7 r
.48941 .84943 m .48769 .84938 L .48856 .84683 L F
.873 .658 .608 r
.48941 .84943 m .48765 .85091 L .48769 .84938 L F
.005 0 0 r
.49039 .84958 m .48941 .84943 L .49056 .85028 L F
.49039 .84958 m .48765 .85091 L .48941 .84943 L F
.242 0 0 r
.49436 .83874 m .49125 .8401 L .49184 .84053 L F
.12 0 0 r
.49315 .8399 m .49302 .83993 L .49125 .8401 L F
.267 .743 .936 r
.49184 .84053 m .49125 .8401 L .48953 .84026 L F
.12 0 0 r
.49302 .83993 m .48995 .84067 L .49125 .8401 L F
.267 .743 .936 r
.48953 .84026 m .49125 .8401 L .48906 .8402 L F
.523 .733 .97 r
.54453 .85623 m .54529 .85756 L .54714 .85707 L F
.382 .124 .392 r
.54482 .85943 m .54529 .85756 L .54714 .85707 L F
.356 .024 .259 r
.59256 .84584 m .59317 .84347 L .59522 .84384 L F
.442 0 0 r
.43133 .8246 m .4332 .8249 L .43466 .82398 L F
.324 0 0 r
.4332 .8249 m .43671 .82438 L .43466 .82398 L F
.784 .655 .721 r
.4892 .81553 m .49198 .81778 L .49238 .81337 L F
.746 .622 .721 r
.64785 .73003 m .64774 .73289 L .64582 .73185 L F
.816 .449 .361 r
.64582 .73185 m .64774 .73289 L .6476 .73405 L F
.37 .738 .99 r
.36721 .74932 m .3697 .74979 L .36924 .74933 L F
.373 .732 .99 r
.3697 .74979 m .37024 .74885 L .36924 .74933 L F
.3697 .74979 m .3716 .7498 L .37024 .74885 L F
.699 .702 .849 r
.57249 .787 m .57591 .78702 L .57467 .78592 L F
.877 .898 .843 r
.57267 .78899 m .57591 .78702 L .57249 .787 L F
.319 0 0 r
.56652 .84751 m .56705 .84737 L .56985 .84827 L F
.287 0 0 r
.55248 .79446 m .55481 .79461 L .55597 .79422 L F
.416 .855 .75 r
.55597 .79422 m .55481 .79461 L .55665 .79369 L F
.548 .886 .987 r
.38856 .90079 m .39194 .90048 L .3905 .90029 L F
.448 .861 .955 r
.3905 .90029 m .39194 .90048 L .39392 .89995 L F
.593 .055 0 r
.54705 .79537 m .54886 .79677 L .54783 .79609 L F
.93 .587 .36 r
.54886 .79677 m .54822 .79883 L .54783 .79609 L F
.54886 .79677 m .54963 .79969 L .54822 .79883 L F
.523 .064 .105 r
.43066 .84206 m .42923 .84339 L .42711 .84323 L F
.336 0 0 r
.43112 .8431 m .43066 .84206 L .43266 .84159 L F
.43112 .8431 m .42923 .84339 L .43066 .84206 L F
.557 .595 .847 r
.37595 .75324 m .37669 .75046 L .37463 .75049 L F
.37595 .75324 m .37785 .753 L .37669 .75046 L F
.577 .436 .652 r
.37595 .75324 m .37827 .7551 L .37785 .753 L F
.37595 .75324 m .37614 .7555 L .37827 .7551 L F
.494 .322 .576 r
.61905 .7914 m .61688 .78938 L .61852 .78735 L F
.541 .307 .511 r
.62086 .78621 m .61852 .78735 L .61922 .78667 L F
.62086 .78621 m .62129 .78898 L .61852 .78735 L F
.546 .303 .497 r
.61852 .78735 m .62098 .79104 L .61905 .7914 L F
.61852 .78735 m .62129 .78898 L .62098 .79104 L F
.492 .233 .448 r
.63288 .77579 m .63258 .77872 L .63049 .77919 L F
.494 .236 .452 r
.63535 .77385 m .63517 .77545 L .63288 .77579 L F
.495 .235 .449 r
.63479 .7783 m .63288 .77579 L .63517 .77545 L F
.63479 .7783 m .63258 .77872 L .63288 .77579 L F
.624 .498 .689 r
.39938 .85174 m .39785 .85382 L .39758 .85207 L F
.39938 .85174 m .39938 .85323 L .39785 .85382 L F
.746 .673 .78 r
.64161 .73837 m .63801 .73768 L .64017 .73695 L F
.739 .701 .815 r
.6434 .73728 m .64161 .73837 L .64017 .73695 L F
0 0 0 r
.58658 .80706 m .58803 .80555 L .58564 .80789 L F
.655 .217 .199 r
.58999 .80735 m .58803 .80555 L .58658 .80706 L F
.388 0 .096 r
.48557 .81259 m .4877 .81229 L .48884 .81077 L F
.279 0 0 r
.4877 .81229 m .49093 .81039 L .48884 .81077 L F
.333 .768 .968 r
.49941 .87697 m .49804 .87751 L .49885 .87719 L F
.49941 .87697 m .50032 .8774 L .49804 .87751 L F
.547 .602 .86 r
.53132 .81224 m .53311 .81614 L .53484 .8149 L F
.803 .333 .109 r
.49765 .84131 m .49436 .83874 L .49558 .84162 L F
.38 .741 .991 r
.40755 .88013 m .40652 .88095 L .40583 .88089 L F
.40755 .88013 m .40886 .88099 L .40652 .88095 L F
.937 .763 .641 r
.49518 .84279 m .49423 .84681 L .49542 .84662 L F
.946 .852 .718 r
.49346 .84893 m .49542 .84662 L .49423 .84681 L F
.667 .453 .585 r
.47697 .8676 m .47705 .8701 L .47449 .87021 L F
.985 .731 .344 r
.47628 .86939 m .47697 .8676 L .47616 .86625 L F
.47628 .86939 m .47705 .8701 L .47697 .8676 L F
.713 .925 .591 r
.63505 .75655 m .63436 .75749 L .6362 .75506 L F
.541 .24 .405 r
.63535 .77385 m .63718 .77516 L .63517 .77545 L F
.63535 .77385 m .63756 .7737 L .63718 .77516 L F
0 .514 .786 r
.37463 .75049 m .3716 .7498 L .37271 .75077 L F
0 0 0 r
.53305 .84634 m .53204 .84687 L .53211 .8474 L F
.785 .967 .919 r
.59199 .75925 m .5926 .75762 L .59342 .75798 L F
.59199 .75925 m .59009 .75949 L .5926 .75762 L F
.255 .76 .876 r
.43431 .87483 m .43288 .87511 L .43087 .87501 L F
.765 .514 .554 r
.58639 .77841 m .58941 .77602 L .58756 .77904 L F
.539 .36 .587 r
.58941 .77602 m .58988 .77883 L .58756 .77904 L F
.765 .514 .554 r
.58639 .77841 m .58988 .77883 L .58941 .77602 L F
.611 .561 .773 r
.58901 .77427 m .58941 .77602 L .59093 .77542 L F
.38 0 .029 r
.46135 .83377 m .45997 .83523 L .45791 .83537 L F
.594 .145 .156 r
.46375 .83492 m .45997 .83523 L .46135 .83377 L F
.609 .24 .318 r
.46361 .83404 m .46375 .83492 L .46135 .83377 L F
.755 .472 .504 r
.49976 .8159 m .49713 .81735 L .49869 .81466 L F
.782 .485 .485 r
.4987 .81679 m .50053 .81793 L .49976 .8159 L F
.641 .849 .979 r
.56951 .78443 m .5723 .7844 L .57159 .78364 L F
.56951 .78443 m .5723 .7844 L .57159 .78364 L F
0 .396 .845 r
.5723 .7844 m .57274 .78389 L .57159 .78364 L F
.5723 .7844 m .57467 .78592 L .57274 .78389 L F
.699 .702 .849 r
.57249 .787 m .57467 .78592 L .5723 .7844 L F
.594 .345 .51 r
.46844 .82013 m .47072 .81806 L .46878 .81837 L F
.725 .633 .755 r
.52554 .84382 m .52308 .84703 L .52352 .84447 L F
.375 .074 .322 r
.37169 .77824 m .37042 .77727 L .37218 .77693 L F
.37169 .77824 m .36986 .77874 L .37042 .77727 L F
.647 .64 .83 r
.34975 .72512 m .34855 .7271 L .34788 .72506 L F
.34975 .72512 m .35055 .72712 L .34855 .7271 L F
.64 .26 .308 r
.35055 .72712 m .34775 .72784 L .34855 .7271 L F
.845 .528 .452 r
.35823 .76815 m .36009 .76843 L .3599 .76874 L F
.382 0 .152 r
.64509 .76904 m .64641 .77045 L .64466 .77029 L F
.64509 .76904 m .64722 .76867 L .64641 .77045 L F
.254 .25 .662 r
.59945 .80072 m .59771 .79975 L .59944 .79939 L F
.66 .625 .804 r
.60045 .79164 m .59939 .795 L .59832 .79198 L F
.6004 .7918 m .60163 .79457 L .59939 .795 L F
.538 .324 .537 r
.60043 .79388 m .59874 .79236 L .59816 .79421 L F
.59874 .79236 m .59832 .79198 L .59828 .79252 L F
.59874 .79236 m .59828 .79252 L .59816 .79421 L F
.66 .625 .804 r
.60045 .79164 m .6005 .79177 L .6004 .7918 L F
.6005 .79177 m .60163 .79457 L .6004 .7918 L F
.569 .455 .684 r
.60206 .79683 m .59939 .795 L .60163 .79457 L F
.60164 .79654 m .59961 .7972 L .59939 .795 L F
.944 .646 .443 r
.60052 .79622 m .60144 .79486 L .60043 .79388 L F
.60144 .79486 m .60163 .79457 L .60139 .79443 L F
.60144 .79486 m .60139 .79443 L .60043 .79388 L F
.569 .455 .684 r
.60206 .79683 m .60168 .79689 L .60164 .79654 L F
.60168 .79689 m .59961 .7972 L .60164 .79654 L F
.923 .574 .355 r
.55102 .80038 m .55025 .80173 L .54963 .79969 L F
.841 .448 .302 r
.55102 .80038 m .55209 .80225 L .55025 .80173 L F
.902 .86 .79 r
.53101 .86763 m .5292 .87084 L .52809 .86997 L F
.389 .073 .303 r
.52878 .87212 m .5292 .87084 L .53116 .87002 L F
.507 .223 .418 r
.64995 .74205 m .65171 .74178 L .65219 .74052 L F
.545 .72 .954 r
.65632 .7392 m .65504 .74063 L .65368 .74002 L F
.65584 .73919 m .65368 .74002 L .65173 .73914 L F
.65632 .7392 m .65368 .74002 L .65584 .73919 L F
.35 .071 .342 r
.65429 .73999 m .65219 .74052 L .65504 .74063 L F
.65429 .73999 m .65171 .74178 L .65216 .7406 L F
.65278 .74037 m .65216 .7406 L .65219 .74052 L F
.65429 .73999 m .65216 .7406 L .65278 .74037 L F
.653 .969 .831 r
.50305 .88486 m .50523 .88394 L .50671 .88277 L F
.732 .646 .764 r
.63082 .74206 m .62747 .73988 L .62954 .73924 L F
.63082 .74206 m .62864 .7429 L .62747 .73988 L F
.687 .671 .829 r
.63293 .73992 m .63082 .74206 L .62954 .73924 L F
.658 .638 .818 r
.63392 .74276 m .63082 .74206 L .63293 .73992 L F
.759 .779 .869 r
.59376 .77339 m .59718 .77364 L .59594 .77091 L F
.59376 .77339 m .59499 .77439 L .59718 .77364 L F
.722 .711 .839 r
.59594 .77091 m .59718 .77364 L .59912 .77126 L F
.639 .583 .775 r
.59718 .77364 m .60009 .77438 L .59912 .77126 L F
.533 .917 .928 r
.51657 .84999 m .51908 .84904 L .51787 .84915 L F
.51657 .84999 m .51787 .84915 L .5159 .85158 L F
.657 .53 .697 r
.59935 .78632 m .60158 .78366 L .59973 .78434 L F
.097 .653 .76 r
.4767 .87488 m .47574 .87502 L .47487 .87257 L F
.4767 .87488 m .47777 .87488 L .47574 .87502 L F
.996 .856 .578 r
.66523 .74992 m .66496 .75264 L .66573 .75238 L F
.561 .317 .504 r
.66496 .75264 m .66812 .7505 L .66573 .75238 L F
.574 .729 .948 r
.40208 .87974 m .40115 .88128 L .4 .88049 L F
.40208 .87974 m .40314 .88101 L .40115 .88128 L F
.373 .41 .77 r
.53386 .81785 m .53562 .8182 L .53472 .81646 L F
.611 .402 .574 r
.38699 .86487 m .38683 .86765 L .38421 .8675 L F
.612 .403 .574 r
.38895 .86725 m .38699 .86487 L .38915 .86478 L F
.38895 .86725 m .38683 .86765 L .38699 .86487 L F
.77 .857 .915 r
.43179 .89022 m .4358 .88955 L .43258 .88978 L F
.529 .903 .958 r
.43258 .88978 m .4358 .88955 L .4376 .88886 L F
.438 .48 .806 r
.57318 .82816 m .57172 .82851 L .57036 .82508 L F
.787 .951 .925 r
.57361 .77886 m .57214 .78021 L .57111 .78034 L F
.902 .86 .79 r
.53101 .86763 m .52809 .86997 L .53066 .86808 L F
0 0 0 r
.53196 .86671 m .53101 .86763 L .53066 .86808 L F
.373 .404 .764 r
.54144 .82834 m .54345 .83114 L .54332 .83044 L F
.979 .758 .535 r
.49186 .81928 m .49312 .81817 L .48991 .81858 L F
.49186 .81928 m .49298 .82056 L .49312 .81817 L F
.478 .843 .991 r
.49312 .81817 m .49263 .81762 L .49522 .81772 L F
.49312 .81817 m .49263 .81762 L .49522 .81772 L F
.292 0 0 r
.44232 .8767 m .44063 .87649 L .43926 .87711 L F
.929 .954 .628 r
.50926 .86125 m .51031 .85989 L .51057 .85762 L F
.401 .4 .743 r
.48931 .81733 m .48707 .81566 L .4892 .81553 L F
.547 .749 .97 r
.359 .75007 m .36028 .74904 L .35839 .74925 L F
.359 .75007 m .36087 .74979 L .36028 .74904 L F
.712 .636 .771 r
.62747 .73988 m .62864 .7429 L .62526 .74212 L F
.638 .944 .955 r
.40376 .8968 m .40482 .89697 L .40668 .89604 L F
.561 .317 .504 r
.66496 .75264 m .66523 .74992 L .66812 .7505 L F
.471 .769 .996 r
.6693 .74946 m .67045 .75043 L .66812 .7505 L F
.736 .707 .823 r
.65112 .73941 m .65172 .73776 L .65153 .73691 L F
.65112 .73941 m .65173 .73914 L .65172 .73776 L F
.647 .403 .535 r
.63663 .75794 m .63937 .75564 L .6362 .75506 L F
.63663 .75794 m .6401 .75771 L .63937 .75564 L F
.727 .35 .336 r
.49298 .82056 m .49527 .82277 L .49639 .82099 L F
.382 0 .074 r
.49527 .82277 m .49819 .82111 L .49639 .82099 L F
.711 .962 .943 r
.5075 .8745 m .50583 .87574 L .50649 .87436 L F
.761 .992 .79 r
.50649 .87436 m .50583 .87574 L .50413 .87662 L F
.651 .177 .114 r
.50601 .82915 m .5081 .83048 L .50923 .82971 L F
.492 .884 .959 r
.38657 .90141 m .38711 .90068 L .3865 .90141 L F
.38657 .90141 m .38725 .90061 L .38711 .90068 L F
.38657 .90141 m .38856 .90079 L .38725 .90061 L F
.694 .908 .971 r
.38193 .83075 m .37917 .83146 L .38048 .83129 L F
.607 .362 .519 r
.38447 .83066 m .38193 .83075 L .38048 .83129 L F
.648 .623 .811 r
.50011 .85198 m .50138 .85518 L .50302 .85412 L F
.776 .675 .752 r
.63495 .75244 m .63835 .75292 L .6384 .75069 L F
.777 .669 .744 r
.63495 .75244 m .6362 .75506 L .63835 .75292 L F
.83 .858 .866 r
.64582 .73185 m .64682 .72951 L .64785 .73003 L F
.65 .503 .67 r
.49431 .86093 m .49735 .86273 L .49897 .85956 L F
.603 .597 .818 r
.38229 .74533 m .379 .74297 L .38106 .74281 L F
.602 .625 .846 r
.38433 .74492 m .38229 .74533 L .38106 .74281 L F
.619 .529 .731 r
.38433 .74492 m .38322 .749 L .38229 .74533 L F
.277 .578 .941 r
.58564 .80789 m .5882 .8086 L .58658 .80706 L F
.879 .443 .089 r
.55857 .81056 m .55841 .81174 L .558 .80971 L F
.55857 .81056 m .55959 .81247 L .55841 .81174 L F
.545 .72 .954 r
.65632 .7392 m .65765 .74049 L .65504 .74063 L F
.65504 .74063 m .65632 .7392 L .65429 .73999 L F
.65504 .74063 m .65765 .74049 L .65632 .7392 L F
.664 .52 .678 r
.59829 .77909 m .60188 .77989 L .60039 .77614 L F
.698 .601 .744 r
.59811 .78122 m .60188 .77989 L .59829 .77909 L F
.514 .37 .623 r
.61278 .79931 m .61027 .79743 L .61276 .79712 L F
.61278 .79931 m .60977 .79978 L .61027 .79743 L F
.408 .198 .48 r
.5713 .78872 m .57267 .78899 L .57249 .787 L F
.6 .411 .597 r
.37191 .76074 m .37412 .76061 L .3741 .75829 L F
.621 .483 .673 r
.3741 .75829 m .37655 .75817 L .37614 .7555 L F
.57 .36 .557 r
.37412 .76061 m .37655 .75817 L .3741 .75829 L F
.743 .624 .726 r
.51698 .84141 m .51479 .8439 L .51495 .84186 L F
.522 .269 .473 r
.3864 .76535 m .386 .76846 L .38388 .76876 L F
.482 .236 .463 r
.38791 .76789 m .3864 .76535 L .38871 .76477 L F
.38791 .76789 m .386 .76846 L .3864 .76535 L F
.574 .635 .874 r
.37481 .73867 m .37582 .74047 L .37273 .73901 L F
.734 .708 .826 r
.37695 .73715 m .37582 .74047 L .37481 .73867 L F
.578 .536 .772 r
.37778 .74004 m .37582 .74047 L .37695 .73715 L F
.574 .635 .874 r
.37481 .73867 m .37273 .73901 L .37217 .73807 L F
.289 0 .037 r
.35117 .72906 m .34905 .72972 L .34768 .72934 L F
.35117 .72906 m .34984 .72952 L .34905 .72972 L F
.532 .604 .871 r
.35117 .72906 m .34905 .72972 L .34984 .72952 L F
.532 .283 .484 r
.39143 .86254 m .39126 .86457 L .38915 .86478 L F
.685 .414 .507 r
.39281 .86444 m .39143 .86254 L .39322 .86247 L F
.39281 .86444 m .39126 .86457 L .39143 .86254 L F
.648 .623 .811 r
.50011 .85198 m .50302 .85412 L .50344 .85203 L F
.765 .668 .754 r
.50202 .84909 m .50344 .85203 L .50527 .84935 L F
.733 .859 .94 r
.52325 .83294 m .52115 .83396 L .51991 .83327 L F
.827 .35 .005 r
.56984 .78975 m .57267 .78899 L .5713 .78872 L F
.644 .611 .801 r
.40092 .85785 m .40152 .86018 L .39883 .85953 L F
.675 .537 .689 r
.40152 .86018 m .4 .8623 L .39883 .85953 L F
0 0 0 r
.50872 .88208 m .51198 .88016 L .51078 .88129 L F
.118 0 0 r
.51329 .88028 m .51198 .88016 L .51398 .87948 L F
.51078 .88129 m .51198 .88016 L .51329 .88028 L F
.634 .572 .768 r
.60009 .77438 m .60039 .77614 L .60224 .77383 L F
.622 .554 .758 r
.60039 .77614 m .60268 .77616 L .60224 .77383 L F
.675 .526 .674 r
.60039 .77614 m .60188 .77989 L .60349 .77889 L F
.556 .331 .529 r
.50618 .85946 m .50854 .85516 L .50431 .85718 L F
.518 .113 .212 r
.4381 .83928 m .43669 .84107 L .43461 .84097 L F
.592 .197 .263 r
.43966 .8405 m .4381 .83928 L .43998 .83859 L F
.43966 .8405 m .43669 .84107 L .4381 .83928 L F
.784 .655 .721 r
.4892 .81553 m .49238 .81337 L .49115 .81492 L F
.148 0 .374 r
.49392 .81199 m .49238 .81337 L .49367 .81103 L F
.664 .505 .659 r
.49392 .81199 m .49115 .81492 L .49238 .81337 L F
0 0 .503 r
.55227 .82783 m .55135 .82686 L .55285 .82513 L F
.55227 .82783 m .5523 .82868 L .55135 .82686 L F
0 .079 .61 r
.55425 .80552 m .55604 .8076 L .55569 .80699 L F
.675 .148 0 r
.55604 .8076 m .558 .80971 L .55695 .80905 L F
.55604 .8076 m .55695 .80905 L .55569 .80699 L F
.725 .732 .857 r
.53762 .82519 m .53523 .82337 L .53686 .82297 L F
.53762 .82519 m .53448 .82527 L .53523 .82337 L F
0 .506 .703 r
.39136 .88003 m .39459 .88042 L .39285 .88021 L F
.765 .686 .775 r
.63606 .74017 m .63392 .74276 L .63293 .73992 L F
.551 .823 .997 r
.41949 .88054 m .41737 .88102 L .41589 .88018 L F
.549 .558 .816 r
.37958 .73968 m .379 .74297 L .37778 .74004 L F
.37958 .73968 m .38106 .74281 L .379 .74297 L F
.799 .94 .92 r
.60119 .75355 m .5977 .75498 L .60031 .75337 L F
.639 .953 .756 r
.60274 .75228 m .60119 .75355 L .60218 .75235 L F
.639 .954 .938 r
.60119 .75355 m .60031 .75337 L .60218 .75235 L F
.113 0 .043 r
.52551 .8074 m .5276 .8066 L .52814 .80518 L F
.782 .324 .158 r
.52764 .80651 m .52944 .80793 L .52814 .80518 L F
.867 .767 .749 r
.52783 .8071 m .52764 .80651 L .5276 .8066 L F
.52811 .8077 m .52783 .80697 L .52783 .8071 L F
.52783 .80697 m .52764 .80651 L .52783 .8071 L F
.782 .324 .158 r
.52789 .80713 m .52944 .80793 L .52764 .80651 L F
0 0 .354 r
.5276 .8066 m .52831 .80992 L .52827 .80887 L F
.52806 .80785 m .52827 .80887 L .52826 .80839 L F
.5276 .8066 m .52827 .80887 L .52806 .80785 L F
.738 .633 .743 r
.53305 .80583 m .52944 .80793 L .52791 .80714 L F
.782 .324 .158 r
.52749 .80692 m .52778 .80687 L .52764 .80651 L F
.867 .767 .749 r
.52826 .80839 m .52811 .8077 L .52793 .80732 L F
.52806 .80785 m .52793 .80732 L .5276 .8066 L F
.52826 .80839 m .52793 .80732 L .52806 .80785 L F
.738 .633 .743 r
.52785 .80685 m .52791 .80714 L .52789 .80713 L F
.52782 .80686 m .52789 .80713 L .52749 .80692 L F
.52785 .80685 m .52789 .80713 L .52782 .80686 L F
.53305 .80583 m .52791 .80714 L .52785 .80685 L F
.683 .406 .497 r
.52551 .8074 m .52831 .80992 L .5276 .8066 L F
.782 .324 .158 r
.52749 .80692 m .52764 .80651 L .5276 .8066 L F
.64 .388 .522 r
.52294 .81003 m .52706 .81067 L .52551 .8074 L F
.683 .406 .497 r
.52551 .8074 m .52706 .81067 L .52831 .80992 L F
.782 .324 .158 r
.52764 .80651 m .52814 .80518 L .5276 .8066 L F
.682 .829 .954 r
.53107 .80576 m .52782 .80682 L .5277 .80578 L F
.867 .767 .749 r
.52784 .80702 m .52775 .80625 L .52764 .80651 L F
.52778 .80618 m .5277 .80578 L .5276 .8066 L F
.737 .725 .199 r
.5277 .80578 m .52749 .80692 L .5276 .8066 L F
.682 .829 .954 r
.52782 .80682 m .52749 .80692 L .5277 .80578 L F
.867 .767 .749 r
.52811 .8077 m .52778 .80618 L .52775 .80625 L F
.52811 .8077 m .52775 .80625 L .52784 .80702 L F
.52826 .80839 m .52585 .80896 L .52744 .80623 L F
.5278 .80626 m .52744 .80623 L .5277 .80578 L F
.738 .633 .743 r
.52782 .80686 m .52749 .80692 L .52782 .80682 L F
.867 .767 .749 r
.52826 .80839 m .52744 .80623 L .5278 .80626 L F
.738 .633 .743 r
.53305 .80583 m .52987 .80646 L .53107 .80576 L F
.52987 .80646 m .52782 .80686 L .5292 .80639 L F
.52987 .80646 m .5292 .80639 L .53107 .80576 L F
.52782 .80686 m .52782 .80682 L .53107 .80576 L F
.42 .111 .334 r
.6283 .77955 m .62784 .78106 L .62587 .78153 L F
.432 .123 .339 r
.63005 .78068 m .6283 .77955 L .63049 .77919 L F
.63005 .78068 m .62784 .78106 L .6283 .77955 L F
.343 .081 .364 r
.59775 .83882 m .59766 .84108 L .59542 .84121 L F
.354 .124 .42 r
.59542 .84121 m .59709 .84321 L .59522 .84384 L F
.59542 .84121 m .59766 .84108 L .59709 .84321 L F
.752 .668 .769 r
.64231 .73438 m .6434 .73728 L .64017 .73695 L F
.704 .668 .812 r
.64542 .7349 m .6434 .73728 L .64231 .73438 L F
.64542 .7349 m .64699 .73683 L .6434 .73728 L F
.593 .642 .868 r
.64995 .74205 m .65112 .73941 L .64876 .74126 L F
.64995 .74205 m .65171 .74178 L .65112 .73941 L F
.687 .601 .754 r
.64995 .74205 m .65351 .74315 L .65171 .74178 L F
.656 .572 .749 r
.38497 .74862 m .38345 .75065 L .38322 .749 L F
.38497 .74862 m .38552 .7499 L .38345 .75065 L F
.634 .571 .766 r
.38652 .75311 m .38345 .75065 L .38552 .7499 L F
.813 .881 .894 r
.61984 .74211 m .61699 .74279 L .61869 .74144 L F
.753 .898 .943 r
.6223 .7405 m .61984 .74211 L .61869 .74144 L F
.753 .786 .88 r
.59093 .77542 m .59499 .77439 L .59376 .77339 L F
0 0 0 r
.47537 .86584 m .47412 .86783 L .47616 .86625 L F
.4775 .862 m .47537 .86584 L .47692 .86324 L F
.04 0 .435 r
.47692 .86324 m .47537 .86584 L .47616 .86625 L F
.622 .196 .211 r
.49819 .82111 m .50047 .82241 L .5015 .82084 L F
.759 .678 .772 r
.50053 .81793 m .5015 .82084 L .50367 .81822 L F
.336 0 .052 r
.5015 .82084 m .50254 .82202 L .50379 .82204 L F
.5015 .82084 m .50047 .82241 L .50254 .82202 L F
.773 .717 .799 r
.54005 .82319 m .53762 .82519 L .53686 .82297 L F
.364 .828 .905 r
.44587 .88793 m .44684 .88739 L .44491 .88805 L F
.44587 .88793 m .44792 .88747 L .44684 .88739 L F
.37 .738 .99 r
.36721 .74932 m .36924 .74933 L .3662 .75001 L F
.563 .925 .76 r
.3865 .90141 m .38711 .90068 L .38522 .90198 L F
.62 .56 .765 r
.4125 .84904 m .41047 .84785 L .41265 .84697 L F
.52 .337 .573 r
.39089 .76068 m .39085 .7629 L .38874 .76316 L F
.512 .283 .503 r
.39083 .76335 m .38874 .76316 L .39085 .7629 L F
.39083 .76335 m .38871 .76477 L .38874 .76316 L F
0 0 .393 r
.56065 .81529 m .56255 .81838 L .56264 .81726 L F
.592 .064 0 r
.56065 .81529 m .56264 .81726 L .56168 .81656 L F
.56065 .81529 m .56168 .81656 L .56053 .81498 L F
.575 .173 .244 r
.45801 .82095 m .45986 .82219 L .46108 .82038 L F
.564 .165 .246 r
.45986 .82219 m .46323 .82057 L .46108 .82038 L F
.94 .861 .735 r
.63957 .76251 m .64218 .76062 L .64205 .76021 L F
.63957 .76251 m .64078 .7635 L .64218 .76062 L F
.619 .529 .731 r
.38433 .74492 m .38497 .74862 L .38322 .749 L F
.05 .547 .884 r
.47707 .88248 m .47989 .88356 L .47859 .8832 L F
0 .149 .604 r
.47989 .88356 m .48121 .88445 L .47859 .8832 L F
.47989 .88356 m .48219 .88522 L .48121 .88445 L F
.525 .292 .504 r
.59944 .79939 m .59961 .7972 L .60206 .79683 L F
0 0 .428 r
.56324 .83101 m .56335 .83377 L .5644 .83283 L F
.829 .556 .527 r
.44675 .87436 m .44908 .87252 L .44817 .87301 L F
.519 .322 .553 r
.38369 .87785 m .38437 .87986 L .38182 .88054 L F
.408 .401 .739 r
.38533 .87685 m .38369 .87785 L .38308 .87471 L F
.663 .573 .743 r
.38533 .87685 m .38437 .87986 L .38369 .87785 L F
.873 .906 .85 r
.59649 .82075 m .59448 .82332 L .5934 .82273 L F
.521 0 0 r
.59448 .82332 m .5958 .82464 L .5934 .82273 L F
.59448 .82332 m .59664 .82531 L .5958 .82464 L F
.631 .501 .686 r
.59649 .82075 m .59741 .82343 L .59448 .82332 L F
.618 .363 .509 r
.59448 .82332 m .59741 .82343 L .59664 .82531 L F
.607 .436 .624 r
.36981 .76344 m .37212 .76334 L .37191 .76074 L F
.51 .313 .55 r
.37212 .76334 m .37412 .76061 L .37191 .76074 L F
.877 .693 .649 r
.49236 .84591 m .49423 .84681 L .49518 .84279 L F
.02 0 0 r
.4963 .84294 m .49428 .84364 L .49518 .84279 L F
.49518 .84279 m .49428 .84364 L .4963 .84294 L F
0 0 0 r
.51479 .8439 m .51286 .84662 L .51392 .84564 L F
.232 .229 .65 r
.51495 .84186 m .51479 .8439 L .51603 .84309 L F
.683 .544 .689 r
.51392 .84564 m .51603 .84309 L .51479 .8439 L F
.574 .093 .074 r
.66809 .74409 m .66908 .74292 L .66593 .74286 L F
.483 .025 .089 r
.66809 .74409 m .67128 .74294 L .66908 .74292 L F
.145 0 0 r
.51057 .83613 m .51105 .83639 L .50862 .8367 L F
.499 .252 .471 r
.36986 .77874 m .36746 .78115 L .36789 .77911 L F
.764 .336 .234 r
.40241 .82655 m .40456 .82801 L .40564 .82744 L F
.469 .868 .693 r
.40564 .82744 m .40649 .82674 L .40774 .82717 L F
.40564 .82744 m .40456 .82801 L .40649 .82674 L F
0 0 0 r
.59553 .82772 m .59288 .83085 L .5942 .8302 L F
.575 .592 .832 r
.59664 .82531 m .59806 .82804 L .59553 .82772 L F
.59664 .82531 m .59761 .82652 L .59773 .82645 L F
.292 .433 .832 r
.59847 .8276 m .59806 .82804 L .59664 .82531 L F
.069 0 .056 r
.59768 .8265 m .59553 .82772 L .5942 .8302 L F
.59773 .82645 m .59761 .82652 L .59768 .8265 L F
.59761 .82652 m .59553 .82772 L .59768 .8265 L F
.292 .433 .832 r
.59895 .82709 m .59847 .8276 L .59761 .82652 L F
.59805 .8264 m .59761 .82652 L .59664 .82531 L F
.59895 .82709 m .59761 .82652 L .59805 .8264 L F
.575 .592 .832 r
.59664 .82531 m .59553 .82772 L .59761 .82652 L F
.294 0 .141 r
.64589 .76091 m .64708 .76209 L .64789 .7602 L F
.64589 .76091 m .6451 .76275 L .64708 .76209 L F
.636 .635 .832 r
.38847 .88578 m .38578 .88391 L .38679 .8826 L F
.434 .818 .989 r
.53686 .82297 m .53895 .82265 L .54005 .82319 L F
.379 0 0 r
.53845 .8191 m .54218 .82061 L .53979 .81951 L F
.975 .841 .645 r
.54005 .82319 m .53979 .81951 L .54218 .82061 L F
.54005 .82319 m .53895 .82265 L .53979 .81951 L F
0 .481 .72 r
.5357 .80635 m .5333 .80592 L .53305 .80583 L F
.585 .329 .496 r
.37169 .76536 m .36981 .76344 L .36972 .76576 L F
.37169 .76536 m .37212 .76334 L .36981 .76344 L F
.751 .777 .874 r
.38023 .87515 m .38161 .87531 L .38087 .87584 L F
.561 .816 .993 r
.41065 .88021 m .4138 .88049 L .41182 .88099 L F
.542 .302 .502 r
.37481 .77381 m .37437 .77676 L .37218 .77693 L F
.526 .295 .507 r
.37687 .77347 m .37437 .77676 L .37481 .77381 L F
0 .432 .852 r
.48311 .88613 m .48374 .88584 L .48219 .88522 L F
.48311 .88613 m .48601 .88744 L .48374 .88584 L F
.435 0 0 r
.48311 .88613 m .48685 .88809 L .48601 .88744 L F
.542 .403 .642 r
.49419 .8364 m .49436 .83874 L .49667 .83764 L F
.287 .672 .972 r
.63867 .76304 m .64078 .7635 L .63957 .76251 L F
.656 .292 .342 r
.63867 .76304 m .6403 .76464 L .64078 .7635 L F
.982 .744 .5 r
.63957 .76251 m .6403 .76464 L .63867 .76304 L F
.955 .61 .289 r
.49268 .83391 m .49043 .83408 L .49014 .83331 L F
.49268 .83391 m .492 .83549 L .49043 .83408 L F
.805 .368 .209 r
.49268 .83391 m .492 .83549 L .49014 .83331 L F
.955 .61 .289 r
.49268 .83391 m .49313 .83629 L .492 .83549 L F
0 0 0 r
.4932 .83393 m .492 .83549 L .49268 .83391 L F
.193 .3 .746 r
.49043 .83408 m .492 .83549 L .49014 .83331 L F
.836 .884 .877 r
.49078 .83481 m .492 .83549 L .4932 .83393 L F
.894 .844 .789 r
.4932 .83393 m .49237 .83436 L .49243 .83416 L F
0 0 0 r
.4959 .83313 m .4932 .83393 L .49268 .83391 L F
.836 .884 .877 r
.49078 .83481 m .4932 .83393 L .49297 .83223 L F
.894 .844 .789 r
.4932 .83393 m .49243 .83416 L .49297 .83223 L F
0 0 0 r
.49632 .83303 m .4932 .83393 L .4959 .83313 L F
.535 .223 .385 r
.38202 .7691 m .38137 .77071 L .37936 .7708 L F
.431 .12 .335 r
.38332 .77027 m .38202 .7691 L .38388 .76876 L F
.38332 .77027 m .38137 .77071 L .38202 .7691 L F
.768 .98 .911 r
.61308 .74599 m .61054 .74788 L .61127 .74635 L F
.78 .992 .883 r
.61054 .74788 m .6098 .74768 L .61127 .74635 L F
.787 .704 .773 r
.39084 .82549 m .39231 .82813 L .38864 .82826 L F
.38973 .82688 m .38864 .82826 L .38863 .82826 L F
.39084 .82549 m .38864 .82826 L .38973 .82688 L F
.502 .303 .543 r
.38973 .82688 m .39083 .82548 L .38886 .82588 L F
.787 .704 .773 r
.39083 .82548 m .39084 .82549 L .38863 .82826 L F
.502 .303 .543 r
.39064 .82793 m .39083 .82548 L .38973 .82688 L F
.39064 .82793 m .38973 .82688 L .38863 .82826 L F
.38973 .82688 m .38886 .82588 L .38863 .82826 L F
.789 .675 .738 r
.38863 .82826 m .39231 .82813 L .38926 .83038 L F
.762 .696 .789 r
.39407 .82578 m .39231 .82813 L .39083 .82548 L F
.43 .247 .529 r
.3939 .82805 m .39231 .82813 L .39407 .82578 L F
0 0 0 r
.36774 .76614 m .36805 .76663 L .36972 .76576 L F
.36774 .76614 m .36626 .76766 L .36805 .76663 L F
.54 .075 .098 r
.43671 .82438 m .43861 .82472 L .43988 .82333 L F
.683 .339 .387 r
.43861 .82472 m .44193 .82313 L .43988 .82333 L F
.426 .088 .288 r
.64258 .77079 m .6419 .77299 L .63977 .77345 L F
.148 0 .177 r
.64318 .77221 m .64258 .77079 L .64466 .77029 L F
.64318 .77221 m .6419 .77299 L .64258 .77079 L F
.44 .221 .484 r
.38863 .82826 m .38687 .82871 L .38648 .83089 L F
.38863 .82826 m .38687 .82871 L .38648 .83089 L F
.787 .668 .731 r
.41411 .84636 m .4125 .84904 L .41265 .84697 L F
.649 .486 .649 r
.41411 .84636 m .41537 .84982 L .4125 .84904 L F
.606 .463 .661 r
.4176 .84915 m .41411 .84636 L .4175 .84642 L F
.4176 .84915 m .41537 .84982 L .41411 .84636 L F
.537 .191 .329 r
.52691 .81309 m .52597 .81498 L .52471 .81508 L F
.52691 .81309 m .52471 .81508 L .52481 .81458 L F
.555 .327 .525 r
.52578 .81623 m .52398 .81778 L .52403 .81513 L F
.58 .308 .469 r
.52597 .81498 m .52578 .81623 L .52403 .81513 L F
0 0 .082 r
.52601 .81233 m .52447 .81634 L .52705 .8115 L F
.52447 .81634 m .52439 .81654 L .52445 .81642 L F
.52447 .81634 m .52445 .81642 L .52705 .8115 L F
.537 .191 .329 r
.52481 .81458 m .52471 .81508 L .52403 .81513 L F
.698 .757 .898 r
.50155 .80991 m .50477 .81068 L .50335 .81048 L F
.724 .38 .395 r
.50178 .81223 m .50477 .81068 L .50155 .80991 L F
.50178 .81223 m .50362 .8124 L .50477 .81068 L F
.547 .171 .281 r
.50477 .81068 m .50362 .8124 L .50682 .81213 L F
.83 .858 .866 r
.64582 .73185 m .64447 .73181 L .64682 .72951 L F
.642 .457 .618 r
.64582 .73185 m .64542 .7349 L .64447 .73181 L F
.64582 .73185 m .6476 .73405 L .64542 .7349 L F
.402 .162 .432 r
.59936 .8381 m .59775 .83882 L .59995 .83629 L F
.191 .063 .466 r
.60169 .83317 m .60161 .83559 L .59995 .83629 L F
.282 .113 .465 r
.60161 .83559 m .59936 .8381 L .59995 .83629 L F
0 0 0 r
.45267 .88606 m .4535 .88574 L .45547 .88524 L F
.723 .531 .63 r
.59505 .81294 m .59465 .81531 L .59255 .81514 L F
.63 .491 .674 r
.59721 .81003 m .59723 .8124 L .59505 .81294 L F
.579 .344 .524 r
.59505 .81294 m .5968 .81499 L .59465 .81531 L F
.59505 .81294 m .59723 .8124 L .5968 .81499 L F
.137 0 .315 r
.59883 .84016 m .59775 .83882 L .59936 .8381 L F
.59883 .84016 m .59766 .84108 L .59775 .83882 L F
.504 .251 .465 r
.40196 .74802 m .4014 .74997 L .39939 .75033 L F
.40196 .74802 m .4014 .74997 L .39939 .75033 L F
.319 .079 .385 r
.40349 .74734 m .4014 .74997 L .40196 .74802 L F
.40196 .74802 m .4014 .74997 L .40349 .74734 L F
.737 .658 .772 r
.63094 .75549 m .63505 .75655 L .63311 .75301 L F
.762 .667 .757 r
.63311 .75301 m .63505 .75655 L .6362 .75506 L F
.502 .565 .852 r
.67358 .74373 m .67218 .74518 L .67128 .74294 L F
.546 .12 .185 r
.40984 .82781 m .41206 .82811 L .41306 .82648 L F
.533 .108 .179 r
.41306 .82648 m .41206 .82811 L .41511 .82734 L F
.475 .322 .593 r
.6128 .80151 m .60977 .79978 L .61278 .79931 L F
.6128 .80151 m .61087 .802 L .60977 .79978 L F
.433 .65 .95 r
.37338 .73704 m .37217 .73807 L .37129 .73726 L F
.37338 .73704 m .37481 .73867 L .37217 .73807 L F
.107 0 0 r
.34734 .72648 m .34975 .72512 L .34788 .72506 L F
.817 .444 0 r
.57782 .80483 m .5765 .8019 L .57717 .80485 L F
.829 .44 0 r
.57822 .80659 m .57782 .80483 L .57717 .80485 L F
.57822 .80659 m .5794 .80861 L .57782 .80483 L F
.734 .494 .565 r
.5794 .80861 m .57955 .80557 L .57782 .80483 L F
.661 .229 .21 r
.47522 .8363 m .47396 .83763 L .472 .83613 L F
.644 .162 0 r
.47522 .8363 m .47605 .83762 L .47396 .83763 L F
.47522 .8363 m .4768 .83829 L .47605 .83762 L F
.465 .839 .989 r
.47692 .83673 m .47541 .83704 L .47605 .83762 L F
.47541 .83704 m .47482 .83716 L .47605 .83762 L F
.644 .162 0 r
.4768 .83829 m .47723 .83883 L .47605 .83762 L F
.725 .457 .521 r
.50701 .82557 m .50491 .82329 L .5074 .82323 L F
.50701 .82557 m .50511 .82559 L .50491 .82329 L F
.517 .408 .669 r
.38768 .75027 m .38652 .75311 L .38552 .7499 L F
.38768 .75027 m .3884 .75273 L .38652 .75311 L F
.525 .441 .703 r
.3884 .75273 m .38878 .75493 L .38652 .75311 L F
.967 .892 .701 r
.50477 .83613 m .50389 .83806 L .5057 .837 L F
.569 .728 .949 r
.34839 .72764 m .34789 .72884 L .3467 .72846 L F
.34789 .72884 m .34768 .72934 L .34708 .7288 L F
.34789 .72884 m .34708 .7288 L .3467 .72846 L F
.64 .26 .308 r
.35055 .72712 m .34977 .72892 L .34775 .72784 L F
.34977 .72892 m .34972 .72903 L .34952 .72891 L F
.34977 .72892 m .34952 .72891 L .34775 .72784 L F
.19 .352 .797 r
.35123 .72586 m .35055 .72712 L .34975 .72512 L F
.936 .629 .434 r
.34972 .72903 m .35117 .72906 L .35055 .72712 L F
0 0 0 r
.35123 .72586 m .34972 .72903 L .35055 .72712 L F
.713 .597 .724 r
.64036 .74998 m .64361 .75052 L .64232 .74735 L F
.717 .485 0 r
.56447 .84412 m .56472 .84577 L .56407 .84348 L F
.56447 .84412 m .56475 .84573 L .56472 .84577 L F
.532 .459 .719 r
.58844 .77121 m .58901 .77427 L .59102 .77322 L F
.611 .561 .773 r
.58901 .77427 m .59093 .77542 L .59102 .77322 L F
.767 .677 .763 r
.63507 .73725 m .63606 .74017 L .63293 .73992 L F
.738 .662 .775 r
.63801 .73768 m .63606 .74017 L .63507 .73725 L F
.435 .571 .891 r
.43724 .8767 m .43564 .87676 L .43431 .87483 L F
.926 .657 .509 r
.64121 .74433 m .6445 .74233 L .64355 .74192 L F
.726 .941 .955 r
.64551 .74095 m .6445 .74233 L .6467 .74215 L F
.64551 .74095 m .64355 .74192 L .6445 .74233 L F
.692 .553 .692 r
.38683 .86765 m .38395 .86966 L .38421 .8675 L F
.611 .492 .694 r
.38437 .87986 m .38195 .88262 L .38182 .88054 L F
.762 .667 .757 r
.63311 .75301 m .6362 .75506 L .63495 .75244 L F
.646 .511 .684 r
.59743 .78904 m .59935 .78632 L .59722 .78675 L F
.735 .525 .609 r
.39921 .86322 m .39664 .86223 L .4 .8623 L F
.675 .537 .689 r
.40152 .86018 m .40213 .86265 L .4 .8623 L F
.599 .268 .379 r
.40213 .86265 m .39921 .86322 L .4 .8623 L F
.863 .822 .806 r
.58365 .77312 m .58844 .77121 L .58688 .7722 L F
.531 .804 .996 r
.58844 .77121 m .59065 .7709 L .58924 .77007 L F
.671 .966 .766 r
.58924 .77007 m .58688 .7722 L .58844 .77121 L F
.532 .459 .719 r
.58844 .77121 m .59102 .77322 L .59065 .7709 L F
.393 .845 .911 r
.39609 .8987 m .39904 .89829 L .39783 .89804 L F
.522 .89 .972 r
.39783 .89804 m .39904 .89829 L .40078 .89774 L F
.66 .66 .84 r
.62526 .74212 m .6223 .7405 L .62433 .73958 L F
.753 .709 .811 r
.62747 .73988 m .62526 .74212 L .62433 .73958 L F
.433 0 0 r
.57484 .83985 m .57343 .83885 L .57222 .8384 L F
.06 .438 .875 r
.57649 .84099 m .57442 .83955 L .57582 .8403 L F
.57442 .83955 m .57343 .83885 L .57582 .8403 L F
.361 0 0 r
.57484 .83985 m .57691 .84088 L .57582 .8403 L F
.57691 .84088 m .578 .84142 L .57582 .8403 L F
.433 0 0 r
.57484 .83985 m .57582 .8403 L .57343 .83885 L F
0 .066 .625 r
.5748 .79673 m .57576 .79917 L .57466 .79954 L F
.621 .604 .812 r
.57576 .79917 m .57711 .79666 L .57466 .79954 L F
.57576 .79917 m .57816 .79969 L .57711 .79666 L F
.809 .47 .414 r
.46979 .83582 m .46846 .83634 L .46694 .83489 L F
.705 .332 .34 r
.472 .83613 m .46846 .83634 L .46979 .83582 L F
.721 .68 .81 r
.44908 .87252 m .45254 .87196 L .45217 .86991 L F
0 .007 .572 r
.44908 .87252 m .4506 .8737 L .45254 .87196 L F
.726 .609 .727 r
.45463 .87 m .45433 .87053 L .45217 .86991 L F
.45433 .87053 m .45303 .87279 L .45274 .87182 L F
.45433 .87053 m .45274 .87182 L .45217 .86991 L F
.628 .552 .749 r
.4551 .87248 m .45303 .87279 L .45217 .86991 L F
0 0 0 r
.45307 .87169 m .45262 .87191 L .4506 .8737 L F
.45262 .87191 m .45254 .87196 L .45223 .87224 L F
.45262 .87191 m .45223 .87224 L .4506 .8737 L F
0 0 .38 r
.45217 .86991 m .45254 .87196 L .45307 .87169 L F
.845 .528 .452 r
.35823 .76815 m .35885 .76965 L .36009 .76843 L F
.076 .043 .512 r
.36098 .76539 m .36009 .76843 L .35885 .76965 L F
.219 .709 .924 r
.36009 .76843 m .36127 .76811 L .36228 .76852 L F
.593 .475 .688 r
.40292 .85683 m .39938 .85323 L .40259 .85456 L F
.40292 .85683 m .40092 .85785 L .39938 .85323 L F
.402 0 .035 r
.65455 .76587 m .65137 .76736 L .6524 .76615 L F
.305 0 .043 r
.47357 .81746 m .47494 .81758 L .47624 .81622 L F
.406 0 .119 r
.47624 .81622 m .47494 .81758 L .47777 .81682 L F
.87 .908 .855 r
.65178 .7265 m .64832 .72794 L .65078 .72664 L F
.586 .256 .377 r
.65078 .72664 m .65396 .72479 L .65178 .7265 L F
.564 .82 .993 r
.50053 .81793 m .50367 .81822 L .50263 .81734 L F
.606 .049 0 r
.50367 .81822 m .50464 .81946 L .50263 .81734 L F
.50367 .81822 m .50582 .82005 L .50464 .81946 L F
.403 .842 .72 r
.4232 .89262 m .42232 .89321 L .42331 .89271 L F
.4232 .89262 m .42169 .89343 L .42232 .89321 L F
.866 .626 .573 r
.50999 .82947 m .50688 .82808 L .51035 .82849 L F
.50999 .82947 m .5081 .83048 L .50688 .82808 L F
.695 .352 .392 r
.50999 .82947 m .50791 .83286 L .51018 .83257 L F
0 0 0 r
.50898 .8319 m .50834 .83215 L .50999 .82947 L F
.337 .395 .775 r
.50688 .82808 m .5081 .83048 L .50601 .82915 L F
.763 .664 .752 r
.50579 .83135 m .50898 .8319 L .508 .82895 L F
.427 .834 .974 r
.50785 .83177 m .5094 .83173 L .50898 .8319 L F
.645 .482 .647 r
.51018 .83257 m .5123 .82968 L .50999 .82947 L F
.333 0 .041 r
.5123 .82968 m .51093 .83169 L .50898 .8319 L F
.31 .231 .603 r
.51246 .82718 m .50999 .82947 L .51035 .82849 L F
.26 0 0 r
.50999 .82947 m .51364 .82865 L .51149 .82916 L F
.50999 .82947 m .5123 .82968 L .51364 .82865 L F
.31 .231 .603 r
.51246 .82718 m .5124 .8281 L .50999 .82947 L F
.541 .853 .998 r
.51102 .82888 m .51149 .82916 L .50999 .82947 L F
.26 0 0 r
.50999 .82947 m .5123 .82968 L .51364 .82865 L F
.31 .231 .603 r
.5124 .8281 m .5123 .82968 L .50999 .82947 L F
.541 .853 .998 r
.51035 .82849 m .51102 .82888 L .50999 .82947 L F
.333 0 .041 r
.5123 .82968 m .50898 .8319 L .50999 .82947 L F
.645 .482 .647 r
.51018 .83257 m .51448 .83289 L .5123 .82968 L F
.527 .518 .789 r
.50898 .8319 m .51093 .83169 L .50991 .82868 L F
.427 .834 .974 r
.5094 .83173 m .51093 .83169 L .50898 .8319 L F
0 0 0 r
.50898 .8319 m .50791 .83286 L .50834 .83215 L F
.557 .509 .757 r
.40292 .85683 m .40152 .86018 L .40092 .85785 L F
.40292 .85683 m .40394 .86034 L .40152 .86018 L F
.607 .494 .699 r
.40446 .8621 m .40152 .86018 L .40394 .86034 L F
.40446 .8621 m .40213 .86265 L .40152 .86018 L F
.769 .615 .688 r
.63921 .74697 m .64251 .74522 L .64121 .74433 L F
.63921 .74697 m .64232 .74735 L .64251 .74522 L F
.733 .514 .595 r
.40845 .85148 m .4092 .85516 L .40493 .85408 L F
.649 .459 .613 r
.40989 .85397 m .40845 .85148 L .4101 .85167 L F
.40989 .85397 m .4092 .85516 L .40845 .85148 L F
.402 .334 .665 r
.67772 .74975 m .67604 .75226 L .67649 .74973 L F
.35 .61 .947 r
.41519 .89522 m .4158 .89455 L .41484 .89488 L F
.41519 .89522 m .41731 .89597 L .4158 .89455 L F
.741 .733 .844 r
.5241 .84146 m .52554 .84382 L .52352 .84447 L F
.591 .72 .933 r
.52608 .84144 m .52554 .84382 L .5241 .84146 L F
.52608 .84144 m .52772 .84353 L .52554 .84382 L F
0 .272 .706 r
.48601 .88744 m .48685 .88809 L .48729 .88815 L F
0 .314 .716 r
.48685 .88809 m .48882 .88908 L .48729 .88815 L F
.855 .997 .783 r
.50379 .82204 m .50464 .81946 L .50582 .82005 L F
.50379 .82204 m .50254 .82202 L .50464 .81946 L F
.727 .942 .954 r
.57256 .81008 m .57493 .80961 L .5741 .80806 L F
.705 .795 .921 r
.57493 .80961 m .57615 .8072 L .5741 .80806 L F
.57493 .80961 m .57731 .80854 L .57615 .8072 L F
.8 .402 .298 r
.56325 .79866 m .56619 .79969 L .56426 .79722 L F
.77 .412 .378 r
.56426 .79722 m .56619 .79969 L .5679 .79928 L F
.54 .57 .834 r
.38536 .82552 m .38863 .82826 L .38886 .82588 L F
.787 .704 .773 r
.39083 .82548 m .38863 .82826 L .38886 .82588 L F
.327 .061 .349 r
.67124 .75949 m .66982 .75864 L .67191 .7583 L F
.67124 .75949 m .66946 .76031 L .66982 .75864 L F
.584 .457 .674 r
.37614 .7555 m .37748 .75626 L .37827 .7551 L F
.37614 .7555 m .37655 .75817 L .37748 .75626 L F
.653 .345 .438 r
.37971 .87108 m .38102 .87234 L .37923 .87237 L F
.541 .357 .581 r
.38174 .86991 m .37971 .87108 L .38164 .86993 L F
.38174 .86991 m .38102 .87234 L .37971 .87108 L F
.38174 .86991 m .37971 .87108 L .38164 .86993 L F
.38174 .86991 m .38102 .87234 L .37971 .87108 L F
.622 .169 .155 r
.5822 .80736 m .57955 .80557 L .5794 .80861 L F
.666 .601 .772 r
.44946 .87343 m .45332 .87457 L .45125 .87559 L F
0 0 0 r
.42694 .87571 m .4247 .87816 L .42643 .87651 L F
.068 0 .02 r
.42694 .87571 m .42738 .87681 L .42871 .875 L F
.42694 .87571 m .42643 .87651 L .42738 .87681 L F
.698 .601 .744 r
.59811 .78122 m .60137 .78155 L .60188 .77989 L F
.512 .339 .583 r
.6089 .80408 m .60842 .80239 L .61087 .802 L F
.432 .15 .383 r
.51382 .85188 m .51178 .85408 L .5138 .85421 L F
.51382 .85188 m .51178 .85408 L .5138 .85421 L F
.583 .553 .787 r
.51382 .85188 m .5159 .85158 L .51465 .84857 L F
.741 .733 .844 r
.5241 .84146 m .52352 .84447 L .52202 .84175 L F
.726 .798 .908 r
.38308 .87471 m .38161 .87531 L .38023 .87515 L F
.834 .856 .862 r
.49581 .80937 m .49298 .81007 L .49496 .8094 L F
.63 .365 .498 r
.49577 .80941 m .49392 .81199 L .49367 .81103 L F
.49579 .80941 m .49392 .81199 L .49577 .80941 L F
.49581 .80937 m .49669 .81239 L .49392 .81199 L F
.773 .448 .436 r
.49756 .81223 m .49669 .81239 L .49581 .80937 L F
.26 0 0 r
.49496 .8094 m .49683 .80986 L .49771 .80995 L F
.4973 .80983 m .49771 .80995 L .4982 .81 L F
.49496 .8094 m .49771 .80995 L .4973 .80983 L F
.63 .365 .498 r
.49581 .80937 m .49579 .80941 L .49577 .80941 L F
.484 .241 .469 r
.52134 .81044 m .52276 .81213 L .52294 .81003 L F
.52134 .81044 m .52064 .81283 L .52276 .81213 L F
.648 .231 .239 r
.56943 .82041 m .57198 .82074 L .57115 .82228 L F
.609 .251 .338 r
.46735 .83352 m .46375 .83492 L .46361 .83404 L F
.46735 .83352 m .46541 .83561 L .46375 .83492 L F
.86 .61 .56 r
.46694 .83489 m .46541 .83561 L .46735 .83352 L F
.829 .556 .527 r
.44675 .87436 m .44946 .87343 L .44908 .87252 L F
0 .007 .572 r
.44908 .87252 m .44946 .87343 L .4506 .8737 L F
.737 .668 .783 r
.63737 .74779 m .64036 .74998 L .63921 .74697 L F
.63737 .74779 m .6384 .75069 L .64036 .74998 L F
.759 .665 .757 r
.63921 .74697 m .64036 .74998 L .64232 .74735 L F
.156 0 0 r
.45956 .88477 m .46115 .88382 L .46318 .88352 L F
.462 .255 .511 r
.6232 .78845 m .62086 .78621 L .6232 .78568 L F
.6232 .78845 m .62129 .78898 L .62086 .78621 L F
.601 .295 .424 r
.66272 .76285 m .66503 .7628 L .66191 .76369 L F
.433 0 0 r
.48906 .8402 m .48584 .8383 L .48751 .839 L F
0 0 0 r
.40004 .82765 m .39732 .82867 L .39959 .82824 L F
.046 0 0 r
.40241 .82655 m .40004 .82765 L .39959 .82824 L F
0 0 0 r
.5736 .77054 m .57476 .76933 L .57128 .77185 L F
.462 .831 .58 r
.5736 .77054 m .57654 .76826 L .57476 .76933 L F
.176 0 0 r
.51644 .87825 m .51939 .87758 L .51843 .87806 L F
.305 0 .02 r
.51939 .87758 m .52006 .8788 L .51843 .87806 L F
.51939 .87758 m .52121 .87715 L .52006 .8788 L F
.649 .455 .608 r
.51077 .8229 m .50701 .82557 L .5074 .82323 L F
.854 .837 .829 r
.57207 .82034 m .57277 .8174 L .57122 .81997 L F
0 0 0 r
.57122 .81997 m .57277 .8174 L .572 .81912 L F
.57122 .81997 m .572 .81912 L .57028 .81956 L F
.57122 .81997 m .57028 .81956 L .56987 .81966 L F
.854 .837 .829 r
.57198 .82074 m .57207 .82034 L .57122 .81997 L F
.57198 .82074 m .57429 .81795 L .57277 .8174 L F
.998 .785 .45 r
.57115 .82228 m .57198 .82074 L .57122 .81997 L F
.761 .962 .932 r
.58424 .76364 m .58481 .7621 L .5854 .76249 L F
.58424 .76364 m .58337 .76321 L .58481 .7621 L F
.507 .812 1 r
.48626 .87858 m .48471 .87898 L .48294 .87813 L F
.652 .943 .96 r
.59342 .75798 m .59446 .75658 L .59703 .75564 L F
.59342 .75798 m .5926 .75762 L .59446 .75658 L F
.606 .444 .635 r
.60137 .78155 m .60158 .78366 L .60381 .78319 L F
.289 .778 .903 r
.4921 .88909 m .49276 .88861 L .49066 .88873 L F
.4921 .88909 m .49421 .88881 L .49276 .88861 L F
.624 .527 .724 r
.60009 .77438 m .60119 .77084 L .59912 .77126 L F
.60009 .77438 m .60224 .77383 L .60119 .77084 L F
.378 .462 .82 r
.5751 .83038 m .57432 .83104 L .57318 .82816 L F
0 0 0 r
.57325 .83257 m .57432 .83104 L .5751 .83038 L F
.593 .444 .649 r
.3927 .75819 m .39302 .76044 L .39089 .76068 L F
.571 .373 .574 r
.39302 .76044 m .39085 .7629 L .39089 .76068 L F
.248 0 0 r
.41511 .82734 m .41718 .82727 L .41864 .82658 L F
.042 0 0 r
.41864 .82658 m .41914 .82688 L .42071 .82647 L F
.41864 .82658 m .41718 .82727 L .41914 .82688 L F
.473 .246 .489 r
.6232 .78568 m .62345 .78385 L .62524 .7834 L F
.52 .909 .77 r
.60274 .75228 m .60393 .75121 L .60549 .75071 L F
.60274 .75228 m .60218 .75235 L .60393 .75121 L F
.983 .714 .433 r
.60043 .79388 m .60163 .79457 L .60045 .79164 L F
.944 .646 .443 r
.60052 .79622 m .60206 .79683 L .60163 .79457 L F
.748 .674 .779 r
.63515 .75025 m .6384 .75069 L .63737 .74779 L F
.776 .675 .752 r
.63495 .75244 m .6384 .75069 L .63515 .75025 L F
.733 .859 .94 r
.52325 .83294 m .51991 .83327 L .52199 .83296 L F
.895 .963 .828 r
.52325 .83294 m .5241 .83034 L .52528 .83263 L F
.52325 .83294 m .52199 .83296 L .5241 .83034 L F
.337 .395 .775 r
.50688 .82808 m .50601 .82915 L .50487 .82792 L F
.708 .565 .691 r
.4125 .84904 m .41349 .85181 L .4101 .85167 L F
.648 .533 .71 r
.41568 .85159 m .4125 .84904 L .41537 .84982 L F
.41568 .85159 m .41349 .85181 L .4125 .84904 L F
0 0 .082 r
.5942 .8302 m .59288 .83085 L .59236 .83267 L F
.488 .271 .509 r
.62587 .78153 m .62781 .78283 L .62524 .7834 L F
.62587 .78153 m .62784 .78106 L .62781 .78283 L F
.424 .866 .8 r
.4247 .87816 m .42097 .87954 L .42274 .87858 L F
.363 .834 .814 r
.4247 .87816 m .42558 .87764 L .42643 .87651 L F
.4247 .87816 m .42274 .87858 L .42558 .87764 L F
.509 .285 .51 r
.36746 .78115 m .36518 .78365 L .36551 .78152 L F
.979 .758 .535 r
.49186 .81928 m .48991 .81858 L .48984 .8202 L F
.589 .371 .552 r
.39112 .86695 m .38915 .86478 L .39126 .86457 L F
.39112 .86695 m .38895 .86725 L .38915 .86478 L F
.055 .242 .738 r
.39798 .88042 m .39889 .87978 L .4 .88049 L F
.39798 .88042 m .39855 .88072 L .39889 .87978 L F
.581 .92 .965 r
.42701 .89159 m .43016 .89101 L .42895 .8908 L F
.593 .92 .97 r
.43078 .88998 m .43016 .89101 L .43179 .89022 L F
.6 .927 .965 r
.42895 .8908 m .43016 .89101 L .43078 .88998 L F
0 .423 .717 r
.35614 .7296 m .35819 .73018 L .35982 .7307 L F
.268 .704 .964 r
.36025 .73 m .35982 .7307 L .35819 .73018 L F
.36025 .73 m .36184 .73074 L .35982 .7307 L F
.586 .62 .852 r
.57115 .82228 m .57036 .82508 L .5694 .82354 L F
.569 .437 .661 r
.59832 .79198 m .60047 .78938 L .59743 .78904 L F
.59832 .79198 m .60045 .79164 L .60047 .78938 L F
.538 .324 .537 r
.60043 .79388 m .60045 .79164 L .59832 .79198 L F
.569 .437 .661 r
.60047 .78938 m .60045 .79164 L .59832 .79198 L F
.461 .225 .468 r
.67604 .75226 m .67619 .75488 L .67413 .75541 L F
.402 .334 .665 r
.67772 .74975 m .67822 .75217 L .67604 .75226 L F
.453 .255 .52 r
.67822 .75217 m .67619 .75488 L .67604 .75226 L F
.615 .279 .378 r
.37578 .83322 m .37917 .83146 L .37701 .83244 L F
.37578 .83322 m .37784 .83309 L .37917 .83146 L F
.595 .288 .42 r
.38111 .83263 m .37917 .83146 L .37784 .83309 L F
.38111 .83263 m .38048 .83129 L .37917 .83146 L F
.646 .511 .684 r
.59743 .78904 m .60047 .78938 L .59935 .78632 L F
.357 0 0 r
.65783 .76502 m .65973 .76501 L .65686 .76581 L F
.126 0 0 r
.46622 .88256 m .46711 .88279 L .46511 .88298 L F
.46622 .88256 m .46832 .88236 L .46711 .88279 L F
.699 .495 .607 r
.39664 .86223 m .39281 .86444 L .39322 .86247 L F
.545 .893 .98 r
.60215 .82778 m .60102 .82882 L .6002 .82871 L F
.60215 .82778 m .60319 .82814 L .60102 .82882 L F
.388 .848 .819 r
.49168 .87744 m .48973 .87818 L .48866 .87835 L F
.645 .667 .857 r
.54645 .83314 m .54559 .83633 L .54524 .8347 L F
.54645 .83314 m .54776 .83634 L .54559 .83633 L F
0 .208 .734 r
.54559 .83633 m .546 .8359 L .54524 .8347 L F
.645 .382 .506 r
.54559 .83633 m .54776 .83634 L .54769 .83836 L F
0 .208 .734 r
.54559 .83633 m .54769 .83836 L .546 .8359 L F
.714 .52 .626 r
.51231 .8206 m .51077 .8229 L .50914 .82081 L F
.51231 .8206 m .51218 .82322 L .51077 .8229 L F
.568 .753 .965 r
.36356 .73068 m .36286 .73221 L .36184 .73074 L F
.36356 .73068 m .36483 .73183 L .36286 .73221 L F
.519 .266 .47 r
.42013 .84448 m .41966 .84658 L .4175 .84642 L F
.607 .389 .56 r
.41974 .84873 m .4175 .84642 L .41966 .84658 L F
.41974 .84873 m .4176 .84915 L .4175 .84642 L F
.401 .435 .78 r
.48825 .83275 m .49043 .83408 L .49014 .83331 L F
.48825 .83275 m .49043 .83408 L .49014 .83331 L F
.537 .009 0 r
.57253 .8486 m .57571 .84873 L .57449 .84914 L F
.445 0 0 r
.57571 .84873 m .57775 .84904 L .57449 .84914 L F
.588 .764 .963 r
.49539 .87548 m .49482 .87726 L .4936 .8767 L F
.49539 .87548 m .49885 .87719 L .49482 .87726 L F
.647 .666 .854 r
.35437 .73022 m .35117 .72906 L .35298 .72898 L F
.621 .762 .946 r
.35614 .7296 m .35437 .73022 L .35298 .72898 L F
.319 .349 .736 r
.51286 .84662 m .51465 .84857 L .51392 .84564 L F
.631 .419 .576 r
.56958 .77804 m .56721 .77598 L .5704 .77572 L F
.353 0 .189 r
.57253 .77566 m .56958 .77804 L .5704 .77572 L F
.745 .62 .72 r
.48976 .86723 m .4906 .87007 L .48748 .87006 L F
.12 0 0 r
.48748 .87006 m .4906 .87007 L .49155 .87017 L F
.178 .257 .708 r
.49168 .86907 m .4906 .87007 L .48976 .86723 L F
.208 .307 .746 r
.49155 .87017 m .4906 .87007 L .49168 .86907 L F
.594 .395 .582 r
.42167 .84359 m .41966 .84658 L .42013 .84448 L F
.573 .012 0 r
.538 .83202 m .53916 .83168 L .54145 .83299 L F
.609 .202 .246 r
.50682 .81213 m .50881 .81213 L .50998 .8106 L F
.59 .18 .233 r
.50998 .8106 m .50881 .81213 L .51211 .81166 L F
.49 0 0 r
.50998 .8106 m .51211 .81166 L .5129 .81169 L F
.638 .393 .532 r
.44734 .83604 m .44509 .83813 L .44548 .83603 L F
.617 .196 .221 r
.37462 .83285 m .37578 .83322 L .37701 .83244 L F
.21 0 0 r
.58518 .84851 m .58855 .84698 L .58732 .84828 L F
.274 0 0 r
.58855 .84698 m .58939 .84788 L .58732 .84828 L F
.58855 .84698 m .59088 .8467 L .58939 .84788 L F
.525 .508 .78 r
.59887 .80948 m .59721 .81003 L .59621 .80776 L F
.565 .472 .708 r
.59887 .80948 m .59723 .8124 L .59721 .81003 L F
.305 0 .161 r
.48365 .81316 m .48102 .81487 L .48373 .81361 L F
.512 .222 .41 r
.48373 .81361 m .48557 .81259 L .48365 .81316 L F
.873 .906 .85 r
.59649 .82075 m .5934 .82273 L .59509 .82023 L F
.64 .64 .834 r
.59766 .81762 m .59649 .82075 L .59509 .82023 L F
.59766 .81762 m .5989 .82047 L .59649 .82075 L F
.592 .338 .5 r
.59649 .82075 m .5989 .82047 L .59848 .8229 L F
.276 .29 .695 r
.59848 .8229 m .59741 .82343 L .59649 .82075 L F
.592 .338 .5 r
.59649 .82075 m .5989 .82047 L .59848 .8229 L F
.75 .753 .855 r
.5262 .82479 m .52722 .82494 L .52411 .8257 L F
.716 .543 .654 r
.52722 .82494 m .52419 .8283 L .52411 .8257 L F
.52722 .82494 m .5292 .82692 L .52419 .8283 L F
.537 .626 .887 r
.52859 .82374 m .52722 .82494 L .5262 .82479 L F
.52859 .82374 m .52945 .82569 L .52722 .82494 L F
.641 .353 .466 r
.52419 .8283 m .5292 .82692 L .52614 .83007 L F
.574 .264 .405 r
.52614 .83007 m .5292 .82692 L .52965 .82799 L F
.841 .392 .148 r
.52965 .82799 m .5292 .82692 L .52722 .82494 L F
.52965 .82799 m .52722 .82494 L .52945 .82569 L F
.6 .581 .804 r
.39792 .88294 m .39587 .88342 L .39459 .88042 L F
.624 .199 .215 r
.51929 .87436 m .51839 .87225 L .51699 .87343 L F
.51929 .87436 m .52056 .87287 L .51839 .87225 L F
.233 .729 .913 r
.57528 .77591 m .5746 .77559 L .57253 .77566 L F
0 0 0 r
.57528 .77591 m .57361 .77886 L .57469 .77769 L F
.57528 .77591 m .57469 .77769 L .5746 .77559 L F
.707 .649 .79 r
.4551 .87248 m .45656 .87551 L .45332 .87457 L F
.682 .754 .906 r
.45706 .87355 m .45656 .87551 L .4551 .87248 L F
.45706 .87355 m .45849 .87473 L .45656 .87551 L F
.491 .165 .342 r
.47061 .82012 m .47357 .81746 L .47072 .81806 L F
.47061 .82012 m .4727 .81989 L .47357 .81746 L F
.551 .292 .476 r
.4727 .81989 m .47494 .81758 L .47357 .81746 L F
.642 .791 .954 r
.49298 .81007 m .49367 .81103 L .49253 .8109 L F
.919 .534 .26 r
.57536 .80176 m .5765 .8019 L .57466 .79954 L F
.864 .571 .49 r
.57494 .80395 m .5765 .8019 L .57536 .80176 L F
.57494 .80395 m .57717 .80485 L .5765 .8019 L F
.599 .268 .379 r
.40213 .86265 m .40213 .86406 L .39921 .86322 L F
.645 .304 .38 r
.40213 .86265 m .40392 .86423 L .40213 .86406 L F
.554 .329 .529 r
.40446 .8621 m .40392 .86423 L .40213 .86265 L F
.726 .798 .908 r
.38308 .87471 m .38102 .87234 L .38178 .87224 L F
.38308 .87471 m .37959 .87439 L .38102 .87234 L F
.38308 .87471 m .38023 .87515 L .37959 .87439 L F
.571 .471 .702 r
.38475 .87255 m .38308 .87471 L .38178 .87224 L F
.38475 .87255 m .38522 .87484 L .38308 .87471 L F
.408 .401 .739 r
.38533 .87685 m .38308 .87471 L .38522 .87484 L F
.699 .495 .607 r
.39664 .86223 m .39652 .86461 L .39281 .86444 L F
.735 .525 .609 r
.39921 .86322 m .39652 .86461 L .39664 .86223 L F
.394 .129 .389 r
.53116 .87002 m .53335 .86775 L .53294 .86954 L F
.528 .787 .992 r
.53441 .86648 m .53335 .86775 L .53196 .86671 L F
0 0 .089 r
.53294 .86954 m .53335 .86775 L .53441 .86648 L F
.784 .649 .713 r
.40245 .74219 m .40267 .74545 L .40583 .74272 L F
.721 .69 .82 r
.59102 .77322 m .59093 .77542 L .59376 .77339 L F
.651 .365 .473 r
.39921 .86322 m .39846 .86663 L .39652 .86461 L F
.698 .478 .585 r
.40213 .86406 m .39846 .86663 L .39921 .86322 L F
.526 .133 .239 r
.45464 .82278 m .45678 .82285 L .45801 .82095 L F
.569 .18 .265 r
.45801 .82095 m .45678 .82285 L .45986 .82219 L F
.673 .529 .681 r
.41362 .85417 m .4101 .85167 L .41349 .85181 L F
.636 .46 .628 r
.41568 .85159 m .41362 .85417 L .41349 .85181 L F
.801 .584 .608 r
.4101 .85167 m .41151 .85491 L .40989 .85397 L F
.673 .529 .681 r
.41362 .85417 m .41151 .85491 L .4101 .85167 L F
0 0 .507 r
.55207 .82214 m .55285 .82513 L .55181 .82307 L F
.312 0 .162 r
.66761 .76107 m .66678 .76226 L .66503 .7628 L F
.218 0 .1 r
.66946 .76031 m .66678 .76226 L .66761 .76107 L F
.58 .585 .822 r
.52124 .84921 m .52332 .84896 L .52211 .84607 L F
.574 .626 .865 r
.39083 .75444 m .388 .75548 L .38878 .75493 L F
.39083 .75444 m .39218 .75688 L .388 .75548 L F
.805 .654 .695 r
.53562 .8182 m .53845 .8191 L .53824 .81992 L F
.547 .087 .112 r
.53979 .81951 m .53824 .81992 L .53845 .8191 L F
.648 .653 .841 r
.38745 .74861 m .38552 .7499 L .38497 .74862 L F
.38745 .74861 m .388 .74946 L .38552 .7499 L F
.647 .622 .811 r
.388 .74946 m .38768 .75027 L .38552 .7499 L F
.775 .542 .582 r
.3939 .82805 m .39407 .82578 L .39083 .82548 L F
.523 .326 .554 r
.39407 .82578 m .39624 .82316 L .39615 .82537 L F
.698 .562 .697 r
.39615 .82537 m .3939 .82805 L .39407 .82578 L F
.523 .326 .554 r
.39407 .82578 m .39624 .82316 L .39615 .82537 L F
.763 .662 .751 r
.39615 .82537 m .3939 .82805 L .39407 .82578 L F
.492 .259 .488 r
.52403 .81513 m .52156 .81751 L .5221 .81549 L F
.821 .811 .841 r
.57274 .78389 m .57467 .78592 L .57651 .78331 L F
.276 .356 .765 r
.56335 .83377 m .56417 .83627 L .56511 .83492 L F
.767 .676 .763 r
.38679 .8826 m .38578 .88391 L .38383 .88247 L F
.423 .023 .173 r
.6424 .76426 m .64078 .7635 L .6403 .76464 L F
.6424 .76426 m .64296 .76323 L .64078 .7635 L F
.511 .231 .426 r
.66809 .74409 m .66593 .74286 L .66584 .74445 L F
.521 .455 .722 r
.59228 .80207 m .59247 .80472 L .59477 .80431 L F
.638 .944 .955 r
.40376 .8968 m .40668 .89604 L .4055 .89582 L F
.633 .936 .964 r
.4073 .89495 m .40668 .89604 L .40871 .89549 L F
.4073 .89495 m .4055 .89582 L .40668 .89604 L F
.081 0 0 r
.47157 .88241 m .47235 .88255 L .47034 .88241 L F
.47157 .88241 m .47363 .88238 L .47235 .88255 L F
.033 0 0 r
.42071 .82647 m .42248 .82636 L .42389 .82591 L F
.236 0 0 r
.42248 .82636 m .42601 .82585 L .42389 .82591 L F
.263 .683 .966 r
.51763 .81172 m .51949 .81185 L .51882 .81245 L F
.213 .61 .95 r
.51949 .81185 m .52064 .81283 L .51882 .81245 L F
.596 .289 .419 r
.38111 .83263 m .38323 .83296 L .38048 .83129 L F
.606 .275 .383 r
.38323 .83296 m .38447 .83066 L .38048 .83129 L F
.786 .694 .763 r
.57711 .79666 m .57816 .79969 L .58054 .79684 L F
.444 .027 .152 r
.47777 .81682 m .47986 .81664 L .48102 .81487 L F
.312 0 .078 r
.48102 .81487 m .48195 .81611 L .48373 .81361 L F
.48102 .81487 m .47986 .81664 L .48195 .81611 L F
.344 .114 .414 r
.52198 .83839 m .52161 .84107 L .51977 .84161 L F
.369 .134 .422 r
.52294 .83975 m .52198 .83839 L .52389 .83836 L F
.52294 .83975 m .52161 .84107 L .52198 .83839 L F
.547 .396 .627 r
.50511 .82559 m .50286 .82784 L .50203 .8263 L F
.567 .176 .262 r
.46323 .82057 m .4653 .82172 L .46623 .82002 L F
.658 .321 .39 r
.4653 .82172 m .46844 .82013 L .46623 .82002 L F
.11 0 .18 r
.47412 .86783 m .47195 .87052 L .47449 .87021 L F
.87 .68 .642 r
.47412 .86783 m .47449 .87021 L .47339 .86922 L F
.132 0 .21 r
.47412 .86783 m .47339 .86922 L .47616 .86625 L F
.495 .874 .975 r
.57161 .79505 m .57368 .79488 L .57387 .79431 L F
.596 .833 .989 r
.40871 .89549 m .41186 .89562 L .41074 .89499 L F
.613 .855 .989 r
.41074 .89499 m .41186 .89562 L .41484 .89488 L F
.762 .697 .79 r
.38603 .87988 m .38679 .8826 L .38383 .88247 L F
.721 .673 .802 r
.38935 .88053 m .38679 .8826 L .38603 .87988 L F
.773 .98 .91 r
.61308 .74599 m .61389 .74437 L .61468 .74473 L F
.61308 .74599 m .61127 .74635 L .61389 .74437 L F
.102 0 0 r
.52496 .83755 m .52649 .83632 L .52842 .83578 L F
.172 0 .389 r
.52649 .83632 m .52812 .83349 L .52842 .83578 L F
.657 .53 .697 r
.59935 .78632 m .60247 .78689 L .60158 .78366 L F
.669 .523 .677 r
.59935 .78632 m .60047 .78938 L .60256 .78901 L F
.511 .025 .037 r
.44898 .87477 m .44946 .87343 L .44675 .87436 L F
0 0 0 r
.4506 .8737 m .44946 .87343 L .44898 .87477 L F
.585 .91 .977 r
.46406 .87284 m .46077 .87323 L .46264 .87237 L F
.466 .841 .988 r
.4647 .87197 m .46406 .87284 L .46264 .87237 L F
0 0 0 r
.56676 .77384 m .56827 .77309 L .56884 .77279 L F
.56676 .77384 m .56557 .775 L .56827 .77309 L F
.56 .548 .797 r
.39457 .75477 m .3927 .75819 L .39218 .75688 L F
.39457 .75477 m .39491 .7581 L .3927 .75819 L F
.639 .531 .716 r
.39491 .7581 m .39302 .76044 L .3927 .75819 L F
0 0 .565 r
.56858 .79969 m .5679 .79928 L .56619 .79969 L F
.814 .589 .597 r
.60206 .79683 m .60422 .79928 L .60162 .79915 L F
.824 .979 .887 r
.60604 .79627 m .60348 .79851 L .60265 .79815 L F
.60604 .79627 m .60265 .79815 L .60452 .79753 L F
.544 .866 .584 r
.60643 .79579 m .60604 .79627 L .60452 .79753 L F
.685 .804 .345 r
.60746 .79319 m .60692 .79453 L .60604 .79627 L F
.092 0 .351 r
.60746 .79319 m .60604 .79627 L .60745 .79487 L F
.544 .866 .584 r
.60745 .79487 m .60604 .79627 L .60643 .79579 L F
0 0 0 r
.60692 .79453 m .60557 .79683 L .60604 .79627 L F
.60557 .79683 m .60528 .79733 L .60604 .79627 L F
0 0 .28 r
.60741 .79125 m .60692 .79453 L .60746 .79319 L F
.557 .133 .192 r
.38517 .83241 m .38447 .83066 L .38323 .83296 L F
.38517 .83241 m .38648 .83089 L .38447 .83066 L F
0 0 0 r
.60604 .79627 m .60528 .79733 L .60422 .79928 L F
.594 .345 .51 r
.46844 .82013 m .47061 .82012 L .47072 .81806 L F
.735 .669 .785 r
.63698 .735 m .63801 .73768 L .63507 .73725 L F
.722 .662 .79 r
.64017 .73695 m .63801 .73768 L .63698 .735 L F
.522 .014 0 r
.56472 .84577 m .56475 .84573 L .56652 .84751 L F
.922 .8 .707 r
.40009 .82247 m .40179 .82313 L .39976 .82525 L F
.839 .628 .617 r
.40179 .82313 m .40177 .82537 L .39976 .82525 L F
.464 .321 .601 r
.40352 .82497 m .40177 .82537 L .40179 .82313 L F
.728 .199 0 r
.40352 .82497 m .40179 .82313 L .40009 .82247 L F
.65 .212 .196 r
.51099 .8196 m .5079 .81967 L .50939 .81857 L F
.533 .348 .576 r
.51116 .81753 m .51099 .8196 L .50939 .81857 L F
.32 .729 .979 r
.52332 .84896 m .52654 .84967 L .52538 .84897 L F
.291 .647 .968 r
.52654 .84967 m .52739 .84888 L .52538 .84897 L F
.52654 .84967 m .52928 .85008 L .52739 .84888 L F
.598 .524 .742 r
.38633 .74455 m .38497 .74862 L .38433 .74492 L F
.38633 .74455 m .38745 .74861 L .38497 .74862 L F
.97 .867 .679 r
.48856 .84683 m .48769 .84938 L .48731 .84784 L F
0 0 0 r
.49015 .84427 m .48856 .84683 L .48921 .84589 L F
0 .172 .703 r
.54983 .81679 m .54948 .81806 L .54828 .81537 L F
.632 .203 0 r
.55038 .81961 m .54948 .81806 L .54983 .81679 L F
.55038 .81961 m .55129 .82099 L .54948 .81806 L F
.389 .073 .303 r
.52878 .87212 m .53116 .87002 L .53077 .87197 L F
.417 .18 .445 r
.53077 .87197 m .53116 .87002 L .53294 .86954 L F
.242 0 0 r
.49436 .83874 m .49315 .8399 L .49125 .8401 L F
.786 .365 .25 r
.49436 .83874 m .49612 .84092 L .49315 .8399 L F
.803 .333 .109 r
.49765 .84131 m .49612 .84092 L .49436 .83874 L F
0 0 0 r
.48416 .85254 m .48281 .85478 L .48332 .85439 L F
0 0 .364 r
.48281 .85478 m .48318 .85652 L .48332 .85439 L F
.648 .439 .585 r
.60381 .78319 m .60654 .78126 L .60361 .78166 L F
.546 .429 .672 r
.60268 .77616 m .60452 .77333 L .60224 .77383 L F
.60268 .77616 m .60466 .77562 L .60452 .77333 L F
.59 .52 .744 r
.60349 .77889 m .60466 .77562 L .60268 .77616 L F
.708 .704 .844 r
.47449 .87021 m .47195 .87052 L .47339 .86922 L F
.681 .557 .708 r
.47705 .8701 m .47487 .87257 L .47449 .87021 L F
.47705 .8701 m .47487 .87257 L .47449 .87021 L F
.122 0 0 r
.47195 .87052 m .46901 .8716 L .47088 .87133 L F
.64 .947 .727 r
.47339 .86922 m .47195 .87052 L .47088 .87133 L F
.787 .951 .925 r
.57361 .77886 m .57111 .78034 L .5728 .77867 L F
.572 .365 .562 r
.5748 .79673 m .57711 .79666 L .57702 .79449 L F
.579 .935 .934 r
.57361 .77886 m .5728 .77867 L .57469 .77769 L F
.763 .662 .751 r
.39615 .82537 m .39732 .82867 L .3939 .82805 L F
.191 .311 .757 r
.39854 .82778 m .39732 .82867 L .39615 .82537 L F
.725 .938 .617 r
.4004 .82763 m .39777 .83007 L .40047 .82919 L F
.046 0 0 r
.40241 .82655 m .39959 .82824 L .39976 .82525 L F
.725 .938 .617 r
.40038 .82695 m .39977 .82768 L .4004 .82763 L F
.458 .838 .987 r
.39853 .82779 m .39959 .82824 L .39732 .82867 L F
.136 .134 .591 r
.39976 .82525 m .39959 .82824 L .40038 .82695 L F
.458 .838 .987 r
.39855 .82778 m .39959 .82824 L .39853 .82779 L F
.725 .938 .617 r
.40038 .82695 m .39959 .82824 L .39777 .83007 L F
.39977 .82768 m .39777 .83007 L .4004 .82763 L F
.458 .838 .987 r
.39854 .82778 m .39855 .82778 L .39853 .82779 L F
.59 .52 .744 r
.60349 .77889 m .60561 .77853 L .60466 .77562 L F
.579 .929 .948 r
.5854 .76249 m .58657 .76117 L .58842 .76073 L F
.5854 .76249 m .58481 .7621 L .58657 .76117 L F
.812 .452 .376 r
.49874 .8334 m .49781 .83669 L .49632 .83303 L F
.664 .573 .743 r
.49909 .83646 m .50071 .83313 L .49874 .8334 L F
0 0 .074 r
.49931 .83456 m .49874 .8334 L .50071 .83313 L F
.49931 .83456 m .49781 .83669 L .49874 .8334 L F
.538 .61 .873 r
.37734 .73194 m .37676 .73456 L .37546 .7325 L F
.37734 .73194 m .37862 .73419 L .37676 .73456 L F
.534 .411 .658 r
.37862 .73419 m .3769 .73697 L .37676 .73456 L F
.801 .923 .918 r
.52637 .87111 m .52298 .87242 L .52456 .87175 L F
.235 0 .2 r
.52596 .87116 m .52456 .87175 L .52386 .87392 L F
.52613 .87094 m .52456 .87175 L .52596 .87116 L F
.801 .923 .918 r
.52298 .87242 m .5227 .87253 L .52456 .87175 L F
.453 .071 .224 r
.63756 .7737 m .6391 .77533 L .63718 .77516 L F
.63756 .7737 m .63977 .77345 L .6391 .77533 L F
.127 0 0 r
.47496 .87187 m .47561 .87141 L .47455 .87197 L F
.67 .922 .615 r
.47561 .87141 m .47487 .87257 L .47635 .8709 L F
.091 .208 .693 r
.47561 .87141 m .4767 .87488 L .47487 .87257 L F
.627 .558 .757 r
.47791 .8734 m .4767 .87488 L .47561 .87141 L F
.47791 .8734 m .47561 .87141 L .47766 .87115 L F
.127 0 0 r
.47766 .87115 m .47561 .87141 L .47496 .87187 L F
.67 .922 .615 r
.47561 .87141 m .47635 .8709 L .47705 .8701 L F
.289 0 .037 r
.35117 .72906 m .34768 .72934 L .34972 .72903 L F
.246 .723 .937 r
.35167 .72855 m .35117 .72906 L .34972 .72903 L F
.35167 .72855 m .35298 .72898 L .35117 .72906 L F
.6 .803 .977 r
.59513 .80688 m .59847 .80731 L .59621 .80776 L F
.525 .508 .78 r
.59887 .80948 m .59621 .80776 L .59847 .80731 L F
.614 .536 .743 r
.38195 .88262 m .38383 .88247 L .38205 .883 L F
.842 .879 .443 r
.55147 .83027 m .5523 .82868 L .55227 .82783 L F
0 .13 .672 r
.48999 .86666 m .48976 .86723 L .4882 .86662 L F
.48999 .86666 m .49168 .86907 L .48976 .86723 L F
.21 0 0 r
.48003 .87425 m .47947 .87411 L .47791 .8734 L F
.48044 .87441 m .48222 .87411 L .47947 .87411 L F
.48044 .87441 m .47947 .87411 L .48003 .87425 L F
.397 .034 .227 r
.48057 .87329 m .47923 .87405 L .47947 .87411 L F
.47923 .87405 m .47777 .87488 L .47947 .87411 L F
.431 0 0 r
.48222 .87411 m .48057 .87329 L .47947 .87411 L F
.36 .052 .3 r
.65892 .74969 m .66223 .74641 L .65873 .74792 L F
.57 .36 .557 r
.37412 .76061 m .37628 .76045 L .37655 .75817 L F
.547 .374 .599 r
.37628 .76045 m .37748 .75626 L .37655 .75817 L F
.565 .472 .708 r
.59887 .80948 m .59928 .81217 L .59723 .8124 L F
.632 .44 .605 r
.59928 .81217 m .5968 .81499 L .59723 .8124 L F
.521 .758 .983 r
.67241 .7493 m .67045 .75043 L .6693 .74946 L F
.67241 .7493 m .67262 .75013 L .67045 .75043 L F
.554 .748 .967 r
.40402 .87956 m .40314 .88101 L .40208 .87974 L F
.40402 .87956 m .40583 .88089 L .40314 .88101 L F
.722 .662 .79 r
.64017 .73695 m .63698 .735 L .63915 .73411 L F
.77 .698 .783 r
.64231 .73438 m .64017 .73695 L .63915 .73411 L F
.738 .611 .716 r
.49186 .81928 m .49353 .82234 L .49298 .82056 L F
.657 .378 .485 r
.49353 .82234 m .49527 .82277 L .49298 .82056 L F
.716 .921 .577 r
.58435 .80484 m .5822 .80736 L .58491 .80686 L F
.695 .757 .899 r
.51888 .82312 m .52076 .82478 L .51684 .82474 L F
.738 .522 .601 r
.52075 .82484 m .51684 .82474 L .52076 .82478 L F
.52043 .82717 m .51952 .82655 L .52075 .82484 L F
.51952 .82655 m .51684 .82474 L .52075 .82484 L F
.896 .977 .685 r
.52193 .82231 m .52076 .82478 L .51888 .82312 L F
.52193 .82231 m .52042 .82485 L .52076 .82478 L F
.638 .742 .923 r
.52193 .82231 m .5216 .82366 L .52042 .82485 L F
.5216 .82366 m .5212 .82533 L .52064 .82499 L F
.5216 .82366 m .52064 .82499 L .52042 .82485 L F
.52193 .82231 m .52306 .82434 L .5212 .82533 L F
.236 .212 .627 r
.52043 .82717 m .52042 .82485 L .5212 .82533 L F
.708 .521 .633 r
.52411 .8257 m .52176 .82589 L .5212 .82533 L F
.652 .293 .35 r
.48921 .84589 m .49236 .84591 L .49015 .84427 L F
.967 .703 .275 r
.57277 .8174 m .57296 .81666 L .57197 .81448 L F
.611 .492 .694 r
.38437 .87986 m .38383 .88247 L .38195 .88262 L F
.518 0 0 r
.47707 .88248 m .47859 .8832 L .47567 .88241 L F
.75 .717 .821 r
.62658 .73756 m .62747 .73988 L .62433 .73958 L F
.665 .672 .847 r
.62954 .73924 m .62747 .73988 L .62658 .73756 L F
0 0 0 r
.49933 .83992 m .49765 .84131 L .50021 .83914 L F
.92 .777 .687 r
.49855 .83835 m .49933 .83992 L .50021 .83914 L F
.65 .851 .977 r
.49855 .83835 m .50021 .83914 L .5018 .83825 L F
.641 .666 .859 r
.54865 .83275 m .54776 .83634 L .54645 .83314 L F
.09 0 0 r
.35301 .7502 m .35456 .75002 L .3522 .75076 L F
.536 .269 .458 r
.36322 .78402 m .36263 .78641 L .36052 .78644 L F
.441 .182 .424 r
.36441 .78593 m .36322 .78402 L .36518 .78365 L F
.36441 .78593 m .36263 .78641 L .36322 .78402 L F
.465 .585 .889 r
.58999 .80735 m .5913 .80982 L .5921 .80873 L F
.369 .451 .814 r
.5921 .80873 m .5913 .80982 L .59303 .8101 L F
.503 .244 .453 r
.38137 .77071 m .3789 .77309 L .37936 .7708 L F
0 0 .551 r
.54332 .83044 m .54476 .83356 L .54345 .83114 L F
.642 .791 .954 r
.49298 .81007 m .49253 .8109 L .49093 .81039 L F
.913 .542 .309 r
.58552 .82593 m .58682 .82815 L .58489 .82713 L F
.727 .302 0 r
.58662 .82796 m .58678 .82808 L .58552 .82593 L F
.58678 .82808 m .58708 .82831 L .58552 .82593 L F
.913 .542 .309 r
.58552 .82593 m .58695 .82822 L .58682 .82815 L F
.656 .229 0 r
.58552 .82593 m .58708 .82831 L .58695 .82822 L F
.91 .903 .496 r
.58602 .83004 m .58708 .82831 L .58677 .82807 L F
.913 .759 .677 r
.58489 .82713 m .58675 .82812 L .58602 .83004 L F
.91 .903 .496 r
.58602 .83004 m .58677 .82807 L .58662 .82796 L F
.913 .759 .677 r
.58675 .82812 m .58695 .82822 L .58602 .83004 L F
.769 .871 .442 r
.58695 .82822 m .58708 .82831 L .58602 .83004 L F
.526 .343 .576 r
.47971 .86178 m .4775 .862 L .47972 .85938 L F
.596 .492 .706 r
.47918 .8644 m .4775 .862 L .47971 .86178 L F
.47918 .8644 m .47773 .86521 L .4775 .862 L F
.396 0 .147 r
.47971 .86178 m .4775 .862 L .47692 .86324 L F
.526 .343 .576 r
.47971 .86178 m .4775 .862 L .47972 .85938 L F
.594 .374 .552 r
.66268 .73977 m .66498 .74191 L .66545 .73951 L F
.66268 .73977 m .66498 .74191 L .66545 .73951 L F
.525 .09 .157 r
.57775 .84904 m .58106 .84842 L .5799 .84916 L F
.503 .045 .097 r
.58106 .84842 m .58304 .84857 L .5799 .84916 L F
.462 .831 .58 r
.5736 .77054 m .57518 .76928 L .57654 .76826 L F
0 0 0 r
.57654 .76826 m .57784 .76758 L .57902 .76617 L F
.57654 .76826 m .57518 .76928 L .57784 .76758 L F
.653 .969 .831 r
.50305 .88486 m .50671 .88277 L .50609 .88315 L F
.461 .883 .917 r
.50762 .88202 m .50671 .88277 L .50872 .88208 L F
.463 .845 .622 r
.50609 .88315 m .50671 .88277 L .50762 .88202 L F
.672 .512 .66 r
.53181 .8234 m .53109 .82539 L .52945 .82569 L F
.475 .851 .985 r
.53364 .82287 m .53181 .8234 L .53045 .82292 L F
.432 .848 .962 r
.44158 .88825 m .44292 .88852 L .44491 .88805 L F
.999 .824 .486 r
.5748 .79673 m .57466 .79954 L .57389 .7987 L F
.86 .953 .871 r
.57389 .7987 m .57711 .79666 L .5748 .79673 L F
.043 .165 .667 r
.57086 .83673 m .56967 .83351 L .56987 .83643 L F
.7 .762 .9 r
.57228 .83513 m .56967 .83351 L .57085 .83312 L F
.57228 .83513 m .56987 .83643 L .56967 .83351 L F
.682 .519 .659 r
.52411 .8257 m .52419 .8283 L .52205 .82812 L F
.749 .748 .851 r
.5262 .82479 m .52411 .8257 L .52306 .82434 L F
.953 .673 .227 r
.47616 .86625 m .47773 .86521 L .47702 .86629 L F
.144 0 .023 r
.47702 .86629 m .47773 .86521 L .47918 .8644 L F
0 .514 .786 r
.37463 .75049 m .37392 .75028 L .3716 .7498 L F
.591 .887 .991 r
.3763 .74946 m .37392 .75028 L .37463 .75049 L F
.508 .586 .868 r
.37463 .75049 m .37669 .75046 L .3763 .74946 L F
.509 .468 .747 r
.38974 .74925 m .38768 .75027 L .388 .74946 L F
.569 .486 .722 r
.38974 .74925 m .3884 .75273 L .38768 .75027 L F
.018 .592 .712 r
.51211 .81166 m .51624 .81158 L .5129 .81169 L F
.232 .229 .65 r
.51495 .84186 m .51603 .84309 L .51572 .84078 L F
.382 .649 .962 r
.3716 .7498 m .37246 .74845 L .37024 .74885 L F
.3716 .7498 m .37392 .75028 L .37246 .74845 L F
.649 .323 .406 r
.48416 .85254 m .48599 .85389 L .4859 .85169 L F
.48416 .85254 m .48332 .85439 L .48599 .85389 L F
.164 .365 .816 r
.48599 .85389 m .48416 .85254 L .4859 .85169 L F
.448 .861 .955 r
.3905 .90029 m .39392 .89995 L .3925 .89973 L F
.736 .938 .952 r
.3925 .89973 m .39392 .89995 L .39609 .8987 L F
.466 0 0 r
.56153 .7979 m .55989 .79882 L .56325 .79866 L F
.586 .62 .852 r
.57115 .82228 m .5725 .82497 L .57036 .82508 L F
.438 .48 .806 r
.57318 .82816 m .57036 .82508 L .5725 .82497 L F
.279 0 0 r
.4877 .81229 m .48963 .81191 L .49093 .81039 L F
.552 .182 .294 r
.48963 .81191 m .49298 .81007 L .49093 .81039 L F
.649 .65 .838 r
.52202 .84175 m .51977 .84161 L .52161 .84107 L F
.224 .009 .363 r
.59412 .79945 m .59228 .80207 L .59412 .80186 L F
.521 .455 .722 r
.59228 .80207 m .59477 .80431 L .59412 .80186 L F
.423 .851 .947 r
.38725 .90061 m .38856 .90079 L .3905 .90029 L F
.721 .725 .853 r
.65112 .73941 m .65171 .74178 L .65429 .73999 L F
.695 .435 .527 r
.43461 .84097 m .43112 .8431 L .43266 .84159 L F
.753 .898 .943 r
.6223 .7405 m .61869 .74144 L .62125 .73954 L F
.684 .836 .956 r
.62433 .73958 m .6223 .7405 L .62125 .73954 L F
.529 .903 .958 r
.43258 .88978 m .4376 .88886 L .43662 .8888 L F
.419 .851 .941 r
.4376 .88886 m .43852 .88816 L .43662 .8888 L F
.4376 .88886 m .43956 .88838 L .43852 .88816 L F
.066 0 0 r
.57302 .80028 m .56963 .80176 L .57205 .8013 L F
.804 .773 .824 r
.41151 .85491 m .41099 .85571 L .40813 .85683 L F
.66 .414 .536 r
.41032 .85857 m .40813 .85683 L .41099 .85571 L F
.553 .329 .529 r
.41362 .85417 m .41099 .85571 L .41151 .85491 L F
.41362 .85417 m .41349 .8559 L .41099 .85571 L F
.628 .398 .55 r
.41349 .8559 m .41032 .85857 L .41099 .85571 L F
.601 .775 .963 r
.36028 .74904 m .36087 .74979 L .36266 .7493 L F
.6 .793 .973 r
.36087 .74979 m .36227 .74941 L .36266 .7493 L F
.911 .603 .449 r
.49765 .84131 m .4963 .84294 L .49612 .84092 L F
.452 .108 .291 r
.49933 .83992 m .4963 .84294 L .49765 .84131 L F
.683 .566 .717 r
.49115 .81492 m .48931 .81733 L .4892 .81553 L F
.405 .603 .928 r
.58613 .83639 m .5832 .8343 L .58529 .83326 L F
.983 .715 .332 r
.58545 .83563 m .58613 .83639 L .58529 .83326 L F
.665 .306 .353 r
.36172 .77012 m .3642 .77033 L .36228 .76852 L F
.989 .737 .449 r
.36127 .76811 m .36172 .77012 L .36228 .76852 L F
.586 .326 .489 r
.36228 .76852 m .3642 .77033 L .36487 .76837 L F
.339 .814 .897 r
.44684 .88739 m .44792 .88747 L .45015 .88698 L F
.749 .748 .851 r
.5262 .82479 m .52306 .82434 L .52532 .82283 L F
.63 .763 .942 r
.52859 .82374 m .5262 .82479 L .52532 .82283 L F
.094 0 0 r
.51398 .87948 m .51514 .87966 L .51329 .88028 L F
.51398 .87948 m .51644 .87825 L .51514 .87966 L F
.564 .165 .246 r
.45986 .82219 m .46204 .82238 L .46323 .82057 L F
.446 0 .034 r
.46204 .82238 m .4653 .82172 L .46323 .82057 L F
.448 .237 .5 r
.66242 .72046 m .66213 .71815 L .66366 .71912 L F
.604 .698 .909 r
.66345 .71663 m .66366 .71912 L .66213 .71815 L F
.66345 .71663 m .66564 .7185 L .66366 .71912 L F
.409 0 .093 r
.66564 .7185 m .66242 .72046 L .66366 .71912 L F
.51 .313 .55 r
.37212 .76334 m .37402 .76305 L .37412 .76061 L F
.482 .248 .481 r
.37402 .76305 m .37628 .76045 L .37412 .76061 L F
.461 .298 .573 r
.509 .85426 m .50854 .85516 L .50842 .85652 L F
.335 .089 .385 r
.50842 .85652 m .50854 .85516 L .50618 .85946 L F
.64 .851 .981 r
.41065 .88021 m .40886 .88099 L .40755 .88013 L F
.624 .523 .719 r
.4551 .87248 m .45332 .87457 L .45303 .87279 L F
0 0 0 r
.66191 .76369 m .66503 .7628 L .66265 .76379 L F
.218 0 .065 r
.66678 .76226 m .66866 .76214 L .66673 .76297 L F
.425 .869 .823 r
.66673 .76297 m .66778 .76224 L .66738 .76229 L F
.511 .048 .092 r
.66678 .76226 m .66673 .76297 L .66265 .76379 L F
.425 .869 .823 r
.66586 .76272 m .66738 .76229 L .66529 .76255 L F
.66673 .76297 m .66738 .76229 L .66586 .76272 L F
.511 .048 .092 r
.66678 .76226 m .66447 .76312 L .66503 .7628 L F
.66447 .76312 m .66265 .76379 L .66385 .76329 L F
.66447 .76312 m .66385 .76329 L .66503 .7628 L F
.659 .26 .277 r
.59255 .81514 m .59465 .81531 L .59464 .81674 L F
.764 .584 .655 r
.5968 .81499 m .59464 .81674 L .59465 .81531 L F
.865 .929 .866 r
.53045 .82292 m .52945 .82569 L .52859 .82374 L F
.778 .589 .644 r
.53109 .82539 m .52965 .82799 L .52945 .82569 L F
.51 .061 .12 r
.38873 .83113 m .38926 .83038 L .38648 .83089 L F
.229 .318 .748 r
.38863 .82826 m .38926 .83038 L .39076 .83068 L F
.314 0 .011 r
.39076 .83068 m .38926 .83038 L .38873 .83113 L F
.801 .314 0 r
.55204 .80338 m .55425 .80552 L .55313 .80486 L F
.552 .042 0 r
.55425 .80552 m .55511 .80652 L .55313 .80486 L F
.55425 .80552 m .55569 .80699 L .55511 .80652 L F
.602 .625 .846 r
.38433 .74492 m .38106 .74281 L .38296 .74221 L F
.586 .608 .841 r
.38633 .74455 m .38433 .74492 L .38296 .74221 L F
.646 .438 .587 r
.63411 .76037 m .63664 .75995 L .63663 .75794 L F
.675 .477 .611 r
.63664 .75995 m .6401 .75771 L .63663 .75794 L F
.326 0 0 r
.5462 .79401 m .54816 .79404 L .5496 .79294 L F
.443 0 0 r
.5496 .79294 m .54816 .79404 L .55146 .79336 L F
.55 .239 .393 r
.37437 .77676 m .37169 .77824 L .37218 .77693 L F
.82 .639 .658 r
.57111 .78034 m .56716 .7783 L .56958 .77804 L F
.57111 .78034 m .56749 .78029 L .56716 .7783 L F
.682 .351 .408 r
.57111 .78034 m .56792 .7818 L .56749 .78029 L F
.637 .718 .906 r
.5728 .77867 m .57111 .78034 L .56958 .77804 L F
.486 .505 .802 r
.37785 .753 m .37858 .75 L .37669 .75046 L F
.37785 .753 m .3796 .75299 L .37858 .75 L F
.494 .419 .701 r
.37785 .753 m .38006 .75474 L .3796 .75299 L F
.516 .418 .682 r
.37827 .7551 m .38006 .75474 L .37785 .753 L F
.549 .315 .513 r
.51054 .85628 m .509 .85426 L .50842 .85652 L F
.647 .33 .421 r
.51054 .85628 m .51178 .85408 L .509 .85426 L F
.357 .709 .986 r
.55357 .79367 m .55248 .79446 L .55146 .79336 L F
.55357 .79367 m .55481 .79461 L .55248 .79446 L F
.41 .052 .245 r
.37313 .76456 m .37212 .76334 L .37169 .76536 L F
.37313 .76456 m .37402 .76305 L .37212 .76334 L F
.048 0 .201 r
.59664 .82531 m .59741 .82343 L .59848 .8229 L F
.664 .529 .69 r
.5138 .85421 m .51234 .85723 L .51178 .85408 L F
.869 .791 .771 r
.51054 .85628 m .5138 .85421 L .51178 .85408 L F
.822 .971 .661 r
.57744 .78042 m .57901 .77898 L .57819 .77838 L F
.57744 .78042 m .57721 .78155 L .57901 .77898 L F
.742 .939 .949 r
.5798 .77735 m .57901 .77898 L .58077 .77762 L F
.5798 .77735 m .57819 .77838 L .57901 .77898 L F
.771 .745 .829 r
.4158 .89455 m .41731 .89597 L .4196 .89411 L F
.661 .305 .358 r
.44724 .82271 m .44907 .82447 L .4504 .82241 L F
.475 .047 .146 r
.44907 .82447 m .45251 .82277 L .4504 .82241 L F
.12 0 0 r
.48748 .87006 m .49155 .87017 L .48732 .87207 L F
0 0 0 r
.58146 .80917 m .58291 .80807 L .58491 .80686 L F
.643 .846 .978 r
.47947 .87411 m .47777 .87488 L .47791 .8734 L F
.842 .986 .864 r
.47791 .8734 m .47777 .87488 L .4767 .87488 L F
.758 .791 .88 r
.49522 .81772 m .49263 .81762 L .49412 .81678 L F
.696 .267 .225 r
.49522 .81772 m .49395 .81931 L .49263 .81762 L F
.601 .757 .953 r
.49713 .81735 m .49522 .81772 L .49412 .81678 L F
.698 .364 .407 r
.49713 .81735 m .49395 .81931 L .49522 .81772 L F
.289 0 0 r
.64722 .76867 m .64831 .76964 L .64641 .77045 L F
.64722 .76867 m .64943 .76824 L .64831 .76964 L F
.978 .909 .664 r
.47561 .87141 m .47705 .8701 L .47628 .86939 L F
0 0 0 r
.65973 .76501 m .66191 .76369 L .66121 .76433 L F
.66191 .76369 m .66265 .76379 L .66121 .76433 L F
.758 .568 .639 r
.55083 .83612 m .55093 .8385 L .54769 .83836 L F
.635 .449 .615 r
.55331 .83583 m .55093 .8385 L .55083 .83612 L F
.705 .332 .34 r
.472 .83613 m .469 .83733 L .46846 .83634 L F
.472 .83613 m .47289 .83741 L .469 .83733 L F
.565 .307 .484 r
.472 .83613 m .47396 .83763 L .47289 .83741 L F
.582 .403 .605 r
.40493 .85408 m .40292 .85683 L .40259 .85456 L F
.382 0 .074 r
.49527 .82277 m .49751 .82251 L .49819 .82111 L F
.058 0 0 r
.49819 .82111 m .49933 .81949 L .50047 .82241 L F
.49819 .82111 m .49875 .82169 L .49933 .81949 L F
.49819 .82111 m .49751 .82251 L .49875 .82169 L F
.743 .643 .748 r
.60247 .78689 m .60381 .78319 L .60158 .78366 L F
.766 .555 .613 r
.45076 .83633 m .44737 .83814 L .44734 .83604 L F
.45076 .83633 m .45054 .83859 L .44737 .83814 L F
.607 .414 .595 r
.45275 .83821 m .45076 .83633 L .45268 .83592 L F
.45275 .83821 m .45054 .83859 L .45076 .83633 L F
.787 .696 .764 r
.56987 .83643 m .57024 .83781 L .57086 .83673 L F
.57086 .83673 m .57024 .83781 L .56987 .83643 L F
.342 0 0 r
.42485 .84315 m .42512 .8437 L .42167 .84359 L F
.256 0 0 r
.4256 .84346 m .42485 .84315 L .42711 .84323 L F
.4256 .84346 m .42512 .8437 L .42485 .84315 L F
.522 .89 .972 r
.39783 .89804 m .40078 .89774 L .39895 .89756 L F
.575 .9 .983 r
.39895 .89756 m .40078 .89774 L .40376 .8968 L F
.702 .784 .304 r
.57711 .78159 m .57721 .78155 L .57744 .78042 L F
.57711 .78159 m .57651 .78331 L .57721 .78155 L F
.547 .396 .627 r
.50511 .82559 m .50487 .82792 L .50286 .82784 L F
.547 .374 .599 r
.37628 .76045 m .37832 .76008 L .37748 .75626 L F
.536 .423 .672 r
.37748 .75626 m .38006 .75474 L .37827 .7551 L F
.37748 .75626 m .38055 .7572 L .38006 .75474 L F
.596 .405 .594 r
.37748 .75626 m .38086 .75944 L .38055 .7572 L F
.37748 .75626 m .37832 .76008 L .38086 .75944 L F
.774 .645 .719 r
.62741 .75751 m .6305 .75821 L .63094 .75549 L F
.701 .563 .696 r
.62741 .75751 m .631 .75995 L .6305 .75821 L F
.751 .574 .655 r
.38178 .87224 m .38102 .87234 L .38174 .86991 L F
.71 .557 .678 r
.38395 .86966 m .38178 .87224 L .38174 .86991 L F
.408 .857 .797 r
.56884 .77279 m .57189 .77156 L .57128 .77185 L F
.178 0 .16 r
.57189 .77156 m .5736 .77054 L .57128 .77185 L F
.727 .59 .702 r
.41691 .85418 m .41362 .85417 L .41568 .85159 L F
.689 .376 .44 r
.41691 .85418 m .41542 .8562 L .41362 .85417 L F
.663 .614 .79 r
.41763 .85129 m .41691 .85418 L .41568 .85159 L F
.41718 .85308 m .41888 .85427 L .41691 .85418 L F
.41829 .85287 m .41888 .85427 L .41718 .85308 L F
.237 0 0 r
.41888 .85427 m .41542 .8562 L .41691 .85418 L F
.41888 .85427 m .41774 .85573 L .41542 .8562 L F
.689 .628 .782 r
.41951 .85254 m .41888 .85427 L .41763 .85129 L F
.553 .245 .4 r
.41951 .85254 m .41774 .85573 L .41888 .85427 L F
.41945 .85265 m .41961 .85572 L .41774 .85573 L F
.41951 .85254 m .41951 .85264 L .41945 .85265 L F
.41951 .85264 m .41961 .85572 L .41945 .85265 L F
.663 .614 .79 r
.41763 .85129 m .41829 .85287 L .41718 .85308 L F
.456 .701 .973 r
.36837 .73228 m .36845 .73358 L .36673 .732 L F
.36837 .73228 m .37028 .73352 L .36845 .73358 L F
0 0 .079 r
.56298 .81995 m .56137 .82308 L .56247 .82211 L F
.212 .342 .779 r
.56137 .82308 m .56359 .825 L .56247 .82211 L F
.875 .435 .077 r
.56137 .82308 m .56405 .82691 L .56359 .825 L F
.199 0 0 r
.42802 .82543 m .43133 .8246 L .42908 .82469 L F
.139 .328 .791 r
.59337 .81444 m .59255 .81514 L .59464 .81674 L F
.757 .73 .827 r
.64143 .73199 m .64231 .73438 L .63915 .73411 L F
.8 .751 .807 r
.64447 .73181 m .64231 .73438 L .64143 .73199 L F
.699 .587 .726 r
.64447 .73181 m .64542 .7349 L .64231 .73438 L F
.497 .303 .547 r
.61278 .79931 m .61276 .79712 L .61493 .79669 L F
.68 .741 .897 r
.45449 .86915 m .45463 .87 L .45217 .86991 L F
.628 .552 .749 r
.4551 .87248 m .45217 .86991 L .45463 .87 L F
.459 .578 .886 r
.4562 .8692 m .45463 .87 L .45449 .86915 L F
.514 .466 .741 r
.4562 .8692 m .4551 .87248 L .45463 .87 L F
.551 .823 .997 r
.41949 .88054 m .41589 .88018 L .4179 .87965 L F
.689 .836 .954 r
.42097 .87954 m .41949 .88054 L .4179 .87965 L F
.531 .758 .98 r
.37855 .73873 m .37778 .74004 L .37695 .73715 L F
.37855 .73873 m .37958 .73968 L .37778 .74004 L F
.361 .543 .898 r
.59895 .82709 m .6002 .82871 L .59806 .82804 L F
.723 .646 .772 r
.59802 .76828 m .60119 .77084 L .60009 .76772 L F
.59802 .76828 m .59912 .77126 L .60119 .77084 L F
.714 .64 .773 r
.60009 .76772 m .60119 .77084 L .60333 .76811 L F
.667 .57 .736 r
.60119 .77084 m .60402 .77117 L .60333 .76811 L F
.654 .53 .701 r
.60224 .77383 m .60402 .77117 L .60119 .77084 L F
.553 .333 .535 r
.66223 .74641 m .66371 .74744 L .66367 .7447 L F
.574 .363 .557 r
.66371 .74744 m .66584 .74445 L .66367 .7447 L F
.743 .643 .748 r
.60247 .78689 m .60464 .78627 L .60381 .78319 L F
.727 .578 .687 r
.60247 .78689 m .60256 .78901 L .60464 .78627 L F
.496 .487 .776 r
.60381 .78319 m .60464 .78627 L .60676 .78606 L F
.469 .819 .997 r
.58201 .78377 m .58541 .78396 L .58434 .78338 L F
.54 .354 .577 r
.58434 .78338 m .58201 .78377 L .58541 .78396 L F
.311 .787 .921 r
.50863 .87401 m .5075 .8745 L .50649 .87436 L F
.50863 .87401 m .50975 .87421 L .5075 .8745 L F
.125 .663 .852 r
.65951 .73946 m .65632 .7392 L .65765 .74049 L F
.65951 .73946 m .65632 .7392 L .65765 .74049 L F
.67 .712 .879 r
.37341 .73426 m .37078 .73489 L .37028 .73352 L F
.532 .343 .571 r
.37341 .73426 m .37129 .73726 L .37078 .73489 L F
.766 .651 .735 r
.62784 .75521 m .63094 .75549 L .62981 .75252 L F
.774 .645 .719 r
.62741 .75751 m .63094 .75549 L .62784 .75521 L F
.719 .628 .756 r
.62981 .75252 m .63094 .75549 L .63311 .75301 L F
.7 .762 .9 r
.57228 .83513 m .57086 .83673 L .56987 .83643 L F
.76 .632 .719 r
.63191 .7499 m .63495 .75244 L .63515 .75025 L F
.63191 .7499 m .63311 .75301 L .63495 .75244 L F
.52 .264 .468 r
.44203 .83863 m .43966 .8405 L .43998 .83859 L F
.217 .63 .954 r
.49941 .87697 m .49885 .87719 L .49539 .87548 L F
.848 .686 .681 r
.49869 .81466 m .49756 .81223 L .49915 .8125 L F
.55 .429 .667 r
.4176 .84915 m .41568 .85159 L .41537 .84982 L F
.4176 .84915 m .41763 .85129 L .41568 .85159 L F
.144 0 0 r
.59446 .75658 m .5977 .75498 L .59703 .75564 L F
.635 .416 .567 r
.5241 .83034 m .52195 .83074 L .52205 .82812 L F
.674 .415 .521 r
.52419 .8283 m .5241 .83034 L .52205 .82812 L F
.778 .589 .644 r
.53109 .82539 m .53271 .82827 L .52965 .82799 L F
.804 .773 .824 r
.41151 .85491 m .40813 .85683 L .40989 .85397 L F
0 0 0 r
.52928 .85008 m .53119 .84918 L .53104 .84868 L F
0 0 .092 r
.53119 .84918 m .53305 .84634 L .53104 .84868 L F
.705 .857 .955 r
.3662 .75001 m .36924 .74933 L .36588 .7482 L F
.393 .774 .991 r
.36924 .74933 m .36892 .74818 L .36588 .7482 L F
.36924 .74933 m .37024 .74885 L .36892 .74818 L F
.638 .287 .36 r
.4838 .83826 m .48273 .84023 L .48051 .83856 L F
.432 .02 .156 r
.48584 .8383 m .48273 .84023 L .4838 .83826 L F
.745 .657 .763 r
.59594 .77091 m .59912 .77126 L .59802 .76828 L F
.433 0 0 r
.48906 .8402 m .48814 .83976 L .48584 .8383 L F
.677 .202 .118 r
.49125 .8401 m .48814 .83976 L .48906 .8402 L F
.633 .482 .66 r
.48183 .85682 m .48238 .85971 L .47972 .85938 L F
0 0 0 r
.48183 .85682 m .47972 .85938 L .48109 .85855 L F
.584 .175 .233 r
.47972 .85938 m .48238 .85971 L .48164 .86046 L F
.477 .304 .568 r
.47972 .85938 m .48164 .86046 L .48109 .85855 L F
.47972 .85938 m .47971 .86178 L .48164 .86046 L F
.584 .175 .233 r
.47972 .85938 m .48164 .86046 L .47971 .86178 L F
.683 .339 .387 r
.43861 .82472 m .44071 .82529 L .44193 .82313 L F
.622 .27 .353 r
.44193 .82313 m .44071 .82529 L .44385 .82477 L F
.602 .279 .395 r
.44193 .82313 m .44385 .82477 L .44414 .82324 L F
.7 .276 .237 r
.50053 .81793 m .49933 .81949 L .49713 .81735 L F
.322 0 .055 r
.50263 .81734 m .49933 .81949 L .50053 .81793 L F
.24 0 .04 r
.48443 .87454 m .48543 .87262 L .48732 .87207 L F
0 0 0 r
.57466 .79954 m .57205 .8013 L .57389 .7987 L F
.86 .953 .871 r
.57389 .7987 m .57466 .79954 L .57711 .79666 L F
.871 .498 .013 r
.57389 .7987 m .57536 .80176 L .57466 .79954 L F
.849 .945 .584 r
.5832 .8343 m .58225 .83621 L .58161 .83646 L F
.808 .951 .61 r
.58161 .83646 m .58225 .83621 L .58156 .83722 L F
0 .121 .671 r
.58161 .83646 m .58205 .83714 L .58162 .83635 L F
.802 1 .83 r
.5834 .83407 m .58161 .83646 L .58072 .83473 L F
0 .121 .671 r
.58161 .83646 m .58162 .83635 L .58072 .83473 L F
.808 .951 .61 r
.58161 .83646 m .58156 .83722 L .58076 .83842 L F
.598 .652 .875 r
.59065 .7709 m .59187 .76832 L .58924 .77007 L F
.59065 .7709 m .59282 .77064 L .59187 .76832 L F
.734 .645 .76 r
.59102 .77322 m .59282 .77064 L .59065 .7709 L F
.654 .53 .701 r
.60224 .77383 m .60452 .77333 L .60402 .77117 L F
.319 .026 .3 r
.63718 .77516 m .63479 .7783 L .63517 .77545 L F
.791 .781 .844 r
.3769 .73697 m .37481 .73867 L .37338 .73704 L F
.734 .708 .826 r
.37695 .73715 m .37481 .73867 L .3769 .73697 L F
.68 .937 .966 r
.49039 .84958 m .49056 .85028 L .49346 .84893 L F
.493 .286 .527 r
.61493 .79669 m .61495 .79455 L .61694 .79425 L F
.696 .659 .809 r
.632 .73724 m .63293 .73992 L .62954 .73924 L F
.785 .705 .776 r
.63507 .73725 m .63293 .73992 L .632 .73724 L F
0 0 0 r
.52496 .83755 m .52294 .83975 L .52389 .83836 L F
.71 .557 .678 r
.38395 .86966 m .38475 .87255 L .38178 .87224 L F
.692 .553 .692 r
.38683 .86765 m .38698 .86981 L .38395 .86966 L F
.584 .481 .702 r
.38684 .87219 m .38395 .86966 L .38698 .86981 L F
.38684 .87219 m .38475 .87255 L .38395 .86966 L F
.749 .352 .299 r
.58494 .82003 m .58647 .82017 L .58698 .82219 L F
.254 0 0 r
.58794 .8205 m .58647 .82017 L .58494 .82003 L F
.392 .357 .7 r
.58883 .81961 m .58647 .82017 L .58794 .8205 L F
.64 .381 .511 r
.58698 .82219 m .58794 .8205 L .58732 .82041 L F
.304 .082 .403 r
.58698 .82219 m .58647 .82017 L .58741 .81995 L F
.64 .381 .511 r
.58698 .82219 m .58732 .82041 L .58494 .82003 L F
0 0 0 r
.58883 .81961 m .58794 .8205 L .58698 .82219 L F
.304 .082 .403 r
.58698 .82219 m .58741 .81995 L .58883 .81961 L F
.361 .824 .742 r
.4961 .88781 m .49715 .88744 L .49788 .88705 L F
.248 .402 .821 r
.60027 .82071 m .5989 .82047 L .59766 .81762 L F
.347 .122 .424 r
.59848 .8229 m .5989 .82047 L .60027 .82071 L F
.122 0 .064 r
.58294 .77289 m .58437 .77283 L .58206 .77278 L F
.58294 .77289 m .58365 .77312 L .58437 .77283 L F
.746 .684 .791 r
.63191 .7499 m .63515 .75025 L .63412 .74928 L F
.754 .684 .784 r
.63412 .74928 m .63515 .75025 L .63737 .74779 L F
.707 .758 .892 r
.46077 .87323 m .45849 .87473 L .45706 .87355 L F
.59 .419 .617 r
.48769 .84938 m .4859 .85169 L .48765 .85091 L F
.48769 .84938 m .4859 .85169 L .48765 .85091 L F
.421 .026 .182 r
.52342 .84274 m .52202 .84175 L .52117 .84283 L F
.52342 .84274 m .5241 .84146 L .52202 .84175 L F
.502 .679 .945 r
.52969 .84324 m .52772 .84353 L .52608 .84144 L F
.478 .88 .953 r
.35823 .74847 m .35839 .74925 L .36028 .74904 L F
.35823 .74847 m .35623 .74911 L .35839 .74925 L F
0 0 .454 r
.55959 .81247 m .56053 .81498 L .56064 .81407 L F
.55959 .81247 m .56064 .81407 L .55841 .81174 L F
.818 .982 .887 r
.61468 .74473 m .61606 .7425 L .61699 .74279 L F
.61468 .74473 m .61389 .74437 L .61606 .7425 L F
.514 .271 .483 r
.39083 .76335 m .38791 .76789 L .38871 .76477 L F
.608 .867 .991 r
.60348 .79851 m .60422 .79928 L .60162 .79915 L F
.931 .891 .768 r
.60422 .79928 m .60166 .80145 L .60162 .79915 L F
.60422 .79928 m .60266 .80207 L .60166 .80145 L F
0 0 0 r
.60604 .79627 m .60422 .79928 L .60348 .79851 L F
.668 .518 .672 r
.60047 .78938 m .60045 .79164 L .60256 .78901 L F
.60047 .78938 m .60045 .79164 L .60256 .78901 L F
.105 0 0 r
.52121 .87715 m .52398 .87577 L .52276 .87711 L F
.114 0 0 r
.52006 .8788 m .52121 .87715 L .52276 .87711 L F
.788 .541 .565 r
.60271 .8044 m .60589 .8048 L .606 .80703 L F
.65 .428 .568 r
.60589 .8048 m .60826 .8072 L .606 .80703 L F
.60589 .8048 m .6089 .80408 L .60826 .8072 L F
.74 .708 .822 r
.41292 .87908 m .4138 .88049 L .41065 .88021 L F
.594 .649 .874 r
.41589 .88018 m .4138 .88049 L .41292 .87908 L F
.639 .347 .46 r
.49667 .83764 m .49855 .83835 L .49909 .83646 L F
.734 .445 .489 r
.49909 .83646 m .49855 .83835 L .5018 .83825 L F
.48 .162 .349 r
.63258 .77872 m .63005 .78068 L .63049 .77919 L F
.349 0 .154 r
.57784 .76758 m .58079 .7652 L .57902 .76617 L F
.354 0 .007 r
.51514 .87966 m .51644 .87825 L .51843 .87806 L F
.009 0 0 r
.64942 .75985 m .65055 .75845 L .64789 .7602 L F
.066 0 .04 r
.64789 .7602 m .64708 .76209 L .64942 .75985 L F
.63 .653 .854 r
.39457 .75477 m .39218 .75688 L .39083 .75444 L F
0 0 0 r
.55877 .78652 m .5602 .78362 L .56024 .78511 L F
.55877 .78652 m .55923 .78575 L .5602 .78362 L F
.59 .492 .711 r
.56024 .78511 m .56092 .78653 L .55877 .78652 L F
.919 .604 .43 r
.56092 .78653 m .55923 .78575 L .55877 .78652 L F
.978 .778 .361 r
.48769 .84938 m .48765 .85091 L .48731 .84784 L F
.586 .256 .377 r
.65078 .72664 m .65331 .72657 L .65396 .72479 L F
.552 .324 .523 r
.65609 .72644 m .65396 .72479 L .65331 .72657 L F
.65609 .72644 m .65609 .72383 L .65396 .72479 L F
.65396 .72479 m .65609 .72383 L .65609 .72644 L F
.638 .393 .532 r
.44734 .83604 m .44737 .83814 L .44509 .83813 L F
.919 .82 .358 r
.56393 .83874 m .56363 .84113 L .56327 .84071 L F
.83 .533 0 r
.56327 .84071 m .56363 .84113 L .56407 .84348 L F
.499 .252 .471 r
.36986 .77874 m .36943 .78082 L .36746 .78115 L F
.518 .304 .529 r
.37169 .77824 m .36943 .78082 L .36986 .77874 L F
.622 .486 .676 r
.38895 .86725 m .38698 .86981 L .38683 .86765 L F
.282 .113 .465 r
.60161 .83559 m .60133 .83783 L .59936 .8381 L F
.218 0 .195 r
.59936 .8381 m .60133 .83783 L .59883 .84016 L F
.107 0 0 r
.34734 .72648 m .34889 .72613 L .34975 .72512 L F
.532 .074 .111 r
.34975 .72512 m .34889 .72613 L .35123 .72586 L F
.201 .354 .794 r
.5644 .83283 m .56335 .83377 L .56511 .83492 L F
.564 .934 .81 r
.60549 .75071 m .60672 .74961 L .60714 .7495 L F
.60549 .75071 m .60393 .75121 L .60672 .74961 L F
.901 .542 .348 r
.55204 .80338 m .55025 .80173 L .55209 .80225 L F
.468 .141 .329 r
.386 .76846 m .38332 .77027 L .38388 .76876 L F
.649 .455 .608 r
.51077 .8229 m .51002 .82561 L .50701 .82557 L F
.505 .236 .44 r
.51218 .82322 m .51002 .82561 L .51077 .8229 L F
.638 .238 .27 r
.36805 .76663 m .37169 .76536 L .36972 .76576 L F
.73 .762 .878 r
.50755 .86226 m .50826 .85938 L .50618 .85946 L F
.50755 .86226 m .50926 .86125 L .50826 .85938 L F
.849 .815 .815 r
.53271 .82827 m .52939 .83003 L .52965 .82799 L F
.53271 .82827 m .53088 .83044 L .52939 .83003 L F
.785 .705 .776 r
.63507 .73725 m .632 .73724 L .63352 .73608 L F
.757 .705 .803 r
.63698 .735 m .63507 .73725 L .63352 .73608 L F
0 0 .38 r
.45217 .86991 m .45307 .87169 L .45449 .86915 L F
.869 .791 .771 r
.51054 .85628 m .51234 .85723 L .5138 .85421 L F
.894 .767 .714 r
.51057 .85762 m .51234 .85723 L .51054 .85628 L F
.58 .508 .739 r
.53824 .81992 m .53686 .82297 L .53628 .82151 L F
.53824 .81992 m .53895 .82265 L .53686 .82297 L F
.863 .97 .862 r
.54482 .85943 m .54584 .85712 L .54453 .85623 L F
.54482 .85943 m .54714 .85707 L .54584 .85712 L F
.094 0 .439 r
.60482 .82721 m .6034 .83059 L .60319 .82814 L F
0 0 0 r
.45267 .88606 m .45547 .88524 L .45457 .88558 L F
.45649 .88516 m .45547 .88524 L .4575 .88488 L F
.45457 .88558 m .45547 .88524 L .45649 .88516 L F
.694 .73 .879 r
.64551 .74095 m .6467 .74215 L .64876 .74126 L F
.098 0 0 r
.42643 .87651 m .42558 .87764 L .42738 .87681 L F
.61 .59 .806 r
.38296 .74221 m .38106 .74281 L .37958 .73968 L F
.771 .745 .829 r
.4158 .89455 m .4196 .89411 L .41807 .89293 L F
.653 .791 .948 r
.41807 .89293 m .4196 .89411 L .42169 .89343 L F
.571 .373 .574 r
.39302 .76044 m .39288 .76263 L .39085 .7629 L F
.639 .531 .716 r
.39491 .7581 m .39541 .76039 L .39302 .76044 L F
.556 .361 .572 r
.39302 .76044 m .39493 .76235 L .39288 .76263 L F
.615 .358 .506 r
.39541 .76039 m .39493 .76235 L .39302 .76044 L F
0 0 0 r
.52577 .87471 m .52878 .87212 L .52758 .87406 L F
.362 0 0 r
.52878 .87212 m .53047 .87257 L .52758 .87406 L F
.52878 .87212 m .53077 .87197 L .53047 .87257 L F
.663 .203 .15 r
.51305 .87463 m .50975 .87421 L .51185 .87461 L F
.513 .905 .935 r
.51482 .87388 m .51305 .87463 L .51185 .87461 L F
.467 .244 .491 r
.468 .8713 m .4681 .86971 L .46622 .8712 L F
.505 .236 .44 r
.51218 .82322 m .51205 .82526 L .51002 .82561 L F
.549 .272 .448 r
.51433 .82481 m .51205 .82526 L .51218 .82322 L F
.434 .382 .701 r
.48318 .85652 m .48398 .85886 L .48183 .85682 L F
.494 .388 .663 r
.48398 .85886 m .48238 .85971 L .48183 .85682 L F
.543 .446 .694 r
.48594 .85852 m .48318 .85652 L .48475 .85567 L F
.48594 .85852 m .48398 .85886 L .48318 .85652 L F
.217 0 .131 r
.48183 .85682 m .48253 .85825 L .48379 .8565 L F
.48183 .85682 m .48109 .85855 L .48253 .85825 L F
.012 0 0 r
.48183 .85682 m .48379 .8565 L .48318 .85652 L F
.762 .531 .584 r
.67475 .74963 m .67781 .74743 L .67454 .74712 L F
.67475 .74963 m .67772 .74975 L .67781 .74743 L F
.855 .778 .775 r
.58642 .78069 m .58988 .77883 L .58639 .77841 L F
.58642 .78069 m .58803 .7818 L .58988 .77883 L F
.526 .295 .507 r
.37687 .77347 m .37647 .77627 L .37437 .77676 L F
.497 .269 .499 r
.37832 .77583 m .37687 .77347 L .3789 .77309 L F
.37832 .77583 m .37647 .77627 L .37687 .77347 L F
.786 .838 .892 r
.63619 .74694 m .63921 .74697 L .6384 .74442 L F
.63619 .74694 m .63737 .74779 L .63921 .74697 L F
.844 .817 .823 r
.6384 .74442 m .63921 .74697 L .64121 .74433 L F
.508 .591 .872 r
.38974 .74925 m .388 .74946 L .38745 .74861 L F
.635 .449 .615 r
.55331 .83583 m .55345 .83822 L .55093 .8385 L F
.507 .634 .91 r
.55518 .83555 m .55331 .83583 L .55213 .8338 L F
.449 .308 .597 r
.5552 .83788 m .55331 .83583 L .55518 .83555 L F
.5552 .83788 m .55345 .83822 L .55331 .83583 L F
.272 .272 .677 r
.5312 .83174 m .52939 .83003 L .53088 .83044 L F
.28 0 .081 r
.64641 .77045 m .64318 .77221 L .64466 .77029 L F
.736 .938 .952 r
.3925 .89973 m .39609 .8987 L .39504 .89877 L F
.571 .897 .984 r
.39666 .89768 m .39609 .8987 L .39783 .89804 L F
.656 .97 .893 r
.39666 .89768 m .39504 .89877 L .39609 .8987 L F
.609 .376 .539 r
.41362 .85417 m .41542 .8562 L .41349 .8559 L F
.666 .729 .896 r
.38815 .87918 m .38935 .88053 L .38603 .87988 L F
.614 .649 .861 r
.39001 .8778 m .38935 .88053 L .38815 .87918 L F
.39001 .8778 m .39136 .88003 L .38935 .88053 L F
.402 0 .035 r
.65455 .76587 m .65355 .76723 L .65137 .76736 L F
.262 0 0 r
.65455 .76587 m .65555 .76654 L .65355 .76723 L F
.65455 .76587 m .65686 .76581 L .65555 .76654 L F
.214 0 0 r
.59513 .80688 m .59815 .80516 L .59847 .80731 L F
.063 0 .442 r
.59815 .80516 m .59945 .80072 L .60058 .80476 L F
.645 .523 .701 r
.60058 .80476 m .59847 .80731 L .59815 .80516 L F
.8 .751 .807 r
.64447 .73181 m .64143 .73199 L .64335 .73095 L F
.832 .863 .868 r
.64682 .72951 m .64447 .73181 L .64335 .73095 L F
.523 .733 .97 r
.54453 .85623 m .54714 .85707 L .54584 .85712 L F
.894 .955 .833 r
.54806 .85547 m .54714 .85707 L .54584 .85712 L F
.54584 .85712 m .54714 .85707 L .54806 .85547 L F
.777 .907 .514 r
.51848 .81943 m .51732 .82191 L .51947 .82 L F
.072 0 0 r
.52156 .81751 m .51848 .81943 L .51947 .82 L F
.734 .645 .76 r
.59102 .77322 m .59376 .77339 L .59282 .77064 L F
.725 .64 .763 r
.59282 .77064 m .59376 .77339 L .59594 .77091 L F
.821 .811 .841 r
.57274 .78389 m .57651 .78331 L .57428 .78431 L F
.804 .999 .834 r
.57711 .78159 m .57428 .78431 L .57651 .78331 L F
.325 .022 .287 r
.47239 .87223 m .47339 .86922 L .47088 .87133 L F
.397 0 .096 r
.47239 .87223 m .47088 .87133 L .47024 .87253 L F
.738 .465 .516 r
.54476 .83356 m .54127 .83545 L .54145 .83299 L F
.54476 .83356 m .54524 .8347 L .54127 .83545 L F
.492 .533 .826 r
.54645 .83314 m .54476 .83356 L .54332 .83044 L F
.442 .322 .621 r
.54645 .83314 m .54524 .8347 L .54476 .83356 L F
.726 .197 0 r
.3769 .73697 m .37533 .7363 L .37341 .73426 L F
.791 .781 .844 r
.3769 .73697 m .37338 .73704 L .37533 .7363 L F
.534 .411 .658 r
.37862 .73419 m .37927 .73661 L .3769 .73697 L F
.509 .282 .505 r
.37927 .73661 m .37695 .73715 L .3769 .73697 L F
.641 .353 .466 r
.52419 .8283 m .52614 .83007 L .5241 .83034 L F
.328 0 0 r
.46846 .83634 m .46541 .83561 L .46694 .83489 L F
.36 .052 .3 r
.65892 .74969 m .66078 .74921 L .66223 .74641 L F
.768 .61 .683 r
.66078 .74921 m .66371 .74744 L .66223 .74641 L F
.55 .367 .586 r
.59412 .80186 m .59628 .80152 L .59412 .79945 L F
.662 .518 .677 r
.59412 .79945 m .59647 .79951 L .59619 .79684 L F
.639 .358 .476 r
.59628 .80152 m .59647 .79951 L .59412 .79945 L F
.437 .06 .223 r
.52148 .87459 m .52056 .87287 L .51929 .87436 L F
.52148 .87459 m .5227 .87253 L .52056 .87287 L F
.64 .239 .267 r
.4982 .81 m .50068 .81179 L .50155 .80991 L F
.949 .637 .411 r
.50155 .80991 m .50068 .81179 L .50178 .81223 L F
.525 .292 .504 r
.59944 .79939 m .60206 .79683 L .60162 .79915 L F
.95 .739 .584 r
.60052 .79622 m .60162 .79915 L .60206 .79683 L F
.622 .486 .676 r
.38895 .86725 m .38911 .86966 L .38698 .86981 L F
.588 .384 .572 r
.38898 .87192 m .38698 .86981 L .38911 .86966 L F
.38898 .87192 m .38684 .87219 L .38698 .86981 L F
.747 .455 .488 r
.3662 .75001 m .36266 .7493 L .36227 .74941 L F
.3662 .75001 m .36354 .74995 L .36266 .7493 L F
.705 .857 .955 r
.3662 .75001 m .36588 .7482 L .36354 .74995 L F
.309 0 0 r
.57449 .84914 m .57775 .84904 L .57598 .84958 L F
.233 0 0 r
.57775 .84904 m .57817 .84974 L .57598 .84958 L F
.57775 .84904 m .5799 .84916 L .57817 .84974 L F
.743 .687 .797 r
.56847 .79497 m .57161 .79505 L .57072 .79437 L F
.694 .847 .956 r
.57072 .79437 m .57161 .79505 L .57387 .79431 L F
.645 .594 .782 r
.67536 .72623 m .67737 .72959 L .67508 .72885 L F
.67536 .72623 m .67508 .72885 L .67566 .72856 L F
.001 .24 .749 r
.67508 .72885 m .67653 .73059 L .67566 .72856 L F
.512 .339 .583 r
.6089 .80408 m .61087 .802 L .61087 .80436 L F
.496 .284 .521 r
.60826 .8072 m .6089 .80408 L .61087 .80436 L F
.658 .321 .39 r
.4653 .82172 m .46728 .82235 L .46844 .82013 L F
.507 .142 .281 r
.46728 .82235 m .47061 .82012 L .46844 .82013 L F
.598 .244 .341 r
.48051 .83856 m .47724 .84047 L .47723 .83883 L F
.48051 .83856 m .47966 .84069 L .47724 .84047 L F
.245 0 .183 r
.48133 .84 m .48051 .83856 L .48273 .84023 L F
.48133 .84 m .47966 .84069 L .48051 .83856 L F
0 0 0 r
.56884 .77279 m .5703 .77246 L .57189 .77156 L F
.56884 .77279 m .56827 .77309 L .5703 .77246 L F
.49272 .8772 m .4936 .8767 L .49168 .87744 L F
.647 .315 .396 r
.35636 .77045 m .3581 .77043 L .35686 .76939 L F
.649 .444 .592 r
.3581 .77043 m .35823 .76815 L .35686 .76939 L F
.549 .319 .518 r
.39288 .76263 m .39083 .76335 L .39085 .7629 L F
.046 0 0 r
.40241 .82655 m .39976 .82525 L .40177 .82537 L F
.539 .529 .793 r
.40352 .82497 m .40241 .82655 L .40177 .82537 L F
.715 .25 0 r
.54637 .81359 m .54564 .81203 L .54439 .81138 L F
.54637 .81359 m .54728 .81457 L .54564 .81203 L F
.387 .717 .988 r
.56743 .79606 m .56637 .79689 L .5653 .79601 L F
.5653 .79601 m .56637 .79689 L .56743 .79606 L F
0 0 0 r
.56743 .79606 m .56637 .79689 L .56847 .79497 L F
.919 .82 .358 r
.56393 .83874 m .56327 .84071 L .56381 .83814 L F
.5 .286 .52 r
.67413 .75541 m .67407 .75784 L .67191 .7583 L F
.451 .247 .51 r
.67595 .75701 m .67413 .75541 L .67619 .75488 L F
.67595 .75701 m .67407 .75784 L .67413 .75541 L F
.574 .035 0 r
.56985 .84827 m .57253 .8486 L .5712 .84895 L F
.462 0 0 r
.57253 .8486 m .5733 .8493 L .5712 .84895 L F
.57253 .8486 m .57449 .84914 L .5733 .8493 L F
.626 .936 .962 r
.49276 .88861 m .49421 .88881 L .4961 .88781 L F
.594 .395 .582 r
.42167 .84359 m .42178 .84635 L .41966 .84658 L F
.551 .362 .578 r
.42383 .84589 m .42167 .84359 L .42512 .8437 L F
.42383 .84589 m .42178 .84635 L .42167 .84359 L F
.675 .477 .611 r
.63664 .75995 m .64034 .76156 L .6401 .75771 L F
.61 .428 .611 r
.64034 .76156 m .64205 .76021 L .6401 .75771 L F
.539 .529 .793 r
.40352 .82497 m .40456 .82801 L .40241 .82655 L F
.753 .538 .605 r
.39407 .86702 m .39126 .86457 L .39281 .86444 L F
.554 .322 .518 r
.39652 .86461 m .39407 .86702 L .39281 .86444 L F
.988 .721 .411 r
.49236 .84591 m .49346 .84893 L .49423 .84681 L F
.702 .616 .757 r
.51465 .84857 m .5159 .85158 L .51787 .84915 L F
.648 .439 .585 r
.60381 .78319 m .60649 .78377 L .60654 .78126 L F
.638 .564 .755 r
.60561 .77853 m .60654 .78126 L .60868 .78099 L F
.573 .359 .552 r
.60649 .78377 m .60868 .78099 L .60654 .78126 L F
0 0 0 r
.65196 .75733 m .65055 .75845 L .64942 .75985 L F
.65239 .75691 m .64942 .75985 L .65146 .75938 L F
.994 .749 .409 r
.65139 .75591 m .65143 .75808 L .65059 .75623 L F
.65143 .75808 m .65146 .75938 L .65119 .75842 L F
0 0 0 r
.65207 .75718 m .65055 .75845 L .65196 .75733 L F
.994 .749 .409 r
.65143 .75808 m .65119 .75842 L .65059 .75623 L F
0 0 0 r
.65239 .75691 m .65207 .75718 L .65196 .75733 L F
.531 .461 .723 r
.52939 .83003 m .52812 .83349 L .52794 .83268 L F
.52939 .83003 m .52984 .83299 L .52812 .83349 L F
.481 .358 .634 r
.52984 .83299 m .52842 .83578 L .52812 .83349 L F
.61 .804 .974 r
.39336 .87947 m .39459 .88042 L .39136 .88003 L F
.585 .795 .979 r
.39534 .87912 m .39459 .88042 L .39336 .87947 L F
.565 .77 .975 r
.39534 .87912 m .39855 .88072 L .39459 .88042 L F
.6 .581 .804 r
.39792 .88294 m .39459 .88042 L .39855 .88072 L F
.881 .914 .845 r
.59816 .79421 m .59619 .79684 L .59832 .79655 L F
.724 .653 .778 r
.59647 .79951 m .59832 .79655 L .59619 .79684 L F
.777 .907 .514 r
.51848 .81943 m .51705 .82202 L .51732 .82191 L F
.071 0 0 r
.42939 .87621 m .43132 .87576 L .43251 .87494 L F
.163 .557 .93 r
.43241 .87498 m .43251 .87494 L .43132 .87576 L F
.43338 .8743 m .43251 .87494 L .43241 .87498 L F
.255 .76 .876 r
.43431 .87483 m .43256 .87493 L .43251 .87494 L F
.43256 .87493 m .43087 .87501 L .43251 .87494 L F
.469 0 0 r
.43463 .87547 m .43431 .87483 L .43251 .87494 L F
.43463 .87547 m .43567 .87558 L .43431 .87483 L F
.435 .571 .891 r
.43594 .87587 m .43431 .87483 L .43567 .87558 L F
.473 .839 .992 r
.43538 .87525 m .43567 .87558 L .43463 .87547 L F
.43718 .87472 m .43567 .87558 L .43538 .87525 L F
.435 .571 .891 r
.43724 .8767 m .43594 .87587 L .43567 .87558 L F
.402 .411 .755 r
.34775 .72784 m .34889 .72613 L .34734 .72648 L F
.34775 .72784 m .34972 .72903 L .34889 .72613 L F
.757 .494 .535 r
.52294 .81003 m .52601 .81233 L .52706 .81067 L F
.52294 .81003 m .52276 .81213 L .52601 .81233 L F
.889 .917 .837 r
.54783 .79609 m .5462 .79401 L .54705 .79537 L F
.613 .855 .989 r
.41074 .89499 m .41484 .89488 L .4127 .89439 L F
.494 .842 .996 r
.4127 .89439 m .41484 .89488 L .4158 .89455 L F
.665 .672 .847 r
.62954 .73924 m .62658 .73756 L .62855 .73659 L F
.707 .681 .822 r
.632 .73724 m .62954 .73924 L .62855 .73659 L F
.538 .515 .778 r
.53428 .83245 m .53456 .83042 L .53292 .83105 L F
.53428 .83245 m .53589 .83327 L .53456 .83042 L F
.483 .025 .089 r
.66809 .74409 m .67037 .74408 L .67128 .74294 L F
0 .406 .735 r
.67222 .74314 m .67128 .74294 L .67037 .74408 L F
.67222 .74314 m .67358 .74373 L .67158 .74304 L F
0 0 .009 r
.67222 .74314 m .67168 .74516 L .67288 .74325 L F
.592 .704 .921 r
.67489 .74134 m .67358 .74373 L .67222 .74314 L F
0 0 .009 r
.67222 .74314 m .67288 .74325 L .67342 .74241 L F
0 .406 .735 r
.67222 .74314 m .67158 .74304 L .67128 .74294 L F
.494 .024 .068 r
.38764 .83157 m .38648 .83089 L .38517 .83241 L F
.38764 .83157 m .38873 .83113 L .38648 .83089 L F
.473 0 0 r
.54002 .80815 m .54126 .80883 L .53885 .80717 L F
.621 .762 .946 r
.35614 .7296 m .35298 .72898 L .35484 .72902 L F
0 .51 .84 r
.35484 .72902 m .35819 .73018 L .35614 .7296 L F
.457 .442 .753 r
.40599 .86166 m .40446 .8621 L .40394 .86034 L F
.709 .483 .579 r
.4069 .86401 m .40446 .8621 L .40599 .86166 L F
.4069 .86401 m .40392 .86423 L .40446 .8621 L F
.652 .461 .613 r
.60266 .80207 m .60058 .80476 L .59945 .80072 L F
0 0 0 r
.60208 .80128 m .60166 .80145 L .60098 .8027 L F
.60268 .80051 m .60166 .80145 L .60208 .80128 L F
0 .499 .849 r
.60166 .80145 m .60266 .80207 L .6014 .80154 L F
.60166 .80145 m .6014 .80154 L .59945 .80072 L F
.652 .461 .613 r
.60266 .80207 m .60271 .8044 L .60058 .80476 L F
.554 .838 .998 r
.40871 .89549 m .40944 .89439 L .4073 .89495 L F
.40871 .89549 m .41074 .89499 L .40944 .89439 L F
.529 .37 .61 r
.47339 .86922 m .47628 .86939 L .47616 .86625 L F
.781 .644 .71 r
.47239 .87223 m .47628 .86939 L .47339 .86922 L F
.704 .509 .623 r
.50701 .82557 m .50487 .82792 L .50511 .82559 L F
.50701 .82557 m .50688 .82808 L .50487 .82792 L F
.656 .474 .626 r
.51002 .82561 m .50688 .82808 L .50701 .82557 L F
.723 .614 .736 r
.62981 .75252 m .63311 .75301 L .63191 .7499 L F
.556 .497 .744 r
.60333 .76811 m .60402 .77117 L .60597 .76999 L F
.631 .563 .759 r
.60452 .77333 m .60597 .76999 L .60402 .77117 L F
.815 .856 .879 r
.65364 .75387 m .65239 .75691 L .65139 .75591 L F
.064 .221 .715 r
.65284 .75495 m .65364 .75387 L .65219 .75532 L F
.815 .856 .879 r
.65364 .75387 m .65503 .75449 L .65239 .75691 L F
.578 .411 .619 r
.65444 .75713 m .65503 .75449 L .65239 .75691 L F
.124 .239 .712 r
.65364 .75387 m .65444 .75713 L .65503 .75449 L F
.664 .439 .569 r
.65444 .75713 m .65679 .75458 L .65503 .75449 L F
.65444 .75713 m .65751 .75646 L .65679 .75458 L F
.124 .239 .712 r
.65364 .75387 m .65563 .756 L .65444 .75713 L F
.76 .705 .801 r
.65503 .75449 m .65679 .75458 L .65718 .75294 L F
.908 .53 .297 r
.65443 .75282 m .65503 .75449 L .65364 .75387 L F
.808 .857 .886 r
.65364 .75387 m .65503 .75449 L .65718 .75294 L F
.064 .221 .715 r
.65498 .75373 m .65563 .756 L .65429 .75457 L F
.65498 .75373 m .65429 .75457 L .65364 .75387 L F
.65 .969 .878 r
.65342 .7542 m .6553 .75334 L .65498 .75373 L F
.405 .669 .968 r
.65553 .75157 m .65718 .75294 L .65434 .75257 L F
.808 .857 .886 r
.65364 .75387 m .65718 .75294 L .65553 .75157 L F
.65 .969 .878 r
.6553 .75334 m .6568 .75266 L .65498 .75373 L F
.064 .221 .715 r
.65498 .75373 m .65364 .75387 L .65284 .75495 L F
.908 .53 .297 r
.65434 .75257 m .65443 .75282 L .65364 .75387 L F
0 0 0 r
.65434 .75257 m .65364 .75387 L .65553 .75157 L F
.493 .752 .987 r
.39889 .87978 m .39855 .88072 L .39534 .87912 L F
.489 .19 .385 r
.36263 .78641 m .36015 .78787 L .36052 .78644 L F
.289 0 .061 r
.42871 .875 m .42939 .87621 L .43087 .87501 L F
.42871 .875 m .42738 .87681 L .42939 .87621 L F
.735 .624 .735 r
.62673 .76517 m .62997 .76561 L .629 .76256 L F
.744 .502 .565 r
.63001 .76781 m .62997 .76561 L .62673 .76517 L F
.678 .592 .752 r
.629 .76256 m .62997 .76561 L .63213 .76321 L F
.689 .609 .761 r
.62997 .76561 m .63289 .76518 L .63213 .76321 L F
.637 .384 .518 r
.63235 .7677 m .62997 .76561 L .63001 .76781 L F
.63235 .7677 m .63289 .76518 L .62997 .76561 L F
.571 .754 .964 r
.36597 .73037 m .36483 .73183 L .36356 .73068 L F
.432 .55 .875 r
.36597 .73037 m .36673 .732 L .36483 .73183 L F
.144 0 .023 r
.47702 .86629 m .47918 .8644 L .48005 .86436 L F
.158 .105 .543 r
.48005 .86436 m .47918 .8644 L .47971 .86178 L F
.84 .71 .719 r
.60868 .78699 m .60782 .78893 L .60676 .78606 L F
.515 .395 .653 r
.38684 .87219 m .38522 .87484 L .38475 .87255 L F
.554 .322 .518 r
.39652 .86461 m .39641 .86683 L .39407 .86702 L F
.609 .368 .526 r
.39846 .86663 m .39641 .86683 L .39652 .86461 L F
0 0 0 r
.40989 .85397 m .40813 .85683 L .4092 .85516 L F
.665 .545 .709 r
.38603 .87988 m .38383 .88247 L .38437 .87986 L F
.229 .318 .748 r
.38863 .82826 m .39076 .83068 L .39064 .82793 L F
.753 .538 .605 r
.39407 .86702 m .39112 .86695 L .39126 .86457 L F
.558 .888 .987 r
.43179 .89022 m .43236 .88931 L .43078 .88998 L F
.43179 .89022 m .43258 .88978 L .43236 .88931 L F
.332 .81 .76 r
.42071 .82647 m .42172 .82589 L .42248 .82636 L F
.42071 .82647 m .41914 .82688 L .42172 .82589 L F
.566 .919 .729 r
.59009 .75949 m .58842 .76073 L .58943 .75972 L F
.583 .945 .859 r
.58842 .76073 m .58657 .76117 L .58943 .75972 L F
.676 .56 .716 r
.631 .75995 m .63415 .7625 L .63411 .76037 L F
.716 .546 .658 r
.63415 .7625 m .63664 .75995 L .63411 .76037 L F
.923 .591 .394 r
.55025 .80173 m .54822 .79883 L .54963 .79969 L F
.507 .812 1 r
.48626 .87858 m .48294 .87813 L .485 .8782 L F
.01 0 0 r
.48708 .87866 m .48626 .87858 L .485 .8782 L F
.48708 .87866 m .48866 .87835 L .48626 .87858 L F
.754 .684 .784 r
.63412 .74928 m .63737 .74779 L .63619 .74694 L F
.512 .222 .41 r
.48373 .81361 m .48587 .8132 L .48557 .81259 L F
.494 .132 .281 r
.48195 .81611 m .48587 .8132 L .48373 .81361 L F
.645 .523 .701 r
.60058 .80476 m .60079 .80712 L .59847 .80731 L F
.562 .452 .686 r
.6002 .80896 m .59847 .80731 L .60079 .80712 L F
.6002 .80896 m .59887 .80948 L .59847 .80731 L F
.473 .246 .489 r
.6232 .78568 m .62524 .7834 L .62512 .78505 L F
.526 .306 .523 r
.62512 .78505 m .62524 .7834 L .62781 .78283 L F
.689 .304 .313 r
.51551 .8324 m .51925 .83079 L .51551 .83011 L F
.51551 .8324 m .51804 .8328 L .51925 .83079 L F
.509 .285 .51 r
.36746 .78115 m .36719 .78331 L .36518 .78365 L F
.542 .328 .539 r
.36943 .78082 m .36719 .78331 L .36746 .78115 L F
.652 .557 .735 r
.57514 .82612 m .57318 .82816 L .5725 .82497 L F
.645 .546 .728 r
.57514 .82612 m .57596 .82778 L .57318 .82816 L F
.378 .462 .82 r
.5751 .83038 m .57318 .82816 L .57596 .82778 L F
.569 .486 .722 r
.38974 .74925 m .3904 .75241 L .3884 .75273 L F
.583 .482 .705 r
.39083 .75444 m .3884 .75273 L .3904 .75241 L F
.39083 .75444 m .38878 .75493 L .3884 .75273 L F
.775 .542 .582 r
.3939 .82805 m .39083 .82548 L .39064 .82793 L F
.505 .786 .996 r
.48729 .88815 m .48882 .88908 L .49066 .88873 L F
.724 .653 .778 r
.59647 .79951 m .59944 .79939 L .59832 .79655 L F
.694 .421 .506 r
.59945 .80072 m .59944 .79939 L .59647 .79951 L F
.602 .588 .81 r
.59944 .79939 m .60052 .79622 L .59832 .79655 L F
.59944 .79939 m .60162 .79915 L .60052 .79622 L F
.644 .381 .506 r
.59944 .79939 m .60166 .80145 L .59945 .80072 L F
0 .499 .849 r
.60166 .80145 m .59945 .80072 L .59944 .79939 L F
.578 .389 .59 r
.60162 .79915 m .60166 .80145 L .59944 .79939 L F
.144 0 0 r
.59446 .75658 m .59648 .75612 L .5977 .75498 L F
0 0 0 r
.5977 .75498 m .59908 .75444 L .60031 .75337 L F
.5977 .75498 m .59648 .75612 L .59908 .75444 L F
.38 .791 .98 r
.5544 .8409 m .55093 .8385 L .55345 .83822 L F
.5544 .8409 m .55117 .84058 L .55093 .8385 L F
.55117 .84058 m .5544 .8409 L .55361 .84102 L F
.981 .687 .345 r
.55361 .84102 m .5544 .8409 L .55345 .83822 L F
0 0 0 r
.52276 .87711 m .52398 .87577 L .52577 .87471 L F
.563 .243 .384 r
.48587 .8132 m .48753 .81388 L .48557 .81259 L F
.531 .267 .459 r
.48557 .81259 m .48753 .81388 L .4877 .81229 L F
.85 .8 .802 r
.64056 .74174 m .6384 .74442 L .64121 .74433 L F
.775 .759 .839 r
.64056 .74174 m .64121 .74433 L .64355 .74192 L F
.413 .02 .181 r
.65988 .75296 m .65679 .75458 L .65718 .75294 L F
.65988 .75296 m .65906 .7542 L .65679 .75458 L F
.665 .297 .337 r
.65906 .7542 m .66188 .7545 L .65988 .75296 L F
.557 .356 .564 r
.65988 .75296 m .66188 .7545 L .66211 .75221 L F
.786 .569 .607 r
.6479 .7391 m .65153 .73691 L .64877 .73619 L F
.6479 .7391 m .65112 .73941 L .65153 .73691 L F
.468 .21 .439 r
.6232 .78568 m .62511 .78793 L .6232 .78845 L F
.6232 .78568 m .62512 .78505 L .62511 .78793 L F
.656 .454 .599 r
.45671 .83664 m .45268 .83592 L .45482 .83553 L F
.45671 .83664 m .45275 .83821 L .45268 .83592 L F
.262 0 0 r
.46832 .88236 m .47034 .88241 L .46711 .88279 L F
.651 .772 .937 r
.56557 .775 m .56721 .77598 L .56394 .77552 L F
.718 .491 .581 r
.56721 .77598 m .56377 .7781 L .56394 .77552 L F
.56721 .77598 m .56716 .7783 L .56377 .7781 L F
.631 .419 .576 r
.56958 .77804 m .56716 .7783 L .56721 .77598 L F
.732 .554 .651 r
.56289 .78477 m .56024 .78511 L .56308 .78402 L F
.56289 .78477 m .56092 .78653 L .56024 .78511 L F
.385 .061 .288 r
.56289 .78477 m .56241 .78805 L .56092 .78653 L F
.56241 .78805 m .56236 .78807 L .56092 .78653 L F
.379 .056 .286 r
.56389 .78704 m .5624 .78811 L .56289 .78477 L F
.641 .592 .784 r
.56213 .78847 m .56312 .79051 L .56085 .79073 L F
.56252 .78778 m .56269 .78857 L .56213 .78847 L F
.56269 .78857 m .56312 .79051 L .56213 .78847 L F
.56235 .78807 m .56085 .79073 L .56013 .7889 L F
.56235 .78807 m .56013 .7889 L .55972 .78785 L F
.676 .343 .403 r
.55662 .78968 m .55972 .78785 L .55851 .79095 L F
.653 .525 .696 r
.56085 .79073 m .55851 .79095 L .55972 .78785 L F
.657 .321 .393 r
.56003 .78813 m .55861 .78997 L .56189 .7898 L F
.55972 .78785 m .55961 .78806 L .56003 .78813 L F
.55961 .78806 m .55861 .78997 L .56003 .78813 L F
.385 .061 .288 r
.56241 .78805 m .5624 .78811 L .56236 .78807 L F
.182 .049 .452 r
.56092 .78653 m .5624 .78811 L .56252 .78778 L F
.641 .592 .784 r
.56252 .78778 m .56235 .78807 L .55972 .78785 L F
.454 .333 .625 r
.56507 .78321 m .56289 .78477 L .56308 .78402 L F
.56507 .78321 m .5655 .78574 L .56289 .78477 L F
.379 .056 .286 r
.56389 .78704 m .56289 .78477 L .5655 .78574 L F
.694 .554 .692 r
.37923 .87237 m .38102 .87234 L .37959 .87439 L F
.285 .598 .95 r
.57061 .78247 m .57159 .78364 L .5722 .7825 L F
.934 .678 .201 r
.57274 .78389 m .5722 .7825 L .57159 .78364 L F
.156 0 0 r
.45956 .88477 m .46318 .88352 L .46153 .88429 L F
0 0 0 r
.46153 .88429 m .46318 .88352 L .46511 .88298 L F
.634 .312 .408 r
.44385 .82477 m .44724 .82271 L .44414 .82324 L F
.44385 .82477 m .44599 .82509 L .44724 .82271 L F
.635 .313 .409 r
.44724 .82271 m .44599 .82509 L .44907 .82447 L F
.827 .657 .672 r
.53979 .81951 m .53895 .82265 L .53824 .81992 L F
.233 0 .198 r
.58 .84065 m .58076 .83842 L .57823 .84069 L F
.835 .538 .487 r
.57712 .84166 m .578 .84142 L .57771 .84128 L F
.57712 .84166 m .57771 .84128 L .57484 .83985 L F
.151 0 0 r
.58 .84065 m .57862 .84068 L .57712 .84166 L F
.57862 .84068 m .57823 .84069 L .57712 .84166 L F
.808 .951 .61 r
.58161 .83646 m .58076 .83842 L .58257 .83813 L F
.223 0 .194 r
.58257 .83813 m .58076 .83842 L .58 .84065 L F
.694 .746 .891 r
.58658 .80706 m .5882 .8086 L .58999 .80735 L F
.205 0 0 r
.45925 .85474 m .45936 .85413 L .4616 .85408 L F
.214 0 0 r
.45936 .85413 m .46027 .85444 L .4616 .85408 L F
.957 .933 .725 r
.4616 .85408 m .46222 .85062 L .46333 .85316 L F
.214 0 0 r
.46027 .85444 m .46043 .8545 L .4616 .85408 L F
.957 .933 .725 r
.4616 .85408 m .46043 .8545 L .46051 .85432 L F
.4616 .85408 m .46051 .85432 L .46222 .85062 L F
.823 .713 .744 r
.46222 .85062 m .46051 .85432 L .45983 .85271 L F
.337 .815 .773 r
.46025 .85438 m .45957 .85462 L .4616 .85408 L F
.46027 .85444 m .45925 .85474 L .4616 .85408 L F
.205 0 0 r
.45925 .85474 m .46027 .85444 L .45936 .85413 L F
.778 .692 .768 r
.45983 .85271 m .46039 .85436 L .45925 .85474 L F
.337 .815 .773 r
.4597 .85459 m .45925 .85474 L .46027 .85444 L F
.205 0 0 r
.45925 .85474 m .46043 .8545 L .46027 .85444 L F
.778 .692 .768 r
.46039 .85436 m .46043 .8545 L .45925 .85474 L F
.337 .815 .773 r
.45957 .85462 m .45925 .85474 L .4597 .85459 L F
.823 .713 .744 r
.46051 .85432 m .46043 .8545 L .46039 .85436 L F
.46051 .85432 m .46039 .85436 L .45983 .85271 L F
.337 .815 .773 r
.46237 .85363 m .46025 .85438 L .46051 .85432 L F
.46196 .85387 m .46051 .85432 L .4616 .85408 L F
.46237 .85363 m .46051 .85432 L .46196 .85387 L F
0 0 0 r
.58452 .8339 m .5832 .8343 L .58161 .83646 L F
.58452 .8339 m .58529 .83326 L .5832 .8343 L F
.671 .666 .836 r
.52614 .83007 m .52528 .83263 L .5241 .83034 L F
.52614 .83007 m .52794 .83268 L .52528 .83263 L F
.606 .308 .437 r
.67227 .7473 m .67241 .7493 L .6693 .74946 L F
.642 .55 .735 r
.67358 .74373 m .67454 .74712 L .67227 .7473 L F
.539 .376 .608 r
.67262 .75013 m .67475 .74963 L .67454 .74712 L F
.289 .081 .414 r
.6735 .74929 m .67227 .7473 L .67454 .74712 L F
.6735 .74929 m .67241 .7493 L .67227 .7473 L F
.752 .511 .568 r
.54769 .83836 m .55093 .8385 L .55117 .84058 L F
.968 .652 .276 r
.54805 .82836 m .54865 .82808 L .54864 .83069 L F
0 0 .413 r
.56405 .82691 m .56425 .82744 L .56359 .825 L F
.641 .56 .748 r
.40592 .85927 m .40394 .86034 L .40292 .85683 L F
.457 .442 .753 r
.40599 .86166 m .40394 .86034 L .40592 .85927 L F
.489 .272 .51 r
.62781 .78283 m .62784 .78106 L .63005 .78068 L F
.038 0 0 r
.5703 .77246 m .5736 .77054 L .57189 .77156 L F
.631 .563 .759 r
.60452 .77333 m .60682 .77291 L .60597 .76999 L F
.688 .586 .736 r
.60466 .77562 m .60682 .77291 L .60452 .77333 L F
.663 .573 .743 r
.38533 .87685 m .38603 .87988 L .38437 .87986 L F
.514 .271 .483 r
.39083 .76335 m .38995 .76755 L .38791 .76789 L F
.549 .319 .518 r
.39288 .76263 m .39276 .76372 L .39083 .76335 L F
.501 .244 .457 r
.39276 .76372 m .38995 .76755 L .39083 .76335 L F
.848 .686 .681 r
.49869 .81466 m .49615 .81475 L .49756 .81223 L F
.845 .756 .764 r
.49869 .81466 m .49713 .81735 L .49615 .81475 L F
.509 .282 .505 r
.37927 .73661 m .37855 .73873 L .37695 .73715 L F
.836 .965 .888 r
.61699 .74279 m .61765 .74089 L .61869 .74144 L F
.61699 .74279 m .61606 .7425 L .61765 .74089 L F
.372 0 .195 r
.67407 .75784 m .67124 .75949 L .67191 .7583 L F
0 0 0 r
.65686 .76581 m .65973 .76501 L .65899 .76528 L F
.546 .877 .991 r
.66081 .76403 m .65973 .76501 L .66121 .76433 L F
.548 .917 .75 r
.65899 .76528 m .65973 .76501 L .66081 .76403 L F
.937 .639 .451 r
.67566 .72856 m .67737 .72959 L .67536 .72623 L F
.903 .769 .703 r
.67653 .73059 m .67737 .72959 L .67566 .72856 L F
.418 0 0 r
.5799 .84916 m .58304 .84857 L .58225 .84926 L F
.286 0 0 r
.58304 .84857 m .58437 .84902 L .58225 .84926 L F
.58304 .84857 m .58518 .84851 L .58437 .84902 L F
.827 .35 .005 r
.56984 .78975 m .57176 .79177 L .57267 .78899 L F
.475 .047 .146 r
.44907 .82447 m .45123 .82445 L .45251 .82277 L F
.587 .204 .283 r
.45123 .82445 m .45464 .82278 L .45251 .82277 L F
.292 0 0 r
.44232 .8767 m .43926 .87711 L .44111 .87634 L F
.781 .798 .867 r
.44346 .87383 m .44232 .8767 L .44111 .87634 L F
.44346 .87383 m .4447 .87495 L .44232 .8767 L F
.514 .466 .741 r
.4562 .8692 m .45726 .8727 L .4551 .87248 L F
.498 .51 .8 r
.45726 .8727 m .45706 .87355 L .4551 .87248 L F
.432 .02 .156 r
.48584 .8383 m .48457 .84007 L .48273 .84023 L F
.173 .71 .801 r
.48814 .83976 m .48457 .84007 L .48584 .8383 L F
.649 .444 .592 r
.3581 .77043 m .35885 .76965 L .35823 .76815 L F
.671 .263 .264 r
.5123 .82968 m .51551 .83011 L .51364 .82865 L F
.594 .76 .958 r
.40755 .88013 m .40583 .88089 L .40402 .87956 L F
.567 .441 .668 r
.52195 .83074 m .51991 .83327 L .52029 .83232 L F
.52195 .83074 m .52199 .83296 L .51991 .83327 L F
.287 .338 .741 r
.64678 .72743 m .6468 .72748 L .64573 .72928 L F
.615 .908 .626 r
.64832 .72794 m .64682 .72951 L .64755 .7286 L F
.507 .169 .328 r
.64573 .72928 m .64755 .7286 L .64682 .72951 L F
.64573 .72928 m .6476 .7302 L .64755 .7286 L F
.287 .338 .741 r
.6468 .72748 m .6476 .7302 L .64573 .72928 L F
.832 .863 .868 r
.64682 .72951 m .64519 .73019 L .64573 .72928 L F
.64519 .73019 m .64335 .73095 L .64573 .72928 L F
.538 .561 .826 r
.52211 .84607 m .52332 .84896 L .52538 .84897 L F
.971 .657 .297 r
.47723 .83883 m .47724 .84047 L .47605 .83762 L F
.516 .235 .426 r
.36719 .78331 m .36441 .78593 L .36518 .78365 L F
.515 .395 .653 r
.38684 .87219 m .38691 .87456 L .38522 .87484 L F
.525 .388 .637 r
.38691 .87456 m .38533 .87685 L .38522 .87484 L F
0 0 0 r
.58939 .84788 m .59088 .8467 L .59256 .84584 L F
.698 .562 .697 r
.39615 .82537 m .39689 .82733 L .3939 .82805 L F
.314 .343 .732 r
.39615 .82537 m .39689 .82733 L .39854 .82778 L F
.694 .847 .956 r
.57072 .79437 m .57387 .79431 L .5727 .79358 L F
.329 0 .124 r
.6451 .76275 m .64296 .76323 L .6424 .76426 L F
.236 0 0 r
.42248 .82636 m .42447 .8264 L .42601 .82585 L F
.479 0 .01 r
.42447 .8264 m .42802 .82543 L .42601 .82585 L F
.601 .56 .78 r
.48731 .84784 m .48765 .85091 L .49039 .84958 L F
.622 .556 .759 r
.50071 .83313 m .50332 .83787 L .50477 .83613 L F
.544 .34 .553 r
.5018 .83825 m .50477 .83613 L .50332 .83787 L F
.775 .578 .632 r
.40813 .85683 m .40493 .85408 L .4092 .85516 L F
.40813 .85683 m .40749 .85725 L .40493 .85408 L F
.592 .392 .58 r
.40806 .85891 m .40749 .85725 L .40813 .85683 L F
.66 .414 .536 r
.41032 .85857 m .40806 .85891 L .40813 .85683 L F
.67 .712 .879 r
.37341 .73426 m .37028 .73352 L .3721 .73311 L F
.532 .343 .571 r
.37341 .73426 m .37338 .73704 L .37129 .73726 L F
.76 .466 .486 r
.39282 .83013 m .3939 .82805 L .39064 .82793 L F
.773 .796 .871 r
.37546 .7325 m .37341 .73426 L .3721 .73311 L F
.542 .352 .573 r
.37533 .7363 m .37338 .73704 L .37341 .73426 L F
.603 .302 .432 r
.39772 .83016 m .3939 .82805 L .39282 .83013 L F
.39772 .83016 m .39689 .82733 L .3939 .82805 L F
.972 .697 .449 r
.58545 .83563 m .58529 .83326 L .58452 .8339 L F
0 0 0 r
.59445 .82182 m .59509 .82023 L .5934 .82273 L F
.697 .963 .72 r
.59766 .81762 m .59509 .82023 L .59516 .81973 L F
.737 .779 .284 r
.59516 .81973 m .59509 .82023 L .59445 .82182 L F
.756 .764 .859 r
.62433 .73958 m .62125 .73954 L .623 .73839 L F
.772 .765 .847 r
.62658 .73756 m .62433 .73958 L .623 .73839 L F
.503 .244 .453 r
.38137 .77071 m .38092 .77278 L .3789 .77309 L F
.521 .278 .488 r
.38332 .77027 m .38092 .77278 L .38137 .77071 L F
.452 .108 .291 r
.49933 .83992 m .49842 .84265 L .4963 .84294 L F
.552 .632 .884 r
.50172 .83928 m .49933 .83992 L .49855 .83835 L F
.595 .327 .48 r
.50172 .83928 m .49842 .84265 L .49933 .83992 L F
.613 .364 .516 r
.45671 .83664 m .45465 .84019 L .45275 .83821 L F
.032 0 .126 r
.45682 .83751 m .45465 .84019 L .45671 .83664 L F
.75 .253 .049 r
.45482 .83553 m .45682 .83751 L .45671 .83664 L F
.696 .337 .361 r
.45791 .83537 m .45682 .83751 L .45482 .83553 L F
.652 .287 .339 r
.46034 .83603 m .45791 .83537 L .45997 .83523 L F
.46034 .83603 m .45682 .83751 L .45791 .83537 L F
0 0 0 r
.58146 .80917 m .58491 .80686 L .5822 .80736 L F
.845 .803 .81 r
.50826 .85938 m .50926 .86125 L .51057 .85762 L F
.664 .923 .975 r
.42331 .89271 m .42701 .89159 L .42529 .89138 L F
.612 .912 .981 r
.42529 .89138 m .42701 .89159 L .42895 .8908 L F
.522 .287 .499 r
.65609 .72644 m .65845 .72353 L .65609 .72383 L F
.65609 .72644 m .65845 .72353 L .65609 .72383 L F
.125 .663 .852 r
.65951 .73946 m .65849 .73923 L .65632 .7392 L F
.65951 .73946 m .65849 .73923 L .65632 .7392 L F
0 0 .362 r
.66094 .73623 m .65951 .73946 L .65849 .73923 L F
.66094 .73623 m .66079 .73854 L .65951 .73946 L F
.488 .882 .959 r
.65951 .73946 m .66079 .73854 L .65849 .73923 L F
.8 .32 .072 r
.54728 .81457 m .54983 .81679 L .54828 .81537 L F
.617 .483 .676 r
.39112 .86695 m .38911 .86966 L .38895 .86725 L F
.506 .905 .924 r
.50762 .88202 m .50872 .88208 L .51078 .88129 L F
.072 0 0 r
.52156 .81751 m .51957 .81921 L .51848 .81943 L F
.525 .304 .521 r
.52403 .81513 m .52398 .81778 L .52156 .81751 L F
.718 .695 .827 r
.52398 .81778 m .52568 .82023 L .52229 .81819 L F
.772 .517 .551 r
.52568 .82023 m .52193 .82231 L .52229 .81819 L F
.41 0 .072 r
.52229 .81819 m .52288 .81894 L .52398 .81778 L F
.717 .66 .792 r
.52219 .81931 m .52288 .81894 L .52229 .81819 L F
.52193 .82231 m .52288 .81894 L .52219 .81931 L F
.589 .646 .875 r
.52721 .81981 m .52568 .82023 L .52398 .81778 L F
.346 .791 .957 r
.52483 .81866 m .52348 .81861 L .52288 .81894 L F
.49 .051 .13 r
.52398 .81778 m .52288 .81894 L .51957 .81921 L F
.346 .791 .957 r
.52348 .81861 m .52163 .81854 L .52288 .81894 L F
.49 .051 .13 r
.52398 .81778 m .51957 .81921 L .52156 .81751 L F
.459 .605 .909 r
.43823 .87509 m .43724 .8767 L .43567 .87558 L F
.43823 .87509 m .43926 .87711 L .43724 .8767 L F
.749 .702 .808 r
.63105 .74732 m .63412 .74928 L .63308 .74632 L F
.63105 .74732 m .63191 .7499 L .63412 .74928 L F
.671 .649 .819 r
.63308 .74632 m .63412 .74928 L .63619 .74694 L F
.68 .937 .966 r
.49039 .84958 m .49346 .84893 L .49258 .84863 L F
.988 .721 .411 r
.49236 .84591 m .49258 .84863 L .49346 .84893 L F
.539 .446 .698 r
.3887 .7441 m .38745 .74861 L .38633 .74455 L F
.3887 .7441 m .38945 .74818 L .38745 .74861 L F
.508 .591 .872 r
.38974 .74925 m .38745 .74861 L .38945 .74818 L F
.937 .638 .449 r
.52999 .81625 m .53 .81633 L .53148 .81638 L F
.518 .906 .94 r
.53207 .8164 m .52941 .81715 L .53148 .81638 L F
.53156 .81658 m .52941 .81715 L .53368 .81595 L F
.526 .315 .536 r
.53148 .81638 m .52941 .81715 L .53486 .81572 L F
.53148 .81638 m .52939 .8195 L .52941 .81715 L F
0 0 0 r
.53148 .81638 m .53023 .81864 L .52939 .8195 L F
.937 .638 .449 r
.53 .81633 m .53023 .81864 L .53148 .81638 L F
.518 .906 .94 r
.53368 .81595 m .53207 .8164 L .53148 .81638 L F
.53486 .81572 m .53156 .81658 L .53368 .81595 L F
.547 .602 .86 r
.53132 .81224 m .5333 .81373 L .53343 .81426 L F
.5333 .81373 m .53484 .8149 L .53343 .81426 L F
.835 .918 .891 r
.53343 .81426 m .53148 .81638 L .53484 .8149 L F
.897 .824 .767 r
.53343 .81426 m .53486 .81572 L .53148 .81638 L F
0 0 0 r
.53343 .81426 m .53285 .81574 L .53359 .81487 L F
.426 .809 .99 r
.53683 .81452 m .53343 .81426 L .53484 .8149 L F
.466 .339 .622 r
.53683 .81452 m .53606 .81523 L .53343 .81426 L F
.626 .129 .051 r
.53472 .81646 m .53148 .81638 L .53435 .81582 L F
.897 .824 .767 r
.53343 .81426 m .53472 .81646 L .53486 .81572 L F
.62 .585 .793 r
.53472 .81646 m .53683 .81452 L .53484 .8149 L F
.466 .339 .622 r
.53606 .81523 m .53431 .81576 L .53343 .81426 L F
0 0 0 r
.53343 .81426 m .53359 .81487 L .53476 .81349 L F
.466 .339 .622 r
.53606 .81523 m .53472 .81646 L .53431 .81576 L F
.626 .129 .051 r
.53472 .81646 m .53388 .81762 L .53148 .81638 L F
.62 .585 .793 r
.53472 .81646 m .53781 .81744 L .53683 .81452 L F
.549 0 0 r
.53562 .8182 m .53781 .81744 L .53472 .81646 L F
.331 0 0 r
.53781 .81744 m .5375 .81748 L .53472 .81646 L F
.466 .339 .622 r
.53683 .81452 m .5375 .81748 L .53472 .81646 L F
.639 .224 .24 r
.5375 .81748 m .53388 .81762 L .53472 .81646 L F
.71 .682 .821 r
.59282 .77064 m .59594 .77091 L .59482 .76793 L F
.784 .719 .792 r
.59482 .76793 m .59594 .77091 L .59802 .76828 L F
.701 .67 .817 r
.60009 .76772 m .60333 .76811 L .60216 .76534 L F
.638 .611 .806 r
.60333 .76811 m .60448 .76475 L .60216 .76534 L F
.60333 .76811 m .60555 .76782 L .60448 .76475 L F
.556 .497 .744 r
.60333 .76811 m .60597 .76999 L .60555 .76782 L F
.69 .577 .724 r
.60466 .77562 m .60561 .77853 L .60776 .77598 L F
.693 .582 .727 r
.60776 .77598 m .60561 .77853 L .60794 .77823 L F
.638 .564 .755 r
.60561 .77853 m .60868 .78099 L .60794 .77823 L F
.496 .487 .776 r
.60381 .78319 m .60676 .78606 L .60649 .78377 L F
.789 .689 .754 r
.62673 .7523 m .62981 .75252 L .62875 .74958 L F
.789 .687 .751 r
.62673 .7523 m .62784 .75521 L .62981 .75252 L F
.763 .676 .767 r
.62875 .74958 m .62981 .75252 L .63191 .7499 L F
.919 .929 .8 r
.5798 .77735 m .58077 .77762 L .58172 .77523 L F
.806 .321 .04 r
.54126 .80883 m .54332 .81018 L .54289 .80948 L F
.328 0 0 r
.46846 .83634 m .46795 .83645 L .46541 .83561 L F
.647 .129 0 r
.469 .83733 m .46795 .83645 L .46846 .83634 L F
.594 .145 .156 r
.46375 .83492 m .46203 .83571 L .45997 .83523 L F
.606 .163 .171 r
.46541 .83561 m .46203 .83571 L .46375 .83492 L F
.736 .707 .823 r
.65112 .73941 m .65429 .73999 L .65173 .73914 L F
.658 .743 .913 r
.65429 .73999 m .65632 .7392 L .65173 .73914 L F
.433 0 0 r
.50101 .87759 m .50237 .87772 L .49941 .87697 L F
.686 .949 .956 r
.50413 .87662 m .50237 .87772 L .50101 .87759 L F
.601 .757 .953 r
.49713 .81735 m .49412 .81678 L .49615 .81475 L F
.698 .364 .407 r
.49713 .81735 m .49634 .81951 L .49395 .81931 L F
.641 .304 .386 r
.49713 .81735 m .49933 .81949 L .49634 .81951 L F
.683 .566 .717 r
.49115 .81492 m .49263 .81762 L .48931 .81733 L F
.605 .507 .716 r
.49186 .81928 m .48931 .81733 L .49263 .81762 L F
.49186 .81928 m .48984 .8202 L .48931 .81733 L F
0 0 0 r
.49788 .88705 m .50201 .88599 L .50012 .88649 L F
.793 .945 .924 r
.50012 .88649 m .50201 .88599 L .50305 .88486 L F
.653 .564 .742 r
.63289 .76518 m .63415 .7625 L .63213 .76321 L F
.63289 .76518 m .63492 .76494 L .63415 .7625 L F
.461 .166 .377 r
.63235 .7677 m .63492 .76494 L .63289 .76518 L F
.694 .421 .506 r
.59945 .80072 m .59647 .79951 L .59628 .80152 L F
.757 .705 .803 r
.63698 .735 m .63352 .73608 L .63598 .7338 L F
.725 .758 .879 r
.63915 .73411 m .63698 .735 L .63598 .7338 L F
.522 .308 .53 r
.66545 .73951 m .66498 .74191 L .66709 .7413 L F
.66709 .7413 m .66498 .74191 L .66545 .73951 L F
.246 0 .329 r
.36487 .76837 m .3642 .77033 L .36626 .76766 L F
.128 0 0 r
.47363 .88238 m .47567 .88241 L .47235 .88255 L F
.398 .185 .47 r
.39854 .82778 m .39689 .82733 L .39772 .83016 L F
.573 .938 .817 r
.52809 .86997 m .52465 .8717 L .52613 .87094 L F
.223 0 .205 r
.5278 .87095 m .52821 .86987 L .52613 .87094 L F
.768 .996 .814 r
.52869 .8686 m .52809 .86997 L .52613 .87094 L F
.223 0 .205 r
.52821 .86987 m .52869 .8686 L .52613 .87094 L F
.573 .938 .817 r
.52465 .8717 m .52456 .87175 L .52613 .87094 L F
.751 .991 .883 r
.52869 .8686 m .53066 .86808 L .52809 .86997 L F
.497 .525 .816 r
.60676 .78606 m .60782 .78893 L .60905 .78829 L F
.306 .122 .459 r
.60905 .78829 m .60782 .78893 L .60741 .79125 L F
.145 0 .31 r
.6034 .83059 m .60274 .83263 L .60169 .83317 L F
.23 .094 .48 r
.60169 .83317 m .60274 .83263 L .60161 .83559 L F
.664 .866 .976 r
.40208 .87974 m .4 .88049 L .39889 .87978 L F
.222 0 0 r
.63977 .77345 m .64076 .77419 L .6391 .77533 L F
.63977 .77345 m .6419 .77299 L .64076 .77419 L F
.619 .823 .979 r
.52276 .81213 m .52064 .81283 L .51949 .81185 L F
.63 .149 .092 r
.58645 .83685 m .58822 .83577 L .58545 .83563 L F
.201 0 .151 r
.58989 .83486 m .59068 .83375 L .58822 .83577 L F
0 0 0 r
.58989 .83486 m .58822 .83577 L .58645 .83685 L F
.706 .618 .757 r
.53269 .84363 m .53211 .8474 L .52969 .84324 L F
.438 .349 .658 r
.53519 .84609 m .53305 .84634 L .53269 .84363 L F
.347 .736 .985 r
.5346 .84601 m .53354 .84624 L .53519 .84609 L F
.53354 .84624 m .53345 .84629 L .53519 .84609 L F
.409 .779 .994 r
.53813 .84821 m .53474 .84778 L .53703 .8452 L F
0 0 0 r
.53305 .84634 m .53225 .84651 L .53269 .84363 L F
.347 .736 .985 r
.53172 .84559 m .53305 .84634 L .5346 .84601 L F
.615 .354 .499 r
.53269 .84363 m .53521 .84336 L .53519 .84609 L F
.941 .641 .442 r
.53519 .84609 m .5352 .84515 L .53402 .84485 L F
.5352 .84515 m .53521 .84336 L .53457 .84417 L F
.5352 .84515 m .53457 .84417 L .53402 .84485 L F
.661 .569 .741 r
.534 .84043 m .53269 .84363 L .53171 .84071 L F
.534 .84043 m .53521 .84336 L .53269 .84363 L F
.657 .495 .652 r
.53399 .83785 m .534 .84043 L .53171 .84071 L F
0 0 0 r
.53589 .84241 m .53521 .84336 L .53702 .8406 L F
.727 .602 .717 r
.53702 .8406 m .53521 .84336 L .534 .84043 L F
.672 .619 .788 r
.53261 .84001 m .53505 .84352 L .53589 .84241 L F
.589 .831 .456 r
.53532 .84316 m .53521 .84336 L .53589 .84241 L F
.672 .619 .788 r
.53505 .84352 m .53536 .84398 L .53589 .84241 L F
.589 .831 .456 r
.53533 .84313 m .53532 .84316 L .53589 .84241 L F
.53457 .84417 m .53521 .84336 L .53526 .84326 L F
.53477 .84389 m .53526 .84326 L .53533 .84313 L F
.53457 .84417 m .53526 .84326 L .53477 .84389 L F
.54 .189 .321 r
.53402 .84485 m .53536 .84398 L .53477 .84389 L F
.53402 .84485 m .53477 .84389 L .53139 .84339 L F
.494 .55 .843 r
.53435 .84383 m .53536 .84398 L .53235 .84072 L F
.589 .831 .456 r
.53402 .84485 m .53457 .84417 L .53533 .84313 L F
.494 .55 .843 r
.53235 .84072 m .535 .84358 L .53261 .84001 L F
.535 .84358 m .53536 .84398 L .53505 .84352 L F
.535 .84358 m .53505 .84352 L .53261 .84001 L F
.71 .602 .734 r
.53171 .84071 m .53269 .84363 L .52969 .84324 L F
.494 .55 .843 r
.53139 .84339 m .53435 .84383 L .53235 .84072 L F
.347 .736 .985 r
.53172 .84559 m .53519 .84609 L .53402 .84485 L F
.782 .709 .783 r
.53402 .84485 m .53703 .8452 L .53474 .84778 L F
.872 .845 .815 r
.53589 .84241 m .53536 .84398 L .53402 .84485 L F
.787 .694 .761 r
.53589 .84241 m .53703 .8452 L .53402 .84485 L F
.822 .708 .74 r
.53484 .84687 m .53703 .8452 L .53589 .84241 L F
.308 .388 .782 r
.5395 .8472 m .53813 .84821 L .53703 .8452 L F
.609 .048 0 r
.53786 .84621 m .53703 .8452 L .53484 .84687 L F
.746 .63 .731 r
.53402 .84485 m .53484 .84687 L .53589 .84241 L F
.609 .048 0 r
.53786 .84621 m .53484 .84687 L .53588 .84707 L F
.085 .238 .726 r
.53588 .84707 m .53484 .84687 L .53402 .84485 L F
.782 .709 .783 r
.53463 .84557 m .53474 .84778 L .53588 .84707 L F
.53402 .84485 m .53426 .8458 L .53463 .84557 L F
.53426 .8458 m .53474 .84778 L .53463 .84557 L F
.347 .736 .985 r
.53354 .84624 m .53305 .84634 L .53345 .84629 L F
0 0 0 r
.53305 .84634 m .53211 .8474 L .53225 .84651 L F
.323 .624 .959 r
.49427 .83532 m .49313 .83629 L .492 .83549 L F
.49427 .83532 m .49578 .83681 L .49313 .83629 L F
.734 .686 .805 r
.52939 .83003 m .52794 .83268 L .52614 .83007 L F
.487 .566 .861 r
.57433 .82478 m .5725 .82497 L .57115 .82228 L F
.652 .557 .735 r
.57514 .82612 m .5725 .82497 L .57433 .82478 L F
.754 .625 .717 r
.66211 .75221 m .66496 .75264 L .66523 .74992 L F
.728 .359 .35 r
.66444 .75437 m .66496 .75264 L .66211 .75221 L F
.447 .063 .217 r
.66444 .75437 m .66734 .7525 L .66496 .75264 L F
.561 .317 .504 r
.66496 .75264 m .66798 .75119 L .66523 .74992 L F
.204 .72 .878 r
.43852 .88816 m .43956 .88838 L .44158 .88825 L F
.571 .929 .763 r
.60714 .7495 m .60809 .74846 L .6098 .74768 L F
.564 .91 .694 r
.60714 .7495 m .60672 .74961 L .60809 .74846 L F
.84 .843 .847 r
.5712 .8092 m .57256 .81008 L .5741 .80806 L F
.933 .784 .672 r
.57185 .81219 m .57256 .81008 L .5712 .8092 L F
.353 0 .189 r
.57253 .77566 m .57166 .7777 L .56958 .77804 L F
.685 .313 .337 r
.57469 .77769 m .57253 .77566 L .5746 .77559 L F
.57469 .77769 m .57166 .7777 L .57253 .77566 L F
0 0 0 r
.56425 .82744 m .56319 .83032 L .56341 .82979 L F
.723 .444 0 r
.56359 .825 m .56425 .82744 L .56427 .82771 L F
0 0 0 r
.56427 .82771 m .56425 .82744 L .56341 .82979 L F
.549 0 0 r
.53562 .8182 m .53824 .81992 L .53644 .81904 L F
.53562 .8182 m .53644 .81904 L .53781 .81744 L F
.587 .492 .714 r
.6002 .80896 m .59928 .81217 L .59887 .80948 L F
.583 .901 .984 r
.6002 .80896 m .59887 .80948 L .59749 .80898 L F
.686 .572 .721 r
.39418 .869 m .39112 .86695 L .39407 .86702 L F
.572 .397 .606 r
.39641 .86683 m .39418 .869 L .39407 .86702 L F
.601 .775 .963 r
.36028 .74904 m .36266 .7493 L .36213 .74849 L F
.185 .448 .875 r
.36266 .7493 m .36346 .74836 L .36213 .74849 L F
.36266 .7493 m .36354 .74995 L .36346 .74836 L F
.54 .354 .577 r
.58201 .78377 m .58222 .78596 L .58434 .78338 L F
.58434 .78338 m .58222 .78596 L .58201 .78377 L F
.577 .418 .629 r
.59832 .79655 m .60043 .79388 L .59816 .79421 L F
0 0 0 r
.45015 .88698 m .45267 .88606 L .45096 .88681 L F
.45096 .88681 m .45267 .88606 L .45457 .88558 L F
.716 .546 .658 r
.63415 .7625 m .63772 .76236 L .63664 .75995 L F
.618 .435 .612 r
.63772 .76236 m .64034 .76156 L .63664 .75995 L F
.475 .895 .881 r
.58365 .77312 m .58688 .7722 L .58612 .77199 L F
.724 .989 .832 r
.58612 .77199 m .58688 .7722 L .58924 .77007 L F
.379 .715 .987 r
.36224 .72972 m .36184 .73074 L .36025 .73 L F
.36224 .72972 m .36356 .73068 L .36184 .73074 L F
.901 .542 .348 r
.55204 .80338 m .55075 .80325 L .55025 .80173 L F
.793 .304 0 r
.55204 .80338 m .55203 .80418 L .55075 .80325 L F
.55204 .80338 m .55313 .80486 L .55203 .80418 L F
.646 .782 .946 r
.37246 .74845 m .37392 .75028 L .3763 .74946 L F
0 0 0 r
.57325 .83257 m .5751 .83038 L .57556 .83263 L F
.174 .059 .472 r
.57609 .83024 m .5751 .83038 L .57596 .82778 L F
.163 .008 .41 r
.57556 .83263 m .5751 .83038 L .57609 .83024 L F
.229 0 .113 r
.66946 .76031 m .66866 .76214 L .66678 .76226 L F
.365 .03 .257 r
.67124 .75949 m .66866 .76214 L .66946 .76031 L F
.018 .592 .712 r
.51211 .81166 m .51413 .81162 L .51624 .81158 L F
.27 .757 .918 r
.51413 .81162 m .51763 .81172 L .51624 .81158 L F
.889 .917 .837 r
.54783 .79609 m .54816 .79404 L .5462 .79401 L F
.54783 .79609 m .54628 .79603 L .54816 .79404 L F
.887 .661 .591 r
.54822 .79883 m .54628 .79603 L .54783 .79609 L F
.754 .625 .717 r
.66211 .75221 m .66523 .74992 L .66411 .74996 L F
.419 .612 .929 r
.66523 .74992 m .66613 .74915 L .66411 .74996 L F
.66523 .74992 m .66798 .75119 L .66613 .74915 L F
.482 .248 .481 r
.37402 .76305 m .37591 .76268 L .37628 .76045 L F
.524 .289 .5 r
.37591 .76268 m .37832 .76008 L .37628 .76045 L F
.699 .278 .242 r
.45054 .83859 m .44951 .83971 L .44737 .83814 L F
.596 .221 .302 r
.45275 .83821 m .44951 .83971 L .45054 .83859 L F
.694 .73 .879 r
.64551 .74095 m .64876 .74126 L .6479 .7391 L F
.746 .752 .857 r
.6479 .7391 m .64876 .74126 L .65112 .73941 L F
.688 .586 .736 r
.60466 .77562 m .60776 .77598 L .60682 .77291 L F
.626 .597 .802 r
.39688 .75747 m .39491 .7581 L .39457 .75477 L F
.495 .436 .719 r
.39705 .75977 m .39491 .7581 L .39688 .75747 L F
.39705 .75977 m .39541 .76039 L .39491 .7581 L F
.743 .493 .552 r
.49683 .80986 m .50068 .81179 L .4982 .81 L F
.695 .435 .527 r
.43461 .84097 m .43355 .84387 L .43112 .8431 L F
.4 .137 .395 r
.43555 .84308 m .43461 .84097 L .43669 .84107 L F
.43555 .84308 m .43355 .84387 L .43461 .84097 L F
.635 .554 .746 r
.38815 .87918 m .38603 .87988 L .38533 .87685 L F
.445 .077 .243 r
.4562 .8692 m .45449 .86915 L .45307 .87169 L F
.632 .44 .605 r
.59928 .81217 m .59949 .81512 L .5968 .81499 L F
.587 .492 .714 r
.6002 .80896 m .60163 .81198 L .59928 .81217 L F
.603 .434 .625 r
.60163 .81198 m .59949 .81512 L .59928 .81217 L F
.664 .511 .667 r
.60794 .77823 m .61007 .77618 L .60776 .77598 L F
.60794 .77823 m .61082 .77832 L .61007 .77618 L F
.53 .358 .593 r
.60868 .78099 m .61082 .77832 L .60794 .77823 L F
.689 .628 .782 r
.41951 .85254 m .41763 .85129 L .42071 .85157 L F
.324 0 .191 r
.4227 .85092 m .41951 .85254 L .42071 .85157 L F
.4227 .85092 m .42162 .85305 L .41951 .85254 L F
.668 .335 .4 r
.42232 .85513 m .41951 .85254 L .42162 .85305 L F
.42232 .85513 m .41961 .85572 L .41951 .85254 L F
.199 0 0 r
.42802 .82543 m .42995 .82522 L .43133 .8246 L F
.463 0 0 r
.43133 .8246 m .42995 .82522 L .4332 .8249 L F
.787 .686 .752 r
.62673 .7523 m .6247 .75494 L .62784 .75521 L F
.772 .636 .71 r
.62456 .75709 m .62784 .75521 L .6247 .75494 L F
.62456 .75709 m .62741 .75751 L .62784 .75521 L F
.36 .123 .413 r
.39705 .75977 m .39493 .76235 L .39541 .76039 L F
.967 .892 .701 r
.50477 .83613 m .50712 .83749 L .50634 .8357 L F
.557 .569 .822 r
.50634 .8357 m .50712 .83749 L .50862 .8367 L F
.782 .666 .735 r
.62349 .76491 m .62673 .76517 L .62683 .76309 L F
.786 .634 .693 r
.62349 .76491 m .62478 .76789 L .62673 .76517 L F
.752 .585 .669 r
.62478 .76789 m .62768 .76764 L .62673 .76517 L F
.738 .628 .737 r
.62683 .76309 m .62673 .76517 L .629 .76256 L F
.744 .502 .565 r
.63001 .76781 m .62673 .76517 L .62768 .76764 L F
.465 .292 .561 r
.61087 .80436 m .61087 .802 L .6128 .80151 L F
.432 .848 .962 r
.44158 .88825 m .44491 .88805 L .4437 .88784 L F
.519 .894 .965 r
.44566 .88717 m .44491 .88805 L .44684 .88739 L F
.521 .896 .963 r
.4437 .88784 m .44491 .88805 L .44566 .88717 L F
.707 .572 .7 r
.40493 .85408 m .40749 .85725 L .40292 .85683 L F
.187 .547 .929 r
.49765 .83725 m .49667 .83764 L .49578 .83681 L F
.49765 .83725 m .49855 .83835 L .49667 .83764 L F
.753 .704 .806 r
.62875 .74958 m .63191 .7499 L .63105 .74732 L F
.772 .517 .551 r
.52568 .82023 m .52532 .82283 L .52332 .82252 L F
.52568 .82023 m .52332 .82252 L .52266 .8219 L F
.478 .252 .492 r
.52721 .81981 m .52532 .82283 L .52568 .82023 L F
.68 .762 .913 r
.52532 .82283 m .52306 .82434 L .52259 .8235 L F
.52332 .82252 m .52259 .8235 L .52193 .82231 L F
.52532 .82283 m .52259 .8235 L .52332 .82252 L F
.713 .538 .652 r
.52721 .81981 m .52762 .82248 L .52532 .82283 L F
.827 .451 .343 r
.52193 .82231 m .52376 .82456 L .52373 .8233 L F
.766 .474 .491 r
.52332 .82252 m .52376 .82456 L .52193 .82231 L F
.717 .66 .792 r
.52193 .82231 m .52373 .8233 L .52362 .82277 L F
.766 .474 .491 r
.52532 .82283 m .52503 .82315 L .52332 .82252 L F
.772 .517 .551 r
.52266 .8219 m .52332 .82252 L .52193 .82231 L F
.516 .521 .8 r
.52365 .82279 m .52363 .82281 L .52368 .82281 L F
.68 .762 .913 r
.52463 .82359 m .5241 .82334 L .52376 .82456 L F
.766 .474 .491 r
.52503 .82315 m .52463 .82359 L .52362 .82277 L F
.63 .763 .942 r
.52859 .82374 m .52532 .82283 L .52762 .82248 L F
.642 .535 .717 r
.52376 .82456 m .52664 .82253 L .52415 .82319 L F
.52376 .82456 m .52415 .82319 L .52373 .8233 L F
.68 .762 .913 r
.5241 .82334 m .52193 .82231 L .52376 .82456 L F
.52532 .82283 m .52332 .82252 L .52463 .82359 L F
.516 .521 .8 r
.52362 .82277 m .52363 .82281 L .52365 .82279 L F
.52363 .82281 m .52373 .8233 L .52406 .82322 L F
.68 .762 .913 r
.52332 .82252 m .52193 .82231 L .52463 .82359 L F
.516 .521 .8 r
.52352 .82226 m .52362 .82277 L .52471 .82069 L F
.52362 .82277 m .52365 .82279 L .52471 .82069 L F
.717 .66 .792 r
.52193 .82231 m .52362 .82277 L .52288 .81894 L F
.766 .474 .491 r
.52503 .82315 m .52362 .82277 L .52332 .82252 L F
.52463 .82359 m .52376 .82456 L .52332 .82252 L F
.516 .521 .8 r
.52471 .82069 m .52365 .82279 L .52664 .82253 L F
.52365 .82279 m .52368 .82281 L .52664 .82253 L F
.52288 .81894 m .52352 .82226 L .52471 .82069 L F
.52363 .82281 m .52406 .82322 L .52664 .82253 L F
.705 .883 .963 r
.40219 .8961 m .4055 .89582 L .40417 .89516 L F
0 0 0 r
.40398 .89525 m .40219 .8961 L .40417 .89516 L F
.575 .9 .983 r
.39914 .89753 m .40376 .8968 L .40219 .8961 L F
0 0 0 r
.39947 .89742 m .40219 .8961 L .40398 .89525 L F
.575 .9 .983 r
.39895 .89756 m .39914 .89753 L .40219 .8961 L F
.705 .883 .963 r
.40219 .8961 m .40376 .8968 L .4055 .89582 L F
.804 .722 .775 r
.53013 .83604 m .5317 .83834 L .52867 .83787 L F
.774 .55 .595 r
.5317 .83834 m .52846 .84044 L .52867 .83787 L F
.5317 .83834 m .53171 .84071 L .52846 .84044 L F
.633 .717 .908 r
.53282 .83606 m .5317 .83834 L .53013 .83604 L F
.53282 .83606 m .53399 .83785 L .5317 .83834 L F
.657 .495 .652 r
.53399 .83785 m .53171 .84071 L .5317 .83834 L F
.696 .63 .779 r
.51465 .84857 m .51787 .84915 L .51695 .84631 L F
.739 .654 .766 r
.51695 .84631 m .51787 .84915 L .51997 .84661 L F
.423 .851 .947 r
.38725 .90061 m .3905 .90029 L .38929 .9 L F
.323 .81 .829 r
.3905 .90029 m .39117 .89986 L .38929 .9 L F
.3905 .90029 m .3925 .89973 L .39117 .89986 L F
.706 .657 .798 r
.60776 .77598 m .61007 .77618 L .61019 .77508 L F
.506 .474 .756 r
.61019 .77508 m .61007 .77618 L .61205 .77511 L F
.644 .592 .781 r
.61082 .77832 m .61205 .77511 L .61007 .77618 L F
0 0 0 r
.48164 .86046 m .48238 .85971 L .48398 .85886 L F
.69 .782 .922 r
.56308 .78402 m .56024 .78511 L .5602 .78362 L F
.804 .992 .876 r
.53196 .86671 m .53066 .86808 L .52869 .8686 L F
.102 0 0 r
.52496 .83755 m .52842 .83578 L .52737 .83715 L F
.481 .358 .634 r
.52984 .83299 m .53013 .83604 L .52842 .83578 L F
.452 .006 .098 r
.53013 .83604 m .52737 .83715 L .52842 .83578 L F
.759 .767 .859 r
.40921 .87909 m .41065 .88021 L .40755 .88013 L F
.753 .767 .864 r
.41292 .87908 m .41065 .88021 L .40921 .87909 L F
.606 .448 .641 r
.42178 .84635 m .41974 .84873 L .41966 .84658 L F
.73 .594 .703 r
.62563 .76002 m .629 .76256 L .62883 .76044 L F
.62563 .76002 m .62683 .76309 L .629 .76256 L F
.689 .567 .713 r
.629 .76256 m .631 .75995 L .62883 .76044 L F
.629 .76256 m .63213 .76321 L .631 .75995 L F
.664 .505 .659 r
.49392 .81199 m .49449 .81604 L .49115 .81492 L F
.597 .458 .662 r
.49615 .81475 m .49392 .81199 L .49669 .81239 L F
.49615 .81475 m .49449 .81604 L .49392 .81199 L F
.535 0 0 r
.47567 .88241 m .47859 .8832 L .47824 .88372 L F
.498 0 0 r
.47859 .8832 m .47973 .88425 L .47824 .88372 L F
.47859 .8832 m .48121 .88445 L .47973 .88425 L F
.387 .717 .988 r
.56743 .79606 m .56568 .79401 L .56847 .79497 L F
0 0 0 r
.5694 .79508 m .56847 .79497 L .57072 .79437 L F
.77 .645 .724 r
.62456 .75709 m .62563 .76002 L .62741 .75751 L F
.718 .57 .687 r
.62563 .76002 m .62883 .76044 L .62741 .75751 L F
.701 .563 .696 r
.62741 .75751 m .62883 .76044 L .631 .75995 L F
.718 .641 .771 r
.54127 .83545 m .54303 .84048 L .53915 .83786 L F
.118 .255 .731 r
.54138 .84031 m .54146 .83942 L .54303 .84048 L F
.391 .445 .796 r
.54409 .83796 m .54303 .84048 L .54127 .83545 L F
.85 .98 .866 r
.54138 .84031 m .54303 .84048 L .54409 .83796 L F
.004 0 0 r
.54133 .8409 m .54138 .84031 L .54366 .83871 L F
.54015 .84201 m .54138 .84031 L .54133 .8409 L F
.118 .255 .731 r
.54138 .84031 m .53915 .83786 L .54146 .83942 L F
.64 .501 .677 r
.41974 .84873 m .41763 .85129 L .4176 .84915 L F
.848 .603 .061 r
.56264 .81726 m .56256 .81887 L .56168 .81656 L F
.56264 .81726 m .56298 .81995 L .56256 .81887 L F
.651 .705 .886 r
.5822 .80736 m .5794 .80861 L .57822 .80659 L F
.453 .85 .975 r
.6735 .74929 m .67262 .75013 L .67241 .7493 L F
.6735 .74929 m .67475 .74963 L .67262 .75013 L F
.611 .761 .95 r
.44675 .87436 m .4447 .87495 L .44346 .87383 L F
.766 .567 .628 r
.52276 .81213 m .52439 .81654 L .52601 .81233 L F
0 0 0 r
.52601 .81233 m .52831 .80992 L .52706 .81067 L F
.52601 .81233 m .52705 .8115 L .52831 .80992 L F
.622 .556 .759 r
.50071 .83313 m .50137 .83362 L .50186 .83385 L F
.50137 .83362 m .50477 .83613 L .50186 .83385 L F
.732 .713 .833 r
.50186 .83385 m .50634 .8357 L .50468 .8336 L F
.731 .758 .874 r
.50468 .8336 m .50478 .83373 L .50791 .83286 L F
.50478 .83373 m .50634 .8357 L .50753 .83355 L F
.50478 .83373 m .50753 .83355 L .50791 .83286 L F
.67 .709 .876 r
.502 .83392 m .50547 .83371 L .50223 .83403 L F
.50186 .83385 m .50468 .83374 L .502 .83392 L F
.50468 .83374 m .50547 .83371 L .502 .83392 L F
.50186 .83385 m .50223 .83403 L .50132 .83412 L F
0 0 0 r
.50186 .83385 m .49931 .83456 L .50071 .83313 L F
.641 .56 .748 r
.40592 .85927 m .40292 .85683 L .40749 .85725 L F
0 0 .465 r
.56341 .82979 m .56319 .83032 L .5644 .83283 L F
.684 .91 .973 r
.59848 .7673 m .5957 .76742 L .59705 .76781 L F
.59848 .7673 m .59705 .76781 L .59769 .76745 L F
.59848 .7673 m .59769 .76745 L .59975 .76631 L F
.465 .035 .138 r
.59848 .7673 m .59822 .76752 L .59769 .76745 L F
.734 .714 .832 r
.59705 .76781 m .59777 .76779 L .59769 .76745 L F
.59777 .76779 m .59996 .76772 L .59834 .76753 L F
.59777 .76779 m .59834 .76753 L .59769 .76745 L F
.59824 .76751 m .60009 .76772 L .59997 .76724 L F
.553 .307 .497 r
.59947 .76702 m .59846 .76748 L .59848 .7673 L F
.465 .035 .138 r
.59848 .7673 m .59846 .76748 L .59822 .76752 L F
.309 .127 .464 r
.60108 .7652 m .60088 .76551 L .59848 .7673 L F
.60114 .76532 m .60006 .76659 L .59848 .7673 L F
.835 .978 .88 r
.59975 .76631 m .60059 .76597 L .60108 .7652 L F
.60059 .76597 m .60216 .76534 L .60108 .7652 L F
.309 .127 .464 r
.60108 .7652 m .60114 .76532 L .60088 .76551 L F
.835 .978 .88 r
.60122 .76571 m .60009 .76772 L .60216 .76534 L F
.60059 .76597 m .60048 .76633 L .60122 .76571 L F
.60048 .76633 m .60009 .76772 L .60122 .76571 L F
.59987 .76681 m .59988 .76684 L .60059 .76597 L F
.59988 .76684 m .60009 .76772 L .60048 .76633 L F
.59988 .76684 m .60048 .76633 L .60059 .76597 L F
.309 .127 .464 r
.60146 .76595 m .59947 .76702 L .59848 .7673 L F
.734 .714 .832 r
.59869 .76744 m .59987 .76681 L .59975 .76631 L F
.553 .307 .497 r
.59976 .76694 m .59846 .76748 L .59947 .76702 L F
.60169 .76641 m .59955 .76712 L .59976 .76694 L F
.734 .714 .832 r
.59869 .76744 m .59997 .76724 L .59987 .76681 L F
.553 .307 .497 r
.59955 .76712 m .59846 .76748 L .59976 .76694 L F
.734 .714 .832 r
.59996 .76772 m .60009 .76772 L .59769 .76745 L F
.59705 .76781 m .59802 .76828 L .60009 .76772 L F
.553 .307 .497 r
.60169 .76641 m .59821 .76941 L .59838 .7681 L F
.59955 .76712 m .59838 .7681 L .59846 .76748 L F
.60169 .76641 m .59838 .7681 L .59955 .76712 L F
.309 .127 .464 r
.60114 .76532 m .60146 .76595 L .60006 .76659 L F
.835 .978 .88 r
.59975 .76631 m .59987 .76681 L .60059 .76597 L F
.734 .714 .832 r
.59824 .76751 m .59869 .76744 L .59975 .76631 L F
.309 .127 .464 r
.60146 .76595 m .60169 .76641 L .59947 .76702 L F
.797 .675 .73 r
.59482 .76793 m .59802 .76828 L .59705 .76781 L F
.465 .035 .138 r
.59822 .76752 m .59821 .76941 L .59592 .76946 L F
.59846 .76748 m .59821 .76941 L .59822 .76752 L F
.734 .714 .832 r
.59769 .76745 m .59824 .76751 L .59975 .76631 L F
.465 .035 .138 r
.59769 .76745 m .59592 .76946 L .59575 .76782 L F
.59822 .76752 m .59592 .76946 L .59769 .76745 L F
.582 .886 .991 r
.5957 .76742 m .59482 .76793 L .59705 .76781 L F
.465 .035 .138 r
.59848 .7673 m .59575 .76782 L .5957 .76742 L F
.586 .608 .841 r
.38633 .74455 m .38296 .74221 L .38495 .74207 L F
.651 .66 .845 r
.3887 .7441 m .38633 .74455 L .38495 .74207 L F
.671 .543 .7 r
.60271 .8044 m .60079 .80712 L .60058 .80476 L F
.894 .955 .833 r
.54806 .85547 m .54584 .85712 L .54701 .85499 L F
.54584 .85712 m .54806 .85547 L .54814 .85635 L F
.806 .317 0 r
.54814 .85635 m .54806 .85547 L .54701 .85499 L F
.544 .34 .553 r
.5018 .83825 m .50389 .83806 L .50477 .83613 L F
.592 .392 .58 r
.40806 .85891 m .40592 .85927 L .40749 .85725 L F
.159 0 .121 r
.59236 .83267 m .59068 .83375 L .58989 .83486 L F
.668 .583 .751 r
.51392 .84564 m .51465 .84857 L .51695 .84631 L F
.668 .415 .529 r
.37578 .83322 m .37781 .83516 L .37784 .83309 L F
.37578 .83322 m .37575 .83562 L .37781 .83516 L F
.714 .259 0 r
.55511 .80652 m .55569 .80699 L .55695 .80905 L F
.038 .267 .764 r
.55841 .81174 m .55695 .80905 L .558 .80971 L F
.552 .182 .294 r
.48963 .81191 m .49209 .8121 L .49298 .81007 L F
.216 0 .138 r
.49298 .81007 m .49373 .81131 L .49496 .8094 L F
.49298 .81007 m .49209 .8121 L .49373 .81131 L F
.573 .359 .552 r
.60649 .78377 m .60884 .78337 L .60868 .78099 L F
.53 .358 .593 r
.60868 .78099 m .61094 .78077 L .61082 .77832 L F
.681 .44 .551 r
.60868 .78099 m .61098 .7832 L .61094 .78077 L F
.60868 .78099 m .60884 .78337 L .61098 .7832 L F
.623 .58 .785 r
.40649 .82674 m .40456 .82801 L .40352 .82497 L F
.809 .93 .913 r
.61869 .74144 m .62022 .73877 L .62125 .73954 L F
.61869 .74144 m .61765 .74089 L .62022 .73877 L F
.391 .445 .796 r
.54409 .83796 m .54127 .83545 L .54524 .8347 L F
.609 .313 .443 r
.54409 .83796 m .54524 .8347 L .546 .8359 L F
.417 .18 .445 r
.53077 .87197 m .53294 .86954 L .53196 .87138 L F
0 0 0 r
.53047 .87257 m .53077 .87197 L .53196 .87138 L F
.675 .563 .72 r
.39107 .86953 m .38911 .86966 L .39112 .86695 L F
.653 .427 .564 r
.39117 .87164 m .38911 .86966 L .39107 .86953 L F
.39117 .87164 m .38898 .87192 L .38911 .86966 L F
.349 0 .154 r
.57784 .76758 m .57986 .7671 L .58079 .7652 L F
.296 0 .267 r
.58079 .7652 m .58249 .76432 L .58337 .76321 L F
.104 0 .037 r
.58079 .7652 m .58229 .76508 L .58249 .76432 L F
.58079 .7652 m .57986 .7671 L .58229 .76508 L F
.682 .566 .718 r
.49412 .81678 m .49115 .81492 L .49449 .81604 L F
.49412 .81678 m .49263 .81762 L .49115 .81492 L F
.396 0 0 r
.42923 .84339 m .4256 .84346 L .42711 .84323 L F
.664 .923 .975 r
.42331 .89271 m .42529 .89138 L .4232 .89262 L F
.653 .791 .948 r
.41807 .89293 m .42169 .89343 L .42018 .89293 L F
.628 .898 .986 r
.42018 .89293 m .42169 .89343 L .4232 .89262 L F
.683 .141 0 r
.5934 .82273 m .5958 .82464 L .59409 .82411 L F
.5934 .82273 m .59409 .82411 L .59445 .82182 L F
.14 0 0 r
.50863 .87401 m .51185 .87461 L .50975 .87421 L F
.55 .239 .393 r
.37437 .77676 m .37385 .77806 L .37169 .77824 L F
.555 .288 .466 r
.37647 .77627 m .37385 .77806 L .37437 .77676 L F
.409 0 .093 r
.66564 .7185 m .66469 .72006 L .66242 .72046 L F
.275 .777 .864 r
.66768 .71792 m .66564 .7185 L .66345 .71663 L F
.66768 .71792 m .66781 .71812 L .66564 .7185 L F
.086 0 0 r
.66745 .71867 m .66564 .7185 L .66781 .71812 L F
.66745 .71867 m .66469 .72006 L .66564 .7185 L F
.52 .264 .468 r
.44203 .83863 m .44151 .84046 L .43966 .8405 L F
.546 .29 .478 r
.44415 .83973 m .44151 .84046 L .44203 .83863 L F
.582 .226 .33 r
.44509 .83813 m .44415 .83973 L .44203 .83863 L F
.824 .397 .227 r
.57822 .80659 m .57717 .80485 L .57494 .80395 L F
.643 .495 .667 r
.37104 .83816 m .37351 .83608 L .37093 .83575 L F
.168 .672 .907 r
.49395 .81931 m .49186 .81928 L .49263 .81762 L F
.741 .729 .84 r
.59187 .76832 m .59282 .77064 L .59482 .76793 L F
.696 .329 .348 r
.53343 .81426 m .53061 .81426 L .53132 .81224 L F
.706 .655 .797 r
.60776 .77598 m .60903 .77241 L .60682 .77291 L F
.60776 .77598 m .61019 .77508 L .60903 .77241 L F
.569 .728 .949 r
.34839 .72764 m .34972 .72903 L .34768 .72934 L F
0 0 .089 r
.53294 .86954 m .53441 .86648 L .53448 .86934 L F
.127 0 .055 r
.53196 .87138 m .53294 .86954 L .53448 .86934 L F
.749 .722 .827 r
.63827 .73177 m .63915 .73411 L .63598 .7338 L F
.755 .725 .825 r
.64143 .73199 m .63915 .73411 L .63827 .73177 L F
.339 .814 .897 r
.44684 .88739 m .45015 .88698 L .44901 .88691 L F
0 0 0 r
.45015 .88698 m .45096 .88681 L .44901 .88691 L F
.217 0 0 r
.60031 .75337 m .60118 .75396 L .60218 .75235 L F
.60031 .75337 m .59908 .75444 L .60118 .75396 L F
.121 0 0 r
.36213 .74849 m .35823 .74847 L .36028 .74904 L F
.565 .394 .609 r
.35885 .76965 m .36127 .76811 L .36098 .76539 L F
.932 .935 .58 r
.52831 .80992 m .52705 .8115 L .52826 .80839 L F
0 .409 .816 r
.48121 .88445 m .48219 .88522 L .48374 .88584 L F
.599 .447 .647 r
.60271 .8044 m .60249 .80635 L .60079 .80712 L F
.695 .566 .705 r
.60249 .80635 m .6002 .80896 L .60079 .80712 L F
.59 .44 .647 r
.57013 .84087 m .57235 .84111 L .57222 .8384 L F
0 0 0 r
.57072 .84038 m .57038 .84058 L .57222 .8384 L F
.57072 .84038 m .57222 .8384 L .56904 .83804 L F
.188 0 0 r
.57104 .84019 m .57072 .84038 L .57028 .8394 L F
.542 .403 .642 r
.57222 .8384 m .57235 .84111 L .57484 .83985 L F
.53 .832 .999 r
.57318 .83999 m .57235 .84111 L .57072 .84038 L F
.188 0 0 r
.57171 .84089 m .57318 .83999 L .57072 .84038 L F
.57171 .84089 m .57072 .84038 L .57104 .84019 L F
0 0 0 r
.57072 .84038 m .57013 .84087 L .57038 .84058 L F
.21 .673 .944 r
.57072 .84038 m .57235 .84111 L .57013 .84087 L F
.511 .224 .415 r
.62475 .77042 m .62768 .76764 L .62478 .76789 L F
.62475 .77042 m .62703 .77006 L .62768 .76764 L F
.662 .385 .49 r
.62703 .77006 m .63001 .76781 L .62768 .76764 L F
.672 .868 .973 r
.36346 .74836 m .36354 .74995 L .36588 .7482 L F
.628 .654 .856 r
.38078 .7338 m .37862 .73419 L .37734 .73194 L F
.914 .631 .492 r
.37731 .73584 m .37927 .73661 L .37862 .73419 L F
.601 .452 .651 r
.38078 .7338 m .37927 .73661 L .37862 .73419 L F
.37 0 .084 r
.38078 .7338 m .37731 .73584 L .37862 .73419 L F
.437 .839 .64 r
.49539 .87548 m .4936 .8767 L .49272 .8772 L F
.656 .474 .626 r
.51002 .82561 m .51035 .82849 L .50688 .82808 L F
.59 .426 .628 r
.51246 .82718 m .51002 .82561 L .51205 .82526 L F
.51246 .82718 m .51035 .82849 L .51002 .82561 L F
.535 .151 .259 r
.44737 .83814 m .44415 .83973 L .44509 .83813 L F
.599 .546 .767 r
.53456 .83042 m .53589 .83327 L .538 .83202 L F
.753 .767 .864 r
.41292 .87908 m .40921 .87909 L .41151 .87747 L F
.655 .773 .936 r
.41422 .87776 m .41292 .87908 L .41151 .87747 L F
.594 .649 .874 r
.41589 .88018 m .41292 .87908 L .41422 .87776 L F
0 0 0 r
.59009 .75949 m .59147 .75917 L .5926 .75762 L F
.59009 .75949 m .58943 .75972 L .59147 .75917 L F
.388 .711 .986 r
.35363 .72802 m .35298 .72898 L .35167 .72855 L F
.35363 .72802 m .35484 .72902 L .35298 .72898 L F
.691 .85 .959 r
.55665 .79369 m .55481 .79461 L .55357 .79367 L F
.849 .494 .38 r
.59664 .82531 m .59773 .82645 L .59617 .82745 L F
.986 .71 .367 r
.5958 .82464 m .59664 .82531 L .59617 .82745 L F
.048 0 .201 r
.59664 .82531 m .59848 .8229 L .59924 .82517 L F
.292 .433 .832 r
.59895 .82709 m .59664 .82531 L .59924 .82517 L F
.723 .805 .915 r
.42097 .87954 m .4179 .87965 L .41997 .87867 L F
.705 .832 .943 r
.42207 .87752 m .42097 .87954 L .41997 .87867 L F
.42207 .87752 m .42274 .87858 L .42097 .87954 L F
.641 .404 .543 r
.48732 .87207 m .49155 .87017 L .48933 .87263 L F
.542 .422 .665 r
.49417 .87179 m .49171 .87314 L .49184 .87148 L F
.49384 .87142 m .49184 .87148 L .492 .86942 L F
.49417 .87179 m .49184 .87148 L .49384 .87142 L F
0 0 0 r
.49221 .87317 m .49171 .87314 L .49417 .87179 L F
0 0 .381 r
.49184 .87148 m .49171 .87314 L .49221 .87317 L F
.4917 .87149 m .49221 .87317 L .49188 .87311 L F
.49155 .87017 m .49171 .87314 L .49184 .87148 L F
.49155 .87017 m .49184 .87148 L .4917 .87149 L F
.49184 .87148 m .49221 .87317 L .4917 .87149 L F
.542 .422 .665 r
.492 .86942 m .49171 .87314 L .49168 .86907 L F
.208 .307 .746 r
.49155 .87017 m .4917 .87149 L .49171 .87314 L F
0 0 .381 r
.49155 .87017 m .49188 .87311 L .48933 .87263 L F
.208 .307 .746 r
.49155 .87017 m .49168 .86907 L .4917 .87149 L F
0 .46 .779 r
.56325 .79866 m .56515 .7992 L .56619 .79969 L F
.18 0 0 r
.56755 .80017 m .56619 .79969 L .56515 .7992 L F
.507 .142 .281 r
.46728 .82235 m .46957 .82233 L .47061 .82012 L F
.367 .006 .212 r
.47061 .82012 m .47143 .82178 L .4727 .81989 L F
.47061 .82012 m .46957 .82233 L .47143 .82178 L F
.574 .363 .557 r
.66371 .74744 m .66566 .74724 L .66584 .74445 L F
.646 .469 .63 r
.66566 .74724 m .66809 .74409 L .66584 .74445 L F
.386 .029 .231 r
.37313 .76456 m .37591 .76268 L .37402 .76305 L F
.046 0 0 r
.64831 .76964 m .64943 .76824 L .65137 .76736 L F
.714 .717 .851 r
.63282 .73354 m .63352 .73608 L .63035 .73568 L F
.752 .628 .723 r
.63352 .73608 m .632 .73724 L .63035 .73568 L F
.748 .736 .842 r
.63598 .7338 m .63352 .73608 L .63282 .73354 L F
.319 .026 .3 r
.63718 .77516 m .63659 .77754 L .63479 .7783 L F
.349 .051 .311 r
.6391 .77533 m .63659 .77754 L .63718 .77516 L F
.676 .56 .716 r
.631 .75995 m .63213 .76321 L .63415 .7625 L F
.574 .264 .405 r
.52614 .83007 m .52965 .82799 L .52939 .83003 L F
.528 .087 .145 r
.43966 .8405 m .43899 .84187 L .43669 .84107 L F
.567 .183 .273 r
.44151 .84046 m .43899 .84187 L .43966 .8405 L F
.919 .604 .43 r
.56092 .78653 m .55972 .78785 L .55923 .78575 L F
.182 .049 .452 r
.56092 .78653 m .56252 .78778 L .55972 .78785 L F
.726 .591 .705 r
.62355 .76268 m .62683 .76309 L .62563 .76002 L F
.782 .666 .735 r
.62349 .76491 m .62683 .76309 L .62355 .76268 L F
.523 .277 .484 r
.38092 .77278 m .37832 .77583 L .3789 .77309 L F
.981 .687 .345 r
.55361 .84102 m .55345 .83822 L .5552 .83788 L F
.636 .672 .867 r
.4179 .87965 m .41589 .88018 L .41422 .87776 L F
.396 0 .147 r
.47971 .86178 m .47692 .86324 L .47867 .86305 L F
.941 .658 .474 r
.47867 .86305 m .48005 .86436 L .47971 .86178 L F
.982 .744 .5 r
.63957 .76251 m .63964 .76522 L .6403 .76464 L F
.473 .066 .186 r
.63964 .76522 m .6424 .76426 L .6403 .76464 L F
.434 .039 .188 r
.52608 .84144 m .5241 .84146 L .52342 .84274 L F
.54 .434 .683 r
.6757 .74448 m .67454 .74712 L .67358 .74373 L F
.6757 .74448 m .6766 .74675 L .67454 .74712 L F
.471 .122 .292 r
.6766 .74675 m .6735 .74929 L .67454 .74712 L F
.292 0 0 r
.5733 .8493 m .57449 .84914 L .57598 .84958 L F
0 .28 .72 r
.48374 .88584 m .48601 .88744 L .48729 .88815 L F
.648 .392 .517 r
.37781 .83516 m .38111 .83263 L .37784 .83309 L F
.61 .59 .806 r
.38296 .74221 m .37958 .73968 L .38214 .74063 L F
.319 .505 .883 r
.38378 .74102 m .38296 .74221 L .38214 .74063 L F
.478 .724 .979 r
.38378 .74102 m .38495 .74207 L .38296 .74221 L F
.475 .851 .985 r
.53364 .82287 m .53045 .82292 L .53249 .82226 L F
.765 .907 .938 r
.53628 .82151 m .53364 .82287 L .53249 .82226 L F
0 0 .301 r
.57283 .8172 m .57277 .8174 L .57197 .81448 L F
.67 .773 .297 r
.572 .81912 m .57277 .8174 L .57283 .8172 L F
.693 .578 .722 r
.41974 .84873 m .42071 .85157 L .41763 .85129 L F
.335 .089 .385 r
.50842 .85652 m .50618 .85946 L .50826 .85938 L F
.567 .382 .59 r
.50963 .85697 m .50842 .85652 L .50826 .85938 L F
.50963 .85697 m .51054 .85628 L .50842 .85652 L F
.451 0 0 r
.57648 .82703 m .57514 .82612 L .57433 .82478 L F
.533 .493 .757 r
.57677 .82648 m .57596 .82778 L .57514 .82612 L F
.451 0 0 r
.57648 .82703 m .57677 .82648 L .57514 .82612 L F
.094 0 .439 r
.60482 .82721 m .60483 .82977 L .6034 .83059 L F
.038 0 .321 r
.6034 .83059 m .6044 .83194 L .60274 .83263 L F
.6034 .83059 m .60483 .82977 L .6044 .83194 L F
.744 .725 .834 r
.66613 .74915 m .66798 .75119 L .6693 .74946 L F
.537 .367 .598 r
.66734 .7525 m .6693 .74946 L .66798 .75119 L F
.648 .392 .517 r
.37781 .83516 m .38084 .83555 L .38111 .83263 L F
.618 .373 .525 r
.38084 .83555 m .38323 .83296 L .38111 .83263 L F
.498 .532 .822 r
.38082 .73775 m .37958 .73968 L .37855 .73873 L F
.38082 .73775 m .38214 .74063 L .37958 .73968 L F
.677 .733 .225 r
.64961 .73363 m .64888 .73583 L .64877 .73619 L F
.395 .02 .204 r
.65107 .73523 m .64961 .73363 L .65124 .73284 L F
.65107 .73523 m .64888 .73583 L .64961 .73363 L F
.461 .166 .377 r
.63235 .7677 m .6345 .7673 L .63492 .76494 L F
.552 .339 .545 r
.63492 .76494 m .63772 .76236 L .63415 .7625 L F
.63492 .76494 m .63759 .76435 L .63772 .76236 L F
.348 0 .078 r
.63619 .76603 m .63492 .76494 L .6345 .7673 L F
.63619 .76603 m .63759 .76435 L .63492 .76494 L F
.573 .735 .952 r
.3721 .73311 m .37028 .73352 L .36837 .73228 L F
0 .47 .779 r
.40649 .82674 m .40856 .82731 L .40984 .82781 L F
.222 .666 .953 r
.41056 .82729 m .40984 .82781 L .40856 .82731 L F
.41056 .82729 m .41206 .82811 L .40984 .82781 L F
.597 .639 .863 r
.3763 .74946 m .37669 .75046 L .37858 .75 L F
.784 .741 .813 r
.64273 .73947 m .64056 .74174 L .64355 .74192 L F
.743 .719 .83 r
.64273 .73947 m .64355 .74192 L .64551 .74095 L F
.525 .388 .637 r
.38691 .87456 m .38682 .87636 L .38533 .87685 L F
.635 .554 .746 r
.38815 .87918 m .38533 .87685 L .38682 .87636 L F
.76 .648 .737 r
.53915 .83786 m .54027 .84091 L .53702 .8406 L F
.406 0 0 r
.53702 .8406 m .54027 .84091 L .53949 .84117 L F
.118 .255 .731 r
.54138 .84031 m .54027 .84091 L .53915 .83786 L F
.354 .816 .72 r
.53949 .84117 m .54027 .84091 L .54138 .84031 L F
.698 .478 .585 r
.40213 .86406 m .40237 .86655 L .39846 .86663 L F
.724 .526 .622 r
.40392 .86423 m .40237 .86655 L .40213 .86406 L F
.734 .627 .74 r
.62253 .75986 m .62563 .76002 L .62456 .75709 L F
.736 .607 .713 r
.62253 .75986 m .62355 .76268 L .62563 .76002 L F
.528 .29 .498 r
.39493 .76235 m .39276 .76372 L .39288 .76263 L F
.772 .765 .847 r
.62658 .73756 m .623 .73839 L .62546 .73643 L F
.712 .8 .92 r
.62855 .73659 m .62658 .73756 L .62546 .73643 L F
.174 .059 .472 r
.57609 .83024 m .57596 .82778 L .57677 .82648 L F
.84 .843 .847 r
.5712 .8092 m .5741 .80806 L .5733 .80712 L F
.694 .83 .948 r
.5741 .80806 m .57615 .8072 L .5733 .80712 L F
.497 .303 .547 r
.61278 .79931 m .61493 .79669 L .61474 .79887 L F
.477 .293 .551 r
.6128 .80151 m .61278 .79931 L .61474 .79887 L F
.711 .515 .622 r
.40708 .86653 m .40392 .86423 L .4069 .86401 L F
.621 .539 .74 r
.40794 .86111 m .4069 .86401 L .40599 .86166 L F
.40794 .86111 m .40914 .86419 L .4069 .86401 L F
.654 .482 .639 r
.40914 .86419 m .40708 .86653 L .4069 .86401 L F
.707 .758 .892 r
.46077 .87323 m .45706 .87355 L .45958 .87211 L F
.699 .789 .921 r
.45958 .87211 m .46264 .87237 L .46077 .87323 L F
.624 .654 .859 r
.39336 .87947 m .39136 .88003 L .39001 .8778 L F
.753 .426 .431 r
.49632 .83303 m .49427 .83532 L .4932 .83393 L F
.49632 .83303 m .49781 .83669 L .49427 .83532 L F
.766 .807 .885 r
.49615 .81475 m .49412 .81678 L .49449 .81604 L F
0 0 .054 r
.49449 .81604 m .49491 .81616 L .49412 .81678 L F
0 0 0 r
.65239 .75691 m .65146 .75938 L .65139 .75591 L F
.48 .162 .349 r
.63258 .77872 m .63209 .78025 L .63005 .78068 L F
.454 .138 .339 r
.63479 .7783 m .63209 .78025 L .63258 .77872 L F
.618 .435 .612 r
.63772 .76236 m .63957 .76251 L .64034 .76156 L F
.686 .499 .628 r
.63759 .76435 m .63957 .76251 L .63772 .76236 L F
.583 .901 .984 r
.39666 .89768 m .39783 .89804 L .39895 .89756 L F
.354 0 .007 r
.51514 .87966 m .51843 .87806 L .51718 .87934 L F
.492 .027 .078 r
.51718 .87934 m .51843 .87806 L .52006 .8788 L F
.727 .58 .689 r
.59198 .80684 m .59513 .80688 L .59477 .80431 L F
.591 .519 .743 r
.59477 .80431 m .59628 .80152 L .59412 .80186 L F
.59477 .80431 m .59664 .8044 L .59628 .80152 L F
.546 .451 .698 r
.59477 .80431 m .59714 .80665 L .59664 .8044 L F
.59477 .80431 m .59513 .80688 L .59714 .80665 L F
.798 .991 .746 r
.59617 .82745 m .59773 .82645 L .5942 .8302 L F
.744 .631 .734 r
.51695 .84631 m .51997 .84661 L .51897 .84367 L F
.662 .586 .759 r
.51897 .84367 m .51997 .84661 L .52211 .84607 L F
.987 .79 .554 r
.56377 .7781 m .56254 .77758 L .56394 .77552 L F
.111 0 0 r
.56394 .77552 m .56524 .77565 L .56557 .775 L F
.56394 .77552 m .56254 .77758 L .56524 .77565 L F
.765 .907 .938 r
.53628 .82151 m .53249 .82226 L .53466 .82093 L F
.822 .941 .905 r
.53824 .81992 m .53628 .82151 L .53466 .82093 L F
.535 .351 .579 r
.65751 .75646 m .65906 .7542 L .65679 .75458 L F
.718 .612 .738 r
.42178 .84635 m .42332 .849 L .41974 .84873 L F
.675 .568 .727 r
.4227 .85092 m .41974 .84873 L .42332 .849 L F
.694 .653 .805 r
.42383 .84589 m .42332 .849 L .42178 .84635 L F
.42383 .84589 m .42541 .84899 L .42332 .849 L F
.533 .256 .441 r
.42541 .84899 m .4227 .85092 L .42332 .849 L F
.847 .684 .681 r
.49756 .81223 m .49615 .81475 L .49669 .81239 L F
.788 .541 .565 r
.60271 .8044 m .606 .80703 L .60249 .80635 L F
.686 .572 .721 r
.39418 .869 m .39107 .86953 L .39112 .86695 L F
.626 .389 .539 r
.39418 .869 m .39117 .87164 L .39107 .86953 L F
.738 .611 .716 r
.49186 .81928 m .48981 .82251 L .49353 .82234 L F
.706 .434 .509 r
.48981 .82251 m .48954 .82602 L .49353 .82234 L F
0 0 0 r
.49353 .82234 m .4943 .82235 L .49527 .82277 L F
.49353 .82234 m .48954 .82602 L .4943 .82235 L F
.773 .796 .871 r
.37546 .7325 m .3721 .73311 L .37408 .7332 L F
.866 .996 .78 r
.37546 .7325 m .37617 .73056 L .37734 .73194 L F
.37546 .7325 m .37408 .7332 L .37617 .73056 L F
.605 .438 .63 r
.40806 .85891 m .40599 .86166 L .40592 .85927 L F
.468 .141 .329 r
.386 .76846 m .38535 .76997 L .38332 .77027 L F
.57 .307 .478 r
.38791 .76789 m .38535 .76997 L .386 .76846 L F
.59 .403 .597 r
.54769 .83836 m .54778 .84078 L .5456 .84087 L F
.54769 .83836 m .54778 .84078 L .5456 .84087 L F
.57 .685 .918 r
.54769 .83836 m .54878 .83667 L .546 .8359 L F
.54769 .83836 m .54954 .83889 L .54878 .83667 L F
.752 .511 .568 r
.54769 .83836 m .55117 .84058 L .54778 .84078 L F
.511 .013 .009 r
.54968 .84094 m .55117 .84058 L .55071 .84103 L F
.54778 .84078 m .54947 .84068 L .54968 .84094 L F
.54947 .84068 m .55117 .84058 L .54968 .84094 L F
.54778 .84078 m .55071 .84103 L .54977 .84113 L F
.003 0 .418 r
.55113 .8366 m .54954 .83889 L .54983 .84112 L F
.54987 .84117 m .54983 .84112 L .54985 .84124 L F
.55113 .8366 m .54983 .84112 L .54987 .84117 L F
.731 .43 .469 r
.54977 .84113 m .54954 .83889 L .54769 .83836 L F
.54985 .84124 m .54983 .84112 L .54977 .84113 L F
.54983 .84112 m .54954 .83889 L .54977 .84113 L F
.511 .013 .009 r
.54977 .84113 m .55071 .84103 L .55047 .84125 L F
.731 .43 .469 r
.54985 .84124 m .54977 .84113 L .54778 .84078 L F
.509 0 0 r
.54778 .84078 m .54985 .84124 L .54987 .84183 L F
.546 .67 .918 r
.54878 .83667 m .54954 .83889 L .55113 .8366 L F
.17 .697 .862 r
.54878 .83667 m .55113 .8366 L .54961 .83633 L F
.049 .216 .715 r
.55063 .83795 m .55041 .8389 L .54961 .83633 L F
.003 0 .418 r
.55113 .8366 m .55005 .8405 L .55041 .8389 L F
.493 .237 .454 r
.55229 .8406 m .55113 .8366 L .55041 .8389 L F
.049 .216 .715 r
.55229 .8406 m .55041 .8389 L .55063 .83795 L F
.003 0 .418 r
.55005 .8405 m .54987 .84117 L .55041 .8389 L F
.54987 .84117 m .54985 .84124 L .54986 .84118 L F
.54987 .84117 m .54986 .84118 L .55041 .8389 L F
.511 .013 .009 r
.54965 .84173 m .55047 .84125 L .54987 .84183 L F
.54778 .84078 m .54987 .84115 L .54965 .84173 L F
.54987 .84115 m .55047 .84125 L .54965 .84173 L F
.731 .43 .469 r
.54977 .84113 m .54769 .83836 L .54778 .84078 L F
.764 .584 .655 r
.5968 .81499 m .59766 .81762 L .59464 .81674 L F
.7 .606 .747 r
.59949 .81512 m .59766 .81762 L .5968 .81499 L F
.74 .504 .573 r
.60249 .80635 m .606 .80703 L .60609 .80929 L F
.632 .354 .478 r
.606 .80703 m .60828 .809 L .60609 .80929 L F
.606 .80703 m .60826 .8072 L .60828 .809 L F
.586 .853 .994 r
.67454 .7255 m .67536 .72623 L .67274 .72556 L F
.912 .967 .798 r
.67265 .72762 m .67149 .72805 L .67216 .72708 L F
.888 .602 .497 r
.67274 .72556 m .6744 .72598 L .67355 .7264 L F
.67274 .72556 m .67566 .72856 L .67265 .72762 L F
.565 .855 .997 r
.6737 .72482 m .67454 .7255 L .67274 .72556 L F
.912 .967 .798 r
.67265 .72762 m .6737 .72482 L .67274 .72556 L F
.67301 .72666 m .67216 .72708 L .6737 .72482 L F
.67265 .72762 m .67216 .72708 L .67301 .72666 L F
.888 .602 .497 r
.67355 .7264 m .67536 .72623 L .67566 .72856 L F
.6744 .72598 m .67536 .72623 L .67355 .7264 L F
.975 .674 .302 r
.67566 .72856 m .67536 .72623 L .67454 .7255 L F
.598 .941 .772 r
.6098 .74768 m .61088 .74655 L .61127 .74635 L F
.6098 .74768 m .60809 .74846 L .61088 .74655 L F
.481 .037 .116 r
.35456 .75002 m .35084 .75144 L .3522 .75076 L F
.131 .265 .736 r
.53683 .81452 m .53781 .81744 L .53877 .81651 L F
0 0 0 r
.53781 .81744 m .53644 .81904 L .53877 .81651 L F
.04 0 .435 r
.47692 .86324 m .47616 .86625 L .47702 .86629 L F
.533 .256 .441 r
.42541 .84899 m .42492 .85091 L .4227 .85092 L F
.547 .581 .841 r
.42703 .84832 m .42541 .84899 L .42383 .84589 L F
.559 .28 .45 r
.42701 .85067 m .42541 .84899 L .42703 .84832 L F
.42701 .85067 m .42492 .85091 L .42541 .84899 L F
.117 0 0 r
.5799 .84916 m .58067 .84943 L .57817 .84974 L F
.5799 .84916 m .58225 .84926 L .58067 .84943 L F
.494 .842 .996 r
.4127 .89439 m .4158 .89455 L .41501 .894 L F
.767 .917 .938 r
.41501 .894 m .4158 .89455 L .41807 .89293 L F
.677 .202 .118 r
.49125 .8401 m .48995 .84067 L .48814 .83976 L F
.532 .534 .802 r
.37858 .75 m .3796 .75299 L .38143 .7514 L F
.585 .477 .697 r
.3796 .75299 m .38216 .75433 L .38143 .7514 L F
.3796 .75299 m .38006 .75474 L .38216 .75433 L F
.628 .398 .55 r
.41349 .8559 m .41268 .8592 L .41032 .85857 L F
.586 .349 .523 r
.41542 .8562 m .41268 .8592 L .41349 .8559 L F
.638 .238 .27 r
.36805 .76663 m .37028 .76704 L .37169 .76536 L F
.483 .162 .346 r
.37028 .76704 m .37313 .76456 L .37169 .76536 L F
0 0 0 r
.38711 .90068 m .38389 .90201 L .38522 .90198 L F
.071 0 0 r
.42939 .87621 m .43251 .87494 L .43087 .87501 L F
.707 .681 .822 r
.632 .73724 m .62855 .73659 L .63035 .73568 L F
.594 .542 .766 r
.60682 .77291 m .60876 .77059 L .60597 .76999 L F
.60682 .77291 m .60903 .77241 L .60876 .77059 L F
.675 .568 .727 r
.4227 .85092 m .42071 .85157 L .41974 .84873 L F
.743 .719 .83 r
.64273 .73947 m .64551 .74095 L .64454 .73817 L F
.672 .67 .84 r
.64454 .73817 m .64551 .74095 L .6479 .7391 L F
.322 0 .055 r
.50263 .81734 m .50124 .81916 L .49933 .81949 L F
.742 .361 .33 r
.50464 .81946 m .50124 .81916 L .50263 .81734 L F
.492 .539 .833 r
.60903 .77241 m .61019 .77508 L .61205 .77511 L F
.74 .676 .789 r
.66211 .75221 m .66078 .74921 L .66083 .75157 L F
.66211 .75221 m .66411 .74996 L .66078 .74921 L F
.728 .359 .35 r
.66444 .75437 m .66211 .75221 L .66188 .7545 L F
.662 .581 .753 r
.47692 .86324 m .47702 .86629 L .48005 .86436 L F
.775 .772 .85 r
.40208 .87974 m .39889 .87978 L .40108 .87804 L F
.555 .595 .849 r
.40285 .87695 m .40208 .87974 L .40108 .87804 L F
.40285 .87695 m .40402 .87956 L .40208 .87974 L F
.743 .731 .84 r
.67677 .74824 m .67772 .74975 L .67475 .74963 L F
.337 .566 .923 r
.67677 .74824 m .67899 .74942 L .67772 .74975 L F
.843 .738 .748 r
.67941 .74892 m .67772 .74975 L .67899 .74942 L F
.67941 .74892 m .68007 .75162 L .67772 .74975 L F
.5 .399 .672 r
.68007 .75162 m .67822 .75217 L .67772 .74975 L F
.592 .704 .921 r
.67489 .74134 m .67616 .7434 L .67358 .74373 L F
.608 .577 .793 r
.67616 .7434 m .6757 .74448 L .67358 .74373 L F
.532 .65 .91 r
.53456 .83042 m .53728 .83001 L .53527 .82825 L F
.599 .546 .767 r
.53456 .83042 m .538 .83202 L .53728 .83001 L F
.494 .132 .281 r
.48195 .81611 m .48421 .81591 L .48587 .8132 L F
.578 .227 .338 r
.48421 .81591 m .48753 .81388 L .48587 .8132 L F
.644 .592 .781 r
.61082 .77832 m .61309 .77813 L .61205 .77511 L F
.662 .46 .6 r
.61082 .77832 m .61315 .78037 L .61309 .77813 L F
.61082 .77832 m .61094 .78077 L .61315 .78037 L F
.551 .292 .476 r
.4727 .81989 m .47487 .81971 L .47494 .81758 L F
.511 .26 .47 r
.47494 .81758 m .47694 .81931 L .47777 .81682 L F
.47494 .81758 m .47487 .81971 L .47694 .81931 L F
.319 0 0 r
.56652 .84751 m .56985 .84827 L .56809 .84832 L F
.654 .148 .03 r
.56985 .84827 m .5712 .84895 L .56809 .84832 L F
.827 .35 .005 r
.56984 .78975 m .57118 .79205 L .57168 .79169 L F
.811 .369 .192 r
.56911 .7908 m .57118 .79205 L .56984 .78975 L F
.604 .658 .875 r
.57142 .79034 m .57118 .79205 L .56911 .7908 L F
.889 .465 .087 r
.57065 .79244 m .57118 .79205 L .57142 .79034 L F
.57065 .79245 m .57118 .79205 L .57065 .79244 L F
.827 .35 .005 r
.57168 .79169 m .57118 .79205 L .57176 .79177 L F
.88 .446 .092 r
.5716 .79296 m .57176 .79177 L .57118 .79205 L F
.565 .842 .997 r
.40944 .89439 m .41074 .89499 L .4127 .89439 L F
.664 .625 .801 r
.60448 .76475 m .60555 .76782 L .6076 .76541 L F
.657 .615 .795 r
.60555 .76782 m .60849 .7678 L .6076 .76541 L F
.625 .449 .625 r
.60597 .76999 m .60849 .7678 L .60555 .76782 L F
.038 0 0 r
.41206 .82811 m .4141 .82776 L .41511 .82734 L F
.216 .722 .899 r
.41511 .82734 m .41594 .827 L .41718 .82727 L F
0 0 0 r
.41511 .82734 m .4141 .82776 L .41594 .827 L F
.754 .779 .874 r
.52739 .84888 m .52928 .85008 L .53104 .84868 L F
.378 .499 .855 r
.54479 .82983 m .54551 .83209 L .54332 .83044 L F
.492 .533 .826 r
.54645 .83314 m .54332 .83044 L .54551 .83209 L F
.59 .402 .595 r
.5456 .84087 m .54778 .84078 L .54564 .84323 L F
.54564 .84323 m .54778 .84078 L .5456 .84087 L F
.672 .581 .745 r
.51603 .84309 m .51771 .8403 L .51572 .84078 L F
.755 .616 .705 r
.62026 .7624 m .62355 .76268 L .62253 .75986 L F
.735 .548 .639 r
.62046 .76468 m .62355 .76268 L .62026 .7624 L F
.62046 .76468 m .62349 .76491 L .62355 .76268 L F
.715 .469 .552 r
.59519 .80943 m .59513 .80688 L .59198 .80684 L F
.625 .449 .625 r
.59519 .80943 m .59714 .80665 L .59513 .80688 L F
.659 .699 .876 r
.53045 .82292 m .52859 .82374 L .52762 .82248 L F
.684 .495 .625 r
.3581 .77043 m .35893 .7705 L .35885 .76965 L F
.663 .48 .626 r
.35885 .76965 m .36172 .77012 L .36127 .76811 L F
.35885 .76965 m .35893 .7705 L .36172 .77012 L F
.75 .632 .73 r
.48332 .85439 m .48318 .85652 L .48599 .85389 L F
0 0 0 r
.56739 .7914 m .56911 .7908 L .56984 .78975 L F
.307 .8 .846 r
.65686 .76581 m .65814 .76525 L .65555 .76654 L F
.65686 .76581 m .65899 .76528 L .65814 .76525 L F
.432 .805 .993 r
.57086 .80089 m .56963 .80176 L .56858 .79969 L F
.57086 .80089 m .57205 .8013 L .56963 .80176 L F
.665 .519 .676 r
.5241 .83034 m .52199 .83296 L .52195 .83074 L F
.24 0 .04 r
.48443 .87454 m .48732 .87207 L .48622 .87365 L F
.638 .261 .313 r
.48732 .87207 m .48845 .87447 L .48622 .87365 L F
.48732 .87207 m .48933 .87263 L .48845 .87447 L F
.513 .905 .935 r
.51482 .87388 m .51185 .87461 L .51442 .87325 L F
.456 .734 .987 r
.51699 .87343 m .51482 .87388 L .51442 .87325 L F
.748 .46 .495 r
.47289 .83741 m .47064 .83999 L .469 .83733 L F
.189 0 .054 r
.47266 .83921 m .47289 .83741 L .47396 .83763 L F
.47266 .83921 m .47064 .83999 L .47289 .83741 L F
.933 .784 .672 r
.57185 .81219 m .5712 .8092 L .57127 .81154 L F
.965 .72 .283 r
.57141 .8135 m .57185 .81219 L .57127 .81154 L F
.493 .286 .527 r
.61493 .79669 m .61694 .79425 L .61658 .7961 L F
.39 .2 .499 r
.61474 .79887 m .61493 .79669 L .61658 .7961 L F
.683 .544 .689 r
.51392 .84564 m .51695 .84631 L .51603 .84309 L F
.132 0 .254 r
.56739 .7914 m .56568 .79401 L .56725 .79319 L F
0 0 .051 r
.56739 .7914 m .56765 .79319 L .56911 .7908 L F
.305 0 .121 r
.56813 .79025 m .56731 .79326 L .56802 .79018 L F
.56911 .7908 m .56765 .7928 L .56813 .79025 L F
0 0 .051 r
.56739 .7914 m .56757 .79319 L .56762 .79295 L F
.305 0 .121 r
.56765 .7928 m .56731 .79326 L .56813 .79025 L F
0 0 .051 r
.56739 .7914 m .56725 .79319 L .56757 .79319 L F
.56762 .79295 m .56757 .79319 L .56765 .79319 L F
.608 .467 .665 r
.38898 .87192 m .38691 .87456 L .38684 .87219 L F
.597 .89 .99 r
.43258 .88978 m .43518 .88831 L .43236 .88931 L F
.43258 .88978 m .43662 .8888 L .43518 .88831 L F
.694 .357 .402 r
.46034 .83603 m .45871 .83955 L .45682 .83751 L F
.444 .165 .394 r
.46203 .83571 m .46034 .83603 L .45997 .83523 L F
.46203 .83571 m .46233 .83688 L .46034 .83603 L F
.613 .27 .364 r
.46067 .83927 m .46034 .83603 L .46233 .83688 L F
.46067 .83927 m .45871 .83955 L .46034 .83603 L F
.822 .941 .905 r
.53824 .81992 m .53466 .82093 L .53644 .81904 L F
.533 .898 .969 r
.60265 .79815 m .60348 .79851 L .60162 .79915 L F
0 0 .396 r
.60162 .79915 m .60268 .80051 L .60265 .79815 L F
.60162 .79915 m .60166 .80145 L .60268 .80051 L F
.672 .581 .745 r
.51603 .84309 m .51897 .84367 L .51771 .8403 L F
.685 .545 .689 r
.51603 .84309 m .51695 .84631 L .51897 .84367 L F
.49 .293 .54 r
.61694 .79425 m .61905 .7914 L .61906 .79373 L F
.441 .184 .428 r
.61658 .7961 m .61694 .79425 L .61906 .79373 L F
.487 .118 .265 r
.50878 .81407 m .51211 .81166 L .50881 .81213 L F
.50878 .81407 m .51093 .81392 L .51211 .81166 L F
.622 .26 .335 r
.51211 .81166 m .51396 .81382 L .51413 .81162 L F
.51211 .81166 m .51093 .81392 L .51396 .81382 L F
0 .481 .72 r
.5357 .80635 m .53305 .80583 L .53451 .80594 L F
.035 .579 .842 r
.53451 .80594 m .53765 .80663 L .5357 .80635 L F
.7 .762 .9 r
.57228 .83513 m .57085 .83312 L .57168 .83627 L F
.561 .305 .484 r
.50143 .81457 m .50362 .8124 L .50178 .81223 L F
.50143 .81457 m .50333 .81463 L .50362 .8124 L F
.698 .426 .509 r
.50362 .8124 m .50658 .81422 L .50682 .81213 L F
.50362 .8124 m .50333 .81463 L .50658 .81422 L F
.654 .671 .853 r
.59895 .82709 m .60215 .82778 L .6002 .82871 L F
.023 0 .436 r
.5723 .82185 m .57115 .82228 L .57122 .81997 L F
.5723 .82185 m .57122 .81997 L .56987 .81966 L F
0 0 .321 r
.57136 .83422 m .57085 .83312 L .57325 .83257 L F
.57136 .83422 m .57168 .83627 L .57085 .83312 L F
.748 .66 .763 r
.56904 .83804 m .57222 .8384 L .57168 .83627 L F
.484 .171 .36 r
.39086 .8323 m .38873 .83113 L .38764 .83157 L F
.39086 .8323 m .39076 .83068 L .38873 .83113 L F
.724 .526 .622 r
.40392 .86423 m .4038 .86685 L .40237 .86655 L F
.711 .515 .622 r
.40708 .86653 m .4038 .86685 L .40392 .86423 L F
.469 .215 .445 r
.4877 .81229 m .48753 .81388 L .48963 .81191 L F
.626 .936 .962 r
.49276 .88861 m .4961 .88781 L .49441 .88841 L F
.537 .926 .871 r
.49693 .88695 m .4961 .88781 L .49741 .88707 L F
.544 .924 .797 r
.49441 .88841 m .4961 .88781 L .49693 .88695 L F
.361 .824 .742 r
.4961 .88781 m .49788 .88705 L .49741 .88707 L F
.311 .802 .836 r
.51105 .83639 m .51457 .83576 L .51306 .83589 L F
.62 .754 .942 r
.51557 .834 m .51457 .83576 L .51667 .83524 L F
.796 .99 .884 r
.51306 .83589 m .51457 .83576 L .51557 .834 L F
0 .289 .764 r
.51457 .83576 m .5171 .83756 L .51667 .83524 L F
.659 .673 .852 r
.45958 .87211 m .45706 .87355 L .45726 .8727 L F
.526 .306 .523 r
.62512 .78505 m .62781 .78283 L .62762 .78577 L F
.493 .167 .342 r
.62512 .78505 m .62697 .78722 L .62511 .78793 L F
.62512 .78505 m .62762 .78577 L .62697 .78722 L F
.596 .221 .302 r
.45275 .83821 m .45125 .84023 L .44951 .83971 L F
.702 .35 .377 r
.45465 .84019 m .45125 .84023 L .45275 .83821 L F
.472 .275 .53 r
.61906 .79373 m .61905 .7914 L .62098 .79104 L F
.577 .418 .629 r
.59832 .79655 m .60052 .79622 L .60043 .79388 L F
.913 .542 .309 r
.58552 .82593 m .58489 .82713 L .58479 .82489 L F
.738 .31 0 r
.58662 .82796 m .58552 .82593 L .58479 .82489 L F
.744 .323 .25 r
.59958 .81096 m .6002 .80896 L .59749 .80898 L F
.695 .566 .705 r
.60249 .80635 m .60383 .80952 L .6002 .80896 L F
.64 .457 .619 r
.60383 .80952 m .60163 .81198 L .6002 .80896 L F
0 0 0 r
.60172 .80832 m .6002 .80896 L .59958 .81096 L F
.309 0 0 r
.59749 .80898 m .6002 .80896 L .60046 .80935 L F
0 0 0 r
.60172 .80832 m .6002 .80896 L .60046 .80935 L F
.324 0 0 r
.4332 .8249 m .43528 .82486 L .43671 .82438 L F
.519 .027 .028 r
.43671 .82438 m .43528 .82486 L .43861 .82472 L F
0 0 0 r
.46153 .88429 m .46511 .88298 L .46346 .88383 L F
.068 0 0 r
.46511 .88298 m .46602 .88318 L .46346 .88383 L F
.46511 .88298 m .46711 .88279 L .46602 .88318 L F
.156 0 0 r
.4575 .88488 m .45956 .88477 L .45649 .88516 L F
.518 .304 .529 r
.37169 .77824 m .37144 .78047 L .36943 .78082 L F
.552 .334 .537 r
.37349 .78013 m .37169 .77824 L .37385 .77806 L F
.37349 .78013 m .37144 .78047 L .37169 .77824 L F
.578 .444 .663 r
.60676 .78606 m .60884 .78337 L .60649 .78377 L F
.587 .204 .283 r
.45123 .82445 m .4534 .82472 L .45464 .82278 L F
.525 .136 .245 r
.45464 .82278 m .45648 .82382 L .45678 .82285 L F
.45464 .82278 m .4534 .82472 L .45648 .82382 L F
.445 .214 .469 r
.62098 .79104 m .62129 .78898 L .6232 .78845 L F
.612 .912 .981 r
.42529 .89138 m .42895 .8908 L .42793 .89084 L F
.51 .912 .891 r
.42793 .89084 m .42895 .8908 L .43078 .88998 L F
.515 .163 .307 r
.64755 .7286 m .65078 .72664 L .64832 .72794 L F
.64755 .7286 m .65074 .72793 L .65078 .72664 L F
.562 .2 .311 r
.65074 .72793 m .65292 .72775 L .65078 .72664 L F
.564 .198 .305 r
.65078 .72664 m .65292 .72775 L .65331 .72657 L F
0 0 0 r
.52276 .87711 m .52577 .87471 L .52428 .87621 L F
.103 0 0 r
.52428 .87621 m .52577 .87471 L .52758 .87406 L F
.31 .8 .778 r
.49064 .8777 m .48866 .87835 L .48708 .87866 L F
.694 .403 .477 r
.59863 .80335 m .59945 .80072 L .59628 .80152 L F
.647 .278 .331 r
.60098 .8027 m .59945 .80072 L .59863 .80335 L F
.60098 .8027 m .60166 .80145 L .59945 .80072 L F
.58 .273 .412 r
.59147 .75917 m .59446 .75658 L .5926 .75762 L F
.525 .329 .558 r
.35666 .77293 m .3581 .77043 L .35636 .77045 L F
.491 .392 .671 r
.38006 .75474 m .38219 .75668 L .38216 .75433 L F
.38006 .75474 m .38055 .7572 L .38219 .75668 L F
.309 .127 .464 r
.60108 .7652 m .59848 .7673 L .59975 .76631 L F
.732 .713 .833 r
.50186 .83385 m .50477 .83613 L .50634 .8357 L F
.606 .597 .815 r
.50791 .83286 m .50634 .8357 L .50833 .83539 L F
.557 .569 .822 r
.50634 .8357 m .50862 .8367 L .50833 .83539 L F
.152 0 .147 r
.58249 .76432 m .58481 .7621 L .58337 .76321 L F
.337 .815 .773 r
.46237 .85363 m .4616 .85408 L .46333 .85316 L F
.27 .757 .918 r
.51413 .81162 m .51639 .81144 L .51763 .81172 L F
.737 .664 .779 r
.52941 .81715 m .52741 .81764 L .52578 .81623 L F
.535 .322 .537 r
.52941 .81715 m .52721 .81981 L .52741 .81764 L F
.52941 .81715 m .52939 .8195 L .52721 .81981 L F
.493 .258 .486 r
.36015 .78787 m .36196 .78813 L .36003 .78854 L F
.489 .19 .385 r
.36263 .78641 m .36196 .78813 L .36015 .78787 L F
.626 .389 .539 r
.39418 .869 m .3951 .87175 L .39117 .87164 L F
.572 .397 .606 r
.39641 .86683 m .39635 .86914 L .39418 .869 L F
.629 .391 .538 r
.39636 .87162 m .39418 .869 L .39635 .86914 L F
.39636 .87162 m .3951 .87175 L .39418 .869 L F
.535 .151 .259 r
.44737 .83814 m .44605 .84004 L .44415 .83973 L F
.68 .318 .353 r
.44951 .83971 m .44605 .84004 L .44737 .83814 L F
.465 .585 .889 r
.58999 .80735 m .5921 .80873 L .59198 .80684 L F
.63 .579 .779 r
.39001 .8778 m .38815 .87918 L .38682 .87636 L F
.525 .329 .558 r
.35666 .77293 m .3587 .77257 L .3581 .77043 L F
.676 .419 .524 r
.3587 .77257 m .35893 .7705 L .3581 .77043 L F
.272 .272 .677 r
.5312 .83174 m .52984 .83299 L .52939 .83003 L F
0 0 .219 r
.5302 .83518 m .52984 .83299 L .5312 .83174 L F
.5302 .83518 m .53013 .83604 L .52984 .83299 L F
.697 .963 .72 r
.59766 .81762 m .59516 .81973 L .59464 .81674 L F
.7 .606 .747 r
.59949 .81512 m .6 .81695 L .59766 .81762 L F
.248 .402 .821 r
.60027 .82071 m .59766 .81762 L .6 .81695 L F
.652 .138 0 r
.54365 .81086 m .54332 .81018 L .54126 .80883 L F
.54365 .81086 m .54439 .81138 L .54332 .81018 L F
.74 .504 .573 r
.60249 .80635 m .60609 .80929 L .60383 .80952 L F
.801 .692 .745 r
.62134 .75653 m .61919 .75939 L .62253 .75986 L F
.801 .693 .746 r
.61919 .75939 m .62026 .7624 L .62253 .75986 L F
.766 .675 .762 r
.62134 .75653 m .62253 .75986 L .62456 .75709 L F
.558 .482 .726 r
.39172 .74896 m .3904 .75241 L .38974 .74925 L F
.39172 .74896 m .39231 .7521 L .3904 .75241 L F
.584 .495 .72 r
.39256 .75391 m .3904 .75241 L .39231 .7521 L F
.39256 .75391 m .39083 .75444 L .3904 .75241 L F
.408 .111 .347 r
.36441 .78593 m .36196 .78813 L .36263 .78641 L F
.573 .405 .616 r
.48731 .84784 m .48921 .84767 L .48921 .84589 L F
.601 .56 .78 r
.48731 .84784 m .49039 .84958 L .48921 .84767 L F
.922 .8 .707 r
.40009 .82247 m .39976 .82525 L .40065 .82465 L F
.136 .134 .591 r
.39976 .82525 m .40038 .82695 L .40065 .82465 L F
.511 .3 .53 r
.58479 .82489 m .58283 .82525 L .58489 .82713 L F
.555 .5 .749 r
.39125 .74731 m .38974 .74925 L .38945 .74818 L F
.39125 .74731 m .39172 .74896 L .38974 .74925 L F
.403 0 0 r
.55117 .84058 m .55361 .84102 L .55102 .8414 L F
.786 .954 .925 r
.55102 .8414 m .55361 .84102 L .55391 .83953 L F
.205 0 .06 r
.55102 .8414 m .55391 .83953 L .5529 .84138 L F
.55102 .8414 m .5529 .84138 L .55274 .84122 L F
.55102 .8414 m .55274 .84122 L .55041 .8389 L F
.403 0 0 r
.55023 .84149 m .55102 .8414 L .54987 .84183 L F
.55117 .84058 m .55102 .8414 L .55023 .84149 L F
.818 .531 .504 r
.4963 .84294 m .49315 .8399 L .49612 .84092 L F
.793 .945 .924 r
.50012 .88649 m .50305 .88486 L .5022 .88451 L F
.614 .957 .869 r
.50305 .88486 m .50377 .88384 L .5022 .88451 L F
.50305 .88486 m .50609 .88315 L .50377 .88384 L F
.542 .328 .539 r
.36943 .78082 m .36923 .78299 L .36719 .78331 L F
.538 .324 .538 r
.37121 .78259 m .36943 .78082 L .37144 .78047 L F
.37121 .78259 m .36923 .78299 L .36943 .78082 L F
.63 .653 .854 r
.39457 .75477 m .39083 .75444 L .39256 .75391 L F
0 0 0 r
.49186 .81928 m .49085 .82167 L .48981 .82251 L F
.168 .672 .907 r
.49395 .81931 m .49278 .81896 L .49186 .81928 L F
.758 .633 .723 r
.49278 .81896 m .49085 .82167 L .49186 .81928 L F
.095 0 0 r
.58518 .84851 m .58641 .84864 L .58437 .84902 L F
.58518 .84851 m .58732 .84828 L .58641 .84864 L F
.662 .385 .49 r
.62703 .77006 m .62974 .76947 L .63001 .76781 L F
.433 .093 .288 r
.62974 .76947 m .63235 .7677 L .63001 .76781 L F
.506 .905 .924 r
.50762 .88202 m .51078 .88129 L .50966 .88127 L F
.352 .82 .748 r
.51078 .88129 m .51167 .88077 L .50966 .88127 L F
.51078 .88129 m .51329 .88028 L .51167 .88077 L F
.557 .464 .705 r
.59303 .8101 m .59519 .80943 L .5921 .80873 L F
.59303 .8101 m .59552 .81169 L .59519 .80943 L F
.387 .717 .988 r
.56743 .79606 m .5653 .79601 L .56568 .79401 L F
.551 .485 .735 r
.5653 .79601 m .56725 .79319 L .56568 .79401 L F
.755 .725 .825 r
.64143 .73199 m .63827 .73177 L .64024 .73079 L F
.731 .782 .893 r
.64335 .73095 m .64143 .73199 L .64024 .73079 L F
.379 .307 .649 r
.48463 .87624 m .48294 .87813 L .4836 .87375 L F
.581 .608 .844 r
.48463 .87624 m .485 .8782 L .48294 .87813 L F
.651 .66 .845 r
.3887 .7441 m .38495 .74207 L .38706 .74161 L F
.497 .558 .849 r
.38898 .74107 m .3887 .7441 L .38706 .74161 L F
.38898 .74107 m .39036 .74379 L .3887 .7441 L F
.571 .468 .698 r
.39125 .74731 m .3887 .7441 L .39036 .74379 L F
.39125 .74731 m .38945 .74818 L .3887 .7441 L F
.448 .237 .5 r
.66213 .71815 m .66036 .72081 L .66242 .72046 L F
.66242 .72046 m .66036 .72081 L .66213 .71815 L F
.427 .295 .598 r
.66213 .71815 m .66438 .71779 L .66345 .71663 L F
.634 .502 .685 r
.66242 .72046 m .66438 .71779 L .66213 .71815 L F
.502 .679 .945 r
.52969 .84324 m .52608 .84144 L .52846 .84044 L F
.765 .687 .776 r
.53171 .84071 m .52969 .84324 L .52846 .84044 L F
.786 .539 .563 r
.43262 .84594 m .42923 .84339 L .43112 .8431 L F
.43262 .84594 m .42935 .84576 L .42923 .84339 L F
.815 .662 .693 r
.43053 .84826 m .42935 .84576 L .43262 .84594 L F
.723 .543 .647 r
.43262 .84594 m .43313 .84888 L .43053 .84826 L F
.547 .555 .814 r
.43416 .84422 m .43262 .84594 L .43112 .8431 L F
.423 .371 .695 r
.43416 .84422 m .43468 .84779 L .43262 .84594 L F
.475 .374 .661 r
.43468 .84779 m .43313 .84888 L .43262 .84594 L F
.715 .469 .552 r
.59519 .80943 m .59198 .80684 L .5921 .80873 L F
.056 0 .228 r
.48318 .85652 m .48379 .8565 L .48475 .85567 L F
.748 .532 .603 r
.42492 .85091 m .42162 .85305 L .4227 .85092 L F
.774 .629 .701 r
.62153 .76751 m .62478 .76789 L .62349 .76491 L F
.807 .622 .652 r
.62151 .76994 m .62478 .76789 L .62153 .76751 L F
.62151 .76994 m .62475 .77042 L .62478 .76789 L F
.142 0 .321 r
.59709 .84321 m .59766 .84108 L .59883 .84016 L F
.715 .578 .701 r
.56749 .78029 m .56377 .7781 L .56716 .7783 L F
.356 .024 .259 r
.59256 .84584 m .59522 .84384 L .59437 .8452 L F
.301 0 .193 r
.59437 .8452 m .59522 .84384 L .59709 .84321 L F
.923 .591 .394 r
.55025 .80173 m .54883 .80134 L .54822 .79883 L F
.85 .391 .04 r
.55075 .80325 m .54883 .80134 L .55025 .80173 L F
.045 .432 .87 r
.57615 .8072 m .57934 .8095 L .57822 .80659 L F
.732 .564 .665 r
.58146 .80917 m .57822 .80659 L .57934 .8095 L F
.453 .255 .52 r
.67822 .75217 m .67811 .75431 L .67619 .75488 L F
.437 .218 .481 r
.67811 .75431 m .67595 .75701 L .67619 .75488 L F
.69 .468 .581 r
.3587 .77257 m .36172 .77012 L .35893 .7705 L F
.804 .992 .876 r
.53196 .86671 m .52869 .8686 L .53068 .8684 L F
.394 .805 .979 r
.53301 .86599 m .53441 .86648 L .53196 .86671 L F
0 0 0 r
.53301 .86599 m .53196 .86671 L .53068 .8684 L F
.736 .5 .571 r
.42923 .84339 m .42584 .84522 L .4256 .84346 L F
.42923 .84339 m .42935 .84576 L .42584 .84522 L F
.479 0 .01 r
.42447 .8264 m .42651 .82663 L .42802 .82543 L F
.527 .092 .158 r
.42651 .82663 m .42995 .82522 L .42802 .82543 L F
.706 .662 .804 r
.51771 .8403 m .52161 .84107 L .52017 .83694 L F
.63 .452 .623 r
.51897 .84367 m .52161 .84107 L .51771 .8403 L F
.51897 .84367 m .52117 .84283 L .52161 .84107 L F
.732 .676 .796 r
.52017 .83694 m .52161 .84107 L .52294 .83975 L F
.803 .653 .696 r
.52741 .81764 m .52721 .81981 L .52578 .81623 L F
.64 .457 .619 r
.60383 .80952 m .6039 .81186 L .60163 .81198 L F
.601 .388 .564 r
.60383 .80952 m .60604 .81158 L .6039 .81186 L F
.60383 .80952 m .60609 .80929 L .60604 .81158 L F
.217 .63 .954 r
.49941 .87697 m .49539 .87548 L .49734 .87571 L F
0 .306 .709 r
.49924 .87672 m .49941 .87697 L .49734 .87571 L F
0 .39 .752 r
.49924 .87672 m .50101 .87759 L .49941 .87697 L F
.685 .877 .971 r
.40417 .89516 m .4055 .89582 L .4073 .89495 L F
.505 .786 .996 r
.48729 .88815 m .49066 .88873 L .48914 .88808 L F
.367 .773 .983 r
.49066 .88873 m .49127 .88782 L .48914 .88808 L F
.49066 .88873 m .49276 .88861 L .49127 .88782 L F
.686 .949 .956 r
.50413 .87662 m .50101 .87759 L .50328 .87678 L F
.659 .942 .686 r
.50557 .87496 m .50413 .87662 L .50328 .87678 L F
.50557 .87496 m .50649 .87436 L .50413 .87662 L F
.211 0 0 r
.46711 .88279 m .47034 .88241 L .46915 .88279 L F
.238 0 0 r
.47034 .88241 m .47113 .88279 L .46915 .88279 L F
.47034 .88241 m .47235 .88255 L .47113 .88279 L F
.78 .891 .924 r
.623 .73839 m .62125 .73954 L .62022 .73877 L F
.394 0 0 r
.54816 .79404 m .55033 .79411 L .55146 .79336 L F
.26 .769 .838 r
.55033 .79411 m .55357 .79367 L .55146 .79336 L F
.626 .597 .802 r
.39688 .75747 m .39457 .75477 L .396 .7545 L F
.59 .519 .743 r
.39827 .75397 m .39688 .75747 L .396 .7545 L F
.39827 .75397 m .39904 .75717 L .39688 .75747 L F
.623 .493 .684 r
.39904 .75717 m .39705 .75977 L .39688 .75747 L F
.643 .495 .667 r
.37104 .83816 m .3735 .83806 L .37351 .83608 L F
.64 .462 .627 r
.3711 .84055 m .3735 .83806 L .37104 .83816 L F
.464 .632 .927 r
.53586 .83779 m .53399 .83785 L .53282 .83606 L F
.716 .66 .793 r
.53586 .83779 m .534 .84043 L .53399 .83785 L F
0 0 .438 r
.58172 .77523 m .58206 .77278 L .58152 .77496 L F
.919 .929 .8 r
.5798 .77735 m .58172 .77523 L .58152 .77496 L F
.997 .837 .563 r
.55227 .82783 m .55285 .82513 L .55156 .82694 L F
.883 .6 .083 r
.55252 .82485 m .55285 .82513 L .55207 .82214 L F
.916 .931 .56 r
.55156 .82694 m .55285 .82513 L .55252 .82485 L F
.507 .634 .91 r
.55518 .83555 m .55213 .8338 L .55392 .83286 L F
.008 .238 .746 r
.55571 .83463 m .55518 .83555 L .55392 .83286 L F
.834 .657 .113 r
.55489 .83676 m .55518 .83555 L .55571 .83463 L F
.55489 .83676 m .5552 .83788 L .55518 .83555 L F
.667 .666 .84 r
.44012 .87405 m .43926 .87711 L .43823 .87509 L F
.44012 .87405 m .44111 .87634 L .43926 .87711 L F
.44 .137 .354 r
.47777 .81682 m .4789 .81889 L .47986 .81664 L F
.47777 .81682 m .47694 .81931 L .4789 .81889 L F
.662 .586 .759 r
.51897 .84367 m .52211 .84607 L .52117 .84283 L F
.57 .509 .748 r
.52211 .84607 m .52342 .84274 L .52117 .84283 L F
.52211 .84607 m .52414 .8458 L .52342 .84274 L F
.538 .561 .826 r
.52211 .84607 m .52538 .84897 L .52414 .8458 L F
.768 .61 .683 r
.66078 .74921 m .66411 .74996 L .66371 .74744 L F
.583 .482 .705 r
.66371 .74744 m .66613 .74915 L .66566 .74724 L F
.66371 .74744 m .66411 .74996 L .66613 .74915 L F
0 0 .252 r
.49085 .82167 m .48954 .82602 L .48981 .82251 L F
0 0 0 r
.65235 .73182 m .65461 .72922 L .65355 .73051 L F
.76 .466 .486 r
.39282 .83013 m .39064 .82793 L .39076 .83068 L F
.822 .939 .574 r
.65461 .72922 m .65609 .72644 L .65513 .72751 L F
.263 .178 .568 r
.65513 .72751 m .65355 .73051 L .65461 .72922 L F
.69 .782 .922 r
.56308 .78402 m .5602 .78362 L .56184 .78263 L F
.697 .719 .866 r
.56391 .78307 m .56308 .78402 L .56203 .78284 L F
.56507 .78321 m .56389 .78369 L .56391 .78307 L F
.56389 .78369 m .56308 .78402 L .56391 .78307 L F
.56507 .78321 m .56203 .78284 L .56258 .78276 L F
.756 .606 .691 r
.56657 .78183 m .56507 .78321 L .56184 .78263 L F
.568 .198 .3 r
.56114 .78489 m .56356 .78529 L .56393 .78257 L F
.56377 .78259 m .56393 .78257 L .56395 .78244 L F
.56114 .78489 m .56393 .78257 L .56377 .78259 L F
.756 .606 .691 r
.56657 .78183 m .56184 .78263 L .56423 .78061 L F
.736 .589 .691 r
.56423 .78061 m .56184 .78263 L .56395 .78244 L F
.697 .719 .866 r
.56258 .78276 m .56203 .78284 L .56184 .78263 L F
.568 .198 .3 r
.56114 .78489 m .56395 .78244 L .56184 .78263 L F
.53 .877 .987 r
.56356 .78529 m .56381 .78199 L .56393 .7824 L F
.56393 .78257 m .56393 .7824 L .56395 .78244 L F
.56356 .78529 m .56393 .7824 L .56393 .78257 L F
.771 .663 .744 r
.62134 .75653 m .62456 .75709 L .6247 .75494 L F
.708 .735 .872 r
.57469 .77769 m .57819 .77838 L .57728 .77722 L F
.57497 .77764 m .57728 .77722 L .57507 .77734 L F
.959 .819 .663 r
.57641 .77983 m .57819 .77838 L .57538 .77783 L F
.57486 .7779 m .57538 .77783 L .57469 .77769 L F
.57641 .77983 m .57538 .77783 L .57486 .7779 L F
.637 .718 .906 r
.57212 .77809 m .56958 .77804 L .57166 .7777 L F
.5728 .77867 m .56972 .77807 L .57212 .77809 L F
.56972 .77807 m .56958 .77804 L .57212 .77809 L F
.737 .635 .746 r
.57702 .77754 m .57639 .77773 L .57512 .77798 L F
.616 .376 .531 r
.57154 .7802 m .57389 .77833 L .5728 .77867 L F
.57154 .7802 m .57457 .78008 L .57468 .77786 L F
.57454 .77781 m .57468 .77786 L .57469 .77769 L F
.57154 .7802 m .57468 .77786 L .57454 .77781 L F
.57454 .77781 m .57455 .77776 L .5728 .77867 L F
.666 .418 .536 r
.57469 .77769 m .57457 .78008 L .57641 .77983 L F
.986 .823 .434 r
.57083 .77891 m .57154 .7802 L .57166 .7777 L F
.304 0 0 r
.57497 .77796 m .57114 .77845 L .57464 .77794 L F
.57512 .77798 m .57504 .77799 L .57497 .77796 L F
.57504 .77799 m .57114 .77845 L .57497 .77796 L F
.737 .635 .746 r
.57639 .77773 m .57228 .77891 L .57451 .77818 L F
.57639 .77773 m .57451 .77818 L .57512 .77798 L F
.616 .376 .531 r
.57389 .77833 m .57454 .77781 L .57312 .77851 L F
.57389 .77833 m .57312 .77851 L .5728 .77867 L F
.57454 .77781 m .57469 .77769 L .57455 .77776 L F
.304 0 0 r
.57447 .77805 m .57083 .77891 L .57114 .77845 L F
.57512 .77798 m .57445 .77812 L .57447 .77805 L F
.57445 .77812 m .57083 .77891 L .57447 .77805 L F
.616 .469 .659 r
.5722 .7825 m .57457 .78008 L .57154 .7802 L F
.5722 .7825 m .57465 .78253 L .57457 .78008 L F
.697 .533 .661 r
.57457 .78008 m .57465 .78253 L .57641 .77983 L F
.773 .564 .616 r
.57524 .78043 m .57283 .78077 L .57228 .77891 L F
.649 .737 .913 r
.57283 .78077 m .57319 .77927 L .57228 .77891 L F
.304 0 0 r
.57453 .77811 m .57228 .77891 L .57175 .77871 L F
.57473 .77811 m .57228 .77891 L .57453 .77811 L F
.737 .635 .746 r
.57702 .77754 m .57583 .77924 L .57228 .77891 L F
.773 .564 .616 r
.57524 .78043 m .57228 .77891 L .57583 .77924 L F
.649 .737 .913 r
.57319 .77927 m .5735 .77798 L .57228 .77891 L F
.304 0 0 r
.57175 .77871 m .57228 .77891 L .57083 .77891 L F
.57512 .77798 m .57473 .77811 L .57453 .77811 L F
.57464 .77794 m .57114 .77845 L .57166 .7777 L F
.498 .468 .754 r
.57562 .7746 m .57469 .77769 L .57641 .7761 L F
.204 .192 .622 r
.57534 .77654 m .57702 .77754 L .57512 .77798 L F
.57562 .7746 m .57583 .77504 L .57534 .77654 L F
.708 .735 .872 r
.57507 .77734 m .57728 .77722 L .57641 .7761 L F
.204 .192 .622 r
.57583 .77504 m .57702 .77754 L .57534 .77654 L F
.654 .411 .539 r
.5746 .77559 m .57505 .77763 L .57469 .77769 L F
.708 .735 .872 r
.57469 .77769 m .57497 .77764 L .57507 .77734 L F
.654 .411 .539 r
.57505 .77763 m .57512 .77798 L .57469 .77769 L F
.565 .522 .766 r
.60203 .81671 m .6 .81695 L .59949 .81512 L F
.665 .569 .737 r
.60203 .81671 m .60027 .82071 L .6 .81695 L F
.578 .444 .663 r
.60676 .78606 m .60892 .78569 L .60884 .78337 L F
.497 .525 .816 r
.60676 .78606 m .60905 .78829 L .60892 .78569 L F
.74 .645 .754 r
.63035 .73568 m .62855 .73659 L .63061 .73414 L F
.714 .717 .851 r
.63282 .73354 m .63035 .73568 L .63061 .73414 L F
.489 .272 .51 r
.62781 .78283 m .63005 .78068 L .62978 .78239 L F
.418 .19 .458 r
.6295 .78504 m .62781 .78283 L .62978 .78239 L F
.6295 .78504 m .62762 .78577 L .62781 .78283 L F
.522 .287 .499 r
.65609 .72644 m .65802 .72542 L .65845 .72353 L F
.65609 .72644 m .65802 .72542 L .65845 .72353 L F
.528 .383 .627 r
.41181 .7439 m .40968 .7417 L .4117 .74133 L F
.41181 .7439 m .40989 .7444 L .40968 .7417 L F
.41181 .7439 m .40968 .7417 L .4117 .74133 L F
.41181 .7439 m .40989 .7444 L .40968 .7417 L F
.038 0 0 r
.5703 .77246 m .57219 .77176 L .5736 .77054 L F
0 0 0 r
.5736 .77054 m .5747 .77001 L .57518 .76928 L F
.57219 .77176 m .5747 .77001 L .5736 .77054 L F
.972 .697 .449 r
.58545 .83563 m .58452 .8339 L .58643 .83477 L F
.06 .066 .549 r
.58645 .83685 m .58545 .83563 L .58643 .83477 L F
.73 .98 .756 r
.5716 .79296 m .57072 .79437 L .5727 .79358 L F
.5716 .79296 m .5694 .79508 L .57072 .79437 L F
.793 .706 .769 r
.62794 .74919 m .62569 .74936 L .62875 .74958 L F
.795 .698 .758 r
.62569 .74936 m .62673 .7523 L .62875 .74958 L F
.763 .724 .816 r
.62794 .74919 m .62875 .74958 L .63105 .74732 L F
0 0 0 r
.49615 .81475 m .49491 .81616 L .49449 .81604 L F
.728 .199 0 r
.40352 .82497 m .40009 .82247 L .40065 .82465 L F
.687 .315 .336 r
.40289 .82639 m .40352 .82497 L .40065 .82465 L F
.479 .1 .242 r
.40465 .82569 m .40352 .82497 L .40289 .82639 L F
.623 .58 .785 r
.40649 .82674 m .40352 .82497 L .40465 .82569 L F
.53 .182 .322 r
.43899 .84187 m .43555 .84308 L .43669 .84107 L F
.715 .777 .901 r
.52276 .81213 m .51949 .81185 L .52173 .81087 L F
.54 .708 .948 r
.52397 .8109 m .52276 .81213 L .52173 .81087 L F
.289 .301 .7 r
.52397 .8109 m .52439 .81654 L .52276 .81213 L F
.341 .791 .952 r
.4943 .82235 m .49751 .82251 L .49527 .82277 L F
.516 .235 .426 r
.36719 .78331 m .36648 .78563 L .36441 .78593 L F
.504 .222 .42 r
.36923 .78299 m .36648 .78563 L .36719 .78331 L F
.715 .578 .701 r
.56749 .78029 m .56657 .78183 L .56377 .7781 L F
.8 .588 .615 r
.56377 .7781 m .56657 .78183 L .56582 .78144 L F
.56399 .77925 m .56582 .78144 L .56423 .78061 L F
.56377 .7781 m .56582 .78144 L .56399 .77925 L F
.735 .588 .691 r
.56792 .7818 m .56665 .78243 L .56749 .78029 L F
.56665 .78243 m .56507 .78321 L .56618 .78187 L F
.814 .714 .755 r
.56749 .78029 m .56507 .78321 L .56657 .78183 L F
.735 .588 .691 r
.56665 .78243 m .56618 .78187 L .56749 .78029 L F
0 .283 .784 r
.37925 .73564 m .37927 .73661 L .37731 .73584 L F
.37925 .73564 m .38082 .73775 L .37927 .73661 L F
.551 .323 .523 r
.38082 .73775 m .37855 .73873 L .37927 .73661 L F
.625 .449 .625 r
.60597 .76999 m .60876 .77059 L .60849 .7678 L F
.801 .665 .713 r
.57205 .8013 m .57536 .80176 L .57389 .7987 L F
.809 .622 .649 r
.57187 .80378 m .57536 .80176 L .57205 .8013 L F
.57187 .80378 m .57494 .80395 L .57536 .80176 L F
.443 .88 .858 r
.3925 .89973 m .39266 .89922 L .39117 .89986 L F
.3925 .89973 m .39504 .89877 L .39266 .89922 L F
.51 .465 .742 r
.67806 .74342 m .6757 .74448 L .67616 .7434 L F
.506 .427 .702 r
.67806 .74342 m .6766 .74675 L .6757 .74448 L F
.521 .278 .488 r
.38332 .77027 m .38297 .77246 L .38092 .77278 L F
.536 .292 .492 r
.38505 .77211 m .38332 .77027 L .38535 .76997 L F
.38505 .77211 m .38297 .77246 L .38332 .77027 L F
.589 .646 .875 r
.52721 .81981 m .52398 .81778 L .52578 .81623 L F
.461 .311 .59 r
.52939 .8195 m .52762 .82248 L .52721 .81981 L F
.751 .594 .681 r
.55147 .83027 m .54865 .83275 L .54864 .83069 L F
.55147 .83027 m .55213 .8338 L .54865 .83275 L F
.842 .879 .443 r
.55147 .83027 m .55227 .82783 L .55327 .82986 L F
.365 .33 .686 r
.55335 .83103 m .55147 .83027 L .55327 .82986 L F
.55335 .83103 m .55213 .8338 L .55147 .83027 L F
.234 0 0 r
.46673 .87188 m .468 .8713 L .4647 .87197 L F
.611 .045 0 r
.46826 .87214 m .468 .8713 L .46673 .87188 L F
.46826 .87214 m .47024 .87253 L .468 .8713 L F
.871 .856 .824 r
.53474 .84778 m .53622 .84846 L .53398 .85113 L F
.614 .435 .615 r
.53622 .84846 m .53619 .85123 L .53398 .85113 L F
.409 .779 .994 r
.53813 .84821 m .53622 .84846 L .53474 .84778 L F
.538 .372 .605 r
.53962 .84903 m .53622 .84846 L .53813 .84821 L F
.53962 .84903 m .53619 .85123 L .53622 .84846 L F
.663 .544 .709 r
.3893 .87416 m .38691 .87456 L .38898 .87192 L F
.68 .541 .689 r
.3893 .87416 m .38682 .87636 L .38691 .87456 L F
.595 .403 .592 r
.64034 .76156 m .63957 .76251 L .64205 .76021 L F
.361 .634 .958 r
.49896 .83676 m .49855 .83835 L .49765 .83725 L F
.552 .632 .884 r
.50172 .83928 m .49855 .83835 L .5015 .83935 L F
.361 .634 .958 r
.49896 .83676 m .5015 .83935 L .49855 .83835 L F
.447 .063 .217 r
.66444 .75437 m .66665 .75429 L .66734 .7525 L F
.21 0 .12 r
.66734 .7525 m .66853 .75342 L .66945 .7519 L F
.66734 .7525 m .66665 .75429 L .66853 .75342 L F
.537 .367 .598 r
.66734 .7525 m .66945 .7519 L .6693 .74946 L F
.347 .122 .424 r
.59848 .8229 m .60027 .82071 L .60053 .82232 L F
.455 .43 .741 r
.60093 .82475 m .59848 .8229 L .60053 .82232 L F
.60093 .82475 m .59924 .82517 L .59848 .8229 L F
.542 .549 .811 r
.52414 .8458 m .52538 .84897 L .52739 .84888 L F
0 0 .408 r
.56576 .78421 m .56507 .78321 L .56792 .7818 L F
.56576 .78421 m .5655 .78574 L .56507 .78321 L F
.469 .066 .192 r
.56861 .78227 m .56576 .78421 L .56792 .7818 L F
.56944 .78282 m .56663 .78388 L .56861 .78227 L F
.56663 .78388 m .56576 .78421 L .56861 .78227 L F
.542 .398 .634 r
.56825 .78155 m .56576 .78421 L .56944 .78282 L F
.847 .997 .775 r
.56498 .78449 m .56517 .78508 L .56825 .78155 L F
.903 .984 .776 r
.56576 .78421 m .56488 .78554 L .5655 .78574 L F
.56488 .78554 m .56389 .78704 L .56522 .78596 L F
.56488 .78554 m .56522 .78596 L .5655 .78574 L F
.902 .985 .773 r
.56376 .78672 m .56389 .78704 L .56488 .78554 L F
.56479 .78543 m .56488 .78554 L .56576 .78421 L F
.56376 .78672 m .56488 .78554 L .56479 .78543 L F
.56376 .78672 m .56576 .78421 L .56528 .78544 L F
.53 .877 .987 r
.56434 .78485 m .56528 .78544 L .56498 .78449 L F
.56432 .78486 m .56437 .78489 L .56434 .78485 L F
.56437 .78489 m .56528 .78544 L .56434 .78485 L F
.56356 .78529 m .56476 .78539 L .56432 .78486 L F
.56476 .78539 m .56528 .78544 L .56432 .78486 L F
.542 .398 .634 r
.56825 .78155 m .56528 .78544 L .56576 .78421 L F
.847 .997 .775 r
.56517 .78508 m .56528 .78544 L .56621 .78423 L F
.56517 .78508 m .56621 .78423 L .56825 .78155 L F
.97 .795 .61 r
.50068 .81179 m .50143 .81457 L .50178 .81223 L F
.763 .728 .82 r
.62855 .73659 m .62546 .73643 L .62804 .7343 L F
.804 .752 .805 r
.63061 .73414 m .62855 .73659 L .62804 .7343 L F
.7 .496 .609 r
.48921 .84767 m .49236 .84591 L .48921 .84589 L F
.48921 .84767 m .49258 .84863 L .49236 .84591 L F
.682 .638 .799 r
.60093 .82475 m .59895 .82709 L .59924 .82517 L F
0 0 0 r
.49788 .88705 m .50012 .88649 L .49741 .88707 L F
.986 .719 .354 r
.60688 .79292 m .60741 .79125 L .60746 .79319 L F
.306 .122 .459 r
.60905 .78829 m .60741 .79125 L .609 .79028 L F
0 0 .008 r
.609 .79028 m .60741 .79125 L .60688 .79292 L F
.466 0 0 r
.55313 .80486 m .55424 .80582 L .55203 .80418 L F
.55313 .80486 m .55511 .80652 L .55424 .80582 L F
.573 .012 0 r
.53989 .83255 m .54145 .83299 L .53989 .83268 L F
0 0 .4 r
.54145 .83299 m .54133 .83466 L .54229 .83471 L F
.54133 .83466 m .54127 .83545 L .54229 .83471 L F
.017 0 0 r
.5429 .83475 m .54229 .83471 L .54084 .83549 L F
.54434 .83423 m .54229 .83471 L .5429 .83475 L F
0 0 .4 r
.54145 .83299 m .54229 .83471 L .53989 .83268 L F
.097 .319 .795 r
.53989 .83268 m .54229 .83471 L .54125 .83228 L F
.53989 .83268 m .54125 .83228 L .53987 .83307 L F
.53989 .83268 m .53987 .83307 L .53801 .83413 L F
.573 .012 0 r
.538 .83202 m .53989 .83255 L .53989 .83268 L F
.443 .247 .518 r
.68007 .75162 m .67811 .75431 L .67822 .75217 L F
.486 .375 .652 r
.66036 .72081 m .6626 .72269 L .66242 .72046 L F
.66036 .72081 m .6626 .72269 L .66242 .72046 L F
.381 0 .136 r
.60218 .75235 m .60337 .75353 L .60393 .75121 L F
.60218 .75235 m .60118 .75396 L .60337 .75353 L F
.55 .883 .626 r
.61127 .74635 m .61225 .74531 L .61389 .74437 L F
.61127 .74635 m .61088 .74655 L .61225 .74531 L F
.978 .695 .414 r
.56387 .7786 m .56387 .77996 L .56254 .77758 L F
0 .003 .573 r
.56254 .77758 m .56423 .78061 L .56374 .77913 L F
.772 .615 .05 r
.56388 .78131 m .56381 .78199 L .56374 .77913 L F
.56395 .78244 m .56388 .78221 L .56388 .78131 L F
.56388 .78221 m .56381 .78199 L .56388 .78131 L F
.978 .695 .414 r
.56377 .7781 m .56387 .7786 L .56254 .77758 L F
.56387 .7786 m .56423 .78061 L .56387 .77996 L F
.788 .652 .712 r
.5733 .80712 m .57615 .8072 L .57494 .80395 L F
.824 .397 .227 r
.57822 .80659 m .57494 .80395 L .57615 .8072 L F
.628 .654 .856 r
.38078 .7338 m .37734 .73194 L .37933 .73156 L F
.37 0 .084 r
.38078 .7338 m .37925 .73564 L .37731 .73584 L F
.415 .558 .89 r
.38161 .73241 m .38078 .7338 L .37933 .73156 L F
.677 .885 .516 r
.38161 .73241 m .37925 .73564 L .38078 .7338 L F
.496 .284 .521 r
.60826 .8072 m .61087 .80436 L .61077 .80656 L F
.47 .228 .464 r
.60828 .809 m .60826 .8072 L .61077 .80656 L F
.646 .782 .946 r
.37246 .74845 m .3763 .74946 L .3743 .74834 L F
.587 .835 .992 r
.3743 .74834 m .3763 .74946 L .37786 .74869 L F
.597 .639 .863 r
.3763 .74946 m .37858 .75 L .37786 .74869 L F
0 0 0 r
.58989 .83486 m .58645 .83685 L .5883 .83556 L F
.159 0 .121 r
.59236 .83267 m .58989 .83486 L .59047 .83373 L F
.71 .979 .781 r
.59047 .83373 m .58989 .83486 L .5883 .83556 L F
.761 .704 .798 r
.46182 .87126 m .46264 .87237 L .45958 .87211 L F
.607 .606 .824 r
.46343 .86917 m .46264 .87237 L .46182 .87126 L F
.46343 .86917 m .4647 .87197 L .46264 .87237 L F
.399 .836 .946 r
.44566 .88717 m .44684 .88739 L .44901 .88691 L F
.101 0 0 r
.50742 .87456 m .50649 .87436 L .50557 .87496 L F
.50742 .87456 m .50863 .87401 L .50649 .87436 L F
.638 .663 .858 r
.54776 .83076 m .54645 .83314 L .54551 .83209 L F
.54776 .83076 m .54865 .83275 L .54645 .83314 L F
0 0 0 r
.38711 .90068 m .38635 .9011 L .38389 .90201 L F
.38711 .90068 m .38725 .90061 L .38635 .9011 L F
.699 .615 .759 r
.50963 .85697 m .51057 .85762 L .51054 .85628 L F
.845 .803 .81 r
.50826 .85938 m .51057 .85762 L .50963 .85697 L F
.194 0 0 r
.67407 .75784 m .67308 .75933 L .67124 .75949 L F
.236 0 .001 r
.67507 .75874 m .67407 .75784 L .67595 .75701 L F
.67507 .75874 m .67308 .75933 L .67407 .75784 L F
.444 0 0 r
.47235 .88255 m .47567 .88241 L .47445 .88288 L F
.599 .094 .024 r
.47445 .88288 m .47567 .88241 L .47824 .88372 L F
.692 .827 .947 r
.42558 .87764 m .42274 .87858 L .42207 .87752 L F
.074 0 0 r
.56557 .775 m .56732 .77481 L .56827 .77309 L F
.028 0 0 r
.56557 .775 m .56524 .77565 L .56732 .77481 L F
.501 .244 .457 r
.39276 .76372 m .39191 .7672 L .38995 .76755 L F
.528 .29 .498 r
.39493 .76235 m .3943 .7638 L .39276 .76372 L F
.537 .28 .474 r
.3943 .7638 m .39191 .7672 L .39276 .76372 L F
.671 .297 .329 r
.46541 .83561 m .46439 .83745 L .46203 .83571 L F
.22 0 .089 r
.4662 .83678 m .46541 .83561 L .46795 .83645 L F
.4662 .83678 m .46439 .83745 L .46541 .83561 L F
0 0 0 r
.64318 .77221 m .64354 .77233 L .6419 .77299 L F
.6419 .77299 m .64354 .77233 L .64076 .77419 L F
.58939 .84788 m .59256 .84584 L .59133 .84736 L F
.139 0 0 r
.59133 .84736 m .59256 .84584 L .59437 .8452 L F
.638 .857 .983 r
.53782 .83709 m .53915 .83786 L .53586 .83779 L F
.789 .694 .759 r
.53586 .83779 m .53915 .83786 L .53702 .8406 L F
.842 .877 .867 r
.54127 .83545 m .53915 .83786 L .53782 .83709 L F
.661 .566 .737 r
.60849 .7678 m .60985 .76467 L .6076 .76541 L F
.60849 .7678 m .61082 .76767 L .60985 .76467 L F
.711 .549 .667 r
.60876 .77059 m .61082 .76767 L .60849 .7678 L F
.686 .499 .628 r
.63759 .76435 m .63964 .76522 L .63957 .76251 L F
.633 .448 .614 r
.39838 .86896 m .39641 .86683 L .39846 .86663 L F
.39838 .86896 m .39635 .86914 L .39641 .86683 L F
.557 .877 .993 r
.43518 .88831 m .43662 .8888 L .43852 .88816 L F
.806 .703 .752 r
.62569 .74936 m .62382 .7523 L .62673 .7523 L F
.804 .713 .764 r
.62382 .7523 m .6247 .75494 L .62673 .7523 L F
.159 0 .121 r
.59236 .83267 m .59047 .83373 L .59133 .83232 L F
.558 .54 .791 r
.59245 .82697 m .59319 .82932 L .59198 .83011 L F
.896 .929 .831 r
.5942 .8302 m .59236 .83267 L .592 .83255 L F
.5942 .8302 m .592 .83255 L .59237 .83155 L F
.59237 .83155 m .592 .83255 L .59133 .83232 L F
.5942 .8302 m .59133 .83232 L .59407 .83214 L F
.558 .54 .791 r
.59319 .82932 m .59407 .83214 L .59266 .83077 L F
.59319 .82932 m .59266 .83077 L .59198 .83011 L F
.481 .037 .116 r
.35456 .75002 m .35303 .75146 L .35084 .75144 L F
.262 0 0 r
.35501 .75106 m .35303 .75146 L .35456 .75002 L F
.668 .974 .88 r
.50377 .88384 m .50609 .88315 L .50762 .88202 L F
.524 .289 .5 r
.37591 .76268 m .37799 .76237 L .37832 .76008 L F
.483 .253 .488 r
.37832 .76008 m .37982 .76199 L .38086 .75944 L F
.37832 .76008 m .37799 .76237 L .37982 .76199 L F
.796 .686 .743 r
.55665 .79369 m .55357 .79367 L .5555 .79078 L F
.646 .611 .8 r
.55907 .79321 m .55665 .79369 L .5555 .79078 L F
.74 .637 .746 r
.55907 .79321 m .55661 .79606 L .55665 .79369 L F
.77 .649 .728 r
.61432 .77023 m .61691 .7707 L .61618 .7677 L F
.787 .618 .67 r
.61416 .77257 m .61691 .7707 L .61432 .77023 L F
.61416 .77257 m .61734 .77295 L .61691 .7707 L F
.588 .471 .687 r
.61691 .7707 m .61841 .76749 L .61618 .7677 L F
.61691 .7707 m .61924 .77029 L .61841 .76749 L F
.582 .481 .705 r
.61691 .7707 m .61946 .77257 L .61924 .77029 L F
.61691 .7707 m .61734 .77295 L .61946 .77257 L F
.572 .754 .963 r
.3565 .77518 m .3587 .77257 L .35666 .77293 L F
.387 .649 .961 r
.66848 .74832 m .6693 .74946 L .66997 .74891 L F
.656 .49 .647 r
.66796 .74823 m .66915 .74856 L .67037 .74408 L F
.668 .797 .944 r
.66613 .74915 m .66677 .74922 L .66818 .74847 L F
.656 .49 .647 r
.66818 .74847 m .66854 .7484 L .66796 .74823 L F
.37 .657 .968 r
.66848 .74832 m .66818 .74847 L .66783 .74844 L F
.668 .797 .944 r
.66783 .74855 m .66818 .74847 L .66848 .74832 L F
.66613 .74915 m .66818 .74847 L .66783 .74855 L F
.656 .49 .647 r
.66783 .74844 m .66818 .74847 L .66796 .74823 L F
.66818 .74847 m .66906 .74855 L .66854 .7484 L F
.66906 .74855 m .66915 .74856 L .66796 .74823 L F
.37 .657 .968 r
.66912 .74855 m .66915 .74856 L .66906 .74855 L F
.087 0 .376 r
.67037 .74408 m .66915 .74856 L .67168 .74516 L F
.301 0 .028 r
.66915 .74856 m .6728 .74792 L .67168 .74516 L F
.37 .657 .968 r
.66848 .74832 m .67049 .74849 L .66915 .74856 L F
.387 .649 .961 r
.66848 .74832 m .66906 .74855 L .67049 .74849 L F
.66906 .74855 m .66997 .74891 L .67007 .74883 L F
.66906 .74855 m .67007 .74883 L .67049 .74849 L F
.37 .657 .968 r
.66848 .74832 m .66906 .74855 L .66818 .74847 L F
.668 .797 .944 r
.66677 .74922 m .6693 .74946 L .66848 .74832 L F
.464 .312 .589 r
.6693 .74946 m .67123 .75071 L .67049 .74849 L F
.6693 .74946 m .66945 .7519 L .67123 .75071 L F
.654 .482 .639 r
.40914 .86419 m .40939 .86667 L .40708 .86653 L F
.465 .329 .61 r
.41071 .86147 m .40914 .86419 L .40794 .86111 L F
.41071 .86147 m .4108 .86413 L .40914 .86419 L F
.468 .359 .647 r
.4108 .86413 m .41115 .86622 L .40914 .86419 L F
.49 .361 .633 r
.41115 .86622 m .40939 .86667 L .40914 .86419 L F
0 0 0 r
.38819 .90044 m .38725 .90061 L .38929 .9 L F
.38635 .9011 m .38725 .90061 L .38819 .90044 L F
.636 .672 .867 r
.4179 .87965 m .41422 .87776 L .41648 .87844 L F
.714 .739 .871 r
.41997 .87867 m .4179 .87965 L .41648 .87844 L F
.871 .856 .824 r
.53474 .84778 m .53398 .85113 L .53483 .84831 L F
0 .558 .716 r
.53398 .85113 m .53464 .85115 L .53483 .84831 L F
.53398 .85113 m .53619 .85123 L .53464 .85115 L F
.662 .581 .753 r
.47692 .86324 m .48005 .86436 L .47867 .86305 L F
0 0 .29 r
.60161 .83559 m .60274 .83263 L .60235 .83493 L F
.156 .038 .456 r
.60235 .83493 m .60133 .83783 L .60161 .83559 L F
.611 .552 .763 r
.61309 .77813 m .61407 .77451 L .61205 .77511 L F
.61309 .77813 m .61531 .7778 L .61407 .77451 L F
.574 .409 .62 r
.61315 .78037 m .61531 .7778 L .61309 .77813 L F
.297 0 .09 r
.6424 .76426 m .64419 .76441 L .6451 .76275 L F
.242 0 .056 r
.6451 .76275 m .64615 .76376 L .64708 .76209 L F
.6451 .76275 m .64419 .76441 L .64615 .76376 L F
.603 .434 .625 r
.60163 .81198 m .60174 .81457 L .59949 .81512 L F
.598 .405 .591 r
.6039 .81186 m .60174 .81457 L .60163 .81198 L F
0 .51 .84 r
.35484 .72902 m .3571 .72961 L .35819 .73018 L F
.284 0 0 r
.3571 .72961 m .36025 .73 L .35819 .73018 L F
.204 .72 .878 r
.43852 .88816 m .44158 .88825 L .44029 .88729 L F
.523 .819 .999 r
.44158 .88825 m .44236 .88712 L .44029 .88729 L F
.44158 .88825 m .4437 .88784 L .44236 .88712 L F
.581 .201 .287 r
.45678 .82285 m .45862 .82415 L .45986 .82219 L F
.566 .182 .273 r
.45862 .82415 m .46204 .82238 L .45986 .82219 L F
.583 .901 .984 r
.39666 .89768 m .39895 .89756 L .3973 .89737 L F
.577 .934 .932 r
.3973 .89737 m .39895 .89756 L .40219 .8961 L F
.699 .567 .703 r
.40794 .86111 m .40599 .86166 L .40806 .85891 L F
.777 .673 .749 r
.52739 .84888 m .53104 .84868 L .52974 .848 L F
.768 .679 .764 r
.52974 .848 m .53104 .84868 L .53305 .84634 L F
.465 .292 .561 r
.61087 .80436 m .6128 .80151 L .61284 .8039 L F
.436 .231 .502 r
.61077 .80656 m .61087 .80436 L .61284 .8039 L F
.547 .084 .105 r
.42995 .82522 m .43183 .82632 L .4332 .8249 L F
.666 .296 .336 r
.43183 .82632 m .43528 .82486 L .4332 .8249 L F
.744 .743 .851 r
.63475 .73251 m .63598 .7338 L .63282 .73354 L F
.76 .745 .839 r
.63827 .73177 m .63598 .7338 L .63475 .73251 L F
.817 .802 .837 r
.5285 .84276 m .53139 .84339 L .53084 .84216 L F
.85 .501 .392 r
.53172 .84559 m .53139 .84339 L .5285 .84276 L F
.494 .55 .843 r
.53139 .84339 m .53261 .84001 L .53084 .84216 L F
.54 .189 .321 r
.53402 .84485 m .53139 .84339 L .53172 .84559 L F
.735 .573 .672 r
.62046 .76468 m .62153 .76751 L .62349 .76491 L F
.687 .315 .336 r
.40289 .82639 m .40065 .82465 L .40038 .82695 L F
.555 .288 .466 r
.37647 .77627 m .37603 .7779 L .37385 .77806 L F
.451 .19 .426 r
.37791 .77743 m .37647 .77627 L .37832 .77583 L F
.37791 .77743 m .37603 .7779 L .37647 .77627 L F
.596 .414 .606 r
.42584 .84522 m .42512 .8437 L .4256 .84346 L F
.69 .468 .581 r
.3587 .77257 m .36134 .77261 L .36172 .77012 L F
.399 .047 .248 r
.36134 .77261 m .3642 .77033 L .36172 .77012 L F
.659 .505 .664 r
.41032 .85857 m .40794 .86111 L .40806 .85891 L F
.754 .501 .55 r
.49373 .81131 m .49683 .80986 L .49496 .8094 L F
.525 .311 .532 r
.36196 .78813 m .35973 .79075 L .36003 .78854 L F
.907 .823 .356 r
.56337 .83862 m .56381 .83814 L .56327 .84071 L F
.957 .722 .541 r
.55859 .79767 m .55989 .79882 L .56 .79624 L F
.468 .776 .997 r
.56049 .79526 m .56204 .79598 L .56 .79624 L F
.698 .92 .587 r
.56049 .79526 m .56 .79624 L .56204 .79598 L F
.441 .669 .96 r
.36746 .73079 m .36673 .732 L .36597 .73037 L F
.36746 .73079 m .36837 .73228 L .36673 .732 L F
.716 .66 .793 r
.53586 .83779 m .53702 .8406 L .534 .84043 L F
.528 .024 .003 r
.53702 .8406 m .53798 .8421 L .53589 .84241 L F
.53702 .8406 m .53949 .84117 L .53798 .8421 L F
.78 .891 .924 r
.623 .73839 m .62022 .73877 L .62192 .73749 L F
.774 .842 .903 r
.62546 .73643 m .623 .73839 L .62192 .73749 L F
.611 .761 .95 r
.44675 .87436 m .44346 .87383 L .44589 .87337 L F
0 .476 .717 r
.44749 .87446 m .44675 .87436 L .44589 .87337 L F
.44749 .87446 m .44898 .87477 L .44675 .87436 L F
.515 .241 .438 r
.63005 .78068 m .63199 .78282 L .62978 .78239 L F
.63005 .78068 m .63209 .78025 L .63199 .78282 L F
.152 0 .147 r
.58249 .76432 m .58412 .76422 L .58481 .7621 L F
.12 0 0 r
.58249 .76432 m .58229 .76508 L .58412 .76422 L F
.658 .507 .668 r
.37351 .83608 m .37572 .83777 L .37575 .83562 L F
.37351 .83608 m .3735 .83806 L .37572 .83777 L F
.594 .76 .958 r
.40755 .88013 m .40402 .87956 L .40598 .87899 L F
.752 .744 .845 r
.40921 .87909 m .40755 .88013 L .40598 .87899 L F
.732 .676 .796 r
.52017 .83694 m .52294 .83975 L .52204 .83755 L F
.788 .766 .834 r
.52204 .83755 m .52294 .83975 L .52496 .83755 L F
.724 .989 .832 r
.58612 .77199 m .58924 .77007 L .5889 .76997 L F
.451 .881 .815 r
.59089 .76894 m .58924 .77007 L .59187 .76832 L F
.59089 .76894 m .5889 .76997 L .58924 .77007 L F
.768 .679 .764 r
.52974 .848 m .53305 .84634 L .53172 .84559 L F
.248 .751 .7 r
.51167 .88077 m .51329 .88028 L .51514 .87966 L F
.651 .66 .845 r
.55392 .83286 m .55213 .8338 L .55335 .83103 L F
.659 .505 .664 r
.41032 .85857 m .41071 .86147 L .40794 .86111 L F
.961 .853 .439 r
.56256 .81887 m .56298 .81995 L .56247 .82211 L F
.626 .529 .724 r
.38086 .75944 m .38219 .75668 L .38055 .7572 L F
.804 .752 .805 r
.63061 .73414 m .62804 .7343 L .62955 .73287 L F
.633 .727 .916 r
.63165 .73226 m .63061 .73414 L .62955 .73287 L F
.63165 .73226 m .63282 .73354 L .63061 .73414 L F
0 0 .356 r
.56247 .82211 m .56359 .825 L .56386 .82528 L F
0 0 .341 r
.56359 .825 m .5643 .8264 L .56386 .82528 L F
.56359 .825 m .56427 .82771 L .5643 .8264 L F
.676 .711 .875 r
.39425 .75214 m .396 .7545 L .39256 .75391 L F
.738 .598 .701 r
.396 .7545 m .39457 .75477 L .39256 .75391 L F
.623 .692 .893 r
.39827 .75397 m .396 .7545 L .39425 .75214 L F
.111 .632 .883 r
.56809 .84832 m .5712 .84895 L .56993 .84849 L F
.265 0 0 r
.5712 .84895 m .57156 .84949 L .56993 .84849 L F
.5712 .84895 m .5733 .8493 L .57156 .84949 L F
.399 .047 .248 r
.36134 .77261 m .3632 .77239 L .3642 .77033 L F
.025 0 .13 r
.36626 .76766 m .3642 .77033 L .36541 .76953 L F
.379 .028 .238 r
.3642 .77033 m .36519 .77189 L .36541 .76953 L F
.3642 .77033 m .3632 .77239 L .36519 .77189 L F
.694 .403 .477 r
.59863 .80335 m .59628 .80152 L .59664 .8044 L F
.557 .429 .662 r
.59664 .8044 m .59955 .80653 L .59863 .80335 L F
.59664 .8044 m .59714 .80665 L .59955 .80653 L F
.589 .455 .666 r
.41327 .86102 m .41032 .85857 L .41268 .8592 L F
.41327 .86102 m .41071 .86147 L .41032 .85857 L F
.746 .626 .726 r
.34889 .72613 m .34972 .72903 L .35123 .72586 L F
.504 .635 .912 r
.34862 .72529 m .34984 .72737 L .34793 .72558 L F
.34854 .72531 m .34793 .72558 L .34784 .7255 L F
.34862 .72529 m .34793 .72558 L .34854 .72531 L F
.578 .538 .774 r
.34744 .72512 m .34636 .72792 L .34539 .72547 L F
.34744 .72512 m .34839 .72764 L .34636 .72792 L F
.959 .724 .54 r
.3487 .72671 m .34931 .72758 L .34889 .72613 L F
.352 .73 .987 r
.34895 .72682 m .34813 .7259 L .34984 .72737 L F
.34829 .72604 m .34793 .72558 L .34984 .72737 L F
.34816 .72592 m .34807 .72581 L .34829 .72604 L F
.594 .338 .498 r
.3487 .72524 m .34882 .72525 L .34881 .72512 L F
.044 0 0 r
.34866 .72526 m .3487 .72524 L .34881 .72512 L F
.793 .735 .799 r
.34858 .72524 m .34881 .72512 L .34833 .72492 L F
.504 .635 .912 r
.3487 .72503 m .3488 .72522 L .34744 .72512 L F
.34856 .72524 m .34984 .72737 L .3475 .72518 L F
.34989 .7253 m .34989 .72553 L .34856 .72524 L F
.34887 .7253 m .34984 .72737 L .34856 .72524 L F
.34985 .72689 m .34984 .72737 L .34862 .72529 L F
.602 .72 .928 r
.35104 .72418 m .35013 .72661 L .3499 .72495 L F
.35013 .72661 m .34984 .72737 L .34986 .72636 L F
.35013 .72661 m .34986 .72636 L .3499 .72495 L F
.504 .635 .912 r
.34986 .72636 m .34984 .72737 L .34887 .7253 L F
.861 .996 .773 r
.35013 .72661 m .34895 .72682 L .34984 .72737 L F
.919 .528 .232 r
.34883 .72542 m .34967 .72669 L .34895 .72682 L F
.34881 .72512 m .34899 .72544 L .34882 .72525 L F
.504 .635 .912 r
.3499 .72495 m .34985 .72689 L .34862 .72529 L F
.919 .528 .232 r
.34904 .72561 m .35028 .7276 L .34883 .72542 L F
.34899 .72544 m .35028 .7276 L .34882 .72525 L F
.504 .635 .912 r
.34989 .72553 m .34986 .72636 L .34887 .7253 L F
.861 .996 .773 r
.35104 .72418 m .34895 .72682 L .35013 .72661 L F
.919 .528 .232 r
.34967 .72669 m .35028 .7276 L .34895 .72682 L F
.34882 .72525 m .34904 .72561 L .34883 .72542 L F
.044 0 0 r
.34807 .72581 m .34866 .72526 L .34788 .72561 L F
.34866 .72526 m .34881 .72512 L .34858 .72524 L F
.34866 .72526 m .34858 .72524 L .34788 .72561 L F
.504 .635 .912 r
.34989 .7253 m .3475 .72518 L .34744 .72512 L F
.594 .338 .498 r
.34812 .72588 m .34895 .72682 L .34882 .72525 L F
.34812 .72588 m .34882 .72525 L .3487 .72524 L F
.352 .73 .987 r
.34826 .72626 m .34839 .72764 L .3477 .72581 L F
.044 0 0 r
.34415 .72948 m .348 .72587 L .34455 .72736 L F
.348 .72587 m .34807 .72581 L .34799 .72585 L F
.348 .72587 m .34799 .72585 L .34455 .72736 L F
.352 .73 .987 r
.34895 .72682 m .34878 .72707 L .34826 .72626 L F
.34878 .72707 m .34839 .72764 L .34826 .72626 L F
.34783 .72556 m .3477 .72581 L .34744 .72512 L F
.626 .614 .819 r
.34511 .72487 m .34744 .72512 L .34539 .72547 L F
.562 .313 .497 r
.34378 .72353 m .34744 .72512 L .34511 .72487 L F
.34378 .72353 m .34579 .72381 L .34744 .72512 L F
.793 .735 .799 r
.34455 .72736 m .34784 .72563 L .34579 .72381 L F
.352 .73 .987 r
.34803 .72575 m .34744 .72512 L .34793 .72558 L F
.044 0 0 r
.34807 .72581 m .34788 .72561 L .34784 .72563 L F
.352 .73 .987 r
.348 .72587 m .3479 .72585 L .34784 .72563 L F
.3479 .72585 m .3477 .72581 L .34783 .72556 L F
.044 0 0 r
.34799 .72585 m .34784 .72563 L .34455 .72736 L F
.34807 .72581 m .34784 .72563 L .34799 .72585 L F
.793 .735 .799 r
.34784 .72563 m .34788 .72561 L .34783 .72556 L F
.352 .73 .987 r
.34813 .7259 m .348 .72587 L .34783 .72556 L F
.348 .72587 m .34784 .72563 L .34783 .72556 L F
.34813 .7259 m .34783 .72556 L .34803 .72575 L F
.34783 .72556 m .34744 .72512 L .34803 .72575 L F
.923 .584 .13 r
.34881 .72512 m .34882 .72525 L .34866 .72495 L F
.504 .635 .912 r
.3499 .72495 m .34784 .7255 L .34757 .72511 L F
.793 .735 .799 r
.34783 .72556 m .34858 .72524 L .34761 .72474 L F
.34788 .72561 m .34858 .72524 L .34783 .72556 L F
.504 .635 .912 r
.34757 .72511 m .34784 .7255 L .34744 .72512 L F
.411 .743 .993 r
.34744 .72512 m .34752 .72471 L .34579 .72381 L F
.793 .735 .799 r
.34762 .72476 m .34761 .72474 L .34579 .72381 L F
.923 .584 .13 r
.34881 .72512 m .3477 .72385 L .34579 .72381 L F
.411 .743 .993 r
.34752 .72471 m .3477 .72385 L .34579 .72381 L F
.793 .735 .799 r
.34784 .72563 m .34762 .72476 L .34579 .72381 L F
.594 .338 .498 r
.3481 .72589 m .34895 .72682 L .34812 .72588 L F
.352 .73 .987 r
.34895 .72682 m .3477 .72581 L .3481 .72589 L F
.594 .338 .498 r
.34685 .72726 m .34895 .72682 L .3481 .72589 L F
.352 .73 .987 r
.34895 .72682 m .3481 .72589 L .34813 .7259 L F
.044 0 0 r
.348 .72587 m .3487 .72524 L .34866 .72526 L F
.34415 .72948 m .34802 .72588 L .348 .72587 L F
.34802 .72588 m .3487 .72524 L .348 .72587 L F
.793 .735 .799 r
.34763 .72475 m .34833 .72492 L .34579 .72381 L F
.411 .743 .993 r
.34744 .72512 m .34844 .72505 L .34752 .72471 L F
.793 .735 .799 r
.34858 .72524 m .34844 .72505 L .34763 .72475 L F
.34844 .72505 m .34833 .72492 L .34763 .72475 L F
.411 .743 .993 r
.34752 .72471 m .3487 .72503 L .3477 .72385 L F
.34844 .72505 m .3487 .72503 L .34752 .72471 L F
.923 .584 .13 r
.34866 .72495 m .34866 .72499 L .3477 .72385 L F
.411 .743 .993 r
.3487 .72503 m .3499 .72495 L .3477 .72385 L F
.923 .584 .13 r
.34866 .72499 m .34874 .72547 L .3477 .72385 L F
.34874 .72547 m .34895 .72682 L .34863 .72606 L F
.34874 .72547 m .34863 .72606 L .3477 .72385 L F
.34882 .72525 m .34895 .72682 L .34866 .72495 L F
.504 .635 .912 r
.3499 .72495 m .34989 .7253 L .3488 .72522 L F
.3499 .72495 m .3488 .72522 L .3487 .72503 L F
.352 .73 .987 r
.34813 .7259 m .34812 .72588 L .34816 .72592 L F
.34812 .72588 m .34807 .72581 L .34816 .72592 L F
.34807 .72581 m .34793 .72558 L .34829 .72604 L F
.044 0 0 r
.34415 .72948 m .34812 .72588 L .34808 .72582 L F
.487 .131 .287 r
.34349 .72945 m .34685 .72726 L .34415 .72948 L F
.34349 .72945 m .34507 .72931 L .34685 .72726 L F
.34507 .72931 m .34555 .72927 L .34685 .72726 L F
.044 0 0 r
.34778 .72618 m .34685 .72726 L .34812 .72588 L F
.34415 .72948 m .34685 .72726 L .34778 .72618 L F
.34808 .72582 m .34812 .72588 L .3487 .72524 L F
.959 .724 .54 r
.34839 .72764 m .34972 .72903 L .34931 .72758 L F
.34839 .72764 m .34931 .72758 L .3487 .72671 L F
.565 .797 .987 r
.35028 .7276 m .34972 .72903 L .34839 .72764 L F
.35028 .7276 m .35167 .72855 L .34972 .72903 L F
.679 .4 .491 r
.61407 .77451 m .61734 .77295 L .61416 .77257 L F
.61407 .77451 m .6172 .77525 L .61734 .77295 L F
.609 .383 .549 r
.6172 .77525 m .61946 .77257 L .61734 .77295 L F
.37 0 0 r
.40717 .82726 m .40649 .82674 L .40465 .82569 L F
.40717 .82726 m .40856 .82731 L .40649 .82674 L F
.792 .688 .751 r
.61919 .75939 m .61719 .76209 L .62026 .7624 L F
.789 .697 .762 r
.61719 .76209 m .61825 .76501 L .62026 .7624 L F
.68 .534 .68 r
.61825 .76501 m .62046 .76468 L .62026 .7624 L F
.565 .522 .766 r
.60203 .81671 m .59949 .81512 L .60174 .81457 L F
.379 .307 .649 r
.48463 .87624 m .4836 .87375 L .48443 .87454 L F
.615 .377 .532 r
.48443 .87454 m .48356 .87239 L .48222 .87411 L F
.691 .37 .428 r
.48443 .87454 m .48622 .87365 L .48569 .87662 L F
.676 .668 .834 r
.48443 .87454 m .48605 .87471 L .48468 .87145 L F
.48605 .87471 m .48636 .87474 L .4863 .87463 L F
.48605 .87471 m .4863 .87463 L .48468 .87145 L F
.512 .207 .387 r
.48569 .87662 m .48603 .87472 L .48605 .87472 L F
.69 .37 .429 r
.48569 .87662 m .48636 .87474 L .48605 .87471 L F
.512 .207 .387 r
.48569 .87662 m .48605 .87472 L .48636 .87468 L F
.69 .37 .429 r
.48569 .87662 m .48605 .87471 L .48443 .87454 L F
0 .149 .692 r
.48468 .87145 m .48636 .87474 L .48627 .87324 L F
.882 .842 .379 r
.48627 .87324 m .48636 .87468 L .48569 .87662 L F
.48636 .87468 m .48636 .87474 L .48569 .87662 L F
.512 .207 .387 r
.48569 .87662 m .48636 .87468 L .48845 .87447 L F
.48603 .87472 m .48622 .87365 L .48773 .87421 L F
.48603 .87472 m .48773 .87421 L .48845 .87447 L F
.765 .255 0 r
.48468 .87145 m .48474 .87267 L .48453 .87225 L F
0 0 0 r
.48483 .87062 m .48356 .87239 L .48468 .87145 L F
.765 .255 0 r
.48468 .87145 m .48453 .87225 L .48389 .87101 L F
0 0 0 r
.48591 .86914 m .48483 .87062 L .48468 .87145 L F
.383 .359 .708 r
.66121 .76433 m .66271 .76319 L .66081 .76403 L F
.66121 .76433 m .66265 .76379 L .66271 .76319 L F
.803 .867 .425 r
.56511 .83492 m .56337 .83862 L .56428 .83655 L F
.161 .325 .781 r
.5644 .83283 m .56511 .83492 L .56539 .83312 L F
.847 .864 .415 r
.56539 .83312 m .56511 .83492 L .56428 .83655 L F
.383 0 .071 r
.54566 .82877 m .547 .82937 L .54479 .82983 L F
.54566 .82877 m .54805 .82836 L .547 .82937 L F
.385 .244 .563 r
.60905 .78829 m .61107 .78544 L .60892 .78569 L F
.60905 .78829 m .61141 .78786 L .61107 .78544 L F
.387 .08 .317 r
.60905 .78829 m .61078 .78991 L .61141 .78786 L F
.60905 .78829 m .609 .79028 L .61078 .78991 L F
.711 .664 .802 r
.62347 .75375 m .6247 .75494 L .62382 .7523 L F
.771 .663 .744 r
.62134 .75653 m .6247 .75494 L .62347 .75375 L F
.696 .882 .967 r
.49741 .88707 m .50012 .88649 L .49906 .8851 L F
.764 .907 .938 r
.49906 .8851 m .50012 .88649 L .5022 .88451 L F
.798 .991 .746 r
.59617 .82745 m .5942 .8302 L .59407 .83214 L F
.577 .332 .507 r
.50658 .81422 m .50881 .81213 L .50682 .81213 L F
.50658 .81422 m .50878 .81407 L .50881 .81213 L F
.595 .602 .829 r
.50254 .82202 m .50047 .82241 L .49933 .81949 L F
.767 .917 .938 r
.41501 .894 m .41807 .89293 L .41711 .89293 L F
.432 .715 .984 r
.41807 .89293 m .41889 .89193 L .41711 .89293 L F
.41807 .89293 m .42018 .89293 L .41889 .89193 L F
0 0 0 r
.45096 .88681 m .45457 .88558 L .45296 .8867 L F
.064 0 0 r
.45457 .88558 m .45465 .88616 L .45296 .8867 L F
.45457 .88558 m .45649 .88516 L .45465 .88616 L F
.603 .944 .933 r
.5887 .79112 m .58786 .79097 L .58957 .79004 L F
.58957 .79004 m .58786 .79097 L .5887 .79112 L F
0 0 0 r
.51081 .87463 m .51058 .87447 L .50957 .87527 L F
.249 0 0 r
.51058 .87447 m .51185 .87461 L .51041 .87434 L F
.542 .908 .96 r
.51281 .87362 m .51185 .87461 L .51058 .87447 L F
0 0 0 r
.51281 .87362 m .51058 .87447 L .51081 .87463 L F
.249 0 0 r
.51058 .87447 m .51041 .87434 L .50863 .87401 L F
.569 .939 .865 r
.51281 .87362 m .51442 .87325 L .51185 .87461 L F
.614 .938 .954 r
.57484 .83985 m .57235 .84111 L .57318 .83999 L F
.571 .406 .619 r
.51433 .82481 m .51246 .82718 L .51205 .82526 L F
.271 .735 .948 r
.47605 .83762 m .47482 .83716 L .47396 .83763 L F
.58 .127 .14 r
.47492 .83915 m .47396 .83763 L .47482 .83716 L F
.47492 .83915 m .47266 .83921 L .47396 .83763 L F
.751 .986 .9 r
.56904 .83804 m .57168 .83627 L .5696 .83677 L F
.917 .91 .798 r
.5696 .83677 m .57168 .83627 L .57136 .83422 L F
.493 0 0 r
.56652 .84751 m .56809 .84832 L .56681 .84807 L F
.83 .773 .265 r
.66768 .71792 m .66745 .71867 L .66781 .71812 L F
.686 .627 .785 r
.63308 .74632 m .63619 .74694 L .63508 .74395 L F
.724 .648 .772 r
.63508 .74395 m .63619 .74694 L .6384 .74442 L F
.665 .569 .737 r
.60203 .81671 m .60308 .8207 L .60027 .82071 L F
.637 .353 .472 r
.60027 .82071 m .60304 .82234 L .60053 .82232 L F
.60027 .82071 m .60308 .8207 L .60304 .82234 L F
.761 .76 .851 r
.63203 .74389 m .62972 .74614 L .63308 .74632 L F
.773 .736 .819 r
.62972 .74614 m .63105 .74732 L .63308 .74632 L F
.768 .763 .848 r
.63203 .74389 m .63308 .74632 L .63508 .74395 L F
.639 .542 .729 r
.45958 .87211 m .45726 .8727 L .4562 .8692 L F
.755 .748 .846 r
.64266 .72857 m .64335 .73095 L .64024 .73079 L F
.743 .741 .85 r
.64573 .72928 m .64335 .73095 L .64266 .72857 L F
.586 .135 .147 r
.60448 .76475 m .60108 .7652 L .60216 .76534 L F
.148 0 0 r
.6735 .74929 m .67677 .74824 L .67475 .74963 L F
.956 .842 .691 r
.6735 .74929 m .67475 .74963 L .67275 .75011 L F
.887 .661 .591 r
.54822 .79883 m .54621 .79832 L .54628 .79603 L F
.895 .575 .435 r
.54822 .79883 m .54682 .80024 L .54621 .79832 L F
.54822 .79883 m .54883 .80134 L .54682 .80024 L F
.196 0 .056 r
.48164 .86046 m .48398 .85886 L .48272 .86092 L F
.718 .352 .355 r
.48398 .85886 m .48587 .8611 L .48272 .86092 L F
.517 .342 .583 r
.48594 .85852 m .48587 .8611 L .48398 .85886 L F
.502 .809 1 r
.3643 .72954 m .36356 .73068 L .36224 .72972 L F
.3643 .72954 m .36597 .73037 L .36356 .73068 L F
.68 .541 .689 r
.3893 .87416 m .39001 .8778 L .38682 .87636 L F
.959 .819 .663 r
.57641 .77983 m .57744 .78042 L .57819 .77838 L F
.723 .739 .864 r
.57641 .7761 m .57819 .77838 L .5798 .77735 L F
.722 .663 .791 r
.61504 .76468 m .61825 .76501 L .61719 .76209 L F
.737 .599 .703 r
.61504 .76468 m .61618 .7677 L .61825 .76501 L F
.7 .545 .674 r
.61618 .7677 m .61841 .76749 L .61825 .76501 L F
.697 .554 .688 r
.61841 .76749 m .62046 .76468 L .61825 .76501 L F
.038 .267 .764 r
.55841 .81174 m .55906 .81107 L .55695 .80905 L F
.034 .26 .759 r
.55841 .81174 m .56064 .81407 L .55906 .81107 L F
.992 .867 .526 r
.57549 .82919 m .57677 .82648 L .57648 .82703 L F
.57549 .82919 m .57609 .83024 L .57677 .82648 L F
.643 .571 .759 r
.5171 .83756 m .51771 .8403 L .52017 .83694 L F
0 0 0 r
.48591 .86914 m .48468 .87145 L .48491 .86866 L F
.87 .945 .862 r
.4882 .86662 m .48591 .86914 L .48491 .86866 L F
.7 .433 .517 r
.4074 .86883 m .4038 .86685 L .40708 .86653 L F
.642 .404 .543 r
.40939 .86667 m .4074 .86883 L .40708 .86653 L F
.466 .809 .999 r
.36892 .74818 m .37024 .74885 L .37246 .74845 L F
.586 .349 .523 r
.41542 .8562 m .41542 .85905 L .41268 .8592 L F
.563 .331 .521 r
.41753 .85844 m .41542 .8562 L .41774 .85573 L F
.41753 .85844 m .41542 .85905 L .41542 .8562 L F
.551 .485 .735 r
.5653 .79601 m .56743 .79606 L .56725 .79319 L F
.613 .576 .789 r
.50862 .8367 m .51063 .83511 L .50833 .83539 L F
.50862 .8367 m .51105 .83639 L .51063 .83511 L F
.624 .654 .859 r
.39336 .87947 m .39001 .8778 L .39212 .8771 L F
.628 .653 .856 r
.39534 .87912 m .39336 .87947 L .39212 .8771 L F
.052 .178 .678 r
.57072 .84038 m .56904 .83804 L .5696 .83677 L F
.67 .544 .702 r
.62151 .76994 m .62454 .77186 L .62475 .77042 L F
.506 .213 .402 r
.62685 .77164 m .62475 .77042 L .62454 .77186 L F
.62685 .77164 m .62703 .77006 L .62475 .77042 L F
.461 .335 .622 r
.53877 .81651 m .5375 .81748 L .53683 .81452 L F
.618 .373 .525 r
.38084 .83555 m .383 .83511 L .38323 .83296 L F
.699 .538 .666 r
.383 .83511 m .38517 .83241 L .38323 .83296 L F
.954 .754 .594 r
.36626 .76766 m .36541 .76953 L .36486 .76696 L F
.63 .894 .986 r
.36805 .76663 m .36626 .76766 L .36649 .76692 L F
.579 .847 .995 r
.36649 .76692 m .36626 .76766 L .36486 .76696 L F
.24 .09 .467 r
.36541 .76953 m .36649 .76692 L .36626 .76766 L F
.501 .037 .085 r
.65513 .72751 m .65331 .72657 L .65292 .72775 L F
.65513 .72751 m .65609 .72644 L .65331 .72657 L F
.494 .098 .218 r
.4727 .81989 m .47455 .82069 L .47487 .81971 L F
.4727 .81989 m .47143 .82178 L .47455 .82069 L F
0 0 0 r
.58481 .7621 m .58614 .76166 L .58657 .76117 L F
.381 .029 .237 r
.58481 .7621 m .58616 .76368 L .58614 .76166 L F
.58481 .7621 m .58412 .76422 L .58616 .76368 L F
.97 .795 .61 r
.50068 .81179 m .50024 .8142 L .50143 .81457 L F
.346 .725 .985 r
.50226 .81384 m .50143 .81457 L .50024 .8142 L F
.50226 .81384 m .50333 .81463 L .50143 .81457 L F
.948 .66 .458 r
.59337 .81444 m .59464 .81674 L .59357 .81655 L F
.125 .319 .788 r
.59337 .81444 m .59464 .81674 L .59568 .81629 L F
0 0 .396 r
.59464 .81674 m .59557 .81863 L .59568 .81629 L F
.59464 .81674 m .59516 .81973 L .59557 .81863 L F
.493 .111 .244 r
.48845 .87447 m .48933 .87263 L .49221 .87317 L F
.646 .469 .63 r
.66566 .74724 m .66783 .74844 L .66809 .74409 L F
.656 .49 .647 r
.66783 .74844 m .67037 .74408 L .66809 .74409 L F
0 .181 .705 r
.56053 .81498 m .56168 .81656 L .56064 .81407 L F
.365 .03 .257 r
.67124 .75949 m .67068 .76153 L .66866 .76214 L F
.256 0 .217 r
.67308 .75933 m .67068 .76153 L .67124 .75949 L F
.196 0 .056 r
.48164 .86046 m .48253 .85825 L .48109 .85855 L F
.48164 .86046 m .48272 .86092 L .48253 .85825 L F
.445 .077 .243 r
.4562 .8692 m .45307 .87169 L .45497 .87118 L F
.34 .76 .976 r
.4575 .86861 m .45866 .86926 L .45629 .8692 L F
.639 .542 .729 r
.45958 .87211 m .4562 .8692 L .45866 .86926 L F
.467 .136 .321 r
.45787 .86879 m .45837 .87056 L .45821 .86836 L F
0 0 .231 r
.45787 .86861 m .4575 .86861 L .45695 .87067 L F
0 0 0 r
.4575 .86861 m .45497 .87118 L .45695 .87067 L F
.133 0 0 r
.45695 .87067 m .45497 .87118 L .45347 .87233 L F
.842 .938 .888 r
.46042 .86682 m .45866 .86926 L .4575 .86861 L F
.46042 .86682 m .4575 .86861 L .45735 .86591 L F
0 0 .231 r
.45831 .86764 m .45695 .87067 L .45821 .86836 L F
.133 0 0 r
.45695 .87067 m .45347 .87233 L .45536 .87201 L F
.467 .136 .321 r
.45536 .87201 m .45821 .86836 L .45695 .87067 L F
.45536 .87201 m .45787 .8708 L .45787 .86879 L F
.45787 .8708 m .45837 .87056 L .45787 .86879 L F
0 0 .231 r
.45798 .86838 m .45787 .86843 L .45787 .86861 L F
.45787 .86843 m .4575 .86861 L .45787 .86861 L F
.45831 .86764 m .4575 .86861 L .45798 .86838 L F
.34 .76 .976 r
.4575 .86861 m .45629 .8692 L .4562 .8692 L F
0 0 0 r
.4575 .86861 m .4562 .8692 L .45497 .87118 L F
.656 .59 .769 r
.48921 .84767 m .49039 .84958 L .49258 .84863 L F
.487 .566 .861 r
.57433 .82478 m .57115 .82228 L .5732 .82419 L F
.134 .288 .757 r
.5732 .82419 m .57115 .82228 L .5723 .82185 L F
.541 .351 .573 r
.39705 .75977 m .39695 .76198 L .39493 .76235 L F
.483 .243 .474 r
.39655 .76352 m .39493 .76235 L .39695 .76198 L F
.39655 .76352 m .3943 .7638 L .39493 .76235 L F
.628 .898 .986 r
.42018 .89293 m .4232 .89262 L .42216 .89224 L F
.676 .926 .972 r
.42306 .89162 m .4232 .89262 L .42529 .89138 L F
.42306 .89162 m .42216 .89224 L .4232 .89262 L F
.898 .759 .699 r
.64671 .7365 m .6479 .7391 L .64877 .73619 L F
.338 .558 .916 r
.35542 .72764 m .35484 .72902 L .35363 .72802 L F
.35542 .72764 m .3571 .72961 L .35484 .72902 L F
.325 .547 .912 r
.37858 .75 m .37906 .74873 L .37786 .74869 L F
.37858 .75 m .38143 .7514 L .37906 .74873 L F
.427 .251 .538 r
.41291 .81976 m .4112 .82293 L .41275 .82204 L F
.41291 .81976 m .4112 .82293 L .41275 .82204 L F
.589 .492 .712 r
.39128 .87378 m .38898 .87192 L .39117 .87164 L F
.39128 .87378 m .3893 .87416 L .38898 .87192 L F
.539 .761 .979 r
.41263 .82662 m .41206 .82811 L .41056 .82729 L F
.41263 .82662 m .4141 .82776 L .41206 .82811 L F
.446 0 .034 r
.46204 .82238 m .4641 .82241 L .4653 .82172 L F
.646 .234 .248 r
.4653 .82172 m .4641 .82241 L .46728 .82235 L F
.738 .845 .93 r
.62453 .74863 m .62794 .74919 L .62675 .74634 L F
.62453 .74863 m .62569 .74936 L .62794 .74919 L F
.831 .829 .846 r
.62675 .74634 m .62794 .74919 L .62972 .74614 L F
.763 .724 .816 r
.62794 .74919 m .63105 .74732 L .62972 .74614 L F
.475 .895 .881 r
.58365 .77312 m .58612 .77199 L .58437 .77283 L F
.581 .476 .698 r
.39212 .8771 m .3893 .87416 L .39128 .87378 L F
.39212 .8771 m .39001 .8778 L .3893 .87416 L F
.523 .277 .484 r
.38092 .77278 m .38021 .77558 L .37832 .77583 L F
.558 .31 .496 r
.38267 .77455 m .38092 .77278 L .38297 .77246 L F
.38267 .77455 m .38021 .77558 L .38092 .77278 L F
.659 .699 .876 r
.53045 .82292 m .52762 .82248 L .52967 .82205 L F
.406 .02 .191 r
.52937 .82447 m .53249 .82226 L .53045 .82292 L F
.573 .735 .952 r
.3721 .73311 m .36837 .73228 L .37085 .73069 L F
.499 .497 .786 r
.37304 .72996 m .3721 .73311 L .37085 .73069 L F
.37304 .72996 m .37408 .7332 L .3721 .73311 L F
.752 .744 .845 r
.40921 .87909 m .40598 .87899 L .40809 .87689 L F
.71 .731 .867 r
.41151 .87747 m .40921 .87909 L .40809 .87689 L F
.57 .307 .478 r
.38791 .76789 m .38752 .76984 L .38535 .76997 L F
.506 .249 .459 r
.38995 .76755 m .38752 .76984 L .38791 .76789 L F
.567 .183 .273 r
.44151 .84046 m .44068 .84232 L .43899 .84187 L F
.612 .3 .418 r
.44415 .83973 m .44068 .84232 L .44151 .84046 L F
.623 .493 .684 r
.39904 .75717 m .39934 .75969 L .39705 .75977 L F
.527 .34 .571 r
.39889 .76158 m .39695 .76198 L .39705 .75977 L F
.595 .337 .496 r
.39934 .75969 m .39889 .76158 L .39705 .75977 L F
.479 .2 .412 r
.37603 .7779 m .37349 .78013 L .37385 .77806 L F
.183 .423 .857 r
.49241 .86816 m .49168 .86907 L .48999 .86666 L F
.235 .5 .901 r
.49311 .86916 m .49168 .86907 L .49241 .86816 L F
.542 .422 .665 r
.49417 .87179 m .49168 .86907 L .49311 .86916 L F
.612 .861 .506 r
.49691 .81368 m .49491 .81616 L .49615 .81475 L F
.744 .651 .757 r
.49491 .81616 m .49691 .81368 L .49615 .81475 L F
0 0 .262 r
.47724 .84047 m .47829 .83728 L .47605 .83762 L F
.47724 .84047 m .47806 .83974 L .47829 .83728 L F
.605 .271 .377 r
.47966 .84069 m .47867 .84213 L .47724 .84047 L F
.829 .704 .727 r
.47867 .84213 m .47806 .83974 L .47724 .84047 L F
.236 .212 .627 r
.52043 .82717 m .52042 .82485 L .52076 .82478 L F
.707 .632 .771 r
.61082 .76767 m .61313 .76773 L .61182 .76412 L F
.711 .548 .666 r
.61092 .77009 m .61313 .76773 L .61082 .76767 L F
.61092 .77009 m .61432 .77023 L .61313 .76773 L F
.754 .657 .754 r
.61182 .76412 m .61313 .76773 L .61504 .76468 L F
.696 .578 .719 r
.61313 .76773 m .61618 .7677 L .61504 .76468 L F
.695 .541 .674 r
.61313 .76773 m .61432 .77023 L .61618 .7677 L F
.304 0 .265 r
.65444 .75713 m .65532 .75806 L .65694 .7575 L F
.65532 .75806 m .65574 .75849 L .65651 .75785 L F
.65532 .75806 m .65651 .75785 L .65694 .7575 L F
.809 .772 .818 r
.65236 .75805 m .65296 .75845 L .65563 .756 L F
.65296 .75845 m .65405 .75919 L .65455 .75819 L F
.304 0 .265 r
.65444 .75713 m .65405 .75919 L .65574 .75849 L F
.589 .261 .381 r
.65694 .7575 m .65751 .75646 L .65444 .75713 L F
0 0 .067 r
.65563 .756 m .65405 .75919 L .65444 .75713 L F
.809 .772 .818 r
.65296 .75845 m .65455 .75819 L .65563 .756 L F
.691 .158 0 r
.57648 .82703 m .57433 .82478 L .5732 .82419 L F
.089 0 0 r
.37313 .76456 m .37458 .76425 L .37591 .76268 L F
.338 0 .058 r
.37591 .76268 m .3767 .76378 L .37799 .76237 L F
.37591 .76268 m .37458 .76425 L .3767 .76378 L F
.51 .348 .597 r
.36714 .75977 m .36719 .76228 L .36904 .76169 L F
.36714 .75977 m .36719 .76228 L .36904 .76169 L F
.473 .066 .186 r
.63964 .76522 m .64194 .76503 L .6424 .76426 L F
.297 0 .09 r
.6424 .76426 m .64194 .76503 L .64419 .76441 L F
.573 .038 0 r
.538 .83202 m .53989 .83268 L .53663 .83219 L F
.916 .76 .673 r
.53728 .83001 m .538 .83202 L .53663 .83219 L F
.73 .454 .51 r
.43313 .84888 m .43234 .85062 L .43053 .84826 L F
.684 .401 .488 r
.43565 .85043 m .43313 .84888 L .43468 .84779 L F
.43565 .85043 m .43234 .85062 L .43313 .84888 L F
.991 .881 .607 r
.58086 .77418 m .58152 .77496 L .58206 .77278 L F
0 0 0 r
.58437 .77283 m .58086 .77418 L .58206 .77278 L F
.675 .315 .355 r
.39086 .8323 m .39262 .83237 L .39076 .83068 L F
.587 .344 .515 r
.39262 .83237 m .39282 .83013 L .39076 .83068 L F
.137 0 .374 r
.60235 .83493 m .60274 .83263 L .6044 .83194 L F
.535 .351 .579 r
.65751 .75646 m .65849 .75549 L .65906 .7542 L F
.487 .089 .211 r
.65849 .75549 m .66188 .7545 L .65906 .7542 L F
.378 .38 .735 r
.57061 .78247 m .5722 .7825 L .57139 .78066 L F
.64 .462 .627 r
.3711 .84055 m .37348 .8404 L .3735 .83806 L F
.655 .475 .628 r
.3735 .83806 m .37578 .84022 L .37572 .83777 L F
.3735 .83806 m .37348 .8404 L .37578 .84022 L F
.289 .787 .78 r
.63619 .76603 m .63964 .76522 L .63759 .76435 L F
.741 .729 .84 r
.59187 .76832 m .59482 .76793 L .59359 .76743 L F
.695 .412 .49 r
.5957 .76742 m .59359 .76743 L .59482 .76793 L F
.697 .554 .688 r
.61841 .76749 m .62153 .76751 L .62046 .76468 L F
.579 .117 .122 r
.55989 .79882 m .56196 .79934 L .56325 .79866 L F
.21 0 0 r
.5645 .79904 m .56325 .79866 L .56196 .79934 L F
.5645 .79904 m .56515 .7992 L .56325 .79866 L F
.575 .644 .881 r
.34636 .72792 m .34839 .72764 L .3467 .72846 L F
.711 .549 .667 r
.60876 .77059 m .61092 .77009 L .61082 .76767 L F
.707 .632 .771 r
.61082 .76767 m .61182 .76412 L .60985 .76467 L F
.375 .133 .415 r
.65899 .75699 m .65751 .75646 L .65694 .7575 L F
.65899 .75699 m .65849 .75549 L .65751 .75646 L F
.163 .557 .93 r
.43338 .8743 m .43463 .87547 L .43251 .87494 L F
.715 .944 .956 r
.41718 .82727 m .41791 .82599 L .41914 .82688 L F
.41718 .82727 m .41594 .827 L .41791 .82599 L F
.44 .497 .821 r
.49781 .83669 m .49578 .83681 L .49427 .83532 L F
.49781 .83669 m .49765 .83725 L .49578 .83681 L F
.046 0 0 r
.64831 .76964 m .65137 .76736 L .65032 .76873 L F
.37 0 0 r
.65137 .76736 m .65241 .76845 L .65032 .76873 L F
.65137 .76736 m .65355 .76723 L .65241 .76845 L F
.934 .678 .201 r
.57274 .78389 m .57253 .78517 L .5722 .7825 L F
0 0 .054 r
.57465 .78253 m .57274 .78389 L .57428 .78431 L F
.57465 .78253 m .57253 .78517 L .57274 .78389 L F
.596 .414 .606 r
.42584 .84522 m .42383 .84589 L .42512 .8437 L F
.748 .776 .876 r
.60271 .82397 m .60411 .82494 L .60093 .82475 L F
.786 .689 .757 r
.60411 .82494 m .60215 .82778 L .60093 .82475 L F
.662 .514 .673 r
.60411 .82494 m .60482 .82721 L .60215 .82778 L F
.602 .599 .821 r
.60508 .82176 m .60411 .82494 L .60271 .82397 L F
.60508 .82176 m .60654 .82468 L .60411 .82494 L F
.349 .171 .493 r
.60654 .82468 m .60482 .82721 L .60411 .82494 L F
.643 .386 .515 r
.4038 .86685 m .40216 .86883 L .40237 .86655 L F
.4038 .86685 m .40376 .86887 L .40216 .86883 L F
.7 .433 .517 r
.4074 .86883 m .40376 .86887 L .4038 .86685 L F
.815 .662 .693 r
.43053 .84826 m .42876 .84806 L .42935 .84576 L F
.717 .529 .635 r
.43234 .85062 m .42876 .84806 L .43053 .84826 L F
.732 .564 .665 r
.58146 .80917 m .5822 .80736 L .57822 .80659 L F
.758 .995 .833 r
.61606 .7425 m .61389 .74437 L .6146 .74298 L F
.76 .988 .764 r
.61389 .74437 m .61225 .74531 L .6146 .74298 L F
.51 .912 .891 r
.42793 .89084 m .43078 .88998 L .4298 .88988 L F
.613 .907 .983 r
.43078 .88998 m .43114 .88893 L .4298 .88988 L F
.43078 .88998 m .43236 .88931 L .43114 .88893 L F
.477 .293 .551 r
.6128 .80151 m .61474 .79887 L .61444 .80099 L F
.41 .244 .543 r
.61284 .8039 m .6128 .80151 L .61444 .80099 L F
.71 .448 .527 r
.38798 .83457 m .38764 .83157 L .38517 .83241 L F
.562 .368 .575 r
.3901 .83446 m .38764 .83157 L .38798 .83457 L F
.3901 .83446 m .39086 .8323 L .38764 .83157 L F
.035 .579 .842 r
.53451 .80594 m .5364 .80622 L .53765 .80663 L F
.499 0 0 r
.53877 .80764 m .53765 .80663 L .5364 .80622 L F
.53877 .80764 m .54002 .80815 L .53765 .80663 L F
.473 .839 .992 r
.43718 .87472 m .43823 .87509 L .43567 .87558 L F
.87 .945 .862 r
.4882 .86662 m .48491 .86866 L .48689 .86828 L F
.45 .043 .175 r
.48906 .86834 m .4882 .86662 L .48689 .86828 L F
.48906 .86834 m .48999 .86666 L .4882 .86662 L F
.609 .313 .443 r
.54409 .83796 m .546 .8359 L .54574 .83749 L F
.191 0 0 r
.546 .8359 m .54739 .83629 L .54574 .83749 L F
.029 .599 .758 r
.54739 .83629 m .54961 .83633 L .54717 .83623 L F
.54739 .83629 m .54717 .83623 L .5464 .8362 L F
.191 0 0 r
.546 .8359 m .54774 .83638 L .54739 .83629 L F
.54774 .83638 m .54878 .83667 L .54739 .83629 L F
.705 .659 .802 r
.56085 .79073 m .56208 .79368 L .55907 .79321 L F
.468 .776 .997 r
.56049 .79526 m .55907 .79321 L .56208 .79368 L F
.56049 .79526 m .56208 .79368 L .56119 .79362 L F
.978 .732 .494 r
.56085 .79073 m .56119 .79362 L .56208 .79368 L F
.68 .343 .398 r
.43528 .82486 m .43726 .8269 L .43861 .82472 L F
.63 .285 .368 r
.43861 .82472 m .43726 .8269 L .44035 .82637 L F
.669 .269 .278 r
.43861 .82472 m .44035 .82637 L .44071 .82529 L F
.461 .311 .59 r
.52939 .8195 m .52967 .82205 L .52762 .82248 L F
.682 .638 .799 r
.60093 .82475 m .60215 .82778 L .59895 .82709 L F
.781 .644 .71 r
.47239 .87223 m .47561 .87141 L .47628 .86939 L F
.553 .399 .626 r
.47628 .86939 m .47561 .87141 L .47766 .87115 L F
.978 .909 .664 r
.47561 .87141 m .47628 .86939 L .47766 .87115 L F
.674 .453 .578 r
.40237 .86655 m .39838 .86896 L .39846 .86663 L F
.40237 .86655 m .40216 .86883 L .39838 .86896 L F
.641 .762 .936 r
.51557 .834 m .51667 .83524 L .5189 .83469 L F
.63 .505 .692 r
.51667 .83524 m .52017 .83694 L .5189 .83469 L F
.51667 .83524 m .5171 .83756 L .52017 .83694 L F
0 0 .339 r
.57284 .81635 m .57283 .8172 L .57197 .81448 L F
.57284 .81635 m .57197 .81448 L .57141 .8135 L F
.593 .772 .965 r
.38706 .74161 m .38495 .74207 L .38378 .74102 L F
.687 .559 .705 r
.61094 .78077 m .61098 .7832 L .61315 .78037 L F
.547 .555 .814 r
.43416 .84422 m .43112 .8431 L .43355 .84387 L F
0 0 0 r
.53013 .83604 m .52867 .83787 L .52945 .83722 L F
.452 .006 .098 r
.53013 .83604 m .52945 .83722 L .52737 .83715 L F
.871 .871 .427 r
.5302 .83518 m .52945 .83722 L .53013 .83604 L F
0 0 0 r
.53013 .83604 m .53108 .83617 L .53282 .83606 L F
.53013 .83604 m .52945 .83722 L .53108 .83617 L F
.248 0 0 r
.45649 .88516 m .45956 .88477 L .45876 .88515 L F
0 0 0 r
.46064 .88453 m .45956 .88477 L .46153 .88429 L F
.46064 .88453 m .46153 .88429 L .46346 .88383 L F
.46064 .88453 m .46346 .88383 L .46257 .88401 L F
.46158 .88428 m .46064 .88453 L .46257 .88401 L F
.45876 .88515 m .45935 .88487 L .46064 .88453 L F
.268 .768 .73 r
.4571 .88555 m .45876 .88515 L .46064 .88453 L F
0 0 0 r
.45703 .88555 m .46064 .88453 L .46158 .88428 L F
.45935 .88487 m .45956 .88477 L .46064 .88453 L F
.487 .089 .211 r
.65849 .75549 m .66115 .7564 L .66188 .7545 L F
.608 .25 .337 r
.66115 .7564 m .66444 .75437 L .66188 .7545 L F
.788 .724 .792 r
.44346 .87383 m .44111 .87634 L .44012 .87405 L F
.583 .445 .659 r
.50833 .83539 m .51018 .83257 L .50791 .83286 L F
.50833 .83539 m .51063 .83511 L .51018 .83257 L F
.433 .093 .288 r
.62974 .76947 m .63174 .76911 L .63235 .7677 L F
.209 0 .031 r
.63174 .76911 m .6345 .7673 L .63235 .7677 L F
.703 .542 .668 r
.60884 .78337 m .60892 .78569 L .61098 .7832 L F
.437 .839 .64 r
.49539 .87548 m .49272 .8772 L .4947 .87652 L F
.417 .024 .183 r
.49658 .8765 m .49539 .87548 L .4947 .87652 L F
.49658 .8765 m .49734 .87571 L .49539 .87548 L F
.455 .63 .929 r
.67806 .74342 m .67616 .7434 L .67489 .74134 L F
.692 .827 .947 r
.42558 .87764 m .42207 .87752 L .42405 .87694 L F
.65 .867 .981 r
.42738 .87681 m .42558 .87764 L .42405 .87694 L F
.561 .352 .554 r
.60609 .80929 m .60821 .81122 L .60604 .81158 L F
.60609 .80929 m .60828 .809 L .60821 .81122 L F
.621 .428 .599 r
.60892 .78569 m .61107 .78544 L .61098 .7832 L F
.679 .547 .698 r
.61315 .78037 m .61098 .7832 L .61272 .78305 L F
.563 .334 .526 r
.61107 .78544 m .61272 .78305 L .61098 .7832 L F
.489 0 0 r
.37617 .73056 m .37933 .73156 L .37734 .73194 L F
.83 .533 0 r
.56327 .84071 m .56407 .84348 L .56434 .84278 L F
0 .005 .551 r
.56407 .84348 m .56472 .84577 L .56434 .84278 L F
.589 .193 .26 r
.45648 .82382 m .45862 .82415 L .45678 .82285 L F
.523 .101 .182 r
.44035 .82637 m .44385 .82477 L .44071 .82529 L F
.44035 .82637 m .44247 .82644 L .44385 .82477 L F
.281 0 0 r
.44247 .82644 m .44599 .82509 L .44385 .82477 L F
.406 .073 .284 r
.63479 .7783 m .63413 .77975 L .63209 .78025 L F
.195 0 .174 r
.63587 .77946 m .63479 .7783 L .63659 .77754 L F
.63587 .77946 m .63413 .77975 L .63479 .7783 L F
.808 .678 .721 r
.5733 .80712 m .57494 .80395 L .57187 .80378 L F
.349 .816 .915 r
.53148 .81638 m .53285 .81574 L .53343 .81426 L F
.53148 .81638 m .52999 .81625 L .53285 .81574 L F
.245 .459 .87 r
.53148 .81638 m .53285 .81574 L .52999 .81625 L F
.53148 .81638 m .53388 .81762 L .53285 .81574 L F
0 0 .321 r
.57136 .83422 m .57325 .83257 L .57225 .83297 L F
.188 .692 .908 r
.57325 .83257 m .57457 .83227 L .57225 .83297 L F
.57325 .83257 m .57556 .83263 L .57457 .83227 L F
.842 .877 .867 r
.54127 .83545 m .53782 .83709 L .54027 .83549 L F
.46 .888 .88 r
.54229 .83471 m .54127 .83545 L .54027 .83549 L F
.643 .471 .636 r
.3951 .87175 m .39128 .87378 L .39117 .87164 L F
.73 .638 .756 r
.60876 .77059 m .60903 .77241 L .61092 .77009 L F
.471 .277 .535 r
.61092 .77009 m .60903 .77241 L .61089 .77227 L F
.61092 .77009 m .60903 .77241 L .61089 .77227 L F
.492 .539 .833 r
.60903 .77241 m .61205 .77511 L .61089 .77227 L F
.714 .739 .871 r
.41997 .87867 m .41648 .87844 L .41863 .87709 L F
.673 .782 .931 r
.42207 .87752 m .41997 .87867 L .41863 .87709 L F
.453 .325 .616 r
.52867 .83787 m .5303 .84038 L .52945 .83722 L F
.52867 .83787 m .52846 .84044 L .5303 .84038 L F
.771 .666 .747 r
.68133 .73651 m .68307 .73886 L .6799 .73848 L F
.73 .342 .316 r
.6799 .73848 m .68307 .73886 L .68209 .74026 L F
0 .057 .606 r
.68299 .73843 m .68307 .73886 L .68133 .73651 L F
.828 .91 .508 r
.68209 .74026 m .68307 .73886 L .68299 .73843 L F
.685 .877 .971 r
.40417 .89516 m .4073 .89495 L .40591 .89447 L F
.593 .129 .122 r
.40944 .89439 m .40591 .89447 L .4073 .89495 L F
.148 0 0 r
.6735 .74929 m .67618 .74883 L .67677 .74824 L F
.471 .122 .292 r
.6766 .74675 m .67618 .74883 L .6735 .74929 L F
.506 .427 .702 r
.67806 .74342 m .67857 .74658 L .6766 .74675 L F
.515 .434 .702 r
.67857 .74658 m .67677 .74824 L .6766 .74675 L F
.761 .931 .942 r
.5175 .82031 m .51705 .82202 L .51848 .81943 L F
.5175 .82031 m .51541 .82173 L .51705 .82202 L F
.786 .651 .713 r
.5152 .82446 m .51705 .82202 L .51541 .82173 L F
.695 .757 .899 r
.51888 .82312 m .51769 .82407 L .51705 .82202 L F
.51769 .82407 m .51684 .82474 L .51695 .82337 L F
.51769 .82407 m .51695 .82337 L .51705 .82202 L F
.685 .485 .609 r
.51684 .82474 m .51439 .82717 L .51433 .82481 L F
.51684 .82474 m .51716 .82739 L .51439 .82717 L F
.738 .522 .601 r
.52043 .82717 m .51716 .82739 L .51684 .82474 L F
.72 .304 .257 r
.5152 .82446 m .5174 .82639 L .51926 .82554 L F
.51853 .82485 m .51926 .82554 L .52031 .82507 L F
.5152 .82446 m .51926 .82554 L .51853 .82485 L F
.786 .651 .713 r
.5152 .82446 m .51888 .82312 L .51705 .82202 L F
.595 .327 .48 r
.50172 .83928 m .50061 .84257 L .49842 .84265 L F
.447 .63 .932 r
.50342 .83919 m .50371 .83951 L .50172 .83928 L F
.50342 .83919 m .50172 .83928 L .5015 .83935 L F
.642 .407 .548 r
.50371 .83951 m .50061 .84257 L .50172 .83928 L F
.398 .473 .821 r
.48708 .87866 m .485 .8782 L .48463 .87624 L F
.385 .456 .811 r
.38254 .73801 m .38214 .74063 L .38082 .73775 L F
.38254 .73801 m .38378 .74102 L .38214 .74063 L F
.621 .429 .601 r
.61924 .77029 m .62153 .76751 L .61841 .76749 L F
.482 .663 .942 r
.50119 .8366 m .5015 .83935 L .49896 .83676 L F
.50119 .8366 m .50342 .83919 L .5015 .83935 L F
.64 .512 .691 r
.37575 .83562 m .37794 .83754 L .37781 .83516 L F
.697 .552 .686 r
.37794 .83754 m .38084 .83555 L .37781 .83516 L F
.667 .48 .622 r
.371 .84287 m .37348 .8404 L .3711 .84055 L F
.533 .479 .741 r
.39425 .75214 m .39256 .75391 L .39231 .7521 L F
0 0 0 r
.58225 .84926 m .58263 .84929 L .58067 .84943 L F
.58225 .84926 m .58437 .84902 L .58263 .84929 L F
.781 .709 .784 r
.63924 .7406 m .63722 .74162 L .64056 .74174 L F
.785 .686 .755 r
.63722 .74162 m .6384 .74442 L .64056 .74174 L F
.767 .71 .798 r
.63924 .7406 m .64056 .74174 L .64273 .73947 L F
.139 .451 .882 r
.39558 .89733 m .39587 .8975 L .39578 .89627 L F
.676 .971 .914 r
.39266 .89922 m .39666 .89768 L .39558 .89733 L F
.249 .734 .927 r
.39558 .89733 m .39666 .89768 L .3973 .89737 L F
.39558 .89733 m .3973 .89737 L .39757 .89853 L F
.139 .451 .882 r
.39587 .8975 m .39757 .89853 L .39611 .89668 L F
.39587 .8975 m .39611 .89668 L .39578 .89627 L F
.805 .962 .641 r
.39524 .89706 m .39558 .89733 L .39578 .89627 L F
.676 .971 .914 r
.39266 .89922 m .39561 .89839 L .39571 .89805 L F
.793 .961 .918 r
.39205 .89893 m .39266 .89922 L .39558 .89733 L F
.39205 .89893 m .39558 .89733 L .39394 .89898 L F
.805 .962 .641 r
.39394 .89898 m .39519 .89772 L .39524 .89706 L F
.39519 .89772 m .39558 .89733 L .39524 .89706 L F
.676 .971 .914 r
.39266 .89922 m .39504 .89877 L .3951 .89873 L F
.39512 .89852 m .3951 .89873 L .39561 .89839 L F
.39266 .89922 m .3951 .89873 L .39512 .89852 L F
.39571 .89805 m .39561 .89839 L .39666 .89768 L F
.584 .457 .673 r
.54701 .85499 m .54584 .85712 L .54814 .85635 L F
.772 .615 .05 r
.56395 .78244 m .56374 .77913 L .56423 .78061 L F
.598 .405 .591 r
.6039 .81186 m .60397 .81419 L .60174 .81457 L F
.55 .368 .587 r
.6039 .81186 m .60604 .81158 L .60397 .81419 L F
.642 .642 .835 r
.40598 .87899 m .40402 .87956 L .40285 .87695 L F
.506 .837 .998 r
.64931 .72257 m .64974 .72319 L .647 .72323 L F
.292 0 .083 r
.64974 .72319 m .64685 .72532 L .647 .72323 L F
.64974 .72319 m .64891 .72485 L .64685 .72532 L F
.979 .835 .437 r
.64931 .72257 m .64891 .72485 L .64974 .72319 L F
.525 .314 .536 r
.66094 .73623 m .66079 .73854 L .65849 .73923 L F
.502 .816 1 r
.66094 .73623 m .6596 .73545 L .66278 .73577 L F
.779 .765 .84 r
.44206 .87201 m .44346 .87383 L .44012 .87405 L F
.578 .721 .94 r
.44436 .87181 m .44346 .87383 L .44206 .87201 L F
.44436 .87181 m .44589 .87337 L .44346 .87383 L F
.087 0 0 r
.46711 .88279 m .4677 .88303 L .46602 .88318 L F
.46711 .88279 m .46915 .88279 L .4677 .88303 L F
.31 .8 .778 r
.49064 .8777 m .48708 .87866 L .48908 .87838 L F
.177 .706 .702 r
.49176 .8774 m .49064 .8777 L .48908 .87838 L F
.49176 .8774 m .49272 .8772 L .49064 .8777 L F
.696 .882 .967 r
.49741 .88707 m .49906 .8851 L .49693 .88695 L F
.647 .129 0 r
.469 .83733 m .46848 .83713 L .46795 .83645 L F
.734 .457 .51 r
.469 .83733 m .4673 .83976 L .46848 .83713 L F
.469 .83733 m .47064 .83999 L .4673 .83976 L F
.103 0 0 r
.52428 .87621 m .52758 .87406 L .52632 .87559 L F
0 0 0 r
.52758 .87406 m .53047 .87257 L .52897 .87379 L F
.52632 .87559 m .52758 .87406 L .52897 .87379 L F
.679 .49 .624 r
.5123 .82968 m .51551 .8324 L .51551 .83011 L F
.434 .039 .188 r
.52608 .84144 m .52342 .84274 L .52537 .84256 L F
.594 .369 .545 r
.5285 .84276 m .52608 .84144 L .52537 .84256 L F
.5285 .84276 m .52846 .84044 L .52608 .84144 L F
.56 .604 .854 r
.38216 .75433 m .38274 .75114 L .38143 .7514 L F
.38216 .75433 m .38405 .75397 L .38274 .75114 L F
.524 .365 .608 r
.38219 .75668 m .38405 .75397 L .38216 .75433 L F
.22 0 .1 r
.52456 .87175 m .52148 .87459 L .52386 .87392 L F
.791 .745 .81 r
.52739 .84888 m .52974 .848 L .52844 .84494 L F
.698 .701 .849 r
.52844 .84494 m .52974 .848 L .53172 .84559 L F
.586 .135 .147 r
.60448 .76475 m .60326 .76632 L .60108 .7652 L F
.664 .625 .801 r
.60448 .76475 m .6076 .76541 L .6066 .76423 L F
.436 .013 .136 r
.6066 .76423 m .60326 .76632 L .60448 .76475 L F
.474 .185 .394 r
.65899 .75699 m .66115 .7564 L .65849 .75549 L F
.74 .686 .8 r
.61182 .76412 m .61504 .76468 L .61393 .76174 L F
.736 .684 .801 r
.61393 .76174 m .61504 .76468 L .61719 .76209 L F
0 .02 .578 r
.55038 .81961 m .55207 .82214 L .55129 .82099 L F
.907 .615 .119 r
.55189 .82379 m .55207 .82214 L .5516 .82121 L F
.55189 .82379 m .55252 .82485 L .55207 .82214 L F
.656 .138 0 r
.54551 .81301 m .54439 .81138 L .54365 .81086 L F
.54551 .81301 m .54637 .81359 L .54439 .81138 L F
.515 .434 .702 r
.67857 .74658 m .67941 .74892 L .67677 .74824 L F
.337 .566 .923 r
.67677 .74824 m .67941 .74892 L .67899 .74942 L F
.117 0 0 r
.47455 .87197 m .47561 .87141 L .47239 .87223 L F
.784 .412 .352 r
.67566 .72856 m .67452 .73005 L .67265 .72762 L F
.975 .674 .302 r
.67566 .72856 m .67454 .7255 L .67491 .72786 L F
.997 .83 .552 r
.67491 .72786 m .67452 .73005 L .67566 .72856 L F
.793 .752 .815 r
.52383 .83528 m .52204 .83755 L .52496 .83755 L F
.523 .6 .873 r
.52737 .83715 m .52873 .83512 L .52576 .83585 L F
.357 0 .014 r
.52873 .83512 m .52646 .83591 L .52576 .83585 L F
.558 .774 .979 r
.52496 .83755 m .52737 .83715 L .52576 .83585 L F
.357 0 .014 r
.52646 .83591 m .52479 .83648 L .52576 .83585 L F
.558 .774 .979 r
.52404 .83571 m .52576 .83585 L .52383 .83528 L F
.52496 .83755 m .52576 .83585 L .52404 .83571 L F
.565 .842 .997 r
.40944 .89439 m .4127 .89439 L .41128 .8939 L F
.613 .822 .981 r
.4127 .89439 m .41376 .89283 L .41128 .8939 L F
.4127 .89439 m .41501 .894 L .41376 .89283 L F
0 0 0 r
.65219 .75532 m .65139 .75591 L .65059 .75623 L F
.65219 .75532 m .65364 .75387 L .65139 .75591 L F
0 .28 .72 r
.48374 .88584 m .48729 .88815 L .48615 .88731 L F
.29 .671 .973 r
.48615 .88731 m .48729 .88815 L .48914 .88808 L F
.76 .7 .795 r
.46087 .86886 m .46182 .87126 L .45958 .87211 L F
.66 .649 .828 r
.46343 .86917 m .46182 .87126 L .46087 .86886 L F
.58 .273 .412 r
.59147 .75917 m .59377 .75908 L .59446 .75658 L F
.576 .319 .489 r
.59377 .75908 m .59648 .75612 L .59446 .75658 L F
.351 .782 .969 r
.53625 .86623 m .53441 .86648 L .53301 .86599 L F
.273 .156 .532 r
.53581 .8681 m .53441 .86648 L .53625 .86623 L F
.53581 .8681 m .53448 .86934 L .53441 .86648 L F
.622 .822 .977 r
.60859 .76363 m .60892 .76368 L .61123 .76218 L F
.60892 .76368 m .61182 .76412 L .61124 .76221 L F
.60892 .76368 m .61124 .76221 L .61123 .76218 L F
.829 .859 .868 r
.61135 .76216 m .61182 .76412 L .61393 .76174 L F
.61129 .76222 m .61182 .76412 L .61135 .76216 L F
.61124 .76221 m .61182 .76412 L .61128 .76218 L F
.622 .822 .977 r
.60859 .76363 m .60985 .76467 L .61182 .76412 L F
.267 0 .207 r
.61222 .76328 m .60971 .76538 L .61034 .763 L F
.61056 .76281 m .61034 .763 L .6104 .76276 L F
.61222 .76328 m .61034 .763 L .61056 .76281 L F
.829 .859 .868 r
.61128 .76218 m .61129 .76222 L .61135 .76216 L F
.61128 .76218 m .61393 .76174 L .61269 .76098 L F
.263 0 .242 r
.61269 .76098 m .61261 .76134 L .61123 .76221 L F
.61269 .76098 m .61123 .76221 L .61056 .76264 L F
.829 .859 .868 r
.61123 .76218 m .61128 .76218 L .61269 .76098 L F
.61123 .76218 m .61124 .76221 L .61128 .76218 L F
.263 0 .242 r
.61056 .76264 m .6107 .76269 L .6104 .76276 L F
.6107 .76269 m .61222 .76328 L .61056 .76281 L F
.6107 .76269 m .61056 .76281 L .6104 .76276 L F
.61261 .76134 m .61222 .76328 L .61056 .76264 L F
.281 0 .268 r
.61032 .76308 m .60859 .76363 L .6104 .76276 L F
.585 .808 .985 r
.60667 .76424 m .60985 .76467 L .60859 .76363 L F
.749 .71 .815 r
.6066 .76423 m .6076 .76541 L .60985 .76467 L F
.281 0 .268 r
.60971 .76538 m .60859 .76363 L .61032 .76308 L F
.585 .808 .985 r
.6066 .76423 m .60667 .76424 L .60859 .76363 L F
.702 .926 .966 r
.48362 .8389 m .48273 .84023 L .48457 .84007 L F
.48362 .8389 m .48133 .84 L .48273 .84023 L F
.612 .489 .688 r
.66566 .74724 m .66848 .74832 L .66783 .74844 L F
.66566 .74724 m .66613 .74915 L .66848 .74832 L F
.574 .409 .62 r
.61315 .78037 m .61541 .78015 L .61531 .7778 L F
.487 .321 .582 r
.61272 .78305 m .61541 .78015 L .61315 .78037 L F
.643 .332 .429 r
.66438 .71779 m .66768 .71792 L .66345 .71663 L F
.431 .418 .744 r
.60538 .82064 m .60308 .8207 L .60203 .81671 L F
.408 .172 .441 r
.60304 .82234 m .60308 .8207 L .60538 .82064 L F
.668 .301 .341 r
.46203 .83571 m .46439 .83745 L .46233 .83688 L F
.586 .368 .551 r
.57539 .79336 m .57496 .79554 L .5727 .79358 L F
.57539 .79336 m .57496 .79554 L .5727 .79358 L F
.801 1 .829 r
.61606 .7425 m .61708 .7406 L .61765 .74089 L F
.61606 .7425 m .6146 .74298 L .61708 .7406 L F
.064 0 0 r
.56827 .77309 m .56902 .77383 L .5703 .77246 L F
.56827 .77309 m .56732 .77481 L .56902 .77383 L F
.068 0 0 r
.52 .81939 m .51848 .81943 L .51957 .81921 L F
.52 .81939 m .5175 .82031 L .51848 .81943 L F
.76 .745 .839 r
.63827 .73177 m .63475 .73251 L .63714 .73071 L F
.721 .813 .922 r
.64024 .73079 m .63827 .73177 L .63714 .73071 L F
.621 .429 .601 r
.61924 .77029 m .62151 .76994 L .62153 .76751 L F
.571 .406 .619 r
.51433 .82481 m .51439 .82717 L .51246 .82718 L F
.547 .433 .675 r
.51515 .82881 m .51246 .82718 L .51439 .82717 L F
.51515 .82881 m .5123 .82968 L .51246 .82718 L F
.809 .743 .791 r
.54864 .83069 m .54865 .83275 L .54776 .83076 L F
.64 .512 .691 r
.37575 .83562 m .37572 .83777 L .37794 .83754 L F
0 .121 .668 r
.46358 .85215 m .46333 .85316 L .46222 .85062 L F
.766 .987 .755 r
.46358 .85215 m .46237 .85363 L .46333 .85316 L F
0 0 0 r
.65899 .76528 m .66043 .76451 L .65814 .76525 L F
.65899 .76528 m .66081 .76403 L .66043 .76451 L F
.563 .334 .526 r
.61107 .78544 m .61349 .78587 L .61272 .78305 L F
.487 .321 .582 r
.61272 .78305 m .61563 .78237 L .61541 .78015 L F
.505 .318 .562 r
.61349 .78587 m .61563 .78237 L .61272 .78305 L F
.564 .396 .613 r
.41327 .86102 m .4108 .86413 L .41071 .86147 L F
.698 .83 .946 r
.58431 .8368 m .58438 .83796 L .58257 .83813 L F
.58431 .8368 m .58509 .83789 L .58257 .83813 L F
.802 1 .83 r
.5834 .83407 m .58452 .8339 L .58161 .83646 L F
.543 .62 .879 r
.58072 .83473 m .58205 .83714 L .58431 .8368 L F
.698 .83 .946 r
.58431 .8368 m .58257 .83813 L .58205 .83714 L F
.58431 .8368 m .58257 .83813 L .58147 .83983 L F
.543 .62 .879 r
.58072 .83473 m .58431 .8368 L .5834 .83407 L F
.876 .943 .856 r
.58439 .83572 m .58431 .8368 L .58436 .83576 L F
.02 .164 .674 r
.58504 .8361 m .58431 .8368 L .58439 .83572 L F
.397 0 .097 r
.58504 .8361 m .58439 .83572 L .58437 .83574 L F
.038 .195 .699 r
.58436 .83574 m .58431 .8368 L .58504 .8361 L F
.5834 .83407 m .58419 .83645 L .58439 .8353 L F
.808 .951 .61 r
.58161 .83646 m .58257 .83813 L .58205 .83714 L F
.848 .998 .792 r
.58155 .83786 m .58437 .83574 L .58087 .83948 L F
.58437 .83574 m .58439 .83572 L .58437 .83575 L F
.58437 .83574 m .58437 .83575 L .58087 .83948 L F
.038 .195 .699 r
.58419 .83645 m .58423 .83656 L .5843 .83602 L F
.58419 .83645 m .5843 .83602 L .58439 .8353 L F
.58423 .83656 m .58431 .8368 L .58436 .83576 L F
.58423 .83656 m .58436 .83576 L .58439 .8353 L F
.223 0 .194 r
.58257 .83813 m .58 .84065 L .58147 .83983 L F
.876 .943 .856 r
.58437 .83575 m .58147 .83983 L .58087 .83948 L F
.58439 .83572 m .58436 .83576 L .58437 .83575 L F
.58436 .83576 m .58147 .83983 L .58437 .83575 L F
.58436 .83576 m .58431 .8368 L .58425 .83592 L F
.58425 .83592 m .58431 .8368 L .58147 .83983 L F
.397 0 .097 r
.58504 .8361 m .58437 .83574 L .58155 .83786 L F
.038 .195 .699 r
.58439 .8353 m .58436 .83574 L .58504 .8361 L F
.698 .83 .946 r
.58431 .8368 m .58509 .83789 L .58438 .83796 L F
.758 .671 .765 r
.45682 .83751 m .45795 .84051 L .45465 .84019 L F
.734 .386 .39 r
.45795 .84051 m .4567 .84248 L .45465 .84019 L F
.082 .251 .738 r
.45871 .83955 m .45795 .84051 L .45682 .83751 L F
.569 .193 .289 r
.45973 .84215 m .45795 .84051 L .45871 .83955 L F
.45973 .84215 m .4567 .84248 L .45795 .84051 L F
.688 .668 .825 r
.3975 .87734 m .39889 .87978 L .39534 .87912 L F
.739 .688 .801 r
.40108 .87804 m .39889 .87978 L .3975 .87734 L F
.727 .82 .923 r
.37085 .73069 m .36837 .73228 L .36746 .73079 L F
.898 .788 .731 r
.56968 .80614 m .5712 .8092 L .5733 .80712 L F
.56968 .80614 m .56963 .80874 L .5712 .8092 L F
0 0 .092 r
.5714 .81145 m .57127 .81154 L .5712 .8092 L F
.5714 .81145 m .5712 .8092 L .56963 .80874 L F
.547 .581 .841 r
.42703 .84832 m .42383 .84589 L .42584 .84522 L F
.625 .449 .625 r
.59519 .80943 m .59749 .80898 L .59714 .80665 L F
.633 .511 .697 r
.59749 .80898 m .59955 .80653 L .59714 .80665 L F
.39 .2 .499 r
.61474 .79887 m .61658 .7961 L .61642 .79822 L F
.394 .186 .475 r
.61444 .80099 m .61474 .79887 L .61642 .79822 L F
.101 0 0 r
.47986 .81664 m .48126 .81648 L .48195 .81611 L F
.577 .324 .497 r
.4789 .81889 m .48126 .81648 L .47986 .81664 L F
.721 .657 .786 r
.63508 .74395 m .6384 .74442 L .63722 .74162 L F
.642 .404 .543 r
.40939 .86667 m .40906 .86885 L .4074 .86883 L F
.688 .554 .697 r
.41115 .86622 m .40906 .86885 L .40939 .86667 L F
.787 .823 .88 r
.62283 .75173 m .62347 .75375 L .62382 .7523 L F
.62283 .75173 m .62026 .75384 L .62347 .75375 L F
.819 .742 .779 r
.62026 .75384 m .62134 .75653 L .62347 .75375 L F
.646 .611 .8 r
.55907 .79321 m .5555 .79078 L .55895 .79175 L F
.709 .665 .804 r
.56085 .79073 m .55907 .79321 L .55895 .79175 L F
.723 .739 .864 r
.57641 .7761 m .5798 .77735 L .57904 .77633 L F
.901 .912 .821 r
.57904 .77633 m .5798 .77735 L .58152 .77496 L F
.531 .08 .124 r
.50333 .81463 m .50545 .81527 L .50658 .81422 L F
.207 0 0 r
.50545 .81527 m .50878 .81407 L .50658 .81422 L F
.549 .002 0 r
.54143 .80917 m .54126 .80883 L .54002 .80815 L F
.46 0 0 r
.5403 .80845 m .54143 .80917 L .54002 .80815 L F
0 .263 .741 r
.54034 .80848 m .54143 .80917 L .5403 .80845 L F
.549 .002 0 r
.54143 .80917 m .54241 .8098 L .54126 .80883 L F
0 .263 .741 r
.54279 .8097 m .54143 .80917 L .54034 .80848 L F
.549 .002 0 r
.54143 .80917 m .54365 .81086 L .54241 .8098 L F
.499 0 0 r
.58643 .83477 m .58452 .8339 L .5834 .83407 L F
.901 .912 .821 r
.57904 .77633 m .58152 .77496 L .58086 .77418 L F
.632 .921 .977 r
.66265 .76379 m .66673 .76297 L .66529 .76255 L F
.425 .869 .823 r
.66673 .76297 m .66866 .76214 L .66778 .76224 L F
0 .409 .816 r
.48121 .88445 m .48374 .88584 L .48317 .88567 L F
.38 0 0 r
.48374 .88584 m .48508 .88668 L .48317 .88567 L F
.48374 .88584 m .48615 .88731 L .48508 .88668 L F
.049 0 0 r
.58732 .84828 m .58859 .84831 L .58641 .84864 L F
.58732 .84828 m .58939 .84788 L .58859 .84831 L F
.701 .624 .767 r
.52705 .8115 m .52439 .81654 L .52397 .8109 L F
.6 .321 .466 r
.51413 .81162 m .5161 .81343 L .51639 .81144 L F
.51413 .81162 m .51396 .81382 L .5161 .81343 L F
.634 .573 .768 r
.42876 .84806 m .42703 .84832 L .42584 .84522 L F
.66 .486 .637 r
.42876 .84806 m .42701 .85067 L .42703 .84832 L F
.155 0 0 r
.47084 .87301 m .47024 .87253 L .46826 .87214 L F
.47084 .87301 m .47239 .87223 L .47024 .87253 L F
.173 .71 .801 r
.48814 .83976 m .48674 .8398 L .48457 .84007 L F
.632 .093 0 r
.48814 .83976 m .48995 .84067 L .48674 .8398 L F
.679 .49 .624 r
.5123 .82968 m .51448 .83289 L .51551 .8324 L F
.72 .465 .54 r
.51515 .82881 m .51093 .83169 L .5123 .82968 L F
.766 .59 .659 r
.61089 .77227 m .61432 .77023 L .61092 .77009 L F
.61089 .77227 m .61416 .77257 L .61432 .77023 L F
.626 .529 .724 r
.38086 .75944 m .38287 .75934 L .38219 .75668 L F
.636 .365 .492 r
.38086 .75944 m .38251 .761 L .38287 .75934 L F
.38086 .75944 m .37982 .76199 L .38251 .761 L F
.596 .101 0 r
.54821 .81581 m .54728 .81457 L .54637 .81359 L F
.54821 .81581 m .54913 .8167 L .54728 .81457 L F
.8 .32 .072 r
.54728 .81457 m .54913 .8167 L .54983 .81679 L F
.85 .391 .04 r
.55075 .80325 m .54973 .80286 L .54883 .80134 L F
.63 .067 0 r
.55075 .80325 m .55184 .80481 L .54973 .80286 L F
.55075 .80325 m .55203 .80418 L .55184 .80481 L F
.527 .092 .158 r
.42651 .82663 m .42877 .82676 L .42995 .82522 L F
.147 0 0 r
.42877 .82676 m .43183 .82632 L .42995 .82522 L F
.562 .17 .256 r
.44599 .82509 m .44783 .82637 L .44907 .82447 L F
.566 .195 .298 r
.44783 .82637 m .45123 .82445 L .44907 .82447 L F
.862 .828 .812 r
.54816 .79404 m .54628 .79603 L .54488 .79547 L F
.5469 .79459 m .54488 .79547 L .54701 .79473 L F
.448 .877 .909 r
.54488 .79547 m .5459 .79471 L .54701 .79473 L F
.183 0 0 r
.5459 .79471 m .54708 .79482 L .54701 .79473 L F
.54708 .79482 m .54911 .79501 L .54701 .79473 L F
.862 .828 .812 r
.54816 .79404 m .5469 .79459 L .54701 .79473 L F
.461 0 0 r
.54701 .79473 m .55033 .79411 L .54816 .79404 L F
.671 .67 .841 r
.64454 .73817 m .6479 .7391 L .64671 .7365 L F
.22 .026 .39 r
.5602 .78362 m .56114 .78489 L .56184 .78263 L F
.5602 .78362 m .55923 .78575 L .56114 .78489 L F
.743 .741 .85 r
.64573 .72928 m .64266 .72857 L .6451 .72767 L F
.287 .338 .741 r
.64678 .72743 m .64573 .72928 L .6451 .72767 L F
.799 .993 .874 r
.51617 .87162 m .51442 .87325 L .51281 .87362 L F
.456 .734 .987 r
.51699 .87343 m .51442 .87325 L .51617 .87162 L F
0 0 0 r
.55301 .84019 m .55391 .83953 L .55229 .8406 L F
.86 .937 .565 r
.55391 .83953 m .55361 .84102 L .55464 .83898 L F
0 0 0 r
.5529 .84138 m .55391 .83953 L .55548 .83878 L F
.55548 .83878 m .55391 .83953 L .55301 .84019 L F
.86 .937 .565 r
.55391 .83953 m .55464 .83898 L .5552 .83788 L F
.913 .94 .58 r
.55391 .83953 m .5552 .83788 L .55489 .83676 L F
.641 .473 .64 r
.37578 .84022 m .37794 .83754 L .37572 .83777 L F
.425 .155 .399 r
.48963 .81191 m .48753 .81388 L .48978 .8132 L F
.688 .469 .584 r
.48978 .8132 m .49209 .8121 L .48963 .81191 L F
.63 .43 .593 r
.39838 .86896 m .39636 .87162 L .39635 .86914 L F
.485 .431 .722 r
.39382 .75098 m .39231 .7521 L .39172 .74896 L F
.533 .479 .741 r
.39425 .75214 m .39231 .7521 L .39382 .75098 L F
.571 .402 .613 r
.40047 .82919 m .40289 .82639 L .40038 .82695 L F
.752 .681 .783 r
.61089 .77227 m .61205 .77511 L .61416 .77257 L F
.629 .496 .681 r
.61205 .77511 m .61407 .77451 L .61416 .77257 L F
.505 .057 .119 r
.59359 .76743 m .59089 .76894 L .59187 .76832 L F
.475 .2 .417 r
.36402 .78763 m .36196 .78813 L .36441 .78593 L F
.522 .243 .432 r
.36441 .78593 m .36601 .78742 L .36402 .78763 L F
.519 .243 .436 r
.36648 .78563 m .36601 .78742 L .36441 .78593 L F
.655 .561 .737 r
.40125 .75677 m .39904 .75717 L .39827 .75397 L F
.645 .51 .683 r
.40125 .75677 m .39934 .75969 L .39904 .75717 L F
.289 .787 .78 r
.63619 .76603 m .63865 .76535 L .63964 .76522 L F
.184 .712 .848 r
.63865 .76535 m .64135 .76524 L .63964 .76522 L F
.073 0 0 r
.63964 .76522 m .64135 .76524 L .64194 .76503 L F
.629 .361 .493 r
.39514 .83172 m .39282 .83013 L .39262 .83237 L F
.39514 .83172 m .39772 .83016 L .39282 .83013 L F
.111 .645 .862 r
.53619 .85123 m .53685 .85088 L .53464 .85115 L F
.574 .437 .658 r
.53962 .84903 m .53831 .85135 L .53619 .85123 L F
.111 .645 .862 r
.53619 .85123 m .53831 .85135 L .53685 .85088 L F
.913 .759 .677 r
.58489 .82713 m .58602 .83004 L .58497 .82962 L F
.948 .89 .739 r
.58497 .82962 m .58602 .83004 L .58662 .82796 L F
.566 .182 .273 r
.45862 .82415 m .46078 .82438 L .46204 .82238 L F
.547 .162 .262 r
.46204 .82238 m .46378 .82353 L .4641 .82241 L F
.46204 .82238 m .46078 .82438 L .46378 .82353 L F
.495 .268 .499 r
.37349 .78013 m .37121 .78259 L .37144 .78047 L F
.738 .31 0 r
.58662 .82796 m .58479 .82489 L .58489 .82713 L F
.598 .547 .769 r
.46087 .86886 m .45866 .86926 L .46042 .86682 L F
.76 .7 .795 r
.46087 .86886 m .45958 .87211 L .45866 .86926 L F
.329 .751 .976 r
.49127 .88782 m .49276 .88861 L .49441 .88841 L F
.992 .865 .522 r
.57556 .83263 m .57609 .83024 L .57549 .82919 L F
.801 .734 .79 r
.62026 .75384 m .61814 .75647 L .62134 .75653 L F
.807 .702 .749 r
.61814 .75647 m .61919 .75939 L .62134 .75653 L F
.813 .933 .911 r
.53388 .82873 m .53218 .83137 L .53527 .82825 L F
.655 .773 .936 r
.41422 .87776 m .41151 .87747 L .41351 .87642 L F
.584 .624 .858 r
.41557 .87604 m .41422 .87776 L .41351 .87642 L F
.41557 .87604 m .41648 .87844 L .41422 .87776 L F
.805 .397 0 r
.55156 .82694 m .55327 .82986 L .55227 .82783 L F
0 0 0 r
.59552 .81169 m .59337 .81444 L .59546 .8142 L F
.125 .319 .788 r
.59337 .81444 m .59568 .81629 L .59546 .8142 L F
.202 0 0 r
.47235 .88255 m .47327 .88293 L .47113 .88279 L F
.47235 .88255 m .47445 .88288 L .47327 .88293 L F
.505 .568 .853 r
.47934 .87145 m .47791 .8734 L .47767 .8713 L F
.47934 .87145 m .48044 .87441 L .47791 .8734 L F
.31 .44 .831 r
.48195 .87332 m .48044 .87441 L .47934 .87145 L F
.48195 .87332 m .47934 .87145 L .48193 .87169 L F
.128 0 0 r
.48177 .87168 m .47934 .87145 L .47855 .87152 L F
.48193 .87169 m .47934 .87145 L .48177 .87168 L F
.505 .568 .853 r
.47934 .87145 m .47767 .8713 L .47766 .87115 L F
.675 .382 .469 r
.47791 .8734 m .48044 .87441 L .48061 .87595 L F
.47791 .8734 m .48044 .87441 L .48061 .87595 L F
.349 .171 .493 r
.60654 .82468 m .60624 .82691 L .60482 .82721 L F
.356 .193 .518 r
.60624 .82691 m .60483 .82977 L .60482 .82721 L F
.623 .505 .699 r
.60397 .81419 m .60203 .81671 L .60174 .81457 L F
.622 .322 .439 r
.6476 .7302 m .65074 .72793 L .64755 .7286 L F
.542 .059 .059 r
.48044 .87441 m .48443 .87454 L .48222 .87411 L F
.715 .628 .76 r
.60304 .82234 m .60093 .82475 L .60053 .82232 L F
.639 .301 .383 r
.49315 .8399 m .49196 .8423 L .48995 .84067 L F
.836 .536 .482 r
.49315 .8399 m .49465 .84303 L .49196 .8423 L F
.818 .531 .504 r
.4963 .84294 m .49465 .84303 L .49315 .8399 L F
.545 .853 .998 r
.42529 .89138 m .42649 .89023 L .42306 .89162 L F
.42529 .89138 m .42793 .89084 L .42649 .89023 L F
.634 .832 .976 r
.50328 .87678 m .50101 .87759 L .49924 .87672 L F
.43 .081 .27 r
.62978 .78239 m .63101 .78423 L .6295 .78504 L F
.62978 .78239 m .63199 .78282 L .63101 .78423 L F
.504 .222 .42 r
.36923 .78299 m .36857 .78537 L .36648 .78563 L F
.418 .143 .387 r
.37036 .78491 m .36923 .78299 L .37121 .78259 L F
.37036 .78491 m .36857 .78537 L .36923 .78299 L F
.72 .31 .27 r
.51639 .81144 m .51832 .81329 L .51949 .81185 L F
.023 0 0 r
.51949 .81185 m .52099 .81161 L .52173 .81087 L F
.51949 .81185 m .51832 .81329 L .52099 .81161 L F
.767 .71 .798 r
.63924 .7406 m .64273 .73947 L .64145 .73835 L F
.78 .786 .857 r
.64145 .73835 m .64273 .73947 L .64454 .73817 L F
.578 .227 .338 r
.48421 .81591 m .48629 .81617 L .48753 .81388 L F
.693 .471 .581 r
.48629 .81617 m .48978 .8132 L .48753 .81388 L F
0 0 0 r
.52897 .87379 m .53047 .87257 L .53196 .87138 L F
.55 .589 .846 r
.46542 .86932 m .4647 .87197 L .46343 .86917 L F
.46542 .86932 m .46673 .87188 L .4647 .87197 L F
.507 .422 .694 r
.39317 .7468 m .39172 .74896 L .39125 .74731 L F
.39317 .7468 m .39352 .74868 L .39172 .74896 L F
.485 .431 .722 r
.39382 .75098 m .39172 .74896 L .39352 .74868 L F
.35 0 0 r
.42172 .82589 m .42447 .8264 L .42248 .82636 L F
.556 .737 .96 r
.64669 .72057 m .64931 .72257 L .647 .72323 L F
.64679 .72091 m .647 .72323 L .64729 .72265 L F
.64669 .72057 m .64671 .72075 L .64679 .72091 L F
.64671 .72075 m .647 .72323 L .64679 .72091 L F
.345 .758 .98 r
.64729 .72265 m .647 .72323 L .64424 .72251 L F
.317 .751 .969 r
.64486 .72205 m .64593 .72232 L .64424 .72251 L F
.64593 .72232 m .64659 .72262 L .64424 .72251 L F
.64486 .72205 m .64583 .72216 L .64486 .72205 L F
.64506 .7219 m .64583 .72216 L .64486 .72205 L F
.64583 .72216 m .64583 .72216 L .64486 .72205 L F
.64593 .72232 m .64729 .72265 L .64659 .72262 L F
.64583 .72216 m .64729 .72265 L .64486 .72205 L F
.82 .629 .644 r
.64685 .72532 m .64424 .72251 L .647 .72323 L F
.64685 .72532 m .64355 .72506 L .64424 .72251 L F
.687 .622 .778 r
.64603 .72095 m .64729 .72265 L .64583 .72216 L F
.95 .854 .711 r
.64508 .72118 m .64551 .72212 L .64603 .72095 L F
.572 .519 .757 r
.64347 .71847 m .64489 .72153 L .64277 .72204 L F
.64489 .72153 m .64503 .72183 L .6447 .72186 L F
.64489 .72153 m .6447 .72186 L .64277 .72204 L F
.757 .604 .688 r
.64677 .71887 m .64575 .72068 L .64347 .71847 L F
.64575 .72068 m .64506 .7219 L .64489 .72153 L F
.64575 .72068 m .64489 .72153 L .64347 .71847 L F
.95 .854 .711 r
.64508 .72118 m .64529 .72113 L .64559 .72029 L F
.64529 .72113 m .64603 .72095 L .64575 .72068 L F
.64502 .7219 m .64551 .72212 L .64508 .72118 L F
.951 .945 .732 r
.64603 .72095 m .64506 .7219 L .64575 .72068 L F
.64603 .72095 m .64575 .72068 L .64677 .71887 L F
.95 .854 .711 r
.64575 .72068 m .64603 .72095 L .64581 .72062 L F
.64529 .72113 m .64581 .72062 L .64559 .72029 L F
.64401 .72145 m .64508 .72118 L .64527 .71982 L F
.64508 .72118 m .64559 .72029 L .64527 .71982 L F
.64403 .72145 m .64502 .7219 L .64508 .72118 L F
.572 .519 .757 r
.64503 .72183 m .64506 .7219 L .64502 .7219 L F
.64503 .72183 m .64502 .7219 L .64277 .72204 L F
.687 .622 .778 r
.64603 .72095 m .64583 .72216 L .64506 .7219 L F
.74 .568 .66 r
.64669 .72225 m .64564 .72328 L .64757 .724 L F
.64564 .72328 m .6445 .72439 L .64548 .72427 L F
.64564 .72328 m .64548 .72427 L .64757 .724 L F
.64603 .72095 m .64551 .72212 L .64669 .72225 L F
.64551 .72212 m .6445 .72439 L .64669 .72225 L F
.317 .751 .969 r
.64457 .72193 m .64424 .72251 L .64277 .72204 L F
.276 .359 .768 r
.64355 .72506 m .64277 .72204 L .64424 .72251 L F
.64355 .72506 m .6445 .72439 L .64277 .72204 L F
.735 .695 .813 r
.6433 .72361 m .64169 .7217 L .64277 .72204 L F
.6433 .72361 m .63955 .72366 L .64169 .7217 L F
.321 .426 .812 r
.6433 .72361 m .64399 .72152 L .64224 .72328 L F
.64399 .72152 m .64401 .72145 L .64396 .7215 L F
.64399 .72152 m .64396 .7215 L .64224 .72328 L F
.317 .751 .969 r
.64502 .7219 m .64479 .72208 L .64457 .72193 L F
.64479 .72208 m .64424 .72251 L .64457 .72193 L F
.64506 .7219 m .64505 .72191 L .64502 .7219 L F
.64505 .72191 m .64424 .72251 L .64502 .7219 L F
.95 .854 .711 r
.64495 .72187 m .6445 .72439 L .64551 .72212 L F
.64401 .72145 m .64402 .72151 L .64495 .72187 L F
.64402 .72151 m .6445 .72439 L .64495 .72187 L F
.64401 .72145 m .64551 .72212 L .64403 .72145 L F
.74 .568 .66 r
.64718 .7223 m .64757 .724 L .64784 .72309 L F
.64603 .72095 m .64669 .72225 L .64718 .7223 L F
.64669 .72225 m .64757 .724 L .64718 .7223 L F
.647 .72135 m .64784 .72309 L .6482 .72185 L F
.687 .622 .778 r
.64603 .72095 m .64669 .72057 L .64729 .72265 L F
.74 .568 .66 r
.64603 .72095 m .64784 .72309 L .647 .72135 L F
.519 .597 .872 r
.49237 .83436 m .492 .83549 L .49078 .83481 L F
.49237 .83436 m .49427 .83532 L .492 .83549 L F
.27 .717 .96 r
.5334 .8054 m .53305 .80583 L .53107 .80576 L F
.5334 .8054 m .53451 .80594 L .53305 .80583 L F
.563 .396 .614 r
.58698 .82219 m .58912 .82192 L .58883 .81961 L F
.58698 .82219 m .58912 .82192 L .58883 .81961 L F
.575 .439 .659 r
.51018 .83257 m .51272 .83449 L .51448 .83289 L F
.51018 .83257 m .51063 .83511 L .51272 .83449 L F
.445 .214 .469 r
.62098 .79104 m .6232 .78845 L .62288 .79044 L F
.438 .204 .46 r
.62288 .79044 m .6232 .78845 L .62511 .78793 L F
.504 .351 .606 r
.4117 .74133 m .41181 .7439 L .41365 .74323 L F
.4117 .74133 m .41181 .7439 L .41365 .74323 L F
.538 .352 .576 r
.4117 .74133 m .41365 .74323 L .41372 .74096 L F
.387 .022 .218 r
.65355 .73051 m .65305 .73217 L .65124 .73284 L F
.263 .178 .568 r
.65513 .72751 m .65572 .73076 L .65355 .73051 L F
.269 0 .176 r
.65355 .73051 m .65572 .73076 L .65305 .73217 L F
.356 0 .156 r
.5747 .77001 m .57784 .76758 L .57518 .76928 L F
.5747 .77001 m .57677 .76952 L .57784 .76758 L F
0 0 0 r
.57784 .76758 m .57832 .76806 L .57986 .7671 L F
.57784 .76758 m .57677 .76952 L .57832 .76806 L F
.442 .547 .867 r
.52846 .84044 m .53084 .84216 L .5303 .84038 L F
.757 .5 .544 r
.5285 .84276 m .53084 .84216 L .52846 .84044 L F
.94 .714 .57 r
.47293 .84838 m .4714 .84802 L .4717 .84533 L F
.731 .641 .759 r
.47501 .84561 m .47293 .84838 L .4717 .84533 L F
.798 .335 .135 r
.47489 .85052 m .4714 .84802 L .47293 .84838 L F
.65 .525 .698 r
.47501 .84561 m .47584 .84857 L .47293 .84838 L F
.638 .365 .489 r
.47584 .84857 m .47489 .85052 L .47293 .84838 L F
.323 .073 .371 r
.43555 .84308 m .43416 .84422 L .43355 .84387 L F
.58 .484 .71 r
.61531 .7778 m .6172 .77525 L .61407 .77451 L F
.61531 .7778 m .6174 .77743 L .6172 .77525 L F
.558 .395 .617 r
.61541 .78015 m .6174 .77743 L .61531 .7778 L F
.774 .842 .903 r
.62546 .73643 m .62192 .73749 L .62416 .73531 L F
.789 .789 .853 r
.62804 .7343 m .62546 .73643 L .62416 .73531 L F
.635 .552 .744 r
.52342 .84274 m .52414 .8458 L .52777 .84271 L F
.507 .344 .595 r
.52414 .8458 m .52601 .84594 L .52777 .84271 L F
.542 .549 .811 r
.52414 .8458 m .52739 .84888 L .52601 .84594 L F
.668 .974 .88 r
.50377 .88384 m .50762 .88202 L .50701 .88229 L F
.55 .904 .971 r
.50854 .88103 m .50762 .88202 L .50966 .88127 L F
.57 .912 .693 r
.50701 .88229 m .50762 .88202 L .50854 .88103 L F
.121 0 0 r
.36213 .74849 m .36024 .74857 L .35823 .74847 L F
.116 .668 .766 r
.36346 .74836 m .36024 .74857 L .36213 .74849 L F
.748 .532 .603 r
.42492 .85091 m .42484 .85322 L .42162 .85305 L F
.623 .442 .616 r
.42701 .85067 m .42484 .85322 L .42492 .85091 L F
.666 .296 .336 r
.43183 .82632 m .43401 .82694 L .43528 .82486 L F
.7 .337 .356 r
.43528 .82486 m .43401 .82694 L .43726 .8269 L F
.628 .653 .856 r
.39534 .87912 m .39212 .8771 L .39409 .87635 L F
.677 .645 .811 r
.3975 .87734 m .39534 .87912 L .39409 .87635 L F
.541 .286 .478 r
.38752 .76984 m .38505 .77211 L .38535 .76997 L F
.021 .583 .804 r
.43468 .84779 m .43642 .84794 L .43782 .84824 L F
.721 .542 .647 r
.43782 .84824 m .43565 .85043 L .43468 .84779 L F
.43782 .84824 m .43781 .85081 L .43565 .85043 L F
.005 .439 .864 r
.43858 .84797 m .43782 .84824 L .43642 .84794 L F
.43858 .84797 m .43969 .84903 L .43782 .84824 L F
.599 .52 .737 r
.43969 .84903 m .43781 .85081 L .43782 .84824 L F
.898 .788 .731 r
.56968 .80614 m .5733 .80712 L .57177 .8058 L F
.808 .678 .721 r
.5733 .80712 m .57187 .80378 L .57177 .8058 L F
.441 .184 .428 r
.61658 .7961 m .61906 .79373 L .61843 .79545 L F
.247 .01 .343 r
.61906 .79373 m .62098 .79104 L .62048 .7929 L F
.218 0 .296 r
.61843 .79545 m .61906 .79373 L .62048 .7929 L F
.406 .072 .282 r
.63209 .78025 m .6335 .78182 L .63199 .78282 L F
.63209 .78025 m .63413 .77975 L .6335 .78182 L F
.483 .162 .346 r
.37028 .76704 m .37236 .76682 L .37313 .76456 L F
.374 .061 .3 r
.37313 .76456 m .3742 .76624 L .37458 .76425 L F
.37313 .76456 m .37236 .76682 L .3742 .76624 L F
.541 .453 .704 r
.59519 .80943 m .59752 .81133 L .59749 .80898 L F
.59519 .80943 m .59552 .81169 L .59752 .81133 L F
.843 .741 .751 r
.57641 .77983 m .57711 .78159 L .57744 .78042 L F
.634 .573 .768 r
.42876 .84806 m .42584 .84522 L .42935 .84576 L F
.087 0 .376 r
.67037 .74408 m .67168 .74516 L .67222 .74314 L F
.537 .28 .474 r
.3943 .7638 m .39387 .76707 L .39191 .7672 L F
.529 .273 .472 r
.39602 .76575 m .3943 .7638 L .39655 .76352 L F
.39602 .76575 m .39387 .76707 L .3943 .7638 L F
.398 .185 .47 r
.39854 .82778 m .39772 .83016 L .39777 .83007 L F
.599 .472 .679 r
.60397 .81419 m .60411 .81657 L .60203 .81671 L F
.431 .418 .744 r
.60538 .82064 m .60203 .81671 L .60411 .81657 L F
.416 .161 .416 r
.62048 .7929 m .62098 .79104 L .62288 .79044 L F
.87 .981 .689 r
.5555 .79078 m .55423 .79167 L .55493 .79068 L F
.5555 .79078 m .55357 .79367 L .55423 .79167 L F
.459 .78 .998 r
.55662 .78968 m .55851 .79095 L .5555 .79078 L F
.56 .936 .862 r
.5555 .79078 m .55493 .79068 L .55662 .78968 L F
.688 .539 .678 r
.55851 .79095 m .55895 .79175 L .5555 .79078 L F
.805 .646 .686 r
.49634 .81951 m .49751 .82251 L .4943 .82235 L F
.661 .576 .749 r
.49875 .82169 m .49751 .82251 L .49634 .81951 L F
.968 .652 .276 r
.54805 .82836 m .54864 .83069 L .54976 .82972 L F
.665 .278 .301 r
.547 .82937 m .54805 .82836 L .54976 .82972 L F
.471 .275 .533 r
.61642 .79822 m .61658 .7961 L .61843 .79545 L F
.082 .262 .749 r
.55571 .83463 m .55392 .83286 L .55335 .83103 L F
.672 .743 .904 r
.67929 .73443 m .67981 .73622 L .67691 .73577 L F
.81 .616 .64 r
.67981 .73622 m .67727 .73849 L .67691 .73577 L F
.67981 .73622 m .6799 .73848 L .67727 .73849 L F
.304 .485 .872 r
.6808 .73548 m .67981 .73622 L .67929 .73443 L F
.643 .485 .654 r
.68133 .73651 m .67981 .73622 L .6808 .73548 L F
.68133 .73651 m .6799 .73848 L .67981 .73622 L F
.575 .503 .736 r
.39317 .7468 m .39125 .74731 L .39036 .74379 L F
0 0 0 r
.67123 .75071 m .66945 .7519 L .66853 .75342 L F
.148 0 0 r
.38929 .9 m .39117 .89986 L .38819 .90044 L F
.623 .298 .399 r
.62703 .77006 m .62911 .7718 L .62974 .76947 L F
.39 .083 .319 r
.62974 .76947 m .63107 .77119 L .63174 .76911 L F
.62974 .76947 m .62911 .7718 L .63107 .77119 L F
.547 .053 .036 r
.4641 .82241 m .46592 .82346 L .46728 .82235 L F
.362 0 0 r
.46592 .82346 m .46957 .82233 L .46728 .82235 L F
.523 0 0 r
.47973 .88425 m .48121 .88445 L .48317 .88567 L F
.089 0 0 r
.59437 .8452 m .59709 .84321 L .59598 .84495 L F
.139 0 .319 r
.59709 .84321 m .59883 .84016 L .59838 .84203 L F
0 0 0 r
.59598 .84495 m .59709 .84321 L .59838 .84203 L F
.597 .048 0 r
.56755 .80017 m .57086 .80089 L .56858 .79969 L F
.748 .759 .862 r
.63475 .73251 m .63282 .73354 L .63165 .73226 L F
.932 .656 .492 r
.52804 .82116 m .52967 .82205 L .52939 .8195 L F
.52804 .82116 m .52939 .8195 L .53023 .81864 L F
.608 .565 .78 r
.55972 .78785 m .56114 .78489 L .55923 .78575 L F
.494 0 0 r
.50957 .87527 m .50863 .87401 L .50742 .87456 L F
.50957 .87527 m .51058 .87447 L .50863 .87401 L F
.557 .877 .993 r
.43518 .88831 m .43852 .88816 L .43719 .88772 L F
.662 .908 .979 r
.43719 .88772 m .43852 .88816 L .44029 .88729 L F
.641 .518 .697 r
.61924 .77029 m .61946 .77257 L .62151 .76994 L F
.542 .397 .634 r
.59546 .8142 m .59752 .81133 L .59552 .81169 L F
.092 0 .351 r
.60746 .79319 m .60745 .79487 L .60688 .79292 L F
0 0 0 r
.64641 .77045 m .64354 .77233 L .64318 .77221 L F
.64641 .77045 m .64508 .77152 L .64354 .77233 L F
.64831 .76964 m .64508 .77152 L .64641 .77045 L F
.788 .447 .409 r
.4963 .84294 m .49516 .84503 L .49465 .84303 L F
.574 .248 .378 r
.49842 .84265 m .49516 .84503 L .4963 .84294 L F
.714 .259 0 r
.55511 .80652 m .55695 .80905 L .55603 .80829 L F
.595 .067 0 r
.55906 .81107 m .55603 .80829 L .55695 .80905 L F
.399 .836 .946 r
.44566 .88717 m .44901 .88691 L .44771 .88665 L F
.153 .69 .837 r
.44901 .88691 m .44973 .88668 L .44771 .88665 L F
.44901 .88691 m .45096 .88681 L .44973 .88668 L F
.739 .688 .801 r
.40108 .87804 m .3975 .87734 L .39948 .87656 L F
.697 .751 .894 r
.40285 .87695 m .40108 .87804 L .39948 .87656 L F
.663 .941 .678 r
.64942 .75985 m .64708 .76209 L .64837 .76042 L F
0 0 0 r
.64708 .76209 m .64615 .76376 L .64837 .76042 L F
.372 0 0 r
.64837 .76042 m .65057 .76105 L .65123 .76097 L F
.554 0 0 r
.64837 .76042 m .6506 .76085 L .64942 .75985 L F
.086 .554 .905 r
.64942 .76025 m .65057 .76105 L .64837 .76042 L F
.806 .952 .914 r
.64615 .76376 m .64918 .7605 L .64837 .76042 L F
.64615 .76376 m .6452 .7633 L .64852 .76097 L F
.64876 .76095 m .64852 .76097 L .64918 .7605 L F
.64615 .76376 m .64852 .76097 L .64876 .76095 L F
.554 0 0 r
.6506 .76085 m .65123 .76097 L .651 .76083 L F
.6506 .76085 m .651 .76083 L .64942 .75985 L F
.481 .187 .389 r
.65123 .76097 m .65137 .76001 L .64942 .75985 L F
.563 .298 .473 r
.6536 .76104 m .65146 .75938 L .65123 .76097 L F
.601 .118 .08 r
.65223 .76071 m .65057 .76105 L .64931 .76 L F
.6536 .76104 m .65264 .76104 L .65223 .76071 L F
.103 0 0 r
.65123 .76097 m .65057 .76105 L .6536 .76104 L F
.601 .118 .08 r
.65264 .76104 m .65057 .76105 L .65223 .76071 L F
.481 .187 .389 r
.65137 .76001 m .65146 .75938 L .65078 .75953 L F
.65137 .76001 m .65078 .75953 L .64942 .75985 L F
.727 .856 .943 r
.64373 .73715 m .64145 .73835 L .64454 .73817 L F
.741 .861 .936 r
.64373 .73715 m .64454 .73817 L .64671 .7365 L F
.623 .692 .893 r
.39827 .75397 m .39425 .75214 L .39693 .75256 L F
.36 .641 .962 r
.39982 .75371 m .39827 .75397 L .39693 .75256 L F
.655 .561 .737 r
.40125 .75677 m .39827 .75397 L .39982 .75371 L F
.284 0 0 r
.3571 .72961 m .35886 .73 L .36025 .73 L F
.629 .951 .938 r
.36025 .73 m .36086 .72899 L .36224 .72972 L F
.36025 .73 m .35886 .73 L .36086 .72899 L F
.572 .754 .963 r
.3565 .77518 m .3586 .77489 L .3587 .77257 L F
.3565 .77518 m .35801 .77498 L .3586 .77489 L F
.587 .423 .628 r
.35654 .77637 m .35801 .77498 L .3565 .77518 L F
.668 .788 .938 r
.41501 .894 m .41556 .89178 L .41376 .89283 L F
.41501 .894 m .41711 .89293 L .41556 .89178 L F
.617 .851 .988 r
.44236 .88712 m .4437 .88784 L .44566 .88717 L F
.341 0 .182 r
.60393 .75121 m .60595 .75121 L .60672 .74961 L F
.522 .277 .485 r
.60337 .75353 m .60595 .75121 L .60393 .75121 L F
.246 0 .135 r
.60672 .74961 m .6078 .75054 L .60809 .74846 L F
.60672 .74961 m .60595 .75121 L .6078 .75054 L F
.667 .48 .622 r
.371 .84287 m .37305 .84279 L .37348 .8404 L F
.642 .456 .616 r
.37348 .8404 m .37305 .84279 L .37343 .84276 L F
.673 .494 .635 r
.37343 .84276 m .37578 .84022 L .37348 .8404 L F
.936 .699 .554 r
.54621 .79832 m .54488 .79547 L .54628 .79603 L F
.496 .323 .575 r
.4012 .75923 m .39934 .75969 L .40125 .75677 L F
.449 .202 .445 r
.4012 .75923 m .39889 .76158 L .39934 .75969 L F
.956 .744 .29 r
.56434 .84278 m .56472 .84577 L .5643 .84451 L F
0 .134 .682 r
.5643 .84451 m .56472 .84577 L .56681 .84807 L F
.281 0 0 r
.44247 .82644 m .44464 .82623 L .44599 .82509 L F
.596 .107 .064 r
.44599 .82509 m .44464 .82623 L .44783 .82637 L F
.001 .571 .78 r
.56681 .84807 m .56809 .84832 L .56993 .84849 L F
.777 .729 .808 r
.4657 .84089 m .46645 .84303 L .46368 .84243 L F
.821 .612 .62 r
.46645 .84303 m .46394 .84506 L .46368 .84243 L F
.46645 .84303 m .46652 .84554 L .46394 .84506 L F
.623 .643 .85 r
.46874 .84271 m .46645 .84303 L .4657 .84089 L F
.598 .433 .629 r
.46874 .84271 m .46652 .84554 L .46645 .84303 L F
.386 .017 .21 r
.35823 .74847 m .35501 .75106 L .35623 .74911 L F
.961 .853 .439 r
.56256 .81887 m .56247 .82211 L .56232 .82143 L F
0 0 .288 r
.56247 .82211 m .56315 .82363 L .56232 .82143 L F
.56247 .82211 m .56386 .82528 L .56315 .82363 L F
.483 .196 .4 r
.38021 .77558 m .37791 .77743 L .37832 .77583 L F
.611 .456 .647 r
.41542 .85905 m .41327 .86102 L .41268 .8592 L F
.205 0 .112 r
.48133 .84 m .47867 .84213 L .47966 .84069 L F
0 0 0 r
.58437 .77283 m .58287 .77348 L .58086 .77418 L F
.287 .764 .654 r
.58546 .77235 m .58437 .77283 L .58612 .77199 L F
.58546 .77235 m .58287 .77348 L .58437 .77283 L F
.78 .732 .809 r
.63411 .74296 m .63203 .74389 L .63508 .74395 L F
.763 .731 .823 r
.63411 .74296 m .63508 .74395 L .63722 .74162 L F
.835 .538 .487 r
.57712 .84166 m .57484 .83985 L .57634 .84212 L F
.356 .827 .788 r
.5781 .84111 m .58 .84065 L .57712 .84166 L F
.5781 .84111 m .57712 .84166 L .57634 .84212 L F
.908 .877 .793 r
.62283 .75173 m .62569 .74936 L .62453 .74863 L F
.62283 .75173 m .62382 .7523 L .62569 .74936 L F
0 0 0 r
.67721 .75592 m .67595 .75701 L .67811 .75431 L F
.545 .343 .558 r
.67721 .75592 m .67507 .75874 L .67595 .75701 L F
.167 0 .142 r
.59883 .84016 m .60133 .83783 L .60062 .83986 L F
.156 .038 .456 r
.60235 .83493 m .60212 .83726 L .60133 .83783 L F
0 0 .06 r
.60133 .83783 m .60181 .83885 L .60062 .83986 L F
.60133 .83783 m .60212 .83726 L .60181 .83885 L F
.755 .994 .868 r
.62022 .73877 m .61765 .74089 L .61708 .7406 L F
.612 .3 .418 r
.44415 .83973 m .44267 .8426 L .44068 .84232 L F
.596 .283 .409 r
.4465 .84111 m .44415 .83973 L .44605 .84004 L F
.4465 .84111 m .44267 .8426 L .44415 .83973 L F
.75 .34 0 r
.56327 .84071 m .56386 .84239 L .5634 .83963 L F
.737 .496 0 r
.56368 .84145 m .5634 .83963 L .56386 .84239 L F
.56314 .83855 m .5634 .83963 L .56368 .84145 L F
.907 .823 .356 r
.56337 .83862 m .56334 .83925 L .5634 .83963 L F
.56334 .83925 m .56327 .84071 L .5634 .83963 L F
.75 .34 0 r
.56327 .84071 m .56434 .84278 L .56386 .84239 L F
0 0 0 r
.67887 .75203 m .67811 .75431 L .68007 .75162 L F
.67887 .75203 m .67869 .75382 L .67811 .75431 L F
.627 .786 .958 r
.67869 .75382 m .67721 .75592 L .67811 .75431 L F
.791 .745 .81 r
.52739 .84888 m .52844 .84494 L .52601 .84594 L F
.006 .535 .85 r
.56063 .79868 m .55989 .79882 L .55859 .79767 L F
.56063 .79868 m .56196 .79934 L .55989 .79882 L F
.223 .006 .358 r
.59838 .84203 m .59883 .84016 L .60062 .83986 L F
.601 .614 .836 r
.39239 .7434 m .39036 .74379 L .38898 .74107 L F
.575 .503 .736 r
.39317 .7468 m .39036 .74379 L .39239 .7434 L F
.589 .336 .5 r
.3586 .77489 m .36134 .77261 L .3587 .77257 L F
.609 .383 .549 r
.6172 .77525 m .61945 .77483 L .61946 .77257 L F
.647 .527 .702 r
.61946 .77257 m .62168 .77251 L .62151 .76994 L F
.621 .387 .541 r
.61945 .77483 m .62168 .77251 L .61946 .77257 L F
.824 .921 .901 r
.6733 .73401 m .6713 .73602 L .67037 .73536 L F
.601 .26 .365 r
.6713 .73602 m .67326 .73774 L .6709 .73705 L F
.631 .532 .723 r
.6733 .73401 m .67363 .73636 L .6713 .73602 L F
.618 .253 .328 r
.67363 .73636 m .67326 .73774 L .6713 .73602 L F
.122 0 0 r
.45649 .88516 m .4571 .88555 L .45465 .88616 L F
.45649 .88516 m .45876 .88515 L .4571 .88555 L F
.701 .354 .385 r
.57469 .77769 m .57512 .77798 L .57166 .7777 L F
.498 .468 .754 r
.57562 .7746 m .57512 .77798 L .57469 .77769 L F
.465 .839 .989 r
.47692 .83673 m .47605 .83762 L .47829 .83728 L F
0 .458 .806 r
.3643 .72954 m .36746 .73079 L .36597 .73037 L F
.571 .513 .751 r
.51105 .83639 m .51272 .83449 L .51063 .83511 L F
.51105 .83639 m .51306 .83589 L .51272 .83449 L F
.765 .682 .771 r
.61603 .75912 m .61919 .75939 L .61814 .75647 L F
.771 .657 .736 r
.61603 .75912 m .61719 .76209 L .61919 .75939 L F
.525 .311 .532 r
.36196 .78813 m .36156 .79007 L .35973 .79075 L F
.479 .251 .49 r
.36402 .78763 m .36156 .79007 L .36196 .78813 L F
.595 .602 .829 r
.50254 .82202 m .49933 .81949 L .50124 .81916 L F
.784 .708 .78 r
.50464 .81946 m .50254 .82202 L .50124 .81916 L F
.55 .252 .415 r
.47455 .82069 m .47694 .81931 L .47487 .81971 L F
.248 .751 .7 r
.51167 .88077 m .51514 .87966 L .51375 .88027 L F
.037 0 0 r
.51514 .87966 m .51502 .88013 L .51375 .88027 L F
.586 .243 .355 r
.51703 .87986 m .51892 .87981 L .51705 .88057 L F
.037 0 0 r
.51514 .87966 m .51718 .87934 L .51506 .88011 L F
.584 .179 .241 r
.51718 .87934 m .52006 .8788 L .51981 .87938 L F
.037 0 0 r
.51502 .88012 m .51506 .88011 L .51502 .88013 L F
.629 .716 .909 r
.51718 .87934 m .51694 .87674 L .51502 .88013 L F
.51718 .87934 m .51981 .87938 L .51694 .87674 L F
.586 .243 .355 r
.51694 .87674 m .5188 .87963 L .51703 .87986 L F
.5188 .87963 m .51892 .87981 L .51703 .87986 L F
.037 0 0 r
.51514 .87966 m .51506 .88011 L .51502 .88012 L F
.811 .761 .806 r
.39578 .89627 m .39695 .89774 L .39945 .89521 L F
.577 .934 .932 r
.3973 .89737 m .40219 .8961 L .40061 .89687 L F
.3973 .89737 m .40061 .89687 L .39841 .8974 L F
.39841 .8974 m .40061 .89687 L .39947 .89742 L F
.401 .249 .558 r
.39945 .89521 m .3973 .89737 L .39947 .89742 L F
.39945 .89521 m .39757 .89853 L .3973 .89737 L F
.811 .761 .806 r
.39695 .89774 m .39757 .89853 L .39818 .89745 L F
.39695 .89774 m .39818 .89745 L .39945 .89521 L F
.139 0 0 r
.59133 .84736 m .59437 .8452 L .59321 .84669 L F
.072 0 0 r
.59321 .84669 m .59437 .8452 L .59598 .84495 L F
.954 .735 .569 r
.56064 .81407 m .56168 .81656 L .56031 .81621 L F
.899 .509 .272 r
.56031 .81621 m .56168 .81656 L .56256 .81887 L F
.641 .762 .936 r
.51557 .834 m .5189 .83469 L .51804 .8328 L F
.715 .455 .53 r
.5214 .83429 m .51804 .8328 L .5189 .83469 L F
.577 .715 .937 r
.5189 .83469 m .52154 .83509 L .5214 .83429 L F
.677 .516 .66 r
.52017 .83694 m .52154 .83509 L .5189 .83469 L F
.628 .65 .852 r
.41863 .87709 m .41648 .87844 L .41557 .87604 L F
.181 .536 .925 r
.50417 .81397 m .50333 .81463 L .50226 .81384 L F
.50417 .81397 m .50545 .81527 L .50333 .81463 L F
.724 .342 .326 r
.53663 .83219 m .53989 .83268 L .53801 .83413 L F
.464 .632 .927 r
.53586 .83779 m .53282 .83606 L .53481 .83536 L F
.646 .654 .843 r
.53782 .83709 m .53586 .83779 L .53481 .83536 L F
.583 .804 .984 r
.35363 .72802 m .35167 .72855 L .35028 .7276 L F
.753 .777 .873 r
.64024 .73079 m .63714 .73071 L .63916 .72966 L F
.77 .78 .862 r
.64266 .72857 m .64024 .73079 L .63916 .72966 L F
.398 0 .064 r
.40922 .82873 m .40856 .82731 L .40717 .82726 L F
.40922 .82873 m .41056 .82729 L .40856 .82731 L F
.788 .573 .61 r
.5958 .82464 m .59245 .82697 L .59409 .82411 L F
.5958 .82464 m .59617 .82745 L .59245 .82697 L F
.948 .89 .739 r
.58497 .82962 m .58662 .82796 L .58489 .82713 L F
.643 .471 .636 r
.3951 .87175 m .39451 .87466 L .39128 .87378 L F
.639 .509 .689 r
.39409 .87635 m .39128 .87378 L .39451 .87466 L F
.39409 .87635 m .39212 .8771 L .39128 .87378 L F
.653 .525 .696 r
.56085 .79073 m .55895 .79175 L .55851 .79095 L F
.593 .129 .122 r
.40944 .89439 m .40882 .89485 L .40591 .89447 L F
.838 .988 .717 r
.41015 .8924 m .40944 .89439 L .41128 .8939 L F
.41015 .8924 m .40882 .89485 L .40944 .89439 L F
.26 .769 .838 r
.55033 .79411 m .55286 .79362 L .55357 .79367 L F
.873 .994 .791 r
.55357 .79367 m .55286 .79362 L .55423 .79167 L F
.699 .538 .666 r
.383 .83511 m .38538 .83508 L .38517 .83241 L F
.71 .448 .527 r
.38798 .83457 m .38517 .83241 L .38538 .83508 L F
.749 .518 .581 r
.41986 .86645 m .41638 .86822 L .41851 .86552 L F
.41986 .86645 m .41968 .86875 L .41638 .86822 L F
.405 .57 .903 r
.42054 .86509 m .41986 .86645 L .41851 .86552 L F
.42054 .86509 m .4214 .86628 L .41986 .86645 L F
.376 .201 .512 r
.4214 .86628 m .41968 .86875 L .41986 .86645 L F
.4214 .86628 m .41968 .86875 L .41986 .86645 L F
.626 .889 .988 r
.43236 .88931 m .4338 .88779 L .43114 .88893 L F
.43236 .88931 m .43518 .88831 L .4338 .88779 L F
.756 .584 .664 r
.52777 .84271 m .5285 .84276 L .52537 .84256 L F
.635 .552 .744 r
.52342 .84274 m .52777 .84271 L .52537 .84256 L F
.348 .465 .837 r
.53985 .84847 m .53813 .84821 L .5395 .8472 L F
.82 .99 .731 r
.53985 .84847 m .53962 .84903 L .53813 .84821 L F
0 0 0 r
.59557 .81863 m .59516 .81973 L .59445 .82182 L F
.406 .02 .191 r
.52937 .82447 m .53147 .82411 L .53249 .82226 L F
0 0 0 r
.53249 .82226 m .53298 .82258 L .53466 .82093 L F
.53249 .82226 m .53147 .82411 L .53298 .82258 L F
.48475 .85567 m .48379 .8565 L .48253 .85825 L F
.292 0 0 r
.5733 .8493 m .57598 .84958 L .57625 .84953 L F
.137 0 0 r
.57156 .84949 m .5733 .8493 L .57625 .84953 L F
.116 .666 .805 r
.53343 .81421 m .53061 .81426 L .53343 .81426 L F
.386 .836 .737 r
.53476 .81349 m .53343 .81421 L .53343 .81426 L F
.589 .336 .5 r
.3586 .77489 m .36093 .7748 L .36134 .77261 L F
.403 .17 .442 r
.36134 .77261 m .36263 .77422 L .3632 .77239 L F
.36134 .77261 m .36093 .7748 L .36263 .77422 L F
.704 .53 .651 r
.39832 .87115 m .39636 .87162 L .39838 .86896 L F
.675 .497 .637 r
.40216 .86883 m .39832 .87115 L .39838 .86896 L F
.748 .759 .862 r
.63475 .73251 m .63165 .73226 L .63395 .73091 L F
.75 .834 .916 r
.63714 .73071 m .63475 .73251 L .63395 .73091 L F
.479 .2 .412 r
.37603 .7779 m .37546 .77979 L .37349 .78013 L F
.474 .195 .409 r
.37742 .77941 m .37603 .7779 L .37791 .77743 L F
.37742 .77941 m .37546 .77979 L .37603 .7779 L F
.612 .303 .422 r
.62685 .77164 m .62911 .7718 L .62703 .77006 L F
.754 .501 .55 r
.49373 .81131 m .49727 .81294 L .49683 .80986 L F
.743 .493 .552 r
.49683 .80986 m .49727 .81294 L .50068 .81179 L F
.608 .658 .873 r
.5303 .84038 m .53084 .84216 L .53261 .84001 L F
.931 .732 .612 r
.57086 .80089 m .57187 .80378 L .57205 .8013 L F
.66 .486 .637 r
.42876 .84806 m .4289 .85072 L .42701 .85067 L F
.717 .529 .635 r
.43234 .85062 m .4289 .85072 L .42876 .84806 L F
.799 .993 .874 r
.51617 .87162 m .51281 .87362 L .51651 .87399 L F
.763 .364 .298 r
.51651 .87399 m .51699 .87343 L .51617 .87162 L F
.789 .789 .853 r
.62804 .7343 m .62416 .73531 L .62658 .73309 L F
.797 .798 .853 r
.62955 .73287 m .62804 .7343 L .62658 .73309 L F
.757 .516 .568 r
.52034 .82954 m .51716 .82739 L .52043 .82717 L F
.236 .212 .627 r
.52043 .82717 m .52142 .82682 L .52042 .82485 L F
.389 .292 .623 r
.52034 .82954 m .52142 .82682 L .52043 .82717 L F
.236 .212 .627 r
.52043 .82717 m .52142 .82682 L .52042 .82485 L F
.389 .292 .623 r
.52142 .82682 m .52034 .82954 L .52043 .82717 L F
.717 .929 .961 r
.4506 .8737 m .44898 .87477 L .44749 .87446 L F
.974 .694 .434 r
.54933 .81896 m .54983 .81679 L .54913 .8167 L F
.54933 .81896 m .55038 .81961 L .54983 .81679 L F
.697 .552 .686 r
.37794 .83754 m .38083 .83773 L .38084 .83555 L F
.666 .527 .685 r
.38084 .83555 m .38083 .83773 L .383 .83511 L F
.642 .642 .835 r
.40598 .87899 m .40285 .87695 L .40473 .87615 L F
.664 .595 .768 r
.40809 .87689 m .40598 .87899 L .40473 .87615 L F
.608 .25 .337 r
.66115 .7564 m .66626 .75633 L .66444 .75437 L F
.201 .721 .702 r
.66462 .75554 m .66536 .75534 L .66537 .75536 L F
0 0 0 r
.66537 .75536 m .66694 .75492 L .66732 .75427 L F
.201 .721 .702 r
.66536 .75534 m .66694 .75492 L .66537 .75536 L F
.514 0 0 r
.66537 .75536 m .66444 .75437 L .66538 .75539 L F
.66537 .75536 m .66538 .75539 L .66626 .75633 L F
.66537 .75536 m .66552 .75521 L .66444 .75437 L F
.457 .089 .251 r
.66552 .75521 m .66665 .75429 L .66444 .75437 L F
.599 .608 .832 r
.40197 .75348 m .40125 .75677 L .39982 .75371 L F
.40197 .75348 m .40334 .75642 L .40125 .75677 L F
.543 .353 .574 r
.40334 .75642 m .4012 .75923 L .40125 .75677 L F
.662 .757 .921 r
.47416 .84458 m .47501 .84561 L .4717 .84533 L F
.51 .565 .848 r
.47608 .84444 m .47501 .84561 L .47416 .84458 L F
.47608 .84444 m .47674 .84536 L .47501 .84561 L F
.545 .46 .71 r
.47769 .84803 m .47501 .84561 L .47674 .84536 L F
.47769 .84803 m .47584 .84857 L .47501 .84561 L F
.27 0 0 r
.5334 .8054 m .5364 .80622 L .53451 .80594 L F
.627 .791 .961 r
.42172 .82589 m .41914 .82688 L .41791 .82599 L F
.707 .291 .257 r
.50373 .82954 m .50579 .83135 L .50692 .82989 L F
.53 0 0 r
.50692 .82989 m .50677 .8303 L .50373 .82954 L F
0 0 0 r
.508 .82895 m .50677 .8303 L .50692 .82989 L F
.763 .664 .752 r
.50638 .83059 m .508 .82895 L .50692 .82989 L F
.692 .307 .314 r
.50373 .82954 m .50237 .83142 L .50579 .83135 L F
.50373 .82954 m .50237 .83142 L .50579 .83135 L F
.42 0 0 r
.50373 .82954 m .50677 .8303 L .50378 .82988 L F
.716 .804 .92 r
.50378 .82988 m .50668 .83029 L .508 .82895 L F
.50668 .83029 m .50677 .8303 L .508 .82895 L F
.763 .664 .752 r
.50579 .83135 m .508 .82895 L .50638 .83059 L F
.653 .128 0 r
.53527 .82825 m .53728 .83001 L .53656 .82963 L F
.943 .877 .74 r
.53663 .83219 m .53656 .82963 L .53728 .83001 L F
.497 .241 .455 r
.39889 .76158 m .39655 .76352 L .39695 .76198 L F
.889 .902 .489 r
.5643 .8264 m .56427 .82771 L .56341 .82979 L F
0 0 0 r
.53798 .8421 m .53949 .84117 L .54138 .84031 L F
.805 .646 .686 r
.49634 .81951 m .4943 .82235 L .49395 .81931 L F
.661 .576 .749 r
.49875 .82169 m .49634 .81951 L .49933 .81949 L F
.763 .364 .298 r
.51651 .87399 m .51929 .87436 L .51699 .87343 L F
.796 .459 .419 r
.51839 .87645 m .51929 .87436 L .51651 .87399 L F
.54 .101 .156 r
.52038 .87618 m .51929 .87436 L .51839 .87645 L F
.52038 .87618 m .52148 .87459 L .51929 .87436 L F
.168 .285 .742 r
.56341 .82979 m .5644 .83283 L .56537 .83175 L F
.181 .307 .757 r
.56537 .83175 m .5644 .83283 L .56539 .83312 L F
.843 .738 .748 r
.67941 .74892 m .67887 .75203 L .68007 .75162 L F
.71 .731 .867 r
.41151 .87747 m .40809 .87689 L .41006 .87611 L F
.72 .72 .85 r
.41351 .87642 m .41151 .87747 L .41006 .87611 L F
.333 0 .177 r
.52006 .8788 m .52276 .87711 L .52197 .87828 L F
0 0 0 r
.52197 .87828 m .52276 .87711 L .52428 .87621 L F
.665 .286 .318 r
.44951 .83971 m .4482 .84182 L .44605 .84004 L F
.689 .353 .402 r
.45125 .84023 m .4482 .84182 L .44951 .83971 L F
.641 .473 .64 r
.37578 .84022 m .3786 .84027 L .37794 .83754 L F
.681 .498 .632 r
.37794 .83754 m .38079 .84003 L .38083 .83773 L F
.37794 .83754 m .3786 .84027 L .38079 .84003 L F
.489 0 0 r
.37617 .73056 m .37799 .73151 L .37933 .73156 L F
0 .458 .827 r
.37998 .73146 m .37933 .73156 L .37799 .73151 L F
.37998 .73146 m .38161 .73241 L .37933 .73156 L F
0 0 0 r
.66271 .76319 m .66215 .76347 L .66081 .76403 L F
.66081 .76403 m .66215 .76347 L .66043 .76451 L F
0 0 .01 r
.55041 .8389 m .54985 .84124 L .54987 .84183 L F
.412 .132 .376 r
.36156 .79007 m .35919 .79284 L .35973 .79075 L F
.321 .692 .98 r
.38143 .7514 m .38171 .75036 L .37906 .74873 L F
.38143 .7514 m .38274 .75114 L .38171 .75036 L F
.552 .331 .533 r
.38505 .77211 m .38267 .77455 L .38297 .77246 L F
.748 .646 .747 r
.61393 .76174 m .61719 .76209 L .61603 .75912 L F
.216 .714 .914 r
.52173 .81087 m .5225 .81044 L .52228 .81088 L F
0 0 0 r
.52099 .81161 m .52109 .81191 L .5225 .81044 L F
.609 .868 .526 r
.5225 .81044 m .52109 .81191 L .52273 .80997 L F
.5225 .81044 m .52273 .80997 L .52318 .80944 L F
.216 .714 .914 r
.52228 .81088 m .5225 .81044 L .52397 .8109 L F
0 0 0 r
.52173 .81087 m .52099 .81161 L .5225 .81044 L F
.651 .796 .952 r
.41889 .89193 m .42018 .89293 L .42216 .89224 L F
.647 .589 .775 r
.38287 .75934 m .3841 .75631 L .38219 .75668 L F
.38287 .75934 m .38513 .75927 L .3841 .75631 L F
.404 .057 .26 r
.38251 .761 m .38513 .75927 L .38287 .75934 L F
.943 .642 .439 r
.67351 .7271 m .67454 .7255 L .6737 .72482 L F
.67351 .7271 m .67491 .72786 L .67454 .7255 L F
.122 0 0 r
.65355 .76723 m .65426 .76795 L .65241 .76845 L F
.65355 .76723 m .65555 .76654 L .65426 .76795 L F
.509 .142 .279 r
.58614 .76166 m .58943 .75972 L .58657 .76117 L F
.58614 .76166 m .58833 .76149 L .58943 .75972 L F
.504 .137 .276 r
.58943 .75972 m .59136 .76087 L .59147 .75917 L F
.58943 .75972 m .58833 .76149 L .59136 .76087 L F
.677 .516 .66 r
.52017 .83694 m .52204 .83755 L .52154 .83509 L F
.195 .406 .841 r
.52154 .83509 m .52269 .83485 L .5214 .83429 L F
.603 .467 .669 r
.52154 .83509 m .52383 .83528 L .52269 .83485 L F
.52154 .83509 m .52204 .83755 L .52383 .83528 L F
.506 .249 .459 r
.38995 .76755 m .38953 .76953 L .38752 .76984 L F
.495 .239 .455 r
.39155 .76914 m .38995 .76755 L .39191 .7672 L F
.39155 .76914 m .38953 .76953 L .38995 .76755 L F
.543 .446 .694 r
.48594 .85852 m .48475 .85567 L .48485 .85758 L F
.975 .739 .516 r
.48468 .86064 m .48594 .85852 L .48485 .85758 L F
.48468 .86064 m .48587 .8611 L .48594 .85852 L F
.524 .365 .608 r
.38219 .75668 m .3841 .75631 L .38405 .75397 L F
.416 .265 .567 r
.61107 .78544 m .61303 .78706 L .61349 .78587 L F
.61107 .78544 m .61141 .78786 L .61303 .78706 L F
.593 .772 .965 r
.38706 .74161 m .38378 .74102 L .38588 .73992 L F
.614 .664 .875 r
.38898 .74107 m .38706 .74161 L .38588 .73992 L F
.518 0 0 r
.37786 .74869 m .37588 .74919 L .3743 .74834 L F
.667 .245 .234 r
.37906 .74873 m .37588 .74919 L .37786 .74869 L F
.805 .853 .886 r
.63628 .74084 m .63924 .7406 L .63833 .738 L F
.63628 .74084 m .63722 .74162 L .63924 .7406 L F
.748 .736 .841 r
.63833 .738 m .63924 .7406 L .64145 .73835 L F
.543 .353 .573 r
.35654 .77637 m .3586 .77489 L .35801 .77498 L F
.35654 .77637 m .35689 .77745 L .3586 .77489 L F
.464 .308 .584 r
.35654 .77754 m .35689 .77745 L .35654 .77637 L F
.543 .353 .573 r
.35654 .77637 m .3586 .77489 L .35801 .77498 L F
.35654 .77637 m .35689 .77745 L .3586 .77489 L F
.695 .412 .49 r
.5957 .76742 m .59592 .76946 L .59359 .76743 L F
.47 .228 .464 r
.60828 .809 m .61077 .80656 L .61037 .8086 L F
.436 .231 .502 r
.61077 .80656 m .61284 .8039 L .61231 .80588 L F
.336 .12 .431 r
.61037 .8086 m .61077 .80656 L .61231 .80588 L F
.639 .794 .957 r
.41594 .827 m .4141 .82776 L .41263 .82662 L F
.589 .098 0 r
.6818 .73719 m .68133 .73651 L .6808 .73548 L F
.6818 .73719 m .68299 .73843 L .68133 .73651 L F
.023 0 .436 r
.5723 .82185 m .56987 .81966 L .572 .81912 L F
.831 .829 .846 r
.62675 .74634 m .62972 .74614 L .62844 .74528 L F
.809 .876 .896 r
.62844 .74528 m .62972 .74614 L .63203 .74389 L F
.771 .636 .712 r
.53388 .82873 m .5312 .83174 L .5319 .83003 L F
0 0 0 r
.50186 .83385 m .50132 .83412 L .49931 .83456 L F
.67 .709 .876 r
.50186 .83385 m .50468 .8336 L .50547 .83371 L F
.276 0 0 r
.37982 .76199 m .37799 .76237 L .3767 .76378 L F
0 .149 .69 r
.60689 .82387 m .60654 .82468 L .60508 .82176 L F
.065 0 .377 r
.60769 .82613 m .60654 .82468 L .60689 .82387 L F
.60769 .82613 m .60624 .82691 L .60654 .82468 L F
.622 .322 .439 r
.6476 .7302 m .6501 .73002 L .65074 .72793 L F
.344 0 .163 r
.6501 .73002 m .65292 .72775 L .65074 .72793 L F
.801 .405 .303 r
.57634 .84212 m .57484 .83985 L .57318 .83999 L F
.372 .527 .882 r
.38097 .7358 m .38082 .73775 L .37925 .73564 L F
.38097 .7358 m .38254 .73801 L .38082 .73775 L F
.512 .312 .546 r
.60821 .81122 m .60828 .809 L .61037 .8086 L F
.605 .528 .74 r
.56725 .79319 m .56743 .79606 L .5694 .79508 L F
.525 .92 .855 r
.58147 .83983 m .58 .84065 L .5781 .84111 L F
.65 .867 .981 r
.42738 .87681 m .42405 .87694 L .42622 .87671 L F
.531 .878 .987 r
.42939 .87621 m .42738 .87681 L .42809 .87586 L F
.579 .93 .946 r
.42738 .87681 m .42622 .87671 L .42809 .87586 L F
.639 .224 .24 r
.5375 .81748 m .53599 .81895 L .53388 .81762 L F
.217 0 .298 r
.53877 .81651 m .53644 .81904 L .5375 .81748 L F
.842 .97 .652 r
.53644 .81904 m .53599 .81895 L .5375 .81748 L F
.896 .977 .685 r
.52193 .82231 m .51888 .82312 L .52138 .82408 L F
.827 .451 .342 r
.52138 .82408 m .52376 .82456 L .52193 .82231 L F
.703 .468 .565 r
.6799 .73848 m .67671 .74031 L .67727 .73849 L F
.6799 .73848 m .68004 .74133 L .67671 .74031 L F
.631 .412 .566 r
.68209 .74026 m .68004 .74133 L .6799 .73848 L F
.673 .494 .635 r
.37343 .84276 m .37595 .84273 L .37578 .84022 L F
.633 .458 .628 r
.37595 .84273 m .3786 .84027 L .37578 .84022 L F
.633 .48 .657 r
.383 .83511 m .38083 .83773 L .38306 .83744 L F
.612 .419 .597 r
.38079 .84003 m .38306 .83744 L .38083 .83773 L F
.564 .396 .613 r
.41327 .86102 m .41335 .86406 L .4108 .86413 L F
.597 .448 .651 r
.41329 .86576 m .4108 .86413 L .41335 .86406 L F
.41329 .86576 m .41115 .86622 L .4108 .86413 L F
.502 .089 .19 r
.65574 .75849 m .65899 .75699 L .65694 .7575 L F
.672 .868 .973 r
.36346 .74836 m .36588 .7482 L .36558 .74785 L F
.253 .735 .93 r
.36892 .74818 m .36558 .74785 L .36588 .7482 L F
.933 .682 .535 r
.49395 .81931 m .4943 .82235 L .49278 .81896 L F
.461 .132 .322 r
.59648 .75612 m .59871 .75597 L .59908 .75444 L F
.547 .211 .349 r
.59871 .75597 m .60091 .75583 L .59908 .75444 L F
.494 .234 .449 r
.59908 .75444 m .60091 .75583 L .60118 .75396 L F
.842 .888 .873 r
.57465 .78253 m .57428 .78431 L .57711 .78159 L F
.359 0 0 r
.66914 .72784 m .67149 .72805 L .67265 .72762 L F
.333 .181 .52 r
.67149 .72805 m .66914 .72784 L .67265 .72762 L F
.061 .225 .72 r
.67265 .72762 m .67351 .7271 L .67149 .72805 L F
.67265 .72762 m .67452 .73005 L .67351 .7271 L F
.565 .687 .922 r
.48457 .84007 m .48481 .83734 L .48362 .8389 L F
.48457 .84007 m .48674 .8398 L .48481 .83734 L F
.743 .437 .464 r
.4932 .83393 m .49427 .83532 L .49237 .83436 L F
.574 .626 .866 r
.49297 .83223 m .4932 .83393 L .49509 .83198 L F
.633 .511 .697 r
.59749 .80898 m .60046 .80935 L .59955 .80653 L F
.551 .386 .611 r
.59749 .80898 m .59752 .81133 L .59958 .81096 L F
.305 0 .121 r
.51981 .87938 m .52006 .8788 L .52197 .87828 L F
.688 .316 .335 r
.45465 .84019 m .4533 .84215 L .45125 .84023 L F
.743 .383 .371 r
.45465 .84019 m .4567 .84248 L .4533 .84215 L F
.118 .518 .912 r
.57363 .81709 m .57283 .8172 L .57284 .81635 L F
.021 0 .191 r
.572 .81912 m .57283 .8172 L .57363 .81709 L F
.809 .743 .791 r
.54864 .83069 m .54776 .83076 L .54976 .82972 L F
.717 .545 .656 r
.37099 .84523 m .37305 .84279 L .371 .84287 L F
.728 .6 .714 r
.67691 .73577 m .6733 .73401 L .6757 .73341 L F
.67691 .73577 m .67363 .73636 L .6733 .73401 L F
.541 .151 .252 r
.67691 .73577 m .67326 .73774 L .67363 .73636 L F
.67691 .73577 m .67633 .73777 L .67326 .73774 L F
.616 .58 .791 r
.67767 .73245 m .67691 .73577 L .6757 .73341 L F
.67767 .73245 m .67929 .73443 L .67691 .73577 L F
.98 .688 .363 r
.67691 .73577 m .67727 .73849 L .67633 .73777 L F
.693 .468 .577 r
.43766 .85296 m .43565 .85043 L .43781 .85081 L F
.599 .52 .737 r
.43969 .84903 m .44057 .85075 L .43781 .85081 L F
.522 .258 .456 r
.44057 .85075 m .43766 .85296 L .43781 .85081 L F
.675 .497 .637 r
.40216 .86883 m .40236 .87279 L .39832 .87115 L F
.579 .423 .634 r
.4037 .87131 m .40216 .86883 L .40376 .86887 L F
.697 .613 .759 r
.4037 .87131 m .4052 .87458 L .40147 .87372 L F
0 0 .043 r
.4037 .87131 m .40147 .87372 L .40236 .87279 L F
.579 .423 .634 r
.4037 .87131 m .40236 .87279 L .40216 .86883 L F
.323 .073 .371 r
.43555 .84308 m .43535 .84477 L .43416 .84422 L F
.476 .488 .791 r
.43535 .84477 m .43468 .84779 L .43416 .84422 L F
.207 0 0 r
.50658 .81486 m .50755 .81493 L .50878 .81407 L F
.526 .086 .147 r
.50755 .81493 m .51093 .81392 L .50878 .81407 L F
.50755 .81493 m .50977 .81546 L .51093 .81392 L F
.423 0 0 r
.50668 .81423 m .50865 .81501 L .50755 .81493 L F
.50865 .81501 m .50977 .81546 L .50755 .81493 L F
.207 0 0 r
.50545 .81527 m .50755 .81493 L .50658 .81486 L F
.433 .872 .894 r
.53481 .83536 m .53282 .83606 L .53108 .83617 L F
.634 .502 .685 r
.66242 .72046 m .66469 .72006 L .66438 .71779 L F
.629 .482 .663 r
.66469 .72006 m .6626 .72269 L .66242 .72046 L F
.66469 .72006 m .6626 .72269 L .66242 .72046 L F
.716 .334 .325 r
.51908 .86349 m .52233 .86374 L .52116 .86554 L F
.162 0 0 r
.52184 .8638 m .52233 .86374 L .51908 .86349 L F
.544 .92 .777 r
.5232 .86287 m .52233 .86374 L .52184 .8638 L F
0 0 0 r
.52116 .86554 m .52233 .86374 L .5232 .86287 L F
.466 .809 .999 r
.36892 .74818 m .37246 .74845 L .37096 .7479 L F
.379 .77 .988 r
.3743 .74834 m .37096 .7479 L .37246 .74845 L F
.761 .571 .64 r
.49691 .81368 m .50068 .81179 L .49727 .81294 L F
.49691 .81368 m .50024 .8142 L .50068 .81179 L F
.607 .036 0 r
.49343 .87833 m .49272 .8772 L .49176 .8774 L F
.49343 .87833 m .49504 .87882 L .49272 .8772 L F
.546 .379 .605 r
.49272 .8772 m .49484 .87869 L .4947 .87652 L F
.49484 .87869 m .49499 .87849 L .4947 .87652 L F
.575 .399 .605 r
.4947 .87652 m .49504 .87882 L .49658 .8765 L F
.889 .85 .799 r
.49651 .87645 m .49343 .87833 L .49554 .87569 L F
.49658 .8765 m .49639 .87661 L .49651 .87645 L F
.49639 .87661 m .49343 .87833 L .49651 .87645 L F
.546 .379 .605 r
.49484 .87869 m .49504 .87882 L .49499 .87849 L F
.505 .057 .119 r
.59359 .76743 m .59279 .76888 L .59089 .76894 L F
.762 .34 .249 r
.59359 .76743 m .59592 .76946 L .59279 .76888 L F
.656 .512 .676 r
.60604 .81158 m .60662 .81385 L .60397 .81419 L F
.675 .545 .698 r
.60662 .81385 m .60411 .81657 L .60397 .81419 L F
.773 .383 .315 r
.48995 .84067 m .48863 .84206 L .48674 .8398 L F
.681 .26 .239 r
.49196 .8423 m .48863 .84206 L .48995 .84067 L F
.141 .071 .51 r
.57274 .81333 m .57127 .81154 L .5714 .81145 L F
.57274 .81333 m .57141 .8135 L .57127 .81154 L F
.462 .177 .393 r
.47707 .85008 m .47584 .84857 L .47769 .84803 L F
.47707 .85008 m .47489 .85052 L .47584 .84857 L F
.436 .013 .136 r
.6066 .76423 m .60547 .76608 L .60326 .76632 L F
.575 .237 .36 r
.60859 .76363 m .60547 .76608 L .6066 .76423 L F
.797 .798 .852 r
.62955 .73287 m .62658 .73309 L .62884 .73095 L F
.648 .663 .85 r
.63066 .72981 m .62955 .73287 L .62884 .73095 L F
.63066 .72981 m .63165 .73226 L .62955 .73287 L F
.505 .907 .909 r
.38389 .90201 m .38421 .90127 L .38257 .90154 L F
.38389 .90201 m .38635 .9011 L .38421 .90127 L F
.675 .503 .645 r
.39617 .87384 m .3951 .87175 L .39636 .87162 L F
.39617 .87384 m .39451 .87466 L .3951 .87175 L F
.992 .865 .522 r
.57556 .83263 m .57549 .82919 L .57457 .83227 L F
.715 .628 .76 r
.60304 .82234 m .60271 .82397 L .60093 .82475 L F
0 .197 .726 r
.55372 .82915 m .55327 .82986 L .55156 .82694 L F
0 .061 .623 r
.55479 .832 m .55327 .82986 L .55372 .82915 L F
.442 .293 .583 r
.55479 .832 m .55335 .83103 L .55327 .82986 L F
.745 .757 .862 r
.68745 .71258 m .68819 .71476 L .68496 .71454 L F
.784 .599 .651 r
.68496 .71454 m .68819 .71476 L .68695 .71784 L F
.735 .543 .632 r
.68819 .71476 m .68857 .71787 L .68695 .71784 L F
.628 .656 .858 r
.68913 .71175 m .68819 .71476 L .68745 .71258 L F
.68913 .71175 m .69049 .71424 L .68819 .71476 L F
.522 .36 .603 r
.69049 .71424 m .68857 .71787 L .68819 .71476 L F
.671 .484 .624 r
.43459 .853 m .43234 .85062 L .43565 .85043 L F
.693 .468 .577 r
.43766 .85296 m .43459 .853 L .43565 .85043 L F
.577 .354 .54 r
.38306 .83744 m .38538 .83508 L .383 .83511 L F
.67 .544 .702 r
.62151 .76994 m .62168 .77251 L .62454 .77186 L F
.135 0 0 r
.47455 .87197 m .47239 .87223 L .47084 .87301 L F
.763 .915 .94 r
.44012 .87405 m .43823 .87509 L .43718 .87472 L F
.476 .488 .791 r
.43535 .84477 m .43642 .84794 L .43468 .84779 L F
.743 .552 .636 r
.4074 .86883 m .4037 .87131 L .40376 .86887 L F
.4074 .86883 m .40712 .87202 L .4037 .87131 L F
.611 .436 .62 r
.40898 .8712 m .4074 .86883 L .40906 .86885 L F
.40898 .8712 m .40712 .87202 L .4074 .86883 L F
0 0 0 r
.64194 .76503 m .64135 .76524 L .64419 .76441 L F
.671 .277 .291 r
.48906 .86834 m .49241 .86816 L .48999 .86666 L F
.641 .399 .537 r
.51716 .82739 m .51515 .82881 L .51439 .82717 L F
.653 .341 .431 r
.50696 .83404 m .50363 .83636 L .50547 .83371 L F
.251 0 0 r
.50468 .8336 m .50696 .83404 L .50547 .83371 L F
.731 .758 .874 r
.50468 .8336 m .50791 .83286 L .50696 .83404 L F
0 0 0 r
.50898 .8319 m .50696 .83404 L .50791 .83286 L F
.993 .829 .577 r
.53474 .84778 m .53483 .84831 L .53388 .84907 L F
.971 .728 .51 r
.53483 .84831 m .53464 .85115 L .53388 .84907 L F
.782 .282 0 r
.54883 .80134 m .5487 .80234 L .54682 .80024 L F
.844 .382 .011 r
.54883 .80134 m .54973 .80286 L .5487 .80234 L F
.69 .527 .661 r
.40751 .87408 m .4052 .87458 L .40678 .87341 L F
.40751 .87408 m .40473 .87615 L .4052 .87458 L F
.40751 .87408 m .40809 .87689 L .40473 .87615 L F
.62 .563 .769 r
.40898 .8712 m .40751 .87408 L .40678 .87341 L F
.40898 .8712 m .41011 .87417 L .40751 .87408 L F
.657 .506 .667 r
.41006 .87611 m .40751 .87408 L .41011 .87417 L F
.41006 .87611 m .40809 .87689 L .40751 .87408 L F
.601 .307 .442 r
.39977 .83173 m .40047 .82919 L .39777 .83007 L F
.571 .402 .613 r
.40047 .82919 m .4026 .82948 L .40289 .82639 L F
.692 .465 .573 r
.39977 .83173 m .4026 .82948 L .40047 .82919 L F
.137 0 .374 r
.60235 .83493 m .6044 .83194 L .60411 .83417 L F
.123 .011 .442 r
.60372 .8363 m .60235 .83493 L .60411 .83417 L F
.60372 .8363 m .60212 .83726 L .60235 .83493 L F
.334 .159 .488 r
.61417 .80317 m .61284 .8039 L .61444 .80099 L F
.269 .045 .378 r
.61231 .80588 m .61284 .8039 L .61417 .80317 L F
.153 .693 .723 r
.58263 .84929 m .58437 .84902 L .58641 .84864 L F
.235 0 .2 r
.52613 .87094 m .52386 .87392 L .52528 .87367 L F
.219 0 .17 r
.5278 .87095 m .52613 .87094 L .52528 .87367 L F
.786 .651 .713 r
.5152 .82446 m .52031 .82507 L .51888 .82312 L F
.33 .482 .86 r
.51888 .82312 m .52031 .82507 L .52138 .82408 L F
.537 .048 .042 r
.52031 .82507 m .52062 .82625 L .52138 .82408 L F
.52031 .82507 m .5174 .82639 L .52062 .82625 L F
.577 .354 .54 r
.38306 .83744 m .38511 .8373 L .38538 .83508 L F
.62 .391 .549 r
.38538 .83508 m .38781 .83692 L .38798 .83457 L F
.38538 .83508 m .38511 .8373 L .38781 .83692 L F
.563 .374 .583 r
.60604 .81158 m .60821 .81122 L .60821 .81355 L F
.437 .373 .688 r
.60821 .81355 m .60662 .81385 L .60604 .81158 L F
.563 .374 .583 r
.60604 .81158 m .60821 .81122 L .60821 .81355 L F
.566 .195 .298 r
.44783 .82637 m .45001 .82648 L .45123 .82445 L F
.561 .177 .271 r
.45001 .82648 m .4534 .82472 L .45123 .82445 L F
.621 .387 .541 r
.61945 .77483 m .62166 .77439 L .62168 .77251 L F
.601 .358 .521 r
.62166 .77439 m .62454 .77186 L .62168 .77251 L F
.823 .713 .744 r
.46222 .85062 m .45983 .85271 L .46246 .85099 L F
.709 .174 0 r
.46246 .85099 m .46358 .85215 L .46222 .85062 L F
.623 .442 .616 r
.42701 .85067 m .42703 .8531 L .42484 .85322 L F
.565 .396 .611 r
.42888 .85277 m .42701 .85067 L .4289 .85072 L F
.42888 .85277 m .42703 .8531 L .42701 .85067 L F
.642 .407 .548 r
.50371 .83951 m .50282 .84268 L .50061 .84257 L F
0 .102 .617 r
.50342 .83919 m .5044 .83997 L .50371 .83951 L F
.671 .437 .557 r
.50603 .84231 m .50371 .83951 L .5044 .83997 L F
.50603 .84231 m .50282 .84268 L .50371 .83951 L F
.558 .395 .617 r
.61541 .78015 m .61772 .77996 L .6174 .77743 L F
.464 .252 .506 r
.61563 .78237 m .61772 .77996 L .61541 .78015 L F
.542 .397 .634 r
.59546 .8142 m .59803 .81399 L .59752 .81133 L F
.478 .166 .358 r
.59686 .8155 m .59546 .8142 L .59568 .81629 L F
.59686 .8155 m .59803 .81399 L .59546 .8142 L F
.73 .384 .393 r
.50547 .83371 m .50363 .83636 L .50132 .83412 L F
.209 0 .031 r
.63174 .76911 m .6335 .769 L .6345 .7673 L F
.593 .945 .808 r
.63555 .76619 m .63619 .76603 L .6345 .7673 L F
0 0 .077 r
.6351 .76776 m .6345 .7673 L .6335 .769 L F
.6351 .76776 m .63555 .76619 L .6345 .7673 L F
.509 .15 .292 r
.46378 .82353 m .46592 .82346 L .4641 .82241 L F
.82 .99 .731 r
.53985 .84847 m .53928 .8496 L .53962 .84903 L F
.205 .125 .538 r
.53962 .84903 m .53928 .8496 L .53967 .84922 L F
.481 .555 .855 r
.53985 .84847 m .54021 .84869 L .53928 .8496 L F
.53967 .84922 m .54309 .85048 L .53928 .8496 L F
.586 .3 .448 r
.53928 .8496 m .54237 .85225 L .54031 .85183 L F
.53928 .8496 m .54309 .85048 L .54237 .85225 L F
.205 .125 .538 r
.53967 .84922 m .53928 .8496 L .54031 .85183 L F
.53949 .84926 m .54031 .85183 L .53831 .85135 L F
.53962 .84903 m .53967 .84922 L .53949 .84926 L F
.53967 .84922 m .54031 .85183 L .53949 .84926 L F
.481 .555 .855 r
.54021 .84869 m .54071 .849 L .53967 .84922 L F
.54071 .849 m .54309 .85048 L .53967 .84922 L F
.681 .892 .974 r
.42649 .89023 m .42793 .89084 L .4298 .88988 L F
.662 .577 .749 r
.60508 .82176 m .60271 .82397 L .60304 .82234 L F
.521 0 0 r
.5645 .79904 m .56755 .80017 L .56515 .7992 L F
0 0 0 r
.53466 .82093 m .53599 .81895 L .53644 .81904 L F
.949 .713 .547 r
.55967 .79239 m .56119 .79362 L .56085 .79073 L F
0 0 0 r
.56189 .7898 m .56085 .79073 L .56312 .79051 L F
.633 .489 .668 r
.56312 .79051 m .56119 .79362 L .56085 .79073 L F
0 0 0 r
.56189 .7898 m .55967 .79239 L .56085 .79073 L F
.801 .588 .614 r
.59006 .8293 m .59198 .83011 L .58848 .82953 L F
.806 .663 .705 r
.59198 .83011 m .58831 .83197 L .58848 .82953 L F
.59198 .83011 m .59133 .83232 L .58831 .83197 L F
.558 .54 .791 r
.59245 .82697 m .59198 .83011 L .59006 .8293 L F
.702 .552 .68 r
.59198 .83011 m .59407 .83214 L .59133 .83232 L F
.673 .782 .931 r
.42207 .87752 m .41863 .87709 L .42074 .87671 L F
.614 .826 .981 r
.42405 .87694 m .42207 .87752 L .42074 .87671 L F
.495 .268 .499 r
.37349 .78013 m .37321 .78221 L .37121 .78259 L F
.529 .306 .521 r
.37546 .77979 m .37321 .78221 L .37349 .78013 L F
.411 .861 .874 r
.47648 .8713 m .47316 .8721 L .47547 .87097 L F
.432 0 0 r
.47578 .87125 m .47648 .8713 L .47547 .87097 L F
.127 0 0 r
.47699 .87133 m .47455 .87197 L .47648 .8713 L F
.411 .861 .874 r
.47648 .8713 m .47455 .87197 L .47316 .8721 L F
.432 0 0 r
.47707 .87244 m .47648 .8713 L .47578 .87125 L F
.127 0 0 r
.47766 .87115 m .47699 .87133 L .47648 .8713 L F
.245 0 0 r
.47934 .87145 m .47766 .87115 L .47648 .8713 L F
0 0 0 r
.5703 .77246 m .57103 .77282 L .57219 .77176 L F
.5703 .77246 m .56902 .77383 L .57103 .77282 L F
.168 .182 .631 r
.48569 .87662 m .48463 .87624 L .48443 .87454 L F
.398 .473 .821 r
.48708 .87866 m .48463 .87624 L .48569 .87662 L F
.851 .971 .872 r
.62022 .73877 m .62069 .73692 L .62192 .73749 L F
.844 .944 .886 r
.62192 .73749 m .62311 .73467 L .62416 .73531 L F
.62192 .73749 m .62069 .73692 L .62311 .73467 L F
.756 .635 .727 r
.66914 .72784 m .66939 .73055 L .66744 .72921 L F
.844 .441 .278 r
.66939 .73055 m .66942 .73218 L .66744 .72921 L F
.333 .181 .52 r
.67149 .72805 m .66939 .73055 L .66914 .72784 L F
.67149 .72805 m .67138 .73082 L .66939 .73055 L F
.337 .031 .29 r
.67138 .73082 m .66942 .73218 L .66939 .73055 L F
.755 .994 .868 r
.62022 .73877 m .61708 .7406 L .61944 .73833 L F
.851 .971 .872 r
.62022 .73877 m .61944 .73833 L .62069 .73692 L F
0 0 0 r
.39947 .89742 m .40417 .89516 L .4028 .89452 L F
.702 .871 .961 r
.4028 .89452 m .40417 .89516 L .40591 .89447 L F
.785 .573 .614 r
.4717 .84533 m .46874 .84271 L .47089 .8443 L F
.4717 .84533 m .46898 .84573 L .46874 .84271 L F
.919 .692 .579 r
.4717 .84533 m .4697 .84747 L .46898 .84573 L F
.4717 .84533 m .4714 .84802 L .4697 .84747 L F
.628 .858 .986 r
.47416 .84458 m .4717 .84533 L .47089 .8443 L F
.684 .858 .965 r
.66083 .75157 m .66237 .75073 L .66055 .75052 L F
.625 .297 .396 r
.39977 .83173 m .39777 .83007 L .39674 .83159 L F
0 0 0 r
.39674 .83159 m .39777 .83007 L .39772 .83016 L F
.687 .534 .673 r
.41961 .85572 m .41753 .85844 L .41774 .85573 L F
.479 .1 .242 r
.40465 .82569 m .40289 .82639 L .40396 .82646 L F
.701 .223 .112 r
.40396 .82646 m .40717 .82726 L .40465 .82569 L F
.722 .563 .674 r
.39832 .87115 m .39617 .87384 L .39636 .87162 L F
.39832 .87115 m .39971 .87423 L .39617 .87384 L F
.668 .539 .699 r
.40147 .87372 m .39832 .87115 L .40236 .87279 L F
.40147 .87372 m .39971 .87423 L .39832 .87115 L F
.578 .126 .143 r
.48289 .87559 m .48044 .87441 L .48061 .87595 L F
.48289 .87559 m .48443 .87454 L .48044 .87441 L F
.047 0 .41 r
.48061 .87595 m .48044 .87441 L .48195 .87332 L F
0 0 0 r
.6391 .77533 m .63823 .77692 L .63659 .77754 L F
.64038 .77466 m .6391 .77533 L .64076 .77419 L F
.64038 .77466 m .63823 .77692 L .6391 .77533 L F
.764 .907 .938 r
.49906 .8851 m .5022 .88451 L .50126 .88445 L F
.472 .891 .903 r
.50126 .88445 m .5022 .88451 L .50377 .88384 L F
.67 .52 .672 r
.42173 .85754 m .41961 .85572 L .42232 .85513 L F
.61 .418 .598 r
.42484 .85322 m .42232 .85513 L .42162 .85305 L F
.42484 .85322 m .42468 .85525 L .42232 .85513 L F
.577 .327 .501 r
.42468 .85525 m .42173 .85754 L .42232 .85513 L F
.256 .762 .739 r
.66866 .76214 m .67004 .76164 L .66778 .76224 L F
.66866 .76214 m .67068 .76153 L .67004 .76164 L F
.054 0 0 r
.46915 .88279 m .46981 .88292 L .4677 .88303 L F
.46915 .88279 m .47113 .88279 L .46981 .88292 L F
.523 .6 .873 r
.52737 .83715 m .52945 .83722 L .52873 .83512 L F
.763 .731 .823 r
.63411 .74296 m .63722 .74162 L .63628 .74084 L F
.301 0 .028 r
.66915 .74856 m .67049 .74849 L .6728 .74792 L F
0 0 0 r
.52897 .87379 m .53196 .87138 L .53091 .87334 L F
.533 .87074 m .53581 .8681 L .53542 .87085 L F
.179 .683 .909 r
.533 .87074 m .5342 .8704 L .53349 .87056 L F
.567 .407 .624 r
.52994 .87096 m .53086 .87119 L .53248 .86828 L F
0 0 0 r
.53196 .87138 m .53255 .8709 L .533 .87074 L F
.53091 .87334 m .53196 .87138 L .533 .87074 L F
.567 .407 .624 r
.53086 .87119 m .5314 .87133 L .53164 .87101 L F
.892 .928 .836 r
.53099 .87188 m .53164 .87101 L .53103 .87113 L F
0 .525 .845 r
.53103 .87113 m .53183 .87143 L .5314 .87133 L F
.53103 .87113 m .5314 .87133 L .52994 .87096 L F
.892 .928 .836 r
.53152 .87139 m .533 .87074 L .53164 .87101 L F
.53091 .87334 m .53219 .87175 L .53152 .87139 L F
.53219 .87175 m .533 .87074 L .53152 .87139 L F
.53091 .87334 m .53164 .87101 L .53099 .87188 L F
.567 .407 .624 r
.53164 .87101 m .53183 .87143 L .53193 .87094 L F
.5314 .87133 m .53183 .87143 L .53164 .87101 L F
.53086 .87119 m .53193 .87094 L .53248 .86828 L F
0 0 0 r
.53301 .86599 m .53068 .8684 L .533 .86833 L F
.074 .636 .762 r
.53248 .86828 m .533 .86833 L .53068 .8684 L F
.53248 .86828 m .53068 .8684 L .52994 .87096 L F
.887 .726 .676 r
.53248 .86828 m .53193 .87094 L .53071 .86754 L F
.53193 .87094 m .53183 .87143 L .5317 .87099 L F
.53193 .87094 m .5317 .87099 L .53071 .86754 L F
.179 .683 .909 r
.53164 .87101 m .53186 .87096 L .53103 .87113 L F
.887 .726 .676 r
.53248 .86828 m .53193 .87094 L .53071 .86754 L F
.53193 .87094 m .53183 .87143 L .5317 .87099 L F
.53193 .87094 m .5317 .87099 L .53071 .86754 L F
.179 .683 .909 r
.533 .87074 m .53311 .8707 L .53164 .87101 L F
0 0 0 r
.53255 .8709 m .53448 .86934 L .533 .87074 L F
.179 .683 .909 r
.53311 .8707 m .53337 .87061 L .53193 .87094 L F
.53311 .8707 m .53193 .87094 L .53164 .87101 L F
.224 .313 .745 r
.53071 .86754 m .5317 .87099 L .53277 .86937 L F
.179 .683 .909 r
.53186 .87096 m .53209 .87089 L .5317 .87099 L F
.53209 .87089 m .5321 .87088 L .53208 .87089 L F
.53209 .87089 m .53208 .87089 L .5317 .87099 L F
.224 .313 .745 r
.5317 .87099 m .53208 .87089 L .53277 .86937 L F
.627 .793 .962 r
.53277 .86937 m .53208 .87089 L .53103 .87113 L F
.224 .313 .745 r
.5317 .87099 m .53183 .87143 L .53208 .87089 L F
.179 .683 .909 r
.5317 .87099 m .5321 .87088 L .5312 .87109 L F
.53186 .87096 m .5312 .87109 L .53103 .87113 L F
.627 .793 .962 r
.53208 .87089 m .53183 .87143 L .53103 .87113 L F
.179 .683 .909 r
.53186 .87096 m .53349 .87056 L .5321 .87088 L F
.53337 .87061 m .53349 .87056 L .53164 .87101 L F
.17 .697 .862 r
.54878 .83667 m .54961 .83633 L .54739 .83629 L F
.849 .713 .712 r
.57187 .80378 m .56968 .80614 L .57177 .8058 L F
.475 .203 .42 r
.36789 .78707 m .36648 .78563 L .36857 .78537 L F
.36789 .78707 m .36601 .78742 L .36648 .78563 L F
.611 .456 .647 r
.41542 .85905 m .41531 .86093 L .41327 .86102 L F
.6 .424 .616 r
.41534 .86332 m .41327 .86102 L .41531 .86093 L F
.41534 .86332 m .41335 .86406 L .41327 .86102 L F
.745 .664 .771 r
.4122 .87366 m .41351 .87642 L .41006 .87611 L F
.598 .514 .73 r
.41511 .87423 m .41351 .87642 L .4122 .87366 L F
.41511 .87423 m .41557 .87604 L .41351 .87642 L F
.727 .82 .923 r
.37085 .73069 m .36746 .73079 L .3696 .73035 L F
.584 .9 .985 r
.37304 .72996 m .37085 .73069 L .37152 .7296 L F
.586 .903 .983 r
.37152 .7296 m .37085 .73069 L .3696 .73035 L F
.843 .741 .751 r
.57641 .77983 m .57465 .78253 L .57711 .78159 L F
.24 .09 .467 r
.36541 .76953 m .36684 .76903 L .36649 .76692 L F
.383 .142 .42 r
.36541 .76953 m .36683 .7712 L .36684 .76903 L F
.36541 .76953 m .36519 .77189 L .36683 .7712 L F
.747 .644 .746 r
.37617 .73056 m .37408 .7332 L .37304 .72996 L F
.345 0 0 r
.48195 .81611 m .48126 .81648 L .48421 .81591 L F
.602 .65 .87 r
.54776 .83076 m .54479 .82983 L .547 .82937 L F
.541 .286 .478 r
.38752 .76984 m .3871 .77181 L .38505 .77211 L F
.482 .232 .458 r
.38906 .77145 m .38752 .76984 L .38953 .76953 L F
.38906 .77145 m .3871 .77181 L .38752 .76984 L F
.765 .386 .338 r
.48569 .87662 m .48443 .87454 L .48289 .87559 L F
.019 0 .053 r
.63659 .77754 m .63823 .77692 L .63587 .77946 L F
.775 .741 .822 r
.6451 .72767 m .64132 .72745 L .64355 .72506 L F
.765 .762 .85 r
.6451 .72767 m .64266 .72857 L .64132 .72745 L F
.8 .749 .805 r
.64685 .72532 m .6451 .72767 L .64355 .72506 L F
.399 .202 .493 r
.64685 .72532 m .64678 .72743 L .6451 .72767 L F
.576 .535 .772 r
.38405 .75397 m .38563 .75109 L .38274 .75114 L F
.38405 .75397 m .38604 .75364 L .38563 .75109 L F
.556 .395 .619 r
.3841 .75631 m .38604 .75364 L .38405 .75397 L F
.763 .915 .94 r
.44012 .87405 m .43718 .87472 L .43892 .87367 L F
.844 .939 .887 r
.44206 .87201 m .44012 .87405 L .43892 .87367 L F
.806 .479 .435 r
.46652 .84554 m .46531 .84744 L .46394 .84506 L F
.563 .191 .294 r
.46898 .84573 m .46531 .84744 L .46652 .84554 L F
.598 .433 .629 r
.46874 .84271 m .46898 .84573 L .46652 .84554 L F
.51 .222 .412 r
.37321 .78221 m .37036 .78491 L .37121 .78259 L F
.762 .56 .624 r
.43234 .85062 m .42888 .85277 L .4289 .85072 L F
.43234 .85062 m .43231 .85313 L .42888 .85277 L F
.671 .484 .624 r
.43459 .853 m .43231 .85313 L .43234 .85062 L F
.445 .112 .306 r
.53068 .8684 m .52869 .8686 L .5278 .87095 L F
.668 .379 .474 r
.36649 .76692 m .37028 .76704 L .36805 .76663 L F
.717 .545 .656 r
.37099 .84523 m .37212 .84525 L .37305 .84279 L F
.633 .453 .621 r
.37305 .84279 m .37346 .84508 L .37343 .84276 L F
.37305 .84279 m .37212 .84525 L .37346 .84508 L F
.641 .762 .936 r
.51557 .834 m .51804 .8328 L .51551 .8324 L F
.697 .585 .726 r
.51804 .8328 m .52175 .83356 L .52034 .82954 L F
.715 .455 .53 r
.5214 .83429 m .52175 .83356 L .51804 .8328 L F
.583 .355 .535 r
.5161 .81343 m .51832 .81329 L .51639 .81144 L F
0 0 0 r
.58859 .84831 m .58939 .84788 L .59133 .84736 L F
.429 .251 .536 r
.67342 .74241 m .67168 .74516 L .67338 .74438 L F
0 0 .156 r
.67338 .74438 m .67305 .7427 L .67342 .74241 L F
0 0 0 r
.67406 .7419 m .67222 .74314 L .67342 .74241 L F
0 0 .156 r
.67305 .7427 m .67263 .7406 L .67342 .74241 L F
0 0 0 r
.67489 .74134 m .67406 .7419 L .67342 .74241 L F
.675 .545 .698 r
.60662 .81385 m .60647 .81653 L .60411 .81657 L F
.639 .482 .654 r
.60591 .81868 m .60411 .81657 L .60647 .81653 L F
.60591 .81868 m .60538 .82064 L .60411 .81657 L F
0 0 0 r
.533 .87074 m .53448 .86934 L .53581 .8681 L F
.009 .576 .788 r
.57625 .84953 m .57598 .84958 L .57817 .84974 L F
.682 .594 .751 r
.46257 .86602 m .46087 .86886 L .46042 .86682 L F
.46257 .86602 m .46343 .86917 L .46087 .86886 L F
.352 .73 .987 r
.34895 .72682 m .35028 .7276 L .34839 .72764 L F
0 0 0 r
.44636 .87095 m .44756 .87051 L .44848 .87084 L F
.44756 .87051 m .44636 .87095 L .44848 .87084 L F
.44756 .87051 m .44543 .87254 L .44636 .87095 L F
0 .118 .621 r
.44613 .87334 m .44481 .87227 L .44497 .87234 L F
.44613 .87334 m .44589 .87337 L .44481 .87227 L F
.43 .87 .893 r
.44206 .87201 m .44345 .87117 L .44436 .87181 L F
.822 .352 .091 r
.44345 .87117 m .44487 .87307 L .44613 .87334 L F
0 0 0 r
.44543 .87254 m .44487 .87307 L .44529 .87248 L F
.44543 .87254 m .44529 .87248 L .44636 .87095 L F
0 .118 .621 r
.44497 .87234 m .44481 .87227 L .44436 .87181 L F
0 .199 .661 r
.44613 .87334 m .44749 .87446 L .44589 .87337 L F
.206 .019 .393 r
.49931 .83456 m .49765 .83725 L .49781 .83669 L F
.49931 .83456 m .49896 .83676 L .49765 .83725 L F
.592 .357 .528 r
.35084 .75144 m .35303 .75146 L .35077 .75192 L F
.442 .249 .522 r
.35645 .77847 m .35689 .77745 L .35654 .77754 L F
.74 .663 .775 r
.40473 .87615 m .40285 .87695 L .4052 .87458 L F
.344 0 .163 r
.6501 .73002 m .65203 .7299 L .65292 .72775 L F
.389 0 .149 r
.65203 .7299 m .65513 .72751 L .65292 .72775 L F
.747 .644 .746 r
.37617 .73056 m .37304 .72996 L .37456 .73003 L F
.425 0 0 r
.37456 .73003 m .37799 .73151 L .37617 .73056 L F
.564 .231 .363 r
.60108 .7652 m .60326 .76632 L .60169 .76641 L F
.455 .63 .929 r
.67806 .74342 m .67489 .74134 L .67671 .74031 L F
.604 .528 .742 r
.68004 .74133 m .67806 .74342 L .67671 .74031 L F
.68004 .74133 m .68032 .74316 L .67806 .74342 L F
.416 .281 .587 r
.68032 .74316 m .67857 .74658 L .67806 .74342 L F
.688 .469 .584 r
.48978 .8132 m .49227 .8159 L .49209 .8121 L F
.246 .134 .523 r
.49209 .8121 m .49229 .81206 L .49373 .81131 L F
.49209 .8121 m .49227 .8159 L .49229 .81206 L F
.541 .31 .515 r
.42703 .8531 m .42468 .85525 L .42484 .85322 L F
.2 0 0 r
.47327 .88293 m .47445 .88288 L .47676 .8833 L F
.599 .094 .024 r
.47445 .88288 m .47824 .88372 L .47676 .8833 L F
.492 .795 .999 r
.49299 .82973 m .49568 .82954 L .49381 .82874 L F
.537 .319 .531 r
.49297 .83223 m .49568 .82954 L .49299 .82973 L F
.577 .551 .789 r
.49381 .82874 m .49297 .83223 L .49299 .82973 L F
.605 .528 .74 r
.56725 .79319 m .5694 .79508 L .56839 .79497 L F
.865 .902 .857 r
.56798 .79372 m .57065 .79245 L .56975 .79213 L F
.605 .528 .74 r
.56725 .79319 m .56822 .79472 L .56765 .79319 L F
.56822 .79472 m .56839 .79497 L .56814 .79436 L F
.56822 .79472 m .56814 .79436 L .56765 .79319 L F
.968 .813 .635 r
.56765 .79319 m .56839 .79497 L .56727 .79435 L F
.865 .902 .857 r
.56727 .79435 m .56803 .79392 L .56798 .79372 L F
.56803 .79392 m .57065 .79245 L .56798 .79372 L F
.461 0 0 r
.54701 .79473 m .54911 .79501 L .55033 .79411 L F
0 0 0 r
.55033 .79411 m .55091 .79377 L .55286 .79362 L F
.55033 .79411 m .54911 .79501 L .55091 .79377 L F
.576 .319 .489 r
.59377 .75908 m .59602 .75889 L .59648 .75612 L F
.549 .295 .482 r
.59648 .75612 m .59886 .75793 L .59871 .75597 L F
.59648 .75612 m .59602 .75889 L .59886 .75793 L F
.868 .793 .774 r
.56825 .78155 m .57154 .7802 L .57083 .77891 L F
.56825 .78155 m .57139 .78066 L .57154 .7802 L F
.757 .571 .645 r
.57139 .78066 m .5722 .7825 L .57154 .7802 L F
.624 .411 .573 r
.37346 .84508 m .37595 .84273 L .37343 .84276 L F
.662 .908 .979 r
.43719 .88772 m .44029 .88729 L .43909 .88705 L F
.35 .777 .973 r
.44029 .88729 m .44121 .88665 L .43909 .88705 L F
.44029 .88729 m .44236 .88712 L .44121 .88665 L F
.318 .763 .962 r
.66278 .73577 m .66203 .73533 L .6596 .73545 L F
.6596 .73545 m .66203 .73533 L .66278 .73577 L F
.439 .854 .959 r
.50854 .88103 m .50966 .88127 L .51167 .88077 L F
.641 .399 .537 r
.51716 .82739 m .51661 .82961 L .51515 .82881 L F
.757 .516 .568 r
.52034 .82954 m .51661 .82961 L .51716 .82739 L F
0 0 0 r
.39674 .83159 m .39772 .83016 L .39514 .83172 L F
.671 .548 .707 r
.59955 .80653 m .60098 .8027 L .59863 .80335 L F
.759 .626 .713 r
.40147 .87372 m .40285 .87695 L .39948 .87656 L F
.703 .601 .739 r
.4052 .87458 m .40285 .87695 L .40147 .87372 L F
.988 .727 .43 r
.53663 .83219 m .5357 .83397 L .53532 .83189 L F
.53663 .83219 m .53683 .83477 L .5357 .83397 L F
.943 .877 .74 r
.53663 .83219 m .53532 .83189 L .53656 .82963 L F
.724 .342 .326 r
.53663 .83219 m .53801 .83413 L .53683 .83477 L F
.826 .694 .718 r
.57034 .80321 m .57187 .80378 L .57086 .80089 L F
.921 .95 .795 r
.56941 .80604 m .57187 .80378 L .57034 .80321 L F
.56941 .80604 m .56968 .80614 L .57187 .80378 L F
0 0 0 r
.53588 .84707 m .53474 .84778 L .53388 .84907 L F
.635 .073 0 r
.55203 .80418 m .55424 .80582 L .55184 .80481 L F
.583 .521 .751 r
.52034 .82954 m .52175 .83356 L .52355 .83184 L F
.455 .276 .548 r
.5214 .83429 m .52355 .83184 L .52175 .83356 L F
0 .45 .732 r
.53685 .85088 m .53831 .85135 L .54031 .85183 L F
.634 .832 .976 r
.50328 .87678 m .49924 .87672 L .50213 .8762 L F
.82 .852 .872 r
.50411 .87388 m .50328 .87678 L .50213 .8762 L F
.50411 .87388 m .50557 .87496 L .50328 .87678 L F
.846 .409 0 r
.55511 .80652 m .55603 .80829 L .55424 .80582 L F
.404 .057 .26 r
.38251 .761 m .38436 .76134 L .38513 .75927 L F
.581 .55 .785 r
.38513 .75927 m .38609 .75602 L .3841 .75631 L F
.38513 .75927 m .3872 .75896 L .38609 .75602 L F
.148 0 .148 r
.38513 .75927 m .38579 .76054 L .3872 .75896 L F
.38513 .75927 m .38436 .76134 L .38579 .76054 L F
.824 .921 .901 r
.6733 .73401 m .67037 .73536 L .67241 .73281 L F
.633 .742 .926 r
.6757 .73341 m .6733 .73401 L .67241 .73281 L F
.623 .643 .85 r
.46874 .84271 m .4657 .84089 L .4673 .83976 L F
.158 0 .291 r
.47064 .83999 m .46874 .84271 L .4673 .83976 L F
.47064 .83999 m .47039 .84208 L .46874 .84271 L F
.333 .345 .723 r
.47039 .84208 m .47089 .8443 L .46874 .84271 L F
.936 .699 .554 r
.54621 .79832 m .5448 .79791 L .54488 .79547 L F
.677 .189 0 r
.54682 .80024 m .5448 .79791 L .54621 .79832 L F
.548 .441 .684 r
.66438 .71779 m .66745 .71867 L .66768 .71792 L F
.66438 .71779 m .66469 .72006 L .66745 .71867 L F
.349 .554 .91 r
.35773 .72848 m .3571 .72961 L .35542 .72764 L F
.35773 .72848 m .35886 .73 L .3571 .72961 L F
.737 .584 .684 r
.51272 .83449 m .51551 .8324 L .51448 .83289 L F
.51272 .83449 m .51557 .834 L .51551 .8324 L F
0 .058 .564 r
.54933 .81896 m .5516 .82121 L .55038 .81961 L F
.867 .759 .742 r
.52826 .80839 m .52705 .8115 L .52585 .80896 L F
.559 .49 .734 r
.4026 .82948 m .40396 .82646 L .40289 .82639 L F
.348 .131 .437 r
.61444 .80099 m .61642 .79822 L .61583 .80022 L F
.39 .206 .508 r
.61417 .80317 m .61444 .80099 L .61583 .80022 L F
.806 .566 .575 r
.58831 .83197 m .59133 .83232 L .59047 .83373 L F
.212 .733 .853 r
.59133 .83232 m .59407 .83214 L .59366 .83207 L F
.673 .663 .832 r
.54976 .82972 m .54776 .83076 L .547 .82937 L F
.155 0 .267 r
.35689 .77745 m .35802 .77703 L .3586 .77489 L F
.588 .296 .44 r
.3586 .77489 m .35802 .77703 L .36029 .77675 L F
.578 .296 .452 r
.3586 .77489 m .36029 .77675 L .36093 .7748 L F
.651 .537 .712 r
.6172 .77525 m .6174 .77743 L .61945 .77483 L F
.609 .478 .677 r
.6174 .77743 m .61964 .77745 L .61945 .77483 L F
.461 .245 .498 r
.61772 .77996 m .61964 .77745 L .6174 .77743 L F
.32 .779 .947 r
.53343 .81421 m .53174 .81372 L .53061 .81426 L F
.981 .833 .623 r
.52895 .81529 m .52999 .81625 L .53061 .81426 L F
.52895 .81529 m .53061 .81426 L .53174 .81372 L F
0 .105 .656 r
.50388 .83884 m .50342 .83919 L .50119 .8366 L F
.50388 .83884 m .5044 .83997 L .50342 .83919 L F
.791 .82 .875 r
.63084 .74293 m .63411 .74296 L .63293 .74034 L F
.63084 .74293 m .63203 .74389 L .63411 .74296 L F
.689 .68 .836 r
.63293 .74034 m .63411 .74296 L .63628 .74084 L F
.85 .98 .866 r
.54138 .84031 m .54409 .83796 L .54366 .83871 L F
.208 0 .078 r
.54366 .83871 m .54409 .83796 L .54574 .83749 L F
.714 .597 .723 r
.39617 .87384 m .3975 .87734 L .39409 .87635 L F
.634 .555 .747 r
.39948 .87656 m .3975 .87734 L .39617 .87384 L F
.778 .668 .742 r
.59374 .82725 m .59407 .83214 L .59245 .82697 L F
.798 .991 .746 r
.59617 .82745 m .59407 .83214 L .59374 .82725 L F
.55 .794 .989 r
.50742 .87456 m .50557 .87496 L .50411 .87388 L F
.688 .554 .697 r
.41115 .86622 m .4125 .86896 L .40906 .86885 L F
.722 .548 .654 r
.4125 .86896 m .40898 .8712 L .40906 .86885 L F
.632 .921 .977 r
.66265 .76379 m .66529 .76255 L .66271 .76319 L F
.614 .414 .587 r
.41372 .74096 m .41365 .74323 L .41629 .74119 L F
.41372 .74096 m .41365 .74323 L .41629 .74119 L F
.35 0 0 r
.42172 .82589 m .42344 .82635 L .42447 .8264 L F
.125 0 0 r
.42344 .82635 m .42651 .82663 L .42447 .8264 L F
.976 .918 .663 r
.55156 .82694 m .55252 .82485 L .55189 .82379 L F
.76 .48 .51 r
.53581 .8681 m .53625 .86623 L .53301 .86599 L F
.889 .465 .087 r
.57065 .79245 m .5716 .79296 L .57118 .79205 L F
.617 .851 .988 r
.44236 .88712 m .44566 .88717 L .4444 .88662 L F
.53 .851 .998 r
.4444 .88662 m .44566 .88717 L .44771 .88665 L F
.655 .364 .465 r
.36649 .76692 m .36951 .76878 L .37028 .76704 L F
.36649 .76692 m .36684 .76903 L .36951 .76878 L F
.544 .746 .97 r
.65146 .75938 m .64931 .76 L .65059 .75623 L F
.65146 .75938 m .65236 .75805 L .64931 .76 L F
.65146 .75938 m .65405 .75919 L .65236 .75805 L F
.563 .298 .473 r
.6536 .76104 m .65405 .75919 L .65146 .75938 L F
.77 .78 .862 r
.64266 .72857 m .63916 .72966 L .64132 .72745 L F
.895 .885 .458 r
.53024 .83333 m .5302 .83518 L .5312 .83174 L F
.964 .812 .644 r
.52873 .83512 m .5302 .83518 L .53024 .83333 L F
.52873 .83512 m .52945 .83722 L .5302 .83518 L F
.87 .866 .832 r
.61269 .76098 m .61393 .76174 L .61603 .75912 L F
.609 .048 0 r
.53786 .84621 m .5395 .8472 L .53703 .8452 L F
.416 .281 .587 r
.68032 .74316 m .68066 .74607 L .67857 .74658 L F
0 0 .528 r
.67951 .74744 m .67857 .74658 L .68066 .74607 L F
.67951 .74744 m .67941 .74892 L .67857 .74658 L F
.924 .728 .239 r
.56386 .84239 m .56434 .84278 L .5643 .84451 L F
.987 .898 .589 r
.67941 .74892 m .6782 .75031 L .67887 .75203 L F
.868 .424 .064 r
.67788 .75245 m .67887 .75203 L .6782 .75031 L F
.67788 .75245 m .67869 .75382 L .67887 .75203 L F
.533 .528 .796 r
.46425 .86641 m .46343 .86917 L .46257 .86602 L F
.46425 .86641 m .46542 .86932 L .46343 .86917 L F
.646 .654 .843 r
.53782 .83709 m .53481 .83536 L .53683 .83477 L F
0 0 0 r
.53943 .8366 m .54027 .83549 L .53782 .83709 L F
.53816 .83571 m .53782 .83709 L .53683 .83477 L F
.884 .7 .648 r
.53666 .83492 m .53683 .83477 L .53655 .83485 L F
.53524 .83619 m .53666 .83492 L .53481 .83536 L F
.53666 .83492 m .53655 .83485 L .53481 .83536 L F
.53532 .83633 m .53566 .83598 L .53524 .83619 L F
.53566 .83598 m .53683 .83477 L .53524 .83619 L F
.53584 .83579 m .5357 .83397 L .53683 .83477 L F
.433 .872 .894 r
.53394 .83555 m .53108 .83617 L .5333 .83537 L F
.194 0 0 r
.53108 .83617 m .53333 .83539 L .5333 .83537 L F
.708 .628 .765 r
.53306 .83529 m .53328 .83549 L .5334 .83544 L F
.53311 .83532 m .5334 .83544 L .5331 .83531 L F
.5334 .83544 m .53602 .83789 L .5359 .8365 L F
.5334 .83544 m .53691 .83693 L .53341 .83544 L F
.194 0 0 r
.53255 .83572 m .53359 .83537 L .53374 .83521 L F
.685 .593 .748 r
.53108 .83617 m .5347 .83931 L .53316 .83553 L F
.194 0 0 r
.53163 .83611 m .53316 .83553 L .53255 .83572 L F
.53316 .83553 m .53359 .83537 L .53255 .83572 L F
.685 .593 .748 r
.53108 .83617 m .53316 .83553 L .53306 .83529 L F
.708 .628 .765 r
.5334 .83544 m .53341 .83544 L .5331 .83531 L F
.194 0 0 r
.53108 .83617 m .53163 .83611 L .53333 .83539 L F
.433 .872 .894 r
.53394 .83555 m .5333 .83537 L .53374 .83521 L F
.194 0 0 r
.5333 .83537 m .53333 .83539 L .53374 .83521 L F
.708 .628 .765 r
.53306 .83529 m .5347 .83931 L .53602 .83789 L F
.194 0 0 r
.53163 .83611 m .53302 .83597 L .53359 .83537 L F
.708 .628 .765 r
.53328 .83549 m .53602 .83789 L .5334 .83544 L F
.5359 .8365 m .53602 .83789 L .53691 .83693 L F
.5359 .8365 m .53691 .83693 L .53591 .83655 L F
.5359 .8365 m .53591 .83655 L .53532 .83633 L F
.5331 .83531 m .5359 .8365 L .53532 .83633 L F
.53306 .83529 m .53311 .83532 L .5331 .83531 L F
.433 .872 .894 r
.53481 .83536 m .53394 .83555 L .53374 .83521 L F
.884 .7 .648 r
.53532 .83633 m .5357 .83399 L .53584 .83579 L F
.5357 .83399 m .5357 .83397 L .53584 .83579 L F
.819 .677 .707 r
.5357 .83397 m .53574 .83408 L .53617 .83423 L F
.53621 .83418 m .53617 .83423 L .53775 .83481 L F
.5357 .83397 m .53617 .83423 L .53621 .83418 L F
.53574 .83408 m .536 .83436 L .53775 .83481 L F
0 0 0 r
.53943 .8366 m .53683 .83477 L .53801 .83413 L F
.819 .677 .707 r
.53742 .83409 m .53775 .83481 L .53801 .83413 L F
.5357 .83397 m .53775 .83481 L .53742 .83409 L F
.779 .791 .863 r
.5357 .83397 m .53801 .83413 L .5381 .83184 L F
0 0 0 r
.53943 .8366 m .53868 .83683 L .53816 .83571 L F
.53868 .83683 m .53782 .83709 L .53816 .83571 L F
.53943 .8366 m .53801 .83413 L .53691 .83693 L F
.714 .738 .87 r
.5381 .83184 m .53801 .83413 L .54125 .83228 L F
.024 0 0 r
.53605 .83442 m .53893 .83299 L .54012 .83467 L F
.53602 .83439 m .53893 .83299 L .53605 .83442 L F
.53597 .83441 m .53602 .83439 L .53605 .83442 L F
.53597 .83441 m .53599 .83442 L .53602 .83439 L F
.819 .677 .707 r
.53615 .8344 m .53712 .83518 L .53775 .83481 L F
.509 .344 .592 r
.53608 .83443 m .53604 .83445 L .53597 .83441 L F
.819 .677 .707 r
.53584 .83432 m .53604 .83445 L .53615 .8344 L F
.53604 .83445 m .53712 .83518 L .53615 .8344 L F
.53638 .83562 m .53691 .83693 L .53768 .83498 L F
.53638 .83562 m .53768 .83498 L .53775 .83481 L F
0 0 0 r
.54084 .83549 m .54027 .83549 L .53943 .8366 L F
.54084 .83549 m .54229 .83471 L .54027 .83549 L F
.174 0 .343 r
.53943 .8366 m .53889 .83884 L .54084 .83549 L F
.509 .344 .592 r
.54084 .83549 m .53889 .83884 L .54073 .83849 L F
.54084 .83549 m .5402 .83712 L .53604 .83445 L F
.54084 .83549 m .53604 .83445 L .53608 .83443 L F
.412 .663 .963 r
.54012 .83467 m .54084 .83549 L .53597 .83441 L F
.024 0 0 r
.53602 .83439 m .53731 .83515 L .53893 .83299 L F
.53599 .83442 m .53731 .83515 L .53602 .83439 L F
.819 .677 .707 r
.53574 .83408 m .53584 .83432 L .536 .83436 L F
.911 .565 .375 r
.53604 .83445 m .53599 .83442 L .53597 .83441 L F
.819 .677 .707 r
.53584 .83432 m .53638 .83562 L .53712 .83518 L F
.911 .565 .375 r
.53805 .83574 m .53731 .83515 L .53599 .83442 L F
.53805 .83574 m .53599 .83442 L .53604 .83445 L F
.5402 .83712 m .53908 .83636 L .53805 .83574 L F
.53908 .83636 m .53731 .83515 L .53805 .83574 L F
.24 0 .143 r
.66744 .72921 m .66978 .72944 L .66914 .72784 L F
.974 .732 .51 r
.66978 .72966 m .66914 .72784 L .66978 .72944 L F
.77 .553 0 r
.66977 .7294 m .66978 .72966 L .66978 .72944 L F
.974 .732 .51 r
.66965 .72931 m .66972 .72789 L .66914 .72784 L F
.77 .553 0 r
.66977 .7294 m .66978 .72944 L .66972 .72936 L F
.909 .874 .441 r
.66883 .73129 m .66978 .72944 L .66744 .72921 L F
.66942 .73218 m .66961 .73073 L .66883 .73129 L F
.66961 .73073 m .66978 .72944 L .66883 .73129 L F
.974 .732 .51 r
.66978 .72966 m .67138 .73082 L .67149 .72805 L F
.274 0 0 r
.67021 .7303 m .67313 .73051 L .67138 .73082 L F
.973 .707 .465 r
.66957 .73002 m .67138 .73082 L .66978 .72966 L F
.274 0 0 r
.66957 .73002 m .67043 .73014 L .67021 .7303 L F
.67043 .73014 m .67313 .73051 L .67021 .7303 L F
.885 .776 .736 r
.66978 .72944 m .66726 .73115 L .66645 .73018 L F
.66952 .7294 m .66645 .73018 L .66516 .72862 L F
.66978 .72944 m .66645 .73018 L .66952 .7294 L F
.66978 .72944 m .66885 .73317 L .66726 .73115 L F
.974 .732 .51 r
.66978 .72966 m .66977 .7294 L .6697 .72935 L F
.66967 .72936 m .6697 .72935 L .66965 .72931 L F
.66978 .72966 m .6697 .72935 L .66967 .72936 L F
.66977 .7294 m .66972 .72789 L .66965 .72931 L F
.66978 .72966 m .67149 .72805 L .66972 .72789 L F
.563 .412 .634 r
.67071 .72805 m .67022 .72901 L .66957 .72839 L F
.77 .553 0 r
.66957 .72839 m .66977 .7294 L .66811 .72698 L F
.66977 .7294 m .66972 .72936 L .66787 .72664 L F
.66957 .72839 m .66978 .72966 L .66977 .7294 L F
.724 .522 .617 r
.66787 .72664 m .66978 .72944 L .66516 .72862 L F
.995 .845 .496 r
.66957 .72839 m .66957 .73002 L .66978 .72966 L F
.886 .739 .231 r
.66957 .72839 m .66939 .73063 L .66957 .73002 L F
.563 .412 .634 r
.67022 .72901 m .66939 .73063 L .66957 .72839 L F
.77 .553 0 r
.66957 .72839 m .66811 .72698 L .66787 .72664 L F
.517 .233 .421 r
.4374 .8444 m .43555 .84308 L .43899 .84187 L F
.57 .238 .367 r
.43949 .84424 m .43899 .84187 L .44068 .84232 L F
.43949 .84424 m .4374 .8444 L .43899 .84187 L F
.025 .265 .765 r
.46733 .87112 m .46673 .87188 L .46542 .86932 L F
.264 .615 .957 r
.46826 .87214 m .46673 .87188 L .46733 .87112 L F
.868 .793 .774 r
.56825 .78155 m .56944 .78282 L .57139 .78066 L F
.658 .565 .739 r
.41329 .86576 m .4125 .86896 L .41115 .86622 L F
.583 .572 .806 r
.39578 .75095 m .39425 .75214 L .39382 .75098 L F
.39578 .75095 m .39693 .75256 L .39425 .75214 L F
.743 .641 .747 r
.41638 .86822 m .41779 .87161 L .41419 .87115 L F
.565 .319 .502 r
.41779 .87161 m .41511 .87423 L .41419 .87115 L F
.41779 .87161 m .41734 .87421 L .41511 .87423 L F
.733 .637 .752 r
.41968 .86875 m .41779 .87161 L .41638 .86822 L F
.52 .278 .489 r
.41959 .87369 m .41779 .87161 L .41971 .87117 L F
.41959 .87369 m .41734 .87421 L .41779 .87161 L F
.52 .359 .602 r
.41971 .87117 m .41779 .87161 L .41968 .86875 L F
.657 .171 .085 r
.4662 .83678 m .46848 .83713 L .46795 .83645 L F
.611 .822 .981 r
.43293 .81661 m .42962 .81635 L .43162 .81561 L F
.43293 .81661 m .42962 .81635 L .43162 .81561 L F
.547 .798 .991 r
.43507 .81624 m .43293 .81661 L .43162 .81561 L F
.43162 .81561 m .43293 .81661 L .43507 .81624 L F
.556 .456 .695 r
.39456 .74299 m .39317 .7468 L .39239 .7434 L F
.39456 .74299 m .39501 .74655 L .39317 .7468 L F
.536 .442 .695 r
.39543 .74835 m .39317 .7468 L .39501 .74655 L F
.39543 .74835 m .39352 .74868 L .39317 .7468 L F
0 0 0 r
.58229 .76508 m .57986 .7671 L .58141 .76593 L F
.074 0 0 r
.57986 .7671 m .58043 .76758 L .58141 .76593 L F
.57986 .7671 m .57832 .76806 L .58043 .76758 L F
.671 .548 .707 r
.59955 .80653 m .60224 .80625 L .60098 .8027 L F
.668 .532 .689 r
.59955 .80653 m .60046 .80935 L .60224 .80625 L F
.634 .555 .747 r
.39948 .87656 m .39617 .87384 L .39971 .87423 L F
.646 .472 .634 r
.40147 .87372 m .39948 .87656 L .39971 .87423 L F
.612 .419 .597 r
.38079 .84003 m .383 .83984 L .38306 .83744 L F
.589 .4 .594 r
.383 .83984 m .38511 .8373 L .38306 .83744 L F
.496 .391 .665 r
.60886 .81614 m .60662 .81385 L .60821 .81355 L F
.60886 .81614 m .60647 .81653 L .60662 .81385 L F
.702 .871 .961 r
.4028 .89452 m .40591 .89447 L .40422 .89373 L F
.378 .739 .991 r
.40591 .89447 m .40543 .89318 L .40422 .89373 L F
.40591 .89447 m .40882 .89485 L .40543 .89318 L F
.408 .172 .441 r
.60304 .82234 m .60538 .82064 L .60508 .82176 L F
.664 .677 .853 r
.52585 .80896 m .52705 .8115 L .52397 .8109 L F
.744 .622 .724 r
.51272 .83449 m .51306 .83589 L .51557 .834 L F
.587 .245 .357 r
.4534 .82472 m .45528 .82619 L .45648 .82382 L F
.544 .175 .29 r
.45528 .82619 m .45862 .82415 L .45648 .82382 L F
.694 .936 .965 r
.53324 .81264 m .53343 .81421 L .53476 .81349 L F
.53324 .81264 m .53174 .81372 L .53343 .81421 L F
.778 .668 .742 r
.59374 .82725 m .59245 .82697 L .59617 .82745 L F
.509 .706 .96 r
.56319 .79764 m .56196 .79934 L .56063 .79868 L F
.56319 .79764 m .5645 .79904 L .56196 .79934 L F
.601 .358 .521 r
.62166 .77439 m .62376 .77478 L .62454 .77186 L F
.498 .226 .432 r
.62376 .77478 m .62685 .77164 L .62454 .77186 L F
.471 .275 .533 r
.61642 .79822 m .61843 .79545 L .61814 .79738 L F
.424 .203 .472 r
.61583 .80022 m .61642 .79822 L .61814 .79738 L F
.483 .196 .4 r
.38021 .77558 m .3799 .7771 L .37791 .77743 L F
.519 .233 .419 r
.38267 .77455 m .3799 .7771 L .38021 .77558 L F
.203 0 .202 r
.6335 .78182 m .63413 .77975 L .63587 .77946 L F
.31 0 .248 r
.62697 .78722 m .62762 .78577 L .6295 .78504 L F
.692 .631 .784 r
.38588 .73992 m .38378 .74102 L .38254 .73801 L F
.676 .343 .403 r
.55662 .78968 m .55861 .78997 L .55972 .78785 L F
.608 .565 .78 r
.55972 .78785 m .56252 .78778 L .56114 .78489 L F
.657 .321 .393 r
.55972 .78785 m .56189 .7898 L .56252 .78778 L F
.87 .866 .832 r
.61269 .76098 m .61603 .75912 L .61489 .75839 L F
.875 .891 .841 r
.61489 .75839 m .61603 .75912 L .61814 .75647 L F
.348 0 .209 r
.58141 .76593 m .58412 .76422 L .58229 .76508 L F
.251 0 .213 r
.63107 .77119 m .6335 .769 L .63174 .76911 L F
.082 .262 .749 r
.55571 .83463 m .55335 .83103 L .55479 .832 L F
.444 .878 .893 r
.38635 .9011 m .38572 .90073 L .38421 .90127 L F
.38635 .9011 m .38819 .90044 L .38572 .90073 L F
.412 .132 .376 r
.36156 .79007 m .361 .79254 L .35919 .79284 L F
.479 .251 .49 r
.36402 .78763 m .36377 .79017 L .36156 .79007 L F
.521 .255 .453 r
.36377 .79017 m .361 .79254 L .36156 .79007 L F
.539 .171 .29 r
.52156 .81822 m .52147 .81835 L .52163 .81854 L F
.053 0 0 r
.52163 .81854 m .51957 .81921 L .52203 .81901 L F
.52163 .81854 m .52 .81939 L .51957 .81921 L F
.525 .913 .927 r
.51815 .81951 m .5175 .82031 L .52 .81939 L F
.51 .057 .112 r
.52163 .81854 m .51815 .81951 L .52 .81939 L F
.52163 .81854 m .52036 .81999 L .51815 .81951 L F
.539 .171 .29 r
.52147 .81835 m .52036 .81999 L .52163 .81854 L F
.053 0 0 r
.52163 .81854 m .52203 .81901 L .52288 .81894 L F
.466 .255 .507 r
.64891 .72485 m .64678 .72743 L .64685 .72532 L F
.85 .501 .392 r
.53172 .84559 m .5285 .84276 L .52844 .84494 L F
.614 .458 .647 r
.41741 .86064 m .41542 .85905 L .41753 .85844 L F
.41741 .86064 m .41531 .86093 L .41542 .85905 L F
.525 .672 .93 r
.36297 .72779 m .36224 .72972 L .36086 .72899 L F
.36297 .72779 m .3643 .72954 L .36224 .72972 L F
.362 0 0 r
.46592 .82346 m .46806 .82344 L .46957 .82233 L F
.604 .224 .295 r
.46806 .82344 m .47143 .82178 L .46957 .82233 L F
.601 .614 .836 r
.39239 .7434 m .38898 .74107 L .39086 .7409 L F
.635 .663 .86 r
.39456 .74299 m .39239 .7434 L .39086 .7409 L F
.744 .651 .757 r
.49491 .81616 m .49814 .8166 L .49691 .81368 L F
.595 .183 .231 r
.49395 .8178 m .49814 .8166 L .49491 .81616 L F
.49395 .8178 m .4953 .8187 L .49814 .8166 L F
.871 .987 .83 r
.49814 .8166 m .50024 .8142 L .49691 .81368 L F
.49814 .8166 m .49927 .81421 L .50024 .8142 L F
.49814 .8166 m .49693 .81706 L .49927 .81421 L F
.955 .874 .718 r
.49814 .8166 m .4953 .8187 L .49693 .81706 L F
.966 .732 .534 r
.47829 .83728 m .47806 .83974 L .47692 .83673 L F
.556 .35 .555 r
.47829 .83728 m .47806 .83974 L .48005 .83895 L F
.424 .246 .533 r
.60867 .81841 m .60647 .81653 L .60886 .81614 L F
.60867 .81841 m .60591 .81868 L .60647 .81653 L F
.593 .483 .698 r
.35627 .77975 m .35689 .77745 L .35645 .77847 L F
.35627 .77975 m .35802 .77703 L .35689 .77745 L F
.716 .599 .725 r
.39617 .87384 m .39409 .87635 L .39451 .87466 L F
.62 .943 .948 r
.35128 .75247 m .35077 .75192 L .35303 .75146 L F
.35128 .75247 m .35029 .7535 L .35077 .75192 L F
.999 .841 .536 r
.59445 .82182 m .59326 .82358 L .59337 .82123 L F
.59445 .82182 m .59409 .82411 L .59326 .82358 L F
0 0 0 r
.59557 .81863 m .59445 .82182 L .59337 .82123 L F
.252 0 0 r
.52386 .87392 m .52148 .87459 L .52038 .87618 L F
.665 .572 .74 r
.45983 .85271 m .45925 .85474 L .46237 .85363 L F
.649 .793 .951 r
.41015 .8924 m .41128 .8939 L .41376 .89283 L F
.815 .757 .798 r
.49237 .83436 m .49078 .83481 L .49297 .83223 L F
.794 .826 .877 r
.52714 .82359 m .52967 .82205 L .52804 .82116 L F
.658 .474 .624 r
.52714 .82359 m .52937 .82447 L .52967 .82205 L F
.921 .549 .128 r
.55906 .81107 m .56064 .81407 L .55977 .81339 L F
.999 .816 .481 r
.56064 .81407 m .55969 .81528 L .55977 .81339 L F
.56064 .81407 m .56031 .81621 L .55969 .81528 L F
0 0 0 r
.67123 .75071 m .66853 .75342 L .67057 .75215 L F
.786 .508 .516 r
.67275 .75011 m .67049 .74849 L .67123 .75071 L F
.181 0 .018 r
.67275 .75011 m .67123 .75071 L .67057 .75215 L F
.926 .54 .169 r
.49465 .84303 m .49411 .84396 L .49196 .8423 L F
.49465 .84303 m .49516 .84503 L .49411 .84396 L F
.159 .694 .84 r
.45096 .88681 m .45296 .8867 L .44973 .88668 L F
.79 .671 .732 r
.58497 .82962 m .58589 .83246 L .58349 .83217 L F
.499 0 0 r
.58643 .83477 m .58349 .83217 L .58589 .83246 L F
.594 .516 .736 r
.58747 .82885 m .58589 .83246 L .58497 .82962 L F
.58747 .82885 m .58831 .83197 L .58589 .83246 L F
.438 .38 .696 r
.58824 .83453 m .58589 .83246 L .58831 .83197 L F
.806 .566 .575 r
.58831 .83197 m .59047 .83373 L .58824 .83453 L F
.206 .096 .5 r
.58831 .83197 m .58824 .83453 L .58956 .83421 L F
.58805 .83376 m .58956 .83421 L .5879 .83483 L F
.58831 .83197 m .58903 .83326 L .58805 .83376 L F
.438 .38 .696 r
.58824 .83453 m .58643 .83477 L .58639 .83461 L F
.58824 .83453 m .58639 .83461 L .58761 .83398 L F
.599 .505 .719 r
.5883 .83556 m .58643 .83477 L .58824 .83453 L F
.438 .38 .696 r
.58824 .83453 m .58831 .83197 L .5879 .83483 L F
.206 .096 .5 r
.58903 .83326 m .58956 .83421 L .58805 .83376 L F
.438 .38 .696 r
.58761 .83398 m .58639 .83461 L .58589 .83246 L F
.666 .363 .45 r
.5192 .83136 m .51661 .82961 L .52034 .82954 L F
.389 .292 .623 r
.52034 .82954 m .52177 .82916 L .52142 .82682 L F
.583 .521 .751 r
.52034 .82954 m .52355 .83184 L .52177 .82916 L F
.381 .032 .243 r
.52177 .82916 m .5192 .83136 L .52034 .82954 L F
.389 .292 .623 r
.52142 .82682 m .52177 .82916 L .52034 .82954 L F
.517 .233 .421 r
.4374 .8444 m .43535 .84477 L .43555 .84308 L F
.625 .812 .972 r
.43559 .87375 m .43463 .87547 L .43338 .8743 L F
.43559 .87375 m .43718 .87472 L .43463 .87547 L F
.218 0 .296 r
.61843 .79545 m .62048 .7929 L .62007 .79482 L F
.445 .245 .513 r
.61814 .79738 m .61843 .79545 L .62007 .79482 L F
.717 .929 .961 r
.4506 .8737 m .44749 .87446 L .44989 .87399 L F
.382 0 0 r
.45134 .87135 m .45146 .87194 L .45041 .87029 L F
.783 .995 .868 r
.45146 .87194 m .45307 .87169 L .45166 .87284 L F
.257 .766 .774 r
.45497 .87118 m .45307 .87169 L .45146 .87194 L F
.45497 .87118 m .45146 .87194 L .45347 .87233 L F
.382 0 0 r
.45241 .87258 m .45146 .87194 L .45134 .87135 L F
.783 .995 .868 r
.45146 .87194 m .45166 .87284 L .4506 .8737 L F
.782 .981 .713 r
.4506 .8737 m .44989 .87399 L .45146 .87194 L F
.75 .581 .666 r
.46439 .83745 m .46067 .83927 L .46233 .83688 L F
.515 .273 .486 r
.47266 .83921 m .47039 .84208 L .47064 .83999 L F
.66 .931 .971 r
.52397 .8109 m .5251 .80919 L .52585 .80896 L F
.52397 .8109 m .5225 .81044 L .5251 .80919 L F
.889 .902 .489 r
.5643 .8264 m .56341 .82979 L .56404 .82904 L F
0 .231 .742 r
.56404 .82904 m .56341 .82979 L .56537 .83175 L F
.527 .815 .998 r
.41889 .89193 m .42216 .89224 L .42088 .89155 L F
.676 .859 .969 r
.42088 .89155 m .42216 .89224 L .42306 .89162 L F
0 0 0 r
.49221 .87317 m .49417 .87179 L .49344 .87353 L F
.508 .49 .771 r
.49566 .87107 m .49417 .87179 L .49311 .86916 L F
.246 0 .276 r
.49344 .87353 m .49417 .87179 L .49566 .87107 L F
.386 .017 .21 r
.35823 .74847 m .35686 .75069 L .35501 .75106 L F
.493 .117 .254 r
.36024 .74857 m .35686 .75069 L .35823 .74847 L F
0 0 0 r
.5889 .76997 m .58733 .77171 L .58612 .77199 L F
.504 .225 .424 r
.58733 .77171 m .58546 .77235 L .58612 .77199 L F
.574 .248 .378 r
.49842 .84265 m .49752 .84509 L .49516 .84503 L F
.045 0 .136 r
.4989 .8442 m .49842 .84265 L .50061 .84257 L F
.4989 .8442 m .49752 .84509 L .49842 .84265 L F
.144 0 .018 r
.49227 .8159 m .49444 .81532 L .49229 .81206 L F
.515 .352 .598 r
.49229 .81206 m .49593 .81298 L .49373 .81131 L F
.897 .749 .689 r
.49444 .81532 m .49593 .81298 L .49229 .81206 L F
.624 .411 .573 r
.37346 .84508 m .3757 .84478 L .37595 .84273 L F
.633 .458 .628 r
.37595 .84273 m .37841 .84266 L .3786 .84027 L F
.713 .56 .68 r
.3757 .84478 m .37841 .84266 L .37595 .84273 L F
.654 .382 .495 r
.52714 .82359 m .5256 .82485 L .52376 .82456 L F
.642 .535 .717 r
.52376 .82456 m .5256 .82485 L .52568 .82467 L F
.581 .334 .507 r
.52376 .82456 m .52483 .82535 L .52572 .82467 L F
.52449 .82435 m .52572 .82467 L .52714 .82359 L F
.587 .471 .688 r
.52664 .82253 m .52568 .82467 L .52804 .82116 L F
.52568 .82467 m .5256 .82485 L .52571 .82468 L F
.52568 .82467 m .52571 .82468 L .52804 .82116 L F
.581 .334 .507 r
.52376 .82456 m .52568 .82467 L .52449 .82435 L F
.52568 .82467 m .52572 .82467 L .52449 .82435 L F
.642 .535 .717 r
.52376 .82456 m .52568 .82467 L .52664 .82253 L F
.794 .826 .877 r
.52714 .82359 m .52804 .82116 L .52571 .82468 L F
.52714 .82359 m .52571 .82468 L .5256 .82485 L F
.581 .334 .507 r
.52483 .82535 m .52605 .82627 L .52714 .82359 L F
.527 .137 .244 r
.52605 .82627 m .52937 .82447 L .52714 .82359 L F
.483 .867 .976 r
.66271 .76319 m .66444 .76202 L .66215 .76347 L F
.66271 .76319 m .66529 .76255 L .66444 .76202 L F
.676 .83 .958 r
.58957 .79004 m .58786 .79097 L .58645 .78996 L F
.58645 .78996 m .58786 .79097 L .58957 .79004 L F
0 0 0 r
.64831 .76964 m .64679 .77071 L .64508 .77152 L F
.64969 .76942 m .64831 .76964 L .65032 .76873 L F
.64969 .76942 m .64679 .77071 L .64831 .76964 L F
.608 .396 .568 r
.37841 .84266 m .38079 .84003 L .3786 .84027 L F
0 0 0 r
.60809 .74846 m .6097 .74783 L .61088 .74655 L F
.6078 .75054 m .6097 .74783 L .60809 .74846 L F
0 .46 .826 r
.47824 .88372 m .47861 .88356 L .47676 .8833 L F
.47824 .88372 m .47973 .88425 L .47861 .88356 L F
0 0 0 r
.61088 .74655 m .61196 .74549 L .61225 .74531 L F
.61088 .74655 m .6097 .74783 L .61196 .74549 L F
.55 .252 .415 r
.47455 .82069 m .47656 .82092 L .47694 .81931 L F
.525 .263 .461 r
.47656 .82092 m .4789 .81889 L .47694 .81931 L F
.915 .766 .681 r
.55903 .79457 m .56119 .79362 L .55967 .79239 L F
.55903 .79457 m .56049 .79526 L .56119 .79362 L F
.895 .885 .458 r
.53024 .83333 m .5312 .83174 L .53036 .8317 L F
.771 .636 .712 r
.53388 .82873 m .53036 .8317 L .5312 .83174 L F
.575 .868 .995 r
.43518 .88831 m .4359 .88717 L .4338 .88779 L F
.43518 .88831 m .43719 .88772 L .4359 .88717 L F
.563 .488 .728 r
.39543 .74835 m .39382 .75098 L .39352 .74868 L F
.39543 .74835 m .39578 .75095 L .39382 .75098 L F
.776 .667 .743 r
.51239 .82111 m .50986 .82419 L .51379 .82363 L F
.683 .345 .397 r
.50986 .82419 m .51199 .82617 L .51379 .82363 L F
.522 .367 .611 r
.51379 .82363 m .51415 .82113 L .51239 .82111 L F
.51379 .82363 m .51541 .82173 L .51415 .82113 L F
.51379 .82363 m .5152 .82446 L .51541 .82173 L F
.424 .05 .223 r
.51379 .82363 m .51408 .82579 L .5152 .82446 L F
.51379 .82363 m .51199 .82617 L .51408 .82579 L F
.265 .773 .803 r
.38819 .90044 m .39117 .89986 L .39012 .89995 L F
.532 .883 .984 r
.39117 .89986 m .39205 .89893 L .39012 .89995 L F
.39117 .89986 m .39266 .89922 L .39205 .89893 L F
.029 .516 .878 r
.66745 .71867 m .67006 .71999 L .66975 .71952 L F
.863 .498 .357 r
.67006 .71999 m .66914 .72154 L .66745 .71867 L F
.944 .882 .474 r
.66975 .71952 m .66914 .72154 L .67006 .71999 L F
.435 .809 .993 r
.42115 .73826 m .42171 .73742 L .42326 .73801 L F
.42115 .73826 m .42171 .73742 L .42326 .73801 L F
0 0 .043 r
.60624 .82691 m .60557 .8288 L .60483 .82977 L F
0 0 .207 r
.60483 .82977 m .60546 .83098 L .6044 .83194 L F
.60483 .82977 m .60557 .8288 L .60546 .83098 L F
.521 .278 .487 r
.36601 .78742 m .36377 .79017 L .36402 .78763 L F
.79 .704 .769 r
.50929 .84228 m .50603 .84231 L .50798 .8399 L F
.676 .466 .594 r
.50813 .84456 m .50603 .84231 L .50929 .84228 L F
.591 .621 .85 r
.51084 .8416 m .50929 .84228 L .50798 .8399 L F
.64 .398 .536 r
.51084 .8416 m .50813 .84456 L .50929 .84228 L F
.509 0 0 r
.5277 .80578 m .53009 .80625 L .53107 .80576 L F
.231 0 0 r
.53009 .80625 m .5334 .8054 L .53107 .80576 L F
.44 .817 .992 r
.50245 .82901 m .5004 .82936 L .50373 .82954 L F
.706 .324 .323 r
.5004 .82936 m .50237 .83142 L .50373 .82954 L F
.601 .036 0 r
.50373 .82954 m .50378 .82988 L .50245 .82901 L F
.722 .548 .654 r
.4125 .86896 m .41249 .87172 L .40898 .8712 L F
.658 .565 .739 r
.41329 .86576 m .41506 .86955 L .4125 .86896 L F
.709 .537 .655 r
.41419 .87115 m .4125 .86896 L .41506 .86955 L F
.41419 .87115 m .41249 .87172 L .4125 .86896 L F
.731 .629 .744 r
.40678 .87341 m .4052 .87458 L .4037 .87131 L F
.395 .15 .42 r
.62288 .79044 m .62511 .78793 L .62458 .78978 L F
.392 .147 .419 r
.62458 .78978 m .62511 .78793 L .62697 .78722 L F
.708 .795 .919 r
.41556 .89178 m .41711 .89293 L .41889 .89193 L F
.116 .668 .766 r
.36346 .74836 m .36218 .74839 L .36024 .74857 L F
.313 .803 .861 r
.36558 .74785 m .36218 .74839 L .36346 .74836 L F
.779 .69 .766 r
.46003 .86617 m .46042 .86682 L .45735 .86591 L F
.716 .849 .945 r
.46174 .86495 m .46042 .86682 L .46003 .86617 L F
.46174 .86495 m .46257 .86602 L .46042 .86682 L F
.416 .161 .416 r
.62048 .7929 m .62288 .79044 L .62244 .79211 L F
.38 .12 .389 r
.62244 .79211 m .62288 .79044 L .62458 .78978 L F
.778 .437 .409 r
.57904 .77633 m .57562 .7746 L .57641 .7761 L F
.352 .041 .29 r
.37028 .76704 m .37145 .76838 L .37236 .76682 L F
.37028 .76704 m .36951 .76878 L .37145 .76838 L F
.731 .629 .744 r
.40678 .87341 m .4037 .87131 L .40712 .87202 L F
.67 .582 .747 r
.40898 .8712 m .40678 .87341 L .40712 .87202 L F
.809 .876 .896 r
.62844 .74528 m .63203 .74389 L .63084 .74293 L F
0 0 0 r
.60268 .80051 m .60098 .8027 L .60337 .80273 L F
.422 .405 .735 r
.60098 .8027 m .603 .80539 L .60337 .80273 L F
.60098 .8027 m .60224 .80625 L .603 .80539 L F
.583 .032 0 r
.34895 .72682 m .35233 .72762 L .35028 .7276 L F
.34895 .72682 m .35059 .72781 L .35233 .72762 L F
.822 .977 .89 r
.35233 .72762 m .35059 .72781 L .35136 .72717 L F
.35233 .72762 m .35136 .72717 L .35309 .72573 L F
.583 .804 .984 r
.35363 .72802 m .35304 .72794 L .35233 .72762 L F
.35304 .72794 m .35028 .7276 L .35233 .72762 L F
.482 .823 .998 r
.35421 .72706 m .35363 .72802 L .35233 .72762 L F
.35421 .72706 m .35542 .72764 L .35363 .72802 L F
.599 .505 .719 r
.5883 .83556 m .58645 .83685 L .58643 .83477 L F
.253 .735 .93 r
.36892 .74818 m .3675 .74779 L .36558 .74785 L F
.45 .828 .99 r
.37096 .7479 m .3675 .74779 L .36892 .74818 L F
.616 .462 .651 r
.5722 .7825 m .57253 .78517 L .57465 .78253 L F
.543 .353 .574 r
.40334 .75642 m .40319 .75889 L .4012 .75923 L F
.756 .684 .782 r
.40526 .75376 m .40334 .75642 L .40197 .75348 L F
.543 .39 .623 r
.40526 .75376 m .40532 .75607 L .40334 .75642 L F
.592 .424 .622 r
.40532 .75607 m .40319 .75889 L .40334 .75642 L F
.444 .878 .884 r
.50024 .8142 m .50104 .81353 L .50226 .81384 L F
.50024 .8142 m .49927 .81421 L .50104 .81353 L F
.693 .471 .581 r
.48629 .81617 m .49089 .81719 L .48978 .8132 L F
.595 .413 .605 r
.48978 .8132 m .49161 .8166 L .49227 .8159 L F
.48978 .8132 m .49089 .81719 L .49161 .8166 L F
.741 .861 .936 r
.64373 .73715 m .64671 .7365 L .64609 .73551 L F
.683 .634 .795 r
.64671 .7365 m .64888 .73583 L .64609 .73551 L F
.552 .331 .533 r
.38505 .77211 m .38474 .77442 L .38267 .77455 L F
.512 .296 .523 r
.38678 .774 m .38505 .77211 L .3871 .77181 L F
.38678 .774 m .38474 .77442 L .38505 .77211 L F
.398 0 0 r
.53388 .81762 m .53463 .81815 L .53285 .81574 L F
.826 .935 .563 r
.53463 .81815 m .53334 .81978 L .53423 .81795 L F
.398 0 0 r
.53388 .81762 m .53499 .81832 L .53463 .81815 L F
.211 .212 .642 r
.53285 .81574 m .53463 .81815 L .53378 .81633 L F
0 .039 .588 r
.53378 .81633 m .53463 .81815 L .53518 .81601 L F
.826 .935 .563 r
.53463 .81815 m .53423 .81795 L .53518 .81601 L F
.398 0 0 r
.53499 .81832 m .53599 .81895 L .53463 .81815 L F
.61 .753 .946 r
.67049 .74849 m .6735 .74929 L .6728 .74792 L F
.786 .508 .516 r
.67275 .75011 m .6735 .74929 L .67049 .74849 L F
.595 .744 .948 r
.6735 .74929 m .67618 .74883 L .6728 .74792 L F
.589 .758 .959 r
.6735 .74929 m .67486 .74767 L .6728 .74792 L F
.6735 .74929 m .67618 .74883 L .67486 .74767 L F
.955 .658 .224 r
.6728 .74792 m .67311 .74966 L .67255 .74987 L F
.589 .758 .959 r
.6733 .74948 m .6735 .74929 L .67275 .75011 L F
.67486 .74767 m .67354 .74925 L .6733 .74948 L F
.67354 .74925 m .6735 .74929 L .6733 .74948 L F
.67486 .74767 m .67618 .74883 L .6735 .74929 L F
.67486 .74767 m .67275 .75011 L .67329 .75071 L F
.955 .658 .224 r
.67311 .74966 m .67329 .75071 L .6727 .75005 L F
.67311 .74966 m .6727 .75005 L .67255 .74987 L F
.487 .889 .942 r
.58918 .82902 m .59006 .8293 L .58848 .82953 L F
.801 .991 .88 r
.59245 .82697 m .59006 .8293 L .58918 .82902 L F
.875 .891 .841 r
.61489 .75839 m .61814 .75647 L .61708 .7558 L F
.881 .9 .839 r
.61708 .7558 m .61814 .75647 L .62026 .75384 L F
.001 .571 .78 r
.56681 .84807 m .56993 .84849 L .56861 .84816 L F
.455 0 0 r
.56861 .84816 m .56993 .84849 L .57156 .84949 L F
0 0 0 r
.53466 .82093 m .53479 .82102 L .53599 .81895 L F
.53298 .82258 m .53479 .82102 L .53466 .82093 L F
.714 .446 .519 r
.39232 .83439 m .39262 .83237 L .39086 .8323 L F
.623 .386 .537 r
.39472 .83451 m .39262 .83237 L .39232 .83439 L F
.39472 .83451 m .39514 .83172 L .39262 .83237 L F
.34 .261 .62 r
.59752 .81133 m .59885 .81282 L .59958 .81096 L F
.59752 .81133 m .59803 .81399 L .59885 .81282 L F
.432 .018 .152 r
.38251 .761 m .37982 .76199 L .38121 .76312 L F
.563 .267 .424 r
.38089 .76498 m .38363 .76316 L .38054 .76302 L F
.429 0 0 r
.38054 .76302 m .38363 .76316 L .38121 .76312 L F
.406 .132 .381 r
.38363 .76316 m .38251 .761 L .38121 .76312 L F
.38363 .76316 m .38436 .76134 L .38251 .761 L F
.751 .731 .833 r
.63833 .738 m .64145 .73835 L .64015 .73763 L F
.711 .739 .873 r
.64015 .73763 m .64145 .73835 L .64373 .73715 L F
.756 .584 .664 r
.52777 .84271 m .52844 .84494 L .5285 .84276 L F
.444 .231 .493 r
.62007 .79482 m .62048 .7929 L .62244 .79211 L F
.574 .331 .509 r
.44605 .84004 m .4482 .84182 L .4465 .84111 L F
.442 .192 .439 r
.4012 .75923 m .40083 .76106 L .39889 .76158 L F
.51 .253 .462 r
.40319 .75889 m .40083 .76106 L .4012 .75923 L F
.727 .28 .188 r
.48416 .85197 m .48038 .85034 L .48308 .85072 L F
.245 0 0 r
.48038 .85034 m .48172 .85068 L .48308 .85072 L F
.38 .842 .882 r
.48308 .85072 m .48172 .85068 L .48466 .85005 L F
.619 .947 .939 r
.48317 .85171 m .48416 .85197 L .48308 .85072 L F
.727 .28 .188 r
.48416 .85197 m .48238 .85222 L .48038 .85034 L F
.619 .947 .939 r
.48317 .85171 m .48308 .85072 L .48466 .85005 L F
.75 .834 .916 r
.63714 .73071 m .63395 .73091 L .63603 .72946 L F
.749 .757 .859 r
.63916 .72966 m .63714 .73071 L .63603 .72946 L F
.608 .396 .568 r
.37841 .84266 m .38064 .84237 L .38079 .84003 L F
.623 .408 .57 r
.38079 .84003 m .38288 .84204 L .383 .83984 L F
.38079 .84003 m .38064 .84237 L .38288 .84204 L F
.966 .776 .596 r
.56189 .7898 m .56312 .79051 L .56252 .78778 L F
.73 .382 .39 r
.52576 .83585 m .52269 .83485 L .52383 .83528 L F
.666 .533 .693 r
.52777 .84271 m .52601 .84594 L .52844 .84494 L F
.639 .627 .822 r
.63286 .7296 m .63165 .73226 L .63066 .72981 L F
.63286 .7296 m .63395 .73091 L .63165 .73226 L F
.718 .568 .685 r
.37125 .84683 m .37212 .84525 L .37099 .84523 L F
.664 .505 .66 r
.3713 .84774 m .37212 .84525 L .37125 .84683 L F
.3713 .84774 m .37346 .84508 L .37212 .84525 L F
.689 .353 .402 r
.45125 .84023 m .44982 .84218 L .4482 .84182 L F
.667 .326 .386 r
.4533 .84215 m .44982 .84218 L .45125 .84023 L F
.052 .178 .678 r
.57072 .84038 m .5696 .83677 L .57028 .8394 L F
.504 .346 .6 r
.42156 .87081 m .41971 .87117 L .41968 .86875 L F
.623 .512 .707 r
.4214 .86628 m .42193 .86864 L .41968 .86875 L F
.597 .353 .518 r
.42193 .86864 m .42156 .87081 L .41968 .86875 L F
.504 .346 .6 r
.42156 .87081 m .41971 .87117 L .41968 .86875 L F
.844 .939 .887 r
.44206 .87201 m .43892 .87367 L .44121 .87197 L F
.43 .87 .893 r
.44206 .87201 m .44121 .87197 L .44345 .87117 L F
.813 .933 .911 r
.53388 .82873 m .53527 .82825 L .5347 .82881 L F
.768 .338 .23 r
.53527 .82825 m .53656 .82963 L .5347 .82881 L F
.766 .835 .905 r
.40543 .89318 m .40882 .89485 L .41015 .8924 L F
.851 .713 .71 r
.46368 .84243 m .46243 .84 L .4657 .84089 L F
.46368 .84243 m .46188 .84218 L .46243 .84 L F
.826 .634 .644 r
.46394 .84506 m .46188 .84218 L .46368 .84243 L F
.998 .783 .473 r
.48491 .86866 m .48389 .87101 L .48318 .86786 L F
.48491 .86866 m .48468 .87145 L .48389 .87101 L F
.503 .803 .999 r
.48689 .86828 m .48491 .86866 L .48318 .86786 L F
.758 .633 .723 r
.49278 .81896 m .4943 .82235 L .49085 .82167 L F
.749 .656 .758 r
.4943 .82235 m .48954 .82602 L .49085 .82167 L F
.901 .765 .701 r
.6709 .73705 m .66918 .73799 L .67037 .73536 L F
.694 .33 .354 r
.6709 .73705 m .67059 .7393 L .66918 .73799 L F
.767 .526 .569 r
.67326 .73774 m .67059 .7393 L .6709 .73705 L F
.682 .257 .231 r
.66745 .71867 m .66975 .71952 L .66768 .71792 L F
.66745 .71867 m .66975 .71952 L .66768 .71792 L F
0 0 0 r
.59598 .84495 m .59838 .84203 L .59743 .844 L F
.223 .006 .358 r
.59838 .84203 m .60062 .83986 L .59988 .84161 L F
.041 0 .03 r
.59743 .844 m .59838 .84203 L .59988 .84161 L F
.271 .07 .414 r
.60224 .80625 m .60046 .80935 L .60172 .80832 L F
.60224 .80625 m .60046 .80935 L .60172 .80832 L F
.623 .661 .866 r
.38772 .73852 m .38898 .74107 L .38588 .73992 L F
.375 .519 .874 r
.38985 .73962 m .38898 .74107 L .38772 .73852 L F
.495 .676 .946 r
.38985 .73962 m .39086 .7409 L .38898 .74107 L F
.329 .751 .976 r
.49127 .88782 m .49441 .88841 L .49286 .88821 L F
.713 .973 .927 r
.49441 .88841 m .49601 .88676 L .49286 .88821 L F
.49441 .88841 m .49693 .88695 L .49601 .88676 L F
.87 .975 .849 r
.57065 .79245 m .5694 .79508 L .5716 .79296 L F
.57065 .79245 m .56839 .79497 L .5694 .79508 L F
.441 .628 .933 r
.48615 .88731 m .48717 .88606 L .48508 .88668 L F
.48615 .88731 m .48829 .88751 L .48717 .88606 L F
.29 .671 .973 r
.48615 .88731 m .48914 .88808 L .48829 .88751 L F
.614 .3 .416 r
.59136 .76087 m .59358 .76089 L .59147 .75917 L F
.592 .31 .457 r
.59147 .75917 m .59358 .76089 L .59377 .75908 L F
.783 .631 .692 r
.46439 .83745 m .4657 .84089 L .46243 .84 L F
.679 .58 .737 r
.4673 .83976 m .4657 .84089 L .46439 .83745 L F
.72 .465 .54 r
.51515 .82881 m .5127 .83182 L .51093 .83169 L F
.636 .353 .472 r
.51664 .83138 m .5127 .83182 L .51515 .82881 L F
.665 .362 .45 r
.51661 .82961 m .51664 .83138 L .51515 .82881 L F
.497 .241 .455 r
.39889 .76158 m .39907 .76279 L .39655 .76352 L F
.527 .315 .535 r
.40083 .76106 m .39907 .76279 L .39889 .76158 L F
.558 .64 .888 r
.48908 .87838 m .48708 .87866 L .48569 .87662 L F
.27 0 0 r
.5334 .8054 m .53491 .80587 L .5364 .80622 L F
.705 .208 .06 r
.53491 .80587 m .53877 .80764 L .5364 .80622 L F
.881 .9 .839 r
.61708 .7558 m .62026 .75384 L .61949 .75382 L F
.712 .986 .828 r
.62134 .7523 m .62026 .75384 L .62283 .75173 L F
.713 .987 .855 r
.62134 .7523 m .61949 .75382 L .62026 .75384 L F
.824 .923 .901 r
.62658 .73309 m .62416 .73531 L .62311 .73467 L F
.91 .882 .794 r
.57136 .83422 m .57225 .83297 L .57129 .83178 L F
.597 .798 .976 r
.57129 .83178 m .57225 .83297 L .57457 .83227 L F
.827 .725 .752 r
.54739 .83629 m .54922 .83976 L .54555 .83932 L F
.802 .448 .386 r
.54555 .83932 m .54922 .83976 L .54759 .8421 L F
.415 .53 .866 r
.55041 .8389 m .54922 .83976 L .54739 .83629 L F
0 0 0 r
.54759 .8421 m .54922 .83976 L .55041 .8389 L F
.963 .839 .672 r
.56857 .80807 m .56963 .80874 L .56968 .80614 L F
0 .057 .618 r
.57109 .80992 m .5714 .81145 L .56963 .80874 L F
.57109 .80992 m .56963 .80874 L .56857 .80807 L F
0 0 0 r
.53798 .8421 m .54138 .84031 L .54015 .84201 L F
.499 0 0 r
.58643 .83477 m .5834 .83407 L .58349 .83217 L F
.374 .796 .974 r
.48272 .86092 m .48587 .8611 L .48468 .86064 L F
.455 .276 .548 r
.5214 .83429 m .52269 .83485 L .52355 .83184 L F
.599 .389 .568 r
.38781 .83692 m .3901 .83446 L .38798 .83457 L F
.961 .661 .415 r
.54813 .81834 m .54913 .8167 L .54821 .81581 L F
.54813 .81834 m .54933 .81896 L .54913 .8167 L F
.579 .79 .979 r
.42987 .87503 m .42939 .87621 L .42809 .87586 L F
.42987 .87503 m .43132 .87576 L .42939 .87621 L F
.445 .486 .808 r
.49408 .86814 m .49311 .86916 L .49241 .86816 L F
.49408 .86814 m .49566 .87107 L .49311 .86916 L F
0 0 0 r
.48475 .85567 m .48253 .85825 L .48485 .85758 L F
.578 .398 .601 r
.48485 .85758 m .487 .85566 L .48475 .85567 L F
.687 .79 .928 r
.47806 .83974 m .48133 .84 L .48005 .83895 L F
.47806 .83974 m .48133 .84 L .48005 .83895 L F
.214 0 .121 r
.48075 .84147 m .47867 .84213 L .48133 .84 L F
.729 .798 .906 r
.48005 .83895 m .48133 .84 L .48362 .8389 L F
.155 .166 .619 r
.57284 .81635 m .57141 .8135 L .57274 .81333 L F
.475 .204 .422 r
.3799 .7771 m .37742 .77941 L .37791 .77743 L F
.024 0 .29 r
.603 .80539 m .60224 .80625 L .60172 .80832 L F
.561 .177 .271 r
.45001 .82648 m .45214 .8265 L .4534 .82472 L F
.608 .231 .302 r
.4534 .82472 m .45214 .8265 L .45528 .82619 L F
.735 .421 .449 r
.49658 .8765 m .49924 .87672 L .49734 .87571 L F
0 0 .258 r
.50092 .83183 m .49931 .83456 L .50132 .83412 L F
.50092 .83183 m .50024 .83418 L .49931 .83456 L F
.615 .574 .785 r
.50024 .83418 m .49896 .83676 L .49931 .83456 L F
.665 .572 .74 r
.45983 .85271 m .46237 .85363 L .46246 .85099 L F
.44 .327 .628 r
.46246 .85099 m .46237 .85363 L .46358 .85215 L F
.563 .917 .724 r
.56523 .77566 m .56254 .77758 L .56383 .77635 L F
.91 .84 .764 r
.56374 .77913 m .56383 .77635 L .56254 .77758 L F
.703 .739 .879 r
.56254 .77869 m .56296 .77678 L .56383 .77635 L F
.56296 .77678 m .56304 .77642 L .56383 .77635 L F
.563 .917 .724 r
.56524 .77565 m .56523 .77566 L .56383 .77635 L F
0 .575 .734 r
.56802 .79018 m .57142 .79034 L .56911 .7908 L F
.305 0 .121 r
.56911 .7908 m .56765 .79319 L .56731 .79326 L F
.461 .205 .439 r
.39346 .76867 m .39191 .7672 L .39387 .76707 L F
.39346 .76867 m .39155 .76914 L .39191 .7672 L F
.625 .197 .209 r
.68695 .71784 m .68857 .71787 L .68755 .71876 L F
.522 .36 .603 r
.69049 .71424 m .69076 .71737 L .68857 .71787 L F
.21 0 0 r
.68857 .71787 m .69076 .71737 L .68755 .71876 L F
.696 .528 .656 r
.59089 .76894 m .58733 .77171 L .5889 .76997 L F
.67 .548 .707 r
.4122 .87366 m .41006 .87611 L .41011 .87417 L F
.899 .948 .595 r
.67951 .74744 m .6782 .75031 L .67941 .74892 L F
.714 .446 .519 r
.39232 .83439 m .39086 .8323 L .3901 .83446 L F
.764 .672 .762 r
.56987 .82419 m .5732 .82419 L .5723 .82185 L F
.459 0 0 r
.57312 .82475 m .5732 .82419 L .57144 .82419 L F
.57232 .82461 m .57144 .82419 L .56987 .82419 L F
.57312 .82475 m .57144 .82419 L .57232 .82461 L F
.322 .198 .551 r
.57265 .82477 m .57233 .82482 L .57232 .82461 L F
.613 .426 .606 r
.57232 .82461 m .57233 .82482 L .56987 .82419 L F
.448 0 0 r
.56987 .82419 m .57233 .82482 L .57298 .82575 L F
.459 0 0 r
.57298 .82575 m .57312 .82475 L .57261 .82466 L F
.151 0 0 r
.57298 .82575 m .57233 .82482 L .57265 .82477 L F
.459 0 0 r
.57298 .82575 m .57261 .82466 L .56987 .82419 L F
.151 0 0 r
.57298 .82575 m .57265 .82477 L .57328 .82466 L F
.322 .198 .551 r
.57328 .82466 m .57265 .82477 L .5723 .82185 L F
.57265 .82477 m .57232 .82461 L .5723 .82185 L F
.613 .426 .606 r
.5723 .82185 m .57232 .82461 L .56987 .82419 L F
0 .243 .68 r
.57455 .82486 m .57671 .82637 L .57426 .82485 L F
.57455 .82486 m .57426 .82485 L .5732 .82419 L F
.691 .158 0 r
.57648 .82703 m .5732 .82419 L .57671 .82637 L F
0 .243 .68 r
.57455 .82486 m .5732 .82419 L .57298 .82575 L F
0 .427 .766 r
.57474 .82486 m .57455 .82486 L .57328 .82466 L F
.57527 .82493 m .57455 .82486 L .57474 .82486 L F
.544 .328 .537 r
.38161 .73241 m .38097 .7358 L .37925 .73564 L F
.83 .851 .862 r
.3835 .73012 m .38161 .73241 L .37998 .73146 L F
0 0 .222 r
.38214 .73343 m .38161 .73241 L .38353 .73287 L F
.38214 .73343 m .38097 .7358 L .38161 .73241 L F
.505 .347 .601 r
.3835 .73012 m .38353 .73287 L .38161 .73241 L F
.681 .597 .754 r
.4122 .87366 m .41011 .87417 L .40898 .8712 L F
.602 .365 .53 r
.52116 .86554 m .52184 .8638 L .51908 .86349 L F
0 0 .064 r
.60181 .83885 m .60212 .83726 L .60372 .8363 L F
.795 .604 .642 r
.51272 .83449 m .50898 .8319 L .51093 .83169 L F
.51272 .83449 m .50888 .83453 L .50898 .8319 L F
.629 .231 .269 r
.51272 .83449 m .50919 .83624 L .50888 .83453 L F
.51272 .83449 m .51107 .83656 L .50919 .83624 L F
.589 .634 .864 r
.5127 .83182 m .51272 .83449 L .51093 .83169 L F
.5127 .83182 m .51645 .83476 L .51272 .83449 L F
.064 0 0 r
.51645 .83476 m .51107 .83656 L .51272 .83449 L F
.537 .319 .531 r
.39907 .76279 m .39602 .76575 L .39655 .76352 L F
.502 .318 .563 r
.61964 .77745 m .62166 .77439 L .61945 .77483 L F
.479 .804 1 r
.41471 .8263 m .41594 .827 L .41263 .82662 L F
0 0 0 r
.41594 .827 m .41691 .82663 L .41791 .82599 L F
.303 .714 .976 r
.41471 .8263 m .41691 .82663 L .41594 .827 L F
.066 0 .234 r
.60709 .82816 m .60624 .82691 L .60769 .82613 L F
.60709 .82816 m .60557 .8288 L .60624 .82691 L F
.606 .425 .61 r
.41741 .86064 m .41534 .86332 L .41531 .86093 L F
.46 0 0 r
.5403 .80845 m .54002 .80815 L .53877 .80764 L F
.566 .918 .725 r
.56524 .77565 m .56617 .77463 L .56732 .77481 L F
.56524 .77565 m .56383 .77635 L .56617 .77463 L F
.541 .31 .515 r
.42703 .8531 m .42685 .8551 L .42468 .85525 L F
.611 .371 .528 r
.42703 .8531 m .42889 .85515 L .42685 .8551 L F
.557 .367 .58 r
.42888 .85277 m .42889 .85515 L .42703 .8531 L F
.611 .693 .901 r
.51981 .87938 m .51966 .87654 L .51694 .87674 L F
.305 0 .121 r
.51981 .87938 m .52197 .87828 L .52192 .87892 L F
.611 .693 .901 r
.51981 .87938 m .52192 .87892 L .51966 .87654 L F
.08 .625 .843 r
.37152 .7296 m .37456 .73003 L .37304 .72996 L F
.13 .508 .91 r
.46317 .86541 m .46257 .86602 L .46174 .86495 L F
.172 .57 .935 r
.46425 .86641 m .46257 .86602 L .46317 .86541 L F
.418 .365 .692 r
.60707 .82046 m .60508 .82176 L .60538 .82064 L F
.394 .32 .655 r
.60689 .82387 m .60508 .82176 L .60707 .82046 L F
.577 .324 .497 r
.4789 .81889 m .48121 .8188 L .48126 .81648 L F
.488 .254 .485 r
.48126 .81648 m .48309 .81839 L .48421 .81591 L F
.48126 .81648 m .48121 .8188 L .48309 .81839 L F
.543 .613 .872 r
.69267 .71398 m .69049 .71424 L .68913 .71175 L F
.532 .371 .608 r
.69267 .71398 m .69076 .71737 L .69049 .71424 L F
.519 .233 .419 r
.38267 .77455 m .382 .77686 L .3799 .7771 L F
.502 .216 .413 r
.38404 .77652 m .38267 .77455 L .38474 .77442 L F
.38404 .77652 m .382 .77686 L .38267 .77455 L F
.635 .576 .771 r
.57363 .81709 m .57478 .81921 L .572 .81912 L F
.625 .357 .492 r
.572 .81912 m .57478 .81921 L .57406 .82107 L F
.487 .363 .636 r
.57406 .82107 m .5723 .82185 L .572 .81912 L F
.747 .347 .293 r
.50977 .81546 m .5131 .81619 L .51093 .81392 L F
.663 .376 .475 r
.51093 .81392 m .5131 .81619 L .51396 .81382 L F
.628 .858 .986 r
.47416 .84458 m .47089 .8443 L .47235 .84438 L F
.904 .89 .806 r
.47416 .84458 m .47649 .84282 L .47608 .84444 L F
.47416 .84458 m .4747 .84171 L .47649 .84282 L F
.47416 .84458 m .47235 .84438 L .4747 .84171 L F
.749 .757 .859 r
.63916 .72966 m .63603 .72946 L .63831 .72742 L F
.786 .795 .86 r
.64132 .72745 m .63916 .72966 L .63831 .72742 L F
.687 .534 .673 r
.41961 .85572 m .41964 .8582 L .41753 .85844 L F
.67 .52 .672 r
.42173 .85754 m .41964 .8582 L .41961 .85572 L F
.692 .631 .784 r
.38588 .73992 m .38254 .73801 L .38467 .73738 L F
.609 .632 .848 r
.38772 .73852 m .38588 .73992 L .38467 .73738 L F
.592 .247 .354 r
.40922 .82873 m .41263 .82662 L .41056 .82729 L F
.246 .759 .769 r
.46346 .88383 m .46455 .88344 L .46257 .88401 L F
.46346 .88383 m .46602 .88318 L .46455 .88344 L F
.208 0 0 r
.65814 .76525 m .65772 .76583 L .65555 .76654 L F
.377 0 .119 r
.65772 .76583 m .65426 .76795 L .65555 .76654 L F
.519 .257 .457 r
.60091 .75583 m .60337 .75353 L .60118 .75396 L F
.614 .826 .981 r
.42405 .87694 m .42074 .87671 L .42283 .87636 L F
.499 .779 .995 r
.42484 .87582 m .42405 .87694 L .42283 .87636 L F
.42484 .87582 m .42622 .87671 L .42405 .87694 L F
.525 .92 .855 r
.58147 .83983 m .5781 .84111 L .58087 .83948 L F
.978 .679 .355 r
.52289 .82527 m .52376 .82456 L .52138 .82408 L F
.52289 .82527 m .52383 .82652 L .52376 .82456 L F
.581 .334 .507 r
.52376 .82456 m .52383 .82652 L .52605 .82627 L F
.514 .13 .25 r
.47143 .82178 m .47321 .82287 L .47455 .82069 L F
.552 .18 .29 r
.47321 .82287 m .47656 .82092 L .47455 .82069 L F
.78 .687 .761 r
.45837 .86281 m .46003 .86617 L .45735 .86591 L F
.53 .569 .839 r
.46174 .86495 m .46003 .86617 L .45837 .86281 L F
.729 .327 .288 r
.48181 .86236 m .48272 .86092 L .48138 .86243 L F
.987 .74 .47 r
.48186 .86206 m .48272 .86092 L .48181 .86236 L F
.864 .68 .652 r
.48172 .86221 m .48181 .86236 L .48138 .86243 L F
.3 0 0 r
.48138 .86243 m .48143 .86238 L .48169 .86227 L F
.48143 .86238 m .48197 .86177 L .4817 .86224 L F
.48143 .86238 m .4817 .86224 L .48169 .86227 L F
.864 .68 .652 r
.47911 .85795 m .48172 .86221 L .48138 .86243 L F
.3 0 0 r
.48174 .8622 m .48272 .86092 L .48177 .86218 L F
.48197 .86177 m .48272 .86092 L .48169 .86227 L F
.864 .68 .652 r
.47911 .85795 m .48042 .86052 L .48023 .86054 L F
.48042 .86052 m .48138 .86243 L .48023 .86054 L F
.955 .62 .336 r
.48023 .86054 m .4817 .86224 L .48058 .86037 L F
.48023 .86054 m .48058 .86037 L .47911 .85795 L F
.4817 .86224 m .48172 .86221 L .47911 .85795 L F
.738 .603 .706 r
.48231 .8569 m .48023 .86054 L .47896 .85636 L F
.457 .433 .744 r
.47896 .85636 m .48023 .86054 L .47911 .85795 L F
.778 .593 .649 r
.47911 .85795 m .48023 .86054 L .47786 .86205 L F
.928 .635 .467 r
.47911 .85795 m .48023 .86054 L .47882 .86149 L F
.352 .481 .85 r
.48023 .86054 m .48111 .85889 L .47961 .86059 L F
.48023 .86054 m .47961 .86059 L .47882 .86149 L F
.987 .74 .47 r
.48253 .85825 m .48272 .86092 L .48186 .86206 L F
.364 0 .113 r
.48369 .85928 m .48253 .85825 L .48186 .86206 L F
.3 0 0 r
.48186 .86206 m .48272 .86092 L .48197 .86211 L F
.364 0 .113 r
.48369 .85928 m .48186 .86206 L .48196 .86211 L F
.833 .755 .777 r
.48369 .85928 m .48196 .86211 L .48036 .86066 L F
.48369 .85928 m .48036 .86066 L .4805 .86044 L F
.364 0 .113 r
.48369 .85928 m .48485 .85758 L .48253 .85825 L F
.833 .755 .777 r
.48369 .85928 m .48023 .86054 L .48231 .8569 L F
.3 0 0 r
.48197 .86211 m .48272 .86092 L .48468 .86064 L F
.955 .62 .336 r
.4817 .86224 m .48181 .86236 L .48172 .86221 L F
.364 0 .113 r
.48196 .86211 m .48186 .86206 L .48181 .86236 L F
.833 .755 .777 r
.48196 .86211 m .48181 .86236 L .4817 .86224 L F
.3 0 0 r
.48138 .86243 m .48468 .86064 L .48416 .86314 L F
.973 .746 .534 r
.48416 .86314 m .48369 .85928 L .48199 .86185 L F
0 0 0 r
.48199 .86185 m .4823 .86138 L .48243 .86135 L F
.4823 .86138 m .48369 .85928 L .48243 .86135 L F
.961 .717 .522 r
.48243 .86135 m .48369 .85928 L .48345 .85887 L F
.48234 .85803 m .48278 .85772 L .48231 .8569 L F
.48243 .86135 m .48232 .8574 L .48438 .8566 L F
.87 .755 .734 r
.48111 .85889 m .48243 .86135 L .48438 .8566 L F
0 0 .534 r
.48111 .85889 m .48249 .86134 L .48243 .86135 L F
.48249 .86134 m .48299 .86223 L .48243 .86135 L F
.961 .717 .522 r
.48232 .8574 m .48231 .8569 L .48266 .85685 L F
.48232 .8574 m .48266 .85685 L .48438 .8566 L F
.833 .755 .777 r
.4805 .86044 m .48036 .86066 L .48023 .86054 L F
.3 0 0 r
.48174 .8622 m .48177 .86218 L .48172 .86225 L F
.48172 .86225 m .48186 .86206 L .48197 .86211 L F
.833 .755 .777 r
.48196 .86211 m .4817 .86224 L .48023 .86054 L F
.3 0 0 r
.48169 .86227 m .48174 .8622 L .48172 .86225 L F
.937 .746 .619 r
.67351 .7271 m .67452 .73005 L .67491 .72786 L F
.93 .971 .715 r
.67489 .74134 m .67519 .7394 L .67671 .74031 L F
.92 .837 .747 r
.67727 .73849 m .67671 .74031 L .67519 .7394 L F
.555 .327 .524 r
.39673 .83424 m .39514 .83172 L .39472 .83451 L F
.39673 .83424 m .39674 .83159 L .39514 .83172 L F
.87 .453 .223 r
.54551 .81301 m .54821 .81581 L .54637 .81359 L F
.579 .43 .643 r
.60268 .80051 m .60452 .79753 L .60265 .79815 L F
.556 .395 .619 r
.3841 .75631 m .38609 .75602 L .38604 .75364 L F
.626 .09 0 r
.6482 .72185 m .64931 .72257 L .64669 .72057 L F
.944 .738 .594 r
.64757 .724 m .64931 .72257 L .6482 .72185 L F
.64757 .724 m .64891 .72485 L .64931 .72257 L F
0 .221 .68 r
.54143 .80917 m .54343 .81048 L .54365 .81086 L F
.922 .548 .288 r
.54343 .81048 m .54551 .81301 L .54365 .81086 L F
.681 .892 .974 r
.42649 .89023 m .4298 .88988 L .42841 .88936 L F
.738 .904 .952 r
.42841 .88936 m .4298 .88988 L .43114 .88893 L F
.276 0 0 r
.37982 .76199 m .3767 .76378 L .37875 .76322 L F
.456 .01 .1 r
.38121 .76312 m .37982 .76199 L .37875 .76322 L F
.003 .574 .77 r
.66055 .75052 m .66237 .75073 L .66257 .75067 L F
.784 .393 .313 r
.66055 .75052 m .66237 .75073 L .66131 .75237 L F
0 0 0 r
.66257 .75067 m .66237 .75073 L .66131 .75237 L F
.66131 .75237 m .66237 .75073 L .66257 .75067 L F
.57549 .82919 m .57648 .82703 L .57567 .82897 L F
.444 .742 .991 r
.57736 .82602 m .57648 .82703 L .57671 .82637 L F
0 0 0 r
.57567 .82897 m .57648 .82703 L .57736 .82602 L F
.884 .7 .648 r
.53532 .83633 m .53481 .83536 L .53374 .83521 L F
.91 .882 .794 r
.57136 .83422 m .57129 .83178 L .57044 .83405 L F
.917 .976 .768 r
.5696 .83677 m .57136 .83422 L .57044 .83405 L F
.302 .405 .802 r
.44053 .84728 m .43969 .84903 L .43858 .84797 L F
.44053 .84728 m .44158 .84983 L .43969 .84903 L F
.342 .39 .766 r
.44158 .84983 m .44057 .85075 L .43969 .84903 L F
.786 .984 .901 r
.49601 .88676 m .49693 .88695 L .49906 .8851 L F
.709 .49 .589 r
.4324 .8551 m .42888 .85277 L .43231 .85313 L F
.719 .477 .559 r
.43459 .853 m .4324 .8551 L .43231 .85313 L F
.5 .243 .457 r
.36263 .77422 m .36519 .77189 L .3632 .77239 L F
.93 .971 .715 r
.67489 .74134 m .67342 .74241 L .67519 .7394 L F
.769 .697 .783 r
.64247 .73484 m .64609 .73551 L .64461 .73222 L F
.777 .68 .756 r
.64247 .73484 m .64373 .73715 L .64609 .73551 L F
.738 .683 .798 r
.64609 .73551 m .64779 .73262 L .64461 .73222 L F
.689 .618 .771 r
.64609 .73551 m .64888 .73583 L .64779 .73262 L F
.607 .552 .767 r
.5303 .84038 m .53108 .83617 L .52945 .83722 L F
.5303 .84038 m .53261 .84001 L .53108 .83617 L F
.722 .267 0 r
.48674 .8398 m .48653 .83981 L .48481 .83734 L F
0 .076 .634 r
.48674 .8398 m .48863 .84206 L .48844 .84132 L F
.48674 .8398 m .48844 .84132 L .48653 .83981 L F
.442 .154 .379 r
.51396 .81382 m .51514 .81561 L .5161 .81343 L F
.51396 .81382 m .5131 .81619 L .51514 .81561 L F
.544 .866 .584 r
.60745 .79487 m .60452 .79753 L .60681 .79717 L F
.432 .275 .566 r
.60745 .79487 m .6093 .79261 L .60688 .79292 L F
.60745 .79487 m .60949 .79487 L .6093 .79261 L F
.421 .191 .457 r
.60888 .79706 m .60745 .79487 L .60681 .79717 L F
.60888 .79706 m .60949 .79487 L .60745 .79487 L F
.577 .327 .501 r
.42468 .85525 m .42418 .85799 L .42173 .85754 L F
.603 .38 .551 r
.42685 .8551 m .42418 .85799 L .42468 .85525 L F
.502 .089 .19 r
.65574 .75849 m .65809 .75839 L .65899 .75699 L F
.537 .194 .333 r
.65809 .75839 m .66115 .7564 L .65899 .75699 L F
.501 .298 .536 r
.60821 .81122 m .61037 .8086 L .61011 .81081 L F
.513 .334 .576 r
.60821 .81355 m .60821 .81122 L .61011 .81081 L F
.691 .58 .726 r
.41638 .86822 m .41506 .86955 L .41329 .86576 L F
.614 .46 .65 r
.41638 .86822 m .41419 .87115 L .41506 .86955 L F
.416 0 0 r
.43726 .8269 m .43884 .82777 L .44035 .82637 L F
.601 .164 .183 r
.43884 .82777 m .44247 .82644 L .44035 .82637 L F
.578 .256 .388 r
.48845 .87447 m .49221 .87317 L .49014 .87656 L F
.56 .237 .377 r
.49014 .87656 m .49221 .87317 L .49344 .87353 L F
.829 .704 .727 r
.47867 .84213 m .47649 .84282 L .47806 .83974 L F
.473 .291 .552 r
.47867 .84213 m .47608 .84444 L .47649 .84282 L F
.47867 .84213 m .47674 .84536 L .47608 .84444 L F
.47867 .84213 m .47888 .84555 L .47674 .84536 L F
.574 .366 .561 r
.48104 .84509 m .47867 .84213 L .48075 .84147 L F
.48104 .84509 m .47888 .84555 L .47867 .84213 L F
.664 .505 .66 r
.3713 .84774 m .37364 .84764 L .37346 .84508 L F
.664 .517 .675 r
.37364 .84764 m .3757 .84478 L .37346 .84508 L F
.784 .599 .651 r
.68496 .71454 m .68695 .71784 L .68507 .71684 L F
.813 .695 .735 r
.68695 .71784 m .68619 .71987 L .68507 .71684 L F
.245 .09 .463 r
.68695 .71784 m .68755 .71876 L .68619 .71987 L F
.445 .472 .793 r
.47888 .84555 m .47934 .84737 L .47674 .84536 L F
.534 .475 .736 r
.47934 .84737 m .47769 .84803 L .47674 .84536 L F
.628 .65 .852 r
.41863 .87709 m .41557 .87604 L .41773 .87549 L F
.62 .646 .854 r
.42074 .87671 m .41863 .87709 L .41773 .87549 L F
.346 .791 .957 r
.52483 .81866 m .52163 .81854 L .52288 .81894 L F
.516 .521 .8 r
.52288 .81894 m .52664 .82253 L .52483 .81866 L F
.724 .688 .815 r
.68401 .71177 m .68496 .71454 L .68181 .71399 L F
.974 .706 .459 r
.68496 .71454 m .68411 .7151 L .68181 .71399 L F
.68496 .71454 m .68507 .71684 L .68411 .7151 L F
.713 .681 .818 r
.68745 .71258 m .68496 .71454 L .68401 .71177 L F
.606 .518 .729 r
.41773 .87549 m .41557 .87604 L .41511 .87423 L F
.06 0 0 r
.66853 .75342 m .66665 .75429 L .66552 .75521 L F
.73 .604 .716 r
.41419 .87115 m .4122 .87366 L .41249 .87172 L F
.713 .578 .702 r
.41419 .87115 m .41511 .87423 L .4122 .87366 L F
.541 .752 .974 r
.48914 .88808 m .49035 .88711 L .48829 .88751 L F
.48914 .88808 m .49127 .88782 L .49035 .88711 L F
.814 .922 .536 r
.62335 .75012 m .62283 .75173 L .62453 .74863 L F
.898 .94 .574 r
.62568 .74531 m .62453 .74863 L .62675 .74634 L F
.62568 .74531 m .62428 .74826 L .62453 .74863 L F
.901 .933 .559 r
.62428 .74826 m .62335 .75012 L .62453 .74863 L F
.75 .581 .666 r
.46439 .83745 m .46243 .84 L .46067 .83927 L F
.679 .58 .737 r
.4673 .83976 m .46439 .83745 L .4662 .83678 L F
.522 .258 .456 r
.44057 .85075 m .43975 .85274 L .43766 .85296 L F
0 0 .083 r
.44158 .84983 m .43975 .85274 L .44057 .85075 L F
.912 .732 .646 r
.68507 .71684 m .68619 .71987 L .68393 .7195 L F
.807 .357 .171 r
.68393 .7195 m .68619 .71987 L .68494 .72026 L F
.663 .968 .914 r
.68755 .71876 m .68725 .71853 L .68619 .71987 L F
.666 .972 .823 r
.68619 .71987 m .68725 .71853 L .68494 .72026 L F
.051 .161 .66 r
.6818 .73719 m .68209 .74026 L .68299 .73843 L F
.941 .782 .656 r
.5448 .79791 m .54403 .79576 L .54488 .79547 L F
.449 .87 .743 r
.54488 .79547 m .54403 .79576 L .5459 .79471 L F
.746 .529 .6 r
.51601 .87608 m .51651 .87399 L .51281 .87362 L F
.796 .459 .419 r
.51839 .87645 m .51651 .87399 L .51601 .87608 L F
0 0 0 r
.35323 .75177 m .35303 .75146 L .35501 .75106 L F
.35323 .75177 m .35128 .75247 L .35303 .75146 L F
.337 .121 .431 r
.61179 .80803 m .61037 .8086 L .61231 .80588 L F
.368 .185 .496 r
.61011 .81081 m .61037 .8086 L .61179 .80803 L F
.628 .583 .784 r
.64779 .73262 m .64888 .73583 L .65107 .73523 L F
.606 .518 .729 r
.41773 .87549 m .41511 .87423 L .41734 .87421 L F
0 0 0 r
.52197 .87828 m .52428 .87621 L .52427 .87833 L F
.394 .102 .347 r
.52192 .87892 m .52197 .87828 L .52427 .87833 L F
.759 .687 .783 r
.46848 .83713 m .4673 .83976 L .4662 .83678 L F
.418 .365 .692 r
.60707 .82046 m .60538 .82064 L .60591 .81868 L F
.426 .254 .542 r
.60707 .82046 m .60591 .81868 L .60867 .81841 L F
.92 .837 .747 r
.67727 .73849 m .67519 .7394 L .67633 .73777 L F
.718 .755 .882 r
.40427 .75243 m .40526 .75376 L .40197 .75348 L F
.538 .681 .931 r
.40668 .75232 m .40526 .75376 L .40427 .75243 L F
.632 .85 .983 r
.4077 .75327 m .40526 .75376 L .40668 .75232 L F
.544 .326 .534 r
.4077 .75327 m .40532 .75607 L .40526 .75376 L F
.976 .918 .663 r
.55156 .82694 m .55189 .82379 L .55181 .82513 L F
.24 .307 .732 r
.55372 .82915 m .55156 .82694 L .55181 .82513 L F
.864 .734 .718 r
.56788 .80272 m .57086 .80089 L .56755 .80017 L F
.56788 .80272 m .57034 .80321 L .57086 .80089 L F
.302 .055 .363 r
.61141 .78786 m .61078 .78991 L .61303 .78706 L F
.951 .941 .737 r
.59326 .82358 m .59409 .82411 L .59245 .82697 L F
.032 0 0 r
.57219 .77176 m .57376 .77146 L .5747 .77001 L F
0 0 0 r
.5747 .77001 m .57532 .77045 L .57677 .76952 L F
.5747 .77001 m .57376 .77146 L .57532 .77045 L F
.56428 .83655 m .56337 .83862 L .56424 .83683 L F
.844 .671 .132 r
.56337 .83862 m .56314 .83855 L .56424 .83683 L F
.56337 .83862 m .5634 .83963 L .56314 .83855 L F
.635 .31 .404 r
.48421 .81591 m .48637 .81784 L .48629 .81617 L F
.48421 .81591 m .48309 .81839 L .48637 .81784 L F
.766 .503 .537 r
.48038 .85034 m .47769 .84803 L .47934 .84737 L F
.48038 .85034 m .47707 .85008 L .47769 .84803 L F
.505 .318 .562 r
.61349 .78587 m .6158 .78506 L .61563 .78237 L F
.464 .252 .506 r
.61563 .78237 m .61751 .78204 L .61772 .77996 L F
.388 .232 .545 r
.61563 .78237 m .61694 .78385 L .61751 .78204 L F
.61563 .78237 m .6158 .78506 L .61694 .78385 L F
.575 .237 .36 r
.60859 .76363 m .60808 .76594 L .60547 .76608 L F
.68 .679 .842 r
.60859 .76363 m .61123 .76218 L .6104 .76276 L F
.281 0 .268 r
.60971 .76538 m .60808 .76594 L .60859 .76363 L F
.765 .894 .934 r
.51415 .82113 m .51541 .82173 L .5175 .82031 L F
0 .058 .564 r
.54933 .81896 m .55129 .82078 L .5516 .82121 L F
.732 .526 0 r
.55176 .82299 m .5516 .82121 L .55129 .82078 L F
.607 .158 0 r
.55173 .82301 m .55176 .82299 L .55092 .82189 L F
.169 .199 .648 r
.55323 .8251 m .55228 .8248 L .55176 .82299 L F
.607 .158 0 r
.55323 .8251 m .55176 .82299 L .55173 .82301 L F
.732 .526 0 r
.55176 .82299 m .55189 .82379 L .5518 .82296 L F
.55176 .82299 m .5518 .82296 L .5516 .82121 L F
.927 .941 .59 r
.49409 .8171 m .49395 .8178 L .49465 .81661 L F
.57 .215 .327 r
.49693 .81706 m .49395 .8178 L .49409 .8171 L F
.052 0 0 r
.49569 .81648 m .49593 .81639 L .49595 .81637 L F
.927 .941 .59 r
.49444 .81532 m .49409 .8171 L .49491 .81616 L F
.49409 .8171 m .49465 .81661 L .49491 .81616 L F
.918 .696 .586 r
.49691 .81368 m .49565 .81452 L .49491 .81616 L F
.49565 .81452 m .49444 .81532 L .49477 .81592 L F
.49565 .81452 m .49477 .81592 L .49491 .81616 L F
.49605 .8163 m .49693 .81706 L .49602 .81642 L F
.49692 .81547 m .49693 .81706 L .49605 .8163 L F
.57 .215 .327 r
.4957 .81649 m .49409 .8171 L .49569 .81648 L F
.052 0 0 r
.49569 .81648 m .49595 .81637 L .49444 .81532 L F
.57 .215 .327 r
.49596 .81638 m .49409 .8171 L .49444 .81532 L F
.052 0 0 r
.49361 .81743 m .49569 .81648 L .49444 .81532 L F
.57 .215 .327 r
.49597 .81638 m .4957 .81649 L .49596 .81638 L F
.4957 .81649 m .49569 .81648 L .49596 .81638 L F
.49693 .81706 m .49461 .8171 L .49596 .81638 L F
.261 0 0 r
.49596 .81638 m .49495 .8175 L .49643 .81727 L F
.49595 .81637 m .49593 .81639 L .49596 .81638 L F
.49593 .81639 m .49495 .8175 L .49596 .81638 L F
.57 .215 .327 r
.49597 .81638 m .49596 .81638 L .49597 .81638 L F
.49693 .81706 m .49596 .81638 L .49597 .81638 L F
.49461 .8171 m .49409 .8171 L .49597 .81638 L F
.564 .405 .624 r
.49927 .81421 m .49693 .81706 L .49691 .81368 L F
.261 0 0 r
.49609 .81632 m .49643 .81727 L .49981 .81501 L F
.918 .696 .586 r
.49691 .81368 m .4961 .81616 L .49565 .81452 L F
.4961 .81616 m .49602 .81642 L .49595 .81609 L F
.4961 .81616 m .49595 .81609 L .49565 .81452 L F
.897 .749 .689 r
.49444 .81532 m .49595 .81637 L .49595 .81609 L F
.261 0 0 r
.49595 .81637 m .49596 .81639 L .496 .81635 L F
.477 .408 .701 r
.49598 .81622 m .49595 .81637 L .496 .81635 L F
.918 .696 .586 r
.49565 .81452 m .49602 .81642 L .49444 .81532 L F
.897 .749 .689 r
.49444 .81532 m .49595 .81609 L .49593 .81298 L F
.261 0 0 r
.496 .81635 m .49601 .81636 L .49609 .81632 L F
.49601 .81636 m .49643 .81727 L .49609 .81632 L F
.49596 .81639 m .49643 .81727 L .496 .81635 L F
.918 .696 .586 r
.49691 .81368 m .49692 .81547 L .49605 .8163 L F
.477 .408 .701 r
.49645 .81324 m .49598 .81622 L .49981 .81501 L F
.49598 .81622 m .496 .81635 L .49981 .81501 L F
.49593 .81298 m .49594 .81405 L .49645 .81324 L F
.49594 .81405 m .49595 .81637 L .49645 .81324 L F
.052 0 0 r
.49385 .81732 m .49495 .8175 L .49593 .81639 L F
.49385 .81732 m .49593 .81639 L .49569 .81648 L F
.49361 .81743 m .49372 .81743 L .49385 .81732 L F
.49372 .81743 m .49495 .8175 L .49385 .81732 L F
.537 .319 .531 r
.49297 .83223 m .49509 .83198 L .49568 .82954 L F
.561 .341 .539 r
.49568 .82954 m .49509 .83198 L .49381 .82874 L F
.49568 .82954 m .4973 .83182 L .49509 .83198 L F
.49509 .83198 m .4973 .83182 L .49568 .82954 L F
.685 .521 .658 r
.41964 .8582 m .41741 .86064 L .41753 .85844 L F
0 0 0 r
.57103 .77282 m .57376 .77146 L .57219 .77176 L F
.365 .092 .36 r
.36093 .7748 m .36029 .77675 L .36263 .77422 L F
.242 .757 .786 r
.58462 .84883 m .58726 .84823 L .58608 .84839 L F
.58462 .84883 m .58608 .84839 L .58607 .84839 L F
.225 .745 .832 r
.58641 .84864 m .58726 .84823 L .58462 .84883 L F
.242 .757 .786 r
.58462 .84883 m .58607 .84839 L .58419 .84914 L F
.153 .693 .723 r
.58263 .84929 m .58372 .8491 L .58462 .84883 L F
.58372 .8491 m .58641 .84864 L .58462 .84883 L F
.225 .745 .832 r
.58641 .84864 m .58859 .84831 L .58726 .84823 L F
.379 .77 .988 r
.3743 .74834 m .37291 .74775 L .37096 .7479 L F
0 .278 .713 r
.3743 .74834 m .37445 .7482 L .37291 .74775 L F
.3743 .74834 m .37588 .74919 L .37445 .7482 L F
.609 .838 .987 r
.52696 .81597 m .52999 .81625 L .52895 .81529 L F
.776 .513 .538 r
.52696 .81846 m .52999 .81625 L .52696 .81597 L F
.52696 .81846 m .53023 .81864 L .52999 .81625 L F
.681 .597 .754 r
.4122 .87366 m .40898 .8712 L .41249 .87172 L F
.735 .532 .618 r
.49771 .86602 m .49408 .86814 L .49626 .8652 L F
.49771 .86602 m .49772 .86839 L .49408 .86814 L F
0 .444 .82 r
.49814 .86582 m .49771 .86602 L .49626 .8652 L F
0 .135 .673 r
.49814 .86582 m .49976 .86806 L .49771 .86602 L F
.526 .364 .604 r
.49976 .86806 m .49772 .86839 L .49771 .86602 L F
.615 .45 .635 r
.60688 .79292 m .6093 .79261 L .609 .79028 L F
.627 .791 .961 r
.42172 .82589 m .41791 .82599 L .41957 .82438 L F
0 0 0 r
.41791 .82599 m .41981 .82547 L .41957 .82438 L F
.41791 .82599 m .41691 .82663 L .41981 .82547 L F
.346 .616 .951 r
.42282 .82532 m .42172 .82589 L .41957 .82438 L F
.42282 .82532 m .42344 .82635 L .42172 .82589 L F
.643 .463 .625 r
.37144 .85017 m .37364 .84764 L .3713 .84774 L F
.955 .807 .658 r
.56818 .80519 m .57034 .80321 L .56788 .80272 L F
.56818 .80519 m .56941 .80604 L .57034 .80321 L F
0 0 0 r
.67191 .76059 m .67068 .76153 L .67308 .75933 L F
.754 .994 .857 r
.67507 .75874 m .67191 .76059 L .67308 .75933 L F
.461 .245 .498 r
.61772 .77996 m .61964 .77945 L .61964 .77745 L F
.502 .318 .563 r
.61964 .77745 m .62166 .77762 L .62166 .77439 L F
.364 .17 .479 r
.61964 .77745 m .62118 .77838 L .62166 .77762 L F
.61964 .77745 m .61964 .77945 L .62118 .77838 L F
.724 .613 .732 r
.68209 .74026 m .68032 .74316 L .68004 .74133 L F
.644 .508 .682 r
.68209 .74026 m .6824 .74303 L .68032 .74316 L F
.519 .302 .525 r
.6824 .74303 m .68066 .74607 L .68032 .74316 L F
.587 .472 .689 r
.41504 .86522 m .41335 .86406 L .41534 .86332 L F
.41504 .86522 m .41329 .86576 L .41335 .86406 L F
.692 .465 .573 r
.39977 .83173 m .40276 .83153 L .4026 .82948 L F
.559 .49 .734 r
.4026 .82948 m .40508 .82955 L .40396 .82646 L F
.637 .489 .665 r
.40276 .83153 m .40508 .82955 L .4026 .82948 L F
.565 .316 .497 r
.58616 .76368 m .58833 .76149 L .58614 .76166 L F
.488 .347 .615 r
.61078 .78991 m .609 .79028 L .61099 .79213 L F
.47 .346 .63 r
.609 .79028 m .6093 .79261 L .61099 .79213 L F
.577 .551 .789 r
.49381 .82874 m .49509 .83198 L .49297 .83223 L F
.778 .437 .409 r
.57904 .77633 m .57746 .77724 L .57562 .7746 L F
.4 .82 .64 r
.57922 .77615 m .57904 .77633 L .58086 .77418 L F
.57922 .77615 m .57746 .77724 L .57904 .77633 L F
.139 0 0 r
.58204 .7744 m .58086 .77418 L .58287 .77348 L F
.58204 .7744 m .57922 .77615 L .58086 .77418 L F
.522 .334 .567 r
.62166 .77439 m .62396 .77669 L .62376 .77478 L F
.62166 .77439 m .62166 .77762 L .62396 .77669 L F
.529 .306 .521 r
.37546 .77979 m .37515 .78196 L .37321 .78221 L F
.479 .249 .487 r
.37742 .77941 m .37515 .78196 L .37546 .77979 L F
0 0 0 r
.56539 .83312 m .56428 .83655 L .56424 .83683 L F
.273 .279 .684 r
.55903 .79457 m .55859 .79767 L .56049 .79526 L F
.633 .742 .926 r
.6757 .73341 m .67241 .73281 L .6746 .73236 L F
.746 .801 .897 r
.67767 .73245 m .6757 .73341 L .6746 .73236 L F
.691 .58 .726 r
.41638 .86822 m .41329 .86576 L .41504 .86522 L F
.747 .646 .749 r
.41851 .86552 m .41638 .86822 L .41504 .86522 L F
.273 .279 .684 r
.55903 .79457 m .56026 .79689 L .55859 .79767 L F
.336 .443 .822 r
.56026 .79689 m .56063 .79868 L .55859 .79767 L F
.544 .175 .29 r
.45528 .82619 m .45744 .82618 L .45862 .82415 L F
.555 .186 .296 r
.45862 .82415 m .46066 .82535 L .46078 .82438 L F
.45862 .82415 m .45744 .82618 L .46066 .82535 L F
.781 .287 .036 r
.55184 .80481 m .5487 .80234 L .54973 .80286 L F
.096 0 0 r
.46981 .88292 m .47113 .88279 L .47327 .88293 L F
.555 .033 0 r
.49878 .87726 m .49924 .87672 L .49658 .8765 L F
.334 .809 .904 r
.50121 .87604 m .49924 .87672 L .49878 .87726 L F
.50121 .87604 m .50213 .8762 L .49924 .87672 L F
.713 .56 .68 r
.3757 .84478 m .37867 .84503 L .37841 .84266 L F
.632 .502 .685 r
.37841 .84266 m .37867 .84503 L .38064 .84237 L F
.719 .477 .559 r
.43459 .853 m .43461 .85559 L .4324 .8551 L F
.663 .432 .559 r
.43689 .85536 m .43459 .853 L .43766 .85296 L F
.43689 .85536 m .43461 .85559 L .43459 .853 L F
.563 .191 .294 r
.46898 .84573 m .46775 .84757 L .46531 .84744 L F
.701 .351 .381 r
.4697 .84747 m .46775 .84757 L .46898 .84573 L F
.547 0 0 r
.67798 .73383 m .67929 .73443 L .67767 .73245 L F
.67798 .73383 m .6808 .73548 L .67929 .73443 L F
.495 .231 .443 r
.39155 .76914 m .38906 .77145 L .38953 .76953 L F
.917 .976 .768 r
.5696 .83677 m .57044 .83405 L .5707 .83621 L F
0 0 .479 r
.5713 .83904 m .5696 .83677 L .5707 .83621 L F
.5713 .83904 m .57028 .8394 L .5696 .83677 L F
.611 .56 .772 r
.38563 .75109 m .38604 .75364 L .38821 .75312 L F
.587 .428 .633 r
.38609 .75602 m .38821 .75312 L .38604 .75364 L F
.635 .663 .86 r
.39456 .74299 m .39086 .7409 L .39296 .7408 L F
.605 .688 .901 r
.39669 .74264 m .39456 .74299 L .39296 .7408 L F
.551 .434 .673 r
.39669 .74264 m .39501 .74655 L .39456 .74299 L F
.269 .045 .378 r
.61231 .80588 m .61417 .80317 L .61389 .80513 L F
.388 .167 .453 r
.61179 .80803 m .61231 .80588 L .61389 .80513 L F
.403 .111 .351 r
.37036 .78491 m .36789 .78707 L .36857 .78537 L F
.735 .435 .473 r
.57562 .7746 m .57746 .77724 L .57702 .77754 L F
.719 .298 .247 r
.50268 .84442 m .4989 .8442 L .50061 .84257 L F
.632 .352 .476 r
.50282 .84268 m .50268 .84442 L .50061 .84257 L F
.939 .932 .766 r
.58406 .82927 m .58497 .82962 L .58349 .83217 L F
.33 .813 .799 r
.58653 .82893 m .58497 .82962 L .58406 .82927 L F
.58653 .82893 m .58747 .82885 L .58497 .82962 L F
.527 .137 .244 r
.52605 .82627 m .52856 .82634 L .52937 .82447 L F
.055 0 .034 r
.52937 .82447 m .53004 .82543 L .53147 .82411 L F
.52937 .82447 m .52856 .82634 L .53004 .82543 L F
.247 .633 .96 r
.36622 .72984 m .36746 .73079 L .3643 .72954 L F
.613 .683 .892 r
.36832 .7286 m .36746 .73079 L .36622 .72984 L F
.36832 .7286 m .3696 .73035 L .36746 .73079 L F
.372 .783 .981 r
.55113 .8366 m .55171 .83573 L .54961 .83633 L F
.55113 .8366 m .55326 .83637 L .55171 .83573 L F
.493 .237 .454 r
.55229 .8406 m .55326 .83637 L .55113 .8366 L F
.558 .34 .54 r
.41942 .86025 m .41741 .86064 L .41964 .8582 L F
.695 .497 .615 r
.42173 .85754 m .41942 .86025 L .41964 .8582 L F
.498 .226 .432 r
.62376 .77478 m .62663 .77477 L .62685 .77164 L F
.389 .139 .409 r
.62685 .77164 m .62842 .77381 L .62911 .7718 L F
.62685 .77164 m .62663 .77477 L .62842 .77381 L F
.924 .728 .239 r
.56386 .84239 m .5643 .84451 L .56464 .84426 L F
0 .128 .669 r
.5643 .84451 m .56671 .84704 L .56464 .84426 L F
0 .134 .682 r
.5643 .84451 m .56681 .84807 L .56671 .84704 L F
.76 .48 .51 r
.53581 .8681 m .53301 .86599 L .533 .86833 L F
.589 .4 .594 r
.383 .83984 m .3852 .83956 L .38511 .8373 L F
.635 .438 .599 r
.3852 .83956 m .38781 .83692 L .38511 .8373 L F
.389 0 .149 r
.65203 .7299 m .65438 .72937 L .65513 .72751 L F
.6 .424 .616 r
.65724 .72722 m .65572 .73076 L .65513 .72751 L F
.941 .685 .52 r
.65613 .72931 m .65513 .72751 L .65438 .72937 L F
.65613 .72931 m .65724 .72722 L .65513 .72751 L F
.58 .347 .527 r
.43975 .85274 m .43689 .85536 L .43766 .85296 L F
.748 .632 .731 r
.64779 .73262 m .65124 .73284 L .6501 .73002 L F
.628 .583 .784 r
.64779 .73262 m .65107 .73523 L .65124 .73284 L F
.086 .445 .88 r
.65305 .73217 m .6501 .73002 L .65124 .73284 L F
.392 .074 .303 r
.61349 .78587 m .61475 .78641 L .6158 .78506 L F
.61349 .78587 m .61303 .78706 L .61475 .78641 L F
.899 .509 .272 r
.56031 .81621 m .56256 .81887 L .56144 .81858 L F
.963 .691 .471 r
.56144 .81858 m .56256 .81887 L .56232 .82143 L F
.446 .832 .986 r
.65937 .72454 m .66148 .72399 L .66234 .72464 L F
.483 .272 .517 r
.66131 .72628 m .65937 .72454 L .66234 .72464 L F
.474 .848 .987 r
.66234 .72464 m .66148 .72399 L .66397 .7236 L F
.305 .007 .283 r
.66397 .7236 m .66131 .72628 L .66234 .72464 L F
.357 0 0 r
.42344 .82635 m .42518 .82681 L .42651 .82663 L F
.031 .602 .726 r
.42518 .82681 m .42877 .82676 L .42651 .82663 L F
0 0 0 r
.52428 .87621 m .52632 .87559 L .52566 .87598 L F
.148 0 .343 r
.52427 .87833 m .52428 .87621 L .52566 .87598 L F
.464 .252 .506 r
.61772 .77996 m .61751 .78204 L .61964 .77945 L F
.49 .809 1 r
.50668 .81423 m .50545 .81527 L .50417 .81397 L F
.50668 .81423 m .50755 .81493 L .50545 .81527 L F
.729 .798 .906 r
.48005 .83895 m .48362 .8389 L .48221 .83884 L F
.641 .389 .521 r
.48481 .83734 m .48221 .83884 L .48362 .8389 L F
.519 .913 .799 r
.64135 .76524 m .64285 .7642 L .64419 .76441 L F
.562 .922 .949 r
.64419 .76441 m .6452 .7633 L .64615 .76376 L F
.64419 .76441 m .64285 .7642 L .6452 .7633 L F
.899 .549 .373 r
.4714 .84802 m .47047 .84959 L .4697 .84747 L F
.772 .371 .294 r
.4714 .84802 m .47322 .85018 L .47047 .84959 L F
.798 .335 .135 r
.47489 .85052 m .47322 .85018 L .4714 .84802 L F
0 0 0 r
.64076 .77419 m .64354 .77233 L .64204 .77361 L F
.64038 .77466 m .64076 .77419 L .64204 .77361 L F
.685 .418 .513 r
.55326 .83637 m .55489 .83676 L .55571 .83463 L F
.55326 .83637 m .55518 .835 L .555 .83641 L F
.647 .57 .754 r
.55326 .83637 m .55391 .83953 L .55489 .83676 L F
.178 .667 .922 r
.55171 .83573 m .55326 .83637 L .555 .83641 L F
.55171 .83573 m .555 .83641 L .55385 .83357 L F
.935 .867 .748 r
.55387 .83583 m .555 .83641 L .55229 .8406 L F
0 0 0 r
.55548 .83878 m .55229 .8406 L .555 .83641 L F
.948 .639 .2 r
.55476 .83827 m .555 .83641 L .55387 .83583 L F
.5548 .83837 m .555 .83641 L .55476 .83827 L F
.685 .418 .513 r
.55518 .835 m .55571 .83463 L .555 .83641 L F
0 0 .372 r
.55524 .83285 m .55571 .83463 L .55479 .832 L F
.967 .823 .4 r
.555 .83641 m .55571 .83463 L .55524 .83285 L F
.673 .141 0 r
.49373 .81131 m .49593 .81298 L .49727 .81294 L F
0 0 0 r
.58859 .84831 m .59133 .84736 L .59079 .84783 L F
.59279 .84712 m .59133 .84736 L .59321 .84669 L F
.59079 .84783 m .59133 .84736 L .59279 .84712 L F
.894 .75 .695 r
.49043 .81868 m .49133 .81888 L .49278 .81896 L F
.143 0 0 r
.49035 .81882 m .49185 .81896 L .49278 .81896 L F
0 .502 .749 r
.49023 .81863 m .49061 .81865 L .49185 .81896 L F
.684 .341 .388 r
.48629 .81617 m .48829 .81825 L .49089 .81719 L F
.779 .584 .637 r
.48829 .81825 m .49161 .8166 L .49089 .81719 L F
.48829 .81825 m .49035 .81882 L .49161 .8166 L F
0 .502 .749 r
.48829 .81825 m .48924 .81841 L .49023 .81863 L F
.48924 .81841 m .49061 .81865 L .49023 .81863 L F
.894 .75 .695 r
.49161 .8166 m .49043 .81868 L .49278 .81896 L F
.49043 .81868 m .49035 .81882 L .49133 .81888 L F
.397 .519 .864 r
.49161 .8166 m .49278 .81896 L .49361 .81743 L F
.78 .994 .873 r
.49278 .81896 m .49185 .81896 L .49361 .81743 L F
.472 .891 .903 r
.50126 .88445 m .50377 .88384 L .50301 .88345 L F
.694 .955 .951 r
.50377 .88384 m .5043 .88283 L .50301 .88345 L F
.50377 .88384 m .50701 .88229 L .5043 .88283 L F
.487 .895 .781 r
.67004 .76164 m .67068 .76153 L .67191 .76059 L F
.512 .207 .387 r
.48569 .87662 m .48845 .87447 L .48766 .87668 L F
.578 .256 .388 r
.48845 .87447 m .49014 .87656 L .48766 .87668 L F
.366 0 .154 r
.65814 .76525 m .65955 .76535 L .65772 .76583 L F
.65814 .76525 m .66043 .76451 L .65955 .76535 L F
.063 0 .082 r
.5161 .81343 m .51664 .81441 L .51832 .81329 L F
.5161 .81343 m .51514 .81561 L .51664 .81441 L F
.676 .859 .969 r
.42088 .89155 m .42306 .89162 L .42206 .89116 L F
.754 .811 .898 r
.42052 .88844 m .42156 .8905 L .42372 .88846 L F
.42156 .8905 m .42211 .89158 L .4228 .89024 L F
.42156 .8905 m .4228 .89024 L .42372 .88846 L F
.685 .881 .971 r
.42306 .89162 m .42495 .88979 L .42206 .89116 L F
.42495 .88979 m .42516 .88958 L .42463 .88985 L F
.42495 .88979 m .42463 .88985 L .42206 .89116 L F
.42306 .89162 m .42649 .89023 L .42516 .88958 L F
.646 .547 .729 r
.41942 .86025 m .42119 .86475 L .41734 .86283 L F
.577 .553 .791 r
.42237 .86415 m .42068 .86521 L .42117 .86477 L F
.42237 .86415 m .42059 .86507 L .42108 .8648 L F
.602 .524 .739 r
.42272 .86336 m .42119 .86475 L .41942 .86025 L F
.617 .553 .76 r
.42054 .86509 m .41734 .86283 L .42108 .8648 L F
.646 .547 .729 r
.42119 .86475 m .42108 .8648 L .41734 .86283 L F
.577 .553 .791 r
.42272 .86336 m .42237 .86415 L .42058 .86506 L F
.602 .524 .739 r
.42272 .86336 m .42124 .86489 L .42119 .86475 L F
.577 .553 .791 r
.42237 .86415 m .4214 .86628 L .42068 .86521 L F
.42117 .86477 m .42068 .86521 L .42059 .86507 L F
.42108 .8648 m .42059 .86507 L .42058 .86506 L F
.617 .553 .76 r
.42054 .86509 m .42108 .8648 L .42124 .86489 L F
.646 .547 .729 r
.42119 .86475 m .42124 .86489 L .42108 .8648 L F
.577 .553 .791 r
.42058 .86506 m .4214 .86628 L .42054 .86509 L F
.42272 .86336 m .42354 .86608 L .4214 .86628 L F
.572 .468 .697 r
.42354 .86608 m .42421 .86844 L .4214 .86628 L F
.558 .469 .711 r
.4214 .86628 m .42421 .86844 L .42193 .86864 L F
.936 .898 .764 r
.49593 .81298 m .49691 .81368 L .49727 .81294 L F
0 0 0 r
.64354 .77233 m .64395 .77282 L .64204 .77361 L F
.64354 .77233 m .64508 .77152 L .64395 .77282 L F
.752 .617 .71 r
.41734 .86283 m .41851 .86552 L .41504 .86522 L F
.617 .553 .76 r
.42054 .86509 m .41851 .86552 L .41734 .86283 L F
.39 .206 .508 r
.61417 .80317 m .61583 .80022 L .61546 .80306 L F
.383 .185 .484 r
.61389 .80513 m .61417 .80317 L .61546 .80306 L F
.439 .854 .959 r
.50854 .88103 m .51167 .88077 L .51061 .88066 L F
.373 .832 .912 r
.51061 .88066 m .51167 .88077 L .51375 .88027 L F
.564 .405 .624 r
.49927 .81421 m .49691 .81368 L .49593 .81298 L F
.544 .321 .527 r
.361 .79254 m .35865 .79494 L .35919 .79284 L F
0 0 0 r
.56539 .83312 m .56424 .83683 L .56598 .83418 L F
0 0 .424 r
.56537 .83175 m .56539 .83312 L .56598 .83418 L F
.051 .161 .66 r
.6818 .73719 m .68356 .74014 L .68209 .74026 L F
.063 .317 .8 r
.68356 .74014 m .68477 .7424 L .68209 .74026 L F
.464 .376 .671 r
.68477 .7424 m .6824 .74303 L .68209 .74026 L F
.172 .294 .748 r
.38609 .75602 m .3872 .75896 L .38814 .7579 L F
.547 .35 .566 r
.38579 .76054 m .38814 .7579 L .3872 .75896 L F
.711 .739 .873 r
.64015 .73763 m .64373 .73715 L .64247 .73484 L F
.55 .794 .989 r
.50742 .87456 m .50411 .87388 L .50597 .87376 L F
0 .441 .802 r
.50957 .87527 m .50742 .87456 L .50597 .87376 L F
.297 .512 .895 r
.33006 .66138 m .33102 .6617 L .33066 .66226 L F
.637 .943 .957 r
.33066 .66226 m .33102 .6617 L .33001 .6622 L F
.847 .434 .255 r
.47489 .85052 m .47392 .85196 L .47322 .85018 L F
.445 0 .019 r
.47618 .8518 m .47489 .85052 L .47707 .85008 L F
.47618 .8518 m .47392 .85196 L .47489 .85052 L F
.647 .829 .97 r
.41556 .89178 m .41889 .89193 L .41766 .89112 L F
.552 .793 .988 r
.41889 .89193 m .41977 .89075 L .41766 .89112 L F
.41889 .89193 m .42088 .89155 L .41977 .89075 L F
.907 .978 .79 r
.50075 .81961 m .49852 .82261 L .50134 .81957 L F
.766 .58 .647 r
.4981 .82355 m .50134 .81957 L .49852 .82261 L F
.4981 .82355 m .50133 .82412 L .50134 .81957 L F
.334 .411 .792 r
.50134 .81957 m .50228 .81827 L .50075 .81961 L F
.50134 .81957 m .50349 .82143 L .50228 .81827 L F
.759 .575 .647 r
.50134 .81957 m .5046 .82411 L .50349 .82143 L F
.50134 .81957 m .50133 .82412 L .5046 .82411 L F
.537 .494 .755 r
.4374 .8444 m .43642 .84794 L .43535 .84477 L F
.4374 .8444 m .43858 .84797 L .43642 .84794 L F
.824 .923 .901 r
.62658 .73309 m .62311 .73467 L .62558 .73239 L F
.833 .905 .889 r
.62884 .73095 m .62658 .73309 L .62558 .73239 L F
.842 .998 .824 r
.62335 .75012 m .62134 .7523 L .62283 .75173 L F
.569 .533 .775 r
.39832 .75104 m .39693 .75256 L .39578 .75095 L F
.39832 .75104 m .39884 .75275 L .39693 .75256 L F
.36 .641 .962 r
.39982 .75371 m .39693 .75256 L .39884 .75275 L F
.547 .798 .991 r
.43507 .81624 m .43162 .81561 L .43367 .81578 L F
.43162 .81561 m .43507 .81624 L .43367 .81578 L F
.912 .732 .645 r
.43376 .81336 m .43367 .81578 L .43507 .81624 L F
.51 .222 .412 r
.37321 .78221 m .3724 .78462 L .37036 .78491 L F
.55 .281 .46 r
.37515 .78196 m .3724 .78462 L .37321 .78221 L F
.279 .782 .82 r
.38572 .90073 m .38819 .90044 L .39012 .89995 L F
.625 .422 .587 r
.383 .83984 m .38528 .84168 L .3852 .83956 L F
.383 .83984 m .38288 .84204 L .38528 .84168 L F
.514 .858 .994 r
.44236 .88712 m .4444 .88662 L .44121 .88665 L F
.53 .851 .998 r
.4444 .88662 m .44771 .88665 L .44646 .88622 L F
.22 .706 .928 r
.44771 .88665 m .44973 .88668 L .44646 .88622 L F
0 0 .49 r
.55603 .80829 m .55591 .80795 L .55424 .80582 L F
.635 .1 0 r
.55603 .80829 m .55819 .81046 L .55718 .80983 L F
.55603 .80829 m .55718 .80983 L .55591 .80795 L F
.595 .067 0 r
.55906 .81107 m .55819 .81046 L .55603 .80829 L F
.535 .327 .544 r
.6536 .76104 m .65574 .75849 L .65405 .75919 L F
.544 .326 .534 r
.4077 .75327 m .40739 .7558 L .40532 .75607 L F
.545 .423 .664 r
.40939 .75078 m .4077 .75327 L .40668 .75232 L F
.40939 .75078 m .40968 .75302 L .4077 .75327 L F
.539 .322 .533 r
.40944 .75539 m .4077 .75327 L .40968 .75302 L F
.40944 .75539 m .40739 .7558 L .4077 .75327 L F
.635 .646 .844 r
.38467 .73738 m .38254 .73801 L .38097 .7358 L F
.841 .871 .865 r
.58824 .83453 m .59047 .83373 L .5883 .83556 L F
.612 .788 .965 r
.49127 .88782 m .49286 .88821 L .49253 .88653 L F
.659 .82 .961 r
.49253 .88653 m .49286 .88821 L .49601 .88676 L F
.447 0 0 r
.43401 .82694 m .43575 .82799 L .43726 .8269 L F
.267 0 0 r
.43726 .8269 m .43771 .82769 L .43884 .82777 L F
.43726 .8269 m .43575 .82799 L .43771 .82769 L F
.424 .203 .472 r
.61583 .80022 m .61814 .79738 L .61824 .80001 L F
.397 .211 .509 r
.61546 .80306 m .61583 .80022 L .61824 .80001 L F
.74 .635 .744 r
.56252 .78778 m .56389 .78704 L .56376 .78672 L F
.56252 .78778 m .5624 .78811 L .56389 .78704 L F
.826 .634 .644 r
.46394 .84506 m .46184 .84493 L .46188 .84218 L F
.782 .475 .468 r
.46394 .84506 m .46187 .84697 L .46184 .84493 L F
.46394 .84506 m .46531 .84744 L .46187 .84697 L F
.604 .224 .295 r
.46806 .82344 m .47049 .82357 L .47143 .82178 L F
.415 0 .075 r
.47049 .82357 m .47321 .82287 L .47143 .82178 L F
.799 .721 .778 r
.59592 .76946 m .594 .77173 L .59279 .76888 L F
.482 .264 .505 r
.59595 .77147 m .594 .77173 L .59592 .76946 L F
.476 .259 .504 r
.59792 .77092 m .59592 .76946 L .59821 .76941 L F
.59792 .77092 m .59595 .77147 L .59592 .76946 L F
.004 0 0 r
.54015 .84201 m .54366 .83871 L .5423 .84213 L F
.747 .545 .621 r
.54555 .83932 m .5423 .84213 L .54366 .83871 L F
.208 0 .078 r
.54366 .83871 m .54574 .83749 L .54555 .83932 L F
.36 .609 .944 r
.58918 .82902 m .58848 .82953 L .58747 .82885 L F
.791 .634 .687 r
.58848 .82953 m .58831 .83197 L .58747 .82885 L F
.34 .733 .984 r
.47861 .88356 m .47973 .88425 L .48056 .88354 L F
.212 .526 .919 r
.47973 .88425 m .48155 .88492 L .48056 .88354 L F
.523 0 0 r
.47973 .88425 m .48317 .88567 L .48155 .88492 L F
.752 .711 .814 r
.63745 .73699 m .64015 .73763 L .63932 .73454 L F
.63745 .73699 m .63833 .738 L .64015 .73763 L F
.749 .707 .812 r
.63932 .73454 m .64015 .73763 L .64247 .73484 L F
.599 .389 .568 r
.38781 .83692 m .38998 .83677 L .3901 .83446 L F
.627 .42 .582 r
.38998 .83677 m .39232 .83439 L .3901 .83446 L F
.608 .879 .991 r
.4359 .88717 m .43719 .88772 L .43909 .88705 L F
.176 .667 .921 r
.51415 .82113 m .51295 .82064 L .51087 .82048 L F
.259 .746 .922 r
.51295 .82064 m .51137 .82056 L .51087 .82048 L F
.738 .619 .726 r
.50858 .81981 m .50993 .82195 L .51239 .82111 L F
.259 .746 .922 r
.51137 .82056 m .5096 .82048 L .51087 .82048 L F
.738 .619 .726 r
.50858 .81981 m .51022 .82037 L .51087 .82048 L F
.51022 .82037 m .51239 .82111 L .51087 .82048 L F
.732 .599 .708 r
.50993 .82195 m .50986 .82419 L .51239 .82111 L F
.176 .667 .921 r
.51415 .82113 m .51087 .82048 L .51239 .82111 L F
.593 .483 .698 r
.35627 .77975 m .35836 .77945 L .35802 .77703 L F
.476 .228 .458 r
.35599 .78196 m .35836 .77945 L .35627 .77975 L F
.817 .666 .695 r
.64652 .7297 m .6476 .7302 L .64678 .72743 L F
.76 .58 .654 r
.64461 .73222 m .6476 .7302 L .64652 .7297 L F
.64461 .73222 m .64779 .73262 L .6476 .7302 L F
.672 .514 .663 r
.6476 .7302 m .64779 .73262 L .6501 .73002 L F
.939 .932 .766 r
.58406 .82927 m .58349 .83217 L .58325 .83145 L F
0 0 .152 r
.58349 .83217 m .58364 .83452 L .58325 .83145 L F
.58349 .83217 m .5834 .83407 L .58364 .83452 L F
.6 .338 .491 r
.59358 .76089 m .59602 .75889 L .59377 .75908 L F
.92 .564 .342 r
.55906 .81107 m .55822 .81257 L .55819 .81046 L F
.55906 .81107 m .55977 .81339 L .55822 .81257 L F
.601 .375 .545 r
.3742 .76624 m .3767 .76378 L .37458 .76425 L F
.522 .286 .498 r
.42421 .86844 m .42156 .87081 L .42193 .86864 L F
.805 .704 .754 r
.50349 .82143 m .50654 .82118 L .50542 .82027 L F
.50349 .82143 m .5046 .82411 L .50654 .82118 L F
.612 .441 .627 r
.5046 .82411 m .50653 .82453 L .50654 .82118 L F
.764 .86 .921 r
.50542 .82027 m .50654 .82118 L .50858 .81981 L F
.674 .599 .763 r
.50654 .82118 m .50993 .82195 L .50858 .81981 L F
.75 .554 .631 r
.50654 .82118 m .50986 .82419 L .50993 .82195 L F
.50654 .82118 m .50653 .82453 L .50986 .82419 L F
.695 .497 .615 r
.42173 .85754 m .42236 .861 L .41942 .86025 L F
.598 .432 .628 r
.42478 .86058 m .42173 .85754 L .42418 .85799 L F
.42478 .86058 m .42236 .861 L .42173 .85754 L F
.551 .434 .673 r
.39669 .74264 m .39729 .74626 L .39501 .74655 L F
.575 .47 .698 r
.39729 .74626 m .39543 .74835 L .39501 .74655 L F
.474 .863 .975 r
.67157 .74822 m .67141 .74769 L .67049 .74849 L F
.796 .362 0 r
.67141 .74769 m .67147 .74854 L .67124 .74712 L F
.67141 .74769 m .67124 .74712 L .67115 .74656 L F
.474 .863 .975 r
.6728 .74792 m .67141 .74769 L .67157 .74822 L F
.599 .861 .993 r
.67674 .73169 m .67767 .73245 L .6746 .73236 L F
.913 .512 .145 r
.67674 .73169 m .67798 .73383 L .67767 .73245 L F
.437 .477 .803 r
.53388 .84907 m .53464 .85115 L .53685 .85088 L F
.83 .851 .862 r
.3835 .73012 m .37998 .73146 L .38233 .72955 L F
.607 .064 0 r
.38233 .72955 m .38633 .73028 L .3835 .73012 L F
.687 .571 .719 r
.38633 .73028 m .38485 .73081 L .3835 .73012 L F
.679 .487 .618 r
.38622 .73237 m .3835 .73012 L .38485 .73081 L F
.38622 .73237 m .38353 .73287 L .3835 .73012 L F
.445 .112 .306 r
.53068 .8684 m .5278 .87095 L .52994 .87096 L F
.633 .43 .591 r
.37633 .8476 m .37867 .84503 L .3757 .84478 L F
.37633 .8476 m .37857 .84735 L .37867 .84503 L F
.616 .479 .672 r
.37867 .84503 m .38077 .84479 L .38064 .84237 L F
.626 .439 .61 r
.37857 .84735 m .38077 .84479 L .37867 .84503 L F
.047 0 .41 r
.48061 .87595 m .48195 .87332 L .48289 .87559 L F
.667 .245 .234 r
.37906 .74873 m .37809 .75009 L .37588 .74919 L F
.756 .611 .697 r
.38144 .75019 m .37809 .75009 L .37906 .74873 L F
.38125 .75032 m .37809 .75009 L .38144 .75019 L F
.38171 .75036 m .38108 .75103 L .37809 .75009 L F
.971 .853 .667 r
.37901 .75013 m .38057 .75081 L .38075 .74869 L F
.38057 .75081 m .38108 .75103 L .381 .7505 L F
.38057 .75081 m .381 .7505 L .38075 .74869 L F
.756 .611 .697 r
.38171 .75036 m .38125 .75032 L .38144 .75019 L F
.769 .945 .936 r
.5043 .88283 m .50701 .88229 L .50854 .88103 L F
.524 .341 .575 r
.50245 .82901 m .50237 .83142 L .5004 .82936 L F
.135 0 0 r
.47455 .87197 m .47084 .87301 L .47316 .8721 L F
.859 .743 .735 r
.59279 .76888 m .594 .77173 L .59202 .77109 L F
.878 .99 .807 r
.594 .77173 m .59137 .77375 L .59202 .77109 L F
.594 .77173 m .59167 .77443 L .59137 .77375 L F
.607 .414 .595 r
.594 .77173 m .59423 .77452 L .59167 .77443 L F
.386 .252 .573 r
.59558 .77337 m .594 .77173 L .59595 .77147 L F
.59558 .77337 m .59423 .77452 L .594 .77173 L F
.636 .734 .919 r
.40096 .75227 m .39982 .75371 L .39884 .75275 L F
.40096 .75227 m .40197 .75348 L .39982 .75371 L F
.445 .245 .513 r
.61814 .79738 m .62007 .79482 L .6205 .7976 L F
.416 .176 .439 r
.61824 .80001 m .61814 .79738 L .6205 .7976 L F
.634 .323 .426 r
.44267 .8426 m .43949 .84424 L .44068 .84232 L F
.963 .839 .672 r
.56857 .80807 m .56968 .80614 L .56941 .80604 L F
.603 .562 .782 r
.56114 .78489 m .56252 .78778 L .56376 .78672 L F
0 .054 .62 r
.56114 .78489 m .56213 .78695 L .56242 .78661 L F
.56213 .78695 m .56252 .78778 L .56242 .78661 L F
.383 .845 .877 r
.56242 .78661 m .56167 .78642 L .56291 .78604 L F
.603 .562 .782 r
.56114 .78489 m .56376 .78672 L .56356 .78529 L F
.865 .8 .785 r
.56356 .78529 m .56376 .78672 L .56528 .78544 L F
.314 .347 .736 r
.56498 .78449 m .56376 .78672 L .56242 .78661 L F
.383 .845 .877 r
.56242 .78661 m .56402 .78571 L .56498 .78449 L F
.56242 .78661 m .56291 .78604 L .56402 .78571 L F
.952 .887 .731 r
.56189 .7898 m .56242 .78661 L .56252 .78778 L F
.119 0 .256 r
.56376 .78672 m .56189 .7898 L .56252 .78778 L F
.754 .927 .946 r
.56376 .78672 m .56252 .78778 L .56242 .78661 L F
.194 .497 .905 r
.54059 .84796 m .53985 .84847 L .5395 .8472 L F
.54059 .84796 m .54309 .85048 L .53985 .84847 L F
.636 .59 .786 r
.52355 .83184 m .52408 .82863 L .52177 .82916 L F
.52355 .83184 m .52523 .83224 L .52408 .82863 L F
.378 .202 .512 r
.52355 .83184 m .52269 .83485 L .52418 .83363 L F
.683 .364 .429 r
.52355 .83184 m .52418 .83363 L .52523 .83224 L F
.672 .619 .788 r
.53261 .84001 m .53589 .84241 L .5347 .83931 L F
.581 .523 .755 r
.53589 .84241 m .53739 .83917 L .5347 .83931 L F
.53589 .84241 m .53798 .8421 L .53739 .83917 L F
.771 .636 .712 r
.53388 .82873 m .5336 .83196 L .53036 .8317 L F
.71 .316 .301 r
.5336 .83196 m .53244 .83366 L .53036 .8317 L F
.551 .442 .683 r
.53532 .83189 m .5336 .83196 L .53388 .82873 L F
.297 0 .054 r
.53437 .83307 m .5336 .83196 L .53532 .83189 L F
.53437 .83307 m .53244 .83366 L .5336 .83196 L F
.09 .531 .907 r
.46944 .87223 m .46826 .87214 L .46733 .87112 L F
.46944 .87223 m .47084 .87301 L .46826 .87214 L F
.664 .517 .675 r
.37364 .84764 m .37633 .8476 L .3757 .84478 L F
.785 .474 .462 r
.40705 .82898 m .40717 .82726 L .40396 .82646 L F
.588 .302 .45 r
.40922 .82873 m .40717 .82726 L .40705 .82898 L F
.643 .463 .625 r
.37144 .85017 m .37428 .85002 L .37364 .84764 L F
.7 .532 .656 r
.37428 .85002 m .37633 .8476 L .37364 .84764 L F
.348 0 .209 r
.58141 .76593 m .58323 .76626 L .58412 .76422 L F
.478 .145 .324 r
.58323 .76626 m .58616 .76368 L .58412 .76422 L F
.677 .189 0 r
.54682 .80024 m .54652 .8002 L .5448 .79791 L F
.635 .123 0 r
.54682 .80024 m .5487 .80234 L .54652 .8002 L F
.35 .195 .525 r
.59686 .8155 m .59568 .81629 L .59557 .81863 L F
.72 .582 .7 r
.41734 .86283 m .41534 .86332 L .41741 .86064 L F
.646 .547 .729 r
.41942 .86025 m .41734 .86283 L .41741 .86064 L F
0 0 0 r
.63555 .76619 m .63865 .76535 L .63619 .76603 L F
.801 .405 .303 r
.57634 .84212 m .57318 .83999 L .5755 .84141 L F
.652 .164 .08 r
.5755 .84141 m .57318 .83999 L .57171 .84089 L F
.525 .28 .486 r
.38885 .77352 m .3871 .77181 L .38906 .77145 L F
.38885 .77352 m .38678 .774 L .3871 .77181 L F
.911 .74 .658 r
.67037 .73536 m .66895 .73518 L .66942 .73218 L F
.869 .507 .362 r
.67037 .73536 m .66945 .73688 L .66895 .73518 L F
.803 .873 .437 r
.67037 .73536 m .66951 .73725 L .66945 .73688 L F
0 .04 .604 r
.66945 .73688 m .67085 .73807 L .66938 .73649 L F
.786 .455 0 r
.66895 .73518 m .66945 .73688 L .66904 .73612 L F
0 .04 .604 r
.66945 .73688 m .66938 .73649 L .66904 .73612 L F
.803 .873 .437 r
.66951 .73725 m .66918 .73799 L .66945 .73688 L F
.758 .666 .76 r
.67241 .73281 m .67037 .73536 L .66942 .73218 L F
.551 .442 .683 r
.53532 .83189 m .53388 .82873 L .5347 .82881 L F
.436 .861 .729 r
.65059 .75623 m .65217 .75521 L .65219 .75532 L F
.292 .356 .758 r
.65236 .75805 m .65059 .75623 L .64931 .76 L F
.65236 .75805 m .65217 .75521 L .65059 .75623 L F
0 0 0 r
.38791 .7298 m .38485 .73081 L .38633 .73028 L F
.058 0 .246 r
.38791 .7298 m .38622 .73237 L .38485 .73081 L F
0 0 0 r
.52651 .80782 m .52585 .80896 L .52691 .80762 L F
.686 .971 .769 r
.52585 .80896 m .5251 .80919 L .52691 .80762 L F
0 0 0 r
.52691 .80762 m .5253 .80905 L .52732 .80741 L F
.479 .081 .207 r
.5277 .80578 m .52691 .80762 L .52881 .8065 L F
.419 .835 .657 r
.52691 .80762 m .5279 .80694 L .52881 .8065 L F
0 0 0 r
.52691 .80762 m .52732 .80741 L .5279 .80694 L F
.5277 .80578 m .52651 .80782 L .52691 .80762 L F
.479 .081 .207 r
.5277 .80578 m .52881 .8065 L .53009 .80625 L F
.647 .174 .117 r
.42171 .73742 m .42532 .73768 L .42326 .73801 L F
.778 .374 .286 r
.42493 .73916 m .42171 .73742 L .42326 .73801 L F
.522 .241 .429 r
.42532 .73768 m .42493 .73916 L .42326 .73801 L F
.493 .117 .254 r
.36024 .74857 m .35919 .75065 L .35686 .75069 L F
.185 0 .097 r
.36083 .74981 m .36024 .74857 L .36218 .74839 L F
.36083 .74981 m .35919 .75065 L .36024 .74857 L F
.653 .341 .431 r
.50696 .83404 m .5057 .83666 L .50363 .83636 L F
.657 .345 .432 r
.50919 .83624 m .50696 .83404 L .50888 .83453 L F
.50919 .83624 m .5057 .83666 L .50696 .83404 L F
.61 .446 .635 r
.50898 .8319 m .50888 .83453 L .50696 .83404 L F
0 0 .382 r
.56031 .81621 m .56118 .81769 L .55969 .81528 L F
.56031 .81621 m .56144 .81858 L .56118 .81769 L F
.666 .363 .45 r
.5192 .83136 m .51664 .83138 L .51661 .82961 L F
.181 0 .018 r
.67275 .75011 m .67057 .75215 L .67329 .75071 L F
.518 .52 .797 r
.46735 .86781 m .46542 .86932 L .46425 .86641 L F
.428 .361 .68 r
.46735 .86781 m .46733 .87112 L .46542 .86932 L F
.676 .83 .958 r
.58957 .79004 m .58645 .78996 L .58887 .78982 L F
.58645 .78996 m .58957 .79004 L .58887 .78982 L F
.506 .355 .61 r
.42156 .87081 m .42165 .87312 L .41971 .87117 L F
.591 .357 .53 r
.42165 .87312 m .41959 .87369 L .41971 .87117 L F
.975 .741 .519 r
.48369 .85928 m .48468 .86064 L .48485 .85758 L F
.521 .278 .487 r
.36601 .78742 m .36558 .79021 L .36377 .79017 L F
.503 .262 .482 r
.36756 .78958 m .36601 .78742 L .36789 .78707 L F
.36756 .78958 m .36558 .79021 L .36601 .78742 L F
.724 .829 .93 r
.43892 .87367 m .43718 .87472 L .43559 .87375 L F
.64 .863 .491 r
.59885 .81282 m .59803 .81399 L .59686 .8155 L F
.593 .242 .344 r
.46078 .82438 m .46266 .82579 L .46378 .82353 L F
.543 .2 .337 r
.46266 .82579 m .46592 .82346 L .46378 .82353 L F
.752 .617 .71 r
.41734 .86283 m .41504 .86522 L .41534 .86332 L F
.231 0 0 r
.53009 .80625 m .53219 .80604 L .5334 .8054 L F
.674 .278 .288 r
.53219 .80604 m .53491 .80587 L .5334 .8054 L F
.458 .158 .367 r
.55493 .79068 m .55729 .79091 L .55662 .78968 L F
.55493 .79068 m .55423 .79167 L .55729 .79091 L F
.338 0 .059 r
.58141 .76593 m .58043 .76758 L .58323 .76626 L F
.235 .368 .794 r
.57536 .81851 m .57478 .81921 L .57363 .81709 L F
0 0 0 r
.57406 .82107 m .57478 .81921 L .57536 .81851 L F
.691 .632 .785 r
.47692 .83673 m .47492 .83915 L .47482 .83716 L F
.277 0 0 r
.44973 .88668 m .45296 .8867 L .45191 .88692 L F
0 0 0 r
.45407 .88646 m .45296 .8867 L .45465 .88616 L F
.151 .687 .692 r
.45191 .88692 m .45296 .8867 L .45407 .88646 L F
.707 .648 .789 r
.63293 .74034 m .63628 .74084 L .63518 .73779 L F
.777 .684 .761 r
.63518 .73779 m .63628 .74084 L .63833 .738 L F
0 0 .01 r
.55041 .8389 m .54987 .84183 L .55102 .8414 L F
.709 .369 .4 r
.50133 .82412 m .50357 .8263 L .5046 .82411 L F
.583 .232 .338 r
.5046 .82411 m .50357 .8263 L .50651 .82563 L F
.604 .218 .285 r
.50651 .82563 m .50653 .82453 L .5046 .82411 L F
.322 .198 .551 r
.57328 .82466 m .5723 .82185 L .57406 .82107 L F
.809 .737 .784 r
.64026 .72469 m .64132 .72745 L .63831 .72742 L F
.76 .714 .809 r
.64355 .72506 m .64132 .72745 L .64026 .72469 L F
.549 .798 .991 r
.66529 .76255 m .66609 .76111 L .66444 .76202 L F
.66529 .76255 m .66778 .76224 L .66609 .76111 L F
0 0 0 r
.51281 .87362 m .50957 .87527 L .5114 .87417 L F
.81 .324 0 r
.51372 .87591 m .51281 .87362 L .5114 .87417 L F
.67 .156 .008 r
.51372 .87591 m .5114 .87417 L .51043 .87489 L F
.273 .751 .933 r
.51278 .87558 m .51372 .87591 L .51252 .87556 L F
.81 .324 0 r
.51372 .87591 m .51477 .87628 L .51281 .87362 L F
.746 .529 .6 r
.51601 .87608 m .51281 .87362 L .51485 .87638 L F
.273 .751 .933 r
.51613 .87573 m .51372 .87591 L .51278 .87558 L F
.81 .324 0 r
.51372 .87591 m .51485 .87638 L .51477 .87628 L F
.69 .345 0 r
.56315 .82363 m .56386 .82528 L .5643 .8264 L F
.594 .28 .406 r
.4465 .84111 m .44472 .84417 L .44267 .8426 L F
.61 .305 .426 r
.4482 .84182 m .44472 .84417 L .4465 .84111 L F
.738 .904 .952 r
.42841 .88936 m .43114 .88893 L .43028 .8885 L F
.625 .922 .975 r
.43028 .8885 m .43114 .88893 L .4338 .88779 L F
.982 .705 .416 r
.68181 .71399 m .68091 .7158 L .68071 .71318 L F
.819 .9 .898 r
.68401 .71177 m .68181 .71399 L .68071 .71318 L F
0 0 0 r
.68308 .71402 m .68181 .71399 L .68411 .7151 L F
.68308 .71402 m .68091 .7158 L .68181 .71399 L F
.606 .532 .745 r
.39747 .74798 m .39578 .75095 L .39543 .74835 L F
.39747 .74798 m .39832 .75104 L .39578 .75095 L F
.519 .302 .525 r
.6824 .74303 m .68278 .74559 L .68066 .74607 L F
.435 .245 .523 r
.68468 .74474 m .6824 .74303 L .68477 .7424 L F
.68468 .74474 m .68278 .74559 L .6824 .74303 L F
.592 .247 .354 r
.40922 .82873 m .41141 .82866 L .41263 .82662 L F
.605 .262 .362 r
.41263 .82662 m .41453 .82827 L .41471 .8263 L F
.41263 .82662 m .41141 .82866 L .41453 .82827 L F
.733 .706 .826 r
.67138 .73082 m .67241 .73281 L .66942 .73218 L F
.608 .634 .851 r
.67313 .73051 m .67241 .73281 L .67138 .73082 L F
.67313 .73051 m .6746 .73236 L .67241 .73281 L F
.664 .957 .943 r
.55286 .79362 m .55091 .79377 L .55344 .79253 L F
0 0 0 r
.55344 .79253 m .55214 .79347 L .5527 .79321 L F
.664 .957 .943 r
.55286 .79362 m .55344 .79253 L .55396 .79205 L F
0 0 0 r
.55344 .79253 m .5527 .79321 L .55424 .7925 L F
.664 .957 .943 r
.55396 .79205 m .55344 .79253 L .55423 .79167 L F
.242 .732 .921 r
.48038 .85034 m .47917 .84999 L .47707 .85008 L F
.335 .262 .624 r
.48156 .84738 m .48038 .85034 L .47934 .84737 L F
.48156 .84738 m .48172 .85068 L .48038 .85034 L F
.023 .256 .758 r
.48038 .85034 m .48138 .84985 L .47917 .84999 L F
.48038 .85034 m .48238 .85222 L .48138 .84985 L F
.444 .231 .493 r
.62007 .79482 m .62244 .79211 L .62248 .79483 L F
.372 .18 .487 r
.62212 .79684 m .62007 .79482 L .62248 .79483 L F
.62212 .79684 m .6205 .7976 L .62007 .79482 L F
.837 .694 .705 r
.57398 .83124 m .57457 .83227 L .57549 .82919 L F
.57398 .83124 m .57549 .82919 L .57567 .82897 L F
.618 .131 0 r
.58364 .83452 m .5834 .83407 L .58504 .8361 L F
.696 .713 .861 r
.36086 .72899 m .35886 .73 L .35773 .72848 L F
.343 .307 .674 r
.45735 .86591 m .4575 .86861 L .45831 .86764 L F
0 0 0 r
.6737 .72482 m .67149 .72805 L .67286 .72652 L F
.638 .914 .98 r
.67286 .72652 m .67149 .72805 L .67351 .7271 L F
.467 .837 .593 r
.61225 .74531 m .61338 .74436 L .6146 .74298 L F
0 0 0 r
.6146 .74298 m .61587 .74205 L .61708 .7406 L F
.6146 .74298 m .61338 .74436 L .61587 .74205 L F
.465 0 .064 r
.50651 .82563 m .50986 .82419 L .50653 .82453 L F
.50651 .82563 m .50875 .82558 L .50986 .82419 L F
.209 .693 .93 r
.50875 .82558 m .51199 .82617 L .50986 .82419 L F
.591 .621 .85 r
.51084 .8416 m .50798 .8399 L .51011 .83945 L F
.64 .398 .536 r
.51084 .8416 m .5102 .84496 L .50813 .84456 L F
.658 .643 .823 r
.51256 .84066 m .51084 .8416 L .51011 .83945 L F
.491 .262 .493 r
.51285 .84378 m .51084 .8416 L .51256 .84066 L F
.51285 .84378 m .5102 .84496 L .51084 .8416 L F
.467 .837 .593 r
.61225 .74531 m .61196 .74549 L .61338 .74436 L F
.607 .064 0 r
.38233 .72955 m .38418 .73072 L .38633 .73028 L F
.38418 .73072 m .38419 .73073 L .3842 .73073 L F
.38418 .73072 m .3842 .73073 L .38633 .73028 L F
.38419 .73073 m .38495 .73091 L .38633 .73028 L F
0 .075 .621 r
.3828 .72836 m .38452 .73065 L .3849 .73043 L F
.996 .865 .563 r
.38633 .73028 m .38493 .73001 L .38485 .72828 L F
.38493 .73001 m .38489 .73 L .38487 .72925 L F
.38493 .73001 m .38487 .72925 L .38485 .72828 L F
.38633 .73028 m .38476 .72816 L .38791 .7298 L F
0 .075 .621 r
.38481 .72848 m .38608 .72976 L .38511 .7285 L F
.3828 .72836 m .38487 .72925 L .38481 .72848 L F
.38487 .72925 m .38608 .72976 L .38481 .72848 L F
.38487 .72925 m .3849 .73043 L .38595 .72984 L F
.996 .865 .563 r
.38633 .73028 m .38496 .73091 L .38491 .73021 L F
.38507 .73003 m .38491 .73021 L .38489 .73 L F
.38633 .73028 m .38491 .73021 L .38507 .73003 L F
.534 .82 .476 r
.38556 .72948 m .38472 .73041 L .38458 .73057 L F
0 .075 .621 r
.3828 .72836 m .3849 .73043 L .38487 .72925 L F
.664 .598 .771 r
.38476 .72816 m .3828 .72836 L .38481 .72848 L F
.996 .865 .563 r
.38485 .72828 m .38486 .72881 L .38476 .72816 L F
.664 .598 .771 r
.38476 .72816 m .38481 .72848 L .38511 .7285 L F
.996 .865 .563 r
.38486 .72881 m .38489 .73 L .38476 .72816 L F
.664 .598 .771 r
.38476 .72816 m .3847 .73045 L .3828 .72836 L F
.534 .82 .476 r
.38486 .73026 m .3847 .73045 L .38452 .73065 L F
.3847 .73045 m .38456 .7306 L .38452 .73065 L F
.607 .064 0 r
.38419 .73073 m .38468 .73104 L .38495 .73091 L F
.664 .598 .771 r
.3847 .73045 m .38468 .73104 L .38445 .73072 L F
.3847 .73045 m .38456 .7306 L .3828 .72836 L F
0 .075 .621 r
.3828 .72836 m .38472 .73041 L .38456 .7306 L F
.3828 .72836 m .38456 .7306 L .38452 .73065 L F
.664 .598 .771 r
.38456 .7306 m .38445 .73072 L .3828 .72836 L F
.534 .82 .476 r
.3847 .73045 m .38458 .73057 L .38456 .7306 L F
.38556 .72948 m .38458 .73057 L .38486 .73026 L F
.714 .71 .845 r
.3849 .73043 m .3859 .73115 L .38608 .72976 L F
.058 0 .246 r
.38791 .7298 m .38744 .7317 L .38622 .73237 L F
.714 .71 .845 r
.3859 .73115 m .38744 .7317 L .38729 .73148 L F
.698 .718 .864 r
.3859 .73115 m .38744 .7317 L .38725 .73148 L F
.714 .71 .845 r
.3859 .73115 m .38729 .73148 L .38608 .72976 L F
.698 .718 .864 r
.3859 .73115 m .38725 .73148 L .38556 .72948 L F
.36 .807 .664 r
.38744 .7317 m .3857 .73262 L .38622 .73237 L F
0 0 .373 r
.38658 .73282 m .3857 .73262 L .38661 .73214 L F
.38702 .73226 m .38661 .73214 L .38744 .7317 L F
.38658 .73282 m .38661 .73214 L .38702 .73226 L F
.954 .661 .444 r
.3862 .73024 m .38727 .73193 L .38744 .7317 L F
0 .075 .621 r
.38584 .72966 m .38595 .72984 L .38608 .72976 L F
.842 .739 .75 r
.38556 .72948 m .38744 .7317 L .38608 .72976 L F
0 .079 .64 r
.38659 .72999 m .3878 .73247 L .38556 .72948 L F
.3878 .73247 m .38801 .73291 L .38767 .73243 L F
.954 .661 .444 r
.38556 .72948 m .38727 .73193 L .3862 .73024 L F
0 .079 .64 r
.3878 .73247 m .38767 .73243 L .38556 .72948 L F
.954 .661 .444 r
.38556 .72948 m .38658 .73282 L .38727 .73193 L F
0 .075 .621 r
.38487 .72925 m .38595 .72984 L .38584 .72966 L F
.996 .865 .563 r
.38496 .73091 m .38495 .73091 L .38495 .73085 L F
.38496 .73091 m .38495 .73085 L .38476 .72816 L F
.698 .718 .864 r
.38486 .73026 m .3859 .73115 L .38556 .72948 L F
.714 .71 .845 r
.38452 .73065 m .38494 .7308 L .3849 .73043 L F
.698 .718 .864 r
.38452 .73065 m .38494 .7308 L .38486 .73026 L F
.714 .71 .845 r
.38494 .7308 m .3859 .73115 L .3849 .73043 L F
.698 .718 .864 r
.38494 .7308 m .3859 .73115 L .38486 .73026 L F
.996 .865 .563 r
.38495 .73091 m .38468 .73104 L .38474 .72887 L F
.38495 .73091 m .38474 .72887 L .38476 .72816 L F
.151 .003 .412 r
.60574 .8335 m .6044 .83194 L .60546 .83098 L F
.60574 .8335 m .60411 .83417 L .6044 .83194 L F
.975 .767 .56 r
.38171 .75036 m .38154 .75272 L .38274 .75114 L F
.664 .716 .887 r
.38274 .75114 m .38355 .74811 L .38171 .75036 L F
.38274 .75114 m .38563 .75109 L .38355 .74811 L F
.975 .767 .56 r
.38171 .75036 m .38154 .75272 L .38274 .75114 L F
.768 .714 .801 r
.63745 .73699 m .63518 .73779 L .63833 .738 L F
.801 .991 .88 r
.59245 .82697 m .58918 .82902 L .59169 .8288 L F
.951 .941 .737 r
.59326 .82358 m .59245 .82697 L .59386 .82618 L F
0 0 .015 r
.59386 .82618 m .59245 .82697 L .59169 .8288 L F
.651 .415 .548 r
.39968 .83383 m .39674 .83159 L .39673 .83424 L F
.39968 .83383 m .39977 .83173 L .39674 .83159 L F
.522 .277 .485 r
.60337 .75353 m .60555 .7532 L .60595 .75121 L F
.484 .243 .473 r
.60595 .75121 m .60758 .75275 L .6078 .75054 L F
.60595 .75121 m .60555 .7532 L .60758 .75275 L F
.691 .632 .785 r
.47692 .83673 m .47806 .83974 L .47492 .83915 L F
.717 .56 .676 r
.47806 .83974 m .47649 .84282 L .47492 .83915 L F
.607 .381 .548 r
.59886 .75793 m .60091 .75583 L .59871 .75597 L F
.072 .618 .84 r
.50104 .81353 m .50417 .81397 L .50226 .81384 L F
.595 .648 .872 r
.54125 .83228 m .54229 .83471 L .54434 .83423 L F
.51 .253 .462 r
.40319 .75889 m .40283 .76087 L .40083 .76106 L F
.512 .256 .462 r
.40319 .75889 m .40506 .76056 L .40283 .76087 L F
.592 .424 .622 r
.40532 .75607 m .40553 .75883 L .40319 .75889 L F
.552 .248 .406 r
.40553 .75883 m .40506 .76056 L .40319 .75889 L F
.601 .118 .08 r
.6536 .76104 m .64931 .76 L .65236 .75805 L F
.491 0 0 r
.64931 .76 m .65122 .75901 L .65236 .75805 L F
.64931 .76 m .64942 .76025 L .65122 .75901 L F
.64931 .76 m .65057 .76105 L .64942 .76025 L F
.008 0 0 r
.63101 .78423 m .63199 .78282 L .6335 .78182 L F
.147 0 0 r
.42877 .82676 m .43084 .82663 L .43183 .82632 L F
.267 .742 .938 r
.43084 .82663 m .43401 .82694 L .43183 .82632 L F
.707 .88 .961 r
.5781 .84111 m .57634 .84212 L .5755 .84141 L F
.525 .263 .461 r
.47656 .82092 m .47858 .8207 L .4789 .81889 L F
.526 .265 .462 r
.47858 .8207 m .48069 .82039 L .4789 .81889 L F
.557 .256 .414 r
.4789 .81889 m .48069 .82039 L .48121 .8188 L F
.201 0 0 r
.50579 .83135 m .50785 .83177 L .50898 .8319 L F
.527 .518 .789 r
.50898 .8319 m .50991 .82868 L .508 .82895 L F
.399 .103 .343 r
.62697 .78722 m .6295 .78504 L .62889 .78671 L F
.213 0 .254 r
.62889 .78671 m .6295 .78504 L .63101 .78423 L F
.709 .49 .589 r
.4324 .8551 m .42889 .85515 L .42888 .85277 L F
.252 0 0 r
.52386 .87392 m .52038 .87618 L .52238 .87595 L F
.127 0 0 r
.52528 .87367 m .52386 .87392 L .52238 .87595 L F
.263 0 .242 r
.61269 .76098 m .6104 .76276 L .61123 .76218 L F
.381 .022 .225 r
.37145 .76838 m .3742 .76624 L .37236 .76682 L F
.456 .554 .866 r
.36482 .72724 m .3643 .72954 L .36297 .72779 L F
.36482 .72724 m .36622 .72984 L .3643 .72954 L F
0 0 0 r
.60172 .80832 m .59958 .81096 L .60079 .8101 L F
0 0 .111 r
.60079 .8101 m .59958 .81096 L .59885 .81282 L F
.091 0 0 r
.59167 .77443 m .59259 .77457 L .59137 .77375 L F
.59167 .77443 m .59423 .77452 L .59259 .77457 L F
.049 .511 .889 r
.35616 .7273 m .35542 .72764 L .35421 .72706 L F
.35616 .7273 m .35773 .72848 L .35542 .72764 L F
.786 .984 .901 r
.49601 .88676 m .49906 .8851 L .49772 .88445 L F
.59 .897 .987 r
.49906 .8851 m .49992 .88409 L .49772 .88445 L F
.49906 .8851 m .50126 .88445 L .49992 .88409 L F
.765 .894 .934 r
.51415 .82113 m .5175 .82031 L .51611 .82032 L F
.525 .913 .927 r
.51815 .81951 m .51611 .82032 L .5175 .82031 L F
.657 .584 .761 r
.52483 .81866 m .52664 .82253 L .52804 .82116 L F
.402 0 0 r
.49096 .86945 m .49241 .86816 L .48906 .86834 L F
.484 .051 .14 r
.49312 .86994 m .49241 .86816 L .49096 .86945 L F
.49312 .86994 m .49408 .86814 L .49241 .86816 L F
.594 .777 .968 r
.44989 .87399 m .44749 .87446 L .44613 .87334 L F
.447 .381 .69 r
.6501 .73002 m .65236 .73101 L .65203 .7299 L F
.086 .445 .88 r
.65305 .73217 m .65236 .73101 L .6501 .73002 L F
.734 .515 .596 r
.50603 .84231 m .50268 .84442 L .50282 .84268 L F
.061 0 .151 r
.47482 .83762 m .47468 .83845 L .47648 .83771 L F
.361 .804 .955 r
.47266 .83921 m .47269 .83919 L .47492 .83915 L F
.47269 .83919 m .47388 .83875 L .47492 .83915 L F
.741 .529 .606 r
.4747 .84171 m .47266 .83921 L .47492 .83915 L F
.809 .599 .618 r
.47492 .83915 m .47649 .84282 L .4747 .84171 L F
.061 0 .151 r
.47468 .83845 m .47438 .84035 L .47641 .8378 L F
.47468 .83845 m .47641 .8378 L .47648 .83771 L F
.361 .804 .955 r
.47269 .83919 m .47376 .8387 L .47388 .83875 L F
.495 .351 .614 r
.40724 .7581 m .40532 .75607 L .40739 .7558 L F
.40724 .7581 m .40553 .75883 L .40532 .75607 L F
.27 0 0 r
.65032 .76873 m .65199 .76905 L .64969 .76942 L F
.65032 .76873 m .65241 .76845 L .65199 .76905 L F
.882 .895 .836 r
.53762 .81823 m .53877 .81883 L .54087 .81619 L F
.616 .455 .641 r
.53877 .81883 m .54111 .81878 L .54087 .81619 L F
.118 .293 .766 r
.54003 .81843 m .53877 .81883 L .53762 .81823 L F
.6 .362 .527 r
.53877 .81883 m .54087 .82082 L .54111 .81878 L F
.118 .293 .766 r
.54003 .81843 m .54087 .82082 L .53877 .81883 L F
.146 0 0 r
.58918 .82902 m .58747 .82885 L .58653 .82893 L F
.268 .768 .73 r
.4571 .88555 m .46064 .88453 L .45703 .88555 L F
.745 .826 .915 r
.43232 .87334 m .43132 .87576 L .42987 .87503 L F
.43232 .87334 m .43338 .8743 L .43132 .87576 L F
.601 .164 .183 r
.43884 .82777 m .44106 .82804 L .44247 .82644 L F
.649 .302 .371 r
.44106 .82804 m .44464 .82623 L .44247 .82644 L F
.889 .85 .799 r
.49658 .8765 m .49504 .87882 L .49343 .87833 L F
0 .401 .734 r
.49711 .87656 m .49658 .8765 L .49554 .87569 L F
.49711 .87656 m .49878 .87726 L .49658 .8765 L F
.591 .265 .385 r
.34339 .72444 m .34531 .72431 L .34378 .72353 L F
.562 .313 .497 r
.34378 .72353 m .34531 .72431 L .34579 .72381 L F
0 0 0 r
.65305 .73217 m .65572 .73076 L .65435 .73168 L F
.65305 .73217 m .65435 .73168 L .65236 .73101 L F
.52 .262 .465 r
.37136 .85251 m .37428 .85002 L .37144 .85017 L F
.692 .257 .213 r
.4567 .84248 m .45557 .84399 L .4533 .84215 L F
.888 .528 .357 r
.4567 .84248 m .45687 .84446 L .45557 .84399 L F
.726 .393 .416 r
.46022 .8443 m .4567 .84248 L .45973 .84215 L F
.46022 .8443 m .45687 .84446 L .4567 .84248 L F
.628 .586 .788 r
.52408 .82863 m .52523 .83224 L .52691 .82961 L F
.561 .499 .742 r
.52523 .83224 m .52751 .83213 L .52691 .82961 L F
.476 .118 .279 r
.52418 .83363 m .52751 .83213 L .52523 .83224 L F
.868 .462 .259 r
.67798 .73383 m .68014 .73675 L .6808 .73548 L F
.851 .437 .249 r
.68014 .73675 m .6818 .73719 L .6808 .73548 L F
.245 0 0 r
.47934 .87145 m .47648 .8713 L .47855 .87152 L F
.833 .905 .889 r
.62884 .73095 m .62558 .73239 L .62789 .73 L F
.762 .859 .921 r
.63066 .72981 m .62884 .73095 L .62789 .73 L F
.761 .656 .746 r
.50798 .8399 m .50603 .84231 L .5044 .83997 L F
.50757 .83991 m .5044 .83997 L .50704 .84002 L F
.755 .322 .223 r
.50388 .83884 m .50704 .84002 L .5044 .83997 L F
.50388 .83884 m .50564 .84094 L .50704 .84002 L F
.829 .987 .719 r
.50704 .84002 m .50564 .84094 L .50623 .84018 L F
.50704 .84002 m .50623 .84018 L .50774 .83821 L F
.761 .656 .746 r
.50798 .8399 m .50757 .83991 L .50704 .84002 L F
.19 .72 .746 r
.50704 .84002 m .51011 .83945 L .50798 .8399 L F
.74 .596 .696 r
.46243 .84 m .46188 .84218 L .46067 .83927 L F
.721 .303 .252 r
.51408 .82579 m .5174 .82639 L .5152 .82446 L F
.489 .196 .394 r
.39602 .76575 m .39346 .76867 L .39387 .76707 L F
0 0 0 r
.6737 .72482 m .67286 .72652 L .67239 .72412 L F
.997 .8 .443 r
.67286 .72652 m .6737 .72482 L .67239 .72412 L F
.67286 .72652 m .67351 .7271 L .6737 .72482 L F
0 0 0 r
.66853 .75342 m .66552 .75521 L .66537 .75536 L F
.635 .438 .599 r
.3852 .83956 m .38787 .83945 L .38781 .83692 L F
.718 .572 .69 r
.38787 .83945 m .38998 .83677 L .38781 .83692 L F
.762 .72 .813 r
.62568 .74531 m .62675 .74634 L .62844 .74528 L F
.024 0 .29 r
.603 .80539 m .60172 .80832 L .60323 .80775 L F
0 0 0 r
.60323 .80775 m .60172 .80832 L .60079 .8101 L F
.38 .12 .389 r
.62244 .79211 m .62458 .78978 L .62464 .79223 L F
.392 .147 .419 r
.62458 .78978 m .62697 .78722 L .62685 .78959 L F
.343 .108 .407 r
.62464 .79223 m .62458 .78978 L .62685 .78959 L F
.552 .672 .918 r
.51966 .87654 m .52192 .87892 L .52427 .87833 L F
0 0 0 r
.63555 .76619 m .63762 .76568 L .63865 .76535 L F
.351 0 0 r
.63762 .76568 m .64118 .76506 L .63865 .76535 L F
.184 .712 .848 r
.63865 .76535 m .64118 .76506 L .64135 .76524 L F
.575 .47 .698 r
.39729 .74626 m .39747 .74798 L .39543 .74835 L F
.384 .115 .377 r
.42671 .73844 m .42532 .73768 L .42851 .73783 L F
.034 0 0 r
.42532 .73768 m .42794 .7378 L .42851 .73783 L F
.636 .965 .86 r
.42851 .73783 m .42794 .7378 L .42927 .73676 L F
.64 .965 .829 r
.42927 .73676 m .42671 .73844 L .42851 .73783 L F
.312 0 0 r
.36558 .74785 m .36435 .74837 L .36218 .74839 L F
.045 0 0 r
.3675 .74779 m .36435 .74837 L .36558 .74785 L F
.62 .943 .948 r
.35128 .75247 m .35068 .75278 L .35029 .7535 L F
.633 .954 .933 r
.35029 .7535 m .35068 .75278 L .3493 .75351 L F
.994 .855 .51 r
.64678 .72743 m .64576 .72901 L .64652 .7297 L F
.89 .957 .838 r
.64578 .72577 m .64678 .72743 L .64891 .72485 L F
.991 .861 .511 r
.64578 .72577 m .64576 .72901 L .64678 .72743 L F
.655 .514 .68 r
.38077 .84479 m .38288 .84204 L .38064 .84237 L F
.45 .828 .99 r
.37096 .7479 m .36954 .74742 L .3675 .74779 L F
0 .535 .723 r
.37291 .74775 m .36954 .74742 L .37096 .7479 L F
.882 .895 .836 r
.53762 .81823 m .54087 .81619 L .54003 .81843 L F
.515 .38 .635 r
.54087 .81619 m .54305 .81836 L .54297 .81586 L F
.54087 .81619 m .54111 .81878 L .54188 .81861 L F
.54223 .81754 m .54188 .81861 L .54305 .81836 L F
.54087 .81619 m .54188 .81861 L .54223 .81754 L F
.824 .596 .594 r
.54297 .81586 m .54003 .81843 L .54087 .81619 L F
.54269 .81611 m .54117 .81705 L .54003 .81843 L F
.54297 .81586 m .54272 .81603 L .54269 .81611 L F
.54272 .81603 m .54117 .81705 L .54269 .81611 L F
.769 .995 .804 r
.61944 .73833 m .61708 .7406 L .6175 .73925 L F
.773 .92 .545 r
.61708 .7406 m .61587 .74205 L .6175 .73925 L F
.734 .515 .596 r
.50603 .84231 m .50594 .84473 L .50268 .84442 L F
.676 .466 .594 r
.50813 .84456 m .50594 .84473 L .50603 .84231 L F
.713 .681 .818 r
.68745 .71258 m .68401 .71177 L .68633 .71089 L F
.665 .62 .794 r
.68633 .71089 m .68913 .71175 L .68745 .71258 L F
.76 .48 .51 r
.53581 .8681 m .533 .86833 L .53529 .86763 L F
.457 .084 .242 r
.53581 .8681 m .53752 .86804 L .53672 .8695 L F
.293 0 0 r
.53745 .86831 m .53752 .86804 L .53581 .8681 L F
.53782 .86836 m .53752 .86804 L .53745 .86831 L F
.5375 .86827 m .53581 .8681 L .53529 .86763 L F
.53782 .86836 m .53745 .86831 L .5375 .86827 L F
.53745 .86831 m .53581 .8681 L .5375 .86827 L F
0 0 .204 r
.53882 .86661 m .53752 .86804 L .53782 .86836 L F
0 0 0 r
.53778 .86798 m .53752 .86804 L .53882 .86661 L F
.53745 .86831 m .53752 .86804 L .53783 .86797 L F
.81 .825 .862 r
.53651 .86691 m .53882 .86661 L .53802 .86584 L F
.536 .86727 m .53665 .86712 L .53651 .86691 L F
.53665 .86712 m .53882 .86661 L .53651 .86691 L F
.131 .507 .91 r
.5371 .86779 m .53529 .86763 L .53596 .8669 L F
.53761 .86819 m .53732 .86812 L .5371 .86779 L F
.53732 .86812 m .53529 .86763 L .5371 .86779 L F
.53782 .86836 m .5375 .86827 L .53761 .86819 L F
0 0 0 r
.53733 .86839 m .53752 .86804 L .53746 .8683 L F
.131 .507 .91 r
.5375 .86827 m .53529 .86763 L .53761 .86819 L F
0 0 0 r
.53672 .8695 m .53733 .86839 L .53739 .86857 L F
.53733 .86839 m .53746 .8683 L .53739 .86857 L F
.131 .507 .91 r
.53782 .86836 m .53596 .8669 L .536 .86727 L F
.81 .825 .862 r
.536 .86727 m .5376 .86823 L .53882 .86661 L F
.5376 .86823 m .53782 .86836 L .53882 .86661 L F
0 0 0 r
.53783 .86797 m .53778 .86798 L .53882 .86661 L F
.53739 .86857 m .53745 .86831 L .53783 .86797 L F
.457 .084 .242 r
.53581 .8681 m .53672 .8695 L .53542 .87085 L F
.62 .646 .854 r
.42074 .87671 m .41773 .87549 L .41952 .87516 L F
.592 .671 .894 r
.42283 .87636 m .42074 .87671 L .41952 .87516 L F
.649 .793 .951 r
.41015 .8924 m .41376 .89283 L .41225 .89176 L F
.738 .794 .897 r
.41225 .89176 m .41376 .89283 L .41556 .89178 L F
.513 .648 .918 r
.38355 .74811 m .38563 .75109 L .38675 .75034 L F
.611 .56 .772 r
.38563 .75109 m .38821 .75312 L .38675 .75034 L F
.389 .819 .962 r
.62844 .74528 m .62769 .74489 L .62568 .74531 L F
1 .807 .478 r
.62768 .74264 m .62844 .74528 L .63084 .74293 L F
.62768 .74264 m .62769 .74489 L .62844 .74528 L F
.806 .799 .845 r
.63173 .73926 m .62988 .74 L .63293 .74034 L F
.832 .751 .774 r
.62988 .74 m .63084 .74293 L .63293 .74034 L F
.792 .798 .857 r
.63173 .73926 m .63293 .74034 L .63518 .73779 L F
.451 .883 .875 r
.53596 .8669 m .53529 .86763 L .533 .86833 L F
.25 .197 .6 r
.60337 .80273 m .603 .80539 L .60483 .80468 L F
.144 0 .332 r
.60483 .80468 m .603 .80539 L .60323 .80775 L F
.475 .204 .422 r
.3799 .7771 m .3794 .77906 L .37742 .77941 L F
.484 .193 .396 r
.382 .77686 m .3794 .77906 L .3799 .7771 L F
.78 .687 .761 r
.45837 .86281 m .45735 .86591 L .456 .86507 L F
.343 .307 .674 r
.45735 .86591 m .45836 .86624 L .456 .86507 L F
.45735 .86591 m .45831 .86764 L .45836 .86624 L F
.619 .947 .939 r
.48317 .85171 m .48238 .85222 L .48416 .85197 L F
.793 .735 .799 r
.34455 .72736 m .34531 .72431 L .34369 .72537 L F
.34455 .72736 m .34579 .72381 L .34531 .72431 L F
0 .575 .734 r
.56802 .79018 m .57102 .79029 L .57142 .79034 L F
.787 .964 .653 r
.57142 .79034 m .57102 .79029 L .57173 .78921 L F
.923 .951 .791 r
.57173 .78921 m .57065 .79245 L .57142 .79034 L F
.448 .286 .568 r
.6093 .79261 m .60949 .79487 L .61099 .79213 L F
.519 .257 .457 r
.60091 .75583 m .60304 .75548 L .60337 .75353 L F
.248 .026 .368 r
.60337 .75353 m .60481 .75427 L .60555 .7532 L F
.60337 .75353 m .60304 .75548 L .60481 .75427 L F
.06 0 0 r
.52632 .87559 m .52897 .87379 L .52766 .87545 L F
.256 0 0 r
.52766 .87545 m .52897 .87379 L .53091 .87334 L F
.342 .082 .367 r
.49344 .87353 m .49566 .87107 L .49406 .8736 L F
.733 .618 .731 r
.49408 .86814 m .49772 .86839 L .49566 .87107 L F
.359 .777 .978 r
.49566 .87107 m .4947 .87291 L .49406 .8736 L F
.49566 .87107 m .49539 .87052 L .4947 .87291 L F
.56 .379 .593 r
.49772 .86839 m .49776 .87092 L .49566 .87107 L F
.359 .777 .978 r
.49566 .87107 m .49776 .87092 L .49539 .87052 L F
0 0 0 r
.62842 .77381 m .63107 .77119 L .62911 .7718 L F
0 .106 .585 r
.57483 .81801 m .57363 .81709 L .57284 .81635 L F
0 .131 .628 r
.5741 .81721 m .57483 .81801 L .57284 .81635 L F
.78 .455 0 r
.5742 .81741 m .57483 .81801 L .5741 .81721 L F
0 .106 .585 r
.57483 .81801 m .57526 .81843 L .57363 .81709 L F
.78 .455 0 r
.57479 .81864 m .57483 .81801 L .5742 .81741 L F
0 .106 .585 r
.57483 .81801 m .57536 .81851 L .57526 .81843 L F
.479 .189 .394 r
.38678 .774 m .38404 .77652 L .38474 .77442 L F
.89 .957 .838 r
.64578 .72577 m .64891 .72485 L .64757 .724 L F
.342 .072 .351 r
.49292 .87733 m .49344 .87353 L .49406 .8736 L F
0 0 .084 r
.49501 .87757 m .49554 .87569 L .49343 .87833 L F
.49492 .87762 m .49343 .87833 L .49277 .8775 L F
.49291 .87733 m .49277 .8775 L .4926 .87729 L F
.49492 .87762 m .49277 .8775 L .49291 .87733 L F
.342 .072 .351 r
.4929 .87733 m .49344 .87353 L .49292 .87733 L F
.56 .237 .377 r
.49014 .87656 m .49344 .87353 L .4929 .87733 L F
.837 .696 .707 r
.49095 .87543 m .49195 .87639 L .4947 .87291 L F
.342 .072 .351 r
.49293 .8773 m .49406 .8736 L .4947 .87291 L F
.49293 .8773 m .49406 .8736 L .49293 .8773 L F
.49292 .87733 m .49406 .8736 L .49293 .87731 L F
.837 .696 .707 r
.49193 .87642 m .49293 .8773 L .4947 .87291 L F
.479 .651 .935 r
.49295 .87625 m .49267 .87707 L .49095 .87543 L F
.49267 .87707 m .4926 .87728 L .49095 .87543 L F
.837 .696 .707 r
.49095 .87543 m .49193 .87642 L .49195 .87639 L F
.479 .651 .935 r
.49267 .87707 m .49276 .87715 L .4926 .87728 L F
.49345 .87657 m .49501 .87757 L .49292 .87732 L F
.342 .072 .351 r
.49293 .87731 m .49293 .8773 L .49293 .8773 L F
.49289 .87741 m .49292 .87733 L .49293 .87731 L F
.49289 .87741 m .4929 .87733 L .49292 .87733 L F
.56 .237 .377 r
.49014 .87656 m .4929 .87733 L .49239 .87726 L F
0 0 .084 r
.49294 .87732 m .49292 .87733 L .4926 .87728 L F
.837 .696 .707 r
.49193 .87642 m .49289 .87741 L .49293 .8773 L F
.479 .651 .935 r
.49295 .87625 m .49345 .87657 L .49276 .87715 L F
.49295 .87625 m .49276 .87715 L .49267 .87707 L F
.49345 .87657 m .49292 .87732 L .4926 .87728 L F
0 0 .084 r
.49501 .87757 m .49492 .87762 L .49292 .87733 L F
.49501 .87757 m .49292 .87733 L .49294 .87732 L F
.49492 .87762 m .4926 .87729 L .4926 .87728 L F
.56 .237 .377 r
.49239 .87726 m .4929 .87733 L .49289 .87741 L F
.463 .889 .876 r
.56617 .77463 m .56902 .77383 L .56732 .77481 L F
0 .573 .739 r
.56681 .84807 m .5673 .84803 L .56671 .84704 L F
.56681 .84807 m .56861 .84816 L .5673 .84803 L F
.804 .626 .66 r
.39945 .89521 m .39947 .89742 L .4028 .89452 L F
.39945 .89521 m .4028 .89452 L .40186 .89481 L F
.452 .88 .799 r
.40365 .89385 m .4028 .89452 L .40422 .89373 L F
.453 .876 .762 r
.40365 .89385 m .40186 .89481 L .4028 .89452 L F
.503 .803 .999 r
.48689 .86828 m .48318 .86786 L .48598 .86799 L F
.305 0 0 r
.48721 .86915 m .48689 .86828 L .48598 .86799 L F
.48721 .86915 m .48906 .86834 L .48689 .86828 L F
.405 .133 .384 r
.62244 .79211 m .62401 .79402 L .62248 .79483 L F
.62244 .79211 m .62464 .79223 L .62401 .79402 L F
.223 .53 .921 r
.42282 .82532 m .42416 .82558 L .42344 .82635 L F
.224 .533 .922 r
.42416 .82558 m .42518 .82681 L .42344 .82635 L F
.388 .748 .992 r
.38257 .90154 m .38246 .90072 L .38126 .90057 L F
.38257 .90154 m .38421 .90127 L .38246 .90072 L F
.719 .761 .886 r
.40427 .75243 m .40197 .75348 L .40096 .75227 L F
.712 .978 .913 r
.5464 .8362 m .54574 .83749 L .54739 .83629 L F
.5464 .8362 m .54574 .83749 L .54739 .83629 L F
.445 .242 .508 r
.54555 .83932 m .54574 .83749 L .54739 .83629 L F
.54739 .83629 m .54574 .83749 L .54555 .83932 L F
.551 .462 .707 r
.41959 .87369 m .41773 .87549 L .41734 .87421 L F
.41959 .87369 m .41952 .87516 L .41773 .87549 L F
.741 .656 .766 r
.63603 .72946 m .63292 .72753 L .63499 .72675 L F
.63603 .72946 m .63286 .7296 L .63292 .72753 L F
.742 .65 .758 r
.63603 .72946 m .63395 .73091 L .63286 .7296 L F
.672 .639 .808 r
.63831 .72742 m .63603 .72946 L .63499 .72675 L F
.513 .342 .586 r
.49974 .87041 m .49772 .86839 L .49976 .86806 L F
.49856 .86924 m .49775 .87005 L .49772 .86839 L F
.49974 .87041 m .49775 .87005 L .49856 .86924 L F
.578 .733 .948 r
.49623 .86984 m .49974 .87041 L .49976 .86806 L F
.49623 .86984 m .49976 .86806 L .49762 .86957 L F
.797 .999 .845 r
.49762 .86957 m .49969 .86812 L .49916 .86784 L F
.49969 .86812 m .49976 .86806 L .49975 .86806 L F
.49969 .86812 m .49975 .86806 L .49916 .86784 L F
.513 .342 .586 r
.49974 .87041 m .49776 .87092 L .49775 .87005 L F
.951 .816 .675 r
.50092 .83183 m .50024 .83418 L .50132 .83412 L F
.61 .413 .589 r
.50132 .83412 m .50119 .8366 L .50024 .83418 L F
.50132 .83412 m .50363 .83636 L .50119 .8366 L F
.519 .913 .799 r
.64135 .76524 m .64118 .76506 L .64285 .7642 L F
.558 .64 .888 r
.48908 .87838 m .48569 .87662 L .48766 .87668 L F
.677 .804 .943 r
.49014 .87656 m .48908 .87838 L .48766 .87668 L F
.49014 .87656 m .49176 .8774 L .48908 .87838 L F
.754 .588 .671 r
.53656 .82963 m .53532 .83189 L .5347 .82881 L F
.674 .836 .961 r
.42809 .87586 m .42622 .87671 L .42484 .87582 L F
.414 .135 .378 r
.62685 .78959 m .62697 .78722 L .62889 .78671 L F
.537 .319 .531 r
.39907 .76279 m .39956 .76586 L .39602 .76575 L F
.527 .315 .535 r
.40083 .76106 m .40083 .76329 L .39907 .76279 L F
.536 .318 .531 r
.40026 .76489 m .39907 .76279 L .40083 .76329 L F
.40026 .76489 m .39956 .76586 L .39907 .76279 L F
.553 .307 .497 r
.60169 .76641 m .60047 .76914 L .59821 .76941 L F
.625 .385 .534 r
.60312 .76807 m .60169 .76641 L .60326 .76632 L F
.60312 .76807 m .60047 .76914 L .60169 .76641 L F
.537 .194 .333 r
.65809 .75839 m .66036 .75837 L .66115 .7564 L F
.312 0 0 r
.66204 .75719 m .66115 .7564 L .66036 .75837 L F
.66204 .75719 m .66366 .75641 L .66115 .7564 L F
.436 .853 .695 r
.66322 .75654 m .66366 .75641 L .66204 .75719 L F
.66537 .75536 m .66366 .75641 L .66322 .75654 L F
.091 0 0 r
.66366 .75641 m .66626 .75633 L .66379 .75636 L F
.66366 .75641 m .66379 .75636 L .66115 .7564 L F
.822 .352 .091 r
.44345 .87117 m .44613 .87334 L .44436 .87181 L F
.695 .903 .97 r
.44636 .87095 m .44436 .87181 L .44345 .87117 L F
.685 .593 .748 r
.53108 .83617 m .53261 .84001 L .5347 .83931 L F
.587 .428 .633 r
.38609 .75602 m .3883 .75588 L .38821 .75312 L F
.172 .294 .748 r
.38609 .75602 m .38814 .7579 L .3883 .75588 L F
.7 .532 .656 r
.37428 .85002 m .37644 .84998 L .37633 .8476 L F
.646 .489 .657 r
.37633 .8476 m .37644 .84998 L .37857 .84735 L F
.711 .582 .709 r
.46067 .83927 m .46188 .84218 L .45973 .84215 L F
.748 .569 .653 r
.46188 .84218 m .46022 .8443 L .45973 .84215 L F
.46188 .84218 m .46184 .84493 L .46022 .8443 L F
.489 .196 .394 r
.39602 .76575 m .39548 .76835 L .39346 .76867 L F
.548 .268 .443 r
.39956 .76586 m .39548 .76835 L .39602 .76575 L F
.889 .828 .781 r
.64353 .73109 m .64652 .7297 L .64576 .72901 L F
.64353 .73109 m .64461 .73222 L .64652 .7297 L F
.765 .255 0 r
.48468 .87145 m .48627 .87324 L .48474 .87267 L F
.565 .316 .497 r
.58616 .76368 m .58838 .76348 L .58833 .76149 L F
.562 .29 .461 r
.58838 .76348 m .59136 .76087 L .58833 .76149 L F
.298 .06 .375 r
.5232 .86287 m .52184 .8638 L .52116 .86554 L F
.064 0 0 r
.51645 .83476 m .51324 .83615 L .51107 .83656 L F
.518 .621 .894 r
.51731 .83335 m .51645 .83476 L .5127 .83182 L F
.401 .02 .197 r
.51731 .83335 m .51324 .83615 L .51645 .83476 L F
.696 .295 .282 r
.49196 .8423 m .49075 .84399 L .48863 .84206 L F
.776 .738 .819 r
.49411 .84396 m .49075 .84399 L .49196 .8423 L F
.711 .582 .709 r
.46067 .83927 m .45973 .84215 L .45871 .83955 L F
0 .263 .741 r
.54279 .8097 m .54343 .81048 L .54143 .80917 L F
.579 .43 .643 r
.60268 .80051 m .60486 .80016 L .60452 .79753 L F
.561 .363 .569 r
.60478 .80244 m .60486 .80016 L .60268 .80051 L F
.395 .357 .698 r
.60268 .80051 m .60337 .80273 L .60478 .80244 L F
.634 .35 .47 r
.48637 .81784 m .48829 .81825 L .48629 .81617 L F
.73 .396 .415 r
.44464 .82623 m .44667 .82849 L .44783 .82637 L F
.601 .259 .363 r
.44667 .82849 m .45001 .82648 L .44783 .82637 L F
.605 .091 0 r
.51694 .87674 m .51601 .87608 L .51485 .87638 L F
.594 .134 .129 r
.51694 .87674 m .51839 .87645 L .51601 .87608 L F
.557 .152 .23 r
.32976 .66176 m .33102 .6617 L .33006 .66138 L F
.052 0 0 r
.66043 .76451 m .66123 .76513 L .65955 .76535 L F
.66043 .76451 m .66215 .76347 L .66123 .76513 L F
0 0 0 r
.46455 .88344 m .46602 .88318 L .4677 .88303 L F
.144 0 .018 r
.49227 .8159 m .49161 .8166 L .49444 .81532 L F
.513 .334 .576 r
.60821 .81355 m .61011 .81081 L .60989 .81318 L F
.48 .324 .592 r
.60986 .81525 m .60821 .81355 L .60989 .81318 L F
.313 .299 .683 r
.60986 .81525 m .60886 .81614 L .60821 .81355 L F
.562 .342 .539 r
.40279 .76288 m .40083 .76106 L .40283 .76087 L F
.40279 .76288 m .40083 .76329 L .40083 .76106 L F
.764 .86 .921 r
.50542 .82027 m .50858 .81981 L .50768 .81925 L F
.623 .068 0 r
.51087 .82048 m .50768 .81925 L .50858 .81981 L F
.515 .718 .964 r
.3918 .73956 m .39086 .7409 L .38985 .73962 L F
.3918 .73956 m .39296 .7408 L .39086 .7409 L F
.08 0 .271 r
.60546 .83098 m .60557 .8288 L .60709 .82816 L F
0 0 .212 r
.58406 .82927 m .58325 .83145 L .58388 .83135 L F
0 0 .352 r
.58325 .83145 m .58364 .83452 L .58388 .83135 L F
.515 .273 .486 r
.47266 .83921 m .47129 .84207 L .47039 .84208 L F
.741 .529 .606 r
.4747 .84171 m .47129 .84207 L .47266 .83921 L F
.941 .782 .656 r
.5448 .79791 m .54344 .79758 L .54403 .79576 L F
.802 .339 .132 r
.5448 .79791 m .54405 .79878 L .54344 .79758 L F
.5448 .79791 m .54652 .8002 L .54405 .79878 L F
.137 0 0 r
.57156 .84949 m .57625 .84953 L .57459 .84914 L F
.156 0 0 r
.57625 .84953 m .57659 .84961 L .57459 .84914 L F
.57625 .84953 m .57768 .84985 L .57659 .84961 L F
.009 .576 .788 r
.57625 .84953 m .57817 .84974 L .57768 .84985 L F
.612 .788 .965 r
.49127 .88782 m .49253 .88653 L .49035 .88711 L F
.76 .673 .766 r
.57129 .83178 m .57457 .83227 L .57398 .83124 L F
.031 .602 .726 r
.42518 .82681 m .42733 .82676 L .42877 .82676 L F
.406 0 0 r
.42733 .82676 m .43084 .82663 L .42877 .82676 L F
0 0 0 r
.53588 .84707 m .53388 .84907 L .53611 .84956 L F
.437 .477 .803 r
.53388 .84907 m .53685 .85088 L .53611 .84956 L F
.486 .807 1 r
.3735 .72927 m .37456 .73003 L .37152 .7296 L F
.228 .44 .859 r
.37557 .72899 m .37456 .73003 L .3735 .72927 L F
.425 0 0 r
.37456 .73003 m .37686 .73118 L .37799 .73151 L F
.228 .44 .859 r
.37557 .72899 m .37686 .73118 L .37456 .73003 L F
.754 .531 .592 r
.4929 .85254 m .49636 .85005 L .49424 .85277 L F
.676 .542 .694 r
.49694 .8525 m .49424 .85277 L .49636 .85005 L F
.04 0 0 r
.49694 .8525 m .49645 .8526 L .49424 .85277 L F
.24 .741 .901 r
.49424 .85277 m .49645 .8526 L .4929 .85254 L F
.767 .526 .569 r
.67326 .73774 m .6742 .74063 L .67059 .7393 L F
.614 .442 .626 r
.67519 .7394 m .67326 .73774 L .67633 .73777 L F
.67519 .7394 m .6742 .74063 L .67326 .73774 L F
.545 .28 .464 r
.66131 .75237 m .66257 .75067 L .66055 .75052 L F
.617 .22 .268 r
.46066 .82535 m .46266 .82579 L .46078 .82438 L F
0 0 0 r
.68439 .71844 m .68507 .71684 L .68393 .7195 L F
.467 .566 .872 r
.68507 .71684 m .68701 .71596 L .68411 .7151 L F
.398 .376 .717 r
.68725 .71853 m .68507 .71684 L .68439 .71844 L F
.68725 .71853 m .68701 .71596 L .68507 .71684 L F
.59 .7 .919 r
.48829 .88751 m .48926 .88569 L .48717 .88606 L F
.48829 .88751 m .49035 .88711 L .48926 .88569 L F
.552 .18 .29 r
.47321 .82287 m .47543 .82294 L .47656 .82092 L F
.457 .084 .242 r
.47543 .82294 m .47858 .8207 L .47656 .82092 L F
.423 .35 .67 r
.5656 .79756 m .5645 .79904 L .56319 .79764 L F
.521 0 0 r
.56572 .7995 m .5662 .79996 L .56755 .80017 L F
.5645 .79904 m .5662 .79996 L .56572 .7995 L F
0 0 .51 r
.56731 .80105 m .5662 .79996 L .5673 .79896 L F
.755 .333 0 r
.5662 .79996 m .56788 .80272 L .56755 .80017 L F
0 0 .51 r
.56732 .80126 m .5662 .79996 L .56731 .80105 L F
.423 .35 .67 r
.5656 .79756 m .5662 .79996 L .5645 .79904 L F
.545 .343 .558 r
.67721 .75592 m .67725 .75834 L .67507 .75874 L F
.627 .786 .958 r
.67869 .75382 m .67923 .75531 L .67721 .75592 L F
.523 .321 .548 r
.67923 .75531 m .67725 .75834 L .67721 .75592 L F
.364 .16 .464 r
.53285 .81574 m .53378 .81633 L .53476 .81349 L F
.627 .42 .582 r
.38998 .83677 m .39218 .8367 L .39232 .83439 L F
.578 .378 .574 r
.39218 .8367 m .3943 .83647 L .39232 .83439 L F
.646 .377 .499 r
.3943 .83647 m .39472 .83451 L .39232 .83439 L F
.605 .688 .901 r
.39669 .74264 m .39296 .7408 L .3952 .74054 L F
.592 .699 .918 r
.39872 .74225 m .39669 .74264 L .3952 .74054 L F
.591 .462 .673 r
.39948 .74555 m .39669 .74264 L .39872 .74225 L F
.39948 .74555 m .39729 .74626 L .39669 .74264 L F
.66 .616 .795 r
.42272 .86336 m .42054 .86509 L .42124 .86489 L F
0 .046 .543 r
.55057 .82006 m .55129 .82078 L .54933 .81896 L F
.55057 .82006 m .54933 .81896 L .54813 .81834 L F
.945 .821 .691 r
.56857 .80807 m .56941 .80604 L .56818 .80519 L F
.603 .38 .551 r
.42685 .8551 m .42686 .85788 L .42418 .85799 L F
.612 .387 .552 r
.42887 .85735 m .42685 .8551 L .42889 .85515 L F
.42887 .85735 m .42686 .85788 L .42685 .8551 L F
.503 0 0 r
.69173 .71831 m .69076 .71737 L .69281 .71658 L F
.462 .889 .84 r
.69076 .71737 m .68725 .71853 L .68755 .71876 L F
.69076 .71737 m .68994 .71723 L .68725 .71853 L F
.503 0 0 r
.69173 .71831 m .68994 .71723 L .69076 .71737 L F
.532 .371 .608 r
.69267 .71398 m .69281 .71658 L .69076 .71737 L F
.365 0 .011 r
.40597 .75237 m .40939 .75078 L .40668 .75232 L F
.40597 .75237 m .40806 .7522 L .40939 .75078 L F
.507 .334 .581 r
.41161 .75048 m .40968 .75302 L .40939 .75078 L F
.794 .567 .593 r
.40806 .7522 m .41161 .75048 L .40939 .75078 L F
.5 .243 .457 r
.36263 .77422 m .36461 .77387 L .36519 .77189 L F
.6 .414 .602 r
.36461 .77387 m .36683 .7712 L .36519 .77189 L F
.765 .386 .338 r
.48569 .87662 m .48289 .87559 L .48485 .87586 L F
.882 .842 .379 r
.48627 .87324 m .48569 .87662 L .48766 .87668 L F
.49 .602 .892 r
.48695 .87528 m .48569 .87662 L .48485 .87586 L F
.48695 .87528 m .48766 .87668 L .48569 .87662 L F
.009 .506 .868 r
.66745 .71867 m .66975 .71952 L .66807 .71857 L F
0 .109 .653 r
.66745 .71867 m .66914 .72154 L .66807 .71857 L F
.381 .032 .243 r
.52177 .82916 m .52099 .83122 L .5192 .83136 L F
.625 .478 .662 r
.52383 .82652 m .52177 .82916 L .52408 .82863 L F
.26 0 .19 r
.52269 .83058 m .52177 .82916 L .52408 .82863 L F
.52269 .83058 m .52099 .83122 L .52177 .82916 L F
.625 .478 .662 r
.52383 .82652 m .52177 .82916 L .52408 .82863 L F
.76 .714 .809 r
.64355 .72506 m .64026 .72469 L .6433 .72361 L F
.31 .425 .817 r
.6433 .72361 m .6445 .72439 L .64355 .72506 L F
.064 .507 .895 r
.38821 .75312 m .38883 .75266 L .38675 .75034 L F
.38821 .75312 m .38979 .75344 L .38883 .75266 L F
.529 .467 .73 r
.3883 .75588 m .38979 .75344 L .38821 .75312 L F
.368 .185 .496 r
.61011 .81081 m .61179 .80803 L .61132 .81039 L F
.396 .216 .516 r
.60989 .81318 m .61011 .81081 L .61132 .81039 L F
0 0 0 r
.51832 .81329 m .51958 .81296 L .52099 .81161 L F
.51832 .81329 m .51664 .81441 L .51958 .81296 L F
.615 .574 .785 r
.50024 .83418 m .50119 .8366 L .49896 .83676 L F
.641 .694 .884 r
.37152 .7296 m .3696 .73035 L .36832 .7286 L F
.626 .439 .61 r
.37857 .84735 m .38079 .84715 L .38077 .84479 L F
.655 .514 .68 r
.38077 .84479 m .38378 .84499 L .38288 .84204 L F
.691 .526 .66 r
.38079 .84715 m .38378 .84499 L .38077 .84479 L F
.461 .232 .48 r
.62376 .77478 m .62586 .77581 L .62663 .77477 L F
.62376 .77478 m .62396 .77669 L .62586 .77581 L F
.3 .794 .857 r
.58859 .84831 m .58902 .84779 L .58726 .84823 L F
.58859 .84831 m .59079 .84783 L .58902 .84779 L F
.798 .69 .746 r
.45604 .86317 m .45292 .8629 L .45423 .86114 L F
.795 .589 .622 r
.45604 .86317 m .45261 .86454 L .45292 .8629 L F
.45604 .86317 m .456 .86507 L .45261 .86454 L F
.702 .679 .825 r
.45837 .86281 m .45604 .86317 L .45423 .86114 L F
.78 .687 .761 r
.45837 .86281 m .456 .86507 L .45604 .86317 L F
.815 .743 .784 r
.62988 .74 m .62768 .74264 L .63084 .74293 L F
.349 .56 .915 r
.48317 .88567 m .4843 .88555 L .48155 .88492 L F
.48317 .88567 m .48508 .88668 L .4843 .88555 L F
0 0 0 r
.57832 .76806 m .57677 .76952 L .57781 .76865 L F
.034 0 0 r
.57677 .76952 m .57739 .76991 L .57781 .76865 L F
.57677 .76952 m .57532 .77045 L .57739 .76991 L F
0 0 0 r
.35686 .75069 m .35323 .75177 L .35501 .75106 L F
.548 .389 .618 r
.35836 .77945 m .36029 .77675 L .35802 .77703 L F
.754 .531 .592 r
.4929 .85254 m .49645 .8526 L .49636 .85005 L F
.958 .7 .502 r
.49694 .8525 m .49645 .8526 L .49636 .85005 L F
.566 .383 .592 r
.49636 .85005 m .49645 .8526 L .49865 .84992 L F
.49636 .85005 m .49645 .8526 L .49865 .84992 L F
.107 .274 .752 r
.55538 .83075 m .55479 .832 L .55372 .82915 L F
.674 .826 .392 r
.55385 .83357 m .55479 .832 L .55538 .83075 L F
.47 .055 .169 r
.55524 .83285 m .55479 .832 L .55385 .83357 L F
.635 .456 .624 r
.38528 .84168 m .38787 .83945 L .3852 .83956 L F
.852 .965 .875 r
.62069 .73692 m .61944 .73833 L .61965 .73645 L F
.882 .698 .648 r
.61711 .73683 m .6175 .73925 L .61758 .73912 L F
.32 .345 .731 r
.61595 .73816 m .61711 .73683 L .61758 .73912 L F
.507 .844 .997 r
.61595 .73816 m .61758 .73912 L .61762 .7391 L F
.899 .984 .787 r
.61944 .73833 m .61767 .73917 L .61965 .73645 L F
.61767 .73917 m .61762 .7391 L .61965 .73645 L F
.734 .601 .708 r
.61965 .73645 m .61762 .7391 L .61711 .73683 L F
.61762 .7391 m .6175 .73925 L .61747 .7391 L F
.61762 .7391 m .61747 .7391 L .61711 .73683 L F
.507 .844 .997 r
.61711 .73826 m .61762 .7391 L .6192 .73844 L F
.61762 .7391 m .61762 .7391 L .61765 .73909 L F
.61762 .7391 m .61765 .73909 L .6192 .73844 L F
.61595 .73816 m .61762 .7391 L .61711 .73826 L F
.899 .984 .787 r
.61767 .73917 m .6175 .73925 L .61762 .7391 L F
.163 0 .17 r
.61762 .7391 m .6175 .73925 L .6192 .73844 L F
.61758 .73912 m .6175 .73925 L .61762 .7391 L F
.899 .984 .787 r
.61762 .7391 m .6175 .73925 L .61762 .7391 L F
.679 .88 .973 r
.42516 .88958 m .42649 .89023 L .42841 .88936 L F
.688 .446 .551 r
.40202 .83429 m .40276 .83153 L .39977 .83173 L F
.637 .489 .665 r
.40276 .83153 m .40489 .83146 L .40508 .82955 L F
.614 .36 .51 r
.40483 .83361 m .40276 .83153 L .40202 .83429 L F
.40483 .83361 m .40489 .83146 L .40276 .83153 L F
.558 .663 .907 r
.54465 .84977 m .54309 .85048 L .54059 .84796 L F
.256 0 .283 r
.54237 .85225 m .54309 .85048 L .54465 .84977 L F
.433 .671 .963 r
.46534 .86517 m .46425 .86641 L .46317 .86541 L F
.46534 .86517 m .46692 .86679 L .46425 .86641 L F
.518 .52 .797 r
.46735 .86781 m .46425 .86641 L .46692 .86679 L F
.634 .323 .426 r
.44267 .8426 m .44275 .84466 L .43949 .84424 L F
.585 .285 .426 r
.44472 .84417 m .44275 .84466 L .44267 .8426 L F
.81 .777 .823 r
.63066 .72981 m .62789 .73 L .6301 .72754 L F
.768 .753 .84 r
.63292 .72753 m .63066 .72981 L .6301 .72754 L F
.691 .614 .765 r
.63292 .72753 m .63286 .7296 L .63066 .72981 L F
.255 0 0 r
.55344 .79253 m .55729 .79091 L .55423 .79167 L F
.451 .883 .875 r
.53596 .8669 m .533 .86833 L .53248 .86828 L F
.571 .424 .643 r
.60452 .79753 m .60486 .80016 L .60681 .79717 L F
.617 .955 .905 r
.50211 .88339 m .50126 .88445 L .50301 .88345 L F
.559 .886 .988 r
.49992 .88409 m .50126 .88445 L .50211 .88339 L F
.6 .338 .491 r
.59358 .76089 m .59585 .76081 L .59602 .75889 L F
.519 .253 .451 r
.59585 .76081 m .59886 .75793 L .59602 .75889 L F
.751 .33 .252 r
.52479 .83648 m .52175 .83609 L .52269 .83485 L F
.117 0 0 r
.52269 .83485 m .52383 .83534 L .52418 .83363 L F
.73 .382 .39 r
.52576 .83585 m .52479 .83648 L .52269 .83485 L F
.117 0 0 r
.52269 .83485 m .52175 .83609 L .52383 .83534 L F
.873 .98 .841 r
.50411 .87388 m .50213 .8762 L .50121 .87604 L F
.633 .511 .696 r
.5347 .83931 m .53739 .83917 L .53691 .83693 L F
.717 .757 .884 r
.63932 .73454 m .64247 .73484 L .64181 .7326 L F
.844 .832 .835 r
.64247 .73484 m .64353 .73109 L .64181 .7326 L F
.64247 .73484 m .64461 .73222 L .64353 .73109 L F
.608 .879 .991 r
.4359 .88717 m .43909 .88705 L .43781 .88645 L F
.464 .83 .993 r
.43909 .88705 m .43993 .88615 L .43781 .88645 L F
.43909 .88705 m .44121 .88665 L .43993 .88615 L F
.769 .945 .936 r
.5043 .88283 m .50854 .88103 L .50734 .8806 L F
.436 .828 .984 r
.50734 .8806 m .50854 .88103 L .51061 .88066 L F
.543 .613 .872 r
.69267 .71398 m .68913 .71175 L .69081 .71185 L F
.144 .444 .878 r
.69081 .71185 m .69355 .71335 L .69267 .71398 L F
.459 .316 .598 r
.69446 .71606 m .69267 .71398 L .69355 .71335 L F
.69446 .71606 m .69281 .71658 L .69267 .71398 L F
.713 .184 0 r
.55184 .80481 m .55424 .80582 L .55304 .80569 L F
.709 .203 0 r
.55424 .80582 m .55492 .80717 L .55304 .80569 L F
.55424 .80582 m .55591 .80795 L .55492 .80717 L F
.493 .19 .38 r
.36683 .7712 m .36951 .76878 L .36684 .76903 L F
.606 .572 .79 r
.40037 .75067 m .39884 .75275 L .39832 .75104 L F
.40037 .75067 m .40096 .75227 L .39884 .75275 L F
.688 .446 .551 r
.40202 .83429 m .39977 .83173 L .39968 .83383 L F
.493 .19 .38 r
.36683 .7712 m .36876 .77087 L .36951 .76878 L F
.621 .42 .589 r
.36876 .77087 m .37145 .76838 L .36951 .76878 L F
.267 .742 .938 r
.43084 .82663 m .43233 .82639 L .43401 .82694 L F
0 .169 .698 r
.43456 .82576 m .43401 .82694 L .43233 .82639 L F
.43456 .82576 m .43575 .82799 L .43401 .82694 L F
.635 .646 .844 r
.38467 .73738 m .38097 .7358 L .38331 .73646 L F
.374 .72 .988 r
.38331 .73646 m .38525 .73647 L .38467 .73738 L F
.303 .632 .963 r
.38525 .73647 m .38657 .73761 L .38467 .73738 L F
.609 .632 .848 r
.38772 .73852 m .38467 .73738 L .38657 .73761 L F
0 0 0 r
.52099 .81161 m .51958 .81296 L .52109 .81191 L F
.724 .829 .93 r
.43892 .87367 m .43559 .87375 L .43762 .87311 L F
.761 .987 .9 r
.44121 .87197 m .43892 .87367 L .43965 .87214 L F
.666 .889 .979 r
.43965 .87214 m .43892 .87367 L .43762 .87311 L F
.57 .215 .327 r
.49693 .81706 m .4953 .8187 L .49395 .8178 L F
.479 .249 .487 r
.37742 .77941 m .37709 .7816 L .37515 .78196 L F
.518 .283 .498 r
.37915 .78119 m .37742 .77941 L .3794 .77906 L F
.37915 .78119 m .37709 .7816 L .37742 .77941 L F
0 0 0 r
.66853 .75342 m .66537 .75536 L .66732 .75427 L F
.66853 .75342 m .67046 .75278 L .67057 .75215 L F
.66853 .75342 m .66732 .75427 L .67046 .75278 L F
.036 0 0 r
.59321 .84669 m .59474 .84647 L .59279 .84712 L F
.59321 .84669 m .59598 .84495 L .59474 .84647 L F
.719 .933 .608 r
.53147 .82411 m .53218 .82274 L .53298 .82258 L F
.53147 .82411 m .53004 .82543 L .53218 .82274 L F
.631 .809 .968 r
.35104 .72418 m .3499 .72495 L .3477 .72385 L F
.377 0 .119 r
.65772 .76583 m .65721 .76667 L .65426 .76795 L F
.234 0 0 r
.65955 .76535 m .65721 .76667 L .65772 .76583 L F
.191 0 .256 r
.61489 .75839 m .61458 .76051 L .61269 .76098 L F
.316 0 .258 r
.61407 .76249 m .61269 .76098 L .61458 .76051 L F
.61407 .76249 m .61222 .76328 L .61269 .76098 L F
.61 .567 .78 r
.48104 .84509 m .47934 .84737 L .47888 .84555 L F
.48104 .84509 m .48156 .84738 L .47934 .84737 L F
.521 .255 .453 r
.36377 .79017 m .36298 .79241 L .361 .79254 L F
.556 .29 .469 r
.36531 .79139 m .36377 .79017 L .36558 .79021 L F
.36531 .79139 m .36298 .79241 L .36377 .79017 L F
.495 .231 .443 r
.39155 .76914 m .39106 .77113 L .38906 .77145 L F
.492 .228 .442 r
.39308 .77075 m .39155 .76914 L .39346 .76867 L F
.39308 .77075 m .39106 .77113 L .39155 .76914 L F
.702 .679 .825 r
.45837 .86281 m .45423 .86114 L .45668 .8606 L F
.301 .718 .974 r
.45923 .86204 m .45837 .86281 L .45668 .8606 L F
.45923 .86204 m .46045 .86278 L .45837 .86281 L F
.53 .569 .839 r
.46174 .86495 m .45837 .86281 L .46045 .86278 L F
.397 .018 .199 r
.58546 .77235 m .58504 .77348 L .58287 .77348 L F
.619 .356 .497 r
.58504 .77348 m .58204 .7744 L .58287 .77348 L F
.675 .823 .955 r
.52378 .8177 m .52163 .81854 L .52483 .81866 L F
.498 .715 .968 r
.52483 .81866 m .52556 .81741 L .52378 .8177 L F
.52483 .81866 m .52696 .81846 L .52556 .81741 L F
.657 .584 .761 r
.52483 .81866 m .52804 .82116 L .52696 .81846 L F
.682 .551 .699 r
.38378 .84499 m .38528 .84168 L .38288 .84204 L F
.685 .843 .959 r
.44121 .88665 m .4444 .88662 L .44317 .88582 L F
.544 .8 .993 r
.44317 .88582 m .4444 .88662 L .44646 .88622 L F
0 0 0 r
.52812 .8158 m .52696 .81597 L .52895 .81529 L F
.52812 .8158 m .52556 .81741 L .52696 .81597 L F
.696 .713 .861 r
.36086 .72899 m .35773 .72848 L .3597 .72736 L F
.683 .775 .921 r
.36297 .72779 m .36086 .72899 L .3597 .72736 L F
.601 .375 .545 r
.3742 .76624 m .37634 .76616 L .3767 .76378 L F
.605 .416 .599 r
.37634 .76616 m .37875 .76322 L .3767 .76378 L F
.777 .704 .784 r
.52696 .81846 m .52804 .82116 L .53023 .81864 L F
.58 .347 .527 r
.43975 .85274 m .44082 .85644 L .43689 .85536 L F
.407 .245 .547 r
.44137 .85216 m .43975 .85274 L .44158 .84983 L F
0 0 .305 r
.44038 .85408 m .43975 .85274 L .44137 .85216 L F
.44038 .85408 m .44082 .85644 L .43975 .85274 L F
.516 .403 .663 r
.48221 .83884 m .48249 .84096 L .48005 .83895 L F
.513 .403 .666 r
.48249 .84096 m .48075 .84147 L .48005 .83895 L F
.503 .28 .509 r
.42088 .89155 m .42206 .89116 L .42211 .89158 L F
.42088 .89155 m .42211 .89158 L .41977 .89075 L F
.117 .297 .77 r
.66918 .73799 m .67059 .7393 L .66945 .73688 L F
.094 0 .382 r
.60867 .81841 m .60886 .81614 L .60986 .81525 L F
.754 .994 .857 r
.67507 .75874 m .67394 .75887 L .67191 .76059 L F
.202 .729 .77 r
.67725 .75834 m .67394 .75887 L .67507 .75874 L F
.617 .858 .989 r
.41225 .89176 m .41556 .89178 L .41428 .89111 L F
.628 .861 .986 r
.41428 .89111 m .41556 .89178 L .41766 .89112 L F
.745 .668 .774 r
.68401 .71177 m .68584 .70933 L .68633 .71089 L F
.648 .635 .823 r
.68799 .70895 m .68633 .71089 L .68584 .70933 L F
.68799 .70895 m .68913 .71175 L .68633 .71089 L F
.041 0 .178 r
.59988 .84161 m .60062 .83986 L .60181 .83885 L F
.542 .74 .967 r
.49411 .84396 m .49516 .84503 L .49623 .84379 L F
.526 .714 .958 r
.49516 .84503 m .49752 .84509 L .49623 .84379 L F
.2 0 0 r
.47327 .88293 m .47676 .8833 L .47537 .88293 L F
.218 .653 .953 r
.47676 .8833 m .47751 .88286 L .47537 .88293 L F
.47676 .8833 m .47861 .88356 L .47751 .88286 L F
.6 .424 .616 r
.65724 .72722 m .65743 .72966 L .65572 .73076 L F
.941 .685 .52 r
.65613 .72931 m .65743 .72966 L .65724 .72722 L F
.478 .269 .516 r
.65724 .72722 m .6593 .72684 L .65937 .72454 L F
.556 .418 .649 r
.6593 .72684 m .65743 .72966 L .65724 .72722 L F
.478 .269 .516 r
.65724 .72722 m .6593 .72684 L .65937 .72454 L F
.556 .418 .649 r
.6593 .72684 m .65743 .72966 L .65724 .72722 L F
.483 .272 .517 r
.65937 .72454 m .66131 .72628 L .66148 .72399 L F
.65937 .72454 m .6593 .72684 L .66131 .72628 L F
.66131 .72628 m .6593 .72684 L .65937 .72454 L F
.119 0 .256 r
.56376 .78672 m .56333 .7895 L .56189 .7898 L F
.314 .347 .736 r
.56498 .78449 m .56566 .78736 L .56376 .78672 L F
.668 .337 .405 r
.56621 .78918 m .56376 .78672 L .56566 .78736 L F
.56621 .78918 m .56333 .7895 L .56376 .78672 L F
.06 0 0 r
.52632 .87559 m .52766 .87545 L .52566 .87598 L F
.524 .87 .99 r
.37799 .73151 m .37838 .73071 L .37998 .73146 L F
.37799 .73151 m .37686 .73118 L .37838 .73071 L F
.602 .524 .739 r
.42272 .86336 m .41942 .86025 L .42236 .861 L F
.476 .228 .458 r
.35599 .78196 m .35799 .78133 L .35836 .77945 L F
.548 .389 .618 r
.35836 .77945 m .36035 .7791 L .36029 .77675 L F
.553 .321 .517 r
.35799 .78133 m .36035 .7791 L .35836 .77945 L F
.445 0 0 r
.54059 .84796 m .5395 .8472 L .53786 .84621 L F
.83 .505 .439 r
.55914 .77945 m .55723 .77883 L .55876 .7788 L F
.55914 .77945 m .5571 .78094 L .55723 .77883 L F
.759 .39 .356 r
.55914 .77945 m .55797 .7827 L .5571 .78094 L F
.547 .385 .613 r
.56254 .77869 m .55914 .77945 L .55876 .7788 L F
.56254 .77869 m .56304 .78111 L .55914 .77945 L F
.286 0 .174 r
.55956 .78186 m .55914 .77945 L .56304 .78111 L F
.55956 .78186 m .55797 .7827 L .55914 .77945 L F
0 0 0 r
.49626 .8652 m .49408 .86814 L .49542 .86723 L F
.811 .776 .821 r
.49312 .86994 m .49542 .86723 L .49408 .86814 L F
.752 .402 .391 r
.44636 .87095 m .44487 .87307 L .44345 .87117 L F
.671 .236 .207 r
.44345 .87117 m .44575 .8719 L .44636 .87095 L F
0 0 0 r
.44636 .87095 m .44575 .8719 L .44756 .87051 L F
.668 .667 .84 r
.33001 .6622 m .33102 .6617 L .32976 .66176 L F
.6 .734 .939 r
.52605 .82627 m .52383 .82652 L .52289 .82527 L F
.565 .435 .662 r
.52383 .82652 m .52628 .82802 L .52605 .82627 L F
.52383 .82652 m .52408 .82863 L .52628 .82802 L F
.52383 .82652 m .52628 .82802 L .52605 .82627 L F
.52383 .82652 m .52408 .82863 L .52628 .82802 L F
.388 .167 .453 r
.61179 .80803 m .61389 .80513 L .61415 .80752 L F
.383 .185 .484 r
.61389 .80513 m .61546 .80306 L .61622 .80503 L F
.374 .151 .441 r
.61415 .80752 m .61389 .80513 L .61622 .80503 L F
.809 .772 .818 r
.65236 .75805 m .65563 .756 L .65574 .75849 L F
.646 .598 .787 r
.6568 .75266 m .65563 .756 L .65498 .75373 L F
.6568 .75266 m .6578 .75573 L .65563 .756 L F
.533 .185 .322 r
.65563 .756 m .65706 .75789 L .65574 .75849 L F
.65563 .756 m .6578 .75573 L .65706 .75789 L F
.599 .253 .354 r
.49815 .82609 m .50133 .82412 L .4981 .82355 L F
.49815 .82609 m .5003 .82628 L .50133 .82412 L F
.706 .37 .407 r
.5003 .82628 m .50357 .8263 L .50133 .82412 L F
.25 .197 .6 r
.60337 .80273 m .60483 .80468 L .60478 .80244 L F
0 0 0 r
.59474 .84647 m .59598 .84495 L .59743 .844 L F
.373 .832 .912 r
.51061 .88066 m .51375 .88027 L .51271 .88049 L F
0 0 0 r
.51271 .88049 m .51375 .88027 L .51502 .88013 L F
.775 .792 .867 r
.63386 .73688 m .63745 .73699 L .63629 .73512 L F
.63386 .73688 m .63518 .73779 L .63745 .73699 L F
.84 .863 .86 r
.63629 .73512 m .63745 .73699 L .63932 .73454 L F
0 0 0 r
.52038 .87618 m .51839 .87645 L .51694 .87674 L F
.766 .728 .817 r
.52751 .83213 m .53036 .8317 L .52843 .82932 L F
.505 .886 .966 r
.52751 .83213 m .53036 .8317 L .52966 .83134 L F
.279 0 0 r
.52751 .83213 m .52593 .83305 L .52966 .83134 L F
.601 .952 .85 r
.52966 .83134 m .52593 .83305 L .52902 .83124 L F
.856 .424 0 r
.52843 .82932 m .53013 .83142 L .52966 .83134 L F
.095 .264 .747 r
.52843 .82932 m .52966 .83134 L .53037 .83045 L F
.601 .952 .85 r
.52966 .83134 m .52902 .83124 L .53037 .83045 L F
.856 .424 0 r
.53013 .83142 m .53036 .8317 L .52966 .83134 L F
.636 .349 .466 r
.53036 .8317 m .53244 .83366 L .53024 .83333 L F
.443 .516 .838 r
.69074 .71028 m .68913 .71175 L .68799 .70895 L F
.466 .554 .862 r
.69074 .71028 m .69081 .71185 L .68913 .71175 L F
.745 .581 .672 r
.3857 .73262 m .38214 .73343 L .38353 .73287 L F
.134 0 0 r
.38622 .73237 m .3857 .73262 L .38353 .73287 L F
.607 .381 .548 r
.59886 .75793 m .60083 .75789 L .60091 .75583 L F
.514 .305 .533 r
.60091 .75583 m .60287 .75743 L .60304 .75548 L F
.60091 .75583 m .60083 .75789 L .60287 .75743 L F
.52 .262 .465 r
.37136 .85251 m .37332 .85182 L .37428 .85002 L F
.703 .482 .585 r
.37332 .85182 m .37644 .84998 L .37428 .85002 L F
.485 .244 .473 r
.36029 .77675 m .36222 .77638 L .36263 .77422 L F
.502 .256 .475 r
.36222 .77638 m .36461 .77387 L .36263 .77422 L F
.553 .319 .515 r
.60547 .76608 m .60312 .76807 L .60326 .76632 L F
.614 .576 .788 r
.42549 .86524 m .42354 .86608 L .42272 .86336 L F
.511 .4 .663 r
.42549 .86524 m .42421 .86844 L .42354 .86608 L F
.55 .281 .46 r
.37515 .78196 m .37448 .78454 L .3724 .78462 L F
.537 .296 .497 r
.37709 .7816 m .37448 .78454 L .37515 .78196 L F
.398 .219 .519 r
.61132 .81039 m .61179 .80803 L .61415 .80752 L F
.539 .238 .405 r
.60047 .76914 m .59792 .77092 L .59821 .76941 L F
.658 .643 .823 r
.51256 .84066 m .51011 .83945 L .51189 .83967 L F
0 .291 .78 r
.51189 .83967 m .5141 .84126 L .51256 .84066 L F
.6 .54 .76 r
.5141 .84126 m .51285 .84378 L .51256 .84066 L F
.798 .303 0 r
.55662 .78968 m .55967 .79239 L .55861 .78997 L F
.55662 .78968 m .55849 .792 L .55967 .79239 L F
0 0 .417 r
.55849 .792 m .55903 .79457 L .55967 .79239 L F
.724 .623 .745 r
.55861 .78997 m .55967 .79239 L .56189 .7898 L F
.374 .006 .205 r
.68278 .74559 m .67951 .74744 L .68066 .74607 L F
.647 .174 .117 r
.42171 .73742 m .42412 .73849 L .42532 .73768 L F
.824 .953 .901 r
.42794 .7378 m .42785 .73609 L .42927 .73676 L F
.42794 .7378 m .4264 .73736 L .42785 .73609 L F
.13 .067 .512 r
.42785 .73609 m .42715 .73753 L .42927 .73676 L F
.42715 .73753 m .42671 .73844 L .42789 .73767 L F
.42715 .73753 m .42789 .73767 L .42927 .73676 L F
.42715 .73753 m .42752 .73888 L .42671 .73844 L F
.42785 .73609 m .42769 .73745 L .42715 .73753 L F
.42769 .73745 m .42752 .73888 L .42715 .73753 L F
0 0 0 r
.42532 .73768 m .42636 .73737 L .427 .73755 L F
.42581 .7377 m .427 .73755 L .42794 .7378 L F
.42532 .73768 m .427 .73755 L .42581 .7377 L F
.42636 .73737 m .4264 .73736 L .42661 .73742 L F
.42636 .73737 m .42661 .73742 L .42794 .7378 L F
.384 .115 .377 r
.42671 .73844 m .42493 .73916 L .42532 .73768 L F
0 0 0 r
.42532 .73768 m .42412 .73849 L .4264 .73736 L F
.238 0 0 r
.52881 .8065 m .53219 .80604 L .53009 .80625 L F
.413 .125 .363 r
.37036 .78491 m .36992 .78669 L .36789 .78707 L F
.498 .2 .392 r
.37191 .78626 m .37036 .78491 L .3724 .78462 L F
.37191 .78626 m .36992 .78669 L .37036 .78491 L F
.719 .761 .886 r
.40427 .75243 m .40096 .75227 L .40317 .75197 L F
.296 .709 .974 r
.40491 .75177 m .40427 .75243 L .40317 .75197 L F
.538 .681 .931 r
.40668 .75232 m .40427 .75243 L .40597 .75237 L F
.296 .709 .974 r
.40491 .75177 m .40597 .75237 L .40427 .75243 L F
.536 .797 .993 r
.44652 .86059 m .4442 .86096 L .44278 .85999 L F
.44652 .86059 m .4442 .86096 L .44278 .85999 L F
.703 .482 .585 r
.37332 .85182 m .37633 .85231 L .37644 .84998 L F
.634 .473 .647 r
.37857 .84735 m .37644 .84998 L .37866 .84975 L F
.678 .495 .631 r
.37633 .85231 m .37866 .84975 L .37644 .84998 L F
.785 .474 .462 r
.40705 .82898 m .40396 .82646 L .40508 .82955 L F
.618 .451 .635 r
.37866 .84975 m .38079 .84715 L .37857 .84735 L F
.945 .779 .319 r
.56375 .82816 m .5643 .8264 L .56404 .82904 L F
.836 .489 0 r
.56315 .82363 m .5643 .8264 L .56385 .82584 L F
.964 .769 .328 r
.56385 .82584 m .5643 .8264 L .56375 .82816 L F
.43 .517 .846 r
.38859 .73698 m .38772 .73852 L .38657 .73761 L F
.38859 .73698 m .38985 .73962 L .38772 .73852 L F
0 0 0 r
.64508 .77152 m .64679 .77071 L .64661 .77095 L F
.64395 .77282 m .64508 .77152 L .64661 .77095 L F
.225 0 .284 r
.59495 .82055 m .59557 .81863 L .59337 .82123 L F
.34 .186 .521 r
.59495 .82055 m .59337 .82123 L .59326 .82358 L F
.743 .823 .914 r
.57129 .83178 m .57398 .83124 L .57131 .82952 L F
.775 .824 .89 r
.57131 .82952 m .57398 .83124 L .57567 .82897 L F
.441 0 0 r
.5673 .84803 m .56861 .84816 L .57042 .84924 L F
.455 0 0 r
.56861 .84816 m .57156 .84949 L .57042 .84924 L F
.91 .84 .764 r
.56374 .77913 m .56254 .77869 L .56383 .77635 L F
.807 .475 0 r
.56381 .78199 m .56254 .77869 L .56374 .77913 L F
.819 .9 .898 r
.68401 .71177 m .68071 .71318 L .68276 .71067 L F
.766 .7 .789 r
.68316 .70873 m .68401 .71177 L .68276 .71067 L F
.68316 .70873 m .68584 .70933 L .68401 .71177 L F
.285 0 .14 r
.53306 .83529 m .53302 .83597 L .53108 .83617 L F
0 0 0 r
.61708 .7558 m .61627 .75746 L .61489 .75839 L F
.262 0 .277 r
.61623 .75975 m .61489 .75839 L .61627 .75746 L F
.61623 .75975 m .61458 .76051 L .61489 .75839 L F
.538 .151 .254 r
.58546 .77235 m .58745 .77332 L .58504 .77348 L F
.504 .225 .424 r
.58733 .77171 m .58745 .77332 L .58546 .77235 L F
.203 0 0 r
.48157 .8756 m .48485 .87586 L .48289 .87559 L F
.957 .737 .564 r
.48157 .8756 m .48289 .87559 L .48195 .87332 L F
.14 .661 .884 r
.44646 .88622 m .44973 .88668 L .44851 .88632 L F
.331 .682 .979 r
.44973 .88668 m .45053 .88589 L .44851 .88632 L F
.44973 .88668 m .45191 .88692 L .45053 .88589 L F
0 0 .01 r
.61751 .78204 m .61889 .7814 L .61964 .77945 L F
.669 .919 .607 r
.61694 .78385 m .61889 .7814 L .61751 .78204 L F
.329 .087 .387 r
.61303 .78706 m .61078 .78991 L .61289 .78919 L F
.329 .047 .324 r
.61289 .78919 m .61475 .78641 L .61303 .78706 L F
.568 .849 .997 r
.66778 .76224 m .66883 .76089 L .66609 .76111 L F
.66778 .76224 m .67004 .76164 L .66883 .76089 L F
.909 .874 .441 r
.66942 .73218 m .66885 .73317 L .66978 .72944 L F
.973 .849 .449 r
.66942 .73218 m .66895 .73518 L .66885 .73317 L F
.66942 .73218 m .66895 .73518 L .66885 .73317 L F
.481 .457 .754 r
.38214 .73343 m .38331 .73646 L .38097 .7358 L F
.662 .517 .676 r
.43376 .81336 m .43367 .81578 L .43162 .81561 L F
.779 .791 .863 r
.5357 .83397 m .5381 .83184 L .53532 .83189 L F
.214 0 0 r
.5381 .83184 m .53437 .83307 L .53532 .83189 L F
.937 .724 .588 r
.6728 .74792 m .67141 .74769 L .67168 .74516 L F
.955 .658 .224 r
.6728 .74792 m .67255 .74987 L .67141 .74769 L F
.589 .758 .959 r
.67486 .74767 m .67329 .75071 L .6728 .74792 L F
.422 .298 .606 r
.61289 .78919 m .61078 .78991 L .61099 .79213 L F
.873 .98 .841 r
.50411 .87388 m .50121 .87604 L .50302 .87295 L F
.471 .745 .989 r
.50597 .87376 m .50411 .87388 L .50302 .87295 L F
.707 .88 .961 r
.5781 .84111 m .5755 .84141 L .57672 .84008 L F
.722 .964 .94 r
.57983 .83913 m .5781 .84111 L .57672 .84008 L F
.57983 .83913 m .58087 .83948 L .5781 .84111 L F
.571 .403 .616 r
.40489 .83146 m .40705 .82898 L .40508 .82955 L F
0 0 0 r
.6158 .78506 m .61475 .78641 L .61694 .78385 L F
.739 .478 .535 r
.46187 .84697 m .46022 .8443 L .46184 .84493 L F
.562 .29 .461 r
.58838 .76348 m .59058 .76326 L .59136 .76087 L F
.609 .337 .479 r
.59136 .76087 m .59344 .76265 L .59358 .76089 L F
.59136 .76087 m .59058 .76326 L .59344 .76265 L F
.472 .251 .497 r
.54111 .81878 m .54087 .82082 L .54305 .81836 L F
.432 0 0 r
.47707 .87244 m .47855 .87152 L .47648 .8713 L F
.35 .195 .525 r
.59686 .8155 m .59557 .81863 L .59638 .81765 L F
0 0 0 r
.59638 .81765 m .59557 .81863 L .59495 .82055 L F
.014 0 0 r
.61964 .77945 m .6213 .77887 L .62118 .77838 L F
.004 0 .045 r
.61964 .77945 m .6204 .78024 L .6213 .77887 L F
.61964 .77945 m .61889 .7814 L .6204 .78024 L F
.674 .278 .288 r
.53219 .80604 m .53416 .80764 L .53491 .80587 L F
.689 .295 .295 r
.53491 .80587 m .53416 .80764 L .5372 .80765 L F
.705 .208 .06 r
.53491 .80587 m .5372 .80765 L .53877 .80764 L F
.543 .2 .337 r
.46266 .82579 m .4648 .82582 L .46592 .82346 L F
.593 .253 .362 r
.46592 .82346 m .46799 .82496 L .46806 .82344 L F
.46592 .82346 m .4648 .82582 L .46799 .82496 L F
.718 .572 .69 r
.38787 .83945 m .39024 .83937 L .38998 .83677 L F
.639 .513 .694 r
.38998 .83677 m .39024 .83937 L .39218 .8367 L F
.485 .168 .353 r
.50662 .83073 m .50378 .82988 L .508 .82895 L F
.14 0 0 r
.50839 .83013 m .508 .82895 L .50991 .82868 L F
.50839 .83013 m .50662 .83073 L .508 .82895 L F
0 .45 .732 r
.53685 .85088 m .54031 .85183 L .53916 .85118 L F
.401 .623 .942 r
.54031 .85183 m .54092 .85094 L .53916 .85118 L F
.54031 .85183 m .54237 .85225 L .54092 .85094 L F
.507 .334 .581 r
.41161 .75048 m .41161 .75278 L .40968 .75302 L F
.551 .368 .587 r
.41161 .75278 m .40944 .75539 L .40968 .75302 L F
.54 .49 .748 r
.47129 .84207 m .47089 .8443 L .47039 .84208 L F
.47129 .84207 m .47235 .84438 L .47089 .8443 L F
.589 .585 .816 r
.53798 .8421 m .53889 .83884 L .53739 .83917 L F
.53798 .8421 m .54015 .84201 L .53889 .83884 L F
.661 .586 .761 r
.34369 .72537 m .34531 .72431 L .34339 .72444 L F
.551 .304 .495 r
.39648 .83629 m .39472 .83451 L .3943 .83647 L F
.39648 .83629 m .39673 .83424 L .39472 .83451 L F
.674 .815 .951 r
.66537 .75536 m .66626 .75633 L .66366 .75641 L F
.807 .475 0 r
.56381 .78199 m .56347 .78184 L .56254 .77869 L F
.53 .877 .987 r
.56356 .78529 m .56498 .78449 L .56381 .78199 L F
.91 .686 .586 r
.56498 .78449 m .56347 .78184 L .56381 .78199 L F
.194 .724 .802 r
.57817 .84974 m .58067 .84943 L .57982 .84946 L F
.117 0 0 r
.58067 .84943 m .58202 .84952 L .57982 .84946 L F
.58067 .84943 m .58263 .84929 L .58202 .84952 L F
.194 .724 .802 r
.57817 .84974 m .57982 .84946 L .57768 .84985 L F
.64 .863 .491 r
.59885 .81282 m .59686 .8155 L .59879 .81509 L F
0 0 .111 r
.60079 .8101 m .59885 .81282 L .59991 .81217 L F
0 0 .192 r
.59991 .81217 m .59885 .81282 L .59879 .81509 L F
0 0 0 r
.47796 .84923 m .47707 .85008 L .47917 .84999 L F
.47796 .84923 m .47618 .8518 L .47707 .85008 L F
.582 .514 .744 r
.39952 .74758 m .39832 .75104 L .39747 .74798 L F
.39952 .74758 m .40037 .75067 L .39832 .75104 L F
.618 .791 .965 r
.43559 .87375 m .43338 .8743 L .43232 .87334 L F
.664 .299 .343 r
.58759 .83624 m .58824 .83453 L .5879 .83483 L F
.091 0 .1 r
.58956 .83421 m .58824 .83453 L .58759 .83624 L F
.535 .327 .544 r
.65574 .75849 m .6536 .76104 L .65236 .75805 L F
.65574 .75849 m .65576 .76066 L .6536 .76104 L F
.6536 .76104 m .65576 .76066 L .65574 .75849 L F
.555 .31 .499 r
.65576 .76066 m .65809 .75839 L .65574 .75849 L F
.058 0 .422 r
.65706 .75789 m .65576 .76066 L .65574 .75849 L F
0 0 .115 r
.65592 .75997 m .65574 .75849 L .65706 .75789 L F
.65592 .75997 m .65576 .76066 L .65574 .75849 L F
.565 .937 .841 r
.65342 .7542 m .65219 .75532 L .65217 .75521 L F
.65342 .7542 m .65498 .75373 L .65219 .75532 L F
.279 .782 .82 r
.38572 .90073 m .39012 .89995 L .38864 .89958 L F
.361 .805 .657 r
.39105 .89941 m .39012 .89995 L .39205 .89893 L F
.334 .782 .956 r
.38864 .89958 m .39012 .89995 L .39105 .89941 L F
.72 .49 .577 r
.4324 .8551 m .42887 .85735 L .42889 .85515 L F
.4324 .8551 m .43227 .85707 L .42887 .85735 L F
.626 .409 .568 r
.4324 .8551 m .43423 .85727 L .43227 .85707 L F
.716 .412 .461 r
.43461 .85559 m .43423 .85727 L .4324 .8551 L F
.892 .787 .738 r
.53599 .81895 m .53291 .82077 L .53463 .81815 L F
.53599 .81895 m .53479 .82102 L .53291 .82077 L F
.23 .742 .874 r
.50237 .83142 m .50448 .8312 L .50579 .83135 L F
.392 .839 .93 r
.50579 .83135 m .50448 .8312 L .50662 .83073 L F
.257 .625 .96 r
.50662 .83073 m .50785 .83177 L .50579 .83135 L F
.444 .148 .367 r
.48121 .8188 m .48069 .82039 L .48309 .81839 L F
.567 .151 .213 r
.43965 .87214 m .44345 .87117 L .44121 .87197 L F
0 .158 .695 r
.57171 .84089 m .57143 .8406 L .57161 .84045 L F
.57143 .8406 m .57028 .8394 L .57161 .84045 L F
.57171 .84089 m .5713 .83904 L .57127 .84102 L F
.706 .762 .896 r
.57334 .83838 m .57171 .84089 L .57127 .84102 L F
0 0 0 r
.57238 .8398 m .57127 .84102 L .57218 .8401 L F
.57334 .83838 m .57191 .8402 L .57238 .8398 L F
.57191 .8402 m .57127 .84102 L .57238 .8398 L F
0 .158 .695 r
.57161 .84045 m .57028 .8394 L .5713 .83904 L F
.478 .145 .324 r
.58323 .76626 m .58519 .76604 L .58616 .76368 L F
.568 .236 .365 r
.58616 .76368 m .58826 .76512 L .58838 .76348 L F
.58616 .76368 m .58519 .76604 L .58826 .76512 L F
.933 .845 .734 r
.62299 .74748 m .62568 .74531 L .62433 .7444 L F
.62299 .74748 m .62428 .74826 L .62568 .74531 L F
.537 .543 .808 r
.62568 .74531 m .62656 .7419 L .62433 .7444 L F
.62568 .74531 m .62769 .74489 L .62656 .7419 L F
.625 .922 .975 r
.43028 .8885 m .4338 .88779 L .43167 .88784 L F
.569 .88 .992 r
.4338 .88779 m .43471 .8867 L .43167 .88784 L F
.4338 .88779 m .4359 .88717 L .43471 .8867 L F
.729 .412 .444 r
.57046 .78387 m .56711 .78353 L .56825 .78155 L F
.57046 .78387 m .56955 .78449 L .56711 .78353 L F
.604 .61 .831 r
.56711 .78353 m .56955 .78449 L .56904 .78286 L F
.847 .997 .775 r
.56536 .78415 m .56825 .78155 L .56711 .78353 L F
0 0 0 r
.56929 .78048 m .56922 .78089 L .56825 .78155 L F
.57083 .77891 m .56922 .78089 L .56929 .78048 L F
.527 .562 .834 r
.56829 .7805 m .56916 .78118 L .56922 .78089 L F
.729 .412 .444 r
.57046 .78387 m .56825 .78155 L .56922 .78089 L F
.798 .643 .69 r
.57358 .78412 m .57046 .78387 L .57283 .78077 L F
.814 .668 .702 r
.57283 .78077 m .57046 .78387 L .56922 .78089 L F
.527 .562 .834 r
.56916 .78118 m .57156 .78306 L .56922 .78089 L F
.604 .61 .831 r
.56711 .78353 m .56904 .78286 L .56829 .7805 L F
.847 .997 .775 r
.56498 .78449 m .56536 .78415 L .56711 .78353 L F
.803 .966 .91 r
.62069 .73692 m .62259 .73437 L .62311 .73467 L F
.62069 .73692 m .61965 .73645 L .62259 .73437 L F
0 0 0 r
.61949 .75382 m .61827 .75488 L .61708 .7558 L F
.591 .404 .597 r
.61827 .75488 m .61627 .75746 L .61708 .7558 L F
0 0 0 r
.52062 .82625 m .52289 .82527 L .52138 .82408 L F
.696 .528 .656 r
.59089 .76894 m .59184 .77166 L .58733 .77171 L F
.723 .542 .645 r
.59202 .77109 m .59089 .76894 L .59279 .76888 L F
.59202 .77109 m .59184 .77166 L .59089 .76894 L F
.929 .887 .77 r
.49454 .82317 m .49373 .82631 L .49602 .82632 L F
.49454 .82317 m .49259 .82644 L .49373 .82631 L F
.479 0 0 r
.49259 .82644 m .49602 .82632 L .49373 .82631 L F
0 .231 .742 r
.56404 .82904 m .56537 .83175 L .56506 .83105 L F
.962 .635 .338 r
.56537 .83175 m .56485 .83348 L .56506 .83105 L F
.56537 .83175 m .56598 .83418 L .56485 .83348 L F
.479 .244 .48 r
.36931 .78881 m .36789 .78707 L .36992 .78669 L F
.36931 .78881 m .36756 .78958 L .36789 .78707 L F
.753 .59 .674 r
.4747 .84171 m .47235 .84438 L .47129 .84207 L F
.672 .398 .498 r
.41957 .82438 m .41981 .82547 L .42282 .82532 L F
.745 .44 .467 r
.43741 .85734 m .43461 .85559 L .43689 .85536 L F
.43741 .85734 m .43423 .85727 L .43461 .85559 L F
.159 0 .171 r
.59879 .81509 m .59686 .8155 L .59638 .81765 L F
.532 .461 .722 r
.49161 .8166 m .49361 .81743 L .49444 .81532 L F
.394 0 .015 r
.36435 .74837 m .36083 .74981 L .36218 .74839 L F
.274 .645 .966 r
.48155 .88492 m .48202 .88399 L .48056 .88354 L F
.48155 .88492 m .4843 .88555 L .48202 .88399 L F
.822 .977 .89 r
.35233 .72762 m .35309 .72573 L .35421 .72706 L F
.477 .205 .423 r
.35538 .78402 m .35799 .78133 L .35599 .78196 L F
.035 .297 .788 r
.64918 .7605 m .64942 .76025 L .64837 .76042 L F
.507 .108 .218 r
.49814 .86582 m .49626 .8652 L .49542 .86723 L F
.546 .36 .579 r
.50245 .82901 m .50448 .8312 L .50237 .83142 L F
.77 .281 .064 r
.50378 .82988 m .50448 .8312 L .50245 .82901 L F
.553 .886 .987 r
.6758 .73124 m .6746 .73236 L .67313 .73051 L F
.6758 .73124 m .67674 .73169 L .6746 .73236 L F
.485 .168 .353 r
.50662 .83073 m .50448 .8312 L .50378 .82988 L F
.843 .773 .784 r
.49696 .82102 m .50075 .81961 L .49907 .81956 L F
.49696 .82102 m .49852 .82261 L .50075 .81961 L F
.44 0 .076 r
.50228 .81827 m .49907 .81956 L .50075 .81961 L F
.557 .41 .638 r
.36035 .7791 m .36222 .77638 L .36029 .77675 L F
.527 .224 .397 r
.40705 .76024 m .40553 .75883 L .40724 .7581 L F
.40705 .76024 m .40506 .76056 L .40553 .75883 L F
.029 .599 .758 r
.5464 .8362 m .54961 .83633 L .54739 .83629 L F
.415 .53 .866 r
.55041 .8389 m .54739 .83629 L .54961 .83633 L F
.952 .887 .731 r
.56189 .7898 m .56093 .78917 L .56242 .78661 L F
.641 .784 .95 r
.48508 .88668 m .48595 .88505 L .4843 .88555 L F
.48508 .88668 m .48717 .88606 L .48595 .88505 L F
0 0 .27 r
.55228 .8248 m .55181 .82513 L .55189 .82379 L F
0 0 .53 r
.55266 .82658 m .55181 .82513 L .55228 .8248 L F
.24 .307 .732 r
.55372 .82915 m .55181 .82513 L .55266 .82658 L F
.611 .472 .667 r
.4247 .86262 m .42236 .861 L .42478 .86058 L F
.4247 .86262 m .42272 .86336 L .42236 .861 L F
.501 .093 .199 r
.59558 .77337 m .59259 .77457 L .59423 .77452 L F
.778 .528 .558 r
.46022 .8443 m .45636 .8464 L .45687 .84446 L F
.46022 .8443 m .4587 .8469 L .45636 .8464 L F
.739 .478 .535 r
.46187 .84697 m .4587 .8469 L .46022 .8443 L F
.467 0 0 r
.50903 .83952 m .50902 .8396 L .50774 .83821 L F
.50982 .84032 m .51096 .84095 L .50902 .8396 L F
.50982 .84032 m .50902 .8396 L .50903 .83952 L F
.19 .72 .746 r
.50902 .83965 m .50902 .8396 L .51011 .83945 L F
.50704 .84002 m .50902 .8396 L .50902 .83965 L F
.649 .233 .242 r
.50902 .8396 m .51189 .83967 L .51011 .83945 L F
.764 .645 .73 r
.42861 .87024 m .42764 .86737 L .42927 .86831 L F
.563 .527 .773 r
.4301 .86505 m .42927 .86831 L .42764 .86737 L F
.4301 .86505 m .43143 .86805 L .42927 .86831 L F
.493 .216 .422 r
.43143 .86805 m .42861 .87024 L .42927 .86831 L F
.584 .522 .751 r
.44053 .84728 m .43858 .84797 L .4374 .8444 L F
.556 .348 .553 r
.39106 .77113 m .38885 .77352 L .38906 .77145 L F
.208 .011 .379 r
.53476 .81349 m .53502 .81278 L .53324 .81264 L F
.53476 .81349 m .53594 .81514 L .53502 .81278 L F
.53476 .81349 m .53378 .81633 L .53594 .81514 L F
.594 .777 .968 r
.44989 .87399 m .44613 .87334 L .44796 .87409 L F
.812 .959 .908 r
.44989 .87399 m .45041 .87209 L .45146 .87194 L F
.44989 .87399 m .44796 .87409 L .45041 .87209 L F
.915 .734 .643 r
.66975 .71952 m .66914 .72154 L .66807 .71857 L F
.654 .496 .656 r
.48389 .87101 m .48598 .86799 L .48318 .86786 L F
.792 .798 .857 r
.63173 .73926 m .63518 .73779 L .63386 .73688 L F
.564 .405 .624 r
.49927 .81421 m .49593 .81298 L .49751 .81375 L F
.622 .194 .208 r
.49751 .81375 m .50104 .81353 L .49927 .81421 L F
.432 .702 .978 r
.57736 .82602 m .57671 .82637 L .57455 .82486 L F
.707 .405 .464 r
.55729 .79091 m .55849 .792 L .55662 .78968 L F
.284 0 .137 r
.62396 .77669 m .62166 .77762 L .62118 .77838 L F
.715 .555 .671 r
.37117 .8548 m .37332 .85182 L .37136 .85251 L F
.653 .434 .574 r
.38777 .84201 m .39024 .83937 L .38787 .83945 L F
.38777 .84201 m .39009 .84171 L .39024 .83937 L F
.637 .511 .693 r
.39024 .83937 m .39255 .8393 L .39218 .8367 L F
.642 .436 .589 r
.39009 .84171 m .39255 .8393 L .39024 .83937 L F
.544 .321 .527 r
.361 .79254 m .3608 .79471 L .35865 .79494 L F
.403 .203 .492 r
.36243 .79414 m .361 .79254 L .36298 .79241 L F
.36243 .79414 m .3608 .79471 L .361 .79254 L F
.397 .211 .509 r
.61546 .80306 m .61824 .80001 L .61803 .80218 L F
.369 .177 .484 r
.61622 .80503 m .61546 .80306 L .61803 .80218 L F
.498 .253 .473 r
.42421 .86844 m .42364 .87063 L .42156 .87081 L F
.764 .645 .73 r
.42861 .87024 m .42663 .87026 L .42764 .86737 L F
.511 .4 .663 r
.42549 .86524 m .42694 .86874 L .42421 .86844 L F
.559 .31 .495 r
.42575 .87026 m .42421 .86844 L .42694 .86875 L F
.764 .645 .73 r
.42663 .87026 m .42575 .87026 L .42694 .86875 L F
.559 .31 .495 r
.42575 .87026 m .42694 .86875 L .42694 .86875 L F
.764 .645 .73 r
.42663 .87026 m .42702 .86832 L .42764 .86737 L F
.601 .446 .643 r
.42764 .86737 m .42694 .86875 L .42694 .86874 L F
.42764 .86737 m .42694 .86874 L .42549 .86524 L F
.764 .645 .73 r
.42694 .86874 m .42575 .87026 L .42702 .86832 L F
.42694 .86875 m .42693 .86875 L .42694 .86874 L F
.42693 .86875 m .42575 .87026 L .42694 .86874 L F
.511 .4 .663 r
.42694 .86874 m .42694 .86875 L .42694 .86875 L F
.42694 .86874 m .42694 .86875 L .42421 .86844 L F
.559 .31 .495 r
.42575 .87026 m .42364 .87063 L .42421 .86844 L F
0 0 .364 r
.45831 .86764 m .45821 .86836 L .45919 .86885 L F
0 0 .255 r
.45821 .86836 m .45837 .87056 L .45919 .86885 L F
.601 .259 .363 r
.44667 .82849 m .44908 .82853 L .45001 .82648 L F
.659 .321 .39 r
.45001 .82648 m .44908 .82853 L .45196 .82836 L F
.612 .332 .468 r
.45001 .82648 m .45196 .82836 L .45214 .8265 L F
.676 .614 .779 r
.50228 .81827 m .50349 .82143 L .50542 .82027 L F
0 0 .305 r
.60502 .83546 m .60411 .83417 L .60574 .8335 L F
.60502 .83546 m .60372 .8363 L .60411 .83417 L F
.579 .473 .698 r
.39952 .74758 m .39729 .74626 L .39948 .74555 L F
.39952 .74758 m .39747 .74798 L .39729 .74626 L F
.404 0 0 r
.49096 .86945 m .48906 .86834 L .48721 .86915 L F
.614 .439 .622 r
.40944 .75539 m .40724 .7581 L .40739 .7558 L F
.676 .237 0 r
.56736 .80492 m .56826 .80623 L .56829 .80608 L F
.945 .821 .691 r
.56857 .80807 m .5683 .80605 L .56829 .80608 L F
0 .322 .809 r
.56924 .80768 m .56857 .80807 L .56829 .80608 L F
.676 .237 0 r
.56826 .80623 m .56924 .80768 L .56829 .80608 L F
.945 .821 .691 r
.5683 .80605 m .56818 .80519 L .56829 .80608 L F
0 .322 .809 r
.56924 .80768 m .57109 .80992 L .56857 .80807 L F
.654 .155 .052 r
.456 .86507 m .45454 .86543 L .45261 .86454 L F
.42 0 0 r
.456 .86507 m .45705 .86582 L .45454 .86543 L F
.456 .86507 m .45836 .86624 L .45705 .86582 L F
.571 .403 .616 r
.40489 .83146 m .40699 .83133 L .40705 .82898 L F
.689 .506 .634 r
.40483 .83361 m .40699 .83133 L .40489 .83146 L F
.42 .829 .975 r
.57871 .8491 m .57768 .84985 L .57982 .84946 L F
.436 .858 .95 r
.57659 .84961 m .57768 .84985 L .57871 .8491 L F
.77 .716 .802 r
.42809 .87586 m .42484 .87582 L .42677 .87344 L F
.735 .774 .884 r
.42896 .873 m .42809 .87586 L .42677 .87344 L F
.42896 .873 m .42987 .87503 L .42809 .87586 L F
.647 .396 .526 r
.41453 .82827 m .41658 .8285 L .41471 .8263 L F
.683 .397 .482 r
.41471 .8263 m .41658 .8285 L .41691 .82663 L F
.357 0 .014 r
.52873 .83512 m .5274 .8363 L .52479 .83648 L F
.118 0 0 r
.52919 .83577 m .52873 .83512 L .53024 .83333 L F
.52919 .83577 m .5274 .8363 L .52873 .83512 L F
.628 .586 .788 r
.52408 .82863 m .52691 .82961 L .52628 .82802 L F
.53 .169 .299 r
.52628 .82802 m .52269 .83058 L .52408 .82863 L F
.595 .648 .872 r
.54125 .83228 m .54434 .83423 L .54329 .83127 L F
.017 0 0 r
.54434 .83423 m .54084 .83549 L .54185 .83475 L F
.135 .269 .738 r
.54329 .83127 m .54434 .83423 L .54471 .83231 L F
.836 .956 .892 r
.54471 .83231 m .54434 .83423 L .54185 .83475 L F
.478 .312 .577 r
.68683 .7327 m .68686 .73444 L .68843 .73501 L F
.912 .571 .385 r
.68843 .73501 m .68733 .73598 L .68686 .73444 L F
.68843 .73501 m .68856 .7372 L .68733 .73598 L F
.478 .312 .577 r
.68686 .73444 m .68683 .7327 L .68843 .73501 L F
.533 .37 .606 r
.68686 .73444 m .68856 .7372 L .68843 .73501 L F
.595 .312 .457 r
.68843 .73501 m .69087 .73665 L .68856 .7372 L F
.107 0 0 r
.65426 .76795 m .65409 .76836 L .65241 .76845 L F
.117 0 0 r
.65241 .76845 m .65409 .76836 L .65199 .76905 L F
.787 .309 .095 r
.46507 .84931 m .46187 .84697 L .46531 .84744 L F
.493 .163 .336 r
.46775 .84757 m .46507 .84931 L .46531 .84744 L F
.002 .407 .853 r
.4926 .87728 m .49176 .8774 L .49014 .87656 L F
.4926 .87728 m .49343 .87833 L .49176 .8774 L F
.691 .526 .66 r
.38079 .84715 m .3837 .84717 L .38378 .84499 L F
.682 .551 .699 r
.38378 .84499 m .38585 .84464 L .38528 .84168 L F
.672 .51 .657 r
.3837 .84717 m .38585 .84464 L .38378 .84499 L F
.045 0 0 r
.3675 .74779 m .36643 .74813 L .36435 .74837 L F
0 0 0 r
.36828 .74771 m .3675 .74779 L .36954 .74742 L F
.36828 .74771 m .36643 .74813 L .3675 .74779 L F
.695 .328 .348 r
.53747 .80956 m .53877 .80764 L .5372 .80765 L F
.53747 .80956 m .5403 .80845 L .53877 .80764 L F
.766 .835 .905 r
.40543 .89318 m .41015 .8924 L .409 .89124 L F
.669 .731 .896 r
.409 .89124 m .41015 .8924 L .41225 .89176 L F
.884 .7 .648 r
.53532 .83633 m .53691 .83693 L .5357 .83397 L F
.618 .369 .519 r
.53691 .83693 m .53889 .83884 L .53943 .8366 L F
.413 .363 .693 r
.53691 .83693 m .53739 .83917 L .53889 .83884 L F
.523 .342 .577 r
.44082 .85644 m .43741 .85734 L .43689 .85536 L F
.571 .406 .618 r
.42363 .87267 m .42156 .87081 L .42364 .87063 L F
.42363 .87267 m .42165 .87312 L .42156 .87081 L F
.649 .302 .371 r
.44106 .82804 m .44345 .82834 L .44464 .82623 L F
.729 .396 .417 r
.44464 .82623 m .44345 .82834 L .44667 .82849 L F
.457 0 0 r
.46014 .86525 m .46317 .86541 L .46174 .86495 L F
.918 .713 .608 r
.46045 .86278 m .46014 .86525 L .46174 .86495 L F
.632 .473 .649 r
.42675 .86 m .42418 .85799 L .42686 .85788 L F
.42675 .86 m .42478 .86058 L .42418 .85799 L F
0 0 .27 r
.55228 .8248 m .55189 .82379 L .55176 .82299 L F
.355 .099 .381 r
.59792 .77092 m .59558 .77337 L .59595 .77147 L F
0 0 .384 r
.48863 .84206 m .4887 .84166 L .48844 .84132 L F
0 .124 .646 r
.48863 .84206 m .49075 .84399 L .4887 .84166 L F
.74 .554 .642 r
.52528 .87367 m .52775 .87503 L .5278 .87095 L F
.493 .352 .618 r
.5278 .87095 m .52985 .87369 L .52994 .87096 L F
.5278 .87095 m .52775 .87503 L .52985 .87369 L F
.875 .491 .018 r
.55969 .81528 m .55822 .81257 L .55977 .81339 L F
.65 .833 .971 r
.3597 .72736 m .35773 .72848 L .35616 .7273 L F
.635 .456 .624 r
.38528 .84168 m .38777 .84201 L .38787 .83945 L F
.695 .615 .763 r
.42165 .87312 m .42283 .87636 L .41952 .87516 L F
.604 .564 .783 r
.42484 .87582 m .42283 .87636 L .42165 .87312 L F
.865 .902 .857 r
.56727 .79435 m .56839 .79497 L .57065 .79245 L F
.623 .509 .703 r
.38585 .84464 m .38777 .84201 L .38528 .84168 L F
.646 .337 .434 r
.4533 .84215 m .45001 .84424 L .44982 .84218 L F
.4533 .84215 m .45315 .84427 L .45001 .84424 L F
.627 .32 .432 r
.45557 .84399 m .45315 .84427 L .4533 .84215 L F
.484 .193 .396 r
.382 .77686 m .38144 .77872 L .3794 .77906 L F
.503 .211 .403 r
.38348 .77836 m .382 .77686 L .38404 .77652 L F
.38348 .77836 m .38144 .77872 L .382 .77686 L F
.704 .546 .67 r
.50594 .84473 m .50356 .84718 L .50268 .84442 L F
.50594 .84473 m .50591 .84721 L .50356 .84718 L F
.65 .478 .638 r
.50813 .84456 m .50591 .84721 L .50594 .84473 L F
0 0 0 r
.54759 .8421 m .55041 .8389 L .54982 .84133 L F
.724 .367 .372 r
.55041 .8389 m .5529 .84138 L .54982 .84133 L F
.381 .022 .225 r
.37145 .76838 m .37312 .76788 L .3742 .76624 L F
.609 .271 .372 r
.37312 .76788 m .37594 .76797 L .3742 .76624 L F
.574 .276 .425 r
.3742 .76624 m .37594 .76797 L .37634 .76616 L F
.724 .986 .891 r
.62311 .73467 m .62338 .73326 L .62558 .73239 L F
.62311 .73467 m .62259 .73437 L .62338 .73326 L F
.788 .655 .716 r
.68506 .70843 m .68584 .70933 L .68316 .70873 L F
.623 .59 .796 r
.68685 .70596 m .68584 .70933 L .68506 .70843 L F
.68685 .70596 m .68799 .70895 L .68584 .70933 L F
.678 .225 .17 r
.53306 .83529 m .53532 .83633 L .53302 .83597 L F
.69 .252 .205 r
.53302 .83597 m .53532 .83633 L .53374 .83521 L F
.234 0 0 r
.65955 .76535 m .65937 .7661 L .65721 .76667 L F
.085 0 0 r
.65955 .76535 m .66123 .76513 L .65937 .7661 L F
.662 .679 .856 r
.56319 .79764 m .56063 .79868 L .56026 .79689 L F
.152 .282 .744 r
.45836 .86624 m .45831 .86764 L .45953 .86715 L F
0 0 .364 r
.45831 .86764 m .45919 .86885 L .45953 .86715 L F
.61 .305 .426 r
.4482 .84182 m .44668 .84412 L .44472 .84417 L F
.706 .421 .49 r
.4482 .84182 m .45001 .84424 L .44668 .84412 L F
.696 .42 .501 r
.44982 .84218 m .45001 .84424 L .4482 .84182 L F
0 0 .417 r
.55849 .792 m .55915 .79397 L .55903 .79457 L F
0 0 .544 r
.55915 .79397 m .56026 .79689 L .55903 .79457 L F
.489 .27 .508 r
.42211 .89158 m .42206 .89116 L .42516 .88958 L F
.493 .118 .256 r
.65743 .72966 m .65435 .73168 L .65572 .73076 L F
.887 .764 .72 r
.49696 .82102 m .4981 .82355 L .49852 .82261 L F
.973 .746 .534 r
.48416 .86314 m .48468 .86064 L .48369 .85928 L F
.824 .596 .594 r
.54297 .81586 m .54305 .81836 L .54117 .81705 L F
.794 .567 .593 r
.40806 .7522 m .41161 .75278 L .41161 .75048 L F
.475 .282 .538 r
.41355 .75015 m .41161 .75278 L .41161 .75048 L F
.41161 .75278 m .41355 .75015 L .41161 .75048 L F
.593 .589 .817 r
.57483 .81801 m .57406 .82107 L .57536 .81851 L F
.57483 .81801 m .57622 .82079 L .57406 .82107 L F
.381 .807 .969 r
.57406 .82107 m .5741 .82297 L .57375 .82251 L F
.57406 .82107 m .57622 .82079 L .57554 .82036 L F
.57406 .82107 m .57554 .82036 L .5741 .82297 L F
.967 .933 .689 r
.5741 .82297 m .57554 .82036 L .57371 .82223 L F
0 0 .396 r
.57371 .82223 m .57423 .82314 L .5741 .82297 L F
.57423 .82314 m .57527 .82493 L .5741 .82297 L F
.381 .807 .969 r
.57375 .82251 m .5741 .82297 L .57328 .82466 L F
.768 .753 .84 r
.63292 .72753 m .6301 .72754 L .6315 .72629 L F
.728 .71 .833 r
.63499 .72675 m .63292 .72753 L .6315 .72629 L F
.529 .467 .73 r
.3883 .75588 m .39022 .75556 L .38979 .75344 L F
.475 .254 .497 r
.3883 .75588 m .38814 .7579 L .39022 .75556 L F
.237 0 .292 r
.38579 .76054 m .38436 .76134 L .38363 .76316 L F
0 0 0 r
.45703 .88555 m .46257 .88401 L .45975 .88534 L F
.45975 .88534 m .46257 .88401 L .46455 .88344 L F
.689 .823 .948 r
.47189 .87067 m .47084 .87301 L .46944 .87223 L F
.47189 .87067 m .47316 .8721 L .47084 .87301 L F
.519 .253 .451 r
.59585 .76081 m .59809 .76045 L .59886 .75793 L F
.502 .237 .445 r
.59886 .75793 m .60029 .76003 L .60083 .75789 L F
.59886 .75793 m .59809 .76045 L .60029 .76003 L F
.518 .621 .894 r
.51731 .83335 m .5127 .83182 L .51664 .83138 L F
.747 .545 .621 r
.54555 .83932 m .54544 .8418 L .5423 .84213 L F
.802 .448 .386 r
.54555 .83932 m .54759 .8421 L .54544 .8418 L F
0 .058 .59 r
.65317 .75644 m .65217 .75521 L .65236 .75805 L F
.715 .928 .596 r
.65122 .75901 m .65317 .75644 L .65236 .75805 L F
.402 .468 .814 r
.4422 .84851 m .44158 .84983 L .44053 .84728 L F
0 0 .07 r
.4422 .84851 m .44137 .85216 L .44158 .84983 L F
.622 .636 .844 r
.65857 .7529 m .6578 .75573 L .6568 .75266 L F
.65857 .7529 m .6599 .75507 L .6578 .75573 L F
.416 .095 .312 r
.6578 .75573 m .65928 .75731 L .65706 .75789 L F
.6578 .75573 m .6599 .75507 L .65928 .75731 L F
.525 .26 .456 r
.35865 .79494 m .36012 .79656 L .35844 .79532 L F
.35865 .79494 m .3608 .79471 L .36012 .79656 L F
.679 .88 .973 r
.42516 .88958 m .42841 .88936 L .4271 .88878 L F
.667 .886 .978 r
.4271 .88878 m .42841 .88936 L .43028 .8885 L F
.743 .823 .914 r
.57129 .83178 m .57131 .82952 L .57134 .83225 L F
0 0 0 r
.57044 .83405 m .57134 .83225 L .5718 .83297 L F
.033 0 .453 r
.5707 .83621 m .57044 .83405 L .5718 .83297 L F
.5707 .83621 m .5718 .83297 L .57217 .83498 L F
.952 .602 .276 r
.57217 .83498 m .5718 .83297 L .57119 .83272 L F
0 0 0 r
.57044 .83405 m .57129 .83178 L .57134 .83221 L F
.952 .602 .276 r
.57112 .83299 m .57119 .83272 L .57093 .83262 L F
.57217 .83498 m .57119 .83272 L .57112 .83299 L F
0 0 0 r
.57131 .83231 m .57134 .83221 L .57134 .83225 L F
.57044 .83405 m .57134 .83221 L .57131 .83231 L F
.777 .459 .449 r
.50977 .81546 m .51116 .81886 L .5131 .81619 L F
0 0 0 r
.5131 .81619 m .5141 .81556 L .51514 .81561 L F
.5131 .81619 m .51116 .81886 L .5141 .81556 L F
.8 .748 .805 r
.49539 .87052 m .49776 .87092 L .49623 .86984 L F
.578 .733 .948 r
.49623 .86984 m .49776 .87092 L .49974 .87041 L F
.465 .284 .551 r
.60627 .80167 m .60486 .80016 L .60478 .80244 L F
.597 .457 .662 r
.60486 .80016 m .60732 .80008 L .60681 .79717 L F
.565 .29 .458 r
.60627 .80167 m .60732 .80008 L .60486 .80016 L F
.622 .465 .649 r
.50363 .83636 m .50388 .83884 L .50119 .8366 L F
0 0 0 r
.45407 .88646 m .45465 .88616 L .4571 .88555 L F
.808 .671 .713 r
.5192 .83136 m .51949 .83412 L .51731 .83335 L F
.795 .37 .238 r
.51949 .83412 m .51857 .83502 L .51731 .83335 L F
0 0 .52 r
.52021 .83314 m .51949 .83412 L .5192 .83136 L F
.599 .87 .539 r
.52021 .83314 m .51857 .83502 L .51949 .83412 L F
.088 .061 .528 r
.60819 .8228 m .60689 .82387 L .60707 .82046 L F
0 .062 .588 r
.60844 .82512 m .60689 .82387 L .60819 .8228 L F
.60844 .82512 m .60769 .82613 L .60689 .82387 L F
.725 .742 .865 r
.67987 .7216 m .68239 .71948 L .68304 .72174 L F
.705 .341 .356 r
.67987 .7216 m .68304 .72174 L .68099 .72378 L F
.629 .682 .881 r
.68239 .71948 m .68329 .71931 L .68304 .72174 L F
.958 .947 .693 r
.68304 .72174 m .68329 .71931 L .68099 .72378 L F
.594 .338 .498 r
.34685 .72726 m .3487 .72794 L .34895 .72682 L F
.329 0 0 r
.34555 .72927 m .3487 .72794 L .34685 .72726 L F
.584 .522 .751 r
.44053 .84728 m .4374 .8444 L .43949 .84424 L F
0 .535 .723 r
.37291 .74775 m .37129 .74757 L .36954 .74742 L F
.535 0 0 r
.37445 .7482 m .37129 .74757 L .37291 .74775 L F
.699 .463 .562 r
.60481 .75427 m .60758 .75275 L .60555 .7532 L F
.362 .828 .764 r
.51611 .82032 m .51517 .82056 L .51415 .82113 L F
.33 .762 .971 r
.51415 .82113 m .51517 .82056 L .51295 .82064 L F
.672 .51 .657 r
.3837 .84717 m .38604 .84705 L .38585 .84464 L F
.623 .509 .703 r
.38585 .84464 m .38802 .84438 L .38777 .84201 L F
.557 .39 .611 r
.38604 .84705 m .38802 .84438 L .38585 .84464 L F
.796 .856 .895 r
.38233 .72955 m .37998 .73146 L .37838 .73071 L F
.678 .495 .631 r
.37633 .85231 m .37878 .85204 L .37866 .84975 L F
.618 .451 .635 r
.37866 .84975 m .38087 .84961 L .38079 .84715 L F
.641 .481 .651 r
.37878 .85204 m .38087 .84961 L .37866 .84975 L F
.659 .554 .725 r
.42165 .87312 m .41952 .87516 L .41959 .87369 L F
.65 .478 .638 r
.50813 .84456 m .50843 .84723 L .50591 .84721 L F
.58 .427 .639 r
.5102 .84679 m .50813 .84456 L .5102 .84496 L F
.5102 .84679 m .50843 .84723 L .50813 .84456 L F
.946 .917 .753 r
.67812 .75477 m .67923 .75531 L .67869 .75382 L F
.523 .321 .548 r
.67923 .75531 m .67943 .75791 L .67725 .75834 L F
.666 .843 .968 r
.68006 .75349 m .67923 .75531 L .67812 .75477 L F
.68006 .75349 m .68094 .7536 L .67923 .75531 L F
.506 .556 .841 r
.68094 .7536 m .68157 .75563 L .67923 .75531 L F
.563 .35 .55 r
.68157 .75563 m .67943 .75791 L .67923 .75531 L F
0 0 0 r
.63177 .7835 m .6335 .78182 L .63198 .78335 L F
.63198 .78335 m .6335 .78182 L .6346 .78081 L F
.703 .965 .72 r
.63198 .78335 m .6346 .78081 L .63272 .78206 L F
.63198 .78335 m .63272 .78206 L .63212 .78324 L F
.63198 .78335 m .63212 .78324 L .63209 .78329 L F
0 0 0 r
.63101 .78423 m .63177 .7835 L .63198 .78335 L F
.6346 .78081 m .6335 .78182 L .63587 .77946 L F
.558 .932 .906 r
.50211 .88339 m .50301 .88345 L .5043 .88283 L F
.848 .998 .792 r
.58155 .83786 m .58087 .83948 L .57983 .83913 L F
.213 .026 .397 r
.61099 .79213 m .60949 .79487 L .61054 .7943 L F
.187 0 .348 r
.61054 .7943 m .60949 .79487 L .60888 .79706 L F
.562 .294 .466 r
.62087 .75396 m .61949 .75382 L .62134 .7523 L F
.62087 .75396 m .61827 .75488 L .61949 .75382 L F
0 0 0 r
.63229 .77018 m .6335 .769 L .63107 .77119 L F
.821 1 .801 r
.63229 .77018 m .6351 .76776 L .6335 .769 L F
.572 .289 .449 r
.59344 .76265 m .59566 .76258 L .59358 .76089 L F
.585 .285 .426 r
.59358 .76089 m .59566 .76258 L .59585 .76081 L F
.61 .329 .466 r
.41691 .82663 m .4195 .82831 L .41981 .82547 L F
.41691 .82663 m .41658 .8285 L .4195 .82831 L F
0 0 0 r
.66215 .76347 m .66444 .76202 L .66371 .76299 L F
.66215 .76347 m .66371 .76299 L .66123 .76513 L F
.666 .47 .61 r
.38087 .84961 m .3837 .84717 L .38079 .84715 L F
.628 .861 .986 r
.41428 .89111 m .41766 .89112 L .41612 .89053 L F
.494 .835 .998 r
.41612 .89053 m .41766 .89112 L .41977 .89075 L F
.072 .618 .84 r
.50104 .81353 m .50322 .81369 L .50417 .81397 L F
.449 0 0 r
.50322 .81369 m .50668 .81423 L .50417 .81397 L F
.774 .674 .753 r
.58364 .83452 m .5879 .83483 L .58579 .83052 L F
.774 .671 .749 r
.58504 .8361 m .5879 .83483 L .58364 .83452 L F
.664 .299 .343 r
.58759 .83624 m .5879 .83483 L .58504 .8361 L F
.461 .521 .833 r
.58579 .83052 m .5879 .83483 L .58956 .83421 L F
0 0 0 r
.63587 .77946 m .63823 .77692 L .63714 .77864 L F
.63587 .77946 m .63714 .77864 L .6346 .78081 L F
.906 .945 .82 r
.57746 .77724 m .57583 .77924 L .57702 .77754 L F
.63 .875 .527 r
.57746 .77724 m .57635 .7784 L .57583 .77924 L F
.582 .246 .365 r
.57922 .77615 m .57635 .7784 L .57746 .77724 L F
.929 .887 .77 r
.49454 .82317 m .49602 .82632 L .49591 .82392 L F
.707 .73 .868 r
.49454 .82317 m .49591 .82392 L .4981 .82355 L F
.697 .55 .683 r
.49591 .82392 m .49602 .82632 L .4981 .82355 L F
.479 .189 .394 r
.38678 .774 m .38603 .77619 L .38404 .77652 L F
.489 .198 .398 r
.38885 .77352 m .38603 .77619 L .38678 .774 L F
.677 .519 .664 r
.48333 .84435 m .48075 .84147 L .48249 .84096 L F
.48333 .84435 m .48104 .84509 L .48075 .84147 L F
.712 .68 .818 r
.36832 .7286 m .36622 .72984 L .36482 .72724 L F
.106 .631 .877 r
.38476 .72816 m .39013 .72926 L .38791 .7298 L F
.267 .018 .339 r
.38922 .73055 m .38791 .7298 L .39013 .72926 L F
.38922 .73055 m .38744 .7317 L .38791 .7298 L F
.555 .599 .853 r
.66885 .73317 m .66895 .73518 L .6694 .73115 L F
.786 .455 0 r
.66895 .73518 m .66904 .73612 L .6694 .73115 L F
.766 .728 .817 r
.52751 .83213 m .52843 .82932 L .52691 .82961 L F
.759 .617 .701 r
.52616 .8327 m .52488 .83042 L .5277 .83037 L F
.308 .778 .662 r
.52492 .83326 m .52531 .83308 L .52751 .83213 L F
.52418 .83363 m .52492 .83326 L .52751 .83213 L F
.52492 .83326 m .52506 .8332 L .52531 .83308 L F
.279 0 0 r
.52751 .83213 m .52506 .8332 L .52593 .83305 L F
.759 .617 .701 r
.52593 .83305 m .52585 .83284 L .52616 .8327 L F
.52585 .83284 m .52488 .83042 L .52616 .8327 L F
.714 .763 .891 r
.43232 .87334 m .42987 .87503 L .42896 .873 L F
.87 .453 .223 r
.54551 .81301 m .5469 .81558 L .54821 .81581 L F
.951 .716 .547 r
.5469 .81558 m .54813 .81834 L .54821 .81581 L F
.923 .951 .791 r
.57173 .78921 m .56975 .79213 L .57065 .79245 L F
.728 .71 .833 r
.63499 .72675 m .6315 .72629 L .63393 .72422 L F
.716 .708 .841 r
.63724 .72452 m .63499 .72675 L .63393 .72422 L F
.675 .635 .801 r
.63724 .72452 m .63831 .72742 L .63499 .72675 L F
0 0 0 r
.58202 .84952 m .58263 .84929 L .58462 .84883 L F
.765 .577 .644 r
.59184 .77166 m .58745 .77332 L .58733 .77171 L F
.561 .708 .939 r
.39383 .73908 m .39296 .7408 L .3918 .73956 L F
.39383 .73908 m .3952 .74054 L .39296 .7408 L F
.463 .889 .876 r
.56617 .77463 m .56811 .77386 L .56902 .77383 L F
0 0 0 r
.56902 .77383 m .57031 .77348 L .57103 .77282 L F
.207 .734 .796 r
.56811 .77386 m .57031 .77348 L .56902 .77383 L F
.43 .58 .901 r
.68411 .7151 m .68519 .71326 L .68308 .71402 L F
.68411 .7151 m .68701 .71596 L .68519 .71326 L F
.603 .416 .602 r
.59202 .77109 m .59137 .77375 L .59184 .77166 L F
.155 .166 .619 r
.57284 .81635 m .57274 .81333 L .57268 .81468 L F
0 .131 .628 r
.5741 .81721 m .57284 .81635 L .57268 .81468 L F
.819 .357 0 r
.68315 .74032 m .6818 .73719 L .68014 .73675 L F
.68315 .74032 m .68356 .74014 L .6818 .73719 L F
0 0 0 r
.64038 .77466 m .63924 .77609 L .63823 .77692 L F
.63924 .77609 m .63714 .77864 L .63823 .77692 L F
.6078 .75054 m .60885 .74992 L .6097 .74783 L F
.518 .314 .543 r
.6078 .75054 m .60967 .75227 L .60885 .74992 L F
.6078 .75054 m .60758 .75275 L .60967 .75227 L F
.998 .84 .511 r
.6351 .76776 m .63448 .76775 L .63555 .76619 L F
.358 0 .1 r
.63488 .76717 m .63762 .76568 L .63555 .76619 L F
.63587 .76683 m .63762 .76568 L .63488 .76717 L F
.63448 .76775 m .63674 .76657 L .63762 .76568 L F
.519 .623 .894 r
.63772 .76388 m .63676 .76653 L .63556 .76458 L F
.63676 .76653 m .63674 .76657 L .63673 .76654 L F
.63676 .76653 m .63673 .76654 L .63556 .76458 L F
.358 0 .1 r
.63448 .76775 m .63587 .76683 L .63488 .76717 L F
.599 .408 .594 r
.40699 .83133 m .40922 .82873 L .40705 .82898 L F
.427 .834 .974 r
.50785 .83177 m .50992 .83137 L .51093 .83169 L F
.22 .318 .753 r
.51093 .83169 m .51211 .83106 L .50991 .82868 L F
.404 .822 .97 r
.50992 .83137 m .51211 .83106 L .51093 .83169 L F
.709 .631 .768 r
.48333 .84435 m .48156 .84738 L .48104 .84509 L F
.522 .395 .649 r
.48331 .84698 m .48156 .84738 L .48333 .84435 L F
.724 .565 .674 r
.48466 .85005 m .48156 .84738 L .48331 .84698 L F
.48466 .85005 m .48172 .85068 L .48156 .84738 L F
.755 .333 0 r
.5662 .79996 m .56735 .80213 L .56767 .80236 L F
0 0 .51 r
.56732 .80126 m .56735 .80213 L .5662 .79996 L F
.729 .429 .471 r
.56691 .8018 m .56735 .80213 L .56732 .80126 L F
.5652 .80407 m .56735 .80213 L .56691 .8018 L F
.755 .333 0 r
.56767 .80236 m .56735 .80213 L .56788 .80272 L F
.963 .684 .255 r
.56736 .80492 m .56788 .80272 L .56735 .80213 L F
.56736 .80492 m .56818 .80519 L .56788 .80272 L F
.707 .73 .868 r
.49454 .82317 m .4981 .82355 L .49696 .82102 L F
.561 .368 .577 r
.49602 .82632 m .49815 .82609 L .4981 .82355 L F
0 0 0 r
.62842 .77381 m .6298 .77261 L .63107 .77119 L F
.63107 .77119 m .6298 .77261 L .63229 .77018 L F
.922 .548 .288 r
.54343 .81048 m .5442 .81251 L .54551 .81301 L F
.856 .457 .283 r
.54445 .81416 m .54551 .81301 L .5442 .81251 L F
.54445 .81416 m .5469 .81558 L .54551 .81301 L F
.668 .881 .977 r
.50121 .87604 m .49878 .87726 L .49711 .87656 L F
.6 .734 .939 r
.52605 .82627 m .52289 .82527 L .52492 .82544 L F
.343 .422 .799 r
.52709 .82587 m .52605 .82627 L .52492 .82544 L F
.509 .271 .489 r
.52628 .82802 m .52856 .82634 L .52605 .82627 L F
.343 .422 .799 r
.52709 .82587 m .52628 .82802 L .52605 .82627 L F
.777 .687 .765 r
.64026 .72469 m .63831 .72742 L .63724 .72452 L F
.457 .084 .242 r
.47543 .82294 m .4775 .82273 L .47858 .8207 L F
.38 0 .168 r
.4775 .82273 m .48069 .82039 L .47858 .8207 L F
.641 .694 .884 r
.37152 .7296 m .36832 .7286 L .37031 .72843 L F
.338 .645 .966 r
.37031 .72843 m .37219 .72864 L .37152 .7296 L F
.47 .813 .999 r
.37152 .7296 m .37219 .72864 L .3735 .72927 L F
.84 .863 .86 r
.63629 .73512 m .63932 .73454 L .63847 .73432 L F
.501 .899 .936 r
.64046 .73356 m .63932 .73454 L .64181 .7326 L F
.64046 .73356 m .63847 .73432 L .63932 .73454 L F
.256 0 0 r
.52766 .87545 m .53091 .87334 L .52985 .87369 L F
.943 .953 .745 r
.52985 .87369 m .53091 .87334 L .53103 .87113 L F
.614 .71 .913 r
.49035 .88711 m .49253 .88653 L .48926 .88569 L F
.592 .699 .918 r
.39872 .74225 m .3952 .74054 L .39707 .73992 L F
.657 .713 .889 r
.40028 .74056 m .39872 .74225 L .39707 .73992 L F
.614 .641 .853 r
.40071 .74178 m .39872 .74225 L .40028 .74056 L F
.621 .49 .681 r
.40139 .74496 m .39872 .74225 L .40071 .74178 L F
.40139 .74496 m .39948 .74555 L .39872 .74225 L F
.659 .82 .961 r
.49253 .88653 m .49601 .88676 L .4945 .88559 L F
.805 .752 .803 r
.4945 .88559 m .49601 .88676 L .49772 .88445 L F
.55 .068 .065 r
.5174 .82639 m .51919 .82772 L .52062 .82625 L F
0 0 0 r
.52094 .82611 m .52167 .82602 L .52289 .82527 L F
0 0 .505 r
.5225 .82437 m .52252 .82592 L .52167 .82602 L F
.461 0 .026 r
.52167 .82602 m .52253 .82692 L .52492 .82544 L F
0 0 .505 r
.52252 .82592 m .52253 .82692 L .52167 .82602 L F
0 0 0 r
.52062 .82625 m .52167 .82602 L .52094 .82611 L F
.52062 .82625 m .51919 .82772 L .52167 .82602 L F
.857 .439 .233 r
.47322 .85018 m .47247 .85144 L .47047 .84959 L F
.47322 .85018 m .47392 .85196 L .47247 .85144 L F
.929 .546 .199 r
.4697 .84747 m .46718 .84906 L .46775 .84757 L F
.4697 .84747 m .46931 .84865 L .46718 .84906 L F
.4697 .84747 m .47047 .84959 L .46931 .84865 L F
.878 .819 .786 r
.53291 .82077 m .53479 .82102 L .53298 .82258 L F
.064 .268 .759 r
.57109 .80992 m .57274 .81333 L .5714 .81145 L F
.607 .494 .699 r
.39255 .8393 m .3943 .83647 L .39218 .8367 L F
.678 .39 0 r
.56118 .81769 m .56144 .81858 L .56205 .82065 L F
.942 .647 .192 r
.56205 .82065 m .56171 .82161 L .56167 .81962 L F
.963 .691 .471 r
.56144 .81858 m .56221 .82108 L .56205 .82065 L F
.942 .647 .192 r
.56205 .82065 m .56167 .81962 L .56166 .81912 L F
.963 .691 .471 r
.56221 .82108 m .56232 .82143 L .56205 .82065 L F
.426 .254 .542 r
.60707 .82046 m .60867 .81841 L .60826 .82045 L F
.088 .061 .528 r
.60819 .8228 m .60707 .82046 L .60826 .82045 L F
.179 .683 .909 r
.533 .87074 m .53542 .87085 L .5342 .8704 L F
.794 .492 .477 r
.58914 .83145 m .58918 .82902 L .58653 .82893 L F
.43 0 .11 r
.59082 .83051 m .58918 .82902 L .58914 .83145 L F
.59082 .83051 m .59169 .8288 L .58918 .82902 L F
.614 .576 .788 r
.42549 .86524 m .42272 .86336 L .4247 .86262 L F
.213 0 .254 r
.62889 .78671 m .63101 .78423 L .63021 .78597 L F
0 0 0 r
.63021 .78597 m .63101 .78423 L .63198 .78335 L F
.918 .56 .116 r
.56232 .82143 m .5624 .82282 L .56205 .82065 L F
.56232 .82143 m .56315 .82363 L .5624 .82282 L F
.618 .3 .409 r
.45196 .82836 m .45528 .82619 L .45214 .8265 L F
.45196 .82836 m .45412 .8286 L .45528 .82619 L F
.569 .247 .384 r
.45528 .82619 m .45705 .82774 L .45744 .82618 L F
.45528 .82619 m .45412 .8286 L .45705 .82774 L F
.939 .693 .54 r
.49211 .85999 m .49335 .86225 L .49212 .86271 L F
0 .326 .723 r
.49416 .86248 m .49335 .86225 L .49211 .85999 L F
.49416 .86248 m .49538 .86327 L .49335 .86225 L F
.49335 .86225 m .49416 .86248 L .49212 .86271 L F
.49335 .86225 m .49538 .86327 L .49416 .86248 L F
.687 .622 .778 r
.64603 .72095 m .6482 .72185 L .64669 .72057 L F
.698 .622 .768 r
.64677 .71887 m .6482 .72185 L .64669 .72057 L F
.356 .292 .647 r
.49752 .84509 m .4989 .8442 L .49623 .84379 L F
.661 .109 0 r
.50071 .84695 m .49924 .84657 L .49752 .84509 L F
.356 .292 .647 r
.49752 .84509 m .49924 .84657 L .4989 .8442 L F
.49752 .84509 m .49924 .84657 L .4989 .8442 L F
.554 .726 .954 r
.49623 .84379 m .49752 .84509 L .4989 .8442 L F
.546 .356 .574 r
.40506 .76056 m .40279 .76288 L .40283 .76087 L F
.625 .821 .976 r
.54799 .79404 m .54911 .79501 L .5459 .79471 L F
.54799 .79404 m .54911 .79501 L .5459 .79471 L F
.729 .852 .939 r
.55091 .79377 m .54911 .79501 L .54799 .79404 L F
.867 .448 .009 r
.49916 .86784 m .49976 .86806 L .49814 .86582 L F
.957 .83 .677 r
.62299 .74748 m .62335 .75012 L .62428 .74826 L F
.751 .52 .581 r
.69446 .71606 m .69173 .71831 L .69281 .71658 L F
.666 .47 .61 r
.38087 .84961 m .38365 .84955 L .3837 .84717 L F
.38365 .84955 m .38604 .84705 L .3837 .84717 L F
.932 .695 .558 r
.50071 .84695 m .4989 .8442 L .50268 .84442 L F
.738 .594 .696 r
.50268 .84442 m .50356 .84718 L .50071 .84695 L F
.792 .717 .781 r
.68402 .70522 m .68506 .70843 L .68316 .70873 L F
.68 .655 .819 r
.68402 .70522 m .68685 .70596 L .68506 .70843 L F
.692 .323 .344 r
.50356 .84718 m .50246 .84818 L .50071 .84695 L F
.475 0 0 r
.50596 .84915 m .50356 .84718 L .50591 .84721 L F
.50596 .84915 m .50246 .84818 L .50356 .84718 L F
.746 .66 .765 r
.48658 .84697 m .48466 .85005 L .48331 .84698 L F
.488 .331 .593 r
.48658 .84697 m .48679 .8497 L .48466 .85005 L F
.377 .03 .244 r
.48679 .8497 m .48317 .85171 L .48466 .85005 L F
.777 .687 .765 r
.64026 .72469 m .63724 .72452 L .63955 .72366 L F
.735 .695 .813 r
.6433 .72361 m .64026 .72469 L .63955 .72366 L F
.493 .118 .256 r
.65743 .72966 m .65683 .73157 L .65435 .73168 L F
.556 .418 .649 r
.6593 .72684 m .65934 .72946 L .65743 .72966 L F
.6593 .72684 m .65934 .72946 L .65743 .72966 L F
.443 .072 .239 r
.65934 .72946 m .65683 .73157 L .65743 .72966 L F
.406 0 0 r
.42733 .82676 m .42925 .82722 L .43084 .82663 L F
.547 .117 .176 r
.42925 .82722 m .43233 .82639 L .43084 .82663 L F
.765 .577 .644 r
.59184 .77166 m .59137 .77375 L .58745 .77332 L F
.6 .734 .939 r
.41977 .89075 m .42211 .89158 L .42052 .88844 L F
.489 .27 .508 r
.42211 .89158 m .42516 .88958 L .42372 .88846 L F
.442 .876 .898 r
.58902 .84779 m .59079 .84783 L .59279 .84712 L F
.498 .839 .559 r
.64204 .77361 m .63924 .77609 L .64038 .77466 L F
.708 .447 .528 r
.50833 .84879 m .50591 .84721 L .50843 .84723 L F
.50833 .84879 m .50596 .84915 L .50591 .84721 L F
.808 .671 .713 r
.5192 .83136 m .51731 .83335 L .51664 .83138 L F
.82 .343 0 r
.5487 .80234 m .5477 .8019 L .54652 .8002 L F
.768 .259 0 r
.55048 .80444 m .5477 .8019 L .5487 .80234 L F
.781 .287 .036 r
.55184 .80481 m .55048 .80444 L .5487 .80234 L F
.631 .602 .802 r
.40232 .75024 m .40096 .75227 L .40037 .75067 L F
.40232 .75024 m .40317 .75197 L .40096 .75227 L F
.28 .779 .871 r
.69321 .72374 m .69385 .72388 L .69165 .72426 L F
.709 .513 .623 r
.69385 .72388 m .6916 .72616 L .69165 .72426 L F
.28 .779 .871 r
.69321 .72374 m .69165 .72426 L .6916 .72616 L F
.414 .135 .378 r
.62685 .78959 m .62889 .78671 L .62779 .78848 L F
0 0 0 r
.62779 .78848 m .62889 .78671 L .63021 .78597 L F
.56 .37 .581 r
.6742 .74063 m .67342 .74241 L .67519 .7394 L F
.523 .765 .985 r
.52691 .82961 m .5279 .82866 L .52628 .82802 L F
.52691 .82961 m .52843 .82932 L .5279 .82866 L F
.321 .426 .812 r
.6433 .72361 m .6445 .72439 L .64401 .72145 L F
.826 .549 .519 r
.64224 .72328 m .64468 .72557 L .6433 .72361 L F
.672 .287 .309 r
.6433 .72361 m .64468 .72557 L .6445 .72439 L F
.553 .319 .515 r
.60547 .76608 m .60572 .76802 L .60312 .76807 L F
.69 .416 .503 r
.60547 .76608 m .60764 .76828 L .60572 .76802 L F
.631 .422 .581 r
.60808 .76594 m .60764 .76828 L .60547 .76608 L F
.793 .343 0 r
.56464 .84426 m .56671 .84704 L .56662 .84768 L F
.707 .174 0 r
.56662 .84768 m .56671 .84704 L .5673 .84803 L F
.98 .846 .636 r
.54403 .79576 m .54344 .79758 L .54254 .7964 L F
.007 0 0 r
.54403 .79576 m .54463 .79598 L .5459 .79471 L F
.54403 .79576 m .54254 .7964 L .54463 .79598 L F
.396 .216 .516 r
.60989 .81318 m .61132 .81039 L .61115 .81238 L F
.398 .219 .519 r
.61132 .81039 m .61415 .80752 L .61404 .80979 L F
.36 .199 .522 r
.61374 .81201 m .61132 .81039 L .61404 .80979 L F
.61374 .81201 m .61115 .81238 L .61132 .81039 L F
.75 .328 .248 r
.67059 .7393 m .6742 .74063 L .6732 .74084 L F
.916 .802 .72 r
.6742 .74063 m .67342 .74241 L .6732 .74084 L F
.6742 .74063 m .67342 .74241 L .6732 .74084 L F
.422 .298 .606 r
.61289 .78919 m .61099 .79213 L .61297 .79155 L F
.259 .066 .417 r
.61297 .79155 m .61099 .79213 L .61054 .7943 L F
.479 0 0 r
.49259 .82644 m .49545 .8273 L .49602 .82632 L F
.712 .344 .35 r
.49545 .8273 m .49815 .82609 L .49602 .82632 L F
0 0 .52 r
.52021 .83314 m .5192 .83136 L .52099 .83122 L F
.57 .936 .911 r
.5225 .81044 m .52318 .80944 L .5251 .80919 L F
.572 .519 .757 r
.64347 .71847 m .64277 .72204 L .64169 .7217 L F
.237 .271 .695 r
.57635 .7784 m .57524 .78043 L .57583 .77924 L F
.185 .547 .929 r
.37588 .74919 m .37688 .74878 L .37445 .7482 L F
.37588 .74919 m .37809 .75009 L .37688 .74878 L F
.751 .746 .847 r
.5656 .79756 m .56319 .79764 L .56547 .79632 L F
.408 .316 .639 r
.56727 .79435 m .5656 .79756 L .56547 .79632 L F
.56727 .79435 m .56786 .79694 L .5656 .79756 L F
.099 .135 .611 r
.5673 .79896 m .5656 .79756 L .56786 .79694 L F
.5673 .79896 m .5662 .79996 L .5656 .79756 L F
.327 .202 .554 r
.61205 .81477 m .60989 .81318 L .61115 .81238 L F
.61205 .81477 m .60986 .81525 L .60989 .81318 L F
0 0 0 r
.52418 .83363 m .52383 .83534 L .52506 .8332 L F
.647 .891 .984 r
.52378 .8177 m .52156 .81822 L .52163 .81854 L F
.004 0 0 r
.35731 .75132 m .35574 .75131 L .35531 .75131 L F
0 0 0 r
.35479 .75131 m .35531 .75131 L .35323 .75177 L F
.204 .731 .825 r
.35531 .75131 m .35394 .75131 L .35195 .75159 L F
.004 0 0 r
.35574 .75131 m .35394 .75131 L .35531 .75131 L F
0 0 0 r
.35686 .75069 m .35531 .75131 L .35479 .75131 L F
.235 0 0 r
.35919 .75065 m .35531 .75131 L .35686 .75069 L F
.329 .047 .324 r
.61289 .78919 m .61462 .78876 L .61475 .78641 L F
.236 0 .284 r
.61475 .78641 m .61677 .78618 L .61694 .78385 L F
.241 0 .305 r
.61475 .78641 m .61462 .78876 L .61677 .78618 L F
0 .552 .745 r
.44777 .90971 m .44892 .90987 L .44576 .90954 L F
.44777 .90971 m .44892 .90987 L .44576 .90954 L F
.637 .616 .813 r
.55723 .77883 m .55868 .77885 L .55876 .7788 L F
.136 .674 .845 r
.55723 .77883 m .55776 .7785 L .55868 .77885 L F
0 0 .312 r
.5571 .78094 m .55776 .7785 L .55723 .77883 L F
.605 .091 0 r
.51694 .87674 m .51485 .87638 L .51721 .87626 L F
.456 .213 .455 r
.51502 .88013 m .51694 .87674 L .51705 .88057 L F
.633 .834 .978 r
.51902 .87521 m .51694 .87674 L .51721 .87626 L F
.51902 .87521 m .52038 .87618 L .51694 .87674 L F
.586 .243 .355 r
.51694 .87674 m .51966 .87654 L .51892 .87981 L F
.836 .596 .577 r
.48481 .83734 m .48653 .83981 L .48431 .83905 L F
.821 .658 .68 r
.48653 .83981 m .48558 .84169 L .48431 .83905 L F
.952 .949 .721 r
.64603 .72095 m .64677 .71887 L .64527 .71982 L F
.669 .919 .607 r
.61694 .78385 m .61734 .78297 L .61889 .7814 L F
0 0 .021 r
.61694 .78385 m .61677 .78618 L .61734 .78297 L F
.899 .982 .797 r
.62558 .73239 m .62609 .73019 L .62789 .73 L F
.62558 .73239 m .62496 .73196 L .62609 .73019 L F
.906 .979 .787 r
.62558 .73239 m .62338 .73326 L .62496 .73196 L F
.427 .766 .996 r
.57083 .77891 m .57228 .77891 L .57144 .7781 L F
.57 .825 .458 r
.57144 .7781 m .56922 .78089 L .57083 .77891 L F
.641 .389 .521 r
.48481 .83734 m .48431 .83905 L .48221 .83884 L F
.6 .414 .602 r
.36461 .77387 m .36679 .77371 L .36683 .7712 L F
.568 .388 .598 r
.36683 .7712 m .36895 .77336 L .36876 .77087 L F
.36683 .7712 m .36679 .77371 L .36895 .77336 L F
.676 .614 .779 r
.50228 .81827 m .50542 .82027 L .50435 .8202 L F
.437 0 .005 r
.50768 .81925 m .50435 .8202 L .50542 .82027 L F
.783 .667 .735 r
.45423 .86114 m .45162 .86226 L .45383 .85969 L F
.45423 .86114 m .45292 .8629 L .45162 .86226 L F
.425 .853 .945 r
.45514 .86053 m .45423 .86114 L .45383 .85969 L F
.45514 .86053 m .45668 .8606 L .45423 .86114 L F
.578 .378 .574 r
.60681 .79717 m .60866 .79909 L .60888 .79706 L F
.467 .368 .659 r
.60681 .79717 m .60732 .80008 L .60866 .79909 L F
.589 .541 .768 r
.58406 .82927 m .585 .82565 L .58274 .82829 L F
.58406 .82927 m .58653 .82893 L .585 .82565 L F
.645 .376 .496 r
.58388 .83135 m .58579 .83052 L .58406 .82927 L F
.229 .746 .847 r
.58506 .82891 m .58406 .82927 L .58274 .82829 L F
.58506 .82891 m .58653 .82893 L .58406 .82927 L F
.568 .409 .626 r
.58406 .82927 m .58579 .83052 L .58653 .82893 L F
.605 .478 .681 r
.53588 .84707 m .53849 .84897 L .53786 .84621 L F
.445 0 0 r
.54059 .84796 m .53786 .84621 L .53849 .84897 L F
.731 .398 .416 r
.43741 .85734 m .43622 .85957 L .43423 .85727 L F
.523 .342 .577 r
.44082 .85644 m .43943 .85713 L .43741 .85734 L F
.618 .269 .355 r
.43973 .85887 m .43741 .85734 L .43943 .85713 L F
.43973 .85887 m .43622 .85957 L .43741 .85734 L F
0 0 0 r
.67182 .75194 m .67329 .75071 L .67057 .75215 L F
.67057 .75215 m .67046 .75278 L .67182 .75194 L F
.436 .828 .984 r
.50734 .8806 m .51061 .88066 L .50943 .8801 L F
.385 .776 .988 r
.50943 .8801 m .51061 .88066 L .51271 .88049 L F
.605 .416 .599 r
.37634 .76616 m .3788 .76597 L .37875 .76322 L F
.592 .406 .598 r
.37875 .76322 m .38089 .76498 L .38054 .76302 L F
.456 .01 .1 r
.38121 .76312 m .37875 .76322 L .38054 .76302 L F
.592 .406 .598 r
.37875 .76322 m .3788 .76597 L .38089 .76498 L F
.275 .416 .823 r
.5547 .82795 m .55372 .82915 L .55266 .82658 L F
.196 .298 .742 r
.55538 .83075 m .55372 .82915 L .5547 .82795 L F
.799 .877 .904 r
.62885 .73945 m .63173 .73926 L .63118 .73724 L F
.62885 .73945 m .62988 .74 L .63173 .73926 L F
.834 .886 .879 r
.63118 .73724 m .63173 .73926 L .63386 .73688 L F
.555 .31 .499 r
.65576 .76066 m .65801 .76048 L .65809 .75839 L F
.454 .159 .375 r
.65801 .76048 m .66036 .75837 L .65809 .75839 L F
.798 .372 .237 r
.60885 .74992 m .60827 .74734 L .6097 .74783 L F
.828 .812 .834 r
.61196 .74549 m .6097 .74783 L .60827 .74734 L F
.544 .8 .993 r
.44317 .88582 m .44646 .88622 L .44555 .8854 L F
.409 .693 .978 r
.44646 .88622 m .44729 .88526 L .44555 .8854 L F
.44646 .88622 m .44851 .88632 L .44729 .88526 L F
.715 .555 .671 r
.37117 .8548 m .37414 .85498 L .37332 .85182 L F
.698 .544 .675 r
.37332 .85182 m .37414 .85498 L .37633 .85231 L F
0 0 0 r
.53023 .81496 m .52895 .81529 L .53025 .81461 L F
.53023 .81496 m .52812 .8158 L .52895 .81529 L F
.981 .833 .623 r
.52895 .81529 m .53174 .81372 L .53025 .81461 L F
.584 .621 .855 r
.56853 .78704 m .56802 .79018 L .56621 .78918 L F
.56853 .78704 m .57102 .79029 L .56802 .79018 L F
.888 .721 .668 r
.56802 .79018 m .56731 .79326 L .56621 .78918 L F
0 .214 .706 r
.46824 .86766 m .46692 .86679 L .46534 .86517 L F
.189 .247 .692 r
.46824 .86766 m .46735 .86781 L .46692 .86679 L F
0 .441 .802 r
.50957 .87527 m .50597 .87376 L .50818 .87573 L F
0 0 0 r
.51043 .87489 m .5114 .87417 L .50957 .87527 L F
.279 .77 .702 r
.51043 .87489 m .50957 .87527 L .50818 .87573 L F
.642 .436 .589 r
.39009 .84171 m .39236 .84134 L .39255 .8393 L F
.607 .494 .699 r
.39255 .8393 m .39464 .83895 L .3943 .83647 L F
.645 .477 .641 r
.39236 .84134 m .39464 .83895 L .39255 .8393 L F
.926 .784 .31 r
.67168 .74516 m .67343 .74455 L .67338 .74438 L F
.67168 .74516 m .67141 .74769 L .67115 .74656 L F
.67168 .74516 m .67115 .74656 L .67343 .74455 L F
.352 .732 .986 r
.47751 .88286 m .47861 .88356 L .48056 .88354 L F
.526 .295 .506 r
.40279 .76288 m .40026 .76489 L .40083 .76329 L F
.652 .909 .98 r
.44191 .88534 m .44121 .88665 L .44317 .88582 L F
.638 .893 .986 r
.43993 .88615 m .44121 .88665 L .44191 .88534 L F
.539 .238 .405 r
.60047 .76914 m .6002 .77075 L .59792 .77092 L F
.613 .331 .466 r
.60312 .76807 m .6002 .77075 L .60047 .76914 L F
.60312 .76807 m .6026 .77054 L .6002 .77075 L F
.622 .385 .538 r
.60572 .76802 m .6026 .77054 L .60312 .76807 L F
.202 .729 .77 r
.67725 .75834 m .67613 .75844 L .67394 .75887 L F
.143 .686 .725 r
.67943 .75791 m .67613 .75844 L .67725 .75834 L F
.602 .556 .776 r
.42668 .86228 m .42549 .86524 L .4247 .86262 L F
.42668 .86228 m .42793 .86527 L .42549 .86524 L F
.601 .446 .643 r
.42764 .86737 m .42549 .86524 L .42793 .86527 L F
.805 .752 .803 r
.4945 .88559 m .49772 .88445 L .49665 .88324 L F
.603 .733 .936 r
.49772 .88445 m .49878 .88277 L .49665 .88324 L F
.49772 .88445 m .49992 .88409 L .49878 .88277 L F
.284 .344 .749 r
.48257 .87209 m .48195 .87332 L .48193 .87169 L F
0 0 .152 r
.48157 .8756 m .48195 .87332 L .48257 .87209 L F
.763 .668 .758 r
.3477 .72385 m .34895 .72682 L .35104 .72418 L F
.518 .267 .474 r
.3487 .72794 m .35059 .72781 L .34895 .72682 L F
.417 .352 .677 r
.46949 .87007 m .46733 .87112 L .46735 .86781 L F
.516 .607 .882 r
.46949 .87007 m .46944 .87223 L .46733 .87112 L F
.661 .351 .438 r
.52479 .83648 m .5221 .83836 L .52175 .83609 L F
.52479 .83648 m .52475 .83854 L .5221 .83836 L F
.497 .22 .423 r
.5274 .8363 m .52475 .83854 L .52479 .83648 L F
.913 .966 .798 r
.56598 .83418 m .56424 .83683 L .56388 .83545 L F
.948 .957 .713 r
.56388 .83545 m .56424 .83683 L .56314 .83855 L F
0 0 .211 r
.57524 .78043 m .57358 .78412 L .57283 .78077 L F
.522 .465 .734 r
.57431 .7807 m .57571 .78076 L .57635 .7784 L F
.237 .271 .695 r
.57635 .7784 m .57695 .78082 L .57524 .78043 L F
.522 .465 .734 r
.57571 .78076 m .57695 .78082 L .57663 .77954 L F
.57571 .78076 m .57663 .77954 L .57635 .7784 L F
0 0 .211 r
.57414 .78286 m .57478 .78358 L .57358 .78412 L F
.57524 .78043 m .57506 .78163 L .57414 .78286 L F
.57506 .78163 m .57478 .78358 L .57414 .78286 L F
.504 .26 .479 r
.57695 .78082 m .57478 .78358 L .57524 .78043 L F
.714 .738 .87 r
.5381 .83184 m .54125 .83228 L .54019 .83101 L F
.726 .668 .793 r
.54019 .83101 m .54125 .83228 L .54329 .83127 L F
.486 .185 .381 r
.37393 .78592 m .37191 .78626 L .3724 .78462 L F
.516 .177 .331 r
.37448 .78454 m .37393 .78592 L .3724 .78462 L F
.553 .922 .768 r
.53324 .81264 m .53025 .81461 L .53174 .81372 L F
.642 .361 .478 r
.39857 .83636 m .39673 .83424 L .39648 .83629 L F
.39857 .83636 m .39968 .83383 L .39673 .83424 L F
.219 .696 .937 r
.39205 .89893 m .39265 .89848 L .39105 .89941 L F
.39205 .89893 m .39394 .89898 L .39265 .89848 L F
.882 .842 .379 r
.48627 .87324 m .48766 .87668 L .48695 .87528 L F
.557 .738 .96 r
.48894 .87535 m .48766 .87668 L .48695 .87528 L F
.48894 .87535 m .49014 .87656 L .48766 .87668 L F
.48894 .87535 m .48766 .87668 L .48695 .87528 L F
.48894 .87535 m .49014 .87656 L .48766 .87668 L F
.553 .321 .517 r
.35799 .78133 m .36008 .78105 L .36035 .7791 L F
.557 .41 .638 r
.36035 .7791 m .36236 .77876 L .36222 .77638 L F
.532 .307 .518 r
.36008 .78105 m .36236 .77876 L .36035 .7791 L F
.656 .936 .967 r
.60481 .75427 m .60304 .75548 L .60415 .75418 L F
.054 0 .413 r
.60287 .75743 m .60415 .75418 L .60304 .75548 L F
.855 .795 .791 r
.38075 .74869 m .38171 .75036 L .38355 .74811 L F
.38075 .74869 m .38108 .75103 L .38171 .75036 L F
.513 .648 .918 r
.38355 .74811 m .38675 .75034 L .38602 .74732 L F
.292 .339 .739 r
.38602 .74732 m .38675 .75034 L .38774 .74892 L F
.256 .29 .705 r
.38675 .75034 m .38883 .75266 L .38774 .74892 L F
.547 .301 .494 r
.35844 .79532 m .36012 .79656 L .35812 .79704 L F
.477 .408 .701 r
.49593 .81298 m .49981 .81501 L .49751 .81375 L F
.612 .895 .988 r
.43471 .8867 m .4359 .88717 L .43781 .88645 L F
.609 .762 .952 r
.409 .89124 m .41225 .89176 L .41111 .8908 L F
.628 .842 .982 r
.41225 .89176 m .41381 .89029 L .41111 .8908 L F
.41225 .89176 m .41428 .89111 L .41381 .89029 L F
.704 .762 .897 r
.3493 .75351 m .35068 .75278 L .34847 .7526 L F
.537 .311 .52 r
.38113 .78078 m .3794 .77906 L .38144 .77872 L F
.38113 .78078 m .37915 .78119 L .3794 .77906 L F
.657 .589 .767 r
.64809 .713 m .64644 .71652 L .64619 .71469 L F
.64809 .713 m .64876 .71622 L .64644 .71652 L F
.644 .494 .664 r
.64876 .71622 m .64677 .71887 L .64644 .71652 L F
.102 .324 .798 r
.64644 .71652 m .647 .71679 L .64619 .71469 L F
.759 .574 .647 r
.64644 .71652 m .64677 .71887 L .64347 .71847 L F
.64644 .71652 m .64347 .71847 L .647 .71679 L F
.683 .775 .921 r
.36297 .72779 m .3597 .72736 L .36161 .72632 L F
.611 .707 .913 r
.36482 .72724 m .36297 .72779 L .36161 .72632 L F
.618 .791 .965 r
.43559 .87375 m .43232 .87334 L .43434 .87226 L F
.651 .702 .884 r
.43762 .87311 m .43559 .87375 L .43434 .87226 L F
.828 .812 .834 r
.61196 .74549 m .6085 .74481 L .61066 .74425 L F
.61196 .74549 m .60827 .74734 L .6085 .74481 L F
.638 .76 .936 r
.61338 .74436 m .61196 .74549 L .61066 .74425 L F
.37 .834 .777 r
.40544 .89309 m .40422 .89373 L .40543 .89318 L F
.40544 .89309 m .40365 .89385 L .40422 .89373 L F
.228 0 0 r
.5279 .80694 m .53137 .8068 L .52881 .8065 L F
.238 0 0 r
.52881 .8065 m .53137 .8068 L .53219 .80604 L F
0 .502 .749 r
.48829 .81825 m .49185 .81896 L .49035 .81882 L F
.415 .837 .962 r
.49185 .81896 m .4929 .81825 L .49361 .81743 L F
.49185 .81896 m .49061 .81865 L .4929 .81825 L F
.513 .265 .477 r
.3951 .77035 m .39346 .76867 L .39548 .76835 L F
.3951 .77035 m .39308 .77075 L .39346 .76867 L F
.875 .491 .018 r
.55969 .81528 m .55917 .81527 L .55822 .81257 L F
.781 .313 0 r
.55969 .81528 m .56028 .81695 L .55917 .81527 L F
.55969 .81528 m .56118 .81769 L .56028 .81695 L F
.476 .232 .465 r
.36756 .78958 m .36531 .79139 L .36558 .79021 L F
.63 .299 .392 r
.48309 .81839 m .48501 .8202 L .48637 .81784 L F
.528 .15 .267 r
.48501 .8202 m .48829 .81825 L .48637 .81784 L F
.605 .478 .681 r
.53588 .84707 m .53611 .84956 L .53849 .84897 L F
.502 .256 .475 r
.36222 .77638 m .36423 .77603 L .36461 .77387 L F
.587 .333 .499 r
.36423 .77603 m .36646 .77577 L .36461 .77387 L F
.58 .333 .507 r
.36461 .77387 m .36646 .77577 L .36679 .77371 L F
.531 .512 .78 r
.39092 .73637 m .38985 .73962 L .38859 .73698 L F
.39092 .73637 m .3918 .73956 L .38985 .73962 L F
.652 .164 .08 r
.5755 .84141 m .57171 .84089 L .57454 .83947 L F
.687 .76 .907 r
.57672 .84008 m .5755 .84141 L .57454 .83947 L F
0 0 0 r
.64661 .77095 m .64679 .77071 L .64969 .76942 L F
.64661 .77095 m .64969 .76942 L .64816 .76982 L F
.487 .896 .919 r
.65199 .76905 m .64816 .76982 L .64969 .76942 L F
.691 .166 0 r
.53137 .8068 m .53416 .80764 L .53219 .80604 L F
.811 .761 .806 r
.39578 .89627 m .39945 .89521 L .39758 .89519 L F
.271 0 0 r
.40186 .89481 m .39758 .89519 L .39945 .89521 L F
.583 .723 .94 r
.48717 .88606 m .48813 .88466 L .48595 .88505 L F
.48717 .88606 m .48926 .88569 L .48813 .88466 L F
.657 .457 .602 r
.38365 .84955 m .3859 .84939 L .38604 .84705 L F
.557 .39 .611 r
.38604 .84705 m .38799 .84665 L .38802 .84438 L F
.652 .502 .667 r
.3859 .84939 m .38799 .84665 L .38604 .84705 L F
.622 .512 .708 r
.44266 .8468 m .43949 .84424 L .44275 .84466 L F
.44266 .8468 m .44053 .84728 L .43949 .84424 L F
.559 .598 .848 r
.44554 .85908 m .44549 .85926 L .44335 .85988 L F
.536 .797 .993 r
.44652 .86059 m .44289 .86001 L .44335 .85988 L F
.44652 .86059 m .44278 .85999 L .44335 .85988 L F
.632 .822 .973 r
.44812 .85982 m .44652 .86059 L .44335 .85988 L F
.744 .349 .303 r
.44652 .86059 m .44808 .86262 L .44477 .86196 L F
.469 .314 .588 r
.44812 .85982 m .44808 .86262 L .44652 .86059 L F
.411 .004 .153 r
.44477 .86196 m .44812 .85982 L .44335 .85988 L F
.559 .598 .848 r
.44549 .85926 m .44477 .86196 L .44335 .85988 L F
.536 .797 .993 r
.44289 .86001 m .44278 .85999 L .44335 .85988 L F
.39 .545 .889 r
.68494 .72026 m .68439 .71844 L .68393 .7195 L F
.702 .892 .966 r
.66883 .76089 m .67004 .76164 L .67191 .76059 L F
.558 .932 .906 r
.50211 .88339 m .5043 .88283 L .50325 .88201 L F
.785 .928 .929 r
.5043 .88283 m .50616 .88016 L .50325 .88201 L F
.5043 .88283 m .50734 .8806 L .50616 .88016 L F
.716 .403 0 r
.56315 .82363 m .56351 .825 L .5624 .82282 L F
.56315 .82363 m .56385 .82584 L .56351 .825 L F
.658 .379 .485 r
.39857 .83636 m .40161 .83598 L .39968 .83383 L F
.683 .377 .45 r
.40161 .83598 m .40202 .83429 L .39968 .83383 L F
.379 .179 .478 r
.41981 .82547 m .42077 .82756 L .42282 .82532 L F
.41981 .82547 m .4195 .82831 L .42077 .82756 L F
.985 .895 .64 r
.67255 .74987 m .67329 .75071 L .67182 .75194 L F
.083 .259 .746 r
.53889 .83884 m .54015 .84201 L .54103 .84107 L F
.379 .722 .989 r
.54015 .84201 m .5423 .84213 L .54103 .84107 L F
.552 .672 .918 r
.51966 .87654 m .52427 .87833 L .52281 .87617 L F
.411 .6 .923 r
.52281 .87617 m .52427 .87833 L .52456 .87761 L F
.148 0 .343 r
.52427 .87833 m .52566 .87598 L .52456 .87761 L F
.816 .627 .647 r
.45292 .8629 m .45261 .86454 L .45162 .86226 L F
.34 .186 .521 r
.59495 .82055 m .59326 .82358 L .59521 .82317 L F
.352 .283 .639 r
.59326 .82358 m .59463 .82437 L .59521 .82317 L F
.59326 .82358 m .59386 .82618 L .59463 .82437 L F
.614 .311 .432 r
.58826 .76512 m .59046 .76525 L .58838 .76348 L F
.573 .323 .5 r
.58838 .76348 m .59046 .76525 L .59058 .76326 L F
.274 0 0 r
.66957 .73002 m .67285 .7307 L .67313 .73051 L F
.291 0 0 r
.67285 .7307 m .6758 .73124 L .67313 .73051 L F
.374 .006 .205 r
.68278 .74559 m .68144 .74711 L .67951 .74744 L F
.165 0 .044 r
.68468 .74474 m .68144 .74711 L .68278 .74559 L F
.674 .51 .655 r
.37414 .85498 m .37636 .85467 L .37633 .85231 L F
.658 .48 .632 r
.37636 .85467 m .37878 .85204 L .37633 .85231 L F
.463 .867 .961 r
.44756 .87051 m .44848 .87084 L .45041 .87029 L F
.45041 .87029 m .44848 .87084 L .44756 .87051 L F
0 0 0 r
.59474 .84647 m .59743 .844 L .59653 .84573 L F
.041 0 .03 r
.59743 .844 m .59988 .84161 L .59901 .84357 L F
.018 0 0 r
.59653 .84573 m .59743 .844 L .59901 .84357 L F
.64 .358 .476 r
.42077 .82756 m .42416 .82558 L .42282 .82532 L F
.737 .496 0 r
.56314 .83855 m .56386 .84239 L .56393 .84115 L F
0 .001 .562 r
.56386 .84239 m .56464 .84426 L .56393 .84115 L F
.764 .405 .374 r
.42416 .82558 m .42733 .82676 L .42518 .82681 L F
.269 0 0 r
.44696 .87368 m .44613 .87334 L .44487 .87307 L F
.44696 .87368 m .44796 .87409 L .44613 .87334 L F
.712 .68 .818 r
.36832 .7286 m .36482 .72724 L .36688 .72689 L F
.518 .627 .898 r
.3687 .72614 m .36832 .7286 L .36688 .72689 L F
.3687 .72614 m .37031 .72843 L .36832 .7286 L F
0 0 .064 r
.59988 .84161 m .60181 .83885 L .60119 .84098 L F
0 0 0 r
.59901 .84357 m .59988 .84161 L .60119 .84098 L F
.471 .745 .989 r
.50597 .87376 m .50302 .87295 L .50526 .87363 L F
.742 .241 .034 r
.50663 .87553 m .50597 .87376 L .50526 .87363 L F
.50663 .87553 m .50818 .87573 L .50597 .87376 L F
.986 .722 .432 r
.55819 .81046 m .5573 .81205 L .55718 .80983 L F
.55819 .81046 m .55822 .81257 L .5573 .81205 L F
.796 .856 .895 r
.38233 .72955 m .37838 .73071 L .38083 .72873 L F
.13 .351 .813 r
.3828 .72836 m .38468 .73104 L .38233 .72955 L F
.518 .801 .997 r
.3828 .72836 m .38233 .72955 L .38083 .72873 L F
.768 .791 .872 r
.68494 .72026 m .68725 .71853 L .68439 .71844 L F
.562 .434 .663 r
.42668 .86228 m .42478 .86058 L .42675 .86 L F
.42668 .86228 m .4247 .86262 L .42478 .86058 L F
.779 .781 .854 r
.64051 .71859 m .64169 .7217 L .63816 .72084 L F
.812 .747 .792 r
.64169 .7217 m .63955 .72366 L .63816 .72084 L F
.824 .801 .83 r
.64347 .71847 m .64169 .7217 L .64051 .71859 L F
.745 .581 .672 r
.3857 .73262 m .38547 .73626 L .38214 .73343 L F
0 0 .373 r
.38658 .73282 m .38547 .73626 L .3857 .73262 L F
.932 .695 .558 r
.50071 .84695 m .49924 .84657 L .4989 .8442 L F
.421 0 0 r
.50246 .84818 m .49924 .84657 L .50071 .84695 L F
.604 .564 .783 r
.42484 .87582 m .42165 .87312 L .42363 .87267 L F
.738 .616 .722 r
.54019 .83101 m .54329 .83127 L .54275 .82919 L F
.561 .563 .813 r
.54329 .83127 m .54424 .82802 L .54275 .82919 L F
.54329 .83127 m .54534 .83102 L .54424 .82802 L F
.135 .269 .738 r
.54329 .83127 m .54471 .83231 L .54534 .83102 L F
0 .485 .795 r
.37809 .75009 m .38108 .75103 L .37901 .75013 L F
.575 .658 .893 r
.47189 .87067 m .46944 .87223 L .46949 .87007 L F
.949 .623 .203 r
.68171 .70825 m .68276 .71067 L .68198 .71018 L F
.468 .461 .766 r
.68071 .71318 m .68198 .71018 L .68276 .71067 L F
.801 .7 .753 r
.68316 .70873 m .68276 .71067 L .68171 .70825 L F
0 0 0 r
.60029 .76003 m .60287 .75743 L .60083 .75789 L F
.869 .526 .398 r
.67584 .73362 m .67674 .73169 L .6758 .73124 L F
.67584 .73362 m .67781 .73427 L .67674 .73169 L F
.913 .512 .145 r
.67674 .73169 m .67781 .73427 L .67798 .73383 L F
.649 .748 .921 r
.38421 .90127 m .38538 .8994 L .38246 .90072 L F
.38421 .90127 m .38572 .90073 L .38538 .8994 L F
.599 .408 .594 r
.40699 .83133 m .40917 .83105 L .40922 .82873 L F
.598 .376 .551 r
.40917 .83105 m .41141 .82866 L .40922 .82873 L F
0 .175 .706 r
.57287 .81284 m .57274 .81333 L .57109 .80992 L F
0 0 .076 r
.57287 .81284 m .57268 .81468 L .57274 .81333 L F
.963 .694 .475 r
.45041 .87029 m .45146 .87194 L .45041 .87209 L F
.382 0 0 r
.45241 .87258 m .45347 .87233 L .45146 .87194 L F
.62 .353 .492 r
.37594 .76797 m .3788 .76597 L .37634 .76616 L F
.675 .382 .47 r
.46799 .82496 m .47013 .8256 L .46806 .82344 L F
.651 .385 .504 r
.46806 .82344 m .47013 .8256 L .47049 .82357 L F
.642 .429 .579 r
.43227 .85707 m .42877 .85984 L .42887 .85735 L F
.43227 .85707 m .43228 .86065 L .42877 .85984 L F
.587 .385 .574 r
.43419 .85949 m .43227 .85707 L .43423 .85727 L F
.43419 .85949 m .43228 .86065 L .43227 .85707 L F
.44 0 .076 r
.50228 .81827 m .50126 .81969 L .49907 .81956 L F
.723 .302 .248 r
.50228 .81827 m .50435 .8202 L .50126 .81969 L F
.578 .435 .651 r
.65236 .73101 m .65438 .72937 L .65203 .7299 L F
.047 0 .298 r
.67958 .74904 m .6782 .75031 L .67951 .74744 L F
.465 .363 .655 r
.67958 .74904 m .67788 .75245 L .6782 .75031 L F
.291 .747 .954 r
.51721 .87626 m .51485 .87638 L .51372 .87591 L F
.864 .912 .862 r
.6301 .72754 m .62789 .73 L .62796 .72799 L F
.889 .928 .84 r
.62796 .72799 m .62789 .73 L .62609 .73019 L F
.417 .352 .677 r
.46949 .87007 m .46735 .86781 L .46824 .86766 L F
.679 .55 .701 r
.38802 .84438 m .39009 .84171 L .38777 .84201 L F
.947 .63 .196 r
.67172 .72335 m .67286 .72652 L .67239 .72412 L F
.64 .823 .971 r
.4508 .85709 m .44817 .85748 L .45072 .85676 L F
.631 .359 .487 r
.4508 .85709 m .45017 .85952 L .44817 .85748 L F
.571 .361 .557 r
.44817 .85748 m .45017 .85952 L .45072 .85676 L F
.394 0 .015 r
.36435 .74837 m .36287 .7497 L .36083 .74981 L F
.474 .052 .158 r
.36643 .74813 m .36287 .7497 L .36435 .74837 L F
.72 .188 0 r
.47592 .86969 m .47374 .86964 L .47593 .86952 L F
.622 .798 .966 r
.47547 .87097 m .47316 .8721 L .47219 .87101 L F
.47547 .87097 m .47219 .87101 L .4729 .87075 L F
.47547 .87097 m .47189 .87067 L .47374 .86964 L F
.72 .188 0 r
.47579 .87196 m .47547 .87097 L .47374 .86964 L F
.47579 .87196 m .47707 .87244 L .47547 .87097 L F
.47579 .87196 m .47429 .87026 L .47592 .86969 L F
.47429 .87026 m .47374 .86964 L .47592 .86969 L F
.622 .798 .966 r
.4729 .87075 m .47219 .87101 L .47189 .87067 L F
.913 .966 .798 r
.56598 .83418 m .56388 .83545 L .56485 .83348 L F
.999 .818 .48 r
.6732 .74084 m .67342 .74241 L .67263 .7406 L F
.548 .182 .298 r
.67097 .76009 m .67219 .7591 L .67142 .75808 L F
.209 .112 .519 r
.67306 .75714 m .67219 .7591 L .67142 .75808 L F
.89 .738 .687 r
.67097 .76009 m .67219 .7591 L .67171 .75877 L F
.765 .759 .848 r
.67242 .75751 m .67171 .75877 L .67142 .75808 L F
.67171 .75877 m .67097 .76009 L .6711 .75951 L F
.67171 .75877 m .6711 .75951 L .67142 .75808 L F
.793 .782 .843 r
.66986 .75748 m .67171 .75877 L .67306 .75714 L F
.67171 .75877 m .67219 .7591 L .67306 .75714 L F
.89 .738 .687 r
.67097 .76009 m .67171 .75877 L .66986 .75748 L F
.765 .759 .848 r
.67306 .75714 m .67097 .76009 L .67242 .75751 L F
0 0 .096 r
.60181 .83885 m .60372 .8363 L .60322 .83827 L F
0 0 .084 r
.60119 .84098 m .60181 .83885 L .60322 .83827 L F
.423 0 0 r
.55868 .77885 m .56254 .77869 L .55876 .7788 L F
.518 .915 .897 r
.55868 .77885 m .55963 .77783 L .56066 .77886 L F
.55868 .77885 m .55776 .7785 L .55963 .77783 L F
.423 0 0 r
.55868 .77885 m .56066 .77886 L .56254 .77869 L F
.813 .345 0 r
.58364 .83452 m .58504 .8361 L .58418 .83561 L F
.397 0 .097 r
.58504 .8361 m .58155 .83786 L .58418 .83561 L F
.813 .345 0 r
.58364 .83452 m .58504 .8361 L .58418 .83561 L F
.248 .703 .954 r
.58614 .83556 m .58504 .8361 L .58418 .83561 L F
.58614 .83556 m .58759 .83624 L .58504 .8361 L F
.173 0 0 r
.64468 .72557 m .64757 .724 L .6445 .72439 L F
.64468 .72557 m .64578 .72577 L .64757 .724 L F
.558 .663 .907 r
.54465 .84977 m .54059 .84796 L .54342 .84917 L F
.871 .905 .852 r
.54237 .85225 m .54342 .84917 L .54092 .85094 L F
.54237 .85225 m .54465 .84977 L .54342 .84917 L F
.499 .064 .144 r
.35309 .72573 m .35147 .72746 L .35377 .72662 L F
.045 .584 .85 r
.35376 .72662 m .35376 .72662 L .35309 .72573 L F
.35376 .72662 m .35421 .72706 L .35311 .72574 L F
.35376 .72662 m .35311 .72574 L .35309 .72573 L F
.49 .05 .13 r
.35147 .72746 m .35357 .72765 L .35409 .72705 L F
.586 .847 .994 r
.3583 .72674 m .35616 .7273 L .35405 .72669 L F
.3583 .72674 m .35405 .72669 L .35423 .72663 L F
.3583 .72674 m .35378 .72662 L .35381 .72661 L F
.045 .584 .85 r
.35376 .72662 m .35616 .7273 L .35421 .72706 L F
.499 .064 .144 r
.35309 .72573 m .35376 .72662 L .35478 .72626 L F
.35376 .72662 m .35377 .72662 L .35378 .72662 L F
.35376 .72662 m .35378 .72662 L .35478 .72626 L F
.586 .847 .994 r
.35381 .72661 m .35379 .72662 L .35376 .72661 L F
.499 .064 .144 r
.35378 .72662 m .35378 .72662 L .35379 .72662 L F
.35378 .72662 m .35379 .72662 L .35478 .72626 L F
.045 .584 .85 r
.35376 .72662 m .35378 .72662 L .35376 .72662 L F
.35376 .72661 m .35378 .72662 L .35376 .72662 L F
.35378 .72662 m .35616 .7273 L .35376 .72662 L F
.49 .05 .13 r
.35377 .72662 m .35409 .72705 L .35439 .7267 L F
.586 .847 .994 r
.35423 .72663 m .35405 .72669 L .35378 .72662 L F
.35684 .72648 m .35376 .72661 L .35674 .72647 L F
.3583 .72674 m .35424 .72663 L .35684 .72648 L F
.161 0 0 r
.35501 .7265 m .35357 .72765 L .35546 .72697 L F
.49 .05 .13 r
.35386 .72661 m .3545 .72658 L .35455 .72652 L F
.334 0 0 r
.35478 .72626 m .35674 .72647 L .35457 .72657 L F
.161 0 0 r
.35478 .72626 m .35455 .72652 L .35462 .7265 L F
.49 .05 .13 r
.35379 .72662 m .35455 .72652 L .35478 .72626 L F
.35377 .72662 m .35455 .72652 L .35379 .72662 L F
.334 0 0 r
.35478 .72626 m .35457 .72657 L .35376 .72661 L F
.161 0 0 r
.35478 .72626 m .35462 .7265 L .35491 .7264 L F
.35491 .7264 m .35476 .72654 L .35501 .7265 L F
.586 .847 .994 r
.35381 .72661 m .35376 .72661 L .35684 .72648 L F
.161 0 0 r
.35476 .72654 m .35357 .72765 L .35501 .7265 L F
.586 .847 .994 r
.35424 .72663 m .35381 .72661 L .3545 .72658 L F
.35424 .72663 m .3545 .72658 L .35684 .72648 L F
.49 .05 .13 r
.3538 .72662 m .35439 .7267 L .3545 .72658 L F
.3538 .72662 m .3545 .72658 L .35386 .72661 L F
.35377 .72662 m .35439 .7267 L .3538 .72662 L F
.161 0 0 r
.35455 .72652 m .35357 .72765 L .35491 .7264 L F
.49 .05 .13 r
.35147 .72746 m .35409 .72705 L .35377 .72662 L F
.045 .584 .85 r
.35376 .72661 m .35376 .72662 L .35309 .72573 L F
.183 .715 .823 r
.52142 .87587 m .52038 .87618 L .51902 .87521 L F
.52142 .87587 m .52238 .87595 L .52038 .87618 L F
.603 .527 .742 r
.40232 .75024 m .40037 .75067 L .39952 .74758 L F
.56 .814 .993 r
.45191 .88692 m .45263 .88557 L .45053 .88589 L F
.45191 .88692 m .45407 .88646 L .45263 .88557 L F
0 0 0 r
.46455 .88344 m .4677 .88303 L .46663 .88309 L F
.079 .64 .757 r
.4677 .88303 m .4687 .88293 L .46663 .88309 L F
.4677 .88303 m .46981 .88292 L .4687 .88293 L F
.582 .235 .347 r
.45744 .82618 m .45927 .82771 L .46066 .82535 L F
.562 .186 .287 r
.45927 .82771 m .46266 .82579 L .46066 .82535 L F
.594 .454 .66 r
.40139 .74496 m .39952 .74758 L .39948 .74555 L F
.747 .58 .668 r
.48658 .84697 m .48333 .84435 L .48574 .84369 L F
.48658 .84697 m .48331 .84698 L .48333 .84435 L F
.703 .638 .781 r
.48861 .84467 m .48658 .84697 L .48574 .84369 L F
.629 .523 .715 r
.48861 .84467 m .48938 .84719 L .48658 .84697 L F
.506 .344 .595 r
.48868 .8491 m .48658 .84697 L .48938 .84719 L F
.48868 .8491 m .48679 .8497 L .48658 .84697 L F
.778 .374 .286 r
.42493 .73916 m .4236 .73919 L .42171 .73742 L F
.6 .447 .646 r
.42171 .73742 m .4236 .73919 L .42412 .73849 L F
.705 .17 0 r
.55304 .80569 m .55048 .80444 L .55184 .80481 L F
.327 .465 .846 r
.69319 .71186 m .69081 .71185 L .69074 .71028 L F
.69319 .71186 m .69355 .71335 L .69081 .71185 L F
.856 .48 .335 r
.67763 .73554 m .67798 .73383 L .67781 .73427 L F
.67763 .73554 m .68014 .73675 L .67798 .73383 L F
.359 0 0 r
.42671 .73844 m .4236 .73919 L .42493 .73916 L F
.917 .613 .454 r
.67841 .72105 m .67987 .7216 L .67945 .72352 L F
.746 .792 .89 r
.68112 .71848 m .67987 .7216 L .67841 .72105 L F
.68112 .71848 m .68239 .71948 L .67987 .7216 L F
.705 .341 .356 r
.67987 .7216 m .68099 .72378 L .67945 .72352 L F
.537 .296 .497 r
.37709 .7816 m .37672 .78429 L .37448 .78454 L F
.467 .235 .478 r
.37861 .78373 m .37709 .7816 L .37915 .78119 L F
.37861 .78373 m .37672 .78429 L .37709 .7816 L F
.493 .163 .336 r
.46775 .84757 m .46718 .84906 L .46507 .84931 L F
.352 0 .083 r
.57781 .76865 m .58043 .76758 L .57832 .76806 L F
.684 .561 .71 r
.51285 .84378 m .5102 .84679 L .5102 .84496 L F
.209 .693 .93 r
.50875 .82558 m .51081 .82567 L .51199 .82617 L F
.114 .263 .739 r
.51295 .82521 m .51199 .82617 L .51081 .82567 L F
.531 .297 .504 r
.51199 .82617 m .51392 .8279 L .51408 .82579 L F
.114 .263 .739 r
.51295 .82521 m .51392 .8279 L .51199 .82617 L F
0 .039 .588 r
.53378 .81633 m .53518 .81601 L .53594 .81514 L F
.521 .506 .781 r
.69013 .70734 m .68799 .70895 L .68685 .70596 L F
.69013 .70734 m .6898 .70882 L .68799 .70895 L F
.521 .494 .768 r
.6898 .70882 m .69074 .71028 L .68799 .70895 L F
.44 .155 .383 r
.67951 .74744 m .6806 .74802 L .67958 .74904 L F
.67951 .74744 m .68144 .74711 L .6806 .74802 L F
.658 .48 .632 r
.37636 .85467 m .37934 .85497 L .37878 .85204 L F
.641 .481 .651 r
.37878 .85204 m .38134 .85209 L .38087 .84961 L F
.638 .465 .633 r
.37934 .85497 m .38134 .85209 L .37878 .85204 L F
.477 .205 .423 r
.35538 .78402 m .35744 .78393 L .35799 .78133 L F
.339 .085 .374 r
.35799 .78133 m .35894 .7833 L .36008 .78105 L F
.35799 .78133 m .35744 .78393 L .35894 .7833 L F
.541 .766 .981 r
.48202 .88399 m .4843 .88555 L .48595 .88505 L F
0 0 .012 r
.62118 .77838 m .62251 .77784 L .62396 .77669 L F
.62118 .77838 m .6213 .77887 L .62251 .77784 L F
.613 .047 0 r
.6732 .74084 m .67132 .74005 L .67059 .7393 L F
0 0 .506 r
.67059 .7393 m .67132 .74005 L .66945 .73688 L F
.467 .166 .371 r
.59566 .76258 m .59809 .76045 L .59585 .76081 L F
.622 .194 .208 r
.49751 .81375 m .49994 .8149 L .50104 .81353 L F
.591 .211 .292 r
.49994 .8149 m .50322 .81369 L .50104 .81353 L F
.383 .609 .939 r
.38126 .90057 m .38056 .89884 L .38038 .89907 L F
.38126 .90057 m .3822 .89929 L .38056 .89884 L F
.38126 .90057 m .38246 .90072 L .3822 .89929 L F
.661 .525 .687 r
.38802 .84438 m .39036 .8442 L .39009 .84171 L F
.669 .494 .638 r
.38799 .84665 m .39036 .8442 L .38802 .84438 L F
.645 .464 .624 r
.38134 .85209 m .38365 .84955 L .38087 .84961 L F
.31 .763 .955 r
.48366 .87545 m .48485 .87586 L .48157 .8756 L F
.882 .842 .379 r
.48627 .87324 m .48695 .87528 L .48485 .87586 L F
0 0 0 r
.48627 .87324 m .48485 .87586 L .48571 .87496 L F
.494 .858 .988 r
.48571 .87496 m .48485 .87586 L .48366 .87545 L F
.128 0 0 r
.48193 .87169 m .47855 .87152 L .48033 .87117 L F
.13 0 0 r
.48033 .87117 m .47855 .87152 L .47707 .87244 L F
0 0 0 r
.48627 .87324 m .48571 .87496 L .48474 .87267 L F
.482 .363 .641 r
.50568 .83805 m .50388 .83884 L .50363 .83636 L F
.649 .322 .404 r
.5057 .83666 m .50568 .83805 L .50363 .83636 L F
.482 .363 .641 r
.50568 .83805 m .50388 .83884 L .50363 .83636 L F
.614 .439 .622 r
.40944 .75539 m .40945 .75788 L .40724 .7581 L F
.551 .368 .587 r
.41161 .75278 m .41151 .75501 L .40944 .75539 L F
.59 .42 .619 r
.41166 .75756 m .40944 .75539 L .41151 .75501 L F
.41166 .75756 m .40945 .75788 L .40944 .75539 L F
.653 .505 .67 r
.42887 .85735 m .42675 .86 L .42686 .85788 L F
.205 .73 .835 r
.51678 .85465 m .51561 .855 L .51402 .85487 L F
.51678 .85465 m .5178 .85472 L .51561 .855 L F
.51561 .855 m .51678 .85465 L .51402 .85487 L F
.51561 .855 m .5178 .85472 L .51678 .85465 L F
.143 .002 .416 r
.6096 .81764 m .60867 .81841 L .60986 .81525 L F
.074 0 .315 r
.60826 .82045 m .60867 .81841 L .6096 .81764 L F
.5 .225 .429 r
.48069 .82039 m .48285 .81995 L .48309 .81839 L F
.593 .307 .452 r
.48285 .81995 m .48501 .8202 L .48309 .81839 L F
.101 0 0 r
.35847 .72147 m .35726 .72138 L .35513 .72115 L F
.35513 .72115 m .35726 .72138 L .35847 .72147 L F
.485 .89 .937 r
.35847 .72147 m .35726 .72138 L .35928 .72069 L F
.35928 .72069 m .35726 .72138 L .35847 .72147 L F
.255 0 0 r
.55344 .79253 m .5556 .79207 L .55729 .79091 L F
.266 .764 .892 r
.5556 .79207 m .55849 .792 L .55729 .79091 L F
.554 .861 .997 r
.57156 .84949 m .57336 .84868 L .57042 .84924 L F
.57156 .84949 m .57459 .84914 L .57336 .84868 L F
0 0 .433 r
.56404 .82904 m .56506 .83105 L .56375 .82816 L F
.461 .131 .319 r
.51892 .87981 m .51966 .87654 L .52281 .87617 L F
0 0 0 r
.65426 .76795 m .65721 .76667 L .65589 .76746 L F
.65721 .76667 m .65752 .76661 L .65589 .76746 L F
.65721 .76667 m .65937 .7661 L .65752 .76661 L F
.903 .966 .647 r
.48238 .85222 m .48092 .85395 L .48189 .85204 L F
.346 .483 .854 r
.48138 .84985 m .48238 .85222 L .48325 .85085 L F
.653 .891 .983 r
.48325 .85085 m .48238 .85222 L .48317 .85171 L F
.653 .593 .775 r
.53685 .85088 m .53849 .84897 L .53611 .84956 L F
.53685 .85088 m .53916 .85118 L .53849 .84897 L F
.63 .777 .952 r
.38859 .73698 m .38657 .73761 L .38525 .73647 L F
.829 .987 .719 r
.50704 .84002 m .50774 .83821 L .50902 .8396 L F
.544 .415 .655 r
.66131 .72628 m .65934 .72946 L .6593 .72684 L F
0 .508 .853 r
.65934 .72946 m .66217 .73027 L .66214 .73026 L F
.544 .415 .655 r
.66051 .72758 m .66187 .73018 L .65934 .72946 L F
0 .508 .853 r
.65934 .72946 m .66214 .73026 L .66064 .72951 L F
.581 .314 .477 r
.66191 .73026 m .66217 .73027 L .65934 .72946 L F
.544 .415 .655 r
.66187 .73018 m .66191 .73026 L .65934 .72946 L F
.66131 .72628 m .6616 .72819 L .66051 .72758 L F
.6616 .72819 m .66191 .73026 L .66051 .72758 L F
.933 .736 .256 r
.6593 .72684 m .65934 .72946 L .65898 .72838 L F
.65934 .72692 m .65898 .72838 L .66056 .7295 L F
.6593 .72684 m .65929 .7269 L .65934 .72692 L F
.65929 .7269 m .65898 .72838 L .65934 .72692 L F
.6593 .72684 m .66056 .7295 L .66131 .72628 L F
.314 .601 .948 r
.57459 .84914 m .57553 .8484 L .57336 .84868 L F
.57459 .84914 m .57659 .84961 L .57553 .8484 L F
.667 .886 .978 r
.4271 .88878 m .43028 .8885 L .42898 .88808 L F
.597 .891 .99 r
.42898 .88808 m .43028 .8885 L .43167 .88784 L F
.608 .459 .654 r
.44266 .8468 m .4422 .84851 L .44053 .84728 L F
.235 .433 .852 r
.68356 .74014 m .68565 .74128 L .68477 .7424 L F
.92 .941 .585 r
.68565 .74128 m .68468 .74474 L .68477 .7424 L F
.245 .743 .904 r
.43021 .89626 m .43165 .89652 L .42941 .89667 L F
.42941 .89667 m .43165 .89652 L .43021 .89626 L F
.737 .768 .878 r
.49363 .82116 m .49145 .82302 L .49454 .82317 L F
.778 .643 .712 r
.49145 .82302 m .49259 .82644 L .49454 .82317 L F
.76 .778 .868 r
.49363 .82116 m .49454 .82317 L .49696 .82102 L F
.468 .461 .766 r
.68071 .71318 m .68308 .71402 L .68198 .71018 L F
.548 .368 .589 r
.68071 .71318 m .68091 .7158 L .68308 .71402 L F
.611 .473 .669 r
.5102 .84679 m .50833 .84879 L .50843 .84723 L F
.786 .297 .05 r
.50991 .82868 m .51117 .83057 L .50839 .83013 L F
.50991 .82868 m .51211 .83106 L .51117 .83057 L F
.256 0 0 r
.5423 .84213 m .54544 .8418 L .54423 .84236 L F
.135 0 0 r
.54544 .8418 m .54622 .842 L .54423 .84236 L F
.54544 .8418 m .54759 .8421 L .54622 .842 L F
.738 .616 .722 r
.54019 .83101 m .54275 .82919 L .54305 .82854 L F
.276 .177 .557 r
.54305 .82854 m .54275 .82919 L .54424 .82802 L F
0 0 0 r
.53208 .81238 m .53025 .81461 L .53324 .81264 L F
.53208 .81238 m .53023 .81496 L .53025 .81461 L F
.714 .576 .698 r
.37341 .85741 m .37414 .85498 L .37117 .8548 L F
.689 .55 .691 r
.37341 .85741 m .37431 .85739 L .37414 .85498 L F
.654 .506 .67 r
.37431 .85739 m .37636 .85467 L .37414 .85498 L F
.389 .743 .992 r
.57228 .77891 m .5735 .77798 L .57144 .7781 L F
.689 .506 .634 r
.40483 .83361 m .40706 .8337 L .40699 .83133 L F
.607 .441 .631 r
.40706 .8337 m .40917 .83105 L .40699 .83133 L F
.385 .753 .992 r
.47917 .84999 m .48138 .84985 L .47796 .84923 L F
.208 0 .22 r
.62275 .75201 m .62134 .7523 L .62335 .75012 L F
.62275 .75201 m .62087 .75396 L .62134 .7523 L F
.156 0 0 r
.51392 .8279 m .5174 .82639 L .51408 .82579 L F
.51392 .8279 m .51591 .82755 L .5174 .82639 L F
.557 .057 .024 r
.51591 .82755 m .51919 .82772 L .5174 .82639 L F
.617 .395 .558 r
.40945 .75788 m .40705 .76024 L .40724 .7581 L F
.796 .727 .787 r
.54305 .81836 m .54087 .82082 L .54003 .81843 L F
.623 .068 0 r
.51087 .82048 m .5096 .82048 L .50768 .81925 L F
.637 .96 .797 r
.62251 .77784 m .62586 .77581 L .62396 .77669 L F
.706 .616 .754 r
.42677 .87344 m .42484 .87582 L .42363 .87267 L F
.556 .348 .553 r
.39106 .77113 m .39085 .77322 L .38885 .77352 L F
.509 .299 .53 r
.39308 .77075 m .39085 .77322 L .39106 .77113 L F
0 0 .07 r
.4422 .84851 m .44156 .85213 L .44137 .85216 L F
.394 .022 .209 r
.44189 .85346 m .44137 .85216 L .44156 .85213 L F
.44189 .85346 m .44038 .85408 L .44137 .85216 L F
.556 .781 .983 r
.50839 .83013 m .50785 .83177 L .50662 .83073 L F
.50839 .83013 m .50992 .83137 L .50785 .83177 L F
.65 .969 .878 r
.65342 .7542 m .65579 .75275 L .6568 .75266 L F
.47 .834 .993 r
.65579 .75275 m .65857 .7529 L .6568 .75266 L F
.611 .381 .544 r
.40391 .83601 m .40202 .83429 L .40161 .83598 L F
.40391 .83601 m .40483 .83361 L .40202 .83429 L F
.773 .733 .816 r
.63816 .72084 m .63955 .72366 L .63601 .72327 L F
.776 .726 .805 r
.63955 .72366 m .63724 .72452 L .63601 .72327 L F
.87 .644 .593 r
.45636 .8464 m .45557 .84399 L .45687 .84446 L F
.728 .615 .732 r
.48558 .84169 m .48333 .84435 L .48249 .84096 L F
.58 .402 .604 r
.48574 .84369 m .48333 .84435 L .48558 .84169 L F
.545 .185 .308 r
.53244 .83366 m .52919 .83577 L .53024 .83333 L F
.578 .435 .651 r
.65236 .73101 m .65435 .73168 L .65438 .72937 L F
0 0 .061 r
.60322 .83827 m .60372 .8363 L .60502 .83546 L F
.796 .727 .787 r
.54305 .81836 m .54003 .81843 L .54117 .81705 L F
.531 .895 .689 r
.56383 .77635 m .56485 .77538 L .56617 .77463 L F
.55 .931 .846 r
.56383 .77635 m .56304 .77642 L .56485 .77538 L F
.475 .185 .393 r
.38603 .77619 m .38348 .77836 L .38404 .77652 L F
.432 .142 .37 r
.36443 .79356 m .36298 .79241 L .36531 .79139 L F
.36443 .79356 m .36243 .79414 L .36298 .79241 L F
.096 0 0 r
.46981 .88292 m .47327 .88293 L .47215 .88295 L F
.402 0 0 r
.47327 .88293 m .47407 .88349 L .47215 .88295 L F
.47327 .88293 m .47537 .88293 L .47407 .88349 L F
.683 .252 .219 r
.59137 .77375 m .58979 .77494 L .58745 .77332 L F
.547 .042 .007 r
.59259 .77457 m .58979 .77494 L .59137 .77375 L F
.83 .77 .795 r
.62656 .7419 m .62988 .74 L .62885 .73945 L F
.62656 .7419 m .62768 .74264 L .62988 .74 L F
.588 .616 .847 r
.56093 .78917 m .56167 .78642 L .56242 .78661 L F
.75 .981 .914 r
.56498 .78449 m .56242 .78661 L .5635 .78481 L F
.961 .839 .416 r
.4508 .85709 m .45017 .85952 L .45072 .85676 L F
.769 .537 .582 r
.54851 .83356 m .54876 .83131 L .54534 .83102 L F
.106 0 0 r
.54534 .83102 m .54779 .83123 L .54745 .83123 L F
.187 0 0 r
.54534 .83102 m .5483 .83132 L .548 .83134 L F
.54534 .83102 m .548 .83134 L .54759 .83135 L F
.54534 .83102 m .54767 .83137 L .547 .83138 L F
.54534 .83102 m .54697 .83137 L .54424 .82802 L F
.54759 .83135 m .548 .83134 L .54767 .83137 L F
.106 0 0 r
.54745 .83123 m .54876 .83131 L .5483 .83132 L F
.54779 .83123 m .54876 .83131 L .54745 .83123 L F
.832 .921 .894 r
.54948 .83033 m .54767 .83137 L .547 .83138 L F
.54839 .83135 m .54715 .83252 L .54636 .83139 L F
.187 0 0 r
.547 .83138 m .54767 .83137 L .54712 .8314 L F
.75 .987 .899 r
.54712 .8314 m .54767 .83137 L .54948 .83033 L F
.54767 .83137 m .5483 .83132 L .54948 .83033 L F
.832 .921 .894 r
.54948 .83033 m .54839 .83135 L .54767 .83137 L F
.187 0 0 r
.54697 .83137 m .547 .83138 L .547 .83126 L F
.547 .83138 m .54701 .83127 L .547 .83126 L F
.832 .921 .894 r
.54701 .83117 m .547 .83138 L .54636 .83139 L F
.54711 .83133 m .547 .83138 L .54701 .83127 L F
.187 0 0 r
.547 .83138 m .54712 .8314 L .54701 .83127 L F
.718 .203 0 r
.54697 .83124 m .54712 .8314 L .54694 .83124 L F
.187 0 0 r
.54697 .83137 m .547 .83126 L .54424 .82802 L F
.718 .203 0 r
.54698 .83124 m .54701 .83127 L .54697 .83124 L F
.54701 .83127 m .54712 .8314 L .54697 .83124 L F
.832 .921 .894 r
.54948 .83033 m .54711 .83133 L .54701 .83117 L F
.54711 .83133 m .54701 .83127 L .54701 .83117 L F
.54948 .83033 m .54701 .83117 L .54858 .82987 L F
.54701 .83117 m .54636 .83139 L .54706 .83091 L F
.718 .203 0 r
.54424 .82802 m .54694 .83119 L .54495 .82952 L F
.54694 .83119 m .54698 .83124 L .5469 .83117 L F
.54694 .83119 m .5469 .83117 L .54495 .82952 L F
.54698 .83124 m .54697 .83124 L .54495 .82952 L F
.54697 .83124 m .54694 .83124 L .54688 .83119 L F
.54697 .83124 m .54688 .83119 L .54495 .82952 L F
.832 .921 .894 r
.54636 .83139 m .54633 .83139 L .54674 .83112 L F
.734 .692 .811 r
.54665 .82815 m .54707 .83105 L .54858 .82987 L F
.832 .921 .894 r
.54701 .83117 m .54703 .83109 L .54858 .82987 L F
.734 .692 .811 r
.54707 .83105 m .54712 .8314 L .54858 .82987 L F
.832 .921 .894 r
.54703 .83109 m .54703 .83107 L .54858 .82987 L F
.743 .709 .819 r
.54495 .82952 m .54677 .8311 L .54858 .82987 L F
.54678 .8311 m .54688 .83119 L .54858 .82987 L F
.832 .921 .894 r
.54675 .83112 m .54674 .83112 L .54858 .82987 L F
.54636 .83139 m .54674 .83112 L .54675 .83112 L F
.736 .988 .891 r
.54667 .83041 m .54858 .82987 L .54674 .83112 L F
.54645 .83101 m .54674 .83112 L .54631 .8314 L F
.54667 .83041 m .54674 .83112 L .54645 .83101 L F
.743 .709 .819 r
.54688 .83119 m .54712 .8314 L .54858 .82987 L F
.832 .921 .894 r
.54703 .83107 m .54706 .83091 L .54858 .82987 L F
.54636 .83139 m .54631 .8314 L .54633 .83139 L F
.54636 .83139 m .54715 .83252 L .54631 .8314 L F
.617 .941 .736 r
.5483 .83132 m .54876 .83131 L .54948 .83033 L F
0 0 .182 r
.54948 .83033 m .54876 .83131 L .54851 .83356 L F
.592 .448 .654 r
.40575 .90201 m .40624 .90464 L .40383 .9046 L F
.40575 .90201 m .40624 .90464 L .40383 .9046 L F
.559 .417 .645 r
.36236 .77876 m .36423 .77603 L .36222 .77638 L F
.296 .767 .937 r
.65707 .76013 m .65576 .76066 L .65592 .75997 L F
.65707 .76013 m .65801 .76048 L .65576 .76066 L F
.594 .454 .66 r
.40139 .74496 m .40169 .74717 L .39952 .74758 L F
.603 .527 .742 r
.40232 .75024 m .39952 .74758 L .40169 .74717 L F
.053 0 0 r
.49361 .81743 m .4929 .81825 L .49495 .8175 L F
.852 .926 .878 r
.6315 .72629 m .62796 .72799 L .63011 .72568 L F
.6315 .72629 m .6301 .72754 L .62796 .72799 L F
.835 .882 .876 r
.6315 .72629 m .63279 .72303 L .63393 .72422 L F
.6315 .72629 m .63011 .72568 L .63279 .72303 L F
.644 .494 .665 r
.48431 .83905 m .48249 .84096 L .48221 .83884 L F
.146 .663 .891 r
.40806 .7522 m .41015 .75242 L .41161 .75278 L F
.475 .282 .538 r
.41355 .75015 m .41344 .75237 L .41161 .75278 L F
.41161 .75278 m .41344 .75237 L .41355 .75015 L F
.124 0 0 r
.41015 .75242 m .41344 .75237 L .41161 .75278 L F
.554 .401 .628 r
.41344 .75237 m .41151 .75501 L .41161 .75278 L F
.792 .717 .781 r
.68402 .70522 m .68316 .70873 L .68171 .70825 L F
.714 .576 .698 r
.37341 .85741 m .37117 .8548 L .37174 .85742 L F
0 0 .007 r
.60709 .82816 m .60769 .82613 L .60844 .82512 L F
.654 .496 .656 r
.48389 .87101 m .48583 .87052 L .48598 .86799 L F
.106 .65 .838 r
.57982 .84946 m .58087 .84929 L .57871 .8491 L F
.57982 .84946 m .58202 .84952 L .58087 .84929 L F
.703 .549 .677 r
.37208 .85981 m .37341 .85741 L .37174 .85742 L F
.538 .152 .258 r
.50919 .83624 m .50568 .83805 L .5057 .83666 L F
.50919 .83624 m .50774 .83821 L .50568 .83805 L F
.476 .035 .12 r
.51107 .83656 m .50774 .83821 L .50919 .83624 L F
.747 .258 .076 r
.52766 .87545 m .52775 .87503 L .52528 .87367 L F
.007 0 0 r
.52985 .87369 m .52775 .87503 L .52766 .87545 L F
.544 .342 .556 r
.61016 .76781 m .60808 .76594 L .60971 .76538 L F
.61016 .76781 m .60764 .76828 L .60808 .76594 L F
.53 .169 .299 r
.52628 .82802 m .52488 .83042 L .52269 .83058 L F
.509 .271 .489 r
.52628 .82802 m .5279 .82866 L .52856 .82634 L F
.343 .422 .799 r
.52709 .82587 m .5279 .82866 L .52628 .82802 L F
.554 .2 .322 r
.5279 .82866 m .52488 .83042 L .52628 .82802 L F
.635 .487 .665 r
.39036 .8442 m .39236 .84134 L .39009 .84171 L F
.501 .093 .199 r
.59558 .77337 m .595 .77522 L .59259 .77457 L F
.355 .099 .381 r
.59792 .77092 m .59767 .7731 L .59558 .77337 L F
.717 .506 .604 r
.59767 .7731 m .595 .77522 L .59558 .77337 L F
0 0 .106 r
.46063 .86449 m .46014 .86525 L .46024 .86442 L F
.46063 .86449 m .46024 .86442 L .46045 .86278 L F
.507 .009 .007 r
.45924 .86459 m .4608 .86453 L .46063 .86449 L F
.23 .734 .899 r
.46304 .86444 m .46201 .86483 L .46063 .86449 L F
.507 .009 .007 r
.4608 .86453 m .46304 .86444 L .46063 .86449 L F
0 0 .106 r
.46063 .86449 m .46045 .86278 L .45923 .86204 L F
.405 0 0 r
.52289 .82527 m .52167 .82602 L .52492 .82544 L F
.682 .482 .609 r
.37421 .85969 m .37341 .85741 L .37208 .85981 L F
.37421 .85969 m .37431 .85739 L .37341 .85741 L F
.776 .738 .819 r
.49411 .84396 m .4914 .84482 L .49075 .84399 L F
.76 .87 .928 r
.49492 .84157 m .49411 .84396 L .49623 .84379 L F
.49492 .84157 m .4914 .84482 L .49411 .84396 L F
.127 0 0 r
.52528 .87367 m .52238 .87595 L .52566 .87598 L F
0 0 0 r
.52456 .87761 m .52566 .87598 L .52483 .87728 L F
.637 .197 .188 r
.52483 .87728 m .52566 .87598 L .52238 .87595 L F
.747 .258 .076 r
.52766 .87545 m .52528 .87367 L .52566 .87598 L F
.618 .705 .907 r
.56191 .79624 m .56319 .79764 L .56026 .79689 L F
.749 .739 .843 r
.56547 .79632 m .56319 .79764 L .56191 .79624 L F
.474 0 0 r
.37129 .74757 m .36828 .74771 L .36954 .74742 L F
.565 .242 .379 r
.45705 .82774 m .45927 .82771 L .45744 .82618 L F
.478 .312 .577 r
.68683 .7327 m .68746 .73203 L .68686 .73444 L F
.68686 .73444 m .68746 .73203 L .68683 .7327 L F
.912 .94 .811 r
.64876 .71622 m .64608 .71827 L .64677 .71887 L F
.964 .929 .706 r
.64527 .71982 m .64677 .71887 L .64608 .71827 L F
.775 .824 .89 r
.57131 .82952 m .57567 .82897 L .57392 .82925 L F
.931 .97 .74 r
.57538 .82767 m .57567 .82897 L .57736 .82602 L F
.881 .973 .838 r
.57392 .82925 m .57567 .82897 L .57538 .82767 L F
.725 .622 .742 r
.48431 .83905 m .48558 .84169 L .48249 .84096 L F
.527 .873 .989 r
.48691 .84055 m .48558 .84169 L .48844 .84132 L F
.48691 .84055 m .48432 .84128 L .48558 .84169 L F
.964 .696 .478 r
.48432 .84128 m .48574 .84369 L .48558 .84169 L F
.821 .576 .568 r
.66787 .72664 m .66397 .7236 L .66617 .72447 L F
.66787 .72664 m .66275 .72602 L .66397 .7236 L F
.815 .706 .745 r
.66787 .72664 m .66516 .72862 L .66275 .72602 L F
.469 .67 .951 r
.66833 .72483 m .66787 .72664 L .66617 .72447 L F
.66833 .72483 m .66948 .72604 L .66787 .72664 L F
.77 .553 0 r
.66957 .72839 m .66787 .72664 L .66948 .72604 L F
.994 .746 .41 r
.54344 .79758 m .5426 .79893 L .54254 .7964 L F
.821 .408 .263 r
.54405 .79878 m .5426 .79893 L .54344 .79758 L F
.317 .169 .516 r
.53103 .87113 m .52994 .87096 L .52985 .87369 L F
.423 0 0 r
.50668 .81423 m .50845 .81508 L .50977 .81546 L F
0 0 .431 r
.5104 .81585 m .50977 .81546 L .50845 .81508 L F
.5104 .81585 m .51116 .81886 L .50977 .81546 L F
.303 .765 .947 r
.57409 .80452 m .57524 .80497 L .57279 .80509 L F
.57409 .80452 m .57524 .80497 L .57279 .80509 L F
.432 .702 .978 r
.57736 .82602 m .57455 .82486 L .57632 .82544 L F
.931 .97 .74 r
.57538 .82767 m .57736 .82602 L .57632 .82544 L F
.923 .561 .131 r
.57554 .82036 m .57622 .82079 L .57483 .81801 L F
.567 .151 .213 r
.43965 .87214 m .44173 .87262 L .44345 .87117 L F
.526 .636 .902 r
.44416 .86964 m .44575 .8719 L .44345 .87117 L F
.752 .402 .39 r
.44173 .87262 m .44487 .87307 L .44345 .87117 L F
.222 .272 .703 r
.44345 .87117 m .44487 .87307 L .44416 .86964 L F
.494 .835 .998 r
.41612 .89053 m .41977 .89075 L .41822 .88981 L F
.6 .734 .939 r
.41977 .89075 m .42052 .88844 L .41822 .88981 L F
.792 .93 .925 r
.40543 .89318 m .409 .89124 L .40737 .89082 L F
.48 .853 .986 r
.409 .89124 m .40941 .89035 L .40737 .89082 L F
.409 .89124 m .41111 .8908 L .40941 .89035 L F
.621 .42 .589 r
.36876 .77087 m .37121 .77096 L .37145 .76838 L F
.552 .361 .575 r
.37145 .76838 m .37334 .77034 L .37312 .76788 L F
.37145 .76838 m .37121 .77096 L .37334 .77034 L F
0 0 0 r
.51733 .82002 m .51611 .82032 L .51815 .81951 L F
.51733 .82002 m .51517 .82056 L .51611 .82032 L F
.489 .198 .398 r
.38885 .77352 m .38803 .77589 L .38603 .77619 L F
.537 .253 .432 r
.39085 .77322 m .38803 .77589 L .38885 .77352 L F
.572 .332 .514 r
.43143 .86805 m .4311 .8705 L .42861 .87024 L F
.272 .064 .403 r
.43324 .8652 m .43143 .86805 L .4301 .86505 L F
.43324 .8652 m .43286 .86764 L .43143 .86805 L F
.557 .319 .511 r
.43315 .86992 m .43143 .86805 L .43286 .86764 L F
.43315 .86992 m .4311 .8705 L .43143 .86805 L F
.352 .334 .7 r
.66129 .75229 m .6599 .75507 L .65857 .7529 L F
.66129 .75229 m .66138 .75448 L .6599 .75507 L F
.746 .598 .692 r
.66138 .75448 m .65928 .75731 L .6599 .75507 L F
.654 .506 .67 r
.37431 .85739 m .37669 .85718 L .37636 .85467 L F
.674 .495 .636 r
.37421 .85969 m .37669 .85718 L .37431 .85739 L F
.457 .467 .78 r
.40423 .74999 m .40317 .75197 L .40232 .75024 L F
.40423 .74999 m .40491 .75177 L .40317 .75197 L F
.628 .942 .954 r
.35128 .75247 m .34999 .75234 L .35068 .75278 L F
0 .428 .775 r
.35068 .75278 m .34929 .75211 L .34847 .7526 L F
.532 .908 .951 r
.35191 .75164 m .35001 .75234 L .35128 .75247 L F
.35001 .75234 m .34999 .75234 L .35128 .75247 L F
.284 0 .156 r
.3522 .75422 m .34993 .75496 L .35117 .75187 L F
.176 0 0 r
.35119 .75183 m .34999 .75234 L .35195 .75159 L F
.284 0 .156 r
.3512 .75186 m .35117 .75187 L .35119 .75183 L F
.532 .908 .951 r
.3525 .75167 m .35128 .75247 L .35323 .75177 L F
.284 0 .156 r
.3522 .75422 m .3512 .75184 L .35282 .75343 L F
.3512 .75184 m .35119 .75183 L .3512 .75184 L F
.3512 .75184 m .3512 .75184 L .35282 .75343 L F
.532 .908 .951 r
.352 .7516 m .35187 .75175 L .3525 .75167 L F
.35187 .75175 m .35128 .75247 L .3525 .75167 L F
.35195 .75159 m .35193 .75162 L .352 .7516 L F
.35193 .75162 m .35128 .75247 L .352 .7516 L F
.204 .731 .825 r
.35531 .75131 m .35195 .75159 L .35323 .75177 L F
.414 .053 .24 r
.35394 .75131 m .35282 .75343 L .3512 .75184 L F
.35134 .7518 m .3512 .75184 L .35119 .75183 L F
.35394 .75131 m .3512 .75184 L .35134 .7518 L F
.284 0 .156 r
.3522 .75422 m .35117 .75187 L .3512 .75186 L F
.532 .908 .951 r
.35001 .75234 m .34999 .75234 L .34999 .75234 L F
.35195 .75159 m .35141 .7518 L .35191 .75164 L F
.35141 .7518 m .34999 .75234 L .35191 .75164 L F
0 .428 .775 r
.35068 .75278 m .34999 .75234 L .34961 .75226 L F
.35068 .75278 m .34929 .75211 L .34847 .7526 L F
.35068 .75278 m .34999 .75234 L .34929 .75211 L F
.434 .055 .22 r
.35112 .75189 m .34993 .75496 L .34858 .75406 L F
.35119 .75183 m .35117 .75187 L .35112 .75189 L F
.35117 .75187 m .34993 .75496 L .35112 .75189 L F
.176 0 0 r
.35119 .75183 m .35046 .75245 L .34999 .75234 L F
.35046 .75245 m .34858 .75406 L .34999 .75234 L F
0 .428 .775 r
.34961 .75226 m .34999 .75234 L .34929 .75211 L F
.912 .94 .811 r
.64876 .71622 m .64784 .71576 L .64608 .71827 L F
.994 .768 .482 r
.64809 .713 m .64784 .71576 L .64876 .71622 L F
.416 .176 .439 r
.61824 .80001 m .6205 .7976 L .61989 .79939 L F
.38 .182 .482 r
.61803 .80218 m .61824 .80001 L .61989 .79939 L F
.896 .721 .657 r
.62656 .7419 m .62769 .74489 L .62768 .74264 L F
0 0 0 r
.45975 .88534 m .46455 .88344 L .46369 .8836 L F
.463 .829 .993 r
.46455 .88344 m .46663 .88309 L .4653 .8826 L F
.564 .935 .825 r
.46369 .8836 m .46455 .88344 L .4653 .8826 L F
.384 .499 .852 r
.68426 .72923 m .68492 .72862 L .68293 .72656 L F
.502 .373 .637 r
.68426 .72923 m .6866 .73135 L .68475 .73198 L F
.125 .08 .531 r
.68506 .73166 m .68426 .72923 L .68475 .73198 L F
.68493 .72891 m .68492 .72862 L .68426 .72923 L F
.233 .337 .766 r
.68548 .72816 m .68562 .72857 L .68426 .72923 L F
.68493 .72891 m .68571 .73055 L .68426 .72923 L F
.125 .08 .531 r
.68506 .73166 m .68493 .72891 L .68426 .72923 L F
.489 .633 .917 r
.68492 .72862 m .68454 .72839 L .68293 .72656 L F
.296 .446 .841 r
.68293 .72656 m .68381 .72756 L .68426 .72923 L F
.68366 .72702 m .68455 .7283 L .68426 .72923 L F
.489 .633 .917 r
.68454 .72839 m .68005 .72573 L .68293 .72656 L F
.296 .446 .841 r
.68293 .72656 m .68366 .72702 L .68381 .72756 L F
.489 .633 .917 r
.68492 .72862 m .6846 .72785 L .68454 .72839 L F
.901 .841 .777 r
.68481 .72867 m .6846 .72785 L .68492 .72862 L F
.68481 .72867 m .68482 .72867 L .68482 .72868 L F
.296 .446 .841 r
.68366 .72702 m .68548 .72816 L .68484 .72872 L F
.747 .648 .751 r
.68099 .72378 m .68293 .72656 L .68005 .72573 L F
.175 .391 .835 r
.68099 .72378 m .68367 .72583 L .68293 .72656 L F
0 .371 .835 r
.68496 .72721 m .68548 .72816 L .68463 .72763 L F
.68383 .72685 m .68443 .72743 L .68293 .72656 L F
.68443 .72743 m .68453 .72756 L .68293 .72656 L F
.489 .633 .917 r
.68454 .72839 m .68421 .72722 L .68413 .72714 L F
0 .371 .835 r
.68383 .72685 m .68293 .72656 L .68376 .72602 L F
.68382 .72614 m .68376 .72602 L .68382 .72599 L F
.68383 .72685 m .68376 .72602 L .68382 .72614 L F
.489 .633 .917 r
.68384 .72798 m .68382 .72632 L .68306 .72751 L F
.68382 .72632 m .68382 .72621 L .68306 .72751 L F
.68306 .72751 m .68382 .72621 L .68005 .72573 L F
.779 .645 .714 r
.67954 .72729 m .68387 .72624 L .68119 .73043 L F
.489 .633 .917 r
.68413 .72714 m .68393 .72623 L .68382 .72621 L F
.779 .645 .714 r
.68387 .72624 m .68393 .72623 L .68389 .72629 L F
.68387 .72624 m .68389 .72629 L .68119 .73043 L F
.489 .633 .917 r
.68454 .72839 m .68382 .72621 L .68384 .72798 L F
.6846 .72785 m .68393 .72623 L .68454 .72839 L F
.901 .841 .777 r
.68119 .73043 m .68374 .72653 L .6846 .72785 L F
.489 .633 .917 r
.68421 .72722 m .68393 .72623 L .68413 .72714 L F
0 .371 .835 r
.68383 .726 m .68383 .72685 L .68382 .72599 L F
.901 .841 .777 r
.68403 .72691 m .68393 .72623 L .68443 .72743 L F
.68389 .72629 m .68393 .72623 L .68403 .72691 L F
0 .371 .835 r
.68496 .72721 m .68403 .72691 L .68383 .726 L F
.68403 .72691 m .68383 .72685 L .68383 .726 L F
.901 .841 .777 r
.68374 .72653 m .68389 .72629 L .68403 .72691 L F
.68374 .72653 m .68443 .72743 L .6846 .72785 L F
0 .371 .835 r
.68443 .72743 m .68463 .72763 L .68453 .72756 L F
.68496 .72721 m .68463 .72763 L .68383 .72685 L F
.68382 .72599 m .68293 .72656 L .68367 .72583 L F
.296 .446 .841 r
.68455 .7283 m .68481 .72867 L .68447 .72905 L F
.901 .841 .777 r
.68119 .73043 m .6846 .72785 L .68481 .72867 L F
.296 .446 .841 r
.68481 .72867 m .68484 .72872 L .68482 .72873 L F
.68481 .72867 m .68482 .72873 L .68447 .72905 L F
.68455 .7283 m .68447 .72905 L .68426 .72923 L F
.901 .841 .777 r
.68119 .73043 m .68481 .72867 L .68506 .73166 L F
.68481 .72867 m .68482 .72868 L .68506 .73166 L F
.68482 .72867 m .68492 .72862 L .68493 .72891 L F
.68482 .72867 m .68493 .72891 L .68506 .73166 L F
.233 .337 .766 r
.68562 .72857 m .6866 .73135 L .68571 .73055 L F
.68562 .72857 m .68571 .73055 L .68493 .72891 L F
.049 .216 .715 r
.55229 .8406 m .54961 .83633 L .55171 .83573 L F
.453 .153 .366 r
.39962 .7678 m .39956 .76586 L .40026 .76489 L F
.526 .295 .506 r
.40279 .76288 m .4022 .7645 L .40026 .76489 L F
.506 .227 .425 r
.4022 .7645 m .39962 .7678 L .40026 .76489 L F
.848 .467 0 r
.54279 .8097 m .5442 .81251 L .54343 .81048 L F
.384 .778 .987 r
.40676 .75165 m .40597 .75237 L .40491 .75177 L F
.40676 .75165 m .40806 .7522 L .40597 .75237 L F
.061 0 .1 r
.60866 .79909 m .60732 .80008 L .60627 .80167 L F
.199 0 0 r
.6398 .7656 m .64285 .7642 L .64118 .76506 L F
.6398 .7656 m .64199 .7651 L .64285 .7642 L F
0 0 0 r
.64285 .7642 m .64465 .76317 L .6452 .7633 L F
.64285 .7642 m .64199 .7651 L .64465 .76317 L F
.682 .949 .957 r
.53853 .83073 m .5381 .83184 L .54019 .83101 L F
.92 .916 .796 r
.54075 .82713 m .54019 .83101 L .54305 .82854 L F
.54075 .82713 m .53853 .83073 L .54019 .83101 L F
.306 .136 .479 r
.6096 .81764 m .60986 .81525 L .61205 .81477 L F
.791 .561 .589 r
.45261 .86454 m .44925 .8625 L .45162 .86226 L F
.45261 .86454 m .44963 .86458 L .44925 .8625 L F
.758 .439 .446 r
.45261 .86454 m .45147 .86572 L .44963 .86458 L F
.542 0 0 r
.45261 .86454 m .45343 .86539 L .45147 .86572 L F
.45261 .86454 m .45454 .86543 L .45343 .86539 L F
.685 .551 .696 r
.42877 .85984 m .42675 .86 L .42887 .85735 L F
.726 .554 .658 r
.42877 .85984 m .42668 .86228 L .42675 .86 L F
.527 .291 .501 r
.41581 .74997 m .41344 .75237 L .41355 .75015 L F
.41581 .74997 m .41344 .75237 L .41355 .75015 L F
.445 0 0 r
.54059 .84796 m .53849 .84897 L .54069 .84803 L F
.41 0 0 r
.54069 .84803 m .54342 .84917 L .54059 .84796 L F
.97 .723 .507 r
.49211 .85999 m .49212 .86271 L .49091 .85944 L F
.553 .545 .799 r
.49091 .85944 m .49416 .86248 L .49211 .85999 L F
.611 .23 .296 r
.49711 .87656 m .49554 .87569 L .49501 .87757 L F
.446 0 0 r
.51857 .83502 m .51775 .83596 L .51525 .83581 L F
.445 .704 .977 r
.51525 .83581 m .51775 .83596 L .51745 .83566 L F
.401 .02 .197 r
.51731 .83335 m .51525 .83581 L .51356 .83593 L F
.705 .384 .43 r
.51857 .83502 m .51525 .83581 L .51731 .83335 L F
.445 .704 .977 r
.51525 .83581 m .51745 .83566 L .51616 .83434 L F
.401 .02 .197 r
.51356 .83593 m .51525 .83581 L .51324 .83615 L F
.208 0 .22 r
.62275 .75201 m .62335 .75012 L .62228 .75004 L F
.957 .83 .677 r
.62299 .74748 m .62228 .75004 L .62335 .75012 L F
.646 .491 .659 r
.37669 .85718 m .37934 .85497 L .37636 .85467 L F
.878 .819 .786 r
.53291 .82077 m .53298 .82258 L .53218 .82274 L F
.598 .376 .551 r
.40917 .83105 m .41124 .83069 L .41141 .82866 L F
.666 .43 .554 r
.41124 .83069 m .41453 .82827 L .41141 .82866 L F
0 0 0 r
.65426 .76795 m .65589 .76746 L .65409 .76836 L F
.348 .088 .371 r
.36012 .79656 m .3608 .79471 L .36243 .79414 L F
.415 0 .075 r
.47049 .82357 m .47236 .82342 L .47321 .82287 L F
.52 .099 .183 r
.47321 .82287 m .47236 .82342 L .47543 .82294 L F
.66 .564 .736 r
.39464 .83895 m .39648 .83629 L .3943 .83647 L F
.671 .357 .433 r
.48257 .87209 m .48389 .87101 L .48474 .87267 L F
.591 .327 .484 r
.48474 .87267 m .48389 .87101 L .48257 .87209 L F
.48474 .87267 m .48583 .87052 L .48389 .87101 L F
.873 .654 .603 r
.48138 .86243 m .48286 .86446 L .48135 .86525 L F
.635 .548 .739 r
.48416 .86314 m .48286 .86446 L .48138 .86243 L F
.48416 .86314 m .48465 .86577 L .48286 .86446 L F
.758 .254 .013 r
.48286 .86446 m .48386 .86657 L .48135 .86525 L F
.48286 .86446 m .48465 .86577 L .48386 .86657 L F
.151 0 0 r
.57298 .82575 m .57328 .82466 L .57455 .82486 L F
0 .427 .766 r
.57527 .82493 m .57328 .82466 L .5741 .82297 L F
.307 0 .013 r
.57031 .77348 m .57376 .77146 L .57103 .77282 L F
.724 .564 .673 r
.51991 .83859 m .51775 .83892 L .51964 .83645 L F
0 0 .068 r
.51775 .83892 m .51861 .83886 L .51964 .83645 L F
.604 .49 .697 r
.52175 .83609 m .51991 .83859 L .51964 .83645 L F
.52145 .8365 m .5221 .83836 L .51991 .83859 L F
.52175 .83609 m .52181 .83649 L .52145 .8365 L F
.52181 .83649 m .5221 .83836 L .52145 .8365 L F
.539 .197 .337 r
.51971 .83655 m .51861 .83886 L .52091 .83853 L F
.51964 .83645 m .5196 .83655 L .51971 .83655 L F
.5196 .83655 m .51861 .83886 L .51971 .83655 L F
.51964 .83645 m .52091 .83853 L .52175 .83609 L F
.621 .638 .846 r
.40237 .73991 m .40071 .74178 L .40028 .74056 L F
.40237 .73991 m .40302 .7419 L .40071 .74178 L F
.523 .378 .626 r
.40302 .7419 m .40139 .74496 L .40071 .74178 L F
.52 .25 .445 r
.47013 .8256 m .47236 .82342 L .47049 .82357 L F
.751 .607 .698 r
.45162 .86226 m .44812 .85982 L .45017 .85952 L F
.45162 .86226 m .44925 .8625 L .44812 .85982 L F
.748 .707 .813 r
.45383 .85969 m .45162 .86226 L .45048 .86011 L F
.881 .656 .593 r
.44925 .8625 m .44808 .86262 L .44812 .85982 L F
.579 .164 .219 r
.44962 .86022 m .44738 .86171 L .4515 .86072 L F
.44812 .85982 m .44787 .86045 L .44962 .86022 L F
.44787 .86045 m .44738 .86171 L .44962 .86022 L F
.748 .707 .813 r
.45369 .85968 m .45048 .86011 L .45017 .85952 L F
.45383 .85969 m .45048 .86011 L .45369 .85968 L F
.776 .69 .768 r
.60194 .74185 m .60316 .74491 L .59983 .7445 L F
.997 .778 .43 r
.60316 .74491 m .60231 .74464 L .59983 .7445 L F
.60316 .74491 m .60311 .74738 L .60231 .74464 L F
.647 .625 .813 r
.60553 .74456 m .60316 .74491 L .60194 .74185 L F
.738 .538 .623 r
.6063 .7474 m .60316 .74491 L .60553 .74456 L F
.6063 .7474 m .60311 .74738 L .60316 .74491 L F
0 0 .391 r
.60478 .80244 m .60579 .80358 L .60627 .80167 L F
.60478 .80244 m .60483 .80468 L .60579 .80358 L F
0 0 .562 r
.54873 .8183 m .54813 .81834 L .54733 .81655 L F
.565 .094 0 r
.54787 .81727 m .54898 .8186 L .54873 .8183 L F
0 .156 .603 r
.54955 .81928 m .54813 .81834 L .54873 .8183 L F
.565 .094 0 r
.54898 .8186 m .54955 .81928 L .54873 .8183 L F
0 0 .562 r
.54873 .8183 m .54733 .81655 L .5469 .81558 L F
.874 .447 .037 r
.54967 .81932 m .54955 .81928 L .54959 .81867 L F
.54992 .82146 m .55075 .82197 L .54955 .81928 L F
.54992 .82146 m .54955 .81928 L .54967 .81932 L F
0 .156 .603 r
.54955 .81928 m .55057 .82006 L .54943 .81925 L F
.54955 .81928 m .54943 .81925 L .54813 .81834 L F
.228 0 .208 r
.66131 .72628 m .66397 .7236 L .66148 .72399 L F
.667 .427 .549 r
.6002 .77075 m .59767 .7731 L .59792 .77092 L F
.127 0 0 r
.52556 .81741 m .52156 .81822 L .52378 .8177 L F
.751 .88 .938 r
.38419 .74659 m .38355 .74811 L .38602 .74732 L F
.268 .714 .96 r
.38419 .74659 m .38602 .74732 L .38715 .74712 L F
.292 .339 .739 r
.38602 .74732 m .38774 .74892 L .38715 .74712 L F
.285 .022 .327 r
.61989 .79939 m .6205 .7976 L .62212 .79684 L F
.396 .831 .952 r
.44317 .88582 m .44391 .88514 L .44191 .88534 L F
.44317 .88582 m .44555 .8854 L .44391 .88514 L F
.597 .648 .871 r
.37838 .73071 m .37686 .73118 L .37557 .72899 L F
.834 .886 .879 r
.63118 .73724 m .63386 .73688 L .63246 .73612 L F
.745 .863 .934 r
.63246 .73612 m .63386 .73688 L .63629 .73512 L F
.721 .412 .456 r
.46187 .84697 m .45833 .84885 L .4587 .8469 L F
.46187 .84697 m .46084 .84928 L .45833 .84885 L F
.705 .394 .449 r
.46187 .84697 m .46449 .84977 L .46084 .84928 L F
.787 .309 .095 r
.46507 .84931 m .46449 .84977 L .46187 .84697 L F
.581 .168 .224 r
.51489 .81489 m .51608 .81462 L .51605 .81474 L F
.52 .878 .649 r
.51602 .81491 m .51605 .81474 L .51664 .81441 L F
0 0 0 r
.51664 .81441 m .51605 .81474 L .51806 .81418 L F
.581 .168 .224 r
.51608 .81462 m .51806 .81418 L .51605 .81474 L F
.52 .878 .649 r
.51514 .81561 m .51605 .81474 L .51602 .81491 L F
.522 .914 .92 r
.51514 .81561 m .5141 .81556 L .51605 .81474 L F
.271 0 0 r
.40186 .89481 m .40026 .89535 L .39805 .89515 L F
.634 .259 .317 r
.40365 .89385 m .40026 .89535 L .40186 .89481 L F
.40365 .89385 m .40233 .89601 L .40026 .89535 L F
.385 .595 .929 r
.40026 .89535 m .40233 .89601 L .40182 .8955 L F
.40026 .89535 m .40182 .8955 L .40097 .89466 L F
.271 0 0 r
.39805 .89515 m .40026 .89535 L .39758 .89519 L F
.539 .171 .29 r
.52156 .81822 m .52271 .81988 L .52036 .81999 L F
.116 0 0 r
.52556 .81741 m .52271 .81988 L .52156 .81822 L F
.743 .31 .223 r
.54424 .82802 m .54075 .82713 L .54305 .82854 L F
.645 .464 .624 r
.38134 .85209 m .38364 .85193 L .38365 .84955 L F
.668 .487 .631 r
.38364 .85193 m .3859 .84939 L .38365 .84955 L F
.991 .738 .43 r
.56731 .79326 m .56702 .79368 L .56621 .78918 L F
.916 .588 .117 r
.56727 .79435 m .56702 .79368 L .56731 .79326 L F
.968 .813 .635 r
.56765 .79319 m .56727 .79435 L .56731 .79326 L F
.351 .165 .483 r
.61205 .81477 m .61115 .81238 L .61374 .81201 L F
.557 .536 .787 r
.68725 .71853 m .68855 .71532 L .68701 .71596 L F
.68725 .71853 m .68994 .71723 L .68855 .71532 L F
.476 .232 .465 r
.36756 .78958 m .36726 .79187 L .36531 .79139 L F
.517 .202 .372 r
.36726 .79187 m .36443 .79356 L .36531 .79139 L F
.666 .43 .554 r
.41124 .83069 m .4144 .83106 L .41453 .82827 L F
.634 .403 .551 r
.41453 .82827 m .4165 .83065 L .41658 .8285 L F
.41453 .82827 m .4144 .83106 L .4165 .83065 L F
.648 .301 .369 r
.50833 .84879 m .50785 .84989 L .50596 .84915 L F
.611 .473 .669 r
.5102 .84679 m .51125 .8492 L .50833 .84879 L F
.513 .093 .181 r
.51125 .8492 m .50785 .84989 L .50833 .84879 L F
.38 0 .168 r
.4775 .82273 m .47952 .82235 L .48069 .82039 L F
.324 0 .104 r
.47952 .82235 m .48285 .81995 L .48069 .82039 L F
.207 0 0 r
.38547 .73626 m .38331 .73646 L .38214 .73343 L F
.38547 .73626 m .38525 .73647 L .38331 .73646 L F
0 0 0 r
.38723 .73584 m .38547 .73626 L .38658 .73282 L F
.38723 .73584 m .38525 .73647 L .38547 .73626 L F
.445 .871 .93 r
.577 .79981 m .57826 .79899 L .57913 .79947 L F
.577 .79981 m .57596 .79969 L .57826 .79899 L F
.577 .79981 m .57826 .79899 L .57913 .79947 L F
.577 .79981 m .57596 .79969 L .57826 .79899 L F
.249 0 .097 r
.57358 .78412 m .57098 .78629 L .57046 .78387 L F
.57358 .78412 m .57273 .78593 L .57098 .78629 L F
0 0 0 r
.57478 .78358 m .57273 .78593 L .57358 .78412 L F
.729 .852 .939 r
.55091 .79377 m .54799 .79404 L .55002 .79366 L F
.266 0 0 r
.55002 .79366 m .55344 .79253 L .55091 .79377 L F
.698 .688 .837 r
.43179 .86312 m .43324 .8652 L .4301 .86505 L F
.283 .491 .883 r
.43417 .86435 m .43324 .8652 L .43179 .86312 L F
.635 .559 .751 r
.43417 .86435 m .43286 .86764 L .43324 .8652 L F
.307 0 .013 r
.57031 .77348 m .57245 .77304 L .57376 .77146 L F
.247 0 0 r
.57376 .77146 m .57452 .77247 L .57532 .77045 L F
.57376 .77146 m .57245 .77304 L .57452 .77247 L F
.546 .356 .574 r
.40506 .76056 m .40482 .76246 L .40279 .76288 L F
.499 .255 .475 r
.40482 .76246 m .4022 .7645 L .40279 .76288 L F
.948 .957 .713 r
.56388 .83545 m .56314 .83855 L .56453 .83805 L F
0 0 .442 r
.56314 .83855 m .56432 .84048 L .56453 .83805 L F
.56314 .83855 m .56393 .84115 L .56432 .84048 L F
.669 .494 .638 r
.38799 .84665 m .39088 .84687 L .39036 .8442 L F
.635 .487 .665 r
.39036 .8442 m .39315 .84426 L .39236 .84134 L F
.645 .486 .653 r
.39088 .84687 m .39315 .84426 L .39036 .8442 L F
.676 .237 0 r
.56736 .80492 m .56829 .80608 L .56818 .80519 L F
.619 .488 .681 r
.53916 .85118 m .54069 .84803 L .53849 .84897 L F
.53916 .85118 m .54092 .85094 L .54069 .84803 L F
.703 .739 .879 r
.56254 .77869 m .56066 .77886 L .56304 .77642 L F
.164 .131 .572 r
.56254 .77869 m .56347 .78184 L .56304 .78111 L F
.269 0 .224 r
.62663 .77477 m .62586 .77581 L .62842 .77381 L F
.719 .19 0 r
.55915 .79397 m .56191 .79624 L .56026 .79689 L F
.57 .206 .312 r
.50357 .8263 m .50517 .82846 L .50651 .82563 L F
.324 0 .191 r
.50651 .82563 m .50808 .82603 L .50875 .82558 L F
.50651 .82563 m .50517 .82846 L .50808 .82603 L F
.286 .064 .391 r
.52856 .82634 m .5279 .82866 L .53004 .82543 L F
.464 .817 .997 r
.46201 .86483 m .46317 .86541 L .46014 .86525 L F
.404 .788 .991 r
.46534 .86517 m .46317 .86541 L .46201 .86483 L F
.673 .178 .065 r
.45514 .86053 m .45923 .86204 L .45668 .8606 L F
.607 .467 .665 r
.42575 .87026 m .42363 .87267 L .42364 .87063 L F
.83 .685 .703 r
.55385 .83357 m .555 .83641 L .55524 .83285 L F
.983 .853 .633 r
.6866 .73135 m .68746 .73203 L .68686 .73444 L F
.18 .098 .52 r
.6886 .73065 m .68746 .73203 L .6866 .73135 L F
.6886 .73065 m .68686 .73444 L .68746 .73203 L F
.948 .639 .2 r
.5548 .83837 m .55548 .83878 L .555 .83641 L F
.548 .268 .443 r
.39956 .76586 m .39765 .76822 L .39548 .76835 L F
.453 .153 .366 r
.39962 .7678 m .39765 .76822 L .39956 .76586 L F
.483 .238 .466 r
.37191 .78626 m .36931 .78881 L .36992 .78669 L F
.749 .739 .843 r
.56547 .79632 m .56191 .79624 L .56423 .79422 L F
.805 .829 .87 r
.56727 .79435 m .56547 .79632 L .56423 .79422 L F
0 .485 .795 r
.37809 .75009 m .37901 .75013 L .37688 .74878 L F
.682 .482 .609 r
.37421 .85969 m .37208 .85981 L .37209 .85994 L F
.528 .15 .267 r
.48501 .8202 m .48729 .82027 L .48829 .81825 L F
.055 0 0 r
.48729 .82027 m .49061 .81865 L .48829 .81825 L F
.501 0 0 r
.41116 .9045 m .41469 .90448 L .41317 .90511 L F
.476 0 0 r
.41335 .90503 m .41469 .90448 L .41116 .9045 L F
.371 .822 .706 r
.41325 .90507 m .41469 .90448 L .41559 .90393 L F
.41317 .90511 m .41469 .90448 L .41325 .90507 L F
.476 0 0 r
.41352 .90507 m .41469 .90448 L .41335 .90503 L F
.369 .809 .655 r
.41559 .90393 m .41469 .90448 L .41352 .90507 L F
.645 .477 .641 r
.39236 .84134 m .39521 .8417 L .39464 .83895 L F
.66 .564 .736 r
.39464 .83895 m .39725 .83897 L .39648 .83629 L F
.694 .534 .666 r
.39521 .8417 m .39725 .83897 L .39464 .83895 L F
.329 0 0 r
.34555 .72927 m .34764 .72902 L .3487 .72794 L F
.137 0 0 r
.3487 .72794 m .34957 .72839 L .35059 .72781 L F
.3487 .72794 m .34764 .72902 L .34957 .72839 L F
.622 .73 .924 r
.39707 .73992 m .3952 .74054 L .39383 .73908 L F
.726 .554 .658 r
.42877 .85984 m .42998 .86342 L .42668 .86228 L F
.615 .493 .691 r
.43179 .86312 m .42877 .85984 L .43228 .86065 L F
.43179 .86312 m .42998 .86342 L .42877 .85984 L F
0 0 0 r
.59272 .82789 m .59169 .8288 L .59082 .83051 L F
0 0 .015 r
.59386 .82618 m .59169 .8288 L .59272 .82789 L F
.499 .203 .395 r
.58204 .7744 m .5826 .77606 L .57922 .77615 L F
.675 .3 .327 r
.58439 .77607 m .5826 .77606 L .58204 .7744 L F
.619 .356 .497 r
.58504 .77348 m .58439 .77607 L .58204 .7744 L F
.437 0 .005 r
.50768 .81925 m .50645 .8203 L .50435 .8202 L F
.658 .214 .184 r
.5096 .82048 m .50645 .8203 L .50768 .81925 L F
.567 .854 .528 r
.5459 .79471 m .54683 .7936 L .54799 .79404 L F
.5459 .79471 m .54463 .79598 L .54683 .7936 L F
.699 .463 .562 r
.60481 .75427 m .60748 .75491 L .60758 .75275 L F
.517 .311 .539 r
.60758 .75275 m .60748 .75491 L .60967 .75227 L F
.529 .85 .998 r
.56066 .77886 m .56149 .77723 L .56304 .77642 L F
.56066 .77886 m .55963 .77783 L .56149 .77723 L F
.628 .456 .631 r
.37214 .86234 m .37421 .85969 L .37209 .85994 L F
.901 .75 .685 r
.69495 .71827 m .69598 .72135 L .6943 .7209 L F
.452 .223 .474 r
.69385 .72388 m .69598 .72135 L .6959 .72329 L F
.904 .612 .48 r
.6943 .7209 m .69598 .72135 L .6959 .72329 L F
.725 .667 .793 r
.69796 .71873 m .69598 .72135 L .69495 .71827 L F
.634 .535 .725 r
.69796 .71873 m .69842 .72147 L .69598 .72135 L F
.609 .297 .416 r
.69598 .72135 m .69818 .72306 L .6959 .72329 L F
.69598 .72135 m .69842 .72147 L .69818 .72306 L F
.737 .291 0 r
.4903 .82474 m .49129 .82593 L .48954 .82299 L F
.962 .712 .513 r
.49129 .82593 m .49145 .82302 L .48954 .82299 L F
.737 .291 0 r
.4903 .82474 m .48954 .82299 L .49145 .82302 L F
.705 .17 0 r
.55304 .80569 m .55277 .8065 L .55048 .80444 L F
.671 .127 0 r
.55304 .80569 m .55492 .80717 L .55277 .8065 L F
.821 1 .801 r
.63229 .77018 m .63448 .76775 L .6351 .76776 L F
.237 0 .292 r
.38579 .76054 m .38363 .76316 L .38566 .76282 L F
.547 .35 .566 r
.38579 .76054 m .38791 .76016 L .38814 .7579 L F
.572 .383 .586 r
.38566 .76282 m .38791 .76016 L .38579 .76054 L F
.695 .328 .348 r
.53747 .80956 m .53959 .81 L .5403 .80845 L F
.635 .263 .321 r
.5403 .80845 m .53959 .81 L .54279 .8097 L F
.616 .564 .773 r
.42896 .873 m .42575 .87026 L .42861 .87024 L F
.615 .442 .625 r
.43093 .87192 m .42861 .87024 L .4311 .8705 L F
.43093 .87192 m .42896 .873 L .42861 .87024 L F
.597 .716 .927 r
.48926 .88569 m .49253 .88653 L .49121 .88532 L F
.746 .803 .898 r
.49253 .88653 m .4937 .88389 L .49121 .88532 L F
.49253 .88653 m .4945 .88559 L .4937 .88389 L F
.676 .852 .967 r
.42516 .88958 m .42578 .88803 L .42372 .88846 L F
.42516 .88958 m .4271 .88878 L .42578 .88803 L F
.47 .778 .998 r
.3742 .7282 m .3735 .72927 L .37219 .72864 L F
.3742 .7282 m .37557 .72899 L .3735 .72927 L F
.714 .763 .891 r
.43232 .87334 m .42896 .873 L .43093 .87192 L F
.724 .736 .861 r
.43434 .87226 m .43232 .87334 L .43093 .87192 L F
.811 .776 .821 r
.49312 .86994 m .49623 .86984 L .49542 .86723 L F
.49312 .86994 m .49539 .87052 L .49623 .86984 L F
.696 .703 .852 r
.49542 .86723 m .49623 .86984 L .49762 .86957 L F
.214 0 0 r
.5381 .83184 m .53744 .83271 L .53437 .83307 L F
.724 .859 .435 r
.53853 .83073 m .53744 .83271 L .5381 .83184 L F
.31 .098 .421 r
.62212 .79684 m .62248 .79483 L .62401 .79402 L F
.562 .387 .601 r
.36876 .77087 m .37076 .77283 L .37121 .77096 L F
.36876 .77087 m .36895 .77336 L .37076 .77283 L F
.174 .71 .752 r
.5251 .80919 m .5253 .80905 L .52691 .80762 L F
.5251 .80919 m .52318 .80944 L .5253 .80905 L F
.436 .853 .695 r
.66537 .75536 m .66204 .75719 L .66462 .75554 L F
.716 .708 .841 r
.63724 .72452 m .63393 .72422 L .63601 .72327 L F
.563 .267 .424 r
.38089 .76498 m .38308 .76487 L .38363 .76316 L F
.501 .215 .411 r
.38308 .76487 m .38566 .76282 L .38363 .76316 L F
0 0 0 r
.59638 .81765 m .59495 .82055 L .59667 .81994 L F
.653 .569 .748 r
.59521 .82317 m .59667 .81994 L .59495 .82055 L F
.5 .385 .655 r
.40575 .90201 m .40624 .90464 L .40784 .90394 L F
.40575 .90201 m .40624 .90464 L .40784 .90394 L F
.285 .673 .972 r
.44642 .90888 m .44576 .90954 L .44777 .90971 L F
.44642 .90888 m .44576 .90954 L .44777 .90971 L F
.6 .827 .986 r
.41381 .89029 m .41428 .89111 L .41612 .89053 L F
.46 .063 .2 r
.5799 .76829 m .58323 .76626 L .58043 .76758 L F
.5799 .76829 m .58213 .76808 L .58323 .76626 L F
.427 .03 .181 r
.58323 .76626 m .58521 .76694 L .58519 .76604 L F
.58323 .76626 m .58213 .76808 L .58521 .76694 L F
.697 .569 .707 r
.39315 .84426 m .39521 .8417 L .39236 .84134 L F
.095 .264 .747 r
.52843 .82932 m .53037 .83045 L .5279 .82866 L F
0 0 0 r
.38814 .7579 m .38862 .75743 L .39022 .75556 L F
.346 .179 .507 r
.38814 .7579 m .38938 .75979 L .38862 .75743 L F
.38814 .7579 m .38791 .76016 L .38938 .75979 L F
.73 .621 .737 r
.43653 .87005 m .43762 .87311 L .43434 .87226 L F
.616 .558 .767 r
.43965 .87214 m .43762 .87311 L .43653 .87005 L F
.551 .262 .429 r
.58745 .77332 m .58439 .77607 L .58504 .77348 L F
.196 .677 .931 r
.50107 .87394 m .50146 .87415 L .50053 .87395 L F
.904 .976 .687 r
.50302 .87295 m .50211 .8745 L .50146 .87415 L F
.534 .013 0 r
.50399 .8744 m .50302 .87295 L .50285 .87308 L F
.50399 .8744 m .50285 .87308 L .50146 .87415 L F
.601 .042 0 r
.50457 .87507 m .50399 .8744 L .50294 .8739 L F
.50601 .87609 m .50399 .8744 L .50457 .87507 L F
.196 .677 .931 r
.50294 .8739 m .50146 .87415 L .50107 .87394 L F
.904 .976 .687 r
.50211 .8745 m .50121 .87604 L .50146 .87415 L F
.534 .013 0 r
.50399 .8744 m .50526 .87363 L .50302 .87295 L F
.187 0 .348 r
.61054 .7943 m .60888 .79706 L .61028 .79642 L F
0 0 .355 r
.60888 .79706 m .60992 .79817 L .61028 .79642 L F
.60888 .79706 m .60866 .79909 L .60992 .79817 L F
.523 .378 .626 r
.40302 .7419 m .40338 .7446 L .40139 .74496 L F
.502 .388 .656 r
.40352 .74687 m .40139 .74496 L .40338 .7446 L F
.40352 .74687 m .40169 .74717 L .40139 .74496 L F
.552 .483 .731 r
.38979 .75344 m .39022 .75556 L .392 .75496 L F
.783 .927 .558 r
.39022 .75556 m .39075 .75406 L .39077 .7558 L F
.39022 .75556 m .38862 .75743 L .39075 .75406 L F
0 0 0 r
.39022 .75556 m .39077 .7558 L .392 .75496 L F
.58202 .84952 m .58462 .84883 L .58419 .84914 L F
.911 .66 .546 r
.57112 .81722 m .57268 .81468 L .57064 .81442 L F
.893 .824 .772 r
.57064 .81442 m .57268 .81468 L .57287 .81284 L F
.682 .349 .405 r
.5741 .81721 m .57268 .81468 L .57112 .81722 L F
.442 .876 .898 r
.58902 .84779 m .59279 .84712 L .5907 .84699 L F
.424 .866 .9 r
.5907 .84699 m .59279 .84712 L .59474 .84647 L F
.962 .712 .513 r
.49129 .82593 m .49259 .82644 L .49145 .82302 L F
.676 .215 .15 r
.49129 .82593 m .49545 .8273 L .49259 .82644 L F
.639 .402 .544 r
.43423 .85727 m .43622 .85957 L .43419 .85949 L F
.529 .856 .996 r
.50734 .8806 m .5082 .87957 L .50616 .88016 L F
.50734 .8806 m .50943 .8801 L .5082 .87957 L F
.612 .895 .988 r
.43471 .8867 m .43781 .88645 L .43652 .88583 L F
.402 .81 .979 r
.43781 .88645 m .43864 .88572 L .43652 .88583 L F
.43781 .88645 m .43993 .88615 L .43864 .88572 L F
.707 .302 .278 r
.56922 .78089 m .57156 .78306 L .57283 .78077 L F
.649 .737 .913 r
.57283 .78077 m .57431 .7807 L .5735 .77798 L F
.799 .472 .435 r
.57156 .78306 m .57431 .7807 L .57283 .78077 L F
.576 .928 .949 r
.63674 .76657 m .6398 .7656 L .63762 .76568 L F
.351 0 0 r
.63762 .76568 m .6398 .7656 L .64118 .76506 L F
.639 .747 .927 r
.49992 .88409 m .50211 .88339 L .49878 .88277 L F
.86 .675 .651 r
.4947 .87291 m .49539 .87052 L .49312 .86994 L F
.724 .822 .926 r
.38572 .90073 m .38734 .89856 L .38538 .8994 L F
.38572 .90073 m .38864 .89958 L .38734 .89856 L F
0 .508 .853 r
.65934 .72946 m .66064 .72951 L .65898 .72838 L F
.706 .616 .753 r
.42575 .87026 m .42677 .87344 L .42363 .87267 L F
.616 .564 .773 r
.42896 .873 m .42677 .87344 L .42575 .87026 L F
.829 .785 .81 r
.64619 .71469 m .647 .71679 L .6445 .71523 L F
.783 .796 .863 r
.6445 .71523 m .647 .71679 L .64347 .71847 L F
.57 .34 .527 r
.36646 .77577 m .36895 .77336 L .36679 .77371 L F
.728 .664 .787 r
.6073 .7418 m .6085 .74481 L .60553 .74456 L F
.739 .618 .723 r
.6085 .74481 m .6063 .7474 L .60553 .74456 L F
.667 .51 .662 r
.6085 .74481 m .60827 .74734 L .6063 .7474 L F
.639 .617 .813 r
.61066 .74425 m .6085 .74481 L .6073 .7418 L F
.621 .928 .68 r
.64046 .73356 m .64181 .7326 L .64353 .73109 L F
.64046 .73356 m .64353 .73109 L .64233 .73264 L F
.364 .114 .396 r
.64576 .72901 m .64498 .72997 L .64353 .73109 L F
0 0 0 r
.64353 .73109 m .64397 .73177 L .64233 .73264 L F
.64353 .73109 m .64498 .72997 L .6444 .73101 L F
.64417 .73117 m .6444 .73101 L .6443 .73118 L F
.64353 .73109 m .6444 .73101 L .64417 .73117 L F
.307 .046 .346 r
.64717 .73061 m .64498 .72997 L .64576 .72901 L F
.573 .534 .773 r
.64551 .73085 m .64519 .73133 L .64717 .73061 L F
.335 0 .021 r
.6444 .73101 m .64498 .72997 L .64717 .73061 L F
.573 .534 .773 r
.64496 .73062 m .64519 .73133 L .64626 .72972 L F
.73 .625 .741 r
.64443 .73107 m .64452 .73111 L .64496 .73062 L F
.64452 .73111 m .64519 .73133 L .64505 .73092 L F
.335 0 .021 r
.6443 .73118 m .6444 .73101 L .64505 .73092 L F
.73 .625 .741 r
.64452 .73111 m .64505 .73092 L .64496 .73062 L F
.757 .363 .306 r
.64397 .73177 m .64519 .73133 L .64452 .73111 L F
.335 0 .021 r
.64397 .73177 m .6443 .73118 L .64449 .73115 L F
0 0 0 r
.64385 .73158 m .6443 .73118 L .64397 .73177 L F
.64353 .73109 m .6443 .73118 L .64385 .73158 L F
.757 .363 .306 r
.64397 .73177 m .64452 .73111 L .64157 .7301 L F
.335 0 .021 r
.64397 .73177 m .64449 .73115 L .64717 .73061 L F
.6443 .73118 m .64505 .73092 L .64717 .73061 L F
.573 .534 .773 r
.64626 .72972 m .64551 .73085 L .64717 .73061 L F
.64391 .72743 m .64496 .73062 L .64626 .72972 L F
.73 .625 .741 r
.64157 .7301 m .64443 .73107 L .64391 .72743 L F
.64443 .73107 m .64496 .73062 L .64391 .72743 L F
.294 0 0 r
.47537 .88293 m .47751 .88286 L .47407 .88349 L F
.716 .614 .743 r
.4301 .86505 m .42668 .86228 L .42998 .86342 L F
.4301 .86505 m .42793 .86527 L .42668 .86228 L F
.563 .527 .773 r
.4301 .86505 m .42764 .86737 L .42793 .86527 L F
.627 .576 .778 r
.43179 .86312 m .4301 .86505 L .42998 .86342 L F
.476 .035 .12 r
.51107 .83656 m .50994 .83815 L .50774 .83821 L F
0 0 0 r
.51175 .83696 m .51107 .83656 L .51324 .83615 L F
.51175 .83696 m .50994 .83815 L .51107 .83656 L F
.56617 .77463 m .56674 .77473 L .56811 .77386 L F
.56617 .77463 m .56485 .77538 L .56674 .77473 L F
.345 .568 .921 r
.49095 .87543 m .49014 .87656 L .48894 .87535 L F
.352 .577 .926 r
.49095 .87543 m .4926 .87728 L .49014 .87656 L F
.345 .568 .921 r
.49095 .87543 m .49289 .87741 L .49014 .87656 L F
.352 .577 .926 r
.49095 .87543 m .49014 .87656 L .48894 .87535 L F
.712 .344 .35 r
.49545 .8273 m .4968 .82775 L .49751 .82637 L F
.538 .866 .589 r
.49545 .8273 m .49564 .82701 L .4968 .82775 L F
.79 .729 .796 r
.49564 .82701 m .49628 .82877 L .4968 .82775 L F
.49628 .82877 m .49664 .82976 L .4968 .82775 L F
.712 .344 .35 r
.49751 .82637 m .4968 .82775 L .49815 .82609 L F
.604 .211 .272 r
.49815 .82609 m .4968 .82775 L .50013 .82766 L F
.59 .221 .312 r
.49815 .82609 m .50013 .82766 L .5003 .82628 L F
.814 .368 .18 r
.54652 .8002 m .54604 .80139 L .54405 .79878 L F
.848 .415 .196 r
.5477 .8019 m .54604 .80139 L .54652 .8002 L F
.582 .246 .365 r
.57922 .77615 m .5788 .7785 L .57635 .7784 L F
.671 .328 .385 r
.58205 .77813 m .57922 .77615 L .5826 .77606 L F
.58205 .77813 m .5788 .7785 L .57922 .77615 L F
.454 .159 .375 r
.65801 .76048 m .66012 .75999 L .66036 .75837 L F
.164 0 .289 r
.66012 .75999 m .66204 .75719 L .66036 .75837 L F
.343 .108 .407 r
.62464 .79223 m .62685 .78959 L .62593 .7913 L F
.083 0 .221 r
.62401 .79402 m .62464 .79223 L .62593 .7913 L F
.535 0 0 r
.37445 .7482 m .37361 .74871 L .37129 .74757 L F
.398 0 0 r
.37688 .74878 m .37361 .74871 L .37445 .7482 L F
.649 .233 .242 r
.50902 .8396 m .51096 .84095 L .51189 .83967 L F
.7 .295 .275 r
.51096 .84095 m .5141 .84126 L .51189 .83967 L F
.705 .514 .627 r
.51991 .83859 m .51756 .84135 L .51775 .83892 L F
.51991 .83859 m .52018 .84143 L .51756 .84135 L F
.594 .432 .632 r
.5221 .83836 m .52018 .84143 L .51991 .83859 L F
.709 .513 .623 r
.69385 .72388 m .69423 .72631 L .6916 .72616 L F
.83 1 .814 r
.69443 .72248 m .69385 .72388 L .69321 .72374 L F
.305 .232 .608 r
.69574 .72528 m .69385 .72388 L .6959 .72329 L F
.69574 .72528 m .69423 .72631 L .69385 .72388 L F
.363 0 .127 r
.47069 .86252 m .46774 .86447 L .47018 .86268 L F
.47069 .86252 m .46949 .86437 L .46774 .86447 L F
.902 .976 .686 r
.47069 .86252 m .47167 .8595 L .47179 .86195 L F
.47069 .86252 m .47018 .86268 L .47167 .8595 L F
0 0 0 r
.47179 .86195 m .46949 .86437 L .47069 .86252 L F
.637 .263 .318 r
.5003 .82628 m .50264 .82753 L .50357 .8263 L F
0 0 .514 r
.50437 .82703 m .50517 .82846 L .50357 .8263 L F
.50437 .82703 m .50357 .8263 L .50264 .82753 L F
.796 .362 0 r
.67141 .74769 m .67255 .74987 L .67147 .74854 L F
.461 .316 .597 r
.50568 .83805 m .50564 .84094 L .50388 .83884 L F
.681 .435 .543 r
.4069 .83587 m .40483 .83361 L .40391 .83601 L F
.4069 .83587 m .40706 .8337 L .40483 .83361 L F
.611 .064 0 r
.47047 .84959 m .47151 .85093 L .46931 .84865 L F
.47047 .84959 m .47247 .85144 L .47151 .85093 L F
.558 .714 .945 r
.48721 .86915 m .48583 .87052 L .48618 .86875 L F
.862 .91 .503 r
.48618 .86875 m .48583 .87052 L .48474 .87267 L F
.606 .343 .492 r
.59046 .76525 m .59344 .76265 L .59058 .76326 L F
.832 .947 .896 r
.5342 .8704 m .53542 .87085 L .53672 .8695 L F
.696 .703 .852 r
.49542 .86723 m .49762 .86957 L .49736 .86933 L F
.674 .939 .659 r
.49736 .86933 m .49762 .86957 L .49916 .86784 L F
.394 .379 .724 r
.48598 .86458 m .48465 .86577 L .48416 .86314 L F
0 0 0 r
.48386 .86657 m .48465 .86577 L .48598 .86458 L F
.403 .805 .983 r
.46718 .84906 m .46599 .8486 L .46507 .84931 L F
0 0 0 r
.46599 .8486 m .46449 .84977 L .46507 .84931 L F
.498 .839 .559 r
.64204 .77361 m .64045 .77497 L .63924 .77609 L F
.496 .903 .905 r
.64204 .77361 m .64395 .77282 L .64322 .77271 L F
0 0 0 r
.64322 .77271 m .64045 .77497 L .64204 .77361 L F
.733 .837 .929 r
.38883 .75266 m .38979 .75344 L .39201 .75255 L F
.552 .483 .731 r
.38979 .75344 m .392 .75496 L .39201 .75255 L F
.449 0 0 r
.50322 .81369 m .50532 .81444 L .50668 .81423 L F
.551 0 0 r
.50532 .81444 m .50845 .81508 L .50668 .81423 L F
.613 .047 0 r
.6732 .74084 m .67243 .74104 L .67132 .74005 L F
.829 .372 0 r
.67263 .7406 m .67243 .74104 L .6732 .74084 L F
.309 .779 .935 r
.3421 .72918 m .34555 .72927 L .34349 .72945 L F
.886 .968 .648 r
.59238 .8276 m .59386 .82618 L .59272 .82789 L F
.889 .968 .649 r
.59463 .82437 m .59386 .82618 L .59238 .8276 L F
.638 .465 .633 r
.37934 .85497 m .38141 .85463 L .38134 .85209 L F
.64 .463 .628 r
.38141 .85463 m .38364 .85193 L .38134 .85209 L F
.682 .544 .691 r
.44472 .84417 m .44266 .8468 L .44275 .84466 L F
.562 .186 .287 r
.45927 .82771 m .46148 .82781 L .46266 .82579 L F
.502 .115 .239 r
.46148 .82781 m .4648 .82582 L .46266 .82579 L F
.774 .796 .871 r
.51596 .84586 m .51332 .8467 L .51547 .84463 L F
.657 .506 .667 r
.51518 .84926 m .51332 .8467 L .51596 .84586 L F
.6 .597 .82 r
.51753 .84377 m .51596 .84586 L .51547 .84463 L F
.51753 .84377 m .51867 .84665 L .51596 .84586 L F
.461 .272 .537 r
.51763 .84869 m .51596 .84586 L .51867 .84665 L F
.51763 .84869 m .51518 .84926 L .51596 .84586 L F
.563 .358 .56 r
.40705 .76024 m .40482 .76246 L .40506 .76056 L F
.768 .667 .751 r
.58388 .83135 m .58364 .83452 L .58579 .83052 L F
.365 .139 .432 r
.36886 .79113 m .36756 .78958 L .36931 .78881 L F
.36886 .79113 m .36726 .79187 L .36756 .78958 L F
0 .546 .745 r
.47482 .83762 m .47648 .83771 L .47503 .83758 L F
.083 0 0 r
.47503 .83758 m .47648 .83771 L .47559 .83764 L F
.828 .767 .795 r
.47414 .83748 m .47482 .83762 L .47503 .83758 L F
.47231 .8371 m .47376 .8387 L .47482 .83762 L F
.083 0 0 r
.47503 .83758 m .47559 .83764 L .47281 .83745 L F
.828 .767 .795 r
.47231 .8371 m .47414 .83748 L .47503 .83758 L F
.356 0 .145 r
.47376 .8387 m .47438 .84035 L .47482 .83762 L F
.372 .809 .652 r
.66444 .76202 m .66514 .76159 L .66371 .76299 L F
.66444 .76202 m .66609 .76111 L .66514 .76159 L F
.65 .833 .971 r
.3597 .72736 m .35616 .7273 L .3583 .72674 L F
.742 .872 .94 r
.36161 .72632 m .3597 .72736 L .3583 .72674 L F
.766 .692 .781 r
.67202 .75861 m .67097 .76009 L .66986 .75748 L F
.811 .974 .673 r
.67106 .75961 m .67097 .76009 L .67202 .75861 L F
.702 .892 .966 r
.66883 .76089 m .67085 .76069 L .67097 .76009 L F
.002 0 0 r
.66883 .76089 m .67097 .76009 L .66966 .76109 L F
.811 .974 .673 r
.66966 .76109 m .67097 .76009 L .67106 .75961 L F
.702 .892 .966 r
.67085 .76069 m .67191 .76059 L .67097 .76009 L F
.765 .759 .848 r
.67306 .75714 m .67191 .76059 L .67097 .76009 L F
.67306 .75714 m .67394 .75887 L .67191 .76059 L F
.435 .076 .255 r
.37672 .78429 m .37393 .78592 L .37448 .78454 L F
.577 .456 .679 r
.54069 .84803 m .54092 .85094 L .54342 .84917 L F
.593 .537 .762 r
.44756 .86983 m .44756 .87051 L .44441 .86973 L F
.641 .686 .877 r
.44756 .87051 m .44416 .86964 L .44441 .86973 L F
.44756 .87051 m .44575 .8719 L .44416 .86964 L F
.969 .658 .274 r
.55057 .82006 m .55176 .82299 L .55129 .82078 L F
0 0 0 r
.68157 .75563 m .68066 .75716 L .67943 .75791 L F
.402 .572 .906 r
.68006 .75349 m .68157 .75563 L .68094 .7536 L F
.68006 .75349 m .68273 .75407 L .68157 .75563 L F
0 0 0 r
.68273 .75407 m .68066 .75716 L .68157 .75563 L F
.792 .93 .925 r
.40543 .89318 m .40737 .89082 L .40544 .89309 L F
.524 .146 .266 r
.6063 .7474 m .60312 .74937 L .60311 .74738 L F
.6063 .7474 m .60555 .74927 L .60312 .74937 L F
.736 .367 .353 r
.6063 .7474 m .60807 .75021 L .60555 .74927 L F
.798 .372 .237 r
.60885 .74992 m .6063 .7474 L .60827 .74734 L F
.98 .688 .332 r
.60885 .74992 m .60874 .75146 L .60807 .75021 L F
0 0 .489 r
.60807 .75021 m .60874 .75146 L .60836 .75068 L F
.798 .372 .237 r
.60885 .74992 m .60807 .75021 L .60638 .74748 L F
0 0 .489 r
.60807 .75021 m .60836 .75068 L .60733 .74859 L F
.798 .372 .237 r
.60638 .74748 m .60807 .75021 L .6063 .7474 L F
.703 .638 .781 r
.48861 .84467 m .48574 .84369 L .48753 .84439 L F
.653 .26 .288 r
.48753 .84439 m .49075 .84399 L .48861 .84467 L F
.506 .449 .727 r
.49107 .84649 m .48861 .84467 L .49075 .84399 L F
.49107 .84649 m .48938 .84719 L .48861 .84467 L F
.516 .476 .75 r
.35489 .78614 m .35744 .78393 L .35538 .78402 L F
.267 .089 .444 r
.61255 .79366 m .61028 .79642 L .61235 .79589 L F
.848 .719 .193 r
.61236 .79549 m .61255 .79366 L .61235 .79589 L F
.259 .066 .417 r
.61274 .7918 m .61054 .7943 L .61255 .79366 L F
.267 .089 .444 r
.61255 .79366 m .61054 .7943 L .61028 .79642 L F
.848 .719 .193 r
.61241 .79194 m .61255 .79366 L .61236 .79549 L F
.259 .066 .417 r
.61297 .79155 m .61274 .7918 L .61255 .79366 L F
.584 .678 .905 r
.49075 .84399 m .4914 .84482 L .49119 .84139 L F
.729 .79 .901 r
.49119 .84139 m .4914 .84482 L .49492 .84157 L F
.668 .881 .977 r
.50121 .87604 m .49711 .87656 L .49984 .87565 L F
.785 .928 .929 r
.50146 .87415 m .50121 .87604 L .49984 .87565 L F
.59 .017 0 r
.45705 .86582 m .45836 .86624 L .45953 .86715 L F
.515 .264 .472 r
.46014 .86525 m .45836 .86624 L .45953 .86715 L F
.668 .487 .631 r
.38364 .85193 m .38597 .85185 L .3859 .84939 L F
.652 .502 .667 r
.3859 .84939 m .38836 .84935 L .38799 .84665 L F
.649 .472 .631 r
.38597 .85185 m .38836 .84935 L .3859 .84939 L F
.799 .472 .435 r
.57156 .78306 m .57478 .78358 L .57431 .7807 L F
.522 .465 .734 r
.57431 .7807 m .57635 .7784 L .5735 .77798 L F
.504 .26 .479 r
.57478 .78358 m .57695 .78082 L .57431 .7807 L F
.284 .344 .749 r
.48257 .87209 m .48193 .87169 L .48033 .87117 L F
.674 .495 .636 r
.37421 .85969 m .37726 .85974 L .37669 .85718 L F
.646 .491 .659 r
.37669 .85718 m .37934 .85726 L .37934 .85497 L F
.701 .556 .688 r
.37726 .85974 m .37934 .85726 L .37669 .85718 L F
.543 .281 .468 r
.55214 .79347 m .55422 .79548 L .55393 .7938 L F
.266 0 0 r
.55113 .79329 m .55214 .79347 L .55344 .79253 L F
0 0 0 r
.55344 .79253 m .55424 .7925 L .5556 .79207 L F
.293 0 0 r
.55424 .7925 m .55773 .79179 L .5556 .79207 L F
.266 .764 .892 r
.5556 .79207 m .55773 .79179 L .55849 .792 L F
.293 0 0 r
.55424 .7925 m .55642 .79248 L .55773 .79179 L F
.724 .213 .005 r
.55209 .79055 m .55642 .79248 L .55424 .7925 L F
.659 .858 .976 r
.55424 .7925 m .55354 .79154 L .55209 .79055 L F
.55424 .7925 m .55214 .79347 L .55354 .79154 L F
.543 .281 .468 r
.55214 .79347 m .55393 .7938 L .55354 .79154 L F
.266 0 0 r
.55002 .79366 m .55214 .79347 L .55113 .79329 L F
0 .04 .604 r
.66945 .73688 m .67132 .74005 L .67085 .73807 L F
.82 .833 .859 r
.4937 .88389 m .4945 .88559 L .49665 .88324 L F
.893 .579 .448 r
.55718 .80983 m .55492 .80717 L .55591 .80795 L F
.656 .493 .652 r
.38836 .84935 m .39088 .84687 L .38799 .84665 L F
.611 .707 .913 r
.36482 .72724 m .36161 .72632 L .36341 .72662 L F
.247 .76 .842 r
.36544 .72691 m .36482 .72724 L .36341 .72662 L F
.36544 .72691 m .36688 .72689 L .36482 .72724 L F
.62 .353 .492 r
.37594 .76797 m .37822 .76792 L .3788 .76597 L F
.559 .31 .496 r
.37822 .76792 m .38089 .76498 L .3788 .76597 L F
.235 0 0 r
.35919 .75065 m .35731 .75132 L .35531 .75131 L F
.622 .246 .309 r
.36083 .74981 m .35731 .75132 L .35919 .75065 L F
0 0 .38 r
.56393 .84115 m .56464 .84426 L .56492 .84392 L F
0 0 .44 r
.56464 .84426 m .56565 .84569 L .56492 .84392 L F
.56464 .84426 m .56662 .84768 L .56565 .84569 L F
.73 .856 .94 r
.38419 .74659 m .38075 .74869 L .38355 .74811 L F
.532 .307 .518 r
.36008 .78105 m .36209 .78079 L .36236 .77876 L F
.559 .417 .645 r
.36236 .77876 m .36438 .77842 L .36423 .77603 L F
.551 .336 .542 r
.36209 .78079 m .36438 .77842 L .36236 .77876 L F
0 0 .243 r
.56118 .81769 m .56205 .82065 L .56166 .81912 L F
.942 .647 .192 r
.56205 .82065 m .5624 .82282 L .56171 .82161 L F
.456 .69 .967 r
.34847 .7526 m .34929 .75211 L .34798 .75212 L F
.684 .655 .815 r
.57173 .78921 m .57102 .79029 L .56853 .78704 L F
.716 .466 .547 r
.48317 .85171 m .48189 .85204 L .48325 .85085 L F
.48317 .85171 m .48092 .85395 L .48189 .85204 L F
.48317 .85171 m .48296 .85454 L .48092 .85395 L F
.031 0 0 r
.48679 .8497 m .48523 .85118 L .48317 .85171 L F
.339 .151 .473 r
.48547 .85343 m .48317 .85171 L .48523 .85118 L F
.48547 .85343 m .48296 .85454 L .48317 .85171 L F
.637 .483 .656 r
.40706 .8337 m .40927 .83354 L .40917 .83105 L F
.662 .446 .582 r
.4069 .83587 m .40927 .83354 L .40706 .8337 L F
.662 .634 .812 r
.5328 .8646 m .53248 .86828 L .53071 .86754 L F
.5328 .8646 m .53596 .8669 L .53248 .86828 L F
.488 .285 .53 r
.44465 .84637 m .44266 .8468 L .44472 .84417 L F
.515 .367 .618 r
.44465 .84637 m .4422 .84851 L .44266 .8468 L F
.16 .586 .934 r
.54103 .84107 m .5423 .84213 L .54423 .84236 L F
.545 .185 .308 r
.53244 .83366 m .53135 .83596 L .52919 .83577 L F
.234 0 .153 r
.53337 .83489 m .53244 .83366 L .53437 .83307 L F
.53337 .83489 m .53135 .83596 L .53244 .83366 L F
.517 .465 .737 r
.40352 .74687 m .40232 .75024 L .40169 .74717 L F
.40352 .74687 m .40423 .74999 L .40232 .75024 L F
.85 .398 .002 r
.44963 .86458 m .44808 .86262 L .44925 .8625 L F
.106 .631 .877 r
.38476 .72816 m .38898 .72877 L .39013 .72926 L F
.953 .758 .602 r
.38839 .72978 m .39013 .72926 L .38898 .72877 L F
.38839 .72978 m .38922 .73055 L .39013 .72926 L F
.615 .27 .363 r
.39013 .72926 m .39152 .73082 L .38922 .73055 L F
.694 .746 .891 r
.47025 .8384 m .47376 .8387 L .47231 .8371 L F
.448 .055 .201 r
.47024 .84098 m .47376 .8387 L .47025 .8384 L F
.47024 .84098 m .47241 .84072 L .47376 .8387 L F
.356 0 .145 r
.47376 .8387 m .47241 .84072 L .47438 .84035 L F
.845 .583 .542 r
.66361 .71082 m .66144 .71227 L .66287 .70948 L F
.66361 .71082 m .6638 .71303 L .66144 .71227 L F
.45 .636 .935 r
.66287 .70948 m .66493 .70956 L .66361 .71082 L F
.592 .393 .581 r
.66618 .71245 m .66361 .71082 L .66493 .70956 L F
.66618 .71245 m .6638 .71303 L .66361 .71082 L F
.474 .185 .394 r
.39765 .76822 m .3951 .77035 L .39548 .76835 L F
.421 .144 .385 r
.49057 .84858 m .48938 .84719 L .49107 .84649 L F
.49057 .84858 m .48868 .8491 L .48938 .84719 L F
.582 .76 .963 r
.48926 .88569 m .49037 .88431 L .48813 .88466 L F
.48926 .88569 m .49121 .88532 L .49037 .88431 L F
.944 .74 .598 r
.51775 .83892 m .51756 .84135 L .51666 .83965 L F
.51775 .83892 m .51666 .83965 L .51861 .83886 L F
.508 .597 .878 r
.68701 .71596 m .6872 .71287 L .68519 .71326 L F
.68701 .71596 m .68855 .71532 L .6872 .71287 L F
.946 .917 .753 r
.67812 .75477 m .67869 .75382 L .67788 .75245 L F
.465 .363 .655 r
.67958 .74904 m .68116 .75195 L .67788 .75245 L F
.774 .891 .928 r
.68116 .75195 m .67812 .75477 L .67788 .75245 L F
.617 .395 .558 r
.40945 .75788 m .40925 .76024 L .40705 .76024 L F
.574 .359 .551 r
.41166 .75756 m .40925 .76024 L .40945 .75788 L F
.098 .256 .738 r
.58723 .82822 m .58653 .82893 L .58507 .82581 L F
.58623 .82707 m .58507 .82581 L .585 .82565 L F
.58723 .82822 m .58507 .82581 L .58623 .82707 L F
.575 .365 .558 r
.58623 .82707 m .58726 .82819 L .58726 .82546 L F
.742 .612 .713 r
.585 .82565 m .58653 .82893 L .58274 .82829 L F
.575 .365 .558 r
.58506 .82891 m .58726 .82819 L .58623 .82707 L F
.58506 .82891 m .58623 .82707 L .585 .82565 L F
.58623 .82707 m .58726 .82546 L .585 .82565 L F
.098 .256 .738 r
.58726 .82819 m .58723 .82822 L .585 .82565 L F
.516 .902 .947 r
.58506 .82891 m .58653 .82893 L .58726 .82819 L F
.794 .492 .477 r
.58914 .83145 m .58653 .82893 L .58579 .83052 L F
.385 .776 .988 r
.50943 .8801 m .51271 .88049 L .51156 .88022 L F
.109 .647 .853 r
.51271 .88049 m .51482 .88059 L .51156 .88022 L F
0 0 0 r
.51271 .88049 m .51502 .88013 L .51482 .88059 L F
.58 .405 .609 r
.65435 .73168 m .65613 .72931 L .65438 .72937 L F
.684 .561 .71 r
.51285 .84378 m .51332 .8467 L .5102 .84679 L F
.68 .506 .644 r
.51332 .8467 m .51125 .8492 L .5102 .84679 L F
.672 .455 .582 r
.44668 .84412 m .44465 .84637 L .44472 .84417 L F
0 0 0 r
.62593 .7913 m .62685 .78959 L .62779 .78848 L F
.479 .237 .468 r
.38348 .77836 m .38113 .78078 L .38144 .77872 L F
.751 .52 .581 r
.69446 .71606 m .69495 .71827 L .69173 .71831 L F
.519 .555 .832 r
.69671 .71556 m .69446 .71606 L .69355 .71335 L F
.69671 .71556 m .69738 .71636 L .69446 .71606 L F
.747 .756 .86 r
.69738 .71636 m .69495 .71827 L .69446 .71606 L F
.475 0 0 r
.50596 .84915 m .50461 .84909 L .50246 .84818 L F
.314 0 0 r
.50596 .84915 m .50704 .84967 L .50461 .84909 L F
.50596 .84915 m .50785 .84989 L .50704 .84967 L F
.982 .731 .475 r
.667 .7156 m .66807 .71857 L .66707 .71826 L F
.398 .458 .806 r
.66981 .71759 m .66807 .71857 L .667 .7156 L F
.916 .746 .656 r
.66981 .71759 m .66707 .71826 L .66807 .71857 L F
.714 .46 .539 r
.6694 .73115 m .66726 .73115 L .66885 .73317 L F
.769 .667 .75 r
.44144 .85705 m .44278 .85999 L .43973 .85887 L F
.802 .427 .346 r
.44278 .85999 m .4415 .86153 L .43973 .85887 L F
.532 .483 .747 r
.44189 .85346 m .44345 .85885 L .44144 .85705 L F
.519 .371 .619 r
.44573 .85403 m .44345 .85885 L .44189 .85346 L F
.44573 .85403 m .44632 .85691 L .44345 .85885 L F
.472 .228 .462 r
.44632 .85691 m .44386 .85885 L .44345 .85885 L F
.013 .328 .813 r
.44144 .85705 m .44345 .85885 L .44386 .85885 L F
.391 .597 .928 r
.44386 .85885 m .44278 .85999 L .44144 .85705 L F
.44386 .85885 m .44335 .85988 L .44278 .85999 L F
.367 .345 .703 r
.44335 .85988 m .44477 .86196 L .44278 .85999 L F
.727 .325 .287 r
.44278 .85999 m .44477 .86196 L .4415 .86153 L F
.661 .501 .657 r
.40917 .83105 m .41201 .83317 L .41124 .83069 L F
.40917 .83105 m .40927 .83354 L .41201 .83317 L F
.334 .057 .336 r
.6139 .79064 m .61289 .78919 L .61297 .79155 L F
.6139 .79064 m .61462 .78876 L .61289 .78919 L F
.832 .482 0 r
.55842 .79253 m .55849 .792 L .55773 .79179 L F
.55842 .79253 m .55915 .79397 L .55849 .792 L F
.57 .424 .643 r
.56082 .79152 m .55915 .79397 L .55849 .792 L F
.733 .837 .929 r
.38883 .75266 m .39201 .75255 L .3905 .75163 L F
.66 .813 .957 r
.3905 .75163 m .39201 .75255 L .39419 .75189 L F
.594 .414 .607 r
.392 .75496 m .39419 .75189 L .39201 .75255 L F
.974 .695 .436 r
.56375 .82816 m .56506 .83105 L .56387 .83032 L F
.978 .75 .526 r
.56387 .83032 m .56506 .83105 L .56485 .83348 L F
.573 .765 .969 r
.44729 .88526 m .44851 .88632 L .45053 .88589 L F
.656 .225 .212 r
.53416 .80764 m .53621 .8092 L .5372 .80765 L F
.895 .54 .363 r
.5372 .80765 m .53621 .8092 L .53747 .80956 L F
.461 .521 .833 r
.58579 .83052 m .58956 .83421 L .58914 .83145 L F
.384 .134 .407 r
.36012 .79656 m .35796 .79932 L .35812 .79704 L F
.824 .801 .83 r
.64347 .71847 m .64051 .71859 L .64256 .71733 L F
.783 .796 .863 r
.6445 .71523 m .64347 .71847 L .64256 .71733 L F
0 0 .152 r
.48157 .8756 m .48257 .87209 L .48366 .87545 L F
.456 .213 .455 r
.51502 .88013 m .51705 .88057 L .51482 .88059 L F
.222 .328 .761 r
.68685 .70596 m .68704 .70478 L .68802 .70501 L F
.356 .573 .922 r
.68802 .70501 m .69013 .70734 L .68685 .70596 L F
.604 .704 .914 r
.68402 .70522 m .68704 .70478 L .68685 .70596 L F
.143 .686 .725 r
.67943 .75791 m .67856 .75803 L .67613 .75844 L F
.416 .863 .816 r
.68066 .75716 m .67856 .75803 L .67943 .75791 L F
.352 .732 .986 r
.47751 .88286 m .48056 .88354 L .47922 .8834 L F
.301 0 0 r
.47922 .8834 m .48056 .88354 L .48202 .88399 L F
.553 .555 .81 r
.40422 .73938 m .40302 .7419 L .40237 .73991 L F
.40422 .73938 m .40497 .74186 L .40302 .7419 L F
.561 .405 .627 r
.40551 .74418 m .40302 .7419 L .40497 .74186 L F
.40551 .74418 m .40338 .7446 L .40302 .7419 L F
.507 .108 .218 r
.49814 .86582 m .49542 .86723 L .49756 .86699 L F
.911 .529 .28 r
.49756 .86699 m .49916 .86784 L .49814 .86582 L F
0 0 0 r
.48253 .86234 m .48138 .86243 L .48055 .86281 L F
.394 .379 .724 r
.48598 .86458 m .48259 .86221 L .48257 .86225 L F
.48598 .86458 m .48416 .86314 L .48259 .86221 L F
.48598 .86458 m .48257 .86225 L .48645 .86425 L F
.48257 .86225 m .48259 .86221 L .48199 .86185 L F
.48257 .86225 m .48199 .86185 L .48274 .86225 L F
.48257 .86225 m .48274 .86225 L .48645 .86425 L F
.562 0 0 r
.48423 .86345 m .48645 .86425 L .48274 .86225 L F
0 0 0 r
.4829 .86225 m .48256 .86229 L .48253 .86233 L F
.252 .468 .874 r
.48023 .86054 m .48061 .86117 L .48299 .86223 L F
.48061 .86117 m .48138 .86243 L .48271 .86227 L F
.562 0 0 r
.48223 .86202 m .48274 .86225 L .48199 .86185 L F
.48271 .86227 m .48274 .86225 L .48223 .86202 L F
.252 .468 .874 r
.48223 .86202 m .48271 .86227 L .48299 .86223 L F
.562 0 0 r
.48264 .86231 m .48271 .86227 L .48223 .86202 L F
0 0 0 r
.48299 .86223 m .48284 .86225 L .48291 .86225 L F
.48284 .86225 m .48256 .86229 L .48291 .86225 L F
.562 0 0 r
.48264 .86231 m .48223 .86202 L .48299 .86223 L F
.48223 .86202 m .48199 .86185 L .48299 .86223 L F
.252 .468 .874 r
.48061 .86117 m .48223 .86202 L .48299 .86223 L F
.562 0 0 r
.48423 .86345 m .48274 .86225 L .48264 .86231 L F
.48423 .86345 m .48264 .86231 L .48299 .86223 L F
0 0 0 r
.48291 .86225 m .4829 .86225 L .48263 .86232 L F
.48263 .86232 m .48263 .86232 L .48253 .86234 L F
.48291 .86225 m .48263 .86232 L .48263 .86232 L F
.4829 .86225 m .48253 .86233 L .48253 .86234 L F
.48256 .86229 m .48138 .86243 L .48253 .86234 L F
.674 .731 .894 r
.38246 .90072 m .38401 .89816 L .3822 .89929 L F
.38246 .90072 m .38538 .8994 L .38401 .89816 L F
.589 .574 .804 r
.44038 .85408 m .43943 .85713 L .44082 .85644 L F
.44038 .85408 m .44144 .85705 L .43943 .85713 L F
.578 .376 .571 r
.44144 .85705 m .43973 .85887 L .43943 .85713 L F
.691 .49 .611 r
.4165 .83065 m .4195 .82831 L .41658 .8285 L F
.856 .778 .774 r
.68034 .70705 m .68121 .70508 L .68171 .70825 L F
.959 .623 .254 r
.68171 .70825 m .68062 .70792 L .68034 .70705 L F
.68171 .70825 m .68198 .71018 L .68062 .70792 L F
.811 .75 .795 r
.68121 .70508 m .68402 .70522 L .68171 .70825 L F
.311 .138 .478 r
.65342 .7542 m .65217 .75521 L .65317 .75644 L F
.555 .247 .4 r
.35894 .7833 m .36209 .78079 L .36008 .78105 L F
.624 .677 .88 r
.38608 .72976 m .38744 .7317 L .38922 .73055 L F
.927 .748 .266 r
.56385 .82584 m .56331 .82758 L .56351 .825 L F
.56385 .82584 m .56375 .82816 L .56331 .82758 L F
.798 .303 0 r
.46683 .83798 m .46754 .83902 L .46821 .83883 L F
.643 .787 .951 r
.46683 .83798 m .46821 .83883 L .47025 .8384 L F
.46683 .83798 m .47025 .8384 L .46905 .8377 L F
.191 .308 .755 r
.46905 .8377 m .46821 .83883 L .46754 .83902 L F
.604 .391 .565 r
.46821 .83883 m .47024 .84098 L .47025 .8384 L F
.191 .308 .755 r
.46905 .8377 m .47024 .84098 L .46821 .83883 L F
.277 .627 .962 r
.38038 .89907 m .38056 .89884 L .37999 .89874 L F
.411 .004 .153 r
.44477 .86196 m .44738 .86171 L .44812 .85982 L F
.579 .164 .219 r
.44812 .85982 m .4515 .86072 L .45017 .85952 L F
.382 0 0 r
.45241 .87258 m .45041 .87029 L .45041 .87209 L F
.163 .631 .931 r
.53324 .81264 m .53411 .81228 L .53208 .81238 L F
.53324 .81264 m .53502 .81278 L .53411 .81228 L F
.402 .856 .875 r
.54622 .842 m .54759 .8421 L .54982 .84133 L F
.885 .882 .825 r
.39265 .89848 m .39394 .89898 L .39578 .89627 L F
.723 .365 .37 r
.44308 .82961 m .44667 .82849 L .44345 .82834 L F
.44308 .82961 m .44529 .83055 L .44667 .82849 L F
.713 .352 .363 r
.44667 .82849 m .44529 .83055 L .44869 .83059 L F
.632 .368 .5 r
.44667 .82849 m .44869 .83059 L .44908 .82853 L F
.613 .277 .377 r
.49751 .81375 m .49981 .81501 L .49994 .8149 L F
.55 .38 .603 r
.4422 .84851 m .44322 .85316 L .44156 .85213 L F
.44322 .85316 m .44322 .85316 L .44156 .85213 L F
.686 .651 .809 r
.4446 .85131 m .44491 .85206 L .44358 .85268 L F
.431 .303 .604 r
.4446 .85131 m .44322 .85316 L .4422 .84851 L F
.603 .345 .499 r
.44322 .85316 m .44189 .85346 L .44156 .85213 L F
.686 .651 .809 r
.44491 .85206 m .44322 .85316 L .44189 .85346 L F
.44322 .85316 m .44259 .85357 L .44189 .85346 L F
.603 .345 .499 r
.44322 .85317 m .44189 .85346 L .44322 .85316 L F
.431 .303 .604 r
.4446 .85131 m .44322 .85317 L .44322 .85316 L F
.686 .651 .809 r
.4446 .85131 m .44358 .85268 L .44189 .85346 L F
.44491 .85206 m .44573 .85403 L .44259 .85357 L F
.55 .38 .603 r
.44322 .85316 m .44322 .85317 L .44322 .85316 L F
.515 .367 .618 r
.44465 .84637 m .44556 .84881 L .4422 .84851 L F
.431 .303 .604 r
.4446 .85131 m .4422 .84851 L .44556 .84881 L F
.487 .896 .919 r
.65199 .76905 m .65059 .76895 L .64816 .76982 L F
.201 .729 .763 r
.65409 .76836 m .65059 .76895 L .65199 .76905 L F
.606 .343 .492 r
.59046 .76525 m .59286 .76523 L .59344 .76265 L F
.555 .283 .459 r
.59286 .76523 m .59566 .76258 L .59344 .76265 L F
.783 .98 .907 r
.64918 .7605 m .6452 .7633 L .64595 .76169 L F
.807 .999 .8 r
.6452 .7633 m .64465 .76317 L .64595 .76169 L F
.673 .53 .682 r
.37934 .85726 m .38141 .85463 L .37934 .85497 L F
.908 .517 .101 r
.55822 .81257 m .55836 .81463 L .5573 .81205 L F
.55822 .81257 m .55917 .81527 L .55836 .81463 L F
.025 0 0 r
.46981 .88292 m .47215 .88295 L .4687 .88293 L F
.983 .853 .633 r
.6866 .73135 m .68686 .73444 L .68475 .7336 L F
.852 .548 .473 r
.68686 .73444 m .68485 .73589 L .68475 .7336 L F
.68686 .73444 m .68733 .73598 L .68485 .73589 L F
.18 .098 .52 r
.6886 .73065 m .68882 .73302 L .68686 .73444 L F
.36 .424 .792 r
.68882 .73302 m .68993 .73618 L .68686 .73444 L F
.533 .37 .606 r
.68686 .73444 m .68733 .73598 L .68856 .7372 L F
.68686 .73444 m .68993 .73618 L .68733 .73598 L F
0 0 0 r
.55452 .82405 m .55351 .82553 L .55323 .8251 L F
.453 0 0 r
.55366 .82737 m .55266 .82658 L .55245 .82561 L F
.55366 .82737 m .55245 .82561 L .5527 .82559 L F
.55366 .82737 m .55228 .8248 L .55323 .8251 L F
.946 .654 .455 r
.55323 .8251 m .55239 .82716 L .55366 .82737 L F
0 0 0 r
.55351 .82553 m .55239 .82716 L .55304 .82556 L F
.55351 .82553 m .55304 .82556 L .55323 .8251 L F
.453 0 0 r
.5527 .82559 m .55245 .82561 L .55228 .8248 L F
.55366 .82737 m .5547 .82795 L .55266 .82658 L F
.144 .467 .892 r
.64858 .75901 m .64942 .76025 L .64918 .7605 L F
.863 .929 .868 r
.64918 .7605 m .64595 .76169 L .64858 .75901 L F
.144 .467 .892 r
.64858 .75901 m .64942 .76025 L .64918 .7605 L F
.694 .534 .666 r
.39521 .8417 m .39747 .84136 L .39725 .83897 L F
.614 .529 .736 r
.39725 .83897 m .39857 .83636 L .39648 .83629 L F
.39725 .83897 m .39943 .83874 L .39857 .83636 L F
.606 .469 .668 r
.39725 .83897 m .39747 .84136 L .39943 .83874 L F
0 0 .156 r
.67338 .74438 m .67343 .74455 L .67263 .7406 L F
.853 .78 .779 r
.47882 .86149 m .48055 .86281 L .47885 .86455 L F
.153 0 0 r
.48004 .86264 m .48055 .86281 L .47882 .86149 L F
.867 .648 .605 r
.48083 .8629 m .47885 .86455 L .48055 .86281 L F
.48138 .86243 m .48135 .86525 L .47885 .86455 L F
.153 0 0 r
.48086 .86342 m .48055 .86281 L .48004 .86264 L F
.867 .648 .605 r
.48138 .86243 m .48083 .8629 L .48055 .86281 L F
.546 .756 .974 r
.38864 .89958 m .38936 .89817 L .38734 .89856 L F
.38864 .89958 m .39105 .89941 L .38936 .89817 L F
.656 .843 .972 r
.45263 .88557 m .45407 .88646 L .45587 .8856 L F
0 0 0 r
.45407 .88646 m .4571 .88555 L .45587 .8856 L F
.74 .71 .823 r
.43315 .86992 m .43434 .87226 L .43093 .87192 L F
.79 .73 .796 r
.43653 .87005 m .43434 .87226 L .43315 .86992 L F
0 0 0 r
.63924 .77609 m .63842 .77747 L .63714 .77864 L F
.64045 .77497 m .63842 .77747 L .63924 .77609 L F
.681 .424 .528 r
.45001 .84424 m .44645 .84632 L .44668 .84412 L F
.45001 .84424 m .45047 .8473 L .44645 .84632 L F
.549 .334 .54 r
.45222 .8462 m .45047 .8473 L .45001 .84424 L F
.638 .311 .402 r
.45315 .84427 m .45222 .8462 L .45001 .84424 L F
.76 .778 .868 r
.49363 .82116 m .49696 .82102 L .49575 .82057 L F
.681 .979 .873 r
.49776 .81986 m .49696 .82102 L .49907 .81956 L F
.606 .891 .989 r
.49776 .81986 m .49575 .82057 L .49696 .82102 L F
.758 .599 .68 r
.6445 .71523 m .64809 .713 L .64619 .71469 L F
.6445 .71523 m .64654 .71255 L .64809 .713 L F
.893 .65 .565 r
.64654 .71255 m .64784 .71576 L .64809 .713 L F
.631 .777 .95 r
.38723 .73584 m .38859 .73698 L .38525 .73647 L F
.641 .779 .947 r
.39092 .73637 m .38859 .73698 L .38723 .73584 L F
.305 .007 .283 r
.66397 .7236 m .66275 .72602 L .66131 .72628 L F
.228 0 .208 r
.66131 .72628 m .66323 .72578 L .66397 .7236 L F
0 0 0 r
.66501 .72455 m .66342 .72656 L .66502 .7251 L F
.66501 .72455 m .66502 .7251 L .66628 .72395 L F
.175 0 .185 r
.665 .724 m .66501 .72455 L .66617 .72447 L F
.66397 .7236 m .66501 .72455 L .665 .724 L F
.66397 .7236 m .66323 .72578 L .66501 .72455 L F
.714 .537 .648 r
.60415 .74605 m .60508 .74471 L .60422 .74392 L F
.647 .625 .813 r
.60553 .74456 m .60213 .742 L .60422 .74392 L F
.845 .841 .84 r
.6073 .7418 m .60553 .74456 L .60422 .74392 L F
.714 .537 .648 r
.60508 .74471 m .60591 .74351 L .60422 .74392 L F
.647 .625 .813 r
.60213 .742 m .60194 .74185 L .60422 .74392 L F
.514 .361 .611 r
.53889 .83884 m .54103 .84107 L .54073 .83849 L F
.706 .762 .896 r
.57334 .83838 m .57454 .83947 L .57171 .84089 L F
.772 .465 .468 r
.4587 .8469 m .45833 .84885 L .45636 .8464 L F
.764 .405 .374 r
.42416 .82558 m .42623 .828 L .42733 .82676 L F
.503 .082 .175 r
.42733 .82676 m .42623 .828 L .42925 .82722 L F
.069 0 0 r
.45463 .87243 m .45347 .87233 L .45241 .87258 L F
.45463 .87243 m .45536 .87201 L .45347 .87233 L F
.811 .67 .708 r
.68733 .73598 m .68865 .73961 L .68579 .73897 L F
.68733 .73598 m .68856 .7372 L .68865 .73961 L F
.716 .4 .443 r
.68865 .73961 m .68565 .74128 L .68579 .73897 L F
.68865 .73961 m .68894 .74138 L .68565 .74128 L F
.679 .563 .717 r
.69087 .73665 m .68865 .73961 L .68856 .7372 L F
.69087 .73665 m .69165 .73952 L .68865 .73961 L F
.664 .442 .572 r
.68865 .73961 m .69083 .74074 L .68894 .74138 L F
.68865 .73961 m .69165 .73952 L .69083 .74074 L F
.259 .707 .958 r
.43994 .82758 m .43884 .82777 L .43771 .82769 L F
.43994 .82758 m .44106 .82804 L .43884 .82777 L F
.561 .31 .492 r
.37334 .77034 m .37594 .76797 L .37312 .76788 L F
.215 .44 .863 r
.52332 .8749 m .52238 .87595 L .52142 .87587 L F
.52332 .8749 m .52483 .87728 L .52238 .87595 L F
.453 .199 .438 r
.38053 .78316 m .37915 .78119 L .38113 .78078 L F
.38053 .78316 m .37861 .78373 L .37915 .78119 L F
0 0 .116 r
.60675 .83015 m .60546 .83098 L .60709 .82816 L F
0 0 .452 r
.60665 .83256 m .60546 .83098 L .60675 .83015 L F
.60665 .83256 m .60574 .8335 L .60546 .83098 L F
0 0 0 r
.60029 .76003 m .6012 .75946 L .60287 .75743 L F
.054 0 .413 r
.60287 .75743 m .60397 .75683 L .60415 .75418 L F
0 0 0 r
.60287 .75743 m .6012 .75946 L .60397 .75683 L F
.934 .719 .589 r
.48432 .84128 m .48476 .84465 L .48574 .84369 L F
.776 .442 .421 r
.48476 .84465 m .48427 .84594 L .48574 .84369 L F
.261 0 .104 r
.48574 .84369 m .48624 .84526 L .48753 .84439 L F
.48574 .84369 m .48427 .84594 L .48624 .84526 L F
0 0 .492 r
.57051 .80916 m .57109 .80992 L .56924 .80768 L F
.63 .237 0 r
.57051 .80916 m .57204 .81196 L .57109 .80992 L F
0 .175 .706 r
.57287 .81284 m .57109 .80992 L .57204 .81196 L F
.622 .385 .538 r
.60572 .76802 m .60615 .77032 L .6026 .77054 L F
.688 .427 .522 r
.60764 .76828 m .60615 .77032 L .60572 .76802 L F
.789 .734 .802 r
.43653 .87005 m .43315 .86992 L .43513 .86752 L F
.614 .663 .875 r
.43729 .8671 m .43653 .87005 L .43513 .86752 L F
.43729 .8671 m .43958 .86987 L .43653 .87005 L F
.625 .603 .808 r
.43958 .86987 m .43836 .87096 L .43653 .87005 L F
.616 .558 .767 r
.43965 .87214 m .43653 .87005 L .43836 .87096 L F
.13 0 0 r
.48033 .87117 m .47707 .87244 L .47918 .87211 L F
.042 .512 .886 r
.48133 .87121 m .48257 .87209 L .48033 .87117 L F
.48133 .87121 m .48033 .87117 L .47918 .87211 L F
.717 .686 .819 r
.61454 .7395 m .61587 .74205 L .61256 .74191 L F
.733 .6 .709 r
.61587 .74205 m .61338 .74436 L .61256 .74191 L F
.627 .429 .595 r
.61338 .74436 m .61592 .74434 L .61587 .74205 L F
.744 .542 .621 r
.61454 .7395 m .6175 .73925 L .61587 .74205 L F
.506 .48 .762 r
.56743 .78587 m .56566 .78736 L .56498 .78449 L F
.598 .486 .696 r
.56853 .78704 m .56566 .78736 L .56743 .78587 L F
.56853 .78704 m .56621 .78918 L .56566 .78736 L F
.078 0 .103 r
.49363 .82116 m .49302 .82267 L .49145 .82302 L F
.215 0 0 r
.49259 .82358 m .49145 .82302 L .49302 .82267 L F
.49259 .82358 m .4903 .82474 L .49145 .82302 L F
.762 .643 .729 r
.42764 .86737 m .42575 .87026 L .42694 .86875 L F
.588 .616 .847 r
.56093 .78917 m .56333 .7895 L .56167 .78642 L F
.598 .197 .255 r
.56093 .78917 m .56319 .79042 L .56333 .7895 L F
.498 .325 .577 r
.56093 .78917 m .56082 .79152 L .56319 .79042 L F
.598 .197 .255 r
.56093 .78917 m .56319 .79042 L .56333 .7895 L F
.414 .827 .973 r
.46201 .86483 m .46014 .86525 L .46063 .86449 L F
.554 .401 .628 r
.41344 .75237 m .41358 .75464 L .41151 .75501 L F
.558 .415 .642 r
.41358 .75464 m .41166 .75756 L .41151 .75501 L F
.438 0 0 r
.52036 .81999 m .51733 .82002 L .51815 .81951 L F
.597 .554 .777 r
.39383 .73908 m .3918 .73956 L .39092 .73637 L F
.687 .76 .907 r
.57672 .84008 m .57454 .83947 L .57642 .83834 L F
.68 .669 .832 r
.57845 .8379 m .57672 .84008 L .57642 .83834 L F
.57845 .8379 m .57983 .83913 L .57672 .84008 L F
.374 .151 .441 r
.61415 .80752 m .61622 .80503 L .61562 .80691 L F
.34 .167 .496 r
.61404 .80979 m .61415 .80752 L .61562 .80691 L F
.721 .785 .903 r
.63601 .72327 m .63393 .72422 L .63279 .72303 L F
.637 .96 .797 r
.62251 .77784 m .62523 .77588 L .62586 .77581 L F
.731 .991 .856 r
.62842 .77381 m .62586 .77581 L .62653 .77457 L F
.737 .985 .777 r
.62586 .77581 m .62523 .77588 L .62653 .77457 L F
.442 .839 .979 r
.41111 .8908 m .41277 .8897 L .40941 .89035 L F
.41111 .8908 m .41381 .89029 L .41277 .8897 L F
.685 .575 .725 r
.68219 .70501 m .68409 .70348 L .68208 .70396 L F
.043 .61 .771 r
.68121 .70508 m .68255 .70502 L .68402 .70522 L F
.68255 .70502 m .68258 .70502 L .6826 .70502 L F
.68255 .70502 m .6826 .70502 L .68402 .70522 L F
.685 .575 .725 r
.68229 .70589 m .68512 .70672 L .6846 .70508 L F
.382 .818 .957 r
.68585 .70417 m .68402 .70522 L .68308 .70509 L F
.68585 .70417 m .68308 .70509 L .6844 .70456 L F
.68585 .70417 m .68266 .70503 L .68486 .70443 L F
.68585 .70417 m .68704 .70478 L .68402 .70522 L F
.698 .577 .715 r
.68409 .70348 m .68585 .70417 L .68445 .70454 L F
.685 .575 .725 r
.68301 .70493 m .68443 .70455 L .68409 .70348 L F
.698 .577 .715 r
.68409 .70348 m .68445 .70454 L .68262 .70502 L F
.703 .227 .116 r
.68685 .70547 m .68516 .70425 L .68512 .70649 L F
.68518 .70667 m .68512 .70649 L .68512 .70672 L F
.68685 .70547 m .68512 .70649 L .68518 .70667 L F
.68516 .70425 m .68409 .70348 L .68443 .70455 L F
.68516 .70425 m .68443 .70455 L .68512 .70672 L F
.382 .818 .957 r
.6844 .70456 m .68308 .70509 L .68266 .70503 L F
.68486 .70443 m .68266 .70503 L .68262 .70502 L F
.685 .575 .725 r
.68293 .70503 m .6846 .70508 L .68443 .70455 L F
.68293 .70503 m .68443 .70455 L .68301 .70493 L F
.043 .61 .771 r
.68258 .70502 m .68264 .70502 L .68402 .70522 L F
.685 .575 .725 r
.68229 .70589 m .6846 .70508 L .68293 .70503 L F
.68229 .70589 m .68293 .70503 L .68219 .70501 L F
.68293 .70503 m .68409 .70348 L .68219 .70501 L F
.043 .61 .771 r
.68258 .70502 m .68262 .70502 L .68264 .70502 L F
.551 .262 .429 r
.58745 .77332 m .58605 .77591 L .58439 .77607 L F
.624 .343 .472 r
.58979 .77494 m .58605 .77591 L .58745 .77332 L F
.588 .556 .785 r
.64702 .72757 m .64576 .72901 L .64578 .72577 L F
.307 .046 .346 r
.64717 .73061 m .64576 .72901 L .64702 .72757 L F
.467 .166 .371 r
.59566 .76258 m .59769 .76242 L .59809 .76045 L F
.629 .313 .416 r
.59809 .76045 m .60015 .76224 L .60029 .76003 L F
.59809 .76045 m .59769 .76242 L .60015 .76224 L F
.135 .342 .804 r
.57575 .82373 m .57527 .82493 L .57371 .82223 L F
.729 .885 .487 r
.57517 .82472 m .57527 .82493 L .57575 .82373 L F
0 .427 .766 r
.57527 .82493 m .57536 .82512 L .57455 .82486 L F
.729 .885 .487 r
.57404 .82662 m .57527 .82493 L .57517 .82472 L F
0 .427 .766 r
.57527 .82493 m .57632 .82544 L .57536 .82512 L F
.769 .537 .582 r
.54851 .83356 m .54534 .83102 L .54471 .83231 L F
0 0 .01 r
.6003 .81204 m .60079 .8101 L .59991 .81217 L F
0 0 0 r
.60223 .8094 m .60323 .80775 L .60079 .8101 L F
0 0 .088 r
.60223 .8094 m .60079 .8101 L .6003 .81204 L F
.769 .849 .399 r
.62338 .74612 m .62299 .74748 L .62433 .7444 L F
0 0 0 r
.62656 .7419 m .62564 .74358 L .62433 .7444 L F
.62564 .74358 m .62338 .74612 L .62433 .7444 L F
.421 0 0 r
.50246 .84818 m .50137 .84777 L .49924 .84657 L F
.396 .454 .803 r
.50246 .84818 m .50357 .84592 L .50137 .84777 L F
.50246 .84818 m .50461 .84909 L .50357 .84592 L F
.657 .713 .889 r
.40028 .74056 m .39707 .73992 L .39912 .73959 L F
.628 .787 .958 r
.40237 .73991 m .40028 .74056 L .39912 .73959 L F
.6 .54 .76 r
.5141 .84126 m .51547 .84463 L .51285 .84378 L F
.62 .516 .715 r
.51547 .84463 m .51332 .8467 L .51285 .84378 L F
.085 0 0 r
.50973 .82571 m .50875 .82558 L .50808 .82603 L F
.50973 .82571 m .51081 .82567 L .50875 .82558 L F
.361 0 .036 r
.49018 .84939 m .48679 .8497 L .48868 .8491 L F
.49018 .84939 m .48523 .85118 L .48679 .8497 L F
.731 .743 .861 r
.49492 .84157 m .49623 .84379 L .49837 .84188 L F
.67 .624 .794 r
.49623 .84379 m .4989 .8442 L .49837 .84188 L F
.822 .378 .178 r
.67763 .73554 m .6794 .73777 L .68014 .73675 L F
.383 0 0 r
.68256 .74029 m .68356 .74014 L .68315 .74032 L F
.8 .345 .162 r
.6794 .73777 m .68315 .74032 L .68014 .73675 L F
.71 .55 .669 r
.51332 .8467 m .5133 .84941 L .51125 .8492 L F
.657 .506 .667 r
.51518 .84926 m .5133 .84941 L .51332 .8467 L F
.582 .517 .746 r
.4236 .73919 m .4264 .73736 L .42412 .73849 L F
.359 0 0 r
.42671 .73844 m .42752 .73888 L .4236 .73919 L F
.582 .517 .746 r
.4236 .73919 m .42752 .73888 L .4264 .73736 L F
.742 .872 .94 r
.36161 .72632 m .3583 .72674 L .36034 .72611 L F
.176 .617 .94 r
.36203 .72576 m .36161 .72632 L .36034 .72611 L F
.36203 .72576 m .36341 .72662 L .36161 .72632 L F
.779 .66 .732 r
.67172 .72335 m .67286 .72652 L .66948 .72604 L F
0 0 0 r
.67105 .72535 m .67192 .72593 L .67095 .72457 L F
.392 .782 .989 r
.66948 .72604 m .6728 .72652 L .67192 .72593 L F
.597 .439 .637 r
.67192 .72593 m .66957 .72839 L .66948 .72604 L F
.323 .07 .366 r
.67192 .72593 m .67071 .72805 L .66957 .72839 L F
0 0 0 r
.67128 .72707 m .67071 .72805 L .67119 .72721 L F
.67128 .72707 m .67119 .72721 L .67192 .72593 L F
.67128 .72707 m .67192 .72593 L .67105 .72535 L F
0 0 .406 r
.6714 .72688 m .67128 .72707 L .67115 .72635 L F
.67211 .72834 m .67128 .72707 L .6714 .72688 L F
.392 .782 .989 r
.6728 .72652 m .67286 .72652 L .67192 .72593 L F
.983 .698 .382 r
.67192 .72593 m .67286 .72652 L .67172 .72335 L F
.628 .456 .631 r
.37214 .86234 m .37435 .862 L .37421 .85969 L F
.661 .47 .615 r
.37435 .862 m .37726 .85974 L .37421 .85969 L F
.633 .257 .314 r
.44738 .86171 m .44902 .8621 L .4515 .86072 L F
.185 0 0 r
.44902 .8621 m .45215 .86164 L .4515 .86072 L F
.77 .289 .092 r
.4515 .86072 m .45215 .86164 L .45017 .85952 L F
.713 .354 .367 r
.45017 .85952 m .45215 .86164 L .45383 .85969 L F
.573 .149 .198 r
.45215 .86164 m .45514 .86053 L .45383 .85969 L F
.072 0 .156 r
.44051 .86955 m .43836 .87096 L .43958 .86987 L F
.51 .53 .813 r
.44051 .86955 m .43965 .87214 L .43836 .87096 L F
.357 .101 .382 r
.52269 .83058 m .52021 .83314 L .52099 .83122 L F
.952 .733 .569 r
.53115 .86513 m .53071 .86754 L .52952 .8643 L F
.514 .816 1 r
.5328 .8646 m .53115 .86513 L .52952 .8643 L F
.662 .634 .812 r
.5328 .8646 m .53071 .86754 L .53115 .86513 L F
.387 0 0 r
.45705 .86582 m .45343 .86539 L .45454 .86543 L F
.576 .373 .569 r
.58506 .82891 m .585 .82565 L .58274 .82829 L F
.098 .256 .738 r
.58726 .82819 m .585 .82565 L .58726 .82546 L F
.916 .588 .117 r
.56727 .79435 m .56673 .79382 L .56702 .79368 L F
.805 .829 .87 r
.56727 .79435 m .56423 .79422 L .56673 .79382 L F
.856 .981 .859 r
.56876 .79161 m .56727 .79435 L .56975 .79213 L F
.974 .737 .515 r
.56621 .78918 m .56702 .79368 L .56503 .79079 L F
.88 .486 .029 r
.56702 .79368 m .56673 .79382 L .56503 .79079 L F
.856 .981 .859 r
.56876 .79161 m .56673 .79382 L .56727 .79435 L F
.951 .653 .437 r
.56627 .79616 m .56727 .79435 L .56673 .79382 L F
.56627 .79616 m .56786 .79694 L .56727 .79435 L F
.64 .463 .628 r
.38141 .85463 m .38365 .8543 L .38364 .85193 L F
.646 .453 .609 r
.38365 .8543 m .38597 .85185 L .38364 .85193 L F
.481 .871 .97 r
.43222 .89574 m .43165 .89652 L .43021 .89626 L F
.43222 .89574 m .43165 .89652 L .43021 .89626 L F
.461 .098 .263 r
.47223 .82535 m .47543 .82294 L .47236 .82342 L F
.47223 .82535 m .47435 .82508 L .47543 .82294 L F
.398 .037 .231 r
.47543 .82294 m .47635 .82469 L .4775 .82273 L F
.47543 .82294 m .47435 .82508 L .47635 .82469 L F
.52 .25 .445 r
.47013 .8256 m .47223 .82535 L .47236 .82342 L F
.722 .898 .52 r
.53463 .81815 m .53291 .82077 L .53334 .81978 L F
.701 .67 .817 r
.68733 .73598 m .69087 .73665 L .68856 .7372 L F
.352 0 .083 r
.57781 .76865 m .5799 .76829 L .58043 .76758 L F
.597 .891 .99 r
.42898 .88808 m .43167 .88784 L .43067 .88728 L F
.699 .836 .948 r
.43167 .88784 m .43323 .88573 L .43067 .88728 L F
.43167 .88784 m .43471 .8867 L .43323 .88573 L F
.931 .822 .717 r
.53546 .8687 m .53672 .8695 L .536 .86727 L F
.832 .947 .896 r
.5342 .8704 m .53672 .8695 L .53546 .8687 L F
.816 .778 .817 r
.536 .86727 m .53672 .8695 L .53882 .86661 L F
.133 .68 .785 r
.66609 .76111 m .66831 .76077 L .66514 .76159 L F
.66609 .76111 m .66883 .76089 L .66831 .76077 L F
.642 .085 0 r
.68112 .71848 m .68329 .71931 L .68239 .71948 L F
.509 .344 .592 r
.54079 .83695 m .54073 .83849 L .5402 .83712 L F
.434 .539 .864 r
.5402 .83712 m .54073 .83849 L .54268 .83853 L F
.5402 .83712 m .54168 .83796 L .54245 .83705 L F
.54168 .83796 m .54268 .83853 L .54245 .83705 L F
.489 .176 .363 r
.54415 .83506 m .54402 .83518 L .54245 .83705 L F
.44 0 0 r
.54245 .83705 m .53987 .83734 L .5402 .83712 L F
.53987 .83734 m .53924 .83742 L .53945 .83735 L F
.53987 .83734 m .53945 .83735 L .5402 .83712 L F
.561 .504 .748 r
.54245 .83705 m .54268 .83853 L .54463 .83715 L F
.489 .176 .363 r
.54182 .83731 m .54356 .83748 L .54136 .83776 L F
.44 0 0 r
.54245 .83705 m .54136 .83776 L .53877 .83747 L F
.489 .176 .363 r
.54402 .83518 m .54136 .83776 L .54245 .83705 L F
.561 .504 .748 r
.54245 .83705 m .54463 .83715 L .54415 .83506 L F
.489 .176 .363 r
.54415 .83506 m .54361 .83727 L .54182 .83731 L F
.54361 .83727 m .54356 .83748 L .54182 .83731 L F
.44 0 0 r
.53924 .83742 m .53877 .83747 L .5402 .83712 L F
.509 .344 .592 r
.54084 .83549 m .54079 .83695 L .5402 .83712 L F
0 0 0 r
.54308 .83377 m .54084 .83549 L .54012 .83467 L F
.54308 .83377 m .54185 .83475 L .54084 .83549 L F
.751 .559 .636 r
.66516 .72862 m .66131 .72628 L .66275 .72602 L F
.66516 .72862 m .66191 .73026 L .66131 .72628 L F
.554 .204 .329 r
.66516 .72862 m .66217 .73027 L .66191 .73026 L F
.614 .113 .037 r
.66726 .73115 m .66662 .73223 L .66397 .73075 L F
.813 .458 .384 r
.66662 .73223 m .66621 .73187 L .66397 .73075 L F
.554 .204 .329 r
.66516 .72862 m .66397 .73075 L .66256 .73006 L F
.749 .427 .439 r
.66516 .72862 m .66726 .73115 L .66397 .73075 L F
.813 .458 .384 r
.66621 .73187 m .66356 .7296 L .66397 .73075 L F
.554 .204 .329 r
.66256 .73006 m .66397 .73075 L .66217 .73027 L F
.537 .253 .432 r
.39085 .77322 m .39025 .77575 L .38803 .77589 L F
.509 .299 .53 r
.39308 .77075 m .39277 .77296 L .39085 .77322 L F
.472 .194 .41 r
.39215 .77533 m .39085 .77322 L .39277 .77296 L F
.39215 .77533 m .39025 .77575 L .39085 .77322 L F
.864 .811 .796 r
.60311 .74738 m .60111 .74998 L .59964 .74909 L F
.478 .256 .498 r
.60312 .74937 m .60111 .74998 L .60311 .74738 L F
.864 .811 .796 r
.60311 .74738 m .59964 .74909 L .60312 .74937 L F
.435 .526 .852 r
.60231 .74464 m .60311 .74738 L .60415 .74605 L F
.619 .532 .734 r
.60312 .74937 m .60415 .74605 L .60311 .74738 L F
0 0 .362 r
.60311 .74738 m .60312 .74937 L .60415 .74605 L F
.416 .175 .438 r
.68475 .73198 m .6866 .73135 L .68475 .7336 L F
.848 .689 .686 r
.68475 .7336 m .68506 .73166 L .68475 .73198 L F
.787 .354 .22 r
.57479 .81864 m .5741 .81721 L .57264 .8174 L F
.57479 .81864 m .57264 .8174 L .57467 .8185 L F
.305 .157 .51 r
.57717 .81835 m .57479 .81864 L .57592 .81918 L F
.617 .813 .976 r
.57717 .81835 m .57592 .81918 L .57582 .81912 L F
.279 .056 .386 r
.57583 .81912 m .57479 .81864 L .57717 .81835 L F
.78 .455 0 r
.57479 .81864 m .57514 .81903 L .57483 .81801 L F
.787 .354 .22 r
.57479 .81864 m .57467 .8185 L .5757 .81906 L F
.345 0 0 r
.57388 .81809 m .57592 .81918 L .57502 .81869 L F
.57388 .81809 m .57502 .81869 L .57264 .8174 L F
.21 0 0 r
.57264 .8174 m .57112 .81722 L .57114 .81955 L F
.835 .975 .672 r
.57264 .8174 m .57114 .81955 L .57166 .81778 L F
.345 0 0 r
.57388 .81809 m .57264 .8174 L .57166 .81778 L F
.283 .7 .971 r
.57289 .81738 m .57388 .81809 L .57166 .81778 L F
.831 .679 .138 r
.57296 .8176 m .57388 .81809 L .57289 .81738 L F
.57367 .81977 m .57388 .81809 L .57296 .8176 L F
.617 .813 .976 r
.57717 .81835 m .57582 .81912 L .57388 .81809 L F
.279 .056 .386 r
.57643 .81939 m .57583 .81912 L .57717 .81835 L F
.787 .354 .22 r
.57479 .81864 m .5757 .81906 L .57592 .81918 L F
.78 .455 0 r
.57479 .81864 m .57554 .82036 L .57514 .81903 L F
.976 .891 .675 r
.57371 .82223 m .57554 .82036 L .57479 .81864 L F
.279 .056 .386 r
.5753 .821 m .57479 .81864 L .57643 .81939 L F
.474 .052 .158 r
.36643 .74813 m .36516 .74957 L .36287 .7497 L F
.404 0 .108 r
.36774 .74913 m .36643 .74813 L .36828 .74771 L F
.36774 .74913 m .36516 .74957 L .36643 .74813 L F
.58 .786 .977 r
.67394 .75887 m .67516 .75735 L .67306 .75714 L F
.67394 .75887 m .67613 .75844 L .67516 .75735 L F
.527 .291 .501 r
.41581 .74997 m .4155 .75205 L .41344 .75237 L F
.41581 .74997 m .4155 .75205 L .41344 .75237 L F
.551 .345 .555 r
.4155 .75205 m .41792 .74948 L .41581 .74997 L F
.41792 .74948 m .4155 .75205 L .41581 .74997 L F
.541 0 0 r
.48844 .84132 m .4887 .84166 L .48691 .84055 L F
.688 .427 .522 r
.60764 .76828 m .60769 .77032 L .60615 .77032 L F
.574 .364 .558 r
.61016 .76781 m .60769 .77032 L .60764 .76828 L F
0 0 .007 r
.60709 .82816 m .60844 .82512 L .60792 .82732 L F
0 0 .038 r
.60675 .83015 m .60709 .82816 L .60792 .82732 L F
.474 0 0 r
.37129 .74757 m .37016 .74846 L .36828 .74771 L F
0 .556 .73 r
.37361 .74871 m .37016 .74846 L .37129 .74757 L F
.034 .605 .711 r
.45587 .8856 m .4571 .88555 L .45703 .88555 L F
.535 .828 .999 r
.6591 .75927 m .65801 .76048 L .65707 .76013 L F
.6591 .75927 m .66012 .75999 L .65801 .76048 L F
.685 .604 .759 r
.70024 .71825 m .69842 .72147 L .69796 .71873 L F
.70024 .71825 m .70209 .719 L .69842 .72147 L F
.331 .018 .275 r
.69842 .72147 m .69984 .72229 L .69818 .72306 L F
.69842 .72147 m .70209 .719 L .69984 .72229 L F
.454 .569 .881 r
.37041 .72603 m .37031 .72843 L .3687 .72614 L F
.37041 .72603 m .37219 .72864 L .37031 .72843 L F
0 0 0 r
.6831 .74634 m .68258 .74628 L .68468 .74474 L F
.814 .935 .567 r
.68322 .74568 m .6831 .74634 L .68433 .74439 L F
0 0 .462 r
.68337 .74638 m .6831 .74634 L .68322 .74568 L F
.68383 .74852 m .6831 .74634 L .68337 .74638 L F
0 0 0 r
.6831 .74634 m .68144 .74711 L .68258 .74628 L F
.92 .941 .585 r
.68565 .74128 m .68433 .74439 L .68468 .74474 L F
.898 .967 .649 r
.68433 .74439 m .6831 .74634 L .68468 .74474 L F
.698 .369 .417 r
.50866 .83259 m .50992 .83137 L .50839 .83013 L F
.50866 .83259 m .51211 .83106 L .50992 .83137 L F
.885 .882 .825 r
.39265 .89848 m .39578 .89627 L .39515 .89618 L F
.637 .964 .89 r
.39515 .89618 m .39578 .89627 L .39758 .89519 L F
.461 .225 .47 r
.3951 .77035 m .39277 .77296 L .39308 .77075 L F
.656 .493 .652 r
.38836 .84935 m .39097 .84918 L .39088 .84687 L F
.645 .486 .653 r
.39088 .84687 m .39312 .84662 L .39315 .84426 L F
.666 .515 .67 r
.39097 .84918 m .39312 .84662 L .39088 .84687 L F
.411 .6 .923 r
.52281 .87617 m .52456 .87761 L .52483 .87728 L F
.506 .227 .425 r
.4022 .7645 m .40171 .76747 L .39962 .7678 L F
.499 .255 .475 r
.40482 .76246 m .40452 .76415 L .4022 .7645 L F
.486 .209 .419 r
.40363 .76707 m .4022 .7645 L .40452 .76415 L F
.40363 .76707 m .40171 .76747 L .4022 .7645 L F
.579 .937 .924 r
.51867 .85372 m .5178 .85472 L .51678 .85465 L F
.51678 .85465 m .5178 .85472 L .51867 .85372 L F
.697 .569 .707 r
.39315 .84426 m .39536 .844 L .39521 .8417 L F
.689 .522 .656 r
.39312 .84662 m .39536 .844 L .39315 .84426 L F
.572 .363 .558 r
.55171 .83573 m .55385 .83357 L .55387 .83583 L F
0 0 0 r
.55494 .83256 m .55385 .83357 L .55538 .83075 L F
0 0 .371 r
.55387 .83583 m .55385 .83357 L .55494 .83256 L F
.28 .779 .87 r
.58202 .84952 m .58314 .84905 L .58087 .84929 L F
.58202 .84952 m .58419 .84914 L .58314 .84905 L F
.642 .844 .978 r
.42578 .88803 m .4271 .88878 L .42898 .88808 L F
0 0 0 r
.40396 .89477 m .40365 .89385 L .40544 .89309 L F
.40396 .89477 m .40233 .89601 L .40365 .89385 L F
.672 .455 .582 r
.44668 .84412 m .44645 .84632 L .44465 .84637 L F
.547 .042 .007 r
.59259 .77457 m .5915 .77535 L .58979 .77494 L F
.461 0 0 r
.595 .77522 m .5915 .77535 L .59259 .77457 L F
.577 .246 .37 r
.44869 .83059 m .45196 .82836 L .44908 .82853 L F
.44869 .83059 m .45104 .8307 L .45196 .82836 L F
.551 .218 .359 r
.45196 .82836 m .45104 .8307 L .45373 .82987 L F
.59 .202 .274 r
.45196 .82836 m .45373 .82987 L .45412 .8286 L F
.649 .472 .631 r
.38597 .85185 m .38872 .85191 L .38836 .84935 L F
.647 .466 .625 r
.38872 .85191 m .39097 .84918 L .38836 .84935 L F
.58 .405 .609 r
.65435 .73168 m .65683 .73157 L .65613 .72931 L F
.559 .31 .496 r
.37822 .76792 m .38031 .76769 L .38089 .76498 L F
.547 .285 .47 r
.38031 .76769 m .38308 .76487 L .38089 .76498 L F
.475 .185 .393 r
.38603 .77619 m .38549 .77804 L .38348 .77836 L F
.486 .196 .398 r
.38753 .77768 m .38603 .77619 L .38803 .77589 L F
.38753 .77768 m .38549 .77804 L .38603 .77619 L F
.091 0 .1 r
.58956 .83421 m .58759 .83624 L .58836 .83489 L F
.327 .321 .7 r
.58914 .83145 m .58956 .83421 L .59013 .83191 L F
.898 .903 .821 r
.59013 .83191 m .58956 .83421 L .58836 .83489 L F
.589 .59 .821 r
.52151 .84572 m .51867 .84665 L .51753 .84377 L F
.572 .221 .336 r
.52142 .8483 m .51867 .84665 L .52151 .84572 L F
.52142 .8483 m .51763 .84869 L .51867 .84665 L F
.116 0 0 r
.52556 .81741 m .52424 .81941 L .52271 .81988 L F
.205 0 .101 r
.52812 .8158 m .52717 .81756 L .52556 .81741 L F
.452 .103 .283 r
.52717 .81756 m .52424 .81941 L .52556 .81741 L F
0 0 0 r
.66732 .75427 m .66871 .75391 L .67046 .75278 L F
.66732 .75427 m .66694 .75492 L .66871 .75391 L F
.733 .862 .437 r
.60483 .80468 m .60323 .80775 L .60374 .80642 L F
0 0 0 r
.60579 .80358 m .60483 .80468 L .60374 .80642 L F
.539 .155 .261 r
.4648 .82582 m .46671 .82687 L .46799 .82496 L F
.505 .051 .107 r
.46671 .82687 m .47013 .8256 L .46799 .82496 L F
.512 .366 .619 r
.65613 .72931 m .65683 .73157 L .65868 .73073 L F
.65613 .72931 m .65683 .73157 L .65868 .73073 L F
.834 .904 .887 r
.58836 .83489 m .58759 .83624 L .58614 .83556 L F
0 0 0 r
.51664 .81441 m .51806 .81418 L .51958 .81296 L F
.609 .887 .573 r
.60667 .801 m .60627 .80167 L .60669 .80183 L F
.60667 .801 m .60866 .79909 L .60627 .80167 L F
0 0 .031 r
.60669 .80183 m .60627 .80167 L .60579 .80358 L F
.654 .944 .699 r
.67046 .75278 m .67186 .75103 L .67182 .75194 L F
.67046 .75278 m .66871 .75391 L .67186 .75103 L F
.442 .1 .29 r
.57781 .76865 m .57739 .76991 L .5799 .76829 L F
.351 .774 .975 r
.4653 .8826 m .46663 .88309 L .4687 .88293 L F
.637 .263 .318 r
.5003 .82628 m .50013 .82766 L .50264 .82753 L F
.82 .833 .859 r
.4937 .88389 m .49665 .88324 L .49546 .88275 L F
.611 .774 .958 r
.49665 .88324 m .4973 .88175 L .49546 .88275 L F
.49665 .88324 m .49878 .88277 L .4973 .88175 L F
.597 .648 .871 r
.37838 .73071 m .37557 .72899 L .37867 .72916 L F
.675 .571 .73 r
.38083 .72873 m .37838 .73071 L .37867 .72916 L F
.653 .509 .675 r
.37239 .86483 m .37435 .862 L .37214 .86234 L F
.622 .466 .649 r
.36423 .77603 m .36438 .77842 L .36646 .77577 L F
.259 .746 .922 r
.51295 .82064 m .51168 .82034 L .5096 .82048 L F
.051 .618 .735 r
.51295 .82064 m .51383 .82057 L .51168 .82034 L F
.51295 .82064 m .51517 .82056 L .51383 .82057 L F
.648 .61 .797 r
.49837 .84188 m .4989 .8442 L .50099 .84317 L F
.522 .412 .669 r
.4989 .8442 m .50261 .84504 L .50099 .84317 L F
.4989 .8442 m .49924 .84657 L .50261 .84504 L F
.769 .537 .582 r
.54851 .83356 m .54471 .83231 L .54715 .83252 L F
0 0 .182 r
.54948 .83033 m .54851 .83356 L .54715 .83252 L F
.728 .446 .5 r
.55166 .85073 m .55194 .84926 L .54862 .84938 L F
.976 .727 .491 r
.55194 .84926 m .55134 .85026 L .54862 .84938 L F
.432 .616 .927 r
.55016 .84858 m .55134 .85026 L .54862 .84938 L F
.976 .727 .491 r
.55176 .85015 m .55194 .84926 L .55318 .84868 L F
.432 .616 .927 r
.55134 .85026 m .55166 .85073 L .55088 .85038 L F
.976 .727 .491 r
.55194 .84926 m .55153 .85142 L .55082 .85111 L F
.55082 .85111 m .55195 .85159 L .55194 .84926 L F
.55082 .85111 m .55134 .85026 L .55176 .85015 L F
.55134 .85026 m .55194 .84926 L .55185 .84972 L F
.988 .795 .557 r
.55143 .84692 m .55174 .84987 L .55052 .84839 L F
.55174 .84987 m .55184 .85081 L .55152 .85021 L F
.976 .727 .491 r
.55134 .85026 m .55185 .84972 L .55152 .85021 L F
.988 .795 .557 r
.55174 .84987 m .55152 .85021 L .55052 .84839 L F
.976 .727 .491 r
.55152 .85021 m .55185 .84972 L .55176 .85015 L F
.432 .616 .927 r
.55134 .85026 m .55088 .85038 L .54862 .84938 L F
.976 .727 .491 r
.55134 .85026 m .55082 .85111 L .54862 .84938 L F
.432 .616 .927 r
.5514 .8502 m .55184 .85081 L .55166 .85073 L F
.5515 .85018 m .55184 .85081 L .5514 .8502 L F
.976 .727 .491 r
.55194 .84926 m .55194 .85113 L .55166 .85073 L F
.728 .446 .5 r
.55184 .85081 m .55194 .84926 L .55166 .85073 L F
.976 .727 .491 r
.55082 .85111 m .55176 .85015 L .55265 .85042 L F
.55176 .85015 m .55318 .84868 L .55278 .85 L F
.55176 .85015 m .55278 .85 L .55265 .85042 L F
.432 .616 .927 r
.55052 .84839 m .5515 .85018 L .5514 .8502 L F
.55052 .84839 m .55166 .85073 L .55016 .84858 L F
.976 .727 .491 r
.55166 .85073 m .55195 .85159 L .55153 .85142 L F
.55194 .85113 m .55195 .85159 L .55166 .85073 L F
.835 .799 .817 r
.55143 .84692 m .55194 .84926 L .55184 .85081 L F
.55143 .84692 m .55418 .84663 L .55194 .84926 L F
.388 .151 .43 r
.55194 .84926 m .55418 .84663 L .55318 .84868 L F
.359 .346 .708 r
.69146 .70726 m .6898 .70882 L .69013 .70734 L F
.405 .432 .775 r
.69146 .70726 m .69074 .71028 L .6898 .70882 L F
.714 .59 .716 r
.61256 .74191 m .61338 .74436 L .61066 .74425 L F
.483 .238 .466 r
.37191 .78626 m .37124 .78849 L .36931 .78881 L F
.489 .231 .449 r
.37393 .78592 m .37124 .78849 L .37191 .78626 L F
.752 .442 .459 r
.45533 .8464 m .45315 .84427 L .45557 .84399 L F
.45533 .8464 m .45222 .8462 L .45315 .84427 L F
.797 .312 .057 r
.54445 .81416 m .54563 .81536 L .5469 .81558 L F
.671 .206 0 r
.54787 .81727 m .5469 .81558 L .54563 .81536 L F
0 .228 .74 r
.54696 .81624 m .54787 .81727 L .54692 .81621 L F
.671 .206 0 r
.54787 .81727 m .54862 .81812 L .5469 .81558 L F
0 .228 .74 r
.54933 .81792 m .54787 .81727 L .54696 .81624 L F
.671 .206 0 r
.54787 .81727 m .54873 .8183 L .54862 .81812 L F
.217 .727 .889 r
.44391 .88514 m .44555 .8854 L .44729 .88526 L F
.714 .855 .949 r
.41368 .90377 m .41559 .90393 L .41392 .90312 L F
.719 .856 .947 r
.41392 .90312 m .41352 .90507 L .41213 .90306 L F
.714 .855 .949 r
.41317 .90511 m .4135 .90495 L .41368 .90377 L F
.4135 .90495 m .41559 .90393 L .41368 .90377 L F
.406 .565 .899 r
.41213 .90306 m .41349 .90502 L .41116 .9045 L F
.41349 .90502 m .41352 .90507 L .41348 .90506 L F
.41349 .90502 m .41348 .90506 L .41116 .9045 L F
.366 .51 .87 r
.41116 .9045 m .41317 .90511 L .41213 .90306 L F
.588 .823 .989 r
.57659 .84961 m .57769 .84825 L .57553 .8484 L F
.57659 .84961 m .57871 .8491 L .57769 .84825 L F
.905 .711 .63 r
.47392 .85196 m .47366 .85431 L .47247 .85144 L F
.593 .385 .568 r
.47618 .8518 m .47366 .85431 L .47392 .85196 L F
.075 .036 .504 r
.5713 .83904 m .5707 .83621 L .57217 .83498 L F
.893 .824 .772 r
.57064 .81442 m .57287 .81284 L .57204 .81196 L F
.974 .737 .515 r
.56621 .78918 m .56319 .79042 L .56333 .7895 L F
.56621 .78918 m .56503 .79079 L .56319 .79042 L F
.743 .618 .72 r
.6968 .71793 m .69796 .71873 L .69495 .71827 L F
.639 .601 .794 r
.69925 .7153 m .69796 .71873 L .6968 .71793 L F
.69925 .7153 m .70024 .71825 L .69796 .71873 L F
.701 .572 .707 r
.39536 .844 m .39747 .84136 L .39521 .8417 L F
.279 .028 .344 r
.66131 .72628 m .66056 .7295 L .66323 .72578 L F
.728 .852 .42 r
.60374 .80642 m .60323 .80775 L .60223 .8094 L F
.64 .358 .476 r
.42077 .82756 m .42428 .82755 L .42416 .82558 L F
.713 .415 .471 r
.42428 .82755 m .42623 .828 L .42416 .82558 L F
.416 .111 .336 r
.5274 .8363 m .52678 .83833 L .52475 .83854 L F
.623 .401 .559 r
.52919 .83577 m .52678 .83833 L .5274 .8363 L F
.39 .832 .705 r
.65937 .7661 m .65929 .76595 L .65752 .76661 L F
.65937 .7661 m .66123 .76513 L .65929 .76595 L F
.665 .487 .635 r
.39312 .84662 m .39542 .84635 L .39536 .844 L F
.62 .458 .641 r
.39536 .844 m .39756 .84376 L .39747 .84136 L F
.62 .452 .633 r
.39542 .84635 m .39756 .84376 L .39536 .844 L F
.797 .5 .485 r
.52175 .83609 m .52451 .83813 L .52383 .83534 L F
.52175 .83609 m .52091 .83853 L .52451 .83813 L F
.667 .427 .549 r
.6002 .77075 m .60031 .77302 L .59767 .7731 L F
.712 .514 .62 r
.6026 .77054 m .60031 .77302 L .6002 .77075 L F
.584 .354 .534 r
.37121 .77096 m .37331 .77216 L .37334 .77034 L F
.37121 .77096 m .37076 .77283 L .37331 .77216 L F
0 0 0 r
.62885 .73945 m .62811 .74105 L .62656 .7419 L F
.263 0 .06 r
.62752 .74302 m .62656 .7419 L .62811 .74105 L F
.62752 .74302 m .62564 .74358 L .62656 .7419 L F
0 0 0 r
.6806 .74802 m .68144 .74711 L .6831 .74634 L F
.541 .766 .981 r
.48202 .88399 m .48595 .88505 L .48459 .88427 L F
.593 .816 .985 r
.48595 .88505 m .487 .88328 L .48459 .88427 L F
.48595 .88505 m .48813 .88466 L .487 .88328 L F
.971 .853 .667 r
.37901 .75013 m .38075 .74869 L .38035 .74822 L F
.433 .859 .943 r
.38217 .7476 m .38075 .74869 L .38419 .74659 L F
.38217 .7476 m .38035 .74822 L .38075 .74869 L F
.074 0 .315 r
.60826 .82045 m .6096 .81764 L .61026 .81996 L F
.341 .194 .532 r
.60819 .8228 m .60826 .82045 L .61026 .81996 L F
.369 .177 .484 r
.61622 .80503 m .61803 .80218 L .61752 .80417 L F
.148 0 .282 r
.61562 .80691 m .61622 .80503 L .61752 .80417 L F
.47 .834 .993 r
.65579 .75275 m .6579 .75231 L .65857 .7529 L F
.671 .277 .291 r
.6579 .75231 m .66129 .75229 L .65857 .7529 L F
.555 .362 .573 r
.69087 .73665 m .69306 .73856 L .69165 .73952 L F
.38 .224 .541 r
.69306 .73856 m .69083 .74074 L .69165 .73952 L F
.662 .446 .582 r
.4069 .83587 m .40921 .83584 L .40927 .83354 L F
.603 .372 .539 r
.40921 .83584 m .41201 .83317 L .40927 .83354 L F
.253 .178 .574 r
.44218 .82523 m .44106 .82804 L .43994 .82758 L F
.44218 .82523 m .44259 .82801 L .44106 .82804 L F
.638 .266 .322 r
.44106 .82804 m .44308 .82961 L .44345 .82834 L F
.252 .332 .752 r
.44259 .82801 m .44308 .82961 L .44106 .82804 L F
.684 .655 .815 r
.57173 .78921 m .56853 .78704 L .57098 .78629 L F
.917 .918 .801 r
.56876 .79161 m .57173 .78921 L .57082 .78898 L F
.56876 .79161 m .56975 .79213 L .57173 .78921 L F
0 0 .253 r
.57122 .78685 m .57173 .78921 L .57098 .78629 L F
.982 .894 .655 r
.57122 .78685 m .57082 .78898 L .57173 .78921 L F
.935 .867 .748 r
.55387 .83583 m .55229 .8406 L .55171 .83573 L F
.842 .75 .761 r
.55275 .84472 m .55418 .84663 L .55143 .84692 L F
.726 .686 .143 r
.55382 .84601 m .55384 .84611 L .55395 .84517 L F
0 0 .474 r
.55384 .84611 m .55418 .84663 L .55385 .84619 L F
.94 .944 .609 r
.55318 .84868 m .55418 .84663 L .55384 .84611 L F
.55318 .84868 m .55384 .84611 L .55343 .84851 L F
.726 .686 .143 r
.55343 .84851 m .55384 .84611 L .55382 .84601 L F
0 0 .474 r
.55384 .84611 m .55385 .84619 L .55275 .84472 L F
.729 .429 .471 r
.5652 .80407 m .56736 .80492 L .56735 .80213 L F
.646 .524 .7 r
.39747 .84136 m .39972 .84115 L .39943 .83874 L F
.627 .457 .633 r
.39756 .84376 m .39972 .84115 L .39747 .84136 L F
.639 .617 .813 r
.61066 .74425 m .6073 .7418 L .61072 .74229 L F
.769 .675 .76 r
.61256 .74191 m .61066 .74425 L .61072 .74229 L F
0 0 0 r
.5529 .84138 m .55548 .83878 L .55537 .8412 L F
.962 .765 .32 r
.55477 .83955 m .55548 .83878 L .5548 .83837 L F
.55477 .83955 m .55537 .8412 L .55548 .83878 L F
.701 .556 .688 r
.37726 .85974 m .37949 .85964 L .37934 .85726 L F
.673 .53 .682 r
.37934 .85726 m .3816 .85695 L .38141 .85463 L F
.674 .536 .689 r
.37949 .85964 m .3816 .85695 L .37934 .85726 L F
.956 .849 .697 r
.53291 .82077 m .53105 .82227 L .53334 .81978 L F
.53291 .82077 m .53218 .82274 L .53105 .82227 L F
.6 .854 .992 r
.54982 .84133 m .5529 .84138 L .55081 .84075 L F
.6 .853 .992 r
.55081 .84075 m .5529 .84138 L .55477 .83955 L F
.528 .218 .385 r
.5529 .84138 m .55378 .843 L .55255 .84286 L F
.5529 .84138 m .55537 .8412 L .55378 .843 L F
.5529 .84138 m .5528 .84182 L .55332 .84122 L F
.55338 .84091 m .55332 .84122 L .55477 .83955 L F
.5529 .84138 m .55332 .84122 L .55338 .84091 L F
.469 0 .05 r
.54982 .84133 m .55331 .84128 L .55123 .84292 L F
.55331 .84128 m .55341 .84128 L .55329 .84137 L F
.55331 .84128 m .55329 .84137 L .55123 .84292 L F
.577 .731 .947 r
.55081 .84075 m .55332 .84126 L .54982 .84133 L F
.55332 .84126 m .55341 .84128 L .55331 .84128 L F
.55332 .84126 m .55331 .84128 L .54982 .84133 L F
.528 .218 .385 r
.5528 .84182 m .55255 .84286 L .55433 .84021 L F
.638 .703 .894 r
.55477 .83955 m .55341 .84128 L .55332 .84126 L F
.528 .218 .385 r
.5528 .84182 m .55332 .84126 L .55477 .83955 L F
.638 .703 .894 r
.55477 .83955 m .55332 .84126 L .55081 .84075 L F
.528 .218 .385 r
.55332 .84126 m .55369 .84088 L .55477 .83955 L F
.71 .959 .692 r
.55123 .84292 m .55329 .84137 L .55477 .83955 L F
.55329 .84137 m .55341 .84128 L .55477 .83955 L F
.528 .218 .385 r
.55369 .84088 m .55433 .84021 L .55477 .83955 L F
.291 .747 .954 r
.51721 .87626 m .51372 .87591 L .51613 .87573 L F
.712 .927 .963 r
.51902 .87521 m .51721 .87626 L .51613 .87573 L F
.954 .661 .442 r
.67678 .73523 m .67781 .73427 L .67584 .73362 L F
.67678 .73523 m .67763 .73554 L .67781 .73427 L F
.579 .41 .617 r
.59983 .7445 m .60036 .74689 L .59774 .74717 L F
.572 .378 .58 r
.59774 .74717 m .59964 .74909 L .60036 .74689 L F
.579 .41 .617 r
.59983 .7445 m .60036 .74689 L .59774 .74717 L F
.572 .378 .58 r
.59774 .74717 m .59964 .74909 L .60036 .74689 L F
.591 .211 .292 r
.49994 .8149 m .5021 .81506 L .50322 .81369 L F
.552 .166 .264 r
.50322 .81369 m .5021 .81506 L .50532 .81444 L F
.619 .639 .848 r
.60742 .75248 m .60481 .75427 L .60415 .75418 L F
.60742 .75248 m .60748 .75491 L .60481 .75427 L F
.155 .654 .911 r
.68993 .73618 m .69087 .73665 L .68733 .73598 L F
.465 .813 .998 r
.69253 .73565 m .69087 .73665 L .68993 .73618 L F
.603 .556 .775 r
.6915 .73272 m .69253 .73565 L .68993 .73618 L F
.987 .837 .455 r
.69206 .73503 m .69253 .73565 L .69205 .73486 L F
.465 .813 .998 r
.69253 .73565 m .69305 .73634 L .69087 .73665 L F
.555 .362 .573 r
.69087 .73665 m .69311 .73633 L .69306 .73856 L F
.987 .837 .455 r
.69217 .73789 m .69253 .73565 L .69206 .73503 L F
.465 .813 .998 r
.69253 .73565 m .69311 .73633 L .69305 .73634 L F
.653 .26 .288 r
.48753 .84439 m .4895 .84579 L .49075 .84399 L F
.584 .678 .905 r
.49075 .84399 m .49119 .84139 L .4887 .84166 L F
.949 .683 .498 r
.4895 .84579 m .49107 .84649 L .49075 .84399 L F
.563 .358 .56 r
.40705 .76024 m .40689 .76232 L .40482 .76246 L F
.531 .331 .554 r
.40705 .76024 m .40896 .76204 L .40689 .76232 L F
.602 .324 .468 r
.40925 .76024 m .40896 .76204 L .40705 .76024 L F
.651 .514 .683 r
.3816 .85695 m .38365 .8543 L .38141 .85463 L F
.761 .625 .708 r
.61256 .74191 m .60935 .73923 L .61159 .7389 L F
.61256 .74191 m .61072 .74229 L .60935 .73923 L F
.72 .691 .822 r
.61454 .7395 m .61256 .74191 L .61159 .7389 L F
0 0 0 r
.56811 .77386 m .56873 .77392 L .57031 .77348 L F
.56811 .77386 m .56674 .77473 L .56873 .77392 L F
.01 0 .081 r
.61965 .73645 m .62115 .73565 L .62259 .73437 L F
.285 .355 .76 r
.62338 .73326 m .62259 .73437 L .62365 .7333 L F
.573 .365 .562 r
.62115 .73565 m .62365 .7333 L .62259 .73437 L F
.553 .545 .799 r
.49091 .85944 m .49212 .86271 L .49416 .86248 L F
.405 .432 .775 r
.69146 .70726 m .69228 .71033 L .69074 .71028 L F
.403 .442 .787 r
.69228 .71033 m .69319 .71186 L .69074 .71028 L F
.7 .446 .536 r
.6916 .72616 m .69423 .72631 L .69384 .72835 L F
.139 0 .343 r
.69384 .72835 m .69423 .72631 L .69574 .72528 L F
.954 .634 .218 r
.55092 .82189 m .55176 .82299 L .55057 .82006 L F
.53 .272 .469 r
.40689 .76232 m .40452 .76415 L .40482 .76246 L F
.87 .644 .593 r
.45636 .8464 m .45533 .8464 L .45557 .84399 L F
.34 0 0 r
.34798 .75212 m .34929 .75211 L .34778 .75226 L F
.656 .102 0 r
.54604 .80139 m .5426 .79893 L .54405 .79878 L F
.587 .803 .982 r
.59964 .74909 m .60111 .74998 L .60312 .74937 L F
.837 .696 .707 r
.49095 .87543 m .4947 .87291 L .49291 .87226 L F
.86 .675 .651 r
.4947 .87291 m .49312 .86994 L .49291 .87226 L F
.28 .779 .871 r
.69321 .72374 m .6916 .72616 L .69087 .72585 L F
.622 .454 .633 r
.6916 .72616 m .69162 .72877 L .69087 .72585 L F
.6916 .72616 m .69384 .72835 L .69162 .72877 L F
.324 0 .104 r
.47952 .82235 m .4815 .8219 L .48285 .81995 L F
.322 0 .103 r
.48285 .81995 m .48347 .82143 L .48501 .8202 L F
.48285 .81995 m .4815 .8219 L .48347 .82143 L F
0 0 0 r
.60992 .79817 m .60866 .79909 L .60667 .801 L F
.424 .823 .982 r
.54799 .79404 m .54683 .7936 L .55002 .79366 L F
.459 .814 .997 r
.40878 .75132 m .40806 .7522 L .40676 .75165 L F
.41 .749 .994 r
.40878 .75132 m .41015 .75242 L .40806 .7522 L F
.638 .482 .656 r
.41201 .83317 m .4144 .83106 L .41124 .83069 L F
.594 .432 .632 r
.5221 .83836 m .5229 .84161 L .52018 .84143 L F
.581 .424 .633 r
.52374 .83966 m .5221 .83836 L .52475 .83854 L F
.52374 .83966 m .5229 .84161 L .52285 .84139 L F
.52365 .83958 m .52285 .84139 L .5221 .83836 L F
.52374 .83966 m .52285 .84139 L .52365 .83958 L F
.486 .197 .399 r
.52091 .83853 m .52267 .83993 L .52451 .83813 L F
0 0 .345 r
.52383 .83534 m .52451 .83813 L .52436 .83624 L F
.911 .944 .589 r
.52448 .83771 m .52267 .83993 L .52436 .83624 L F
.52451 .83813 m .52413 .83851 L .52448 .83771 L F
.52413 .83851 m .52267 .83993 L .52448 .83771 L F
.719 .898 .96 r
.46905 .8377 m .47025 .8384 L .47231 .8371 L F
.196 .298 .742 r
.55538 .83075 m .5547 .82795 L .55459 .83035 L F
0 0 0 r
.55494 .83256 m .55538 .83075 L .55459 .83035 L F
.557 .375 .591 r
.61623 .75975 m .61407 .76249 L .61458 .76051 L F
.901 .695 .615 r
.54279 .8097 m .54254 .81232 L .5442 .81251 L F
.821 .34 0 r
.54254 .81232 m .54445 .81416 L .5442 .81251 L F
.821 .965 .899 r
.62774 .77321 m .62842 .77381 L .62653 .77457 L F
.62774 .77321 m .6298 .77261 L .62842 .77381 L F
.425 .147 .386 r
.37067 .79063 m .36931 .78881 L .37124 .78849 L F
.37067 .79063 m .36886 .79113 L .36931 .78881 L F
.125 0 0 r
.37999 .89874 m .38056 .89884 L .37919 .89861 L F
.646 .453 .609 r
.38365 .8543 m .38587 .85396 L .38597 .85185 L F
.7 .549 .679 r
.38587 .85396 m .38872 .85191 L .38597 .85185 L F
.797 .477 .447 r
.56078 .79585 m .56097 .79813 L .56181 .79707 L F
.719 .19 0 r
.55934 .79413 m .56078 .79585 L .56191 .79624 L F
.424 .023 .173 r
.56078 .79585 m .56423 .79422 L .56191 .79624 L F
.797 .477 .447 r
.56078 .79585 m .56181 .79707 L .56293 .79564 L F
.719 .19 0 r
.55915 .79397 m .56078 .79585 L .55934 .79413 L F
.563 .226 .356 r
.58519 .76604 m .58726 .76732 L .58826 .76512 L F
.647 .315 .396 r
.58826 .76512 m .59044 .76675 L .59046 .76525 L F
.58826 .76512 m .58726 .76732 L .59044 .76675 L F
.995 .814 .55 r
.5459 .78382 m .54455 .7855 L .54553 .78565 L F
.5459 .78382 m .54455 .7855 L .54553 .78565 L F
.669 .835 .963 r
.48476 .87067 m .48257 .87209 L .48133 .87121 L F
.591 .327 .484 r
.48474 .87267 m .48257 .87209 L .48476 .87067 L F
.58 .47 .693 r
.48571 .87496 m .48257 .87209 L .48474 .87267 L F
.48571 .87496 m .48366 .87545 L .48257 .87209 L F
.728 .627 .745 r
.3779 .72816 m .37867 .72916 L .37557 .72899 L F
.682 .616 .776 r
.38083 .72873 m .37867 .72916 L .3779 .72816 L F
.385 0 0 r
.61711 .73683 m .6199 .73708 L .61965 .73645 L F
.6199 .73708 m .61994 .73707 L .61965 .73645 L F
.494 .496 .787 r
.61794 .7331 m .61978 .73676 L .61711 .73683 L F
.822 .778 .811 r
.61982 .7371 m .6202 .73701 L .62115 .73565 L F
.01 0 .081 r
.61965 .73645 m .61994 .73709 L .62115 .73565 L F
.722 .602 .723 r
.62115 .73565 m .61994 .73709 L .61991 .73701 L F
.62115 .73565 m .61991 .73701 L .61794 .7331 L F
.494 .496 .787 r
.61978 .73676 m .61991 .73701 L .61972 .737 L F
.61978 .73676 m .61972 .737 L .61711 .73683 L F
.61991 .73701 m .6199 .73708 L .61711 .73683 L F
.822 .778 .811 r
.61797 .73757 m .61982 .7371 L .62115 .73565 L F
.61697 .73687 m .61996 .73599 L .6184 .73557 L F
.61996 .73599 m .62115 .73565 L .62005 .73562 L F
.61996 .73599 m .62005 .73562 L .6184 .73557 L F
.61797 .73757 m .6192 .73844 L .6202 .73701 L F
.385 0 0 r
.6199 .73708 m .61994 .73709 L .61994 .73707 L F
.494 .496 .787 r
.61991 .73701 m .61994 .73709 L .6199 .73708 L F
.822 .778 .811 r
.61697 .73687 m .61797 .73757 L .61994 .73638 L F
.61996 .73599 m .61994 .73638 L .62115 .73565 L F
.61697 .73687 m .61994 .73638 L .61996 .73599 L F
.124 0 0 r
.41015 .75242 m .41205 .75243 L .41344 .75237 L F
.484 .871 .972 r
.41344 .75237 m .41522 .75177 L .4155 .75205 L F
.41344 .75237 m .41205 .75243 L .41522 .75177 L F
.555 .402 .628 r
.41555 .75423 m .41344 .75237 L .4155 .75205 L F
.41555 .75423 m .41358 .75464 L .41344 .75237 L F
.547 .117 .176 r
.42925 .82722 m .43136 .82758 L .43233 .82639 L F
.718 .478 .562 r
.43136 .82758 m .43456 .82576 L .43233 .82639 L F
.306 .136 .479 r
.6096 .81764 m .61205 .81477 L .61173 .81695 L F
.296 .144 .498 r
.61026 .81996 m .6096 .81764 L .61173 .81695 L F
.973 .716 .485 r
.4162 .90685 m .41784 .90956 L .4166 .90954 L F
.566 .643 .886 r
.41967 .90909 m .41784 .90956 L .4162 .90685 L F
.321 .807 .864 r
.4166 .90954 m .41784 .90956 L .41967 .90909 L F
.622 .73 .924 r
.39707 .73992 m .39383 .73908 L .39583 .73877 L F
.535 .756 .978 r
.39781 .73852 m .39707 .73992 L .39583 .73877 L F
.39781 .73852 m .39912 .73959 L .39707 .73992 L F
.642 .085 0 r
.68112 .71848 m .68275 .71963 L .68329 .71931 L F
0 .08 .641 r
.68103 .72249 m .68147 .72231 L .68005 .72206 L F
.862 .928 .543 r
.68182 .72217 m .68147 .72231 L .68099 .72378 L F
0 .061 .625 r
.68147 .72231 m .68367 .72583 L .68099 .72378 L F
0 .08 .641 r
.68284 .72329 m .68329 .72461 L .68147 .72231 L F
0 .061 .625 r
.68364 .72578 m .68329 .72461 L .68367 .72583 L F
.68147 .72231 m .68316 .72444 L .68364 .72578 L F
.68316 .72444 m .68329 .72461 L .68364 .72578 L F
0 .08 .641 r
.68284 .72329 m .68147 .72231 L .68103 .72249 L F
.862 .928 .543 r
.68329 .71931 m .68147 .72231 L .68182 .72217 L F
.68329 .71931 m .68275 .71963 L .68147 .72231 L F
.553 .644 .894 r
.68068 .72372 m .68147 .72231 L .68099 .72378 L F
.946 .681 .503 r
.67945 .72352 m .68005 .72573 L .67887 .72563 L F
.553 .644 .894 r
.67945 .72352 m .68099 .72378 L .68005 .72573 L F
.946 .681 .503 r
.67945 .72352 m .67887 .72563 L .68015 .72343 L F
.67945 .72352 m .68015 .72343 L .68024 .72327 L F
.917 .613 .454 r
.67841 .72105 m .67945 .72352 L .68024 .72327 L F
.971 .85 .664 r
.67981 .72307 m .67792 .72457 L .67715 .72183 L F
.68024 .72327 m .68012 .72334 L .67981 .72307 L F
.553 .644 .894 r
.67945 .72352 m .67997 .72321 L .68022 .72342 L F
.971 .85 .664 r
.68012 .72334 m .67792 .72457 L .67981 .72307 L F
.68012 .72334 m .67887 .72563 L .67792 .72457 L F
.68024 .72327 m .68015 .72343 L .68012 .72334 L F
.68015 .72343 m .67887 .72563 L .68012 .72334 L F
.553 .644 .894 r
.68022 .72342 m .68012 .72333 L .68027 .72341 L F
.68012 .72333 m .67998 .7232 L .68011 .7233 L F
.68012 .72333 m .68011 .7233 L .68027 .72341 L F
.67997 .72321 m .67998 .7232 L .68022 .72342 L F
.67945 .72352 m .68027 .72341 L .68068 .72372 L F
.67998 .7232 m .68147 .72231 L .68068 .72372 L F
.858 .449 .259 r
.67841 .72105 m .68024 .72327 L .67981 .72307 L F
.6777 .72149 m .67981 .72307 L .67715 .72183 L F
.67841 .72105 m .67981 .72307 L .6777 .72149 L F
.553 .644 .894 r
.67945 .72352 m .68147 .72231 L .68099 .72378 L F
.867 .764 .748 r
.68147 .72231 m .68275 .71963 L .6806 .71966 L F
.68147 .72231 m .6806 .71966 L .68005 .72206 L F
.241 .501 .901 r
.68126 .72122 m .68266 .72305 L .68005 .72206 L F
.68266 .72305 m .68284 .72329 L .68272 .72324 L F
.68266 .72305 m .68272 .72324 L .68005 .72206 L F
.66 .813 .957 r
.3905 .75163 m .39419 .75189 L .3928 .74927 L F
.594 .414 .607 r
.392 .75496 m .39414 .75483 L .39419 .75189 L F
.615 .601 .813 r
.39419 .75189 m .39594 .75021 L .3928 .74927 L F
.39419 .75189 m .39643 .75153 L .39594 .75021 L F
.597 .422 .616 r
.39414 .75483 m .39643 .75153 L .39419 .75189 L F
.327 .321 .7 r
.58914 .83145 m .59013 .83191 L .58987 .83214 L F
.58914 .83145 m .58987 .83214 L .59082 .83051 L F
.796 .715 .776 r
.58085 .83523 m .58155 .83786 L .57983 .83913 L F
.729 .677 .799 r
.58418 .83561 m .58155 .83786 L .58085 .83523 L F
.747 .701 .808 r
.51756 .84135 m .5141 .84126 L .51666 .83965 L F
.667 .576 .743 r
.51753 .84377 m .5141 .84126 L .51756 .84135 L F
.69 .489 .61 r
.51977 .84349 m .51756 .84135 L .52018 .84143 L F
.51977 .84349 m .51753 .84377 L .51756 .84135 L F
.665 .521 .678 r
.5229 .84161 m .51977 .84349 L .52018 .84143 L F
0 0 0 r
.59272 .82789 m .59082 .83051 L .59238 .8276 L F
.197 .678 .931 r
.5082 .87957 m .50943 .8801 L .51156 .88022 L F
.929 .702 .574 r
.56347 .78184 m .55956 .78186 L .56304 .78111 L F
.6 .827 .986 r
.41381 .89029 m .41612 .89053 L .41502 .89045 L F
.401 .856 .852 r
.41612 .89053 m .41698 .88991 L .41502 .89045 L F
.41612 .89053 m .41822 .88981 L .41698 .88991 L F
.661 .47 .615 r
.37435 .862 m .37714 .8622 L .37726 .85974 L F
.68 .478 .606 r
.37714 .8622 m .37949 .85964 L .37726 .85974 L F
.51 .53 .813 r
.44051 .86955 m .44173 .87262 L .43965 .87214 L F
.549 .365 .585 r
.59983 .7445 m .60231 .74464 L .60194 .74185 L F
.55 .392 .619 r
.59983 .7445 m .60036 .74689 L .60231 .74464 L F
.691 .49 .611 r
.4165 .83065 m .41893 .83078 L .4195 .82831 L F
.544 .348 .565 r
.4195 .82831 m .42108 .83032 L .42077 .82756 L F
.4195 .82831 m .41893 .83078 L .42108 .83032 L F
.747 .756 .86 r
.69738 .71636 m .6968 .71793 L .69495 .71827 L F
.728 .734 .856 r
.69925 .7153 m .6968 .71793 L .69738 .71636 L F
.221 0 0 r
.50126 .81969 m .49776 .81986 L .49907 .81956 L F
.092 0 0 r
.52586 .82562 m .52628 .82559 L .52709 .82587 L F
.1 0 0 r
.52628 .82559 m .52667 .82612 L .52676 .82554 L F
.52628 .82559 m .52703 .82378 L .52771 .82423 L F
.52628 .82559 m .52676 .82554 L .52703 .82378 L F
.092 0 0 r
.52492 .82544 m .52628 .82559 L .52586 .82562 L F
.52492 .82544 m .52253 .82692 L .52628 .82559 L F
.745 .863 .934 r
.63246 .73612 m .63629 .73512 L .6353 .73406 L F
.717 .846 .943 r
.6353 .73406 m .63629 .73512 L .63847 .73432 L F
.427 0 0 r
.47407 .88349 m .47751 .88286 L .47609 .88402 L F
.538 .05 .045 r
.47609 .88402 m .47751 .88286 L .47922 .8834 L F
.695 .39 .455 r
.5133 .84941 m .51325 .85123 L .51125 .8492 L F
.587 .289 .43 r
.51518 .84926 m .51325 .85123 L .5133 .84941 L F
.513 .093 .181 r
.51125 .8492 m .51019 .85053 L .50785 .84989 L F
.053 .587 .859 r
.51325 .85123 m .51019 .85053 L .51125 .8492 L F
.572 .383 .586 r
.38566 .76282 m .38778 .76262 L .38791 .76016 L F
.53 .348 .578 r
.38791 .76016 m .38982 .7622 L .38938 .75979 L F
.38791 .76016 m .38778 .76262 L .38982 .7622 L F
0 .316 .755 r
.68484 .74055 m .68356 .74014 L .68256 .74029 L F
.68484 .74055 m .68565 .74128 L .68356 .74014 L F
.91 .686 .586 r
.56498 .78449 m .5635 .78481 L .56347 .78184 L F
.884 .934 .847 r
.56608 .78238 m .56498 .78449 L .56711 .78353 L F
.56608 .78238 m .5635 .78481 L .56498 .78449 L F
.691 .249 .197 r
.56498 .78449 m .56402 .78571 L .56743 .78587 L F
.596 .444 .645 r
.56498 .78449 m .56743 .78587 L .56711 .78353 L F
.817 .93 .908 r
.45041 .87209 m .44796 .87409 L .44696 .87368 L F
.85 .398 .002 r
.44963 .86458 m .44921 .86455 L .44808 .86262 L F
.848 .448 .286 r
.45147 .86572 m .44921 .86455 L .44963 .86458 L F
.755 .74 .838 r
.63507 .72065 m .63601 .72327 L .63279 .72303 L F
.785 .755 .825 r
.63816 .72084 m .63601 .72327 L .63507 .72065 L F
.59 .763 .962 r
.49878 .88277 m .50211 .88339 L .50062 .88234 L F
.775 .789 .864 r
.50062 .88234 m .50211 .88339 L .50325 .88201 L F
.57 .34 .527 r
.36646 .77577 m .36858 .77552 L .36895 .77336 L F
.573 .359 .553 r
.36858 .77552 m .37076 .77283 L .36895 .77336 L F
.198 0 .332 r
.6195 .80134 m .61803 .80218 L .61989 .79939 L F
.205 0 .345 r
.61752 .80417 m .61803 .80218 L .6195 .80134 L F
.593 .581 .809 r
.70249 .71775 m .70373 .72129 L .70209 .719 L F
.926 .593 .389 r
.70209 .719 m .70373 .72129 L .70358 .72352 L F
.61 .562 .775 r
.70528 .71742 m .70373 .72129 L .70249 .71775 L F
.70528 .71742 m .70638 .72071 L .70373 .72129 L F
.535 .299 .504 r
.70373 .72129 m .70607 .72265 L .70358 .72352 L F
.70373 .72129 m .70638 .72071 L .70607 .72265 L F
.321 0 .021 r
.53744 .83271 m .53536 .8335 L .53437 .83307 L F
.407 .019 .187 r
.53536 .8335 m .53337 .83489 L .53437 .83307 L F
.68 .478 .606 r
.37714 .8622 m .37947 .86197 L .37949 .85964 L F
.645 .496 .666 r
.37949 .85964 m .38178 .8596 L .3816 .85695 L F
.637 .429 .584 r
.38156 .86171 m .37949 .85964 L .37947 .86197 L F
.38156 .86171 m .38178 .8596 L .37949 .85964 L F
.598 .162 .184 r
.58521 .76694 m .58726 .76732 L .58519 .76604 L F
.71 .69 .829 r
.47796 .84923 m .48138 .84985 L .47995 .8483 L F
.433 .599 .914 r
.47995 .8483 m .48138 .84985 L .48206 .84845 L F
.339 .483 .857 r
.48138 .84985 m .48325 .85085 L .48206 .84845 L F
0 0 0 r
.35059 .72781 m .35147 .72746 L .35309 .72573 L F
.35059 .72781 m .34957 .72839 L .35147 .72746 L F
.803 .712 .764 r
.67866 .7178 m .67841 .72105 L .67663 .71967 L F
.67866 .7178 m .67869 .71885 L .67841 .72105 L F
.858 .449 .259 r
.67841 .72105 m .67715 .72183 L .67663 .71967 L F
.717 .678 .811 r
.6799 .7169 m .67841 .72105 L .67869 .71885 L F
.6799 .7169 m .68112 .71848 L .67841 .72105 L F
.501 .215 .411 r
.38308 .76487 m .38509 .76458 L .38566 .76282 L F
.351 0 .215 r
.38509 .76458 m .38778 .76262 L .38566 .76282 L F
.559 .598 .848 r
.44554 .85908 m .44335 .85988 L .44386 .85885 L F
0 0 .427 r
.56432 .84048 m .56393 .84115 L .56492 .84392 L F
.384 .134 .407 r
.36012 .79656 m .35984 .79849 L .35796 .79932 L F
.466 .24 .486 r
.36243 .79414 m .36159 .79623 L .36012 .79656 L F
.443 .183 .424 r
.36159 .79623 m .35984 .79849 L .36012 .79656 L F
.314 0 .182 r
.57532 .77045 m .57652 .77178 L .57739 .76991 L F
.57532 .77045 m .57452 .77247 L .57652 .77178 L F
.57 .446 .672 r
.45636 .8464 m .45623 .84876 L .45533 .8464 L F
.45636 .8464 m .45833 .84885 L .45623 .84876 L F
.7 .472 .574 r
.60194 .74185 m .60231 .74464 L .60422 .74392 L F
.309 .779 .935 r
.3421 .72918 m .34411 .72897 L .34555 .72927 L F
.339 .792 .949 r
.34411 .72897 m .34764 .72902 L .34555 .72927 L F
.467 .114 .283 r
.51806 .81418 m .52109 .81191 L .51958 .81296 L F
.502 .115 .239 r
.46148 .82781 m .46366 .8277 L .4648 .82582 L F
.539 .155 .261 r
.4648 .82582 m .46366 .8277 L .46671 .82687 L F
.482 .371 .651 r
.68232 .75145 m .67958 .74904 L .6806 .74802 L F
0 0 0 r
.6806 .74802 m .6831 .74634 L .68383 .74852 L F
.319 .232 .598 r
.68356 .7507 m .6806 .74802 L .68383 .74852 L F
.68356 .7507 m .68232 .75145 L .6806 .74802 L F
0 0 0 r
.62316 .74769 m .62299 .74748 L .62338 .74612 L F
.62316 .74769 m .62228 .75004 L .62299 .74748 L F
.816 .778 .817 r
.536 .86727 m .53882 .86661 L .53802 .86584 L F
.834 .551 .509 r
.55842 .79253 m .56078 .79585 L .55915 .79397 L F
.555 .914 .726 r
.64395 .77282 m .64515 .77168 L .64322 .77271 L F
.64395 .77282 m .64661 .77095 L .64515 .77168 L F
.561 .31 .492 r
.37334 .77034 m .37551 .77007 L .37594 .76797 L F
.581 .327 .497 r
.37551 .77007 m .37776 .76985 L .37594 .76797 L F
.612 .326 .458 r
.37594 .76797 m .37776 .76985 L .37822 .76792 L F
.854 .822 .816 r
.60967 .75227 m .60742 .75248 L .60874 .75146 L F
.60967 .75227 m .60748 .75491 L .60742 .75248 L F
0 0 0 r
.60874 .75146 m .60757 .75305 L .60804 .75246 L F
.98 .688 .332 r
.60917 .75083 m .60967 .75227 L .60874 .75146 L F
.492 .804 1 r
.60967 .75227 m .61174 .7519 L .60874 .75146 L F
.60967 .75227 m .61174 .7519 L .60874 .75146 L F
0 0 0 r
.60874 .75146 m .60804 .75246 L .60959 .75052 L F
.98 .688 .332 r
.60885 .74992 m .60917 .75083 L .60874 .75146 L F
.488 .846 .993 r
.46815 .8481 m .46718 .84906 L .46931 .84865 L F
.46815 .8481 m .46599 .8486 L .46718 .84906 L F
.889 .968 .649 r
.59463 .82437 m .59238 .8276 L .59472 .82542 L F
.27 .118 .483 r
.59521 .82317 m .59463 .82437 L .59642 .82386 L F
.142 0 .126 r
.59642 .82386 m .59463 .82437 L .59472 .82542 L F
.644 .503 .677 r
.3816 .85695 m .38394 .8567 L .38365 .8543 L F
.645 .497 .668 r
.38178 .8596 m .38394 .8567 L .3816 .85695 L F
0 0 0 r
.61177 .76389 m .60971 .76538 L .61222 .76328 L F
.042 0 0 r
.61407 .76249 m .61177 .76389 L .61222 .76328 L F
.499 .064 .144 r
.35309 .72573 m .35478 .72626 L .35376 .72661 L F
.576 .928 .949 r
.63674 .76657 m .63872 .7653 L .6398 .7656 L F
.621 .945 .946 r
.6398 .7656 m .64092 .76436 L .64199 .7651 L F
.6398 .7656 m .63872 .7653 L .64092 .76436 L F
.524 .396 .648 r
.43397 .86255 m .43228 .86065 L .43419 .85949 L F
.43397 .86255 m .43179 .86312 L .43228 .86065 L F
.757 .995 .827 r
.6296 .73801 m .62885 .73945 L .63118 .73724 L F
0 0 0 r
.6296 .73801 m .62811 .74105 L .62885 .73945 L F
.768 .259 0 r
.55048 .80444 m .5494 .80399 L .5477 .8019 L F
.69 .145 0 r
.55048 .80444 m .55137 .80599 L .5494 .80399 L F
.55048 .80444 m .55277 .8065 L .55137 .80599 L F
.941 .714 .566 r
.57046 .78387 m .57098 .78629 L .56911 .78548 L F
.776 .683 .76 r
.57098 .78629 m .56853 .78704 L .56743 .78587 L F
0 0 .253 r
.57122 .78685 m .57098 .78629 L .57273 .78593 L F
.572 .181 .263 r
.57046 .78387 m .56911 .78548 L .56955 .78449 L F
.892 .88 .816 r
.62869 .77191 m .6298 .77261 L .62774 .77321 L F
.838 .893 .879 r
.63229 .77018 m .6298 .77261 L .62869 .77191 L F
.593 .385 .568 r
.47618 .8518 m .47591 .85412 L .47366 .85431 L F
.595 .814 .416 r
.47681 .85086 m .47668 .85108 L .47796 .84923 L F
0 0 0 r
.47883 .84906 m .47681 .85086 L .47796 .84923 L F
.851 .936 .88 r
.4763 .84974 m .47681 .85086 L .47883 .84906 L F
0 0 .406 r
.47693 .85066 m .47681 .85086 L .4763 .84974 L F
.47773 .85184 m .47681 .85086 L .47693 .85066 L F
.595 .814 .416 r
.47681 .85086 m .47618 .8518 L .47668 .85108 L F
0 0 .225 r
.47678 .85301 m .47618 .8518 L .47681 .85086 L F
.47678 .85301 m .47591 .85412 L .47618 .8518 L F
.424 .866 .9 r
.5907 .84699 m .59474 .84647 L .59403 .84693 L F
0 0 0 r
.59619 .84625 m .59474 .84647 L .59653 .84573 L F
.59403 .84693 m .59474 .84647 L .59619 .84625 L F
.629 .901 .985 r
.43864 .88572 m .43993 .88615 L .44191 .88534 L F
.574 .359 .551 r
.41166 .75756 m .41166 .75994 L .40925 .76024 L F
.558 .415 .642 r
.41358 .75464 m .4138 .75752 L .41166 .75756 L F
.439 .252 .53 r
.41328 .75932 m .41166 .75756 L .4138 .75752 L F
.41328 .75932 m .41166 .75994 L .41166 .75756 L F
0 0 .312 r
.5571 .78094 m .55757 .78035 L .55776 .7785 L F
0 .014 .557 r
.5571 .78094 m .55797 .7827 L .55757 .78035 L F
.59 .022 0 r
.50702 .87596 m .50818 .87573 L .50663 .87553 L F
.337 .815 .771 r
.51043 .87489 m .50818 .87573 L .50702 .87596 L F
.744 .542 .621 r
.61454 .7395 m .61775 .74157 L .6175 .73925 L F
.545 .445 .691 r
.61775 .74157 m .6192 .73844 L .6175 .73925 L F
.657 .281 .321 r
.39077 .7558 m .39414 .75483 L .392 .75496 L F
0 0 .033 r
.49889 .84774 m .49885 .84865 L .49924 .84657 L F
.503 .368 .63 r
.49924 .84657 m .50137 .84777 L .50261 .84504 L F
.666 .515 .67 r
.39097 .84918 m .39323 .84901 L .39312 .84662 L F
.646 .483 .648 r
.39323 .84901 m .39542 .84635 L .39312 .84662 L F
.745 .854 .93 r
.3779 .72816 m .3742 .7282 L .37592 .72685 L F
.3779 .72816 m .37557 .72899 L .3742 .7282 L F
.675 .825 .956 r
.37976 .72695 m .3779 .72816 L .37592 .72685 L F
.682 .616 .776 r
.38083 .72873 m .3779 .72816 L .37976 .72695 L F
.591 .404 .597 r
.61827 .75488 m .61861 .75735 L .61627 .75746 L F
.562 .294 .466 r
.62087 .75396 m .62102 .75488 L .61827 .75488 L F
.301 .202 .572 r
.61968 .75675 m .61827 .75488 L .62102 .75488 L F
.61968 .75675 m .61861 .75735 L .61827 .75488 L F
.45 .224 .478 r
.36276 .79558 m .36243 .79414 L .36443 .79356 L F
.36276 .79558 m .36159 .79623 L .36243 .79414 L F
.71 .811 .928 r
.49037 .88431 m .49121 .88532 L .4937 .88389 L F
.541 .452 .704 r
.43397 .86255 m .43417 .86435 L .43179 .86312 L F
.242 .757 .786 r
.58608 .84839 m .58726 .84823 L .58902 .84779 L F
.647 .466 .625 r
.38872 .85191 m .39098 .85158 L .39097 .84918 L F
.659 .476 .626 r
.39098 .85158 m .39323 .84901 L .39097 .84918 L F
.826 .439 .319 r
.5494 .80399 m .54604 .80139 L .5477 .8019 L F
.674 .939 .659 r
.49736 .86933 m .49916 .86784 L .49756 .86699 L F
.482 .325 .591 r
.61177 .76389 m .61167 .76705 L .60971 .76538 L F
.419 .327 .645 r
.61167 .76705 m .61016 .76781 L .60971 .76538 L F
.404 .788 .991 r
.46534 .86517 m .46201 .86483 L .46407 .8647 L F
.543 .905 .964 r
.46623 .86424 m .46774 .86447 L .46534 .86517 L F
.5 .842 .997 r
.46623 .86424 m .46534 .86517 L .46407 .8647 L F
0 .214 .706 r
.46824 .86766 m .46534 .86517 L .46774 .86447 L F
.522 .763 .985 r
.41091 .7508 m .41015 .75242 L .40878 .75132 L F
.41091 .7508 m .41205 .75243 L .41015 .75242 L F
.804 .626 .661 r
.54271 .83301 m .53853 .83073 L .54096 .83099 L F
.54271 .83301 m .53893 .83299 L .53853 .83073 L F
.8 .72 .777 r
.54271 .83301 m .54012 .83467 L .53893 .83299 L F
0 0 0 r
.54308 .83377 m .54012 .83467 L .54271 .83301 L F
.67 .788 .937 r
.54462 .83151 m .54271 .83301 L .54096 .83099 L F
.686 .558 .705 r
.54471 .83231 m .54271 .83301 L .54462 .83151 L F
.54471 .83231 m .54308 .83377 L .54271 .83301 L F
.637 .964 .89 r
.39515 .89618 m .39758 .89519 L .39671 .89457 L F
.262 .69 .965 r
.39758 .89519 m .39867 .89472 L .39671 .89457 L F
.39758 .89519 m .40026 .89535 L .39867 .89472 L F
.611 .23 .296 r
.49711 .87656 m .49501 .87757 L .496 .87654 L F
.527 .899 .963 r
.49891 .87539 m .49711 .87656 L .496 .87654 L F
.49891 .87539 m .49984 .87565 L .49711 .87656 L F
0 .067 .585 r
.4691 .86644 m .46824 .86766 L .46774 .86447 L F
.123 .255 .729 r
.47038 .87018 m .46949 .87007 L .46824 .86766 L F
.795 .338 .156 r
.46899 .87005 m .47038 .87018 L .46824 .86766 L F
.46899 .87005 m .46824 .86766 L .4691 .86644 L F
.637 .776 .947 r
.61575 .73446 m .61711 .73683 L .6136 .73623 L F
.32 .345 .731 r
.61595 .73816 m .6136 .73623 L .61711 .73683 L F
.494 .496 .787 r
.61794 .7331 m .61711 .73683 L .61575 .73446 L F
.948 .935 .747 r
.61734 .78297 m .61681 .78277 L .61889 .7814 L F
.741 .982 .755 r
.61889 .7814 m .61963 .77998 L .6204 .78024 L F
.61889 .7814 m .61681 .78277 L .61963 .77998 L F
.712 .514 .62 r
.6026 .77054 m .60283 .77302 L .60031 .77302 L F
.598 .43 .625 r
.60573 .77248 m .6026 .77054 L .60615 .77032 L F
.60573 .77248 m .60283 .77302 L .6026 .77054 L F
.626 .486 .672 r
.52678 .83833 m .52374 .83966 L .52475 .83854 L F
.653 .509 .675 r
.37239 .86483 m .37501 .86493 L .37435 .862 L F
.674 .549 .704 r
.37456 .8673 m .37239 .86483 L .37258 .86729 L F
.37456 .8673 m .37501 .86493 L .37239 .86483 L F
.479 .237 .468 r
.38348 .77836 m .38318 .78041 L .38113 .78078 L F
.537 .287 .484 r
.38518 .78007 m .38348 .77836 L .38549 .77804 L F
.38518 .78007 m .38318 .78041 L .38348 .77836 L F
.591 .617 .847 r
.56167 .78642 m .56333 .7895 L .56471 .78783 L F
.599 .453 .655 r
.56319 .79042 m .56471 .78783 L .56333 .7895 L F
.886 .892 .83 r
.53218 .82274 m .52893 .82487 L .53105 .82227 L F
.53218 .82274 m .53004 .82543 L .52893 .82487 L F
.209 0 .256 r
.61989 .79939 m .62212 .79684 L .62184 .79891 L F
.241 .01 .35 r
.6195 .80134 m .61989 .79939 L .62184 .79891 L F
.711 .582 .709 r
.39943 .83874 m .40161 .83598 L .39857 .83636 L F
.614 .446 .631 r
.39943 .83874 m .40161 .83836 L .40161 .83598 L F
.642 .427 .577 r
.40161 .83836 m .40391 .83601 L .40161 .83598 L F
.603 .372 .539 r
.40921 .83584 m .41132 .83572 L .41201 .83317 L F
.638 .482 .656 r
.41201 .83317 m .41424 .83318 L .4144 .83106 L F
.635 .404 .55 r
.41201 .83317 m .4142 .83542 L .41424 .83318 L F
.41201 .83317 m .41132 .83572 L .4142 .83542 L F
.825 .846 .864 r
.54471 .83231 m .54185 .83475 L .54308 .83377 L F
.764 .663 .75 r
.45623 .84876 m .45335 .84884 L .45533 .8464 L F
.718 .494 .585 r
.4569 .84941 m .45335 .84884 L .45623 .84876 L F
.601 .436 .631 r
.45833 .84885 m .4569 .84941 L .45623 .84876 L F
.474 .185 .394 r
.39765 .76822 m .39709 .77002 L .3951 .77035 L F
.469 .181 .392 r
.39914 .7696 m .39765 .76822 L .39962 .7678 L F
.39914 .7696 m .39709 .77002 L .39765 .76822 L F
.258 .531 .917 r
.50785 .84989 m .50877 .84884 L .50704 .84967 L F
.50785 .84989 m .51019 .85053 L .50877 .84884 L F
.845 .841 .84 r
.6073 .7418 m .60422 .74392 L .60591 .74351 L F
.699 .597 .739 r
.60935 .73923 m .61072 .74229 L .6073 .7418 L F
0 0 0 r
.60935 .73923 m .6073 .7418 L .60838 .74074 L F
.2 0 .159 r
.6073 .7418 m .60849 .74152 L .60838 .74074 L F
.6073 .7418 m .60591 .74351 L .60849 .74152 L F
0 0 0 r
.6213 .77887 m .6204 .78024 L .62251 .77784 L F
.442 0 0 r
.69173 .71831 m .69495 .71827 L .69399 .71869 L F
.983 .857 .638 r
.69485 .71869 m .6943 .7209 L .69399 .71869 L F
.332 .416 .798 r
.69399 .71869 m .6943 .7209 L .69609 .71946 L F
.377 0 0 r
.69234 .71869 m .69399 .71869 L .69609 .71946 L F
.69156 .71853 m .69399 .71869 L .69234 .71869 L F
.983 .857 .638 r
.69495 .71827 m .69485 .71869 L .69399 .71869 L F
.633 .516 .703 r
.39972 .84115 m .40161 .83836 L .39943 .83874 L F
.874 .749 .722 r
.68485 .73589 m .68733 .73598 L .68579 .73897 L F
.555 .283 .459 r
.59286 .76523 m .59511 .76508 L .59566 .76258 L F
.707 .429 .501 r
.59566 .76258 m .59799 .76486 L .59769 .76242 L F
.59566 .76258 m .59511 .76508 L .59799 .76486 L F
.803 .713 .766 r
.53004 .82543 m .52709 .82587 L .52893 .82487 L F
.53004 .82543 m .5279 .82866 L .52709 .82587 L F
.448 .793 .998 r
.44378 .87236 m .44487 .87307 L .44173 .87262 L F
.71 .613 .746 r
.44416 .86964 m .44487 .87307 L .44756 .87051 L F
.438 .489 .814 r
.44587 .87111 m .44487 .87307 L .44378 .87236 L F
.44587 .87111 m .44696 .87368 L .44487 .87307 L F
.575 .69 .919 r
.38324 .72753 m .38083 .72873 L .37976 .72695 L F
.38324 .72753 m .3828 .72836 L .38083 .72873 L F
.796 .715 .776 r
.58085 .83523 m .57983 .83913 L .57845 .8379 L F
.717 .846 .943 r
.6353 .73406 m .63847 .73432 L .63704 .73319 L F
.632 .779 .951 r
.63704 .73319 m .63847 .73432 L .64046 .73356 L F
.554 .2 .322 r
.5279 .82866 m .5277 .83037 L .52488 .83042 L F
.49 0 0 r
.5279 .82866 m .52899 .82963 L .5277 .83037 L F
.5279 .82866 m .53037 .83045 L .52899 .82963 L F
.668 .276 0 r
.56171 .82161 m .5624 .82282 L .56351 .825 L F
.642 .427 .577 r
.40161 .83836 m .40398 .83819 L .40391 .83601 L F
.661 .433 .563 r
.40674 .83838 m .40391 .83601 L .40398 .83819 L F
.40674 .83838 m .4069 .83587 L .40391 .83601 L F
.682 .152 0 r
.53137 .8068 m .53289 .80771 L .53416 .80764 L F
0 .243 .753 r
.53561 .80814 m .53416 .80764 L .53289 .80771 L F
.53561 .80814 m .53621 .8092 L .53416 .80764 L F
.532 .483 .747 r
.44189 .85346 m .44144 .85705 L .44038 .85408 L F
.373 0 .114 r
.34999 .75234 m .34778 .75226 L .34929 .75211 L F
.34999 .75234 m .34684 .75414 L .34778 .75226 L F
.622 .246 .309 r
.36083 .74981 m .35952 .7519 L .35731 .75132 L F
.32 0 .056 r
.36287 .7497 m .35952 .7519 L .36083 .74981 L F
.435 .076 .255 r
.37672 .78429 m .37594 .7856 L .37393 .78592 L F
.412 .053 .242 r
.37797 .78523 m .37672 .78429 L .37861 .78373 L F
.37797 .78523 m .37594 .7856 L .37672 .78429 L F
0 0 0 r
.51937 .83265 m .51857 .83502 L .52021 .83314 L F
.51937 .83265 m .5188 .8349 L .51857 .83502 L F
.5188 .8349 m .51775 .83596 L .51857 .83502 L F
.641 .779 .947 r
.39092 .73637 m .38723 .73584 L .38953 .73504 L F
.364 .515 .875 r
.39144 .73476 m .39092 .73637 L .38953 .73504 L F
.39144 .73476 m .39251 .73661 L .39092 .73637 L F
.597 .554 .777 r
.39383 .73908 m .39092 .73637 L .39251 .73661 L F
.408 0 0 r
.4687 .88293 m .47215 .88295 L .47065 .88327 L F
.419 0 0 r
.47215 .88295 m .47262 .88352 L .47065 .88327 L F
.47215 .88295 m .47407 .88349 L .47262 .88352 L F
.791 .348 0 r
.56166 .81912 m .56028 .81695 L .56118 .81769 L F
.534 .906 .73 r
.64776 .7699 m .64661 .77095 L .64816 .76982 L F
.531 .902 .718 r
.64515 .77168 m .64661 .77095 L .64776 .7699 L F
.607 .526 .737 r
.68308 .71402 m .68438 .70949 L .68198 .71018 L F
.68308 .71402 m .68519 .71326 L .68438 .70949 L F
0 0 .06 r
.62361 .79586 m .62212 .79684 L .62401 .79402 L F
0 0 .172 r
.62184 .79891 m .62212 .79684 L .62361 .79586 L F
.695 .836 .951 r
.43323 .88573 m .43471 .8867 L .43652 .88583 L F
.71 .879 .96 r
.57042 .84924 m .57336 .84868 L .57218 .84799 L F
.48 .8 1 r
.57336 .84868 m .57468 .84767 L .57218 .84799 L F
.57336 .84868 m .57553 .8484 L .57468 .84767 L F
.625 .504 .695 r
.43315 .86992 m .43093 .87192 L .4311 .8705 L F
.551 .4 .63 r
.40551 .74418 m .40352 .74687 L .40338 .7446 L F
0 .499 .847 r
.38056 .89884 m .37864 .89881 L .37919 .89861 L F
.38056 .89884 m .38058 .89844 L .37864 .89881 L F
.38056 .89884 m .3822 .89929 L .38058 .89844 L F
.881 .991 .75 r
.62609 .73019 m .62496 .73196 L .62538 .73022 L F
.333 0 .145 r
.62338 .73326 m .62538 .73022 L .62496 .73196 L F
.674 .533 .684 r
.37501 .86493 m .37714 .8622 L .37435 .862 L F
.756 .568 .642 r
.667 .7156 m .6638 .71303 L .66618 .71245 L F
.667 .7156 m .66374 .71549 L .6638 .71303 L F
.884 .644 .57 r
.667 .7156 m .66542 .7176 L .66374 .71549 L F
.667 .7156 m .66707 .71826 L .66542 .7176 L F
.374 .363 .719 r
.66903 .71447 m .667 .7156 L .66618 .71245 L F
.66903 .71447 m .66824 .71586 L .667 .7156 L F
.307 .447 .838 r
.66824 .71586 m .66981 .71759 L .667 .7156 L F
.551 .336 .542 r
.36209 .78079 m .36416 .78058 L .36438 .77842 L F
.562 .346 .544 r
.36416 .78058 m .36626 .78036 L .36438 .77842 L F
.541 .358 .582 r
.36438 .77842 m .36638 .77808 L .36646 .77577 L F
.537 .345 .568 r
.36438 .77842 m .36626 .78036 L .36638 .77808 L F
.505 .051 .107 r
.46671 .82687 m .46876 .82709 L .47013 .8256 L F
.421 0 .086 r
.46876 .82709 m .47223 .82535 L .47013 .8256 L F
.909 .636 .512 r
.56375 .82816 m .56228 .83008 L .56331 .82758 L F
.56375 .82816 m .56387 .83032 L .56228 .83008 L F
.774 .891 .928 r
.68116 .75195 m .68006 .75349 L .67812 .75477 L F
.669 .791 .939 r
.39105 .89941 m .39265 .89848 L .38936 .89817 L F
.824 .851 .868 r
.63556 .76458 m .63674 .76657 L .63448 .76775 L F
.519 .623 .894 r
.63772 .76388 m .63872 .7653 L .63674 .76657 L F
.653 .569 .748 r
.59521 .82317 m .59663 .82196 L .59667 .81994 L F
.27 .118 .483 r
.59521 .82317 m .59642 .82386 L .59663 .82196 L F
.461 .131 .319 r
.51892 .87981 m .52281 .87617 L .52094 .87946 L F
.685 .274 .261 r
.52281 .87617 m .52281 .87881 L .52094 .87946 L F
.52281 .87617 m .52483 .87728 L .52281 .87881 L F
.654 .507 .671 r
.38394 .8567 m .38587 .85396 L .38365 .8543 L F
.459 .563 .874 r
.69505 .71186 m .69355 .71335 L .69319 .71186 L F
.439 .531 .854 r
.69505 .71186 m .69671 .71556 L .69355 .71335 L F
.853 .78 .779 r
.47882 .86149 m .47684 .86433 L .47786 .86205 L F
.47882 .86149 m .47885 .86455 L .47684 .86433 L F
.816 .398 .251 r
.47885 .86455 m .48059 .86778 L .48044 .86764 L F
.48044 .86764 m .48059 .86778 L .48056 .86787 L F
0 0 .434 r
.47885 .86455 m .48056 .86787 L .48044 .86745 L F
.47885 .86455 m .48044 .86745 L .47684 .86433 L F
0 .207 .725 r
.47688 .86421 m .48044 .86745 L .4771 .86366 L F
.47684 .86433 m .47847 .86574 L .47688 .86421 L F
.47847 .86574 m .48044 .86745 L .47688 .86421 L F
.816 .398 .251 r
.47885 .86455 m .48135 .86525 L .48059 .86778 L F
.591 .156 .183 r
.48056 .86787 m .48135 .86525 L .48386 .86657 L F
.844 .472 0 r
.67172 .72335 m .67138 .72355 L .67033 .72045 L F
0 0 0 r
.66833 .72483 m .67172 .72335 L .66948 .72604 L F
0 0 .244 r
.67055 .72391 m .67128 .72707 L .67095 .72457 L F
0 0 0 r
.66833 .72483 m .67078 .7238 L .67131 .72353 L F
.67078 .7238 m .67138 .72355 L .67131 .72353 L F
.649 .839 .973 r
.67077 .72244 m .67138 .72355 L .66833 .72483 L F
.67091 .72231 m .66833 .72483 L .66732 .72397 L F
.514 .913 .897 r
.67091 .72231 m .66732 .72397 L .66628 .72395 L F
.66997 .72238 m .66628 .72395 L .66794 .72255 L F
.67091 .72231 m .67006 .72261 L .66997 .72238 L F
.67006 .72261 m .66628 .72395 L .66997 .72238 L F
0 0 .244 r
.67027 .72345 m .67042 .72398 L .67055 .72391 L F
.67042 .72398 m .67128 .72707 L .67055 .72391 L F
.14 .323 .786 r
.67033 .72045 m .67266 .72246 L .67172 .72335 L F
.874 .897 .846 r
.67095 .72261 m .67266 .72246 L .67164 .72176 L F
.649 .839 .973 r
.67095 .72261 m .6711 .72282 L .67096 .72265 L F
.67109 .72278 m .6711 .72282 L .67095 .72261 L F
.6711 .72282 m .67138 .72355 L .67077 .72244 L F
.874 .897 .846 r
.67027 .72345 m .67128 .72303 L .67095 .72261 L F
.67128 .72303 m .67266 .72246 L .67095 .72261 L F
.649 .839 .973 r
.67093 .72237 m .67109 .72278 L .67095 .72261 L F
.901 .666 .574 r
.67095 .72261 m .67009 .72241 L .67027 .72345 L F
.67164 .72176 m .67091 .72207 L .67095 .72261 L F
.649 .839 .973 r
.67091 .72231 m .67093 .72237 L .67077 .72244 L F
.67093 .72237 m .67096 .72265 L .67077 .72244 L F
.901 .666 .574 r
.67093 .72237 m .67009 .72241 L .67095 .72261 L F
.764 .42 0 r
.67033 .72045 m .67138 .72355 L .67019 .72011 L F
.697 .378 0 r
.67033 .72045 m .67132 .72335 L .67091 .72231 L F
.901 .666 .574 r
.67091 .72207 m .67083 .7221 L .67093 .72237 L F
.487 .088 .208 r
.67019 .72011 m .67091 .72231 L .66794 .72255 L F
.901 .666 .574 r
.67083 .7221 m .67009 .72241 L .67093 .72237 L F
.874 .897 .846 r
.6712 .72306 m .67176 .72357 L .67128 .72303 L F
.67027 .72345 m .67137 .72354 L .6712 .72306 L F
.697 .378 0 r
.67132 .72335 m .67138 .72355 L .6711 .72282 L F
0 0 0 r
.67131 .72353 m .67138 .72355 L .67172 .72335 L F
.874 .897 .846 r
.67137 .72354 m .67176 .72357 L .6712 .72306 L F
.697 .378 0 r
.67101 .72258 m .6711 .72282 L .67093 .72237 L F
.67132 .72335 m .6711 .72282 L .67101 .72258 L F
.67132 .72335 m .67093 .72237 L .67091 .72231 L F
.901 .666 .574 r
.67164 .72176 m .67037 .72335 L .67009 .72241 L F
0 0 .334 r
.67042 .72356 m .67027 .72345 L .67017 .72288 L F
.874 .897 .846 r
.67027 .72345 m .67095 .72457 L .67176 .72357 L F
0 0 .334 r
.6705 .7238 m .67045 .72372 L .67042 .72356 L F
.67045 .72372 m .67027 .72345 L .67042 .72356 L F
.98 .895 .662 r
.67071 .72215 m .6703 .72303 L .67164 .72176 L F
.901 .666 .574 r
.67037 .72335 m .66981 .72405 L .67009 .72241 L F
0 0 .334 r
.67066 .7241 m .67017 .72288 L .67009 .72241 L F
.98 .895 .662 r
.6703 .72304 m .66981 .72405 L .67037 .72335 L F
.67029 .72303 m .66981 .72405 L .6703 .72304 L F
0 0 .334 r
.67115 .72558 m .67074 .72459 L .6705 .7238 L F
.67074 .72459 m .67027 .72345 L .6705 .7238 L F
.67115 .72558 m .67017 .72288 L .67066 .7241 L F
.67115 .72558 m .67115 .72635 L .67027 .72345 L F
.93 .804 .34 r
.67009 .72241 m .66981 .72405 L .66962 .72249 L F
.974 .926 .632 r
.66962 .72249 m .66981 .72405 L .67029 .72303 L F
.875 .5 .021 r
.66979 .72246 m .67029 .72303 L .67009 .72241 L F
.67029 .72303 m .6703 .72304 L .67009 .72241 L F
.66962 .72249 m .6703 .72304 L .66979 .72246 L F
.974 .926 .632 r
.66962 .72249 m .67029 .72303 L .67071 .72215 L F
.875 .5 .021 r
.67029 .72303 m .6703 .72304 L .6703 .72304 L F
.66962 .72249 m .67115 .72558 L .6703 .72304 L F
.98 .895 .662 r
.6703 .72303 m .67029 .72303 L .6703 .72304 L F
.6703 .72303 m .67037 .72335 L .67164 .72176 L F
.983 .699 .377 r
.67095 .72457 m .67172 .72335 L .67266 .72246 L F
.874 .897 .846 r
.67128 .72303 m .67176 .72357 L .67266 .72246 L F
.983 .699 .377 r
.67095 .72457 m .67192 .72593 L .67172 .72335 L F
.526 .911 .937 r
.3687 .72614 m .36688 .72689 L .36544 .72691 L F
.742 .48 .535 r
.69083 .74074 m .6893 .74327 L .68894 .74138 L F
.69083 .74074 m .69133 .74414 L .6893 .74327 L F
.38 .224 .541 r
.69306 .73856 m .69304 .74117 L .69083 .74074 L F
.698 .617 .762 r
.69304 .74117 m .69133 .74414 L .69083 .74074 L F
.587 .289 .43 r
.51518 .84926 m .51556 .85109 L .51325 .85123 L F
.476 .219 .444 r
.51748 .85079 m .51518 .84926 L .51763 .84869 L F
.51748 .85079 m .51556 .85109 L .51518 .84926 L F
.627 .793 .962 r
.53277 .86937 m .53103 .87113 L .5342 .8704 L F
.413 .254 .554 r
.61807 .7589 m .61627 .75746 L .61861 .75735 L F
.61807 .7589 m .61623 .75975 L .61627 .75746 L F
.654 .343 .434 r
.45373 .82987 m .45705 .82774 L .45412 .8286 L F
.848 .448 .286 r
.45147 .86572 m .44983 .86637 L .44921 .86455 L F
0 0 0 r
.45265 .86525 m .45147 .86572 L .45343 .86539 L F
.45265 .86525 m .44983 .86637 L .45147 .86572 L F
.487 0 0 r
.51156 .88022 m .51482 .88059 L .51393 .88092 L F
.143 0 0 r
.51482 .88059 m .51548 .88096 L .51393 .88092 L F
.51482 .88059 m .51705 .88057 L .51548 .88096 L F
.627 .457 .633 r
.39756 .84376 m .39987 .84343 L .39972 .84115 L F
.633 .516 .703 r
.39972 .84115 m .40253 .84135 L .40161 .83836 L F
.673 .528 .679 r
.39987 .84343 m .40253 .84135 L .39972 .84115 L F
.393 .715 .987 r
.54631 .8314 m .54471 .83231 L .54462 .83151 L F
.54631 .8314 m .54715 .83252 L .54471 .83231 L F
.67 .382 .475 r
.43973 .85887 m .43805 .86128 L .43622 .85957 L F
.698 .417 .495 r
.43973 .85887 m .4415 .86153 L .43805 .86128 L F
.732 .315 .257 r
.44808 .86262 m .44678 .86397 L .44477 .86196 L F
.841 .47 .352 r
.44808 .86262 m .44921 .86455 L .44678 .86397 L F
.24 .753 .857 r
.44111 .8178 m .44335 .81747 L .44343 .81756 L F
.44111 .8178 m .44335 .81747 L .44343 .81756 L F
.409 .032 .208 r
.5293 .81704 m .52812 .8158 L .53023 .81496 L F
.5293 .81704 m .52717 .81756 L .52812 .8158 L F
.903 .694 .61 r
.6638 .71303 m .66125 .71497 L .66144 .71227 L F
.6638 .71303 m .66374 .71549 L .66125 .71497 L F
.554 .368 .584 r
.43613 .86182 m .43419 .85949 L .43622 .85957 L F
.43613 .86182 m .43397 .86255 L .43419 .85949 L F
.055 0 0 r
.48729 .82027 m .48919 .81969 L .49061 .81865 L F
.515 .089 .17 r
.48919 .81969 m .4929 .81825 L .49061 .81865 L F
.205 0 .191 r
.61235 .79589 m .61028 .79642 L .60992 .79817 L F
.895 .709 .642 r
.47247 .85144 m .47366 .85431 L .47213 .85362 L F
.799 .577 .601 r
.47366 .85431 m .47078 .85638 L .47213 .85362 L F
.47366 .85431 m .47362 .85672 L .47078 .85638 L F
.531 .319 .537 r
.47591 .85412 m .47362 .85672 L .47366 .85431 L F
.808 .38 .23 r
.50663 .87553 m .50526 .87363 L .50399 .8744 L F
.897 .681 .17 r
.57114 .83022 m .57134 .83225 L .57131 .82952 L F
.78 .712 .176 r
.57114 .83022 m .57131 .82952 L .57146 .82816 L F
.57 .695 .926 r
.57131 .82952 m .57339 .82753 L .57146 .82816 L F
.57131 .82952 m .57392 .82925 L .57339 .82753 L F
.893 .579 .448 r
.55718 .80983 m .55549 .80939 L .55492 .80717 L F
.781 .338 0 r
.5573 .81205 m .55549 .80939 L .55718 .80983 L F
.573 .765 .969 r
.44729 .88526 m .45053 .88589 L .44938 .88488 L F
.55 .749 .969 r
.45053 .88589 m .45155 .88456 L .44938 .88488 L F
.45053 .88589 m .45263 .88557 L .45155 .88456 L F
.654 .343 .434 r
.45373 .82987 m .45605 .83012 L .45705 .82774 L F
.578 .267 .405 r
.45605 .83012 m .45927 .82771 L .45705 .82774 L F
.406 .128 .375 r
.38235 .78265 m .38113 .78078 L .38318 .78041 L F
.38235 .78265 m .38053 .78316 L .38113 .78078 L F
.817 .93 .908 r
.45041 .87209 m .44696 .87368 L .44921 .87309 L F
.212 0 0 r
.45041 .87209 m .4514 .8726 L .45241 .87258 L F
.45041 .87209 m .44921 .87309 L .4514 .8726 L F
.798 .702 .758 r
.57548 .83563 m .57642 .83834 L .57334 .83838 L F
.781 .771 .844 r
.57334 .83838 m .57642 .83834 L .57454 .83947 L F
.662 .724 .895 r
.57725 .83583 m .57642 .83834 L .57548 .83563 L F
.57725 .83583 m .57845 .8379 L .57642 .83834 L F
.541 .358 .582 r
.36646 .77577 m .36839 .77772 L .36858 .77552 L F
.36646 .77577 m .36638 .77808 L .36839 .77772 L F
.512 .454 .729 r
.4064 .74955 m .40491 .75177 L .40423 .74999 L F
.4064 .74955 m .40676 .75165 L .40491 .75177 L F
.791 .299 .025 r
.536 .86727 m .53596 .8669 L .5328 .8646 L F
.667 .576 .743 r
.51753 .84377 m .51547 .84463 L .5141 .84126 L F
.516 .772 .989 r
.48813 .88466 m .48822 .883 L .487 .88328 L F
.48813 .88466 m .49037 .88431 L .48822 .883 L F
.707 .174 0 r
.56662 .84768 m .5673 .84803 L .5668 .84798 L F
.172 .706 .834 r
.5673 .84803 m .56887 .84776 L .5668 .84798 L F
.5673 .84803 m .56945 .84787 L .56887 .84776 L F
.441 0 0 r
.5673 .84803 m .57042 .84924 L .56945 .84787 L F
.864 .95 .594 r
.65591 .75897 m .65592 .75997 L .65706 .75789 L F
.629 .143 .079 r
.65706 .75789 m .6591 .75927 L .65591 .75897 L F
.528 .28 .483 r
.65928 .75731 m .6591 .75927 L .65706 .75789 L F
.478 .191 .398 r
.35984 .79849 m .35702 .80125 L .35796 .79932 L F
.462 .275 .541 r
.58726 .82546 m .58726 .82819 L .58915 .82733 L F
.58726 .82546 m .58726 .82819 L .58915 .82733 L F
.904 .612 .48 r
.6943 .7209 m .6959 .72329 L .69443 .72248 L F
.452 .038 .162 r
.6959 .72329 m .69749 .7247 L .69574 .72528 L F
.6959 .72329 m .69818 .72306 L .69749 .7247 L F
.055 0 .196 r
.62559 .79341 m .62401 .79402 L .62593 .7913 L F
.02 0 .102 r
.62361 .79586 m .62401 .79402 L .62559 .79341 L F
.62 .452 .633 r
.39542 .84635 m .39756 .84601 L .39756 .84376 L F
.671 .521 .673 r
.39756 .84601 m .39987 .84343 L .39756 .84376 L F
.555 .247 .4 r
.35894 .7833 m .36105 .78317 L .36209 .78079 L F
.529 .22 .388 r
.36209 .78079 m .36364 .78198 L .36416 .78058 L F
.36209 .78079 m .36105 .78317 L .36364 .78198 L F
.647 .148 .05 r
.50435 .8202 m .50288 .82127 L .50126 .81969 L F
.22 0 0 r
.50504 .82094 m .50435 .8202 L .50645 .8203 L F
.50504 .82094 m .50288 .82127 L .50435 .8202 L F
.646 .483 .648 r
.39323 .84901 m .39548 .84887 L .39542 .84635 L F
.672 .531 .684 r
.39548 .84887 m .39756 .84601 L .39542 .84635 L F
.201 .729 .763 r
.65409 .76836 m .65328 .76842 L .65059 .76895 L F
0 0 0 r
.65409 .76836 m .65589 .76746 L .65538 .76773 L F
.65409 .76836 m .65538 .76773 L .65328 .76842 L F
.978 .75 .526 r
.56387 .83032 m .56485 .83348 L .56414 .83266 L F
.964 .904 .712 r
.56414 .83266 m .56485 .83348 L .56388 .83545 L F
.574 .526 .763 r
.51556 .85109 m .51678 .85465 L .51402 .85487 L F
.11 .663 .767 r
.51402 .85487 m .51678 .85465 L .51556 .85465 L F
.574 .526 .763 r
.51552 .85424 m .51402 .85487 L .51551 .85466 L F
.51556 .85109 m .51479 .853 L .51552 .85424 L F
.51479 .853 m .51402 .85487 L .51552 .85424 L F
.622 .554 .757 r
.51867 .85372 m .51678 .85465 L .51556 .85109 L F
.564 .934 .911 r
.51561 .85465 m .51678 .85465 L .51621 .8544 L F
.657 .481 .635 r
.51551 .85473 m .51662 .85445 L .51621 .8544 L F
.51553 .85468 m .51621 .8544 L .51571 .85433 L F
.51551 .85473 m .51621 .8544 L .51553 .85468 L F
.622 .554 .757 r
.51867 .85372 m .51556 .85109 L .51748 .85079 L F
.233 .352 .78 r
.51991 .85326 m .51867 .85372 L .51748 .85079 L F
.639 .399 .538 r
.52142 .8483 m .51995 .85087 L .51748 .85079 L F
.233 .352 .78 r
.51991 .85326 m .51748 .85079 L .51995 .85087 L F
.649 .599 .785 r
.51765 .8538 m .51909 .85001 L .51748 .85079 L F
.51767 .85419 m .51786 .85365 L .51765 .8538 L F
.51786 .85365 m .51909 .85001 L .51765 .8538 L F
.564 .934 .911 r
.5172 .85412 m .51678 .85465 L .51867 .85372 L F
.51621 .8544 m .5166 .85457 L .5172 .85412 L F
.5166 .85457 m .51678 .85465 L .5172 .85412 L F
.5153 .85465 m .51561 .85465 L .51621 .8544 L F
.51569 .85454 m .51867 .85372 L .51585 .85481 L F
.657 .481 .635 r
.51571 .85433 m .51767 .85419 L .51748 .85079 L F
.51662 .85445 m .51767 .85419 L .51571 .85433 L F
.564 .934 .911 r
.51666 .8545 m .51674 .85447 L .51725 .85521 L F
.51674 .85447 m .51782 .85461 L .51725 .85521 L F
.495 .121 .259 r
.51725 .85521 m .51767 .85419 L .51662 .85445 L F
.51725 .85521 m .51662 .85445 L .51551 .85473 L F
.564 .934 .911 r
.51585 .85481 m .51666 .8545 L .51725 .85521 L F
.51674 .85447 m .51867 .85372 L .51782 .85461 L F
.5153 .85465 m .51569 .85454 L .51585 .85481 L F
.11 .663 .767 r
.51402 .85487 m .51556 .85465 L .5153 .85465 L F
.574 .526 .763 r
.51551 .85466 m .51402 .85487 L .51551 .85473 L F
.11 .663 .767 r
.51402 .85487 m .5153 .85465 L .51551 .85473 L F
.538 .54 .805 r
.40635 .73916 m .40497 .74186 L .40422 .73938 L F
.40635 .73916 m .40775 .74196 L .40497 .74186 L F
.598 .433 .628 r
.40759 .74383 m .40497 .74186 L .40775 .74196 L F
.40759 .74383 m .40551 .74418 L .40497 .74186 L F
.416 .163 .419 r
.59839 .81733 m .59879 .81509 L .59638 .81765 L F
0 0 .06 r
.59991 .81217 m .59879 .81509 L .59966 .81408 L F
0 0 .113 r
.59966 .81408 m .59879 .81509 L .59839 .81733 L F
.279 .339 .746 r
.43938 .8664 m .43958 .86987 L .43729 .8671 L F
.43938 .8664 m .44051 .86955 L .43958 .86987 L F
.587 .418 .619 r
.50774 .83821 m .50564 .84094 L .50568 .83805 L F
.583 .39 .585 r
.41424 .83318 m .4165 .83065 L .4144 .83106 L F
0 0 0 r
.60502 .83546 m .60574 .8335 L .60665 .83256 L F
.857 .417 .161 r
.67285 .7307 m .67584 .73362 L .6758 .73124 L F
.862 .91 .503 r
.48618 .86875 m .48474 .87267 L .48476 .87067 L F
.902 .899 .813 r
.61692 .74199 m .61592 .74434 L .61775 .74157 L F
.61692 .74199 m .61485 .74372 L .61592 .74434 L F
.586 .458 .673 r
.61592 .74434 m .61814 .74407 L .61775 .74157 L F
.299 .755 .954 r
.61485 .74372 m .61814 .74407 L .61592 .74434 L F
.659 .841 .97 r
.45263 .88557 m .45587 .8856 L .45482 .88483 L F
.489 .786 .998 r
.45587 .8856 m .45673 .8846 L .45482 .88483 L F
.45587 .8856 m .45789 .88534 L .45673 .8846 L F
.034 .605 .711 r
.45587 .8856 m .45703 .88555 L .45789 .88534 L F
.327 .348 .729 r
.55052 .84839 m .54862 .84938 L .55082 .85111 L F
.952 .752 .597 r
.56627 .79616 m .5673 .79896 L .56786 .79694 L F
.593 .581 .809 r
.70249 .71775 m .70209 .719 L .70024 .71825 L F
.926 .593 .389 r
.70209 .719 m .70245 .72199 L .69984 .72229 L F
.70209 .719 m .70358 .72352 L .70245 .72199 L F
.698 .369 .417 r
.50866 .83259 m .51076 .83342 L .51211 .83106 L F
.788 .71 .778 r
.51117 .83057 m .51211 .83106 L .51392 .8279 L F
.509 .158 .307 r
.51211 .83106 m .51389 .8325 L .51427 .83074 L F
.51211 .83106 m .51076 .83342 L .51389 .8325 L F
.586 .449 .662 r
.51392 .8279 m .51211 .83106 L .51427 .83074 L F
.208 0 .22 r
.62275 .75201 m .62228 .75004 L .6228 .75162 L F
.909 .533 .303 r
.62228 .75004 m .62134 .75108 L .6228 .75162 L F
.803 .919 .533 r
.62316 .74769 m .62134 .75108 L .62228 .75004 L F
.909 .533 .303 r
.62228 .75004 m .62134 .75108 L .6228 .75162 L F
.156 0 0 r
.65546 .75391 m .65579 .75275 L .65342 .7542 L F
.31 .155 .503 r
.65317 .75644 m .65546 .75391 L .65342 .7542 L F
.219 .62 .953 r
.66732 .72397 m .66617 .72447 L .66501 .72455 L F
.66732 .72397 m .66833 .72483 L .66617 .72447 L F
.736 .612 .72 r
.48092 .85395 m .48231 .8569 L .47896 .85636 L F
.573 .48 .711 r
.48296 .85454 m .48231 .8569 L .48092 .85395 L F
.48296 .85454 m .48438 .8566 L .48231 .8569 L F
.636 .589 .784 r
.70144 .71479 m .70024 .71825 L .69925 .7153 L F
.70144 .71479 m .70249 .71775 L .70024 .71825 L F
.482 .371 .651 r
.68232 .75145 m .68116 .75195 L .67958 .74904 L F
.002 0 0 r
.66883 .76089 m .66966 .76109 L .66831 .76077 L F
.547 .285 .47 r
.38031 .76769 m .38256 .76743 L .38308 .76487 L F
.464 .191 .413 r
.38256 .76743 m .38509 .76458 L .38308 .76487 L F
.628 .787 .958 r
.40237 .73991 m .39912 .73959 L .4011 .73906 L F
.613 .796 .969 r
.40422 .73938 m .40237 .73991 L .4011 .73906 L F
.642 .844 .978 r
.42578 .88803 m .42898 .88808 L .42784 .88737 L F
.65 .913 .98 r
.42898 .88808 m .42779 .88715 L .42784 .88737 L F
.42898 .88808 m .43067 .88728 L .42779 .88715 L F
.673 .496 .638 r
.39098 .85158 m .39331 .85136 L .39323 .84901 L F
.66 .496 .651 r
.39331 .85136 m .39548 .84887 L .39323 .84901 L F
.572 .615 .857 r
.39436 .73625 m .39383 .73908 L .39251 .73661 L F
.39436 .73625 m .39583 .73877 L .39383 .73908 L F
.586 .565 .797 r
.38774 .74892 m .38996 .74876 L .38715 .74712 L F
.38774 .74892 m .39075 .75001 L .38996 .74876 L F
.646 .539 .719 r
.38774 .74892 m .3905 .75163 L .39075 .75001 L F
.38774 .74892 m .38883 .75266 L .3905 .75163 L F
.7 .549 .679 r
.38587 .85396 m .38886 .85423 L .38872 .85191 L F
.658 .517 .68 r
.38886 .85423 m .39098 .85158 L .38872 .85191 L F
.566 .304 .478 r
.41166 .75994 m .40896 .76204 L .40925 .76024 L F
.417 0 0 r
.63507 .72065 m .63746 .72099 L .63816 .72084 L F
.944 .949 .749 r
.63816 .72084 m .6392 .71739 L .64051 .71859 L F
.63816 .72084 m .63746 .72099 L .6392 .71739 L F
.712 .927 .963 r
.51902 .87521 m .51613 .87573 L .51752 .87464 L F
.415 .781 .995 r
.51995 .87439 m .51885 .87515 L .51752 .87464 L F
.275 0 0 r
.51995 .87439 m .51752 .87464 L .51683 .87559 L F
.51708 .87555 m .51683 .87559 L .51676 .87568 L F
.51995 .87439 m .51683 .87559 L .51708 .87555 L F
.3 .59 .945 r
.51995 .87439 m .52142 .87587 L .51902 .87521 L F
.415 .781 .995 r
.51995 .87439 m .51902 .87521 L .51885 .87515 L F
.275 0 0 r
.51995 .87439 m .5184 .8768 L .5171 .87575 L F
.709 .375 .411 r
.5171 .87575 m .5184 .8768 L .51896 .87839 L F
.275 0 0 r
.51843 .87675 m .51751 .87616 L .5184 .8768 L F
.51751 .87616 m .51754 .87621 L .5184 .8768 L F
.51995 .87439 m .51708 .87555 L .51843 .87675 L F
.803 .628 .665 r
.51765 .87628 m .51815 .87625 L .51734 .87578 L F
.51815 .87625 m .52041 .87611 L .518 .87585 L F
.51815 .87625 m .518 .87585 L .51734 .87578 L F
.813 .429 0 r
.51896 .87839 m .5184 .8768 L .51832 .8767 L F
0 .33 .801 r
.51832 .8767 m .5184 .8768 L .51754 .87621 L F
.803 .628 .665 r
.51896 .87839 m .51955 .87746 L .51765 .87628 L F
.51955 .87746 m .52041 .87611 L .51765 .87628 L F
.437 .863 .737 r
.51727 .87572 m .51734 .87578 L .52041 .87611 L F
.813 .429 0 r
.51896 .87839 m .51832 .8767 L .51759 .87568 L F
.803 .628 .665 r
.51775 .87668 m .51734 .87578 L .5171 .87575 L F
.437 .863 .737 r
.51727 .87572 m .5171 .87575 L .51734 .87578 L F
.275 0 0 r
.51708 .87555 m .51676 .87568 L .51843 .87675 L F
0 .33 .801 r
.51759 .87568 m .51832 .8767 L .51676 .87568 L F
.803 .628 .665 r
.51896 .87839 m .51734 .87578 L .51775 .87668 L F
.275 0 0 r
.51751 .87616 m .51676 .87568 L .51754 .87621 L F
0 .33 .801 r
.51832 .8767 m .51754 .87621 L .51676 .87568 L F
.437 .863 .737 r
.52073 .875 m .51727 .87572 L .52041 .87611 L F
.52106 .87362 m .51995 .87439 L .5171 .87575 L F
.52114 .87358 m .51995 .87439 L .52106 .87362 L F
.669 .751 .912 r
.52332 .8749 m .52142 .87587 L .51995 .87439 L F
.688 .737 .888 r
.52176 .87464 m .52332 .8749 L .51995 .87439 L F
.426 .779 .996 r
.52114 .87358 m .52176 .87464 L .51995 .87439 L F
.437 .863 .737 r
.52114 .87358 m .51764 .87546 L .52073 .875 L F
.51764 .87546 m .5171 .87575 L .52073 .875 L F
0 0 0 r
.51339 .83633 m .51324 .83615 L .51525 .83581 L F
.51339 .83633 m .51175 .83696 L .51324 .83615 L F
.627 .572 .773 r
.67829 .71665 m .67869 .71885 L .67866 .7178 L F
.795 .665 .72 r
.67829 .71665 m .67866 .7178 L .67862 .7178 L F
.561 .526 .773 r
.67845 .71752 m .67885 .7186 L .67869 .71885 L F
.67829 .71665 m .67862 .7178 L .67845 .71752 L F
.67862 .7178 m .67885 .7186 L .67845 .71752 L F
.796 .604 .642 r
.67453 .71763 m .67862 .7178 L .67663 .71967 L F
.67862 .7178 m .67866 .7178 L .67864 .71783 L F
.67862 .7178 m .67864 .71783 L .67663 .71967 L F
.795 .665 .72 r
.67829 .71665 m .67862 .7178 L .67453 .71763 L F
.561 .526 .773 r
.67829 .71665 m .6799 .7169 L .67885 .7186 L F
.314 0 .212 r
.49493 .82195 m .49363 .82116 L .49575 .82057 L F
.49493 .82195 m .49302 .82267 L .49363 .82116 L F
.848 .793 .797 r
.63174 .76793 m .63229 .77018 L .62967 .77054 L F
.838 .893 .879 r
.63229 .77018 m .62869 .77191 L .62967 .77054 L F
.798 .766 .824 r
.63174 .76793 m .63448 .76775 L .63229 .77018 L F
.538 .27 .456 r
.59044 .76675 m .5924 .76685 L .59046 .76525 L F
.58 .255 .382 r
.59046 .76525 m .5924 .76685 L .59286 .76523 L F
.755 .49 .532 r
.44635 .84862 m .44465 .84637 L .44645 .84632 L F
.44635 .84862 m .44556 .84881 L .44465 .84637 L F
.638 .915 .623 r
.6445 .71523 m .64256 .71733 L .64225 .71728 L F
.6445 .71523 m .64225 .71728 L .64258 .71696 L F
.782 .595 .647 r
.64183 .71705 m .6419 .71716 L .64384 .71659 L F
.516 .498 .775 r
.64023 .71511 m .64197 .71729 L .6392 .71739 L F
.64042 .71469 m .64149 .71649 L .64023 .71511 L F
.64149 .71649 m .64197 .71729 L .64023 .71511 L F
.782 .595 .647 r
.6402 .71643 m .64064 .71732 L .64269 .71685 L F
.773 .52 .553 r
.64149 .71649 m .64223 .71728 L .6402 .71643 L F
.638 .915 .623 r
.6445 .71523 m .64258 .71696 L .64384 .71659 L F
.782 .595 .647 r
.64142 .7173 m .6432 .71726 L .64384 .71659 L F
.638 .915 .623 r
.64258 .71696 m .64225 .71728 L .64223 .71728 L F
.64258 .71696 m .64223 .71728 L .64384 .71659 L F
.782 .595 .647 r
.643 .71655 m .64269 .71685 L .64384 .71659 L F
.6402 .71643 m .64269 .71685 L .643 .71655 L F
.773 .52 .553 r
.64384 .71659 m .64223 .71728 L .64149 .71649 L F
.516 .498 .775 r
.64065 .71418 m .64223 .71728 L .64197 .71729 L F
.64065 .71418 m .64197 .71729 L .64042 .71469 L F
.782 .595 .647 r
.64064 .71732 m .64142 .7173 L .6419 .71716 L F
.64064 .71732 m .6419 .71716 L .64183 .71705 L F
.05 .618 .738 r
.64197 .71729 m .64256 .71733 L .6392 .71739 L F
.64225 .71728 m .64256 .71733 L .64197 .71729 L F
.816 .73 .77 r
.6392 .71739 m .64256 .71733 L .64051 .71859 L F
.782 .595 .647 r
.64064 .71732 m .64151 .71907 L .6432 .71726 L F
.05 .618 .738 r
.64223 .71728 m .64225 .71728 L .64197 .71729 L F
.575 .658 .893 r
.47189 .87067 m .46949 .87007 L .47038 .87018 L F
.349 .805 .681 r
.45636 .87145 m .45837 .87056 L .45536 .87201 L F
.45636 .87145 m .45536 .87201 L .45463 .87243 L F
.645 .497 .668 r
.38178 .8596 m .38459 .85954 L .38394 .8567 L F
.699 .538 .667 r
.38156 .86171 m .38459 .85954 L .38178 .8596 L F
.626 .778 .954 r
.58291 .83449 m .58418 .83561 L .58085 .83523 L F
.407 .687 .976 r
.58614 .83556 m .58418 .83561 L .58291 .83449 L F
.807 .956 .912 r
.47018 .86268 m .46774 .86447 L .46623 .86424 L F
0 .067 .585 r
.4691 .86644 m .46774 .86447 L .46949 .86437 L F
0 0 .095 r
.62134 .75108 m .62165 .75338 L .6228 .75162 L F
.62134 .75108 m .62169 .75372 L .62165 .75338 L F
.62169 .75372 m .6218 .75449 L .62165 .75338 L F
.085 0 .43 r
.62165 .75338 m .62087 .75396 L .62162 .75319 L F
.62165 .75338 m .62162 .75319 L .62275 .75201 L F
.62165 .75338 m .62102 .75488 L .62087 .75396 L F
.379 .623 .948 r
.64858 .75901 m .6506 .75928 L .64942 .76025 L F
.488 .874 .682 r
.64942 .76025 m .6506 .75928 L .65122 .75901 L F
.64942 .76025 m .6506 .75928 L .65122 .75901 L F
.085 0 .43 r
.62165 .75338 m .62275 .75201 L .6228 .75162 L F
.74 .588 .687 r
.43771 .82769 m .43456 .82576 L .43693 .82525 L F
.43771 .82769 m .43575 .82799 L .43456 .82576 L F
.617 .64 .851 r
.43889 .82509 m .43771 .82769 L .43693 .82525 L F
.43889 .82509 m .43994 .82758 L .43771 .82769 L F
.566 .386 .596 r
.38883 .75266 m .39075 .75406 L .3905 .75163 L F
.268 .714 .96 r
.38419 .74659 m .38715 .74712 L .38625 .74624 L F
.261 .51 .903 r
.38715 .74712 m .3881 .74634 L .38625 .74624 L F
.38715 .74712 m .38996 .74876 L .3881 .74634 L F
.667 .475 .615 r
.47911 .85795 m .47786 .86205 L .47701 .85913 L F
.457 .433 .744 r
.47896 .85636 m .47911 .85795 L .47701 .85913 L F
.928 .635 .467 r
.47911 .85795 m .47882 .86149 L .47786 .86205 L F
.667 .475 .615 r
.47911 .85795 m .47786 .86205 L .47701 .85913 L F
.635 .559 .751 r
.43417 .86435 m .43513 .86752 L .43286 .86764 L F
.632 .493 .675 r
.43513 .86752 m .43315 .86992 L .43286 .86764 L F
.642 .666 .857 r
.33011 .66594 m .33077 .66837 L .32869 .66805 L F
.33011 .66594 m .33173 .66832 L .33077 .66837 L F
.514 .773 .99 r
.33054 .67063 m .32869 .66805 L .33077 .66837 L F
.524 .304 .523 r
.33173 .66832 m .33054 .67063 L .33077 .66837 L F
0 0 .505 r
.59638 .81765 m .59772 .81912 L .59839 .81733 L F
.59638 .81765 m .59667 .81994 L .59772 .81912 L F
.731 .743 .861 r
.49492 .84157 m .49837 .84188 L .49679 .84104 L F
.63 .192 .19 r
.50027 .84096 m .49679 .84104 L .49837 .84188 L F
.648 .61 .797 r
.49837 .84188 m .50099 .84317 L .50027 .84096 L F
.588 .768 .965 r
.4973 .88175 m .49878 .88277 L .50062 .88234 L F
.162 0 0 r
.51247 .87558 m .51252 .87556 L .51128 .87534 L F
.51455 .87599 m .51252 .87556 L .51247 .87558 L F
.238 0 0 r
.51252 .87556 m .51372 .87591 L .51256 .87555 L F
.51252 .87556 m .51256 .87555 L .51043 .87489 L F
.672 .442 .564 r
.40674 .83838 m .40913 .83808 L .4069 .83587 L F
.661 .444 .578 r
.4069 .83587 m .40913 .83808 L .40921 .83584 L F
.747 .335 .269 r
.50532 .81444 m .50737 .81656 L .50845 .81508 L F
.616 .238 .303 r
.50737 .81656 m .5104 .81585 L .50845 .81508 L F
.436 .834 .98 r
.67613 .75844 m .67777 .75745 L .67516 .75735 L F
.67613 .75844 m .67856 .75803 L .67777 .75745 L F
.719 .841 .94 r
.42052 .88844 m .42372 .88846 L .42304 .88765 L F
.586 .787 .976 r
.42304 .88765 m .42372 .88846 L .42578 .88803 L F
.691 .735 .884 r
.38538 .8994 m .38734 .89856 L .38401 .89816 L F
0 0 0 r
.55265 .85042 m .55318 .84868 L .55343 .84851 L F
.343 .525 .891 r
.6911 .706 m .69013 .70734 L .68802 .70501 L F
.6911 .706 m .69146 .70726 L .69013 .70734 L F
.743 .31 .223 r
.54424 .82802 m .54345 .82847 L .54075 .82713 L F
.749 .984 .756 r
.54416 .82735 m .54345 .82847 L .54424 .82802 L F
.718 .203 0 r
.54424 .82802 m .54495 .82952 L .54416 .82735 L F
.555 .412 .642 r
.41578 .75689 m .41358 .75464 L .41555 .75423 L F
.41578 .75689 m .4138 .75752 L .41358 .75464 L F
.543 .377 .607 r
.62759 .72777 m .63011 .72568 L .62796 .72799 L F
.62759 .72777 m .6294 .72511 L .63011 .72568 L F
.869 .981 .845 r
.63011 .72568 m .63262 .72198 L .63279 .72303 L F
.63011 .72568 m .6294 .72511 L .63262 .72198 L F
.43 .26 .549 r
.69384 .72835 m .69209 .73106 L .69162 .72877 L F
.868 .699 .671 r
.69087 .72585 m .69162 .72877 L .69064 .72753 L F
.775 .607 .671 r
.69162 .72877 m .6886 .73065 L .69064 .72753 L F
.69162 .72877 m .69209 .73106 L .6886 .73065 L F
.011 0 .236 r
.50099 .84317 m .50238 .84124 L .50027 .84096 L F
.50099 .84317 m .50247 .84233 L .50238 .84124 L F
.578 .562 .799 r
.50261 .84504 m .50247 .84233 L .50099 .84317 L F
0 0 0 r
.47883 .84906 m .47796 .84923 L .47995 .8483 L F
.71 .613 .746 r
.44416 .86964 m .44756 .87051 L .44587 .87111 L F
.593 .537 .762 r
.44756 .86983 m .44587 .87111 L .44756 .87051 L F
.826 .549 .519 r
.64224 .72328 m .64227 .72575 L .64385 .72479 L F
.776 .994 .784 r
.64401 .72145 m .64242 .72233 L .64224 .72328 L F
.063 .089 .576 r
.64242 .72233 m .64227 .72575 L .64224 .72328 L F
.64228 .72561 m .643 .72491 L .64227 .72575 L F
.64242 .72233 m .643 .72491 L .64228 .72561 L F
.629 .948 .748 r
.64506 .72027 m .64401 .72145 L .64527 .71982 L F
.64506 .72027 m .64242 .72233 L .64401 .72145 L F
.231 .199 .615 r
.64382 .72122 m .64391 .72407 L .643 .72491 L F
.558 .22 .352 r
.64391 .72407 m .64366 .72427 L .643 .72491 L F
.64366 .72427 m .64161 .72585 L .643 .72491 L F
.9 .772 .711 r
.64069 .72671 m .64227 .72575 L .643 .72491 L F
.64045 .7269 m .64227 .72575 L .64069 .72671 L F
.826 .549 .519 r
.64385 .72479 m .64227 .72575 L .64468 .72557 L F
.561 .211 .333 r
.64141 .72794 m .64468 .72557 L .64227 .72575 L F
.64141 .72794 m .64391 .72743 L .64468 .72557 L F
.588 .556 .785 r
.64702 .72757 m .64578 .72577 L .64679 .72598 L F
.352 0 .062 r
.64391 .72743 m .64679 .72598 L .64468 .72557 L F
.173 0 0 r
.64468 .72557 m .64679 .72598 L .64578 .72577 L F
.343 0 0 r
.5096 .82048 m .50867 .8207 L .50645 .8203 L F
.533 .053 .063 r
.51168 .82034 m .50867 .8207 L .5096 .82048 L F
.609 .356 .509 r
.37776 .76985 m .38031 .76769 L .37822 .76792 L F
.488 .096 .224 r
.37016 .74846 m .36774 .74913 L .36828 .74771 L F
.481 .12 .276 r
.47635 .82469 m .47952 .82235 L .4775 .82273 L F
.199 0 0 r
.49219 .86976 m .49312 .86994 L .49096 .86945 L F
.873 .655 .606 r
.49082 .87242 m .49312 .86994 L .49219 .86976 L F
.49082 .87242 m .49291 .87226 L .49312 .86994 L F
.573 .149 .198 r
.45215 .86164 m .45418 .86175 L .45514 .86053 L F
.669 .262 .264 r
.45418 .86175 m .45727 .86194 L .45514 .86053 L F
.673 .178 .065 r
.45514 .86053 m .45727 .86194 L .45923 .86204 L F
.548 .343 .554 r
.60029 .76003 m .60238 .7619 L .6012 .75946 L F
.60029 .76003 m .60015 .76224 L .60238 .7619 L F
.611 .73 .93 r
.64679 .72598 m .64878 .72604 L .64702 .72757 L F
.501 .304 .545 r
.64878 .72604 m .64717 .73061 L .64702 .72757 L F
.152 .654 .908 r
.57871 .8491 m .57973 .84883 L .57769 .84825 L F
.57871 .8491 m .58087 .84929 L .57973 .84883 L F
.775 .789 .864 r
.50062 .88234 m .50325 .88201 L .5029 .88046 L F
.758 .959 .935 r
.50325 .88201 m .50501 .87992 L .5029 .88046 L F
.50325 .88201 m .50608 .88021 L .50501 .87992 L F
.541 .871 .993 r
.5029 .88046 m .50501 .87992 L .5037 .87949 L F
.327 0 0 r
.50501 .87992 m .50594 .88093 L .5039 .87962 L F
.50501 .87992 m .5039 .87962 L .5037 .87949 L F
.758 .959 .935 r
.50608 .88021 m .50616 .88016 L .50501 .87992 L F
.338 0 .044 r
.60838 .74074 m .61159 .7389 L .60935 .73923 L F
.636 .823 .972 r
.41522 .75177 m .41205 .75243 L .41091 .7508 L F
.757 .794 .883 r
.44463 .86665 m .44441 .86973 L .44416 .86964 L F
.447 .396 .708 r
.4467 .8662 m .44441 .86973 L .44463 .86665 L F
.4467 .8662 m .44756 .86983 L .44441 .86973 L F
.807 .956 .912 r
.47018 .86268 m .46623 .86424 L .46867 .86181 L F
.873 .878 .836 r
.47167 .8595 m .47018 .86268 L .46867 .86181 L F
.866 .873 .432 r
.67255 .74987 m .67186 .75103 L .67147 .74854 L F
.67255 .74987 m .67182 .75194 L .67186 .75103 L F
.516 .476 .75 r
.35489 .78614 m .35665 .78563 L .35744 .78393 L F
.282 0 .266 r
.35744 .78393 m .35665 .78563 L .35894 .7833 L F
.834 .904 .887 r
.58836 .83489 m .58614 .83556 L .58818 .83341 L F
.902 .913 .819 r
.59013 .83191 m .58836 .83489 L .58818 .83341 L F
.725 .887 .492 r
.59013 .83191 m .58836 .83489 L .58987 .83214 L F
.654 .507 .671 r
.38394 .8567 m .38667 .85691 L .38587 .85396 L F
.683 .545 .69 r
.38459 .85954 m .38667 .85691 L .38394 .8567 L F
.272 .777 .829 r
.51295 .82521 m .51081 .82567 L .50973 .82571 L F
0 0 0 r
.6266 .79031 m .62593 .7913 L .62779 .78848 L F
0 0 .015 r
.62559 .79341 m .62593 .7913 L .6266 .79031 L F
.638 .546 .734 r
.54103 .84107 m .54268 .83853 L .54073 .83849 L F
.565 .494 .734 r
.40556 .74651 m .40423 .74999 L .40352 .74687 L F
.40556 .74651 m .4064 .74955 L .40423 .74999 L F
.949 .727 .568 r
.4895 .84579 m .49057 .84858 L .49107 .84649 L F
.763 .749 .839 r
.52068 .82325 m .52167 .82602 L .51856 .82465 L F
.228 .291 .721 r
.51919 .82772 m .51856 .82465 L .52167 .82602 L F
.227 .405 .831 r
.5225 .82437 m .52167 .82602 L .52068 .82325 L F
.222 .574 .941 r
.65591 .75897 m .65707 .76013 L .65592 .75997 L F
.679 .504 .642 r
.38667 .85691 m .38886 .85423 L .38587 .85396 L F
.604 .61 .831 r
.56711 .78353 m .56829 .7805 L .56608 .78238 L F
.595 .411 .601 r
.37331 .77216 m .37551 .77007 L .37334 .77034 L F
.461 .225 .47 r
.3951 .77035 m .39477 .77254 L .39277 .77296 L F
.549 .303 .495 r
.39678 .77221 m .3951 .77035 L .39709 .77002 L F
.39678 .77221 m .39477 .77254 L .3951 .77035 L F
.28 .251 .647 r
.69443 .72248 m .69609 .71946 L .6943 .7209 L F
.729 .698 .821 r
.64545 .70767 m .64656 .71022 L .64335 .70982 L F
.609 .108 .037 r
.64656 .71022 m .64553 .71086 L .64335 .70982 L F
.395 .509 .856 r
.6481 .70902 m .64656 .71022 L .64545 .70767 L F
.466 .85 .635 r
.6481 .70902 m .64553 .71086 L .64656 .71022 L F
.263 0 0 r
.48808 .87541 m .48894 .87535 L .48571 .87496 L F
.48808 .87541 m .48894 .87535 L .48571 .87496 L F
.058 .616 .803 r
.48917 .87519 m .48894 .87535 L .48808 .87541 L F
.48917 .87519 m .49095 .87543 L .48894 .87535 L F
.48917 .87519 m .48894 .87535 L .48808 .87541 L F
.48917 .87519 m .49095 .87543 L .48894 .87535 L F
.59 .017 0 r
.45705 .86582 m .45953 .86715 L .45854 .86722 L F
.868 .55 .033 r
.45919 .86885 m .45854 .86722 L .45953 .86715 L F
.911 .968 .8 r
.45919 .86885 m .45837 .87056 L .45636 .87145 L F
.795 .754 .815 r
.47584 .85657 m .47701 .85913 L .4758 .85934 L F
.752 .523 .584 r
.47701 .85913 m .47362 .86199 L .4758 .85934 L F
.47701 .85913 m .47786 .86205 L .47362 .86199 L F
.819 .763 .8 r
.47896 .85636 m .47701 .85913 L .47584 .85657 L F
.652 .921 .628 r
.62779 .78848 m .63021 .78597 L .62995 .78602 L F
0 0 0 r
.63021 .78597 m .63104 .7845 L .62995 .78602 L F
.63021 .78597 m .63198 .78335 L .63209 .78329 L F
.63021 .78597 m .63209 .78329 L .63104 .7845 L F
.845 .997 .775 r
.62796 .72799 m .62609 .73019 L .62538 .73022 L F
.62796 .72799 m .62538 .73022 L .62765 .73005 L F
.62796 .72799 m .62765 .73005 L .62759 .72777 L F
.51 .288 .513 r
.46905 .8377 m .46754 .83902 L .46683 .83798 L F
.703 .562 .692 r
.45047 .8473 m .44635 .84862 L .44645 .84632 L F
.964 .856 .686 r
.57538 .82767 m .57632 .82544 L .57527 .82493 L F
.505 .478 .761 r
.68232 .75145 m .68006 .75349 L .68116 .75195 L F
.68232 .75145 m .68273 .75407 L .68006 .75349 L F
.75 .446 .469 r
.51096 .84095 m .51042 .84419 L .5141 .84126 L F
0 0 0 r
.5141 .84126 m .51527 .84054 L .51666 .83965 L F
.5141 .84126 m .51042 .84419 L .51527 .84054 L F
.516 .476 .75 r
.35489 .78614 m .35636 .78578 L .35665 .78563 L F
.324 0 .209 r
.3547 .78652 m .35636 .78578 L .35489 .78614 L F
.583 .39 .585 r
.41424 .83318 m .41641 .83301 L .4165 .83065 L F
.627 .426 .591 r
.4165 .83065 m .41865 .83274 L .41893 .83078 L F
.4165 .83065 m .41641 .83301 L .41865 .83274 L F
.9 .974 .811 r
.63157 .73553 m .63118 .73724 L .63246 .73612 L F
.877 .944 .855 r
.63397 .73289 m .63246 .73612 L .6353 .73406 L F
.63397 .73289 m .63157 .73553 L .63246 .73612 L F
.796 .596 .63 r
.53954 .81174 m .54279 .8097 L .53959 .81 L F
.53954 .81174 m .54254 .81232 L .54279 .8097 L F
.602 .952 .889 r
.41698 .88991 m .41822 .88981 L .42052 .88844 L F
.528 .09 .152 r
.68005 .72573 m .67954 .72729 L .67887 .72563 L F
.68005 .72573 m .68393 .72623 L .67954 .72729 L F
0 .488 .834 r
.68894 .70485 m .68802 .70501 L .68723 .70444 L F
.285 0 0 r
.68894 .70485 m .68723 .70444 L .68716 .70461 L F
0 .451 .772 r
.68802 .70501 m .68704 .70478 L .68636 .70443 L F
.285 0 0 r
.68861 .70494 m .68716 .70461 L .68685 .70547 L F
.68894 .70485 m .68716 .70461 L .68861 .70494 L F
0 .451 .772 r
.68674 .70452 m .68636 .70443 L .68585 .70417 L F
.68802 .70501 m .68636 .70443 L .68674 .70452 L F
.455 .885 .883 r
.5852 .84838 m .58419 .84914 L .58608 .84839 L F
.449 .877 .916 r
.58314 .84905 m .58419 .84914 L .5852 .84838 L F
0 0 .06 r
.59991 .81217 m .59966 .81408 L .6003 .81204 L F
.222 .118 .518 r
.49057 .84858 m .49018 .84939 L .48868 .8491 L F
.489 .231 .449 r
.37393 .78592 m .37303 .7888 L .37124 .78849 L F
.553 .293 .476 r
.3759 .78594 m .37393 .78592 L .37594 .7856 L F
.3759 .78594 m .37303 .7888 L .37393 .78592 L F
.831 .965 .892 r
.56941 .77957 m .56922 .78089 L .57144 .7781 L F
.016 0 0 r
.57246 .77819 m .57144 .7781 L .5735 .77798 L F
.57246 .77819 m .56941 .77957 L .57144 .7781 L F
.674 .549 .704 r
.37456 .8673 m .37521 .86727 L .37501 .86493 L F
.712 .518 .625 r
.37262 .86969 m .37456 .8673 L .37258 .86729 L F
.37262 .86969 m .37408 .86971 L .37456 .8673 L F
.667 .475 .615 r
.37408 .86971 m .37521 .86727 L .37456 .8673 L F
.931 .935 .782 r
.52002 .83211 m .52021 .83314 L .52269 .83058 L F
.52002 .83211 m .51937 .83265 L .52021 .83314 L F
.43 .26 .549 r
.69384 .72835 m .69368 .73019 L .69209 .73106 L F
0 0 0 r
.69205 .73224 m .69209 .73106 L .69368 .73019 L F
.69205 .73224 m .6915 .73272 L .69209 .73106 L F
.473 .065 .185 r
.69209 .73106 m .68882 .73302 L .6886 .73065 L F
.69209 .73106 m .6915 .73272 L .68882 .73302 L F
0 0 .291 r
.61297 .79155 m .61255 .79366 L .6139 .79064 L F
.494 .201 .397 r
.38957 .77733 m .38753 .77768 L .38803 .77589 L F
.517 .198 .364 r
.39025 .77575 m .38957 .77733 L .38803 .77589 L F
.069 0 0 r
.47262 .87108 m .47374 .86964 L .47189 .87067 L F
.328 0 0 r
.47593 .86952 m .47374 .86964 L .47262 .87108 L F
.831 .965 .892 r
.56941 .77957 m .56829 .7805 L .56922 .78089 L F
.624 .677 .88 r
.38608 .72976 m .38922 .73055 L .38839 .72978 L F
.043 .569 .865 r
.41277 .8897 m .41381 .89029 L .41502 .89045 L F
0 0 0 r
.48199 .86185 m .48243 .86135 L .48299 .86223 L F
.352 .481 .85 r
.48023 .86054 m .48299 .86223 L .48111 .85889 L F
.104 0 .315 r
.61516 .80921 m .61404 .80979 L .61562 .80691 L F
.143 0 .398 r
.61374 .81201 m .61404 .80979 L .61516 .80921 L F
.507 .85 .579 r
.66123 .76513 m .66371 .76299 L .66237 .76406 L F
.555 .923 .766 r
.66123 .76513 m .66237 .76406 L .65929 .76595 L F
.573 .359 .553 r
.36858 .77552 m .37074 .7753 L .37076 .77283 L F
.533 .299 .505 r
.37074 .7753 m .37331 .77216 L .37076 .77283 L F
.84 .657 .655 r
.48141 .84287 m .48432 .84128 L .48312 .84086 L F
.48141 .84287 m .48476 .84465 L .48432 .84128 L F
.557 .882 .99 r
.48581 .83996 m .48432 .84128 L .48691 .84055 L F
.48581 .83996 m .48312 .84086 L .48432 .84128 L F
.574 .438 .658 r
.38608 .72976 m .38898 .72877 L .38511 .7285 L F
.38608 .72976 m .38839 .72978 L .38898 .72877 L F
.524 .304 .523 r
.33173 .66832 m .33155 .67048 L .33054 .67063 L F
.534 .619 .883 r
.33264 .66616 m .33173 .66832 L .33011 .66594 L F
.597 .691 .909 r
.33264 .66616 m .33403 .66842 L .33173 .66832 L F
.49 .276 .515 r
.33377 .6692 m .33173 .66832 L .33403 .66842 L F
.33353 .66924 m .33173 .66832 L .33377 .6692 L F
.33372 .66934 m .33155 .67048 L .33173 .66832 L F
.642 .666 .857 r
.33011 .66594 m .32869 .66805 L .3283 .66769 L F
.656 .517 .682 r
.32824 .6678 m .33173 .66962 L .33011 .66594 L F
.514 .773 .99 r
.33054 .67063 m .32827 .66818 L .32869 .66805 L F
.668 .173 .063 r
.32827 .66818 m .33173 .66962 L .32824 .6678 L F
.32827 .66818 m .33013 .6695 L .33173 .66962 L F
.24 .293 .717 r
.33011 .66594 m .33173 .66962 L .33228 .66822 L F
.675 .876 .974 r
.33173 .66962 m .3325 .66882 L .33228 .66822 L F
.3325 .66882 m .3329 .66839 L .33271 .66834 L F
.3325 .66882 m .33271 .66834 L .33228 .66822 L F
.703 .829 .942 r
.33013 .6695 m .33155 .67048 L .33182 .67034 L F
.33223 .66941 m .33182 .67034 L .33372 .66934 L F
.675 .876 .974 r
.33173 .66962 m .33139 .66959 L .33182 .66952 L F
.33139 .66959 m .33013 .6695 L .33182 .66952 L F
.703 .829 .942 r
.33013 .6695 m .33182 .67034 L .33223 .66941 L F
.675 .876 .974 r
.33182 .66952 m .33013 .6695 L .3329 .66839 L F
.49 .276 .515 r
.33372 .66934 m .33353 .66924 L .33377 .6692 L F
.674 .533 .684 r
.37501 .86493 m .37726 .86457 L .37714 .8622 L F
.678 .551 .704 r
.37501 .86493 m .37521 .86727 L .37726 .86457 L F
.748 .639 .74 r
.65928 .75731 m .66012 .75999 L .6591 .75927 L F
.65928 .75731 m .66204 .75719 L .66012 .75999 L F
.679 .504 .642 r
.38667 .85691 m .38893 .85662 L .38886 .85423 L F
.623 .468 .651 r
.38886 .85423 m .39103 .85396 L .39098 .85158 L F
.643 .489 .659 r
.38893 .85662 m .39103 .85396 L .38886 .85423 L F
.602 .176 .206 r
.51733 .82002 m .51383 .82057 L .51517 .82056 L F
0 0 0 r
.56304 .77642 m .56324 .77653 L .56485 .77538 L F
.56304 .77642 m .56149 .77723 L .56324 .77653 L F
.525 .352 .589 r
.49542 .86723 m .49736 .86933 L .49756 .86699 L F
.341 .194 .532 r
.60819 .8228 m .61026 .81996 L .61014 .82212 L F
.122 .076 .528 r
.60982 .8243 m .60819 .8228 L .61014 .82212 L F
.60982 .8243 m .60844 .82512 L .60819 .8228 L F
.746 .598 .692 r
.66138 .75448 m .66204 .75719 L .65928 .75731 L F
.663 .589 .762 r
.66334 .75163 m .66138 .75448 L .66129 .75229 L F
.66334 .75163 m .66462 .75554 L .66138 .75448 L F
.685 .56 .708 r
.66138 .75448 m .66462 .75554 L .66204 .75719 L F
.758 .599 .68 r
.6445 .71523 m .64784 .71576 L .64654 .71255 L F
.507 .252 .463 r
.39477 .77254 m .39215 .77533 L .39277 .77296 L F
.777 .72 .799 r
.44416 .86964 m .44051 .86955 L .44243 .86697 L F
.523 .305 .525 r
.44416 .86964 m .44173 .87262 L .44051 .86955 L F
.44416 .86964 m .44378 .87236 L .44173 .87262 L F
.757 .794 .883 r
.44463 .86665 m .44416 .86964 L .44243 .86697 L F
.564 .341 .536 r
.44587 .87111 m .44378 .87236 L .44416 .86964 L F
.861 .742 .731 r
.66175 .70702 m .66287 .70948 L .66084 .70902 L F
.82 .66 .685 r
.66287 .70948 m .65964 .71145 L .66084 .70902 L F
.66287 .70948 m .66144 .71227 L .65964 .71145 L F
.457 .628 .927 r
.66439 .70818 m .66287 .70948 L .66175 .70702 L F
.66439 .70818 m .66493 .70956 L .66287 .70948 L F
.693 .548 .684 r
.37726 .86457 m .37947 .86197 L .37714 .8622 L F
.975 .723 .49 r
.5426 .79893 m .54145 .79842 L .54254 .7964 L F
.393 .014 .196 r
.54145 .79842 m .54463 .79598 L .54254 .7964 L F
.517 .202 .372 r
.36726 .79187 m .36644 .79348 L .36443 .79356 L F
.418 .1 .316 r
.36842 .79301 m .36726 .79187 L .36886 .79113 L F
.36842 .79301 m .36644 .79348 L .36726 .79187 L F
.682 .512 .65 r
.4142 .83542 m .41641 .83301 L .41424 .83318 L F
.481 .831 .997 r
.65718 .75168 m .6579 .75231 L .65579 .75275 L F
.65718 .75168 m .65579 .75275 L .65546 .75391 L F
.369 .331 .685 r
.59667 .81994 m .59663 .82196 L .59874 .82199 L F
.352 .095 .377 r
.59874 .82199 m .59663 .82196 L .59642 .82386 L F
.64 .945 .719 r
.6346 .78081 m .63714 .77864 L .63551 .77963 L F
.636 .938 .698 r
.6346 .78081 m .63551 .77963 L .63272 .78206 L F
.402 .856 .875 r
.54622 .842 m .54982 .84133 L .54853 .84288 L F
.469 0 .05 r
.54982 .84133 m .55123 .84292 L .54853 .84288 L F
.489 .016 .058 r
.48347 .82143 m .48729 .82027 L .48501 .8202 L F
.942 .942 .758 r
.48189 .85204 m .48092 .85395 L .47992 .85344 L F
.849 .802 .805 r
.48092 .85395 m .4777 .85414 L .47992 .85344 L F
.48092 .85395 m .47896 .85636 L .4777 .85414 L F
.667 .475 .615 r
.37408 .86971 m .37521 .86963 L .37521 .86727 L F
.658 .523 .688 r
.37521 .86727 m .37758 .86728 L .37726 .86457 L F
.654 .464 .615 r
.37521 .86963 m .37758 .86728 L .37521 .86727 L F
.299 .561 .928 r
.66217 .73027 m .66356 .7296 L .66064 .72951 L F
.66217 .73027 m .66397 .73075 L .66356 .7296 L F
.015 0 0 r
.56873 .77392 m .57245 .77304 L .57031 .77348 L F
.359 0 .191 r
.5799 .76829 m .57739 .76991 L .57957 .76939 L F
.458 .075 .224 r
.57957 .76939 m .58177 .76912 L .5799 .76829 L F
.461 .065 .202 r
.5799 .76829 m .58177 .76912 L .58213 .76808 L F
.964 .757 .575 r
.60415 .75418 m .60275 .75475 L .60315 .75165 L F
.92 .552 .124 r
.60397 .75683 m .60275 .75475 L .60415 .75418 L F
.688 .659 .816 r
.60742 .75248 m .60415 .75418 L .60315 .75165 L F
.718 .478 .562 r
.43136 .82758 m .43426 .82797 L .43456 .82576 L F
.534 .313 .525 r
.43456 .82576 m .43632 .82708 L .43693 .82525 L F
.43456 .82576 m .43426 .82797 L .43632 .82708 L F
.748 .617 .713 r
.58439 .77607 m .58205 .77813 L .5826 .77606 L F
.41 .113 .347 r
.58439 .77607 m .58407 .77791 L .58205 .77813 L F
.58439 .77607 m .58407 .77791 L .58205 .77813 L F
.536 .221 .381 r
.58632 .77742 m .58439 .77607 L .58605 .77591 L F
.58632 .77742 m .58407 .77791 L .58439 .77607 L F
.597 .422 .616 r
.39414 .75483 m .39638 .75483 L .39643 .75153 L F
.557 .567 .819 r
.39594 .75021 m .39643 .75153 L .39847 .75128 L F
.606 .43 .617 r
.39643 .75153 m .39837 .75394 L .39847 .75128 L F
.39643 .75153 m .39638 .75483 L .39837 .75394 L F
.633 .848 .461 r
.64608 .71827 m .64784 .71576 L .64683 .71707 L F
.701 .281 .246 r
.64683 .71707 m .64784 .71576 L .6445 .71523 L F
.646 .388 .514 r
.43805 .86128 m .43613 .86182 L .43622 .85957 L F
.574 .364 .558 r
.61016 .76781 m .61009 .77013 L .60769 .77032 L F
.347 .182 .51 r
.61167 .76705 m .61009 .77013 L .61016 .76781 L F
0 0 0 r
.64527 .71982 m .64608 .71827 L .64683 .71707 L F
.551 .4 .63 r
.40551 .74418 m .40556 .74651 L .40352 .74687 L F
0 .451 .772 r
.36203 .72576 m .36544 .72691 L .36341 .72662 L F
.069 0 0 r
.47262 .87108 m .47189 .87067 L .47038 .87018 L F
.589 .59 .821 r
.52151 .84572 m .51753 .84377 L .51977 .84349 L F
.665 .521 .678 r
.5229 .84161 m .52329 .84402 L .51977 .84349 L F
.712 .597 .726 r
.52329 .84402 m .52151 .84572 L .51977 .84349 L F
.53 .272 .469 r
.40689 .76232 m .40736 .76388 L .40452 .76415 L F
.561 .327 .518 r
.40896 .76204 m .40736 .76388 L .40689 .76232 L F
.788 .71 .778 r
.51117 .83057 m .51392 .8279 L .51271 .82861 L F
.551 .515 .769 r
.51494 .82449 m .51392 .8279 L .51295 .82521 L F
.51494 .82449 m .51591 .82755 L .51392 .8279 L F
.607 .499 .706 r
.51427 .83074 m .51591 .82755 L .51392 .8279 L F
.285 0 0 r
.51591 .82755 m .51271 .82861 L .51392 .8279 L F
.963 .736 .549 r
.51295 .82521 m .51271 .82861 L .51392 .8279 L F
.295 0 0 r
.47262 .88352 m .47407 .88349 L .47609 .88402 L F
.86 .561 .481 r
.55492 .80717 m .55307 .80825 L .55277 .8065 L F
.55492 .80717 m .55549 .80939 L .55307 .80825 L F
.891 .788 .74 r
.68506 .73166 m .68117 .73241 L .68119 .73043 L F
.68506 .73166 m .68316 .73342 L .68117 .73241 L F
.848 .689 .686 r
.68475 .7336 m .68316 .73342 L .68506 .73166 L F
.929 .702 .574 r
.56347 .78184 m .56168 .7817 L .55956 .78186 L F
.56347 .78184 m .5635 .78481 L .56168 .7817 L F
.545 .545 .805 r
.52952 .8643 m .53071 .86754 L .53338 .86706 L F
.504 .338 .589 r
.53338 .86706 m .53071 .86754 L .53277 .86937 L F
.602 .348 .504 r
.41893 .83078 m .42098 .83244 L .42108 .83032 L F
.41893 .83078 m .41865 .83274 L .42098 .83244 L F
.672 .572 .735 r
.68855 .71532 m .68994 .71723 L .69173 .71831 L F
.566 .563 .81 r
.66457 .75927 m .66514 .76159 L .66831 .76077 L F
.897 .629 .12 r
.66457 .75927 m .66479 .76079 L .66514 .76159 L F
.66479 .76079 m .66496 .76197 L .66511 .76165 L F
.66479 .76079 m .66511 .76165 L .66514 .76159 L F
.382 .273 .604 r
.66457 .75927 m .66492 .76169 L .66616 .76047 L F
.66457 .75927 m .66616 .76047 L .66645 .76018 L F
.551 .223 .366 r
.66033 .7593 m .66457 .75927 L .66424 .7602 L F
.35 .576 .925 r
.66349 .75996 m .66424 .7602 L .66412 .76009 L F
.66033 .7593 m .66291 .7599 L .66349 .75996 L F
.66291 .7599 m .66424 .7602 L .66349 .75996 L F
.43 .028 .173 r
.66142 .76129 m .66341 .76105 L .66408 .76002 L F
.66349 .75996 m .66408 .76002 L .66457 .75927 L F
.66142 .76129 m .66408 .76002 L .66349 .75996 L F
.66142 .76129 m .66349 .75996 L .66033 .7593 L F
.66349 .75996 m .66457 .75927 L .66033 .7593 L F
.35 .576 .925 r
.66033 .7593 m .66412 .76009 L .66186 .75797 L F
.564 .88 .601 r
.66389 .7627 m .66371 .76299 L .66514 .76159 L F
.66237 .76406 m .66315 .76343 L .66389 .7627 L F
.66315 .76343 m .66371 .76299 L .66389 .7627 L F
.66237 .76406 m .66514 .76159 L .66496 .76197 L F
.935 .658 .492 r
.66386 .76132 m .66496 .76197 L .66479 .76079 L F
.66424 .7602 m .66479 .76079 L .66457 .75927 L F
.66386 .76132 m .66479 .76079 L .66424 .7602 L F
.66408 .76002 m .66424 .7602 L .66457 .75927 L F
.551 .223 .366 r
.66424 .7602 m .66457 .75927 L .6655 .76049 L F
.508 .109 .219 r
.66619 .76005 m .66563 .76023 L .66624 .76031 L F
.66457 .75927 m .66555 .76015 L .66619 .76005 L F
.66555 .76015 m .66563 .76023 L .66619 .76005 L F
.682 .618 .778 r
.66186 .75797 m .66327 .75895 L .66584 .75814 L F
.161 .135 .578 r
.6655 .76049 m .66457 .75927 L .66555 .76015 L F
.508 .109 .219 r
.66457 .75927 m .66408 .76002 L .66563 .76023 L F
.682 .618 .778 r
.66327 .75895 m .66511 .76022 L .66529 .75971 L F
.566 .563 .81 r
.66457 .75927 m .66831 .76077 L .66761 .76059 L F
.66457 .75927 m .66761 .76059 L .66619 .76005 L F
.277 .327 .734 r
.66584 .75814 m .66457 .75927 L .66657 .76023 L F
.161 .135 .578 r
.66555 .76015 m .66457 .75927 L .66568 .75828 L F
.682 .618 .778 r
.66327 .75895 m .66529 .75971 L .66584 .75814 L F
.712 .554 .673 r
.66783 .76097 m .66655 .76032 L .66657 .76023 L F
.566 .563 .81 r
.66619 .76005 m .66761 .76059 L .6672 .76048 L F
.66619 .76005 m .6672 .76048 L .66657 .76023 L F
.712 .554 .673 r
.66759 .76063 m .66657 .76023 L .66676 .75945 L F
.66783 .76097 m .66657 .76023 L .66759 .76063 L F
.566 .563 .81 r
.66657 .76023 m .6672 .76048 L .66691 .7604 L F
.161 .135 .578 r
.66555 .76015 m .66568 .75828 L .66573 .75892 L F
.66573 .75892 m .66568 .75828 L .66584 .75814 L F
.682 .618 .778 r
.66511 .76022 m .66555 .76015 L .66584 .75814 L F
.712 .554 .673 r
.66657 .76023 m .66186 .75797 L .66676 .75945 L F
.382 .273 .604 r
.66645 .76018 m .66644 .76078 L .66655 .76032 L F
.66655 .76023 m .66655 .76032 L .66657 .76023 L F
.66645 .76018 m .66655 .76032 L .66655 .76023 L F
.712 .554 .673 r
.66655 .76032 m .66341 .76105 L .66642 .76026 L F
.66783 .76097 m .66651 .76099 L .66655 .76032 L F
.382 .273 .604 r
.66645 .76018 m .66496 .76197 L .66644 .76078 L F
.66492 .76169 m .66496 .76197 L .66645 .76018 L F
.669 .815 .954 r
.66341 .76105 m .66496 .76197 L .66652 .76071 L F
.712 .554 .673 r
.66652 .76071 m .66341 .76105 L .66655 .76032 L F
.382 .273 .604 r
.66657 .76023 m .66644 .76078 L .66691 .7604 L F
.669 .815 .954 r
.66341 .76105 m .66652 .76071 L .66691 .7604 L F
.712 .554 .673 r
.66651 .76099 m .66341 .76105 L .66652 .76071 L F
.66655 .76032 m .66642 .76026 L .66657 .76023 L F
.508 .109 .219 r
.66619 .76005 m .66624 .76029 L .66655 .76023 L F
.712 .554 .673 r
.66642 .76026 m .66186 .75797 L .66657 .76023 L F
.508 .109 .219 r
.66624 .76029 m .66624 .76031 L .66642 .76026 L F
.66624 .76029 m .66642 .76026 L .66655 .76023 L F
.277 .327 .734 r
.66584 .75814 m .66657 .76023 L .66691 .7604 L F
.712 .554 .673 r
.66676 .75945 m .66624 .75929 L .66584 .75814 L F
.66624 .75929 m .66186 .75797 L .66584 .75814 L F
.682 .618 .778 r
.66511 .76022 m .6655 .76049 L .66555 .76015 L F
.35 .576 .925 r
.6646 .76028 m .66453 .76011 L .66437 .76008 L F
.935 .658 .492 r
.66341 .76105 m .66386 .76132 L .66424 .7602 L F
.66341 .76105 m .66424 .7602 L .66408 .76002 L F
.508 .109 .219 r
.66408 .76002 m .66341 .76105 L .66646 .76048 L F
.66408 .76002 m .66646 .76048 L .66691 .7604 L F
.35 .576 .925 r
.66437 .76008 m .66439 .75972 L .66274 .75858 L F
.66453 .76011 m .66439 .75972 L .66437 .76008 L F
.66332 .7592 m .66274 .75858 L .66186 .75797 L F
.6646 .76028 m .66274 .75858 L .66332 .7592 L F
.66424 .7602 m .6646 .76028 L .66332 .7592 L F
.66424 .7602 m .66332 .7592 L .66186 .75797 L F
.6646 .76028 m .6655 .76049 L .66439 .75972 L F
.712 .554 .673 r
.6658 .75995 m .66341 .76105 L .66186 .75797 L F
.66642 .76026 m .66584 .76041 L .6658 .75995 L F
.66584 .76041 m .66341 .76105 L .6658 .75995 L F
.508 .109 .219 r
.66655 .76023 m .66624 .76031 L .66691 .7604 L F
.434 .554 .877 r
.56904 .80617 m .56924 .80768 L .56736 .80492 L F
0 .13 .675 r
.56904 .80617 m .57051 .80916 L .56924 .80768 L F
.671 .961 .938 r
.58017 .83576 m .57938 .83638 L .5785 .83676 L F
.685 .935 .64 r
.57938 .83638 m .58085 .83523 L .57845 .8379 L F
0 0 0 r
.5822 .83499 m .58085 .83523 L .57938 .83638 L F
.407 .687 .976 r
.58614 .83556 m .58291 .83449 L .58517 .83335 L F
0 0 0 r
.58517 .83335 m .58291 .83449 L .5822 .83499 L F
.58517 .83335 m .5822 .83499 L .58245 .83451 L F
.58491 .8331 m .58245 .83451 L .5838 .83201 L F
.58517 .83335 m .58245 .83451 L .58491 .8331 L F
.58291 .83449 m .58085 .83523 L .5822 .83499 L F
.5838 .83201 m .58245 .83451 L .58291 .83386 L F
.685 .935 .64 r
.57938 .83638 m .57812 .83734 L .57725 .83583 L F
.198 0 0 r
.57938 .83638 m .57725 .83583 L .5758 .83551 L F
.57938 .83638 m .5758 .83551 L .5785 .83676 L F
.784 .758 .83 r
.5797 .83331 m .58273 .83418 L .5785 .83676 L F
.083 .124 .606 r
.58315 .83352 m .5822 .83499 L .58279 .8342 L F
.784 .758 .83 r
.58273 .83418 m .58279 .8342 L .58269 .83426 L F
.58273 .83418 m .58269 .83426 L .5785 .83676 L F
0 0 0 r
.58332 .83314 m .58291 .83386 L .58315 .83352 L F
.5838 .83201 m .58291 .83386 L .58332 .83314 L F
.58245 .83451 m .5822 .83499 L .58263 .83432 L F
.58245 .83451 m .58263 .83432 L .58315 .83352 L F
.671 .961 .938 r
.58269 .83426 m .58079 .83548 L .58017 .83576 L F
.58279 .8342 m .58268 .83426 L .58269 .83426 L F
.58268 .83426 m .58079 .83548 L .58269 .83426 L F
.58079 .83548 m .57938 .83638 L .57982 .83603 L F
.58079 .83548 m .57982 .83603 L .58017 .83576 L F
.685 .935 .64 r
.57938 .83638 m .57845 .8379 L .57812 .83734 L F
.681 .727 .885 r
.68198 .71018 m .68307 .70727 L .68062 .70792 L F
.68198 .71018 m .68438 .70949 L .68307 .70727 L F
.23 .734 .899 r
.46304 .86444 m .46407 .8647 L .46201 .86483 L F
.351 .774 .975 r
.4653 .8826 m .4687 .88293 L .46744 .88261 L F
0 .516 .769 r
.4687 .88293 m .46952 .88296 L .46744 .88261 L F
.4687 .88293 m .47065 .88327 L .46952 .88296 L F
.659 .531 .697 r
.40253 .84135 m .40398 .83819 L .40161 .83836 L F
.8 .53 0 r
.55075 .82197 m .55057 .82006 L .54955 .81928 L F
.55075 .82197 m .55092 .82189 L .55057 .82006 L F
.582 .377 .569 r
.40921 .83584 m .41117 .83757 L .41132 .83572 L F
.40921 .83584 m .40913 .83808 L .41117 .83757 L F
.755 .945 .943 r
.45975 .88534 m .46369 .8836 L .46231 .88331 L F
.705 .94 .96 r
.46231 .88331 m .46369 .8836 L .4653 .8826 L F
.718 .494 .585 r
.4569 .84941 m .45318 .85108 L .45335 .84884 L F
.705 .466 .56 r
.4569 .84941 m .45525 .85349 L .45318 .85108 L F
.601 .436 .631 r
.45833 .84885 m .45856 .85092 L .4569 .84941 L F
.661 .417 .541 r
.45886 .85329 m .4569 .84941 L .45856 .85092 L F
.45886 .85329 m .45525 .85349 L .4569 .84941 L F
0 0 .371 r
.55387 .83583 m .55494 .83256 L .55549 .83481 L F
.028 .083 .585 r
.55554 .83732 m .55387 .83583 L .55549 .83481 L F
.55554 .83732 m .5548 .83837 L .55387 .83583 L F
.719 .898 .96 r
.46905 .8377 m .47231 .8371 L .4712 .83735 L F
.063 0 0 r
.47503 .83758 m .4712 .83735 L .47231 .8371 L F
.921 .955 .626 r
.67991 .70647 m .68121 .70508 L .68034 .70705 L F
.752 .385 0 r
.67991 .70647 m .68062 .70792 L .68034 .70705 L F
.944 .925 .758 r
.55378 .843 m .55537 .8412 L .55477 .83955 L F
.419 .434 .77 r
.68855 .71532 m .6902 .71402 L .6872 .71287 L F
.68855 .71532 m .69023 .71541 L .6902 .71402 L F
.41 .466 .807 r
.68855 .71532 m .69186 .71733 L .69023 .71541 L F
.672 .572 .735 r
.68855 .71532 m .69173 .71831 L .69186 .71733 L F
.77 .672 .755 r
.45533 .8464 m .45335 .84884 L .45222 .8462 L F
.717 .506 .604 r
.59767 .7731 m .59695 .77525 L .595 .77522 L F
.731 .567 .67 r
.60031 .77302 m .59695 .77525 L .59767 .7731 L F
.795 .777 .836 r
.63308 .76674 m .63448 .76775 L .63174 .76793 L F
.824 .851 .868 r
.63556 .76458 m .63448 .76775 L .63308 .76674 L F
.756 .618 .705 r
.6136 .73623 m .61454 .7395 L .61159 .7389 L F
.32 .345 .731 r
.61503 .73903 m .61454 .7395 L .61415 .73812 L F
.61465 .73829 m .61415 .73812 L .6136 .73623 L F
.61503 .73903 m .61415 .73812 L .61465 .73829 L F
.723 .419 .464 r
.61053 .74037 m .61467 .7383 L .61159 .7389 L F
.61467 .7383 m .61471 .73828 L .61465 .73829 L F
.61467 .7383 m .61465 .73829 L .61159 .7389 L F
.687 .518 .653 r
.61159 .7389 m .61465 .73829 L .6136 .73623 L F
.61465 .73829 m .61471 .73828 L .6136 .73623 L F
.303 .364 .76 r
.61471 .73828 m .61472 .73783 L .6136 .73623 L F
.61471 .73828 m .61595 .73816 L .61472 .73783 L F
.669 .488 .632 r
.6147 .73834 m .61595 .73816 L .61471 .73828 L F
.32 .345 .731 r
.61595 .73816 m .61535 .73873 L .61504 .73829 L F
.744 .542 .621 r
.61454 .7395 m .61692 .74199 L .61775 .74157 L F
.924 .804 .709 r
.61595 .73816 m .61692 .74199 L .61454 .7395 L F
.669 .488 .632 r
.61445 .74104 m .61595 .73816 L .6147 .73834 L F
.32 .345 .731 r
.61595 .73816 m .61504 .73829 L .61472 .73783 L F
.61595 .73816 m .61472 .73783 L .6136 .73623 L F
.666 .967 .919 r
.61575 .73446 m .6136 .73623 L .61475 .73487 L F
.303 .364 .76 r
.61472 .73783 m .61595 .73816 L .61475 .73487 L F
.61472 .73783 m .61475 .73487 L .6136 .73623 L F
.723 .419 .464 r
.61053 .74037 m .61445 .74104 L .6147 .73834 L F
.61467 .7383 m .6147 .73834 L .61471 .73828 L F
.61053 .74037 m .6147 .73834 L .61467 .7383 L F
.32 .345 .731 r
.61535 .73873 m .61517 .7389 L .6136 .73623 L F
.61517 .7389 m .61503 .73903 L .61463 .73825 L F
.61517 .7389 m .61463 .73825 L .6136 .73623 L F
.435 .823 .987 r
.66939 .73063 m .67285 .7307 L .66957 .73002 L F
.551 .345 .555 r
.4155 .75205 m .41756 .75174 L .41792 .74948 L F
.41792 .74948 m .41756 .75174 L .4155 .75205 L F
.414 .224 .512 r
.41973 .74679 m .41792 .74948 L .41953 .74895 L F
.563 .356 .558 r
.41792 .74948 m .41993 .75103 L .41953 .74895 L F
.41792 .74948 m .41756 .75174 L .41993 .75103 L F
.414 .224 .512 r
.41973 .74679 m .41792 .74948 L .41953 .74895 L F
.563 .356 .558 r
.41792 .74948 m .41993 .75103 L .41953 .74895 L F
.41792 .74948 m .41756 .75174 L .41993 .75103 L F
.539 .892 .978 r
.36034 .72611 m .3583 .72674 L .35674 .72647 L F
.651 .486 .647 r
.37726 .86457 m .37954 .86427 L .37947 .86197 L F
.662 .515 .673 r
.37954 .86427 m .38156 .86171 L .37947 .86197 L F
.614 .438 .621 r
.42077 .82756 m .42377 .83005 L .42428 .82755 L F
.42077 .82756 m .42108 .83032 L .42377 .83005 L F
.652 .695 .877 r
.68686 .72924 m .6866 .73135 L .68548 .72816 L F
.649 .154 0 r
.68496 .72721 m .68686 .72924 L .68548 .72816 L F
.68496 .72721 m .68519 .72749 L .68686 .72924 L F
.652 .695 .877 r
.68686 .72924 m .68829 .73076 L .6866 .73135 L F
.649 .154 0 r
.68519 .72749 m .68715 .72988 L .68686 .72924 L F
.652 .695 .877 r
.68686 .72924 m .6886 .73065 L .68829 .73076 L F
.981 .761 .351 r
.69306 .73856 m .69311 .73633 L .69253 .73565 L F
.672 .193 .107 r
.48624 .84526 m .4895 .84579 L .48753 .84439 L F
.67 .501 .648 r
.39103 .85396 m .39331 .85136 L .39098 .85158 L F
.094 0 0 r
.51666 .83965 m .51726 .84008 L .51861 .83886 L F
.51666 .83965 m .51527 .84054 L .51726 .84008 L F
.617 .929 .692 r
.48275 .85124 m .48189 .85204 L .47992 .85344 L F
.48325 .85085 m .4827 .85133 L .48275 .85124 L F
.4827 .85133 m .48189 .85204 L .48275 .85124 L F
.48325 .85085 m .47992 .85344 L .48178 .85292 L F
.318 0 .071 r
.48178 .85292 m .48326 .85176 L .48325 .85085 L F
.882 .521 .037 r
.48325 .85085 m .48326 .85176 L .48206 .84845 L F
0 0 .501 r
.48317 .85045 m .48326 .85176 L .48333 .85072 L F
.48206 .84845 m .48294 .85088 L .48317 .85045 L F
.48294 .85088 m .48326 .85176 L .48317 .85045 L F
.811 .792 .834 r
.4777 .85414 m .47896 .85636 L .47584 .85657 L F
.747 .662 .766 r
.45335 .84884 m .44994 .84874 L .45222 .8462 L F
.733 .527 .613 r
.45318 .85108 m .44994 .84874 L .45335 .84884 L F
.947 .694 .522 r
.67263 .7406 m .67185 .74344 L .67243 .74104 L F
.67263 .7406 m .67343 .74455 L .67185 .74344 L F
.71 .879 .96 r
.57042 .84924 m .57218 .84799 L .56945 .84787 L F
.517 .328 .564 r
.40737 .89082 m .40719 .89288 L .40544 .89309 L F
0 0 0 r
.40525 .89339 m .40544 .89309 L .40719 .89288 L F
.40525 .89339 m .40396 .89477 L .40544 .89309 L F
.811 .458 .389 r
.45727 .86194 m .45784 .86358 L .45923 .86204 L F
.796 .436 .376 r
.45784 .86358 m .46063 .86449 L .45923 .86204 L F
.9 .974 .811 r
.63157 .73553 m .6296 .73801 L .63118 .73724 L F
.32 0 .15 r
.56955 .78449 m .56743 .78587 L .56911 .78548 L F
.527 .562 .834 r
.56829 .7805 m .56955 .78449 L .57156 .78306 L F
0 0 0 r
.56955 .78449 m .56911 .78548 L .57156 .78306 L F
.77 .362 .278 r
.52269 .83058 m .52197 .83233 L .52002 .83211 L F
.52269 .83058 m .5247 .83299 L .52197 .83233 L F
.981 .77 .359 r
.52488 .83042 m .5247 .83299 L .52269 .83058 L F
.874 .749 .722 r
.68485 .73589 m .68579 .73897 L .68485 .73829 L F
.998 .792 .491 r
.68579 .73897 m .68484 .74055 L .68485 .73829 L F
.68579 .73897 m .68565 .74128 L .68484 .74055 L F
.244 0 0 r
.41522 .75177 m .41756 .75174 L .4155 .75205 L F
.61 .441 .628 r
.41771 .75387 m .4155 .75205 L .41756 .75174 L F
.41771 .75387 m .41555 .75423 L .4155 .75205 L F
.743 .993 .853 r
.63842 .77747 m .6379 .77723 L .63714 .77864 L F
.746 .982 .747 r
.63714 .77864 m .6379 .77723 L .63551 .77963 L F
.741 .744 .854 r
.69952 .74487 m .70085 .74682 L .69755 .74641 L F
.813 .549 .539 r
.70085 .74682 m .69789 .74848 L .69755 .74641 L F
.70085 .74682 m .70079 .74891 L .69789 .74848 L F
.575 .677 .91 r
.70292 .74635 m .70085 .74682 L .69952 .74487 L F
.495 .284 .522 r
.70292 .74635 m .70079 .74891 L .70085 .74682 L F
.964 .904 .712 r
.56414 .83266 m .56388 .83545 L .56426 .83511 L F
0 0 .283 r
.56388 .83545 m .56456 .8372 L .56426 .83511 L F
.56388 .83545 m .56453 .83805 L .56456 .8372 L F
.997 .782 .432 r
.55389 .82954 m .5547 .82795 L .55366 .82737 L F
.55389 .82954 m .55459 .83035 L .5547 .82795 L F
.504 .26 .479 r
.57478 .78358 m .57687 .78326 L .57695 .78082 L F
.57695 .78082 m .57687 .78326 L .57478 .78358 L F
.437 .208 .467 r
.57886 .78244 m .57687 .78326 L .57695 .78082 L F
.618 .527 .73 r
.57635 .7784 m .57695 .78082 L .5788 .7785 L F
.437 .208 .467 r
.57886 .78244 m .57687 .78326 L .57695 .78082 L F
.695 .836 .951 r
.43323 .88573 m .43652 .88583 L .43535 .88496 L F
.408 .731 .991 r
.43535 .88496 m .43652 .88583 L .43732 .8849 L F
.425 .756 .995 r
.43652 .88583 m .43864 .88572 L .43732 .8849 L F
.217 .727 .889 r
.44391 .88514 m .44729 .88526 L .44598 .88469 L F
.506 .825 1 r
.44729 .88526 m .44798 .8842 L .44598 .88469 L F
.44729 .88526 m .44938 .88488 L .44798 .8842 L F
.629 .901 .985 r
.43864 .88572 m .44191 .88534 L .44064 .88503 L F
.304 .773 .938 r
.44064 .88503 m .44191 .88534 L .44391 .88514 L F
.127 .289 .76 r
.4854 .85584 m .48296 .85454 L .48547 .85343 L F
.4854 .85584 m .48438 .8566 L .48296 .85454 L F
.556 .201 .322 r
.66766 .74811 m .66768 .74685 L .6653 .74693 L F
.6653 .74693 m .66768 .74685 L .66766 .74811 L F
.66766 .74811 m .66768 .74685 L .6653 .74693 L F
.592 .633 .861 r
.3742 .7282 m .37219 .72864 L .37041 .72603 L F
.813 .742 .785 r
.5141 .81556 m .5104 .81585 L .51262 .81517 L F
.5141 .81556 m .51116 .81886 L .5104 .81585 L F
.4 .818 .972 r
.5141 .81556 m .51489 .81489 L .51605 .81474 L F
.5141 .81556 m .51262 .81517 L .51489 .81489 L F
.668 .335 .402 r
.66374 .71549 m .66069 .71721 L .66125 .71497 L F
.66374 .71549 m .6642 .71736 L .66069 .71721 L F
.773 .403 .355 r
.66374 .71549 m .66542 .7176 L .6642 .71736 L F
.855 .997 .787 r
.61677 .78618 m .61462 .78876 L .61474 .78748 L F
.836 .847 .384 r
.61474 .78748 m .61462 .78876 L .6139 .79064 L F
0 0 0 r
.48094 .84802 m .47995 .8483 L .48206 .84845 L F
.48094 .84802 m .47883 .84906 L .47995 .8483 L F
.657 .281 .321 r
.39077 .7558 m .39336 .75631 L .39414 .75483 L F
.509 .111 .221 r
.39569 .75612 m .39414 .75483 L .39336 .75631 L F
.39569 .75612 m .39638 .75483 L .39414 .75483 L F
.712 .337 .337 r
.46931 .84865 m .46802 .85063 L .46815 .8481 L F
.46931 .84865 m .47151 .85093 L .46802 .85063 L F
0 0 0 r
.48386 .86657 m .48598 .86458 L .48672 .86588 L F
.36 .812 .686 r
.48744 .8638 m .48598 .86458 L .48645 .86425 L F
.108 0 .381 r
.48672 .86588 m .48598 .86458 L .48744 .8638 L F
.351 0 .215 r
.38509 .76458 m .38687 .76458 L .38778 .76262 L F
.361 .006 .221 r
.38778 .76262 m .38844 .76406 L .38982 .7622 L F
.38778 .76262 m .38687 .76458 L .38844 .76406 L F
.826 .501 .439 r
.48315 .84576 m .48476 .84465 L .48141 .84287 L F
.48315 .84576 m .48427 .84594 L .48476 .84465 L F
.202 0 0 r
.69173 .71831 m .69156 .71853 L .69186 .71733 L F
.69173 .71831 m .69399 .71869 L .69156 .71853 L F
.68 .601 .76 r
.69925 .7153 m .69738 .71636 L .69671 .71556 L F
.722 .366 .374 r
.37688 .74878 m .37526 .7503 L .37361 .74871 L F
0 .297 .76 r
.37688 .74878 m .37901 .75013 L .37774 .74906 L F
.215 0 0 r
.37699 .74984 m .37688 .74878 L .37774 .74906 L F
.37699 .74984 m .37526 .7503 L .37688 .74878 L F
.709 .764 .895 r
.50839 .83013 m .51117 .83057 L .50943 .82782 L F
.668 .747 .909 r
.50943 .82782 m .51117 .83057 L .51271 .82861 L F
.66 .496 .651 r
.39331 .85136 m .39625 .85157 L .39548 .84887 L F
.672 .531 .684 r
.39548 .84887 m .39839 .84892 L .39756 .84601 L F
.701 .546 .673 r
.39625 .85157 m .39839 .84892 L .39548 .84887 L F
0 0 0 r
.6266 .79031 m .62779 .78848 L .62792 .78865 L F
.652 .921 .628 r
.62779 .78848 m .62845 .78753 L .62792 .78865 L F
.62779 .78848 m .62995 .78602 L .62845 .78753 L F
.659 .262 .281 r
.65898 .72838 m .66064 .72951 L .66056 .7295 L F
.388 .347 .692 r
.49259 .82358 m .49129 .82593 L .4903 .82474 L F
.676 .215 .15 r
.49129 .82593 m .49428 .82824 L .49545 .8273 L F
.388 .347 .692 r
.49259 .82358 m .49428 .82824 L .49129 .82593 L F
.688 .602 .754 r
.39075 .75001 m .3905 .75163 L .3928 .74927 L F
.821 .34 0 r
.54254 .81232 m .54362 .8139 L .54445 .81416 L F
.691 .164 0 r
.54456 .81474 m .54445 .81416 L .54362 .8139 L F
.54456 .81474 m .54563 .81536 L .54445 .81416 L F
.64 .655 .849 r
.6799 .7169 m .68345 .71774 L .68112 .71848 L F
.581 .33 .501 r
.40736 .76388 m .40363 .76707 L .40452 .76415 L F
.301 0 0 r
.47922 .8834 m .48202 .88399 L .48162 .88396 L F
.2 .683 .929 r
.48202 .88399 m .48486 .88385 L .48162 .88396 L F
.48202 .88399 m .48459 .88427 L .48486 .88385 L F
.671 .521 .673 r
.39756 .84601 m .40052 .84631 L .39987 .84343 L F
.673 .528 .679 r
.39987 .84343 m .40261 .84365 L .40253 .84135 L F
.673 .523 .673 r
.40052 .84631 m .40261 .84365 L .39987 .84343 L F
.443 .183 .424 r
.36159 .79623 m .36166 .79877 L .35984 .79849 L F
.376 .134 .415 r
.3633 .79812 m .36159 .79623 L .36276 .79558 L F
.3633 .79812 m .36166 .79877 L .36159 .79623 L F
.545 .445 .691 r
.61775 .74157 m .61967 .74123 L .6192 .73844 L F
.546 .447 .693 r
.61775 .74157 m .62032 .74369 L .61967 .74123 L F
.568 .446 .673 r
.61814 .74407 m .62032 .74369 L .61775 .74157 L F
.266 .771 .763 r
.50713 .87976 m .50616 .88016 L .5082 .87957 L F
.241 .742 .9 r
.50501 .87992 m .50616 .88016 L .50713 .87976 L F
.618 .404 .569 r
.60283 .77302 m .60027 .77545 L .60031 .77302 L F
.60283 .77302 m .60278 .7754 L .60027 .77545 L F
.535 .31 .519 r
.60573 .77248 m .60278 .7754 L .60283 .77302 L F
.545 .545 .805 r
.52952 .8643 m .53338 .86706 L .5328 .8646 L F
.791 .299 .025 r
.536 .86727 m .5328 .8646 L .53338 .86706 L F
.762 .683 .775 r
.52702 .84078 m .52823 .84365 L .52497 .84339 L F
.497 .368 .635 r
.52705 .84543 m .52497 .84339 L .52823 .84365 L F
.583 .563 .797 r
.5292 .84039 m .52823 .84365 L .52702 .84078 L F
.5292 .84039 m .53033 .84334 L .52823 .84365 L F
.657 .352 .444 r
.53033 .84334 m .52705 .84543 L .52823 .84365 L F
.706 .587 .72 r
.37758 .86728 m .37954 .86427 L .37726 .86457 L F
.67 .53 .685 r
.39839 .84892 m .40052 .84631 L .39756 .84601 L F
.792 .661 .719 r
.57635 .7784 m .57483 .77828 L .5735 .77798 L F
.483 .83 .997 r
.57635 .7784 m .57752 .77741 L .57483 .77828 L F
.437 .744 .992 r
.57635 .7784 m .5788 .7785 L .57752 .77741 L F
.055 0 .031 r
.69087 .72585 m .69263 .72519 L .69321 .72374 L F
.152 0 .263 r
.69205 .72695 m .69087 .72585 L .69064 .72753 L F
.69205 .72695 m .69263 .72519 L .69087 .72585 L F
.651 .432 .573 r
.60744 .77207 m .60615 .77032 L .60769 .77032 L F
.619 .532 .734 r
.60312 .74937 m .60555 .74927 L .60415 .74605 L F
.596 .359 .528 r
.60312 .74937 m .6053 .75129 L .60555 .74927 L F
.60312 .74937 m .6053 .75129 L .60555 .74927 L F
.607 .391 .563 r
.61009 .77013 m .60744 .77207 L .60769 .77032 L F
.118 .287 .761 r
.68208 .70396 m .68262 .70502 L .68121 .70508 L F
0 .033 .56 r
.68229 .70589 m .68121 .70508 L .67991 .70647 L F
.68229 .70589 m .68208 .70396 L .68121 .70508 L F
.651 .432 .573 r
.60744 .77207 m .60573 .77248 L .60615 .77032 L F
.841 .393 .151 r
.67678 .73523 m .6794 .73777 L .67763 .73554 L F
.499 .283 .517 r
.53802 .86584 m .53799 .86464 L .536 .86727 L F
.549 .322 .523 r
.54051 .86455 m .53799 .86464 L .53802 .86584 L F
.53802 .86584 m .53799 .86464 L .54051 .86455 L F
.628 .495 .681 r
.52497 .84339 m .5229 .84161 L .52374 .83966 L F
.626 .486 .672 r
.52678 .83833 m .52702 .84078 L .52374 .83966 L F
.627 .484 .669 r
.52702 .84078 m .52497 .84339 L .52374 .83966 L F
.612 .749 .943 r
.45703 .88555 m .45975 .88534 L .45875 .88482 L F
.45703 .88555 m .45875 .88482 L .45789 .88534 L F
.7 .612 .755 r
.63698 .71769 m .63746 .72099 L .63507 .72065 L F
.63698 .71769 m .63507 .72065 L .63432 .72023 L F
.92 .641 .496 r
.63637 .71983 m .63473 .72015 L .6343 .72177 L F
.63473 .72015 m .63432 .72023 L .63432 .72051 L F
.82 .883 .89 r
.63507 .72065 m .63262 .72198 L .63432 .72023 L F
.92 .641 .496 r
.63473 .72015 m .63432 .72051 L .6343 .72177 L F
.82 .883 .89 r
.63507 .72065 m .63279 .72303 L .63263 .722 L F
.6327 .72194 m .63263 .722 L .63262 .72198 L F
.63507 .72065 m .63263 .722 L .6327 .72194 L F
.435 .526 .852 r
.60231 .74464 m .60415 .74605 L .60422 .74392 L F
.795 .665 .72 r
.67829 .71665 m .67453 .71763 L .67619 .71538 L F
.773 .321 .175 r
.67619 .71538 m .6799 .7169 L .67829 .71665 L F
.164 .33 .785 r
.66493 .70956 m .66717 .71146 L .66618 .71245 L F
.209 .404 .836 r
.66717 .71146 m .66903 .71447 L .66618 .71245 L F
.461 .467 .778 r
.66612 .75362 m .66462 .75554 L .66334 .75163 L F
.645 .736 .916 r
.66612 .75362 m .66694 .75492 L .66462 .75554 L F
.609 .31 .436 r
.42591 .82998 m .42925 .82722 L .42623 .828 L F
.42591 .82998 m .42813 .82989 L .42925 .82722 L F
.617 .318 .44 r
.42925 .82722 m .43116 .82939 L .43136 .82758 L F
.42925 .82722 m .42813 .82989 L .43116 .82939 L F
.611 .783 .964 r
.4011 .73906 m .39912 .73959 L .39781 .73852 L F
.839 .794 .298 r
.61734 .78297 m .61677 .78618 L .61686 .78449 L F
.902 .983 .783 r
.61677 .78618 m .61474 .78748 L .61686 .78449 L F
.802 .692 .743 r
.56168 .7817 m .5635 .78481 L .56608 .78238 L F
.56168 .7817 m .56608 .78238 L .56488 .78226 L F
.202 0 0 r
.56829 .7805 m .56488 .78226 L .56608 .78238 L F
.341 .133 .445 r
.61741 .80603 m .61562 .80691 L .61752 .80417 L F
.319 .093 .406 r
.61516 .80921 m .61562 .80691 L .61741 .80603 L F
.831 .571 .545 r
.68475 .7336 m .6832 .73561 L .68316 .73342 L F
.68475 .7336 m .68485 .73589 L .6832 .73561 L F
.33 0 .121 r
.52036 .81999 m .51733 .82252 L .51733 .82002 L F
.52036 .81999 m .51991 .82219 L .51733 .82252 L F
.762 .325 .213 r
.52253 .82207 m .52019 .82218 L .52036 .81999 L F
.52019 .82218 m .52019 .82218 L .52019 .82218 L F
.52019 .82218 m .52019 .82218 L .52036 .81999 L F
.841 .822 .83 r
.52043 .82066 m .51994 .82249 L .52132 .82151 L F
.731 .663 .783 r
.52068 .82325 m .51856 .82465 L .51733 .82252 L F
.52068 .82325 m .51733 .82252 L .51972 .82221 L F
.51997 .82228 m .51972 .82221 L .51991 .82219 L F
.52068 .82325 m .51972 .82221 L .51997 .82228 L F
.777 .931 .934 r
.52019 .82218 m .52068 .82325 L .52256 .82211 L F
.51991 .82219 m .51997 .82228 L .52019 .82218 L F
.51997 .82228 m .52068 .82325 L .52019 .82218 L F
.769 .651 .732 r
.52073 .82236 m .52183 .82274 L .52138 .82165 L F
.52115 .82175 m .52138 .82165 L .52132 .82151 L F
.52073 .82236 m .52138 .82165 L .52115 .82175 L F
.52066 .82245 m .52183 .82274 L .52073 .82236 L F
.51951 .82411 m .52181 .82275 L .52066 .82245 L F
.52181 .82275 m .52183 .82274 L .52066 .82245 L F
.841 .822 .83 r
.51994 .82249 m .51951 .82411 L .52073 .82236 L F
.51994 .82249 m .52073 .82236 L .52132 .82151 L F
.762 .325 .213 r
.52256 .82211 m .52228 .82211 L .52253 .82207 L F
.52228 .82211 m .52019 .82218 L .52253 .82207 L F
.227 .405 .831 r
.5225 .82437 m .52068 .82325 L .52256 .82211 L F
.769 .651 .732 r
.51951 .82411 m .5225 .82437 L .52183 .82274 L F
.612 .399 .568 r
.52271 .81988 m .52256 .82211 L .52036 .81999 L F
.543 .41 .65 r
.52424 .81941 m .52256 .82211 L .52271 .81988 L F
.52424 .81941 m .52459 .82178 L .52256 .82211 L F
.51 .291 .517 r
.52459 .82178 m .5225 .82437 L .52256 .82211 L F
.769 .651 .732 r
.52132 .82151 m .52183 .82274 L .52459 .82178 L F
.52183 .82274 m .5225 .82437 L .52339 .82327 L F
.52183 .82274 m .52339 .82327 L .52459 .82178 L F
.762 .325 .213 r
.52019 .82218 m .51991 .82219 L .51993 .82209 L F
.52019 .82218 m .51993 .82209 L .52036 .81999 L F
.649 .126 0 r
.53793 .81027 m .53747 .80956 L .53621 .8092 L F
.53793 .81027 m .53954 .81174 L .53747 .80956 L F
.712 .421 .482 r
.53747 .80956 m .53954 .81174 L .53959 .81 L F
.751 .539 .608 r
.54683 .7936 m .54978 .79608 L .55002 .79366 L F
.436 .194 .447 r
.54978 .79608 m .55214 .79347 L .55002 .79366 L F
.568 .302 .472 r
.37303 .7888 m .37067 .79063 L .37124 .78849 L F
.656 .654 .836 r
.69884 .71448 m .69671 .71556 L .69505 .71186 L F
.68 .601 .76 r
.69925 .7153 m .69671 .71556 L .69884 .71448 L F
.636 .57 .764 r
.38953 .73504 m .38723 .73584 L .38658 .73282 L F
.187 0 0 r
.46449 .84977 m .46068 .85086 L .46084 .84928 L F
.46449 .84977 m .46266 .85068 L .46068 .85086 L F
.743 .494 .554 r
.46599 .8486 m .46266 .85068 L .46449 .84977 L F
.714 .46 .539 r
.6694 .73115 m .66852 .73316 L .66726 .73115 L F
.861 .626 .091 r
.66904 .73612 m .66852 .73316 L .6694 .73115 L F
.577 .354 .541 r
.43632 .82708 m .43889 .82509 L .43693 .82525 L F
.623 .401 .559 r
.52919 .83577 m .52907 .83811 L .52678 .83833 L F
.562 .35 .551 r
.53124 .83775 m .52907 .83811 L .52919 .83577 L F
.577 .349 .534 r
.53135 .83596 m .53124 .83775 L .52919 .83577 L F
.753 .596 .682 r
.4758 .85934 m .47167 .8595 L .47362 .85672 L F
.554 .263 .428 r
.4758 .85934 m .47179 .86195 L .47167 .8595 L F
.4758 .85934 m .47362 .86199 L .47179 .86195 L F
.795 .754 .815 r
.47584 .85657 m .4758 .85934 L .47362 .85672 L F
.769 .495 .52 r
.68894 .74138 m .68762 .74372 L .68565 .74128 L F
.68894 .74138 m .6893 .74327 L .68762 .74372 L F
0 0 .373 r
.53502 .81278 m .53583 .81452 L .53563 .81395 L F
.53502 .81278 m .53563 .81395 L .53411 .81228 L F
.693 .453 .555 r
.53411 .81228 m .53527 .81473 L .53119 .81401 L F
.77 .649 .728 r
.53518 .81601 m .53492 .81487 L .53547 .81464 L F
.693 .453 .555 r
.53527 .81473 m .53536 .81493 L .53498 .81484 L F
.53527 .81473 m .53498 .81484 L .53119 .81401 L F
.77 .649 .728 r
.53518 .81601 m .53389 .8162 L .53492 .81487 L F
.53547 .81464 m .53527 .81473 L .53559 .81403 L F
.53561 .81402 m .5356 .81399 L .53563 .81395 L F
.551 .391 .618 r
.53563 .81395 m .53536 .81493 L .53527 .81473 L F
0 0 .33 r
.53585 .81464 m .5357 .81425 L .53502 .81278 L F
.551 .391 .618 r
.53563 .81395 m .53527 .81473 L .53411 .81228 L F
.77 .649 .728 r
.53559 .81403 m .53492 .81487 L .5356 .81399 L F
.53527 .81473 m .53492 .81487 L .53559 .81403 L F
.53518 .81601 m .5356 .81399 L .53561 .81402 L F
0 0 .33 r
.53594 .81514 m .53585 .81464 L .53502 .81278 L F
.53585 .81464 m .53583 .81452 L .5357 .81425 L F
.731 .567 .67 r
.60031 .77302 m .60027 .77545 L .59695 .77525 L F
.793 .782 .843 r
.66986 .75748 m .67306 .75714 L .67234 .7569 L F
.233 0 .012 r
.67516 .75735 m .67234 .7569 L .67306 .75714 L F
0 0 0 r
.38418 .74699 m .38419 .74659 L .38625 .74624 L F
.38418 .74699 m .38217 .7476 L .38419 .74659 L F
.3 .366 .764 r
.70611 .71899 m .70638 .72071 L .70528 .71742 L F
.996 .802 .438 r
.70607 .72265 m .70638 .72071 L .70611 .71899 L F
.67 .501 .648 r
.39103 .85396 m .39417 .85395 L .39331 .85136 L F
.697 .55 .684 r
.39417 .85395 m .39625 .85157 L .39331 .85136 L F
0 .045 .578 r
.57072 .81033 m .57178 .81152 L .57174 .81143 L F
.63 .237 0 r
.5717 .81133 m .57174 .81143 L .57204 .81196 L F
.217 .197 .621 r
.57174 .81143 m .57064 .81442 L .57204 .81196 L F
.123 .134 .598 r
.57293 .81282 m .57235 .81413 L .57174 .81143 L F
0 .045 .578 r
.57178 .81152 m .57293 .81282 L .57174 .81143 L F
.63 .237 0 r
.57051 .80916 m .57174 .81143 L .5717 .81133 L F
.628 .495 .681 r
.52497 .84339 m .52329 .84402 L .5229 .84161 L F
.659 .531 .697 r
.40253 .84135 m .40468 .84101 L .40398 .83819 L F
.656 .514 .679 r
.40253 .84135 m .40261 .84365 L .40468 .84101 L F
.493 .143 .301 r
.35353 .78786 m .35636 .78578 L .3547 .78652 L F
0 0 .326 r
.40828 .89194 m .40737 .89082 L .40941 .89035 L F
.411 0 0 r
.41047 .89226 m .40857 .89223 L .40828 .89194 L F
0 0 .326 r
.40828 .89194 m .40719 .89288 L .40735 .89102 L F
.516 .916 .844 r
.40828 .89194 m .40525 .89339 L .40719 .89288 L F
.411 0 0 r
.40857 .89223 m .40697 .8922 L .40828 .89194 L F
0 0 .326 r
.40828 .89194 m .40735 .89102 L .40737 .89082 L F
.613 .505 .707 r
.52383 .83534 m .5261 .83548 L .52506 .8332 L F
.874 .487 .017 r
.52506 .8332 m .52537 .83388 L .5247 .83299 L F
.52537 .83388 m .5261 .83548 L .52539 .83422 L F
.52537 .83388 m .52539 .83422 L .5247 .83299 L F
0 .106 .66 r
.5247 .83299 m .5261 .83548 L .52577 .83439 L F
0 0 .345 r
.52383 .83534 m .52577 .83439 L .5261 .83548 L F
.52383 .83534 m .52436 .83624 L .52543 .83484 L F
.52541 .83456 m .52543 .83484 L .52577 .83439 L F
.52383 .83534 m .52543 .83484 L .52541 .83456 L F
.566 .643 .886 r
.41967 .90909 m .4162 .90685 L .41839 .90859 L F
.321 .807 .864 r
.4166 .90954 m .41967 .90909 L .41839 .90859 L F
.578 .267 .405 r
.45605 .83012 m .45833 .83006 L .45927 .82771 L F
.558 .247 .396 r
.45927 .82771 m .46113 .82933 L .46148 .82781 L F
.45927 .82771 m .45833 .83006 L .46113 .82933 L F
.373 0 .114 r
.34999 .75234 m .34858 .75406 L .34684 .75414 L F
0 0 .351 r
.68519 .71326 m .68644 .70933 L .68438 .70949 L F
.739 .251 .082 r
.68865 .71223 m .68691 .7114 L .68631 .7119 L F
.68691 .7114 m .68621 .71106 L .68631 .7119 L F
0 0 .351 r
.68538 .71267 m .68631 .7119 L .68644 .70933 L F
.68519 .71326 m .68631 .7119 L .68538 .71267 L F
.534 .757 .979 r
.68519 .71326 m .6872 .71287 L .68631 .7119 L F
.562 .415 .639 r
.60591 .74351 m .606 .74841 L .60975 .74664 L F
.606 .74841 m .6062 .74841 L .60975 .74664 L F
.714 .537 .648 r
.60415 .74605 m .606 .74841 L .60591 .74351 L F
.635 .548 .739 r
.60733 .74859 m .60975 .74664 L .6062 .74841 L F
.563 .503 .746 r
.60415 .74605 m .60597 .74837 L .60733 .74859 L F
.60597 .74837 m .60641 .74894 L .60733 .74859 L F
.635 .548 .739 r
.60733 .74859 m .6062 .74841 L .606 .74851 L F
.562 .415 .639 r
.606 .74841 m .606 .74851 L .6062 .74841 L F
.563 .503 .746 r
.606 .74841 m .60555 .74927 L .60641 .74894 L F
.60415 .74605 m .60518 .74842 L .606 .74841 L F
.60518 .74842 m .60555 .74927 L .606 .74841 L F
.714 .537 .648 r
.60415 .74605 m .606 .74851 L .606 .74841 L F
.562 .415 .639 r
.60591 .74351 m .60975 .74664 L .60849 .74152 L F
.515 .089 .17 r
.48919 .81969 m .49137 .81984 L .4929 .81825 L F
.433 0 .109 r
.4929 .81825 m .49478 .8187 L .49495 .8175 L F
.4929 .81825 m .49137 .81984 L .49478 .8187 L F
.789 .738 .806 r
.47213 .85362 m .47151 .85093 L .47247 .85144 L F
.612 .328 .463 r
.49981 .81501 m .50011 .8169 L .49994 .8149 L F
.594 .311 .457 r
.49994 .8149 m .50011 .8169 L .502 .8167 L F
.618 .303 .415 r
.49994 .8149 m .502 .8167 L .5021 .81506 L F
.531 .319 .537 r
.47591 .85412 m .47584 .85657 L .47362 .85672 L F
.342 .585 .934 r
.47678 .85301 m .4777 .85414 L .47591 .85412 L F
.401 .215 .511 r
.4777 .85414 m .47584 .85657 L .47591 .85412 L F
.572 .133 .167 r
.58205 .77813 m .58117 .77967 L .5788 .7785 L F
.757 .343 .266 r
.58205 .77813 m .58443 .78052 L .58117 .77967 L F
.483 .386 .67 r
.58407 .77791 m .58443 .78052 L .58205 .77813 L F
.59 .501 .722 r
.66186 .75797 m .66142 .76129 L .66033 .7593 L F
.139 0 .343 r
.69384 .72835 m .69574 .72528 L .69551 .72762 L F
0 0 .319 r
.6947 .72853 m .69384 .72835 L .69551 .72762 L F
.6947 .72853 m .69368 .73019 L .69384 .72835 L F
.8 .892 .91 r
.64465 .76317 m .64199 .7651 L .64092 .76436 L F
.12 .274 .748 r
.59772 .81912 m .59667 .81994 L .59874 .82199 L F
.367 .34 .697 r
.38556 .72948 m .38801 .73291 L .38658 .73282 L F
0 .079 .64 r
.38659 .72999 m .38556 .72948 L .38472 .73041 L F
.723 .43 .481 r
.46084 .84928 m .46068 .85086 L .45833 .84885 L F
.63 .192 .19 r
.50027 .84096 m .4992 .84247 L .49679 .84104 L F
.603 .169 .19 r
.50238 .84124 m .4992 .84247 L .50027 .84096 L F
.902 .913 .819 r
.59013 .83191 m .58818 .83341 L .58987 .83214 L F
.32 0 .056 r
.36287 .7497 m .3615 .75153 L .35952 .7519 L F
.525 .103 .183 r
.36455 .75072 m .3615 .75153 L .36287 .7497 L F
.509 .126 .25 r
.36516 .74957 m .36455 .75072 L .36287 .7497 L F
.669 .754 .914 r
.38401 .89816 m .38734 .89856 L .38624 .89733 L F
.587 .724 .939 r
.38624 .89733 m .38734 .89856 L .38936 .89817 L F
0 0 .073 r
.65122 .75901 m .65264 .75844 L .65317 .75644 L F
0 0 0 r
.6506 .75928 m .65264 .75844 L .65122 .75901 L F
.387 0 0 r
.45705 .86582 m .45624 .86618 L .45343 .86539 L F
.719 .191 0 r
.45705 .86582 m .45854 .86722 L .45624 .86618 L F
.778 .308 0 r
.55917 .81527 m .56028 .81695 L .55836 .81463 L F
.699 .538 .667 r
.38156 .86171 m .38461 .86187 L .38459 .85954 L F
.683 .545 .69 r
.38459 .85954 m .3868 .85925 L .38667 .85691 L F
.679 .523 .667 r
.38461 .86187 m .3868 .85925 L .38459 .85954 L F
.805 .701 .751 r
.44218 .82523 m .43889 .82509 L .44091 .82228 L F
.798 .73 .788 r
.44218 .82523 m .43994 .82758 L .43889 .82509 L F
.524 .694 .946 r
.44294 .82393 m .44218 .82523 L .44091 .82228 L F
.44294 .82393 m .44442 .8253 L .44218 .82523 L F
.743 .623 .726 r
.44075 .8246 m .44072 .82514 L .44294 .82393 L F
.44072 .82514 m .44063 .82661 L .44186 .82519 L F
.44072 .82514 m .44186 .82519 L .44294 .82393 L F
.947 .66 .207 r
.44225 .8252 m .44218 .82523 L .44442 .8253 L F
.889 .922 .838 r
.44294 .82393 m .44186 .82519 L .44163 .82517 L F
.947 .66 .207 r
.44163 .82517 m .44169 .82518 L .44186 .82519 L F
.889 .922 .838 r
.44186 .82519 m .44063 .82661 L .44163 .82517 L F
.947 .66 .207 r
.44163 .82517 m .44186 .82519 L .44225 .8252 L F
.44169 .82518 m .44218 .82523 L .44225 .8252 L F
.44163 .82517 m .44259 .82801 L .44218 .82523 L F
.601 .538 .756 r
.43729 .8671 m .43513 .86752 L .43417 .86435 L F
.435 .818 .989 r
.47579 .87196 m .47918 .87211 L .47707 .87244 L F
.339 .792 .949 r
.34411 .72897 m .34609 .72866 L .34764 .72902 L F
.482 .864 .978 r
.34764 .72902 m .34814 .72818 L .34957 .72839 L F
.34764 .72902 m .34609 .72866 L .34814 .72818 L F
.299 .108 .445 r
.57339 .82753 m .57114 .83022 L .57146 .82816 L F
.6 .58 .803 r
.4712 .83735 m .47024 .84098 L .46905 .8377 L F
.4712 .83735 m .47241 .84072 L .47024 .84098 L F
.567 .361 .561 r
.47024 .84098 m .47227 .843 L .47241 .84072 L F
.47241 .84072 m .47227 .843 L .47024 .84098 L F
.529 .296 .506 r
.36839 .77772 m .37074 .7753 L .36858 .77552 L F
.688 .548 .69 r
.3868 .85925 m .38893 .85662 L .38667 .85691 L F
.672 .324 .375 r
.67115 .74656 m .66766 .74811 L .66768 .74685 L F
.586 .162 .205 r
.66768 .74685 m .66958 .74706 L .67115 .74656 L F
.672 .324 .375 r
.67115 .74656 m .66958 .7487 L .66766 .74811 L F
.843 .851 .85 r
.67115 .74656 m .67185 .74344 L .67343 .74455 L F
.67115 .74656 m .66958 .74706 L .67185 .74344 L F
.836 .544 .494 r
.67147 .74854 m .66958 .7487 L .67115 .74656 L F
.671 .277 .291 r
.6579 .75231 m .6602 .7538 L .66129 .75229 L F
.246 0 .028 r
.66129 .75229 m .66222 .75318 L .66334 .75163 L F
.66129 .75229 m .6602 .7538 L .66222 .75318 L F
.526 .911 .937 r
.3687 .72614 m .36544 .72691 L .36783 .72614 L F
.31 .754 .963 r
.36971 .72563 m .3687 .72614 L .36783 .72614 L F
.36971 .72563 m .37041 .72603 L .3687 .72614 L F
.538 .05 .045 r
.47609 .88402 m .47922 .8834 L .47815 .8844 L F
.508 0 0 r
.47922 .8834 m .48024 .88468 L .47815 .8844 L F
.47922 .8834 m .48162 .88396 L .48024 .88468 L F
.349 .044 .298 r
.59286 .76523 m .59441 .76615 L .59511 .76508 L F
.59286 .76523 m .5924 .76685 L .59441 .76615 L F
.71 .811 .928 r
.49037 .88431 m .4937 .88389 L .49171 .88355 L F
.628 .962 .849 r
.4937 .88389 m .49451 .8829 L .49171 .88355 L F
.4937 .88389 m .49546 .88275 L .49451 .8829 L F
.042 0 0 r
.61407 .76249 m .61292 .76366 L .61177 .76389 L F
.621 .31 .422 r
.61624 .76213 m .61292 .76366 L .61407 .76249 L F
.557 .375 .591 r
.61623 .75975 m .61624 .76213 L .61407 .76249 L F
.197 .678 .931 r
.5082 .87957 m .51156 .88022 L .5102 .88023 L F
.491 0 0 r
.51156 .88022 m .51228 .88136 L .5102 .88023 L F
.51156 .88022 m .51393 .88092 L .51228 .88136 L F
0 0 .005 r
.69321 .72374 m .69392 .72441 L .69443 .72248 L F
.28 .251 .647 r
.69443 .72248 m .69672 .72237 L .69609 .71946 L F
.2 0 .059 r
.69392 .72441 m .69672 .72237 L .69443 .72248 L F
.636 .823 .972 r
.41522 .75177 m .41091 .7508 L .41296 .75051 L F
0 .184 .708 r
.41482 .75031 m .41522 .75177 L .41296 .75051 L F
.244 0 0 r
.41522 .75177 m .41628 .75223 L .41756 .75174 L F
0 .184 .708 r
.41482 .75031 m .41628 .75223 L .41522 .75177 L F
.828 .914 .515 r
.53594 .81514 m .53518 .81601 L .53583 .81452 L F
.679 .613 .775 r
.70455 .71539 m .70249 .71775 L .70144 .71479 L F
.662 .586 .76 r
.70455 .71539 m .70528 .71742 L .70249 .71775 L F
.782 .973 .916 r
.50146 .87415 m .49984 .87565 L .49891 .87539 L F
.798 .626 .669 r
.50051 .83063 m .50446 .83157 L .50264 .82753 L F
.493 .611 .897 r
.50051 .83063 m .50327 .8328 L .50446 .83157 L F
.512 .491 .77 r
.50264 .82753 m .50446 .83157 L .50551 .83027 L F
.661 .917 .608 r
.50446 .83157 m .50327 .8328 L .50551 .83027 L F
.719 .856 .947 r
.41392 .90312 m .41559 .90393 L .41352 .90507 L F
.916 .898 .489 r
.56966 .81577 m .57008 .81603 L .57064 .81442 L F
.911 .66 .546 r
.57112 .81722 m .57064 .81442 L .56977 .81694 L F
.145 0 .27 r
.57064 .81442 m .57147 .81625 L .56966 .81577 L F
0 .517 .845 r
.56966 .81577 m .5706 .81575 L .56929 .81554 L F
.56966 .81577 m .56929 .81554 L .56919 .81552 L F
.916 .898 .489 r
.56966 .81577 m .56977 .81694 L .57008 .81603 L F
.217 .197 .621 r
.57174 .81143 m .57235 .81413 L .57064 .81442 L F
.145 0 .27 r
.57064 .81442 m .57235 .81413 L .57147 .81625 L F
.337 .815 .771 r
.51043 .87489 m .50702 .87596 L .50941 .87542 L F
.307 0 0 r
.51128 .87534 m .51043 .87489 L .50941 .87542 L F
.51128 .87534 m .51252 .87556 L .51043 .87489 L F
.661 .539 .705 r
.4264 .73736 m .42752 .73888 L .42785 .73609 L F
.585 .394 .588 r
.36644 .79348 m .36276 .79558 L .36443 .79356 L F
0 0 0 r
.59653 .84573 m .59901 .84357 L .59797 .84533 L F
.59901 .84357 m .60119 .84098 L .60023 .84286 L F
.59797 .84533 m .59901 .84357 L .60023 .84286 L F
0 0 .005 r
.69321 .72374 m .69263 .72519 L .69392 .72441 L F
.435 .077 .257 r
.57652 .77178 m .57957 .76939 L .57739 .76991 L F
.549 .466 .714 r
.50461 .84909 m .50626 .84599 L .50357 .84592 L F
.50461 .84909 m .50704 .84967 L .50626 .84599 L F
.025 0 0 r
.3407 .72912 m .34411 .72897 L .3421 .72918 L F
0 0 0 r
.64527 .71982 m .64683 .71707 L .6468 .71927 L F
.64527 .71982 m .6468 .71927 L .64506 .72027 L F
.513 .907 .93 r
.69952 .72207 m .69818 .72306 L .69984 .72229 L F
0 0 0 r
.69749 .7247 m .69818 .72306 L .69952 .72207 L F
.079 0 .166 r
.61968 .75675 m .61807 .7589 L .61861 .75735 L F
.533 .659 .917 r
.33563 .66732 m .33403 .66842 L .33264 .66616 L F
0 0 0 r
.33563 .66732 m .33372 .66934 L .33403 .66842 L F
.654 .464 .615 r
.37521 .86963 m .37812 .86961 L .37758 .86728 L F
.706 .587 .72 r
.37758 .86728 m .38044 .86715 L .37954 .86427 L F
.713 .517 .623 r
.37812 .86961 m .38044 .86715 L .37758 .86728 L F
.753 .398 .381 r
.44477 .86196 m .4434 .86349 L .4415 .86153 L F
.559 .598 .848 r
.44554 .85908 m .44738 .86171 L .44477 .86196 L F
.704 .333 .342 r
.44477 .86196 m .44678 .86397 L .4434 .86349 L F
0 0 0 r
.69007 .72786 m .69205 .72695 L .69064 .72753 L F
.68686 .72924 m .69064 .72753 L .6886 .73065 L F
.68686 .72924 m .69007 .72786 L .69064 .72753 L F
.612 .328 .463 r
.49981 .81501 m .49643 .81727 L .50011 .8169 L F
.732 .911 .956 r
.42779 .88715 m .43067 .88728 L .43323 .88573 L F
.713 .517 .623 r
.37812 .86961 m .38045 .86956 L .38044 .86715 L F
.64 .537 .721 r
.38044 .86715 m .38245 .86463 L .37954 .86427 L F
.38044 .86715 m .3827 .86703 L .38245 .86463 L F
.623 .411 .573 r
.38258 .86931 m .38044 .86715 L .38045 .86956 L F
.38258 .86931 m .3827 .86703 L .38044 .86715 L F
.714 .855 .949 r
.41317 .90511 m .41392 .90312 L .41213 .90306 L F
.411 .751 .994 r
.56945 .84787 m .57142 .84725 L .56887 .84776 L F
.56945 .84787 m .57218 .84799 L .57142 .84725 L F
.914 .87 .78 r
.47362 .85672 m .47072 .85917 L .47078 .85638 L F
.47362 .85672 m .47167 .8595 L .47072 .85917 L F
.534 .335 .557 r
.66939 .73063 m .66726 .73115 L .66957 .72839 L F
.66939 .73063 m .66726 .73115 L .66957 .72839 L F
.842 .795 .806 r
.53277 .86937 m .5342 .8704 L .53534 .86886 L F
.53521 .86876 m .53534 .86886 L .53546 .8687 L F
.53277 .86937 m .53534 .86886 L .53521 .86876 L F
.53277 .86937 m .53546 .8687 L .53498 .86923 L F
.801 .314 0 r
.53375 .86846 m .53498 .86923 L .53391 .86779 L F
.53348 .86746 m .53391 .86779 L .53338 .86706 L F
.53375 .86846 m .53391 .86779 L .53348 .86746 L F
.781 .43 .392 r
.53498 .86923 m .536 .86727 L .53338 .86706 L F
.838 .873 .431 r
.53498 .86923 m .53546 .8687 L .536 .86727 L F
.924 .804 .709 r
.61595 .73816 m .61476 .74106 L .61692 .74199 L F
.959 .881 .713 r
.61476 .74106 m .61485 .74372 L .61692 .74199 L F
.634 .46 .63 r
.45833 .84885 m .46068 .85086 L .45856 .85092 L F
.33 .197 .544 r
.61794 .76121 m .61623 .75975 L .61807 .7589 L F
.61794 .76121 m .61624 .76213 L .61623 .75975 L F
.419 .766 .996 r
.57468 .84767 m .57553 .8484 L .57769 .84825 L F
.588 .324 .484 r
.56471 .78783 m .56743 .78587 L .56402 .78571 L F
.56471 .78783 m .56727 .78792 L .56743 .78587 L F
.661 .479 .627 r
.56727 .78792 m .56911 .78548 L .56743 .78587 L F
.52 .241 .431 r
.40171 .76747 m .39914 .7696 L .39962 .7678 L F
.582 .359 .542 r
.41578 .75689 m .41328 .75932 L .4138 .75752 L F
.88 .552 .424 r
.66707 .71826 m .66602 .71988 L .66542 .7176 L F
.783 .415 .361 r
.67019 .72011 m .66602 .71988 L .66707 .71826 L F
.916 .746 .656 r
.66981 .71759 m .67019 .72011 L .66707 .71826 L F
.653 .527 .698 r
.40398 .83819 m .40468 .84101 L .40674 .83838 L F
.6 .439 .635 r
.40759 .74383 m .40556 .74651 L .40551 .74418 L F
.205 0 .345 r
.61752 .80417 m .6195 .80134 L .61928 .80354 L F
.21 .031 .407 r
.61741 .80603 m .61752 .80417 L .61928 .80354 L F
0 0 .412 r
.38382 .72714 m .3828 .72836 L .38324 .72753 L F
.194 .28 .725 r
.38382 .72714 m .38472 .73041 L .3828 .72836 L F
.712 .597 .726 r
.52329 .84402 m .52268 .84628 L .52151 .84572 L F
.721 .466 .54 r
.52268 .84628 m .52142 .8483 L .52151 .84572 L F
.52268 .84628 m .5228 .8485 L .52142 .8483 L F
.637 .519 .703 r
.52497 .84339 m .52268 .84628 L .52329 .84402 L F
.561 .415 .64 r
.52497 .84339 m .52524 .84589 L .52268 .84628 L F
.523 .315 .539 r
.52498 .84808 m .52268 .84628 L .52524 .84589 L F
.52498 .84808 m .5228 .8485 L .52268 .84628 L F
.861 .626 .091 r
.66904 .73612 m .66867 .7356 L .66852 .73316 L F
.926 .551 .274 r
.67085 .73807 m .66867 .7356 L .66904 .73612 L F
.421 0 .086 r
.46876 .82709 m .4709 .82695 L .47223 .82535 L F
.584 .214 .307 r
.4709 .82695 m .47435 .82508 L .47223 .82535 L F
.873 .446 .188 r
.66726 .73115 m .66852 .73316 L .66662 .73223 L F
.725 .686 .812 r
.63704 .73319 m .64046 .73356 L .63945 .7308 L F
.599 .615 .839 r
.63945 .7308 m .64046 .73356 L .64233 .73264 L F
.522 .357 .599 r
.61337 .7666 m .61177 .76389 L .61292 .76366 L F
.61337 .7666 m .61167 .76705 L .61177 .76389 L F
.79 .763 .828 r
.64335 .70982 m .64039 .70972 L .64256 .70759 L F
.668 .602 .772 r
.64309 .71166 m .64039 .70972 L .64335 .70982 L F
.754 .745 .844 r
.64545 .70767 m .64335 .70982 L .64256 .70759 L F
.306 .795 .761 r
.64553 .71086 m .64309 .71166 L .64335 .70982 L F
.694 .774 .913 r
.38936 .89817 m .39265 .89848 L .39131 .89743 L F
.835 .884 .877 r
.39265 .89848 m .39363 .89558 L .39131 .89743 L F
.39265 .89848 m .39515 .89618 L .39363 .89558 L F
.594 .902 .985 r
.64816 .76982 m .64938 .76857 L .64776 .7699 L F
.64816 .76982 m .65059 .76895 L .64938 .76857 L F
.725 .606 .725 r
.3928 .74927 m .39594 .75021 L .39536 .74918 L F
.61 .561 .775 r
.39536 .74918 m .39594 .75021 L .39762 .74957 L F
.557 .567 .819 r
.39594 .75021 m .39847 .75128 L .39762 .74957 L F
.49 .251 .479 r
.38753 .77768 m .38518 .78007 L .38549 .77804 L F
.781 .338 0 r
.5573 .81205 m .55677 .81185 L .55549 .80939 L F
0 0 .4 r
.5573 .81205 m .55814 .81341 L .55677 .81185 L F
.5573 .81205 m .55836 .81463 L .55814 .81341 L F
.586 .409 .609 r
.36626 .78036 m .36839 .77772 L .36638 .77808 L F
0 0 0 r
.60119 .84098 m .60322 .83827 L .6024 .84013 L F
.60023 .84286 m .60119 .84098 L .6024 .84013 L F
.613 .796 .969 r
.40422 .73938 m .4011 .73906 L .40319 .73887 L F
.399 .779 .992 r
.40534 .73867 m .40422 .73938 L .40319 .73887 L F
.40534 .73867 m .40635 .73916 L .40422 .73938 L F
0 0 .023 r
.55275 .84472 m .55143 .84692 L .55236 .84618 L F
.835 .461 .344 r
.55275 .84472 m .55384 .84611 L .55236 .84618 L F
.689 .603 .755 r
.38996 .74876 m .39075 .75001 L .3928 .74927 L F
.916 .746 .656 r
.66981 .71759 m .67033 .72045 L .67019 .72011 L F
.697 .378 0 r
.67033 .72045 m .67091 .72231 L .67019 .72011 L F
.359 .34 .702 r
.67136 .71709 m .67033 .72045 L .66981 .71759 L F
.67136 .71709 m .67203 .7201 L .67033 .72045 L F
.364 .366 .728 r
.67203 .7201 m .67266 .72246 L .67033 .72045 L F
.585 .596 .83 r
.4477 .85362 m .44573 .85403 L .4446 .85131 L F
.471 .339 .619 r
.44802 .85603 m .44573 .85403 L .4477 .85362 L F
.44802 .85603 m .44632 .85691 L .44573 .85403 L F
0 0 0 r
.59653 .84573 m .59797 .84533 L .59619 .84625 L F
.865 .837 .816 r
.70358 .72352 m .70352 .7251 L .70203 .72549 L F
.793 .495 .484 r
.70203 .72549 m .70352 .7251 L .70392 .72776 L F
.527 .375 .618 r
.70607 .72265 m .70352 .7251 L .70358 .72352 L F
.70607 .72265 m .70632 .72517 L .70352 .7251 L F
.516 .28 .495 r
.70352 .7251 m .70594 .72711 L .70392 .72776 L F
.70352 .7251 m .70632 .72517 L .70594 .72711 L F
.695 .353 .391 r
.50126 .81969 m .49991 .82189 L .49776 .81986 L F
.604 .298 .425 r
.50288 .82127 m .49991 .82189 L .50126 .81969 L F
.505 .226 .425 r
.38053 .78316 m .37797 .78523 L .37861 .78373 L F
.51 .107 .212 r
.49774 .82161 m .49575 .82057 L .49776 .81986 L F
.49774 .82161 m .49493 .82195 L .49575 .82057 L F
.857 .417 .161 r
.67285 .7307 m .67454 .7333 L .67584 .73362 L F
.865 .425 .15 r
.67454 .7333 m .67678 .73523 L .67584 .73362 L F
.627 .462 .639 r
.3868 .85925 m .38907 .85892 L .38893 .85662 L F
.643 .489 .659 r
.38893 .85662 m .39129 .85652 L .39103 .85396 L F
.61 .427 .61 r
.38907 .85892 m .39129 .85652 L .38893 .85662 L F
.668 .506 .657 r
.38461 .86187 m .38687 .86171 L .3868 .85925 L F
.671 .533 .688 r
.38687 .86171 m .38907 .85892 L .3868 .85925 L F
.701 .546 .673 r
.39625 .85157 m .39847 .85129 L .39839 .84892 L F
.68 .545 .693 r
.39839 .84892 m .40069 .84865 L .40052 .84631 L F
.65 .487 .65 r
.39847 .85129 m .40069 .84865 L .39839 .84892 L F
.692 .549 .687 r
.40052 .84631 m .4028 .84608 L .40261 .84365 L F
.675 .542 .695 r
.40261 .84365 m .40492 .84336 L .40468 .84101 L F
.632 .477 .654 r
.4028 .84608 m .40492 .84336 L .40261 .84365 L F
.309 .497 .88 r
.52569 .87706 m .52483 .87728 L .52332 .8749 L F
0 0 0 r
.52281 .87881 m .52483 .87728 L .52569 .87706 L F
.81 .983 .891 r
.52709 .82587 m .52771 .82423 L .52893 .82487 L F
.52709 .82587 m .52628 .82559 L .52771 .82423 L F
.533 .299 .505 r
.37074 .7753 m .37285 .77505 L .37331 .77216 L F
.595 .411 .601 r
.37331 .77216 m .37546 .77209 L .37551 .77007 L F
.491 .261 .493 r
.37331 .77216 m .37478 .77456 L .37546 .77209 L F
.37331 .77216 m .37285 .77505 L .37478 .77456 L F
.982 .693 .374 r
.56387 .83032 m .5631 .83139 L .56228 .83008 L F
.56387 .83032 m .56414 .83266 L .5631 .83139 L F
0 0 .409 r
.56565 .84569 m .56662 .84768 L .5668 .84798 L F
.362 0 0 r
.44529 .83055 m .4471 .83108 L .44869 .83059 L F
.418 0 0 r
.44869 .83059 m .45036 .83151 L .45104 .8307 L F
0 .235 .666 r
.44992 .83118 m .45036 .83151 L .44869 .83059 L F
.44992 .83118 m .44869 .83059 L .4471 .83108 L F
.624 .435 .606 r
.39129 .85652 m .39417 .85395 L .39103 .85396 L F
.467 0 0 r
.50982 .84032 m .50774 .83821 L .50994 .83815 L F
.909 .97 .667 r
.62165 .75338 m .61968 .75675 L .62102 .75488 L F
.66 .699 .875 r
.70144 .71479 m .69925 .7153 L .69884 .71448 L F
0 0 0 r
.53119 .81401 m .53023 .81496 L .53208 .81238 L F
.653 .502 .666 r
.53119 .81401 m .5293 .81704 L .53023 .81496 L F
.596 .26 .37 r
.51427 .83074 m .51389 .8325 L .51615 .83234 L F
.607 .499 .706 r
.51427 .83074 m .51645 .83046 L .51591 .82755 L F
.548 .275 .454 r
.51427 .83074 m .51615 .83234 L .51645 .83046 L F
.518 .581 .857 r
.68438 .70949 m .68512 .70672 L .68307 .70727 L F
.68438 .70949 m .68644 .70933 L .68512 .70672 L F
.964 .856 .686 r
.57538 .82767 m .57527 .82493 L .57339 .82753 L F
.868 .863 .831 r
.57392 .82925 m .57538 .82767 L .57339 .82753 L F
.834 .418 .252 r
.4887 .84166 m .48835 .84285 L .48691 .84055 L F
0 0 .002 r
.48986 .84146 m .4887 .84166 L .49119 .84139 L F
.48986 .84146 m .48835 .84285 L .4887 .84166 L F
.44 .107 .303 r
.36364 .78198 m .36626 .78036 L .36416 .78058 L F
.685 .647 .807 r
.4446 .85131 m .44189 .85346 L .44322 .85317 L F
0 0 .035 r
.60446 .83748 m .60322 .83827 L .60502 .83546 L F
0 0 0 r
.6024 .84013 m .60322 .83827 L .60446 .83748 L F
.656 .364 .465 r
.58979 .77494 m .58632 .77742 L .58605 .77591 L F
.58979 .77494 m .5886 .77768 L .58632 .77742 L F
.623 .328 .449 r
.59171 .77724 m .58979 .77494 L .5915 .77535 L F
.59171 .77724 m .5886 .77768 L .58979 .77494 L F
.615 .685 .893 r
.38511 .7285 m .38898 .72877 L .38476 .72816 L F
.662 .515 .673 r
.37954 .86427 m .38245 .86463 L .38156 .86171 L F
.693 .453 .555 r
.53411 .81228 m .53119 .81401 L .53208 .81238 L F
.637 .876 .986 r
.45263 .88557 m .45347 .88416 L .45155 .88456 L F
.45263 .88557 m .45482 .88483 L .45347 .88416 L F
.647 .38 .501 r
.42377 .83005 m .42623 .828 L .42428 .82755 L F
.891 .881 .817 r
.57432 .83483 m .57548 .83563 L .57334 .83838 L F
.205 .639 .95 r
.57725 .83583 m .57548 .83563 L .57432 .83483 L F
.759 .617 .701 r
.52593 .83305 m .52506 .8332 L .52488 .83042 L F
.731 .697 .818 r
.53037 .83045 m .52593 .83305 L .5277 .83037 L F
.299 .755 .954 r
.61485 .74372 m .61695 .74361 L .61814 .74407 L F
.033 0 0 r
.61695 .74361 m .62032 .74369 L .61814 .74407 L F
.878 .969 .846 r
.6204 .78024 m .62185 .77743 L .62251 .77784 L F
.888 .977 .826 r
.62251 .77784 m .62395 .77483 L .62523 .77588 L F
.62251 .77784 m .62185 .77743 L .62395 .77483 L F
.699 .741 .883 r
.39181 .74837 m .39536 .74918 L .39353 .74663 L F
.39181 .74837 m .3928 .74927 L .39536 .74918 L F
.597 .733 .939 r
.39353 .74663 m .39536 .74918 L .39786 .74864 L F
.61 .561 .775 r
.39536 .74918 m .39762 .74957 L .39786 .74864 L F
.017 0 .247 r
.51247 .83979 m .51096 .84095 L .50982 .84032 L F
.51247 .83979 m .51042 .84419 L .51096 .84095 L F
.609 .356 .509 r
.37776 .76985 m .38003 .76973 L .38031 .76769 L F
.54 .287 .481 r
.38003 .76973 m .38256 .76743 L .38031 .76769 L F
.698 .534 .662 r
.38245 .86463 m .38461 .86187 L .38156 .86171 L F
.16 .586 .934 r
.54103 .84107 m .54423 .84236 L .54318 .84043 L F
.493 .464 .754 r
.54423 .84236 m .54543 .84027 L .54318 .84043 L F
.54423 .84236 m .54622 .842 L .54543 .84027 L F
.362 .829 .772 r
.51548 .88096 m .51705 .88057 L .51892 .87981 L F
.566 .304 .478 r
.41166 .75994 m .41109 .76194 L .40896 .76204 L F
.539 .33 .545 r
.41328 .75932 m .41109 .76194 L .41166 .75994 L F
.766 .692 .781 r
.67202 .75861 m .66986 .75748 L .67234 .7569 L F
.061 0 0 r
.6714 .76013 m .67444 .75867 L .67328 .75989 L F
.6714 .76013 m .67328 .75989 L .6732 .75983 L F
.811 .974 .673 r
.67041 .7603 m .67202 .75861 L .6714 .76013 L F
.228 0 0 r
.67202 .75861 m .67444 .75867 L .6714 .76013 L F
.061 0 0 r
.6714 .76013 m .6732 .75983 L .67126 .75816 L F
.811 .974 .673 r
.66966 .76109 m .67041 .7603 L .6714 .76013 L F
.233 0 .012 r
.67516 .75735 m .67202 .75861 L .67234 .7569 L F
.67516 .75735 m .67444 .75867 L .67202 .75861 L F
.488 .902 .888 r
.45241 .87258 m .45336 .87176 L .45463 .87243 L F
.45241 .87258 m .4514 .8726 L .45336 .87176 L F
.406 .481 .825 r
.48917 .87519 m .48808 .87541 L .48888 .87338 L F
.42 .611 .928 r
.48571 .87496 m .48808 .87541 L .48916 .87513 L F
.48571 .87496 m .48916 .87513 L .48911 .87505 L F
.551 .141 .217 r
.48639 .87673 m .48808 .87541 L .48571 .87496 L F
.102 0 0 r
.48917 .87519 m .48808 .87541 L .48639 .87673 L F
.551 .141 .217 r
.48639 .87673 m .48571 .87496 L .48911 .87505 L F
.877 .792 .762 r
.48919 .87519 m .48918 .87517 L .48917 .87519 L F
.49086 .87334 m .48945 .87472 L .48918 .87517 L F
.955 .939 .727 r
.48917 .87519 m .48986 .87221 L .48888 .87338 L F
.408 .494 .836 r
.48944 .87506 m .48917 .87519 L .48888 .87338 L F
.42 .611 .928 r
.48911 .87505 m .48916 .87513 L .48944 .87506 L F
.408 .494 .836 r
.48944 .87506 m .48808 .87541 L .48917 .87519 L F
.551 .141 .217 r
.48866 .87549 m .48911 .87505 L .48944 .87506 L F
.48639 .87673 m .48911 .87505 L .48866 .87549 L F
.877 .792 .762 r
.49095 .87543 m .49086 .87334 L .48918 .87517 L F
.49086 .87334 m .49082 .87242 L .48945 .87472 L F
.49095 .87543 m .48918 .87517 L .48919 .87519 L F
.586 .787 .976 r
.42304 .88765 m .42578 .88803 L .42458 .8874 L F
.047 .615 .742 r
.42784 .88737 m .42458 .8874 L .42578 .88803 L F
0 0 .481 r
.5713 .83904 m .57127 .84102 L .57218 .8401 L F
.616 .13 .077 r
.50867 .8207 m .50504 .82094 L .50645 .8203 L F
.718 .516 .615 r
.50013 .82766 m .50051 .83063 L .50264 .82753 L F
.512 .491 .77 r
.50264 .82753 m .50551 .83027 L .50437 .82703 L F
.877 .792 .762 r
.49095 .87543 m .49291 .87226 L .49082 .87242 L F
.538 .866 .589 r
.49545 .8273 m .49428 .82824 L .49564 .82701 L F
.705 .493 .598 r
.60028 .77767 m .59695 .77525 L .60027 .77545 L F
.554 .303 .49 r
.60278 .7754 m .60028 .77767 L .60027 .77545 L F
.703 .562 .692 r
.45047 .8473 m .44994 .84874 L .44635 .84862 L F
.633 .484 .663 r
.45222 .8462 m .44994 .84874 L .45047 .8473 L F
.602 .426 .616 r
.40069 .84865 m .4028 .84608 L .40052 .84631 L F
.588 .768 .965 r
.4973 .88175 m .50062 .88234 L .49977 .88059 L F
.763 .806 .887 r
.49977 .88059 m .50062 .88234 L .5029 .88046 L F
.514 .773 .99 r
.33054 .67063 m .33013 .6695 L .32827 .66818 L F
.33054 .67063 m .33155 .67048 L .33013 .6695 L F
.467 .114 .283 r
.51806 .81418 m .52018 .81394 L .52109 .81191 L F
.562 .382 .595 r
.52109 .81191 m .52316 .81165 L .52318 .80944 L F
.34 0 .221 r
.52109 .81191 m .52232 .8131 L .52316 .81165 L F
.52109 .81191 m .52018 .81394 L .52232 .8131 L F
.681 .312 .341 r
.64384 .71659 m .64683 .71707 L .6445 .71523 L F
.486 .486 .783 r
.69421 .70867 m .69228 .71033 L .69146 .70726 L F
.48 .478 .777 r
.69421 .70867 m .69319 .71186 L .69228 .71033 L F
.518 .293 .513 r
.37546 .77209 m .37776 .76985 L .37551 .77007 L F
.729 .79 .901 r
.49119 .84139 m .49492 .84157 L .4935 .84102 L F
.519 0 0 r
.49679 .84104 m .4935 .84102 L .49492 .84157 L F
.721 .539 .643 r
.44669 .85023 m .44556 .84881 L .44635 .84862 L F
.703 .501 .612 r
.44994 .84874 m .44669 .85023 L .44635 .84862 L F
.647 .843 .975 r
.45673 .8846 m .45789 .88534 L .45875 .88482 L F
.487 .088 .208 r
.67019 .72011 m .66794 .72255 L .66602 .71988 L F
.558 .714 .945 r
.48721 .86915 m .48618 .86875 L .48593 .86828 L F
.581 .757 .962 r
.48913 .86843 m .48721 .86915 L .48593 .86828 L F
.48913 .86843 m .4898 .86929 L .48721 .86915 L F
.404 0 0 r
.49096 .86945 m .48721 .86915 L .4898 .86929 L F
.878 .969 .846 r
.6204 .78024 m .61963 .77998 L .62185 .77743 L F
.464 .191 .413 r
.38256 .76743 m .38457 .76712 L .38509 .76458 L F
.383 .12 .386 r
.38509 .76458 m .38627 .76652 L .38687 .76458 L F
.38509 .76458 m .38457 .76712 L .38627 .76652 L F
.338 0 .044 r
.60838 .74074 m .61053 .74037 L .61159 .7389 L F
.714 .541 .653 r
.37317 .87218 m .37408 .86971 L .37262 .86969 L F
.65 .464 .619 r
.37317 .87218 m .37521 .86963 L .37408 .86971 L F
.988 .795 .557 r
.55143 .84692 m .55052 .84839 L .55236 .84618 L F
0 0 0 r
.60502 .83546 m .60665 .83256 L .60581 .83433 L F
.60446 .83748 m .60502 .83546 L .60581 .83433 L F
.647 .38 .501 r
.42377 .83005 m .42591 .82998 L .42623 .828 L F
.911 .968 .8 r
.45919 .86885 m .45636 .87145 L .45912 .86952 L F
.868 .55 .033 r
.45919 .86885 m .45912 .86952 L .45854 .86722 L F
.675 .559 .716 r
.40468 .84101 m .407 .84068 L .40674 .83838 L F
.64 .516 .696 r
.40468 .84101 m .40724 .84311 L .407 .84068 L F
.40468 .84101 m .40492 .84336 L .40724 .84311 L F
.595 .051 0 r
.53954 .81174 m .54203 .8131 L .54254 .81232 L F
.831 .36 .053 r
.54203 .8131 m .54362 .8139 L .54254 .81232 L F
0 .192 .707 r
.67132 .74005 m .67243 .74104 L .67085 .73807 L F
.8 .892 .91 r
.64465 .76317 m .64092 .76436 L .64281 .76335 L F
.855 .886 .86 r
.64465 .76317 m .64511 .76107 L .64595 .76169 L F
.64465 .76317 m .64281 .76335 L .64511 .76107 L F
.675 .825 .956 r
.37976 .72695 m .37592 .72685 L .37778 .72583 L F
.139 .636 .91 r
.38032 .72653 m .37976 .72695 L .37778 .72583 L F
.38032 .72653 m .38324 .72753 L .37976 .72695 L F
.675 .47 .599 r
.41117 .83757 m .4142 .83542 L .41132 .83572 L F
.597 .493 .707 r
.43608 .86396 m .43397 .86255 L .43613 .86182 L F
.43608 .86396 m .43417 .86435 L .43397 .86255 L F
.242 .757 .786 r
.58608 .84839 m .58902 .84779 L .58804 .84769 L F
.318 .807 .828 r
.58804 .84769 m .58945 .84733 L .58922 .84714 L F
.503 .881 .973 r
.58804 .84769 m .5907 .84699 L .58945 .84733 L F
.041 .61 .73 r
.5907 .84699 m .58961 .84731 L .58945 .84733 L F
.503 .881 .973 r
.58946 .84732 m .58961 .84731 L .5907 .84699 L F
.58961 .84731 m .59007 .84729 L .5907 .84699 L F
.041 .61 .73 r
.5907 .84699 m .59235 .84693 L .58961 .84731 L F
.195 .723 .83 r
.58922 .84714 m .58943 .84732 L .59235 .84693 L F
.58943 .84732 m .58945 .84733 L .58961 .84731 L F
.58943 .84732 m .58961 .84731 L .59235 .84693 L F
.503 .881 .973 r
.58804 .84769 m .58902 .84779 L .59007 .84729 L F
.58804 .84769 m .59007 .84729 L .58946 .84732 L F
.911 .565 .375 r
.5402 .83712 m .53877 .83747 L .53731 .83515 L F
.59 .678 .901 r
.3881 .74634 m .38996 .74876 L .39181 .74837 L F
.689 .603 .755 r
.38996 .74876 m .3928 .74927 L .39181 .74837 L F
.676 .355 .424 r
.44921 .86455 m .4467 .8662 L .44678 .86397 L F
.44921 .86455 m .44983 .86637 L .4467 .8662 L F
.48 .478 .777 r
.69421 .70867 m .69505 .71186 L .69319 .71186 L F
.786 .635 .694 r
.50808 .82603 m .50517 .82846 L .50437 .82703 L F
.50808 .82603 m .50437 .82703 L .50732 .82801 L F
.221 0 .254 r
.50808 .82603 m .50985 .82565 L .50973 .82571 L F
.50808 .82603 m .50732 .82801 L .50985 .82565 L F
.38 .23 .549 r
.48713 .8525 m .48523 .85118 L .49018 .84939 L F
.222 .118 .518 r
.49057 .84858 m .4908 .85048 L .49018 .84939 L F
.486 .084 .203 r
.4908 .85048 m .48713 .8525 L .49018 .84939 L F
.87 .755 .734 r
.48111 .85889 m .48438 .8566 L .48056 .85925 L F
.873 .97 .85 r
.47837 .86082 m .47882 .86149 L .48111 .85889 L F
.47837 .86082 m .48111 .85889 L .47913 .86091 L F
.54 .839 .516 r
.48115 .85885 m .47913 .86091 L .48111 .85889 L F
.568 .886 .611 r
.48204 .85786 m .48111 .85889 L .48056 .85925 L F
.801 .991 .878 r
.48204 .85786 m .48056 .85925 L .48108 .85888 L F
.54 .839 .516 r
.48204 .85786 m .48108 .85888 L .48115 .85885 L F
.801 .991 .878 r
.48204 .85786 m .48108 .85888 L .4854 .85584 L F
.54 .839 .516 r
.48204 .85786 m .48106 .85889 L .48108 .85888 L F
.48106 .85889 m .47913 .86091 L .48115 .85885 L F
.424 .818 .594 r
.4854 .85584 m .48108 .85888 L .48438 .8566 L F
.48108 .85888 m .48056 .85925 L .4811 .85887 L F
.48108 .85888 m .4811 .85887 L .48438 .8566 L F
.846 .445 .281 r
.55773 .79179 m .55642 .79248 L .55842 .79253 L F
.703 .501 .612 r
.44994 .84874 m .44985 .85113 L .44669 .85023 L F
.733 .527 .613 r
.45318 .85108 m .44985 .85113 L .44994 .84874 L F
.585 .394 .588 r
.36644 .79348 m .36589 .79764 L .36276 .79558 L F
.417 .148 .395 r
.365 .79766 m .36276 .79558 L .36589 .79764 L F
.365 .79766 m .3633 .79812 L .36276 .79558 L F
.714 .541 .653 r
.37317 .87218 m .37262 .86969 L .37285 .87218 L F
0 0 .05 r
.49885 .84865 m .4977 .85016 L .49889 .84774 L F
.73 .248 .101 r
.49856 .84779 m .49885 .84865 L .49889 .84774 L F
.948 .728 .572 r
.49889 .84774 m .4977 .85016 L .49856 .84779 L F
.798 .702 .759 r
.5666 .79886 m .5673 .79896 L .56627 .79616 L F
.827 .585 .573 r
.5666 .79886 m .56732 .80126 L .5673 .79896 L F
.69 .552 .693 r
.59769 .76242 m .59799 .76486 L .60015 .76224 L F
.153 0 0 r
.48086 .86342 m .48299 .86223 L .48055 .86281 L F
0 .172 .656 r
.67232 .72949 m .6715 .73029 L .67227 .72937 L F
0 0 .438 r
.67389 .73212 m .67285 .7307 L .6715 .73029 L F
0 .172 .656 r
.67318 .73137 m .6715 .73029 L .67232 .72949 L F
.435 .823 .987 r
.67111 .73067 m .6715 .73029 L .67285 .7307 L F
.66939 .73063 m .6715 .73029 L .67111 .73067 L F
0 0 .438 r
.67389 .73212 m .67454 .7333 L .67285 .7307 L F
.601 .538 .756 r
.43729 .8671 m .43417 .86435 L .43608 .86396 L F
.635 .671 .867 r
.496 .87654 m .49501 .87757 L .49295 .87625 L F
.698 .534 .662 r
.38245 .86463 m .38475 .86427 L .38461 .86187 L F
.615 .437 .618 r
.38475 .86427 m .38687 .86171 L .38461 .86187 L F
.838 .883 .874 r
.39363 .89558 m .39515 .89618 L .39671 .89457 L F
.647 .19 .153 r
.51726 .84008 m .52055 .84029 L .51861 .83886 L F
.572 .274 .425 r
.51861 .83886 m .52055 .84029 L .52091 .83853 L F
.544 .402 .638 r
.41775 .75636 m .41555 .75423 L .41771 .75387 L F
.41775 .75636 m .41578 .75689 L .41555 .75423 L F
.606 .921 .973 r
.67777 .75745 m .68066 .75716 L .67949 .75613 L F
.486 .02 .073 r
.67952 .75679 m .68119 .75766 L .67957 .7578 L F
.67949 .75613 m .67991 .75651 L .67952 .75679 L F
.67991 .75651 m .68119 .75766 L .67952 .75679 L F
.606 .921 .973 r
.67874 .75735 m .67856 .75803 L .68066 .75716 L F
.67777 .75745 m .67818 .75775 L .67874 .75735 L F
.67818 .75775 m .67856 .75803 L .67874 .75735 L F
.31 .155 .503 r
.65317 .75644 m .65512 .75638 L .65546 .75391 L F
.263 0 .189 r
.65317 .75644 m .65264 .75844 L .65512 .75638 L F
.426 .87 .853 r
.48486 .88385 m .48459 .88427 L .487 .88328 L F
.98 .693 .394 r
.57093 .83262 m .5718 .83297 L .57134 .83225 L F
.36 .808 .67 r
.65719 .76673 m .65589 .76746 L .65752 .76661 L F
.35 .792 .632 r
.65538 .76773 m .65589 .76746 L .65719 .76673 L F
.711 .204 .025 r
.57752 .77741 m .5776 .77749 L .57483 .77828 L F
0 0 0 r
.5776 .77749 m .5735 .77798 L .57483 .77828 L F
.602 .426 .616 r
.40069 .84865 m .40282 .84828 L .4028 .84608 L F
.632 .477 .654 r
.4028 .84608 m .40513 .84592 L .40492 .84336 L F
.636 .46 .628 r
.40282 .84828 m .40513 .84592 L .4028 .84608 L F
.445 .704 .977 r
.51525 .83581 m .51616 .83434 L .51339 .83633 L F
.068 0 .255 r
.61309 .8141 m .61205 .81477 L .61374 .81201 L F
.15 0 .398 r
.61173 .81695 m .61205 .81477 L .61309 .8141 L F
.557 .624 .874 r
.39657 .73614 m .39583 .73877 L .39436 .73625 L F
.39657 .73614 m .39781 .73852 L .39583 .73877 L F
.602 .176 .206 r
.51733 .82002 m .5158 .82162 L .51383 .82057 L F
.909 .615 .476 r
.51733 .82002 m .51733 .82252 L .5158 .82162 L F
.49 .324 .583 r
.52318 .80944 m .52503 .81072 L .5253 .80905 L F
.52318 .80944 m .52316 .81165 L .52503 .81072 L F
.65 .487 .65 r
.39847 .85129 m .40075 .85125 L .40069 .84865 L F
.632 .485 .664 r
.40075 .85125 m .40282 .84828 L .40069 .84865 L F
.424 .023 .173 r
.56078 .79585 m .56293 .79564 L .56423 .79422 L F
.771 .552 .603 r
.56293 .79564 m .56673 .79382 L .56423 .79422 L F
.981 .77 .359 r
.52488 .83042 m .52506 .8332 L .5247 .83299 L F
.638 .546 .734 r
.54103 .84107 m .54318 .84043 L .54268 .83853 L F
.697 .425 .508 r
.502 .8167 m .50532 .81444 L .5021 .81506 L F
.502 .8167 m .50411 .81705 L .50532 .81444 L F
.649 .371 .485 r
.50532 .81444 m .50411 .81705 L .50737 .81656 L F
.755 .945 .943 r
.45975 .88534 m .46231 .88331 L .45875 .88482 L F
.65 .464 .619 r
.37317 .87218 m .37522 .87198 L .37521 .86963 L F
.66 .477 .626 r
.37522 .87198 m .37812 .86961 L .37521 .86963 L F
.711 .51 .616 r
.49664 .82976 m .50013 .82766 L .4968 .82775 L F
0 0 0 r
.56485 .77538 m .56542 .77569 L .56674 .77473 L F
.56485 .77538 m .56324 .77653 L .56542 .77569 L F
.891 .881 .817 r
.57432 .83483 m .57334 .83838 L .57327 .83622 L F
.075 .036 .504 r
.5713 .83904 m .57217 .83498 L .57302 .83797 L F
.939 .918 .544 r
.57329 .83683 m .57334 .83838 L .5727 .83933 L F
.075 .036 .504 r
.57299 .83808 m .57302 .83797 L .57304 .83805 L F
.5713 .83904 m .57302 .83797 L .57299 .83808 L F
.939 .918 .544 r
.57299 .83808 m .5727 .83933 L .57218 .8401 L F
0 0 .481 r
.57299 .83808 m .57218 .8401 L .57304 .83805 L F
.5713 .83904 m .57218 .8401 L .57299 .83808 L F
.855 .619 .582 r
.57158 .83779 m .57298 .83804 L .57217 .83498 L F
.57298 .83804 m .57304 .83805 L .57302 .83797 L F
.57298 .83804 m .57302 .83797 L .57217 .83498 L F
.939 .918 .544 r
.5729 .83826 m .57299 .83808 L .57218 .8401 L F
.852 .684 .673 r
.57218 .8401 m .57304 .83805 L .57298 .83804 L F
.57218 .8401 m .57298 .83804 L .57158 .83779 L F
.939 .918 .544 r
.57263 .83877 m .5729 .83826 L .57218 .8401 L F
.57329 .83683 m .57302 .83797 L .57263 .83877 L F
.57302 .83797 m .57299 .83808 L .57263 .83877 L F
.57327 .83622 m .57329 .83683 L .57218 .8401 L F
.759 .597 .676 r
.53853 .83073 m .53893 .83299 L .53744 .83271 L F
0 0 .163 r
.54019 .82942 m .53853 .83073 L .54075 .82713 L F
.489 .598 .888 r
.54019 .82942 m .54096 .83099 L .53853 .83073 L F
.705 .94 .96 r
.46231 .88331 m .4653 .8826 L .46429 .88252 L F
.036 .605 .756 r
.4653 .8826 m .46744 .88261 L .46429 .88252 L F
.798 .71 .768 r
.57156 .78306 m .57273 .78593 L .57478 .78358 L F
.478 .191 .398 r
.35984 .79849 m .35897 .8011 L .35702 .80125 L F
.441 .155 .382 r
.3609 .80063 m .35984 .79849 L .36166 .79877 L F
.3609 .80063 m .35897 .8011 L .35984 .79849 L F
.824 .687 .147 r
.66144 .71227 m .66128 .71277 L .66038 .71205 L F
.65997 .7116 m .66038 .71205 L .65964 .71145 L F
.66144 .71227 m .66038 .71205 L .65997 .7116 L F
.174 .203 .651 r
.66078 .71248 m .66122 .71296 L .66064 .71309 L F
.824 .687 .147 r
.66128 .71277 m .66122 .71296 L .66063 .7124 L F
.174 .203 .651 r
.66126 .71046 m .66122 .71296 L .66078 .71248 L F
.824 .687 .147 r
.66128 .71277 m .66063 .7124 L .65964 .71145 L F
.565 .619 .864 r
.66126 .71046 m .65964 .71145 L .66084 .70903 L F
.66126 .71046 m .66084 .70903 L .66084 .70902 L F
.174 .203 .651 r
.66126 .71046 m .66285 .71271 L .66122 .71296 L F
.081 .384 .845 r
.66285 .71271 m .66156 .71145 L .66126 .71046 L F
.565 .619 .864 r
.66126 .71046 m .65854 .71073 L .65964 .71145 L F
.66126 .71046 m .66078 .71248 L .65854 .71073 L F
.081 .384 .845 r
.66156 .71145 m .65997 .7099 L .66126 .71046 L F
.112 .221 .698 r
.65964 .71145 m .66063 .7124 L .66064 .71309 L F
.565 .619 .864 r
.66078 .71248 m .66064 .71309 L .66063 .7124 L F
.112 .221 .698 r
.66063 .7124 m .66122 .71296 L .66064 .71309 L F
.565 .619 .864 r
.66063 .7124 m .66064 .71309 L .65938 .71168 L F
.112 .221 .698 r
.65964 .71145 m .66064 .71309 L .65854 .71073 L F
.565 .619 .864 r
.66078 .71248 m .65938 .71168 L .65854 .71073 L F
.824 .687 .147 r
.66144 .71227 m .66125 .71497 L .66122 .71296 L F
.771 .552 .603 r
.56293 .79564 m .56627 .79616 L .56673 .79382 L F
.724 .641 .766 r
.56503 .79079 m .56673 .79382 L .56876 .79161 L F
.834 .999 .79 r
.64016 .77466 m .63842 .77747 L .64045 .77497 L F
.64016 .77466 m .6379 .77723 L .63842 .77747 L F
.399 .099 .336 r
.38422 .78215 m .38318 .78041 L .38518 .78007 L F
.38422 .78215 m .38235 .78265 L .38318 .78041 L F
.447 .727 .986 r
.6692 .74574 m .66958 .74706 L .66852 .74694 L F
0 0 0 r
.6692 .74574 m .66812 .74777 L .6694 .74538 L F
.896 .972 .82 r
.67185 .74344 m .6692 .74574 L .67038 .74357 L F
0 0 0 r
.6692 .74574 m .6694 .74538 L .67038 .74357 L F
.447 .727 .986 r
.6692 .74574 m .66852 .74694 L .66768 .74685 L F
.147 .589 .93 r
.66766 .74811 m .6692 .74574 L .66768 .74685 L F
.053 .587 .859 r
.51325 .85123 m .51211 .85081 L .51019 .85053 L F
.095 .198 .682 r
.51325 .85123 m .51428 .85057 L .51211 .85081 L F
.574 .526 .763 r
.51556 .85109 m .51551 .85473 L .51325 .85123 L F
.095 .198 .682 r
.51325 .85123 m .51551 .85473 L .51428 .85057 L F
.21 0 0 r
.57264 .8174 m .5741 .81721 L .57112 .81722 L F
0 0 .163 r
.54019 .82942 m .54075 .82713 L .54023 .82739 L F
.112 .518 .911 r
.54075 .82713 m .54345 .82847 L .5416 .8268 L F
.54075 .82713 m .5416 .8268 L .54023 .82739 L F
.669 .835 .963 r
.48476 .87067 m .48133 .87121 L .48351 .86951 L F
.867 .847 .822 r
.48618 .86875 m .48476 .87067 L .48351 .86951 L F
.436 .74 .992 r
.48822 .883 m .49037 .88431 L .49171 .88355 L F
.64 .487 .659 r
.40513 .84592 m .40724 .84311 L .40492 .84336 L F
.162 .298 .756 r
.38862 .75743 m .38938 .75979 L .39037 .75897 L F
.329 .283 .654 r
.38938 .75979 m .3911 .76139 L .39037 .75897 L F
.38938 .75979 m .38982 .7622 L .3911 .76139 L F
.603 .169 .19 r
.50238 .84124 m .5011 .84287 L .4992 .84247 L F
.63 .221 .249 r
.50238 .84124 m .50438 .8429 L .50247 .84233 L F
.578 .562 .799 r
.50261 .84504 m .50357 .84592 L .50247 .84233 L F
.77 .674 .757 r
.50247 .84233 m .50357 .84592 L .5056 .84331 L F
.50247 .84233 m .5056 .84331 L .50438 .8429 L F
.64 .212 .214 r
.50438 .8429 m .5011 .84287 L .50238 .84124 L F
.009 0 .298 r
.60792 .82732 m .60844 .82512 L .60982 .8243 L F
.791 .846 .893 r
.38058 .89844 m .3822 .89929 L .38401 .89816 L F
.272 .777 .829 r
.51217 .82533 m .50973 .82571 L .51202 .82513 L F
.333 0 0 r
.50985 .82565 m .51202 .82513 L .50973 .82571 L F
.50985 .82565 m .51055 .82627 L .51202 .82513 L F
.743 .964 .681 r
.51202 .82513 m .51055 .82627 L .51179 .82485 L F
.51202 .82513 m .51179 .82485 L .51251 .82402 L F
.272 .777 .829 r
.51295 .82521 m .51217 .82533 L .51202 .82513 L F
.595 .892 .989 r
.51494 .82449 m .51295 .82521 L .51385 .824 L F
.653 .966 .912 r
.51295 .82521 m .51202 .82513 L .51385 .824 L F
.539 .892 .978 r
.36034 .72611 m .35702 .72644 L .359 .72552 L F
.68 .906 .975 r
.36034 .72611 m .359 .72552 L .36082 .72465 L F
.36 0 .088 r
.35747 .72672 m .36065 .72476 L .359 .72552 L F
.36065 .72476 m .36082 .72465 L .359 .72552 L F
.539 .892 .978 r
.35702 .72644 m .35674 .72647 L .359 .72552 L F
.68 .906 .975 r
.36034 .72611 m .36082 .72465 L .36203 .72576 L F
.711 .51 .616 r
.49664 .82976 m .50051 .83063 L .50013 .82766 L F
.947 .878 .735 r
.68329 .74317 m .68565 .74128 L .68484 .74055 L F
.68329 .74317 m .68433 .74439 L .68565 .74128 L F
.83 .396 .203 r
.68565 .74128 m .68524 .74278 L .68484 .74055 L F
.68565 .74128 m .68762 .74372 L .68524 .74278 L F
.682 .512 .65 r
.4142 .83542 m .41654 .83537 L .41641 .83301 L F
.607 .455 .649 r
.41641 .83301 m .41869 .83511 L .41865 .83274 L F
.41641 .83301 m .41654 .83537 L .41869 .83511 L F
0 .126 .633 r
.54692 .81621 m .54563 .81536 L .54456 .81474 L F
.54692 .81621 m .54787 .81727 L .54563 .81536 L F
.042 0 .428 r
.66957 .71464 m .66824 .71586 L .66903 .71447 L F
.471 .506 .812 r
.67136 .71709 m .66824 .71586 L .66957 .71464 L F
.67136 .71709 m .66981 .71759 L .66824 .71586 L F
.636 .57 .764 r
.38953 .73504 m .38658 .73282 L .38801 .73291 L F
.364 .494 .856 r
.45343 .86539 m .45417 .86364 L .45265 .86525 L F
.45343 .86539 m .45624 .86618 L .45417 .86364 L F
.697 .55 .684 r
.39417 .85395 m .39626 .85385 L .39625 .85157 L F
.703 .555 .684 r
.39626 .85385 m .39847 .85129 L .39625 .85157 L F
0 .53 .803 r
.49123 .8694 m .4898 .86929 L .48913 .86843 L F
.199 0 0 r
.49219 .86976 m .49096 .86945 L .4898 .86929 L F
.809 .805 .847 r
.48959 .86823 m .49123 .8694 L .49252 .86809 L F
.527 .836 .521 r
.49128 .86932 m .49123 .8694 L .49252 .86809 L F
.49 .8706 m .49123 .8694 L .49128 .86932 L F
0 .53 .803 r
.49123 .8694 m .49219 .86976 L .49113 .86955 L F
.49123 .8694 m .49113 .86955 L .4898 .86929 L F
.796 .843 .887 r
.62653 .77457 m .62523 .77588 L .62395 .77483 L F
.613 .809 .976 r
.56281 .78485 m .56167 .78642 L .56402 .78571 L F
.56281 .78485 m .56167 .78642 L .56402 .78571 L F
.591 .617 .847 r
.56167 .78642 m .56471 .78783 L .56402 .78571 L F
.632 .452 .621 r
.39626 .85385 m .39852 .85376 L .39847 .85129 L F
.601 .399 .581 r
.39852 .85376 m .40075 .85125 L .39847 .85129 L F
.481 .12 .276 r
.47635 .82469 m .47856 .82454 L .47952 .82235 L F
.171 0 .129 r
.47952 .82235 m .48035 .82359 L .4815 .8219 L F
.47952 .82235 m .47856 .82454 L .48035 .82359 L F
.713 .657 .793 r
.49789 .83284 m .50301 .83297 L .50051 .83063 L F
.695 .464 .569 r
.49792 .83523 m .50301 .83297 L .49789 .83284 L F
.49792 .83523 m .50168 .83524 L .50301 .83297 L F
.493 .611 .897 r
.50051 .83063 m .50301 .83297 L .50327 .8328 L F
.705 .477 .575 r
.50301 .83297 m .50358 .83517 L .50327 .8328 L F
.50301 .83297 m .50168 .83524 L .50358 .83517 L F
.632 .219 .242 r
.59441 .76615 m .59799 .76486 L .59511 .76508 L F
.59441 .76615 m .59708 .76658 L .59799 .76486 L F
.519 .317 .547 r
.59799 .76486 m .60008 .76461 L .60015 .76224 L F
0 0 0 r
.59799 .76486 m .59922 .76254 L .60008 .76461 L F
.59799 .76486 m .59708 .76658 L .59922 .76254 L F
.551 .344 .552 r
.60015 .76224 m .60225 .76412 L .60238 .7619 L F
.60015 .76224 m .60008 .76461 L .60225 .76412 L F
.436 .86 .728 r
.49546 .88275 m .4973 .88175 L .4964 .88206 L F
.437 .875 .82 r
.49451 .8829 m .49546 .88275 L .4964 .88206 L F
.806 .798 .844 r
.4802 .86877 m .48133 .87121 L .47918 .87211 L F
.64 .719 .905 r
.48351 .86951 m .48133 .87121 L .4802 .86877 L F
.51 .241 .444 r
.3759 .78594 m .37292 .79056 L .37303 .7888 L F
.3759 .78594 m .37491 .79038 L .37292 .79056 L F
.435 .17 .412 r
.37797 .78523 m .3759 .78594 L .37594 .7856 L F
.37797 .78523 m .37733 .78781 L .3759 .78594 L F
.455 .192 .425 r
.37679 .78981 m .3759 .78594 L .37733 .78781 L F
.37679 .78981 m .37491 .79038 L .3759 .78594 L F
.414 .053 .24 r
.35394 .75131 m .35119 .75183 L .35195 .75159 L F
.599 .453 .655 r
.56319 .79042 m .56503 .79079 L .56471 .78783 L F
.533 .053 .063 r
.51168 .82034 m .51041 .8221 L .50867 .8207 L F
.422 0 .003 r
.51326 .82061 m .51168 .82034 L .51373 .82056 L F
.51326 .82061 m .51041 .8221 L .51168 .82034 L F
.877 .651 .592 r
.5096 .82099 m .51326 .82061 L .51166 .81834 L F
.50953 .82109 m .51326 .82061 L .5096 .82099 L F
.422 0 .003 r
.51326 .82061 m .51373 .82056 L .51383 .82057 L F
.656 .461 .609 r
.51645 .83046 m .51919 .82772 L .51591 .82755 L F
.592 .55 .777 r
.5214 .83071 m .52002 .83211 L .52012 .83027 L F
.656 .461 .609 r
.51834 .82857 m .5214 .83071 L .51919 .82772 L F
.51753 .82938 m .52012 .83027 L .51834 .82857 L F
.52012 .83027 m .5214 .83071 L .51834 .82857 L F
.592 .55 .777 r
.5214 .83071 m .52027 .82722 L .51919 .82772 L F
.5214 .83071 m .52012 .83027 L .52027 .82722 L F
.476 .45 .749 r
.52027 .82722 m .52012 .83027 L .52307 .82953 L F
.637 .931 .674 r
.5214 .83071 m .52081 .83127 L .52002 .83211 L F
.476 .45 .749 r
.52053 .83067 m .52002 .83211 L .52081 .83127 L F
.52011 .83042 m .52002 .83211 L .52053 .83067 L F
.757 .717 .815 r
.51615 .83234 m .51937 .83265 L .52081 .83127 L F
.52088 .83087 m .52081 .83127 L .5214 .83071 L F
.476 .45 .749 r
.52053 .83067 m .52081 .83127 L .52086 .83098 L F
.757 .717 .815 r
.51615 .83234 m .52081 .83127 L .52088 .83087 L F
.476 .45 .749 r
.52086 .83098 m .52081 .83127 L .52098 .8311 L F
.52012 .83027 m .52011 .83042 L .52053 .83067 L F
.757 .717 .815 r
.51615 .83234 m .52088 .83087 L .51645 .83046 L F
.52088 .83087 m .5214 .83071 L .52053 .83067 L F
.52088 .83087 m .52053 .83067 L .51645 .83046 L F
.637 .931 .674 r
.52081 .83127 m .51937 .83265 L .52002 .83211 L F
.476 .45 .749 r
.52098 .8311 m .52002 .83211 L .52109 .83121 L F
.656 .461 .609 r
.51645 .83046 m .5214 .83071 L .51753 .82938 L F
.476 .45 .749 r
.52012 .83027 m .52109 .83121 L .52307 .82953 L F
.228 .291 .721 r
.51919 .82772 m .52027 .82722 L .51856 .82465 L F
0 .13 .675 r
.56904 .80617 m .57089 .8085 L .57051 .80916 L F
0 0 .568 r
.57089 .8085 m .57174 .81143 L .57051 .80916 L F
.562 .448 .681 r
.40841 .74907 m .40676 .75165 L .4064 .74955 L F
.40841 .74907 m .40878 .75132 L .40676 .75165 L F
.241 .01 .35 r
.6195 .80134 m .62184 .79891 L .62121 .80092 L F
.235 0 .337 r
.61928 .80354 m .6195 .80134 L .62121 .80092 L F
.558 .544 .795 r
.39322 .73313 m .39251 .73661 L .39144 .73476 L F
.39322 .73313 m .39436 .73625 L .39251 .73661 L F
.71 .836 .942 r
.52575 .87395 m .52648 .87488 L .52332 .8749 L F
.508 .211 .398 r
.52191 .87467 m .52332 .8749 L .52176 .87464 L F
.309 .497 .88 r
.52569 .87706 m .52332 .8749 L .52629 .8754 L F
0 0 .043 r
.52569 .87706 m .52648 .87488 L .52742 .87405 L F
.52569 .87706 m .52742 .87405 L .52759 .87643 L F
.508 .211 .398 r
.5268 .87563 m .52332 .8749 L .52191 .87467 L F
.309 .497 .88 r
.52629 .8754 m .52332 .8749 L .52648 .87488 L F
.328 .636 .964 r
.52742 .87405 m .52648 .87488 L .52575 .87395 L F
.791 .846 .893 r
.38058 .89844 m .38401 .89816 L .38259 .89778 L F
.801 .914 .916 r
.38498 .89565 m .38401 .89816 L .38624 .89733 L F
.38498 .89565 m .38259 .89778 L .38401 .89816 L F
.789 .738 .806 r
.47213 .85362 m .46922 .85351 L .47151 .85093 L F
.803 .649 .692 r
.47213 .85362 m .47078 .85638 L .46922 .85351 L F
.529 .17 .302 r
.58177 .76912 m .58521 .76694 L .58213 .76808 L F
.58177 .76912 m .58404 .76914 L .58521 .76694 L F
.643 .298 .372 r
.58404 .76914 m .58726 .76732 L .58521 .76694 L F
.871 .792 .77 r
.48593 .86828 m .48618 .86875 L .48351 .86951 L F
.794 .515 .514 r
.55637 .79546 m .55842 .79253 L .55642 .79248 L F
.55637 .79546 m .55831 .79568 L .55842 .79253 L F
.834 .551 .509 r
.55842 .79253 m .55831 .79568 L .56078 .79585 L F
.676 .675 .842 r
.44828 .87078 m .44696 .87368 L .44587 .87111 L F
.44828 .87078 m .44921 .87309 L .44696 .87368 L F
.437 .451 .777 r
.60849 .74152 m .61053 .74037 L .60838 .74074 L F
.60849 .74152 m .61128 .7434 L .61053 .74037 L F
.585 .416 .619 r
.60849 .74152 m .61171 .74574 L .61128 .7434 L F
.60849 .74152 m .60975 .74664 L .61171 .74574 L F
.439 .12 .326 r
.39215 .77533 m .38957 .77733 L .39025 .77575 L F
.688 .659 .816 r
.60742 .75248 m .60315 .75165 L .6053 .75129 L F
.678 .267 .259 r
.6053 .75129 m .60874 .75146 L .60742 .75248 L F
.334 0 0 r
.35478 .72626 m .35546 .72697 L .35674 .72647 L F
.471 .24 .482 r
.39914 .7696 m .39678 .77221 L .39709 .77002 L F
.57 .012 0 r
.54477 .80085 m .54145 .79842 L .5426 .79893 L F
.656 .102 0 r
.54604 .80139 m .54477 .80085 L .5426 .79893 L F
.75 .987 .899 r
.54712 .8314 m .54948 .83033 L .54858 .82987 L F
.839 .794 .298 r
.61734 .78297 m .61686 .78449 L .61681 .78277 L F
.761 .504 .545 r
.59688 .77765 m .595 .77522 L .59695 .77525 L F
.705 .493 .598 r
.60028 .77767 m .59688 .77765 L .59695 .77525 L F
.976 .683 .391 r
.70746 .71522 m .70673 .71476 L .70854 .71411 L F
.475 .477 .78 r
.70715 .71715 m .70455 .71539 L .70673 .71476 L F
.976 .683 .391 r
.70607 .71663 m .70715 .71715 L .70673 .71476 L F
.70607 .71663 m .7065 .71542 L .70746 .71522 L F
.7065 .71542 m .70673 .71476 L .70746 .71522 L F
.475 .477 .78 r
.70715 .71715 m .70528 .71742 L .7047 .7158 L F
.70506 .71573 m .7047 .7158 L .70455 .71539 L F
.70715 .71715 m .7047 .7158 L .70506 .71573 L F
.3 .366 .764 r
.70611 .71899 m .70528 .71742 L .70715 .71715 L F
.461 .467 .778 r
.66612 .75362 m .66334 .75163 L .66487 .75146 L F
0 0 0 r
.66222 .75318 m .66487 .75146 L .66334 .75163 L F
.489 .016 .058 r
.48347 .82143 m .48584 .82158 L .48729 .82027 L F
.487 .085 .204 r
.48584 .82158 m .48919 .81969 L .48729 .82027 L F
.428 .87 .878 r
.5852 .84838 m .58608 .84839 L .58804 .84769 L F
.304 .777 .932 r
.58087 .84929 m .58197 .84876 L .57973 .84883 L F
.58087 .84929 m .58314 .84905 L .58197 .84876 L F
.737 .666 .78 r
.53744 .83271 m .53893 .83299 L .53536 .8335 L F
.805 .545 .545 r
.53893 .83299 m .53556 .83462 L .53536 .8335 L F
.53893 .83299 m .53731 .83515 L .53556 .83462 L F
.228 0 0 r
.5279 .80694 m .52952 .80701 L .53137 .8068 L F
.429 0 0 r
.52952 .80701 m .53289 .80771 L .53137 .8068 L F
0 0 .459 r
.55212 .82337 m .55092 .82189 L .55075 .82197 L F
.703 .169 0 r
.55106 .82287 m .55212 .82337 L .55075 .82197 L F
.144 .639 .913 r
.55106 .82287 m .55197 .82311 L .55212 .82337 L F
.55197 .82311 m .55355 .82353 L .55212 .82337 L F
0 0 .459 r
.55212 .82337 m .55333 .82506 L .55243 .82388 L F
.55212 .82337 m .55243 .82388 L .55092 .82189 L F
.607 .158 0 r
.55323 .8251 m .55092 .82189 L .55333 .82506 L F
.87 .954 .861 r
.60667 .801 m .60669 .80183 L .60607 .80062 L F
.976 .923 .648 r
.60607 .80062 m .60669 .80183 L .60579 .80358 L F
.97 .835 .655 r
.47786 .86205 m .47585 .86326 L .47362 .86199 L F
.47786 .86205 m .47684 .86433 L .47585 .86326 L F
.563 .503 .746 r
.60415 .74605 m .60733 .74859 L .606 .74851 L F
.618 .481 .672 r
.5292 .84039 m .52678 .83833 L .52907 .83811 L F
.5292 .84039 m .52702 .84078 L .52678 .83833 L F
.731 .679 .8 r
.56911 .78548 m .57273 .78593 L .57156 .78306 L F
.772 .544 .589 r
.56911 .78548 m .57122 .78685 L .57273 .78593 L F
.572 .446 .669 r
.4162 .90685 m .4166 .90954 L .41839 .90859 L F
.493 .143 .301 r
.35353 .78786 m .35665 .78563 L .35636 .78578 L F
.469 .153 .348 r
.5253 .80905 m .52713 .80889 L .5279 .80694 L F
.378 .018 .223 r
.52713 .80889 m .52952 .80701 L .5279 .80694 L F
.333 0 .145 r
.62338 .73326 m .62573 .73279 L .62538 .73022 L F
.62338 .73326 m .62365 .7333 L .62573 .73279 L F
.493 .281 .52 r
.6806 .71966 m .68037 .71875 L .67913 .71887 L F
.68037 .71875 m .6799 .7169 L .67939 .71819 L F
.68037 .71875 m .67939 .71819 L .67913 .71887 L F
.697 .16 0 r
.67671 .71645 m .67784 .7173 L .67619 .71538 L F
.47 .04 .141 r
.67939 .71819 m .6797 .71868 L .67913 .71887 L F
.6799 .7169 m .6797 .71868 L .67939 .71819 L F
.697 .16 0 r
.67784 .7173 m .6797 .71868 L .67883 .71787 L F
.67784 .7173 m .67883 .71787 L .67619 .71538 L F
.773 .321 .175 r
.67619 .71538 m .6797 .71868 L .6799 .7169 L F
0 .536 .818 r
.68231 .71732 m .68345 .71774 L .6799 .7169 L F
.493 .281 .52 r
.6806 .71966 m .68231 .71732 L .6799 .7169 L F
.231 0 .217 r
.35894 .7833 m .35665 .78563 L .35847 .78482 L F
.629 .284 .368 r
.35847 .78482 m .36072 .78504 L .35894 .7833 L F
.571 .294 .458 r
.35894 .7833 m .36072 .78504 L .36105 .78317 L F
.352 0 .062 r
.64391 .72743 m .64621 .72696 L .64679 .72598 L F
.264 0 0 r
.64789 .72646 m .64679 .72598 L .64621 .72696 L F
.611 .73 .93 r
.64679 .72598 m .64901 .72541 L .64878 .72604 L F
.264 0 0 r
.64789 .72646 m .64901 .72541 L .64679 .72598 L F
.721 .539 .643 r
.44669 .85023 m .4446 .85131 L .44556 .84881 L F
.635 .53 .717 r
.40674 .83838 m .407 .84068 L .40904 .84039 L F
.652 .515 .684 r
.40724 .84311 m .40904 .84039 L .407 .84068 L F
.624 .435 .606 r
.39129 .85652 m .39385 .85667 L .39417 .85395 L F
.677 .439 .553 r
.39607 .85635 m .39417 .85395 L .39385 .85667 L F
.39607 .85635 m .39626 .85385 L .39417 .85395 L F
.385 .595 .929 r
.40026 .89535 m .40097 .89466 L .39867 .89472 L F
0 .39 .846 r
.5788 .7785 m .58075 .77887 L .57752 .77741 L F
.5788 .7785 m .58117 .77967 L .58075 .77887 L F
.632 .283 .361 r
.58726 .76732 m .58936 .76898 L .59044 .76675 L F
.553 .215 .35 r
.58936 .76898 m .5924 .76685 L .59044 .76675 L F
.601 .637 .859 r
.60733 .74859 m .60807 .75021 L .60555 .74927 L F
.60555 .74927 m .60807 .75021 L .60733 .74859 L F
.60555 .74927 m .60807 .75021 L .60733 .74859 L F
.451 .233 .491 r
.60555 .74927 m .6053 .75129 L .60733 .74859 L F
.60555 .74927 m .6053 .75129 L .60733 .74859 L F
.656 .517 .682 r
.32824 .6678 m .33011 .66594 L .3283 .66769 L F
.632 .535 .727 r
.40841 .74907 m .4064 .74955 L .40556 .74651 L F
.959 .659 .237 r
.55389 .82954 m .55494 .83256 L .55459 .83035 L F
.743 .641 .748 r
.6392 .71739 m .63746 .72099 L .63698 .71769 L F
.673 .796 .941 r
.65591 .75897 m .6591 .75927 L .65707 .76013 L F
.838 .883 .874 r
.39363 .89558 m .39671 .89457 L .39497 .89421 L F
.296 .677 .974 r
.39671 .89457 m .39769 .89422 L .39497 .89421 L F
.39671 .89457 m .39867 .89472 L .39769 .89422 L F
.836 .647 .647 r
.56293 .79564 m .5666 .79886 L .56627 .79616 L F
.56293 .79564 m .56317 .79836 L .5666 .79886 L F
.834 .597 .579 r
.56295 .8007 m .5666 .79886 L .56317 .79836 L F
.56295 .8007 m .56469 .80142 L .5666 .79886 L F
.827 .585 .573 r
.5666 .79886 m .56469 .80142 L .56732 .80126 L F
.615 .437 .618 r
.38475 .86427 m .38686 .86406 L .38687 .86171 L F
.671 .533 .688 r
.38687 .86171 m .38981 .86177 L .38907 .85892 L F
.682 .504 .639 r
.38686 .86406 m .38981 .86177 L .38687 .86171 L F
.015 0 0 r
.56873 .77392 m .57115 .77357 L .57245 .77304 L F
.337 0 0 r
.57115 .77357 m .57452 .77247 L .57245 .77304 L F
.507 .844 .997 r
.61595 .73816 m .6192 .73844 L .61697 .73687 L F
.631 .501 .686 r
.6192 .73844 m .62167 .73809 L .62115 .73565 L F
.423 .359 .681 r
.6192 .73844 m .62163 .74039 L .62167 .73809 L F
.6192 .73844 m .61967 .74123 L .62163 .74039 L F
.615 .422 .598 r
.42098 .83244 m .42377 .83005 L .42108 .83032 L F
.645 .561 .745 r
.55757 .78035 m .55797 .7827 L .55956 .78186 L F
.78 .68 .754 r
.63397 .73289 m .63704 .73319 L .63622 .72999 L F
.764 .725 .817 r
.63397 .73289 m .6353 .73406 L .63704 .73319 L F
.692 .628 .779 r
.63622 .72999 m .63704 .73319 L .63945 .7308 L F
.671 .395 .494 r
.39569 .75612 m .39837 .75394 L .39638 .75483 L F
.708 .587 .718 r
.38245 .86463 m .3827 .86703 L .38475 .86427 L F
.611 .454 .644 r
.3827 .86703 m .38489 .86699 L .38475 .86427 L F
.596 .361 .53 r
.38449 .86893 m .3827 .86703 L .38258 .86931 L F
.38449 .86893 m .38489 .86699 L .3827 .86703 L F
.584 .442 .654 r
.56471 .78783 m .56825 .78858 L .56727 .78792 L F
.56471 .78783 m .56503 .79079 L .56825 .78858 L F
.944 .96 .724 r
.6139 .79064 m .61255 .79366 L .61241 .79194 L F
.754 .454 .475 r
.56753 .81905 m .56977 .81694 L .56966 .81577 L F
.56753 .81905 m .57114 .81955 L .56977 .81694 L F
.708 .438 .515 r
.57114 .81955 m .57112 .81722 L .56977 .81694 L F
.143 0 .398 r
.61374 .81201 m .61516 .80921 L .61551 .81151 L F
.172 0 .309 r
.61309 .8141 m .61374 .81201 L .61551 .81151 L F
.738 .991 .819 r
.64256 .77259 m .64045 .77497 L .64322 .77271 L F
.64256 .77259 m .64016 .77466 L .64045 .77497 L F
.743 .735 .844 r
.50739 .82923 m .50551 .83027 L .50839 .83013 L F
.664 .486 .634 r
.50644 .83236 m .50839 .83013 L .50551 .83027 L F
.50644 .83236 m .50866 .83259 L .50839 .83013 L F
.709 .764 .895 r
.50839 .83013 m .50943 .82782 L .50739 .82923 L F
.635 .53 .717 r
.40674 .83838 m .40904 .84039 L .40913 .83808 L F
.67 .788 .937 r
.54462 .83151 m .54096 .83099 L .54303 .83026 L F
.328 .658 .972 r
.54631 .8314 m .54462 .83151 L .54303 .83026 L F
.175 0 .185 r
.47082 .86387 m .46949 .86437 L .47179 .86195 L F
.325 .013 .273 r
.47333 .86308 m .47179 .86195 L .47362 .86199 L F
.47333 .86308 m .47082 .86387 L .47179 .86195 L F
.668 .876 .501 r
.69205 .73224 m .69368 .73019 L .6947 .72853 L F
.563 .224 .353 r
.46113 .82933 m .46327 .82933 L .46148 .82781 L F
.547 .23 .382 r
.46148 .82781 m .46327 .82933 L .46366 .8277 L F
.754 .499 .546 r
.595 .77522 m .59171 .77724 L .5915 .77535 L F
.595 .77522 m .59518 .77762 L .59171 .77724 L F
.761 .504 .545 r
.59688 .77765 m .59518 .77762 L .595 .77522 L F
.652 .74 .914 r
.66871 .75391 m .66694 .75492 L .66612 .75362 L F
.626 .483 .668 r
.41939 .75232 m .41756 .75174 L .41993 .75103 L F
.087 0 0 r
.41628 .75223 m .41993 .75103 L .41756 .75174 L F
.626 .483 .668 r
.41939 .75232 m .41771 .75387 L .41756 .75174 L F
.063 0 0 r
.47503 .83758 m .47281 .83745 L .4712 .83735 L F
.585 .666 .895 r
.39006 .73258 m .38953 .73504 L .38801 .73291 L F
.39006 .73258 m .39144 .73476 L .38953 .73504 L F
.626 .395 .546 r
.39607 .85635 m .39832 .85591 L .39626 .85385 L F
.621 .395 .553 r
.39832 .85591 m .39852 .85376 L .39626 .85385 L F
.616 .46 .648 r
.40759 .74383 m .40774 .74602 L .40556 .74651 L F
.632 .535 .727 r
.40841 .74907 m .40556 .74651 L .40774 .74602 L F
.3 .366 .764 r
.70611 .71899 m .70715 .71715 L .70663 .71868 L F
.817 .644 .669 r
.7044 .72177 m .70607 .72265 L .70611 .71899 L F
.7044 .72177 m .70611 .71899 L .70663 .71868 L F
.602 .952 .889 r
.41698 .88991 m .42052 .88844 L .41919 .88764 L F
.607 .923 .972 r
.42052 .88844 m .42184 .88717 L .41919 .88764 L F
.42052 .88844 m .42304 .88765 L .42184 .88717 L F
.497 .368 .635 r
.52705 .84543 m .52524 .84589 L .52497 .84339 L F
.981 .761 .351 r
.69306 .73856 m .69253 .73565 L .69217 .73789 L F
.992 .745 .442 r
.69306 .73856 m .69217 .73789 L .69304 .74117 L F
.902 .893 .811 r
.60397 .75683 m .60115 .7587 L .60322 .75622 L F
.60397 .75683 m .6012 .75946 L .60115 .7587 L F
.581 .401 .602 r
.60326 .75851 m .60374 .75792 L .60322 .75622 L F
.92 .552 .124 r
.60397 .75683 m .60322 .75622 L .60279 .75482 L F
.581 .401 .602 r
.60374 .75792 m .60539 .75588 L .60322 .75622 L F
.92 .552 .124 r
.60279 .75482 m .60322 .75622 L .60275 .75475 L F
.814 .935 .567 r
.68322 .74568 m .68433 .74439 L .68329 .74317 L F
.873 .878 .836 r
.47167 .8595 m .46867 .86181 L .47072 .85917 L F
.61 .427 .61 r
.38907 .85892 m .39115 .85863 L .39129 .85652 L F
.683 .545 .691 r
.39115 .85863 m .39385 .85667 L .39129 .85652 L F
.522 .795 .995 r
.44938 .88488 m .45037 .88364 L .44798 .8842 L F
.44938 .88488 m .45155 .88456 L .45037 .88364 L F
.159 .697 .724 r
.41277 .8897 m .41094 .89003 L .40941 .89035 L F
.624 .374 .519 r
.41094 .89003 m .40828 .89194 L .40941 .89035 L F
.026 .208 .715 r
.4895 .84579 m .49139 .84803 L .49057 .84858 L F
.569 .589 .833 r
.49139 .84803 m .4908 .85048 L .49057 .84858 L F
.603 .556 .775 r
.6915 .73272 m .68993 .73618 L .68882 .73302 L F
.085 .535 .905 r
.49192 .87517 m .49095 .87543 L .48917 .87519 L F
.49192 .87517 m .49163 .87571 L .49095 .87543 L F
.361 0 0 r
.49099 .87591 m .49192 .87517 L .48917 .87519 L F
.569 .916 .964 r
.49216 .87474 m .49192 .87517 L .49099 .87591 L F
.49261 .87429 m .49192 .87517 L .49216 .87474 L F
.085 .535 .905 r
.49192 .87517 m .49295 .87625 L .49163 .87571 L F
.731 .531 .621 r
.46068 .85086 m .45886 .85329 L .45856 .85092 L F
.61 .425 .607 r
.54463 .79598 m .54685 .79596 L .54683 .7936 L F
.751 .539 .608 r
.54683 .7936 m .54685 .79596 L .54978 .79608 L F
.894 .543 .372 r
.48835 .84285 m .48581 .83996 L .48691 .84055 L F
.678 .549 .701 r
.40904 .84039 m .41117 .83757 L .40913 .83808 L F
.957 .842 .689 r
.68275 .71963 m .68345 .71774 L .68231 .71732 L F
.59 .894 .988 r
.68345 .71774 m .6844 .71657 L .68231 .71732 L F
.68345 .71774 m .6844 .71657 L .68231 .71732 L F
.699 .464 .563 r
.45181 .85319 m .44985 .85113 L .45318 .85108 L F
.724 .465 .536 r
.45318 .85108 m .45525 .85349 L .45181 .85319 L F
0 .556 .73 r
.37361 .74871 m .37192 .74857 L .37016 .74846 L F
.681 .14 0 r
.37526 .7503 m .37192 .74857 L .37361 .74871 L F
.467 0 0 r
.5082 .87957 m .5102 .88023 L .50713 .87976 L F
.98 .685 .341 r
.56434 .80539 m .5652 .80407 L .56363 .80415 L F
.56434 .80539 m .56548 .80659 L .5652 .80407 L F
.933 .863 .748 r
.56469 .80142 m .5652 .80407 L .56732 .80126 L F
.56469 .80142 m .56363 .80415 L .5652 .80407 L F
.384 .029 .234 r
.56548 .80659 m .56736 .80492 L .5652 .80407 L F
.925 .73 .62 r
.44259 .82801 m .44202 .83029 L .44308 .82961 L F
.44259 .82801 m .44202 .83029 L .44308 .82961 L F
.244 0 0 r
.44202 .83029 m .44529 .83055 L .44308 .82961 L F
.551 .602 .858 r
.56565 .84569 m .5668 .84798 L .56887 .84776 L F
.611 .783 .964 r
.4011 .73906 m .39781 .73852 L .39981 .73842 L F
.44 .788 .998 r
.40183 .73815 m .4011 .73906 L .39981 .73842 L F
.40183 .73815 m .40319 .73887 L .4011 .73906 L F
0 .557 .799 r
.46952 .88296 m .47065 .88327 L .47262 .88352 L F
.61 .783 .964 r
.5416 .8268 m .54345 .82847 L .54416 .82735 L F
.265 .048 .386 r
.4691 .86644 m .46949 .86437 L .47082 .86387 L F
.256 .036 .376 r
.69551 .72762 m .69574 .72528 L .69749 .7247 L F
.561 .327 .518 r
.40896 .76204 m .40856 .76385 L .40736 .76388 L F
.492 .216 .423 r
.41109 .76194 m .40856 .76385 L .40896 .76204 L F
.543 .202 .34 r
.36774 .74913 m .36455 .75072 L .36516 .74957 L F
.673 .559 .718 r
.38981 .86177 m .39115 .85863 L .38907 .85892 L F
.317 .776 .947 r
.42304 .88765 m .42458 .8874 L .42184 .88717 L F
.401 .837 .947 r
.46623 .86424 m .46407 .8647 L .46304 .86444 L F
.597 .025 0 r
.50702 .87596 m .50663 .87553 L .50399 .8744 L F
.66 .512 .673 r
.38489 .86699 m .38686 .86406 L .38475 .86427 L F
0 .357 .829 r
.65933 .75253 m .6579 .75231 L .65718 .75168 L F
.65933 .75253 m .6602 .7538 L .6579 .75231 L F
.679 .569 .724 r
.50261 .84504 m .50137 .84777 L .50357 .84592 L F
.66 .699 .875 r
.70144 .71479 m .69884 .71448 L .70048 .71218 L F
.667 .662 .835 r
.70258 .71129 m .70144 .71479 L .70048 .71218 L F
.70258 .71129 m .70385 .7151 L .70144 .71479 L F
.706 .528 .645 r
.70385 .7151 m .70455 .71539 L .70144 .71479 L F
.818 .376 .188 r
.55549 .80939 m .55498 .81075 L .55307 .80825 L F
.846 .414 .2 r
.55549 .80939 m .55677 .81185 L .55498 .81075 L F
.755 .635 .728 r
.49664 .82976 m .49453 .83266 L .49789 .83284 L F
.766 .534 .583 r
.49453 .83266 m .49792 .83523 L .49789 .83284 L F
.683 .6 .757 r
.49664 .82976 m .49789 .83284 L .50051 .83063 L F
.273 .751 .933 r
.51613 .87573 m .51252 .87556 L .51455 .87599 L F
0 0 0 r
.51676 .87568 m .51613 .87573 L .51455 .87599 L F
.51676 .87568 m .51752 .87464 L .5162 .87568 L F
0 .33 .801 r
.51728 .87567 m .51676 .87568 L .51533 .87565 L F
.51759 .87568 m .51676 .87568 L .51728 .87567 L F
0 0 0 r
.51676 .87568 m .5162 .87568 L .51613 .87573 L F
.512 .313 .547 r
.60275 .75475 m .6053 .75129 L .60315 .75165 L F
.819 .441 .34 r
.54604 .80139 m .54497 .8029 L .54477 .80085 L F
.54604 .80139 m .54779 .80396 L .54497 .8029 L F
.826 .439 .319 r
.5494 .80399 m .54779 .80396 L .54604 .80139 L F
.842 .78 .793 r
.62809 .76941 m .62869 .77191 L .62774 .77321 L F
.804 .759 .812 r
.62967 .77054 m .62869 .77191 L .62809 .76941 L F
.598 .567 .791 r
.69664 .74354 m .6941 .74355 L .69304 .74117 L F
.631 .296 .385 r
.69542 .74401 m .6941 .74355 L .69664 .74354 L F
.598 .567 .791 r
.69664 .74354 m .69304 .74117 L .69512 .74413 L F
.69664 .74354 m .69512 .74413 L .69519 .74423 L F
.012 0 0 r
.69541 .74419 m .69664 .74354 L .69519 .74423 L F
.631 .296 .385 r
.69612 .74426 m .69561 .74408 L .69664 .74354 L F
.92 .784 .695 r
.69664 .74354 m .69755 .74641 L .69655 .74586 L F
.69664 .74354 m .69655 .74586 L .69612 .74426 L F
.717 .688 .822 r
.69952 .74487 m .69755 .74641 L .69664 .74354 L F
.69952 .74487 m .69664 .74354 L .69927 .74322 L F
.012 0 0 r
.6994 .74333 m .69664 .74354 L .69541 .74419 L F
.631 .296 .385 r
.69561 .74408 m .69542 .74401 L .69664 .74354 L F
.546 .569 .829 r
.69519 .74416 m .69519 .74423 L .69518 .74416 L F
.631 .296 .385 r
.69542 .74524 m .69453 .7441 L .69612 .74426 L F
.69518 .74416 m .6941 .74355 L .69612 .74426 L F
.347 .418 .793 r
.69446 .73979 m .69518 .74416 L .69304 .74117 L F
.69518 .74416 m .69519 .74423 L .69512 .74413 L F
.69518 .74416 m .69512 .74413 L .69304 .74117 L F
.631 .296 .385 r
.69453 .7441 m .69417 .74364 L .69518 .74416 L F
.69417 .74364 m .6941 .74355 L .69518 .74416 L F
.546 .569 .829 r
.69505 .74021 m .69519 .74416 L .69446 .73979 L F
.69519 .74416 m .69518 .74416 L .69446 .73979 L F
.012 0 0 r
.6994 .74333 m .69927 .74322 L .69664 .74354 L F
.546 .569 .829 r
.6994 .74333 m .69607 .74405 L .69505 .74021 L F
.69607 .74405 m .69519 .74423 L .69505 .74021 L F
.92 .784 .695 r
.69612 .74426 m .69655 .74586 L .69542 .74524 L F
.945 .659 .466 r
.69755 .74641 m .6966 .74802 L .69542 .74524 L F
.878 .549 .423 r
.69755 .74641 m .69789 .74848 L .6966 .74802 L F
.675 .47 .599 r
.41117 .83757 m .41402 .83799 L .4142 .83542 L F
.612 .415 .591 r
.4142 .83542 m .41629 .83761 L .41654 .83537 L F
.4142 .83542 m .41402 .83799 L .41629 .83761 L F
.743 .494 .554 r
.46599 .8486 m .46607 .85152 L .46266 .85068 L F
.535 .36 .591 r
.46815 .8481 m .46802 .85063 L .46599 .8486 L F
.575 .361 .553 r
.46802 .85063 m .46607 .85152 L .46599 .8486 L F
.592 .633 .861 r
.3742 .7282 m .37041 .72603 L .37293 .7269 L F
.75 .789 .885 r
.37592 .72685 m .3742 .7282 L .37293 .7269 L F
.724 .641 .766 r
.56503 .79079 m .56876 .79161 L .56721 .79114 L F
0 0 0 r
.56967 .79054 m .56876 .79161 L .57082 .78898 L F
.58 .873 .994 r
.56721 .79114 m .56876 .79161 L .56967 .79054 L F
.484 .487 .785 r
.39847 .75128 m .39927 .74807 L .39762 .74957 L F
.39847 .75128 m .40017 .75105 L .39927 .74807 L F
.501 .397 .668 r
.39837 .75394 m .40017 .75105 L .39847 .75128 L F
.535 .31 .519 r
.60573 .77248 m .60494 .77522 L .60278 .7754 L F
.565 .339 .531 r
.60653 .7745 m .60573 .77248 L .60744 .77207 L F
.60653 .7745 m .60494 .77522 L .60573 .77248 L F
.773 .634 .706 r
.63802 .71217 m .63888 .71522 L .63621 .71497 L F
.735 .579 .68 r
.63888 .71522 m .63698 .71769 L .63621 .71497 L F
.63888 .71522 m .6392 .71739 L .63698 .71769 L F
.054 0 .152 r
.64107 .71236 m .63888 .71522 L .63802 .71217 L F
.64107 .71236 m .64065 .71418 L .63888 .71522 L F
.516 .498 .775 r
.64065 .71418 m .6392 .71739 L .63888 .71522 L F
.607 .391 .563 r
.61009 .77013 m .60891 .77374 L .60744 .77207 L F
.368 .205 .524 r
.61158 .76931 m .61009 .77013 L .61167 .76705 L F
.552 .336 .54 r
.61209 .77265 m .61009 .77013 L .61158 .76931 L F
.61209 .77265 m .60891 .77374 L .61009 .77013 L F
.842 .78 .793 r
.62809 .76941 m .62774 .77321 L .62582 .77186 L F
.785 .674 .741 r
.62582 .77186 m .62774 .77321 L .62653 .77457 L F
.723 .636 .761 r
.64039 .70972 m .64107 .71236 L .63802 .71217 L F
.668 .602 .772 r
.64309 .71166 m .64107 .71236 L .64039 .70972 L F
.562 .243 .386 r
.64309 .71166 m .64065 .71418 L .64107 .71236 L F
.52 .367 .614 r
.40942 .74104 m .40759 .74383 L .40775 .74196 L F
.40942 .74104 m .40954 .74354 L .40759 .74383 L F
.594 .482 .696 r
.40954 .74354 m .40774 .74602 L .40759 .74383 L F
.785 .747 .819 r
.58818 .83341 m .58614 .83556 L .58517 .83335 L F
.676 .607 .771 r
.40942 .74104 m .40775 .74196 L .40635 .73916 L F
.842 .847 .849 r
.64858 .75901 m .64595 .76169 L .64511 .76107 L F
.705 .581 .713 r
.37292 .87249 m .37317 .87218 L .37285 .87218 L F
.613 .445 .63 r
.37316 .87469 m .37317 .87218 L .37292 .87249 L F
0 0 0 r
.66323 .72578 m .66056 .7295 L .66296 .72689 L F
.66296 .72689 m .66501 .72455 L .66323 .72578 L F
.538 .314 .523 r
.37067 .79063 m .36842 .79301 L .36886 .79113 L F
.393 .014 .196 r
.54145 .79842 m .544 .79803 L .54463 .79598 L F
.73 .337 .306 r
.54463 .79598 m .54687 .79806 L .54685 .79596 L F
.54463 .79598 m .544 .79803 L .54687 .79806 L F
.656 .654 .836 r
.69884 .71448 m .69505 .71186 L .69745 .71374 L F
.815 .966 .903 r
.70048 .71218 m .69884 .71448 L .69745 .71374 L F
.976 .752 .536 r
.56996 .7886 m .56967 .79054 L .57082 .78898 L F
.949 .855 .713 r
.57122 .78685 m .56996 .7886 L .57082 .78898 L F
.744 .222 0 r
.43136 .82758 m .4346 .83022 L .43426 .82797 L F
.415 .36 .688 r
.43426 .82797 m .43636 .82938 L .43632 .82708 L F
.43426 .82797 m .4346 .83022 L .43636 .82938 L F
.613 .445 .63 r
.37316 .87469 m .37522 .87198 L .37317 .87218 L F
.355 .814 .709 r
.4964 .88206 m .4973 .88175 L .49977 .88059 L F
.706 .43 .504 r
.49856 .84779 m .49556 .84879 L .49776 .84746 L F
.49856 .84779 m .49577 .84993 L .49556 .84879 L F
.49856 .84779 m .4977 .85016 L .49577 .84993 L F
.809 .365 0 r
.49812 .84761 m .49885 .84865 L .49856 .84779 L F
.49817 .84791 m .49885 .84865 L .49812 .84761 L F
.49776 .84746 m .49817 .84791 L .49812 .84761 L F
.595 .776 .967 r
.49839 .84726 m .49885 .84865 L .49776 .84746 L F
0 0 .101 r
.49839 .84726 m .4977 .85016 L .49885 .84865 L F
.4982 .84808 m .49795 .84996 L .4977 .85016 L F
.49839 .84726 m .49823 .84827 L .4982 .84808 L F
.49823 .84827 m .49795 .84996 L .4982 .84808 L F
0 0 0 r
.55452 .82405 m .55323 .8251 L .55333 .82506 L F
.304 .773 .938 r
.44064 .88503 m .44391 .88514 L .44268 .88473 L F
.493 .849 .993 r
.44391 .88514 m .44472 .88423 L .44268 .88473 L F
.44391 .88514 m .44598 .88469 L .44472 .88423 L F
.702 .682 .827 r
.70571 .71192 m .70385 .7151 L .70258 .71129 L F
.667 .629 .802 r
.70571 .71192 m .70455 .71539 L .70385 .7151 L F
.878 .442 .135 r
.67544 .71895 m .67717 .7224 L .67558 .72103 L F
.67544 .71895 m .67558 .72103 L .67572 .72042 L F
.796 .604 .642 r
.67534 .71842 m .67663 .71967 L .67544 .71895 L F
.756 .336 0 r
.67715 .72183 m .67544 .71895 L .67663 .71967 L F
.67715 .72183 m .67717 .7224 L .67544 .71895 L F
.878 .442 .135 r
.67544 .71895 m .67572 .72042 L .67619 .71841 L F
.796 .604 .642 r
.67453 .71763 m .67534 .71842 L .67544 .71895 L F
.493 .143 .301 r
.35353 .78786 m .35552 .78776 L .35665 .78563 L F
.539 .28 .47 r
.35552 .78776 m .35847 .78482 L .35665 .78563 L F
.707 .485 .584 r
.3803 .87188 m .38045 .86956 L .37812 .86961 L F
.603 .412 .596 r
.3803 .87188 m .38258 .86931 L .38045 .86956 L F
.526 .32 .544 r
.39075 .75406 m .38862 .75743 L .39052 .75646 L F
.656 .566 .742 r
.39262 .75381 m .39077 .7558 L .39075 .75406 L F
.39262 .75381 m .39336 .75631 L .39077 .7558 L F
.49 .29 .535 r
.39075 .75406 m .39052 .75646 L .39262 .75381 L F
.664 .127 0 r
.5494 .80399 m .55027 .80536 L .54779 .80396 L F
.5494 .80399 m .55137 .80599 L .55027 .80536 L F
.13 0 .26 r
.62136 .75538 m .62165 .75338 L .6218 .75449 L F
.62136 .75538 m .61968 .75675 L .62165 .75338 L F
.501 .304 .545 r
.64878 .72604 m .64924 .72993 L .64717 .73061 L F
.549 .382 .608 r
.65121 .72489 m .64878 .72604 L .64901 .72541 L F
.65121 .72489 m .65166 .72778 L .64878 .72604 L F
.336 .026 .284 r
.65166 .72778 m .64924 .72993 L .64878 .72604 L F
.686 .583 .734 r
.44243 .86697 m .44051 .86955 L .43938 .8664 L F
.668 .276 0 r
.56171 .82161 m .56351 .825 L .56317 .82434 L F
.928 .764 .285 r
.56351 .825 m .56301 .82667 L .56317 .82434 L F
.56351 .825 m .56331 .82758 L .56301 .82667 L F
.701 .6 .74 r
.50551 .83027 m .50327 .8328 L .50644 .83236 L F
.523 .269 .472 r
.50358 .83517 m .50644 .83236 L .50327 .8328 L F
.479 .115 .27 r
.38982 .7622 m .39117 .7635 L .3911 .76139 L F
.38982 .7622 m .38844 .76406 L .39117 .7635 L F
.657 .352 .444 r
.53033 .84334 m .52949 .84561 L .52705 .84543 L F
.57 .555 .798 r
.53239 .8429 m .53033 .84334 L .5292 .84039 L F
.561 .253 .404 r
.53248 .84503 m .53033 .84334 L .53239 .8429 L F
.53248 .84503 m .52949 .84561 L .53033 .84334 L F
.873 .879 .837 r
.53105 .82227 m .52893 .82487 L .52771 .82423 L F
.686 .617 .773 r
.44294 .82393 m .44605 .8229 L .44442 .8253 L F
.55 .529 .784 r
.44605 .8229 m .44663 .82519 L .44442 .8253 L F
.155 .69 .842 r
.44663 .82519 m .44163 .82517 L .44442 .8253 L F
.895 .9 .823 r
.63063 .7673 m .63174 .76793 L .62967 .77054 L F
.836 .909 .888 r
.63174 .76621 m .63174 .76793 L .63063 .7673 L F
.63174 .76621 m .63308 .76674 L .63174 .76793 L F
.519 0 0 r
.49679 .84104 m .4963 .84198 L .4935 .84102 L F
.768 .418 .392 r
.4992 .84247 m .4963 .84198 L .49679 .84104 L F
.518 .599 .874 r
.37864 .89881 m .38058 .89844 L .37835 .89829 L F
.285 0 0 r
.51591 .82755 m .51462 .82851 L .51271 .82861 L F
.521 .497 .77 r
.51766 .82694 m .51591 .82755 L .51494 .82449 L F
.053 0 0 r
.51743 .82749 m .51591 .82755 L .51766 .82694 L F
.51743 .82749 m .51462 .82851 L .51591 .82755 L F
.585 .596 .83 r
.4477 .85362 m .4446 .85131 L .44669 .85023 L F
.531 .329 .552 r
.44985 .85113 m .4477 .85362 L .44669 .85023 L F
0 0 0 r
.5776 .77749 m .57246 .77819 L .5735 .77798 L F
.529 .296 .506 r
.36839 .77772 m .37044 .77741 L .37074 .7753 L F
.489 .261 .495 r
.37074 .7753 m .37237 .77701 L .37285 .77505 L F
.37074 .7753 m .37044 .77741 L .37237 .77701 L F
.896 .972 .82 r
.67185 .74344 m .66958 .74706 L .6692 .74574 L F
.731 .697 .818 r
.53037 .83045 m .5277 .83037 L .52899 .82963 L F
.962 .716 .518 r
.53037 .83045 m .52899 .83206 L .52899 .82963 L F
.936 .671 .51 r
.68316 .73342 m .68176 .73522 L .68117 .73241 L F
.68316 .73342 m .6832 .73561 L .68176 .73522 L F
.634 .835 .978 r
.43732 .8849 m .43864 .88572 L .44064 .88503 L F
.043 .569 .865 r
.41277 .8897 m .41502 .89045 L .4137 .88989 L F
.537 .849 .998 r
.4137 .88989 m .41502 .89045 L .41698 .88991 L F
.415 .794 .992 r
.45482 .88483 m .45529 .88401 L .45347 .88416 L F
.45482 .88483 m .45673 .8846 L .45529 .88401 L F
.655 .374 .483 r
.43116 .82939 m .43333 .82971 L .43136 .82758 L F
.744 .222 0 r
.43136 .82758 m .43333 .82971 L .4346 .83022 L F
.667 .629 .802 r
.70571 .71192 m .70673 .71476 L .70455 .71539 L F
.933 .929 .565 r
.66084 .70902 m .6615 .70611 L .66175 .70702 L F
.274 .589 .947 r
.6615 .70611 m .66256 .70618 L .66175 .70702 L F
.22 .506 .907 r
.66256 .70618 m .66439 .70818 L .66175 .70702 L F
.486 .197 .399 r
.52091 .83853 m .52055 .84029 L .52267 .83993 L F
.434 .412 .735 r
.39786 .74864 m .39762 .74957 L .39927 .74807 L F
.332 .794 .939 r
.57218 .84799 m .5733 .8474 L .57142 .84725 L F
.57218 .84799 m .57468 .84767 L .5733 .8474 L F
.436 .194 .447 r
.54978 .79608 m .55197 .79584 L .55214 .79347 L F
.543 .281 .468 r
.55214 .79347 m .55197 .79584 L .55422 .79548 L F
.639 .399 .538 r
.52142 .8483 m .51748 .85079 L .51763 .84869 L F
.754 .745 .844 r
.64545 .70767 m .64256 .70759 L .64445 .70648 L F
.43 .506 .836 r
.64663 .70604 m .64545 .70767 L .64445 .70648 L F
.64663 .70604 m .6481 .70902 L .64545 .70767 L F
.676 .456 .579 r
.60891 .77374 m .60653 .7745 L .60744 .77207 L F
.826 .445 .33 r
.55255 .84286 m .55378 .843 L .55395 .84517 L F
.944 .925 .758 r
.55378 .843 m .55477 .83955 L .55569 .84224 L F
.2 0 .348 r
.55395 .84517 m .55378 .843 L .55569 .84224 L F
.404 .856 .886 r
.59235 .84693 m .59403 .84693 L .59619 .84625 L F
.011 0 0 r
.59306 .8469 m .59235 .84693 L .59353 .84681 L F
.041 .61 .73 r
.59129 .84698 m .59403 .84693 L .59235 .84693 L F
.011 0 0 r
.59155 .84717 m .59235 .84693 L .59306 .8469 L F
.041 .61 .73 r
.5907 .84699 m .59129 .84698 L .59235 .84693 L F
.507 .252 .463 r
.39477 .77254 m .39429 .77504 L .39215 .77533 L F
.446 .198 .443 r
.39612 .77442 m .39477 .77254 L .39678 .77221 L F
.39612 .77442 m .39429 .77504 L .39477 .77254 L F
.562 .557 .806 r
.47438 .84035 m .47241 .84072 L .4712 .83735 L F
.508 .312 .549 r
.47241 .84072 m .47227 .843 L .47438 .84035 L F
.47241 .84072 m .47227 .843 L .47438 .84035 L F
.673 .878 .975 r
.50832 .83712 m .50994 .83815 L .51175 .83696 L F
.69 .289 .281 r
.51175 .83696 m .50832 .83712 L .50994 .83815 L F
.608 .374 .536 r
.51247 .83979 m .50994 .83815 L .51175 .83696 L F
.51247 .83979 m .50982 .84032 L .50994 .83815 L F
.904 .965 .647 r
.59238 .8276 m .59082 .83051 L .59087 .82915 L F
0 0 0 r
.59355 .82677 m .59472 .82542 L .59238 .8276 L F
.59355 .82677 m .59238 .8276 L .59087 .82915 L F
.692 .584 .73 r
.43938 .8664 m .43729 .8671 L .43608 .86396 L F
.842 .847 .849 r
.64858 .75901 m .64511 .76107 L .64784 .75839 L F
.214 .643 .953 r
.64784 .75839 m .6506 .75928 L .64858 .75901 L F
.407 .019 .187 r
.53536 .8335 m .53556 .83462 L .53337 .83489 L F
.656 .379 .489 r
.43333 .82971 m .43636 .82938 L .4346 .83022 L F
.871 .792 .77 r
.48593 .86828 m .48386 .86657 L .48672 .86588 L F
.48593 .86828 m .48351 .86951 L .48386 .86657 L F
.554 .716 .948 r
.48763 .86687 m .48593 .86828 L .48672 .86588 L F
.48763 .86687 m .48913 .86843 L .48593 .86828 L F
.587 .724 .939 r
.38624 .89733 m .38936 .89817 L .38841 .8969 L F
.692 .74 .888 r
.38936 .89817 m .38992 .89537 L .38841 .8969 L F
.38936 .89817 m .39131 .89743 L .38992 .89537 L F
.953 .613 .322 r
.49658 .81921 m .49776 .81986 L .49643 .81727 L F
0 0 0 r
.49776 .81986 m .50011 .8169 L .49643 .81727 L F
.49776 .81986 m .49854 .8196 L .49999 .81704 L F
.686 .357 .413 r
.49776 .81986 m .49991 .82189 L .49774 .82161 L F
.661 .397 .511 r
.49658 .81921 m .49854 .8196 L .49776 .81986 L F
.49658 .81921 m .49785 .82082 L .49854 .8196 L F
.48 .074 .192 r
.49991 .82189 m .49704 .82345 L .49774 .82161 L F
.661 .397 .511 r
.49785 .82082 m .49894 .82219 L .49854 .8196 L F
0 0 0 r
.49999 .81704 m .49854 .8196 L .50011 .8169 L F
.392 .349 .69 r
.61967 .74123 m .61998 .74177 L .62163 .74039 L F
.61967 .74123 m .62032 .74369 L .61998 .74177 L F
.927 .774 .671 r
.56166 .81912 m .56171 .82161 L .56005 .82175 L F
.835 .448 .318 r
.56005 .82175 m .56171 .82161 L .56317 .82434 L F
0 0 0 r
.38692 .74616 m .38625 .74624 L .3881 .74634 L F
.38692 .74616 m .38418 .74699 L .38625 .74624 L F
.668 .931 .971 r
.64322 .77271 m .64515 .77168 L .64425 .77127 L F
.706 .985 .866 r
.64256 .77259 m .64322 .77271 L .64425 .77127 L F
.734 .63 .743 r
.55776 .7785 m .55757 .78035 L .55963 .77783 L F
.811 .923 .539 r
.55757 .78035 m .5585 .77805 L .55963 .77783 L F
.55757 .78035 m .55722 .78036 L .5585 .77805 L F
.645 .561 .745 r
.55757 .78035 m .55956 .78186 L .55864 .78069 L F
.708 .217 .074 r
.55864 .78069 m .55722 .78036 L .55757 .78035 L F
.278 .578 .941 r
.52002 .83211 m .52248 .83148 L .52307 .82953 L F
.52002 .83211 m .52197 .83233 L .52248 .83148 L F
.782 .973 .916 r
.50146 .87415 m .49891 .87539 L .50053 .87395 L F
.196 .677 .931 r
.50294 .8739 m .50399 .8744 L .50146 .87415 L F
.555 .37 .586 r
.53337 .83489 m .53124 .83775 L .53135 .83596 L F
.243 .741 .667 r
.64397 .73177 m .64519 .73133 L .64717 .73061 L F
.66 .477 .626 r
.37522 .87198 m .37796 .87203 L .37812 .86961 L F
.707 .485 .584 r
.3803 .87188 m .37812 .86961 L .37796 .87203 L F
.025 0 0 r
.3407 .72912 m .34253 .72909 L .34411 .72897 L F
0 0 0 r
.34253 .72909 m .34609 .72866 L .34411 .72897 L F
.296 .144 .498 r
.61026 .81996 m .61173 .81695 L .61176 .81931 L F
.338 .158 .484 r
.61014 .82212 m .61026 .81996 L .61176 .81931 L F
.199 .442 .868 r
.66439 .70818 m .66595 .70875 L .66493 .70956 L F
.134 .323 .788 r
.66595 .70875 m .66717 .71146 L .66493 .70956 L F
.601 .399 .581 r
.39852 .85376 m .40072 .85357 L .40075 .85125 L F
.632 .485 .664 r
.40075 .85125 m .40356 .85108 L .40282 .84828 L F
.638 .442 .602 r
.40072 .85357 m .40356 .85108 L .40075 .85125 L F
.517 0 0 r
.70242 .74686 m .70194 .74681 L .70292 .74635 L F
.188 .697 .9 r
.70211 .74675 m .70292 .74635 L .70194 .74681 L F
.715 .655 .789 r
.7051 .74635 m .70308 .74883 L .70292 .74635 L F
.188 .697 .9 r
.70442 .74605 m .70292 .74635 L .70211 .74675 L F
.575 .677 .91 r
.70292 .74635 m .69952 .74487 L .7022 .74671 L F
.70292 .74635 m .7022 .74671 L .70242 .74686 L F
.658 .504 .664 r
.70292 .74635 m .70308 .74883 L .70079 .74891 L F
.188 .697 .9 r
.70442 .74605 m .70509 .74635 L .70292 .74635 L F
.397 .318 .649 r
.70346 .74686 m .70372 .74573 L .70442 .74605 L F
.70372 .74573 m .70405 .74427 L .70442 .74605 L F
.188 .697 .9 r
.70442 .74605 m .7051 .74635 L .70509 .74635 L F
.328 0 0 r
.47593 .86952 m .47262 .87108 L .47579 .87196 L F
.873 .879 .837 r
.53105 .82227 m .52771 .82423 L .52976 .82135 L F
.825 .797 .825 r
.53334 .81978 m .53105 .82227 L .52976 .82135 L F
.534 .619 .883 r
.33264 .66616 m .33011 .66594 L .33228 .66822 L F
.472 .228 .462 r
.44632 .85691 m .44554 .85908 L .44386 .85885 L F
.641 .465 .629 r
.41869 .83511 m .42098 .83244 L .41865 .83274 L F
.523 .269 .472 r
.50358 .83517 m .50553 .83509 L .50644 .83236 L F
.611 .334 .473 r
.50553 .83509 m .50866 .83259 L .50644 .83236 L F
.732 .911 .956 r
.42779 .88715 m .43323 .88573 L .43203 .88544 L F
.466 .855 .978 r
.43373 .88516 m .43323 .88573 L .43535 .88496 L F
.43373 .88516 m .43203 .88544 L .43323 .88573 L F
.38 .23 .549 r
.48713 .8525 m .48547 .85343 L .48523 .85118 L F
.611 .319 .45 r
.49478 .8187 m .49658 .81921 L .49495 .8175 L F
.953 .613 .322 r
.49658 .81921 m .49643 .81727 L .49495 .8175 L F
.384 .029 .234 r
.56548 .80659 m .56703 .80628 L .56736 .80492 L F
.812 .438 .348 r
.56736 .80492 m .56703 .80628 L .56904 .80617 L F
.757 .528 .586 r
.70132 .75065 m .69789 .74848 L .70079 .74891 L F
.722 .413 .456 r
.70079 .74891 m .70314 .75109 L .70132 .75065 L F
.647 .435 .582 r
.70308 .74883 m .70314 .75109 L .70079 .74891 L F
.586 .86 .995 r
.49495 .87514 m .49295 .87625 L .49192 .87517 L F
.635 .671 .867 r
.496 .87654 m .49295 .87625 L .49495 .87514 L F
.98 .693 .394 r
.57093 .83262 m .57134 .83225 L .57114 .83022 L F
.573 .365 .562 r
.62115 .73565 m .62355 .73527 L .62365 .7333 L F
.575 .405 .614 r
.62355 .73527 m .62573 .73279 L .62365 .7333 L F
.554 .303 .49 r
.60278 .7754 m .60257 .7774 L .60028 .77767 L F
.461 .224 .468 r
.60459 .77689 m .60278 .7754 L .60494 .77522 L F
.60459 .77689 m .60257 .7774 L .60278 .7754 L F
0 0 0 r
.56453 .83805 m .56451 .83959 L .56456 .8372 L F
.56453 .83805 m .56432 .84048 L .56451 .83959 L F
0 0 .113 r
.59966 .81408 m .59839 .81733 L .59978 .81644 L F
0 0 .066 r
.59978 .81644 m .59839 .81733 L .59772 .81912 L F
.682 .429 .533 r
.41654 .83537 m .41863 .83753 L .41869 .83511 L F
.41654 .83537 m .41629 .83761 L .41863 .83753 L F
.733 .719 .838 r
.6344 .7634 m .63308 .76674 L .63174 .76621 L F
.6344 .7634 m .63556 .76458 L .63308 .76674 L F
.636 .46 .628 r
.40282 .84828 m .40558 .84862 L .40513 .84592 L F
.64 .487 .659 r
.40513 .84592 m .40785 .84582 L .40724 .84311 L F
.635 .459 .628 r
.40513 .84592 m .40776 .84831 L .40785 .84582 L F
.40513 .84592 m .40558 .84862 L .40776 .84831 L F
.821 .641 .658 r
.62653 .77457 m .62404 .77237 L .62582 .77186 L F
.62653 .77457 m .62395 .77483 L .62404 .77237 L F
.647 .843 .975 r
.45673 .8846 m .45875 .88482 L .45693 .88468 L F
.702 .873 .962 r
.45875 .88482 m .46069 .88266 L .45693 .88468 L F
.45875 .88482 m .46231 .88331 L .46069 .88266 L F
.518 .293 .513 r
.37546 .77209 m .37747 .77172 L .37776 .76985 L F
.481 .184 .384 r
.37747 .77172 m .38003 .76973 L .37776 .76985 L F
.475 .195 .408 r
.37478 .77456 m .37747 .77172 L .37546 .77209 L F
0 .451 .772 r
.68802 .70501 m .68585 .70417 L .68723 .70444 L F
0 .488 .834 r
.68894 .70485 m .6911 .706 L .68802 .70501 L F
.6 .14 .134 r
.48423 .86345 m .48299 .86223 L .48086 .86342 L F
.473 .564 .866 r
.51019 .85053 m .51081 .84827 L .50877 .84884 L F
.51019 .85053 m .51211 .85081 L .51081 .84827 L F
.742 .497 .559 r
.54685 .79596 m .54983 .79773 L .54978 .79608 L F
.541 .395 .632 r
.54983 .79773 m .55197 .79584 L .54978 .79608 L F
.432 .345 .657 r
.41993 .75103 m .4215 .75087 L .41953 .74895 L F
.41993 .75103 m .4215 .75087 L .41953 .74895 L F
.722 .602 .723 r
.62115 .73565 m .61794 .7331 L .6184 .73557 L F
.585 .46 .676 r
.62167 .73809 m .62355 .73527 L .62115 .73565 L F
.704 .227 0 r
.56028 .81695 m .55959 .81636 L .55836 .81463 L F
.856 .406 .018 r
.56028 .81695 m .56058 .81879 L .55959 .81636 L F
.56028 .81695 m .56154 .81928 L .56058 .81879 L F
.791 .348 0 r
.56166 .81912 m .56154 .81928 L .56028 .81695 L F
.787 .513 .522 r
.45036 .83151 m .45373 .82987 L .45104 .8307 L F
.895 .9 .823 r
.63063 .7673 m .62967 .77054 L .62809 .76941 L F
.56 .376 .588 r
.41939 .75232 m .41775 .75636 L .41771 .75387 L F
.57 .615 .858 r
.4514 .8726 m .44921 .87309 L .44828 .87078 L F
.652 .515 .684 r
.40724 .84311 m .40991 .8433 L .40904 .84039 L F
.685 .516 .651 r
.40724 .84311 m .41012 .84569 L .40991 .8433 L F
.40724 .84311 m .40785 .84582 L .41012 .84569 L F
.558 .863 .996 r
.65059 .76895 m .65138 .76788 L .64938 .76857 L F
.65059 .76895 m .65328 .76842 L .65138 .76788 L F
.725 .397 .424 r
.68762 .74372 m .6893 .74327 L .68806 .74543 L F
.733 .407 .429 r
.6893 .74327 m .69114 .74557 L .68806 .74543 L F
.75 .405 .399 r
.69133 .74414 m .69114 .74557 L .6893 .74327 L F
.621 .31 .422 r
.61624 .76213 m .61623 .76378 L .61292 .76366 L F
.572 .42 .636 r
.61794 .76121 m .61623 .76378 L .61624 .76213 L F
.455 .608 .913 r
.69288 .70594 m .69146 .70726 L .6911 .706 L F
.393 .502 .85 r
.69288 .70594 m .69421 .70867 L .69146 .70726 L F
.678 .267 .259 r
.6053 .75129 m .60757 .75305 L .60874 .75146 L F
0 0 0 r
.60874 .75146 m .61042 .74784 L .60733 .74859 L F
.60874 .75146 m .60959 .75052 L .61042 .74784 L F
.538 .357 .584 r
.36842 .79301 m .36589 .79764 L .36644 .79348 L F
.793 .495 .484 r
.70203 .72549 m .70392 .72776 L .7016 .72797 L F
.598 .512 .728 r
.7016 .72797 m .70295 .72481 L .70203 .72549 L F
.7016 .72797 m .70392 .72776 L .70295 .72481 L F
.643 .823 .969 r
.47721 .8715 m .47918 .87211 L .47579 .87196 L F
.806 .798 .844 r
.4802 .86877 m .47918 .87211 L .47721 .8715 L F
.62 .568 .774 r
.54318 .84043 m .54463 .83715 L .54268 .83853 L F
.54318 .84043 m .54543 .84027 L .54463 .83715 L F
.9 .772 .711 r
.64045 .7269 m .64141 .72794 L .64227 .72575 L F
.185 .709 .868 r
.63262 .72198 m .6343 .72177 L .63432 .72023 L F
0 0 .355 r
.63432 .72023 m .63433 .71768 L .63698 .71769 L F
.63432 .72023 m .6348 .71944 L .63433 .71768 L F
.92 .641 .496 r
.63637 .71983 m .6348 .71944 L .63432 .72023 L F
.381 .826 .943 r
.34957 .72839 m .35016 .72778 L .35147 .72746 L F
.34957 .72839 m .34814 .72818 L .35016 .72778 L F
.83 .564 .536 r
.68485 .73589 m .68329 .73781 L .6832 .73561 L F
.915 .708 .608 r
.68485 .73829 m .68329 .73781 L .68485 .73589 L F
.582 .359 .542 r
.41578 .75689 m .41545 .75915 L .41328 .75932 L F
.592 .406 .599 r
.41775 .75636 m .41545 .75915 L .41578 .75689 L F
0 .451 .772 r
.36203 .72576 m .36416 .72637 L .36544 .72691 L F
.307 .792 .897 r
.36416 .72637 m .36783 .72614 L .36544 .72691 L F
.374 0 0 r
.35731 .75132 m .35601 .75164 L .35394 .75131 L F
.64 .166 .112 r
.35952 .7519 m .35601 .75164 L .35731 .75132 L F
.682 .504 .639 r
.38686 .86406 m .38981 .86416 L .38981 .86177 L F
.673 .559 .718 r
.38981 .86177 m .39203 .86154 L .39115 .85863 L F
.662 .488 .638 r
.38981 .86416 m .39203 .86154 L .38981 .86177 L F
.584 .214 .307 r
.4709 .82695 m .47311 .82702 L .47435 .82508 L F
.358 0 .17 r
.47435 .82508 m .47528 .82655 L .47635 .82469 L F
.47435 .82508 m .47311 .82702 L .47528 .82655 L F
.787 .513 .522 r
.45036 .83151 m .45272 .8324 L .45373 .82987 L F
.638 .347 .46 r
.45373 .82987 m .45572 .8318 L .45605 .83012 L F
.45373 .82987 m .45272 .8324 L .45572 .8318 L F
.568 .372 .576 r
.4415 .86153 m .43918 .86488 L .43805 .86128 L F
.4415 .86153 m .44151 .86438 L .43918 .86488 L F
.632 .423 .582 r
.4434 .86349 m .44151 .86438 L .4415 .86153 L F
.52 .241 .431 r
.40171 .76747 m .40125 .7693 L .39914 .7696 L F
.531 .251 .435 r
.40335 .76899 m .40125 .7693 L .40171 .76747 L F
.504 .254 .469 r
.40363 .76707 m .40335 .76899 L .40171 .76747 L F
.763 .806 .887 r
.49977 .88059 m .5029 .88046 L .50172 .87967 L F
.541 .871 .993 r
.5029 .88046 m .5037 .87949 L .50172 .87967 L F
.805 .945 .593 r
.63802 .71217 m .63621 .71497 L .63691 .71313 L F
0 0 0 r
.63802 .71217 m .63935 .71123 L .64039 .70972 L F
.63802 .71217 m .63691 .71313 L .63935 .71123 L F
.904 .965 .646 r
.59087 .82915 m .59082 .83051 L .58987 .83214 L F
.342 .82 .787 r
.55963 .77783 m .56068 .77726 L .56149 .77723 L F
.55963 .77783 m .5585 .77805 L .56068 .77726 L F
.825 .797 .825 r
.53334 .81978 m .52976 .82135 L .53203 .81901 L F
.859 .862 .841 r
.53518 .81601 m .53334 .81978 L .53203 .81901 L F
.671 .395 .494 r
.39569 .75612 m .39814 .75623 L .39837 .75394 L F
.501 .397 .668 r
.39837 .75394 m .4006 .75376 L .40017 .75105 L F
.52 .293 .51 r
.39814 .75623 m .4006 .75376 L .39837 .75394 L F
.643 .492 .662 r
.40282 .84828 m .40571 .85089 L .40558 .84862 L F
.40282 .84828 m .40356 .85108 L .40571 .85089 L F
.721 .42 .467 r
.45418 .86175 m .45784 .86358 L .45727 .86194 L F
.32 .568 .928 r
.37128 .72504 m .37041 .72603 L .36971 .72563 L F
.37128 .72504 m .37293 .7269 L .37041 .72603 L F
.865 .425 .15 r
.67454 .7333 m .67533 .7349 L .67678 .73523 L F
.847 .393 .119 r
.67533 .7349 m .67824 .73764 L .67678 .73523 L F
.841 .393 .151 r
.67678 .73523 m .67824 .73764 L .6794 .73777 L F
.773 .36 .267 r
.56772 .80782 m .56904 .80617 L .56703 .80628 L F
.56772 .80782 m .57089 .8085 L .56904 .80617 L F
.475 .337 .613 r
.57327 .82971 m .57114 .83022 L .57339 .82753 L F
.448 .259 .53 r
.57093 .83262 m .57114 .83022 L .57327 .82971 L F
.814 .603 .617 r
.43875 .82924 m .44259 .82801 L .44063 .82661 L F
.43875 .82924 m .44202 .83029 L .44259 .82801 L F
.779 .721 .798 r
.44063 .82661 m .44259 .82801 L .44163 .82517 L F
.718 .591 .712 r
.43805 .86128 m .43608 .86396 L .43613 .86182 L F
.687 .546 .688 r
.43805 .86128 m .43918 .86488 L .43608 .86396 L F
.741 .699 .811 r
.70358 .72352 m .70607 .72265 L .7044 .72177 L F
.711 .51 .616 r
.70295 .72481 m .70607 .72265 L .70358 .72352 L F
.70295 .72481 m .70632 .72517 L .70607 .72265 L F
.489 .347 .614 r
.70814 .72456 m .70632 .72517 L .70607 .72265 L F
.70607 .72265 m .70632 .72517 L .70814 .72456 L F
.70814 .72456 m .70632 .72517 L .70607 .72265 L F
.692 .584 .73 r
.43938 .8664 m .43608 .86396 L .43918 .86488 L F
.616 .558 .767 r
.44151 .86438 m .43938 .8664 L .43918 .86488 L F
.66 .634 .813 r
.44151 .86438 m .44243 .86697 L .43938 .8664 L F
.587 .437 .645 r
.53124 .83775 m .5292 .84039 L .52907 .83811 L F
0 0 .206 r
.55477 .83955 m .5548 .83837 L .55554 .83732 L F
.643 .298 .372 r
.58404 .76914 m .58664 .76923 L .58726 .76732 L F
.629 .284 .367 r
.58726 .76732 m .58664 .76923 L .58936 .76898 L F
.563 .412 .634 r
.67071 .72805 m .6715 .73029 L .66939 .73063 L F
.44 .107 .303 r
.36364 .78198 m .36531 .78259 L .36626 .78036 L F
.402 .031 .214 r
.36531 .78259 m .36845 .78022 L .36626 .78036 L F
.586 .409 .609 r
.36626 .78036 m .36845 .78022 L .36839 .77772 L F
.824 .512 .462 r
.55831 .79568 m .55959 .79806 L .56078 .79585 L F
.797 .477 .447 r
.56078 .79585 m .55959 .79806 L .56097 .79813 L F
.454 0 0 r
.46949 .87037 m .47038 .87018 L .46899 .87005 L F
.444 0 0 r
.47262 .87108 m .47038 .87018 L .46949 .87037 L F
.556 .378 .595 r
.61337 .7666 m .61158 .76931 L .61167 .76705 L F
.244 0 0 r
.44202 .83029 m .44388 .83061 L .44529 .83055 L F
.004 .459 .867 r
.44622 .83029 m .44529 .83055 L .44388 .83061 L F
.44622 .83029 m .4471 .83108 L .44529 .83055 L F
.227 0 0 r
.48024 .88468 m .48162 .88396 L .48486 .88385 L F
.698 .617 .762 r
.69304 .74117 m .6941 .74355 L .69133 .74414 L F
.558 .223 .357 r
.6941 .74355 m .69114 .74557 L .69133 .74414 L F
.49 .251 .479 r
.38753 .77768 m .38709 .77977 L .38518 .78007 L F
.46 .196 .426 r
.38957 .77733 m .38709 .77977 L .38753 .77768 L F
.695 .562 .7 r
.50357 .84592 m .50626 .84599 L .5056 .84331 L F
.462 .313 .592 r
.36839 .77772 m .37018 .77956 L .37044 .77741 L F
.36839 .77772 m .36845 .78022 L .37018 .77956 L F
.824 .98 .692 r
.60223 .8094 m .6003 .81204 L .6006 .81073 L F
.732 .763 .26 r
.6006 .81073 m .6003 .81204 L .59966 .81408 L F
.125 0 .262 r
.68212 .7558 m .68066 .75716 L .68273 .75407 L F
.726 .833 .931 r
.67949 .75613 m .68066 .75716 L .68212 .7558 L F
.67949 .75613 m .68066 .75716 L .68212 .7558 L F
.605 .279 .391 r
.46327 .82933 m .46671 .82687 L .46366 .8277 L F
.46327 .82933 m .46553 .82943 L .46671 .82687 L F
.542 .203 .343 r
.46553 .82943 m .46876 .82709 L .46671 .82687 L F
.772 .544 .589 r
.56911 .78548 m .56996 .7886 L .57122 .78685 L F
.54 .554 .818 r
.37835 .89829 m .37945 .89587 L .37736 .89707 L F
.37835 .89829 m .38058 .89844 L .37945 .89587 L F
.785 .747 .819 r
.58818 .83341 m .58517 .83335 L .58706 .83231 L F
.774 .81 .881 r
.58706 .83231 m .58987 .83214 L .58818 .83341 L F
.145 0 .221 r
.70295 .72481 m .70358 .72352 L .70203 .72549 L F
.741 .699 .811 r
.70358 .72352 m .7044 .72177 L .70245 .72199 L F
.975 .696 .434 r
.65992 .70848 m .66126 .71046 L .65997 .7099 L F
.995 .849 .501 r
.66013 .70807 m .6599 .70787 L .66047 .70584 L F
.66002 .70883 m .6599 .70787 L .66013 .70807 L F
.906 .975 .798 r
.65926 .70733 m .6599 .70787 L .65924 .70734 L F
.995 .849 .501 r
.66002 .70883 m .66047 .70584 L .6615 .70611 L F
.037 .59 .824 r
.66047 .70584 m .66256 .70618 L .6615 .70611 L F
.607 .777 .962 r
.66196 .70504 m .66256 .70618 L .66047 .70584 L F
.282 .046 .369 r
.66047 .70584 m .6599 .70787 L .66196 .70504 L F
.906 .975 .798 r
.66196 .70504 m .6599 .70787 L .65926 .70733 L F
.565 .619 .864 r
.66126 .71046 m .66084 .70902 L .66002 .70883 L F
.569 .607 .851 r
.66002 .70883 m .66126 .71046 L .6599 .70787 L F
.975 .696 .434 r
.6599 .70787 m .66011 .70828 L .65992 .70848 L F
.66011 .70828 m .66126 .71046 L .65992 .70848 L F
.933 .929 .565 r
.66084 .70902 m .66002 .70883 L .6606 .70776 L F
.66129 .70702 m .6606 .70776 L .6615 .70611 L F
.66084 .70902 m .6606 .70776 L .66129 .70702 L F
.42 .196 .465 r
.50773 .84063 m .5056 .84331 L .50751 .84259 L F
.50773 .84063 m .5056 .84331 L .50751 .84259 L F
.588 .373 .557 r
.50982 .84032 m .50751 .84259 L .50773 .84063 L F
.50982 .84032 m .50751 .84259 L .50773 .84063 L F
.329 .786 .947 r
.55956 .78186 m .56319 .78104 L .55864 .78069 L F
.55956 .78186 m .56168 .7817 L .56319 .78104 L F
.54 .287 .481 r
.38003 .76973 m .38216 .76945 L .38256 .76743 L F
.338 .109 .412 r
.38256 .76743 m .38378 .76886 L .38457 .76712 L F
.38256 .76743 m .38216 .76945 L .38378 .76886 L F
.957 .842 .689 r
.68275 .71963 m .68231 .71732 L .6806 .71966 L F
.784 .644 .707 r
.46922 .85351 m .47078 .85638 L .46747 .85597 L F
.762 .424 .412 r
.47078 .85638 m .46917 .85828 L .46747 .85597 L F
.936 .707 .566 r
.47078 .85638 m .47072 .85917 L .46917 .85828 L F
.661 .313 .373 r
.50751 .84259 m .50438 .8429 L .5056 .84331 L F
.635 .571 .765 r
.50626 .84599 m .50751 .84259 L .5056 .84331 L F
.429 0 0 r
.52952 .80701 m .53187 .80801 L .53289 .80771 L F
.268 0 0 r
.53289 .80771 m .53187 .80801 L .53561 .80814 L F
.434 .113 .32 r
.34684 .75414 m .34858 .75406 L .34644 .75511 L F
.312 .6 .948 r
.6872 .71287 m .68865 .71223 L .68631 .7119 L F
.6872 .71287 m .6902 .71402 L .68865 .71223 L F
.944 .96 .724 r
.6139 .79064 m .61241 .79194 L .61377 .79055 L F
.836 .847 .384 r
.61474 .78748 m .6139 .79064 L .61377 .79055 L F
.71 .553 0 r
.56414 .83266 m .56421 .83432 L .5631 .83139 L F
.56414 .83266 m .56426 .83511 L .56421 .83432 L F
.613 .445 .63 r
.37316 .87469 m .37522 .87455 L .37522 .87198 L F
.674 .505 .649 r
.37522 .87455 m .37796 .87203 L .37522 .87198 L F
.494 .282 .521 r
.44091 .82228 m .43889 .82509 L .44075 .8246 L F
.68 .44 .551 r
.44091 .82228 m .44075 .8246 L .44294 .82393 L F
.531 .329 .552 r
.44985 .85113 m .44986 .85348 L .4477 .85362 L F
.533 .34 .564 r
.44986 .85348 m .44802 .85603 L .4477 .85362 L F
.699 .464 .563 r
.45181 .85319 m .44986 .85348 L .44985 .85113 L F
.678 .549 .701 r
.40904 .84039 m .41203 .84062 L .41117 .83757 L F
.67 .526 .68 r
.40904 .84039 m .41218 .843 L .41203 .84062 L F
.40904 .84039 m .40991 .8433 L .41218 .843 L F
.621 .752 .94 r
.66986 .75748 m .67234 .7569 L .66878 .7562 L F
.66986 .75748 m .67234 .7569 L .66878 .7562 L F
.581 .33 .501 r
.40736 .76388 m .40582 .76706 L .40363 .76707 L F
.556 .303 .487 r
.40856 .76385 m .40582 .76706 L .40736 .76388 L F
0 0 .427 r
.56432 .84048 m .56492 .84392 L .56487 .84268 L F
0 0 .54 r
.56492 .84392 m .56565 .84569 L .56487 .84268 L F
0 .023 .553 r
.67128 .72707 m .6715 .73029 L .67071 .72805 L F
.933 .572 .307 r
.55307 .80825 m .55137 .80599 L .55277 .8065 L F
.084 0 .356 r
.60754 .8295 m .60675 .83015 L .60792 .82732 L F
.151 .035 .456 r
.60665 .83256 m .60675 .83015 L .60754 .8295 L F
.751 .722 .826 r
.6738 .71473 m .67453 .71763 L .67136 .71709 L F
.418 0 0 r
.67136 .71709 m .67453 .71763 L .6742 .71801 L F
.775 .737 .818 r
.67619 .71538 m .67453 .71763 L .6738 .71473 L F
.194 .601 .945 r
.67544 .71895 m .6742 .71801 L .67453 .71763 L F
.676 .837 .96 r
.61901 .72919 m .62013 .73023 L .61683 .73013 L F
.967 .816 .642 r
.62013 .73023 m .61901 .72919 L .61683 .73013 L F
.62013 .73023 m .61923 .73259 L .61901 .72919 L F
.592 .604 .833 r
.62111 .7271 m .62013 .73023 L .61901 .72919 L F
.62111 .7271 m .6224 .72987 L .62013 .73023 L F
.531 .296 .503 r
.6224 .72987 m .61923 .73259 L .62013 .73023 L F
.978 .7 .429 r
.67147 .74854 m .67055 .74993 L .66958 .7487 L F
.67147 .74854 m .67186 .75103 L .67055 .74993 L F
.797 .742 .802 r
.37774 .74906 m .37901 .75013 L .38035 .74822 L F
0 0 .056 r
.66852 .73316 m .66867 .7356 L .66862 .73447 L F
.66852 .73316 m .66862 .73447 L .66662 .73223 L F
.63 .626 .827 r
.68062 .70792 m .68229 .70589 L .67991 .70647 L F
.68062 .70792 m .68307 .70727 L .68229 .70589 L F
.557 .38 .597 r
.49493 .82195 m .49259 .82358 L .49302 .82267 L F
.369 .762 .987 r
.38032 .72653 m .38382 .72714 L .38324 .72753 L F
.464 .889 .891 r
.62032 .74369 m .62146 .7428 L .61998 .74177 L F
.246 0 .32 r
.61998 .74177 m .6235 .73989 L .62163 .74039 L F
.61998 .74177 m .62146 .7428 L .6235 .73989 L F
.007 .07 .579 r
.62032 .74369 m .62146 .7428 L .61998 .74177 L F
.197 .012 .388 r
.61998 .74177 m .62114 .74258 L .62163 .74039 L F
.62114 .74258 m .62151 .742 L .62163 .74039 L F
.384 .128 .398 r
.62163 .74039 m .62413 .73711 L .62167 .73809 L F
.62163 .74039 m .6235 .73989 L .62413 .73711 L F
.776 .653 .726 r
.62309 .73959 m .62003 .74168 L .6222 .73893 L F
.6235 .73989 m .62259 .74036 L .62309 .73959 L F
.62259 .74036 m .62003 .74168 L .62309 .73959 L F
.197 .012 .388 r
.62114 .74258 m .62146 .7428 L .62151 .742 L F
.442 .405 .721 r
.6294 .72511 m .63072 .72172 L .63262 .72198 L F
.185 .709 .868 r
.63262 .72198 m .63072 .72172 L .6343 .72177 L F
.687 .525 .661 r
.37307 .87705 m .37522 .87455 L .37316 .87469 L F
.565 .513 .756 r
.66064 .72951 m .66296 .72689 L .66056 .7295 L F
.66064 .72951 m .66356 .7296 L .66296 .72689 L F
.715 .655 .789 r
.7051 .74635 m .70621 .74882 L .70308 .74883 L F
.655 .441 .582 r
.7063 .75064 m .70308 .74883 L .70621 .74882 L F
.588 .591 .823 r
.70819 .74841 m .70621 .74882 L .7051 .74635 L F
.474 .232 .466 r
.70749 .75026 m .70621 .74882 L .70819 .74841 L F
.70749 .75026 m .7063 .75064 L .70621 .74882 L F
.927 .774 .671 r
.56166 .81912 m .56005 .82175 L .56154 .81928 L F
.215 .211 .638 r
.68356 .7507 m .68273 .75407 L .68232 .75145 L F
.68356 .7507 m .68429 .75317 L .68273 .75407 L F
.077 0 .365 r
.68273 .75407 m .68394 .75536 L .68212 .7558 L F
.68273 .75407 m .68429 .75317 L .68394 .75536 L F
.661 .479 .627 r
.56727 .78792 m .56996 .7886 L .56911 .78548 L F
.098 0 0 r
.51228 .88136 m .51393 .88092 L .51548 .88096 L F
.52 .204 .371 r
.52232 .8131 m .52503 .81072 L .52316 .81165 L F
.959 .881 .713 r
.61476 .74106 m .61376 .74349 L .61485 .74372 L F
.4 .837 .947 r
.61485 .74372 m .61602 .743 L .61695 .74361 L F
.61485 .74372 m .61376 .74349 L .61602 .743 L F
.832 .966 .642 r
.6266 .79031 m .62792 .78865 L .62845 .78753 L F
.094 .443 .879 r
.53561 .80814 m .53697 .80866 L .53621 .8092 L F
.094 .442 .878 r
.53697 .80866 m .53793 .81027 L .53621 .8092 L F
.693 .593 .739 r
.50437 .82703 m .50551 .83027 L .50739 .82923 L F
.185 0 0 r
.44966 .86201 m .45093 .86205 L .45215 .86164 L F
.644 .356 .467 r
.45215 .86164 m .45417 .86364 L .45418 .86175 L F
.416 .395 .727 r
.45215 .8596 m .45283 .86211 L .45093 .86205 L F
.611 .078 0 r
.45302 .86282 m .45215 .86164 L .45093 .86205 L F
.416 .395 .727 r
.45283 .86211 m .45302 .86282 L .45093 .86205 L F
.185 0 0 r
.44902 .8621 m .45093 .86205 L .44966 .86201 L F
.611 .078 0 r
.45302 .86282 m .45417 .86364 L .45215 .86164 L F
.983 .697 .344 r
.67887 .72563 m .67816 .7268 L .67792 .72457 L F
.882 .476 .245 r
.67887 .72563 m .67954 .72729 L .67816 .7268 L F
.505 .226 .425 r
.38053 .78316 m .37993 .78494 L .37797 .78523 L F
.409 .135 .383 r
.38235 .78265 m .37993 .78494 L .38053 .78316 L F
.676 .607 .771 r
.40942 .74104 m .40635 .73916 L .40843 .73856 L F
.555 .545 .799 r
.41051 .73816 m .40942 .74104 L .40843 .73856 L F
.41051 .73816 m .41107 .74072 L .40942 .74104 L F
.544 .396 .631 r
.41107 .74072 m .40954 .74354 L .40942 .74104 L F
.355 0 0 r
.39581 .72815 m .39229 .72944 L .39423 .72709 L F
.39581 .72815 m .39468 .72941 L .39344 .72902 L F
.134 .663 .87 r
.39423 .72709 m .3976 .72746 L .39581 .72815 L F
.39544 .72722 m .39627 .72715 L .3976 .72746 L F
.39423 .72709 m .39627 .72715 L .39544 .72722 L F
.284 .738 .956 r
.3976 .72746 m .39743 .72681 L .39627 .72715 L F
.3976 .72746 m .39993 .72747 L .39743 .72681 L F
.423 .801 .992 r
.39743 .72681 m .39889 .72681 L .39627 .72715 L F
.111 0 0 r
.39743 .72681 m .39732 .72705 L .39627 .72715 L F
.691 .893 .525 r
.39627 .72715 m .39581 .72815 L .3976 .72746 L F
.111 0 0 r
.39732 .72705 m .39692 .72795 L .39627 .72715 L F
.691 .893 .525 r
.39627 .72715 m .39468 .72941 L .39581 .72815 L F
.776 .95 .62 r
.39527 .72804 m .39468 .72941 L .39627 .72715 L F
.169 .297 .752 r
.39527 .72804 m .39589 .72979 L .39468 .72941 L F
.39589 .72979 m .39636 .7311 L .39468 .72941 L F
.355 0 0 r
.39344 .72902 m .39468 .72941 L .39229 .72944 L F
.724 .717 .843 r
.43438 .89536 m .43222 .89574 L .43415 .8939 L F
.607 .27 .373 r
.43438 .89536 m .43382 .89653 L .43222 .89574 L F
.402 .481 .826 r
.43415 .8939 m .43631 .89505 L .43438 .89536 L F
.262 0 .193 r
.43631 .89505 m .43382 .89653 L .43438 .89536 L F
.537 .44 .693 r
.40993 .74568 m .40841 .74907 L .40774 .74602 L F
.40993 .74568 m .41046 .74879 L .40841 .74907 L F
.595 .471 .681 r
.41091 .7508 m .40841 .74907 L .41046 .74879 L F
.41091 .7508 m .40878 .75132 L .40841 .74907 L F
.362 .829 .772 r
.51548 .88096 m .51892 .87981 L .51767 .88077 L F
.17 0 0 r
.51767 .88077 m .51892 .87981 L .52094 .87946 L F
.846 .936 .884 r
.59473 .82402 m .59472 .82542 L .59355 .82677 L F
.59473 .82402 m .59642 .82386 L .59472 .82542 L F
.731 .531 .621 r
.46068 .85086 m .46048 .85351 L .45886 .85329 L F
.694 .595 .741 r
.46266 .85068 m .46048 .85351 L .46068 .85086 L F
.622 .411 .576 r
.39832 .85591 m .40072 .85357 L .39852 .85376 L F
.511 .195 .368 r
.38709 .77977 m .38422 .78215 L .38518 .78007 L F
.635 .571 .765 r
.50626 .84599 m .5097 .84675 L .50751 .84259 L F
.54 .46 .714 r
.50626 .84599 m .50877 .84884 L .5097 .84675 L F
.50626 .84599 m .50704 .84967 L .50877 .84884 L F
.256 0 .022 r
.67722 .75785 m .67516 .75735 L .67777 .75745 L F
.67722 .75785 m .67444 .75867 L .67516 .75735 L F
.766 .268 .03 r
.6794 .73777 m .68256 .74029 L .68315 .74032 L F
.903 .701 .62 r
.63621 .71497 m .63698 .71769 L .63433 .71768 L F
.86 .943 .578 r
.60374 .80642 m .60223 .8094 L .60253 .80781 L F
.869 .983 .699 r
.60253 .80781 m .60223 .8094 L .6006 .81073 L F
.419 .766 .996 r
.57468 .84767 m .57769 .84825 L .57652 .84789 L F
0 .405 .692 r
.57769 .84825 m .57865 .8485 L .57652 .84789 L F
.57769 .84825 m .57973 .84883 L .57865 .8485 L F
.59 .678 .901 r
.3881 .74634 m .39181 .74837 L .39022 .7463 L F
.649 .74 .916 r
.39022 .7463 m .39181 .74837 L .39353 .74663 L F
.562 .243 .386 r
.64309 .71166 m .64215 .71512 L .64065 .71418 L F
.306 .795 .761 r
.64553 .71086 m .64457 .71104 L .64309 .71166 L F
.002 0 .165 r
.64457 .71104 m .64215 .71512 L .64309 .71166 L F
.698 .651 .799 r
.51733 .82252 m .51856 .82465 L .51494 .82449 L F
.521 .497 .77 r
.51766 .82694 m .51494 .82449 L .51856 .82465 L F
.669 .452 .582 r
.51856 .82465 m .52027 .82722 L .51766 .82694 L F
.648 .58 .765 r
.43415 .8939 m .43222 .89574 L .43164 .89362 L F
.975 .741 .521 r
.43164 .89362 m .43222 .89574 L .43103 .89476 L F
.607 .658 .874 r
.43416 .8929 m .43415 .8939 L .43164 .89362 L F
.665 .236 .217 r
.43304 .89503 m .43415 .8939 L .43365 .89296 L F
.678 .717 .879 r
.43342 .89254 m .43365 .89296 L .43416 .8929 L F
.665 .236 .217 r
.43349 .89286 m .43365 .89296 L .43342 .89254 L F
.566 .843 .997 r
.43416 .8929 m .43349 .89286 L .43318 .8914 L F
.43349 .89286 m .42971 .89261 L .43318 .8914 L F
.678 .717 .879 r
.43246 .89072 m .43342 .89254 L .43416 .8929 L F
.566 .843 .997 r
.43318 .8914 m .43199 .89182 L .43199 .88959 L F
.43199 .89182 m .42971 .89261 L .43077 .89121 L F
.43199 .89182 m .43077 .89121 L .43199 .88959 L F
.665 .236 .217 r
.43268 .89232 m .43349 .89286 L .43246 .89072 L F
.43349 .89286 m .43342 .89254 L .43246 .89072 L F
.566 .843 .997 r
.43365 .89296 m .43164 .89362 L .43096 .89327 L F
.43374 .89302 m .43164 .89362 L .43365 .89296 L F
.43416 .8929 m .43096 .89327 L .42971 .89261 L F
.665 .236 .217 r
.43304 .89503 m .43365 .89296 L .43268 .89232 L F
.566 .843 .997 r
.43416 .8929 m .43374 .89302 L .43365 .89296 L F
.678 .717 .879 r
.43365 .89296 m .43415 .8939 L .43416 .8929 L F
.478 .526 .829 r
.43103 .89476 m .43304 .89503 L .43219 .89307 L F
.43157 .893 m .43219 .89307 L .43181 .89219 L F
.181 .645 .937 r
.42944 .89278 m .43164 .89362 L .42897 .89306 L F
.669 .312 .358 r
.43164 .89362 m .43103 .89476 L .42897 .89306 L F
.478 .526 .829 r
.43103 .89476 m .43219 .89307 L .43157 .893 L F
.181 .645 .937 r
.42971 .89261 m .43018 .89286 L .42944 .89278 L F
.43018 .89286 m .43164 .89362 L .42944 .89278 L F
0 .281 .783 r
.42897 .89306 m .43103 .89476 L .42971 .89261 L F
.616 .609 .821 r
.44463 .86665 m .44243 .86697 L .44151 .86438 L F
.505 .26 .478 r
.44759 .85851 m .44632 .85691 L .44802 .85603 L F
.44759 .85851 m .44554 .85908 L .44632 .85691 L F
0 0 .501 r
.48206 .84845 m .48343 .84777 L .48094 .84802 L F
.48206 .84845 m .48333 .85072 L .48343 .84777 L F
.593 .537 .762 r
.44756 .86983 m .44828 .87078 L .44587 .87111 L F
.542 .369 .596 r
.56503 .79079 m .56721 .79114 L .56825 .78858 L F
.435 .077 .257 r
.57652 .77178 m .57867 .77144 L .57957 .76939 L F
.55 .215 .354 r
.57867 .77144 m .58177 .76912 L .57957 .76939 L F
.79 .729 .796 r
.49564 .82701 m .4935 .82963 L .49664 .82976 L F
.797 .7 .757 r
.4935 .82963 m .49453 .83266 L .49664 .82976 L F
.033 0 0 r
.61695 .74361 m .61931 .74368 L .62032 .74369 L F
.464 .889 .891 r
.62032 .74369 m .61931 .74368 L .62146 .7428 L F
.665 .407 .52 r
.48315 .84576 m .48343 .84777 L .48427 .84594 L F
.335 0 .236 r
.48343 .84777 m .48624 .84526 L .48427 .84594 L F
.148 .451 .882 r
.43222 .89574 m .43304 .89503 L .43103 .89476 L F
.43222 .89574 m .43382 .89653 L .43304 .89503 L F
.56 .376 .588 r
.41939 .75232 m .41982 .75605 L .41775 .75636 L F
.503 .432 .71 r
.4215 .75087 m .41939 .75232 L .41993 .75103 L F
.4215 .75087 m .422 .75316 L .41939 .75232 L F
.6 .437 .632 r
.422 .75316 m .41982 .75605 L .41939 .75232 L F
.683 .889 .973 r
.45636 .87145 m .45463 .87243 L .45336 .87176 L F
.594 .482 .696 r
.40954 .74354 m .40993 .74568 L .40774 .74602 L F
.793 .935 .924 r
.51733 .82252 m .51494 .82449 L .51385 .824 L F
.609 .928 .967 r
.49743 .87516 m .496 .87654 L .49495 .87514 L F
.49743 .87516 m .49891 .87539 L .496 .87654 L F
.605 .638 .857 r
.38624 .89733 m .38681 .89439 L .38498 .89565 L F
.38624 .89733 m .38841 .8969 L .38681 .89439 L F
.513 .513 .793 r
.6902 .71402 m .69023 .71541 L .69232 .71406 L F
0 0 .129 r
.69186 .71733 m .69232 .71406 L .69023 .71541 L F
.599 .615 .839 r
.63945 .7308 m .64233 .73264 L .64157 .7301 L F
.757 .363 .306 r
.64397 .73177 m .64157 .7301 L .64233 .73264 L F
.585 .46 .676 r
.62167 .73809 m .62413 .73711 L .62355 .73527 L F
.715 .455 .532 r
.66542 .7176 m .66409 .71881 L .6642 .71736 L F
.66542 .7176 m .66602 .71988 L .66409 .71881 L F
.511 .216 .402 r
.36072 .78504 m .36364 .78198 L .36105 .78317 L F
.36072 .78504 m .36281 .78481 L .36364 .78198 L F
.423 .134 .367 r
.36364 .78198 m .3647 .78431 L .36531 .78259 L F
.36364 .78198 m .36281 .78481 L .3647 .78431 L F
.631 .296 .385 r
.69542 .74524 m .69345 .74547 L .6941 .74355 L F
.558 .223 .357 r
.6941 .74355 m .69345 .74547 L .69114 .74557 L F
.107 .439 .877 r
.53793 .81027 m .54027 .81118 L .53954 .81174 L F
.088 .406 .859 r
.54027 .81118 m .54203 .8131 L .53954 .81174 L F
.407 .011 .172 r
.35702 .80125 m .35897 .8011 L .35678 .80161 L F
.65 .532 .707 r
.41117 .83757 m .41426 .84032 L .41402 .83799 L F
.41117 .83757 m .41203 .84062 L .41426 .84032 L F
.704 .449 .536 r
.61475 .73487 m .61794 .7331 L .61575 .73446 L F
.61475 .73487 m .6184 .73557 L .61794 .7331 L F
.554 .903 .686 r
.42645 .88731 m .42667 .88735 L .42727 .88663 L F
.047 .615 .742 r
.42681 .88738 m .42667 .88735 L .42458 .8874 L F
.425 0 .074 r
.42458 .8874 m .42667 .88735 L .42536 .88823 L F
.554 .903 .686 r
.42536 .88823 m .42667 .88735 L .42645 .88731 L F
.047 .615 .742 r
.42784 .88737 m .42667 .88735 L .42681 .88738 L F
.389 .845 .902 r
.42853 .88681 m .42784 .88737 L .42779 .88715 L F
.42853 .88681 m .42667 .88735 L .42784 .88737 L F
.665 .492 .641 r
.38981 .86416 m .39207 .86393 L .39203 .86154 L F
.681 .563 .716 r
.39115 .85863 m .39203 .86154 L .39407 .85891 L F
.645 .513 .688 r
.39203 .86154 m .39425 .86134 L .39407 .85891 L F
.652 .49 .652 r
.39207 .86393 m .39425 .86134 L .39203 .86154 L F
.553 .372 .589 r
.52705 .84543 m .52498 .84808 L .52524 .84589 L F
.725 .196 0 r
.6805 .7396 m .6794 .73777 L .67824 .73764 L F
.6805 .7396 m .68185 .7403 L .6794 .73777 L F
.766 .268 .03 r
.6794 .73777 m .68185 .7403 L .68256 .74029 L F
.611 .334 .473 r
.50553 .83509 m .50778 .83512 L .50866 .83259 L F
.7 .427 .507 r
.50866 .83259 m .50778 .83512 L .51054 .83502 L F
.69 .426 .518 r
.50866 .83259 m .51054 .83502 L .51076 .83342 L F
.877 .91 .848 r
.59611 .82222 m .59642 .82386 L .59473 .82402 L F
.782 .861 .908 r
.59874 .82199 m .59642 .82386 L .59611 .82222 L F
.532 .331 .553 r
.38862 .75743 m .39037 .75897 L .39052 .75646 L F
.801 .314 0 r
.53375 .86846 m .53338 .86706 L .53277 .86937 L F
.683 .545 .691 r
.39115 .85863 m .39407 .85891 L .39385 .85667 L F
.616 .446 .629 r
.52503 .81072 m .52713 .80889 L .5253 .80905 L F
.655 .441 .582 r
.7063 .75064 m .70314 .75109 L .70308 .74883 L F
.64 .813 .966 r
.69984 .72229 m .7014 .72102 L .69952 .72207 L F
.69984 .72229 m .70245 .72199 L .7014 .72102 L F
.878 .992 .758 r
.6052 .80347 m .60374 .80642 L .60336 .80602 L F
.6052 .80347 m .60579 .80358 L .60374 .80642 L F
.943 .935 .589 r
.60336 .80602 m .60374 .80642 L .60253 .80781 L F
.66 .512 .673 r
.38489 .86699 m .38763 .86677 L .38686 .86406 L F
.681 .523 .665 r
.38763 .86677 m .38981 .86416 L .38686 .86406 L F
.009 0 .298 r
.60792 .82732 m .60982 .8243 L .60949 .82652 L F
.074 0 .352 r
.60754 .8295 m .60792 .82732 L .60949 .82652 L F
.597 .733 .939 r
.39353 .74663 m .39786 .74864 L .39502 .74594 L F
.509 .686 .946 r
.39502 .74594 m .39786 .74864 L .39927 .74807 L F
.319 .093 .406 r
.61516 .80921 m .61741 .80603 L .61687 .80837 L F
.235 .082 .46 r
.61551 .81151 m .61516 .80921 L .61687 .80837 L F
.613 .045 0 r
.69904 .74507 m .69952 .74487 L .69927 .74322 L F
.088 0 0 r
.70216 .74674 m .70346 .74686 L .70442 .74605 L F
.801 .329 .1 r
.69904 .74507 m .70194 .74681 L .70242 .74686 L F
.088 0 0 r
.70194 .74681 m .70218 .74681 L .70216 .74674 L F
.613 .045 0 r
.70216 .74673 m .70242 .74686 L .70215 .74668 L F
.088 0 0 r
.70218 .74681 m .70346 .74686 L .70216 .74674 L F
.613 .045 0 r
.69904 .74507 m .70216 .74673 L .69952 .74487 L F
.70216 .74673 m .70215 .74668 L .69952 .74487 L F
.604 .864 .992 r
.40843 .73856 m .40635 .73916 L .40534 .73867 L F
.539 .33 .545 r
.41328 .75932 m .41315 .7616 L .41109 .76194 L F
.539 .306 .51 r
.41545 .75915 m .41315 .7616 L .41328 .75932 L F
.568 .302 .472 r
.37303 .7888 m .37292 .79056 L .37067 .79063 L F
.722 .552 .659 r
.38449 .86893 m .38763 .86677 L .38489 .86699 L F
.616 .13 .077 r
.50867 .8207 m .5073 .82156 L .50504 .82094 L F
.154 0 0 r
.50872 .82126 m .50652 .82214 L .5073 .82156 L F
.50953 .82109 m .50879 .82134 L .50872 .82126 L F
.50879 .82134 m .50652 .82214 L .50872 .82126 L F
0 .116 .644 r
.50867 .8207 m .5094 .82128 L .50953 .82109 L F
.5094 .82128 m .51041 .8221 L .50953 .82109 L F
.087 0 .153 r
.51019 .81917 m .50953 .82109 L .51166 .81834 L F
.51019 .81917 m .51054 .82025 L .50953 .82109 L F
.51019 .81917 m .50923 .82121 L .51054 .82025 L F
.474 .858 .649 r
.51054 .82025 m .50964 .82091 L .50953 .82109 L F
.087 0 .153 r
.50923 .82121 m .50904 .82161 L .51054 .82025 L F
.474 .858 .649 r
.51054 .82025 m .50967 .82087 L .50964 .82091 L F
.154 0 0 r
.50917 .82121 m .50834 .8218 L .50652 .82214 L F
.508 0 0 r
.50903 .8216 m .50902 .82159 L .50887 .82145 L F
.50887 .82145 m .50887 .82145 L .50623 .819 L F
.50903 .8216 m .50887 .82145 L .50887 .82145 L F
0 .116 .644 r
.50867 .8207 m .50953 .82109 L .50872 .82126 L F
.474 .858 .649 r
.50968 .82086 m .50885 .82145 L .50961 .82096 L F
.50885 .82145 m .50837 .82179 L .50887 .82145 L F
.666 .375 .469 r
.50887 .82145 m .5092 .82123 L .51019 .81917 L F
.474 .858 .649 r
.50885 .82145 m .50887 .82145 L .50961 .82096 L F
.50968 .82086 m .50822 .82188 L .50837 .82179 L F
.50961 .82096 m .50837 .82179 L .50953 .82109 L F
0 .116 .644 r
.50867 .8207 m .50872 .82126 L .50838 .82088 L F
.666 .375 .469 r
.50623 .819 m .50887 .82145 L .51019 .81917 L F
.50887 .82145 m .50903 .8216 L .5092 .82123 L F
.50903 .8216 m .50904 .82161 L .50906 .82159 L F
.50903 .8216 m .50906 .82159 L .51019 .81917 L F
.154 0 0 r
.50834 .8218 m .50822 .82188 L .50788 .82193 L F
.50834 .8218 m .50788 .82193 L .50652 .82214 L F
.508 0 0 r
.50896 .82153 m .50903 .8216 L .50894 .82152 L F
.50903 .8216 m .50904 .82161 L .50902 .82159 L F
.721 .745 .871 r
.51054 .82025 m .50904 .82161 L .50886 .82145 L F
.508 0 0 r
.50703 .81982 m .50896 .82153 L .50623 .819 L F
.50896 .82153 m .50894 .82152 L .50623 .819 L F
.721 .745 .871 r
.51054 .82025 m .50886 .82145 L .50703 .81982 L F
.474 .858 .649 r
.51054 .82025 m .50968 .82086 L .50967 .82087 L F
0 .116 .644 r
.50838 .82088 m .50872 .82126 L .5073 .82156 L F
0 0 0 r
.51725 .85521 m .51867 .85372 L .51991 .85326 L F
.576 .558 .797 r
.70794 .71145 m .70673 .71476 L .70571 .71192 L F
.70794 .71145 m .70854 .71411 L .70673 .71476 L F
.573 .274 .423 r
.5228 .8485 m .51995 .85087 L .52142 .8483 L F
.5228 .8485 m .52275 .85065 L .51995 .85087 L F
.638 .326 .427 r
.5228 .8485 m .52494 .85041 L .52275 .85065 L F
.533 .347 .574 r
.52498 .84808 m .52494 .85041 L .5228 .8485 L F
0 .181 .716 r
.68329 .72461 m .68496 .72721 L .68367 .72583 L F
.21 .031 .407 r
.61741 .80603 m .61928 .80354 L .61896 .80571 L F
.181 0 .265 r
.61687 .80837 m .61741 .80603 L .61896 .80571 L F
.75 .789 .885 r
.37592 .72685 m .37293 .7269 L .37486 .72684 L F
.118 0 0 r
.37486 .72684 m .37778 .72583 L .37592 .72685 L F
.255 .743 .922 r
.39363 .89558 m .38992 .89537 L .39131 .89743 L F
.841 .987 .863 r
.63238 .78162 m .63209 .78329 L .63272 .78206 L F
.88 .988 .725 r
.63104 .7845 m .63209 .78329 L .63238 .78162 L F
.577 .354 .541 r
.43632 .82708 m .43864 .82713 L .43889 .82509 L F
.555 .461 .703 r
.43889 .82509 m .44063 .82661 L .44075 .8246 L F
.68 .446 .561 r
.43889 .82509 m .43864 .82713 L .44063 .82661 L F
.639 .33 .431 r
.45572 .8318 m .45804 .83206 L .45605 .83012 L F
.598 .337 .492 r
.45605 .83012 m .45804 .83206 L .45833 .83006 L F
.599 .898 .614 r
.64256 .70759 m .64039 .70972 L .64137 .70855 L F
0 0 0 r
.64039 .70972 m .63935 .71123 L .64137 .70855 L F
.324 .796 .701 r
.68686 .72924 m .68913 .72816 L .69007 .72786 L F
0 0 0 r
.68715 .72988 m .68913 .72816 L .68686 .72924 L F
.737 .669 .784 r
.49307 .83176 m .49453 .83266 L .4935 .82963 L F
.803 .563 .575 r
.49138 .83445 m .49453 .83266 L .49307 .83176 L F
.49138 .83445 m .49469 .83499 L .49453 .83266 L F
.766 .534 .583 r
.49453 .83266 m .49469 .83499 L .49792 .83523 L F
.591 .404 .597 r
.61968 .75675 m .62058 .75869 L .61807 .7589 L F
.703 .603 .742 r
.62136 .75538 m .62058 .75869 L .61968 .75675 L F
.693 .593 .739 r
.50437 .82703 m .50739 .82923 L .50732 .82801 L F
.629 .611 .813 r
.50732 .82801 m .50739 .82923 L .50943 .82782 L F
.15 0 .398 r
.61173 .81695 m .61309 .8141 L .61302 .81632 L F
.182 .08 .496 r
.61342 .81864 m .61173 .81695 L .61302 .81632 L F
.61342 .81864 m .61176 .81931 L .61173 .81695 L F
.428 .87 .878 r
.5852 .84838 m .58804 .84769 L .58726 .84776 L F
.318 .807 .828 r
.58804 .84769 m .58922 .84714 L .58726 .84776 L F
.615 .422 .598 r
.42098 .83244 m .42362 .83257 L .42377 .83005 L F
.672 .471 .605 r
.42377 .83005 m .42589 .83233 L .42591 .82998 L F
.42377 .83005 m .42362 .83257 L .42589 .83233 L F
.623 .411 .573 r
.60061 .77932 m .59688 .77765 L .60028 .77767 L F
.586 .268 .396 r
.60231 .77918 m .60028 .77767 L .60257 .7774 L F
.60231 .77918 m .60061 .77932 L .60028 .77767 L F
.708 .578 .707 r
.63945 .7308 m .64157 .7301 L .64141 .72794 L F
.73 .625 .741 r
.64157 .7301 m .64391 .72743 L .64141 .72794 L F
.914 .92 .805 r
.62845 .78753 m .62995 .78602 L .62886 .78539 L F
.851 .937 .88 r
.62886 .78539 m .62995 .78602 L .63104 .7845 L F
.802 .714 .768 r
.63861 .72812 m .64141 .72794 L .64045 .7269 L F
.63861 .72812 m .63945 .7308 L .64141 .72794 L F
.986 .787 .388 r
.55066 .84962 m .55081 .85097 L .55032 .84976 L F
.028 0 0 r
.54984 .84996 m .55032 .84976 L .55316 .84947 L F
.701 .203 .055 r
.55032 .84976 m .55001 .85014 L .54921 .85005 L F
.028 0 0 r
.54921 .85005 m .55032 .84976 L .54984 .84996 L F
.986 .787 .388 r
.55063 .84938 m .55066 .84962 L .55032 .84976 L F
.55081 .85097 m .55082 .85111 L .55075 .85091 L F
.55081 .85097 m .55075 .85091 L .55032 .84976 L F
.635 .764 .941 r
.55032 .84976 m .55082 .85111 L .55265 .85042 L F
.701 .203 .055 r
.55032 .84976 m .55265 .85042 L .55001 .85014 L F
.539 .872 .992 r
.54984 .84996 m .55265 .85042 L .55316 .84947 L F
.54921 .85005 m .55001 .85014 L .54984 .84996 L F
.55001 .85014 m .55265 .85042 L .54984 .84996 L F
.986 .787 .388 r
.55052 .84839 m .55063 .84938 L .55032 .84976 L F
.015 0 .271 r
.62894 .74025 m .62811 .74105 L .6296 .73801 L F
.149 0 .313 r
.6294 .74196 m .62811 .74105 L .62894 .74025 L F
.6294 .74196 m .62752 .74302 L .62811 .74105 L F
.883 .975 .672 r
.57408 .82576 m .57404 .82662 L .57575 .82373 L F
.077 .351 .823 r
.57439 .82613 m .57404 .82662 L .57408 .82576 L F
.578 .81 .419 r
.57363 .82719 m .57527 .82493 L .57404 .82662 L F
.077 .351 .823 r
.57521 .82711 m .57404 .82662 L .57439 .82613 L F
.578 .81 .419 r
.57339 .82753 m .57363 .82719 L .57404 .82662 L F
.678 .645 .81 r
.63622 .72999 m .63945 .7308 L .63861 .72812 L F
.64 .444 .601 r
.43636 .82938 m .43864 .82713 L .43632 .82708 L F
.071 0 0 r
.43535 .88496 m .43732 .8849 L .43373 .88516 L F
.405 .527 .867 r
.44771 .86014 m .44738 .86171 L .44554 .85908 L F
.501 .625 .905 r
.44771 .86014 m .44902 .8621 L .44738 .86171 L F
.636 .451 .615 r
.44902 .8621 m .44678 .86397 L .44738 .86171 L F
.797 .742 .802 r
.37774 .74906 m .38035 .74822 L .37976 .74877 L F
.062 0 0 r
.38197 .74811 m .38035 .74822 L .38217 .7476 L F
.38197 .74811 m .37976 .74877 L .38035 .74822 L F
.866 .583 .507 r
.45854 .86722 m .45725 .86813 L .45624 .86618 L F
.45854 .86722 m .45912 .86952 L .45725 .86813 L F
.087 0 0 r
.41628 .75223 m .41791 .75197 L .41993 .75103 L F
.01 0 0 r
.41993 .75103 m .42039 .75133 L .4215 .75087 L F
.41993 .75103 m .41791 .75197 L .42039 .75133 L F
.387 .139 .412 r
.62564 .74358 m .62514 .74571 L .62338 .74612 L F
.56 .339 .537 r
.62752 .74302 m .62514 .74571 L .62564 .74358 L F
.616 .238 .303 r
.50737 .81656 m .50954 .81695 L .5104 .81585 L F
.499 .104 .222 r
.5104 .81585 m .51205 .81668 L .51262 .81517 L F
.5104 .81585 m .50954 .81695 L .51205 .81668 L F
.991 .731 .401 r
.49207 .84092 m .49202 .84108 L .49254 .84107 L F
.215 .739 .82 r
.49254 .84107 m .49119 .84139 L .49324 .84106 L F
.49254 .84107 m .48986 .84146 L .49119 .84139 L F
.474 .026 .106 r
.49254 .84107 m .48832 .84293 L .48986 .84146 L F
.49254 .84107 m .49139 .84319 L .48832 .84293 L F
.991 .731 .401 r
.49202 .84108 m .49139 .84319 L .49254 .84107 L F
.215 .739 .82 r
.49254 .84107 m .49324 .84106 L .4935 .84102 L F
.641 .465 .629 r
.41869 .83511 m .42142 .83509 L .42098 .83244 L F
.65 .471 .628 r
.42098 .83244 m .42367 .83495 L .42362 .83257 L F
.42098 .83244 m .42142 .83509 L .42367 .83495 L F
.706 .813 .931 r
.51616 .83434 m .51775 .83596 L .5188 .8349 L F
.637 .511 .693 r
.39385 .85667 m .39407 .85891 L .39607 .85635 L F
.491 .307 .558 r
.62514 .74571 m .62316 .74769 L .62338 .74612 L F
.549 .591 .848 r
.39853 .73545 m .39781 .73852 L .39657 .73614 L F
.39853 .73545 m .39981 .73842 L .39781 .73852 L F
.676 .696 .861 r
.40097 .89466 m .40233 .89601 L .40396 .89477 L F
0 0 0 r
.48312 .84086 m .48173 .84261 L .48141 .84287 L F
.894 .543 .372 r
.48835 .84285 m .48706 .84254 L .48581 .83996 L F
.719 .496 .587 r
.48581 .83996 m .48706 .84254 L .48554 .84213 L F
.58 .205 .296 r
.48567 .84108 m .48312 .84086 L .48581 .83996 L F
.997 .808 .453 r
.48581 .83996 m .48554 .84213 L .4856 .84007 L F
.214 .094 .492 r
.48617 .84104 m .48826 .84053 L .4856 .84007 L F
.48706 .84254 m .48805 .84088 L .48617 .84104 L F
.48805 .84088 m .48826 .84053 L .48617 .84104 L F
.58 .205 .296 r
.48554 .84213 m .48382 .84123 L .48567 .84108 L F
.48382 .84123 m .48312 .84086 L .48567 .84108 L F
.48554 .84213 m .48173 .84261 L .48312 .84086 L F
.976 .923 .648 r
.60607 .80062 m .60579 .80358 L .6052 .80347 L F
.452 .103 .283 r
.52717 .81756 m .52633 .81897 L .52453 .81923 L F
.57 .231 .355 r
.52875 .81876 m .5256 .8202 L .52717 .81756 L F
.37 .807 .959 r
.52787 .81874 m .52755 .8183 L .5252 .8187 L F
.52875 .81876 m .52848 .81865 L .52787 .81874 L F
.52848 .81865 m .52755 .8183 L .52787 .81874 L F
.452 .103 .283 r
.52453 .81923 m .5256 .8202 L .52424 .81941 L F
.52633 .81897 m .5256 .8202 L .52453 .81923 L F
.57 .231 .355 r
.52875 .81876 m .52717 .81756 L .5293 .81704 L F
.417 0 0 r
.47362 .86199 m .47546 .86321 L .47333 .86308 L F
.47362 .86199 m .47585 .86326 L .47546 .86321 L F
.644 .497 .668 r
.41203 .84062 m .41218 .843 L .41426 .84032 L F
.152 0 0 r
.56674 .77473 m .56828 .77468 L .56873 .77392 L F
.083 0 0 r
.56674 .77473 m .56542 .77569 L .56828 .77468 L F
.59 .054 0 r
.48696 .84538 m .48812 .84601 L .4895 .84579 L F
.776 .33 .19 r
.48812 .84601 m .49139 .84803 L .4895 .84579 L F
.361 .4 .767 r
.4895 .84434 m .49027 .84716 L .48812 .84601 L F
.776 .33 .19 r
.48812 .84601 m .49059 .84833 L .49139 .84803 L F
.361 .4 .767 r
.49027 .84716 m .49059 .84833 L .48812 .84601 L F
.59 .054 0 r
.48624 .84526 m .48812 .84601 L .48696 .84538 L F
.67 .683 .853 r
.70245 .72199 m .70371 .71885 L .7014 .72102 L F
.70245 .72199 m .7044 .72177 L .70371 .71885 L F
.67 .862 .972 r
.48179 .84425 m .48141 .84287 L .48173 .84261 L F
.48179 .84425 m .48315 .84576 L .48141 .84287 L F
.72 .703 .833 r
.64092 .76436 m .63872 .7653 L .63772 .76388 L F
.667 .443 .57 r
.59688 .77765 m .59499 .77989 L .59518 .77762 L F
.59688 .77765 m .59716 .78013 L .59499 .77989 L F
.623 .411 .573 r
.60061 .77932 m .59716 .78013 L .59688 .77765 L F
0 0 0 r
.58932 .83218 m .58987 .83214 L .58706 .83231 L F
.58932 .83218 m .58987 .83214 L .58706 .83231 L F
.904 .965 .646 r
.59087 .82915 m .58987 .83214 L .58932 .83218 L F
.803 .695 .746 r
.60238 .7619 m .60115 .7587 L .6012 .75946 L F
.60238 .7619 m .5993 .7617 L .60115 .7587 L F
.616 .6 .812 r
.60225 .76412 m .5993 .7617 L .60238 .7619 L F
.505 .16 .316 r
.50168 .83524 m .50194 .83703 L .50358 .83517 L F
.752 .407 .4 r
.50194 .83703 m .50538 .83765 L .50358 .83517 L F
.544 .373 .599 r
.50358 .83517 m .50538 .83765 L .50553 .83509 L F
.195 .553 .932 r
.36281 .72508 m .36203 .72576 L .36082 .72465 L F
.36281 .72508 m .36416 .72637 L .36203 .72576 L F
.439 .12 .326 r
.39215 .77533 m .39155 .77695 L .38957 .77733 L F
.449 .122 .318 r
.39429 .77504 m .39155 .77695 L .39215 .77533 L F
.591 .156 .183 r
.48056 .86787 m .48386 .86657 L .4823 .86618 L F
.886 .913 .839 r
.48636 .86334 m .48645 .86425 L .48423 .86345 L F
.788 .665 .728 r
.48266 .86616 m .48555 .86536 L .48636 .86334 L F
.48246 .86631 m .48283 .8662 L .48266 .86616 L F
.48283 .8662 m .48555 .86536 L .48266 .86616 L F
.294 .153 .513 r
.48386 .86657 m .48467 .8666 L .4823 .86618 L F
.48467 .8666 m .48471 .8666 L .48455 .86657 L F
.48467 .8666 m .48455 .86657 L .4823 .86618 L F
.48386 .86657 m .48485 .86782 L .48471 .8666 L F
.48386 .86657 m .48351 .86951 L .48485 .86782 L F
.995 .756 .435 r
.68485 .73829 m .684 .73982 L .68329 .73781 L F
.68485 .73829 m .68484 .74055 L .684 .73982 L F
.021 .389 .848 r
.51383 .82057 m .5158 .82162 L .51516 .82062 L F
.51383 .82057 m .51516 .82062 L .51326 .82061 L F
.205 .639 .95 r
.57725 .83583 m .57432 .83483 L .5758 .83551 L F
.79 .923 .545 r
.63621 .71497 m .63433 .71768 L .63691 .71313 L F
.836 .37 .086 r
.51615 .83234 m .5188 .8349 L .51937 .83265 L F
.56 .018 0 r
.54345 .81399 m .54362 .8139 L .54203 .8131 L F
.54345 .81399 m .54456 .81474 L .54362 .8139 L F
.724 .239 .091 r
.45924 .86459 m .46063 .86449 L .45784 .86358 L F
.614 .413 .585 r
.58632 .77742 m .5863 .77954 L .58407 .77791 L F
.545 .431 .674 r
.5863 .77954 m .58443 .78052 L .58407 .77791 L F
.63 .84 .981 r
.65328 .76842 m .65395 .76678 L .65138 .76788 L F
.65328 .76842 m .65538 .76773 L .65395 .76678 L F
.742 .497 .559 r
.54685 .79596 m .54687 .79806 L .54983 .79773 L F
.378 .018 .223 r
.52713 .80889 m .52931 .80854 L .52952 .80701 L F
.491 .11 .245 r
.52952 .80701 m .52931 .80854 L .53187 .80801 L F
.979 .836 .63 r
.63509 .72943 m .63491 .73081 L .63622 .72999 L F
.78 .68 .754 r
.63397 .73289 m .63622 .72999 L .63491 .73081 L F
.736 .984 .906 r
.63622 .72999 m .63731 .72826 L .63509 .72943 L F
.63622 .72999 m .63861 .72812 L .63731 .72826 L F
.722 .725 .852 r
.39322 .73313 m .39144 .73476 L .39006 .73258 L F
.481 .184 .384 r
.37747 .77172 m .37952 .77138 L .38003 .76973 L F
.514 .215 .397 r
.37952 .77138 m .38216 .76945 L .38003 .76973 L F
0 .236 .748 r
.54787 .81727 m .54959 .81867 L .54955 .81928 L F
.721 .42 .467 r
.45418 .86175 m .45417 .86364 L .45784 .86358 L F
.984 .721 .442 r
.65318 .71135 m .65422 .71202 L .65309 .70904 L F
.65318 .71135 m .65422 .71202 L .65309 .70904 L F
.543 .377 .607 r
.62759 .72777 m .62971 .72736 L .6294 .72511 L F
.554 .38 .6 r
.62765 .73005 m .62971 .72736 L .62759 .72777 L F
.264 .429 .839 r
.68644 .70933 m .68758 .70828 L .68512 .70672 L F
.739 .251 .082 r
.68865 .71223 m .68765 .71267 L .68722 .71218 L F
.929 .967 .676 r
.68631 .7119 m .68669 .71081 L .6864 .71006 L F
.68669 .71081 m .68758 .70828 L .6864 .71006 L F
.68631 .7119 m .68621 .71106 L .68758 .70828 L F
.739 .251 .082 r
.68692 .7114 m .68722 .71218 L .68621 .71106 L F
.68865 .71223 m .68722 .71218 L .68692 .7114 L F
.929 .967 .676 r
.6864 .71006 m .68758 .70828 L .68644 .70933 L F
.492 .216 .423 r
.41109 .76194 m .41089 .76341 L .40856 .76385 L F
.527 .261 .454 r
.41315 .7616 m .41089 .76341 L .41109 .76194 L F
.543 .202 .34 r
.36774 .74913 m .36664 .75077 L .36455 .75072 L F
.305 0 .184 r
.36864 .74995 m .36774 .74913 L .37016 .74846 L F
.36864 .74995 m .36664 .75077 L .36774 .74913 L F
.37 .125 .407 r
.63137 .73641 m .6296 .73801 L .63157 .73553 L F
.053 0 .096 r
.63368 .73326 m .63157 .73553 L .63397 .73289 L F
.253 0 .31 r
.63368 .73326 m .63137 .73641 L .63157 .73553 L F
.671 .533 .688 r
.40991 .8433 m .41012 .84569 L .41218 .843 L F
0 0 0 r
.52281 .87881 m .52569 .87706 L .52512 .878 L F
.52512 .878 m .52569 .87706 L .52759 .87643 L F
.573 .534 .773 r
.64391 .72743 m .64717 .73061 L .64621 .72696 L F
.526 .16 .29 r
.48035 .82359 m .48347 .82143 L .4815 .8219 L F
.953 .915 .738 r
.49082 .87242 m .49219 .86976 L .49123 .8694 L F
.85 .964 .877 r
.49123 .8694 m .49219 .86976 L .49252 .86809 L F
.49252 .86809 m .49219 .86976 L .49123 .8694 L F
.619 .412 .579 r
.62058 .75869 m .61794 .76121 L .61807 .7589 L F
.708 .653 .793 r
.46607 .85152 m .46706 .85358 L .46619 .85352 L F
.752 .553 .626 r
.46706 .85358 m .46394 .85575 L .46619 .85352 L F
.46706 .85358 m .46747 .85597 L .46394 .85575 L F
.691 .644 .798 r
.46802 .85063 m .46706 .85358 L .46607 .85152 L F
.46802 .85063 m .46922 .85351 L .46706 .85358 L F
.69 .51 .64 r
.46922 .85351 m .46747 .85597 L .46706 .85358 L F
.765 .655 .74 r
.48604 .83238 m .48934 .83263 L .48827 .82966 L F
.656 .205 .167 r
.48604 .83238 m .48817 .83393 L .48934 .83263 L F
.667 .603 .774 r
.48827 .82966 m .48934 .83263 L .49171 .83069 L F
.707 .267 .205 r
.48817 .83393 m .49138 .83445 L .48934 .83263 L F
.703 .673 .818 r
.49171 .83069 m .48934 .83263 L .49307 .83176 L F
.605 .329 .471 r
.48934 .83263 m .49138 .83445 L .49307 .83176 L F
.606 .846 .989 r
.46429 .88252 m .46744 .88261 L .46624 .88187 L F
.46429 .88252 m .46744 .88261 L .46624 .88187 L F
.358 .636 .96 r
.46744 .88261 m .4683 .88163 L .46624 .88187 L F
.46744 .88261 m .46952 .88296 L .4683 .88163 L F
.202 0 0 r
.56829 .7805 m .56666 .782 L .56488 .78226 L F
0 0 0 r
.56941 .77957 m .56954 .77961 L .56829 .7805 L F
.159 .628 .93 r
.56168 .7817 m .56488 .78226 L .56295 .78155 L F
.675 .414 .518 r
.56549 .78217 m .56295 .78155 L .56488 .78226 L F
.56666 .782 m .56529 .78183 L .56549 .78217 L F
.56529 .78183 m .56295 .78155 L .56549 .78217 L F
.693 .699 .851 r
.56991 .77964 m .56666 .782 L .56954 .77961 L F
.681 .9 .975 r
.56541 .77992 m .56478 .78097 L .5693 .7799 L F
.675 .414 .518 r
.56666 .782 m .56408 .78213 L .56295 .78155 L F
.681 .9 .975 r
.56478 .78097 m .56408 .78213 L .56519 .78166 L F
.56478 .78097 m .56519 .78166 L .5693 .7799 L F
.56961 .77966 m .5693 .7799 L .56991 .77964 L F
.56541 .77992 m .5693 .7799 L .56961 .77966 L F
0 0 0 r
.56954 .77961 m .5678 .78106 L .56829 .7805 L F
.5678 .78106 m .56666 .782 L .56709 .7816 L F
.5678 .78106 m .56709 .7816 L .56829 .7805 L F
.471 .24 .482 r
.39914 .7696 m .39879 .77192 L .39678 .77221 L F
.532 .294 .499 r
.40084 .7715 m .39914 .7696 L .40125 .7693 L F
.40084 .7715 m .39879 .77192 L .39914 .7696 L F
.054 .22 .718 r
.55571 .83167 m .55494 .83256 L .55389 .82954 L F
0 0 .168 r
.55525 .83385 m .55494 .83256 L .55571 .83167 L F
.55525 .83385 m .55549 .83481 L .55494 .83256 L F
.727 .373 .378 r
.49469 .83499 m .49656 .83733 L .49792 .83523 L F
.708 .349 .366 r
.49792 .83523 m .49656 .83733 L .49997 .83748 L F
.668 .356 .436 r
.49792 .83523 m .49997 .83748 L .50168 .83524 L F
.508 .211 .398 r
.5268 .87563 m .52575 .87395 L .52332 .8749 L F
.476 .208 .427 r
.3793 .7873 m .37797 .78523 L .37993 .78494 L F
.3793 .7873 m .37733 .78781 L .37797 .78523 L F
0 0 0 r
.57187 .7786 m .56941 .77957 L .57246 .77819 L F
.57187 .7786 m .56954 .77961 L .56941 .77957 L F
.671 .553 .713 r
.53124 .83775 m .53248 .84076 L .5292 .84039 L F
.57 .555 .798 r
.53239 .8429 m .5292 .84039 L .53248 .84076 L F
.296 0 0 r
.37192 .74857 m .36864 .74995 L .37016 .74846 L F
.505 .16 .316 r
.50168 .83524 m .49997 .83748 L .50194 .83703 L F
.49 0 0 r
.56825 .78858 m .56996 .7886 L .56727 .78792 L F
0 0 .172 r
.62184 .79891 m .62361 .79586 L .62273 .79806 L F
0 0 .188 r
.62121 .80092 m .62184 .79891 L .62273 .79806 L F
.674 .505 .649 r
.37522 .87455 m .37802 .87456 L .37796 .87203 L F
.601 .403 .585 r
.37802 .87456 m .3803 .87188 L .37796 .87203 L F
.472 .069 .194 r
.65017 .72637 m .64901 .72541 L .64789 .72646 L F
.65017 .72637 m .65121 .72489 L .64901 .72541 L F
.427 .465 .796 r
.39544 .73438 m .39436 .73625 L .39322 .73313 L F
.529 .594 .864 r
.39544 .73438 m .39657 .73614 L .39436 .73625 L F
.626 .473 .656 r
.66069 .71721 m .66099 .72008 L .65861 .72014 L F
0 0 0 r
.66069 .71721 m .65861 .72014 L .65991 .71907 L F
.192 0 0 r
.66099 .72008 m .66047 .72052 L .65861 .72014 L F
.146 .081 .52 r
.65861 .72014 m .66047 .72052 L .65991 .71907 L F
.65 .47 .627 r
.40785 .84582 m .41001 .84797 L .41012 .84569 L F
.40785 .84582 m .40776 .84831 L .41001 .84797 L F
.557 .38 .597 r
.49493 .82195 m .49469 .82355 L .49259 .82358 L F
.66 .5 .656 r
.49564 .82701 m .49259 .82358 L .49469 .82355 L F
.49564 .82701 m .49428 .82824 L .49259 .82358 L F
.52 .358 .602 r
.62573 .73279 m .62765 .73005 L .62538 .73022 L F
.795 .623 .667 r
.46619 .85352 m .46266 .85068 L .46607 .85152 L F
.46619 .85352 m .46452 .85367 L .46266 .85068 L F
.794 .613 .656 r
.46619 .85352 m .46394 .85575 L .46452 .85367 L F
0 .119 .669 r
.55239 .82716 m .55389 .82954 L .55366 .82737 L F
.668 .554 .717 r
.39407 .85891 m .39631 .85858 L .39607 .85635 L F
.647 .504 .675 r
.39425 .86134 m .39631 .85858 L .39407 .85891 L F
.764 .71 .801 r
.62483 .76904 m .62582 .77186 L .62404 .77237 L F
.743 .699 .81 r
.62809 .76941 m .62582 .77186 L .62483 .76904 L F
.503 .787 .996 r
.45037 .88364 m .45155 .88456 L .45347 .88416 L F
.337 0 0 r
.57115 .77357 m .57331 .77345 L .57452 .77247 L F
.283 0 0 r
.57331 .77345 m .57652 .77178 L .57452 .77247 L F
.581 .168 .224 r
.51489 .81489 m .51689 .81595 L .51806 .81418 L F
.535 .118 .197 r
.51806 .81418 m .51937 .81571 L .52018 .81394 L F
.51806 .81418 m .51689 .81595 L .51937 .81571 L F
.573 .938 .813 r
.64638 .7099 m .64553 .71086 L .6481 .70902 L F
.64638 .7099 m .64457 .71104 L .64553 .71086 L F
.382 .846 .854 r
.58314 .84905 m .58415 .84844 L .58197 .84876 L F
.58314 .84905 m .5852 .84838 L .58415 .84844 L F
0 0 .129 r
.69186 .71733 m .69221 .71673 L .69232 .71406 L F
0 0 0 r
.69186 .71733 m .69156 .71853 L .69221 .71673 L F
.681 .523 .665 r
.38763 .86677 m .3899 .86656 L .38981 .86416 L F
.643 .477 .643 r
.3899 .86656 m .39207 .86393 L .38981 .86416 L F
.794 .999 .841 r
.60927 .79807 m .60992 .79817 L .60667 .801 L F
.852 .959 .877 r
.61152 .79538 m .60992 .79817 L .60927 .79807 L F
.61152 .79538 m .61235 .79589 L .60992 .79817 L F
.487 .085 .204 r
.48584 .82158 m .48794 .8215 L .48919 .81969 L F
.499 .098 .211 r
.48919 .81969 m .49177 .81999 L .49137 .81984 L F
.48919 .81969 m .48794 .8215 L .49177 .81999 L F
.703 .829 .942 r
.33013 .6695 m .33372 .66934 L .3329 .66839 L F
.066 .556 .893 r
.33372 .66934 m .33414 .66896 L .3329 .66839 L F
.561 .401 .622 r
.33563 .66732 m .33566 .66982 L .33372 .66934 L F
.066 .556 .893 r
.33372 .66934 m .33566 .66982 L .33414 .66896 L F
.726 .686 .143 r
.55343 .84851 m .55395 .84517 L .55409 .84755 L F
0 0 0 r
.55265 .85042 m .55343 .84851 L .55409 .84755 L F
.307 .792 .897 r
.36416 .72637 m .36611 .72602 L .36783 .72614 L F
.542 .909 .957 r
.36783 .72614 m .36812 .72526 L .36971 .72563 L F
.36783 .72614 m .36611 .72602 L .36812 .72526 L F
0 0 .259 r
.63509 .72943 m .63397 .73289 L .63491 .73081 L F
.63509 .72943 m .63489 .73188 L .63397 .73289 L F
.038 .034 .522 r
.63489 .73188 m .63368 .73326 L .63397 .73289 L F
.527 .262 .456 r
.39879 .77192 m .39612 .77442 L .39678 .77221 L F
.665 .449 .581 r
.61042 .74784 m .60966 .74914 L .60733 .74859 L F
.635 .548 .739 r
.60733 .74859 m .60966 .74914 L .60975 .74664 L F
.603 .412 .596 r
.3803 .87188 m .3824 .87166 L .38258 .86931 L F
.733 .608 .718 r
.3824 .87166 m .38449 .86893 L .38258 .86931 L F
.638 .442 .602 r
.40072 .85357 m .40357 .85351 L .40356 .85108 L F
.697 .49 .604 r
.40356 .85108 m .40579 .8533 L .40571 .85089 L F
.40356 .85108 m .40357 .85351 L .40579 .8533 L F
0 .367 .788 r
.48959 .86823 m .48913 .86843 L .48763 .86687 L F
.48959 .86823 m .49123 .8694 L .48913 .86843 L F
.698 .651 .8 r
.5993 .7617 m .60008 .76461 L .59922 .76254 L F
.5993 .7617 m .60008 .76461 L .5993 .7617 L F
.616 .6 .812 r
.60225 .76412 m .5993 .7617 L .59931 .76171 L F
.131 0 0 r
.60268 .76224 m .60118 .76346 L .60387 .76248 L F
.60215 .76213 m .60178 .76265 L .60268 .76224 L F
.60178 .76265 m .60118 .76346 L .60268 .76224 L F
.616 .6 .812 r
.60225 .76412 m .60008 .76461 L .5998 .76355 L F
.60092 .76303 m .5998 .76355 L .5993 .7617 L F
.60225 .76412 m .5998 .76355 L .60092 .76303 L F
.59931 .76171 m .5993 .7617 L .5993 .7617 L F
.89 .776 .729 r
.59922 .76254 m .5957 .76561 L .59795 .76316 L F
.59922 .76254 m .59708 .76658 L .5957 .76561 L F
.718 .331 .314 r
.59795 .76316 m .60118 .76346 L .60178 .76265 L F
.60131 .76247 m .60178 .76265 L .60201 .76233 L F
.59795 .76316 m .60178 .76265 L .60131 .76247 L F
.60167 .76225 m .60201 .76233 L .60215 .76213 L F
.59795 .76316 m .60201 .76233 L .60167 .76225 L F
.698 .651 .8 r
.5993 .7617 m .5993 .7617 L .5993 .7617 L F
.752 .674 .775 r
.47151 .85093 m .46922 .85351 L .46802 .85063 L F
.634 .835 .978 r
.43732 .8849 m .44064 .88503 L .43938 .88449 L F
.444 .813 .994 r
.43938 .88449 m .44064 .88503 L .44268 .88473 L F
.596 .413 .604 r
.42591 .82998 m .42803 .83203 L .42813 .82989 L F
.42591 .82998 m .42589 .83233 L .42803 .83203 L F
.674 .517 .664 r
.41863 .83753 m .42142 .83509 L .41869 .83511 L F
.375 .766 .988 r
.40183 .73815 m .40534 .73867 L .40319 .73887 L F
.848 .719 .193 r
.61241 .79194 m .61235 .79589 L .61152 .79538 L F
.401 .837 .947 r
.46623 .86424 m .46304 .86444 L .4649 .86353 L F
.849 .866 .854 r
.46867 .86181 m .46623 .86424 L .4649 .86353 L F
0 0 0 r
.66069 .71721 m .65991 .71907 L .65913 .71722 L F
.896 .836 .779 r
.66069 .71721 m .66122 .71296 L .66125 .71497 L F
.66069 .71721 m .65913 .71722 L .66122 .71296 L F
.693 .523 .653 r
.66409 .71881 m .66069 .71721 L .6642 .71736 L F
.66409 .71881 m .66099 .72008 L .66069 .71721 L F
.556 .303 .487 r
.40856 .76385 m .4081 .76688 L .40582 .76706 L F
.51 .263 .475 r
.41001 .76648 m .40856 .76385 L .41089 .76341 L F
.41001 .76648 m .4081 .76688 L .40856 .76385 L F
.553 .215 .35 r
.58936 .76898 m .59166 .76899 L .5924 .76685 L F
.43 .868 .908 r
.5924 .76685 m .5933 .76626 L .59376 .76638 L F
0 0 .019 r
.5924 .76685 m .59298 .7673 L .5933 .76626 L F
.989 .764 .377 r
.59298 .7673 m .59273 .76611 L .5933 .76626 L F
.59273 .76611 m .5926 .76551 L .5933 .76626 L F
.43 .868 .908 r
.59376 .76638 m .5933 .76626 L .59441 .76615 L F
0 0 .019 r
.5924 .76685 m .59166 .76899 L .59298 .7673 L F
0 0 0 r
.61171 .74574 m .61042 .74784 L .61272 .74814 L F
.61171 .74574 m .60966 .74914 L .61042 .74784 L F
.568 .241 .375 r
.60959 .75052 m .61272 .74814 L .61042 .74784 L F
.097 0 .223 r
.63137 .73641 m .62894 .74025 L .6296 .73801 L F
.052 0 0 r
.64256 .70759 m .64338 .7079 L .64445 .70648 L F
.64256 .70759 m .64137 .70855 L .64338 .7079 L F
.559 .828 .996 r
.44598 .88469 m .4469 .88343 L .44472 .88423 L F
.44598 .88469 m .44798 .8842 L .4469 .88343 L F
.873 .896 .847 r
.41698 .88991 m .41919 .88764 L .41808 .88694 L F
.46 .797 .999 r
.41808 .88694 m .41919 .88764 L .42184 .88717 L F
.671 .925 .973 r
.54452 .78476 m .54455 .7855 L .54609 .78447 L F
0 0 0 r
.65752 .76661 m .6593 .76615 L .65719 .76673 L F
.65752 .76661 m .65929 .76595 L .6593 .76615 L F
.668 .747 .909 r
.50943 .82782 m .51271 .82861 L .51159 .82797 L F
.281 .734 .957 r
.51271 .82861 m .51364 .82805 L .51159 .82797 L F
.51271 .82861 m .51462 .82851 L .51364 .82805 L F
.926 .551 .274 r
.67085 .73807 m .66952 .73743 L .66867 .7356 L F
0 .062 .626 r
.67085 .73807 m .67243 .74104 L .6721 .73973 L F
.784 .581 .627 r
.6721 .73973 m .66952 .73743 L .67085 .73807 L F
.63 .369 .505 r
.50011 .8169 m .50237 .81871 L .502 .8167 L F
.50011 .8169 m .49854 .8196 L .50237 .81871 L F
0 .207 .725 r
.47684 .86433 m .4771 .86366 L .47585 .86326 L F
.442 .405 .721 r
.6294 .72511 m .63163 .72492 L .63072 .72172 L F
.608 .541 .753 r
.62971 .72736 m .63163 .72492 L .6294 .72511 L F
.635 .867 .985 r
.54173 .82964 m .54096 .83099 L .54019 .82942 L F
.54173 .82964 m .54303 .83026 L .54096 .83099 L F
.462 .889 .872 r
.46231 .88331 m .46293 .88272 L .46069 .88266 L F
.46231 .88331 m .46429 .88252 L .46293 .88272 L F
.727 .771 .888 r
.67645 .7139 m .67619 .71538 L .6738 .71473 L F
.697 .16 0 r
.67671 .71645 m .67619 .71538 L .67645 .7139 L F
.253 0 .31 r
.63368 .73326 m .63323 .73687 L .63137 .73641 L F
.038 .034 .522 r
.63489 .73188 m .63523 .73412 L .63368 .73326 L F
.185 0 .29 r
.63523 .73412 m .63323 .73687 L .63368 .73326 L F
.849 .866 .854 r
.46867 .86181 m .4649 .86353 L .46666 .86263 L F
.889 .958 .838 r
.47072 .85917 m .46867 .86181 L .46827 .86053 L F
.911 .96 .807 r
.46867 .86181 m .46666 .86263 L .46827 .86053 L F
.486 .084 .203 r
.4908 .85048 m .48935 .85237 L .48713 .8525 L F
.569 .589 .833 r
.49139 .84803 m .49276 .85078 L .4908 .85048 L F
.706 .392 .443 r
.49276 .85078 m .48935 .85237 L .4908 .85048 L F
.438 .773 .997 r
.53277 .86937 m .53498 .86923 L .53375 .86846 L F
.415 .807 .988 r
.54543 .84027 m .54619 .83938 L .54463 .83715 L F
.54543 .84027 m .54775 .83997 L .54619 .83938 L F
.614 .558 .767 r
.54622 .842 m .54775 .83997 L .54543 .84027 L F
.591 .424 .624 r
.41218 .843 m .41012 .84569 L .41226 .84536 L F
.63 .429 .592 r
.41012 .84569 m .41235 .84779 L .41226 .84536 L F
.41012 .84569 m .41001 .84797 L .41235 .84779 L F
.635 .506 .688 r
.41402 .83799 m .41426 .84032 L .41629 .83761 L F
.523 .784 .992 r
.66772 .75302 m .66871 .75391 L .66612 .75362 L F
.842 .877 .867 r
.67186 .75103 m .66871 .75391 L .66772 .75302 L F
.38 0 0 r
.4963 .84198 m .49254 .84107 L .4935 .84102 L F
.182 .201 .645 r
.69582 .70871 m .69505 .71186 L .69421 .70867 L F
.69582 .70871 m .69645 .71068 L .69505 .71186 L F
.76 .772 .863 r
.69945 .71082 m .69643 .71146 L .69645 .71068 L F
.26 .337 .753 r
.69612 .71095 m .69639 .71291 L .69505 .71186 L F
.69645 .71068 m .69643 .71146 L .69612 .71095 L F
.69643 .71146 m .69639 .71291 L .69612 .71095 L F
.815 .966 .903 r
.70048 .71218 m .69745 .71374 L .69984 .71378 L F
.73 .532 .623 r
.69643 .71146 m .69769 .71232 L .69945 .71082 L F
.69668 .71187 m .69984 .71378 L .69643 .71146 L F
.69769 .71232 m .69984 .71378 L .6996 .7119 L F
.69769 .71232 m .6996 .7119 L .69945 .71082 L F
.76 .772 .863 r
.69945 .71082 m .69645 .71068 L .69843 .71035 L F
.585 .59 .823 r
.6966 .71128 m .69984 .71378 L .69843 .71035 L F
.26 .337 .753 r
.69645 .71068 m .69716 .71352 L .69639 .71291 L F
.73 .532 .623 r
.6961 .71153 m .69668 .71187 L .69643 .71146 L F
.585 .59 .823 r
.6961 .71153 m .69668 .71187 L .6966 .71128 L F
.69668 .71187 m .69984 .71378 L .6966 .71128 L F
.26 .337 .753 r
.6966 .71128 m .69745 .71374 L .69716 .71352 L F
.585 .59 .823 r
.6966 .71128 m .69843 .71035 L .69645 .71068 L F
.26 .337 .753 r
.69645 .71068 m .69657 .71105 L .6966 .71128 L F
.69657 .71105 m .69745 .71374 L .6966 .71128 L F
.76 .772 .863 r
.69643 .71146 m .6961 .71153 L .69645 .71068 L F
.585 .59 .823 r
.6961 .71153 m .6966 .71128 L .69645 .71068 L F
.756 .644 .736 r
.69413 .71344 m .69745 .71374 L .69703 .71246 L F
.6945 .713 m .69703 .71246 L .69645 .71068 L F
.69413 .71344 m .69703 .71246 L .6945 .713 L F
.159 .628 .93 r
.56168 .7817 m .56295 .78155 L .56319 .78104 L F
.78 .751 .827 r
.70371 .71885 m .7044 .72177 L .70663 .71868 L F
.698 .73 .875 r
.63982 .76321 m .64092 .76436 L .63772 .76388 L F
.75 .74 .843 r
.64281 .76335 m .64092 .76436 L .63982 .76321 L F
.874 .768 .742 r
.61644 .77975 m .61681 .78277 L .61502 .78211 L F
.864 .666 .633 r
.61686 .78449 m .61502 .78211 L .61681 .78277 L F
.764 .694 .785 r
.61963 .77998 m .61681 .78277 L .61644 .77975 L F
.716 .985 .886 r
.64515 .77168 m .64571 .77048 L .64425 .77127 L F
.64515 .77168 m .64776 .7699 L .64571 .77048 L F
.879 .536 .038 r
.67715 .72183 m .67732 .72381 L .67717 .7224 L F
.67715 .72183 m .67792 .72457 L .67732 .72381 L F
.512 .313 .547 r
.60275 .75475 m .60569 .75418 L .6053 .75129 L F
.558 .345 .548 r
.6053 .75129 m .60569 .75418 L .60757 .75305 L F
.327 0 0 r
.50501 .87992 m .50713 .87976 L .50594 .88093 L F
.771 .501 .527 r
.5247 .83299 m .52162 .83467 L .52197 .83233 L F
.5247 .83299 m .52377 .83548 L .52162 .83467 L F
.736 .462 .514 r
.52577 .83439 m .52377 .83548 L .5247 .83299 L F
0 .166 .7 r
.66937 .71339 m .66903 .71447 L .66717 .71146 L F
.66937 .71339 m .66957 .71464 L .66903 .71447 L F
0 0 .127 r
.56421 .83432 m .56426 .83511 L .56456 .8372 L F
.559 .516 .764 r
.65121 .72489 m .65359 .72461 L .6528 .72361 L F
.434 .251 .532 r
.65359 .72461 m .65166 .72778 L .65121 .72489 L F
.695 .467 .573 r
.65017 .72637 m .65359 .72461 L .65121 .72489 L F
.559 .516 .764 r
.65121 .72489 m .65359 .72461 L .6528 .72361 L F
.836 .507 0 r
.69205 .73486 m .69221 .73474 L .6915 .73272 L F
0 0 .433 r
.69255 .7339 m .69205 .73486 L .6915 .73272 L F
.914 .678 .568 r
.69183 .73504 m .69205 .73486 L .69255 .7339 L F
.69047 .73718 m .69205 .73486 L .69183 .73504 L F
.836 .507 0 r
.69205 .73486 m .69253 .73565 L .69221 .73474 L F
.794 .999 .841 r
.60927 .79807 m .60667 .801 L .60607 .80062 L F
.488 .164 .343 r
.35678 .80161 m .35832 .80241 L .35627 .80327 L F
.35678 .80161 m .35897 .8011 L .35832 .80241 L F
.437 .091 .279 r
.51262 .81517 m .51416 .81624 L .51489 .81489 L F
.51262 .81517 m .51205 .81668 L .51416 .81624 L F
.315 .367 .757 r
.69217 .73789 m .69446 .73979 L .69304 .74117 L F
.675 .708 .873 r
.63772 .76388 m .63556 .76458 L .6344 .7634 L F
.614 .558 .767 r
.54622 .842 m .54853 .84288 L .54775 .83997 L F
.295 0 0 r
.47262 .88352 m .47609 .88402 L .47544 .88379 L F
.001 .549 .828 r
.47609 .88402 m .47701 .88398 L .47544 .88379 L F
.47609 .88402 m .47815 .8844 L .47701 .88398 L F
.842 .877 .867 r
.67186 .75103 m .66772 .75302 L .66741 .75077 L F
.768 .859 .917 r
.67186 .75103 m .66741 .75077 L .67055 .74993 L F
.652 .49 .652 r
.39207 .86393 m .39457 .86378 L .39425 .86134 L F
.647 .504 .675 r
.39425 .86134 m .39728 .86146 L .39631 .85858 L F
.606 .421 .606 r
.39457 .86378 m .39728 .86146 L .39425 .86134 L F
.708 .749 .884 r
.47992 .85344 m .4777 .85414 L .47678 .85301 L F
.687 .525 .661 r
.37307 .87705 m .37595 .87725 L .37522 .87455 L F
.675 .517 .664 r
.37595 .87725 m .37802 .87456 L .37522 .87455 L F
.663 .651 .828 r
.57318 .83221 m .57217 .83498 L .57093 .83262 L F
.57318 .83221 m .57432 .83483 L .57217 .83498 L F
.577 .221 .328 r
.57217 .83498 m .57327 .83622 L .57158 .83779 L F
.57217 .83498 m .57432 .83483 L .57327 .83622 L F
.296 0 0 r
.35546 .72697 m .359 .72552 L .35674 .72647 L F
.722 .552 .659 r
.38449 .86893 m .38768 .86916 L .38763 .86677 L F
.68 .518 .66 r
.38768 .86916 m .3899 .86656 L .38763 .86677 L F
.721 .604 .726 r
.39336 .75631 m .39052 .75646 L .39262 .75381 L F
.661 .337 .413 r
.39052 .75646 m .39248 .75843 L .39336 .75631 L F
.344 .79 .956 r
.39336 .75631 m .3947 .75583 L .39569 .75612 L F
.049 0 .117 r
.39336 .75631 m .39248 .75843 L .3947 .75583 L F
.404 .856 .886 r
.59235 .84693 m .59619 .84625 L .59353 .84681 L F
.531 .922 .878 r
.59353 .84681 m .59619 .84625 L .59797 .84533 L F
.998 .775 .445 r
.56301 .82667 m .56293 .82802 L .56228 .82603 L F
.958 .711 .263 r
.56228 .82603 m .56288 .82883 L .56282 .82783 L F
.998 .775 .445 r
.56293 .82802 m .56288 .82883 L .56262 .82762 L F
0 0 0 r
.56314 .828 m .56228 .83008 L .56312 .82815 L F
0 0 .396 r
.56288 .82883 m .56387 .83017 L .56282 .82783 L F
.813 .391 0 r
.56286 .82793 m .56279 .82785 L .56282 .82783 L F
.798 .481 0 r
.56282 .82783 m .56252 .82711 L .56228 .82603 L F
.998 .775 .445 r
.56263 .82763 m .56262 .82762 L .56228 .82603 L F
.798 .481 0 r
.56252 .82711 m .56186 .82552 L .56228 .82603 L F
.998 .775 .445 r
.56293 .82802 m .56263 .82763 L .56228 .82603 L F
.813 .391 0 r
.56307 .82841 m .56249 .82801 L .56279 .82785 L F
.56307 .82841 m .56279 .82785 L .56286 .82793 L F
.56387 .83017 m .56301 .82883 L .56307 .82841 L F
.56301 .82883 m .56249 .82801 L .56307 .82841 L F
0 0 0 r
.56312 .82815 m .56228 .83008 L .56288 .82883 L F
.56331 .82758 m .56314 .828 L .56312 .82815 L F
0 .12 .645 r
.56288 .82883 m .56228 .83008 L .5631 .83139 L F
.644 .501 .673 r
.40558 .84862 m .40571 .85089 L .40776 .84831 L F
.597 .649 .872 r
.3831 .91677 m .38249 .91884 L .38194 .91821 L F
.3831 .91677 m .38422 .91839 L .38242 .91907 L F
.615 .743 .937 r
.38661 .91774 m .38422 .91839 L .3831 .91677 L F
.444 .864 .947 r
.3841 .91837 m .38497 .91748 L .38238 .91813 L F
.38422 .91839 m .38427 .91832 L .3841 .91837 L F
.38427 .91832 m .38497 .91748 L .3841 .91837 L F
.597 .649 .872 r
.38249 .91884 m .38242 .91907 L .38232 .91889 L F
.38249 .91884 m .38232 .91889 L .38194 .91821 L F
.067 0 0 r
.38242 .91907 m .38422 .91839 L .38189 .91959 L F
.601 .403 .585 r
.37802 .87456 m .3802 .87423 L .3803 .87188 L F
.656 .479 .633 r
.3802 .87423 m .3824 .87166 L .3803 .87188 L F
.597 .025 0 r
.50702 .87596 m .50399 .8744 L .50601 .87609 L F
.64 .491 .665 r
.41218 .843 m .4144 .84285 L .41426 .84032 L F
.607 .437 .626 r
.41218 .843 m .41441 .84509 L .4144 .84285 L F
.41218 .843 m .41226 .84536 L .41441 .84509 L F
.336 .177 .512 r
.5416 .8268 m .54019 .82942 L .54023 .82739 L F
.329 0 0 r
.47498 .87187 m .47579 .87196 L .47262 .87108 L F
.615 .869 .99 r
.47635 .87079 m .47721 .8715 L .47579 .87196 L F
.744 .992 .874 r
.47635 .87079 m .47579 .87196 L .47498 .87187 L F
.756 .272 0 r
.55836 .81463 m .55889 .81596 L .55814 .81341 L F
.55836 .81463 m .55959 .81636 L .55889 .81596 L F
0 0 0 r
.50797 .87589 m .50702 .87596 L .50601 .87609 L F
.50797 .87589 m .50941 .87542 L .50702 .87596 L F
0 .001 .559 r
.66356 .7296 m .66417 .72886 L .66342 .72656 L F
.889 .545 .057 r
.66342 .72656 m .66417 .72886 L .6633 .72678 L F
0 0 0 r
.66296 .72689 m .66342 .72656 L .66366 .72609 L F
.889 .545 .057 r
.66342 .72656 m .6633 .72678 L .663 .72607 L F
0 0 0 r
.66366 .72609 m .66342 .72656 L .66501 .72455 L F
.346 .823 .861 r
.66732 .72397 m .66501 .72455 L .66628 .72395 L F
.516 0 0 r
.50713 .87976 m .5102 .88023 L .51002 .88099 L F
.543 0 0 r
.51002 .88099 m .5102 .88023 L .51228 .88136 L F
0 0 0 r
.56331 .82758 m .56288 .82883 L .56301 .82667 L F
0 .421 .842 r
.53928 .81027 m .53793 .81027 L .53697 .80866 L F
.53928 .81027 m .54027 .81118 L .53793 .81027 L F
.647 .386 .511 r
.51076 .83342 m .51368 .83484 L .51389 .8325 L F
.51076 .83342 m .51054 .83502 L .51368 .83484 L F
.555 .327 .525 r
.37237 .77701 m .37478 .77456 L .37285 .77505 L F
.538 .314 .523 r
.37067 .79063 m .37043 .79279 L .36842 .79301 L F
.502 .283 .514 r
.37238 .79228 m .37067 .79063 L .37292 .79056 L F
.37238 .79228 m .37043 .79279 L .37067 .79063 L F
.411 .05 .238 r
.35492 .75294 m .35394 .75131 L .35601 .75164 L F
.35492 .75294 m .35282 .75343 L .35394 .75131 L F
.799 .443 .383 r
.68762 .74372 m .68524 .7449 L .68524 .74278 L F
.68762 .74372 m .68806 .74543 L .68524 .7449 L F
.877 .651 .592 r
.50953 .82109 m .51041 .8221 L .51326 .82061 L F
.257 .384 .801 r
.51326 .82061 m .51389 .81792 L .51166 .81834 L F
.51326 .82061 m .51516 .82062 L .51389 .81792 L F
.197 .663 .94 r
.45693 .88468 m .45529 .88401 L .45673 .8846 L F
.575 .405 .614 r
.62355 .73527 m .6261 .73496 L .62573 .73279 L F
.664 .578 .749 r
.62413 .73711 m .6261 .73496 L .62355 .73527 L F
.594 .16 .186 r
.54687 .79806 m .54912 .79864 L .54983 .79773 L F
.541 .395 .632 r
.54983 .79773 m .55213 .79728 L .55197 .79584 L F
.523 .173 .316 r
.54912 .79864 m .55213 .79728 L .54983 .79773 L F
.722 .696 .824 r
.62252 .77147 m .62404 .77237 L .62072 .77216 L F
.737 .569 .665 r
.62404 .77237 m .6205 .77447 L .62072 .77216 L F
.62404 .77237 m .62395 .77483 L .6205 .77447 L F
.764 .71 .801 r
.62483 .76904 m .62404 .77237 L .62252 .77147 L F
.71 .959 .692 r
.55123 .84292 m .55477 .83955 L .55255 .84286 L F
.69 .423 .513 r
.55255 .84286 m .55131 .84559 L .55123 .84292 L F
.55255 .84286 m .55395 .84517 L .55131 .84559 L F
.551 .602 .858 r
.56565 .84569 m .56887 .84776 L .5678 .84804 L F
.445 .853 .965 r
.56887 .84776 m .57007 .84695 L .5678 .84804 L F
.56887 .84776 m .57142 .84725 L .57007 .84695 L F
0 0 .362 r
.56487 .84268 m .56565 .84569 L .56559 .84486 L F
0 .021 .558 r
.56565 .84569 m .56697 .84691 L .56559 .84486 L F
.56565 .84569 m .5678 .84804 L .56697 .84691 L F
.956 .674 .46 r
.6832 .73561 m .682 .73716 L .68176 .73522 L F
.6832 .73561 m .68329 .73781 L .682 .73716 L F
.722 .512 .605 r
.45525 .85349 m .45312 .85567 L .45181 .85319 L F
.45525 .85349 m .45511 .85604 L .45312 .85567 L F
.672 .469 .602 r
.45886 .85329 m .45511 .85604 L .45525 .85349 L F
.526 .784 .991 r
.39867 .89472 m .40108 .8941 L .39769 .89422 L F
.39867 .89472 m .40097 .89466 L .40108 .8941 L F
.566 .39 .602 r
.60275 .75475 m .60539 .75588 L .60569 .75418 L F
.60275 .75475 m .60322 .75622 L .60539 .75588 L F
.737 .669 .784 r
.49307 .83176 m .4935 .82963 L .49171 .83069 L F
.707 .458 .545 r
.70594 .72711 m .70295 .72481 L .70392 .72776 L F
.70594 .72711 m .70632 .72517 L .70295 .72481 L F
.426 .199 .464 r
.70594 .72711 m .70632 .72517 L .70814 .72456 L F
.70594 .72711 m .70632 .72517 L .70814 .72456 L F
.562 .557 .806 r
.47438 .84035 m .4712 .83735 L .47281 .83745 L F
.692 .562 .703 r
.47648 .83771 m .47438 .84035 L .47281 .83745 L F
.25 .637 .961 r
.52282 .87362 m .52176 .87464 L .52114 .87358 L F
.52282 .87362 m .5268 .87563 L .52176 .87464 L F
.555 .37 .586 r
.53337 .83489 m .53335 .83754 L .53128 .83769 L F
0 0 .373 r
.53424 .83617 m .53335 .83754 L .53337 .83489 L F
.53432 .8363 m .53423 .83641 L .53424 .83617 L F
.53423 .83641 m .53335 .83754 L .53424 .83617 L F
.936 .688 .537 r
.53292 .83671 m .53335 .83754 L .53432 .8363 L F
.53292 .83671 m .53559 .83738 L .53335 .83754 L F
.53559 .83738 m .53559 .83738 L .53335 .83754 L F
.705 .588 .722 r
.53669 .84008 m .53459 .84073 L .53335 .83754 L F
.53669 .84008 m .53335 .83754 L .53559 .83738 L F
.936 .688 .537 r
.53423 .83704 m .53442 .83923 L .53559 .83738 L F
.608 .537 .749 r
.53335 .83754 m .53248 .84076 L .53124 .83775 L F
.53335 .83754 m .53459 .84073 L .53248 .84076 L F
.555 .37 .586 r
.53128 .83769 m .53335 .83754 L .53124 .83775 L F
.619 .565 .773 r
.53324 .83587 m .53192 .83863 L .53292 .83671 L F
.791 .786 .848 r
.53192 .83863 m .5293 .83931 L .53292 .83671 L F
.936 .688 .537 r
.53292 .83671 m .53379 .83816 L .53423 .83704 L F
.53379 .83816 m .53423 .83818 L .53423 .83704 L F
.53422 .83889 m .53442 .83923 L .53423 .83704 L F
.619 .565 .773 r
.53324 .83587 m .53292 .83671 L .53432 .8363 L F
.949 .679 .491 r
.53292 .83671 m .533 .83703 L .53442 .83923 L F
.53373 .83816 m .53407 .84071 L .53442 .83923 L F
.533 .83703 m .53332 .83812 L .53373 .83816 L F
.53332 .83812 m .53407 .84071 L .53373 .83816 L F
.467 .878 .944 r
.53332 .83812 m .53192 .83863 L .53284 .8367 L F
.632 .48 .658 r
.53288 .83676 m .53291 .8368 L .53292 .83671 L F
.467 .878 .944 r
.53296 .83686 m .53284 .8367 L .53288 .83661 L F
.53332 .83812 m .53284 .8367 L .53291 .8368 L F
.53332 .83812 m .53326 .83812 L .53328 .83814 L F
.699 .54 .668 r
.53291 .8368 m .53275 .83823 L .533 .83703 L F
.53275 .83823 m .53232 .84188 L .53284 .83821 L F
.53275 .83823 m .53284 .83821 L .533 .83703 L F
.533 .83703 m .53284 .83821 L .53327 .83812 L F
.467 .878 .944 r
.53332 .83812 m .53291 .8368 L .533 .83703 L F
.632 .48 .658 r
.52902 .84132 m .53232 .84188 L .53275 .83823 L F
.53137 .83859 m .53275 .83823 L .53291 .8368 L F
.612 .934 .96 r
.52988 .8385 m .5293 .83931 L .53008 .83911 L F
.53137 .83859 m .53008 .83911 L .53192 .83863 L F
.53131 .83861 m .53008 .83911 L .53137 .83859 L F
.632 .48 .658 r
.52902 .84132 m .53131 .83861 L .5293 .83931 L F
.53132 .8386 m .53292 .83671 L .52985 .83892 L F
.53132 .8386 m .53291 .8368 L .53288 .83676 L F
.53131 .83861 m .53132 .8386 L .53132 .8386 L F
.53132 .8386 m .53291 .8368 L .53132 .8386 L F
.467 .878 .944 r
.53328 .83814 m .53299 .83817 L .53137 .83859 L F
.632 .48 .658 r
.53137 .83859 m .53291 .8368 L .53131 .83861 L F
.467 .878 .944 r
.53299 .83817 m .52988 .8385 L .53136 .83859 L F
.53299 .83817 m .53136 .83859 L .53137 .83859 L F
.533 .83824 m .53137 .83859 L .53192 .83863 L F
.53328 .83814 m .53137 .83859 L .533 .83824 L F
.632 .48 .658 r
.53131 .83861 m .53132 .8386 L .5293 .83931 L F
.53132 .8386 m .52985 .83892 L .5293 .83931 L F
.612 .934 .96 r
.53136 .83859 m .53131 .83861 L .53137 .83859 L F
.52988 .8385 m .53008 .83911 L .53136 .83859 L F
.632 .48 .658 r
.52902 .84132 m .53137 .83859 L .53131 .83861 L F
.52902 .84132 m .53275 .83823 L .53137 .83859 L F
0 0 .373 r
.53432 .8363 m .53337 .83489 L .53556 .83462 L F
.802 .581 .603 r
.53731 .83515 m .53559 .83738 L .53556 .83462 L F
0 0 .403 r
.53556 .83462 m .53559 .83738 L .53649 .83616 L F
.53556 .83462 m .53649 .83616 L .53432 .8363 L F
.8 .714 .769 r
.53877 .83747 m .53669 .84008 L .53559 .83738 L F
.597 .415 .606 r
.53917 .8397 m .53669 .84008 L .53877 .83747 L F
.66 .306 .361 r
.53559 .83738 m .53442 .83923 L .53842 .83817 L F
.335 .775 .965 r
.53432 .8363 m .53649 .83616 L .53324 .83587 L F
.743 .381 .366 r
.53649 .83616 m .53551 .83781 L .53493 .83732 L F
.53481 .83601 m .53493 .83732 L .53324 .83587 L F
.53649 .83616 m .53493 .83732 L .53481 .83601 L F
.467 .878 .944 r
.53511 .83747 m .53332 .83812 L .53324 .83587 L F
.53332 .83812 m .53288 .83661 L .53324 .83587 L F
.641 .548 .735 r
.53459 .84073 m .53239 .8429 L .53248 .84076 L F
.949 .679 .491 r
.533 .83703 m .53399 .84104 L .53407 .84071 L F
.467 .878 .944 r
.5351 .83748 m .53223 .83803 L .5332 .83811 L F
.743 .381 .366 r
.53511 .83747 m .53484 .8375 L .53324 .83587 L F
.467 .878 .944 r
.5352 .83744 m .53495 .83749 L .5351 .83748 L F
.53495 .83749 m .53223 .83803 L .5351 .83748 L F
.743 .381 .366 r
.53551 .83781 m .53537 .83804 L .53484 .8375 L F
.53551 .83781 m .53484 .8375 L .53511 .83747 L F
.467 .878 .944 r
.53355 .83802 m .5332 .83811 L .53327 .83812 L F
.5352 .83744 m .5332 .83811 L .53355 .83802 L F
.53342 .83808 m .53327 .83812 L .53332 .83812 L F
.5352 .83744 m .53327 .83812 L .53342 .83808 L F
.53326 .83812 m .532 .83808 L .5332 .83813 L F
.53326 .83812 m .5332 .83813 L .53328 .83814 L F
.699 .54 .668 r
.53327 .83812 m .53232 .84188 L .53399 .84104 L F
.53284 .83821 m .53232 .84188 L .53327 .83812 L F
.467 .878 .944 r
.53223 .83803 m .532 .83808 L .53332 .83812 L F
.532 .83808 m .52988 .8385 L .53328 .83814 L F
.936 .688 .537 r
.53379 .83816 m .53422 .83889 L .53423 .83818 L F
.62 .287 .384 r
.53495 .83749 m .53461 .83789 L .52988 .8385 L F
.5352 .83744 m .53497 .8377 L .53495 .83749 L F
.53497 .8377 m .53212 .84083 L .53495 .83749 L F
.467 .878 .944 r
.5352 .83744 m .53511 .83747 L .53324 .83587 L F
.696 .399 .469 r
.53324 .83587 m .53496 .83762 L .5352 .83744 L F
.53496 .83762 m .53537 .83804 L .5352 .83744 L F
.62 .287 .384 r
.53461 .83789 m .53212 .84083 L .53153 .84022 L F
.53461 .83789 m .53153 .84022 L .52988 .8385 L F
.699 .54 .668 r
.53292 .83671 m .53291 .8368 L .533 .83703 L F
.467 .878 .944 r
.533 .83703 m .53291 .8368 L .53296 .83686 L F
.643 .477 .643 r
.3899 .86656 m .3922 .86645 L .39207 .86393 L F
.642 .47 .635 r
.3922 .86645 m .39457 .86378 L .39207 .86393 L F
.537 .849 .998 r
.4137 .88989 m .41698 .88991 L .41592 .88924 L F
.873 .896 .847 r
.41698 .88991 m .41808 .88694 L .41592 .88924 L F
.99 .797 .55 r
.56434 .80539 m .56428 .80841 L .56548 .80659 L F
.4 0 .16 r
.56548 .80659 m .56625 .80775 L .56703 .80628 L F
.56548 .80659 m .56428 .80841 L .56625 .80775 L F
.172 0 .309 r
.61309 .8141 m .61551 .81151 L .61468 .81325 L F
.163 .042 .457 r
.61302 .81632 m .61309 .8141 L .61468 .81325 L F
.703 .219 .097 r
.58443 .78052 m .58318 .78134 L .58117 .77967 L F
.617 .262 .346 r
.5863 .77954 m .58318 .78134 L .58443 .78052 L F
.64 .166 .112 r
.35952 .7519 m .35783 .75289 L .35601 .75164 L F
.556 .138 .205 r
.3615 .75153 m .35783 .75289 L .35952 .7519 L F
.47 .62 .915 r
.6902 .71402 m .69101 .71185 L .68865 .71223 L F
.6902 .71402 m .69232 .71406 L .69101 .71185 L F
.67 .862 .972 r
.48179 .84425 m .47957 .84513 L .48315 .84576 L F
.858 .719 .708 r
.47957 .84513 m .48094 .84802 L .48315 .84576 L F
.665 .407 .52 r
.48315 .84576 m .48094 .84802 L .48343 .84777 L F
.75 .74 .843 r
.64281 .76335 m .63982 .76321 L .64193 .76101 L F
.809 .768 .814 r
.64511 .76107 m .64281 .76335 L .64193 .76101 L F
.779 .645 .714 r
.67954 .72729 m .68119 .73043 L .67991 .72963 L F
.971 .678 .411 r
.68117 .73241 m .67991 .72963 L .68119 .73043 L F
.542 .367 .593 r
.61623 .76378 m .61337 .7666 L .61292 .76366 L F
.209 .344 .783 r
.50751 .84259 m .5097 .84675 L .50979 .84468 L F
.513 .308 .539 r
.5097 .84675 m .51081 .84827 L .50979 .84468 L F
.5097 .84675 m .50877 .84884 L .51081 .84827 L F
.372 .819 .945 r
.35016 .72778 m .35357 .72765 L .35147 .72746 L F
.622 .411 .576 r
.39832 .85591 m .40053 .8556 L .40072 .85357 L F
.694 .529 .659 r
.40053 .8556 m .40357 .85351 L .40072 .85357 L F
.426 .87 .853 r
.48486 .88385 m .487 .88328 L .48563 .88418 L F
.106 0 0 r
.48563 .88418 m .487 .88328 L .48822 .883 L F
.953 .915 .738 r
.49082 .87242 m .49123 .8694 L .48986 .87221 L F
.961 .774 .606 r
.48749 .87363 m .48887 .87464 L .48888 .87338 L F
.48887 .87464 m .48944 .87506 L .48922 .87441 L F
.48887 .87464 m .48922 .87441 L .48888 .87338 L F
.955 .939 .727 r
.48937 .87432 m .49082 .87242 L .48986 .87221 L F
.48917 .87519 m .48988 .874 L .48937 .87432 L F
.48988 .874 m .49082 .87242 L .48937 .87432 L F
.811 .956 .91 r
.50053 .87395 m .49891 .87539 L .49743 .87516 L F
.972 .711 .478 r
.55527 .78535 m .55409 .78481 L .5541 .78242 L F
.827 .915 .897 r
.55527 .78535 m .55738 .78266 L .5541 .78242 L F
.55527 .78535 m .55679 .78273 L .55738 .78266 L F
.55527 .78535 m .55409 .78481 L .55679 .78273 L F
.12 0 0 r
.51128 .87534 m .50941 .87542 L .50797 .87589 L F
.647 .523 .698 r
.41629 .83761 m .41426 .84032 L .4166 .84002 L F
.648 .5 .669 r
.4144 .84285 m .4166 .84002 L .41426 .84032 L F
.801 .786 .839 r
.64511 .76107 m .64193 .76101 L .64425 .75855 L F
.787 .779 .846 r
.64784 .75839 m .64511 .76107 L .64425 .75855 L F
.796 .618 .66 r
.59518 .77762 m .59194 .77959 L .59171 .77724 L F
.59518 .77762 m .59499 .77989 L .59194 .77959 L F
.851 .936 .88 r
.4763 .84974 m .47883 .84906 L .47758 .84764 L F
.65 .791 .95 r
.47758 .84764 m .47883 .84906 L .48094 .84802 L F
0 .549 .77 r
.5733 .8474 m .57468 .84767 L .57652 .84789 L F
.402 .031 .214 r
.36531 .78259 m .36721 .78231 L .36845 .78022 L F
.442 .119 .321 r
.36721 .78231 m .37018 .77956 L .36845 .78022 L F
.651 .528 .701 r
.39631 .85858 m .39832 .85591 L .39607 .85635 L F
.39631 .85858 m .39938 .85903 L .39832 .85591 L F
.671 .517 .668 r
.39631 .85858 m .39933 .86112 L .39938 .85903 L F
.39631 .85858 m .39728 .86146 L .39933 .86112 L F
0 0 .278 r
.56432 .84048 m .5649 .84191 L .56451 .83959 L F
.56432 .84048 m .56487 .84268 L .5649 .84191 L F
.452 .14 .345 r
.40582 .76706 m .40335 .76899 L .40363 .76707 L F
.781 .735 .811 r
.6343 .72177 m .63713 .72237 L .63637 .71983 L F
.775 .368 .281 r
.6343 .72177 m .63599 .72386 L .63713 .72237 L F
.583 .507 .735 r
.63713 .72237 m .63872 .71918 L .63637 .71983 L F
.63713 .72237 m .63931 .72199 L .63872 .71918 L F
.394 0 .08 r
.63599 .72386 m .63931 .72199 L .63713 .72237 L F
.551 .347 .557 r
.39052 .75646 m .39037 .75897 L .39248 .75843 L F
.937 .819 .702 r
.67243 .74104 m .67136 .74117 L .6721 .73973 L F
.67243 .74104 m .67185 .74344 L .67136 .74117 L F
.482 .07 .182 r
.49137 .81984 m .4935 .82039 L .49478 .8187 L F
.513 .073 .139 r
.4935 .82039 m .49658 .81921 L .49478 .8187 L F
.532 .583 .851 r
.44997 .85986 m .44902 .8621 L .44771 .86014 L F
.44997 .85986 m .45093 .86205 L .44902 .8621 L F
.629 .611 .813 r
.50732 .82801 m .50943 .82782 L .50985 .82565 L F
.854 .404 .012 r
.67436 .73423 m .67454 .7333 L .67389 .73212 L F
.67436 .73423 m .67533 .7349 L .67454 .7333 L F
.523 .784 .992 r
.66772 .75302 m .66612 .75362 L .66487 .75146 L F
.544 .396 .631 r
.41107 .74072 m .41143 .74319 L .40954 .74354 L F
.548 .445 .689 r
.41143 .74319 m .40993 .74568 L .40954 .74354 L F
.641 .548 .735 r
.53459 .84073 m .53484 .84313 L .53239 .8429 L F
.574 .335 .516 r
.53239 .8429 m .53449 .84471 L .53248 .84503 L F
.631 .318 .423 r
.53484 .84313 m .53449 .84471 L .53239 .8429 L F
.761 .704 .799 r
.61963 .77998 m .61644 .77975 L .61865 .77731 L F
.784 .716 .788 r
.62185 .77743 m .61963 .77998 L .61865 .77731 L F
.475 .195 .408 r
.37478 .77456 m .37677 .7742 L .37747 .77172 L F
.465 .186 .405 r
.37747 .77172 m .37866 .77378 L .37952 .77138 L F
.37747 .77172 m .37677 .7742 L .37866 .77378 L F
.933 .572 .307 r
.55307 .80825 m .55199 .80792 L .55137 .80599 L F
.753 .255 0 r
.55307 .80825 m .55397 .81008 L .55199 .80792 L F
.55307 .80825 m .55498 .81075 L .55397 .81008 L F
.744 .306 .211 r
.5225 .82437 m .52628 .82559 L .52253 .82692 L F
0 0 .406 r
.47773 .85184 m .47678 .85297 L .47681 .85086 L F
.47773 .85184 m .4763 .84974 L .47638 .85147 L F
.535 .709 .951 r
.47848 .85094 m .47773 .85184 L .47638 .85147 L F
.47897 .85082 m .47773 .85184 L .47848 .85094 L F
0 0 .406 r
.47773 .85184 m .47678 .85301 L .47678 .85297 L F
.643 .466 .628 r
.38768 .86916 m .38997 .86896 L .3899 .86656 L F
.611 .421 .6 r
.38997 .86896 m .3922 .86645 L .3899 .86656 L F
.968 .72 .508 r
.53344 .82446 m .53334 .82727 L .53436 .82725 L F
.732 .656 .774 r
.53344 .82446 m .53647 .8246 L .53532 .82168 L F
.653 .582 .762 r
.53344 .82446 m .5351 .82443 L .53647 .8246 L F
.53344 .82446 m .53436 .82725 L .5351 .82443 L F
.244 .759 .824 r
.53436 .82725 m .53567 .82682 L .5351 .82443 L F
.53436 .82725 m .53334 .82727 L .53567 .82682 L F
.799 .414 .327 r
.43875 .82924 m .44069 .83169 L .44202 .83029 L F
.539 .105 .165 r
.44069 .83169 m .44388 .83061 L .44202 .83029 L F
.461 .197 .426 r
.52742 .87405 m .52575 .87395 L .5268 .87563 L F
.681 .14 0 r
.37526 .7503 m .37399 .7503 L .37192 .74857 L F
.433 .872 .891 r
.37609 .74958 m .37526 .7503 L .37699 .74984 L F
.37609 .74958 m .37399 .7503 L .37526 .7503 L F
.46 .196 .426 r
.38957 .77733 m .38907 .77944 L .38709 .77977 L F
.504 .247 .458 r
.39155 .77695 m .38907 .77944 L .38957 .77733 L F
.758 .93 .944 r
.64818 .76825 m .64776 .7699 L .64938 .76857 L F
.831 .986 .873 r
.64571 .77048 m .64776 .7699 L .64818 .76825 L F
.548 .359 .577 r
.58632 .77742 m .58851 .77929 L .5863 .77954 L F
.649 .332 .422 r
.5886 .77768 m .58851 .77929 L .58632 .77742 L F
.57 .155 .215 r
.33228 .66822 m .33563 .66732 L .33264 .66616 L F
.73 .61 .723 r
.44678 .86397 m .44463 .86665 L .4434 .86349 L F
.709 .578 .706 r
.4467 .8662 m .44463 .86665 L .44678 .86397 L F
0 .557 .799 r
.46952 .88296 m .47262 .88352 L .47159 .88293 L F
.235 .681 .955 r
.47262 .88352 m .47452 .88319 L .47159 .88293 L F
.47262 .88352 m .47544 .88379 L .47452 .88319 L F
.556 .378 .595 r
.61337 .7666 m .61414 .7693 L .61158 .76931 L F
.542 .367 .593 r
.61623 .76378 m .61534 .76713 L .61337 .7666 L F
.603 .441 .635 r
.61534 .76713 m .61414 .7693 L .61337 .7666 L F
.185 0 0 r
.5541 .78242 m .55679 .78273 L .55738 .78266 L F
.6 .948 .809 r
.5584 .78155 m .55679 .78273 L .55738 .78266 L F
.5584 .78155 m .55679 .78273 L .55738 .78266 L F
.592 .406 .599 r
.41775 .75636 m .41776 .75898 L .41545 .75915 L F
.54 .365 .592 r
.41971 .7585 m .41775 .75636 L .41982 .75605 L F
.41971 .7585 m .41776 .75898 L .41775 .75636 L F
.794 .745 .808 r
.67136 .74117 m .67185 .74344 L .66926 .74273 L F
.896 .972 .82 r
.67185 .74344 m .67038 .74357 L .66926 .74273 L F
.65 .528 .702 r
.44957 .86706 m .4467 .8662 L .44983 .86637 L F
.44957 .86706 m .44756 .86983 L .4467 .8662 L F
.542 .203 .343 r
.46553 .82943 m .46767 .8294 L .46876 .82709 L F
.587 .25 .366 r
.46876 .82709 m .47078 .8283 L .4709 .82695 L F
.46876 .82709 m .46767 .8294 L .47078 .8283 L F
.718 .965 .939 r
.62409 .79458 m .62361 .79586 L .62473 .79488 L F
.674 .763 .277 r
.62273 .79806 m .62361 .79586 L .62409 .79458 L F
.02 0 .102 r
.62361 .79586 m .62559 .79341 L .62473 .79488 L F
.793 .935 .924 r
.51733 .82252 m .51385 .824 L .5158 .82162 L F
.889 .958 .838 r
.47072 .85917 m .46827 .86053 L .46917 .85828 L F
.65 .347 .444 r
.60798 .77643 m .60494 .77522 L .60653 .7745 L F
.60798 .77643 m .60459 .77689 L .60494 .77522 L F
.914 .916 .525 r
.62592 .79124 m .62559 .79341 L .6266 .79031 L F
.933 .945 .607 r
.62473 .79488 m .62559 .79341 L .62592 .79124 L F
.616 .609 .821 r
.44463 .86665 m .44151 .86438 L .4434 .86349 L F
.604 .864 .992 r
.40843 .73856 m .40534 .73867 L .40726 .738 L F
.464 .833 .992 r
.40932 .73774 m .40843 .73856 L .40726 .738 L F
.40932 .73774 m .41051 .73816 L .40843 .73856 L F
.57 .155 .215 r
.33228 .66822 m .33531 .66799 L .33563 .66732 L F
.975 .837 .432 r
.33563 .66732 m .33531 .66556 L .33629 .6656 L F
.33563 .66732 m .33531 .66799 L .33531 .66556 L F
.638 .643 .839 r
.33629 .6656 m .338 .66727 L .33563 .66732 L F
.575 .212 .317 r
.338 .66727 m .33658 .66856 L .33563 .66732 L F
.119 .584 .918 r
.33821 .66574 m .33967 .66662 L .33629 .6656 L F
.799 .814 .864 r
.33806 .66586 m .33967 .66662 L .33821 .66574 L F
.231 .141 .543 r
.33651 .66848 m .33566 .66982 L .33563 .66732 L F
.557 .624 .874 r
.33629 .6656 m .33967 .66662 L .338 .66727 L F
.799 .814 .864 r
.33518 .66812 m .3371 .66748 L .33806 .66586 L F
.3371 .66748 m .33967 .66662 L .33806 .66586 L F
.231 .141 .543 r
.33658 .66856 m .33598 .66939 L .33651 .66848 L F
.33598 .66939 m .33566 .66982 L .33651 .66848 L F
.483 .564 .861 r
.45892 .88251 m .45693 .88468 L .46069 .88266 L F
.45892 .88251 m .45939 .88489 L .45693 .88468 L F
.197 .663 .94 r
.45693 .88468 m .45939 .88489 L .45529 .88401 L F
.12 .274 .748 r
.59772 .81912 m .59874 .82199 L .59611 .82222 L F
.381 .055 .283 r
.45239 .86569 m .44983 .86637 L .45265 .86525 L F
.41 .113 .347 r
.44957 .86706 m .44983 .86637 L .45239 .86569 L F
.686 .617 .773 r
.44294 .82393 m .44663 .82519 L .44605 .8229 L F
.729 .552 .651 r
.44294 .82393 m .44163 .82517 L .44663 .82519 L F
.551 .53 .784 r
.44837 .82444 m .44663 .82519 L .44605 .8229 L F
.44837 .82444 m .44663 .82519 L .44605 .8229 L F
0 .023 .553 r
.67128 .72707 m .67227 .72937 L .6715 .73029 L F
0 .172 .656 r
.67318 .73137 m .67389 .73212 L .6715 .73029 L F
.722 .285 .21 r
.42184 .88717 m .42458 .8874 L .42337 .88801 L F
.425 0 .074 r
.42458 .8874 m .42536 .88823 L .42337 .88801 L F
.596 .933 .953 r
.70742 .74543 m .7051 .74635 L .70442 .74605 L F
.588 .591 .823 r
.70819 .74841 m .7051 .74635 L .70742 .74543 L F
.577 .304 .466 r
.45804 .83206 m .46113 .82933 L .45833 .83006 L F
.579 .516 .748 r
.64717 .73061 m .64789 .72646 L .64621 .72696 L F
.64717 .73061 m .64924 .72993 L .64789 .72646 L F
.676 .473 .603 r
.46051 .85573 m .45886 .85329 L .46048 .85351 L F
.694 .595 .741 r
.46266 .85068 m .46452 .85367 L .46048 .85351 L F
.727 .482 .556 r
.46394 .85575 m .46048 .85351 L .46452 .85367 L F
.46394 .85575 m .46051 .85573 L .46048 .85351 L F
.538 .357 .584 r
.36842 .79301 m .36838 .79769 L .36589 .79764 L F
0 0 .042 r
.36842 .79422 m .36842 .79301 L .37043 .79279 L F
.414 .161 .419 r
.36842 .79422 m .36919 .79719 L .36845 .79738 L F
0 0 .042 r
.36842 .79422 m .36838 .79769 L .36841 .7931 L F
.414 .161 .419 r
.36842 .79422 m .3674 .79765 L .36838 .79769 L F
.36842 .79422 m .36845 .79738 L .3674 .79765 L F
0 0 .042 r
.36842 .79422 m .36841 .7931 L .36842 .79301 L F
.101 0 .329 r
.347 .7551 m .34644 .75511 L .34858 .75406 L F
0 0 0 r
.3457 .75592 m .34688 .75524 L .34495 .75692 L F
.744 .704 .813 r
.34495 .75692 m .34688 .75524 L .34682 .75524 L F
.101 0 .329 r
.34699 .7551 m .3457 .75592 L .34644 .75511 L F
.34695 .75513 m .3457 .75592 L .34699 .7551 L F
.347 .7551 m .34688 .75524 L .3457 .75592 L F
.744 .704 .813 r
.34489 .75681 m .34682 .75524 L .34382 .75499 L F
.34495 .75692 m .34682 .75524 L .34489 .75681 L F
.101 0 .329 r
.347 .7551 m .34695 .75513 L .34699 .7551 L F
.767 .427 0 r
.53532 .82168 m .53647 .8246 L .53612 .824 L F
.358 .244 .585 r
.5351 .82443 m .53612 .824 L .53647 .8246 L F
.497 .284 .52 r
.37044 .77741 m .37018 .77956 L .37237 .77701 L F
.638 .629 .825 r
.68229 .70589 m .68307 .70727 L .68512 .70672 L F
.859 .996 .806 r
.48333 .85072 m .48326 .85176 L .48178 .85292 L F
.994 .806 .435 r
.46854 .86855 m .46899 .87005 L .4691 .86644 L F
.265 .048 .386 r
.4691 .86644 m .47082 .86387 L .47104 .86439 L F
.372 .117 .393 r
.47104 .86439 m .46854 .86855 L .4691 .86644 L F
.147 .589 .93 r
.66766 .74811 m .66812 .74777 L .6692 .74574 L F
.66778 .74815 m .66958 .7487 L .66812 .74777 L F
.7 .51 .627 r
.66864 .75015 m .6667 .75046 L .66812 .74777 L F
0 0 0 r
.66847 .74738 m .66812 .74777 L .6676 .74903 L F
.66852 .74728 m .66812 .74777 L .66847 .74738 L F
.147 .589 .93 r
.66766 .74811 m .66778 .74815 L .66812 .74777 L F
.576 .424 .638 r
.61414 .7693 m .61209 .77265 L .61158 .76931 L F
.831 .645 .65 r
.4771 .86366 m .48044 .86745 L .4807 .86499 L F
.47984 .86348 m .4807 .86499 L .48086 .86342 L F
.4771 .86366 m .4807 .86499 L .47984 .86348 L F
.754 .267 .078 r
.47895 .86191 m .47882 .86149 L .47837 .86082 L F
.831 .645 .65 r
.4771 .86366 m .47984 .86348 L .47991 .86371 L F
.47984 .86348 m .48086 .86342 L .47991 .86371 L F
.754 .267 .078 r
.47991 .86371 m .47953 .86293 L .47895 .86191 L F
.47953 .86293 m .47882 .86149 L .47895 .86191 L F
.47991 .86371 m .48086 .86342 L .47882 .86149 L F
.639 .515 .696 r
.37517 .87964 m .37307 .87705 L .37361 .87966 L F
.37517 .87964 m .37595 .87725 L .37307 .87705 L F
.794 .615 .659 r
.64151 .71907 m .64506 .72027 L .64384 .71659 L F
.458 .277 .547 r
.64506 .72027 m .64683 .71707 L .64384 .71659 L F
0 .518 .728 r
.47678 .85301 m .47932 .85332 L .47992 .85344 L F
.535 .709 .951 r
.47897 .85082 m .48126 .85292 L .47773 .85184 L F
.817 .493 .441 r
.47967 .85339 m .48178 .85292 L .47992 .85344 L F
.47932 .85332 m .48062 .85311 L .47967 .85339 L F
.48062 .85311 m .48178 .85292 L .47967 .85339 L F
.47932 .85332 m .48089 .85515 L .48097 .85494 L F
.47932 .85332 m .48097 .85494 L .48178 .85292 L F
.775 .506 .528 r
.47788 .85189 m .47932 .85332 L .47773 .85184 L F
.48159 .85322 m .47932 .85332 L .47788 .85189 L F
.535 .709 .951 r
.48126 .85292 m .48159 .85322 L .48097 .853 L F
.48126 .85292 m .48097 .853 L .47773 .85184 L F
.612 .389 .554 r
.42813 .82989 m .43043 .83181 L .43116 .82939 L F
.42813 .82989 m .42803 .83203 L .43043 .83181 L F
.338 .158 .484 r
.61014 .82212 m .61176 .81931 L .61122 .82132 L F
.18 .012 .403 r
.60982 .8243 m .61014 .82212 L .61122 .82132 L F
.556 .572 .825 r
.38528 .72743 m .38472 .73041 L .38382 .72714 L F
.38528 .72743 m .38659 .72999 L .38472 .73041 L F
.07 0 .376 r
.5753 .821 m .57371 .82223 L .57479 .81864 L F
.52 .358 .602 r
.62573 .73279 m .62798 .73241 L .62765 .73005 L F
.173 0 .31 r
.6261 .73496 m .62798 .73241 L .62573 .73279 L F
.665 .236 .217 r
.43304 .89503 m .43631 .89505 L .43415 .8939 L F
.579 .595 .833 r
.38924 .73009 m .38801 .73291 L .38659 .72999 L F
.38924 .73009 m .39006 .73258 L .38801 .73291 L F
.773 .571 .626 r
.52132 .82151 m .52459 .82178 L .52424 .81941 L F
.52132 .82151 m .52424 .81941 L .52347 .82037 L F
.158 .249 .709 r
.52424 .81941 m .5256 .8202 L .5252 .8187 L F
.665 .496 .646 r
.52424 .81941 m .52675 .82206 L .52459 .82178 L F
0 0 0 r
.5252 .8187 m .52347 .82037 L .52424 .81941 L F
.325 0 .062 r
.47528 .82655 m .47856 .82454 L .47635 .82469 L F
.692 .536 .67 r
.3739 .88195 m .37517 .87964 L .37361 .87966 L F
.529 .259 .449 r
.38687 .76458 m .38831 .7662 L .38844 .76406 L F
.38687 .76458 m .38627 .76652 L .38831 .7662 L F
.677 .416 .52 r
.50237 .81871 m .504 .81916 L .502 .8167 L F
.696 .417 .497 r
.502 .8167 m .504 .81916 L .50411 .81705 L F
.68 .551 .702 r
.40776 .84831 m .40571 .85089 L .40805 .85065 L F
.647 .477 .64 r
.40579 .8533 m .40805 .85065 L .40571 .85089 L F
.588 .373 .557 r
.50982 .84032 m .50971 .8426 L .50751 .84259 L F
.50982 .84032 m .50971 .8426 L .50751 .84259 L F
.573 .581 .823 r
.51211 .85081 m .51299 .84768 L .51081 .84827 L F
.51211 .85081 m .51428 .85057 L .51299 .84768 L F
.943 .68 .51 r
.59966 .81408 m .59978 .81644 L .59842 .81569 L F
.732 .763 .26 r
.6006 .81073 m .59966 .81408 L .59934 .81376 L F
.907 .941 .58 r
.59934 .81376 m .59966 .81408 L .59842 .81569 L F
.943 .68 .51 r
.59966 .81408 m .59978 .81644 L .59842 .81569 L F
.794 .65 .703 r
.6205 .77447 m .62185 .77743 L .61865 .77731 L F
.731 .623 .739 r
.62395 .77483 m .62185 .77743 L .6205 .77447 L F
.412 .846 .716 r
.48635 .85281 m .48547 .85343 L .48713 .8525 L F
.939 .684 .526 r
.48393 .85515 m .4854 .85584 L .48547 .85343 L F
.48393 .85515 m .48547 .85343 L .48635 .85281 L F
.976 .847 .65 r
.70663 .71868 m .70715 .71715 L .70607 .71663 L F
.278 .755 .933 r
.51428 .85057 m .51748 .85079 L .51788 .85062 L F
.657 .481 .635 r
.51551 .85473 m .51748 .85079 L .51428 .85057 L F
0 0 0 r
.51788 .85062 m .51748 .85079 L .51909 .85001 L F
.717 .577 .697 r
.37595 .87725 m .37823 .8768 L .37802 .87456 L F
.691 .602 .752 r
.37823 .8768 m .3802 .87423 L .37802 .87456 L F
.399 .839 .941 r
.38911 .74563 m .3881 .74634 L .39022 .7463 L F
.38911 .74563 m .38692 .74616 L .3881 .74634 L F
.869 .952 .862 r
.65639 .75124 m .65546 .75391 L .65449 .75301 L F
.65639 .75124 m .65718 .75168 L .65546 .75391 L F
.676 .145 0 r
.65546 .75391 m .65551 .75476 L .65449 .75301 L F
.497 .317 .567 r
.65546 .75391 m .65512 .75638 L .65713 .75575 L F
.676 .145 0 r
.65546 .75391 m .65713 .75575 L .65551 .75476 L F
.71 .656 .794 r
.53518 .81601 m .53747 .81675 L .53583 .81452 L F
.55 .215 .354 r
.57867 .77144 m .58083 .77139 L .58177 .76912 L F
.657 .327 .403 r
.58177 .76912 m .5841 .77112 L .58404 .76914 L F
.58177 .76912 m .58083 .77139 L .5841 .77112 L F
.097 0 .223 r
.63137 .73641 m .63086 .73939 L .62894 .74025 L F
.257 0 .276 r
.63323 .73687 m .63086 .73939 L .63137 .73641 L F
.568 .241 .375 r
.60959 .75052 m .61189 .7505 L .61272 .74814 L F
.364 .463 .828 r
.61171 .74574 m .61272 .74814 L .61383 .74724 L F
.548 .222 .367 r
.61272 .74814 m .61397 .7499 L .61383 .74724 L F
.61272 .74814 m .61189 .7505 L .61397 .7499 L F
.318 .447 .834 r
.57609 .83455 m .57432 .83483 L .57318 .83221 L F
.319 .481 .863 r
.57609 .83455 m .5758 .83551 L .57432 .83483 L F
.914 .92 .805 r
.62845 .78753 m .62886 .78539 L .62719 .78719 L F
.773 .934 .578 r
.62654 .79003 m .62845 .78753 L .62719 .78719 L F
.62654 .79003 m .6266 .79031 L .62845 .78753 L F
.494 .655 .931 r
.44572 .82237 m .44605 .8229 L .44296 .82196 L F
.44296 .82196 m .44605 .8229 L .44572 .82237 L F
.669 .488 .632 r
.61445 .74104 m .61476 .74106 L .61595 .73816 L F
.635 .565 .758 r
.61475 .73487 m .61595 .73816 L .61697 .73687 L F
.602 .386 .561 r
.51389 .8325 m .51616 .83434 L .51615 .83234 L F
.51389 .8325 m .51368 .83484 L .51616 .83434 L F
.539 .306 .51 r
.41545 .75915 m .41523 .76127 L .41315 .7616 L F
.555 .308 .496 r
.41776 .75898 m .41523 .76127 L .41545 .75915 L F
.363 0 .129 r
.37976 .74877 m .37699 .74984 L .37774 .74906 L F
.983 .711 .428 r
.67203 .7201 m .67164 .72176 L .67266 .72246 L F
.851 .937 .88 r
.62886 .78539 m .63104 .7845 L .63018 .78402 L F
.88 .988 .725 r
.63104 .7845 m .63238 .78162 L .63018 .78402 L F
.68 .537 .684 r
.45312 .85567 m .44986 .85348 L .45181 .85319 L F
.548 .445 .689 r
.41143 .74319 m .41188 .74532 L .40993 .74568 L F
.577 .468 .694 r
.41248 .74841 m .40993 .74568 L .41188 .74532 L F
.41248 .74841 m .41046 .74879 L .40993 .74568 L F
.744 .306 .211 r
.5225 .82437 m .52474 .8268 L .52628 .82559 L F
.1 0 0 r
.52628 .82559 m .52474 .8268 L .52667 .82612 L F
.073 0 0 r
.51928 .82667 m .51766 .82694 L .52027 .82722 L F
.51928 .82667 m .51743 .82749 L .51766 .82694 L F
.448 .259 .53 r
.57093 .83262 m .57327 .82971 L .57318 .83221 L F
.762 .593 .667 r
.56097 .79813 m .56317 .79836 L .56293 .79564 L F
.746 .782 .882 r
.66301 .72137 m .6613 .7201 L .66047 .72052 L F
.6613 .7201 m .65991 .71907 L .66047 .72052 L F
.6613 .7201 m .66247 .71863 L .65991 .71907 L F
.66301 .72137 m .66157 .72 L .6613 .7201 L F
.811 .521 .498 r
.66157 .72 m .66301 .72137 L .66047 .72052 L F
.66409 .71881 m .66301 .72137 L .66157 .72 L F
.746 .782 .882 r
.66301 .72137 m .66266 .71961 L .66157 .72 L F
.811 .521 .498 r
.66273 .71937 m .6613 .7201 L .66099 .72008 L F
.66409 .71881 m .66047 .72052 L .66273 .71937 L F
.746 .782 .882 r
.66266 .71961 m .66247 .71863 L .6613 .7201 L F
.811 .521 .498 r
.6613 .7201 m .66047 .72052 L .66073 .7203 L F
.6613 .7201 m .66073 .7203 L .66099 .72008 L F
.709 .388 .432 r
.66602 .71988 m .66301 .72137 L .66409 .71881 L F
.501 .47 .754 r
.70912 .74722 m .70819 .74841 L .70742 .74543 L F
.326 .132 .457 r
.70912 .74722 m .70749 .75026 L .70819 .74841 L F
.733 .608 .718 r
.3824 .87166 m .38556 .8718 L .38449 .86893 L F
.729 .538 .633 r
.38227 .87382 m .38556 .8718 L .3824 .87166 L F
.38227 .87382 m .38564 .87422 L .38556 .8718 L F
.719 .601 .724 r
.38556 .8718 m .38768 .86916 L .38449 .86893 L F
.629 .471 .65 r
.38556 .8718 m .38778 .87163 L .38768 .86916 L F
.617 .413 .583 r
.38767 .87397 m .38556 .8718 L .38564 .87422 L F
.38767 .87397 m .38778 .87163 L .38556 .8718 L F
.471 .506 .812 r
.67136 .71709 m .66957 .71464 L .67174 .716 L F
.329 .42 .803 r
.67174 .716 m .67233 .71603 L .67136 .71709 L F
.12 .612 .91 r
.67097 .71533 m .67233 .71603 L .67174 .716 L F
.971 .686 .28 r
.67097 .71533 m .67145 .71675 L .67233 .71603 L F
.577 .887 .605 r
.67136 .71709 m .67233 .71603 L .67319 .71532 L F
.398 .527 .87 r
.67136 .71709 m .6742 .71801 L .67233 .71603 L F
0 0 .331 r
.67191 .71809 m .67136 .71709 L .67233 .71603 L F
.971 .686 .28 r
.67145 .71675 m .67191 .71809 L .67233 .71603 L F
.577 .887 .605 r
.67319 .71532 m .67233 .71603 L .6738 .71473 L F
0 0 .331 r
.67191 .71809 m .67203 .7201 L .67136 .71709 L F
.604 .464 .664 r
.62433 .74906 m .62134 .75108 L .62316 .74769 L F
.524 .357 .597 r
.62372 .7532 m .62134 .75108 L .62433 .74906 L F
.62372 .7532 m .6218 .75449 L .62134 .75108 L F
.314 0 0 r
.34 .72969 m .34253 .72909 L .3407 .72912 L F
.487 .189 .385 r
.3532 .78913 m .35552 .78776 L .35353 .78786 L F
.458 .277 .547 r
.64506 .72027 m .6468 .71927 L .64683 .71707 L F
.517 .324 .557 r
.64683 .71707 m .64892 .71662 L .6468 .71927 L F
.64683 .71707 m .64892 .71662 L .6468 .71927 L F
.449 .461 .78 r
.40017 .75105 m .40084 .7478 L .39927 .74807 L F
.40017 .75105 m .40193 .75098 L .40084 .7478 L F
.522 .444 .709 r
.4006 .75376 m .40193 .75098 L .40017 .75105 L F
.751 .962 .668 r
.55236 .84618 m .55052 .84839 L .55083 .84739 L F
.902 .63 .516 r
.55052 .84839 m .54854 .84991 L .55083 .84739 L F
.55052 .84839 m .55032 .84976 L .54854 .84991 L F
.442 .816 .565 r
.64382 .72122 m .64242 .72233 L .64506 .72027 L F
.231 .199 .615 r
.64382 .72122 m .643 .72491 L .64242 .72233 L F
.744 .489 .545 r
.46747 .85597 m .46609 .85871 L .46394 .85575 L F
.685 .419 .514 r
.46917 .85828 m .46609 .85871 L .46747 .85597 L F
.672 .469 .602 r
.45886 .85329 m .45829 .85596 L .45511 .85604 L F
.676 .473 .603 r
.46051 .85573 m .45829 .85596 L .45886 .85329 L F
.645 .556 .74 r
.60975 .74664 m .60966 .74914 L .61171 .74574 L F
.139 .608 .924 r
.64945 .75853 m .6506 .75928 L .64784 .75839 L F
.494 .863 .985 r
.64945 .75853 m .65264 .75844 L .6506 .75928 L F
.676 .456 .579 r
.60891 .77374 m .6099 .77459 L .60653 .7745 L F
.606 .467 .667 r
.61209 .77265 m .6099 .77459 L .60891 .77374 L F
.355 .814 .709 r
.4964 .88206 m .49977 .88059 L .49784 .88118 L F
.54 .927 .877 r
.49977 .88059 m .5007 .87976 L .49784 .88118 L F
.49977 .88059 m .50172 .87967 L .5007 .87976 L F
.661 .494 .647 r
.57339 .82753 m .57555 .82939 L .57327 .82971 L F
.286 .445 .845 r
.57404 .82662 m .57555 .82939 L .57339 .82753 L F
.603 .438 .631 r
.61128 .7434 m .61445 .74104 L .61053 .74037 L F
.61128 .7434 m .61376 .74349 L .61445 .74104 L F
.494 .273 .508 r
.61171 .74574 m .61376 .74349 L .61128 .7434 L F
.497 .505 .795 r
.41286 .73951 m .41107 .74072 L .41051 .73816 L F
.508 .419 .691 r
.41286 .73951 m .41143 .74319 L .41107 .74072 L F
0 0 0 r
.66222 .75318 m .66395 .75216 L .66487 .75146 L F
.388 .509 .86 r
.6667 .75046 m .66772 .75302 L .66487 .75146 L F
.6667 .75046 m .66487 .75146 L .66395 .75216 L F
.758 .668 .763 r
.61901 .72919 m .61923 .73259 L .6224 .72987 L F
.61901 .72919 m .6224 .72987 L .62116 .72964 L F
.202 .37 .808 r
.62352 .7289 m .6224 .72987 L .62111 .7271 L F
.501 .89 .957 r
.62116 .72964 m .6224 .72987 L .62352 .7289 L F
.787 .769 .837 r
.45636 .87145 m .45336 .87176 L .45519 .87055 L F
.779 .77 .844 r
.45912 .86952 m .45636 .87145 L .45519 .87055 L F
.653 .502 .666 r
.53119 .81401 m .53254 .81712 L .5293 .81704 L F
.69 .52 .651 r
.53389 .8162 m .53119 .81401 L .53536 .81493 L F
.53389 .8162 m .53254 .81712 L .53119 .81401 L F
.423 .137 .372 r
.36279 .80011 m .36166 .79877 L .3633 .79812 L F
.36279 .80011 m .3609 .80063 L .36166 .79877 L F
.403 .49 .835 r
.64955 .7076 m .6481 .70902 L .64663 .70604 L F
.612 .945 .764 r
.64955 .7076 m .64638 .7099 L .6481 .70902 L F
.151 .035 .456 r
.60665 .83256 m .60754 .8295 L .60765 .83162 L F
0 0 0 r
.60581 .83433 m .60665 .83256 L .60765 .83162 L F
.639 .515 .696 r
.37517 .87964 m .37608 .8795 L .37595 .87725 L F
.632 .466 .641 r
.37393 .88218 m .37517 .87964 L .3739 .88195 L F
.37393 .88218 m .37608 .8795 L .37517 .87964 L F
.623 .457 .637 r
.56967 .79054 m .56721 .79114 L .56825 .78858 L F
.56967 .79054 m .56825 .78858 L .5683 .78959 L F
.49 0 0 r
.56825 .78858 m .5683 .78959 L .56996 .7886 L F
.411 .207 .49 r
.57135 .7897 m .56967 .79054 L .56996 .7886 L F
.603 .108 .051 r
.57135 .7897 m .5683 .78959 L .56996 .7886 L F
.997 .781 .48 r
.68296 .7476 m .68383 .74852 L .68322 .74568 L F
0 0 0 r
.68369 .74981 m .68356 .7507 L .68383 .74852 L F
.68369 .74981 m .68383 .74852 L .68296 .7476 L F
.656 .626 .807 r
.37736 .89707 m .37664 .89495 L .37608 .8953 L F
.37736 .89707 m .37807 .89403 L .37664 .89495 L F
.37736 .89707 m .37945 .89587 L .37807 .89403 L F
0 0 .206 r
.55477 .83955 m .55554 .83732 L .55492 .84033 L F
.935 .583 .328 r
.55492 .84033 m .55569 .84224 L .55477 .83955 L F
.677 .518 .663 r
.37608 .8795 m .37823 .8768 L .37595 .87725 L F
.37608 .8795 m .37881 .87973 L .37823 .8768 L F
.691 .602 .752 r
.37823 .8768 m .38127 .87726 L .3802 .87423 L F
.707 .469 .561 r
.38101 .8794 m .37823 .8768 L .37881 .87973 L F
.38101 .8794 m .38127 .87726 L .37823 .8768 L F
.469 .17 .375 r
.49774 .82161 m .49469 .82355 L .49493 .82195 L F
.886 .632 .549 r
.69789 .74848 m .698 .75076 L .6966 .74802 L F
.757 .528 .586 r
.70132 .75065 m .698 .75076 L .69789 .74848 L F
.784 .383 .293 r
.64151 .71907 m .64382 .72122 L .64506 .72027 L F
.59 .468 .681 r
.32924 .67681 m .33143 .67733 L .32935 .67764 L F
0 .521 .822 r
.32994 .67673 m .32924 .67681 L .32915 .67753 L F
.32994 .67673 m .33143 .67733 L .32924 .67681 L F
.671 .868 .974 r
.55395 .84517 m .55236 .84618 L .55131 .84559 L F
.965 .72 .517 r
.55131 .84559 m .55236 .84618 L .55083 .84739 L F
.52 .204 .371 r
.52232 .8131 m .52436 .8132 L .52503 .81072 L F
.616 .446 .629 r
.52503 .81072 m .52737 .81062 L .52713 .80889 L F
.584 .273 .407 r
.52436 .8132 m .52737 .81062 L .52503 .81072 L F
.42 .224 .507 r
.47333 .86308 m .47104 .86439 L .47082 .86387 L F
.753 .625 .718 r
.5993 .7617 m .60215 .76213 L .60115 .7587 L F
.985 .901 .629 r
.59922 .76254 m .59795 .76316 L .5993 .7617 L F
.718 .331 .314 r
.59795 .76316 m .60215 .76213 L .5993 .7617 L F
.295 .338 .736 r
.60115 .7587 m .60215 .76213 L .60242 .75968 L F
.131 0 0 r
.60215 .76213 m .60387 .76248 L .60242 .75968 L F
0 0 0 r
.34253 .72909 m .3446 .72884 L .34609 .72866 L F
.364 0 0 r
.3446 .72884 m .34814 .72818 L .34609 .72866 L F
.629 .46 .635 r
.38778 .87163 m .38997 .86896 L .38768 .86916 L F
.982 .886 .653 r
.67191 .71809 m .67164 .72176 L .67203 .7201 L F
.755 .79 .881 r
.48629 .82807 m .48484 .82949 L .48827 .82966 L F
.795 .703 .763 r
.48484 .82949 m .48604 .83238 L .48827 .82966 L F
.614 .071 0 r
.49056 .82914 m .48629 .82807 L .48827 .82966 L F
.667 .603 .774 r
.48827 .82966 m .49171 .83069 L .49056 .82914 L F
.666 .663 .838 r
.38841 .8969 m .38992 .89537 L .38681 .89439 L F
.553 .4 .627 r
.44957 .86706 m .44993 .87116 L .44756 .86983 L F
.365 .453 .818 r
.44756 .86983 m .44993 .87116 L .44828 .87078 L F
.693 .237 .166 r
.37192 .74857 m .37399 .7503 L .37075 .74972 L F
.666 .161 .035 r
.37263 .74996 m .37197 .7498 L .37075 .74972 L F
.296 0 0 r
.37192 .74857 m .37075 .74972 L .36939 .74964 L F
.666 .161 .035 r
.37197 .7498 m .36943 .74919 L .37075 .74972 L F
.296 0 0 r
.36939 .74964 m .37075 .74972 L .36864 .74995 L F
.15 0 0 r
.64445 .70648 m .64546 .70705 L .64663 .70604 L F
.64445 .70648 m .64338 .7079 L .64546 .70705 L F
.432 0 0 r
.68212 .7558 m .68215 .75636 L .67949 .75613 L F
.07 0 0 r
.68394 .75536 m .68215 .75636 L .68212 .7558 L F
.564 .303 .479 r
.43116 .82939 m .43239 .83144 L .43333 .82971 L F
.43116 .82939 m .43043 .83181 L .43239 .83144 L F
.785 .705 .776 r
.52976 .82135 m .52675 .82206 L .52875 .81876 L F
.778 .652 .723 r
.52976 .82135 m .52771 .82423 L .52675 .82206 L F
.733 .68 .799 r
.53203 .81901 m .52976 .82135 L .52875 .81876 L F
.492 .151 .316 r
.504 .81916 m .50737 .81656 L .50411 .81705 L F
.716 .646 .778 r
.37945 .89587 m .38058 .89844 L .38259 .89778 L F
.746 .624 .723 r
.53254 .81712 m .52875 .81876 L .5293 .81704 L F
.992 .737 .413 r
.57072 .81033 m .57174 .81143 L .57089 .8085 L F
.207 0 0 r
.68256 .74029 m .68185 .7403 L .68484 .74055 L F
.704 .673 .817 r
.62495 .75635 m .62589 .75908 L .62237 .75881 L F
.661 .378 .481 r
.62589 .75908 m .62268 .76119 L .62237 .75881 L F
.62589 .75908 m .62605 .76117 L .62268 .76119 L F
.796 .721 .782 r
.62794 .7563 m .62589 .75908 L .62495 .75635 L F
.616 .345 .483 r
.62589 .75908 m .62798 .76082 L .62605 .76117 L F
.546 .372 .596 r
.62799 .75861 m .62589 .75908 L .62794 .7563 L F
.543 .362 .586 r
.62799 .75861 m .62798 .76082 L .62589 .75908 L F
.57 .615 .858 r
.4514 .8726 m .44828 .87078 L .44993 .87116 L F
.648 .75 .924 r
.45336 .87176 m .4514 .8726 L .44993 .87116 L F
.413 .725 .989 r
.61831 .74255 m .61695 .74361 L .61602 .743 L F
.61815 .74268 m .61931 .74368 L .61695 .74361 L F
.61845 .74271 m .61931 .74368 L .61815 .74268 L F
.615 .831 .983 r
.62146 .7428 m .61931 .74368 L .61892 .74324 L F
.61971 .74266 m .61892 .74324 L .61831 .74255 L F
.62146 .7428 m .61892 .74324 L .61971 .74266 L F
.782 .651 .718 r
.62146 .7428 m .61831 .74255 L .62003 .74168 L F
.234 .087 .467 r
.62053 .74206 m .61985 .74547 L .6219 .74312 L F
.62003 .74168 m .61999 .74245 L .62053 .74206 L F
.61999 .74245 m .61985 .74547 L .62053 .74206 L F
.632 .409 .561 r
.61727 .74541 m .61985 .74547 L .61997 .74286 L F
.61921 .74278 m .61997 .74286 L .62003 .74168 L F
.61727 .74541 m .61997 .74286 L .61921 .74278 L F
.413 .725 .989 r
.61831 .74255 m .61845 .74271 L .61815 .74268 L F
.404 .383 .722 r
.38315 .91589 m .38194 .91821 L .38067 .91626 L F
.38315 .91589 m .3831 .91677 L .38194 .91821 L F
.694 .486 .6 r
.43864 .82713 m .43875 .82924 L .44063 .82661 L F
.136 0 0 r
.57006 .81944 m .57114 .81955 L .56753 .81905 L F
.794 .985 .896 r
.57166 .81778 m .57114 .81955 L .57006 .81944 L F
.664 .578 .749 r
.62413 .73711 m .62679 .73673 L .6261 .73496 L F
0 0 .216 r
.62413 .73711 m .62511 .73817 L .62679 .73673 L F
.62413 .73711 m .6235 .73989 L .62511 .73817 L F
.893 .834 .781 r
.5146 .83833 m .51453 .83926 L .51391 .83973 L F
.741 .599 .698 r
.51527 .84054 m .51347 .84006 L .51391 .83973 L F
.51527 .84054 m .51042 .84419 L .51247 .83979 L F
.721 .457 .526 r
.51391 .83973 m .51726 .84008 L .51527 .84054 L F
.51391 .83973 m .51745 .84162 L .51726 .84008 L F
.51391 .83973 m .51435 .84174 L .51745 .84162 L F
.893 .834 .781 r
.51453 .83926 m .51435 .84174 L .51391 .83973 L F
.741 .599 .698 r
.51347 .84006 m .51247 .83979 L .51391 .83973 L F
.492 .151 .316 r
.504 .81916 m .50623 .819 L .50737 .81656 L F
.655 .334 .417 r
.50623 .819 m .50954 .81695 L .50737 .81656 L F
.475 .891 .915 r
.56149 .77723 m .56262 .77641 L .56324 .77653 L F
.475 .896 .864 r
.56149 .77723 m .56068 .77726 L .56262 .77641 L F
.759 .651 .743 r
.62696 .76635 m .62809 .76941 L .62483 .76904 L F
.704 .623 .764 r
.62696 .76635 m .63063 .7673 L .62809 .76941 L F
.733 .726 .845 r
.5838 .83201 m .58706 .83231 L .58517 .83335 L F
.118 0 0 r
.37486 .72684 m .37687 .72647 L .37778 .72583 L F
.509 0 0 r
.37778 .72583 m .37687 .72647 L .38032 .72653 L F
.674 .517 .664 r
.41863 .83753 m .42152 .83756 L .42142 .83509 L F
.635 .486 .663 r
.42142 .83509 m .42377 .83733 L .42367 .83495 L F
.42142 .83509 m .42152 .83756 L .42377 .83733 L F
.194 .601 .945 r
.67544 .71895 m .67619 .71841 L .6742 .71801 L F
.629 .514 .704 r
.40776 .84831 m .41024 .85033 L .41001 .84797 L F
.40776 .84831 m .40805 .85065 L .41024 .85033 L F
.319 .364 .752 r
.57575 .82373 m .57371 .82223 L .5753 .821 L F
.557 .087 .093 r
.4137 .88989 m .41094 .89003 L .41277 .8897 L F
.673 .878 .975 r
.50832 .83712 m .51175 .83696 L .51054 .83502 L F
.69 .289 .281 r
.51175 .83696 m .51136 .83822 L .50832 .83712 L F
.608 .606 .823 r
.51054 .83502 m .51175 .83696 L .51339 .83633 L F
.399 .355 .694 r
.51175 .83696 m .51391 .83973 L .51247 .83979 L F
0 0 .48 r
.51264 .83803 m .51175 .83696 L .51136 .83822 L F
.51264 .83803 m .51391 .83973 L .51229 .83766 L F
.27 .443 .849 r
.5146 .83833 m .51391 .83973 L .51264 .83803 L F
.824 .728 .759 r
.51158 .83933 m .51286 .84144 L .5146 .83833 L F
.51158 .83933 m .5146 .83833 L .51418 .83883 L F
.25 0 0 r
.51264 .83803 m .51158 .83933 L .5135 .83896 L F
.51264 .83803 m .5135 .83896 L .51418 .83883 L F
0 0 .48 r
.51264 .83803 m .51229 .83766 L .51175 .83696 L F
.558 .89 .986 r
.69235 .73156 m .6915 .73272 L .69205 .73224 L F
0 0 .165 r
.69247 .72923 m .69205 .73224 L .69445 .72889 L F
.69247 .72923 m .69445 .72889 L .6947 .72853 L F
0 .006 .575 r
.6909 .72917 m .69108 .72948 L .69247 .72923 L F
0 0 .165 r
.69247 .72923 m .69235 .73156 L .69205 .73224 L F
0 .006 .575 r
.69108 .72948 m .69235 .73156 L .69247 .72923 L F
0 0 .433 r
.69255 .7339 m .6915 .73272 L .69235 .73156 L F
.13 0 0 r
.36455 .75072 m .36346 .75128 L .3615 .75153 L F
.614 .199 .231 r
.36664 .75077 m .36346 .75128 L .36455 .75072 L F
.255 .743 .922 r
.39363 .89558 m .39228 .89528 L .38992 .89537 L F
.829 .967 .892 r
.39401 .89387 m .39363 .89558 L .39497 .89421 L F
.782 .93 .931 r
.39401 .89387 m .39228 .89528 L .39363 .89558 L F
.686 .601 .755 r
.38127 .87726 m .38227 .87382 L .3802 .87423 L F
.38127 .87726 m .38365 .87675 L .38227 .87382 L F
.643 .41 .551 r
.38101 .8794 m .38338 .87918 L .38127 .87726 L F
.635 .412 .562 r
.38338 .87918 m .38365 .87675 L .38127 .87726 L F
.551 .53 .784 r
.44837 .82444 m .44605 .8229 L .44832 .8219 L F
.44837 .82444 m .44605 .8229 L .44832 .8219 L F
.727 .563 .669 r
.44832 .8219 m .44605 .8229 L .44522 .82027 L F
.886 .913 .839 r
.48636 .86334 m .48744 .8638 L .48645 .86425 L F
.849 .613 .582 r
.48555 .86536 m .48744 .8638 L .48636 .86334 L F
.108 0 .381 r
.48672 .86588 m .48744 .8638 L .48763 .86687 L F
.849 .613 .582 r
.48555 .86536 m .48763 .86687 L .48744 .8638 L F
.98 .714 .453 r
.54415 .83506 m .54463 .83715 L .54356 .83748 L F
.593 .495 .713 r
.54415 .83506 m .54463 .83715 L .5463 .83472 L F
.54415 .83506 m .54463 .83715 L .5463 .83472 L F
.563 .355 .556 r
.60459 .77689 m .60231 .77918 L .60257 .7774 L F
.653 .491 .651 r
.4166 .84002 m .41863 .83753 L .41629 .83761 L F
.537 .508 .771 r
.54775 .83997 m .54853 .84288 L .55123 .84292 L F
.539 .28 .47 r
.35552 .78776 m .35773 .78762 L .35847 .78482 L F
.469 .214 .444 r
.35847 .78482 m .35963 .78724 L .36072 .78504 L F
.35847 .78482 m .35773 .78762 L .35963 .78724 L F
.14 0 .257 r
.69392 .72441 m .69263 .72519 L .69205 .72695 L F
.433 .647 .948 r
.69165 .70429 m .6911 .706 L .68894 .70485 L F
.69165 .70429 m .69288 .70594 L .6911 .706 L F
.683 .525 .665 r
.42362 .83257 m .42367 .83495 L .42589 .83233 L F
.955 .625 .226 r
.44522 .82027 m .44605 .8229 L .44572 .82237 L F
.44522 .82027 m .44605 .8229 L .44572 .82237 L F
.672 .54 .695 r
.39832 .85591 m .40139 .85855 L .40053 .8556 L F
.39832 .85591 m .39938 .85903 L .40139 .85855 L F
.328 .016 .274 r
.38457 .76712 m .38378 .76886 L .38627 .76652 L F
.449 .698 .973 r
.37363 .72564 m .37293 .7269 L .37128 .72504 L F
.37363 .72564 m .37486 .72684 L .37293 .7269 L F
.797 .72 .779 r
.62072 .77216 m .61747 .77266 L .61918 .77121 L F
.62072 .77216 m .61863 .77462 L .61747 .77266 L F
.662 .509 .667 r
.62072 .77216 m .6205 .77447 L .61863 .77462 L F
.73 .754 .871 r
.62252 .77147 m .62072 .77216 L .61918 .77121 L F
.511 .336 .58 r
.33143 .67733 m .32947 .68002 L .32935 .67764 L F
0 0 0 r
.55265 .85042 m .55409 .84755 L .55316 .84947 L F
.836 .926 .892 r
.4802 .86877 m .47721 .8715 L .47635 .87079 L F
.17 0 0 r
.51767 .88077 m .52094 .87946 L .52014 .8796 L F
.621 .833 .982 r
.52185 .87801 m .52094 .87946 L .52281 .87881 L F
.744 .993 .824 r
.52014 .8796 m .52094 .87946 L .52185 .87801 L F
.674 .924 .973 r
.65538 .76773 m .65616 .76626 L .65395 .76678 L F
.65538 .76773 m .65719 .76673 L .65616 .76626 L F
.689 .545 .684 r
.44986 .85348 m .44997 .85621 L .44802 .85603 L F
.68 .537 .684 r
.45312 .85567 m .44997 .85621 L .44986 .85348 L F
.563 .48 .72 r
.41248 .74841 m .41091 .7508 L .41046 .74879 L F
.41248 .74841 m .41296 .75051 L .41091 .7508 L F
.653 .491 .651 r
.4166 .84002 m .41926 .84006 L .41863 .83753 L F
.651 .489 .652 r
.41863 .83753 m .42155 .83992 L .42152 .83756 L F
.41863 .83753 m .41926 .84006 L .42155 .83992 L F
.511 .195 .368 r
.38709 .77977 m .38632 .78194 L .38422 .78215 L F
.537 .26 .442 r
.38907 .77944 m .38632 .78194 L .38709 .77977 L F
.653 .241 .251 r
.70132 .75065 m .7002 .7521 L .698 .75076 L F
.689 .27 .245 r
.70132 .75065 m .70224 .75283 L .7002 .7521 L F
.70132 .75065 m .70314 .75109 L .70224 .75283 L F
.769 .634 .711 r
.39229 .72944 m .39322 .73313 L .39006 .73258 L F
.601 .53 .747 r
.39469 .73013 m .39322 .73313 L .39229 .72944 L F
.524 .44 .702 r
.39469 .73013 m .39544 .73438 L .39322 .73313 L F
.656 .421 .553 r
.6099 .77459 m .60798 .77643 L .60653 .7745 L F
.763 .709 .802 r
.61747 .77266 m .61863 .77462 L .61548 .77454 L F
.733 .525 .61 r
.61863 .77462 m .61525 .77681 L .61548 .77454 L F
.61863 .77462 m .61865 .77731 L .61525 .77681 L F
.794 .65 .703 r
.6205 .77447 m .61865 .77731 L .61863 .77462 L F
.648 .5 .669 r
.4144 .84285 m .41708 .84275 L .4166 .84002 L F
.643 .447 .603 r
.41441 .84509 m .41708 .84275 L .4144 .84285 L F
.572 0 0 r
.54497 .8029 m .54779 .80396 L .54758 .80444 L F
.574 0 0 r
.55027 .80536 m .54758 .80444 L .54779 .80396 L F
.546 .117 .177 r
.70224 .75283 m .70314 .75109 L .70541 .7523 L F
.536 .148 .253 r
.70541 .7523 m .70314 .75109 L .7063 .75064 L F
.751 .971 .928 r
.40108 .8941 m .40097 .89466 L .40304 .89284 L F
.676 .696 .861 r
.40097 .89466 m .40396 .89477 L .40304 .89284 L F
.716 .646 .778 r
.37945 .89587 m .38259 .89778 L .3814 .89518 L F
.718 .693 .826 r
.3814 .89518 m .38259 .89778 L .38498 .89565 L F
.642 .47 .635 r
.3922 .86645 m .39489 .8663 L .39457 .86378 L F
.606 .421 .606 r
.39457 .86378 m .39696 .86379 L .39728 .86146 L F
.627 .459 .636 r
.39457 .86378 m .39708 .86612 L .39696 .86379 L F
.39457 .86378 m .39489 .8663 L .39708 .86612 L F
.64 .719 .905 r
.48351 .86951 m .4802 .86877 L .48197 .86904 L F
.795 .885 .911 r
.48485 .86782 m .48351 .86951 L .48197 .86904 L F
.413 .801 .989 r
.39627 .72715 m .39993 .72747 L .3976 .72746 L F
.844 .717 .723 r
.68155 .74259 m .68484 .74055 L .68185 .7403 L F
.68155 .74259 m .68329 .74317 L .68484 .74055 L F
.961 .636 .25 r
.68524 .74278 m .684 .73982 L .68484 .74055 L F
.786 .731 .801 r
.4919 .86137 m .4929 .86386 L .49045 .86362 L F
.965 .71 .502 r
.4929 .86386 m .4916 .86577 L .49045 .86362 L F
.4929 .86386 m .49291 .86619 L .4916 .86577 L F
.167 .353 .804 r
.49386 .86296 m .4929 .86386 L .4919 .86137 L F
0 0 .342 r
.49325 .86549 m .4929 .86386 L .49386 .86296 L F
.74 .929 .952 r
.49379 .8659 m .49325 .86549 L .49409 .86591 L F
0 0 .342 r
.49325 .86549 m .49291 .86619 L .4929 .86523 L F
.74 .929 .952 r
.4916 .86577 m .49291 .86619 L .49325 .86549 L F
.4916 .86577 m .49325 .86549 L .49379 .8659 L F
0 0 .342 r
.49325 .86549 m .4929 .86523 L .4929 .86386 L F
.769 .561 .616 r
.59481 .78164 m .59194 .77959 L .59499 .77989 L F
.58 .351 .533 r
.59499 .77989 m .59703 .7818 L .59481 .78164 L F
.652 .337 .427 r
.59716 .78013 m .59703 .7818 L .59499 .77989 L F
.647 .477 .64 r
.40579 .8533 m .40816 .85321 L .40805 .85065 L F
.629 .47 .648 r
.40816 .85321 m .41024 .85033 L .40805 .85065 L F
.425 0 0 r
.49251 .83464 m .49371 .83516 L .49469 .83499 L F
.66 .164 0 r
.49545 .83631 m .49469 .83499 L .49371 .83516 L F
.217 .348 .783 r
.49438 .83347 m .49527 .83583 L .49371 .83516 L F
.49527 .83583 m .49545 .83631 L .49371 .83516 L F
.425 0 0 r
.49138 .83445 m .49371 .83516 L .49251 .83464 L F
.66 .164 0 r
.49545 .83631 m .49656 .83733 L .49469 .83499 L F
.074 0 .352 r
.60754 .8295 m .60949 .82652 L .60928 .82871 L F
.097 0 .296 r
.60765 .83162 m .60754 .8295 L .60928 .82871 L F
.491 .307 .558 r
.62514 .74571 m .62398 .74775 L .62316 .74769 L F
.142 .207 .671 r
.62398 .74775 m .62433 .74906 L .62316 .74769 L F
.451 .19 .425 r
.38235 .78265 m .3819 .78454 L .37993 .78494 L F
.521 .288 .503 r
.38422 .78215 m .3819 .78454 L .38235 .78265 L F
.577 .304 .466 r
.45804 .83206 m .46025 .83198 L .46113 .82933 L F
.56 .274 .439 r
.46025 .83198 m .46327 .82933 L .46113 .82933 L F
.675 .708 .873 r
.63772 .76388 m .6344 .7634 L .63668 .7614 L F
.695 .691 .843 r
.63982 .76321 m .63772 .76388 L .63668 .7614 L F
.595 .134 .13 r
.45417 .86364 m .45644 .86481 L .45784 .86358 L F
.588 .076 .002 r
.45644 .86481 m .45924 .86459 L .45784 .86358 L F
.779 .77 .844 r
.45912 .86952 m .45519 .87055 L .45725 .86813 L F
.687 .709 .865 r
.40304 .89284 m .40396 .89477 L .40525 .89339 L F
.766 .761 .848 r
.61261 .77365 m .6099 .77459 L .61209 .77265 L F
.669 .431 .552 r
.61261 .77365 m .60998 .77674 L .6099 .77459 L F
.61261 .77365 m .61177 .77663 L .60998 .77674 L F
.575 .571 .811 r
.61436 .77178 m .61261 .77365 L .61209 .77265 L F
.61436 .77178 m .61548 .77454 L .61261 .77365 L F
.738 .574 .67 r
.61548 .77454 m .61177 .77663 L .61261 .77365 L F
.661 .313 .373 r
.50751 .84259 m .50652 .8447 L .50438 .8429 L F
.704 .361 .393 r
.50979 .84468 m .50751 .84259 L .50971 .8426 L F
.50979 .84468 m .50652 .8447 L .50751 .84259 L F
.209 .344 .783 r
.50751 .84259 m .50979 .84468 L .50971 .8426 L F
.86 .728 .716 r
.48484 .82949 m .48429 .83208 L .48604 .83238 L F
.865 .598 .533 r
.48429 .83208 m .48464 .83438 L .48604 .83238 L F
.615 .269 .36 r
.48604 .83238 m .48464 .83438 L .48817 .83393 L F
.584 .473 .693 r
.44759 .85851 m .44771 .86014 L .44554 .85908 L F
.688 .697 .854 r
.70489 .71044 m .70571 .71192 L .70258 .71129 L F
.614 .663 .874 r
.70794 .71145 m .70571 .71192 L .70489 .71044 L F
.109 0 .309 r
.61122 .82132 m .61176 .81931 L .61342 .81864 L F
.702 .305 .292 r
.54463 .83715 m .54289 .83944 L .54356 .83748 L F
.54463 .83715 m .54619 .83938 L .54289 .83944 L F
.399 .642 .954 r
.66133 .75268 m .6602 .7538 L .65933 .75253 L F
.535 .867 .993 r
.66222 .75318 m .6602 .7538 L .66133 .75268 L F
.66222 .75318 m .6602 .7538 L .66133 .75268 L F
0 .234 .752 r
.68329 .72461 m .68541 .72655 L .68496 .72721 L F
0 .075 .634 r
.68507 .727 m .68496 .72721 L .68541 .72655 L F
.68507 .727 m .68715 .72988 L .68496 .72721 L F
.523 .393 .645 r
.52737 .81062 m .52931 .80854 L .52713 .80889 L F
.788 .753 .821 r
.62794 .7563 m .62495 .75635 L .6267 .75501 L F
.54 .54 .804 r
.6291 .75317 m .62794 .7563 L .6267 .75501 L F
.6291 .75317 m .62996 .75607 L .62794 .7563 L F
.535 .464 .722 r
.62794 .7563 m .63028 .75806 L .62799 .75861 L F
.62794 .7563 m .62996 .75607 L .63028 .75806 L F
.747 .53 .601 r
.59171 .77724 m .58851 .77929 L .5886 .77768 L F
.811 .956 .91 r
.50053 .87395 m .49743 .87516 L .49973 .8745 L F
.435 0 0 r
.50156 .87416 m .50108 .87404 L .50035 .8729 L F
.50236 .87499 m .50369 .87525 L .50108 .87404 L F
.50236 .87499 m .50108 .87404 L .50156 .87416 L F
.05 0 0 r
.50108 .87404 m .50294 .8739 L .5007 .87394 L F
.50108 .87404 m .5007 .87394 L .50053 .87395 L F
0 0 0 r
.50108 .87404 m .50053 .87395 L .49973 .8745 L F
.335 0 .236 r
.48343 .84777 m .48539 .84733 L .48624 .84526 L F
.214 .55 .931 r
.48703 .84471 m .48812 .84601 L .48624 .84526 L F
.43 .254 .541 r
.48539 .84733 m .48703 .84471 L .48624 .84526 L F
.305 0 0 r
.48986 .84146 m .48706 .84254 L .48835 .84285 L F
.741 .677 .788 r
.49056 .82914 m .49171 .83069 L .4935 .82963 L F
.388 0 0 r
.34993 .75496 m .347 .7551 L .34858 .75406 L F
.632 .466 .641 r
.37393 .88218 m .37613 .88201 L .37608 .8795 L F
.739 .609 .714 r
.37613 .88201 m .37881 .87973 L .37608 .8795 L F
.223 .721 .912 r
.57865 .8485 m .57973 .84883 L .58197 .84876 L F
.64 .444 .601 r
.43636 .82938 m .43875 .82924 L .43864 .82713 L F
.914 .916 .525 r
.62592 .79124 m .6266 .79031 L .62654 .79003 L F
.706 .392 .443 r
.49276 .85078 m .49187 .8532 L .48935 .85237 L F
.712 .658 .794 r
.49556 .84879 m .49276 .85078 L .49139 .84803 L F
.72 .408 .448 r
.49301 .8528 m .49187 .8532 L .49276 .85078 L F
.717 .669 .802 r
.49577 .84993 m .49276 .85078 L .49556 .84879 L F
.756 .542 .607 r
.49577 .84993 m .49301 .8528 L .49276 .85078 L F
.681 .258 .236 r
.51726 .84008 m .51937 .84182 L .52055 .84029 L F
.269 0 0 r
.51937 .84182 m .52267 .83993 L .52055 .84029 L F
.247 .43 .845 r
.66547 .7072 m .66439 .70818 L .66256 .70618 L F
.66547 .7072 m .66595 .70875 L .66439 .70818 L F
.57 .012 0 r
.54477 .80085 m .54387 .80041 L .54145 .79842 L F
.529 .371 .611 r
.54145 .79842 m .54387 .80041 L .544 .79803 L F
.57 .377 .581 r
.44973 .85814 m .44759 .85851 L .44802 .85603 L F
.679 .39 .477 r
.44997 .85621 m .44973 .85814 L .44802 .85603 L F
.394 .429 .779 r
.69498 .70565 m .69421 .70867 L .69288 .70594 L F
.69498 .70565 m .69582 .70871 L .69421 .70867 L F
.705 .231 .121 r
.68723 .70444 m .68585 .70417 L .68409 .70348 L F
.703 .227 .116 r
.68685 .70547 m .68723 .70444 L .68409 .70348 L F
.706 .813 .931 r
.51616 .83434 m .5188 .8349 L .5179 .83482 L F
.686 .414 .505 r
.51616 .83434 m .5179 .83482 L .51615 .83234 L F
.836 .37 .086 r
.51615 .83234 m .5179 .83482 L .5188 .8349 L F
.514 .215 .397 r
.37952 .77138 m .38155 .77118 L .38216 .76945 L F
.487 .189 .385 r
.38216 .76945 m .38363 .77082 L .38378 .76886 L F
.38216 .76945 m .38155 .77118 L .38363 .77082 L F
.739 .589 .015 r
.55546 .83621 m .55549 .83481 L .55525 .83385 L F
.55546 .83621 m .55554 .83732 L .55549 .83481 L F
.721 .814 .922 r
.43304 .89503 m .43382 .89653 L .43631 .89505 L F
.586 .411 .611 r
.41708 .84275 m .41926 .84006 L .4166 .84002 L F
.032 .603 .742 r
.36838 .79769 m .365 .79766 L .36589 .79764 L F
.854 .948 .878 r
.63272 .78206 m .63551 .77963 L .63464 .77918 L F
.854 .891 .863 r
.63551 .77963 m .63682 .77649 L .63464 .77918 L F
.63551 .77963 m .6379 .77723 L .63682 .77649 L F
.554 .38 .6 r
.62765 .73005 m .62981 .72975 L .62971 .72736 L F
.554 .382 .602 r
.62765 .73005 m .62798 .73241 L .62981 .72975 L F
.086 0 0 r
.65929 .76595 m .66237 .76406 L .66127 .76547 L F
.81 .816 .855 r
.66237 .76406 m .66341 .76105 L .66142 .76129 L F
.66237 .76406 m .66496 .76197 L .66341 .76105 L F
.238 .346 .772 r
.66377 .76333 m .66237 .76406 L .66142 .76129 L F
0 0 0 r
.66127 .76547 m .66237 .76406 L .66377 .76333 L F
.865 .841 .819 r
.61474 .78748 m .61271 .78758 L .61473 .78502 L F
.863 .727 .71 r
.61474 .78748 m .61204 .78942 L .61271 .78758 L F
.61474 .78748 m .61377 .79055 L .61204 .78942 L F
.876 .849 .813 r
.61686 .78449 m .61474 .78748 L .61473 .78502 L F
.976 .683 .391 r
.70607 .71663 m .70854 .71411 L .70797 .71546 L F
.38 .421 .778 r
.71065 .7135 m .70854 .71411 L .70794 .71145 L F
.104 0 0 r
.70797 .71546 m .70854 .71411 L .71065 .7135 L F
.328 .658 .972 r
.54631 .8314 m .54303 .83026 L .54495 .82952 L F
.736 .988 .891 r
.54667 .83041 m .54631 .8314 L .54495 .82952 L F
.544 .405 .642 r
.53532 .82168 m .53612 .824 L .53344 .82446 L F
.358 .244 .585 r
.5351 .82443 m .53735 .82591 L .53612 .824 L F
.435 .216 .481 r
.5351 .82443 m .53567 .82682 L .53735 .82591 L F
.519 .327 .56 r
.53567 .82682 m .53344 .82446 L .53612 .824 L F
.53567 .82682 m .53334 .82727 L .53344 .82446 L F
.629 .866 .987 r
.54495 .82952 m .54303 .83026 L .54173 .82964 L F
.766 .551 .607 r
.54495 .82952 m .5416 .8268 L .54416 .82735 L F
.614 .442 .626 r
.54665 .82815 m .54495 .82952 L .54416 .82735 L F
.517 .259 .463 r
.40335 .76899 m .40084 .7715 L .40125 .7693 L F
0 .302 .771 r
.54604 .81524 m .54456 .81474 L .54345 .81399 L F
.54604 .81524 m .54692 .81621 L .54456 .81474 L F
.369 .838 .838 r
.46293 .88272 m .46429 .88252 L .46624 .88187 L F
.743 .709 .819 r
.54495 .82952 m .54858 .82987 L .54665 .82815 L F
.542 .018 0 r
.54665 .82815 m .54858 .82987 L .54799 .82943 L F
.806 .988 .883 r
.54799 .82943 m .54858 .82987 L .54667 .83041 L F
.311 .788 .702 r
.42853 .88681 m .42814 .88701 L .43203 .88544 L F
.42853 .88681 m .43203 .88544 L .43063 .88655 L F
.227 .737 .883 r
.42895 .88659 m .42853 .88681 L .43063 .88655 L F
.42727 .88663 m .42853 .88681 L .42895 .88659 L F
.311 .788 .702 r
.42853 .88681 m .42779 .88715 L .42814 .88701 L F
.748 .576 .662 r
.3743 .88445 m .37393 .88218 L .37387 .88275 L F
.3743 .88445 m .37613 .88201 L .37393 .88218 L F
.619 .412 .579 r
.62058 .75869 m .62062 .76105 L .61794 .76121 L F
.703 .603 .742 r
.62136 .75538 m .62237 .75881 L .62058 .75869 L F
.686 .465 .581 r
.62058 .75869 m .62268 .76119 L .62062 .76105 L F
.702 .466 .563 r
.62237 .75881 m .62268 .76119 L .62058 .75869 L F
.553 .372 .589 r
.52705 .84543 m .52707 .84777 L .52498 .84808 L F
.596 .421 .616 r
.52707 .84777 m .52494 .85041 L .52498 .84808 L F
.864 .666 .633 r
.61686 .78449 m .61473 .78502 L .61502 .78211 L F
.823 .401 .24 r
.52436 .83624 m .52377 .83548 L .52577 .83439 L F
.638 .46 .627 r
.42589 .83233 m .42367 .83495 L .42593 .83471 L F
.613 .441 .625 r
.42589 .83233 m .42818 .8344 L .42803 .83203 L F
.42589 .83233 m .42593 .83471 L .42818 .8344 L F
.73 .754 .871 r
.62252 .77147 m .61918 .77121 L .62165 .7688 L F
.761 .72 .815 r
.62483 .76904 m .62252 .77147 L .62165 .7688 L F
.348 .826 .843 r
.58415 .84844 m .5852 .84838 L .58726 .84776 L F
.829 .686 .705 r
.70742 .74543 m .70442 .74605 L .70706 .74525 L F
.806 1 .822 r
.70706 .74525 m .70963 .74282 L .70742 .74543 L F
.563 .379 .591 r
.70963 .74282 m .70991 .7452 L .70742 .74543 L F
.501 .47 .754 r
.70912 .74722 m .70742 .74543 L .70991 .7452 L F
.743 .964 .681 r
.51202 .82513 m .51251 .82402 L .51385 .824 L F
.615 .43 .608 r
.39728 .86146 m .39923 .86351 L .39933 .86112 L F
.39728 .86146 m .39696 .86379 L .39923 .86351 L F
.859 .862 .841 r
.53518 .81601 m .53203 .81901 L .53389 .8162 L F
.77 .649 .728 r
.53518 .81601 m .53563 .81395 L .53583 .81452 L F
.611 .421 .6 r
.38997 .86896 m .39229 .86883 L .3922 .86645 L F
.615 .409 .579 r
.39229 .86883 m .39489 .8663 L .3922 .86645 L F
.644 .568 .755 r
.62495 .75635 m .62237 .75881 L .62136 .75538 L F
.761 .531 .584 r
.56097 .79813 m .56295 .8007 L .56317 .79836 L F
.405 .08 .297 r
.35832 .80241 m .35897 .8011 L .3609 .80063 L F
.656 .479 .633 r
.3802 .87423 m .38227 .87382 L .3824 .87166 L F
.177 .675 .915 r
.4935 .82963 m .4923 .82916 L .49056 .82914 L F
.4935 .82963 m .4923 .82916 L .49056 .82914 L F
.573 .225 .34 r
.49564 .82701 m .4923 .82916 L .4935 .82963 L F
.19 .717 .719 r
.49171 .88355 m .49451 .8829 L .49274 .88327 L F
.462 .889 .846 r
.49274 .88327 m .49451 .8829 L .4964 .88206 L F
.981 .688 .364 r
.54477 .80085 m .54497 .8029 L .54387 .80041 L F
.514 .255 .46 r
.3819 .78454 m .3793 .7873 L .37993 .78494 L F
.56 .339 .537 r
.62752 .74302 m .62829 .74656 L .62514 .74571 L F
0 0 .348 r
.62793 .74453 m .62752 .74302 L .6294 .74196 L F
.62793 .74453 m .62829 .74656 L .62752 .74302 L F
.527 .261 .454 r
.41315 .7616 m .41305 .76339 L .41089 .76341 L F
.567 .319 .499 r
.41523 .76127 m .41305 .76339 L .41315 .7616 L F
.707 .539 .66 r
.40357 .85351 m .40351 .85587 L .40579 .8533 L F
.661 .472 .619 r
.40579 .8533 m .40351 .85587 L .40582 .85567 L F
.631 .439 .605 r
.40582 .85567 m .40816 .85321 L .40579 .8533 L F
.637 .481 .655 r
.41235 .84779 m .41441 .84509 L .41226 .84536 L F
.941 .637 .435 r
.67954 .72729 m .67855 .72896 L .67816 .7268 L F
.67954 .72729 m .67991 .72963 L .67855 .72896 L F
.802 .581 .603 r
.53731 .83515 m .53877 .83747 L .53559 .83738 L F
.748 .985 .904 r
.63731 .72826 m .63861 .72812 L .64045 .7269 L F
.63731 .72826 m .64045 .7269 L .64088 .72597 L F
.682 .976 .811 r
.64088 .72597 m .64045 .7269 L .643 .72491 L F
.341 0 0 r
.49177 .81999 m .4935 .82039 L .49137 .81984 L F
.572 .579 .822 r
.40056 .73479 m .39981 .73842 L .39853 .73545 L F
.40056 .73479 m .40183 .73815 L .39981 .73842 L F
.933 .623 .432 r
.66377 .76333 m .66496 .76197 L .66341 .76105 L F
.707 .597 .731 r
.53669 .84008 m .53484 .84313 L .53459 .84073 L F
.599 .459 .662 r
.53669 .84008 m .53692 .84279 L .53484 .84313 L F
.62 .363 .506 r
.53692 .84279 m .53449 .84471 L .53484 .84313 L F
0 .119 .669 r
.55239 .82716 m .55418 .82905 L .55389 .82954 L F
0 .096 .652 r
.55418 .82905 m .55571 .83167 L .55389 .82954 L F
.794 .757 .819 r
.64784 .75839 m .64425 .75855 L .64624 .75643 L F
.604 .597 .818 r
.64624 .75643 m .64945 .75853 L .64784 .75839 L F
.576 .186 .265 r
.51489 .81489 m .51416 .81624 L .51689 .81595 L F
.987 .837 .455 r
.69217 .73789 m .69205 .73486 L .69212 .73718 L F
.719 .236 .096 r
.69189 .73919 m .69217 .73789 L .69212 .73718 L F
.69189 .73919 m .69446 .73979 L .69217 .73789 L F
.661 .437 .57 r
.39554 .75844 m .39569 .75612 L .3947 .75583 L F
.39554 .75844 m .39793 .75842 L .39569 .75612 L F
.679 .436 .547 r
.39569 .75612 m .39793 .75842 L .39814 .75623 L F
.663 .473 .618 r
.50553 .83509 m .50832 .83712 L .50778 .83512 L F
.50553 .83509 m .50538 .83765 L .50832 .83712 L F
.519 .333 .568 r
.4975 .85236 m .49577 .84993 L .4977 .85016 L F
.314 .74 .973 r
.49964 .85221 m .4977 .85016 L .49795 .84996 L F
.49964 .85221 m .4975 .85236 L .4977 .85016 L F
.635 .565 .758 r
.61475 .73487 m .61697 .73687 L .6184 .73557 L F
.089 0 0 r
.33967 .66662 m .33658 .66856 L .338 .66727 L F
.62 .384 .538 r
.52949 .84561 m .52707 .84777 L .52705 .84543 L F
.756 .542 .607 r
.49577 .84993 m .49543 .85329 L .49301 .8528 L F
.519 .333 .568 r
.4975 .85236 m .49543 .85329 L .49577 .84993 L F
.536 .478 .738 r
.3911 .76139 m .39248 .75843 L .39037 .75897 L F
.3911 .76139 m .39323 .76115 L .39248 .75843 L F
.604 .455 .652 r
.39117 .7635 m .39323 .76115 L .3911 .76139 L F
.694 .529 .659 r
.40053 .8556 m .40351 .85587 L .40357 .85351 L F
.866 .889 .849 r
.63682 .77649 m .6379 .77723 L .64016 .77466 L F
.691 .533 .668 r
.53563 .81395 m .53389 .8162 L .53536 .81493 L F
.444 .817 .993 r
.52027 .82722 m .52229 .82687 L .51928 .82667 L F
.476 .45 .749 r
.52027 .82722 m .52307 .82953 L .52229 .82687 L F
.806 1 .822 r
.70706 .74525 m .70883 .7427 L .70963 .74282 L F
.749 .994 .849 r
.70963 .74282 m .71053 .74131 L .71174 .74035 L F
.70963 .74282 m .70883 .7427 L .71053 .74131 L F
.507 .327 .572 r
.71174 .74035 m .71182 .74265 L .70963 .74282 L F
.327 .116 .432 r
.71182 .74265 m .70991 .7452 L .70963 .74282 L F
.72 .616 .741 r
.38227 .87382 m .38365 .87675 L .38564 .87422 L F
.519 .339 .577 r
.38564 .87422 m .38365 .87675 L .38556 .87659 L F
.511 .305 .536 r
.38556 .87659 m .38365 .87675 L .38338 .87918 L F
.559 .078 .069 r
.5776 .77749 m .57187 .7786 L .57246 .77819 L F
.639 .354 .471 r
.45194 .858 m .44997 .85621 L .45312 .85567 L F
.45194 .858 m .44973 .85814 L .44997 .85621 L F
.296 0 0 r
.35546 .72697 m .35747 .72672 L .359 .72552 L F
.563 .376 .586 r
.60115 .7587 m .60326 .75851 L .60322 .75622 L F
.295 .338 .736 r
.60115 .7587 m .60242 .75968 L .60326 .75851 L F
.504 .645 .92 r
.50943 .82782 m .51055 .82627 L .50985 .82565 L F
.50943 .82782 m .51159 .82797 L .51055 .82627 L F
.398 0 0 r
.43732 .8849 m .43528 .88586 L .43373 .88516 L F
0 0 0 r
.43852 .8844 m .43732 .8849 L .43938 .88449 L F
.43852 .8844 m .43528 .88586 L .43732 .8849 L F
.7 .51 .627 r
.66864 .75015 m .66812 .74777 L .66958 .7487 L F
.717 .322 .3 r
.67055 .74993 m .66864 .75015 L .66958 .7487 L F
.743 .707 .817 r
.58566 .83147 m .58706 .83231 L .5838 .83201 L F
.552 .65 .899 r
.58839 .83079 m .58706 .83231 L .58566 .83147 L F
.58839 .83079 m .58932 .83218 L .58706 .83231 L F
0 0 .236 r
.70003 .7443 m .69927 .74322 L .69974 .74182 L F
0 0 0 r
.69974 .74182 m .69927 .74322 L .6994 .74333 L F
0 0 .236 r
.70003 .7443 m .69904 .74507 L .69927 .74322 L F
0 0 .523 r
.66717 .75997 m .66754 .76056 L .66584 .75814 L F
.314 0 0 r
.66966 .76109 m .66754 .76056 L .66831 .76077 L F
.66754 .76056 m .66751 .76056 L .66831 .76077 L F
.66754 .76056 m .66691 .7604 L .66751 .76056 L F
.66966 .76109 m .66903 .76102 L .66792 .7607 L F
.66888 .76089 m .66792 .7607 L .66691 .7604 L F
.66966 .76109 m .66792 .7607 L .66888 .76089 L F
0 0 .523 r
.66761 .76054 m .66783 .76097 L .66754 .76056 L F
.729 .93 .957 r
.66523 .76051 m .66783 .76097 L .66767 .76065 L F
.664 .58 .751 r
.66761 .7606 m .66903 .76102 L .66717 .75997 L F
0 0 .523 r
.66758 .76055 m .66757 .76055 L .66717 .75997 L F
.66757 .76055 m .66754 .76056 L .66717 .75997 L F
.664 .58 .751 r
.66691 .7604 m .66761 .7606 L .66717 .75997 L F
.66691 .7604 m .66717 .75997 L .66584 .75814 L F
.66717 .75997 m .66857 .75766 L .66584 .75814 L F
0 0 .523 r
.66761 .76054 m .66758 .76055 L .66584 .75814 L F
.66696 .75925 m .66761 .76054 L .66685 .75951 L F
.66696 .75925 m .66685 .75951 L .66584 .75814 L F
.664 .58 .751 r
.66717 .75997 m .66903 .76102 L .66857 .75766 L F
.759 .647 .738 r
.66857 .75766 m .66903 .76102 L .67126 .75816 L F
.517 .033 .044 r
.66857 .75766 m .66905 .75934 L .66696 .75925 L F
.129 .658 .871 r
.66696 .75925 m .66754 .75895 L .66704 .75903 L F
.66696 .75925 m .66704 .75903 L .66571 .75923 L F
.729 .93 .957 r
.66561 .76023 m .66767 .76065 L .66696 .75925 L F
.66523 .76051 m .66767 .76065 L .66561 .76023 L F
.671 .535 .69 r
.39938 .85903 m .39933 .86112 L .40139 .85855 L F
0 0 0 r
.62018 .8025 m .61928 .80354 L .62121 .80092 L F
0 0 .179 r
.61896 .80571 m .61928 .80354 L .62018 .8025 L F
.512 .832 .526 r
.3277 .67891 m .32994 .67673 L .32915 .67753 L F
.449 .122 .318 r
.39429 .77504 m .39357 .77662 L .39155 .77695 L F
.364 .039 .274 r
.39612 .77442 m .39357 .77662 L .39429 .77504 L F
.526 .16 .29 r
.48035 .82359 m .4825 .82358 L .48347 .82143 L F
.352 0 .063 r
.4825 .82358 m .48584 .82158 L .48347 .82143 L F
.689 .782 .922 r
.55452 .82405 m .55333 .82506 L .55212 .82337 L F
0 .001 .559 r
.66356 .7296 m .66342 .72656 L .66296 .72689 L F
.813 .458 .384 r
.66662 .73223 m .66507 .7321 L .66356 .7296 L F
.873 .757 .732 r
.66507 .7321 m .66417 .72886 L .66356 .7296 L F
.747 .53 .601 r
.59171 .77724 m .59194 .77959 L .58851 .77929 L F
.632 .378 .516 r
.51937 .81571 m .52232 .8131 L .52018 .81394 L F
.557 .031 0 r
.544 .79803 m .54591 .79891 L .54687 .79806 L F
.507 0 0 r
.54591 .79891 m .54912 .79864 L .54687 .79806 L F
.572 .42 .636 r
.61794 .76121 m .61815 .76412 L .61623 .76378 L F
.622 .446 .623 r
.61843 .76626 m .61623 .76378 L .61815 .76412 L F
.61843 .76626 m .61534 .76713 L .61623 .76378 L F
.791 .505 .503 r
.55646 .79754 m .55831 .79568 L .55637 .79546 L F
.55646 .79754 m .55959 .79806 L .55831 .79568 L F
.608 .541 .753 r
.62971 .72736 m .632 .72705 L .63163 .72492 L F
.545 .353 .571 r
.62981 .72975 m .632 .72705 L .62971 .72736 L F
.412 .809 .985 r
.39497 .89421 m .39769 .89422 L .39547 .89345 L F
.53 .77 .985 r
.39769 .89422 m .39813 .89207 L .39547 .89345 L F
.39769 .89422 m .40108 .8941 L .39813 .89207 L F
0 .138 .682 r
.46949 .87037 m .46899 .87005 L .46854 .86855 L F
.506 .329 .576 r
.69247 .72923 m .69007 .72786 L .68913 .72816 L F
.69247 .72923 m .69205 .72695 L .69007 .72786 L F
.474 .861 .976 r
.44798 .8842 m .44872 .88332 L .4469 .88343 L F
.44798 .8842 m .45037 .88364 L .44872 .88332 L F
.709 .388 .432 r
.66602 .71988 m .66728 .7221 L .66301 .72137 L F
.834 .369 0 r
.66602 .71988 m .66794 .72255 L .66728 .7221 L F
.929 .578 .145 r
.52771 .82423 m .52703 .82378 L .52675 .82206 L F
.52771 .82423 m .52703 .82378 L .52675 .82206 L F
.739 .609 .714 r
.37613 .88201 m .37929 .88214 L .37881 .87973 L F
.67 .467 .602 r
.37681 .88486 m .37929 .88214 L .37613 .88201 L F
.37681 .88486 m .37923 .88447 L .37929 .88214 L F
.567 .457 .689 r
.37929 .88214 m .38101 .8794 L .37881 .87973 L F
.37929 .88214 m .38129 .88185 L .38101 .8794 L F
.588 .42 .622 r
.37923 .88447 m .38129 .88185 L .37929 .88214 L F
.674 .543 .697 r
.41024 .85033 m .41235 .84779 L .41001 .84797 L F
.976 .847 .65 r
.70663 .71868 m .70607 .71663 L .70371 .71885 L F
.704 .314 .307 r
.43373 .88516 m .43063 .88655 L .43203 .88544 L F
.464 .266 .527 r
.56154 .81928 m .56005 .82175 L .56172 .82173 L F
.56154 .81928 m .56172 .82173 L .56058 .81879 L F
.656 .472 .623 r
.57327 .82971 m .57555 .82939 L .57318 .83221 L F
.41 .113 .347 r
.44957 .86706 m .45239 .86569 L .45084 .86739 L F
.582 .422 .629 r
.45181 .87057 m .44957 .86706 L .45084 .86739 L F
.45181 .87057 m .44993 .87116 L .44957 .86706 L F
.52 .293 .51 r
.39814 .75623 m .40032 .75597 L .4006 .75376 L F
.522 .444 .709 r
.4006 .75376 m .40254 .75338 L .40193 .75098 L F
.313 .117 .447 r
.4006 .75376 m .40182 .75522 L .40254 .75338 L F
.4006 .75376 m .40032 .75597 L .40182 .75522 L F
.031 .591 .809 r
.57007 .84695 m .57142 .84725 L .5733 .8474 L F
.169 0 .382 r
.63086 .73939 m .6294 .74196 L .62894 .74025 L F
0 0 0 r
.50172 .87967 m .50241 .87966 L .5007 .87976 L F
.50172 .87967 m .5037 .87949 L .50241 .87966 L F
.22 0 .06 r
.70749 .75026 m .70541 .7523 L .7063 .75064 L F
.888 .776 .732 r
.6947 .72853 m .69551 .72762 L .69412 .72622 L F
.838 .785 .8 r
.69412 .72622 m .69551 .72762 L .69749 .7247 L F
.656 .421 .553 r
.6099 .77459 m .60998 .77674 L .60798 .77643 L F
.767 .623 .7 r
.6344 .7634 m .63125 .76118 L .63339 .76049 L F
.6344 .7634 m .63307 .76463 L .63125 .76118 L F
.883 .926 .846 r
.63174 .76621 m .63307 .76463 L .6344 .7634 L F
.658 .627 .807 r
.63668 .7614 m .6344 .7634 L .63339 .76049 L F
.74 .429 .456 r
.68806 .74543 m .69114 .74557 L .69048 .74772 L F
.61 .4 .572 r
.69114 .74557 m .69349 .7477 L .69048 .74772 L F
.69114 .74557 m .69345 .74547 L .69349 .7477 L F
.61 .398 .569 r
.52285 .85273 m .51995 .85087 L .52275 .85065 L F
.52285 .85273 m .51991 .85326 L .51995 .85087 L F
.854 .948 .878 r
.63272 .78206 m .63464 .77918 L .63238 .78162 L F
.386 .157 .439 r
.41262 .88979 m .41094 .89003 L .4137 .88989 L F
.542 .919 .935 r
.41469 .88888 m .4137 .88989 L .41592 .88924 L F
.41469 .88888 m .41262 .88979 L .4137 .88989 L F
.444 .813 .994 r
.43938 .88449 m .44268 .88473 L .4414 .88404 L F
.561 .832 .996 r
.4414 .88404 m .44268 .88473 L .44472 .88423 L F
.469 .17 .375 r
.49774 .82161 m .49704 .82345 L .49469 .82355 L F
.488 .422 .709 r
.49704 .82345 m .49564 .82701 L .49469 .82355 L F
.837 .738 .755 r
.39229 .72944 m .38924 .73009 L .39087 .72849 L F
.39229 .72944 m .39006 .73258 L .38924 .73009 L F
.837 .852 .856 r
.39423 .72709 m .39229 .72944 L .39087 .72849 L F
.601 .53 .747 r
.39469 .73013 m .39229 .72944 L .39468 .72941 L F
0 .228 .74 r
.54933 .81792 m .54959 .81867 L .54787 .81727 L F
.372 .117 .393 r
.47104 .86439 m .47019 .86819 L .46854 .86855 L F
.42 .224 .507 r
.47333 .86308 m .47281 .86589 L .47104 .86439 L F
.49 .222 .435 r
.47219 .86786 m .47104 .86439 L .47281 .86589 L F
.47219 .86786 m .47019 .86819 L .47104 .86439 L F
.823 .89 .891 r
.70706 .74525 m .70405 .74427 L .70489 .7445 L F
.70706 .74525 m .70442 .74605 L .70405 .74427 L F
.733 .967 .935 r
.70706 .74525 m .70735 .74282 L .70883 .7427 L F
.70706 .74525 m .70489 .7445 L .70735 .74282 L F
.629 .46 .635 r
.38778 .87163 m .39015 .87152 L .38997 .86896 L F
.595 .422 .617 r
.39015 .87152 m .39229 .86883 L .38997 .86896 L F
.627 .449 .621 r
.42152 .83756 m .42155 .83992 L .42377 .83733 L F
.106 0 0 r
.48563 .88418 m .48822 .883 L .48723 .88364 L F
0 .538 .761 r
.48822 .883 m .49095 .88335 L .49003 .88315 L F
.48822 .883 m .49003 .88315 L .48723 .88364 L F
.436 .74 .992 r
.48822 .883 m .49171 .88355 L .49095 .88335 L F
.35 .725 .986 r
.52459 .82178 m .52675 .82206 L .52545 .82104 L F
.653 .342 .432 r
.52675 .82206 m .52703 .82378 L .52459 .82178 L F
.12 .332 .8 r
.52459 .82178 m .52703 .82378 L .52545 .82104 L F
.642 .515 .694 r
.55213 .79728 m .55422 .79548 L .55197 .79584 L F
.866 .889 .849 r
.63682 .77649 m .64016 .77466 L .63917 .77401 L F
.829 .929 .898 r
.63917 .77401 m .64016 .77466 L .64256 .77259 L F
.603 .447 .643 r
.42367 .83495 m .42585 .83699 L .42593 .83471 L F
.42367 .83495 m .42377 .83733 L .42585 .83699 L F
.283 0 0 r
.57331 .77345 m .57535 .77311 L .57652 .77178 L F
.455 .019 .12 r
.57535 .77311 m .57867 .77144 L .57652 .77178 L F
.615 .743 .937 r
.38661 .91774 m .38726 .91885 L .38422 .91839 L F
.38661 .91774 m .38726 .91885 L .38422 .91839 L F
.052 .379 .844 r
.38661 .91774 m .38726 .91885 L .38762 .91804 L F
.38661 .91774 m .38726 .91885 L .38762 .91804 L F
.979 .719 .466 r
.5541 .78242 m .55298 .78413 L .55042 .78304 L F
.123 0 0 r
.55042 .78304 m .55151 .78315 L .5541 .78242 L F
.979 .719 .466 r
.5541 .78242 m .55409 .78481 L .55298 .78413 L F
.742 .992 .866 r
.5541 .78242 m .55589 .78036 L .55679 .78273 L F
.5541 .78242 m .55151 .78315 L .55589 .78036 L F
.777 .34 0 r
.55199 .80792 m .55027 .80536 L .55137 .80599 L F
.686 .373 .439 r
.43239 .83144 m .43534 .83172 L .43333 .82971 L F
.656 .379 .489 r
.43333 .82971 m .43534 .83172 L .43636 .82938 L F
.66 .519 .682 r
.39933 .86112 m .40169 .86102 L .40139 .85855 L F
.667 .446 .576 r
.39933 .86112 m .40148 .86337 L .40169 .86102 L F
.39933 .86112 m .39923 .86351 L .40148 .86337 L F
.647 .393 .521 r
.60061 .77932 m .59703 .7818 L .59716 .78013 L F
.507 .009 .007 r
.45924 .86459 m .46147 .86538 L .46304 .86444 L F
.854 .996 .764 r
.46304 .86444 m .46361 .86275 L .4649 .86353 L F
.46304 .86444 m .46147 .86538 L .46361 .86275 L F
.362 .077 .34 r
.54136 .83776 m .53917 .8397 L .53877 .83747 L F
.708 .217 .074 r
.55864 .78069 m .5584 .78155 L .55722 .78036 L F
.578 .199 .287 r
.56319 .78104 m .5584 .78155 L .55864 .78069 L F
.23 .441 .86 r
.54966 .78138 m .55042 .78304 L .54877 .78242 L F
.039 0 0 r
.55042 .78304 m .54966 .78138 L .54877 .78242 L F
.82 .572 .564 r
.45624 .86618 m .45404 .86824 L .45419 .86606 L F
.45624 .86618 m .45725 .86813 L .45404 .86824 L F
.831 .615 .61 r
.45417 .86364 m .45624 .86618 L .45419 .86606 L F
.455 .688 .966 r
.4683 .88163 m .46952 .88296 L .47159 .88293 L F
.462 .182 .403 r
.37441 .79183 m .37292 .79056 L .37491 .79038 L F
.37441 .79183 m .37238 .79228 L .37292 .79056 L F
.565 .828 .995 r
.53375 .86846 m .53498 .86923 L .53701 .86871 L F
.53375 .86846 m .53498 .86923 L .53701 .86871 L F
.695 .691 .843 r
.63982 .76321 m .63668 .7614 L .63867 .76059 L F
.731 .704 .825 r
.64193 .76101 m .63982 .76321 L .63867 .76059 L F
.111 .243 .721 r
.67913 .71887 m .68005 .72206 L .6806 .71966 L F
.669 .505 .654 r
.61445 .74104 m .61376 .74349 L .61476 .74106 L F
.102 0 0 r
.48917 .87519 m .48639 .87673 L .48959 .8758 L F
.14 0 0 r
.49099 .87591 m .48959 .8758 L .49018 .87575 L F
0 .446 .739 r
.49099 .87591 m .49018 .87575 L .48998 .87569 L F
.361 0 0 r
.49099 .87591 m .48917 .87519 L .48943 .87556 L F
.803 .849 .885 r
.48639 .87673 m .48944 .87506 L .48512 .87499 L F
.793 .859 .899 r
.48512 .87499 m .48944 .87506 L .48749 .87363 L F
.678 .349 .41 r
.48749 .87363 m .4893 .87342 L .48908 .87532 L F
0 .446 .739 r
.48887 .87527 m .48772 .87494 L .48815 .87506 L F
.49099 .87591 m .4888 .87526 L .48887 .87527 L F
.4888 .87526 m .48772 .87494 L .48887 .87527 L F
.837 .878 .873 r
.49065 .87358 m .48928 .87536 L .4893 .87342 L F
.361 0 0 r
.48983 .87582 m .48943 .87556 L .48959 .8758 L F
.48998 .87569 m .48943 .87556 L .48983 .87582 L F
.61 .887 .99 r
.48732 .87498 m .48998 .87569 L .48639 .87673 L F
.48737 .87489 m .48751 .87493 L .48732 .87498 L F
.48751 .87493 m .48998 .87569 L .48732 .87498 L F
.803 .849 .885 r
.48639 .87673 m .48512 .87499 L .48342 .87646 L F
.779 .843 .9 r
.48512 .87499 m .48639 .87673 L .48342 .87646 L F
.61 .887 .99 r
.48739 .87483 m .48639 .87673 L .48512 .87499 L F
.441 .109 .305 r
.48435 .87572 m .48735 .87535 L .48405 .876 L F
.48512 .87499 m .48642 .8752 L .48435 .87572 L F
.48642 .8752 m .48735 .87535 L .48435 .87572 L F
.726 .35 .338 r
.48735 .87535 m .48739 .87489 L .48904 .87568 L F
.48739 .87489 m .48749 .87363 L .48842 .87485 L F
.61 .887 .99 r
.48754 .87488 m .48998 .87569 L .48737 .87489 L F
0 .446 .739 r
.48815 .87506 m .48772 .87494 L .48754 .87488 L F
.726 .35 .338 r
.48754 .87488 m .48842 .87485 L .48868 .87521 L F
0 .446 .739 r
.48785 .87497 m .48754 .87488 L .48739 .87483 L F
.48815 .87506 m .48754 .87488 L .48785 .87497 L F
.726 .35 .338 r
.48739 .87489 m .48754 .87488 L .48904 .87568 L F
.61 .887 .99 r
.48998 .87569 m .49018 .87575 L .48979 .87585 L F
.361 0 0 r
.49099 .87591 m .48998 .87569 L .48983 .87582 L F
0 .446 .739 r
.49099 .87591 m .48998 .87569 L .48772 .87494 L F
.49099 .87591 m .48785 .87497 L .48904 .87568 L F
.726 .35 .338 r
.48754 .87488 m .48785 .87497 L .48904 .87568 L F
0 .446 .739 r
.48785 .87497 m .48739 .87483 L .48904 .87568 L F
.726 .35 .338 r
.48785 .87497 m .48868 .87521 L .48904 .87568 L F
.61 .887 .99 r
.48739 .87483 m .48754 .87488 L .48737 .87489 L F
.303 0 0 r
.49018 .87575 m .48959 .8758 L .48639 .87673 L F
.61 .887 .99 r
.48998 .87569 m .48979 .87585 L .48639 .87673 L F
.837 .878 .873 r
.48928 .87536 m .48904 .87568 L .48908 .87532 L F
.48928 .87536 m .48908 .87532 L .4893 .87342 L F
.678 .349 .41 r
.48868 .87521 m .48908 .87532 L .48904 .87568 L F
.48749 .87363 m .48908 .87532 L .48868 .87521 L F
.434 0 0 r
.57717 .77837 m .57335 .7787 L .5776 .77749 L F
.711 .204 .025 r
.57752 .77741 m .57717 .77837 L .5776 .77749 L F
.604 .083 0 r
.58075 .77887 m .57717 .77837 L .57752 .77741 L F
.74 .71 .823 r
.70258 .71129 m .70048 .71218 L .69945 .71082 L F
.482 .182 .38 r
.39959 .75782 m .39814 .75623 L .39793 .75842 L F
.39959 .75782 m .40032 .75597 L .39814 .75623 L F
.645 .219 .221 r
.49763 .82922 m .49717 .83014 L .49454 .82922 L F
.49578 .82965 m .4968 .8301 L .49454 .82922 L F
.49717 .83014 m .49691 .83011 L .49578 .82965 L F
.49691 .83011 m .4968 .8301 L .49578 .82965 L F
.488 .422 .709 r
.49704 .82345 m .49778 .82683 L .49564 .82701 L F
.712 .378 .411 r
.49763 .82922 m .49564 .82701 L .49778 .82683 L F
.49763 .82922 m .49454 .82922 L .49564 .82701 L F
.813 .723 .766 r
.50135 .82677 m .49763 .82922 L .49997 .82606 L F
.591 .302 .446 r
.50034 .82743 m .49973 .83099 L .49763 .82922 L F
.50135 .82677 m .5007 .82846 L .50034 .82743 L F
.5007 .82846 m .49973 .83099 L .50034 .82743 L F
.665 .38 .478 r
.50176 .83074 m .49973 .83099 L .50135 .82677 L F
.728 .534 .628 r
.50176 .83074 m .49977 .83336 L .49973 .83099 L F
.864 .45 .239 r
.49985 .82998 m .50065 .83217 L .50157 .83098 L F
.50144 .83062 m .50157 .83098 L .50176 .83074 L F
.49985 .82998 m .50157 .83098 L .50144 .83062 L F
.705 .561 .689 r
.49997 .82606 m .49763 .82922 L .49778 .82683 L F
.673 .25 .235 r
.49973 .83099 m .49895 .83106 L .49763 .82922 L F
.49895 .83106 m .49663 .83124 L .49714 .83021 L F
.49895 .83106 m .49714 .83021 L .49763 .82922 L F
.706 .566 .694 r
.49997 .82606 m .49778 .82683 L .49731 .82468 L F
.49782 .82414 m .49731 .82468 L .49704 .82345 L F
.49997 .82606 m .49865 .82537 L .4988 .82501 L F
.604 .298 .425 r
.50288 .82127 m .50221 .8221 L .49991 .82189 L F
.706 .566 .694 r
.49865 .82537 m .49731 .82468 L .4988 .82501 L F
.49997 .82606 m .49782 .82414 L .49871 .82541 L F
.49782 .82414 m .49704 .82345 L .49773 .82425 L F
.4988 .82501 m .49731 .82468 L .49782 .82414 L F
.49782 .82414 m .49773 .82425 L .49871 .82541 L F
.48 .074 .192 r
.49991 .82189 m .49782 .82417 L .49704 .82345 L F
0 .072 .634 r
.49782 .82417 m .49773 .82425 L .49704 .82345 L F
.48 .074 .192 r
.49782 .82417 m .49754 .82447 L .49704 .82345 L F
0 .072 .634 r
.49774 .82385 m .49782 .82417 L .49704 .82345 L F
.967 .931 .694 r
.49753 .82306 m .49754 .82447 L .4978 .82406 L F
.49753 .82306 m .4978 .82406 L .49894 .82219 L F
0 0 0 r
.49991 .82189 m .50025 .82156 L .49894 .82294 L F
.27 0 .274 r
.49894 .82219 m .4978 .82406 L .50073 .82109 L F
0 .072 .634 r
.49788 .82412 m .49783 .82416 L .4978 .82406 L F
.49783 .82416 m .49782 .82417 L .49774 .82385 L F
.498 .824 m .49871 .82541 L .49773 .82425 L F
0 0 0 r
.49783 .82416 m .49788 .82412 L .49762 .82439 L F
.49763 .82437 m .49762 .82439 L .49754 .82447 L F
.27 0 .274 r
.4978 .82406 m .49754 .82447 L .49788 .82412 L F
0 0 0 r
.49894 .82294 m .50073 .82109 L .49788 .82412 L F
.49894 .82294 m .49788 .82412 L .49783 .82416 L F
.49894 .82294 m .49762 .82439 L .49763 .82437 L F
.594 .26 .372 r
.50221 .8221 m .49903 .8254 L .49991 .82189 L F
0 0 0 r
.50025 .82156 m .49897 .8254 L .50073 .82109 L F
.458 .821 .995 r
.49884 .82541 m .49895 .82542 L .49874 .82542 L F
.594 .26 .372 r
.49903 .8254 m .49896 .82541 L .49991 .82189 L F
.54 .22 .374 r
.50504 .82094 m .50221 .8221 L .50288 .82127 L F
.434 .064 .235 r
.50424 .82196 m .50221 .8221 L .50277 .82187 L F
.50424 .82196 m .50277 .82187 L .50504 .82094 L F
.274 0 0 r
.5073 .82156 m .50652 .82214 L .50424 .82196 L F
.379 .59 .927 r
.50424 .82196 m .50652 .82214 L .50649 .8221 L F
.274 0 0 r
.5073 .82156 m .50424 .82196 L .50504 .82094 L F
.379 .59 .927 r
.50424 .82196 m .50649 .8221 L .50488 .82029 L F
.458 .821 .995 r
.49894 .82543 m .50223 .82558 L .49888 .8255 L F
.49895 .82542 m .49985 .82546 L .49894 .82543 L F
.49985 .82546 m .50223 .82558 L .50001 .82548 L F
.49985 .82546 m .50001 .82548 L .49894 .82543 L F
.49895 .82542 m .49894 .82543 L .49874 .82542 L F
.49888 .8255 m .50223 .82558 L .49997 .82606 L F
.49874 .82542 m .49894 .82543 L .49888 .8255 L F
.49871 .82541 m .49884 .82541 L .49874 .82542 L F
.684 .335 .378 r
.50336 .82723 m .50135 .82677 L .49997 .82606 L F
.544 .717 .953 r
.50223 .82558 m .50336 .82723 L .49997 .82606 L F
.724 .383 .402 r
.49871 .82541 m .50066 .8278 L .50223 .82558 L F
.434 .064 .235 r
.50424 .82196 m .49893 .8255 L .50221 .8221 L F
.799 .657 .706 r
.50073 .82109 m .49898 .82538 L .50424 .82196 L F
.594 .26 .372 r
.49903 .8254 m .49893 .8255 L .49896 .82541 L F
.799 .657 .706 r
.49898 .82538 m .49893 .8255 L .4991 .82539 L F
.49898 .82538 m .4991 .82539 L .50424 .82196 L F
0 0 0 r
.49954 .82324 m .49896 .82541 L .50025 .82156 L F
.49896 .82541 m .49893 .8255 L .49897 .8254 L F
.49896 .82541 m .49897 .8254 L .50025 .82156 L F
.49897 .8254 m .49893 .8255 L .49898 .82538 L F
.49897 .8254 m .49898 .82538 L .50073 .82109 L F
.49991 .82189 m .49954 .82324 L .50025 .82156 L F
.50025 .82156 m .50073 .82109 L .49894 .82294 L F
.27 0 .274 r
.4978 .82406 m .49788 .82412 L .50073 .82109 L F
0 .072 .634 r
.498 .824 m .49788 .82412 L .49774 .82385 L F
.49788 .82412 m .4978 .82406 L .49774 .82385 L F
.49753 .82306 m .498 .824 L .49704 .82345 L F
.527 .504 .774 r
.49535 .82528 m .50009 .829 L .49871 .82541 L F
.87 .779 .759 r
.50009 .82933 m .50091 .82845 L .50025 .82889 L F
.418 .277 .58 r
.50033 .8292 m .49985 .82998 L .50066 .8278 L F
.527 .504 .774 r
.50009 .829 m .50033 .8292 L .50021 .82892 L F
.50009 .829 m .50021 .82892 L .49871 .82541 L F
.87 .779 .759 r
.50009 .82933 m .50176 .83074 L .50091 .82845 L F
.50025 .82889 m .50091 .82845 L .50066 .8278 L F
.49985 .82998 m .5001 .83008 L .50009 .82933 L F
.5001 .83008 m .50176 .83074 L .50009 .82933 L F
.527 .504 .774 r
.49535 .82528 m .49691 .8301 L .50009 .82926 L F
.50009 .829 m .50009 .82926 L .50033 .8292 L F
.49535 .82528 m .50009 .82926 L .50009 .829 L F
.49691 .8301 m .49691 .83011 L .49693 .83011 L F
.49691 .8301 m .49693 .83011 L .50033 .8292 L F
.49691 .83011 m .49693 .83018 L .49702 .83016 L F
.49691 .83011 m .49702 .83016 L .50033 .8292 L F
.573 .225 .34 r
.49564 .82701 m .49454 .82922 L .49296 .82873 L F
.714 .615 .745 r
.49346 .82813 m .4968 .8301 L .49535 .82528 L F
.4968 .8301 m .49693 .83018 L .49691 .83011 L F
.4968 .8301 m .49691 .83011 L .49535 .82528 L F
.353 0 .11 r
.49702 .83016 m .49985 .82998 L .50033 .8292 L F
.49693 .83018 m .49705 .83018 L .49702 .83016 L F
.645 .219 .221 r
.49717 .83014 m .49713 .83023 L .49696 .83012 L F
.353 0 .11 r
.49705 .83018 m .49985 .82998 L .49702 .83016 L F
.645 .219 .221 r
.49696 .83012 m .49713 .83023 L .4968 .8301 L F
.49713 .83023 m .49713 .83023 L .49705 .83018 L F
.49713 .83023 m .49705 .83018 L .49705 .83018 L F
.353 0 .11 r
.49705 .83018 m .49663 .83124 L .49985 .82998 L F
.49693 .83018 m .49663 .83124 L .49705 .83018 L F
.645 .219 .221 r
.49705 .83018 m .49705 .83018 L .49696 .83012 L F
.653 .215 .197 r
.49454 .82922 m .49693 .83018 L .4968 .8301 L F
.49454 .82922 m .49663 .83124 L .49693 .83018 L F
.645 .219 .221 r
.49713 .83023 m .49663 .83124 L .49454 .82922 L F
.653 .215 .197 r
.49454 .82922 m .4968 .8301 L .49617 .82973 L F
.49454 .82922 m .49617 .82973 L .49346 .82813 L F
.573 .225 .34 r
.49296 .82873 m .49454 .82922 L .4923 .82916 L F
.746 .866 .935 r
.33414 .66896 m .33566 .66982 L .33658 .66856 L F
.559 .888 .988 r
.36971 .72563 m .37028 .7246 L .37128 .72504 L F
.36971 .72563 m .36812 .72526 L .37028 .7246 L F
0 .092 .639 r
.6261 .73496 m .62679 .73673 L .62754 .73676 L F
0 0 0 r
.62679 .73673 m .62511 .73817 L .62754 .73676 L F
.74 .874 .458 r
.62164 .79971 m .62121 .80092 L .62273 .79806 L F
.735 .863 .439 r
.62018 .8025 m .62121 .80092 L .62164 .79971 L F
.612 .403 .574 r
.38767 .87397 m .39015 .87152 L .38778 .87163 L F
.836 .926 .892 r
.4802 .86877 m .47635 .87079 L .47888 .8686 L F
.122 0 0 r
.48197 .86904 m .4802 .86877 L .47888 .8686 L F
.712 .396 0 r
.56487 .84268 m .56559 .84486 L .56535 .84438 L F
.56487 .84268 m .56535 .84438 L .5649 .84191 L F
.631 .361 .492 r
.43534 .83172 m .43875 .82924 L .43636 .82938 L F
.707 .619 .757 r
.62916 .76385 m .63063 .7673 L .62696 .76635 L F
.73 .621 .737 r
.62916 .76385 m .63174 .76621 L .63063 .7673 L F
.571 .088 .07 r
.50594 .88093 m .50713 .87976 L .51002 .88099 L F
.393 .04 .242 r
.36072 .78504 m .36154 .7868 L .36281 .78481 L F
.36072 .78504 m .35963 .78724 L .36154 .7868 L F
.473 .309 .577 r
.52899 .82963 m .52899 .83206 L .53074 .83093 L F
.52899 .82963 m .52899 .83206 L .53074 .83093 L F
.787 .538 0 r
.56323 .80253 m .56363 .80415 L .56295 .8007 L F
.794 .682 .74 r
.56295 .8007 m .56363 .80415 L .56469 .80142 L F
0 0 .494 r
.56434 .80539 m .56363 .80415 L .56323 .80253 L F
.787 .538 0 r
.56323 .80253 m .56363 .80415 L .56295 .8007 L F
.943 .595 .324 r
.37306 .88392 m .37387 .88275 L .37252 .88258 L F
.37306 .88392 m .3743 .88445 L .37387 .88275 L F
.544 0 0 r
.38032 .72653 m .3822 .72726 L .38382 .72714 L F
.189 .706 .884 r
.3822 .72726 m .38528 .72743 L .38382 .72714 L F
.527 .5 .77 r
.4856 .84007 m .48826 .84053 L .48877 .83885 L F
.4856 .84007 m .48877 .83885 L .48878 .83882 L F
0 0 0 r
.4856 .84007 m .48575 .84006 L .48579 .84 L F
.4856 .84007 m .48579 .84 L .48581 .83996 L F
.412 .809 .985 r
.39497 .89421 m .39547 .89345 L .39401 .89387 L F
.452 .14 .345 r
.40582 .76706 m .40539 .76863 L .40335 .76899 L F
.489 .156 .328 r
.4081 .76688 m .40539 .76863 L .40582 .76706 L F
0 0 .303 r
.55546 .83957 m .55492 .84033 L .55554 .83732 L F
.875 .493 .019 r
.55535 .84237 m .55569 .84224 L .55492 .84033 L F
.55535 .84237 m .55492 .84033 L .55546 .83957 L F
.796 .744 .804 r
.3745 .8872 m .37554 .88734 L .37681 .88486 L F
.789 .567 .6 r
.37458 .88963 m .37554 .88734 L .3745 .8872 L F
.37458 .88963 m .37541 .88971 L .37554 .88734 L F
.692 .61 .76 r
.37554 .88734 m .37762 .88752 L .37681 .88486 L F
.766 .594 .665 r
.37541 .88971 m .37762 .88752 L .37554 .88734 L F
.881 .992 .778 r
.67126 .75816 m .66966 .76109 L .6714 .76013 L F
.67126 .75816 m .66903 .76102 L .66966 .76109 L F
.36 0 .098 r
.56873 .77392 m .57039 .77428 L .57115 .77357 L F
.56873 .77392 m .56828 .77468 L .57039 .77428 L F
.835 .448 .318 r
.56005 .82175 m .56317 .82434 L .56172 .82173 L F
.738 .615 .721 r
.53389 .8162 m .53203 .81901 L .53254 .81712 L F
.691 .565 .708 r
.40053 .8556 m .40139 .85855 L .40351 .85587 L F
.688 .432 .53 r
.46394 .85575 m .46046 .85811 L .46051 .85573 L F
.46394 .85575 m .46426 .85823 L .46046 .85811 L F
.77 .491 .512 r
.46394 .85575 m .46609 .85871 L .46426 .85823 L F
.428 .431 .76 r
.68512 .70672 m .68758 .70828 L .68685 .70547 L F
.563 .314 .496 r
.41301 .7651 m .41089 .76341 L .41305 .76339 L F
.41301 .7651 m .41001 .76648 L .41089 .76341 L F
.124 .511 .911 r
.65843 .75153 m .65718 .75168 L .65639 .75124 L F
.65843 .75153 m .65933 .75253 L .65718 .75168 L F
.592 .797 .978 r
.70156 .71024 m .70258 .71129 L .69945 .71082 L F
.688 .834 .953 r
.70489 .71044 m .70258 .71129 L .70156 .71024 L F
.835 .745 .765 r
.61204 .78942 m .61377 .79055 L .61241 .79194 L F
.551 .361 .577 r
.38556 .87659 m .38767 .87397 L .38564 .87422 L F
.495 .121 .259 r
.51725 .85521 m .51551 .85473 L .5153 .85465 L F
.908 .683 .585 r
.52197 .83233 m .52038 .83348 L .52248 .83148 L F
.52197 .83233 m .52162 .83467 L .52038 .83348 L F
.732 .95 .949 r
.38189 .91959 m .38238 .91813 L .38056 .91903 L F
.38189 .91959 m .38422 .91839 L .38238 .91813 L F
0 0 0 r
.5416 .8268 m .54069 .82862 L .54019 .82942 L F
.219 .592 .947 r
.54069 .82862 m .54173 .82964 L .54019 .82942 L F
.576 .442 .661 r
.53909 .84212 m .53669 .84008 L .53917 .8397 L F
.53909 .84212 m .53692 .84279 L .53669 .84008 L F
.609 .373 .534 r
.38831 .7662 m .39117 .7635 L .38844 .76406 L F
.838 .785 .8 r
.69412 .72622 m .69749 .7247 L .69681 .72412 L F
.899 .964 .823 r
.69681 .72412 m .69749 .7247 L .69952 .72207 L F
.559 .078 .069 r
.5776 .77749 m .57335 .7787 L .57187 .7786 L F
.375 .766 .988 r
.40183 .73815 m .40392 .73802 L .40534 .73867 L F
.542 .839 .999 r
.40534 .73867 m .40602 .73754 L .40726 .738 L F
.40534 .73867 m .40392 .73802 L .40602 .73754 L F
.671 .383 .475 r
.45511 .85604 m .45194 .858 L .45312 .85567 L F
.45511 .85604 m .45515 .85793 L .45194 .858 L F
.719 .486 .572 r
.45829 .85596 m .45515 .85793 L .45511 .85604 L F
.531 .922 .878 r
.59353 .84681 m .59797 .84533 L .59443 .84764 L F
0 0 0 r
.59797 .84533 m .60023 .84286 L .59913 .8446 L F
.59443 .84764 m .59797 .84533 L .59913 .8446 L F
.509 .686 .946 r
.39502 .74594 m .39927 .74807 L .39648 .74581 L F
.449 .67 .958 r
.39927 .74807 m .39941 .7465 L .39648 .74581 L F
.39927 .74807 m .40084 .7478 L .39941 .7465 L F
0 0 .297 r
.56795 .80439 m .56736 .80557 L .56687 .80576 L F
.201 .658 .944 r
.56434 .80539 m .56687 .80576 L .56703 .80628 L F
.873 .888 .461 r
.56687 .80576 m .56625 .80775 L .56703 .80628 L F
0 0 .297 r
.56736 .80557 m .56625 .80775 L .56687 .80576 L F
.201 .658 .944 r
.56621 .80601 m .56687 .80576 L .56703 .80628 L F
.56434 .80539 m .56687 .80576 L .56621 .80601 L F
.686 .325 .357 r
.56625 .80775 m .56772 .80782 L .56703 .80628 L F
.513 .073 .139 r
.4935 .82039 m .49545 .82077 L .49658 .81921 L F
.782 .389 .31 r
.49545 .82077 m .49894 .82219 L .49658 .81921 L F
.639 .492 .667 r
.40351 .85587 m .40139 .85855 L .40363 .85828 L F
.585 .465 .683 r
.40139 .85855 m .40373 .86058 L .40363 .85828 L F
.40139 .85855 m .40169 .86102 L .40373 .86058 L F
.4 .854 .809 r
.5074 .86064 m .50585 .86132 L .50468 .86156 L F
.50468 .86156 m .50585 .86132 L .5074 .86064 L F
.727 .771 .888 r
.67645 .7139 m .6738 .71473 L .67241 .71396 L F
.878 .683 .635 r
.6738 .71473 m .67233 .71603 L .67241 .71396 L F
.785 .488 .485 r
.67949 .75613 m .67722 .75785 L .67777 .75745 L F
.67949 .75613 m .67957 .7578 L .67722 .75785 L F
.486 .02 .073 r
.67949 .75613 m .68215 .75636 L .68119 .75766 L F
.404 .801 .986 r
.54619 .83938 m .54775 .83997 L .54953 .83962 L F
.537 .508 .771 r
.54775 .83997 m .55123 .84292 L .54953 .83962 L F
.084 .612 .872 r
.47815 .8844 m .48024 .88468 L .47701 .88398 L F
.582 .4 .6 r
.62062 .76105 m .61815 .76412 L .61794 .76121 L F
.377 0 0 r
.69156 .71853 m .69609 .71946 L .69515 .7166 L F
.339 .431 .809 r
.69515 .7166 m .69609 .71946 L .69755 .71829 L F
.342 .438 .814 r
.69609 .71946 m .69858 .72098 L .69755 .71829 L F
.714 .826 .934 r
.69672 .72237 m .69858 .72098 L .69609 .71946 L F
.62 .384 .538 r
.52949 .84561 m .52948 .84778 L .52707 .84777 L F
.555 .297 .479 r
.53248 .84503 m .52948 .84778 L .52949 .84561 L F
.698 .577 .715 r
.68409 .70348 m .68262 .70502 L .68208 .70396 L F
.766 .594 .665 r
.37541 .88971 m .37783 .88999 L .37762 .88752 L F
.634 .576 .771 r
.37681 .88486 m .37762 .88752 L .37978 .88724 L F
.563 .408 .63 r
.37783 .88999 m .37978 .88724 L .37762 .88752 L F
.503 .787 .996 r
.45037 .88364 m .45347 .88416 L .45194 .88355 L F
.48 .76 .992 r
.45347 .88416 m .45438 .88329 L .45194 .88355 L F
.45347 .88416 m .45529 .88401 L .45438 .88329 L F
.857 .69 .675 r
.61525 .77681 m .61644 .77975 L .61489 .77895 L F
.91 .766 .69 r
.61502 .78211 m .61489 .77895 L .61644 .77975 L F
.716 .63 .76 r
.61865 .77731 m .61644 .77975 L .61525 .77681 L F
.746 .624 .723 r
.53254 .81712 m .53203 .81901 L .52875 .81876 L F
0 .12 .645 r
.56288 .82883 m .5631 .83139 L .56309 .83157 L F
.705 .362 0 r
.56309 .83157 m .5631 .83139 L .56421 .83432 L F
.305 0 0 r
.48986 .84146 m .48832 .84293 L .48706 .84254 L F
.956 .684 .481 r
.48826 .84053 m .48832 .84293 L .48986 .84146 L F
.281 .035 .352 r
.60176 .84192 m .60023 .84286 L .6024 .84013 L F
0 0 0 r
.59913 .8446 m .60023 .84286 L .60176 .84192 L F
.19 .717 .719 r
.49171 .88355 m .49274 .88327 L .49095 .88335 L F
.382 .493 .848 r
.47773 .85184 m .47932 .85332 L .47678 .85301 L F
.555 .327 .525 r
.37237 .77701 m .37449 .77675 L .37478 .77456 L F
.509 .288 .514 r
.37478 .77456 m .37646 .77637 L .37677 .7742 L F
.37478 .77456 m .37449 .77675 L .37646 .77637 L F
.757 .41 0 r
.58117 .77967 m .58083 .77921 L .58075 .77887 L F
.865 .429 .168 r
.58318 .78134 m .58083 .77921 L .58117 .77967 L F
.678 .32 .36 r
.50438 .8429 m .50133 .84437 L .5011 .84287 L F
.50438 .8429 m .50335 .84485 L .50133 .84437 L F
.668 .309 .354 r
.50652 .8447 m .50335 .84485 L .50438 .8429 L F
0 .045 .613 r
.66699 .71042 m .66717 .71146 L .66595 .70875 L F
0 .196 .719 r
.66869 .71223 m .66717 .71146 L .66699 .71042 L F
.66869 .71223 m .66937 .71339 L .66717 .71146 L F
.714 .826 .934 r
.69672 .72237 m .69952 .72207 L .69858 .72098 L F
.899 .964 .823 r
.69681 .72412 m .69952 .72207 L .69672 .72237 L F
.761 .84 .911 r
.69858 .72098 m .69952 .72207 L .7014 .72102 L F
.998 .782 .456 r
.56317 .82434 m .56301 .82667 L .56228 .82603 L F
.91 .538 .096 r
.56172 .82173 m .56317 .82434 L .56249 .8238 L F
.999 .799 .458 r
.56249 .8238 m .56317 .82434 L .56228 .82603 L F
.727 .609 .726 r
.55354 .79154 m .55637 .79546 L .55642 .79248 L F
.55354 .79154 m .55642 .79248 L .55522 .79249 L F
.724 .213 .005 r
.55209 .79055 m .55522 .79249 L .55642 .79248 L F
.086 0 0 r
.65929 .76595 m .66127 .76547 L .6593 .76615 L F
.064 0 .348 r
.55013 .78985 m .55025 .79051 L .55082 .78957 L F
.55013 .78985 m .55025 .79051 L .55082 .78957 L F
.531 .325 .546 r
.62829 .74656 m .62398 .74775 L .62514 .74571 L F
.603 .628 .848 r
.39853 .73545 m .39657 .73614 L .39544 .73438 L F
.162 0 0 r
.51455 .87599 m .51128 .87534 L .51386 .87676 L F
.245 .756 .858 r
.51533 .87565 m .51455 .87599 L .51386 .87676 L F
.51533 .87565 m .51676 .87568 L .51455 .87599 L F
.903 .501 .096 r
.43246 .89072 m .43416 .8929 L .43199 .88959 L F
.617 .262 .346 r
.5863 .77954 m .58529 .78172 L .58318 .78134 L F
.599 .243 .337 r
.58942 .78117 m .5863 .77954 L .58851 .77929 L F
.58942 .78117 m .58529 .78172 L .5863 .77954 L F
.559 .034 0 r
.53187 .80801 m .53398 .80852 L .53561 .80814 L F
.598 .122 .095 r
.53398 .80852 m .53697 .80866 L .53561 .80814 L F
.801 .329 .1 r
.69904 .74507 m .70113 .74733 L .70194 .74681 L F
.088 0 0 r
.70194 .74681 m .70113 .74733 L .70346 .74686 L F
.643 .447 .603 r
.41441 .84509 m .4172 .84517 L .41708 .84275 L F
.586 .411 .611 r
.41708 .84275 m .41924 .84261 L .41926 .84006 L F
.667 .466 .603 r
.41708 .84275 m .41946 .84497 L .41924 .84261 L F
.41708 .84275 m .4172 .84517 L .41946 .84497 L F
.733 .855 .938 r
.65138 .76788 m .64818 .76825 L .64938 .76857 L F
.724 .537 .638 r
.50778 .83512 m .50832 .83712 L .51054 .83502 L F
.608 .606 .823 r
.51054 .83502 m .51339 .83633 L .51368 .83484 L F
.629 .207 .223 r
.35783 .75289 m .35492 .75294 L .35601 .75164 L F
.541 .457 .71 r
.42385 .75283 m .4215 .75087 L .42375 .75041 L F
.025 0 0 r
.4215 .75087 m .42221 .75096 L .42375 .75041 L F
.4215 .75087 m .42039 .75133 L .42221 .75096 L F
.541 .457 .71 r
.42385 .75283 m .422 .75316 L .4215 .75087 L F
.737 .438 .474 r
.54452 .78476 m .54544 .78534 L .54609 .78447 L F
0 0 0 r
.54609 .78447 m .54544 .78534 L .54556 .78523 L F
.706 .367 .4 r
.54556 .78523 m .54552 .78674 L .54509 .7859 L F
.54609 .78447 m .54595 .78505 L .54556 .78523 L F
.54595 .78505 m .54552 .78674 L .54556 .78523 L F
0 0 0 r
.54609 .78447 m .54814 .78273 L .54845 .78451 L F
.238 0 .247 r
.54712 .78597 m .54629 .78475 L .54845 .78451 L F
.54629 .78475 m .54609 .78447 L .5468 .78448 L F
.54629 .78475 m .5468 .78448 L .54845 .78451 L F
.54712 .78597 m .54552 .78674 L .54609 .78447 L F
0 0 0 r
.54609 .78447 m .54571 .78501 L .54814 .78273 L F
.54571 .78501 m .54556 .78523 L .54814 .78273 L F
.54396 .78499 m .54814 .78273 L .54578 .78502 L F
.54536 .78533 m .54556 .78523 L .54544 .78534 L F
.706 .367 .4 r
.54609 .78447 m .54509 .7859 L .54452 .78476 L F
0 0 0 r
.54541 .78521 m .54578 .78502 L .54556 .78523 L F
.817 .366 0 r
.54452 .78476 m .54552 .78674 L .54446 .7857 L F
.58 .006 0 r
.54452 .78476 m .54396 .78499 L .54544 .78534 L F
0 0 0 r
.54396 .78499 m .54578 .78502 L .54541 .78521 L F
.54396 .78499 m .54556 .78523 L .54536 .78533 L F
.444 .864 .947 r
.38422 .91839 m .38661 .91774 L .38497 .91748 L F
.655 .334 .417 r
.50623 .819 m .51019 .81917 L .50954 .81695 L F
.606 .306 .434 r
.50954 .81695 m .51019 .81917 L .51166 .81834 L F
.59 .319 .474 r
.50954 .81695 m .51166 .81834 L .51205 .81668 L F
.768 .418 .392 r
.4992 .84247 m .49749 .84277 L .4963 .84198 L F
.762 .407 .381 r
.4992 .84247 m .49798 .84444 L .49749 .84277 L F
.675 .3 .328 r
.50133 .84437 m .4992 .84247 L .5011 .84287 L F
.50133 .84437 m .49798 .84444 L .4992 .84247 L F
.776 .576 .629 r
.51928 .82667 m .5225 .82437 L .51951 .82411 L F
.51928 .82667 m .52229 .82687 L .5225 .82437 L F
.498 .333 .587 r
.52229 .82687 m .52474 .8268 L .5225 .82437 L F
.511 .336 .58 r
.33143 .67733 m .33128 .67943 L .32947 .68002 L F
.56 .393 .611 r
.33128 .67943 m .32938 .68228 L .32947 .68002 L F
.682 .976 .811 r
.64088 .72597 m .643 .72491 L .64161 .72585 L F
.444 0 0 r
.47262 .87108 m .46949 .87037 L .47135 .87121 L F
0 .397 .716 r
.47356 .87133 m .47262 .87108 L .47135 .87121 L F
.47356 .87133 m .47498 .87187 L .47262 .87108 L F
.704 .314 .307 r
.43373 .88516 m .43299 .88717 L .43063 .88655 L F
.244 0 .131 r
.43493 .88642 m .43373 .88516 L .43528 .88586 L F
.43493 .88642 m .43299 .88717 L .43373 .88516 L F
.73 .621 .737 r
.62916 .76385 m .63307 .76463 L .63174 .76621 L F
0 0 .386 r
.6841 .74442 m .68322 .74568 L .68329 .74317 L F
.6841 .74442 m .68329 .74317 L .68155 .74259 L F
.173 0 .31 r
.6261 .73496 m .62728 .73452 L .62798 .73241 L F
0 .092 .639 r
.6261 .73496 m .62754 .73676 L .62728 .73452 L F
.336 .026 .284 r
.65166 .72778 m .65111 .72918 L .64924 .72993 L F
.434 .251 .532 r
.65359 .72461 m .6535 .72684 L .65166 .72778 L F
.571 .36 .555 r
.6535 .72684 m .65111 .72918 L .65166 .72778 L F
.163 .042 .457 r
.61302 .81632 m .61468 .81325 L .6142 .81554 L F
.051 0 .413 r
.61342 .81864 m .61302 .81632 L .6142 .81554 L F
.059 0 0 r
.38363 .7474 m .38217 .7476 L .38418 .74699 L F
.38363 .7474 m .38197 .74811 L .38217 .7476 L F
.644 .456 .613 r
.57555 .82939 m .57576 .83198 L .57318 .83221 L F
.407 .517 .857 r
.57661 .82894 m .57555 .82939 L .57404 .82662 L F
.258 .133 .512 r
.57709 .83186 m .57555 .82939 L .57661 .82894 L F
.166 .101 .534 r
.57709 .83186 m .57576 .83198 L .57565 .83057 L F
.57709 .83186 m .57565 .83057 L .57631 .83062 L F
.318 .447 .834 r
.57609 .83455 m .57318 .83221 L .57576 .83198 L F
.313 .226 .595 r
.57732 .83386 m .57576 .83198 L .57709 .83186 L F
.57732 .83386 m .57609 .83455 L .57576 .83198 L F
.258 .133 .512 r
.57709 .83186 m .57687 .83057 L .57705 .83074 L F
.57687 .83057 m .57661 .82894 L .57705 .83074 L F
.981 .772 .548 r
.57705 .83074 m .57732 .83386 L .57709 .83186 L F
.683 .658 .82 r
.57712 .83073 m .57732 .83386 L .57705 .83074 L F
.57833 .83053 m .57803 .83151 L .57712 .83073 L F
.57803 .83151 m .57732 .83386 L .57712 .83073 L F
.306 .466 .856 r
.5785 .83676 m .57609 .83455 L .57732 .83386 L F
.784 .758 .83 r
.5797 .83331 m .5785 .83676 L .57732 .83386 L F
.683 .658 .82 r
.57803 .83151 m .57901 .83257 L .57732 .83386 L F
.57901 .83257 m .57856 .83357 L .57732 .83386 L F
.57881 .83151 m .5797 .83331 L .57803 .83151 L F
.62 .254 .326 r
.57744 .83491 m .57899 .83233 L .5753 .83305 L F
.57899 .83233 m .57831 .83175 L .5753 .83305 L F
.871 .728 .701 r
.58001 .83134 m .5797 .83331 L .57881 .83151 L F
.57951 .8311 m .57881 .83151 L .57833 .83053 L F
.58001 .83134 m .57881 .83151 L .57951 .8311 L F
.62 .254 .326 r
.57899 .83233 m .5795 .8315 L .57844 .83172 L F
.57835 .83178 m .57844 .83172 L .57831 .83175 L F
.57899 .83233 m .57844 .83172 L .57835 .83178 L F
.763 .874 .45 r
.579 .83177 m .57962 .83123 L .57744 .83491 L F
.62 .254 .326 r
.5795 .8315 m .57971 .83115 L .57888 .8315 L F
.763 .874 .45 r
.57962 .83123 m .57971 .83115 L .5795 .8315 L F
.57962 .83123 m .5795 .8315 L .57744 .83491 L F
.683 .658 .82 r
.57901 .83257 m .5797 .83331 L .57856 .83357 L F
.57833 .83053 m .57881 .83151 L .57803 .83151 L F
.62 .254 .326 r
.5795 .8315 m .57888 .8315 L .57831 .83175 L F
.835 .71 .726 r
.5753 .83305 m .57753 .83119 L .57705 .83074 L F
.57753 .83119 m .57806 .83075 L .57705 .83074 L F
.57806 .83075 m .57833 .83053 L .57732 .8307 L F
.57806 .83075 m .57732 .8307 L .57705 .83074 L F
.166 .101 .534 r
.57631 .83062 m .57565 .83057 L .57555 .82939 L F
.6 .437 .632 r
.422 .75316 m .42212 .75556 L .41982 .75605 L F
.585 .389 .582 r
.42252 .75743 m .41982 .75605 L .42212 .75556 L F
.42252 .75743 m .41971 .7585 L .41982 .75605 L F
.584 .273 .407 r
.52436 .8132 m .52669 .81312 L .52737 .81062 L F
.523 .393 .645 r
.52737 .81062 m .52913 .81072 L .52931 .80854 L F
.522 .221 .398 r
.52669 .81312 m .52913 .81072 L .52737 .81062 L F
.79 .292 0 r
.55814 .81341 m .55498 .81075 L .55677 .81185 L F
.622 .351 .485 r
.47078 .8283 m .47293 .82891 L .4709 .82695 L F
.624 .35 .482 r
.4709 .82695 m .47293 .82891 L .47311 .82702 L F
.714 .753 .883 r
.62372 .7532 m .62136 .75538 L .6218 .75449 L F
.627 .59 .792 r
.62372 .7532 m .62495 .75635 L .62136 .75538 L F
.899 .497 .235 r
.55959 .81636 m .55935 .81837 L .55889 .81596 L F
.55959 .81636 m .56058 .81879 L .55935 .81837 L F
.869 .5 .346 r
.56065 .79982 m .56097 .79813 L .55959 .79806 L F
.56065 .79982 m .56295 .8007 L .56097 .79813 L F
.581 .224 .328 r
.45272 .8324 m .45466 .83391 L .45572 .8318 L F
.678 .357 .423 r
.45466 .83391 m .45804 .83206 L .45572 .8318 L F
.727 .771 .888 r
.67645 .7139 m .67241 .71396 L .67441 .71172 L F
.081 .425 .87 r
.67441 .71172 m .67724 .71339 L .67645 .7139 L F
.944 .621 .389 r
.6753 .71551 m .67671 .71645 L .67645 .7139 L F
.6753 .71551 m .67645 .7139 L .67724 .71339 L F
.538 .51 .772 r
.65359 .72461 m .65551 .72408 L .6528 .72361 L F
.6528 .72361 m .65551 .72408 L .65359 .72461 L F
.65359 .72461 m .65551 .72408 L .6528 .72361 L F
.522 .783 .992 r
.3648 .72511 m .36416 .72637 L .36281 .72508 L F
.3648 .72511 m .36611 .72602 L .36416 .72637 L F
0 0 0 r
.65512 .75638 m .65264 .75844 L .65419 .7572 L F
.68 .374 .449 r
.65419 .7572 m .65713 .75575 L .65512 .75638 L F
.611 .431 .614 r
.41926 .84006 m .42145 .84231 L .42155 .83992 L F
.41926 .84006 m .41924 .84261 L .42145 .84231 L F
.394 0 .08 r
.63599 .72386 m .63837 .72375 L .63931 .72199 L F
.044 .125 .625 r
.63872 .71918 m .63931 .72199 L .64046 .72101 L F
0 0 0 r
.63931 .72199 m .63837 .72375 L .64046 .72101 L F
.479 .892 .788 r
.71157 .7402 m .713 .7396 L .71174 .74035 L F
.684 .94 .654 r
.71157 .7402 m .71174 .74035 L .71053 .74131 L F
.118 0 .395 r
.713 .7396 m .71182 .74265 L .71174 .74035 L F
.508 .419 .691 r
.41286 .73951 m .41371 .74332 L .41143 .74319 L F
.501 .464 .748 r
.41371 .74332 m .41394 .74498 L .41143 .74319 L F
.566 .457 .688 r
.41143 .74319 m .41394 .74498 L .41188 .74532 L F
0 0 0 r
.6024 .84013 m .60446 .83748 L .60369 .83922 L F
0 0 .147 r
.60176 .84192 m .6024 .84013 L .60369 .83922 L F
.971 .678 .411 r
.68117 .73241 m .6802 .73196 L .67991 .72963 L F
.949 .673 .481 r
.68117 .73241 m .68008 .73399 L .6802 .73196 L F
.68117 .73241 m .68176 .73522 L .68008 .73399 L F
.795 .73 .792 r
.62696 .76635 m .62388 .76629 L .62603 .76367 L F
.798 .715 .772 r
.62696 .76635 m .62483 .76904 L .62388 .76629 L F
.765 .715 .806 r
.62916 .76385 m .62696 .76635 L .62603 .76367 L F
.527 .262 .456 r
.39879 .77192 m .39818 .77415 L .39612 .77442 L F
.53 .271 .467 r
.40084 .7715 m .39818 .77415 L .39879 .77192 L F
.637 .47 .64 r
.40363 .85828 m .40582 .85567 L .40351 .85587 L F
.829 .929 .898 r
.63917 .77401 m .64256 .77259 L .64063 .77305 L F
.774 .936 .935 r
.64256 .77259 m .64324 .77079 L .64063 .77305 L F
.64256 .77259 m .64425 .77127 L .64324 .77079 L F
.736 .597 .702 r
.6402 .71643 m .64223 .71728 L .64065 .71418 L F
.555 .276 .447 r
.37866 .77378 m .38155 .77118 L .37952 .77138 L F
.438 .721 .985 r
.5957 .76561 m .59441 .76615 L .5933 .76626 L F
.5957 .76561 m .59708 .76658 L .59441 .76615 L F
.364 0 0 r
.3446 .72884 m .34665 .72894 L .34814 .72818 L F
0 0 0 r
.34814 .72818 m .34859 .72839 L .35016 .72778 L F
.34814 .72818 m .34665 .72894 L .34859 .72839 L F
.629 .47 .648 r
.40816 .85321 m .41078 .8532 L .41024 .85033 L F
.674 .543 .697 r
.41024 .85033 m .41301 .85044 L .41235 .84779 L F
.626 .468 .649 r
.41024 .85033 m .41298 .85289 L .41301 .85044 L F
.41024 .85033 m .41078 .8532 L .41298 .85289 L F
.142 .207 .671 r
.62398 .74775 m .62544 .75016 L .62433 .74906 L F
.413 .241 .537 r
.62544 .75016 m .62372 .7532 L .62433 .74906 L F
.586 .86 .995 r
.49495 .87514 m .49192 .87517 L .49397 .87436 L F
.362 0 0 r
.49604 .87594 m .49743 .87516 L .49495 .87514 L F
.49604 .87594 m .49495 .87514 L .49397 .87436 L F
.556 .138 .205 r
.3615 .75153 m .36024 .75316 L .35783 .75289 L F
.215 0 0 r
.36182 .75266 m .3615 .75153 L .36346 .75128 L F
.36182 .75266 m .36024 .75316 L .3615 .75153 L F
.555 .308 .496 r
.41776 .75898 m .41736 .76103 L .41523 .76127 L F
.579 .365 .554 r
.41971 .7585 m .41736 .76103 L .41776 .75898 L F
.631 .439 .605 r
.40582 .85567 m .4081 .85559 L .40816 .85321 L F
.668 .502 .651 r
.4081 .85559 m .41078 .8532 L .40816 .85321 L F
.531 .325 .546 r
.62829 .74656 m .62738 .74785 L .62398 .74775 L F
.555 .397 .623 r
.62738 .74785 m .62544 .75016 L .62398 .74775 L F
0 0 0 r
.57147 .81625 m .57235 .81413 L .57293 .81282 L F
.851 .734 .733 r
.66952 .73743 m .66862 .73447 L .66867 .7356 L F
.372 .819 .945 r
.35016 .72778 m .35213 .72739 L .35357 .72765 L F
.374 .82 .946 r
.35357 .72765 m .35388 .72705 L .35546 .72697 L F
.35357 .72765 m .35213 .72739 L .35388 .72705 L F
.471 .292 .556 r
.71481 .72957 m .71285 .73277 L .71477 .73202 L F
.71477 .73202 m .71285 .73277 L .71481 .72957 L F
.674 .763 .277 r
.62273 .79806 m .62409 .79458 L .62269 .79762 L F
.806 .898 .487 r
.62164 .79971 m .62273 .79806 L .62269 .79762 L F
.734 .611 .721 r
.63125 .76118 m .63307 .76463 L .62916 .76385 L F
.712 .658 .794 r
.49556 .84879 m .49139 .84803 L .49541 .84915 L F
.632 .287 .369 r
.49541 .84915 m .49776 .84746 L .49556 .84879 L F
.769 .7 .786 r
.62388 .76629 m .62483 .76904 L .62165 .7688 L F
.748 .576 .662 r
.3743 .88445 m .37681 .88486 L .37613 .88201 L F
0 0 .244 r
.67027 .72345 m .67115 .72635 L .67128 .72707 L F
0 0 .406 r
.67211 .72834 m .67227 .72937 L .67128 .72707 L F
.903 .891 .808 r
.56641 .81845 m .56753 .81905 L .56966 .81577 L F
.233 .647 .959 r
.56846 .8185 m .56753 .81905 L .56641 .81845 L F
.56846 .8185 m .57006 .81944 L .56753 .81905 L F
.548 .409 .644 r
.42385 .75283 m .42212 .75556 L .422 .75316 L F
.201 .729 .821 r
.40932 .73774 m .41263 .73746 L .41051 .73816 L F
.497 .505 .795 r
.41286 .73951 m .41051 .73816 L .41263 .73746 L F
.953 .949 .715 r
.59642 .8198 m .59772 .81912 L .59611 .82222 L F
.857 .826 .816 r
.59842 .81569 m .59772 .81912 L .59731 .81905 L F
.59842 .81569 m .59978 .81644 L .59772 .81912 L F
.709 .975 .759 r
.59731 .81905 m .59772 .81912 L .59642 .8198 L F
.676 .582 .742 r
.57327 .83622 m .57218 .8401 L .57158 .83779 L F
.519 .249 .446 r
.36842 .79422 m .37043 .79279 L .37202 .79422 L F
.427 .117 .334 r
.36842 .79422 m .37043 .79279 L .37238 .79228 L F
.288 0 0 r
.45036 .83151 m .45106 .83181 L .45272 .8324 L F
.004 .254 .759 r
.45324 .83123 m .45272 .8324 L .45106 .83181 L F
.45324 .83123 m .45466 .83391 L .45272 .8324 L F
.649 .599 .785 r
.51767 .85419 m .51991 .85326 L .51909 .85001 L F
.694 .49 .608 r
.51991 .85326 m .51725 .85521 L .51767 .85419 L F
.446 .862 .952 r
.42727 .88663 m .42667 .88735 L .42853 .88681 L F
.227 0 0 r
.48024 .88468 m .48486 .88385 L .48233 .88473 L F
.476 0 .039 r
.48233 .88473 m .48486 .88385 L .48563 .88418 L F
.947 .623 .384 r
.68329 .73781 m .68245 .73936 L .682 .73716 L F
.895 .534 .35 r
.684 .73982 m .68245 .73936 L .68329 .73781 L F
.641 .621 .814 r
.37807 .89403 m .37945 .89587 L .3814 .89518 L F
.416 .395 .727 r
.45215 .8596 m .45093 .86205 L .44997 .85986 L F
.823 .401 .24 r
.52436 .83624 m .52162 .83467 L .52377 .83548 L F
.52436 .83624 m .52341 .83729 L .52162 .83467 L F
.103 .131 .605 r
.52267 .83993 m .52341 .83729 L .52436 .83624 L F
0 0 0 r
.60513 .83623 m .60446 .83748 L .60581 .83433 L F
.60369 .83922 m .60446 .83748 L .60513 .83623 L F
.615 .409 .579 r
.39229 .86883 m .39477 .86884 L .39489 .8663 L F
.644 .433 .583 r
.39489 .8663 m .39704 .86858 L .39708 .86612 L F
.39489 .8663 m .39477 .86884 L .39704 .86858 L F
.904 .899 .812 r
.52875 .81876 m .52675 .82206 L .52545 .82104 L F
.234 0 0 r
.37976 .74877 m .37609 .74958 L .37699 .74984 L F
0 0 0 r
.60581 .83433 m .60765 .83162 L .60685 .83352 L F
.60513 .83623 m .60581 .83433 L .60685 .83352 L F
.551 .366 .584 r
.61901 .72919 m .62116 .72964 L .62111 .7271 L F
.626 .902 .985 r
.51364 .82805 m .51462 .82851 L .51743 .82749 L F
.478 .526 .829 r
.43103 .89476 m .43181 .89219 L .42971 .89261 L F
.56 .274 .439 r
.46025 .83198 m .46245 .83177 L .46327 .82933 L F
.529 .204 .361 r
.46245 .83177 m .46553 .82943 L .46327 .82933 L F
.847 .393 .119 r
.67533 .7349 m .67709 .7374 L .67824 .73764 L F
.516 0 0 r
.67959 .73893 m .67824 .73764 L .67709 .7374 L F
.67959 .73893 m .6805 .7396 L .67824 .73764 L F
.695 .467 .573 r
.65017 .72637 m .6535 .72684 L .65359 .72461 L F
.539 .37 .601 r
.65551 .72408 m .6535 .72684 L .65359 .72461 L F
.65551 .72408 m .6535 .72684 L .65359 .72461 L F
.679 .432 .541 r
.5841 .77112 m .58664 .76923 L .58404 .76914 L F
.504 .247 .458 r
.39155 .77695 m .39117 .77908 L .38907 .77944 L F
.541 .28 .468 r
.39325 .77874 m .39155 .77695 L .39357 .77662 L F
.39325 .77874 m .39117 .77908 L .39155 .77695 L F
.933 .945 .607 r
.62473 .79488 m .62592 .79124 L .62409 .79458 L F
.903 .891 .808 r
.56641 .81845 m .56966 .81577 L .56919 .81552 L F
.94 .913 .763 r
.5706 .81575 m .57147 .81625 L .57293 .81282 L F
0 0 0 r
.57116 .81564 m .57116 .81565 L .5706 .81575 L F
0 .517 .845 r
.57001 .81586 m .57147 .81625 L .5706 .81575 L F
0 0 0 r
.57116 .81565 m .56969 .81726 L .5706 .81575 L F
0 .517 .845 r
.56966 .81577 m .57001 .81586 L .5706 .81575 L F
.828 .764 .792 r
.45725 .86813 m .45519 .87055 L .45404 .86824 L F
.823 .533 .498 r
.56772 .80782 m .57072 .81033 L .57089 .8085 L F
.523 .173 .316 r
.54912 .79864 m .5511 .79951 L .55213 .79728 L F
.642 .515 .694 r
.55213 .79728 m .55446 .79814 L .55422 .79548 L F
.713 .377 .407 r
.55213 .79728 m .55342 .79894 L .55446 .79814 L F
.55213 .79728 m .5511 .79951 L .55342 .79894 L F
0 0 .29 r
.68428 .74646 m .68322 .74568 L .6841 .74442 L F
.68428 .74646 m .68296 .7476 L .68322 .74568 L F
.486 .172 .358 r
.35289 .78991 m .355 .78946 L .3532 .78913 L F
.487 .189 .385 r
.3532 .78913 m .355 .78946 L .35552 .78776 L F
.299 .347 .745 r
.64065 .71418 m .64215 .71512 L .6418 .71295 L F
.284 .224 .612 r
.6418 .71295 m .6402 .71643 L .64065 .71418 L F
.536 .725 .961 r
.63953 .71299 m .64065 .71418 L .6418 .71295 L F
.471 .292 .556 r
.71481 .72957 m .71477 .73202 L .71373 .72905 L F
.984 .733 .471 r
.71373 .72905 m .71481 .72957 L .71477 .73202 L F
.635 .455 .622 r
.45417 .86364 m .45419 .86606 L .45265 .86525 L F
.126 .411 .858 r
.45488 .86284 m .45417 .86364 L .45302 .86282 L F
.45488 .86284 m .45644 .86481 L .45417 .86364 L F
.867 .874 .84 r
.45417 .86364 m .45265 .86525 L .45302 .86282 L F
.675 .528 .678 r
.40148 .86337 m .40373 .86058 L .40169 .86102 L F
.494 .273 .508 r
.61171 .74574 m .6135 .74543 L .61376 .74349 L F
.561 .357 .562 r
.6135 .74543 m .61602 .743 L .61376 .74349 L F
0 .549 .77 r
.5733 .8474 m .57652 .84789 L .57538 .84751 L F
0 .494 .832 r
.57652 .84789 m .57711 .84776 L .57538 .84751 L F
.57652 .84789 m .57865 .8485 L .57711 .84776 L F
.717 .401 .443 r
.66662 .73223 m .66549 .7343 L .66507 .7321 L F
.66662 .73223 m .66862 .73447 L .66549 .7343 L F
.741 .614 .717 r
.63872 .71918 m .63637 .71983 L .63849 .71722 L F
.687 .558 .703 r
.63872 .71918 m .6402 .71643 L .63849 .71722 L F
.63872 .71918 m .64151 .71907 L .6402 .71643 L F
.044 .125 .625 r
.63872 .71918 m .64046 .72101 L .64151 .71907 L F
.545 .465 .717 r
.61171 .74574 m .61383 .74724 L .6135 .74543 L F
.614 .071 0 r
.49056 .82914 m .48964 .82974 L .48629 .82807 L F
.605 .906 .631 r
.49105 .82844 m .49056 .82914 L .4923 .82916 L F
.49105 .82844 m .48964 .82974 L .49056 .82914 L F
.432 .08 .266 r
.35832 .80241 m .35525 .805 L .35627 .80327 L F
.362 .746 .988 r
.54953 .84459 m .55131 .84559 L .54862 .84541 L F
.63 .341 .461 r
.55131 .84559 m .55083 .84739 L .54862 .84541 L F
.088 .292 .774 r
.54862 .84541 m .55083 .84739 L .54953 .84459 L F
.494 .863 .985 r
.64945 .75853 m .65167 .75803 L .65264 .75844 L F
.608 .911 .981 r
.65264 .75844 m .65167 .75803 L .65419 .7572 L F
.913 .938 .81 r
.48044 .86745 m .4823 .86618 L .48086 .86342 L F
.48044 .86745 m .48056 .86787 L .4823 .86618 L F
0 0 0 r
.4823 .86618 m .48423 .86345 L .48086 .86342 L F
.4823 .86618 m .48246 .86631 L .48423 .86345 L F
.2 0 0 r
.4823 .86618 m .48471 .8666 L .48246 .86631 L F
.605 .072 0 r
.54854 .84991 m .55032 .84976 L .54921 .85005 L F
.719 .486 .572 r
.45829 .85596 m .45865 .85753 L .45515 .85793 L F
.675 .462 .588 r
.46051 .85573 m .45865 .85753 L .45829 .85596 L F
.543 .457 .708 r
.64924 .72993 m .65017 .72637 L .64789 .72646 L F
.64924 .72993 m .65111 .72918 L .65017 .72637 L F
.761 .84 .911 r
.69858 .72098 m .7014 .72102 L .70092 .71882 L F
.801 .816 .863 r
.70092 .71882 m .7014 .72102 L .70371 .71885 L F
.888 .776 .732 r
.6947 .72853 m .69412 .72622 L .69247 .72923 L F
.438 .143 .365 r
.35552 .78776 m .35691 .78901 L .35773 .78762 L F
.35552 .78776 m .355 .78946 L .35691 .78901 L F
.642 .53 .711 r
.51368 .83484 m .51339 .83633 L .51616 .83434 L F
.624 .374 .519 r
.41094 .89003 m .41047 .89226 L .40828 .89194 L F
.386 .157 .439 r
.41262 .88979 m .41047 .89226 L .41094 .89003 L F
.649 .74 .916 r
.39022 .7463 m .39353 .74663 L .39233 .74607 L F
.126 .675 .788 r
.39502 .74594 m .39233 .74607 L .39353 .74663 L F
.427 .117 .334 r
.36842 .79422 m .37238 .79228 L .37202 .79422 L F
.421 .166 .418 r
.37105 .79662 m .36842 .79422 L .37202 .79422 L F
.37105 .79662 m .36919 .79719 L .36842 .79422 L F
.979 .691 .401 r
.67816 .7268 m .67713 .72611 L .67792 .72457 L F
.992 .806 .427 r
.67792 .72457 m .67713 .72611 L .67732 .72381 L F
.979 .691 .401 r
.67816 .7268 m .67713 .72611 L .67792 .72457 L F
.325 0 .062 r
.47528 .82655 m .47724 .82622 L .47856 .82454 L F
.504 .182 .354 r
.47724 .82622 m .48035 .82359 L .47856 .82454 L F
.842 .829 .835 r
.59611 .82222 m .59473 .82402 L .59268 .82346 L F
.891 .761 .712 r
.59268 .82346 m .59473 .82402 L .59355 .82677 L F
.306 .466 .856 r
.5785 .83676 m .5758 .83551 L .57609 .83455 L F
.588 .076 .002 r
.45644 .86481 m .45825 .8655 L .45924 .86459 L F
.496 0 0 r
.45825 .8655 m .46147 .86538 L .45924 .86459 L F
.637 .481 .655 r
.41235 .84779 m .41503 .84808 L .41441 .84509 L F
.645 .536 .716 r
.41301 .85044 m .41503 .84808 L .41235 .84779 L F
.515 .085 .16 r
.3329 .66839 m .33531 .66799 L .33228 .66822 L F
.3329 .66839 m .33414 .66896 L .33531 .66799 L F
.302 .312 .705 r
.33531 .66556 m .33531 .66799 L .33655 .66662 L F
0 0 0 r
.33531 .66799 m .33518 .66812 L .33655 .66662 L F
.33531 .66799 m .33414 .66896 L .33518 .66812 L F
.671 .961 .938 r
.58279 .8342 m .5822 .83499 L .57938 .83638 L F
.722 .565 .677 r
.37796 .89241 m .37783 .88999 L .37541 .88971 L F
.37796 .89241 m .37833 .89236 L .37783 .88999 L F
.563 .408 .63 r
.37783 .88999 m .37951 .88991 L .37978 .88724 L F
.475 .358 .64 r
.37833 .89236 m .37951 .88991 L .37783 .88999 L F
.326 .132 .457 r
.70912 .74722 m .70975 .74981 L .70749 .75026 L F
.312 .173 .525 r
.71127 .74478 m .70912 .74722 L .70991 .7452 L F
.71127 .74478 m .71118 .74683 L .70912 .74722 L F
.295 .114 .457 r
.71118 .74683 m .70975 .74981 L .70912 .74722 L F
.851 .626 .597 r
.6966 .74802 m .698 .75076 L .69668 .75037 L F
.836 .48 .38 r
.69668 .75037 m .698 .75076 L .69693 .75229 L F
.652 .246 .263 r
.698 .75076 m .69916 .75289 L .69693 .75229 L F
.698 .75076 m .7002 .7521 L .69916 .75289 L F
.835 .745 .765 r
.61204 .78942 m .61241 .79194 L .61 .7922 L F
.8 .643 .687 r
.61241 .79194 m .61152 .79538 L .61 .7922 L F
.689 .541 .68 r
.42585 .83699 m .42818 .8344 L .42593 .83471 L F
.614 .199 .231 r
.36664 .75077 m .36521 .75241 L .36346 .75128 L F
.486 .27 .51 r
.37237 .77701 m .37018 .77956 L .3721 .77911 L F
.792 .995 .871 r
.36752 .74903 m .36664 .75077 L .36864 .74995 L F
.36752 .74903 m .36554 .75079 L .36664 .75077 L F
.777 .767 .844 r
.36395 .74942 m .36554 .75079 L .36752 .74903 L F
.358 .179 .497 r
.36485 .75001 m .36554 .75079 L .36395 .74942 L F
.36665 .75119 m .36554 .75079 L .36485 .75001 L F
.991 .823 .58 r
.36554 .75079 m .36521 .75241 L .36609 .75141 L F
.36554 .75079 m .36609 .75141 L .36664 .75077 L F
.5 .282 .514 r
.37237 .77701 m .37407 .77865 L .37449 .77675 L F
.37237 .77701 m .3721 .77911 L .37407 .77865 L F
.497 .84 .997 r
.33354 .67686 m .33143 .67733 L .32994 .67673 L F
.575 .411 .623 r
.33354 .67686 m .33128 .67943 L .33143 .67733 L F
0 0 0 r
.55589 .78036 m .55446 .78142 L .55536 .78095 L F
.923 .97 .683 r
.55792 .7791 m .55722 .78036 L .55733 .77952 L F
.55792 .7791 m .55733 .77952 L .55743 .77872 L F
.066 .21 .705 r
.55722 .78036 m .5584 .78155 L .55743 .77872 L F
.632 .641 .841 r
.5584 .78155 m .55679 .78273 L .55589 .78036 L F
0 0 .343 r
.5584 .78155 m .55941 .7784 L .55743 .77872 L F
.632 .641 .841 r
.5584 .78155 m .55589 .78036 L .55844 .78054 L F
0 0 0 r
.55589 .78036 m .55836 .77941 L .55844 .78054 L F
.5565 .78012 m .55536 .78095 L .55836 .77941 L F
.55589 .78036 m .55536 .78095 L .5565 .78012 L F
.923 .97 .683 r
.5585 .77805 m .55792 .7791 L .55743 .77872 L F
.209 0 0 r
.55743 .77872 m .56068 .77726 L .5585 .77805 L F
.442 .119 .321 r
.36721 .78231 m .36916 .78196 L .37018 .77956 L F
.489 .189 .383 r
.36916 .78196 m .3721 .77911 L .37018 .77956 L F
.567 .335 .523 r
.58664 .76923 m .58869 .77102 L .58936 .76898 L F
.472 .148 .335 r
.58936 .76898 m .59118 .77034 L .59166 .76899 L F
.58936 .76898 m .58869 .77102 L .59118 .77034 L F
.12 0 0 r
.51128 .87534 m .50797 .87589 L .51015 .87585 L F
.636 .11 0 r
.51015 .87585 m .51386 .87676 L .51128 .87534 L F
.634 .486 .663 r
.39708 .86612 m .39923 .86351 L .39696 .86379 L F
.837 .852 .856 r
.39423 .72709 m .39087 .72849 L .39302 .72774 L F
.424 0 0 r
.39302 .72774 m .39627 .72715 L .39423 .72709 L F
.119 .584 .918 r
.33821 .66574 m .33629 .6656 L .33531 .66556 L F
.576 .257 .391 r
.6402 .71643 m .63713 .71918 L .63849 .71722 L F
.6402 .71643 m .63981 .71872 L .63713 .71918 L F
.284 .224 .612 r
.6418 .71295 m .64188 .71557 L .6402 .71643 L F
.004 0 .211 r
.64136 .71746 m .6402 .71643 L .64188 .71557 L F
.64136 .71746 m .63981 .71872 L .6402 .71643 L F
.634 .48 .656 r
.41441 .84509 m .41721 .84763 L .4172 .84517 L F
.41441 .84509 m .41503 .84808 L .41721 .84763 L F
.738 .574 .67 r
.61548 .77454 m .61525 .77681 L .61177 .77663 L F
.734 .656 .772 r
.61747 .77266 m .61548 .77454 L .61436 .77178 L F
.691 .465 .575 r
.69349 .7477 m .69542 .74524 L .6966 .74802 L F
.834 .613 .602 r
.6966 .74802 m .6936 .7499 L .69349 .7477 L F
.6966 .74802 m .69668 .75037 L .6936 .7499 L F
.59 .407 .602 r
.42818 .8344 m .43043 .83181 L .42803 .83203 L F
.753 .682 .783 r
.47758 .84764 m .48094 .84802 L .47957 .84513 L F
.638 .847 .98 r
.57135 .7897 m .56967 .79054 L .5683 .78959 L F
.576 .424 .638 r
.61414 .7693 m .61436 .77178 L .61209 .77265 L F
.489 .353 .622 r
.67233 .71603 m .6753 .71551 L .67241 .71396 L F
.607 .178 .201 r
.67241 .71396 m .6753 .71551 L .6736 .71544 L F
.35 .55 .907 r
.67011 .71421 m .67174 .716 L .66947 .71398 L F
.12 .612 .91 r
.67097 .71533 m .67174 .716 L .66937 .71339 L F
.607 .178 .201 r
.6716 .71473 m .6736 .71544 L .67097 .71533 L F
.67241 .71396 m .6736 .71544 L .6716 .71473 L F
.35 .55 .907 r
.66947 .71398 m .67174 .716 L .66957 .71464 L F
.66937 .71339 m .67011 .71421 L .66947 .71398 L F
.533 .911 .945 r
.52281 .87881 m .52353 .87792 L .52185 .87801 L F
.52281 .87881 m .52512 .878 L .52353 .87792 L F
.694 .672 .824 r
.51428 .85057 m .51788 .85062 L .5152 .84712 L F
.472 .587 .888 r
.5152 .84712 m .51788 .85062 L .51909 .85001 L F
.849 .58 .531 r
.53826 .84436 m .53692 .84279 L .53909 .84212 L F
.53826 .84436 m .53663 .84488 L .53692 .84279 L F
.68 .254 .229 r
.53826 .84436 m .53889 .8468 L .53663 .84488 L F
.356 .185 .507 r
.54103 .84208 m .53826 .84436 L .53909 .84212 L F
.54103 .84208 m .54105 .84432 L .53826 .84436 L F
.478 .127 .292 r
.54087 .84648 m .53826 .84436 L .54105 .84432 L F
.54087 .84648 m .53889 .8468 L .53826 .84436 L F
.495 .869 .98 r
.65719 .76673 m .65833 .76577 L .65616 .76626 L F
.65719 .76673 m .6593 .76615 L .65833 .76577 L F
.683 .389 .469 r
.45265 .86525 m .45419 .86606 L .45239 .86569 L F
.694 .672 .824 r
.51428 .85057 m .5152 .84712 L .51299 .84768 L F
.111 .243 .721 r
.67913 .71887 m .68126 .72122 L .68005 .72206 L F
.526 .603 .873 r
.4169 .74986 m .41628 .75223 L .41482 .75031 L F
.4169 .74986 m .41791 .75197 L .41628 .75223 L F
.59 .243 .35 r
.48794 .8215 m .48999 .82382 L .49177 .81999 L F
.48999 .82382 m .49024 .82373 L .49177 .81999 L F
.526 .178 .321 r
.49177 .81999 m .49024 .82373 L .49207 .82289 L F
.586 .413 .615 r
.49024 .82373 m .49016 .8253 L .49185 .82316 L F
.48997 .8238 m .49185 .82316 L .49207 .82289 L F
.48958 .82397 m .48999 .82382 L .48997 .8238 L F
.48999 .82382 m .49185 .82316 L .48997 .8238 L F
.48897 .82257 m .48958 .82397 L .49207 .82289 L F
0 0 .5 r
.48897 .82257 m .49013 .82399 L .48999 .82382 L F
.48897 .82257 m .48999 .82382 L .48794 .8215 L F
.526 .178 .321 r
.49024 .82373 m .49013 .82399 L .49207 .82289 L F
.586 .413 .615 r
.48958 .82397 m .48961 .82403 L .49024 .82373 L F
.48961 .82403 m .49016 .8253 L .49024 .82373 L F
.59 .243 .35 r
.48999 .82382 m .49013 .82399 L .49024 .82373 L F
.526 .178 .321 r
.49177 .81999 m .49207 .82289 L .4935 .82039 L F
.36 0 .088 r
.35747 .72672 m .35953 .7264 L .36082 .72465 L F
.225 0 .007 r
.36082 .72465 m .36146 .72573 L .36281 .72508 L F
.36082 .72465 m .35953 .7264 L .36146 .72573 L F
.718 .693 .826 r
.3814 .89518 m .38498 .89565 L .38347 .89478 L F
.776 .814 .883 r
.38347 .89478 m .38498 .89565 L .38681 .89439 L F
.523 .326 .554 r
.51385 .824 m .5159 .82376 L .51521 .82234 L F
.713 .405 .455 r
.51251 .82402 m .5159 .82376 L .51385 .824 L F
.51251 .82402 m .51695 .82595 L .5159 .82376 L F
.51695 .82595 m .51769 .82627 L .5159 .82376 L F
.523 .326 .554 r
.51521 .82234 m .5159 .82376 L .5158 .82162 L F
.111 0 .353 r
.61138 .82354 m .60982 .8243 L .61122 .82132 L F
.127 0 .389 r
.60949 .82652 m .60982 .8243 L .61138 .82354 L F
.927 .894 .777 r
.60625 .79797 m .60607 .80062 L .60495 .80046 L F
.979 .893 .668 r
.60607 .80062 m .6043 .80309 L .60495 .80046 L F
.60607 .80062 m .6052 .80347 L .6043 .80309 L F
.767 .728 .817 r
.60783 .79694 m .60607 .80062 L .60625 .79797 L F
.60783 .79694 m .60927 .79807 L .60607 .80062 L F
.361 .4 .767 r
.4895 .84434 m .48812 .84601 L .48703 .84471 L F
0 .459 .858 r
.64832 .70629 m .6494 .70715 L .64663 .70604 L F
.403 .49 .835 r
.64955 .7076 m .64663 .70604 L .6494 .70715 L F
0 .459 .858 r
.64832 .70629 m .64663 .70604 L .64546 .70705 L F
.614 .513 .715 r
.63072 .72172 m .63384 .7243 L .6343 .72177 L F
.609 .376 .538 r
.6343 .72177 m .63384 .7243 L .63599 .72386 L F
.642 .469 .634 r
.42155 .83992 m .42381 .83981 L .42377 .83733 L F
.637 .466 .634 r
.42377 .83733 m .42618 .83956 L .42585 .83699 L F
.42377 .83733 m .42381 .83981 L .42618 .83956 L F
.783 .756 .829 r
.45519 .87055 m .45181 .87057 L .45404 .86824 L F
.45519 .87055 m .45336 .87176 L .45181 .87057 L F
.788 .665 .728 r
.48246 .86631 m .48636 .86334 L .48423 .86345 L F
0 0 0 r
.63713 .71918 m .63637 .71983 L .63849 .71722 L F
.631 .361 .492 r
.43534 .83172 m .43779 .83165 L .43875 .82924 L F
.691 .427 .518 r
.43779 .83165 m .44069 .83169 L .43875 .82924 L F
.555 .466 .709 r
.41438 .74801 m .41188 .74532 L .41394 .74498 L F
.41438 .74801 m .41248 .74841 L .41188 .74532 L F
.675 .462 .588 r
.46051 .85573 m .46046 .85811 L .45865 .85753 L F
.601 .924 .968 r
.58506 .83059 m .58566 .83147 L .5838 .83201 L F
.367 .83 .905 r
.58694 .83065 m .58566 .83147 L .58506 .83059 L F
.58694 .83065 m .58839 .83079 L .58566 .83147 L F
.527 .524 .796 r
.5158 .82162 m .51691 .81834 L .51516 .82062 L F
.5158 .82162 m .51811 .82133 L .51691 .81834 L F
.614 .474 .667 r
.5159 .82376 m .51811 .82133 L .5158 .82162 L F
.985 .731 .463 r
.5416 .8268 m .54173 .82964 L .54069 .82862 L F
.766 .551 .607 r
.54495 .82952 m .54173 .82964 L .5416 .8268 L F
.489 .34 .605 r
.48333 .85072 m .48539 .84733 L .48343 .84777 L F
.22 0 .06 r
.70749 .75026 m .70686 .75172 L .70541 .7523 L F
.192 0 .048 r
.70749 .75026 m .70975 .74981 L .70686 .75172 L F
.859 .996 .806 r
.48333 .85072 m .48202 .85257 L .48342 .85242 L F
.481 .234 .463 r
.48342 .85242 m .48547 .85021 L .48333 .85072 L F
.48342 .85242 m .48521 .85255 L .48547 .85021 L F
.747 .394 .383 r
.48164 .85171 m .48427 .85233 L .48342 .85242 L F
.48427 .85233 m .48521 .85255 L .48342 .85242 L F
.859 .996 .806 r
.48202 .85257 m .48178 .85292 L .48342 .85242 L F
.727 .388 .405 r
.48178 .85292 m .48393 .85515 L .48342 .85242 L F
.48178 .85292 m .48089 .85515 L .48393 .85515 L F
.48178 .85292 m .48089 .85515 L .48393 .85515 L F
.652 .748 .92 r
.45181 .87057 m .45336 .87176 L .44993 .87116 L F
.322 .442 .827 r
.38755 .72868 m .38659 .72999 L .38528 .72743 L F
.504 .699 .957 r
.38755 .72868 m .38924 .73009 L .38659 .72999 L F
.763 .622 .703 r
.63028 .75806 m .62798 .76082 L .62799 .75861 L F
.605 .693 .905 r
.38681 .89439 m .38992 .89537 L .38943 .89384 L F
.292 .474 .867 r
.38992 .89537 m .39084 .89438 L .38943 .89384 L F
.478 .766 .994 r
.38992 .89537 m .39228 .89528 L .39084 .89438 L F
.679 .432 .541 r
.5841 .77112 m .58643 .77146 L .58664 .76923 L F
.567 .335 .523 r
.58664 .76923 m .58643 .77146 L .58869 .77102 L F
.637 .47 .64 r
.40363 .85828 m .40601 .85815 L .40582 .85567 L F
.652 .492 .654 r
.40601 .85815 m .4081 .85559 L .40582 .85567 L F
.627 .304 .404 r
.51745 .84162 m .51937 .84182 L .51726 .84008 L F
.833 .506 0 r
.68386 .75258 m .68356 .7507 L .68369 .74981 L F
.68386 .75258 m .68429 .75317 L .68356 .7507 L F
.771 .395 0 r
.65913 .71722 m .65991 .71907 L .65863 .71658 L F
.394 .081 .312 r
.65863 .71658 m .66122 .71296 L .65913 .71722 L F
.801 .991 .878 r
.48204 .85786 m .4854 .85584 L .48393 .85515 L F
.521 .582 .857 r
.69232 .71406 m .69333 .71116 L .69101 .71185 L F
.69232 .71406 m .69413 .71344 L .69333 .71116 L F
.745 .651 .756 r
.69221 .71673 m .69413 .71344 L .69232 .71406 L F
.597 .483 .694 r
.44973 .85814 m .44771 .86014 L .44759 .85851 L F
.647 .393 .521 r
.60061 .77932 m .59951 .78198 L .59703 .7818 L F
.512 .22 .407 r
.60231 .77918 m .59951 .78198 L .60061 .77932 L F
.85 .665 .651 r
.66926 .74273 m .66987 .73972 L .67136 .74117 L F
.783 .695 .767 r
.6721 .73973 m .67136 .74117 L .66987 .73972 L F
.517 .259 .463 r
.40335 .76899 m .40297 .77116 L .40084 .7715 L F
.563 .332 .523 r
.40539 .76863 m .40297 .77116 L .40335 .76899 L F
.098 0 0 r
.51228 .88136 m .51548 .88096 L .51445 .88119 L F
.266 .759 .905 r
.51548 .88096 m .51654 .8806 L .51445 .88119 L F
.51548 .88096 m .51767 .88077 L .51654 .8806 L F
.796 .744 .804 r
.3745 .8872 m .3743 .88445 L .37377 .88512 L F
.3745 .8872 m .37681 .88486 L .3743 .88445 L F
.539 .105 .165 r
.44069 .83169 m .443 .83191 L .44388 .83061 L F
.284 0 .022 r
.44388 .83061 m .44517 .83118 L .44622 .83029 L F
.44388 .83061 m .443 .83191 L .44517 .83118 L F
.59 .501 .722 r
.66186 .75797 m .66341 .76105 L .66142 .76129 L F
.238 .346 .772 r
.66377 .76333 m .66142 .76129 L .66341 .76105 L F
.438 .246 .521 r
.49854 .8196 m .50073 .82109 L .50237 .81871 L F
.49854 .8196 m .49894 .82219 L .50073 .82109 L F
.62 .363 .506 r
.53692 .84279 m .53663 .84488 L .53449 .84471 L F
.691 .465 .575 r
.69349 .7477 m .69345 .74547 L .69542 .74524 L F
.418 .739 .992 r
.44769 .83008 m .4471 .83108 L .44622 .83029 L F
.44769 .83008 m .44992 .83118 L .4471 .83108 L F
.09 .633 .843 r
.43741 .74007 m .43398 .73965 L .43536 .74036 L F
.43741 .74007 m .43398 .73965 L .43536 .74036 L F
.413 .801 .989 r
.39627 .72715 m .39889 .72681 L .39993 .72747 L F
.134 0 0 r
.40162 .72671 m .39743 .72681 L .39993 .72747 L F
.594 .89 .99 r
.39993 .72747 m .39889 .72681 L .40162 .72671 L F
.482 .345 .617 r
.40162 .72671 m .40178 .72944 L .39993 .72747 L F
.614 .663 .874 r
.70794 .71145 m .70489 .71044 L .70691 .70846 L F
.63 .593 .794 r
.71025 .71098 m .70794 .71145 L .70691 .70846 L F
.38 .421 .778 r
.71065 .7135 m .70794 .71145 L .71025 .71098 L F
.769 .561 .616 r
.59481 .78164 m .59194 .78193 L .59194 .77959 L F
.635 .344 .46 r
.59481 .78164 m .59198 .78434 L .59194 .78193 L F
.59481 .78164 m .59399 .78431 L .59198 .78434 L F
.604 .313 .448 r
.59718 .78342 m .59481 .78164 L .59703 .7818 L F
.59718 .78342 m .59399 .78431 L .59481 .78164 L F
.603 .441 .635 r
.61534 .76713 m .61626 .76913 L .61414 .7693 L F
.623 .45 .627 r
.61843 .76626 m .61626 .76913 L .61534 .76713 L F
.472 .835 .58 r
.54607 .82857 m .54495 .82952 L .54665 .82815 L F
.26 .425 .837 r
.54607 .82857 m .54667 .83041 L .54495 .82952 L F
.576 .871 .995 r
.64088 .72024 m .64382 .72122 L .64151 .71907 L F
.64194 .7211 m .64382 .72122 L .64088 .72024 L F
.464 .34 .627 r
.64625 .72078 m .64391 .72407 L .64382 .72122 L F
.576 .871 .995 r
.64046 .72101 m .64262 .72051 L .64382 .72122 L F
.64046 .72101 m .64194 .7211 L .64088 .72024 L F
.766 .704 .794 r
.64053 .72313 m .64262 .72051 L .64046 .72101 L F
.505 .049 .103 r
.64319 .71999 m .64079 .72216 L .64065 .71904 L F
.64386 .72024 m .64354 .72045 L .64319 .71999 L F
.56 .472 .712 r
.64369 .72212 m .64262 .72051 L .64329 .7222 L F
.64465 .72193 m .64378 .72132 L .64369 .72212 L F
.64378 .72132 m .64262 .72051 L .64369 .72212 L F
0 0 .442 r
.64415 .71758 m .64411 .71809 L .64386 .72024 L F
.56 .472 .712 r
.64464 .72191 m .64262 .72051 L .64465 .72193 L F
.443 .823 .99 r
.64499 .72018 m .64382 .72122 L .64372 .72116 L F
.64386 .72034 m .64372 .72116 L .64262 .72051 L F
.64499 .72018 m .64372 .72116 L .64386 .72034 L F
0 0 .442 r
.64411 .71809 m .64392 .71996 L .64386 .72024 L F
.64392 .71996 m .64386 .72054 L .64386 .72029 L F
.64392 .71996 m .64386 .72029 L .64386 .72024 L F
.443 .823 .99 r
.64499 .72018 m .64625 .72078 L .64382 .72122 L F
.56 .472 .712 r
.64466 .72193 m .64499 .72018 L .64262 .72051 L F
0 0 .442 r
.64411 .71809 m .64383 .72169 L .64386 .72054 L F
.558 .22 .352 r
.64391 .72407 m .64381 .72604 L .64161 .72585 L F
.464 .34 .627 r
.64625 .72078 m .64649 .72341 L .64391 .72407 L F
.536 .3 .504 r
.64649 .72341 m .64381 .72604 L .64391 .72407 L F
.766 .704 .794 r
.64053 .72313 m .64411 .72426 L .64262 .72051 L F
.505 .049 .103 r
.64354 .72045 m .64079 .72216 L .64319 .71999 L F
.56 .472 .712 r
.64466 .72193 m .64464 .72191 L .64465 .72193 L F
.64439 .72308 m .64329 .7222 L .64411 .72426 L F
.64466 .72193 m .64329 .7222 L .64439 .72308 L F
.645 .536 .716 r
.41301 .85044 m .41527 .85028 L .41503 .84808 L F
.63 .431 .594 r
.41301 .85044 m .41298 .85289 L .41527 .85028 L F
.235 .082 .46 r
.61551 .81151 m .61687 .80837 L .61643 .81036 L F
0 0 0 r
.61468 .81325 m .61551 .81151 L .61643 .81036 L F
.559 .372 .584 r
.62116 .72964 m .62352 .7289 L .62111 .7271 L F
.936 .564 .251 r
.58229 .82997 m .5838 .83201 L .58198 .83017 L F
0 0 0 r
.5838 .83201 m .58315 .83352 L .58198 .83017 L F
.601 .924 .968 r
.58506 .83059 m .5838 .83201 L .58229 .82997 L F
.868 .7 .176 r
.55513 .8384 m .55554 .83732 L .55546 .83621 L F
.55513 .8384 m .55546 .83957 L .55554 .83732 L F
.687 .709 .865 r
.40304 .89284 m .40525 .89339 L .40551 .89197 L F
.715 .671 .806 r
.40551 .89197 m .40525 .89339 L .40828 .89194 L F
.629 .454 .626 r
.40373 .86058 m .40601 .85815 L .40363 .85828 L F
.358 0 0 r
.38103 .7496 m .38037 .74987 L .37804 .74955 L F
.399 .678 .973 r
.37804 .74955 m .38037 .74987 L .38001 .74955 L F
.234 0 0 r
.37976 .74877 m .37804 .74955 L .37627 .74954 L F
.499 0 0 r
.38103 .7496 m .37804 .74955 L .37976 .74877 L F
.399 .678 .973 r
.37804 .74955 m .38001 .74955 L .37875 .74847 L F
.234 0 0 r
.37627 .74954 m .37804 .74955 L .37609 .74958 L F
.406 .062 .266 r
.38197 .74811 m .38103 .7496 L .37976 .74877 L F
.733 .432 .471 r
.50211 .8393 m .50538 .83765 L .50194 .83703 L F
.50211 .8393 m .50536 .83948 L .50538 .83765 L F
.646 .382 .505 r
.50536 .83948 m .50832 .83712 L .50538 .83765 L F
.91 .766 .69 r
.61502 .78211 m .61356 .78186 L .61489 .77895 L F
.846 .649 .636 r
.61502 .78211 m .61296 .78388 L .61356 .78186 L F
.61502 .78211 m .61473 .78502 L .61296 .78388 L F
0 0 0 r
.4919 .86137 m .49045 .86362 L .49109 .86282 L F
0 .066 .586 r
.49109 .86282 m .49045 .86362 L .4916 .86577 L F
.724 .642 .766 r
.4919 .86137 m .49045 .86362 L .48847 .86069 L F
.688 .834 .953 r
.70489 .71044 m .70156 .71024 L .70433 .70836 L F
.793 .849 .893 r
.70691 .70846 m .70489 .71044 L .70433 .70836 L F
.542 .735 .965 r
.39022 .7463 m .39086 .74476 L .38911 .74563 L F
.39022 .7463 m .39233 .74607 L .39086 .74476 L F
.2 .411 .844 r
.54287 .8124 m .54203 .8131 L .54027 .81118 L F
.54287 .8124 m .54345 .81399 L .54203 .8131 L F
.614 .51 .712 r
.44997 .85986 m .44771 .86014 L .44973 .85814 L F
.462 .889 .846 r
.49274 .88327 m .4964 .88206 L .4956 .88221 L F
.528 .917 .807 r
.4956 .88221 m .4964 .88206 L .49784 .88118 L F
.727 .609 .726 r
.55354 .79154 m .55422 .79548 L .55637 .79546 L F
.727 .579 .689 r
.55422 .79548 m .55446 .79814 L .55637 .79546 L F
.489 .271 .509 r
.55637 .79546 m .55446 .79814 L .55646 .79754 L F
.906 .938 .819 r
.6052 .80347 m .60336 .80602 L .60219 .8058 L F
.967 .86 .682 r
.60219 .8058 m .60336 .80602 L .60253 .80781 L F
.48 .228 .453 r
.36476 .79963 m .3633 .79812 L .365 .79766 L F
.36476 .79963 m .36279 .80011 L .3633 .79812 L F
.634 .576 .771 r
.37681 .88486 m .37978 .88724 L .37923 .88447 L F
.164 .416 .856 r
.68284 .72329 m .68429 .7239 L .68329 .72461 L F
.099 .288 .767 r
.68429 .7239 m .68541 .72655 L .68329 .72461 L F
.68 .213 0 r
.67618 .73642 m .67533 .7349 L .67436 .73423 L F
.67618 .73642 m .67709 .7374 L .67533 .7349 L F
.369 .838 .838 r
.46293 .88272 m .46624 .88187 L .46279 .88309 L F
.034 0 0 r
.46624 .88187 m .46721 .88195 L .46279 .88309 L F
.46624 .88187 m .4683 .88163 L .46721 .88195 L F
.331 .045 .319 r
.36531 .78259 m .36646 .78361 L .36721 .78231 L F
.36531 .78259 m .3647 .78431 L .36646 .78361 L F
.612 .403 .574 r
.38767 .87397 m .38998 .87403 L .39015 .87152 L F
.595 .422 .617 r
.39015 .87152 m .39231 .87135 L .39229 .86883 L F
.651 .436 .579 r
.39015 .87152 m .39269 .8738 L .39231 .87135 L F
.39015 .87152 m .38998 .87403 L .39269 .8738 L F
.862 .589 .522 r
.48641 .86887 m .48763 .86687 L .48555 .86536 L F
.602 .26 .363 r
.48959 .86823 m .48763 .86687 L .48641 .86887 L F
.461 .197 .426 r
.52742 .87405 m .5268 .87563 L .52625 .87352 L F
.586 .685 .91 r
.52832 .87211 m .52742 .87405 L .52625 .87352 L F
.52832 .87211 m .52972 .87378 L .52742 .87405 L F
.536 .377 .613 r
.52961 .87613 m .52742 .87405 L .52972 .87378 L F
.52961 .87613 m .52759 .87643 L .52742 .87405 L F
.505 .413 .685 r
.41438 .74801 m .41296 .75051 L .41248 .74841 L F
.748 .641 .742 r
.61918 .77121 m .61626 .76913 L .61981 .76972 L F
.61918 .77121 m .61747 .77266 L .61626 .76913 L F
.685 .594 .748 r
.62165 .7688 m .61918 .77121 L .61981 .76972 L F
.67 .425 .541 r
.60798 .77643 m .60462 .77903 L .60459 .77689 L F
.60798 .77643 m .60664 .77907 L .60462 .77903 L F
.686 .459 .573 r
.60998 .77674 m .60664 .77907 L .60798 .77643 L F
.763 .622 .703 r
.63028 .75806 m .63125 .76118 L .62798 .76082 L F
.758 .649 .74 r
.62798 .76082 m .63125 .76118 L .62916 .76385 L F
.65 .558 .738 r
.63028 .75806 m .63312 .7589 L .63125 .76118 L F
.679 .6 .761 r
.63312 .7589 m .63339 .76049 L .63125 .76118 L F
.781 .662 .732 r
.5252 .8187 m .5256 .8202 L .52875 .81876 L F
.904 .899 .812 r
.52875 .81876 m .52545 .82104 L .5252 .8187 L F
.332 .81 .892 r
.56324 .77653 m .56474 .77595 L .56542 .77569 L F
.56324 .77653 m .56262 .77641 L .56474 .77595 L F
.555 .297 .479 r
.53248 .84503 m .5317 .84754 L .52948 .84778 L F
.46 .205 .44 r
.53372 .84708 m .53248 .84503 L .53449 .84471 L F
.53372 .84708 m .5317 .84754 L .53248 .84503 L F
.692 .5 .623 r
.39229 .86883 m .39502 .87119 L .39477 .86884 L F
.39229 .86883 m .39231 .87135 L .39502 .87119 L F
.356 0 0 r
.5151 .85485 m .51725 .85521 L .5153 .85465 L F
.628 .421 .583 r
.42155 .83992 m .42366 .84198 L .42381 .83981 L F
.42155 .83992 m .42145 .84231 L .42366 .84198 L F
.802 .455 .4 r
.68806 .74543 m .68699 .74722 L .68524 .7449 L F
.824 .485 .413 r
.68806 .74543 m .68822 .74714 L .68699 .74722 L F
.74 .429 .456 r
.68806 .74543 m .69048 .74772 L .68822 .74714 L F
.709 .554 .675 r
.37796 .89241 m .37807 .89403 L .37833 .89236 L F
.475 .358 .64 r
.37833 .89236 m .38001 .89229 L .37951 .88991 L F
.646 .618 .807 r
.37807 .89403 m .38001 .89229 L .37833 .89236 L F
.138 .615 .921 r
.47452 .88319 m .47544 .88379 L .47701 .88398 L F
.842 .829 .835 r
.59611 .82222 m .59268 .82346 L .59478 .82146 L F
.953 .949 .715 r
.59642 .8198 m .59611 .82222 L .59478 .82146 L F
.92 .641 .496 r
.63637 .71983 m .63506 .72095 L .6348 .71944 L F
.488 .196 .396 r
.63713 .71918 m .63506 .72095 L .63637 .71983 L F
.394 .081 .312 r
.65863 .71658 m .66094 .7161 L .66122 .71296 L F
.104 0 .242 r
.66122 .71296 m .66094 .7161 L .66285 .71271 L F
.46 .797 .999 r
.41808 .88694 m .42184 .88717 L .4202 .88669 L F
0 .233 .628 r
.42184 .88717 m .42268 .88762 L .4202 .88669 L F
.17 .7 .852 r
.42268 .88762 m .42234 .88738 L .42229 .88738 L F
0 .233 .628 r
.42184 .88717 m .42313 .88788 L .42268 .88762 L F
.468 0 0 r
.4202 .88669 m .42268 .88762 L .42024 .88744 L F
.17 .7 .852 r
.42268 .88762 m .42229 .88738 L .42024 .88744 L F
0 .233 .628 r
.42313 .88788 m .42337 .88801 L .42268 .88762 L F
.917 .897 .793 r
.55291 .84454 m .55395 .84517 L .55569 .84224 L F
.988 .726 .36 r
.55333 .84712 m .55395 .84517 L .55291 .84454 L F
.55333 .84712 m .55409 .84755 L .55395 .84517 L F
.917 .897 .793 r
.55291 .84454 m .55569 .84224 L .55535 .84237 L F
.603 .444 .639 r
.61626 .76913 m .61436 .77178 L .61414 .7693 L F
.505 .413 .685 r
.41438 .74801 m .41482 .75031 L .41296 .75051 L F
.85 .665 .651 r
.66926 .74273 m .66768 .74023 L .66987 .73972 L F
.66926 .74273 m .66763 .74277 L .66768 .74023 L F
.651 .159 .069 r
.67038 .74357 m .66763 .74277 L .66926 .74273 L F
.784 .581 .627 r
.6721 .73973 m .66987 .73972 L .66952 .73743 L F
.668 .531 .689 r
.38101 .8794 m .38129 .88185 L .38338 .87918 L F
0 0 0 r
.69555 .7233 m .69672 .72237 L .69392 .72441 L F
.954 .627 .36 r
.69555 .7233 m .69681 .72412 L .69672 .72237 L F
.567 .319 .499 r
.41523 .76127 m .41496 .76324 L .41305 .76339 L F
.541 .295 .493 r
.41523 .76127 m .41704 .76298 L .41496 .76324 L F
.551 .294 .48 r
.41736 .76103 m .41704 .76298 L .41523 .76127 L F
.352 0 .063 r
.4825 .82358 m .48453 .82326 L .48584 .82158 L F
.503 .086 .182 r
.48453 .82326 m .48794 .8215 L .48584 .82158 L F
.759 .994 .87 r
.33929 .73092 m .34253 .72909 L .34 .72969 L F
.33931 .73103 m .34253 .72909 L .33929 .73092 L F
.33919 .7311 m .34117 .72962 L .34253 .72909 L F
.38 .068 .305 r
.33936 .73126 m .34098 .73085 L .34117 .72962 L F
.33905 .73154 m .33938 .73142 L .33936 .73126 L F
.33938 .73142 m .34098 .73085 L .33936 .73126 L F
.759 .994 .87 r
.33919 .7311 m .33931 .73103 L .33929 .73092 L F
.906 .938 .819 r
.6052 .80347 m .60219 .8058 L .6043 .80309 L F
0 0 .086 r
.62981 .72975 m .62798 .73241 L .62934 .73158 L F
.164 0 .373 r
.62728 .73452 m .62934 .73158 L .62798 .73241 L F
.722 .565 .677 r
.37796 .89241 m .37493 .89017 L .37552 .8924 L F
.37796 .89241 m .37541 .88971 L .37493 .89017 L F
.791 .657 .715 r
.37564 .89485 m .37664 .89495 L .37796 .89241 L F
.709 .554 .675 r
.37796 .89241 m .37664 .89495 L .37807 .89403 L F
.791 .657 .715 r
.37564 .89485 m .37645 .894 L .3756 .89396 L F
.778 .709 .788 r
.37564 .89485 m .37568 .89484 L .37562 .89439 L F
.37568 .89484 m .37807 .89403 L .37562 .89439 L F
.244 .664 .961 r
.37543 .89372 m .37552 .89377 L .37562 .89439 L F
.37552 .89377 m .37715 .89462 L .37562 .89439 L F
.393 0 0 r
.37562 .89439 m .3778 .89407 L .37715 .89462 L F
.3778 .89407 m .37807 .89403 L .378 .89408 L F
.778 .709 .788 r
.37564 .89485 m .37664 .89495 L .37807 .89403 L F
.393 0 0 r
.3778 .89407 m .378 .89408 L .37715 .89462 L F
.791 .657 .715 r
.3756 .89396 m .37796 .89241 L .37552 .8924 L F
.37645 .894 m .37796 .89241 L .3756 .89396 L F
.348 .826 .843 r
.58415 .84844 m .58726 .84776 L .58623 .84786 L F
.332 .815 .818 r
.58623 .84786 m .58726 .84776 L .58922 .84714 L F
.713 .477 .566 r
.52495 .85275 m .52275 .85065 L .52494 .85041 L F
.52495 .85275 m .52285 .85273 L .52275 .85065 L F
.527 .5 .77 r
.4856 .84007 m .48878 .83882 L .48575 .84006 L F
.214 .094 .492 r
.48706 .84254 m .4856 .84007 L .48575 .84006 L F
0 0 .158 r
.4856 .84007 m .48554 .84213 L .48575 .84006 L F
.832 .645 .65 r
.41808 .88694 m .41469 .88888 L .41592 .88924 L F
.678 .357 .423 r
.45466 .83391 m .45719 .83403 L .45804 .83206 L F
.566 .237 .371 r
.45804 .83206 m .45719 .83403 L .45987 .83365 L F
.557 .24 .388 r
.45804 .83206 m .45987 .83365 L .46025 .83198 L F
.818 .406 .264 r
.59194 .78193 m .58851 .77929 L .59194 .77959 L F
.628 .572 .772 r
.50979 .84468 m .51081 .84827 L .51299 .84768 L F
.405 .036 .221 r
.50237 .81871 m .50284 .82047 L .504 .81916 L F
.50237 .81871 m .50073 .82109 L .50284 .82047 L F
.798 .958 .63 r
.55248 .82625 m .55239 .82716 L .55452 .82405 L F
.657 .122 0 r
.5534 .82866 m .55239 .82716 L .55248 .82625 L F
.5534 .82866 m .55418 .82905 L .55239 .82716 L F
.745 .639 .743 r
.61626 .76913 m .61747 .77266 L .61436 .77178 L F
.149 .291 .754 r
.39468 .72941 m .39636 .7311 L .39469 .73013 L F
.61 .499 .703 r
.39783 .7339 m .39469 .73013 L .39636 .7311 L F
.39783 .7339 m .39544 .73438 L .39469 .73013 L F
.778 .658 .73 r
.62798 .76082 m .62916 .76385 L .62603 .76367 L F
.596 .421 .616 r
.52707 .84777 m .52723 .85036 L .52494 .85041 L F
.593 .406 .597 r
.52723 .85036 m .52495 .85275 L .52494 .85041 L F
.517 .362 .609 r
.52917 .84987 m .52707 .84777 L .52948 .84778 L F
.52917 .84987 m .52723 .85036 L .52707 .84777 L F
.795 .885 .911 r
.48485 .86782 m .48197 .86904 L .48407 .87055 L F
.862 .589 .522 r
.48641 .86887 m .48471 .8666 L .48485 .86782 L F
.507 .2 .38 r
.48641 .86887 m .48485 .86782 L .48407 .87055 L F
.269 0 0 r
.51937 .84182 m .52122 .8415 L .52267 .83993 L F
.103 .131 .605 r
.52267 .83993 m .52381 .83934 L .52341 .83729 L F
0 0 0 r
.52267 .83993 m .52122 .8415 L .52381 .83934 L F
.46 .211 .449 r
.47311 .82702 m .4748 .82812 L .47528 .82655 L F
.47311 .82702 m .47293 .82891 L .4748 .82812 L F
.444 .163 .391 r
.38378 .76886 m .38582 .76845 L .38627 .76652 L F
.608 .313 .443 r
.38582 .76845 m .38811 .76832 L .38627 .76652 L F
.55 .318 .516 r
.38627 .76652 m .38811 .76832 L .38831 .7662 L F
.673 .743 .903 r
.53408 .85615 m .53465 .85851 L .53158 .85819 L F
.697 .319 .328 r
.53158 .85819 m .53465 .85851 L .53387 .8603 L F
.53158 .85819 m .53387 .8603 L .53342 .86022 L F
.769 .494 .519 r
.52996 .85841 m .52993 .85913 L .53165 .86081 L F
.783 .52 .54 r
.52993 .85913 m .53031 .85892 L .53165 .86081 L F
.769 .494 .519 r
.52996 .85841 m .53165 .86081 L .53031 .85892 L F
.52996 .85841 m .53031 .85892 L .52993 .85913 L F
.52996 .85841 m .53031 .85892 L .52997 .85843 L F
.52996 .85841 m .53158 .85819 L .53031 .85892 L F
.783 .52 .54 r
.53031 .85892 m .53158 .85819 L .53165 .86081 L F
.769 .494 .519 r
.52997 .85843 m .53165 .86081 L .53035 .85917 L F
.697 .319 .328 r
.53158 .85819 m .53375 .86059 L .53165 .86081 L F
.568 .61 .854 r
.5308 .85975 m .53251 .85777 L .53035 .85917 L F
.53165 .86081 m .5319 .85994 L .5308 .85975 L F
.5319 .85994 m .53251 .85777 L .5308 .85975 L F
.697 .319 .328 r
.53342 .86022 m .53387 .8603 L .53375 .86059 L F
.582 .682 .909 r
.5371 .85811 m .53465 .85851 L .53408 .85615 L F
.412 .031 .202 r
.53375 .86059 m .53465 .85851 L .5371 .85811 L F
0 .276 .7 r
.44992 .83118 m .45106 .83181 L .45036 .83151 L F
.545 .471 .722 r
.37923 .88447 m .37978 .88724 L .38154 .88668 L F
.586 .457 .672 r
.37951 .88991 m .38154 .88668 L .37978 .88724 L F
.945 .669 .483 r
.49059 .84833 m .49033 .84955 L .49139 .84803 L F
.525 .111 .197 r
.49139 .84803 m .49371 .84882 L .49541 .84915 L F
.49139 .84803 m .49033 .84955 L .49371 .84882 L F
.678 .848 .965 r
.46666 .86263 m .4649 .86353 L .46361 .86275 L F
.109 0 .309 r
.61122 .82132 m .61342 .81864 L .61271 .82063 L F
.074 0 .345 r
.61138 .82354 m .61122 .82132 L .61271 .82063 L F
.917 .851 .763 r
.66794 .72255 m .66628 .72395 L .66728 .7221 L F
.545 .353 .571 r
.62981 .72975 m .63195 .72946 L .632 .72705 L F
.512 .406 .67 r
.632 .72705 m .63384 .7243 L .63163 .72492 L F
.632 .72705 m .63397 .72661 L .63384 .7243 L F
.763 .533 .585 r
.632 .72705 m .63509 .72943 L .63397 .72661 L F
.632 .72705 m .63195 .72946 L .63509 .72943 L F
.224 0 .046 r
.62934 .73158 m .63195 .72946 L .62981 .72975 L F
.743 .94 .949 r
.6631 .75157 m .66222 .75318 L .66133 .75268 L F
.6631 .75157 m .66395 .75216 L .66222 .75318 L F
.774 .734 .815 r
.66741 .75077 m .66772 .75302 L .6667 .75046 L F
.93 .741 .626 r
.6805 .7396 m .68155 .74259 L .68185 .7403 L F
.493 .791 .998 r
.6805 .7396 m .68245 .73936 L .68185 .7403 L F
.739 .216 0 r
.54665 .82815 m .54799 .82943 L .54607 .82857 L F
.703 .169 0 r
.55106 .82287 m .55075 .82197 L .54992 .82146 L F
.588 .42 .622 r
.37923 .88447 m .38118 .88414 L .38129 .88185 L F
.545 .471 .722 r
.37923 .88447 m .38154 .88668 L .38118 .88414 L F
.577 .358 .547 r
.3793 .7873 m .37679 .78981 L .37733 .78781 L F
.65 .517 .688 r
.60569 .75418 m .60539 .75588 L .60757 .75305 L F
.521 .288 .503 r
.38422 .78215 m .3839 .78423 L .3819 .78454 L F
.501 .245 .458 r
.38632 .78194 m .3839 .78423 L .38422 .78215 L F
.776 .814 .883 r
.38347 .89478 m .38681 .89439 L .38548 .89363 L F
.549 .819 .996 r
.38548 .89363 m .38681 .89439 L .38943 .89384 L F
.684 .335 .378 r
.50336 .82723 m .50316 .82864 L .50135 .82677 L F
.665 .38 .478 r
.50176 .83074 m .50135 .82677 L .50316 .82864 L F
.318 .805 .871 r
.43852 .8844 m .43938 .88449 L .4414 .88404 L F
.923 .735 .629 r
.54497 .8029 m .54344 .80297 L .54387 .80041 L F
0 .423 .753 r
.54758 .80444 m .54344 .80297 L .54497 .8029 L F
.563 .355 .556 r
.60459 .77689 m .60462 .77903 L .60231 .77918 L F
.509 .802 .998 r
.37558 .72569 m .37486 .72684 L .37363 .72564 L F
.37558 .72569 m .37687 .72647 L .37486 .72684 L F
.772 .606 .674 r
.61525 .77681 m .61185 .77867 L .61177 .77663 L F
.61525 .77681 m .61489 .77895 L .61185 .77867 L F
.847 .706 .707 r
.60809 .79498 m .60927 .79807 L .60783 .79694 L F
.756 .666 .762 r
.61152 .79538 m .60927 .79807 L .60809 .79498 L F
.725 .82 .924 r
.39813 .89207 m .40108 .8941 L .40168 .89229 L F
.751 .971 .928 r
.40108 .8941 m .40304 .89284 L .40168 .89229 L F
0 0 0 r
.52347 .82037 m .52245 .82111 L .52132 .82151 L F
.215 .614 .952 r
.52132 .82151 m .52245 .82111 L .52043 .82066 L F
.52132 .82151 m .52245 .82111 L .52043 .82066 L F
.961 .636 .25 r
.68524 .74278 m .68449 .74226 L .684 .73982 L F
.948 .672 .481 r
.68524 .74278 m .6841 .74442 L .68449 .74226 L F
.68524 .74278 m .68524 .7449 L .6841 .74442 L F
.632 .378 .516 r
.51937 .81571 m .52253 .81584 L .52232 .8131 L F
.716 .442 .509 r
.52232 .8131 m .52431 .81578 L .52436 .8132 L F
.52232 .8131 m .52253 .81584 L .52431 .81578 L F
.689 .782 .922 r
.55452 .82405 m .55212 .82337 L .55355 .82353 L F
.798 .958 .63 r
.55248 .82625 m .55452 .82405 L .55355 .82353 L F
.582 .4 .6 r
.62062 .76105 m .62053 .76379 L .61815 .76412 L F
.618 .43 .605 r
.62267 .76319 m .62062 .76105 L .62268 .76119 L F
.62267 .76319 m .62053 .76379 L .62062 .76105 L F
.522 .25 .443 r
.60242 .75968 m .60551 .75842 L .60326 .75851 L F
.581 .401 .602 r
.60326 .75851 m .60551 .75842 L .60539 .75588 L F
.817 .366 0 r
.54452 .78476 m .54446 .7857 L .54396 .78499 L F
.628 .487 .671 r
.60539 .75588 m .60773 .75576 L .60757 .75305 L F
.546 .374 .599 r
.60539 .75588 m .60762 .75785 L .60773 .75576 L F
.60539 .75588 m .60551 .75842 L .60762 .75785 L F
.552 .283 .462 r
.51205 .81668 m .51389 .81792 L .51416 .81624 L F
.51205 .81668 m .51166 .81834 L .51389 .81792 L F
.609 .373 .534 r
.38831 .7662 m .39061 .76615 L .39117 .7635 L F
.604 .455 .652 r
.39117 .7635 m .3933 .76339 L .39323 .76115 L F
.588 .354 .528 r
.39117 .7635 m .39292 .7651 L .3933 .76339 L F
.39117 .7635 m .39061 .76615 L .39292 .7651 L F
.742 .684 .796 r
.64097 .75816 m .64193 .76101 L .63867 .76059 L F
.75 .689 .793 r
.64425 .75855 m .64193 .76101 L .64097 .75816 L F
.959 .641 .237 r
.56217 .80059 m .56295 .8007 L .56065 .79982 L F
.56217 .80059 m .56323 .80253 L .56295 .8007 L F
.621 .362 .504 r
.38238 .91813 m .38067 .91626 L .3802 .91826 L F
.404 .383 .722 r
.38315 .91589 m .38067 .91626 L .38118 .91596 L F
.621 .362 .504 r
.38238 .91813 m .38118 .91596 L .38067 .91626 L F
.405 .08 .297 r
.35832 .80241 m .3609 .80063 L .36041 .80182 L F
.366 .041 .275 r
.36279 .80011 m .36041 .80182 L .3609 .80063 L F
.221 .725 .902 r
.44872 .88332 m .45037 .88364 L .45194 .88355 L F
.484 .047 .132 r
.34117 .72962 m .3446 .72884 L .34253 .72909 L F
.743 .65 .757 r
.6267 .75501 m .62495 .75635 L .62372 .7532 L F
.537 .26 .442 r
.38907 .77944 m .38846 .78175 L .38632 .78194 L F
.485 .208 .418 r
.39117 .77908 m .38846 .78175 L .38907 .77944 L F
.743 .65 .757 r
.6267 .75501 m .62372 .7532 L .62734 .75452 L F
0 0 0 r
.62734 .75452 m .6291 .75317 L .6267 .75501 L F
.507 0 0 r
.54591 .79891 m .54777 .79937 L .54912 .79864 L F
0 .56 .716 r
.54777 .79937 m .5511 .79951 L .54912 .79864 L F
.579 .583 .821 r
.40308 .73574 m .40183 .73815 L .40056 .73479 L F
.555 .554 .808 r
.40308 .73574 m .40392 .73802 L .40183 .73815 L F
.733 .781 .891 r
.37608 .8953 m .37664 .89495 L .37564 .89485 L F
.668 .443 .571 r
.45419 .86606 m .45084 .86739 L .45239 .86569 L F
.815 .756 .798 r
.48376 .82892 m .48429 .83208 L .48484 .82949 L F
.799 .905 .916 r
.48376 .82892 m .48484 .82949 L .48629 .82807 L F
.945 .951 .641 r
.48986 .87221 m .49123 .8694 L .49 .8706 L F
.759 .27 .071 r
.51364 .82805 m .51055 .82627 L .51159 .82797 L F
.635 .578 .774 r
.63237 .75576 m .63028 .75806 L .62996 .75607 L F
.63237 .75576 m .63312 .7589 L .63028 .75806 L F
.78 .743 .819 r
.63764 .75316 m .63454 .75314 L .63673 .75055 L F
.694 .441 .536 r
.63764 .75316 m .63438 .75491 L .63454 .75314 L F
.63764 .75316 m .63795 .75576 L .63438 .75491 L F
.546 .541 .8 r
.63869 .7499 m .63764 .75316 L .63673 .75055 L F
.63869 .7499 m .63984 .75293 L .63764 .75316 L F
.64 .402 .542 r
.63943 .75478 m .63795 .75576 L .63764 .75316 L F
.535 .411 .659 r
.63984 .75293 m .63943 .75478 L .63764 .75316 L F
.63984 .75293 m .63943 .75478 L .63764 .75316 L F
.561 .832 .996 r
.4414 .88404 m .44472 .88423 L .44356 .88346 L F
.611 .887 .99 r
.44472 .88423 m .44613 .88285 L .44356 .88346 L F
.44472 .88423 m .4469 .88343 L .44613 .88285 L F
.596 .458 .664 r
.62053 .76379 m .61843 .76626 L .61815 .76412 L F
.465 .785 .999 r
.48713 .8525 m .48798 .85173 L .48635 .85281 L F
.48713 .8525 m .48935 .85237 L .48798 .85173 L F
.512 .22 .407 r
.60231 .77918 m .60151 .78164 L .59951 .78198 L F
.621 .327 .45 r
.60511 .78123 m .60231 .77918 L .60462 .77903 L F
.60511 .78123 m .60151 .78164 L .60231 .77918 L F
.354 .812 .934 r
.69843 .71035 m .70156 .71024 L .69945 .71082 L F
.223 .721 .912 r
.57865 .8485 m .58197 .84876 L .58076 .84835 L F
.359 .809 .946 r
.58197 .84876 m .58268 .84818 L .58076 .84835 L F
.58197 .84876 m .58415 .84844 L .58268 .84818 L F
.832 .645 .65 r
.41808 .88694 m .41815 .88734 L .41469 .88888 L F
.35 .776 .973 r
.41863 .88625 m .41808 .88694 L .4202 .88669 L F
.23 .225 .647 r
.41898 .88771 m .41808 .88694 L .41863 .88625 L F
.41898 .88771 m .41815 .88734 L .41808 .88694 L F
.991 .731 .401 r
.49207 .84092 m .49254 .84107 L .49464 .84181 L F
.38 0 0 r
.4963 .84198 m .49464 .84181 L .49254 .84107 L F
.508 .229 .426 r
.39612 .77442 m .39565 .7763 L .39357 .77662 L F
.512 .233 .427 r
.39772 .77598 m .39565 .7763 L .39612 .77442 L F
.516 .232 .422 r
.39818 .77415 m .39772 .77598 L .39612 .77442 L F
.822 .775 .808 r
.70092 .71882 m .70371 .71885 L .70297 .71637 L F
.77 .76 .843 r
.70371 .71885 m .70495 .71524 L .70297 .71637 L F
.70371 .71885 m .70607 .71663 L .70495 .71524 L F
.711 .277 .217 r
.48817 .83393 m .48884 .83554 L .49138 .83445 L F
.06 0 0 r
.49138 .83445 m .49368 .8343 L .49371 .83516 L F
.49138 .83445 m .48884 .83554 L .49368 .8343 L F
.233 0 0 r
.47546 .86321 m .47585 .86326 L .4771 .86366 L F
.105 0 0 r
.46069 .88266 m .46188 .88287 L .45892 .88251 L F
.46069 .88266 m .46293 .88272 L .46188 .88287 L F
.604 .452 .649 r
.69205 .72695 m .69412 .72622 L .69392 .72441 L F
.571 .373 .573 r
.69247 .72923 m .69412 .72622 L .69205 .72695 L F
.604 .452 .649 r
.69205 .72695 m .69412 .72622 L .69392 .72441 L F
.409 .729 .99 r
.45529 .88401 m .45939 .88489 L .45412 .88269 L F
.755 .752 .85 r
.45412 .88269 m .45939 .88489 L .45892 .88251 L F
.646 .382 .505 r
.50536 .83948 m .50755 .83969 L .50832 .83712 L F
.308 .06 .366 r
.50832 .83712 m .50944 .83895 L .51136 .83822 L F
.50832 .83712 m .50755 .83969 L .50944 .83895 L F
.733 .855 .938 r
.65138 .76788 m .65101 .76666 L .64818 .76825 L F
.694 .796 .928 r
.65138 .76788 m .6529 .76561 L .65101 .76666 L F
.65138 .76788 m .65395 .76678 L .6529 .76561 L F
.67 .535 .691 r
.38129 .88185 m .38357 .88169 L .38338 .87918 L F
.733 .594 .701 r
.38118 .88414 m .38357 .88169 L .38129 .88185 L F
.626 .092 0 r
.50241 .87966 m .5037 .87949 L .50594 .88093 L F
.601 .847 .483 r
.61687 .80837 m .61896 .80571 L .61757 .80736 L F
0 0 .057 r
.61643 .81036 m .61687 .80837 L .61757 .80736 L F
.899 .971 .816 r
.62719 .78719 m .62886 .78539 L .62689 .78637 L F
.854 .92 .875 r
.62903 .78355 m .62886 .78539 L .63018 .78402 L F
.912 .957 .806 r
.62689 .78637 m .62886 .78539 L .62903 .78355 L F
.954 .636 .387 r
.68176 .73522 m .68078 .73635 L .68008 .73399 L F
.68176 .73522 m .682 .73716 L .68078 .73635 L F
.393 0 0 r
.37562 .89439 m .37807 .89403 L .37715 .89462 L F
.646 .618 .807 r
.37807 .89403 m .3814 .89518 L .38001 .89229 L F
.843 .751 .762 r
.59087 .82915 m .58839 .83079 L .59006 .82865 L F
.59087 .82915 m .58932 .83218 L .58839 .83079 L F
.792 .998 .847 r
.59295 .82651 m .59087 .82915 L .59006 .82865 L F
.59295 .82651 m .59355 .82677 L .59087 .82915 L F
.327 .116 .432 r
.71182 .74265 m .71127 .74478 L .70991 .7452 L F
.767 .725 .814 r
.37493 .89017 m .37541 .88971 L .37458 .88963 L F
.851 .734 .733 r
.66952 .73743 m .66686 .7373 L .66862 .73447 L F
.877 .795 .766 r
.66952 .73743 m .6664 .73955 L .66686 .7373 L F
.66952 .73743 m .66768 .74023 L .6664 .73955 L F
.683 .513 .649 r
.66987 .73972 m .66768 .74023 L .66952 .73743 L F
.362 .077 .34 r
.54136 .83776 m .54072 .83973 L .53917 .8397 L F
.555 .476 .721 r
.54072 .83973 m .53909 .84212 L .53917 .8397 L F
.608 .159 .159 r
.41898 .88771 m .41528 .88866 L .41815 .88734 L F
.344 .804 .688 r
.41815 .88734 m .41506 .88866 L .41469 .88888 L F
.41506 .88866 m .41473 .8888 L .41472 .88882 L F
.608 .159 .159 r
.41528 .88866 m .41473 .8888 L .41506 .88866 L F
.41528 .88866 m .41506 .88866 L .41815 .88734 L F
.344 .804 .688 r
.41506 .88866 m .41472 .88882 L .41469 .88888 L F
.608 .159 .159 r
.41898 .88771 m .4189 .88912 L .41473 .8888 L F
0 0 .078 r
.42024 .88744 m .4189 .88912 L .41898 .88771 L F
.654 .649 .833 r
.41801 .88726 m .41868 .88866 L .42024 .88744 L F
.41868 .88866 m .4189 .88912 L .41927 .88866 L F
.41868 .88866 m .41927 .88866 L .42024 .88744 L F
.41724 .8872 m .4175 .88751 L .41801 .88726 L F
.4175 .88751 m .4189 .88912 L .41801 .88726 L F
.815 .756 .798 r
.48376 .82892 m .48164 .83221 L .48429 .83208 L F
.927 .64 .162 r
.48396 .83303 m .48429 .83208 L .48164 .83221 L F
.48396 .83303 m .48464 .83438 L .48429 .83208 L F
.634 .486 .663 r
.39708 .86612 m .39931 .86593 L .39923 .86351 L F
.625 .436 .605 r
.39708 .86612 m .39704 .86858 L .39931 .86593 L F
.601 .042 0 r
.50601 .87609 m .50294 .8739 L .50461 .87649 L F
.076 0 0 r
.50797 .87589 m .50601 .87609 L .50461 .87649 L F
.648 .909 .981 r
.64324 .77079 m .64425 .77127 L .64571 .77048 L F
.529 .204 .361 r
.46245 .83177 m .46468 .83152 L .46553 .82943 L F
.533 .208 .363 r
.46553 .82943 m .46727 .83072 L .46767 .8294 L F
.46553 .82943 m .46468 .83152 L .46727 .83072 L F
.584 .526 .756 r
.63107 .75233 m .62996 .75607 L .6291 .75317 L F
.63107 .75233 m .63237 .75576 L .62996 .75607 L F
.959 .669 .441 r
.67991 .72963 m .67893 .73116 L .67855 .72896 L F
.67991 .72963 m .6802 .73196 L .67893 .73116 L F
.732 .626 .741 r
.39248 .75843 m .39554 .75844 L .3947 .75583 L F
.606 .416 .598 r
.39323 .76115 m .39554 .75844 L .39248 .75843 L F
.39323 .76115 m .39535 .76081 L .39554 .75844 L F
.535 .355 .584 r
.39554 .75844 m .39741 .76031 L .39793 .75842 L F
.39554 .75844 m .39535 .76081 L .39741 .76031 L F
.614 .513 .715 r
.63072 .72172 m .63163 .72492 L .63384 .7243 L F
0 0 .425 r
.56535 .84438 m .56559 .84486 L .56697 .84691 L F
.621 .313 .427 r
.48554 .84213 m .48179 .84425 L .48173 .84261 L F
.593 .492 .708 r
.42558 .75013 m .42385 .75283 L .42375 .75041 L F
.147 0 0 r
.42221 .75096 m .42558 .75013 L .42375 .75041 L F
.74 .613 .717 r
.61843 .76626 m .61981 .76972 L .61626 .76913 L F
.681 .584 .74 r
.62165 .7688 m .61981 .76972 L .61843 .76626 L F
.526 .807 .997 r
.55857 .79715 m .55959 .79806 L .55646 .79754 L F
0 0 .534 r
.55857 .79715 m .56065 .79982 L .55959 .79806 L F
.652 .211 0 r
.50369 .87525 m .50294 .8739 L .50108 .87404 L F
.404 0 0 r
.50374 .87544 m .50369 .87525 L .50236 .87499 L F
.652 .211 0 r
.50369 .87525 m .50461 .87649 L .50359 .87492 L F
.076 0 0 r
.50797 .87589 m .50687 .87609 L .50682 .87618 L F
.50687 .87609 m .50461 .87649 L .50682 .87618 L F
.535 .739 .969 r
.50682 .87618 m .50461 .87649 L .50389 .87552 L F
.50682 .87618 m .50389 .87552 L .50369 .87525 L F
.269 0 0 r
.50677 .87628 m .50682 .87618 L .50533 .87595 L F
.50942 .8769 m .50682 .87618 L .50677 .87628 L F
.404 0 0 r
.50533 .87595 m .50369 .87525 L .50374 .87544 L F
.652 .211 0 r
.50369 .87525 m .50359 .87492 L .50294 .8739 L F
.505 .405 .675 r
.52229 .82687 m .52459 .82881 L .52474 .8268 L F
.476 .405 .697 r
.52229 .82687 m .52307 .82953 L .52459 .82881 L F
.712 .361 .38 r
.49656 .83733 m .49871 .8393 L .49997 .83748 L F
.688 .331 .364 r
.49997 .83748 m .49871 .8393 L .50211 .8393 L F
.599 .37 .541 r
.49997 .83748 m .50211 .8393 L .50194 .83703 L F
.765 .63 .711 r
.61 .7922 m .61152 .79538 L .60809 .79498 L F
.548 .409 .644 r
.42385 .75283 m .42424 .75547 L .42212 .75556 L F
.589 .427 .629 r
.42424 .75547 m .42252 .75743 L .42212 .75556 L F
.469 .871 .703 r
.53074 .83093 m .52899 .83206 L .52981 .83136 L F
.53074 .83093 m .52899 .83206 L .52981 .83136 L F
.835 .709 .177 r
.63479 .73109 m .63509 .72943 L .63195 .72946 L F
.63479 .73109 m .63489 .73188 L .63509 .72943 L F
.684 .706 .865 r
.63509 .72943 m .63624 .72626 L .63397 .72661 L F
.63509 .72943 m .63731 .72826 L .63624 .72626 L F
.201 .729 .821 r
.40932 .73774 m .41136 .73746 L .41263 .73746 L F
.151 .599 .931 r
.41354 .73708 m .41263 .73746 L .41136 .73746 L F
.41354 .73708 m .41426 .73755 L .41263 .73746 L F
.554 .428 .663 r
.41476 .73905 m .41263 .73746 L .41426 .73755 L F
.41476 .73905 m .41286 .73951 L .41263 .73746 L F
.314 0 .101 r
.55342 .79894 m .55646 .79754 L .55446 .79814 L F
.49 .848 .992 r
.40726 .738 m .40808 .73705 L .40932 .73774 L F
.40726 .738 m .40602 .73754 L .40808 .73705 L F
.519 .233 .42 r
.54356 .83748 m .54072 .83973 L .54136 .83776 L F
.603 .628 .848 r
.39853 .73545 m .39544 .73438 L .39783 .7339 L F
.753 .576 .656 r
.62605 .76117 m .62267 .76319 L .62268 .76119 L F
.547 .645 .898 r
.69397 .70394 m .69288 .70594 L .69165 .70429 L F
.69397 .70394 m .69498 .70565 L .69288 .70594 L F
.79 .292 0 r
.55814 .81341 m .55673 .8129 L .55498 .81075 L F
.931 .584 .351 r
.55814 .81341 m .55718 .81508 L .55673 .8129 L F
.55814 .81341 m .55889 .81596 L .55718 .81508 L F
.883 .897 .836 r
.37377 .88512 m .37306 .88392 L .37244 .88444 L F
.37377 .88512 m .3743 .88445 L .37306 .88392 L F
0 0 .179 r
.61896 .80571 m .62018 .8025 L .61977 .80453 L F
.613 .854 .488 r
.61757 .80736 m .61896 .80571 L .61977 .80453 L F
.841 .822 .83 r
.52043 .82066 m .51786 .82389 L .51951 .82411 L F
.212 .354 .791 r
.51786 .82389 m .51928 .82667 L .51951 .82411 L F
.437 .082 .263 r
.36154 .7868 m .3647 .78431 L .36281 .78481 L F
.432 .08 .266 r
.35832 .80241 m .35718 .80477 L .35525 .805 L F
.314 0 .205 r
.359 .80419 m .35832 .80241 L .36041 .80182 L F
.359 .80419 m .35718 .80477 L .35832 .80241 L F
.137 0 0 r
.67328 .75989 m .67444 .75867 L .67722 .75785 L F
.489 .156 .328 r
.4081 .76688 m .40748 .76838 L .40539 .76863 L F
.545 .252 .421 r
.41001 .76648 m .40748 .76838 L .4081 .76688 L F
.621 .362 .504 r
.38238 .91813 m .38315 .91589 L .38118 .91596 L F
.514 .255 .46 r
.3819 .78454 m .38132 .78711 L .3793 .7873 L F
.526 .266 .463 r
.38384 .7857 m .3819 .78454 L .3839 .78423 L F
.38384 .7857 m .38132 .78711 L .3819 .78454 L F
.668 .502 .651 r
.4081 .85559 m .41085 .85551 L .41078 .8532 L F
.655 .492 .651 r
.41078 .8532 m .41313 .85525 L .41298 .85289 L F
.41078 .8532 m .41085 .85551 L .41313 .85525 L F
.914 .678 .568 r
.69047 .73718 m .69212 .73718 L .69205 .73486 L F
.777 .34 0 r
.55199 .80792 m .55173 .80811 L .55027 .80536 L F
.665 .139 0 r
.55199 .80792 m .55397 .81008 L .55173 .80811 L F
.621 .313 .427 r
.48554 .84213 m .48387 .84472 L .48179 .84425 L F
.755 .48 .515 r
.48703 .84471 m .48554 .84213 L .48706 .84254 L F
.48703 .84471 m .48387 .84472 L .48554 .84213 L F
.551 .361 .577 r
.38556 .87659 m .38764 .87632 L .38767 .87397 L F
.594 .31 .454 r
.3895 .87589 m .38767 .87397 L .38764 .87632 L F
.3895 .87589 m .38998 .87403 L .38767 .87397 L F
.891 .761 .712 r
.59268 .82346 m .59355 .82677 L .59295 .82651 L F
.511 .305 .536 r
.38556 .87659 m .38338 .87918 L .3854 .87887 L F
.652 .495 .658 r
.3854 .87887 m .38764 .87632 L .38556 .87659 L F
.561 .542 .79 r
.40193 .75098 m .40282 .74752 L .40084 .7478 L F
.40193 .75098 m .40391 .75093 L .40282 .74752 L F
.557 .384 .603 r
.40193 .75098 m .40397 .75262 L .40391 .75093 L F
.442 .392 .707 r
.40193 .75098 m .40254 .75338 L .40397 .75262 L F
.677 .831 .958 r
.56697 .84691 m .5678 .84804 L .57007 .84695 L F
.4 0 0 r
.47004 .87081 m .46949 .87037 L .46863 .86872 L F
.47004 .87081 m .46863 .86872 L .46867 .86875 L F
.47004 .87081 m .46854 .86855 L .47019 .86819 L F
.766 .55 .605 r
.46689 .87047 m .47004 .87081 L .47019 .86819 L F
.46689 .87047 m .46901 .869 L .46885 .86954 L F
.46901 .869 m .47019 .86819 L .46922 .86916 L F
.46901 .869 m .46922 .86916 L .46885 .86954 L F
.4 0 0 r
.46867 .86875 m .46863 .86872 L .46854 .86855 L F
0 0 0 r
.47004 .87081 m .46887 .87284 L .47012 .87107 L F
.47004 .87081 m .47094 .8699 L .47221 .87054 L F
.47004 .87081 m .47012 .87107 L .47094 .8699 L F
.4 0 0 r
.47004 .87081 m .47135 .87121 L .46996 .87059 L F
.47004 .87081 m .46996 .87059 L .46949 .87037 L F
.824 .478 .402 r
.46827 .86053 m .46609 .85871 L .46917 .85828 L F
.05 .616 .762 r
.37687 .72647 m .37886 .72646 L .38032 .72653 L F
.216 .678 .945 r
.37886 .72646 m .3822 .72726 L .38032 .72653 L F
.957 .784 .627 r
.55123 .84292 m .55131 .84559 L .54953 .84459 L F
.658 .627 .807 r
.63543 .75859 m .63339 .76049 L .63312 .7589 L F
.63543 .75859 m .63668 .7614 L .63339 .76049 L F
.815 .861 .883 r
.54877 .78959 m .55025 .79051 L .55082 .78957 L F
.54877 .78959 m .55025 .79051 L .55082 .78957 L F
.455 .019 .12 r
.57535 .77311 m .57766 .77303 L .57867 .77144 L F
.625 .2 .216 r
.57867 .77144 m .58099 .77292 L .58083 .77139 L F
.57867 .77144 m .57766 .77303 L .58099 .77292 L F
.668 .588 .756 r
.38357 .88169 m .3854 .87887 L .38338 .87918 L F
.346 .602 .943 r
.68786 .72693 m .68507 .727 L .68541 .72655 L F
.68786 .72693 m .68913 .72816 L .68507 .727 L F
.568 .488 .725 r
.68507 .727 m .68913 .72816 L .68715 .72988 L F
.293 0 0 r
.40828 .89194 m .40697 .8922 L .40551 .89197 L F
.40828 .89194 m .40697 .8922 L .40551 .89197 L F
.666 .775 .931 r
.50545 .82642 m .50336 .82723 L .50223 .82558 L F
.659 .312 .374 r
.50336 .82723 m .50518 .82886 L .50316 .82864 L F
.539 .341 .56 r
.50545 .82642 m .50518 .82886 L .50336 .82723 L F
.235 0 0 r
.47701 .88398 m .48024 .88468 L .47892 .88447 L F
.093 .643 .824 r
.48024 .88468 m .48086 .88449 L .47892 .88447 L F
.48024 .88468 m .48233 .88473 L .48086 .88449 L F
.737 .633 .744 r
.62544 .75016 m .62734 .75452 L .62372 .7532 L F
.665 .635 .81 r
.62783 .74992 m .62734 .75452 L .62544 .75016 L F
.62783 .74992 m .6291 .75317 L .62734 .75452 L F
.774 .905 .932 r
.52512 .878 m .52582 .8756 L .52353 .87792 L F
.52512 .878 m .52759 .87643 L .52582 .8756 L F
.409 .729 .99 r
.45529 .88401 m .45412 .88269 L .45438 .88329 L F
.688 .905 .973 r
.40365 .89138 m .40304 .89284 L .40551 .89197 L F
.66 .876 .979 r
.40168 .89229 m .40304 .89284 L .40365 .89138 L F
.524 .258 .453 r
.37679 .78981 m .37441 .79183 L .37491 .79038 L F
.624 .491 .68 r
.41924 .84261 m .41946 .84497 L .42145 .84231 L F
0 .531 .784 r
.49047 .86103 m .4919 .86137 L .48847 .86069 L F
.48847 .86069 m .4919 .86137 L .49047 .86103 L F
.894 .602 .484 r
.49109 .86282 m .4919 .86137 L .49047 .86103 L F
.686 .331 .368 r
.49109 .86282 m .49386 .86296 L .4919 .86137 L F
.602 .649 .87 r
.3814 .89518 m .38211 .89254 L .38001 .89229 L F
.3814 .89518 m .38347 .89478 L .38211 .89254 L F
.214 .094 .492 r
.48706 .84254 m .48594 .84042 L .48694 .84173 L F
.48706 .84254 m .48832 .84293 L .48826 .84053 L F
.725 .203 0 r
.48694 .84173 m .48832 .84293 L .48706 .84254 L F
.538 .384 .62 r
.4847 .84113 m .48804 .84316 L .48694 .84173 L F
.48804 .84316 m .48818 .84324 L .48694 .84173 L F
.214 .094 .492 r
.48594 .84042 m .48575 .84006 L .48694 .84173 L F
.587 .361 .54 r
.4895 .84434 m .48706 .84254 L .48832 .84293 L F
.4895 .84434 m .48703 .84471 L .48706 .84254 L F
.928 .961 .773 r
.63691 .71313 m .63433 .71768 L .63476 .71593 L F
0 0 .476 r
.63433 .71768 m .6348 .71944 L .63476 .71593 L F
.694 .49 .608 r
.51991 .85326 m .52262 .85678 L .51725 .85521 L F
0 0 0 r
.51725 .85521 m .51991 .85326 L .52262 .85678 L F
.501 .445 .726 r
.52184 .85317 m .51991 .85326 L .52285 .85273 L F
.499 .5 .789 r
.51909 .85001 m .51991 .85326 L .52184 .85317 L F
.501 .445 .726 r
.52184 .85317 m .52262 .85678 L .51991 .85326 L F
.52184 .85317 m .52262 .85678 L .51991 .85326 L F
.527 .836 .521 r
.49 .8706 m .49252 .86809 L .48959 .86823 L F
.448 0 0 r
.47004 .85267 m .47078 .85325 L .47334 .85293 L F
.674 .963 .935 r
.47334 .85293 m .47078 .85325 L .47134 .85298 L F
.227 0 0 r
.47334 .85293 m .47214 .85296 L .47004 .85267 L F
.674 .963 .935 r
.47334 .85293 m .47235 .85296 L .47449 .85147 L F
.415 .245 .54 r
.47449 .85147 m .47294 .85307 L .4731 .85243 L F
.47449 .85147 m .4731 .85243 L .47364 .85034 L F
.674 .963 .935 r
.47235 .85296 m .47134 .85298 L .47449 .85147 L F
.227 0 0 r
.47334 .85293 m .47294 .85307 L .47214 .85296 L F
.64 .926 .656 r
.47449 .85147 m .47294 .85307 L .47334 .85293 L F
.791 .865 .904 r
.69412 .72622 m .69555 .7233 L .69392 .72441 L F
.626 .445 .617 r
.39931 .86593 m .40148 .86337 L .39923 .86351 L F
.848 .991 .846 r
.63018 .78402 m .63167 .78137 L .62903 .78355 L F
.63018 .78402 m .63238 .78162 L .63167 .78137 L F
.59 .407 .602 r
.42818 .8344 m .43038 .83418 L .43043 .83181 L F
.645 .473 .636 r
.43038 .83418 m .43239 .83144 L .43043 .83181 L F
.695 .558 .696 r
.60757 .75305 m .6096 .75315 L .60959 .75052 L F
.636 .51 .693 r
.60959 .75052 m .61224 .7524 L .61189 .7505 L F
.60959 .75052 m .6096 .75315 L .61224 .7524 L F
.287 0 0 r
.50284 .82047 m .50623 .819 L .504 .81916 L F
.837 .878 .873 r
.49065 .87358 m .49261 .87429 L .49099 .87591 L F
.734 .232 .034 r
.49104 .874 m .49261 .87429 L .49065 .87358 L F
.569 .916 .964 r
.49261 .87429 m .49366 .87448 L .49192 .87517 L F
.734 .232 .034 r
.49304 .87611 m .49261 .87429 L .49104 .874 L F
.569 .916 .964 r
.49261 .87429 m .49397 .87436 L .49366 .87448 L F
.709 .931 .963 r
.6667 .75046 m .66395 .75216 L .6631 .75157 L F
.689 .541 .68 r
.42585 .83699 m .42895 .83715 L .42818 .8344 L F
.676 .533 .683 r
.42818 .8344 m .43121 .83684 L .43038 .83418 L F
.42818 .8344 m .42895 .83715 L .43121 .83684 L F
.756 .499 .544 r
.49301 .8528 m .49543 .85329 L .49478 .8553 L F
.741 .602 .703 r
.4975 .85236 m .49478 .8553 L .49543 .85329 L F
.674 .503 .645 r
.4172 .84517 m .41721 .84763 L .41946 .84497 L F
.566 .439 .667 r
.60757 .75305 m .60994 .75534 L .6096 .75315 L F
.60757 .75305 m .60773 .75576 L .60994 .75534 L F
.586 .801 .982 r
.67186 .71283 m .67241 .71396 L .66937 .71339 L F
.842 .921 .886 r
.67441 .71172 m .67241 .71396 L .67186 .71283 L F
.607 .178 .201 r
.67241 .71396 m .67097 .71533 L .67186 .71283 L F
.56 .393 .611 r
.33128 .67943 m .3316 .68171 L .32938 .68228 L F
.529 .317 .536 r
.3316 .68171 m .32917 .68448 L .32938 .68228 L F
.826 .903 .893 r
.55298 .78413 m .55409 .78481 L .55679 .78273 L F
.686 .459 .573 r
.60998 .77674 m .61017 .77915 L .60664 .77907 L F
.715 .481 .57 r
.61185 .77867 m .60998 .77674 L .61177 .77663 L F
.61185 .77867 m .61017 .77915 L .60998 .77674 L F
.53 .271 .467 r
.40084 .7715 m .40019 .77398 L .39818 .77415 L F
.56 .317 .504 r
.40297 .77116 m .40019 .77398 L .40084 .7715 L F
.448 .083 .251 r
.35181 .79178 m .355 .78946 L .35289 .78991 L F
.652 .492 .654 r
.40601 .85815 m .40863 .85805 L .4081 .85559 L F
.673 .505 .651 r
.4081 .85559 m .41097 .85792 L .41085 .85551 L F
.4081 .85559 m .40863 .85805 L .41097 .85792 L F
.668 .443 .571 r
.45419 .86606 m .45404 .86824 L .45084 .86739 L F
.381 .288 .624 r
.49047 .87329 m .4893 .87342 L .48982 .87133 L F
.855 .982 .857 r
.48749 .87363 m .48986 .87221 L .49 .8706 L F
.381 .288 .624 r
.49006 .87096 m .48982 .87133 L .49 .8706 L F
.49047 .87329 m .48982 .87133 L .49006 .87096 L F
.855 .982 .857 r
.48881 .87284 m .48888 .87338 L .48986 .87221 L F
.48749 .87363 m .48839 .87347 L .48881 .87284 L F
.48839 .87347 m .48888 .87338 L .48881 .87284 L F
.799 .814 .864 r
.33518 .66812 m .33658 .66856 L .33967 .66662 L F
.763 .253 0 r
.55498 .81075 m .55558 .81233 L .55397 .81008 L F
.55498 .81075 m .55673 .8129 L .55558 .81233 L F
.848 .776 .781 r
.51646 .86659 m .51796 .86893 L .5148 .86801 L F
.526 0 0 r
.5148 .86801 m .51796 .86893 L .51698 .86892 L F
.573 .677 .91 r
.51973 .86831 m .51796 .86893 L .51646 .86659 L F
.373 .84 .85 r
.51698 .86892 m .51796 .86893 L .51973 .86831 L F
.688 .391 .467 r
.45865 .85753 m .45711 .86014 L .45515 .85793 L F
.652 .349 .445 r
.46089 .85958 m .45865 .85753 L .46046 .85811 L F
.46089 .85958 m .45711 .86014 L .45865 .85753 L F
.755 .275 .1 r
.4963 .84198 m .49749 .84277 L .49464 .84181 L F
.659 .471 .62 r
.41527 .85028 m .41298 .85289 L .41522 .85264 L F
.649 .538 .715 r
.41503 .84808 m .41527 .85028 L .41721 .84763 L F
.617 .495 .691 r
.41721 .84763 m .41527 .85028 L .41744 .84998 L F
.663 .51 .666 r
.41522 .85264 m .41744 .84998 L .41527 .85028 L F
.209 0 .219 r
.52913 .81072 m .53187 .80801 L .52931 .80854 L F
.69 .643 .797 r
.63867 .76059 m .63668 .7614 L .63543 .75859 L F
.55 .685 .928 r
.38438 .91563 m .3831 .91677 L .38315 .91589 L F
.38438 .91563 m .38661 .91774 L .3831 .91677 L F
.772 .584 .644 r
.61489 .77895 m .61356 .78186 L .61185 .77867 L F
.715 .72 .854 r
.52038 .83348 m .5179 .83482 L .52162 .83467 L F
.52038 .83348 m .5179 .83482 L .52162 .83467 L F
0 .043 .612 r
.52162 .83467 m .52272 .83562 L .52038 .83348 L F
.52162 .83467 m .52341 .83729 L .52272 .83562 L F
.813 .711 .753 r
.53047 .85496 m .53158 .85819 L .52996 .85841 L F
.601 .595 .818 r
.53309 .85582 m .53158 .85819 L .53047 .85496 L F
.53346 .85595 m .53325 .8562 L .53309 .85582 L F
.53325 .8562 m .53158 .85819 L .53309 .85582 L F
.664 .527 .688 r
.53242 .85246 m .53408 .85615 L .53047 .85496 L F
.978 .715 .462 r
.53208 .85347 m .53283 .85479 L .53242 .85246 L F
.53135 .85568 m .53268 .85488 L .53208 .85347 L F
.53268 .85488 m .53283 .85479 L .53208 .85347 L F
.845 .813 .819 r
.53242 .85246 m .53047 .85496 L .52923 .85352 L F
.53242 .85246 m .52923 .85352 L .5306 .85103 L F
.978 .715 .462 r
.53135 .85568 m .53208 .85347 L .5306 .85103 L F
.53208 .85347 m .53242 .85246 L .53082 .8512 L F
.53208 .85347 m .53082 .8512 L .5306 .85103 L F
.601 .595 .818 r
.53408 .85615 m .53373 .85644 L .53346 .85595 L F
.53373 .85644 m .53158 .85819 L .53346 .85595 L F
.797 .667 .72 r
.38447 .88665 m .38776 .88704 L .38667 .88419 L F
.637 .133 .035 r
.38447 .88665 m .38627 .88731 L .38776 .88704 L F
.576 .514 .748 r
.38776 .88704 m .38884 .88373 L .38667 .88419 L F
.38776 .88704 m .3898 .88679 L .38884 .88373 L F
.582 .163 .211 r
.38627 .88731 m .3898 .88679 L .38776 .88704 L F
.114 .572 .917 r
.37239 .72478 m .37128 .72504 L .37028 .7246 L F
.37239 .72478 m .37363 .72564 L .37128 .72504 L F
.826 .903 .893 r
.55298 .78413 m .55679 .78273 L .55558 .78208 L F
.707 .926 .964 r
.55844 .78054 m .55679 .78273 L .5584 .78155 L F
.55844 .78054 m .55558 .78208 L .55679 .78273 L F
.799 .576 .599 r
.55354 .79154 m .5524 .79214 L .55209 .79055 L F
.683 .357 .417 r
.55354 .79154 m .55522 .79249 L .5524 .79214 L F
.522 .25 .443 r
.60242 .75968 m .60549 .76038 L .60551 .75842 L F
.637 .453 .617 r
.60387 .76248 m .60549 .76038 L .60242 .75968 L F
0 0 .127 r
.56421 .83432 m .56456 .8372 L .56464 .83656 L F
.722 .601 .029 r
.56456 .8372 m .56451 .83959 L .56451 .83894 L F
.56456 .8372 m .56451 .83894 L .56464 .83656 L F
.577 .433 .649 r
.39323 .76115 m .39531 .76302 L .39535 .76081 L F
.39323 .76115 m .3933 .76339 L .39531 .76302 L F
.214 .556 .934 r
.66371 .70561 m .66256 .70618 L .66196 .70504 L F
.66371 .70561 m .66547 .7072 L .66256 .70618 L F
.471 .271 .527 r
.38378 .76886 m .38556 .77017 L .38582 .76845 L F
.38378 .76886 m .38363 .77082 L .38556 .77017 L F
.677 .493 .629 r
.42366 .84198 m .42618 .83956 L .42381 .83981 L F
0 0 .418 r
.54953 .83962 m .55123 .84292 L .55078 .84181 L F
.957 .784 .627 r
.55123 .84292 m .55163 .84403 L .55078 .84181 L F
.55123 .84292 m .54953 .84459 L .55163 .84403 L F
.169 .668 .912 r
.42337 .88801 m .42387 .88755 L .42268 .88762 L F
.42337 .88801 m .42536 .88823 L .42387 .88755 L F
.199 0 .239 r
.40182 .75522 m .40032 .75597 L .39959 .75782 L F
.733 .594 .701 r
.38118 .88414 m .38445 .88439 L .38357 .88169 L F
.639 .407 .551 r
.38154 .88668 m .38445 .88439 L .38118 .88414 L F
.38154 .88668 m .38447 .88665 L .38445 .88439 L F
.635 .539 .728 r
.38357 .88169 m .38445 .88439 L .38667 .88419 L F
.797 .667 .72 r
.38447 .88665 m .38667 .88419 L .38445 .88439 L F
.195 .723 .83 r
.58922 .84714 m .59235 .84693 L .59155 .84717 L F
.703 .923 .966 r
.67055 .74993 m .66741 .75077 L .66864 .75015 L F
.166 .203 .656 r
.47913 .86091 m .47991 .86371 L .47837 .86082 L F
.703 .427 .503 r
.69747 .74761 m .70113 .74733 L .69904 .74507 L F
.69747 .74761 m .69904 .74507 L .70003 .7443 L F
.629 .454 .626 r
.40373 .86058 m .40614 .86052 L .40601 .85815 L F
.631 .442 .609 r
.40614 .86052 m .40863 .85805 L .40601 .85815 L F
.661 .459 .6 r
.63691 .71313 m .63953 .71299 L .63935 .71123 L F
.352 .129 .429 r
.63935 .71123 m .64102 .71074 L .64137 .70855 L F
.61 .529 .738 r
.63953 .71299 m .64102 .71074 L .63935 .71123 L F
.032 .603 .742 r
.36838 .79769 m .3674 .79765 L .365 .79766 L F
.473 .283 .542 r
.53735 .82591 m .53567 .82682 L .53612 .824 L F
.571 .36 .555 r
.65111 .72918 m .6535 .72684 L .65017 .72637 L F
.555 .276 .447 r
.37866 .77378 m .38108 .77369 L .38155 .77118 L F
.34 .088 .379 r
.38155 .77118 m .3827 .77305 L .38363 .77082 L F
.38155 .77118 m .38108 .77369 L .3827 .77305 L F
.626 .902 .985 r
.51364 .82805 m .51743 .82749 L .51633 .82687 L F
.674 .894 .977 r
.51633 .82687 m .51743 .82749 L .51928 .82667 L F
.575 .411 .623 r
.33354 .67686 m .33328 .67942 L .33128 .67943 L F
.392 .176 .462 r
.33328 .67942 m .3316 .68171 L .33128 .67943 L F
.068 .568 .889 r
.40551 .89197 m .40584 .89153 L .40365 .89138 L F
.40551 .89197 m .40697 .8922 L .40584 .89153 L F
.753 .576 .656 r
.62605 .76117 m .62603 .76367 L .62267 .76319 L F
.669 .507 .656 r
.62798 .76082 m .62603 .76367 L .62605 .76117 L F
.668 .588 .756 r
.38357 .88169 m .38643 .88176 L .3854 .87887 L F
.635 .539 .728 r
.38357 .88169 m .38667 .88419 L .38643 .88176 L F
.529 .325 .548 r
.6096 .75315 m .61207 .75481 L .61224 .7524 L F
.6096 .75315 m .60994 .75534 L .61207 .75481 L F
.558 .353 .558 r
.37646 .77637 m .37866 .77378 L .37677 .7742 L F
.126 .675 .788 r
.39502 .74594 m .39392 .74591 L .39233 .74607 L F
.217 .739 .83 r
.39599 .74563 m .39502 .74594 L .39648 .74581 L F
.39599 .74563 m .39392 .74591 L .39502 .74594 L F
.182 0 .246 r
.40254 .75338 m .40182 .75522 L .40397 .75262 L F
.806 .456 .394 r
.6936 .7499 m .69668 .75037 L .69693 .75229 L F
.955 .616 .323 r
.67323 .73339 m .67389 .73212 L .67318 .73137 L F
.67323 .73339 m .67436 .73423 L .67389 .73212 L F
.661 .48 .628 r
.42618 .83956 m .42895 .83715 L .42585 .83699 L F
.756 .751 .847 r
.52506 .85687 m .52639 .85863 L .52402 .85824 L F
.751 .342 .275 r
.52402 .85824 m .52639 .85863 L .52569 .85907 L F
.747 .748 .853 r
.52815 .85569 m .52639 .85863 L .52506 .85687 L F
.659 .629 .809 r
.52815 .85569 m .52996 .85841 L .52639 .85863 L F
.451 0 .036 r
.52639 .85863 m .52815 .85915 L .52569 .85907 L F
.52639 .85863 m .52996 .85841 L .52815 .85915 L F
.031 .591 .809 r
.57007 .84695 m .5733 .8474 L .57221 .84687 L F
.239 .697 .951 r
.5733 .8474 m .5742 .84695 L .57221 .84687 L F
.5733 .8474 m .57538 .84751 L .5742 .84695 L F
.579 .365 .554 r
.41971 .7585 m .41949 .76089 L .41736 .76103 L F
.557 .339 .54 r
.42252 .75743 m .41949 .76089 L .41971 .7585 L F
.306 0 0 r
.6742 .71801 m .6753 .71551 L .67233 .71603 L F
.6742 .71801 m .67619 .71841 L .67499 .71852 L F
.6742 .71801 m .67499 .71852 L .6753 .71551 L F
.746 .866 .935 r
.33414 .66896 m .33658 .66856 L .33518 .66812 L F
.4 .854 .809 r
.5074 .86064 m .50468 .86156 L .50644 .85881 L F
.50468 .86156 m .5074 .86064 L .50694 .86303 L F
0 .097 .653 r
.50764 .86045 m .5074 .86064 L .50644 .85881 L F
0 0 0 r
.50694 .86303 m .5074 .86064 L .50764 .86045 L F
.528 .151 .269 r
.46767 .8294 m .46937 .83057 L .47078 .8283 L F
.416 .034 .203 r
.47078 .8283 m .47151 .83015 L .47293 .82891 L F
.47078 .8283 m .46937 .83057 L .47151 .83015 L F
.554 .645 .894 r
.65991 .71907 m .66094 .7161 L .65863 .71658 L F
.65991 .71907 m .66247 .71863 L .66094 .7161 L F
.305 .04 .337 r
.39959 .75782 m .39793 .75842 L .39741 .76031 L F
.801 .898 .911 r
.47635 .87079 m .47498 .87187 L .47356 .87133 L F
.624 .612 .818 r
.40056 .73479 m .39853 .73545 L .39783 .7339 L F
.455 .688 .966 r
.4683 .88163 m .47159 .88293 L .47006 .88222 L F
0 .548 .739 r
.47159 .88293 m .47255 .88295 L .47006 .88222 L F
.47159 .88293 m .47452 .88319 L .47255 .88295 L F
.681 .584 .74 r
.62165 .7688 m .61843 .76626 L .62053 .7656 L F
.702 .592 .729 r
.62388 .76629 m .62165 .7688 L .62053 .7656 L F
.133 .681 .763 r
.35388 .72705 m .35747 .72672 L .35546 .72697 L F
.675 .528 .678 r
.40148 .86337 m .40434 .86345 L .40373 .86058 L F
.603 .482 .687 r
.40373 .86058 m .40643 .86319 L .40614 .86052 L F
.40373 .86058 m .40434 .86345 L .40643 .86319 L F
.572 .344 .531 r
.41496 .76324 m .41301 .7651 L .41305 .76339 L F
.762 .651 .739 r
.64302 .7554 m .64425 .75855 L .64097 .75816 L F
.724 .632 .755 r
.64624 .75643 m .64425 .75855 L .64302 .7554 L F
.779 .427 .388 r
.58851 .77929 m .59034 .78161 L .58942 .78117 L F
.818 .406 .264 r
.59194 .78193 m .59034 .78161 L .58851 .77929 L F
.118 0 .395 r
.713 .7396 m .71354 .74174 L .71182 .74265 L F
0 0 .184 r
.71354 .74174 m .71127 .74478 L .71182 .74265 L F
.689 .595 .745 r
.62053 .7656 m .61843 .76626 L .62053 .76379 L F
.586 .457 .672 r
.37951 .88991 m .3833 .88964 L .38154 .88668 L F
.342 .27 .629 r
.37951 .88991 m .38139 .89118 L .3833 .88964 L F
.37951 .88991 m .38001 .89229 L .38139 .89118 L F
0 0 0 r
.38513 .74657 m .38418 .74699 L .38692 .74616 L F
.507 .911 .844 r
.38772 .74533 m .38692 .74616 L .38911 .74563 L F
.38772 .74533 m .38513 .74657 L .38692 .74616 L F
.08 0 0 r
.34859 .72839 m .35213 .72739 L .35016 .72778 L F
.626 .445 .617 r
.39931 .86593 m .40145 .86584 L .40148 .86337 L F
.691 .498 .621 r
.40148 .86337 m .40445 .86572 L .40434 .86345 L F
.40148 .86337 m .40145 .86584 L .40445 .86572 L F
.739 .669 .782 r
.47411 .84741 m .47758 .84764 L .47637 .84491 L F
.749 .619 .715 r
.47411 .84741 m .4763 .84974 L .47758 .84764 L F
.747 .672 .778 r
.47637 .84491 m .47758 .84764 L .47957 .84513 L F
.302 .107 .441 r
.38762 .91804 m .38661 .91774 L .38816 .91573 L F
0 .4 .85 r
.38762 .91804 m .38661 .91774 L .38438 .91563 L F
.239 0 0 r
.38497 .91748 m .38661 .91774 L .38762 .91804 L F
.584 .861 .995 r
.5957 .76561 m .5933 .76626 L .5926 .76551 L F
.753 .831 .912 r
.51767 .88077 m .51896 .87839 L .51654 .8806 L F
.51767 .88077 m .52014 .8796 L .51896 .87839 L F
.982 .886 .653 r
.67191 .71809 m .67071 .72215 L .67164 .72176 L F
.966 .923 .702 r
.6006 .81073 m .59857 .81241 L .59929 .81011 L F
.6006 .81073 m .59934 .81376 L .59857 .81241 L F
.88 .845 .806 r
.60253 .80781 m .6006 .81073 L .59929 .81011 L F
.535 .308 .517 r
.33531 .66556 m .33655 .66662 L .33821 .66574 L F
.65 .826 .968 r
.36812 .72526 m .36611 .72602 L .3648 .72511 L F
.691 .531 .665 r
.64102 .71074 m .64338 .7079 L .64137 .70855 L F
0 0 0 r
.59913 .8446 m .60176 .84192 L .60087 .84347 L F
0 0 .147 r
.60176 .84192 m .60369 .83922 L .60367 .8418 L F
.185 0 .003 r
.60087 .84347 m .60176 .84192 L .60367 .8418 L F
.738 .399 .408 r
.46609 .85871 m .46256 .85981 L .46426 .85823 L F
.46609 .85871 m .46601 .86037 L .46256 .85981 L F
.824 .478 .402 r
.46827 .86053 m .46601 .86037 L .46609 .85871 L F
.09 .647 .775 r
.49095 .88335 m .49181 .88322 L .49003 .88315 L F
.49095 .88335 m .49274 .88327 L .49181 .88322 L F
.899 .97 .817 r
.68394 .75536 m .68119 .75766 L .68215 .75636 L F
.354 .662 .972 r
.66133 .75268 m .65933 .75253 L .65843 .75153 L F
.745 .651 .756 r
.69221 .71673 m .69515 .7166 L .69413 .71344 L F
.745 .649 .753 r
.69156 .71853 m .69515 .7166 L .69221 .71673 L F
.652 .598 .781 r
.69413 .71344 m .69515 .7166 L .69742 .71612 L F
.339 .431 .809 r
.69515 .7166 m .69755 .71829 L .69742 .71612 L F
.335 0 .135 r
.53663 .84488 m .53372 .84708 L .53449 .84471 L F
.66 .306 .361 r
.53559 .83738 m .53842 .83817 L .53649 .83616 L F
.698 .46 .56 r
.66377 .76333 m .66341 .76105 L .66783 .76097 L F
.66377 .76333 m .66783 .76097 L .66523 .76051 L F
.494 .396 .673 r
.59118 .77034 m .59298 .7673 L .59166 .76899 L F
.646 .462 .621 r
.41946 .84497 m .41721 .84763 L .41946 .8473 L F
.637 .509 .691 r
.42145 .84231 m .41946 .84497 L .42172 .84468 L F
.668 .507 .658 r
.41946 .8473 m .42172 .84468 L .41946 .84497 L F
.089 .306 .786 r
.66657 .70799 m .66595 .70875 L .66547 .7072 L F
0 0 .235 r
.66657 .70799 m .66699 .71042 L .66595 .70875 L F
.485 .011 .054 r
.48233 .88473 m .48563 .88418 L .48442 .88497 L F
0 0 0 r
.48666 .88406 m .48563 .88418 L .48723 .88364 L F
.48442 .88497 m .48563 .88418 L .48666 .88406 L F
.5 .266 .491 r
.37441 .79183 m .37202 .79422 L .37238 .79228 L F
.995 .869 .559 r
.68386 .75258 m .68394 .75536 L .68429 .75317 L F
.589 .455 .666 r
.66778 .75553 m .66857 .75766 L .66584 .75814 L F
0 0 .523 r
.66696 .75925 m .66584 .75814 L .66857 .75766 L F
.589 .455 .666 r
.66584 .75814 m .66857 .75766 L .66778 .75553 L F
.61 .487 .687 r
.41567 .74244 m .41286 .73951 L .41476 .73905 L F
.41567 .74244 m .41371 .74332 L .41286 .73951 L F
.687 .256 .22 r
.67722 .75785 m .67957 .7578 L .67851 .75934 L F
.106 0 0 r
.67957 .7578 m .68119 .75766 L .67851 .75934 L F
.85 .807 .808 r
.60219 .8058 m .60253 .80781 L .60012 .80814 L F
.88 .845 .806 r
.60253 .80781 m .59929 .81011 L .60012 .80814 L F
.473 .219 .448 r
.37449 .77675 m .37604 .77821 L .37646 .77637 L F
.37449 .77675 m .37407 .77865 L .37604 .77821 L F
.614 .512 .714 r
.63438 .75491 m .63312 .7589 L .63237 .75576 L F
.63438 .75491 m .63543 .75859 L .63312 .7589 L F
.558 .125 .175 r
.56474 .77595 m .56828 .77468 L .56542 .77569 L F
.56474 .77595 m .56704 .77625 L .56828 .77468 L F
.402 0 .076 r
.56828 .77468 m .57008 .77558 L .57039 .77428 L F
.56828 .77468 m .56704 .77625 L .57008 .77558 L F
.985 .734 .465 r
.68053 .74195 m .68155 .74259 L .6805 .7396 L F
0 .159 .615 r
.68324 .74372 m .68155 .74259 L .68053 .74195 L F
.68324 .74372 m .6841 .74442 L .68155 .74259 L F
.565 .383 .594 r
.62793 .74453 m .62738 .74785 L .62829 .74656 L F
.62793 .74453 m .63015 .74746 L .62738 .74785 L F
.419 .3 .61 r
.6294 .74196 m .63121 .74391 L .62793 .74453 L F
.626 .396 .549 r
.63222 .74703 m .62793 .74453 L .63121 .74391 L F
.63222 .74703 m .63015 .74746 L .62793 .74453 L F
.93 .62 .432 r
.66768 .74023 m .66658 .74137 L .6664 .73955 L F
.993 .793 .533 r
.66768 .74023 m .66763 .74277 L .66658 .74137 L F
.189 .706 .884 r
.3822 .72726 m .38465 .72719 L .38528 .72743 L F
.165 .433 .868 r
.38586 .72635 m .38528 .72743 L .38465 .72719 L F
.38586 .72635 m .38755 .72868 L .38528 .72743 L F
.425 .206 .476 r
.47546 .86321 m .47437 .86524 L .47333 .86308 L F
.375 .184 .49 r
.47437 .86524 m .47281 .86589 L .47333 .86308 L F
.63 .593 .794 r
.71025 .71098 m .70691 .70846 L .70917 .70798 L F
.495 .524 .816 r
.71131 .71015 m .71025 .71098 L .70917 .70798 L F
0 0 .399 r
.71131 .71015 m .71065 .7135 L .71025 .71098 L F
.757 .514 .566 r
.42847 .8917 m .43199 .88959 L .42971 .89261 L F
.42847 .8917 m .43181 .89219 L .43199 .88959 L F
.903 .501 .096 r
.43246 .89072 m .43199 .88959 L .43181 .89219 L F
.543 0 0 r
.51002 .88099 m .51228 .88136 L .51144 .88197 L F
.222 0 0 r
.51228 .88136 m .51357 .88167 L .51144 .88197 L F
.51228 .88136 m .51445 .88119 L .51357 .88167 L F
.543 .353 .574 r
.52248 .83148 m .52459 .82881 L .52307 .82953 L F
0 0 0 r
.38513 .74657 m .38363 .7474 L .38418 .74699 L F
.522 .221 .398 r
.52669 .81312 m .5293 .81292 L .52913 .81072 L F
.209 0 .219 r
.52913 .81072 m .53108 .81025 L .53187 .80801 L F
.041 0 .339 r
.52913 .81072 m .53019 .81168 L .53108 .81025 L F
.52913 .81072 m .5293 .81292 L .53019 .81168 L F
.816 .477 .415 r
.49798 .84444 m .49464 .84181 L .49749 .84277 L F
.761 .619 .702 r
.67913 .71887 m .6797 .71868 L .67671 .71645 L F
.135 .64 .903 r
.37075 .74972 m .36752 .74903 L .36864 .74995 L F
.122 0 0 r
.48197 .86904 m .47888 .8686 L .48093 .86817 L F
.377 .367 .721 r
.48354 .86768 m .48197 .86904 L .48093 .86817 L F
.48354 .86768 m .48407 .87055 L .48197 .86904 L F
.701 .513 .63 r
.5524 .79214 m .55522 .79249 L .55209 .79055 L F
.944 .621 .391 r
.67816 .7268 m .67731 .72835 L .67713 .72611 L F
.67816 .7268 m .67855 .72896 L .67731 .72835 L F
.634 .42 .575 r
.5317 .84754 m .52917 .84987 L .52948 .84778 L F
.813 .771 .813 r
.6094 .78967 m .61 .7922 L .60715 .7922 L F
.825 .72 .75 r
.61 .7922 m .60809 .79498 L .60715 .7922 L F
.839 .785 .8 r
.61204 .78942 m .61 .7922 L .6094 .78967 L F
.588 .411 .609 r
.45194 .858 m .44997 .85986 L .44973 .85814 L F
.665 .937 .967 r
.69101 .71185 m .68765 .71267 L .68865 .71223 L F
.652 .598 .781 r
.69413 .71344 m .69742 .71612 L .69745 .71374 L F
.497 .363 .628 r
.69742 .71612 m .69958 .71568 L .69745 .71374 L F
.64 .345 .455 r
.69745 .71374 m .69958 .71568 L .69984 .71378 L F
.497 .363 .628 r
.69742 .71612 m .69958 .71568 L .69745 .71374 L F
.647 .516 .69 r
.45404 .86824 m .45181 .87057 L .45084 .86739 L F
.172 .273 .728 r
.69688 .70714 m .69582 .70871 L .69498 .70565 L F
.551 .426 .663 r
.69843 .71035 m .69582 .70871 L .69688 .70714 L F
.69843 .71035 m .69645 .71068 L .69582 .70871 L F
.826 .764 .794 r
.61473 .78502 m .61113 .78668 L .61296 .78388 L F
.61473 .78502 m .61271 .78758 L .61113 .78668 L F
.68 .374 .449 r
.65419 .7572 m .65692 .75711 L .65713 .75575 L F
.354 .744 .986 r
.65713 .75575 m .65757 .75552 L .65551 .75476 L F
.1 0 .328 r
.65692 .75711 m .65757 .75552 L .65713 .75575 L F
.8 .615 .651 r
.47411 .84741 m .47364 .85034 L .4763 .84974 L F
.667 .291 .324 r
.47364 .85034 m .47449 .85147 L .4763 .84974 L F
.353 0 0 r
.47449 .85147 m .47638 .85147 L .4763 .84974 L F
.766 .837 .906 r
.39084 .89438 m .39228 .89528 L .39401 .89387 L F
.519 .126 .235 r
.57115 .77357 m .57039 .77428 L .57331 .77345 L F
.588 .411 .609 r
.45194 .858 m .45215 .8596 L .44997 .85986 L F
.982 .878 .653 r
.62565 .7896 m .62719 .78719 L .62689 .78637 L F
.62565 .7896 m .62654 .79003 L .62719 .78719 L F
.951 .598 .271 r
.68255 .74931 m .68369 .74981 L .68296 .7476 L F
.68255 .74931 m .68296 .7476 L .68428 .74646 L F
.522 .288 .501 r
.39526 .77832 m .39357 .77662 L .39565 .7763 L F
.39526 .77832 m .39325 .77874 L .39357 .77662 L F
.843 .737 .746 r
.6418 .71295 m .64215 .71512 L .64397 .71204 L F
.64391 .71149 m .64397 .71204 L .64457 .71104 L F
.6418 .71295 m .64397 .71204 L .64391 .71149 L F
.6418 .71295 m .64457 .71104 L .64368 .71263 L F
0 0 0 r
.64773 .7093 m .64638 .7099 L .64955 .7076 L F
.7 .342 .366 r
.64546 .70705 m .64773 .7093 L .64712 .7077 L F
.64546 .70705 m .64498 .70961 L .64773 .7093 L F
0 0 0 r
.64773 .7093 m .64602 .71045 L .64638 .7099 L F
.691 .888 .97 r
.64498 .70961 m .64602 .71045 L .64773 .7093 L F
.065 0 .021 r
.64773 .7093 m .64498 .70961 L .64703 .7083 L F
0 0 0 r
.64638 .7099 m .64602 .71045 L .64457 .71104 L F
.64602 .71045 m .64368 .71263 L .64457 .71104 L F
.64602 .71045 m .64469 .71205 L .64368 .71263 L F
.956 .881 .72 r
.64498 .70961 m .64469 .71205 L .64602 .71045 L F
.065 0 .021 r
.64773 .7093 m .64469 .71205 L .64498 .70961 L F
.752 .52 .58 r
.64703 .7083 m .64554 .70986 L .64498 .70961 L F
0 .031 .567 r
.6436 .70872 m .64431 .71142 L .64352 .70805 L F
.691 .531 .665 r
.64102 .71074 m .64431 .71142 L .64338 .7079 L F
.065 0 .021 r
.64773 .7093 m .64695 .71109 L .64469 .71205 L F
.659 .267 .291 r
.64419 .71127 m .64695 .71109 L .64498 .70961 L F
.64419 .71127 m .64695 .71109 L .64498 .70961 L F
.752 .52 .58 r
.64554 .70986 m .64419 .71127 L .64498 .70961 L F
0 .031 .567 r
.64352 .70805 m .64376 .70906 L .64498 .70961 L F
.64376 .70906 m .64431 .71142 L .64498 .70961 L F
.64338 .7079 m .6436 .70872 L .64352 .70805 L F
.593 .492 .708 r
.42558 .75013 m .42597 .7524 L .42385 .75283 L F
.592 .44 .644 r
.42623 .75482 m .42385 .75283 L .42597 .7524 L F
.42623 .75482 m .42424 .75547 L .42385 .75283 L F
.854 .746 .744 r
.61271 .78758 m .61204 .78942 L .61113 .78668 L F
.571 .36 .555 r
.65111 .72918 m .65345 .72901 L .6535 .72684 L F
.6535 .72684 m .65345 .72901 L .65111 .72918 L F
.539 .37 .601 r
.65551 .72408 m .65562 .72644 L .6535 .72684 L F
.524 .322 .548 r
.65562 .72644 m .65345 .72901 L .6535 .72684 L F
.539 .37 .601 r
.65551 .72408 m .65562 .72644 L .6535 .72684 L F
.524 .322 .548 r
.6535 .72684 m .65345 .72901 L .65562 .72644 L F
0 0 .471 r
.56058 .81879 m .56172 .82173 L .56149 .82083 L F
.923 .551 .133 r
.56172 .82173 m .56162 .82295 L .56149 .82083 L F
.56172 .82173 m .56249 .8238 L .56162 .82295 L F
.252 .006 .333 r
.38438 .91563 m .38315 .91589 L .38238 .91813 L F
.632 .287 .369 r
.49541 .84915 m .49572 .84952 L .49776 .84746 L F
.885 .758 .717 r
.49572 .84952 m .49839 .84726 L .49776 .84746 L F
.873 .757 .732 r
.66507 .7321 m .66275 .73155 L .66417 .72886 L F
.809 .54 .532 r
.66507 .7321 m .6623 .73377 L .66275 .73155 L F
.66507 .7321 m .66549 .7343 L .6623 .73377 L F
.661 .48 .628 r
.42618 .83956 m .42894 .83956 L .42895 .83715 L F
.665 .483 .628 r
.42895 .83715 m .42894 .83956 L .43121 .83684 L F
.556 .575 .829 r
.56492 .80254 m .56434 .80539 L .56323 .80253 L F
.56492 .80254 m .56687 .80576 L .56434 .80539 L F
.662 .517 .677 r
.56625 .80775 m .56434 .80539 L .56687 .80576 L F
.56625 .80775 m .56428 .80841 L .56434 .80539 L F
.844 .742 .751 r
.61204 .78942 m .6094 .78967 L .61113 .78668 L F
.292 0 .176 r
.35773 .78762 m .35881 .78836 L .35963 .78724 L F
.35773 .78762 m .35691 .78901 L .35881 .78836 L F
.827 .744 .772 r
.46827 .86053 m .46459 .86217 L .46601 .86037 L F
.46827 .86053 m .46666 .86263 L .46459 .86217 L F
.821 .586 .032 r
.54933 .81792 m .54992 .82146 L .54959 .81867 L F
.666 .541 .702 r
.39477 .86884 m .39502 .87119 L .39704 .86858 L F
.407 .517 .857 r
.57661 .82894 m .57404 .82662 L .57521 .82711 L F
.883 .975 .672 r
.57408 .82576 m .57575 .82373 L .57555 .82368 L F
.848 .616 .074 r
.57555 .82368 m .57575 .82373 L .5753 .821 L F
.836 .788 .806 r
.70691 .70846 m .70433 .70836 L .70585 .7072 L F
.607 .728 .931 r
.70917 .70798 m .70691 .70846 L .70585 .7072 L F
.489 .34 .605 r
.48333 .85072 m .48547 .85021 L .48539 .84733 L F
.701 .514 .632 r
.39231 .87135 m .39507 .87364 L .39502 .87119 L F
.39231 .87135 m .39269 .8738 L .39507 .87364 L F
.435 .804 .994 r
.52582 .8756 m .52759 .87643 L .52961 .87613 L F
.583 .109 .094 r
.50979 .84468 m .50893 .84623 L .50652 .8447 L F
.628 .572 .772 r
.50979 .84468 m .51299 .84768 L .51155 .84526 L F
.8 .547 .555 r
.51204 .84646 m .50979 .84468 L .51155 .84526 L F
.51204 .84646 m .50893 .84623 L .50979 .84468 L F
.619 .956 .904 r
.52038 .83348 m .5179 .83482 L .51916 .8335 L F
.52038 .83348 m .5179 .83482 L .51916 .8335 L F
.561 .357 .562 r
.6135 .74543 m .61606 .7459 L .61602 .743 L F
.587 .569 .8 r
.61383 .74724 m .61606 .7459 L .6135 .74543 L F
.802 .5 .478 r
.49301 .8528 m .49155 .85458 L .49187 .8532 L F
.488 .522 .819 r
.49033 .84955 m .4917 .8528 L .49483 .85241 L F
.4917 .8528 m .49187 .8532 L .49207 .85314 L F
.802 .5 .478 r
.49301 .8528 m .49478 .8553 L .49431 .85519 L F
.488 .522 .819 r
.4917 .8528 m .49207 .85314 L .49483 .85241 L F
.802 .5 .478 r
.49245 .85349 m .49431 .85519 L .49155 .85458 L F
.49301 .8528 m .49431 .85519 L .49245 .85349 L F
.587 .569 .8 r
.61383 .74724 m .6167 .74707 L .61606 .7459 L F
.546 .388 .618 r
.61397 .7499 m .6167 .74707 L .61383 .74724 L F
.209 0 0 r
.55743 .77872 m .55941 .7784 L .56068 .77726 L F
.155 0 0 r
.55941 .7784 m .56262 .77641 L .56068 .77726 L F
.945 .927 .756 r
.62592 .79124 m .62654 .79003 L .62565 .7896 L F
.778 .626 .691 r
.48471 .8666 m .48555 .86536 L .48246 .86631 L F
.862 .589 .522 r
.48641 .86887 m .48555 .86536 L .48471 .8666 L F
.614 .199 .232 r
.36521 .75241 m .36182 .75266 L .36346 .75128 L F
.911 .659 .544 r
.59194 .78193 m .59042 .78347 L .59034 .78161 L F
.59194 .78193 m .59198 .78434 L .59042 .78347 L F
.872 .932 .859 r
.63238 .78162 m .6337 .77859 L .63167 .78137 L F
.63238 .78162 m .63464 .77918 L .6337 .77859 L F
.626 .437 .606 r
.39931 .86593 m .39704 .86858 L .39931 .86824 L F
.628 .438 .606 r
.39931 .86593 m .4017 .8679 L .40145 .86584 L F
.39931 .86593 m .39931 .86824 L .4017 .8679 L F
.703 .734 .875 r
.70607 .71663 m .70692 .71354 L .70495 .71524 L F
.70607 .71663 m .70797 .71546 L .70692 .71354 L F
.554 .323 .519 r
.60773 .75576 m .60977 .75747 L .60994 .75534 L F
.60773 .75576 m .60762 .75785 L .60977 .75747 L F
.633 .479 .656 r
.41085 .85551 m .4132 .85765 L .41313 .85525 L F
.41085 .85551 m .41097 .85792 L .4132 .85765 L F
.945 .927 .756 r
.62592 .79124 m .62565 .7896 L .62391 .79238 L F
.939 .885 .753 r
.62409 .79458 m .62592 .79124 L .62391 .79238 L F
.555 .476 .721 r
.54072 .83973 m .54103 .84208 L .53909 .84212 L F
.528 .917 .807 r
.4956 .88221 m .49784 .88118 L .49756 .88179 L F
.081 0 0 r
.49784 .88118 m .5007 .87976 L .49946 .88106 L F
.075 0 0 r
.49756 .88179 m .49784 .88118 L .49946 .88106 L F
.624 .342 .471 r
.54953 .83962 m .54614 .84221 L .54619 .83938 L F
.54953 .83962 m .54948 .84206 L .54614 .84221 L F
.644 .359 .472 r
.55078 .84181 m .54948 .84206 L .54953 .83962 L F
0 0 .381 r
.49704 .82345 m .49754 .82447 L .49753 .82306 L F
.968 .923 .699 r
.59857 .81241 m .59934 .81376 L .59842 .81569 L F
.648 .386 .509 r
.45987 .83365 m .46245 .83177 L .46025 .83198 L F
.785 .837 .891 r
.51896 .87839 m .52014 .8796 L .52185 .87801 L F
.298 .789 .749 r
.6593 .76615 m .66069 .76557 L .65833 .76577 L F
.6593 .76615 m .66127 .76547 L .66069 .76557 L F
.691 .617 .769 r
.62267 .76319 m .62388 .76629 L .62053 .7656 L F
.741 .642 .75 r
.62603 .76367 m .62388 .76629 L .62267 .76319 L F
.691 .617 .769 r
.62267 .76319 m .62053 .7656 L .62053 .76379 L F
.761 .619 .702 r
.67913 .71887 m .67671 .71645 L .67619 .71841 L F
.703 .246 .163 r
.678 .71935 m .67913 .71887 L .67619 .71841 L F
0 .114 .665 r
.68059 .71996 m .68126 .72122 L .67913 .71887 L F
.68059 .71996 m .67913 .71887 L .678 .71935 L F
0 0 0 r
.5144 .84732 m .51415 .8474 L .51299 .84768 L F
.5152 .84712 m .51415 .8474 L .5144 .84732 L F
.5152 .84712 m .51415 .8474 L .51299 .84768 L F
.122 .34 .806 r
.51299 .84768 m .51415 .8474 L .51155 .84526 L F
.712 .319 .302 r
.51155 .84526 m .51415 .8474 L .51204 .84646 L F
.7 .892 .517 r
.51495 .84588 m .51385 .8475 L .51415 .8474 L F
.376 0 0 r
.51375 .84757 m .51304 .84871 L .51062 .84886 L F
.51415 .8474 m .51304 .84871 L .51375 .84757 L F
.51415 .8474 m .51062 .84886 L .51204 .84646 L F
.46 .07 .211 r
.51062 .84886 m .51304 .84871 L .51214 .85057 L F
.91 .87 .435 r
.51231 .84987 m .51304 .84871 L .51287 .84759 L F
.51214 .85057 m .51304 .84871 L .51231 .84987 L F
.7 .892 .517 r
.51385 .8475 m .51304 .84871 L .51415 .8474 L F
.87 .912 .856 r
.71288 .73781 m .713 .7396 L .71157 .7402 L F
.389 .546 .89 r
.71288 .73781 m .71445 .73857 L .713 .7396 L F
.07 0 .392 r
.71445 .73857 m .71354 .74174 L .713 .7396 L F
.791 .865 .904 r
.69412 .72622 m .69681 .72412 L .69555 .7233 L F
.578 .199 .287 r
.56319 .78104 m .56102 .78185 L .56096 .78185 L F
.56319 .78104 m .56096 .78185 L .5584 .78155 L F
.74 .956 .943 r
.56279 .78119 m .56319 .78104 L .56295 .78155 L F
.56254 .78065 m .56319 .78104 L .56279 .78119 L F
.403 .536 .876 r
.56295 .78155 m .56541 .77992 L .56254 .78065 L F
.56295 .78155 m .56408 .78213 L .56541 .77992 L F
.464 .282 .548 r
.61602 .743 m .61727 .74541 L .61831 .74255 L F
.61602 .743 m .61606 .7459 L .61727 .74541 L F
.683 .566 .716 r
.39502 .87119 m .3976 .87115 L .39704 .86858 L F
.677 .499 .638 r
.39507 .87364 m .3976 .87115 L .39502 .87119 L F
.819 .734 .771 r
.69156 .71853 m .69023 .71879 L .69221 .71673 L F
.699 .477 .583 r
.69156 .71853 m .68992 .72116 L .69023 .71879 L F
.69156 .71853 m .69273 .72116 L .68992 .72116 L F
.322 .197 .55 r
.69221 .71673 m .6936 .71857 L .69156 .71853 L F
.418 .394 .725 r
.6936 .71857 m .69273 .72116 L .69156 .71853 L F
.503 .086 .182 r
.48453 .82326 m .48686 .82386 L .48794 .8215 L F
0 0 .5 r
.48897 .82257 m .48794 .8215 L .48686 .82386 L F
.996 .806 .445 r
.5816 .82942 m .58229 .82997 L .58198 .83017 L F
.02 .529 .868 r
.58506 .83059 m .58229 .82997 L .5816 .82942 L F
.69 .643 .797 r
.63867 .76059 m .63543 .75859 L .63757 .75767 L F
.719 .645 .775 r
.64097 .75816 m .63867 .76059 L .63757 .75767 L F
.497 .84 .997 r
.33354 .67686 m .32994 .67673 L .33212 .67614 L F
.453 .8 .998 r
.33212 .67614 m .33496 .67637 L .33354 .67686 L F
.556 .395 .618 r
.33572 .6789 m .33354 .67686 L .33496 .67637 L F
.33572 .6789 m .33328 .67942 L .33354 .67686 L F
.7 .658 .805 r
.64525 .7546 m .64624 .75643 L .64302 .7554 L F
.599 .558 .78 r
.64736 .7525 m .64624 .75643 L .64525 .7546 L F
.64736 .7525 m .64859 .7559 L .64624 .75643 L F
.604 .597 .818 r
.64624 .75643 m .64859 .7559 L .64945 .75853 L F
.801 .898 .911 r
.47635 .87079 m .47356 .87133 L .47552 .8705 L F
.785 .991 .884 r
.47888 .8686 m .47635 .87079 L .47552 .8705 L F
.628 .302 .4 r
.46046 .85811 m .46256 .85981 L .46089 .85958 L F
.647 .289 .35 r
.46426 .85823 m .46256 .85981 L .46046 .85811 L F
.67 .361 .441 r
.58083 .77139 m .58301 .77348 L .5841 .77112 L F
.67 .36 .441 r
.5841 .77112 m .58301 .77348 L .58625 .77313 L F
.5841 .77112 m .58625 .77313 L .58643 .77146 L F
.416 0 .128 r
.49873 .87543 m .49743 .87516 L .49604 .87594 L F
.49873 .87543 m .49973 .8745 L .49743 .87516 L F
.559 0 0 r
.53928 .81027 m .54287 .8124 L .54027 .81118 L F
.467 0 0 r
.50944 .83895 m .51264 .83803 L .51136 .83822 L F
.928 .961 .773 r
.63691 .71313 m .63476 .71593 L .63602 .7153 L F
.415 .819 .612 r
.63602 .7153 m .63953 .71299 L .63691 .71313 L F
.514 .237 .431 r
.41949 .76089 m .41704 .76298 L .41736 .76103 L F
.127 0 .389 r
.60949 .82652 m .61138 .82354 L .61111 .8258 L F
.151 .013 .425 r
.60928 .82871 m .60949 .82652 L .61111 .8258 L F
.554 .45 .691 r
.41567 .74244 m .41394 .74498 L .41371 .74332 L F
.41567 .74244 m .41594 .74461 L .41394 .74498 L F
.522 .421 .681 r
.41594 .74461 m .41438 .74801 L .41394 .74498 L F
.962 .639 .349 r
.684 .73982 m .68332 .74147 L .68245 .73936 L F
.684 .73982 m .68449 .74226 L .68332 .74147 L F
.204 0 .137 r
.38363 .7474 m .38103 .7496 L .38197 .74811 L F
.815 .861 .883 r
.54877 .78959 m .55082 .78957 L .55086 .78892 L F
.54877 .78959 m .55082 .78957 L .55086 .78892 L F
.782 .759 .832 r
.39087 .72849 m .38924 .73009 L .38755 .72868 L F
.531 .617 .883 r
.40084 .7478 m .40199 .74659 L .39941 .7465 L F
.40084 .7478 m .40282 .74752 L .40199 .74659 L F
.629 .584 .785 r
.65059 .75496 m .64945 .75853 L .64859 .7559 L F
.65059 .75496 m .65167 .75803 L .64945 .75853 L F
.227 0 .228 r
.53187 .80801 m .53285 .80941 L .53398 .80852 L F
.53187 .80801 m .53108 .81025 L .53285 .80941 L F
.886 .917 .84 r
.63464 .77918 m .6358 .77591 L .6337 .77859 L F
.63464 .77918 m .63682 .77649 L .6358 .77591 L F
.799 .905 .916 r
.48376 .82892 m .48629 .82807 L .48587 .82685 L F
.484 .484 .782 r
.48629 .82807 m .48785 .82594 L .48587 .82685 L F
.48629 .82807 m .48964 .82974 L .48785 .82594 L F
.564 .304 .48 r
.38811 .76832 m .39061 .76615 L .38831 .7662 L F
.644 .488 .657 r
.41313 .85525 m .41522 .85264 L .41298 .85289 L F
0 0 0 r
.66812 .74777 m .6667 .75046 L .6676 .74903 L F
.67038 .74357 m .66812 .74777 L .66852 .74728 L F
.598 .122 .095 r
.53398 .80852 m .5362 .8098 L .53697 .80866 L F
.689 .225 .147 r
.5362 .8098 m .53928 .81027 L .53697 .80866 L F
.667 .587 .756 r
.3854 .87887 m .38643 .88176 L .38874 .88154 L F
.634 .506 .69 r
.38643 .88176 m .38884 .88373 L .38874 .88154 L F
.38643 .88176 m .38667 .88419 L .38884 .88373 L F
.424 0 0 r
.39302 .72774 m .39527 .72804 L .39627 .72715 L F
.237 0 0 r
.39627 .72715 m .39692 .72795 L .39527 .72804 L F
.489 .189 .383 r
.36916 .78196 m .37128 .78169 L .3721 .77911 L F
.451 .153 .367 r
.3721 .77911 m .37329 .78112 L .37407 .77865 L F
.3721 .77911 m .37128 .78169 L .37329 .78112 L F
.432 .093 .289 r
.57187 .7786 m .56991 .77964 L .56954 .77961 L F
.09 .633 .843 r
.43741 .74007 m .4361 .73975 L .43414 .73967 L F
.43741 .74007 m .4361 .73975 L .43398 .73965 L F
.606 .699 .909 r
.43988 .73966 m .43741 .74007 L .43778 .73799 L F
.641 .933 .969 r
.43741 .74007 m .43833 .73862 L .43778 .73799 L F
.691 .15 0 r
.43924 .74157 m .4361 .73975 L .43741 .74007 L F
.539 .282 .474 r
.43988 .73966 m .43924 .74157 L .43741 .74007 L F
.691 .15 0 r
.43924 .74157 m .4381 .74144 L .4361 .73975 L F
.524 .362 .603 r
.4361 .73975 m .4381 .74144 L .43823 .73985 L F
.641 .933 .969 r
.43741 .74007 m .4361 .73975 L .43833 .73862 L F
.524 .362 .603 r
.4361 .73975 m .43823 .73985 L .43833 .73862 L F
.09 .633 .843 r
.43414 .73967 m .4361 .73975 L .43398 .73965 L F
.467 .208 .437 r
.39292 .7651 m .39531 .76302 L .3933 .76339 L F
.577 .326 .5 r
.59703 .7818 m .5992 .78359 L .59718 .78342 L F
.628 .306 .406 r
.59951 .78198 m .5992 .78359 L .59703 .7818 L F
.363 .696 .983 r
.39233 .74607 m .39272 .74507 L .39086 .74476 L F
.39233 .74607 m .39392 .74591 L .39272 .74507 L F
.627 .872 .52 r
.52495 .85275 m .52282 .8554 L .52351 .85445 L F
.638 .48 .652 r
.52495 .85275 m .52534 .85552 L .52282 .8554 L F
.635 .434 .593 r
.52282 .8554 m .52506 .85687 L .52534 .85552 L F
.52534 .85552 m .52506 .85687 L .52282 .8554 L F
.415 .478 .816 r
.52282 .8554 m .52506 .85687 L .52351 .85445 L F
.61 .447 .637 r
.52282 .8554 m .52253 .85812 L .52506 .85687 L F
.52506 .85687 m .52253 .85812 L .52282 .8554 L F
.306 .551 .92 r
.53102 .87304 m .52972 .87378 L .52832 .87211 L F
.033 0 .412 r
.52961 .87613 m .52972 .87378 L .53102 .87304 L F
.563 .254 .403 r
.45515 .85793 m .45215 .8596 L .45194 .858 L F
.563 .857 .54 r
.52588 .85165 m .52495 .85275 L .52723 .85036 L F
.627 .272 .35 r
.52917 .84987 m .52588 .85165 L .52723 .85036 L F
.146 0 0 r
.37609 .74958 m .37263 .74996 L .37399 .7503 L F
.014 0 0 r
.37499 .74985 m .37383 .75007 L .37263 .74996 L F
.005 .566 .806 r
.37399 .7503 m .37263 .74996 L .37149 .74985 L F
.014 0 0 r
.37383 .75007 m .37092 .75061 L .37263 .74996 L F
.005 .566 .806 r
.37149 .74985 m .37263 .74996 L .37075 .74972 L F
.639 .665 .859 r
.42039 .75133 m .41791 .75197 L .4169 .74986 L F
.039 0 0 r
.55042 .78304 m .54845 .78451 L .54814 .78273 L F
.55042 .78304 m .54994 .78404 L .54845 .78451 L F
0 0 0 r
.54994 .78404 m .54712 .78597 L .54845 .78451 L F
.678 .848 .965 r
.46666 .86263 m .46361 .86275 L .46459 .86217 L F
.853 .671 .655 r
.52285 .85273 m .52262 .85678 L .52184 .85317 L F
.627 .872 .52 r
.52495 .85275 m .52184 .85317 L .52285 .85273 L F
.52495 .85275 m .52351 .85445 L .52184 .85317 L F
.521 .397 .652 r
.52705 .85449 m .52534 .85552 L .52495 .85275 L F
.658 .366 .464 r
.52351 .85445 m .52705 .85449 L .52495 .85275 L F
.52351 .85445 m .52495 .85275 L .52588 .85165 L F
.776 .653 .726 r
.6235 .73989 m .62146 .7428 L .62003 .74168 L F
.642 .788 .952 r
.62511 .73817 m .6235 .73989 L .6222 .73893 L F
.79 .715 .782 r
.52625 .87352 m .5268 .87563 L .52282 .87362 L F
.971 .89 .689 r
.55316 .84947 m .55409 .84755 L .5523 .84909 L F
.96 .937 .712 r
.5523 .84909 m .55409 .84755 L .55333 .84712 L F
.22 0 0 r
.3522 .75422 m .35282 .75343 L .35492 .75294 L F
.648 .514 .687 r
.40445 .86572 m .40643 .86319 L .40434 .86345 L F
.563 .254 .403 r
.45515 .85793 m .45424 .85919 L .45215 .8596 L F
.676 .392 .484 r
.45515 .85793 m .45711 .86014 L .45424 .85919 L F
.396 .656 .963 r
.44769 .83008 m .45106 .83181 L .44992 .83118 L F
.039 0 0 r
.55042 .78304 m .54814 .78273 L .54966 .78138 L F
.16 .126 .568 r
.55172 .78106 m .55042 .78304 L .54966 .78138 L F
.55172 .78106 m .55151 .78315 L .55042 .78304 L F
.635 .183 .162 r
.55298 .78413 m .54994 .78404 L .55049 .78307 L F
.574 .84 .995 r
.55188 .78339 m .54994 .78404 L .55298 .78413 L F
0 0 0 r
.55075 .78378 m .54913 .78546 L .54994 .78404 L F
.54913 .78546 m .54888 .78572 L .54994 .78404 L F
.635 .183 .162 r
.55049 .78307 m .54994 .78404 L .55042 .78304 L F
.563 .332 .523 r
.40539 .76863 m .40509 .77091 L .40297 .77116 L F
.54 .312 .517 r
.40721 .77054 m .40539 .76863 L .40748 .76838 L F
.40721 .77054 m .40509 .77091 L .40539 .76863 L F
.388 0 0 r
.46188 .88287 m .46293 .88272 L .46279 .88309 L F
.614 .474 .667 r
.5159 .82376 m .51786 .82389 L .51811 .82133 L F
0 .106 .656 r
.5159 .82376 m .51686 .82412 L .51786 .82389 L F
.5159 .82376 m .51769 .82627 L .51704 .8246 L F
.714 .395 .436 r
.51139 .82587 m .51769 .82627 L .51251 .82402 L F
.759 .27 .071 r
.51364 .82805 m .51262 .82837 L .51055 .82627 L F
.951 .619 .357 r
.51156 .8273 m .51139 .82587 L .51055 .82627 L F
.51262 .82837 m .51215 .8274 L .51156 .8273 L F
.51215 .8274 m .51139 .82587 L .51156 .8273 L F
.51262 .82837 m .51143 .8279 L .51139 .82587 L F
.224 0 0 r
.51143 .8279 m .51366 .82768 L .51369 .82767 L F
.51287 .82753 m .51309 .82756 L .51769 .82627 L F
.51309 .82756 m .51415 .82751 L .51769 .82627 L F
.51143 .8279 m .51262 .82759 L .51139 .82587 L F
.51262 .82759 m .51769 .82627 L .51367 .82601 L F
.51262 .82759 m .51367 .82601 L .51139 .82587 L F
.518 .162 .303 r
.51366 .82768 m .51704 .82458 L .51704 .8246 L F
.51415 .82751 m .51704 .8246 L .51769 .82627 L F
.51366 .82768 m .51704 .8246 L .51415 .82751 L F
.51704 .82458 m .51741 .82423 L .51769 .82627 L F
0 .106 .656 r
.51686 .82412 m .51769 .82627 L .51686 .82412 L F
.674 .894 .977 r
.51633 .82687 m .51928 .82667 L .51794 .82627 L F
.433 .057 .224 r
.51846 .82694 m .51633 .82687 L .51794 .82627 L F
.51846 .82694 m .51484 .82857 L .51633 .82687 L F
.518 .162 .303 r
.51704 .82458 m .51704 .82458 L .51741 .82423 L F
.896 .75 .692 r
.51686 .82412 m .51704 .82458 L .51741 .82423 L F
.51704 .82458 m .51769 .82627 L .51741 .82423 L F
.518 .162 .303 r
.51704 .82458 m .51719 .82473 L .51741 .82423 L F
.702 .45 .541 r
.51846 .82694 m .51478 .82993 L .51484 .82857 L F
.451 .096 .271 r
.51759 .82508 m .51604 .82741 L .51804 .8273 L F
.51604 .82741 m .51586 .82768 L .51803 .8273 L F
.51604 .82741 m .51803 .8273 L .51804 .8273 L F
.224 0 0 r
.51309 .82756 m .51369 .82767 L .51415 .82751 L F
.51143 .8279 m .51369 .82767 L .51287 .82753 L F
.451 .096 .271 r
.51741 .82423 m .51719 .82473 L .51759 .82508 L F
.609 .265 .362 r
.51633 .82687 m .51262 .82837 L .51364 .82805 L F
.51633 .82687 m .51484 .82857 L .51262 .82837 L F
.451 .096 .271 r
.51719 .82473 m .51586 .82768 L .51759 .82508 L F
0 .106 .656 r
.51695 .82451 m .51704 .8246 L .51704 .82458 L F
.5159 .82376 m .51704 .8246 L .51695 .82451 L F
.5164 .82395 m .51704 .82458 L .51686 .82412 L F
.5159 .82376 m .51704 .82458 L .5164 .82395 L F
.518 .162 .303 r
.51366 .82768 m .51586 .82768 L .51719 .82473 L F
.51366 .82768 m .51719 .82473 L .51704 .82458 L F
0 0 .123 r
.68621 .71106 m .6874 .71017 L .68758 .70828 L F
.144 .217 .682 r
.68621 .71106 m .68765 .71267 L .6874 .71017 L F
.283 .757 .936 r
.57865 .8485 m .58014 .84797 L .57711 .84776 L F
.57865 .8485 m .58076 .84835 L .58014 .84797 L F
.645 .473 .636 r
.43038 .83418 m .43312 .83424 L .43239 .83144 L F
.682 .495 .627 r
.43239 .83144 m .43532 .83405 L .43534 .83172 L F
.43239 .83144 m .43312 .83424 L .43532 .83405 L F
.775 .506 .528 r
.48159 .85322 m .48089 .85515 L .47932 .85332 L F
.304 .603 .95 r
.48164 .85171 m .48159 .85322 L .47897 .85082 L F
.575 .574 .814 r
.48164 .85171 m .48089 .85515 L .48159 .85322 L F
.857 .923 .872 r
.6358 .77591 m .63682 .77649 L .63917 .77401 L F
.636 .494 .672 r
.41744 .84998 m .41946 .8473 L .41721 .84763 L F
.535 .301 .507 r
.65771 .72403 m .65562 .72644 L .65551 .72408 L F
.65771 .72403 m .65562 .72644 L .65551 .72408 L F
.248 .2 .605 r
.49457 .86468 m .49325 .86549 L .49386 .86296 L F
.077 0 .298 r
.49409 .86591 m .49325 .86549 L .49457 .86468 L F
.806 .64 .677 r
.49545 .83631 m .49545 .83876 L .49656 .83733 L F
.727 .348 .332 r
.49545 .83876 m .49871 .8393 L .49656 .83733 L F
.618 .596 .806 r
.48935 .85237 m .49033 .84955 L .48798 .85173 L F
.48935 .85237 m .49187 .8532 L .49033 .84955 L F
.704 .36 .391 r
.49187 .8532 m .49155 .85458 L .48935 .85237 L F
.49187 .8532 m .49155 .85458 L .48935 .85237 L F
.668 .488 .631 r
.42894 .83956 m .4312 .8395 L .43121 .83684 L F
.532 .408 .657 r
.43121 .83684 m .43312 .83424 L .43038 .83418 L F
.43121 .83684 m .43315 .83663 L .43312 .83424 L F
.594 .46 .668 r
.4312 .8395 m .43315 .83663 L .43121 .83684 L F
.798 .481 0 r
.56282 .82783 m .56249 .82801 L .56186 .82552 L F
.555 .787 .985 r
.42971 .89261 m .43181 .89219 L .42847 .8917 L F
.103 .414 .863 r
.57723 .82877 m .57661 .82894 L .57521 .82711 L F
.291 .112 .457 r
.57833 .83053 m .57661 .82894 L .57723 .82877 L F
.57833 .83053 m .57705 .83074 L .57661 .82894 L F
.719 .943 .956 r
.42387 .88755 m .42536 .88823 L .42727 .88663 L F
.747 .672 .778 r
.47637 .84491 m .47957 .84513 L .47843 .84455 L F
.534 .051 .055 r
.48179 .84425 m .47843 .84455 L .47957 .84513 L F
.318 .805 .871 r
.43852 .8844 m .4414 .88404 L .43982 .88441 L F
.229 .745 .738 r
.43982 .88441 m .4414 .88404 L .44356 .88346 L F
.911 .728 .642 r
.43181 .89219 m .43304 .89503 L .43246 .89072 L F
.677 .493 .629 r
.42366 .84198 m .42673 .84228 L .42618 .83956 L F
.671 .489 .63 r
.42618 .83956 m .42893 .84194 L .42894 .83956 L F
.42618 .83956 m .42673 .84228 L .42893 .84194 L F
.694 .273 .242 r
.59795 .76316 m .60024 .76519 L .60118 .76346 L F
.552 .118 .17 r
.60118 .76346 m .60243 .76488 L .60387 .76248 L F
.60118 .76346 m .60024 .76519 L .60243 .76488 L F
.759 .831 .908 r
.57166 .81778 m .57006 .81944 L .56846 .8185 L F
.631 .442 .609 r
.40614 .86052 m .40859 .86043 L .40863 .85805 L F
.659 .465 .611 r
.40863 .85805 m .4109 .86024 L .41097 .85792 L F
.40863 .85805 m .40859 .86043 L .4109 .86024 L F
.501 .245 .458 r
.38632 .78194 m .38592 .78394 L .3839 .78423 L F
.3879 .78349 m .38632 .78194 L .38846 .78175 L F
.3879 .78349 m .38592 .78394 L .38632 .78194 L F
.625 .75 .937 r
.65395 .76678 m .655 .76496 L .6529 .76561 L F
.65395 .76678 m .65616 .76626 L .655 .76496 L F
.717 .475 .558 r
.69048 .74772 m .69349 .7477 L .6936 .7499 L F
.169 0 0 r
.50108 .87404 m .49973 .8745 L .49873 .87543 L F
.458 0 0 r
.46721 .88195 m .4683 .88163 L .47006 .88222 L F
.626 .501 .691 r
.42145 .84231 m .42392 .84439 L .42366 .84198 L F
.42145 .84231 m .42172 .84468 L .42392 .84439 L F
.783 .283 0 r
.54604 .81524 m .54933 .81792 L .54692 .81621 L F
.73 .817 .919 r
.51651 .85431 m .51725 .85521 L .5151 .85485 L F
.633 .302 .392 r
.51725 .85521 m .5142 .85728 L .5151 .85485 L F
.51725 .85521 m .51688 .8576 L .5142 .85728 L F
.335 .627 .958 r
.51844 .85455 m .51725 .85521 L .51651 .85431 L F
0 0 .187 r
.51844 .85455 m .51688 .8576 L .51725 .85521 L F
.823 .533 .498 r
.56772 .80782 m .56921 .81088 L .57072 .81033 L F
0 .045 .578 r
.57072 .81033 m .57297 .81271 L .57293 .81282 L F
.676 .146 0 r
.56921 .81088 m .57297 .81271 L .57072 .81033 L F
.796 .488 0 r
.54287 .81293 m .54345 .81399 L .54311 .81306 L F
.54289 .81299 m .54345 .81399 L .54287 .81293 L F
0 .316 .709 r
.54501 .81461 m .54345 .81399 L .54289 .81299 L F
.823 .454 .357 r
.54287 .81293 m .54289 .81299 L .54501 .81461 L F
.54158 .81191 m .54323 .81449 L .54287 .81293 L F
.796 .488 0 r
.54284 .81291 m .54289 .81299 L .54287 .81293 L F
0 .316 .709 r
.54501 .81461 m .54289 .81299 L .54284 .81291 L F
.54501 .81461 m .54604 .81524 L .54345 .81399 L F
.823 .454 .357 r
.54289 .81299 m .54341 .81477 L .54501 .81461 L F
.54323 .81449 m .54341 .81477 L .54287 .81293 L F
.54158 .81191 m .54287 .81293 L .54284 .81291 L F
.54287 .81293 m .54501 .81461 L .54284 .81291 L F
.796 .488 0 r
.54284 .81291 m .54311 .81306 L .54287 .8124 L F
.504 .182 .354 r
.47724 .82622 m .47937 .82611 L .48035 .82359 L F
.685 .425 .523 r
.47937 .82611 m .4825 .82358 L .48035 .82359 L F
.653 .45 .596 r
.43532 .83405 m .43779 .83165 L .43534 .83172 L F
.522 .421 .681 r
.41594 .74461 m .41633 .74779 L .41438 .74801 L F
.585 .467 .686 r
.4169 .74986 m .41438 .74801 L .41633 .74779 L F
.4169 .74986 m .41482 .75031 L .41438 .74801 L F
.885 .758 .717 r
.49572 .84952 m .49795 .84996 L .49839 .84726 L F
.706 .375 .415 r
.4957 .8522 m .49795 .84996 L .49572 .84952 L F
.4957 .8522 m .49964 .85221 L .49795 .84996 L F
.134 0 0 r
.40162 .72671 m .39889 .72681 L .39743 .72681 L F
.525 .377 .623 r
.4038 .72886 m .40162 .72671 L .40368 .72632 L F
.4038 .72886 m .40178 .72944 L .40162 .72671 L F
.40162 .72671 m .4038 .72886 L .40368 .72632 L F
.40162 .72671 m .40178 .72944 L .4038 .72886 L F
.577 .358 .547 r
.3793 .7873 m .37917 .78978 L .37679 .78981 L F
.461 .263 .524 r
.38102 .78904 m .3793 .7873 L .38132 .78711 L F
.38102 .78904 m .37917 .78978 L .3793 .7873 L F
.332 .815 .818 r
.58623 .84786 m .58922 .84714 L .5884 .84747 L F
.241 0 0 r
.58922 .84714 m .59044 .84756 L .5884 .84747 L F
.58922 .84714 m .59155 .84717 L .59044 .84756 L F
.873 .711 .19 r
.55535 .84237 m .55546 .83957 L .55513 .8384 L F
.132 .366 .825 r
.69047 .73718 m .69189 .73919 L .69212 .73718 L F
.592 .594 .822 r
.69843 .71035 m .69984 .71378 L .70182 .7131 L F
.585 .296 .444 r
.69984 .71378 m .70159 .71467 L .70182 .7131 L F
.69984 .71378 m .69958 .71568 L .70159 .71467 L F
.921 .825 .366 r
.55571 .83167 m .555 .83346 L .55525 .83385 L F
.786 .379 0 r
.55518 .83111 m .5554 .83114 L .55418 .82905 L F
0 0 .518 r
.55516 .82996 m .55518 .83111 L .55418 .82905 L F
.937 .771 .301 r
.55477 .83106 m .55518 .83111 L .55516 .82996 L F
.55455 .83167 m .55518 .83111 L .55477 .83106 L F
.786 .379 0 r
.55518 .83111 m .55571 .83167 L .5554 .83114 L F
.984 .794 .391 r
.55518 .83111 m .555 .83346 L .55571 .83167 L F
.677 .499 .638 r
.39507 .87364 m .39801 .87362 L .3976 .87115 L F
.635 .525 .712 r
.3976 .87115 m .39931 .86824 L .39704 .86858 L F
.3976 .87115 m .40002 .87115 L .39931 .86824 L F
.695 .511 .635 r
.3976 .87115 m .40038 .87353 L .40002 .87115 L F
.3976 .87115 m .39801 .87362 L .40038 .87353 L F
.167 .358 .809 r
.66763 .74277 m .6686 .74237 L .66658 .74137 L F
.651 .159 .069 r
.67038 .74357 m .66987 .74428 L .66763 .74277 L F
.167 .358 .809 r
.66763 .74277 m .66987 .74428 L .6686 .74237 L F
.886 .905 .836 r
.69221 .71673 m .69023 .71879 L .68945 .71795 L F
.69221 .71673 m .68945 .71795 L .69243 .71778 L F
.752 .248 .019 r
.69309 .71873 m .69221 .71673 L .69243 .71778 L F
.69309 .71873 m .6936 .71857 L .69221 .71673 L F
.732 .211 0 r
.69243 .71778 m .6936 .71857 L .69221 .71673 L F
.505 .169 .33 r
.46727 .83072 m .46937 .83057 L .46767 .8294 L F
.948 .739 .588 r
.52431 .81578 m .52382 .8184 L .5252 .8187 L F
.624 .415 .578 r
.5252 .8187 m .52545 .82104 L .52347 .82037 L F
.939 .568 .228 r
.52382 .8184 m .52545 .82104 L .5252 .8187 L F
.544 .508 .765 r
.5252 .8187 m .52661 .81518 L .52431 .81578 L F
.5252 .8187 m .52755 .8183 L .52661 .81518 L F
.572 .277 .428 r
.365 .79766 m .36672 .79932 L .36476 .79963 L F
.365 .79766 m .3674 .79765 L .36672 .79932 L F
.306 0 .164 r
.36721 .78231 m .36835 .78304 L .36916 .78196 L F
.36721 .78231 m .36646 .78361 L .36835 .78304 L F
.662 .426 .553 r
.56413 .81026 m .56625 .80775 L .56428 .80841 L F
0 0 .22 r
.56505 .80928 m .56428 .80841 L .56625 .80775 L F
.56505 .80928 m .56413 .81026 L .56428 .80841 L F
.341 .746 .982 r
.44613 .88285 m .4469 .88343 L .44872 .88332 L F
.808 .712 .76 r
.60715 .7922 m .60809 .79498 L .60513 .79491 L F
.781 .644 .71 r
.60809 .79498 m .60625 .79797 L .60513 .79491 L F
.60809 .79498 m .60783 .79694 L .60625 .79797 L F
.445 .297 .586 r
.39535 .76081 m .39712 .76214 L .39741 .76031 L F
.39535 .76081 m .39531 .76302 L .39712 .76214 L F
.781 .624 .685 r
.3895 .87589 m .39269 .8738 L .38998 .87403 L F
.743 .375 .357 r
.48354 .86768 m .48471 .8666 L .48246 .86631 L F
.477 .867 .971 r
.58268 .84818 m .58415 .84844 L .58623 .84786 L F
.216 .728 .884 r
.41047 .89226 m .40924 .89203 L .40697 .8922 L F
.876 .953 .855 r
.41098 .88994 m .41047 .89226 L .41262 .88979 L F
.874 .951 .858 r
.41098 .88994 m .40924 .89203 L .41047 .89226 L F
.702 .201 0 r
.69189 .73919 m .69455 .74208 L .69446 .73979 L F
.029 .149 .656 r
.68685 .70547 m .68758 .70828 L .68833 .70697 L F
0 0 .043 r
.68758 .70828 m .6874 .71017 L .68833 .70697 L F
.546 .569 .829 r
.6994 .74333 m .69446 .73979 L .69603 .74002 L F
.196 .1 .512 r
.69446 .73979 m .69588 .74116 L .69603 .74002 L F
.69446 .73979 m .69455 .74208 L .69588 .74116 L F
.716 .503 .601 r
.51389 .81792 m .51689 .81595 L .51416 .81624 L F
.593 .306 .45 r
.60551 .75842 m .60549 .76038 L .6076 .76008 L F
.528 .326 .55 r
.60551 .75842 m .6076 .76008 L .60762 .75785 L F
.94 .913 .763 r
.5706 .81575 m .57293 .81282 L .57297 .81271 L F
.751 .539 .608 r
.49207 .82289 m .49545 .82077 L .4935 .82039 L F
.744 .601 .698 r
.66728 .7221 m .66305 .72385 L .66301 .72137 L F
.66728 .7221 m .66628 .72395 L .66305 .72385 L F
0 0 0 r
.6142 .81554 m .61468 .81325 L .61441 .81525 L F
.61562 .81192 m .61468 .81325 L .61643 .81036 L F
0 0 .037 r
.61441 .81525 m .61468 .81325 L .61562 .81192 L F
.468 0 0 r
.66857 .75766 m .67126 .75816 L .66938 .75803 L F
.697 .199 .056 r
.66938 .75803 m .67126 .75816 L .67328 .75989 L F
.716 .503 .601 r
.51389 .81792 m .51691 .81834 L .51689 .81595 L F
.729 .553 .653 r
.51691 .81834 m .51937 .81571 L .51689 .81595 L F
.221 .725 .902 r
.44872 .88332 m .45194 .88355 L .45073 .88315 L F
.164 .703 .796 r
.45194 .88355 m .45257 .88331 L .45073 .88315 L F
.45194 .88355 m .45438 .88329 L .45257 .88331 L F
.477 .177 .377 r
.40019 .77398 m .39772 .77598 L .39818 .77415 L F
.47 0 .056 r
.48464 .83438 m .48718 .83515 L .48817 .83393 L F
.546 0 0 r
.48718 .83515 m .48884 .83554 L .48817 .83393 L F
.967 .786 .606 r
.54387 .80041 m .54211 .80268 L .54248 .7998 L F
.54387 .80041 m .54344 .80297 L .54211 .80268 L F
.738 .9 .951 r
.54591 .79891 m .54387 .80041 L .54248 .7998 L F
.212 .354 .791 r
.51786 .82389 m .52034 .82621 L .51928 .82667 L F
.611 .298 .415 r
.52034 .82621 m .51794 .82627 L .51928 .82667 L F
.678 .358 .426 r
.58099 .77292 m .58301 .77348 L .58083 .77139 L F
.467 0 0 r
.50944 .83895 m .51158 .83933 L .51264 .83803 L F
.25 0 0 r
.51264 .83803 m .51418 .83883 L .5146 .83833 L F
.631 .225 .255 r
.5511 .79951 m .55362 .80019 L .55342 .79894 L F
.314 0 .101 r
.55342 .79894 m .55547 .79926 L .55646 .79754 L F
.447 .23 .491 r
.55362 .80019 m .55547 .79926 L .55342 .79894 L F
.729 .726 .848 r
.63624 .72626 m .63731 .72826 L .64088 .72597 L F
.546 .768 .98 r
.49105 .82844 m .4923 .82916 L .49346 .82813 L F
.523 .723 .965 r
.4923 .82916 m .49454 .82922 L .49346 .82813 L F
.456 .231 .483 r
.62934 .73158 m .63097 .73311 L .63109 .73105 L F
.606 .77 .958 r
.63097 .73311 m .63074 .73186 L .63109 .73105 L F
.224 0 .046 r
.62934 .73158 m .63109 .73105 L .63171 .72966 L F
.606 .77 .958 r
.63074 .73186 m .63038 .73 L .63109 .73105 L F
.224 0 .046 r
.63171 .72966 m .63109 .73105 L .63195 .72946 L F
.159 .693 .847 r
.63109 .73105 m .63479 .73109 L .63195 .72946 L F
.515 .561 .841 r
.39831 .73085 m .39783 .7339 L .39636 .7311 L F
.39831 .73085 m .39931 .73355 L .39783 .7339 L F
.624 .612 .818 r
.40056 .73479 m .39783 .7339 L .39931 .73355 L F
.842 .921 .886 r
.67441 .71172 m .67186 .71283 L .67376 .71026 L F
0 .252 .679 r
.67577 .71241 m .67441 .71172 L .67376 .71026 L F
.655 .792 .948 r
.67577 .71241 m .67916 .71254 L .67724 .71339 L F
.67577 .71241 m .67916 .71254 L .67724 .71339 L F
0 0 .348 r
.67577 .71241 m .67717 .7111 L .67696 .71294 L F
0 .252 .679 r
.67577 .71241 m .67724 .71339 L .67494 .71203 L F
0 0 .315 r
.67577 .71241 m .6753 .71551 L .67724 .71339 L F
0 0 .348 r
.67577 .71241 m .67696 .71294 L .67685 .7139 L F
0 .252 .679 r
.67577 .71241 m .67494 .71203 L .67441 .71172 L F
.648 .909 .981 r
.64324 .77079 m .64571 .77048 L .64537 .76978 L F
.84 .883 .872 r
.64571 .77048 m .6471 .76761 L .64537 .76978 L F
.64571 .77048 m .64818 .76825 L .6471 .76761 L F
.344 .317 .684 r
.66778 .75553 m .66938 .75803 L .66857 .75766 L F
.66778 .75553 m .66938 .75803 L .66857 .75766 L F
.823 .785 .817 r
.54607 .82857 m .54799 .82943 L .54667 .83041 L F
.574 0 0 r
.55027 .80536 m .54882 .80518 L .54758 .80444 L F
.832 .384 0 r
.55027 .80536 m .55057 .80697 L .54882 .80518 L F
.55027 .80536 m .55173 .80811 L .55057 .80697 L F
.663 .51 .666 r
.41522 .85264 m .4182 .85291 L .41744 .84998 L F
.636 .494 .672 r
.41744 .84998 m .41987 .84986 L .41946 .8473 L F
.652 .503 .669 r
.41744 .84998 m .42037 .85261 L .41987 .84986 L F
.41744 .84998 m .4182 .85291 L .42037 .85261 L F
.519 .34 .579 r
.61224 .7524 m .61397 .7499 L .61189 .7505 L F
.197 .283 .727 r
.38154 .88668 m .38282 .88832 L .38447 .88665 L F
.38154 .88668 m .3833 .88964 L .38282 .88832 L F
.746 .782 .882 r
.66301 .72137 m .66164 .72014 L .66247 .71863 L F
.66301 .72137 m .65985 .72124 L .66164 .72014 L F
.711 .528 .64 r
.66301 .72137 m .66102 .72371 L .65985 .72124 L F
.66301 .72137 m .66305 .72385 L .66102 .72371 L F
.736 .273 .15 r
.50223 .82558 m .50443 .82752 L .50545 .82642 L F
.492 .3 .548 r
.50728 .82835 m .50518 .82886 L .50545 .82642 L F
.725 .259 .142 r
.50443 .82752 m .50728 .82835 L .50545 .82642 L F
.718 .662 .793 r
.69755 .71829 m .69858 .72098 L .70092 .71882 L F
.684 .465 .584 r
.58625 .77313 m .58869 .77102 L .58643 .77146 L F
.813 .711 .753 r
.53047 .85496 m .52996 .85841 L .52815 .85569 L F
.769 .494 .519 r
.52996 .85841 m .53035 .85917 L .52815 .85915 L F
.76 .513 .56 r
.56654 .81055 m .56772 .80782 L .56625 .80775 L F
.56654 .81055 m .56921 .81088 L .56772 .80782 L F
.877 .896 .841 r
.65456 .75129 m .65639 .75124 L .65449 .75301 L F
.425 .632 .941 r
.65704 .74975 m .65639 .75124 L .65456 .75129 L F
.65704 .74975 m .65843 .75153 L .65639 .75124 L F
.697 .684 .834 r
.63013 .74965 m .6291 .75317 L .62783 .74992 L F
.63013 .74965 m .63107 .75233 L .6291 .75317 L F
.644 .488 .657 r
.41313 .85525 m .41536 .85513 L .41522 .85264 L F
.647 .476 .639 r
.4132 .85765 m .41536 .85513 L .41313 .85525 L F
.543 .37 .597 r
.63397 .72661 m .63599 .72386 L .63384 .7243 L F
.997 .791 .436 r
.473 .84677 m .47364 .85034 L .47411 .84741 L F
.858 .925 .872 r
.473 .84677 m .47411 .84741 L .47637 .84491 L F
.519 .34 .579 r
.61224 .7524 m .61458 .75253 L .61397 .7499 L F
.541 .293 .489 r
.61224 .7524 m .61425 .75445 L .61458 .75253 L F
.61224 .7524 m .61207 .75481 L .61425 .75445 L F
.304 .7 .977 r
.47221 .87054 m .47135 .87121 L .47004 .87081 L F
.47221 .87054 m .47356 .87133 L .47135 .87121 L F
0 0 0 r
.67038 .74357 m .66852 .74728 L .66987 .74428 L F
.346 .738 .985 r
.37755 .72572 m .37687 .72647 L .37558 .72569 L F
.37755 .72572 m .37886 .72646 L .37687 .72647 L F
.604 .083 0 r
.58075 .77887 m .57865 .77898 L .57717 .77837 L F
.62 .107 .005 r
.58083 .77921 m .57865 .77898 L .58075 .77887 L F
.677 .527 .674 r
.41536 .85513 m .4182 .85291 L .41522 .85264 L F
.345 .409 .785 r
.48594 .83273 m .48464 .83438 L .48396 .83303 L F
.48594 .83273 m .48718 .83515 L .48464 .83438 L F
.399 .836 .947 r
.39087 .72849 m .38755 .72868 L .38951 .72823 L F
.108 .659 .708 r
.38951 .72823 m .39302 .72774 L .39087 .72849 L F
.415 .819 .612 r
.63602 .7153 m .63868 .71352 L .63953 .71299 L F
.61 .529 .738 r
.63953 .71299 m .6418 .71295 L .64102 .71074 L F
.531 .908 .949 r
.63868 .71352 m .6418 .71295 L .63953 .71299 L F
.614 .41 .581 r
.69742 .71612 m .69913 .71777 L .69958 .71568 L F
.69742 .71612 m .69755 .71829 L .69913 .71777 L F
.668 .507 .658 r
.41946 .8473 m .42245 .84734 L .42172 .84468 L F
.665 .505 .659 r
.42172 .84468 m .42463 .84722 L .42392 .84439 L F
.42172 .84468 m .42245 .84734 L .42463 .84722 L F
.314 .74 .973 r
.49964 .85221 m .50017 .85269 L .4975 .85236 L F
.722 .476 .552 r
.4975 .85236 m .50017 .85269 L .4999 .85546 L F
.991 .782 .399 r
.4999 .85546 m .50017 .85269 L .49964 .85221 L F
.485 .208 .418 r
.39117 .77908 m .39046 .78142 L .38846 .78175 L F
.503 .225 .425 r
.39258 .78105 m .39117 .77908 L .39325 .77874 L F
.39258 .78105 m .39046 .78142 L .39117 .77908 L F
.35 0 0 r
.5007 .87976 m .50136 .8808 L .49946 .88106 L F
.5007 .87976 m .50241 .87966 L .50136 .8808 L F
.545 .252 .421 r
.41001 .76648 m .40963 .76819 L .40748 .76838 L F
.541 .262 .44 r
.41301 .7651 m .40963 .76819 L .41001 .76648 L F
.617 .471 .661 r
.40614 .86052 m .40872 .86292 L .40859 .86043 L F
.40614 .86052 m .40643 .86319 L .40872 .86292 L F
.164 0 .373 r
.62728 .73452 m .62897 .73381 L .62934 .73158 L F
.891 .977 .822 r
.62754 .73676 m .62897 .73381 L .62728 .73452 L F
.448 .083 .251 r
.35181 .79178 m .35383 .79154 L .355 .78946 L F
.441 .076 .247 r
.355 .78946 m .35594 .7912 L .35691 .78901 L F
.355 .78946 m .35383 .79154 L .35594 .7912 L F
.354 .812 .934 r
.69843 .71035 m .70065 .70997 L .70156 .71024 L F
.542 .91 .956 r
.70156 .71024 m .70283 .70928 L .70433 .70836 L F
.70156 .71024 m .70065 .70997 L .70283 .70928 L F
0 0 0 r
.36281 .72508 m .36343 .72485 L .3648 .72511 L F
.36281 .72508 m .36146 .72573 L .36343 .72485 L F
.555 .397 .623 r
.62738 .74785 m .62783 .74992 L .62544 .75016 L F
.724 .458 .523 r
.60462 .77903 m .60665 .7813 L .60511 .78123 L F
.676 .46 .585 r
.60664 .77907 m .60665 .7813 L .60462 .77903 L F
.725 .785 .9 r
.64818 .76825 m .64975 .76538 L .6471 .76761 L F
.64818 .76825 m .65101 .76666 L .64975 .76538 L F
.709 .212 .056 r
.49441 .8759 m .49397 .87436 L .49261 .87429 L F
.49441 .8759 m .49604 .87594 L .49397 .87436 L F
.757 .579 .656 r
.61185 .77867 m .61005 .78147 L .61017 .77915 L F
.61185 .77867 m .61356 .78186 L .61005 .78147 L F
.444 .464 .785 r
.56396 .79941 m .56323 .80253 L .56217 .80059 L F
.56396 .79941 m .56492 .80254 L .56323 .80253 L F
.557 .339 .54 r
.42252 .75743 m .42177 .76067 L .41949 .76089 L F
.589 .427 .629 r
.42424 .75547 m .42396 .75712 L .42252 .75743 L F
.493 .279 .517 r
.42368 .7602 m .42252 .75743 L .42396 .75712 L F
.42368 .7602 m .42177 .76067 L .42252 .75743 L F
.989 .757 .494 r
.6802 .73196 m .67917 .73367 L .67893 .73116 L F
.6802 .73196 m .68008 .73399 L .67917 .73367 L F
.979 .888 .665 r
.59842 .81569 m .59681 .81651 L .5973 .81518 L F
.59842 .81569 m .59731 .81905 L .59681 .81651 L F
.968 .923 .699 r
.59857 .81241 m .59842 .81569 L .5973 .81518 L F
.582 .682 .909 r
.5371 .85811 m .53408 .85615 L .53553 .85738 L F
.412 .031 .202 r
.53375 .86059 m .5371 .85811 L .53553 .85738 L F
.63 .619 .82 r
.38056 .91903 m .38238 .91813 L .3802 .91826 L F
.732 .406 .428 r
.46708 .85422 m .47004 .85267 L .46905 .85197 L F
.46708 .85422 m .46935 .85481 L .47004 .85267 L F
.115 0 0 r
.47267 .85303 m .47121 .85286 L .47004 .85267 L F
.77 .88 .926 r
.47449 .85147 m .47152 .85289 L .47121 .85286 L F
.47152 .85289 m .47078 .85325 L .47121 .85286 L F
.115 0 0 r
.47294 .85307 m .47121 .85286 L .47267 .85303 L F
0 .471 .847 r
.47004 .85267 m .47121 .85286 L .46905 .85197 L F
.222 0 .227 r
.47004 .85267 m .46935 .85481 L .47078 .85325 L F
.366 .041 .275 r
.36279 .80011 m .36196 .80252 L .36041 .80182 L F
.111 0 .163 r
.36338 .80153 m .36279 .80011 L .36476 .79963 L F
.36338 .80153 m .36196 .80252 L .36279 .80011 L F
.985 .757 .513 r
.52993 .82872 m .52981 .83136 L .53074 .83093 L F
.068 .254 .745 r
.53074 .83093 m .53176 .83057 L .52993 .82872 L F
0 0 0 r
.53074 .83093 m .52981 .83136 L .53176 .83057 L F
.668 .494 .64 r
.4109 .86024 m .4132 .85765 L .41097 .85792 L F
.693 .699 .851 r
.56991 .77964 m .56408 .78213 L .56666 .782 L F
.549 .819 .996 r
.38548 .89363 m .38943 .89384 L .38776 .89316 L F
.123 .48 .898 r
.38943 .89384 m .38929 .893 L .38776 .89316 L F
.38943 .89384 m .39084 .89438 L .38929 .893 L F
.862 .973 .86 r
.59006 .82865 m .58839 .83079 L .58694 .83065 L F
.729 .553 .653 r
.51691 .81834 m .52002 .81897 L .51937 .81571 L F
.612 .476 .672 r
.51937 .81571 m .52279 .81823 L .52253 .81584 L F
.51937 .81571 m .52002 .81897 L .52279 .81823 L F
.335 0 .135 r
.53663 .84488 m .53578 .84679 L .53372 .84708 L F
.158 0 .058 r
.53654 .84615 m .53663 .84488 L .53889 .8468 L F
.53654 .84615 m .53578 .84679 L .53663 .84488 L F
.138 .615 .921 r
.47452 .88319 m .47701 .88398 L .47565 .88378 L F
.193 0 0 r
.47701 .88398 m .47781 .88422 L .47565 .88378 L F
.47701 .88398 m .47892 .88447 L .47781 .88422 L F
.667 .587 .756 r
.3854 .87887 m .38874 .88154 L .38743 .87818 L F
.709 .6 .732 r
.38743 .87818 m .38874 .88154 L .39075 .87884 L F
.607 .459 .655 r
.39075 .87884 m .38874 .88154 L .39094 .8813 L F
.671 .556 .715 r
.38884 .88373 m .39094 .8813 L .38874 .88154 L F
.88 .455 .182 r
.55935 .81837 m .56058 .81879 L .56009 .81988 L F
.932 .552 .218 r
.56058 .81879 m .56149 .82083 L .56009 .81988 L F
.714 .614 .745 r
.6419 .75225 m .64302 .7554 L .63943 .75478 L F
.721 .59 .709 r
.64302 .7554 m .64097 .75816 L .63943 .75478 L F
.685 .599 .754 r
.64525 .7546 m .64302 .7554 L .6419 .75225 L F
0 .561 .783 r
.48233 .88473 m .48442 .88473 L .48086 .88449 L F
.48233 .88473 m .48442 .88497 L .48442 .88473 L F
.546 .388 .618 r
.61397 .7499 m .61663 .74954 L .6167 .74707 L F
.472 .311 .581 r
.61397 .7499 m .61644 .75184 L .61663 .74954 L F
.61397 .7499 m .61458 .75253 L .61644 .75184 L F
.217 .348 .783 r
.49438 .83347 m .49371 .83516 L .49368 .8343 L F
.484 .047 .132 r
.34117 .72962 m .34302 .73047 L .3446 .72884 L F
.254 0 0 r
.34302 .73047 m .34665 .72894 L .3446 .72884 L F
.388 .001 .179 r
.36041 .80182 m .36089 .8037 L .359 .80419 L F
.36041 .80182 m .36196 .80252 L .36089 .8037 L F
.774 .734 .815 r
.66741 .75077 m .6667 .75046 L .66864 .75015 L F
.474 .213 .437 r
.47528 .82655 m .4748 .82812 L .47724 .82622 L F
.857 .923 .872 r
.6358 .77591 m .63917 .77401 L .63785 .77325 L F
.784 .853 .903 r
.63785 .77325 m .63917 .77401 L .64063 .77305 L F
.718 .589 .711 r
.63438 .75491 m .63237 .75576 L .63454 .75314 L F
.675 .548 .703 r
.63757 .75767 m .63438 .75491 L .63795 .75576 L F
.63757 .75767 m .63543 .75859 L .63438 .75491 L F
.472 .587 .888 r
.5152 .84712 m .51909 .85001 L .51724 .84698 L F
.399 .427 .774 r
.51909 .85001 m .51937 .84648 L .51724 .84698 L F
.51909 .85001 m .52041 .84964 L .51937 .84648 L F
.499 .5 .789 r
.51909 .85001 m .52088 .85207 L .52041 .84964 L F
.52088 .85207 m .5212 .85159 L .52041 .84964 L F
.927 .724 .609 r
.52041 .84964 m .52184 .85317 L .52099 .85169 L F
.583 .536 .768 r
.52041 .84964 m .52099 .85169 L .52279 .84967 L F
.489 .039 .107 r
.52047 .85102 m .52224 .84999 L .52099 .85169 L F
.52224 .84999 m .52279 .84967 L .52151 .85111 L F
.52224 .84999 m .52151 .85111 L .52099 .85169 L F
.499 .5 .789 r
.52088 .85207 m .52184 .85317 L .5212 .85159 L F
.82 .751 .787 r
.69333 .71116 m .69645 .71068 L .69526 .71009 L F
.69333 .71116 m .69413 .71344 L .69645 .71068 L F
.528 .847 .998 r
.69754 .70956 m .69645 .71068 L .69843 .71035 L F
.69754 .70956 m .69526 .71009 L .69645 .71068 L F
.606 .584 .803 r
.40602 .73754 m .40392 .73802 L .40308 .73574 L F
.572 .344 .531 r
.41496 .76324 m .41468 .76487 L .41301 .7651 L F
.519 .277 .489 r
.41704 .76298 m .41468 .76487 L .41496 .76324 L F
0 0 .057 r
.61643 .81036 m .61757 .80736 L .61711 .80929 L F
0 0 0 r
.61562 .81192 m .61643 .81036 L .61711 .80929 L F
.148 0 0 r
.50682 .87618 m .51015 .87585 L .50797 .87589 L F
.753 .495 .541 r
.69048 .74772 m .69053 .74984 L .68822 .74714 L F
.717 .475 .558 r
.69048 .74772 m .6936 .7499 L .69053 .74984 L F
.547 .408 .643 r
.52436 .8132 m .52661 .81518 L .52669 .81312 L F
.52436 .8132 m .52431 .81578 L .52661 .81518 L F
.743 .611 .711 r
.66628 .72395 m .66342 .72656 L .66305 .72385 L F
.701 .692 .838 r
.38211 .89254 m .38347 .89478 L .38548 .89363 L F
.517 .781 .992 r
.41001 .73645 m .40932 .73774 L .40808 .73705 L F
.41001 .73645 m .41136 .73746 L .40932 .73774 L F
.696 .655 .805 r
.63367 .75015 m .63454 .75314 L .63107 .75233 L F
.726 .602 .718 r
.63454 .75314 m .63237 .75576 L .63107 .75233 L F
.745 .683 .791 r
.63673 .75055 m .63454 .75314 L .63367 .75015 L F
.876 .953 .855 r
.41098 .88994 m .41262 .88979 L .41158 .88971 L F
.636 .881 .986 r
.41322 .88841 m .41262 .88979 L .41469 .88888 L F
.744 .983 .907 r
.41158 .88971 m .41262 .88979 L .41322 .88841 L F
.741 .602 .703 r
.4975 .85236 m .49794 .85528 L .49478 .8553 L F
.738 .298 .206 r
.49835 .85731 m .49478 .8553 L .49794 .85528 L F
.722 .476 .552 r
.4975 .85236 m .4999 .85546 L .49794 .85528 L F
.68 .554 .706 r
.4999 .85546 m .50145 .8578 L .49835 .85731 L F
0 0 0 r
.49889 .85667 m .49835 .85731 L .4999 .85546 L F
0 0 .446 r
.49889 .85667 m .49794 .85528 L .4999 .85546 L F
.49889 .85667 m .49835 .85731 L .49794 .85528 L F
.221 .336 .769 r
.6753 .71551 m .67619 .71841 L .67671 .71645 L F
.532 .302 .511 r
.38592 .78394 m .38384 .7857 L .3839 .78423 L F
.454 .398 .705 r
.52703 .82378 m .52768 .82132 L .52545 .82104 L F
.52703 .82378 m .52842 .82365 L .52768 .82132 L F
.429 .249 .534 r
.52703 .82378 m .52667 .82612 L .52842 .82365 L F
.52703 .82378 m .52667 .82612 L .52842 .82365 L F
.652 .495 .658 r
.3854 .87887 m .38743 .87818 L .38764 .87632 L F
.689 .641 .797 r
.38743 .87818 m .3895 .87589 L .38764 .87632 L F
.662 .426 .553 r
.56413 .81026 m .56654 .81055 L .56625 .80775 L F
0 0 .297 r
.56795 .80439 m .56769 .80686 L .56625 .80775 L F
0 0 0 r
.56769 .80686 m .56505 .80928 L .56625 .80775 L F
.812 .453 .376 r
.68524 .7449 m .68428 .74646 L .6841 .74442 L F
.68524 .7449 m .68699 .74722 L .68428 .74646 L F
.481 .064 .171 r
.57039 .77428 m .57219 .77518 L .57331 .77345 L F
.34 0 .076 r
.57219 .77518 m .57535 .77311 L .57331 .77345 L F
.799 .657 .706 r
.50073 .82109 m .50424 .82196 L .50284 .82047 L F
.379 .59 .927 r
.50424 .82196 m .50488 .82029 L .50284 .82047 L F
.695 .626 .775 r
.51389 .81792 m .51516 .82062 L .51691 .81834 L F
0 0 .235 r
.66657 .70799 m .66703 .7099 L .66699 .71042 L F
0 .08 .629 r
.66703 .7099 m .66869 .71223 L .66699 .71042 L F
.43 .254 .541 r
.48539 .84733 m .48708 .84697 L .48703 .84471 L F
.593 .421 .618 r
.48539 .84733 m .48777 .84986 L .48708 .84697 L F
.48539 .84733 m .48547 .85021 L .48777 .84986 L F
.496 .536 .828 r
.38001 .89229 m .38211 .89254 L .38139 .89118 L F
.519 .233 .42 r
.54356 .83748 m .54289 .83944 L .54072 .83973 L F
.952 .887 .731 r
.62172 .79706 m .62409 .79458 L .62301 .79409 L F
.62172 .79706 m .62269 .79762 L .62409 .79458 L F
.939 .885 .753 r
.62409 .79458 m .62391 .79238 L .62301 .79409 L F
.524 .258 .453 r
.37679 .78981 m .37642 .79168 L .37441 .79183 L F
.491 .228 .443 r
.37848 .79125 m .37679 .78981 L .37917 .78978 L F
.37848 .79125 m .37642 .79168 L .37679 .78981 L F
.518 .515 .792 r
.40282 .74752 m .40391 .75093 L .40599 .75078 L F
.545 .405 .641 r
.40397 .75262 m .40599 .75078 L .40391 .75093 L F
.216 .678 .945 r
.37886 .72646 m .38092 .72661 L .3822 .72726 L F
.388 .749 .992 r
.38312 .72632 m .3822 .72726 L .38092 .72661 L F
.38312 .72632 m .38465 .72719 L .3822 .72726 L F
.327 0 .108 r
.55646 .79754 m .55745 .79884 L .55857 .79715 L F
.55646 .79754 m .55547 .79926 L .55745 .79884 L F
.616 .436 .616 r
.41987 .84986 m .42245 .84734 L .41946 .8473 L F
.622 .173 .163 r
.52545 .82104 m .52245 .82111 L .52347 .82037 L F
0 0 .396 r
.56288 .82883 m .56309 .83157 L .56387 .83017 L F
.063 .249 .742 r
.56309 .83157 m .56421 .83432 L .56407 .83309 L F
.918 .619 .136 r
.56421 .83432 m .56414 .83568 L .56407 .83309 L F
.56421 .83432 m .56464 .83656 L .56414 .83568 L F
.792 .647 .701 r
.66862 .73447 m .66579 .73613 L .66549 .7343 L F
.66862 .73447 m .66686 .7373 L .66579 .73613 L F
.677 .831 .958 r
.56697 .84691 m .57007 .84695 L .56892 .84672 L F
.205 .717 .89 r
.57007 .84695 m .57109 .84661 L .56892 .84672 L F
.57007 .84695 m .57221 .84687 L .57109 .84661 L F
.624 .438 .611 r
.40145 .86584 m .4037 .86751 L .40445 .86572 L F
.40145 .86584 m .4017 .8679 L .4037 .86751 L F
.733 .596 .702 r
.63943 .75478 m .64097 .75816 L .63757 .75767 L F
.571 .417 .634 r
.49155 .85458 m .49483 .85241 L .49187 .8532 L F
.529 .317 .536 r
.3316 .68171 m .33136 .68372 L .32917 .68448 L F
.392 .176 .462 r
.33328 .67942 m .33304 .68146 L .3316 .68171 L F
.377 .178 .478 r
.33304 .68146 m .33136 .68372 L .3316 .68171 L F
.743 .451 .488 r
.37209 .88386 m .37306 .88392 L .37252 .88258 L F
.658 .597 .775 r
.51691 .81834 m .51811 .82133 L .52043 .82066 L F
.628 .486 .669 r
.51811 .82133 m .51786 .82389 L .52043 .82066 L F
.73 .662 .783 r
.50354 .85808 m .50468 .86156 L .5013 .86029 L F
.592 .023 0 r
.5013 .86029 m .50468 .86156 L .50378 .86184 L F
.741 .668 .779 r
.50644 .85881 m .50468 .86156 L .50354 .85808 L F
.608 .042 0 r
.50585 .86232 m .50694 .86303 L .50573 .86257 L F
0 0 0 r
.50694 .86303 m .50764 .86045 L .50761 .86152 L F
.717 .212 .032 r
.50378 .86184 m .50694 .86303 L .50517 .86323 L F
.926 .934 .79 r
.50517 .86323 m .50694 .86303 L .50761 .86152 L F
.50551 .86304 m .50761 .86152 L .50772 .86181 L F
.50517 .86323 m .50555 .86297 L .50551 .86304 L F
.50555 .86297 m .50761 .86152 L .50551 .86304 L F
.608 .042 0 r
.50468 .86156 m .50585 .86232 L .50378 .86184 L F
.50585 .86232 m .50573 .86257 L .50378 .86184 L F
.117 .669 .763 r
.52038 .83348 m .52206 .83328 L .52248 .83148 L F
.52038 .83348 m .51916 .8335 L .52206 .83328 L F
.364 .369 .731 r
.52038 .83348 m .52206 .83328 L .51916 .8335 L F
.52038 .83348 m .52272 .83562 L .52206 .83328 L F
.007 0 0 r
.35783 .75289 m .35383 .754 L .35492 .75294 L F
.35783 .75289 m .35567 .75367 L .35383 .754 L F
.518 .656 .921 r
.35783 .75289 m .35747 .75265 L .35567 .75367 L F
.35783 .75289 m .35876 .75143 L .35747 .75265 L F
.35783 .75289 m .36024 .75316 L .35876 .75143 L F
0 0 .309 r
.63525 .73189 m .63489 .73188 L .63479 .73109 L F
.63525 .73189 m .63523 .73412 L .63489 .73188 L F
.592 .07 0 r
.53285 .80941 m .5362 .8098 L .53398 .80852 L F
.535 .301 .507 r
.65771 .72403 m .65782 .72622 L .65562 .72644 L F
.65771 .72403 m .65782 .72622 L .65562 .72644 L F
.679 .602 .762 r
.66102 .72371 m .65771 .72403 L .65985 .72124 L F
0 0 0 r
.65985 .72124 m .65771 .72403 L .659 .72257 L F
.445 .106 .296 r
.66102 .72371 m .65782 .72622 L .65771 .72403 L F
.583 .547 .78 r
.65782 .72622 m .659 .72257 L .65771 .72403 L F
.792 .702 .766 r
.39298 .89159 m .39084 .89438 L .39401 .89387 L F
.566 .57 .816 r
.39401 .89387 m .39486 .8912 L .39298 .89159 L F
.39401 .89387 m .39547 .89345 L .39486 .8912 L F
.806 .64 .677 r
.49545 .83631 m .49368 .83931 L .49545 .83876 L F
0 0 0 r
.49444 .83834 m .49368 .83931 L .49545 .83631 L F
.672 .951 .954 r
.49216 .83941 m .49368 .83931 L .49444 .83834 L F
.246 0 0 r
.49394 .8388 m .49316 .83923 L .49216 .83941 L F
.672 .951 .954 r
.49216 .83941 m .49207 .84092 L .49368 .83931 L F
.246 0 0 r
.49316 .83923 m .49125 .84028 L .49216 .83941 L F
.963 .661 .407 r
.48987 .83957 m .49018 .83976 L .49216 .83941 L F
.49018 .83976 m .49207 .84092 L .49216 .83941 L F
.48987 .83957 m .49139 .84319 L .49207 .84092 L F
.541 .488 .745 r
.49464 .84181 m .49368 .83931 L .49207 .84092 L F
.016 0 0 r
.51445 .88119 m .51654 .8806 L .51565 .88119 L F
.013 0 0 r
.51357 .88167 m .51445 .88119 L .51565 .88119 L F
.543 .37 .597 r
.63397 .72661 m .63624 .72626 L .63599 .72386 L F
.796 .527 .531 r
.682 .73716 m .67959 .73893 L .68078 .73635 L F
.682 .73716 m .68245 .73936 L .67959 .73893 L F
.872 .865 .829 r
.59198 .78434 m .58982 .78749 L .5888 .78626 L F
.543 .388 .621 r
.59192 .78679 m .58982 .78749 L .59198 .78434 L F
.735 .326 .273 r
.59192 .78679 m .5888 .78626 L .58982 .78749 L F
.996 .785 .502 r
.56162 .82295 m .56249 .8238 L .56228 .82603 L F
.728 .548 .647 r
.61017 .77915 m .60665 .7813 L .60664 .77907 L F
.428 .838 .971 r
.54459 .86246 m .54348 .86326 L .54212 .86291 L F
.54212 .86291 m .54348 .86326 L .54459 .86246 L F
.54459 .86246 m .54348 .86326 L .54212 .86291 L F
.632 .103 0 r
.51237 .8772 m .51386 .87676 L .51015 .87585 L F
.635 .963 .826 r
.51533 .87565 m .51386 .87676 L .51237 .8772 L F
0 0 .11 r
.53442 .83923 m .53485 .83995 L .53842 .83817 L F
.317 .438 .826 r
.53842 .83817 m .53858 .83577 L .53649 .83616 L F
.53842 .83817 m .53993 .83846 L .53858 .83577 L F
.6 .17 .196 r
.53485 .83995 m .53993 .83846 L .53842 .83817 L F
.865 .429 .168 r
.58318 .78134 m .58203 .7811 L .58083 .77921 L F
.646 .29 .353 r
.58529 .78172 m .58203 .7811 L .58318 .78134 L F
.885 .778 .283 r
.69023 .71879 m .68981 .72011 L .68945 .71795 L F
.69023 .71879 m .68992 .72116 L .68981 .72011 L F
.437 .082 .263 r
.36154 .7868 m .36361 .78649 L .3647 .78431 L F
.361 .007 .223 r
.3647 .78431 m .36553 .78602 L .36646 .78361 L F
.3647 .78431 m .36361 .78649 L .36553 .78602 L F
.263 .616 .958 r
.64832 .70629 m .65022 .70661 L .64982 .70721 L F
.616 .891 .577 r
.65022 .70661 m .64955 .7076 L .64982 .70721 L F
.118 .252 .728 r
.64982 .70721 m .64955 .7076 L .6494 .70715 L F
.263 .616 .958 r
.64832 .70629 m .64982 .70721 L .6494 .70715 L F
.616 .891 .577 r
.65022 .70661 m .64773 .7093 L .64955 .7076 L F
.56 .317 .504 r
.40297 .77116 m .40231 .77394 L .40019 .77398 L F
.586 .342 .513 r
.40478 .773 m .40297 .77116 L .40509 .77091 L F
.40478 .773 m .40231 .77394 L .40297 .77116 L F
.709 .57 .696 r
.39269 .8738 m .3929 .8762 L .39507 .87364 L F
.597 .41 .6 r
.3929 .8762 m .3952 .876 L .39507 .87364 L F
.452 .3 .584 r
.39507 .87364 m .39691 .87558 L .39801 .87362 L F
.39507 .87364 m .3952 .876 L .39691 .87558 L F
.695 .706 .856 r
.40293 .73421 m .40056 .73479 L .39931 .73355 L F
.579 .583 .821 r
.40308 .73574 m .40056 .73479 L .40293 .73421 L F
.611 .346 .492 r
.60151 .78164 m .5992 .78359 L .59951 .78198 L F
.731 .268 .149 r
.6909 .72917 m .69247 .72923 L .69027 .72852 L F
0 0 .528 r
.69242 .72752 m .69227 .73059 L .6909 .72917 L F
.69227 .73059 m .69225 .73098 L .6909 .72917 L F
.731 .268 .149 r
.6909 .72917 m .69027 .72852 L .68913 .72816 L F
.505 .323 .569 r
.43779 .83165 m .44174 .83318 L .44069 .83169 L F
.607 .09 0 r
.44069 .83169 m .44278 .83306 L .443 .83191 L F
.44069 .83169 m .44174 .83318 L .44278 .83306 L F
.594 .435 .635 r
.42894 .83956 m .43106 .84159 L .4312 .8395 L F
.42894 .83956 m .42893 .84194 L .43106 .84159 L F
.608 .412 .591 r
.33572 .6789 m .33304 .68146 L .33328 .67942 L F
0 0 .157 r
.56451 .83959 m .56483 .84119 L .56451 .83894 L F
.56451 .83959 m .5649 .84191 L .56483 .84119 L F
.65 .826 .968 r
.36812 .72526 m .3648 .72511 L .36714 .72439 L F
.616 .852 .988 r
.37028 .7246 m .36812 .72526 L .36714 .72439 L F
.686 .538 .678 r
.42392 .84439 m .42673 .84228 L .42366 .84198 L F
.989 .764 .377 r
.59298 .7673 m .59255 .76795 L .5926 .76551 L F
.627 .296 .391 r
.59255 .76795 m .5957 .76561 L .5926 .76551 L F
.59255 .76795 m .59431 .76793 L .5957 .76561 L F
.412 .195 .471 r
.5957 .76561 m .59792 .76578 L .59795 .76316 L F
.63 .299 .392 r
.5957 .76561 m .59813 .76771 L .59792 .76578 L F
.5957 .76561 m .59431 .76793 L .59813 .76771 L F
.704 .487 .591 r
.50211 .8393 m .5055 .8411 L .50536 .83948 L F
.621 .347 .482 r
.5055 .8411 m .50742 .84146 L .50536 .83948 L F
.639 .344 .453 r
.50536 .83948 m .50742 .84146 L .50755 .83969 L F
.755 .585 .666 r
.48708 .84697 m .49033 .84955 L .49059 .84833 L F
.48708 .84697 m .49059 .84833 L .48998 .84831 L F
.532 .515 .782 r
.49308 .84672 m .49059 .84833 L .4895 .84434 L F
.57 .233 .358 r
.49308 .84672 m .48998 .84831 L .49059 .84833 L F
.284 0 0 r
.44622 .83029 m .44703 .83054 L .44769 .83008 L F
.44622 .83029 m .44517 .83118 L .44703 .83054 L F
.512 .317 .553 r
.42623 .75482 m .42396 .75712 L .42424 .75547 L F
.781 .624 .685 r
.3895 .87589 m .3929 .8762 L .39269 .8738 L F
.67 .271 .281 r
.7002 .7521 m .70224 .75283 L .69916 .75289 L F
.585 .182 .245 r
.50652 .8447 m .50314 .84646 L .50335 .84485 L F
.50652 .8447 m .5053 .84651 L .50314 .84646 L F
.517 .108 .204 r
.50755 .84634 m .50652 .8447 L .50893 .84623 L F
.50755 .84634 m .5053 .84651 L .50652 .8447 L F
.653 .45 .596 r
.43532 .83405 m .43762 .83402 L .43779 .83165 L F
.505 .323 .569 r
.43779 .83165 m .43762 .83402 L .44174 .83318 L F
.648 .514 .687 r
.40445 .86572 m .40669 .86562 L .40643 .86319 L F
.678 .458 .58 r
.4037 .86751 m .40669 .86562 L .40445 .86572 L F
.803 .628 .665 r
.51896 .87839 m .52185 .87801 L .52041 .87611 L F
.482 .539 .839 r
.52041 .87611 m .52185 .87801 L .52353 .87792 L F
.759 .612 .696 r
.61296 .78388 m .61005 .78147 L .61356 .78186 L F
.582 .163 .211 r
.38627 .88731 m .38819 .8888 L .3898 .88679 L F
.577 .451 .672 r
.3898 .88679 m .39149 .8841 L .38884 .88373 L F
.3898 .88679 m .39186 .88682 L .39149 .8841 L F
.395 0 .087 r
.3898 .88679 m .3904 .88832 L .39186 .88682 L F
.3898 .88679 m .38819 .8888 L .3904 .88832 L F
.642 .578 .768 r
.52402 .85824 m .52569 .85907 L .52506 .85687 L F
.692 .652 .805 r
.52506 .85687 m .52402 .85824 L .52253 .85812 L F
.711 .526 .637 r
.52402 .85824 m .52569 .85907 L .52253 .85812 L F
0 0 .425 r
.66869 .71223 m .67097 .71533 L .66937 .71339 L F
.139 0 .156 r
.38363 .77082 m .38423 .7724 L .38556 .77017 L F
.38363 .77082 m .3827 .77305 L .38423 .7724 L F
0 0 .457 r
.67211 .72834 m .67318 .73137 L .67227 .72937 L F
.784 .853 .903 r
.63785 .77325 m .64063 .77305 L .63965 .77217 L F
.807 .883 .901 r
.63965 .77217 m .64063 .77305 L .64324 .77079 L F
.765 .64 .722 r
.63943 .75478 m .63757 .75767 L .63795 .75576 L F
.714 .614 .745 r
.6419 .75225 m .63943 .75478 L .63984 .75293 L F
.549 .327 .531 r
.52506 .85687 m .52253 .85812 L .5228 .8601 L F
.52506 .85687 m .52253 .85812 L .5228 .8601 L F
.785 .991 .884 r
.47888 .8686 m .47552 .8705 L .47738 .86973 L F
.145 0 0 r
.48093 .86817 m .47888 .8686 L .47738 .86973 L F
.287 0 0 r
.50284 .82047 m .50488 .82029 L .50623 .819 L F
.508 0 0 r
.50703 .81982 m .50623 .819 L .50488 .82029 L F
.514 .571 .851 r
.54446 .7857 m .5465 .78576 L .54588 .7844 L F
0 0 0 r
.54396 .78499 m .54556 .7845 L .54563 .78446 L F
.54615 .78381 m .5469 .78359 L .54814 .78273 L F
.54556 .7845 m .54651 .7842 L .54693 .78382 L F
.54588 .78429 m .54693 .78382 L .54814 .78273 L F
.54556 .7845 m .54693 .78382 L .54588 .78429 L F
.002 0 0 r
.54814 .78273 m .54861 .7831 L .54966 .78138 L F
.54814 .78273 m .54648 .78423 L .54861 .7831 L F
.501 .552 .84 r
.54986 .78058 m .54863 .78306 L .5459 .78296 L F
.54863 .78306 m .54861 .7831 L .54855 .7831 L F
.54863 .78306 m .54855 .7831 L .5459 .78296 L F
.786 .562 .596 r
.54855 .7831 m .54566 .78308 L .5459 .78296 L F
.54854 .7831 m .54528 .78308 L .54855 .7831 L F
0 0 0 r
.54445 .78473 m .54563 .78446 L .5469 .78359 L F
.54445 .78473 m .5469 .78359 L .54615 .78381 L F
.786 .562 .596 r
.54861 .7831 m .54648 .78423 L .54528 .78308 L F
0 .178 .695 r
.5459 .78296 m .54712 .78363 L .54752 .78217 L F
.588 .946 .844 r
.54986 .78058 m .5459 .78296 L .54773 .7814 L F
0 .178 .695 r
.5459 .78296 m .54752 .78217 L .54773 .7814 L F
.786 .562 .596 r
.54566 .78308 m .54528 .78308 L .5459 .78296 L F
.54861 .7831 m .54854 .7831 L .54855 .7831 L F
0 0 0 r
.54396 .78499 m .54563 .78446 L .54445 .78473 L F
.325 .456 .839 r
.54704 .78414 m .5465 .78576 L .54758 .78446 L F
0 0 0 r
.54556 .7845 m .54648 .78423 L .54651 .7842 L F
.472 .54 .845 r
.54528 .78308 m .54648 .78423 L .54597 .78438 L F
.325 .456 .839 r
.54528 .78308 m .54588 .7844 L .54597 .78438 L F
.472 .54 .845 r
.54528 .78308 m .54556 .7845 L .54396 .78499 L F
.514 .571 .851 r
.54475 .78477 m .54556 .7845 L .54528 .78308 L F
.54556 .7845 m .54588 .7844 L .54528 .78308 L F
.472 .54 .845 r
.54528 .78308 m .54597 .78438 L .54556 .7845 L F
.325 .456 .839 r
.54528 .78308 m .54597 .78438 L .54704 .78414 L F
.54588 .7844 m .5465 .78576 L .54704 .78414 L F
.514 .571 .851 r
.54446 .7857 m .54588 .7844 L .54475 .78477 L F
.388 0 0 r
.34993 .75496 m .34917 .75534 L .347 .7551 L F
0 0 0 r
.35109 .75466 m .34993 .75496 L .3522 .75422 L F
.35109 .75466 m .34917 .75534 L .34993 .75496 L F
.948 .702 .53 r
.67717 .7224 m .676 .72313 L .67558 .72103 L F
.67717 .7224 m .67732 .72381 L .676 .72313 L F
.566 .445 .674 r
.33136 .68372 m .32957 .68701 L .32917 .68448 L F
.692 .622 .774 r
.6419 .75225 m .63984 .75293 L .63869 .7499 L F
.678 .329 .376 r
.51435 .84174 m .51562 .84403 L .51745 .84162 L F
.56 .174 .266 r
.51562 .84403 m .51937 .84182 L .51745 .84162 L F
.275 0 0 r
.47151 .83015 m .4748 .82812 L .47293 .82891 L F
.78 .994 .782 r
.56872 .81573 m .56641 .81845 L .56919 .81552 L F
.534 .442 .697 r
.56872 .81573 m .56846 .8185 L .56641 .81845 L F
.808 .372 .209 r
.4847 .84113 m .48694 .84173 L .48575 .84006 L F
.379 0 .083 r
.48878 .83882 m .4847 .84113 L .48575 .84006 L F
.832 .744 .766 r
.60625 .79797 m .60495 .80046 L .60296 .79955 L F
.978 .837 .634 r
.60495 .80046 m .60329 .80231 L .60296 .79955 L F
.60495 .80046 m .6043 .80309 L .60329 .80231 L F
.558 .353 .558 r
.37646 .77637 m .37859 .7761 L .37866 .77378 L F
.491 .299 .547 r
.37866 .77378 m .38048 .77566 L .38108 .77369 L F
.37866 .77378 m .37859 .7761 L .38048 .77566 L F
.727 .903 .529 r
.48238 .83062 m .48164 .83221 L .48376 .82892 L F
.314 .504 .884 r
.48238 .83062 m .48396 .83303 L .48164 .83221 L F
.689 .641 .797 r
.38743 .87818 m .39075 .87884 L .3895 .87589 L F
.772 .68 .762 r
.3895 .87589 m .39075 .87884 L .3929 .8762 L F
.691 .556 .697 r
.39075 .87884 m .39354 .87888 L .3929 .8762 L F
.612 .401 .571 r
.39094 .8813 m .39354 .87888 L .39075 .87884 L F
.584 .045 0 r
.69397 .70394 m .69731 .70487 L .69498 .70565 L F
.459 .264 .527 r
.69731 .70487 m .69688 .70714 L .69498 .70565 L F
.78 .765 .84 r
.70692 .71354 m .70797 .71546 L .71065 .7135 L F
.315 .411 .801 r
.67869 .73603 m .67709 .7374 L .67618 .73642 L F
.67869 .73603 m .67959 .73893 L .67709 .7374 L F
.507 .387 .651 r
.45424 .85919 m .45302 .86282 L .45215 .8596 L F
.45424 .85919 m .45488 .86284 L .45302 .86282 L F
0 0 .343 r
.5584 .78155 m .55953 .78124 L .55941 .7784 L F
.982 .828 .614 r
.56102 .78185 m .55953 .78124 L .5584 .78155 L F
0 0 0 r
.51652 .84686 m .5152 .84712 L .51724 .84698 L F
.51652 .84686 m .51415 .8474 L .5152 .84712 L F
.152 .111 .554 r
.48826 .84053 m .48987 .83957 L .48878 .83882 L F
.543 .509 .768 r
.48832 .84293 m .48987 .83957 L .48826 .84053 L F
.811 .48 .429 r
.68822 .74714 m .68738 .74916 L .68699 .74722 L F
.68822 .74714 m .69053 .74984 L .68738 .74916 L F
.624 .807 .97 r
.58315 .83352 m .58279 .8342 L .5797 .83331 L F
.78 .672 .745 r
.60513 .79491 m .60625 .79797 L .60463 .79701 L F
.832 .744 .766 r
.60625 .79797 m .60296 .79955 L .60463 .79701 L F
0 .326 .807 r
.68126 .72122 m .68429 .7239 L .68284 .72329 L F
.285 0 0 r
.68894 .70485 m .68685 .70547 L .68897 .70502 L F
.029 .149 .656 r
.68685 .70547 m .68833 .70697 L .68897 .70502 L F
.147 0 0 r
.42227 .75094 m .42446 .7508 L .42558 .75013 L F
.596 .482 .694 r
.42783 .74972 m .42597 .7524 L .42558 .75013 L F
.231 0 0 r
.42558 .75013 m .42446 .7508 L .42614 .75078 L F
.338 .704 .983 r
.42589 .75071 m .42446 .7508 L .42347 .74997 L F
.42614 .75078 m .42446 .7508 L .42589 .75071 L F
.147 0 0 r
.42221 .75096 m .42446 .7508 L .42227 .75094 L F
.231 0 0 r
.42558 .75013 m .42614 .75078 L .42783 .74972 L F
.896 .624 .518 r
.68189 .75172 m .68369 .74981 L .68255 .74931 L F
.68189 .75172 m .68386 .75258 L .68369 .74981 L F
.581 .467 .689 r
.39354 .87888 m .3952 .876 L .3929 .8762 L F
.468 0 0 r
.4202 .88669 m .41898 .88771 L .41863 .88625 L F
.4202 .88669 m .42024 .88744 L .41898 .88771 L F
0 0 0 r
.49274 .88327 m .49382 .88302 L .49181 .88322 L F
.49274 .88327 m .4956 .88221 L .49382 .88302 L F
0 0 .577 r
.48089 .85515 m .48204 .85786 L .48393 .85515 L F
.756 .684 .781 r
.48342 .85242 m .48393 .85515 L .48635 .85281 L F
.645 .591 .779 r
.52041 .87611 m .52282 .87362 L .52114 .87358 L F
.108 .659 .708 r
.38951 .72823 m .39154 .72793 L .39302 .72774 L F
.197 .725 .751 r
.39302 .72774 m .39357 .7275 L .39527 .72804 L F
.39302 .72774 m .39154 .72793 L .39357 .7275 L F
.648 .386 .509 r
.45987 .83365 m .46216 .8338 L .46245 .83177 L F
.575 .324 .498 r
.46216 .8338 m .46468 .83152 L .46245 .83177 L F
.541 .262 .44 r
.41301 .7651 m .4118 .76796 L .40963 .76819 L F
.494 .201 .397 r
.41468 .76487 m .4118 .76796 L .41301 .7651 L F
.492 .598 .887 r
.69974 .74182 m .6994 .74333 L .69603 .74002 L F
.564 .304 .48 r
.38811 .76832 m .39028 .76817 L .39061 .76615 L F
.509 .235 .435 r
.39028 .76817 m .39292 .7651 L .39061 .76615 L F
.339 0 0 r
.5317 .84754 m .53015 .84753 L .52795 .84704 L F
.5317 .84754 m .53015 .84753 L .52795 .84704 L F
.634 .42 .575 r
.5317 .84754 m .5314 .85011 L .52917 .84987 L F
.905 .914 .816 r
.53188 .84414 m .5317 .84754 L .53372 .84708 L F
.53188 .84414 m .53015 .84753 L .5317 .84754 L F
.107 .66 .719 r
.53372 .84708 m .53015 .84753 L .5317 .84754 L F
.746 .639 .742 r
.53372 .84708 m .5314 .85011 L .5317 .84754 L F
.442 .254 .529 r
.52705 .85449 m .52506 .85687 L .52534 .85552 L F
.293 .129 .48 r
.63086 .73939 m .63066 .74182 L .6294 .74196 L F
.32 .282 .659 r
.63066 .74182 m .63121 .74391 L .6294 .74196 L F
.499 .868 .983 r
.54921 .85005 m .54924 .85005 L .54923 .85005 L F
.805 .751 .803 r
.54793 .84726 m .54854 .84991 L .54727 .84957 L F
0 .538 .789 r
.54727 .84957 m .54854 .84991 L .54897 .84997 L F
.805 .751 .803 r
.54793 .84726 m .55083 .84739 L .54854 .84991 L F
0 .538 .789 r
.54797 .8497 m .54897 .84997 L .55103 .8503 L F
.499 .868 .983 r
.54978 .84988 m .55316 .84947 L .5523 .84909 L F
.54923 .85005 m .55015 .84991 L .54978 .84988 L F
.55015 .84991 m .55316 .84947 L .54978 .84988 L F
.54924 .85005 m .55316 .84947 L .54923 .85005 L F
.365 0 0 r
.54921 .85005 m .55316 .84947 L .55103 .8503 L F
.499 .868 .983 r
.5493 .85003 m .5523 .84909 L .55103 .8503 L F
.605 .072 0 r
.54854 .84991 m .54921 .85005 L .55103 .8503 L F
0 .538 .789 r
.54751 .84966 m .55103 .8503 L .54975 .85051 L F
.54727 .84957 m .54797 .8497 L .54751 .84966 L F
.54727 .84957 m .54897 .84997 L .54797 .8497 L F
.54797 .8497 m .55103 .8503 L .54751 .84966 L F
.533 .363 .596 r
.63599 .72386 m .63624 .72626 L .63837 .72375 L F
.348 0 0 r
.70224 .75283 m .70541 .7523 L .70444 .75327 L F
.092 0 0 r
.70541 .7523 m .70686 .75172 L .707 .75215 L F
.054 0 0 r
.70444 .75327 m .70541 .7523 L .707 .75215 L F
0 0 0 r
.48139 .85937 m .47913 .86091 L .48204 .85786 L F
0 0 .577 r
.48089 .85515 m .48235 .85722 L .48204 .85786 L F
0 0 0 r
.48235 .85722 m .48139 .85937 L .48204 .85786 L F
.877 .896 .841 r
.65456 .75129 m .65449 .75301 L .65274 .7524 L F
.461 .265 .527 r
.65449 .75301 m .65356 .75534 L .65274 .7524 L F
.65449 .75301 m .65551 .75476 L .65356 .75534 L F
.728 .548 .647 r
.61017 .77915 m .61005 .78147 L .60665 .7813 L F
.685 .599 .754 r
.64525 .7546 m .6419 .75225 L .64549 .75355 L F
.71 .689 .828 r
.64549 .75355 m .64736 .7525 L .64525 .7546 L F
.759 .612 .696 r
.61296 .78388 m .61188 .78482 L .61005 .78147 L F
.768 .629 .707 r
.61296 .78388 m .61113 .78668 L .61188 .78482 L F
.133 .681 .763 r
.35388 .72705 m .35598 .72679 L .35747 .72672 L F
.281 .783 .834 r
.35747 .72672 m .35826 .7263 L .35953 .7264 L F
.35747 .72672 m .35598 .72679 L .35826 .7263 L F
.716 .695 .828 r
.63367 .75015 m .63107 .75233 L .63013 .74965 L F
.628 .521 .713 r
.39931 .86824 m .40223 .87084 L .4017 .8679 L F
.39931 .86824 m .40002 .87115 L .40223 .87084 L F
.858 .925 .872 r
.473 .84677 m .47637 .84491 L .47496 .84639 L F
.65 .314 .391 r
.47843 .84455 m .47496 .84639 L .47637 .84491 L F
.836 .576 .546 r
.48703 .84471 m .48484 .84654 L .48387 .84472 L F
.48703 .84471 m .48708 .84697 L .48484 .84654 L F
0 0 .184 r
.71354 .74174 m .7128 .74372 L .71127 .74478 L F
0 0 .262 r
.71195 .74552 m .71127 .74478 L .7128 .74372 L F
.71195 .74552 m .71118 .74683 L .71127 .74478 L F
.61 .566 .78 r
.41633 .73697 m .41476 .73905 L .41426 .73755 L F
.41633 .73697 m .41747 .73984 L .41476 .73905 L F
.624 .516 .711 r
.41776 .74195 m .41476 .73905 L .41747 .73984 L F
.41776 .74195 m .41567 .74244 L .41476 .73905 L F
.48 .067 .179 r
.57039 .77428 m .57008 .77558 L .57219 .77518 L F
.099 .603 .896 r
.5742 .84695 m .57538 .84751 L .57711 .84776 L F
.992 .742 .438 r
.67959 .73893 m .68053 .74195 L .6805 .7396 L F
.899 .97 .817 r
.68394 .75536 m .68328 .75483 L .68119 .75766 L F
.995 .869 .559 r
.68386 .75258 m .68328 .75483 L .68394 .75536 L F
.596 .482 .694 r
.42783 .74972 m .42846 .7524 L .42597 .7524 L F
.572 .435 .656 r
.42831 .75415 m .42597 .7524 L .42846 .7524 L F
.42831 .75415 m .42623 .75482 L .42597 .7524 L F
.957 .622 .331 r
.55889 .81596 m .55827 .81802 L .55718 .81508 L F
.55889 .81596 m .55935 .81837 L .55827 .81802 L F
.736 .556 .65 r
.54619 .83938 m .5447 .84108 L .54289 .83944 L F
.54619 .83938 m .54614 .84221 L .5447 .84108 L F
.61 .565 .779 r
.52569 .85907 m .5277 .85675 L .52506 .85687 L F
.52569 .85907 m .52815 .85915 L .5277 .85675 L F
0 .27 .775 r
.51916 .82396 m .51786 .82389 L .51686 .82412 L F
.51916 .82396 m .52034 .82621 L .51786 .82389 L F
.078 .229 .719 r
.67633 .73531 m .67436 .73423 L .67323 .73339 L F
.67633 .73531 m .67618 .73642 L .67436 .73423 L F
.625 .486 .673 r
.63015 .74746 m .62783 .74992 L .62738 .74785 L F
.678 .612 .774 r
.65419 .7572 m .65167 .75803 L .65059 .75496 L F
.671 .556 .715 r
.38884 .88373 m .39149 .8841 L .39094 .8813 L F
.692 .344 .38 r
.50133 .84437 m .50011 .84668 L .49798 .84444 L F
.667 .315 .366 r
.50314 .84646 m .50011 .84668 L .50133 .84437 L F
.677 .314 .35 r
.50335 .84485 m .50314 .84646 L .50133 .84437 L F
.89 .701 .64 r
.59071 .82181 m .59268 .82346 L .59113 .82379 L F
.848 .909 .876 r
.59354 .82105 m .59268 .82346 L .59071 .82181 L F
.59354 .82105 m .59478 .82146 L .59268 .82346 L F
.991 .731 .392 r
.59268 .82346 m .5921 .82591 L .59113 .82379 L F
.59268 .82346 m .59295 .82651 L .5921 .82591 L F
.647 .476 .639 r
.4132 .85765 m .41615 .85792 L .41536 .85513 L F
.677 .527 .674 r
.41536 .85513 m .41831 .85517 L .4182 .85291 L F
.691 .502 .627 r
.41536 .85513 m .41833 .85755 L .41831 .85517 L F
.41536 .85513 m .41615 .85792 L .41833 .85755 L F
.38 .068 .305 r
.33905 .73154 m .34117 .72962 L .33919 .7311 L F
.456 .13 .324 r
.34098 .73085 m .34302 .73047 L .34117 .72962 L F
.723 .988 .825 r
.71053 .74131 m .70883 .7427 L .70981 .74121 L F
.723 .989 .86 r
.70981 .74121 m .70883 .7427 L .70735 .74282 L F
.647 .529 .706 r
.33655 .66662 m .33518 .66812 L .33821 .66574 L F
.943 .704 .547 r
.57381 .82068 m .5753 .821 L .57388 .81809 L F
.757 .663 .758 r
.57388 .81809 m .5753 .821 L .57717 .81835 L F
0 0 .344 r
.5761 .82241 m .57555 .82368 L .5753 .821 L F
.5761 .82241 m .5753 .821 L .57381 .82068 L F
.571 .088 .07 r
.50594 .88093 m .51002 .88099 L .50791 .88145 L F
.741 .383 .374 r
.51002 .88099 m .51144 .88197 L .50791 .88145 L F
.011 0 0 r
.59155 .84717 m .59353 .84681 L .59368 .84682 L F
.41 .459 .801 r
.59353 .84681 m .59443 .84764 L .59571 .84634 L F
.59353 .84681 m .59571 .84634 L .59368 .84682 L F
.976 .738 .32 r
.66342 .72656 m .663 .72607 L .66305 .72385 L F
.709 .931 .963 r
.6667 .75046 m .6631 .75157 L .66583 .7501 L F
.718 .934 .959 r
.6667 .75046 m .66583 .7501 L .6676 .74903 L F
.566 .251 .395 r
.64161 .72585 m .64411 .72426 L .64053 .72313 L F
.64161 .72585 m .64381 .72604 L .64411 .72426 L F
.588 .511 .736 r
.64381 .72604 m .64466 .72193 L .64411 .72426 L F
.106 0 .303 r
.60917 .83117 m .60765 .83162 L .60928 .82871 L F
.086 0 .238 r
.60685 .83352 m .60765 .83162 L .60917 .83117 L F
.155 0 0 r
.55941 .7784 m .56126 .77801 L .56262 .77641 L F
.291 0 0 r
.56262 .77641 m .56342 .7775 L .56474 .77595 L F
.56262 .77641 m .56126 .77801 L .56342 .7775 L F
.47 .205 .43 r
.39772 .77598 m .39526 .77832 L .39565 .7763 L F
.573 .677 .91 r
.51973 .86831 m .51646 .86659 L .51811 .86727 L F
.373 .84 .85 r
.51698 .86892 m .51973 .86831 L .51811 .86727 L F
0 0 0 r
.51055 .82627 m .51139 .82587 L .51251 .82402 L F
.851 .973 .871 r
.45257 .88331 m .45438 .88329 L .45412 .88269 L F
.514 .237 .431 r
.41949 .76089 m .41913 .76271 L .41704 .76298 L F
.485 .187 .384 r
.42177 .76067 m .41913 .76271 L .41949 .76089 L F
.612 .401 .571 r
.39094 .8813 m .39325 .8813 L .39354 .87888 L F
.581 .467 .689 r
.39354 .87888 m .39569 .87881 L .3952 .876 L F
.709 .488 .587 r
.39354 .87888 m .39606 .88121 L .39569 .87881 L F
.39354 .87888 m .39325 .8813 L .39606 .88121 L F
.813 .708 .75 r
.55589 .78036 m .55151 .78315 L .55172 .78106 L F
.55589 .78036 m .55172 .78106 L .55446 .78142 L F
.08 0 0 r
.34859 .72839 m .35059 .72807 L .35213 .72739 L F
0 0 0 r
.35213 .72739 m .35244 .72751 L .35388 .72705 L F
.35213 .72739 m .35059 .72807 L .35244 .72751 L F
.671 .775 .928 r
.52923 .85352 m .53047 .85496 L .52705 .85449 L F
.76 .663 .755 r
.52705 .85449 m .53047 .85496 L .52815 .85569 L F
.534 .051 .055 r
.48179 .84425 m .48102 .84499 L .47843 .84455 L F
.728 .429 .473 r
.48484 .84654 m .48179 .84425 L .48387 .84472 L F
.48484 .84654 m .48102 .84499 L .48179 .84425 L F
.653 .508 .674 r
.4182 .85291 m .41831 .85517 L .42037 .85261 L F
.627 .514 .706 r
.40002 .87115 m .40038 .87353 L .40223 .87084 L F
.607 .728 .931 r
.70917 .70798 m .70585 .7072 L .70786 .70589 L F
.456 .606 .91 r
.71044 .70667 m .70917 .70798 L .70786 .70589 L F
.391 .501 .85 r
.71044 .70667 m .71203 .70933 L .70917 .70798 L F
.495 .524 .816 r
.71131 .71015 m .70917 .70798 L .71203 .70933 L F
.535 .266 .454 r
.37604 .77821 m .37809 .77799 L .37646 .77637 L F
.53 .266 .459 r
.37646 .77637 m .37809 .77799 L .37859 .7761 L F
.772 .352 .253 r
.49545 .82077 m .49753 .82306 L .49894 .82219 L F
.74 .956 .943 r
.56254 .78065 m .56102 .78185 L .56319 .78104 L F
.547 .35 .565 r
.45237 .82361 m .45242 .82603 L .45443 .82382 L F
.546 .4 .633 r
.45415 .82281 m .45443 .82382 L .45237 .82361 L F
.547 .35 .565 r
.45237 .82361 m .45443 .82382 L .45415 .82281 L F
.45237 .82361 m .45242 .82603 L .45443 .82382 L F
.594 .46 .668 r
.4312 .8395 m .43313 .83935 L .43315 .83663 L F
.599 .38 .555 r
.4312 .8395 m .43316 .84094 L .43313 .83935 L F
.4312 .8395 m .43106 .84159 L .43316 .84094 L F
.621 .494 .687 r
.40643 .86319 m .40669 .86562 L .40872 .86292 L F
.615 .37 .524 r
.48093 .86817 m .48354 .86768 L .48246 .86631 L F
0 0 0 r
.48202 .86765 m .48246 .86631 L .48093 .86817 L F
.425 .33 .644 r
.48515 .86748 m .48354 .86768 L .48246 .86631 L F
0 0 0 r
.48167 .86839 m .48202 .86765 L .48077 .86917 L F
.528 .023 0 r
.48515 .86748 m .48263 .86639 L .48202 .86765 L F
.48515 .86748 m .48202 .86765 L .48383 .8665 L F
0 0 0 r
.48383 .8665 m .48202 .86765 L .48167 .86839 L F
.528 .023 0 r
.48263 .86639 m .48246 .86631 L .48202 .86765 L F
.48 .041 .126 r
.71128 .71318 m .70927 .71373 L .71065 .7135 L F
.71128 .71318 m .71166 .71418 L .70927 .71373 L F
.393 .535 .879 r
.70927 .71373 m .71166 .71418 L .71163 .71409 L F
.78 .765 .84 r
.708 .71353 m .71065 .7135 L .70927 .71373 L F
0 0 .399 r
.71131 .71015 m .71128 .71318 L .71065 .7135 L F
.393 .535 .879 r
.70927 .71373 m .71163 .71409 L .71074 .71201 L F
.78 .765 .84 r
.70692 .71354 m .708 .71353 L .70927 .71373 L F
.343 0 .206 r
.38556 .77017 m .38811 .76832 L .38582 .76845 L F
.792 .583 .618 r
.39691 .87558 m .40038 .87353 L .39801 .87362 L F
.566 .445 .674 r
.33136 .68372 m .33137 .687 L .32957 .68701 L F
.495 .353 .617 r
.33137 .687 m .32984 .68948 L .32957 .68701 L F
.607 .516 .725 r
.52351 .85445 m .52262 .85678 L .52184 .85317 L F
.5 .266 .491 r
.37441 .79183 m .37455 .79379 L .37202 .79422 L F
.573 .343 .528 r
.37642 .79168 m .37455 .79379 L .37441 .79183 L F
0 .031 .567 r
.64338 .7079 m .64498 .70961 L .64546 .70705 L F
.617 .38 .536 r
.38447 .88665 m .38592 .88717 L .38627 .88731 L F
.38447 .88665 m .38282 .88832 L .38592 .88717 L F
.944 .654 .198 r
.7131 .72786 m .71373 .72905 L .71317 .72962 L F
0 .34 .821 r
.71429 .72865 m .71373 .72905 L .7131 .72786 L F
0 0 0 r
.71317 .72962 m .71373 .72905 L .71429 .72865 L F
.129 .111 .567 r
.63476 .71593 m .6348 .71944 L .63601 .71777 L F
.592 .592 .82 r
.63506 .72095 m .63601 .71777 L .6348 .71944 L F
.517 .033 .044 r
.66857 .75766 m .66938 .75803 L .66905 .75934 L F
.694 .707 .858 r
.40154 .73294 m .40293 .73421 L .39931 .73355 L F
.449 .525 .844 r
.40379 .73181 m .40293 .73421 L .40154 .73294 L F
.40379 .73181 m .40466 .73402 L .40293 .73421 L F
.505 .441 .718 r
.40466 .73402 m .40308 .73574 L .40293 .73421 L F
.326 0 0 r
.49155 .85458 m .49478 .8553 L .4936 .8552 L F
.088 .261 .746 r
.49478 .8553 m .49587 .8544 L .4936 .8552 L F
.738 .298 .206 r
.49835 .85731 m .49705 .85758 L .49478 .8553 L F
.088 .261 .746 r
.49478 .8553 m .49705 .85758 L .49587 .8544 L F
.951 .888 .732 r
.62164 .79971 m .62269 .79762 L .62172 .79706 L F
.135 .64 .903 r
.37038 .74964 m .36943 .74919 L .36752 .74903 L F
.703 .526 .646 r
.37092 .75061 m .36852 .74876 L .36943 .74919 L F
.241 .665 .96 r
.36752 .74903 m .36943 .74919 L .36806 .74841 L F
.703 .526 .646 r
.36852 .74876 m .36806 .74841 L .36943 .74919 L F
.135 .64 .903 r
.37075 .74972 m .36943 .74919 L .37038 .74964 L F
.865 .854 .83 r
.59681 .81651 m .59731 .81905 L .59642 .8198 L F
0 .417 .702 r
.37239 .72478 m .37558 .72569 L .37363 .72564 L F
.674 .455 .58 r
.52279 .81823 m .52431 .81578 L .52253 .81584 L F
.52279 .81823 m .52382 .8184 L .52431 .81578 L F
.313 0 0 r
.65419 .7572 m .65583 .75752 L .65692 .75711 L F
.424 .043 .208 r
.65757 .75552 m .65583 .75752 L .65551 .75476 L F
.1 0 .328 r
.65692 .75711 m .65825 .75691 L .65757 .75552 L F
0 0 0 r
.65583 .75752 m .65825 .75691 L .65692 .75711 L F
.424 .043 .208 r
.65757 .75552 m .65825 .75691 L .65583 .75752 L F
.129 .111 .567 r
.63476 .71593 m .63601 .71777 L .63602 .7153 L F
.137 0 0 r
.67328 .75989 m .67722 .75785 L .67559 .75999 L F
.178 0 0 r
.67851 .75934 m .67559 .75999 L .67722 .75785 L F
.512 .317 .553 r
.42623 .75482 m .42593 .75708 L .42396 .75712 L F
.544 .318 .523 r
.42593 .75708 m .42368 .7602 L .42396 .75712 L F
.665 .937 .967 r
.69101 .71185 m .68935 .71176 L .68765 .71267 L F
.662 .936 .967 r
.69238 .71038 m .69101 .71185 L .69333 .71116 L F
.69238 .71038 m .68935 .71176 L .69101 .71185 L F
0 .41 .77 r
.457 .86484 m .45644 .86481 L .45488 .86284 L F
.457 .86484 m .45825 .8655 L .45644 .86481 L F
.431 .192 .45 r
.48547 .85021 m .48635 .85281 L .48798 .85173 L F
.48547 .85021 m .48689 .85147 L .48635 .85281 L F
.715 .96 .945 r
.48689 .85147 m .48521 .85255 L .48635 .85281 L F
.512 .139 .269 r
.48689 .85147 m .48541 .85248 L .48521 .85255 L F
.565 .895 .642 r
.48367 .85367 m .48282 .85462 L .48521 .85255 L F
.512 .139 .269 r
.48541 .85248 m .48367 .85367 L .48521 .85255 L F
.756 .684 .781 r
.48342 .85242 m .48498 .85263 L .48521 .85255 L F
.48498 .85263 m .48635 .85281 L .48521 .85255 L F
.632 .409 .561 r
.61727 .74541 m .62003 .74168 L .61831 .74255 L F
.021 0 .151 r
.62003 .74168 m .6218 .74084 L .6222 .73893 L F
.234 .087 .467 r
.62003 .74168 m .6219 .74312 L .6218 .74084 L F
.616 .436 .616 r
.41987 .84986 m .4225 .85002 L .42245 .84734 L F
.641 .506 .683 r
.41987 .84986 m .42255 .85221 L .4225 .85002 L F
.41987 .84986 m .42037 .85261 L .42255 .85221 L F
.169 0 0 r
.50108 .87404 m .5004 .87458 L .50035 .8729 L F
.50108 .87404 m .49873 .87543 L .5004 .87458 L F
.755 .445 .46 r
.663 .72607 m .66102 .72371 L .66305 .72385 L F
.223 0 .28 r
.46361 .86275 m .46147 .86538 L .46296 .86443 L F
0 .106 .653 r
.46361 .86275 m .46601 .86037 L .46459 .86217 L F
.46361 .86275 m .46256 .85981 L .46601 .86037 L F
.46361 .86275 m .46404 .86198 L .46256 .85981 L F
0 0 0 r
.46296 .86443 m .46404 .86198 L .46361 .86275 L F
.467 .208 .437 r
.39292 .7651 m .39474 .76455 L .39531 .76302 L F
.377 .139 .421 r
.39474 .76455 m .39712 .76214 L .39531 .76302 L F
.692 .622 .774 r
.6419 .75225 m .63869 .7499 L .64067 .74935 L F
.691 .606 .757 r
.64407 .74984 m .6419 .75225 L .64067 .74935 L F
.668 .571 .736 r
.64407 .74984 m .64549 .75355 L .6419 .75225 L F
.718 .662 .793 r
.69755 .71829 m .70092 .71882 L .69913 .71777 L F
.751 .653 .753 r
.70092 .71882 m .69958 .71568 L .69913 .71777 L F
.70092 .71882 m .70159 .71467 L .69958 .71568 L F
.70092 .71882 m .70297 .71637 L .70159 .71467 L F
.683 .489 .618 r
.42245 .84734 m .42468 .84957 L .42463 .84722 L F
.42245 .84734 m .4225 .85002 L .42468 .84957 L F
.792 .583 .618 r
.39691 .87558 m .40035 .87592 L .40038 .87353 L F
.58 .453 .671 r
.40223 .87084 m .40038 .87353 L .40244 .87322 L F
.639 .456 .62 r
.40038 .87353 m .40269 .8755 L .40244 .87322 L F
.40038 .87353 m .40035 .87592 L .40269 .8755 L F
.536 0 0 r
.663 .72607 m .66271 .72692 L .65994 .72584 L F
.874 .578 .483 r
.66271 .72692 m .66208 .72633 L .65994 .72584 L F
.445 .106 .296 r
.66102 .72371 m .65994 .72584 L .65868 .72555 L F
.755 .445 .46 r
.663 .72607 m .65994 .72584 L .66102 .72371 L F
.874 .578 .483 r
.66208 .72633 m .66026 .72463 L .65994 .72584 L F
.445 .106 .296 r
.65868 .72555 m .65994 .72584 L .65782 .72622 L F
.372 .483 .843 r
.56795 .80439 m .56687 .80576 L .56492 .80254 L F
.509 .235 .435 r
.39028 .76817 m .39238 .76783 L .39292 .7651 L F
.463 .196 .423 r
.39238 .76783 m .39474 .76455 L .39292 .7651 L F
.62 .498 .693 r
.41776 .74195 m .41594 .74461 L .41567 .74244 L F
0 .251 .731 r
.52184 .85317 m .52286 .85346 L .52099 .85169 L F
.52184 .85317 m .52351 .85445 L .52286 .85346 L F
.645 .591 .779 r
.52041 .87611 m .52379 .87633 L .52282 .87362 L F
.482 .539 .839 r
.52041 .87611 m .52353 .87792 L .52379 .87633 L F
.488 .196 .396 r
.63713 .71918 m .63723 .72057 L .63506 .72095 L F
.606 .283 .396 r
.63946 .71997 m .63713 .71918 L .63981 .71872 L F
.63946 .71997 m .63723 .72057 L .63713 .71918 L F
.817 .705 .742 r
.54953 .84459 m .55083 .84739 L .54793 .84726 L F
.872 .865 .829 r
.59198 .78434 m .5888 .78626 L .59042 .78347 L F
.639 .357 .476 r
.59399 .78431 m .59393 .78619 L .59198 .78434 L F
.517 .367 .616 r
.59393 .78619 m .59192 .78679 L .59198 .78434 L F
.051 0 .413 r
.61342 .81864 m .6142 .81554 L .61376 .818 L F
0 0 0 r
.61271 .82063 m .61342 .81864 L .61376 .818 L F
.832 .996 .847 r
.59642 .8198 m .59478 .82146 L .59527 .81995 L F
.741 .92 .952 r
.59527 .81995 m .59478 .82146 L .59354 .82105 L F
.668 .494 .64 r
.4109 .86024 m .41341 .8601 L .4132 .85765 L F
.685 .545 .689 r
.41341 .8601 m .41615 .85792 L .4132 .85765 L F
.513 .882 .977 r
.38991 .74476 m .38911 .74563 L .39086 .74476 L F
.38991 .74476 m .38772 .74533 L .38911 .74563 L F
.286 0 .228 r
.37284 .79583 m .37202 .79422 L .37455 .79379 L F
.37284 .79583 m .37105 .79662 L .37202 .79422 L F
.639 .665 .859 r
.42039 .75133 m .4169 .74986 L .41889 .7496 L F
.679 .733 .891 r
.42221 .75096 m .42039 .75133 L .41889 .7496 L F
.664 .493 .643 r
.40859 .86043 m .40872 .86292 L .4109 .86024 L F
.876 .922 .853 r
.71288 .73781 m .71157 .7402 L .71151 .73817 L F
.916 .972 .681 r
.71053 .74131 m .71151 .73817 L .71157 .7402 L F
.946 .732 .583 r
.67732 .72381 m .67713 .72611 L .676 .72313 L F
.6 .74 .943 r
.65616 .76626 m .65833 .76577 L .655 .76496 L F
.826 .564 .542 r
.66579 .73613 m .6623 .73377 L .66549 .7343 L F
.916 .972 .681 r
.71053 .74131 m .70981 .74121 L .71151 .73817 L F
.146 0 0 r
.37609 .74958 m .37499 .74985 L .37263 .74996 L F
.198 .727 .813 r
.37804 .74955 m .37499 .74985 L .37609 .74958 L F
.686 .538 .678 r
.42392 .84439 m .42679 .84458 L .42673 .84228 L F
.681 .534 .678 r
.42673 .84228 m .42679 .84458 L .42893 .84194 L F
.303 0 0 r
.46042 .86572 m .46147 .86538 L .45825 .8655 L F
.515 .909 .787 r
.46296 .86443 m .46147 .86538 L .46042 .86572 L F
.31 0 0 r
.54344 .80297 m .54468 .80358 L .54211 .80268 L F
0 .423 .753 r
.54758 .80444 m .54666 .804 L .54344 .80297 L F
.31 0 0 r
.54344 .80297 m .54666 .804 L .54468 .80358 L F
.631 .511 .698 r
.42392 .84439 m .42682 .84693 L .42679 .84458 L F
.42392 .84439 m .42463 .84722 L .42682 .84693 L F
.229 .745 .738 r
.43982 .88441 m .44356 .88346 L .44174 .88173 L F
.611 .755 .947 r
.44174 .88173 m .44356 .88346 L .44613 .88285 L F
.709 .548 .668 r
.53283 .85479 m .53408 .85615 L .53242 .85246 L F
.996 .806 .445 r
.5816 .82942 m .58198 .83017 L .58001 .83134 L F
.938 .626 .423 r
.58198 .83017 m .5797 .83331 L .58001 .83134 L F
.58198 .83017 m .58165 .83321 L .5797 .83331 L F
.58198 .83017 m .58315 .83352 L .58165 .83321 L F
.753 .66 .758 r
.63548 .74915 m .63673 .75055 L .63367 .75015 L F
.68 .649 .812 r
.63869 .7499 m .63673 .75055 L .63548 .74915 L F
.689 .534 .672 r
.43312 .83424 m .43315 .83663 L .43532 .83405 L F
.1 .401 .855 r
.52598 .8739 m .52505 .87373 L .52723 .87501 L F
.79 .715 .782 r
.52625 .87352 m .52423 .87358 L .52505 .87373 L F
.745 .74 .848 r
.5273 .87024 m .52625 .87352 L .52505 .87373 L F
.654 .844 .441 r
.52581 .87237 m .5273 .87024 L .52505 .87373 L F
.52581 .87237 m .52505 .87373 L .5241 .87223 L F
.1 .401 .855 r
.5241 .87223 m .52505 .87373 L .52598 .8739 L F
.79 .715 .782 r
.52423 .87358 m .52282 .87362 L .52505 .87373 L F
.745 .74 .848 r
.5273 .87024 m .52832 .87211 L .52625 .87352 L F
.688 .572 .719 r
.5447 .84108 m .54103 .84208 L .54072 .83973 L F
.574 .317 .489 r
.5447 .84108 m .54105 .84432 L .54103 .84208 L F
.613 .437 .621 r
.60977 .75747 m .61207 .75481 L .60994 .75534 L F
.583 .328 .497 r
.59795 .76316 m .59792 .76578 L .60024 .76519 L F
.658 .597 .775 r
.51691 .81834 m .52043 .82066 L .52002 .81897 L F
.57 .433 .654 r
.52043 .82066 m .52279 .81823 L .52002 .81897 L F
.767 .615 .69 r
.61005 .78147 m .61188 .78482 L .60982 .78359 L F
.757 .616 .703 r
.61188 .78482 m .6078 .78643 L .60982 .78359 L F
.61188 .78482 m .61113 .78668 L .6078 .78643 L F
.75 .994 .823 r
.66127 .76547 m .66377 .76333 L .66207 .76402 L F
.747 .983 .751 r
.66069 .76557 m .66127 .76547 L .66207 .76402 L F
.718 .186 0 r
.54882 .80518 m .54666 .804 L .54758 .80444 L F
.969 .661 .379 r
.56009 .81988 m .56149 .82083 L .56162 .82295 L F
.22 0 0 r
.3522 .75422 m .35492 .75294 L .35383 .754 L F
.719 .648 .777 r
.70297 .71637 m .70495 .71524 L .70159 .71467 L F
.429 .056 .226 r
.35881 .78836 m .36154 .7868 L .35963 .78724 L F
.841 .696 .702 r
.62754 .73676 m .62484 .7374 L .62685 .73631 L F
.62754 .73676 m .62511 .73817 L .62484 .7374 L F
.891 .977 .822 r
.62754 .73676 m .62685 .73631 L .62897 .73381 L F
.397 .005 .174 r
.35525 .805 m .35718 .80477 L .35516 .80514 L F
.641 .107 0 r
.43833 .73862 m .43988 .73966 L .43778 .73799 L F
.812 .328 .021 r
.43833 .73862 m .43924 .74157 L .43988 .73966 L F
.494 .396 .673 r
.59118 .77034 m .59255 .76795 L .59298 .7673 L F
.948 .594 .281 r
.67893 .73116 m .67731 .72835 L .67855 .72896 L F
.312 .061 .364 r
.47219 .86786 m .47281 .86589 L .47437 .86524 L F
.969 .812 .631 r
.67619 .71841 m .67558 .72103 L .67499 .71852 L F
.221 .336 .769 r
.6753 .71551 m .67721 .71742 L .67619 .71841 L F
.346 .544 .904 r
.67619 .71841 m .67721 .71742 L .678 .71935 L F
.685 .425 .523 r
.47937 .82611 m .48288 .82613 L .4825 .82358 L F
.6 .366 .533 r
.4825 .82358 m .48457 .82566 L .48453 .82326 L F
.4825 .82358 m .48288 .82613 L .48457 .82566 L F
.557 .321 .514 r
.40933 .77024 m .40748 .76838 L .40963 .76819 L F
.40933 .77024 m .40721 .77054 L .40748 .76838 L F
.435 .804 .994 r
.52582 .8756 m .52961 .87613 L .52899 .87604 L F
.033 0 .412 r
.52961 .87613 m .53102 .87304 L .53064 .87534 L F
.468 .891 .888 r
.52899 .87604 m .52961 .87613 L .53064 .87534 L F
.621 .39 .546 r
.32734 .67886 m .32994 .67673 L .3277 .67891 L F
0 0 .534 r
.55857 .79715 m .56046 .79937 L .56065 .79982 L F
0 .369 .795 r
.56046 .79937 m .56217 .80059 L .56065 .79982 L F
.494 0 0 r
.47255 .88295 m .47452 .88319 L .47565 .88378 L F
.92 .798 .709 r
.48288 .82613 m .48203 .82828 L .48376 .82892 L F
.727 .903 .529 r
.48238 .83062 m .48376 .82892 L .48203 .82828 L F
.752 .722 .824 r
.48288 .82613 m .48376 .82892 L .48587 .82685 L F
.701 .692 .838 r
.38211 .89254 m .38548 .89363 L .38414 .89217 L F
.588 .745 .951 r
.38414 .89217 m .38548 .89363 L .38776 .89316 L F
.997 .791 .436 r
.473 .84677 m .47278 .84965 L .47364 .85034 L F
.664 .17 0 r
.47278 .84965 m .47449 .85147 L .47364 .85034 L F
.151 .013 .425 r
.60928 .82871 m .61111 .8258 L .61058 .82793 L F
0 0 .261 r
.60917 .83117 m .60928 .82871 L .61058 .82793 L F
.489 .901 .894 r
.71945 .72274 m .71797 .72373 L .71721 .72366 L F
.71945 .72274 m .71797 .72373 L .71721 .72366 L F
.971 .686 .28 r
.67097 .71533 m .67119 .7176 L .67191 .71809 L F
.85 .844 .38 r
.67111 .7197 m .67191 .71809 L .67119 .7176 L F
.67111 .7197 m .67071 .72215 L .67191 .71809 L F
.659 .568 .741 r
.64961 .75198 m .64859 .7559 L .64736 .7525 L F
.64961 .75198 m .65059 .75496 L .64859 .7559 L F
.684 .465 .584 r
.58625 .77313 m .58852 .7733 L .58869 .77102 L F
.705 .559 .686 r
.58852 .7733 m .59118 .77034 L .58869 .77102 L F
.621 .39 .546 r
.32734 .67886 m .33043 .67799 L .32994 .67673 L F
.3 .223 .6 r
.33043 .67799 m .33129 .67814 L .32994 .67673 L F
.494 .241 .458 r
.32994 .67673 m .33129 .67814 L .33212 .67614 L F
.755 .752 .85 r
.45412 .88269 m .45892 .88251 L .45978 .88412 L F
.443 0 .083 r
.45978 .88412 m .45892 .88251 L .46188 .88287 L F
.321 .084 .391 r
.50755 .83969 m .50742 .84146 L .50944 .83895 L F
.53 .403 .652 r
.45683 .86245 m .45424 .85919 L .45711 .86014 L F
.45683 .86245 m .45488 .86284 L .45424 .85919 L F
.714 .33 .319 r
.52703 .84737 m .52476 .84768 L .52263 .84693 L F
.597 .622 .848 r
.52263 .84693 m .52476 .84768 L .52474 .84763 L F
.698 .288 .267 r
.52263 .84693 m .52361 .84776 L .52475 .84763 L F
.52263 .84693 m .52474 .84763 L .52703 .84737 L F
.807 .745 .795 r
.52367 .84406 m .52474 .84763 L .52688 .8439 L F
.52474 .84763 m .52476 .84768 L .52479 .84763 L F
.52474 .84763 m .52479 .84763 L .52688 .8439 L F
.698 .288 .267 r
.52474 .84763 m .52475 .84763 L .52479 .84763 L F
.52474 .84763 m .52479 .84763 L .52703 .84737 L F
.597 .622 .848 r
.52263 .84693 m .52474 .84763 L .52367 .84406 L F
.832 .782 .804 r
.52688 .8439 m .52479 .84763 L .52703 .84737 L F
.52479 .84763 m .52476 .84768 L .52703 .84737 L F
.698 .288 .267 r
.52361 .84776 m .52474 .84872 L .52703 .84737 L F
.832 .782 .804 r
.52688 .8439 m .52703 .84737 L .52795 .84704 L F
.599 .223 .301 r
.52474 .84872 m .52795 .84704 L .52703 .84737 L F
.521 .671 .931 r
.40697 .8922 m .40787 .89073 L .40584 .89153 L F
.40697 .8922 m .40924 .89203 L .40787 .89073 L F
0 0 .495 r
.47995 .86166 m .47913 .86091 L .48139 .85937 L F
.47995 .86166 m .47991 .86371 L .47913 .86091 L F
.536 .331 .55 r
.52669 .81312 m .52871 .81468 L .5293 .81292 L F
.52669 .81312 m .52661 .81518 L .52871 .81468 L F
0 0 0 r
.55401 .84356 m .55535 .84237 L .55406 .84371 L F
.991 .882 .609 r
.55406 .84371 m .55535 .84237 L .55464 .84153 L F
.713 .553 0 r
.55412 .84391 m .55406 .84371 L .55423 .84276 L F
.55408 .84436 m .55406 .84371 L .55412 .84391 L F
0 0 0 r
.55291 .84454 m .55401 .84356 L .55406 .84371 L F
0 0 .478 r
.55419 .84628 m .55291 .84454 L .55406 .84371 L F
.55419 .84628 m .55333 .84712 L .55291 .84454 L F
.459 .166 .379 r
.39046 .78142 m .3879 .78349 L .38846 .78175 L F
.672 .294 .321 r
.49275 .86524 m .49386 .86296 L .49109 .86282 L F
.829 .481 .397 r
.49457 .86468 m .49386 .86296 L .49275 .86524 L F
.178 .156 .594 r
.71203 .70933 m .71293 .70963 L .71131 .71015 L F
.402 .324 .654 r
.71293 .70963 m .71128 .71318 L .71131 .71015 L F
.698 .46 .56 r
.66377 .76333 m .66523 .76051 L .66347 .76289 L F
.789 .999 .823 r
.66207 .76402 m .66377 .76333 L .66347 .76289 L F
.741 .668 .779 r
.50644 .85881 m .50354 .85808 L .5057 .8571 L F
0 .126 .675 r
.50758 .85939 m .50644 .85881 L .5057 .8571 L F
.50758 .85939 m .50764 .86045 L .50644 .85881 L F
.379 .085 .334 r
.3674 .79765 m .36919 .79719 L .36672 .79932 L F
.553 .351 .562 r
.39959 .75782 m .40174 .75754 L .40182 .75522 L F
.551 .36 .576 r
.40182 .75522 m .40392 .75493 L .40397 .75262 L F
.635 .467 .637 r
.40174 .75754 m .40392 .75493 L .40182 .75522 L F
.678 .458 .58 r
.4037 .86751 m .40657 .86793 L .40669 .86562 L F
.655 .541 .714 r
.40669 .86562 m .40925 .86554 L .40872 .86292 L F
.704 .526 .645 r
.40657 .86793 m .40925 .86554 L .40669 .86562 L F
.526 .117 .209 r
.48937 .86957 m .48959 .86823 L .48641 .86887 L F
0 0 .388 r
.49044 .86981 m .49 .8706 L .48959 .86823 L F
.49044 .86981 m .48959 .86823 L .48937 .86957 L F
.688 .572 .719 r
.5447 .84108 m .54072 .83973 L .54289 .83944 L F
.568 .61 .854 r
.53165 .86081 m .53375 .86059 L .53251 .85777 L F
.82 .58 .576 r
.69823 .74899 m .70113 .74733 L .69747 .74761 L F
.69823 .74899 m .7012 .74963 L .70113 .74733 L F
.649 .443 .591 r
.70113 .74733 m .70348 .74927 L .70346 .74686 L F
.70113 .74733 m .7012 .74963 L .70348 .74927 L F
.87 .63 .574 r
.47996 .87675 m .48342 .87646 L .48194 .87542 L F
.841 .533 .468 r
.48201 .87812 m .48342 .87646 L .47996 .87675 L F
0 0 0 r
.48405 .876 m .48342 .87646 L .48512 .87499 L F
.246 .577 .943 r
.48194 .87542 m .48342 .87646 L .48405 .876 L F
0 0 0 r
.48405 .876 m .48342 .87646 L .48512 .87499 L F
.48405 .876 m .48342 .87646 L .48201 .87812 L F
.545 .405 .641 r
.40397 .75262 m .40611 .75231 L .40599 .75078 L F
.529 .343 .572 r
.40397 .75262 m .40392 .75493 L .40611 .75231 L F
.775 .88 .923 r
.51788 .84683 m .51652 .84686 L .51724 .84698 L F
.56 .174 .266 r
.51562 .84403 m .51743 .84426 L .51937 .84182 L F
.51743 .84426 m .51788 .84432 L .5183 .8436 L F
.51743 .84426 m .5183 .8436 L .51937 .84182 L F
.576 .241 .365 r
.51788 .84432 m .52122 .8415 L .51937 .84182 L F
.51788 .84432 m .52006 .84425 L .52122 .8415 L F
.47 .653 .94 r
.517 .84318 m .51788 .84432 L .51562 .84403 L F
.595 .713 .926 r
.517 .84318 m .52006 .84425 L .51788 .84432 L F
.692 .678 .832 r
.517 .84318 m .5167 .84686 L .52006 .84425 L F
.5167 .84686 m .51669 .84705 L .51697 .8468 L F
.5167 .84686 m .51699 .8468 L .52006 .84425 L F
.775 .88 .923 r
.51697 .8468 m .51652 .84686 L .5167 .84686 L F
.933 .883 .761 r
.51652 .84686 m .51669 .84705 L .5167 .84686 L F
.775 .88 .923 r
.51697 .8468 m .51669 .84705 L .51652 .84686 L F
.51937 .84648 m .51697 .8468 L .51788 .84683 L F
.51697 .8468 m .5167 .84686 L .51788 .84683 L F
.51937 .84648 m .51669 .84705 L .51697 .8468 L F
.692 .678 .832 r
.51697 .8468 m .51669 .84705 L .51699 .8468 L F
.933 .883 .761 r
.51652 .84686 m .5167 .84686 L .51688 .84468 L F
.5168 .84474 m .51688 .84468 L .517 .84318 L F
.51652 .84686 m .51688 .84468 L .5168 .84474 L F
.672 .294 .321 r
.49275 .86524 m .49109 .86282 L .4916 .86577 L F
.261 .693 .964 r
.4916 .86577 m .49409 .86591 L .49275 .86524 L F
.705 .763 .897 r
.34382 .75499 m .34688 .75524 L .347 .7551 L F
.519 .369 .617 r
.41787 .74425 m .41594 .74461 L .41776 .74195 L F
.543 .437 .683 r
.41833 .74694 m .41594 .74461 L .41787 .74425 L F
.41833 .74694 m .41633 .74779 L .41594 .74461 L F
.354 .662 .972 r
.66133 .75268 m .65843 .75153 L .66028 .75166 L F
.745 .829 .916 r
.6631 .75157 m .66133 .75268 L .66028 .75166 L F
.459 .164 .376 r
.37407 .77865 m .37525 .7807 L .37604 .77821 L F
.37407 .77865 m .37329 .78112 L .37525 .7807 L F
.109 0 0 r
.45242 .83147 m .45324 .83123 L .45106 .83181 L F
.396 .656 .963 r
.44769 .83008 m .45242 .83147 L .45106 .83181 L F
.57 .433 .654 r
.52043 .82066 m .52245 .82111 L .52279 .81823 L F
.52 .248 .444 r
.52206 .83328 m .52457 .83115 L .52248 .83148 L F
.543 .353 .574 r
.52248 .83148 m .52457 .83115 L .52459 .82881 L F
.637 .461 .628 r
.43532 .83405 m .43315 .83663 L .4356 .83602 L F
.594 .431 .63 r
.43532 .83405 m .43747 .83534 L .43762 .83402 L F
.43532 .83405 m .4356 .83602 L .43747 .83534 L F
.687 .564 .71 r
.52474 .8268 m .52459 .82881 L .52667 .82612 L F
.662 .528 .691 r
.52459 .82881 m .52681 .82881 L .52667 .82612 L F
.616 .388 .549 r
.52457 .83115 m .52681 .82881 L .52459 .82881 L F
.505 .441 .718 r
.40466 .73402 m .40497 .73556 L .40308 .73574 L F
.606 .584 .803 r
.40602 .73754 m .40308 .73574 L .40497 .73556 L F
.41 .126 .368 r
.39445 .78049 m .39325 .77874 L .39526 .77832 L F
.39445 .78049 m .39258 .78105 L .39325 .77874 L F
.865 .854 .83 r
.59681 .81651 m .59642 .8198 L .59527 .81995 L F
.893 .834 .781 r
.5146 .83833 m .51286 .84144 L .51435 .84174 L F
.697 .335 .358 r
.51285 .84365 m .51435 .84174 L .51286 .84144 L F
.51285 .84365 m .51562 .84403 L .51435 .84174 L F
.663 .39 .497 r
.50518 .82886 m .50176 .83074 L .50316 .82864 L F
.662 .522 .682 r
.42037 .85261 m .41831 .85517 L .42042 .85496 L F
.609 .425 .607 r
.41833 .85755 m .42042 .85496 L .41831 .85517 L F
.781 .647 .715 r
.66686 .7373 m .6664 .73955 L .66579 .73613 L F
.403 .253 .561 r
.39149 .8841 m .39325 .8813 L .39094 .8813 L F
.39149 .8841 m .39336 .88351 L .39325 .8813 L F
.603 .469 .672 r
.39149 .8841 m .39436 .88633 L .39336 .88351 L F
.39149 .8841 m .39186 .88682 L .39436 .88633 L F
.531 .908 .949 r
.63916 .71344 m .64064 .71269 L .6418 .71295 L F
.256 0 .091 r
.63977 .71393 m .64161 .71219 L .64064 .71269 L F
0 .071 .618 r
.64102 .71074 m .6418 .71295 L .64222 .71163 L F
.721 .972 .929 r
.6418 .71295 m .64064 .71269 L .64222 .71163 L F
.256 0 .091 r
.64161 .71219 m .64222 .71163 L .64064 .71269 L F
.531 .908 .949 r
.63868 .71352 m .64064 .71269 L .63916 .71344 L F
.06 0 .317 r
.64368 .71263 m .64188 .71557 L .6418 .71295 L F
0 0 0 r
.61376 .818 m .6142 .81554 L .61441 .81525 L F
.739 .663 .776 r
.63837 .72375 m .63624 .72626 L .64088 .72597 L F
.536 .529 .794 r
.64088 .72597 m .64053 .72313 L .63837 .72375 L F
.64088 .72597 m .64161 .72585 L .64053 .72313 L F
0 .216 .713 r
.66577 .70699 m .66547 .7072 L .66371 .70561 L F
.66577 .70699 m .66657 .70799 L .66547 .7072 L F
.471 0 0 r
.69273 .72116 m .69261 .72151 L .68992 .72116 L F
.418 .394 .725 r
.6936 .71857 m .69467 .72052 L .69273 .72116 L F
.049 0 0 r
.69467 .72052 m .69261 .72151 L .69273 .72116 L F
.562 .386 .601 r
.40586 .72602 m .4038 .72886 L .40368 .72632 L F
.40368 .72632 m .4038 .72886 L .40586 .72602 L F
.638 .472 .642 r
.42893 .84194 m .42679 .84458 L .42892 .84439 L F
.607 .454 .648 r
.42892 .84439 m .43106 .84159 L .42893 .84194 L F
.751 .523 0 r
.54936 .81855 m .54992 .82146 L .54933 .81792 L F
.988 .753 .489 r
.54936 .81855 m .55106 .82287 L .54992 .82146 L F
.231 .378 .806 r
.68429 .7239 m .6867 .72578 L .68541 .72655 L F
.35 .65 .967 r
.6867 .72578 m .68786 .72693 L .68541 .72655 L F
.362 .694 .982 r
.68992 .72116 m .6911 .72018 L .68981 .72011 L F
.68992 .72116 m .69261 .72151 L .6911 .72018 L F
.929 .737 .622 r
.6664 .73955 m .66445 .73882 L .66579 .73613 L F
.87 .57 .478 r
.6664 .73955 m .66387 .74036 L .66445 .73882 L F
.6664 .73955 m .66658 .74137 L .66387 .74036 L F
.756 .619 .707 r
.61113 .78668 m .6094 .78967 L .6078 .78643 L F
.395 .369 .711 r
.6167 .74707 m .61727 .74541 L .61606 .7459 L F
.6167 .74707 m .61815 .74682 L .61727 .74541 L F
.512 .412 .678 r
.61663 .74954 m .61815 .74682 L .6167 .74707 L F
.498 .882 .967 r
.6904 .70408 m .69165 .70429 L .68894 .70485 L F
.6904 .70408 m .68894 .70485 L .68897 .70502 L F
.888 .912 .836 r
.60001 .80636 m .60219 .8058 L .60012 .80814 L F
.885 .899 .834 r
.60224 .80341 m .6043 .80309 L .60219 .8058 L F
.892 .903 .828 r
.60224 .80341 m .60219 .8058 L .60001 .80636 L F
.702 .201 0 r
.69189 .73919 m .69444 .74216 L .69455 .74208 L F
.621 .85 .476 r
.69444 .74216 m .69354 .74333 L .69455 .74208 L F
.7 .578 .715 r
.69354 .74333 m .69588 .74116 L .69455 .74208 L F
0 0 0 r
.59443 .84764 m .59913 .8446 L .59829 .84521 L F
.59732 .84589 m .59829 .84521 L .59756 .84574 L F
.59443 .84764 m .59829 .84521 L .59732 .84589 L F
.59443 .84764 m .59756 .84574 L .59571 .84634 L F
.091 0 0 r
.59515 .84702 m .59571 .84634 L .59676 .84628 L F
.59623 .84665 m .59676 .84628 L .59744 .84625 L F
.59515 .84702 m .59676 .84628 L .59623 .84665 L F
.994 .818 .561 r
.68449 .74226 m .68324 .74372 L .68332 .74147 L F
.68449 .74226 m .6841 .74442 L .68324 .74372 L F
.358 .179 .497 r
.36665 .75119 m .36521 .75241 L .36554 .75079 L F
.707 .259 .185 r
.50241 .87966 m .50452 .88138 L .50136 .8808 L F
.626 .092 0 r
.50241 .87966 m .50594 .88093 L .50452 .88138 L F
.305 .04 .337 r
.39959 .75782 m .39741 .76031 L .39951 .75993 L F
.637 .471 .641 r
.39951 .75993 m .40174 .75754 L .39959 .75782 L F
.865 .425 .149 r
.58083 .77921 m .58052 .7803 L .57865 .77898 L F
.58083 .77921 m .58203 .7811 L .58052 .7803 L F
.692 .408 .488 r
.45466 .83391 m .45674 .83623 L .45719 .83403 L F
.567 .273 .429 r
.45674 .83623 m .45987 .83365 L .45719 .83403 L F
.541 .911 .954 r
.54712 .78597 m .5465 .78576 L .54552 .78674 L F
.401 .695 .98 r
.54552 .78674 m .5465 .78576 L .54446 .7857 L F
.985 .879 .641 r
.55184 .82559 m .55355 .82353 L .55106 .82287 L F
.55184 .82559 m .55248 .82625 L .55355 .82353 L F
0 .006 .575 r
.6909 .72917 m .69225 .73098 L .69235 .73156 L F
0 0 .416 r
.69225 .73098 m .69255 .7339 L .69235 .73156 L F
.938 .684 .21 r
.55503 .83571 m .55525 .83385 L .555 .83346 L F
.55503 .83571 m .55546 .83621 L .55525 .83385 L F
.765 .504 .539 r
.59042 .78347 m .58942 .78117 L .59034 .78161 L F
.862 .973 .86 r
.59006 .82865 m .58694 .83065 L .58842 .83017 L F
.619 .95 .776 r
.59096 .82755 m .59295 .82651 L .59006 .82865 L F
.584 .876 .569 r
.59096 .82755 m .59006 .82865 L .58842 .83017 L F
.114 0 .044 r
.64163 .71344 m .6428 .71245 L .64222 .71163 L F
.6428 .71245 m .64419 .71127 L .64222 .71163 L F
0 .071 .618 r
.64169 .71088 m .64222 .71163 L .64431 .71142 L F
.64102 .71074 m .64222 .71163 L .64169 .71088 L F
.726 .785 .9 r
.64975 .76538 m .65101 .76666 L .6529 .76561 L F
.685 .59 .743 r
.52351 .85445 m .52506 .85687 L .52705 .85449 L F
.747 .748 .853 r
.52815 .85569 m .52506 .85687 L .5277 .85675 L F
.601 .467 .671 r
.52506 .85687 m .5277 .85675 L .52705 .85449 L F
.338 0 .193 r
.35718 .80477 m .35429 .80711 L .35516 .80514 L F
.627 .272 .35 r
.52917 .84987 m .52806 .85195 L .52588 .85165 L F
.571 .212 .32 r
.5306 .85103 m .52806 .85195 L .52917 .84987 L F
.59 .201 .274 r
.52917 .84987 m .5314 .85011 L .5306 .85103 L F
.785 .558 .592 r
.49876 .84134 m .50211 .8393 L .49871 .8393 L F
.49876 .84134 m .50197 .8418 L .50211 .8393 L F
.704 .487 .591 r
.50211 .8393 m .50197 .8418 L .5055 .8411 L F
.725 .82 .924 r
.39813 .89207 m .40168 .89229 L .40035 .89165 L F
.661 .873 .979 r
.40035 .89165 m .40168 .89229 L .40365 .89138 L F
.772 .829 .896 r
.69605 .74644 m .69692 .74403 L .69497 .74647 L F
.69605 .74644 m .69805 .74514 L .69692 .74403 L F
.784 .293 .043 r
.69497 .74647 m .69823 .74899 L .69605 .74644 L F
.653 .518 .687 r
.69605 .74644 m .69747 .74761 L .69805 .74514 L F
.792 .322 .115 r
.69823 .74899 m .69747 .74761 L .69605 .74644 L F
.643 .418 .563 r
.60762 .75785 m .60996 .75983 L .60977 .75747 L F
.60762 .75785 m .6076 .76008 L .60996 .75983 L F
0 0 .47 r
.45395 .83207 m .45428 .83302 L .45324 .83123 L F
.503 .857 .605 r
.45324 .83123 m .45274 .83157 L .45429 .83027 L F
.442 .276 .56 r
.45429 .83027 m .45274 .83157 L .45324 .83123 L F
.45332 .83109 m .45424 .83254 L .45429 .83027 L F
0 0 .47 r
.45399 .83214 m .45428 .83302 L .45395 .83207 L F
.442 .276 .56 r
.45429 .83027 m .45427 .83117 L .45274 .83157 L F
.45427 .83117 m .45424 .83261 L .45392 .83239 L F
0 0 .47 r
.45331 .83132 m .45466 .83391 L .45324 .83123 L F
.45358 .83163 m .45399 .83251 L .45331 .83132 L F
.45399 .83251 m .45466 .83391 L .45331 .83132 L F
.786 .552 .583 r
.45011 .83325 m .45354 .8358 L .45428 .83302 L F
.45428 .83302 m .45428 .83302 L .45428 .83302 L F
.45011 .83325 m .45428 .83302 L .45428 .83302 L F
.759 .73 .826 r
.45274 .83157 m .45011 .83325 L .45428 .83302 L F
.45428 .83301 m .45428 .83302 L .45428 .83302 L F
.45274 .83157 m .45428 .83302 L .45428 .83301 L F
.935 .871 .447 r
.45428 .83302 m .45428 .83301 L .45398 .83211 L F
0 .212 .7 r
.45428 .83302 m .45428 .83301 L .45428 .83301 L F
0 0 .47 r
.45441 .83326 m .45466 .83391 L .45427 .83309 L F
.45441 .83326 m .45427 .83309 L .45428 .83301 L F
.935 .871 .447 r
.45428 .83302 m .45428 .83302 L .45428 .83301 L F
.744 .398 .395 r
.45354 .8358 m .45466 .83391 L .45429 .83294 L F
0 .212 .7 r
.45428 .83301 m .45394 .83242 L .45274 .83157 L F
0 0 .47 r
.45428 .83301 m .45427 .83309 L .45358 .83163 L F
0 .212 .7 r
.45428 .83301 m .45392 .83239 L .45428 .83301 L F
0 0 .47 r
.45409 .83245 m .45428 .83301 L .45358 .83163 L F
.45428 .83301 m .45428 .83302 L .45428 .83301 L F
.45428 .83301 m .45428 .83301 L .45358 .83163 L F
.935 .871 .447 r
.45428 .83302 m .45354 .8358 L .45396 .83223 L F
0 0 .47 r
.45395 .83207 m .45409 .83245 L .45358 .83163 L F
.442 .276 .56 r
.45399 .83214 m .45392 .83239 L .4535 .83137 L F
0 0 .47 r
.45399 .83214 m .45466 .83391 L .45395 .83207 L F
.744 .398 .395 r
.45399 .83214 m .45429 .83294 L .45399 .83214 L F
.442 .276 .56 r
.45274 .83157 m .45424 .83254 L .45332 .83109 L F
.935 .871 .447 r
.45399 .83214 m .45396 .83223 L .45398 .83211 L F
.45428 .83302 m .45396 .83223 L .45399 .83214 L F
.442 .276 .56 r
.45394 .83234 m .45424 .83261 L .45424 .83254 L F
.45274 .83157 m .45392 .83239 L .45394 .83234 L F
.744 .398 .395 r
.45395 .83244 m .45422 .83284 L .45399 .83214 L F
.442 .276 .56 r
.45392 .83239 m .45424 .83261 L .45394 .83234 L F
.744 .398 .395 r
.45422 .83284 m .45429 .83294 L .45399 .83214 L F
0 .212 .7 r
.45428 .83302 m .45428 .833 L .45428 .83301 L F
0 0 .47 r
.45409 .83245 m .45441 .83326 L .45428 .83302 L F
0 .212 .7 r
.45428 .83301 m .45424 .83261 L .45392 .83239 L F
.45428 .833 m .45424 .83261 L .45428 .83301 L F
.744 .398 .395 r
.45354 .8358 m .45429 .83294 L .45395 .83244 L F
0 .212 .7 r
.45394 .83242 m .45392 .83239 L .45392 .83239 L F
.45394 .83242 m .45392 .83239 L .45274 .83157 L F
.442 .276 .56 r
.45427 .83117 m .45399 .83214 L .4535 .83137 L F
0 0 .47 r
.45398 .83211 m .45399 .83214 L .45395 .83207 L F
.45398 .83211 m .45399 .83214 L .45395 .83207 L F
.442 .276 .56 r
.4535 .83137 m .45392 .83239 L .45274 .83157 L F
.744 .398 .395 r
.45396 .83223 m .45399 .83214 L .45398 .83211 L F
.45354 .8358 m .45399 .83214 L .45396 .83223 L F
.45354 .8358 m .45674 .83623 L .45466 .83391 L F
.759 .831 .908 r
.57166 .81778 m .56846 .8185 L .5707 .82013 L F
.001 0 .092 r
.57166 .81778 m .5707 .82013 L .57289 .81738 L F
.295 .765 .938 r
.58014 .84797 m .58076 .84835 L .58268 .84818 L F
.715 .656 .789 r
.70159 .71467 m .70495 .71524 L .70389 .71264 L F
.653 .624 .808 r
.70389 .71264 m .70495 .71524 L .70692 .71354 L F
.705 .763 .897 r
.34382 .75499 m .347 .7551 L .34587 .75415 L F
.454 .66 .95 r
.347 .7551 m .3479 .75389 L .34587 .75415 L F
.347 .7551 m .34917 .75534 L .3479 .75389 L F
.003 0 0 r
.59044 .84756 m .59155 .84717 L .59368 .84682 L F
.477 .177 .377 r
.40019 .77398 m .39978 .77563 L .39772 .77598 L F
.537 .231 .396 r
.40231 .77394 m .39978 .77563 L .40019 .77398 L F
.639 .196 .183 r
.5706 .81575 m .56872 .81573 L .56919 .81552 L F
0 .218 .741 r
.66094 .7161 m .66247 .71863 L .66217 .71733 L F
0 0 0 r
.66164 .72014 m .66217 .71733 L .66247 .71863 L F
.589 .4 .594 r
.42682 .84693 m .42892 .84439 L .42679 .84458 L F
.6 .316 .457 r
.59718 .78342 m .59393 .78619 L .59399 .78431 L F
.603 .141 .129 r
.69916 .75289 m .70224 .75283 L .70136 .75415 L F
.377 0 .008 r
.70136 .75415 m .70224 .75283 L .70444 .75327 L F
.678 .565 .72 r
.70283 .70928 m .70324 .70739 L .70433 .70836 L F
.70283 .70928 m .70367 .70727 L .70324 .70739 L F
.70367 .70727 m .70416 .70608 L .70324 .70739 L F
.854 .857 .842 r
.70567 .7067 m .70469 .70698 L .705 .70481 L F
.70469 .70698 m .7044 .7064 L .705 .70481 L F
.70412 .70714 m .70423 .70624 L .70425 .70621 L F
.70428 .70671 m .70425 .70621 L .705 .70481 L F
.70412 .70714 m .70425 .70621 L .70428 .70671 L F
.373 .441 .802 r
.70416 .70608 m .70424 .70613 L .70424 .70607 L F
.453 .443 .758 r
.70416 .70608 m .70423 .70623 L .70424 .70613 L F
.678 .565 .72 r
.70367 .70727 m .70423 .70623 L .70416 .70608 L F
.795 .953 .62 r
.70416 .70608 m .70324 .70739 L .7042 .70599 L F
.70416 .70608 m .7042 .70599 L .705 .70481 L F
.854 .857 .842 r
.70367 .70727 m .70324 .70739 L .7042 .70599 L F
.70428 .70615 m .7042 .70599 L .70498 .70485 L F
.70367 .70727 m .7042 .70599 L .70428 .70615 L F
.70367 .70727 m .70498 .70485 L .705 .70481 L F
.66 .718 .891 r
.70786 .70589 m .70585 .7072 L .705 .70481 L F
.382 .575 .915 r
.70424 .70607 m .70656 .7056 L .70442 .70541 L F
.7042 .70599 m .70442 .70541 L .70388 .70536 L F
.70424 .70607 m .70442 .70541 L .7042 .70599 L F
.854 .857 .842 r
.70585 .7072 m .70324 .70739 L .70567 .7067 L F
.373 .441 .802 r
.70424 .70607 m .70755 .7085 L .70656 .7056 L F
.70424 .70613 m .70755 .7085 L .70424 .70607 L F
.697 .594 .736 r
.705 .70481 m .7022 .70528 L .70385 .70171 L F
.54 .927 .852 r
.7035 .70437 m .7022 .70528 L .705 .70481 L F
.382 .575 .915 r
.70388 .70536 m .70656 .7056 L .7035 .70437 L F
.70416 .70608 m .70424 .70607 L .70388 .70536 L F
.854 .857 .842 r
.70469 .70698 m .70412 .70714 L .7044 .7064 L F
.70412 .70714 m .70367 .70727 L .70423 .70624 L F
.70585 .7072 m .70433 .70836 L .70392 .708 L F
.7041 .70733 m .70392 .708 L .70345 .70758 L F
.70585 .7072 m .70392 .708 L .7041 .70733 L F
.678 .565 .72 r
.70283 .70928 m .70601 .71057 L .70432 .70646 L F
.70384 .70708 m .70432 .70646 L .70423 .70623 L F
.854 .857 .842 r
.7041 .70733 m .70345 .70758 L .70362 .70737 L F
.678 .565 .72 r
.70283 .70928 m .70432 .70646 L .70384 .70708 L F
.854 .857 .842 r
.70362 .70737 m .70345 .70758 L .70324 .70739 L F
.453 .443 .758 r
.70438 .70623 m .70601 .71057 L .70755 .7085 L F
.70424 .70613 m .70434 .70639 L .70438 .70623 L F
.70434 .70639 m .70601 .71057 L .70438 .70623 L F
.70423 .70623 m .70601 .71057 L .70424 .70613 L F
.678 .565 .72 r
.70283 .70928 m .70423 .70623 L .70367 .70727 L F
.621 .457 .639 r
.42463 .84722 m .42468 .84957 L .42682 .84693 L F
.679 .733 .891 r
.42221 .75096 m .41889 .7496 L .42099 .74913 L F
.347 .71 .985 r
.42347 .74997 m .42221 .75096 L .42099 .74913 L F
.42347 .74997 m .42446 .7508 L .42221 .75096 L F
.422 .15 .395 r
.39712 .76214 m .39951 .75993 L .39741 .76031 L F
.365 .134 .424 r
.38265 .78845 m .38132 .78711 L .38384 .7857 L F
.38265 .78845 m .38102 .78904 L .38132 .78711 L F
.634 .324 .427 r
.58942 .78117 m .58739 .78346 L .58529 .78172 L F
.765 .504 .539 r
.59042 .78347 m .58739 .78346 L .58942 .78117 L F
.413 .029 .198 r
.33769 .73319 m .34098 .73085 L .33905 .73154 L F
.627 .486 .671 r
.42042 .85496 m .42255 .85221 L .42037 .85261 L F
.249 0 0 r
.4956 .88221 m .49604 .88306 L .49382 .88302 L F
.4956 .88221 m .49756 .88179 L .49604 .88306 L F
.646 .29 .353 r
.58529 .78172 m .58207 .78337 L .58203 .7811 L F
.58529 .78172 m .58414 .78372 L .58207 .78337 L F
.661 .307 .361 r
.58739 .78346 m .58414 .78372 L .58529 .78172 L F
.507 .2 .38 r
.48641 .86887 m .48407 .87055 L .4854 .86972 L F
.526 .117 .209 r
.48937 .86957 m .48641 .86887 L .4854 .86972 L F
.879 .907 .845 r
.60329 .80231 m .6043 .80309 L .60224 .80341 L F
.304 0 0 r
.46885 .86954 m .47019 .86819 L .47219 .86786 L F
0 0 0 r
.6325 .73801 m .63086 .73939 L .63323 .73687 L F
.538 .402 .644 r
.6325 .73801 m .63066 .74182 L .63086 .73939 L F
.886 .688 .628 r
.68078 .73635 m .67917 .73367 L .68008 .73399 L F
.743 .704 .814 r
.37244 .88444 m .37306 .88392 L .37209 .88386 L F
0 0 .081 r
.63468 .73588 m .63323 .73687 L .63523 .73412 L F
.54 .384 .618 r
.63468 .73588 m .6325 .73801 L .63323 .73687 L F
.774 .621 .69 r
.61005 .78147 m .60668 .78328 L .60665 .7813 L F
.61005 .78147 m .60982 .78359 L .60668 .78328 L F
.678 .612 .774 r
.65419 .7572 m .65059 .75496 L .65356 .75534 L F
.385 .301 .637 r
.65551 .75476 m .65419 .7572 L .65356 .75534 L F
.65551 .75476 m .65583 .75752 L .65419 .7572 L F
.4 0 .131 r
.36835 .78304 m .37128 .78169 L .36916 .78196 L F
.702 .547 .674 r
.40872 .86292 m .41126 .86299 L .4109 .86024 L F
.66 .509 .668 r
.41126 .86299 m .41341 .8601 L .4109 .86024 L F
.807 .883 .901 r
.63965 .77217 m .64324 .77079 L .64208 .76991 L F
.727 .848 .938 r
.64208 .76991 m .64324 .77079 L .64537 .76978 L F
.6 .316 .457 r
.59718 .78342 m .59621 .78606 L .59393 .78619 L F
.658 .415 .541 r
.5992 .78359 m .59621 .78606 L .59718 .78342 L F
.517 .315 .545 r
.42831 .75415 m .42593 .75708 L .42623 .75482 L F
.541 .488 .745 r
.49464 .84181 m .49545 .83876 L .49368 .83931 L F
.49464 .84181 m .49517 .84225 L .49545 .83876 L F
.816 .477 .415 r
.49798 .84444 m .49615 .8442 L .49464 .84181 L F
.714 .463 .543 r
.49464 .84181 m .49615 .8442 L .49517 .84225 L F
.495 .353 .617 r
.33137 .687 m .33164 .68877 L .32984 .68948 L F
.384 .162 .45 r
.33164 .68877 m .32955 .69164 L .32984 .68948 L F
.571 .812 .99 r
.69323 .70282 m .69165 .70429 L .6904 .70408 L F
.69323 .70282 m .69397 .70394 L .69165 .70429 L F
.722 .624 .747 r
.65274 .7524 m .65356 .75534 L .65059 .75496 L F
.754 .954 .643 r
.43851 .88258 m .43712 .88421 L .43779 .88028 L F
.783 .729 .802 r
.43779 .88028 m .43761 .88133 L .43792 .88129 L F
.828 .99 .732 r
.43637 .88506 m .43749 .8839 L .43851 .88258 L F
.754 .954 .643 r
.43851 .88258 m .43749 .8839 L .4372 .88415 L F
.828 .99 .732 r
.43651 .88489 m .43851 .88258 L .43689 .88452 L F
.754 .954 .643 r
.43851 .88258 m .4372 .88415 L .43712 .88421 L F
.783 .729 .802 r
.43761 .88133 m .43712 .88421 L .43772 .88368 L F
.43831 .88311 m .43772 .88368 L .43833 .88316 L F
.93 .928 .784 r
.43637 .88506 m .43852 .8844 L .43749 .8839 L F
.828 .99 .732 r
.43644 .88506 m .43689 .88452 L .43758 .88502 L F
.43689 .88452 m .43851 .88258 L .43831 .88311 L F
.105 .656 .809 r
.43852 .8844 m .4398 .88441 L .43717 .88422 L F
.43852 .8844 m .43712 .88421 L .43749 .8839 L F
.43716 .88422 m .43717 .88422 L .43712 .88421 L F
.43852 .8844 m .43717 .88422 L .43716 .88422 L F
.828 .99 .732 r
.43689 .88452 m .43719 .88421 L .43758 .88502 L F
.818 .923 .906 r
.43712 .88421 m .44174 .88173 L .4409 .88091 L F
.828 .99 .732 r
.43735 .88406 m .43826 .88324 L .43791 .88414 L F
.993 .75 .451 r
.43791 .88414 m .43826 .88324 L .43726 .88404 L F
.43826 .88324 m .43851 .88258 L .43807 .88309 L F
.828 .99 .732 r
.43735 .88406 m .43831 .88311 L .43826 .88324 L F
.783 .729 .802 r
.43761 .88133 m .43772 .88368 L .43831 .88311 L F
.993 .75 .451 r
.43826 .88324 m .43807 .88309 L .43726 .88404 L F
.818 .923 .906 r
.43854 .88345 m .43982 .88441 L .44174 .88173 L F
.43726 .88414 m .43978 .88441 L .43854 .88345 L F
.43978 .88441 m .43982 .88441 L .43854 .88345 L F
.43712 .88421 m .43717 .88422 L .43726 .88414 L F
.43717 .88422 m .43982 .88441 L .43726 .88414 L F
.828 .99 .732 r
.43719 .88421 m .43735 .88406 L .43791 .88414 L F
.43719 .88421 m .43791 .88414 L .43758 .88502 L F
.783 .729 .802 r
.44045 .88097 m .43833 .88316 L .4409 .88091 L F
.997 .84 .563 r
.43809 .88255 m .43851 .88258 L .43779 .88028 L F
.993 .75 .451 r
.43823 .88291 m .43851 .88258 L .43809 .88255 L F
.783 .729 .802 r
.43761 .88133 m .43831 .88311 L .44045 .88097 L F
.43831 .88311 m .43833 .88316 L .44045 .88097 L F
.828 .99 .732 r
.43637 .88506 m .43651 .88489 L .43644 .88506 L F
.43651 .88489 m .43689 .88452 L .43644 .88506 L F
.997 .84 .563 r
.43674 .88243 m .43809 .88255 L .43779 .88028 L F
.783 .729 .802 r
.43779 .88028 m .43792 .88129 L .4409 .88091 L F
.993 .75 .451 r
.43726 .88404 m .43823 .88291 L .43674 .88243 L F
.43823 .88291 m .43809 .88255 L .43674 .88243 L F
.43758 .88502 m .43791 .88414 L .43726 .88404 L F
.105 .656 .809 r
.4398 .88441 m .43982 .88441 L .43978 .88441 L F
.4398 .88441 m .43978 .88441 L .43712 .88421 L F
.693 .564 .704 r
.64407 .74984 m .64736 .7525 L .64549 .75355 L F
.64 .516 .697 r
.4017 .8679 m .4045 .87056 L .4037 .86751 L F
.4017 .8679 m .40223 .87084 L .4045 .87056 L F
.628 .575 .776 r
.50145 .8578 m .5013 .86029 L .49937 .85815 L F
.885 .502 .303 r
.49937 .85815 m .5013 .86029 L .49968 .86017 L F
.731 .665 .784 r
.50354 .85808 m .5013 .86029 L .50145 .8578 L F
.601 .037 0 r
.49968 .86017 m .5013 .86029 L .50378 .86184 L F
.947 .929 .751 r
.61932 .80203 m .62164 .79971 L .62092 .79909 L F
.61932 .80203 m .62018 .8025 L .62164 .79971 L F
.951 .888 .732 r
.62164 .79971 m .62172 .79706 L .62092 .79909 L F
.477 .867 .971 r
.58268 .84818 m .58623 .84786 L .58501 .84764 L F
.283 .781 .867 r
.58623 .84786 m .58724 .84743 L .58501 .84764 L F
.58623 .84786 m .5884 .84747 L .58724 .84743 L F
.252 .006 .333 r
.38438 .91563 m .38238 .91813 L .38497 .91748 L F
.494 .201 .397 r
.41468 .76487 m .41381 .76769 L .4118 .76796 L F
.519 .277 .489 r
.41704 .76298 m .41672 .76467 L .41468 .76487 L F
.542 .263 .441 r
.41672 .76467 m .41381 .76769 L .41468 .76487 L F
.852 .58 .526 r
.63981 .71872 m .64046 .72101 L .63946 .71997 L F
0 0 .203 r
.64136 .71746 m .63946 .71997 L .63981 .71872 L F
0 0 0 r
.38363 .7474 m .38234 .74919 L .38103 .7496 L F
.38392 .74819 m .38363 .7474 L .38513 .74657 L F
.282 0 .026 r
.38601 .74761 m .38392 .74819 L .38403 .74804 L F
.38601 .74761 m .38403 .74804 L .38513 .74657 L F
.395 0 .157 r
.38809 .74722 m .38601 .74761 L .38702 .74619 L F
.197 .724 .834 r
.38809 .74722 m .38771 .74724 L .38601 .74761 L F
.282 0 .026 r
.38601 .74761 m .38513 .74657 L .38702 .74619 L F
.197 .724 .834 r
.38771 .74724 m .38478 .7474 L .38601 .74761 L F
.338 .803 .93 r
.38601 .74761 m .38497 .74765 L .38392 .74819 L F
.38497 .74765 m .38276 .74773 L .38392 .74819 L F
0 0 0 r
.38392 .74819 m .38234 .74919 L .38254 .7489 L F
.38392 .74819 m .38254 .7489 L .38363 .7474 L F
.488 .522 .819 r
.49033 .84955 m .49483 .85241 L .49371 .84882 L F
.646 .287 .348 r
.49371 .84882 m .49572 .84952 L .49541 .84915 L F
.744 .486 .54 r
.49371 .84882 m .4957 .8522 L .49572 .84952 L F
.49371 .84882 m .49483 .85241 L .4957 .8522 L F
.592 .594 .822 r
.69843 .71035 m .70182 .7131 L .70065 .70997 L F
.615 .606 .819 r
.70065 .70997 m .70182 .7131 L .70389 .71264 L F
.715 .656 .789 r
.70159 .71467 m .70389 .71264 L .70182 .7131 L F
.666 .928 .972 r
.51512 .85397 m .5151 .85485 L .51302 .85472 L F
.51512 .85397 m .51651 .85431 L .5151 .85485 L F
.857 .681 .663 r
.5151 .85485 m .5142 .85728 L .51302 .85472 L F
.343 0 .206 r
.38556 .77017 m .38676 .77047 L .38811 .76832 L F
.5 .15 .303 r
.38811 .76832 m .38909 .76962 L .39028 .76817 L F
.38811 .76832 m .38676 .77047 L .38909 .76962 L F
.904 .941 .822 r
.66275 .73155 m .66315 .72946 L .66417 .72886 L F
.666 .321 0 r
.663 .72607 m .66417 .72886 L .66351 .72733 L F
.977 .921 .63 r
.66417 .72886 m .66315 .72946 L .66351 .72733 L F
.613 .475 .67 r
.43315 .83663 m .43442 .83915 L .4356 .83602 L F
.43315 .83663 m .43313 .83935 L .43442 .83915 L F
.806 .456 .394 r
.6936 .7499 m .69693 .75229 L .69366 .75228 L F
.773 .566 .619 r
.6936 .7499 m .69047 .752 L .69053 .74984 L F
.6936 .7499 m .69366 .75228 L .69047 .752 L F
.579 .003 0 r
.38592 .88717 m .38819 .8888 L .38627 .88731 L F
.574 .317 .489 r
.5447 .84108 m .54327 .84421 L .54105 .84432 L F
.636 .32 .419 r
.54614 .84221 m .54327 .84421 L .5447 .84108 L F
.605 .472 .674 r
.52842 .82365 m .52667 .82612 L .52903 .82566 L F
.715 .569 .689 r
.52667 .82612 m .52993 .82872 L .52903 .82566 L F
.52667 .82612 m .52681 .82881 L .52993 .82872 L F
.537 .076 .105 r
.39889 .72681 m .39692 .72795 L .39743 .72681 L F
.671 .661 .831 r
.40199 .74659 m .40282 .74752 L .40502 .74704 L F
.518 .515 .792 r
.40282 .74752 m .40599 .75078 L .40502 .74704 L F
.873 .711 .19 r
.55535 .84237 m .55513 .8384 L .55464 .84153 L F
.734 .839 .93 r
.68091 .71325 m .68136 .71215 L .68266 .71372 L F
.87 .551 .445 r
.68266 .71372 m .68224 .71489 L .68091 .71325 L F
.509 .568 .851 r
.68402 .71182 m .68266 .71372 L .68136 .71215 L F
0 0 0 r
.6854 .71298 m .68224 .71489 L .68266 .71372 L F
.6854 .71298 m .68507 .71345 L .68224 .71489 L F
.209 0 0 r
.68266 .71372 m .68488 .71348 L .6854 .71298 L F
.68488 .71348 m .68507 .71345 L .6851 .71341 L F
.68488 .71348 m .6851 .71341 L .6854 .71298 L F
.714 .652 .787 r
.68204 .71429 m .68402 .71182 L .68136 .71215 L F
.68224 .71489 m .6827 .7141 L .68204 .71429 L F
.509 .568 .851 r
.68402 .71182 m .68507 .71345 L .68266 .71372 L F
.714 .652 .787 r
.6827 .7141 m .68402 .71182 L .68204 .71429 L F
.691 .2 .074 r
.53375 .85597 m .53283 .85479 L .53135 .85568 L F
.521 0 0 r
.53375 .85597 m .53408 .85615 L .53283 .85479 L F
.663 .39 .497 r
.50518 .82886 m .50507 .83086 L .50176 .83074 L F
.619 .434 .609 r
.50728 .82835 m .50507 .83086 L .50518 .82886 L F
.924 .692 .202 r
.6599 .70787 m .65957 .70911 L .65924 .70734 L F
.6599 .70787 m .65997 .7099 L .65957 .70911 L F
0 0 .518 r
.55516 .82996 m .55418 .82905 L .5534 .82866 L F
.855 .982 .857 r
.48749 .87363 m .49 .8706 L .4893 .87342 L F
.837 .878 .873 r
.49065 .87358 m .4893 .87342 L .49047 .87329 L F
.254 0 0 r
.34302 .73047 m .34505 .73018 L .34665 .72894 L F
.383 0 .053 r
.34505 .73018 m .34859 .72839 L .34665 .72894 L F
.906 .975 .798 r
.66196 .70504 m .65924 .70734 L .66058 .70519 L F
0 .426 .774 r
.66243 .70499 m .66196 .70504 L .66058 .70519 L F
.66243 .70499 m .66371 .70561 L .66196 .70504 L F
.847 .779 .785 r
.60715 .7922 m .60373 .79405 L .60575 .79127 L F
.60715 .7922 m .60513 .79491 L .60373 .79405 L F
.828 .801 .825 r
.6094 .78967 m .60715 .7922 L .60575 .79127 L F
.925 .829 .732 r
.60513 .79491 m .60463 .79701 L .60319 .79603 L F
.937 .855 .735 r
.60296 .79955 m .60319 .79603 L .60463 .79701 L F
.738 .9 .951 r
.54591 .79891 m .54248 .7998 L .54479 .79869 L F
.568 .01 0 r
.54479 .79869 m .54777 .79937 L .54591 .79891 L F
.939 .568 .228 r
.52382 .8184 m .52448 .82063 L .52545 .82104 L F
.446 .842 .978 r
.52545 .82104 m .52448 .82063 L .52245 .82111 L F
.701 .593 .733 r
.52545 .82104 m .52768 .82132 L .52755 .8183 L F
.345 .191 .524 r
.60503 .8387 m .60369 .83922 L .60513 .83623 L F
.346 .194 .527 r
.60367 .8418 m .60369 .83922 L .60503 .8387 L F
.492 .231 .446 r
.41913 .76271 m .41672 .76467 L .41704 .76298 L F
.452 .719 .982 r
.39648 .74581 m .39941 .7465 L .39797 .74547 L F
.607 .713 .92 r
.39941 .7465 m .40033 .74407 L .39797 .74547 L F
.39941 .7465 m .40199 .74659 L .40033 .74407 L F
.669 .477 .617 r
.38139 .89118 m .38282 .88832 L .3833 .88964 L F
.616 .852 .988 r
.37028 .7246 m .36714 .72439 L .36825 .72393 L F
.57 .017 0 r
.36825 .72393 m .37239 .72478 L .37028 .7246 L F
.81 .678 .133 r
.56464 .83656 m .56445 .83931 L .56414 .83568 L F
.56464 .83656 m .56451 .83894 L .56445 .83931 L F
.542 .409 .649 r
.63525 .73189 m .63468 .73588 L .63523 .73412 L F
.452 .719 .982 r
.39648 .74581 m .39797 .74547 L .39599 .74563 L F
.623 .12 .035 r
.50791 .88145 m .51144 .88197 L .51018 .8829 L F
.177 0 0 r
.51018 .8829 m .51144 .88197 L .51357 .88167 L F
0 .4 .85 r
.38762 .91804 m .38438 .91563 L .38497 .91748 L F
.595 .638 .864 r
.40808 .73705 m .40602 .73754 L .40497 .73556 L F
.778 .624 .69 r
.48785 .82594 m .49105 .82844 L .49016 .8253 L F
.48785 .82594 m .48964 .82974 L .49105 .82844 L F
.597 .54 .761 r
.49105 .82844 m .49328 .82596 L .49016 .8253 L F
.49105 .82844 m .49346 .82813 L .49328 .82596 L F
.546 .474 .725 r
.41833 .74694 m .4169 .74986 L .41633 .74779 L F
.41833 .74694 m .41889 .7496 L .4169 .74986 L F
.669 .324 .38 r
.57717 .77837 m .57553 .78058 L .57335 .7787 L F
.487 .063 .16 r
.57865 .77898 m .57553 .78058 L .57717 .77837 L F
.611 .346 .492 r
.60151 .78164 m .60144 .78355 L .5992 .78359 L F
.712 .501 .602 r
.60511 .78123 m .60144 .78355 L .60151 .78164 L F
.06 0 .317 r
.64368 .71263 m .64329 .71454 L .64188 .71557 L F
0 0 .104 r
.64188 .71557 m .64329 .71454 L .64136 .71746 L F
0 0 0 r
.43637 .88506 m .43528 .88586 L .43852 .8844 L F
.575 .495 .727 r
.52755 .8183 m .52768 .82132 L .53057 .82031 L F
.505 .428 .704 r
.52768 .82132 m .5297 .82285 L .53057 .82031 L F
.52768 .82132 m .52842 .82365 L .5297 .82285 L F
.316 0 .133 r
.659 .72257 m .66164 .72014 L .65985 .72124 L F
.95 .897 .738 r
.60012 .80814 m .59827 .8096 L .60001 .80636 L F
.60012 .80814 m .59929 .81011 L .59827 .8096 L F
.416 .55 .882 r
.69059 .7274 m .68913 .72816 L .68786 .72693 L F
.69059 .7274 m .6909 .72917 L .68913 .72816 L F
0 .56 .716 r
.54777 .79937 m .54985 .79945 L .5511 .79951 L F
.747 .437 .459 r
.54985 .79945 m .55362 .80019 L .5511 .79951 L F
.636 .32 .419 r
.54614 .84221 m .54642 .84428 L .54327 .84421 L F
.962 .771 .598 r
.54948 .84206 m .54642 .84428 L .54614 .84221 L F
.431 .192 .45 r
.48547 .85021 m .48798 .85173 L .48777 .84986 L F
.48547 .85021 m .48521 .85255 L .48689 .85147 L F
.943 .624 .402 r
.55718 .81508 m .55558 .81233 L .55673 .8129 L F
.88 .497 .308 r
.49835 .85731 m .49937 .85815 L .49968 .86017 L F
.628 .575 .776 r
.50145 .8578 m .49937 .85815 L .49835 .85731 L F
0 0 0 r
.51654 .8806 m .51752 .88064 L .51565 .88119 L F
.51654 .8806 m .51896 .87839 L .51752 .88064 L F
.556 .6 .853 r
.56535 .84438 m .56697 .84691 L .56892 .84672 L F
.496 .258 .482 r
.40721 .77054 m .40478 .773 L .40509 .77091 L F
.389 .676 .974 r
.37954 .72533 m .37886 .72646 L .37755 .72572 L F
.37954 .72533 m .38092 .72661 L .37886 .72646 L F
.706 .325 .325 r
.44278 .83306 m .44478 .8335 L .443 .83191 L F
.58 .372 .563 r
.443 .83191 m .44478 .8335 L .44517 .83118 L F
.737 .489 .554 r
.52681 .82881 m .52981 .83136 L .52993 .82872 L F
.533 .615 .88 r
.52993 .82872 m .53054 .826 L .52903 .82566 L F
.52993 .82872 m .53152 .82844 L .53054 .826 L F
.495 .347 .609 r
.52993 .82872 m .53176 .83057 L .53152 .82844 L F
.746 .639 .742 r
.53372 .84708 m .53453 .84975 L .5314 .85011 L F
.528 .877 .987 r
.5314 .85011 m .53453 .84975 L .5335 .84932 L F
.984 .729 .463 r
.5335 .84932 m .53453 .84975 L .53372 .84708 L F
.988 .812 .578 r
.59827 .8096 m .59929 .81011 L .59857 .81241 L F
.596 .687 .906 r
.35876 .75143 m .36024 .75316 L .36182 .75266 L F
.465 .56 .868 r
.65906 .74911 m .65843 .75153 L .65704 .74975 L F
.65906 .74911 m .66028 .75166 L .65843 .75153 L F
.522 .783 .992 r
.41354 .73708 m .41136 .73746 L .41001 .73645 L F
.68 .649 .812 r
.63869 .7499 m .63548 .74915 L .63777 .7471 L F
.748 .686 .791 r
.64098 .74747 m .63869 .7499 L .63777 .7471 L F
.719 .635 .764 r
.64067 .74935 m .63869 .7499 L .64098 .74747 L F
.639 .29 .364 r
.49814 .87771 m .49873 .87543 L .49604 .87594 L F
0 0 .128 r
.5004 .87458 m .49873 .87543 L .49814 .87771 L F
.271 .552 .927 r
.529 .87088 m .53102 .87304 L .52832 .87211 L F
.122 .463 .89 r
.53168 .87275 m .53102 .87304 L .529 .87088 L F
.53168 .87275 m .529 .87088 L .53178 .87033 L F
.251 0 0 r
.52807 .87189 m .53007 .87105 L .529 .87088 L F
.53007 .87105 m .53178 .87033 L .529 .87088 L F
.271 .552 .927 r
.529 .87088 m .52832 .87211 L .52753 .87066 L F
.529 .87088 m .52753 .87066 L .5273 .87024 L F
.635 .963 .826 r
.51533 .87565 m .51237 .8772 L .51433 .87761 L F
.816 .631 .652 r
.51433 .87761 m .51759 .87568 L .51533 .87565 L F
.669 .477 .617 r
.38139 .89118 m .38414 .89217 L .38282 .88832 L F
.568 .422 .642 r
.38282 .88832 m .38633 .89162 L .38592 .88717 L F
.38282 .88832 m .38414 .89217 L .38633 .89162 L F
.818 .985 .882 r
.52286 .85346 m .52351 .85445 L .52588 .85165 L F
.588 .554 .784 r
.41917 .73812 m .41747 .73984 L .41633 .73697 L F
.537 .455 .71 r
.41917 .73812 m .41776 .74195 L .41747 .73984 L F
.323 0 .094 r
.36533 .8011 m .36476 .79963 L .36672 .79932 L F
.36533 .8011 m .36338 .80153 L .36476 .79963 L F
.996 .785 .502 r
.56162 .82295 m .56228 .82603 L .56186 .82552 L F
.353 0 0 r
.47449 .85147 m .47626 .85181 L .47638 .85147 L F
.27 0 0 r
.47626 .85181 m .47897 .85082 L .47638 .85147 L F
.408 .069 .276 r
.35691 .78901 m .35792 .79079 L .35881 .78836 L F
.35691 .78901 m .35594 .7912 L .35792 .79079 L F
.171 .632 .935 r
.51727 .85386 m .51651 .85431 L .51512 .85397 L F
.51727 .85386 m .51844 .85455 L .51651 .85431 L F
.699 .58 .719 r
.64284 .74648 m .64067 .74935 L .64098 .74747 L F
.64284 .74648 m .64407 .74984 L .64067 .74935 L F
.683 .159 0 r
.55397 .81008 m .55336 .80985 L .55173 .80811 L F
.884 .551 .412 r
.55558 .81233 m .55336 .80985 L .55397 .81008 L F
0 0 0 r
.38234 .74919 m .38037 .74987 L .38103 .7496 L F
.772 .641 .716 r
.60982 .78359 m .6078 .78643 L .60668 .78328 L F
.592 .592 .82 r
.63506 .72095 m .63723 .72057 L .63601 .71777 L F
0 0 0 r
.43637 .88506 m .43493 .88642 L .43528 .88586 L F
.911 .933 .813 r
.62613 .78577 m .62903 .78355 L .62793 .78299 L F
.62613 .78577 m .62689 .78637 L .62903 .78355 L F
.809 .888 .901 r
.62903 .78355 m .63053 .7806 L .62793 .78299 L F
.62903 .78355 m .63167 .78137 L .63053 .7806 L F
.341 .746 .982 r
.44613 .88285 m .44872 .88332 L .44749 .8829 L F
.482 .782 .997 r
.44872 .88332 m .4498 .88239 L .44749 .8829 L F
.44872 .88332 m .45073 .88315 L .4498 .88239 L F
.132 .366 .825 r
.69047 .73718 m .69251 .73841 L .69189 .73919 L F
.767 .268 0 r
.69245 .74058 m .69444 .74216 L .69189 .73919 L F
.69253 .74078 m .69283 .74099 L .69245 .74058 L F
.69283 .74099 m .69444 .74216 L .69245 .74058 L F
.7 .578 .715 r
.69354 .74333 m .69692 .74403 L .69588 .74116 L F
.335 .46 .838 r
.69409 .74123 m .69534 .74252 L .69455 .74288 L F
.69386 .74212 m .69455 .74288 L .69354 .74333 L F
.923 .81 .716 r
.69253 .74078 m .69354 .74333 L .69444 .74216 L F
.335 .46 .838 r
.69409 .74123 m .69455 .74288 L .69386 .74212 L F
.767 .268 0 r
.69253 .74078 m .69189 .73919 L .69251 .73841 L F
.664 .953 .951 r
.68765 .71267 m .68507 .71345 L .6854 .71298 L F
.68765 .71267 m .68507 .71345 L .6854 .71298 L F
.333 .807 .738 r
.48442 .88473 m .48442 .88474 L .48551 .88452 L F
.48442 .88474 m .48442 .88497 L .48544 .88455 L F
.48442 .88474 m .48544 .88455 L .48551 .88452 L F
0 0 0 r
.48518 .88465 m .48609 .88464 L .48419 .88478 L F
.48434 .88475 m .48419 .88478 L .48399 .88479 L F
.48518 .88465 m .48419 .88478 L .48434 .88475 L F
.01 0 0 r
.48442 .88473 m .48518 .88465 L .48434 .88475 L F
.48442 .88473 m .48434 .88475 L .48399 .88479 L F
.333 .807 .738 r
.48442 .88473 m .48551 .88452 L .48666 .88406 L F
.721 .277 0 r
.56309 .83157 m .56341 .83251 L .56387 .83017 L F
.56309 .83157 m .56407 .83309 L .56341 .83251 L F
.69 .664 .819 r
.40154 .73294 m .39931 .73355 L .39831 .73085 L F
.639 .617 .811 r
.39486 .8912 m .39547 .89345 L .39813 .89207 L F
.68 .452 .569 r
.49798 .84444 m .4948 .84739 L .49615 .8442 L F
.49798 .84444 m .49889 .84816 L .4948 .84739 L F
.518 .352 .595 r
.50011 .84668 m .49889 .84816 L .49798 .84444 L F
.632 .321 .426 r
.54861 .7831 m .55172 .78106 L .54966 .78138 L F
.797 .895 .913 r
.55188 .78339 m .55298 .78413 L .55558 .78208 L F
.575 .324 .498 r
.46216 .8338 m .46448 .83359 L .46468 .83152 L F
.46 .161 .37 r
.46448 .83359 m .46727 .83072 L .46468 .83152 L F
.537 .544 .809 r
.66039 .71506 m .65863 .71658 L .65771 .71516 L F
.66039 .71506 m .66094 .7161 L .65863 .71658 L F
.65863 .71658 m .66039 .71506 L .65771 .71516 L F
.65863 .71658 m .66094 .7161 L .66039 .71506 L F
.531 .71 .954 r
.65771 .71516 m .66094 .7161 L .65863 .71658 L F
.34 0 .076 r
.57219 .77518 m .57419 .77481 L .57535 .77311 L F
.416 0 .09 r
.57419 .77481 m .57766 .77303 L .57535 .77311 L F
0 .57 .709 r
.4771 .86366 m .47991 .86371 L .47854 .86368 L F
.905 .955 .818 r
.47854 .86368 m .47991 .86371 L .47995 .86166 L F
.609 .425 .607 r
.41833 .85755 m .4204 .8573 L .42042 .85496 L F
.627 .486 .671 r
.42042 .85496 m .42216 .85501 L .42255 .85221 L F
.606 .413 .594 r
.4204 .8573 m .42216 .85501 L .42042 .85496 L F
.602 .487 .694 r
.43032 .75183 m .42783 .74972 L .42967 .7494 L F
.43032 .75183 m .42846 .7524 L .42783 .74972 L F
.216 0 0 r
.42614 .75078 m .42967 .7494 L .42783 .74972 L F
0 0 0 r
.60045 .84398 m .59913 .8446 L .60087 .84347 L F
.59756 .84574 m .59913 .8446 L .60045 .84398 L F
.275 0 0 r
.47151 .83015 m .47354 .82969 L .4748 .82812 L F
.175 0 .095 r
.4748 .82812 m .47632 .8283 L .47724 .82622 L F
.17 0 0 r
.4748 .82812 m .47354 .82969 L .47632 .8283 L F
.96 .787 .625 r
.61859 .80395 m .62018 .8025 L .61932 .80203 L F
.61859 .80395 m .61977 .80453 L .62018 .8025 L F
.765 .975 .919 r
.64431 .71142 m .64222 .71163 L .64498 .70961 L F
.502 .005 .007 r
.50942 .8769 m .51015 .87585 L .50682 .87618 L F
.748 .385 .366 r
.50942 .8769 m .51237 .8772 L .51015 .87585 L F
.538 .57 .835 r
.39692 .72795 m .39636 .7311 L .39527 .72804 L F
.39692 .72795 m .39831 .73085 L .39636 .7311 L F
.588 .529 .756 r
.49545 .83876 m .49517 .84225 L .49876 .84134 L F
.491 .37 .642 r
.49517 .84225 m .49926 .84298 L .49876 .84134 L F
.49517 .84225 m .49615 .8442 L .49926 .84298 L F
.823 .642 .657 r
.6078 .78643 m .6094 .78967 L .60758 .78878 L F
.828 .801 .825 r
.6094 .78967 m .60575 .79127 L .60758 .78878 L F
.558 .906 .973 r
.3648 .72511 m .36553 .72407 L .36714 .72439 L F
.3648 .72511 m .36343 .72485 L .36553 .72407 L F
.451 .145 .354 r
.56654 .81055 m .56852 .81153 L .56921 .81088 L F
.668 .129 0 r
.56852 .81153 m .57129 .81237 L .56921 .81088 L F
.676 .146 0 r
.56921 .81088 m .57129 .81237 L .57297 .81271 L F
.546 .019 0 r
.50594 .88093 m .50697 .88248 L .50452 .88138 L F
.50594 .88093 m .50791 .88145 L .50697 .88248 L F
.549 .304 .496 r
.38102 .78904 m .37848 .79125 L .37917 .78978 L F
.551 .426 .663 r
.69843 .71035 m .69688 .70714 L .69754 .70956 L F
.518 .808 .998 r
.69754 .70956 m .70065 .70997 L .69843 .71035 L F
.69754 .70956 m .70065 .70997 L .69843 .71035 L F
.242 .228 .643 r
.3952 .876 m .39681 .87798 L .39691 .87558 L F
.3952 .876 m .39569 .87881 L .39681 .87798 L F
.579 .654 .887 r
.38951 .72823 m .38755 .72868 L .38586 .72635 L F
.751 .539 .608 r
.49207 .82289 m .49594 .82444 L .49545 .82077 L F
0 0 .359 r
.49545 .82077 m .49565 .82228 L .49624 .82226 L F
.49565 .82228 m .49594 .82444 L .49623 .82234 L F
.49565 .82228 m .49623 .82234 L .49624 .82226 L F
.49647 .8219 m .4963 .8223 L .49753 .82306 L F
.72 .589 .709 r
.49207 .82289 m .49535 .82528 L .49594 .82444 L F
.335 .101 .403 r
.49594 .82444 m .49753 .82306 L .49628 .82229 L F
.49594 .82444 m .49628 .82229 L .49623 .82232 L F
.72 .589 .709 r
.49207 .82289 m .49328 .82596 L .49535 .82528 L F
.313 0 .18 r
.49683 .82209 m .49416 .82368 L .49611 .8224 L F
0 0 0 r
.49621 .82251 m .49629 .82232 L .49652 .82222 L F
.49675 .82214 m .49652 .82222 L .49683 .82209 L F
.364 .732 .989 r
.49633 .82229 m .49703 .82231 L .4963 .8223 L F
.49703 .82231 m .49864 .82238 L .49703 .82232 L F
.49703 .82231 m .49703 .82232 L .4963 .8223 L F
.4963 .8223 m .49801 .82235 L .49753 .82306 L F
.49801 .82235 m .49864 .82238 L .49853 .82244 L F
.49801 .82235 m .49853 .82244 L .49753 .82306 L F
.727 .674 .799 r
.49535 .82528 m .49871 .82541 L .49753 .82306 L F
.335 .101 .403 r
.49594 .82444 m .49535 .82528 L .49753 .82306 L F
.473 .121 .287 r
.49744 .82425 m .49685 .82216 L .49812 .82301 L F
.49685 .82216 m .49683 .82209 L .49695 .82218 L F
.364 .732 .989 r
.49636 .82226 m .49657 .82228 L .49628 .82229 L F
.49657 .82228 m .49864 .82238 L .49654 .8223 L F
.49657 .82228 m .49654 .8223 L .49628 .82229 L F
.49624 .82226 m .49864 .82238 L .49753 .82306 L F
.313 0 .18 r
.49667 .82218 m .49317 .82505 L .49416 .82368 L F
.49683 .82209 m .49674 .82217 L .49667 .82218 L F
0 0 0 r
.49621 .82251 m .49652 .82222 L .49675 .82214 L F
0 .242 .738 r
.49709 .82189 m .49688 .82205 L .49567 .82288 L F
.49688 .82205 m .49683 .82209 L .49675 .82214 L F
.49688 .82205 m .49675 .82214 L .49567 .82288 L F
.473 .121 .287 r
.49685 .82216 m .49695 .82218 L .49812 .82301 L F
0 .242 .738 r
.49709 .82189 m .49812 .82301 L .49695 .82218 L F
.49688 .82205 m .49695 .82218 L .49683 .82209 L F
.49709 .82189 m .49695 .82218 L .49688 .82205 L F
.364 .732 .989 r
.49628 .82229 m .49633 .82229 L .4963 .8223 L F
0 0 .359 r
.49545 .82077 m .4963 .8223 L .49647 .8219 L F
.364 .732 .989 r
.49624 .82226 m .49636 .82226 L .49628 .82229 L F
.313 0 .18 r
.49674 .82217 m .49317 .82505 L .49667 .82218 L F
.49611 .8224 m .49416 .82368 L .49463 .82303 L F
.335 .101 .403 r
.49623 .82232 m .49628 .82229 L .49624 .82226 L F
0 0 0 r
.49567 .82288 m .49463 .82303 L .49625 .82234 L F
.49627 .82234 m .49625 .82234 L .49629 .82232 L F
.49567 .82288 m .49625 .82234 L .49627 .82234 L F
.49567 .82288 m .49629 .82232 L .49621 .82251 L F
0 0 .359 r
.49545 .82077 m .49624 .82226 L .4963 .8223 L F
.616 .388 .549 r
.52457 .83115 m .52676 .83133 L .52681 .82881 L F
.737 .489 .554 r
.52681 .82881 m .52676 .83133 L .52981 .83136 L F
.621 .483 .673 r
.40223 .87084 m .40475 .87294 L .4045 .87056 L F
.40223 .87084 m .40244 .87322 L .40475 .87294 L F
.609 .16 .161 r
.69366 .75228 m .69693 .75229 L .69597 .75358 L F
.609 .119 .064 r
.69693 .75229 m .69815 .75396 L .69597 .75358 L F
.69693 .75229 m .69916 .75289 L .69815 .75396 L F
.642 .788 .952 r
.62511 .73817 m .6222 .73893 L .62484 .7374 L F
0 0 0 r
.6222 .73893 m .6236 .73835 L .62484 .7374 L F
.551 .473 .72 r
.6218 .74084 m .6236 .73835 L .6222 .73893 L F
.572 .596 .839 r
.49166 .84386 m .4895 .84434 L .48832 .84293 L F
.532 .515 .782 r
.49308 .84672 m .4895 .84434 L .49166 .84386 L F
.536 .908 .735 r
.70686 .75172 m .70817 .75056 L .707 .75215 L F
.70686 .75172 m .70975 .74981 L .70817 .75056 L F
.532 .302 .511 r
.38592 .78394 m .38533 .78555 L .38384 .7857 L F
.452 .142 .349 r
.38464 .78809 m .38384 .7857 L .38533 .78555 L F
.38464 .78809 m .38265 .78845 L .38384 .7857 L F
.521 0 0 r
.53375 .85597 m .53553 .85738 L .53408 .85615 L F
.826 .564 .542 r
.66579 .73613 m .66241 .73581 L .6623 .73377 L F
.932 .924 .551 r
.66579 .73613 m .66441 .73787 L .66241 .73581 L F
.66579 .73613 m .66445 .73882 L .66441 .73787 L F
.612 .52 .726 r
.43747 .83534 m .44174 .83318 L .43762 .83402 L F
0 .141 .686 r
.56003 .79801 m .56046 .79937 L .55857 .79715 L F
.56003 .79801 m .55857 .79715 L .55745 .79884 L F
.112 .653 .845 r
.47781 .88422 m .47892 .88447 L .48086 .88449 L F
.377 .178 .478 r
.33304 .68146 m .33289 .68346 L .33136 .68372 L F
.453 .354 .653 r
.33338 .68576 m .33136 .68372 L .33289 .68346 L F
.33338 .68576 m .33137 .687 L .33136 .68372 L F
.229 .706 .937 r
.41469 .88888 m .41523 .88843 L .41322 .88841 L F
.447 .833 .608 r
.41469 .88888 m .41473 .8888 L .41523 .88843 L F
.687 .574 .723 r
.64621 .74736 m .64407 .74984 L .64284 .74648 L F
.692 .583 .728 r
.64621 .74736 m .6473 .74993 L .64407 .74984 L F
.693 .564 .704 r
.64407 .74984 m .6473 .74993 L .64736 .7525 L F
.649 .847 .976 r
.41633 .73697 m .41426 .73755 L .41354 .73708 L F
.676 .806 .944 r
.69692 .74403 m .69805 .74514 L .70003 .7443 L F
.703 .427 .503 r
.69747 .74761 m .70003 .7443 L .69805 .74514 L F
.244 .664 .961 r
.37543 .89372 m .37715 .89462 L .37562 .89439 L F
.825 .769 .8 r
.39164 .89079 m .39004 .8919 L .39298 .89159 L F
.796 .71 .769 r
.38929 .893 m .39298 .89159 L .39004 .8919 L F
.38929 .893 m .39084 .89438 L .39298 .89159 L F
.587 .771 .967 r
.39164 .89079 m .39298 .89159 L .39486 .8912 L F
.744 .634 .738 r
.63548 .74915 m .63222 .74703 L .63433 .74642 L F
.63548 .74915 m .63367 .75015 L .63222 .74703 L F
.689 .664 .821 r
.63777 .7471 m .63548 .74915 L .63433 .74642 L F
.702 .592 .73 r
.64961 .75198 m .65274 .7524 L .65059 .75496 L F
.974 .926 .632 r
.66962 .72249 m .67071 .72215 L .67111 .7197 L F
0 0 0 r
.71118 .74683 m .71051 .74838 L .70975 .74981 L F
.71195 .74552 m .71051 .74838 L .71118 .74683 L F
.093 .638 .84 r
.57221 .84687 m .5742 .84695 L .57109 .84661 L F
.737 .521 .6 r
.60668 .78328 m .60511 .78123 L .60665 .7813 L F
.428 .157 .399 r
.3879 .78349 m .38533 .78555 L .38592 .78394 L F
.925 .829 .732 r
.60513 .79491 m .60319 .79603 L .60373 .79405 L F
.69 .341 .379 r
.50223 .82558 m .50066 .8278 L .50443 .82752 L F
.597 .911 .656 r
.51571 .86719 m .51646 .86659 L .5148 .86801 L F
.677 .348 .409 r
.51571 .86719 m .51811 .86727 L .51646 .86659 L F
.751 .616 .049 r
.50761 .86152 m .50764 .86045 L .50758 .85939 L F
.399 0 0 r
.32629 .67851 m .33043 .67799 L .32734 .67886 L F
.077 .351 .823 r
.57521 .82711 m .57408 .82576 L .57494 .82815 L F
.813 .445 .36 r
.57494 .82815 m .57723 .82877 L .57521 .82711 L F
.735 .326 .273 r
.59192 .78679 m .59074 .78827 L .5888 .78626 L F
.564 .12 .156 r
.5941 .78803 m .59192 .78679 L .59393 .78619 L F
.5941 .78803 m .59074 .78827 L .59192 .78679 L F
.764 .689 .779 r
.48777 .84986 m .48798 .85173 L .49033 .84955 L F
.575 .574 .814 r
.48164 .85171 m .48282 .85462 L .48089 .85515 L F
.479 .262 .505 r
.48282 .85462 m .48235 .85722 L .48089 .85515 L F
.63 .47 .648 r
.40925 .86554 m .41126 .86299 L .40872 .86292 L F
.777 .767 .844 r
.36395 .74942 m .36752 .74903 L .36608 .74836 L F
.241 .665 .96 r
.36752 .74903 m .36806 .74841 L .36608 .74836 L F
.019 0 .023 r
.47724 .82622 m .47784 .8272 L .47937 .82611 L F
.47724 .82622 m .47632 .8283 L .47784 .8272 L F
.681 .264 .247 r
.39186 .88682 m .3904 .88832 L .39381 .88804 L F
.582 .395 .593 r
.39186 .88682 m .39381 .88804 L .39436 .88633 L F
.66 .509 .668 r
.41126 .86299 m .41397 .8629 L .41341 .8601 L F
.685 .545 .689 r
.41341 .8601 m .41617 .86019 L .41615 .85792 L F
.661 .51 .668 r
.41341 .8601 m .41616 .86247 L .41617 .86019 L F
.41341 .8601 m .41397 .8629 L .41616 .86247 L F
.748 .989 .782 r
.70975 .74981 m .71051 .74838 L .70817 .75056 L F
.598 .637 .861 r
.52815 .85915 m .52923 .85664 L .5277 .85675 L F
.52815 .85915 m .53035 .85917 L .52923 .85664 L F
0 0 .172 r
.5649 .84191 m .56535 .84438 L .56483 .84119 L F
.625 .486 .673 r
.63015 .74746 m .63013 .74965 L .62783 .74992 L F
.441 .477 .801 r
.52341 .83729 m .52481 .83555 L .52272 .83562 L F
.52341 .83729 m .52592 .83878 L .52481 .83555 L F
.563 .449 .681 r
.52341 .83729 m .52381 .83934 L .52592 .83878 L F
.537 .455 .71 r
.41917 .73812 m .41969 .74157 L .41776 .74195 L F
.516 .371 .622 r
.41969 .74157 m .41982 .74388 L .41776 .74195 L F
.521 .371 .617 r
.41982 .74388 m .41787 .74425 L .41776 .74195 L F
.704 .526 .645 r
.40657 .86793 m .40986 .86814 L .40925 .86554 L F
.63 .47 .648 r
.40925 .86554 m .41197 .86574 L .41126 .86299 L F
.699 .523 .646 r
.40925 .86554 m .41188 .86768 L .41197 .86574 L F
.40925 .86554 m .40986 .86814 L .41188 .86768 L F
.379 0 .083 r
.48878 .83882 m .48684 .84085 L .4847 .84113 L F
.44 .015 .133 r
.48987 .83957 m .48684 .84085 L .48878 .83882 L F
.961 .688 .472 r
.56302 .81198 m .56453 .81318 L .56413 .81026 L F
.646 .324 .412 r
.56413 .81026 m .56618 .8121 L .56654 .81055 L F
.476 .348 .627 r
.56413 .81026 m .56453 .81318 L .56618 .8121 L F
0 0 0 r
.56505 .80928 m .56302 .81198 L .56413 .81026 L F
.635 .419 .572 r
.38592 .88717 m .38805 .89074 L .38819 .8888 L F
.38592 .88717 m .38633 .89162 L .38805 .89074 L F
.694 .31 .316 r
.64466 .72193 m .64625 .72078 L .64499 .72018 L F
.425 .312 .621 r
.64625 .72078 m .64807 .72272 L .64649 .72341 L F
.694 .31 .316 r
.64466 .72193 m .64807 .72272 L .64625 .72078 L F
.608 .585 .802 r
.52379 .87633 m .52505 .87373 L .52282 .87362 L F
.52379 .87633 m .52582 .8756 L .52505 .87373 L F
.538 .379 .614 r
.52379 .87633 m .52353 .87792 L .52582 .8756 L F
0 0 .52 r
.67115 .72558 m .67211 .72834 L .67115 .72635 L F
.074 0 .345 r
.61138 .82354 m .61271 .82063 L .61221 .82245 L F
0 0 .303 r
.61111 .8258 m .61138 .82354 L .61221 .82245 L F
.559 0 0 r
.53928 .81027 m .54158 .81191 L .54287 .8124 L F
.673 .125 0 r
.54158 .81191 m .54284 .81291 L .54287 .8124 L F
.617 .268 .356 r
.46089 .85958 m .459 .86202 L .45711 .86014 L F
.444 .029 .155 r
.46256 .85981 m .459 .86202 L .46089 .85958 L F
.609 .922 .973 r
.47428 .87024 m .47356 .87133 L .47221 .87054 L F
.47428 .87024 m .47552 .8705 L .47356 .87133 L F
.752 .722 .824 r
.48288 .82613 m .48587 .82685 L .48457 .82566 L F
.706 .769 .901 r
.48457 .82566 m .48587 .82685 L .48785 .82594 L F
.699 .513 .632 r
.41126 .86299 m .41396 .86519 L .41397 .8629 L F
.41126 .86299 m .41197 .86574 L .41396 .86519 L F
.828 .487 .411 r
.33383 .69237 m .33053 .6916 L .33384 .691 L F
.33383 .69237 m .33069 .69358 L .33053 .6916 L F
.4 .092 .324 r
.33211 .69458 m .33069 .69358 L .33383 .69237 L F
0 0 0 r
.33529 .69042 m .33383 .69237 L .33384 .691 L F
.33529 .69042 m .33446 .69223 L .33383 .69237 L F
.33446 .69223 m .33211 .69458 L .33383 .69237 L F
.651 .471 .627 r
.43316 .84094 m .43442 .83915 L .43313 .83935 L F
.981 .721 .325 r
.67186 .71283 m .67088 .70966 L .67376 .71026 L F
.67186 .71283 m .67118 .7123 L .67088 .70966 L F
.982 .904 .583 r
.67097 .71533 m .67118 .7123 L .67186 .71283 L F
.982 .828 .614 r
.56102 .78185 m .55939 .78299 L .55953 .78124 L F
.817 .987 .721 r
.56151 .78033 m .56102 .78185 L .56254 .78065 L F
.56151 .78033 m .55939 .78299 L .56102 .78185 L F
.659 .77 .932 r
.33372 .67538 m .33496 .67637 L .33212 .67614 L F
.582 .749 .957 r
.33607 .67601 m .33496 .67637 L .33372 .67538 L F
.33618 .67604 m .33606 .67607 L .33607 .67601 L F
.33606 .67607 m .33496 .67637 L .33607 .67601 L F
.925 .934 .572 r
.33602 .67626 m .33607 .67601 L .33372 .67538 L F
.33607 .67601 m .33624 .67512 L .33372 .67538 L F
.582 .749 .957 r
.3368 .67587 m .33618 .67604 L .33372 .67538 L F
.497 .443 .727 r
.33731 .6783 m .33574 .67701 L .3368 .67587 L F
.33574 .67701 m .33496 .67637 L .33575 .67615 L F
.33731 .6783 m .33572 .6789 L .33545 .678 L F
.33574 .67701 m .33545 .678 L .33496 .67637 L F
.33731 .6783 m .33545 .678 L .33574 .67701 L F
.691 .449 .552 r
.33212 .67614 m .33129 .67814 L .3359 .67631 L F
.33212 .67614 m .3359 .67631 L .33585 .67625 L F
.33212 .67614 m .33602 .67626 L .33372 .67538 L F
.087 0 0 r
.33067 .67878 m .33602 .67626 L .33129 .67814 L F
.3307 .67877 m .33215 .67851 L .33602 .67626 L F
.33067 .67878 m .33215 .67851 L .3307 .67877 L F
.555 .271 .439 r
.33215 .67851 m .33464 .67717 L .33602 .67626 L F
.33215 .67851 m .33414 .67889 L .33464 .67717 L F
.452 .557 .871 r
.33305 .6768 m .33379 .67822 L .33215 .67851 L F
.33379 .67822 m .33414 .67889 L .33215 .67851 L F
.582 .749 .957 r
.3368 .67587 m .33608 .67575 L .33624 .67512 L F
.33608 .67575 m .33372 .67538 L .33624 .67512 L F
.925 .934 .572 r
.33605 .67586 m .33464 .67717 L .3361 .6753 L F
.33604 .67599 m .33601 .67602 L .33605 .67586 L F
.33601 .67602 m .33464 .67717 L .33605 .67586 L F
.691 .449 .552 r
.33585 .67625 m .3359 .67631 L .33602 .67626 L F
.497 .443 .727 r
.33596 .67637 m .33575 .67615 L .33606 .67607 L F
.925 .934 .572 r
.33602 .67619 m .33597 .67622 L .33604 .67599 L F
.33597 .67622 m .33464 .67717 L .33604 .67599 L F
.497 .443 .727 r
.33574 .67701 m .33575 .67615 L .33596 .67637 L F
.925 .934 .572 r
.33602 .67626 m .33599 .67627 L .33602 .67619 L F
.497 .443 .727 r
.33574 .67701 m .33606 .67607 L .3368 .67587 L F
.925 .934 .572 r
.33599 .67627 m .33464 .67717 L .33602 .67619 L F
.33607 .67601 m .3361 .6753 L .33624 .67512 L F
.33602 .67626 m .3361 .6753 L .33607 .67601 L F
.65 .133 0 r
.47546 .86321 m .4771 .86366 L .4762 .8639 L F
0 .57 .709 r
.4771 .86366 m .47854 .86368 L .4762 .8639 L F
.145 0 0 r
.48093 .86817 m .47738 .86973 L .47966 .86978 L F
0 0 0 r
.48202 .86765 m .48093 .86817 L .47966 .86978 L F
.745 .829 .916 r
.6631 .75157 m .66028 .75166 L .66239 .75105 L F
.727 .829 .928 r
.66468 .74902 m .6631 .75157 L .66239 .75105 L F
.66468 .74902 m .66583 .7501 L .6631 .75157 L F
0 .335 .797 r
.67721 .71742 m .68059 .71996 L .678 .71935 L F
.397 .318 .649 r
.70346 .74686 m .70529 .74652 L .70405 .74427 L F
.452 .342 .639 r
.70348 .74927 m .70529 .74652 L .70346 .74686 L F
.778 .83 .893 r
.47449 .85147 m .47121 .85286 L .47294 .85307 L F
.458 0 0 r
.46721 .88195 m .47006 .88222 L .46888 .8819 L F
.212 0 0 r
.46888 .8819 m .47006 .88222 L .47255 .88295 L F
.763 .673 .763 r
.64284 .74648 m .64098 .74747 L .64314 .74484 L F
.69 .566 .71 r
.64534 .74389 m .64284 .74648 L .64314 .74484 L F
.64534 .74389 m .64621 .74736 L .64284 .74648 L F
.567 .273 .429 r
.45674 .83623 m .45898 .83626 L .45987 .83365 L F
.624 .331 .452 r
.45987 .83365 m .46186 .8354 L .46216 .8338 L F
.45987 .83365 m .45898 .83626 L .46186 .8354 L F
.569 .783 .979 r
.39272 .74507 m .39392 .74591 L .39599 .74563 L F
.425 0 0 r
.43135 .88829 m .42974 .88714 L .43145 .88835 L F
.42808 .88603 m .42974 .88714 L .43135 .88829 L F
.587 .159 .195 r
.42727 .88663 m .42896 .88659 L .42974 .88714 L F
.42896 .88659 m .43063 .88655 L .42974 .88714 L F
.669 .211 .155 r
.43063 .88655 m .43145 .88835 L .42974 .88714 L F
.43063 .88655 m .43299 .88717 L .43145 .88835 L F
.704 .56 .689 r
.41615 .85792 m .41617 .86019 L .41833 .85755 L F
.63 .455 .627 r
.41833 .85755 m .41617 .86019 L .41831 .85987 L F
.601 .424 .615 r
.41831 .85987 m .4204 .8573 L .41833 .85755 L F
.755 .585 .666 r
.48708 .84697 m .48777 .84986 L .49033 .84955 L F
.407 .009 .17 r
.64546 .70705 m .64712 .7077 L .64832 .70629 L F
.364 .112 .393 r
.38108 .77369 m .38223 .77505 L .3827 .77305 L F
.38108 .77369 m .38048 .77566 L .38223 .77505 L F
.699 .239 .157 r
.68245 .73936 m .68195 .74076 L .67959 .73893 L F
.905 .507 .238 r
.68245 .73936 m .68332 .74147 L .68195 .74076 L F
.456 .231 .483 r
.62934 .73158 m .62897 .73381 L .63097 .73311 L F
.966 .899 .705 r
.62565 .7896 m .62689 .78637 L .62613 .78577 L F
.88 .827 .791 r
.39681 .87798 m .40035 .87592 L .39691 .87558 L F
.39681 .87798 m .39809 .87848 L .40035 .87592 L F
.734 .564 .662 r
.39809 .87848 m .40113 .87851 L .40035 .87592 L F
.623 .481 .668 r
.40113 .87851 m .40269 .8755 L .40035 .87592 L F
.855 .59 .537 r
.69053 .74984 m .68788 .75123 L .68738 .74916 L F
.69053 .74984 m .69047 .752 L .68788 .75123 L F
.441 .109 .305 r
.48512 .87499 m .48749 .87363 L .48735 .87535 L F
.928 .728 .613 r
.48342 .85242 m .48282 .85462 L .48164 .85171 L F
.743 .634 .739 r
.63222 .74703 m .63367 .75015 L .63013 .74965 L F
.623 .556 .759 r
.52661 .81518 m .52755 .8183 L .52975 .81788 L F
.575 .495 .727 r
.52755 .8183 m .53057 .82031 L .52975 .81788 L F
.639 .196 .183 r
.5706 .81575 m .56969 .81726 L .56872 .81573 L F
0 0 .298 r
.57129 .81237 m .5706 .81575 L .57297 .81271 L F
.57129 .81237 m .57116 .81564 L .5706 .81575 L F
.484 .589 .883 r
.57152 .8327 m .57199 .83389 L .5705 .83133 L F
.995 .783 .504 r
.57152 .8327 m .57199 .83389 L .57152 .8327 L F
.269 .339 .751 r
.57247 .83274 m .57318 .83104 L .5716 .83292 L F
.372 .368 .726 r
.57348 .83255 m .57394 .83605 L .57199 .83389 L F
.269 .339 .751 r
.57311 .833 m .57394 .83605 L .57344 .83274 L F
.57199 .83389 m .57284 .83484 L .57311 .833 L F
.57284 .83484 m .57394 .83605 L .57311 .833 L F
.57199 .83389 m .5734 .83246 L .57247 .83274 L F
.57199 .83389 m .57247 .83274 L .5716 .83292 L F
.57199 .83389 m .57152 .8327 L .5705 .83133 L F
.496 .097 .214 r
.56871 .8321 m .56967 .83256 L .56847 .83184 L F
.975 .744 .526 r
.57089 .83565 m .57137 .83339 L .56967 .83256 L F
.57137 .83339 m .57152 .8327 L .56967 .83256 L F
.269 .339 .751 r
.5716 .83292 m .57318 .83104 L .57095 .83128 L F
.912 .934 .812 r
.5719 .83241 m .57089 .83565 L .56967 .83256 L F
.496 .097 .214 r
.5708 .83433 m .56967 .83256 L .56871 .8321 L F
.949 .629 .39 r
.57152 .8327 m .57152 .8327 L .5705 .83133 L F
.269 .339 .751 r
.57152 .8327 m .57095 .83128 L .5705 .83133 L F
.949 .629 .39 r
.56967 .83256 m .57152 .8327 L .5705 .83133 L F
.995 .783 .504 r
.57089 .83565 m .57199 .83389 L .57152 .8327 L F
.912 .934 .812 r
.5719 .83241 m .57318 .83253 L .57089 .83565 L F
.57318 .83253 m .57348 .83255 L .57311 .833 L F
.372 .368 .726 r
.57311 .833 m .57199 .83389 L .57089 .83565 L F
.57348 .83255 m .57199 .83389 L .57311 .833 L F
.269 .339 .751 r
.57199 .83389 m .57344 .83274 L .5734 .83246 L F
.912 .934 .812 r
.57318 .83253 m .57311 .833 L .57089 .83565 L F
.269 .339 .751 r
.57247 .83274 m .5734 .83246 L .57318 .83104 L F
.494 .46 .749 r
.5753 .83305 m .57394 .83605 L .57348 .83255 L F
.132 .556 .923 r
.57374 .83241 m .5753 .83305 L .57348 .83255 L F
.613 .599 .813 r
.57451 .8323 m .57445 .8327 L .5753 .83305 L F
.132 .556 .923 r
.5734 .83246 m .57355 .83252 L .57327 .8325 L F
.57374 .83241 m .57355 .83252 L .5734 .83246 L F
.57355 .83252 m .57348 .83255 L .5734 .83255 L F
.613 .599 .813 r
.5734 .83246 m .57394 .83605 L .57451 .8323 L F
.132 .556 .923 r
.57428 .8321 m .5753 .83305 L .57374 .83241 L F
.613 .599 .813 r
.57445 .8327 m .57394 .83605 L .5753 .83305 L F
.57318 .83104 m .5734 .83246 L .57451 .8323 L F
.132 .556 .923 r
.57393 .8323 m .57374 .83241 L .5734 .83246 L F
.57428 .8321 m .57393 .8323 L .5719 .83241 L F
.57393 .8323 m .57327 .8325 L .5719 .83241 L F
.57355 .83252 m .5734 .83255 L .5719 .83241 L F
.597 .041 0 r
.52099 .85169 m .52079 .8521 L .52047 .85102 L F
.52099 .85169 m .52286 .85346 L .52079 .8521 L F
.935 .93 .774 r
.5921 .82591 m .59295 .82651 L .59096 .82755 L F
.633 .539 .73 r
.64845 .74664 m .6473 .74993 L .64621 .74736 L F
.64845 .74664 m .64936 .74977 L .6473 .74993 L F
.631 .514 .702 r
.6473 .74993 m .64936 .74977 L .64736 .7525 L F
.6 .444 .642 r
.45655 .82061 m .45703 .82368 L .45415 .82281 L F
.605 .435 .625 r
.45443 .82382 m .45703 .82368 L .45415 .82281 L F
.6 .444 .642 r
.45655 .82061 m .45415 .82281 L .45443 .82382 L F
.78 .754 .829 r
.67239 .70818 m .67376 .71026 L .67088 .70966 L F
.332 .542 .907 r
.67239 .70818 m .67489 .70922 L .67376 .71026 L F
.199 .316 .76 r
.67489 .70922 m .67577 .71241 L .67376 .71026 L F
.351 .814 .718 r
.52705 .85449 m .52923 .85352 L .52848 .85375 L F
.209 .309 .748 r
.52705 .85449 m .52923 .85664 L .52848 .85375 L F
.413 .351 .679 r
.52705 .85449 m .5277 .85675 L .52923 .85664 L F
.727 .848 .938 r
.64208 .76991 m .64537 .76978 L .64475 .76814 L F
.862 .879 .849 r
.64475 .76814 m .64537 .76978 L .6471 .76761 L F
.521 .353 .594 r
.39156 .93845 m .38954 .93847 L .38894 .93967 L F
.39156 .93845 m .38954 .93847 L .38894 .93967 L F
.884 .543 .396 r
.68699 .74722 m .68599 .749 L .68428 .74646 L F
.68699 .74722 m .68738 .74916 L .68599 .749 L F
0 0 0 r
.43145 .88835 m .43299 .88717 L .43493 .88642 L F
.589 .4 .594 r
.42682 .84693 m .42895 .84675 L .42892 .84439 L F
.607 .454 .648 r
.42892 .84439 m .43058 .84453 L .43106 .84159 L F
.588 .4 .593 r
.42892 .84439 m .43002 .84652 L .43058 .84453 L F
.42892 .84439 m .42895 .84675 L .43002 .84652 L F
.277 .368 .777 r
.67959 .73893 m .68195 .74076 L .68053 .74195 L F
.67 .196 .118 r
.68042 .74365 m .68324 .74372 L .68053 .74195 L F
.68042 .74365 m .68053 .74195 L .68195 .74076 L F
.972 .732 .516 r
.67202 .73068 m .67318 .73137 L .67211 .72834 L F
.994 .747 .413 r
.67241 .73252 m .67318 .73137 L .67202 .73068 L F
.67241 .73252 m .67323 .73339 L .67318 .73137 L F
.325 .242 .606 r
.52903 .82566 m .5297 .82285 L .52842 .82365 L F
.65 .314 .391 r
.47843 .84455 m .47746 .84649 L .47496 .84639 L F
.662 .364 .458 r
.48102 .84499 m .47746 .84649 L .47843 .84455 L F
.931 .73 .61 r
.676 .72313 m .67713 .72611 L .67569 .72564 L F
.897 .52 .31 r
.67713 .72611 m .67645 .7276 L .67569 .72564 L F
.986 .71 .367 r
.67713 .72611 m .67731 .72835 L .67645 .7276 L F
.46 .161 .37 r
.46448 .83359 m .46645 .8333 L .46727 .83072 L F
.431 .102 .306 r
.46645 .8333 m .46937 .83057 L .46727 .83072 L F
.559 .269 .432 r
.48405 .876 m .48739 .87483 L .48512 .87499 L F
.71 .625 .761 r
.64936 .74977 m .64961 .75198 L .64736 .7525 L F
.831 .679 .138 r
.57367 .81977 m .57381 .82068 L .57388 .81809 L F
0 0 .511 r
.67499 .71852 m .67558 .72103 L .67562 .72006 L F
.827 .618 .066 r
.676 .72313 m .67562 .72006 L .67558 .72103 L F
.608 .412 .591 r
.33572 .6789 m .33571 .68124 L .33304 .68146 L F
.417 .259 .559 r
.33727 .68056 m .33572 .6789 L .33731 .6783 L F
.33727 .68056 m .33571 .68124 L .33572 .6789 L F
.712 .501 .602 r
.60511 .78123 m .60519 .78391 L .60144 .78355 L F
.737 .521 .6 r
.60668 .78328 m .60519 .78391 L .60511 .78123 L F
.672 .533 .687 r
.4037 .86751 m .4045 .87056 L .40657 .86793 L F
.726 .785 .899 r
.64975 .76538 m .6529 .76561 L .65188 .76443 L F
.651 .754 .925 r
.6529 .76561 m .65343 .76384 L .65188 .76443 L F
.6529 .76561 m .655 .76496 L .65343 .76384 L F
0 0 .101 r
.60644 .83557 m .60513 .83623 L .60685 .83352 L F
.046 0 .417 r
.60503 .8387 m .60513 .83623 L .60644 .83557 L F
.731 .665 .784 r
.50354 .85808 m .50145 .8578 L .50222 .85708 L F
.755 .813 .899 r
.50222 .85708 m .5057 .8571 L .50354 .85808 L F
.638 .493 .669 r
.43442 .83915 m .43747 .83534 L .4356 .83602 L F
.301 0 0 r
.36521 .75241 m .36331 .75317 L .36182 .75266 L F
.532 .122 .209 r
.36665 .75119 m .36331 .75317 L .36521 .75241 L F
.636 .222 .242 r
.57766 .77303 m .58013 .77466 L .58099 .77292 L F
.744 .388 .377 r
.58013 .77466 m .58301 .77348 L .58099 .77292 L F
.574 .382 .584 r
.39325 .8813 m .39467 .88303 L .39606 .88121 L F
.65 .544 .721 r
.39569 .87881 m .39606 .88121 L .39809 .87848 L F
.71 .427 .494 r
.39467 .88303 m .39627 .8833 L .39606 .88121 L F
.62 .502 .697 r
.39809 .87848 m .39606 .88121 L .39833 .88086 L F
.752 .577 .658 r
.39627 .8833 m .39833 .88086 L .39606 .88121 L F
.207 0 0 r
.48723 .88364 m .49003 .88315 L .48868 .88367 L F
.323 0 0 r
.48868 .88367 m .49003 .88315 L .49181 .88322 L F
.37 .778 .982 r
.39272 .74507 m .38991 .74476 L .39086 .74476 L F
.706 .582 .713 r
.4225 .85002 m .42255 .85221 L .42468 .84957 L F
.623 .464 .645 r
.42468 .84957 m .42255 .85221 L .42471 .8517 L F
.643 .507 .681 r
.42216 .85501 m .42471 .8517 L .42255 .85221 L F
.575 .94 .897 r
.49889 .85667 m .49705 .85758 L .49835 .85731 L F
.88 .497 .308 r
.49835 .85731 m .49968 .86017 L .49889 .85667 L F
.47 .205 .43 r
.39772 .77598 m .39729 .77793 L .39526 .77832 L F
.498 .23 .439 r
.39939 .77752 m .39772 .77598 L .39978 .77563 L F
.39939 .77752 m .39729 .77793 L .39772 .77598 L F
.66 .737 .907 r
.40033 .74407 m .40199 .74659 L .40374 .74459 L F
.671 .661 .831 r
.40199 .74659 m .40502 .74704 L .40374 .74459 L F
.827 .982 .697 r
.57389 .8251 m .57408 .82576 L .57555 .82368 L F
.766 .416 0 r
.57454 .82757 m .57408 .82576 L .57389 .8251 L F
.57454 .82757 m .57494 .82815 L .57408 .82576 L F
.086 0 .238 r
.60685 .83352 m .60917 .83117 L .60822 .83237 L F
0 0 .067 r
.60644 .83557 m .60685 .83352 L .60822 .83237 L F
.989 .733 .367 r
.56407 .83309 m .56339 .83578 L .56341 .83251 L F
.56407 .83309 m .56414 .83568 L .56339 .83578 L F
.765 .707 .798 r
.6492 .74034 m .65043 .74186 L .64725 .74157 L F
.575 .35 .537 r
.65043 .74186 m .6479 .74481 L .64725 .74157 L F
.65043 .74186 m .65083 .74472 L .6479 .74481 L F
.442 .489 .813 r
.65192 .7411 m .65043 .74186 L .6492 .74034 L F
.65192 .7411 m .65193 .74231 L .65043 .74186 L F
.601 .389 .566 r
.65193 .74231 m .65083 .74472 L .65043 .74186 L F
.624 .807 .97 r
.58315 .83352 m .5797 .83331 L .58165 .83321 L F
.613 .319 .447 r
.38423 .7724 m .38676 .77047 L .38556 .77017 L F
.634 .639 .837 r
.40502 .74704 m .40576 .74365 L .40374 .74459 L F
.40502 .74704 m .40726 .74687 L .40576 .74365 L F
.661 .542 .709 r
.40502 .74704 m .40816 .74973 L .40726 .74687 L F
.40502 .74704 m .40599 .75078 L .40816 .74973 L F
.548 .376 .599 r
.43032 .75183 m .42831 .75415 L .42846 .7524 L F
.316 0 .133 r
.659 .72257 m .66097 .72215 L .66164 .72014 L F
0 0 0 r
.66164 .72014 m .66181 .71972 L .66217 .71733 L F
.66164 .72014 m .66097 .72215 L .66181 .71972 L F
0 0 .341 r
.49077 .87226 m .49 .8706 L .49044 .86981 L F
.49077 .87226 m .49047 .87329 L .49 .8706 L F
.424 .401 .729 r
.4854 .86972 m .48407 .87055 L .48354 .86768 L F
.449 .19 .429 r
.37859 .7761 m .37809 .77799 L .38048 .77566 L F
.577 .578 .817 r
.38139 .89118 m .38211 .89254 L .38414 .89217 L F
.684 .643 .803 r
.65165 .74945 m .64961 .75198 L .64936 .74977 L F
.65165 .74945 m .65274 .7524 L .64961 .75198 L F
.719 .943 .956 r
.42387 .88755 m .42727 .88663 L .42604 .88652 L F
.24 .644 .96 r
.42727 .88663 m .42808 .88603 L .42604 .88652 L F
.42727 .88663 m .42974 .88714 L .42808 .88603 L F
.509 .404 .67 r
.33338 .68576 m .33164 .68877 L .33137 .687 L F
.375 .054 .288 r
.36646 .78361 m .36738 .78547 L .36835 .78304 L F
.36646 .78361 m .36553 .78602 L .36738 .78547 L F
.69 .664 .819 r
.40154 .73294 m .39831 .73085 L .4 .73096 L F
.607 .743 .941 r
.40379 .73181 m .40154 .73294 L .4 .73096 L F
.705 .763 .897 r
.34382 .75499 m .34587 .75415 L .34365 .75485 L F
.535 .915 .938 r
.35953 .7264 m .36015 .72553 L .36146 .72573 L F
.35953 .7264 m .35826 .7263 L .36015 .72553 L F
.588 .529 .756 r
.49545 .83876 m .49876 .84134 L .49871 .8393 L F
.703 .669 .814 r
.53858 .83577 m .54296 .8385 L .54067 .83344 L F
.815 .359 .147 r
.54184 .83856 m .54296 .8385 L .54206 .83794 L F
.54184 .83856 m .54206 .83794 L .53901 .83604 L F
0 0 0 r
.54184 .83856 m .54036 .84132 L .54118 .8404 L F
.347 .467 .84 r
.54067 .83344 m .54296 .8385 L .54309 .8352 L F
.919 .941 .8 r
.54309 .8352 m .54296 .8385 L .54184 .83856 L F
.54309 .8352 m .54184 .83856 L .54396 .83824 L F
0 0 0 r
.54184 .83856 m .54308 .83826 L .54396 .83824 L F
.54184 .83856 m .54118 .8404 L .54308 .83826 L F
.815 .359 .147 r
.54184 .83856 m .53901 .83604 L .53899 .83613 L F
.467 .09 .24 r
.54309 .8352 m .54213 .83587 L .54085 .83559 L F
.815 .359 .147 r
.54184 .83856 m .53916 .83627 L .53993 .83846 L F
.467 .09 .24 r
.54213 .83587 m .53983 .83747 L .54059 .83608 L F
.54213 .83587 m .54059 .83608 L .54085 .83559 L F
.815 .359 .147 r
.53916 .83627 m .53899 .83613 L .53906 .83628 L F
.53916 .83627 m .53906 .83628 L .53993 .83846 L F
.53899 .83613 m .53858 .83577 L .53876 .83613 L F
.53899 .83613 m .53876 .83613 L .53993 .83846 L F
.358 0 .077 r
.54034 .83608 m .53983 .83747 L .53877 .83761 L F
.54085 .83559 m .54059 .83608 L .54034 .83608 L F
.54059 .83608 m .53983 .83747 L .54034 .83608 L F
.53887 .83697 m .53877 .83761 L .53776 .83774 L F
.54085 .83559 m .53877 .83761 L .53887 .83697 L F
.815 .359 .147 r
.53899 .83613 m .53901 .83604 L .53858 .83577 L F
.681 .625 .786 r
.65375 .7489 m .65274 .7524 L .65165 .74945 L F
.65375 .7489 m .65456 .75129 L .65274 .7524 L F
.644 .143 .043 r
.5362 .8098 m .53843 .8112 L .53928 .81027 L F
.748 .335 .267 r
.53843 .8112 m .54158 .81191 L .53928 .81027 L F
.837 .878 .873 r
.49065 .87358 m .49099 .87591 L .48904 .87568 L F
.644 .848 .978 r
.38586 .72635 m .38465 .72719 L .38312 .72632 L F
.65 .544 .721 r
.39569 .87881 m .39809 .87848 L .39681 .87798 L F
.633 .465 .637 r
.41617 .86019 m .41819 .86181 L .41831 .85987 L F
.41617 .86019 m .41616 .86247 L .41819 .86181 L F
.605 .435 .625 r
.42682 .84693 m .42468 .84957 L .42696 .84917 L F
.609 .452 .643 r
.42471 .8517 m .42696 .84917 L .42468 .84957 L F
.813 .429 0 r
.51896 .87839 m .51759 .87568 L .51723 .87834 L F
.866 .584 .509 r
.51752 .88064 m .51896 .87839 L .51723 .87834 L F
.512 .412 .678 r
.61663 .74954 m .61862 .74905 L .61815 .74682 L F
.461 .25 .505 r
.61663 .74954 m .61835 .75138 L .61862 .74905 L F
.61663 .74954 m .61644 .75184 L .61835 .75138 L F
.904 .941 .822 r
.66275 .73155 m .66179 .73136 L .66315 .72946 L F
.822 .754 .788 r
.6623 .73377 m .66179 .73136 L .66275 .73155 L F
.813 .66 .693 r
.60668 .78328 m .6078 .78643 L .60489 .78612 L F
.839 .625 .614 r
.60758 .78878 m .60489 .78612 L .6078 .78643 L F
.729 .609 .724 r
.64534 .74389 m .64314 .74484 L .64498 .74216 L F
.632 .55 .744 r
.64725 .74157 m .64534 .74389 L .64498 .74216 L F
.64725 .74157 m .6479 .74481 L .64534 .74389 L F
.653 .55 .726 r
.6479 .74481 m .64621 .74736 L .64534 .74389 L F
.651 .162 .077 r
.66905 .75934 m .66938 .75803 L .6721 .75977 L F
.697 .199 .056 r
.66938 .75803 m .67328 .75989 L .6721 .75977 L F
.463 .196 .423 r
.39238 .76783 m .39438 .7674 L .39474 .76455 L F
.377 .139 .421 r
.39474 .76455 m .39661 .76486 L .39712 .76214 L F
.385 .131 .401 r
.39474 .76455 m .39614 .76682 L .39661 .76486 L F
.39474 .76455 m .39438 .7674 L .39614 .76682 L F
.688 .587 .737 r
.40269 .8755 m .40475 .87294 L .40244 .87322 L F
.386 .838 .747 r
.35388 .72705 m .35454 .72654 L .35598 .72679 L F
.35388 .72705 m .35244 .72751 L .35454 .72654 L F
.485 .187 .384 r
.42177 .76067 m .42119 .7624 L .41913 .76271 L F
.453 .156 .37 r
.4232 .76196 m .42177 .76067 L .42368 .7602 L F
.4232 .76196 m .42119 .7624 L .42177 .76067 L F
.705 .559 .686 r
.58852 .7733 m .59144 .77336 L .59118 .77034 L F
.494 .396 .673 r
.59118 .77034 m .59306 .76988 L .59255 .76795 L F
.571 .458 .686 r
.59118 .77034 m .59357 .77288 L .59306 .76988 L F
.59118 .77034 m .59144 .77336 L .59357 .77288 L F
.411 .546 .881 r
.69242 .72752 m .6909 .72917 L .69059 .7274 L F
.653 .55 .726 r
.6479 .74481 m .64845 .74664 L .64621 .74736 L F
.231 .741 .881 r
.50434 .85695 m .5057 .8571 L .50222 .85708 L F
.937 .846 .727 r
.50561 .85523 m .5057 .8571 L .50434 .85695 L F
.302 .35 .746 r
.50728 .85717 m .5057 .8571 L .50561 .85523 L F
0 .126 .675 r
.50758 .85939 m .5057 .8571 L .50728 .85717 L F
.563 .403 .623 r
.42682 .84693 m .42888 .84863 L .42895 .84675 L F
.42682 .84693 m .42696 .84917 L .42888 .84863 L F
.543 .3 .497 r
.40963 .76819 m .41143 .76994 L .40933 .77024 L F
.554 .299 .484 r
.4118 .76796 m .41143 .76994 L .40963 .76819 L F
.528 .877 .987 r
.5314 .85011 m .5335 .84932 L .5306 .85103 L F
.758 .659 .752 r
.63987 .74447 m .64098 .74747 L .63777 .7471 L F
.753 .656 .754 r
.64314 .74484 m .64098 .74747 L .63987 .74447 L F
.499 .278 .51 r
.459 .86202 m .45683 .86245 L .45711 .86014 L F
.41 .204 .487 r
.3347 .68275 m .33304 .68146 L .33571 .68124 L F
.3347 .68275 m .33289 .68346 L .33304 .68146 L F
.607 .218 .281 r
.58301 .77348 m .58522 .775 L .58625 .77313 L F
.807 .454 .389 r
.58522 .775 m .58856 .77601 L .58625 .77313 L F
.684 .464 .582 r
.58625 .77313 m .58856 .77601 L .58852 .7733 L F
.7 .337 .356 r
.69588 .74116 m .6993 .74189 L .69603 .74002 L F
.492 .598 .887 r
.69974 .74182 m .69603 .74002 L .6993 .74189 L F
.28 0 0 r
.56474 .77595 m .56571 .77699 L .56704 .77625 L F
.56474 .77595 m .56342 .7775 L .56571 .77699 L F
.358 .522 .883 r
.57494 .82815 m .57833 .83053 L .57723 .82877 L F
.474 .141 .321 r
.35167 .79209 m .35383 .79154 L .35181 .79178 L F
.939 .843 .723 r
.47996 .87675 m .48194 .87542 L .48108 .87333 L F
.128 .56 .922 r
.48194 .87542 m .48262 .87488 L .48108 .87333 L F
.48194 .87542 m .48405 .876 L .48262 .87488 L F
.305 .683 .976 r
.45887 .86463 m .45825 .8655 L .457 .86484 L F
.45887 .86463 m .46042 .86572 L .45825 .8655 L F
.505 .332 .58 r
.52245 .82111 m .52382 .8184 L .52279 .81823 L F
0 .143 .664 r
.56546 .80141 m .56492 .80254 L .56396 .79941 L F
.921 .618 .453 r
.56546 .80141 m .56795 .80439 L .56492 .80254 L F
.725 .203 0 r
.48694 .84173 m .48818 .84324 L .48832 .84293 L F
.543 .509 .768 r
.48832 .84293 m .49139 .84319 L .48987 .83957 L F
.442 0 0 r
.48818 .84324 m .49166 .84386 L .48832 .84293 L F
.573 .343 .528 r
.37642 .79168 m .37619 .79365 L .37455 .79379 L F
.501 .272 .5 r
.37848 .79125 m .37619 .79365 L .37642 .79168 L F
.741 .868 .94 r
.69238 .71038 m .69333 .71116 L .69526 .71009 L F
.614 .551 .76 r
.68091 .71325 m .68224 .71489 L .68024 .7156 L F
.68091 .71325 m .68224 .71489 L .68024 .7156 L F
.56 .389 .606 r
.61425 .75445 m .61644 .75184 L .61458 .75253 L F
.683 .426 .527 r
.50197 .8418 m .50397 .84415 L .5055 .8411 L F
.662 .419 .542 r
.50397 .84415 m .50742 .84146 L .5055 .8411 L F
.574 .382 .584 r
.39325 .8813 m .39336 .88351 L .39467 .88303 L F
.681 .9 .975 r
.56541 .77992 m .56991 .77964 L .56701 .78017 L F
.519 0 0 r
.56991 .77964 m .57122 .78049 L .56701 .78017 L F
.432 .093 .289 r
.57187 .7786 m .57122 .78049 L .56991 .77964 L F
.399 0 0 r
.32629 .67851 m .3282 .67861 L .33043 .67799 L F
.341 0 0 r
.3282 .67861 m .33129 .67814 L .33043 .67799 L F
.628 .467 .645 r
.40599 .75078 m .40611 .75231 L .40816 .74973 L F
.991 .782 .399 r
.4999 .85546 m .49964 .85221 L .49941 .85461 L F
.989 .87 .622 r
.49941 .85461 m .49889 .85667 L .4999 .85546 L F
.412 .452 .792 r
.50222 .85708 m .50145 .8578 L .4999 .85546 L F
.706 .341 .354 r
.49889 .85667 m .50222 .85708 L .4999 .85546 L F
.063 0 0 r
.52122 .8415 m .5227 .84125 L .52381 .83934 L F
.68 .287 .295 r
.52381 .83934 m .5227 .84125 L .52555 .84093 L F
.523 .329 .56 r
.52381 .83934 m .52555 .84093 L .52592 .83878 L F
.29 .395 .797 r
.56969 .81726 m .56846 .8185 L .56872 .81573 L F
.56969 .81726 m .5707 .82013 L .56846 .8185 L F
.107 .66 .719 r
.53372 .84708 m .53251 .84722 L .53015 .84753 L F
.501 .637 .915 r
.53372 .84708 m .53347 .84424 L .53188 .84414 L F
.53372 .84708 m .53578 .84679 L .53347 .84424 L F
.817 .997 .777 r
.53308 .84906 m .53372 .84708 L .53251 .84722 L F
.984 .729 .463 r
.5335 .84932 m .53372 .84708 L .53578 .84679 L F
.817 .997 .777 r
.53308 .84906 m .53578 .84679 L .53372 .84708 L F
.595 .476 .688 r
.55163 .84403 m .54948 .84206 L .55078 .84181 L F
.82 .488 .425 r
.48708 .84697 m .48595 .84954 L .48484 .84654 L F
.707 .354 .375 r
.4871 .84744 m .48708 .84697 L .48998 .84831 L F
.4871 .84744 m .48595 .84954 L .48708 .84697 L F
.616 .462 .65 r
.43106 .84159 m .43387 .84412 L .43316 .84094 L F
.43106 .84159 m .43058 .84453 L .43387 .84412 L F
.422 .203 .474 r
.4762 .8639 m .47437 .86524 L .47546 .86321 L F
.023 0 0 r
.49604 .88306 m .49756 .88179 L .49946 .88106 L F
.786 .29 .016 r
.54655 .81709 m .54604 .81524 L .54501 .81461 L F
.54655 .81709 m .54792 .81748 L .54604 .81524 L F
.783 .283 0 r
.54604 .81524 m .54792 .81748 L .54933 .81792 L F
.881 .563 .443 r
.4948 .87779 m .49604 .87594 L .49441 .8759 L F
.662 .274 .299 r
.49814 .87771 m .49604 .87594 L .4948 .87779 L F
.685 .443 .55 r
.44703 .83054 m .45242 .83147 L .44769 .83008 L F
.15 .144 .596 r
.69556 .70199 m .69397 .70394 L .69323 .70282 L F
.584 .045 0 r
.69397 .70394 m .69615 .70579 L .69731 .70487 L F
.15 .144 .596 r
.69556 .70199 m .69615 .70579 L .69397 .70394 L F
.907 .953 .816 r
.63167 .78137 m .63284 .77816 L .63053 .7806 L F
.63167 .78137 m .6337 .77859 L .63284 .77816 L F
.722 .661 .789 r
.655 .76496 m .65833 .76577 L .6573 .76268 L F
.585 .56 .793 r
.65833 .76577 m .6594 .76217 L .6573 .76268 L F
.65833 .76577 m .66069 .76557 L .6594 .76217 L F
.207 0 0 r
.48723 .88364 m .48868 .88367 L .48666 .88406 L F
.865 .787 .772 r
.62391 .79238 m .62565 .7896 L .62415 .78857 L F
.966 .899 .705 r
.62565 .7896 m .62613 .78577 L .62415 .78857 L F
.826 .566 .546 r
.68154 .74573 m .6841 .74442 L .68324 .74372 L F
.68154 .74573 m .68428 .74646 L .6841 .74442 L F
.981 .694 .385 r
.6841 .74442 m .68337 .7459 L .68324 .74372 L F
.6841 .74442 m .68428 .74646 L .68337 .7459 L F
.962 .771 .598 r
.54948 .84206 m .54837 .84377 L .54642 .84428 L F
.54948 .84206 m .54953 .84459 L .54837 .84377 L F
.595 .476 .688 r
.55163 .84403 m .54953 .84459 L .54948 .84206 L F
.099 .603 .896 r
.5742 .84695 m .57711 .84776 L .57612 .8476 L F
.09 .631 .851 r
.57711 .84776 m .57783 .84741 L .57612 .8476 L F
.57711 .84776 m .58014 .84797 L .57783 .84741 L F
.744 .682 .791 r
.64234 .7423 m .64314 .74484 L .63987 .74447 L F
.798 .711 .768 r
.64498 .74216 m .64314 .74484 L .64234 .7423 L F
.22 0 0 r
.57335 .7787 m .57122 .78049 L .57187 .7786 L F
.664 .466 .606 r
.44478 .8335 m .44703 .83054 L .44517 .83118 L F
.637 .453 .617 r
.60387 .76248 m .60551 .76257 L .60549 .76038 L F
.672 .5 .644 r
.60551 .76257 m .6076 .76008 L .60549 .76038 L F
.798 .711 .768 r
.64498 .74216 m .64234 .7423 L .64395 .74095 L F
.644 .741 .919 r
.64725 .74157 m .64498 .74216 L .64395 .74095 L F
.649 .847 .976 r
.41633 .73697 m .41354 .73708 L .41533 .73633 L F
.291 .688 .974 r
.41743 .73649 m .41633 .73697 L .41533 .73633 L F
.41743 .73649 m .41816 .73709 L .41633 .73697 L F
.588 .554 .784 r
.41917 .73812 m .41633 .73697 L .41816 .73709 L F
.847 .811 .814 r
.6337 .77859 m .63448 .77526 L .63284 .77816 L F
.6337 .77859 m .6358 .77591 L .63448 .77526 L F
.606 .413 .594 r
.4204 .8573 m .42222 .8571 L .42216 .85501 L F
.643 .507 .681 r
.42216 .85501 m .42547 .8547 L .42471 .8517 L F
.633 .438 .601 r
.42222 .8571 m .42547 .8547 L .42216 .85501 L F
0 0 0 r
.54915 .81904 m .54933 .81792 L .54792 .81748 L F
.54915 .81904 m .54936 .81855 L .54933 .81792 L F
.525 .383 .631 r
.45683 .86245 m .457 .86484 L .45488 .86284 L F
.879 .656 .596 r
.57318 .83104 m .57705 .83074 L .57494 .82815 L F
.613 .599 .813 r
.57318 .83104 m .5753 .83305 L .57705 .83074 L F
.358 .522 .883 r
.57494 .82815 m .57705 .83074 L .57833 .83053 L F
.249 0 0 r
.69255 .7339 m .68927 .73613 L .69047 .73718 L F
.483 0 0 r
.68927 .73613 m .69251 .73841 L .69047 .73718 L F
.664 .518 .676 r
.63222 .74703 m .63013 .74965 L .63015 .74746 L F
.913 .801 .722 r
.64573 .76687 m .6471 .76761 L .64648 .76494 L F
.862 .879 .849 r
.64475 .76814 m .6471 .76761 L .64573 .76687 L F
.729 .699 .822 r
.64648 .76494 m .6471 .76761 L .64975 .76538 L F
.22 0 0 r
.57335 .7787 m .57232 .78051 L .57122 .78049 L F
.713 .276 .211 r
.57553 .78058 m .57232 .78051 L .57335 .7787 L F
.739 .437 .47 r
.56046 .79937 m .56396 .79941 L .56217 .80059 L F
.305 0 .058 r
.34365 .75485 m .34587 .75415 L .34362 .75489 L F
.613 .437 .621 r
.60977 .75747 m .61206 .75725 L .61207 .75481 L F
.605 .445 .639 r
.61206 .75725 m .61425 .75445 L .61207 .75481 L F
.612 .496 .697 r
.39809 .87848 m .40052 .88031 L .40113 .87851 L F
.623 .481 .668 r
.40113 .87851 m .40346 .87829 L .40269 .8755 L F
.34 0 .186 r
.40052 .88031 m .40346 .87829 L .40113 .87851 L F
.602 .111 .059 r
.69916 .75289 m .70136 .75415 L .69815 .75396 L F
.739 .631 .739 r
.51937 .84648 m .52041 .84964 L .52263 .84693 L F
.584 .408 .61 r
.52041 .84964 m .52279 .84967 L .52263 .84693 L F
.666 .161 .035 r
.37263 .74996 m .37092 .75061 L .36943 .74919 L F
.599 .223 .301 r
.52474 .84872 m .52702 .84902 L .52795 .84704 L F
.587 .524 .751 r
.52795 .84704 m .52911 .84386 L .52688 .8439 L F
.52795 .84704 m .53015 .84753 L .52911 .84386 L F
.526 .005 0 r
.52914 .84837 m .52795 .84704 L .52702 .84902 L F
.52914 .84837 m .53015 .84753 L .52795 .84704 L F
.429 .056 .226 r
.35881 .78836 m .3608 .78806 L .36154 .7868 L F
.38 .006 .198 r
.36154 .7868 m .36268 .78764 L .36361 .78649 L F
.36154 .7868 m .3608 .78806 L .36268 .78764 L F
.765 .968 .679 r
.57389 .8251 m .57555 .82368 L .5761 .82241 L F
.888 .878 .82 r
.61757 .80736 m .61977 .80453 L .61859 .80395 L F
.599 .208 .273 r
.6928 .75416 m .69366 .75228 L .69597 .75358 L F
.72 .34 .329 r
.69047 .752 m .69366 .75228 L .6928 .75416 L F
.451 .145 .354 r
.56654 .81055 m .56618 .8121 L .56852 .81153 L F
.85 .81 .811 r
.63448 .77526 m .6358 .77591 L .63785 .77325 L F
.424 .401 .729 r
.4854 .86972 m .48354 .86768 L .48515 .86748 L F
.591 .418 .615 r
.60996 .75983 m .61206 .75725 L .60977 .75747 L F
0 0 0 r
.61221 .82245 m .61271 .82063 L .61219 .82263 L F
.61332 .81963 m .61271 .82063 L .61376 .818 L F
.61219 .82263 m .61271 .82063 L .61332 .81963 L F
.651 .471 .627 r
.43316 .84094 m .43612 .84126 L .43442 .83915 L F
.638 .493 .669 r
.43442 .83915 m .43817 .8389 L .43747 .83534 L F
.644 .482 .648 r
.43612 .84126 m .43817 .8389 L .43442 .83915 L F
.585 .398 .594 r
.48601 .82406 m .48704 .82462 L .48686 .82386 L F
.48453 .82326 m .48457 .82566 L .48704 .82462 L F
.64 .344 .453 r
.48587 .82532 m .48686 .82386 L .48704 .82462 L F
.48587 .82532 m .48775 .82365 L .48686 .82386 L F
.48775 .82365 m .48897 .82257 L .48686 .82386 L F
.585 .398 .594 r
.48453 .82326 m .48601 .82406 L .48686 .82386 L F
.505 .332 .58 r
.52245 .82111 m .52448 .82063 L .52382 .8184 L F
.932 .755 .639 r
.68188 .75403 m .68386 .75258 L .68189 .75172 L F
.68188 .75403 m .68328 .75483 L .68386 .75258 L F
.731 .503 .581 r
.58852 .7733 m .59158 .77566 L .59144 .77336 L F
.58852 .7733 m .58856 .77601 L .59158 .77566 L F
0 0 .11 r
.53442 .83923 m .53399 .84104 L .53485 .83995 L F
.611 .755 .947 r
.44174 .88173 m .44613 .88285 L .44383 .88185 L F
.273 .68 .97 r
.44613 .88285 m .44561 .88234 L .44383 .88185 L F
.44613 .88285 m .44749 .8829 L .44561 .88234 L F
.72 .247 .125 r
.70018 .74986 m .7012 .74963 L .69823 .74899 L F
0 0 0 r
.70348 .74927 m .7012 .74963 L .70018 .74986 L F
.56 .38 .594 r
.40657 .86793 m .4045 .87056 L .40659 .87025 L F
.604 .46 .658 r
.4045 .87056 m .40703 .87241 L .40659 .87025 L F
.4045 .87056 m .40475 .87294 L .40703 .87241 L F
.429 .111 .322 r
.39729 .77793 m .39445 .78049 L .39526 .77832 L F
.622 .548 .75 r
.54396 .78499 m .54231 .7866 L .54446 .7857 L F
.797 .895 .913 r
.55188 .78339 m .55558 .78208 L .55446 .78142 L F
.72 .897 .959 r
.55446 .78142 m .55558 .78208 L .55844 .78054 L F
.85 .81 .811 r
.63448 .77526 m .63785 .77325 L .63638 .77259 L F
.756 .834 .912 r
.63638 .77259 m .63785 .77325 L .63965 .77217 L F
.664 .953 .951 r
.68765 .71267 m .68683 .71236 L .68507 .71345 L F
.68765 .71267 m .68683 .71236 L .68507 .71345 L F
.589 .944 .908 r
.68765 .71267 m .68885 .71152 L .6874 .71017 L F
.68885 .71152 m .68888 .7115 L .68885 .71147 L F
.68885 .71152 m .68885 .71147 L .6874 .71017 L F
.646 .583 .769 r
.68871 .71054 m .69046 .71021 L .69026 .70831 L F
.68818 .71131 m .68878 .71102 L .68871 .71054 L F
.68878 .71102 m .69046 .71021 L .68871 .71054 L F
.58 .922 .962 r
.68888 .7115 m .68683 .71236 L .68765 .71267 L F
.589 .944 .908 r
.68765 .71267 m .68935 .71176 L .68888 .7115 L F
.58 .922 .962 r
.68888 .7115 m .68683 .71236 L .68765 .71267 L F
.697 .594 .736 r
.5148 .86801 m .51698 .86892 L .51571 .86719 L F
.714 .598 .725 r
.51571 .86719 m .51698 .86892 L .51811 .86727 L F
.734 .232 .034 r
.49304 .87611 m .49441 .8759 L .49261 .87429 L F
.627 .469 .649 r
.71429 .73633 m .71288 .73781 L .71151 .73817 L F
.71429 .73633 m .71445 .73857 L .71288 .73781 L F
.583 .547 .78 r
.65782 .72622 m .65994 .72584 L .659 .72257 L F
.444 .029 .155 r
.46256 .85981 m .46186 .86174 L .459 .86202 L F
0 0 0 r
.46227 .86097 m .46256 .85981 L .46404 .86198 L F
.46227 .86097 m .46186 .86174 L .46256 .85981 L F
.679 .734 .892 r
.51937 .84648 m .52263 .84693 L .52122 .84473 L F
.597 .622 .848 r
.52263 .84693 m .52367 .84406 L .52122 .84473 L F
.521 .36 .604 r
.52263 .84693 m .52279 .84967 L .52474 .84872 L F
.607 .449 .642 r
.45443 .82382 m .45703 .82368 L .45655 .82061 L F
.571 .268 .415 r
.46186 .8354 m .46398 .83548 L .46216 .8338 L F
.558 .271 .435 r
.46216 .8338 m .46398 .83548 L .46448 .83359 L F
.665 .525 .684 r
.41397 .8629 m .41396 .86519 L .41616 .86247 L F
.169 0 .034 r
.34587 .75415 m .34276 .75682 L .34362 .75489 L F
.588 .745 .951 r
.38414 .89217 m .38776 .89316 L .38633 .89162 L F
.619 .645 .854 r
.38776 .89316 m .38805 .89074 L .38633 .89162 L F
.38776 .89316 m .38929 .893 L .38805 .89074 L F
.937 .855 .735 r
.60296 .79955 m .60182 .79906 L .60319 .79603 L F
.963 .675 .437 r
.60296 .79955 m .60329 .80231 L .60182 .79906 L F
.635 .467 .637 r
.40174 .75754 m .40395 .75726 L .40392 .75493 L F
.637 .49 .666 r
.40611 .75231 m .40392 .75493 L .40609 .75458 L F
.651 .49 .653 r
.40395 .75726 m .40609 .75458 L .40392 .75493 L F
.849 .753 .757 r
.54953 .84459 m .54625 .84643 L .54837 .84377 L F
.54953 .84459 m .54793 .84726 L .54625 .84643 L F
.433 .311 .614 r
.59144 .77336 m .59321 .775 L .59357 .77288 L F
.59144 .77336 m .59158 .77566 L .59321 .775 L F
.718 .186 0 r
.54882 .80518 m .54806 .8053 L .54666 .804 L F
0 .117 .663 r
.54882 .80518 m .55037 .80636 L .54806 .8053 L F
.54882 .80518 m .55057 .80697 L .55037 .80636 L F
.688 .587 .737 r
.40269 .8755 m .40556 .8759 L .40475 .87294 L F
.683 .503 .637 r
.40346 .87829 m .40556 .8759 L .40269 .8755 L F
.623 .556 .759 r
.52661 .81518 m .52975 .81788 L .52871 .81468 L F
.571 .417 .634 r
.49155 .85458 m .4936 .8552 L .49483 .85241 L F
.487 .063 .16 r
.57865 .77898 m .57774 .78043 L .57553 .78058 L F
.646 .234 .25 r
.58052 .7803 m .57774 .78043 L .57865 .77898 L F
.638 .958 .925 r
.6904 .70408 m .68897 .70502 L .68994 .70376 L F
.345 .272 .63 r
.68833 .70697 m .68994 .70376 L .68897 .70502 L F
.726 .944 .954 r
.50643 .85413 m .5078 .85449 L .50561 .85523 L F
.302 .35 .746 r
.50728 .85717 m .50561 .85523 L .5078 .85449 L F
.38 .816 .959 r
.50986 .85414 m .5078 .85449 L .5066 .85417 L F
.50986 .85414 m .5066 .85417 L .50684 .85413 L F
.757 .597 .679 r
.50986 .85414 m .50728 .85717 L .5078 .85449 L F
.38 .816 .959 r
.50986 .85414 m .50643 .85413 L .50846 .85348 L F
.757 .597 .679 r
.50986 .85414 m .51096 .85642 L .50728 .85717 L F
.444 .355 .661 r
.50876 .85653 m .50728 .85717 L .51096 .85642 L F
.562 .489 .731 r
.50728 .85717 m .50919 .85635 L .50855 .85383 L F
.444 .355 .661 r
.50848 .85655 m .50728 .85717 L .50876 .85653 L F
.562 .489 .731 r
.50728 .85717 m .5094 .85716 L .50919 .85635 L F
.50833 .85387 m .50855 .85383 L .50846 .85348 L F
.50728 .85717 m .50855 .85383 L .50833 .85387 L F
.38 .816 .959 r
.50684 .85413 m .5066 .85417 L .50643 .85413 L F
.249 0 0 r
.69255 .7339 m .69144 .73543 L .68927 .73613 L F
0 0 .416 r
.69225 .73098 m .69305 .733 L .69255 .7339 L F
.633 .837 .438 r
.69305 .733 m .69144 .73543 L .69255 .7339 L F
.487 .896 .79 r
.35308 .75358 m .3522 .75422 L .35383 .754 L F
.35308 .75358 m .35109 .75466 L .3522 .75422 L F
.961 .762 .589 r
.6753 .71551 m .67382 .71733 L .67097 .71533 L F
.6753 .71551 m .67499 .71852 L .67382 .71733 L F
0 0 .315 r
.67577 .71241 m .67593 .71455 L .6753 .71551 L F
.114 .301 .775 r
.67593 .71455 m .67721 .71742 L .6753 .71551 L F
.65 .281 .331 r
.67097 .71533 m .6753 .71551 L .67382 .71733 L F
.459 .166 .379 r
.39046 .78142 m .39008 .78315 L .3879 .78349 L F
.526 .225 .4 r
.39214 .78286 m .39046 .78142 L .39258 .78105 L F
.39214 .78286 m .39008 .78315 L .39046 .78142 L F
.948 .594 .281 r
.67893 .73116 m .67798 .73072 L .67731 .72835 L F
.921 .656 .519 r
.67893 .73116 m .67759 .73294 L .67798 .73072 L F
.67893 .73116 m .67917 .73367 L .67759 .73294 L F
.469 .353 .639 r
.45857 .82262 m .45655 .82061 L .45865 .82031 L F
.45857 .82262 m .45703 .82368 L .45655 .82061 L F
.45857 .82262 m .45655 .82061 L .45865 .82031 L F
.45857 .82262 m .45703 .82368 L .45655 .82061 L F
.661 .873 .979 r
.40035 .89165 m .40365 .89138 L .40217 .89063 L F
.545 .58 .84 r
.40365 .89138 m .40438 .88868 L .40217 .89063 L F
.40365 .89138 m .40584 .89153 L .40438 .88868 L F
.088 0 0 r
.46279 .88309 m .46721 .88195 L .46588 .88273 L F
.182 0 0 r
.46588 .88273 m .46721 .88195 L .46888 .8819 L F
.642 .385 .515 r
.52057 .82794 m .51709 .83055 L .51846 .82694 L F
.52057 .82794 m .51846 .82694 L .52015 .82775 L F
.659 .204 .162 r
.51794 .82627 m .52015 .82775 L .51846 .82694 L F
.611 .298 .415 r
.52034 .82621 m .52015 .82775 L .51794 .82627 L F
0 0 .425 r
.66869 .71223 m .67042 .71457 L .67097 .71533 L F
0 0 .233 r
.67042 .71457 m .67119 .7176 L .67097 .71533 L F
.982 .904 .583 r
.67097 .71533 m .67042 .71457 L .67118 .7123 L F
.469 0 0 r
.67097 .71533 m .6727 .71669 L .67042 .71457 L F
.67097 .71533 m .67382 .71733 L .6727 .71669 L F
.696 .562 .699 r
.64046 .72101 m .63837 .72375 L .64053 .72313 L F
.64046 .72101 m .63837 .72375 L .64053 .72313 L F
.974 .807 .389 r
.55513 .8384 m .55546 .83621 L .55503 .83571 L F
.781 .655 .723 r
.51302 .85472 m .5142 .85728 L .51096 .85642 L F
.799 .497 .477 r
.51096 .85642 m .5142 .85728 L .51298 .85949 L F
.637 .321 .418 r
.5142 .85728 m .51688 .8576 L .51479 .85878 L F
.802 .984 .894 r
.51479 .85878 m .51688 .8576 L .51686 .85732 L F
.51512 .85838 m .51686 .85732 L .51679 .85639 L F
.51479 .85878 m .51686 .85732 L .51512 .85838 L F
.51479 .85878 m .51679 .85639 L .51578 .85782 L F
.51567 .85794 m .51578 .85782 L .51573 .8579 L F
.721 .324 .297 r
.51572 .85791 m .51679 .85639 L .514 .85613 L F
.69 .253 .209 r
.514 .85613 m .51679 .85639 L .51622 .85791 L F
.403 .357 .693 r
.514 .85613 m .51591 .85766 L .51576 .85597 L F
.51591 .85766 m .51622 .85791 L .51611 .85743 L F
.51591 .85766 m .51611 .85743 L .51576 .85597 L F
.802 .984 .894 r
.51479 .85878 m .51578 .85782 L .51567 .85794 L F
.51479 .85878 m .51573 .8579 L .51572 .85791 L F
0 0 .467 r
.51491 .85866 m .51479 .85878 L .51536 .85952 L F
.5142 .85728 m .51479 .85878 L .51491 .85866 L F
.5142 .85728 m .51485 .85855 L .51298 .85949 L F
.51485 .85855 m .51536 .85952 L .51331 .85949 L F
.51485 .85855 m .51331 .85949 L .51298 .85949 L F
.888 .823 .778 r
.40852 .86997 m .41188 .86768 L .40986 .86814 L F
.40852 .86997 m .41005 .87048 L .41188 .86768 L F
.929 .713 .59 r
.40852 .86997 m .40977 .87296 L .41005 .87048 L F
.676 .617 .782 r
.40703 .87241 m .40856 .87272 L .40852 .86997 L F
.40856 .87272 m .40977 .87296 L .40923 .87168 L F
.40856 .87272 m .40923 .87168 L .40852 .86997 L F
.619 .822 .415 r
.41005 .87048 m .40927 .87163 L .41188 .86768 L F
.40927 .87163 m .40888 .8722 L .40952 .87124 L F
.40927 .87163 m .40952 .87124 L .41188 .86768 L F
.731 .625 .74 r
.41197 .86574 m .41188 .86768 L .41396 .86519 L F
0 0 0 r
.41396 .86519 m .41188 .86768 L .41315 .86625 L F
.715 .489 .581 r
.41188 .86768 m .41497 .87039 L .41315 .86625 L F
.653 .452 .6 r
.41005 .87048 m .40977 .87296 L .41208 .87232 L F
.41005 .87048 m .41208 .87232 L .40888 .8722 L F
.715 .489 .581 r
.41188 .86768 m .40888 .8722 L .41497 .87039 L F
.394 .023 .212 r
.40659 .87025 m .40986 .86814 L .40657 .86793 L F
.52 .248 .444 r
.52206 .83328 m .52425 .83301 L .52457 .83115 L F
.506 .176 .342 r
.52425 .83301 m .52676 .83133 L .52457 .83115 L F
.535 .181 .314 r
.38909 .76962 m .39174 .7696 L .39028 .76817 L F
.489 .185 .377 r
.39028 .76817 m .39174 .7696 L .39238 .76783 L F
.338 0 .193 r
.35718 .80477 m .356 .80695 L .35429 .80711 L F
.383 .019 .218 r
.35803 .80656 m .35718 .80477 L .359 .80419 L F
.35803 .80656 m .356 .80695 L .35718 .80477 L F
0 .417 .702 r
.37239 .72478 m .37421 .72528 L .37558 .72569 L F
.64 .909 .982 r
.37558 .72569 m .37421 .72528 L .3763 .72438 L F
.445 .674 .961 r
.3763 .72438 m .37755 .72572 L .37558 .72569 L F
.64 .909 .982 r
.37558 .72569 m .37421 .72528 L .3763 .72438 L F
.742 .51 .578 r
.49941 .85461 m .49964 .85221 L .4957 .8522 L F
.515 .909 .787 r
.46296 .86443 m .46042 .86572 L .46281 .86521 L F
0 0 0 r
.46296 .86443 m .46281 .86521 L .46404 .86198 L F
.198 .727 .813 r
.37804 .74955 m .37774 .74947 L .37499 .74985 L F
.663 .963 .764 r
.37875 .74847 m .37774 .74947 L .37804 .74955 L F
.325 .242 .606 r
.52903 .82566 m .53054 .826 L .5297 .82285 L F
.542 .15 .248 r
.50001 .85051 m .49648 .84916 L .49725 .84794 L F
0 .437 .843 r
.49695 .84904 m .49648 .84916 L .50001 .85051 L F
0 0 0 r
.49725 .84794 m .49648 .84916 L .49591 .84932 L F
.644 .263 .308 r
.49725 .84794 m .49648 .84916 L .49521 .84817 L F
.44 0 0 r
.49521 .84817 m .49648 .84916 L .49525 .84822 L F
0 .437 .843 r
.49525 .84822 m .49648 .84916 L .49695 .84904 L F
0 0 0 r
.49591 .84932 m .49648 .84916 L .49572 .84952 L F
.615 .606 .819 r
.70065 .70997 m .70389 .71264 L .70283 .70928 L F
.651 .588 .772 r
.70283 .70928 m .70389 .71264 L .70601 .71057 L F
.665 .612 .786 r
.70389 .71264 m .70692 .71354 L .70601 .71057 L F
.996 .807 .532 r
.58001 .78389 m .57878 .78572 L .57909 .78318 L F
.511 .331 .572 r
.58207 .78337 m .58001 .78389 L .58203 .7811 L F
.702 .773 .907 r
.48457 .82566 m .48785 .82594 L .48704 .82462 L F
.466 .883 .929 r
.49016 .8253 m .48875 .82519 L .48785 .82594 L F
.24 .512 .908 r
.48785 .82594 m .48875 .82519 L .48704 .82462 L F
.664 .466 .606 r
.44478 .8335 m .44805 .83383 L .44703 .83054 L F
.636 .449 .613 r
.44703 .83054 m .45011 .83325 L .45242 .83147 L F
.44703 .83054 m .44805 .83383 L .45011 .83325 L F
.412 .031 .202 r
.53375 .86059 m .53553 .85738 L .53498 .85875 L F
.733 .696 .815 r
.53251 .85777 m .53375 .86059 L .53498 .85875 L F
.881 .446 .12 r
.55827 .81802 m .55935 .81837 L .56009 .81988 L F
.517 .315 .545 r
.42831 .75415 m .42842 .75685 L .42593 .75708 L F
.548 .376 .599 r
.43032 .75183 m .43052 .75408 L .42831 .75415 L F
.567 .366 .568 r
.43052 .75408 m .42842 .75685 L .42831 .75415 L F
.995 .832 .57 r
.61711 .80929 m .61757 .80736 L .61673 .80677 L F
.888 .878 .82 r
.61757 .80736 m .61859 .80395 L .61673 .80677 L F
.637 .471 .641 r
.39951 .75993 m .40181 .75992 L .40174 .75754 L F
.636 .47 .641 r
.40181 .75992 m .40395 .75726 L .40174 .75754 L F
.567 .437 .662 r
.61727 .74541 m .62027 .7464 L .61985 .74547 L F
.61727 .74541 m .61815 .74682 L .62027 .7464 L F
.627 .469 .649 r
.71429 .73633 m .71151 .73817 L .71453 .73523 L F
.938 .917 .768 r
.71457 .73445 m .71429 .73633 L .71453 .73523 L F
.591 .407 .601 r
.71457 .73445 m .7167 .73565 L .71429 .73633 L F
.348 .157 .473 r
.71429 .73633 m .71637 .73781 L .71445 .73857 L F
.71429 .73633 m .7167 .73565 L .71637 .73781 L F
.422 .15 .395 r
.39712 .76214 m .39849 .76223 L .39951 .75993 L F
.691 .478 .593 r
.39849 .76223 m .40181 .75992 L .39951 .75993 L F
.271 .301 .71 r
.70484 .74312 m .70489 .7445 L .70405 .74427 L F
.681 .637 .799 r
.70735 .74282 m .70489 .7445 L .70484 .74312 L F
.224 .239 .665 r
.70405 .74427 m .70529 .74652 L .70484 .74312 L F
0 0 0 r
.61376 .818 m .61441 .81525 L .61376 .81738 L F
.61332 .81963 m .61376 .818 L .61376 .81738 L F
.537 .231 .396 r
.40231 .77394 m .40194 .77544 L .39978 .77563 L F
.564 .276 .436 r
.40478 .773 m .40194 .77544 L .40231 .77394 L F
.451 .018 .124 r
.54994 .78404 m .5465 .78576 L .54712 .78597 L F
.54994 .78404 m .54888 .78572 L .5465 .78576 L F
0 0 0 r
.55075 .78378 m .5506 .78382 L .55188 .78339 L F
.951 .702 .525 r
.55172 .78106 m .55075 .78378 L .55188 .78339 L F
.052 0 .162 r
.55172 .78106 m .55188 .78339 L .55446 .78142 L F
.55174 .78138 m .55267 .78192 L .55188 .78339 L F
.55172 .78106 m .55267 .78192 L .55174 .78138 L F
.094 0 0 r
.55388 .782 m .55335 .78231 L .55267 .78192 L F
.733 .991 .836 r
.55267 .78192 m .55075 .78378 L .55188 .78339 L F
.094 0 0 r
.55206 .78306 m .55123 .78354 L .55267 .78192 L F
.55335 .78231 m .55206 .78306 L .55267 .78192 L F
0 0 0 r
.55123 .78354 m .55098 .78373 L .55075 .78378 L F
.604 .89 .587 r
.54966 .7847 m .54888 .78572 L .5494 .78518 L F
.54966 .7847 m .5494 .78518 L .55075 .78378 L F
0 0 0 r
.55098 .78373 m .54966 .7847 L .55075 .78378 L F
.55123 .78354 m .551 .78394 L .54966 .7847 L F
.405 .854 .903 r
.551 .78394 m .54989 .78426 L .54966 .7847 L F
.797 .362 .213 r
.54966 .7847 m .54712 .78363 L .54758 .78446 L F
.54966 .7847 m .54811 .78477 L .54712 .78363 L F
.405 .854 .903 r
.54989 .78426 m .54811 .78477 L .54966 .7847 L F
0 0 0 r
.55075 .78378 m .54994 .78404 L .5506 .78382 L F
.568 .01 0 r
.54479 .79869 m .5473 .7997 L .54777 .79937 L F
.949 .897 .508 r
.5473 .7997 m .5466 .80114 L .54777 .79937 L F
.372 .729 .989 r
.5488 .79861 m .54985 .79945 L .54777 .79937 L F
0 0 0 r
.54777 .79937 m .5466 .80114 L .5488 .79861 L F
.42 .046 .22 r
.35077 .79366 m .35383 .79154 L .35167 .79209 L F
.744 .388 .377 r
.58013 .77466 m .58177 .77537 L .58301 .77348 L F
.605 .222 .29 r
.58301 .77348 m .58177 .77537 L .58522 .775 L F
.865 .787 .772 r
.62391 .79238 m .62415 .78857 L .62281 .79158 L F
.891 .8 .753 r
.62192 .793 m .62391 .79238 L .62281 .79158 L F
.62192 .793 m .62301 .79409 L .62391 .79238 L F
.544 .318 .523 r
.42593 .75708 m .42575 .75987 L .42368 .7602 L F
.549 .342 .552 r
.42842 .75685 m .42575 .75987 L .42593 .75708 L F
.817 .943 .585 r
.69731 .70487 m .69861 .70219 L .69956 .70498 L F
.69731 .70487 m .69615 .70579 L .69861 .70219 L F
.673 .914 .59 r
.6988 .70462 m .69731 .70487 L .69956 .70498 L F
.6988 .70462 m .69688 .70714 L .69731 .70487 L F
.812 .328 .021 r
.43833 .73862 m .44137 .74136 L .43924 .74157 L F
.369 .828 .917 r
.44014 .74098 m .43924 .74157 L .44137 .74136 L F
.44014 .74098 m .4381 .74144 L .43924 .74157 L F
.621 .104 0 r
.50697 .88248 m .50791 .88145 L .51018 .8829 L F
.394 .023 .212 r
.40659 .87025 m .40852 .86997 L .40986 .86814 L F
.988 .753 .489 r
.54936 .81855 m .55004 .8225 L .55106 .82287 L F
.888 .528 .048 r
.55118 .82485 m .55106 .82287 L .55004 .8225 L F
.55118 .82485 m .55184 .82559 L .55106 .82287 L F
.886 .688 .628 r
.68078 .73635 m .67869 .73603 L .67917 .73367 L F
.878 .752 .719 r
.68078 .73635 m .67959 .73893 L .67869 .73603 L F
.742 .952 .645 r
.5803 .83006 m .5816 .82942 L .58001 .83134 L F
.489 0 0 r
.5842 .8305 m .5816 .82942 L .5803 .83006 L F
.02 .529 .868 r
.58506 .83059 m .58338 .83002 L .5842 .8305 L F
0 .209 .686 r
.58488 .83089 m .5842 .8305 L .58315 .82954 L F
.037 .604 .771 r
.5842 .8305 m .58694 .83065 L .58506 .83059 L F
.664 .2 .142 r
.58592 .8317 m .58694 .83065 L .5842 .8305 L F
0 .209 .686 r
.58592 .8317 m .5842 .8305 L .58488 .83089 L F
.02 .529 .868 r
.58338 .83002 m .5816 .82942 L .5842 .8305 L F
.704 .687 .831 r
.41035 .74916 m .41364 .74982 L .41216 .74711 L F
.559 .127 .177 r
.41009 .75114 m .41364 .74982 L .41035 .74916 L F
.41009 .75114 m .41241 .75127 L .41364 .74982 L F
.609 .643 .859 r
.41216 .74711 m .41364 .74982 L .41546 .74876 L F
.225 0 0 r
.41364 .74982 m .41439 .75072 L .41546 .74876 L F
.41364 .74982 m .41241 .75127 L .41439 .75072 L F
.665 .831 .963 r
.6911 .72018 m .69261 .72151 L .69467 .72052 L F
.462 .153 .354 r
.37525 .7807 m .37809 .77799 L .37604 .77821 L F
.658 .415 .541 r
.5992 .78359 m .59966 .78601 L .59621 .78606 L F
.737 .544 .632 r
.60144 .78355 m .59966 .78601 L .5992 .78359 L F
.175 .678 .909 r
.5884 .84747 m .59059 .84709 L .58724 .84743 L F
.5884 .84747 m .59044 .84756 L .59059 .84709 L F
.619 .603 .813 r
.49773 .83587 m .49545 .83631 L .49438 .83347 L F
.305 0 .154 r
.49636 .83777 m .49545 .83631 L .49773 .83587 L F
.49636 .83777 m .49444 .83834 L .49545 .83631 L F
.784 .638 .7 r
.59071 .82181 m .59113 .82379 L .588 .82296 L F
.556 .77 .978 r
.588 .82296 m .59113 .82379 L .59013 .82258 L F
.818 .399 0 r
.59162 .8251 m .59161 .82484 L .5921 .82591 L F
.59013 .82258 m .59113 .82379 L .59161 .82484 L F
.59013 .82258 m .59161 .82484 L .59162 .8251 L F
.59013 .82258 m .5921 .82591 L .59209 .82437 L F
.916 .979 .735 r
.59209 .82437 m .5921 .82591 L .59096 .82755 L F
.59167 .82593 m .59096 .82755 L .59147 .82669 L F
.59209 .82437 m .59165 .8256 L .59167 .82593 L F
.59165 .8256 m .59096 .82755 L .59167 .82593 L F
.747 .437 .459 r
.54985 .79945 m .55308 .80155 L .55362 .80019 L F
.541 .182 .308 r
.55308 .80155 m .55531 .80139 L .55362 .80019 L F
.447 .23 .491 r
.55362 .80019 m .55531 .80139 L .55547 .79926 L F
.526 .666 .925 r
.52282 .87362 m .52505 .87373 L .5241 .87223 L F
.52282 .87362 m .52505 .87373 L .5241 .87223 L F
.622 .734 .927 r
.3479 .75389 m .34917 .75534 L .35109 .75466 L F
.6 .17 .196 r
.53485 .83995 m .53805 .84167 L .53993 .83846 L F
.409 0 .093 r
.53805 .84167 m .54184 .83856 L .53993 .83846 L F
.733 .696 .815 r
.53251 .85777 m .53553 .85738 L .53375 .85597 L F
.53251 .85777 m .53498 .85875 L .53553 .85738 L F
.653 .453 .6 r
.60243 .76488 m .60551 .76257 L .60387 .76248 L F
.351 .753 .984 r
.52871 .81468 m .53019 .81168 L .5293 .81292 L F
0 0 0 r
.5523 .84909 m .55333 .84712 L .55419 .84628 L F
.683 .503 .637 r
.40346 .87829 m .40535 .87828 L .40556 .8759 L F
.608 .537 .75 r
.40475 .87294 m .40556 .8759 L .40764 .87549 L F
.558 .385 .602 r
.40535 .87828 m .40764 .87549 L .40556 .8759 L F
.003 0 0 r
.59044 .84756 m .59368 .84682 L .59274 .84735 L F
0 0 0 r
.59274 .84735 m .59368 .84682 L .59571 .84634 L F
.93 .807 .702 r
.49409 .86591 m .49457 .86468 L .49275 .86524 L F
.691 .901 .971 r
.52555 .84093 m .5227 .84125 L .52466 .84022 L F
.394 0 .145 r
.52119 .84263 m .52367 .84091 L .5227 .84125 L F
.52367 .84091 m .52466 .84022 L .5227 .84125 L F
.102 0 .134 r
.52122 .8415 m .52108 .84183 L .5227 .84125 L F
.52108 .84183 m .52006 .84425 L .5227 .84125 L F
.796 .303 .007 r
.663 .72607 m .66351 .72733 L .66271 .72692 L F
.714 .707 .841 r
.54258 .79894 m .54248 .7998 L .53921 .79961 L F
.84 .642 .635 r
.54248 .7998 m .53977 .80078 L .53921 .79961 L F
.54248 .7998 m .54211 .80268 L .53977 .80078 L F
.686 .681 .839 r
.54479 .79869 m .54248 .7998 L .54258 .79894 L F
0 0 0 r
.46905 .85197 m .46729 .85438 L .46708 .85422 L F
.604 .349 .504 r
.46935 .85481 m .47103 .85529 L .47078 .85325 L F
0 0 .348 r
.47103 .85529 m .47128 .85395 L .47078 .85325 L F
.644 .352 .46 r
.47128 .85395 m .46729 .85438 L .46905 .85197 L F
.205 0 .301 r
.47078 .85325 m .47128 .85395 L .47121 .85286 L F
.706 .316 .308 r
.47121 .85286 m .47128 .85395 L .46905 .85197 L F
.719 .362 .371 r
.46707 .87159 m .47004 .87081 L .46689 .87047 L F
.46707 .87159 m .46887 .87284 L .47004 .87081 L F
0 .326 .807 r
.68126 .72122 m .6836 .72286 L .68429 .7239 L F
0 .209 .717 r
.6836 .72286 m .6867 .72578 L .68429 .7239 L F
.558 .313 .501 r
.54327 .84421 m .54087 .84648 L .54105 .84432 L F
.937 .771 .301 r
.55455 .83167 m .555 .83346 L .55518 .83111 L F
.719 .299 .249 r
.49876 .84134 m .50086 .8433 L .50197 .8418 L F
.797 .401 .303 r
.50086 .8433 m .50397 .84415 L .50197 .8418 L F
.295 .765 .938 r
.58014 .84797 m .58268 .84818 L .58208 .84769 L F
.442 .854 .962 r
.58268 .84818 m .58234 .84743 L .58208 .84769 L F
.58268 .84818 m .58501 .84764 L .58234 .84743 L F
.428 .157 .399 r
.3879 .78349 m .38722 .78613 L .38533 .78555 L F
.435 .115 .323 r
.3866 .78771 m .38533 .78555 L .38722 .78613 L F
.3866 .78771 m .38464 .78809 L .38533 .78555 L F
.413 .029 .198 r
.33769 .73319 m .33972 .73288 L .34098 .73085 L F
.369 0 .173 r
.34098 .73085 m .34169 .73247 L .34302 .73047 L F
.34098 .73085 m .33972 .73288 L .34169 .73247 L F
.634 .561 .755 r
.65052 .74628 m .64936 .74977 L .64845 .74664 L F
.65052 .74628 m .65165 .74945 L .64936 .74977 L F
.67 .525 .679 r
.40816 .74973 m .40611 .75231 L .40883 .75182 L F
.637 .49 .666 r
.40611 .75231 m .4087 .75423 L .40883 .75182 L F
.40611 .75231 m .40609 .75458 L .4087 .75423 L F
.512 .285 .506 r
.39661 .76486 m .39849 .76223 L .39712 .76214 L F
.583 .412 .615 r
.41396 .86519 m .41615 .86696 L .41616 .86247 L F
.461 .661 .948 r
.41315 .86625 m .41615 .86696 L .41396 .86519 L F
.601 .424 .615 r
.41831 .85987 m .42021 .85943 L .4204 .8573 L F
.633 .464 .636 r
.42021 .85943 m .42222 .8571 L .4204 .8573 L F
.494 0 0 r
.47255 .88295 m .47565 .88378 L .47437 .88356 L F
.095 .584 .903 r
.47565 .88378 m .47642 .88347 L .47437 .88356 L F
.47565 .88378 m .47781 .88422 L .47642 .88347 L F
.855 .481 0 r
.55262 .82747 m .55248 .82625 L .55184 .82559 L F
.55262 .82747 m .5534 .82866 L .55248 .82625 L F
.635 .658 .855 r
.52923 .85664 m .53035 .85917 L .53251 .85777 L F
.544 .441 .688 r
.42005 .74634 m .41787 .74425 L .41982 .74388 L F
.42005 .74634 m .41833 .74694 L .41787 .74425 L F
.744 .668 .776 r
.63601 .71777 m .63723 .72057 L .63946 .71997 L F
0 0 0 r
.63998 .7198 m .63946 .71997 L .64136 .71746 L F
.62 .404 .567 r
.64079 .72216 m .64065 .71904 L .63981 .72005 L F
0 0 0 r
.63964 .72031 m .63964 .7203 L .63981 .72005 L F
.62 .404 .567 r
.63867 .72179 m .63981 .72005 L .63839 .72174 L F
.64079 .72216 m .63981 .72005 L .63867 .72179 L F
0 0 0 r
.63966 .72035 m .63964 .72031 L .63998 .7198 L F
.63964 .72031 m .63981 .72005 L .63998 .7198 L F
.63964 .7203 m .63946 .71997 L .63998 .7198 L F
.63966 .72035 m .63998 .7198 L .64065 .71904 L F
.63998 .7198 m .64136 .71746 L .64065 .71904 L F
.943 .958 .734 r
.63955 .72011 m .64029 .71657 L .63789 .71659 L F
.908 .973 .797 r
.63965 .71991 m .63976 .72005 L .63962 .72021 L F
.63977 .71966 m .63976 .72005 L .63965 .71991 L F
.943 .958 .734 r
.63966 .72035 m .63977 .71966 L .63955 .72011 L F
.63977 .71966 m .64029 .71657 L .63955 .72011 L F
.908 .973 .797 r
.63984 .7182 m .63977 .71966 L .63965 .71991 L F
.943 .958 .734 r
.63977 .71966 m .63984 .7182 L .64029 .71657 L F
.63966 .72035 m .63984 .7182 L .63977 .71966 L F
.908 .973 .797 r
.63984 .7182 m .63987 .71992 L .63976 .72005 L F
.63984 .7182 m .64057 .71896 L .63987 .71992 L F
.63962 .72021 m .63987 .71992 L .63961 .72029 L F
.64057 .71896 m .64065 .71904 L .63981 .72005 L F
.64057 .71896 m .63981 .72005 L .63961 .72029 L F
.63909 .72004 m .63961 .72029 L .63839 .72174 L F
.744 .668 .776 r
.63601 .71777 m .63946 .71997 L .63964 .7203 L F
.63601 .71777 m .63964 .7203 L .6395 .72023 L F
.45 .42 .733 r
.63601 .71777 m .6395 .72023 L .63789 .71659 L F
.908 .973 .797 r
.63966 .71986 m .63961 .72029 L .6395 .72023 L F
.744 .668 .776 r
.6395 .72023 m .63964 .7203 L .63966 .72035 L F
.45 .42 .733 r
.6395 .72023 m .63966 .72035 L .63955 .72011 L F
.6395 .72023 m .63955 .72011 L .63789 .71659 L F
.908 .973 .797 r
.63984 .7182 m .63966 .71986 L .63909 .72004 L F
.63966 .71986 m .6395 .72023 L .63909 .72004 L F
.933 .958 .646 r
.66987 .74428 m .66852 .74728 L .66858 .74558 L F
.969 .877 .687 r
.66852 .74728 m .66724 .74696 L .66858 .74558 L F
.66852 .74728 m .6676 .74903 L .66724 .74696 L F
.951 .678 .484 r
.5888 .78626 m .58739 .78346 L .59042 .78347 L F
.768 .597 .666 r
.60668 .78328 m .60489 .78612 L .60519 .78391 L F
.8 .547 .555 r
.51204 .84646 m .50958 .8469 L .50893 .84623 L F
.787 .508 .514 r
.51204 .84646 m .51062 .84886 L .50958 .8469 L F
.766 .701 .79 r
.6993 .74189 m .70003 .7443 L .69974 .74182 L F
.6993 .74189 m .69692 .74403 L .70003 .7443 L F
.839 .625 .614 r
.60758 .78878 m .60475 .78845 L .60489 .78612 L F
.83 .719 .742 r
.60758 .78878 m .60575 .79127 L .60475 .78845 L F
.655 .592 .772 r
.63433 .74642 m .63222 .74703 L .63121 .74391 L F
.538 .534 .799 r
.70601 .71057 m .70692 .71354 L .7092 .7119 L F
.593 .648 .874 r
.70692 .71354 m .70927 .71373 L .7092 .7119 L F
.609 .452 .643 r
.42471 .8517 m .42682 .85118 L .42696 .84917 L F
.621 .492 .685 r
.42547 .8547 m .42682 .85118 L .42471 .8517 L F
.664 .558 .725 r
.40726 .74687 m .40816 .74973 L .41035 .74916 L F
.565 .284 .448 r
.40816 .74973 m .41009 .75114 L .41035 .74916 L F
.349 .333 .7 r
.40816 .74973 m .40883 .75182 L .41009 .75114 L F
.244 .645 .961 r
.4498 .88239 m .45073 .88315 L .45257 .88331 L F
.851 .973 .871 r
.45257 .88331 m .45412 .88269 L .45488 .88186 L F
.003 .53 .85 r
.45412 .88269 m .4581 .88335 L .45488 .88186 L F
.45412 .88269 m .45978 .88412 L .45857 .88357 L F
.789 .399 .316 r
.45922 .88372 m .46119 .88468 L .45909 .88519 L F
.443 0 .083 r
.45978 .88412 m .46188 .88287 L .46127 .88266 L F
.839 .856 .856 r
.45978 .88412 m .46127 .88266 L .45932 .88254 L F
.789 .399 .316 r
.45932 .88254 m .46064 .88405 L .45922 .88372 L F
.46064 .88405 m .46119 .88468 L .45922 .88372 L F
.003 .53 .85 r
.45645 .88308 m .45857 .88357 L .4581 .88335 L F
.45412 .88269 m .45857 .88357 L .45645 .88308 L F
.635 .483 .659 r
.41819 .86181 m .42021 .85943 L .41831 .85987 L F
.536 .3 .504 r
.64649 .72341 m .64611 .72569 L .64381 .72604 L F
.52 .343 .581 r
.64807 .72272 m .64611 .72569 L .64649 .72341 L F
.612 .52 .726 r
.43747 .83534 m .44014 .83603 L .44174 .83318 L F
.56 .4 .62 r
.43817 .8389 m .44014 .83603 L .43747 .83534 L F
.967 .648 .341 r
.55173 .80811 m .55105 .80924 L .55057 .80697 L F
.793 .356 .21 r
.55173 .80811 m .55336 .80985 L .55105 .80924 L F
.496 .258 .482 r
.40721 .77054 m .40681 .77275 L .40478 .773 L F
.536 .293 .494 r
.40894 .77239 m .40721 .77054 L .40933 .77024 L F
.40894 .77239 m .40681 .77275 L .40721 .77054 L F
.816 .626 .646 r
.65926 .73346 m .66103 .73391 L .6623 .73377 L F
.822 .754 .788 r
.6623 .73377 m .66103 .73391 L .66106 .73381 L F
.745 .596 .691 r
.66095 .73381 m .65926 .73346 L .66137 .73368 L F
.889 .83 .783 r
.66179 .73136 m .66106 .73381 L .66044 .73038 L F
.66106 .73381 m .66103 .73391 L .66102 .73383 L F
.66106 .73381 m .66102 .73383 L .66044 .73038 L F
.745 .596 .691 r
.66106 .73381 m .66137 .73368 L .6623 .73377 L F
.66095 .73381 m .66137 .73368 L .66106 .73381 L F
.751 .747 .848 r
.66102 .73383 m .66103 .73391 L .65926 .73346 L F
.745 .596 .691 r
.65978 .73385 m .65926 .73346 L .66095 .73381 L F
.751 .747 .848 r
.66044 .73038 m .66102 .73383 L .65926 .73346 L F
.822 .754 .788 r
.6623 .73377 m .66106 .73381 L .66179 .73136 L F
.745 .596 .691 r
.66241 .73581 m .65978 .73385 L .6623 .73377 L F
.203 0 .186 r
.53108 .81025 m .53019 .81168 L .53285 .80941 L F
.456 .062 .202 r
.53776 .83774 m .53649 .83616 L .53858 .83577 L F
.53776 .83774 m .53537 .83804 L .53649 .83616 L F
.628 .442 .612 r
.43387 .84412 m .43612 .84126 L .43316 .84094 L F
.849 .467 .323 r
.66658 .74137 m .66539 .74279 L .66387 .74036 L F
.327 0 0 r
.6686 .74237 m .66539 .74279 L .66658 .74137 L F
.664 .615 .79 r
.65375 .7489 m .65704 .74975 L .65456 .75129 L F
.783 .646 .711 r
.58207 .78337 m .58052 .7803 L .58203 .7811 L F
.492 .231 .446 r
.41913 .76271 m .41872 .76396 L .41672 .76467 L F
.493 .232 .447 r
.42084 .7637 m .41913 .76271 L .42119 .7624 L F
.42084 .7637 m .41872 .76396 L .41913 .76271 L F
.343 .696 .982 r
.39575 .72703 m .39527 .72804 L .39357 .7275 L F
.39575 .72703 m .39692 .72795 L .39527 .72804 L F
.081 .384 .845 r
.66285 .71271 m .66305 .71208 L .65997 .7099 L F
.799 .654 .702 r
.66285 .71271 m .66094 .7161 L .66039 .71506 L F
.66285 .71271 m .66039 .71506 L .66128 .71469 L F
.207 .534 .924 r
.6622 .7113 m .66305 .71208 L .66285 .71271 L F
.272 .238 .637 r
.66218 .71138 m .6622 .7113 L .66228 .71147 L F
0 .206 .671 r
.65997 .7099 m .66084 .71052 L .66169 .71091 L F
.66084 .71052 m .66252 .71171 L .66218 .71138 L F
.66084 .71052 m .66218 .71138 L .66169 .71091 L F
.272 .238 .637 r
.66128 .71469 m .66218 .71138 L .66285 .71271 L F
.66128 .71469 m .66265 .71462 L .66221 .7114 L F
.66218 .71138 m .66221 .7114 L .6622 .7113 L F
.66128 .71469 m .66221 .7114 L .66218 .71138 L F
.991 .734 .381 r
.6622 .7113 m .66176 .71392 L .66188 .71102 L F
.014 .043 .545 r
.66176 .71392 m .66198 .71093 L .66188 .71102 L F
.66198 .71093 m .66203 .71022 L .66188 .71102 L F
0 .206 .671 r
.66169 .71091 m .66185 .71105 L .66188 .71102 L F
.66185 .71105 m .66305 .71208 L .66188 .71102 L F
.66252 .71171 m .66305 .71208 L .66169 .71091 L F
.272 .238 .637 r
.66218 .71138 m .66228 .71147 L .66285 .71271 L F
.304 0 0 r
.46885 .86954 m .47219 .86786 L .47094 .8699 L F
.018 0 .093 r
.47437 .86524 m .473 .8691 L .47219 .86786 L F
.134 0 .019 r
.473 .8691 m .47094 .8699 L .47219 .86786 L F
.337 .085 .377 r
.68981 .72011 m .69243 .71778 L .68945 .71795 L F
.634 .46 .63 r
.43002 .84652 m .43387 .84412 L .43058 .84453 L F
.4 0 .131 r
.36835 .78304 m .37054 .78277 L .37128 .78169 L F
.581 .276 .416 r
.37054 .78277 m .37329 .78112 L .37128 .78169 L F
.784 .638 .7 r
.59071 .82181 m .588 .82296 L .59054 .82059 L F
.692 .776 .916 r
.59215 .81994 m .59071 .82181 L .59054 .82059 L F
.59215 .81994 m .59354 .82105 L .59071 .82181 L F
.673 .235 0 r
.6686 .74237 m .66987 .74428 L .66942 .74378 L F
.942 .954 .646 r
.66942 .74378 m .66987 .74428 L .66858 .74558 L F
.742 .952 .645 r
.58029 .8301 m .58001 .83134 L .57907 .83089 L F
.58004 .83015 m .57907 .83089 L .57833 .83053 L F
.58029 .8301 m .57907 .83089 L .58004 .83015 L F
.832 .838 .851 r
.58101 .82898 m .5803 .83006 L .58008 .8301 L F
0 0 0 r
.58101 .82898 m .58008 .8301 L .58004 .83015 L F
.835 .71 .726 r
.5753 .83305 m .57971 .83115 L .57833 .83053 L F
0 0 0 r
.58031 .82995 m .58004 .83015 L .579 .83177 L F
.58101 .82898 m .58004 .83015 L .58031 .82995 L F
.64 .079 0 r
.57833 .83053 m .57971 .83115 L .579 .83177 L F
.57833 .83053 m .579 .83177 L .58004 .83015 L F
.57833 .83053 m .58004 .83015 L .58008 .8301 L F
.742 .952 .645 r
.5803 .83006 m .58029 .8301 L .57833 .83053 L F
.109 0 0 r
.45242 .83147 m .45274 .83157 L .45324 .83123 L F
.926 .622 .447 r
.41222 .73114 m .41082 .73279 L .40966 .7299 L F
.595 .027 0 r
.40966 .7299 m .4118 .73113 L .41222 .73114 L F
.672 .969 .783 r
.41222 .73114 m .4118 .73113 L .4124 .73029 L F
.737 .909 .537 r
.4124 .73029 m .41082 .73279 L .41222 .73114 L F
.587 .771 .967 r
.39164 .89079 m .39486 .8912 L .39381 .88804 L F
.657 .586 .764 r
.39381 .88804 m .39486 .8912 L .39697 .88923 L F
.66 .592 .767 r
.39486 .8912 m .39813 .89207 L .39697 .88923 L F
.658 .671 .851 r
.35876 .75143 m .36182 .75266 L .36055 .75011 L F
0 0 .478 r
.36055 .75011 m .36182 .75266 L .36117 .75089 L F
.878 .599 .512 r
.36331 .75317 m .36117 .75089 L .36182 .75266 L F
.612 .496 .697 r
.39809 .87848 m .39833 .88086 L .40052 .88031 L F
.535 .739 .969 r
.50682 .87618 m .50369 .87525 L .50533 .87595 L F
0 0 0 r
.70348 .74927 m .70018 .74986 L .70262 .75001 L F
.101 0 0 r
.70504 .74962 m .70348 .74927 L .70262 .75001 L F
.70504 .74962 m .70561 .74884 L .70348 .74927 L F
.452 .342 .639 r
.70348 .74927 m .70561 .74884 L .70529 .74652 L F
.507 .626 .903 r
.68059 .71996 m .68292 .71977 L .68126 .72122 L F
.135 .01 .433 r
.68126 .72122 m .68262 .72235 L .6836 .72286 L F
.68126 .72122 m .68292 .71977 L .68262 .72235 L F
.569 .783 .979 r
.39272 .74507 m .39599 .74563 L .3949 .74489 L F
.56 .79 .985 r
.39599 .74563 m .39702 .74428 L .3949 .74489 L F
.39599 .74563 m .39797 .74547 L .39702 .74428 L F
.586 .503 .727 r
.65083 .74472 m .64845 .74664 L .6479 .74481 L F
.65083 .74472 m .65052 .74628 L .64845 .74664 L F
.508 .362 .618 r
.49871 .82541 m .50033 .8292 L .50066 .8278 L F
.672 .5 .644 r
.60551 .76257 m .60771 .76249 L .6076 .76008 L F
.617 .457 .643 r
.6076 .76008 m .61011 .76218 L .60996 .75983 L F
.6076 .76008 m .60771 .76249 L .61011 .76218 L F
.309 0 .259 r
.36672 .79932 m .36919 .79719 L .36851 .79846 L F
.363 .048 .291 r
.36851 .79846 m .36919 .79719 L .37105 .79662 L F
.872 .726 .697 r
.54793 .84726 m .54727 .84957 L .54625 .84643 L F
.649 .235 .246 r
.52676 .83133 m .52878 .83294 L .52981 .83136 L F
.549 .125 .188 r
.52981 .83136 m .53246 .83227 L .53176 .83057 L F
.52981 .83136 m .52878 .83294 L .53246 .83227 L F
.702 .673 .818 r
.40576 .74365 m .40726 .74687 L .40872 .74429 L F
.625 .573 .775 r
.40726 .74687 m .40997 .74747 L .40872 .74429 L F
.664 .558 .725 r
.40726 .74687 m .41035 .74916 L .40997 .74747 L F
.371 0 .126 r
.37619 .79365 m .37284 .79583 L .37455 .79379 L F
.778 .728 .807 r
.40787 .89073 m .40924 .89203 L .41098 .88994 L F
0 0 .314 r
.66699 .70858 m .66657 .70799 L .66577 .70699 L F
.66699 .70858 m .66703 .7099 L .66657 .70799 L F
.159 .693 .847 r
.63109 .73105 m .63311 .73097 L .63479 .73109 L F
.542 .409 .649 r
.63506 .73318 m .63701 .73548 L .63468 .73588 L F
.63525 .73189 m .63584 .73309 L .63506 .73318 L F
.63584 .73309 m .63701 .73548 L .63506 .73318 L F
0 0 .309 r
.63525 .73189 m .63479 .73109 L .63717 .73305 L F
.641 .083 0 r
.63529 .73214 m .63717 .73305 L .63479 .73109 L F
.344 .216 .559 r
.63717 .73305 m .63701 .73548 L .63525 .73189 L F
.454 .778 .998 r
.63529 .73214 m .63751 .73197 L .6372 .73294 L F
.63698 .73296 m .6372 .73294 L .63717 .73305 L F
.63529 .73214 m .6372 .73294 L .63698 .73296 L F
.641 .083 0 r
.63529 .73214 m .63479 .73109 L .63311 .73097 L F
.741 .868 .94 r
.69238 .71038 m .69526 .71009 L .69424 .70925 L F
.568 .819 .992 r
.69424 .70925 m .69526 .71009 L .69754 .70956 L F
.604 .947 .791 r
.47515 .86427 m .47437 .86524 L .4762 .8639 L F
0 0 0 r
.47515 .86427 m .473 .8691 L .47437 .86524 L F
.47644 .87012 m .47552 .8705 L .47638 .87034 L F
.272 .766 .901 r
.47428 .87024 m .4751 .86978 L .47638 .87034 L F
.526 0 0 r
.47627 .87072 m .47638 .87034 L .4751 .86978 L F
.47704 .87135 m .47638 .87034 L .47627 .87072 L F
0 0 0 r
.47738 .86973 m .47644 .87012 L .47638 .87034 L F
.103 .646 .842 r
.47638 .87034 m .47552 .8705 L .47428 .87024 L F
.416 0 .09 r
.57419 .77481 m .57653 .77458 L .57766 .77303 L F
.602 .144 .137 r
.57653 .77458 m .58013 .77466 L .57766 .77303 L F
.97 .68 .274 r
.56451 .83894 m .56483 .84119 L .56406 .84012 L F
.56451 .83894 m .56406 .84012 L .56445 .83931 L F
.562 .633 .88 r
.50652 .82214 m .50703 .81982 L .50488 .82029 L F
.50652 .82214 m .50822 .82188 L .50703 .81982 L F
.504 .691 .952 r
.70072 .70348 m .69956 .70498 L .69861 .70219 L F
.70072 .70348 m .7022 .70528 L .69956 .70498 L F
.365 .489 .851 r
.69956 .70498 m .70072 .70348 L .6988 .70462 L F
.564 .132 .179 r
.7022 .70528 m .70133 .70561 L .69956 .70498 L F
.365 .489 .851 r
.69956 .70498 m .70133 .70561 L .70072 .70348 L F
.698 .505 .623 r
.41616 .86247 m .41921 .8653 L .41819 .86181 L F
.41616 .86247 m .41615 .86696 L .41921 .8653 L F
.506 .12 .242 r
.64832 .70629 m .64712 .7077 L .65022 .70661 L F
.734 .643 .758 r
.49328 .82596 m .49346 .82813 L .49535 .82528 L F
.383 0 .053 r
.34505 .73018 m .34711 .72998 L .34859 .72839 L F
.284 0 0 r
.34711 .72998 m .35059 .72807 L .34859 .72839 L F
.542 .263 .441 r
.41672 .76467 m .41597 .76748 L .41381 .76769 L F
.534 .271 .463 r
.41872 .76396 m .41597 .76748 L .41672 .76467 L F
.724 .605 .724 r
.53183 .81517 m .52975 .81788 L .53222 .81589 L F
.505 .425 .7 r
.52975 .81788 m .53198 .81952 L .53222 .81589 L F
.586 .658 .887 r
.53222 .81589 m .53372 .81458 L .53183 .81517 L F
.53222 .81589 m .53368 .81598 L .53372 .81458 L F
.514 .293 .517 r
.53198 .81952 m .53368 .81598 L .53222 .81589 L F
.627 .664 .866 r
.48594 .83273 m .48396 .83303 L .48238 .83062 L F
.132 .388 .842 r
.66703 .7099 m .66956 .71155 L .66869 .71223 L F
0 0 .47 r
.67007 .71394 m .66869 .71223 L .66956 .71155 L F
.67007 .71394 m .67042 .71457 L .66869 .71223 L F
.903 .796 .732 r
.62172 .79706 m .62301 .79409 L .62192 .793 L F
0 .206 .671 r
.65997 .7099 m .66188 .71102 L .65957 .70911 L F
.595 .638 .864 r
.40808 .73705 m .40497 .73556 L .40675 .73545 L F
.618 .707 .909 r
.41001 .73645 m .40808 .73705 L .40675 .73545 L F
.726 .828 .928 r
.6676 .74903 m .66583 .7501 L .66468 .74902 L F
.052 .572 .872 r
.47391 .85107 m .47449 .85147 L .47278 .84965 L F
.47391 .85107 m .47626 .85181 L .47449 .85147 L F
.468 0 .039 r
.67328 .75989 m .67459 .76126 L .6721 .75977 L F
.67328 .75989 m .67559 .75999 L .67459 .76126 L F
.747 .64 .741 r
.52871 .81468 m .52975 .81788 L .53183 .81517 L F
.505 .425 .7 r
.52975 .81788 m .53057 .82031 L .53198 .81952 L F
.384 .162 .45 r
.33164 .68877 m .33053 .6916 L .32955 .69164 L F
.509 .404 .67 r
.33338 .68576 m .33259 .68852 L .33164 .68877 L F
.624 .411 .572 r
.33384 .691 m .33164 .68877 L .33259 .68852 L F
.33384 .691 m .33053 .6916 L .33164 .68877 L F
.739 .987 .782 r
.54975 .85051 m .55092 .85031 L .55047 .85011 L F
.55047 .85011 m .55103 .8503 L .5523 .84909 L F
.55092 .85031 m .55103 .8503 L .55047 .85011 L F
.54975 .85051 m .5523 .84909 L .55181 .85124 L F
.329 .458 .839 r
.54799 .84869 m .54975 .85051 L .5509 .85042 L F
.393 0 0 r
.54989 .84984 m .5509 .85042 L .5507 .85034 L F
.54799 .84869 m .5501 .84994 L .54989 .84984 L F
.5501 .84994 m .5509 .85042 L .54989 .84984 L F
.538 .402 .644 r
.6325 .73801 m .63374 .74145 L .63066 .74182 L F
.506 .369 .629 r
.63374 .74145 m .63121 .74391 L .63066 .74182 L F
.401 .027 .211 r
.36851 .79846 m .36533 .8011 L .36672 .79932 L F
.996 .859 .573 r
.59655 .81463 m .5973 .81518 L .59681 .81651 L F
.945 .939 .753 r
.59857 .81241 m .5973 .81518 L .59655 .81463 L F
.969 .661 .379 r
.56009 .81988 m .56162 .82295 L .56111 .82225 L F
.946 .714 .247 r
.56186 .82552 m .56111 .82225 L .56162 .82295 L F
.433 .258 .542 r
.47462 .84865 m .473 .84677 L .47496 .84639 L F
.47462 .84865 m .47278 .84965 L .473 .84677 L F
.401 .808 .598 r
.63762 .71422 m .63868 .71352 L .63602 .7153 L F
.1 0 0 r
.63977 .71393 m .63868 .71352 L .63762 .71422 L F
.63977 .71393 m .64064 .71269 L .63868 .71352 L F
.723 .837 .393 r
.48647 .8482 m .48595 .84954 L .4871 .84744 L F
.48647 .8482 m .48595 .84954 L .4871 .84744 L F
.22 .108 .507 r
.4871 .84744 m .48689 .85147 L .48595 .84954 L F
.4871 .84744 m .48796 .85136 L .48689 .85147 L F
.564 .047 0 r
.48998 .84831 m .49118 .84886 L .4871 .84744 L F
.623 .378 .526 r
.49118 .84886 m .48796 .85136 L .4871 .84744 L F
.756 .834 .912 r
.63638 .77259 m .63965 .77217 L .63908 .7701 L F
.792 .798 .857 r
.63908 .7701 m .63965 .77217 L .64208 .76991 L F
0 0 .418 r
.56483 .84119 m .56535 .84438 L .56527 .84319 L F
0 .215 .732 r
.56535 .84438 m .56701 .8453 L .56527 .84319 L F
.556 .6 .853 r
.56535 .84438 m .56892 .84672 L .56795 .84664 L F
0 .215 .732 r
.56535 .84438 m .56795 .84664 L .56701 .8453 L F
.421 .764 .996 r
.56892 .84672 m .57109 .84661 L .56991 .84585 L F
.509 .907 .92 r
.56795 .84664 m .56892 .84672 L .56991 .84585 L F
.421 .764 .996 r
.56892 .84672 m .57109 .84661 L .56991 .84585 L F
.765 .538 .59 r
.50198 .83353 m .49977 .8354 L .49977 .83336 L F
.50198 .83353 m .49977 .83336 L .50247 .83371 L F
.491 .216 .424 r
.50464 .83289 m .50198 .83353 L .50247 .83371 L F
.50464 .83289 m .50421 .83545 L .50225 .83377 L F
.50258 .83339 m .50225 .83377 L .50198 .83353 L F
.728 .534 .628 r
.50244 .83356 m .50247 .83371 L .50232 .83369 L F
.587 .446 .656 r
.50464 .83289 m .50247 .83371 L .50244 .83356 L F
.491 .216 .424 r
.50464 .83289 m .50244 .83356 L .50258 .83339 L F
.587 .446 .656 r
.50464 .83289 m .50244 .83356 L .50176 .83074 L F
.491 .216 .424 r
.50464 .83289 m .50225 .83377 L .50244 .83356 L F
.728 .534 .628 r
.50176 .83074 m .50244 .83356 L .49977 .83336 L F
.50244 .83356 m .50232 .83369 L .49977 .83336 L F
0 0 .103 r
.50176 .83074 m .50443 .82752 L .50066 .8278 L F
.50176 .83074 m .5031 .83044 L .50443 .82752 L F
.587 .446 .656 r
.50464 .83289 m .50176 .83074 L .50507 .83086 L F
.612 .34 .481 r
.50065 .83217 m .5031 .83044 L .50176 .83074 L F
.768 .264 0 r
.67241 .73252 m .67633 .73531 L .67323 .73339 L F
.331 .669 .975 r
.68941 .72631 m .68786 .72693 L .6867 .72578 L F
.68941 .72631 m .69059 .7274 L .68786 .72693 L F
.335 .123 .436 r
.33053 .6916 m .32925 .6938 L .32955 .69164 L F
.497 .906 .849 r
.70119 .74096 m .69974 .74182 L .6993 .74189 L F
.70119 .74096 m .69974 .74182 L .6993 .74189 L F
.752 .577 .658 r
.39627 .8833 m .39867 .88379 L .39833 .88086 L F
.618 .487 .679 r
.39867 .88379 m .40052 .88031 L .39833 .88086 L F
0 0 .489 r
.39436 .88633 m .39467 .88303 L .39336 .88351 L F
.39436 .88633 m .39509 .88609 L .39467 .88303 L F
.094 .342 .813 r
.39436 .88633 m .39625 .88776 L .39509 .88609 L F
.579 .63 .866 r
.39381 .88804 m .39625 .88776 L .39436 .88633 L F
.28 .749 .942 r
.51686 .82412 m .51741 .82423 L .51916 .82396 L F
.451 .096 .271 r
.51741 .82423 m .51804 .8273 L .51916 .82396 L F
.516 .238 .432 r
.38974 .78479 m .3879 .78349 L .39008 .78315 L F
.38974 .78479 m .38722 .78613 L .3879 .78349 L F
.351 .753 .984 r
.52993 .81487 m .53183 .81517 L .53077 .81454 L F
.494 .827 .999 r
.53077 .81454 m .53183 .81517 L .53372 .81458 L F
.689 .35 .397 r
.53372 .81458 m .53281 .81663 L .53077 .81454 L F
.238 .311 .736 r
.53077 .81454 m .53281 .81663 L .532 .81406 L F
.53077 .81454 m .532 .81406 L .5318 .81343 L F
.351 .753 .984 r
.52871 .81468 m .52993 .81487 L .53077 .81454 L F
.446 .703 .976 r
.43028 .75033 m .43032 .75183 L .42967 .7494 L F
.43028 .75033 m .43233 .75179 L .43032 .75183 L F
.553 .391 .616 r
.43233 .75179 m .43052 .75408 L .43032 .75183 L F
.564 .276 .436 r
.40478 .773 m .40414 .77536 L .40194 .77544 L F
.54 .279 .468 r
.40681 .77275 m .40414 .77536 L .40478 .773 L F
.347 .226 .569 r
.63601 .71777 m .63762 .71422 L .63602 .7153 L F
.439 .556 .877 r
.53054 .826 m .53152 .82844 L .53261 .82764 L F
0 0 .354 r
.53176 .83057 m .53261 .82764 L .53152 .82844 L F
.093 .25 .734 r
.71325 .70888 m .71203 .70933 L .71044 .70667 L F
.71325 .70888 m .71293 .70963 L .71203 .70933 L F
.774 .76 .84 r
.65343 .76384 m .655 .76496 L .6573 .76268 L F
.228 0 .028 r
.38772 .74533 m .38702 .74619 L .38513 .74657 L F
.64 .639 .833 r
.40664 .73347 m .40466 .73402 L .40379 .73181 L F
.492 .348 .613 r
.40664 .73347 m .40497 .73556 L .40466 .73402 L F
.68 .812 .946 r
.56618 .8121 m .56453 .81318 L .56302 .81198 L F
0 0 0 r
.60087 .84347 m .60195 .84296 L .60045 .84398 L F
.60087 .84347 m .60367 .8418 L .60195 .84296 L F
.402 .324 .654 r
.71293 .70963 m .71359 .71177 L .71128 .71318 L F
.146 0 .236 r
.71359 .71177 m .71166 .71418 L .71128 .71318 L F
.66 .718 .891 r
.70786 .70589 m .705 .70481 L .70742 .70427 L F
.504 .589 .873 r
.70921 .70405 m .70786 .70589 L .70742 .70427 L F
.70921 .70405 m .71044 .70667 L .70786 .70589 L F
.522 .435 .698 r
.52272 .83562 m .52425 .83301 L .52206 .83328 L F
.52272 .83562 m .52481 .83555 L .52425 .83301 L F
.492 .348 .613 r
.40664 .73347 m .40675 .73545 L .40497 .73556 L F
.938 .594 .349 r
.71182 .72764 m .7131 .72786 L .71317 .72962 L F
.825 .651 .666 r
.71317 .72962 m .71429 .72865 L .71182 .72764 L F
.595 .022 0 r
.71429 .72865 m .71319 .72792 L .71329 .72825 L F
.908 .867 .787 r
.71317 .72962 m .71429 .72865 L .71355 .72708 L F
.71317 .72962 m .71335 .72843 L .71331 .73032 L F
.71335 .72843 m .71355 .72708 L .71343 .72869 L F
.71335 .72843 m .71343 .72869 L .71331 .73032 L F
.595 .022 0 r
.71329 .72825 m .7131 .72786 L .71182 .72764 L F
.71319 .72792 m .7131 .72786 L .71329 .72825 L F
.85 .739 .74 r
.49615 .8442 m .4948 .84739 L .4932 .84451 L F
.49615 .8442 m .4932 .84451 L .4965 .84577 L F
.764 .266 0 r
.49615 .8442 m .4965 .84577 L .49618 .84533 L F
.49615 .8442 m .49618 .84533 L .49926 .84298 L F
.625 .496 .684 r
.42682 .85118 m .42888 .84863 L .42696 .84917 L F
.951 .678 .484 r
.5888 .78626 m .58743 .78568 L .58739 .78346 L F
.724 .334 .31 r
.5888 .78626 m .58754 .78791 L .58743 .78568 L F
.5888 .78626 m .59074 .78827 L .58754 .78791 L F
.346 .194 .527 r
.60367 .8418 m .60503 .8387 L .60461 .84081 L F
.551 .895 .66 r
.60195 .84296 m .60367 .8418 L .60461 .84081 L F
.608 .537 .75 r
.40475 .87294 m .40764 .87549 L .40703 .87241 L F
.941 .747 .614 r
.67115 .72558 m .67068 .72775 L .67211 .72834 L F
.67115 .72558 m .67068 .72775 L .67211 .72834 L F
.994 .772 .406 r
.67135 .72983 m .67211 .72834 L .67068 .72775 L F
.67135 .72983 m .67202 .73068 L .67211 .72834 L F
.596 .507 .725 r
.42099 .74913 m .41889 .7496 L .41833 .74694 L F
.333 .807 .738 r
.48442 .88473 m .48666 .88406 L .48518 .88465 L F
.124 0 0 r
.48666 .88406 m .48719 .88458 L .48518 .88465 L F
.48666 .88406 m .48868 .88367 L .48719 .88458 L F
.633 .268 .332 r
.56541 .77992 m .56151 .78033 L .56254 .78065 L F
.586 .413 .615 r
.48897 .82257 m .48875 .82519 L .49016 .8253 L F
.677 .568 .725 r
.49016 .8253 m .49328 .82596 L .49207 .82289 L F
.71 .504 .608 r
.49973 .83099 m .49685 .83292 L .49663 .83124 L F
.49973 .83099 m .49977 .83336 L .49685 .83292 L F
.653 .707 .887 r
.523 .82533 m .52034 .82621 L .51916 .82396 L F
.639 .422 .573 r
.523 .82533 m .52015 .82775 L .52034 .82621 L F
.177 0 0 r
.51018 .8829 m .51357 .88167 L .51233 .88324 L F
.347 0 .119 r
.51357 .88167 m .51444 .88302 L .51233 .88324 L F
.51357 .88167 m .51565 .88119 L .51444 .88302 L F
.771 .885 .927 r
.52006 .84425 m .51937 .84648 L .52122 .84473 L F
.52006 .84425 m .51669 .84705 L .51937 .84648 L F
.777 .781 .856 r
.40981 .88854 m .41098 .88994 L .41158 .88971 L F
.743 .791 .891 r
.40981 .88854 m .41158 .88971 L .41322 .88841 L F
.718 .689 .821 r
.38805 .89074 m .38929 .893 L .39004 .8919 L F
.596 .507 .725 r
.42099 .74913 m .41833 .74694 L .42005 .74634 L F
.327 0 0 r
.6686 .74237 m .66828 .74305 L .66539 .74279 L F
.777 .281 0 r
.6686 .74237 m .66942 .74378 L .66828 .74305 L F
.291 0 0 r
.62484 .7374 m .62577 .73794 L .62685 .73631 L F
.62484 .7374 m .6236 .73835 L .62577 .73794 L F
.17 .7 .852 r
.42268 .88762 m .42387 .88755 L .42234 .88738 L F
.522 .783 .992 r
.41354 .73708 m .41001 .73645 L .41206 .73603 L F
.65 .813 .962 r
.41533 .73633 m .41354 .73708 L .41206 .73603 L F
.651 .49 .653 r
.40395 .75726 m .40621 .75698 L .40609 .75458 L F
.607 .438 .628 r
.40621 .75698 m .4087 .75423 L .40609 .75458 L F
.528 .715 .958 r
.38156 .72492 m .38092 .72661 L .37954 .72533 L F
.38156 .72492 m .38312 .72632 L .38092 .72661 L F
.698 .652 .801 r
.63666 .74421 m .63777 .7471 L .63433 .74642 L F
.779 .692 .768 r
.63987 .74447 m .63777 .7471 L .63666 .74421 L F
.017 0 0 r
.67851 .75934 m .68095 .75782 L .68003 .75902 L F
.67851 .75934 m .68003 .75902 L .67779 .75975 L F
.252 0 .027 r
.67779 .75975 m .68003 .75902 L .67905 .76063 L F
.994 .843 .486 r
.67913 .76019 m .68003 .75902 L .67944 .75835 L F
.67905 .76063 m .68003 .75902 L .67913 .76019 L F
.017 0 0 r
.68095 .75782 m .68119 .75766 L .68003 .75902 L F
.854 .83 .823 r
.68119 .75766 m .68188 .75403 L .68139 .75601 L F
.68119 .75766 m .68328 .75483 L .68188 .75403 L F
.895 .94 .573 r
.68003 .75902 m .68119 .75766 L .68139 .75601 L F
.511 .428 .699 r
.4087 .75423 m .41009 .75114 L .40883 .75182 L F
.334 .422 .804 r
.52505 .87373 m .52582 .8756 L .52723 .87501 L F
.413 .738 .992 r
.52582 .8756 m .52899 .87604 L .52723 .87501 L F
.655 .128 0 r
.50443 .82752 m .50595 .82848 L .50728 .82835 L F
.619 .434 .609 r
.50728 .82835 m .5073 .83076 L .50507 .83086 L F
.598 .178 .216 r
.50595 .82848 m .50935 .82802 L .50728 .82835 L F
.602 .45 .648 r
.50935 .82802 m .5073 .83076 L .50728 .82835 L F
.929 .625 .445 r
.55941 .7784 m .55953 .78124 L .55825 .78004 L F
.775 .599 .662 r
.55825 .78004 m .56126 .77801 L .55941 .7784 L F
.549 .304 .496 r
.38102 .78904 m .38055 .79112 L .37848 .79125 L F
.368 .139 .43 r
.38265 .78845 m .38055 .79112 L .38102 .78904 L F
.579 .654 .887 r
.38951 .72823 m .38586 .72635 L .38838 .72729 L F
.128 .639 .896 r
.38838 .72729 m .39154 .72793 L .38951 .72823 L F
.632 .321 .426 r
.54861 .7831 m .55075 .78378 L .55172 .78106 L F
.439 .648 .947 r
.55302 .78031 m .55446 .78142 L .55172 .78106 L F
.052 0 .162 r
.55172 .78106 m .55446 .78142 L .55302 .78031 L F
.55172 .78106 m .55075 .78378 L .55267 .78192 L F
.662 .419 .542 r
.50397 .84415 m .50748 .84406 L .50742 .84146 L F
.711 .458 .541 r
.50742 .84146 m .50748 .84406 L .50938 .844 L F
.669 .535 .692 r
.50742 .84146 m .50984 .84139 L .50944 .83895 L F
.659 .452 .592 r
.50742 .84146 m .50938 .844 L .50984 .84139 L F
.95 .811 .365 r
.676 .72313 m .67569 .72564 L .67535 .72463 L F
.827 .618 .066 r
.676 .72313 m .67578 .7225 L .67562 .72006 L F
.911 .823 .357 r
.676 .72313 m .67535 .72463 L .67578 .7225 L F
.739 .437 .47 r
.56046 .79937 m .56345 .80171 L .56396 .79941 L F
.639 .339 .446 r
.56396 .79941 m .56345 .80171 L .56546 .80141 L F
.588 .511 .736 r
.64381 .72604 m .64611 .72569 L .64466 .72193 L F
.271 0 .262 r
.35881 .78836 m .35954 .79015 L .3608 .78806 L F
.35881 .78836 m .35792 .79079 L .35954 .79015 L F
0 0 0 r
.5523 .84909 m .55419 .84628 L .55258 .849 L F
.55181 .85124 m .5523 .84909 L .55258 .849 L F
0 0 .173 r
.49065 .87358 m .49047 .87329 L .49077 .87226 L F
.546 0 0 r
.48718 .83515 m .48896 .83591 L .48884 .83554 L F
.063 .57 .884 r
.48963 .83473 m .49034 .83488 L .49013 .83503 L F
0 0 .02 r
.48973 .83531 m .49013 .83503 L .49368 .8343 L F
.873 .733 .704 r
.49368 .8343 m .49013 .83503 L .4914 .83312 L F
.356 .104 .387 r
.49013 .83503 m .49199 .83524 L .49188 .83407 L F
.063 .57 .884 r
.49034 .83488 m .49199 .83524 L .49013 .83503 L F
0 0 .02 r
.48884 .83554 m .49013 .83503 L .48973 .83531 L F
.48884 .83554 m .48896 .83591 L .49013 .83503 L F
.597 .408 .597 r
.42888 .84863 m .43002 .84652 L .42895 .84675 L F
.431 .102 .306 r
.46645 .8333 m .46852 .83292 L .46937 .83057 L F
.151 0 .179 r
.46937 .83057 m .47001 .83207 L .47151 .83015 L F
.46937 .83057 m .46852 .83292 L .47001 .83207 L F
.588 .818 .987 r
.57109 .84661 m .5742 .84695 L .57335 .84604 L F
.025 .461 .875 r
.57335 .84604 m .5742 .84695 L .57507 .84724 L F
.5752 .84721 m .57507 .84724 L .57549 .84739 L F
.57335 .84604 m .57507 .84724 L .5752 .84721 L F
.364 .543 .897 r
.57562 .84709 m .57783 .84741 L .57698 .84709 L F
.025 .461 .875 r
.57335 .84604 m .57488 .847 L .57554 .84728 L F
.57488 .847 m .57549 .84739 L .57552 .84731 L F
.364 .543 .897 r
.57527 .84719 m .57612 .8476 L .57783 .84741 L F
.025 .461 .875 r
.57488 .847 m .57552 .84731 L .57554 .84728 L F
.57554 .84728 m .57549 .84739 L .57612 .8476 L F
.364 .543 .897 r
.57417 .8471 m .57612 .8476 L .57527 .84719 L F
.025 .461 .875 r
.57335 .84604 m .57535 .84717 L .57417 .8471 L F
.364 .543 .897 r
.57417 .8471 m .57527 .84719 L .57535 .84717 L F
.025 .461 .875 r
.57535 .84717 m .57612 .8476 L .57417 .8471 L F
.364 .543 .897 r
.57417 .8471 m .57535 .84717 L .57562 .84709 L F
.57527 .84719 m .57783 .84741 L .57562 .84709 L F
.136 .593 .925 r
.57351 .84596 m .57417 .8471 L .57562 .84709 L F
.5758 .84671 m .57562 .84709 L .57698 .84709 L F
.57351 .84596 m .57562 .84709 L .5758 .84671 L F
.816 .631 .652 r
.51433 .87761 m .51723 .87834 L .51759 .87568 L F
.788 .727 .796 r
.5306 .85103 m .52923 .85352 L .52806 .85195 L F
.952 .601 .279 r
.52806 .85195 m .52923 .85352 L .52848 .85375 L F
.514 .834 .999 r
.54319 .86184 m .54459 .86246 L .54212 .86291 L F
.54212 .86291 m .54459 .86246 L .54319 .86184 L F
.776 .702 .781 r
.63987 .74447 m .63666 .74421 L .63876 .74175 L F
.747 .688 .794 r
.64234 .7423 m .63987 .74447 L .63876 .74175 L F
.251 .744 .914 r
.47937 .82611 m .48138 .82595 L .48288 .82613 L F
.121 0 0 r
.47784 .8272 m .48138 .82595 L .47937 .82611 L F
.242 0 0 r
.56571 .77699 m .56929 .77615 L .56704 .77625 L F
.464 .061 .19 r
.56704 .77625 m .56929 .77615 L .57008 .77558 L F
.736 .487 .552 r
.46708 .85422 m .46861 .85706 L .46935 .85481 L F
.604 .349 .504 r
.46935 .85481 m .46861 .85706 L .47103 .85529 L F
.1 0 0 r
.36553 .72407 m .36825 .72393 L .36714 .72439 L F
.432 .491 .82 r
.68224 .71489 m .68136 .71215 L .68091 .71325 L F
.672 .598 .764 r
.39697 .88923 m .39813 .89207 L .40035 .89165 L F
.783 .661 .728 r
.38805 .89074 m .39164 .89079 L .3904 .88832 L F
.38805 .89074 m .39004 .8919 L .39164 .89079 L F
.813 .763 .806 r
.3904 .88832 m .39164 .89079 L .39381 .88804 L F
.64 .475 .644 r
.40181 .75992 m .40404 .75978 L .40395 .75726 L F
.601 .417 .606 r
.40404 .75978 m .40621 .75698 L .40395 .75726 L F
.731 .623 .738 r
.64469 .71205 m .64329 .71454 L .64368 .71263 L F
.619 .395 .556 r
.33727 .68056 m .3347 .68275 L .33571 .68124 L F
.653 .453 .6 r
.60243 .76488 m .60548 .76481 L .60551 .76257 L F
.667 .464 .601 r
.60548 .76481 m .60771 .76249 L .60551 .76257 L F
.36 .516 .877 r
.67744 .73523 m .67618 .73642 L .67633 .73531 L F
.768 .264 0 r
.67241 .73252 m .67499 .73493 L .67633 .73531 L F
.514 .784 .994 r
.67689 .73575 m .67783 .73616 L .67651 .73637 L F
.67649 .73613 m .67651 .73637 L .67618 .73642 L F
.67689 .73575 m .67651 .73637 L .67649 .73613 L F
0 0 .4 r
.6764 .73481 m .67715 .73695 L .67645 .73454 L F
.67633 .73531 m .67645 .73454 L .67744 .73523 L F
.67633 .73531 m .67645 .73556 L .6764 .73481 L F
.67645 .73556 m .67715 .73695 L .6764 .73481 L F
.768 .264 0 r
.67499 .73493 m .67715 .73695 L .67645 .73556 L F
.67499 .73493 m .67645 .73556 L .67633 .73531 L F
.514 .784 .994 r
.67744 .73523 m .67869 .73603 L .67783 .73616 L F
.67744 .73523 m .67783 .73616 L .67689 .73575 L F
0 0 .297 r
.71445 .73857 m .71474 .7408 L .71354 .74174 L F
.143 0 .329 r
.71637 .73781 m .71474 .7408 L .71445 .73857 L F
.63 .873 .987 r
.54258 .79894 m .53921 .79961 L .53793 .79888 L F
0 .208 .717 r
.53977 .80078 m .53793 .79888 L .53921 .79961 L F
.612 .943 .943 r
.36461 .74837 m .36395 .74942 L .36608 .74836 L F
.36461 .74837 m .36395 .74942 L .36608 .74836 L F
.358 .179 .497 r
.36665 .75119 m .36395 .74942 L .36608 .74836 L F
.662 .364 .458 r
.48102 .84499 m .4807 .84652 L .47746 .84649 L F
.728 .429 .473 r
.48484 .84654 m .4807 .84652 L .48102 .84499 L F
.27 0 0 r
.47626 .85181 m .47837 .85151 L .47897 .85082 L F
.637 .862 .491 r
.47897 .85082 m .48033 .84888 L .48164 .85171 L F
.47897 .85082 m .47837 .85151 L .48033 .84888 L F
.447 .315 .607 r
.5297 .82285 m .53198 .81952 L .53057 .82031 L F
.5297 .82285 m .5329 .82289 L .53198 .81952 L F
.3 .226 .604 r
.5297 .82285 m .53214 .82462 L .5329 .82289 L F
.5297 .82285 m .53054 .826 L .53214 .82462 L F
.621 .556 .76 r
.40997 .74747 m .41035 .74916 L .41216 .74711 L F
.943 .584 .198 r
.67731 .72835 m .67708 .73001 L .67645 .7276 L F
.67731 .72835 m .67798 .73072 L .67708 .73001 L F
.55 .628 .882 r
.33624 .67512 m .33859 .67469 L .33776 .67368 L F
.468 .53 .838 r
.33721 .67494 m .3368 .67587 L .33624 .67512 L F
.33721 .67494 m .33833 .67554 L .3368 .67587 L F
.205 0 0 r
.33836 .67483 m .33858 .67469 L .33721 .67494 L F
.33858 .67469 m .33859 .67469 L .33634 .6751 L F
.33635 .6751 m .33634 .6751 L .33624 .67512 L F
.33858 .67469 m .33634 .6751 L .33635 .6751 L F
.45 .586 .897 r
.33776 .67368 m .33859 .67469 L .33998 .67431 L F
.507 .557 .841 r
.33998 .67431 m .33949 .67467 L .33776 .67368 L F
.756 .401 .381 r
.33859 .67469 m .33887 .67504 L .33998 .67431 L F
.507 .557 .841 r
.33949 .67467 m .33888 .67505 L .33942 .67468 L F
.33888 .67505 m .3383 .67542 L .33887 .67504 L F
.33888 .67505 m .33887 .67504 L .33942 .67468 L F
.33949 .67467 m .33833 .67554 L .3383 .67542 L F
.45 .416 .73 r
.33833 .67554 m .3391 .67777 L .3368 .67587 L F
.507 .418 .689 r
.3368 .67587 m .3391 .67777 L .33731 .6783 L F
.232 .207 .624 r
.33998 .67431 m .3391 .67777 L .33833 .67554 L F
.33961 .67578 m .34014 .6776 L .3391 .67777 L F
.33998 .67431 m .34008 .67661 L .33961 .67578 L F
.756 .401 .381 r
.33887 .67504 m .34008 .67661 L .33998 .67431 L F
.34008 .67661 m .34012 .67666 L .33998 .67431 L F
.503 .421 .696 r
.34018 .67758 m .34014 .6776 L .33998 .67431 L F
.232 .207 .624 r
.34009 .67664 m .34014 .6776 L .33961 .67578 L F
.756 .401 .381 r
.33993 .67647 m .33644 .67671 L .34023 .67687 L F
.33887 .67504 m .33866 .67518 L .33993 .67647 L F
.33866 .67518 m .33644 .67671 L .33993 .67647 L F
.503 .421 .696 r
.34228 .67642 m .34073 .67728 L .33998 .67431 L F
.34073 .67728 m .34018 .67758 L .34012 .67666 L F
.34073 .67728 m .34012 .67666 L .33998 .67431 L F
.756 .401 .381 r
.34012 .67666 m .34028 .67687 L .33998 .67431 L F
.232 .207 .624 r
.33998 .67431 m .34009 .67664 L .34008 .67661 L F
.756 .401 .381 r
.34008 .67661 m .34023 .67687 L .34028 .67687 L F
.33887 .67504 m .34023 .67687 L .34008 .67661 L F
.33859 .67469 m .33847 .6748 L .33887 .67504 L F
.507 .557 .841 r
.33942 .67468 m .3383 .67542 L .33812 .67486 L F
.468 .53 .838 r
.33812 .67486 m .33833 .67554 L .33721 .67494 L F
.756 .401 .381 r
.33847 .6748 m .33644 .67671 L .33887 .67504 L F
.507 .557 .841 r
.33949 .67467 m .33812 .67486 L .33776 .67368 L F
.468 .53 .838 r
.33776 .67368 m .33812 .67486 L .33721 .67494 L F
.205 0 0 r
.33464 .67717 m .33836 .67483 L .33624 .67512 L F
.33836 .67483 m .33721 .67494 L .33624 .67512 L F
.468 .53 .838 r
.33776 .67368 m .33721 .67494 L .33624 .67512 L F
.591 .418 .615 r
.60996 .75983 m .61222 .75961 L .61206 .75725 L F
.562 .383 .597 r
.60996 .75983 m .61229 .76171 L .61222 .75961 L F
.60996 .75983 m .61011 .76218 L .61229 .76171 L F
0 0 .189 r
.48326 .85641 m .48282 .85462 L .48367 .85367 L F
.48326 .85641 m .48235 .85722 L .48282 .85462 L F
.34 0 .186 r
.40052 .88031 m .4021 .88031 L .40346 .87829 L F
.771 .464 .468 r
.40346 .87829 m .40442 .87943 L .40535 .87828 L F
.40346 .87829 m .4021 .88031 L .40442 .87943 L F
.762 .7 .793 r
.6492 .74034 m .64623 .73904 L .64831 .7382 L F
.6492 .74034 m .64725 .74157 L .64623 .73904 L F
.519 .6 .875 r
.65049 .73785 m .6492 .74034 L .64831 .7382 L F
.65049 .73785 m .65192 .7411 L .6492 .74034 L F
.014 0 0 r
.37499 .74985 m .37304 .75035 L .37092 .75061 L F
.186 0 0 r
.37528 .75003 m .37673 .74989 L .37507 .75012 L F
.047 0 0 r
.37774 .74947 m .37507 .75012 L .37304 .75035 L F
.186 0 0 r
.37875 .74847 m .37507 .75012 L .37774 .74947 L F
.37875 .74847 m .37678 .74985 L .37528 .75003 L F
.37678 .74985 m .37673 .74989 L .37528 .75003 L F
.047 0 0 r
.37753 .7495 m .37383 .7502 L .37499 .74985 L F
.37749 .74951 m .37383 .7502 L .37753 .7495 L F
.514 .871 .634 r
.37931 .74787 m .37677 .74985 L .37875 .74847 L F
.37677 .74985 m .37673 .74989 L .37678 .74985 L F
.37677 .74985 m .37678 .74985 L .37875 .74847 L F
.047 0 0 r
.37774 .74947 m .37749 .74951 L .37753 .7495 L F
.37383 .7502 m .37304 .75035 L .37344 .75025 L F
.37383 .7502 m .37344 .75025 L .37499 .74985 L F
.876 .453 .035 r
.6937 .71984 m .6936 .71857 L .69309 .71873 L F
.6937 .71984 m .69467 .72052 L .6936 .71857 L F
.865 .885 .848 r
.51182 .85408 m .51302 .85472 L .51096 .85642 L F
.388 .849 .834 r
.51512 .85397 m .51302 .85472 L .51454 .85396 L F
.428 .788 .996 r
.51454 .85396 m .51302 .85472 L .51182 .85408 L F
.652 .663 .848 r
.66239 .75105 m .66028 .75166 L .65906 .74911 L F
.483 .236 .463 r
.41346 .76948 m .4118 .76796 L .41381 .76769 L F
.41346 .76948 m .41143 .76994 L .4118 .76796 L F
.73 .931 .594 r
.71474 .7408 m .7128 .74372 L .71354 .74174 L F
.762 .673 .764 r
.54625 .84643 m .54727 .84957 L .54409 .8492 L F
.694 .265 .226 r
.54409 .8492 m .54727 .84957 L .54835 .85221 L F
.381 .112 .375 r
.54835 .85221 m .54727 .84957 L .54975 .85051 L F
.471 0 0 r
.58856 .77601 m .59092 .77677 L .59158 .77566 L F
.629 .306 .404 r
.59092 .77677 m .59321 .775 L .59158 .77566 L F
.907 .499 .138 r
.5131 .83747 m .51418 .83883 L .5146 .83833 L F
.5131 .83747 m .51418 .83883 L .5146 .83833 L F
.714 .652 .787 r
.68224 .71489 m .68507 .71345 L .68402 .71182 L F
.777 .781 .856 r
.40981 .88854 m .40787 .89073 L .41098 .88994 L F
.609 .647 .863 r
.4932 .84451 m .4948 .84739 L .49308 .84672 L F
.699 .399 .465 r
.49521 .84817 m .49308 .84672 L .4948 .84739 L F
.644 .263 .308 r
.49725 .84794 m .4948 .84739 L .49889 .84816 L F
.49725 .84794 m .49521 .84817 L .4948 .84739 L F
.169 0 .034 r
.34587 .75415 m .34426 .75644 L .34276 .75682 L F
.504 .14 .283 r
.3479 .75389 m .34426 .75644 L .34587 .75415 L F
.873 .733 .704 r
.49368 .8343 m .49147 .83316 L .49438 .83347 L F
.49147 .83316 m .49151 .83314 L .49438 .83347 L F
.799 .729 .787 r
.49438 .83347 m .4914 .83312 L .49295 .83223 L F
.75 .731 .835 r
.49663 .83124 m .49438 .83347 L .49295 .83223 L F
.393 .028 .221 r
.49358 .83216 m .49188 .83407 L .49556 .83195 L F
.49295 .83223 m .49277 .83255 L .49358 .83216 L F
.49277 .83255 m .49188 .83407 L .49358 .83216 L F
.873 .733 .704 r
.49147 .83316 m .4914 .83312 L .49151 .83314 L F
.422 .53 .862 r
.39928 .72915 m .39831 .73085 L .39692 .72795 L F
.39928 .72915 m .4 .73096 L .39831 .73085 L F
.57 .233 .358 r
.49308 .84672 m .49118 .84886 L .48998 .84831 L F
.609 .647 .863 r
.4932 .84451 m .49308 .84672 L .49166 .84386 L F
.699 .399 .465 r
.49521 .84817 m .49118 .84886 L .49308 .84672 L F
.708 .296 0 r
.46766 .85563 m .46861 .85706 L .46837 .85662 L F
.46766 .85563 m .46837 .85662 L .46708 .85422 L F
.46766 .85563 m .46708 .85422 L .46729 .85438 L F
.454 .01 .103 r
.47128 .85395 m .46766 .85563 L .46729 .85438 L F
.821 .947 .904 r
.4682 .85396 m .46714 .8549 L .46766 .85563 L F
.46714 .8549 m .46615 .85579 L .46766 .85563 L F
.644 .741 .919 r
.64725 .74157 m .64395 .74095 L .64623 .73904 L F
.633 .438 .601 r
.42222 .8571 m .42565 .85718 L .42547 .8547 L F
.621 .492 .685 r
.42547 .8547 m .42773 .85456 L .42682 .85118 L F
.68 .473 .599 r
.42547 .8547 m .42783 .85692 L .42773 .85456 L F
.42547 .8547 m .42565 .85718 L .42783 .85692 L F
.605 .445 .639 r
.61206 .75725 m .61442 .75688 L .61425 .75445 L F
.627 .445 .616 r
.61206 .75725 m .61487 .75918 L .61442 .75688 L F
.61206 .75725 m .61222 .75961 L .61487 .75918 L F
.002 .31 .801 r
.5761 .82241 m .57381 .82068 L .57367 .81977 L F
.532 .122 .209 r
.36665 .75119 m .36548 .75311 L .36331 .75317 L F
.151 .068 .5 r
.36806 .74841 m .36665 .75119 L .36608 .74836 L F
.36806 .74841 m .36791 .75136 L .36665 .75119 L F
.175 0 .015 r
.36791 .75136 m .36548 .75311 L .36665 .75119 L F
.903 .965 .644 r
.51705 .8561 m .51688 .8576 L .51844 .85455 L F
.095 0 .377 r
.51832 .8555 m .51767 .85448 L .51834 .85291 L F
.51767 .85448 m .51727 .85386 L .51823 .85301 L F
.51767 .85448 m .51823 .85301 L .51834 .85291 L F
.903 .965 .644 r
.51679 .85639 m .51682 .85671 L .51705 .8561 L F
.51682 .85671 m .51688 .8576 L .51705 .8561 L F
.969 .93 .683 r
.71457 .73445 m .71453 .73523 L .71327 .73547 L F
.83 1 .807 r
.71327 .73547 m .71453 .73523 L .71151 .73817 L F
.728 .781 .895 r
.59527 .81995 m .59354 .82105 L .59215 .81994 L F
.112 .653 .845 r
.47781 .88422 m .48086 .88449 L .4795 .88401 L F
.087 .611 .876 r
.4795 .88401 m .48086 .88449 L .48442 .88473 L F
.216 0 0 r
.42635 .7507 m .4283 .75044 L .42967 .7494 L F
0 0 0 r
.4283 .75044 m .43028 .75033 L .42967 .7494 L F
.552 .63 .883 r
.42885 .74782 m .43027 .75017 L .4283 .75044 L F
0 0 0 r
.4283 .75044 m .43037 .75033 L .43028 .75033 L F
.552 .63 .883 r
.43027 .75017 m .43037 .75033 L .4283 .75044 L F
.216 0 0 r
.42614 .75078 m .4283 .75044 L .42635 .7507 L F
.686 .408 .496 r
.59393 .78619 m .59617 .78834 L .5941 .78803 L F
.627 .418 .579 r
.59621 .78606 m .59617 .78834 L .59393 .78619 L F
.731 .562 .663 r
.60519 .78391 m .60145 .78593 L .60144 .78355 L F
.60519 .78391 m .60489 .78612 L .60145 .78593 L F
.329 .402 .786 r
.38148 .93048 m .38192 .93077 L .38162 .93088 L F
.109 0 .235 r
.38162 .93088 m .38192 .93077 L .38144 .93149 L F
.476 .59 .888 r
.41816 .73709 m .42091 .73794 L .41917 .73812 L F
.564 .504 .747 r
.42091 .73794 m .41969 .74157 L .41917 .73812 L F
.742 .623 .726 r
.5293 .83931 m .52694 .84175 L .52902 .84132 L F
.67 .511 .661 r
.52688 .8439 m .52902 .84132 L .52694 .84175 L F
.52688 .8439 m .52911 .84386 L .52902 .84132 L F
.651 .519 .689 r
.52911 .84386 m .53232 .84188 L .52902 .84132 L F
.691 .478 .593 r
.39849 .76223 m .40173 .76222 L .40181 .75992 L F
.592 .372 .551 r
.40173 .76222 m .40404 .75978 L .40181 .75992 L F
.635 .483 .659 r
.41819 .86181 m .42134 .86262 L .42021 .85943 L F
.648 .509 .679 r
.41819 .86181 m .42144 .86491 L .42134 .86262 L F
.41819 .86181 m .41921 .8653 L .42144 .86491 L F
.564 .01 0 r
.48818 .84324 m .49012 .84403 L .49166 .84386 L F
.708 .318 .307 r
.49012 .84403 m .4932 .84451 L .49166 .84386 L F
.63 .873 .987 r
.54258 .79894 m .53793 .79888 L .53781 .79834 L F
.423 .802 .992 r
.53798 .79836 m .54375 .79855 L .54258 .79894 L F
.53803 .79835 m .54375 .79855 L .53798 .79836 L F
.53781 .79834 m .54226 .79804 L .54375 .79855 L F
.363 .792 .969 r
.53781 .79834 m .53912 .79783 L .54226 .79804 L F
.217 .342 .777 r
.53793 .79888 m .54034 .80079 L .53917 .79796 L F
.53884 .79807 m .53917 .79796 L .53912 .79783 L F
.53793 .79888 m .53917 .79796 L .53884 .79807 L F
.423 .802 .992 r
.53781 .79834 m .53803 .79835 L .53798 .79836 L F
.686 .681 .839 r
.54479 .79869 m .54258 .79894 L .54375 .79855 L F
.988 .812 .578 r
.59827 .8096 m .59857 .81241 L .59801 .81171 L F
.945 .939 .753 r
.59857 .81241 m .59655 .81463 L .59801 .81171 L F
.716 .718 .85 r
.64648 .76494 m .64975 .76538 L .6488 .7642 L F
.716 .721 .853 r
.64975 .76538 m .65071 .76205 L .6488 .7642 L F
.64975 .76538 m .65188 .76443 L .65071 .76205 L F
.328 0 0 r
.48868 .88367 m .49181 .88322 L .4906 .88372 L F
.161 0 0 r
.4906 .88372 m .49181 .88322 L .49382 .88302 L F
.385 .616 .942 r
.51048 .83793 m .51158 .83933 L .50944 .83895 L F
.51048 .83793 m .51158 .83933 L .50944 .83895 L F
.721 .57 .684 r
.50944 .83895 m .51286 .84144 L .51158 .83933 L F
.50944 .83895 m .50984 .84139 L .51286 .84144 L F
.937 .846 .727 r
.50561 .85523 m .50728 .85717 L .50643 .85413 L F
.50561 .85523 m .50434 .85695 L .50728 .85717 L F
.407 .843 .944 r
.36146 .72573 m .36217 .72507 L .36343 .72485 L F
.36146 .72573 m .36015 .72553 L .36217 .72507 L F
.763 .805 .323 r
.61133 .82463 m .61111 .8258 L .61221 .82245 L F
.724 .726 .203 r
.61058 .82793 m .61111 .8258 L .61133 .82463 L F
.046 0 .417 r
.60503 .8387 m .60644 .83557 L .60653 .83796 L F
0 0 .143 r
.60461 .84081 m .60503 .8387 L .60653 .83796 L F
.845 .984 .865 r
.35721 .7516 m .35747 .75265 L .35876 .75143 L F
.28 0 0 r
.36055 .75011 m .35721 .7516 L .35876 .75143 L F
.561 .29 .463 r
.40194 .77544 m .39939 .77752 L .39978 .77563 L F
.564 .504 .747 r
.42091 .73794 m .42172 .74116 L .41969 .74157 L F
.521 .366 .612 r
.42172 .74116 m .41982 .74388 L .41969 .74157 L F
.836 .982 .875 r
.35567 .75367 m .35747 .75265 L .35721 .7516 L F
.467 .252 .503 r
.59306 .76988 m .59431 .76793 L .59255 .76795 L F
.818 .714 .75 r
.60575 .79127 m .60294 .79125 L .60475 .78845 L F
.86 .811 .8 r
.60575 .79127 m .60231 .79329 L .60294 .79125 L F
.60575 .79127 m .60373 .79405 L .60231 .79329 L F
.737 .544 .632 r
.60144 .78355 m .60145 .78593 L .59966 .78601 L F
.161 .318 .775 r
.51262 .82837 m .51366 .82768 L .51143 .8279 L F
.602 .242 .33 r
.51484 .82857 m .51478 .82993 L .51262 .82837 L F
.161 .318 .775 r
.51262 .82837 m .51478 .82993 L .51366 .82768 L F
.704 .495 .602 r
.50984 .84139 m .51285 .84365 L .51286 .84144 L F
.57 .305 .475 r
.5073 .83076 m .50464 .83289 L .50507 .83086 L F
.514 .293 .517 r
.53198 .81952 m .53428 .8198 L .53368 .81598 L F
.389 .322 .661 r
.53368 .81598 m .53588 .81445 L .53372 .81458 L F
.53368 .81598 m .53644 .81732 L .53588 .81445 L F
.468 .263 .517 r
.53368 .81598 m .53428 .8198 L .53644 .81732 L F
.552 .38 .603 r
.61815 .74682 m .62041 .74871 L .62027 .7464 L F
.472 .385 .677 r
.61862 .74905 m .62041 .74871 L .61815 .74682 L F
.597 .743 .946 r
.53654 .84615 m .53889 .8468 L .54087 .84648 L F
.7 .892 .517 r
.51495 .84588 m .51415 .8474 L .51652 .84686 L F
.568 .936 .912 r
.68888 .7115 m .68935 .71176 L .69238 .71038 L F
.601 .389 .566 r
.65193 .74231 m .65268 .74381 L .65083 .74472 L F
.582 .607 .843 r
.65411 .74059 m .65193 .74231 L .65192 .7411 L F
.711 .647 .784 r
.65411 .74059 m .65268 .74381 L .65193 .74231 L F
.662 .192 .126 r
.53285 .80941 m .53512 .81076 L .5362 .8098 L F
.421 0 0 r
.53512 .81076 m .53843 .8112 L .5362 .8098 L F
.969 .78 .593 r
.51679 .85639 m .51844 .85455 L .51727 .85386 L F
.518 .42 .683 r
.62027 .7464 m .6219 .74312 L .61985 .74547 L F
.903 .796 .732 r
.62172 .79706 m .62192 .793 L .61994 .79622 L F
.877 .731 .698 r
.62092 .79909 m .62172 .79706 L .61994 .79622 L F
.57 .017 0 r
.36825 .72393 m .37084 .72497 L .37239 .72478 L F
.402 0 0 r
.37084 .72497 m .37421 .72528 L .37239 .72478 L F
.683 .847 .961 r
.39702 .74428 m .39797 .74547 L .40033 .74407 L F
.633 .464 .636 r
.42021 .85943 m .4234 .86001 L .42222 .8571 L F
.659 .477 .627 r
.42222 .8571 m .42566 .8596 L .42565 .85718 L F
.42222 .8571 m .4234 .86001 L .42566 .8596 L F
.814 .721 .762 r
.58359 .81573 m .58416 .81794 L .58309 .81762 L F
.828 .615 .614 r
.58416 .81794 m .58188 .81976 L .58309 .81762 L F
.58416 .81794 m .58473 .8203 L .58188 .81976 L F
.562 .552 .801 r
.58443 .81547 m .58416 .81794 L .58359 .81573 L F
.58443 .81547 m .58615 .81792 L .58416 .81794 L F
.686 .604 .759 r
.58615 .81792 m .58473 .8203 L .58416 .81794 L F
.655 .592 .772 r
.63433 .74642 m .63121 .74391 L .6333 .74388 L F
.73 .713 .834 r
.63666 .74421 m .63433 .74642 L .6333 .74388 L F
.558 .385 .602 r
.40535 .87828 m .40703 .87996 L .40764 .87549 L F
.465 .629 .924 r
.40442 .87943 m .40703 .87996 L .40535 .87828 L F
.54 .384 .618 r
.63468 .73588 m .63491 .73773 L .6325 .73801 L F
.649 .462 .617 r
.63554 .74102 m .6325 .73801 L .63491 .73773 L F
.63554 .74102 m .63374 .74145 L .6325 .73801 L F
.65 .244 .261 r
.38124 .93075 m .38192 .93077 L .38148 .93048 L F
.042 .503 .886 r
.53498 .85875 m .53789 .85989 L .53663 .85885 L F
.53498 .85875 m .53789 .85989 L .53663 .85885 L F
.027 0 0 r
.45242 .83147 m .45011 .83325 L .45274 .83157 L F
.943 .624 .402 r
.55718 .81508 m .55603 .81476 L .55558 .81233 L F
.809 .525 .508 r
.55718 .81508 m .55549 .81707 L .55603 .81476 L F
.55718 .81508 m .55827 .81802 L .55549 .81707 L F
.724 .858 .945 r
.58911 .81946 m .59054 .82059 L .58832 .82093 L F
.771 .659 .738 r
.58832 .82093 m .59054 .82059 L .588 .82296 L F
.573 .81 .989 r
.59215 .81994 m .59054 .82059 L .58911 .81946 L F
.519 .077 .139 r
.71355 .72708 m .7149 .72568 L .71462 .72644 L F
.982 .698 .398 r
.71476 .72605 m .7149 .72568 L .71462 .72644 L F
0 0 0 r
.71465 .72633 m .7149 .72568 L .71643 .72511 L F
.71446 .72628 m .7149 .72568 L .71477 .72602 L F
.71355 .72708 m .71383 .7268 L .71446 .72628 L F
.71383 .7268 m .7149 .72568 L .71446 .72628 L F
.883 .808 .77 r
.71607 .72231 m .71476 .72605 L .7128 .72459 L F
.71476 .72605 m .71462 .72644 L .71446 .72628 L F
.71476 .72605 m .71446 .72628 L .7128 .72459 L F
.923 .793 .7 r
.7128 .72459 m .71446 .72628 L .71355 .72708 L F
.71446 .72628 m .71462 .72644 L .71355 .72708 L F
0 0 0 r
.71355 .72708 m .71477 .72602 L .71465 .72633 L F
.982 .698 .398 r
.71607 .72231 m .7149 .72568 L .71476 .72605 L F
.71607 .72231 m .71643 .72511 L .7149 .72568 L F
.644 .559 .744 r
.52911 .84386 m .53015 .84753 L .53188 .84414 L F
.716 .401 .444 r
.52914 .84837 m .53251 .84722 L .53015 .84753 L F
.473 .062 .178 r
.529 .87088 m .5273 .87024 L .52581 .87237 L F
.52 .361 .606 r
.49483 .85241 m .49587 .8544 L .4957 .8522 L F
.742 .51 .578 r
.49941 .85461 m .4957 .8522 L .49587 .8544 L F
.751 .616 .049 r
.50761 .86152 m .50758 .85939 L .50772 .86181 L F
.877 .734 .7 r
.60319 .79603 m .60231 .79329 L .60373 .79405 L F
.42 .046 .22 r
.35077 .79366 m .35257 .79373 L .35383 .79154 L F
.329 0 .169 r
.35383 .79154 m .35454 .7932 L .35594 .7912 L F
.35383 .79154 m .35257 .79373 L .35454 .7932 L F
.598 .368 .539 r
.46398 .83548 m .46645 .8333 L .46448 .83359 L F
.79 .707 .773 r
.52555 .84093 m .5293 .83931 L .5275 .83909 L F
.52555 .84093 m .52694 .84175 L .5293 .83931 L F
.562 .875 .994 r
.52988 .8385 m .5275 .83909 L .5293 .83931 L F
.472 .54 .845 r
.54528 .78308 m .54396 .78499 L .54341 .78308 L F
.313 .421 .812 r
.54396 .78499 m .54446 .7857 L .54341 .78308 L F
.844 .504 .409 r
.68788 .75123 m .69047 .752 L .68962 .7541 L F
.711 .347 .356 r
.69047 .752 m .6928 .75416 L .68962 .7541 L F
.506 .176 .342 r
.52425 .83301 m .52644 .83274 L .52676 .83133 L F
.608 .269 .371 r
.52644 .83274 m .52878 .83294 L .52676 .83133 L F
.677 .506 .647 r
.42021 .85943 m .42355 .86222 L .4234 .86001 L F
.42021 .85943 m .42134 .86262 L .42355 .86222 L F
.626 .323 .438 r
.50198 .83353 m .5021 .83612 L .49977 .8354 L F
.485 .217 .433 r
.50421 .83545 m .5021 .83612 L .50198 .83353 L F
.56 .389 .606 r
.61425 .75445 m .61648 .75407 L .61644 .75184 L F
.586 .441 .651 r
.61442 .75688 m .61648 .75407 L .61425 .75445 L F
.514 .571 .851 r
.54446 .7857 m .54528 .78308 L .54341 .78308 L F
.579 .63 .866 r
.39381 .88804 m .39697 .88923 L .39625 .88776 L F
.609 .04 0 r
.6644 .70655 m .66371 .70561 L .66243 .70499 L F
.6644 .70655 m .66577 .70699 L .66371 .70561 L F
.646 .505 .676 r
.59792 .76578 m .59813 .76771 L .60024 .76519 L F
.501 .272 .5 r
.37848 .79125 m .37794 .79341 L .37619 .79365 L F
.508 .179 .343 r
.37848 .79125 m .37946 .79361 L .37794 .79341 L F
.37848 .79125 m .38055 .79112 L .37946 .79361 L F
.274 0 0 r
.49806 .8824 m .50136 .8808 L .5002 .88243 L F
.311 .737 .972 r
.49806 .8824 m .5002 .88243 L .49914 .88221 L F
.023 0 0 r
.49678 .88263 m .49946 .88106 L .49806 .8824 L F
.274 0 0 r
.49806 .8824 m .49946 .88106 L .50136 .8808 L F
.311 .737 .972 r
.49806 .8824 m .49914 .88221 L .49703 .88178 L F
.023 0 0 r
.49604 .88306 m .49678 .88263 L .49806 .8824 L F
.393 .535 .879 r
.70927 .71373 m .71074 .71201 L .7092 .7119 L F
.178 0 0 r
.67851 .75934 m .67779 .75975 L .67559 .75999 L F
.824 .686 .711 r
.52634 .8414 m .52688 .84389 L .52694 .84175 L F
.52555 .84093 m .52593 .84178 L .52634 .8414 L F
.52593 .84178 m .52688 .84389 L .52634 .8414 L F
.812 .681 .72 r
.52593 .84178 m .52367 .84406 L .52555 .84093 L F
.824 .686 .711 r
.52555 .84093 m .52688 .8439 L .52688 .84389 L F
.812 .681 .72 r
.52593 .84178 m .52367 .84406 L .52688 .8439 L F
.5259 .8417 m .52367 .84406 L .52593 .84178 L F
.52471 .84234 m .52367 .84406 L .5259 .8417 L F
.373 0 .091 r
.52615 .84157 m .5226 .84404 L .52352 .84406 L F
.52593 .84178 m .52352 .84406 L .52367 .84406 L F
.52615 .84156 m .52352 .84406 L .52593 .84178 L F
.52615 .84157 m .5248 .84355 L .5226 .84404 L F
.812 .681 .72 r
.52555 .84093 m .52471 .84234 L .5259 .8417 L F
.52615 .84156 m .52593 .84178 L .52555 .84093 L F
.63 .79 .959 r
.45548 .83522 m .45674 .83623 L .45354 .8358 L F
.506 .709 .963 r
.45777 .83496 m .45674 .83623 L .45548 .83522 L F
.45777 .83496 m .45898 .83626 L .45674 .83623 L F
.939 .843 .723 r
.47996 .87675 m .48108 .87333 L .4787 .87507 L F
.121 0 .086 r
.48015 .87514 m .4787 .87507 L .48108 .87333 L F
.65 .097 0 r
.48078 .87759 m .48201 .87812 L .47996 .87675 L F
.106 .219 .699 r
.48078 .87759 m .4787 .87507 L .48015 .87514 L F
.65 .097 0 r
.48078 .87759 m .47996 .87675 L .4787 .87507 L F
.625 .496 .684 r
.42682 .85118 m .42972 .85206 L .42888 .84863 L F
.657 .514 .678 r
.42682 .85118 m .42996 .85422 L .42972 .85206 L F
.42682 .85118 m .42773 .85456 L .42996 .85422 L F
.545 .271 .451 r
.42575 .75987 m .4232 .76196 L .42368 .7602 L F
.72 .897 .959 r
.55446 .78142 m .55844 .78054 L .55836 .77941 L F
.749 .433 .449 r
.39627 .8833 m .39793 .88562 L .39867 .88379 L F
.618 .487 .679 r
.39867 .88379 m .40124 .88359 L .40052 .88031 L F
.758 .443 .452 r
.39867 .88379 m .40123 .88582 L .40124 .88359 L F
.39867 .88379 m .39793 .88562 L .40123 .88582 L F
.497 .467 .754 r
.48809 .8324 m .48718 .83515 L .48594 .83273 L F
.48809 .8324 m .48896 .83591 L .48718 .83515 L F
.667 .464 .601 r
.60548 .76481 m .60771 .76482 L .60771 .76249 L F
.621 .427 .598 r
.60771 .76249 m .61008 .76451 L .61011 .76218 L F
.60771 .76249 m .60771 .76482 L .61008 .76451 L F
.623 .813 .973 r
.52723 .87501 m .52899 .87604 L .53064 .87534 L F
.206 .558 .935 r
.63225 .73042 m .63109 .73105 L .63038 .73 L F
.238 .075 .447 r
.63298 .73091 m .63109 .73105 L .63225 .73042 L F
.63109 .73105 m .63298 .73091 L .63311 .73097 L F
.63298 .73091 m .63097 .73311 L .63109 .73105 L F
.63109 .73105 m .63097 .73311 L .63298 .73091 L F
.804 .694 .744 r
.49207 .82289 m .49013 .82399 L .48897 .82257 L F
.799 .696 .751 r
.68255 .74931 m .68428 .74646 L .68154 .74573 L F
.257 .701 .96 r
.68154 .74573 m .68401 .74639 L .68337 .7459 L F
.68401 .74639 m .68428 .74646 L .68337 .7459 L F
.761 .326 0 r
.68471 .7486 m .68267 .74538 L .68337 .7459 L F
.68267 .74538 m .6825 .74512 L .68337 .7459 L F
.893 .489 .24 r
.68599 .749 m .68337 .7459 L .68428 .74646 L F
.706 .6 .735 r
.65377 .7468 m .65165 .74945 L .65052 .74628 L F
.701 .593 .732 r
.65377 .7468 m .65375 .7489 L .65165 .74945 L F
.506 .369 .629 r
.63374 .74145 m .6333 .74388 L .63121 .74391 L F
.635 .538 .728 r
.57032 .7916 m .5708 .79437 L .56825 .7939 L F
0 0 0 r
.57032 .7916 m .56825 .7939 L .56927 .79291 L F
.61 .181 .203 r
.5708 .79437 m .57217 .79611 L .56825 .7939 L F
.232 .397 .822 r
.56825 .7939 m .57217 .79611 L .56927 .79291 L F
.418 0 0 r
.54375 .79855 m .5473 .7997 L .54479 .79869 L F
.436 .845 .666 r
.57243 .78878 m .57313 .78823 L .57525 .78701 L F
.62 .534 .736 r
.57525 .78701 m .57458 .78914 L .57243 .78878 L F
.537 .04 .022 r
.57458 .78914 m .57368 .78972 L .57243 .78878 L F
0 .169 .698 r
.57243 .78878 m .57368 .78972 L .57313 .78823 L F
.247 .149 .542 r
.57368 .78972 m .57255 .79111 L .57243 .78878 L F
.661 .448 .586 r
.44278 .83306 m .44469 .83567 L .44478 .8335 L F
.672 .41 .517 r
.44478 .8335 m .44784 .83528 L .44805 .83383 L F
.44478 .8335 m .44469 .83567 L .44784 .83528 L F
.297 0 .276 r
.38048 .77566 m .37809 .77799 L .37983 .77724 L F
.381 .076 .319 r
.38048 .77566 m .3816 .77663 L .38223 .77505 L F
.38048 .77566 m .37983 .77724 L .3816 .77663 L F
.704 .495 .602 r
.50984 .84139 m .50938 .844 L .51285 .84365 L F
.466 .213 .446 r
.3827 .77305 m .38417 .77453 L .38423 .7724 L F
.3827 .77305 m .38223 .77505 L .38417 .77453 L F
.623 .773 .952 r
.62784 .73309 m .62897 .73381 L .62558 .73316 L F
.761 .647 .736 r
.62897 .73381 m .62685 .73631 L .62558 .73316 L F
.606 .77 .958 r
.63097 .73311 m .62897 .73381 L .62784 .73309 L F
.409 .474 .815 r
.52592 .83878 m .52632 .83596 L .52481 .83555 L F
.52592 .83878 m .5275 .83909 L .52632 .83596 L F
.79 .707 .773 r
.52555 .84093 m .5275 .83909 L .52592 .83878 L F
.961 .75 .574 r
.56414 .83568 m .56224 .83749 L .56339 .83578 L F
.56414 .83568 m .56445 .83931 L .56224 .83749 L F
.803 .767 .82 r
.64114 .76749 m .63908 .7701 L .64208 .76991 L F
.717 .725 .856 r
.64114 .76749 m .64208 .76991 L .64475 .76814 L F
.644 .482 .648 r
.43612 .84126 m .43835 .84128 L .43817 .8389 L F
.56 .4 .62 r
.43817 .8389 m .44034 .83866 L .44014 .83603 L F
.606 .453 .648 r
.43817 .8389 m .44054 .84093 L .44034 .83866 L F
.43817 .8389 m .43835 .84128 L .44054 .84093 L F
.623 .571 .776 r
.40872 .74429 m .40997 .74747 L .41216 .74711 L F
.883 .495 .035 r
.67499 .71852 m .67483 .71932 L .67382 .71733 L F
.67499 .71852 m .67562 .72006 L .67483 .71932 L F
.467 .252 .503 r
.59306 .76988 m .59469 .76958 L .59431 .76793 L F
.747 .544 .621 r
.59469 .76958 m .59813 .76771 L .59431 .76793 L F
0 0 0 r
.43145 .88835 m .43493 .88642 L .43348 .8861 L F
.515 .844 .555 r
.43571 .88562 m .43493 .88642 L .43637 .88506 L F
.46 .858 .972 r
.43348 .8861 m .43493 .88642 L .43571 .88562 L F
.963 .733 .542 r
.4654 .86846 m .46579 .87098 L .46689 .87047 L F
.622 .122 .043 r
.46689 .87047 m .46579 .87098 L .46571 .87122 L F
.678 .73 .889 r
.4654 .86846 m .46689 .87047 L .46885 .86954 L F
0 0 .367 r
.46779 .87139 m .46707 .87159 L .46689 .87047 L F
.46779 .87139 m .46689 .87047 L .46571 .87122 L F
.455 .125 .316 r
.36738 .78547 m .37054 .78277 L .36835 .78304 L F
.941 .847 .412 r
.57422 .82706 m .57454 .82757 L .57429 .82601 L F
.57402 .82975 m .57454 .82757 L .57422 .82706 L F
.929 .944 .599 r
.57318 .83104 m .57492 .82818 L .57454 .82757 L F
.57492 .82818 m .57494 .82815 L .57454 .82757 L F
.995 .832 .57 r
.61711 .80929 m .61673 .80677 L .61546 .80922 L F
.744 .885 .479 r
.61529 .81222 m .61711 .80929 L .61546 .80922 L F
.61529 .81222 m .61562 .81192 L .61711 .80929 L F
.488 .814 1 r
.35383 .754 m .35492 .75331 L .35308 .75358 L F
.35383 .754 m .35567 .75367 L .35492 .75331 L F
.589 .418 .618 r
.46014 .8519 m .46249 .85198 L .46225 .84925 L F
.46014 .8519 m .46249 .85198 L .46225 .84925 L F
.597 .408 .597 r
.42888 .84863 m .43055 .84778 L .43002 .84652 L F
.634 .46 .63 r
.43002 .84652 m .43408 .84658 L .43387 .84412 L F
.664 .512 .668 r
.43055 .84778 m .43408 .84658 L .43002 .84652 L F
.628 .442 .612 r
.43387 .84412 m .43622 .84396 L .43612 .84126 L F
.677 .481 .613 r
.43612 .84126 m .43845 .84364 L .43835 .84128 L F
.43612 .84126 m .43622 .84396 L .43845 .84364 L F
.572 .371 .569 r
.44014 .83603 m .44278 .83306 L .44174 .83318 L F
.44014 .83603 m .44249 .83596 L .44278 .83306 L F
.661 .448 .586 r
.44278 .83306 m .44249 .83596 L .44469 .83567 L F
0 0 .261 r
.53081 .87493 m .53102 .87304 L .53168 .87275 L F
.53069 .87504 m .53102 .87304 L .53081 .87493 L F
0 0 .007 r
.53124 .87452 m .53064 .87534 L .53155 .8745 L F
0 0 .261 r
.53064 .87534 m .53081 .87493 L .53155 .8745 L F
.623 .813 .973 r
.53116 .87453 m .53064 .87534 L .53124 .87452 L F
0 0 .261 r
.53112 .8745 m .53168 .87275 L .5316 .87386 L F
.53081 .87493 m .53097 .87451 L .53112 .8745 L F
.53097 .87451 m .53168 .87275 L .53112 .8745 L F
.53081 .87493 m .5316 .87386 L .53116 .87453 L F
0 .488 .792 r
.53119 .8745 m .53124 .87452 L .53155 .8745 L F
.52 .852 .997 r
.53116 .87453 m .53122 .87452 L .53118 .87451 L F
.53122 .87452 m .53124 .87452 L .53123 .87452 L F
0 0 .261 r
.53081 .87493 m .53158 .87407 L .53155 .8745 L F
0 .488 .792 r
.52858 .87349 m .53119 .8745 L .53155 .8745 L F
0 0 .261 r
.53064 .87534 m .53069 .87504 L .53081 .87493 L F
.623 .813 .973 r
.52723 .87501 m .53064 .87534 L .53116 .87453 L F
0 0 .261 r
.53116 .87453 m .5316 .87386 L .53158 .87407 L F
.52 .852 .997 r
.52723 .87501 m .53116 .87453 L .52881 .87358 L F
.52723 .87501 m .52881 .87358 L .52848 .87361 L F
.52723 .87501 m .52848 .87361 L .52665 .87406 L F
.682 .443 .554 r
.52743 .87371 m .53003 .87347 L .52807 .87189 L F
.52 .852 .997 r
.52848 .87361 m .52858 .87349 L .52829 .87358 L F
.52848 .87361 m .52829 .87358 L .52665 .87406 L F
.682 .443 .554 r
.52853 .87362 m .53057 .87391 L .53003 .87347 L F
.52742 .87373 m .52998 .87388 L .52853 .87362 L F
0 .488 .792 r
.52858 .87349 m .53155 .8745 L .53057 .87391 L F
.682 .443 .554 r
.52998 .87388 m .53057 .87391 L .52853 .87362 L F
.52742 .87373 m .53003 .87347 L .52743 .87371 L F
.52 .852 .997 r
.52848 .87361 m .52881 .87358 L .52858 .87349 L F
.53116 .87453 m .53118 .87451 L .52858 .87349 L F
.53122 .87452 m .53123 .87452 L .52858 .87349 L F
.371 0 .126 r
.37619 .79365 m .37478 .79548 L .37284 .79583 L F
.274 0 .063 r
.37702 .79478 m .37619 .79365 L .37794 .79341 L F
.37702 .79478 m .37478 .79548 L .37619 .79365 L F
.747 .688 .794 r
.64234 .7423 m .63876 .74175 L .64077 .74083 L F
.764 .734 .825 r
.64395 .74095 m .64234 .7423 L .64077 .74083 L F
.817 .635 .656 r
.71429 .72865 m .71612 .73097 L .71317 .72962 L F
.898 .646 .548 r
.71612 .73097 m .71461 .73295 L .71317 .72962 L F
.71612 .73097 m .71645 .73321 L .71461 .73295 L F
.603 .647 .867 r
.71734 .72867 m .71612 .73097 L .71429 .72865 L F
.71734 .72867 m .71862 .73078 L .71612 .73097 L F
.603 .442 .637 r
.71612 .73097 m .71862 .73078 L .71645 .73321 L F
.71612 .73097 m .71862 .73078 L .71645 .73321 L F
.644 .848 .978 r
.38586 .72635 m .38312 .72632 L .38491 .7255 L F
.357 .544 .901 r
.38688 .72523 m .38586 .72635 L .38491 .7255 L F
.38688 .72523 m .38838 .72729 L .38586 .72635 L F
.397 .239 .547 r
.33884 .67995 m .33731 .6783 L .3391 .67777 L F
.33884 .67995 m .33727 .68056 L .33731 .6783 L F
.982 .698 .398 r
.71607 .72231 m .71721 .72366 L .71643 .72511 L F
.662 .785 .94 r
.71945 .72274 m .71721 .72366 L .71607 .72231 L F
.189 0 0 r
.71643 .72511 m .71721 .72366 L .71945 .72274 L F
.652 .598 .781 r
.6594 .76217 m .66069 .76557 L .66207 .76402 L F
.676 .617 .782 r
.40703 .87241 m .40852 .86997 L .40659 .87025 L F
.461 .661 .948 r
.41315 .86625 m .41725 .86779 L .41615 .86696 L F
.653 .545 .72 r
.41315 .86625 m .41719 .87019 L .41725 .86779 L F
.41315 .86625 m .41497 .87039 L .41719 .87019 L F
.337 .085 .377 r
.68981 .72011 m .6911 .72018 L .69243 .71778 L F
.567 .808 .99 r
.46281 .86521 m .46042 .86572 L .45887 .86463 L F
.625 .454 .631 r
.60033 .76765 m .60243 .76488 L .60024 .76519 L F
.60033 .76765 m .60307 .76776 L .60243 .76488 L F
.598 .437 .634 r
.60243 .76488 m .60559 .76737 L .60548 .76481 L F
.60243 .76488 m .60307 .76776 L .60559 .76737 L F
.575 .027 0 r
.50136 .8808 m .50452 .88138 L .50357 .88208 L F
.5 0 0 r
.50357 .88208 m .50452 .88138 L .50697 .88248 L F
.799 .696 .751 r
.68255 .74931 m .68154 .74573 L .68174 .74842 L F
.982 .852 .636 r
.68174 .74842 m .68189 .75172 L .68255 .74931 L F
0 .032 .544 r
.66094 .7161 m .66128 .71469 L .66039 .71506 L F
.66094 .7161 m .6613 .71637 L .66128 .71469 L F
.66094 .7161 m .66217 .71733 L .6613 .71637 L F
.672 .598 .764 r
.39697 .88923 m .40035 .89165 L .39923 .89036 L F
.712 .709 .846 r
.39923 .89036 m .40035 .89165 L .40217 .89063 L F
.694 .566 .706 r
.65615 .74647 m .65375 .7489 L .65377 .7468 L F
.65615 .74647 m .65704 .74975 L .65375 .7489 L F
.478 .112 .264 r
.38991 .74476 m .38702 .74619 L .38772 .74533 L F
.627 .664 .866 r
.48594 .83273 m .48238 .83062 L .48485 .8318 L F
.432 0 0 r
.48485 .8318 m .48809 .8324 L .48594 .83273 L F
.37 .778 .982 r
.39272 .74507 m .39118 .74455 L .38991 .74476 L F
.435 .788 .997 r
.39272 .74507 m .39357 .74423 L .39118 .74455 L F
.39272 .74507 m .3949 .74489 L .39388 .74438 L F
0 0 0 r
.39456 .74416 m .39456 .74475 L .39191 .74539 L F
.573 .844 .996 r
.39357 .74423 m .39702 .74428 L .39583 .74356 L F
0 0 0 r
.39583 .74356 m .39555 .74383 L .39456 .74416 L F
.573 .844 .996 r
.39357 .74423 m .3949 .74489 L .39702 .74428 L F
0 0 0 r
.39555 .74383 m .39456 .74475 L .39456 .74416 L F
.435 .788 .997 r
.39317 .74462 m .39388 .74438 L .39357 .74423 L F
.39272 .74507 m .39388 .74438 L .39317 .74462 L F
.477 .355 .635 r
.3347 .68275 m .33482 .68537 L .33289 .68346 L F
.421 .349 .671 r
.33289 .68346 m .33482 .68537 L .33338 .68576 L F
.351 .753 .984 r
.52871 .81468 m .53077 .81454 L .53019 .81168 L F
.489 .039 .107 r
.52047 .85102 m .52194 .85128 L .52279 .84967 L F
.81 .581 .592 r
.52194 .85128 m .52474 .84872 L .52279 .84967 L F
0 0 0 r
.36089 .8037 m .36196 .80252 L .36338 .80153 L F
.498 .273 .504 r
.6874 .71017 m .68683 .71236 L .68888 .7115 L F
.659 .22 .198 r
.6874 .71017 m .68888 .7115 L .68818 .71131 L F
.225 .107 .501 r
.6874 .71017 m .68818 .71131 L .68833 .70697 L F
.809 .711 .756 r
.66144 .76172 m .66523 .76051 L .66359 .75949 L F
.66144 .76172 m .66347 .76289 L .66523 .76051 L F
.722 .85 .942 r
.66359 .75949 m .66523 .76051 L .66696 .75925 L F
.623 .618 .825 r
.68507 .71345 m .68683 .71236 L .68402 .71182 L F
.68507 .71345 m .68683 .71236 L .68402 .71182 L F
.692 .583 .729 r
.40703 .87241 m .40764 .87549 L .40977 .87296 L F
.651 .523 .694 r
.40977 .87296 m .40764 .87549 L .40981 .87432 L F
.692 .506 .631 r
.40764 .87549 m .41069 .8781 L .40981 .87432 L F
.40764 .87549 m .40703 .87996 L .41069 .8781 L F
.986 .759 .508 r
.68332 .74147 m .68222 .74302 L .68195 .74076 L F
.68332 .74147 m .68324 .74372 L .68222 .74302 L F
.743 .533 .61 r
.46289 .85117 m .46249 .85198 L .46225 .84925 L F
.46289 .85117 m .46249 .85198 L .46225 .84925 L F
.576 .619 .858 r
.3261 .67818 m .3282 .67861 L .32629 .67851 L F
.601 .417 .606 r
.40404 .75978 m .40659 .75969 L .40621 .75698 L F
.607 .438 .628 r
.40621 .75698 m .40856 .75686 L .4087 .75423 L F
.524 .363 .605 r
.40621 .75698 m .40823 .75919 L .40856 .75686 L F
.40621 .75698 m .40659 .75969 L .40823 .75919 L F
.774 .76 .84 r
.65343 .76384 m .6573 .76268 L .6562 .76235 L F
.385 .842 .906 r
.6573 .76268 m .65839 .76201 L .6562 .76235 L F
.6573 .76268 m .6594 .76217 L .65839 .76201 L F
.379 .267 .598 r
.33482 .68537 m .33259 .68852 L .33338 .68576 L F
.33482 .68537 m .33502 .68756 L .33259 .68852 L F
.197 .13 .551 r
.33502 .68756 m .33384 .691 L .33259 .68852 L F
.558 .313 .501 r
.54327 .84421 m .54307 .84624 L .54087 .84648 L F
.763 .606 .684 r
.54642 .84428 m .54307 .84624 L .54327 .84421 L F
.747 .394 .383 r
.48164 .85171 m .48334 .85299 L .48521 .85255 L F
.851 .868 .853 r
.48521 .85255 m .48595 .84954 L .48689 .85147 L F
.48521 .85255 m .48334 .85299 L .48595 .84954 L F
.619 .603 .813 r
.49773 .83587 m .49438 .83347 L .49685 .83292 L F
.561 .509 .755 r
.49977 .8354 m .49773 .83587 L .49685 .83292 L F
0 0 0 r
.49799 .83692 m .49773 .83587 L .49977 .8354 L F
.49799 .83692 m .49636 .83777 L .49773 .83587 L F
.144 0 0 r
.56929 .77615 m .57219 .77518 L .57008 .77558 L F
.768 .777 .861 r
.66724 .74696 m .6676 .74903 L .66468 .74902 L F
0 .296 .764 r
.53977 .80078 m .54211 .80268 L .54155 .80172 L F
.795 .305 .034 r
.54468 .80358 m .54155 .80172 L .54211 .80268 L F
.302 0 .098 r
.36361 .78649 m .36268 .78764 L .36553 .78602 L F
.539 .262 .443 r
.39258 .78105 m .3942 .78266 L .39214 .78286 L F
.473 .263 .513 r
.39445 .78049 m .3942 .78266 L .39258 .78105 L F
.946 .714 .247 r
.56186 .82552 m .56122 .82507 L .56111 .82225 L F
0 0 .206 r
.56186 .82552 m .56229 .82693 L .56122 .82507 L F
.56186 .82552 m .56249 .82801 L .56229 .82693 L F
.462 .153 .354 r
.37525 .7807 m .37729 .78037 L .37809 .77799 L F
.425 .118 .339 r
.37809 .77799 m .37928 .77992 L .37983 .77724 L F
.37809 .77799 m .37729 .78037 L .37928 .77992 L F
.673 .914 .59 r
.6988 .70462 m .69705 .70674 L .69688 .70714 L F
.667 .808 .362 r
.69705 .70674 m .69615 .7085 L .69688 .70714 L F
.928 .672 .53 r
.69615 .7085 m .69754 .70956 L .69688 .70714 L F
.834 .496 .415 r
.54862 .80093 m .55025 .8014 L .54985 .79945 L F
.747 .437 .459 r
.54985 .79945 m .55025 .8014 L .55308 .80155 L F
.972 .927 .666 r
.61401 .81308 m .61441 .81525 L .61562 .81192 L F
.61401 .81308 m .61562 .81192 L .61529 .81222 L F
.093 0 0 r
.58842 .83017 m .58694 .83065 L .58592 .8317 L F
.943 .753 .616 r
.67917 .73367 m .67744 .73523 L .67759 .73294 L F
.67917 .73367 m .67869 .73603 L .67744 .73523 L F
.585 .525 .754 r
.59357 .77288 m .59469 .76958 L .59306 .76988 L F
.59357 .77288 m .59589 .77259 L .59469 .76958 L F
.573 .369 .567 r
.59321 .775 m .59589 .77259 L .59357 .77288 L F
.961 .632 .331 r
.49931 .87249 m .50035 .8729 L .5004 .87458 L F
.664 .358 .444 r
.5004 .87458 m .50035 .8729 L .49931 .87249 L F
.5004 .87458 m .50236 .87499 L .50035 .8729 L F
.407 .107 .34 r
.39238 .76783 m .39365 .76907 L .39438 .7674 L F
.39238 .76783 m .39174 .7696 L .39365 .76907 L F
.622 .727 .922 r
.44561 .88234 m .44749 .8829 L .4498 .88239 L F
0 .028 .588 r
.659 .72257 m .65994 .72584 L .66026 .72463 L F
.974 .694 .433 r
.62558 .73316 m .62685 .73631 L .62549 .73487 L F
.97 .743 .54 r
.62685 .73631 m .62577 .73794 L .62549 .73487 L F
.693 .962 .719 r
.67239 .70818 m .67088 .70966 L .67221 .70785 L F
.928 .688 .555 r
.67088 .70966 m .66956 .71155 L .67221 .70785 L F
.67088 .70966 m .67118 .7123 L .66956 .71155 L F
.981 .727 .471 r
.5539 .83497 m .555 .83346 L .55455 .83167 L F
.5539 .83497 m .55503 .83571 L .555 .83346 L F
.369 .61 .943 r
.41943 .73624 m .41816 .73709 L .41743 .73649 L F
.41943 .73624 m .42091 .73794 L .41816 .73709 L F
.622 .768 .95 r
.37875 .74847 m .38037 .74987 L .38234 .74919 L F
.661 .602 .778 r
.53858 .83577 m .54085 .83559 L .54067 .83344 L F
.358 0 .077 r
.54085 .83559 m .53776 .83774 L .53858 .83577 L F
.742 .594 .691 r
.69156 .74672 m .69497 .74647 L .69354 .74333 L F
.658 .302 .358 r
.69156 .74672 m .6938 .74864 L .69497 .74647 L F
.701 .576 .711 r
.69354 .74333 m .69497 .74647 L .69692 .74403 L F
.721 .375 .391 r
.69497 .74647 m .6938 .74864 L .69693 .74868 L F
.784 .293 .043 r
.69497 .74647 m .69693 .74868 L .69823 .74899 L F
0 .236 .745 r
.55516 .82996 m .5534 .82866 L .55262 .82747 L F
.905 .616 .486 r
.68599 .749 m .68738 .74916 L .68628 .75107 L F
.847 .53 .452 r
.68738 .74916 m .68788 .75123 L .68628 .75107 L F
.463 .427 .732 r
.48349 .82578 m .48203 .82828 L .48138 .82595 L F
.48349 .82578 m .48382 .82787 L .48203 .82828 L F
.311 .234 .605 r
.48408 .82974 m .48203 .82828 L .48382 .82787 L F
.48408 .82974 m .48238 .83062 L .48203 .82828 L F
.914 .622 .476 r
.56852 .81153 m .57116 .81564 L .57129 .81237 L F
.266 .763 .897 r
.4762 .8639 m .47688 .86347 L .47515 .86427 L F
.4762 .8639 m .47854 .86368 L .47688 .86347 L F
.725 .529 .625 r
.48484 .84654 m .48033 .84888 L .4807 .84652 L F
.48484 .84654 m .48395 .85033 L .48033 .84888 L F
.539 .347 .569 r
.48595 .84954 m .48395 .85033 L .48484 .84654 L F
.653 .69 .872 r
.65071 .76205 m .65188 .76443 L .65343 .76384 L F
.566 .312 .49 r
.50314 .84646 m .50008 .84939 L .50011 .84668 L F
.50314 .84646 m .5024 .84935 L .50008 .84939 L F
.754 .499 .546 r
.50555 .84915 m .50314 .84646 L .5053 .84651 L F
.50555 .84915 m .5024 .84935 L .50314 .84646 L F
.112 0 0 r
.5306 .85103 m .5335 .84932 L .53221 .85097 L F
0 0 .415 r
.53164 .85293 m .5306 .85103 L .53221 .85097 L F
.53158 .85282 m .53135 .85568 L .5306 .85103 L F
.724 .531 .629 r
.5313 .85107 m .52914 .84837 L .52894 .85135 L F
.53221 .85097 m .53114 .85006 L .5313 .85107 L F
.53114 .85006 m .52914 .84837 L .5313 .85107 L F
0 0 .415 r
.53164 .85293 m .53162 .8531 L .53158 .85282 L F
.53162 .8531 m .53135 .85568 L .53158 .85282 L F
.724 .524 .619 r
.60489 .78612 m .60147 .78813 L .60145 .78593 L F
.60489 .78612 m .60475 .78845 L .60147 .78813 L F
.534 .271 .463 r
.41872 .76396 m .41803 .76722 L .41597 .76748 L F
.53 .268 .462 r
.42051 .76594 m .41872 .76396 L .42084 .7637 L F
.42051 .76594 m .41803 .76722 L .41872 .76396 L F
.565 .6 .847 r
.70601 .71057 m .70785 .71024 L .70755 .7085 L F
.538 .534 .799 r
.70601 .71057 m .7092 .7119 L .70785 .71024 L F
.55 .409 .642 r
.61648 .75407 m .61835 .75138 L .61644 .75184 L F
0 0 0 r
.69354 .74333 m .6928 .74525 L .69156 .74672 L F
.335 .46 .838 r
.69409 .74123 m .69354 .74333 L .69253 .74078 L F
.778 .635 .703 r
.69534 .74252 m .6928 .74525 L .69354 .74333 L F
.869 .853 .824 r
.48262 .87488 m .48405 .876 L .48201 .87812 L F
.559 .269 .432 r
.48405 .876 m .48735 .87535 L .48739 .87483 L F
.341 0 0 r
.3282 .67861 m .33067 .67878 L .33129 .67814 L F
.687 .496 .623 r
.41208 .87232 m .41497 .87039 L .40888 .8722 L F
.41208 .87232 m .41515 .87301 L .41497 .87039 L F
.641 .462 .625 r
.41497 .87039 m .41515 .87301 L .41719 .87019 L F
.708 .596 .728 r
.60024 .76519 m .59813 .76771 L .60033 .76765 L F
.684 .491 .619 r
.59813 .76771 m .60034 .76968 L .60033 .76765 L F
.662 .496 .649 r
.60034 .76968 m .60307 .76776 L .60033 .76765 L F
.669 .71 .878 r
.41615 .86696 m .41725 .86779 L .41941 .86758 L F
.67 .506 .655 r
.41725 .86779 m .41719 .87019 L .41941 .86758 L F
.522 .27 .475 r
.41101 .77204 m .40933 .77024 L .41143 .76994 L F
.41101 .77204 m .40894 .77239 L .40933 .77024 L F
.461 .715 .978 r
.44174 .88173 m .44274 .88073 L .4409 .88091 L F
.44174 .88173 m .44383 .88185 L .44274 .88073 L F
.812 .328 .021 r
.43833 .73862 m .44014 .74098 L .44137 .74136 L F
.554 .888 .986 r
.44217 .74029 m .44014 .74098 L .44137 .74136 L F
.44217 .74029 m .44014 .74098 L .44137 .74136 L F
.722 .627 .752 r
.65574 .74436 m .65615 .74647 L .65377 .7468 L F
.585 .511 .739 r
.65794 .74401 m .65615 .74647 L .65574 .74436 L F
.65794 .74401 m .65913 .74784 L .65615 .74647 L F
.587 .5 .724 r
.65906 .74911 m .65615 .74647 L .65913 .74784 L F
.65906 .74911 m .65704 .74975 L .65615 .74647 L F
.068 .631 .724 r
.35454 .72654 m .35826 .7263 L .35598 .72679 L F
.473 .313 .582 r
.459 .86202 m .457 .86484 L .45683 .86245 L F
.747 .544 .621 r
.59469 .76958 m .59805 .77006 L .59813 .76771 L F
.684 .491 .619 r
.59813 .76771 m .59805 .77006 L .60034 .76968 L F
.944 .583 .271 r
.56224 .83749 m .56445 .83931 L .56406 .84012 L F
0 0 0 r
.66058 .70519 m .65924 .70734 L .66027 .70616 L F
.797 .738 .212 r
.66058 .70519 m .66056 .70425 L .66243 .70499 L F
.66058 .70519 m .66027 .70616 L .66056 .70425 L F
.863 .804 .791 r
.70385 .70171 m .7022 .70528 L .70072 .70348 L F
.54 .927 .852 r
.7035 .70437 m .70133 .70561 L .7022 .70528 L F
.634 .454 .623 r
.44014 .83603 m .44257 .8383 L .44249 .83596 L F
.44014 .83603 m .44034 .83866 L .44257 .8383 L F
.52 .361 .606 r
.49483 .85241 m .4936 .8552 L .49587 .8544 L F
.71 .659 .798 r
.40438 .88868 m .40584 .89153 L .40787 .89073 L F
0 0 0 r
.68994 .70376 m .69323 .70282 L .6904 .70408 L F
0 .189 .717 r
.54666 .804 m .54683 .80338 L .54468 .80358 L F
.54666 .804 m .54806 .8053 L .54683 .80338 L F
.604 .643 .862 r
.39625 .88776 m .39697 .88923 L .39725 .88741 L F
.503 .546 .833 r
.39697 .88923 m .39923 .89036 L .39725 .88741 L F
.581 .422 .63 r
.61835 .75138 m .62041 .74871 L .61862 .74905 L F
.818 .985 .882 r
.52286 .85346 m .52588 .85165 L .52482 .85413 L F
.704 .385 .434 r
.52588 .85165 m .52749 .85295 L .5253 .853 L F
.623 .312 .422 r
.52269 .85306 m .52683 .85261 L .52194 .85128 L F
.52286 .85346 m .52497 .85301 L .52269 .85306 L F
.52497 .85301 m .52683 .85261 L .52269 .85306 L F
.704 .385 .434 r
.5253 .853 m .52848 .85375 L .52482 .85413 L F
.52749 .85295 m .52848 .85375 L .5253 .853 L F
.65 .415 .549 r
.52806 .85195 m .52848 .85375 L .52588 .85165 L F
.307 .73 .973 r
.50846 .85348 m .51182 .85408 L .50986 .85414 L F
.865 .885 .848 r
.51182 .85408 m .51096 .85642 L .50986 .85414 L F
.487 .263 .5 r
.55547 .79926 m .55531 .80139 L .55745 .79884 L F
.651 .519 .689 r
.52911 .84386 m .53188 .84414 L .53232 .84188 L F
0 .089 .647 r
.51096 .85642 m .51298 .85949 L .51171 .85661 L F
.51096 .85642 m .51171 .85661 L .50867 .85654 L F
.762 .513 .557 r
.51171 .85661 m .50846 .85348 L .50924 .85655 L F
.51171 .85661 m .50924 .85655 L .5094 .85716 L F
0 .089 .647 r
.50867 .85654 m .51171 .85661 L .50848 .85655 L F
.755 .644 .737 r
.58832 .82093 m .588 .82296 L .58462 .8229 L F
.28 0 0 r
.58462 .8229 m .588 .82296 L .58727 .82321 L F
.382 .821 .952 r
.588 .82296 m .58912 .82228 L .58727 .82321 L F
.588 .82296 m .59013 .82258 L .58912 .82228 L F
.253 0 0 r
.35429 .80711 m .356 .80695 L .35374 .80768 L F
.687 .647 .805 r
.49587 .8544 m .49705 .85758 L .49889 .85667 L F
.64 .639 .833 r
.40664 .73347 m .40379 .73181 L .4053 .73099 L F
.502 .586 .872 r
.40765 .73167 m .40664 .73347 L .4053 .73099 L F
.461 .534 .846 r
.40765 .73167 m .40874 .73355 L .40664 .73347 L F
.591 .424 .624 r
.40894 .73455 m .40664 .73347 L .40874 .73355 L F
.40894 .73455 m .40675 .73545 L .40664 .73347 L F
.511 .428 .699 r
.4087 .75423 m .41054 .75387 L .41009 .75114 L F
.489 .339 .604 r
.4087 .75423 m .41044 .75627 L .41054 .75387 L F
.4087 .75423 m .40856 .75686 L .41044 .75627 L F
.737 .61 .717 r
.38144 .93149 m .38192 .93077 L .38124 .93075 L F
.76 .387 .348 r
.58743 .78568 m .58414 .78372 L .58739 .78346 L F
.795 .599 .637 r
.58473 .8203 m .5815 .82236 L .58188 .81976 L F
.58473 .8203 m .58462 .8229 L .5815 .82236 L F
.686 .604 .759 r
.58615 .81792 m .58752 .81985 L .58473 .8203 L F
.685 .596 .751 r
.58752 .81985 m .58832 .82093 L .58473 .8203 L F
.755 .644 .737 r
.58832 .82093 m .58462 .8229 L .58473 .8203 L F
.7 .578 .715 r
.69588 .74116 m .69692 .74403 L .6993 .74189 L F
.713 .547 .663 r
.40052 .88031 m .40342 .8832 L .4021 .88031 L F
.40052 .88031 m .40124 .88359 L .40342 .8832 L F
.702 .45 .541 r
.51846 .82694 m .51709 .83055 L .51478 .82993 L F
.949 .629 .39 r
.56967 .83256 m .5705 .83133 L .57005 .83032 L F
.362 0 .199 r
.5705 .83133 m .57318 .83104 L .5719 .83241 L F
.5705 .83133 m .5719 .83241 L .57005 .83032 L F
.52 0 0 r
.49984 .84243 m .49876 .84134 L .49926 .84298 L F
.49984 .84243 m .50086 .8433 L .49876 .84134 L F
.113 .666 .754 r
.58501 .84764 m .58391 .84766 L .58234 .84743 L F
.58501 .84764 m .58724 .84743 L .58391 .84766 L F
0 .024 .56 r
.57335 .84604 m .57417 .8471 L .57351 .84596 L F
.429 .111 .322 r
.39729 .77793 m .39642 .7801 L .39445 .78049 L F
.45 .128 .327 r
.39939 .77752 m .39642 .7801 L .39729 .77793 L F
.719 .82 .928 r
.42387 .88755 m .42476 .88539 L .42234 .88738 L F
.42387 .88755 m .42604 .88652 L .42476 .88539 L F
.227 0 .257 r
.66128 .71469 m .6613 .71637 L .66265 .71462 L F
0 0 .199 r
.56483 .84119 m .56527 .84319 L .56529 .84284 L F
.56483 .84119 m .56529 .84284 L .56406 .84012 L F
.98 .892 .542 r
.61376 .81738 m .61441 .81525 L .61401 .81308 L F
.499 .135 .279 r
.34169 .73247 m .34505 .73018 L .34302 .73047 L F
.87 .731 .706 r
.4021 .88031 m .40342 .8832 L .40442 .87943 L F
.685 .533 .674 r
.40342 .8832 m .40649 .88344 L .40442 .87943 L F
.465 .629 .924 r
.40442 .87943 m .40844 .8809 L .40703 .87996 L F
.676 .53 .679 r
.40442 .87943 m .4087 .88316 L .40844 .8809 L F
.40442 .87943 m .40649 .88344 L .4087 .88316 L F
.701 .614 .756 r
.65268 .74381 m .65377 .7468 L .65052 .74628 L F
.719 .624 .75 r
.65268 .74381 m .65574 .74436 L .65377 .7468 L F
.622 .734 .927 r
.3479 .75389 m .35109 .75466 L .3497 .75368 L F
.659 .951 .951 r
.35209 .75351 m .35109 .75466 L .35308 .75358 L F
.35153 .75373 m .35109 .75466 L .35209 .75351 L F
.469 .756 .992 r
.3497 .75368 m .35109 .75466 L .35165 .75348 L F
.553 .213 .347 r
.3536 .75391 m .34801 .75745 L .34801 .75511 L F
.35017 .75427 m .34801 .75511 L .34801 .75449 L F
.3536 .75391 m .34801 .75511 L .35017 .75427 L F
.659 .951 .951 r
.35165 .75348 m .35153 .75373 L .35209 .75351 L F
.71 .657 .795 r
.49685 .83292 m .49438 .83347 L .49663 .83124 L F
.515 .658 .924 r
.327 .6767 m .3261 .67818 L .32496 .67648 L F
.327 .6767 m .3282 .67861 L .3261 .67818 L F
.345 .272 .63 r
.68833 .70697 m .69027 .70608 L .68994 .70376 L F
.339 .198 .538 r
.68833 .70697 m .69026 .70831 L .69027 .70608 L F
.68833 .70697 m .68818 .71131 L .69026 .70831 L F
.736 .782 .89 r
.64395 .74095 m .64077 .74083 L .64322 .73886 L F
.77 .8 .877 r
.64623 .73904 m .64395 .74095 L .64322 .73886 L F
0 0 .528 r
.69242 .72752 m .69277 .73093 L .69225 .73098 L F
.706 .347 0 r
.69256 .73197 m .69225 .73098 L .69277 .73093 L F
.69256 .73197 m .69305 .733 L .69225 .73098 L F
.743 .791 .891 r
.40981 .88854 m .41322 .88841 L .41205 .8884 L F
.013 0 0 r
.41322 .88841 m .41523 .88843 L .41205 .8884 L F
.665 .831 .963 r
.6911 .72018 m .69467 .72052 L .6937 .71984 L F
.592 .372 .551 r
.40173 .76222 m .40397 .76208 L .40404 .75978 L F
.538 .295 .494 r
.40397 .76208 m .40659 .75969 L .40404 .75978 L F
.691 .2 .074 r
.53375 .85597 m .53135 .85568 L .53135 .85601 L F
.838 .721 .735 r
.53251 .85777 m .53375 .85597 L .53135 .85601 L F
0 0 .233 r
.67042 .71457 m .67094 .71633 L .67119 .7176 L F
.983 .769 .362 r
.67048 .71836 m .67119 .7176 L .67094 .71633 L F
.67048 .71836 m .67111 .7197 L .67119 .7176 L F
.581 .276 .416 r
.37054 .78277 m .37268 .7828 L .37329 .78112 L F
.533 .262 .449 r
.37268 .7828 m .37525 .7807 L .37329 .78112 L F
.737 .472 .527 r
.50208 .85957 m .50222 .85708 L .49889 .85667 L F
.627 .377 .52 r
.50208 .85957 m .50431 .8592 L .50222 .85708 L F
.621 .377 .528 r
.50222 .85708 m .50431 .8592 L .50434 .85695 L F
.656 .456 .601 r
.39467 .88303 m .39793 .88562 L .39627 .8833 L F
.39467 .88303 m .39509 .88609 L .39793 .88562 L F
.825 .664 .682 r
.60182 .79906 m .60329 .80231 L .6014 .80112 L F
.762 .647 .734 r
.60329 .80231 m .59947 .80401 L .6014 .80112 L F
.60329 .80231 m .60224 .80341 L .59947 .80401 L F
.884 .551 .412 r
.55558 .81233 m .55398 .81216 L .55336 .80985 L F
.965 .64 .278 r
.55558 .81233 m .5552 .81422 L .55398 .81216 L F
.55558 .81233 m .55603 .81476 L .5552 .81422 L F
.821 .551 .531 r
.51752 .88064 m .51723 .87834 L .51433 .87761 L F
.388 0 0 r
.46188 .88287 m .46279 .88309 L .46373 .88323 L F
.088 0 0 r
.46279 .88309 m .46588 .88273 L .46373 .88323 L F
.818 .705 .74 r
.66207 .76402 m .66347 .76289 L .66144 .76172 L F
0 0 .354 r
.53176 .83057 m .53315 .8295 L .53261 .82764 L F
.227 .279 .708 r
.53246 .83227 m .53315 .8295 L .53176 .83057 L F
.709 .209 .046 r
.58522 .775 m .58733 .7768 L .58856 .77601 L F
.363 0 0 r
.58733 .7768 m .59092 .77677 L .58856 .77601 L F
.254 0 0 r
.46188 .88287 m .46211 .88308 L .46127 .88266 L F
.46188 .88287 m .46373 .88323 L .46211 .88308 L F
.996 .859 .573 r
.59655 .81463 m .59681 .81651 L .59468 .81764 L F
.9 .822 .761 r
.59681 .81651 m .59527 .81995 L .59468 .81764 L F
.698 .508 .627 r
.59966 .78601 m .59617 .78834 L .59621 .78606 L F
0 0 0 r
.59274 .84735 m .59571 .84634 L .59515 .84702 L F
.113 0 0 r
.59744 .84625 m .59571 .84634 L .59756 .84574 L F
.702 .616 .758 r
.65083 .74472 m .65268 .74381 L .65052 .74628 L F
.4 0 .12 r
.67559 .75999 m .67684 .76136 L .67459 .76126 L F
.67559 .75999 m .67779 .75975 L .67684 .76136 L F
.687 .647 .805 r
.49587 .8544 m .49889 .85667 L .49941 .85461 L F
.144 0 0 r
.56929 .77615 m .57132 .77578 L .57219 .77518 L F
.16 0 0 r
.57132 .77578 m .57419 .77481 L .57219 .77518 L F
.925 .747 .642 r
.61961 .79804 m .62092 .79909 L .61994 .79622 L F
.912 .851 .77 r
.61807 .80133 m .62092 .79909 L .61961 .79804 L F
.61807 .80133 m .61932 .80203 L .62092 .79909 L F
.693 .597 .744 r
.50011 .84668 m .49725 .84794 L .49889 .84816 L F
.542 .15 .248 r
.50001 .85051 m .49725 .84794 L .50008 .84939 L F
.66 .511 .67 r
.50011 .84668 m .50008 .84939 L .49725 .84794 L F
.763 .805 .323 r
.61133 .82463 m .61221 .82245 L .61219 .82263 L F
.232 .741 .883 r
.48743 .86937 m .4854 .86972 L .48515 .86748 L F
.753 .491 .536 r
.48609 .86921 m .48743 .86937 L .4861 .86911 L F
.232 .741 .883 r
.48743 .86937 m .48918 .86958 L .4854 .86972 L F
.753 .491 .536 r
.48589 .87209 m .48872 .87163 L .48743 .86937 L F
.799 .699 .755 r
.48589 .87209 m .48701 .87375 L .48707 .87367 L F
.48646 .872 m .48707 .87367 L .48872 .87163 L F
.48589 .87209 m .48707 .87367 L .48646 .872 L F
.938 .567 .212 r
.48612 .87363 m .48701 .87375 L .48589 .87209 L F
.48612 .87363 m .48701 .87375 L .48589 .87209 L F
0 0 .355 r
.48612 .87363 m .48589 .87209 L .48607 .86999 L F
.988 .72 .406 r
.48523 .87241 m .48612 .87363 L .48609 .871 L F
.939 .798 .338 r
.48607 .86999 m .48589 .87209 L .48602 .87019 L F
.988 .72 .406 r
.48601 .87017 m .48602 .87019 L .48607 .86999 L F
.851 .739 .739 r
.48269 .87112 m .48607 .86999 L .4861 .86911 L F
.939 .798 .338 r
.48607 .86999 m .48602 .87019 L .4861 .86911 L F
.988 .72 .406 r
.48602 .87019 m .48608 .8703 L .48607 .86999 L F
.753 .491 .536 r
.48589 .87209 m .48647 .87106 L .48602 .87019 L F
.988 .72 .406 r
.48595 .87062 m .48609 .871 L .48608 .8703 L F
.48523 .87241 m .48609 .871 L .48595 .87062 L F
.48523 .87241 m .48608 .8703 L .48601 .87017 L F
.753 .491 .536 r
.48602 .87019 m .48743 .86937 L .48609 .86921 L F
.48647 .87106 m .48743 .86937 L .48602 .87019 L F
.232 .741 .883 r
.48743 .86937 m .48937 .86957 L .48918 .86958 L F
.804 .716 .768 r
.53347 .84424 m .53654 .84615 L .53652 .84424 L F
.53347 .84424 m .53578 .84679 L .53654 .84615 L F
.685 .847 .96 r
.53652 .84424 m .53654 .84615 L .54013 .84442 L F
.597 .743 .946 r
.53654 .84615 m .54087 .84648 L .54013 .84442 L F
.8 .676 .727 r
.55827 .81802 m .56009 .81988 L .55925 .81871 L F
.848 .428 0 r
.56009 .81988 m .56033 .82152 L .55925 .81871 L F
.56009 .81988 m .56111 .82225 L .56033 .82152 L F
.202 .703 .911 r
.59059 .84709 m .59044 .84756 L .59274 .84735 L F
.669 .71 .878 r
.41615 .86696 m .41941 .86758 L .41921 .8653 L F
.652 .529 .701 r
.41921 .8653 m .41941 .86758 L .42144 .86491 L F
.186 0 .171 r
.35965 .80561 m .359 .80419 L .36089 .8037 L F
.35965 .80561 m .35803 .80656 L .359 .80419 L F
.783 .646 .711 r
.58207 .78337 m .57909 .78318 L .58052 .7803 L F
.708 .511 .62 r
.58191 .78496 m .57909 .78318 L .58207 .78337 L F
.623 .324 .442 r
.58207 .78337 m .58441 .78531 L .58191 .78496 L F
.651 .309 .38 r
.58414 .78372 m .58441 .78531 L .58207 .78337 L F
.748 .385 .366 r
.50942 .8769 m .5114 .87816 L .51237 .8772 L F
.533 .11 .184 r
.51237 .8772 m .5114 .87816 L .51433 .87761 L F
.705 .598 .734 r
.70742 .70427 m .705 .70481 L .70385 .70171 L F
.743 .714 .824 r
.50703 .81982 m .50822 .82188 L .51054 .82025 L F
.771 .769 .851 r
.64334 .7169 m .64386 .72024 L .64065 .71904 L F
.505 .049 .103 r
.64386 .72024 m .64383 .72169 L .64079 .72216 L F
.496 .361 .627 r
.64334 .7169 m .64415 .71758 L .64386 .72024 L F
.684 .497 .628 r
.43387 .84412 m .43627 .84628 L .43622 .84396 L F
.43387 .84412 m .43408 .84658 L .43627 .84628 L F
.749 .743 .847 r
.59468 .81764 m .59527 .81995 L .59215 .81994 L F
.83 .528 .48 r
.60001 .80636 m .59743 .80435 L .59947 .80401 L F
.60001 .80636 m .59813 .80689 L .59743 .80435 L F
.935 .907 .769 r
.60001 .80636 m .59734 .80898 L .59813 .80689 L F
.60001 .80636 m .59827 .8096 L .59734 .80898 L F
.765 .667 .754 r
.60224 .80341 m .60001 .80636 L .59947 .80401 L F
.564 .729 .952 r
.37954 .72533 m .37755 .72572 L .3763 .72438 L F
.253 .356 .775 r
.67489 .70922 m .67717 .7111 L .67577 .71241 L F
0 0 .348 r
.67577 .71241 m .67685 .7139 L .67593 .71455 L F
.974 .807 .389 r
.55513 .8384 m .55503 .83571 L .55526 .83845 L F
.994 .864 .588 r
.5538 .84068 m .55464 .84153 L .55513 .8384 L F
.5538 .84068 m .55513 .8384 L .55526 .83845 L F
0 .335 .797 r
.67721 .71742 m .6797 .71879 L .68059 .71996 L F
.39 .754 .992 r
.68133 .71909 m .68059 .71996 L .6797 .71879 L F
.68133 .71909 m .68292 .71977 L .68059 .71996 L F
0 0 .328 r
.53019 .81168 m .53077 .81454 L .53035 .81149 L F
.074 0 0 r
.53035 .81149 m .53285 .80941 L .53019 .81168 L F
.497 .236 .449 r
.4232 .76196 m .42084 .7637 L .42119 .7624 L F
.78 .891 .924 r
.71461 .73295 m .71457 .73445 L .71327 .73547 L F
.71461 .73295 m .71645 .73321 L .71457 .73445 L F
.591 .407 .601 r
.71457 .73445 m .71645 .73321 L .7167 .73565 L F
.561 .509 .755 r
.49977 .8354 m .49685 .83292 L .49977 .83336 L F
.64 .505 .682 r
.42888 .84863 m .43193 .85165 L .43055 .84778 L F
.42888 .84863 m .42972 .85206 L .43193 .85165 L F
.545 .38 .608 r
.43833 .73862 m .4381 .74144 L .44014 .74098 L F
.745 .596 .691 r
.66241 .73581 m .65905 .73581 L .65926 .73346 L F
.344 0 .182 r
.66241 .73581 m .65949 .73819 L .65905 .73581 L F
.66241 .73581 m .66179 .73794 L .65949 .73819 L F
.75 .358 .309 r
.66441 .73787 m .66179 .73794 L .66241 .73581 L F
0 .323 .686 r
.69912 .74931 m .69823 .74899 L .69693 .74868 L F
0 0 0 r
.69912 .74931 m .69836 .74982 L .69922 .74929 L F
.69912 .74931 m .70026 .74865 L .70152 .74931 L F
.69912 .74931 m .69922 .74929 L .70026 .74865 L F
0 .323 .686 r
.69912 .74931 m .70018 .74986 L .699 .74933 L F
.69912 .74931 m .699 .74933 L .69823 .74899 L F
.567 .366 .568 r
.43052 .75408 m .43035 .75656 L .42842 .75685 L F
.553 .391 .616 r
.43233 .75179 m .43254 .75375 L .43052 .75408 L F
.528 .334 .561 r
.43241 .75557 m .43052 .75408 L .43254 .75375 L F
.43241 .75557 m .43035 .75656 L .43052 .75408 L F
.568 .819 .992 r
.69424 .70925 m .69754 .70956 L .69615 .7085 L F
.618 .707 .909 r
.41001 .73645 m .40675 .73545 L .40894 .73455 L F
.589 .636 .866 r
.41206 .73603 m .41001 .73645 L .40894 .73455 L F
.877 .797 .768 r
.71151 .73817 m .70833 .74055 L .71107 .73807 L F
.71151 .73817 m .70981 .74121 L .70833 .74055 L F
.83 1 .807 r
.71327 .73547 m .71151 .73817 L .71107 .73807 L F
0 0 .284 r
.67569 .72564 m .67645 .7276 L .67535 .72463 L F
.817 .997 .777 r
.53308 .84906 m .5335 .84932 L .53578 .84679 L F
.934 .937 .584 r
.53221 .85097 m .5335 .84932 L .53308 .84906 L F
.208 0 0 r
.49044 .86981 m .48937 .86957 L .48743 .86937 L F
.757 .702 .801 r
.6317 .7752 m .63448 .77526 L .63365 .77228 L F
.767 .61 .684 r
.63284 .77816 m .63448 .77526 L .6317 .7752 L F
.804 .729 .781 r
.63365 .77228 m .63448 .77526 L .63638 .77259 L F
.724 .858 .945 r
.58911 .81946 m .58832 .82093 L .58752 .81985 L F
.959 .917 .725 r
.66387 .74036 m .66441 .73787 L .66445 .73882 L F
.182 0 0 r
.46588 .88273 m .46888 .8819 L .46798 .88297 L F
.638 .189 .17 r
.46888 .8819 m .4711 .88307 L .46798 .88297 L F
.212 0 0 r
.46888 .8819 m .47255 .88295 L .4711 .88307 L F
.017 .585 .781 r
.47094 .8699 m .47428 .87024 L .47221 .87054 L F
.693 .962 .719 r
.67239 .70818 m .67221 .70785 L .67161 .70662 L F
0 .369 .736 r
.67297 .70831 m .67239 .70818 L .67161 .70662 L F
.67297 .70831 m .67489 .70922 L .67239 .70818 L F
.592 .397 .586 r
.41941 .86758 m .41719 .87019 L .41934 .86987 L F
.645 .518 .695 r
.41941 .86758 m .42184 .86747 L .42144 .86491 L F
.65 .457 .609 r
.41934 .86987 m .42184 .86747 L .41941 .86758 L F
.652 .663 .848 r
.66239 .75105 m .65906 .74911 L .66164 .74866 L F
.759 .774 .865 r
.66468 .74902 m .66239 .75105 L .66164 .74866 L F
.705 .598 .734 r
.70742 .70427 m .70463 .70227 L .70559 .70271 L F
.098 .652 .794 r
.70511 .70322 m .70672 .70324 L .70559 .70271 L F
.44 .641 .942 r
.70944 .70327 m .70742 .70427 L .70559 .70271 L F
.098 .652 .794 r
.70672 .70324 m .70944 .70327 L .70559 .70271 L F
.705 .598 .734 r
.70463 .70227 m .70385 .70171 L .70559 .70271 L F
.44 .641 .942 r
.70944 .70327 m .70921 .70405 L .70742 .70427 L F
.393 .097 .34 r
.50443 .82752 m .50512 .82959 L .50595 .82848 L F
.50443 .82752 m .5031 .83044 L .50512 .82959 L F
.672 .528 .68 r
.40981 .87432 m .41208 .87232 L .40977 .87296 L F
.71 .659 .798 r
.40438 .88868 m .40787 .89073 L .40652 .88818 L F
.739 .713 .827 r
.40652 .88818 m .40787 .89073 L .40981 .88854 L F
.869 .902 .854 r
.55861 .80643 m .55974 .80705 L .5616 .80454 L F
.567 .432 .656 r
.55974 .80705 m .56199 .80678 L .5616 .80454 L F
.406 .791 .99 r
.55861 .80643 m .56199 .80678 L .55974 .80705 L F
.401 .027 .211 r
.36851 .79846 m .3673 .80075 L .36533 .8011 L F
.363 .048 .291 r
.36851 .79846 m .37105 .79662 L .36993 .79895 L F
.267 0 .14 r
.36898 .80024 m .36851 .79846 L .36993 .79895 L F
.36898 .80024 m .3673 .80075 L .36851 .79846 L F
.284 0 0 r
.34711 .72998 m .34911 .7296 L .35059 .72807 L F
.279 0 0 r
.35059 .72807 m .3511 .72921 L .35244 .72751 L F
.35059 .72807 m .34911 .7296 L .3511 .72921 L F
.601 .037 0 r
.49968 .86017 m .50378 .86184 L .50309 .86137 L F
.6 .065 0 r
.50309 .86137 m .50378 .86184 L .50517 .86323 L F
.786 .705 .774 r
.64346 .76464 m .64648 .76494 L .64544 .7621 L F
.818 .648 .671 r
.64346 .76464 m .64573 .76687 L .64648 .76494 L F
.709 .666 .805 r
.64544 .7621 m .64648 .76494 L .6488 .7642 L F
.947 .873 .731 r
.58359 .81573 m .58309 .81762 L .58183 .81695 L F
.963 .85 .682 r
.58183 .81695 m .58309 .81762 L .58188 .81976 L F
.607 .647 .864 r
.71289 .70618 m .71044 .70667 L .70921 .70405 L F
.093 .25 .734 r
.71325 .70888 m .71044 .70667 L .71289 .70618 L F
.171 0 0 r
.48868 .88367 m .48953 .88408 L .48719 .88458 L F
.48868 .88367 m .4906 .88372 L .48953 .88408 L F
.584 .437 .648 r
.50773 .84873 m .5053 .84651 L .50755 .84634 L F
.50773 .84873 m .50555 .84915 L .50538 .84729 L F
.50773 .84873 m .50538 .84729 L .50594 .84709 L F
.638 .433 .589 r
.50755 .84634 m .50773 .84873 L .5053 .84651 L F
.75 .559 .638 r
.50893 .84623 m .50958 .8469 L .50755 .84634 L F
.737 .493 .56 r
.50958 .8469 m .50773 .84873 L .50755 .84634 L F
.74 .51 .582 r
.50893 .84623 m .50773 .84873 L .50755 .84634 L F
.224 0 0 r
.50764 .8465 m .50616 .84819 L .50824 .84755 L F
.50755 .84634 m .50736 .8466 L .50764 .8465 L F
.50736 .8466 m .50616 .84819 L .50764 .8465 L F
.584 .437 .648 r
.50594 .84709 m .50538 .84729 L .5053 .84651 L F
.359 .252 .595 r
.42243 .74635 m .42099 .74913 L .42005 .74634 L F
.42243 .74635 m .42265 .74887 L .42099 .74913 L F
.391 .506 .855 r
.42265 .74887 m .42347 .74997 L .42099 .74913 L F
.392 .841 .743 r
.70444 .75327 m .707 .75215 L .7054 .7527 L F
.615 .851 .482 r
.70799 .75072 m .707 .75215 L .70817 .75056 L F
.707 .984 .826 r
.7054 .7527 m .707 .75215 L .70799 .75072 L F
.349 .795 .955 r
.57783 .84741 m .58014 .84797 L .58208 .84769 L F
0 0 .527 r
.56527 .84319 m .56701 .8453 L .56529 .84284 L F
.537 0 0 r
.47255 .88295 m .47437 .88356 L .4711 .88307 L F
0 0 .287 r
.52672 .84012 m .52615 .84156 L .52555 .84093 L F
.52672 .84012 m .52687 .84316 L .52615 .84156 L F
.335 0 .07 r
.52687 .84316 m .5248 .84355 L .52615 .84156 L F
.264 .509 .902 r
.52672 .84012 m .52615 .84156 L .52555 .84093 L F
.57 .305 .475 r
.5073 .83076 m .50713 .83269 L .50464 .83289 L F
.636 .361 .485 r
.5073 .83076 m .50933 .83282 L .50713 .83269 L F
.602 .45 .648 r
.50935 .82802 m .50957 .83055 L .5073 .83076 L F
.583 .364 .549 r
.50957 .83055 m .50933 .83282 L .5073 .83076 L F
.655 .506 .669 r
.42773 .85456 m .42783 .85692 L .42996 .85422 L F
.745 .431 .452 r
.48735 .87535 m .48904 .87568 L .48739 .87483 L F
.736 .54 .627 r
.60147 .78813 m .59966 .78601 L .60145 .78593 L F
.921 .618 .453 r
.56546 .80141 m .56614 .80382 L .56795 .80439 L F
.97 .739 .534 r
.56635 .80611 m .56795 .80439 L .56614 .80382 L F
.56635 .80611 m .56769 .80686 L .56795 .80439 L F
.521 .366 .612 r
.42172 .74116 m .42178 .74358 L .41982 .74388 L F
.589 .506 .729 r
.42178 .74358 m .42005 .74634 L .41982 .74388 L F
.65 .813 .962 r
.41533 .73633 m .41206 .73603 L .41411 .73557 L F
.393 .679 .975 r
.4161 .73524 m .41533 .73633 L .41411 .73557 L F
.4161 .73524 m .41743 .73649 L .41533 .73633 L F
.877 .734 .7 r
.60319 .79603 m .60095 .79619 L .60231 .79329 L F
.9 .797 .737 r
.60319 .79603 m .6004 .79836 L .60095 .79619 L F
.60319 .79603 m .60182 .79906 L .6004 .79836 L F
.538 .843 .999 r
.59771 .82454 m .59669 .8257 L .59885 .82517 L F
.59771 .82454 m .59669 .8257 L .59885 .82517 L F
.962 .735 .548 r
.59827 .8096 m .59695 .81129 L .59734 .80898 L F
.59827 .8096 m .59801 .81171 L .59695 .81129 L F
.578 .779 .974 r
.66837 .70604 m .67161 .70662 L .66941 .70701 L F
.702 .443 .53 r
.67221 .70785 m .66941 .70701 L .67161 .70662 L F
.67221 .70785 m .66837 .70604 L .66941 .70701 L F
.67221 .70785 m .66902 .70891 L .66837 .70604 L F
0 .027 .542 r
.66902 .70891 m .66885 .70693 L .66837 .70604 L F
.972 .839 .653 r
.66902 .70891 m .66825 .70954 L .66971 .70761 L F
0 .189 .626 r
.66805 .7101 m .66703 .7099 L .66699 .70858 L F
.66856 .71083 m .66793 .71045 L .66805 .7101 L F
.66793 .71045 m .66703 .7099 L .66805 .7101 L F
.758 .266 0 r
.66755 .7101 m .66856 .71083 L .66808 .71015 L F
.66755 .7101 m .66808 .71015 L .66699 .70858 L F
.648 .132 .003 r
.66429 .70946 m .66511 .71016 L .66755 .7101 L F
.447 .198 .442 r
.66203 .71022 m .66352 .71014 L .66353 .70874 L F
.66352 .71014 m .66494 .71006 L .66393 .70911 L F
.66352 .71014 m .66393 .70911 L .66353 .70874 L F
.748 .333 .263 r
.66403 .70886 m .66535 .70774 L .66443 .70785 L F
.66403 .70886 m .66755 .7101 L .66535 .70774 L F
.66429 .70946 m .66755 .7101 L .66403 .70886 L F
.447 .198 .442 r
.66384 .70844 m .66494 .71006 L .66443 .70785 L F
.66353 .70874 m .66429 .70946 L .66384 .70844 L F
.66429 .70946 m .66494 .71006 L .66384 .70844 L F
.748 .333 .263 r
.66351 .7093 m .66429 .70946 L .66403 .70886 L F
.66351 .7093 m .66403 .70886 L .66443 .70785 L F
.661 .331 .403 r
.66494 .71006 m .665 .71031 L .66351 .7093 L F
.648 .132 .003 r
.66351 .7093 m .66538 .71047 L .66429 .70946 L F
.661 .331 .403 r
.66443 .70785 m .66494 .71006 L .66351 .7093 L F
.648 .132 .003 r
.66511 .71016 m .66578 .71072 L .66602 .71064 L F
.66511 .71016 m .66602 .71064 L .66755 .7101 L F
.66538 .71047 m .66578 .71072 L .66429 .70946 L F
.447 .198 .442 r
.66203 .71022 m .665 .71031 L .66494 .71006 L F
.58 .939 .798 r
.66755 .7101 m .66578 .71072 L .66689 .71005 L F
.972 .839 .653 r
.66825 .70954 m .66755 .7101 L .66839 .70913 L F
.758 .266 0 r
.66755 .7101 m .66699 .70858 L .66535 .70774 L F
.58 .939 .798 r
.66755 .7101 m .66689 .71005 L .66871 .70895 L F
.972 .839 .653 r
.66825 .70954 m .66839 .70913 L .66971 .70761 L F
0 .189 .626 r
.66856 .71083 m .66956 .71155 L .66703 .7099 L F
.084 .614 .869 r
.70262 .75001 m .70018 .74986 L .69912 .74931 L F
.672 .528 .68 r
.40981 .87432 m .413 .87577 L .41208 .87232 L F
.66 .511 .671 r
.41069 .8781 m .413 .87577 L .40981 .87432 L F
.97 .658 .36 r
.67 .72482 m .67115 .72558 L .66962 .72249 L F
.978 .797 .593 r
.67 .72482 m .67068 .72775 L .67115 .72558 L F
.896 .848 .789 r
.62684 .78216 m .62793 .78299 L .62764 .78053 L F
.87 .816 .794 r
.62483 .78506 m .62793 .78299 L .62684 .78216 L F
.62483 .78506 m .62613 .78577 L .62793 .78299 L F
.798 .787 .843 r
.62793 .78299 m .63053 .7806 L .62764 .78053 L F
.438 .755 .995 r
.3445 .66216 m .34493 .66103 L .34296 .66116 L F
.3445 .66216 m .34493 .66103 L .34296 .66116 L F
.335 .123 .436 r
.33053 .6916 m .33069 .69358 L .32925 .6938 L F
.347 .226 .569 r
.63601 .71777 m .63789 .71659 L .63762 .71422 L F
.869 .853 .824 r
.48262 .87488 m .48201 .87812 L .48078 .87759 L F
.695 .658 .81 r
.41473 .8888 m .4189 .88912 L .41724 .8872 L F
.609 .643 .859 r
.41216 .74711 m .41546 .74876 L .41422 .7468 L F
.468 .589 .892 r
.41422 .7468 m .41546 .74876 L .41691 .74777 L F
.392 .138 .405 r
.41439 .75072 m .41691 .74777 L .41546 .74876 L F
.742 .267 .12 r
.47391 .85107 m .47478 .85191 L .47626 .85181 L F
.435 .871 .904 r
.47626 .85181 m .47736 .85104 L .47837 .85151 L F
.47626 .85181 m .47478 .85191 L .47736 .85104 L F
.799 .741 .799 r
.63365 .77228 m .63638 .77259 L .63581 .76966 L F
.733 .699 .818 r
.63581 .76966 m .63638 .77259 L .63908 .7701 L F
.763 .606 .684 r
.54642 .84428 m .54625 .84643 L .54307 .84624 L F
.659 .514 .676 r
.54837 .84377 m .54625 .84643 L .54642 .84428 L F
.729 .741 .224 r
.55423 .84276 m .55464 .84153 L .5538 .84068 L F
.55423 .84276 m .55406 .84371 L .55464 .84153 L F
.525 .755 .98 r
.44383 .88185 m .44561 .88234 L .44511 .8805 L F
.582 .795 .98 r
.44511 .8805 m .44561 .88234 L .44843 .88103 L F
.622 .727 .922 r
.44561 .88234 m .4498 .88239 L .44843 .88103 L F
.428 .828 .98 r
.36806 .74841 m .36461 .74837 L .36608 .74836 L F
.36461 .74837 m .36806 .74841 L .36608 .74836 L F
.625 .467 .648 r
.43835 .84128 m .44073 .8434 L .44054 .84093 L F
.43835 .84128 m .43845 .84364 L .44073 .8434 L F
.712 .709 .846 r
.39923 .89036 m .40217 .89063 L .40215 .88894 L F
.639 .548 .736 r
.40215 .88894 m .40217 .89063 L .40438 .88868 L F
.863 .819 .804 r
.62415 .78857 m .62613 .78577 L .62483 .78506 L F
.9 .588 .093 r
.67194 .73196 m .67202 .73068 L .67135 .72983 L F
.67194 .73196 m .67241 .73252 L .67202 .73068 L F
.386 .567 .908 r
.56171 .79817 m .56046 .79937 L .56003 .79801 L F
.772 .309 .146 r
.56165 .80224 m .56345 .80171 L .56046 .79937 L F
.56165 .80224 m .56046 .79937 L .56171 .79817 L F
.452 .128 .325 r
.46861 .85706 m .47015 .85843 L .47103 .85529 L F
0 0 .348 r
.47103 .85529 m .47136 .85675 L .47128 .85395 L F
.587 .254 .372 r
.47103 .85529 m .47015 .85843 L .47136 .85675 L F
.259 .721 .95 r
.71642 .7283 m .71429 .72865 L .71355 .72708 L F
.71642 .7283 m .71734 .72867 L .71429 .72865 L F
.234 0 .014 r
.47151 .83015 m .47272 .83053 L .47354 .82969 L F
.47151 .83015 m .47001 .83207 L .47272 .83053 L F
.892 .767 .716 r
.61636 .80422 m .61932 .80203 L .61807 .80133 L F
.61636 .80422 m .61859 .80395 L .61932 .80203 L F
.586 .441 .651 r
.61442 .75688 m .61676 .75704 L .61648 .75407 L F
.613 .477 .673 r
.61487 .75918 m .61676 .75704 L .61442 .75688 L F
.649 .437 .582 r
.44784 .83528 m .45011 .83325 L .44805 .83383 L F
.568 .936 .912 r
.68888 .7115 m .69238 .71038 L .69046 .71021 L F
.736 .931 .954 r
.69331 .70864 m .69238 .71038 L .69424 .70925 L F
.69331 .70864 m .69046 .71021 L .69238 .71038 L F
.185 .713 .714 r
.58828 .81962 m .58752 .81985 L .58615 .81792 L F
.58828 .81962 m .58911 .81946 L .58752 .81985 L F
.737 .472 .527 r
.50208 .85957 m .49889 .85667 L .49968 .86017 L F
.572 .54 .781 r
.49968 .86017 m .50309 .86137 L .50208 .85957 L F
.92 .821 .732 r
.62281 .79158 m .62415 .78857 L .62293 .78779 L F
.863 .819 .804 r
.62415 .78857 m .62483 .78506 L .62293 .78779 L F
.655 .559 .733 r
.63701 .73548 m .63491 .73773 L .63468 .73588 L F
.577 .832 .993 r
.57109 .84661 m .57251 .84524 L .56991 .84585 L F
.57109 .84661 m .57335 .84604 L .57251 .84524 L F
.302 0 .093 r
.51444 .88302 m .51565 .88119 L .51752 .88064 L F
.668 .438 .563 r
.60548 .76481 m .60773 .767 L .60771 .76482 L F
.60548 .76481 m .60559 .76737 L .60773 .767 L F
.375 .031 .248 r
.37179 .79849 m .37105 .79662 L .37284 .79583 L F
.37179 .79849 m .36993 .79895 L .37105 .79662 L F
.757 .665 .761 r
.54625 .84643 m .54409 .8492 L .54307 .84624 L F
.594 .378 .558 r
.54409 .8492 m .54689 .84994 L .54299 .84852 L F
.54409 .8492 m .54835 .85221 L .54689 .84994 L F
.502 .48 .764 r
.54067 .83344 m .54309 .8352 L .54085 .83559 L F
.833 .362 .052 r
.55398 .81216 m .55105 .80924 L .55336 .80985 L F
.603 .598 .819 r
.54087 .84648 m .54184 .84325 L .54013 .84442 L F
.54087 .84648 m .54307 .84624 L .54184 .84325 L F
.573 .365 .56 r
.54087 .84648 m .54299 .84852 L .54307 .84624 L F
.54087 .84648 m .54299 .84852 L .54307 .84624 L F
.589 .367 .546 r
.61229 .76171 m .61487 .75918 L .61222 .75961 L F
.653 .707 .887 r
.523 .82533 m .51916 .82396 L .52145 .82427 L F
.639 .422 .573 r
.523 .82533 m .52251 .82833 L .52015 .82775 L F
.671 .154 0 r
.52145 .82427 m .52412 .82503 L .523 .82533 L F
.527 .321 .543 r
.52459 .82787 m .523 .82533 L .52412 .82503 L F
.52459 .82787 m .52251 .82833 L .523 .82533 L F
.387 .763 .991 r
.51602 .85319 m .51512 .85397 L .51454 .85396 L F
.51602 .85319 m .51727 .85386 L .51512 .85397 L F
.429 .781 .997 r
.47642 .88347 m .47781 .88422 L .4795 .88401 L F
.645 .721 .904 r
.40576 .74365 m .40872 .74429 L .40798 .74299 L F
.483 .635 .921 r
.40798 .74299 m .40872 .74429 L .40983 .74291 L F
.52 .69 .945 r
.40872 .74429 m .41103 .7442 L .40983 .74291 L F
.623 .571 .776 r
.40872 .74429 m .41216 .74711 L .41103 .7442 L F
.864 .839 .819 r
.66315 .72946 m .66179 .73136 L .66044 .73038 L F
.245 .233 .647 r
.65957 .70911 m .66027 .70616 L .65924 .70734 L F
.71 .643 .78 r
.65543 .74323 m .65574 .74436 L .65268 .74381 L F
.619 .557 .764 r
.65699 .74074 m .65574 .74436 L .65543 .74323 L F
.65699 .74074 m .65794 .74401 L .65574 .74436 L F
.695 .658 .81 r
.41473 .8888 m .41724 .8872 L .41523 .88843 L F
.339 .62 .955 r
.69146 .72636 m .69059 .7274 L .68941 .72631 L F
.69146 .72636 m .69242 .72752 L .69059 .7274 L F
.679 .532 .679 r
.41208 .87232 m .413 .87577 L .41515 .87301 L F
.607 .743 .941 r
.40379 .73181 m .4 .73096 L .40232 .73086 L F
.653 .829 .968 r
.4053 .73099 m .40379 .73181 L .40232 .73086 L F
.589 .506 .729 r
.42178 .74358 m .42243 .74635 L .42005 .74634 L F
.92 .871 .772 r
.57313 .78823 m .57458 .78914 L .57525 .78701 L F
.977 .775 .566 r
.57313 .78823 m .57368 .78972 L .57458 .78914 L F
.569 .493 .729 r
.57271 .79347 m .5708 .79437 L .57032 .7916 L F
.113 .658 .832 r
.5736 .79636 m .5708 .79437 L .57271 .79347 L F
.597 .566 .79 r
.57271 .79347 m .5736 .79636 L .5708 .79437 L F
.142 .261 .727 r
.57271 .79347 m .57463 .79539 L .5736 .79636 L F
.388 .163 .446 r
.57313 .7962 m .57301 .79654 L .57463 .79539 L F
.97 .892 .522 r
.57313 .7962 m .57251 .79806 L .5736 .79636 L F
.388 .163 .446 r
.57301 .79654 m .57251 .79806 L .57337 .79698 L F
0 0 0 r
.57463 .79539 m .57251 .79806 L .5736 .79636 L F
.388 .163 .446 r
.57301 .79654 m .57337 .79698 L .57463 .79539 L F
.113 .658 .832 r
.57187 .79514 m .57217 .79611 L .5708 .79437 L F
.5736 .79636 m .57275 .79621 L .57187 .79514 L F
.57275 .79621 m .57217 .79611 L .57187 .79514 L F
.399 0 .062 r
.45898 .83626 m .46107 .83614 L .46186 .8354 L F
0 0 0 r
.46107 .83614 m .46398 .83548 L .46186 .8354 L F
.986 .71 .368 r
.67562 .72006 m .67485 .7215 L .67483 .71932 L F
.67562 .72006 m .67578 .7225 L .67485 .7215 L F
.695 .698 .849 r
.65049 .73785 m .65384 .73842 L .65192 .7411 L F
.582 .607 .843 r
.65411 .74059 m .65192 .7411 L .65384 .73842 L F
.926 .973 .745 r
.70735 .74282 m .70833 .74055 L .70981 .74121 L F
.442 .402 .719 r
.70484 .74312 m .70529 .74652 L .70725 .74532 L F
.644 .592 .782 r
.70561 .74884 m .70725 .74532 L .70529 .74652 L F
.613 .319 .447 r
.38423 .7724 m .38658 .77224 L .38676 .77047 L F
.626 .353 .485 r
.38658 .77224 m .38909 .76962 L .38676 .77047 L F
.317 0 .149 r
.3608 .78806 m .36144 .78963 L .36268 .78764 L F
.3608 .78806 m .35954 .79015 L .36144 .78963 L F
.561 .29 .463 r
.40194 .77544 m .40148 .7774 L .39939 .77752 L F
.464 .148 .344 r
.40414 .77536 m .40148 .7774 L .40194 .77544 L F
.443 .853 .965 r
.59743 .80435 m .59864 .80354 L .59947 .80401 L F
.711 .424 0 r
.59743 .80435 m .59771 .80554 L .59864 .80354 L F
.59743 .80435 m .59813 .80689 L .59771 .80554 L F
.52 .343 .581 r
.64611 .72569 m .64807 .72272 L .64466 .72193 L F
.308 .094 .418 r
.64329 .71454 m .64334 .7169 L .64136 .71746 L F
.771 .769 .851 r
.64334 .7169 m .64065 .71904 L .64136 .71746 L F
.668 .498 .645 r
.41719 .87019 m .41515 .87301 L .41726 .87255 L F
.656 .518 .684 r
.41726 .87255 m .41934 .86987 L .41719 .87019 L F
.512 .285 .506 r
.39661 .76486 m .39841 .76448 L .39849 .76223 L F
.673 .416 .525 r
.39849 .76223 m .40139 .7642 L .40173 .76222 L F
.39849 .76223 m .39841 .76448 L .40139 .7642 L F
.9 .801 .741 r
.68057 .75137 m .68189 .75172 L .68174 .74842 L F
.922 .68 .555 r
.68188 .75403 m .68189 .75172 L .68057 .75137 L F
.219 0 0 r
.36217 .72507 m .36553 .72407 L .36343 .72485 L F
.232 .618 .955 r
.48651 .86736 m .48515 .86748 L .48383 .8665 L F
.276 .34 .749 r
.48743 .86937 m .48515 .86748 L .48651 .86736 L F
0 0 0 r
.52481 .83555 m .52644 .83274 L .52425 .83301 L F
.553 .831 .486 r
.69156 .74672 m .6928 .74525 L .69065 .74771 L F
.708 .234 .122 r
.69065 .74771 m .6938 .74864 L .69156 .74672 L F
.721 .587 .705 r
.40124 .88359 m .40123 .88582 L .40342 .8832 L F
.658 .495 .652 r
.40123 .88582 m .40366 .88569 L .40342 .8832 L F
.688 .519 .653 r
.40366 .88569 m .40649 .88344 L .40342 .8832 L F
.715 .35 .356 r
.56302 .81198 m .56526 .81409 L .56618 .8121 L F
.372 0 .195 r
.56618 .8121 m .56731 .81365 L .56852 .81153 L F
.56618 .8121 m .56526 .81409 L .56731 .81365 L F
0 0 .261 r
.60917 .83117 m .61058 .82793 L .61029 .82981 L F
0 0 0 r
.60822 .83237 m .60917 .83117 L .61029 .82981 L F
.409 0 .093 r
.53805 .84167 m .54036 .84132 L .54184 .83856 L F
.704 .36 .392 r
.51285 .84365 m .51495 .84588 L .51562 .84403 L F
.933 .883 .761 r
.51652 .84686 m .51562 .84403 L .51495 .84588 L F
.51652 .84686 m .517 .84318 L .51562 .84403 L F
.731 .623 .738 r
.64469 .71205 m .64499 .71398 L .64329 .71454 L F
.34 .031 .287 r
.64499 .71398 m .64334 .7169 L .64329 .71454 L F
.64499 .71398 m .64526 .71623 L .64334 .7169 L F
.218 .155 .568 r
.64695 .71109 m .64499 .71398 L .64469 .71205 L F
.64695 .71109 m .64726 .71348 L .64499 .71398 L F
.332 .127 .445 r
.64726 .71348 m .64526 .71623 L .64499 .71398 L F
.64 .344 .453 r
.48587 .82532 m .48704 .82462 L .48875 .82519 L F
.621 .468 .653 r
.61008 .76451 m .61229 .76171 L .61011 .76218 L F
.709 .666 .805 r
.64544 .7621 m .6488 .7642 L .6476 .76155 L F
.678 .659 .824 r
.6488 .7642 m .65071 .76205 L .6476 .76155 L F
.858 .548 .462 r
.492 .8767 m .49441 .8759 L .49304 .87611 L F
.492 .8767 m .4948 .87779 L .49441 .8759 L F
.445 .348 .651 r
.47462 .84865 m .47391 .85107 L .47278 .84965 L F
.338 .448 .826 r
.67593 .71455 m .67852 .71643 L .67721 .71742 L F
.304 .383 .779 r
.67852 .71643 m .6797 .71879 L .67721 .71742 L F
.737 .493 .56 r
.50958 .8469 m .51062 .84886 L .50773 .84873 L F
.728 .825 .368 r
.7128 .74372 m .71195 .74532 L .71195 .74552 L F
.73 .931 .594 r
.71474 .7408 m .7128 .74337 L .7128 .74372 L F
.762 .838 .381 r
.7128 .74337 m .71195 .74532 L .7128 .74372 L F
.863 .804 .791 r
.70385 .70171 m .70072 .70348 L .7035 .70437 L F
0 0 0 r
.7035 .70437 m .70559 .70271 L .70385 .70171 L F
.608 .479 .679 r
.48395 .85033 m .48164 .85171 L .48033 .84888 L F
.48395 .85033 m .48334 .85299 L .48164 .85171 L F
.626 .353 .485 r
.38658 .77224 m .38893 .77225 L .38909 .76962 L F
.523 .24 .426 r
.38893 .77225 m .39174 .7696 L .38909 .76962 L F
.778 .692 .768 r
.57289 .81738 m .5707 .82013 L .56969 .81726 L F
.128 .639 .896 r
.38838 .72729 m .39026 .72745 L .39154 .72793 L F
.665 .907 .978 r
.39154 .72793 m .39237 .72649 L .39357 .7275 L F
.39154 .72793 m .39026 .72745 L .39237 .72649 L F
.462 .874 .946 r
.3302 .69518 m .32925 .6938 L .33069 .69358 L F
.3302 .69518 m .32868 .69582 L .32925 .6938 L F
.52 .343 .581 r
.64611 .72569 m .64814 .725 L .64807 .72272 L F
.64807 .72272 m .64814 .725 L .64611 .72569 L F
0 0 0 r
.71645 .73321 m .71862 .73078 L .71742 .73215 L F
0 0 .443 r
.7167 .73565 m .71645 .73321 L .71742 .73215 L F
.635 .658 .855 r
.52923 .85664 m .53251 .85777 L .53135 .85601 L F
.707 .486 .586 r
.47746 .84649 m .47462 .84865 L .47496 .84639 L F
.786 .552 .583 r
.45011 .83325 m .45004 .83546 L .45354 .8358 L F
.714 .302 .264 r
.45004 .83546 m .45212 .83773 L .45354 .8358 L F
.494 .052 .126 r
.45354 .8358 m .45437 .83723 L .45548 .83522 L F
.45354 .8358 m .45212 .83773 L .45437 .83723 L F
0 0 0 r
.53188 .84414 m .53399 .84104 L .53232 .84188 L F
.53188 .84414 m .53284 .84339 L .53399 .84104 L F
.742 .981 .914 r
.53485 .83995 m .53399 .84104 L .53459 .83992 L F
0 0 0 r
.53399 .84104 m .53284 .84339 L .53459 .83992 L F
.864 .839 .819 r
.66315 .72946 m .66044 .73038 L .66271 .72692 L F
.839 .784 .799 r
.66351 .72733 m .66315 .72946 L .66271 .72692 L F
.664 .512 .668 r
.43055 .84778 m .43411 .84892 L .43408 .84658 L F
.636 .501 .682 r
.43055 .84778 m .43411 .85128 L .43411 .84892 L F
.43055 .84778 m .43193 .85165 L .43411 .85128 L F
.598 .178 .216 r
.50595 .82848 m .50885 .82986 L .50935 .82802 L F
.762 .346 .261 r
.50935 .82802 m .51168 .83014 L .51143 .8279 L F
.57 .426 .646 r
.51168 .83014 m .50957 .83055 L .50935 .82802 L F
.762 .346 .261 r
.50935 .82802 m .50885 .82986 L .51168 .83014 L F
.57 .426 .646 r
.51168 .83014 m .50935 .82802 L .51143 .8279 L F
.549 .342 .552 r
.42842 .75685 m .42781 .75963 L .42575 .75987 L F
.577 .368 .561 r
.42969 .75778 m .42842 .75685 L .43035 .75656 L F
.42969 .75778 m .42781 .75963 L .42842 .75685 L F
.596 .753 .953 r
.43432 .7513 m .43233 .75179 L .43028 .75033 L F
.551 .39 .616 r
.43471 .75329 m .43233 .75179 L .43432 .7513 L F
.43471 .75329 m .43254 .75375 L .43233 .75179 L F
.477 .763 .993 r
.48735 .87535 m .48904 .87568 L .4883 .87476 L F
.48735 .87535 m .48904 .87568 L .4883 .87476 L F
.51 .781 .994 r
.4883 .87476 m .48904 .87568 L .49046 .87452 L F
.49046 .87452 m .48904 .87568 L .4883 .87476 L F
0 0 0 r
.5803 .83006 m .57833 .83053 L .58008 .8301 L F
.818 .648 .671 r
.64346 .76464 m .6432 .7668 L .64573 .76687 L F
.814 .716 .757 r
.6432 .7668 m .64475 .76814 L .64573 .76687 L F
.54 .279 .468 r
.40681 .77275 m .40627 .77515 L .40414 .77536 L F
.516 .253 .454 r
.40894 .77239 m .40627 .77515 L .40681 .77275 L F
.751 .747 .848 r
.66044 .73038 m .65926 .73346 L .65809 .73285 L F
.926 .762 .659 r
.65926 .73346 m .65905 .73581 L .65809 .73285 L F
.947 .873 .731 r
.58359 .81573 m .58183 .81695 L .58247 .81471 L F
.62 .797 .967 r
.58448 .81423 m .58359 .81573 L .58247 .81471 L F
.58448 .81423 m .58443 .81547 L .58359 .81573 L F
.242 0 0 r
.56571 .77699 m .56787 .77688 L .56929 .77615 L F
0 0 0 r
.56929 .77615 m .56992 .77635 L .57132 .77578 L F
.56929 .77615 m .56787 .77688 L .56992 .77635 L F
.478 .112 .264 r
.38991 .74476 m .38949 .74641 L .38702 .74619 L F
.581 .206 .295 r
.39157 .74578 m .38991 .74476 L .39118 .74455 L F
.39157 .74578 m .38949 .74641 L .38991 .74476 L F
.698 .508 .627 r
.59966 .78601 m .59966 .78831 L .59617 .78834 L F
.736 .54 .627 r
.60147 .78813 m .59966 .78831 L .59966 .78601 L F
.915 .807 .726 r
.46404 .86198 m .46109 .86428 L .46227 .86097 L F
.46404 .86198 m .46281 .86521 L .46109 .86428 L F
.519 .232 .418 r
.41597 .76748 m .41346 .76948 L .41381 .76769 L F
.546 .291 .48 r
.40139 .7642 m .40349 .764 L .40173 .76222 L F
.569 .29 .454 r
.40173 .76222 m .40349 .764 L .40397 .76208 L F
.342 .514 .882 r
.54491 .84655 m .54817 .84789 L .54753 .84708 L F
.54491 .84655 m .54753 .84708 L .54595 .84511 L F
.291 0 0 r
.54349 .84627 m .54491 .84655 L .54307 .84624 L F
.54625 .84643 m .54491 .84655 L .54349 .84627 L F
.802 .984 .894 r
.51479 .85878 m .51572 .85791 L .51536 .85952 L F
.689 .558 .702 r
.42134 .86262 m .42144 .86491 L .42355 .86222 L F
.952 .904 .525 r
.67007 .71394 m .67118 .7123 L .66956 .71155 L F
.67007 .71394 m .67042 .71457 L .67118 .7123 L F
.721 .745 .871 r
.51054 .82025 m .50703 .81982 L .50902 .81996 L F
.743 .714 .824 r
.50703 .81982 m .51054 .82025 L .50902 .81996 L F
.422 0 0 r
.50902 .81996 m .51181 .81918 L .51054 .82025 L F
.50902 .81996 m .51181 .81918 L .51054 .82025 L F
.512 .139 .269 r
.48689 .85147 m .48585 .85362 L .48367 .85367 L F
.638 .389 .526 r
.48796 .85136 m .48585 .85362 L .48689 .85147 L F
.634 .673 .87 r
.70072 .70348 m .70133 .70561 L .7035 .70437 L F
.569 .493 .729 r
.57271 .79347 m .57032 .7916 L .57255 .79111 L F
.794 .569 .596 r
.56927 .79291 m .57255 .79111 L .57032 .7916 L F
.759 .61 .692 r
.39941 .88862 m .40215 .88894 L .40123 .88582 L F
.712 .709 .846 r
.39923 .89036 m .40215 .88894 L .39941 .88862 L F
.636 .522 .707 r
.40215 .88894 m .40366 .88569 L .40123 .88582 L F
.40215 .88894 m .40438 .88868 L .40366 .88569 L F
.693 .53 .662 r
.42565 .85718 m .42566 .8596 L .42783 .85692 L F
.769 .726 .813 r
.57289 .81738 m .56969 .81726 L .5717 .81528 L F
.508 .745 .981 r
.57367 .81566 m .57289 .81738 L .5717 .81528 L F
.57367 .81566 m .5745 .81696 L .57289 .81738 L F
.217 .215 .641 r
.57463 .81934 m .57289 .81738 L .5745 .81696 L F
.57463 .81934 m .57367 .81977 L .57289 .81738 L F
.73 .713 .834 r
.63666 .74421 m .6333 .74388 L .6352 .74296 L F
.786 .719 .789 r
.63876 .74175 m .63666 .74421 L .6352 .74296 L F
.586 .571 .804 r
.41216 .74711 m .41296 .74365 L .41103 .7442 L F
.41216 .74711 m .41422 .7468 L .41296 .74365 L F
.26 .759 .893 r
.47934 .84386 m .48152 .8436 L .48261 .84379 L F
.48261 .84379 m .48152 .8436 L .47934 .84386 L F
.512 .898 .952 r
.48261 .84379 m .48152 .8436 L .48347 .84291 L F
.607 .439 .629 r
.48261 .84379 m .48469 .84413 L .4847 .84113 L F
0 0 0 r
.4847 .84113 m .48347 .84291 L .48261 .84379 L F
.512 .898 .952 r
.48261 .84379 m .48152 .8436 L .48347 .84291 L F
.357 .675 .977 r
.48347 .84291 m .48469 .84413 L .48261 .84379 L F
.766 .584 .652 r
.50431 .8592 m .50728 .85717 L .50434 .85695 L F
.752 .644 .741 r
.64712 .7077 m .64773 .7093 L .65022 .70661 L F
.76 .387 .348 r
.58743 .78568 m .58441 .78531 L .58414 .78372 L F
.459 .17 .387 r
.39214 .78286 m .38974 .78479 L .39008 .78315 L F
.452 .517 .835 r
.46885 .86954 m .46985 .86699 L .46756 .8679 L F
.721 .55 .657 r
.46985 .86699 m .46951 .86717 L .46756 .8679 L F
.678 .73 .889 r
.46578 .86858 m .46885 .86954 L .46756 .8679 L F
.721 .55 .657 r
.46951 .86717 m .46667 .86865 L .46756 .8679 L F
.678 .73 .889 r
.4654 .86846 m .46578 .86858 L .46756 .8679 L F
.452 .517 .835 r
.46885 .86954 m .47094 .8699 L .46985 .86699 L F
.652 .598 .781 r
.6594 .76217 m .66207 .76402 L .66144 .76172 L F
.538 .384 .62 r
.4847 .84113 m .48678 .84347 L .48818 .84324 L F
.4847 .84113 m .48469 .84413 L .48678 .84347 L F
.79 .579 .616 r
.48684 .84085 m .48347 .84291 L .4847 .84113 L F
.628 .382 .526 r
.49361 .85072 m .49118 .84886 L .49521 .84817 L F
.365 .007 .218 r
.4955 .85037 m .49521 .84817 L .49525 .84822 L F
.777 .404 .35 r
.49447 .8496 m .49684 .85091 L .4955 .85037 L F
.49684 .85091 m .49747 .85126 L .4955 .85037 L F
.365 .007 .218 r
.4955 .85037 m .49361 .85072 L .49417 .84982 L F
.4955 .85037 m .49417 .84982 L .49521 .84817 L F
.754 .603 .689 r
.39725 .88741 m .40123 .88582 L .39793 .88562 L F
.39725 .88741 m .39941 .88862 L .40123 .88582 L F
.387 .759 .992 r
.52466 .84022 m .52672 .84012 L .52555 .84093 L F
.504 .14 .283 r
.3479 .75389 m .34614 .75638 L .34426 .75644 L F
.338 0 .173 r
.34801 .75449 m .3479 .75389 L .3497 .75368 L F
.34801 .75449 m .34614 .75638 L .3479 .75389 L F
.653 .69 .872 r
.65071 .76205 m .65343 .76384 L .65298 .76162 L F
.646 .669 .858 r
.65343 .76384 m .65515 .76101 L .65298 .76162 L F
.65343 .76384 m .6562 .76235 L .65515 .76101 L F
.641 .491 .664 r
.42355 .86222 m .42144 .86491 L .42374 .86459 L F
.611 .495 .696 r
.42144 .86491 m .42384 .86703 L .42374 .86459 L F
.42144 .86491 m .42184 .86747 L .42384 .86703 L F
.694 .156 0 r
.55827 .81802 m .55925 .81871 L .55779 .81874 L F
.925 .722 .609 r
.56033 .82152 m .55779 .81874 L .55925 .81871 L F
.544 .187 .312 r
.50949 .84581 m .51285 .84365 L .50938 .844 L F
.50949 .84581 m .51165 .84585 L .51285 .84365 L F
.7 .361 .398 r
.51285 .84365 m .51165 .84585 L .51495 .84588 L F
.573 .688 .919 r
.3292 .67635 m .3282 .67861 L .327 .6767 L F
.472 .569 .872 r
.3292 .67635 m .33067 .67878 L .3282 .67861 L F
.641 .083 0 r
.63529 .73214 m .63311 .73097 L .63298 .73091 L F
.748 .335 .267 r
.53843 .8112 m .54016 .81226 L .54158 .81191 L F
.84 .517 .442 r
.54016 .81226 m .54029 .81393 L .54158 .81191 L F
.795 .455 .412 r
.54029 .81393 m .54341 .81477 L .54158 .81191 L F
.658 .481 .633 r
.42783 .85692 m .42566 .8596 L .42796 .85933 L F
.635 .478 .653 r
.42783 .85692 m .43018 .85684 L .42996 .85422 L F
.588 .398 .592 r
.42796 .85933 m .43018 .85684 L .42783 .85692 L F
.568 .773 .975 r
.42476 .88539 m .42604 .88652 L .42808 .88603 L F
.629 .782 .955 r
.52923 .85664 m .53048 .8547 L .52848 .85375 L F
.52923 .85664 m .53135 .85601 L .53048 .8547 L F
.66 .737 .907 r
.40033 .74407 m .40374 .74459 L .40245 .74329 L F
.737 .711 .827 r
.40245 .74329 m .40374 .74459 L .40576 .74365 L F
.589 .285 .422 r
.62549 .73487 m .62784 .73309 L .62558 .73316 L F
.338 .617 .953 r
.53188 .84414 m .53347 .84424 L .53284 .84339 L F
.473 .313 .582 r
.459 .86202 m .45887 .86463 L .457 .86484 L F
.074 0 0 r
.53035 .81149 m .53176 .81105 L .53285 .80941 L F
.711 .356 .373 r
.53176 .81105 m .53512 .81076 L .53285 .80941 L F
.814 .744 .786 r
.62764 .78053 m .63053 .7806 L .62964 .77784 L F
.784 .729 .802 r
.63053 .7806 m .63284 .77816 L .62964 .77784 L F
.244 .645 .961 r
.4498 .88239 m .45257 .88331 L .45183 .88204 L F
.752 .809 .898 r
.45183 .88204 m .45257 .88331 L .45488 .88186 L F
.204 0 .027 r
.35594 .7912 m .35632 .79257 L .35792 .79079 L F
.35594 .7912 m .35454 .7932 L .35632 .79257 L F
.551 .242 .398 r
.6911 .72018 m .69309 .71873 L .69243 .71778 L F
.518 .42 .683 r
.62027 .7464 m .62222 .74607 L .6219 .74312 L F
.576 .438 .656 r
.62041 .74871 m .62222 .74607 L .62027 .7464 L F
.783 .661 .728 r
.38805 .89074 m .3904 .88832 L .38819 .8888 L F
.516 .704 .955 r
.4598 .8347 m .45898 .83626 L .45777 .83496 L F
.4598 .8347 m .46107 .83614 L .45898 .83626 L F
.504 0 0 r
.50086 .8433 m .50467 .84586 L .50397 .84415 L F
.828 .698 .72 r
.50467 .84586 m .50748 .84406 L .50397 .84415 L F
.794 .569 .596 r
.56927 .79291 m .57271 .79347 L .57255 .79111 L F
.886 .825 .781 r
.61673 .80677 m .61859 .80395 L .61636 .80422 L F
.711 .647 .784 r
.65411 .74059 m .65543 .74323 L .65268 .74381 L F
.874 .84 .809 r
.61931 .79353 m .62192 .793 L .62138 .79079 L F
.88 .795 .762 r
.61994 .79622 m .62192 .793 L .61931 .79353 L F
.867 .837 .814 r
.62138 .79079 m .62192 .793 L .62281 .79158 L F
.648 .427 .569 r
.60771 .76482 m .61008 .76676 L .61008 .76451 L F
.60771 .76482 m .60773 .767 L .61008 .76676 L F
.432 .685 .97 r
.64773 .7093 m .64913 .70831 L .64703 .7083 L F
.355 0 .146 r
.64908 .71063 m .64773 .7093 L .64913 .70831 L F
.64908 .71063 m .64695 .71109 L .64773 .7093 L F
.647 .537 .715 r
.42972 .85206 m .42996 .85422 L .43193 .85165 L F
.626 .507 .698 r
.42996 .85422 m .4322 .85399 L .43193 .85165 L F
.611 .455 .646 r
.43018 .85684 m .4322 .85399 L .42996 .85422 L F
.467 .863 .971 r
.6594 .76217 m .66065 .76125 L .65839 .76201 L F
.6594 .76217 m .66144 .76172 L .66065 .76125 L F
.545 .271 .451 r
.42575 .75987 m .42536 .7618 L .4232 .76196 L F
.491 .209 .413 r
.42781 .75963 m .42536 .7618 L .42575 .75987 L F
.707 .486 .586 r
.47746 .84649 m .47711 .84897 L .47462 .84865 L F
.749 .525 .591 r
.48033 .84888 m .47746 .84649 L .4807 .84652 L F
.48033 .84888 m .47711 .84897 L .47746 .84649 L F
0 .028 .588 r
.659 .72257 m .66026 .72463 L .66097 .72215 L F
.282 .426 .83 r
.58648 .81715 m .58615 .81792 L .58443 .81547 L F
.185 .713 .714 r
.58828 .81962 m .58615 .81792 L .58648 .81715 L F
.041 .437 .872 r
.39767 .72749 m .39692 .72795 L .39575 .72703 L F
.39767 .72749 m .39928 .72915 L .39692 .72795 L F
.1 0 0 r
.36553 .72407 m .36758 .72408 L .36825 .72393 L F
.503 0 0 r
.36758 .72408 m .37084 .72497 L .36825 .72393 L F
.649 .437 .582 r
.44784 .83528 m .45004 .83546 L .45011 .83325 L F
.717 .725 .856 r
.64114 .76749 m .64475 .76814 L .6432 .7668 L F
.44 .015 .133 r
.48987 .83957 m .48904 .84068 L .48684 .84085 L F
.418 0 .12 r
.49125 .84028 m .48987 .83957 L .49216 .83941 L F
.49125 .84028 m .48904 .84068 L .48987 .83957 L F
.684 .326 .362 r
.48684 .84551 m .48818 .84324 L .48678 .84347 L F
.48737 .84461 m .49012 .84403 L .48818 .84324 L F
.4882 .84489 m .49012 .84403 L .48737 .84461 L F
.48684 .84551 m .49103 .84583 L .49012 .84403 L F
.72 .437 .497 r
.4894 .84531 m .48678 .84347 L .48922 .84205 L F
.48941 .84544 m .4891 .84521 L .4894 .84531 L F
.4891 .84521 m .48678 .84347 L .4894 .84531 L F
.684 .326 .362 r
.48684 .84551 m .4882 .84489 L .48737 .84461 L F
.675 .762 .916 r
.38491 .7255 m .38312 .72632 L .38156 .72492 L F
.867 .747 .728 r
.68042 .74365 m .68154 .74573 L .68324 .74372 L F
.989 .721 .389 r
.68324 .74372 m .6825 .74512 L .68222 .74302 L F
.68324 .74372 m .68337 .7459 L .6825 .74512 L F
.28 0 0 r
.36055 .75011 m .3593 .75128 L .35721 .7516 L F
.474 .003 .055 r
.36117 .75089 m .3593 .75128 L .36055 .75011 L F
.798 .87 .901 r
.51997 .87838 m .52013 .87956 L .51752 .88064 L F
.613 .298 .413 r
.51752 .88064 m .52013 .87956 L .5195 .88234 L F
.171 .379 .826 r
.52219 .88029 m .52013 .87956 L .51997 .87838 L F
.419 .123 .353 r
.5195 .88234 m .52013 .87956 L .52219 .88029 L F
.499 .302 .544 r
.38248 .79071 m .38055 .79112 L .38265 .78845 L F
.407 .079 .293 r
.37946 .79361 m .38055 .79112 L .38248 .79071 L F
.838 .437 .285 r
.46211 .88308 m .46373 .88323 L .46248 .885 L F
.804 .604 .632 r
.46588 .88273 m .46248 .885 L .46373 .88323 L F
.118 .327 .796 r
.68475 .72238 m .6836 .72286 L .68262 .72235 L F
.68475 .72238 m .68585 .72465 L .6836 .72286 L F
0 .209 .717 r
.6836 .72286 m .68585 .72465 L .6867 .72578 L F
.92 .766 .673 r
.6004 .79836 m .60182 .79906 L .6014 .80112 L F
.677 .556 .71 r
.4234 .86001 m .42355 .86222 L .42566 .8596 L F
.643 .506 .681 r
.42566 .8596 m .42355 .86222 L .4258 .86202 L F
.598 .459 .663 r
.42355 .86222 m .42589 .86415 L .4258 .86202 L F
.42355 .86222 m .42374 .86459 L .42589 .86415 L F
.895 .914 .828 r
.47869 .8624 m .47854 .86368 L .47995 .86166 L F
.941 .823 .7 r
.47946 .85908 m .47995 .86166 L .48139 .85937 L F
.47946 .85908 m .47785 .86274 L .47995 .86166 L F
.895 .914 .828 r
.47688 .86347 m .47869 .8624 L .47785 .86274 L F
.47869 .8624 m .47995 .86166 L .47891 .8622 L F
.47869 .8624 m .47891 .8622 L .47785 .86274 L F
.208 .124 .536 r
.48109 .86018 m .47944 .86367 L .47945 .86169 L F
.48101 .8602 m .47945 .86169 L .47945 .86055 L F
.48109 .86018 m .47945 .86169 L .48101 .8602 L F
.47993 .8594 m .47945 .86055 L .47946 .85908 L F
.48109 .86018 m .47945 .86055 L .47993 .8594 L F
.895 .914 .828 r
.47688 .86347 m .47818 .86364 L .47869 .8624 L F
.47818 .86364 m .47854 .86368 L .47869 .8624 L F
.377 0 .008 r
.70136 .75415 m .70444 .75327 L .70361 .75398 L F
.392 .841 .743 r
.70444 .75327 m .7054 .7527 L .70361 .75398 L F
.413 .465 .804 r
.48408 .82974 m .48485 .8318 L .48238 .83062 L F
.454 .044 .17 r
.49463 .82303 m .49317 .82505 L .49091 .82519 L F
.49463 .82303 m .49317 .82505 L .49091 .82519 L F
0 0 0 r
.49567 .82288 m .49317 .82505 L .49463 .82303 L F
.226 .347 .779 r
.65809 .73285 m .65905 .73581 L .659 .73422 L F
.756 .537 .6 r
.65905 .73581 m .65594 .73761 L .659 .73422 L F
.65905 .73581 m .65949 .73819 L .65594 .73761 L F
.828 .698 .72 r
.50467 .84586 m .50755 .84634 L .50748 .84406 L F
.793 .409 .328 r
.50467 .84586 m .50616 .84819 L .50755 .84634 L F
.386 .164 .45 r
.50755 .84634 m .50938 .844 L .50748 .84406 L F
.50755 .84634 m .50949 .84581 L .50938 .844 L F
.224 0 0 r
.50755 .84634 m .50824 .84755 L .50949 .84581 L F
.72 .281 .208 r
.5815 .82236 m .58462 .8229 L .58361 .82427 L F
0 .527 .735 r
.58462 .8229 m .58427 .82279 L .58361 .82427 L F
.58462 .8229 m .58727 .82321 L .58427 .82279 L F
0 0 0 r
.52481 .83555 m .52547 .83489 L .52644 .83274 L F
.146 .505 .91 r
.52481 .83555 m .52632 .83596 L .52547 .83489 L F
.697 .354 .391 r
.48108 .87333 m .48262 .87488 L .48015 .87514 L F
.786 .719 .789 r
.63876 .74175 m .63554 .74102 L .63741 .74015 L F
.63876 .74175 m .6352 .74296 L .63554 .74102 L F
.693 .63 .782 r
.64077 .74083 m .63876 .74175 L .63741 .74015 L F
.121 0 0 r
.47784 .8272 m .47978 .82689 L .48138 .82595 L F
.42 0 0 r
.47978 .82689 m .48349 .82578 L .48138 .82595 L F
.605 .442 .634 r
.40823 .75919 m .41044 .75627 L .40856 .75686 L F
.481 .447 .743 r
.70725 .74532 m .70918 .74531 L .70646 .74342 L F
.683 .147 0 r
.70646 .74342 m .70918 .74531 L .70809 .7453 L F
.70646 .74342 m .70809 .7453 L .70763 .74416 L F
.681 .637 .799 r
.70735 .74282 m .7058 .743 L .70646 .74342 L F
.926 .973 .745 r
.70735 .74282 m .70646 .74342 L .70833 .74055 L F
.928 .905 .781 r
.70833 .74055 m .70688 .74278 L .70658 .74154 L F
.70688 .74278 m .70646 .74342 L .70658 .74154 L F
.898 .771 .713 r
.7078 .73745 m .70833 .74055 L .70644 .74026 L F
.928 .905 .781 r
.70833 .74055 m .70658 .74154 L .70644 .74026 L F
.964 .94 .665 r
.70597 .73928 m .7078 .73745 L .70644 .74026 L F
0 0 .562 r
.70658 .74154 m .70597 .73928 L .70644 .74026 L F
.70658 .74154 m .70743 .74159 L .70606 .73941 L F
.70658 .74154 m .70606 .73941 L .70597 .73928 L F
.683 .147 0 r
.70646 .74342 m .70763 .74416 L .70658 .74154 L F
.681 .637 .799 r
.7058 .743 m .70484 .74312 L .70646 .74342 L F
.442 .402 .719 r
.70484 .74312 m .70725 .74532 L .70646 .74342 L F
.338 .507 .878 r
.72001 .72983 m .71862 .73078 L .71734 .72867 L F
0 0 0 r
.71742 .73215 m .71862 .73078 L .72001 .72983 L F
.113 .658 .832 r
.5736 .79636 m .57313 .7962 L .57217 .79611 L F
.713 .553 0 r
.55408 .84436 m .55419 .84628 L .55406 .84371 L F
.688 .519 .653 r
.40366 .88569 m .40652 .88578 L .40649 .88344 L F
.672 .506 .653 r
.40649 .88344 m .40652 .88578 L .4087 .88316 L F
.768 .626 .704 r
.58052 .7803 m .57909 .78318 L .57774 .78043 L F
.723 .578 .692 r
.60475 .78845 m .60294 .79125 L .60147 .78813 L F
.993 .817 .561 r
.67798 .73072 m .6767 .7323 L .67708 .73001 L F
.67798 .73072 m .67759 .73294 L .6767 .7323 L F
.673 .504 .648 r
.59589 .77259 m .59805 .77006 L .59469 .76958 L F
.59589 .77259 m .59802 .77258 L .59805 .77006 L F
.68 .51 .649 r
.59805 .77006 m .60104 .77204 L .60034 .76968 L F
.59805 .77006 m .59802 .77258 L .60104 .77204 L F
.585 .518 .746 r
.42374 .74076 m .42172 .74116 L .42091 .73794 L F
.542 .383 .615 r
.42386 .74323 m .42172 .74116 L .42374 .74076 L F
.42386 .74323 m .42178 .74358 L .42172 .74116 L F
.432 .068 .245 r
.33767 .73323 m .33972 .73288 L .33769 .73319 L F
.971 .807 .385 r
.61029 .82981 m .61058 .82793 L .60984 .82994 L F
.724 .726 .203 r
.61058 .82793 m .61133 .82463 L .61105 .82691 L F
0 0 0 r
.60984 .82994 m .61058 .82793 L .61105 .82691 L F
.55 .409 .642 r
.61648 .75407 m .61861 .75371 L .61835 .75138 L F
.554 .417 .649 r
.61648 .75407 m .61887 .75612 L .61861 .75371 L F
.61648 .75407 m .61676 .75704 L .61887 .75612 L F
.691 .638 .792 r
.65699 .74074 m .65543 .74323 L .65411 .74059 L F
.743 .526 .6 r
.55025 .8014 m .55309 .80324 L .55308 .80155 L F
.456 .261 .526 r
.55308 .80155 m .55532 .80235 L .55531 .80139 L F
.55308 .80155 m .55309 .80324 L .55532 .80235 L F
.845 .619 .597 r
.66217 .71733 m .65995 .71928 L .6613 .71637 L F
.66217 .71733 m .66181 .71972 L .65995 .71928 L F
.835 .394 .18 r
.5474 .81881 m .54792 .81748 L .54655 .81709 L F
.5474 .81881 m .54915 .81904 L .54792 .81748 L F
.656 .788 .945 r
.40245 .74329 m .40576 .74365 L .40486 .74249 L F
.574 .877 .993 r
.40576 .74365 m .40644 .74247 L .40486 .74249 L F
.40576 .74365 m .40798 .74299 L .40644 .74247 L F
.692 .546 .683 r
.43622 .84396 m .43627 .84628 L .43845 .84364 L F
.281 .213 .6 r
.53198 .81952 m .53355 .8219 L .53428 .8198 L F
.53198 .81952 m .5329 .82289 L .53355 .8219 L F
.637 .65 .845 r
.40703 .87996 m .41085 .88048 L .41069 .8781 L F
.66 .511 .671 r
.41069 .8781 m .41293 .87785 L .413 .87577 L F
.65 .463 .617 r
.41069 .8781 m .41085 .88048 L .41293 .87785 L F
.093 0 0 r
.58842 .83017 m .58592 .8317 L .5874 .83144 L F
0 0 0 r
.59078 .82787 m .58842 .83017 L .58876 .83031 L F
.59078 .82787 m .59096 .82755 L .58842 .83017 L F
.58876 .83031 m .58842 .83017 L .5874 .83144 L F
.77 .8 .877 r
.64623 .73904 m .64322 .73886 L .64533 .7377 L F
.678 .712 .874 r
.64831 .7382 m .64623 .73904 L .64533 .7377 L F
.818 .349 0 r
.5455 .81642 m .54501 .81461 L .54341 .81477 L F
.5455 .81642 m .54655 .81709 L .54501 .81461 L F
.995 .784 .416 r
.59947 .80401 m .5986 .80107 L .6014 .80112 L F
.59947 .80401 m .59864 .80354 L .5986 .80107 L F
.716 .627 .757 r
.39725 .88741 m .39923 .89036 L .39941 .88862 L F
.528 .345 .578 r
.38464 .78809 m .38457 .79042 L .38265 .78845 L F
.552 .346 .555 r
.38265 .78845 m .38457 .79042 L .38248 .79071 L F
.525 .755 .98 r
.44383 .88185 m .44511 .8805 L .44274 .88073 L F
.589 .285 .422 r
.62549 .73487 m .6277 .7355 L .62784 .73309 L F
.625 .878 .538 r
.63038 .73 m .62784 .73309 L .62938 .73101 L F
.606 .77 .958 r
.63097 .73311 m .62784 .73309 L .63038 .73 L F
.424 .152 .395 r
.62784 .73309 m .62994 .73457 L .62938 .73101 L F
.62784 .73309 m .6277 .7355 L .62994 .73457 L F
.662 .496 .649 r
.60034 .76968 m .60329 .7698 L .60307 .76776 L F
.623 .432 .603 r
.60104 .77204 m .60329 .7698 L .60034 .76968 L F
.836 .982 .875 r
.35567 .75367 m .35721 .7516 L .35492 .75331 L F
.467 .109 .275 r
.33665 .735 m .33972 .73288 L .33767 .73323 L F
.619 .395 .556 r
.33727 .68056 m .33708 .68273 L .3347 .68275 L F
.374 .19 .498 r
.33884 .67995 m .33708 .68273 L .33727 .68056 L F
.771 .53 .57 r
.54375 .79855 m .5466 .80114 L .5473 .7997 L F
.65 .457 .609 r
.41934 .86987 m .42161 .86975 L .42184 .86747 L F
.689 .546 .686 r
.42161 .86975 m .42384 .86703 L .42184 .86747 L F
.716 .401 .444 r
.52914 .84837 m .53308 .84906 L .53251 .84722 L F
.869 .902 .854 r
.55861 .80643 m .5616 .80454 L .55962 .80429 L F
.174 0 0 r
.5616 .80454 m .5618 .80458 L .55962 .80429 L F
.294 .116 .461 r
.56345 .80171 m .5616 .80454 L .56399 .80406 L F
.56345 .80171 m .5618 .80458 L .5616 .80454 L F
.895 .924 .832 r
.56199 .80678 m .56399 .80406 L .5616 .80454 L F
.584 .158 .198 r
.5002 .88243 m .50136 .8808 L .50357 .88208 L F
.161 0 0 r
.4906 .88372 m .49382 .88302 L .4927 .88465 L F
.467 .003 .067 r
.49382 .88302 m .49484 .88447 L .4927 .88465 L F
.49382 .88302 m .49604 .88306 L .49484 .88447 L F
.837 .445 0 r
.55118 .82485 m .55262 .82747 L .55184 .82559 L F
.702 .565 .697 r
.41515 .87301 m .413 .87577 L .41516 .87519 L F
.662 .533 .696 r
.41515 .87301 m .41765 .87483 L .41726 .87255 L F
.41515 .87301 m .41516 .87519 L .41765 .87483 L F
.704 .705 .848 r
.55836 .77941 m .55446 .78142 L .55302 .78031 L F
.55836 .77941 m .55446 .78142 L .55302 .78031 L F
.551 .242 .398 r
.6911 .72018 m .6937 .71984 L .69309 .71873 L F
.92 .821 .732 r
.62281 .79158 m .62293 .78779 L .62138 .79079 L F
.64 .509 .687 r
.60329 .7698 m .60559 .76737 L .60307 .76776 L F
.75 .731 .835 r
.49663 .83124 m .49295 .83223 L .49556 .83195 L F
.674 .365 .443 r
.49556 .83195 m .49985 .82998 L .49663 .83124 L F
.527 .083 .137 r
.47738 .86973 m .47638 .87034 L .47966 .86978 L F
.322 .792 .928 r
.35308 .75358 m .35365 .75304 L .35165 .75348 L F
.35308 .75358 m .35492 .75331 L .35365 .75304 L F
.551 .473 .72 r
.6218 .74084 m .62397 .74046 L .6236 .73835 L F
.534 .37 .605 r
.6219 .74312 m .62397 .74046 L .6218 .74084 L F
.637 .65 .845 r
.40703 .87996 m .40844 .8809 L .41085 .88048 L F
.556 .413 .641 r
.4087 .88316 m .41085 .88048 L .40844 .8809 L F
.189 0 0 r
.71643 .72511 m .71945 .72274 L .71607 .72231 L F
.482 .073 .187 r
.50008 .84939 m .5024 .84935 L .50245 .85028 L F
0 .36 .709 r
.50008 .84939 m .50245 .85028 L .50141 .84979 L F
.50008 .84939 m .50141 .84979 L .50001 .85051 L F
.793 .583 .616 r
.53663 .85885 m .54003 .8566 L .53789 .85989 L F
.686 .565 .712 r
.54003 .8566 m .54049 .85958 L .53789 .85989 L F
.78 .626 .69 r
.53901 .86062 m .53663 .85885 L .53789 .85989 L F
.529 .12 .209 r
.53789 .85989 m .54049 .85958 L .53901 .86062 L F
.669 .537 .694 r
.48235 .85722 m .48265 .85986 L .48139 .85937 L F
.401 0 0 r
.48139 .85937 m .48146 .85965 L .47946 .85908 L F
.48139 .85937 m .48265 .85986 L .48146 .85965 L F
.801 .496 .473 r
.57553 .78058 m .57235 .78256 L .57232 .78051 L F
.57553 .78058 m .57437 .78292 L .57235 .78256 L F
.691 .364 .418 r
.57739 .78262 m .57437 .78292 L .57553 .78058 L F
.907 .662 .556 r
.57774 .78043 m .57739 .78262 L .57553 .78058 L F
.049 .153 .653 r
.48963 .83473 m .48896 .83591 L .48809 .8324 L F
.64 .907 .982 r
.49013 .83503 m .48896 .83591 L .48963 .83473 L F
.521 .711 .958 r
.4498 .88239 m .45027 .88058 L .44843 .88103 L F
.4498 .88239 m .45183 .88204 L .45027 .88058 L F
.999 .844 .538 r
.61332 .81963 m .61376 .81738 L .61258 .81912 L F
.98 .892 .542 r
.61376 .81738 m .61401 .81308 L .61323 .81692 L F
.983 .889 .545 r
.61258 .81912 m .61376 .81738 L .61323 .81692 L F
.813 .612 .63 r
.69861 .70219 m .69556 .70199 L .69851 .70184 L F
.69861 .70219 m .69615 .70579 L .69556 .70199 L F
.577 .776 .973 r
.70118 .70163 m .69861 .70219 L .69851 .70184 L F
.567 .437 .663 r
.70118 .70163 m .70072 .70348 L .69861 .70219 L F
.348 0 0 r
.37121 .88817 m .37351 .88862 L .37428 .88845 L F
.37121 .88817 m .37351 .88862 L .37428 .88845 L F
.558 .931 .81 r
.37428 .88845 m .37351 .88862 L .37496 .88765 L F
.37496 .88765 m .37351 .88862 L .37428 .88845 L F
.648 .513 .686 r
.44034 .83866 m .44054 .84093 L .44257 .8383 L F
.279 0 .109 r
.37794 .79341 m .37869 .7948 L .37702 .79478 L F
.37794 .79341 m .37946 .79361 L .37869 .7948 L F
.804 .627 .662 r
.62964 .77784 m .63284 .77816 L .6317 .7752 L F
.81 .581 .592 r
.52287 .85043 m .52683 .85261 L .52474 .84872 L F
.52381 .85179 m .52683 .85261 L .52287 .85043 L F
.261 .338 .754 r
.52474 .84872 m .52683 .85261 L .52699 .85079 L F
.623 .312 .422 r
.52286 .85346 m .52482 .85413 L .52683 .85261 L F
.675 .556 .712 r
.52482 .85413 m .52699 .85079 L .52683 .85261 L F
.673 .312 .353 r
.52482 .85413 m .52848 .85375 L .52707 .85606 L F
.675 .556 .712 r
.52512 .85367 m .5272 .85414 L .52699 .85079 L F
.52482 .85413 m .52543 .85413 L .52512 .85367 L F
.52543 .85413 m .5272 .85414 L .52512 .85367 L F
.81 .581 .592 r
.52194 .85128 m .52381 .85179 L .52287 .85043 L F
.261 .338 .754 r
.52474 .84872 m .52699 .85079 L .52702 .84902 L F
.989 .734 .443 r
.69156 .73784 m .69253 .74078 L .69251 .73841 L F
.561 .364 .572 r
.69156 .73784 m .69374 .73969 L .69376 .73949 L F
.69156 .73784 m .69376 .73949 L .69398 .73737 L F
.483 0 0 r
.68936 .7362 m .69156 .73784 L .69251 .73841 L F
.68927 .73613 m .69156 .73784 L .68936 .7362 L F
.598 .368 .539 r
.46398 .83548 m .46623 .83546 L .46645 .8333 L F
.507 .29 .519 r
.46645 .8333 m .46623 .83546 L .46852 .83292 L F
.766 .584 .652 r
.50431 .8592 m .50758 .85939 L .50728 .85717 L F
.562 .489 .731 r
.50728 .85717 m .50846 .85348 L .50643 .85413 L F
.444 .355 .661 r
.50728 .85717 m .50848 .85655 L .5094 .85716 L F
.50728 .85717 m .50758 .85939 L .50848 .85655 L F
.50848 .85655 m .50758 .85939 L .50728 .85717 L F
.63 .458 .631 r
.43845 .84364 m .43627 .84628 L .43854 .84605 L F
.614 .446 .63 r
.43845 .84364 m .44086 .84581 L .44073 .8434 L F
.43845 .84364 m .43854 .84605 L .44086 .84581 L F
.455 .125 .316 r
.36738 .78547 m .3694 .78511 L .37054 .78277 L F
.495 .139 .29 r
.3694 .78511 m .37268 .7828 L .37054 .78277 L F
.626 .733 .924 r
.51048 .83793 m .51158 .83933 L .51418 .83883 L F
.51048 .83793 m .51158 .83933 L .51418 .83883 L F
.455 .34 .634 r
.413 .87577 m .41293 .87785 L .41463 .87718 L F
.609 .319 .452 r
.413 .87577 m .41463 .87718 L .41516 .87519 L F
.527 .432 .691 r
.4846 .85751 m .48235 .85722 L .48326 .85641 L F
.4846 .85751 m .48265 .85986 L .48235 .85722 L F
.783 .523 .543 r
.46766 .85563 m .47015 .85843 L .46861 .85706 L F
.519 .276 .487 r
.41346 .76948 m .41101 .77204 L .41143 .76994 L F
.804 .497 .47 r
.50555 .84915 m .50245 .85028 L .5024 .84935 L F
.50555 .84915 m .50525 .85093 L .50245 .85028 L F
.7 .501 .616 r
.50773 .84873 m .50525 .85093 L .50555 .84915 L F
.068 .631 .724 r
.35454 .72654 m .35661 .72639 L .35826 .7263 L F
.36 0 0 r
.35661 .72639 m .36015 .72553 L .35826 .7263 L F
.261 .023 .351 r
.50586 .83442 m .50464 .83289 L .50713 .83269 L F
.50586 .83442 m .50421 .83545 L .50464 .83289 L F
.689 .628 .782 r
.39509 .88609 m .39625 .88776 L .39793 .88562 L F
.604 .643 .862 r
.39625 .88776 m .39725 .88741 L .39793 .88562 L F
.508 .182 .35 r
.41463 .87718 m .41765 .87483 L .41516 .87519 L F
.567 .808 .99 r
.46281 .86521 m .45887 .86463 L .46109 .86428 L F
.952 .749 .593 r
.55105 .80924 m .55037 .80636 L .55057 .80697 L F
.985 .718 .344 r
.55443 .83772 m .55503 .83571 L .5539 .83497 L F
.55443 .83772 m .55526 .83845 L .55503 .83571 L F
.133 0 0 r
.34276 .75682 m .34426 .75644 L .34211 .75764 L F
.692 .535 .669 r
.43408 .84658 m .43411 .84892 L .43627 .84628 L F
.01 .371 .838 r
.46779 .87139 m .46887 .87284 L .46707 .87159 L F
.315 0 .217 r
.53526 .81573 m .53372 .81458 L .53588 .81445 L F
.53526 .81573 m .53281 .81663 L .53372 .81458 L F
.722 .85 .942 r
.66359 .75949 m .66696 .75925 L .66571 .75923 L F
.129 .658 .871 r
.66696 .75925 m .66905 .75934 L .66754 .75895 L F
.839 .772 .788 r
.62862 .77481 m .6317 .7752 L .63059 .77217 L F
.841 .686 .69 r
.62829 .77672 m .6317 .7752 L .62862 .77481 L F
.62829 .77672 m .62964 .77784 L .6317 .7752 L F
.788 .75 .818 r
.6317 .7752 m .63365 .77228 L .63059 .77217 L F
.683 .841 .959 r
.52006 .84425 m .52122 .84473 L .52367 .84406 L F
.584 .129 .138 r
.52251 .82833 m .52057 .82794 L .52015 .82775 L F
.735 .535 .621 r
.60147 .78813 m .59982 .7907 L .59966 .78831 L F
.786 .603 .653 r
.60147 .78813 m .60294 .79125 L .59982 .7907 L F
0 .15 .64 r
.58612 .81647 m .58443 .81547 L .58446 .81476 L F
.58612 .81647 m .58446 .81476 L .5851 .81509 L F
.58612 .81647 m .58648 .81715 L .58443 .81547 L F
0 0 .535 r
.58569 .8155 m .58612 .81647 L .5851 .81509 L F
.58569 .8155 m .5851 .81509 L .58448 .81423 L F
.739 .383 .378 r
.58479 .81856 m .58648 .81715 L .58612 .81647 L F
.58479 .81856 m .58828 .81962 L .58648 .81715 L F
.664 .167 .057 r
.58712 .82004 m .58828 .81962 L .58479 .81856 L F
.158 .125 .567 r
.58568 .81895 m .58479 .81856 L .58612 .81647 L F
.58568 .81895 m .58612 .81647 L .58569 .8155 L F
.743 .772 .877 r
.58791 .81545 m .58568 .81895 L .58569 .8155 L F
.039 0 0 r
.58642 .81603 m .58569 .8155 L .58497 .81742 L F
.58662 .81584 m .58569 .8155 L .58642 .81603 L F
.58692 .81556 m .58597 .81552 L .58662 .81584 L F
.58597 .81552 m .58569 .8155 L .58662 .81584 L F
0 .15 .64 r
.5851 .81509 m .58446 .81476 L .58448 .81423 L F
0 .208 .717 r
.53977 .80078 m .54034 .80079 L .53793 .79888 L F
0 .291 .752 r
.53977 .80078 m .54155 .80172 L .54034 .80079 L F
.197 .13 .551 r
.33502 .68756 m .33529 .69042 L .33384 .691 L F
.63 .068 0 r
.40977 .73014 m .4118 .73113 L .40966 .7299 L F
.518 .783 .993 r
.4124 .73029 m .4118 .73113 L .40977 .73014 L F
.209 .627 .951 r
.68824 .72547 m .6867 .72578 L .68585 .72465 L F
.68824 .72547 m .68941 .72631 L .6867 .72578 L F
.959 .917 .725 r
.66387 .74036 m .66294 .74103 L .66441 .73787 L F
.673 .445 .567 r
.66387 .74036 m .66245 .74265 L .66294 .74103 L F
.66387 .74036 m .66539 .74279 L .66245 .74265 L F
.693 .41 .489 r
.5941 .78803 m .59273 .79044 L .59074 .78827 L F
.749 .515 .576 r
.59617 .78834 m .59273 .79044 L .5941 .78803 L F
.497 .715 .968 r
.5465 .78576 m .54888 .78572 L .54758 .78446 L F
.115 0 0 r
.35016 .79469 m .35257 .79373 L .35077 .79366 L F
.68 .314 .346 r
.49691 .87975 m .49814 .87771 L .4948 .87779 L F
.672 .565 .727 r
.49814 .87771 m .50041 .87746 L .5004 .87458 L F
.585 .254 .374 r
.49975 .88 m .49814 .87771 L .49691 .87975 L F
.49975 .88 m .50041 .87746 L .49814 .87771 L F
.672 .565 .727 r
.49814 .87771 m .50041 .87746 L .5004 .87458 L F
.659 .488 .642 r
.4087 .88316 m .40652 .88578 L .4088 .88551 L F
.556 .413 .641 r
.4087 .88316 m .41074 .88287 L .41085 .88048 L F
.708 .616 .752 r
.4088 .88551 m .41074 .88287 L .4087 .88316 L F
.735 .734 .85 r
.41212 .88565 m .41431 .88579 L .41271 .88282 L F
.739 .419 .44 r
.41212 .88565 m .41609 .88655 L .41431 .88579 L F
.674 .707 .873 r
.41271 .88282 m .41431 .88579 L .41582 .88322 L F
.686 .55 .694 r
.41431 .88579 m .41759 .88568 L .41582 .88322 L F
.41431 .88579 m .41609 .88655 L .41759 .88568 L F
.629 .306 .404 r
.59092 .77677 m .59271 .77709 L .59321 .775 L F
.573 .369 .567 r
.59321 .775 m .59578 .77468 L .59589 .77259 L F
.658 .408 .531 r
.59271 .77709 m .59578 .77468 L .59321 .775 L F
.925 .778 .68 r
.61546 .80922 m .61673 .80677 L .61561 .80589 L F
.886 .825 .781 r
.61673 .80677 m .61636 .80422 L .61561 .80589 L F
.622 .462 .645 r
.4258 .86202 m .42796 .85933 L .42566 .8596 L F
.635 .824 .973 r
.68927 .73613 m .68894 .73562 L .68825 .73511 L F
.68927 .73613 m .69144 .73543 L .68894 .73562 L F
.816 .354 .125 r
.68825 .73511 m .69156 .73784 L .68927 .73613 L F
.665 .497 .647 r
.43627 .84628 m .43411 .84892 L .43638 .84866 L F
.627 .463 .641 r
.43638 .84866 m .43854 .84605 L .43627 .84628 L F
.573 .81 .989 r
.59215 .81994 m .58911 .81946 L .59128 .81928 L F
.985 .873 .64 r
.59128 .81928 m .59215 .81994 L .59093 .82208 L F
.812 .943 .911 r
.59468 .81764 m .59215 .81994 L .59128 .81928 L F
.985 .873 .64 r
.59128 .81928 m .59215 .81994 L .59093 .82208 L F
.633 .268 .332 r
.56541 .77992 m .56335 .78088 L .56151 .78033 L F
.541 .129 .208 r
.56701 .78017 m .56335 .78088 L .56541 .77992 L F
.722 .381 .402 r
.57122 .78049 m .56914 .78237 L .56701 .78017 L F
.17 0 0 r
.5711 .78168 m .57122 .78049 L .57232 .78051 L F
.5711 .78168 m .56914 .78237 L .57122 .78049 L F
.622 .768 .95 r
.37875 .74847 m .38234 .74919 L .38073 .74826 L F
.671 .842 .965 r
.38073 .74826 m .38234 .74919 L .38392 .74819 L F
.589 .367 .546 r
.61229 .76171 m .61475 .76152 L .61487 .75918 L F
.613 .477 .673 r
.61487 .75918 m .61704 .75903 L .61676 .75704 L F
.584 .358 .539 r
.61475 .76152 m .61704 .75903 L .61487 .75918 L F
0 0 0 r
.59147 .82669 m .59096 .82755 L .59078 .82787 L F
.322 .766 .962 r
.3729 .72482 m .37421 .72528 L .37084 .72497 L F
.645 .905 .982 r
.3763 .72438 m .37421 .72528 L .3729 .72482 L F
.656 .518 .684 r
.41726 .87255 m .4198 .87252 L .41934 .86987 L F
.641 .491 .664 r
.41765 .87483 m .4198 .87252 L .41726 .87255 L F
.552 .406 .637 r
.66092 .74637 m .65906 .74911 L .65913 .74784 L F
.66092 .74637 m .66164 .74866 L .65906 .74911 L F
.557 .319 .51 r
.39614 .76682 m .39841 .76448 L .39661 .76486 L F
.099 .655 .744 r
.58391 .84766 m .58724 .84743 L .59059 .84709 L F
.489 0 0 r
.5842 .8305 m .5803 .83006 L .58315 .82954 L F
.622 .513 .709 r
.40366 .88569 m .40652 .88818 L .40652 .88578 L F
.40366 .88569 m .40438 .88868 L .40652 .88818 L F
.397 .514 .859 r
.40094 .72936 m .4 .73096 L .39928 .72915 L F
.517 .668 .931 r
.40094 .72936 m .40232 .73086 L .4 .73096 L F
.802 .631 .67 r
.60231 .79329 m .59982 .7907 L .60294 .79125 L F
.759 .774 .865 r
.66468 .74902 m .66164 .74866 L .66337 .74798 L F
.777 .802 .873 r
.66724 .74696 m .66468 .74902 L .66337 .74798 L F
.914 .622 .476 r
.56852 .81153 m .56966 .81586 L .57116 .81564 L F
.527 0 0 r
.56687 .81649 m .56905 .81708 L .56883 .81739 L F
.56905 .81708 m .56969 .81726 L .56883 .81739 L F
.396 0 .137 r
.56735 .81858 m .56857 .81773 L .56883 .81739 L F
.527 0 0 r
.56687 .81649 m .56969 .81726 L .56883 .81739 L F
.878 .993 .784 r
.56883 .81739 m .56969 .81726 L .57116 .81564 L F
.572 .94 .84 r
.57058 .81632 m .56969 .81726 L .56883 .81739 L F
.396 0 .137 r
.56857 .81773 m .57058 .81632 L .56883 .81739 L F
.878 .993 .784 r
.56883 .81739 m .57116 .81564 L .56966 .81586 L F
.538 .295 .494 r
.40397 .76208 m .40608 .76186 L .40659 .75969 L F
.526 .284 .49 r
.40659 .75969 m .40815 .76143 L .40823 .75919 L F
.40659 .75969 m .40608 .76186 L .40815 .76143 L F
.835 .933 .556 r
.66968 .72191 m .67111 .7197 L .67048 .71836 L F
.66968 .72191 m .66962 .72249 L .67111 .7197 L F
.867 .747 .728 r
.68042 .74365 m .67974 .74577 L .68154 .74573 L F
.842 .627 .611 r
.67972 .74805 m .68154 .74573 L .67974 .74577 L F
.67972 .74805 m .68174 .74842 L .68154 .74573 L F
.46 .602 .905 r
.42145 .73587 m .42091 .73794 L .41943 .73624 L F
.42145 .73587 m .42275 .73791 L .42091 .73794 L F
.585 .518 .746 r
.42374 .74076 m .42091 .73794 L .42275 .73791 L F
.655 .559 .733 r
.63701 .73548 m .63746 .73841 L .63491 .73773 L F
.667 .535 .693 r
.63746 .73841 m .63554 .74102 L .63491 .73773 L F
0 .015 .556 r
.71325 .70888 m .71359 .71177 L .71293 .70963 L F
.92 .766 .673 r
.6004 .79836 m .6014 .80112 L .5986 .80107 L F
.394 0 0 r
.69815 .75396 m .70136 .75415 L .70066 .75445 L F
.061 .625 .716 r
.70136 .75415 m .70361 .75398 L .70284 .75403 L F
.70136 .75415 m .70284 .75403 L .70066 .75445 L F
.644 .592 .782 r
.70561 .74884 m .70805 .74822 L .70725 .74532 L F
.503 0 0 r
.70697 .75007 m .70561 .74884 L .70504 .74962 L F
.70697 .75007 m .70799 .75072 L .70561 .74884 L F
.575 .358 .548 r
.70561 .74884 m .70799 .75072 L .70805 .74822 L F
.256 0 .091 r
.63977 .71393 m .64163 .71344 L .64222 .71163 L F
.112 0 .037 r
.64222 .71163 m .64419 .71127 L .64498 .70961 L F
.606 .36 .518 r
.59578 .77468 m .59802 .77258 L .59589 .77259 L F
.515 0 0 r
.66905 .75934 m .6721 .75977 L .67187 .76054 L F
.504 0 0 r
.67459 .76126 m .67187 .76054 L .6721 .75977 L F
0 .332 .789 r
.48328 .86108 m .48146 .85965 L .48265 .85986 L F
.691 .675 .829 r
.48495 .85954 m .48265 .85986 L .4846 .85751 L F
.758 .481 .515 r
.48495 .85954 m .48328 .86108 L .48265 .85986 L F
.501 .552 .84 r
.54986 .78058 m .55075 .78378 L .54861 .7831 L F
0 .022 .587 r
.63751 .73197 m .63848 .73504 L .63717 .73305 L F
.344 .216 .559 r
.63717 .73305 m .63848 .73504 L .63701 .73548 L F
.695 .335 0 r
.71317 .72962 m .71415 .73204 L .71331 .73032 L F
.71317 .72962 m .71461 .73295 L .71415 .73204 L F
.406 .424 .766 r
.70785 .71024 m .70952 .70849 L .70755 .7085 L F
.70785 .71024 m .71074 .71201 L .70952 .70849 L F
.302 .428 .823 r
.7092 .7119 m .71074 .71201 L .70785 .71024 L F
.503 .569 .855 r
.53054 .826 m .53261 .82764 L .53214 .82462 L F
.764 .642 .727 r
.40652 .88818 m .40981 .88854 L .4088 .88551 L F
.567 .413 .632 r
.40981 .88854 m .41212 .88565 L .4088 .88551 L F
.40981 .88854 m .41205 .8884 L .41212 .88565 L F
.863 .932 .868 r
.69578 .70595 m .69424 .70925 L .69615 .7085 L F
.69578 .70595 m .69331 .70864 L .69424 .70925 L F
.379 .345 .695 r
.54227 .85931 m .54049 .85958 L .54003 .8566 L F
.135 0 0 r
.54068 .85968 m .54049 .85958 L .54097 .85951 L F
.53901 .86062 m .54019 .85979 L .54068 .85968 L F
.54019 .85979 m .54049 .85958 L .54068 .85968 L F
.456 .366 .664 r
.54003 .8566 m .54071 .85967 L .54227 .85931 L F
.54071 .85967 m .54082 .86017 L .54227 .85931 L F
.793 .583 .616 r
.53663 .85885 m .5402 .85998 L .54003 .8566 L F
.5402 .85998 m .54082 .86017 L .54071 .85967 L F
.5402 .85998 m .54071 .85967 L .54003 .8566 L F
.78 .626 .69 r
.53901 .86062 m .54082 .86017 L .5402 .85998 L F
.53901 .86062 m .5402 .85998 L .53663 .85885 L F
.135 0 0 r
.53938 .86047 m .5402 .85998 L .54227 .85931 L F
.5402 .85998 m .54097 .85951 L .5411 .85949 L F
.5402 .85998 m .5411 .85949 L .54227 .85931 L F
.53901 .86062 m .54097 .85951 L .53938 .86047 L F
.651 .505 .672 r
.6352 .74296 m .63374 .74145 L .63554 .74102 L F
.6352 .74296 m .6333 .74388 L .63374 .74145 L F
.389 0 0 r
.69597 .75358 m .69503 .7542 L .6928 .75416 L F
.354 0 0 r
.69597 .75358 m .69719 .75416 L .69503 .7542 L F
.69597 .75358 m .69815 .75396 L .69719 .75416 L F
.681 .533 .678 r
.44249 .83596 m .44257 .8383 L .44469 .83567 L F
.502 .288 .521 r
.39642 .7801 m .3942 .78266 L .39445 .78049 L F
.654 .1 0 r
.58912 .82228 m .59013 .82258 L .59209 .82437 L F
.523 0 0 r
.55549 .81707 m .55827 .81802 L .55779 .81874 L F
.601 .45 .648 r
.44257 .8383 m .44054 .84093 L .44265 .84055 L F
.628 .494 .68 r
.44073 .8434 m .44265 .84055 L .44054 .84093 L F
.456 .366 .664 r
.54003 .8566 m .54227 .85931 L .54198 .85754 L F
.379 .345 .695 r
.54227 .85931 m .54003 .8566 L .54198 .85754 L F
.674 .365 .443 r
.49556 .83195 m .49735 .83284 L .49985 .82998 L F
.657 .344 .43 r
.49985 .82998 m .49735 .83284 L .50065 .83217 L F
.206 .696 .924 r
.4711 .88307 m .47437 .88356 L .47325 .88311 L F
.265 .734 .944 r
.47325 .88311 m .47437 .88356 L .47642 .88347 L F
.454 .01 .103 r
.47128 .85395 m .46999 .85568 L .46766 .85563 L F
.977 .722 .481 r
.47128 .85395 m .47136 .85675 L .46999 .85568 L F
.909 .623 .128 r
.54915 .81904 m .55004 .8225 L .54936 .81855 L F
.54915 .81904 m .5497 .8231 L .55004 .8225 L F
.671 .288 0 r
.55062 .82382 m .55004 .8225 L .5497 .8231 L F
.55062 .82382 m .55118 .82485 L .55004 .8225 L F
.45 .128 .327 r
.39939 .77752 m .39843 .77974 L .39642 .7801 L F
.529 .205 .362 r
.40148 .7774 m .39843 .77974 L .39939 .77752 L F
.395 0 .157 r
.38809 .74722 m .38702 .74619 L .38949 .74641 L F
.689 .636 .791 r
.63974 .73788 m .64077 .74083 L .63741 .74015 L F
.662 .621 .797 r
.64322 .73886 m .64077 .74083 L .63974 .73788 L F
.671 .562 .724 r
.66092 .74637 m .65913 .74784 L .65794 .74401 L F
.914 .93 .808 r
.48033 .84888 m .47736 .85104 L .47711 .84897 L F
.48033 .84888 m .47837 .85151 L .47736 .85104 L F
.683 .847 .961 r
.39702 .74428 m .40033 .74407 L .39918 .7436 L F
.634 .89 .986 r
.40107 .74282 m .40033 .74407 L .40245 .74329 L F
.40107 .74282 m .39918 .7436 L .40033 .74407 L F
.233 0 .18 r
.36089 .8037 m .36338 .80153 L .36231 .80387 L F
.402 .059 .265 r
.36231 .80387 m .36338 .80153 L .36533 .8011 L F
0 0 0 r
.68994 .70376 m .69192 .70337 L .69323 .70282 L F
.733 .5 .575 r
.69192 .70337 m .69556 .70199 L .69323 .70282 L F
.324 .011 .27 r
.39438 .7674 m .39365 .76907 L .39614 .76682 L F
.659 .683 .862 r
.53214 .82462 m .53261 .82764 L .53498 .82567 L F
.717 .819 .929 r
.53498 .82567 m .53261 .82764 L .53449 .82655 L F
.602 .322 .464 r
.53315 .8295 m .53449 .82655 L .53261 .82764 L F
.488 0 0 r
.66188 .71102 m .66305 .71208 L .6622 .7113 L F
.17 0 0 r
.36268 .78764 m .36408 .78769 L .36553 .78602 L F
.259 0 0 r
.36553 .78602 m .36593 .78728 L .36738 .78547 L F
.36553 .78602 m .36408 .78769 L .36593 .78728 L F
.907 .662 .556 r
.57774 .78043 m .57909 .78318 L .57739 .78262 L F
.9 .587 .445 r
.57909 .78318 m .57783 .78479 L .57739 .78262 L F
.992 .799 .544 r
.57909 .78318 m .57878 .78572 L .57783 .78479 L F
.708 .511 .62 r
.58191 .78496 m .57878 .78572 L .57909 .78318 L F
.589 .111 .088 r
.5021 .83612 m .49799 .83692 L .49977 .8354 L F
.636 .411 .559 r
.51163 .83256 m .50957 .83055 L .51168 .83014 L F
.51163 .83256 m .50933 .83282 L .50957 .83055 L F
.19 0 0 r
.35374 .80768 m .35442 .80839 L .35286 .80884 L F
.35374 .80768 m .356 .80695 L .35442 .80839 L F
.371 0 .163 r
.51878 .83106 m .51709 .83055 L .52057 .82794 L F
.584 .129 .138 r
.52251 .82833 m .52199 .82886 L .52057 .82794 L F
.395 0 .144 r
.52199 .82886 m .51878 .83106 L .52057 .82794 L F
.533 .262 .449 r
.37268 .7828 m .37478 .7826 L .37525 .7807 L F
.418 .156 .407 r
.37525 .7807 m .37665 .78201 L .37729 .78037 L F
.37525 .7807 m .37478 .7826 L .37665 .78201 L F
0 0 .006 r
.55961 .80548 m .55962 .80429 L .5618 .80458 L F
.867 .847 .822 r
.5629 .80378 m .56099 .80619 L .56034 .80586 L F
.56093 .8048 m .56034 .80586 L .55961 .80548 L F
.866 .971 .654 r
.56212 .80265 m .5618 .80458 L .56345 .80171 L F
.56196 .80293 m .5618 .80458 L .56212 .80265 L F
.867 .847 .822 r
.5629 .80378 m .5618 .80458 L .56198 .80275 L F
.5629 .80378 m .55961 .80548 L .5618 .80458 L F
.5629 .80378 m .56034 .80586 L .56093 .8048 L F
.866 .971 .654 r
.56198 .80275 m .56196 .80293 L .56212 .80265 L F
.641 .517 .696 r
.42384 .86703 m .42589 .86415 L .42374 .86459 L F
.404 0 0 r
.50533 .87595 m .50261 .87773 L .50461 .87751 L F
.50533 .87595 m .50236 .87499 L .50261 .87773 L F
.64 .271 .329 r
.50461 .87751 m .50769 .8774 L .50533 .87595 L F
.269 0 0 r
.50942 .8769 m .50533 .87595 L .50769 .8774 L F
.499 .135 .279 r
.34169 .73247 m .34382 .73235 L .34505 .73018 L F
.417 .037 .208 r
.34382 .73235 m .34711 .72998 L .34505 .73018 L F
.697 .286 .263 r
.48875 .82519 m .4875 .82672 L .48587 .82532 L F
.64 .344 .453 r
.48587 .82532 m .48739 .82561 L .48897 .82257 L F
.586 .413 .615 r
.48897 .82257 m .49091 .82519 L .48875 .82519 L F
.227 0 0 r
.48739 .82561 m .48859 .82546 L .4876 .8252 L F
.48859 .82546 m .49091 .82519 L .48883 .8252 L F
.48859 .82546 m .48883 .8252 L .4876 .8252 L F
.48859 .82546 m .48943 .82565 L .49091 .82519 L F
0 0 0 r
.48883 .8252 m .48814 .82598 L .48875 .82519 L F
.48814 .82598 m .48772 .82644 L .488 .82611 L F
.48814 .82598 m .488 .82611 L .48875 .82519 L F
.48883 .8252 m .48875 .82519 L .49091 .82519 L F
.227 0 0 r
.4876 .8252 m .49091 .82519 L .48897 .82257 L F
.49 .581 .874 r
.48896 .82405 m .48922 .82496 L .48739 .82561 L F
.227 0 0 r
.4885 .82563 m .48943 .82565 L .48859 .82546 L F
.49 .581 .874 r
.48922 .82496 m .48943 .82565 L .4885 .82563 L F
.227 0 0 r
.48739 .82561 m .4885 .82563 L .48859 .82546 L F
.49 .581 .874 r
.48922 .82496 m .4885 .82563 L .48739 .82561 L F
0 0 0 r
.48843 .82578 m .4875 .82672 L .48772 .82644 L F
.48903 .82522 m .4884 .82583 L .48843 .82578 L F
.4884 .82583 m .4875 .82672 L .48843 .82578 L F
.48903 .82522 m .48772 .82644 L .48883 .8252 L F
.753 .748 .848 r
.49153 .82298 m .48978 .82521 L .48896 .82405 L F
.48978 .82521 m .48943 .82565 L .4893 .82521 L F
0 0 0 r
.48954 .82521 m .48883 .8252 L .49091 .82519 L F
.753 .748 .848 r
.48978 .82521 m .4893 .82521 L .48896 .82405 L F
0 0 0 r
.48903 .82522 m .48898 .82521 L .48954 .82521 L F
.48898 .82521 m .48883 .8252 L .48954 .82521 L F
.544 .437 .683 r
.34014 .6776 m .33884 .67995 L .3391 .67777 L F
.687 .513 .647 r
.41085 .88048 m .41317 .88048 L .41293 .87785 L F
.558 .456 .695 r
.41317 .88048 m .41463 .87718 L .41293 .87785 L F
.753 .345 .279 r
.50769 .8774 m .5114 .87816 L .50942 .8769 L F
.74 .686 .799 r
.63581 .76966 m .63908 .7701 L .63812 .76716 L F
.762 .698 .791 r
.63812 .76716 m .63908 .7701 L .64114 .76749 L F
.738 .62 .727 r
.41759 .88568 m .41523 .88843 L .41724 .8872 L F
.604 .715 .923 r
.41724 .8872 m .41892 .88622 L .41759 .88568 L F
.41724 .8872 m .42024 .88744 L .41892 .88622 L F
.772 .639 .715 r
.41205 .8884 m .41609 .88655 L .41212 .88565 L F
.41205 .8884 m .41523 .88843 L .41609 .88655 L F
.672 .52 .67 r
.41609 .88655 m .41523 .88843 L .41759 .88568 L F
.44 .075 .248 r
.4914 .83312 m .49188 .83407 L .49295 .83223 L F
.83 .358 .061 r
.66535 .70774 m .66577 .70699 L .6644 .70655 L F
.66535 .70774 m .66699 .70858 L .66577 .70699 L F
.903 .723 .648 r
.61961 .79804 m .61994 .79622 L .61842 .79558 L F
.88 .795 .762 r
.61994 .79622 m .61931 .79353 L .61842 .79558 L F
.775 .599 .662 r
.55825 .78004 m .56151 .78033 L .56126 .77801 L F
.81 .604 .623 r
.56096 .7798 m .56126 .77801 L .56151 .78033 L F
.56096 .7798 m .56342 .7775 L .56126 .77801 L F
.653 .62 .803 r
.52632 .83596 m .5275 .83909 L .52988 .8385 L F
.964 .795 .626 r
.67 .72482 m .66949 .72732 L .67068 .72775 L F
.768 .438 0 r
.67104 .72923 m .67068 .72775 L .66949 .72732 L F
.67104 .72923 m .67135 .72983 L .67068 .72775 L F
.402 .114 .356 r
.3816 .77663 m .38417 .77453 L .38223 .77505 L F
.749 .515 .576 r
.59617 .78834 m .59614 .79061 L .59273 .79044 L F
.723 .525 .622 r
.59966 .78831 m .59614 .79061 L .59617 .78834 L F
.16 0 0 r
.57132 .77578 m .57339 .77537 L .57419 .77481 L F
.427 0 .023 r
.57339 .77537 m .57653 .77458 L .57419 .77481 L F
.74 .638 .746 r
.63741 .74015 m .63554 .74102 L .63746 .73841 L F
.689 .636 .791 r
.63974 .73788 m .63741 .74015 L .63746 .73841 L F
.245 .233 .647 r
.65957 .70911 m .66052 .70945 L .66027 .70616 L F
.152 .308 .769 r
.65957 .70911 m .66188 .71102 L .66052 .70945 L F
.508 .746 .981 r
.49245 .86425 m .49275 .86524 L .48967 .86436 L F
.783 .477 .47 r
.49275 .86524 m .49131 .86703 L .48967 .86436 L F
.706 .623 .762 r
.49324 .86492 m .49275 .86524 L .49245 .86425 L F
.49324 .86492 m .49131 .86703 L .49275 .86524 L F
.619 .469 .656 r
.4198 .87252 m .42161 .86975 L .41934 .86987 L F
.634 .443 .607 r
.44469 .83567 m .44715 .83754 L .44784 .83528 L F
.56 .308 .49 r
.44784 .83528 m .44941 .83691 L .45004 .83546 L F
.44784 .83528 m .44715 .83754 L .44941 .83691 L F
.828 .99 .732 r
.43637 .88506 m .43758 .88502 L .43571 .88562 L F
.683 .841 .959 r
.52006 .84425 m .52367 .84406 L .5226 .84404 L F
.28 .768 .692 r
.54731 .85628 m .54539 .85702 L .54447 .85734 L F
.017 .585 .781 r
.47094 .8699 m .47309 .87005 L .47428 .87024 L F
.272 .766 .901 r
.47428 .87024 m .47309 .87005 L .4751 .86978 L F
.228 0 .063 r
.35965 .80561 m .36089 .8037 L .36231 .80387 L F
.611 .517 .723 r
.65946 .74008 m .65794 .74401 L .65699 .74074 L F
.65946 .74008 m .66034 .74358 L .65794 .74401 L F
.671 .562 .724 r
.66092 .74637 m .65794 .74401 L .66034 .74358 L F
.497 .236 .449 r
.4232 .76196 m .42295 .76365 L .42084 .7637 L F
.596 .397 .582 r
.42295 .76365 m .42051 .76594 L .42084 .7637 L F
.401 .138 .395 r
.37983 .77724 m .38107 .77937 L .3816 .77663 L F
.37983 .77724 m .37928 .77992 L .38107 .77937 L F
.557 .461 .701 r
.41009 .75114 m .41206 .75322 L .41241 .75127 L F
.41009 .75114 m .41054 .75387 L .41206 .75322 L F
.772 .272 .017 r
.67325 .73494 m .67241 .73252 L .67194 .73196 L F
0 .06 .575 r
.67426 .73671 m .67452 .73646 L .67451 .73615 L F
.772 .272 .017 r
.67274 .73347 m .67715 .73695 L .67241 .73252 L F
.67395 .73531 m .67715 .73695 L .67274 .73347 L F
.67325 .73494 m .67395 .73531 L .67274 .73347 L F
.831 .681 .696 r
.67645 .73454 m .67715 .73695 L .67325 .73494 L F
.67645 .73454 m .67325 .73494 L .6755 .73155 L F
0 .06 .575 r
.67431 .73585 m .67451 .73615 L .67449 .73313 L F
.67426 .73671 m .67451 .73615 L .67431 .73585 L F
.752 .809 .898 r
.45183 .88204 m .45488 .88186 L .45365 .88184 L F
.473 0 0 r
.45365 .88184 m .45488 .88186 L .4581 .88335 L F
.553 .823 .467 r
.55745 .79884 m .55531 .80139 L .55613 .80038 L F
.287 0 0 r
.55613 .80038 m .56003 .79801 L .55745 .79884 L F
.587 .458 .672 r
.48595 .84954 m .48334 .85299 L .48395 .85033 L F
.795 .554 .572 r
.58743 .78568 m .58458 .78738 L .58441 .78531 L F
.58743 .78568 m .58754 .78791 L .58458 .78738 L F
.618 .502 .698 r
.43193 .85165 m .43448 .85373 L .43411 .85128 L F
.43193 .85165 m .4322 .85399 L .43448 .85373 L F
.554 .36 .573 r
.43471 .75329 m .43241 .75557 L .43254 .75375 L F
.764 .642 .727 r
.40652 .88818 m .4088 .88551 L .40652 .88578 L F
.252 0 .027 r
.67779 .75975 m .67905 .76063 L .67684 .76136 L F
.723 .525 .622 r
.59966 .78831 m .59982 .7907 L .59614 .79061 L F
.381 .566 .909 r
.41582 .88322 m .41759 .88568 L .41818 .88446 L F
.259 .415 .828 r
.41759 .88568 m .41892 .88622 L .41818 .88446 L F
.622 .462 .645 r
.4258 .86202 m .42809 .86195 L .42796 .85933 L F
.647 .484 .648 r
.42589 .86415 m .42809 .86195 L .4258 .86202 L F
.561 .386 .601 r
.46109 .86428 m .459 .86202 L .46186 .86174 L F
.46109 .86428 m .45887 .86463 L .459 .86202 L F
.814 .573 .573 r
.50442 .8616 m .50758 .85939 L .50431 .8592 L F
.50442 .8616 m .50772 .86181 L .50758 .85939 L F
.452 .878 .917 r
.50846 .85348 m .50643 .85413 L .50691 .85353 L F
.50691 .85353 m .50643 .85413 L .50846 .85348 L F
.588 .398 .592 r
.42796 .85933 m .43008 .85904 L .43018 .85684 L F
.611 .455 .646 r
.43018 .85684 m .43236 .85665 L .4322 .85399 L F
.626 .445 .617 r
.43008 .85904 m .43236 .85665 L .43018 .85684 L F
.972 .787 .594 r
.54806 .8053 m .54661 .80631 L .54683 .80338 L F
.656 .208 .175 r
.55037 .80636 m .54661 .80631 L .54806 .8053 L F
.63 .473 .652 r
.33708 .68273 m .33482 .68537 L .3347 .68275 L F
.458 .59 .897 r
.3887 .72523 m .38838 .72729 L .38688 .72523 L F
.3887 .72523 m .39026 .72745 L .38838 .72729 L F
.708 .318 .307 r
.49012 .84403 m .49236 .84582 L .4932 .84451 L F
.475 .478 .781 r
.49525 .84822 m .49728 .84789 L .49676 .84651 L F
.542 .13 .209 r
.4926 .84545 m .4965 .84577 L .4932 .84451 L F
.49397 .8458 m .4965 .84577 L .4926 .84545 L F
.767 .706 .794 r
.49218 .84754 m .4965 .84577 L .49236 .84582 L F
.49218 .84754 m .49525 .84822 L .4965 .84577 L F
0 0 .543 r
.49618 .84533 m .4965 .84577 L .49619 .845 L F
.475 .478 .781 r
.49525 .84822 m .49619 .845 L .4965 .84577 L F
.49582 .84627 m .49676 .84651 L .49619 .845 L F
.49525 .84822 m .49676 .84651 L .49582 .84627 L F
.542 .13 .209 r
.49236 .84582 m .49397 .8458 L .4926 .84545 L F
.535 .236 .408 r
.51804 .8273 m .52145 .82427 L .51916 .82396 L F
.758 .481 .515 r
.48495 .85954 m .48528 .86198 L .48328 .86108 L F
.242 .339 .764 r
.4846 .85751 m .48624 .8592 L .48495 .85954 L F
.529 .321 .542 r
.48739 .86115 m .48495 .85954 L .48624 .8592 L F
.48739 .86115 m .48528 .86198 L .48495 .85954 L F
.946 .731 .264 r
.66968 .72191 m .67 .72482 L .66962 .72249 L F
.669 .503 .652 r
.43411 .85128 m .43638 .84866 L .43411 .84892 L F
.621 .468 .653 r
.61008 .76451 m .61282 .76441 L .61229 .76171 L F
.636 .461 .629 r
.61008 .76676 m .61282 .76441 L .61008 .76451 L F
.514 .365 .616 r
.63789 .71659 m .63977 .71393 L .63762 .71422 L F
.835 .438 .295 r
.6702 .71578 m .67042 .71457 L .67007 .71394 L F
.6702 .71578 m .67094 .71633 L .67042 .71457 L F
.682 .345 .399 r
.67042 .71457 m .6702 .71578 L .67007 .71394 L F
.67042 .71457 m .67094 .71633 L .6702 .71578 L F
.67042 .71457 m .6727 .71669 L .67094 .71633 L F
.592 .41 .604 r
.44469 .83567 m .44257 .8383 L .44474 .83792 L F
.634 .443 .607 r
.44469 .83567 m .44474 .83792 L .44715 .83754 L F
.463 0 0 r
.48953 .88408 m .4906 .88372 L .4927 .88465 L F
.802 .631 .67 r
.60231 .79329 m .59939 .79313 L .59982 .7907 L F
.839 .683 .689 r
.60231 .79329 m .59918 .79548 L .59939 .79313 L F
.60231 .79329 m .60095 .79619 L .59918 .79548 L F
.503 .216 .411 r
.42536 .7618 m .42295 .76365 L .4232 .76196 L F
0 0 0 r
.59756 .84574 m .60045 .84398 L .59868 .84515 L F
.401 .807 .593 r
.59868 .84515 m .60045 .84398 L .60195 .84296 L F
.75 .656 .756 r
.70817 .75056 m .71051 .74838 L .70805 .74822 L F
.871 .694 .169 r
.70799 .75072 m .70817 .75056 L .70805 .74822 L F
.445 .348 .651 r
.47462 .84865 m .47478 .85191 L .47391 .85107 L F
.176 .215 .663 r
.53035 .81149 m .53077 .81454 L .5318 .81343 L F
.589 .636 .866 r
.41206 .73603 m .40894 .73455 L .41117 .73392 L F
.604 .614 .835 r
.41411 .73557 m .41206 .73603 L .41117 .73392 L F
.564 .729 .952 r
.37954 .72533 m .3763 .72438 L .37822 .72461 L F
.305 .758 .956 r
.37822 .72461 m .38156 .72492 L .37954 .72533 L F
.478 .528 .83 r
.54307 .84624 m .54381 .84343 L .54184 .84325 L F
.54307 .84624 m .54491 .84655 L .54381 .84343 L F
.543 .341 .556 r
.54307 .84624 m .54299 .84852 L .54491 .84655 L F
.432 0 0 r
.48485 .8318 m .48653 .83243 L .48809 .8324 L F
.026 .598 .715 r
.48809 .8324 m .48653 .83243 L .48997 .83234 L F
.365 .706 .985 r
.48997 .83234 m .4914 .83312 L .48809 .8324 L F
.049 .153 .653 r
.48963 .83473 m .48809 .8324 L .4914 .83312 L F
0 0 0 r
.46107 .83614 m .46206 .83616 L .46398 .83548 L F
.673 .227 .182 r
.46206 .83616 m .46623 .83546 L .46398 .83548 L F
.464 .148 .344 r
.40414 .77536 m .40354 .77708 L .40148 .7774 L F
.471 .154 .347 r
.40563 .77672 m .40414 .77536 L .40627 .77515 L F
.40563 .77672 m .40354 .77708 L .40414 .77536 L F
.581 .422 .63 r
.61835 .75138 m .62062 .75106 L .62041 .74871 L F
.538 .373 .605 r
.61861 .75371 m .62062 .75106 L .61835 .75138 L F
.733 .212 0 r
.68962 .7541 m .68628 .75107 L .68788 .75123 L F
.813 .391 0 r
.56387 .83017 m .56341 .82989 L .56249 .82801 L F
.989 .892 .59 r
.56341 .83251 m .56341 .82989 L .56387 .83017 L F
.574 .818 .991 r
.70805 .74822 m .71051 .74838 L .70964 .74759 L F
.629 .92 .647 r
.71195 .74552 m .70964 .74759 L .71051 .74838 L F
0 0 0 r
.56403 .81104 m .56302 .81198 L .56505 .80928 L F
.172 .323 .776 r
.56403 .81104 m .56526 .81409 L .56302 .81198 L F
.645 .544 .725 r
.5004 .87458 m .50041 .87746 L .50236 .87499 L F
.647 .314 .393 r
.50232 .87973 m .50041 .87746 L .49975 .88 L F
.572 .442 .665 r
.50041 .87746 m .50261 .87773 L .50236 .87499 L F
.573 .31 .479 r
.50232 .87973 m .50261 .87773 L .50041 .87746 L F
.53 .533 .803 r
.32603 .67382 m .32496 .67648 L .3243 .67487 L F
.32603 .67382 m .327 .6767 L .32496 .67648 L F
.927 .881 .769 r
.59801 .81171 m .59545 .81404 L .59695 .81129 L F
.59801 .81171 m .59655 .81463 L .59545 .81404 L F
.606 .36 .518 r
.59578 .77468 m .59811 .77464 L .59802 .77258 L F
.657 .41 .535 r
.59811 .77464 m .60104 .77204 L .59802 .77258 L F
.741 .773 .879 r
.43779 .88028 m .4409 .88091 L .43868 .87876 L F
.241 .616 .956 r
.44274 .88073 m .43868 .87876 L .4409 .88091 L F
.568 .239 .371 r
.45437 .83723 m .45777 .83496 L .45548 .83522 L F
.623 .432 .603 r
.60104 .77204 m .60353 .77216 L .60329 .7698 L F
.64 .509 .687 r
.60329 .7698 m .6056 .76965 L .60559 .76737 L F
.629 .436 .603 r
.60329 .7698 m .60353 .77216 L .6056 .76965 L F
.63 .485 .666 r
.42809 .86195 m .43008 .85904 L .42796 .85933 L F
.821 .551 .531 r
.51752 .88064 m .51433 .87761 L .51546 .87942 L F
.302 0 .093 r
.51444 .88302 m .51752 .88064 L .51757 .88249 L F
.699 .65 .798 r
.51997 .87838 m .51752 .88064 L .51546 .87942 L F
.616 .297 .407 r
.51757 .88249 m .51752 .88064 L .5195 .88234 L F
.511 .302 .533 r
.43241 .75557 m .42969 .75778 L .43035 .75656 L F
.508 .182 .35 r
.41463 .87718 m .41692 .8768 L .41765 .87483 L F
.641 .491 .664 r
.41765 .87483 m .42022 .87516 L .4198 .87252 L F
.552 .183 .294 r
.41692 .8768 m .42022 .87516 L .41765 .87483 L F
.621 .594 .802 r
.41117 .73392 m .40894 .73455 L .40874 .73355 L F
.397 .018 .198 r
.3511 .72921 m .35454 .72654 L .35244 .72751 L F
.493 .862 .985 r
.51331 .87191 m .51315 .87253 L .51148 .87237 L F
.948 .712 .547 r
.51315 .87253 m .5117 .87454 L .51148 .87237 L F
.51315 .87253 m .5131 .8749 L .5117 .87454 L F
0 0 0 r
.51318 .87249 m .51315 .87253 L .51331 .87191 L F
.236 .122 .513 r
.51376 .87498 m .51315 .87253 L .51318 .87249 L F
.51376 .87498 m .5131 .8749 L .51315 .87253 L F
.826 .987 .873 r
.66065 .76125 m .66144 .76172 L .66359 .75949 L F
.588 .302 .449 r
.52881 .83509 m .53246 .83227 L .52878 .83294 L F
.52881 .83509 m .53112 .83513 L .53246 .83227 L F
.612 .328 .462 r
.53246 .83227 m .53112 .83513 L .53577 .83346 L F
.512 .338 .582 r
.53112 .83513 m .53192 .83586 L .53577 .83346 L F
.53192 .83586 m .53328 .83709 L .53498 .83461 L F
.53192 .83586 m .53498 .83461 L .53577 .83346 L F
.612 .328 .462 r
.53246 .83227 m .53577 .83346 L .53464 .83443 L F
.364 0 .152 r
.53328 .83709 m .53631 .83491 L .53577 .83346 L F
.689 .418 .508 r
.53577 .83346 m .53631 .83491 L .53464 .83443 L F
.682 .47 .592 r
.53464 .83443 m .5351 .83456 L .53524 .83428 L F
.53464 .83443 m .53524 .83428 L .53635 .8321 L F
.5351 .83456 m .53631 .83491 L .53632 .83407 L F
.5351 .83456 m .53632 .83407 L .53635 .8321 L F
.227 .279 .708 r
.53246 .83227 m .53464 .83443 L .53401 .83234 L F
.53299 .83214 m .53401 .83234 L .53388 .83191 L F
.53246 .83227 m .53401 .83234 L .53299 .83214 L F
.785 .625 .682 r
.53315 .8295 m .53464 .83443 L .53473 .83217 L F
.279 0 0 r
.53422 .83239 m .53397 .83331 L .53172 .83344 L F
.53473 .83217 m .53454 .83245 L .53422 .83239 L F
.53454 .83245 m .53397 .83331 L .53422 .83239 L F
.53401 .8321 m .53172 .83344 L .53294 .832 L F
.53473 .83217 m .53422 .83239 L .53401 .8321 L F
.53422 .83239 m .53172 .83344 L .53401 .8321 L F
.227 .279 .708 r
.53289 .83054 m .53388 .83191 L .53315 .8295 L F
.53246 .83227 m .53388 .83191 L .53289 .83054 L F
.755 .43 .435 r
.59074 .78827 m .5895 .79023 L .58754 .78791 L F
.733 .402 .42 r
.59273 .79044 m .5895 .79023 L .59074 .78827 L F
.49 .159 .333 r
.40548 .76357 m .40397 .76208 L .40349 .764 L F
.40548 .76357 m .40608 .76186 L .40397 .76208 L F
.794 .582 .614 r
.52547 .83489 m .52878 .83294 L .52644 .83274 L F
.31 .57 .931 r
.56701 .8453 m .56795 .84664 L .56901 .84578 L F
.494 .902 .906 r
.56901 .84578 m .56795 .84664 L .56991 .84585 L F
.56901 .84578 m .56795 .84664 L .56991 .84585 L F
.639 .479 .651 r
.44257 .8383 m .44514 .84035 L .44474 .83792 L F
.44257 .8383 m .44265 .84055 L .44514 .84035 L F
.497 .034 .084 r
.47638 .87034 m .47826 .87165 L .47966 .86978 L F
.527 .066 .102 r
.47966 .86978 m .48046 .87153 L .48077 .86917 L F
.596 .607 .833 r
.48046 .87153 m .48014 .86996 L .48077 .86917 L F
0 0 0 r
.48077 .86917 m .48188 .86778 L .47966 .86978 L F
.596 .607 .833 r
.48014 .86996 m .47971 .86786 L .48077 .86917 L F
0 0 0 r
.48077 .86917 m .48202 .86765 L .48188 .86778 L F
.527 .066 .102 r
.47966 .86978 m .47826 .87165 L .48046 .87153 L F
.543 .222 .374 r
.51062 .84886 m .50737 .85116 L .50773 .84873 L F
.51062 .84886 m .50991 .851 L .50737 .85116 L F
.46 .07 .211 r
.51062 .84886 m .51214 .85057 L .50991 .851 L F
.922 .68 .555 r
.68188 .75403 m .68057 .75137 L .68055 .75344 L F
.953 .769 .617 r
.68037 .75542 m .68188 .75403 L .68055 .75344 L F
.68037 .75542 m .68139 .75601 L .68188 .75403 L F
.658 .492 .647 r
.4322 .85399 m .43492 .85648 L .43448 .85373 L F
.4322 .85399 m .43236 .85665 L .43492 .85648 L F
.406 .791 .99 r
.55861 .80643 m .56099 .80619 L .56199 .80678 L F
.695 .152 0 r
.56211 .80302 m .5629 .80378 L .56198 .80275 L F
.895 .924 .832 r
.56199 .80678 m .56099 .80619 L .5629 .80378 L F
.695 .152 0 r
.56285 .80456 m .5629 .80378 L .56211 .80302 L F
.895 .924 .832 r
.56365 .80452 m .5629 .80378 L .56399 .80406 L F
.56199 .80678 m .5629 .80378 L .56365 .80452 L F
0 .169 .644 r
.57251 .84524 m .57335 .84604 L .57351 .84596 L F
.925 .883 .773 r
.59545 .81404 m .59655 .81463 L .59468 .81764 L F
.607 .647 .864 r
.71289 .70618 m .70921 .70405 L .71099 .70398 L F
0 0 .466 r
.71402 .70529 m .71289 .70618 L .71099 .70398 L F
.71402 .70529 m .71365 .70729 L .71289 .70618 L F
.71365 .70729 m .71325 .70888 L .71289 .70618 L F
.939 .701 .551 r
.56967 .83256 m .57005 .83032 L .56847 .83184 L F
.725 .344 .329 r
.56847 .83184 m .57005 .83032 L .5719 .83241 L F
.597 .457 .662 r
.41044 .75627 m .41206 .75322 L .41054 .75387 L F
.705 .255 .181 r
.50697 .88248 m .51018 .8829 L .50928 .88384 L F
.531 .039 .033 r
.51018 .8829 m .51086 .88438 L .50928 .88384 L F
.51018 .8829 m .51233 .88324 L .51086 .88438 L F
.459 .17 .387 r
.39214 .78286 m .39117 .78558 L .38974 .78479 L F
.561 .27 .431 r
.39379 .78448 m .39214 .78286 L .3942 .78266 L F
.39379 .78448 m .39117 .78558 L .39214 .78286 L F
.527 0 0 r
.66242 .7052 m .66243 .70499 L .66056 .70425 L F
.66242 .7052 m .6644 .70655 L .66243 .70499 L F
.238 0 .006 r
.47354 .82969 m .4754 .82915 L .47632 .8283 L F
.315 0 .052 r
.47272 .83053 m .4754 .82915 L .47354 .82969 L F
.355 0 .169 r
.53425 .83986 m .5352 .83744 L .53537 .83804 L F
.53425 .83986 m .53212 .84083 L .5352 .83744 L F
.51 .569 .851 r
.51171 .85661 m .51298 .85949 L .51415 .85756 L F
.546 .616 .874 r
.51298 .85949 m .51536 .85952 L .51415 .85756 L F
.804 .353 .169 r
.49046 .87452 m .49304 .87611 L .49065 .87358 L F
.764 .695 .153 r
.49046 .87452 m .49065 .87358 L .49077 .87226 L F
.338 .704 .983 r
.42614 .75078 m .42347 .74997 L .42496 .75043 L F
.492 .811 1 r
.42672 .74988 m .42614 .75078 L .42496 .75043 L F
.42672 .74988 m .4283 .75044 L .42614 .75078 L F
.696 .795 .325 r
.55532 .80235 m .55613 .80038 L .55531 .80139 L F
.599 .166 .191 r
.50512 .82959 m .50885 .82986 L .50595 .82848 L F
.577 .427 .641 r
.56399 .80406 m .56546 .80141 L .56345 .80171 L F
.56399 .80406 m .56614 .80382 L .56546 .80141 L F
.912 .625 .485 r
.56476 .80544 m .56399 .80406 L .5629 .80378 L F
.56476 .80544 m .56614 .80382 L .56399 .80406 L F
.858 .712 .7 r
.55953 .78124 m .55939 .78299 L .55825 .78004 L F
.765 .672 .76 r
.55825 .78004 m .55939 .78299 L .56151 .78033 L F
.636 .305 .393 r
.51433 .87761 m .51094 .87958 L .51311 .87989 L F
.51433 .87761 m .5114 .87816 L .51094 .87958 L F
.374 .403 .762 r
.51596 .87698 m .51546 .87942 L .51433 .87761 L F
.789 .462 .436 r
.51311 .87989 m .51384 .87839 L .51433 .87761 L F
.39 .072 .3 r
.3885 .78727 m .38722 .78613 L .38974 .78479 L F
.3885 .78727 m .3866 .78771 L .38722 .78613 L F
0 0 .116 r
.56635 .80611 m .56505 .80928 L .56769 .80686 L F
.56635 .80611 m .56562 .80908 L .56518 .80895 L F
.774 .593 .654 r
.56293 .8083 m .56562 .80908 L .56635 .80611 L F
0 .374 .722 r
.56511 .80882 m .56598 .80918 L .56562 .80908 L F
.56598 .80918 m .5685 .81021 L .56562 .80908 L F
0 0 .116 r
.56518 .80895 m .56562 .80908 L .56505 .80928 L F
.801 .731 .787 r
.56562 .80908 m .56403 .81104 L .56505 .80928 L F
.762 .513 .557 r
.51171 .85661 m .51182 .85408 L .50846 .85348 L F
.596 .373 .547 r
.51171 .85661 m .514 .85613 L .51182 .85408 L F
.601 .372 .542 r
.51182 .85408 m .514 .85613 L .51454 .85396 L F
.369 .07 .32 r
.4754 .82915 m .47784 .8272 L .47632 .8283 L F
.994 .872 .561 r
.55603 .81476 m .55505 .81571 L .5552 .81422 L F
.55603 .81476 m .55549 .81707 L .55505 .81571 L F
.219 0 0 r
.36217 .72507 m .36427 .7248 L .36553 .72407 L F
.212 0 0 r
.36427 .7248 m .36758 .72408 L .36553 .72407 L F
.1 .401 .855 r
.5241 .87223 m .52723 .87501 L .52581 .87237 L F
.606 .8 .974 r
.48678 .84347 m .48469 .84413 L .48347 .84291 L F
.766 .686 .774 r
.64012 .76443 m .64346 .76464 L .6424 .76177 L F
.669 .51 .66 r
.64114 .76749 m .64346 .76464 L .64012 .76443 L F
.64114 .76749 m .6432 .7668 L .64346 .76464 L F
.778 .692 .769 r
.6424 .76177 m .64346 .76464 L .64544 .7621 L F
.578 .779 .974 r
.66837 .70604 m .67106 .70551 L .67161 .70662 L F
.804 .313 0 r
.67142 .70752 m .67161 .70662 L .67106 .70551 L F
.67142 .70752 m .67297 .70831 L .67161 .70662 L F
.551 .426 .663 r
.61704 .75903 m .61887 .75612 L .61676 .75704 L F
.595 .441 .644 r
.61282 .76441 m .61475 .76152 L .61229 .76171 L F
.182 0 .041 r
.36268 .78764 m .36144 .78963 L .36408 .78769 L F
.205 0 0 r
.33464 .67717 m .33644 .67671 L .33859 .67469 L F
.653 .829 .968 r
.4053 .73099 m .40232 .73086 L .40422 .73009 L F
.381 .617 .944 r
.40592 .72986 m .4053 .73099 L .40422 .73009 L F
.40592 .72986 m .40765 .73167 L .4053 .73099 L F
.519 .232 .418 r
.41597 .76748 m .41556 .76925 L .41346 .76948 L F
.544 .267 .445 r
.41803 .76722 m .41556 .76925 L .41597 .76748 L F
.566 .449 .679 r
.66245 .74265 m .66092 .74637 L .66034 .74358 L F
.66245 .74265 m .66336 .7465 L .66092 .74637 L F
.645 .459 .618 r
.66337 .74798 m .66092 .74637 L .66336 .7465 L F
.66337 .74798 m .66164 .74866 L .66092 .74637 L F
.577 .498 .729 r
.42447 .74581 m .42243 .74635 L .42178 .74358 L F
.587 .442 .65 r
.42447 .74581 m .42265 .74887 L .42243 .74635 L F
.644 .438 .59 r
.69556 .70199 m .69758 .70333 L .69851 .70184 L F
.592 .761 .96 r
.69973 .70069 m .70118 .70163 L .69851 .70184 L F
0 0 0 r
.69851 .70184 m .69758 .70333 L .69973 .70069 L F
.002 .31 .801 r
.5761 .82241 m .57367 .81977 L .57373 .82031 L F
.57411 .82158 m .57373 .82031 L .57385 .82148 L F
.5761 .82241 m .57373 .82031 L .57411 .82158 L F
.996 .776 .423 r
.57411 .82326 m .57392 .82375 L .5739 .82286 L F
.57411 .82326 m .5739 .82286 L .57385 .82148 L F
.854 .997 .781 r
.57392 .82375 m .57421 .82357 L .57411 .823 L F
.57389 .82282 m .57411 .823 L .57385 .82148 L F
.57417 .8228 m .5761 .82241 L .57411 .82158 L F
.57421 .82357 m .57434 .8235 L .57417 .8228 L F
.57434 .8235 m .5761 .82241 L .57417 .8228 L F
.088 0 .338 r
.57385 .82148 m .57417 .8228 L .57411 .82326 L F
.229 .11 .503 r
.57419 .8231 m .57411 .82326 L .57417 .8228 L F
.854 .997 .781 r
.57421 .82357 m .57411 .82158 L .57385 .82148 L F
.088 0 .338 r
.57385 .82148 m .57463 .81934 L .57417 .8228 L F
.229 .11 .503 r
.57588 .8193 m .57441 .82259 L .57463 .81934 L F
.57441 .82259 m .57426 .8221 L .57463 .81934 L F
.088 0 .338 r
.57385 .82148 m .57367 .81977 L .57463 .81934 L F
.228 .106 .497 r
.57588 .8193 m .57463 .81934 L .5745 .81696 L F
.742 .689 .801 r
.57273 .81819 m .57403 .82295 L .57588 .8193 L F
.57403 .82295 m .57411 .82326 L .57419 .8231 L F
.229 .11 .503 r
.57441 .82259 m .57419 .8231 L .57426 .8221 L F
.57419 .8231 m .57417 .8228 L .57426 .8221 L F
.742 .689 .801 r
.57403 .82295 m .57419 .8231 L .57588 .8193 L F
.854 .997 .781 r
.5739 .82286 m .57403 .82295 L .57389 .82282 L F
.57403 .82295 m .57411 .823 L .57389 .82282 L F
.823 .734 .767 r
.5739 .82286 m .57411 .82326 L .57403 .82295 L F
.996 .777 .423 r
.57268 .82317 m .574 .82326 L .57081 .82077 L F
.574 .82326 m .57411 .82326 L .57213 .82176 L F
.574 .82326 m .57213 .82176 L .57081 .82077 L F
.823 .734 .767 r
.57081 .82077 m .57411 .82326 L .57193 .81926 L F
.854 .997 .781 r
.57391 .82318 m .57411 .823 L .5739 .82286 L F
.996 .777 .423 r
.57268 .82317 m .57348 .82429 L .57396 .82351 L F
.574 .82326 m .57396 .82351 L .57411 .82326 L F
.854 .997 .781 r
.57392 .82375 m .574 .82326 L .57391 .82318 L F
.996 .777 .423 r
.57268 .82317 m .57396 .82351 L .574 .82326 L F
.854 .997 .781 r
.57392 .82375 m .57404 .82329 L .574 .82326 L F
.996 .776 .423 r
.57411 .82326 m .57396 .82351 L .57392 .82375 L F
.854 .997 .781 r
.57392 .82375 m .57396 .82351 L .57392 .82375 L F
.996 .776 .423 r
.57396 .82351 m .57348 .82429 L .57392 .82375 L F
.854 .997 .781 r
.57392 .82375 m .574 .82326 L .57396 .82351 L F
.57404 .82329 m .57411 .823 L .57391 .82318 L F
.823 .734 .767 r
.57193 .81926 m .5739 .82286 L .57273 .81819 L F
.5739 .82286 m .57403 .82295 L .57273 .81819 L F
.64 .547 .734 r
.63974 .73788 m .63746 .73841 L .63701 .73548 L F
.749 .436 .455 r
.58221 .77668 m .58522 .775 L .58177 .77537 L F
.58221 .77668 m .58434 .77719 L .58522 .775 L F
.64 .317 .409 r
.58522 .775 m .58434 .77719 L .58733 .7768 L F
.896 .479 .177 r
.67382 .71733 m .67343 .71856 L .6727 .71669 L F
.67382 .71733 m .67483 .71932 L .67343 .71856 L F
.429 .781 .997 r
.47642 .88347 m .4795 .88401 L .47826 .88344 L F
.1 .605 .897 r
.47826 .88344 m .4795 .88401 L .48218 .88438 L F
.087 .611 .876 r
.4795 .88401 m .48442 .88473 L .48218 .88438 L F
.675 .762 .916 r
.38491 .7255 m .38156 .72492 L .38362 .72442 L F
.54 .696 .941 r
.38572 .72379 m .38491 .7255 L .38362 .72442 L F
.38572 .72379 m .38688 .72523 L .38491 .7255 L F
.516 .253 .454 r
.40894 .77239 m .40833 .77484 L .40627 .77515 L F
.529 .27 .467 r
.41101 .77204 m .40833 .77484 L .40894 .77239 L F
.988 .877 .533 r
.56151 .78033 m .5604 .78202 L .56096 .7798 L F
.666 .267 .278 r
.56384 .78216 m .5604 .78202 L .56151 .78033 L F
.636 .296 .38 r
.56335 .78088 m .56384 .78216 L .56151 .78033 L F
.928 .85 .745 r
.66942 .74378 m .66858 .74558 L .66828 .74305 L F
.634 .743 .927 r
.64717 .73699 m .64831 .7382 L .64533 .7377 L F
.573 .699 .927 r
.6495 .73689 m .64831 .7382 L .64717 .73699 L F
.6495 .73689 m .65049 .73785 L .64831 .7382 L F
.564 .723 .948 r
.42024 .88744 m .42183 .88602 L .41892 .88622 L F
.42024 .88744 m .42234 .88738 L .42183 .88602 L F
.657 .41 .535 r
.59811 .77464 m .60044 .77458 L .60104 .77204 L F
.654 .408 .534 r
.60104 .77204 m .60356 .77439 L .60353 .77216 L F
.60104 .77204 m .60044 .77458 L .60356 .77439 L F
.898 .704 .632 r
.48997 .83234 m .48963 .83473 L .4914 .83312 L F
.356 .104 .387 r
.49013 .83503 m .49188 .83407 L .4914 .83312 L F
.758 .243 0 r
.48997 .83234 m .49188 .83407 L .4914 .83312 L F
.349 .795 .955 r
.57783 .84741 m .58208 .84769 L .58123 .84712 L F
.336 .782 .958 r
.58123 .84712 m .58208 .84769 L .58234 .84743 L F
.787 .787 .853 r
.65853 .62498 m .65957 .62651 L .65654 .6272 L F
.647 .291 .355 r
.65957 .62651 m .6588 .62893 L .65654 .6272 L F
.585 .759 .962 r
.65853 .62498 m .66098 .62552 L .65957 .62651 L F
.529 .254 .442 r
.66098 .62552 m .6588 .62893 L .65957 .62651 L F
.963 .85 .682 r
.58183 .81695 m .58188 .81976 L .58158 .8198 L F
0 0 .383 r
.58188 .81976 m .5815 .82236 L .58251 .82126 L F
.58188 .81976 m .58251 .82126 L .58158 .8198 L F
.893 .489 .24 r
.68599 .749 m .68471 .7486 L .68337 .7459 L F
.939 .649 .186 r
.68599 .749 m .68564 .74992 L .68471 .7486 L F
.68599 .749 m .68628 .75107 L .68564 .74992 L F
.619 .469 .656 r
.4198 .87252 m .42239 .87257 L .42161 .86975 L F
.685 .522 .66 r
.4198 .87252 m .42264 .87478 L .42239 .87257 L F
.4198 .87252 m .42022 .87516 L .42264 .87478 L F
.596 .753 .953 r
.43432 .7513 m .43028 .75033 L .43404 .75043 L F
.583 .611 .846 r
.43611 .7502 m .43432 .7513 L .43404 .75043 L F
.655 .56 .736 r
.43611 .7502 m .43471 .75329 L .43432 .7513 L F
.867 .537 .024 r
.67645 .7276 m .67595 .72691 L .67535 .72463 L F
.952 .606 .303 r
.67645 .7276 m .67593 .72931 L .67595 .72691 L F
.67645 .7276 m .67708 .73001 L .67593 .72931 L F
0 0 0 r
.6074 .83465 m .60644 .83557 L .60822 .83237 L F
0 0 .329 r
.60717 .83695 m .60644 .83557 L .6074 .83465 L F
.60717 .83695 m .60653 .83796 L .60644 .83557 L F
.457 .789 .999 r
.48032 .84284 m .47934 .84386 L .47808 .84299 L F
.48032 .84284 m .48152 .8436 L .47934 .84386 L F
.47934 .84386 m .48032 .84284 L .47808 .84299 L F
.47934 .84386 m .48152 .8436 L .48032 .84284 L F
.629 .92 .647 r
.71195 .74552 m .71195 .74532 L .70964 .74759 L F
.577 .498 .729 r
.42447 .74581 m .42178 .74358 L .42386 .74323 L F
.501 .726 .973 r
.41816 .735 m .41743 .73649 L .4161 .73524 L F
.41816 .735 m .41943 .73624 L .41743 .73649 L F
.787 .655 .716 r
.6424 .76177 m .64544 .7621 L .64445 .76158 L F
.695 .655 .806 r
.64544 .7621 m .64647 .75858 L .64445 .76158 L F
.64544 .7621 m .6476 .76155 L .64647 .75858 L F
.867 .53 .412 r
.67297 .70831 m .674 .71124 L .67489 .70922 L F
.684 .31 .332 r
.674 .71124 m .67717 .7111 L .67489 .70922 L F
.881 .835 .796 r
.69578 .70595 m .69615 .7085 L .69705 .70674 L F
.708 .616 .752 r
.4088 .88551 m .41212 .88565 L .41074 .88287 L F
.735 .734 .85 r
.41212 .88565 m .41271 .88282 L .41074 .88287 L F
.854 .583 .527 r
.57217 .79611 m .57271 .79347 L .56927 .79291 L F
.57217 .79611 m .57313 .7962 L .57271 .79347 L F
.475 .32 .591 r
.57271 .79347 m .57313 .7962 L .57463 .79539 L F
.628 .494 .68 r
.44073 .8434 m .44347 .84339 L .44265 .84055 L F
.618 .439 .617 r
.44086 .84581 m .44347 .84339 L .44073 .8434 L F
.689 .546 .686 r
.42161 .86975 m .42456 .86982 L .42384 .86703 L F
.641 .517 .696 r
.42384 .86703 m .42659 .86724 L .42589 .86415 L F
.42384 .86703 m .42456 .86982 L .42659 .86724 L F
.451 .131 .331 r
.37478 .79548 m .37179 .79849 L .37284 .79583 L F
0 0 .443 r
.7167 .73565 m .71742 .73215 L .71753 .73444 L F
0 0 .147 r
.71637 .73781 m .7167 .73565 L .71753 .73444 L F
.082 .201 .69 r
.54309 .8352 m .54396 .83824 L .54443 .83648 L F
.862 .994 .818 r
.54396 .83824 m .54308 .83826 L .54443 .83648 L F
.989 .768 .513 r
.67759 .73294 m .67645 .73454 L .6767 .7323 L F
.67759 .73294 m .67744 .73523 L .67645 .73454 L F
.428 .828 .98 r
.36806 .74841 m .36662 .748 L .36461 .74837 L F
.36461 .74837 m .36662 .748 L .36806 .74841 L F
.703 .526 .646 r
.37092 .75061 m .36791 .75136 L .36806 .74841 L F
.979 .838 .633 r
.53048 .8547 m .53135 .85601 L .53135 .85568 L F
.843 .612 .588 r
.54862 .80093 m .55021 .80364 L .55025 .8014 L F
.743 .526 .6 r
.55025 .8014 m .55021 .80364 L .55309 .80324 L F
.866 .971 .654 r
.56198 .80275 m .56345 .80171 L .56165 .80224 L F
.574 .786 .979 r
.39575 .72703 m .39357 .7275 L .39237 .72649 L F
.576 .438 .656 r
.62041 .74871 m .62263 .74834 L .62222 .74607 L F
.517 .344 .586 r
.62062 .75106 m .62263 .74834 L .62041 .74871 L F
.521 .824 1 r
.51834 .85291 m .51727 .85386 L .51602 .85319 L F
.095 0 .377 r
.51832 .8555 m .51679 .85639 L .51727 .85386 L F
.935 .675 .521 r
.49931 .87249 m .5004 .87458 L .49787 .87421 L F
0 0 0 r
.59756 .84574 m .59868 .84515 L .59744 .84625 L F
.523 .24 .426 r
.38893 .77225 m .39116 .77197 L .39174 .7696 L F
.463 .196 .422 r
.39116 .77197 m .39365 .76907 L .39174 .7696 L F
.745 .625 .726 r
.65949 .73819 m .65699 .74074 L .65594 .73761 L F
.645 .467 .628 r
.65949 .73819 m .65946 .74008 L .65699 .74074 L F
.415 .706 .982 r
.65949 .73819 m .66179 .73794 L .66029 .73701 L F
.126 .307 .776 r
.66029 .73701 m .66103 .73953 L .65949 .73819 L F
.507 .355 .609 r
.65949 .73819 m .66103 .73953 L .65946 .74008 L F
.669 .503 .652 r
.43411 .85128 m .43656 .85126 L .43638 .84866 L F
.627 .463 .641 r
.43638 .84866 m .43865 .84843 L .43854 .84605 L F
.631 .474 .652 r
.43638 .84866 m .4392 .85093 L .43865 .84843 L F
.43638 .84866 m .43656 .85126 L .4392 .85093 L F
.617 .728 .925 r
.40983 .74291 m .41103 .7442 L .41296 .74365 L F
.594 .891 .99 r
.40107 .74282 m .40245 .74329 L .40486 .74249 L F
.854 .997 .781 r
.57392 .82375 m .57389 .8251 L .5761 .82241 L F
0 0 .264 r
.57429 .82601 m .57389 .8251 L .57392 .82375 L F
.57429 .82601 m .57454 .82757 L .57389 .8251 L F
.497 .857 .612 r
.49926 .84298 m .49618 .84533 L .49984 .84243 L F
.628 .472 .651 r
.43865 .84843 m .44086 .84581 L .43854 .84605 L F
.445 .168 .398 r
.42938 .76094 m .42781 .75963 L .42969 .75778 L F
.511 .302 .533 r
.43241 .75557 m .43209 .75883 L .42969 .75778 L F
.573 .31 .48 r
.43209 .75883 m .42938 .76094 L .42969 .75778 L F
.68 .586 .744 r
.50208 .85957 m .50309 .86137 L .50431 .8592 L F
.246 .077 .444 r
.50431 .8592 m .50309 .86137 L .50442 .8616 L F
.6 .065 0 r
.50309 .86137 m .50517 .86323 L .50465 .86326 L F
.192 .259 .703 r
.50309 .86137 m .50465 .86326 L .50442 .8616 L F
.546 .555 .815 r
.41422 .7468 m .4145 .74346 L .41296 .74365 L F
.41422 .7468 m .41601 .74671 L .4145 .74346 L F
.468 .589 .892 r
.41422 .7468 m .41691 .74777 L .41601 .74671 L F
.942 .838 .398 r
.67578 .7225 m .67513 .72367 L .67485 .7215 L F
.67578 .7225 m .67535 .72463 L .67513 .72367 L F
.713 .524 .633 r
.42161 .86975 m .42475 .87231 L .42456 .86982 L F
.42161 .86975 m .42239 .87257 L .42475 .87231 L F
.623 .312 .422 r
.52286 .85346 m .52194 .85128 L .52079 .8521 L F
.602 .144 .137 r
.57653 .77458 m .5787 .77508 L .58013 .77466 L F
.744 .377 .359 r
.58013 .77466 m .5787 .77508 L .58177 .77537 L F
.773 .664 .743 r
.63812 .76716 m .64114 .76749 L .64012 .76443 L F
.632 .435 .598 r
.52699 .85079 m .52914 .84837 L .52702 .84902 L F
.706 .53 .649 r
.51478 .82993 m .51143 .8279 L .51366 .82768 L F
.51478 .82993 m .51168 .83014 L .51143 .8279 L F
.211 0 .309 r
.51168 .83014 m .51366 .82768 L .51143 .8279 L F
.623 .378 .526 r
.49118 .84886 m .4912 .85099 L .48796 .85136 L F
.628 .382 .526 r
.49361 .85072 m .4912 .85099 L .49118 .84886 L F
.904 .617 .489 r
.56731 .81365 m .56966 .81586 L .56852 .81153 L F
.53 .39 .635 r
.41074 .88287 m .41271 .88282 L .41085 .88048 L F
.67 .414 .525 r
.41085 .88048 m .41271 .88282 L .41317 .88048 L F
.163 .41 .851 r
.67685 .7139 m .67852 .71643 L .67593 .71455 L F
.979 .838 .633 r
.53048 .8547 m .53135 .85568 L .53164 .85293 L F
.525 .841 .535 r
.5717 .81528 m .56969 .81726 L .57058 .81632 L F
.786 .838 .375 r
.61249 .82124 m .61332 .81963 L .61258 .81912 L F
.61249 .82124 m .61219 .82263 L .61332 .81963 L F
.609 .454 .646 r
.71359 .71177 m .7141 .71427 L .71166 .71418 L F
.817 .771 .81 r
.71074 .71201 m .71166 .71418 L .71359 .71177 L F
.609 .454 .646 r
.71359 .71177 m .7141 .71427 L .71166 .71418 L F
.479 .386 .672 r
.48587 .82532 m .48382 .82787 L .48349 .82578 L F
.48587 .82532 m .48601 .82739 L .48382 .82787 L F
.264 .028 .356 r
.48601 .82739 m .48408 .82974 L .48382 .82787 L F
.421 0 0 r
.53512 .81076 m .53705 .8113 L .53843 .8112 L F
.726 .235 .073 r
.53705 .8113 m .54016 .81226 L .53843 .8112 L F
.614 .419 .594 r
.68195 .74076 m .68222 .74302 L .68042 .74365 L F
.903 .723 .648 r
.61961 .79804 m .61842 .79558 L .61676 .79826 L F
.819 .678 .707 r
.61807 .80133 m .61961 .79804 L .61676 .79826 L F
.43 .07 .252 r
.39117 .78558 m .3885 .78727 L .38974 .78479 L F
.495 .139 .29 r
.3694 .78511 m .37159 .78496 L .37268 .7828 L F
.366 .01 .222 r
.37268 .7828 m .37353 .78451 L .37478 .7826 L F
.37268 .7828 m .37159 .78496 L .37353 .78451 L F
.271 .734 .949 r
.40644 .74247 m .40798 .74299 L .40983 .74291 L F
.851 .6 .558 r
.48872 .87163 m .49044 .86981 L .48743 .86937 L F
.48872 .87163 m .49077 .87226 L .49044 .86981 L F
.222 0 0 r
.35442 .80839 m .356 .80695 L .35803 .80656 L F
.976 .739 .515 r
.46437 .86921 m .46579 .87098 L .4654 .86846 L F
.215 0 0 r
.46667 .86865 m .4654 .86846 L .46756 .8679 L F
.46667 .86865 m .46437 .86921 L .4654 .86846 L F
.777 .802 .873 r
.66724 .74696 m .66337 .74798 L .66615 .74613 L F
.854 .875 .854 r
.66858 .74558 m .66724 .74696 L .66615 .74613 L F
.56 .182 .282 r
.58191 .78496 m .5816 .78693 L .57878 .78572 L F
.681 .196 .091 r
.58458 .78738 m .58191 .78496 L .58441 .78531 L F
.58458 .78738 m .5816 .78693 L .58191 .78496 L F
.657 .654 .836 r
.55267 .78192 m .5521 .77924 L .55302 .78031 L F
.844 .393 .138 r
.5521 .77924 m .55267 .78192 L .55302 .78031 L F
.547 .863 .996 r
.49703 .88178 m .49604 .88306 L .49806 .8824 L F
.57 .83 .468 r
.49484 .88447 m .49604 .88306 L .49703 .88178 L F
.422 0 0 r
.50902 .81996 m .5113 .81992 L .51181 .81918 L F
.50902 .81996 m .5113 .81992 L .51181 .81918 L F
0 0 0 r
.51181 .81918 m .51379 .81731 L .51351 .81935 L F
.212 0 0 r
.51351 .81935 m .5113 .81992 L .51181 .81918 L F
0 0 0 r
.51181 .81918 m .5113 .81992 L .51379 .81731 L F
.519 .362 .608 r
.38423 .7724 m .38626 .77403 L .38658 .77224 L F
.38423 .7724 m .38417 .77453 L .38626 .77403 L F
.79 .579 .616 r
.48684 .84085 m .48678 .84347 L .48347 .84291 L F
.508 .346 .596 r
.48922 .84205 m .48684 .84085 L .48904 .84068 L F
.48922 .84205 m .48678 .84347 L .48684 .84085 L F
.859 .572 .5 r
.49308 .87987 m .4948 .87779 L .492 .8767 L F
.677 .316 .354 r
.49691 .87975 m .4948 .87779 L .49308 .87987 L F
0 0 0 r
.6074 .83465 m .60822 .83237 L .60801 .83276 L F
.60801 .83276 m .60822 .83237 L .61029 .82981 L F
.846 .89 .87 r
.53781 .79834 m .53793 .79888 L .53687 .79809 L F
.53781 .79834 m .53687 .79809 L .53912 .79783 L F
.217 .342 .777 r
.53793 .79888 m .53912 .79783 L .53687 .79809 L F
.541 0 0 r
.52848 .85375 m .52865 .85458 L .52837 .85477 L F
.52789 .85471 m .52837 .85477 L .52751 .85534 L F
.52848 .85375 m .52837 .85477 L .52789 .85471 L F
.374 .22 .541 r
.52837 .85477 m .52883 .85501 L .52884 .8547 L F
.541 0 0 r
.52848 .85375 m .52898 .85479 L .52865 .85458 L F
.374 .22 .541 r
.52865 .85458 m .52884 .8547 L .52885 .85445 L F
.52837 .85477 m .52884 .8547 L .52865 .85458 L F
.541 0 0 r
.52848 .85375 m .53048 .8547 L .52902 .85479 L F
.507 .328 .572 r
.52894 .85135 m .52884 .8547 L .53118 .8523 L F
.52884 .8547 m .52883 .85501 L .52902 .85479 L F
.52884 .8547 m .52902 .85479 L .53118 .8523 L F
.541 0 0 r
.52897 .85476 m .52902 .85479 L .52898 .85479 L F
.52848 .85375 m .52902 .85479 L .52897 .85476 L F
.52865 .85458 m .52898 .85479 L .52869 .8548 L F
.309 .065 .373 r
.52837 .85477 m .52869 .8548 L .52883 .85501 L F
.374 .22 .541 r
.5272 .85414 m .52837 .85477 L .52894 .85135 L F
.309 .065 .373 r
.5272 .85414 m .52869 .8548 L .52837 .85477 L F
.374 .22 .541 r
.52837 .85477 m .52885 .85445 L .52894 .85135 L F
.541 0 0 r
.52751 .85534 m .52869 .8548 L .52707 .85606 L F
.52865 .85458 m .52869 .8548 L .52751 .85534 L F
.872 .546 .43 r
.39191 .74539 m .39118 .74455 L .39357 .74423 L F
.39191 .74539 m .39157 .74578 L .39118 .74455 L F
.02 0 0 r
.39204 .74616 m .39157 .74578 L .39191 .74539 L F
0 0 0 r
.39583 .74356 m .39191 .74539 L .39357 .74423 L F
.39456 .74475 m .39204 .74616 L .39191 .74539 L F
.699 .6 .742 r
.65594 .73761 m .65411 .74059 L .65384 .73842 L F
.65594 .73761 m .65699 .74074 L .65411 .74059 L F
.803 .691 .742 r
.63059 .77217 m .63365 .77228 L .63255 .76933 L F
.756 .669 .766 r
.63255 .76933 m .63365 .77228 L .63581 .76966 L F
.491 .209 .413 r
.42781 .75963 m .42744 .76145 L .42536 .7618 L F
.445 .168 .398 r
.42938 .76094 m .42744 .76145 L .42781 .75963 L F
.898 .834 .774 r
.66828 .74305 m .66858 .74558 L .66726 .7449 L F
.854 .875 .854 r
.66858 .74558 m .66615 .74613 L .66726 .7449 L F
.685 .847 .96 r
.53652 .84424 m .54013 .84442 L .53852 .8435 L F
.741 .859 .935 r
.53852 .8435 m .54013 .84442 L .54184 .84325 L F
.013 .062 .568 r
.32351 .66563 m .32261 .66683 L .32132 .66419 L F
.32351 .66563 m .32267 .66698 L .32261 .66683 L F
.165 .145 .589 r
.32261 .66683 m .32267 .66698 L .32263 .66701 L F
.641 .319 .411 r
.44941 .83691 m .45212 .83773 L .45004 .83546 L F
.651 .625 .81 r
.41082 .73279 m .40874 .73355 L .40765 .73167 L F
.621 .594 .802 r
.41117 .73392 m .40874 .73355 L .41082 .73279 L F
.989 .892 .59 r
.56341 .83251 m .5627 .83202 L .56341 .82989 L F
0 0 .119 r
.56341 .83251 m .5636 .83443 L .5627 .83202 L F
.56341 .83251 m .56339 .83578 L .5636 .83443 L F
.425 0 0 r
.42808 .88603 m .43145 .88835 L .43034 .88571 L F
.764 .699 .79 r
.43034 .88571 m .43145 .88835 L .43348 .8861 L F
.64 .547 .734 r
.63974 .73788 m .63701 .73548 L .63848 .73504 L F
.841 .849 .85 r
.69578 .70595 m .69705 .70674 L .6988 .70462 L F
0 0 0 r
.69503 .7542 m .69155 .75439 L .6928 .75416 L F
.209 0 0 r
.68962 .7541 m .6928 .75416 L .69155 .75439 L F
.475 .218 .444 r
.49015 .84789 m .49236 .84582 L .49103 .84583 L F
.759 .597 .676 r
.4891 .84568 m .49015 .84789 L .49103 .84583 L F
.48684 .84551 m .48817 .84647 L .4891 .84568 L F
.48817 .84647 m .49015 .84789 L .4891 .84568 L F
0 0 0 r
.49024 .84409 m .48991 .84465 L .48942 .84543 L F
.72 .437 .497 r
.48941 .84544 m .48684 .84551 L .48678 .84347 L F
.759 .597 .676 r
.48684 .84551 m .48647 .8482 L .49015 .84789 L F
.646 .959 .928 r
.48725 .84686 m .48684 .84551 L .48941 .84544 L F
.698 .332 .349 r
.49012 .84403 m .49018 .84416 L .49021 .84411 L F
0 0 0 r
.49096 .8429 m .48941 .84544 L .48922 .84205 L F
.59 .912 .668 r
.48991 .84465 m .48725 .84686 L .48926 .84554 L F
0 0 0 r
.48944 .8454 m .48942 .84543 L .48941 .84544 L F
.59 .912 .668 r
.48945 .84538 m .48926 .84554 L .48941 .84544 L F
.48991 .84465 m .48926 .84554 L .48945 .84538 L F
.97 .835 .423 r
.49135 .84651 m .48972 .84497 L .48991 .84465 L F
.035 0 .435 r
.4884 .84371 m .48725 .84686 L .48991 .84465 L F
.97 .835 .423 r
.48972 .84497 m .4884 .84371 L .48991 .84465 L F
0 0 0 r
.49096 .8429 m .48991 .84465 L .49024 .84409 L F
.49096 .8429 m .48942 .84543 L .48944 .8454 L F
.698 .332 .349 r
.49021 .84411 m .49103 .84583 L .49236 .84582 L F
.49018 .84416 m .49103 .84583 L .49021 .84411 L F
.968 .648 .337 r
.54844 .82176 m .54915 .81904 L .5474 .81881 L F
.54844 .82176 m .5497 .8231 L .54915 .81904 L F
.669 .566 .73 r
.41206 .75322 m .41439 .75072 L .41241 .75127 L F
.883 .808 .77 r
.71607 .72231 m .7128 .72459 L .71519 .72127 L F
.474 0 0 r
.71745 .7235 m .71607 .72231 L .71519 .72127 L F
.189 0 0 r
.71643 .72511 m .71607 .72231 L .7184 .72421 L F
.474 0 0 r
.71745 .7235 m .71802 .7239 L .71607 .72231 L F
.548 .912 .957 r
.71745 .7235 m .71874 .7224 L .7169 .72311 L F
.675 .135 0 r
.71663 .72322 m .71745 .7235 L .71655 .72261 L F
.71663 .72322 m .71655 .72261 L .71519 .72127 L F
.679 .961 .941 r
.71556 .72462 m .71745 .7235 L .71663 .72322 L F
.65 .878 .983 r
.71643 .72511 m .71745 .7235 L .71556 .72462 L F
.71643 .72511 m .7184 .72421 L .71745 .7235 L F
.273 0 .098 r
.71663 .72322 m .71802 .72412 L .71564 .72436 L F
.043 0 0 r
.71671 .7238 m .71663 .72322 L .71564 .72436 L F
.548 .912 .957 r
.71745 .7235 m .7169 .72311 L .71663 .72322 L F
.71745 .7235 m .71874 .7224 L .71663 .72322 L F
.474 0 0 r
.71745 .7235 m .7184 .72421 L .71802 .7239 L F
.273 0 .098 r
.71663 .72322 m .71874 .7224 L .71802 .72412 L F
.628 .599 .801 r
.71768 .7194 m .71874 .7224 L .71663 .72322 L F
.71768 .7194 m .71663 .72322 L .71859 .72267 L F
.732 .788 .302 r
.71849 .72299 m .71874 .7224 L .71876 .72231 L F
.628 .599 .801 r
.71883 .72195 m .71859 .72267 L .71909 .72253 L F
.091 .247 .732 r
.71914 .72099 m .71874 .7224 L .71768 .7194 L F
.628 .599 .801 r
.71768 .7194 m .71859 .72267 L .71883 .72195 L F
.732 .788 .302 r
.71802 .72412 m .71846 .72307 L .71849 .72299 L F
.71846 .72307 m .71874 .7224 L .71849 .72299 L F
.902 .575 .416 r
.71768 .7194 m .71883 .72195 L .71726 .72073 L F
.71883 .72195 m .71909 .72253 L .71873 .72218 L F
.71883 .72195 m .71873 .72218 L .71726 .72073 L F
.043 0 0 r
.71851 .72284 m .71663 .72322 L .71671 .7238 L F
.71859 .72267 m .71663 .72322 L .71851 .72284 L F
.675 .135 0 r
.71663 .72322 m .71519 .72127 L .71526 .72253 L F
.679 .961 .941 r
.71556 .72462 m .71663 .72322 L .71526 .72253 L F
.587 .486 .707 r
.71564 .72436 m .71726 .72073 L .71873 .72218 L F
.732 .788 .302 r
.71851 .72284 m .71876 .72231 L .71867 .72236 L F
.043 0 0 r
.71909 .72253 m .71859 .72267 L .71851 .72284 L F
.587 .486 .707 r
.71851 .72284 m .71873 .72218 L .71909 .72253 L F
.71564 .72436 m .71873 .72218 L .71851 .72284 L F
.732 .788 .302 r
.71867 .72236 m .71876 .72231 L .71895 .72165 L F
.71839 .72309 m .71851 .72284 L .71867 .72236 L F
.71856 .72262 m .71895 .72165 L .71914 .72099 L F
.71839 .72309 m .71895 .72165 L .71856 .72262 L F
.71802 .72412 m .71876 .72231 L .71839 .72309 L F
.36 0 0 r
.35661 .72639 m .35857 .72647 L .36015 .72553 L F
.215 0 0 r
.35857 .72647 m .36217 .72507 L .36015 .72553 L F
.534 .37 .605 r
.6219 .74312 m .62427 .7428 L .62397 .74046 L F
.477 .353 .633 r
.62222 .74607 m .62427 .7428 L .6219 .74312 L F
.465 .389 .686 r
.32267 .66698 m .32302 .66954 L .32263 .66701 L F
.924 .835 .738 r
.67933 .75056 m .68174 .74842 L .67972 .74805 L F
.67933 .75056 m .68057 .75137 L .68174 .74842 L F
.695 .302 .299 r
.5787 .77508 m .58221 .77668 L .58177 .77537 L F
.691 .637 .791 r
.6476 .76155 m .65071 .76205 L .64976 .75911 L F
.617 .533 .737 r
.65071 .76205 m .65209 .75854 L .64976 .75911 L F
.65071 .76205 m .65298 .76162 L .65209 .75854 L F
.711 .319 0 r
.52581 .87237 m .52723 .87501 L .52665 .87406 L F
.246 0 0 r
.49394 .8388 m .49216 .83941 L .49444 .83834 L F
.517 .054 .095 r
.62938 .73101 m .63225 .73042 L .63038 .73 L F
.821 .945 .59 r
.55275 .8479 m .55258 .849 L .55419 .84628 L F
.774 .805 .319 r
.55181 .85124 m .55258 .849 L .55275 .8479 L F
.646 .583 .769 r
.68818 .71131 m .68888 .7115 L .69046 .71021 L F
.524 .496 .767 r
.42479 .73754 m .42374 .74076 L .42275 .73791 L F
.42479 .73754 m .42558 .74069 L .42374 .74076 L F
.629 .5 .686 r
.42558 .74069 m .42386 .74323 L .42374 .74076 L F
.7 .558 .69 r
.60559 .76737 m .6056 .76965 L .60773 .767 L F
0 0 .434 r
.46189 .83457 m .46107 .83614 L .4598 .8347 L F
.46189 .83457 m .46206 .83616 L .46107 .83614 L F
.439 .042 .187 r
.52459 .82787 m .52199 .82886 L .52251 .82833 L F
.642 .266 .317 r
.55021 .80364 m .55197 .80506 L .55309 .80324 L F
.574 .292 .45 r
.55197 .80506 m .55532 .80235 L .55309 .80324 L F
.584 .358 .539 r
.61475 .76152 m .61698 .76176 L .61704 .75903 L F
.551 .426 .663 r
.61704 .75903 m .61923 .75866 L .61887 .75612 L F
.508 .297 .528 r
.61704 .75903 m .61833 .75967 L .61923 .75866 L F
.61704 .75903 m .61698 .76176 L .61833 .75967 L F
.558 .435 .669 r
.47736 .85104 m .47478 .85191 L .47462 .84865 L F
.699 .407 .478 r
.47711 .84897 m .47736 .85104 L .47462 .84865 L F
.795 .305 .034 r
.54468 .80358 m .54341 .80331 L .54155 .80172 L F
.963 .765 .589 r
.54355 .80097 m .54468 .80358 L .54683 .80338 L F
.54355 .80097 m .54341 .80331 L .54468 .80358 L F
.936 .569 .18 r
.46571 .87122 m .46579 .87098 L .46437 .86921 L F
.176 .215 .663 r
.53035 .81149 m .5318 .81343 L .53176 .81105 L F
.788 .466 .444 r
.51094 .87958 m .5114 .87816 L .50769 .8774 L F
.558 .456 .695 r
.41317 .88048 m .41509 .88018 L .41463 .87718 L F
.53 .284 .486 r
.41317 .88048 m .41487 .88251 L .41509 .88018 L F
.41317 .88048 m .41271 .88282 L .41487 .88251 L F
.655 .493 .653 r
.60773 .767 m .6056 .76965 L .60789 .7693 L F
.654 .486 .643 r
.60789 .7693 m .61008 .76676 L .60773 .767 L F
.95 .941 .617 r
.55275 .8479 m .55419 .84628 L .55408 .84436 L F
.912 .698 .6 r
.68262 .72235 m .68292 .71977 L .68133 .71909 L F
.51 .445 .719 r
.69521 .72991 m .69277 .73093 L .69242 .72752 L F
.206 0 .085 r
.69473 .73076 m .69277 .73093 L .69521 .72991 L F
.69473 .73076 m .69256 .73197 L .69277 .73093 L F
.705 .661 .803 r
.6476 .76155 m .64976 .75911 L .64647 .75858 L F
.691 .725 .876 r
.42476 .88539 m .42808 .88603 L .42727 .88484 L F
.567 .672 .91 r
.42727 .88484 m .42808 .88603 L .43034 .88571 L F
.632 .658 .858 r
.51854 .87767 m .51546 .87942 L .51596 .87698 L F
.218 0 0 r
.51752 .87665 m .51854 .87767 L .51741 .87656 L F
.51979 .8785 m .51854 .87767 L .51752 .87665 L F
.699 .65 .798 r
.51997 .87838 m .51938 .87852 L .51854 .87767 L F
.51938 .87852 m .51546 .87942 L .51854 .87767 L F
.081 .196 .685 r
.52581 .87237 m .52742 .87373 L .52753 .87158 L F
.52581 .87237 m .52753 .87158 L .52755 .87127 L F
.682 .443 .554 r
.52742 .87373 m .52807 .87189 L .52773 .87149 L F
.473 .062 .178 r
.529 .87088 m .52581 .87237 L .52832 .87122 L F
.682 .443 .554 r
.52753 .87158 m .52773 .87149 L .52755 .87127 L F
.52742 .87373 m .52773 .87149 L .52753 .87158 L F
.473 .062 .178 r
.52832 .87122 m .52774 .87148 L .52826 .87124 L F
.357 .183 .503 r
.52755 .87127 m .52773 .87149 L .52826 .87124 L F
.52773 .87149 m .52807 .87189 L .52826 .87124 L F
.473 .062 .178 r
.52774 .87148 m .52753 .87158 L .52826 .87124 L F
.52753 .87158 m .52581 .87237 L .52614 .87221 L F
.52753 .87158 m .52614 .87221 L .52826 .87124 L F
.251 0 0 r
.52807 .87189 m .529 .87088 L .52826 .87124 L F
.588 .408 .605 r
.43448 .85373 m .43656 .85126 L .43411 .85128 L F
.075 0 0 r
.50866 .83258 m .50713 .83269 L .50933 .83282 L F
.50866 .83258 m .50586 .83442 L .50713 .83269 L F
.467 .109 .275 r
.33665 .735 m .33851 .73509 L .33972 .73288 L F
.434 .086 .274 r
.33851 .73509 m .34169 .73247 L .33972 .73288 L F
.532 .521 .789 r
.70725 .74532 m .70805 .74822 L .70964 .74759 L F
.239 .368 .793 r
.32351 .66563 m .32459 .66852 L .32267 .66698 L F
.465 .389 .686 r
.32267 .66698 m .32459 .66852 L .32302 .66954 L F
0 .222 .741 r
.55118 .82485 m .55304 .82667 L .55262 .82747 L F
0 .236 .745 r
.55516 .82996 m .55262 .82747 L .55408 .82961 L F
.987 .777 .535 r
.55304 .82667 m .55408 .82961 L .55262 .82747 L F
.7 .501 .616 r
.50773 .84873 m .50737 .85116 L .50525 .85093 L F
.651 .531 .704 r
.42659 .86724 m .42456 .86982 L .42688 .8696 L F
.627 .472 .652 r
.42475 .87231 m .42688 .8696 L .42456 .86982 L F
.504 .456 .737 r
.32374 .6726 m .32603 .67382 L .3243 .67487 L F
.522 .326 .556 r
.33708 .68273 m .33685 .685 L .33482 .68537 L F
.37 .176 .482 r
.33685 .685 m .33502 .68756 L .33482 .68537 L F
.54 .08 .111 r
.56992 .77635 m .57339 .77537 L .57132 .77578 L F
.255 .331 .749 r
.58251 .82126 m .5815 .82236 L .58361 .82427 L F
.991 .734 .381 r
.6622 .7113 m .66265 .71462 L .66176 .71392 L F
.817 .771 .81 r
.71074 .71201 m .71359 .71177 L .71299 .71116 L F
.996 .798 .436 r
.71299 .71116 m .71359 .71177 L .71325 .70888 L F
.525 .399 .65 r
.71359 .71177 m .7161 .71366 L .7141 .71427 L F
.952 .65 .213 r
.71299 .71116 m .7141 .71427 L .71359 .71177 L F
.525 .399 .65 r
.71359 .71177 m .7161 .71366 L .7141 .71427 L F
.81 .604 .623 r
.56096 .7798 m .56201 .78128 L .56342 .7775 L F
.088 0 .269 r
.56342 .7775 m .56466 .77737 L .56571 .77699 L F
.56342 .7775 m .56201 .78128 L .56466 .77737 L F
.238 0 0 r
.35792 .79079 m .35825 .79206 L .35954 .79015 L F
.35792 .79079 m .35632 .79257 L .35825 .79206 L F
0 0 0 r
.60801 .83276 m .61029 .82981 L .60984 .82994 L F
.672 .919 .605 r
.5227 .84125 m .52006 .84425 L .52119 .84263 L F
.645 .905 .982 r
.3763 .72438 m .3729 .72482 L .37488 .72422 L F
.179 .639 .938 r
.37688 .72388 m .3763 .72438 L .37488 .72422 L F
.37688 .72388 m .37822 .72461 L .3763 .72438 L F
.713 .429 .493 r
.56701 .78017 m .56384 .78216 L .56335 .78088 L F
.56701 .78017 m .56686 .78237 L .56384 .78216 L F
.672 .393 .491 r
.56701 .78017 m .56914 .78237 L .56686 .78237 L F
.833 .362 .052 r
.55398 .81216 m .55275 .81174 L .55105 .80924 L F
.856 .403 .101 r
.55398 .81216 m .55364 .81334 L .55275 .81174 L F
.86 .409 .102 r
.55398 .81216 m .5552 .81422 L .55364 .81334 L F
.648 .506 .676 r
.44265 .84055 m .4455 .84312 L .44514 .84035 L F
.44265 .84055 m .44347 .84339 L .4455 .84312 L F
.831 .7 .719 r
.66181 .71972 m .66097 .72215 L .65995 .71928 L F
.812 .943 .911 r
.59468 .81764 m .59128 .81928 L .59363 .81695 L F
.925 .883 .773 r
.59545 .81404 m .59468 .81764 L .59363 .81695 L F
.653 .62 .803 r
.52632 .83596 m .52988 .8385 L .52881 .83509 L F
.284 .359 .764 r
.52881 .83509 m .52988 .8385 L .53127 .83756 L F
.229 .251 .677 r
.52988 .8385 m .53212 .84083 L .53127 .83756 L F
.731 .624 .739 r
.54299 .84852 m .54689 .84994 L .54491 .84655 L F
.574 .561 .802 r
.54491 .84655 m .54689 .84994 L .54799 .84869 L F
.404 .315 .64 r
.54689 .84994 m .54835 .85221 L .54799 .84869 L F
.717 .66 .792 r
.68894 .73562 m .69144 .73543 L .69305 .733 L F
.566 .381 .589 r
.69144 .73543 m .69398 .73737 L .69395 .7351 L F
.69144 .73543 m .69156 .73784 L .69398 .73737 L F
.69144 .73543 m .69398 .73737 L .69395 .7351 L F
.69144 .73543 m .69156 .73784 L .69398 .73737 L F
.42 0 0 r
.47978 .82689 m .48213 .82683 L .48349 .82578 L F
.666 .367 .456 r
.48213 .82683 m .48587 .82532 L .48349 .82578 L F
.846 .809 .815 r
.47094 .8699 m .46887 .87284 L .46779 .87139 L F
.839 .601 .578 r
.64333 .73634 m .64365 .73661 L .64415 .73709 L F
.472 .842 .99 r
.64477 .73768 m .64415 .73709 L .64533 .7377 L F
.791 .725 .79 r
.64533 .7377 m .64322 .73886 L .64188 .73756 L F
.584 .893 .989 r
.64533 .7377 m .64415 .73709 L .64717 .73699 L F
.75 .385 .362 r
.64415 .73709 m .64628 .73885 L .64717 .73699 L F
.839 .601 .578 r
.64365 .73661 m .64628 .73885 L .64415 .73709 L F
.472 .842 .99 r
.64188 .73756 m .64415 .73709 L .64477 .73768 L F
.792 .961 .919 r
.35365 .75304 m .35492 .75331 L .35721 .7516 L F
.602 .322 .464 r
.53315 .8295 m .53462 .82944 L .53449 .82655 L F
.442 .465 .787 r
.53449 .82655 m .53751 .82718 L .53498 .82567 L F
.511 .253 .46 r
.53449 .82655 m .53462 .82944 L .53751 .82718 L F
.848 .732 .735 r
.62418 .78219 m .62216 .78505 L .62483 .78506 L F
.843 .762 .773 r
.62483 .78506 m .62216 .78505 L .62293 .78779 L F
.78 .693 .768 r
.62418 .78219 m .62483 .78506 L .62684 .78216 L F
.54 .143 .237 r
.69394 .75044 m .69693 .74868 L .6938 .74864 L F
.69394 .75044 m .69629 .75058 L .69693 .74868 L F
0 0 0 r
.69629 .75058 m .69912 .74931 L .69693 .74868 L F
.724 .686 .814 r
.62577 .73794 m .6289 .73806 L .6277 .7355 L F
.169 0 .141 r
.62756 .73902 m .62792 .7385 L .6279 .73823 L F
.452 .542 .857 r
.6277 .7355 m .6289 .73806 L .62958 .73609 L F
.53 .319 .539 r
.62789 .73802 m .6279 .73823 L .6289 .73806 L F
.869 .989 .829 r
.6289 .73806 m .6279 .73823 L .62958 .73609 L F
.169 0 .141 r
.62792 .7385 m .62958 .73609 L .6279 .73823 L F
.53 .319 .539 r
.62577 .73794 m .6279 .73823 L .62789 .73802 L F
.749 .689 .793 r
.63255 .76933 m .63581 .76966 L .6347 .76683 L F
.738 .684 .798 r
.6347 .76683 m .63581 .76966 L .63812 .76716 L F
.514 .871 .634 r
.37931 .74787 m .37875 .74847 L .38073 .74826 L F
.788 .675 .739 r
.64116 .75884 m .64445 .76158 L .64343 .75816 L F
.64116 .75884 m .6424 .76177 L .64445 .76158 L F
.711 .665 .804 r
.64343 .75816 m .64445 .76158 L .64647 .75858 L F
.246 0 .054 r
.49636 .83777 m .49394 .8388 L .49444 .83834 L F
.287 0 0 r
.55613 .80038 m .5593 .79995 L .56003 .79801 L F
.472 .266 .519 r
.56003 .79801 m .56171 .79817 L .56191 .796 L F
.925 .693 .568 r
.55971 .80015 m .56003 .79801 L .5593 .79995 L F
.55971 .80015 m .56171 .79817 L .56003 .79801 L F
.472 .266 .519 r
.56191 .796 m .56171 .79817 L .56003 .79801 L F
.56191 .796 m .56171 .79817 L .56003 .79801 L F
.355 0 .169 r
.53425 .83986 m .53537 .83804 L .53459 .83992 L F
.742 .981 .914 r
.53485 .83995 m .53459 .83992 L .53537 .83804 L F
.519 .314 .542 r
.53776 .83774 m .53485 .83995 L .53537 .83804 L F
.133 0 0 r
.46798 .88297 m .4711 .88307 L .46992 .88313 L F
.353 .717 .986 r
.4711 .88307 m .47199 .88226 L .46992 .88313 L F
.4711 .88307 m .47325 .88311 L .47199 .88226 L F
.066 .582 .879 r
.69815 .75396 m .69962 .75389 L .69719 .75416 L F
.69815 .75396 m .70066 .75445 L .69962 .75389 L F
.952 .749 .593 r
.55105 .80924 m .54972 .8091 L .55037 .80636 L F
.837 .38 .121 r
.55105 .80924 m .55058 .81038 L .54972 .8091 L F
.55105 .80924 m .55275 .81174 L .55058 .81038 L F
.688 .538 .677 r
.62549 .73487 m .6236 .73835 L .62577 .73794 L F
.55 .435 .675 r
.62549 .73487 m .62577 .73794 L .6277 .7355 L F
.407 .079 .293 r
.37946 .79361 m .38248 .79071 L .38187 .79207 L F
.317 0 .183 r
.38457 .79042 m .38187 .79207 L .38248 .79071 L F
.476 0 0 r
.36644 .72463 m .36783 .7254 L .36953 .72461 L F
.353 .803 .666 r
.36953 .72461 m .36783 .7254 L .36946 .72459 L F
.36953 .72461 m .36946 .72459 L .37048 .72408 L F
.187 0 0 r
.36957 .72462 m .36953 .72461 L .37084 .72497 L F
.36758 .72408 m .36953 .72461 L .36957 .72462 L F
.342 .769 .973 r
.37153 .72429 m .37084 .72497 L .36953 .72461 L F
.37153 .72429 m .3729 .72482 L .37084 .72497 L F
.693 .526 .657 r
.60353 .77216 m .60567 .77212 L .6056 .76965 L F
.651 .49 .653 r
.60567 .77212 m .60789 .7693 L .6056 .76965 L F
.435 .27 .558 r
.38625 .78973 m .38464 .78809 L .3866 .78771 L F
.38625 .78973 m .38457 .79042 L .38464 .78809 L F
.24 .419 .838 r
.71018 .70309 m .70921 .70405 L .70944 .70327 L F
.404 .687 .977 r
.71018 .70309 m .71099 .70398 L .70921 .70405 L F
.454 .404 .713 r
.32459 .66852 m .32365 .6722 L .32302 .66954 L F
.32459 .66852 m .32525 .67202 L .32365 .6722 L F
.474 .465 .768 r
.32525 .67202 m .32374 .6726 L .32365 .6722 L F
.538 .373 .605 r
.61861 .75371 m .62076 .75333 L .62062 .75106 L F
.556 .424 .656 r
.61887 .75612 m .62076 .75333 L .61861 .75371 L F
.492 .146 .307 r
.34801 .75449 m .34801 .75745 L .34614 .75638 L F
.626 .526 .721 r
.35165 .75348 m .34801 .75449 L .3497 .75368 L F
.35165 .75348 m .3536 .75391 L .34801 .75449 L F
.35165 .75348 m .3536 .75391 L .34801 .75449 L F
.474 .465 .768 r
.32525 .67202 m .32603 .67382 L .32374 .6726 L F
0 0 .301 r
.40966 .7299 m .41082 .73279 L .40977 .73014 L F
.909 .654 .54 r
.67855 .75313 m .68057 .75137 L .67933 .75056 L F
.67855 .75313 m .68055 .75344 L .68057 .75137 L F
.778 .711 .789 r
.48794 .86231 m .48967 .86436 L .48612 .86439 L F
.772 .533 .574 r
.48612 .86439 m .48967 .86436 L .48908 .86613 L F
.587 .627 .858 r
.48999 .86186 m .48967 .86436 L .48794 .86231 L F
.48999 .86186 m .49245 .86425 L .48967 .86436 L F
.705 .46 .552 r
.48967 .86436 m .49131 .86703 L .48908 .86613 L F
.963 .867 .695 r
.59813 .80689 m .59634 .80837 L .59771 .80554 L F
.59813 .80689 m .59734 .80898 L .59634 .80837 L F
.862 .964 .633 r
.55387 .83984 m .5538 .84068 L .55526 .83845 L F
.992 .869 .603 r
.55443 .83772 m .55387 .83984 L .55526 .83845 L F
.794 .853 .401 r
.61133 .82463 m .61219 .82263 L .61249 .82124 L F
.604 .852 .991 r
.39583 .74356 m .39702 .74428 L .39918 .7436 L F
.611 .932 .962 r
.54227 .85931 m .54082 .86017 L .53901 .86062 L F
.405 .682 .974 r
.57367 .81566 m .57598 .81621 L .5745 .81696 L F
.228 .106 .497 r
.57588 .8193 m .5745 .81696 L .57598 .81621 L F
.529 .205 .362 r
.40148 .7774 m .40064 .77964 L .39843 .77974 L F
.382 .064 .297 r
.40252 .77911 m .40148 .7774 L .40354 .77708 L F
.40252 .77911 m .40064 .77964 L .40148 .7774 L F
.902 .759 .693 r
.61401 .81308 m .61529 .81222 L .61366 .81113 L F
.899 .762 .701 r
.61366 .81113 m .61529 .81222 L .61546 .80922 L F
.108 0 .28 r
.33884 .67995 m .33798 .6823 L .33708 .68273 L F
.433 .306 .607 r
.33798 .6823 m .33685 .685 L .33708 .68273 L F
.647 .484 .648 r
.42589 .86415 m .42847 .86452 L .42809 .86195 L F
.671 .536 .691 r
.42589 .86415 m .42891 .86689 L .42847 .86452 L F
.42589 .86415 m .42659 .86724 L .42891 .86689 L F
.557 .319 .51 r
.39614 .76682 m .3983 .76659 L .39841 .76448 L F
.491 .265 .498 r
.39841 .76448 m .40025 .76616 L .40139 .7642 L F
.39841 .76448 m .3983 .76659 L .40025 .76616 L F
.612 .297 .413 r
.40025 .76616 m .40349 .764 L .40139 .7642 L F
.984 .755 .513 r
.55408 .82961 m .55455 .83167 L .55516 .82996 L F
0 0 .006 r
.55961 .80548 m .55861 .80643 L .55962 .80429 L F
0 0 0 r
.7035 .70437 m .70511 .70322 L .70559 .70271 L F
.411 .573 .903 r
.7035 .70437 m .70656 .7056 L .70511 .70322 L F
.887 .551 .406 r
.659 .73422 m .65701 .7344 L .65809 .73285 L F
0 0 0 r
.66044 .73038 m .65809 .73285 L .65936 .73183 L F
.752 .63 .725 r
.65701 .7344 m .65936 .73183 L .65809 .73285 L F
.792 .662 .719 r
.66441 .73787 m .66103 .73953 L .66179 .73794 L F
.66441 .73787 m .66294 .74103 L .66103 .73953 L F
.526 0 0 r
.47704 .87135 m .47826 .87165 L .47638 .87034 L F
.656 .628 .81 r
.68894 .73562 m .68732 .73235 L .68825 .73511 L F
.68894 .73562 m .69106 .73337 L .68732 .73235 L F
.804 .983 .894 r
.69256 .73197 m .69106 .73337 L .68894 .73562 L F
.717 .66 .792 r
.68894 .73562 m .69305 .733 L .69256 .73197 L F
.689 .519 .651 r
.5488 .79861 m .5466 .80114 L .54862 .80093 L F
.605 .442 .634 r
.40823 .75919 m .41084 .75892 L .41044 .75627 L F
.612 .379 .54 r
.40823 .75919 m .41066 .76058 L .41084 .75892 L F
.40823 .75919 m .40815 .76143 L .41066 .76058 L F
.671 .21 .149 r
.57406 .83444 m .5753 .83305 L .57428 .8321 L F
.57406 .83444 m .57744 .83491 L .5753 .83305 L F
.63 .485 .666 r
.42809 .86195 m .43068 .86179 L .43008 .85904 L F
.645 .483 .649 r
.42809 .86195 m .43087 .86421 L .43068 .86179 L F
.42809 .86195 m .42847 .86452 L .43087 .86421 L F
.245 .347 .771 r
.69156 .73784 m .69374 .73969 L .69253 .74078 L F
.372 .567 .913 r
.69374 .73969 m .69409 .74123 L .69253 .74078 L F
.613 .282 .385 r
.57058 .81632 m .57367 .81566 L .5717 .81528 L F
.994 .766 .479 r
.57878 .78572 m .57776 .78718 L .57783 .78479 L F
.436 0 0 r
.5816 .78693 m .57776 .78718 L .57878 .78572 L F
.933 .686 .54 r
.54226 .79804 m .54355 .80097 L .54375 .79855 L F
.771 .53 .57 r
.54375 .79855 m .54355 .80097 L .5466 .80114 L F
.626 .445 .617 r
.43008 .85904 m .43289 .85931 L .43236 .85665 L F
.675 .476 .61 r
.43236 .85665 m .4351 .8589 L .43492 .85648 L F
.43236 .85665 m .43289 .85931 L .4351 .8589 L F
.602 .476 .681 r
.53347 .86928 m .53168 .87275 L .53178 .87033 L F
.53347 .86928 m .53404 .87187 L .53168 .87275 L F
.353 0 .193 r
.53168 .87275 m .53368 .87258 L .53155 .8745 L F
.53168 .87275 m .53404 .87187 L .53368 .87258 L F
.632 .59 .789 r
.50848 .85655 m .51171 .85661 L .5094 .85716 L F
0 .567 .713 r
.43037 .75033 m .43404 .75043 L .43028 .75033 L F
.207 0 0 r
.43037 .75033 m .43226 .75058 L .43404 .75043 L F
.2 .729 .804 r
.43226 .75058 m .43611 .7502 L .43404 .75043 L F
.477 .353 .633 r
.62222 .74607 m .62386 .74561 L .62427 .7428 L F
.396 .277 .599 r
.62263 .74834 m .62386 .74561 L .62222 .74607 L F
.764 .537 .59 r
.59939 .79313 m .59614 .79061 L .59982 .7907 L F
.359 0 0 r
.66754 .75895 m .66905 .75934 L .67187 .76054 L F
.738 .743 .856 r
.43034 .88571 m .43348 .8861 L .43237 .88488 L F
.632 .714 .906 r
.43348 .8861 m .4346 .88425 L .43237 .88488 L F
.43348 .8861 m .43571 .88562 L .4346 .88425 L F
.876 .703 .665 r
.46227 .86097 m .46109 .86428 L .46186 .86174 L F
.794 .582 .614 r
.52547 .83489 m .52881 .83509 L .52878 .83294 L F
0 .159 .688 r
.55549 .81707 m .55598 .81697 L .55505 .81571 L F
.55549 .81707 m .55779 .81874 L .55598 .81697 L F
.028 .462 .876 r
.7203 .72945 m .71734 .72867 L .71642 .7283 L F
.7203 .72945 m .72001 .72983 L .71734 .72867 L F
.732 .668 .787 r
.71107 .73807 m .70833 .74055 L .7078 .73745 L F
.773 .729 .813 r
.62622 .77965 m .62684 .78216 L .62764 .78053 L F
.62622 .77965 m .62418 .78219 L .62684 .78216 L F
.935 .589 .349 r
.56381 .83996 m .56456 .84212 L .56325 .84163 L F
.56381 .83996 m .56456 .84212 L .56325 .84163 L F
0 0 0 r
.56381 .83996 m .56325 .84163 L .56379 .84008 L F
.56381 .83996 m .56379 .84008 L .564 .83946 L F
.944 .583 .271 r
.56224 .83749 m .56384 .8398 L .56381 .83996 L F
.56384 .8398 m .56406 .84012 L .56381 .83996 L F
.721 .334 0 r
.56381 .83996 m .56406 .84012 L .56529 .84284 L F
.737 .64 .752 r
.66294 .74103 m .66245 .74265 L .66034 .74358 L F
.625 .456 .633 r
.66539 .74279 m .66336 .7465 L .66245 .74265 L F
.667 .784 .936 r
.69486 .72698 m .69242 .72752 L .69146 .72636 L F
.51 .445 .719 r
.69521 .72991 m .69242 .72752 L .69486 .72698 L F
.552 .183 .294 r
.41692 .8768 m .41906 .87698 L .42022 .87516 L F
.722 .381 .4 r
.41906 .87698 m .42232 .87713 L .42022 .87516 L F
.652 .406 .534 r
.42022 .87516 m .42232 .87713 L .42264 .87478 L F
.597 .457 .662 r
.41044 .75627 m .41301 .75647 L .41206 .75322 L F
.617 .45 .633 r
.41044 .75627 m .41302 .75858 L .41301 .75647 L F
.41044 .75627 m .41084 .75892 L .41302 .75858 L F
.084 .632 .833 r
.68675 .70343 m .68938 .70356 L .68994 .70376 L F
.68994 .70376 m .68938 .70356 L .68675 .70343 L F
.766 .996 .846 r
.68994 .70376 m .69081 .70235 L .69192 .70337 L F
.68994 .70376 m .68938 .70356 L .69081 .70235 L F
.68994 .70376 m .69081 .70235 L .69192 .70337 L F
.68994 .70376 m .68938 .70356 L .69081 .70235 L F
.561 .463 .7 r
.69027 .70608 m .69192 .70337 L .68994 .70376 L F
.084 .632 .833 r
.68675 .70343 m .68938 .70356 L .68994 .70376 L F
.519 .276 .487 r
.41346 .76948 m .41311 .77175 L .41101 .77204 L F
.554 .314 .505 r
.41556 .76925 m .41311 .77175 L .41346 .76948 L F
.486 .418 .706 r
.42467 .74863 m .42347 .74997 L .42265 .74887 L F
.42467 .74863 m .42496 .75043 L .42347 .74997 L F
.658 .408 .531 r
.59271 .77709 m .59597 .77701 L .59578 .77468 L F
.671 .459 .589 r
.59597 .77701 m .59811 .77464 L .59578 .77468 L F
.726 .758 .878 r
.49985 .8733 m .49787 .87421 L .49931 .87249 L F
.49985 .8733 m .49931 .87249 L .49891 .87311 L F
.247 .549 .928 r
.49985 .8733 m .49891 .87311 L .49863 .87251 L F
.92 .809 .721 r
.49779 .8709 m .49896 .87234 L .49847 .87319 L F
.49785 .87338 m .49847 .87319 L .49787 .87421 L F
.49779 .8709 m .49847 .87319 L .49785 .87338 L F
.49779 .8709 m .49787 .87421 L .49475 .87413 L F
.751 .824 .909 r
.49475 .87413 m .49787 .87421 L .49824 .87336 L F
.076 0 0 r
.49595 .87401 m .49824 .87336 L .49574 .87427 L F
.49719 .87359 m .49824 .87336 L .49527 .8742 L F
.726 .758 .878 r
.49985 .8733 m .50117 .87445 L .49787 .87421 L F
.49787 .87421 m .50117 .87445 L .49985 .8733 L F
.337 0 .16 r
.49787 .87421 m .49985 .8733 L .49874 .87575 L F
.49787 .87421 m .49874 .87575 L .49824 .87336 L F
.791 .377 .266 r
.49574 .87427 m .49824 .87336 L .49874 .87575 L F
.49574 .87427 m .49874 .87575 L .49787 .87315 L F
.668 .655 .829 r
.49574 .87427 m .49874 .87575 L .49787 .87315 L F
.85 .805 .806 r
.4967 .87409 m .49665 .87387 L .49828 .8746 L F
.076 0 0 r
.49475 .87413 m .49719 .87359 L .49527 .8742 L F
0 0 0 r
.49662 .87388 m .49627 .874 L .49787 .87315 L F
.766 .653 .737 r
.49366 .87104 m .49779 .8709 L .49475 .87413 L F
.076 0 0 r
.49475 .87413 m .49574 .87427 L .4935 .87585 L F
.443 .835 .62 r
.49432 .87521 m .4935 .87585 L .49574 .87427 L F
.052 0 0 r
.49432 .87521 m .49574 .87427 L .4967 .87409 L F
0 0 0 r
.49432 .87521 m .49787 .87315 L .4967 .87409 L F
.85 .805 .806 r
.4967 .87409 m .49787 .87315 L .49636 .87229 L F
.49665 .87387 m .49636 .87229 L .49745 .8736 L F
.49665 .87387 m .49745 .8736 L .49828 .8746 L F
0 0 0 r
.49557 .87448 m .49574 .87427 L .49627 .874 L F
.49557 .87448 m .49627 .874 L .49662 .87388 L F
.49432 .87521 m .49574 .87427 L .49557 .87448 L F
.076 0 0 r
.49527 .8742 m .49595 .87401 L .49574 .87427 L F
.992 .814 .437 r
.49826 .87169 m .49891 .87311 L .49896 .87234 L F
.247 .549 .928 r
.49864 .87208 m .49863 .87251 L .49826 .87169 L F
.882 .954 .606 r
.49896 .87234 m .49931 .87249 L .49862 .87331 L F
.942 .784 .322 r
.49891 .87311 m .49931 .87249 L .49896 .87234 L F
.247 .549 .928 r
.49985 .8733 m .49863 .87251 L .49864 .87208 L F
.882 .954 .606 r
.49863 .87291 m .49862 .87331 L .49787 .87421 L F
.49896 .87234 m .49862 .87331 L .49863 .87291 L F
.657 .654 .836 r
.55267 .78192 m .55075 .78378 L .54986 .78058 L F
0 0 0 r
.55123 .78354 m .55075 .78378 L .55267 .78192 L F
.421 .78 .996 r
.58968 .81869 m .59128 .81928 L .58911 .81946 L F
.599 .948 .817 r
.58968 .81869 m .58911 .81946 L .58828 .81962 L F
.653 .368 .474 r
.38626 .77403 m .38859 .77432 L .38658 .77224 L F
.63 .37 .506 r
.38658 .77224 m .38859 .77432 L .38893 .77225 L F
.985 .724 .446 r
.56111 .82225 m .56027 .82436 L .56033 .82152 L F
.56111 .82225 m .56122 .82507 L .56027 .82436 L F
0 0 0 r
.46623 .83546 m .46727 .83479 L .46852 .83292 L F
.316 0 .108 r
.46852 .83292 m .46925 .83433 L .47001 .83207 L F
.46852 .83292 m .46727 .83479 L .46925 .83433 L F
.581 .425 .634 r
.51386 .83214 m .51168 .83014 L .51478 .82993 L F
.62 .349 .484 r
.51652 .83154 m .51386 .83214 L .51478 .82993 L F
.692 .322 .341 r
.51709 .83055 m .51652 .83154 L .51478 .82993 L F
.452 .878 .917 r
.50846 .85348 m .50525 .85093 L .50737 .85116 L F
.50846 .85348 m .50691 .85353 L .50525 .85093 L F
.50691 .85353 m .50846 .85348 L .50785 .85478 L F
.094 .276 .758 r
.50968 .85321 m .50846 .85348 L .50737 .85116 L F
0 0 0 r
.50785 .85478 m .50846 .85348 L .50968 .85321 L F
.992 .872 .603 r
.66097 .72215 m .66026 .72463 L .65968 .72365 L F
.758 .436 0 r
.66097 .72215 m .66079 .72193 L .65995 .71928 L F
.81 .941 .583 r
.66097 .72215 m .65968 .72365 L .66079 .72193 L F
.56 .732 .955 r
.52006 .84425 m .5226 .84404 L .52119 .84263 L F
.35 0 0 r
.37092 .75061 m .36929 .75198 L .36791 .75136 L F
.345 0 0 r
.37304 .75035 m .36929 .75198 L .37092 .75061 L F
.839 .856 .856 r
.45978 .88412 m .45932 .88254 L .4581 .88335 L F
.322 .75 .972 r
.53347 .84424 m .53523 .84344 L .53284 .84339 L F
.53347 .84424 m .53652 .84424 L .53523 .84344 L F
.488 .87 .669 r
.70495 .75289 m .70361 .75398 L .7054 .7527 L F
.532 .923 .848 r
.70284 .75403 m .70361 .75398 L .70495 .75289 L F
.706 .759 .893 r
.66112 .75867 m .66359 .75949 L .66272 .75824 L F
.826 .987 .873 r
.66065 .76125 m .66359 .75949 L .66112 .75867 L F
.515 .674 .936 r
.66272 .75824 m .66359 .75949 L .66571 .75923 L F
.874 .578 .483 r
.66271 .72692 m .66102 .72681 L .66026 .72463 L F
.925 .936 .791 r
.66271 .72692 m .65985 .72942 L .66102 .72681 L F
.66127 .72911 m .66044 .73038 L .65985 .72942 L F
.515 .38 .635 r
.65936 .73183 m .65985 .72942 L .66044 .73038 L F
.031 .218 .722 r
.65985 .72942 m .66095 .73079 L .66157 .73047 L F
.66095 .73079 m .66142 .73137 L .66157 .73047 L F
.276 .744 .944 r
.66157 .73047 m .66252 .73026 L .66205 .73022 L F
.515 .38 .635 r
.65936 .73183 m .66142 .73137 L .65985 .72942 L F
.031 .218 .722 r
.65985 .72942 m .66157 .73047 L .65874 .72967 L F
.276 .744 .944 r
.66157 .73047 m .66205 .73022 L .6593 .72994 L F
.031 .218 .722 r
.65985 .72942 m .65874 .72967 L .65785 .72942 L F
.925 .936 .791 r
.66271 .72692 m .66127 .72911 L .65985 .72942 L F
.841 .849 .85 r
.69578 .70595 m .6988 .70462 L .69758 .70333 L F
.77 .75 .835 r
.69758 .70333 m .6988 .70462 L .70072 .70348 L F
.768 .805 .883 r
.50517 .86323 m .50442 .8616 L .50465 .86326 L F
.50517 .86323 m .50772 .86181 L .50442 .8616 L F
.673 .227 .182 r
.46206 .83616 m .46469 .83681 L .46623 .83546 L F
.573 .309 .478 r
.46469 .83681 m .46727 .83479 L .46623 .83546 L F
.654 .486 .643 r
.60789 .7693 m .61085 .76933 L .61008 .76676 L F
.636 .461 .629 r
.61008 .76676 m .61297 .76688 L .61282 .76441 L F
.652 .498 .661 r
.61085 .76933 m .61297 .76688 L .61008 .76676 L F
.21 0 0 r
.51233 .88324 m .51294 .88393 L .51086 .88438 L F
.51233 .88324 m .51444 .88302 L .51294 .88393 L F
.695 .569 .709 r
.66294 .74103 m .65946 .74008 L .66103 .73953 L F
.66294 .74103 m .66034 .74358 L .65946 .74008 L F
.67 .511 .661 r
.43008 .85904 m .43301 .86156 L .43289 .85931 L F
.43008 .85904 m .43068 .86179 L .43301 .86156 L F
.46 .06 .192 r
.50866 .83258 m .51168 .83014 L .50885 .82986 L F
.50866 .83258 m .51058 .83223 L .51168 .83014 L F
.211 0 .309 r
.51168 .83014 m .5132 .82988 L .51366 .82768 L F
.581 .425 .634 r
.51386 .83214 m .51163 .83256 L .51168 .83014 L F
.147 0 .038 r
.51168 .83014 m .5123 .8314 L .5132 .82988 L F
.51168 .83014 m .51067 .83206 L .5123 .8314 L F
.797 .431 .364 r
.50885 .82986 m .51058 .83223 L .51168 .83014 L F
.299 0 .13 r
.5132 .82988 m .5123 .8314 L .51425 .83086 L F
.317 0 0 r
.51102 .83047 m .51378 .83081 L .5123 .8314 L F
.51378 .83081 m .51425 .83086 L .5123 .8314 L F
.147 0 .038 r
.51067 .83206 m .51058 .83223 L .5123 .8314 L F
.386 .661 .967 r
.54758 .78446 m .54888 .78572 L .54966 .7847 L F
.54758 .78446 m .54888 .78572 L .54966 .7847 L F
0 0 0 r
.48383 .8665 m .48077 .86917 L .48304 .8666 L F
.937 .963 .678 r
.48383 .8665 m .48463 .86354 L .48612 .86439 L F
.48383 .8665 m .48304 .8666 L .48463 .86354 L F
.232 .618 .955 r
.48651 .86736 m .48383 .8665 L .48612 .86439 L F
.902 .788 .726 r
.62293 .78779 m .62216 .78505 L .6217 .78678 L F
.847 .721 .725 r
.6198 .78978 m .62293 .78779 L .6217 .78678 L F
.6198 .78978 m .62138 .79079 L .62293 .78779 L F
.57 .627 .869 r
.64045 .73502 m .63974 .73788 L .63848 .73504 L F
.64045 .73502 m .64188 .73756 L .63974 .73788 L F
.662 .621 .797 r
.64322 .73886 m .63974 .73788 L .64188 .73756 L F
.746 .63 .732 r
.64066 .73206 m .63992 .72892 L .64077 .73012 L F
.516 .823 1 r
.64182 .72892 m .64077 .73012 L .63992 .72892 L F
.64182 .72892 m .64303 .7297 L .64077 .73012 L F
.637 .429 .584 r
.64303 .7297 m .64066 .73206 L .64077 .73012 L F
.589 .649 .877 r
.6562 .76235 m .65728 .76054 L .65515 .76101 L F
.6562 .76235 m .65839 .76201 L .65728 .76054 L F
.6 .444 .642 r
.44514 .84035 m .44715 .83754 L .44474 .83792 L F
.519 .314 .542 r
.53776 .83774 m .53805 .84167 L .53485 .83995 L F
.427 0 .023 r
.57339 .77537 m .57561 .77602 L .57653 .77458 L F
.632 .181 .162 r
.57561 .77602 m .5787 .77508 L .57653 .77458 L F
.836 .688 .699 r
.60095 .79619 m .6004 .79836 L .59918 .79548 L F
.588 .408 .605 r
.43448 .85373 m .43678 .85398 L .43656 .85126 L F
.542 .416 .658 r
.43492 .85648 m .43678 .85398 L .43448 .85373 L F
.462 .874 .946 r
.3302 .69518 m .33011 .69521 L .32868 .69582 L F
.231 0 .316 r
.32868 .69582 m .33011 .69521 L .32811 .69786 L F
.68 .709 .869 r
.58212 .81349 m .58247 .81471 L .579 .81459 L F
.805 .639 .676 r
.58247 .81471 m .57923 .81651 L .579 .81459 L F
.58247 .81471 m .58183 .81695 L .57923 .81651 L F
.607 .781 .964 r
.58396 .8132 m .58247 .81471 L .58212 .81349 L F
.58396 .8132 m .58448 .81423 L .58247 .81471 L F
.711 .779 .906 r
.69973 .70069 m .70288 .70097 L .70118 .70163 L F
.653 .522 .692 r
.70118 .70163 m .70072 .70348 L .70288 .70097 L F
.786 .708 .778 r
.69758 .70333 m .70072 .70348 L .69973 .70069 L F
.765 .698 .788 r
.69973 .70069 m .70072 .70348 L .70288 .70097 L F
.846 .809 .815 r
.47094 .8699 m .46779 .87139 L .46986 .87014 L F
.512 .555 .836 r
.46985 .86699 m .47094 .8699 L .473 .8691 L F
.224 .685 .947 r
.47251 .86953 m .47094 .8699 L .46986 .87014 L F
.47251 .86953 m .47309 .87005 L .47094 .8699 L F
.77 .554 .605 r
.53705 .8113 m .54029 .81393 L .54016 .81226 L F
.542 .374 .603 r
.43656 .85126 m .43861 .85295 L .4392 .85093 L F
.43656 .85126 m .43678 .85398 L .43861 .85295 L F
.595 .441 .644 r
.61282 .76441 m .61512 .76417 L .61475 .76152 L F
.621 .467 .652 r
.61297 .76688 m .61512 .76417 L .61282 .76441 L F
.701 .69 .837 r
.65269 .73573 m .65384 .73842 L .65049 .73785 L F
.741 .71 .822 r
.65594 .73761 m .65384 .73842 L .65269 .73573 L F
.465 .273 .535 r
.62397 .74046 m .62577 .73794 L .6236 .73835 L F
.62397 .74046 m .626 .74011 L .62577 .73794 L F
.341 .165 .491 r
.62427 .7428 m .626 .74011 L .62397 .74046 L F
.554 .36 .573 r
.43471 .75329 m .43451 .75543 L .43241 .75557 L F
.571 .354 .547 r
.43436 .75831 m .43241 .75557 L .43451 .75543 L F
.43436 .75831 m .43209 .75883 L .43241 .75557 L F
.417 .037 .208 r
.34382 .73235 m .34591 .732 L .34711 .72998 L F
.345 0 .167 r
.34711 .72998 m .34781 .73153 L .34911 .7296 L F
.34711 .72998 m .34591 .732 L .34781 .73153 L F
.672 .534 .689 r
.58251 .82126 m .58492 .82256 L .58479 .81856 L F
.58492 .82256 m .58504 .82255 L .58479 .81856 L F
.58505 .82262 m .58552 .82255 L .58479 .81856 L F
.667 .646 .82 r
.58427 .82279 m .58551 .82255 L .58449 .82257 L F
.58551 .82255 m .58561 .82253 L .58552 .82254 L F
.58551 .82255 m .58552 .82254 L .58449 .82257 L F
.664 .167 .057 r
.58712 .82004 m .58479 .81856 L .58552 .82254 L F
.667 .646 .82 r
.58514 .82248 m .58805 .82206 L .58781 .82153 L F
.58514 .82248 m .58781 .82153 L .58712 .82004 L F
.58561 .82253 m .58805 .82206 L .58449 .82257 L F
.609 .934 .959 r
.58727 .82321 m .588 .82214 L .5854 .82259 L F
.58475 .82286 m .5854 .82259 L .58427 .82279 L F
.58727 .82321 m .5854 .82259 L .58475 .82286 L F
.664 .167 .057 r
.58712 .82004 m .58552 .82254 L .58552 .82255 L F
.58585 .82241 m .58552 .82255 L .58558 .82291 L F
.58712 .82004 m .58552 .82255 L .58585 .82241 L F
.617 .551 .758 r
.58492 .82256 m .58427 .82279 L .58558 .82291 L F
.58251 .82126 m .58427 .82279 L .58492 .82256 L F
.667 .646 .82 r
.58449 .82257 m .58514 .82248 L .58712 .82004 L F
.672 .534 .689 r
.58492 .82256 m .58505 .82262 L .58504 .82255 L F
.58505 .82262 m .58558 .82291 L .58552 .82255 L F
.609 .934 .959 r
.588 .82214 m .58805 .82206 L .58561 .82253 L F
.588 .82214 m .58561 .82253 L .58427 .82279 L F
.58727 .82321 m .58912 .82228 L .58805 .82206 L F
0 0 .478 r
.56249 .82801 m .56341 .82989 L .56229 .82693 L F
.726 .612 .729 r
.42239 .87257 m .42264 .87478 L .42475 .87231 L F
.589 .412 .61 r
.42264 .87478 m .42475 .87475 L .42475 .87231 L F
.622 .403 .564 r
.42232 .87713 m .42475 .87475 L .42264 .87478 L F
.423 .05 .224 r
.66885 .70693 m .67106 .70551 L .66837 .70604 L F
.476 .537 .84 r
.70755 .7085 m .70798 .70531 L .70656 .7056 L F
.70755 .7085 m .70952 .70849 L .70798 .70531 L F
.407 .724 .989 r
.50179 .8424 m .50086 .8433 L .49984 .84243 L F
.504 0 0 r
.50086 .8433 m .50486 .84614 L .50467 .84586 L F
.226 .428 .85 r
.50179 .8424 m .50486 .84614 L .50086 .8433 L F
.741 .71 .822 r
.65594 .73761 m .65269 .73573 L .65477 .7349 L F
.807 .747 .797 r
.659 .73422 m .65594 .73761 L .65477 .7349 L F
.668 .153 .004 r
.46127 .88266 m .46211 .88308 L .45932 .88254 L F
.393 .52 .866 r
.39945 .72675 m .39928 .72915 L .39767 .72749 L F
.39945 .72675 m .40094 .72936 L .39928 .72915 L F
.831 .772 .796 r
.62622 .77965 m .62764 .78053 L .62964 .77784 L F
.467 .09 .24 r
.54309 .8352 m .54235 .83712 L .53983 .83747 L F
.6 .22 .295 r
.54443 .83648 m .54309 .8352 L .54493 .835 L F
.54443 .83648 m .54235 .83712 L .54309 .8352 L F
.082 .201 .69 r
.54309 .8352 m .54443 .83648 L .54493 .835 L F
.306 .382 .776 r
.53588 .81445 m .5382 .81687 L .53704 .81367 L F
.559 .438 .671 r
.53588 .81445 m .53644 .81732 L .5382 .81687 L F
0 0 0 r
.53704 .81367 m .53526 .81573 L .53588 .81445 L F
.814 .867 .886 r
.42234 .88738 m .42337 .88472 L .42183 .88602 L F
.42234 .88738 m .42476 .88539 L .42337 .88472 L F
.959 .943 .704 r
.67944 .75835 m .68139 .75601 L .68037 .75542 L F
.67944 .75835 m .68003 .75902 L .68139 .75601 L F
.807 .747 .797 r
.659 .73422 m .65477 .7349 L .65701 .7344 L F
.472 .266 .519 r
.56384 .7955 m .56171 .79817 L .56191 .796 L F
.56384 .7955 m .56171 .79817 L .56191 .796 L F
.628 .472 .651 r
.43865 .84843 m .44117 .84858 L .44086 .84581 L F
.639 .489 .663 r
.4392 .85093 m .44117 .84858 L .43865 .84843 L F
.671 .154 0 r
.52145 .82427 m .52267 .82494 L .52412 .82503 L F
.826 .436 .312 r
.52267 .82494 m .52328 .82652 L .52412 .82503 L F
.581 .446 .662 r
.52662 .82725 m .52412 .82503 L .52649 .8246 L F
.52662 .82725 m .52459 .82787 L .5244 .82669 L F
.52516 .82596 m .5244 .82669 L .52412 .82503 L F
.52662 .82725 m .5244 .82669 L .52516 .82596 L F
0 0 0 r
.52649 .8246 m .52788 .82433 L .52842 .82457 L F
.659 .489 .644 r
.52959 .82654 m .52649 .8246 L .52842 .82457 L F
.52959 .82654 m .52662 .82725 L .52649 .8246 L F
0 0 0 r
.5266 .82458 m .52552 .82674 L .52788 .82433 L F
.52649 .8246 m .52642 .82475 L .5266 .82458 L F
.52642 .82475 m .52552 .82674 L .5266 .82458 L F
.549 .166 .269 r
.52328 .82652 m .52649 .8246 L .52412 .82503 L F
.4 .092 .324 r
.33211 .69458 m .3302 .69518 L .33069 .69358 L F
.889 .728 .677 r
.47256 .866 m .473 .8691 L .47413 .86655 L F
.47256 .866 m .47413 .86655 L .47515 .86427 L F
.47256 .866 m .47515 .86427 L .47435 .8658 L F
.683 .845 .961 r
.47256 .866 m .47435 .8658 L .47203 .86582 L F
.47256 .866 m .47203 .86582 L .47071 .86584 L F
.392 .13 .393 r
.47688 .86347 m .47728 .86388 L .47515 .86427 L F
.489 .19 .385 r
.47728 .86388 m .47435 .8658 L .47515 .86427 L F
.52 .858 .995 r
.38276 .74773 m .38073 .74826 L .38392 .74819 L F
.256 .767 .828 r
.59274 .84735 m .59515 .84702 L .5938 .84699 L F
0 0 0 r
.59515 .84702 m .59571 .84699 L .5938 .84699 L F
.59515 .84702 m .59744 .84625 L .59571 .84699 L F
.925 .778 .68 r
.61546 .80922 m .61561 .80589 L .61399 .80886 L F
.899 .762 .701 r
.61366 .81113 m .61546 .80922 L .61399 .80886 L F
.831 .772 .796 r
.62622 .77965 m .62964 .77784 L .62829 .77672 L F
.834 .763 .784 r
.57945 .81232 m .579 .81459 L .57636 .81379 L F
.765 .464 .477 r
.579 .81459 m .57598 .81621 L .57636 .81379 L F
.579 .81459 m .57923 .81651 L .57598 .81621 L F
.68 .709 .869 r
.58212 .81349 m .579 .81459 L .57945 .81232 L F
.534 .532 .799 r
.47015 .85843 m .46999 .85568 L .47136 .85675 L F
.627 .472 .652 r
.42475 .87231 m .42724 .87222 L .42688 .8696 L F
.643 .47 .633 r
.42475 .87475 m .42724 .87222 L .42475 .87231 L F
.449 .785 .998 r
.55961 .80548 m .56099 .80619 L .55861 .80643 L F
.782 .677 .748 r
.48262 .87488 m .48078 .87759 L .48015 .87514 L F
.878 .599 .512 r
.36331 .75317 m .36255 .75375 L .36117 .75089 L F
.493 .044 .112 r
.36548 .75311 m .36255 .75375 L .36331 .75317 L F
.215 .231 .661 r
.51376 .87498 m .51384 .87839 L .5131 .8749 L F
0 0 .21 r
.5131 .8749 m .51384 .87839 L .51356 .87646 L F
.5131 .8749 m .51356 .87646 L .5117 .87454 L F
.401 .807 .593 r
.59868 .84515 m .60195 .84296 L .60155 .84342 L F
0 0 0 r
.60195 .84296 m .60461 .84081 L .60316 .84219 L F
.60155 .84342 m .60195 .84296 L .60316 .84219 L F
.524 .888 .674 r
.36634 .75228 m .36548 .75311 L .36791 .75136 L F
.018 0 0 r
.36862 .75168 m .36791 .75136 L .36929 .75198 L F
.36862 .75168 m .36634 .75228 L .36791 .75136 L F
.792 .961 .919 r
.35365 .75304 m .35721 .7516 L .35568 .75281 L F
.238 0 0 r
.35721 .7516 m .35766 .75249 L .35568 .75281 L F
.35721 .7516 m .3593 .75128 L .35766 .75249 L F
.503 .216 .411 r
.42536 .7618 m .42502 .7633 L .42295 .76365 L F
.503 .223 .422 r
.42744 .76145 m .42502 .7633 L .42536 .7618 L F
.733 .979 .916 r
.52065 .87716 m .51997 .87838 L .51854 .87767 L F
.52065 .87716 m .52189 .87718 L .51997 .87838 L F
.171 .379 .826 r
.52219 .88029 m .51997 .87838 L .52189 .87718 L F
.402 .059 .265 r
.36231 .80387 m .36533 .8011 L .36417 .80339 L F
.411 .048 .235 r
.36533 .8011 m .36613 .803 L .36417 .80339 L F
.36533 .8011 m .3673 .80075 L .36613 .803 L F
.607 .456 .651 r
.42688 .8696 m .42891 .86689 L .42659 .86724 L F
.625 .428 .596 r
.56594 .79052 m .56831 .79035 L .56837 .78801 L F
.56594 .79052 m .56831 .79035 L .56837 .78801 L F
.544 .363 .587 r
.57054 .78535 m .56837 .78801 L .57015 .78759 L F
.572 .385 .589 r
.57088 .78984 m .56837 .78801 L .57015 .78759 L F
.57088 .78984 m .56831 .79035 L .56837 .78801 L F
0 0 .274 r
.56837 .78801 m .5691 .7892 L .57015 .78759 L F
.56837 .78801 m .56831 .79035 L .5691 .7892 L F
.544 .363 .587 r
.57054 .78535 m .56837 .78801 L .57015 .78759 L F
.195 0 0 r
.51984 .85103 m .52194 .85128 L .52047 .85102 L F
.94 .57 .22 r
.52047 .85102 m .52079 .8521 L .51984 .85103 L F
.948 .957 .683 r
.6613 .71637 m .66176 .71392 L .66265 .71462 L F
.457 .86 .966 r
.56991 .84585 m .57251 .84524 L .57099 .84501 L F
.476 .893 .904 r
.56901 .84578 m .56991 .84585 L .57099 .84501 L F
.943 .958 .734 r
.63966 .72035 m .64065 .71904 L .63984 .7182 L F
.52 .311 .537 r
.39642 .7801 m .39621 .78229 L .3942 .78266 L F
.515 .308 .536 r
.39815 .78188 m .39642 .7801 L .39843 .77974 L F
.39815 .78188 m .39621 .78229 L .39642 .7801 L F
.589 .111 .088 r
.5021 .83612 m .50062 .83718 L .49799 .83692 L F
.353 0 0 r
.50357 .83618 m .50338 .83572 L .50421 .83545 L F
.50289 .83696 m .5021 .83612 L .50338 .83572 L F
.50289 .83696 m .50338 .83572 L .50357 .83618 L F
.752 .54 .608 r
.50294 .83423 m .50289 .83696 L .50421 .83545 L F
.50294 .83423 m .50421 .83545 L .50586 .83442 L F
.50294 .83423 m .50575 .83664 L .50289 .83696 L F
.371 .03 .251 r
.50575 .83664 m .50295 .83899 L .50289 .83696 L F
.752 .54 .608 r
.50294 .83423 m .50403 .83742 L .50575 .83664 L F
0 0 .264 r
.5036 .83595 m .50391 .83703 L .50294 .83423 L F
.50391 .83703 m .50403 .83742 L .50379 .83673 L F
.50391 .83703 m .50379 .83673 L .50294 .83423 L F
.353 0 0 r
.50289 .83696 m .50062 .83718 L .5021 .83612 L F
.669 .566 .73 r
.41206 .75322 m .41483 .75341 L .41439 .75072 L F
.609 .465 .66 r
.41206 .75322 m .41507 .75611 L .41483 .75341 L F
.41206 .75322 m .41301 .75647 L .41507 .75611 L F
.491 .19 .382 r
.34426 .75644 m .34161 .75862 L .34211 .75764 L F
.402 .114 .356 r
.3816 .77663 m .38344 .77693 L .38417 .77453 L F
.45 .173 .4 r
.3816 .77663 m .38302 .77893 L .38344 .77693 L F
.3816 .77663 m .38107 .77937 L .38302 .77893 L F
.465 .706 .973 r
.45183 .88204 m .45276 .88101 L .45027 .88058 L F
.45183 .88204 m .45365 .88184 L .45276 .88101 L F
.781 .454 .434 r
.58754 .78791 m .58628 .78989 L .58458 .78738 L F
.762 .429 .422 r
.58754 .78791 m .5895 .79023 L .58628 .78989 L F
.682 .435 .542 r
.49424 .84247 m .49125 .84028 L .49394 .8388 L F
.246 0 .054 r
.49636 .83777 m .49516 .83961 L .49394 .8388 L F
.701 .673 .819 r
.49516 .83961 m .49424 .84247 L .49397 .83921 L F
.49516 .83961 m .49604 .84289 L .49424 .84247 L F
.697 .67 .82 r
.49843 .84024 m .49604 .84289 L .49516 .83961 L F
.552 .073 .073 r
.49338 .83982 m .49566 .83979 L .49516 .83961 L F
.697 .67 .82 r
.49843 .84024 m .49516 .83961 L .49719 .83976 L F
.552 .073 .073 r
.49566 .83979 m .49719 .83976 L .49516 .83961 L F
.701 .673 .819 r
.49516 .83961 m .49397 .83921 L .49394 .8388 L F
.492 .151 .315 r
.40627 .77515 m .40775 .77648 L .40563 .77672 L F
.476 .154 .34 r
.40833 .77484 m .40775 .77648 L .40627 .77515 L F
.929 .944 .599 r
.57318 .83104 m .57411 .82868 L .57402 .82975 L F
.634 .479 .656 r
.57402 .82975 m .5719 .83241 L .57318 .83104 L F
.57402 .82975 m .57428 .8321 L .5719 .83241 L F
.519 .395 .652 r
.57393 .83093 m .57402 .82975 L .57346 .8294 L F
.57428 .8321 m .57402 .82975 L .57393 .83093 L F
.929 .944 .599 r
.57411 .82868 m .57454 .82757 L .57402 .82975 L F
.517 .344 .586 r
.62062 .75106 m .62267 .75066 L .62263 .74834 L F
.511 .347 .595 r
.62076 .75333 m .62267 .75066 L .62062 .75106 L F
.373 .067 .312 r
.37729 .78037 m .3785 .78143 L .37928 .77992 L F
.37729 .78037 m .37665 .78201 L .3785 .78143 L F
.916 .706 .604 r
.61659 .80035 m .61807 .80133 L .61676 .79826 L F
.864 .765 .751 r
.61636 .80422 m .61807 .80133 L .61659 .80035 L F
.752 .52 .58 r
.64703 .7083 m .64695 .71109 L .64419 .71127 L F
.521 .329 .56 r
.64908 .71063 m .64703 .7083 L .64913 .70831 L F
.64908 .71063 m .64695 .71109 L .64703 .7083 L F
.495 .112 .242 r
.36593 .78728 m .3694 .78511 L .36738 .78547 L F
.604 .614 .835 r
.41411 .73557 m .41117 .73392 L .41282 .73463 L F
.511 .778 .993 r
.41282 .73463 m .4161 .73524 L .41411 .73557 L F
.544 .437 .683 r
.34014 .6776 m .34074 .6796 L .33884 .67995 L F
.341 .109 .41 r
.34024 .68117 m .33884 .67995 L .34074 .6796 L F
.34024 .68117 m .33798 .6823 L .33884 .67995 L F
.468 .186 .402 r
.38344 .77693 m .38626 .77403 L .38417 .77453 L F
.435 .152 .383 r
.39621 .78229 m .39379 .78448 L .3942 .78266 L F
.487 .211 .42 r
.41394 .73265 m .41117 .73392 L .41082 .73279 L F
.41394 .73265 m .41282 .73463 L .41117 .73392 L F
.53 .319 .539 r
.62577 .73794 m .626 .74011 L .6279 .73823 L F
.864 .962 .629 r
.5636 .83443 m .56339 .83578 L .56224 .83749 L F
.651 .49 .653 r
.60567 .77212 m .60853 .772 L .60789 .7693 L F
.584 .393 .589 r
.60853 .772 m .61085 .76933 L .60789 .7693 L F
.714 .497 .594 r
.59614 .79061 m .59411 .79263 L .59273 .79044 L F
.59614 .79061 m .59619 .79293 L .59411 .79263 L F
.764 .537 .59 r
.59939 .79313 m .59619 .79293 L .59614 .79061 L F
.698 .483 .593 r
.60356 .77439 m .60567 .77212 L .60353 .77216 L F
.587 .442 .65 r
.42447 .74581 m .42467 .74863 L .42265 .74887 L F
.733 .5 .575 r
.69192 .70337 m .69584 .70377 L .69556 .70199 L F
.644 .438 .59 r
.69556 .70199 m .69584 .70377 L .69758 .70333 L F
.705 .82 .936 r
.52547 .83489 m .52632 .83596 L .52881 .83509 L F
.549 .425 .663 r
.54528 .78308 m .54758 .78446 L .5459 .78296 L F
.826 .411 .255 r
.50933 .83282 m .50843 .83441 L .50866 .83258 L F
.50933 .83282 m .5114 .83555 L .50843 .83441 L F
.816 .42 .301 r
.51258 .8353 m .50933 .83282 L .51163 .83256 L F
.51258 .8353 m .5114 .83555 L .50933 .83282 L F
.618 .439 .617 r
.44086 .84581 m .44333 .84572 L .44347 .84339 L F
.553 .376 .596 r
.44117 .84858 m .44333 .84572 L .44086 .84581 L F
.607 .456 .651 r
.42688 .8696 m .42914 .86946 L .42891 .86689 L F
.627 .471 .652 r
.42688 .8696 m .42968 .87191 L .42914 .86946 L F
.42688 .8696 m .42724 .87222 L .42968 .87191 L F
.352 .152 .464 r
.71461 .73295 m .71565 .73332 L .71415 .73204 L F
.71461 .73295 m .71327 .73547 L .71565 .73332 L F
.656 .485 .641 r
.61475 .76152 m .61741 .76389 L .61698 .76176 L F
.61475 .76152 m .61512 .76417 L .61741 .76389 L F
.366 .153 .451 r
.51454 .85396 m .51576 .85597 L .51602 .85319 L F
.51454 .85396 m .514 .85613 L .51576 .85597 L F
0 0 0 r
.34934 .79537 m .35155 .79448 L .35016 .79469 L F
.115 0 0 r
.35016 .79469 m .35155 .79448 L .35257 .79373 L F
.797 .661 .712 r
.63839 .72174 m .63963 .72483 L .63655 .72482 L F
.617 .563 .771 r
.63848 .72577 m .63655 .72482 L .63963 .72483 L F
0 0 .574 r
.64019 .72447 m .63963 .72483 L .63839 .72174 L F
.535 .61 .874 r
.64019 .72447 m .63848 .72577 L .63963 .72483 L F
.852 .729 .727 r
.67848 .74327 m .68042 .74365 L .68222 .74302 L F
.67848 .74327 m .67974 .74577 L .68042 .74365 L F
.151 .693 .796 r
.52281 .87695 m .52189 .87718 L .52065 .87716 L F
.52281 .87695 m .52396 .87697 L .52189 .87718 L F
.376 .257 .587 r
.52344 .87902 m .52189 .87718 L .52396 .87697 L F
.52344 .87902 m .52219 .88029 L .52189 .87718 L F
.978 .808 .603 r
.59734 .80898 m .5959 .81028 L .59634 .80837 L F
.59734 .80898 m .59695 .81129 L .5959 .81028 L F
.655 .56 .736 r
.43611 .7502 m .43699 .75359 L .43471 .75329 L F
.55 .275 .451 r
.43699 .75359 m .43451 .75543 L .43471 .75329 L F
.711 .356 .373 r
.53176 .81105 m .53367 .81143 L .53512 .81076 L F
.569 .138 .182 r
.53512 .81076 m .53367 .81143 L .53705 .8113 L F
.371 0 .163 r
.51878 .83106 m .51652 .83154 L .51709 .83055 L F
.875 .904 .848 r
.67221 .70785 m .66956 .71155 L .66856 .71083 L F
.669 .722 .889 r
.40422 .73009 m .40232 .73086 L .40094 .72936 L F
0 0 .346 r
.71355 .72708 m .71331 .73032 L .71399 .72896 L F
.772 .963 .927 r
.71355 .72708 m .71556 .72462 L .7128 .72459 L F
.71355 .72708 m .71643 .72511 L .71556 .72462 L F
.287 .784 .759 r
.71399 .72896 m .71642 .7283 L .71355 .72708 L F
.518 .346 .588 r
.54198 .85754 m .54227 .85931 L .54429 .85879 L F
.54198 .85754 m .54227 .85931 L .54429 .85879 L F
.397 .018 .198 r
.3511 .72921 m .35312 .72884 L .35454 .72654 L F
.489 .125 .273 r
.35312 .72884 m .35661 .72639 L .35454 .72654 L F
.46 .621 .92 r
.33075 .67677 m .33067 .67878 L .3292 .67635 L F
.33075 .67677 m .33215 .67851 L .33067 .67878 L F
.973 .681 .285 r
.67104 .72923 m .67194 .73196 L .67135 .72983 L F
.568 .239 .371 r
.45437 .83723 m .45663 .83732 L .45777 .83496 L F
.514 .183 .343 r
.45777 .83496 m .45961 .83671 L .4598 .8347 L F
.45777 .83496 m .45663 .83732 L .45961 .83671 L F
0 0 .472 r
.50459 .84535 m .50616 .84819 L .50467 .84586 L F
0 0 .324 r
.50467 .84586 m .50486 .84614 L .50459 .84535 L F
.584 .383 .575 r
.44333 .84572 m .4455 .84312 L .44347 .84339 L F
.305 .758 .956 r
.37822 .72461 m .38031 .72448 L .38156 .72492 L F
.526 .868 .992 r
.38156 .72492 m .3824 .72389 L .38362 .72442 L F
.38156 .72492 m .38031 .72448 L .3824 .72389 L F
.963 .765 .589 r
.54355 .80097 m .54683 .80338 L .5466 .80114 L F
.679 .472 .599 r
.5466 .80114 m .54683 .80338 L .54862 .80093 L F
.46 .131 .32 r
.40815 .76143 m .40608 .76186 L .40548 .76357 L F
.514 .365 .616 r
.63789 .71659 m .64029 .71657 L .63977 .71393 L F
.625 .456 .633 r
.66539 .74279 m .66615 .74613 L .66336 .7465 L F
.633 .461 .632 r
.66726 .7449 m .66539 .74279 L .66828 .74305 L F
.66726 .7449 m .66615 .74613 L .66539 .74279 L F
.751 .752 .853 r
.40977 .73014 m .40765 .73167 L .40592 .72986 L F
.683 .597 .753 r
.40977 .73014 m .41082 .73279 L .40765 .73167 L F
.729 .543 .639 r
.47946 .85908 m .47944 .86367 L .47785 .86274 L F
.208 .124 .536 r
.48109 .86018 m .47946 .85908 L .48146 .85965 L F
.784 .319 .137 r
.48415 .85875 m .4846 .85751 L .48326 .85641 L F
.48415 .85875 m .48624 .8592 L .4846 .85751 L F
.912 .625 .485 r
.56476 .80544 m .56635 .80611 L .56614 .80382 L F
.544 .267 .445 r
.41803 .76722 m .41775 .76904 L .41556 .76925 L F
.434 .172 .415 r
.41966 .76853 m .41803 .76722 L .42051 .76594 L F
.41966 .76853 m .41775 .76904 L .41803 .76722 L F
.698 .483 .593 r
.60356 .77439 m .6058 .77445 L .60567 .77212 L F
.64 .437 .592 r
.6058 .77445 m .60853 .772 L .60567 .77212 L F
.837 .689 .698 r
.6004 .79836 m .59757 .79873 L .59918 .79548 L F
.783 .631 .693 r
.6004 .79836 m .59793 .80046 L .59875 .79857 L F
.59793 .80046 m .59708 .80118 L .59758 .8004 L F
.59793 .80046 m .59758 .8004 L .59875 .79857 L F
.6004 .79836 m .5986 .80107 L .59708 .80118 L F
.785 .668 .735 r
.59708 .80118 m .5986 .80107 L .59758 .8004 L F
.59708 .80118 m .59758 .8004 L .59597 .79934 L F
.928 .723 .605 r
.59758 .8004 m .59725 .80034 L .59597 .79934 L F
.746 .657 .761 r
.59725 .80034 m .59708 .80118 L .59597 .79934 L F
.928 .723 .605 r
.59725 .80034 m .59625 .80016 L .59597 .79934 L F
.746 .657 .761 r
.59757 .79873 m .59725 .80034 L .59597 .79934 L F
.783 .631 .693 r
.59875 .79857 m .59708 .80118 L .59757 .79873 L F
.928 .723 .605 r
.5986 .80107 m .59713 .80284 L .59625 .80016 L F
.5986 .80107 m .59625 .80016 L .59758 .8004 L F
.714 .658 .793 r
.63677 .76406 m .64012 .76443 L .63917 .76158 L F
.73 .601 .713 r
.63677 .76406 m .63812 .76716 L .64012 .76443 L F
.766 .686 .774 r
.63917 .76158 m .64012 .76443 L .6424 .76177 L F
.218 0 0 r
.39011 .74676 m .38949 .74641 L .39157 .74578 L F
.02 0 0 r
.39204 .74616 m .39011 .74676 L .39157 .74578 L F
.921 .975 .711 r
.65488 .62603 m .65588 .62485 L .65654 .6272 L F
.662 .362 .454 r
.65654 .6272 m .65318 .62891 L .65488 .62603 L F
.65654 .6272 m .65648 .62895 L .65318 .62891 L F
.2 .623 .948 r
.65604 .62409 m .65654 .6272 L .65588 .62485 L F
.65604 .62409 m .65853 .62498 L .65654 .6272 L F
.609 .318 .451 r
.65654 .6272 m .6588 .62893 L .65648 .62895 L F
.832 .838 .851 r
.58101 .82898 m .58315 .82954 L .5803 .83006 L F
.684 .144 0 r
.58504 .83123 m .58315 .82954 L .58101 .82898 L F
0 .209 .686 r
.58592 .8317 m .58315 .82954 L .58504 .83123 L F
.468 .667 .95 r
.69089 .7252 m .68941 .72631 L .68824 .72547 L F
.69089 .7252 m .69146 .72636 L .68941 .72631 L F
.946 .731 .264 r
.66968 .72191 m .66959 .72417 L .67 .72482 L F
.83 .779 .274 r
.66956 .72604 m .67 .72482 L .66959 .72417 L F
.66956 .72604 m .66949 .72732 L .67 .72482 L F
.542 .416 .658 r
.43492 .85648 m .43699 .8563 L .43678 .85398 L F
.623 .455 .635 r
.43492 .85648 m .43733 .85864 L .43699 .8563 L F
.43492 .85648 m .4351 .8589 L .43733 .85864 L F
0 0 0 r
.57015 .78759 m .57148 .78564 L .57054 .78535 L F
.665 .678 .853 r
.57148 .78564 m .57015 .78759 L .57054 .78535 L F
.943 .889 .486 r
.51356 .87646 m .51384 .87839 L .51311 .87989 L F
.6 .548 .768 r
.51596 .87698 m .51384 .87839 L .51376 .87498 L F
.265 .734 .944 r
.47325 .88311 m .47642 .88347 L .47525 .88292 L F
.315 .746 .971 r
.47642 .88347 m .47713 .88289 L .47525 .88292 L F
.47642 .88347 m .47826 .88344 L .47713 .88289 L F
.638 .389 .526 r
.48796 .85136 m .48756 .85374 L .48585 .85362 L F
.673 .422 .533 r
.4912 .85337 m .48796 .85136 L .4912 .85099 L F
.4912 .85337 m .48756 .85374 L .48796 .85136 L F
0 .149 .692 r
.67986 .74541 m .67974 .74577 L .67848 .74327 L F
.957 .745 .576 r
.67858 .74786 m .67974 .74577 L .67986 .74541 L F
.67858 .74786 m .67972 .74805 L .67974 .74577 L F
.446 .473 .794 r
.56687 .81649 m .56731 .81365 L .56557 .81597 L F
.56687 .81649 m .56883 .81739 L .56731 .81365 L F
.626 .165 .139 r
.56735 .81858 m .56687 .81649 L .56557 .81597 L F
.56735 .81858 m .56883 .81739 L .56687 .81649 L F
0 0 0 r
.48518 .88465 m .48719 .88458 L .48609 .88464 L F
.873 .811 .785 r
.61318 .80599 m .61561 .80589 L .61495 .80339 L F
.882 .757 .719 r
.61399 .80886 m .61561 .80589 L .61318 .80599 L F
.86 .805 .795 r
.61495 .80339 m .61561 .80589 L .61636 .80422 L F
.789 .399 .316 r
.45932 .88254 m .46211 .88308 L .46248 .885 L F
.741 .859 .935 r
.53852 .8435 m .54184 .84325 L .54075 .84298 L F
0 .541 .735 r
.54184 .84325 m .54255 .84327 L .54075 .84298 L F
.54184 .84325 m .54381 .84343 L .54255 .84327 L F
.6 .444 .642 r
.44514 .84035 m .44752 .84041 L .44715 .83754 L F
.514 .362 .612 r
.4455 .84312 m .44752 .84041 L .44514 .84035 L F
.441 0 .086 r
.54026 .81638 m .54341 .81477 L .54029 .81393 L F
.594 .023 0 r
.54108 .81583 m .54374 .81707 L .54241 .81641 L F
.54374 .81707 m .54512 .81772 L .54241 .81641 L F
.441 0 .086 r
.54129 .81585 m .54241 .81641 L .54341 .81477 L F
.54026 .81638 m .54241 .81641 L .54129 .81585 L F
.657 .221 .2 r
.54341 .81477 m .54241 .81641 L .5455 .81642 L F
.665 .564 .732 r
.4124 .73029 m .41394 .73265 L .41082 .73279 L F
.548 .525 .782 r
.46667 .86865 m .46571 .87122 L .46437 .86921 L F
.46667 .86865 m .46779 .87139 L .46571 .87122 L F
.282 0 .046 r
.50949 .84581 m .51024 .84698 L .51165 .84585 L F
.50949 .84581 m .50824 .84755 L .51024 .84698 L F
.49 .883 .713 r
.53272 .86956 m .53347 .86928 L .53178 .87033 L F
.701 .341 .362 r
.53432 .86786 m .53578 .86672 L .53421 .86783 L F
.758 .98 .73 r
.53527 .86728 m .53347 .86928 L .53454 .86769 L F
.53454 .86769 m .5344 .86789 L .53433 .86785 L F
.53578 .86672 m .53527 .86728 L .53454 .86769 L F
.668 .558 .721 r
.53578 .86672 m .5356 .86857 L .53347 .86928 L F
.422 .34 .659 r
.53786 .8689 m .5356 .86857 L .53578 .86672 L F
.701 .341 .362 r
.53786 .8689 m .53578 .86672 L .53432 .86786 L F
.438 .222 .488 r
.53571 .87158 m .5356 .86857 L .53786 .8689 L F
.701 .341 .362 r
.53786 .8689 m .53421 .86783 L .53777 .86825 L F
.607 .3 .423 r
.5357 .86901 m .53693 .86911 L .5376 .86813 L F
.416 .811 .986 r
.53775 .86791 m .53777 .86825 L .53546 .86776 L F
.607 .3 .423 r
.5374 .8681 m .5376 .86813 L .53775 .86791 L F
.5357 .86901 m .5376 .86813 L .5374 .8681 L F
.01 .57 .807 r
.53507 .86779 m .53777 .86825 L .53432 .86784 L F
.53546 .86776 m .53652 .86798 L .53507 .86779 L F
.53652 .86798 m .53777 .86825 L .53507 .86779 L F
.758 .98 .73 r
.53578 .86672 m .53432 .86784 L .53421 .86783 L F
.01 .57 .807 r
.53432 .86784 m .53432 .86784 L .53421 .86783 L F
.758 .98 .73 r
.53432 .86784 m .53366 .86834 L .53421 .86783 L F
.01 .57 .807 r
.53429 .86782 m .53432 .86784 L .53421 .86783 L F
.53546 .86776 m .53432 .86784 L .53429 .86782 L F
.758 .98 .73 r
.53433 .86785 m .53347 .86928 L .53365 .86838 L F
.5344 .86789 m .53347 .86928 L .53433 .86785 L F
.01 .57 .807 r
.53546 .86776 m .53429 .86782 L .53374 .86826 L F
.53429 .86782 m .53421 .86783 L .5341 .86793 L F
.488 .822 .525 r
.53374 .86826 m .53421 .86783 L .53366 .86834 L F
.01 .57 .807 r
.53429 .86782 m .5341 .86793 L .53374 .86826 L F
.758 .98 .73 r
.53578 .86672 m .53365 .86838 L .53366 .86834 L F
.764 .974 .701 r
.53366 .86834 m .53347 .86928 L .53272 .86956 L F
.347 .306 .67 r
.53571 .87158 m .53347 .86928 L .5356 .86857 L F
.53571 .87158 m .53404 .87187 L .53347 .86928 L F
.819 .344 .066 r
.54972 .8091 m .54661 .80631 L .55037 .80636 L F
.769 .597 .665 r
.54683 .80338 m .55021 .80364 L .54862 .80093 L F
.609 .118 .06 r
.54683 .80338 m .5487 .804 L .55021 .80364 L F
.658 .172 .086 r
.5487 .804 m .55197 .80506 L .55021 .80364 L F
.724 .531 .629 r
.53221 .85097 m .53308 .84906 L .52914 .84837 L F
.395 .45 .8 r
.48542 .82938 m .48485 .8318 L .48408 .82974 L F
.48542 .82938 m .48653 .83243 L .48485 .8318 L F
.553 .303 .49 r
.50457 .87955 m .50261 .87773 L .50232 .87973 L F
.50457 .87955 m .50461 .87751 L .50261 .87773 L F
.807 .959 .63 r
.60498 .83955 m .60461 .84081 L .60653 .83796 L F
.808 .963 .641 r
.60316 .84219 m .60461 .84081 L .60498 .83955 L F
.339 .03 .286 r
.39365 .76907 m .39538 .76869 L .39614 .76682 L F
.521 .206 .374 r
.39614 .76682 m .39784 .76826 L .3983 .76659 L F
.39614 .76682 m .39538 .76869 L .39784 .76826 L F
.47 0 0 r
.40486 .74249 m .40316 .7431 L .40107 .74282 L F
.26 0 0 r
.40644 .74247 m .40316 .7431 L .40486 .74249 L F
.552 .63 .883 r
.42885 .74782 m .4283 .75044 L .42672 .74988 L F
.58 .651 .885 r
.42388 .73586 m .42275 .73791 L .42145 .73587 L F
.42388 .73586 m .42479 .73754 L .42275 .73791 L F
.529 .27 .467 r
.41101 .77204 m .41042 .7746 L .40833 .77484 L F
.557 .296 .476 r
.41284 .77389 m .41101 .77204 L .41311 .77175 L F
.41284 .77389 m .41042 .7746 L .41101 .77204 L F
.667 .784 .936 r
.69486 .72698 m .69146 .72636 L .69381 .72563 L F
.378 0 0 r
.69381 .72563 m .69723 .72546 L .69486 .72698 L F
.554 .547 .801 r
.69723 .72546 m .69714 .72707 L .69486 .72698 L F
.453 .31 .596 r
.69699 .72905 m .69486 .72698 L .69714 .72707 L F
.69699 .72905 m .69521 .72991 L .69486 .72698 L F
.709 .427 0 r
.67535 .72463 m .6753 .72467 L .67513 .72367 L F
.67535 .72463 m .67595 .72691 L .6753 .72467 L F
.556 .424 .656 r
.61887 .75612 m .62093 .75594 L .62076 .75333 L F
.569 .446 .672 r
.61923 .75866 m .62093 .75594 L .61887 .75612 L F
.796 .595 .63 r
.59939 .79313 m .59618 .79518 L .59619 .79293 L F
.59939 .79313 m .59918 .79548 L .59618 .79518 L F
.582 .61 .845 r
.32766 .67363 m .327 .6767 L .32603 .67382 L F
.32766 .67363 m .3292 .67635 L .327 .6767 L F
.636 .856 .983 r
.42337 .88472 m .42476 .88539 L .42727 .88484 L F
.801 .731 .787 r
.56562 .80908 m .56714 .81231 L .56403 .81104 L F
.574 .577 .818 r
.56731 .81365 m .56403 .81104 L .56714 .81231 L F
.372 .504 .862 r
.5685 .81021 m .56714 .81231 L .56562 .80908 L F
0 0 .21 r
.56785 .81251 m .56714 .81231 L .5685 .81021 L F
.56785 .81251 m .56731 .81365 L .56714 .81231 L F
0 0 0 r
.53644 .81732 m .53428 .8198 L .53541 .81872 L F
.073 0 .358 r
.53355 .8219 m .53541 .81872 L .53428 .8198 L F
.212 0 .31 r
.51366 .82768 m .51485 .82908 L .51586 .82768 L F
.51366 .82768 m .5132 .82988 L .51485 .82908 L F
.644 .894 .562 r
.60498 .83955 m .60653 .83796 L .60717 .83695 L F
.949 .691 .513 r
.48701 .87683 m .4883 .87476 L .48701 .87375 L F
.567 .372 .577 r
.4883 .87476 m .48872 .87163 L .48701 .87375 L F
.4883 .87476 m .49077 .87226 L .48872 .87163 L F
.4883 .87476 m .49046 .87452 L .49077 .87226 L F
.758 .407 .389 r
.48701 .87683 m .49019 .87727 L .4883 .87476 L F
.51 .781 .994 r
.49046 .87452 m .4883 .87476 L .49019 .87727 L F
.454 .059 .2 r
.54447 .85734 m .54731 .85628 L .54633 .85822 L F
.345 0 .04 r
.54682 .85699 m .54731 .85628 L .54447 .85734 L F
0 0 0 r
.54633 .85822 m .54731 .85628 L .54862 .85582 L F
.54862 .85582 m .54731 .85628 L .54682 .85699 L F
.315 0 .052 r
.47272 .83053 m .47415 .83091 L .4754 .82915 L F
.369 .07 .32 r
.4754 .82915 m .47706 .82986 L .47784 .8272 L F
.408 0 .106 r
.4754 .82915 m .47415 .83091 L .47706 .82986 L F
.444 0 0 r
.71166 .73556 m .71224 .73553 L .712 .73628 L F
.783 .978 .704 r
.712 .73628 m .71327 .73547 L .71163 .73741 L F
.59 .913 .669 r
.71565 .73332 m .71327 .73547 L .712 .73628 L F
.71565 .73332 m .712 .73628 L .71515 .73535 L F
.444 0 0 r
.71224 .73553 m .71515 .73535 L .712 .73628 L F
.783 .978 .704 r
.712 .73628 m .71163 .73741 L .71107 .73807 L F
.239 .368 .793 r
.54381 .84343 m .54491 .84655 L .54595 .84511 L F
.574 .561 .802 r
.54491 .84655 m .54799 .84869 L .54817 .84789 L F
.755 .612 .699 r
.6347 .76683 m .63812 .76716 L .63677 .76406 L F
0 0 0 r
.5329 .82289 m .53214 .82462 L .53355 .8219 L F
.451 .131 .331 r
.37478 .79548 m .37381 .79813 L .37179 .79849 L F
.473 .171 .372 r
.37702 .79478 m .37381 .79813 L .37478 .79548 L F
.617 .728 .925 r
.40983 .74291 m .41296 .74365 L .412 .74236 L F
.511 .653 .922 r
.41296 .74365 m .41397 .7421 L .412 .74236 L F
.41296 .74365 m .4145 .74346 L .41397 .7421 L F
.726 .585 .697 r
.51832 .8555 m .51622 .85791 L .51679 .85639 L F
.58 .506 .737 r
.42654 .74534 m .42447 .74581 L .42386 .74323 L F
.565 .424 .649 r
.42675 .74815 m .42447 .74581 L .42654 .74534 L F
.42675 .74815 m .42467 .74863 L .42447 .74581 L F
.732 .668 .787 r
.71107 .73807 m .7078 .73745 L .70999 .73684 L F
.783 .978 .704 r
.712 .73628 m .71107 .73807 L .70999 .73684 L F
.392 .138 .405 r
.41439 .75072 m .41621 .75026 L .41691 .74777 L F
.4 .507 .852 r
.41601 .74671 m .41691 .74777 L .41845 .74774 L F
.657 .489 .646 r
.41621 .75026 m .41845 .74774 L .41691 .74777 L F
.657 .55 .722 r
.42847 .86452 m .42891 .86689 L .43087 .86421 L F
.601 .473 .679 r
.43087 .86421 m .42891 .86689 L .43105 .86663 L F
.589 .443 .651 r
.42891 .86689 m .43118 .86909 L .43105 .86663 L F
.42891 .86689 m .42914 .86946 L .43118 .86909 L F
.132 0 0 r
.35257 .79373 m .35155 .79448 L .35454 .7932 L F
.642 .552 .738 r
.66615 .74613 m .66337 .74798 L .66336 .7465 L F
.672 .684 .852 r
.39237 .72649 m .39026 .72745 L .3887 .72523 L F
.518 .377 .629 r
.7161 .71366 m .71584 .71657 L .7141 .71427 L F
.748 .229 0 r
.68628 .75107 m .68622 .75189 L .68564 .74992 L F
.68628 .75107 m .68863 .75378 L .68622 .75189 L F
.733 .212 0 r
.68962 .7541 m .68863 .75378 L .68628 .75107 L F
.37 .176 .482 r
.33685 .685 m .33655 .68718 L .33502 .68756 L F
.328 .226 .584 r
.33651 .68949 m .33502 .68756 L .33655 .68718 L F
.33651 .68949 m .33529 .69042 L .33502 .68756 L F
.893 .989 .753 r
.51287 .84759 m .51304 .84871 L .51495 .84588 L F
.801 .479 .445 r
.50525 .85093 m .50405 .853 L .50245 .85028 L F
.79 .465 .438 r
.50525 .85093 m .50691 .85353 L .50405 .853 L F
.314 .49 .873 r
.51415 .85756 m .51536 .85952 L .51572 .85791 L F
.396 .277 .599 r
.62263 .74834 m .62439 .74783 L .62386 .74561 L F
.426 .371 .694 r
.62263 .74834 m .62485 .75027 L .62439 .74783 L F
.549 .37 .591 r
.62263 .74834 m .62267 .75066 L .62485 .75027 L F
.701 .641 .785 r
.69026 .70831 m .69046 .71021 L .69331 .70864 L F
.612 .34 .481 r
.50065 .83217 m .50278 .83243 L .5031 .83044 L F
.754 .607 .695 r
.50278 .83243 m .50512 .82959 L .5031 .83044 L F
.715 .921 .579 r
.71344 .74211 m .7128 .74337 L .71474 .7408 L F
0 0 .002 r
.71593 .73967 m .71474 .7408 L .71637 .73781 L F
0 0 0 r
.71593 .73967 m .71344 .74211 L .71474 .7408 L F
.527 .27 .469 r
.38859 .77432 m .39116 .77197 L .38893 .77225 L F
.546 .704 .943 r
.44326 .88008 m .44511 .8805 L .44383 .87935 L F
.44274 .88073 m .44488 .88052 L .44326 .88008 L F
.44488 .88052 m .44511 .8805 L .44326 .88008 L F
.675 .638 .805 r
.43868 .87876 m .43922 .87898 L .44065 .87669 L F
.188 .189 .627 r
.44326 .88008 m .44319 .88064 L .44274 .88073 L F
.44383 .87935 m .44319 .88064 L .44326 .88008 L F
.675 .638 .805 r
.43922 .87898 m .44319 .88064 L .44274 .87994 L F
.43922 .87898 m .44274 .87994 L .44065 .87669 L F
.241 .616 .956 r
.44274 .88073 m .44319 .88064 L .43868 .87876 L F
.561 .463 .7 r
.69027 .70608 m .69243 .70566 L .69192 .70337 L F
.707 .622 .759 r
.69026 .70831 m .69243 .70566 L .69027 .70608 L F
.49 .883 .713 r
.53272 .86956 m .53178 .87033 L .52807 .87189 L F
.931 .728 .605 r
.51258 .8353 m .51034 .83801 L .5114 .83555 L F
.051 0 .388 r
.51386 .83214 m .51258 .8353 L .51163 .83256 L F
.51386 .83214 m .51369 .83518 L .51258 .8353 L F
0 0 0 r
.51369 .83518 m .51034 .83801 L .51258 .8353 L F
.632 .435 .598 r
.52699 .85079 m .52894 .85135 L .52914 .84837 L F
.532 .521 .789 r
.70725 .74532 m .70964 .74759 L .70918 .74531 L F
.585 .568 .801 r
.65515 .76101 m .65209 .75854 L .65298 .76162 L F
.922 .697 .58 r
.48198 .85593 m .48326 .85641 L .48367 .85367 L F
.116 0 .01 r
.48465 .85403 m .48367 .85367 L .48585 .85362 L F
.48465 .85403 m .48198 .85593 L .48367 .85367 L F
.77 .667 .749 r
.64116 .75884 m .63917 .76158 L .6424 .76177 L F
.64 .356 .472 r
.48904 .84068 m .49096 .8429 L .48922 .84205 L F
.59 .354 .526 r
.49125 .84028 m .49096 .8429 L .48904 .84068 L F
.574 .786 .979 r
.39575 .72703 m .39237 .72649 L .39431 .72621 L F
.498 .793 .998 r
.39645 .72594 m .39575 .72703 L .39431 .72621 L F
.3 .532 .909 r
.39645 .72594 m .39767 .72749 L .39575 .72703 L F
.699 .688 .835 r
.65163 .73443 m .65049 .73785 L .6495 .73689 L F
.65163 .73443 m .65269 .73573 L .65049 .73785 L F
.544 .23 .387 r
.47784 .8272 m .48015 .82901 L .47978 .82689 L F
.47784 .8272 m .47706 .82986 L .48015 .82901 L F
.39 .739 .992 r
.69155 .75439 m .68863 .75378 L .68962 .7541 L F
.982 .892 .653 r
.71123 .74473 m .7128 .74337 L .71344 .74211 L F
.71123 .74473 m .71195 .74532 L .7128 .74337 L F
.607 .444 .635 r
.44752 .84041 m .44941 .83691 L .44715 .83754 L F
.921 .975 .711 r
.65488 .62603 m .65604 .62409 L .65588 .62485 L F
.305 .793 .887 r
.41463 .87718 m .41572 .87673 L .41692 .8768 L F
.41692 .8768 m .41572 .87673 L .41463 .87718 L F
.711 .563 .686 r
.41463 .87718 m .41812 .88006 L .41692 .8768 L F
.41463 .87718 m .41509 .88018 L .41812 .88006 L F
.1 0 0 r
.37478 .7826 m .37525 .78369 L .37665 .78201 L F
.37478 .7826 m .37353 .78451 L .37525 .78369 L F
.808 .577 .588 r
.57923 .81651 m .58183 .81695 L .58158 .8198 L F
.596 .397 .582 r
.42295 .76365 m .42197 .76786 L .42051 .76594 L F
.621 .441 .617 r
.42502 .7633 m .42197 .76786 L .42295 .76365 L F
0 0 .147 r
.71637 .73781 m .71753 .73444 L .71628 .73704 L F
.843 .749 .232 r
.71628 .73704 m .71593 .73967 L .71637 .73781 L F
.585 .759 .962 r
.65853 .62498 m .66073 .62462 L .66098 .62552 L F
.529 .254 .442 r
.66098 .62552 m .66108 .6286 L .6588 .62893 L F
.159 .429 .866 r
.66073 .62462 m .66295 .6257 L .66098 .62552 L F
.246 .048 .402 r
.66098 .62552 m .66295 .6257 L .66108 .6286 L F
.639 .331 .434 r
.52482 .85413 m .52707 .85606 L .5272 .85414 L F
.515 .464 .738 r
.41483 .75341 m .41621 .75026 L .41439 .75072 L F
.41483 .75341 m .41675 .75376 L .41621 .75026 L F
.579 .393 .594 r
.41483 .75341 m .41717 .75564 L .41675 .75376 L F
.41483 .75341 m .41507 .75611 L .41717 .75564 L F
.959 .914 .724 r
.6613 .71637 m .65922 .71849 L .66082 .71575 L F
.6613 .71637 m .65995 .71928 L .65922 .71849 L F
.948 .957 .683 r
.6613 .71637 m .66082 .71575 L .66176 .71392 L F
.461 .623 .922 r
.38767 .72361 m .38688 .72523 L .38572 .72379 L F
.38767 .72361 m .3887 .72523 L .38688 .72523 L F
.363 0 0 r
.58733 .7768 m .58927 .77694 L .59092 .77677 L F
.468 0 0 r
.59092 .77677 m .58927 .77694 L .59271 .77709 L F
.678 .304 .33 r
.46553 .88366 m .46539 .88505 L .46475 .8857 L F
.46588 .88273 m .46565 .88385 L .46553 .88366 L F
.46565 .88385 m .46539 .88505 L .46553 .88366 L F
.43 0 .062 r
.46596 .88439 m .46798 .88297 L .46992 .88313 L F
.46539 .88457 m .46588 .88426 L .46596 .88439 L F
.46588 .88426 m .46798 .88297 L .46596 .88439 L F
.678 .304 .33 r
.46588 .88273 m .46539 .88457 L .46539 .88505 L F
.46588 .88273 m .46798 .88297 L .46539 .88457 L F
.772 .533 .574 r
.48612 .86439 m .48908 .86613 L .48651 .86736 L F
.937 .631 .435 r
.4861 .86911 m .48743 .86937 L .48651 .86736 L F
.4861 .86911 m .48651 .86736 L .48908 .86613 L F
.5 0 0 r
.50357 .88208 m .50697 .88248 L .50564 .88224 L F
.706 .266 .203 r
.50697 .88248 m .50764 .88453 L .50564 .88224 L F
.50697 .88248 m .50928 .88384 L .50764 .88453 L F
.493 .526 .819 r
.4145 .74346 m .41601 .74671 L .41743 .74478 L F
.465 .487 .797 r
.41601 .74671 m .41845 .74774 L .41743 .74478 L F
.162 0 0 r
.66221 .70768 m .6644 .70655 L .66242 .7052 L F
.66221 .70768 m .66535 .70774 L .6644 .70655 L F
.094 .276 .758 r
.50968 .85321 m .50737 .85116 L .50991 .851 L F
0 .178 .695 r
.5459 .78296 m .54758 .78446 L .54712 .78363 L F
.874 .433 .105 r
.5463 .81832 m .54655 .81709 L .5455 .81642 L F
.5463 .81832 m .5474 .81881 L .54655 .81709 L F
.852 .729 .727 r
.67848 .74327 m .68222 .74302 L .68126 .74457 L F
.96 .665 .427 r
.68222 .74302 m .6825 .74512 L .68126 .74457 L F
.879 .77 .738 r
.61607 .79547 m .61842 .79558 L .61772 .79261 L F
.874 .788 .762 r
.61676 .79826 m .61842 .79558 L .61607 .79547 L F
.832 .745 .768 r
.61772 .79261 m .61842 .79558 L .61931 .79353 L F
.491 .19 .382 r
.34426 .75644 m .34373 .75811 L .34161 .75862 L F
.391 .033 .233 r
.34614 .75638 m .34373 .75811 L .34426 .75644 L F
.805 .824 .866 r
.71167 .70791 m .71325 .70888 L .71365 .70729 L F
.938 .703 .556 r
.71167 .70791 m .71299 .71116 L .71325 .70888 L F
.629 .5 .686 r
.42558 .74069 m .4261 .74272 L .42386 .74323 L F
.58 .506 .737 r
.42654 .74534 m .42386 .74323 L .4261 .74272 L F
.901 .801 .739 r
.53459 .83992 m .53212 .84083 L .53425 .83986 L F
.53459 .83992 m .53284 .84339 L .53212 .84083 L F
.488 .754 .989 r
.50902 .81996 m .5113 .81992 L .50989 .81872 L F
.50902 .81996 m .5113 .81992 L .50989 .81872 L F
.984 .727 .458 r
.67483 .71932 m .67379 .72069 L .67343 .71856 L F
.67483 .71932 m .67485 .7215 L .67379 .72069 L F
.58 .613 .85 r
.41892 .88622 m .42022 .88428 L .41818 .88446 L F
.41892 .88622 m .42183 .88602 L .42022 .88428 L F
.212 0 0 r
.36427 .7248 m .36644 .72463 L .36758 .72408 L F
.476 0 0 r
.36644 .72463 m .36953 .72461 L .36758 .72408 L F
.394 0 .145 r
.52119 .84263 m .523 .84254 L .52466 .84022 L F
.341 0 .07 r
.523 .84254 m .52672 .84012 L .52466 .84022 L F
.773 .661 .74 r
.62934 .76905 m .63255 .76933 L .63145 .76632 L F
.775 .65 .724 r
.62934 .76905 m .63059 .77217 L .63255 .76933 L F
.714 .631 .764 r
.63145 .76632 m .63255 .76933 L .6347 .76683 L F
.616 .855 .989 r
.48347 .84291 m .48152 .8436 L .48032 .84284 L F
.48347 .84291 m .48152 .8436 L .48032 .84284 L F
0 0 0 r
.58702 .83172 m .58592 .8317 L .58504 .83123 L F
.58702 .83172 m .5874 .83144 L .58592 .8317 L F
.818 .737 .775 r
.61931 .79353 m .62138 .79079 L .6198 .78978 L F
.875 .904 .848 r
.67221 .70785 m .66856 .71083 L .66902 .70891 L F
0 0 .271 r
.67328 .70901 m .67297 .70831 L .67142 .70752 L F
.67328 .70901 m .674 .71124 L .67297 .70831 L F
.421 0 0 r
.42197 .76786 m .41966 .76853 L .42051 .76594 L F
.671 .516 .666 r
.43068 .86179 m .43087 .86421 L .43301 .86156 L F
.215 0 0 r
.35857 .72647 m .36064 .72614 L .36217 .72507 L F
.417 0 .009 r
.36064 .72614 m .36427 .7248 L .36217 .72507 L F
.858 .551 .468 r
.57232 .78051 m .57235 .78256 L .5711 .78168 L F
.692 .627 .779 r
.63655 .72482 m .63643 .72748 L .6341 .72689 L F
.726 .476 .549 r
.63643 .72748 m .63423 .72936 L .6341 .72689 L F
.63643 .72748 m .63762 .72968 L .63423 .72936 L F
.617 .563 .771 r
.63848 .72577 m .63643 .72748 L .63655 .72482 L F
.635 .444 .607 r
.63992 .72892 m .63643 .72748 L .63848 .72577 L F
.63992 .72892 m .63762 .72968 L .63643 .72748 L F
.761 .901 .939 r
.63848 .72577 m .63643 .72748 L .63539 .72602 L F
.893 .989 .753 r
.51287 .84759 m .51495 .84588 L .51165 .84585 L F
.772 .725 .809 r
.63584 .76124 m .63362 .76374 L .63677 .76406 L F
.791 .665 .725 r
.63362 .76374 m .6347 .76683 L .63677 .76406 L F
.743 .71 .82 r
.63584 .76124 m .63677 .76406 L .63917 .76158 L F
.313 0 .18 r
.49683 .82209 m .49403 .82608 L .49317 .82505 L F
.473 .121 .287 r
.49744 .82425 m .49403 .82608 L .49683 .82209 L F
.41 .362 .694 r
.66027 .70616 m .66052 .70945 L .66221 .70768 L F
0 0 0 r
.66188 .71102 m .66221 .70768 L .66052 .70945 L F
.804 .604 .632 r
.46588 .88273 m .46475 .8857 L .46248 .885 L F
.284 .359 .764 r
.52881 .83509 m .53127 .83756 L .53112 .83513 L F
.864 .765 .751 r
.61636 .80422 m .61659 .80035 L .61495 .80339 L F
.698 .649 .798 r
.65209 .75854 m .64865 .7561 L .64976 .75911 L F
.65209 .75854 m .65236 .75713 L .64865 .7561 L F
.742 .693 .804 r
.65209 .75854 m .654 .75591 L .65236 .75713 L F
.637 .541 .729 r
.65209 .75854 m .6553 .76003 L .654 .75591 L F
.585 .568 .801 r
.65515 .76101 m .6553 .76003 L .65209 .75854 L F
.496 .097 .214 r
.5708 .83433 m .5719 .83241 L .56967 .83256 L F
.548 .749 .97 r
.54512 .85528 m .54682 .85699 L .54447 .85734 L F
.454 .059 .2 r
.54447 .85734 m .54633 .85822 L .54429 .85879 L F
0 0 0 r
.54512 .85528 m .54447 .85734 L .54429 .85879 L F
.586 .923 .964 r
.57801 .81077 m .57594 .81155 L .57769 .81034 L F
.671 .621 .79 r
.57801 .81077 m .57945 .81232 L .57594 .81155 L F
.834 .763 .784 r
.57945 .81232 m .57636 .81379 L .57594 .81155 L F
.265 .155 .536 r
.57594 .81155 m .57773 .81293 L .57769 .81034 L F
.57594 .81155 m .57636 .81379 L .57773 .81293 L F
0 0 0 r
.36548 .75311 m .36456 .75334 L .36255 .75375 L F
.538 .923 .818 r
.36634 .75228 m .36456 .75334 L .36548 .75311 L F
.788 .415 .351 r
.55 .85116 m .55181 .85124 L .55072 .85296 L F
.55025 .85069 m .55181 .85124 L .55 .85116 L F
.54975 .85051 m .55072 .85296 L .54851 .85284 L F
0 0 0 r
.5509 .85042 m .54981 .85152 L .54971 .85248 L F
.54981 .85152 m .54851 .85284 L .54921 .85263 L F
.54981 .85152 m .54921 .85263 L .54971 .85248 L F
.788 .415 .351 r
.54975 .85051 m .55025 .85069 L .55 .85116 L F
.774 .805 .319 r
.55181 .85124 m .55275 .8479 L .5509 .85042 L F
.997 .793 .507 r
.55072 .85296 m .55181 .85124 L .5509 .85042 L F
.463 .196 .422 r
.39116 .77197 m .39308 .7716 L .39365 .76907 L F
.49 .22 .431 r
.39365 .76907 m .39515 .77113 L .39538 .76869 L F
.39365 .76907 m .39308 .7716 L .39515 .77113 L F
.496 .361 .627 r
.64334 .7169 m .64526 .71623 L .64415 .71758 L F
.365 .771 .983 r
.37046 .71624 m .37247 .71595 L .37424 .71679 L F
.972 .754 .551 r
.37424 .71679 m .37247 .71595 L .37046 .71624 L F
.37424 .71679 m .37371 .71888 L .37247 .71595 L F
.537 .852 .998 r
.37424 .71679 m .37247 .71595 L .37584 .71618 L F
.347 .107 .402 r
.37584 .71618 m .37371 .71888 L .37424 .71679 L F
.33 0 .14 r
.37869 .7948 m .38187 .79207 L .38083 .79428 L F
.37869 .7948 m .37946 .79361 L .38187 .79207 L F
.317 0 .183 r
.38457 .79042 m .38343 .79259 L .38187 .79207 L F
.32 0 .162 r
.38343 .79259 m .38083 .79428 L .38187 .79207 L F
.447 .283 .565 r
.53541 .81872 m .5382 .81687 L .53644 .81732 L F
.552 .843 .998 r
.50995 .87166 m .51148 .87237 L .51331 .87191 L F
.946 .633 .409 r
.50995 .87166 m .51148 .87237 L .5117 .87454 L F
.55 .275 .451 r
.43699 .75359 m .43686 .75529 L .43451 .75543 L F
.604 .517 .729 r
.43883 .75119 m .43699 .75359 L .43611 .7502 L F
.43883 .75119 m .43909 .75342 L .43699 .75359 L F
.567 .296 .465 r
.43909 .75342 m .43686 .75529 L .43699 .75359 L F
.867 .979 .85 r
.43741 .87988 m .43779 .88028 L .43868 .87876 L F
.989 .881 .549 r
.43741 .87988 m .43674 .88243 L .43779 .88028 L F
.699 .43 .513 r
.6908 .75074 m .6938 .74864 L .69065 .74771 L F
.6908 .75074 m .69394 .75044 L .6938 .74864 L F
0 0 .282 r
.55387 .83984 m .55423 .84276 L .5538 .84068 L F
.671 .459 .589 r
.59597 .77701 m .59814 .77698 L .59811 .77464 L F
.667 .456 .59 r
.59814 .77698 m .60044 .77458 L .59811 .77464 L F
.985 .873 .64 r
.59128 .81928 m .59093 .82208 L .59189 .82113 L F
.654 .1 0 r
.59182 .82116 m .59093 .82208 L .59189 .82113 L F
.985 .873 .64 r
.59275 .82127 m .59232 .82146 L .59334 .82133 L F
.59232 .82146 m .5925 .82159 L .59334 .82133 L F
.263 .312 .726 r
.59093 .82208 m .5925 .82218 L .59334 .82133 L F
.436 .184 .432 r
.59193 .82119 m .59334 .82133 L .5925 .82218 L F
.59189 .82113 m .59334 .82133 L .59193 .82119 L F
.416 .353 .68 r
.59128 .81928 m .59334 .82133 L .59189 .82113 L F
.985 .873 .64 r
.59312 .82111 m .59275 .82127 L .59334 .82133 L F
.59232 .82146 m .59093 .82208 L .5925 .82159 L F
.436 .184 .432 r
.59189 .82113 m .59193 .82119 L .59187 .82115 L F
.985 .873 .64 r
.59182 .82116 m .59093 .82208 L .59312 .82111 L F
.654 .1 0 r
.58912 .82228 m .59209 .82437 L .59093 .82208 L F
.263 .312 .726 r
.59093 .82208 m .59209 .82437 L .5925 .82218 L F
.436 .184 .432 r
.59187 .82115 m .5925 .82218 L .59037 .82365 L F
.59193 .82119 m .5925 .82218 L .59187 .82115 L F
.985 .873 .64 r
.59128 .81928 m .59093 .82208 L .59248 .82047 L F
.654 .1 0 r
.58912 .82228 m .59093 .82208 L .59182 .82116 L F
.333 0 .129 r
.58912 .82228 m .59182 .82116 L .59037 .82365 L F
.59182 .82116 m .59189 .82113 L .59187 .82115 L F
.59182 .82116 m .59187 .82115 L .59037 .82365 L F
.985 .873 .64 r
.59248 .82047 m .59182 .82116 L .59312 .82111 L F
.912 .698 .6 r
.68262 .72235 m .68133 .71909 L .68168 .72131 L F
.594 .722 .934 r
.68168 .72131 m .68475 .72238 L .68262 .72235 L F
.754 .376 .337 r
.57783 .78479 m .57437 .78292 L .57739 .78262 L F
.716 .64 .772 r
.64647 .75858 m .64976 .75911 L .64865 .7561 L F
0 .014 .57 r
.68966 .73646 m .68825 .73511 L .68723 .73504 L F
.816 .354 .125 r
.68825 .73511 m .69036 .7377 L .69156 .73784 L F
0 .014 .57 r
.68966 .73646 m .69036 .7377 L .68825 .73511 L F
.974 .71 .469 r
.68723 .73504 m .68825 .73511 L .68732 .73235 L F
0 0 0 r
.69503 .7542 m .69413 .75425 L .69155 .75439 L F
.139 0 0 r
.69719 .75416 m .69413 .75425 L .69503 .7542 L F
.563 .067 .037 r
.48653 .83243 m .48833 .8329 L .48997 .83234 L F
.914 .721 .627 r
.48833 .8329 m .48963 .83473 L .48997 .83234 L F
0 0 0 r
.63655 .72482 m .6341 .72689 L .63539 .72602 L F
.704 .684 .828 r
.63423 .72936 m .63539 .72602 L .6341 .72689 L F
.632 .181 .162 r
.57561 .77602 m .5775 .77638 L .5787 .77508 L F
.713 .281 .223 r
.5775 .77638 m .58065 .77682 L .5787 .77508 L F
.695 .302 .299 r
.5787 .77508 m .58065 .77682 L .58221 .77668 L F
.965 .774 .596 r
.67708 .73001 m .6755 .73155 L .67593 .72931 L F
.67708 .73001 m .6767 .7323 L .6755 .73155 L F
.584 .383 .575 r
.44333 .84572 m .4455 .84555 L .4455 .84312 L F
.514 .362 .612 r
.4455 .84312 m .44759 .84291 L .44752 .84041 L F
.61 .404 .577 r
.4455 .84312 m .44776 .84529 L .44759 .84291 L F
.4455 .84312 m .4455 .84555 L .44776 .84529 L F
.748 .535 .607 r
.41487 .88251 m .41812 .88006 L .41509 .88018 L F
.41487 .88251 m .41786 .88254 L .41812 .88006 L F
.678 .601 .762 r
.41692 .8768 m .41812 .88006 L .41974 .87753 L F
.547 .357 .574 r
.41786 .88254 m .42001 .88236 L .41812 .88006 L F
.679 .601 .762 r
.41812 .88006 m .4208 .88038 L .41974 .87753 L F
.679 .37 .445 r
.41812 .88006 m .42001 .88236 L .4208 .88038 L F
.539 .743 .97 r
.42145 .73587 m .41943 .73624 L .41816 .735 L F
.598 .399 .582 r
.53983 .83747 m .53805 .84167 L .53776 .83774 L F
.993 .75 .451 r
.43758 .88502 m .4346 .88425 L .43571 .88562 L F
.818 .737 .775 r
.61931 .79353 m .6198 .78978 L .61772 .79261 L F
.659 .683 .862 r
.53214 .82462 m .53498 .82567 L .5337 .82479 L F
.415 0 0 r
.53498 .82567 m .53611 .82646 L .5337 .82479 L F
.53498 .82567 m .53751 .82718 L .53611 .82646 L F
.439 .042 .187 r
.52459 .82787 m .52367 .8297 L .52199 .82886 L F
.56 .163 .247 r
.52632 .82911 m .52367 .8297 L .52459 .82787 L F
.483 .212 .426 r
.52662 .82725 m .52632 .82911 L .52459 .82787 L F
.636 .856 .983 r
.42337 .88472 m .42727 .88484 L .42544 .88266 L F
.583 .67 .899 r
.42727 .88484 m .4276 .88202 L .42544 .88266 L F
.42727 .88484 m .42906 .88453 L .4276 .88202 L F
.567 .672 .91 r
.42727 .88484 m .43034 .88571 L .42906 .88453 L F
.336 .782 .958 r
.58123 .84712 m .58234 .84743 L .58244 .84709 L F
.34 .706 .984 r
.58234 .84743 m .58442 .84679 L .58244 .84709 L F
.58234 .84743 m .58391 .84766 L .58442 .84679 L F
.639 .489 .663 r
.4392 .85093 m .44142 .85087 L .44117 .84858 L F
.656 .438 .576 r
.43861 .85295 m .44142 .85087 L .4392 .85093 L F
.733 .57 .671 r
.51572 .81676 m .51548 .81607 L .51664 .81678 L F
.102 0 0 r
.51752 .81699 m .51664 .81678 L .51548 .81607 L F
.51752 .81699 m .51896 .81665 L .51664 .81678 L F
.384 .232 .548 r
.51752 .81699 m .51664 .81678 L .51896 .81665 L F
.51752 .81699 m .51572 .81676 L .51664 .81678 L F
.402 .51 .854 r
.68475 .72238 m .68713 .72338 L .68585 .72465 L F
.416 .534 .868 r
.68713 .72338 m .68824 .72547 L .68585 .72465 L F
.54 .08 .111 r
.56992 .77635 m .57219 .77666 L .57339 .77537 L F
.428 0 .034 r
.57339 .77537 m .57219 .77666 L .57561 .77602 L F
.51 .569 .851 r
.51171 .85661 m .51415 .85756 L .514 .85613 L F
.817 .689 .723 r
.66102 .72681 m .65968 .72365 L .66026 .72463 L F
0 .332 .789 r
.48328 .86108 m .48391 .86112 L .48146 .85965 L F
.753 .476 .513 r
.48328 .86108 m .48463 .86354 L .48166 .86365 L F
.758 .478 .508 r
.48528 .86198 m .48463 .86354 L .48328 .86108 L F
.753 .476 .513 r
.48328 .86108 m .48166 .86365 L .48391 .86112 L F
.848 .992 .844 r
.49091 .82519 m .49153 .82298 L .49317 .82505 L F
.761 .394 .36 r
.49317 .82505 m .48944 .8252 L .49091 .82519 L F
.48944 .8252 m .48903 .82522 L .49091 .82519 L F
.848 .992 .844 r
.49091 .82519 m .48943 .82565 L .48979 .8252 L F
.49091 .82519 m .48979 .8252 L .49153 .82298 L F
0 0 0 r
.67034 .71901 m .66934 .72064 L .66968 .72191 L F
.67005 .71923 m .66934 .72064 L .67034 .71901 L F
.67005 .71923 m .67026 .71912 L .66934 .72064 L F
.67048 .71836 m .67005 .71923 L .67034 .71901 L F
.67048 .71836 m .67026 .71912 L .67005 .71923 L F
.67066 .7189 m .67026 .71912 L .67199 .718 L F
.929 .959 .647 r
.66934 .72064 m .67026 .71912 L .66908 .71998 L F
0 0 0 r
.66908 .71998 m .67026 .71912 L .67066 .7189 L F
.922 .721 .23 r
.66914 .72329 m .66968 .72191 L .66934 .72064 L F
.66914 .72329 m .66959 .72417 L .66968 .72191 L F
.694 .389 .454 r
.64628 .73885 m .6495 .73689 L .64717 .73699 L F
.174 .398 .84 r
.32184 .66298 m .32132 .66419 L .32105 .66381 L F
.32184 .66298 m .32351 .66563 L .32132 .66419 L F
.799 .75 .807 r
.48794 .86231 m .48528 .86198 L .48739 .86115 L F
.48794 .86231 m .48463 .86354 L .48528 .86198 L F
.427 0 0 r
.56466 .77737 m .56787 .77688 L .56571 .77699 L F
.751 .752 .853 r
.40977 .73014 m .40592 .72986 L .40852 .73014 L F
.503 .906 .91 r
.40977 .73014 m .41043 .72931 L .41154 .72989 L F
.40977 .73014 m .40852 .73014 L .41043 .72931 L F
.394 .777 .991 r
.40977 .73014 m .41154 .72989 L .4124 .73029 L F
.897 .502 .072 r
.36117 .75089 m .36135 .75198 L .3593 .75128 L F
.36147 .75152 m .36255 .75375 L .36135 .75198 L F
.558 .666 .909 r
.36255 .75375 m .36313 .75186 L .36135 .75198 L F
.31 0 0 r
.36313 .75186 m .36115 .75279 L .36135 .75198 L F
.36115 .75279 m .35952 .75356 L .36135 .75198 L F
.897 .502 .072 r
.36117 .75089 m .36147 .75152 L .36135 .75198 L F
.371 0 0 r
.63428 .73165 m .63298 .73091 L .63225 .73042 L F
.63428 .73165 m .63529 .73214 L .63298 .73091 L F
.25 .593 .949 r
.57988 .81161 m .57945 .81232 L .57801 .81077 L F
.57988 .81161 m .58212 .81349 L .57945 .81232 L F
.2 0 .114 r
.53368 .87258 m .53404 .87187 L .53571 .87158 L F
.584 .393 .589 r
.60853 .772 m .61091 .7719 L .61085 .76933 L F
.652 .498 .661 r
.61085 .76933 m .61314 .76919 L .61297 .76688 L F
.647 .442 .592 r
.61085 .76933 m .61321 .77159 L .61314 .76919 L F
.61085 .76933 m .61091 .7719 L .61321 .77159 L F
.408 .043 .231 r
.38549 .79215 m .38457 .79042 L .38625 .78973 L F
.38549 .79215 m .38343 .79259 L .38457 .79042 L F
.607 .406 .584 r
.41066 .76058 m .41302 .75858 L .41084 .75892 L F
.604 .852 .991 r
.39583 .74356 m .39918 .7436 L .39773 .74291 L F
.095 .652 .77 r
.40107 .74282 m .39773 .74291 L .39918 .7436 L F
.771 .67 .751 r
.62334 .77933 m .62098 .78237 L .62418 .78219 L F
.769 .611 .683 r
.62098 .78237 m .62216 .78505 L .62418 .78219 L F
.715 .638 .77 r
.62334 .77933 m .62418 .78219 L .62622 .77965 L F
.612 .297 .413 r
.40025 .76616 m .40237 .76635 L .40349 .764 L F
.598 .283 .406 r
.40349 .764 m .40536 .76564 L .40548 .76357 L F
.40349 .764 m .40237 .76635 L .40536 .76564 L F
.582 .795 .98 r
.44511 .8805 m .44843 .88103 L .44718 .87971 L F
.575 .719 .94 r
.44843 .88103 m .44926 .87939 L .44718 .87971 L F
.44843 .88103 m .45027 .88058 L .44926 .87939 L F
.741 .775 .88 r
.51984 .85103 m .52079 .8521 L .52194 .85128 L F
.878 .456 .039 r
.52049 .85272 m .52079 .8521 L .51984 .85103 L F
.222 0 0 r
.35442 .80839 m .35803 .80656 L .35595 .80758 L F
.417 .843 .691 r
.35595 .80758 m .35803 .80656 L .35965 .80561 L F
.621 .467 .652 r
.61297 .76688 m .61524 .76667 L .61512 .76417 L F
.623 .475 .661 r
.61297 .76688 m .61314 .76919 L .61524 .76667 L F
.434 .086 .274 r
.33851 .73509 m .34066 .73471 L .34169 .73247 L F
.35 .005 .232 r
.34169 .73247 m .34242 .73417 L .34382 .73235 L F
.34169 .73247 m .34066 .73471 L .34242 .73417 L F
.984 .755 .513 r
.55408 .82961 m .55372 .83189 L .55455 .83167 L F
.741 .716 .185 r
.554 .8341 m .55455 .83167 L .55372 .83189 L F
.554 .8341 m .5539 .83497 L .55455 .83167 L F
.922 .791 .317 r
.61105 .82691 m .61133 .82463 L .61078 .82652 L F
.794 .853 .401 r
.61133 .82463 m .61249 .82124 L .61154 .82445 L F
0 0 0 r
.61078 .82652 m .61133 .82463 L .61154 .82445 L F
.036 .599 .795 r
.65464 .72156 m .6571 .72172 L .65785 .72189 L F
.65785 .72189 m .6571 .72172 L .65464 .72156 L F
.573 .934 .928 r
.65785 .72189 m .6571 .72172 L .65905 .72074 L F
.65905 .72074 m .6571 .72172 L .65785 .72189 L F
.036 .599 .795 r
.65464 .72156 m .6571 .72172 L .65785 .72189 L F
.65464 .72156 m .6571 .72172 L .65785 .72189 L F
.842 .402 .178 r
.69036 .7377 m .69093 .73919 L .69156 .73784 L F
.459 0 0 r
.69285 .73894 m .69156 .73784 L .69093 .73919 L F
.69285 .73894 m .69374 .73969 L .69156 .73784 L F
.561 .364 .572 r
.69398 .73737 m .69374 .73969 L .69156 .73784 L F
0 .412 .737 r
.69491 .74135 m .69409 .74123 L .69374 .73969 L F
.69491 .74135 m .69732 .74229 L .69409 .74123 L F
.51 .514 .797 r
.69409 .74123 m .69732 .74229 L .69534 .74252 L F
.083 .556 .903 r
.56701 .8453 m .56765 .84492 L .56529 .84284 L F
.56701 .8453 m .56901 .84578 L .56765 .84492 L F
.679 .135 0 r
.55188 .82611 m .55304 .82667 L .55118 .82485 L F
.55188 .82611 m .55118 .82485 L .55062 .82382 L F
.569 .489 .725 r
.65515 .76101 m .65759 .75905 L .6553 .76003 L F
.65515 .76101 m .65728 .76054 L .65759 .75905 L F
.878 .662 .606 r
.67809 .7553 m .68055 .75344 L .67855 .75313 L F
.67809 .7553 m .68037 .75542 L .68055 .75344 L F
.218 0 0 r
.39011 .74676 m .38809 .74722 L .38949 .74641 L F
.853 .74 .739 r
.59695 .81129 m .59404 .81366 L .5959 .81028 L F
.59695 .81129 m .59545 .81404 L .59404 .81366 L F
.374 .22 .541 r
.5272 .85414 m .52894 .85135 L .52699 .85079 L F
.309 .065 .373 r
.5272 .85414 m .52707 .85606 L .52869 .8548 L F
0 0 .267 r
.66056 .70425 m .66027 .70616 L .66116 .70474 L F
.19 .341 .787 r
.66027 .70616 m .66221 .70768 L .66116 .70474 L F
.91 .705 .614 r
.67728 .75019 m .67972 .74805 L .67858 .74786 L F
.67728 .75019 m .67933 .75056 L .67972 .74805 L F
.778 .635 .703 r
.69534 .74252 m .69596 .7456 L .6928 .74525 L F
.625 .128 .05 r
.69596 .7456 m .69489 .74624 L .6928 .74525 L F
.289 .714 .97 r
.68619 .70284 m .68938 .70356 L .68675 .70343 L F
.199 .119 .534 r
.69732 .74229 m .69596 .7456 L .69534 .74252 L F
.69732 .74229 m .69759 .74524 L .69596 .7456 L F
0 0 0 r
.69596 .7456 m .69759 .74524 L .69489 .74624 L F
.114 0 0 r
.35286 .80884 m .35442 .80839 L .35225 .80972 L F
.643 .47 .633 r
.42475 .87475 m .42719 .87506 L .42724 .87222 L F
.484 .272 .515 r
.42719 .87506 m .42968 .87191 L .42724 .87222 L F
.665 .678 .853 r
.57148 .78564 m .57313 .78823 L .57015 .78759 L F
.092 .119 .596 r
.57147 .78846 m .57015 .78759 L .57313 .78823 L F
.417 .56 .89 r
.57405 .787 m .57313 .78823 L .57148 .78564 L F
.687 .457 .568 r
.57405 .787 m .57147 .78846 L .57313 .78823 L F
.436 .242 .518 r
.64126 .71559 m .63977 .71393 L .64029 .71657 L F
.64126 .71559 m .64163 .71344 L .63977 .71393 L F
.931 .59 .367 r
.65995 .71928 m .65905 .72074 L .65922 .71849 L F
.65995 .71928 m .66079 .72193 L .65905 .72074 L F
.271 .734 .949 r
.40644 .74247 m .40983 .74291 L .40855 .74198 L F
.574 .846 .996 r
.40983 .74291 m .41068 .74159 L .40855 .74198 L F
.40983 .74291 m .412 .74236 L .41068 .74159 L F
.604 .411 .595 r
.63655 .72482 m .63981 .72444 L .63839 .72174 L F
.908 .973 .797 r
.63984 .7182 m .63839 .72174 L .64033 .72041 L F
0 0 .574 r
.64019 .72447 m .63839 .72174 L .64079 .72216 L F
0 .043 .602 r
.63839 .72174 m .64019 .72447 L .64033 .72041 L F
.63839 .72174 m .63981 .72444 L .64019 .72447 L F
.395 0 .144 r
.52199 .82886 m .52075 .83084 L .51878 .83106 L F
.084 0 0 r
.52261 .82988 m .52075 .83084 L .52199 .82886 L F
.849 .978 .679 r
.52196 .82845 m .52075 .83084 L .52261 .82988 L F
.823 .473 .394 r
.52261 .82988 m .52133 .8305 L .52192 .8301 L F
.084 0 0 r
.52261 .82988 m .52199 .82886 L .52348 .8296 L F
.823 .473 .394 r
.52261 .82988 m .52427 .8285 L .52196 .82845 L F
.52261 .82988 m .52192 .8301 L .52427 .8285 L F
.084 0 0 r
.52261 .82988 m .52348 .8296 L .52367 .8297 L F
.433 .306 .607 r
.33798 .6823 m .3384 .6845 L .33685 .685 L F
.509 .296 .525 r
.33851 .68674 m .33685 .685 L .3384 .6845 L F
.33851 .68674 m .33655 .68718 L .33685 .685 L F
.666 .283 .311 r
.41342 .92491 m .41661 .9248 L .41525 .92671 L F
0 0 0 r
.41595 .92483 m .41661 .9248 L .41342 .92491 L F
.503 .909 .84 r
.41737 .92405 m .41661 .9248 L .41595 .92483 L F
0 0 0 r
.41525 .92671 m .41661 .9248 L .41737 .92405 L F
0 .118 .67 r
.41364 .73114 m .41394 .73265 L .4124 .73029 L F
.41364 .73114 m .4124 .73029 L .41154 .72989 L F
.902 .6 .104 r
.55365 .83653 m .5539 .83497 L .554 .8341 L F
.55365 .83653 m .55443 .83772 L .5539 .83497 L F
.765 .622 .701 r
.59273 .79044 m .59084 .79283 L .5895 .79023 L F
.717 .551 .663 r
.59411 .79263 m .59084 .79283 L .59273 .79044 L F
.553 .376 .596 r
.44117 .84858 m .44341 .8483 L .44333 .84572 L F
.608 .493 .697 r
.44142 .85087 m .44341 .8483 L .44117 .84858 L F
.084 .614 .869 r
.70262 .75001 m .69912 .74931 L .70152 .74931 L F
.555 .79 .987 r
.70437 .74869 m .70262 .75001 L .70152 .74931 L F
.70437 .74869 m .70504 .74962 L .70262 .75001 L F
.215 .518 .915 r
.41364 .73114 m .41516 .73284 L .41394 .73265 L F
.738 .677 .792 r
.41516 .73284 m .41282 .73463 L .41394 .73265 L F
.381 .112 .375 r
.54835 .85221 m .54975 .85051 L .54799 .84869 L F
.393 0 0 r
.54799 .84869 m .5507 .85034 L .54817 .84789 L F
.701 .558 .69 r
.43087 .86421 m .4334 .86421 L .43301 .86156 L F
.699 .577 .714 r
.43289 .85931 m .43301 .86156 L .4351 .8589 L F
.643 .496 .668 r
.4351 .8589 m .43301 .86156 L .43531 .86131 L F
.592 .45 .657 r
.4334 .86421 m .43531 .86131 L .43301 .86156 L F
.64 .437 .592 r
.6058 .77445 m .60884 .77436 L .60853 .772 L F
.676 .462 .588 r
.60853 .772 m .61108 .77423 L .61091 .7719 L F
.60853 .772 m .60884 .77436 L .61108 .77423 L F
.453 0 0 r
.48788 .86758 m .4882 .86708 L .49048 .86785 L F
.937 .631 .435 r
.4861 .86911 m .48835 .86685 L .4882 .86708 L F
.863 .961 .866 r
.4861 .86911 m .4882 .86708 L .48609 .8674 L F
.453 0 0 r
.48609 .8674 m .4882 .86708 L .48788 .86758 L F
.937 .631 .435 r
.48835 .86685 m .48908 .86613 L .4882 .86708 L F
.648 .128 0 r
.48908 .86613 m .49048 .86785 L .4882 .86708 L F
.48908 .86613 m .49131 .86703 L .49048 .86785 L F
.569 .446 .672 r
.61923 .75866 m .62147 .75859 L .62093 .75594 L F
.607 .476 .677 r
.61833 .75967 m .62147 .75859 L .61923 .75866 L F
.211 .089 .486 r
.34228 .67642 m .34074 .6796 L .34014 .6776 L F
.422 .665 .962 r
.58579 .8132 m .58448 .81423 L .58396 .8132 L F
0 0 .535 r
.58569 .8155 m .58448 .81423 L .58579 .8132 L F
.5 .325 .575 r
.67852 .71643 m .68133 .71909 L .6797 .71879 L F
.408 0 0 r
.66056 .70425 m .66116 .70474 L .66242 .7052 L F
.567 .538 .783 r
.41974 .87753 m .4208 .88038 L .42263 .87974 L F
.623 .397 .553 r
.42001 .88236 m .42263 .87974 L .4208 .88038 L F
.575 .529 .767 r
.42753 .7389 m .42558 .74069 L .42479 .73754 L F
.527 .435 .694 r
.42801 .74239 m .42558 .74069 L .42753 .7389 L F
.42801 .74239 m .4261 .74272 L .42558 .74069 L F
.728 .691 .814 r
.42906 .88453 m .43034 .88571 L .43237 .88488 L F
.2 .729 .804 r
.43226 .75058 m .43439 .75023 L .43611 .7502 L F
.355 .819 .918 r
.43611 .7502 m .43649 .74957 L .43817 .74973 L F
.419 .865 .883 r
.43611 .7502 m .43439 .75023 L .43649 .74957 L F
.559 .581 .832 r
.43817 .74973 m .43883 .75119 L .43611 .7502 L F
.757 .641 .733 r
.62726 .77172 m .63059 .77217 L .62934 .76905 L F
.806 .718 .767 r
.62721 .77375 m .63059 .77217 L .62726 .77172 L F
.62721 .77375 m .62862 .77481 L .63059 .77217 L F
.763 .604 .681 r
.492 .8767 m .49304 .87611 L .49046 .87452 L F
.549 .166 .269 r
.52328 .82652 m .52552 .82674 L .52649 .8246 L F
.554 .314 .505 r
.41556 .76925 m .41527 .77144 L .41311 .77175 L F
.563 .321 .507 r
.41741 .77112 m .41556 .76925 L .41775 .76904 L F
.41741 .77112 m .41527 .77144 L .41556 .76925 L F
.68 .499 .634 r
.49361 .85072 m .4912 .85337 L .4912 .85099 L F
.478 .254 .494 r
.38861 .78922 m .3866 .78771 L .3885 .78727 L F
.38861 .78922 m .38625 .78973 L .3866 .78771 L F
.988 .888 .622 r
.61241 .81649 m .61323 .81692 L .61401 .81308 L F
.993 .873 .594 r
.61258 .81912 m .61323 .81692 L .61241 .81649 L F
.772 .681 .762 r
.62721 .77375 m .62829 .77672 L .62862 .77481 L F
.62721 .77375 m .62519 .77684 L .62829 .77672 L F
.773 .641 .716 r
.62519 .77684 m .62622 .77965 L .62829 .77672 L F
.667 .456 .59 r
.59814 .77698 m .60055 .77683 L .60044 .77458 L F
.646 .423 .567 r
.60055 .77683 m .60356 .77439 L .60044 .77458 L F
.503 .421 .696 r
.34228 .67642 m .33998 .67431 L .34136 .67407 L F
0 0 0 r
.34028 .67687 m .34136 .67407 L .33998 .67431 L F
.202 .703 .911 r
.59059 .84709 m .59274 .84735 L .59184 .84704 L F
.256 .767 .828 r
.59274 .84735 m .5938 .84699 L .59184 .84704 L F
.535 .236 .408 r
.51804 .8273 m .52015 .82713 L .52145 .82427 L F
.66 .371 .471 r
.52145 .82427 m .52328 .82652 L .52267 .82494 L F
.52145 .82427 m .52015 .82713 L .52328 .82652 L F
.333 0 .157 r
.37179 .79849 m .36898 .80024 L .36993 .79895 L F
.614 .513 .716 r
.61698 .76176 m .61946 .76147 L .61833 .75967 L F
.607 .476 .677 r
.61833 .75967 m .62172 .76087 L .62147 .75859 L F
.639 .412 .558 r
.61833 .75967 m .61946 .76147 L .62172 .76087 L F
.628 .472 .652 r
.61512 .76417 m .61748 .76622 L .61741 .76389 L F
.61512 .76417 m .61524 .76667 L .61748 .76622 L F
.541 .243 .41 r
.49199 .83524 m .49556 .83195 L .49188 .83407 L F
.49199 .83524 m .49441 .8349 L .49556 .83195 L F
.533 .234 .406 r
.49556 .83195 m .49722 .83439 L .49735 .83284 L F
.49556 .83195 m .49441 .8349 L .49722 .83439 L F
.622 .403 .564 r
.42232 .87713 m .42475 .87709 L .42475 .87475 L F
.438 .258 .538 r
.42475 .87475 m .42652 .8765 L .42719 .87506 L F
.42475 .87475 m .42475 .87709 L .42652 .8765 L F
.954 .745 .581 r
.61659 .80035 m .61676 .79826 L .61549 .79751 L F
.874 .788 .762 r
.61676 .79826 m .61607 .79547 L .61549 .79751 L F
.458 .11 .287 r
.40563 .77672 m .40252 .77911 L .40354 .77708 L F
.142 .308 .773 r
.49291 .86315 m .49245 .86425 L .48999 .86186 L F
.49291 .86315 m .49324 .86492 L .49245 .86425 L F
.473 .008 .069 r
.53848 .83185 m .53473 .83217 L .53635 .8321 L F
.573 .39 .596 r
.53631 .83491 m .53848 .83185 L .53635 .8321 L F
.753 .241 0 r
.48428 .8288 m .48619 .83008 L .48542 .82938 L F
.306 .392 .787 r
.4877 .83109 m .48653 .83243 L .48608 .83119 L F
.4877 .83109 m .48608 .83119 L .48542 .82938 L F
.119 .659 .847 r
.48622 .83082 m .48875 .83102 L .4877 .83109 L F
.48875 .83102 m .48953 .83109 L .4877 .83109 L F
.753 .241 0 r
.48619 .83008 m .4877 .83109 L .48542 .82938 L F
.264 .028 .356 r
.48482 .82884 m .48542 .82938 L .48408 .82974 L F
.48601 .82739 m .48542 .82938 L .48482 .82884 L F
.727 .622 .74 r
.64343 .75816 m .64647 .75858 L .64553 .75571 L F
.692 .602 .751 r
.64647 .75858 m .64865 .7561 L .64553 .75571 L F
.633 .74 .925 r
.40311 .7287 m .40422 .73009 L .40094 .72936 L F
.425 .641 .947 r
.40495 .72874 m .40422 .73009 L .40311 .7287 L F
.504 .739 .979 r
.40495 .72874 m .40592 .72986 L .40422 .73009 L F
.996 .787 .426 r
.70918 .74531 m .70964 .74759 L .70879 .7477 L F
.761 .706 .801 r
.70964 .74759 m .71195 .74532 L .70918 .74531 L F
.815 .575 .576 r
.71107 .74445 m .71123 .74473 L .71111 .74442 L F
.519 .849 .997 r
.70918 .74531 m .71195 .74532 L .71123 .74473 L F
.292 .374 .776 r
.71154 .74704 m .70918 .74531 L .71123 .74473 L F
.815 .575 .576 r
.70907 .74601 m .71042 .74521 L .71107 .74445 L F
.71042 .74521 m .71123 .74473 L .71107 .74445 L F
.292 .374 .776 r
.71154 .74704 m .70964 .74759 L .7094 .74641 L F
.70989 .74583 m .7094 .74641 L .70918 .74531 L F
.71154 .74704 m .7094 .74641 L .70989 .74583 L F
.224 .742 .748 r
.70879 .7477 m .70964 .74759 L .71154 .74704 L F
.435 .035 .18 r
.33613 .73579 m .33851 .73509 L .33665 .735 L F
.653 .454 .603 r
.44333 .84572 m .44568 .84796 L .4455 .84555 L F
.44333 .84572 m .44341 .8483 L .44568 .84796 L F
.555 .867 .995 r
.37488 .72422 m .3729 .72482 L .37153 .72429 L F
.487 0 0 r
.38276 .74773 m .37931 .74787 L .38073 .74826 L F
.537 0 0 r
.57988 .81161 m .58396 .8132 L .58212 .81349 L F
.928 .723 .605 r
.5986 .80107 m .59864 .80354 L .59713 .80284 L F
.996 .861 .539 r
.53118 .8523 m .53221 .85097 L .52894 .85135 L F
.53118 .8523 m .53164 .85293 L .53221 .85097 L F
.806 .769 .818 r
.66029 .73701 m .66103 .73953 L .66179 .73794 L F
.66179 .73794 m .66103 .73953 L .66029 .73701 L F
.345 0 0 r
.37304 .75035 m .37117 .75177 L .36929 .75198 L F
0 0 0 r
.37399 .75032 m .37304 .75035 L .37507 .75012 L F
.37399 .75032 m .37117 .75177 L .37304 .75035 L F
.674 .707 .873 r
.41271 .88282 m .41582 .88322 L .41487 .88251 L F
.657 .814 .959 r
.41487 .88251 m .41582 .88322 L .41786 .88254 L F
.381 .566 .909 r
.41582 .88322 m .41818 .88446 L .41786 .88254 L F
.596 .83 .988 r
.5226 .84404 m .523 .84254 L .52119 .84263 L F
.5226 .84404 m .5248 .84355 L .523 .84254 L F
.799 .75 .807 r
.48794 .86231 m .48612 .86439 L .48463 .86354 L F
.626 .239 .291 r
.50653 .87921 m .50769 .8774 L .50461 .87751 L F
.769 .411 .379 r
.50653 .87921 m .50978 .88004 L .50769 .8774 L F
.788 .466 .444 r
.51094 .87958 m .50769 .8774 L .50978 .88004 L F
.634 .499 .68 r
.43087 .86421 m .43346 .86635 L .4334 .86421 L F
.43087 .86421 m .43105 .86663 L .43346 .86635 L F
0 .451 .862 r
.67685 .7139 m .68087 .71611 L .67852 .71643 L F
.5 .325 .575 r
.67852 .71643 m .68026 .719 L .68133 .71909 L F
.67852 .71643 m .68087 .71611 L .68026 .719 L F
.383 .834 .733 r
.49799 .83692 m .4975 .83709 L .49636 .83777 L F
0 0 0 r
.4975 .83709 m .49516 .83961 L .49636 .83777 L F
.322 .022 .291 r
.52826 .87124 m .52581 .87237 L .52755 .87127 L F
.081 .196 .685 r
.52581 .87237 m .52665 .87406 L .52742 .87373 L F
.455 .833 .989 r
.69962 .75389 m .70066 .75445 L .70284 .75403 L F
.707 .622 .759 r
.69026 .70831 m .69331 .70864 L .69243 .70566 L F
.725 .632 .754 r
.69243 .70566 m .69331 .70864 L .69578 .70595 L F
0 0 .044 r
.35365 .75304 m .3536 .75391 L .35165 .75348 L F
0 0 0 r
.57015 .78759 m .57082 .78682 L .57148 .78564 L F
.57015 .78759 m .5691 .7892 L .57082 .78682 L F
.092 .119 .596 r
.57147 .78846 m .57088 .78984 L .57015 .78759 L F
.511 .347 .595 r
.62076 .75333 m .62279 .75289 L .62267 .75066 L F
.609 .504 .709 r
.62093 .75594 m .62279 .75289 L .62076 .75333 L F
.341 .165 .491 r
.62427 .7428 m .62577 .74232 L .626 .74011 L F
.481 .357 .634 r
.62427 .7428 m .62616 .74469 L .62577 .74232 L F
.62427 .7428 m .62386 .74561 L .62616 .74469 L F
.618 .471 .66 r
.43531 .86131 m .43733 .85864 L .4351 .8589 L F
.861 .496 0 r
.66956 .72604 m .67104 .72923 L .66949 .72732 L F
.646 .513 .687 r
.41302 .75858 m .41507 .75611 L .41301 .75647 L F
.84 .676 .679 r
.56731 .81365 m .56883 .81739 L .56966 .81586 L F
.706 .601 .736 r
.42968 .87191 m .43118 .86909 L .42914 .86946 L F
.864 .962 .629 r
.5636 .83443 m .56224 .83749 L .56354 .83684 L F
.151 .194 .652 r
.56224 .83749 m .56381 .83996 L .56354 .83684 L F
.2 .623 .948 r
.65604 .62409 m .65788 .62434 L .65853 .62498 L F
.683 .796 .935 r
.65788 .62434 m .66073 .62462 L .65853 .62498 L F
.728 .691 .814 r
.42906 .88453 m .43237 .88488 L .43087 .88269 L F
.632 .707 .9 r
.43237 .88488 m .43304 .88201 L .43087 .88269 L F
.43237 .88488 m .4346 .88425 L .43304 .88201 L F
.824 .923 .901 r
.7054 .7527 m .70697 .75007 L .70495 .75289 L F
.7054 .7527 m .70799 .75072 L .70697 .75007 L F
.902 .759 .693 r
.61401 .81308 m .61366 .81113 L .61225 .81379 L F
.988 .888 .622 r
.61241 .81649 m .61401 .81308 L .61225 .81379 L F
.865 .996 .797 r
.58887 .82891 m .59078 .82787 L .58876 .83031 L F
.831 .989 .866 r
.58887 .82891 m .58876 .83031 L .5874 .83144 L F
.733 .57 .672 r
.69243 .70566 m .69584 .70377 L .69192 .70337 L F
.69243 .70566 m .69578 .70595 L .69584 .70377 L F
.67 .518 .67 r
.69584 .70377 m .69578 .70595 L .69758 .70333 L F
.987 .828 .443 r
.71584 .71657 m .71613 .71666 L .7161 .71366 L F
.521 0 0 r
.71613 .71666 m .71738 .71775 L .71584 .71657 L F
.127 .141 .605 r
.71793 .71622 m .71613 .71666 L .7161 .71366 L F
.106 .061 .519 r
.71793 .71622 m .71738 .71775 L .71613 .71666 L F
.215 0 0 r
.47001 .83207 m .47155 .83211 L .47272 .83053 L F
.39 0 .15 r
.47155 .83211 m .47415 .83091 L .47272 .83053 L F
.591 .493 .711 r
.42672 .74988 m .42467 .74863 L .42675 .74815 L F
.42672 .74988 m .42496 .75043 L .42467 .74863 L F
.098 .652 .794 r
.70658 .70324 m .70734 .70315 L .70944 .70327 L F
.70511 .70322 m .70734 .70315 L .70658 .70324 L F
0 .381 .705 r
.70734 .70315 m .70875 .70359 L .70877 .70299 L F
.614 .932 .964 r
.70944 .70327 m .70734 .70315 L .71023 .70191 L F
.691 .757 .902 r
.71023 .70191 m .70734 .70315 L .70644 .70178 L F
.71023 .70191 m .70644 .70178 L .70883 .70132 L F
0 .381 .705 r
.70734 .70315 m .70877 .70299 L .70883 .70132 L F
.386 .475 .829 r
.70656 .7056 m .70734 .70315 L .70511 .70322 L F
.70656 .7056 m .70798 .70531 L .70734 .70315 L F
.576 .432 .649 r
.63762 .72968 m .63529 .73214 L .63428 .73165 L F
.63762 .72968 m .63751 .73197 L .63529 .73214 L F
.27 .571 .938 r
.31996 .66265 m .32115 .66293 L .32105 .66381 L F
.174 .398 .84 r
.32184 .66298 m .32105 .66381 L .32115 .66293 L F
.562 .854 .997 r
.70897 .73617 m .70999 .73684 L .7078 .73745 L F
.534 .836 .516 r
.70897 .73617 m .7078 .73745 L .70597 .73928 L F
.592 .45 .657 r
.4334 .86421 m .43576 .86408 L .43531 .86131 L F
.557 .378 .595 r
.4334 .86421 m .43541 .86589 L .43576 .86408 L F
.4334 .86421 m .43346 .86635 L .43541 .86589 L F
.489 .769 .993 r
.38478 .7474 m .38683 .74716 L .38543 .74623 L F
.251 0 .105 r
.38546 .74684 m .38478 .7474 L .38543 .74623 L F
.338 .803 .93 r
.38601 .74761 m .38478 .7474 L .38445 .74767 L F
.197 .724 .834 r
.38809 .74722 m .38683 .74716 L .38478 .7474 L F
.251 0 .105 r
.38555 .74867 m .38478 .7474 L .38546 .74684 L F
.338 .803 .93 r
.38445 .74767 m .38478 .7474 L .38276 .74773 L F
.504 0 0 r
.67459 .76126 m .67372 .76131 L .67187 .76054 L F
.194 .692 .915 r
.67459 .76126 m .67588 .76093 L .67372 .76131 L F
.67459 .76126 m .67684 .76136 L .67588 .76093 L F
.506 .845 .997 r
.5691 .7892 m .56831 .79035 L .57088 .78984 L F
.637 .429 .584 r
.64303 .7297 m .64324 .73217 L .64066 .73206 L F
.24 .726 .926 r
.64182 .72892 m .64504 .72924 L .64303 .7297 L F
.504 .331 .579 r
.64504 .72924 m .64324 .73217 L .64303 .7297 L F
.662 .197 .138 r
.33644 .67671 m .33828 .67823 L .34028 .67687 L F
0 0 0 r
.34028 .67687 m .34065 .67623 L .34136 .67407 L F
.34028 .67687 m .34014 .67765 L .34065 .67623 L F
.34028 .67687 m .33828 .67823 L .34014 .67765 L F
.6727 .71669 m .67048 .71836 L .67094 .71633 L F
.682 .435 .542 r
.49424 .84247 m .49096 .8429 L .49125 .84028 L F
.816 .825 .857 r
.59363 .81695 m .59128 .81928 L .58968 .81869 L F
.664 .676 .852 r
.65839 .76201 m .66065 .76125 L .65728 .76054 L F
.333 0 .129 r
.58912 .82228 m .59037 .82365 L .58805 .82206 L F
.709 .68 .82 r
.68732 .73235 m .68933 .72984 L .6862 .72925 L F
.667 .616 .788 r
.68732 .73235 m .69106 .73337 L .68933 .72984 L F
.798 .725 .783 r
.68732 .73235 m .68491 .73139 L .68528 .73097 L F
.974 .71 .469 r
.68532 .73106 m .68732 .73235 L .68528 .73097 L F
.798 .725 .783 r
.68732 .73235 m .68532 .73106 L .68491 .73139 L F
0 .034 .602 r
.68491 .73139 m .68532 .73106 L .68528 .73097 L F
.798 .725 .783 r
.68532 .73106 m .68517 .73096 L .68491 .73139 L F
0 .034 .602 r
.68491 .73139 m .68723 .73504 L .68532 .73106 L F
.974 .71 .469 r
.68723 .73504 m .68732 .73235 L .68532 .73106 L F
.798 .725 .783 r
.68732 .73235 m .6862 .72925 L .68517 .73096 L F
.457 .769 .997 r
.47199 .88226 m .47325 .88311 L .47525 .88292 L F
.363 .766 .984 r
.37878 .72386 m .37822 .72461 L .37688 .72388 L F
.37878 .72386 m .38031 .72448 L .37822 .72461 L F
.561 .052 .001 r
.51294 .88393 m .51444 .88302 L .51598 .88386 L F
.545 .162 .267 r
.51444 .88302 m .51757 .88249 L .51598 .88386 L F
.715 .627 .757 r
.63145 .76632 m .6347 .76683 L .63362 .76374 L F
.588 .121 .113 r
.47688 .86347 m .4796 .8641 L .47728 .86388 L F
.621 .499 .693 r
.47785 .86274 m .4796 .8641 L .47688 .86347 L F
.795 .633 .681 r
.59918 .79548 m .59757 .79873 L .59618 .79518 L F
.607 .444 .635 r
.44752 .84041 m .44972 .84022 L .44941 .83691 L F
.661 .484 .634 r
.44941 .83691 m .45207 .83998 L .45212 .83773 L F
.44941 .83691 m .44972 .84022 L .45207 .83998 L F
.782 .556 .593 r
.58945 .77912 m .59271 .77709 L .58927 .77694 L F
.58945 .77912 m .59267 .77954 L .59271 .77709 L F
.692 .501 .624 r
.59267 .77954 m .59597 .77701 L .59271 .77709 L F
.574 .292 .45 r
.55197 .80506 m .55419 .80539 L .55532 .80235 L F
.696 .795 .325 r
.55532 .80235 m .55476 .80361 L .55613 .80038 L F
.574 .292 .451 r
.55532 .80235 m .55419 .80539 L .55476 .80361 L F
.475 .111 .267 r
.34781 .73153 m .3511 .72921 L .34911 .7296 L F
.605 .463 .661 r
.43678 .85398 m .43923 .85601 L .43861 .85295 L F
.43678 .85398 m .43699 .8563 L .43923 .85601 L F
.553 .351 .56 r
.43635 .75754 m .43451 .75543 L .43686 .75529 L F
.43635 .75754 m .43436 .75831 L .43451 .75543 L F
.881 .483 .034 r
.67268 .71997 m .67184 .71852 L .67199 .718 L F
0 0 0 r
.67225 .71703 m .67199 .718 L .67048 .71836 L F
.67199 .718 m .67026 .71912 L .67048 .71836 L F
.66908 .71998 m .67199 .718 L .67109 .71723 L F
.881 .483 .034 r
.67184 .71852 m .67109 .71723 L .67199 .718 L F
0 0 0 r
.6727 .71669 m .67199 .718 L .67225 .71703 L F
.137 .146 .605 r
.71331 .73032 m .71415 .73204 L .71399 .72896 L F
.651 .964 .794 r
.59571 .84699 m .59744 .84625 L .59868 .84515 L F
.894 .986 .79 r
.59147 .82669 m .59078 .82787 L .58887 .82891 L F
.565 .441 .671 r
.6277 .7355 m .62958 .73609 L .62994 .73457 L F
.88 .445 .11 r
.56122 .82507 m .56108 .82629 L .56027 .82436 L F
.56122 .82507 m .56229 .82693 L .56108 .82629 L F
.666 .865 .975 r
.65954 .75821 m .66112 .75867 L .66272 .75824 L F
.9 .719 .649 r
.65954 .75821 m .66065 .76125 L .66112 .75867 L F
.184 .711 .701 r
.58391 .84766 m .58673 .84692 L .58442 .84679 L F
.58391 .84766 m .58821 .84658 L .58673 .84692 L F
.099 .655 .744 r
.58391 .84766 m .59059 .84709 L .58821 .84658 L F
.254 0 .027 r
.57773 .81293 m .57801 .81077 L .57769 .81034 L F
.57773 .81293 m .57988 .81161 L .57801 .81077 L F
0 0 0 r
.35954 .79015 m .3598 .79106 L .36144 .78963 L F
.35954 .79015 m .35825 .79206 L .3598 .79106 L F
.987 .777 .535 r
.55304 .82667 m .55288 .82903 L .55408 .82961 L F
.976 .764 .553 r
.55288 .82903 m .55372 .83189 L .55408 .82961 L F
.821 .947 .904 r
.4682 .85396 m .46766 .85563 L .46999 .85568 L F
.77 .26 0 r
.46615 .85579 m .46976 .85849 L .46766 .85563 L F
.783 .523 .543 r
.46766 .85563 m .46976 .85849 L .47015 .85843 L F
.762 .637 .722 r
.54226 .79804 m .54034 .80079 L .54355 .80097 L F
.718 .543 .652 r
.54155 .80172 m .54355 .80097 L .54034 .80079 L F
.54155 .80172 m .54341 .80331 L .54355 .80097 L F
.574 .577 .818 r
.56731 .81365 m .56526 .81409 L .56403 .81104 L F
.9 .576 .423 r
.56526 .81409 m .56403 .81571 L .56557 .81597 L F
0 0 0 r
.56567 .8146 m .56526 .81409 L .56731 .81365 L F
.56567 .8146 m .56403 .81571 L .56526 .81409 L F
.666 .367 .456 r
.48213 .82683 m .48472 .8273 L .48587 .82532 L F
.638 .328 .43 r
.48587 .82532 m .4875 .82672 L .48739 .82561 L F
.442 .357 .665 r
.4875 .82672 m .48601 .82739 L .48587 .82532 L F
.635 .33 .437 r
.48587 .82532 m .48472 .8273 L .4875 .82672 L F
.473 .143 .325 r
.41042 .7746 m .40775 .77648 L .40833 .77484 L F
.571 .134 .171 r
.5002 .88243 m .50357 .88208 L .50228 .88286 L F
.565 .201 .309 r
.50357 .88208 m .50463 .88427 L .50228 .88286 L F
.50357 .88208 m .50564 .88224 L .50463 .88427 L F
.788 .415 .351 r
.54975 .85051 m .54851 .85284 L .5509 .85042 L F
.72 .619 .743 r
.64865 .7561 m .65236 .75713 L .65083 .7535 L F
.701 .604 .745 r
.65236 .75713 m .65286 .75289 L .65083 .7535 L F
.65236 .75713 m .654 .75591 L .65286 .75289 L F
.707 .47 .564 r
.59294 .79475 m .59084 .79283 L .59411 .79263 L F
.717 .493 .583 r
.59619 .79293 m .59294 .79475 L .59411 .79263 L F
.59619 .79293 m .59618 .79518 L .59294 .79475 L F
.642 .617 .809 r
.48999 .86186 m .48794 .86231 L .48739 .86115 L F
.495 .112 .242 r
.36593 .78728 m .36816 .78728 L .3694 .78511 L F
.363 0 .17 r
.3694 .78511 m .37015 .78671 L .37159 .78496 L F
.3694 .78511 m .36816 .78728 L .37015 .78671 L F
.973 .681 .285 r
.67104 .72923 m .67115 .73175 L .67194 .73196 L F
.875 .435 .106 r
.6718 .73317 m .67194 .73196 L .67115 .73175 L F
.6718 .73317 m .67325 .73494 L .67194 .73196 L F
.631 .907 .983 r
.53523 .84344 m .53652 .84424 L .53852 .8435 L F
.942 .734 .593 r
.56229 .82693 m .56341 .82989 L .56198 .82931 L F
.923 .888 .473 r
.5627 .83202 m .56246 .83153 L .56341 .82989 L F
.935 .619 .418 r
.56341 .82989 m .56246 .83153 L .56198 .82931 L F
.942 .734 .593 r
.56229 .82693 m .56341 .82989 L .56198 .82931 L F
.935 .619 .418 r
.56341 .82989 m .56246 .83153 L .56198 .82931 L F
.706 .623 .762 r
.49324 .86492 m .49296 .86747 L .49131 .86703 L F
.827 .515 .462 r
.49296 .86747 m .49198 .86862 L .49131 .86703 L F
.49296 .86747 m .49471 .86943 L .49198 .86862 L F
.447 .39 .701 r
.49552 .86605 m .49296 .86747 L .49324 .86492 L F
.606 .609 .828 r
.49552 .86605 m .49471 .86943 L .49296 .86747 L F
.582 .459 .678 r
.62439 .74783 m .62616 .74469 L .62386 .74561 L F
.664 .578 .748 r
.70952 .70849 m .71074 .71201 L .71299 .71116 L F
.626 .239 .291 r
.50653 .87921 m .50461 .87751 L .50457 .87955 L F
.546 .443 .689 r
.42851 .74492 m .4261 .74272 L .42801 .74239 L F
.42851 .74492 m .42654 .74534 L .4261 .74272 L F
.726 .71 .836 r
.53212 .84083 m .53284 .84339 L .53001 .84332 L F
.026 .597 .746 r
.53284 .84339 m .53239 .84334 L .53001 .84332 L F
.318 .467 .852 r
.53284 .84339 m .53413 .84226 L .53239 .84334 L F
.53284 .84339 m .53523 .84344 L .53413 .84226 L F
0 0 0 r
.53214 .82462 m .53254 .82407 L .53355 .8219 L F
.189 .639 .943 r
.53254 .82407 m .5337 .82479 L .53214 .82462 L F
.46 .131 .32 r
.40815 .76143 m .40548 .76357 L .40781 .76348 L F
.571 .312 .485 r
.40781 .76348 m .41066 .76058 L .40815 .76143 L F
.882 .757 .719 r
.61399 .80886 m .61318 .80599 L .61268 .80828 L F
.935 .764 .646 r
.61268 .80828 m .61366 .81113 L .61399 .80886 L F
.681 .196 .091 r
.58458 .78738 m .58268 .78723 L .5816 .78693 L F
.833 .572 .544 r
.58458 .78738 m .58293 .78953 L .58268 .78723 L F
.749 .451 .479 r
.58458 .78738 m .58628 .78989 L .58293 .78953 L F
.503 .223 .422 r
.42744 .76145 m .4271 .76301 L .42502 .7633 L F
.53 .286 .491 r
.42938 .76094 m .4271 .76301 L .42744 .76145 L F
.529 .823 .999 r
.64333 .73634 m .64188 .73756 L .64045 .73502 L F
.64333 .73634 m .64415 .73709 L .64188 .73756 L F
.567 .037 0 r
.54468 .80347 m .54507 .8035 L .54558 .80387 L F
.832 .653 .661 r
.54683 .80338 m .54576 .80399 L .54558 .80387 L F
.54683 .80338 m .54661 .80631 L .54382 .80509 L F
.186 .706 .877 r
.54558 .80387 m .5487 .804 L .54683 .80338 L F
.567 .037 0 r
.54507 .8035 m .54781 .80376 L .54558 .80387 L F
.832 .653 .661 r
.54576 .80399 m .54382 .80509 L .54558 .80387 L F
.051 .589 .852 r
.51024 .84698 m .51287 .84759 L .51165 .84585 L F
.279 0 .164 r
.36613 .803 m .3673 .80075 L .36898 .80024 L F
.588 .016 0 r
.57099 .84501 m .57251 .84524 L .57351 .84596 L F
.558 .666 .909 r
.36255 .75375 m .36456 .75334 L .36313 .75186 L F
.761 .326 0 r
.68443 .74817 m .68387 .74765 L .6825 .74512 L F
.872 .433 .126 r
.6825 .74512 m .68387 .74765 L .68275 .74722 L F
.07 0 0 r
.6864 .74724 m .68341 .74722 L .68387 .74765 L F
.68341 .74722 m .68275 .74722 L .68387 .74765 L F
.761 .326 0 r
.68471 .7486 m .68387 .74765 L .68443 .74817 L F
.644 .18 0 r
.68471 .7486 m .68564 .74992 L .68387 .74765 L F
.592 .13 .124 r
.3593 .75128 m .36135 .75198 L .35766 .75249 L F
.763 .604 .681 r
.492 .8767 m .49046 .87452 L .49019 .87727 L F
.939 .598 .354 r
.49174 .8792 m .492 .8767 L .49019 .87727 L F
.49174 .8792 m .49308 .87987 L .492 .8767 L F
.78 .924 .932 r
.38362 .72442 m .38425 .72207 L .38572 .72379 L F
.38362 .72442 m .3824 .72389 L .38425 .72207 L F
.672 .684 .852 r
.39237 .72649 m .3887 .72523 L .39125 .72529 L F
.553 .664 .911 r
.39318 .72419 m .39237 .72649 L .39125 .72529 L F
.39318 .72419 m .39431 .72621 L .39237 .72649 L F
.541 .122 .195 r
.49735 .83284 m .49955 .83381 L .50065 .83217 L F
.756 .469 .498 r
.49955 .83381 m .50278 .83243 L .50065 .83217 L F
.677 .553 .707 r
.61524 .76667 m .61314 .76919 L .61564 .76906 L F
.683 .474 .597 r
.61314 .76919 m .61564 .77138 L .61564 .76906 L F
.61314 .76919 m .61321 .77159 L .61564 .77138 L F
.431 .23 .505 r
.39991 .78138 m .39843 .77974 L .40064 .77964 L F
.39991 .78138 m .39815 .78188 L .39843 .77974 L F
.382 .794 .98 r
.4751 .86978 m .47309 .87005 L .47251 .86953 L F
.235 .753 .803 r
.48609 .88464 m .48719 .88458 L .48953 .88408 L F
.686 .624 .782 r
.68933 .72984 m .69106 .73337 L .69256 .73197 L F
.458 .414 .721 r
.32701 .67013 m .32603 .67382 L .32525 .67202 L F
.32701 .67013 m .32766 .67363 L .32603 .67382 L F
.293 0 0 r
.51757 .88249 m .51895 .88282 L .51598 .88386 L F
.51757 .88249 m .5195 .88234 L .51895 .88282 L F
.569 .525 .766 r
.5318 .81343 m .53281 .81663 L .53526 .81573 L F
.357 0 0 r
.51191 .88016 m .51094 .87958 L .50828 .88062 L F
0 0 0 r
.50828 .88062 m .51094 .87958 L .50978 .88004 L F
.511 .064 .124 r
.51084 .8815 m .51191 .88016 L .50925 .8805 L F
.50903 .88088 m .50925 .8805 L .50828 .88062 L F
.51084 .8815 m .50925 .8805 L .50903 .88088 L F
.459 .767 .996 r
.5079 .88283 m .50857 .88164 L .50758 .88335 L F
.511 .064 .124 r
.51084 .8815 m .50828 .88062 L .50857 .88164 L F
.459 .767 .996 r
.50941 .88042 m .51084 .8815 L .50857 .88164 L F
.50941 .88042 m .50869 .88147 L .5079 .88283 L F
.50869 .88147 m .50857 .88164 L .5079 .88283 L F
.579 .825 .451 r
.51162 .8805 m .51191 .88016 L .51084 .8815 L F
.51334 .8783 m .51191 .88016 L .51162 .8805 L F
.357 0 0 r
.51191 .88016 m .51311 .87989 L .51224 .87977 L F
.51191 .88016 m .51224 .87977 L .51094 .87958 L F
0 .457 .857 r
.71312 .70449 m .71099 .70398 L .71018 .70309 L F
.71312 .70449 m .71402 .70529 L .71099 .70398 L F
.989 .885 .621 r
.59209 .82437 m .59147 .82669 L .59078 .82608 L F
.938 .947 .616 r
.59209 .82437 m .59078 .82608 L .5925 .82218 L F
.482 0 0 r
.66885 .70693 m .67142 .70752 L .67106 .70551 L F
.646 .423 .567 r
.60055 .77683 m .60355 .77688 L .60356 .77439 L F
.704 .47 .568 r
.60356 .77439 m .60355 .77688 L .6058 .77657 L F
.696 .472 .579 r
.60356 .77439 m .6058 .77657 L .6058 .77445 L F
.927 .916 .785 r
.59545 .81404 m .59262 .81653 L .59404 .81366 L F
.59545 .81404 m .59363 .81695 L .59262 .81653 L F
.614 .932 .964 r
.70944 .70327 m .71023 .70191 L .71018 .70309 L F
.955 .634 .375 r
.68026 .719 m .68168 .72131 L .68133 .71909 L F
.647 .429 .574 r
.39784 .76826 m .40025 .76616 L .3983 .76659 L F
.925 .693 .568 r
.55971 .80015 m .56165 .80224 L .56171 .79817 L F
.435 .152 .383 r
.39621 .78229 m .3953 .78449 L .39379 .78448 L F
.465 .181 .397 r
.39815 .78188 m .3953 .78449 L .39621 .78229 L F
.65 .499 .665 r
.43118 .86909 m .43346 .86635 L .43105 .86663 L F
.236 .122 .513 r
.51376 .87498 m .51318 .87249 L .5142 .874 L F
0 .353 .725 r
.51621 .87591 m .51376 .87498 L .5142 .874 L F
.51621 .87591 m .51741 .87656 L .51376 .87498 L F
.428 .515 .846 r
.51741 .87656 m .51596 .87698 L .51376 .87498 L F
.724 .314 0 r
.55505 .81571 m .55364 .81334 L .5552 .81422 L F
.831 .989 .866 r
.58887 .82891 m .5874 .83144 L .58702 .83172 L F
.082 .588 .89 r
.47826 .88344 m .48053 .88349 L .47713 .88289 L F
.47826 .88344 m .48105 .88394 L .48053 .88349 L F
.1 .605 .897 r
.47826 .88344 m .48218 .88438 L .48105 .88394 L F
.381 .406 .761 r
.50442 .8616 m .50465 .86326 L .50635 .86356 L F
.725 .616 .735 r
.64323 .75612 m .64116 .75884 L .64343 .75816 L F
.727 .622 .74 r
.64343 .75816 m .64553 .75571 L .64323 .75612 L F
.614 .513 .716 r
.61698 .76176 m .61741 .76389 L .61946 .76147 L F
.871 .44 .178 r
.49048 .86785 m .49131 .86703 L .49198 .86862 L F
.356 0 .105 r
.34373 .75811 m .34058 .75999 L .34161 .75862 L F
.656 .438 .576 r
.43861 .85295 m .44137 .85326 L .44142 .85087 L F
.608 .493 .697 r
.44142 .85087 m .4436 .85062 L .44341 .8483 L F
.662 .443 .577 r
.44142 .85087 m .44377 .853 L .4436 .85062 L F
.44142 .85087 m .44137 .85326 L .44377 .853 L F
.517 .054 .095 r
.62938 .73101 m .6312 .73179 L .63225 .73042 L F
.145 0 0 r
.63225 .73042 m .63323 .73095 L .63428 .73165 L F
.63225 .73042 m .6312 .73179 L .63323 .73095 L F
.687 .509 .641 r
.6058 .77657 m .60884 .77436 L .6058 .77445 L F
.902 .521 .295 r
.6727 .71669 m .67343 .71856 L .67199 .718 L F
.624 .448 .623 r
.44752 .84041 m .44983 .84262 L .44972 .84022 L F
.44752 .84041 m .44759 .84291 L .44983 .84262 L F
.474 .084 .219 r
.6928 .74525 m .68966 .74727 L .69065 .74771 L F
.951 .657 .215 r
.68966 .74727 m .6908 .75074 L .69065 .74771 L F
.666 .865 .975 r
.65954 .75821 m .66272 .75824 L .66191 .75597 L F
.642 .634 .827 r
.66272 .75824 m .66387 .75499 L .66191 .75597 L F
.66272 .75824 m .66516 .75793 L .66387 .75499 L F
.515 .674 .936 r
.66272 .75824 m .66571 .75923 L .66516 .75793 L F
.446 .312 .604 r
.34024 .68117 m .3384 .6845 L .33798 .6823 L F
.754 .607 .695 r
.50278 .83243 m .50669 .83347 L .50512 .82959 L F
.762 .474 .497 r
.50586 .83442 m .50278 .83243 L .50669 .83347 L F
.526 .489 .758 r
.50512 .82959 m .50669 .83347 L .50866 .83258 L F
.094 0 0 r
.50669 .83347 m .50586 .83442 L .50866 .83258 L F
.211 .089 .486 r
.34228 .67642 m .34185 .67921 L .34074 .6796 L F
.303 0 .257 r
.34198 .68053 m .34074 .6796 L .34185 .67921 L F
.34198 .68053 m .34024 .68117 L .34074 .6796 L F
.666 .59 .761 r
.61741 .76389 m .61981 .76369 L .61946 .76147 L F
.664 .486 .634 r
.61748 .76622 m .61981 .76369 L .61741 .76389 L F
.657 .654 .836 r
.55267 .78192 m .54986 .78058 L .5521 .77924 L F
.844 .393 .138 r
.5521 .77924 m .55499 .78206 L .55267 .78192 L F
.094 0 0 r
.55388 .782 m .55267 .78192 L .55499 .78206 L F
.505 .441 .718 r
.32701 .67013 m .32525 .67202 L .32459 .66852 L F
.678 .601 .762 r
.41692 .8768 m .41974 .87753 L .41906 .87698 L F
.085 0 0 r
.41572 .87673 m .41906 .87698 L .41692 .8768 L F
.41572 .87673 m .41906 .87698 L .41692 .8768 L F
.721 .324 .297 r
.51572 .85791 m .514 .85613 L .51415 .85756 L F
.01 0 0 r
.48442 .88473 m .48399 .88479 L .48218 .88438 L F
.68 .499 .634 r
.49361 .85072 m .49365 .85344 L .4912 .85337 L F
.589 .426 .629 r
.49582 .85279 m .49361 .85072 L .4955 .85037 L F
.49582 .85279 m .49365 .85344 L .49361 .85072 L F
.738 .677 .792 r
.41516 .73284 m .4161 .73524 L .41282 .73463 L F
.58 .591 .829 r
.41736 .73292 m .4161 .73524 L .41516 .73284 L F
.558 .565 .816 r
.41736 .73292 m .41816 .735 L .4161 .73524 L F
.607 .518 .729 r
.6553 .76003 m .65636 .75548 L .654 .75591 L F
.6553 .76003 m .65759 .75905 L .65636 .75548 L F
.073 0 .358 r
.53355 .8219 m .53504 .82105 L .53541 .81872 L F
0 0 0 r
.53355 .8219 m .53254 .82407 L .53504 .82105 L F
.643 .622 .814 r
.32604 .66763 m .32459 .66852 L .32351 .66563 L F
.552 .43 .667 r
.32604 .66763 m .32697 .66814 L .32459 .66852 L F
.505 .441 .718 r
.32701 .67013 m .32459 .66852 L .32697 .66814 L F
.458 .035 .147 r
.51694 .85496 m .51602 .85319 L .51576 .85597 L F
.51694 .85496 m .51834 .85291 L .51602 .85319 L F
.739 .654 .765 r
.62825 .76618 m .63145 .76632 L .63037 .7634 L F
.744 .617 .718 r
.62934 .76905 m .63145 .76632 L .62825 .76618 L F
.73 .649 .769 r
.63037 .7634 m .63145 .76632 L .63362 .76374 L F
.292 .053 .369 r
.4875 .82672 m .48542 .82938 L .48601 .82739 L F
.771 .385 .325 r
.57437 .78292 m .57495 .7847 L .57235 .78256 L F
.754 .376 .337 r
.57783 .78479 m .57495 .7847 L .57437 .78292 L F
.19 0 0 r
.48218 .88438 m .48269 .88456 L .48105 .88394 L F
.48218 .88438 m .48399 .88479 L .48269 .88456 L F
.764 .908 .521 r
.65488 .62603 m .65475 .62572 L .65604 .62409 L F
.104 0 0 r
.65675 .6242 m .65604 .62409 L .65475 .62572 L F
.65675 .6242 m .65788 .62434 L .65604 .62409 L F
.499 .563 .852 r
.44065 .87669 m .44319 .88064 L .44383 .87935 L F
.695 .152 0 r
.56285 .80456 m .56476 .80544 L .5629 .80378 L F
.734 .683 .801 r
.64425 .7503 m .64747 .75073 L .6464 .7479 L F
.753 .629 .723 r
.64543 .75343 m .64747 .75073 L .64425 .7503 L F
.713 .571 .693 r
.64543 .75343 m .64892 .75421 L .64747 .75073 L F
.721 .676 .806 r
.6464 .7479 m .64747 .75073 L .64985 .74815 L F
.701 .643 .789 r
.64747 .75073 m .64984 .75033 L .64985 .74815 L F
.669 .55 .71 r
.64747 .75073 m .65083 .7535 L .64984 .75033 L F
.64747 .75073 m .64892 .75421 L .65083 .7535 L F
.814 .637 .663 r
.59084 .79283 m .5882 .79277 L .5895 .79023 L F
.734 .491 .56 r
.59084 .79283 m .58754 .79498 L .5882 .79277 L F
.59084 .79283 m .59103 .79528 L .58754 .79498 L F
.707 .47 .564 r
.59294 .79475 m .59103 .79528 L .59084 .79283 L F
.725 .344 .329 r
.56847 .83184 m .5719 .83241 L .57098 .83063 L F
.638 .709 .898 r
.5719 .83241 m .5725 .83077 L .57098 .83063 L F
.5719 .83241 m .57428 .8321 L .5725 .83077 L F
.603 .362 .525 r
.57406 .83444 m .5719 .83241 L .5708 .83433 L F
.57406 .83444 m .57428 .8321 L .5719 .83241 L F
.327 0 .236 r
.37928 .77992 m .3785 .78143 L .38107 .77937 L F
.475 .218 .444 r
.49015 .84789 m .49218 .84754 L .49236 .84582 L F
.427 .764 .996 r
.47895 .84207 m .48032 .84284 L .47808 .84299 L F
.47895 .84207 m .48032 .84284 L .47808 .84299 L F
.722 .616 .738 r
.62334 .77933 m .62622 .77965 L .62519 .77684 L F
.597 .21 .281 r
.64079 .72216 m .64297 .72345 L .64221 .72367 L F
.64079 .72216 m .64264 .72413 L .64019 .72447 L F
.64079 .72216 m .64383 .72169 L .64297 .72345 L F
.541 .772 .983 r
.64019 .72447 m .64207 .72318 L .64033 .72041 L F
.64207 .72318 m .64075 .72409 L .63955 .72433 L F
.64075 .72409 m .64019 .72447 L .63975 .72437 L F
.64075 .72409 m .63975 .72437 L .63955 .72433 L F
.597 .21 .281 r
.64221 .72367 m .64297 .72345 L .64264 .72413 L F
0 0 .442 r
.64415 .71758 m .64491 .72053 L .64383 .72169 L F
0 0 0 r
.64383 .72169 m .64491 .72053 L .64264 .72413 L F
.656 .211 0 r
.48833 .8329 m .48919 .83426 L .48963 .83473 L F
.825 .53 .49 r
.48919 .83426 m .49199 .83524 L .48963 .83473 L F
.55 .532 .787 r
.64039 .73278 m .63848 .73504 L .63751 .73197 L F
.521 .488 .761 r
.64039 .73278 m .64045 .73502 L .63848 .73504 L F
.509 .271 .489 r
.46925 .83433 m .47155 .83211 L .47001 .83207 L F
.694 .389 .454 r
.64628 .73885 m .64934 .73988 L .6495 .73689 L F
.122 0 .256 r
.6495 .73689 m .65176 .7355 L .65085 .73533 L F
.576 .289 .444 r
.6495 .73689 m .6518 .73892 L .65176 .7355 L F
.544 .451 .7 r
.65176 .7355 m .6518 .73892 L .65381 .73698 L F
.139 0 0 r
.65176 .7355 m .64962 .73552 L .65272 .73567 L F
.726 .694 .82 r
.65477 .7349 m .65269 .73573 L .65163 .73443 L F
.65477 .7349 m .65163 .73443 L .65372 .73445 L F
.649 .216 .206 r
.65372 .73445 m .65701 .7344 L .65477 .7349 L F
.65372 .73445 m .65576 .73635 L .65701 .7344 L F
0 .071 .593 r
.65523 .73569 m .65576 .73635 L .65372 .73445 L F
.65523 .73569 m .65372 .73445 L .65283 .73567 L F
.187 0 0 r
.65176 .7355 m .65372 .73445 L .65163 .73443 L F
.65176 .7355 m .65283 .73567 L .65372 .73445 L F
.92 .963 .789 r
.65283 .73567 m .654 .73234 L .65523 .73569 L F
0 0 0 r
.65433 .73495 m .65283 .73567 L .65523 .73569 L F
.65433 .73495 m .65382 .73543 L .65283 .73567 L F
.544 .451 .7 r
.65222 .73583 m .65307 .73644 L .65283 .73567 L F
.65307 .73644 m .65381 .73698 L .65283 .73567 L F
.586 .798 .98 r
.65381 .73698 m .65523 .73569 L .65283 .73567 L F
0 0 0 r
.65382 .73543 m .65187 .73727 L .65283 .73567 L F
.544 .451 .7 r
.65176 .7355 m .65222 .73583 L .65283 .73567 L F
.139 0 0 r
.65176 .7355 m .65272 .73567 L .65283 .73567 L F
.683 .268 .252 r
.65283 .73567 m .65187 .73727 L .64962 .73552 L F
.387 0 0 r
.64962 .73552 m .65178 .73591 L .65283 .73567 L F
.92 .963 .789 r
.65283 .73567 m .65178 .73591 L .65253 .7347 L F
.65283 .73567 m .65253 .7347 L .654 .73234 L F
.122 0 .256 r
.65085 .73533 m .65176 .7355 L .65163 .73443 L F
.576 .289 .444 r
.6495 .73689 m .64934 .73988 L .6518 .73892 L F
.756 .654 .748 r
.63791 .75844 m .64116 .75884 L .64 .75578 L F
.758 .648 .741 r
.63791 .75844 m .63917 .76158 L .64116 .75884 L F
.749 .65 .752 r
.64 .75578 m .64116 .75884 L .64323 .75612 L F
.24 0 0 r
.46985 .86699 m .46917 .86702 L .46649 .86655 L F
.46985 .86699 m .46917 .86702 L .46649 .86655 L F
.721 .55 .657 r
.46985 .86699 m .46986 .87014 L .46667 .86865 L F
.647 .852 .978 r
.47071 .86584 m .46985 .86699 L .47256 .866 L F
.727 .99 .86 r
.47071 .86584 m .46917 .86702 L .46985 .86699 L F
.623 .547 .748 r
.46985 .86699 m .473 .8691 L .47256 .866 L F
.779 .358 .25 r
.47944 .86367 m .4796 .8641 L .47785 .86274 L F
.489 .125 .273 r
.35312 .72884 m .35527 .72869 L .35661 .72639 L F
.277 0 .151 r
.35661 .72639 m .35712 .72804 L .35857 .72647 L F
.35661 .72639 m .35527 .72869 L .35712 .72804 L F
.403 .797 .987 r
.52496 .87617 m .52396 .87697 L .52281 .87695 L F
.52496 .87617 m .52643 .87673 L .52396 .87697 L F
.982 .787 .567 r
.52344 .87902 m .52396 .87697 L .52281 .87695 L F
.4 0 .076 r
.52396 .87697 m .52455 .87851 L .52281 .87695 L F
.52396 .87697 m .52643 .87673 L .52455 .87851 L F
.875 .923 .854 r
.52869 .8548 m .53048 .8547 L .53164 .85293 L F
.287 .784 .759 r
.71399 .72896 m .71542 .72846 L .71642 .7283 L F
.346 .543 .904 r
.7185 .72703 m .71642 .7283 L .71542 .72846 L F
.7185 .72703 m .7203 .72945 L .71642 .7283 L F
.654 .122 0 r
.48798 .85541 m .48465 .85403 L .48585 .85362 L F
.618 .297 .404 r
.48756 .85374 m .48798 .85541 L .48585 .85362 L F
.565 .564 .811 r
.65636 .75548 m .65286 .75289 L .654 .75591 L F
.618 .471 .66 r
.43531 .86131 m .43758 .86125 L .43733 .85864 L F
.568 .433 .657 r
.43531 .86131 m .43752 .86357 L .43758 .86125 L F
.43531 .86131 m .43576 .86408 L .43752 .86357 L F
.406 .283 .599 r
.64526 .71623 m .64546 .71915 L .64415 .71758 L F
.685 .361 .421 r
.64415 .71758 m .64546 .71915 L .64491 .72053 L F
.965 .886 .703 r
.59864 .80354 m .59679 .80478 L .59713 .80284 L F
.59864 .80354 m .59771 .80554 L .59679 .80478 L F
.607 .406 .584 r
.41066 .76058 m .41285 .76059 L .41302 .75858 L F
.646 .513 .687 r
.41302 .75858 m .41533 .75841 L .41507 .75611 L F
.505 .243 .451 r
.41285 .76059 m .41533 .75841 L .41302 .75858 L F
.763 .651 .738 r
.63584 .76124 m .63917 .76158 L .63791 .75844 L F
.716 .48 .567 r
.53367 .81143 m .53704 .81367 L .53705 .8113 L F
.77 .554 .605 r
.53705 .8113 m .53704 .81367 L .54029 .81393 L F
.485 .292 .543 r
.62279 .75289 m .62485 .75027 L .62267 .75066 L F
.813 .85 .877 r
.51379 .81731 m .5113 .81992 L .50989 .81872 L F
.583 .795 .98 r
.50989 .81872 m .5113 .81992 L .51351 .81935 L F
.636 .4 .543 r
.45961 .83671 m .46189 .83457 L .4598 .8347 L F
0 0 0 r
.5195 .88234 m .52219 .88029 L .52066 .88175 L F
.127 .281 .752 r
.52455 .87851 m .52344 .87902 L .52281 .87695 L F
0 0 0 r
.52318 .8796 m .52344 .87902 L .52455 .87851 L F
.469 .325 .603 r
.5242 .8782 m .52318 .8796 L .52455 .87851 L F
.52281 .87695 m .52313 .87928 L .5242 .8782 L F
.52313 .87928 m .52318 .8796 L .5242 .8782 L F
.533 .844 .535 r
.5217 .88072 m .52219 .88029 L .52344 .87902 L F
.52066 .88175 m .52117 .88126 L .5217 .88072 L F
.52117 .88126 m .52219 .88029 L .5217 .88072 L F
.605 .4 .577 r
.5318 .81343 m .53367 .81143 L .53176 .81105 L F
.5318 .81343 m .53402 .81441 L .53367 .81143 L F
.716 .48 .567 r
.53367 .81143 m .53402 .81441 L .53704 .81367 L F
.585 .585 .819 r
.66571 .75923 m .66639 .7559 L .66516 .75793 L F
.66571 .75923 m .66754 .75895 L .66639 .7559 L F
.391 .033 .233 r
.34614 .75638 m .34578 .75765 L .34373 .75811 L F
.503 .132 .27 r
.34614 .75638 m .34801 .75745 L .34578 .75765 L F
.793 .878 .909 r
.63539 .72602 m .63981 .72444 L .63655 .72482 L F
.512 .338 .582 r
.53112 .83513 m .53127 .83756 L .53328 .83709 L F
.767 .653 .737 r
.53704 .81367 m .5382 .81687 L .54029 .81393 L F
.54 .349 .571 r
.54029 .81393 m .5382 .81687 L .54026 .81638 L F
.979 .681 .341 r
.56159 .7851 m .56069 .78454 L .5604 .78202 L F
.858 .947 .873 r
.56159 .7851 m .56384 .78216 L .5604 .78202 L F
.56159 .7851 m .56288 .78255 L .56384 .78216 L F
.56159 .7851 m .56069 .78454 L .56288 .78255 L F
0 0 0 r
.51895 .88282 m .5195 .88234 L .52066 .88175 L F
.719 .596 .718 r
.64553 .75571 m .64543 .75343 L .64323 .75612 L F
.7 .567 .702 r
.64553 .75571 m .64892 .75421 L .64543 .75343 L F
.64553 .75571 m .64865 .7561 L .64892 .75421 L F
.941 .847 .412 r
.57402 .82975 m .57429 .82601 L .57346 .8294 L F
.519 .395 .652 r
.57428 .8321 m .57613 .83168 L .57402 .82975 L F
.57402 .82975 m .57613 .83168 L .57428 .8321 L F
.468 .186 .402 r
.38344 .77693 m .38541 .77664 L .38626 .77403 L F
.401 .019 .195 r
.38541 .77664 m .38859 .77432 L .38626 .77403 L F
.444 .508 .83 r
.43089 .74737 m .43037 .75033 L .42885 .74782 L F
.43089 .74737 m .43226 .75058 L .43037 .75033 L F
.685 .795 .933 r
.41906 .87698 m .42232 .87713 L .41974 .87753 L F
.567 .538 .783 r
.41974 .87753 m .42263 .87974 L .42232 .87713 L F
.526 .489 .758 r
.50512 .82959 m .50866 .83258 L .50885 .82986 L F
.115 0 0 r
.51586 .82768 m .51657 .82848 L .51804 .8273 L F
.51586 .82768 m .51485 .82908 L .51657 .82848 L F
.538 .307 .513 r
.41474 .77341 m .41311 .77175 L .41527 .77144 L F
.41474 .77341 m .41284 .77389 L .41311 .77175 L F
.638 .68 .873 r
.42693 .73701 m .42479 .73754 L .42388 .73586 L F
.575 .529 .767 r
.42753 .7389 m .42479 .73754 L .42693 .73701 L F
.571 .312 .485 r
.40781 .76348 m .41002 .76337 L .41066 .76058 L F
.525 .241 .426 r
.41002 .76337 m .41285 .76059 L .41066 .76058 L F
.484 .206 .416 r
.48166 .86365 m .47944 .86367 L .48109 .86018 L F
.48166 .86365 m .4796 .8641 L .47944 .86367 L F
.673 .593 .757 r
.46667 .86865 m .46986 .87014 L .46779 .87139 L F
.621 .441 .617 r
.42502 .7633 m .42518 .76819 L .42197 .76786 L F
.525 .357 .597 r
.4271 .76301 m .42518 .76819 L .42502 .7633 L F
.527 .27 .469 r
.38859 .77432 m .39071 .77406 L .39116 .77197 L F
.455 .205 .445 r
.39116 .77197 m .39261 .77356 L .39308 .7716 L F
.39116 .77197 m .39071 .77406 L .39261 .77356 L F
.816 .825 .857 r
.59363 .81695 m .58968 .81869 L .59262 .81653 L F
.692 .501 .624 r
.59267 .77954 m .59617 .77958 L .59597 .77701 L F
.724 .525 .621 r
.59597 .77701 m .59832 .77934 L .59814 .77698 L F
.59597 .77701 m .59617 .77958 L .59832 .77934 L F
.159 0 .254 r
.71519 .72127 m .7128 .72459 L .71526 .72253 L F
.017 0 .132 r
.33651 .68949 m .33446 .69223 L .33529 .69042 L F
.386 .51 .861 r
.674 .71124 m .67685 .7139 L .67717 .7111 L F
.567 .296 .465 r
.43909 .75342 m .43883 .75514 L .43686 .75529 L F
.624 .532 .729 r
.44095 .75072 m .43909 .75342 L .43883 .75119 L F
.501 .238 .448 r
.43909 .75342 m .44087 .7549 L .43883 .75514 L F
.608 .51 .717 r
.44095 .75072 m .44126 .75358 L .43909 .75342 L F
.572 .213 .321 r
.44126 .75358 m .44087 .7549 L .43909 .75342 L F
.62 .514 .712 r
.61524 .76667 m .61787 .76862 L .61748 .76622 L F
.61524 .76667 m .61564 .76906 L .61787 .76862 L F
.573 .451 .675 r
.42851 .74492 m .42675 .74815 L .42654 .74534 L F
.968 .76 .569 r
.6767 .7323 m .67645 .73454 L .6755 .73155 L F
.45 0 0 r
.56686 .78237 m .56575 .78264 L .56384 .78216 L F
0 0 0 r
.56793 .78216 m .56686 .78237 L .56914 .78237 L F
.56793 .78216 m .56575 .78264 L .56686 .78237 L F
.55 .753 .971 r
.66258 .73668 m .66179 .73794 L .66029 .73701 L F
.177 .363 .811 r
.56161 .77883 m .56201 .78128 L .56096 .7798 L F
.863 .875 .845 r
.56466 .77737 m .56201 .78128 L .56161 .77883 L F
.535 .872 .991 r
.64419 .71127 m .64605 .71057 L .64695 .71109 L F
.538 .382 .617 r
.64908 .71063 m .64726 .71348 L .64695 .71109 L F
.401 .17 .445 r
.51151 .85251 m .50991 .851 L .51214 .85057 L F
.51151 .85251 m .50968 .85321 L .50991 .851 L F
.609 .504 .709 r
.62093 .75594 m .62356 .75592 L .62279 .75289 L F
.617 .484 .677 r
.62147 .75859 m .62356 .75592 L .62093 .75594 L F
.618 .383 .538 r
.42232 .87713 m .42438 .8793 L .42475 .87709 L F
.484 .372 .651 r
.42232 .87713 m .42263 .87974 L .42438 .8793 L F
.684 .41 .501 r
.58434 .77719 m .58737 .77888 L .58733 .7768 L F
.685 .44 .546 r
.58737 .77888 m .58927 .77694 L .58733 .7768 L F
.655 .556 .731 r
.64984 .75033 m .65176 .74767 L .64985 .74815 L F
.64984 .75033 m .653 .75091 L .65176 .74767 L F
.695 .551 .687 r
.64984 .75033 m .65286 .75289 L .653 .75091 L F
.64984 .75033 m .65083 .7535 L .65286 .75289 L F
.335 .544 .907 r
.4145 .74346 m .41563 .74233 L .41397 .7421 L F
.4145 .74346 m .41743 .74478 L .41563 .74233 L F
.466 .717 .978 r
.45365 .88184 m .45479 .88099 L .45276 .88101 L F
.45365 .88184 m .45592 .88192 L .45479 .88099 L F
.473 0 0 r
.45365 .88184 m .4581 .88335 L .45592 .88192 L F
.663 .533 .695 r
.64892 .75421 m .64865 .7561 L .65083 .7535 L F
.417 0 .009 r
.36064 .72614 m .36273 .72616 L .36427 .7248 L F
.373 0 0 r
.36427 .7248 m .36594 .72515 L .36644 .72463 L F
.36427 .7248 m .36273 .72616 L .36594 .72515 L F
.552 .843 .998 r
.50995 .87166 m .51331 .87191 L .5108 .86908 L F
.878 .602 .515 r
.51318 .87249 m .51331 .87191 L .5108 .86908 L F
.965 .709 .497 r
.67595 .72691 m .67467 .7285 L .6753 .72467 L F
.67595 .72691 m .67593 .72931 L .67467 .7285 L F
.484 .272 .515 r
.42719 .87506 m .42887 .87482 L .42968 .87191 L F
.706 .601 .736 r
.42968 .87191 m .43208 .87193 L .43118 .86909 L F
.675 .447 .568 r
.42887 .87482 m .43208 .87193 L .42968 .87191 L F
.42887 .87482 m .43195 .87422 L .43208 .87193 L F
.64 .563 .752 r
.43118 .86909 m .43208 .87193 L .43391 .86936 L F
.645 .569 .755 r
.43208 .87193 m .43448 .87185 L .43391 .86936 L F
.735 .573 .673 r
.43195 .87422 m .43448 .87185 L .43208 .87193 L F
.353 .442 .814 r
.3293 .67337 m .3292 .67635 L .32766 .67363 L F
.3293 .67337 m .33075 .67677 L .3292 .67635 L F
.684 .542 .687 r
.61564 .77138 m .61787 .76862 L .61564 .76906 L F
.596 .83 .988 r
.69329 .72505 m .69146 .72636 L .69089 .7252 L F
.69329 .72505 m .69381 .72563 L .69146 .72636 L F
.304 .135 .479 r
.51537 .8338 m .51386 .83214 L .51652 .83154 L F
.51537 .8338 m .51369 .83518 L .51386 .83214 L F
.872 .433 .126 r
.6825 .74512 m .68275 .74722 L .68126 .74457 L F
0 .214 .738 r
.65062 .70895 m .65131 .71029 L .64913 .70831 L F
.556 .354 .562 r
.64913 .70831 m .65131 .71029 L .64908 .71063 L F
0 .214 .738 r
.65062 .70895 m .64913 .70831 L .64919 .7093 L F
.766 .628 .707 r
.62612 .76873 m .62934 .76905 L .62825 .76618 L F
.763 .65 .737 r
.62612 .76873 m .62726 .77172 L .62934 .76905 L F
.735 .689 .806 r
.64 .75578 m .64323 .75612 L .6423 .75338 L F
.792 .712 .776 r
.64323 .75612 m .64404 .75246 L .6423 .75338 L F
.64323 .75612 m .64543 .75343 L .64404 .75246 L F
.904 .985 .766 r
.60805 .83118 m .60801 .83276 L .60984 .82994 L F
.883 .859 .408 r
.6074 .83465 m .60801 .83276 L .60805 .83118 L F
.463 0 0 r
.48953 .88408 m .4927 .88465 L .49154 .88441 L F
.256 .751 .907 r
.4927 .88465 m .49484 .88447 L .49154 .88441 L F
.542 .305 .505 r
.41525 .92671 m .41595 .92483 L .41342 .92491 L F
.774 .593 .654 r
.56293 .8083 m .56635 .80611 L .56476 .80544 L F
.45 .819 .993 r
.57783 .84741 m .57985 .84678 L .57698 .84709 L F
.57783 .84741 m .58123 .84712 L .57985 .84678 L F
.88 .713 .67 r
.67944 .75835 m .68037 .75542 L .67809 .7553 L F
.565 .105 .121 r
.48647 .8482 m .48843 .84938 L .49015 .84789 L F
0 0 0 r
.48843 .84938 m .49218 .84754 L .49015 .84789 L F
.43 .07 .252 r
.39117 .78558 m .39059 .78699 L .3885 .78727 L F
.447 .087 .26 r
.39269 .7866 m .39117 .78558 L .39379 .78448 L F
.39269 .7866 m .39059 .78699 L .39117 .78558 L F
.856 .675 .656 r
.64404 .75246 m .64543 .75343 L .64425 .7503 L F
.824 .701 .729 r
.6217 .78678 m .62076 .78399 L .61879 .787 L F
.6217 .78678 m .62216 .78505 L .62076 .78399 L F
.811 .708 .751 r
.61879 .787 m .6198 .78978 L .6217 .78678 L F
.765 .906 .517 r
.65304 .62867 m .65488 .62603 L .65318 .62891 L F
.65304 .62867 m .65475 .62572 L .65488 .62603 L F
.932 .867 .752 r
.6959 .72588 m .69714 .72707 L .69723 .72546 L F
.989 .728 .429 r
.6959 .72588 m .69699 .72905 L .69714 .72707 L F
.884 .651 .58 r
.62076 .78399 m .62216 .78505 L .62098 .78237 L F
.588 .524 .75 r
.41818 .88446 m .42001 .88236 L .41786 .88254 L F
.41818 .88446 m .42022 .88428 L .42001 .88236 L F
0 0 0 r
.66188 .71102 m .66203 .71022 L .66221 .70768 L F
.75 .505 .562 r
.54308 .83826 m .53983 .83747 L .54235 .83712 L F
.54308 .83826 m .54036 .84132 L .53983 .83747 L F
.807 .805 .85 r
.54443 .83648 m .54308 .83826 L .54235 .83712 L F
.735 .374 0 r
.67513 .72367 m .67379 .72069 L .67485 .7215 L F
.612 .503 .706 r
.43699 .8563 m .43733 .85864 L .43923 .85601 L F
.298 .793 .852 r
.52742 .87373 m .52665 .87406 L .52858 .87349 L F
.421 .145 .386 r
.33464 .67717 m .33414 .67889 L .33644 .67671 L F
.547 .92 .938 r
.5604 .78202 m .56161 .77883 L .56096 .7798 L F
.632 .658 .858 r
.51854 .87767 m .51596 .87698 L .51741 .87656 L F
.798 .395 .288 r
.49198 .86862 m .49471 .86943 L .49366 .87104 L F
.606 .609 .828 r
.49552 .86605 m .49705 .86893 L .49471 .86943 L F
.993 .827 .575 r
.49366 .87104 m .49326 .8734 L .49228 .87307 L F
.49366 .87104 m .49228 .87307 L .49277 .87241 L F
.49366 .87104 m .49277 .87241 L .4943 .8703 L F
.618 .177 .18 r
.49471 .86943 m .49471 .86943 L .49366 .87104 L F
.49471 .86943 m .49779 .8709 L .49366 .87104 L F
.894 .497 .063 r
.49705 .86893 m .49779 .8709 L .49471 .86943 L F
.749 .446 .47 r
.53619 .81708 m .53371 .8181 L .53526 .81573 L F
.447 .283 .565 r
.53541 .81872 m .53657 .81691 L .5382 .81687 L F
.53657 .81691 m .53714 .81601 L .53765 .81642 L F
.53657 .81691 m .53765 .81642 L .5382 .81687 L F
.53541 .81872 m .53705 .81831 L .53714 .81601 L F
.749 .446 .47 r
.53705 .81831 m .53392 .81812 L .53619 .81708 L F
.53392 .81812 m .53371 .8181 L .53619 .81708 L F
.569 .816 .991 r
.54026 .81638 m .5382 .81687 L .53714 .81601 L F
.317 0 0 r
.5711 .78168 m .56793 .78216 L .56914 .78237 L F
.614 .788 .965 r
.42962 .73653 m .43019 .73743 L .42693 .73701 L F
.589 .495 .717 r
.42941 .73847 m .42693 .73701 L .43019 .73743 L F
.313 .606 .951 r
.42962 .73653 m .43092 .73644 L .43019 .73743 L F
.56 .521 .768 r
.43092 .73644 m .42941 .73847 L .43019 .73743 L F
0 .497 .814 r
.50147 .84982 m .50245 .85028 L .50163 .84985 L F
.798 .349 0 r
.50245 .85028 m .5037 .85245 L .50163 .84985 L F
.50245 .85028 m .50405 .853 L .5037 .85245 L F
.853 .643 .618 r
.50163 .84985 m .5037 .85245 L .49994 .85271 L F
.729 .55 .649 r
.50175 .85173 m .50339 .85015 L .50163 .84985 L F
.50339 .85015 m .50418 .84938 L .50163 .84985 L F
0 .497 .814 r
.50141 .84979 m .50147 .84982 L .50163 .84985 L F
.627 .641 .845 r
.40311 .7287 m .40094 .72936 L .39945 .72675 L F
.553 .213 .347 r
.3536 .75391 m .35012 .75749 L .34801 .75745 L F
0 0 .044 r
.35365 .75304 m .35365 .75416 L .3536 .75391 L F
.508 .213 .4 r
.35365 .75416 m .35012 .75749 L .3536 .75391 L F
0 0 0 r
.6279 .73823 m .626 .74011 L .62756 .73902 L F
.187 .039 .435 r
.626 .74011 m .62743 .74057 L .62756 .73902 L F
.626 .74011 m .62577 .74232 L .62743 .74057 L F
.568 .275 .43 r
.52959 .82654 m .52632 .82911 L .52662 .82725 L F
.473 .171 .372 r
.37702 .79478 m .37582 .79782 L .37381 .79813 L F
.542 .24 .404 r
.37803 .79635 m .37702 .79478 L .37869 .7948 L F
.37803 .79635 m .37582 .79782 L .37702 .79478 L F
.817 .689 .723 r
.66102 .72681 m .65812 .72649 L .65968 .72365 L F
.821 .66 .684 r
.66102 .72681 m .65985 .72942 L .65812 .72649 L F
.746 .63 .732 r
.64066 .73206 m .63751 .73197 L .63992 .72892 L F
.55 .532 .787 r
.64039 .73278 m .63751 .73197 L .64066 .73206 L F
.426 .258 .549 r
.64219 .73126 m .64066 .73206 L .64324 .73217 L F
.64219 .73126 m .64039 .73278 L .64066 .73206 L F
.76 .659 .75 r
.61983 .77905 m .62334 .77933 L .62209 .77629 L F
.761 .654 .744 r
.61983 .77905 m .62098 .78237 L .62334 .77933 L F
.747 .653 .756 r
.62209 .77629 m .62334 .77933 L .62519 .77684 L F
.352 .422 .794 r
.48624 .8592 m .48885 .86089 L .48739 .86115 L F
.642 .617 .809 r
.48999 .86186 m .48739 .86115 L .48885 .86089 L F
.455 .09 .256 r
.39479 .78628 m .39379 .78448 L .3953 .78449 L F
.39479 .78628 m .39269 .7866 L .39379 .78448 L F
.245 0 0 r
.34812 .66623 m .35056 .66643 L .35145 .66624 L F
.211 0 0 r
.34978 .66652 m .35056 .66643 L .34812 .66623 L F
.219 0 0 r
.35145 .66624 m .34978 .66652 L .34812 .66623 L F
.498 .169 .339 r
.3525 .66519 m .34978 .66652 L .35145 .66624 L F
.569 .938 .831 r
.35145 .66624 m .35056 .66643 L .3525 .66519 L F
.184 0 .125 r
.69521 .72991 m .69473 .73076 L .69699 .72905 L F
.783 .594 .644 r
.57923 .81651 m .57635 .81891 L .57723 .81632 L F
.663 .636 .812 r
.57775 .81742 m .57917 .81498 L .57748 .81561 L F
.57745 .81569 m .57748 .81561 L .57744 .81562 L F
.57775 .81742 m .57748 .81561 L .57745 .81569 L F
.783 .594 .644 r
.57723 .81632 m .57588 .8193 L .57598 .81621 L F
.57635 .81891 m .57588 .8193 L .57723 .81632 L F
.57923 .81651 m .57902 .81927 L .57588 .8193 L F
.808 .577 .588 r
.57923 .81651 m .58158 .8198 L .57902 .81927 L F
0 0 0 r
.71742 .73215 m .72001 .72983 L .7193 .73142 L F
.031 0 .031 r
.71742 .73215 m .71657 .73374 L .71753 .73444 L F
.71742 .73215 m .71829 .73288 L .71657 .73374 L F
.71742 .73215 m .7193 .73142 L .71829 .73288 L F
.812 .376 .207 r
.48415 .85875 m .48534 .86026 L .48624 .8592 L F
.267 .72 .956 r
.48534 .86026 m .48885 .86089 L .48624 .8592 L F
.849 .735 .737 r
.61098 .81118 m .61366 .81113 L .61268 .80828 L F
.851 .7 .695 r
.61225 .81379 m .61366 .81113 L .61098 .81118 L F
.368 .747 .989 r
.58821 .84658 m .59059 .84709 L .59184 .84704 L F
.64 .624 .818 r
.70798 .70531 m .70952 .70849 L .71167 .70791 L F
.664 .578 .748 r
.70952 .70849 m .71299 .71116 L .71167 .70791 L F
.792 .655 .711 r
.42652 .8765 m .42887 .87482 L .42719 .87506 L F
.218 0 0 r
.51979 .8785 m .52065 .87716 L .51854 .87767 L F
.834 .598 .582 r
.67595 .74436 m .67848 .74327 L .67803 .74179 L F
.67595 .74436 m .67986 .74541 L .67848 .74327 L F
.829 .414 .254 r
.68126 .74457 m .67803 .74179 L .67848 .74327 L F
.427 0 0 r
.56466 .77737 m .56624 .77852 L .56787 .77688 L F
.19 0 0 r
.56787 .77688 m .56871 .77764 L .56992 .77635 L F
.56787 .77688 m .56624 .77852 L .56871 .77764 L F
.954 .745 .581 r
.61659 .80035 m .61549 .79751 L .61542 .80051 L F
.912 .824 .747 r
.61495 .80339 m .61659 .80035 L .61542 .80051 L F
.894 .986 .79 r
.59147 .82669 m .58887 .82891 L .59078 .82608 L F
.557 .849 .525 r
.72108 .7286 m .72001 .72983 L .7203 .72945 L F
0 0 0 r
.7193 .73142 m .72001 .72983 L .72108 .7286 L F
.656 .705 .884 r
.4276 .88202 m .42906 .88453 L .43087 .88269 L F
.907 .811 .741 r
.60856 .82911 m .61105 .82691 L .61078 .82652 L F
.60856 .82911 m .60984 .82994 L .61105 .82691 L F
.791 .571 .603 r
.53001 .84332 m .52672 .84012 L .52909 .83975 L F
.53001 .84332 m .52687 .84316 L .52672 .84012 L F
.31 0 0 r
.53001 .84332 m .52826 .84349 L .52687 .84316 L F
.654 .597 .779 r
.53212 .84083 m .53001 .84332 L .52909 .83975 L F
.368 .699 .983 r
.53001 .84332 m .53107 .84214 L .52826 .84349 L F
.53001 .84332 m .53239 .84334 L .53107 .84214 L F
.214 .034 .407 r
.48739 .82561 m .48903 .82522 L .48896 .82405 L F
.48739 .82561 m .4875 .82672 L .48903 .82522 L F
.348 .458 .831 r
.48146 .85965 m .48293 .86116 L .48109 .86018 L F
.48146 .85965 m .48391 .86112 L .48244 .85792 L F
.48146 .85965 m .48244 .85792 L .48293 .86116 L F
.787 .667 .731 r
.61761 .78177 m .62098 .78237 L .61983 .77905 L F
.771 .589 .652 r
.61761 .78177 m .62076 .78399 L .62098 .78237 L F
.644 .546 .729 r
.43733 .85864 m .43967 .85854 L .43923 .85601 L F
.606 .442 .633 r
.43758 .86125 m .43967 .85854 L .43733 .85864 L F
.98 .686 .358 r
.49447 .8496 m .49525 .84822 L .49218 .84754 L F
.49447 .8496 m .4955 .85037 L .49525 .84822 L F
0 .437 .843 r
.49525 .84822 m .50001 .85051 L .49728 .84789 L F
.848 .683 .678 r
.5895 .79023 m .58625 .79194 L .58628 .78989 L F
.5895 .79023 m .5882 .79277 L .58625 .79194 L F
.095 .652 .77 r
.40107 .74282 m .39945 .74282 L .39773 .74291 L F
.578 .062 0 r
.40316 .7431 m .39945 .74282 L .40107 .74282 L F
.491 .542 .837 r
.44 .74962 m .43883 .75119 L .43817 .74973 L F
.624 .532 .729 r
.44095 .75072 m .43883 .75119 L .44 .74962 L F
.486 .287 .535 r
.3302 .69518 m .32811 .69786 L .33011 .69521 L F
.3302 .69518 m .32993 .69732 L .32811 .69786 L F
.371 .135 .42 r
.32993 .69732 m .32783 .70004 L .32811 .69786 L F
.832 .635 .636 r
.53473 .83217 m .53315 .8295 L .53462 .82944 L F
.53473 .83217 m .53294 .832 L .53315 .8295 L F
.785 .625 .682 r
.53315 .8295 m .53473 .83217 L .53462 .82944 L F
.446 0 0 r
.53748 .83317 m .53397 .83331 L .53473 .83217 L F
.473 .008 .069 r
.53848 .83185 m .53748 .83317 L .53473 .83217 L F
0 0 0 r
.35155 .79448 m .35263 .79416 L .35454 .7932 L F
.412 .837 .678 r
.35454 .7932 m .35506 .79277 L .35632 .79257 L F
.35454 .7932 m .35263 .79416 L .35506 .79277 L F
.746 .416 .425 r
.58065 .77682 m .58434 .77719 L .58221 .77668 L F
.78 .498 .508 r
.58093 .77874 m .58434 .77719 L .58065 .77682 L F
.58093 .77874 m .58412 .77911 L .58434 .77719 L F
.684 .41 .501 r
.58434 .77719 m .58412 .77911 L .58737 .77888 L F
.887 .746 .7 r
.67627 .74618 m .67986 .74541 L .67595 .74436 L F
.67627 .74618 m .67858 .74786 L .67986 .74541 L F
.578 .537 .773 r
.7128 .72459 m .71556 .72462 L .71526 .72253 L F
.773 .654 .732 r
.62404 .7715 m .62726 .77172 L .62612 .76873 L F
.741 .62 .724 r
.62404 .7715 m .62721 .77375 L .62726 .77172 L F
.782 .666 .735 r
.53912 .79783 m .54034 .80079 L .54226 .79804 L F
.772 .624 .696 r
.46475 .8857 m .46574 .88774 L .4624 .88749 L F
.376 .792 .977 r
.4624 .88749 m .46574 .88774 L .4645 .88726 L F
.955 .643 .398 r
.4645 .88726 m .46574 .88774 L .46475 .8857 L F
.504 0 0 r
.50764 .88453 m .50928 .88384 L .51086 .88438 L F
.215 0 0 r
.51878 .83106 m .518 .83176 L .51652 .83154 L F
.23 0 .123 r
.518 .83176 m .51537 .8338 L .51652 .83154 L F
.697 .744 .888 r
.44383 .87935 m .44511 .8805 L .44718 .87971 L F
.959 .812 .375 r
.71534 .71586 m .71584 .71657 L .7161 .71366 L F
.662 .28 .311 r
.71793 .71622 m .7161 .71366 L .71534 .71586 L F
.288 0 0 r
.5318 .81343 m .53092 .81399 L .5285 .81397 L F
.5318 .81343 m .53092 .81399 L .5285 .81397 L F
.469 .847 .619 r
.5318 .81343 m .53092 .81399 L .53282 .81257 L F
.907 .72 .639 r
.53402 .81441 m .5318 .81343 L .53282 .81257 L F
.569 .525 .766 r
.5318 .81343 m .53526 .81573 L .53402 .81441 L F
.907 .72 .639 r
.53402 .81441 m .53092 .81399 L .5318 .81343 L F
0 0 0 r
.69629 .75058 m .69836 .74982 L .69912 .74931 L F
.636 .495 .673 r
.59814 .77698 m .6004 .7789 L .60055 .77683 L F
.59814 .77698 m .59832 .77934 L .6004 .7789 L F
.589 .537 .765 r
.57702 .7928 m .57684 .79525 L .57463 .79539 L F
0 0 0 r
.57702 .7928 m .57463 .79539 L .57566 .79442 L F
.45 .777 .998 r
.57463 .79539 m .57684 .79525 L .57566 .79442 L F
.231 .744 .724 r
.51995 .81634 m .51896 .81665 L .51752 .81699 L F
.265 .298 .71 r
.51995 .81634 m .52084 .81846 L .51896 .81665 L F
.723 .247 .118 r
.51896 .81665 m .51793 .81763 L .51752 .81699 L F
.51896 .81665 m .52084 .81846 L .51793 .81763 L F
.228 0 .063 r
.35965 .80561 m .36231 .80387 L .36152 .80498 L F
.327 0 .153 r
.36231 .80387 m .36417 .80339 L .36152 .80498 L F
.495 0 0 r
.52687 .84316 m .523 .84254 L .5248 .84355 L F
.805 .824 .866 r
.71167 .70791 m .71365 .70729 L .71402 .70529 L F
.696 .431 .518 r
.43349 .75885 m .43209 .75883 L .43436 .75831 L F
.43349 .75885 m .43156 .76087 L .43209 .75883 L F
.56 .247 .395 r
.43349 .75885 m .43338 .76239 L .43156 .76087 L F
.47 .257 .508 r
.43635 .75754 m .43349 .75885 L .43436 .75831 L F
.43635 .75754 m .43605 .76045 L .43349 .75885 L F
.587 .311 .465 r
.43605 .76045 m .43338 .76239 L .43349 .75885 L F
.452 .557 .871 r
.33305 .6768 m .33215 .67851 L .33075 .67677 L F
.571 .545 .787 r
.65568 .71814 m .65464 .72156 L .65348 .72112 L F
.65568 .71814 m .6571 .72172 L .65464 .72156 L F
.064 .608 .844 r
.6571 .72172 m .65348 .72112 L .65464 .72156 L F
.804 .354 .172 r
.54661 .80631 m .5457 .80734 L .54382 .80509 L F
.82 .377 .185 r
.54661 .80631 m .54915 .80961 L .5457 .80734 L F
.819 .344 .066 r
.54972 .8091 m .54915 .80961 L .54661 .80631 L F
.667 .975 .871 r
.54986 .78058 m .55075 .77948 L .5521 .77924 L F
.54986 .78058 m .54773 .7814 L .55075 .77948 L F
.987 .741 .473 r
.61249 .82124 m .61258 .81912 L .61159 .81862 L F
.993 .873 .594 r
.61258 .81912 m .61241 .81649 L .61159 .81862 L F
.517 .159 .298 r
.37525 .78369 m .3785 .78143 L .37665 .78201 L F
.191 .579 .94 r
.56384 .78216 m .56456 .78162 L .56288 .78255 L F
.56384 .78216 m .56575 .78264 L .56456 .78162 L F
.855 .945 .876 r
.53155 .8745 m .53368 .87258 L .53205 .87245 L F
.597 .929 .96 r
.53205 .87245 m .53368 .87258 L .53571 .87158 L F
.867 .979 .85 r
.43741 .87988 m .43868 .87876 L .43848 .8771 L F
.675 .638 .805 r
.43868 .87876 m .44065 .87669 L .43848 .8771 L F
.544 .439 .685 r
.41507 .75611 m .4173 .75799 L .41717 .75564 L F
.41507 .75611 m .41533 .75841 L .4173 .75799 L F
.505 0 0 r
.54972 .8091 m .54912 .80978 L .54915 .80961 L F
.804 .316 .027 r
.54972 .8091 m .55058 .81038 L .54912 .80978 L F
.576 .432 .649 r
.63762 .72968 m .63428 .73165 L .63423 .72936 L F
.657 .501 .661 r
.63992 .72892 m .63751 .73197 L .63762 .72968 L F
.664 .486 .634 r
.61748 .76622 m .61976 .76612 L .61981 .76369 L F
.642 .534 .716 r
.61981 .76369 m .62172 .76087 L .61946 .76147 L F
.61981 .76369 m .62279 .76396 L .62172 .76087 L F
.695 .561 .699 r
.61976 .76612 m .62279 .76396 L .61981 .76369 L F
.433 .785 .997 r
.41068 .74159 m .412 .74236 L .41397 .7421 L F
.865 .982 .694 r
.65176 .62995 m .65318 .62891 L .65125 .63168 L F
.697 .536 .666 r
.65125 .63168 m .65318 .62891 L .65345 .6314 L F
.679 .942 .666 r
.65304 .62867 m .65318 .62891 L .65176 .62995 L F
.685 .463 .58 r
.65318 .62891 m .65618 .63102 L .65345 .6314 L F
.65318 .62891 m .65648 .62895 L .65618 .63102 L F
.495 0 0 r
.52687 .84316 m .52579 .84354 L .523 .84254 L F
.47 .507 .814 r
.523 .84254 m .52579 .84354 L .52522 .84244 L F
.341 0 .07 r
.523 .84254 m .52474 .84246 L .52672 .84012 L F
.47 .507 .814 r
.523 .84254 m .52522 .84244 L .5248 .84165 L F
.341 0 .07 r
.523 .84254 m .52461 .84262 L .52474 .84246 L F
.353 0 .078 r
.52672 .84012 m .52757 .84159 L .52909 .83975 L F
.52672 .84012 m .52461 .84262 L .52757 .84159 L F
.631 .907 .983 r
.53523 .84344 m .53852 .8435 L .53738 .84267 L F
.617 .82 .979 r
.53738 .84267 m .53852 .8435 L .54075 .84298 L F
.909 .713 .625 r
.67855 .75313 m .67933 .75056 L .67728 .75019 L F
.573 .31 .48 r
.43209 .75883 m .43156 .76087 L .42938 .76094 L F
.407 0 .145 r
.34382 .73235 m .34518 .73309 L .34591 .732 L F
.34382 .73235 m .34242 .73417 L .34518 .73309 L F
.405 .217 .51 r
.33159 .69632 m .3302 .69518 L .33211 .69458 L F
.33159 .69632 m .32993 .69732 L .3302 .69518 L F
.729 .47 .536 r
.49703 .88178 m .49691 .87975 L .49308 .87987 L F
.795 .662 .716 r
.49703 .88178 m .49975 .88 L .49691 .87975 L F
.26 0 0 r
.40644 .74247 m .40429 .74336 L .40316 .7431 L F
0 0 0 r
.4074 .74238 m .40644 .74247 L .40855 .74198 L F
.4074 .74238 m .40429 .74336 L .40644 .74247 L F
.443 .601 .912 r
.4877 .83109 m .48833 .8329 L .48653 .83243 L F
.67 .424 .54 r
.48015 .82901 m .48213 .82683 L .47978 .82689 L F
.795 .662 .716 r
.49703 .88178 m .5002 .88243 L .49975 .88 L F
0 .009 .556 r
.49975 .88 m .5002 .88243 L .50096 .88175 L F
.256 .642 .963 r
.5002 .88243 m .50228 .88286 L .50096 .88175 L F
.859 .483 .335 r
.55364 .81334 m .55058 .81038 L .55275 .81174 L F
.779 .693 .769 r
.61659 .78958 m .6198 .78978 L .61879 .787 L F
.783 .674 .743 r
.61659 .78958 m .61772 .79261 L .6198 .78978 L F
0 0 0 r
.34934 .79537 m .35076 .79481 L .3513 .79458 L F
.323 .807 .782 r
.34872 .7955 m .35076 .79481 L .34934 .79537 L F
.438 .869 .771 r
.34728 .79631 m .35076 .79481 L .34872 .7955 L F
.34728 .79631 m .34894 .79542 L .35076 .79481 L F
0 0 0 r
.35076 .79481 m .34894 .79542 L .34986 .7952 L F
.35076 .79481 m .34986 .7952 L .35164 .79476 L F
.3513 .79458 m .35076 .79481 L .35155 .79448 L F
.18 0 0 r
.39642 .74425 m .39583 .74356 L .39773 .74291 L F
.39642 .74425 m .39456 .74475 L .39583 .74356 L F
.773 .479 .489 r
.49085 .86304 m .49093 .86533 L .49168 .86534 L F
.995 .847 .502 r
.49221 .86387 m .49324 .86492 L .49221 .86385 L F
.49221 .86385 m .49324 .86492 L .49291 .86315 L F
0 .351 .779 r
.49552 .86605 m .49324 .86492 L .4922 .86386 L F
.773 .479 .489 r
.49219 .86392 m .49168 .86534 L .49441 .86537 L F
.49085 .86304 m .49168 .86534 L .49219 .86392 L F
.995 .847 .502 r
.4922 .86386 m .49221 .86387 L .49221 .86385 L F
0 0 .119 r
.49735 .83284 m .49822 .83346 L .49955 .83381 L F
.49735 .83284 m .49722 .83439 L .49822 .83346 L F
.761 .394 .36 r
.49317 .82505 m .49211 .82678 L .48903 .82522 L F
.787 .797 .86 r
.49567 .82288 m .49317 .82505 L .49153 .82298 L F
.364 0 .132 r
.49403 .82608 m .49211 .82678 L .49317 .82505 L F
0 .232 .71 r
.71415 .73204 m .71565 .73332 L .71657 .73374 L F
.12 0 .163 r
.71657 .73374 m .71565 .73332 L .71515 .73535 L F
.79 .499 .494 r
.70658 .74154 m .70537 .74483 L .7052 .74239 L F
.70658 .74154 m .70809 .7453 L .70537 .74483 L F
.944 .66 .47 r
.70586 .74294 m .70719 .74401 L .70637 .74205 L F
.79 .499 .494 r
.70658 .74154 m .7052 .74239 L .7067 .74185 L F
.70715 .74157 m .7067 .74185 L .70743 .74159 L F
.70658 .74154 m .7067 .74185 L .70715 .74157 L F
.54 .646 .903 r
.70743 .74159 m .7052 .74239 L .70587 .74086 L F
.944 .66 .47 r
.70586 .74237 m .70637 .74205 L .70587 .74086 L F
.70586 .74294 m .70637 .74205 L .70586 .74237 L F
.793 .878 .909 r
.63539 .72602 m .63848 .72577 L .63981 .72444 L F
.693 .256 .208 r
.63762 .7279 m .63848 .72577 L .63539 .72602 L F
.666 .95 .706 r
.63981 .72444 m .63848 .72577 L .63802 .72567 L F
.904 .81 .335 r
.63802 .72567 m .63848 .72577 L .63762 .7279 L F
.535 .61 .874 r
.64019 .72447 m .64137 .72662 L .63848 .72577 L F
.53 .4 .648 r
.64137 .72662 m .63992 .72892 L .63848 .72577 L F
.731 .645 .763 r
.63037 .7634 m .63362 .76374 L .6325 .76074 L F
.722 .64 .767 r
.6325 .76074 m .63362 .76374 L .63584 .76124 L F
.686 .624 .782 r
.68933 .72984 m .69256 .73197 L .69153 .72911 L F
.669 .63 .802 r
.69153 .72911 m .69256 .73197 L .69473 .73076 L F
.474 .084 .219 r
.6928 .74525 m .69195 .74718 L .68966 .74727 L F
.306 0 .144 r
.69407 .74642 m .6928 .74525 L .69489 .74624 L F
.69407 .74642 m .69195 .74718 L .6928 .74525 L F
.908 .566 .383 r
.48198 .85593 m .48244 .85792 L .48326 .85641 L F
.864 .499 .357 r
.48244 .85792 m .48415 .85875 L .48326 .85641 L F
.748 .649 .751 r
.62209 .77629 m .62519 .77684 L .62529 .7747 L F
.753 .653 .751 r
.62529 .7747 m .62519 .77684 L .62721 .77375 L F
.993 .75 .451 r
.43758 .88502 m .43674 .88243 L .4346 .88425 L F
.724 .314 0 r
.55505 .81571 m .55494 .81592 L .55364 .81334 L F
.661 .176 0 r
.55505 .81571 m .55598 .81697 L .55494 .81592 L F
.617 .551 .758 r
.58251 .82126 m .58361 .82427 L .58427 .82279 L F
.852 .886 .862 r
.4581 .88335 m .45932 .88254 L .45779 .88249 L F
.906 .721 .64 r
.45932 .88254 m .45909 .88519 L .45779 .88249 L F
.789 .399 .316 r
.45932 .88254 m .46248 .885 L .46119 .88468 L F
0 .241 .632 r
.54595 .84511 m .54255 .84327 L .54381 .84343 L F
.552 .491 .741 r
.41621 .75026 m .41675 .75376 L .4186 .75209 L F
.567 .412 .631 r
.41675 .75376 m .41926 .75517 L .4186 .75209 L F
.41675 .75376 m .41717 .75564 L .41926 .75517 L F
.736 .738 .852 r
.49984 .84243 m .49604 .84289 L .49843 .84024 L F
.742 .641 .748 r
.49984 .84243 m .49618 .84533 L .49604 .84289 L F
.539 .523 .786 r
.50072 .83924 m .49984 .84243 L .49843 .84024 L F
.50072 .83924 m .50179 .8424 L .49984 .84243 L F
.685 .44 .546 r
.58737 .77888 m .58945 .77912 L .58927 .77694 L F
.782 .521 .541 r
.46976 .85849 m .46948 .86119 L .47015 .85843 L F
.534 .532 .799 r
.47015 .85843 m .47244 .8578 L .46999 .85568 L F
.47015 .85843 m .47196 .85905 L .47244 .8578 L F
.759 .57 .641 r
.46948 .86119 m .47196 .85905 L .47015 .85843 L F
.387 .762 .992 r
.37564 .88684 m .37734 .88764 L .37496 .88765 L F
.37564 .88684 m .37734 .88764 L .37496 .88765 L F
.898 .82 .762 r
.54851 .85284 m .54682 .85699 L .54512 .85528 L F
0 0 0 r
.54862 .85582 m .54682 .85699 L .54851 .85284 L F
.7 .629 .774 r
.65728 .76054 m .66065 .76125 L .65954 .75821 L F
.855 .945 .876 r
.53155 .8745 m .53205 .87245 L .53057 .87391 L F
.904 .985 .766 r
.60805 .83118 m .60984 .82994 L .60856 .82911 L F
.711 .639 .775 r
.62825 .76618 m .62499 .7635 L .62506 .76583 L F
.62825 .76618 m .62846 .76412 L .62499 .7635 L F
.764 .624 .705 r
.62612 .76873 m .62825 .76618 L .62506 .76583 L F
.755 .679 .777 r
.62825 .76618 m .63037 .7634 L .62846 .76412 L F
.432 .64 .944 r
.46649 .86655 m .46917 .86702 L .46801 .86595 L F
.46801 .86595 m .46917 .86702 L .46649 .86655 L F
.46649 .86655 m .46917 .86702 L .46801 .86595 L F
.809 .361 0 r
.58158 .8198 m .57835 .81991 L .57902 .81927 L F
.58158 .8198 m .58146 .82027 L .57835 .81991 L F
.58158 .8198 m .58251 .82126 L .58146 .82027 L F
.744 .591 .686 r
.45212 .83773 m .45207 .83998 L .45437 .83723 L F
.636 .436 .595 r
.45207 .83998 m .45459 .84001 L .45437 .83723 L F
.571 .388 .594 r
.45437 .83723 m .45677 .83959 L .45663 .83732 L F
.45437 .83723 m .45459 .84001 L .45677 .83959 L F
.773 .546 .591 r
.4912 .85337 m .48798 .85541 L .48756 .85374 L F
.139 0 0 r
.69719 .75416 m .69621 .75435 L .69413 .75425 L F
.233 .752 .81 r
.69962 .75389 m .69621 .75435 L .69719 .75416 L F
.577 .019 0 r
.49085 .86304 m .48999 .86186 L .48885 .86089 L F
.49085 .86304 m .49291 .86315 L .48999 .86186 L F
.505 .271 .493 r
.41942 .77074 m .41775 .76904 L .41966 .76853 L F
.41942 .77074 m .41741 .77112 L .41775 .76904 L F
.627 .479 .661 r
.4455 .84555 m .44568 .84796 L .44776 .84529 L F
.773 .546 .591 r
.4912 .85337 m .49111 .85561 L .48798 .85541 L F
.652 .425 .562 r
.49365 .85344 m .49111 .85561 L .4912 .85337 L F
.811 .633 .662 r
.57636 .81379 m .57744 .81562 L .57773 .81293 L F
.57636 .81379 m .57598 .81621 L .57744 .81562 L F
.249 .151 .543 r
.57598 .81621 m .57775 .81742 L .57744 .81562 L F
0 0 .307 r
.57744 .81562 m .57921 .81275 L .57773 .81293 L F
.57744 .81562 m .57917 .81498 L .57921 .81275 L F
.654 .508 .673 r
.43861 .85295 m .43923 .85601 L .44137 .85326 L F
.65 .499 .665 r
.43118 .86909 m .43391 .86936 L .43346 .86635 L F
.672 .57 .732 r
.65286 .75289 m .65508 .75026 L .653 .75091 L F
.547 .509 .765 r
.65636 .75548 m .65648 .75542 L .65671 .75558 L F
.66 .553 .722 r
.65499 .75036 m .65671 .75558 L .65508 .75026 L F
.6564 .7551 m .65671 .75558 L .65499 .75036 L F
.65648 .75542 m .65671 .75558 L .65406 .75147 L F
.525 .471 .739 r
.65508 .75026 m .65671 .75558 L .65757 .75504 L F
.65624 .75147 m .65757 .75504 L .65888 .75421 L F
.65508 .75026 m .65757 .75504 L .65624 .75147 L F
.69 .626 .78 r
.65759 .75905 m .65813 .75654 L .65651 .75545 L F
.65813 .75654 m .65843 .75516 L .65766 .75527 L F
.65813 .75654 m .65766 .75527 L .65651 .75545 L F
.65746 .75867 m .65651 .75545 L .65636 .75548 L F
.65759 .75905 m .65651 .75545 L .65746 .75867 L F
.66 .553 .722 r
.65406 .75147 m .6564 .7551 L .65499 .75036 L F
.65291 .75283 m .65648 .75542 L .65406 .75147 L F
.547 .509 .765 r
.65648 .75542 m .65888 .75421 L .65671 .75558 L F
.65648 .75542 m .65843 .75516 L .65888 .75421 L F
.565 .564 .811 r
.65636 .75548 m .65671 .75558 L .65649 .75542 L F
.547 .509 .765 r
.65636 .75548 m .65649 .75542 L .65648 .75542 L F
.565 .564 .811 r
.65636 .75548 m .65649 .75542 L .65286 .75289 L F
.547 .509 .765 r
.65636 .75548 m .65651 .75545 L .65649 .75542 L F
.65651 .75545 m .65843 .75516 L .65648 .75542 L F
.66 .553 .722 r
.65286 .75289 m .65671 .75558 L .65291 .75283 L F
0 0 .543 r
.49618 .84533 m .49619 .845 L .49604 .84289 L F
0 .009 .556 r
.49975 .88 m .50096 .88175 L .50232 .87973 L F
.698 .321 .33 r
.50096 .88175 m .50519 .88174 L .50232 .87973 L F
.592 .41 .605 r
.50232 .87973 m .50519 .88174 L .50457 .87955 L F
.517 .71 .959 r
.38968 .7237 m .3887 .72523 L .38767 .72361 L F
.38968 .7237 m .39125 .72529 L .3887 .72523 L F
.954 .667 .455 r
.64914 .63452 m .64921 .63661 L .64789 .63577 L F
.888 .979 .822 r
.64914 .63452 m .64939 .63252 L .65125 .63168 L F
.64914 .63452 m .64856 .63394 L .64939 .63252 L F
.985 .901 .589 r
.64789 .63577 m .64856 .63394 L .64914 .63452 L F
.665 .535 .696 r
.65125 .63168 m .65164 .63444 L .64914 .63452 L F
.637 .396 .537 r
.65164 .63444 m .64921 .63661 L .64914 .63452 L F
.328 .598 .944 r
.49854 .82213 m .49812 .82301 L .49709 .82189 L F
.652 .799 .351 r
.49854 .82213 m .49744 .82425 L .49812 .82301 L F
.772 .624 .696 r
.46475 .8857 m .4624 .88749 L .46248 .885 L F
.955 .643 .398 r
.4645 .88726 m .46475 .8857 L .46539 .88505 L F
.581 .494 .72 r
.42885 .74782 m .42672 .74988 L .42675 .74815 L F
.875 .736 .223 r
.55423 .84276 m .55385 .84478 L .55408 .84436 L F
0 0 .335 r
.55387 .83984 m .55441 .84245 L .55423 .84276 L F
0 0 0 r
.55441 .84245 m .55385 .84478 L .55423 .84276 L F
.666 .527 .685 r
.61091 .7719 m .61108 .77423 L .61321 .77159 L F
.395 .512 .858 r
.68623 .72066 m .68475 .72238 L .68389 .72087 L F
.68623 .72066 m .68713 .72338 L .68475 .72238 L F
.594 .722 .934 r
.68168 .72131 m .68389 .72087 L .68475 .72238 L F
.594 .844 .992 r
.52422 .83418 m .52547 .83489 L .52671 .83362 L F
.52422 .83418 m .52547 .83489 L .52671 .83362 L F
.23 .593 .948 r
.70548 .74892 m .70504 .74962 L .70437 .74869 L F
.70548 .74892 m .70697 .75007 L .70504 .74962 L F
.834 .708 .725 r
.48029 .8743 m .48089 .8755 L .47871 .87409 L F
.422 .512 .846 r
.48039 .87427 m .48089 .8755 L .48029 .8743 L F
.806 .723 .773 r
.47971 .87262 m .48039 .87427 L .48046 .87153 L F
.4804 .8743 m .48089 .8755 L .48072 .87398 L F
.312 .35 .741 r
.48046 .87153 m .48089 .8755 L .48256 .87351 L F
.422 .512 .846 r
.48256 .87351 m .48089 .8755 L .48039 .87427 L F
.407 .13 .378 r
.48029 .8743 m .4803 .87441 L .48036 .87435 L F
.422 .512 .846 r
.48039 .87427 m .48029 .8743 L .48036 .87435 L F
.806 .723 .773 r
.47967 .87471 m .48089 .8755 L .48011 .8745 L F
.601 .278 .394 r
.47837 .87635 m .48034 .8779 L .4803 .87441 L F
.48011 .8745 m .4803 .87441 L .48029 .8743 L F
.47837 .87635 m .4803 .87441 L .48011 .8745 L F
.806 .723 .773 r
.48011 .8745 m .48089 .8755 L .48053 .87462 L F
.47871 .87409 m .47967 .87471 L .48011 .8745 L F
.834 .708 .725 r
.48029 .8743 m .47871 .87409 L .48011 .8745 L F
.806 .723 .773 r
.47871 .87409 m .48053 .87462 L .47971 .87262 L F
.834 .708 .725 r
.48011 .8745 m .47871 .87409 L .47837 .87635 L F
.407 .13 .378 r
.48036 .87435 m .48034 .8779 L .48247 .87588 L F
.4803 .87441 m .48034 .8779 L .48036 .87435 L F
.806 .723 .773 r
.48039 .87427 m .4804 .8743 L .48068 .87358 L F
.4804 .8743 m .48072 .87398 L .48068 .87358 L F
.48039 .87427 m .48068 .87358 L .48046 .87153 L F
.422 .512 .846 r
.48256 .87351 m .48039 .87427 L .48247 .87588 L F
.48039 .87427 m .48036 .87435 L .48247 .87588 L F
.353 .803 .666 r
.36953 .72461 m .37048 .72408 L .37153 .72429 L F
.598 .399 .582 r
.53983 .83747 m .54036 .84132 L .53805 .84167 L F
0 .027 .542 r
.66902 .70891 m .66971 .70761 L .66885 .70693 L F
.972 .839 .653 r
.66902 .70891 m .66856 .71083 L .66755 .7101 L F
.548 .632 .887 r
.45027 .88058 m .45142 .87887 L .44926 .87939 L F
.45027 .88058 m .45276 .88101 L .45142 .87887 L F
.732 .524 .61 r
.57783 .78479 m .57405 .787 L .57495 .7847 L F
.57783 .78479 m .57776 .78718 L .57405 .787 L F
0 0 0 r
.35155 .79448 m .35076 .79481 L .35263 .79416 L F
.683 .796 .935 r
.65788 .62434 m .6599 .62337 L .66073 .62462 L F
.681 .56 .712 r
.6599 .62337 m .66295 .6257 L .66073 .62462 L F
.503 .222 .421 r
.6588 .62893 m .65618 .63102 L .65648 .62895 L F
.659 .505 .664 r
.43346 .86635 m .43619 .8689 L .43541 .86589 L F
.43346 .86635 m .43391 .86936 L .43619 .8689 L F
.162 0 0 r
.66221 .70768 m .66443 .70785 L .66535 .70774 L F
.716 .642 .774 r
.42022 .88428 m .42183 .88602 L .42337 .88472 L F
.993 .744 .412 r
.48701 .87683 m .48701 .87375 L .48612 .87363 L F
.401 .019 .195 r
.38541 .77664 m .38746 .77631 L .38859 .77432 L F
.356 0 .17 r
.38859 .77432 m .38939 .77587 L .39071 .77406 L F
.38859 .77432 m .38746 .77631 L .38939 .77587 L F
.186 .706 .877 r
.54558 .80387 m .54781 .80376 L .5487 .804 L F
.424 0 0 r
.54968 .80473 m .5487 .804 L .54781 .80376 L F
.54968 .80473 m .5508 .80542 L .5487 .804 L F
.658 .172 .086 r
.5487 .804 m .5508 .80542 L .55197 .80506 L F
.343 0 .22 r
.36408 .78769 m .36144 .78963 L .36318 .78919 L F
0 0 0 r
.36318 .78919 m .36593 .78728 L .36408 .78769 L F
.539 .743 .97 r
.42145 .73587 m .41816 .735 L .42014 .73454 L F
.522 .747 .978 r
.42223 .73445 m .42145 .73587 L .42014 .73454 L F
.42223 .73445 m .42388 .73586 L .42145 .73587 L F
.925 .722 .609 r
.56033 .82152 m .55908 .82156 L .55779 .81874 L F
.997 .771 .444 r
.56033 .82152 m .55947 .82366 L .55908 .82156 L F
.56033 .82152 m .56027 .82436 L .55947 .82366 L F
.239 0 0 r
.6908 .75074 m .69335 .75078 L .69394 .75044 L F
.36 .728 .988 r
.69546 .74976 m .69629 .75058 L .69394 .75044 L F
.69546 .74976 m .69394 .75044 L .69335 .75078 L F
.698 .559 .694 r
.6004 .7789 m .60355 .77688 L .60055 .77683 L F
.417 .843 .691 r
.35595 .80758 m .35965 .80561 L .35753 .80709 L F
.358 0 .042 r
.36152 .80498 m .35753 .80709 L .35965 .80561 L F
.43 0 .062 r
.46539 .88457 m .46992 .88313 L .46879 .8823 L F
.638 .864 .984 r
.46879 .8823 m .46992 .88313 L .47199 .88226 L F
.505 .243 .451 r
.41285 .76059 m .41494 .76032 L .41533 .75841 L F
.511 .268 .482 r
.41494 .76032 m .4173 .75799 L .41533 .75841 L F
.568 .275 .43 r
.52959 .82654 m .52856 .829 L .52632 .82911 L F
.644 .646 .837 r
.53089 .82455 m .52959 .82654 L .52842 .82457 L F
.53089 .82455 m .53184 .8269 L .52959 .82654 L F
.737 .458 .507 r
.53134 .82754 m .52959 .82654 L .53184 .8269 L F
.53134 .82754 m .52856 .829 L .52959 .82654 L F
.792 .735 .8 r
.47272 .86343 m .47728 .86388 L .47456 .86104 L F
.489 .19 .385 r
.47728 .86388 m .47636 .86578 L .47435 .8658 L F
.824 .426 .296 r
.47272 .86343 m .47636 .86578 L .47728 .86388 L F
0 .299 .784 r
.47456 .86104 m .47728 .86388 L .47695 .86267 L F
.658 .784 .322 r
.47728 .86388 m .4768 .86476 L .47695 .86267 L F
.47728 .86388 m .47636 .86578 L .4768 .86476 L F
.664 .362 .451 r
.4796 .8641 m .47636 .86578 L .47728 .86388 L F
.733 .57 .671 r
.51572 .81676 m .51379 .81731 L .51548 .81607 L F
.51572 .81676 m .51351 .81935 L .51379 .81731 L F
.491 .24 .462 r
.51568 .819 m .51351 .81935 L .51572 .81676 L F
.384 .232 .548 r
.51752 .81699 m .51793 .81763 L .51572 .81676 L F
.418 .184 .449 r
.51793 .81763 m .51568 .819 L .51572 .81676 L F
.704 .684 .828 r
.63423 .72936 m .6357 .72939 L .63539 .72602 L F
.357 0 0 r
.63569 .73027 m .6357 .72939 L .63423 .72936 L F
.693 .256 .208 r
.63762 .7279 m .63539 .72602 L .6357 .72939 L F
.637 .447 .609 r
.63569 .73027 m .63762 .7279 L .6357 .72939 L F
0 0 .203 r
.64029 .71657 m .63984 .7182 L .64126 .71559 L F
.861 .496 0 r
.66956 .72604 m .67026 .72833 L .67104 .72923 L F
.928 .614 .427 r
.66962 .73124 m .67104 .72923 L .67026 .72833 L F
.66962 .73124 m .67115 .73175 L .67104 .72923 L F
.519 .395 .652 r
.57428 .8321 m .57346 .8294 L .5725 .83077 L F
.47 .25 .497 r
.57406 .83444 m .57613 .83168 L .57428 .8321 L F
.671 .21 .149 r
.57406 .83444 m .57428 .8321 L .57613 .83168 L F
.953 .909 .738 r
.59771 .80554 m .59544 .80782 L .59679 .80478 L F
.59771 .80554 m .59634 .80837 L .59544 .80782 L F
.687 .509 .641 r
.6058 .77657 m .6091 .77688 L .60884 .77436 L F
.684 .507 .641 r
.60884 .77436 m .6091 .77688 L .61108 .77423 L F
.898 .82 .762 r
.54851 .85284 m .54512 .85528 L .54732 .85513 L F
.51 .315 .552 r
.54862 .85582 m .54851 .85284 L .55072 .85296 L F
0 0 0 r
.54971 .85248 m .54851 .85284 L .54732 .85513 L F
.904 .722 .646 r
.61614 .79215 m .61772 .79261 L .61659 .78958 L F
.838 .708 .72 r
.61456 .79462 m .61772 .79261 L .61614 .79215 L F
.61456 .79462 m .61607 .79547 L .61772 .79261 L F
.332 .127 .445 r
.64726 .71348 m .64681 .71558 L .64526 .71623 L F
.406 .283 .599 r
.64534 .71731 m .64619 .71723 L .64546 .71915 L F
.802 .719 .774 r
.64546 .71915 m .64681 .71558 L .64602 .71722 L F
.178 .702 .869 r
.65062 .71674 m .64602 .71722 L .64681 .71558 L F
.65063 .7168 m .64602 .71722 L .65062 .71674 L F
.65072 .71694 m .64602 .71722 L .65078 .71679 L F
.65078 .71679 m .65063 .7168 L .65062 .71674 L F
.498 .343 .601 r
.64903 .71244 m .65094 .71641 L .64681 .71558 L F
.65094 .71641 m .65078 .71679 L .64681 .71558 L F
.758 .642 .733 r
.65254 .71501 m .65158 .71697 L .65078 .71694 L F
.606 .391 .563 r
.65254 .71501 m .65118 .71691 L .65094 .71641 L F
.65254 .71501 m .65094 .71641 L .64903 .71244 L F
.758 .642 .733 r
.65124 .71557 m .6509 .71645 L .64823 .71685 L F
.6509 .71645 m .65078 .71679 L .65052 .71679 L F
.6509 .71645 m .65052 .71679 L .64823 .71685 L F
.65078 .71679 m .65067 .71706 L .65065 .71706 L F
.65078 .71679 m .65065 .71706 L .64823 .71685 L F
.65254 .71501 m .65067 .71706 L .65124 .71557 L F
.498 .343 .601 r
.65094 .71641 m .65118 .71691 L .65078 .71679 L F
.178 .702 .869 r
.65118 .71691 m .65001 .71689 L .64979 .71691 L F
.65072 .71694 m .64979 .71691 L .64684 .71717 L F
.65118 .71691 m .64979 .71691 L .65072 .71694 L F
.758 .642 .733 r
.65078 .71694 m .6515 .71713 L .65067 .71706 L F
.65158 .71697 m .6515 .71713 L .65078 .71694 L F
.178 .702 .869 r
.64844 .71703 m .64823 .71685 L .64684 .71717 L F
.65001 .71689 m .64823 .71685 L .64844 .71703 L F
.64684 .71717 m .64772 .71697 L .64602 .71722 L F
.64772 .71697 m .64823 .71685 L .64756 .71697 L F
.64772 .71697 m .64756 .71697 L .64602 .71722 L F
.529 .355 .588 r
.64823 .71685 m .64628 .71967 L .64619 .7188 L F
.64756 .71697 m .64619 .7188 L .64602 .71722 L F
.64823 .71685 m .64619 .7188 L .64756 .71697 L F
0 0 .252 r
.64602 .71722 m .64491 .72053 L .64546 .71915 L F
.64602 .71722 m .64619 .7188 L .64491 .72053 L F
.64619 .7188 m .64628 .71967 L .64546 .72018 L F
.64619 .7188 m .64546 .72018 L .64491 .72053 L F
.749 .674 .778 r
.64345 .71765 m .64677 .71769 L .64645 .71693 L F
.64677 .71769 m .64685 .71769 L .64681 .71761 L F
.64677 .71769 m .64681 .71761 L .64645 .71693 L F
.406 .283 .599 r
.64526 .71623 m .64681 .71558 L .64619 .71723 L F
.749 .674 .778 r
.64381 .71684 m .64645 .71693 L .64498 .71419 L F
.406 .283 .599 r
.64526 .71623 m .64619 .71723 L .64534 .71731 L F
.749 .674 .778 r
.64345 .71765 m .64645 .71693 L .64381 .71684 L F
0 0 .038 r
.64685 .71769 m .6473 .71837 L .64823 .71685 L F
.889 .884 .454 r
.64823 .71685 m .6473 .71837 L .64795 .71661 L F
.498 .343 .601 r
.64903 .71244 m .64681 .71558 L .64726 .71348 L F
.545 .581 .842 r
.64498 .71419 m .64823 .71685 L .64744 .7141 L F
.889 .884 .454 r
.64823 .71685 m .64795 .71661 L .64805 .71633 L F
.533 .186 .325 r
.65067 .71706 m .64835 .71948 L .64823 .71685 L F
.6515 .71713 m .65078 .71767 L .65067 .71706 L F
.65078 .71767 m .64835 .71948 L .65067 .71706 L F
.178 .702 .869 r
.65118 .71691 m .65072 .71694 L .65078 .71679 L F
.76 .612 .694 r
.53184 .8269 m .53315 .8295 L .53134 .82754 L F
.799 .606 .641 r
.53294 .832 m .53134 .82754 L .53315 .8295 L F
.619 .674 .881 r
.53419 .82751 m .53315 .8295 L .53184 .8269 L F
.53419 .82751 m .53462 .82944 L .53315 .8295 L F
.681 .599 .757 r
.65759 .75905 m .65728 .76054 L .65954 .75821 L F
.397 .744 .993 r
.52049 .85272 m .51834 .85291 L .51913 .85195 L F
0 0 0 r
.51913 .85195 m .51834 .85291 L .51694 .85496 L F
.636 .502 .682 r
.52049 .85272 m .51832 .8555 L .51834 .85291 L F
.555 .867 .995 r
.37488 .72422 m .37171 .72429 L .37357 .72404 L F
.301 0 0 r
.3721 .72515 m .3756 .72377 L .37357 .72404 L F
.272 .77 .888 r
.37357 .72404 m .37567 .72374 L .37688 .72388 L F
.301 0 0 r
.3756 .72377 m .37567 .72374 L .37357 .72404 L F
.555 .867 .995 r
.37171 .72429 m .37153 .72429 L .37357 .72404 L F
.272 .77 .888 r
.37357 .72404 m .37688 .72388 L .37488 .72422 L F
.734 .605 .713 r
.59618 .79518 m .59757 .79873 L .5941 .79781 L F
.854 .546 .467 r
.59713 .80284 m .59423 .80006 L .59597 .79934 L F
.746 .657 .761 r
.59757 .79873 m .59597 .79934 L .59423 .80006 L F
.59757 .79873 m .59423 .80006 L .5941 .79781 L F
.127 .674 .714 r
.37673 .74989 m .37399 .75032 L .37507 .75012 L F
.458 .11 .287 r
.40563 .77672 m .40458 .77882 L .40252 .77911 L F
.526 .192 .345 r
.40775 .77648 m .40458 .77882 L .40563 .77672 L F
.62 .622 .831 r
.66387 .75499 m .66516 .75793 L .66639 .7559 L F
.187 .32 .768 r
.50457 .87955 m .50564 .88224 L .50677 .88173 L F
.728 .381 .391 r
.50564 .88224 m .50764 .88453 L .50463 .88427 L F
.741 .62 .724 r
.62404 .7715 m .62529 .7747 L .62721 .77375 L F
.705 .37 0 r
.5627 .83202 m .5636 .83443 L .56246 .83153 L F
.733 .745 .862 r
.43304 .88201 m .4346 .88425 L .43674 .88243 L F
.487 0 0 r
.38276 .74773 m .38122 .74871 L .37931 .74787 L F
.687 .321 .348 r
.38478 .7474 m .38122 .74871 L .38276 .74773 L F
.511 .516 .798 r
.47067 .86819 m .46986 .87014 L .46917 .86702 L F
.591 .608 .837 r
.47067 .86819 m .47251 .86953 L .46986 .87014 L F
.482 0 0 r
.66885 .70693 m .66971 .70761 L .67142 .70752 L F
.878 .602 .515 r
.51318 .87249 m .5108 .86908 L .50995 .87166 L F
.764 .394 .353 r
.5142 .874 m .51318 .87249 L .50995 .87166 L F
.639 .953 .939 r
.38889 .74607 m .38809 .74722 L .39011 .74676 L F
.38889 .74607 m .38683 .74716 L .38809 .74722 L F
.753 .454 .477 r
.50785 .85478 m .50405 .853 L .50691 .85353 L F
.519 .884 .978 r
.67588 .76093 m .67684 .76136 L .67905 .76063 L F
.646 .959 .928 r
.48725 .84686 m .48647 .8482 L .48684 .84551 L F
.784 .723 .796 r
.64425 .7503 m .64318 .74751 L .64108 .7501 L F
.775 .6 .662 r
.64113 .75226 m .64425 .7503 L .64108 .7501 L F
.64113 .75226 m .64404 .75246 L .64425 .7503 L F
.747 .705 .812 r
.64425 .7503 m .6464 .7479 L .64318 .74751 L F
.673 .542 .697 r
.44341 .8483 m .4436 .85062 L .44568 .84796 L F
.981 .898 .563 r
.5114 .83555 m .50809 .8368 L .50843 .83441 L F
.5114 .83555 m .511 .83587 L .50809 .8368 L F
.511 .83587 m .50895 .83667 L .50809 .8368 L F
.389 .459 .812 r
.50809 .8368 m .5077 .83444 L .50843 .83441 L F
.766 .559 .617 r
.51034 .83801 m .50809 .8368 L .51019 .83649 L F
.389 .459 .812 r
.50809 .8368 m .50881 .8371 L .5077 .83444 L F
.872 .707 .675 r
.5077 .83444 m .50868 .83678 L .50576 .83326 L F
.50868 .83678 m .50881 .8371 L .50859 .83682 L F
.50868 .83678 m .50859 .83682 L .50576 .83326 L F
.981 .898 .563 r
.5114 .83555 m .51034 .83801 L .51019 .83649 L F
.545 .107 .158 r
.51369 .83518 m .51019 .83649 L .51034 .83801 L F
.344 .616 .952 r
.51274 .83753 m .51034 .83801 L .51026 .83712 L F
.51136 .83696 m .51026 .83712 L .51019 .83649 L F
.51274 .83753 m .51026 .83712 L .51136 .83696 L F
.106 0 0 r
.51441 .83585 m .51207 .83686 L .51369 .83518 L F
.545 .107 .158 r
.51369 .83518 m .5115 .83698 L .51019 .83649 L F
.5115 .83698 m .51117 .83725 L .51019 .83649 L F
.106 0 0 r
.51207 .83686 m .51174 .837 L .51155 .83694 L F
.51207 .83686 m .51155 .83694 L .51369 .83518 L F
.693 .609 .758 r
.51071 .83644 m .51174 .837 L .51441 .83585 L F
.782 .557 .595 r
.51077 .83644 m .51181 .83701 L .51167 .83697 L F
.51071 .83644 m .51167 .83697 L .51019 .83649 L F
.51077 .83644 m .51167 .83697 L .51071 .83644 L F
.693 .609 .758 r
.51016 .83549 m .51071 .83644 L .51441 .83585 L F
.106 0 0 r
.51174 .837 m .5115 .83698 L .51155 .83694 L F
.782 .557 .595 r
.51181 .83701 m .51136 .83696 L .51019 .83649 L F
.106 0 0 r
.51174 .837 m .51117 .83725 L .5115 .83698 L F
.693 .609 .758 r
.51071 .83644 m .51117 .83725 L .51174 .837 L F
0 .18 .712 r
.51019 .83649 m .51083 .83667 L .51071 .83644 L F
.981 .898 .563 r
.511 .83587 m .51019 .83649 L .50975 .83636 L F
0 .18 .712 r
.51019 .83649 m .51071 .83644 L .51016 .83549 L F
.782 .557 .595 r
.50973 .83586 m .51077 .83644 L .51019 .83649 L F
.51181 .83701 m .51274 .83753 L .51136 .83696 L F
0 .18 .712 r
.51019 .83649 m .51117 .83725 L .51083 .83667 L F
.981 .898 .563 r
.50975 .83636 m .51019 .83649 L .50895 .83667 L F
.468 .301 .571 r
.33822 .68885 m .33655 .68718 L .33851 .68674 L F
.33822 .68885 m .33651 .68949 L .33655 .68718 L F
.513 .453 .727 r
.47043 .85756 m .47096 .8596 L .46962 .85942 L F
.934 .673 .517 r
.46828 .85924 m .46976 .85849 L .46862 .85869 L F
.46828 .85924 m .46948 .86119 L .46976 .85849 L F
.513 .453 .727 r
.46892 .85873 m .46962 .85942 L .46828 .85924 L F
.77 .26 0 r
.46615 .85579 m .46723 .85706 L .46976 .85849 L F
.46723 .85706 m .46884 .85865 L .46976 .85849 L F
.513 .453 .727 r
.47043 .85756 m .46962 .85942 L .46892 .85873 L F
.77 .26 0 r
.46723 .85706 m .46862 .85869 L .46884 .85865 L F
0 0 .199 r
.57009 .82912 m .56847 .83184 L .57098 .83063 L F
.57009 .82912 m .56965 .83123 L .56847 .83184 L F
.733 .207 0 r
.56972 .83398 m .5708 .83433 L .56847 .83184 L F
.56972 .83398 m .56847 .83184 L .56965 .83123 L F
.918 .523 .149 r
.54743 .82092 m .5474 .81881 L .5463 .81832 L F
.54743 .82092 m .54844 .82176 L .5474 .81881 L F
0 .086 .636 r
.55296 .77894 m .5521 .77924 L .55075 .77948 L F
.844 .393 .138 r
.5521 .77924 m .55388 .782 L .55499 .78206 L F
0 .086 .636 r
.55296 .77894 m .55388 .782 L .5521 .77924 L F
.664 .362 .451 r
.4796 .8641 m .47925 .86609 L .47636 .86578 L F
.591 .295 .435 r
.4796 .8641 m .48144 .86586 L .47925 .86609 L F
.522 .301 .52 r
.48166 .86365 m .48144 .86586 L .4796 .8641 L F
.357 0 0 r
.63569 .73027 m .63423 .72936 L .63428 .73165 L F
.801 .721 .776 r
.37247 .71595 m .37371 .71888 L .37584 .71618 L F
.756 .469 .498 r
.49955 .83381 m .50294 .83423 L .50278 .83243 L F
.762 .474 .497 r
.50586 .83442 m .50294 .83423 L .50278 .83243 L F
.50278 .83243 m .50294 .83423 L .50586 .83442 L F
.596 .41 .6 r
.52869 .8548 m .53118 .8523 L .52936 .85441 L F
.52869 .8548 m .52936 .85441 L .52883 .85501 L F
.875 .923 .854 r
.52869 .8548 m .53164 .85293 L .53162 .85304 L F
.52869 .8548 m .53162 .85304 L .53121 .85539 L F
.358 .709 .986 r
.53327 .85234 m .53164 .85293 L .53118 .8523 L F
.496 .313 .563 r
.53327 .85234 m .53121 .85539 L .53164 .85293 L F
.421 0 0 r
.42197 .76786 m .42179 .76851 L .41966 .76853 L F
.297 0 0 r
.42518 .76819 m .42179 .76851 L .42197 .76786 L F
.617 .484 .677 r
.62147 .75859 m .62384 .75824 L .62356 .75592 L F
.617 .483 .677 r
.62147 .75859 m .62172 .76087 L .62384 .75824 L F
.73 .555 .654 r
.59617 .77958 m .59612 .78174 L .59832 .77934 L F
.699 .507 .625 r
.59612 .78174 m .59834 .78206 L .59832 .77934 L F
.645 .464 .624 r
.59832 .77934 m .60158 .78179 L .6004 .7789 L F
.59832 .77934 m .59834 .78206 L .60158 .78179 L F
.53 .4 .648 r
.64137 .72662 m .64182 .72892 L .63992 .72892 L F
.573 .39 .596 r
.53631 .83491 m .53849 .83465 L .53848 .83185 L F
.629 .435 .601 r
.53848 .83185 m .54086 .83431 L .54065 .83168 L F
.209 0 0 r
.53945 .83268 m .53848 .83185 L .54065 .83168 L F
.629 .435 .601 r
.53848 .83185 m .53849 .83465 L .54086 .83431 L F
.209 0 0 r
.53945 .83268 m .53748 .83317 L .53848 .83185 L F
.429 .694 .975 r
.40712 .72874 m .40592 .72986 L .40495 .72874 L F
.40712 .72874 m .40852 .73014 L .40592 .72986 L F
0 0 .139 r
.55613 .80038 m .55476 .80361 L .55613 .80153 L F
.549 .428 .668 r
.55419 .80539 m .55613 .80153 L .55476 .80361 L F
.657 .489 .646 r
.41621 .75026 m .41854 .7502 L .41845 .74774 L F
.517 .524 .802 r
.41845 .74774 m .4192 .74445 L .41743 .74478 L F
.41845 .74774 m .42033 .74762 L .4192 .74445 L F
.604 .496 .704 r
.41854 .7502 m .42033 .74762 L .41845 .74774 L F
.666 .523 .68 r
.43541 .86589 m .43752 .86357 L .43576 .86408 L F
.659 .519 .681 r
.61787 .76862 m .61976 .76612 L .61748 .76622 L F
.89 .497 .278 r
.70809 .7453 m .70918 .74531 L .70857 .74626 L F
.991 .792 .409 r
.70857 .74626 m .70918 .74531 L .70879 .7477 L F
.573 .451 .675 r
.42851 .74492 m .42885 .74782 L .42675 .74815 L F
.468 .145 .336 r
.35568 .75281 m .35365 .75416 L .35365 .75304 L F
.894 .497 .063 r
.49705 .86893 m .49896 .87234 L .49779 .8709 L F
.992 .814 .437 r
.49826 .87169 m .49896 .87234 L .49804 .8707 L F
.247 .549 .928 r
.49985 .8733 m .49826 .87169 L .49925 .87256 L F
.702 .33 .34 r
.49838 .87383 m .49925 .87256 L .49826 .87169 L F
.49852 .87288 m .49826 .87169 L .49893 .87004 L F
.49838 .87383 m .49826 .87169 L .49852 .87288 L F
.992 .814 .437 r
.49826 .87169 m .49804 .8707 L .49705 .86893 L F
.623 .397 .553 r
.42001 .88236 m .42237 .88181 L .42263 .87974 L F
.436 .234 .506 r
.42263 .87974 m .42237 .88181 L .42438 .8793 L F
.643 .622 .814 r
.32604 .66763 m .32351 .66563 L .32512 .66611 L F
.288 .43 .831 r
.3271 .66587 m .32604 .66763 L .32512 .66611 L F
.3271 .66587 m .32808 .66827 L .32604 .66763 L F
.212 .461 .879 r
.32604 .66763 m .32808 .66827 L .32697 .66814 L F
.663 .49 .641 r
.44972 .84022 m .44983 .84262 L .45207 .83998 L F
.721 .606 .728 r
.43528 .87666 m .43848 .8771 L .4376 .87387 L F
.702 .78 .296 r
.43848 .8771 m .43752 .87944 L .43741 .87988 L F
.595 .361 .531 r
.43528 .87666 m .43752 .87944 L .43848 .8771 L F
.627 .548 .747 r
.4376 .87387 m .43848 .8771 L .44065 .87669 L F
.752 .63 .725 r
.65701 .7344 m .66023 .73464 L .65936 .73183 L F
.125 0 0 r
.65701 .7344 m .65942 .73464 L .66023 .73464 L F
.643 .616 .807 r
.66023 .73464 m .66142 .73137 L .65936 .73183 L F
.66023 .73464 m .66279 .73444 L .66142 .73137 L F
.589 .598 .829 r
.66153 .73384 m .66023 .73464 L .65942 .73464 L F
.544 .331 .542 r
.66029 .73701 m .66279 .73444 L .66023 .73464 L F
.589 .598 .829 r
.66153 .73384 m .66029 .73701 L .66023 .73464 L F
.946 .633 .409 r
.50995 .87166 m .5117 .87454 L .51024 .87399 L F
.736 .212 0 r
.51024 .87399 m .5117 .87454 L .51356 .87646 L F
.667 .551 .715 r
.653 .75091 m .65489 .74975 L .65176 .74767 L F
.653 .75091 m .65508 .75026 L .65489 .74975 L F
.536 .843 .999 r
.712 .73628 m .70999 .73684 L .70897 .73617 L F
.652 .425 .562 r
.49365 .85344 m .49322 .85586 L .49111 .85561 L F
.692 .526 .657 r
.49582 .85279 m .49322 .85586 L .49365 .85344 L F
.201 0 .003 r
.37099 .79949 m .36898 .80024 L .37179 .79849 L F
.374 0 .128 r
.37381 .79813 m .37099 .79949 L .37179 .79849 L F
.437 .049 .205 r
.3355 .73677 m .33778 .7362 L .33613 .73579 L F
.435 .035 .18 r
.33613 .73579 m .33778 .7362 L .33851 .73509 L F
.893 .804 .755 r
.48463 .86354 m .48144 .86586 L .48166 .86365 L F
.48463 .86354 m .48304 .8666 L .48144 .86586 L F
.633 .488 .668 r
.44759 .84291 m .44776 .84529 L .44983 .84262 L F
.735 .573 .673 r
.43195 .87422 m .43526 .87475 L .43448 .87185 L F
.632 .532 .723 r
.43448 .87185 m .43619 .8689 L .43391 .86936 L F
.43448 .87185 m .43702 .87199 L .43619 .8689 L F
.698 .551 .684 r
.43448 .87185 m .4376 .87387 L .43702 .87199 L F
.43448 .87185 m .43526 .87475 L .4376 .87387 L F
.847 .594 .052 r
.65968 .72365 m .65905 .72074 L .66079 .72193 L F
.73 .57 .675 r
.61108 .77423 m .6091 .77688 L .6112 .77661 L F
.671 .535 .69 r
.61321 .77159 m .61108 .77423 L .61332 .77386 L F
.678 .536 .685 r
.6112 .77661 m .61332 .77386 L .61108 .77423 L F
.872 .693 .657 r
.4349 .87973 m .43741 .87988 L .43752 .87944 L F
.4349 .87973 m .43674 .88243 L .43741 .87988 L F
.865 .982 .694 r
.65176 .62995 m .65125 .63168 L .65088 .63132 L F
.77 .997 .826 r
.65125 .63168 m .64939 .63252 L .65088 .63132 L F
.658 .529 .696 r
.65355 .63266 m .65125 .63168 L .65345 .6314 L F
.65355 .63266 m .65164 .63444 L .65125 .63168 L F
.766 .903 .936 r
.57147 .78846 m .5691 .7892 L .57088 .78984 L F
.535 .591 .857 r
.38634 .72081 m .38572 .72379 L .38425 .72207 L F
.38634 .72081 m .38767 .72361 L .38572 .72379 L F
.388 .084 .323 r
.38744 .79158 m .38625 .78973 L .38861 .78922 L F
.38744 .79158 m .38549 .79215 L .38625 .78973 L F
.356 0 .105 r
.34373 .75811 m .34242 .75987 L .34058 .75999 L F
.429 .041 .201 r
.34578 .75765 m .34242 .75987 L .34373 .75811 L F
.605 .448 .642 r
.44568 .84796 m .4436 .85062 L .44583 .85036 L F
.586 .427 .633 r
.44377 .853 m .44583 .85036 L .4436 .85062 L F
.725 .61 .729 r
.58712 .82004 m .58968 .81869 L .58828 .81962 L F
0 0 0 r
.35225 .80972 m .35097 .81029 L .35089 .81034 L F
.35225 .80972 m .35274 .80958 L .35097 .81029 L F
.35225 .80972 m .35442 .80839 L .35274 .80958 L F
.843 .851 .849 r
.48304 .8666 m .48077 .86917 L .47971 .86786 L F
.986 .77 .373 r
.54403 .83676 m .54383 .83929 L .54443 .83648 L F
.72 .384 .409 r
.54443 .83648 m .54706 .83939 L .54611 .83634 L F
.54443 .83648 m .54383 .83929 L .54706 .83939 L F
.01 0 0 r
.54443 .83648 m .54611 .83634 L .54403 .83676 L F
.016 0 0 r
.54403 .83676 m .54235 .83712 L .54443 .83648 L F
.064 .379 .843 r
.41229 .72918 m .41154 .72989 L .41043 .72931 L F
.41229 .72918 m .41364 .73114 L .41154 .72989 L F
.739 .507 .578 r
.58945 .77912 m .59287 .7815 L .59267 .77954 L F
.757 .46 .481 r
.59267 .77954 m .59612 .78174 L .59617 .77958 L F
.59267 .77954 m .59287 .7815 L .59612 .78174 L F
.517 .27 .479 r
.43883 .75514 m .43635 .75754 L .43686 .75529 L F
.76 .575 .646 r
.47435 .8658 m .47067 .86819 L .47071 .86584 L F
.524 .435 .696 r
.47692 .86874 m .4751 .86978 L .47435 .8658 L F
.165 .183 .632 r
.47435 .8658 m .4751 .86978 L .47512 .86917 L F
.76 .575 .646 r
.47435 .8658 m .47512 .86917 L .47067 .86819 L F
.524 .435 .696 r
.47692 .86874 m .47435 .8658 L .47636 .86578 L F
.982 .822 .423 r
.56229 .82693 m .56149 .82861 L .56108 .82629 L F
.56229 .82693 m .56198 .82931 L .56149 .82861 L F
.721 .334 0 r
.56381 .83996 m .56529 .84284 L .56456 .84212 L F
.728 .296 .223 r
.56529 .84284 m .56634 .84512 L .56456 .84212 L F
.56529 .84284 m .56765 .84492 L .56634 .84512 L F
.56 .335 .531 r
.65618 .63102 m .65355 .63266 L .65345 .6314 L F
.771 .654 .734 r
.63469 .75814 m .63791 .75844 L .63675 .75541 L F
.77 .66 .742 r
.63469 .75814 m .63584 .76124 L .63791 .75844 L F
.75 .644 .744 r
.63675 .75541 m .63791 .75844 L .64 .75578 L F
.873 .896 .846 r
.58146 .82027 m .58251 .82126 L .58479 .81856 L F
.969 .892 .695 r
.5332 .82646 m .53419 .82751 L .53184 .8269 L F
.62 .408 .573 r
.53389 .82671 m .53324 .82648 L .53189 .82518 L F
.504 .328 .576 r
.53176 .82429 m .53191 .82527 L .53089 .82455 L F
.62 .408 .573 r
.53187 .82504 m .53189 .82518 L .53103 .82434 L F
.53389 .82671 m .53189 .82518 L .53187 .82504 L F
.53447 .82586 m .53389 .82671 L .53103 .82434 L F
.53355 .82677 m .53112 .82454 L .53103 .82434 L F
.969 .892 .695 r
.53362 .82661 m .53419 .82751 L .5332 .82646 L F
.53362 .82661 m .53279 .82833 L .53419 .82751 L F
.62 .408 .573 r
.53373 .82695 m .53354 .82678 L .53355 .82677 L F
.53354 .82678 m .53112 .82454 L .53355 .82677 L F
.166 .342 .795 r
.53089 .82455 m .53191 .82527 L .53184 .8269 L F
.53191 .82527 m .5332 .82646 L .53184 .8269 L F
.62 .408 .573 r
.53373 .82695 m .53279 .82833 L .53112 .82454 L F
.969 .892 .695 r
.53347 .82638 m .53279 .82833 L .53362 .82661 L F
.584 .452 .668 r
.53254 .82407 m .53447 .82586 L .53182 .82469 L F
.504 .328 .576 r
.53254 .82407 m .53182 .82469 L .53176 .82429 L F
.584 .452 .668 r
.53254 .82407 m .53182 .82469 L .53103 .82434 L F
.504 .328 .576 r
.53254 .82407 m .53191 .82527 L .53182 .82469 L F
.53254 .82407 m .53347 .82638 L .53191 .82527 L F
.969 .892 .695 r
.53347 .82638 m .53362 .82661 L .5332 .82646 L F
.62 .408 .573 r
.53389 .82671 m .53373 .82695 L .53324 .82648 L F
.166 .342 .795 r
.53191 .82527 m .53347 .82638 L .5332 .82646 L F
.64 .126 0 r
.54844 .82176 m .55062 .82382 L .5497 .8231 L F
.523 .296 .512 r
.39538 .76869 m .39724 .77069 L .39784 .76826 L F
.39538 .76869 m .39515 .77113 L .39724 .77069 L F
.606 .442 .633 r
.43758 .86125 m .4401 .86108 L .43967 .85854 L F
.614 .444 .628 r
.43752 .86357 m .4401 .86108 L .43758 .86125 L F
.455 .833 .989 r
.69962 .75389 m .70284 .75403 L .7018 .75329 L F
.691 .9 .972 r
.7018 .75329 m .70284 .75403 L .70495 .75289 L F
.62 .606 .815 r
.68965 .72294 m .68824 .72547 L .68713 .72338 L F
.68965 .72294 m .69089 .7252 L .68824 .72547 L F
.288 0 .034 r
.37159 .78496 m .37221 .78625 L .37353 .78451 L F
.37159 .78496 m .37015 .78671 L .37221 .78625 L F
.613 .282 .385 r
.57058 .81632 m .57268 .81639 L .57367 .81566 L F
.681 .382 .461 r
.57268 .81639 m .57598 .81621 L .57367 .81566 L F
.651 .964 .794 r
.59571 .84699 m .59868 .84515 L .59697 .84645 L F
.615 .957 .852 r
.59868 .84515 m .60155 .84342 L .59947 .8441 L F
.613 .914 .647 r
.59697 .84645 m .59868 .84515 L .59947 .8441 L F
.719 .598 .72 r
.65176 .74767 m .64851 .74507 L .64852 .74733 L F
.65176 .74767 m .65208 .74569 L .64851 .74507 L F
.732 .647 .765 r
.64985 .74815 m .65176 .74767 L .64852 .74733 L F
.709 .589 .719 r
.65176 .74767 m .65399 .74501 L .65208 .74569 L F
.69 .56 .702 r
.65176 .74767 m .65489 .74975 L .65399 .74501 L F
.852 .886 .862 r
.4581 .88335 m .45779 .88249 L .45592 .88192 L F
0 0 0 r
.55613 .80153 m .55691 .80153 L .55815 .80064 L F
0 0 .389 r
.55701 .80143 m .55815 .80064 L .55691 .80153 L F
.264 0 0 r
.55613 .80038 m .55815 .80064 L .55911 .79997 L F
0 0 0 r
.55613 .80153 m .55815 .80064 L .55613 .80038 L F
0 0 .389 r
.55947 .79924 m .55815 .80064 L .55701 .80143 L F
.264 0 0 r
.55911 .79997 m .55815 .80064 L .5593 .79995 L F
.364 0 .152 r
.53328 .83709 m .53465 .83691 L .53631 .83491 L F
.67 .538 .695 r
.53127 .83756 m .53425 .83986 L .53328 .83709 L F
.53127 .83756 m .53212 .84083 L .53425 .83986 L F
.53127 .83756 m .53212 .84083 L .53425 .83986 L F
.984 .699 .375 r
.53328 .83709 m .53425 .83986 L .53323 .83881 L F
.53328 .83709 m .53323 .83881 L .53533 .83682 L F
.898 .987 .748 r
.53353 .83799 m .53254 .83884 L .53417 .83628 L F
.53323 .83881 m .53267 .83883 L .53353 .83799 L F
.53267 .83883 m .53254 .83884 L .53353 .83799 L F
.364 0 .152 r
.53465 .83691 m .53533 .83682 L .53591 .83569 L F
.53465 .83691 m .53591 .83569 L .53631 .83491 L F
0 0 0 r
.53631 .83491 m .5364 .83584 L .53849 .83465 L F
.53631 .83491 m .53533 .83682 L .5364 .83584 L F
.911 .949 .812 r
.55499 .78206 m .55598 .7789 L .55714 .78181 L F
.55499 .78206 m .55388 .782 L .55598 .7789 L F
.123 0 0 r
.55714 .78181 m .55388 .782 L .55499 .78206 L F
.736 .686 .803 r
.63675 .75541 m .64 .75578 L .63901 .753 L F
.733 .685 .804 r
.63901 .753 m .64 .75578 L .6423 .75338 L F
.805 .793 .297 r
.55387 .83889 m .55443 .83772 L .55365 .83653 L F
.55387 .83889 m .55387 .83984 L .55443 .83772 L F
.943 .889 .486 r
.51356 .87646 m .51311 .87989 L .51334 .8783 L F
.867 .987 .837 r
.51334 .8783 m .51311 .87989 L .51191 .88016 L F
.412 .199 .477 r
.42475 .87709 m .42438 .8793 L .42652 .8765 L F
.631 .411 .565 r
.40536 .76564 m .40781 .76348 L .40548 .76357 L F
0 .162 .658 r
.71584 .71657 m .71738 .71775 L .71534 .71586 L F
.721 .61 .733 r
.6219 .7741 m .62529 .7747 L .62404 .7715 L F
.748 .649 .751 r
.62209 .77629 m .62529 .7747 L .6219 .7741 L F
.473 .143 .325 r
.41042 .7746 m .40983 .77617 L .40775 .77648 L F
.439 .091 .278 r
.41284 .77389 m .40983 .77617 L .41042 .7746 L F
.663 .701 .875 r
.39945 .72675 m .39767 .72749 L .39645 .72594 L F
.604 .605 .826 r
.50824 .84755 m .50616 .84819 L .50459 .84535 L F
.169 0 .141 r
.62756 .73902 m .62888 .73861 L .62958 .73609 L F
.222 0 .162 r
.62958 .73609 m .63215 .73432 L .62994 .73457 L F
.62958 .73609 m .6316 .73626 L .63215 .73432 L F
.222 0 .16 r
.62958 .73609 m .62888 .73861 L .6316 .73626 L F
.455 .172 .393 r
.40252 .77911 m .39991 .78138 L .40064 .77964 L F
.682 .758 .909 r
.44383 .87935 m .44718 .87971 L .44653 .87885 L F
.569 .711 .938 r
.44653 .87885 m .44718 .87971 L .44926 .87939 L F
.885 .833 .79 r
.61318 .80599 m .61495 .80339 L .61366 .80266 L F
.912 .824 .747 r
.61495 .80339 m .61542 .80051 L .61366 .80266 L F
0 .204 .691 r
.50929 .8691 m .5097 .86969 L .50814 .86813 L F
.933 .796 .686 r
.50988 .86995 m .5108 .86908 L .5097 .86969 L F
.50855 .87121 m .50995 .87166 L .5108 .86908 L F
0 0 .262 r
.51144 .87091 m .50995 .87166 L .5108 .86908 L F
.51144 .87091 m .5108 .86908 L .5097 .86969 L F
0 .204 .691 r
.51144 .87091 m .5097 .86969 L .50929 .8691 L F
.933 .796 .686 r
.50855 .87121 m .50988 .86995 L .5097 .86969 L F
.475 .111 .267 r
.34781 .73153 m .34993 .73131 L .3511 .72921 L F
.443 .087 .264 r
.34993 .73131 m .35312 .72884 L .3511 .72921 L F
.731 .204 0 r
.57235 .78256 m .57325 .78388 L .5711 .78168 L F
.57235 .78256 m .57495 .7847 L .57325 .78388 L F
.715 .647 .78 r
.42022 .88428 m .42337 .88472 L .42237 .88181 L F
.678 .627 .79 r
.42237 .88181 m .42337 .88472 L .42544 .88266 L F
.532 .313 .527 r
.39059 .78699 m .38861 .78922 L .3885 .78727 L F
.552 .491 .741 r
.41621 .75026 m .4186 .75209 L .41854 .7502 L F
.457 .769 .997 r
.47199 .88226 m .47525 .88292 L .47386 .88236 L F
.242 .723 .932 r
.47525 .88292 m .47561 .88218 L .47386 .88236 L F
.47525 .88292 m .47713 .88289 L .47561 .88218 L F
.754 .673 .772 r
.62846 .76412 m .63037 .7634 L .62922 .76039 L F
.747 .67 .775 r
.62922 .76039 m .63037 .7634 L .6325 .76074 L F
.713 .573 .696 r
.59618 .79518 m .5941 .79781 L .59294 .79475 L F
.612 .498 .699 r
.43967 .85854 m .44145 .85561 L .43923 .85601 L F
.43967 .85854 m .44227 .85858 L .44145 .85561 L F
.633 .46 .631 r
.43967 .85854 m .4423 .86087 L .44227 .85858 L F
.43967 .85854 m .4401 .86108 L .4423 .86087 L F
0 0 0 r
.64304 .71246 m .64419 .71127 L .64163 .71344 L F
.063 0 0 r
.64304 .71246 m .64605 .71057 L .64419 .71127 L F
.628 .642 .845 r
.62994 .73457 m .6312 .73179 L .62938 .73101 L F
.62994 .73457 m .63215 .73432 L .6312 .73179 L F
.661 .499 .654 r
.61332 .77386 m .61564 .77138 L .61321 .77159 L F
.813 .85 .877 r
.51379 .81731 m .50989 .81872 L .51217 .81878 L F
.368 0 .158 r
.51217 .81878 m .51548 .81607 L .51379 .81731 L F
.143 .683 .83 r
.43817 .74973 m .43649 .74957 L .44 .74962 L F
.525 .241 .426 r
.41002 .76337 m .41214 .76311 L .41285 .76059 L F
.549 .285 .468 r
.41214 .76311 m .41494 .76032 L .41285 .76059 L F
.117 .669 .785 r
.48399 .88479 m .48488 .88461 L .48269 .88456 L F
.48399 .88479 m .48609 .88464 L .48488 .88461 L F
.692 .699 .852 r
.6862 .72925 m .68933 .72984 L .68814 .72816 L F
.676 .694 .859 r
.68814 .72816 m .68933 .72984 L .69153 .72911 L F
.972 .811 .624 r
.59634 .80837 m .59478 .80948 L .59544 .80782 L F
.59634 .80837 m .5959 .81028 L .59478 .80948 L F
.138 .572 .927 r
.58821 .84658 m .59021 .84608 L .58673 .84692 L F
.368 .747 .989 r
.58821 .84658 m .59184 .84704 L .59214 .84781 L F
.138 .572 .927 r
.58821 .84658 m .59214 .84781 L .59021 .84608 L F
.888 .967 .835 r
.64504 .72924 m .64219 .73126 L .64324 .73217 L F
.638 .68 .873 r
.42693 .73701 m .42388 .73586 L .42603 .73489 L F
.64 .715 .901 r
.42962 .73653 m .42693 .73701 L .42603 .73489 L F
.589 .495 .717 r
.42941 .73847 m .42753 .7389 L .42693 .73701 L F
.074 .631 .805 r
.5604 .78202 m .5594 .78185 L .55714 .78181 L F
.975 .676 .382 r
.5604 .78202 m .5594 .78185 L .55714 .78181 L F
.5604 .78202 m .56069 .78454 L .5594 .78185 L F
.547 .92 .938 r
.5604 .78202 m .5614 .78101 L .56161 .77883 L F
.5604 .78202 m .5594 .78185 L .5614 .78101 L F
.723 .637 .762 r
.6325 .76074 m .63584 .76124 L .63469 .75814 L F
.811 .796 .838 r
.53751 .82718 m .53419 .82751 L .53611 .82646 L F
.53751 .82718 m .53462 .82944 L .53419 .82751 L F
.599 .868 .993 r
.53931 .82645 m .53751 .82718 L .53611 .82646 L F
.53931 .82645 m .53751 .82718 L .53611 .82646 L F
.561 .85 .997 r
.3824 .72389 m .38031 .72448 L .37878 .72386 L F
.721 .59 .709 r
.64851 .74507 m .65208 .74569 L .65053 .74486 L F
.735 .689 .807 r
.65208 .74569 m .65283 .74214 L .65053 .74486 L F
.65208 .74569 m .65399 .74501 L .65283 .74214 L F
.446 .312 .604 r
.34024 .68117 m .34008 .68423 L .3384 .6845 L F
.49 .337 .6 r
.34037 .68599 m .3384 .6845 L .34008 .68423 L F
.34037 .68599 m .33851 .68674 L .3384 .6845 L F
.873 .896 .846 r
.58194 .82014 m .58405 .81897 L .58407 .81955 L F
.58405 .81897 m .58479 .81856 L .58407 .81955 L F
.746 .288 0 r
.58409 .82003 m .58407 .81955 L .58415 .82014 L F
.873 .896 .846 r
.58169 .82016 m .58479 .81856 L .58194 .82014 L F
.567 .642 .884 r
.58043 .81803 m .58407 .81955 L .58328 .81835 L F
.746 .288 0 r
.58328 .81835 m .58407 .81955 L .58409 .82003 L F
.361 0 0 r
.58407 .81955 m .58568 .81895 L .58576 .82058 L F
.601 .03 0 r
.58407 .81955 m .58576 .82058 L .58415 .82014 L F
.746 .288 0 r
.58328 .81835 m .58409 .82003 L .58497 .81742 L F
.58409 .82003 m .58415 .82014 L .58419 .82002 L F
.361 0 0 r
.58407 .81955 m .58479 .81856 L .58568 .81895 L F
.746 .288 0 r
.58409 .82003 m .58419 .82002 L .58497 .81742 L F
.873 .896 .846 r
.58146 .82027 m .58169 .82016 L .58194 .82014 L F
.721 .676 .806 r
.6464 .7479 m .64985 .74815 L .64852 .74733 L F
.634 .839 .979 r
.56765 .84492 m .56901 .84578 L .57099 .84501 L F
.63 .634 .836 r
.65283 .74214 m .65399 .74501 L .65633 .7446 L F
.671 .566 .729 r
.65489 .74975 m .65633 .7446 L .65399 .74501 L F
.748 .59 .681 r
.5941 .79781 m .59103 .79528 L .59294 .79475 L F
.408 0 0 r
.55197 .80506 m .5508 .80542 L .55419 .80539 L F
.637 .396 .537 r
.65164 .63444 m .65174 .6365 L .64921 .63661 L F
.488 .278 .521 r
.65355 .63266 m .65174 .6365 L .65164 .63444 L F
.884 .699 .647 r
.53134 .82754 m .52861 .83128 L .52856 .829 L F
.53134 .82754 m .53032 .83176 L .52861 .83128 L F
.799 .606 .641 r
.53294 .832 m .53032 .83176 L .53134 .82754 L F
.684 .542 .687 r
.61564 .77138 m .61858 .77146 L .61787 .76862 L F
.659 .519 .681 r
.61787 .76862 m .62079 .76885 L .61976 .76612 L F
.659 .527 .692 r
.61787 .76862 m .61858 .77146 L .62079 .76885 L F
.56 .474 .715 r
.44359 .75263 m .44126 .75358 L .44095 .75072 L F
.592 .36 .533 r
.44359 .75263 m .44087 .7549 L .44126 .75358 L F
.787 .797 .86 r
.49567 .82288 m .49153 .82298 L .49408 .82256 L F
.66 .211 .175 r
.49408 .82256 m .49709 .82189 L .49567 .82288 L F
.728 .605 .719 r
.43195 .87422 m .43528 .87666 L .43526 .87475 L F
.43195 .87422 m .43334 .87685 L .43528 .87666 L F
.448 0 0 r
.43131 .87849 m .43528 .87666 L .43334 .87685 L F
.43131 .87849 m .4349 .87973 L .43528 .87666 L F
.721 .606 .728 r
.43528 .87666 m .4376 .87387 L .43526 .87475 L F
.595 .361 .531 r
.43528 .87666 m .4349 .87973 L .43752 .87944 L F
.628 .48 .661 r
.44568 .84796 m .44802 .84775 L .44776 .84529 L F
.586 .434 .641 r
.44568 .84796 m .44796 .85002 L .44802 .84775 L F
.44568 .84796 m .44583 .85036 L .44796 .85002 L F
.578 .084 .045 r
.57588 .8193 m .57902 .81927 L .57835 .81991 L F
.485 .292 .543 r
.62279 .75289 m .6248 .75261 L .62485 .75027 L F
.643 .583 .772 r
.62356 .75592 m .6248 .75261 L .62279 .75289 L F
.952 .771 .621 r
.66116 .70474 m .66221 .70768 L .66242 .7052 L F
.756 .609 .695 r
.53402 .81441 m .53526 .81573 L .53704 .81367 L F
.661 .499 .654 r
.61332 .77386 m .6165 .77421 L .61564 .77138 L F
.699 .521 .643 r
.61564 .77138 m .61865 .7738 L .61858 .77146 L F
.61564 .77138 m .6165 .77421 L .61865 .7738 L F
.738 .449 .49 r
.49604 .84289 m .49282 .84477 L .49424 .84247 L F
.49604 .84289 m .49619 .845 L .49282 .84477 L F
0 0 0 r
.54512 .85528 m .54429 .85879 L .54633 .85822 L F
.841 .664 .662 r
.65985 .72942 m .65785 .72942 L .65812 .72649 L F
.69 .626 .78 r
.65759 .75905 m .65954 .75821 L .65843 .75516 L F
.573 .589 .831 r
.45779 .88249 m .45909 .88519 L .46119 .88468 L F
.117 0 0 r
.36144 .78963 m .36166 .79044 L .36318 .78919 L F
.36144 .78963 m .3598 .79106 L .36166 .79044 L F
.731 .585 .693 r
.60355 .77688 m .60358 .77925 L .6058 .77657 L F
.708 .552 .675 r
.6058 .77657 m .60358 .77925 L .60676 .77919 L F
.685 .54 .683 r
.60676 .77919 m .6091 .77688 L .6058 .77657 L F
.951 .657 .215 r
.69013 .74868 m .69001 .74945 L .6908 .75074 L F
.68966 .74727 m .69001 .74945 L .69013 .74868 L F
.628 .264 .333 r
.68913 .75118 m .68978 .7509 L .69001 .74945 L F
.293 .718 .971 r
.69184 .75002 m .6908 .75074 L .69001 .74945 L F
.628 .264 .333 r
.68978 .7509 m .69184 .75002 L .69001 .74945 L F
.293 .718 .971 r
.69184 .75002 m .69335 .75078 L .6908 .75074 L F
.792 .655 .711 r
.42652 .8765 m .42985 .87681 L .42887 .87482 L F
.623 .501 .693 r
.42652 .8765 m .42958 .8786 L .42985 .87681 L F
.719 .626 .753 r
.42887 .87482 m .42985 .87681 L .43195 .87422 L F
.157 .694 .834 r
.42958 .8786 m .43131 .87849 L .42985 .87681 L F
.697 .593 .735 r
.42985 .87681 m .43334 .87685 L .43195 .87422 L F
.58 .148 .185 r
.43131 .87849 m .43334 .87685 L .42985 .87681 L F
.582 .459 .678 r
.62439 .74783 m .6264 .74782 L .62616 .74469 L F
.51 .388 .65 r
.62485 .75027 m .6264 .74782 L .62439 .74783 L F
.506 .275 .499 r
.56293 .8083 m .56511 .80882 L .56562 .80908 L F
.942 .819 .694 r
.59195 .81336 m .59404 .81366 L .59262 .81653 L F
.59195 .81336 m .59228 .81495 L .5911 .81548 L F
.59228 .81495 m .59262 .81653 L .5916 .81582 L F
.59228 .81495 m .5916 .81582 L .5911 .81548 L F
.948 .786 .646 r
.59203 .81484 m .59404 .81366 L .59195 .81336 L F
.928 .961 .775 r
.5959 .81028 m .5958 .81046 L .59203 .81484 L F
.5958 .81046 m .59404 .81366 L .59265 .81448 L F
.5958 .81046 m .59265 .81448 L .59203 .81484 L F
0 0 .418 r
.66914 .72329 m .66956 .72604 L .66959 .72417 L F
.53 .286 .491 r
.42938 .76094 m .4291 .76284 L .4271 .76301 L F
.494 .208 .408 r
.43156 .76087 m .4291 .76284 L .42938 .76094 L F
.735 .374 0 r
.67513 .72367 m .67465 .72291 L .67379 .72069 L F
.887 .467 .07 r
.67513 .72367 m .67488 .72484 L .67465 .72291 L F
.67513 .72367 m .6753 .72467 L .67488 .72484 L F
.345 .098 .389 r
.64324 .71477 m .64163 .71344 L .64126 .71559 L F
.64324 .71477 m .64304 .71246 L .64163 .71344 L F
.72 .602 .724 r
.62318 .76866 m .62612 .76873 L .62506 .76583 L F
.721 .578 .694 r
.62318 .76866 m .62404 .7715 L .62612 .76873 L F
.465 .181 .397 r
.39815 .78188 m .39751 .78441 L .3953 .78449 L F
.455 .172 .393 r
.39946 .78401 m .39815 .78188 L .39991 .78138 L F
.39946 .78401 m .39751 .78441 L .39815 .78188 L F
.438 .145 .369 r
.41741 .77112 m .41474 .77341 L .41527 .77144 L F
.658 .711 .887 r
.68564 .74992 m .6864 .74724 L .68387 .74765 L F
.68564 .74992 m .68886 .74749 L .6864 .74724 L F
.155 0 .217 r
.68656 .75169 m .68564 .74992 L .68622 .75189 L F
.68656 .75169 m .68886 .74749 L .68564 .74992 L F
.612 .477 .673 r
.62172 .76087 m .62395 .76042 L .62384 .75824 L F
.687 .592 .744 r
.62279 .76396 m .62395 .76042 L .62172 .76087 L F
.302 .07 .387 r
.38344 .77693 m .38464 .77821 L .38541 .77664 L F
.38344 .77693 m .38302 .77893 L .38464 .77821 L F
.435 .515 .842 r
.67328 .70901 m .67564 .70968 L .674 .71124 L F
.425 .499 .832 r
.67564 .70968 m .67665 .7123 L .674 .71124 L F
.386 .51 .861 r
.674 .71124 m .67665 .7123 L .67685 .7139 L F
.387 0 .156 r
.33778 .7362 m .34066 .73471 L .33851 .73509 L F
.344 .436 .811 r
.66639 .7559 m .66754 .75895 L .66804 .75762 L F
.481 0 0 r
.66754 .75895 m .67033 .76067 L .66949 .76039 L F
.359 0 0 r
.66754 .75895 m .67187 .76054 L .67033 .76067 L F
.481 0 0 r
.66754 .75895 m .66949 .76039 L .66804 .75762 L F
.725 .981 .77 r
.56785 .81251 m .56567 .8146 L .56731 .81365 L F
.623 .109 .004 r
.67187 .76054 m .67372 .76131 L .67033 .76067 L F
.686 .228 .159 r
.4901 .87914 m .49019 .87727 L .48701 .87683 L F
.779 .321 .158 r
.49174 .8792 m .49019 .87727 L .4901 .87914 L F
.6 .71 .921 r
.41671 .73221 m .41516 .73284 L .41364 .73114 L F
.58 .591 .829 r
.41736 .73292 m .41516 .73284 L .41671 .73221 L F
.723 .667 .794 r
.64851 .74507 m .65053 .74486 L .64953 .74178 L F
.679 .642 .806 r
.65053 .74486 m .65283 .74214 L .64953 .74178 L F
.759 .443 .451 r
.58268 .78723 m .57969 .78735 L .5816 .78693 L F
.817 .457 .375 r
.58293 .78953 m .57969 .78735 L .58268 .78723 L F
.24 .726 .926 r
.64182 .72892 m .64421 .72888 L .64504 .72924 L F
.888 .967 .835 r
.64504 .72924 m .64421 .72888 L .64219 .73126 L F
.218 .712 .92 r
.64421 .72888 m .64725 .72927 L .64504 .72924 L F
.64421 .72888 m .64725 .72927 L .64504 .72924 L F
.533 .701 .947 r
.52943 .82319 m .52842 .82457 L .52788 .82433 L F
.52943 .82319 m .53089 .82455 L .52842 .82457 L F
.475 .693 .963 r
.44191 .74958 m .44095 .75072 L .44 .74962 L F
.44191 .74958 m .44229 .75023 L .44095 .75072 L F
.56 .474 .715 r
.44359 .75263 m .44095 .75072 L .44229 .75023 L F
.644 .493 .664 r
.44137 .85326 m .43923 .85601 L .44145 .85561 L F
.171 .479 .896 r
.46999 .85568 m .47069 .8551 L .4682 .85396 L F
.11 .37 .832 r
.46999 .85568 m .47244 .8578 L .47069 .8551 L F
.591 .613 .842 r
.39507 .7232 m .39431 .72621 L .39318 .72419 L F
.39507 .7232 m .39645 .72594 L .39431 .72621 L F
.667 .646 .82 r
.58427 .82279 m .58712 .82004 L .58558 .82291 L F
.378 0 0 r
.69381 .72563 m .6959 .72588 L .69723 .72546 L F
.64 .624 .818 r
.70798 .70531 m .71167 .70791 L .71007 .70667 L F
.784 .73 .802 r
.71007 .70667 m .71167 .70791 L .71402 .70529 L F
.24 .732 .919 r
.58123 .84712 m .58174 .84682 L .57985 .84678 L F
.58123 .84712 m .58244 .84709 L .58174 .84682 L F
.299 0 .13 r
.5132 .82988 m .51425 .83086 L .51485 .82908 L F
.521 .417 .676 r
.42941 .73847 m .42801 .74239 L .42753 .7389 L F
.646 .959 .928 r
.48725 .84686 m .48618 .84773 L .48647 .8482 L F
.927 .881 .461 r
.48618 .84773 m .48549 .8499 L .48647 .8482 L F
.558 .128 .181 r
.48647 .8482 m .48549 .8499 L .48843 .84938 L F
.748 .59 .681 r
.5941 .79781 m .59067 .79769 L .59103 .79528 L F
.771 .533 .574 r
.5941 .79781 m .59104 .79972 L .59067 .79769 L F
.5941 .79781 m .59423 .80006 L .59104 .79972 L F
.703 .537 .661 r
.60898 .77919 m .6112 .77661 L .6091 .77688 L F
.60898 .77919 m .61253 .77926 L .6112 .77661 L F
.678 .536 .685 r
.6112 .77661 m .61441 .77694 L .61332 .77386 L F
.739 .616 .721 r
.61253 .77926 m .61441 .77694 L .6112 .77661 L F
.988 .72 .406 r
.48523 .87241 m .48607 .86999 L .48269 .87112 L F
.695 .561 .699 r
.61976 .76612 m .62284 .76617 L .62279 .76396 L F
.695 .537 .669 r
.61976 .76612 m .62079 .76885 L .62284 .76617 L F
.288 .088 .425 r
.64903 .71244 m .64726 .71348 L .64908 .71063 L F
.674 .534 .686 r
.61332 .77386 m .61652 .77644 L .6165 .77421 L F
.61332 .77386 m .61441 .77694 L .61652 .77644 L F
.567 .497 .735 r
.4376 .87387 m .43912 .87159 L .43702 .87199 L F
.4376 .87387 m .43965 .87371 L .43912 .87159 L F
.627 .548 .747 r
.4376 .87387 m .44065 .87669 L .43965 .87371 L F
.349 .756 .982 r
.59184 .84704 m .5938 .84699 L .59411 .84661 L F
.59184 .84704 m .59411 .84661 L .59214 .84781 L F
.641 .46 .623 r
.45207 .83998 m .44983 .84262 L .45223 .84242 L F
.519 .29 .507 r
.45223 .84242 m .45459 .84001 L .45207 .83998 L F
.387 .641 .957 r
.32058 .6616 m .31996 .66265 L .31854 .66203 L F
.32058 .6616 m .32115 .66293 L .31996 .66265 L F
.78 .712 .788 r
.58037 .82643 m .58101 .82898 L .57828 .82898 L F
.784 .682 .751 r
.57828 .82898 m .58101 .82898 L .579 .83177 L F
0 .112 .647 r
.582 .82885 m .58101 .82898 L .58037 .82643 L F
.02 .495 .875 r
.58337 .82974 m .58101 .82898 L .582 .82885 L F
.684 .144 0 r
.58504 .83123 m .58101 .82898 L .58337 .82974 L F
.396 0 .137 r
.56735 .81858 m .56936 .81804 L .57058 .81632 L F
.697 .319 .329 r
.57058 .81632 m .56936 .81804 L .57273 .81819 L F
.633 .354 .477 r
.57058 .81632 m .57273 .81819 L .57268 .81639 L F
.647 .429 .574 r
.39784 .76826 m .40012 .76839 L .40025 .76616 L F
.482 .291 .545 r
.40025 .76616 m .40012 .76839 L .40198 .76789 L F
.609 .286 .397 r
.40025 .76616 m .40198 .76789 L .40237 .76635 L F
.774 .635 .707 r
.64113 .75226 m .6423 .75338 L .64404 .75246 L F
.988 .807 .416 r
.60717 .83695 m .6074 .83465 L .60661 .83653 L F
.883 .859 .408 r
.6074 .83465 m .60805 .83118 L .60711 .83424 L F
.929 .838 .391 r
.60661 .83653 m .6074 .83465 L .60711 .83424 L F
.57 .094 .086 r
.36135 .75198 m .35952 .75356 L .35766 .75249 L F
.716 .628 .758 r
.62499 .7635 m .62846 .76412 L .62734 .76314 L F
.754 .673 .772 r
.62846 .76412 m .62922 .76039 L .62734 .76314 L F
.182 .405 .844 r
.50459 .84535 m .50486 .84614 L .50179 .8424 L F
.88 .713 .67 r
.67944 .75835 m .67809 .7553 L .67793 .75763 L F
.931 .734 .615 r
.67793 .75763 m .67905 .76063 L .67944 .75835 L F
.503 .153 .306 r
.51804 .8273 m .52 .82891 L .52015 .82713 L F
.014 .187 .698 r
.51986 .82765 m .52 .82891 L .51807 .82732 L F
.51986 .82765 m .51807 .82732 L .51804 .8273 L F
.51986 .82765 m .51804 .8273 L .51657 .82848 L F
.495 .871 .978 r
.51986 .82765 m .51657 .82848 L .5175 .82757 L F
.139 0 0 r
.51986 .82765 m .5175 .82757 L .52028 .82773 L F
.561 .201 .314 r
.52015 .82713 m .52 .82891 L .52196 .82845 L F
.728 .771 .887 r
.52196 .82845 m .51986 .82765 L .52098 .82777 L F
.139 0 0 r
.51986 .82765 m .52028 .82773 L .52098 .82777 L F
.671 .566 .729 r
.65489 .74975 m .65797 .74868 L .65633 .7446 L F
.627 .53 .725 r
.65489 .74975 m .6574 .74975 L .65797 .74868 L F
.65489 .74975 m .65508 .75026 L .6574 .74975 L F
.624 .061 0 r
.5337 .82479 m .53447 .82586 L .53254 .82407 L F
.5337 .82479 m .53611 .82646 L .53447 .82586 L F
.885 .833 .79 r
.61318 .80599 m .61366 .80266 L .61154 .80529 L F
.882 .719 .676 r
.61154 .80529 m .61268 .80828 L .61318 .80599 L F
.617 .82 .979 r
.53738 .84267 m .54075 .84298 L .53953 .84219 L F
.424 .605 .922 r
.54075 .84298 m .54198 .84172 L .53953 .84219 L F
.54075 .84298 m .54255 .84327 L .54198 .84172 L F
.525 .471 .739 r
.65508 .75026 m .65888 .75421 L .6574 .74975 L F
.744 .62 .721 r
.61865 .7738 m .6219 .7741 L .62087 .77112 L F
.746 .6 .694 r
.61865 .7738 m .6199 .77695 L .6219 .7741 L F
.755 .612 .7 r
.6219 .7741 m .6199 .77695 L .62209 .77629 L F
.718 .606 .731 r
.62087 .77112 m .6219 .7741 L .62404 .7715 L F
.76 .666 .758 r
.61783 .77951 m .61983 .77905 L .6199 .77695 L F
.787 .667 .731 r
.61761 .78177 m .61983 .77905 L .61783 .77951 L F
.76 .659 .75 r
.61983 .77905 m .62209 .77629 L .6199 .77695 L F
.771 .589 .652 r
.61761 .78177 m .61914 .78505 L .62076 .78399 L F
.828 .72 .746 r
.61914 .78505 m .61879 .787 L .62076 .78399 L F
.658 .489 .645 r
.44145 .85561 m .44377 .853 L .44137 .85326 L F
.67 .424 .54 r
.48015 .82901 m .48194 .82918 L .48213 .82683 L F
.568 .336 .525 r
.48213 .82683 m .48428 .8288 L .48472 .8273 L F
.48213 .82683 m .48194 .82918 L .48428 .8288 L F
.843 .851 .849 r
.48304 .8666 m .47971 .86786 L .48144 .86586 L F
.863 .875 .845 r
.56466 .77737 m .56161 .77883 L .56353 .77834 L F
0 .111 .655 r
.56569 .77782 m .56466 .77737 L .56353 .77834 L F
.56569 .77782 m .56624 .77852 L .56466 .77737 L F
0 .282 .779 r
.67187 .70718 m .67142 .70752 L .66971 .70761 L F
.67187 .70718 m .67328 .70901 L .67142 .70752 L F
.895 .479 .188 r
.49375 .88146 m .49308 .87987 L .49174 .8792 L F
.729 .47 .536 r
.49703 .88178 m .49308 .87987 L .49375 .88146 L F
0 0 0 r
.57148 .78564 m .57325 .78388 L .57405 .787 L F
.57148 .78564 m .57082 .78682 L .57325 .78388 L F
.687 .592 .744 r
.62279 .76396 m .62499 .7635 L .62395 .76042 L F
.678 .547 .699 r
.62279 .76396 m .62284 .76617 L .62499 .7635 L F
.728 .397 .421 r
.56401 .81818 m .56557 .81597 L .56403 .81571 L F
.56401 .81818 m .56735 .81858 L .56557 .81597 L F
.751 .688 .79 r
.64528 .74476 m .64851 .74507 L .64747 .7422 L F
.763 .643 .729 r
.64528 .74476 m .6464 .7479 L .64851 .74507 L F
.71 .565 .689 r
.64851 .74507 m .6464 .7479 L .64852 .74733 L F
.723 .667 .794 r
.64851 .74507 m .64953 .74178 L .64747 .7422 L F
.578 .062 0 r
.40316 .7431 m .40178 .74397 L .39945 .74282 L F
0 0 0 r
.40368 .74337 m .40316 .7431 L .40429 .74336 L F
.40368 .74337 m .40178 .74397 L .40316 .7431 L F
.922 .958 .79 r
.68491 .73139 m .68544 .72878 L .68445 .73054 L F
.68491 .73139 m .6862 .72925 L .68544 .72878 L F
0 0 .452 r
.6851 .73155 m .68491 .73139 L .68445 .73054 L F
.6851 .73155 m .68664 .73365 L .68491 .73139 L F
.282 .51 .897 r
.6851 .73155 m .68736 .7324 L .68664 .73365 L F
.688 .277 .26 r
.68682 .73315 m .68664 .73365 L .68736 .7324 L F
0 .034 .602 r
.68491 .73139 m .68664 .73365 L .68654 .73395 L F
.688 .277 .26 r
.68532 .73522 m .68664 .73365 L .68682 .73315 L F
0 .034 .602 r
.68654 .73395 m .68664 .73365 L .68723 .73504 L F
.618 .468 .656 r
.44983 .84262 m .44776 .84529 L .44998 .84503 L F
.561 .431 .66 r
.44776 .84529 m .45008 .84737 L .44998 .84503 L F
.44776 .84529 m .44802 .84775 L .45008 .84737 L F
.851 .7 .695 r
.61225 .81379 m .61098 .81118 L .61037 .81342 L F
.792 .587 .624 r
.61037 .81342 m .61241 .81649 L .61225 .81379 L F
.521 .417 .676 r
.42941 .73847 m .42998 .74207 L .42801 .74239 L F
.534 .446 .702 r
.43034 .74432 m .42801 .74239 L .42998 .74207 L F
.43034 .74432 m .42851 .74492 L .42801 .74239 L F
.666 .95 .706 r
.63981 .72444 m .63955 .72433 L .64019 .72447 L F
.63981 .72444 m .63802 .72567 L .63955 .72433 L F
.643 .583 .772 r
.62356 .75592 m .62591 .75561 L .6248 .75261 L F
.637 .527 .711 r
.62609 .75788 m .62356 .75592 L .62384 .75824 L F
.62609 .75788 m .62591 .75561 L .62356 .75592 L F
.724 .971 .931 r
.57891 .7921 m .57702 .7928 L .57799 .79177 L F
.54 .351 .573 r
.57891 .7921 m .57684 .79525 L .57702 .7928 L F
.57891 .7921 m .57901 .795 L .57684 .79525 L F
.702 .966 .938 r
.57891 .7921 m .57992 .79055 L .58137 .79158 L F
.57891 .7921 m .57799 .79177 L .57992 .79055 L F
.769 .637 .715 r
.58137 .79158 m .57901 .795 L .57891 .7921 L F
.452 .574 .886 r
.45592 .88192 m .457 .87987 L .45479 .88099 L F
.45592 .88192 m .45779 .88249 L .457 .87987 L F
.51 .388 .65 r
.62485 .75027 m .62687 .74984 L .6264 .74782 L F
.503 .363 .623 r
.62485 .75027 m .62703 .75217 L .62687 .74984 L F
.567 .358 .557 r
.6248 .75261 m .62703 .75217 L .62485 .75027 L F
.6248 .75261 m .62703 .75217 L .62485 .75027 L F
.743 .606 .705 r
.62284 .76617 m .62079 .76885 L .62318 .76866 L F
.723 .579 .693 r
.62087 .77112 m .62318 .76866 L .62079 .76885 L F
.62087 .77112 m .62404 .7715 L .62318 .76866 L F
.72 .602 .724 r
.62318 .76866 m .62506 .76583 L .62284 .76617 L F
.503 .222 .421 r
.6588 .62893 m .6588 .6306 L .65618 .63102 L F
.54 .283 .476 r
.6588 .62893 m .66096 .63043 L .6588 .6306 L F
.6588 .62893 m .66108 .6286 L .66096 .63043 L F
.673 .7 .867 r
.36313 .75186 m .36456 .75334 L .36634 .75228 L F
.715 .647 .78 r
.42022 .88428 m .42237 .88181 L .42001 .88236 L F
.436 0 0 r
.5816 .78693 m .57969 .78735 L .57776 .78718 L F
.748 .671 .776 r
.52352 .85547 m .52506 .85853 L .52152 .85878 L F
.79 .552 .577 r
.52506 .85853 m .52171 .86035 L .52152 .85878 L F
.52506 .85853 m .52477 .86083 L .52171 .86035 L F
.633 .256 0 r
.52532 .85904 m .52506 .85853 L .52352 .85547 L F
0 0 .279 r
.52588 .85983 m .52477 .86083 L .52506 .85853 L F
.52588 .85983 m .52506 .85853 L .52532 .85904 L F
.283 0 0 r
.35712 .72804 m .36064 .72614 L .35857 .72647 L F
.357 .44 .81 r
.32403 .66307 m .32351 .66563 L .32184 .66298 L F
.32403 .66307 m .32512 .66611 L .32351 .66563 L F
.406 .216 .508 r
.4173 .75799 m .41926 .75517 L .41717 .75564 L F
.382 .794 .98 r
.4751 .86978 m .47251 .86953 L .47512 .86917 L F
.707 .172 0 r
.47546 .87095 m .47704 .87135 L .4751 .86978 L F
.47546 .87095 m .4751 .86978 L .47692 .86874 L F
.279 0 .164 r
.36613 .803 m .36898 .80024 L .36811 .80253 L F
.342 .009 .247 r
.36811 .80253 m .36898 .80024 L .37099 .79949 L F
.839 .586 .557 r
.51979 .8785 m .52281 .87695 L .52065 .87716 L F
.758 .667 .761 r
.57828 .82898 m .579 .83177 L .57613 .83168 L F
.95 .935 .744 r
.579 .83177 m .57667 .83431 L .57613 .83168 L F
.579 .83177 m .57744 .83491 L .57667 .83431 L F
.954 .754 .595 r
.52455 .87851 m .52643 .87673 L .52496 .87617 L F
.37 .492 .852 r
.67842 .71249 m .67685 .7139 L .67665 .7123 L F
.67842 .71249 m .68019 .71531 L .67685 .7139 L F
0 .451 .862 r
.67685 .7139 m .68019 .71531 L .68087 .71611 L F
0 0 .537 r
.54595 .84511 m .54817 .84789 L .54787 .84729 L F
0 .082 .604 r
.54817 .84789 m .5507 .85034 L .54787 .84729 L F
.591 .584 .813 r
.42014 .73454 m .41816 .735 L .41736 .73292 L F
.537 0 0 r
.57988 .81161 m .58239 .81292 L .58396 .8132 L F
.12 .659 .848 r
.58239 .81292 m .58579 .8132 L .58396 .8132 L F
.969 .659 .368 r
.67343 .71856 m .67268 .71997 L .67199 .718 L F
.67343 .71856 m .67379 .72069 L .67268 .71997 L F
.476 0 0 r
.69491 .74135 m .69945 .74193 L .69732 .74229 L F
.557 .394 .615 r
.69945 .74193 m .69759 .74524 L .69732 .74229 L F
.014 .043 .545 r
.66176 .71392 m .66259 .7127 L .66203 .71022 L F
.877 .769 .739 r
.66176 .71392 m .65972 .71343 L .66259 .7127 L F
.66176 .71392 m .66082 .71575 L .65972 .71343 L F
.794 .407 .322 r
.57099 .84501 m .57351 .84596 L .57295 .84741 L F
.375 0 0 r
.57351 .84596 m .57543 .84687 L .57295 .84741 L F
.136 .593 .925 r
.57351 .84596 m .5761 .84681 L .5761 .84672 L F
.5761 .84681 m .57698 .84709 L .5761 .84672 L F
.449 .828 .989 r
.5761 .84672 m .57735 .84596 L .57609 .84656 L F
.375 0 0 r
.57351 .84596 m .57609 .84672 L .57543 .84687 L F
.57609 .84672 m .5761 .84672 L .57543 .84687 L F
.608 .941 .755 r
.57468 .84704 m .57543 .84687 L .57625 .84586 L F
0 0 0 r
.57169 .84804 m .57543 .84687 L .57399 .84756 L F
.608 .941 .755 r
.57399 .84756 m .57543 .84687 L .57468 .84704 L F
.449 .828 .989 r
.5761 .84672 m .57609 .84656 L .57543 .84687 L F
.702 .583 .718 r
.62284 .76617 m .62506 .76583 L .62499 .7635 L F
.627 .641 .845 r
.40311 .7287 m .39945 .72675 L .40147 .72686 L F
.462 .592 .896 r
.40357 .72667 m .40311 .7287 L .40147 .72686 L F
.40357 .72667 m .40495 .72874 L .40311 .7287 L F
.698 .559 .694 r
.6004 .7789 m .60358 .77925 L .60355 .77688 L F
.705 .505 .615 r
.6004 .7789 m .60362 .78158 L .60358 .77925 L F
.6004 .7789 m .60158 .78179 L .60362 .78158 L F
.525 .357 .597 r
.4271 .76301 m .42844 .76787 L .42518 .76819 L F
.43 .3 .602 r
.4293 .76518 m .4271 .76301 L .4291 .76284 L F
.514 .25 .452 r
.43118 .76463 m .43013 .76572 L .4293 .76518 L F
.43 .3 .602 r
.4293 .76518 m .42844 .76787 L .42735 .7639 L F
.349 .819 .905 r
.42824 .76768 m .42844 .76787 L .4293 .76518 L F
.514 .25 .452 r
.43013 .76572 m .42824 .76768 L .4293 .76518 L F
.43 .3 .602 r
.4293 .76518 m .42735 .7639 L .4271 .76301 L F
.837 .638 .633 r
.6755 .74912 m .67858 .74786 L .67627 .74618 L F
.6755 .74912 m .67728 .75019 L .67858 .74786 L F
.652 .352 .45 r
.49424 .84247 m .49282 .84477 L .49096 .8429 L F
.631 .411 .565 r
.40536 .76564 m .40767 .76573 L .40781 .76348 L F
.284 .127 .483 r
.40781 .76348 m .40927 .76456 L .41002 .76337 L F
.40781 .76348 m .40767 .76573 L .40927 .76456 L F
.472 .354 .637 r
.34374 .67348 m .34228 .67642 L .34136 .67407 L F
.34374 .67348 m .34393 .67609 L .34228 .67642 L F
.222 .098 .491 r
.34346 .67792 m .34228 .67642 L .34393 .67609 L F
.34346 .67792 m .34185 .67921 L .34228 .67642 L F
.583 .795 .98 r
.50989 .81872 m .51351 .81935 L .51217 .81878 L F
.419 .811 .986 r
.51217 .81878 m .51351 .81935 L .51568 .819 L F
.669 .63 .802 r
.69153 .72911 m .69473 .73076 L .69371 .72829 L F
.699 .612 .756 r
.69371 .72829 m .69473 .73076 L .69699 .72905 L F
.976 .764 .553 r
.55288 .82903 m .55263 .8314 L .55372 .83189 L F
.947 .672 .483 r
.55263 .8314 m .554 .8341 L .55372 .83189 L F
.745 .372 0 r
.68966 .73646 m .69093 .73919 L .69036 .7377 L F
.645 .804 .959 r
.53951 .81528 m .54026 .81638 L .53714 .81601 L F
.284 .723 .965 r
.54108 .81583 m .54026 .81638 L .53951 .81528 L F
.54108 .81583 m .54241 .81641 L .54026 .81638 L F
.817 .378 .196 r
.48733 .83365 m .48919 .83426 L .48833 .8329 L F
1 .831 .52 r
.4877 .83109 m .48733 .83365 L .48833 .8329 L F
.533 .844 .535 r
.52066 .88175 m .52344 .87902 L .52318 .8796 L F
0 0 .251 r
.71399 .72896 m .71415 .73204 L .71426 .73072 L F
.2 .374 .812 r
.71657 .73374 m .71426 .73072 L .71415 .73204 L F
.368 0 .158 r
.51217 .81878 m .51441 .81828 L .51548 .81607 L F
.083 0 .025 r
.51548 .81607 m .51793 .81763 L .51752 .81699 L F
.51548 .81607 m .51684 .81636 L .51793 .81763 L F
.51548 .81607 m .51441 .81828 L .51684 .81636 L F
.803 .893 .908 r
.46341 .88458 m .46539 .88505 L .46539 .88457 L F
.924 .749 .646 r
.46341 .88458 m .4645 .88726 L .46539 .88505 L F
.654 .597 .779 r
.53212 .84083 m .52909 .83975 L .53086 .83953 L F
.735 .469 .526 r
.52757 .84159 m .53086 .83953 L .52909 .83975 L F
.359 .766 .983 r
.57667 .83431 m .57744 .83491 L .57406 .83444 L F
.851 .739 .739 r
.48269 .87112 m .4861 .86911 L .48483 .86864 L F
.863 .961 .866 r
.4861 .86911 m .48609 .8674 L .48483 .86864 L F
.851 .709 .705 r
.46248 .885 m .4624 .88749 L .46119 .88468 L F
.57 .59 .834 r
.4624 .88749 m .46341 .88458 L .46119 .88468 L F
.4624 .88749 m .4645 .88726 L .46341 .88458 L F
.685 .566 .715 r
.62079 .76885 m .61858 .77146 L .62087 .77112 L F
.744 .62 .721 r
.61865 .7738 m .62087 .77112 L .61858 .77146 L F
.616 .741 .935 r
.70148 .74607 m .70152 .74931 L .70026 .74865 L F
.70148 .74607 m .70437 .74869 L .70152 .74931 L F
.488 .278 .521 r
.65355 .63266 m .65375 .63603 L .65174 .6365 L F
.56 .335 .531 r
.65618 .63102 m .65611 .63354 L .65355 .63266 L F
.564 .337 .53 r
.65611 .63354 m .65375 .63603 L .65355 .63266 L F
.872 .769 .746 r
.65926 .72389 m .65715 .72514 L .65941 .72328 L F
.65968 .72365 m .65812 .72649 L .65715 .72514 L F
.847 .594 .052 r
.65962 .72338 m .65941 .72328 L .65905 .72074 L F
.65968 .72365 m .65941 .72328 L .65962 .72338 L F
.201 0 .195 r
.65715 .72514 m .65807 .72511 L .65941 .72328 L F
.351 .277 .632 r
.65807 .72511 m .65919 .72318 L .65941 .72328 L F
0 0 .349 r
.65905 .72074 m .65941 .72328 L .65981 .72212 L F
.351 .277 .632 r
.65919 .72318 m .65961 .72246 L .65941 .72328 L F
.65961 .72246 m .65981 .72212 L .65941 .72328 L F
.872 .769 .746 r
.65968 .72365 m .65926 .72389 L .65941 .72328 L F
.458 .004 .085 r
.36594 .72515 m .36783 .7254 L .36644 .72463 L F
.511 .54 .822 r
.64264 .72413 m .64137 .72662 L .64019 .72447 L F
.64264 .72413 m .64343 .72664 L .64137 .72662 L F
.572 .458 .685 r
.64343 .72664 m .64182 .72892 L .64137 .72662 L F
.945 .96 .691 r
.71563 .73609 m .71753 .73444 L .71657 .73374 L F
.71563 .73609 m .71628 .73704 L .71753 .73444 L F
.587 .746 .952 r
.68253 .71913 m .68168 .72131 L .68026 .719 L F
.68253 .71913 m .68389 .72087 L .68168 .72131 L F
.759 .659 .751 r
.48317 .83653 m .48461 .83863 L .48441 .83732 L F
.204 0 0 r
.48535 .83678 m .48317 .83653 L .48421 .83719 L F
.4872 .83699 m .48535 .83678 L .48441 .83732 L F
.499 .394 .666 r
.48691 .83987 m .4886 .84036 L .48723 .83708 L F
.587 .935 .941 r
.48687 .83684 m .48663 .83697 L .4872 .83699 L F
.653 .435 .575 r
.48461 .83863 m .4872 .83699 L .48441 .83732 L F
.48461 .83863 m .48691 .83987 L .4872 .83699 L F
.499 .394 .666 r
.48691 .83987 m .48687 .83684 L .4872 .83699 L F
.48687 .83684 m .48686 .83621 L .4872 .83699 L F
.761 .52 .57 r
.48639 .83691 m .48723 .83708 L .48635 .83698 L F
.499 .394 .666 r
.48687 .83684 m .48708 .83673 L .48687 .83678 L F
.761 .52 .57 r
.48686 .83621 m .48708 .83673 L .48639 .83691 L F
.587 .935 .941 r
.48726 .83668 m .48687 .83684 L .4872 .83699 L F
.48708 .83673 m .48687 .83684 L .48726 .83668 L F
.499 .394 .666 r
.48687 .83702 m .48723 .83708 L .48708 .83673 L F
.48687 .83702 m .48708 .83673 L .48687 .83684 L F
.204 0 0 r
.4872 .83699 m .48663 .83697 L .48586 .83684 L F
.761 .52 .57 r
.48708 .83673 m .48723 .83708 L .48639 .83691 L F
.587 .935 .941 r
.48738 .83611 m .4872 .83699 L .48686 .83621 L F
.48727 .83662 m .48708 .83673 L .48726 .83668 L F
.204 0 0 r
.48663 .83697 m .48621 .83696 L .48586 .83684 L F
.761 .52 .57 r
.48686 .83621 m .48639 .83691 L .48527 .83693 L F
.587 .935 .941 r
.48668 .83691 m .48527 .83693 L .48663 .83697 L F
.641 .321 .415 r
.48103 .83953 m .48316 .84146 L .48461 .83863 L F
.759 .659 .751 r
.48317 .83653 m .48103 .83953 L .48461 .83863 L F
.614 .457 .646 r
.48317 .83653 m .48414 .83959 L .48103 .83953 L F
.596 .333 .489 r
.48103 .83953 m .48316 .84146 L .48414 .83959 L F
.634 .309 .403 r
.48078 .8401 m .48242 .83925 L .4826 .83883 L F
.761 .52 .57 r
.48638 .83693 m .48521 .83867 L .48525 .83759 L F
.204 0 0 r
.48586 .83684 m .48621 .83696 L .48317 .83653 L F
.48621 .83696 m .48416 .83672 L .48317 .83653 L F
.509 .396 .661 r
.48481 .83783 m .48317 .83653 L .48409 .8363 L F
.48521 .83867 m .48447 .83789 L .48481 .83783 L F
.48447 .83789 m .48317 .83653 L .48481 .83783 L F
.48521 .83867 m .48414 .83959 L .48317 .83653 L F
.204 0 0 r
.48535 .83678 m .48421 .83719 L .48441 .83732 L F
.48621 .83696 m .48527 .83693 L .48416 .83672 L F
.403 .406 .748 r
.48317 .83653 m .48527 .83693 L .4841 .83349 L F
.509 .396 .661 r
.48521 .83867 m .48409 .8363 L .48527 .83693 L F
.634 .309 .403 r
.48242 .83925 m .48536 .83773 L .48464 .83795 L F
.48536 .83773 m .48646 .83716 L .48499 .8378 L F
.761 .52 .57 r
.48639 .83691 m .48638 .83693 L .48527 .83693 L F
.48638 .83693 m .48525 .83759 L .48527 .83693 L F
.587 .935 .941 r
.48738 .83611 m .48527 .83693 L .48668 .83691 L F
.761 .52 .57 r
.48704 .83617 m .48527 .83693 L .48738 .83611 L F
.48686 .83621 m .48656 .83635 L .48704 .83617 L F
.48656 .83635 m .48527 .83693 L .48704 .83617 L F
.803 .634 .672 r
.4841 .83349 m .48527 .83693 L .48733 .83365 L F
.609 .383 .548 r
.48733 .83365 m .48527 .83693 L .48738 .83611 L F
.716 .374 .397 r
.48409 .8363 m .48738 .83611 L .4864 .83649 L F
.48409 .8363 m .4864 .83649 L .48527 .83693 L F
.403 .406 .748 r
.48317 .83653 m .48359 .83514 L .48409 .8363 L F
.48359 .83514 m .4841 .83349 L .48409 .8363 L F
.638 .701 .892 r
.48272 .8362 m .4842 .83657 L .48409 .8363 L F
.716 .374 .397 r
.48409 .8363 m .48456 .83678 L .48508 .83666 L F
.729 .835 .93 r
.48738 .83611 m .48527 .83693 L .48409 .8363 L F
.716 .374 .397 r
.48409 .8363 m .48508 .83666 L .48738 .83611 L F
.48456 .83678 m .48619 .8371 L .48738 .83611 L F
.499 .394 .666 r
.48691 .83987 m .48723 .83708 L .48687 .83702 L F
.761 .52 .57 r
.48635 .83698 m .48828 .83988 L .48521 .83867 L F
.638 .701 .892 r
.48456 .83678 m .48218 .83811 L .48647 .83715 L F
.48218 .83811 m .48342 .83847 L .48647 .83715 L F
.716 .374 .397 r
.48456 .83678 m .48548 .8377 L .48619 .8371 L F
.761 .52 .57 r
.48723 .83708 m .4886 .84036 L .48635 .83698 L F
0 .364 .792 r
.48521 .83867 m .48691 .83987 L .48461 .83863 L F
0 0 0 r
.48461 .83863 m .48316 .84146 L .48521 .83867 L F
.634 .309 .403 r
.48078 .8401 m .48288 .84022 L .48646 .83716 L F
.761 .52 .57 r
.48828 .83988 m .48675 .83944 L .48521 .83867 L F
.714 .371 .396 r
.48738 .83611 m .48653 .83752 L .48935 .8382 L F
.135 .54 .921 r
.48521 .83867 m .4886 .84036 L .48691 .83987 L F
.13 0 .202 r
.48521 .83867 m .48316 .84146 L .48414 .83959 L F
.646 .326 .416 r
.48653 .83752 m .48288 .84022 L .48331 .84018 L F
.761 .52 .57 r
.48828 .83988 m .4886 .84036 L .48675 .83944 L F
.212 .546 .929 r
.48691 .83987 m .49028 .84166 L .4886 .84036 L F
.542 .152 .252 r
.4886 .84036 m .48801 .84156 L .48691 .83987 L F
.4886 .84036 m .48801 .84156 L .48691 .83987 L F
.634 .353 .475 r
.48268 .8423 m .48726 .83985 L .48288 .84022 L F
.8 .325 .093 r
.48706 .83957 m .48778 .84051 L .48631 .83848 L F
.48631 .83848 m .48742 .84002 L .48881 .84048 L F
.589 .352 .525 r
.48735 .8398 m .48778 .84051 L .48706 .83957 L F
.634 .353 .475 r
.48726 .83985 m .48735 .8398 L .48723 .83982 L F
.48726 .83985 m .48723 .83982 L .48288 .84022 L F
.8 .325 .093 r
.48742 .84002 m .48778 .84051 L .4879 .8405 L F
.48742 .84002 m .4879 .8405 L .48881 .84048 L F
.646 .326 .416 r
.48631 .83848 m .48595 .83869 L .48684 .83925 L F
.48653 .83752 m .48331 .84018 L .48666 .83828 L F
.8 .325 .093 r
.48607 .83829 m .48706 .83957 L .48631 .83848 L F
.646 .326 .416 r
.48684 .83925 m .48595 .83869 L .48687 .83942 L F
.8 .325 .093 r
.48631 .83848 m .48881 .84048 L .48668 .83827 L F
.646 .326 .416 r
.48666 .83828 m .48631 .83848 L .48684 .83925 L F
.589 .352 .525 r
.48735 .8398 m .48706 .83957 L .48607 .83829 L F
.646 .326 .416 r
.48687 .83942 m .48331 .84018 L .48695 .83984 L F
.48595 .83869 m .48331 .84018 L .48687 .83942 L F
.807 .689 .735 r
.4886 .84036 m .49028 .84166 L .49185 .83926 L F
.4886 .84036 m .49185 .83926 L .49084 .84 L F
.8 .325 .093 r
.48668 .83827 m .48881 .84048 L .48935 .8382 L F
.48607 .83829 m .48631 .83848 L .48668 .83827 L F
.714 .371 .396 r
.48653 .83752 m .48607 .83829 L .48668 .83827 L F
.48653 .83752 m .48668 .83827 L .48935 .8382 L F
.646 .326 .416 r
.48646 .83716 m .48646 .83717 L .48653 .83752 L F
.48646 .83717 m .48288 .84022 L .48653 .83752 L F
.48648 .83715 m .48646 .83716 L .48735 .8398 L F
.48646 .83716 m .48695 .83984 L .48735 .8398 L F
.716 .374 .397 r
.48548 .8377 m .48648 .8376 L .48646 .83716 L F
.48646 .83716 m .48646 .83716 L .48646 .83716 L F
.48548 .8377 m .48646 .83716 L .48646 .83716 L F
.48548 .8377 m .48607 .83829 L .48648 .8376 L F
.48646 .83716 m .48648 .8376 L .48688 .83693 L F
.634 .309 .403 r
.48646 .83716 m .48646 .83716 L .48648 .83715 L F
.48078 .8401 m .48646 .83716 L .48646 .83716 L F
.48646 .83716 m .48648 .83715 L .48647 .83715 L F
.48646 .83716 m .48647 .83715 L .48499 .8378 L F
.716 .374 .398 r
.48648 .83715 m .48607 .83829 L .48456 .83678 L F
.716 .374 .397 r
.48548 .8377 m .48648 .83715 L .4862 .8371 L F
.48648 .83715 m .48688 .83693 L .4862 .8371 L F
.587 .935 .941 r
.48738 .83611 m .48663 .83697 L .48727 .83662 L F
.716 .374 .397 r
.4862 .8371 m .48688 .83693 L .48738 .83611 L F
.716 .374 .398 r
.48648 .83715 m .48456 .83678 L .48409 .8363 L F
.638 .701 .892 r
.48099 .83608 m .48099 .83609 L .48456 .83678 L F
.48099 .83609 m .48218 .83811 L .48456 .83678 L F
.48218 .83811 m .4826 .83883 L .48342 .83847 L F
.4842 .83657 m .48648 .83715 L .48409 .8363 L F
.48077 .8357 m .48272 .8362 L .48409 .8363 L F
.48077 .8357 m .48099 .83608 L .48648 .83715 L F
.48099 .83608 m .48647 .83715 L .48648 .83715 L F
.634 .309 .403 r
.48536 .83773 m .48499 .8378 L .48464 .83795 L F
.48242 .83925 m .48464 .83795 L .4826 .83883 L F
0 0 .207 r
.71677 .73833 m .71628 .73704 L .71563 .73609 L F
.71677 .73833 m .71593 .73967 L .71628 .73704 L F
.797 .605 .641 r
.57273 .81819 m .57598 .81621 L .57268 .81639 L F
.57273 .81819 m .57588 .8193 L .57598 .81621 L F
.249 .151 .543 r
.57598 .81621 m .57588 .8193 L .57775 .81742 L F
.846 .687 .684 r
.5882 .79277 m .58754 .79498 L .58625 .79194 L F
.336 .004 .246 r
.38107 .77937 m .3785 .78143 L .38034 .78082 L F
.389 .056 .275 r
.38107 .77937 m .38237 .7803 L .38302 .77893 L F
.38107 .77937 m .38034 .78082 L .38237 .7803 L F
.984 .867 .5 r
.68087 .71611 m .67991 .71743 L .68026 .719 L F
.998 .827 .486 r
.68087 .71611 m .68019 .71531 L .67991 .71743 L F
.946 .916 .545 r
.6114 .82277 m .61154 .82445 L .61249 .82124 L F
.94 .898 .502 r
.61078 .82652 m .61154 .82445 L .6114 .82277 L F
.707 .985 .869 r
.59947 .8441 m .60155 .84342 L .60316 .84219 L F
.64 .126 0 r
.54844 .82176 m .55002 .82347 L .55062 .82382 L F
.836 .426 .263 r
.54961 .82526 m .55062 .82382 L .55002 .82347 L F
.54961 .82526 m .55188 .82611 L .55062 .82382 L F
.838 .708 .72 r
.61456 .79462 m .61549 .79751 L .61607 .79547 L F
.752 .652 .75 r
.62922 .76039 m .6325 .76074 L .63139 .75772 L F
.723 .637 .762 r
.63139 .75772 m .6325 .76074 L .63469 .75814 L F
.685 .54 .683 r
.60676 .77919 m .60898 .77919 L .6091 .77688 L F
.756 .448 .464 r
.57765 .77834 m .58065 .77682 L .5775 .77638 L F
.57765 .77834 m .58093 .77874 L .58065 .77682 L F
.317 0 0 r
.5711 .78168 m .57025 .78218 L .56793 .78216 L F
.795 .4 .306 r
.57325 .78388 m .57025 .78218 L .5711 .78168 L F
.235 .753 .803 r
.48609 .88464 m .48953 .88408 L .48819 .88416 L F
.3 0 0 r
.48953 .88408 m .49154 .88441 L .48819 .88416 L F
.763 .82 .897 r
.59039 .81707 m .59262 .81653 L .58968 .81869 L F
.5911 .81548 m .59228 .8163 L .59039 .81707 L F
.59228 .8163 m .59262 .81653 L .59039 .81707 L F
.5911 .81548 m .59039 .81707 L .59106 .81716 L F
.59039 .81707 m .58968 .81869 L .59106 .81716 L F
.725 .61 .729 r
.58712 .82004 m .59106 .81716 L .58968 .81869 L F
.58712 .82004 m .59024 .82197 L .59106 .81716 L F
.675 .483 .617 r
.58578 .81897 m .59106 .81716 L .58967 .82003 L F
.58568 .81895 m .58653 .81867 L .58578 .81897 L F
.58653 .81867 m .59106 .81716 L .58578 .81897 L F
.759 .57 .641 r
.46948 .86119 m .47369 .86128 L .47196 .85905 L F
0 0 .243 r
.47244 .8578 m .47196 .85905 L .47291 .85785 L F
.282 .416 .82 r
.47196 .85905 m .47456 .86104 L .47291 .85785 L F
.47196 .85905 m .47369 .86128 L .47456 .86104 L F
.604 .496 .704 r
.41854 .7502 m .42092 .7499 L .42033 .74762 L F
.633 .49 .67 r
.4186 .75209 m .42092 .7499 L .41854 .7502 L F
.681 .272 .265 r
.49154 .88441 m .49484 .88447 L .49334 .88602 L F
.433 0 0 r
.49484 .88447 m .49553 .88533 L .49334 .88602 L F
.57 .83 .468 r
.49484 .88447 m .49703 .88178 L .49712 .88485 L F
.642 .517 .696 r
.49326 .88516 m .4957 .88404 L .49315 .88387 L F
.49334 .88602 m .49436 .88516 L .49326 .88516 L F
.49436 .88516 m .4957 .88404 L .49326 .88516 L F
.433 0 0 r
.49484 .88447 m .49712 .88485 L .49603 .88518 L F
.4954 .88517 m .49603 .88518 L .49553 .88533 L F
.49484 .88447 m .49603 .88518 L .4954 .88517 L F
.977 .707 .447 r
.48472 .8273 m .48542 .82938 L .4875 .82672 L F
.48472 .8273 m .48428 .8288 L .48542 .82938 L F
.677 .463 .589 r
.60362 .78158 m .60676 .77919 L .60358 .77925 L F
.60362 .78158 m .60701 .78173 L .60676 .77919 L F
.73 .503 .582 r
.60676 .77919 m .60908 .78167 L .60898 .77919 L F
.60676 .77919 m .60701 .78173 L .60908 .78167 L F
.739 .616 .721 r
.61253 .77926 m .61431 .77929 L .61441 .77694 L F
.724 .509 .6 r
.61253 .77926 m .61434 .78147 L .61431 .77929 L F
.682 .568 .72 r
.61441 .77694 m .61431 .77929 L .61652 .77644 L F
.694 .585 .729 r
.61431 .77929 m .61783 .77951 L .61652 .77644 L F
.76 .618 .702 r
.61434 .78147 m .61783 .77951 L .61431 .77929 L F
.082 .303 .784 r
.49775 .86906 m .49705 .86893 L .49552 .86605 L F
.148 .152 .606 r
.49826 .87169 m .49705 .86893 L .49775 .86906 L F
.746 .368 .336 r
.53294 .832 m .53172 .83344 L .53032 .83176 L F
0 .329 .791 r
.68865 .7354 m .68723 .73504 L .68664 .73365 L F
.68865 .7354 m .68966 .73646 L .68723 .73504 L F
.552 .31 .502 r
.39261 .77356 m .39515 .77113 L .39308 .7716 L F
.573 .877 .993 r
.68275 .71344 m .68388 .7122 L .68176 .71286 L F
.68176 .71286 m .68388 .7122 L .68275 .71344 L F
.658 .489 .645 r
.44145 .85561 m .44393 .85547 L .44377 .853 L F
.586 .427 .633 r
.44377 .853 m .44589 .85272 L .44583 .85036 L F
.626 .487 .672 r
.44393 .85547 m .44589 .85272 L .44377 .853 L F
.828 .668 .684 r
.59103 .79528 m .58808 .79711 L .58754 .79498 L F
.59103 .79528 m .59067 .79769 L .58808 .79711 L F
.479 .447 .745 r
.32808 .66827 m .32701 .67013 L .32697 .66814 L F
.577 .669 .901 r
.49747 .85126 m .49582 .85279 L .49554 .85061 L F
.763 .405 .378 r
.49616 .852 m .49765 .85132 L .49747 .85126 L F
.382 .532 .881 r
.49776 .85127 m .49804 .85229 L .49747 .85126 L F
.763 .405 .378 r
.49765 .85132 m .49776 .85127 L .49747 .85126 L F
.577 .669 .901 r
.49747 .85126 m .49554 .85061 L .4955 .85037 L F
.553 .436 .674 r
.43089 .74737 m .42851 .74492 L .43034 .74432 L F
.43089 .74737 m .42885 .74782 L .42851 .74492 L F
.46 .543 .854 r
.58629 .82905 m .58504 .83123 L .58337 .82974 L F
.58629 .82905 m .58702 .83172 L .58504 .83123 L F
.995 .756 .428 r
.6755 .73155 m .67467 .7285 L .67593 .72931 L F
.438 .396 .714 r
.62577 .74232 m .62749 .74239 L .62743 .74057 L F
.558 .515 .764 r
.62616 .74469 m .62749 .74239 L .62577 .74232 L F
.132 0 0 r
.53163 .8707 m .53272 .86956 L .52807 .87189 L F
.612 .462 .654 r
.52807 .87189 m .53205 .87245 L .53163 .8707 L F
.52807 .87189 m .53057 .87391 L .53205 .87245 L F
.289 .675 .973 r
.69317 .75396 m .69155 .75439 L .69413 .75425 L F
.69317 .75396 m .69085 .75369 L .69155 .75439 L F
.39 .739 .992 r
.69155 .75439 m .69085 .75369 L .68863 .75378 L F
.691 .627 .78 r
.65843 .75516 m .65954 .75821 L .66191 .75597 L F
.784 .73 .802 r
.71007 .70667 m .71402 .70529 L .71312 .70449 L F
.612 .781 .962 r
.42603 .73489 m .42388 .73586 L .42223 .73445 L F
.716 .633 .764 r
.62499 .7635 m .62734 .76314 L .62615 .75998 L F
.709 .63 .766 r
.62734 .76314 m .62922 .76039 L .62615 .75998 L F
.772 .716 .8 r
.64908 .71063 m .64605 .71057 L .64919 .7093 L F
.579 .343 .523 r
.65131 .71029 m .64903 .71244 L .64908 .71063 L F
.526 .614 .883 r
.45276 .88101 m .45345 .87872 L .45142 .87887 L F
.45276 .88101 m .45479 .88099 L .45345 .87872 L F
.781 .928 .931 r
.54382 .80509 m .54468 .80347 L .54558 .80387 L F
.713 .331 .323 r
.49282 .84477 m .48991 .84465 L .49096 .8429 L F
.551 .362 .577 r
.50228 .88286 m .50519 .88174 L .50096 .88175 L F
.50228 .88286 m .50463 .88427 L .50519 .88174 L F
.825 .53 .49 r
.48919 .83426 m .4896 .837 L .49199 .83524 L F
.54 0 0 r
.49516 .83961 m .49338 .83982 L .49185 .83926 L F
.548 .407 .641 r
.49185 .83926 m .49338 .83982 L .49516 .83961 L F
.83 .685 .703 r
.49249 .8365 m .49338 .83982 L .49506 .83693 L F
.382 0 .036 r
.49199 .83524 m .49249 .8365 L .49418 .83678 L F
.539 .238 .405 r
.49199 .83524 m .49418 .83678 L .49441 .8349 L F
.83 .685 .703 r
.49418 .83678 m .49506 .83693 L .49497 .83629 L F
.657 .333 .412 r
.49441 .8349 m .49438 .8366 L .49563 .83595 L F
.83 .685 .703 r
.49438 .8366 m .49497 .83629 L .49494 .83607 L F
.49418 .83678 m .49497 .83629 L .49438 .8366 L F
.657 .333 .412 r
.49438 .8366 m .49437 .83692 L .49563 .83595 L F
.539 .238 .405 r
.49418 .83678 m .49437 .83692 L .49438 .8366 L F
.49418 .83678 m .49438 .8366 L .49441 .8349 L F
.83 .685 .703 r
.49494 .83607 m .49506 .83693 L .49563 .83595 L F
.49249 .8365 m .49418 .83678 L .49494 .83607 L F
.382 0 .036 r
.49418 .83678 m .49249 .8365 L .49437 .83692 L F
.49199 .83524 m .4896 .837 L .49249 .8365 L F
.498 .811 1 r
.57698 .84709 m .57919 .84636 L .5761 .84672 L F
.57698 .84709 m .57985 .84678 L .57919 .84636 L F
0 0 0 r
.41068 .74159 m .4074 .74238 L .40855 .74198 L F
.546 .351 .567 r
.44998 .84503 m .45223 .84242 L .44983 .84262 L F
.768 .645 .727 r
.64318 .74751 m .6464 .7479 L .64528 .74476 L F
0 0 0 r
.5509 .85042 m .55275 .8479 L .55154 .84966 L F
.947 .941 .61 r
.55231 .84755 m .55275 .8479 L .55408 .84436 L F
.961 .912 .552 r
.55154 .84966 m .55275 .8479 L .55231 .84755 L F
.543 .328 .538 r
.66221 .70768 m .66203 .71022 L .66443 .70785 L F
.716 .633 .764 r
.62499 .7635 m .62615 .75998 L .62395 .76042 L F
.221 0 0 r
.65576 .73635 m .65942 .73464 L .65701 .7344 L F
.484 .774 .996 r
.57684 .79525 m .57781 .79408 L .57566 .79442 L F
.57684 .79525 m .57901 .795 L .57781 .79408 L F
.586 .093 .052 r
.54241 .81641 m .54512 .81772 L .5455 .81642 L F
.91 .504 .161 r
.5455 .81642 m .54512 .81772 L .5463 .81832 L F
.691 .947 .958 r
.68544 .72878 m .6862 .72925 L .68814 .72816 L F
.419 .51 .845 r
.64194 .7337 m .64045 .73502 L .64039 .73278 L F
.64194 .7337 m .64333 .73634 L .64045 .73502 L F
.532 .294 .499 r
.45677 .83959 m .45961 .83671 L .45663 .83732 L F
.822 .569 .556 r
.71023 .70191 m .71312 .70449 L .71018 .70309 L F
.893 .732 .675 r
.61442 .79663 m .61549 .79751 L .61456 .79462 L F
.898 .727 .661 r
.61542 .80051 m .61549 .79751 L .61442 .79663 L F
.923 .556 .308 r
.55971 .80015 m .56198 .80275 L .56165 .80224 L F
.544 .331 .542 r
.66029 .73701 m .66258 .73668 L .66279 .73444 L F
.188 0 0 r
.65942 .73464 m .66065 .73476 L .66153 .73384 L F
.408 .145 .4 r
.66065 .73476 m .66121 .73408 L .66153 .73384 L F
.978 .696 .421 r
.66228 .7333 m .66153 .73384 L .66142 .73137 L F
.447 .269 .546 r
.66142 .73137 m .66153 .73384 L .66303 .73182 L F
.408 .145 .4 r
.66121 .73408 m .66303 .73182 L .66153 .73384 L F
.978 .696 .421 r
.66279 .73444 m .66153 .73384 L .66228 .7333 L F
.985 .75 .499 r
.66279 .73444 m .66258 .73668 L .66153 .73384 L F
.76 .578 .651 r
.47512 .86917 m .47251 .86953 L .47067 .86819 L F
.231 .658 .957 r
.69426 .72545 m .69381 .72563 L .69329 .72505 L F
.677 .617 .78 r
.69329 .72505 m .69371 .72829 L .69573 .72606 L F
.231 .658 .957 r
.69426 .72545 m .6959 .72588 L .69381 .72563 L F
.677 .617 .78 r
.69329 .72505 m .69426 .72545 L .6959 .72588 L F
.69329 .72505 m .69458 .72546 L .69494 .72518 L F
.69458 .72546 m .6959 .72588 L .69494 .72518 L F
.585 .353 .531 r
.69622 .72402 m .69555 .72472 L .69494 .72518 L F
.231 .658 .957 r
.69494 .72518 m .6959 .72588 L .69426 .72545 L F
.677 .617 .78 r
.69426 .72545 m .69573 .72606 L .6959 .72588 L F
.585 .353 .531 r
.69555 .72472 m .69398 .72635 L .69494 .72518 L F
.231 .658 .957 r
.69494 .72518 m .69426 .72545 L .69329 .72505 L F
.636 .4 .543 r
.45961 .83671 m .46168 .83688 L .46189 .83457 L F
.748 .499 .555 r
.46189 .83457 m .46469 .83681 L .46206 .83616 L F
.46189 .83457 m .46168 .83688 L .46469 .83681 L F
.187 .32 .768 r
.50457 .87955 m .50677 .88173 L .50653 .87921 L F
.559 .391 .61 r
.50519 .88174 m .50677 .88173 L .50457 .87955 L F
.782 .415 .362 r
.68616 .69679 m .68875 .69724 L .68893 .69778 L F
.821 .891 .892 r
.68977 .6977 m .68796 .70026 L .68691 .69929 L F
.69015 .69748 m .69 .69767 L .68977 .6977 L F
.69015 .69748 m .68691 .69929 L .68919 .69859 L F
.782 .415 .362 r
.68799 .69788 m .68893 .69778 L .68919 .69859 L F
.68616 .69679 m .68893 .69778 L .68799 .69788 L F
.821 .891 .892 r
.69 .69767 m .68796 .70026 L .68977 .6977 L F
.506 .664 .933 r
.68796 .70026 m .68919 .69859 L .68691 .69929 L F
.69 .662 .818 r
.69122 .69917 m .68796 .70026 L .69015 .69748 L F
.69165 .69984 m .69124 .69989 L .69122 .69917 L F
.69124 .69989 m .68796 .70026 L .69122 .69917 L F
.256 0 0 r
.68796 .70026 m .69015 .70022 L .69165 .69984 L F
.721 .673 .803 r
.69128 .69782 m .69165 .69984 L .69015 .69748 L F
.896 .818 .764 r
.68919 .69859 m .69015 .70022 L .69118 .69802 L F
.69118 .69785 m .69118 .69802 L .69128 .69782 L F
.68919 .69859 m .69118 .69802 L .69118 .69785 L F
.506 .664 .933 r
.68796 .70026 m .69015 .70022 L .68919 .69859 L F
.947 .941 .61 r
.55231 .84755 m .55408 .84436 L .55385 .84478 L F
.707 .545 .667 r
.58625 .79194 m .58293 .78953 L .58628 .78989 L F
.625 .19 .194 r
.56871 .77764 m .57219 .77666 L .56992 .77635 L F
0 0 0 r
.35274 .80958 m .35442 .80839 L .35595 .80758 L F
.763 .487 .516 r
.59287 .7815 m .59476 .78377 L .59612 .78174 L F
.711 .42 .482 r
.59476 .78377 m .5982 .78403 L .59612 .78174 L F
.695 .422 .507 r
.59612 .78174 m .5982 .78403 L .59834 .78206 L F
.82 .537 0 r
.55366 .84023 m .55387 .83984 L .55387 .83889 L F
.55366 .84023 m .55441 .84245 L .55387 .83984 L F
.816 .601 .611 r
.53526 .81573 m .53332 .81604 L .53402 .81441 L F
.779 .485 .49 r
.53526 .81573 m .53371 .8181 L .53332 .81604 L F
.553 .598 .853 r
.53577 .81389 m .53526 .81573 L .53402 .81441 L F
.53577 .81389 m .53714 .81601 L .53526 .81573 L F
.749 .446 .47 r
.53705 .81831 m .53526 .81573 L .53714 .81601 L F
.8 .724 .78 r
.33644 .67671 m .33305 .6768 L .33469 .67629 L F
.33644 .67671 m .33414 .67889 L .33305 .6768 L F
0 .164 .684 r
.337 .67667 m .33644 .67671 L .33469 .67629 L F
.337 .67667 m .33828 .67823 L .33644 .67671 L F
.371 .135 .42 r
.32993 .69732 m .32917 .69933 L .32783 .70004 L F
.386 .162 .447 r
.33159 .69632 m .32917 .69933 L .32993 .69732 L F
.474 .424 .721 r
.32874 .66996 m .32766 .67363 L .32701 .67013 L F
.32874 .66996 m .3293 .67337 L .32766 .67363 L F
.439 .091 .278 r
.41284 .77389 m .41185 .77583 L .40983 .77617 L F
.37 .024 .241 r
.41382 .77538 m .41284 .77389 L .41474 .77341 L F
.41382 .77538 m .41185 .77583 L .41284 .77389 L F
.828 .473 0 r
.57348 .82429 m .57429 .82601 L .57392 .82375 L F
.573 .309 .478 r
.46469 .83681 m .46687 .83681 L .46727 .83479 L F
.461 .207 .443 r
.46727 .83479 m .46883 .83637 L .46925 .83433 L F
.46727 .83479 m .46687 .83681 L .46883 .83637 L F
.443 .09 .27 r
.34518 .73309 m .34781 .73153 L .34591 .732 L F
.727 .411 0 r
.61245 .8213 m .61249 .82124 L .61159 .81862 L F
.581 .808 .413 r
.6114 .82277 m .61249 .82124 L .61245 .8213 L F
.643 .56 .746 r
.49657 .8565 m .49441 .85838 L .49348 .85769 L F
.49657 .8565 m .49654 .85852 L .49441 .85838 L F
.822 .354 .095 r
.49651 .86034 m .49348 .85769 L .49441 .85838 L F
.634 .345 .462 r
.49654 .85852 m .49651 .86034 L .49441 .85838 L F
.51 .071 .14 r
.40021 .74392 m .39773 .74291 L .39945 .74282 L F
.40021 .74392 m .39642 .74425 L .39773 .74291 L F
0 0 0 r
.5509 .85042 m .54971 .85248 L .5507 .85034 L F
.993 .787 .521 r
.54971 .85248 m .55072 .85296 L .5509 .85042 L F
.54971 .85248 m .5509 .85042 L .55154 .84966 L F
0 0 0 r
.65922 .62375 m .6599 .62337 L .65788 .62434 L F
.65922 .62375 m .65788 .62434 L .65675 .6242 L F
.982 .744 .5 r
.55188 .82611 m .55288 .82903 L .55304 .82667 L F
.964 .815 .648 r
.47148 .86277 m .47369 .86128 L .46948 .86119 L F
.47148 .86277 m .47272 .86343 L .47369 .86128 L F
.792 .735 .8 r
.47272 .86343 m .47456 .86104 L .47369 .86128 L F
.589 .598 .829 r
.66153 .73384 m .66258 .73668 L .66029 .73701 L F
0 0 0 r
.48843 .84938 m .49063 .84853 L .49218 .84754 L F
.061 .293 .781 r
.49323 .84705 m .49447 .8496 L .49218 .84754 L F
.49323 .84705 m .49218 .84754 L .49063 .84853 L F
.445 .342 .645 r
.5766 .78852 m .57405 .787 L .57776 .78718 L F
.268 0 0 r
.57969 .78735 m .5766 .78852 L .57776 .78718 L F
.823 .734 .767 r
.63984 .7182 m .64045 .71854 L .64126 .71559 L F
.448 .236 .498 r
.64033 .72041 m .64045 .71854 L .63984 .7182 L F
.64033 .72041 m .64185 .72141 L .64045 .71854 L F
.324 .219 .578 r
.64045 .71854 m .64324 .71477 L .64126 .71559 L F
.64045 .71854 m .64345 .71765 L .64324 .71477 L F
0 0 0 r
.64185 .72141 m .64345 .71765 L .64045 .71854 L F
.666 .523 .68 r
.43541 .86589 m .43821 .86628 L .43752 .86357 L F
.662 .547 .714 r
.43541 .86589 m .43619 .8689 L .43821 .86628 L F
.613 .569 .781 r
.43965 .87371 m .44065 .87669 L .44277 .87631 L F
.499 .563 .852 r
.44065 .87669 m .44383 .87935 L .44277 .87631 L F
.875 .609 .533 r
.50995 .87166 m .50764 .87368 L .50855 .87121 L F
.50995 .87166 m .51024 .87399 L .50764 .87368 L F
.317 .65 .969 r
.51144 .87091 m .51224 .872 L .50995 .87166 L F
.764 .394 .353 r
.5142 .874 m .50995 .87166 L .51224 .872 L F
.665 .507 .661 r
.62615 .75998 m .62384 .75824 L .62395 .76042 L F
.62615 .75998 m .62609 .75788 L .62384 .75824 L F
.76 .618 .702 r
.61434 .78147 m .61761 .78177 L .61783 .77951 L F
.713 .594 .721 r
.61652 .77644 m .61783 .77951 L .6199 .77695 L F
.798 .517 .513 r
.53086 .83953 m .53425 .83986 L .53212 .84083 L F
.508 0 0 r
.52826 .84349 m .52579 .84354 L .52687 .84316 L F
.43 .18 .433 r
.33378 .69341 m .33211 .69458 L .33446 .69223 L F
.443 .194 .441 r
.33405 .69517 m .33211 .69458 L .33378 .69341 L F
.33405 .69517 m .33159 .69632 L .33211 .69458 L F
.617 .252 .328 r
.69074 .74149 m .69374 .73969 L .69285 .73894 L F
.69074 .74149 m .69287 .74172 L .69374 .73969 L F
.657 .294 .345 r
.69374 .73969 m .69287 .74172 L .69491 .74135 L F
.618 .524 .725 r
.43619 .8689 m .43702 .87199 L .43912 .87159 L F
.721 .348 .342 r
.49111 .85561 m .48988 .85752 L .48798 .85541 L F
.709 .333 .334 r
.49111 .85561 m .49348 .85769 L .48988 .85752 L F
.646 .369 .485 r
.49322 .85586 m .49348 .85769 L .49111 .85561 L F
.928 .961 .775 r
.5959 .81028 m .59203 .81484 L .59478 .80948 L F
.648 .76 .931 r
.39318 .72419 m .39125 .72529 L .38968 .7237 L F
.826 .754 .784 r
.66082 .71575 m .65807 .71587 L .65972 .71343 L F
.829 .734 .76 r
.66082 .71575 m .65922 .71849 L .65807 .71587 L F
.673 .467 .599 r
.60908 .78167 m .61253 .77926 L .60898 .77919 L F
.664 .551 .716 r
.43821 .86628 m .43619 .8689 L .43861 .8687 L F
.618 .524 .725 r
.43619 .8689 m .43912 .87159 L .43861 .8687 L F
.774 .682 .761 r
.63566 .75244 m .63355 .75513 L .63675 .75541 L F
.778 .665 .739 r
.63355 .75513 m .63469 .75814 L .63675 .75541 L F
.716 .652 .785 r
.63566 .75244 m .63675 .75541 L .63901 .753 L F
.983 .738 .484 r
.46507 .85278 m .46505 .85556 L .46615 .85579 L F
.748 .298 .184 r
.4682 .85396 m .46507 .85278 L .46615 .85579 L F
.081 .227 .716 r
.46712 .85491 m .46615 .85579 L .46505 .85556 L F
.46712 .85491 m .46862 .85869 L .46615 .85579 L F
.506 .655 .927 r
.41743 .74478 m .41743 .74232 L .41563 .74233 L F
.41743 .74478 m .4192 .74445 L .41743 .74232 L F
.301 0 .122 r
.36152 .80498 m .36417 .80339 L .36332 .80434 L F
.359 0 .167 r
.36332 .80434 m .36417 .80339 L .36613 .803 L F
.582 .404 .605 r
.5721 .83089 m .57098 .83063 L .5725 .83077 L F
.5721 .83089 m .57009 .82912 L .57098 .83063 L F
.628 .508 .697 r
.44145 .85561 m .44435 .85818 L .44393 .85547 L F
.44145 .85561 m .44227 .85858 L .44435 .85818 L F
.27 .774 .775 r
.35632 .79257 m .35718 .79219 L .35825 .79206 L F
.35632 .79257 m .35506 .79277 L .35718 .79219 L F
.688 .62 .775 r
.44277 .87631 m .44383 .87935 L .44653 .87885 L F
.191 0 0 r
.52007 .83129 m .51878 .83106 L .52075 .83084 L F
.52007 .83129 m .518 .83176 L .51878 .83106 L F
.381 .163 .453 r
.33593 .69127 m .33446 .69223 L .33651 .68949 L F
.435 .216 .48 r
.33593 .69127 m .33378 .69341 L .33446 .69223 L F
.676 .694 .859 r
.68814 .72816 m .69153 .72911 L .69022 .72768 L F
.731 .744 .862 r
.69022 .72768 m .69153 .72911 L .69371 .72829 L F
.801 .515 .504 r
.53849 .83465 m .54235 .83712 L .54086 .83431 L F
.53849 .83465 m .53893 .83735 L .54235 .83712 L F
.703 .395 .452 r
.53838 .83917 m .54235 .83712 L .53893 .83735 L F
.53838 .83917 m .54164 .83952 L .54235 .83712 L F
.583 .578 .813 r
.54086 .83431 m .54235 .83712 L .54403 .83676 L F
.626 .316 .426 r
.54235 .83712 m .54383 .83929 L .54403 .83676 L F
.54235 .83712 m .54164 .83952 L .54383 .83929 L F
.064 .608 .844 r
.6571 .72172 m .65673 .72137 L .65348 .72112 L F
.603 .563 .782 r
.65905 .72074 m .6571 .72172 L .65568 .71814 L F
.601 .11 .062 r
.65905 .72074 m .65673 .72137 L .6571 .72172 L F
.692 .526 .657 r
.49582 .85279 m .49657 .8565 L .49322 .85586 L F
.577 .669 .901 r
.49747 .85126 m .49804 .85229 L .49582 .85279 L F
.6 .488 .698 r
.49804 .85229 m .49657 .8565 L .49582 .85279 L F
.818 .703 .738 r
.61359 .78952 m .61659 .78958 L .61553 .78672 L F
.811 .626 .652 r
.61348 .79171 m .61659 .78958 L .61359 .78952 L F
.61348 .79171 m .61614 .79215 L .61659 .78958 L F
.772 .682 .764 r
.61553 .78672 m .61659 .78958 L .61879 .787 L F
.224 .743 .849 r
.58244 .84709 m .5839 .84672 L .58174 .84682 L F
.58244 .84709 m .58442 .84679 L .5839 .84672 L F
.517 .27 .479 r
.43883 .75514 m .4391 .75716 L .43635 .75754 L F
.585 .36 .541 r
.44087 .7549 m .4391 .75716 L .43883 .75514 L F
.871 .44 .178 r
.49048 .86785 m .49198 .86862 L .49211 .86829 L F
0 0 .536 r
.49198 .86862 m .49366 .87104 L .49211 .86829 L F
.907 .727 .646 r
.61128 .80735 m .61268 .80828 L .61154 .80529 L F
.869 .766 .746 r
.61098 .81118 m .61268 .80828 L .61128 .80735 L F
.432 .219 .487 r
.32917 .69933 m .32748 .70219 L .32783 .70004 L F
.614 .866 .99 r
.69546 .74976 m .69836 .74982 L .69629 .75058 L F
.496 .309 .557 r
.65972 .71343 m .65807 .71587 L .65781 .71323 L F
.775 .669 .746 r
.61553 .78672 m .61879 .787 L .61914 .78505 L F
0 0 .251 r
.71399 .72896 m .71426 .73072 L .71542 .72846 L F
.341 .105 .404 r
.41737 .92405 m .41595 .92483 L .41525 .92671 L F
.178 0 .075 r
.38083 .79428 m .37803 .79635 L .37869 .7948 L F
.673 .467 .599 r
.60908 .78167 m .61251 .78176 L .61253 .77926 L F
.724 .509 .6 r
.61253 .77926 m .61251 .78176 L .61434 .78147 L F
.724 .542 .645 r
.5982 .78403 m .60158 .78179 L .59834 .78206 L F
.479 .447 .745 r
.32808 .66827 m .32874 .66996 L .32701 .67013 L F
.76 .576 .648 r
.61432 .78388 m .61761 .78177 L .61434 .78147 L F
.61432 .78388 m .6174 .78409 L .61761 .78177 L F
.778 .592 .648 r
.6174 .78409 m .61914 .78505 L .61761 .78177 L F
.733 .685 .804 r
.63901 .753 m .6423 .75338 L .64113 .75226 L F
.898 .727 .661 r
.61542 .80051 m .61442 .79663 L .61297 .79996 L F
.894 .792 .741 r
.61366 .80266 m .61542 .80051 L .61297 .79996 L F
.4 .486 .832 r
.70798 .70531 m .71017 .70412 L .70734 .70315 L F
.416 .525 .861 r
.70798 .70531 m .71007 .70667 L .71017 .70412 L F
.614 .444 .628 r
.43752 .86357 m .44019 .86367 L .4401 .86108 L F
.657 .517 .682 r
.43752 .86357 m .44054 .86595 L .44019 .86367 L F
.43752 .86357 m .43821 .86628 L .44054 .86595 L F
.555 .342 .545 r
.6588 .6306 m .65611 .63354 L .65618 .63102 L F
.767 .68 .767 r
.43304 .88201 m .43674 .88243 L .4349 .87973 L F
.629 .485 .668 r
.44589 .85272 m .44796 .85002 L .44583 .85036 L F
.715 .585 .708 r
.61652 .77644 m .6199 .77695 L .61865 .7738 L F
.526 .192 .345 r
.40775 .77648 m .40682 .77874 L .40458 .77882 L F
.422 .091 .297 r
.40874 .77831 m .40775 .77648 L .40983 .77617 L F
.40874 .77831 m .40682 .77874 L .40775 .77648 L F
.521 .677 .935 r
.70644 .70178 m .70734 .70315 L .70511 .70322 L F
.70511 .70322 m .70734 .70315 L .70644 .70178 L F
.558 .515 .764 r
.62616 .74469 m .6283 .74448 L .62749 .74239 L F
.486 .387 .668 r
.62616 .74469 m .6287 .74682 L .6283 .74448 L F
.62616 .74469 m .6264 .74782 L .6287 .74682 L F
.663 .701 .875 r
.39945 .72675 m .39645 .72594 L .39841 .72567 L F
.401 .641 .954 r
.40033 .72557 m .39945 .72675 L .39841 .72567 L F
.40033 .72557 m .40147 .72686 L .39945 .72675 L F
.517 .159 .298 r
.37525 .78369 m .37741 .78361 L .3785 .78143 L F
.375 .018 .224 r
.3785 .78143 m .37937 .78316 L .38034 .78082 L F
.3785 .78143 m .37741 .78361 L .37937 .78316 L F
.771 .421 .393 r
.50828 .88062 m .50978 .88004 L .50653 .87921 L F
0 0 0 r
.63215 .73432 m .63323 .73095 L .6312 .73179 L F
.63215 .73432 m .63428 .73165 L .63323 .73095 L F
.63215 .73432 m .63349 .73353 L .63428 .73165 L F
0 0 .034 r
.63215 .73432 m .6316 .73626 L .63349 .73353 L F
.654 .325 .403 r
.58412 .77911 m .58634 .78103 L .58737 .77888 L F
.786 .544 .571 r
.58634 .78103 m .58945 .77912 L .58737 .77888 L F
.486 0 0 r
.51294 .88393 m .51598 .88386 L .51528 .88446 L F
0 0 0 r
.51598 .88386 m .51895 .88282 L .51723 .88373 L F
.51528 .88446 m .51598 .88386 L .51723 .88373 L F
.528 .223 .395 r
.39751 .78441 m .39479 .78628 L .3953 .78449 L F
.425 .205 .474 r
.3382 .69046 m .33651 .68949 L .33822 .68885 L F
.3382 .69046 m .33593 .69127 L .33651 .68949 L F
.664 .9 .561 r
.53366 .86834 m .53272 .86956 L .53163 .8707 L F
.907 .72 .639 r
.53402 .81441 m .53124 .81515 L .53092 .81399 L F
.53402 .81441 m .53332 .81604 L .53124 .81515 L F
.503 .819 1 r
.53449 .81314 m .53402 .81441 L .53282 .81257 L F
.53449 .81314 m .53577 .81389 L .53402 .81441 L F
.874 .468 .019 r
.56027 .82436 m .56108 .82629 L .55947 .82366 L F
.493 .366 .636 r
.6597 .74936 m .66165 .74918 L .66153 .74707 L F
.6597 .74936 m .66153 .74707 L .66095 .74882 L F
.491 .469 .76 r
.65633 .7446 m .65797 .74868 L .66095 .74882 L F
.591 .69 .911 r
.6574 .74975 m .66095 .74882 L .65797 .74868 L F
.332 0 .095 r
.39071 .77406 m .39135 .77545 L .39261 .77356 L F
.39071 .77406 m .38939 .77587 L .39135 .77545 L F
.891 .559 .065 r
.56246 .83153 m .5636 .83443 L .56304 .83381 L F
.954 .749 .293 r
.5636 .83443 m .56309 .83619 L .56304 .83381 L F
.5636 .83443 m .56354 .83684 L .56309 .83619 L F
.806 .549 .549 r
.59104 .79972 m .58808 .79711 L .59067 .79769 L F
.714 .583 .707 r
.6165 .77421 m .61652 .77644 L .61865 .7738 L F
.728 .691 .815 r
.65807 .71587 m .65922 .71849 L .65568 .71814 L F
.603 .563 .782 r
.65905 .72074 m .65568 .71814 L .65922 .71849 L F
.474 .243 .483 r
.56293 .8083 m .5608 .81073 L .56221 .81014 L F
.56293 .8083 m .5608 .81073 L .56221 .81014 L F
.919 .97 .78 r
.56244 .8075 m .56293 .8083 L .56476 .80544 L F
.78 .338 .2 r
.56244 .8075 m .56221 .81014 L .56293 .8083 L F
.506 .275 .499 r
.56293 .8083 m .56221 .81014 L .56511 .80882 L F
.86 .71 .694 r
.49994 .85271 m .5037 .85245 L .50073 .8551 L F
.7 .418 .494 r
.50405 .853 m .50073 .8551 L .5037 .85245 L F
.606 .42 .605 r
.44802 .84775 m .45017 .84965 L .45008 .84737 L F
.44802 .84775 m .44796 .85002 L .45017 .84965 L F
.687 .631 .788 r
.69371 .72829 m .69699 .72905 L .6959 .72588 L F
.562 .56 .809 r
.43299 .74699 m .43226 .75058 L .43089 .74737 L F
.43299 .74699 m .43439 .75023 L .43226 .75058 L F
.909 .713 .625 r
.67855 .75313 m .67728 .75019 L .67669 .75236 L F
.843 .669 .666 r
.67669 .75236 m .67809 .7553 L .67855 .75313 L F
.42 .071 .265 r
.39724 .77069 m .40012 .76839 L .39784 .76826 L F
.597 .929 .96 r
.53205 .87245 m .53571 .87158 L .5347 .87174 L F
0 0 0 r
.53571 .87158 m .53786 .8689 L .53682 .87106 L F
.316 .804 .789 r
.5347 .87174 m .53571 .87158 L .53682 .87106 L F
.433 .785 .997 r
.41068 .74159 m .41397 .7421 L .41256 .74164 L F
0 .551 .821 r
.41563 .74233 m .41256 .74164 L .41397 .7421 L F
.575 .846 .996 r
.38889 .74607 m .39011 .74676 L .39204 .74616 L F
.769 .637 .715 r
.58137 .79158 m .58233 .79527 L .57901 .795 L F
.577 .823 .991 r
.57901 .795 m .58233 .79527 L .58107 .79442 L F
.097 .19 .673 r
.58325 .79401 m .58233 .79527 L .58137 .79158 L F
.532 .806 .996 r
.58107 .79442 m .58233 .79527 L .58325 .79401 L F
.571 .522 .761 r
.50295 .83899 m .50179 .8424 L .50072 .83924 L F
.50295 .83899 m .50388 .84213 L .50179 .8424 L F
.182 .405 .844 r
.50459 .84535 m .50179 .8424 L .50388 .84213 L F
.638 .864 .984 r
.46879 .8823 m .47199 .88226 L .47097 .88126 L F
.475 .723 .978 r
.47097 .88126 m .47199 .88226 L .4732 .88114 L F
.435 .65 .95 r
.47199 .88226 m .47386 .88236 L .4732 .88114 L F
.561 .201 .314 r
.52015 .82713 m .52196 .82845 L .52328 .82652 L F
.531 .138 .24 r
.52196 .82845 m .52552 .82674 L .52328 .82652 L F
.643 .178 .133 r
.49485 .88225 m .49703 .88178 L .49443 .88153 L F
0 0 .411 r
.49459 .88134 m .49526 .88298 L .49485 .88225 L F
.768 .424 .403 r
.4957 .88404 m .49703 .88178 L .49485 .88225 L F
0 0 .411 r
.49526 .88298 m .4957 .88404 L .49485 .88225 L F
.643 .178 .133 r
.49485 .88225 m .49443 .88153 L .49375 .88146 L F
.53 .406 .656 r
.4991 .88431 m .49712 .88485 L .49703 .88178 L F
.768 .424 .403 r
.4957 .88404 m .4991 .88431 L .49703 .88178 L F
.357 0 0 r
.63569 .73027 m .63428 .73165 L .63323 .73095 L F
.034 0 .025 r
.63428 .73165 m .63506 .73246 L .63323 .73095 L F
.63428 .73165 m .63349 .73353 L .63506 .73246 L F
.353 .757 .983 r
.56793 .78216 m .56456 .78162 L .56575 .78264 L F
.576 .429 .645 r
.54086 .83431 m .54292 .83136 L .54065 .83168 L F
.454 0 .045 r
.54292 .83136 m .53945 .83268 L .54065 .83168 L F
.447 .235 .498 r
.37575 .71846 m .37769 .71813 L .37786 .71579 L F
.37575 .71846 m .37769 .71813 L .37786 .71579 L F
.76 .246 0 r
.68622 .75189 m .68863 .75378 L .68744 .75345 L F
.335 .745 .98 r
.68863 .75378 m .68939 .75317 L .68744 .75345 L F
.68863 .75378 m .69085 .75369 L .68939 .75317 L F
.89 .579 .075 r
.56198 .82931 m .56196 .83086 L .56149 .82861 L F
.56198 .82931 m .56246 .83153 L .56196 .83086 L F
.438 0 0 r
.50062 .83718 m .4975 .83709 L .49799 .83692 L F
.781 .681 .753 r
.49955 .83381 m .4975 .83709 L .50062 .83718 L F
.653 .609 .792 r
.49955 .83381 m .50062 .83718 L .50289 .83696 L F
.584 .382 .573 r
.50289 .83696 m .50072 .83924 L .50062 .83718 L F
.50289 .83696 m .50072 .83924 L .50062 .83718 L F
.863 .735 .719 r
.56735 .81858 m .56659 .82143 L .56895 .82136 L F
.989 .812 .572 r
.56737 .82301 m .56895 .82136 L .56703 .82142 L F
.56737 .82301 m .56835 .82397 L .56895 .82136 L F
.401 .197 .484 r
.56895 .82136 m .56835 .82397 L .57081 .82077 L F
.875 .894 .843 r
.57081 .82077 m .56835 .82397 L .56737 .82301 L F
.57081 .82077 m .56737 .82301 L .56906 .82143 L F
.989 .812 .572 r
.56737 .82301 m .56703 .82142 L .56659 .82143 L F
.967 .906 .548 r
.56624 .8199 m .56659 .82143 L .5668 .82066 L F
.56624 .8199 m .5668 .82066 L .56735 .81858 L F
.56624 .8199 m .56735 .81858 L .56401 .81818 L F
0 .13 .603 r
.56501 .81879 m .56624 .8199 L .56538 .81923 L F
.56501 .81879 m .56538 .81923 L .56401 .81818 L F
.179 .714 .804 r
.56185 .81914 m .56501 .81879 L .56287 .81813 L F
0 0 0 r
.56491 .81867 m .56501 .81879 L .56397 .81886 L F
.56608 .81843 m .56501 .81879 L .56491 .81867 L F
.312 .732 .975 r
.56487 .81886 m .56624 .8199 L .56501 .81879 L F
.56486 .81886 m .56489 .81888 L .56487 .81886 L F
.56489 .81888 m .56624 .8199 L .56487 .81886 L F
.727 .643 .765 r
.56397 .81886 m .56575 .8219 L .56611 .82148 L F
.312 .732 .975 r
.56486 .81886 m .56567 .81911 L .56624 .8199 L F
.515 .526 .805 r
.56895 .82136 m .56936 .81804 L .56735 .81858 L F
.56895 .82136 m .57081 .82077 L .56936 .81804 L F
.312 .732 .975 r
.56567 .81911 m .56924 .82018 L .56624 .8199 L F
.153 .132 .579 r
.56753 .8214 m .56659 .82143 L .56624 .8199 L F
.16 .314 .772 r
.5666 .8209 m .56707 .82035 L .56906 .82143 L F
.153 .132 .579 r
.56784 .82139 m .56753 .8214 L .56624 .8199 L F
.16 .314 .772 r
.56685 .82061 m .56624 .8199 L .56707 .82035 L F
.5666 .8209 m .56624 .8199 L .56685 .82061 L F
.153 .132 .579 r
.56753 .8214 m .56737 .82301 L .56659 .82143 L F
.16 .314 .772 r
.56737 .82301 m .56756 .82111 L .56906 .82143 L F
.153 .132 .579 r
.56784 .82139 m .56737 .82301 L .56753 .8214 L F
.16 .314 .772 r
.56737 .82301 m .5666 .8209 L .56756 .82111 L F
.545 .727 .959 r
.56924 .82018 m .56906 .82143 L .56624 .8199 L F
.16 .314 .772 r
.56737 .82301 m .5677 .8227 L .56769 .82268 L F
0 0 .396 r
.56737 .82301 m .56842 .82443 L .5684 .82206 L F
.887 .747 .702 r
.56769 .82268 m .56755 .82388 L .56737 .82301 L F
0 0 .396 r
.56737 .82301 m .56738 .82536 L .56842 .82443 L F
.887 .747 .702 r
.56755 .82388 m .56738 .82536 L .56737 .82301 L F
.56769 .82268 m .56586 .82504 L .56738 .82536 L F
.56784 .82139 m .56769 .82268 L .56737 .82301 L F
.56784 .82139 m .56747 .82207 L .56769 .82268 L F
.16 .314 .772 r
.56737 .82301 m .56744 .82294 L .56624 .8199 L F
.951 .952 .663 r
.56748 .82181 m .56747 .82207 L .56784 .82139 L F
.16 .314 .772 r
.56744 .82294 m .56751 .82117 L .56624 .8199 L F
.947 .747 .6 r
.56575 .8219 m .5654 .82426 L .56748 .82181 L F
.56737 .82151 m .56748 .82181 L .56784 .82139 L F
.56575 .8219 m .56748 .82181 L .56737 .82151 L F
.16 .314 .772 r
.56748 .82181 m .56835 .82202 L .56751 .82117 L F
.56744 .82294 m .56778 .82259 L .56748 .82181 L F
.56778 .82259 m .56835 .82202 L .56748 .82181 L F
.951 .952 .663 r
.5654 .82426 m .56586 .82504 L .56747 .82207 L F
.758 .633 .722 r
.56936 .81804 m .57081 .82077 L .57273 .81819 L F
.613 .824 .981 r
.57052 .81941 m .56924 .82018 L .56486 .81886 L F
.773 .719 .802 r
.56772 .81959 m .5674 .81996 L .5684 .82206 L F
.582 .06 0 r
.56624 .8199 m .5684 .82206 L .56784 .82139 L F
.773 .719 .802 r
.5674 .81996 m .56575 .8219 L .56676 .82196 L F
.5674 .81996 m .56676 .82196 L .5684 .82206 L F
.951 .952 .663 r
.56639 .8231 m .56747 .82207 L .56748 .82181 L F
.5654 .82426 m .56633 .82327 L .56639 .8231 L F
.56633 .82327 m .56747 .82207 L .56639 .8231 L F
.887 .747 .702 r
.56747 .82207 m .56586 .82504 L .56769 .82268 L F
.16 .314 .772 r
.56769 .82268 m .5684 .82206 L .56835 .82202 L F
.5677 .8227 m .5684 .82206 L .56769 .82268 L F
.727 .643 .765 r
.56497 .81905 m .56611 .82148 L .56772 .81959 L F
.56397 .81886 m .56611 .82148 L .56497 .81905 L F
.731 .744 .862 r
.69022 .72768 m .69371 .72829 L .69329 .72505 L F
.771 .683 .766 r
.69022 .72768 m .69371 .72829 L .69329 .72505 L F
.227 0 .126 r
.37891 .74875 m .37673 .74989 L .37931 .74787 L F
.445 .017 .13 r
.38122 .74871 m .37891 .74875 L .37931 .74787 L F
.968 .934 .646 r
.48293 .86116 m .48166 .86365 L .48109 .86018 L F
.765 .511 .55 r
.47695 .86267 m .48128 .86327 L .48109 .86018 L F
.48128 .86327 m .48225 .8634 L .48199 .86269 L F
.48128 .86327 m .48199 .86269 L .48109 .86018 L F
.968 .934 .646 r
.48227 .86246 m .48206 .86319 L .48203 .86293 L F
0 0 .326 r
.48194 .86234 m .48225 .8634 L .48217 .86294 L F
.48109 .86018 m .48199 .86269 L .48194 .86234 L F
.48199 .86269 m .48225 .8634 L .48194 .86234 L F
.968 .934 .646 r
.48227 .86246 m .48391 .86112 L .48206 .86319 L F
.48203 .86293 m .48206 .86319 L .48166 .86365 L F
.48293 .86116 m .48391 .86112 L .48227 .86246 L F
.48391 .86112 m .48391 .86112 L .48227 .86246 L F
0 .36 .699 r
.48105 .88394 m .48142 .88401 L .48053 .88349 L F
.48105 .88394 m .48269 .88456 L .48142 .88401 L F
.519 .29 .507 r
.45223 .84242 m .45423 .84213 L .45459 .84001 L F
.575 .354 .543 r
.45423 .84213 m .45677 .83959 L .45459 .84001 L F
.64 .715 .901 r
.42962 .73653 m .42603 .73489 L .42785 .73468 L F
.337 .545 .908 r
.42901 .73433 m .42962 .73653 L .42785 .73468 L F
.42901 .73433 m .43092 .73644 L .42962 .73653 L F
.698 .908 .557 r
.5721 .83089 m .5725 .83077 L .57346 .8294 L F
.478 .707 .97 r
.52926 .81255 m .5285 .81397 L .52735 .81344 L F
.52926 .81255 m .53092 .81399 L .5285 .81397 L F
.52926 .81255 m .5285 .81397 L .52735 .81344 L F
.52926 .81255 m .53092 .81399 L .5285 .81397 L F
.424 .222 .5 r
.53541 .81872 m .53504 .82105 L .53705 .81831 L F
.706 .734 .873 r
.65715 .72514 m .65812 .72649 L .65477 .72613 L F
.714 .549 .664 r
.65812 .72649 m .65616 .72884 L .65477 .72613 L F
.65812 .72649 m .65785 .72942 L .65616 .72884 L F
.727 .471 .541 r
.34136 .67407 m .34393 .67609 L .34374 .67348 L F
.34136 .67407 m .34065 .67623 L .34393 .67609 L F
.852 .756 .756 r
.69128 .69782 m .69015 .70022 L .69165 .69984 L F
.661 .48 .629 r
.4401 .86108 m .44249 .86328 L .4423 .86087 L F
.4401 .86108 m .44019 .86367 L .44249 .86328 L F
.409 .102 .33 r
.40237 .76635 m .40395 .76717 L .40536 .76564 L F
.032 0 0 r
.40536 .76564 m .40656 .76558 L .40767 .76573 L F
.40536 .76564 m .40395 .76717 L .40656 .76558 L F
.723 .638 .763 r
.63139 .75772 m .63469 .75814 L .63355 .75513 L F
.523 .039 .049 r
.37048 .72408 m .37357 .72404 L .37153 .72429 L F
.465 .193 .415 r
.42179 .76851 m .41942 .77074 L .41966 .76853 L F
.409 .102 .33 r
.40237 .76635 m .40198 .76789 L .40395 .76717 L F
.358 0 .042 r
.36152 .80498 m .36088 .80588 L .35753 .80709 L F
.177 0 0 r
.36287 .8052 m .36152 .80498 L .36332 .80434 L F
.36287 .8052 m .36088 .80588 L .36152 .80498 L F
.436 .493 .82 r
.33177 .67475 m .33075 .67677 L .3293 .67337 L F
.544 .626 .883 r
.33177 .67475 m .33305 .6768 L .33075 .67677 L F
0 0 .348 r
.53775 .86791 m .53786 .8689 L .53777 .86825 L F
.87 .87 .426 r
.53682 .87106 m .53786 .8689 L .53775 .86791 L F
0 0 .418 r
.66914 .72329 m .66976 .7251 L .66956 .72604 L F
.902 .523 .078 r
.66942 .72749 m .67026 .72833 L .66956 .72604 L F
.66942 .72749 m .66956 .72604 L .66976 .7251 L F
.063 0 0 r
.64304 .71246 m .64501 .71203 L .64605 .71057 L F
.365 .19 .506 r
.64324 .71477 m .64501 .71203 L .64304 .71246 L F
.216 .709 .921 r
.37747 .72344 m .37688 .72388 L .37567 .72374 L F
.37747 .72344 m .37878 .72386 L .37688 .72388 L F
.231 0 0 r
.37117 .75177 m .36862 .75168 L .36929 .75198 L F
.798 .517 .513 r
.53086 .83953 m .53413 .84226 L .53425 .83986 L F
0 .068 .57 r
.53425 .83986 m .53467 .84012 L .53323 .83881 L F
.53425 .83986 m .5358 .84127 L .53467 .84012 L F
.589 .378 .563 r
.53425 .83986 m .53413 .84226 L .5358 .84127 L F
.685 .611 .767 r
.52114 .85511 m .52152 .85878 L .5184 .85698 L F
.802 .448 .386 r
.5184 .85698 m .52152 .85878 L .52171 .86035 L F
.724 .639 .763 r
.52352 .85547 m .52152 .85878 L .52114 .85511 L F
.687 .321 .348 r
.38478 .7474 m .38366 .74932 L .38122 .74871 L F
.251 0 .105 r
.38555 .74867 m .38366 .74932 L .38478 .7474 L F
.81 .673 .713 r
.58625 .79194 m .58754 .79498 L .58482 .79432 L F
.81 .534 .52 r
.58808 .79711 m .58482 .79432 L .58754 .79498 L F
.432 .227 .5 r
.34037 .68599 m .33822 .68885 L .33851 .68674 L F
.604 .604 .825 r
.69201 .72362 m .69089 .7252 L .68965 .72294 L F
.69201 .72362 m .69329 .72505 L .69089 .7252 L F
.919 .97 .78 r
.56244 .8075 m .56476 .80544 L .56285 .80456 L F
.63 .634 .836 r
.65283 .74214 m .65633 .7446 L .65522 .74134 L F
.578 .566 .804 r
.65633 .7446 m .65737 .74104 L .65522 .74134 L F
.65633 .7446 m .65839 .74422 L .65737 .74104 L F
.491 .469 .76 r
.65633 .7446 m .66095 .74882 L .65839 .74422 L F
.873 .749 .723 r
.60791 .8129 m .61037 .81342 L .60936 .81017 L F
.872 .635 .576 r
.6077 .8153 m .61037 .81342 L .60791 .8129 L F
.6077 .8153 m .61023 .81574 L .61037 .81342 L F
.824 .59 .585 r
.61023 .81574 m .61241 .81649 L .61037 .81342 L F
.819 .724 .76 r
.60936 .81017 m .61037 .81342 L .61098 .81118 L F
.757 .729 .827 r
.46801 .86595 m .46917 .86702 L .47071 .86584 L F
.47071 .86584 m .46917 .86702 L .46801 .86595 L F
.511 .516 .798 r
.47067 .86819 m .46917 .86702 L .47071 .86584 L F
.56 .329 .522 r
.37786 .71579 m .37769 .71813 L .37885 .71642 L F
.37885 .71642 m .37769 .71813 L .37786 .71579 L F
.541 .415 .657 r
.34198 .68053 m .34008 .68423 L .34024 .68117 L F
.669 .55 .711 r
.62609 .75788 m .62818 .75516 L .62591 .75561 L F
.675 .56 .716 r
.62609 .75788 m .62931 .75828 L .62818 .75516 L F
.717 .602 .727 r
.62615 .75998 m .62931 .75828 L .62609 .75788 L F
.7 .418 .494 r
.50405 .853 m .50451 .85545 L .50073 .8551 L F
.989 .745 .467 r
.50552 .86408 m .50633 .86592 L .50635 .86356 L F
.753 .454 .477 r
.50785 .85478 m .50451 .85545 L .50405 .853 L F
.638 .787 .953 r
.41043 .72931 m .40852 .73014 L .40712 .72874 L F
.828 .473 0 r
.57348 .82429 m .57406 .8261 L .57429 .82601 L F
.913 .765 .684 r
.57187 .82854 m .57429 .82601 L .57406 .8261 L F
.57187 .82854 m .57346 .8294 L .57429 .82601 L F
.967 .717 .504 r
.5596 .81223 m .56081 .8131 L .5608 .81073 L F
.486 .633 .918 r
.56081 .8131 m .5596 .81223 L .5608 .81073 L F
0 0 0 r
.36318 .78919 m .36449 .78881 L .36593 .78728 L F
.36593 .78728 m .36639 .78772 L .36816 .78728 L F
.36593 .78728 m .36449 .78881 L .36639 .78772 L F
.509 .904 .772 r
.69586 .74522 m .69489 .74624 L .69759 .74524 L F
.69586 .74522 m .69407 .74642 L .69489 .74624 L F
.775 .669 .746 r
.61553 .78672 m .61914 .78505 L .6174 .78409 L F
.511 .268 .482 r
.41494 .76032 m .41698 .76001 L .4173 .75799 L F
.406 .216 .508 r
.4173 .75799 m .41914 .75747 L .41926 .75517 L F
.54 .361 .587 r
.41698 .76001 m .41914 .75747 L .4173 .75799 L F
.707 .358 .384 r
.58092 .78019 m .58412 .77911 L .58093 .77874 L F
.58092 .78019 m .58319 .78128 L .58412 .77911 L F
.669 .317 .368 r
.58412 .77911 m .58319 .78128 L .58634 .78103 L F
.987 .893 .572 r
.49838 .87383 m .49985 .8733 L .49925 .87256 L F
.999 .785 .459 r
.49874 .87575 m .49985 .8733 L .49838 .87383 L F
.786 .544 .571 r
.58634 .78103 m .58955 .78141 L .58945 .77912 L F
.739 .507 .578 r
.58945 .77912 m .58955 .78141 L .59287 .7815 L F
.66 .211 .175 r
.49408 .82256 m .496 .82338 L .49709 .82189 L F
.462 0 .057 r
.49709 .82189 m .496 .82338 L .49854 .82213 L F
.681 .637 .798 r
.62591 .75561 m .62703 .75217 L .6248 .75261 L F
.62591 .75561 m .62818 .75516 L .62703 .75217 L F
.953 .66 .444 r
.64789 .63577 m .64921 .63661 L .64817 .63805 L F
.709 .295 .259 r
.64921 .63661 m .65147 .6385 L .64817 .63805 L F
.626 .356 .489 r
.65174 .6365 m .65147 .6385 L .64921 .63661 L F
.757 .698 .796 r
.67446 .74183 m .67803 .74179 L .67603 .7398 L F
.763 .619 .7 r
.67446 .74183 m .67595 .74436 L .67803 .74179 L F
0 .364 .831 r
.67603 .7398 m .67803 .74179 L .67772 .74096 L F
.802 .332 0 r
.67803 .74179 m .67964 .74444 L .67897 .7442 L F
.67803 .74179 m .67897 .7442 L .67772 .74096 L F
.829 .414 .254 r
.68126 .74457 m .67964 .74444 L .67803 .74179 L F
.854 .546 .467 r
.59713 .80284 m .5949 .80245 L .59423 .80006 L F
.877 .632 .564 r
.59679 .80478 m .5949 .80245 L .59713 .80284 L F
.468 .145 .336 r
.35568 .75281 m .35479 .75405 L .35365 .75416 L F
.13 0 0 r
.35766 .75249 m .35479 .75405 L .35568 .75281 L F
0 0 .463 r
.53962 .83657 m .53893 .83735 L .53849 .83465 L F
.53962 .83657 m .53849 .83465 L .5364 .83584 L F
.935 .85 .734 r
.5925 .82218 m .59078 .82608 L .59037 .82365 L F
.691 .9 .972 r
.7018 .75329 m .70495 .75289 L .70398 .75228 L F
.904 .92 .819 r
.70398 .75228 m .70495 .75289 L .70697 .75007 L F
.465 .352 .641 r
.34346 .67792 m .34198 .68053 L .34185 .67921 L F
.438 .145 .369 r
.41741 .77112 m .41658 .77373 L .41474 .77341 L F
.505 .22 .416 r
.41942 .77074 m .41658 .77373 L .41741 .77112 L F
.781 .928 .931 r
.54382 .80509 m .54212 .80536 L .54468 .80347 L F
.717 .213 .035 r
.5457 .80734 m .54212 .80536 L .54382 .80509 L F
.297 0 0 r
.42518 .76819 m .42423 .76854 L .42179 .76851 L F
0 0 0 r
.42626 .76812 m .42518 .76819 L .42844 .76787 L F
.42626 .76812 m .42423 .76854 L .42518 .76819 L F
.678 .627 .79 r
.42237 .88181 m .42544 .88266 L .42434 .88183 L F
.665 .808 .952 r
.42544 .88266 m .4276 .88202 L .42434 .88183 L F
.904 .92 .819 r
.70398 .75228 m .70697 .75007 L .70548 .74892 L F
.704 .37 .409 r
.50764 .88453 m .51086 .88438 L .50995 .88686 L F
.411 .055 .247 r
.51086 .88438 m .51189 .88627 L .50995 .88686 L F
.51086 .88438 m .51294 .88393 L .51189 .88627 L F
.688 .62 .775 r
.44277 .87631 m .44653 .87885 L .4451 .87578 L F
.569 .596 .84 r
.4451 .87578 m .44653 .87885 L .44856 .87829 L F
.569 .711 .938 r
.44653 .87885 m .44926 .87939 L .44856 .87829 L F
.257 .708 .956 r
.67033 .76067 m .67372 .76131 L .67315 .76077 L F
.568 .697 .929 r
.67372 .76131 m .67454 .75954 L .67315 .76077 L F
.67372 .76131 m .67588 .76093 L .67454 .75954 L F
.601 .454 .654 r
.44227 .85858 m .44452 .86057 L .44435 .85818 L F
.44227 .85858 m .4423 .86087 L .44452 .86057 L F
.455 .177 .401 r
.50785 .85478 m .50968 .85321 L .50932 .85485 L F
.364 .096 .369 r
.50932 .85485 m .50968 .85321 L .51151 .85251 L F
.51 .328 .57 r
.42438 .8793 m .42237 .88181 L .42434 .88183 L F
.87 .429 .129 r
.55195 .81295 m .54912 .80978 L .55058 .81038 L F
.859 .483 .335 r
.55364 .81334 m .55195 .81295 L .55058 .81038 L F
.669 .599 .768 r
.49728 .84789 m .50001 .85051 L .50141 .84979 L F
.546 .351 .567 r
.44998 .84503 m .45213 .84475 L .45223 .84242 L F
.543 .377 .606 r
.44998 .84503 m .45197 .84692 L .45213 .84475 L F
.44998 .84503 m .45008 .84737 L .45197 .84692 L F
.707 .985 .869 r
.59947 .8441 m .60316 .84219 L .60246 .84199 L F
.904 .984 .77 r
.60246 .84199 m .60316 .84219 L .60498 .83955 L F
.374 0 .128 r
.37381 .79813 m .37274 .79952 L .37099 .79949 L F
.277 0 .012 r
.37582 .79782 m .37274 .79952 L .37381 .79813 L F
.494 .208 .408 r
.43156 .76087 m .43117 .76256 L .4291 .76284 L F
.543 .253 .424 r
.43156 .76087 m .43338 .76239 L .43117 .76256 L F
.947 .591 .278 r
.48121 .85595 m .48244 .85792 L .48198 .85593 L F
.698 .983 .863 r
.48121 .85595 m .48198 .85593 L .48465 .85403 L F
.718 .328 .31 r
.57656 .83043 m .57682 .83046 L .5772 .82852 L F
.633 .874 .522 r
.57828 .82898 m .57613 .83168 L .57629 .83144 L F
.57762 .82962 m .57629 .83144 L .57728 .82994 L F
.57828 .82898 m .57629 .83144 L .57762 .82962 L F
.88 .924 .849 r
.57933 .82585 m .57828 .82898 L .5772 .82852 L F
.265 .237 .639 r
.5772 .82852 m .57782 .82934 L .57842 .82828 L F
.88 .924 .849 r
.57933 .82585 m .58037 .82643 L .57828 .82898 L F
.265 .237 .639 r
.57782 .82934 m .57885 .83069 L .57846 .82847 L F
.57782 .82934 m .57846 .82847 L .57842 .82828 L F
.633 .874 .522 r
.57828 .82898 m .57728 .82994 L .57736 .82985 L F
0 0 .457 r
.57729 .82998 m .57613 .83168 L .57667 .83431 L F
.718 .328 .31 r
.57728 .82994 m .57885 .83069 L .57782 .82934 L F
0 0 .457 r
.5773 .82991 m .57728 .82994 L .57729 .82998 L F
.57728 .82994 m .57613 .83168 L .57729 .82998 L F
.718 .328 .31 r
.57682 .83046 m .57751 .83054 L .57728 .82994 L F
.57751 .83054 m .57885 .83069 L .57728 .82994 L F
.633 .874 .522 r
.57828 .82898 m .57736 .82985 L .5772 .82852 L F
.718 .328 .31 r
.57682 .83046 m .57736 .82985 L .5772 .82852 L F
.633 .874 .522 r
.57736 .82985 m .5773 .82991 L .5772 .82852 L F
.718 .328 .31 r
.57736 .82985 m .57782 .82934 L .5772 .82852 L F
.633 .874 .522 r
.57736 .82985 m .57728 .82994 L .5773 .82991 L F
0 0 .315 r
.59106 .81716 m .59024 .82197 L .59135 .82031 L F
.852 .755 .755 r
.59135 .82031 m .58995 .82109 L .58967 .82003 L F
.819 .472 .399 r
.59037 .82365 m .58756 .82051 L .58805 .82206 L F
.59037 .82365 m .59024 .82197 L .58712 .82004 L F
.852 .755 .755 r
.58995 .82109 m .58792 .8222 L .589 .82086 L F
.58995 .82109 m .589 .82086 L .58967 .82003 L F
.819 .472 .399 r
.58756 .82051 m .58712 .82004 L .58732 .82046 L F
.58756 .82051 m .58732 .82046 L .58805 .82206 L F
.789 .442 .399 r
.55364 .81334 m .55216 .81503 L .55195 .81295 L F
.55364 .81334 m .55494 .81592 L .55216 .81503 L F
.795 .536 .546 r
.52632 .82911 m .52261 .82988 L .52367 .8297 L F
.52632 .82911 m .52507 .83164 L .52261 .82988 L F
.664 .38 .48 r
.52861 .83128 m .52632 .82911 L .52856 .829 L F
.52861 .83128 m .52507 .83164 L .52632 .82911 L F
.372 0 .14 r
.47415 .83091 m .47612 .83123 L .47706 .82986 L F
0 0 0 r
.47706 .82986 m .47731 .83041 L .47909 .8296 L F
.47706 .82986 m .47612 .83123 L .47731 .83041 L F
.283 0 0 r
.47706 .82986 m .47909 .8296 L .48015 .82901 L F
.591 .69 .911 r
.6574 .74975 m .6597 .74936 L .66095 .74882 L F
.662 .541 .706 r
.65888 .75421 m .6597 .74936 L .6574 .74975 L F
.546 .322 .527 r
.43896 .75986 m .43635 .75754 L .4391 .75716 L F
.43896 .75986 m .43605 .76045 L .43635 .75754 L F
.687 .457 .568 r
.57405 .787 m .57506 .78925 L .57147 .78846 L F
.826 .733 .762 r
.57495 .7847 m .57405 .787 L .57325 .78388 L F
.268 0 0 r
.57969 .78735 m .57889 .78832 L .5766 .78852 L F
.317 .774 .95 r
.57889 .78832 m .57808 .78828 L .5766 .78852 L F
.57808 .78828 m .57554 .78816 L .5766 .78852 L F
.445 .342 .645 r
.5766 .78852 m .57506 .78925 L .57486 .78881 L F
.5766 .78852 m .57486 .78881 L .57405 .787 L F
.519 .329 .562 r
.45223 .84242 m .45412 .8443 L .45423 .84213 L F
.45223 .84242 m .45213 .84475 L .45412 .8443 L F
0 0 .318 r
.56354 .83684 m .56381 .83996 L .564 .83946 L F
.633 .49 .67 r
.4186 .75209 m .42168 .75258 L .42092 .7499 L F
.557 .404 .629 r
.41926 .75517 m .42168 .75258 L .4186 .75209 L F
.408 0 .107 r
.64605 .71057 m .64739 .71167 L .64919 .7093 L F
.325 0 .072 r
.64919 .7093 m .64954 .71121 L .65062 .70895 L F
.64919 .7093 m .64739 .71167 L .64954 .71121 L F
.809 .648 .683 r
.61159 .81862 m .61241 .81649 L .61023 .81574 L F
.803 .893 .908 r
.46341 .88458 m .46539 .88457 L .46554 .88164 L F
.692 .632 .785 r
.46554 .88164 m .46539 .88457 L .46879 .8823 L F
.106 0 0 r
.51441 .83585 m .51369 .83518 L .51537 .8338 L F
.904 .984 .77 r
.60246 .84199 m .60498 .83955 L .60445 .83918 L F
.873 .991 .815 r
.60498 .83955 m .60661 .83653 L .60445 .83918 L F
.60498 .83955 m .60717 .83695 L .60661 .83653 L F
.123 0 0 r
.55714 .78181 m .55411 .78204 L .55388 .782 L F
.546 .529 .787 r
.55819 .77833 m .55714 .78181 L .55598 .7789 L F
.55819 .77833 m .5594 .78185 L .55714 .78181 L F
.19 .717 .849 r
.5594 .78185 m .55411 .78204 L .55714 .78181 L F
.968 .934 .646 r
.48293 .86116 m .48217 .86294 L .48391 .86112 L F
.825 .706 .733 r
.48244 .85792 m .48391 .86112 L .48415 .85875 L F
.699 .916 .576 r
.48391 .86112 m .48447 .85998 L .48534 .86026 L F
.48391 .86112 m .48217 .86294 L .48447 .85998 L F
.791 .684 .746 r
.67588 .76093 m .67905 .76063 L .67793 .75763 L F
0 .155 .665 r
.55598 .81697 m .5557 .81638 L .55494 .81592 L F
.55598 .81697 m .55752 .81824 L .5557 .81638 L F
0 .244 .759 r
.55598 .81697 m .55779 .81874 L .55752 .81824 L F
.739 .605 .708 r
.64108 .7501 m .63901 .753 L .64113 .75226 L F
.299 .35 .747 r
.50609 .8442 m .50459 .84535 L .50388 .84213 L F
.413 .565 .896 r
.50609 .8442 m .50804 .8466 L .50459 .84535 L F
.604 .605 .826 r
.50824 .84755 m .50459 .84535 L .50804 .8466 L F
.625 .733 .925 r
.44856 .87829 m .44926 .87939 L .45142 .87887 L F
.602 .815 .982 r
.69979 .69422 m .69659 .69388 L .69769 .69487 L F
.69979 .69422 m .69659 .69388 L .69769 .69487 L F
.127 .674 .714 r
.37673 .74989 m .37587 .75001 L .37399 .75032 L F
.315 0 .001 r
.37891 .74875 m .37587 .75001 L .37673 .74989 L F
.634 .512 .697 r
.43861 .8687 m .44054 .86595 L .43821 .86628 L F
.43861 .8687 m .44115 .86872 L .44054 .86595 L F
.56 .408 .632 r
.43912 .87159 m .44115 .86872 L .43861 .8687 L F
.726 .585 .697 r
.51832 .8555 m .5184 .85698 L .51622 .85791 L F
.636 .502 .682 r
.52049 .85272 m .52114 .85511 L .51832 .8555 L F
.685 .611 .767 r
.52114 .85511 m .5184 .85698 L .51832 .8555 L F
.795 .706 .766 r
.63793 .74992 m .64108 .7501 L .64001 .74723 L F
.798 .692 .748 r
.63793 .74992 m .63901 .753 L .64108 .7501 L F
.765 .692 .781 r
.64108 .7501 m .64318 .74751 L .64001 .74723 L F
.56 .521 .768 r
.43092 .73644 m .43151 .73804 L .42941 .73847 L F
.619 .515 .714 r
.43151 .73804 m .42998 .74207 L .42941 .73847 L F
.62 .54 .743 r
.49854 .85566 m .49654 .85852 L .49657 .8565 L F
.568 .471 .704 r
.49854 .85566 m .49996 .85975 L .49654 .85852 L F
.647 .389 .514 r
.49996 .85975 m .49651 .86034 L .49654 .85852 L F
.381 .349 .698 r
.51458 .84457 m .51502 .84735 L .51287 .84759 L F
.51458 .84457 m .51287 .84759 L .51309 .84756 L F
.051 .589 .852 r
.51024 .84698 m .51309 .84756 L .51287 .84759 L F
.232 .114 .505 r
.51344 .85033 m .51214 .85057 L .51287 .84759 L F
0 0 .134 r
.5138 .84995 m .51394 .8494 L .51502 .84735 L F
0 0 .381 r
.51393 .84944 m .5146 .84911 L .51366 .84911 L F
.51472 .8504 m .5146 .84911 L .51393 .84944 L F
.532 .479 .742 r
.5154 .85002 m .51469 .85013 L .5146 .84911 L F
0 0 .381 r
.51478 .85048 m .5146 .84911 L .51472 .8504 L F
.532 .479 .742 r
.51419 .85021 m .51367 .85225 L .51344 .85033 L F
.51427 .85029 m .51367 .85225 L .51419 .85021 L F
.51442 .85061 m .51367 .85225 L .51417 .8506 L F
.51456 .8511 m .51367 .85225 L .51445 .85055 L F
.51452 .85057 m .51445 .85055 L .5145 .85043 L F
.51456 .8511 m .51445 .85055 L .51452 .85057 L F
.268 .279 .686 r
.51367 .85225 m .51214 .85057 L .51344 .85033 L F
.579 .328 .499 r
.51151 .85251 m .51214 .85057 L .51367 .85225 L F
.51151 .85251 m .51214 .85057 L .51367 .85225 L F
.667 .484 .628 r
.51367 .85225 m .51152 .85493 L .51151 .85251 L F
.51367 .85225 m .51388 .85502 L .51152 .85493 L F
.638 .631 .827 r
.51487 .8507 m .51595 .85247 L .5143 .85231 L F
.747 .599 .692 r
.51595 .85247 m .51388 .85502 L .51367 .85225 L F
.621 .282 .374 r
.51484 .85057 m .51508 .85356 L .51537 .8513 L F
.532 .479 .742 r
.5154 .85002 m .51487 .8507 L .51486 .85065 L F
0 0 .381 r
.51478 .85048 m .51483 .85056 L .51475 .85021 L F
.621 .282 .374 r
.51478 .85048 m .5148 .85068 L .51483 .85056 L F
.51478 .85048 m .51466 .85062 L .5148 .85068 L F
.486 .116 .264 r
.51459 .85062 m .51466 .85062 L .51478 .85048 L F
.782 .667 .736 r
.5145 .85043 m .51452 .85055 L .51478 .85048 L F
.486 .116 .264 r
.51459 .85062 m .51478 .85048 L .51452 .85055 L F
.782 .667 .736 r
.51445 .85037 m .51478 .85048 L .51472 .8504 L F
.5145 .85043 m .51478 .85048 L .51445 .85037 L F
.532 .479 .742 r
.51496 .85009 m .51479 .85074 L .5143 .8502 L F
0 0 .381 r
.51475 .85021 m .51537 .8513 L .5146 .84911 L F
.638 .631 .827 r
.5154 .85002 m .51556 .85074 L .51487 .8507 L F
0 0 .381 r
.51483 .85056 m .51484 .85057 L .51475 .85021 L F
.638 .631 .827 r
.51556 .85074 m .51595 .85247 L .51487 .8507 L F
0 0 .381 r
.51484 .85057 m .51537 .8513 L .51479 .85027 L F
.51484 .85057 m .51479 .85027 L .51475 .85021 L F
.532 .479 .742 r
.51486 .85065 m .51481 .85077 L .51479 .85074 L F
.51487 .8507 m .51481 .85077 L .51486 .85065 L F
.5154 .85002 m .51479 .85074 L .51496 .85009 L F
.621 .282 .374 r
.51483 .85056 m .5148 .8507 L .51484 .85057 L F
.5148 .85068 m .5148 .8507 L .51483 .85056 L F
.5148 .8507 m .51508 .85356 L .51484 .85057 L F
.638 .631 .827 r
.51476 .85085 m .5143 .85231 L .51367 .85225 L F
.51487 .8507 m .5143 .85231 L .51476 .85085 L F
.621 .282 .374 r
.5148 .8507 m .51155 .85404 L .51508 .85356 L F
.5148 .85068 m .51478 .8507 L .5148 .8507 L F
.51478 .8507 m .51155 .85404 L .5148 .8507 L F
.532 .479 .742 r
.51481 .85077 m .51456 .8511 L .5145 .85043 L F
.621 .282 .374 r
.51466 .85062 m .51155 .85404 L .5148 .85068 L F
.364 .096 .369 r
.50932 .85485 m .51151 .85251 L .51152 .85493 L F
.486 .116 .264 r
.50934 .8543 m .51155 .85404 L .51466 .85062 L F
.50934 .8543 m .51466 .85062 L .51459 .85062 L F
.532 .479 .742 r
.5145 .85043 m .51442 .85061 L .5143 .8502 L F
.51442 .85061 m .51417 .8506 L .5143 .8502 L F
.782 .667 .736 r
.50952 .84941 m .50927 .85174 L .51452 .85055 L F
.134 .052 .49 r
.51376 .84973 m .51344 .85033 L .51366 .84911 L F
0 0 .134 r
.5138 .84995 m .51344 .85033 L .51394 .8494 L F
.782 .667 .736 r
.51372 .85027 m .5138 .84995 L .51362 .84907 L F
.5138 .84995 m .51393 .84944 L .51366 .84911 L F
.5138 .84995 m .51366 .84911 L .51362 .84907 L F
.134 .052 .49 r
.51366 .84911 m .51344 .85033 L .51319 .84911 L F
.5141 .84911 m .51376 .84973 L .51366 .84911 L F
0 0 .134 r
.5146 .84911 m .51402 .84949 L .51408 .84937 L F
.5146 .84911 m .5138 .84995 L .51402 .84949 L F
.134 .052 .49 r
.5146 .84911 m .51396 .84978 L .5141 .84911 L F
.51396 .84978 m .51344 .85033 L .5141 .84911 L F
.782 .667 .736 r
.51386 .8503 m .51452 .85055 L .5145 .85043 L F
.50952 .84941 m .51384 .85039 L .51386 .8503 L F
.51384 .85039 m .51452 .85055 L .51386 .8503 L F
.486 .116 .264 r
.50934 .8543 m .51459 .85062 L .50927 .85174 L F
.51459 .85062 m .51452 .85055 L .50927 .85174 L F
.532 .479 .742 r
.5143 .8502 m .51427 .85029 L .51419 .85021 L F
.782 .667 .736 r
.51372 .85027 m .5145 .85043 L .51445 .85037 L F
.5138 .84995 m .51472 .8504 L .51393 .84944 L F
.532 .479 .742 r
.5143 .8502 m .51344 .85033 L .5138 .84995 L F
.782 .667 .736 r
.51372 .85027 m .51472 .8504 L .5138 .84995 L F
.532 .479 .742 r
.51469 .85013 m .5143 .8502 L .5146 .84911 L F
.5143 .8502 m .5138 .84995 L .5146 .84911 L F
0 0 .134 r
.5146 .84911 m .51408 .84937 L .51502 .84735 L F
.134 .052 .49 r
.5146 .84911 m .51319 .84911 L .51287 .84759 L F
0 0 .381 r
.51366 .84911 m .5146 .84911 L .51362 .84907 L F
.782 .667 .736 r
.50952 .84941 m .51372 .85027 L .51362 .84907 L F
.134 .052 .49 r
.5146 .84911 m .51287 .84759 L .51502 .84735 L F
.429 .041 .201 r
.34578 .75765 m .3445 .75962 L .34242 .75987 L F
.581 .234 .346 r
.34801 .75745 m .3445 .75962 L .34578 .75765 L F
.473 .566 .869 r
.41671 .73221 m .41908 .73277 L .41736 .73292 L F
.591 .584 .813 r
.42014 .73454 m .41736 .73292 L .41908 .73277 L F
.77 .642 .72 r
.64205 .74444 m .64528 .74476 L .64424 .74173 L F
.769 .647 .727 r
.64205 .74444 m .64318 .74751 L .64528 .74476 L F
.7 .605 .747 r
.64424 .74173 m .64528 .74476 L .64747 .7422 L F
.572 .458 .685 r
.64343 .72664 m .64421 .72888 L .64182 .72892 L F
.626 .487 .672 r
.44393 .85547 m .44643 .85549 L .44589 .85272 L F
.593 .437 .639 r
.44435 .85818 m .44643 .85549 L .44393 .85547 L F
.603 .524 .738 r
.62687 .74984 m .6287 .74682 L .6264 .74782 L F
.82 .515 .475 r
.50609 .8442 m .50786 .84579 L .50804 .8466 L F
.50786 .84579 m .50926 .84705 L .50804 .8466 L F
.387 0 0 r
.50804 .8466 m .51024 .84698 L .50825 .84755 L F
.50804 .8466 m .50825 .84755 L .50824 .84755 L F
.443 .087 .264 r
.34993 .73131 m .35206 .73099 L .35312 .72884 L F
.352 0 .217 r
.35312 .72884 m .35391 .73052 L .35527 .72869 L F
.35312 .72884 m .35206 .73099 L .35391 .73052 L F
.634 .839 .979 r
.56765 .84492 m .57099 .84501 L .56925 .8451 L F
.82 .374 .178 r
.57099 .84501 m .57072 .84666 L .56925 .8451 L F
.57099 .84501 m .57295 .84741 L .57072 .84666 L F
.65 .412 .545 r
.51622 .85791 m .5184 .85698 L .518 .85875 L F
.815 .43 .325 r
.5184 .85698 m .51993 .86034 L .518 .85875 L F
.5184 .85698 m .52171 .86035 L .51993 .86034 L F
.748 .333 .262 r
.51694 .85496 m .51952 .85761 L .5173 .85697 L F
.332 .083 .379 r
.52106 .85652 m .51952 .85761 L .51877 .85881 L F
0 .19 .707 r
.51812 .85838 m .518 .85875 L .51929 .85982 L F
.51682 .85678 m .51929 .85982 L .51813 .85828 L F
.51682 .85678 m .51755 .85801 L .51812 .85838 L F
.51755 .85801 m .518 .85875 L .51812 .85838 L F
.51813 .85828 m .51929 .85982 L .51993 .86034 L F
.51675 .85674 m .518 .85875 L .51682 .85678 L F
.51679 .85682 m .51993 .86034 L .51827 .85962 L F
.748 .333 .262 r
.51682 .85678 m .51682 .85678 L .51682 .85678 L F
.51694 .85496 m .51682 .85678 L .51653 .85659 L F
0 .19 .707 r
.51668 .85662 m .51675 .85674 L .51682 .85678 L F
.51668 .85662 m .51682 .85678 L .51679 .85682 L F
.51682 .85678 m .51993 .86034 L .51679 .85682 L F
.51679 .85682 m .51827 .85962 L .51952 .85761 L F
.748 .333 .262 r
.51681 .85683 m .51735 .85725 L .51679 .85716 L F
.51682 .85678 m .5169 .85686 L .51681 .85683 L F
.5169 .85686 m .51735 .85725 L .51681 .85683 L F
.51682 .85678 m .51735 .85725 L .51682 .85678 L F
.332 .083 .379 r
.51892 .8589 m .51877 .85881 L .51827 .85962 L F
.52106 .85652 m .51877 .85881 L .51892 .8589 L F
.748 .333 .262 r
.51694 .85496 m .5173 .85697 L .51682 .85678 L F
.5173 .85697 m .51735 .85725 L .51691 .85686 L F
.5173 .85697 m .51691 .85686 L .51682 .85678 L F
0 .19 .707 r
.51668 .85662 m .51679 .85682 L .51952 .85761 L F
.748 .333 .262 r
.5173 .85697 m .51952 .85761 L .51735 .85725 L F
.755 .324 .228 r
.51668 .85662 m .51952 .85761 L .51694 .85496 L F
.714 .788 .91 r
.51723 .85709 m .51952 .85761 L .52106 .85652 L F
.51679 .85716 m .51735 .85725 L .51723 .85709 L F
.51735 .85725 m .51952 .85761 L .51723 .85709 L F
.125 .497 .906 r
.51622 .85791 m .518 .85875 L .51675 .85674 L F
.51665 .85672 m .51675 .85674 L .51668 .85662 L F
.51622 .85791 m .51675 .85674 L .51665 .85672 L F
.748 .333 .262 r
.51651 .85669 m .51679 .85716 L .51641 .85707 L F
0 0 .405 r
.51587 .85642 m .51622 .85791 L .51647 .85723 L F
.59 .392 .581 r
.51582 .85693 m .51376 .85951 L .51362 .85707 L F
.51582 .85693 m .51597 .85976 L .51376 .85951 L F
.615 .87 .99 r
.51784 .85883 m .51597 .85976 L .51582 .85693 L F
.603 .052 0 r
.51739 .85849 m .51582 .85693 L .51556 .85711 L F
.51784 .85883 m .51719 .85822 L .51739 .85849 L F
.51719 .85822 m .51582 .85693 L .51739 .85849 L F
.695 .364 .411 r
.51388 .85502 m .5159 .85498 L .51582 .85693 L F
0 0 .405 r
.51576 .85597 m .51655 .85653 L .51694 .85496 L F
.695 .364 .411 r
.5159 .85498 m .51694 .85496 L .5163 .85608 L F
0 0 .405 r
.51576 .85597 m .51587 .85642 L .51652 .85667 L F
.695 .364 .411 r
.5159 .85498 m .5163 .85608 L .51582 .85693 L F
0 0 .405 r
.51648 .85658 m .51652 .85667 L .51665 .85672 L F
.51576 .85597 m .51652 .85667 L .51648 .85658 L F
.51587 .85642 m .51647 .85723 L .51665 .85672 L F
.51655 .85653 m .51665 .85672 L .51668 .85662 L F
.51576 .85597 m .51665 .85672 L .51655 .85653 L F
.748 .333 .262 r
.5163 .85608 m .51641 .85707 L .51582 .85693 L F
.51694 .85496 m .51655 .85653 L .5163 .85608 L F
.51655 .85653 m .51641 .85707 L .5163 .85608 L F
.51653 .85659 m .51658 .8567 L .51651 .85669 L F
.51658 .8567 m .51679 .85716 L .51651 .85669 L F
.51682 .85678 m .51679 .85716 L .51653 .85659 L F
0 0 .405 r
.51655 .85653 m .51668 .85662 L .51694 .85496 L F
.536 .843 .999 r
.712 .73628 m .70897 .73617 L .71166 .73556 L F
.923 .556 .308 r
.55971 .80015 m .56061 .8022 L .56198 .80275 L F
.847 .619 .592 r
.56061 .8022 m .56285 .80456 L .56198 .80275 L F
.644 .705 .891 r
.42092 .7499 m .42361 .75054 L .42261 .74886 L F
.722 .543 .647 r
.42092 .7499 m .42395 .7525 L .42361 .75054 L F
.57 .669 .906 r
.42261 .74886 m .42361 .75054 L .42481 .7486 L F
.362 .396 .762 r
.42361 .75054 m .42586 .75199 L .42481 .7486 L F
.504 .37 .631 r
.42361 .75054 m .42395 .7525 L .42586 .75199 L F
.507 .162 .317 r
.33946 .69347 m .33601 .69447 L .3364 .69525 L F
.435 .216 .48 r
.33397 .69321 m .3364 .69525 L .33378 .69341 L F
.33493 .69226 m .33601 .69447 L .33397 .69321 L F
.33601 .69447 m .3364 .69525 L .33397 .69321 L F
.6 .331 .481 r
.33946 .69347 m .3364 .69525 L .33633 .69466 L F
.507 .162 .317 r
.33946 .69347 m .33762 .69546 L .33633 .69466 L F
.33946 .69347 m .33633 .69466 L .33601 .69447 L F
.6 .331 .481 r
.33946 .69347 m .33633 .69466 L .33593 .69127 L F
.435 .216 .48 r
.33593 .69127 m .3364 .69525 L .33493 .69226 L F
.507 .162 .317 r
.33601 .69447 m .33733 .69578 L .33591 .6945 L F
.33762 .69546 m .33733 .69578 L .33601 .69447 L F
.33601 .69447 m .33591 .6945 L .3364 .69525 L F
.411 .224 .514 r
.33378 .69341 m .3364 .69525 L .33591 .6945 L F
.33378 .69341 m .33591 .6945 L .33405 .69517 L F
.128 .609 .916 r
.47713 .88289 m .47784 .88223 L .47561 .88218 L F
.47713 .88289 m .48053 .88349 L .47784 .88223 L F
.387 .641 .957 r
.32058 .6616 m .32184 .66298 L .32115 .66293 L F
0 .062 .572 r
.51344 .87314 m .5142 .874 L .51224 .872 L F
.687 .143 0 r
.51502 .87546 m .5142 .874 L .51344 .87314 L F
.51502 .87546 m .51621 .87591 L .5142 .874 L F
.643 .56 .746 r
.49657 .8565 m .49348 .85769 L .49322 .85586 L F
.772 .32 .176 r
.4922 .86386 m .49291 .86315 L .49085 .86304 L F
.748 .298 .184 r
.4682 .85396 m .46712 .85491 L .46507 .85278 L F
.611 .123 .071 r
.47069 .8551 m .46712 .85491 L .4682 .85396 L F
.545 0 0 r
.51979 .8785 m .51741 .87656 L .51621 .87591 L F
.561 .85 .997 r
.3824 .72389 m .37878 .72386 L .38132 .7237 L F
.774 .986 .899 r
.38425 .72207 m .3824 .72389 L .38296 .72236 L F
.757 .974 .923 r
.38296 .72236 m .3824 .72389 L .38132 .7237 L F
.717 .602 .727 r
.62615 .75998 m .62922 .76039 L .62931 .75828 L F
.723 .607 .727 r
.62931 .75828 m .62922 .76039 L .63139 .75772 L F
.688 .417 .507 r
.50785 .85478 m .50399 .85761 L .50451 .85545 L F
.50785 .85478 m .50622 .85768 L .50399 .85761 L F
.646 .422 .565 r
.50932 .85485 m .50622 .85768 L .50785 .85478 L F
.595 .427 .624 r
.34586 .67081 m .34593 .67312 L .34374 .67348 L F
.551 .387 .613 r
.34593 .67312 m .34393 .67609 L .34374 .67348 L F
.595 .427 .624 r
.34374 .67348 m .34593 .67312 L .34586 .67081 L F
.551 .387 .613 r
.34593 .67312 m .34393 .67609 L .34374 .67348 L F
.595 .427 .624 r
.34586 .67081 m .34593 .67312 L .34374 .67348 L F
.34586 .67081 m .34593 .67312 L .34374 .67348 L F
.666 .664 .838 r
.68842 .72012 m .68713 .72338 L .68623 .72066 L F
.68842 .72012 m .68965 .72294 L .68713 .72338 L F
.754 .965 .678 r
.71111 .74442 m .71123 .74473 L .71344 .74211 L F
.815 .575 .576 r
.70907 .74601 m .71154 .74704 L .71123 .74473 L F
.829 .714 .738 r
.47906 .85751 m .48109 .86018 L .48032 .85822 L F
.565 .582 .829 r
.48032 .85822 m .48121 .85595 L .47906 .85751 L F
.48032 .85822 m .48244 .85792 L .48121 .85595 L F
.369 .246 .579 r
.48109 .86018 m .48244 .85792 L .48032 .85822 L F
.707 .85 .951 r
.53107 .84214 m .53239 .84334 L .53413 .84226 L F
.929 .972 .739 r
.50843 .83441 m .50931 .83163 L .51058 .83223 L F
.611 .897 .987 r
.5123 .8314 m .51058 .83223 L .50931 .83163 L F
.821 .718 .751 r
.66277 .75216 m .66075 .75517 L .66387 .75499 L F
.788 .83 .885 r
.66075 .75517 m .66191 .75597 L .66387 .75499 L F
.591 .568 .797 r
.66387 .75499 m .66522 .75168 L .66277 .75216 L F
.66387 .75499 m .66691 .75478 L .66522 .75168 L F
.58 .64 .875 r
.66387 .75499 m .66639 .7559 L .66691 .75478 L F
.653 .609 .792 r
.49955 .83381 m .50289 .83696 L .50294 .83423 L F
0 0 .264 r
.5036 .83595 m .50294 .83423 L .50289 .83696 L F
.325 .809 .877 r
.48488 .88461 m .48609 .88464 L .48819 .88416 L F
.299 .748 .96 r
.5938 .84699 m .59472 .84656 L .59411 .84661 L F
.5938 .84699 m .59571 .84699 L .59472 .84656 L F
.608 .287 .4 r
.46145 .83902 m .46469 .83681 L .46168 .83688 L F
.46145 .83902 m .46374 .83912 L .46469 .83681 L F
.633 .313 .411 r
.46469 .83681 m .46624 .83883 L .46687 .83681 L F
.46469 .83681 m .46374 .83912 L .46624 .83883 L F
.254 0 .027 r
.57773 .81293 m .57921 .81275 L .57988 .81161 L F
.669 .25 .24 r
.57921 .81275 m .58239 .81292 L .57988 .81161 L F
0 .097 .654 r
.38634 .72081 m .38829 .72327 L .38767 .72361 L F
.131 .653 .884 r
.38829 .72327 m .38968 .7237 L .38767 .72361 L F
.642 .683 .873 r
.57913 .81941 m .58146 .82027 L .58063 .81846 L F
.57835 .81991 m .57938 .82003 L .57913 .81941 L F
.57938 .82003 m .58146 .82027 L .57913 .81941 L F
.561 .636 .882 r
.57652 .81865 m .57907 .81926 L .57775 .81742 L F
.578 .084 .045 r
.57588 .8193 m .57835 .81991 L .57913 .81941 L F
.642 .683 .873 r
.57907 .81926 m .58063 .81846 L .58043 .81803 L F
.57835 .81991 m .57913 .81941 L .57907 .81926 L F
.57913 .81941 m .58063 .81846 L .57907 .81926 L F
.561 .636 .882 r
.57588 .8193 m .57913 .81941 L .57652 .81865 L F
.57913 .81941 m .57981 .81944 L .57907 .81926 L F
.57913 .81941 m .57907 .81926 L .57652 .81865 L F
.57907 .81926 m .57981 .81944 L .57871 .81836 L F
.57907 .81926 m .57871 .81836 L .57775 .81742 L F
.578 .084 .045 r
.57913 .81941 m .57835 .81991 L .57981 .81944 L F
.642 .683 .873 r
.57835 .81991 m .57907 .81926 L .57981 .81944 L F
.57907 .81926 m .58043 .81803 L .57981 .81944 L F
.868 .826 .805 r
.4771 .87358 m .47871 .87409 L .48046 .87153 L F
.92 .708 .6 r
.4771 .87358 m .47837 .87635 L .47871 .87409 L F
.545 .557 .817 r
.39722 .72273 m .39645 .72594 L .39507 .7232 L F
.39722 .72273 m .39841 .72567 L .39645 .72594 L F
.233 .752 .81 r
.69962 .75389 m .69828 .75394 L .69621 .75435 L F
.582 .921 .964 r
.7018 .75329 m .69828 .75394 L .69962 .75389 L F
1 .8 .482 r
.48617 .87914 m .48701 .87683 L .48621 .87649 L F
.992 .74 .397 r
.48621 .87649 m .4868 .8761 L .48612 .87363 L F
0 0 .348 r
.48694 .87526 m .48621 .87649 L .48612 .87363 L F
.695 .937 .635 r
.48529 .8771 m .48621 .87649 L .48694 .87526 L F
.841 .917 .885 r
.48248 .87833 m .48372 .8788 L .48621 .87649 L F
.48248 .87833 m .48621 .87649 L .48365 .87891 L F
.695 .937 .635 r
.48365 .87891 m .48621 .87649 L .48529 .8771 L F
.992 .74 .397 r
.48621 .87649 m .48701 .87683 L .4868 .8761 L F
.641 .306 .388 r
.4901 .87914 m .48701 .87683 L .48617 .87914 L F
0 0 0 r
.37353 .78451 m .37377 .78534 L .37525 .78369 L F
.37353 .78451 m .37221 .78625 L .37377 .78534 L F
.749 .593 .682 r
.6755 .73155 m .67325 .73494 L .6718 .73317 L F
0 .06 .575 r
.67426 .73671 m .67449 .73313 L .6718 .73317 L F
.979 .682 .355 r
.67449 .73313 m .67381 .7347 L .67381 .73468 L F
.749 .593 .682 r
.6751 .73172 m .6718 .73317 L .67449 .73313 L F
.979 .682 .355 r
.67449 .73313 m .67381 .73468 L .67357 .73241 L F
.749 .593 .682 r
.6755 .73155 m .6751 .73172 L .67449 .73313 L F
.995 .756 .428 r
.6755 .73155 m .67468 .73084 L .67467 .7285 L F
.998 .791 .488 r
.6755 .73155 m .67449 .73313 L .67468 .73084 L F
.455 .172 .393 r
.40252 .77911 m .40206 .78118 L .39991 .78138 L F
.511 .222 .412 r
.40416 .7808 m .40252 .77911 L .40458 .77882 L F
.40416 .7808 m .40206 .78118 L .40252 .77911 L F
.451 .397 .706 r
.42033 .74762 m .42155 .74408 L .4192 .74445 L F
.42033 .74762 m .42221 .74775 L .42155 .74408 L F
.43 .48 .81 r
.42033 .74762 m .42261 .74886 L .42221 .74775 L F
.644 .705 .891 r
.42092 .7499 m .42261 .74886 L .42033 .74762 L F
.684 .747 .899 r
.48046 .87153 m .47826 .87165 L .47704 .87135 L F
.868 .826 .805 r
.4771 .87358 m .48046 .87153 L .47704 .87135 L F
.596 .607 .833 r
.48046 .87153 m .48134 .86954 L .47971 .86786 L F
.48046 .87153 m .48269 .87112 L .48134 .86954 L F
.553 .375 .594 r
.48046 .87153 m .48256 .87351 L .48269 .87112 L F
.673 .7 .867 r
.36313 .75186 m .36634 .75228 L .36428 .75125 L F
.59 .799 .979 r
.36428 .75125 m .36634 .75228 L .36862 .75168 L F
.455 .576 .886 r
.457 .87987 m .45779 .88249 L .45892 .88078 L F
.495 .63 .912 r
.45779 .88249 m .4602 .88235 L .45892 .88078 L F
.573 .589 .831 r
.45779 .88249 m .46119 .88468 L .4602 .88235 L F
.549 .285 .468 r
.41214 .76311 m .41448 .76285 L .41494 .76032 L F
.467 .198 .423 r
.41448 .76285 m .41698 .76001 L .41494 .76032 L F
.656 .705 .884 r
.4276 .88202 m .43087 .88269 L .42998 .88142 L F
.519 .9 .956 r
.43087 .88269 m .43207 .88181 L .42998 .88142 L F
.43087 .88269 m .43304 .88201 L .43207 .88181 L F
.59 .721 .935 r
.52943 .82319 m .53254 .82407 L .53089 .82455 L F
.426 .258 .549 r
.64219 .73126 m .64194 .7337 L .64039 .73278 L F
.778 .373 .287 r
.67991 .71743 m .68253 .71913 L .68026 .719 L F
.716 .581 .703 r
.62818 .75516 m .63139 .75772 L .63045 .75473 L F
.62818 .75516 m .62931 .75828 L .63139 .75772 L F
.72 .634 .761 r
.63045 .75473 m .63139 .75772 L .63355 .75513 L F
.867 .85 .824 r
.58293 .78953 m .58137 .79158 L .57992 .79055 L F
.625 .471 .653 r
.58293 .78953 m .58259 .79228 L .58137 .79158 L F
.097 .19 .673 r
.58325 .79401 m .58137 .79158 L .58259 .79228 L F
.869 .766 .746 r
.61098 .81118 m .61128 .80735 L .60936 .81017 L F
.754 .965 .678 r
.71111 .74442 m .71344 .74211 L .71275 .74157 L F
.855 .975 .865 r
.71275 .74157 m .71344 .74211 L .71593 .73967 L F
.673 .395 .491 r
.40927 .76456 m .41214 .76311 L .41002 .76337 L F
.529 .375 .617 r
.34809 .67273 m .34593 .67312 L .34586 .67081 L F
.34809 .67273 m .34593 .67312 L .34586 .67081 L F
.532 .313 .527 r
.39059 .78699 m .39014 .78935 L .38861 .78922 L F
.507 .291 .519 r
.39198 .78868 m .39059 .78699 L .39269 .7866 L F
.39198 .78868 m .39014 .78935 L .39059 .78699 L F
.853 .884 .86 r
.54633 .85822 m .54732 .85513 L .54512 .85528 L F
.54633 .85822 m .54862 .85582 L .54732 .85513 L F
.691 .947 .958 r
.68544 .72878 m .68814 .72816 L .68698 .72768 L F
.228 .747 .768 r
.68814 .72816 m .69035 .72756 L .68698 .72768 L F
.68814 .72816 m .69022 .72768 L .69035 .72756 L F
.396 .034 .229 r
.34058 .75999 m .34242 .75987 L .34037 .76038 L F
.475 0 0 r
.57309 .83485 m .57406 .83444 L .5708 .83433 L F
.076 .637 .756 r
.57577 .83429 m .57406 .83444 L .57309 .83485 L F
.57577 .83429 m .57667 .83431 L .57406 .83444 L F
.768 .673 .758 r
.5594 .78185 m .56288 .78255 L .5614 .78101 L F
.5594 .78185 m .56069 .78454 L .56288 .78255 L F
.659 .17 .078 r
.56456 .78162 m .5614 .78101 L .56288 .78255 L F
.711 .531 .644 r
.60158 .78179 m .60153 .78407 L .60362 .78158 L F
.71 .53 .643 r
.60362 .78158 m .60153 .78407 L .6038 .78403 L F
.675 .499 .639 r
.6038 .78403 m .60701 .78173 L .60362 .78158 L F
.977 .694 .416 r
.55779 .81874 m .55908 .82156 L .55779 .82094 L F
.933 .597 .155 r
.55908 .82156 m .55871 .82277 L .55779 .82094 L F
.55908 .82156 m .55947 .82366 L .55871 .82277 L F
.231 .744 .724 r
.51995 .81634 m .51752 .81699 L .51981 .81528 L F
.712 .324 .313 r
.51981 .81528 m .52289 .81575 L .51995 .81634 L F
0 0 0 r
.52289 .81575 m .52084 .81846 L .51995 .81634 L F
.76 .464 .484 r
.59423 .80006 m .59294 .80225 L .59104 .79972 L F
.8 .516 .508 r
.59423 .80006 m .5949 .80245 L .59294 .80225 L F
.671 .536 .691 r
.42438 .8793 m .42689 .8793 L .42652 .8765 L F
.769 .62 .695 r
.42434 .88183 m .42689 .8793 L .42438 .8793 L F
.742 .705 .817 r
.53413 .84226 m .53738 .84267 L .5358 .84127 L F
.771 .568 .624 r
.53413 .84226 m .53523 .84344 L .53738 .84267 L F
.616 .689 .895 r
.5358 .84127 m .53738 .84267 L .53953 .84219 L F
.722 .651 .777 r
.41629 .73029 m .41671 .73221 L .41364 .73114 L F
.441 .46 .783 r
.41837 .73039 m .41671 .73221 L .41629 .73029 L F
.498 .547 .838 r
.41837 .73039 m .41908 .73277 L .41671 .73221 L F
.759 .617 .702 r
.61432 .78388 m .61553 .78672 L .6174 .78409 L F
.5 .183 .361 r
.33477 .73876 m .33778 .7362 L .3355 .73677 L F
.387 0 .156 r
.33778 .7362 m .33978 .73587 L .34066 .73471 L F
.33 0 .119 r
.34066 .73471 m .34187 .73539 L .34242 .73417 L F
.34066 .73471 m .33978 .73587 L .34187 .73539 L F
.508 .213 .4 r
.35365 .75416 m .35222 .75724 L .35012 .75749 L F
.444 .147 .366 r
.35418 .75682 m .35365 .75416 L .35479 .75405 L F
.35418 .75682 m .35222 .75724 L .35365 .75416 L F
.776 .413 .368 r
.5508 .80542 m .55448 .80759 L .55419 .80539 L F
.549 .428 .668 r
.55419 .80539 m .55615 .80555 L .55613 .80153 L F
.551 .391 .618 r
.55419 .80539 m .55448 .80759 L .55615 .80555 L F
.557 .404 .629 r
.41926 .75517 m .42138 .75491 L .42168 .75258 L F
.62 .392 .55 r
.41926 .75517 m .42141 .75725 L .42138 .75491 L F
.41926 .75517 m .41914 .75747 L .42141 .75725 L F
.855 .975 .865 r
.71275 .74157 m .71593 .73967 L .71358 .74058 L F
.698 .983 .861 r
.71358 .74058 m .71593 .73967 L .71677 .73833 L F
.545 .352 .571 r
.57566 .79442 m .57799 .79177 L .57702 .7928 L F
.64 .563 .752 r
.62818 .75516 m .63045 .7527 L .62703 .75217 L F
.62818 .75516 m .63045 .75473 L .63045 .7527 L F
.439 .272 .556 r
.66108 .6286 m .66295 .6257 L .66288 .62796 L F
.587 .412 .612 r
.66288 .62796 m .66096 .63043 L .66108 .6286 L F
.868 .676 .64 r
.67641 .75468 m .67809 .7553 L .67669 .75236 L F
.828 .622 .624 r
.67518 .75787 m .67809 .7553 L .67641 .75468 L F
.67518 .75787 m .67793 .75763 L .67809 .7553 L F
.839 .601 .578 r
.64333 .73634 m .64326 .73906 L .64628 .73885 L F
.85 .775 .778 r
.64326 .73906 m .64424 .74173 L .64628 .73885 L F
.71 .562 .686 r
.64424 .74173 m .64747 .7422 L .64628 .73885 L F
.651 .531 .704 r
.64747 .7422 m .64934 .73988 L .64628 .73885 L F
.824 .426 .296 r
.47272 .86343 m .47453 .86606 L .47636 .86578 L F
.561 .933 .907 r
.47636 .86578 m .47453 .86606 L .4768 .86476 L F
.266 .253 .658 r
.4784 .86777 m .47636 .86578 L .47925 .86609 L F
.4784 .86777 m .47692 .86874 L .47636 .86578 L F
.691 .627 .78 r
.65843 .75516 m .66191 .75597 L .66075 .75517 L F
.817 .457 .375 r
.58293 .78953 m .58089 .78981 L .57969 .78735 L F
.867 .85 .824 r
.58293 .78953 m .57992 .79055 L .58089 .78981 L F
.707 .545 .667 r
.58625 .79194 m .58259 .79228 L .58293 .78953 L F
.774 .477 .484 r
.49799 .84734 m .49734 .84701 L .49619 .845 L F
.116 .248 .724 r
.49708 .84735 m .49734 .84701 L .49647 .84573 L F
.49728 .84789 m .49731 .84736 L .49708 .84735 L F
.49731 .84736 m .49734 .84701 L .49708 .84735 L F
.49728 .84789 m .49748 .84726 L .49733 .84713 L F
.368 0 0 r
.49821 .84739 m .49761 .84737 L .49799 .84734 L F
.651 .18 .122 r
.49799 .84734 m .49761 .84737 L .49754 .84731 L F
.774 .477 .484 r
.49799 .84734 m .49754 .84731 L .49734 .84701 L F
0 .026 .582 r
.49619 .845 m .49821 .84739 L .49799 .84734 L F
.116 .248 .724 r
.4977 .84766 m .49821 .84739 L .49619 .845 L F
.368 0 0 r
.49821 .84739 m .49503 .84758 L .49761 .84737 L F
.651 .18 .122 r
.49562 .8472 m .49503 .84758 L .49323 .84705 L F
.774 .477 .484 r
.49734 .84701 m .49323 .84705 L .49282 .84477 L F
.116 .248 .724 r
.49733 .84713 m .49748 .84726 L .49734 .84701 L F
.774 .477 .484 r
.49754 .84731 m .49323 .84705 L .49734 .84701 L F
.972 .732 .517 r
.49323 .84705 m .49333 .85011 L .49447 .8496 L F
.656 .944 .695 r
.49584 .84629 m .49327 .84873 L .49503 .84758 L F
.49327 .84873 m .49325 .84875 L .49503 .84758 L F
.651 .18 .122 r
.49754 .84731 m .49503 .84758 L .49562 .8472 L F
.49761 .84737 m .49503 .84758 L .49754 .84731 L F
.116 .248 .724 r
.49728 .84789 m .4977 .84766 L .49748 .84726 L F
.49647 .84573 m .49734 .84701 L .49619 .845 L F
.774 .477 .484 r
.49734 .84701 m .49282 .84477 L .49619 .845 L F
.32 .728 .979 r
.49728 .84789 m .49856 .84764 L .49821 .84739 L F
.669 .599 .768 r
.49728 .84789 m .50141 .84979 L .49856 .84764 L F
.571 .496 .731 r
.43965 .87371 m .44132 .8713 L .43912 .87159 L F
.43965 .87371 m .44171 .87341 L .44132 .8713 L F
.613 .569 .781 r
.43965 .87371 m .44277 .87631 L .44171 .87341 L F
0 0 0 r
.49553 .88533 m .49712 .88485 L .4991 .88431 L F
.42 .071 .265 r
.39724 .77069 m .39905 .77044 L .40012 .76839 L F
.476 .128 .296 r
.40012 .76839 m .40162 .76952 L .40198 .76789 L F
.40012 .76839 m .39905 .77044 L .40162 .76952 L F
.67 .453 .581 r
.60686 .78414 m .60908 .78167 L .60701 .78173 L F
.60686 .78414 m .60908 .78388 L .60908 .78167 L F
.717 .541 .65 r
.60908 .78388 m .61251 .78176 L .60908 .78167 L F
.591 .241 .344 r
.57219 .77666 m .57436 .7781 L .57561 .77602 L F
.747 .424 .437 r
.57561 .77602 m .57765 .77834 L .5775 .77638 L F
.57561 .77602 m .57436 .7781 L .57765 .77834 L F
.646 .637 .827 r
.53951 .81528 m .53714 .81601 L .53577 .81389 L F
.715 .595 .721 r
.65477 .72613 m .65616 .72884 L .65264 .7288 L F
.571 .114 .129 r
.65616 .72884 m .65491 .72924 L .65264 .7288 L F
.306 0 0 r
.65785 .72942 m .65491 .72924 L .65616 .72884 L F
.589 .16 .195 r
.39945 .74282 m .40178 .74397 L .40021 .74392 L F
.498 .169 .339 r
.3525 .66519 m .34978 .66652 L .35056 .66643 L F
.657 .333 .412 r
.49441 .8349 m .4975 .83709 L .49722 .83439 L F
.49441 .8349 m .49563 .83595 L .4975 .83709 L F
.717 .651 .782 r
.63566 .75244 m .63901 .753 L .63793 .74992 L F
.532 .294 .499 r
.45677 .83959 m .45891 .8393 L .45961 .83671 L F
.663 .422 .545 r
.45961 .83671 m .46145 .83902 L .46168 .83688 L F
.45961 .83671 m .45891 .8393 L .46145 .83902 L F
.049 .317 .801 r
.66639 .7559 m .66847 .75661 L .66691 .75478 L F
.66639 .7559 m .66804 .75762 L .66847 .75661 L F
.955 .863 .45 r
.60805 .83118 m .60856 .82911 L .60766 .8309 L F
.876 .911 .849 r
.60856 .82911 m .6097 .82591 L .60804 .82859 L F
.60856 .82911 m .61078 .82652 L .6097 .82591 L F
.987 .838 .459 r
.60766 .8309 m .60856 .82911 L .60804 .82859 L F
.441 .851 .68 r
.51723 .88373 m .51895 .88282 L .52066 .88175 L F
.82 .37 0 r
.68126 .74457 m .68165 .74629 L .67964 .74444 L F
.68126 .74457 m .68275 .74722 L .68165 .74629 L F
0 0 0 r
.36166 .79044 m .36449 .78881 L .36318 .78919 L F
.797 .694 .751 r
.61348 .79171 m .61456 .79462 L .61614 .79215 L F
.452 .088 .255 r
.41658 .77373 m .41382 .77538 L .41474 .77341 L F
.434 .1 .299 r
.38343 .79259 m .38304 .79389 L .38083 .79428 L F
.521 .221 .398 r
.38549 .79215 m .38304 .79389 L .38343 .79259 L F
.584 .382 .573 r
.50289 .83696 m .50295 .83899 L .50072 .83924 L F
.50289 .83696 m .50295 .83899 L .50072 .83924 L F
.446 .497 .818 r
.50295 .83899 m .5036 .83595 L .50289 .83696 L F
.283 0 0 r
.35712 .72804 m .35915 .72766 L .36064 .72614 L F
.438 0 .068 r
.35915 .72766 m .36273 .72616 L .36064 .72614 L F
.629 .485 .668 r
.44589 .85272 m .4485 .85288 L .44796 .85002 L F
.595 .442 .644 r
.44643 .85549 m .4485 .85288 L .44589 .85272 L F
.887 .472 .06 r
.67379 .72069 m .67377 .72213 L .67268 .71997 L F
.67379 .72069 m .67465 .72291 L .67377 .72213 L F
.724 .542 .645 r
.5982 .78403 m .60153 .78407 L .60158 .78179 L F
.746 .811 .904 r
.71017 .70412 m .71007 .70667 L .71312 .70449 L F
0 .511 .707 r
.47244 .8578 m .47043 .85756 L .47069 .8551 L F
.47244 .8578 m .47291 .85785 L .47043 .85756 L F
.982 .744 .5 r
.55188 .82611 m .55181 .8287 L .55288 .82903 L F
.909 .62 .125 r
.55181 .8287 m .55263 .8314 L .55288 .82903 L F
0 .268 .676 r
.54255 .84327 m .54379 .84383 L .54198 .84172 L F
.54255 .84327 m .54512 .84465 L .54379 .84383 L F
0 .241 .632 r
.54595 .84511 m .54512 .84465 L .54255 .84327 L F
.3 0 0 r
.65608 .72943 m .6593 .72994 L .65616 .72987 L F
0 0 .004 r
.65608 .72943 m .65616 .72987 L .65617 .7298 L F
0 .514 .763 r
.66157 .73047 m .65608 .72943 L .65785 .72942 L F
.66157 .73047 m .66014 .73014 L .65608 .72943 L F
.34 0 0 r
.66037 .73005 m .66156 .73041 L .6593 .72994 L F
.66252 .73026 m .66156 .73041 L .66037 .73005 L F
.329 .536 .904 r
.66142 .73137 m .66252 .73026 L .66157 .73047 L F
.447 .269 .546 r
.66142 .73137 m .66303 .73182 L .66252 .73026 L F
.092 .314 .792 r
.66303 .73182 m .6648 .73218 L .66252 .73026 L F
.517 0 0 r
.66252 .73026 m .66378 .73147 L .66156 .73041 L F
.218 .434 .857 r
.66156 .73041 m .66378 .73147 L .6635 .73099 L F
.66156 .73041 m .6635 .73099 L .6626 .7294 L F
0 0 0 r
.66035 .72948 m .6593 .72994 L .66156 .73041 L F
.66035 .72948 m .65959 .72989 L .6593 .72994 L F
0 .514 .763 r
.66014 .73014 m .65865 .72984 L .65608 .72943 L F
.705 .581 .714 r
.6593 .72994 m .65716 .73262 L .65616 .72987 L F
.841 .997 .767 r
.65802 .73074 m .65716 .73262 L .6593 .72994 L F
0 0 0 r
.65959 .72989 m .65802 .73074 L .6593 .72994 L F
0 .514 .763 r
.65923 .72996 m .6593 .72994 L .65865 .72984 L F
.66014 .73014 m .6593 .72994 L .65923 .72996 L F
.76 .604 .685 r
.65616 .72987 m .65423 .72995 L .65504 .72911 L F
0 0 .004 r
.65608 .72943 m .65617 .7298 L .65642 .7277 L F
.306 0 0 r
.65606 .72931 m .65608 .72943 L .65491 .72924 L F
.473 .632 .924 r
.65491 .72924 m .65608 .72943 L .65642 .7277 L F
.76 .604 .685 r
.65622 .72935 m .65504 .72911 L .65642 .7277 L F
.65616 .72987 m .65504 .72911 L .65622 .72935 L F
.306 0 0 r
.65785 .72942 m .65608 .72943 L .65606 .72931 L F
.698 .983 .863 r
.48121 .85595 m .48465 .85403 L .48349 .85528 L F
.653 .22 .207 r
.48627 .85521 m .48349 .85528 L .48465 .85403 L F
.654 .122 0 r
.48798 .85541 m .48627 .85521 L .48465 .85403 L F
.393 .048 .257 r
.38541 .77664 m .38664 .77768 L .38746 .77631 L F
.38541 .77664 m .38464 .77821 L .38664 .77768 L F
.775 .65 .725 r
.64001 .74723 m .64318 .74751 L .64205 .74444 L F
.425 .527 .858 r
.50141 .84979 m .50142 .84789 L .49856 .84764 L F
.50141 .84979 m .50163 .84985 L .50142 .84789 L F
.529 .579 .85 r
.42125 .73247 m .42014 .73454 L .41908 .73277 L F
.42125 .73247 m .42223 .73445 L .42014 .73454 L F
.39 0 .15 r
.47155 .83211 m .47359 .83176 L .47415 .83091 L F
.372 0 .14 r
.47415 .83091 m .47359 .83176 L .47612 .83123 L F
.623 .501 .693 r
.42652 .8765 m .42689 .8793 L .42958 .8786 L F
.548 .414 .651 r
.65843 .75516 m .66073 .75234 L .65888 .75421 L F
.65843 .75516 m .66075 .75517 L .66073 .75234 L F
.56 .408 .632 r
.43912 .87159 m .44132 .8713 L .44115 .86872 L F
.907 .939 .818 r
.54862 .85582 m .55072 .85296 L .54971 .85248 L F
.31 0 0 r
.36313 .75186 m .36159 .75338 L .35952 .75356 L F
0 0 0 r
.3638 .75183 m .36313 .75186 L .36428 .75125 L F
.54 .219 .372 r
.3638 .75183 m .36159 .75338 L .36313 .75186 L F
.829 .714 .738 r
.47906 .85751 m .4773 .86031 L .48109 .86018 L F
.765 .511 .55 r
.47695 .86267 m .48109 .86018 L .4773 .86031 L F
.369 .246 .579 r
.48109 .86018 m .48293 .86116 L .48244 .85792 L F
0 0 .326 r
.48109 .86018 m .48217 .86294 L .48293 .86116 L F
.796 .309 0 r
.582 .82885 m .58037 .82643 L .57933 .82585 L F
.722 .543 .647 r
.42092 .7499 m .42168 .75258 L .42395 .7525 L F
.625 .19 .194 r
.56871 .77764 m .57104 .77817 L .57219 .77666 L F
.623 .187 .192 r
.57219 .77666 m .57104 .77817 L .57436 .7781 L F
.818 .793 .829 r
.65568 .71814 m .65286 .7182 L .65496 .7168 L F
.829 .756 .783 r
.65568 .71814 m .65348 .72112 L .65286 .7182 L F
.77 .777 .858 r
.65807 .71587 m .65568 .71814 L .65496 .7168 L F
.548 .529 .786 r
.46119 .88468 m .46214 .88127 L .4602 .88235 L F
.46119 .88468 m .46341 .88458 L .46214 .88127 L F
.432 .517 .845 r
.67409 .70664 m .67328 .70901 L .67187 .70718 L F
.67409 .70664 m .67564 .70968 L .67328 .70901 L F
.907 .939 .818 r
.54862 .85582 m .54971 .85248 L .54732 .85513 L F
.839 .586 .557 r
.51979 .8785 m .52318 .8796 L .52281 .87695 L F
.634 .822 .973 r
.52496 .87617 m .52281 .87695 L .5241 .8752 L F
.273 .31 .718 r
.5241 .8752 m .52281 .87695 L .52455 .87851 L F
.664 .9 .561 r
.53366 .86834 m .53342 .87014 L .53374 .86826 L F
.53366 .86834 m .53163 .8707 L .53342 .87014 L F
.548 .384 .612 r
.44249 .86328 m .44452 .86057 L .4423 .86087 L F
.484 .242 .471 r
.65375 .63603 m .65147 .6385 L .65174 .6365 L F
.512 0 0 r
.48819 .88416 m .49154 .88441 L .49017 .88472 L F
.706 .233 .126 r
.49017 .88472 m .49154 .88441 L .49334 .88602 L F
.533 .8 .995 r
.52138 .85158 m .52049 .85272 L .51913 .85195 L F
.227 .24 .665 r
.52049 .85272 m .52209 .85526 L .52114 .85511 L F
.617 .193 0 r
.52151 .85439 m .52209 .85526 L .52049 .85272 L F
.52151 .85439 m .52049 .85272 L .52138 .85158 L F
.478 .065 .179 r
.38861 .78922 m .38915 .79082 L .38744 .79158 L F
.38861 .78922 m .39014 .78935 L .38915 .79082 L F
.736 .557 .651 r
.61251 .78176 m .61237 .78414 L .61434 .78147 L F
.737 .559 .652 r
.61237 .78414 m .61432 .78388 L .61434 .78147 L F
.544 .311 .512 r
.43118 .76463 m .4291 .76284 L .43117 .76256 L F
.43118 .76463 m .4293 .76518 L .4291 .76284 L F
.596 .41 .6 r
.52869 .8548 m .53121 .85539 L .53118 .8523 L F
.311 .069 .377 r
.65264 .7288 m .65459 .72841 L .65477 .72613 L F
.411 .664 .964 r
.65264 .7288 m .65491 .72924 L .65459 .72841 L F
.777 .277 .006 r
.48878 .86051 m .48885 .86089 L .48865 .85963 L F
0 0 .441 r
.48885 .86089 m .48886 .86055 L .48865 .85963 L F
.681 .889 .974 r
.48865 .85963 m .48886 .86055 L .48878 .86053 L F
.48865 .85963 m .48878 .86053 L .4868 .86011 L F
.777 .277 .006 r
.48871 .86015 m .48878 .86051 L .48865 .85963 L F
.48893 .86224 m .48885 .86089 L .48871 .86015 L F
.267 .72 .956 r
.48534 .86026 m .48878 .86054 L .48885 .86089 L F
.48878 .86054 m .48886 .86055 L .48885 .86089 L F
.777 .277 .006 r
.48893 .86224 m .49085 .86304 L .48885 .86089 L F
.6 .488 .698 r
.49804 .85229 m .49854 .85566 L .49657 .8565 L F
.342 .009 .247 r
.36811 .80253 m .37099 .79949 L .36991 .80172 L F
.396 .029 .219 r
.37099 .79949 m .3719 .80118 L .36991 .80172 L F
.37099 .79949 m .37274 .79952 L .3719 .80118 L F
.732 .652 .77 r
.64953 .74178 m .64934 .73988 L .64747 .7422 L F
.693 .598 .745 r
.64953 .74178 m .6518 .73892 L .64934 .73988 L F
.64953 .74178 m .65283 .74214 L .6518 .73892 L F
.371 .03 .251 r
.50575 .83664 m .50544 .83734 L .50464 .83757 L F
.808 .622 .65 r
.50809 .8368 m .50477 .83889 L .50575 .83664 L F
.371 .03 .251 r
.50575 .83664 m .50477 .83889 L .50295 .83899 L F
.575 .806 .987 r
.50739 .83679 m .50403 .83742 L .5036 .83595 L F
.766 .559 .617 r
.51034 .83801 m .50807 .83946 L .50808 .83733 L F
.50951 .83756 m .50808 .83733 L .50809 .8368 L F
.51034 .83801 m .50808 .83733 L .50951 .83756 L F
.808 .622 .65 r
.50746 .8372 m .50807 .83946 L .50477 .83889 L F
.50809 .8368 m .50808 .83733 L .50746 .8372 L F
.50808 .83733 m .50807 .83946 L .50746 .8372 L F
.587 .234 .337 r
.50575 .83664 m .50403 .83742 L .50881 .8371 L F
.575 .806 .987 r
.50738 .83719 m .50729 .8372 L .50729 .83719 L F
.50881 .8371 m .50741 .83719 L .50738 .83719 L F
.50741 .83719 m .50729 .8372 L .50738 .83719 L F
.587 .234 .337 r
.50575 .83664 m .50881 .8371 L .50809 .8368 L F
.575 .806 .987 r
.50881 .8371 m .50729 .83719 L .50739 .83679 L F
.50729 .8372 m .50551 .83732 L .50643 .83706 L F
.50729 .8372 m .50643 .83706 L .50739 .83679 L F
.50551 .83732 m .50403 .83742 L .50739 .83679 L F
.371 .03 .251 r
.50464 .83757 m .50477 .83889 L .50295 .83899 L F
.50544 .83734 m .50477 .83889 L .50464 .83757 L F
.286 0 0 r
.36273 .72616 m .36474 .72597 L .36594 .72515 L F
.212 0 0 r
.36474 .72597 m .36783 .7254 L .36594 .72515 L F
.686 .306 .322 r
.49719 .83976 m .50072 .83924 L .49843 .84024 L F
.008 0 0 r
.47909 .8296 m .48194 .82918 L .48015 .82901 L F
.883 .463 .196 r
.57969 .78735 m .58089 .78981 L .57889 .78832 L F
.797 .694 .751 r
.61139 .79437 m .61456 .79462 L .61348 .79171 L F
.848 .615 .586 r
.61139 .79437 m .61442 .79663 L .61456 .79462 L F
.396 .265 .582 r
.66275 .6229 m .66418 .62011 L .66198 .62056 L F
.66418 .62011 m .66275 .6229 L .66198 .62056 L F
.57 .399 .612 r
.69195 .74718 m .69001 .74945 L .68966 .74727 L F
.675 .529 .68 r
.6599 .62337 m .66275 .6229 L .66198 .62056 L F
.6599 .62337 m .66275 .6229 L .66198 .62056 L F
.265 0 0 r
.68563 .72118 m .68623 .72066 L .68389 .72087 L F
.704 .345 .365 r
.68623 .72066 m .68506 .72149 L .68629 .72117 L F
.265 0 0 r
.68566 .72119 m .68569 .72116 L .68563 .72118 L F
.68569 .72116 m .68623 .72066 L .68563 .72118 L F
.773 .825 .894 r
.68298 .72244 m .68506 .72149 L .68502 .72137 L F
.265 0 0 r
.68566 .72119 m .68389 .72087 L .68253 .71913 L F
.063 .436 .874 r
.68426 .71944 m .68566 .72119 L .68253 .71913 L F
.773 .825 .894 r
.68319 .72195 m .68502 .72137 L .68426 .71944 L F
.68298 .72244 m .68502 .72137 L .68319 .72195 L F
.496 .313 .563 r
.53121 .85539 m .53327 .85234 L .53118 .8523 L F
.251 .294 .713 r
.54595 .84511 m .54736 .84406 L .54512 .84465 L F
.54595 .84511 m .54787 .84729 L .54736 .84406 L F
.592 .36 .533 r
.44359 .75263 m .44312 .7548 L .44087 .7549 L F
.362 .439 .806 r
.44229 .75023 m .44508 .75189 L .44359 .75263 L F
.141 0 .354 r
.44508 .75189 m .44312 .7548 L .44359 .75263 L F
.868 .817 .796 r
.59037 .82365 m .59078 .82608 L .58834 .82648 L F
.87 .803 .781 r
.58834 .82648 m .59078 .82608 L .58887 .82891 L F
.408 0 .107 r
.64605 .71057 m .64501 .71203 L .64739 .71167 L F
.94 .898 .502 r
.61078 .82652 m .6114 .82277 L .6097 .82591 L F
.576 .429 .645 r
.54086 .83431 m .54343 .8339 L .54292 .83136 L F
.583 .578 .813 r
.54086 .83431 m .54403 .83676 L .54343 .8339 L F
.058 0 0 r
.69413 .75425 m .69537 .75435 L .69317 .75396 L F
.69413 .75425 m .69621 .75435 L .69537 .75435 L F
.626 .595 .799 r
.44171 .87341 m .44277 .87631 L .4451 .87578 L F
.861 .639 .601 r
.67446 .74183 m .67425 .74425 L .67595 .74436 L F
.849 .567 .511 r
.67425 .74425 m .67458 .74644 L .67595 .74436 L F
.822 .528 .493 r
.67458 .74644 m .67627 .74618 L .67595 .74436 L F
.698 .908 .557 r
.5721 .83089 m .57346 .8294 L .57187 .82854 L F
.724 .472 .545 r
.58961 .78365 m .59287 .7815 L .58955 .78141 L F
.58961 .78365 m .59288 .78405 L .59287 .7815 L F
.745 .489 .543 r
.59287 .7815 m .59288 .78405 L .59476 .78377 L F
.552 .31 .502 r
.39261 .77356 m .39474 .77337 L .39515 .77113 L F
.549 .321 .522 r
.39474 .77337 m .39724 .77069 L .39515 .77113 L F
.439 0 .08 r
.66115 .62465 m .6599 .62337 L .65922 .62375 L F
.681 .56 .712 r
.6599 .62337 m .66275 .6229 L .66295 .6257 L F
.439 0 .08 r
.66115 .62465 m .66275 .6229 L .6599 .62337 L F
.341 .796 .946 r
.43649 .74957 m .43849 .74927 L .44 .74962 L F
.428 .841 .967 r
.44 .74962 m .44049 .74883 L .44191 .74958 L F
.44 .74962 m .43849 .74927 L .44049 .74883 L F
.414 .727 .989 r
.57985 .84678 m .58227 .8464 L .57919 .84636 L F
.57985 .84678 m .58174 .84682 L .58227 .8464 L F
.742 .553 .639 r
.53172 .83344 m .52861 .83128 L .53032 .83176 L F
.741 .703 .815 r
.65286 .7182 m .65348 .72112 L .65039 .72056 L F
.229 0 0 r
.65348 .72112 m .6525 .72103 L .65039 .72056 L F
.191 .65 .941 r
.65348 .72112 m .65472 .72071 L .6525 .72103 L F
.65348 .72112 m .65673 .72137 L .65472 .72071 L F
.686 .306 .322 r
.49719 .83976 m .49936 .84139 L .50072 .83924 L F
.629 .291 .38 r
.49936 .84139 m .50295 .83899 L .50072 .83924 L F
.65 .948 .953 r
.40927 .76456 m .40767 .76573 L .4085 .76447 L F
.655 .955 .945 r
.40767 .76573 m .40656 .76558 L .4085 .76447 L F
.651 .685 .869 r
.52858 .87349 m .53057 .87391 L .52742 .87373 L F
.318 .074 .378 r
.65477 .72613 m .65642 .7277 L .65715 .72514 L F
.65477 .72613 m .65459 .72841 L .65642 .7277 L F
.579 .343 .523 r
.65131 .71029 m .65151 .7122 L .64903 .71244 L F
.597 .722 .932 r
.65357 .70992 m .65131 .71029 L .65062 .70895 L F
.683 .418 .516 r
.65131 .71029 m .65348 .71231 L .65151 .7122 L F
.584 .431 .64 r
.65357 .70992 m .65348 .71231 L .65131 .71029 L F
.766 .42 .399 r
.52171 .86035 m .52477 .86083 L .52511 .86274 L F
.22 .363 .796 r
.52588 .85983 m .52718 .86312 L .52477 .86083 L F
.735 .398 .41 r
.52477 .86083 m .52718 .86312 L .52511 .86274 L F
0 0 .299 r
.59135 .82031 m .59024 .82197 L .59037 .82365 L F
.769 .62 .695 r
.42434 .88183 m .4276 .88202 L .42689 .8793 L F
.636 .54 .729 r
.42689 .8793 m .4276 .88202 L .42998 .88142 L F
.68 .571 .725 r
.44019 .86367 m .44054 .86595 L .44249 .86328 L F
.596 .455 .66 r
.44054 .86595 m .44283 .86567 L .44249 .86328 L F
.604 .494 .701 r
.44115 .86872 m .44283 .86567 L .44054 .86595 L F
.769 .711 .798 r
.55615 .80555 m .55448 .80759 L .55648 .80753 L F
.744 .461 .503 r
.55448 .80759 m .55622 .81035 L .55648 .80753 L F
.454 .488 .804 r
.55648 .80753 m .55897 .80756 L .55615 .80555 L F
.43 .193 .451 r
.55648 .80753 m .55826 .8091 L .55897 .80756 L F
.55648 .80753 m .55622 .81035 L .55826 .8091 L F
.119 0 0 r
.52209 .85526 m .52352 .85547 L .52176 .8552 L F
0 .175 .691 r
.52252 .85534 m .52209 .85526 L .52151 .85439 L F
0 0 .353 r
.52446 .85717 m .52352 .85547 L .52209 .85526 L F
0 .175 .691 r
.52446 .85717 m .52209 .85526 L .52252 .85534 L F
.119 0 0 r
.52209 .85526 m .52176 .8552 L .52114 .85511 L F
0 0 .353 r
.52446 .85717 m .52532 .85904 L .52352 .85547 L F
.853 .643 .618 r
.50163 .84985 m .49994 .85271 L .49776 .85127 L F
.50163 .84985 m .49776 .85127 L .50175 .85173 L F
.444 .543 .863 r
.50142 .84789 m .50163 .84985 L .50418 .84938 L F
.809 .648 .683 r
.61159 .81862 m .61023 .81574 L .61007 .8186 L F
.836 .451 .323 r
.61081 .82039 m .61159 .81862 L .61007 .8186 L F
.935 .598 .369 r
.61081 .82039 m .61245 .8213 L .61159 .81862 L F
.491 .243 .466 r
.40206 .78118 m .39946 .78401 L .39991 .78138 L F
.56 .726 .952 r
.53205 .82213 m .53254 .82407 L .52943 .82319 L F
.459 0 0 r
.52943 .82319 m .53103 .82434 L .53205 .82213 L F
.52943 .82319 m .53194 .82508 L .53103 .82434 L F
.518 .36 .606 r
.53103 .82434 m .53279 .82833 L .53347 .82638 L F
.377 .014 .216 r
.53194 .82508 m .53107 .82757 L .53103 .82434 L F
.556 .355 .563 r
.53254 .82407 m .53347 .82638 L .53103 .82434 L F
.893 .917 .832 r
.53504 .82105 m .53254 .82407 L .5322 .82271 L F
.53245 .82198 m .5322 .82271 L .53205 .82213 L F
.53504 .82105 m .5322 .82271 L .53245 .82198 L F
.017 0 .441 r
.53194 .82344 m .53325 .82509 L .53313 .82226 L F
.53103 .82434 m .53156 .82452 L .53194 .82344 L F
.53156 .82452 m .53325 .82509 L .53194 .82344 L F
.53103 .82434 m .53313 .82226 L .53205 .82213 L F
.507 .172 .334 r
.52639 .82838 m .53124 .82549 L .52687 .82546 L F
.53124 .82549 m .53194 .82508 L .53139 .82512 L F
.612 .414 .59 r
.53139 .82512 m .53194 .82508 L .53166 .82487 L F
0 0 .137 r
.53103 .82434 m .53105 .82574 L .53132 .82518 L F
.507 .172 .334 r
.52639 .82838 m .52871 .8282 L .53118 .82582 L F
.53124 .82549 m .53118 .82582 L .53194 .82508 L F
0 0 .137 r
.53105 .82574 m .53106 .82639 L .5313 .82523 L F
.507 .172 .334 r
.52639 .82838 m .53118 .82582 L .53124 .82549 L F
.377 .014 .216 r
.53194 .82508 m .53118 .82582 L .53107 .82757 L F
0 0 .137 r
.53106 .82639 m .53107 .82757 L .53118 .82582 L F
.377 .014 .216 r
.53118 .82582 m .52871 .8282 L .53107 .82757 L F
0 0 .137 r
.53118 .82582 m .53107 .82757 L .5313 .82523 L F
.5313 .82523 m .53107 .82757 L .53132 .82518 L F
.53139 .82512 m .53191 .82685 L .53192 .82464 L F
.53132 .82518 m .53133 .8252 L .53139 .82512 L F
.53133 .8252 m .53191 .82685 L .53139 .82512 L F
.53103 .82434 m .53132 .82518 L .53192 .82464 L F
.507 .172 .334 r
.53133 .8252 m .53139 .82512 L .53135 .82512 L F
.53124 .82549 m .53139 .82512 L .53133 .8252 L F
0 0 .137 r
.53132 .82518 m .53132 .82524 L .53133 .8252 L F
.507 .172 .334 r
.53124 .82549 m .53135 .82512 L .52687 .82546 L F
0 0 .137 r
.53133 .8252 m .53107 .82757 L .53191 .82685 L F
.53132 .82524 m .53107 .82757 L .53133 .8252 L F
.612 .414 .59 r
.52687 .82546 m .53135 .82512 L .52943 .82319 L F
.53135 .82512 m .53139 .82512 L .53137 .8251 L F
.53135 .82512 m .53137 .8251 L .52943 .82319 L F
.53139 .82512 m .53166 .82487 L .52943 .82319 L F
0 0 .137 r
.53192 .82464 m .53191 .82685 L .53325 .82509 L F
0 0 0 r
.35076 .79481 m .35164 .79476 L .35263 .79416 L F
.683 .592 .748 r
.6518 .73892 m .65283 .74214 L .65522 .74134 L F
.488 0 0 r
.70148 .74607 m .70548 .74892 L .70437 .74869 L F
.6 .331 .481 r
.33946 .69347 m .33593 .69127 L .3382 .69046 L F
.315 .308 .692 r
.47096 .8596 m .46948 .86119 L .46828 .85924 L F
.47096 .8596 m .47148 .86277 L .46948 .86119 L F
.859 .529 .426 r
.48798 .85541 m .48663 .85723 L .48627 .85521 L F
.726 .346 .33 r
.48798 .85541 m .48988 .85752 L .48663 .85723 L F
.848 .615 .586 r
.61139 .79437 m .61141 .79671 L .61442 .79663 L F
.859 .661 .634 r
.61127 .79892 m .61442 .79663 L .61141 .79671 L F
.61127 .79892 m .61297 .79996 L .61442 .79663 L F
.853 .776 .776 r
.64326 .73906 m .64143 .74185 L .64424 .74173 L F
.851 .781 .783 r
.64424 .74173 m .64143 .74185 L .64205 .74444 L F
.771 .421 .393 r
.50828 .88062 m .50653 .87921 L .50677 .88173 L F
.895 .479 .188 r
.49375 .88146 m .49174 .8792 L .49224 .88163 L F
.102 .657 .719 r
.49459 .88134 m .49375 .88146 L .49224 .88163 L F
0 .284 .786 r
.49485 .88225 m .49375 .88146 L .49459 .88134 L F
.375 .006 .205 r
.37792 .79741 m .37582 .79782 L .37803 .79635 L F
.178 0 .075 r
.38083 .79428 m .37958 .7964 L .37803 .79635 L F
.187 0 .171 r
.37958 .7964 m .37792 .79741 L .37803 .79635 L F
.865 .723 .704 r
.52422 .83418 m .52242 .83393 L .52261 .82988 L F
.705 .385 .432 r
.52422 .83418 m .52127 .83595 L .52242 .83393 L F
.52422 .83418 m .52317 .83666 L .52127 .83595 L F
.649 .618 .805 r
.52671 .83362 m .52422 .83418 L .52261 .82988 L F
.206 0 .194 r
.52516 .83565 m .52422 .83418 L .52671 .83362 L F
.52516 .83565 m .52317 .83666 L .52422 .83418 L F
.432 .219 .487 r
.32917 .69933 m .32873 .70152 L .32748 .70219 L F
.386 .162 .447 r
.33159 .69632 m .33144 .69913 L .32917 .69933 L F
.345 .117 .419 r
.33144 .69913 m .32873 .70152 L .32917 .69933 L F
.766 .559 .617 r
.51034 .83801 m .51198 .83998 L .50807 .83946 L F
.344 .616 .952 r
.51274 .83753 m .51363 .83889 L .51034 .83801 L F
.557 .523 .773 r
.51363 .83889 m .51198 .83998 L .51034 .83801 L F
0 .187 .702 r
.51034 .83801 m .51117 .83725 L .51019 .83649 L F
.535 .578 .844 r
.54403 .83676 m .54476 .83352 L .54343 .8339 L F
.54403 .83676 m .54611 .83634 L .54476 .83352 L F
0 0 0 r
.4784 .86777 m .47546 .87095 L .47692 .86874 L F
.612 .474 .67 r
.44796 .85002 m .45069 .85256 L .45017 .84965 L F
.44796 .85002 m .4485 .85288 L .45069 .85256 L F
.78 .338 .2 r
.56244 .8075 m .56511 .80882 L .56221 .81014 L F
.364 .023 .248 r
.38302 .77893 m .38413 .77975 L .38464 .77821 L F
.38302 .77893 m .38237 .7803 L .38413 .77975 L F
.222 .739 .733 r
.37245 .75137 m .37117 .75177 L .37399 .75032 L F
.263 0 0 r
.37587 .75001 m .37245 .75137 L .37399 .75032 L F
.593 .437 .639 r
.44435 .85818 m .44659 .85796 L .44643 .85549 L F
.593 .436 .639 r
.44435 .85818 m .44452 .86057 L .44659 .85796 L F
.541 .415 .657 r
.34198 .68053 m .34244 .68396 L .34008 .68423 L F
.545 .412 .65 r
.34244 .68396 m .34037 .68599 L .34008 .68423 L F
.636 .54 .729 r
.42689 .8793 m .42998 .88142 L .42958 .8786 L F
.476 0 0 r
.69491 .74135 m .69826 .74222 L .69945 .74193 L F
.557 .394 .615 r
.69945 .74193 m .69983 .74461 L .69759 .74524 L F
.916 .973 .782 r
.69945 .74193 m .70061 .73857 L .7016 .74142 L F
.69945 .74193 m .69826 .74222 L .70061 .73857 L F
.723 .51 .601 r
.70264 .74434 m .69945 .74193 L .7016 .74142 L F
.70264 .74434 m .69983 .74461 L .69945 .74193 L F
.992 .846 .596 r
.69658 .7439 m .69759 .74524 L .69983 .74461 L F
.69707 .74455 m .69586 .74522 L .69759 .74524 L F
.722 .711 .839 r
.69744 .74446 m .69535 .74551 L .69586 .74522 L F
.503 0 0 r
.69586 .74522 m .69364 .74504 L .69407 .74642 L F
.722 .711 .839 r
.69535 .74551 m .69523 .74557 L .69586 .74522 L F
.992 .846 .596 r
.69658 .7439 m .69586 .74522 L .69707 .74455 L F
0 .351 .779 r
.49552 .86605 m .4922 .86386 L .49441 .86537 L F
.106 .586 .909 r
.49724 .8663 m .49552 .86605 L .49441 .86537 L F
.082 .303 .784 r
.49775 .86906 m .49552 .86605 L .49724 .8663 L F
.987 .715 .359 r
.47627 .87285 m .47704 .87135 L .47546 .87095 L F
.47627 .87285 m .4771 .87358 L .47704 .87135 L F
.691 .872 .967 r
.59214 .84781 m .59163 .8461 L .59021 .84608 L F
.59214 .84781 m .59411 .84661 L .59163 .8461 L F
.675 .499 .639 r
.6038 .78403 m .60686 .78414 L .60701 .78173 L F
.467 .283 .547 r
.50519 .88174 m .50463 .88427 L .50648 .8839 L F
.547 .31 .509 r
.50648 .8839 m .50677 .88173 L .50519 .88174 L F
.467 .283 .547 r
.50519 .88174 m .50463 .88427 L .50648 .8839 L F
0 .011 .581 r
.68744 .75345 m .68656 .75169 L .68622 .75189 L F
.534 .714 .955 r
.32261 .66134 m .32184 .66298 L .32058 .6616 L F
.462 .627 .924 r
.32261 .66134 m .32403 .66307 L .32184 .66298 L F
.98 .805 .595 r
.55274 .84415 m .55441 .84245 L .55366 .84023 L F
.55274 .84415 m .55385 .84478 L .55441 .84245 L F
.691 .71 .863 r
.70879 .7477 m .70907 .74601 L .70857 .74626 L F
.70879 .7477 m .71154 .74704 L .70907 .74601 L F
.619 .515 .714 r
.43151 .73804 m .43216 .74163 L .42998 .74207 L F
.587 .489 .71 r
.43252 .74391 m .42998 .74207 L .43216 .74163 L F
.43252 .74391 m .43034 .74432 L .42998 .74207 L F
.625 .082 0 r
.50764 .87368 m .51024 .87399 L .50983 .87492 L F
.77 .263 0 r
.50983 .87492 m .51024 .87399 L .5123 .87631 L F
.736 .212 0 r
.51024 .87399 m .51356 .87646 L .5123 .87631 L F
.419 .811 .986 r
.51217 .81878 m .51568 .819 L .51441 .81828 L F
.716 .898 .961 r
.51441 .81828 m .51568 .819 L .51793 .81763 L F
.929 .972 .739 r
.50843 .83441 m .5077 .83444 L .50931 .83163 L F
.519 .916 .89 r
.6947 .7497 m .69335 .75078 L .69184 .75002 L F
.6947 .7497 m .69546 .74976 L .69335 .75078 L F
.509 .271 .489 r
.46925 .83433 m .47134 .83402 L .47155 .83211 L F
.354 .142 .446 r
.47155 .83211 m .47307 .83312 L .47359 .83176 L F
.47155 .83211 m .47134 .83402 L .47307 .83312 L F
.7 .724 .204 r
.54712 .78363 m .54723 .78312 L .54773 .7814 L F
.242 0 .111 r
.54773 .7814 m .55007 .78114 L .55075 .77948 L F
.243 0 .106 r
.54773 .7814 m .54928 .78201 L .55007 .78114 L F
.54773 .7814 m .54723 .78312 L .54928 .78201 L F
.881 .573 .061 r
.53332 .81604 m .53321 .81695 L .53124 .81515 L F
.53332 .81604 m .53371 .8181 L .53321 .81695 L F
.862 .682 .657 r
.60856 .80761 m .61154 .80529 L .61018 .80484 L F
.60856 .80761 m .61128 .80735 L .61154 .80529 L F
.815 .756 .797 r
.61154 .80529 m .61281 .80142 L .61018 .80484 L F
.61154 .80529 m .61366 .80266 L .61281 .80142 L F
.829 .395 .208 r
.58482 .79432 m .58259 .79228 L .58625 .79194 L F
0 0 .218 r
.48964 .83608 m .4896 .837 L .48919 .83426 L F
.48964 .83608 m .48919 .83426 L .48733 .83365 L F
.378 0 .188 r
.38158 .79596 m .38083 .79428 L .38304 .79389 L F
.38158 .79596 m .37958 .7964 L .38083 .79428 L F
.58 .641 .876 r
.45345 .87872 m .45479 .88099 L .457 .87987 L F
.63 .645 .846 r
.69117 .72158 m .68965 .72294 L .68842 .72012 L F
.601 .593 .815 r
.69117 .72158 m .69201 .72362 L .68965 .72294 L F
.353 .757 .983 r
.56793 .78216 m .56664 .78156 L .56456 .78162 L F
.621 .103 0 r
.57025 .78218 m .56664 .78156 L .56793 .78216 L F
.84 .713 .724 r
.66962 .73124 m .6718 .73317 L .67115 .73175 L F
.947 .672 .483 r
.55263 .8314 m .55297 .83428 L .554 .8341 L F
.781 .706 .167 r
.55364 .83606 m .554 .8341 L .55297 .83428 L F
.55364 .83606 m .55365 .83653 L .554 .8341 L F
.724 .62 .742 r
.63045 .75473 m .63355 .75513 L .63242 .752 L F
.74 .629 .736 r
.63242 .752 m .63355 .75513 L .63566 .75244 L F
.231 0 0 r
.37117 .75177 m .37047 .7519 L .36862 .75168 L F
.222 .739 .733 r
.37245 .75137 m .37047 .7519 L .37117 .75177 L F
.443 .09 .27 r
.34518 .73309 m .34729 .7328 L .34781 .73153 L F
.489 .135 .291 r
.34729 .7328 m .3493 .73266 L .34781 .73153 L F
.486 .136 .298 r
.34781 .73153 m .3493 .73266 L .34993 .73131 L F
.359 0 .167 r
.36332 .80434 m .36613 .803 L .36442 .80419 L F
0 0 0 r
.36442 .80419 m .36287 .8052 L .36332 .80434 L F
.878 .952 .853 r
.48144 .86586 m .4784 .86777 L .47925 .86609 L F
.465 .193 .415 r
.42179 .76851 m .42146 .77035 L .41942 .77074 L F
.533 .252 .435 r
.42363 .76999 m .42146 .77035 L .42179 .76851 L F
.569 .238 .369 r
.42423 .76854 m .42363 .76999 L .42179 .76851 L F
.583 .47 .69 r
.43252 .74391 m .43089 .74737 L .43034 .74432 L F
.842 .781 .792 r
.58887 .82891 m .58702 .83172 L .58629 .82905 L F
.809 .667 .706 r
.6755 .74912 m .67669 .75236 L .67728 .75019 L F
.795 .715 .776 r
.57082 .78682 m .5691 .7892 L .57147 .78846 L F
.179 .686 .903 r
.5766 .78852 m .57554 .78816 L .57372 .78818 L F
.5766 .78852 m .57554 .78816 L .57372 .78818 L F
.595 .195 .255 r
.57554 .78816 m .5753 .78817 L .57372 .78818 L F
.424 .507 .84 r
.57147 .78846 m .57372 .78818 L .57137 .78821 L F
.595 .195 .255 r
.5753 .78817 m .57022 .78836 L .57372 .78818 L F
.424 .507 .84 r
.57137 .78821 m .57372 .78818 L .57082 .78682 L F
.371 .694 .982 r
.57147 .78846 m .57506 .78925 L .57372 .78818 L F
.781 .549 .585 r
.58246 .81531 m .58579 .8132 L .58239 .81292 L F
.58246 .81531 m .58569 .8155 L .58579 .8132 L F
.581 .816 .988 r
.57781 .79408 m .57901 .795 L .58107 .79442 L F
.645 .11 0 r
.52084 .81846 m .51953 .81856 L .51793 .81763 L F
0 0 0 r
.52289 .81575 m .52186 .81769 L .52084 .81846 L F
.457 .885 .895 r
.52186 .81769 m .51953 .81856 L .52084 .81846 L F
.447 .687 .967 r
.67033 .76067 m .67166 .75941 L .66949 .76039 L F
.67033 .76067 m .67315 .76077 L .67166 .75941 L F
0 0 0 r
.55274 .78281 m .55123 .78354 L .55388 .782 L F
.55274 .78281 m .551 .78394 L .55123 .78354 L F
.008 0 0 r
.47909 .8296 m .48122 .82937 L .48194 .82918 L F
.587 .469 .685 r
.48194 .82918 m .48455 .83107 L .48428 .8288 L F
.48194 .82918 m .48231 .83144 L .48455 .83107 L F
.406 .829 .964 r
.48194 .82918 m .48298 .8285 L .48428 .8288 L F
.735 .326 0 r
.70809 .7453 m .70429 .74512 L .70537 .74483 L F
.674 .523 .672 r
.7052 .74239 m .70537 .74483 L .70264 .74434 L F
.735 .326 0 r
.70809 .7453 m .70719 .74401 L .70429 .74512 L F
.70809 .7453 m .70857 .74626 L .70719 .74401 L F
.72 .681 .811 r
.63242 .752 m .63566 .75244 L .63465 .74961 L F
.742 .692 .803 r
.63465 .74961 m .63566 .75244 L .63793 .74992 L F
.752 .614 .705 r
.61236 .7864 m .61553 .78672 L .61432 .78388 L F
.753 .607 .696 r
.61236 .7864 m .61359 .78952 L .61553 .78672 L F
.541 .772 .983 r
.64019 .72447 m .64264 .72413 L .64207 .72318 L F
.64207 .72318 m .64264 .72413 L .64019 .72447 L F
.913 .582 .404 r
.54512 .81772 m .54743 .82092 L .5463 .81832 L F
.603 .524 .738 r
.62687 .74984 m .62912 .74954 L .6287 .74682 L F
.586 .426 .631 r
.62687 .74984 m .62703 .75217 L .62912 .74954 L F
.788 .74 .809 r
.69758 .74821 m .69836 .74982 L .69546 .74976 L F
.661 .683 .86 r
.70026 .74865 m .69836 .74982 L .69758 .74821 L F
.525 .347 .582 r
.46712 .85491 m .46505 .85556 L .46507 .85278 L F
.717 .541 .65 r
.60908 .78388 m .61237 .78414 L .61251 .78176 L F
.459 .114 .293 r
.41185 .77583 m .40874 .77831 L .40983 .77617 L F
.455 .588 .897 r
.40572 .72713 m .40495 .72874 L .40357 .72667 L F
.496 .637 .917 r
.40572 .72713 m .40712 .72874 L .40495 .72874 L F
.313 0 .217 r
.34242 .75987 m .33964 .76239 L .34037 .76038 L F
0 0 0 r
.41068 .74159 m .40925 .74201 L .4074 .74238 L F
.347 0 0 r
.41256 .74164 m .40925 .74201 L .41068 .74159 L F
.735 .393 .401 r
.34065 .67623 m .34346 .67792 L .34393 .67609 L F
.551 .387 .613 r
.34593 .67312 m .34617 .67575 L .34393 .67609 L F
.506 .235 .437 r
.34617 .67575 m .34346 .67792 L .34393 .67609 L F
.551 .387 .613 r
.34593 .67312 m .34617 .67575 L .34393 .67609 L F
.506 .235 .437 r
.34617 .67575 m .34346 .67792 L .34393 .67609 L F
.999 .79 .471 r
.54811 .78477 m .54723 .78312 L .54712 .78363 L F
.81 .389 .247 r
.55012 .80696 m .5508 .80542 L .54968 .80473 L F
.55012 .80696 m .5528 .80782 L .5508 .80542 L F
.776 .413 .368 r
.5508 .80542 m .5528 .80782 L .55448 .80759 L F
.824 .613 .617 r
.67077 .73586 m .67426 .73671 L .6718 .73317 L F
.854 .613 .574 r
.67077 .73586 m .67326 .73878 L .67426 .73671 L F
.533 .352 .581 r
.67326 .73878 m .67452 .73646 L .67426 .73671 L F
.829 .395 .208 r
.58482 .79432 m .58325 .79401 L .58259 .79228 L F
.526 .323 .549 r
.34737 .7069 m .34711 .70942 L .34528 .70734 L F
.34737 .7069 m .34711 .70942 L .34528 .70734 L F
.824 .758 .789 r
.61281 .80142 m .61366 .80266 L .61297 .79996 L F
.378 .156 .445 r
.33312 .69845 m .33159 .69632 L .33405 .69517 L F
.33312 .69845 m .33144 .69913 L .33159 .69632 L F
0 0 0 r
.35274 .80958 m .35595 .80758 L .35484 .80873 L F
.123 0 0 r
.35753 .80709 m .35734 .8076 L .35595 .80758 L F
.119 0 0 r
.35595 .80758 m .35734 .8076 L .35484 .80873 L F
.841 .788 .801 r
.58834 .82648 m .58887 .82891 L .58629 .82905 L F
.743 .432 .456 r
.50463 .88427 m .50764 .88453 L .50768 .88652 L F
.677 .378 .46 r
.50764 .88453 m .50995 .88686 L .50768 .88652 L F
.777 .45 .435 r
.68919 .69859 m .69128 .69782 L .69015 .69748 L F
.717 .677 .81 r
.69015 .69748 m .69261 .69741 L .69128 .69782 L F
.221 0 0 r
.65576 .73635 m .65828 .73576 L .65942 .73464 L F
.188 0 0 r
.65942 .73464 m .65828 .73576 L .66065 .73476 L F
.937 .962 .748 r
.53419 .82751 m .53447 .82586 L .53611 .82646 L F
.53419 .82751 m .53279 .82833 L .53447 .82586 L F
.601 .11 .062 r
.65905 .72074 m .65921 .72181 L .65673 .72137 L F
0 0 .349 r
.65905 .72074 m .65981 .72212 L .65921 .72181 L F
.575 .354 .543 r
.45423 .84213 m .45652 .84192 L .45677 .83959 L F
.501 .291 .526 r
.45677 .83959 m .45851 .84144 L .45891 .8393 L F
.45677 .83959 m .45652 .84192 L .45851 .84144 L F
.491 .433 .72 r
.66438 .62234 m .66295 .6257 L .66275 .6229 L F
.66438 .62234 m .66424 .62465 L .66295 .6257 L F
.002 0 .297 r
.66424 .62465 m .66288 .62796 L .66295 .6257 L F
.604 .494 .701 r
.44115 .86872 m .44333 .8685 L .44283 .86567 L F
.647 .474 .635 r
.44115 .86872 m .44358 .87093 L .44333 .8685 L F
.44115 .86872 m .44132 .8713 L .44358 .87093 L F
.903 .799 .735 r
.49563 .83595 m .49516 .83961 L .4975 .83709 L F
.49563 .83595 m .49338 .83982 L .49516 .83961 L F
.712 .324 .313 r
.51981 .81528 m .52225 .8163 L .52289 .81575 L F
.735 .957 .665 r
.52289 .81575 m .52449 .81342 L .52433 .81571 L F
.52289 .81575 m .52225 .8163 L .52449 .81342 L F
0 0 0 r
.52311 .81656 m .52289 .81575 L .52433 .81571 L F
.52311 .81656 m .52186 .81769 L .52289 .81575 L F
.604 .372 .538 r
.42138 .75491 m .42395 .7525 L .42168 .75258 L F
.42138 .75491 m .42365 .75467 L .42395 .7525 L F
.528 .334 .562 r
.42365 .75467 m .42586 .75199 L .42395 .7525 L F
.449 .828 .989 r
.5761 .84672 m .57919 .84636 L .57735 .84596 L F
.876 .717 .681 r
.67273 .74124 m .67446 .74183 L .67326 .73878 L F
.839 .619 .604 r
.67146 .7438 m .67446 .74183 L .67273 .74124 L F
.67146 .7438 m .67425 .74425 L .67446 .74183 L F
.857 .881 .855 r
.67446 .74183 m .67548 .7385 L .67326 .73878 L F
.67446 .74183 m .67603 .7398 L .67548 .7385 L F
.472 .877 .722 r
.35825 .79206 m .35894 .79145 L .3598 .79106 L F
.448 .882 .851 r
.35825 .79206 m .35718 .79219 L .35894 .79145 L F
.582 .404 .605 r
.5721 .83089 m .57187 .82854 L .57009 .82912 L F
.373 .137 .421 r
.57187 .82854 m .56965 .83123 L .57009 .82912 L F
.385 .259 .583 r
.64033 .72041 m .64207 .72318 L .64185 .72141 L F
.499 .242 .455 r
.46925 .83433 m .46883 .83637 L .47134 .83402 L F
.977 .713 .461 r
.381 .88683 m .38239 .8899 L .38119 .88956 L F
.568 .587 .832 r
.38432 .88949 m .38239 .8899 L .381 .88683 L F
.402 .83 .959 r
.38119 .88956 m .38239 .8899 L .38432 .88949 L F
0 .292 .74 r
.44395 .75106 m .44229 .75023 L .44191 .74958 L F
.44395 .75106 m .44508 .75189 L .44229 .75023 L F
.579 .583 .821 r
.64264 .72413 m .6454 .72483 L .64343 .72664 L F
0 0 .332 r
.6454 .72483 m .64421 .72888 L .64343 .72664 L F
.758 .485 .52 r
.51135 .84177 m .50807 .83946 L .51198 .83998 L F
.754 .634 .728 r
.51363 .83889 m .51135 .84177 L .51198 .83998 L F
.396 .265 .582 r
.66275 .6229 m .66438 .62234 L .66418 .62011 L F
.752 .524 .587 r
.66115 .62465 m .66438 .62234 L .66275 .6229 L F
.396 .265 .582 r
.66418 .62011 m .66438 .62234 L .66275 .6229 L F
.89 .958 .838 r
.43207 .88181 m .43304 .88201 L .4349 .87973 L F
.849 .978 .679 r
.52196 .82845 m .52007 .83129 L .52075 .83084 L F
.99 .889 .607 r
.67467 .7285 m .67488 .72484 L .6753 .72467 L F
.471 .823 .547 r
.69035 .72756 m .69022 .72768 L .69329 .72505 L F
.69035 .72756 m .69329 .72505 L .69205 .72636 L F
.331 .503 .877 r
.69494 .72518 m .69329 .72505 L .69201 .72362 L F
.325 0 0 r
.69494 .72518 m .69205 .72636 L .69329 .72505 L F
.735 .746 .86 r
.41629 .73029 m .41364 .73114 L .41229 .72918 L F
0 0 .334 r
.56354 .83684 m .564 .83946 L .56429 .83834 L F
.56354 .83684 m .56429 .83834 L .56309 .83619 L F
.5 .183 .361 r
.33477 .73876 m .33683 .73864 L .33778 .7362 L F
.434 .119 .33 r
.33778 .7362 m .33879 .73823 L .33978 .73587 L F
.33778 .7362 m .33683 .73864 L .33879 .73823 L F
.632 .811 .969 r
.69131 .69625 m .69261 .69741 L .69015 .69748 L F
.69131 .69625 m .69261 .69741 L .69015 .69748 L F
.702 .833 .945 r
.69131 .69625 m .69261 .69741 L .69433 .69633 L F
.69131 .69625 m .69261 .69741 L .69433 .69633 L F
0 .013 .587 r
.47405 .86466 m .47272 .86343 L .47148 .86277 L F
.47405 .86466 m .47453 .86606 L .47272 .86343 L F
.607 .486 .689 r
.45017 .84965 m .45197 .84692 L .45008 .84737 L F
.585 .36 .541 r
.44087 .7549 m .44093 .75699 L .4391 .75716 L F
.601 .377 .549 r
.44312 .7548 m .44093 .75699 L .44087 .7549 L F
.531 .138 .24 r
.52196 .82845 m .52427 .8285 L .52552 .82674 L F
0 0 0 r
.52788 .82433 m .52552 .82674 L .52687 .82546 L F
.505 .211 .4 r
.52427 .8285 m .52687 .82546 L .52552 .82674 L F
.868 .73 .213 r
.66898 .72223 m .66934 .72064 L .66908 .71998 L F
.66898 .72223 m .66914 .72329 L .66934 .72064 L F
.743 .543 .624 r
.60164 .78635 m .6038 .78403 L .60153 .78407 L F
.60164 .78635 m .60391 .78667 L .6038 .78403 L F
.712 .552 .67 r
.60391 .78667 m .60686 .78414 L .6038 .78403 L F
.575 .846 .996 r
.38889 .74607 m .39204 .74616 L .39101 .74559 L F
.185 0 0 r
.39456 .74475 m .39101 .74559 L .39204 .74616 L F
0 0 0 r
.36613 .803 m .36613 .80344 L .36442 .80419 L F
.36613 .803 m .36811 .80253 L .36613 .80344 L F
.595 .442 .644 r
.44643 .85549 m .44861 .85528 L .4485 .85288 L F
.635 .469 .641 r
.44643 .85549 m .44886 .85766 L .44861 .85528 L F
.44643 .85549 m .44659 .85796 L .44886 .85766 L F
.648 .129 0 r
.67564 .70968 m .67842 .71249 L .67665 .7123 L F
.581 .234 .346 r
.34801 .75745 m .34685 .75961 L .3445 .75962 L F
.39 .037 .241 r
.34882 .75916 m .34801 .75745 L .35012 .75749 L F
.34882 .75916 m .34685 .75961 L .34801 .75745 L F
.735 .469 .526 r
.52757 .84159 m .53107 .84214 L .53086 .83953 L F
.798 .517 .513 r
.53086 .83953 m .53107 .84214 L .53413 .84226 L F
.644 .13 0 r
.54743 .82092 m .55002 .82347 L .54844 .82176 L F
.735 .746 .86 r
.41629 .73029 m .41229 .72918 L .41458 .72863 L F
.295 .646 .968 r
.41582 .72857 m .41629 .73029 L .41458 .72863 L F
.41582 .72857 m .41837 .73039 L .41629 .73029 L F
.454 0 .045 r
.54292 .83136 m .54157 .83289 L .53945 .83268 L F
.309 .168 .521 r
.54343 .8339 m .54481 .83114 L .54292 .83136 L F
.789 .559 .588 r
.54481 .83114 m .54157 .83289 L .54292 .83136 L F
.959 .744 .57 r
.5123 .87631 m .51356 .87646 L .51334 .8783 L F
.748 .635 .734 r
.49722 .83439 m .4975 .83709 L .49955 .83381 L F
.842 .681 .683 r
.67375 .75211 m .67669 .75236 L .6755 .74912 L F
.825 .634 .644 r
.67364 .75435 m .67669 .75236 L .67375 .75211 L F
.67364 .75435 m .67641 .75468 L .67669 .75236 L F
.537 .87 .993 r
.59472 .84656 m .59571 .84699 L .59697 .84645 L F
.523 .039 .049 r
.37048 .72408 m .3721 .72515 L .37357 .72404 L F
.743 .772 .877 r
.58791 .81545 m .59106 .81716 L .58568 .81895 L F
.765 .768 .856 r
.5911 .81548 m .59106 .81716 L .58791 .81545 L F
0 0 0 r
.58967 .82003 m .59106 .81716 L .59078 .81797 L F
0 0 .315 r
.59106 .81716 m .59135 .82031 L .59078 .81797 L F
.656 .658 .841 r
.71534 .71586 m .71738 .71775 L .71793 .71622 L F
.539 .53 .793 r
.71793 .71622 m .71881 .71804 L .71738 .71775 L F
0 .381 .705 r
.70734 .70315 m .70883 .70132 L .70644 .70178 L F
.70734 .70315 m .71017 .70412 L .70875 .70359 L F
.405 .35 .684 r
.5248 .84165 m .52461 .84262 L .523 .84254 L F
.232 .356 .784 r
.32572 .66426 m .32512 .66611 L .32403 .66307 L F
.49 .643 .924 r
.32572 .66426 m .3271 .66587 L .32512 .66611 L F
.683 .592 .748 r
.6518 .73892 m .65522 .74134 L .65424 .73846 L F
.57 .555 .798 r
.65522 .74134 m .6563 .73797 L .65424 .73846 L F
.65522 .74134 m .65737 .74104 L .6563 .73797 L F
.738 .475 .532 r
.5982 .78403 m .60164 .78635 L .60153 .78407 L F
.773 .991 .887 r
.66259 .7127 m .665 .71031 L .66203 .71022 L F
.389 .85 .849 r
.51024 .84698 m .51156 .84627 L .51309 .84756 L F
.695 .688 .839 r
.51458 .84457 m .51309 .84756 L .51109 .8445 L F
.437 .486 .812 r
.49982 .86801 m .49775 .86906 L .49724 .8663 L F
0 .019 .541 r
.49893 .87004 m .49775 .86906 L .49982 .86801 L F
.49893 .87004 m .49826 .87169 L .49775 .86906 L F
.748 .635 .734 r
.49722 .83439 m .49955 .83381 L .49822 .83346 L F
.857 .903 .865 r
.64939 .63252 m .64856 .63394 L .64761 .63282 L F
.983 .857 .637 r
.64761 .63282 m .64856 .63394 L .64789 .63577 L F
.831 .75 .774 r
.50552 .86408 m .50633 .86592 L .50369 .86571 L F
.793 .565 .591 r
.50633 .86592 m .50328 .86801 L .50369 .86571 L F
.50633 .86592 m .50632 .86829 L .50328 .86801 L F
.414 .53 .866 r
.50778 .86511 m .50633 .86592 L .50552 .86408 L F
.471 .302 .57 r
.50814 .86813 m .50633 .86592 L .50778 .86511 L F
.50814 .86813 m .50632 .86829 L .50633 .86592 L F
.448 0 0 r
.43131 .87849 m .43388 .87953 L .4349 .87973 L F
.89 .958 .838 r
.43207 .88181 m .4349 .87973 L .43388 .87953 L F
.502 .887 .963 r
.4349 .87973 m .4361 .8788 L .43752 .87944 L F
.4349 .87973 m .43388 .87953 L .4361 .8788 L F
.4349 .87973 m .4361 .8788 L .43752 .87944 L F
.4349 .87973 m .43388 .87953 L .4361 .8788 L F
.548 .384 .612 r
.44249 .86328 m .44454 .86298 L .44452 .86057 L F
.493 .348 .612 r
.44283 .86567 m .44454 .86298 L .44249 .86328 L F
.798 .958 .917 r
.7206 .72774 m .7203 .72945 L .7185 .72703 L F
.7206 .72774 m .72108 .7286 L .7203 .72945 L F
.083 0 .044 r
.55075 .77948 m .55166 .78022 L .55296 .77894 L F
.55075 .77948 m .55007 .78114 L .55166 .78022 L F
.644 .687 .876 r
.46554 .88164 m .46879 .8823 L .46774 .88138 L F
.412 .617 .935 r
.46774 .88138 m .46879 .8823 L .46956 .88102 L F
.674 .944 .961 r
.46879 .8823 m .47097 .88126 L .46956 .88102 L F
.46879 .8823 m .47097 .88126 L .46956 .88102 L F
.877 .632 .564 r
.59679 .80478 m .59486 .80501 L .5949 .80245 L F
.926 .848 .746 r
.59679 .80478 m .59423 .80716 L .59486 .80501 L F
.59679 .80478 m .59544 .80782 L .59423 .80716 L F
.625 .733 .925 r
.44856 .87829 m .45142 .87887 L .45042 .87778 L F
.438 .757 .995 r
.45142 .87887 m .45217 .87785 L .45042 .87778 L F
.45142 .87887 m .45345 .87872 L .45217 .87785 L F
.956 .614 .298 r
.56246 .83153 m .56169 .83366 L .56196 .83086 L F
.56246 .83153 m .56304 .83381 L .56169 .83366 L F
.675 .483 .617 r
.58568 .81895 m .58967 .82003 L .58576 .82058 L F
.492 .183 .369 r
.37937 .78316 m .38237 .7803 L .38034 .78082 L F
.742 .304 0 r
.56456 .84212 m .56524 .84383 L .56325 .84163 L F
.56456 .84212 m .56634 .84512 L .56524 .84383 L F
.752 .614 .705 r
.61236 .7864 m .61432 .78388 L .61237 .78414 L F
.402 .278 .595 r
.34764 .6749 m .34593 .67312 L .34809 .67273 L F
.34764 .6749 m .34617 .67575 L .34593 .67312 L F
0 0 .167 r
.34593 .67312 m .34627 .67414 L .34809 .67273 L F
.34593 .67312 m .34617 .67575 L .34627 .67414 L F
.748 .32 0 r
.66804 .75762 m .66857 .75914 L .66847 .75661 L F
.66804 .75762 m .66949 .76039 L .66857 .75914 L F
0 0 .281 r
.50477 .83889 m .50388 .84213 L .50295 .83899 L F
.50472 .83909 m .50465 .84127 L .50388 .84213 L F
.079 .272 .759 r
.50465 .84127 m .50489 .84151 L .50388 .84213 L F
.299 .35 .747 r
.50609 .8442 m .50388 .84213 L .50486 .84153 L F
.50494 .84162 m .50486 .84153 L .50489 .84151 L F
.50609 .8442 m .50486 .84153 L .50494 .84162 L F
.708 .45 .533 r
.50158 .8414 m .5046 .84328 L .50465 .84129 L F
.50464 .84127 m .50465 .84129 L .50465 .84127 L F
.50158 .8414 m .50465 .84129 L .50464 .84127 L F
.5046 .84328 m .5049 .84347 L .50465 .84127 L F
0 0 .281 r
.50477 .83889 m .50465 .84127 L .50472 .83909 L F
.958 .715 .528 r
.5594 .81483 m .56081 .8131 L .5596 .81223 L F
.5594 .81483 m .56087 .81562 L .56081 .8131 L F
.486 .633 .918 r
.56081 .8131 m .56186 .81159 L .5596 .81223 L F
.56081 .8131 m .5626 .81302 L .56186 .81159 L F
.761 .552 .614 r
.56081 .8131 m .56403 .81571 L .5626 .81302 L F
.56081 .8131 m .56087 .81562 L .56403 .81571 L F
.451 .054 .195 r
.39135 .77545 m .39474 .77337 L .39261 .77356 L F
.662 .541 .706 r
.65888 .75421 m .66073 .75234 L .6597 .74936 L F
.13 0 0 r
.35766 .75249 m .35631 .75404 L .35479 .75405 L F
.512 .314 .548 r
.35631 .75404 m .35418 .75682 L .35479 .75405 L F
.689 .98 .834 r
.51981 .81528 m .51752 .81699 L .5189 .8154 L F
0 0 .051 r
.51793 .81763 m .5189 .8154 L .51752 .81699 L F
.787 .367 0 r
.56108 .82629 m .56049 .8257 L .55947 .82366 L F
.952 .645 .212 r
.56108 .82629 m .56078 .82787 L .56049 .8257 L F
.56108 .82629 m .56149 .82861 L .56078 .82787 L F
.606 .391 .563 r
.65254 .71501 m .64903 .71244 L .65151 .7122 L F
.741 .646 .754 r
.63045 .7527 m .63045 .75473 L .63242 .752 L F
.432 .227 .5 r
.34037 .68599 m .33995 .68846 L .33822 .68885 L F
.503 .308 .55 r
.33995 .68846 m .3382 .69046 L .33822 .68885 L F
.793 .749 .813 r
.64205 .74444 m .64143 .74185 L .63896 .7443 L F
.807 .699 .747 r
.63896 .7443 m .64001 .74723 L .64205 .74444 L F
.523 .496 .767 r
.62749 .74239 m .6283 .74448 L .63027 .7439 L F
.514 .365 .616 r
.6283 .74448 m .63051 .74625 L .63027 .7439 L F
.6283 .74448 m .6287 .74682 L .63051 .74625 L F
.567 .037 0 r
.54468 .80347 m .54652 .80435 L .54781 .80376 L F
.587 .062 0 r
.54652 .80435 m .54968 .80473 L .54781 .80376 L F
.878 .952 .853 r
.48144 .86586 m .47971 .86786 L .4784 .86777 L F
.79 .446 .405 r
.47971 .86786 m .47834 .87034 L .4784 .86777 L F
.47971 .86786 m .48134 .86954 L .47834 .87034 L F
.829 .602 .595 r
.60734 .81765 m .61023 .81574 L .6077 .8153 L F
.60734 .81765 m .61007 .8186 L .61023 .81574 L F
.854 .993 .833 r
.70897 .73617 m .70592 .73845 L .70808 .73556 L F
.70897 .73617 m .70597 .73928 L .70592 .73845 L F
.216 .731 .875 r
.70808 .73556 m .71166 .73556 L .70897 .73617 L F
.382 .532 .881 r
.49776 .85127 m .49994 .85271 L .49804 .85229 L F
0 .045 .556 r
.49928 .85482 m .49804 .85229 L .49994 .85271 L F
.49928 .85482 m .49854 .85566 L .49804 .85229 L F
.719 .186 0 r
.51256 .87358 m .51224 .872 L .51144 .87091 L F
.51256 .87358 m .51344 .87314 L .51224 .872 L F
.458 .248 .506 r
.56161 .77883 m .5614 .78101 L .56353 .77834 L F
.601 .668 .886 r
.48455 .83107 m .48231 .83144 L .48122 .82937 L F
.539 .3 .501 r
.48455 .83107 m .4841 .83349 L .48231 .83144 L F
.48455 .83107 m .4841 .83349 L .48231 .83144 L F
.555 .342 .545 r
.6588 .6306 m .65915 .63206 L .65611 .63354 L F
.581 .348 .528 r
.66096 .63043 m .65915 .63206 L .6588 .6306 L F
.731 .387 .397 r
.68875 .69724 m .69015 .69748 L .68919 .69859 L F
.632 .811 .969 r
.69131 .69625 m .69015 .69748 L .68875 .69724 L F
.69131 .69625 m .69015 .69748 L .68919 .69859 L F
0 0 0 r
.68919 .69859 m .69015 .69748 L .69131 .69625 L F
.255 0 0 r
.37048 .72408 m .36783 .7254 L .37002 .7248 L F
.518 .049 .08 r
.37002 .7248 m .3721 .72515 L .37048 .72408 L F
.636 .601 .797 r
.65381 .73698 m .6518 .73892 L .65424 .73846 L F
.352 0 0 r
.35952 .75356 m .35631 .75404 L .35766 .75249 L F
.648 .76 .931 r
.39318 .72419 m .38968 .7237 L .39178 .72302 L F
.727 .778 .893 r
.39507 .7232 m .39318 .72419 L .39178 .72302 L F
.181 0 .36 r
.32873 .70152 m .32734 .70445 L .32748 .70219 L F
.84 .713 .724 r
.66962 .73124 m .66888 .73331 L .6718 .73317 L F
.918 .575 .373 r
.66888 .73331 m .67077 .73586 L .6718 .73317 L F
.647 .712 .895 r
.53205 .87245 m .53342 .87014 L .53163 .8707 L F
.53205 .87245 m .5347 .87174 L .53342 .87014 L F
.781 .386 .305 r
.57765 .77834 m .58092 .78019 L .58093 .77874 L F
.895 .821 .767 r
.50814 .86813 m .5097 .86969 L .50855 .87121 L F
.604 .694 .907 r
.33363 .67445 m .33305 .6768 L .33177 .67475 L F
.33363 .67445 m .33469 .67629 L .33305 .6768 L F
.803 .893 .908 r
.46341 .88458 m .46554 .88164 L .46468 .8807 L F
.708 .617 .753 r
.46214 .88127 m .46321 .88405 L .46468 .8807 L F
.46321 .88405 m .46341 .88458 L .46398 .88282 L F
.46321 .88405 m .46398 .88282 L .46468 .8807 L F
.982 .724 .462 r
.46468 .8807 m .46554 .88164 L .46426 .88114 L F
.646 .678 .866 r
.46489 .88139 m .46628 .8784 L .46426 .88114 L F
.46554 .88164 m .466 .87963 L .46489 .88139 L F
.466 .87963 m .46628 .8784 L .46489 .88139 L F
.46554 .88164 m .46774 .88138 L .46628 .8784 L F
.452 .405 .715 r
.33039 .66976 m .3293 .67337 L .32874 .66996 L F
.33039 .66976 m .33107 .67312 L .3293 .67337 L F
.461 .49 .803 r
.33107 .67312 m .33177 .67475 L .3293 .67337 L F
.273 0 0 r
.51294 .88393 m .51421 .88442 L .51189 .88627 L F
.5141 .88419 m .51528 .88446 L .51421 .88442 L F
.466 .888 .903 r
.51421 .88442 m .51723 .88373 L .51633 .88353 L F
0 0 0 r
.51428 .88458 m .51421 .88442 L .51633 .88353 L F
.546 .895 .667 r
.51189 .88627 m .51387 .8847 L .51277 .88535 L F
.51387 .8847 m .51421 .88442 L .51277 .88535 L F
0 0 0 r
.51277 .88535 m .51421 .88442 L .51428 .88458 L F
.51277 .88535 m .51633 .88353 L .51548 .88323 L F
.135 0 .084 r
.51277 .88535 m .51548 .88323 L .51453 .88427 L F
.378 .801 .614 r
.51194 .88584 m .51277 .88535 L .51453 .88427 L F
.5119 .88587 m .51277 .88535 L .51194 .88584 L F
.273 0 0 r
.51294 .88393 m .5141 .88419 L .51421 .88442 L F
.797 .543 .554 r
.58644 .7829 m .58955 .78141 L .58634 .78103 L F
.58644 .7829 m .58961 .78365 L .58955 .78141 L F
.837 .751 .769 r
.67454 .75954 m .67793 .75763 L .67518 .75787 L F
.67454 .75954 m .67588 .76093 L .67793 .75763 L F
0 0 0 r
.66971 .70761 m .66755 .7101 L .66871 .70895 L F
.716 .836 .939 r
.38543 .74623 m .38683 .74716 L .38889 .74607 L F
.168 .679 .899 r
.47386 .88236 m .47465 .88199 L .4732 .88114 L F
.47386 .88236 m .47561 .88218 L .47465 .88199 L F
.977 .735 .502 r
.56287 .81813 m .56403 .81571 L .56087 .81562 L F
.56287 .81813 m .56401 .81818 L .56403 .81571 L F
.684 .652 .812 r
.5626 .81302 m .56403 .81571 L .56567 .8146 L F
.806 .357 .174 r
.54912 .80978 m .5457 .80734 L .54915 .80961 L F
.893 .917 .832 r
.53504 .82105 m .53205 .82213 L .53387 .82115 L F
.153 .324 .783 r
.53504 .82105 m .53371 .8181 L .53705 .81831 L F
.53504 .82105 m .53608 .82027 L .53371 .8181 L F
.461 .888 .871 r
.53504 .82105 m .53387 .82115 L .53608 .82027 L F
.583 .47 .69 r
.43252 .74391 m .43299 .74699 L .43089 .74737 L F
.632 .599 .798 r
.65737 .74104 m .65839 .74422 L .66037 .74232 L F
.639 .61 .805 r
.65839 .74422 m .66068 .74389 L .66037 .74232 L F
.634 .505 .688 r
.65839 .74422 m .66153 .74707 L .66068 .74389 L F
.65839 .74422 m .66095 .74882 L .66153 .74707 L F
.794 .716 .779 r
.55598 .7789 m .55388 .782 L .55296 .77894 L F
.576 .074 .025 r
.55411 .78204 m .55274 .78281 L .55388 .782 L F
.766 .653 .737 r
.49366 .87104 m .49475 .87413 L .49326 .8734 L F
.076 0 0 r
.49475 .87413 m .4935 .87585 L .49326 .8734 L F
.185 0 0 r
.39456 .74475 m .39285 .7455 L .39101 .74559 L F
.211 0 0 r
.39642 .74425 m .39285 .7455 L .39456 .74475 L F
.791 .416 .346 r
.56634 .84512 m .56765 .84492 L .56651 .84682 L F
.5 .034 .079 r
.56765 .84492 m .56819 .84655 L .56651 .84682 L F
.56765 .84492 m .56925 .8451 L .56819 .84655 L F
.103 .069 .531 r
.55613 .80153 m .55615 .80555 L .55762 .80485 L F
.858 .404 .063 r
.55613 .80153 m .55762 .80485 L .55624 .80374 L F
.55613 .80153 m .55624 .80374 L .55691 .80153 L F
.733 .785 .894 r
.53282 .81257 m .53092 .81399 L .52926 .81255 L F
.742 .323 .251 r
.53124 .81515 m .52948 .81519 L .53092 .81399 L F
.734 .311 .243 r
.53092 .81399 m .52948 .81519 L .52735 .81344 L F
.046 0 0 r
.36838 .78749 m .36816 .78728 L .36639 .78772 L F
0 0 0 r
.37015 .78671 m .36816 .78728 L .36838 .78749 L F
.909 .854 .776 r
.496 .82338 m .49744 .82425 L .49854 .82213 L F
.105 0 .154 r
.65715 .72514 m .65803 .72652 L .65807 .72511 L F
.65715 .72514 m .65642 .7277 L .65803 .72652 L F
.659 .612 .79 r
.43649 .74957 m .43439 .75023 L .43299 .74699 L F
.289 .72 .969 r
.48269 .88456 m .48354 .88394 L .48142 .88401 L F
.48269 .88456 m .48488 .88461 L .48354 .88394 L F
.753 .748 .848 r
.49153 .82298 m .48896 .82405 L .49056 .82334 L F
0 0 0 r
.49153 .82298 m .4926 .82276 L .49408 .82256 L F
.49153 .82298 m .49056 .82334 L .4926 .82276 L F
.508 0 0 r
.52826 .84349 m .52742 .84415 L .52579 .84354 L F
0 0 0 r
.52907 .84334 m .52826 .84349 L .53107 .84214 L F
.52907 .84334 m .52742 .84415 L .52826 .84349 L F
.752 .462 .492 r
.49211 .82678 m .49165 .82842 L .48903 .82522 L F
.522 .234 .418 r
.49402 .82787 m .49165 .82842 L .49211 .82678 L F
.6 .45 .65 r
.48903 .82522 m .49165 .82842 L .49301 .82737 L F
.48903 .82522 m .49301 .82737 L .48838 .8258 L F
.994 .789 .521 r
.48903 .82522 m .48838 .8258 L .48896 .82405 L F
.505 .22 .416 r
.41942 .77074 m .41866 .77347 L .41658 .77373 L F
.507 .222 .417 r
.4209 .77269 m .41942 .77074 L .42146 .77035 L F
.4209 .77269 m .41866 .77347 L .41942 .77074 L F
.219 0 .266 r
.48896 .82405 m .48838 .8258 L .49056 .82334 L F
.638 .787 .953 r
.41043 .72931 m .40712 .72874 L .40919 .72765 L F
.475 .586 .885 r
.41155 .72753 m .41043 .72931 L .40919 .72765 L F
.41155 .72753 m .41229 .72918 L .41043 .72931 L F
.324 0 .089 r
.35527 .72869 m .35592 .73007 L .35712 .72804 L F
.35527 .72869 m .35391 .73052 L .35592 .73007 L F
.409 .132 .378 r
.46624 .83883 m .46883 .83637 L .46687 .83681 L F
.612 .956 .854 r
.49481 .82513 m .49744 .82425 L .496 .82338 L F
.49481 .82513 m .49403 .82608 L .49744 .82425 L F
.862 .791 .78 r
.60856 .80761 m .60936 .81017 L .61128 .80735 L F
.64 .508 .687 r
.45197 .84692 m .45412 .8443 L .45213 .84475 L F
.851 .694 .687 r
.4766 .87612 m .47837 .87635 L .4771 .87358 L F
.843 .557 .504 r
.4766 .87612 m .47696 .87867 L .47837 .87635 L F
.283 0 0 r
.47696 .87867 m .48034 .8779 L .47837 .87635 L F
.464 .765 .995 r
.37954 .7227 m .37878 .72386 L .37747 .72344 L F
.37954 .7227 m .38132 .7237 L .37878 .72386 L F
.387 0 0 r
.50804 .8466 m .50926 .84705 L .51024 .84698 L F
.389 .85 .849 r
.51024 .84698 m .50926 .84705 L .51156 .84627 L F
.71 .283 .233 r
.5528 .80782 m .55311 .80889 L .55448 .80759 L F
.868 .426 .127 r
.55474 .80969 m .55448 .80759 L .55311 .80889 L F
.55474 .80969 m .55622 .81035 L .55448 .80759 L F
.306 0 .03 r
.58479 .83049 m .58337 .82974 L .582 .82885 L F
.58479 .83049 m .58629 .82905 L .58337 .82974 L F
.627 .705 .902 r
.41743 .74232 m .4192 .74445 L .42155 .74408 L F
.612 .781 .962 r
.42603 .73489 m .42223 .73445 L .42446 .73434 L F
.464 .799 .999 r
.42653 .73403 m .42603 .73489 L .42446 .73434 L F
.42653 .73403 m .42785 .73468 L .42603 .73489 L F
.69 .556 .698 r
.6597 .74936 m .66277 .75216 L .66165 .74918 L F
.6597 .74936 m .66073 .75234 L .66277 .75216 L F
.567 .359 .557 r
.45423 .84213 m .45625 .8439 L .45652 .84192 L F
.45423 .84213 m .45412 .8443 L .45625 .8439 L F
.277 0 .012 r
.37582 .79782 m .37464 .79937 L .37274 .79952 L F
.047 0 0 r
.37628 .79863 m .37582 .79782 L .37792 .79741 L F
.37628 .79863 m .37464 .79937 L .37582 .79782 L F
.315 0 .001 r
.37891 .74875 m .37765 .75047 L .37587 .75001 L F
.445 .017 .13 r
.38122 .74871 m .38007 .74938 L .37891 .74875 L F
.704 .375 .417 r
.38007 .74938 m .37765 .75047 L .37891 .74875 L F
0 .374 .722 r
.56511 .80882 m .56732 .80965 L .5685 .81021 L F
.977 .804 .603 r
.56732 .80965 m .56785 .81251 L .5685 .81021 L F
.332 .052 .33 r
.51485 .82908 m .51425 .83086 L .51657 .82848 L F
.77 .383 .321 r
.70597 .73928 m .70587 .74086 L .70592 .73845 L F
.70597 .73928 m .70743 .74159 L .70587 .74086 L F
.514 .271 .484 r
.3941 .78752 m .39269 .7866 L .39479 .78628 L F
.3941 .78752 m .39198 .78868 L .39269 .7866 L F
.545 .412 .65 r
.34244 .68396 m .34225 .6856 L .34037 .68599 L F
.436 .204 .462 r
.34225 .6856 m .33995 .68846 L .34037 .68599 L F
.806 .549 .549 r
.59104 .79972 m .58842 .79973 L .58808 .79711 L F
.73 .539 .633 r
.59163 .80188 m .58842 .79973 L .59104 .79972 L F
.77 .464 .468 r
.59104 .79972 m .59294 .80225 L .59163 .80188 L F
.208 .723 .879 r
.54069 .84738 m .54184 .84702 L .53949 .84705 L F
.54069 .84738 m .54301 .84726 L .54184 .84702 L F
.54069 .84738 m .54184 .84702 L .53949 .84705 L F
.54069 .84738 m .54301 .84726 L .54184 .84702 L F
.69 .731 .881 r
.38919 .89032 m .39105 .89236 L .38812 .89115 L F
.83 .496 .423 r
.38812 .89115 m .39105 .89236 L .38893 .89281 L F
.115 .455 .885 r
.39194 .89193 m .39105 .89236 L .38919 .89032 L F
.3 .794 .789 r
.38893 .89281 m .39105 .89236 L .39194 .89193 L F
.071 0 0 r
.66971 .70761 m .6711 .70803 L .67187 .70718 L F
.66971 .70761 m .66871 .70895 L .6711 .70803 L F
.323 .453 .837 r
.32903 .66689 m .32808 .66827 L .3271 .66587 L F
.314 .441 .83 r
.32903 .66689 m .33039 .66976 L .32808 .66827 L F
.465 .439 .745 r
.32808 .66827 m .33039 .66976 L .32874 .66996 L F
.552 .201 .327 r
.34187 .73539 m .34518 .73309 L .34242 .73417 L F
.34187 .73539 m .344 .73539 L .34518 .73309 L F
.506 .173 .337 r
.344 .73539 m .34729 .7328 L .34518 .73309 L F
.83 .558 .527 r
.48955 .88094 m .49174 .8792 L .49036 .87871 L F
.779 .321 .158 r
.49174 .8792 m .4901 .87914 L .49036 .87871 L F
.83 .558 .527 r
.48955 .88094 m .49224 .88163 L .49174 .8792 L F
.517 .497 .773 r
.62749 .74239 m .62931 .74076 L .62743 .74057 L F
.62749 .74239 m .63027 .7439 L .62931 .74076 L F
.372 .623 .949 r
.57175 .83311 m .5708 .83433 L .56972 .83398 L F
.57175 .83311 m .57309 .83485 L .5708 .83433 L F
.862 .496 0 r
.57268 .82317 m .57406 .8261 L .57348 .82429 L F
.612 .456 .645 r
.4485 .85288 m .45083 .85497 L .45069 .85256 L F
.4485 .85288 m .44861 .85528 L .45083 .85497 L F
.469 .469 .775 r
.64414 .73319 m .64333 .73634 L .64194 .7337 L F
.64414 .73319 m .64494 .73579 L .64333 .73634 L F
.973 .726 .504 r
.64212 .73821 m .64326 .73906 L .64333 .73634 L F
.64212 .73821 m .64333 .73634 L .64494 .73579 L F
0 .176 .625 r
.47291 .85785 m .47393 .85856 L .47395 .85855 L F
.47393 .85856 m .47582 .85987 L .47395 .85855 L F
.507 .537 .822 r
.47395 .85855 m .47582 .85987 L .4747 .85705 L F
0 0 0 r
.47432 .8578 m .47402 .85851 L .47395 .85855 L F
.305 .445 .838 r
.47393 .85856 m .47456 .86104 L .47582 .85987 L F
0 0 0 r
.47402 .85851 m .47389 .85883 L .47395 .85855 L F
.4747 .85705 m .47461 .85725 L .47432 .8578 L F
.47461 .85725 m .47389 .85883 L .47432 .8578 L F
.305 .445 .838 r
.47291 .85785 m .4736 .85919 L .47393 .85856 L F
.4736 .85919 m .47456 .86104 L .47393 .85856 L F
.279 .401 .808 r
.47456 .86104 m .47695 .86267 L .47582 .85987 L F
0 .569 .748 r
.5839 .84672 m .58442 .84679 L .58673 .84692 L F
.979 .893 .668 r
.60633 .83341 m .60805 .83118 L .60766 .8309 L F
.60633 .83341 m .60711 .83424 L .60805 .83118 L F
.682 .431 .536 r
.59521 .78632 m .5982 .78403 L .59476 .78377 L F
.59521 .78632 m .59829 .7862 L .5982 .78403 L F
.738 .475 .532 r
.5982 .78403 m .59829 .7862 L .60164 .78635 L F
.646 .637 .827 r
.53951 .81528 m .53577 .81389 L .53873 .81481 L F
.724 .208 0 r
.53873 .81481 m .54108 .81583 L .53951 .81528 L F
.567 .642 .884 r
.58043 .81803 m .58146 .82027 L .58407 .81955 L F
.998 .818 .534 r
.59478 .80948 m .59423 .80716 L .59544 .80782 L F
.673 .395 .491 r
.40927 .76456 m .41176 .76501 L .41214 .76311 L F
.548 .278 .459 r
.41176 .76501 m .41448 .76285 L .41214 .76311 L F
.857 .546 .462 r
.58482 .79432 m .58347 .79633 L .58325 .79401 L F
.58482 .79432 m .58607 .79695 L .58347 .79633 L F
.81 .534 .52 r
.58808 .79711 m .58607 .79695 L .58482 .79432 L F
0 0 0 r
.71426 .73072 m .71505 .72962 L .71542 .72846 L F
0 .216 .737 r
.71505 .72962 m .71738 .73329 L .71755 .73319 L F
.354 .809 .687 r
.71829 .73288 m .71762 .73317 L .71657 .73374 L F
.2 .374 .812 r
.71657 .73374 m .71732 .73333 L .71426 .73072 L F
.354 .809 .687 r
.71762 .73317 m .71755 .73319 L .71657 .73374 L F
.717 .73353 m .71737 .7333 L .71657 .73374 L F
.2 .374 .812 r
.71657 .73374 m .71751 .73349 L .71732 .73333 L F
0 .216 .737 r
.71738 .73329 m .71751 .73349 L .71755 .73319 L F
.354 .809 .687 r
.71829 .73288 m .71763 .73316 L .71737 .7333 L F
.71829 .73288 m .71737 .7333 L .717 .73353 L F
.227 .381 .81 r
.71732 .73333 m .71738 .73329 L .71505 .72962 L F
.354 .809 .687 r
.71763 .73316 m .71755 .73319 L .71684 .73359 L F
.71763 .73316 m .71684 .73359 L .71657 .73374 L F
.227 .381 .81 r
.71426 .73072 m .71732 .73333 L .71505 .72962 L F
.71732 .73333 m .71751 .73349 L .71738 .73329 L F
.81 .535 .522 r
.58808 .79711 m .58633 .79895 L .58607 .79695 L F
.829 .565 .54 r
.58808 .79711 m .58842 .79973 L .58633 .79895 L F
.477 .404 .696 r
.62743 .74057 m .62888 .73861 L .62756 .73902 L F
.263 .386 .8 r
.69316 .72268 m .69201 .72362 L .69117 .72158 L F
.331 .503 .877 r
.69494 .72518 m .69201 .72362 L .69316 .72268 L F
.789 .716 .783 r
.68797 .6936 m .68875 .69724 L .68616 .69679 L F
.571 .573 .816 r
.69131 .69625 m .68875 .69724 L .68797 .6936 L F
.767 .614 .689 r
.61027 .78909 m .61359 .78952 L .61236 .7864 L F
.75 .584 .67 r
.61036 .79151 m .61359 .78952 L .61027 .78909 L F
.61036 .79151 m .61348 .79171 L .61359 .78952 L F
.77 .777 .858 r
.65807 .71587 m .65496 .7168 L .65701 .71569 L F
0 0 0 r
.65972 .71343 m .65807 .71587 L .65905 .71472 L F
.674 .962 .938 r
.65807 .71587 m .65701 .71569 L .65905 .71472 L F
.616 .689 .895 r
.5358 .84127 m .53953 .84219 L .53838 .83917 L F
.617 .589 .8 r
.53838 .83917 m .53953 .84219 L .54198 .84172 L F
.771 .421 .393 r
.50828 .88062 m .50677 .88173 L .50857 .88164 L F
.612 .414 .59 r
.52687 .82546 m .52943 .82319 L .52788 .82433 L F
.73 .606 .719 r
.62912 .74954 m .63242 .752 L .63136 .74901 L F
.62912 .74954 m .63045 .7527 L .63242 .752 L F
.697 .641 .79 r
.63136 .74901 m .63242 .752 L .63465 .74961 L F
.582 .921 .964 r
.7018 .75329 m .69977 .75314 L .69828 .75394 L F
.714 .951 .952 r
.70309 .75157 m .7018 .75329 L .70398 .75228 L F
.70309 .75157 m .69977 .75314 L .7018 .75329 L F
.799 .738 .796 r
.54094 .80304 m .54212 .80536 L .53964 .80404 L F
.732 .206 0 r
.54212 .80536 m .54171 .80595 L .53964 .80404 L F
.533 0 0 r
.54094 .80304 m .54468 .80347 L .54212 .80536 L F
.511 0 0 r
.54212 .80536 m .54338 .80659 L .54171 .80595 L F
.621 .897 .588 r
.54338 .80659 m .54204 .80784 L .54322 .80655 L F
.717 .213 .035 r
.5457 .80734 m .54445 .8074 L .54212 .80536 L F
.732 .567 .668 r
.54485 .80386 m .54338 .80659 L .54648 .80634 L F
.621 .897 .588 r
.54338 .80659 m .54322 .80655 L .54422 .80545 L F
.511 0 0 r
.54212 .80536 m .54358 .80663 L .54338 .80659 L F
.54358 .80663 m .54445 .8074 L .54338 .80659 L F
.549 0 0 r
.67603 .7398 m .67642 .74041 L .67548 .7385 L F
.67603 .7398 m .67772 .74096 L .67642 .74041 L F
.549 .743 .966 r
.40218 .7254 m .40147 .72686 L .40033 .72557 L F
.40218 .7254 m .40357 .72667 L .40147 .72686 L F
.399 0 0 r
.53449 .81314 m .53873 .81481 L .53577 .81389 L F
.536 .881 .986 r
.50073 .8551 m .49854 .85566 L .49928 .85482 L F
.657 .52 .686 r
.50199 .85824 m .49854 .85566 L .50073 .8551 L F
.50199 .85824 m .49996 .85975 L .49854 .85566 L F
.754 .623 .714 r
.6875 .73905 m .69093 .73919 L .68966 .73646 L F
.723 .576 .69 r
.6875 .73905 m .69074 .74149 L .69093 .73919 L F
.639 .462 .627 r
.69093 .73919 m .69074 .74149 L .69285 .73894 L F
0 .125 .654 r
.48627 .87329 m .48612 .87363 L .48523 .87241 L F
0 0 .348 r
.48694 .87526 m .48612 .87363 L .48627 .87329 L F
.508 .225 .419 r
.40629 .78039 m .40458 .77882 L .40682 .77874 L F
.40629 .78039 m .40416 .7808 L .40458 .77882 L F
.478 .093 .23 r
.65905 .71472 m .66259 .7127 L .65972 .71343 L F
.614 .808 .392 r
.64349 .72278 m .64491 .72053 L .64392 .72207 L F
0 0 .099 r
.64491 .72053 m .64484 .72259 L .64392 .72207 L F
.791 .592 .632 r
.64484 .72259 m .64424 .72153 L .64392 .72207 L F
.64424 .72153 m .64291 .71915 L .64392 .72207 L F
.614 .808 .392 r
.64264 .72413 m .64349 .72278 L .64392 .72207 L F
0 0 .099 r
.64491 .72053 m .64628 .71967 L .64484 .72259 L F
.587 .79 .976 r
.57372 .78818 m .57506 .78925 L .5766 .78852 L F
.809 .577 .588 r
.55815 .80064 m .55971 .80015 L .5593 .79995 L F
0 0 .389 r
.55947 .79924 m .55971 .80015 L .55815 .80064 L F
.55947 .79924 m .56061 .8022 L .55971 .80015 L F
.325 .809 .877 r
.48488 .88461 m .48819 .88416 L .48719 .88457 L F
0 .498 .822 r
.48819 .88416 m .48915 .88416 L .48719 .88457 L F
.48819 .88416 m .49017 .88472 L .48915 .88416 L F
.712 .552 .67 r
.60391 .78667 m .60694 .7865 L .60686 .78414 L F
.688 .533 .671 r
.60686 .78414 m .60694 .7865 L .60908 .78388 L F
.182 .207 .652 r
.42958 .8786 m .42998 .88142 L .43022 .8799 L F
.473 .488 .793 r
.42998 .88142 m .43207 .88181 L .43022 .8799 L F
.564 .337 .53 r
.65611 .63354 m .6561 .63561 L .65375 .63603 L F
.541 .316 .522 r
.65611 .63354 m .65838 .63522 L .6561 .63561 L F
.65611 .63354 m .65915 .63206 L .65838 .63522 L F
.636 .496 .674 r
.44659 .85796 m .44452 .86057 L .4468 .86035 L F
.654 .486 .644 r
.44454 .86298 m .4468 .86035 L .44452 .86057 L F
.746 .604 .7 r
.60908 .78603 m .61237 .78414 L .60908 .78388 L F
.60908 .78603 m .61236 .7864 L .61237 .78414 L F
.691 .969 .93 r
.47043 .85756 m .46828 .85924 L .46862 .85869 L F
.432 .454 .783 r
.70857 .74626 m .709 .7432 L .70719 .74401 L F
.70857 .74626 m .70907 .74601 L .709 .7432 L F
.794 .716 .779 r
.55598 .7789 m .55296 .77894 L .55508 .7778 L F
.28 .592 .947 r
.55508 .7778 m .55684 .7782 L .55598 .7789 L F
.447 .866 .946 r
.55598 .7789 m .55684 .7782 L .55819 .77833 L F
.55598 .7789 m .55684 .7782 L .55819 .77833 L F
.848 .762 .768 r
.64931 .63012 m .65176 .62995 L .65088 .63132 L F
.844 .808 .816 r
.65088 .63132 m .64939 .63252 L .64931 .63012 L F
.465 .352 .641 r
.34346 .67792 m .34379 .68024 L .34198 .68053 L F
.528 .405 .656 r
.34438 .68275 m .34198 .68053 L .34379 .68024 L F
.34438 .68275 m .34244 .68396 L .34198 .68053 L F
.688 .277 .26 r
.68532 .73522 m .68865 .7354 L .68664 .73365 L F
.772 .823 .892 r
.53467 .84012 m .5358 .84127 L .53838 .83917 L F
.473 .632 .924 r
.65491 .72924 m .65642 .7277 L .65459 .72841 L F
.152 .644 .917 r
.68939 .75317 m .69085 .75369 L .69317 .75396 L F
.607 .486 .689 r
.45017 .84965 m .45263 .84983 L .45197 .84692 L F
.553 .395 .621 r
.45069 .85256 m .45263 .84983 L .45017 .84965 L F
.686 .525 .663 r
.66073 .75234 m .66075 .75517 L .66277 .75216 L F
.639 .275 .336 r
.70264 .74434 m .70171 .74626 L .69983 .74461 L F
.72 .61 .733 r
.7052 .74239 m .70264 .74434 L .7016 .74142 L F
.378 .01 .207 r
.70394 .74566 m .70264 .74434 L .70429 .74512 L F
.70394 .74566 m .70171 .74626 L .70264 .74434 L F
.675 .361 .436 r
.70264 .74434 m .70537 .74483 L .70429 .74512 L F
0 0 0 r
.47909 .8296 m .47968 .82959 L .48122 .82937 L F
.47909 .8296 m .47731 .83041 L .47968 .82959 L F
.592 .693 .913 r
.31926 .65972 m .31854 .66203 L .31719 .66024 L F
.31926 .65972 m .32058 .6616 L .31854 .66203 L F
.027 .499 .879 r
.52051 .81493 m .51981 .81528 L .5189 .8154 L F
.52051 .81493 m .52225 .8163 L .51981 .81528 L F
.909 .62 .125 r
.55181 .8287 m .55214 .83085 L .55263 .8314 L F
.928 .662 .179 r
.55214 .83085 m .55297 .83428 L .55263 .8314 L F
.441 .851 .68 r
.51723 .88373 m .52066 .88175 L .51971 .88178 L F
.775 .734 .815 r
.52066 .88175 m .52318 .8796 L .51979 .8785 L F
.52066 .88175 m .51979 .8785 L .52081 .88016 L F
.858 .994 .824 r
.51971 .88178 m .52066 .88175 L .52081 .88016 L F
.742 .639 .745 r
.48134 .86954 m .48269 .87112 L .48483 .86864 L F
.314 .179 .532 r
.48269 .87112 m .48451 .87287 L .48523 .87241 L F
.48269 .87112 m .48256 .87351 L .48451 .87287 L F
.029 0 .092 r
.64219 .73126 m .64421 .72888 L .64384 .73038 L F
0 0 .332 r
.6454 .72483 m .64533 .72748 L .64421 .72888 L F
0 0 .224 r
.64421 .72888 m .64492 .72986 L .64384 .73038 L F
.64421 .72888 m .64533 .72748 L .64492 .72986 L F
.569 .596 .84 r
.4451 .87578 m .44856 .87829 L .44705 .87566 L F
.53 .59 .858 r
.44705 .87566 m .44856 .87829 L .45042 .87778 L F
.977 .694 .416 r
.55779 .81874 m .55779 .82094 L .55752 .81824 L F
.594 .527 .749 r
.64384 .73038 m .64194 .7337 L .64219 .73126 L F
.82 .989 .874 r
.48942 .86632 m .4894 .86694 L .49093 .86533 L F
.48778 .86741 m .4894 .86694 L .48942 .86632 L F
.453 0 0 r
.48609 .8674 m .48936 .86773 L .4894 .86694 L F
.48936 .86773 m .49048 .86785 L .4894 .86694 L F
.094 .538 .909 r
.4894 .86694 m .49048 .86785 L .49211 .86829 L F
.876 .817 .787 r
.65346 .62463 m .65304 .62867 L .65133 .62734 L F
.65346 .62463 m .65475 .62572 L .65304 .62867 L F
.823 .747 .78 r
.65133 .62734 m .65304 .62867 L .65176 .62995 L F
.735 .393 .401 r
.34065 .67623 m .34014 .67765 L .34346 .67792 L F
0 0 0 r
.518 .83176 m .51668 .83339 L .51537 .8338 L F
.71 .453 .534 r
.52007 .83129 m .51668 .83339 L .518 .83176 L F
.765 .975 .92 r
.65568 .62395 m .65475 .62572 L .65346 .62463 L F
.65568 .62395 m .65675 .6242 L .65475 .62572 L F
.467 .198 .423 r
.41448 .76285 m .4165 .76249 L .41698 .76001 L F
.54 .361 .587 r
.41698 .76001 m .41897 .75972 L .41914 .75747 L F
.43 .142 .372 r
.4165 .76249 m .41897 .75972 L .41698 .76001 L F
.748 .585 .674 r
.60908 .78603 m .61027 .78909 L .61236 .7864 L F
.789 .691 .756 r
.63689 .74696 m .64001 .74723 L .63896 .7443 L F
.788 .694 .761 r
.63689 .74696 m .63793 .74992 L .64001 .74723 L F
.649 .618 .805 r
.52671 .83362 m .52261 .82988 L .52507 .83164 L F
.515 .361 .611 r
.52861 .83128 m .52671 .83362 L .52507 .83164 L F
.52861 .83128 m .52849 .83371 L .52671 .83362 L F
.23 0 0 r
.5272 .83503 m .52671 .83362 L .52849 .83371 L F
.5272 .83503 m .52516 .83565 L .52671 .83362 L F
.522 .234 .418 r
.49402 .82787 m .49211 .82678 L .49403 .82608 L F
.753 .241 0 r
.48428 .8288 m .48622 .83082 L .4877 .83109 L F
.505 .331 .578 r
.48953 .83109 m .48733 .83365 L .4877 .83109 L F
.99 .889 .607 r
.67467 .7285 m .67404 .72785 L .67488 .72484 L F
.998 .783 .457 r
.67468 .73084 m .67404 .72785 L .67467 .7285 L F
.543 .536 .797 r
.43288 .73639 m .43151 .73804 L .43092 .73644 L F
.43288 .73639 m .43348 .73774 L .43151 .73804 L F
.558 .473 .715 r
.43418 .74127 m .43151 .73804 L .43348 .73774 L F
.43418 .74127 m .43216 .74163 L .43151 .73804 L F
.19 .717 .849 r
.5594 .78185 m .55834 .78173 L .55411 .78204 L F
.622 .573 .779 r
.5614 .78101 m .5594 .78185 L .55819 .77833 L F
.512 .053 .101 r
.5614 .78101 m .55834 .78173 L .5594 .78185 L F
.706 .633 .773 r
.70372 .73901 m .7052 .74239 L .7016 .74142 L F
.371 .448 .81 r
.70587 .74086 m .7052 .74239 L .70372 .73901 L F
.852 .787 .787 r
.60771 .80964 m .60936 .81017 L .60856 .80761 L F
.875 .752 .724 r
.60791 .8129 m .60936 .81017 L .60771 .80964 L F
.59 .799 .979 r
.36428 .75125 m .36862 .75168 L .36795 .75091 L F
.234 .657 .959 r
.36862 .75168 m .36911 .75107 L .36795 .75091 L F
.36862 .75168 m .37047 .7519 L .36911 .75107 L F
.769 .826 .897 r
.5123 .8314 m .50931 .83163 L .51102 .83047 L F
.561 .405 .627 r
.65039 .72056 m .6525 .72103 L .65286 .7182 L F
.662 .496 .649 r
.60908 .78388 m .60694 .7865 L .60908 .78603 L F
.629 .291 .38 r
.49936 .84139 m .50158 .8414 L .50295 .83899 L F
.446 .497 .818 r
.50295 .83899 m .50477 .83889 L .5036 .83595 L F
.646 .31 .39 r
.50295 .83899 m .50465 .84127 L .50477 .83889 L F
.50295 .83899 m .50158 .8414 L .50465 .84127 L F
.759 .681 .776 r
.68946 .74618 m .69001 .74945 L .69195 .74718 L F
.548 .534 .791 r
.68886 .74749 m .69001 .74945 L .68946 .74618 L F
.442 .024 .15 r
.68656 .75169 m .69001 .74945 L .68886 .74749 L F
.68808 .7507 m .68913 .75118 L .69001 .74945 L F
.704 .167 0 r
.69237 .75322 m .69066 .75214 L .68939 .75317 L F
.69066 .75214 m .68913 .75118 L .68931 .75257 L F
.69066 .75214 m .68931 .75257 L .68939 .75317 L F
.69153 .75269 m .69115 .75303 L .68913 .75118 L F
.69237 .75322 m .69115 .75303 L .69153 .75269 L F
.022 0 0 r
.69286 .75292 m .69059 .75354 L .69115 .75303 L F
.152 .644 .917 r
.68939 .75317 m .69317 .75396 L .69237 .75322 L F
.022 0 0 r
.69059 .75354 m .68886 .75401 L .69115 .75303 L F
.76 .656 .747 r
.6934 .75287 m .69668 .7533 L .69593 .75063 L F
.69506 .75089 m .69593 .75063 L .69576 .75004 L F
.628 .264 .333 r
.68913 .75118 m .69171 .75291 L .6898 .75089 L F
.6912 .75029 m .69182 .75048 L .69184 .75002 L F
.594 .603 .831 r
.692 .75053 m .69171 .75291 L .68847 .74949 L F
.76 .656 .747 r
.69353 .75272 m .69593 .75063 L .69506 .75089 L F
.311 .016 .293 r
.69414 .75104 m .69171 .75291 L .69464 .75153 L F
.6948 .75133 m .69464 .75153 L .69494 .75139 L F
.69414 .75104 m .69464 .75153 L .6948 .75133 L F
.036 0 .036 r
.69491 .75115 m .69494 .75139 L .69576 .75004 L F
.832 .56 .527 r
.69576 .75004 m .69494 .75139 L .69487 .75128 L F
0 0 0 r
.69528 .75071 m .69496 .75108 L .69576 .75004 L F
.69496 .75108 m .69492 .75112 L .69576 .75004 L F
.69492 .75112 m .6936 .75265 L .69505 .7509 L F
.69492 .75112 m .69505 .7509 L .69576 .75004 L F
.311 .016 .293 r
.69431 .75111 m .6948 .75133 L .69488 .75094 L F
.6948 .75133 m .69494 .75139 L .69491 .75115 L F
.6948 .75133 m .69491 .75115 L .69488 .75094 L F
.036 0 .036 r
.6947 .7497 m .69491 .75115 L .69576 .75004 L F
0 0 0 r
.6936 .75265 m .69353 .75272 L .69576 .75004 L F
.311 .016 .293 r
.69184 .75002 m .69431 .75111 L .6947 .7497 L F
.69431 .75111 m .69488 .75094 L .6947 .7497 L F
.722 .988 .873 r
.69627 .74843 m .69546 .74976 L .6947 .7497 L F
.036 0 .036 r
.6947 .7497 m .69576 .75004 L .69627 .74843 L F
.832 .56 .527 r
.69576 .75004 m .69487 .75128 L .69323 .74873 L F
0 0 0 r
.69547 .75048 m .69528 .75071 L .69576 .75004 L F
.311 .016 .293 r
.69184 .75002 m .69176 .75179 L .69414 .75104 L F
.69176 .75179 m .69171 .75291 L .69414 .75104 L F
.594 .603 .831 r
.69481 .75135 m .69318 .75222 L .692 .75053 L F
.69494 .75139 m .69464 .75153 L .69481 .75135 L F
.69464 .75153 m .69318 .75222 L .69481 .75135 L F
.76 .656 .747 r
.6934 .75287 m .69354 .75275 L .69353 .75272 L F
0 0 0 r
.6936 .75265 m .6934 .75287 L .69353 .75272 L F
.76 .656 .747 r
.69354 .75275 m .69593 .75063 L .69353 .75272 L F
0 0 0 r
.69399 .75235 m .6934 .75287 L .69547 .75048 L F
.594 .603 .831 r
.69376 .74954 m .68847 .74949 L .69323 .74873 L F
.69049 .75006 m .68847 .74949 L .69376 .74954 L F
.69481 .75135 m .68847 .74949 L .69487 .75128 L F
0 .327 .812 r
.68847 .74949 m .69083 .75197 L .68913 .75118 L F
.68847 .74949 m .68913 .75118 L .68831 .75096 L F
0 .045 .554 r
.68847 .74949 m .68831 .75096 L .68906 .74939 L F
.624 .81 .971 r
.68906 .74939 m .6886 .75035 L .68685 .74996 L F
.6886 .75035 m .68831 .75096 L .68764 .7505 L F
.6886 .75035 m .68764 .7505 L .68685 .74996 L F
.594 .603 .831 r
.69487 .75128 m .69049 .75006 L .69376 .74954 L F
.69494 .75139 m .69481 .75135 L .69487 .75128 L F
0 0 0 r
.69466 .75174 m .69399 .75235 L .69435 .75189 L F
.69526 .7508 m .69435 .75189 L .69547 .75048 L F
.69466 .75174 m .69435 .75189 L .69526 .7508 L F
.594 .603 .831 r
.69318 .75222 m .69171 .75291 L .692 .75053 L F
0 .327 .812 r
.69083 .75197 m .69171 .75291 L .68913 .75118 L F
.442 .024 .15 r
.68656 .75169 m .68913 .75118 L .68808 .7507 L F
.313 .418 .809 r
.68758 .74182 m .6893 .74453 L .68877 .74438 L F
0 0 .064 r
.6893 .74453 m .69074 .74149 L .68758 .74182 L F
.815 .612 .628 r
.68448 .74354 m .6893 .74453 L .68758 .74182 L F
.232 .198 .613 r
.68902 .74438 m .689 .74499 L .68877 .74438 L F
.631 .098 0 r
.68673 .74508 m .68921 .74455 L .68448 .74354 L F
.68921 .74455 m .6893 .74453 L .68915 .7445 L F
.68921 .74455 m .68915 .7445 L .68448 .74354 L F
.232 .198 .613 r
.68929 .74438 m .68921 .74455 L .68902 .74438 L F
.68921 .74455 m .689 .74499 L .68902 .74438 L F
.877 .985 .826 r
.68673 .74508 m .68874 .74271 L .68927 .74442 L F
.68921 .74455 m .68927 .74442 L .6893 .74453 L F
.68673 .74508 m .68927 .74442 L .68921 .74455 L F
.232 .198 .613 r
.69009 .74437 m .68946 .74618 L .689 .74499 L F
0 0 .064 r
.6893 .74453 m .68938 .74456 L .69074 .74149 L F
.232 .198 .613 r
.69009 .74437 m .6895 .74471 L .68953 .74438 L F
.6895 .74471 m .68909 .74494 L .68938 .74456 L F
.6895 .74471 m .68938 .74456 L .68953 .74438 L F
0 0 .064 r
.68938 .74456 m .69013 .7436 L .69074 .74149 L F
0 0 .561 r
.68874 .74271 m .68979 .74475 L .68938 .74456 L F
.68927 .74442 m .68938 .74456 L .6893 .74453 L F
.68874 .74271 m .68938 .74456 L .68927 .74442 L F
0 0 .064 r
.68938 .74456 m .68979 .74475 L .69013 .7436 L F
.232 .198 .613 r
.68953 .74438 m .689 .74499 L .68929 .74438 L F
.68909 .74494 m .689 .74499 L .68953 .74438 L F
.389 .802 .596 r
.35089 .81034 m .35097 .81029 L .35083 .81039 L F
.706 .595 .729 r
.62703 .75217 m .63045 .7527 L .62912 .74954 L F
.626 .595 .799 r
.44171 .87341 m .4451 .87578 L .44382 .8733 L F
.533 .612 .877 r
.4451 .87578 m .44626 .87412 L .44382 .8733 L F
.4451 .87578 m .44705 .87566 L .44626 .87412 L F
.742 .639 .745 r
.48134 .86954 m .48483 .86864 L .48372 .8684 L F
.773 .865 .917 r
.48495 .86651 m .48483 .86864 L .48609 .8674 L F
.89 .947 .839 r
.48372 .8684 m .48483 .86864 L .48495 .86651 L F
.521 .221 .398 r
.38549 .79215 m .38494 .79365 L .38304 .79389 L F
.455 .157 .369 r
.38669 .79338 m .38549 .79215 L .38744 .79158 L F
.38669 .79338 m .38494 .79365 L .38549 .79215 L F
.577 .084 .046 r
.54383 .83929 m .54511 .84021 L .54706 .83939 L F
.115 .113 .578 r
.54706 .83939 m .54785 .83618 L .54611 .83634 L F
.54706 .83939 m .54836 .83858 L .54785 .83618 L F
.609 .396 .567 r
.54511 .84021 m .54836 .83858 L .54706 .83939 L F
.438 0 .068 r
.35915 .72766 m .36129 .72761 L .36273 .72616 L F
.417 0 .081 r
.36129 .72761 m .36474 .72597 L .36273 .72616 L F
.558 .449 .686 r
.43418 .74127 m .43252 .74391 L .43216 .74163 L F
.528 .223 .395 r
.39751 .78441 m .3969 .7862 L .39479 .78628 L F
.424 .124 .35 r
.39887 .78565 m .39751 .78441 L .39946 .78401 L F
.39887 .78565 m .3969 .7862 L .39751 .78441 L F
.665 .56 .727 r
.44132 .8713 m .44171 .87341 L .44358 .87093 L F
.573 .435 .655 r
.44171 .87341 m .44382 .8733 L .44358 .87093 L F
.972 .763 .334 r
.55128 .82785 m .55188 .82611 L .54961 .82526 L F
.55128 .82785 m .55181 .8287 L .55188 .82611 L F
.55 .348 .559 r
.42141 .75725 m .42365 .75467 L .42138 .75491 L F
.748 .674 .779 r
.63465 .74961 m .63793 .74992 L .63689 .74696 L F
.318 .806 .805 r
.40574 .74273 m .40429 .74336 L .4074 .74238 L F
.40574 .74273 m .40368 .74337 L .40429 .74336 L F
.795 .4 .306 r
.57325 .78388 m .57122 .78382 L .57025 .78218 L F
.878 .874 .829 r
.57325 .78388 m .56979 .78594 L .57122 .78382 L F
.57325 .78388 m .57082 .78682 L .56979 .78594 L F
.847 .619 .592 r
.56061 .8022 m .56058 .80458 L .56285 .80456 L F
.929 .747 .635 r
.56063 .80675 m .56285 .80456 L .56058 .80458 L F
.56063 .80675 m .56244 .8075 L .56285 .80456 L F
.371 .121 .399 r
.71515 .73535 m .71563 .73609 L .71657 .73374 L F
.428 .867 .789 r
.71542 .72846 m .7169 .72757 L .7185 .72703 L F
0 0 0 r
.71542 .72846 m .71505 .72962 L .7169 .72757 L F
.229 .527 .919 r
.71755 .73319 m .71751 .73349 L .71657 .73374 L F
.807 .5 .469 r
.49282 .84477 m .49135 .84651 L .48991 .84465 L F
.49282 .84477 m .49323 .84705 L .49135 .84651 L F
.187 .708 .872 r
.47097 .88126 m .4732 .88114 L .46956 .88102 L F
.645 .622 .812 r
.66165 .74918 m .66277 .75216 L .66522 .75168 L F
.998 .842 .551 r
.60661 .83653 m .60711 .83424 L .60633 .83341 L F
.444 0 0 r
.71166 .73556 m .71349 .73586 L .71382 .73543 L F
.233 .64 .958 r
.71252 .73501 m .71349 .73586 L .71166 .73556 L F
.967 .645 .282 r
.71252 .73501 m .71305 .73643 L .71349 .73586 L F
.71305 .73643 m .71373 .73826 L .71349 .73586 L F
.444 0 0 r
.71382 .73543 m .71349 .73586 L .71515 .73535 L F
.657 .201 .157 r
.71349 .73586 m .71563 .73609 L .71515 .73535 L F
0 0 0 r
.57082 .78682 m .57079 .78806 L .5691 .7892 L F
.876 .858 .82 r
.57082 .78682 m .5691 .7892 L .56789 .78799 L F
.396 .696 .981 r
.5691 .7892 m .57079 .78806 L .56789 .78799 L F
0 0 0 r
.68544 .72878 m .68525 .72937 L .68445 .73054 L F
.112 .105 .57 r
.68445 .73054 m .68525 .72937 L .6851 .73155 L F
.945 .858 .725 r
.54954 .84768 m .55172 .84577 L .55049 .84529 L F
.54921 .8485 m .5497 .84797 L .54954 .84768 L F
.5497 .84797 m .55172 .84577 L .54954 .84768 L F
0 .326 .811 r
.54787 .84729 m .5507 .85034 L .55041 .84927 L F
.55027 .84901 m .55041 .84927 L .55036 .84907 L F
.54787 .84729 m .55041 .84927 L .55027 .84901 L F
.908 .882 .797 r
.54971 .85248 m .55036 .84907 L .5507 .85034 L F
.646 .422 .565 r
.50932 .85485 m .50949 .85753 L .50622 .85768 L F
.614 .422 .598 r
.51152 .85493 m .50949 .85753 L .50932 .85485 L F
.776 .605 .668 r
.59288 .78405 m .59286 .78619 L .59476 .78377 L F
.685 .476 .596 r
.59286 .78619 m .59521 .78632 L .59476 .78377 L F
0 0 0 r
.7202 .73005 m .7193 .73142 L .72052 .72949 L F
.723 .792 .31 r
.72053 .72888 m .71989 .73062 L .7202 .73005 L F
.596 .81 .407 r
.71829 .73288 m .7193 .73142 L .7202 .73005 L F
.71829 .73288 m .7202 .73005 L .71947 .73182 L F
.723 .792 .31 r
.71989 .73062 m .71941 .7319 L .7202 .73005 L F
0 0 0 r
.7202 .73005 m .72052 .72949 L .72108 .7286 L F
0 0 .509 r
.57193 .82203 m .57268 .82317 L .57176 .82199 L F
.57193 .82203 m .57176 .82199 L .57081 .82077 L F
.376 .238 .563 r
.57111 .82416 m .57217 .82208 L .57193 .82203 L F
.252 .726 .939 r
.57193 .82203 m .57249 .82147 L .57397 .82199 L F
.376 .238 .563 r
.57217 .82208 m .57249 .82147 L .57193 .82203 L F
0 0 .509 r
.57193 .82203 m .57081 .82077 L .56906 .82143 L F
.378 .765 .989 r
.58174 .84682 m .58299 .84612 L .58227 .8464 L F
.58174 .84682 m .5839 .84672 L .58299 .84612 L F
.248 0 .044 r
.38915 .79082 m .39014 .78935 L .39198 .78868 L F
.493 .348 .612 r
.44283 .86567 m .44461 .86527 L .44454 .86298 L F
.644 .521 .699 r
.44283 .86567 m .44564 .86828 L .44461 .86527 L F
.44283 .86567 m .44333 .8685 L .44564 .86828 L F
.667 .663 .836 r
.51588 .83712 m .51675 .84048 L .51363 .83889 L F
.646 .582 .769 r
.51703 .84195 m .51363 .83889 L .51675 .84048 L F
.467 .421 .723 r
.51768 .83592 m .51675 .84048 L .51588 .83712 L F
.51768 .83592 m .51881 .84033 L .51675 .84048 L F
.557 .4 .624 r
.51916 .8413 m .51675 .84048 L .51881 .84033 L F
.51916 .8413 m .51703 .84195 L .51675 .84048 L F
.996 .789 .511 r
.50367 .88462 m .50463 .88427 L .50431 .88668 L F
.743 .432 .456 r
.50463 .88427 m .50768 .88652 L .50431 .88668 L F
0 0 0 r
.50648 .8839 m .50463 .88427 L .50367 .88462 L F
.073 .484 .893 r
.52577 .87569 m .52496 .87617 L .5241 .8752 L F
.273 .31 .718 r
.5241 .8752 m .52455 .87851 L .52349 .87856 L F
0 0 .166 r
.52455 .87851 m .52577 .87569 L .52594 .87811 L F
.228 .749 .809 r
.52455 .87851 m .52594 .87811 L .52349 .87856 L F
.323 0 0 r
.52349 .87856 m .52511 .87826 L .52447 .87967 L F
.52511 .87826 m .52594 .87811 L .52529 .8788 L F
.52511 .87826 m .52529 .8788 L .52447 .87967 L F
0 0 .166 r
.52491 .87768 m .52496 .87617 L .52577 .87569 L F
.52455 .87851 m .52477 .87726 L .52491 .87768 L F
.52477 .87726 m .52496 .87617 L .52491 .87768 L F
.157 .694 .834 r
.42958 .8786 m .43054 .87843 L .43131 .87849 L F
.182 .207 .652 r
.42958 .8786 m .43022 .8799 L .43054 .87843 L F
.675 .127 0 r
.55615 .80555 m .55897 .80756 L .55725 .80696 L F
.55615 .80555 m .55725 .80696 L .55762 .80485 L F
.51 .612 .89 r
.39925 .72398 m .39841 .72567 L .39722 .72273 L F
.39925 .72398 m .40033 .72557 L .39841 .72567 L F
.477 .404 .696 r
.62743 .74057 m .62931 .74076 L .62888 .73861 L F
.574 .356 .547 r
.4408 .75894 m .4391 .75716 L .44093 .75699 L F
.4408 .75894 m .43896 .75986 L .4391 .75716 L F
.536 .146 .25 r
.38296 .72236 m .38634 .72081 L .38425 .72207 L F
.597 .722 .932 r
.65357 .70992 m .65086 .70903 L .65246 .70902 L F
.559 .751 .967 r
.65478 .70832 m .65357 .70992 L .65246 .70902 L F
.712 .466 .551 r
.65161 .71084 m .65392 .70901 L .65246 .70902 L F
.65392 .70901 m .65478 .70832 L .65246 .70902 L F
.597 .722 .932 r
.65086 .70903 m .65062 .70895 L .65246 .70902 L F
.559 .751 .967 r
.65478 .70832 m .65571 .70951 L .65357 .70992 L F
.598 .469 .676 r
.65571 .70951 m .65348 .71231 L .65357 .70992 L F
.754 .634 .728 r
.51363 .83889 m .51511 .84234 L .51135 .84177 L F
.704 .467 .562 r
.51511 .84234 m .51109 .8445 L .51135 .84177 L F
.51511 .84234 m .51458 .84457 L .51109 .8445 L F
.646 .582 .769 r
.51703 .84195 m .51511 .84234 L .51363 .83889 L F
.582 .348 .526 r
.51677 .84411 m .51511 .84234 L .51703 .84195 L F
.51677 .84411 m .51458 .84457 L .51511 .84234 L F
.502 .272 .497 r
.50857 .88164 m .50677 .88173 L .50648 .8839 L F
.71 .795 .918 r
.39459 .72199 m .39507 .7232 L .39178 .72302 L F
.223 .472 .884 r
.39572 .72219 m .39507 .7232 L .39459 .72199 L F
.515 .845 .998 r
.39572 .72219 m .39722 .72273 L .39507 .7232 L F
.39572 .72219 m .39722 .72273 L .39507 .7232 L F
.804 .57 .584 r
.49563 .83595 m .49437 .83692 L .49249 .8365 L F
.472 .244 .486 r
.35083 .81039 m .35173 .81015 L .34939 .8112 L F
.35083 .81039 m .35274 .80958 L .35173 .81015 L F
.35083 .81039 m .35097 .81029 L .35274 .80958 L F
.573 .44 .662 r
.48725 .84686 m .48549 .8499 L .48618 .84773 L F
.488 0 0 r
.70148 .74607 m .70504 .74871 L .70548 .74892 L F
.958 .888 .72 r
.70309 .75157 m .70548 .74892 L .70504 .74871 L F
.70309 .75157 m .70398 .75228 L .70548 .74892 L F
.498 .169 .339 r
.3525 .66519 m .35099 .66681 L .34978 .66652 L F
.3525 .66519 m .35099 .66681 L .34978 .66652 L F
.895 .821 .767 r
.50814 .86813 m .50855 .87121 L .50626 .87061 L F
.864 .653 .616 r
.50626 .87061 m .50855 .87121 L .50764 .87368 L F
.138 .662 .88 r
.4868 .86011 m .48534 .86026 L .48447 .85998 L F
.4868 .86011 m .48886 .86055 L .48534 .86026 L F
.369 0 .2 r
.38746 .77631 m .38664 .77768 L .38939 .77587 L F
.876 .858 .82 r
.57082 .78682 m .56789 .78799 L .56979 .78594 L F
.614 .083 0 r
.57372 .78818 m .57079 .78806 L .57082 .78682 L F
.907 .646 .531 r
.57586 .80999 m .57428 .80713 L .57584 .80766 L F
.12 0 0 r
.57428 .80713 m .57799 .80732 L .57584 .80766 L F
0 0 .333 r
.57665 .80897 m .57584 .80766 L .57799 .80732 L F
.57665 .80897 m .57586 .80999 L .57584 .80766 L F
.825 .643 .656 r
.67518 .75787 m .67641 .75468 L .67364 .75435 L F
0 .173 .706 r
.66522 .75168 m .66691 .75478 L .66721 .75373 L F
0 .091 .645 r
.66691 .75478 m .66847 .75661 L .66721 .75373 L F
.599 .468 .674 r
.44659 .85796 m .44896 .86007 L .44886 .85766 L F
.44659 .85796 m .4468 .86035 L .44896 .86007 L F
.549 .321 .522 r
.39474 .77337 m .39694 .77314 L .39724 .77069 L F
.451 .236 .496 r
.39724 .77069 m .39877 .77257 L .39905 .77044 L F
.39724 .77069 m .39694 .77314 L .39877 .77257 L F
.822 .569 .556 r
.71023 .70191 m .71017 .70412 L .71312 .70449 L F
.71 .98 .907 r
.52349 .87856 m .52318 .8796 L .52455 .87851 L F
.541 .304 .505 r
.43338 .76239 m .43118 .76463 L .43117 .76256 L F
.749 .619 .715 r
.61036 .79151 m .61139 .79437 L .61348 .79171 L F
0 0 0 r
.49553 .88533 m .4991 .88431 L .4957 .88404 L F
.659 .17 .078 r
.56456 .78162 m .56352 .78262 L .5614 .78101 L F
.535 .078 .115 r
.56664 .78156 m .56352 .78262 L .56456 .78162 L F
0 .551 .821 r
.41563 .74233 m .41451 .74196 L .41256 .74164 L F
.327 0 0 r
.41743 .74232 m .41451 .74196 L .41563 .74233 L F
.492 .231 .446 r
.40162 .76952 m .40395 .76717 L .40198 .76789 L F
.398 .574 .909 r
.43179 .73503 m .43092 .73644 L .42901 .73433 L F
.462 .658 .946 r
.43179 .73503 m .43288 .73639 L .43092 .73644 L F
.848 .762 .768 r
.64931 .63012 m .65133 .62734 L .65176 .62995 L F
.797 .726 .786 r
.67246 .74904 m .6755 .74912 L .67458 .74644 L F
.803 .626 .662 r
.6723 .75138 m .6755 .74912 L .67246 .74904 L F
.6723 .75138 m .67375 .75211 L .6755 .74912 L F
.871 .759 .736 r
.67458 .74644 m .6755 .74912 L .67627 .74618 L F
.922 .572 .354 r
.52171 .86035 m .52079 .86179 L .51993 .86034 L F
.52171 .86035 m .52237 .86256 L .52079 .86179 L F
.766 .42 .399 r
.52171 .86035 m .52511 .86274 L .52237 .86256 L F
.484 .173 .362 r
.42626 .76812 m .42363 .76999 L .42423 .76854 L F
.522 .105 .19 r
.37377 .78534 m .37741 .78361 L .37525 .78369 L F
.621 .103 0 r
.57025 .78218 m .56903 .7829 L .56664 .78156 L F
.832 .4 .209 r
.57025 .78218 m .57122 .78382 L .56903 .7829 L F
.415 .547 .881 r
.46628 .8784 m .46774 .88138 L .46956 .88102 L F
.98 .847 .458 r
.7206 .72774 m .7202 .73005 L .72108 .7286 L F
.571 .697 .926 r
.41974 .73057 m .41908 .73277 L .41837 .73039 L F
.41974 .73057 m .42125 .73247 L .41908 .73277 L F
.58 .596 .833 r
.42261 .74886 m .42424 .74736 L .42221 .74775 L F
.42261 .74886 m .42481 .7486 L .42424 .74736 L F
.548 .534 .791 r
.68886 .74749 m .68946 .74618 L .6864 .74724 L F
.678 .511 .652 r
.49028 .84166 m .49189 .84223 L .49185 .83926 L F
.275 .531 .914 r
.49185 .83926 m .49338 .83982 L .49286 .83836 L F
.828 .781 .808 r
.49338 .83982 m .49185 .83926 L .49286 .83836 L F
.548 .407 .641 r
.49185 .83926 m .49189 .84223 L .49338 .83982 L F
.828 .781 .808 r
.49338 .83982 m .49084 .84 L .49185 .83926 L F
.484 .845 .594 r
.49286 .83836 m .49084 .84 L .49185 .83926 L F
.443 .349 .654 r
.48428 .8288 m .48622 .83082 L .48455 .83107 L F
.48428 .8288 m .48622 .83082 L .48455 .83107 L F
.701 .167 0 r
.485 .83023 m .48428 .8288 L .48298 .8285 L F
.485 .83023 m .48622 .83082 L .48526 .82982 L F
0 0 0 r
.48597 .82926 m .48474 .83062 L .485 .83023 L F
.601 .668 .886 r
.48455 .83107 m .48122 .82937 L .48298 .8285 L F
.879 .951 .598 r
.48355 .83195 m .48344 .83325 L .485 .83023 L F
0 0 0 r
.48474 .83062 m .48355 .83195 L .485 .83023 L F
.701 .167 0 r
.485 .83023 m .48526 .82982 L .48428 .8288 L F
.87 .429 .129 r
.55195 .81295 m .55075 .81258 L .54912 .80978 L F
.961 .658 .411 r
.55195 .81295 m .55216 .81503 L .55075 .81258 L F
.879 .852 .812 r
.6875 .73905 m .68966 .73646 L .68865 .7354 L F
.744 .504 .567 r
.60391 .78667 m .60697 .78887 L .60694 .7865 L F
.722 .573 .687 r
.60697 .78887 m .60908 .78603 L .60694 .7865 L F
.456 .29 .567 r
.41914 .75747 m .4208 .75915 L .42141 .75725 L F
.41914 .75747 m .41897 .75972 L .4208 .75915 L F
.37 .809 .958 r
.51768 .83592 m .51537 .8338 L .51668 .83339 L F
.496 .01 .031 r
.51274 .83753 m .51588 .83712 L .51363 .83889 L F
.51274 .83753 m .51439 .83796 L .51588 .83712 L F
.846 .999 .801 r
.51588 .83712 m .51439 .83796 L .51524 .83699 L F
.37 .809 .958 r
.51692 .83591 m .51441 .83585 L .51736 .83562 L F
.51768 .83592 m .51692 .83591 L .51736 .83562 L F
.51768 .83592 m .51653 .83554 L .51441 .83585 L F
.846 .999 .801 r
.51618 .83639 m .51524 .83699 L .51653 .83554 L F
.51588 .83712 m .51524 .83699 L .51618 .83639 L F
.37 .809 .958 r
.51736 .83562 m .51441 .83585 L .51537 .8338 L F
.709 .713 .852 r
.68946 .74618 m .69195 .74718 L .69009 .74437 L F
.632 .683 .88 r
.69009 .74437 m .69195 .74718 L .69407 .74642 L F
.545 .352 .571 r
.57566 .79442 m .57781 .79408 L .57799 .79177 L F
.771 .584 .646 r
.57842 .82828 m .57885 .83069 L .57759 .83054 L F
0 0 .457 r
.5773 .82991 m .57667 .83431 L .57767 .83104 L F
.5773 .82991 m .57767 .83104 L .57752 .83007 L F
.576 .387 .589 r
.57752 .83007 m .57656 .83043 L .5773 .82991 L F
.771 .584 .646 r
.57752 .83007 m .57759 .83054 L .57656 .83043 L F
.576 .387 .589 r
.57787 .83036 m .57656 .83043 L .57752 .83007 L F
.653 .261 .288 r
.5773 .82991 m .57656 .83043 L .5772 .82852 L F
.771 .584 .646 r
.57742 .82944 m .57752 .83007 L .57656 .83043 L F
.57842 .82828 m .57759 .83054 L .57742 .82944 L F
0 0 .457 r
.57752 .83007 m .57767 .83104 L .57787 .83036 L F
.891 .985 .804 r
.57787 .83036 m .57667 .83431 L .57577 .83429 L F
.533 .352 .581 r
.67326 .73878 m .67548 .7385 L .67452 .73646 L F
.882 .451 .076 r
.67452 .73646 m .67548 .7385 L .67442 .73781 L F
0 0 .295 r
.67449 .73313 m .67452 .73646 L .67479 .73545 L F
0 0 0 r
.67479 .73545 m .67452 .73646 L .67442 .73781 L F
.849 .607 .572 r
.5949 .80245 m .59299 .80421 L .59294 .80225 L F
.5949 .80245 m .59486 .80501 L .59299 .80421 L F
.625 .812 .972 r
.68176 .71286 m .68388 .7122 L .68066 .71187 L F
.68176 .71286 m .68388 .7122 L .68066 .71187 L F
.978 .698 .421 r
.68066 .71187 m .68088 .71416 L .68176 .71286 L F
.175 .709 .743 r
.69621 .75435 m .69768 .754 L .69537 .75435 L F
.69621 .75435 m .69828 .75394 L .69768 .754 L F
.412 0 0 r
.35099 .66681 m .34861 .66694 L .34978 .66652 L F
.931 .747 .631 r
.66822 .73063 m .67026 .72833 L .66942 .72749 L F
.66822 .73063 m .66962 .73124 L .67026 .72833 L F
.857 .903 .865 r
.64939 .63252 m .64761 .63282 L .64931 .63012 L F
.564 .889 .988 r
.39178 .72302 m .38968 .7237 L .38829 .72327 L F
.07 0 0 r
.6864 .74724 m .68572 .74732 L .68275 .74722 L F
.656 .282 .324 r
.68946 .74618 m .68572 .74732 L .6864 .74724 L F
.793 .544 .562 r
.57917 .81498 m .58239 .81292 L .57921 .81275 L F
.57917 .81498 m .58246 .81531 L .58239 .81292 L F
.999 .79 .471 r
.54811 .78477 m .54719 .78593 L .54723 .78312 L F
.321 0 0 r
.55022 .78501 m .54811 .78477 L .551 .78394 L F
.55022 .78501 m .54719 .78593 L .54811 .78477 L F
0 0 0 r
.35506 .79277 m .35263 .79416 L .35446 .79327 L F
.23 0 0 r
.35164 .79476 m .35446 .79327 L .35263 .79416 L F
.927 .897 .778 r
.55172 .84577 m .55385 .84478 L .55274 .84415 L F
.55172 .84577 m .55231 .84755 L .55385 .84478 L F
.013 .588 .731 r
.57919 .84636 m .58235 .84638 L .57735 .84596 L F
.57919 .84636 m .58227 .8464 L .58235 .84638 L F
.642 .506 .682 r
.44333 .8685 m .44358 .87093 L .44564 .86828 L F
.331 .414 .797 r
.71795 .71565 m .71881 .71804 L .71793 .71622 L F
0 0 .212 r
.49481 .82513 m .49402 .82787 L .49403 .82608 L F
.442 .089 .27 r
.3493 .73266 m .35206 .73099 L .34993 .73131 L F
.959 .744 .57 r
.5123 .87631 m .51334 .8783 L .51334 .87841 L F
.579 .825 .451 r
.51334 .8783 m .51282 .88065 L .51334 .87841 L F
.51334 .8783 m .51084 .8815 L .51282 .88065 L F
.643 .552 .736 r
.6287 .74682 m .62912 .74954 L .63136 .74901 L F
.431 0 .074 r
.37765 .75047 m .37661 .75104 L .37451 .75112 L F
.815 .432 .33 r
.37661 .75104 m .37614 .75106 L .37451 .75112 L F
.263 0 0 r
.37587 .75001 m .37451 .75112 L .37293 .75118 L F
.37293 .75118 m .37451 .75112 L .37245 .75137 L F
.484 .784 .998 r
.37245 .75137 m .37451 .75112 L .37132 .75055 L F
.3 0 0 r
.37451 .75112 m .37266 .75115 L .37132 .75055 L F
.815 .432 .33 r
.37614 .75106 m .37266 .75115 L .37451 .75112 L F
.431 0 .074 r
.37765 .75047 m .37451 .75112 L .37587 .75001 L F
.659 .612 .79 r
.43649 .74957 m .43299 .74699 L .43505 .74663 L F
.558 .588 .84 r
.43705 .7462 m .43649 .74957 L .43505 .74663 L F
.43705 .7462 m .43849 .74927 L .43649 .74957 L F
.601 .377 .549 r
.44312 .7548 m .44302 .75693 L .44093 .75699 L F
.546 .519 .777 r
.44395 .75106 m .44312 .7548 L .44508 .75189 L F
.44395 .75106 m .44515 .75441 L .44312 .7548 L F
.488 .284 .529 r
.44515 .75441 m .44302 .75693 L .44312 .7548 L F
.44515 .75441 m .44302 .75693 L .44312 .7548 L F
.799 .704 .76 r
.69658 .7439 m .69983 .74461 L .69826 .74222 L F
0 .275 .779 r
.69826 .74222 m .69983 .74461 L .699 .74233 L F
.686 .234 .173 r
.69983 .74461 m .69852 .74591 L .699 .74233 L F
.661 .683 .86 r
.70026 .74865 m .69758 .74821 L .69976 .74534 L F
.686 .234 .173 r
.69983 .74461 m .70102 .74566 L .69923 .7452 L F
.661 .683 .86 r
.69988 .74537 m .69976 .74534 L .69986 .74521 L F
.70026 .74865 m .69976 .74534 L .69988 .74537 L F
.57 .559 .802 r
.70148 .74607 m .70026 .74865 L .69988 .74537 L F
.686 .234 .173 r
.70102 .74566 m .70145 .74604 L .70125 .74595 L F
.70069 .74557 m .70125 .74595 L .69988 .74537 L F
.70102 .74566 m .70125 .74595 L .70069 .74557 L F
.57 .559 .802 r
.70148 .74607 m .70125 .74595 L .70171 .74626 L F
.70125 .74595 m .69988 .74537 L .69986 .74521 L F
.70125 .74595 m .69986 .74521 L .70171 .74626 L F
.70148 .74607 m .69988 .74537 L .70125 .74595 L F
.845 .998 .818 r
.69758 .74821 m .69852 .74591 L .69976 .74534 L F
.686 .234 .173 r
.69923 .7452 m .70171 .74626 L .69852 .74591 L F
.845 .998 .818 r
.69976 .74534 m .69852 .74591 L .69986 .74521 L F
.686 .234 .173 r
.69988 .74537 m .70171 .74626 L .69966 .74538 L F
.69976 .74534 m .69966 .74538 L .69923 .7452 L F
.69988 .74537 m .69966 .74538 L .69976 .74534 L F
.70145 .74604 m .70171 .74626 L .69988 .74537 L F
.684 .652 .812 r
.5626 .81302 m .56567 .8146 L .56553 .81323 L F
.83 .919 .896 r
.56553 .81323 m .56567 .8146 L .56785 .81251 L F
.78 .338 .2 r
.56244 .8075 m .56392 .80948 L .56511 .80882 L F
.549 .029 0 r
.56511 .80882 m .56392 .80948 L .56732 .80965 L F
.747 .701 .808 r
.70372 .73901 m .7016 .74142 L .70061 .73857 L F
.309 .168 .521 r
.54343 .8339 m .54476 .83352 L .54481 .83114 L F
0 0 .395 r
.68066 .71187 m .68019 .71531 L .67842 .71249 L F
.68066 .71187 m .68088 .71416 L .68019 .71531 L F
0 0 .335 r
.68019 .71531 m .68092 .7165 L .67991 .71743 L F
.68019 .71531 m .68088 .71416 L .68092 .7165 L F
.534 .006 0 r
.49348 .85769 m .4915 .8579 L .48988 .85752 L F
.8 .309 0 r
.49348 .85769 m .49399 .85945 L .4915 .8579 L F
.49348 .85769 m .49519 .86005 L .49399 .85945 L F
.822 .354 .095 r
.49651 .86034 m .49519 .86005 L .49348 .85769 L F
.484 .242 .471 r
.65375 .63603 m .65363 .63795 L .65147 .6385 L F
.398 .096 .332 r
.6561 .63561 m .65363 .63795 L .65375 .63603 L F
0 0 .102 r
.5393 .83814 m .53893 .83735 L .53962 .83657 L F
.5393 .83814 m .53838 .83917 L .53893 .83735 L F
.496 .313 .563 r
.53121 .85539 m .53315 .85481 L .53327 .85234 L F
.53327 .85234 m .53315 .85481 L .53121 .85539 L F
.747 .507 .567 r
.60164 .78859 m .60391 .78667 L .60164 .78635 L F
.60164 .78859 m .60383 .78893 L .60391 .78667 L F
.744 .504 .567 r
.60391 .78667 m .60383 .78893 L .60697 .78887 L F
.722 .217 .031 r
.38362 .72186 m .38681 .72353 L .38498 .72252 L F
.38681 .72353 m .38708 .72367 L .38498 .72252 L F
.536 .146 .25 r
.3839 .72193 m .38498 .72252 L .38634 .72081 L F
.38296 .72236 m .38498 .72252 L .3839 .72193 L F
.725 .376 .387 r
.38498 .72252 m .38829 .72327 L .38634 .72081 L F
.583 .365 .551 r
.38846 .72023 m .38829 .72327 L .38634 .72081 L F
.998 .818 .534 r
.59478 .80948 m .59386 .80945 L .59423 .80716 L F
.943 .962 .704 r
.59478 .80948 m .59262 .81235 L .59386 .80945 L F
0 0 .22 r
.59195 .81336 m .5911 .81548 L .59147 .81521 L F
.59209 .81382 m .59147 .81521 L .59231 .81459 L F
.59195 .81336 m .59147 .81521 L .59209 .81382 L F
.943 .962 .704 r
.59478 .80948 m .59203 .81484 L .59248 .81292 L F
.59291 .81196 m .59248 .81292 L .59262 .81235 L F
.59478 .80948 m .59248 .81292 L .59291 .81196 L F
.498 .178 .355 r
.47307 .83312 m .47612 .83123 L .47359 .83176 L F
.907 .8 .73 r
.6114 .82277 m .61245 .8213 L .61081 .82039 L F
.659 .969 .901 r
.57992 .79055 m .57799 .79177 L .57852 .79074 L F
.955 .64 .394 r
.58024 .79331 m .57852 .79074 L .57799 .79177 L F
.57 .374 .576 r
.57799 .79177 m .57781 .79408 L .58024 .79331 L F
0 0 .092 r
.68641 .72502 m .68544 .72878 L .68698 .72768 L F
.68641 .72502 m .68608 .72736 L .68564 .72803 L F
.993 .81 .437 r
.68554 .72651 m .68608 .72736 L .68641 .72502 L F
.553 .38 .601 r
.68641 .72686 m .68608 .72736 L .68554 .72651 L F
.61 .642 .858 r
.68698 .72768 m .68848 .72469 L .68641 .72502 L F
.68698 .72768 m .69035 .72756 L .68848 .72469 L F
.553 .38 .601 r
.68886 .72783 m .68608 .72736 L .68641 .72686 L F
0 0 .092 r
.68564 .72803 m .68608 .72736 L .68544 .72878 L F
.208 .144 .561 r
.68608 .72736 m .68525 .72937 L .68544 .72878 L F
.995 .836 .482 r
.64692 .63715 m .64789 .63577 L .64817 .63805 L F
.64692 .63715 m .64725 .635 L .64789 .63577 L F
.983 .857 .637 r
.64761 .63282 m .64789 .63577 L .64725 .635 L F
.586 .604 .837 r
.42329 .73197 m .42223 .73445 L .42125 .73247 L F
.42329 .73197 m .42446 .73434 L .42223 .73445 L F
.536 .003 0 r
.49651 .86034 m .49895 .86227 L .49519 .86005 L F
.49895 .86227 m .49893 .86226 L .49519 .86005 L F
.49651 .86034 m .49886 .86092 L .49897 .86229 L F
.647 .389 .514 r
.49996 .85975 m .49886 .86092 L .49651 .86034 L F
.67 .487 .63 r
.50199 .85824 m .49886 .86092 L .49996 .85975 L F
.50199 .85824 m .50164 .86042 L .49886 .86092 L F
.612 .072 0 r
.49989 .86224 m .49886 .86092 L .50066 .8622 L F
.4991 .86228 m .49899 .86165 L .49989 .86224 L F
.49899 .86165 m .49886 .86092 L .49989 .86224 L F
.49897 .86229 m .49897 .86225 L .4991 .86228 L F
.56 .207 .326 r
.49886 .86092 m .50164 .86042 L .50066 .8622 L F
.612 .072 0 r
.49899 .86222 m .50066 .8622 L .49944 .85974 L F
.49897 .86229 m .49903 .86228 L .49899 .86222 L F
.49903 .86228 m .50066 .8622 L .49899 .86222 L F
.78 .687 .761 r
.49808 .85913 m .49878 .86152 L .49843 .86149 L F
.405 0 0 r
.49399 .85945 m .49519 .86005 L .49897 .86229 L F
.49399 .85945 m .49897 .86229 L .49635 .8613 L F
.536 .003 0 r
.49895 .86227 m .49897 .86229 L .49893 .86226 L F
.986 .761 .512 r
.49897 .86229 m .49877 .86157 L .49635 .8613 L F
.835 .634 .631 r
.49878 .86152 m .49873 .86156 L .49635 .8613 L F
.78 .687 .761 r
.49737 .86009 m .49843 .86149 L .49648 .86131 L F
.49808 .85913 m .49843 .86149 L .49737 .86009 L F
.49638 .86127 m .49648 .86131 L .49635 .8613 L F
.49808 .85913 m .49648 .86131 L .49638 .86127 L F
.986 .761 .512 r
.49877 .86157 m .49808 .85913 L .49635 .8613 L F
.835 .634 .631 r
.49873 .86156 m .49669 .86335 L .49635 .8613 L F
.986 .761 .512 r
.49897 .86229 m .49899 .86222 L .49878 .86152 L F
.49897 .86229 m .49878 .86152 L .49877 .86157 L F
.612 .072 0 r
.49897 .86225 m .49886 .86092 L .4991 .86228 L F
.986 .761 .512 r
.49899 .86222 m .49944 .85974 L .49861 .85936 L F
.49864 .86104 m .49861 .85936 L .49808 .85913 L F
.49899 .86222 m .49861 .85936 L .49864 .86104 L F
.835 .634 .631 r
.49962 .86159 m .49944 .86468 L .49871 .86433 L F
.49867 .86216 m .49871 .86433 L .49669 .86335 L F
.49962 .86159 m .49871 .86433 L .49867 .86216 L F
.49962 .86159 m .49867 .86216 L .49878 .86152 L F
.49867 .86216 m .49669 .86335 L .49878 .86152 L F
.986 .761 .512 r
.49877 .86157 m .49878 .86152 L .49808 .85913 L F
.78 .687 .761 r
.49808 .85913 m .49962 .86159 L .49878 .86152 L F
0 .311 .803 r
.49962 .86159 m .50244 .86382 L .50239 .86387 L F
.50041 .86258 m .50239 .86387 L .50192 .86447 L F
.49962 .86159 m .50239 .86387 L .50041 .86258 L F
.49993 .86247 m .50192 .86447 L .50064 .86447 L F
.49962 .86159 m .50041 .86258 L .49993 .86247 L F
.50041 .86258 m .50192 .86447 L .49993 .86247 L F
.987 .722 .356 r
.50807 .83946 m .50725 .84073 L .50477 .83889 L F
.50807 .83946 m .50804 .84154 L .50725 .84073 L F
.758 .485 .52 r
.51135 .84177 m .50804 .84154 L .50807 .83946 L F
.558 .449 .686 r
.43418 .74127 m .43441 .74356 L .43252 .74391 L F
.572 .468 .697 r
.43441 .74356 m .43299 .74699 L .43252 .74391 L F
.729 .403 .429 r
.49282 .85185 m .49447 .8496 L .49333 .85011 L F
.49282 .85185 m .49616 .852 L .49447 .8496 L F
.777 .404 .35 r
.49447 .8496 m .49616 .852 L .49747 .85126 L F
0 0 0 r
.40925 .74201 m .40574 .74273 L .4074 .74238 L F
.576 .074 .025 r
.55411 .78204 m .55514 .78336 L .55274 .78281 L F
.374 .034 .254 r
.55697 .78268 m .55411 .78204 L .55834 .78173 L F
.55697 .78268 m .55514 .78336 L .55411 .78204 L F
.587 .311 .465 r
.43605 .76045 m .43557 .7624 L .43338 .76239 L F
.579 .34 .518 r
.43896 .75986 m .43557 .7624 L .43605 .76045 L F
.981 .912 .613 r
.65496 .7168 m .65411 .71767 L .65479 .71628 L F
.157 .053 .476 r
.65286 .7182 m .65425 .71907 L .65496 .7168 L F
.21 0 .229 r
.65496 .7168 m .65669 .71648 L .65701 .71569 L F
.383 .069 .304 r
.65425 .71907 m .65669 .71648 L .65496 .7168 L F
.716 .898 .961 r
.51441 .81828 m .51793 .81763 L .51684 .81636 L F
0 0 .051 r
.51793 .81763 m .5184 .81751 L .5189 .8154 L F
0 .338 .784 r
.51793 .81763 m .51953 .81856 L .5184 .81751 L F
.631 .882 .987 r
.43928 .87863 m .43752 .87944 L .4361 .8788 L F
.43928 .87863 m .43752 .87944 L .4361 .8788 L F
.001 0 0 r
.35753 .80709 m .36088 .80588 L .35913 .80686 L F
0 0 0 r
.35913 .80686 m .36088 .80588 L .36287 .8052 L F
.959 .821 .664 r
.55036 .84907 m .55231 .84755 L .55172 .84577 L F
.55036 .84907 m .55154 .84966 L .55231 .84755 L F
.313 0 .217 r
.34242 .75987 m .3413 .76206 L .33964 .76239 L F
.537 .219 .377 r
.3445 .75962 m .3413 .76206 L .34242 .75987 L F
.618 .485 .677 r
.44861 .85528 m .44886 .85766 L .45083 .85497 L F
.269 0 .032 r
.35075 .75869 m .35012 .75749 L .35222 .75724 L F
.35075 .75869 m .34882 .75916 L .35012 .75749 L F
.581 .348 .528 r
.66096 .63043 m .66096 .63212 L .65915 .63206 L F
.587 .412 .612 r
.66288 .62796 m .66321 .63015 L .66096 .63043 L F
.537 .294 .494 r
.66321 .63015 m .66096 .63212 L .66096 .63043 L F
.651 .642 .828 r
.66068 .74389 m .66267 .74177 L .66037 .74232 L F
.66068 .74389 m .66335 .74414 L .66267 .74177 L F
.621 .501 .695 r
.66068 .74389 m .66369 .74649 L .66335 .74414 L F
.66068 .74389 m .66153 .74707 L .66369 .74649 L F
.67 .257 .254 r
.58576 .82058 m .58967 .82003 L .58792 .8222 L F
0 0 0 r
.58967 .82003 m .59078 .81797 L .59135 .82031 L F
.002 0 .297 r
.66424 .62465 m .66424 .62704 L .66288 .62796 L F
.257 .23 .636 r
.66438 .62234 m .66573 .62383 L .66424 .62465 L F
0 0 .038 r
.66573 .62383 m .66424 .6272 L .66496 .62514 L F
.097 0 .323 r
.66573 .62383 m .66424 .6272 L .66424 .62704 L F
.6644 .62457 m .66424 .62704 L .66424 .62465 L F
.66474 .62511 m .66424 .62704 L .6644 .62457 L F
.585 .071 0 r
.66115 .62465 m .66328 .62556 L .66478 .62518 L F
.66474 .62511 m .66478 .62518 L .66496 .62514 L F
.66115 .62465 m .66478 .62518 L .66474 .62511 L F
.097 0 .323 r
.66495 .62426 m .66474 .62511 L .6644 .62457 L F
.752 .524 .587 r
.66474 .62511 m .66496 .62514 L .66486 .62463 L F
.097 0 .323 r
.66573 .62383 m .66486 .62463 L .66495 .62426 L F
.321 .242 .61 r
.66438 .62234 m .66486 .62463 L .66573 .62383 L F
.66486 .62463 m .66496 .62514 L .66573 .62383 L F
.097 0 .323 r
.66573 .62383 m .66424 .62704 L .66486 .62463 L F
.752 .524 .587 r
.66465 .6251 m .66474 .62511 L .66481 .62438 L F
.66474 .62511 m .66486 .62463 L .66481 .62438 L F
.66115 .62465 m .66465 .6251 L .66438 .62234 L F
.66465 .6251 m .66481 .62438 L .66438 .62234 L F
.002 0 .297 r
.66424 .62704 m .66424 .6272 L .66421 .62722 L F
.66424 .62704 m .66421 .62722 L .66288 .62796 L F
.618 .629 .839 r
.66424 .6272 m .66321 .63015 L .66288 .62796 L F
.181 0 .36 r
.32873 .70152 m .32883 .70393 L .32734 .70445 L F
.345 .117 .419 r
.33144 .69913 m .3309 .70133 L .32873 .70152 L F
.204 0 .365 r
.33015 .70286 m .32873 .70152 L .3309 .70133 L F
.33015 .70286 m .32883 .70393 L .32873 .70152 L F
.079 .301 .783 r
.49211 .86829 m .49366 .87104 L .4943 .8703 L F
.255 0 0 r
.48549 .8499 m .48781 .84981 L .48843 .84938 L F
.604 .855 .991 r
.48919 .84816 m .49063 .84853 L .48843 .84938 L F
.695 .939 .642 r
.48843 .84938 m .48781 .84981 L .48919 .84816 L F
.716 .836 .939 r
.38543 .74623 m .38889 .74607 L .38755 .7452 L F
.54 .815 .997 r
.38889 .74607 m .38971 .74483 L .38755 .7452 L F
.38889 .74607 m .39101 .74559 L .38971 .74483 L F
.598 .184 .228 r
.69491 .74135 m .69287 .74172 L .69576 .74317 L F
.879 .904 .843 r
.69576 .74317 m .69826 .74222 L .69491 .74135 L F
.748 .496 .551 r
.67128 .74605 m .67425 .74425 L .67146 .7438 L F
.67128 .74605 m .67458 .74644 L .67425 .74425 L F
.748 .366 .328 r
.47834 .87034 m .48134 .86954 L .48007 .8723 L F
.164 0 .075 r
.48132 .87052 m .48134 .86954 L .48372 .8684 L F
.499 .134 .277 r
.48132 .87052 m .48007 .8723 L .48134 .86954 L F
.575 .806 .987 r
.50881 .8371 m .5036 .83595 L .50567 .83557 L F
.505 .211 .4 r
.52427 .8285 m .52639 .82838 L .52687 .82546 L F
.382 .398 .753 r
.58246 .81531 m .58497 .81742 L .58569 .8155 L F
.039 0 0 r
.58692 .81556 m .58791 .81545 L .58569 .8155 L F
.782 .72 .794 r
.61281 .80142 m .61127 .79892 L .60929 .8017 L F
.61281 .80142 m .61297 .79996 L .61127 .79892 L F
.801 .712 .766 r
.60929 .8017 m .61018 .80484 L .61281 .80142 L F
.922 .661 .526 r
.55752 .81824 m .55614 .8193 L .5557 .81638 L F
.55752 .81824 m .55779 .82094 L .55614 .8193 L F
.807 .366 .195 r
.54771 .80974 m .54445 .8074 L .5457 .80734 L F
.806 .357 .174 r
.54912 .80978 m .54771 .80974 L .5457 .80734 L F
.853 .435 .236 r
.55075 .81258 m .54771 .80974 L .54912 .80978 L F
0 .219 .705 r
.44281 .74993 m .44191 .74958 L .44049 .74883 L F
.44281 .74993 m .44395 .75106 L .44191 .74958 L F
.459 .114 .293 r
.41185 .77583 m .41088 .77811 L .40874 .77831 L F
.394 .052 .262 r
.41285 .77756 m .41185 .77583 L .41382 .77538 L F
.41285 .77756 m .41088 .77811 L .41185 .77583 L F
.89 .642 .557 r
.57072 .84666 m .57295 .84741 L .57169 .84804 L F
.083 0 0 r
.57169 .84804 m .57295 .84741 L .57543 .84687 L F
.711 .765 .895 r
.71442 .71479 m .71795 .71565 L .71534 .71586 L F
.71442 .71479 m .71795 .71565 L .71534 .71586 L F
.662 .28 .311 r
.71793 .71622 m .71534 .71586 L .71795 .71565 L F
.656 .658 .841 r
.71534 .71586 m .71793 .71622 L .71795 .71565 L F
.812 .649 .681 r
.60834 .79413 m .61139 .79437 L .61036 .79151 L F
.757 .54 .602 r
.60817 .79643 m .61139 .79437 L .60834 .79413 L F
.60817 .79643 m .61141 .79671 L .61139 .79437 L F
.656 .798 .951 r
.57781 .79408 m .58107 .79442 L .58024 .79331 L F
.392 .66 .966 r
.58024 .79331 m .58107 .79442 L .58211 .7934 L F
.494 .826 .999 r
.58211 .7934 m .58107 .79442 L .58325 .79401 L F
.643 .656 .847 r
.57775 .81742 m .57981 .81944 L .58043 .81803 L F
.579 .565 .802 r
.65381 .73698 m .65424 .73846 L .6563 .73797 L F
.719 .283 .214 r
.56819 .84655 m .56925 .8451 L .57072 .84666 L F
.791 .937 .925 r
.5364 .83584 m .53397 .83331 L .53748 .83317 L F
.484 .28 .527 r
.53945 .83268 m .5364 .83584 L .53748 .83317 L F
.957 .681 .472 r
.5594 .81483 m .55968 .81743 L .56087 .81562 L F
.744 .359 .323 r
.55968 .81743 m .56287 .81813 L .56087 .81562 L F
.854 .613 .574 r
.67077 .73586 m .67063 .73873 L .67326 .73878 L F
.824 .661 .681 r
.67015 .74074 m .67326 .73878 L .67063 .73873 L F
.67015 .74074 m .67273 .74124 L .67326 .73878 L F
.818 .888 .894 r
.52449 .81342 m .52225 .8163 L .52051 .81493 L F
.539 .235 .4 r
.45851 .84144 m .46145 .83902 L .45891 .8393 L F
.68 .547 .696 r
.50399 .85761 m .50073 .8551 L .50451 .85545 L F
.979 .737 .326 r
.69627 .74843 m .69576 .75004 L .69569 .74826 L F
.69627 .74843 m .69569 .74826 L .69567 .74775 L F
.725 .99 .851 r
.69758 .74821 m .697 .74864 L .69627 .74843 L F
.697 .74864 m .69546 .74976 L .69627 .74843 L F
.845 .998 .818 r
.69758 .74821 m .69627 .74843 L .69852 .74591 L F
.491 .295 .542 r
.63323 .73095 m .63506 .73246 L .63569 .73027 L F
.64 .508 .687 r
.45197 .84692 m .45454 .84685 L .45412 .8443 L F
.566 .413 .633 r
.45263 .84983 m .45454 .84685 L .45197 .84692 L F
.722 .573 .687 r
.60697 .78887 m .61027 .78909 L .60908 .78603 L F
.917 .598 .423 r
.49928 .85482 m .49957 .85694 L .50073 .8551 L F
.665 .662 .838 r
.50073 .8551 m .50175 .85173 L .49928 .85482 L F
.50073 .8551 m .50367 .85535 L .50175 .85173 L F
.68 .547 .696 r
.50322 .85703 m .50199 .85824 L .50073 .8551 L F
.50399 .85761 m .50295 .85794 L .50322 .85703 L F
.50295 .85794 m .50199 .85824 L .50322 .85703 L F
.101 0 .419 r
.50291 .85865 m .50199 .85824 L .50295 .85794 L F
.50341 .85817 m .50295 .85794 L .50399 .85761 L F
.825 .586 .578 r
.49957 .85694 m .50299 .8584 L .50367 .85535 L F
.50299 .8584 m .50335 .85855 L .50339 .85816 L F
.101 0 .419 r
.50292 .85844 m .50295 .85794 L .50339 .85816 L F
.825 .586 .578 r
.50299 .8584 m .50339 .85816 L .50367 .85535 L F
.101 0 .419 r
.50291 .85865 m .50292 .85844 L .50341 .85817 L F
.50292 .85844 m .50339 .85816 L .50341 .85817 L F
.184 .06 .466 r
.5034 .85817 m .50501 .85451 L .50375 .8553 L F
.842 .611 .589 r
.50622 .85768 m .50434 .85974 L .50399 .85761 L F
.101 0 .428 r
.50399 .85761 m .50434 .85974 L .50508 .85899 L F
.50399 .85761 m .50508 .85899 L .50384 .8588 L F
.184 .06 .466 r
.50335 .85855 m .50347 .85826 L .5034 .85817 L F
.50347 .85826 m .50341 .85817 L .5034 .85817 L F
.101 0 .428 r
.50341 .85817 m .50384 .8588 L .50291 .85865 L F
.50399 .85761 m .50392 .85818 L .50341 .85817 L F
.50392 .85818 m .50356 .85835 L .50341 .85817 L F
.184 .06 .466 r
.50335 .85855 m .50356 .85835 L .50347 .85826 L F
.101 0 .428 r
.50356 .85835 m .50354 .85836 L .50347 .85826 L F
.50356 .85835 m .50347 .85826 L .50341 .85817 L F
.184 .06 .466 r
.50347 .85826 m .50473 .85727 L .50501 .85451 L F
.50356 .85835 m .50473 .85727 L .50347 .85826 L F
.755 .606 .692 r
.49957 .85694 m .50291 .85865 L .50335 .85855 L F
.566 .478 .715 r
.50291 .85865 m .50473 .85727 L .50356 .85835 L F
.50291 .85865 m .50356 .85835 L .50335 .85855 L F
.101 0 .428 r
.50392 .85818 m .50384 .8588 L .50354 .85836 L F
.184 .06 .466 r
.50347 .85826 m .50349 .85821 L .50341 .85817 L F
.50349 .85821 m .50501 .85451 L .5034 .85817 L F
.50364 .85566 m .50375 .8553 L .50367 .85535 L F
.50335 .85855 m .50375 .8553 L .50364 .85566 L F
.825 .586 .578 r
.49957 .85694 m .50367 .85535 L .50073 .8551 L F
.654 .486 .644 r
.44454 .86298 m .44686 .86298 L .4468 .86035 L F
.637 .496 .674 r
.44686 .86298 m .44896 .86007 L .4468 .86035 L F
.212 0 0 r
.36474 .72597 m .36682 .72584 L .36783 .7254 L F
.303 0 0 r
.36682 .72584 m .37002 .7248 L .36783 .7254 L F
.167 .679 .897 r
.59163 .8461 m .59411 .84661 L .59472 .84656 L F
.627 .705 .902 r
.41743 .74232 m .42155 .74408 L .41927 .74218 L F
.312 .588 .942 r
.42155 .74408 m .42211 .74289 L .41927 .74218 L F
.42155 .74408 m .42276 .74384 L .42211 .74289 L F
.544 .462 .712 r
.42155 .74408 m .42424 .74736 L .42276 .74384 L F
.42155 .74408 m .42221 .74775 L .42424 .74736 L F
.729 .368 .366 r
.57436 .7781 m .57649 .78029 L .57765 .77834 L F
.752 .396 .38 r
.57649 .78029 m .57962 .78075 L .57765 .77834 L F
.781 .386 .305 r
.57765 .77834 m .57962 .78075 L .58092 .78019 L F
.902 .642 .534 r
.70875 .70359 m .71023 .70191 L .70883 .70132 L F
.70875 .70359 m .71017 .70412 L .71023 .70191 L F
.614 .808 .392 r
.64264 .72413 m .64392 .72207 L .64207 .72318 L F
.571 .591 .834 r
.64392 .72207 m .64264 .72413 L .64207 .72318 L F
.64392 .72207 m .6454 .72483 L .64264 .72413 L F
.59 .708 .925 r
.34014 .67765 m .33828 .67823 L .337 .67667 L F
.723 .576 .69 r
.6875 .73905 m .68758 .74182 L .69074 .74149 L F
.017 .581 .796 r
.69216 .7415 m .69287 .74172 L .69074 .74149 L F
.69216 .7415 m .69074 .74149 L .68979 .74475 L F
.347 0 0 r
.41256 .74164 m .412 .74242 L .40925 .74201 L F
.548 .038 0 r
.41451 .74196 m .412 .74242 L .41256 .74164 L F
.883 .455 .074 r
.55947 .82366 m .55947 .82512 L .55871 .82277 L F
.55947 .82366 m .56049 .8257 L .55947 .82512 L F
.805 .576 .591 r
.65348 .71231 m .65254 .71501 L .65151 .7122 L F
.807 .806 .85 r
.33256 .66489 m .32996 .66458 L .33157 .66246 L F
.691 .535 .67 r
.33162 .66585 m .32996 .66458 L .33256 .66489 L F
0 0 .171 r
.33373 .66166 m .33256 .66489 L .33157 .66246 L F
.33373 .66166 m .33343 .66373 L .33256 .66489 L F
.401 .236 .539 r
.33343 .66373 m .33162 .66585 L .33256 .66489 L F
.734 .701 .819 r
.709 .7432 m .70907 .74601 L .71111 .74442 L F
.665 .288 .321 r
.4768 .86476 m .48225 .8634 L .47695 .86267 L F
.4768 .86476 m .47875 .86511 L .48225 .8634 L F
.79 .627 .679 r
.47875 .86511 m .48217 .86294 L .48225 .8634 L F
.691 .3 .302 r
.52926 .81255 m .53143 .81452 L .53282 .81257 L F
.479 .061 .168 r
.53282 .81257 m .53366 .81425 L .53449 .81314 L F
.53282 .81257 m .53143 .81452 L .53366 .81425 L F
.651 .575 .756 r
.47043 .85756 m .46712 .85491 L .47069 .8551 L F
.717 .711 .844 r
.45892 .88078 m .4602 .88235 L .46214 .88127 L F
.006 0 0 r
.37221 .78625 m .37015 .78671 L .36838 .78749 L F
.896 .572 .426 r
.4886 .84036 m .48827 .84103 L .49028 .84166 L F
.48827 .84103 m .48834 .84157 L .49028 .84166 L F
.928 .726 .609 r
.48801 .84156 m .4884 .84371 L .49028 .84166 L F
0 0 .345 r
.48881 .84048 m .48906 .84304 L .48861 .84349 L F
.48851 .8428 m .48861 .84349 L .4884 .84371 L F
.48881 .84048 m .48861 .84349 L .48851 .8428 L F
.896 .572 .426 r
.48827 .84103 m .48801 .84156 L .48834 .84157 L F
.806 .511 .49 r
.49028 .84166 m .4884 .84371 L .49188 .84365 L F
.678 .51 .651 r
.49028 .84166 m .49188 .84365 L .49189 .84223 L F
.506 .235 .437 r
.34617 .67575 m .34553 .67758 L .34346 .67792 L F
.34617 .67575 m .34553 .67758 L .34346 .67792 L F
.226 0 .303 r
.34617 .67575 m .34764 .6749 L .34627 .67414 L F
.34617 .67575 m .34553 .67758 L .34764 .6749 L F
.34764 .6749 m .34553 .67758 L .34617 .67575 L F
.643 .552 .736 r
.6287 .74682 m .63136 .74901 L .63051 .74625 L F
.419 .093 .304 r
.33978 .73587 m .34072 .7378 L .34187 .73539 L F
.33978 .73587 m .33879 .73823 L .34072 .7378 L F
0 0 .337 r
.66898 .72223 m .66976 .7251 L .66914 .72329 L F
.553 .395 .621 r
.45069 .85256 m .45274 .85235 L .45263 .84983 L F
.607 .455 .649 r
.45069 .85256 m .45308 .85469 L .45274 .85235 L F
.45069 .85256 m .45083 .85497 L .45308 .85469 L F
.259 .016 .342 r
.33458 .69777 m .33405 .69517 L .33591 .6945 L F
.33458 .69777 m .33312 .69845 L .33405 .69517 L F
.879 .852 .812 r
.6875 .73905 m .68865 .7354 L .68656 .73641 L F
.755 .678 .777 r
.68452 .73847 m .6875 .73905 L .68656 .73641 L F
.859 .684 .664 r
.68469 .74114 m .6875 .73905 L .68452 .73847 L F
.68469 .74114 m .68758 .74182 L .6875 .73905 L F
.451 .054 .195 r
.39135 .77545 m .39354 .77522 L .39474 .77337 L F
.387 0 .128 r
.39354 .77522 m .39694 .77314 L .39474 .77337 L F
.147 .162 .618 r
.59262 .81235 m .59203 .81484 L .59195 .81336 L F
.668 .542 .702 r
.44358 .87093 m .44615 .87115 L .44564 .86828 L F
.615 .42 .595 r
.44382 .8733 m .44615 .87115 L .44358 .87093 L F
.394 .734 .991 r
.70026 .72319 m .70151 .72227 L .69926 .72226 L F
.567 .769 .973 r
.70275 .72077 m .70151 .72227 L .70037 .72109 L F
.70151 .72227 m .70275 .72077 L .7022 .72143 L F
.394 .734 .991 r
.70026 .72319 m .70075 .72321 L .70151 .72227 L F
.70026 .72319 m .7027 .72331 L .70151 .72227 L F
.70026 .72319 m .70151 .72227 L .69926 .72226 L F
.391 0 0 r
.70056 .72342 m .70151 .72227 L .69926 .72226 L F
.567 .769 .973 r
.70151 .72227 m .7022 .72143 L .70056 .72342 L F
.394 .734 .991 r
.70075 .72321 m .7027 .72331 L .70151 .72227 L F
.346 0 .111 r
.38494 .79365 m .38158 .79596 L .38304 .79389 L F
.478 .093 .23 r
.65905 .71472 m .66184 .71452 L .66259 .7127 L F
.773 .991 .887 r
.66259 .7127 m .66294 .71135 L .665 .71031 L F
0 0 0 r
.66259 .7127 m .66321 .71341 L .66294 .71135 L F
.66259 .7127 m .66184 .71452 L .66321 .71341 L F
.871 .747 .723 r
.60929 .8017 m .60748 .80448 L .61018 .80484 L F
.859 .697 .681 r
.60714 .80656 m .61018 .80484 L .60748 .80448 L F
.60714 .80656 m .60856 .80761 L .61018 .80484 L F
.791 .548 .569 r
.50328 .86801 m .50632 .86829 L .50626 .87061 L F
.466 .279 .542 r
.50626 .87061 m .50632 .86829 L .50814 .86813 L F
.83 .356 .009 r
.54857 .82261 m .55002 .82347 L .54743 .82092 L F
.999 .818 .528 r
.54891 .82486 m .55002 .82347 L .54857 .82261 L F
.54891 .82486 m .54961 .82526 L .55002 .82347 L F
.898 .987 .748 r
.53323 .83881 m .53417 .83628 L .53533 .83682 L F
.833 .63 .629 r
.53467 .84012 m .53254 .83884 L .53323 .83881 L F
.989 .856 .614 r
.47555 .87533 m .4771 .87358 L .47627 .87285 L F
.47555 .87533 m .4766 .87612 L .4771 .87358 L F
.172 .708 .752 r
.65785 .62392 m .65675 .6242 L .65568 .62395 L F
.65785 .62392 m .65922 .62375 L .65675 .6242 L F
.63 .645 .846 r
.69117 .72158 m .68842 .72012 L .69107 .71994 L F
.08 .379 .842 r
.69285 .72161 m .69117 .72158 L .69107 .71994 L F
.69285 .72161 m .69316 .72268 L .69117 .72158 L F
.533 0 0 r
.54094 .80304 m .54394 .80444 L .54468 .80347 L F
0 0 0 r
.54468 .80347 m .54485 .80386 L .54652 .80435 L F
.54468 .80347 m .54402 .80434 L .54485 .80386 L F
.766 .61 .685 r
.54221 .80356 m .54388 .80442 L .54485 .80386 L F
0 .31 .7 r
.54221 .80356 m .54394 .80444 L .54364 .8043 L F
.54221 .80356 m .54364 .8043 L .54094 .80304 L F
.766 .61 .685 r
.54221 .80356 m .54279 .80505 L .54388 .80442 L F
.54279 .80505 m .54338 .80659 L .54485 .80386 L F
0 0 0 r
.54402 .80434 m .54394 .80444 L .54485 .80386 L F
.539 .235 .4 r
.45851 .84144 m .46059 .84127 L .46145 .83902 L F
.664 .364 .454 r
.46145 .83902 m .46059 .84127 L .4635 .8411 L F
.628 .369 .507 r
.46145 .83902 m .4635 .8411 L .46374 .83912 L F
.545 .832 .998 r
.42901 .73433 m .42785 .73468 L .42653 .73403 L F
.709 .471 .562 r
.59831 .78858 m .60164 .78635 L .59829 .7862 L F
.59831 .78858 m .60164 .78859 L .60164 .78635 L F
.631 .629 .83 r
.5347 .87174 m .5357 .86901 L .53342 .87014 L F
.5347 .87174 m .53682 .87106 L .5357 .86901 L F
.742 .553 .639 r
.53172 .83344 m .52849 .83371 L .52861 .83128 L F
.757 .445 .457 r
.64817 .63805 m .65147 .6385 L .65089 .63978 L F
.439 .142 .363 r
.65147 .6385 m .65322 .64017 L .65089 .63978 L F
.65147 .6385 m .65363 .63795 L .65322 .64017 L F
.266 0 0 r
.35446 .79327 m .35718 .79219 L .35506 .79277 L F
.719 .482 .566 r
.49776 .85127 m .49928 .85482 L .49994 .85271 L F
.763 .405 .378 r
.49616 .852 m .49994 .85271 L .49776 .85127 L F
.549 .543 .799 r
.49776 .85127 m .49994 .85271 L .50175 .85173 L F
.734 .34 .303 r
.57962 .78075 m .58319 .78128 L .58092 .78019 L F
.874 .771 .745 r
.52242 .83393 m .52133 .8305 L .52261 .82988 L F
.52242 .83393 m .52004 .83369 L .52133 .8305 L F
.882 .731 .69 r
.52242 .83393 m .52127 .83595 L .52004 .83369 L F
.271 0 .224 r
.46883 .83637 m .47031 .83615 L .47134 .83402 L F
.365 .04 .275 r
.47134 .83402 m .47189 .83491 L .47307 .83312 L F
.47134 .83402 m .47031 .83615 L .47189 .83491 L F
.441 .581 .897 r
.33543 .67429 m .33469 .67629 L .33363 .67445 L F
.33543 .67429 m .337 .67667 L .33469 .67629 L F
.568 .587 .832 r
.38432 .88949 m .381 .88683 L .38119 .88956 L F
.805 .576 .591 r
.65348 .71231 m .65328 .71509 L .65254 .71501 L F
.845 .612 .587 r
.65348 .71231 m .65479 .71628 L .65328 .71509 L F
.598 .469 .676 r
.65571 .70951 m .65642 .71209 L .65348 .71231 L F
.611 .495 .696 r
.65642 .71209 m .65479 .71628 L .65348 .71231 L F
.971 .824 .64 r
.564 .83946 m .56216 .84101 L .56429 .83834 L F
.564 .83946 m .56325 .84163 L .56216 .84101 L F
.823 .923 .902 r
.47783 .85703 m .48121 .85595 L .47992 .85607 L F
.47783 .85703 m .47906 .85751 L .48121 .85595 L F
.36 .832 .855 r
.48121 .85595 m .481 .85548 L .47992 .85607 L F
.48121 .85595 m .48349 .85528 L .481 .85548 L F
.397 .173 .453 r
.48455 .83107 m .4841 .83349 L .48622 .83082 L F
.48455 .83107 m .4841 .83349 L .48622 .83082 L F
.48622 .83082 m .4841 .83349 L .48455 .83107 L F
.758 .329 .232 r
.55494 .81592 m .55425 .81722 L .55216 .81503 L F
.611 .162 .159 r
.5557 .81638 m .55425 .81722 L .55494 .81592 L F
.791 .937 .925 r
.5364 .83584 m .53533 .83682 L .53417 .83628 L F
.349 .819 .905 r
.42824 .76768 m .42626 .76812 L .42844 .76787 L F
0 .13 .603 r
.56501 .81879 m .56401 .81818 L .56287 .81813 L F
.617 .589 .8 r
.53838 .83917 m .54198 .84172 L .54164 .83952 L F
.69 .55 .69 r
.54164 .83952 m .54198 .84172 L .54383 .83929 L F
0 0 0 r
.70586 .74294 m .70429 .74512 L .70719 .74401 L F
.70586 .74294 m .70394 .74566 L .70429 .74512 L F
.752 .608 .698 r
.60698 .79128 m .61027 .78909 L .60697 .78887 L F
.60698 .79128 m .61036 .79151 L .61027 .78909 L F
.981 .691 .345 r
.56196 .83086 m .56078 .82787 L .56149 .82861 L F
.351 .493 .861 r
.50175 .85173 m .50367 .85535 L .50501 .85451 L F
.631 .446 .614 r
.51916 .8413 m .51677 .84411 L .51703 .84195 L F
.496 .245 .463 r
.66096 .63212 m .65838 .63522 L .65915 .63206 L F
.572 .468 .697 r
.43441 .74356 m .43505 .74663 L .43299 .74699 L F
.55 .348 .559 r
.42141 .75725 m .42351 .75693 L .42365 .75467 L F
.528 .334 .562 r
.42365 .75467 m .42569 .75428 L .42586 .75199 L F
.557 .368 .581 r
.42351 .75693 m .42569 .75428 L .42365 .75467 L F
.5 .372 .637 r
.34447 .6845 m .34244 .68396 L .34438 .68275 L F
.34447 .6845 m .34225 .6856 L .34244 .68396 L F
.875 .752 .724 r
.60791 .8129 m .60771 .80964 L .60616 .81238 L F
.948 .727 .57 r
.60645 .81482 m .60791 .8129 L .60616 .81238 L F
.60645 .81482 m .6077 .8153 L .60791 .8129 L F
.589 .412 .61 r
.45625 .8439 m .45851 .84144 L .45652 .84192 L F
.764 .546 .602 r
.58961 .78365 m .59286 .78619 L .59288 .78405 L F
0 0 .544 r
.67409 .70664 m .67614 .70967 L .67564 .70968 L F
.648 .129 0 r
.67564 .70968 m .67767 .71198 L .67842 .71249 L F
.433 .819 .988 r
.67702 .71078 m .6785 .71053 L .67751 .71098 L F
.444 .575 .891 r
.67614 .70967 m .6771 .71113 L .67564 .70968 L F
.67614 .70967 m .67751 .71098 L .67767 .71198 L F
.834 .362 .027 r
.67551 .71015 m .67751 .71098 L .67621 .70974 L F
.67551 .71015 m .67621 .70974 L .67614 .70967 L F
.51 .368 .624 r
.67569 .71175 m .67551 .71015 L .67319 .71067 L F
.67569 .71175 m .67551 .71015 L .67319 .71067 L F
.305 .794 .884 r
.67517 .71035 m .67551 .71015 L .67469 .71055 L F
.444 .575 .891 r
.6771 .71113 m .67717 .71142 L .67564 .70968 L F
.305 .794 .884 r
.67673 .7097 m .67806 .70975 L .67551 .71015 L F
.433 .819 .988 r
.67551 .71015 m .67692 .71033 L .67702 .71078 L F
.543 .849 .998 r
.67551 .71015 m .67806 .70975 L .6785 .71053 L F
.433 .819 .988 r
.67692 .71033 m .6785 .71053 L .67702 .71078 L F
.644 .48 .646 r
.67551 .71015 m .67806 .70975 L .67746 .71145 L F
.67551 .71015 m .67746 .71145 L .67743 .71137 L F
.64 .462 .627 r
.67669 .7109 m .67806 .70975 L .67551 .71015 L F
.644 .48 .646 r
.67551 .71015 m .67743 .71137 L .67673 .7097 L F
.64 .462 .627 r
.67569 .71175 m .67669 .7109 L .67551 .71015 L F
.305 .794 .884 r
.67673 .7097 m .67551 .71015 L .67517 .71035 L F
.444 .575 .891 r
.6771 .71113 m .67767 .71198 L .67717 .71142 L F
.301 0 0 r
.3721 .72515 m .37418 .72496 L .37567 .72374 L F
.084 0 0 r
.37567 .72374 m .37617 .72431 L .37747 .72344 L F
.37567 .72374 m .37418 .72496 L .37617 .72431 L F
.595 .389 .572 r
.44461 .86527 m .44686 .86298 L .44454 .86298 L F
.528 .052 .068 r
.53172 .83344 m .53102 .83421 L .52849 .83371 L F
.383 0 0 r
.53397 .83331 m .53102 .83421 L .53172 .83344 L F
.409 .057 .253 r
.3969 .7862 m .3941 .78752 L .39479 .78628 L F
.896 .823 .768 r
.47582 .85987 m .47906 .85751 L .47783 .85703 L F
.47582 .85987 m .4773 .86031 L .47906 .85751 L F
0 0 0 r
.32818 .70578 m .32734 .70445 L .32883 .70393 L F
.32818 .70578 m .32689 .70656 L .32734 .70445 L F
.001 0 0 r
.35753 .80709 m .35913 .80686 L .35734 .8076 L F
.823 .473 .394 r
.52261 .82988 m .52507 .83164 L .52133 .8305 L F
.52133 .8305 m .52507 .83164 L .52261 .82988 L F
.594 .452 .658 r
.44886 .85766 m .45103 .85737 L .45083 .85497 L F
.613 .462 .653 r
.44896 .86007 m .45103 .85737 L .44886 .85766 L F
.534 .494 .758 r
.66335 .74414 m .66496 .74095 L .66267 .74177 L F
.66335 .74414 m .66598 .74376 L .66496 .74095 L F
.558 .436 .67 r
.66369 .74649 m .66598 .74376 L .66335 .74414 L F
0 0 0 r
.36613 .80344 m .36811 .80253 L .36991 .80172 L F
.637 .075 0 r
.48663 .85723 m .48349 .85528 L .48627 .85521 L F
.595 .893 .989 r
.3852 .88629 m .38342 .88711 L .38642 .88675 L F
.3852 .88629 m .38342 .88711 L .38642 .88675 L F
.392 .849 .888 r
.68747 .72001 m .68623 .72066 L .68566 .72119 L F
.68747 .72001 m .68842 .72012 L .68623 .72066 L F
.157 .053 .476 r
.65286 .7182 m .6525 .72103 L .65425 .71907 L F
.873 .966 .853 r
.54184 .84702 m .54301 .84726 L .54434 .84505 L F
.54434 .84505 m .54301 .84726 L .54184 .84702 L F
.715 .712 .846 r
.40919 .72765 m .40712 .72874 L .40572 .72713 L F
.537 .87 .993 r
.59472 .84656 m .59697 .84645 L .59658 .84614 L F
.75 .989 .785 r
.59697 .84645 m .59914 .84396 L .59658 .84614 L F
.59697 .84645 m .59947 .8441 L .59914 .84396 L F
.753 .56 .636 r
.60698 .79128 m .60834 .79413 L .61036 .79151 L F
.351 .018 .253 r
.37274 .79952 m .37381 .80085 L .3719 .80118 L F
.37274 .79952 m .37464 .79937 L .37381 .80085 L F
.968 .729 .522 r
.55935 .80379 m .56058 .80458 L .56061 .8022 L F
.922 .596 .132 r
.55947 .79924 m .55999 .80166 L .56057 .80209 L F
.274 0 .172 r
.55947 .79924 m .56048 .80061 L .55999 .80166 L F
.961 .833 .671 r
.55939 .80123 m .55999 .80166 L .56048 .80061 L F
.55866 .80164 m .55999 .80166 L .55939 .80123 L F
.922 .596 .132 r
.56057 .80209 m .55999 .80166 L .56061 .8022 L F
.984 .902 .587 r
.55999 .80166 m .55935 .80379 L .56061 .8022 L F
.839 .444 0 r
.67772 .74096 m .67798 .7427 L .67642 .74041 L F
.67772 .74096 m .67893 .74408 L .67798 .7427 L F
.735 .747 .862 r
.6797 .74251 m .67725 .74164 L .67798 .7427 L F
.697 .229 0 r
.67642 .74041 m .67798 .7427 L .67696 .74154 L F
.735 .747 .862 r
.67725 .74164 m .67696 .74154 L .67798 .7427 L F
.839 .444 0 r
.67893 .74408 m .67897 .7442 L .67798 .7427 L F
.405 .026 .204 r
.64954 .71121 m .65246 .70902 L .65062 .70895 L F
.025 .583 .813 r
.50142 .84789 m .49821 .84739 L .49856 .84764 L F
.813 .328 0 r
.51502 .87546 m .51344 .87314 L .51256 .87358 L F
.088 .335 .809 r
.32427 .66202 m .32403 .66307 L .32261 .66134 L F
.32427 .66202 m .32572 .66426 L .32403 .66307 L F
.312 0 0 r
.37766 .88655 m .3798 .88694 L .381 .88683 L F
.37766 .88655 m .3798 .88694 L .381 .88683 L F
.949 .689 .509 r
.381 .88683 m .38119 .88956 L .3798 .88694 L F
.255 .695 .961 r
.38168 .8863 m .381 .88683 L .3798 .88694 L F
.38168 .8863 m .38342 .88711 L .381 .88683 L F
.38168 .8863 m .381 .88683 L .3798 .88694 L F
.38168 .8863 m .38342 .88711 L .381 .88683 L F
.491 .243 .466 r
.40206 .78118 m .4015 .78377 L .39946 .78401 L F
.497 .249 .468 r
.40352 .78338 m .40206 .78118 L .40416 .7808 L F
.40352 .78338 m .4015 .78377 L .40206 .78118 L F
.866 .844 .821 r
.50414 .86274 m .50552 .86408 L .50369 .86571 L F
.641 .803 .961 r
.50696 .86312 m .50552 .86408 L .50523 .8638 L F
.50583 .86297 m .50523 .8638 L .50414 .86274 L F
.50696 .86312 m .50523 .8638 L .50583 .86297 L F
.688 .233 .166 r
.50583 .86297 m .5058 .86286 L .50414 .86274 L F
.641 .803 .961 r
.50713 .86301 m .50696 .86312 L .50414 .86274 L F
.414 .53 .866 r
.50778 .86511 m .50552 .86408 L .50713 .86301 L F
.767 .585 .652 r
.50617 .86001 m .50634 .86053 L .50524 .86164 L F
.50617 .86001 m .50524 .86164 L .50511 .86144 L F
.50634 .86053 m .50713 .86301 L .50589 .8629 L F
.354 .425 .797 r
.50571 .86238 m .5058 .86286 L .50592 .86271 L F
.701 .618 .76 r
.50589 .8629 m .50592 .86271 L .5058 .86286 L F
.767 .585 .652 r
.50634 .86053 m .506 .86232 L .50414 .86274 L F
.791 .735 .8 r
.50414 .86274 m .5058 .86286 L .50571 .86238 L F
.767 .585 .652 r
.506 .86232 m .50589 .8629 L .50414 .86274 L F
.50511 .86144 m .50524 .86164 L .50414 .86274 L F
.842 .611 .589 r
.50622 .85768 m .50617 .86001 L .50446 .85975 L F
.5044 .85966 m .50446 .85975 L .50434 .85974 L F
.50622 .85768 m .50446 .85975 L .5044 .85966 L F
.635 .423 .578 r
.50949 .85753 m .50617 .86001 L .50622 .85768 L F
.50949 .85753 m .50936 .86013 L .50617 .86001 L F
.767 .585 .652 r
.50617 .86001 m .50414 .86274 L .50434 .85974 L F
.639 .513 .694 r
.50936 .86013 m .50713 .86301 L .50617 .86001 L F
.354 .425 .797 r
.50508 .85899 m .50556 .8616 L .50749 .8608 L F
.50556 .8616 m .50571 .86238 L .50592 .86219 L F
.50556 .8616 m .50592 .86219 L .50749 .8608 L F
.791 .735 .8 r
.50414 .86274 m .50571 .86238 L .50508 .85899 L F
.354 .425 .797 r
.50571 .86238 m .50592 .86271 L .50749 .8608 L F
.701 .618 .76 r
.50583 .86297 m .50589 .8629 L .5058 .86286 L F
.50589 .8629 m .50688 .86155 L .50592 .86271 L F
.50626 .8644 m .50749 .8608 L .50688 .86155 L F
.50626 .8644 m .50688 .86155 L .50583 .86297 L F
.688 .233 .166 r
.50626 .8644 m .50583 .86297 L .50414 .86274 L F
.976 .68 .309 r
.56309 .83619 m .56169 .83366 L .56304 .83381 L F
.422 0 0 r
.47784 .88223 m .48053 .88349 L .48142 .88401 L F
.552 .073 .073 r
.49338 .83982 m .4961 .84088 L .49719 .83976 L F
.704 .257 .186 r
.4961 .84088 m .49936 .84139 L .49719 .83976 L F
.815 .612 .628 r
.68448 .74354 m .68758 .74182 L .68469 .74114 L F
.766 .343 .245 r
.56206 .80917 m .56244 .8075 L .56063 .80675 L F
.56206 .80917 m .56392 .80948 L .56244 .8075 L F
.211 0 0 r
.39642 .74425 m .39492 .74524 L .39285 .7455 L F
.281 .78 .864 r
.39855 .74486 m .39492 .74524 L .39642 .74425 L F
.493 .04 .103 r
.40021 .74392 m .39855 .74486 L .39642 .74425 L F
.572 .55 .792 r
.65737 .74104 m .65844 .73763 L .6563 .73797 L F
.65737 .74104 m .65951 .74066 L .65844 .73763 L F
.632 .599 .798 r
.65737 .74104 m .66037 .74232 L .65951 .74066 L F
.694 .153 0 r
.51843 .87809 m .51621 .87591 L .51502 .87546 L F
.545 0 0 r
.51979 .8785 m .51621 .87591 L .51843 .87809 L F
.366 .621 .95 r
.40446 .72557 m .40357 .72667 L .40218 .7254 L F
.40446 .72557 m .40572 .72713 L .40357 .72667 L F
.733 .74 .857 r
.51772 .84976 m .51913 .85195 L .51595 .85247 L F
.728 .589 .701 r
.51913 .85195 m .51694 .85496 L .51595 .85247 L F
.595 .677 .898 r
.51985 .84942 m .51913 .85195 L .51772 .84976 L F
.51985 .84942 m .52138 .85158 L .51913 .85195 L F
.101 0 .419 r
.50291 .85865 m .50164 .86042 L .50199 .85824 L F
.448 .668 .957 r
.54611 .83634 m .54514 .83422 L .54476 .83352 L F
.54611 .83634 m .54785 .83618 L .54514 .83422 L F
.238 .22 .636 r
.42586 .75199 m .4267 .74858 L .42481 .7486 L F
.42586 .75199 m .42687 .75168 L .4267 .74858 L F
.364 .198 .518 r
.42586 .75199 m .42728 .75368 L .42687 .75168 L F
.42586 .75199 m .42569 .75428 L .42728 .75368 L F
.3 .527 .905 r
.53321 .81695 m .53371 .8181 L .53472 .8171 L F
.181 .331 .781 r
.53371 .8181 m .53608 .82027 L .53472 .8171 L F
.462 .169 .382 r
.42141 .75725 m .42295 .75872 L .42351 .75693 L F
.42141 .75725 m .4208 .75915 L .42295 .75872 L F
.606 .452 .647 r
.66153 .74707 m .66165 .74918 L .66369 .74649 L F
.733 .303 .228 r
.58319 .78128 m .58644 .7829 L .58634 .78103 L F
0 0 .057 r
.55364 .83606 m .55387 .83889 L .55365 .83653 L F
.692 .648 .802 r
.63136 .74901 m .63465 .74961 L .63361 .74681 L F
.751 .679 .781 r
.63361 .74681 m .63465 .74961 L .63689 .74696 L F
.453 .576 .887 r
.68275 .74722 m .68438 .74535 L .68165 .74629 L F
.68275 .74722 m .68572 .74732 L .68438 .74535 L F
.805 .98 .897 r
.63875 .72386 m .63802 .72567 L .63788 .72439 L F
.63875 .72386 m .63955 .72433 L .63802 .72567 L F
.916 .816 .35 r
.63788 .72439 m .63802 .72567 L .63762 .7279 L F
.29 0 0 r
.35894 .79145 m .36166 .79044 L .3598 .79106 L F
.437 0 0 r
.55908 .77899 m .55819 .77833 L .55684 .7782 L F
.622 .573 .779 r
.5614 .78101 m .55992 .77977 L .56049 .77917 L F
.55992 .77977 m .55819 .77833 L .56049 .77917 L F
.217 0 0 r
.55908 .77899 m .56102 .77861 L .56049 .77917 L F
.56102 .77861 m .56227 .77836 L .56049 .77917 L F
.437 0 0 r
.55908 .77899 m .56049 .77917 L .55819 .77833 L F
0 0 .22 r
.59195 .81336 m .59231 .81459 L .59262 .81235 L F
.772 .823 .892 r
.53467 .84012 m .53838 .83917 L .53738 .83941 L F
.591 .947 .829 r
.5393 .83814 m .53738 .83941 L .53838 .83917 L F
.384 .731 .99 r
.45217 .87785 m .45345 .87872 L .45424 .87785 L F
.372 .713 .987 r
.45345 .87872 m .45541 .87873 L .45424 .87785 L F
.58 .641 .876 r
.45345 .87872 m .457 .87987 L .45541 .87873 L F
.385 0 0 r
.36428 .75125 m .36795 .75091 L .3638 .75183 L F
.557 .308 .495 r
.44302 .75693 m .4408 .75894 L .44093 .75699 L F
.521 .857 .995 r
.58874 .81504 m .5911 .81548 L .58791 .81545 L F
.474 .841 .991 r
.59231 .81459 m .5911 .81548 L .58874 .81504 L F
.793 .718 .781 r
.48622 .83082 m .4841 .83349 L .48733 .83365 L F
.757 .701 .799 r
.48622 .83082 m .48733 .83365 L .48953 .83109 L F
0 0 .218 r
.48964 .83608 m .48733 .83365 L .48738 .83611 L F
.548 .278 .459 r
.41176 .76501 m .41396 .76485 L .41448 .76285 L F
.44 .178 .419 r
.41448 .76285 m .41588 .76431 L .4165 .76249 L F
.41448 .76285 m .41396 .76485 L .41588 .76431 L F
0 0 .009 r
.54383 .83929 m .54198 .84172 L .54347 .84043 L F
.381 0 0 r
.54347 .84043 m .54511 .84021 L .54383 .83929 L F
.216 .731 .875 r
.70808 .73556 m .71029 .73539 L .71166 .73556 L F
.233 .64 .958 r
.71252 .73501 m .71166 .73556 L .71029 .73539 L F
.492 .183 .369 r
.37937 .78316 m .38145 .78288 L .38237 .7803 L F
.512 .229 .422 r
.38145 .78288 m .38413 .77975 L .38237 .7803 L F
.645 .622 .812 r
.66165 .74918 m .66522 .75168 L .66352 .74848 L F
.707 .634 .773 r
.66352 .74848 m .66522 .75168 L .66705 .74911 L F
.535 .4 .643 r
.66522 .75168 m .66726 .7516 L .66705 .74911 L F
0 .173 .706 r
.66522 .75168 m .66721 .75373 L .66726 .7516 L F
.579 .416 .624 r
.39982 .75254 m .40123 .75477 L .39866 .75498 L F
0 .131 .667 r
.40085 .75329 m .40123 .75477 L .40044 .75352 L F
.40007 .75272 m .39996 .75277 L .39982 .75254 L F
.40038 .75295 m .39996 .75277 L .40007 .75272 L F
.11 0 .316 r
.39982 .75254 m .39912 .75402 L .40053 .75254 L F
.39912 .75402 m .39866 .75498 L .39969 .75363 L F
.39912 .75402 m .39969 .75363 L .40053 .75254 L F
0 .131 .667 r
.40085 .75329 m .40044 .75352 L .40038 .75295 L F
.445 .527 .848 r
.40033 .7532 m .40123 .75477 L .40085 .75329 L F
.39933 .75304 m .39972 .75339 L .39976 .75311 L F
.592 .557 .784 r
.39866 .75498 m .39933 .75304 L .39734 .75387 L F
.793 .849 .892 r
.3997 .75351 m .39866 .75498 L .39972 .75339 L F
.592 .557 .784 r
.39866 .75498 m .40123 .75477 L .39972 .75339 L F
.39866 .75498 m .39972 .75339 L .39933 .75304 L F
.793 .849 .892 r
.39972 .75339 m .39866 .75498 L .39979 .75285 L F
.39979 .75285 m .39866 .75498 L .39734 .75387 L F
.524 .302 .52 r
.39933 .75304 m .39976 .75311 L .40053 .75254 L F
.793 .849 .892 r
.40026 .75274 m .3997 .75351 L .39976 .75311 L F
0 .131 .667 r
.40038 .75295 m .40044 .75352 L .39996 .75277 L F
.117 .104 .565 r
.40085 .75329 m .39982 .75254 L .40053 .75254 L F
.793 .849 .892 r
.40053 .75254 m .40036 .75276 L .40035 .75262 L F
.524 .302 .52 r
.39976 .75311 m .40085 .75329 L .40053 .75254 L F
.793 .849 .892 r
.40035 .75262 m .40026 .75274 L .39979 .75285 L F
.40026 .75274 m .39976 .75311 L .39979 .75285 L F
.445 .527 .848 r
.39976 .75311 m .39986 .75352 L .40033 .7532 L F
.793 .849 .892 r
.40036 .75276 m .39866 .75498 L .40035 .75262 L F
.445 .527 .848 r
.39972 .75339 m .39986 .75352 L .39976 .75311 L F
.39986 .75352 m .40123 .75477 L .40033 .7532 L F
.793 .849 .892 r
.40032 .75263 m .39734 .75387 L .39933 .75304 L F
.40053 .75254 m .40035 .75262 L .40032 .75263 L F
.40035 .75262 m .39734 .75387 L .40032 .75263 L F
.568 .491 .728 r
.48247 .87588 m .48451 .87287 L .48256 .87351 L F
.614 .049 0 r
.48611 .88078 m .48372 .8788 L .48248 .87833 L F
.64 .491 .665 r
.48372 .8788 m .48617 .87914 L .48621 .87649 L F
.623 .273 .356 r
.48611 .88078 m .48617 .87914 L .48372 .8788 L F
.5 .185 .363 r
.33452 .73939 m .33683 .73864 L .33477 .73876 L F
.817 .444 .348 r
.61081 .82039 m .61007 .8186 L .60734 .81765 L F
0 .227 .745 r
.67964 .74444 m .68165 .74629 L .68116 .74505 L F
.67964 .74444 m .68116 .74505 L .67897 .7442 L F
.503 .308 .55 r
.33995 .68846 m .33971 .69064 L .3382 .69046 L F
.439 .333 .637 r
.33971 .69064 m .33946 .69347 L .3382 .69046 L F
.059 0 0 r
.48609 .8674 m .4894 .86694 L .48778 .86741 L F
.48609 .8674 m .48778 .86741 L .48495 .86651 L F
.41 .131 .375 r
.38413 .77975 m .38664 .77768 L .38464 .77821 L F
.759 .499 .54 r
.52718 .86312 m .52362 .86523 L .52511 .86274 L F
.52718 .86312 m .52675 .86524 L .52362 .86523 L F
.579 .59 .829 r
.52909 .86243 m .52718 .86312 L .52588 .85983 L F
.718 .582 .701 r
.52909 .86243 m .52675 .86524 L .52718 .86312 L F
.378 .313 .657 r
.54198 .84172 m .54379 .84383 L .54347 .84043 L F
.436 .204 .462 r
.34225 .6856 m .34166 .68801 L .33995 .68846 L F
.451 .218 .469 r
.34305 .6872 m .34225 .6856 L .34447 .6845 L F
.34305 .6872 m .34166 .68801 L .34225 .6856 L F
.466 .888 .903 r
.51421 .88442 m .51528 .88446 L .51723 .88373 L F
.754 .567 .643 r
.60383 .78893 m .60505 .79149 L .60697 .78887 L F
.765 .582 .65 r
.60697 .78887 m .60505 .79149 L .60698 .79128 L F
.634 .572 .767 r
.44461 .86527 m .44564 .86828 L .4479 .86796 L F
.607 .49 .694 r
.44615 .87115 m .4479 .86796 L .44564 .86828 L F
.828 .781 .808 r
.49338 .83982 m .49189 .84223 L .49084 .84 L F
0 .127 .659 r
.49188 .84365 m .49084 .84 L .49189 .84223 L F
.939 .68 .519 r
.67465 .72291 m .67358 .72433 L .67377 .72213 L F
.67465 .72291 m .67488 .72484 L .67358 .72433 L F
.892 .581 .452 r
.48957 .86416 m .49085 .86304 L .48893 .86224 L F
.48957 .86416 m .49093 .86533 L .49085 .86304 L F
.773 .479 .489 r
.49085 .86304 m .49441 .86537 L .4922 .86386 L F
.572 .445 .669 r
.45454 .84685 m .45625 .8439 L .45412 .8443 L F
.446 0 0 r
.34014 .67765 m .34197 .67812 L .34346 .67792 L F
.298 .233 .614 r
.34346 .67792 m .34508 .68007 L .34379 .68024 L F
0 0 .514 r
.34416 .67863 m .34346 .67792 L .34197 .67812 L F
.34416 .67863 m .34508 .68007 L .34346 .67792 L F
.913 .962 .802 r
.60156 .84172 m .60445 .83918 L .60358 .83876 L F
.60156 .84172 m .60246 .84199 L .60445 .83918 L F
.854 .997 .778 r
.60445 .83918 m .606 .83638 L .60358 .83876 L F
.60445 .83918 m .60661 .83653 L .606 .83638 L F
.817 .609 .622 r
.58633 .79895 m .58347 .79633 L .58607 .79695 L F
.594 .527 .749 r
.64384 .73038 m .64414 .73319 L .64194 .7337 L F
.965 .801 .63 r
.56683 .81188 m .56785 .81251 L .56732 .80965 L F
.83 .919 .896 r
.56553 .81323 m .56785 .81251 L .56683 .81188 L F
.784 .98 .907 r
.59947 .8441 m .60156 .84172 L .59914 .84396 L F
.59947 .8441 m .60246 .84199 L .60156 .84172 L F
.905 .898 .809 r
.58771 .82431 m .59037 .82365 L .58834 .82648 L F
0 0 .299 r
.59135 .82031 m .59037 .82365 L .58979 .82321 L F
.791 .98 .904 r
.58979 .82321 m .59037 .82365 L .58771 .82431 L F
.47 .624 .918 r
.56186 .81159 m .5626 .81302 L .56374 .81183 L F
.486 .649 .931 r
.5626 .81302 m .56553 .81323 L .56374 .81183 L F
.492 .179 .363 r
.40815 .78003 m .40682 .77874 L .40874 .77831 L F
.40815 .78003 m .40629 .78039 L .40682 .77874 L F
.566 .413 .633 r
.45263 .84983 m .45473 .8496 L .45454 .84685 L F
.57 .408 .623 r
.45263 .84983 m .45481 .85194 L .45473 .8496 L F
.45263 .84983 m .45274 .85235 L .45481 .85194 L F
.53 .374 .614 r
.49017 .88472 m .49315 .88387 L .48915 .88416 L F
.706 .233 .126 r
.49017 .88472 m .49334 .88602 L .49279 .88656 L F
.53 .374 .614 r
.49017 .88472 m .49279 .88656 L .49315 .88387 L F
.859 .516 .401 r
.58644 .7829 m .58963 .78599 L .58961 .78365 L F
.764 .546 .602 r
.58961 .78365 m .58963 .78599 L .59286 .78619 L F
.958 .751 .582 r
.34809 .67273 m .34627 .67414 L .34764 .6749 L F
.827 .64 .65 r
.67015 .74074 m .67146 .7438 L .67273 .74124 L F
.175 0 0 r
.4085 .76447 m .41176 .76501 L .40927 .76456 L F
.165 0 0 r
.34639 .7964 m .34894 .79542 L .34728 .79631 L F
.512 .053 .101 r
.5614 .78101 m .56036 .78241 L .55834 .78173 L F
.806 .74 .79 r
.56353 .77834 m .5614 .78101 L .56049 .77917 L F
.649 .206 .185 r
.5614 .78101 m .56352 .78262 L .56036 .78241 L F
.283 .609 .955 r
.43267 .87825 m .43131 .87849 L .43054 .87843 L F
.43267 .87825 m .43388 .87953 L .43131 .87849 L F
.669 .52 .673 r
.43022 .8799 m .43267 .87825 L .43054 .87843 L F
.43022 .8799 m .43388 .87953 L .43267 .87825 L F
.43022 .8799 m .43207 .88181 L .43388 .87953 L F
.583 .685 .911 r
.68974 .71701 m .68842 .72012 L .68747 .72001 L F
.68974 .71701 m .69107 .71994 L .68842 .72012 L F
.387 .76 .992 r
.48488 .88461 m .4858 .88374 L .48354 .88394 L F
.48488 .88461 m .48719 .88457 L .4858 .88374 L F
.998 .783 .457 r
.67468 .73084 m .67389 .73016 L .67404 .72785 L F
.995 .783 .508 r
.67468 .73084 m .67357 .73241 L .67389 .73016 L F
.67468 .73084 m .67449 .73313 L .67357 .73241 L F
.025 .583 .813 r
.50142 .84789 m .50087 .84768 L .49821 .84739 L F
.331 .754 .975 r
.50142 .84789 m .50281 .84712 L .50087 .84768 L F
.50142 .84789 m .50357 .84782 L .50281 .84712 L F
.444 .543 .863 r
.50142 .84789 m .50418 .84938 L .50357 .84782 L F
.509 .344 .593 r
.57175 .83311 m .56972 .83398 L .56965 .83123 L F
.582 .404 .605 r
.5721 .83089 m .56965 .83123 L .57187 .82854 L F
.564 .34 .534 r
.5721 .83089 m .57175 .83311 L .56965 .83123 L F
.582 .404 .605 r
.5721 .83089 m .56965 .83123 L .57187 .82854 L F
.67 .611 .78 r
.63051 .74625 m .63136 .74901 L .63361 .74681 L F
.895 .71 .644 r
.51135 .84177 m .50863 .84356 L .50804 .84154 L F
.51135 .84177 m .51109 .8445 L .50863 .84356 L F
0 .18 .712 r
.51019 .83649 m .51016 .83549 L .50973 .83586 L F
.791 .789 .851 r
.67315 .76077 m .67454 .75954 L .67166 .75941 L F
.93 .588 .147 r
.56524 .84383 m .56634 .84512 L .56651 .84682 L F
.956 .642 .392 r
.47559 .87803 m .4766 .87612 L .47555 .87533 L F
.47559 .87803 m .47696 .87867 L .4766 .87612 L F
.248 0 .044 r
.38915 .79082 m .39198 .78868 L .39133 .79018 L F
.545 .213 .355 r
.3941 .78752 m .39133 .79018 L .39198 .78868 L F
.576 .729 .947 r
.57396 .83292 m .57309 .83485 L .57175 .83311 L F
.57396 .83292 m .57577 .83429 L .57309 .83485 L F
.343 0 .166 r
.35712 .72804 m .35783 .72962 L .35915 .72766 L F
.35712 .72804 m .35592 .73007 L .35783 .72962 L F
.458 .168 .384 r
.42363 .76999 m .4209 .77269 L .42146 .77035 L F
.506 .173 .337 r
.344 .73539 m .34611 .73523 L .34729 .7328 L F
.347 .015 .252 r
.34729 .7328 m .348 .73462 L .3493 .73266 L F
.34729 .7328 m .34611 .73523 L .348 .73462 L F
.8 .513 .502 r
.50926 .84705 m .51362 .84907 L .51156 .84627 L F
.50926 .84705 m .50952 .84941 L .51362 .84907 L F
.109 .397 .851 r
.51156 .84627 m .51362 .84907 L .5146 .84911 L F
.586 .798 .98 r
.65381 .73698 m .65576 .73635 L .65523 .73569 L F
.579 .565 .802 r
.65381 .73698 m .6563 .73797 L .65576 .73635 L F
.409 .132 .378 r
.46624 .83883 m .46822 .83873 L .46883 .83637 L F
.419 .141 .382 r
.46883 .83637 m .47018 .83813 L .47031 .83615 L F
.46883 .83637 m .46822 .83873 L .47018 .83813 L F
.998 .842 .551 r
.60661 .83653 m .60633 .83341 L .606 .83638 L F
.75 .832 .915 r
.38296 .72236 m .38132 .7237 L .37954 .7227 L F
.452 .088 .255 r
.41658 .77373 m .41592 .77509 L .41382 .77538 L F
.436 .067 .238 r
.41866 .77347 m .41592 .77509 L .41658 .77373 L F
.751 .972 .703 r
.57254 .82688 m .57187 .82854 L .57406 .8261 L F
.901 .857 .409 r
.57209 .828 m .5721 .83089 L .57187 .82854 L F
.57236 .82856 m .5721 .83089 L .57209 .828 L F
.57236 .82856 m .5717 .83103 L .5721 .83089 L F
.57254 .82688 m .57236 .82856 L .57209 .828 L F
.747 .659 .762 r
.56957 .82948 m .5717 .83103 L .57216 .82876 L F
.57176 .82797 m .57216 .82876 L .57254 .82688 L F
.901 .857 .409 r
.57254 .82688 m .57216 .82876 L .57236 .82856 L F
.715 .612 .74 r
.57254 .82688 m .574 .82855 L .57176 .82797 L F
.57254 .82688 m .57176 .82797 L .56973 .82744 L F
.747 .659 .762 r
.57162 .82768 m .57176 .82797 L .57254 .82688 L F
.699 .638 .785 r
.56973 .82744 m .57176 .82797 L .57162 .82768 L F
.747 .659 .762 r
.57162 .82768 m .57254 .82688 L .56973 .82744 L F
.699 .638 .785 r
.56973 .82744 m .57162 .82768 L .57055 .8255 L F
.747 .659 .762 r
.56957 .82948 m .57162 .82768 L .56973 .82744 L F
.56957 .82948 m .57216 .82876 L .57162 .82768 L F
.699 .638 .785 r
.57055 .8255 m .57228 .8281 L .57111 .82416 L F
.57176 .82797 m .57228 .8281 L .57055 .8255 L F
.735 .429 .463 r
.57676 .82558 m .57551 .82592 L .57406 .8261 L F
.525 .555 .828 r
.57676 .82558 m .57406 .8261 L .57268 .82317 L F
.57676 .82558 m .57268 .82317 L .57548 .82593 L F
.57676 .82558 m .57548 .82593 L .5757 .82614 L F
.725 .528 .623 r
.57792 .8252 m .57749 .82538 L .57725 .82321 L F
.57792 .8252 m .57676 .82558 L .5757 .82614 L F
.57616 .82576 m .5757 .82614 L .57585 .82586 L F
.352 .437 .809 r
.5756 .82591 m .5757 .82614 L .57548 .82593 L F
.648 .61 .797 r
.57725 .82321 m .57587 .82582 L .57397 .82199 L F
.735 .429 .463 r
.57616 .82576 m .57585 .82586 L .57551 .82592 L F
.648 .61 .797 r
.57585 .82586 m .5757 .82614 L .5756 .82591 L F
.735 .429 .463 r
.57585 .82586 m .5757 .8259 L .57562 .82591 L F
.57585 .82586 m .57562 .82591 L .57551 .82592 L F
.648 .61 .797 r
.57587 .82582 m .57585 .82586 L .57551 .82569 L F
.57585 .82586 m .5756 .82591 L .57551 .82569 L F
.57587 .82582 m .57551 .82569 L .57397 .82199 L F
.735 .429 .463 r
.57592 .82584 m .57497 .82733 L .57254 .82688 L F
.57616 .82576 m .57607 .82589 L .57592 .82584 L F
.57607 .82589 m .57497 .82733 L .57592 .82584 L F
.57676 .82558 m .57667 .82567 L .57616 .82576 L F
.725 .528 .623 r
.57691 .82563 m .5757 .82614 L .57616 .82576 L F
.735 .429 .463 r
.57667 .82567 m .57497 .82733 L .57616 .82576 L F
.725 .528 .623 r
.57749 .82538 m .57691 .82563 L .57667 .82567 L F
.57749 .82538 m .57667 .82567 L .57726 .82545 L F
.864 .701 .678 r
.57792 .8252 m .57497 .82733 L .57667 .82567 L F
.57792 .8252 m .57667 .82567 L .57676 .82558 L F
.725 .528 .623 r
.57726 .82545 m .57667 .82567 L .57616 .82576 L F
.735 .429 .463 r
.57676 .82558 m .57616 .82576 L .57551 .82592 L F
.725 .528 .623 r
.57749 .82538 m .57585 .82586 L .57725 .82321 L F
.735 .429 .463 r
.57616 .82576 m .57574 .82589 L .5757 .8259 L F
.57574 .82589 m .57254 .82688 L .57399 .82613 L F
.57574 .82589 m .57399 .82613 L .57406 .8261 L F
.352 .437 .809 r
.57397 .82199 m .5756 .82591 L .57268 .82317 L F
.5756 .82591 m .57548 .82593 L .57268 .82317 L F
.503 .558 .845 r
.57499 .82728 m .57254 .82688 L .57497 .82733 L F
.57509 .8271 m .57294 .82691 L .57499 .82728 L F
.57294 .82691 m .57254 .82688 L .57499 .82728 L F
.699 .638 .785 r
.57228 .8281 m .574 .82855 L .57292 .82691 L F
.57251 .82684 m .57292 .82691 L .57259 .82641 L F
.57228 .8281 m .57292 .82691 L .57251 .82684 L F
.503 .558 .845 r
.57509 .8271 m .574 .82855 L .57254 .82688 L F
.699 .638 .785 r
.57228 .8281 m .57259 .82641 L .57111 .82416 L F
.901 .857 .409 r
.57216 .82876 m .57211 .82899 L .57212 .82898 L F
.57216 .82876 m .57212 .82898 L .57236 .82856 L F
.57211 .82899 m .5717 .83103 L .57236 .82856 L F
.461 0 .059 r
.56957 .82948 m .57282 .82921 L .5717 .83103 L F
.57189 .82938 m .57233 .82997 L .57273 .82935 L F
.56957 .82948 m .57163 .82984 L .57189 .82938 L F
.57163 .82984 m .57233 .82997 L .57189 .82938 L F
.57267 .82922 m .57273 .82935 L .57282 .82921 L F
.56957 .82948 m .57273 .82935 L .57267 .82922 L F
.561 .804 .99 r
.70446 .73888 m .70372 .73901 L .70061 .73857 L F
.609 .47 .668 r
.70592 .73845 m .70587 .74086 L .70372 .73901 L F
.70592 .73845 m .70587 .74086 L .70372 .73901 L F
.583 .394 .59 r
.70592 .73845 m .70372 .73901 L .70446 .73888 L F
.965 .768 .589 r
.57992 .79055 m .57889 .78832 L .58089 .78981 L F
.615 .42 .595 r
.44382 .8733 m .44626 .87412 L .44615 .87115 L F
.607 .49 .694 r
.44615 .87115 m .44846 .87101 L .4479 .86796 L F
.655 .452 .596 r
.44615 .87115 m .44863 .87345 L .44846 .87101 L F
.44615 .87115 m .44626 .87412 L .44863 .87345 L F
.696 .377 .432 r
.38366 .74932 m .38007 .74938 L .38122 .74871 L F
.59 .159 .19 r
.6711 .70803 m .67409 .70664 L .67187 .70718 L F
.557 .641 .889 r
.32114 .6592 m .32058 .6616 L .31926 .65972 L F
.32114 .6592 m .32261 .66134 L .32058 .6616 L F
.819 .481 .417 r
.49315 .88387 m .49224 .88163 L .48955 .88094 L F
.544 .352 .571 r
.49315 .88387 m .49459 .88134 L .49224 .88163 L F
.806 .74 .79 r
.56353 .77834 m .56049 .77917 L .56227 .77836 L F
.455 0 0 r
.56227 .77836 m .56569 .77782 L .56353 .77834 L F
.527 .492 .761 r
.33291 .67143 m .33177 .67475 L .33107 .67312 L F
.33291 .67143 m .33363 .67445 L .33177 .67475 L F
.749 .467 .505 r
.58963 .78599 m .59295 .78818 L .59286 .78619 L F
.712 .435 .503 r
.59295 .78818 m .59502 .7885 L .59286 .78619 L F
.681 .438 .548 r
.59286 .78619 m .59502 .7885 L .59521 .78632 L F
.789 .559 .588 r
.54481 .83114 m .54476 .83352 L .54157 .83289 L F
0 0 0 r
.38919 .89032 m .38812 .89115 L .38896 .89069 L F
.18 .21 .655 r
.38812 .89115 m .38893 .89281 L .38896 .89069 L F
.106 .586 .909 r
.49724 .8663 m .49441 .86537 L .4964 .86752 L F
.728 .332 .299 r
.4964 .86752 m .49982 .86801 L .49724 .8663 L F
.778 .373 .287 r
.67991 .71743 m .68183 .72038 L .68253 .71913 L F
.078 .155 .644 r
.68092 .7165 m .68183 .72038 L .67991 .71743 L F
.881 .483 .034 r
.67268 .71997 m .67189 .71926 L .67109 .71723 L F
.881 .446 .092 r
.67268 .71997 m .67249 .72111 L .67189 .71926 L F
.67268 .71997 m .67377 .72213 L .67249 .72111 L F
.664 .709 .881 r
.685 .69393 m .68616 .69679 L .68392 .69663 L F
.706 .489 .592 r
.68037 .69643 m .6835 .69725 L .68392 .69663 L F
.752 .551 .624 r
.6835 .69725 m .68342 .69801 L .68295 .69806 L F
.68392 .69663 m .68367 .69733 L .6835 .69725 L F
.68367 .69733 m .68342 .69801 L .6835 .69725 L F
.68392 .69663 m .68304 .69706 L .68037 .69643 L F
.588 .662 .889 r
.68058 .696 m .68304 .69706 L .68037 .69643 L F
.68304 .69706 m .6835 .69725 L .68037 .69643 L F
.752 .551 .624 r
.68304 .69706 m .68053 .69828 L .68037 .69643 L F
.68392 .69663 m .68295 .69806 L .68053 .69828 L F
.588 .662 .889 r
.68164 .69384 m .68374 .69732 L .6835 .69725 L F
.68164 .69384 m .6835 .69725 L .68058 .696 L F
.706 .489 .592 r
.6835 .69725 m .68374 .69732 L .68392 .69663 L F
0 0 0 r
.68594 .69698 m .68392 .69663 L .68616 .69679 L F
.664 .709 .881 r
.685 .69393 m .68392 .69663 L .68374 .69732 L F
.656 .25 .263 r
.68164 .69384 m .685 .69393 L .68385 .69703 L F
.68358 .69704 m .68385 .69703 L .68374 .69732 L F
.68164 .69384 m .68385 .69703 L .68358 .69704 L F
0 0 0 r
.68553 .69734 m .68478 .69701 L .68594 .69698 L F
.68478 .69701 m .68392 .69663 L .68594 .69698 L F
.843 .794 .804 r
.68797 .6936 m .68616 .69679 L .685 .69393 L F
.782 .415 .362 r
.68616 .69679 m .68919 .69859 L .68804 .69615 L F
.68616 .69679 m .68804 .69615 L .68553 .69734 L F
.839 .767 .783 r
.60874 .8232 m .6114 .82277 L .61081 .82039 L F
.84 .744 .758 r
.60874 .8232 m .6097 .82591 L .6114 .82277 L F
.747 .599 .692 r
.51595 .85247 m .51694 .85496 L .51388 .85502 L F
.631 .712 .905 r
.66037 .74232 m .66152 .7404 L .65951 .74066 L F
.66037 .74232 m .66267 .74177 L .66152 .7404 L F
.566 .343 .536 r
.53374 .86826 m .5357 .86901 L .53546 .86776 L F
.53374 .86826 m .53342 .87014 L .5357 .86901 L F
.408 .145 .4 r
.66065 .73476 m .66299 .7346 L .66303 .73182 L F
.439 .273 .558 r
.66299 .7346 m .6648 .73218 L .66303 .73182 L F
0 0 0 r
.68553 .69734 m .68342 .69801 L .68392 .69663 L F
.372 0 0 r
.69576 .74317 m .69287 .74172 L .69216 .7415 L F
.399 .77 .993 r
.45892 .88078 m .46214 .88127 L .46092 .88057 L F
.336 0 0 r
.46214 .88127 m .46468 .8807 L .46426 .88114 L F
.387 .764 .991 r
.46214 .88127 m .46426 .88114 L .46092 .88057 L F
.772 .669 .749 r
.71111 .74442 m .70929 .74114 L .709 .7432 L F
.71111 .74442 m .71275 .74157 L .70929 .74114 L F
.645 .51 .684 r
.34166 .68801 m .33971 .69064 L .33995 .68846 L F
.733 .74 .857 r
.51772 .84976 m .51595 .85247 L .5154 .85002 L F
.841 .757 .77 r
.6399 .74075 m .64326 .73906 L .64212 .73821 L F
.6399 .74075 m .64143 .74185 L .64326 .73906 L F
.965 .768 .589 r
.57992 .79055 m .57852 .79074 L .57889 .78832 L F
.749 .479 .523 r
.68037 .69643 m .67728 .69827 L .678 .69609 L F
.68037 .69643 m .68053 .69828 L .67728 .69827 L F
.866 .65 .608 r
.678 .69609 m .67947 .69718 L .68037 .69643 L F
.588 .662 .889 r
.68164 .69384 m .68037 .69643 L .67947 .69718 L F
.796 .702 .761 r
.63559 .74587 m .63896 .7443 L .63769 .74346 L F
.63559 .74587 m .63689 .74696 L .63896 .7443 L F
.802 .768 .821 r
.63896 .7443 m .6399 .74075 L .63769 .74346 L F
.63896 .7443 m .64143 .74185 L .6399 .74075 L F
.741 .627 .733 r
.58043 .81803 m .58328 .81835 L .58246 .81531 L F
.382 .398 .753 r
.58246 .81531 m .58328 .81835 L .58497 .81742 L F
0 0 0 r
.58668 .82906 m .58834 .82648 L .58629 .82905 L F
.994 .876 .575 r
.58771 .82431 m .58834 .82648 L .58668 .82906 L F
.43 .142 .372 r
.4165 .76249 m .41834 .76208 L .41897 .75972 L F
.445 .156 .378 r
.41897 .75972 m .42029 .76155 L .4208 .75915 L F
.41897 .75972 m .41834 .76208 L .42029 .76155 L F
.949 .668 .473 r
.49326 .8734 m .49222 .87599 L .49228 .87307 L F
.49326 .8734 m .4935 .87585 L .49222 .87599 L F
.918 .575 .373 r
.66888 .73331 m .66941 .73546 L .67077 .73586 L F
.908 .664 .557 r
.66919 .73781 m .67077 .73586 L .66941 .73546 L F
.66919 .73781 m .67063 .73873 L .67077 .73586 L F
.593 .178 .225 r
.54981 .80931 m .5528 .80782 L .55012 .80696 L F
.54981 .80931 m .55311 .80889 L .5528 .80782 L F
.669 .717 .885 r
.68939 .75317 m .68656 .75169 L .68744 .75345 L F
0 0 .563 r
.55304 .83301 m .55297 .83428 L .55214 .83085 L F
.876 .624 .098 r
.55304 .83301 m .55364 .83606 L .55297 .83428 L F
.88 .924 .849 r
.57933 .82585 m .5772 .82852 L .57842 .82828 L F
.048 0 0 r
.37807 .79809 m .37792 .79741 L .37958 .7964 L F
.37807 .79809 m .37628 .79863 L .37792 .79741 L F
.711 .765 .895 r
.71442 .71479 m .71666 .71389 L .71795 .71565 L F
.71442 .71479 m .71666 .71389 L .71795 .71565 L F
.511 .678 .94 r
.71877 .71371 m .71795 .71565 L .71981 .71445 L F
.71877 .71371 m .71666 .71389 L .71795 .71565 L F
.71877 .71371 m .71795 .71565 L .71981 .71445 L F
.71877 .71371 m .71666 .71389 L .71795 .71565 L F
.573 .44 .662 r
.48725 .84686 m .48781 .84981 L .48549 .8499 L F
0 0 0 r
.35274 .80958 m .35484 .80873 L .35383 .80957 L F
.35173 .81015 m .35274 .80958 L .35383 .80957 L F
.41 0 0 r
.40178 .74397 m .39855 .74486 L .40021 .74392 L F
.907 .618 .122 r
.55128 .82785 m .55214 .83085 L .55181 .8287 L F
.581 .573 .809 r
.5388 .7915 m .53977 .7882 L .54104 .78871 L F
.553 .362 .577 r
.54104 .78871 m .54098 .79126 L .5388 .7915 L F
.97 .725 .51 r
.53977 .7882 m .54098 .79126 L .54104 .78871 L F
.541 .304 .505 r
.43338 .76239 m .43312 .76425 L .43118 .76463 L F
.504 .216 .409 r
.43557 .7624 m .43312 .76425 L .43338 .76239 L F
.727 .452 .511 r
.52511 .86274 m .52362 .86523 L .52237 .86256 L F
.534 .412 .661 r
.5264 .8152 m .5262 .81206 L .52735 .81344 L F
.714 .772 .898 r
.52926 .81255 m .52735 .81344 L .5262 .81206 L F
.708 .354 .375 r
.52735 .81344 m .52948 .81519 L .5264 .8152 L F
.564 .403 .622 r
.45103 .85737 m .45308 .85469 L .45083 .85497 L F
.715 .764 .891 r
.70929 .74114 m .71275 .74157 L .71133 .74044 L F
.744 .767 .871 r
.71133 .74044 m .71275 .74157 L .71358 .74058 L F
.642 .517 .696 r
.49334 .88602 m .49315 .88387 L .49279 .88656 L F
.49334 .88602 m .49553 .88533 L .4957 .88404 L F
.251 .453 .863 r
.32789 .66525 m .3271 .66587 L .32572 .66426 L F
.32789 .66525 m .32903 .66689 L .3271 .66587 L F
.522 .105 .19 r
.37377 .78534 m .37601 .78535 L .37741 .78361 L F
.463 .081 .228 r
.37601 .78535 m .37937 .78316 L .37741 .78361 L F
.61 .804 .974 r
.49249 .8365 m .4896 .837 L .48964 .83608 L F
.492 .231 .446 r
.40162 .76952 m .40351 .76913 L .40395 .76717 L F
.146 0 0 r
.40395 .76717 m .40578 .7668 L .40656 .76558 L F
.429 .244 .526 r
.40351 .76913 m .40578 .7668 L .40395 .76717 L F
.417 0 .081 r
.36129 .72761 m .36337 .72746 L .36474 .72597 L F
.46 .034 .142 r
.36337 .72746 m .36682 .72584 L .36474 .72597 L F
.724 .208 0 r
.53873 .81481 m .54084 .81707 L .54108 .81583 L F
.512 0 0 r
.54108 .81583 m .54174 .81695 L .54345 .81731 L F
.54108 .81583 m .54084 .81707 L .54174 .81695 L F
.594 .023 0 r
.54108 .81583 m .54345 .81731 L .54512 .81772 L F
.154 0 0 r
.55296 .77894 m .55367 .77962 L .55508 .7778 L F
.55296 .77894 m .55166 .78022 L .55367 .77962 L F
0 .253 .693 r
.3981 .72306 m .39722 .72273 L .39572 .72219 L F
.08 0 0 r
.3981 .72306 m .39648 .72302 L .39838 .72312 L F
.088 .62 .867 r
.3981 .72306 m .39988 .72319 L .40158 .72372 L F
.08 0 0 r
.3981 .72306 m .39838 .72312 L .39988 .72319 L F
0 .253 .693 r
.3981 .72306 m .39925 .72398 L .3976 .72296 L F
.3981 .72306 m .3976 .72296 L .39722 .72273 L F
0 0 0 r
.58668 .82906 m .58629 .82905 L .58543 .82836 L F
.971 .855 .668 r
.58543 .82836 m .58629 .82905 L .58479 .83049 L F
.651 .575 .756 r
.47043 .85756 m .46862 .85869 L .46712 .85491 L F
.581 .573 .809 r
.5388 .7915 m .54098 .79126 L .53977 .7882 L F
.815 .632 .654 r
.58842 .79973 m .58778 .80191 L .58633 .79895 L F
.73 .539 .633 r
.59163 .80188 m .58778 .80191 L .58842 .79973 L F
.908 .882 .797 r
.54971 .85248 m .55154 .84966 L .55036 .84907 L F
.595 .389 .572 r
.44461 .86527 m .4469 .86494 L .44686 .86298 L F
.637 .496 .674 r
.44686 .86298 m .44944 .86279 L .44896 .86007 L F
.585 .355 .533 r
.4469 .86494 m .44944 .86279 L .44686 .86298 L F
.907 .96 .632 r
.68947 .74497 m .68946 .74618 L .69009 .74437 L F
.656 .282 .324 r
.68946 .74618 m .68777 .7482 L .68572 .74732 L F
.907 .96 .632 r
.68947 .74497 m .68777 .7482 L .68946 .74618 L F
.564 .819 .993 r
.36911 .75107 m .37047 .7519 L .37245 .75137 L F
.565 .521 .766 r
.63027 .7439 m .63153 .74042 L .62931 .74076 L F
.63027 .7439 m .63237 .7435 L .63153 .74042 L F
.679 .591 .749 r
.63051 .74625 m .63237 .7435 L .63027 .7439 L F
.572 .445 .669 r
.45454 .84685 m .45678 .84694 L .45625 .8439 L F
.56 .409 .633 r
.45454 .84685 m .45678 .84925 L .45678 .84694 L F
.45454 .84685 m .45473 .8496 L .45678 .84925 L F
.74 .495 .559 r
.59299 .80421 m .59163 .80188 L .59294 .80225 L F
.332 .57 .927 r
.457 .87987 m .45742 .87892 L .45541 .87873 L F
.457 .87987 m .45892 .88078 L .45742 .87892 L F
.264 0 0 r
.66294 .71135 m .66351 .7093 L .665 .71031 L F
.66294 .71135 m .66578 .71072 L .66351 .7093 L F
.564 .889 .988 r
.39178 .72302 m .38829 .72327 L .39053 .72238 L F
.681 .888 .974 r
.39459 .72199 m .39178 .72302 L .39053 .72238 L F
.41 0 0 r
.40178 .74397 m .4004 .74504 L .39855 .74486 L F
.369 0 .04 r
.40368 .74337 m .4004 .74504 L .40178 .74397 L F
.71 .453 .534 r
.52007 .83129 m .52004 .83369 L .51668 .83339 L F
.191 0 .319 r
.52133 .8305 m .52007 .83129 L .52196 .82845 L F
.285 .118 .47 r
.52133 .8305 m .52004 .83369 L .52007 .83129 L F
.717 .597 .721 r
.52 .82891 m .52007 .83129 L .52196 .82845 L F
.388 0 0 r
.63875 .72386 m .64207 .72318 L .63955 .72433 L F
.827 .601 .596 r
.4965 .85418 m .49994 .85271 L .49616 .852 L F
.4965 .85418 m .49928 .85482 L .49994 .85271 L F
.323 .093 .402 r
.49994 .85271 m .49928 .85482 L .50175 .85173 L F
.907 .646 .531 r
.57586 .80999 m .57438 .81003 L .57428 .80713 L F
.325 .808 .883 r
.57586 .80999 m .57579 .80937 L .57438 .81003 L F
.618 .936 .716 r
.57665 .80897 m .57579 .80937 L .57586 .80999 L F
.766 .496 .525 r
.57933 .82585 m .57726 .82813 L .57792 .8252 L F
.57933 .82585 m .57842 .82828 L .57726 .82813 L F
.465 .792 .999 r
.58058 .82504 m .57933 .82585 L .57792 .8252 L F
.333 .055 .333 r
.5807 .82729 m .57933 .82585 L .58058 .82504 L F
.796 .309 0 r
.582 .82885 m .57933 .82585 L .57842 .82828 L F
.333 .055 .333 r
.5807 .82729 m .57842 .82828 L .57933 .82585 L F
.813 .733 .775 r
.60682 .82558 m .6097 .82591 L .60874 .8232 L F
.895 .858 .797 r
.60669 .82789 m .6097 .82591 L .60682 .82558 L F
.60669 .82789 m .60804 .82859 L .6097 .82591 L F
.97 .835 .423 r
.49135 .84651 m .49188 .84365 L .4884 .84371 L F
.49135 .84651 m .49075 .84649 L .49188 .84365 L F
.301 0 0 r
.49272 .84174 m .49362 .84213 L .49438 .84085 L F
0 .127 .659 r
.49188 .84365 m .49296 .84318 L .49165 .84122 L F
.49188 .84365 m .49165 .84122 L .49111 .84095 L F
.302 .28 .668 r
.49084 .84 m .49296 .84318 L .49272 .84087 L F
.953 .757 .6 r
.49272 .84087 m .49296 .84318 L .49151 .84239 L F
.301 0 0 r
.49151 .84239 m .49353 .84214 L .49272 .84174 L F
.49353 .84214 m .49362 .84213 L .49272 .84174 L F
0 .127 .659 r
.49111 .84095 m .49165 .84122 L .49084 .84 L F
.164 0 .116 r
.49188 .84365 m .49264 .84549 L .49296 .84318 L F
.49188 .84365 m .49075 .84649 L .49264 .84549 L F
.614 .422 .598 r
.51152 .85493 m .5115 .85754 L .50949 .85753 L F
.653 .386 .503 r
.51152 .85493 m .51362 .85707 L .5115 .85754 L F
.51152 .85493 m .51388 .85502 L .51362 .85707 L F
.82 .7 .733 r
.67166 .75941 m .67454 .75954 L .67349 .75659 L F
.782 .683 .754 r
.67349 .75659 m .67454 .75954 L .67518 .75787 L F
.927 .742 .632 r
.47582 .85987 m .47695 .86267 L .4773 .86031 L F
.209 .638 .951 r
.69317 .75396 m .69435 .75358 L .69237 .75322 L F
.69317 .75396 m .69537 .75435 L .69435 .75358 L F
.652 .541 .716 r
.47395 .85855 m .47043 .85756 L .47291 .85785 L F
.56 .248 .397 r
.4635 .8411 m .46624 .83883 L .46374 .83912 L F
.4635 .8411 m .46571 .84112 L .46624 .83883 L F
.551 .305 .496 r
.46571 .84112 m .46822 .83873 L .46624 .83883 L F
.246 .761 .808 r
.51425 .83086 m .51539 .83062 L .51657 .82848 L F
.359 .12 .409 r
.51657 .82848 m .51762 .82997 L .5175 .82757 L F
.51657 .82848 m .51539 .83062 L .51762 .82997 L F
.646 .163 .09 r
.4926 .82276 m .496 .82338 L .49408 .82256 L F
.751 .679 .781 r
.63361 .74681 m .63689 .74696 L .63559 .74587 L F
.958 .763 .597 r
.60766 .8309 m .60804 .82859 L .60669 .82789 L F
.737 .533 .617 r
.59502 .7885 m .59829 .7862 L .59521 .78632 L F
.484 .822 .999 r
.58299 .84612 m .5839 .84672 L .58587 .84633 L F
0 .569 .748 r
.5839 .84672 m .58673 .84692 L .58587 .84633 L F
0 0 .133 r
.54736 .84406 m .54787 .84729 L .54769 .84606 L F
.52 0 0 r
.54787 .84729 m .54921 .8485 L .54769 .84606 L F
.54787 .84729 m .55036 .84907 L .54921 .8485 L F
.529 .464 .727 r
.43541 .73747 m .43418 .74127 L .43348 .73774 L F
.43541 .73747 m .43611 .74106 L .43418 .74127 L F
.608 .533 .745 r
.43611 .74106 m .43441 .74356 L .43418 .74127 L F
.679 .747 .903 r
.40845 .7266 m .40919 .72765 L .40572 .72713 L F
.51 .703 .957 r
.41094 .72631 m .40919 .72765 L .40845 .7266 L F
.41094 .72631 m .41155 .72753 L .40919 .72765 L F
.365 .19 .506 r
.64324 .71477 m .64498 .71419 L .64501 .71203 L F
.749 .674 .778 r
.64345 .71765 m .64498 .71419 L .64324 .71477 L F
.737 .533 .617 r
.59502 .7885 m .59831 .78858 L .59829 .7862 L F
.398 .096 .332 r
.6561 .63561 m .65575 .63723 L .65363 .63795 L F
.477 .159 .348 r
.6561 .63561 m .65794 .63682 L .65575 .63723 L F
.6561 .63561 m .65838 .63522 L .65794 .63682 L F
.386 .078 .316 r
.40082 .78502 m .39946 .78401 L .4015 .78377 L F
.40082 .78502 m .39887 .78565 L .39946 .78401 L F
.606 .217 .279 r
.50431 .88668 m .50768 .88652 L .50631 .88785 L F
.504 0 0 r
.50768 .88652 m .50834 .88751 L .50631 .88785 L F
.50768 .88652 m .50995 .88686 L .50834 .88751 L F
.682 .265 .248 r
.52757 .84159 m .52907 .84334 L .53107 .84214 L F
.791 .937 .925 r
.5364 .83584 m .53417 .83628 L .53397 .83331 L F
0 0 .463 r
.53962 .83657 m .5364 .83584 L .53945 .83268 L F
.771 .72 .805 r
.68804 .69615 m .68919 .69859 L .69131 .69625 L F
.668 .673 .845 r
.68553 .69734 m .68919 .69859 L .68804 .69615 L F
.718 .705 .836 r
.44626 .87412 m .44705 .87566 L .44863 .87345 L F
.579 .507 .738 r
.44705 .87566 m .449 .87547 L .44863 .87345 L F
.53 .59 .858 r
.44705 .87566 m .45042 .87778 L .449 .87547 L F
.473 .533 .838 r
.49093 .86533 m .49431 .86806 L .49441 .86537 L F
.635 .373 .504 r
.49431 .86806 m .4964 .86752 L .49441 .86537 L F
.827 .743 .771 r
.50931 .83163 m .5077 .83444 L .50576 .83326 L F
.711 .648 .784 r
.52757 .84159 m .52461 .84262 L .5248 .84165 L F
.514 .328 .567 r
.52579 .84354 m .52757 .84159 L .5248 .84165 L F
.52579 .84354 m .52742 .84415 L .52757 .84159 L F
.573 .867 .995 r
.54592 .84352 m .54512 .84465 L .54736 .84406 L F
.512 .787 .995 r
.54379 .84383 m .54512 .84465 L .54592 .84352 L F
.728 .771 .887 r
.52196 .82845 m .52 .82891 L .51986 .82765 L F
.75 .325 .241 r
.52098 .82777 m .52133 .8305 L .52196 .82845 L F
.804 .517 0 r
.49286 .83836 m .49338 .83982 L .49249 .8365 L F
.822 .444 .338 r
.49286 .83836 m .4961 .84088 L .49338 .83982 L F
.866 .844 .821 r
.50414 .86274 m .50369 .86571 L .50201 .86515 L F
.79 .616 .665 r
.50369 .86571 m .50099 .86784 L .50201 .86515 L F
.50369 .86571 m .50328 .86801 L .50099 .86784 L F
.458 0 .042 r
.47968 .82959 m .48298 .8285 L .48122 .82937 L F
.12 0 0 r
.57428 .80713 m .57765 .80737 L .57799 .80732 L F
.504 .896 .746 r
.57799 .80732 m .57765 .80737 L .57904 .80643 L F
0 0 0 r
.57904 .80643 m .57665 .80897 L .57799 .80732 L F
.535 .078 .115 r
.56664 .78156 m .56569 .78281 L .56352 .78262 L F
.634 .189 .177 r
.56903 .7829 m .56569 .78281 L .56664 .78156 L F
.693 .737 .884 r
.70189 .73577 m .70446 .73888 L .70061 .73857 L F
.731 .747 .865 r
.70506 .73628 m .70446 .73888 L .70189 .73577 L F
.583 .394 .59 r
.70592 .73845 m .70446 .73888 L .70506 .73628 L F
0 .357 .68 r
.41155 .72753 m .41458 .72863 L .41229 .72918 L F
.404 0 .085 r
.57885 .83069 m .582 .82885 L .57842 .82828 L F
.57885 .83069 m .58162 .8303 L .582 .82885 L F
.349 .439 .813 r
.58387 .82772 m .58479 .83049 L .582 .82885 L F
.58387 .82772 m .582 .82885 L .58162 .8303 L F
.626 .479 .663 r
.66369 .74649 m .66165 .74918 L .66352 .74848 L F
.222 0 0 r
.53102 .83421 m .5272 .83503 L .52849 .83371 L F
.996 .789 .511 r
.50367 .88462 m .50431 .88668 L .50123 .88574 L F
.778 .344 .221 r
.50123 .88574 m .50431 .88668 L .50322 .88779 L F
.617 .139 .095 r
.50322 .88779 m .50431 .88668 L .50631 .88785 L F
.094 .538 .909 r
.4894 .86694 m .49211 .86829 L .49093 .86533 L F
.473 .533 .838 r
.49093 .86533 m .49211 .86829 L .49431 .86806 L F
.467 .385 .681 r
.49211 .86829 m .4943 .8703 L .49431 .86806 L F
.827 .743 .771 r
.50931 .83163 m .50576 .83326 L .50855 .83056 L F
.768 .82 .894 r
.51102 .83047 m .50931 .83163 L .50855 .83056 L F
.484 .173 .362 r
.42626 .76812 m .4257 .76972 L .42363 .76999 L F
.483 .189 .389 r
.42824 .76768 m .4257 .76972 L .42626 .76812 L F
.497 .228 .437 r
.3413 .76206 m .33898 .76377 L .33964 .76239 L F
.531 .6 .867 r
.6525 .72103 m .65472 .72071 L .65425 .71907 L F
.034 .506 .882 r
.71909 .72675 m .7185 .72703 L .7169 .72757 L F
.71909 .72675 m .7206 .72774 L .7185 .72703 L F
.632 .683 .88 r
.69009 .74437 m .69407 .74642 L .69364 .74504 L F
.908 .799 .728 r
.66822 .73063 m .66888 .73331 L .66962 .73124 L F
.317 0 0 r
.51102 .83047 m .51315 .83094 L .51425 .83086 L F
.246 .761 .808 r
.51425 .83086 m .51315 .83094 L .51539 .83062 L F
.618 .629 .839 r
.66424 .6272 m .66556 .63002 L .66321 .63015 L F
.538 .26 .44 r
.66556 .63002 m .66324 .63195 L .66321 .63015 L F
.537 .294 .494 r
.66321 .63015 m .66324 .63195 L .66096 .63212 L F
.722 .336 .317 r
.48988 .85752 m .48885 .85934 L .48663 .85723 L F
.622 .22 .261 r
.4915 .8579 m .48885 .85934 L .48988 .85752 L F
.758 .488 .525 r
.38366 .74932 m .37991 .75101 L .38007 .74938 L F
.38366 .74932 m .38318 .75122 L .37991 .75101 L F
.573 .372 .57 r
.38555 .74867 m .38318 .75122 L .38366 .74932 L F
.177 0 .194 r
.38915 .79082 m .38669 .79338 L .38744 .79158 L F
.338 0 .163 r
.38939 .77587 m .38664 .77768 L .38863 .77715 L F
.371 0 .18 r
.38863 .77715 m .39135 .77545 L .38939 .77587 L F
.424 0 .118 r
.65478 .70832 m .65786 .70665 L .65571 .70951 L F
.608 .443 .633 r
.65786 .70665 m .65828 .70931 L .65571 .70951 L F
.431 .365 .682 r
.65796 .71139 m .65571 .70951 L .65828 .70931 L F
.65796 .71139 m .65642 .71209 L .65571 .70951 L F
.532 .517 .784 r
.43482 .73601 m .43348 .73774 L .43288 .73639 L F
.43482 .73601 m .43541 .73747 L .43348 .73774 L F
.351 .277 .632 r
.65807 .72511 m .66048 .72426 L .65981 .72212 L F
.133 0 .102 r
.65807 .72511 m .65803 .72652 L .66048 .72426 L F
.596 .707 .921 r
.42329 .73197 m .42125 .73247 L .41974 .73057 L F
.986 .854 .625 r
.48955 .88094 m .49036 .87871 L .4901 .87914 L F
.756 .813 .898 r
.67767 .71198 m .68066 .71187 L .67842 .71249 L F
.913 .582 .404 r
.54512 .81772 m .54622 .82066 L .54743 .82092 L F
.817 .355 .127 r
.54622 .82066 m .54693 .82193 L .54743 .82092 L F
.844 .394 .143 r
.54693 .82193 m .54857 .82261 L .54743 .82092 L F
.84 .617 .601 r
.65479 .71628 m .65411 .71767 L .65328 .71509 L F
.611 .495 .696 r
.65642 .71209 m .65701 .71569 L .65479 .71628 L F
0 0 0 r
.65625 .71448 m .65479 .71628 L .65701 .71569 L F
.65625 .71448 m .65411 .71767 L .65479 .71628 L F
.543 .915 .752 r
.71947 .73182 m .71755 .73319 L .71829 .73288 L F
.424 0 .118 r
.65478 .70832 m .65698 .70835 L .65786 .70665 L F
.675 .254 .238 r
.65786 .70665 m .65992 .70842 L .66003 .70643 L F
.436 .323 .627 r
.65992 .70842 m .65828 .70931 L .65786 .70665 L F
.675 .254 .238 r
.65786 .70665 m .65698 .70835 L .65992 .70842 L F
.436 .323 .627 r
.65992 .70842 m .65786 .70665 L .66003 .70643 L F
.825 .643 .656 r
.67518 .75787 m .67364 .75435 L .67349 .75659 L F
.496 .251 .472 r
.39905 .77044 m .40078 .77216 L .40162 .76952 L F
.39905 .77044 m .39877 .77257 L .40078 .77216 L F
0 0 0 r
.48838 .8258 m .48918 .82492 L .49056 .82334 L F
.317 .646 .968 r
.48838 .8258 m .49301 .82737 L .48918 .82492 L F
.559 .719 .948 r
.42508 .73253 m .42446 .73434 L .42329 .73197 L F
.42508 .73253 m .42653 .73403 L .42446 .73434 L F
.435 .155 .388 r
.62888 .73861 m .63105 .73848 L .6316 .73626 L F
0 0 0 r
.63349 .73353 m .6316 .73626 L .63306 .73421 L F
.526 .238 .42 r
.6316 .73626 m .63322 .73786 L .63306 .73421 L F
.6316 .73626 m .63105 .73848 L .63322 .73786 L F
0 0 0 r
.50758 .88335 m .50857 .88164 L .50648 .8839 L F
.702 .956 .95 r
.68629 .72117 m .68506 .72149 L .68298 .72244 L F
.655 .5 .661 r
.684 .72516 m .68629 .72117 L .68298 .72244 L F
.684 .72516 m .68641 .72502 L .68629 .72117 L F
.364 .419 .784 r
.68629 .72117 m .68747 .72001 L .68506 .72149 L F
.68629 .72117 m .6886 .72266 L .68747 .72001 L F
.499 .377 .645 r
.68629 .72117 m .68848 .72469 L .6886 .72266 L F
.68629 .72117 m .68641 .72502 L .68848 .72469 L F
.481 .421 .713 r
.51687 .84647 m .51502 .84735 L .51458 .84457 L F
.581 .395 .594 r
.51687 .84647 m .5146 .84911 L .51502 .84735 L F
.507 .451 .728 r
.42481 .7486 m .42634 .74688 L .42424 .74736 L F
.42481 .7486 m .4267 .74858 L .42634 .74688 L F
.721 .304 .253 r
.4085 .76447 m .41029 .76645 L .41176 .76501 L F
.5 .064 .142 r
.41029 .76645 m .41396 .76485 L .41176 .76501 L F
.629 .78 .953 r
.4768 .86476 m .47453 .86606 L .47405 .86466 L F
.635 .829 .975 r
.5184 .81751 m .51953 .81856 L .52186 .81769 L F
.536 .01 0 r
.46956 .88102 m .4732 .88114 L .47131 .88147 L F
.556 .038 0 r
.47131 .88147 m .4732 .88114 L .47465 .88199 L F
.612 .098 0 r
.64484 .72259 m .6454 .72483 L .64392 .72207 L F
.64484 .72259 m .64677 .72441 L .6454 .72483 L F
.379 .193 .498 r
.6454 .72483 m .64677 .72441 L .64533 .72748 L F
0 0 0 r
.40925 .74201 m .40782 .74242 L .40574 .74273 L F
.163 .697 .844 r
.412 .74242 m .40782 .74242 L .40925 .74201 L F
.303 0 0 r
.36682 .72584 m .36898 .72561 L .37002 .7248 L F
.199 0 0 r
.36898 .72561 m .3721 .72515 L .37002 .7248 L F
.669 .717 .885 r
.68939 .75317 m .68913 .75118 L .68656 .75169 L F
.734 .34 .303 r
.57962 .78075 m .58201 .78291 L .58319 .78128 L F
.715 .316 .29 r
.58201 .78291 m .58513 .78329 L .58319 .78128 L F
.733 .303 .228 r
.58319 .78128 m .58513 .78329 L .58644 .7829 L F
.729 .551 .65 r
.60487 .79381 m .60698 .79128 L .60505 .79149 L F
.60487 .79381 m .60834 .79413 L .60698 .79128 L F
.613 .462 .653 r
.44896 .86007 m .45118 .86002 L .45103 .85737 L F
.547 .397 .629 r
.44944 .86279 m .45118 .86002 L .44896 .86007 L F
0 0 0 r
.50066 .8622 m .50164 .86042 L .50291 .85865 L F
.482 .403 .691 r
.33162 .66585 m .33039 .66976 L .32903 .66689 L F
.33162 .66585 m .33213 .66953 L .33039 .66976 L F
.53 .459 .72 r
.33291 .67143 m .33039 .66976 L .33213 .66953 L F
.33291 .67143 m .33107 .67312 L .33039 .66976 L F
.727 .892 .955 r
.55826 .8091 m .55622 .81035 L .55474 .80969 L F
.037 0 0 r
.40578 .7668 m .4085 .76447 L .40656 .76558 L F
.759 .565 .635 r
.61127 .79892 m .61141 .79671 L .60817 .79643 L F
.503 .31 .551 r
.47834 .87034 m .47546 .87095 L .4784 .86777 L F
.95 .757 .608 r
.47834 .87034 m .47697 .87226 L .47546 .87095 L F
.481 .421 .713 r
.51687 .84647 m .51458 .84457 L .51677 .84411 L F
.711 .832 .94 r
.35099 .66681 m .34861 .66694 L .35107 .6659 L F
.35107 .6659 m .34861 .66694 L .35099 .66681 L F
.372 .524 .879 r
.35107 .6659 m .35268 .66607 L .35099 .66681 L F
.35099 .66681 m .35268 .66607 L .35107 .6659 L F
.35099 .66681 m .35268 .66607 L .35107 .6659 L F
.746 .393 .383 r
.54652 .80435 m .54844 .80667 L .54968 .80473 L F
.875 .569 .466 r
.54968 .80473 m .54844 .80667 L .55012 .80696 L F
.346 0 .111 r
.38494 .79365 m .38364 .79557 L .38158 .79596 L F
.517 .151 .285 r
.38669 .79338 m .38364 .79557 L .38494 .79365 L F
.634 .572 .767 r
.44461 .86527 m .4479 .86796 L .4469 .86494 L F
.167 .679 .897 r
.59163 .8461 m .59472 .84656 L .59365 .84645 L F
.441 .852 .964 r
.59472 .84656 m .59563 .84579 L .59365 .84645 L F
.59472 .84656 m .59658 .84614 L .59563 .84579 L F
.331 .503 .877 r
.69494 .72518 m .69316 .72268 L .6945 .72389 L F
.325 0 0 r
.69494 .72518 m .69398 .72635 L .69205 .72636 L F
.416 .62 .936 r
.69622 .72402 m .69494 .72518 L .6945 .72389 L F
.889 .561 .42 r
.71538 .73642 m .71563 .73609 L .71349 .73586 L F
.71538 .73642 m .71677 .73833 L .71563 .73609 L F
.797 .635 .681 r
.6723 .75138 m .67364 .75435 L .67375 .75211 L F
.545 .832 .998 r
.42901 .73433 m .42653 .73403 L .42858 .73347 L F
.417 .566 .895 r
.43042 .73286 m .42901 .73433 L .42858 .73347 L F
.43042 .73286 m .43179 .73503 L .42901 .73433 L F
.866 .811 .794 r
.55725 .80696 m .55897 .80756 L .56058 .80458 L F
.371 .199 .514 r
.56058 .80458 m .55897 .80756 L .56063 .80675 L F
.269 .012 .327 r
.55897 .80756 m .55826 .8091 L .56063 .80675 L F
.442 .089 .27 r
.3493 .73266 m .35127 .73235 L .35206 .73099 L F
.352 0 .218 r
.35206 .73099 m .35127 .73235 L .35391 .73052 L F
.625 .358 .493 r
.59163 .80188 m .58771 .8043 L .58778 .80191 L F
.59163 .80188 m .59026 .80437 L .58771 .8043 L F
.74 .495 .559 r
.59299 .80421 m .59026 .80437 L .59163 .80188 L F
.342 .822 .842 r
.56186 .81159 m .56071 .81163 L .5596 .81223 L F
0 0 .021 r
.5596 .81365 m .5596 .81223 L .56071 .81163 L F
.5596 .81365 m .5594 .81483 L .5596 .81223 L F
.836 .755 .774 r
.68307 .73831 m .68452 .73847 L .6833 .7362 L F
.847 .586 .545 r
.68355 .73947 m .68452 .73847 L .68307 .73831 L F
.807 .779 .827 r
.68452 .73847 m .68532 .73522 L .6833 .7362 L F
.68452 .73847 m .68656 .73641 L .68532 .73522 L F
.842 .579 .54 r
.68355 .73947 m .68469 .74114 L .68452 .73847 L F
.536 .624 .886 r
.40158 .72372 m .40033 .72557 L .39925 .72398 L F
.40158 .72372 m .40218 .7254 L .40033 .72557 L F
.557 .925 .934 r
.69828 .75394 m .6994 .75289 L .69768 .754 L F
.69828 .75394 m .69977 .75314 L .6994 .75289 L F
0 .304 .798 r
.53124 .81515 m .53143 .81452 L .52948 .81519 L F
.53124 .81515 m .53321 .81695 L .53143 .81452 L F
.073 0 0 r
.35241 .75819 m .35222 .75724 L .35418 .75682 L F
.35241 .75819 m .35075 .75869 L .35222 .75724 L F
.608 .533 .745 r
.43611 .74106 m .43661 .74346 L .43441 .74356 L F
.552 .454 .697 r
.43705 .7462 m .43441 .74356 L .43661 .74346 L F
.43705 .7462 m .43505 .74663 L .43441 .74356 L F
.617 .78 .959 r
.4361 .8788 m .43388 .87953 L .43267 .87825 L F
.4361 .8788 m .43388 .87953 L .43267 .87825 L F
.607 .463 .66 r
.49301 .82737 m .49165 .82842 L .49402 .82787 L F
.663 .636 .812 r
.57775 .81742 m .58043 .81803 L .57917 .81498 L F
.856 .834 .824 r
.53964 .80404 m .53996 .80145 L .54094 .80304 L F
0 .31 .7 r
.54221 .80356 m .54094 .80304 L .53996 .80145 L F
.545 .213 .355 r
.3941 .78752 m .39329 .79036 L .39133 .79018 L F
.409 .057 .253 r
.3969 .7862 m .39579 .78857 L .3941 .78752 L F
.32 .01 .272 r
.39527 .78942 m .3941 .78752 L .39579 .78857 L F
.39527 .78942 m .39329 .79036 L .3941 .78752 L F
.826 .397 0 r
.55779 .82094 m .55786 .82188 L .55614 .8193 L F
.55779 .82094 m .55871 .82277 L .55786 .82188 L F
.824 .672 .695 r
.59486 .80501 m .59423 .80716 L .59299 .80421 L F
.891 .746 .695 r
.64863 .62624 m .65133 .62734 L .64841 .62648 L F
.65078 .6251 m .65133 .62734 L .64863 .62624 L F
.866 .794 .778 r
.64801 .6269 m .65133 .62734 L .64994 .62926 L F
.64841 .62648 m .65133 .62734 L .64801 .6269 L F
.723 .535 .636 r
.64817 .62703 m .65041 .6289 L .64829 .62677 L F
.866 .794 .778 r
.64805 .627 m .64994 .62926 L .64931 .63012 L F
.64801 .6269 m .64994 .62926 L .64805 .627 L F
.64801 .6269 m .64931 .63012 L .65041 .6289 L F
.723 .535 .636 r
.64816 .62706 m .65041 .6289 L .64817 .62703 L F
.64812 .62678 m .64816 .62706 L .64829 .62677 L F
.64798 .62692 m .64816 .62706 L .64812 .62678 L F
.951 .892 .736 r
.64776 .62628 m .64776 .62632 L .64945 .6225 L F
.64776 .62632 m .64784 .6268 L .64811 .62607 L F
.64776 .62632 m .64811 .62607 L .64945 .6225 L F
.96 .943 .652 r
.64785 .62676 m .64784 .6268 L .64785 .62669 L F
.6479 .62642 m .64789 .6265 L .64789 .62644 L F
.64945 .6225 m .64789 .6265 L .6479 .62642 L F
.64945 .6225 m .64785 .62676 L .64789 .6265 L F
.951 .892 .736 r
.64804 .62607 m .64945 .6225 L .65057 .62423 L F
.6478 .62625 m .64945 .6225 L .64804 .62607 L F
.64779 .62621 m .64945 .6225 L .6478 .62625 L F
.96 .943 .652 r
.64945 .6225 m .64839 .62519 L .64831 .6232 L F
.64839 .62519 m .64789 .62644 L .64831 .6232 L F
.272 0 0 r
.65239 .62166 m .64945 .6225 L .65057 .62423 L F
.65239 .62166 m .65205 .622 L .64945 .6225 L F
.739 .799 .9 r
.64869 .62052 m .65205 .622 L .65185 .62204 L F
.64869 .62052 m .65185 .62204 L .64945 .6225 L F
.74 .576 .671 r
.64869 .62052 m .64497 .62224 L .64709 .61962 L F
.618 .448 .629 r
.64752 .61995 m .64869 .62052 L .64709 .61962 L F
.997 .844 .566 r
.64945 .6225 m .64831 .6232 L .64869 .62052 L F
.74 .576 .671 r
.64869 .62052 m .64831 .6232 L .64497 .62224 L F
.618 .448 .629 r
.65039 .62223 m .64869 .62052 L .64752 .61995 L F
.709 .822 .935 r
.64831 .6232 m .65039 .62223 L .64827 .6221 L F
.64831 .6232 m .64827 .6221 L .6475 .62205 L F
.96 .943 .652 r
.64785 .62676 m .64785 .62669 L .64831 .6232 L F
.808 .881 .899 r
.64788 .62648 m .65039 .62223 L .64831 .6232 L F
.64784 .6268 m .64793 .62663 L .64788 .62648 L F
.64793 .62663 m .65039 .62223 L .64788 .62648 L F
.951 .892 .736 r
.64776 .62628 m .64779 .62621 L .6478 .62625 L F
.866 .794 .778 r
.64776 .62628 m .64841 .62648 L .64834 .62656 L F
.808 .881 .899 r
.64787 .62674 m .64806 .62656 L .64798 .62655 L F
.8 .996 .861 r
.64846 .62633 m .64784 .6268 L .64812 .62678 L F
.866 .794 .778 r
.64833 .62656 m .64834 .62656 L .64812 .62678 L F
.8 .996 .861 r
.6484 .62647 m .64812 .62678 L .64829 .62677 L F
.64846 .62633 m .64812 .62678 L .6484 .62647 L F
.866 .794 .778 r
.64787 .62655 m .64833 .62656 L .64801 .6269 L F
.64833 .62656 m .64812 .62678 L .64801 .6269 L F
.8 .996 .861 r
.64846 .62633 m .64827 .62643 L .64784 .6268 L F
.866 .794 .778 r
.64819 .62649 m .64808 .62656 L .64787 .62655 L F
.8 .996 .861 r
.64827 .62643 m .64813 .6265 L .64808 .62656 L F
.64827 .62643 m .64787 .62677 L .64787 .62677 L F
.891 .746 .695 r
.64878 .62553 m .6484 .62647 L .64776 .62628 L F
.808 .881 .899 r
.64798 .62655 m .65149 .62311 L .65039 .62223 L F
.891 .746 .695 r
.65057 .62423 m .6484 .62647 L .64878 .62553 L F
.808 .881 .899 r
.64806 .62656 m .65149 .62311 L .64798 .62655 L F
.64787 .62677 m .65149 .62311 L .64787 .62674 L F
.866 .794 .778 r
.64798 .6265 m .64801 .6269 L .65041 .6289 L F
.64776 .62628 m .64819 .62649 L .64787 .62655 L F
.64786 .62639 m .64793 .62662 L .64798 .6265 L F
.8 .996 .861 r
.64827 .62643 m .64808 .62656 L .64787 .62677 L F
.866 .794 .778 r
.64793 .62662 m .64801 .6269 L .64798 .6265 L F
.8 .996 .861 r
.64787 .62677 m .64787 .62677 L .64784 .6268 L F
.866 .794 .778 r
.64819 .62649 m .64834 .62656 L .64808 .62656 L F
.808 .881 .899 r
.64784 .6268 m .64787 .62677 L .64787 .62674 L F
.866 .794 .778 r
.64785 .62637 m .64786 .62642 L .64786 .62639 L F
.64786 .62642 m .64801 .6269 L .64786 .62639 L F
.64776 .62628 m .64785 .62651 L .64785 .62637 L F
.64785 .62651 m .64801 .6269 L .64785 .62637 L F
.723 .535 .636 r
.64784 .6268 m .64798 .62692 L .64812 .62678 L F
.392 .518 .866 r
.64776 .62628 m .65041 .6289 L .64784 .6268 L F
0 .331 .809 r
.64952 .62766 m .65041 .6289 L .64798 .62692 L F
.64792 .62684 m .64798 .62692 L .64784 .6268 L F
.64952 .62766 m .64798 .62692 L .64792 .62684 L F
.723 .535 .636 r
.64829 .62677 m .65041 .6289 L .65077 .6266 L F
.843 .7 .705 r
.64709 .6262 m .64814 .62935 L .64665 .62832 L F
.6 .774 .963 r
.64952 .62766 m .64814 .62935 L .64709 .6262 L F
.245 .758 .841 r
.64701 .62792 m .64952 .62766 L .64755 .62647 L F
.64706 .62682 m .64755 .62647 L .64709 .6262 L F
.64701 .62792 m .64755 .62647 L .64706 .62682 L F
.891 .746 .695 r
.64842 .62645 m .64841 .62648 L .6484 .62647 L F
.64863 .62624 m .64841 .62648 L .64842 .62645 L F
.65057 .62423 m .65078 .6251 L .64863 .62624 L F
.751 .668 .769 r
.65346 .62463 m .65133 .62734 L .65057 .62423 L F
.66 .772 .933 r
.65216 .62353 m .65346 .62463 L .65057 .62423 L F
.8 .996 .861 r
.65216 .62353 m .65149 .62311 L .64813 .6265 L F
.65216 .62353 m .64813 .6265 L .64846 .62633 L F
.65216 .62353 m .64846 .62633 L .65077 .6266 L F
.64846 .62633 m .64829 .62677 L .65077 .6266 L F
.398 .004 .17 r
.3337 .74059 m .33683 .73864 L .33452 .73939 L F
.973 .726 .504 r
.64212 .73821 m .64494 .73579 L .6447 .73657 L F
.586 .501 .725 r
.64636 .73269 m .64494 .73579 L .64414 .73319 L F
.64636 .73269 m .64706 .7349 L .64494 .73579 L F
.133 0 0 r
.64706 .7349 m .6447 .73657 L .64494 .73579 L F
.388 0 .119 r
.48918 .82492 m .4926 .82276 L .49056 .82334 L F
.631 .882 .987 r
.43928 .87863 m .4361 .8788 L .43801 .87809 L F
.43928 .87863 m .4361 .8788 L .43801 .87809 L F
.768 .36 0 r
.55075 .81258 m .55216 .81503 L .55142 .81405 L F
.888 .507 .307 r
.55425 .81722 m .55142 .81405 L .55216 .81503 L F
.675 .296 .321 r
.57104 .77817 m .57321 .77995 L .57436 .7781 L F
.733 .366 .356 r
.57321 .77995 m .57649 .78029 L .57436 .7781 L F
.413 .476 .816 r
.68646 .72966 m .6851 .73155 L .68525 .72937 L F
.68646 .72966 m .68736 .7324 L .6851 .73155 L F
.829 .76 .787 r
.6667 .73122 m .66888 .73331 L .66822 .73063 L F
.882 .553 .423 r
.66771 .73482 m .66888 .73331 L .6667 .73122 L F
.66771 .73482 m .66941 .73546 L .66888 .73331 L F
.952 .661 .448 r
.5557 .81638 m .55489 .81864 L .55425 .81722 L F
.5557 .81638 m .55614 .8193 L .55489 .81864 L F
.97 .744 .541 r
.64692 .63715 m .64817 .63805 L .6482 .64056 L F
.757 .445 .457 r
.64817 .63805 m .65089 .63978 L .6482 .64056 L F
.503 .34 .593 r
.3426 .71929 m .34071 .71739 L .34277 .71701 L F
.3426 .71929 m .34073 .7198 L .34071 .71739 L F
.3426 .71929 m .34071 .71739 L .34277 .71701 L F
.3426 .71929 m .34073 .7198 L .34071 .71739 L F
.51 .466 .744 r
.45042 .87778 m .45147 .8761 L .449 .87547 L F
.45042 .87778 m .45217 .87785 L .45147 .8761 L F
.537 .219 .377 r
.3445 .75962 m .34336 .76216 L .3413 .76206 L F
.651 .341 .433 r
.34639 .76149 m .34336 .76216 L .3445 .75962 L F
.616 .347 .487 r
.34685 .75961 m .34639 .76149 L .3445 .75962 L F
.063 .436 .874 r
.68426 .71944 m .68253 .71913 L .68183 .72038 L F
.985 .869 .639 r
.67488 .72484 m .6732 .72709 L .67358 .72433 L F
.67488 .72484 m .67404 .72785 L .6732 .72709 L F
.387 .121 .384 r
.63306 .73421 m .63506 .73246 L .63349 .73353 L F
.843 .794 .804 r
.68797 .6936 m .685 .69393 L .68675 .69505 L F
.902 .595 .455 r
.68675 .69505 m .68797 .6936 L .68653 .69342 L F
.843 .794 .804 r
.68797 .6936 m .68675 .69505 L .68804 .69615 L F
.556 .893 .984 r
.68653 .69342 m .68797 .6936 L .6892 .69245 L F
.947 .681 .5 r
.68675 .69505 m .68804 .69615 L .68797 .6936 L F
.571 .573 .816 r
.69131 .69625 m .68797 .6936 L .68804 .69615 L F
0 0 0 r
.68675 .69505 m .68797 .6936 L .6892 .69245 L F
.038 .491 .884 r
.41582 .72857 m .41868 .7298 L .41837 .73039 L F
.102 .568 .911 r
.41868 .7298 m .41974 .73057 L .41837 .73039 L F
.558 .436 .67 r
.66369 .74649 m .66606 .74617 L .66598 .74376 L F
.696 .655 .806 r
.66352 .74848 m .66606 .74617 L .66369 .74649 L F
.918 .556 .329 r
.51109 .8445 m .50977 .84461 L .50863 .84356 L F
.51109 .8445 m .51156 .84627 L .50977 .84461 L F
.9 .482 .146 r
.52237 .86256 m .52233 .86444 L .52079 .86179 L F
.52237 .86256 m .52362 .86523 L .52233 .86444 L F
.514 .25 .452 r
.43118 .76463 m .43034 .76735 L .42824 .76768 L F
.517 .251 .45 r
.43312 .76425 m .43034 .76735 L .43118 .76463 L F
.496 .245 .463 r
.66096 .63212 m .66059 .63486 L .65838 .63522 L F
.525 .253 .445 r
.66096 .63212 m .66257 .63452 L .66059 .63486 L F
.66096 .63212 m .66324 .63195 L .66257 .63452 L F
.616 .605 .817 r
.34508 .68007 m .34438 .68275 L .34379 .68024 L F
.802 .724 .778 r
.60771 .80964 m .60714 .80656 L .60531 .8095 L F
.60771 .80964 m .60856 .80761 L .60714 .80656 L F
.868 .756 .737 r
.60616 .81238 m .60771 .80964 L .60531 .8095 L F
.632 .757 .938 r
.44637 .75041 m .44731 .75171 L .44395 .75106 L F
.752 .633 .729 r
.44731 .75171 m .44515 .75441 L .44395 .75106 L F
.673 .517 .665 r
.44772 .75427 m .44515 .75441 L .44731 .75171 L F
.594 .74 .945 r
.44948 .75136 m .44731 .75171 L .44637 .75041 L F
.556 .436 .671 r
.44979 .7538 m .44731 .75171 L .44948 .75136 L F
.44979 .7538 m .44772 .75427 L .44731 .75171 L F
.687 .487 .611 r
.48955 .88094 m .48617 .87914 L .48611 .88078 L F
.48955 .88094 m .4901 .87914 L .48617 .87914 L F
0 0 0 r
.50834 .88751 m .50995 .88686 L .51189 .88627 L F
.536 .819 .998 r
.31787 .65903 m .31719 .66024 L .31579 .65927 L F
.31787 .65903 m .31926 .65972 L .31719 .66024 L F
.696 .655 .806 r
.66352 .74848 m .66705 .74911 L .66606 .74617 L F
.628 .594 .796 r
.66705 .74911 m .66805 .74585 L .66606 .74617 L F
.66705 .74911 m .66922 .7487 L .66805 .74585 L F
.605 .452 .648 r
.66705 .74911 m .66917 .75114 L .66922 .7487 L F
.66705 .74911 m .66726 .7516 L .66917 .75114 L F
.786 .695 .764 r
.58043 .81803 m .58246 .81531 L .57917 .81498 L F
.485 .476 .772 r
.62888 .73861 m .63153 .74042 L .63105 .73848 L F
.567 .466 .698 r
.62931 .74076 m .63153 .74042 L .62888 .73861 L F
0 0 0 r
.58235 .84638 m .58227 .8464 L .58299 .84612 L F
.50648 .8839 m .50367 .88462 L .50532 .88373 L F
.33 .803 .915 r
.50758 .88335 m .50648 .8839 L .50532 .88373 L F
.614 .854 .989 r
.3852 .88629 m .38342 .88711 L .38168 .8863 L F
.38168 .8863 m .38342 .88711 L .3852 .88629 L F
.557 .308 .495 r
.44302 .75693 m .44284 .75884 L .4408 .75894 L F
.529 .221 .39 r
.44537 .75709 m .44284 .75884 L .44302 .75693 L F
.633 .479 .657 r
.44515 .75441 m .44537 .75709 L .44302 .75693 L F
.72 .683 .813 r
.52127 .83595 m .51768 .83592 L .52004 .83369 L F
.547 .473 .724 r
.52102 .83981 m .51768 .83592 L .52127 .83595 L F
.346 .182 .511 r
.52218 .83875 m .52102 .83981 L .52116 .83764 L F
.557 .547 .799 r
.52127 .84084 m .51916 .8413 L .51881 .84033 L F
.547 .473 .724 r
.52102 .83981 m .51881 .84033 L .51819 .83789 L F
.52102 .83981 m .51819 .83789 L .51854 .83795 L F
.52102 .83981 m .51812 .83764 L .51946 .83799 L F
.542 .145 .237 r
.5166 .84047 m .51904 .84051 L .52068 .83831 L F
.52057 .83829 m .52068 .83831 L .52077 .83818 L F
.5166 .84047 m .52068 .83831 L .52057 .83829 L F
.547 .473 .724 r
.51854 .83795 m .51819 .83789 L .51812 .83764 L F
.51946 .83799 m .51812 .83764 L .51768 .83592 L F
.426 .359 .679 r
.52218 .83875 m .52127 .84084 L .52102 .83981 L F
.52273 .83824 m .52243 .83878 L .52218 .83875 L F
.52243 .83878 m .52127 .84084 L .52218 .83875 L F
.52273 .83824 m .52275 .84141 L .52127 .84084 L F
.394 .419 .768 r
.52313 .83936 m .52363 .83772 L .52277 .83802 L F
.447 .44 .758 r
.52363 .83772 m .52319 .83954 L .52273 .83824 L F
.585 .193 .265 r
.52269 .83802 m .52313 .83936 L .52277 .83802 L F
.447 .44 .758 r
.52301 .8393 m .52275 .84141 L .52274 .83894 L F
.585 .193 .265 r
.52301 .8393 m .52313 .83936 L .52269 .83802 L F
.52301 .8393 m .52307 .83938 L .52313 .83936 L F
.447 .44 .758 r
.52319 .83954 m .52274 .83894 L .52273 .83824 L F
.346 .182 .511 r
.52273 .83824 m .52218 .83875 L .52127 .83595 L F
.52218 .83875 m .52116 .83764 L .52127 .83595 L F
.585 .193 .265 r
.52077 .83818 m .52301 .8393 L .52269 .83802 L F
.447 .44 .758 r
.52318 .83959 m .52435 .8409 L .52275 .84141 L F
.693 .348 .387 r
.52313 .83936 m .52309 .83941 L .52355 .83985 L F
.52313 .83936 m .52355 .83985 L .52381 .84004 L F
.394 .419 .768 r
.52313 .83936 m .52499 .84018 L .52363 .83772 L F
.412 .428 .766 r
.52363 .83772 m .52499 .84018 L .52617 .83957 L F
.43 .428 .756 r
.52617 .83957 m .52504 .8404 L .52363 .83772 L F
.52504 .8404 m .52435 .8409 L .52418 .84012 L F
.693 .348 .387 r
.52375 .83998 m .52399 .84006 L .52499 .84018 L F
.52381 .84004 m .52504 .84031 L .52499 .84018 L F
.43 .428 .756 r
.52504 .8404 m .52418 .84012 L .52363 .83772 L F
.693 .348 .387 r
.52313 .83936 m .52375 .83998 L .52499 .84018 L F
.52375 .83998 m .52381 .84004 L .52399 .84006 L F
.447 .44 .758 r
.52418 .84012 m .52423 .84034 L .52381 .84004 L F
0 0 .364 r
.52504 .8404 m .52521 .84283 L .52435 .8409 L F
0 0 .411 r
.52508 .84041 m .52617 .83957 L .52499 .84018 L F
0 0 .364 r
.52617 .83957 m .52582 .84075 L .52508 .84041 L F
0 0 .411 r
.52559 .84182 m .52617 .83957 L .52508 .84041 L F
0 0 .364 r
.52617 .83957 m .52508 .84041 L .52504 .8404 L F
.52582 .84075 m .52521 .84283 L .52504 .8404 L F
.693 .348 .387 r
.52381 .84004 m .52559 .84182 L .52508 .84041 L F
.52469 .84023 m .52508 .84041 L .52504 .84031 L F
.52381 .84004 m .52508 .84041 L .52469 .84023 L F
.447 .44 .758 r
.52363 .83772 m .52418 .84012 L .52318 .83959 L F
.52418 .84012 m .52381 .84004 L .52318 .83959 L F
.52423 .84034 m .52435 .8409 L .52318 .83959 L F
0 0 .364 r
.52617 .83957 m .52616 .84194 L .52521 .84283 L F
.693 .348 .387 r
.52381 .84004 m .52355 .83985 L .52559 .84182 L F
.447 .44 .758 r
.52309 .8394 m .52314 .83978 L .52301 .8393 L F
.52318 .83959 m .52314 .83978 L .52309 .8394 L F
.52314 .83978 m .52275 .84141 L .52301 .8393 L F
.718 .518 .619 r
.52206 .84304 m .51916 .8413 L .52127 .84084 L F
.428 .548 .876 r
.52275 .84141 m .52206 .84304 L .52127 .84084 L F
.52275 .84141 m .52426 .84372 L .52206 .84304 L F
.212 .428 .854 r
.52275 .84141 m .52521 .84283 L .52426 .84372 L F
.44 .417 .737 r
.52435 .8409 m .52521 .84283 L .52275 .84141 L F
.693 .348 .387 r
.52309 .83941 m .52093 .84201 L .52431 .84187 L F
.52309 .83941 m .52431 .84187 L .52559 .84182 L F
.447 .44 .758 r
.52319 .83954 m .52318 .83959 L .52309 .8394 L F
.585 .193 .265 r
.52242 .83901 m .52283 .83945 L .52307 .83938 L F
.52242 .83901 m .52307 .83938 L .52301 .8393 L F
.52154 .83865 m .51904 .84051 L .52283 .83945 L F
.52119 .83844 m .52104 .83858 L .52154 .83865 L F
.52104 .83858 m .51904 .84051 L .52154 .83865 L F
.52077 .83818 m .52068 .83831 L .52119 .83844 L F
.52068 .83831 m .51904 .84051 L .52119 .83844 L F
.52077 .83818 m .52283 .83945 L .52242 .83901 L F
.695 .28 .256 r
.52317 .83666 m .52273 .83824 L .52127 .83595 L F
0 0 0 r
.48881 .84048 m .4886 .84036 L .49084 .84 L F
.48881 .84048 m .48801 .84156 L .4886 .84036 L F
0 0 .215 r
.57428 .80713 m .57463 .80838 L .57415 .8063 L F
.57428 .80713 m .57438 .81003 L .57463 .80838 L F
.383 .717 .988 r
.57585 .80607 m .57428 .80713 L .57415 .8063 L F
.57585 .80607 m .57765 .80737 L .57428 .80713 L F
.899 .498 .239 r
.5123 .87631 m .5117 .87763 L .50983 .87492 L F
.5123 .87631 m .51334 .87841 L .5117 .87763 L F
.864 .653 .616 r
.50626 .87061 m .50764 .87368 L .50838 .87274 L F
.308 .455 .846 r
.50764 .87368 m .50983 .87492 L .50838 .87274 L F
.759 .645 .735 r
.66922 .7487 m .67246 .74904 L .67128 .74605 L F
.771 .601 .668 r
.66917 .75114 m .67246 .74904 L .66922 .7487 L F
.66917 .75114 m .6723 .75138 L .67246 .74904 L F
.742 .637 .743 r
.67128 .74605 m .67246 .74904 L .67458 .74644 L F
.587 .604 .836 r
.44049 .74883 m .43849 .74927 L .43705 .7462 L F
.548 .821 .997 r
.70355 .72186 m .7027 .72331 L .70151 .72227 L F
.647 .524 .699 r
.7027 .72331 m .70489 .72306 L .70548 .72298 L F
.548 .821 .997 r
.70355 .72186 m .70489 .72306 L .7027 .72331 L F
.196 .369 .81 r
.7027 .72331 m .70355 .72186 L .70151 .72227 L F
.555 .219 .354 r
.70548 .72298 m .70478 .72449 L .7027 .72331 L F
.196 .369 .81 r
.7027 .72331 m .70478 .72449 L .70355 .72186 L F
0 0 0 r
.64185 .72141 m .64291 .71915 L .64345 .71765 L F
.746 .697 .805 r
.64207 .72318 m .64291 .71915 L .64185 .72141 L F
.368 0 0 r
.49821 .84739 m .49856 .84801 L .49503 .84758 L F
.476 0 0 r
.50087 .84768 m .49856 .84801 L .49821 .84739 L F
.714 .551 .666 r
.60161 .79119 m .60383 .78893 L .60164 .78859 L F
.60161 .79119 m .60505 .79149 L .60383 .78893 L F
.62 .841 .984 r
.38416 .7454 m .38211 .74608 L .38543 .74623 L F
.969 .704 .476 r
.38416 .7454 m .38543 .74623 L .38211 .74608 L F
.38416 .7454 m .38555 .74867 L .38543 .74623 L F
.701 .862 .959 r
.38416 .7454 m .38543 .74623 L .38755 .7452 L F
.695 .364 .411 r
.51388 .85502 m .51582 .85693 L .51362 .85707 L F
.59 .61 .84 r
.5357 .86901 m .53682 .87106 L .53693 .86911 L F
.87 .87 .426 r
.53682 .87106 m .53775 .86791 L .53693 .86911 L F
.88 .605 .516 r
.58325 .79401 m .58179 .79537 L .58211 .7934 L F
.58325 .79401 m .58347 .79633 L .58179 .79537 L F
.498 .178 .355 r
.47307 .83312 m .47511 .83286 L .47612 .83123 L F
0 0 .001 r
.47612 .83123 m .47511 .83286 L .47731 .83041 L F
.71 .541 .658 r
.5115 .85754 m .50936 .86013 L .50949 .85753 L F
0 0 0 r
.35913 .80686 m .36287 .8052 L .36101 .80633 L F
.408 .82 .625 r
.36101 .80633 m .36287 .8052 L .36442 .80419 L F
.603 .088 0 r
.48451 .87287 m .48627 .87329 L .48523 .87241 L F
0 0 .544 r
.52588 .85983 m .52532 .85904 L .52446 .85717 L F
.794 .764 .825 r
.48077 .8357 m .47851 .83861 L .4826 .83883 L F
.489 .267 .504 r
.47851 .83861 m .48078 .8401 L .4826 .83883 L F
0 .15 .693 r
.56325 .84163 m .56398 .8413 L .56216 .84101 L F
.56325 .84163 m .56524 .84383 L .56398 .8413 L F
.574 .508 .743 r
.4479 .86796 m .44918 .8646 L .4469 .86494 L F
.4479 .86796 m .44996 .86767 L .44918 .8646 L F
.569 .465 .696 r
.44846 .87101 m .44996 .86767 L .4479 .86796 L F
.035 0 .435 r
.4884 .84371 m .4884 .84674 L .48725 .84686 L F
.525 .408 .662 r
.48919 .84816 m .48725 .84686 L .4884 .84674 L F
.48919 .84816 m .48781 .84981 L .48725 .84686 L F
.856 .834 .824 r
.53964 .80404 m .53783 .80412 L .53996 .80145 L F
0 .159 .681 r
.53964 .80404 m .53996 .80393 L .53783 .80412 L F
.53964 .80404 m .54171 .80595 L .53996 .80393 L F
.416 .247 .543 r
.52757 .84159 m .52742 .84415 L .52907 .84334 L F
.392 .732 .991 r
.39101 .74559 m .39172 .74469 L .38971 .74483 L F
.39101 .74559 m .39285 .7455 L .39172 .74469 L F
.79 .549 .571 r
.64291 .71915 m .64685 .71769 L .64345 .71765 L F
.64291 .71915 m .64628 .71967 L .64685 .71769 L F
.545 .581 .842 r
.64498 .71419 m .64685 .71769 L .64823 .71685 L F
0 0 .038 r
.64685 .71769 m .64628 .71967 L .6473 .71837 L F
.443 0 0 r
.68342 .69801 m .68282 .69857 L .68053 .69828 L F
0 0 0 r
.68553 .69734 m .6849 .69771 L .68342 .69801 L F
.6849 .69771 m .68282 .69857 L .68342 .69801 L F
.993 .81 .437 r
.68554 .72651 m .684 .72516 L .684 .72625 L F
.68554 .72651 m .68641 .72502 L .684 .72516 L F
.893 .699 .634 r
.68279 .72558 m .684 .72516 L .68298 .72244 L F
.625 .171 .154 r
.68279 .72558 m .684 .72625 L .684 .72516 L F
.438 0 .059 r
.55367 .77962 m .55684 .7782 L .55508 .7778 L F
.532 .733 .967 r
.4338 .73498 m .43288 .73639 L .43179 .73503 L F
.4338 .73498 m .43482 .73601 L .43288 .73639 L F
.641 .729 .913 r
.49727 .83034 m .50033 .83094 L .49932 .82958 L F
.49932 .82958 m .50033 .83094 L .49727 .83034 L F
0 .476 .798 r
.49932 .82958 m .5025 .83064 L .50033 .83094 L F
.5025 .83064 m .49932 .82958 L .50033 .83094 L F
.641 .729 .913 r
.49932 .82958 m .50033 .83094 L .49727 .83034 L F
.232 0 .088 r
.55251 .784 m .551 .78394 L .55274 .78281 L F
.55251 .784 m .55022 .78501 L .551 .78394 L F
.564 .403 .622 r
.45103 .85737 m .45322 .85706 L .45308 .85469 L F
.566 .426 .65 r
.45103 .85737 m .45349 .85948 L .45322 .85706 L F
.45103 .85737 m .45118 .86002 L .45349 .85948 L F
.725 .771 .889 r
.68656 .73641 m .68865 .7354 L .68532 .73522 L F
.879 .904 .843 r
.69576 .74317 m .69658 .7439 L .69826 .74222 L F
.885 .986 .721 r
.69915 .74083 m .69826 .74222 L .69884 .74003 L F
0 .465 .783 r
.69826 .74222 m .69869 .74213 L .69884 .74003 L F
0 .15 .682 r
.69884 .74003 m .69616 .73698 L .69895 .73801 L F
.69884 .74003 m .69864 .73941 L .69616 .73698 L F
.78 .73 .806 r
.69869 .74213 m .69864 .73951 L .69884 .74003 L F
.69864 .73951 m .69864 .73941 L .69884 .74003 L F
.885 .986 .721 r
.70061 .73857 m .69915 .74083 L .69884 .74003 L F
0 .465 .783 r
.69826 .74222 m .699 .74233 L .69869 .74213 L F
.745 .344 .292 r
.5262 .81206 m .5284 .81451 L .52926 .81255 L F
.7 .293 .273 r
.52926 .81255 m .5284 .81451 L .53143 .81452 L F
.23 0 0 r
.35164 .79476 m .35295 .79487 L .35446 .79327 L F
.266 0 0 r
.35446 .79327 m .35563 .7937 L .35718 .79219 L F
.263 0 0 r
.35446 .79327 m .35295 .79487 L .35563 .7937 L F
.413 0 0 r
.56569 .77782 m .56871 .77764 L .56624 .77852 L F
.56569 .77782 m .56781 .77805 L .56871 .77764 L F
.567 .056 0 r
.56871 .77764 m .56781 .77805 L .57104 .77817 L F
.238 0 0 r
.35718 .79219 m .35759 .79324 L .35894 .79145 L F
.35718 .79219 m .35563 .7937 L .35759 .79324 L F
.579 .34 .518 r
.43896 .75986 m .4378 .76236 L .43557 .7624 L F
.544 .302 .499 r
.4408 .75894 m .4378 .76236 L .43896 .75986 L F
.817 .642 .665 r
.67076 .75407 m .67364 .75435 L .6723 .75138 L F
.784 .594 .644 r
.67039 .75637 m .67364 .75435 L .67076 .75407 L F
.67039 .75637 m .67349 .75659 L .67364 .75435 L F
.941 .771 .643 r
.60645 .81482 m .60734 .81765 L .6077 .8153 L F
.387 0 .128 r
.39354 .77522 m .3957 .77496 L .39694 .77314 L F
.157 0 0 r
.39694 .77314 m .39743 .77426 L .39877 .77257 L F
.39694 .77314 m .3957 .77496 L .39743 .77426 L F
.898 .544 .366 r
.54891 .82486 m .55128 .82785 L .54961 .82526 L F
.394 .162 .439 r
.33269 .70065 m .33144 .69913 L .33312 .69845 L F
.33269 .70065 m .3309 .70133 L .33144 .69913 L F
.469 .177 .386 r
.40162 .76952 m .40282 .77178 L .40351 .76913 L F
.40162 .76952 m .40078 .77216 L .40282 .77178 L F
.637 .447 .609 r
.63569 .73027 m .63774 .73044 L .63762 .7279 L F
.916 .816 .35 r
.63788 .72439 m .63762 .7279 L .63923 .72807 L F
.366 .354 .713 r
.63762 .7279 m .63979 .7298 L .63923 .72807 L F
.521 .358 .601 r
.63762 .7279 m .63774 .73044 L .63979 .7298 L F
.982 .728 .47 r
.5049 .84347 m .50609 .8442 L .50489 .84151 L F
.82 .515 .475 r
.50609 .8442 m .50621 .84639 L .50926 .84705 L F
.50621 .84639 m .50624 .84686 L .50683 .8469 L F
.50621 .84639 m .50683 .8469 L .50926 .84705 L F
.188 0 0 r
.50608 .84871 m .50926 .84705 L .50624 .84686 L F
.50608 .84871 m .50807 .84792 L .50926 .84705 L F
0 .31 .79 r
.50897 .84771 m .50807 .84792 L .50639 .846 L F
.50807 .84792 m .50807 .84792 L .50806 .84791 L F
.50807 .84792 m .50806 .84791 L .50639 .846 L F
0 0 .136 r
.50639 .846 m .50624 .84686 L .50609 .8442 L F
.50639 .846 m .50609 .8442 L .5049 .84347 L F
.786 .708 .778 r
.50804 .84154 m .50609 .8442 L .50489 .84151 L F
.431 .28 .574 r
.47395 .85855 m .47148 .86277 L .47096 .8596 L F
.47395 .85855 m .47314 .86262 L .47148 .86277 L F
.45 .429 .743 r
.47314 .86262 m .47405 .86466 L .47148 .86277 L F
.604 .782 .966 r
.57052 .81941 m .56906 .82143 L .56924 .82018 L F
.798 .719 .777 r
.57052 .81941 m .57193 .82203 L .56906 .82143 L F
.574 .479 .709 r
.6563 .73797 m .65828 .73576 L .65576 .73635 L F
.6563 .73797 m .65844 .73763 L .65828 .73576 L F
.327 0 0 r
.41743 .74232 m .41648 .74249 L .41451 .74196 L F
0 0 0 r
.41927 .74218 m .41648 .74249 L .41743 .74232 L F
.79 .659 .718 r
.49315 .88387 m .4957 .88404 L .49459 .88134 L F
.48 .216 .435 r
.4054 .78297 m .40416 .7808 L .40629 .78039 L F
.4054 .78297 m .40352 .78338 L .40416 .7808 L F
.563 .427 .654 r
.44744 .75662 m .44515 .75441 L .44772 .75427 L F
.44744 .75662 m .44537 .75709 L .44515 .75441 L F
.654 .415 .545 r
.50855 .83056 m .51007 .83201 L .51102 .83047 L F
.71 .484 .58 r
.51007 .83201 m .51315 .83094 L .51102 .83047 L F
.866 .811 .794 r
.55725 .80696 m .56058 .80458 L .55935 .80379 L F
.569 .8 .986 r
.58673 .84692 m .58801 .84574 L .58587 .84633 L F
.58673 .84692 m .59021 .84608 L .58801 .84574 L F
.049 .032 .514 r
.66997 .71656 m .66908 .71998 L .67109 .71723 L F
.66997 .71656 m .67043 .71871 L .66908 .71998 L F
.059 0 .459 r
.67043 .71871 m .66898 .72223 L .66908 .71998 L F
.969 .659 .277 r
.38845 .88895 m .38919 .89032 L .38896 .89069 L F
.03 .424 .865 r
.39034 .89042 m .39194 .89193 L .38919 .89032 L F
.39034 .89042 m .38919 .89032 L .38896 .89069 L F
.681 .888 .974 r
.39459 .72199 m .39053 .72238 L .39242 .71951 L F
.831 .401 .215 r
.39242 .71951 m .39572 .72219 L .39459 .72199 L F
0 0 .057 r
.55364 .83606 m .55385 .8387 L .55387 .83889 L F
.995 .809 .545 r
.55297 .84029 m .55387 .83889 L .55385 .8387 L F
.55297 .84029 m .55366 .84023 L .55387 .83889 L F
.885 .575 .455 r
.54386 .8193 m .54512 .81772 L .54345 .81731 L F
.54386 .8193 m .54622 .82066 L .54512 .81772 L F
.527 .397 .647 r
.45308 .85469 m .45481 .85194 L .45274 .85235 L F
.388 .093 .337 r
.33643 .69721 m .33591 .6945 L .33733 .69578 L F
.33643 .69721 m .33458 .69777 L .33591 .6945 L F
.631 .446 .614 r
.51916 .8413 m .51908 .84447 L .51677 .84411 L F
.718 .518 .619 r
.52206 .84304 m .51908 .84447 L .51916 .8413 L F
.64 .895 .985 r
.69693 .68971 m .69592 .69125 L .69465 .69063 L F
.69465 .69063 m .69592 .69125 L .69693 .68971 L F
.833 .63 .629 r
.53467 .84012 m .53174 .84098 L .53254 .83884 L F
.47 .163 .362 r
.53467 .84012 m .53202 .84376 L .53174 .84098 L F
.53467 .84012 m .53467 .84373 L .53202 .84376 L F
.323 0 .081 r
.53738 .83941 m .53695 .84137 L .53467 .84012 L F
.53695 .84137 m .5369 .84141 L .53467 .84012 L F
.244 0 .329 r
.53587 .84277 m .53467 .84012 L .5369 .84141 L F
.498 .204 .397 r
.54116 .83997 m .53806 .84261 L .53657 .84216 L F
.244 0 .329 r
.53587 .84277 m .5369 .84141 L .5369 .84148 L F
.616 .622 .834 r
.53559 .84187 m .53587 .84277 L .53684 .84155 L F
.498 .204 .397 r
.5369 .84142 m .53684 .84155 L .53559 .84187 L F
.54116 .83997 m .53657 .84216 L .5369 .84142 L F
.244 0 .329 r
.5369 .84148 m .5369 .84142 L .53694 .84143 L F
.616 .622 .834 r
.53559 .84187 m .53684 .84155 L .53694 .84143 L F
.498 .204 .397 r
.53684 .84155 m .53657 .84216 L .53559 .84187 L F
.573 .238 .364 r
.54116 .83997 m .53686 .84144 L .54034 .83916 L F
.244 0 .329 r
.5369 .84142 m .5369 .84141 L .5369 .84141 L F
.5369 .84142 m .5369 .84141 L .53694 .84143 L F
.573 .238 .364 r
.54034 .83916 m .5373 .84089 L .5393 .83814 L F
.553 .213 .346 r
.5393 .83814 m .53695 .84137 L .53738 .83941 L F
.573 .238 .364 r
.53686 .84144 m .53559 .84187 L .54034 .83916 L F
.553 .213 .346 r
.5393 .83814 m .53694 .84143 L .53695 .84137 L F
.573 .238 .364 r
.5373 .84089 m .53688 .84113 L .5393 .83814 L F
.53688 .84113 m .53559 .84187 L .53685 .84061 L F
.53688 .84113 m .53685 .84061 L .5393 .83814 L F
.323 0 .081 r
.53695 .84137 m .53694 .84143 L .5369 .84141 L F
.244 0 .329 r
.53587 .84277 m .53467 .84373 L .53467 .84012 L F
.546 0 0 r
.48349 .85528 m .48418 .85616 L .481 .85548 L F
.723 .262 .157 r
.48418 .85616 m .48643 .85813 L .4832 .85754 L F
.48418 .85616 m .4832 .85754 L .48417 .85648 L F
.637 .075 0 r
.48663 .85723 m .48531 .85683 L .48349 .85528 L F
.586 .024 0 r
.48531 .85683 m .48643 .85813 L .48418 .85616 L F
.004 0 0 r
.48528 .8553 m .48564 .85532 L .48707 .85518 L F
.924 .825 .73 r
.484 .85277 m .48403 .85576 L .48545 .85507 L F
.723 .262 .157 r
.48418 .85616 m .48417 .85648 L .48525 .85529 L F
.48522 .85528 m .48525 .85529 L .48545 .85507 L F
.48418 .85616 m .48525 .85529 L .48522 .85528 L F
.546 0 0 r
.48349 .85528 m .48419 .85587 L .48418 .85616 L F
.48419 .85587 m .48531 .85683 L .48418 .85616 L F
.043 .53 .884 r
.48418 .85616 m .48024 .8546 L .481 .85548 L F
.48418 .85616 m .48403 .85576 L .48024 .8546 L F
.461 .872 .951 r
.48545 .85507 m .48403 .85576 L .48418 .85616 L F
.749 .344 .284 r
.48403 .85576 m .48195 .85532 L .48024 .8546 L F
.321 .545 .912 r
.47992 .85607 m .48024 .8546 L .4791 .85411 L F
.47992 .85607 m .481 .85548 L .48024 .8546 L F
.749 .344 .284 r
.48195 .85532 m .47955 .85482 L .48024 .8546 L F
.321 .545 .912 r
.4791 .85411 m .48024 .8546 L .47898 .85381 L F
.749 .344 .284 r
.48403 .85576 m .48182 .85645 L .47955 .85482 L F
.924 .825 .73 r
.484 .85277 m .48182 .85645 L .48403 .85576 L F
.815 .827 .859 r
.4832 .85754 m .48386 .8554 L .48545 .85507 L F
.004 0 0 r
.48386 .8554 m .48535 .85533 L .48528 .8553 L F
.48535 .85533 m .48564 .85532 L .48528 .8553 L F
.679 .591 .749 r
.63051 .74625 m .63361 .74681 L .63237 .7435 L F
.744 .767 .871 r
.71133 .74044 m .71358 .74058 L .71373 .73826 L F
.786 .816 .876 r
.71373 .73826 m .71358 .74058 L .71677 .73833 L F
0 0 0 r
.36166 .79044 m .36289 .79031 L .36449 .78881 L F
.36639 .78772 m .36449 .78881 L .36521 .7884 L F
.36521 .7884 m .36449 .78881 L .36289 .79031 L F
.55 .303 .494 r
.65844 .73763 m .66065 .73476 L .65828 .73576 L F
.65844 .73763 m .66051 .73737 L .66065 .73476 L F
.679 .554 .706 r
.66051 .73737 m .66299 .7346 L .66065 .73476 L F
.589 .412 .61 r
.45625 .8439 m .45843 .84371 L .45851 .84144 L F
.555 .433 .669 r
.45625 .8439 m .45887 .84655 L .45843 .84371 L F
.45625 .8439 m .45678 .84694 L .45887 .84655 L F
.383 0 0 r
.53397 .83331 m .53338 .83417 L .53102 .83421 L F
.114 .052 .502 r
.53397 .83331 m .5353 .83512 L .53507 .83328 L F
.53397 .83331 m .53417 .83628 L .5353 .83512 L F
.53397 .83331 m .53507 .83328 L .53338 .83417 L F
.509 .672 .937 r
.45892 .88078 m .45955 .87901 L .45742 .87892 L F
.45892 .88078 m .46092 .88057 L .45955 .87901 L F
.986 .839 .457 r
.669 .72565 m .66942 .72749 L .66976 .7251 L F
.722 .441 0 r
.66898 .72223 m .66969 .72501 L .66976 .7251 L F
.602 .894 .6 r
.66969 .72501 m .669 .72565 L .66976 .7251 L F
.858 .843 .829 r
.34445 .71356 m .34294 .71456 L .34412 .71286 L F
.692 .448 .549 r
.34445 .71356 m .34532 .71505 L .34294 .71456 L F
.353 .568 .919 r
.34412 .71286 m .34688 .71398 L .34445 .71356 L F
.491 .376 .65 r
.34688 .71398 m .34532 .71505 L .34445 .71356 L F
.778 .945 .605 r
.68675 .69505 m .68553 .69734 L .68804 .69615 L F
.68675 .69505 m .6849 .69771 L .68553 .69734 L F
.59 .708 .925 r
.34014 .67765 m .337 .67667 L .33899 .67632 L F
.446 .668 .957 r
.34086 .67627 m .34014 .67765 L .33899 .67632 L F
.379 .586 .924 r
.34086 .67627 m .34197 .67812 L .34014 .67765 L F
.614 .854 .989 r
.3852 .88629 m .38484 .88342 L .38518 .88384 L F
.408 .797 .989 r
.38484 .88342 m .3857 .883 L .38518 .88384 L F
0 0 .357 r
.3857 .883 m .3852 .88629 L .38518 .88384 L F
.563 .446 .678 r
.54157 .83289 m .53962 .83657 L .53945 .83268 L F
.422 0 0 r
.47784 .88223 m .48142 .88401 L .47998 .88396 L F
.08 .64 .775 r
.47998 .88396 m .48142 .88401 L .48354 .88394 L F
.787 .843 .894 r
.49323 .84705 m .49063 .84853 L .48919 .84816 L F
.997 .807 .45 r
.70592 .73845 m .70505 .74005 L .70587 .74086 L F
.813 .752 .795 r
.70808 .73556 m .70592 .73845 L .70506 .73628 L F
.032 0 0 r
.7074 .73829 m .70592 .73845 L .70741 .73872 L F
.65 .696 .879 r
.70587 .74086 m .70741 .73872 L .70592 .73845 L F
.032 0 0 r
.7074 .73829 m .70505 .74005 L .70592 .73845 L F
.787 .567 .602 r
.50328 .86801 m .5031 .87031 L .50099 .86784 L F
.791 .548 .569 r
.50328 .86801 m .50626 .87061 L .5031 .87031 L F
.928 .922 .785 r
.57122 .78382 m .56894 .78525 L .56903 .7829 L F
.57122 .78382 m .56979 .78594 L .56894 .78525 L F
.797 .411 .323 r
.56309 .83619 m .56174 .8379 L .56299 .83721 L F
.976 .68 .309 r
.56309 .83619 m .56299 .83721 L .56293 .83706 L F
.797 .411 .323 r
.56309 .83619 m .56429 .83834 L .56275 .83807 L F
.56309 .83619 m .56293 .83706 L .56174 .8379 L F
.98 .725 .475 r
.56169 .83366 m .56293 .83706 L .56081 .83475 L F
.56293 .83706 m .56299 .83721 L .5629 .83711 L F
.56293 .83706 m .5629 .83711 L .56081 .83475 L F
.797 .411 .323 r
.56293 .83706 m .56275 .83807 L .56226 .83799 L F
.56293 .83706 m .56226 .83799 L .56174 .8379 L F
.976 .68 .309 r
.56309 .83619 m .56293 .83706 L .56169 .83366 L F
.679 .525 .669 r
.45693 .74632 m .45896 .74608 L .459 .7437 L F
.45693 .74632 m .45896 .74608 L .459 .7437 L F
.549 .417 .654 r
.46145 .74535 m .45896 .74608 L .459 .7437 L F
.46145 .74535 m .45896 .74608 L .459 .7437 L F
.787 .843 .894 r
.49323 .84705 m .48919 .84816 L .49135 .84651 L F
.212 0 .148 r
.55691 .80153 m .55866 .80164 L .55947 .79924 L F
.274 0 .172 r
.55947 .79924 m .55866 .80164 L .56048 .80061 L F
.29 0 0 r
.35894 .79145 m .36116 .79113 L .36166 .79044 L F
0 0 0 r
.36166 .79044 m .36116 .79113 L .36289 .79031 L F
.345 0 .221 r
.39771 .78794 m .3969 .7862 L .39887 .78565 L F
.39771 .78794 m .39579 .78857 L .3969 .7862 L F
.972 .666 .366 r
.56049 .8257 m .55966 .82706 L .55947 .82512 L F
.56049 .8257 m .56078 .82787 L .55966 .82706 L F
.888 .459 .126 r
.67548 .7385 m .67516 .7397 L .67442 .73781 L F
.67548 .7385 m .67642 .74041 L .67516 .7397 L F
.663 .955 .731 r
.65077 .6266 m .65346 .62463 L .65216 .62353 L F
.65077 .6266 m .65163 .62612 L .65346 .62463 L F
.435 .122 .335 r
.65163 .62612 m .65568 .62395 L .65346 .62463 L F
.485 .151 .325 r
.41592 .77509 m .41285 .77756 L .41382 .77538 L F
.652 .541 .716 r
.47395 .85855 m .47096 .8596 L .47043 .85756 L F
.784 .365 0 r
.49301 .82737 m .49117 .8251 L .48918 .82492 L F
.49301 .82737 m .49238 .82668 L .49117 .8251 L F
.607 .463 .66 r
.49301 .82737 m .49402 .82787 L .49238 .82668 L F
.556 .562 .815 r
.5036 .83595 m .50477 .83889 L .50581 .83684 L F
.414 .392 .726 r
.50477 .83889 m .50725 .84073 L .50581 .83684 L F
.646 .455 .61 r
.64498 .71419 m .64739 .71167 L .64501 .71203 L F
.768 .497 .525 r
.5031 .87031 m .50626 .87061 L .50615 .8728 L F
.636 .384 .52 r
.50626 .87061 m .50838 .87274 L .50615 .8728 L F
.831 .675 .689 r
.59299 .80421 m .59423 .80716 L .59137 .80649 L F
.872 .662 .616 r
.59423 .80716 m .59287 .80854 L .59137 .80649 L F
.59423 .80716 m .59386 .80945 L .59287 .80854 L F
.462 .103 .269 r
.34072 .7378 m .344 .73539 L .34187 .73539 L F
.566 .524 .767 r
.48272 .86556 m .48417 .86333 L .48217 .86294 L F
.48291 .86526 m .4851 .86615 L .48417 .86333 L F
.48272 .86556 m .48309 .86566 L .48291 .86526 L F
.48309 .86566 m .4851 .86615 L .48291 .86526 L F
.668 .354 .433 r
.48272 .86556 m .48495 .86651 L .4851 .86615 L F
.386 .378 .728 r
.48297 .86578 m .48272 .86556 L .48217 .86294 L F
.48301 .86593 m .48272 .86556 L .48297 .86578 L F
.79 .627 .679 r
.47875 .86511 m .48273 .86588 L .48269 .86477 L F
.759 .447 .457 r
.48301 .86593 m .48219 .86767 L .48272 .86556 L F
.79 .627 .679 r
.48273 .86588 m .48301 .86593 L .48297 .86578 L F
.668 .354 .433 r
.48272 .86556 m .48263 .86592 L .48297 .86578 L F
.79 .627 .679 r
.48273 .86588 m .48297 .86578 L .48269 .86477 L F
.668 .354 .433 r
.48297 .86578 m .48219 .86767 L .48418 .86684 L F
.48263 .86592 m .48219 .86767 L .48297 .86578 L F
.48272 .86556 m .48418 .86684 L .48495 .86651 L F
.79 .627 .679 r
.48192 .86309 m .48269 .86477 L .48217 .86294 L F
.47875 .86511 m .48269 .86477 L .48192 .86309 L F
.759 .751 .845 r
.63448 .74306 m .63769 .74346 L .63679 .74064 L F
.789 .689 .755 r
.63448 .74306 m .63559 .74587 L .63769 .74346 L F
.78 .762 .837 r
.63679 .74064 m .63769 .74346 L .6399 .74075 L F
.58 .302 .459 r
.42295 .75872 m .42564 .75662 L .42351 .75693 L F
.557 .368 .581 r
.42351 .75693 m .42564 .75662 L .42569 .75428 L F
.458 .168 .384 r
.42363 .76999 m .42269 .77268 L .4209 .77269 L F
.521 .229 .411 r
.42514 .77178 m .42363 .76999 L .4257 .76972 L F
.42514 .77178 m .42269 .77268 L .42363 .76999 L F
.979 .682 .355 r
.67449 .73313 m .67479 .73545 L .67381 .7347 L F
.507 .874 .981 r
.57372 .78818 m .57022 .78836 L .57079 .78806 L F
0 0 .472 r
.50804 .84154 m .50863 .84356 L .5092 .84274 L F
.50804 .84154 m .5092 .84274 L .50725 .84073 L F
.413 .252 .552 r
.42569 .75428 m .42731 .75602 L .42728 .75368 L F
.42569 .75428 m .42564 .75662 L .42731 .75602 L F
.704 .375 .417 r
.38007 .74938 m .37991 .75101 L .37765 .75047 L F
.387 0 0 r
.36851 .78747 m .37221 .78625 L .36838 .78749 L F
.36851 .78747 m .37042 .78755 L .37221 .78625 L F
0 0 0 r
.37221 .78625 m .37235 .7869 L .37377 .78534 L F
.37221 .78625 m .37042 .78755 L .37235 .7869 L F
.981 .691 .345 r
.56196 .83086 m .56075 .83119 L .56078 .82787 L F
.985 .716 .426 r
.56196 .83086 m .56064 .83196 L .56075 .83119 L F
.56196 .83086 m .56169 .83366 L .56064 .83196 L F
.512 .229 .422 r
.38145 .78288 m .38356 .78261 L .38413 .77975 L F
.41 .131 .375 r
.38413 .77975 m .38603 .78021 L .38664 .77768 L F
.337 .077 .364 r
.38413 .77975 m .38527 .78193 L .38603 .78021 L F
.38413 .77975 m .38356 .78261 L .38527 .78193 L F
.607 .3 .423 r
.5357 .86901 m .53775 .86791 L .53546 .86776 L F
.859 .516 .401 r
.58644 .7829 m .58801 .78563 L .58963 .78599 L F
.834 .571 .541 r
.58801 .78563 m .58989 .78804 L .58963 .78599 L F
.749 .467 .505 r
.58963 .78599 m .58989 .78804 L .59295 .78818 L F
.419 .135 .374 r
.65363 .63795 m .65527 .63966 L .65322 .64017 L F
.65363 .63795 m .65575 .63723 L .65527 .63966 L F
.513 .648 .918 r
.52158 .84966 m .52138 .85158 L .51985 .84942 L F
.52158 .84966 m .52337 .85148 L .52138 .85158 L F
.449 .297 .581 r
.52361 .85407 m .52138 .85158 L .52337 .85148 L F
.52361 .85407 m .52151 .85439 L .52138 .85158 L F
.548 .038 0 r
.41451 .74196 m .41328 .74281 L .412 .74242 L F
.425 0 0 r
.41648 .74249 m .41328 .74281 L .41451 .74196 L F
.616 .605 .817 r
.34508 .68007 m .34607 .68251 L .34438 .68275 L F
.62 .451 .631 r
.34511 .68325 m .34438 .68275 L .34607 .68251 L F
.34511 .68325 m .34447 .6845 L .34438 .68275 L F
.978 .726 .482 r
.66996 .71427 m .67109 .71723 L .66997 .71656 L F
.66996 .71427 m .67109 .71723 L .66997 .71656 L F
.932 .602 .389 r
.67189 .71926 m .66997 .71656 L .67109 .71723 L F
.829 .535 .491 r
.50807 .84792 m .50952 .84941 L .50926 .84705 L F
.594 .215 .293 r
.38019 .72338 m .38153 .72279 L .38191 .72259 L F
.75 .832 .915 r
.38296 .72236 m .38219 .72244 L .38191 .72259 L F
.232 .689 .95 r
.38362 .72186 m .38296 .72236 L .38191 .72259 L F
.594 .215 .293 r
.38153 .72279 m .38362 .72186 L .38191 .72259 L F
.75 .832 .915 r
.38219 .72244 m .37954 .7227 L .38191 .72259 L F
.232 .689 .95 r
.38362 .72186 m .38498 .72252 L .38296 .72236 L F
0 0 0 r
.36613 .80344 m .36991 .80172 L .36822 .80292 L F
.09 0 0 r
.36822 .80292 m .36991 .80172 L .3719 .80118 L F
.585 .355 .533 r
.4469 .86494 m .44918 .8646 L .44944 .86279 L F
.547 .397 .629 r
.44944 .86279 m .4515 .86256 L .45118 .86002 L F
.611 .431 .614 r
.44918 .8646 m .4515 .86256 L .44944 .86279 L F
.622 .22 .261 r
.4915 .8579 m .49068 .85952 L .48885 .85934 L F
.615 .212 .257 r
.49399 .85945 m .49068 .85952 L .4915 .8579 L F
.809 .63 .659 r
.58778 .80191 m .5849 .80174 L .58633 .79895 L F
.781 .624 .686 r
.58771 .8043 m .5849 .80174 L .58778 .80191 L F
.803 .966 .91 r
.51723 .88373 m .5184 .88169 L .51633 .88353 L F
.51723 .88373 m .51971 .88178 L .5184 .88169 L F
.885 .986 .721 r
.70061 .73857 m .69884 .74003 L .69895 .73801 L F
.693 .737 .884 r
.70189 .73577 m .70061 .73857 L .69895 .73801 L F
.517 .314 .543 r
.45843 .84371 m .46059 .84127 L .45851 .84144 L F
.619 .425 .598 r
.48034 .8779 m .48248 .87833 L .48247 .87588 L F
.48034 .8779 m .48248 .87833 L .48247 .87588 L F
.568 .491 .728 r
.48247 .87588 m .48542 .87672 L .48451 .87287 L F
.461 .166 .377 r
.48248 .87833 m .48542 .87672 L .48247 .87588 L F
.716 .58 .702 r
.59831 .78858 m .60161 .79119 L .60164 .78859 L F
.991 .734 .424 r
.65625 .71448 m .65701 .71569 L .65669 .71375 L F
.65625 .71448 m .65669 .71375 L .65642 .71209 L F
.957 .625 .233 r
.65328 .71509 m .65411 .71767 L .65267 .71602 L F
.505 .085 .176 r
.65625 .71448 m .65267 .71602 L .65411 .71767 L F
.65396 .71547 m .65507 .71648 L .65267 .71602 L F
.65625 .71448 m .65507 .71648 L .65396 .71547 L F
.164 .22 .675 r
.65507 .71648 m .65425 .71907 L .65267 .71602 L F
.383 .069 .304 r
.65425 .71907 m .65575 .71984 L .65669 .71648 L F
.65575 .71984 m .65581 .71977 L .65669 .71648 L F
.65579 .71986 m .65599 .71976 L .65669 .71648 L F
.164 .22 .675 r
.65507 .71648 m .65588 .71963 L .65425 .71907 L F
.383 .069 .304 r
.65575 .71984 m .65579 .71986 L .65581 .71977 L F
.729 .963 .69 r
.65579 .71987 m .65576 .71997 L .65654 .71956 L F
.383 .069 .304 r
.65592 .7198 m .65596 .71994 L .65599 .71976 L F
.164 .22 .675 r
.65584 .71969 m .65579 .71986 L .65575 .71984 L F
.459 .13 .32 r
.65604 .71954 m .6588 .71619 L .65669 .71648 L F
.65599 .71976 m .65657 .71903 L .65604 .71954 L F
.65657 .71903 m .6588 .71619 L .65604 .71954 L F
.729 .963 .69 r
.65571 .71986 m .65548 .72011 L .65567 .71991 L F
.65724 .71781 m .65568 .71989 L .65571 .71986 L F
.65588 .71964 m .65567 .71991 L .65592 .7198 L F
.459 .13 .32 r
.65613 .71971 m .6588 .71619 L .65599 .71976 L F
.65613 .71971 m .65834 .71888 L .6588 .71619 L F
.729 .963 .69 r
.65613 .71971 m .65654 .71956 L .65658 .71954 L F
.65816 .71871 m .65555 .72008 L .65834 .71888 L F
.459 .13 .32 r
.65596 .71994 m .65834 .71888 L .65613 .71971 L F
.729 .963 .69 r
.65599 .71976 m .65613 .71971 L .65816 .71871 L F
.65613 .71971 m .65658 .71954 L .65816 .71871 L F
.65724 .71781 m .65609 .71971 L .65816 .71871 L F
.65567 .71991 m .65654 .71956 L .65599 .71976 L F
.459 .13 .32 r
.65596 .71994 m .65613 .71971 L .65599 .71976 L F
.737 .8 .903 r
.65724 .71781 m .65596 .71994 L .65588 .71963 L F
.65724 .71781 m .65588 .71963 L .65507 .71648 L F
.729 .963 .69 r
.65724 .71781 m .65555 .72002 L .65568 .71989 L F
.65555 .72002 m .65548 .72011 L .65571 .71986 L F
.164 .22 .675 r
.65588 .71963 m .65596 .71994 L .65579 .71986 L F
.65588 .71963 m .65579 .71986 L .65584 .71969 L F
.729 .963 .69 r
.65567 .71991 m .65555 .72008 L .65576 .71997 L F
.65567 .71991 m .65576 .71997 L .65579 .71987 L F
.164 .22 .675 r
.65588 .71963 m .65575 .71984 L .65425 .71907 L F
.729 .963 .69 r
.65599 .71944 m .65504 .72028 L .65548 .72011 L F
.65724 .71781 m .65645 .7187 L .65599 .71944 L F
.65645 .7187 m .65504 .72028 L .65599 .71944 L F
.65567 .71991 m .65548 .72011 L .65555 .72008 L F
.957 .625 .233 r
.65328 .71509 m .6515 .71713 L .65254 .71501 L F
.65328 .71509 m .65267 .71602 L .6515 .71713 L F
.758 .642 .733 r
.65254 .71501 m .64823 .71685 L .65118 .71691 L F
.532 .288 .49 r
.65267 .71602 m .65568 .71443 L .65173 .71339 L F
.65267 .71602 m .65507 .71648 L .65568 .71443 L F
0 .528 .808 r
.65275 .71581 m .65507 .71648 L .65267 .71602 L F
.591 .02 0 r
.65275 .71581 m .65588 .71721 L .65507 .71648 L F
.65588 .71721 m .65724 .71781 L .65507 .71648 L F
.665 .818 .382 r
.65701 .71295 m .65525 .71616 L .65625 .71448 L F
.65525 .71616 m .65507 .71648 L .65625 .71448 L F
.991 .734 .424 r
.65625 .71448 m .65642 .71209 L .65796 .71139 L F
.849 .775 .779 r
.64931 .63012 m .64596 .63194 L .64814 .62935 L F
.64931 .63012 m .64761 .63282 L .64596 .63194 L F
.553 .829 .997 r
.65041 .6289 m .64931 .63012 L .64814 .62935 L F
.565 .412 .632 r
.51006 .82804 m .50855 .83056 L .50792 .82828 L F
.51006 .82804 m .50855 .83056 L .50792 .82828 L F
.796 .542 .553 r
.51324 .83291 m .51539 .83062 L .51315 .83094 L F
.51324 .83291 m .51668 .83339 L .51539 .83062 L F
.648 .581 .767 r
.51668 .83339 m .51762 .82997 L .51539 .83062 L F
.733 .577 .68 r
.60487 .79381 m .60817 .79643 L .60834 .79413 L F
.569 .465 .696 r
.44846 .87101 m .45051 .87075 L .44996 .86767 L F
.58 .438 .653 r
.44846 .87101 m .45076 .87307 L .45051 .87075 L F
.44846 .87101 m .44863 .87345 L .45076 .87307 L F
.724 .317 .277 r
.69852 .74591 m .70171 .74626 L .69986 .74521 L F
.611 .577 .791 r
.42424 .74736 m .42553 .74505 L .42276 .74384 L F
.42424 .74736 m .42634 .74688 L .42553 .74505 L F
.929 .582 .352 r
.51827 .85962 m .51993 .86034 L .51901 .86183 L F
.791 .374 .258 r
.51901 .86183 m .51993 .86034 L .52079 .86179 L F
.722 .711 .839 r
.69744 .74446 m .69658 .7439 L .69576 .74317 L F
.69744 .74446 m .69586 .74522 L .69658 .7439 L F
.734 .66 .777 r
.5216 .87149 m .52331 .87419 L .5206 .87323 L F
.757 .56 .631 r
.52331 .87419 m .51961 .87465 L .5206 .87323 L F
.52331 .87419 m .5241 .8752 L .51961 .87465 L F
.481 .884 .949 r
.52743 .87306 m .52452 .87411 L .52442 .87409 L F
.182 .39 .831 r
.52459 .87393 m .52331 .87419 L .5216 .87149 L F
.481 .884 .949 r
.52743 .87306 m .5251 .87344 L .52557 .87176 L F
.153 .381 .832 r
.52469 .87264 m .52469 .87384 L .5216 .87149 L F
.5249 .87305 m .52469 .87384 L .52469 .87264 L F
.52469 .87384 m .52459 .87393 L .5216 .87149 L F
.52458 .87256 m .5216 .87149 L .52105 .87082 L F
.481 .884 .949 r
.5251 .87344 m .52462 .87251 L .52557 .87176 L F
.153 .381 .832 r
.52498 .87275 m .52469 .87264 L .52458 .87256 L F
.52469 .87264 m .5216 .87149 L .52458 .87256 L F
.831 .796 .818 r
.5216 .87149 m .5206 .87323 L .51908 .8726 L F
.5216 .87149 m .51908 .8726 L .52105 .87082 L F
.557 0 0 r
.52038 .87133 m .52396 .87244 L .52105 .87082 L F
.52396 .87244 m .52498 .87275 L .52458 .87256 L F
.52396 .87244 m .52458 .87256 L .52105 .87082 L F
.481 .884 .949 r
.52743 .87306 m .52442 .87409 L .52516 .87343 L F
.153 .381 .832 r
.52469 .87384 m .52465 .87398 L .52459 .87393 L F
.313 .791 .915 r
.52301 .87377 m .52469 .87384 L .5249 .87305 L F
.671 .739 .901 r
.52902 .87214 m .52743 .87306 L .52557 .87176 L F
.199 0 .244 r
.52697 .87209 m .52557 .87176 L .52487 .87317 L F
.481 .884 .949 r
.52516 .87343 m .52459 .87393 L .5251 .87344 L F
.52459 .87393 m .52442 .87409 L .5251 .87344 L F
.182 .39 .831 r
.52465 .87398 m .52451 .87401 L .52459 .87393 L F
.703 .733 .874 r
.52743 .87306 m .52577 .87569 L .52452 .87411 L F
.3 .418 .815 r
.52577 .87569 m .52465 .87398 L .52452 .87411 L F
.52577 .87569 m .52331 .87419 L .52465 .87398 L F
.199 0 .244 r
.52664 .87238 m .52487 .87317 L .52416 .8746 L F
.52697 .87209 m .52487 .87317 L .52664 .87238 L F
.481 .884 .949 r
.5251 .87344 m .52468 .87384 L .52348 .87379 L F
.52381 .87365 m .52348 .87379 L .52301 .87377 L F
.5251 .87344 m .52348 .87379 L .52381 .87365 L F
.52468 .87384 m .52442 .87409 L .52301 .87377 L F
.313 .791 .915 r
.52301 .87377 m .52465 .87398 L .52469 .87384 L F
.481 .884 .949 r
.52487 .87306 m .52301 .87377 L .52457 .87255 L F
.5251 .87344 m .52457 .87255 L .52469 .87264 L F
.313 .791 .915 r
.52301 .87377 m .5249 .87305 L .52498 .87275 L F
.481 .884 .949 r
.5251 .87344 m .52301 .87377 L .52487 .87306 L F
.52458 .87256 m .52457 .87255 L .52457 .87255 L F
.5251 .87344 m .52457 .87255 L .52458 .87256 L F
.52469 .87264 m .52457 .87255 L .52462 .87251 L F
.153 .381 .832 r
.52498 .87275 m .5249 .87305 L .52469 .87264 L F
.182 .39 .831 r
.52451 .87401 m .52331 .87419 L .52459 .87393 L F
.3 .418 .815 r
.52577 .87569 m .5241 .8752 L .52331 .87419 L F
.846 .999 .801 r
.51588 .83712 m .51653 .83554 L .51768 .83592 L F
.7 .646 .792 r
.52004 .83369 m .51768 .83592 L .51668 .83339 L F
.982 .722 .458 r
.51768 .83592 m .51653 .83554 L .51668 .83339 L F
.51668 .83339 m .51653 .83554 L .51768 .83592 L F
.562 .467 .705 r
.50934 .86241 m .50778 .86511 L .50713 .86301 L F
.50934 .86241 m .50983 .86497 L .50778 .86511 L F
.485 .402 .687 r
.51001 .86756 m .50778 .86511 L .50983 .86497 L F
.51001 .86756 m .50814 .86813 L .50778 .86511 L F
.743 .486 .542 r
.48964 .83608 m .49286 .83836 L .49249 .8365 L F
.833 .682 .696 r
.60838 .79879 m .60623 .80149 L .60929 .8017 L F
.832 .686 .701 r
.60623 .80149 m .60748 .80448 L .60929 .8017 L F
.74 .634 .741 r
.60929 .8017 m .61127 .79892 L .60838 .79879 L F
.72 .433 .491 r
.71349 .73586 m .71373 .73826 L .71538 .73642 L F
.967 .645 .282 r
.71252 .73501 m .71373 .73826 L .71349 .73586 L F
.813 .752 .795 r
.70808 .73556 m .70506 .73628 L .7072 .7357 L F
0 0 0 r
.7072 .7357 m .71029 .73539 L .70808 .73556 L F
.729 .55 .649 r
.50175 .85173 m .50443 .85208 L .50418 .84938 L F
.527 .463 .728 r
.50418 .84938 m .50624 .84686 L .50357 .84782 L F
.574 .936 .92 r
.50807 .84792 m .50462 .84877 L .50608 .84871 L F
0 0 0 r
.50705 .84817 m .50681 .84835 L .50462 .84877 L F
.50807 .84792 m .50779 .84802 L .50705 .84817 L F
.50779 .84802 m .50681 .84835 L .50705 .84817 L F
.527 .463 .728 r
.50418 .84938 m .50608 .84871 L .50611 .84837 L F
.50477 .84866 m .50611 .84837 L .50624 .84686 L F
.50418 .84938 m .50611 .84837 L .50477 .84866 L F
.66 .568 .741 r
.50443 .85208 m .50608 .84871 L .50418 .84938 L F
.334 .064 .346 r
.38664 .77768 m .38769 .77956 L .38863 .77715 L F
.38664 .77768 m .38603 .78021 L .38769 .77956 L F
.731 .578 .683 r
.60169 .79362 m .60505 .79149 L .60161 .79119 L F
.60169 .79362 m .60487 .79381 L .60505 .79149 L F
.144 0 .091 r
.52516 .83565 m .52273 .83824 L .52317 .83666 L F
.504 .216 .409 r
.43557 .7624 m .43523 .76413 L .43312 .76425 L F
.507 .219 .41 r
.43557 .7624 m .43743 .7638 L .43523 .76413 L F
.54 .203 .345 r
.4378 .76236 m .43743 .7638 L .43557 .7624 L F
.771 .58 .64 r
.66917 .75114 m .67076 .75407 L .6723 .75138 L F
0 .204 .691 r
.51144 .87091 m .50815 .86814 L .50973 .87035 L F
.914 .562 .357 r
.51068 .87235 m .51144 .87091 L .50973 .87035 L F
.094 .196 .68 r
.51007 .86946 m .51048 .87138 L .50973 .87035 L F
.51048 .87138 m .51068 .87235 L .50973 .87035 L F
0 .204 .691 r
.50815 .86814 m .50814 .86813 L .50973 .87035 L F
.802 .402 .294 r
.51256 .87358 m .51144 .87091 L .51068 .87235 L F
.527 .397 .647 r
.45308 .85469 m .45504 .85436 L .45481 .85194 L F
.498 .353 .615 r
.45308 .85469 m .45506 .85674 L .45504 .85436 L F
.45308 .85469 m .45322 .85706 L .45506 .85674 L F
.667 .671 .844 r
.64492 .72986 m .64414 .73319 L .64384 .73038 L F
.64492 .72986 m .64636 .73269 L .64414 .73319 L F
.857 .955 .874 r
.5184 .88169 m .51971 .88178 L .52081 .88016 L F
.5184 .88169 m .52081 .88016 L .52064 .88125 L F
.85 .436 .251 r
.52064 .88125 m .51979 .8785 L .51843 .87809 L F
.52064 .88125 m .52081 .88016 L .51979 .8785 L F
0 0 0 r
.35484 .80873 m .35549 .80867 L .35383 .80957 L F
.35484 .80873 m .35734 .8076 L .35549 .80867 L F
0 .492 .722 r
.54432 .86002 m .54537 .86023 L .54205 .85965 L F
.54432 .86002 m .54537 .86023 L .54205 .85965 L F
.668 .958 .942 r
.54432 .86002 m .54537 .86023 L .54602 .85903 L F
.54432 .86002 m .54537 .86023 L .54602 .85903 L F
.71 .607 .739 r
.63237 .7435 m .63361 .74681 L .63559 .74587 L F
.672 .726 .89 r
.66267 .74177 m .66496 .74095 L .66152 .7404 L F
.904 .706 .625 r
.64761 .63282 m .64725 .635 L .64596 .63194 L F
.282 .701 .97 r
.65673 .72137 m .65794 .72094 L .65472 .72071 L F
.65673 .72137 m .65921 .72181 L .65794 .72094 L F
.08 .244 .733 r
.57282 .82921 m .5721 .83089 L .5717 .83103 L F
.57282 .82921 m .57396 .83292 L .5721 .83089 L F
.587 .36 .54 r
.5721 .83089 m .57396 .83292 L .57175 .83311 L F
.38 0 .152 r
.348 .73462 m .35127 .73235 L .3493 .73266 L F
.398 .004 .17 r
.3337 .74059 m .33565 .74053 L .33683 .73864 L F
.289 0 .108 r
.33683 .73864 m .33748 .74003 L .33879 .73823 L F
.33683 .73864 m .33565 .74053 L .33748 .74003 L F
.382 .05 .274 r
.41088 .77811 m .40815 .78003 L .40874 .77831 L F
.673 .77 .923 r
.40845 .7266 m .40572 .72713 L .40446 .72557 L F
.532 .369 .606 r
.45481 .85194 m .45678 .84925 L .45473 .8496 L F
.593 .947 .903 r
.57543 .84687 m .57735 .84596 L .57625 .84586 L F
.544 .302 .499 r
.4408 .75894 m .43997 .76198 L .4378 .76236 L F
.584 .35 .527 r
.44284 .75884 m .43997 .76198 L .4408 .75894 L F
.695 .577 .719 r
.70587 .74086 m .70719 .74401 L .70929 .74114 L F
.709 .598 .73 r
.70719 .74401 m .709 .7432 L .70929 .74114 L F
.352 0 0 r
.35952 .75356 m .35836 .75408 L .35631 .75404 L F
.218 0 0 r
.36159 .75338 m .35836 .75408 L .35952 .75356 L F
.557 .547 .799 r
.52127 .84084 m .51881 .84033 L .52102 .83981 L F
.879 .512 .344 r
.58572 .78473 m .58644 .7829 L .58513 .78329 L F
.58572 .78473 m .58801 .78563 L .58644 .7829 L F
.59 .159 .19 r
.6711 .70803 m .67317 .70819 L .67409 .70664 L F
.783 .385 .298 r
.67317 .70819 m .67614 .70967 L .67409 .70664 L F
.518 .647 .914 r
.69263 .71928 m .69107 .71994 L .68974 .71701 L F
.08 .379 .842 r
.69285 .72161 m .69107 .71994 L .69263 .71928 L F
.838 .987 .714 r
.37747 .72344 m .37825 .72151 L .37954 .7227 L F
.37747 .72344 m .37617 .72431 L .37825 .72151 L F
.759 .584 .66 r
.56392 .80948 m .56683 .81188 L .56732 .80965 L F
.52 .305 .528 r
.44951 .75614 m .44772 .75427 L .44979 .7538 L F
.44951 .75614 m .44744 .75662 L .44772 .75427 L F
0 0 0 r
.58934 .81501 m .58874 .81504 L .58791 .81545 L F
.58934 .81501 m .58791 .81545 L .58692 .81556 L F
.346 .054 .319 r
.36525 .75257 m .3638 .75183 L .36795 .75091 L F
0 0 0 r
.36705 .75177 m .36795 .75091 L .36911 .75107 L F
.36705 .75177 m .36525 .75257 L .36795 .75091 L F
.716 .58 .702 r
.59831 .78858 m .59862 .79126 L .60161 .79119 L F
.712 .535 .648 r
.59862 .79126 m .59953 .7937 L .60161 .79119 L F
.724 .552 .657 r
.60161 .79119 m .59953 .7937 L .60169 .79362 L F
.556 .519 .77 r
.65951 .74066 m .66051 .73737 L .65844 .73763 L F
.65951 .74066 m .66152 .7404 L .66051 .73737 L F
.302 0 .017 r
.53205 .82213 m .53313 .82226 L .53387 .82115 L F
.127 0 0 r
.53313 .82226 m .53608 .82027 L .53387 .82115 L F
.662 .725 .896 r
.38893 .89281 m .39034 .89042 L .38896 .89069 L F
.38893 .89281 m .39194 .89193 L .39034 .89042 L F
.283 0 0 r
.47696 .87867 m .47922 .87852 L .48033 .8779 L F
.696 .263 .217 r
.47559 .87803 m .47922 .87852 L .47696 .87867 L F
.47559 .87803 m .47747 .87951 L .47922 .87852 L F
.47747 .87951 m .47792 .87986 L .47922 .87852 L F
.283 0 0 r
.48033 .8779 m .47922 .87852 L .48034 .8779 L F
.553 .071 .065 r
.48034 .8779 m .47922 .87852 L .48248 .87833 L F
.985 .812 .587 r
.5241 .8752 m .52248 .87765 L .51961 .87465 L F
.5241 .8752 m .52349 .87856 L .52248 .87765 L F
.185 .539 .926 r
.67848 .6952 m .67947 .69718 L .678 .69609 L F
.855 .942 .877 r
.68164 .69384 m .67947 .69718 L .67848 .6952 L F
.915 .978 .717 r
.49325 .84875 m .49333 .85011 L .49503 .84758 L F
.656 .944 .695 r
.49584 .84629 m .49503 .84758 L .49856 .84801 L F
.89 .642 .557 r
.57072 .84666 m .57169 .84804 L .5719 .84839 L F
0 0 0 r
.57169 .84804 m .57399 .84756 L .5719 .84839 L F
.564 .38 .59 r
.48217 .86294 m .48417 .86333 L .48447 .85998 L F
.59 .397 .589 r
.48417 .86333 m .4868 .86011 L .48447 .85998 L F
.702 .794 .922 r
.66949 .76039 m .67166 .75941 L .66857 .75914 L F
.581 .63 .865 r
.68848 .72469 m .69035 .72756 L .69205 .72636 L F
.968 .743 .546 r
.48091 .86713 m .48301 .86593 L .47875 .86511 L F
.48091 .86713 m .48219 .86767 L .48301 .86593 L F
0 0 0 r
.51908 .84447 m .51687 .84647 L .51677 .84411 L F
.476 .804 1 r
.4858 .88374 m .48719 .88457 L .48915 .88416 L F
.208 .144 .561 r
.68608 .72736 m .68646 .72966 L .68525 .72937 L F
.474 .176 .38 r
.65089 .63978 m .64838 .64263 L .6482 .64056 L F
.65089 .63978 m .65063 .64219 L .64838 .64263 L F
.485 .19 .389 r
.65322 .64017 m .65063 .64219 L .65089 .63978 L F
.759 .565 .635 r
.61127 .79892 m .60817 .79643 L .60838 .79879 L F
0 0 0 r
.63506 .73246 m .63774 .73044 L .63569 .73027 L F
.786 .816 .876 r
.71373 .73826 m .71677 .73833 L .71538 .73642 L F
.71 .607 .739 r
.63237 .7435 m .63559 .74587 L .63448 .74306 L F
.718 .332 .318 r
.4926 .82276 m .49467 .82483 L .496 .82338 L F
.867 .961 .624 r
.496 .82338 m .49467 .82483 L .49481 .82513 L F
.439 .333 .637 r
.33971 .69064 m .3402 .69341 L .33946 .69347 L F
.645 .51 .684 r
.34166 .68801 m .34095 .69128 L .33971 .69064 L F
.028 0 .29 r
.34095 .69128 m .3402 .69341 L .33971 .69064 L F
.505 .025 .048 r
.56036 .78241 m .55697 .78268 L .55834 .78173 L F
.985 .71 .405 r
.70484 .74234 m .70587 .74086 L .70505 .74005 L F
.70484 .74234 m .70586 .74294 L .70587 .74086 L F
.65 .696 .879 r
.70587 .74086 m .70929 .74114 L .70741 .73872 L F
.74 .599 .7 r
.59502 .7885 m .59628 .79108 L .59831 .78858 L F
.739 .597 .698 r
.59628 .79108 m .59862 .79126 L .59831 .78858 L F
.817 .609 .622 r
.58633 .79895 m .58327 .79869 L .58347 .79633 L F
.827 .653 .667 r
.58633 .79895 m .58312 .80096 L .58327 .79869 L F
.58633 .79895 m .5849 .80174 L .58312 .80096 L F
.364 .815 .941 r
.70588 .72211 m .70489 .72306 L .70355 .72186 L F
.609 .458 .652 r
.70553 .71984 m .70761 .72048 L .70742 .72041 L F
.766 .544 .597 r
.70485 .71811 m .70742 .72041 L .70562 .71981 L F
.609 .458 .652 r
.70621 .72 m .70742 .72041 L .70661 .7201 L F
.70553 .71984 m .70742 .72041 L .70621 .72 L F
.766 .544 .597 r
.70485 .71811 m .7085 .71848 L .70742 .72041 L F
.724 .975 .925 r
.70738 .72176 m .70772 .71988 L .7085 .71848 L F
.609 .458 .652 r
.70553 .71984 m .70588 .72211 L .7084 .72072 L F
.766 .544 .597 r
.70584 .7203 m .70742 .72041 L .70657 .72192 L F
.70621 .72 m .70742 .72041 L .70584 .7203 L F
.542 .412 .653 r
.70355 .72186 m .70588 .72211 L .70553 .71984 L F
.339 .637 .963 r
.70584 .7203 m .70553 .71984 L .70485 .71811 L F
.70657 .72192 m .70553 .71984 L .70584 .7203 L F
.621 .431 .605 r
.70587 .72035 m .70725 .72026 L .70621 .72 L F
.542 .412 .653 r
.70355 .72186 m .70553 .71984 L .70275 .72077 L F
.339 .637 .963 r
.70657 .72192 m .70275 .72077 L .70553 .71984 L F
.621 .431 .605 r
.70483 .72145 m .70617 .72079 L .70587 .72035 L F
.70617 .72079 m .70725 .72026 L .70587 .72035 L F
.70506 .72092 m .70621 .72 L .70553 .71984 L F
.70483 .72145 m .70621 .72 L .70506 .72092 L F
.766 .544 .597 r
.70562 .71981 m .70621 .72 L .70584 .7203 L F
.609 .458 .652 r
.70588 .72211 m .70742 .72157 L .70748 .72123 L F
.724 .975 .925 r
.70738 .72176 m .70657 .72192 L .70772 .71988 L F
.609 .458 .652 r
.70661 .7201 m .7084 .72072 L .70725 .72026 L F
.70761 .72048 m .7084 .72072 L .70661 .7201 L F
.724 .975 .925 r
.70915 .72142 m .70738 .72176 L .7078 .72055 L F
.70906 .72102 m .7078 .72055 L .7085 .71848 L F
.70915 .72142 m .7078 .72055 L .70906 .72102 L F
.667 .819 .957 r
.70915 .72142 m .70727 .72258 L .70812 .72251 L F
.546 .371 .595 r
.70812 .72251 m .70584 .72346 L .70548 .72298 L F
.667 .819 .957 r
.70727 .72258 m .70584 .72346 L .70812 .72251 L F
.535 .368 .602 r
.70727 .72258 m .70493 .72441 L .70584 .72346 L F
.724 .975 .925 r
.70915 .72142 m .70812 .72251 L .70778 .72239 L F
.535 .368 .602 r
.70915 .72142 m .70778 .72239 L .70727 .72258 L F
.724 .975 .925 r
.70915 .72142 m .70778 .72239 L .70693 .72206 L F
.535 .368 .602 r
.70915 .72142 m .7078 .72238 L .70778 .72239 L F
.364 .815 .941 r
.70727 .72258 m .70812 .72251 L .70688 .72272 L F
.546 .371 .595 r
.70812 .72251 m .70548 .72298 L .70489 .72306 L F
.535 .368 .602 r
.7078 .72238 m .70493 .72441 L .70727 .72258 L F
.364 .815 .941 r
.7054 .72272 m .70727 .72258 L .70489 .72306 L F
.70727 .72258 m .70688 .72272 L .70489 .72306 L F
.537 .396 .637 r
.70765 .72443 m .70852 .72588 L .70493 .72441 L F
.872 .43 .097 r
.70765 .72443 m .70852 .72588 L .70837 .72572 L F
.535 .368 .602 r
.70688 .72303 m .70765 .72443 L .70493 .72441 L F
.872 .43 .097 r
.70765 .72443 m .70837 .72572 L .70605 .72317 L F
.535 .368 .602 r
.7078 .72238 m .70765 .72443 L .70688 .72303 L F
.70915 .72142 m .70876 .7222 L .7078 .72238 L F
.70876 .7222 m .70765 .72443 L .7078 .72238 L F
.364 .815 .941 r
.70621 .72217 m .7076 .72242 L .7054 .72272 L F
.7076 .72242 m .70812 .72251 L .7064 .72264 L F
.7076 .72242 m .7064 .72264 L .7054 .72272 L F
.609 .458 .652 r
.70621 .72217 m .70685 .72207 L .70742 .72157 L F
.364 .815 .941 r
.70657 .72192 m .70693 .72206 L .70621 .72217 L F
.86 .768 .76 r
.70605 .72317 m .70765 .72443 L .70876 .7222 L F
.70783 .72217 m .70876 .7222 L .70915 .72142 L F
.70605 .72317 m .70876 .7222 L .70783 .72217 L F
.364 .815 .941 r
.70655 .72211 m .70812 .72251 L .70621 .72217 L F
.70693 .72206 m .70714 .72214 L .70655 .72211 L F
.70714 .72214 m .70812 .72251 L .70655 .72211 L F
.609 .458 .652 r
.70588 .72211 m .70621 .72217 L .70742 .72157 L F
.70621 .72217 m .70665 .72224 L .70685 .72207 L F
.70748 .72123 m .70742 .72157 L .7084 .72072 L F
.70665 .72224 m .7069 .72228 L .70743 .72174 L F
.70665 .72224 m .70743 .72174 L .7084 .72072 L F
.724 .975 .925 r
.70738 .72176 m .70693 .72206 L .70657 .72192 L F
.70915 .72142 m .70693 .72206 L .70738 .72176 L F
.364 .815 .941 r
.70623 .72215 m .70621 .72217 L .70588 .72211 L F
.70621 .72217 m .70489 .72306 L .70588 .72211 L F
.609 .458 .652 r
.70588 .72211 m .70605 .72317 L .7069 .72228 L F
.542 .412 .653 r
.70355 .72186 m .70605 .72317 L .70588 .72211 L F
.364 .815 .941 r
.70657 .72192 m .70623 .72215 L .70355 .72186 L F
.873 .966 .853 r
.54184 .84702 m .54434 .84505 L .54343 .84537 L F
.54434 .84505 m .54184 .84702 L .54343 .84537 L F
0 0 .388 r
.54736 .84406 m .54769 .84606 L .54825 .84577 L F
.54736 .84406 m .54825 .84577 L .54592 .84352 L F
.463 .183 .402 r
.47189 .83491 m .47511 .83286 L .47307 .83312 L F
.93 .876 .761 r
.60495 .83195 m .60766 .8309 L .60687 .83025 L F
.60495 .83195 m .60633 .83341 L .60766 .8309 L F
.958 .763 .597 r
.60766 .8309 m .60669 .82789 L .60687 .83025 L F
.538 .26 .44 r
.66556 .63002 m .6655 .63176 L .66324 .63195 L F
.545 .817 .996 r
.66666 .62865 m .66556 .63002 L .66424 .6272 L F
.66666 .62865 m .66791 .62963 L .66556 .63002 L F
.627 .332 .45 r
.66556 .63002 m .66785 .63181 L .6655 .63176 L F
.573 .354 .544 r
.66791 .62963 m .66785 .63181 L .66556 .63002 L F
.39 .114 .369 r
.4165 .76249 m .41775 .7638 L .41834 .76208 L F
.4165 .76249 m .41588 .76431 L .41775 .7638 L F
.733 .577 .68 r
.60487 .79381 m .60497 .79644 L .60817 .79643 L F
.766 .588 .657 r
.605 .79859 m .60817 .79643 L .60497 .79644 L F
.605 .79859 m .60838 .79879 L .60817 .79643 L F
.436 .067 .238 r
.41866 .77347 m .41804 .77474 L .41592 .77509 L F
.49 .153 .322 r
.4209 .77269 m .41804 .77474 L .41866 .77347 L F
.406 0 .122 r
.35783 .72962 m .36129 .72761 L .35915 .72766 L F
.662 .783 .939 r
.68426 .71944 m .68566 .72119 L .68747 .72001 L F
.678 .776 .924 r
.68426 .71944 m .68506 .72149 L .68747 .72001 L F
.511 .409 .676 r
.5438 .83546 m .54157 .83289 L .54476 .83352 L F
.517 .195 .36 r
.54514 .83422 m .5438 .83546 L .54476 .83352 L F
.6 .16 .176 r
.53366 .81425 m .53707 .81432 L .53449 .81314 L F
.399 0 0 r
.53449 .81314 m .53707 .81432 L .53873 .81481 L F
.121 .074 .526 r
.56789 .78799 m .56894 .78525 L .56979 .78594 L F
.818 .888 .894 r
.52449 .81342 m .52051 .81493 L .52281 .81461 L F
.534 .412 .661 r
.5264 .8152 m .52449 .81342 L .5262 .81206 L F
.5264 .8152 m .52433 .81571 L .52449 .81342 L F
.195 0 0 r
.52449 .81342 m .52468 .81403 L .5262 .81206 L F
.52449 .81342 m .52281 .81461 L .52468 .81403 L F
.738 .604 .707 r
.66811 .74347 m .67146 .7438 L .67015 .74074 L F
.776 .629 .697 r
.66805 .74585 m .67146 .7438 L .66811 .74347 L F
.66805 .74585 m .67128 .74605 L .67146 .7438 L F
.632 .103 0 r
.65785 .62392 m .66115 .62465 L .65922 .62375 L F
.646 .095 0 r
.65981 .72212 m .65794 .72094 L .65921 .72181 L F
.897 .768 .712 r
.6047 .81199 m .60616 .81238 L .60531 .8095 L F
.883 .602 .507 r
.60488 .81368 m .60616 .81238 L .6047 .81199 L F
.60488 .81368 m .60645 .81482 L .60616 .81238 L F
.096 .198 .682 r
.51007 .86946 m .50814 .86813 L .51001 .86756 L F
.51007 .86946 m .50973 .87035 L .50814 .86813 L F
.555 .326 .522 r
.34882 .75916 m .34639 .76149 L .34685 .75961 L F
.744 .45 .484 r
.50624 .84686 m .50281 .84712 L .50357 .84782 L F
.871 .747 .723 r
.60596 .81742 m .60734 .81765 L .60645 .81482 L F
.937 .677 .519 r
.60668 .81768 m .60734 .81765 L .60596 .81742 L F
.60668 .81768 m .60741 .81998 L .60734 .81765 L F
.817 .444 .348 r
.61081 .82039 m .60734 .81765 L .60741 .81998 L F
.998 .781 .469 r
.67389 .73016 m .6732 .72709 L .67404 .72785 L F
.493 .683 .951 r
.57397 .82199 m .57268 .82317 L .57193 .82203 L F
.782 .568 .611 r
.59652 .79351 m .59862 .79126 L .59628 .79108 L F
.59652 .79351 m .59953 .7937 L .59862 .79126 L F
.417 0 .071 r
.52102 .84556 m .51908 .84447 L .52206 .84304 L F
.559 .14 .204 r
.52312 .84532 m .52206 .84304 L .52426 .84372 L F
.52312 .84532 m .52102 .84556 L .52206 .84304 L F
.217 0 .213 r
.55691 .80153 m .55624 .80374 L .55866 .80164 L F
.261 .667 .967 r
.45541 .87873 m .45628 .87812 L .45424 .87785 L F
.45541 .87873 m .45742 .87892 L .45628 .87812 L F
.579 .59 .829 r
.52909 .86243 m .52588 .85983 L .52646 .86258 L F
.511 .776 .992 r
.5256 .86434 m .52909 .86243 L .52646 .86258 L F
.718 .582 .701 r
.52909 .86243 m .52976 .86515 L .52675 .86524 L F
.511 .776 .992 r
.5256 .86434 m .52799 .86428 L .52909 .86243 L F
0 0 .428 r
.52996 .86464 m .52976 .86515 L .52909 .86243 L F
.747 .395 .385 r
.52996 .86464 m .52909 .86243 L .52799 .86428 L F
.777 .702 .781 r
.69298 .73263 m .69396 .73579 L .6908 .73525 L F
.731 .631 .747 r
.69101 .73987 m .68874 .74271 L .68769 .73974 L F
.734 .573 .673 r
.68769 .73974 m .68954 .74061 L .69101 .73987 L F
.798 .762 .82 r
.69101 .73987 m .68954 .74061 L .69135 .73735 L F
.69165 .73738 m .69135 .73735 L .69193 .7363 L F
.69101 .73987 m .69135 .73735 L .69165 .73738 L F
.722 .282 .204 r
.69396 .73579 m .69321 .73752 L .6908 .73525 L F
.69321 .73752 m .69317 .73761 L .69306 .7375 L F
.908 .945 .816 r
.6899 .73783 m .68954 .74061 L .68905 .73847 L F
.69193 .7363 m .69135 .73735 L .6899 .73783 L F
.69135 .73735 m .68954 .74061 L .6899 .73783 L F
.722 .282 .204 r
.69321 .73752 m .69306 .7375 L .69251 .73696 L F
.69259 .73694 m .69251 .73696 L .6908 .73525 L F
.69321 .73752 m .69251 .73696 L .69259 .73694 L F
.718 .67 .801 r
.69635 .73321 m .69396 .73579 L .69298 .73263 L F
.277 0 .028 r
.69532 .73682 m .69396 .73579 L .69616 .73698 L F
.69532 .73682 m .69317 .73761 L .69396 .73579 L F
.681 .608 .768 r
.69635 .73321 m .69851 .7356 L .69396 .73579 L F
.564 .158 .231 r
.69851 .7356 m .69616 .73698 L .69396 .73579 L F
.739 .57 .664 r
.66721 .75373 m .66917 .75114 L .66726 .7516 L F
.556 .62 .871 r
.33745 .67386 m .337 .67667 L .33543 .67429 L F
.33745 .67386 m .33899 .67632 L .337 .67667 L F
.97 .744 .541 r
.64692 .63715 m .6482 .64056 L .64538 .63983 L F
.786 .507 .515 r
.6482 .64056 m .64516 .64215 L .64538 .63983 L F
.6482 .64056 m .64838 .64263 L .64516 .64215 L F
.455 0 0 r
.56227 .77836 m .56512 .77913 L .56569 .77782 L F
.535 .056 .065 r
.56512 .77913 m .56781 .77805 L .56569 .77782 L F
.702 .25 .176 r
.53889 .81676 m .53873 .81481 L .53707 .81432 L F
.53889 .81676 m .54084 .81707 L .53873 .81481 L F
.406 .634 .948 r
.67985 .71056 m .68189 .71074 L .68066 .71187 L F
0 0 0 r
.68189 .71074 m .68088 .71416 L .68066 .71187 L F
.756 .813 .898 r
.67767 .71198 m .67985 .71056 L .68066 .71187 L F
.75 .325 .241 r
.52098 .82777 m .52427 .8285 L .52133 .8305 L F
.52098 .82777 m .5229 .82987 L .52427 .8285 L F
.067 0 0 r
.52427 .8285 m .52495 .82909 L .52639 .82838 L F
.52427 .8285 m .5229 .82987 L .52495 .82909 L F
.475 .15 .336 r
.65669 .71648 m .65905 .71472 L .65701 .71569 L F
.676 .373 .453 r
.52976 .86515 m .5295 .8675 L .52675 .86524 L F
0 0 0 r
.52996 .86464 m .5295 .8675 L .52976 .86515 L F
.773 .825 .894 r
.68298 .72244 m .68426 .71944 L .68183 .72038 L F
.924 .729 .62 r
.68282 .72507 m .68298 .72244 L .68179 .72146 L F
.797 .749 .809 r
.68145 .72231 m .68183 .72038 L .68085 .71903 L F
.844 .796 .805 r
.68124 .72076 m .68183 .72038 L .68145 .72231 L F
.924 .729 .62 r
.68169 .7221 m .68179 .72146 L .68129 .72104 L F
.68282 .72507 m .68179 .72146 L .68169 .7221 L F
.839 .78 .795 r
.68298 .72244 m .68183 .72038 L .68124 .72076 L F
.68298 .72244 m .68124 .72076 L .68129 .72104 L F
.325 .412 .797 r
.68124 .72076 m .68336 .72066 L .6815 .72227 L F
.68096 .71911 m .68103 .71915 L .68124 .72076 L F
.957 .722 .539 r
.68085 .71903 m .68183 .72038 L .68092 .7165 L F
.688 .719 .873 r
.68085 .71903 m .68426 .71944 L .68183 .72038 L F
.68183 .72038 m .68426 .71944 L .68085 .71903 L F
.293 0 .075 r
.68183 .72038 m .68426 .71944 L .68131 .72077 L F
.325 .412 .797 r
.68115 .72067 m .68123 .72089 L .68145 .72231 L F
.844 .796 .805 r
.68108 .72087 m .68124 .72076 L .68145 .72231 L F
.325 .412 .797 r
.68085 .71903 m .68123 .72089 L .68115 .72067 L F
.839 .78 .795 r
.68129 .72104 m .68124 .72076 L .68108 .72087 L F
.293 0 .075 r
.68124 .72076 m .68131 .72077 L .68108 .72087 L F
.68183 .72038 m .68131 .72077 L .68124 .72076 L F
.325 .412 .797 r
.68121 .72076 m .6815 .72227 L .68145 .72231 L F
.68096 .71911 m .68124 .72076 L .68121 .72076 L F
.68124 .72076 m .6815 .72227 L .68121 .72076 L F
.68103 .71915 m .68336 .72066 L .68124 .72076 L F
.924 .729 .62 r
.68279 .72558 m .68282 .72507 L .68108 .72087 L F
.68282 .72507 m .68129 .72104 L .68108 .72087 L F
.68279 .72558 m .68164 .72242 L .68166 .72441 L F
.232 .137 .536 r
.68165 .72298 m .68166 .72441 L .68153 .72314 L F
.68169 .7221 m .68153 .72314 L .68145 .72231 L F
.841 .582 .037 r
.68145 .72231 m .68166 .72441 L .68108 .72087 L F
.924 .729 .62 r
.68164 .72242 m .68108 .72087 L .68166 .72441 L F
.232 .137 .536 r
.68336 .72066 m .68166 .72441 L .68165 .72298 L F
.68336 .72066 m .68153 .72314 L .68169 .7221 L F
.325 .412 .797 r
.68085 .71903 m .68096 .71911 L .68123 .72089 L F
.339 .736 .983 r
.57735 .84596 m .5778 .84493 L .57625 .84586 L F
.57735 .84596 m .58235 .84638 L .5778 .84493 L F
.731 .555 .653 r
.60169 .79362 m .60297 .79628 L .60487 .79381 L F
.762 .6 .677 r
.60297 .79628 m .60497 .79644 L .60487 .79381 L F
.367 .412 .775 r
.53321 .81695 m .53366 .81425 L .53143 .81452 L F
.53321 .81695 m .53472 .8171 L .53366 .81425 L F
.475 .15 .336 r
.65669 .71648 m .6588 .71619 L .65905 .71472 L F
.462 .14 .332 r
.6588 .71619 m .66024 .71602 L .65905 .71472 L F
.499 .141 .289 r
.65905 .71472 m .66024 .71602 L .66184 .71452 L F
.076 0 0 r
.33897 .69495 m .33946 .69347 L .3402 .69341 L F
.33897 .69495 m .33733 .69578 L .33946 .69347 L F
.633 .458 .629 r
.45118 .86002 m .4538 .86226 L .45349 .85948 L F
.45118 .86002 m .4515 .86256 L .4538 .86226 L F
.834 .831 .844 r
.48219 .86767 m .48372 .8684 L .48495 .86651 L F
.856 .821 .813 r
.48219 .86767 m .48132 .87052 L .48372 .8684 L F
.772 .665 .745 r
.66805 .74585 m .66922 .7487 L .67128 .74605 L F
.162 .422 .861 r
.32114 .6592 m .32312 .66026 L .32261 .66134 L F
.232 .51 .908 r
.32312 .66026 m .32427 .66202 L .32261 .66134 L F
.288 0 .004 r
.37807 .79809 m .37958 .7964 L .38158 .79596 L F
.779 .553 .593 r
.48077 .8357 m .4841 .83349 L .48344 .83325 L F
.48077 .8357 m .48409 .8363 L .4841 .83349 L F
.942 .963 .701 r
.485 .83023 m .4841 .83349 L .48622 .83082 L F
.485 .83023 m .48344 .83325 L .4841 .83349 L F
.65 .201 .171 r
.56781 .77805 m .57001 .77955 L .57104 .77817 L F
.7 .26 .203 r
.57001 .77955 m .57321 .77995 L .57104 .77817 L F
.998 .847 .541 r
.70493 .72441 m .70548 .72298 L .70584 .72346 L F
.70493 .72441 m .70478 .72449 L .70548 .72298 L F
.661 .589 .763 r
.65576 .73635 m .65675 .73388 L .65523 .73569 L F
.65576 .73635 m .65828 .73576 L .65675 .73388 L F
.65576 .73635 m .65675 .73388 L .65523 .73569 L F
.65576 .73635 m .65828 .73576 L .65675 .73388 L F
.782 .645 .71 r
.67039 .75637 m .67166 .75941 L .67349 .75659 L F
0 0 0 r
.32818 .70578 m .32807 .70585 L .32689 .70656 L F
.351 .15 .461 r
.32807 .70585 m .32626 .70857 L .32689 .70656 L F
.955 .64 .394 r
.58024 .79331 m .57897 .79311 L .57852 .79074 L F
.029 .595 .782 r
.58211 .7934 m .57897 .79311 L .58024 .79331 L F
.987 .744 .48 r
.70411 .73053 m .70308 .7305 L .70314 .7299 L F
.467 .826 .995 r
.70314 .7299 m .70629 .72995 L .70411 .73053 L F
.745 .654 .76 r
.70629 .72995 m .70425 .73288 L .70411 .73053 L F
.70629 .72995 m .70713 .73285 L .70425 .73288 L F
.467 .826 .995 r
.70314 .7299 m .70524 .72958 L .70629 .72995 L F
.761 .46 .476 r
.70384 .72979 m .70603 .73207 L .70524 .72958 L F
.70314 .7299 m .70353 .73019 L .70384 .72979 L F
.646 .441 .591 r
.70411 .73053 m .70157 .73284 L .70219 .73188 L F
.70411 .73053 m .70425 .73288 L .70157 .73284 L F
.761 .46 .476 r
.70353 .73019 m .70603 .73207 L .70384 .72979 L F
.646 .441 .591 r
.70327 .73051 m .70219 .73188 L .70308 .7305 L F
.70411 .73053 m .70219 .73188 L .70327 .73051 L F
.923 .795 .701 r
.55134 .84347 m .55366 .84023 L .55297 .84029 L F
.55134 .84347 m .55274 .84415 L .55366 .84023 L F
.533 .186 .325 r
.6515 .71713 m .65061 .7194 L .64835 .71948 L F
.689 .347 .391 r
.65425 .71907 m .6515 .71713 L .65267 .71602 L F
.65425 .71907 m .65061 .7194 L .6515 .71713 L F
.453 .884 .868 r
.49222 .87599 m .4935 .87585 L .49432 .87521 L F
.712 .715 .852 r
.70741 .73872 m .70929 .74114 L .71133 .74044 L F
.561 .866 .996 r
.44532 .74974 m .44395 .75106 L .44281 .74993 L F
.44532 .74974 m .44637 .75041 L .44395 .75106 L F
.404 .197 .482 r
.34511 .68325 m .34305 .6872 L .34447 .6845 L F
.34511 .68325 m .3456 .68702 L .34305 .6872 L F
.385 .304 .642 r
.34743 .68158 m .34511 .68325 L .34607 .68251 L F
.34743 .68158 m .3478 .68439 L .34511 .68325 L F
.411 .202 .483 r
.34735 .68636 m .34511 .68325 L .3478 .68439 L F
.34735 .68636 m .3456 .68702 L .34511 .68325 L F
.331 .128 .447 r
.65992 .70842 m .65796 .71139 L .65828 .70931 L F
.405 .026 .204 r
.64954 .71121 m .65161 .71084 L .65246 .70902 L F
.639 .578 .77 r
.449 .87547 m .45076 .87307 L .44863 .87345 L F
.449 .87547 m .45147 .8761 L .45076 .87307 L F
.529 .221 .39 r
.44537 .75709 m .44495 .75872 L .44284 .75884 L F
.534 .226 .392 r
.44537 .75709 m .44707 .75855 L .44495 .75872 L F
.495 .235 .449 r
.44744 .75662 m .44707 .75855 L .44537 .75709 L F
.54 .219 .372 r
.3638 .75183 m .36352 .75343 L .36159 .75338 L F
.346 .054 .319 r
.36525 .75257 m .36352 .75343 L .3638 .75183 L F
.46 .034 .142 r
.36337 .72746 m .36559 .72738 L .36682 .72584 L F
.312 0 .047 r
.36682 .72584 m .36839 .72612 L .36898 .72561 L F
.36682 .72584 m .36559 .72738 L .36839 .72612 L F
.91 .799 .724 r
.66201 .614 m .65928 .61344 L .66105 .61275 L F
.707 .179 0 r
.66201 .614 m .66081 .61444 L .65928 .61344 L F
.609 .732 .932 r
.66428 .61348 m .66201 .614 L .66105 .61275 L F
.631 .194 .192 r
.66428 .61348 m .66081 .61444 L .66201 .614 L F
.71 .541 .658 r
.5115 .85754 m .51161 .85981 L .50936 .86013 L F
.593 .45 .656 r
.51362 .85707 m .51161 .85981 L .5115 .85754 L F
.829 .771 .797 r
.49238 .82668 m .49402 .82787 L .49481 .82513 L F
.199 .558 .934 r
.54514 .83422 m .54785 .83618 L .54627 .83448 L F
.904 .539 .083 r
.54836 .83858 m .54627 .83448 L .54785 .83618 L F
0 .357 .68 r
.41155 .72753 m .41334 .72816 L .41458 .72863 L F
.551 0 0 r
.41334 .72816 m .41582 .72857 L .41458 .72863 L F
.321 0 .131 r
.5264 .8152 m .52311 .81656 L .52433 .81571 L F
.727 .892 .955 r
.55826 .8091 m .55474 .80969 L .55737 .80892 L F
.717 .461 .538 r
.55737 .80892 m .56063 .80675 L .55826 .8091 L F
.165 0 0 r
.34639 .7964 m .34804 .7962 L .34894 .79542 L F
.155 0 0 r
.34894 .79542 m .34998 .79573 L .35164 .79476 L F
.34894 .79542 m .34804 .7962 L .34998 .79573 L F
.191 0 0 r
.46426 .88114 m .46281 .88097 L .46092 .88057 L F
.415 .547 .881 r
.46628 .8784 m .46956 .88102 L .46488 .88031 L F
0 0 0 r
.4644 .88098 m .46426 .88114 L .46498 .88017 L F
.46488 .88031 m .46498 .88017 L .46628 .8784 L F
.4644 .88098 m .46498 .88017 L .46488 .88031 L F
.57 .048 0 r
.46486 .88034 m .46956 .88102 L .46872 .88182 L F
.46471 .88028 m .46488 .88031 L .46486 .88034 L F
.46488 .88031 m .46956 .88102 L .46486 .88034 L F
.415 .547 .881 r
.46628 .8784 m .46488 .88031 L .46471 .88028 L F
.286 .533 .913 r
.46471 .88028 m .46872 .88182 L .46699 .87996 L F
.46471 .88028 m .46493 .88025 L .46494 .88032 L F
.46493 .88025 m .46699 .87996 L .46494 .88032 L F
0 0 0 r
.46494 .88032 m .4644 .88098 L .46493 .88024 L F
.46494 .88032 m .46493 .88024 L .46628 .8784 L F
.478 .885 .943 r
.46494 .88032 m .46281 .88097 L .46426 .88114 L F
.734 .686 .804 r
.66703 .74049 m .67015 .74074 L .66919 .73781 L F
.749 .62 .715 r
.66703 .74049 m .66811 .74347 L .67015 .74074 L F
.85 .744 .746 r
.66919 .73781 m .67015 .74074 L .67063 .73873 L F
.425 .762 .996 r
.40467 .8865 m .40718 .88639 L .40537 .88551 L F
.40467 .8865 m .40718 .88639 L .40537 .88551 L F
.808 .364 .187 r
.54445 .8074 m .54354 .80874 L .54338 .80659 L F
.54445 .8074 m .54672 .81012 L .54354 .80874 L F
.807 .366 .195 r
.54771 .80974 m .54672 .81012 L .54445 .8074 L F
.369 0 .04 r
.40368 .74337 m .40224 .74495 L .4004 .74504 L F
0 0 0 r
.40416 .74384 m .40368 .74337 L .40574 .74273 L F
.40416 .74384 m .40224 .74495 L .40368 .74337 L F
.46 .553 .864 r
.70364 .74647 m .70504 .74871 L .70349 .74757 L F
.70363 .74647 m .70346 .74754 L .70148 .74607 L F
.70364 .74647 m .70148 .74607 L .70171 .74626 L F
.70364 .74647 m .70171 .74626 L .70394 .74566 L F
.914 .927 .549 r
.70371 .74597 m .70347 .74567 L .70279 .74721 L F
.70394 .74566 m .70376 .74567 L .70371 .74597 L F
.70376 .74567 m .70347 .74567 L .70371 .74597 L F
.46 .553 .864 r
.70364 .74647 m .70349 .74757 L .70346 .74754 L F
.70364 .74647 m .70346 .74754 L .70363 .74647 L F
.925 .926 .552 r
.70371 .74597 m .70364 .74647 L .70394 .74566 L F
.70279 .74721 m .70364 .74647 L .70371 .74597 L F
.726 .989 .821 r
.59658 .84614 m .59854 .84389 L .59563 .84579 L F
.59658 .84614 m .59914 .84396 L .59854 .84389 L F
.63 .383 .525 r
.48738 .83611 m .48935 .8382 L .48964 .83608 L F
.458 0 .042 r
.47968 .82959 m .48165 .82979 L .48298 .8285 L F
.5 0 0 r
.48381 .82931 m .48298 .8285 L .48165 .82979 L F
.48381 .82931 m .485 .83023 L .48298 .8285 L F
0 0 0 r
.35549 .80867 m .35734 .8076 L .35913 .80686 L F
.563 .446 .678 r
.54157 .83289 m .54211 .83627 L .53962 .83657 L F
.453 .152 .363 r
.54148 .83764 m .53962 .83657 L .54211 .83627 L F
.54148 .83764 m .5393 .83814 L .53962 .83657 L F
.564 .819 .993 r
.36911 .75107 m .37245 .75137 L .37132 .75055 L F
.121 .074 .526 r
.56789 .78799 m .56926 .78752 L .56894 .78525 L F
.289 .71 .971 r
.56789 .78799 m .57079 .78806 L .56926 .78752 L F
.982 .699 .394 r
.52488 .85951 m .52588 .85983 L .52446 .85717 L F
.836 .548 .501 r
.5243 .86174 m .52588 .85983 L .52488 .85951 L F
.5243 .86174 m .52646 .86258 L .52588 .85983 L F
.079 0 0 r
.35164 .79476 m .35196 .79529 L .35295 .79487 L F
.35164 .79476 m .34998 .79573 L .35196 .79529 L F
.811 .842 .873 r
.33373 .66166 m .33157 .66246 L .3319 .66059 L F
.558 .806 .991 r
.33528 .661 m .33373 .66166 L .3319 .66059 L F
.341 .135 .448 r
.33528 .661 m .33343 .66373 L .33373 .66166 L F
.549 .494 .746 r
.43883 .7428 m .43661 .74346 L .43611 .74106 L F
.558 .427 .658 r
.43912 .74581 m .43661 .74346 L .43883 .7428 L F
.43912 .74581 m .43705 .7462 L .43661 .74346 L F
.091 0 0 r
.68053 .69828 m .67961 .69835 L .67728 .69827 L F
.316 .806 .817 r
.68178 .69772 m .68053 .69828 L .68282 .69857 L F
.68178 .69772 m .67961 .69835 L .68053 .69828 L F
.037 0 0 r
.40578 .7668 m .40702 .76637 L .4085 .76447 L F
.689 .314 .332 r
.4085 .76447 m .40702 .76637 L .41029 .76645 L F
.672 .835 .962 r
.52362 .86523 m .52675 .86524 L .5256 .86434 L F
.511 .776 .992 r
.5256 .86434 m .52675 .86524 L .52799 .86428 L F
.321 .397 .785 r
.52675 .86524 m .5295 .8675 L .52799 .86428 L F
.97 .922 .691 r
.56206 .80917 m .56186 .81159 L .56392 .80948 L F
.56206 .80917 m .56071 .81163 L .56186 .81159 L F
.47 .624 .918 r
.56186 .81159 m .56374 .81183 L .56392 .80948 L F
.777 .602 .662 r
.49893 .87004 m .49982 .86801 L .4964 .86752 L F
.649 .535 .711 r
.50201 .86515 m .50099 .86784 L .49982 .86801 L F
.596 .337 .495 r
.5017 .87006 m .50099 .86784 L .49982 .86801 L F
.649 .535 .711 r
.50201 .86515 m .50099 .86784 L .49982 .86801 L F
.883 .496 .298 r
.50099 .86784 m .5017 .87006 L .49982 .86801 L F
.541 .334 .548 r
.49893 .87004 m .49982 .86801 L .5017 .87006 L F
.004 0 0 r
.55007 .78114 m .54928 .78201 L .55166 .78022 L F
.669 .125 0 r
.48663 .85723 m .48761 .8587 L .48531 .85683 L F
.48663 .85723 m .48885 .85934 L .48761 .8587 L F
.336 .215 .564 r
.34354 .68971 m .34166 .68801 L .34305 .6872 L F
.34354 .68971 m .34095 .69128 L .34166 .68801 L F
.639 .513 .694 r
.50936 .86013 m .50934 .86241 L .50713 .86301 L F
.643 .76 .934 r
.51698 .84872 m .5154 .85002 L .5146 .84911 L F
.51698 .84872 m .51772 .84976 L .5154 .85002 L F
.701 .862 .959 r
.38416 .7454 m .38755 .7452 L .38618 .74502 L F
.129 .677 .782 r
.38971 .74483 m .38618 .74502 L .38755 .7452 L F
.876 .624 .098 r
.55304 .83301 m .55332 .83561 L .55364 .83606 L F
.972 .7 .458 r
.55259 .83825 m .55364 .83606 L .55332 .83561 L F
.55259 .83825 m .55385 .8387 L .55364 .83606 L F
.517 .251 .45 r
.43312 .76425 m .43232 .767 L .43034 .76735 L F
.563 .295 .468 r
.43497 .76586 m .43312 .76425 L .43523 .76413 L F
.43497 .76586 m .43232 .767 L .43312 .76425 L F
.463 .081 .228 r
.37601 .78535 m .37815 .7852 L .37937 .78316 L F
.34 0 .158 r
.37937 .78316 m .38006 .78474 L .38145 .78288 L F
.37937 .78316 m .37815 .7852 L .38006 .78474 L F
.965 .763 .582 r
.60463 .83547 m .60633 .83341 L .60495 .83195 L F
.60463 .83547 m .606 .83638 L .60633 .83341 L F
.776 .972 .686 r
.32996 .66458 m .32996 .66413 L .33157 .66246 L F
.822 .689 .717 r
.32996 .66458 m .32789 .66525 L .32996 .66413 L F
.32996 .66458 m .32903 .66689 L .32789 .66525 L F
.691 .535 .67 r
.33162 .66585 m .32903 .66689 L .32996 .66458 L F
0 0 0 r
.46471 .88028 m .46494 .88032 L .46628 .8784 L F
.984 .719 .338 r
.55142 .83017 m .55214 .83085 L .55128 .82785 L F
.944 .586 .204 r
.55142 .83017 m .55304 .83301 L .55214 .83085 L F
.41 .079 .29 r
.66059 .63486 m .65794 .63682 L .65838 .63522 L F
.871 .993 .751 r
.34412 .71286 m .34294 .71456 L .34346 .71317 L F
.576 .674 .906 r
.34294 .71456 m .34532 .71505 L .34346 .71317 L F
.681 .535 .681 r
.34532 .71505 m .34277 .71701 L .34294 .71456 L F
.34532 .71505 m .34277 .71701 L .34294 .71456 L F
.5 .064 .142 r
.41029 .76645 m .41245 .76647 L .41396 .76485 L F
.475 .036 .124 r
.41396 .76485 m .41538 .76588 L .41588 .76431 L F
.41396 .76485 m .41245 .76647 L .41538 .76588 L F
.485 .312 .571 r
.45678 .84925 m .45887 .84655 L .45678 .84694 L F
.813 .376 .203 r
.54771 .80974 m .54689 .81107 L .54672 .81012 L F
.836 .436 .288 r
.55142 .81405 m .54986 .81397 L .55075 .81258 L F
.712 .275 .21 r
.55075 .81258 m .54986 .81397 L .55048 .81387 L F
.854 .434 .229 r
.54771 .80974 m .55048 .81387 L .54689 .81107 L F
.853 .435 .236 r
.55075 .81258 m .55048 .81387 L .54771 .80974 L F
.732 .567 .668 r
.54485 .80386 m .54648 .80634 L .54652 .80435 L F
.701 .398 .46 r
.54648 .80634 m .54844 .80667 L .54652 .80435 L F
.388 0 0 r
.63875 .72386 m .64084 .72402 L .64207 .72318 L F
.746 .697 .805 r
.64207 .72318 m .64392 .72207 L .64291 .71915 L F
.316 0 .18 r
.64207 .72318 m .643 .72391 L .64392 .72207 L F
.628 .268 .34 r
.64084 .72402 m .64392 .72207 L .64207 .72318 L F
.673 .77 .923 r
.40845 .7266 m .40446 .72557 L .4065 .72513 L F
.454 .723 .983 r
.4083 .72489 m .40845 .7266 L .4065 .72513 L F
.4083 .72489 m .41094 .72631 L .40845 .7266 L F
.389 .168 .454 r
.5189 .8154 m .5184 .81751 L .52051 .81493 L F
.5189 .8154 m .5184 .81751 L .52051 .81493 L F
.834 .537 .486 r
.49282 .85275 m .49494 .85195 L .49282 .85185 L F
.498 .272 .502 r
.49414 .85072 m .49282 .85275 L .49282 .85185 L F
.49414 .85072 m .49208 .85304 L .49282 .85275 L F
.49208 .85304 m .4917 .85346 L .49282 .85275 L F
.834 .537 .486 r
.49282 .85275 m .49616 .852 L .49494 .85195 L F
.49282 .85275 m .4965 .85418 L .49616 .852 L F
.503 .484 .769 r
.33447 .67108 m .33363 .67445 L .33291 .67143 L F
.33447 .67108 m .33543 .67429 L .33363 .67445 L F
.934 .78 .665 r
.49787 .87315 m .49874 .87575 L .49838 .87383 L F
.801 .321 0 r
.57072 .84666 m .57094 .84769 L .56819 .84655 L F
.57072 .84666 m .5719 .84839 L .57094 .84769 L F
.536 .234 .403 r
.65041 .6289 m .65163 .62612 L .65077 .6266 L F
.65041 .6289 m .65284 .62863 L .65163 .62612 L F
.435 .122 .335 r
.65163 .62612 m .65498 .62627 L .65568 .62395 L F
.333 .053 .331 r
.65284 .62863 m .65498 .62627 L .65163 .62612 L F
.461 .712 .977 r
.69009 .74437 m .69364 .74504 L .692 .74375 L F
.69009 .74437 m .692 .74375 L .68947 .74497 L F
.484 .822 .999 r
.58299 .84612 m .58587 .84633 L .58504 .84585 L F
.208 .728 .708 r
.58587 .84633 m .58722 .84593 L .58504 .84585 L F
.58587 .84633 m .58801 .84574 L .58722 .84593 L F
.778 .512 .534 r
.48773 .88271 m .48955 .88094 L .48611 .88078 L F
.868 .668 .629 r
.48773 .88271 m .48915 .88416 L .48955 .88094 L F
.819 .481 .417 r
.49315 .88387 m .48955 .88094 L .48915 .88416 L F
.48 .813 .999 r
.69537 .75435 m .69668 .7533 L .69435 .75358 L F
.69537 .75435 m .69768 .754 L .69668 .7533 L F
.79 .503 .502 r
.49641 .85646 m .49928 .85482 L .4965 .85418 L F
.49641 .85646 m .49957 .85694 L .49928 .85482 L F
.483 .189 .389 r
.42824 .76768 m .42777 .76938 L .4257 .76972 L F
.497 .203 .397 r
.43034 .76735 m .42777 .76938 L .42824 .76768 L F
.594 .74 .945 r
.44948 .75136 m .44637 .75041 L .44813 .75056 L F
0 .143 .652 r
.45014 .75158 m .44948 .75136 L .44813 .75056 L F
.45014 .75158 m .45148 .75307 L .44948 .75136 L F
.503 .371 .633 r
.45148 .75307 m .44979 .7538 L .44948 .75136 L F
.942 .832 .706 r
.66704 .7299 m .66942 .72749 L .669 .72565 L F
.66704 .7299 m .66822 .73063 L .66942 .72749 L F
.028 0 .29 r
.34095 .69128 m .34147 .69268 L .3402 .69341 L F
.223 0 .252 r
.34307 .69175 m .34095 .69128 L .34354 .68971 L F
.34307 .69175 m .34147 .69268 L .34095 .69128 L F
.781 .614 .673 r
.59502 .7885 m .59313 .79082 L .59628 .79108 L F
.751 .509 .566 r
.59302 .79317 m .59628 .79108 L .59313 .79082 L F
.59302 .79317 m .59652 .79351 L .59628 .79108 L F
.639 .593 .786 r
.63237 .7435 m .63359 .73993 L .63153 .74042 L F
.63237 .7435 m .63448 .74306 L .63359 .73993 L F
.051 0 0 r
.34586 .79663 m .34804 .7962 L .34639 .7964 L F
.371 0 .18 r
.38863 .77715 m .39072 .77676 L .39135 .77545 L F
.564 .181 .274 r
.39072 .77676 m .3929 .77684 L .39135 .77545 L F
.513 .194 .363 r
.39135 .77545 m .3929 .77684 L .39354 .77522 L F
.959 .867 .704 r
.68307 .73831 m .6833 .7362 L .68195 .73713 L F
.856 .589 .535 r
.68045 .74002 m .68307 .73831 L .68195 .73713 L F
.68045 .74002 m .68355 .73947 L .68307 .73831 L F
.596 .707 .921 r
.42329 .73197 m .41974 .73057 L .42184 .73014 L F
.315 .451 .838 r
.42389 .72997 m .42329 .73197 L .42184 .73014 L F
.42389 .72997 m .42508 .73253 L .42329 .73197 L F
.452 0 0 r
.46956 .88102 m .46939 .88192 L .46872 .88182 L F
.46956 .88102 m .47131 .88147 L .46939 .88192 L F
.753 .686 .787 r
.56374 .81183 m .56553 .81323 L .56683 .81188 L F
.763 .542 .597 r
.60297 .79873 m .60497 .79644 L .60297 .79628 L F
.60297 .79873 m .605 .79859 L .60497 .79644 L F
.781 .624 .686 r
.58771 .8043 m .58434 .80404 L .5849 .80174 L F
.851 .625 .596 r
.58771 .8043 m .58495 .80661 L .58434 .80404 L F
.58771 .8043 m .58824 .80726 L .58495 .80661 L F
.598 .456 .66 r
.58935 .80683 m .58771 .8043 L .59026 .80437 L F
.58935 .80683 m .58824 .80726 L .58771 .8043 L F
.933 .902 .77 r
.55049 .84529 m .55274 .84415 L .55134 .84347 L F
.55049 .84529 m .55172 .84577 L .55274 .84415 L F
.754 .632 .725 r
.60874 .8232 m .61081 .82039 L .60741 .81998 L F
.088 .62 .867 r
.3981 .72306 m .40158 .72372 L .39925 .72398 L F
.749 .755 .857 r
.57787 .83036 m .57577 .83429 L .57396 .83292 L F
.613 .833 .984 r
.51282 .88065 m .51084 .8815 L .50941 .88042 L F
.711 .546 .663 r
.59137 .80649 m .59026 .80437 L .59299 .80421 L F
.199 0 0 r
.36898 .72561 m .37046 .72577 L .3721 .72515 L F
.033 0 0 r
.37046 .72577 m .37418 .72496 L .3721 .72515 L F
.62 .742 .934 r
.42858 .73347 m .42653 .73403 L .42508 .73253 L F
.846 .819 .822 r
.49135 .84651 m .4884 .84674 L .49075 .84649 L F
.49135 .84651 m .48919 .84816 L .4884 .84674 L F
.754 .536 .601 r
.59953 .7937 m .60297 .79628 L .60169 .79362 L F
.766 .578 .643 r
.605 .79859 m .60623 .80149 L .60838 .79879 L F
.628 .268 .34 r
.64084 .72402 m .643 .72391 L .64392 .72207 L F
.708 .479 .575 r
.643 .72391 m .64484 .72259 L .64392 .72207 L F
.272 0 0 r
.65239 .62166 m .65057 .62423 L .65216 .62353 L F
.605 .579 .798 r
.64787 .72961 m .64636 .73269 L .64492 .72986 L F
.64787 .72961 m .64885 .73254 L .64636 .73269 L F
.645 .568 .754 r
.64885 .73254 m .64706 .7349 L .64636 .73269 L F
.517 0 0 r
.66252 .73026 m .6648 .73218 L .66378 .73147 L F
.751 .393 .376 r
.57649 .78029 m .57845 .78273 L .57962 .78075 L F
.719 .355 .358 r
.57962 .78075 m .57845 .78273 L .58201 .78291 L F
.78 .442 .414 r
.58792 .8222 m .58415 .82014 L .58576 .82058 L F
.361 .494 .858 r
.32646 .66261 m .32572 .66426 L .32427 .66202 L F
.41 .553 .887 r
.32646 .66261 m .32789 .66525 L .32572 .66426 L F
.269 0 .03 r
.35894 .79145 m .35959 .7927 L .36116 .79113 L F
.35894 .79145 m .35759 .79324 L .35959 .7927 L F
.712 .715 .852 r
.70741 .73872 m .71133 .74044 L .71077 .73816 L F
.729 .757 .875 r
.71077 .73816 m .71133 .74044 L .71373 .73826 L F
.955 .949 .706 r
.59386 .80945 m .59262 .81235 L .59187 .81178 L F
.967 .732 .53 r
.59262 .81235 m .59106 .8139 L .59187 .81178 L F
.59262 .81235 m .59231 .81459 L .59106 .8139 L F
.378 .463 .821 r
.34743 .68158 m .34607 .68251 L .34508 .68007 L F
.387 .121 .384 r
.63306 .73421 m .63509 .73417 L .63506 .73246 L F
.571 .455 .682 r
.63322 .73786 m .63509 .73417 L .63306 .73421 L F
.517 .151 .285 r
.38669 .79338 m .3858 .79558 L .38364 .79557 L F
.177 0 .194 r
.38915 .79082 m .38819 .79338 L .38669 .79338 L F
.17 0 .13 r
.38819 .79338 m .3858 .79558 L .38669 .79338 L F
0 0 .444 r
.54723 .78312 m .54841 .78463 L .54928 .78201 L F
.54723 .78312 m .54719 .78593 L .54841 .78463 L F
.351 .493 .861 r
.50175 .85173 m .50501 .85451 L .50443 .85208 L F
.66 .568 .741 r
.50443 .85208 m .50708 .85177 L .50608 .84871 L F
.619 .454 .637 r
.50443 .85208 m .50705 .85412 L .50708 .85177 L F
.50443 .85208 m .50501 .85451 L .50705 .85412 L F
0 0 .139 r
.47367 .8619 m .47314 .86262 L .47352 .86069 L F
.47367 .8619 m .47352 .86069 L .47395 .85855 L F
.81 .503 0 r
.47325 .86103 m .47377 .86267 L .47367 .8619 L F
0 .487 .851 r
.47428 .8643 m .47314 .86262 L .47367 .8619 L F
.81 .503 0 r
.47377 .86267 m .47428 .8643 L .47367 .8619 L F
.94 .731 .257 r
.47325 .86103 m .47367 .8619 L .47395 .85855 L F
.47325 .86103 m .47395 .85855 L .47389 .85883 L F
.519 .27 .478 r
.42029 .76155 m .42295 .75872 L .4208 .75915 L F
.839 .492 .398 r
.57852 .79074 m .57554 .78816 L .57889 .78832 L F
.716 .518 .621 r
.59295 .78818 m .59313 .79082 L .59502 .7885 L F
.71 .592 .722 r
.66496 .74095 m .66811 .74347 L .66703 .74049 L F
.66496 .74095 m .66598 .74376 L .66811 .74347 L F
.65 .477 .637 r
.66606 .74617 m .66811 .74347 L .66598 .74376 L F
.66606 .74617 m .66805 .74585 L .66811 .74347 L F
.09 .406 .859 r
.41094 .72631 m .41182 .72651 L .41155 .72753 L F
.102 .42 .866 r
.41182 .72651 m .41334 .72816 L .41155 .72753 L F
.808 .589 .605 r
.59141 .79017 m .59295 .78818 L .58989 .78804 L F
.59141 .79017 m .59313 .79082 L .59295 .78818 L F
.767 .689 .776 r
.52051 .81493 m .5184 .81751 L .52186 .81769 L F
.75 .682 .785 r
.52051 .81493 m .52186 .81769 L .52311 .81656 L F
.373 .589 .928 r
.42276 .74384 m .42385 .74287 L .42211 .74289 L F
.42276 .74384 m .42553 .74505 L .42385 .74287 L F
.769 .897 .933 r
.50235 .88387 m .50367 .88462 L .50123 .88574 L F
.655 .876 .981 r
.50532 .88373 m .50367 .88462 L .50235 .88387 L F
.915 .761 .676 r
.58596 .80897 m .58624 .812 L .58522 .81156 L F
.812 .579 .586 r
.58624 .812 m .58368 .81427 L .58522 .81156 L F
.58624 .812 m .58692 .81556 L .58368 .81427 L F
.915 .761 .676 r
.58522 .81156 m .58624 .812 L .58596 .80897 L F
.624 .647 .852 r
.588 .81214 m .58624 .812 L .58522 .81156 L F
.588 .81214 m .58692 .81556 L .58624 .812 L F
.395 .071 .294 r
.39012 .79284 m .38915 .79082 L .39133 .79018 L F
.39012 .79284 m .38819 .79338 L .38915 .79082 L F
.44 .094 .281 r
.40352 .78338 m .40082 .78502 L .4015 .78377 L F
.788 .943 .595 r
.5206 .87323 m .51938 .87439 L .51908 .8726 L F
.5206 .87323 m .51961 .87465 L .51938 .87439 L F
.133 0 0 r
.64706 .7349 m .64641 .73602 L .6447 .73657 L F
.645 .568 .754 r
.64885 .73254 m .64962 .73552 L .64706 .7349 L F
.522 .905 .948 r
.64962 .73552 m .64641 .73602 L .64706 .7349 L F
.388 0 .119 r
.48998 .82442 m .49157 .82445 L .4926 .82276 L F
.473 .054 .164 r
.4926 .82276 m .49117 .8251 L .49352 .82461 L F
.682 .534 .678 r
.49097 .82396 m .49299 .82448 L .49225 .82363 L F
.49299 .82448 m .49352 .82461 L .49336 .82449 L F
.49299 .82448 m .49336 .82449 L .49225 .82363 L F
.388 0 .119 r
.48918 .82492 m .49117 .8251 L .49157 .82445 L F
.48918 .82492 m .49157 .82445 L .48998 .82442 L F
.473 .054 .164 r
.4926 .82276 m .49352 .82461 L .49467 .82483 L F
0 .206 .721 r
.71505 .72962 m .71598 .73044 L .71552 .72936 L F
.71598 .73044 m .71824 .73243 L .71552 .72936 L F
0 0 0 r
.71524 .72941 m .71552 .72936 L .7169 .72757 L F
0 .216 .737 r
.71505 .72962 m .71755 .73319 L .71824 .73243 L F
.016 0 0 r
.7169 .72757 m .71552 .72936 L .7184 .72735 L F
.633 .964 .872 r
.71824 .73243 m .71755 .73319 L .71947 .73182 L F
0 0 0 r
.71947 .73182 m .71941 .7319 L .71824 .73243 L F
.71947 .73182 m .71941 .7319 L .71824 .73243 L F
.522 0 0 r
.71941 .7319 m .71552 .72936 L .71824 .73243 L F
.815 .9 .901 r
.71645 .72788 m .71552 .72936 L .71496 .72829 L F
.7184 .72735 m .71605 .72899 L .71645 .72788 L F
.71605 .72899 m .71552 .72936 L .71645 .72788 L F
.746 .634 .735 r
.71704 .72628 m .71424 .72552 L .71598 .72479 L F
.016 0 0 r
.7169 .72757 m .7184 .72735 L .71909 .72675 L F
.815 .9 .901 r
.7184 .72735 m .71496 .72829 L .71859 .72845 L F
.746 .634 .735 r
.71859 .72845 m .71671 .72718 L .71704 .72628 L F
.71671 .72718 m .71424 .72552 L .71704 .72628 L F
.574 .408 .618 r
.71552 .72936 m .71916 .73196 L .71756 .73216 L F
.522 0 0 r
.71941 .7319 m .71923 .73194 L .71552 .72936 L F
.71923 .73194 m .71916 .73196 L .71816 .73125 L F
.71923 .73194 m .71816 .73125 L .71552 .72936 L F
.621 .421 .589 r
.71255 .72633 m .71394 .72968 L .70998 .7295 L F
.529 .375 .617 r
.71496 .72829 m .71394 .72968 L .71255 .72633 L F
.532 .478 .741 r
.7128 .7309 m .70998 .7295 L .71394 .72968 L F
.89 .97 .83 r
.71496 .72829 m .7128 .7309 L .71394 .72968 L F
.708 .582 .711 r
.71449 .72886 m .71756 .73216 L .7128 .7309 L F
0 0 .527 r
.71552 .72936 m .71523 .72869 L .71496 .72829 L F
.71552 .72936 m .71566 .72933 L .71496 .72829 L F
.708 .582 .711 r
.71496 .72829 m .71601 .72985 L .71449 .72886 L F
0 0 .527 r
.71552 .72936 m .71756 .73216 L .71523 .72869 L F
.71552 .72936 m .71756 .73216 L .71566 .72933 L F
0 0 0 r
.71505 .72962 m .71552 .72936 L .71524 .72941 L F
.708 .582 .711 r
.71601 .72985 m .71756 .73216 L .71449 .72886 L F
.692 .231 .153 r
.4961 .84088 m .49863 .84289 L .49936 .84139 L F
.808 .373 .21 r
.49863 .84289 m .50128 .84373 L .49936 .84139 L F
.663 .409 .526 r
.49936 .84139 m .50128 .84373 L .50158 .8414 L F
.574 .489 .72 r
.43734 .73714 m .43611 .74106 L .43541 .73747 L F
.43734 .73714 m .43817 .74059 L .43611 .74106 L F
.549 .494 .746 r
.43883 .7428 m .43611 .74106 L .43817 .74059 L F
0 0 0 r
.41927 .74218 m .41847 .74227 L .41648 .74249 L F
.237 .618 .956 r
.41927 .74218 m .42091 .74189 L .41847 .74227 L F
.41927 .74218 m .42211 .74289 L .42091 .74189 L F
.512 .314 .548 r
.35631 .75404 m .35617 .75639 L .35418 .75682 L F
.569 .361 .559 r
.35836 .75408 m .35617 .75639 L .35631 .75404 L F
.883 .496 .298 r
.50099 .86784 m .5031 .87031 L .5017 .87006 L F
.109 0 .399 r
.50201 .86515 m .50099 .86784 L .5028 .86679 L F
.176 .102 .528 r
.5028 .86679 m .50099 .86784 L .5017 .87006 L F
.992 .837 .588 r
.34373 .71133 m .34346 .71317 L .34412 .71286 L F
.612 .089 0 r
.34346 .71317 m .34688 .71398 L .34412 .71286 L F
0 0 0 r
.72053 .72888 m .7206 .72774 L .71909 .72675 L F
.72053 .72888 m .72021 .73002 L .7206 .72774 L F
.208 .496 .903 r
.7184 .72735 m .72053 .72888 L .71909 .72675 L F
.7184 .72735 m .7207 .72828 L .72053 .72888 L F
.7207 .72828 m .72105 .72843 L .72053 .72888 L F
0 0 0 r
.72053 .72888 m .7202 .73005 L .72021 .73002 L F
.352 .5 .867 r
.40314 .72395 m .40218 .7254 L .40158 .72372 L F
.46 .646 .938 r
.40314 .72395 m .40446 .72557 L .40218 .7254 L F
.462 .103 .269 r
.34072 .7378 m .3429 .73754 L .344 .73539 L F
.329 0 .198 r
.344 .73539 m .34478 .73697 L .34611 .73523 L F
.344 .73539 m .3429 .73754 L .34478 .73697 L F
.932 .742 .623 r
.67358 .72433 m .67249 .72111 L .67377 .72213 L F
.47 .404 .701 r
.4267 .74858 m .42687 .75168 L .42914 .75046 L F
.616 .54 .746 r
.42728 .75368 m .42914 .75046 L .42687 .75168 L F
.279 0 0 r
.35617 .75639 m .35241 .75819 L .35418 .75682 L F
.563 .014 0 r
.38498 .72252 m .38708 .72367 L .38829 .72327 L F
.531 .1 .167 r
.38708 .72367 m .39053 .72238 L .38829 .72327 L F
.507 .221 .415 r
.40815 .78003 m .4054 .78297 L .40629 .78039 L F
0 0 .502 r
.6982 .73285 m .69851 .7356 L .69635 .73321 L F
.6982 .73285 m .69889 .73648 L .69851 .7356 L F
.815 .708 .747 r
.69889 .73648 m .69616 .73698 L .69851 .7356 L F
.632 .196 0 r
.54693 .82193 m .54891 .82486 L .54857 .82261 L F
0 0 .252 r
.5599 .81627 m .5594 .81483 L .5596 .81365 L F
.5599 .81627 m .55968 .81743 L .5594 .81483 L F
0 0 .349 r
.55947 .82512 m .55786 .82188 L .55871 .82277 L F
.401 .236 .539 r
.33343 .66373 m .33324 .66584 L .33162 .66585 L F
.502 .446 .727 r
.33324 .66584 m .33213 .66953 L .33162 .66585 L F
.222 0 0 r
.53102 .83421 m .52943 .83491 L .5272 .83503 L F
0 0 0 r
.53139 .83441 m .53102 .83421 L .53338 .83417 L F
.53139 .83441 m .52943 .83491 L .53102 .83421 L F
.517 .314 .543 r
.45843 .84371 m .46056 .84347 L .46059 .84127 L F
.517 .383 .637 r
.45843 .84371 m .46086 .84574 L .46056 .84347 L F
.45843 .84371 m .45887 .84655 L .46086 .84574 L F
.312 0 .171 r
.35391 .73052 m .35127 .73235 L .3532 .73173 L F
.313 0 .128 r
.3532 .73173 m .35592 .73007 L .35391 .73052 L F
0 0 0 r
.63506 .73246 m .63649 .73184 L .63774 .73044 L F
.333 0 .041 r
.63649 .73184 m .63979 .7298 L .63774 .73044 L F
.573 .372 .57 r
.38555 .74867 m .38536 .75104 L .38318 .75122 L F
0 .082 .639 r
.38416 .7454 m .3859 .74774 L .38555 .74867 L F
0 0 .385 r
.3859 .74774 m .38536 .75104 L .38555 .74867 L F
.776 .642 .713 r
.60722 .82203 m .60874 .8232 L .60741 .81998 L F
.761 .647 .735 r
.60682 .82558 m .60874 .8232 L .60722 .82203 L F
.759 .584 .66 r
.56392 .80948 m .56374 .81183 L .56683 .81188 L F
.535 .287 .486 r
.47031 .83615 m .47251 .8378 L .47189 .83491 L F
.463 .183 .402 r
.47189 .83491 m .47468 .8355 L .47511 .83286 L F
.35 .094 .377 r
.47251 .8378 m .47468 .8355 L .47189 .83491 L F
.975 .722 .487 r
.68563 .75088 m .68656 .75169 L .68569 .75335 L F
.532 .369 .606 r
.45481 .85194 m .45681 .85166 L .45678 .84925 L F
.545 .413 .651 r
.45504 .85436 m .45681 .85166 L .45481 .85194 L F
.65 .695 .879 r
.34346 .71317 m .34532 .71505 L .34688 .71398 L F
.466 .131 .314 r
.46056 .84347 m .4635 .8411 L .46059 .84127 L F
.46056 .84347 m .46254 .8433 L .4635 .8411 L F
.506 .154 .304 r
.46254 .8433 m .46571 .84112 L .4635 .8411 L F
.429 .244 .526 r
.40351 .76913 m .40553 .76957 L .40578 .7668 L F
.335 .057 .334 r
.40351 .76913 m .40455 .77103 L .40553 .76957 L F
.40351 .76913 m .40282 .77178 L .40455 .77103 L F
.646 .455 .61 r
.64498 .71419 m .64744 .7141 L .64739 .71167 L F
.541 .372 .601 r
.64744 .7141 m .64954 .71121 L .64739 .71167 L F
.758 .54 .601 r
.5963 .79588 m .59953 .7937 L .59652 .79351 L F
.5963 .79588 m .59962 .79611 L .59953 .7937 L F
.754 .536 .601 r
.59953 .7937 m .59962 .79611 L .60297 .79628 L F
.587 .604 .836 r
.44049 .74883 m .43705 .7462 L .43912 .74581 L F
.497 .518 .809 r
.44118 .74547 m .44049 .74883 L .43912 .74581 L F
.44118 .74547 m .44232 .74861 L .44049 .74883 L F
.496 .503 .794 r
.44232 .74861 m .44281 .74993 L .44049 .74883 L F
0 0 0 r
.53254 .83884 m .53315 .83839 L .53417 .83628 L F
0 0 .055 r
.53174 .84098 m .53315 .83839 L .53254 .83884 L F
.437 .706 .979 r
.47561 .88218 m .4767 .88162 L .47465 .88199 L F
.47561 .88218 m .47784 .88223 L .4767 .88162 L F
.037 .341 .82 r
.69285 .72161 m .6945 .72389 L .69316 .72268 L F
.75 .682 .785 r
.52051 .81493 m .52311 .81656 L .52281 .81461 L F
.703 .786 .916 r
.52281 .81461 m .52311 .81656 L .5264 .8152 L F
.597 .553 .776 r
.43734 .73714 m .43541 .73747 L .43482 .73601 L F
.778 .765 .841 r
.63679 .74064 m .6399 .74075 L .63873 .73977 L F
.807 .763 .812 r
.63873 .73977 m .6399 .74075 L .64212 .73821 L F
.82 .989 .874 r
.48778 .86741 m .49093 .86533 L .48957 .86416 L F
.587 .518 .744 r
.44996 .86767 m .45161 .86509 L .44918 .8646 L F
.44996 .86767 m .45208 .86741 L .45161 .86509 L F
.558 .457 .696 r
.44996 .86767 m .45253 .87038 L .45208 .86741 L F
.44996 .86767 m .45051 .87075 L .45253 .87038 L F
.408 .82 .625 r
.36101 .80633 m .36442 .80419 L .36288 .80579 L F
.002 0 0 r
.36288 .80579 m .36442 .80419 L .36613 .80344 L F
0 0 .179 r
.70157 .73284 m .70314 .7299 L .70308 .7305 L F
.70157 .73284 m .70278 .73198 L .70314 .7299 L F
.668 .337 .405 r
.70157 .73284 m .70055 .73244 L .70278 .73198 L F
.70157 .73284 m .70078 .73457 L .70055 .73244 L F
.70157 .73284 m .70382 .73466 L .70078 .73457 L F
.63 .358 .487 r
.70425 .73288 m .70382 .73466 L .70157 .73284 L F
.905 .892 .806 r
.70206 .75084 m .70504 .74871 L .70364 .74647 L F
.70206 .75084 m .70309 .75157 L .70504 .74871 L F
.461 .688 .964 r
.69926 .72226 m .70096 .72227 L .70037 .72109 L F
.391 0 0 r
.70056 .72342 m .69926 .72226 L .70037 .72109 L F
.95 .682 .228 r
.69978 .71991 m .70037 .72109 L .70056 .72342 L F
.69969 .7195 m .70037 .72109 L .69978 .71991 L F
.461 .688 .964 r
.70096 .72227 m .70151 .72227 L .70037 .72109 L F
.357 .812 .938 r
.51857 .84923 m .51772 .84976 L .51698 .84872 L F
.51857 .84923 m .51985 .84942 L .51772 .84976 L F
.508 .491 .773 r
.45076 .87307 m .45147 .8761 L .45352 .87506 L F
.549 .523 .778 r
.45217 .87785 m .45352 .87506 L .45147 .8761 L F
.717 .577 .697 r
.50936 .86013 m .51161 .85981 L .50934 .86241 L F
.579 .38 .575 r
.51161 .85981 m .51154 .86206 L .50934 .86241 L F
.579 .432 .646 r
.51362 .85707 m .51376 .85951 L .51161 .85981 L F
.728 .605 .719 r
.51376 .85951 m .51154 .86206 L .51161 .85981 L F
.611 .888 .99 r
.59021 .84608 m .59163 .8461 L .59079 .8456 L F
.2 .647 .946 r
.59163 .8461 m .59258 .84575 L .59079 .8456 L F
.59163 .8461 m .59365 .84645 L .59258 .84575 L F
.927 .71 .589 r
.64596 .63194 m .64725 .635 L .64575 .63423 L F
.924 .724 .614 r
.64575 .63423 m .64725 .635 L .64692 .63715 L F
0 0 .245 r
.49414 .85072 m .49333 .85011 L .49325 .84875 L F
.49414 .85072 m .49282 .85185 L .49333 .85011 L F
.823 .894 .893 r
.49946 .88555 m .50123 .88574 L .49864 .88695 L F
.702 .447 .536 r
.49864 .88695 m .50123 .88574 L .50096 .88802 L F
.769 .897 .933 r
.50235 .88387 m .50123 .88574 L .49946 .88555 L F
.781 .296 .073 r
.50123 .88574 m .502 .88781 L .50096 .88802 L F
.50123 .88574 m .50322 .88779 L .502 .88781 L F
.22 0 .174 r
.37381 .80085 m .37464 .79937 L .37628 .79863 L F
.618 .376 .528 r
.6655 .63176 m .66257 .63452 L .66324 .63195 L F
.955 .949 .706 r
.59386 .80945 m .59187 .81178 L .59287 .80854 L F
.886 .719 .669 r
.68158 .743 m .68355 .73947 L .68045 .74002 L F
.842 .653 .648 r
.68158 .743 m .68448 .74354 L .68355 .73947 L F
.681 .555 .706 r
.68448 .74354 m .68469 .74114 L .68355 .73947 L F
.57 .601 .845 r
.52907 .84334 m .52974 .8441 L .52742 .84415 L F
.52907 .84334 m .52974 .8441 L .52742 .84415 L F
.387 0 0 r
.52742 .84415 m .52906 .84342 L .52907 .84334 L F
.52742 .84415 m .52974 .8441 L .52662 .84522 L F
.52742 .84415 m .52662 .84522 L .52906 .84342 L F
.49 .153 .322 r
.4209 .77269 m .42017 .77447 L .41804 .77474 L F
.428 .087 .284 r
.42269 .77268 m .42017 .77447 L .4209 .77269 L F
.381 0 0 r
.54347 .84043 m .54538 .84075 L .54511 .84021 L F
.581 .538 .772 r
.54379 .84383 m .54538 .84075 L .54347 .84043 L F
0 0 0 r
.51053 .88674 m .51189 .88627 L .51037 .88697 L F
.553 .918 .746 r
.51037 .88697 m .51189 .88627 L .51277 .88535 L F
.446 .842 .639 r
.51037 .88697 m .5119 .88587 L .5102 .8872 L F
.51037 .88697 m .5102 .8872 L .50955 .88771 L F
0 0 0 r
.50834 .88751 m .51053 .88674 L .51037 .88697 L F
.508 .382 .643 r
.45322 .85706 m .4553 .8591 L .45506 .85674 L F
.45322 .85706 m .45349 .85948 L .4553 .8591 L F
.6 .656 .876 r
.38069 .88439 m .3798 .88694 L .38168 .8863 L F
.38069 .88439 m .3798 .88694 L .38168 .8863 L F
.782 .645 .71 r
.66857 .75914 m .67166 .75941 L .67039 .75637 L F
0 .476 .798 r
.49932 .82958 m .50124 .83007 L .5025 .83064 L F
.5025 .83064 m .50124 .83007 L .49932 .82958 L F
.852 .755 .755 r
.59135 .82031 m .58979 .82321 L .58792 .8222 L F
.059 0 .459 r
.67043 .71871 m .67059 .72094 L .66898 .72223 L F
.006 .046 .552 r
.67068 .72343 m .66898 .72223 L .67059 .72094 L F
.67068 .72343 m .66969 .72501 L .66898 .72223 L F
0 0 .514 r
.5031 .87031 m .50412 .87143 L .5017 .87006 L F
.768 .497 .525 r
.5031 .87031 m .50615 .8728 L .50502 .87296 L F
0 0 .514 r
.5031 .87031 m .50502 .87296 L .50412 .87143 L F
.709 .685 .824 r
.66152 .7404 m .66496 .74095 L .66411 .73853 L F
.71 .685 .824 r
.66411 .73853 m .66496 .74095 L .66703 .74049 L F
.612 .098 0 r
.64484 .72259 m .64667 .7245 L .64677 .72441 L F
.746 .565 .65 r
.64331 .72845 m .64551 .72613 L .643 .72391 L F
.618 .822 .416 r
.64583 .72641 m .64557 .72615 L .64533 .72748 L F
.64677 .72441 m .6458 .72581 L .64583 .72641 L F
.6458 .72581 m .64557 .72615 L .64583 .72641 L F
.64677 .72441 m .64667 .7245 L .64525 .72661 L F
0 0 0 r
.64371 .72858 m .6447 .72723 L .64353 .72874 L F
.6447 .72723 m .64551 .72613 L .64467 .72724 L F
.6447 .72723 m .64467 .72724 L .64353 .72874 L F
.705 .433 .511 r
.64534 .72645 m .64433 .72536 L .64551 .72613 L F
.64433 .72536 m .643 .72391 L .64405 .72483 L F
.64433 .72536 m .64405 .72483 L .64551 .72613 L F
.414 .035 .207 r
.64463 .72507 m .64447 .7252 L .64432 .72518 L F
.705 .433 .511 r
.64479 .72503 m .64667 .7245 L .64456 .7249 L F
.64589 .72567 m .64657 .72464 L .64479 .72503 L F
.64657 .72464 m .64667 .7245 L .64479 .72503 L F
.64492 .72483 m .64667 .7245 L .64556 .72432 L F
.708 .479 .575 r
.643 .72391 m .64667 .7245 L .64484 .72259 L F
.55 .471 .719 r
.64484 .72259 m .64667 .7245 L .64846 .72367 L F
.64484 .72259 m .64667 .7245 L .64846 .72367 L F
.594 .914 .977 r
.64667 .7245 m .64672 .72386 L .64846 .72367 L F
.414 .035 .207 r
.64846 .72367 m .64463 .72507 L .64672 .72386 L F
.64463 .72507 m .64432 .72518 L .64446 .72511 L F
.64463 .72507 m .64446 .72511 L .64672 .72386 L F
.705 .433 .511 r
.64589 .72567 m .64456 .7249 L .64453 .72494 L F
.414 .035 .207 r
.64846 .72367 m .64765 .72556 L .64447 .7252 L F
.64846 .72367 m .64447 .7252 L .64463 .72507 L F
.705 .433 .511 r
.64393 .72502 m .64429 .72495 L .643 .72391 L F
.64429 .72495 m .64492 .72483 L .64341 .7241 L F
.64429 .72495 m .64341 .7241 L .643 .72391 L F
.64492 .72483 m .64556 .72432 L .643 .72391 L F
0 0 0 r
.64446 .72511 m .64749 .72239 L .64672 .72386 L F
.64432 .72518 m .64443 .72508 L .64446 .72511 L F
.64443 .72508 m .64749 .72239 L .64446 .72511 L F
.64443 .72508 m .64644 .72454 L .64749 .72239 L F
.64432 .72518 m .64437 .72517 L .64443 .72508 L F
.64437 .72517 m .64644 .72454 L .64443 .72508 L F
.705 .433 .511 r
.64453 .72494 m .64456 .7249 L .64449 .72492 L F
0 0 0 r
.64519 .72655 m .64551 .72613 L .64517 .72649 L F
.705 .433 .511 r
.64366 .7247 m .643 .72391 L .64422 .72523 L F
.456 .217 .462 r
.64428 .72535 m .64466 .72574 L .64521 .72662 L F
.6452 .72663 m .64521 .72662 L .64526 .72671 L F
.64428 .72535 m .64521 .72662 L .6452 .72663 L F
.535 0 0 r
.64645 .72863 m .64533 .72748 L .64526 .72671 L F
.456 .217 .462 r
.64526 .72671 m .64526 .72671 L .64645 .72863 L F
.535 0 0 r
.64645 .72863 m .64526 .72671 L .64525 .72661 L F
.669 .446 .574 r
.64533 .72748 m .64787 .72961 L .64492 .72986 L F
.456 .217 .462 r
.64414 .72875 m .64526 .72671 L .64645 .72863 L F
.6452 .72656 m .64534 .72645 L .64551 .72613 L F
.64356 .72878 m .64521 .72662 L .6452 .72656 L F
.64521 .72662 m .64534 .72645 L .6452 .72656 L F
.618 .822 .416 r
.64544 .72688 m .64526 .72671 L .64533 .72748 L F
.64557 .72615 m .64526 .72671 L .64544 .72688 L F
.64526 .72671 m .64526 .72671 L .64544 .72688 L F
.658 .229 0 r
.64526 .72671 m .64531 .72681 L .64527 .72672 L F
.64531 .72681 m .64531 .72681 L .64527 .72672 L F
.64521 .72662 m .64524 .7267 L .64526 .72671 L F
.64524 .7267 m .64534 .72689 L .64526 .72671 L F
.456 .217 .462 r
.64521 .72666 m .64645 .72863 L .64525 .72661 L F
.64356 .72878 m .64526 .72671 L .64414 .72875 L F
.64356 .72878 m .64645 .72863 L .64521 .72666 L F
.658 .229 0 r
.64531 .72681 m .64534 .72689 L .64531 .72681 L F
.438 .211 .47 r
.64447 .7252 m .64446 .72542 L .64432 .72518 L F
.705 .433 .511 r
.64525 .72661 m .64437 .72517 L .64446 .72542 L F
.64459 .72582 m .64366 .7247 L .64451 .72559 L F
.64459 .72582 m .64451 .72559 L .64534 .72645 L F
.658 .229 0 r
.64466 .72574 m .64499 .7263 L .64521 .72662 L F
.456 .217 .462 r
.64521 .72662 m .64525 .72661 L .64534 .72645 L F
.705 .433 .511 r
.64525 .72661 m .64459 .72582 L .64534 .72645 L F
.64428 .72535 m .64461 .72565 L .64466 .72574 L F
.64499 .7263 m .64446 .72542 L .64459 .72582 L F
.658 .229 0 r
.64432 .72518 m .64534 .72689 L .64466 .72574 L F
.705 .433 .511 r
.64525 .72661 m .64446 .72542 L .64499 .7263 L F
0 0 0 r
.64353 .72874 m .64519 .72655 L .64331 .72845 L F
.64519 .72655 m .64517 .72649 L .64331 .72845 L F
.64356 .72878 m .64371 .72858 L .64353 .72874 L F
.456 .217 .462 r
.64356 .72878 m .64428 .72535 L .64526 .72671 L F
.658 .229 0 r
.64499 .7263 m .64511 .72651 L .64514 .72654 L F
.64511 .72651 m .64522 .72668 L .64514 .72654 L F
.64514 .72654 m .64522 .72668 L .64521 .72667 L F
.64499 .7263 m .64521 .72667 L .64521 .72662 L F
.64522 .72668 m .64534 .72689 L .64521 .72662 L F
.64522 .72669 m .64525 .72674 L .64525 .72674 L F
.64525 .72674 m .64542 .72707 L .64525 .72674 L F
.64525 .72674 m .64542 .72707 L .64534 .72689 L F
.64432 .72518 m .64523 .72674 L .64522 .72669 L F
.64523 .72674 m .64542 .72707 L .64522 .72669 L F
.456 .217 .462 r
.64356 .72878 m .64521 .72666 L .64521 .72662 L F
.64521 .72666 m .64525 .72661 L .64521 .72662 L F
.705 .433 .511 r
.64428 .72535 m .64422 .72523 L .64461 .72565 L F
.64466 .72574 m .64461 .72565 L .64534 .72645 L F
.64366 .7247 m .64422 .72523 L .64428 .72535 L F
.456 .217 .462 r
.64428 .72535 m .64432 .72518 L .64466 .72574 L F
.64428 .72535 m .64444 .72559 L .64432 .72518 L F
.047 .066 .557 r
.64432 .72518 m .64446 .72542 L .64437 .72517 L F
.705 .433 .511 r
.64443 .72563 m .64437 .72517 L .64393 .72502 L F
.64459 .72582 m .64446 .72542 L .64443 .72563 L F
.456 .217 .462 r
.64444 .72559 m .64446 .72542 L .64432 .72518 L F
.705 .433 .511 r
.64446 .72542 m .64437 .72517 L .64443 .72563 L F
.456 .217 .462 r
.64444 .72559 m .64597 .72801 L .64446 .72542 L F
.64356 .72878 m .64574 .72808 L .64428 .72535 L F
.64574 .72808 m .64597 .72801 L .64428 .72535 L F
.705 .433 .511 r
.64447 .7252 m .64449 .72492 L .64393 .72502 L F
.64589 .72567 m .64449 .72492 L .64447 .7252 L F
.193 .607 .946 r
.64432 .72518 m .64438 .72519 L .64437 .72517 L F
.705 .433 .511 r
.64525 .72661 m .64589 .72567 L .64437 .72517 L F
.618 .822 .416 r
.64557 .72615 m .64525 .72661 L .64526 .72671 L F
.438 .211 .47 r
.6472 .72551 m .64542 .72707 L .64446 .72542 L F
.6472 .72551 m .64446 .72542 L .64447 .7252 L F
.193 .607 .946 r
.64437 .72517 m .64578 .72535 L .64575 .72475 L F
.64447 .7252 m .64578 .72535 L .64437 .72517 L F
.64575 .72475 m .64765 .72556 L .64644 .72454 L F
.64578 .72535 m .64765 .72556 L .64575 .72475 L F
.047 .066 .557 r
.64437 .72517 m .64542 .72707 L .64644 .72454 L F
.64446 .72542 m .64542 .72707 L .64437 .72517 L F
.658 .229 0 r
.64527 .72672 m .64597 .72801 L .64645 .72863 L F
.64542 .72707 m .64597 .72801 L .64527 .72672 L F
.438 .211 .47 r
.64765 .72556 m .64597 .72801 L .64542 .72707 L F
.047 .066 .557 r
.64542 .72707 m .64597 .72801 L .64612 .72692 L F
.438 .211 .47 r
.64765 .72556 m .64542 .72707 L .6472 .72551 L F
.047 .066 .557 r
.64542 .72707 m .64612 .72692 L .64644 .72454 L F
.529 .853 .997 r
.5264 .8152 m .52948 .81519 L .5284 .81451 L F
.56 .866 .996 r
.5284 .81451 m .52948 .81519 L .53143 .81452 L F
.888 .778 .283 r
.54963 .80869 m .55012 .80696 L .54844 .80667 L F
.199 .583 .942 r
.54753 .80785 m .54947 .80893 L .54963 .80869 L F
.888 .778 .283 r
.54963 .80869 m .54981 .80931 L .54996 .80817 L F
0 .369 .731 r
.55028 .80937 m .54981 .80931 L .54963 .80869 L F
.199 .583 .942 r
.54947 .80893 m .55028 .80937 L .54963 .80869 L F
.888 .778 .283 r
.54963 .80869 m .54996 .80817 L .55012 .80696 L F
.613 .129 .08 r
.38318 .75122 m .38213 .75179 L .37991 .75101 L F
.524 .085 .147 r
.38536 .75104 m .38213 .75179 L .38318 .75122 L F
.689 .362 .417 r
.52468 .81403 m .5284 .81451 L .5262 .81206 L F
.873 .657 .129 r
.48863 .86174 m .48893 .86224 L .48865 .85963 L F
.862 .794 .782 r
.48863 .86174 m .48957 .86416 L .48893 .86224 L F
.549 .523 .778 r
.45217 .87785 m .45424 .87785 L .45352 .87506 L F
.827 .982 .881 r
.59914 .84396 m .59932 .84231 L .59854 .84389 L F
.59914 .84396 m .60156 .84172 L .59932 .84231 L F
.723 .257 0 r
.55614 .8193 m .55709 .821 L .55489 .81864 L F
.55614 .8193 m .55786 .82188 L .55709 .821 L F
.487 .552 .848 r
.48495 .86651 m .48658 .86464 L .4851 .86615 L F
.48495 .86651 m .48778 .86741 L .48658 .86464 L F
.945 .858 .725 r
.54921 .8485 m .55036 .84907 L .55172 .84577 L F
.574 .357 .547 r
.51509 .88051 m .51334 .87841 L .51282 .88065 L F
.77 .261 0 r
.5117 .87763 m .51334 .87841 L .51509 .88051 L F
.633 .958 .918 r
.6994 .75289 m .69977 .75314 L .70309 .75157 L F
.559 .751 .967 r
.47295 .8723 m .47627 .87285 L .47697 .87226 L F
.818 .631 .65 r
.47303 .87452 m .47627 .87285 L .47295 .8723 L F
.47303 .87452 m .47555 .87533 L .47627 .87285 L F
.005 0 0 r
.47627 .87285 m .47771 .87273 L .47674 .87293 L F
.439 .349 .657 r
.63509 .73417 m .63649 .73184 L .63506 .73246 L F
.982 .728 .47 r
.5049 .84347 m .50489 .84151 L .50465 .84127 L F
.583 .607 .842 r
.4267 .74858 m .42731 .74535 L .42634 .74688 L F
.4267 .74858 m .42875 .74816 L .42731 .74535 L F
.47 .404 .701 r
.4267 .74858 m .42914 .75046 L .42875 .74816 L F
.576 .847 .996 r
.31986 .65855 m .31926 .65972 L .31787 .65903 L F
.31986 .65855 m .32114 .6592 L .31926 .65972 L F
.633 .958 .918 r
.6994 .75289 m .70309 .75157 L .70206 .75084 L F
.829 .644 .651 r
.58327 .79869 m .58179 .79537 L .58347 .79633 L F
.761 .647 .735 r
.60682 .82558 m .60722 .82203 L .60506 .82515 L F
.822 .638 .653 r
.60506 .82515 m .60669 .82789 L .60682 .82558 L F
0 0 0 r
.48881 .84048 m .49084 .84 L .48935 .8382 L F
.415 .188 .459 r
.49084 .84 m .49286 .83836 L .48935 .8382 L F
.49084 .84 m .49272 .84087 L .49286 .83836 L F
.739 .57 .664 r
.66721 .75373 m .67076 .75407 L .66917 .75114 L F
.776 .552 .596 r
.70713 .73285 m .70382 .73466 L .70425 .73288 L F
.70713 .73285 m .7072 .7357 L .70382 .73466 L F
.285 .357 .762 r
.70834 .73154 m .70713 .73285 L .70629 .72995 L F
.579 .525 .758 r
.70834 .73154 m .7072 .7357 L .70713 .73285 L F
.49 .254 .483 r
.50576 .83326 m .50785 .83302 L .50855 .83056 L F
.654 .415 .545 r
.50855 .83056 m .50785 .83302 L .51007 .83201 L F
.485 .151 .325 r
.41592 .77509 m .41482 .77739 L .41285 .77756 L F
.523 .207 .374 r
.41804 .77474 m .41482 .77739 L .41592 .77509 L F
.535 .287 .486 r
.47031 .83615 m .47018 .83813 L .47251 .8378 L F
.593 .178 .225 r
.54981 .80931 m .55199 .80966 L .55311 .80889 L F
.683 .303 .321 r
.55199 .80966 m .55474 .80969 L .55311 .80889 L F
.708 .45 .533 r
.50158 .8414 m .50128 .84373 L .5049 .84347 L F
.618 .348 .485 r
.52102 .84556 m .52023 .84606 L .51897 .846 L F
.417 0 .071 r
.52102 .84556 m .51897 .846 L .51908 .84447 L F
.632 .461 .633 r
.52023 .84606 m .51789 .84616 L .51897 .846 L F
.417 0 .071 r
.51897 .846 m .51811 .84618 L .51814 .84612 L F
.51897 .846 m .51814 .84612 L .51908 .84447 L F
.14 .415 .859 r
.52256 .84955 m .52158 .84966 L .52087 .84926 L F
.52338 .84969 m .52299 .84968 L .52256 .84955 L F
.52299 .84968 m .52158 .84966 L .52256 .84955 L F
.352 0 0 r
.5207 .84932 m .52338 .84969 L .52087 .84926 L F
.091 .614 .879 r
.52087 .84926 m .52158 .84966 L .51985 .84942 L F
.352 0 0 r
.52045 .84941 m .52144 .8495 L .5207 .84932 L F
.52144 .8495 m .52338 .84969 L .5207 .84932 L F
.632 .461 .633 r
.52043 .84647 m .52197 .84962 L .51887 .84702 L F
.52197 .84962 m .52183 .8496 L .51887 .84702 L F
.879 .542 .409 r
.5221 .84588 m .52023 .84606 L .52312 .84532 L F
.366 .44 .805 r
.51887 .84702 m .52183 .8496 L .52126 .84873 L F
.879 .542 .409 r
.51973 .84667 m .52082 .84813 L .52023 .84606 L F
.366 .44 .805 r
.51989 .84688 m .52126 .84873 L .52005 .84686 L F
.51887 .84702 m .52126 .84873 L .51989 .84688 L F
.879 .542 .409 r
.51902 .84754 m .52109 .84908 L .52082 .84813 L F
.51902 .84754 m .52082 .84813 L .51973 .84667 L F
.52082 .84813 m .52182 .84931 L .52023 .84606 L F
.52109 .84908 m .52166 .84926 L .52082 .84813 L F
.52166 .84926 m .52182 .84931 L .52082 .84813 L F
.088 0 0 r
.52418 .84558 m .52221 .84604 L .52063 .84679 L F
.366 .44 .805 r
.52127 .84875 m .52194 .84963 L .52006 .84687 L F
.52127 .84875 m .52006 .84687 L .52006 .84687 L F
.52183 .8496 m .51997 .84673 L .51996 .84673 L F
.52006 .84687 m .52006 .84687 L .51997 .84673 L F
.52183 .8496 m .52193 .84963 L .52127 .84875 L F
.879 .542 .409 r
.52166 .84926 m .52206 .84981 L .52182 .84931 L F
.578 .671 .903 r
.52528 .85083 m .52337 .85148 L .52158 .84966 L F
.52528 .85083 m .52158 .84966 L .52394 .8511 L F
.14 .415 .859 r
.52338 .84969 m .52394 .8511 L .52158 .84966 L F
.546 .382 .61 r
.52292 .85027 m .52226 .8496 L .52031 .84946 L F
.632 .461 .633 r
.52197 .84962 m .52206 .84981 L .52183 .8496 L F
.366 .44 .805 r
.52183 .8496 m .52206 .84981 L .5219 .84962 L F
.5219 .84962 m .52206 .84981 L .52193 .84963 L F
.352 0 0 r
.52141 .84954 m .52338 .84969 L .52045 .84941 L F
.879 .542 .409 r
.52109 .84908 m .52206 .84981 L .52166 .84926 L F
.51902 .84754 m .51973 .84667 L .51997 .84673 L F
.632 .461 .633 r
.52043 .84647 m .51887 .84702 L .51802 .84628 L F
.879 .542 .409 r
.51973 .84667 m .52023 .84606 L .52036 .84682 L F
.366 .44 .805 r
.51996 .84673 m .51997 .84673 L .51982 .84651 L F
.51887 .84702 m .52005 .84686 L .51982 .84651 L F
.632 .461 .633 r
.52023 .84606 m .52043 .84647 L .51802 .84628 L F
.52023 .84606 m .51802 .84628 L .51789 .84616 L F
.417 0 .071 r
.5181 .8462 m .51758 .8461 L .51908 .84447 L F
.618 .348 .485 r
.52102 .84556 m .51897 .846 L .51763 .84593 L F
.417 0 .071 r
.52102 .84556 m .5181 .8462 L .51811 .84618 L F
.632 .461 .633 r
.51897 .846 m .51789 .84616 L .51763 .84593 L F
.417 0 .071 r
.5181 .8462 m .51735 .84636 L .51758 .8461 L F
.366 .44 .805 r
.51789 .84616 m .5181 .8462 L .51794 .84611 L F
.618 .348 .485 r
.5181 .8462 m .51763 .84593 L .51735 .84636 L F
.52102 .84556 m .51763 .84593 L .5181 .8462 L F
.366 .44 .805 r
.51794 .84611 m .51982 .84651 L .51889 .84514 L F
.5181 .8462 m .51982 .84651 L .51794 .84611 L F
.871 .584 .499 r
.51889 .84514 m .52118 .84851 L .51895 .84625 L F
.366 .44 .805 r
.52193 .84963 m .52206 .84981 L .52194 .84963 L F
.52193 .84963 m .52194 .84963 L .52127 .84875 L F
.51789 .84616 m .51887 .84702 L .51982 .84651 L F
.871 .584 .499 r
.52118 .84851 m .52206 .84981 L .51895 .84625 L F
.879 .542 .409 r
.51902 .84754 m .51997 .84673 L .52036 .84682 L F
.871 .584 .499 r
.51895 .84625 m .51963 .84702 L .51902 .84754 L F
.51963 .84702 m .52206 .84981 L .51902 .84754 L F
.546 .382 .61 r
.52127 .85241 m .52292 .85027 L .52031 .84946 L F
.52292 .85027 m .52338 .84969 L .52226 .8496 L F
.088 0 0 r
.52123 .8467 m .52063 .84679 L .51902 .84754 L F
.52418 .84558 m .52063 .84679 L .52123 .8467 L F
.879 .542 .409 r
.52036 .84682 m .52023 .84606 L .5221 .84588 L F
.704 .498 .607 r
.52312 .84532 m .52023 .84606 L .52102 .84556 L F
.686 .591 .743 r
.51889 .84514 m .5222 .84604 L .52093 .84201 L F
.5222 .84604 m .52221 .84604 L .52221 .84603 L F
.161 0 0 r
.52344 .8454 m .52418 .84558 L .5221 .84588 L F
.686 .591 .743 r
.5222 .84604 m .52221 .84603 L .52093 .84201 L F
.161 0 0 r
.52176 .8462 m .52418 .84558 L .52123 .8467 L F
.5221 .84588 m .52301 .84575 L .52221 .84603 L F
.509 .485 .766 r
.52221 .84603 m .52221 .84604 L .52418 .84558 L F
.161 0 0 r
.52301 .84575 m .52418 .84558 L .52176 .8462 L F
.52312 .84532 m .52344 .8454 L .5221 .84588 L F
.647 .222 .224 r
.52662 .84522 m .52312 .84532 L .52426 .84372 L F
.507 0 0 r
.52662 .84522 m .52551 .84578 L .52312 .84532 L F
.509 .485 .766 r
.52093 .84201 m .52221 .84603 L .52418 .84558 L F
.871 .584 .499 r
.5222 .84604 m .51902 .84754 L .52221 .84604 L F
.161 0 0 r
.52184 .84612 m .5222 .84604 L .52176 .8462 L F
.5222 .84604 m .5222 .84604 L .52176 .8462 L F
.5221 .84588 m .52221 .84603 L .52184 .84612 L F
.5221 .84588 m .52123 .8467 L .52036 .84682 L F
.871 .584 .499 r
.51889 .84514 m .51902 .84754 L .5222 .84604 L F
.161 0 0 r
.5222 .84604 m .52221 .84603 L .5222 .84604 L F
.52036 .84682 m .52123 .8467 L .51902 .84754 L F
.352 0 0 r
.52031 .84946 m .52141 .84954 L .52045 .84941 L F
.366 .44 .805 r
.51771 .84601 m .51789 .84616 L .51889 .84514 L F
.51763 .84593 m .51771 .84601 L .51889 .84514 L F
.51771 .84601 m .51889 .84514 L .51889 .84514 L F
0 0 0 r
.51908 .84447 m .51758 .8461 L .51687 .84647 L F
.51758 .8461 m .51735 .84636 L .51718 .8464 L F
.51758 .8461 m .51718 .8464 L .51687 .84647 L F
.743 .486 .542 r
.48964 .83608 m .48935 .8382 L .49286 .83836 L F
.712 .644 .779 r
.50567 .83557 m .50785 .83302 L .50576 .83326 L F
.332 .797 .69 r
.34939 .8112 m .34935 .8112 L .34856 .81169 L F
.34939 .8112 m .34988 .81089 L .34935 .8112 L F
.34939 .8112 m .35173 .81015 L .34988 .81089 L F
.556 .562 .815 r
.5036 .83595 m .50581 .83684 L .50567 .83557 L F
.499 .134 .277 r
.48132 .87052 m .48218 .87223 L .48007 .8723 L F
.382 .318 .66 r
.48413 .8696 m .48132 .87052 L .48219 .86767 L F
.641 .196 .177 r
.48543 .87217 m .48132 .87052 L .48413 .8696 L F
.48543 .87217 m .48218 .87223 L .48132 .87052 L F
.28 .555 .927 r
.51156 .84627 m .51263 .84551 L .50977 .84461 L F
.254 .504 .9 r
.51156 .84627 m .5132 .8468 L .51263 .84551 L F
.109 .397 .851 r
.51156 .84627 m .5146 .84911 L .5132 .8468 L F
.749 .806 .898 r
.47637 .85619 m .4747 .85705 L .47783 .85703 L F
.792 .689 .751 r
.4747 .85705 m .47582 .85987 L .47783 .85703 L F
.709 .806 .925 r
.47637 .85619 m .47783 .85703 L .47992 .85607 L F
.703 .419 .49 r
.68116 .74505 m .68448 .74354 L .68158 .743 L F
.68116 .74505 m .68438 .74535 L .68448 .74354 L F
.631 .098 0 r
.68673 .74508 m .68448 .74354 L .68438 .74535 L F
.046 0 0 r
.36838 .78749 m .36639 .78772 L .36851 .78747 L F
.227 0 0 r
.36639 .78772 m .36521 .7884 L .36851 .78747 L F
.791 .592 .632 r
.64484 .72259 m .64628 .71967 L .64291 .71915 L F
.529 .355 .588 r
.64823 .71685 m .64835 .71948 L .64628 .71967 L F
.506 .263 .48 r
.64628 .71967 m .64835 .71948 L .64484 .72259 L F
.843 .873 .863 r
.64484 .72259 m .6473 .71837 L .64628 .71967 L F
.409 .615 .934 r
.34264 .6765 m .34197 .67812 L .34086 .67627 L F
.34264 .6765 m .34416 .67863 L .34197 .67812 L F
.782 .557 .595 r
.50973 .83586 m .50923 .83809 L .51274 .83753 L F
.71 .366 .394 r
.50923 .83809 m .511 .84029 L .51274 .83753 L F
.66 .306 .363 r
.51274 .83753 m .51466 .84029 L .51439 .83796 L F
.51274 .83753 m .511 .84029 L .51466 .84029 L F
.701 .636 .781 r
.54928 .78201 m .5524 .78285 L .55166 .78022 L F
.209 0 0 r
.54841 .78463 m .5524 .78285 L .54928 .78201 L F
.54841 .78463 m .55065 .78435 L .5524 .78285 L F
.316 .384 .774 r
.55166 .78022 m .5524 .78285 L .55325 .78177 L F
0 0 0 r
.5524 .78285 m .55213 .78326 L .55325 .78177 L F
.5524 .78285 m .55065 .78435 L .55213 .78326 L F
.363 .437 .804 r
.42553 .74505 m .42634 .74688 L .42731 .74535 L F
.281 .78 .864 r
.39855 .74486 m .39698 .74485 L .39492 .74524 L F
.289 .761 .937 r
.4004 .74504 m .39698 .74485 L .39855 .74486 L F
0 .338 .792 r
.68166 .72441 m .684 .72625 L .68279 .72558 L F
.71 .685 .824 r
.66411 .73853 m .66703 .74049 L .66595 .7374 L F
.74 .695 .809 r
.66595 .7374 m .66703 .74049 L .66919 .73781 L F
.58 .302 .459 r
.42295 .75872 m .42516 .75861 L .42564 .75662 L F
.528 .322 .544 r
.42516 .75861 m .42731 .75602 L .42564 .75662 L F
.438 0 .059 r
.55367 .77962 m .55587 .77957 L .55684 .7782 L F
.192 0 0 r
.55684 .7782 m .55801 .77888 L .55908 .77899 L F
.55684 .7782 m .55587 .77957 L .55801 .77888 L F
.486 .112 .254 r
.66561 .71109 m .66871 .70895 L .66578 .71072 L F
.66561 .71109 m .6685 .7105 L .66871 .70895 L F
0 0 0 r
.6685 .7105 m .6711 .70803 L .66871 .70895 L F
.526 .296 .509 r
.51441 .83585 m .51668 .83339 L .51324 .83291 L F
.51441 .83585 m .51653 .83554 L .51668 .83339 L F
.648 .581 .767 r
.51668 .83339 m .5195 .83326 L .51762 .82997 L F
.494 .188 .376 r
.51653 .83554 m .5195 .83326 L .51668 .83339 L F
.614 .854 .989 r
.3852 .88629 m .38168 .8863 L .38484 .88342 L F
.38168 .8863 m .3852 .88629 L .38389 .88627 L F
0 0 .357 r
.3857 .883 m .38584 .88544 L .3852 .88629 L F
.543 .919 .935 r
.3852 .88629 m .38584 .88544 L .38389 .88627 L F
.992 .852 .494 r
.66896 .71584 m .66996 .71427 L .66997 .71656 L F
.66896 .71584 m .6694 .71364 L .66996 .71427 L F
.66996 .71427 m .66896 .71584 L .66997 .71656 L F
.66996 .71427 m .6694 .71364 L .66896 .71584 L F
.479 .458 .757 r
.33213 .66953 m .33447 .67108 L .33291 .67143 L F
.655 .911 .596 r
.67625 .69783 m .678 .69609 L .67728 .69827 L F
.67625 .69783 m .67848 .6952 L .678 .69609 L F
.819 .686 .717 r
.60714 .80656 m .60579 .80376 L .60418 .80649 L F
.60714 .80656 m .60748 .80448 L .60579 .80376 L F
.858 .75 .742 r
.60377 .80869 m .60714 .80656 L .60418 .80649 L F
.60377 .80869 m .60531 .8095 L .60714 .80656 L F
.025 .092 .596 r
.54592 .84352 m .54691 .84263 L .54632 .84126 L F
.54602 .84104 m .54632 .84126 L .54604 .8406 L F
.54592 .84352 m .54632 .84126 L .54602 .84104 L F
.264 .75 .922 r
.54523 .84046 m .54805 .84085 L .54511 .84021 L F
.54538 .84075 m .54564 .84076 L .54523 .84046 L F
.54564 .84076 m .54805 .84085 L .54523 .84046 L F
.609 .396 .567 r
.54511 .84021 m .54805 .84085 L .54836 .83858 L F
.765 .66 .746 r
.53588 .82474 m .5392 .82505 L .53827 .82214 L F
.744 .51 .575 r
.53313 .82226 m .53588 .82474 L .5348 .8218 L F
0 0 0 r
.53827 .82214 m .53665 .82441 L .53588 .82474 L F
.744 .51 .575 r
.53313 .82226 m .53325 .82509 L .53588 .82474 L F
.986 .708 .384 r
.53588 .82474 m .53506 .82458 L .5348 .8218 L F
.346 .495 .865 r
.53665 .82441 m .5348 .8218 L .53506 .82458 L F
.53665 .82441 m .53472 .8224 L .5348 .8218 L F
.127 0 0 r
.53313 .82226 m .5348 .8218 L .53491 .82105 L F
.346 .495 .865 r
.53472 .8224 m .53355 .82119 L .5348 .8218 L F
.127 0 0 r
.53491 .82105 m .5348 .8218 L .53608 .82027 L F
.901 .882 .806 r
.5348 .8218 m .53532 .81984 L .53544 .81958 L F
.877 .527 .031 r
.53472 .8171 m .53562 .8192 L .53544 .81958 L F
0 0 .523 r
.53472 .8171 m .53544 .81958 L .53602 .81719 L F
.901 .882 .806 r
.53532 .81984 m .53602 .81719 L .53544 .81958 L F
.877 .527 .031 r
.53562 .8192 m .53608 .82027 L .53544 .81958 L F
.713 .305 .272 r
.5348 .8218 m .53827 .82214 L .53608 .82027 L F
.5348 .8218 m .53608 .82027 L .53544 .81958 L F
.5348 .8218 m .53827 .82214 L .53608 .82027 L F
.822 .682 .709 r
.60579 .80376 m .60748 .80448 L .60623 .80149 L F
.364 .397 .762 r
.48417 .86333 m .4851 .86615 L .48658 .86464 L F
.497 .228 .437 r
.3413 .76206 m .34082 .76399 L .33898 .76377 L F
.424 .162 .41 r
.34287 .76323 m .3413 .76206 L .34336 .76216 L F
.34287 .76323 m .34082 .76399 L .3413 .76206 L F
.544 .237 .399 r
.43997 .76198 m .43743 .7638 L .4378 .76236 L F
.502 .446 .727 r
.33324 .66584 m .33378 .66918 L .33213 .66953 L F
.504 .455 .736 r
.33378 .66918 m .33447 .67108 L .33213 .66953 L F
.066 0 0 r
.47922 .87852 m .48154 .87849 L .48248 .87833 L F
.461 .166 .377 r
.48248 .87833 m .48365 .87891 L .48542 .87672 L F
0 .105 .631 r
.48296 .87838 m .48248 .87833 L .48154 .87849 L F
.614 .049 0 r
.48611 .88078 m .48248 .87833 L .48459 .88033 L F
0 .105 .631 r
.48296 .87838 m .48459 .88033 L .48248 .87833 L F
.89 .611 .508 r
.56586 .82504 m .56606 .82735 L .56738 .82536 L F
.712 .611 .743 r
.56606 .82735 m .56842 .82443 L .56738 .82536 L F
.813 .328 0 r
.51502 .87546 m .51256 .87358 L .51424 .87438 L F
0 .316 .798 r
.51574 .87527 m .51502 .87546 L .51424 .87438 L F
.694 .153 0 r
.51843 .87809 m .51695 .87694 L .5178 .8778 L F
.51695 .87694 m .51502 .87546 L .5178 .8778 L F
.105 .02 .466 r
.51861 .87861 m .5178 .8778 L .51886 .877 L F
.829 .438 .31 r
.51821 .88124 m .51843 .87809 L .5178 .8778 L F
.105 .02 .466 r
.51821 .88124 m .5178 .8778 L .51861 .87861 L F
0 .246 .758 r
.51574 .87527 m .5178 .8778 L .51502 .87546 L F
.297 .481 .871 r
.69364 .74504 m .69504 .7441 L .692 .74375 L F
.503 0 0 r
.69586 .74522 m .69523 .74557 L .69364 .74504 L F
.297 .481 .871 r
.69364 .74504 m .69523 .74557 L .69504 .7441 L F
.844 .443 .284 r
.54386 .8193 m .54693 .82193 L .54622 .82066 L F
.664 .137 0 r
.51961 .87465 m .52168 .87722 L .51938 .87439 L F
.51961 .87465 m .52124 .87635 L .52168 .87722 L F
.52124 .87635 m .52237 .87752 L .52168 .87722 L F
.829 .438 .31 r
.51821 .88124 m .52064 .88125 L .51843 .87809 L F
.986 .71 .395 r
.52248 .87765 m .52286 .88053 L .52081 .88016 L F
.349 0 .169 r
.52286 .88053 m .52081 .88016 L .52064 .88125 L F
.986 .71 .395 r
.52248 .87765 m .52081 .88016 L .52064 .88125 L F
.895 .835 .779 r
.52248 .87765 m .52064 .88125 L .51834 .88124 L F
0 0 0 r
.51886 .88165 m .5183 .88121 L .51664 .88035 L F
.804 .808 .855 r
.51633 .88353 m .5184 .88169 L .51664 .88035 L F
.635 .253 .303 r
.51644 .88216 m .51912 .88163 L .51639 .88259 L F
0 0 0 r
.5184 .88169 m .51886 .88165 L .51664 .88035 L F
.635 .253 .303 r
.51664 .88035 m .5183 .88121 L .51644 .88216 L F
.895 .835 .779 r
.5183 .88121 m .51834 .88124 L .51824 .88124 L F
0 0 0 r
.51886 .88165 m .51912 .88163 L .5183 .88121 L F
.635 .253 .303 r
.5183 .88121 m .51912 .88163 L .51644 .88216 L F
.895 .835 .779 r
.51827 .88119 m .5183 .88121 L .51821 .88124 L F
.5183 .88121 m .51824 .88124 L .51821 .88124 L F
.52248 .87765 m .51834 .88124 L .51827 .88119 L F
.52248 .87765 m .51821 .88124 L .52129 .87949 L F
.999 .83 .532 r
.52168 .87722 m .52248 .87765 L .52129 .87949 L F
0 0 .206 r
.52198 .8778 m .52168 .87722 L .52129 .87949 L F
.52261 .87624 m .52168 .87722 L .52198 .8778 L F
.832 .374 .127 r
.51938 .87439 m .52113 .87653 L .52042 .87711 L F
.52113 .87653 m .52168 .87722 L .52042 .87711 L F
.728 .695 .818 r
.52042 .87711 m .51821 .88124 L .51876 .87765 L F
.52042 .87711 m .51876 .87765 L .51886 .877 L F
.529 .908 .947 r
.52042 .87711 m .52168 .87722 L .52096 .8769 L F
.728 .695 .818 r
.52042 .87711 m .52129 .87949 L .51821 .88124 L F
.529 .908 .947 r
.52096 .8769 m .52168 .87722 L .52261 .87624 L F
.664 .137 0 r
.52237 .87752 m .52248 .87765 L .52168 .87722 L F
0 0 .206 r
.52261 .87624 m .52129 .87949 L .52042 .87711 L F
0 0 0 r
.52185 .87664 m .52042 .87711 L .51939 .87795 L F
.52261 .87624 m .52042 .87711 L .52185 .87664 L F
.51939 .87795 m .52042 .87711 L .51905 .87813 L F
.864 .701 .678 r
.57792 .8252 m .57726 .82813 L .57497 .82733 L F
.615 .62 .832 r
.57927 .82192 m .57792 .8252 L .57725 .82321 L F
.57927 .82192 m .58058 .82504 L .57792 .8252 L F
.874 .971 .849 r
.50192 .86447 m .50414 .86274 L .50201 .86515 L F
.109 0 .399 r
.50201 .86515 m .5028 .86679 L .50192 .86447 L F
.248 .688 .959 r
.65472 .72071 m .65555 .72008 L .65425 .71907 L F
.65472 .72071 m .65794 .72094 L .65555 .72008 L F
.464 .138 .328 r
.40082 .78502 m .39771 .78794 L .39887 .78565 L F
.767 .562 .622 r
.66595 .7374 m .66941 .73546 L .66771 .73482 L F
.66595 .7374 m .66919 .73781 L .66941 .73546 L F
.495 .212 .413 r
.33898 .76377 m .34082 .76399 L .3388 .76435 L F
.641 .541 .725 r
.51154 .86206 m .50983 .86497 L .50934 .86241 L F
.373 .164 .463 r
.34512 .68911 m .34305 .6872 L .3456 .68702 L F
.34512 .68911 m .34354 .68971 L .34305 .6872 L F
.467 .795 .999 r
.39285 .7455 m .39361 .74452 L .39172 .74469 L F
.39285 .7455 m .39492 .74524 L .39361 .74452 L F
.66 .518 .68 r
.66847 .75661 m .67076 .75407 L .66721 .75373 L F
.66847 .75661 m .67039 .75637 L .67076 .75407 L F
.649 .466 .622 r
.66847 .75661 m .66857 .75914 L .67039 .75637 L F
.729 .511 .596 r
.59956 .79853 m .60297 .79628 L .59962 .79611 L F
.59956 .79853 m .60297 .79873 L .60297 .79628 L F
.611 .431 .614 r
.44918 .8646 m .45161 .86509 L .4515 .86256 L F
.807 .763 .812 r
.63873 .73977 m .64212 .73821 L .64103 .73709 L F
.779 .793 .864 r
.64103 .73709 m .64212 .73821 L .6447 .73657 L F
0 .021 .59 r
.54825 .84577 m .54769 .84606 L .54921 .8485 L F
.343 0 .069 r
.39877 .77257 m .39949 .7739 L .40078 .77216 L F
.39877 .77257 m .39743 .77426 L .39949 .7739 L F
.491 .212 .419 r
.42777 .76938 m .42514 .77178 L .4257 .76972 L F
.014 0 0 r
.34062 .69413 m .3402 .69341 L .34147 .69268 L F
.34062 .69413 m .33897 .69495 L .3402 .69341 L F
.584 .35 .527 r
.44284 .75884 m .44361 .76071 L .43997 .76198 L F
.582 .363 .548 r
.44495 .75872 m .44361 .76071 L .44284 .75884 L F
.678 .337 .391 r
.6406 .63209 m .64388 .6319 L .64289 .63395 L F
.54 .064 .074 r
.64299 .63225 m .64388 .6319 L .6406 .63209 L F
.79 .578 .615 r
.64596 .63194 m .64289 .63395 L .64388 .6319 L F
.725 .729 .853 r
.64299 .63225 m .64596 .63194 L .64388 .6319 L F
.873 .657 .129 r
.48863 .86174 m .48865 .85963 L .4868 .86011 L F
.272 0 0 r
.65239 .62166 m .65216 .62353 L .65149 .62311 L F
.077 0 .445 r
.6537 .61832 m .65239 .62166 L .65205 .622 L F
.6537 .61832 m .6538 .62076 L .65239 .62166 L F
.988 .841 .463 r
.65239 .62166 m .65149 .62311 L .65216 .62353 L F
.65239 .62166 m .65149 .62311 L .65216 .62353 L F
0 0 0 r
.65239 .62166 m .6538 .62076 L .65149 .62311 L F
.588 .757 .959 r
.43711 .73561 m .43482 .73601 L .4338 .73498 L F
.597 .553 .776 r
.43734 .73714 m .43482 .73601 L .43711 .73561 L F
.777 .602 .662 r
.49893 .87004 m .4964 .86752 L .49651 .87054 L F
.77 .595 .661 r
.49787 .87315 m .49893 .87004 L .49651 .87054 L F
.702 .33 .34 r
.49838 .87383 m .49893 .87004 L .49787 .87315 L F
.985 .76 .361 r
.67442 .73781 m .67381 .7347 L .67479 .73545 L F
.656 .589 .768 r
.63105 .73848 m .63153 .74042 L .63322 .73786 L F
.573 .479 .71 r
.63322 .73786 m .63153 .74042 L .63359 .73993 L F
.096 .192 .675 r
.57438 .81003 m .57579 .80937 L .57463 .80838 L F
.695 .233 .151 r
.55968 .81743 m .56185 .81914 L .56287 .81813 L F
.843 .761 .772 r
.58792 .8222 m .58979 .82321 L .58771 .82431 L F
.316 .803 .875 r
.6603 .62588 m .66328 .62556 L .66115 .62465 L F
.725 .278 .19 r
.65785 .62392 m .6603 .62588 L .66115 .62465 L F
.962 .703 .263 r
.56078 .82787 m .56041 .83041 L .55966 .82706 L F
.56078 .82787 m .56075 .83119 L .56041 .83041 L F
0 0 0 r
.7072 .7357 m .7096 .73547 L .71026 .7354 L F
.579 .525 .758 r
.70834 .73154 m .7096 .73547 L .7072 .7357 L F
.072 .192 .685 r
.71007 .73352 m .7096 .73547 L .70834 .73154 L F
.884 .985 .714 r
.71007 .73352 m .70878 .73557 L .7096 .73547 L F
.70878 .73557 m .70846 .73607 L .7096 .73547 L F
0 0 0 r
.71026 .7354 m .7096 .73547 L .71029 .73539 L F
.918 .968 .667 r
.71138 .73574 m .71029 .73539 L .7096 .73547 L F
.71138 .73574 m .71252 .73501 L .71029 .73539 L F
.545 .817 .996 r
.6704 .62902 m .66791 .62963 L .66666 .62865 L F
.565 .381 .591 r
.6704 .62902 m .66785 .63181 L .66791 .62963 L F
.709 .985 .881 r
.64823 .71685 m .6497 .71396 L .64744 .7141 L F
.64823 .71685 m .64944 .71507 L .6497 .71396 L F
.64823 .71685 m .64805 .71633 L .64944 .71507 L F
.385 .06 .286 r
.55139 .78683 m .54942 .78737 L .55022 .78501 L F
.572 .559 .801 r
.54996 .78578 m .54942 .78737 L .55139 .78683 L F
.757 .428 .429 r
.55022 .78501 m .54754 .78623 L .54719 .78593 L F
.55022 .78501 m .54942 .78737 L .54703 .78646 L F
.572 .559 .801 r
.54841 .78463 m .54891 .78597 L .54996 .78578 L F
.54891 .78597 m .54942 .78737 L .54996 .78578 L F
.757 .428 .429 r
.54754 .78623 m .54703 .78646 L .54708 .78631 L F
.54754 .78623 m .54708 .78631 L .54719 .78593 L F
.385 .06 .286 r
.55139 .78683 m .55022 .78501 L .55251 .784 L F
.957 .643 .39 r
.47184 .87418 m .47295 .8723 L .47108 .87195 L F
.47184 .87418 m .47303 .87452 L .47295 .8723 L F
.78 .929 .932 r
.4735 .87028 m .47295 .8723 L .47697 .87226 L F
.4735 .87028 m .47108 .87195 L .47295 .8723 L F
.626 .716 .911 r
.39034 .89042 m .39194 .89193 L .39368 .89119 L F
.39034 .89042 m .39194 .89193 L .39368 .89119 L F
.524 .394 .646 r
.45076 .87307 m .45253 .87038 L .45051 .87075 L F
.589 .292 .433 r
.65498 .62627 m .65785 .62392 L .65568 .62395 L F
.349 .001 .226 r
.53417 .83628 m .53517 .83771 L .5353 .83512 L F
.53417 .83628 m .53315 .83839 L .53517 .83771 L F
.09 0 0 r
.36822 .80292 m .3719 .80118 L .37005 .80243 L F
.213 0 0 r
.3719 .80118 m .37308 .80157 L .37005 .80243 L F
.3719 .80118 m .37381 .80085 L .37308 .80157 L F
.38 0 .152 r
.348 .73462 m .35003 .73427 L .35127 .73235 L F
.427 .065 .246 r
.35003 .73427 m .3532 .73173 L .35127 .73235 L F
.717 .461 .538 r
.55737 .80892 m .56071 .80916 L .56063 .80675 L F
.786 .517 .53 r
.56063 .80675 m .56071 .80916 L .56206 .80917 L F
.805 .678 .724 r
.65675 .73388 m .65523 .73569 L .654 .73234 L F
.65675 .73388 m .654 .73234 L .65433 .73495 L F
.912 .915 .807 r
.65433 .73495 m .65523 .73569 L .65675 .73388 L F
.296 .285 .677 r
.58576 .82482 m .58543 .82836 L .58387 .82772 L F
.58576 .82482 m .58668 .82906 L .58543 .82836 L F
.901 .759 .694 r
.58543 .82836 m .58479 .83049 L .58387 .82772 L F
.525 .107 .189 r
.55514 .78336 m .55251 .784 L .55274 .78281 L F
.59 .397 .589 r
.48417 .86333 m .48833 .86234 L .4868 .86011 L F
.299 .299 .691 r
.4868 .86011 m .48833 .86234 L .48863 .86174 L F
.639 .947 .951 r
.63764 .72367 m .63875 .72386 L .63788 .72439 L F
.63788 .72439 m .63875 .72386 L .63764 .72367 L F
.916 .816 .35 r
.63788 .72439 m .63923 .72807 L .63875 .72386 L F
0 .175 .691 r
.52446 .85717 m .52151 .85439 L .52299 .85611 L F
.812 .692 .732 r
.52337 .85886 m .52407 .85754 L .52322 .85638 L F
0 .175 .691 r
.52377 .85673 m .52307 .85617 L .52322 .85638 L F
.52446 .85717 m .52299 .85611 L .52377 .85673 L F
.683 .569 .721 r
.52649 .85457 m .52446 .85717 L .52322 .85638 L F
.812 .692 .732 r
.52407 .85754 m .52465 .85647 L .52322 .85638 L F
0 .175 .691 r
.52307 .85617 m .52299 .85611 L .52322 .85638 L F
.587 .592 .825 r
.52106 .85652 m .52165 .85504 L .5203 .85466 L F
.448 .294 .578 r
.52361 .85407 m .52322 .85638 L .52151 .85439 L F
.587 .592 .825 r
.52165 .85504 m .52215 .85378 L .52084 .8544 L F
.52165 .85504 m .52084 .8544 L .5203 .85466 L F
.711 .582 .709 r
.47227 .84395 m .4726 .84686 L .471 .84634 L F
.743 .465 .509 r
.4726 .84686 m .47235 .84892 L .471 .84634 L F
.562 .473 .712 r
.47227 .84395 m .4726 .84686 L .47476 .84641 L F
.511 .269 .484 r
.47235 .84892 m .47476 .84641 L .4726 .84686 L F
.476 0 0 r
.50087 .84768 m .49926 .84842 L .49856 .84801 L F
.177 0 0 r
.50261 .84763 m .50087 .84768 L .50281 .84712 L F
.50261 .84763 m .49926 .84842 L .50087 .84768 L F
.322 .059 .35 r
.47511 .83286 m .4771 .83278 L .47731 .83041 L F
.417 .143 .389 r
.47511 .83286 m .47661 .83491 L .4771 .83278 L F
.47511 .83286 m .47468 .8355 L .47661 .83491 L F
.406 0 .122 r
.35783 .72962 m .35987 .72939 L .36129 .72761 L F
.466 .054 .173 r
.35987 .72939 m .36337 .72746 L .36129 .72761 L F
.295 .038 .343 r
.47731 .83041 m .4786 .83206 L .47968 .82959 L F
.47731 .83041 m .4771 .83278 L .4786 .83206 L F
.641 .824 .971 r
.57904 .80643 m .57765 .80737 L .57585 .80607 L F
.535 0 0 r
.64645 .72863 m .64787 .72961 L .64533 .72748 L F
.514 .326 .564 r
.54379 .84383 m .54184 .84702 L .54343 .84537 L F
.581 .538 .772 r
.54379 .84383 m .54592 .84352 L .54538 .84075 L F
.485 .312 .571 r
.45678 .84925 m .45869 .84884 L .45887 .84655 L F
.531 .385 .628 r
.45681 .85166 m .45869 .84884 L .45678 .84925 L F
.302 0 .256 r
.33269 .70065 m .33015 .70286 L .3309 .70133 L F
.815 .669 .701 r
.50785 .83302 m .51016 .83549 L .51007 .83201 L F
.50785 .83302 m .50973 .83586 L .51016 .83549 L F
.665 .594 .766 r
.51007 .83201 m .51016 .83549 L .51324 .83291 L F
.693 .609 .758 r
.51016 .83549 m .51441 .83585 L .51324 .83291 L F
.299 .089 .418 r
.33458 .69777 m .33269 .70065 L .33312 .69845 L F
.724 .464 .533 r
.33157 .66246 m .33343 .66373 L .3319 .66059 L F
.33157 .66246 m .32996 .66413 L .33343 .66373 L F
.61 .43 .614 r
.4515 .86256 m .45385 .86467 L .4538 .86226 L F
.4515 .86256 m .45161 .86509 L .45385 .86467 L F
.522 .905 .948 r
.64962 .73552 m .64893 .73521 L .64641 .73602 L F
.566 .53 .775 r
.65095 .73246 m .64962 .73552 L .64885 .73254 L F
.65095 .73246 m .65178 .73591 L .64962 .73552 L F
.741 .643 .751 r
.654 .73234 m .6539 .73249 L .65095 .73246 L F
.6539 .73249 m .65178 .73591 L .65133 .73403 L F
.6539 .73249 m .65133 .73403 L .65095 .73246 L F
.604 .334 .481 r
.64918 .73532 m .65176 .73355 L .64893 .73521 L F
.64962 .73552 m .65105 .7342 L .64918 .73532 L F
.65105 .7342 m .65176 .73355 L .64918 .73532 L F
.64962 .73552 m .65178 .73591 L .65176 .73355 L F
.64962 .73552 m .65187 .73727 L .65178 .73591 L F
.491 .202 .402 r
.65575 .63723 m .65751 .63926 L .65527 .63966 L F
.65575 .63723 m .65794 .63682 L .65751 .63926 L F
0 0 .084 r
.47227 .84395 m .47192 .84571 L .47132 .84574 L F
.906 .556 .366 r
.47094 .84366 m .47192 .84574 L .47227 .84395 L F
.47094 .84366 m .47192 .84574 L .47227 .84395 L F
0 .048 .606 r
.47229 .84456 m .47206 .84512 L .47094 .84366 L F
.47248 .84568 m .47223 .8457 L .47094 .84366 L F
0 .065 .615 r
.47094 .84366 m .47258 .84625 L .47192 .84574 L F
0 .048 .606 r
.47229 .84456 m .47094 .84366 L .46949 .84331 L F
.162 0 .069 r
.46949 .84331 m .47021 .84388 L .47229 .84456 L F
.47021 .84388 m .47057 .84418 L .47206 .84451 L F
.47021 .84388 m .47206 .84451 L .47229 .84456 L F
.754 .382 .349 r
.46774 .84191 m .46949 .84331 L .46787 .84091 L F
.824 .358 .103 r
.46787 .84091 m .47094 .84366 L .47031 .84078 L F
.46787 .84091 m .46949 .84331 L .47094 .84366 L F
.618 .378 .532 r
.46456 .84522 m .46774 .84191 L .46494 .84302 L F
.46456 .84522 m .4668 .8454 L .46774 .84191 L F
0 .252 .747 r
.46774 .84191 m .46961 .84306 L .46949 .84331 L F
.438 .206 .463 r
.46774 .84191 m .46904 .84474 L .46949 .84331 L F
.46774 .84191 m .4668 .8454 L .46904 .84474 L F
.496 .144 .299 r
.46571 .84112 m .46494 .84302 L .46774 .84191 L F
.162 0 .069 r
.46949 .84331 m .46904 .84474 L .47057 .84418 L F
0 0 0 r
.46949 .84331 m .46904 .84474 L .46961 .84306 L F
.896 .718 .653 r
.46961 .84306 m .46904 .84474 L .46733 .84159 L F
.646 .777 .944 r
.47047 .84199 m .46961 .84306 L .46733 .84159 L F
.742 .678 .789 r
.46733 .84159 m .4682 .8432 L .47047 .84199 L F
.4682 .8432 m .46904 .84474 L .46959 .84368 L F
0 0 .17 r
.46961 .84306 m .46904 .84474 L .47047 .84199 L F
.742 .678 .789 r
.4682 .8432 m .46959 .84368 L .47047 .84199 L F
.541 .88 .988 r
.47265 .84367 m .47229 .84456 L .47057 .84418 L F
.279 0 0 r
.47466 .84364 m .47094 .84366 L .47227 .84395 L F
.562 .473 .712 r
.47227 .84395 m .47476 .84641 L .47466 .84364 L F
.541 .88 .988 r
.47276 .84365 m .47229 .84456 L .47265 .84367 L F
0 .048 .606 r
.47229 .84456 m .47248 .84568 L .47206 .84512 L F
.47248 .84568 m .47258 .84625 L .47223 .8457 L F
0 0 .084 r
.47132 .84574 m .47192 .84574 L .471 .84634 L F
.47192 .84571 m .47192 .84574 L .47132 .84574 L F
0 0 0 r
.68736 .7324 m .68442 .73425 L .68532 .73522 L F
.818 .771 .808 r
.68442 .73425 m .68274 .73526 L .68532 .73522 L F
.83 .68 .697 r
.68532 .73522 m .68195 .73713 L .6833 .7362 L F
.68532 .73522 m .68274 .73526 L .68195 .73713 L F
.697 .699 .849 r
.69494 .73187 m .69635 .73321 L .69298 .73263 L F
.566 .59 .836 r
.69765 .73135 m .69635 .73321 L .69494 .73187 L F
.69765 .73135 m .6982 .73285 L .69635 .73321 L F
.106 .181 .659 r
.47192 .84574 m .47235 .84892 L .471 .84634 L F
.587 .71 .928 r
.56651 .84682 m .56794 .8453 L .56524 .84383 L F
.56651 .84682 m .56819 .84655 L .56794 .8453 L F
.815 .708 .747 r
.69889 .73648 m .69895 .73801 L .69616 .73698 L F
.647 .578 .763 r
.70189 .73577 m .69895 .73801 L .69889 .73648 L F
.551 .743 .966 r
.38027 .72111 m .37954 .7227 L .37825 .72151 L F
.38027 .72111 m .38191 .72259 L .37954 .7227 L F
.641 .541 .725 r
.51154 .86206 m .51255 .86461 L .50983 .86497 L F
.592 .337 .5 r
.50983 .86497 m .51214 .86752 L .51001 .86756 L F
.50983 .86497 m .51255 .86461 L .51249 .86501 L F
.763 .501 .538 r
.51214 .86752 m .51294 .86499 L .51271 .86496 L F
.662 .396 .507 r
.51249 .86501 m .51266 .86517 L .51214 .86752 L F
.739 .704 .819 r
.51271 .86496 m .51294 .86499 L .51288 .86492 L F
.662 .396 .507 r
.51284 .86493 m .51295 .86505 L .51249 .86501 L F
.51295 .86505 m .51407 .86628 L .51285 .86534 L F
.51407 .86628 m .514 .8664 L .51285 .86534 L F
0 0 .132 r
.51295 .86505 m .51294 .86499 L .51214 .86752 L F
.662 .396 .507 r
.51309 .86462 m .51493 .86465 L .51295 .86505 L F
0 0 .132 r
.51298 .86496 m .51298 .86496 L .51295 .86505 L F
.51298 .86496 m .51294 .86499 L .51295 .86505 L F
.734 .641 .756 r
.51538 .86888 m .51667 .86743 L .5159 .8672 L F
.662 .396 .507 r
.51295 .86505 m .51493 .86465 L .51512 .86738 L F
.51295 .86505 m .51512 .86738 L .51508 .86739 L F
.221 0 .292 r
.51147 .86917 m .51214 .86752 L .51143 .86923 L F
.662 .396 .507 r
.51297 .86545 m .51507 .86739 L .51214 .86752 L F
.51507 .86739 m .51487 .86744 L .51214 .86752 L F
.734 .641 .756 r
.51538 .86888 m .5159 .8672 L .5143 .86756 L F
.662 .396 .507 r
.51507 .86739 m .51512 .86743 L .51487 .86744 L F
.734 .641 .756 r
.51486 .86743 m .51508 .86739 L .51337 .86644 L F
.676 .653 .819 r
.51337 .86644 m .51512 .86743 L .51487 .86744 L F
.51337 .86644 m .51487 .86744 L .51214 .86752 L F
.734 .641 .756 r
.5143 .86756 m .51486 .86743 L .51337 .86644 L F
.221 0 .292 r
.51337 .86644 m .51214 .86752 L .51147 .86917 L F
.662 .396 .507 r
.51266 .86517 m .51297 .86545 L .51214 .86752 L F
.719 .44 .502 r
.51512 .86738 m .51667 .86743 L .51512 .86743 L F
.51493 .86465 m .51667 .86743 L .51512 .86738 L F
.734 .641 .756 r
.51511 .86738 m .5159 .8672 L .51586 .86719 L F
.51508 .86739 m .51512 .86738 L .51511 .86738 L F
.51512 .86738 m .5159 .8672 L .51511 .86738 L F
.51508 .86739 m .51586 .86719 L .51337 .86644 L F
.662 .396 .507 r
.51508 .86739 m .51512 .86738 L .51512 .86743 L F
.51255 .86461 m .51309 .86462 L .51298 .86496 L F
.679 .506 .646 r
.51447 .86246 m .51255 .86461 L .51154 .86206 L F
.51447 .86246 m .51493 .86465 L .51255 .86461 L F
.368 .566 .913 r
.5103 .8619 m .51288 .86492 L .5139 .86425 L F
.51288 .86492 m .51294 .86499 L .51298 .86496 L F
.51288 .86492 m .51298 .86496 L .5139 .86425 L F
.662 .396 .507 r
.5128 .86488 m .51298 .86496 L .51295 .86505 L F
.51255 .86461 m .51298 .86496 L .5128 .86488 L F
.772 .449 .441 r
.51337 .86644 m .51486 .86473 L .5139 .86425 L F
.51486 .86473 m .51493 .86465 L .5149 .86464 L F
.51486 .86473 m .5149 .86464 L .5139 .86425 L F
.662 .396 .507 r
.51407 .86628 m .51512 .86743 L .514 .8664 L F
.51295 .86505 m .51285 .86534 L .51249 .86501 L F
0 0 .132 r
.5139 .86425 m .51298 .86496 L .51214 .86752 L F
.592 .337 .5 r
.51061 .86583 m .51249 .86501 L .51214 .86752 L F
.50983 .86497 m .51249 .86501 L .51061 .86583 L F
.763 .501 .538 r
.51214 .86752 m .51271 .86496 L .50792 .86438 L F
.662 .396 .507 r
.51255 .86461 m .51284 .86493 L .51249 .86501 L F
.739 .704 .819 r
.51264 .86495 m .51271 .86496 L .51284 .86486 L F
.51271 .86496 m .51288 .86492 L .51284 .86486 L F
.50792 .86438 m .51264 .86495 L .5103 .8619 L F
.51264 .86495 m .51284 .86486 L .5103 .8619 L F
.845 .906 .878 r
.66704 .7299 m .6667 .73122 L .66822 .73063 L F
.692 .587 .733 r
.50608 .84871 m .50708 .85177 L .50952 .84941 L F
.69 .583 .731 r
.50708 .85177 m .50927 .85174 L .50952 .84941 L F
.626 .402 .558 r
.50705 .85412 m .50927 .85174 L .50708 .85177 L F
.581 .395 .594 r
.51687 .84647 m .51698 .84872 L .5146 .84911 L F
0 0 0 r
.51687 .84647 m .51735 .84636 L .51763 .84593 L F
.99 .728 .411 r
.51608 .84692 m .51687 .84647 L .51763 .84593 L F
.51608 .84692 m .51698 .84872 L .51687 .84647 L F
0 0 .326 r
.56174 .8379 m .56081 .83475 L .56299 .83721 L F
.543 .834 .999 r
.59106 .8139 m .59231 .81459 L .58874 .81504 L F
.59106 .8139 m .59231 .81459 L .58874 .81504 L F
0 0 0 r
.59106 .8139 m .58874 .81504 L .58934 .81501 L F
.779 .793 .864 r
.64103 .73709 m .6447 .73657 L .64341 .73558 L F
.508 .664 .932 r
.6447 .73657 m .64542 .73452 L .64341 .73558 L F
.6447 .73657 m .64641 .73602 L .64542 .73452 L F
.791 .735 .8 r
.50414 .86274 m .50508 .85899 L .50434 .85974 L F
.688 .233 .166 r
.50626 .8644 m .50414 .86274 L .50192 .86447 L F
.798 .568 .589 r
.60485 .81998 m .60668 .81768 L .60596 .81742 L F
.933 .809 .7 r
.60485 .81998 m .60422 .82206 L .60668 .81768 L F
.849 .707 .706 r
.60422 .82206 m .60741 .81998 L .60668 .81768 L F
.613 .678 .888 r
.5146 .84911 m .51608 .84692 L .5132 .8468 L F
.5146 .84911 m .51698 .84872 L .51608 .84692 L F
.53 .297 .507 r
.51537 .8513 m .51698 .84872 L .5146 .84911 L F
.217 0 0 r
.55908 .77899 m .56205 .77903 L .56227 .77836 L F
.745 .468 .511 r
.56205 .77903 m .56512 .77913 L .56227 .77836 L F
.437 .117 .324 r
.38863 .77715 m .38968 .77918 L .39072 .77676 L F
.38863 .77715 m .38769 .77956 L .38968 .77918 L F
.711 .546 .663 r
.59137 .80649 m .58935 .80683 L .59026 .80437 L F
.806 .743 .793 r
.58522 .81156 m .58494 .80767 L .58596 .80897 L F
.327 .001 .25 r
.58782 .80855 m .58596 .80897 L .58799 .80745 L F
.58782 .80855 m .58799 .80745 L .58824 .80726 L F
.483 .743 .985 r
.58782 .80855 m .58596 .80897 L .58494 .80767 L F
.915 .761 .676 r
.58522 .81156 m .58596 .80897 L .58782 .80855 L F
.127 0 .241 r
.58765 .81044 m .58522 .81156 L .58686 .80967 L F
.58765 .81044 m .58686 .80967 L .58782 .80855 L F
.58765 .81044 m .58522 .81156 L .58782 .80855 L F
.483 .743 .985 r
.58782 .80855 m .58494 .80767 L .58659 .80801 L F
.127 0 .241 r
.58757 .81026 m .58782 .80855 L .58659 .80801 L F
0 0 .525 r
.58659 .80801 m .58788 .81066 L .58765 .81044 L F
.58788 .81066 m .58796 .81083 L .58765 .81044 L F
.127 0 .241 r
.58765 .81044 m .58782 .80855 L .58757 .81026 L F
.998 .781 .469 r
.67389 .73016 m .67307 .72953 L .6732 .72709 L F
.988 .797 .558 r
.67389 .73016 m .67259 .73168 L .67307 .72953 L F
.67389 .73016 m .67357 .73241 L .67259 .73168 L F
.134 0 .27 r
.33015 .70286 m .32818 .70578 L .32883 .70393 L F
.589 .806 .404 r
.6024 .84047 m .60156 .84172 L .60358 .83876 L F
.841 .869 .863 r
.60358 .83876 m .60463 .83547 L .60393 .83742 L F
.60358 .83876 m .606 .83638 L .60463 .83547 L F
.808 .905 .5 r
.6024 .84047 m .60358 .83876 L .60393 .83742 L F
.746 .601 .696 r
.52528 .85083 m .52361 .85407 L .52337 .85148 L F
.551 .305 .496 r
.46571 .84112 m .46787 .84091 L .46822 .83873 L F
.642 .466 .629 r
.46787 .84091 m .47018 .83813 L .46822 .83873 L F
.147 0 0 r
.69237 .75322 m .69435 .75358 L .69115 .75303 L F
.685 .621 .778 r
.63359 .73993 m .63448 .74306 L .63679 .74064 L F
.426 .425 .755 r
.54171 .80595 m .54221 .80356 L .53996 .80393 L F
.54171 .80595 m .54338 .80659 L .54221 .80356 L F
.511 .409 .676 r
.5438 .83546 m .54211 .83627 L .54157 .83289 L F
0 .137 .683 r
.50838 .87274 m .50983 .87492 L .51039 .8749 L F
0 .07 .633 r
.50983 .87492 m .5117 .87763 L .51039 .8749 L F
.524 .332 .563 r
.53783 .80412 m .53996 .80393 L .53996 .80145 L F
.345 .504 .873 r
.46092 .88057 m .4618 .87953 L .45955 .87901 L F
.46092 .88057 m .46281 .88097 L .4618 .87953 L F
.986 .71 .395 r
.52248 .87765 m .52349 .87856 L .52286 .88053 L F
.323 0 0 r
.52349 .87856 m .52447 .87967 L .52286 .88053 L F
.829 .771 .797 r
.49238 .82668 m .49481 .82513 L .49467 .82483 L F
.08 .64 .775 r
.47998 .88396 m .48354 .88394 L .4827 .88409 L F
.192 .72 .727 r
.48499 .88355 m .48354 .88394 L .4858 .88374 L F
.48499 .88355 m .4827 .88409 L .48354 .88394 L F
.327 0 0 r
.36159 .75338 m .36013 .75403 L .35836 .75408 L F
.475 .008 .064 r
.36352 .75343 m .36013 .75403 L .36159 .75338 L F
.306 0 .077 r
.33879 .73823 m .33945 .73955 L .34072 .7378 L F
.33879 .73823 m .33748 .74003 L .33945 .73955 L F
.688 .978 .895 r
.59932 .84231 m .60156 .84172 L .6024 .84047 L F
.04 0 0 r
.54703 .78646 m .54621 .78688 L .54719 .78593 L F
.678 .619 .782 r
.54703 .78646 m .54841 .78463 L .54719 .78593 L F
.52 .6 .874 r
.43244 .73256 m .43179 .73503 L .43042 .73286 L F
.43244 .73256 m .4338 .73498 L .43179 .73503 L F
.697 .229 0 r
.67642 .74041 m .67696 .74154 L .67516 .7397 L F
.264 0 0 r
.66294 .71135 m .66561 .71109 L .66578 .71072 L F
.834 .505 .43 r
.58495 .80661 m .58824 .80726 L .58782 .80855 L F
.633 .352 .475 r
.58935 .80683 m .58782 .80855 L .58824 .80726 L F
.645 .49 .659 r
.45148 .75307 m .44951 .75614 L .44979 .7538 L F
.849 .707 .706 r
.60422 .82206 m .60722 .82203 L .60741 .81998 L F
.845 .749 .757 r
.60422 .82206 m .60506 .82515 L .60722 .82203 L F
.904 .539 .083 r
.54836 .83858 m .54777 .83834 L .54627 .83448 L F
.854 .791 .789 r
.54805 .84085 m .54777 .83834 L .54836 .83858 L F
.961 .833 .671 r
.55866 .80164 m .55935 .80379 L .55999 .80166 L F
.771 .584 .646 r
.57842 .82828 m .57656 .83043 L .57726 .82813 L F
.621 .544 .746 r
.5807 .82729 m .57885 .83069 L .57842 .82828 L F
.251 .748 .68 r
.36966 .75085 m .36911 .75107 L .37132 .75055 L F
.36966 .75085 m .36705 .75177 L .36911 .75107 L F
.712 .466 .551 r
.65161 .71084 m .65734 .7112 L .65478 .70832 L F
0 .024 .562 r
.65478 .70832 m .65694 .71066 L .65698 .70835 L F
.65478 .70832 m .65734 .7112 L .65694 .71066 L F
.932 .742 .623 r
.67358 .72433 m .67187 .72407 L .67249 .72111 L F
.932 .719 .592 r
.67358 .72433 m .67162 .72636 L .67187 .72407 L F
.67358 .72433 m .6732 .72709 L .67162 .72636 L F
.491 .516 .811 r
.68572 .74732 m .68673 .74508 L .68438 .74535 L F
.68572 .74732 m .68777 .7482 L .68673 .74508 L F
.806 .685 .731 r
.65642 .7277 m .65266 .72937 L .65527 .72765 L F
.65642 .7277 m .65423 .72995 L .65266 .72937 L F
0 0 0 r
.65527 .72765 m .65803 .72652 L .65642 .7277 L F
.932 .602 .389 r
.67189 .71926 m .67043 .71871 L .66997 .71656 L F
.906 .623 .496 r
.67249 .72111 m .67043 .71871 L .67189 .71926 L F
.5 .307 .55 r
.68653 .69342 m .68675 .69505 L .6892 .69245 L F
.689 .44 .54 r
.685 .69393 m .68675 .69505 L .68653 .69342 L F
0 0 0 r
.68189 .71074 m .68148 .71268 L .68088 .71416 L F
.68088 .71416 m .68033 .71599 L .68092 .7165 L F
.68088 .71416 m .68148 .71268 L .68033 .71599 L F
.323 0 0 r
.46939 .88192 m .47131 .88147 L .47373 .88198 L F
.556 .038 0 r
.47131 .88147 m .47465 .88199 L .47373 .88198 L F
.596 .609 .835 r
.69115 .75303 m .68831 .75096 L .68913 .75118 L F
0 0 0 r
.58235 .84638 m .58299 .84612 L .58257 .84622 L F
.543 .733 .963 r
.58299 .84612 m .58499 .84514 L .58257 .84622 L F
.58299 .84612 m .58504 .84585 L .58499 .84514 L F
.82 .665 .691 r
.5849 .80174 m .58434 .80404 L .58312 .80096 L F
.535 .056 .065 r
.56512 .77913 m .5667 .77927 L .56781 .77805 L F
.652 .191 .146 r
.5667 .77927 m .57001 .77955 L .56781 .77805 L F
.379 .721 .989 r
.67728 .69827 m .67857 .69741 L .67625 .69783 L F
.67728 .69827 m .67961 .69835 L .67857 .69741 L F
.944 .586 .204 r
.55142 .83017 m .55153 .8324 L .55304 .83301 L F
.954 .671 .228 r
.55239 .83394 m .55304 .83301 L .55153 .8324 L F
.55239 .83394 m .55332 .83561 L .55304 .83301 L F
.904 .618 .492 r
.58604 .78696 m .58801 .78563 L .58572 .78473 L F
.58604 .78696 m .58839 .78793 L .58801 .78563 L F
.834 .571 .541 r
.58801 .78563 m .58839 .78793 L .58989 .78804 L F
.8 .597 .628 r
.51653 .83554 m .52077 .83818 L .51861 .83548 L F
.51653 .83554 m .51646 .83791 L .52077 .83818 L F
.542 .145 .237 r
.5166 .84047 m .52077 .83818 L .51646 .83791 L F
.494 .61 .896 r
.52077 .83818 m .52067 .83502 L .51861 .83548 L F
.52077 .83818 m .52277 .83802 L .52067 .83502 L F
0 .31 .7 r
.54221 .80356 m .53996 .80145 L .53996 .80393 L F
.542 .347 .566 r
.53996 .80145 m .53996 .80393 L .54209 .80111 L F
.731 .747 .865 r
.70506 .73628 m .70189 .73577 L .70382 .73466 L F
.649 .713 .894 r
.7072 .7357 m .70506 .73628 L .70382 .73466 L F
0 0 0 r
.68736 .7324 m .68667 .73284 L .68442 .73425 L F
.581 .584 .821 r
.69037 .73142 m .68736 .7324 L .68646 .72966 L F
.475 .097 .242 r
.69037 .73142 m .68667 .73284 L .68736 .7324 L F
.626 .402 .558 r
.50705 .85412 m .50934 .8543 L .50927 .85174 L F
.382 .05 .274 r
.41088 .77811 m .41054 .77956 L .40815 .78003 L F
.471 .127 .302 r
.41233 .77918 m .41088 .77811 L .41285 .77756 L F
.41233 .77918 m .41054 .77956 L .41088 .77811 L F
0 .427 .717 r
.44532 .74974 m .44813 .75056 L .44637 .75041 L F
.644 .576 .763 r
.68747 .72001 m .6886 .72266 L .69062 .72211 L F
.61 .453 .645 r
.6886 .72266 m .68848 .72469 L .69062 .72211 L F
.95 .757 .608 r
.47834 .87034 m .47674 .87293 L .47697 .87226 L F
.47834 .87034 m .47771 .87273 L .47674 .87293 L F
.605 .38 .549 r
.48007 .8723 m .47771 .87273 L .47834 .87034 L F
.655 .717 .894 r
.68165 .74629 m .68438 .74535 L .68116 .74505 L F
.545 .413 .651 r
.45504 .85436 m .45707 .85406 L .45681 .85166 L F
.616 .477 .669 r
.45506 .85674 m .45707 .85406 L .45504 .85436 L F
.767 .701 .789 r
.69084 .7245 m .6945 .72389 L .69285 .72161 L F
.497 .239 .453 r
.69205 .72636 m .6945 .72389 L .69084 .7245 L F
.69205 .72636 m .69398 .72635 L .6945 .72389 L F
.313 .667 .974 r
.6949 .72304 m .69622 .72402 L .6945 .72389 L F
.686 .911 .573 r
.6945 .72389 m .69271 .7259 L .6949 .72304 L F
.881 .847 .806 r
.4943 .8703 m .49228 .87307 L .49094 .87234 L F
.956 .722 .544 r
.49228 .87307 m .49222 .87599 L .49116 .87297 L F
.49139 .87258 m .49116 .87297 L .49094 .87234 L F
.49228 .87307 m .49116 .87297 L .49139 .87258 L F
.678 .637 .802 r
.49222 .87599 m .49319 .87151 L .49094 .87234 L F
.726 .683 .808 r
.48927 .87286 m .49093 .8735 L .48818 .87335 L F
0 0 0 r
.49093 .8735 m .48719 .87629 L .48818 .87335 L F
.759 .871 .444 r
.49142 .87229 m .49018 .87444 L .49061 .8739 L F
.49111 .87306 m .49061 .8739 L .49093 .8735 L F
.881 .847 .806 r
.49174 .87185 m .49094 .87234 L .49155 .87211 L F
.4943 .8703 m .49174 .87185 L .49319 .87151 L F
.49174 .87185 m .49155 .87211 L .49319 .87151 L F
.63 .684 .882 r
.48966 .87043 m .49094 .87234 L .49319 .87151 L F
.48966 .87043 m .49223 .87121 L .49209 .87065 L F
.49223 .87121 m .49319 .87151 L .49209 .87065 L F
.321 0 .03 r
.48966 .87043 m .49085 .87139 L .49209 .87065 L F
.914 .979 .722 r
.49209 .87065 m .49085 .87139 L .49185 .86972 L F
.49209 .87065 m .49185 .86972 L .49272 .86827 L F
.759 .871 .444 r
.49209 .87065 m .49094 .87234 L .49319 .87151 L F
.49209 .87065 m .49093 .8735 L .49094 .87234 L F
.49142 .87229 m .49061 .8739 L .49111 .87306 L F
.49209 .87065 m .49091 .87298 L .49142 .87229 L F
.726 .683 .808 r
.48927 .87286 m .49094 .87234 L .49093 .8735 L F
.759 .871 .444 r
.49091 .87298 m .49018 .87444 L .49142 .87229 L F
.707 .583 .714 r
.49431 .86806 m .4943 .8703 L .4964 .86752 L F
.73 .283 .19 r
.49319 .87151 m .49636 .87229 L .4943 .8703 L F
.657 .512 .675 r
.4943 .8703 m .49651 .87054 L .4964 .86752 L F
.644 .335 .434 r
.4943 .8703 m .49636 .87229 L .49651 .87054 L F
.855 .573 .51 r
.54174 .81695 m .54386 .8193 L .54345 .81731 L F
.66 .58 .755 r
.66051 .73737 m .66152 .7404 L .66411 .73853 L F
.831 .401 .215 r
.39242 .71951 m .39421 .72202 L .39572 .72219 L F
.895 .554 .392 r
.39421 .72202 m .39423 .72339 L .39572 .72219 L F
.242 0 0 r
.39572 .72219 m .39648 .72302 L .3981 .72306 L F
.39572 .72219 m .39423 .72339 L .39648 .72302 L F
.71 .484 .58 r
.51007 .83201 m .51324 .83291 L .51315 .83094 L F
.464 .531 .841 r
.67897 .7442 m .6797 .74251 L .67798 .7427 L F
.67897 .7442 m .68116 .74505 L .6797 .74251 L F
.497 .308 .554 r
.39053 .72238 m .39322 .72204 L .39155 .72082 L F
.39322 .72204 m .39327 .72204 L .39316 .72196 L F
.679 .364 .435 r
.39205 .72168 m .39327 .72204 L .39316 .72185 L F
0 0 0 r
.39327 .72204 m .39205 .72168 L .39342 .72202 L F
.39053 .72238 m .39205 .72168 L .39327 .72204 L F
.679 .364 .435 r
.39205 .72168 m .39399 .72321 L .39327 .72204 L F
.157 .698 .754 r
.3911 .72382 m .39412 .72341 L .39205 .72168 L F
.39412 .72341 m .39423 .72339 L .39399 .72321 L F
.39412 .72341 m .39399 .72321 L .39205 .72168 L F
.497 .308 .554 r
.39322 .72204 m .39316 .72196 L .39155 .72082 L F
.679 .364 .435 r
.39316 .72185 m .39423 .72339 L .39421 .72202 L F
.497 .308 .554 r
.39327 .72204 m .39342 .72202 L .39316 .72185 L F
.39327 .72204 m .39316 .72185 L .39155 .72082 L F
.679 .364 .435 r
.39399 .72321 m .39423 .72339 L .39316 .72185 L F
.39205 .72168 m .39316 .72185 L .39342 .72202 L F
.39316 .72185 m .39421 .72202 L .39342 .72202 L F
.497 .308 .554 r
.39155 .72082 m .39342 .72202 L .39242 .71951 L F
.722 .419 .465 r
.39342 .72202 m .39421 .72202 L .39242 .71951 L F
.712 .644 .779 r
.50567 .83557 m .50973 .83586 L .50785 .83302 L F
.683 .458 .574 r
.50581 .83684 m .50973 .83586 L .50567 .83557 L F
.50581 .83684 m .50923 .83809 L .50973 .83586 L F
.555 .326 .522 r
.34882 .75916 m .34848 .76135 L .34639 .76149 L F
.57 .38 .584 r
.35075 .75869 m .34848 .76135 L .34882 .75916 L F
.665 .867 .975 r
.52233 .86444 m .52362 .86523 L .5256 .86434 L F
.858 .751 .745 r
.55762 .80485 m .55725 .80696 L .55624 .80374 L F
.789 .718 .785 r
.55624 .80374 m .55725 .80696 L .55935 .80379 L F
.415 .112 .34 r
.33305 .74262 m .33565 .74053 L .3337 .74059 L F
.755 .606 .692 r
.49957 .85694 m .49944 .85974 L .50291 .85865 L F
.763 .634 .719 r
.49944 .85974 m .50066 .8622 L .50291 .85865 L F
.566 .478 .715 r
.50291 .85865 m .50508 .85899 L .50473 .85727 L F
.535 .824 .999 r
.42184 .73014 m .41974 .73057 L .41868 .7298 L F
.888 .643 .562 r
.60499 .82743 m .60669 .82789 L .60506 .82515 L F
.858 .608 .56 r
.60509 .82982 m .60669 .82789 L .60499 .82743 L F
.60509 .82982 m .60687 .83025 L .60669 .82789 L F
.401 .838 .709 r
.35179 .81046 m .35383 .80957 L .35549 .80867 L F
0 0 0 r
.35744 .80809 m .3565 .80856 L .35311 .80988 L F
.332 .806 .734 r
.35311 .80988 m .3565 .80856 L .35511 .80901 L F
.401 .838 .709 r
.35242 .81018 m .35549 .80867 L .35311 .80988 L F
0 0 0 r
.35744 .80809 m .35311 .80988 L .35549 .80867 L F
.332 .806 .734 r
.35311 .80988 m .35511 .80901 L .35383 .80944 L F
0 0 0 r
.34988 .81089 m .35383 .80957 L .35179 .81046 L F
.401 .838 .709 r
.35229 .81024 m .35242 .81018 L .35311 .80988 L F
.35179 .81046 m .3524 .81017 L .35229 .81024 L F
0 0 0 r
.35275 .80993 m .35291 .80982 L .35383 .80957 L F
.401 .838 .709 r
.3524 .81017 m .35549 .80867 L .35229 .81024 L F
0 0 0 r
.34988 .81089 m .35173 .81015 L .35291 .80982 L F
.34988 .81089 m .35291 .80982 L .35275 .80993 L F
.552 .299 .486 r
.48417 .86333 m .48658 .86464 L .48833 .86234 L F
.531 .1 .167 r
.38708 .72367 m .389 .72394 L .39053 .72238 L F
0 0 0 r
.39053 .72238 m .389 .72394 L .39205 .72168 L F
.617 .139 .095 r
.50322 .88779 m .50631 .88785 L .50525 .88833 L F
.047 0 0 r
.50525 .88833 m .50631 .88785 L .50834 .88751 L F
.305 .503 .886 r
.42553 .74505 m .42659 .74383 L .42385 .74287 L F
.42553 .74505 m .42731 .74535 L .42659 .74383 L F
0 .487 .851 r
.47428 .8643 m .47405 .86466 L .47314 .86262 L F
.609 .732 .932 r
.66428 .61348 m .66105 .61275 L .66359 .61199 L F
.631 .194 .192 r
.66428 .61348 m .66326 .615 L .66108 .61436 L F
.66108 .61436 m .66326 .615 L .66081 .61444 L F
.622 .587 .793 r
.66081 .61444 m .66326 .615 L .66264 .61322 L F
.478 .807 1 r
.66105 .61275 m .66205 .61152 L .66359 .61199 L F
.659 .739 .909 r
.66746 .61325 m .6654 .61318 L .66545 .61219 L F
.392 .584 .918 r
.66545 .61219 m .66428 .61348 L .66359 .61199 L F
.994 .758 .46 r
.66346 .61277 m .66428 .61348 L .66545 .61219 L F
.622 .587 .793 r
.66093 .61416 m .66264 .61322 L .66241 .61254 L F
.934 .622 .163 r
.66205 .61152 m .66326 .615 L .66242 .61307 L F
.994 .758 .46 r
.66242 .61307 m .66277 .61315 L .66346 .61277 L F
.659 .739 .909 r
.6654 .61318 m .66242 .61307 L .66346 .61277 L F
.6654 .61318 m .66346 .61277 L .66545 .61219 L F
.622 .587 .793 r
.66168 .61239 m .66241 .61254 L .66205 .61152 L F
.66093 .61416 m .66241 .61254 L .66168 .61239 L F
.66081 .61444 m .66264 .61322 L .66093 .61416 L F
.994 .758 .46 r
.66277 .61315 m .66428 .61348 L .66346 .61277 L F
.66242 .61307 m .66326 .615 L .66428 .61348 L F
.759 .382 .341 r
.66538 .61561 m .66326 .615 L .66242 .61307 L F
.66676 .61681 m .66326 .615 L .66538 .61561 L F
.81 .685 .727 r
.60596 .81742 m .60488 .81368 L .6031 .81678 L F
.60596 .81742 m .60645 .81482 L .60488 .81368 L F
.798 .568 .589 r
.60485 .81998 m .60596 .81742 L .6031 .81678 L F
.746 .521 .59 r
.48536 .84625 m .4884 .84674 L .4884 .84371 L F
.48536 .84625 m .4884 .84371 L .48758 .84606 L F
0 0 .345 r
.48881 .84048 m .4884 .84371 L .48801 .84156 L F
0 0 0 r
.48906 .84304 m .48758 .84606 L .4884 .84371 L F
.553 .38 .601 r
.68886 .72783 m .68646 .72966 L .68608 .72736 L F
.784 .447 .416 r
.59287 .80854 m .58935 .80683 L .59137 .80649 L F
.59287 .80854 m .58985 .80888 L .58935 .80683 L F
.654 .322 .398 r
.59194 .81062 m .58985 .80888 L .59287 .80854 L F
.497 .499 .788 r
.58985 .80888 m .59236 .80905 L .59095 .80532 L F
.59236 .80905 m .59299 .8091 L .59252 .80823 L F
.59236 .80905 m .59252 .80823 L .59095 .80532 L F
.654 .322 .398 r
.59188 .81155 m .59287 .80854 L .59187 .81178 L F
.59194 .81062 m .59215 .81017 L .59188 .81155 L F
.59215 .81017 m .59287 .80854 L .59188 .81155 L F
.594 .372 .55 r
.44951 .75614 m .44707 .75855 L .44744 .75662 L F
.565 .309 .486 r
.41775 .7638 m .42029 .76155 L .41834 .76208 L F
.288 0 .004 r
.37807 .79809 m .38158 .79596 L .37985 .79744 L F
.204 0 0 r
.38158 .79596 m .38177 .79685 L .37985 .79744 L F
.38158 .79596 m .38364 .79557 L .38177 .79685 L F
.683 .775 .294 r
.7202 .73005 m .71941 .7319 L .71947 .73182 L F
.516 .004 0 r
.47405 .86466 m .47548 .8651 L .4768 .86476 L F
.4 0 0 r
.47548 .8651 m .47875 .86511 L .4768 .86476 L F
.709 .348 .362 r
.71726 .72073 m .71914 .72099 L .71768 .7194 L F
.84 .61 .59 r
.58839 .78793 m .58873 .79 L .58989 .78804 L F
.772 .518 .55 r
.58873 .79 m .59141 .79017 L .58989 .78804 L F
.83 .549 .002 r
.48451 .87287 m .48542 .87672 L .4849 .87531 L F
0 0 0 r
.48542 .87672 m .48495 .87568 L .4849 .87531 L F
.48547 .87667 m .48694 .87526 L .48495 .87568 L F
.48542 .87672 m .48365 .87891 L .48694 .87526 L F
.502 .406 .679 r
.48818 .87335 m .48694 .87526 L .48627 .87329 L F
.622 .286 .38 r
.48818 .87335 m .48495 .87568 L .48694 .87526 L F
.48818 .87335 m .48719 .87629 L .48495 .87568 L F
.503 0 0 r
.48495 .87568 m .48642 .87608 L .48617 .87658 L F
.48642 .87608 m .48719 .87629 L .48617 .87658 L F
.815 .459 .384 r
.48617 .87658 m .48664 .87849 L .48495 .87845 L F
0 0 0 r
.48617 .87658 m .48495 .87845 L .4858 .87734 L F
.48989 .87428 m .49018 .87444 L .48719 .87629 L F
.49093 .8735 m .49018 .87444 L .48989 .87428 L F
.138 0 .101 r
.49057 .87467 m .49018 .87444 L .4904 .87333 L F
.4907 .87566 m .49018 .87444 L .49057 .87467 L F
.7 .44 .528 r
.49018 .87444 m .48617 .87658 L .48719 .87629 L F
.49018 .87444 m .48852 .87663 L .48617 .87658 L F
0 0 0 r
.48617 .87658 m .4858 .87734 L .48723 .87548 L F
.503 0 0 r
.48495 .87568 m .48617 .87658 L .48473 .87527 L F
.753 .281 0 r
.48396 .87457 m .4849 .87531 L .48495 .87568 L F
.503 0 0 r
.48495 .87568 m .48473 .87527 L .48396 .87457 L F
0 0 0 r
.48542 .87672 m .48547 .87667 L .48495 .87568 L F
.351 0 0 r
.50615 .8728 m .50747 .87346 L .50502 .87296 L F
.50615 .8728 m .50838 .87274 L .50747 .87346 L F
.605 .05 0 r
.56894 .78525 m .56569 .78281 L .56903 .7829 L F
.785 .603 .654 r
.65716 .73262 m .65423 .72995 L .65616 .72987 L F
.65716 .73262 m .654 .73234 L .65423 .72995 L F
.107 .65 .84 r
.65716 .73262 m .65666 .73241 L .654 .73234 L F
.841 .997 .767 r
.65802 .73074 m .65666 .73241 L .65716 .73262 L F
.561 .47 .709 r
.4538 .86226 m .4553 .8591 L .45349 .85948 L F
.692 .587 .733 r
.50608 .84871 m .50952 .84941 L .50807 .84792 L F
.765 .577 .644 r
.60287 .80115 m .605 .79859 L .60297 .79873 L F
.60287 .80115 m .60623 .80149 L .605 .79859 L F
.811 .964 .644 r
.48833 .86234 m .48658 .86464 L .48863 .86174 L F
.862 .794 .782 r
.48863 .86174 m .48658 .86464 L .48957 .86416 L F
.864 .737 .722 r
.48658 .86464 m .48778 .86741 L .48957 .86416 L F
.254 0 0 r
.36898 .72561 m .36839 .72612 L .37046 .72577 L F
.754 .803 .892 r
.67751 .71098 m .67985 .71056 L .67767 .71198 L F
.485 .312 .571 r
.50501 .85451 m .50643 .85668 L .50705 .85412 L F
.50501 .85451 m .50473 .85727 L .50643 .85668 L F
.142 .573 .928 r
.57022 .78836 m .56926 .78752 L .57079 .78806 L F
.57022 .78836 m .5706 .78784 L .56926 .78752 L F
.595 .195 .255 r
.57554 .78816 m .57423 .78992 L .57022 .78836 L F
.79 .395 .304 r
.57423 .78992 m .5706 .78784 L .57022 .78836 L F
.837 .483 .385 r
.37324 .89666 m .37183 .89794 L .37052 .89598 L F
.41 .57 .901 r
.3709 .8948 m .37281 .89675 L .37317 .89595 L F
.777 .959 .643 r
.37317 .89595 m .37279 .89679 L .37324 .89666 L F
.41 .57 .901 r
.37281 .89675 m .37289 .89684 L .37317 .89595 L F
.777 .959 .643 r
.37317 .89595 m .37256 .89686 L .37279 .89679 L F
.37256 .89686 m .37183 .89794 L .37324 .89666 L F
.455 0 0 r
.37278 .8968 m .37324 .89666 L .37289 .89684 L F
.37052 .89598 m .37324 .89666 L .37278 .8968 L F
.805 .906 .503 r
.37317 .89595 m .37324 .89666 L .37289 .89684 L F
.35 .5 .867 r
.32504 .66007 m .32427 .66202 L .32312 .66026 L F
.32504 .66007 m .32646 .66261 L .32427 .66202 L F
.304 .79 .895 r
.47465 .88199 m .47552 .88143 L .47373 .88198 L F
.47465 .88199 m .4767 .88162 L .47552 .88143 L F
.812 .549 .541 r
.50807 .84792 m .50624 .84686 L .50639 .846 L F
.50807 .84792 m .50462 .84877 L .50624 .84686 L F
.782 .6 .654 r
.50897 .84771 m .50681 .84835 L .50807 .84792 L F
0 0 0 r
.6908 .73525 m .69234 .73427 L .69298 .73263 L F
.25 .293 .712 r
.6908 .73525 m .69317 .73761 L .69234 .73427 L F
.232 0 0 r
.51556 .85711 m .51582 .85693 L .51679 .85716 L F
.416 .747 .994 r
.58235 .84638 m .57909 .84462 L .5778 .84493 L F
.58235 .84638 m .58257 .84622 L .57909 .84462 L F
.529 .706 .952 r
.48543 .87217 m .48627 .87329 L .48451 .87287 L F
.83 .549 .002 r
.48451 .87287 m .4849 .87531 L .48543 .87217 L F
.464 .067 .202 r
.38006 .78474 m .38356 .78261 L .38145 .78288 L F
.669 .692 .863 r
.32996 .66413 m .32789 .66525 L .32646 .66261 L F
.06 0 0 r
.52639 .82838 m .52726 .82866 L .52871 .8282 L F
.52639 .82838 m .52495 .82909 L .52726 .82866 L F
.204 0 .216 r
.39354 .77522 m .39449 .77622 L .3957 .77496 L F
.39354 .77522 m .3929 .77684 L .39449 .77622 L F
.302 .795 .866 r
.3469 .79612 m .34586 .79663 L .34443 .79691 L F
.3469 .79612 m .34804 .7962 L .34586 .79663 L F
.524 .394 .646 r
.45076 .87307 m .45273 .87282 L .45253 .87038 L F
.508 .491 .773 r
.45076 .87307 m .45352 .87506 L .45273 .87282 L F
.486 .266 .505 r
.34082 .76399 m .33862 .76663 L .3388 .76435 L F
.507 .221 .415 r
.40815 .78003 m .40758 .78265 L .4054 .78297 L F
.456 .188 .418 r
.41054 .77956 m .40758 .78265 L .40815 .78003 L F
.279 0 0 r
.47466 .84364 m .4734 .84386 L .47094 .84366 L F
.858 .981 .855 r
.47567 .84095 m .47466 .84364 L .47691 .84326 L F
.47567 .84095 m .4734 .84386 L .47466 .84364 L F
.72 .526 .628 r
.47466 .84364 m .47765 .84621 L .47691 .84326 L F
.47466 .84364 m .47476 .84641 L .47765 .84621 L F
.729 .764 .881 r
.3823 .8816 m .38484 .88342 L .38047 .88307 L F
.774 .662 .74 r
.38484 .88342 m .38168 .8863 L .38047 .88307 L F
0 .316 .656 r
.3823 .8816 m .3857 .883 L .38484 .88342 L F
.898 .544 .366 r
.54891 .82486 m .54974 .82747 L .55128 .82785 L F
.9 .553 .378 r
.54974 .82747 m .55031 .82946 L .55128 .82785 L F
.979 .707 .438 r
.55031 .82946 m .55142 .83017 L .55128 .82785 L F
.633 .173 .144 r
.56352 .78262 m .56248 .78318 L .56036 .78241 L F
.398 0 0 r
.56569 .78281 m .56248 .78318 L .56352 .78262 L F
.823 .484 .414 r
.57554 .78816 m .57626 .79031 L .57423 .78992 L F
.839 .492 .398 r
.57852 .79074 m .57626 .79031 L .57554 .78816 L F
.852 .397 .024 r
.52079 .86179 m .5212 .86387 L .51901 .86183 L F
.52079 .86179 m .52233 .86444 L .52151 .86423 L F
.5212 .86387 m .52121 .86391 L .52086 .86376 L F
.792 .613 .659 r
.52072 .86377 m .5217 .86576 L .52119 .8639 L F
.852 .397 .024 r
.52121 .86391 m .52126 .86417 L .52093 .86383 L F
.52121 .86391 m .52093 .86383 L .52086 .86376 L F
.792 .613 .659 r
.52119 .8639 m .5217 .86576 L .52148 .86424 L F
.991 .734 .404 r
.52126 .86417 m .52148 .86423 L .5217 .86576 L F
.52148 .86423 m .52233 .86444 L .5217 .86576 L F
.792 .613 .659 r
.52148 .86424 m .5217 .86576 L .52203 .86488 L F
.852 .397 .024 r
.5212 .86387 m .52086 .86376 L .51901 .86183 L F
.792 .613 .659 r
.52024 .8628 m .52072 .86377 L .52119 .8639 L F
.852 .397 .024 r
.5212 .86387 m .52151 .86423 L .52148 .86423 L F
.5212 .86387 m .52148 .86423 L .52121 .86391 L F
.792 .613 .659 r
.52039 .86292 m .52203 .86488 L .52218 .86448 L F
.52024 .8628 m .52203 .86488 L .52039 .86292 L F
.852 .397 .024 r
.52121 .86391 m .52148 .86423 L .52126 .86417 L F
.52079 .86179 m .52148 .86412 L .52119 .8638 L F
.743 .625 .729 r
.52024 .86275 m .52321 .86115 L .51995 .8609 L F
.52024 .8628 m .52027 .86278 L .52024 .86275 L F
.52027 .86278 m .52321 .86115 L .52024 .86275 L F
.852 .397 .024 r
.52119 .8638 m .52151 .86423 L .5212 .86387 L F
.52148 .86412 m .52151 .86423 L .52119 .8638 L F
.743 .625 .729 r
.52027 .86278 m .52167 .86404 L .52321 .86115 L F
.52024 .8628 m .52039 .86292 L .52027 .86278 L F
.52039 .86292 m .52167 .86404 L .52027 .86278 L F
.52167 .86404 m .52218 .86448 L .52225 .86424 L F
.52167 .86404 m .52225 .86424 L .52321 .86115 L F
.728 .396 .417 r
.57342 .78166 m .57649 .78029 L .57321 .77995 L F
.57342 .78166 m .57676 .78196 L .57649 .78029 L F
.57676 .78196 m .57845 .78273 L .57649 .78029 L F
.566 .15 .213 r
.37235 .7869 m .37601 .78535 L .37377 .78534 L F
.736 .526 .608 r
.58968 .79303 m .59313 .79082 L .59141 .79017 L F
.58968 .79303 m .59302 .79317 L .59313 .79082 L F
.476 .804 1 r
.4858 .88374 m .48915 .88416 L .48773 .88271 L F
.815 .6 .612 r
.57897 .79311 m .57626 .79031 L .57852 .79074 L F
.609 .553 .766 r
.70078 .73457 m .69889 .73648 L .6982 .73285 L F
.647 .578 .763 r
.70189 .73577 m .69889 .73648 L .70078 .73457 L F
.91 .906 .503 r
.63965 .63998 m .63864 .64147 L .63951 .63928 L F
.739 .658 .77 r
.64082 .63924 m .63965 .63998 L .63951 .63928 L F
.64082 .63924 m .63864 .64147 L .63965 .63998 L F
.625 .384 .532 r
.51762 .82997 m .52098 .82777 L .5175 .82757 L F
.51762 .82997 m .52005 .83032 L .52098 .82777 L F
.598 .356 .521 r
.52098 .82777 m .52005 .83032 L .5229 .82987 L F
0 0 0 r
.35549 .80867 m .35913 .80686 L .35744 .80809 L F
.076 0 0 r
.35744 .80809 m .35913 .80686 L .36101 .80633 L F
0 0 0 r
.66184 .71452 m .66024 .71602 L .66321 .71341 L F
.647 .222 .224 r
.52662 .84522 m .52426 .84372 L .52521 .84283 L F
.494 .581 .871 r
.33923 .6736 m .33899 .67632 L .33745 .67386 L F
.33923 .6736 m .34086 .67627 L .33899 .67632 L F
.882 .852 .808 r
.55259 .83825 m .55297 .84029 L .55385 .8387 L F
.62 .742 .934 r
.42858 .73347 m .42508 .73253 L .42722 .73231 L F
.585 .787 .976 r
.43042 .73286 m .42858 .73347 L .42722 .73231 L F
.709 .806 .925 r
.47637 .85619 m .47992 .85607 L .47898 .85381 L F
.562 .565 .814 r
.48765 .87064 m .48627 .87329 L .48543 .87217 L F
.48765 .87064 m .48927 .87286 L .48627 .87329 L F
.502 .406 .679 r
.48818 .87335 m .48627 .87329 L .48927 .87286 L F
.911 .93 .554 r
.70484 .74234 m .70394 .74566 L .70586 .74294 L F
.497 .203 .397 r
.43034 .76735 m .42986 .76908 L .42777 .76938 L F
.564 .296 .468 r
.43232 .767 m .42986 .76908 L .43034 .76735 L F
.984 .857 .633 r
.57726 .82813 m .57572 .82935 L .57497 .82733 L F
.57726 .82813 m .57656 .83043 L .57572 .82935 L F
.702 .361 .395 r
.37991 .75101 m .37661 .75104 L .37765 .75047 L F
.949 .865 .448 r
.69576 .75004 m .6958 .74912 L .69567 .74775 L F
.925 .606 .14 r
.69627 .74843 m .69567 .74775 L .69554 .74641 L F
.744 .658 .765 r
.69852 .74591 m .69627 .74843 L .69523 .74557 L F
.949 .865 .448 r
.6958 .74912 m .69593 .74648 L .69567 .74775 L F
.925 .606 .14 r
.69554 .74641 m .69567 .74775 L .69523 .74557 L F
.496 0 0 r
.54981 .80931 m .55176 .81006 L .55199 .80966 L F
0 .369 .731 r
.55028 .80937 m .55176 .81006 L .54981 .80931 L F
.177 0 0 r
.40658 .74334 m .40574 .74273 L .40782 .74242 L F
.40658 .74334 m .40416 .74384 L .40574 .74273 L F
.538 0 0 r
.70493 .72441 m .70852 .72588 L .70478 .72449 L F
.924 .724 .614 r
.64575 .63423 m .64692 .63715 L .64553 .63636 L F
.834 .694 .709 r
.64692 .63715 m .64383 .63895 L .64553 .63636 L F
.64692 .63715 m .64538 .63983 L .64383 .63895 L F
.396 .763 .993 r
.6406 .63209 m .64196 .63132 L .64299 .63225 L F
.717 .281 .213 r
.6406 .63209 m .64289 .63395 L .63959 .63331 L F
0 0 0 r
.63959 .63331 m .64196 .63132 L .6406 .63209 L F
.646 .095 0 r
.65981 .72212 m .6591 .72195 L .65794 .72094 L F
.944 .585 .207 r
.65981 .72212 m .66048 .72426 L .6591 .72195 L F
.728 .605 .719 r
.51376 .85951 m .51447 .86246 L .51154 .86206 L F
0 0 .444 r
.51458 .86185 m .51447 .86246 L .51376 .85951 L F
.977 .683 .391 r
.5139 .86425 m .51447 .86246 L .51458 .86185 L F
.5139 .86425 m .51493 .86465 L .51447 .86246 L F
.653 .86 .978 r
.68178 .69772 m .68282 .69857 L .6849 .69771 L F
.517 .453 .723 r
.34685 .67973 m .34508 .68007 L .34416 .67863 L F
.34685 .67973 m .34743 .68158 L .34508 .68007 L F
.673 .619 .786 r
.65061 .72972 m .64885 .73254 L .64787 .72961 L F
.54 .446 .697 r
.65061 .72972 m .65095 .73246 L .64885 .73254 L F
.883 .837 .796 r
.68387 .69656 m .68675 .69505 L .68653 .69487 L F
0 0 .114 r
.685 .69393 m .68575 .69421 L .68675 .69505 L F
.883 .837 .796 r
.68464 .6956 m .68653 .69487 L .68575 .69421 L F
.68387 .69656 m .68653 .69487 L .68464 .6956 L F
.656 .25 .263 r
.68164 .69384 m .6845 .69561 L .685 .69393 L F
.6845 .69561 m .68455 .69561 L .685 .69393 L F
.68454 .69563 m .68477 .69555 L .685 .69393 L F
0 0 .114 r
.685 .69393 m .68474 .69576 L .68575 .69421 L F
.788 .73 .799 r
.68277 .69413 m .68412 .69528 L .68575 .69421 L F
0 .305 .77 r
.68277 .69413 m .6845 .69561 L .68164 .69384 L F
.788 .73 .799 r
.68348 .6957 m .68464 .6956 L .68575 .69421 L F
.68348 .6957 m .68387 .69656 L .68464 .6956 L F
.656 .25 .263 r
.6845 .69561 m .68454 .69563 L .68455 .69561 L F
0 .305 .77 r
.68277 .69413 m .68474 .69576 L .6845 .69561 L F
.788 .73 .799 r
.68277 .69413 m .68348 .6957 L .68412 .69528 L F
.656 .25 .263 r
.68454 .69563 m .68474 .69576 L .68477 .69555 L F
0 .487 .851 r
.47428 .8643 m .47548 .8651 L .47405 .86466 L F
.552 .698 .937 r
.31641 .65738 m .31579 .65927 L .31441 .65787 L F
.31641 .65738 m .31787 .65903 L .31579 .65927 L F
.616 .54 .746 r
.42728 .75368 m .42953 .75341 L .42914 .75046 L F
.516 .307 .535 r
.42731 .75602 m .42953 .75341 L .42728 .75368 L F
.129 .677 .782 r
.38971 .74483 m .3882 .74483 L .38618 .74502 L F
.286 .785 .857 r
.39024 .74442 m .38971 .74483 L .39172 .74469 L F
.39024 .74442 m .3882 .74483 L .38971 .74483 L F
.87 .738 .715 r
.6047 .81199 m .60531 .8095 L .60377 .80869 L F
.632 .196 0 r
.54693 .82193 m .54857 .82446 L .54891 .82486 L F
.933 .554 .207 r
.5486 .82672 m .54891 .82486 L .54857 .82446 L F
.5486 .82672 m .54974 .82747 L .54891 .82486 L F
.702 .425 .502 r
.49286 .83836 m .49272 .84087 L .49438 .84085 L F
.822 .444 .338 r
.49286 .83836 m .49438 .84085 L .4961 .84088 L F
.481 .268 .512 r
.46353 .74495 m .46313 .7475 L .46145 .74535 L F
.46353 .74495 m .46313 .7475 L .46145 .74535 L F
.447 .69 .969 r
.45742 .87892 m .45821 .87771 L .45628 .87812 L F
.45742 .87892 m .45955 .87901 L .45821 .87771 L F
.728 .527 .619 r
.65173 .71339 m .65734 .7112 L .65161 .71084 L F
.65173 .71339 m .65568 .71443 L .65734 .7112 L F
.133 0 .251 r
.65734 .7112 m .65568 .71443 L .65701 .71295 L F
.65734 .7112 m .65701 .71295 L .65694 .71066 L F
.67 .826 .396 r
.65701 .71295 m .65796 .71139 L .65694 .71066 L F
.65701 .71295 m .65625 .71448 L .65796 .71139 L F
.898 .898 .818 r
.65694 .71066 m .65796 .71139 L .65992 .70842 L F
.424 .234 .516 r
.50725 .84073 m .50923 .83809 L .50581 .83684 L F
.708 .903 .965 r
.69668 .7533 m .69768 .754 L .6994 .75289 L F
.578 .484 .712 r
.6655 .62372 m .66631 .62617 L .66328 .62556 L F
0 0 .285 r
.6655 .62372 m .66679 .62273 L .66773 .62285 L F
.486 .43 .719 r
.66796 .62517 m .6655 .62372 L .66773 .62285 L F
.66796 .62517 m .66631 .62617 L .6655 .62372 L F
0 0 .285 r
.6655 .62372 m .66533 .62492 L .66679 .62273 L F
.437 .423 .746 r
.66631 .62617 m .66391 .62664 L .66459 .62582 L F
0 0 .285 r
.66533 .62492 m .66512 .62647 L .66638 .62365 L F
.66533 .62492 m .66638 .62365 L .66679 .62273 L F
.437 .423 .746 r
.66631 .62617 m .66424 .6272 L .66391 .62664 L F
.66459 .62582 m .66391 .62664 L .66328 .62556 L F
.66631 .62617 m .66666 .62865 L .66424 .6272 L F
.781 .648 .715 r
.58312 .80096 m .58434 .80404 L .58118 .80368 L F
.739 .461 .508 r
.58434 .80404 m .58122 .80579 L .58118 .80368 L F
.58434 .80404 m .58495 .80661 L .58122 .80579 L F
.588 .399 .593 r
.45887 .84655 m .46066 .84852 L .46086 .84574 L F
.45887 .84655 m .45869 .84884 L .46066 .84852 L F
.761 .671 .763 r
.5287 .85399 m .52986 .85692 L .52662 .85693 L F
.454 0 0 r
.52662 .85693 m .52986 .85692 L .52918 .85771 L F
.241 .365 .79 r
.53108 .85627 m .52986 .85692 L .5287 .85399 L F
0 0 0 r
.52918 .85771 m .52986 .85692 L .53108 .85627 L F
.369 0 .026 r
.34639 .76149 m .34287 .76323 L .34336 .76216 L F
.34639 .76149 m .34502 .76305 L .34287 .76323 L F
.603 .223 .296 r
.34848 .76135 m .34502 .76305 L .34639 .76149 L F
.927 .755 .65 r
.58341 .81658 m .58497 .81742 L .58415 .82014 L F
.752 .681 .782 r
.58368 .81427 m .58497 .81742 L .58341 .81658 L F
.58368 .81427 m .58692 .81556 L .58497 .81742 L F
.648 .343 .441 r
.64838 .64263 m .64511 .64467 L .64516 .64215 L F
.64838 .64263 m .64838 .64421 L .64511 .64467 L F
.453 .168 .389 r
.65063 .64219 m .64838 .64421 L .64838 .64263 L F
.494 .188 .376 r
.51653 .83554 m .51861 .83548 L .5195 .83326 L F
.361 .444 .811 r
.51762 .82997 m .5195 .83326 L .52072 .83246 L F
.445 .14 .352 r
.5195 .83326 m .52067 .83502 L .52072 .83246 L F
.5195 .83326 m .51861 .83548 L .52067 .83502 L F
.4 0 0 r
.47548 .8651 m .47735 .86569 L .47875 .86511 L F
0 .162 .697 r
.48025 .86589 m .48091 .86713 L .47875 .86511 L F
.48025 .86589 m .47875 .86511 L .47735 .86569 L F
.864 .809 .794 r
.64596 .63194 m .64535 .62929 L .64665 .62832 L F
.725 .729 .853 r
.64412 .63084 m .64535 .62929 L .64541 .62954 L F
.482 .248 .482 r
.64422 .63069 m .64665 .62832 L .64535 .62929 L F
.64422 .63069 m .64701 .62792 L .64681 .62814 L F
.64599 .62897 m .64681 .62814 L .64665 .62832 L F
.64422 .63069 m .64681 .62814 L .64599 .62897 L F
.725 .729 .853 r
.64299 .63225 m .64412 .63084 L .64596 .63194 L F
.64412 .63084 m .64541 .62954 L .64596 .63194 L F
.79 .578 .615 r
.64596 .63194 m .64575 .63423 L .64289 .63395 L F
.864 .809 .794 r
.64596 .63194 m .64665 .62832 L .64814 .62935 L F
.633 .352 .475 r
.58935 .80683 m .58985 .80888 L .58782 .80855 L F
.836 .788 .806 r
.69216 .7415 m .68979 .74475 L .68874 .74271 L F
.888 .507 .307 r
.55425 .81722 m .55281 .81703 L .55142 .81405 L F
0 .239 .702 r
.55489 .81864 m .55281 .81703 L .55425 .81722 L F
.81 .418 .309 r
.69298 .73263 m .69234 .73427 L .69165 .73279 L F
.836 .945 .893 r
.69298 .73263 m .69432 .72988 L .69494 .73187 L F
.69298 .73263 m .69165 .73279 L .69432 .72988 L F
.611 .888 .99 r
.59021 .84608 m .59079 .8456 L .58801 .84574 L F
.703 .786 .916 r
.52281 .81461 m .5264 .8152 L .52468 .81403 L F
.568 .744 .96 r
.5264 .8152 m .5284 .81451 L .52468 .81403 L F
.609 .394 .564 r
.41538 .76588 m .41775 .7638 L .41588 .76431 L F
.517 .322 .555 r
.38618 .74502 m .3859 .74774 L .38416 .7454 L F
.597 .859 .993 r
.59258 .84575 m .59365 .84645 L .59563 .84579 L F
.96 .624 .306 r
.49962 .86159 m .50066 .8622 L .49944 .85974 L F
.541 .372 .601 r
.64744 .7141 m .6497 .71396 L .64954 .71121 L F
.707 .304 .282 r
.55176 .81006 m .55474 .80969 L .55199 .80966 L F
.55176 .81006 m .55526 .81047 L .55474 .80969 L F
.656 .262 .288 r
.55526 .81047 m .55726 .81142 L .55474 .80969 L F
.621 .544 .746 r
.5807 .82729 m .58162 .8303 L .57885 .83069 L F
.606 .454 .649 r
.57885 .83069 m .57939 .8329 L .58162 .8303 L F
.57885 .83069 m .57939 .8329 L .58162 .8303 L F
.541 .313 .518 r
.43743 .7638 m .43497 .76586 L .43523 .76413 L F
.786 .62 .675 r
.58179 .79537 m .57897 .79311 L .58211 .7934 L F
.829 .644 .651 r
.58327 .79869 m .5806 .79852 L .58179 .79537 L F
.808 .649 .685 r
.58312 .80096 m .5806 .79852 L .58327 .79869 L F
.561 .47 .709 r
.4538 .86226 m .45582 .86202 L .4553 .8591 L F
.633 .434 .596 r
.4538 .86226 m .45618 .86446 L .45582 .86202 L F
.4538 .86226 m .45385 .86467 L .45618 .86446 L F
.798 .719 .777 r
.57052 .81941 m .5684 .82206 L .57193 .82203 L F
.632 .446 .613 r
.5684 .82206 m .57111 .82416 L .57193 .82203 L F
.606 .527 .739 r
.43918 .73494 m .43734 .73714 L .43711 .73561 L F
.43918 .73494 m .44021 .73768 L .43734 .73714 L F
.509 .378 .638 r
.44021 .73768 m .43817 .74059 L .43734 .73714 L F
.216 0 .006 r
.34611 .73523 m .34661 .73642 L .348 .73462 L F
.34611 .73523 m .34478 .73697 L .34661 .73642 L F
.091 .614 .879 r
.52087 .84926 m .51985 .84942 L .51857 .84923 L F
.262 0 0 r
.32996 .66413 m .33153 .66426 L .33343 .66373 L F
.756 .662 .757 r
.3319 .66059 m .33343 .66373 L .33528 .661 L F
0 0 .522 r
.33342 .66343 m .33343 .66373 L .33153 .66426 L F
.33342 .66343 m .33495 .66553 L .33343 .66373 L F
.442 .271 .552 r
.33343 .66373 m .33495 .66553 L .33324 .66584 L F
.506 .154 .304 r
.46254 .8433 m .46494 .84302 L .46571 .84112 L F
.496 .144 .299 r
.46571 .84112 m .46774 .84191 L .46787 .84091 L F
.361 .187 .506 r
.40578 .7668 m .40698 .76885 L .40702 .76637 L F
.40578 .7668 m .40553 .76957 L .40698 .76885 L F
.571 .5 .736 r
.70998 .7295 m .70797 .73004 L .70921 .72778 L F
.828 .784 .81 r
.70921 .72778 m .70725 .7298 L .70613 .72788 L F
.017 .559 .84 r
.70524 .72958 m .70711 .72984 L .70629 .72995 L F
.70711 .72984 m .7072 .72986 L .70629 .72995 L F
.7072 .72986 m .70733 .72989 L .70731 .72989 L F
.7072 .72986 m .70731 .72989 L .70629 .72995 L F
.828 .784 .81 r
.70725 .7298 m .7072 .72986 L .70613 .7279 L F
.285 .357 .762 r
.70822 .73145 m .70629 .72995 L .70731 .72989 L F
.822 .957 .902 r
.70603 .73207 m .70709 .73043 L .70524 .72958 L F
.828 .784 .81 r
.7072 .72986 m .70714 .72993 L .70715 .72984 L F
.285 .357 .762 r
.70834 .73154 m .70822 .73145 L .70733 .72989 L F
.70822 .73145 m .70731 .72989 L .70733 .72989 L F
.70834 .73154 m .70733 .72989 L .70755 .73016 L F
.571 .5 .736 r
.70998 .7295 m .70834 .73154 L .70755 .73016 L F
.285 .357 .762 r
.70834 .73154 m .70755 .73016 L .70765 .73027 L F
.571 .5 .736 r
.70755 .73016 m .70834 .73154 L .70729 .73023 L F
.822 .957 .902 r
.70748 .73046 m .70834 .73154 L .70765 .73027 L F
.70603 .73207 m .70834 .73154 L .70748 .73046 L F
.70603 .73207 m .70765 .73027 L .70723 .73022 L F
.571 .5 .736 r
.70729 .73023 m .70834 .73154 L .70669 .73039 L F
.70755 .73016 m .70729 .73023 L .70733 .72989 L F
.70797 .73004 m .70755 .73016 L .70733 .72989 L F
.285 .357 .762 r
.70765 .73027 m .70733 .72989 L .70744 .72988 L F
.822 .957 .902 r
.70723 .73022 m .70765 .73027 L .70744 .72988 L F
.571 .5 .736 r
.70729 .73023 m .70723 .73024 L .70724 .73022 L F
.70729 .73023 m .70724 .73022 L .70733 .72989 L F
.822 .957 .902 r
.70709 .73043 m .70723 .73022 L .70714 .72993 L F
.70709 .73043 m .70714 .72993 L .70524 .72958 L F
.70714 .72993 m .70715 .72984 L .70711 .72984 L F
.70714 .72993 m .70711 .72984 L .70524 .72958 L F
.571 .5 .736 r
.70733 .72989 m .70717 .73002 L .7072 .72986 L F
.70717 .73002 m .70669 .73039 L .70714 .72993 L F
.70717 .73002 m .70714 .72993 L .7072 .72986 L F
.70723 .73024 m .70669 .73039 L .70717 .73002 L F
.70723 .73024 m .70717 .73002 L .70733 .72989 L F
.70797 .73004 m .7072 .72986 L .70921 .72778 L F
.017 .559 .84 r
.70711 .72984 m .70744 .72988 L .70733 .72989 L F
.822 .957 .902 r
.70714 .72993 m .70744 .72988 L .70715 .72984 L F
.70723 .73022 m .70744 .72988 L .70714 .72993 L F
.828 .784 .81 r
.70715 .72984 m .70669 .73039 L .70653 .72966 L F
.70714 .72993 m .70669 .73039 L .70715 .72984 L F
.7072 .72986 m .70653 .72966 L .70613 .7279 L F
.70725 .7298 m .70613 .7279 L .70613 .72788 L F
.701 .28 .245 r
.58201 .78291 m .58397 .78462 L .58513 .78329 L F
.783 .389 .308 r
.58513 .78329 m .58397 .78462 L .58572 .78473 L F
.662 .783 .939 r
.68426 .71944 m .68747 .72001 L .68634 .71865 L F
.678 .776 .924 r
.68426 .71944 m .68747 .72001 L .68634 .71865 L F
.796 .811 .864 r
.68974 .71701 m .68747 .72001 L .68634 .71865 L F
.636 .762 .939 r
.68634 .71865 m .68747 .72001 L .6895 .7193 L F
.644 .576 .763 r
.68747 .72001 m .69062 .72211 L .6895 .7193 L F
0 0 0 r
.52363 .83772 m .52273 .83824 L .52516 .83565 L F
.246 .754 .729 r
.5272 .83503 m .52629 .83524 L .52516 .83565 L F
0 0 0 r
.52629 .83524 m .52363 .83772 L .52516 .83565 L F
.991 .742 .447 r
.47463 .87723 m .47555 .87533 L .47303 .87452 L F
.47463 .87723 m .47559 .87803 L .47555 .87533 L F
.741 .551 .636 r
.59627 .79824 m .59962 .79611 L .5963 .79588 L F
.59627 .79824 m .59956 .79853 L .59962 .79611 L F
.774 .764 .844 r
.55866 .80164 m .55624 .80374 L .55935 .80379 L F
.152 0 .157 r
.35779 .75544 m .35617 .75639 L .35836 .75408 L F
.414 .042 .221 r
.36013 .75403 m .35779 .75544 L .35836 .75408 L F
.876 .741 .71 r
.4965 .88649 m .49864 .88695 L .4977 .88896 L F
.792 .846 .892 r
.49946 .88555 m .49864 .88695 L .4965 .88649 L F
.702 .447 .536 r
.49864 .88695 m .50096 .88802 L .4977 .88896 L F
.41 .079 .29 r
.66059 .63486 m .66017 .63625 L .65794 .63682 L F
.507 .2 .38 r
.66257 .63452 m .66017 .63625 L .66059 .63486 L F
.18 0 0 r
.37991 .75101 m .37898 .75119 L .37661 .75104 L F
.262 .579 .943 r
.37991 .75101 m .38051 .7501 L .37898 .75119 L F
.37991 .75101 m .38213 .75179 L .38051 .7501 L F
.806 .45 .382 r
.47696 .83987 m .47851 .83861 L .47734 .83764 L F
.47696 .83987 m .47914 .84073 L .47851 .83861 L F
.864 .902 .859 r
.47734 .83764 m .47851 .83861 L .48077 .8357 L F
.489 .267 .504 r
.47851 .83861 m .47914 .84073 L .48078 .8401 L F
.661 .526 .688 r
.68848 .72469 m .69084 .7245 L .69062 .72211 L F
.581 .63 .865 r
.68848 .72469 m .69205 .72636 L .69084 .7245 L F
.87 .738 .715 r
.6047 .81199 m .60377 .80869 L .60241 .81161 L F
.826 .591 .584 r
.60189 .81378 m .6047 .81199 L .60241 .81161 L F
.60189 .81378 m .60488 .81368 L .6047 .81199 L F
.56 .478 .72 r
.63923 .72807 m .64084 .72402 L .63875 .72386 L F
.63923 .72807 m .64331 .72845 L .64084 .72402 L F
.568 .375 .58 r
.64121 .72903 m .63923 .72807 L .63979 .7298 L F
.64121 .72903 m .64331 .72845 L .63923 .72807 L F
.525 .107 .189 r
.55514 .78336 m .55496 .78395 L .55251 .784 L F
.577 .155 .205 r
.55514 .78336 m .55693 .78452 L .55496 .78395 L F
.487 .241 .466 r
.55697 .78268 m .55693 .78452 L .55514 .78336 L F
0 0 0 r
.56429 .83834 m .56216 .84101 L .56312 .84034 L F
.24 .577 .943 r
.56216 .84101 m .56398 .8413 L .56312 .84034 L F
.541 .304 .504 r
.5438 .83546 m .54148 .83764 L .54211 .83627 L F
0 0 0 r
.36116 .79113 m .36138 .79185 L .36289 .79031 L F
.36116 .79113 m .35959 .7927 L .36138 .79185 L F
0 .571 .769 r
.63764 .72367 m .64084 .72402 L .63875 .72386 L F
.63764 .72367 m .64084 .72402 L .63875 .72386 L F
.957 .793 .638 r
.60372 .82444 m .60506 .82515 L .60422 .82206 L F
.967 .72 .51 r
.60499 .82743 m .60506 .82515 L .60372 .82444 L F
.85 .475 .342 r
.48593 .88303 m .48611 .88078 L .48459 .88033 L F
.48593 .88303 m .48773 .88271 L .48611 .88078 L F
.781 .586 .637 r
.59309 .79565 m .59652 .79351 L .59302 .79317 L F
.59309 .79565 m .5963 .79588 L .59652 .79351 L F
.876 .733 .701 r
.699 .74233 m .69744 .74446 L .69869 .74213 L F
.699 .74233 m .69852 .74591 L .69744 .74446 L F
.643 .834 .974 r
.57094 .84769 m .5719 .84839 L .57399 .84756 L F
.509 .378 .638 r
.44021 .73768 m .44007 .74026 L .43817 .74059 L F
.522 .438 .701 r
.44007 .74026 m .44058 .74232 L .43817 .74059 L F
.496 .441 .725 r
.44058 .74232 m .43883 .7428 L .43817 .74059 L F
.453 0 0 r
.49438 .84085 m .49863 .84289 L .4961 .84088 L F
.182 .424 .858 r
.32193 .65837 m .32114 .6592 L .31986 .65855 L F
.32193 .65837 m .32312 .66026 L .32114 .6592 L F
.44 .094 .281 r
.40352 .78338 m .40287 .78469 L .40082 .78502 L F
.454 .124 .316 r
.4054 .78297 m .40287 .78469 L .40352 .78338 L F
.316 .384 .774 r
.55166 .78022 m .55325 .78177 L .55367 .77962 L F
.679 .554 .706 r
.66051 .73737 m .66411 .73853 L .66299 .7346 L F
.518 .647 .914 r
.69263 .71928 m .68974 .71701 L .69164 .71627 L F
.244 .321 .745 r
.69164 .71627 m .69412 .71861 L .69254 .719 L F
.737 .239 .049 r
.69179 .71906 m .69412 .71861 L .69164 .71627 L F
.181 .711 .719 r
.69508 .71837 m .69412 .71861 L .69179 .71906 L F
.69621 .71813 m .69412 .71861 L .69508 .71837 L F
.244 .321 .745 r
.69254 .719 m .69412 .71861 L .69263 .71928 L F
.348 .825 .83 r
.69263 .71928 m .69412 .71861 L .69179 .71933 L F
.033 0 0 r
.37046 .72577 m .37249 .7255 L .37418 .72496 L F
.187 0 0 r
.37249 .7255 m .37617 .72431 L .37418 .72496 L F
.406 .153 .415 r
.51007 .86946 m .51001 .86756 L .51214 .86752 L F
.719 .7 .831 r
.50646 .87882 m .50825 .88137 L .5042 .88046 L F
.762 .415 .397 r
.5042 .88046 m .50825 .88137 L .50652 .88328 L F
.592 .653 .879 r
.50941 .88042 m .50825 .88137 L .50646 .87882 L F
0 0 0 r
.50786 .88195 m .50825 .88137 L .50941 .88042 L F
.552 .913 .724 r
.50646 .87882 m .5042 .88046 L .5062 .87889 L F
0 0 0 r
.5084 .88245 m .50758 .88335 L .50941 .88042 L F
.50652 .88328 m .50941 .88042 L .5084 .88245 L F
.549 .449 .693 r
.5062 .87889 m .50807 .88192 L .50693 .87955 L F
.50807 .88192 m .5084 .88245 L .50813 .88192 L F
.50807 .88192 m .50813 .88192 L .50693 .87955 L F
0 0 0 r
.50652 .88328 m .5077 .88198 L .50786 .88195 L F
.5077 .88198 m .50825 .88137 L .50786 .88195 L F
.655 .876 .981 r
.50532 .88373 m .50235 .88387 L .50443 .88221 L F
.278 .778 .87 r
.50652 .88328 m .50532 .88373 L .50443 .88221 L F
.50652 .88328 m .50758 .88335 L .50532 .88373 L F
.77 .595 .661 r
.49787 .87315 m .49651 .87054 L .49636 .87229 L F
0 0 .444 r
.51458 .86185 m .51376 .85951 L .51597 .85976 L F
.828 .646 .656 r
.5599 .81627 m .56185 .81914 L .55968 .81743 L F
.911 .93 .554 r
.70484 .74234 m .70347 .74567 L .70394 .74566 L F
.385 .057 .282 r
.39206 .79229 m .39133 .79018 L .39329 .79036 L F
.39206 .79229 m .39012 .79284 L .39133 .79018 L F
.537 0 0 r
.47784 .88223 m .47998 .88396 L .47881 .88314 L F
.166 .676 .9 r
.47998 .88396 m .48175 .8836 L .47881 .88314 L F
.47998 .88396 m .4827 .88409 L .48175 .8836 L F
0 0 0 r
.52907 .84334 m .53051 .84183 L .53174 .84098 L F
.695 .527 .656 r
.53174 .84098 m .53202 .84376 L .52907 .84334 L F
0 0 .055 r
.53227 .84001 m .53311 .83943 L .53315 .83839 L F
.686 .223 .146 r
.53315 .83839 m .53309 .83988 L .53173 .83933 L F
.313 .775 .945 r
.5318 .83928 m .53573 .83918 L .53315 .83839 L F
.53173 .83933 m .53216 .83931 L .5318 .83928 L F
.53216 .83931 m .53573 .83918 L .5318 .83928 L F
.553 .213 .346 r
.5393 .83814 m .53559 .84187 L .53694 .84143 L F
.283 .053 .378 r
.53587 .84277 m .53392 .8454 L .53467 .84373 L F
.517 .336 .575 r
.53587 .84277 m .53587 .84543 L .53392 .8454 L F
.439 .278 .565 r
.53392 .8454 m .53202 .84376 L .53467 .84373 L F
.872 .861 .826 r
.53366 .84428 m .53392 .8454 L .53435 .84483 L F
.53366 .84428 m .53435 .84483 L .53587 .84277 L F
.313 .775 .945 r
.53335 .83927 m .53377 .83909 L .53573 .83918 L F
0 0 0 r
.52907 .84334 m .52906 .84342 L .53051 .84183 L F
.774 .829 .896 r
.53051 .84183 m .52906 .84342 L .52968 .84212 L F
.655 .522 .689 r
.53202 .84376 m .52974 .8441 L .52907 .84334 L F
.53202 .84376 m .5303 .84744 L .52974 .8441 L F
.439 .278 .565 r
.53392 .8454 m .5303 .84744 L .53202 .84376 L F
.67 .487 .629 r
.52968 .84212 m .5307 .84532 L .53366 .84428 L F
.52968 .84212 m .53366 .84428 L .53321 .84407 L F
.665 .596 .768 r
.53321 .84407 m .53413 .84411 L .53377 .83909 L F
.872 .861 .826 r
.53366 .84428 m .5343 .84384 L .53478 .84384 L F
.53366 .84428 m .53478 .84384 L .5342 .84412 L F
.5343 .84384 m .53587 .84277 L .53538 .84349 L F
.5343 .84384 m .53538 .84349 L .53515 .84383 L F
.517 .336 .575 r
.53587 .84277 m .53587 .84543 L .53392 .8454 L F
.665 .596 .768 r
.53413 .84415 m .53572 .84338 L .53377 .83909 L F
.52 .75 .979 r
.53515 .84383 m .53338 .84405 L .53341 .84408 L F
.5342 .84412 m .53341 .84408 L .53366 .84428 L F
.573 .381 .582 r
.53819 .84474 m .53587 .84543 L .53587 .84277 L F
.53819 .84474 m .53587 .84543 L .53587 .84277 L F
.665 .596 .768 r
.53413 .84415 m .53615 .84432 L .53572 .84338 L F
.872 .861 .826 r
.5342 .84412 m .53478 .84384 L .53515 .84383 L F
.52 .75 .979 r
.53515 .84383 m .53341 .84408 L .5342 .84412 L F
.665 .596 .768 r
.53321 .84407 m .53413 .84415 L .53413 .84411 L F
.596 .376 .553 r
.53806 .84261 m .53814 .84392 L .53587 .84277 L F
.53814 .84392 m .53819 .84474 L .53745 .84412 L F
.53814 .84392 m .53745 .84412 L .53587 .84277 L F
.07 .55 .897 r
.54142 .84332 m .54072 .84326 L .54238 .84352 L F
.28 0 0 r
.54238 .84352 m .54072 .84326 L .53996 .84353 L F
.54238 .84352 m .53996 .84353 L .54086 .8432 L F
.54238 .84352 m .54086 .8432 L .54361 .8422 L F
.07 .55 .897 r
.54198 .84336 m .54142 .84332 L .54238 .84352 L F
.498 .204 .397 r
.54116 .83997 m .54015 .84296 L .53816 .84252 L F
.702 .409 .477 r
.54361 .8422 m .54086 .8432 L .54116 .83997 L F
.07 .55 .897 r
.54036 .84303 m .54072 .84326 L .54114 .8433 L F
.615 .391 .553 r
.54072 .84326 m .53819 .84474 L .53806 .84261 L F
.54072 .84326 m .53806 .84261 L .53943 .84327 L F
.752 .677 .779 r
.54045 .84327 m .54072 .84326 L .54064 .84321 L F
.54035 .84329 m .54072 .84326 L .54045 .84327 L F
.53697 .84358 m .53819 .84474 L .54072 .84326 L F
.615 .391 .553 r
.54072 .84326 m .53943 .84327 L .53996 .84353 L F
.752 .677 .779 r
.54035 .84329 m .54064 .84321 L .54036 .84303 L F
.702 .409 .477 r
.54036 .84303 m .54012 .84305 L .54015 .84296 L F
.752 .677 .779 r
.54008 .84305 m .54036 .84303 L .53913 .84222 L F
.54035 .84329 m .54036 .84303 L .54008 .84305 L F
.702 .409 .477 r
.54086 .8432 m .53996 .84353 L .54012 .84305 L F
.54086 .8432 m .54012 .84305 L .54036 .84303 L F
.54086 .8432 m .54015 .84296 L .54116 .83997 L F
.07 .55 .897 r
.5403 .84299 m .54036 .84303 L .54198 .84336 L F
.54036 .84303 m .54114 .8433 L .54198 .84336 L F
.53913 .84222 m .5403 .84299 L .54198 .84336 L F
.498 .204 .397 r
.53816 .84252 m .54012 .84305 L .53806 .84261 L F
.54015 .84296 m .54012 .84305 L .53816 .84252 L F
.752 .677 .779 r
.53901 .84341 m .54035 .84329 L .54009 .84306 L F
.498 .204 .397 r
.54012 .84305 m .53996 .84353 L .53943 .84327 L F
.54012 .84305 m .53943 .84327 L .53806 .84261 L F
.752 .677 .779 r
.53697 .84358 m .53901 .84341 L .53913 .84222 L F
.53901 .84341 m .54009 .84306 L .53913 .84222 L F
.509 .515 .798 r
.53717 .84291 m .5366 .84371 L .53747 .84325 L F
.635 .768 .943 r
.53747 .84325 m .53693 .84353 L .53697 .84358 L F
0 .125 .626 r
.53587 .84277 m .53742 .84409 L .53697 .84358 L F
.509 .515 .798 r
.5366 .84371 m .53615 .84432 L .53747 .84325 L F
.635 .768 .943 r
.53747 .84325 m .53682 .84342 L .53693 .84353 L F
0 .125 .626 r
.53587 .84277 m .53697 .84358 L .53679 .84361 L F
.53587 .84277 m .53679 .84361 L .53538 .84349 L F
.509 .515 .798 r
.53396 .83949 m .53615 .84432 L .53415 .83951 L F
0 .125 .626 r
.53538 .84349 m .53679 .84361 L .53515 .84383 L F
.509 .515 .798 r
.53576 .84337 m .53582 .84353 L .53717 .84291 L F
.53582 .84353 m .53602 .844 L .53646 .84358 L F
.53582 .84353 m .53646 .84358 L .53717 .84291 L F
.53602 .844 m .53615 .84432 L .5366 .84371 L F
.53602 .844 m .5366 .84371 L .53717 .84291 L F
.635 .768 .943 r
.53682 .84342 m .53515 .84383 L .53679 .84361 L F
.53693 .84353 m .53679 .84361 L .53697 .84358 L F
.53682 .84342 m .53679 .84361 L .53693 .84353 L F
0 .125 .626 r
.53742 .84409 m .53781 .84442 L .53697 .84358 L F
.53781 .84442 m .53819 .84474 L .53721 .84381 L F
.53781 .84442 m .53721 .84381 L .53697 .84358 L F
.635 .768 .943 r
.53682 .84342 m .53615 .84432 L .53515 .84383 L F
.53747 .84325 m .53702 .84362 L .53682 .84342 L F
.53702 .84362 m .53615 .84432 L .53682 .84342 L F
.616 .622 .834 r
.53559 .84187 m .53806 .84261 L .53587 .84277 L F
.509 .515 .798 r
.53415 .83951 m .53576 .84337 L .53717 .84291 L F
.52 .75 .979 r
.53338 .84405 m .53321 .84407 L .53366 .84428 L F
.509 .515 .798 r
.53377 .83909 m .53396 .83949 L .53415 .83951 L F
.313 .775 .945 r
.53173 .83933 m .53358 .83911 L .53335 .83927 L F
.53358 .83911 m .53377 .83909 L .53335 .83927 L F
0 0 .055 r
.53174 .84098 m .53309 .83988 L .53311 .83943 L F
.53174 .84098 m .53311 .83943 L .53227 .84001 L F
.452 .833 .6 r
.53174 .84098 m .53051 .84183 L .53309 .83988 L F
.185 .102 .522 r
.66294 .71135 m .66499 .71204 L .66561 .71109 L F
.66294 .71135 m .66321 .71341 L .66499 .71204 L F
.762 .623 .705 r
.60579 .80376 m .60623 .80149 L .60287 .80115 L F
.534 .418 .667 r
.45208 .86741 m .45385 .86467 L .45161 .86509 L F
.45208 .86741 m .45412 .86707 L .45385 .86467 L F
.484 .392 .676 r
.45208 .86741 m .45436 .86983 L .45412 .86707 L F
.45208 .86741 m .45253 .87038 L .45436 .86983 L F
.726 .34 .319 r
.66105 .61275 m .65777 .61277 L .65994 .61188 L F
.66105 .61275 m .65928 .61344 L .65777 .61277 L F
.478 .807 1 r
.66105 .61275 m .65994 .61188 L .66205 .61152 L F
.954 .834 .687 r
.70099 .75005 m .70364 .74647 L .70279 .74721 L F
.70099 .75005 m .70206 .75084 L .70364 .74647 L F
.372 0 0 r
.69576 .74317 m .69216 .7415 L .69398 .74049 L F
.45 .552 .868 r
.69711 .7421 m .69576 .74317 L .69398 .74049 L F
.389 .44 .792 r
.69711 .7421 m .69744 .74446 L .69576 .74317 L F
.524 .085 .147 r
.38536 .75104 m .38388 .75263 L .38213 .75179 L F
0 0 .385 r
.3859 .74774 m .38607 .75029 L .38536 .75104 L F
0 0 0 r
.38607 .75029 m .38388 .75263 L .38536 .75104 L F
.722 .711 .839 r
.69744 .74446 m .69852 .74591 L .69523 .74557 L F
.806 .743 .793 r
.58522 .81156 m .58237 .81147 L .58494 .80767 L F
.857 .698 .684 r
.58522 .81156 m .58209 .81319 L .58237 .81147 L F
.58522 .81156 m .58368 .81427 L .58209 .81319 L F
.39 .45 .802 r
.58765 .81044 m .588 .81214 L .58522 .81156 L F
0 0 0 r
.56429 .83834 m .56312 .84034 L .56174 .8379 L F
.845 .906 .878 r
.66704 .7299 m .6648 .73218 L .6667 .73122 L F
.818 .57 .564 r
.6648 .73218 m .66771 .73482 L .6667 .73122 L F
.519 .27 .478 r
.42029 .76155 m .42228 .76127 L .42295 .75872 L F
.598 .346 .506 r
.42295 .75872 m .42499 .76029 L .42516 .75861 L F
.42295 .75872 m .42228 .76127 L .42499 .76029 L F
.836 .788 .806 r
.69216 .7415 m .68874 .74271 L .69101 .73987 L F
.656 .751 .92 r
.69101 .73987 m .69398 .74049 L .69216 .7415 L F
.898 .898 .818 r
.65694 .71066 m .65992 .70842 L .65698 .70835 L F
.646 .326 .416 r
.48648 .83715 m .48735 .8398 L .48607 .83829 L F
.624 .647 .852 r
.588 .81214 m .58934 .81501 L .58692 .81556 L F
.333 0 0 r
.47792 .87986 m .48154 .87849 L .47922 .87852 L F
.618 .376 .528 r
.6655 .63176 m .66554 .63368 L .66257 .63452 L F
.581 .303 .461 r
.66785 .63181 m .66554 .63368 L .6655 .63176 L F
.768 .295 .117 r
.50747 .87346 m .50838 .87274 L .51039 .8749 L F
.744 .45 .484 r
.50624 .84686 m .50462 .84877 L .50281 .84712 L F
.903 .489 .157 r
.55142 .81405 m .55171 .81653 L .54986 .81397 L F
.55142 .81405 m .55281 .81703 L .55171 .81653 L F
.227 0 0 r
.55801 .77888 m .56205 .77903 L .55908 .77899 L F
.279 0 0 r
.35617 .75639 m .35454 .75781 L .35241 .75819 L F
.561 .225 .357 r
.35779 .75544 m .35454 .75781 L .35617 .75639 L F
.819 .771 .807 r
.68673 .74508 m .68947 .74497 L .68874 .74271 L F
.828 .708 .732 r
.68673 .74508 m .68777 .7482 L .68947 .74497 L F
.681 .696 .857 r
.68874 .74271 m .68947 .74497 L .692 .74375 L F
.68874 .74271 m .692 .74375 L .69059 .74292 L F
.495 .579 .868 r
.68874 .74271 m .68947 .74497 L .69059 .74292 L F
.57 .488 .723 r
.44058 .74232 m .43912 .74581 L .43883 .7428 L F
.313 0 .128 r
.3532 .73173 m .35497 .73133 L .35592 .73007 L F
.401 .036 .226 r
.35497 .73133 m .35783 .72962 L .35592 .73007 L F
.985 .76 .361 r
.67442 .73781 m .6738 .73696 L .67381 .7347 L F
0 .154 .692 r
.67516 .7397 m .6738 .73696 L .67442 .73781 L F
.584 .535 .766 r
.33745 .67386 m .33543 .67429 L .33447 .67108 L F
.833 .517 .454 r
.49282 .85275 m .49351 .85377 L .4965 .85418 L F
.49351 .85377 m .49505 .85604 L .4963 .85443 L F
.49351 .85377 m .4963 .85443 L .4965 .85418 L F
0 .21 .724 r
.49384 .85314 m .49505 .85604 L .49282 .85275 L F
.49384 .85314 m .49282 .85275 L .4917 .85346 L F
.498 .272 .502 r
.49402 .85086 m .49384 .85314 L .4917 .85346 L F
.49414 .85072 m .49384 .85314 L .49402 .85086 L F
.458 .795 .999 r
.4918 .85336 m .49384 .85314 L .49266 .85249 L F
.49203 .85341 m .49384 .85314 L .4918 .85336 L F
.777 .699 .777 r
.49266 .85249 m .49384 .85314 L .4917 .85346 L F
.49266 .85249 m .49374 .85442 L .49384 .85314 L F
.49374 .85442 m .494 .85489 L .49384 .85314 L F
.458 .795 .999 r
.4917 .85346 m .49203 .85341 L .4918 .85336 L F
.924 .667 .53 r
.49505 .85604 m .49641 .85646 L .4965 .85418 L F
.544 .237 .399 r
.43997 .76198 m .43952 .76365 L .43743 .7638 L F
.631 .387 .531 r
.44361 .76071 m .43952 .76365 L .43997 .76198 L F
.646 .637 .826 r
.58205 .8227 m .58058 .82504 L .57927 .82192 L F
.588 .559 .789 r
.58205 .8227 m .5827 .82489 L .58058 .82504 L F
.578 .388 .588 r
.58159 .8257 m .58058 .82504 L .5827 .82489 L F
.58159 .8257 m .5807 .82729 L .58058 .82504 L F
.33 .473 .853 r
.50863 .84356 m .50977 .84461 L .5092 .84274 L F
.762 .623 .705 r
.60579 .80376 m .60287 .80115 L .60286 .8035 L F
.781 .62 .681 r
.60286 .8035 m .60418 .80649 L .60579 .80376 L F
.766 .622 .7 r
.71252 .73501 m .71077 .73816 L .71373 .73826 L F
.346 0 .117 r
.64196 .63132 m .64535 .62929 L .64299 .63225 L F
.534 .366 .6 r
.64954 .71121 m .65173 .71339 L .65161 .71084 L F
.64954 .71121 m .6497 .71396 L .65173 .71339 L F
.756 .669 .765 r
.6355 .73755 m .63873 .73977 L .63777 .73707 L F
.6355 .73755 m .63679 .74064 L .63873 .73977 L F
.79 .755 .821 r
.63777 .73707 m .63873 .73977 L .64103 .73709 L F
.523 .207 .374 r
.41804 .77474 m .41711 .77728 L .41482 .77739 L F
.542 .227 .382 r
.41988 .77617 m .41804 .77474 L .42017 .77447 L F
.41988 .77617 m .41711 .77728 L .41804 .77474 L F
.333 0 .041 r
.63649 .73184 m .6386 .73157 L .63979 .7298 L F
.56 .226 .36 r
.6386 .73157 m .64121 .72903 L .63979 .7298 L F
.136 0 .305 r
.52974 .8441 m .52867 .84623 L .52662 .84522 L F
.734 .58 .682 r
.52974 .8441 m .53054 .84904 L .52745 .84865 L F
.136 0 .305 r
.52974 .8441 m .52745 .84865 L .52885 .84817 L F
.52974 .8441 m .5291 .84704 L .52867 .84623 L F
.533 .447 .704 r
.5303 .84744 m .53054 .84904 L .52974 .8441 L F
.678 .767 .918 r
.52802 .84499 m .52867 .84623 L .5307 .84532 L F
.52735 .84491 m .52867 .84623 L .52802 .84499 L F
.136 0 .305 r
.5291 .84704 m .52885 .84817 L .52867 .84623 L F
.645 .637 .827 r
.69062 .72211 m .69179 .71933 L .6895 .7193 L F
.69062 .72211 m .69285 .72161 L .69179 .71933 L F
.767 .701 .789 r
.69084 .7245 m .69285 .72161 L .69062 .72211 L F
.984 .809 .588 r
.49808 .85913 m .49957 .85694 L .49641 .85646 L F
.49808 .85913 m .49944 .85974 L .49957 .85694 L F
.456 .612 .915 r
.56794 .8453 m .56819 .84655 L .56976 .84536 L F
.422 .544 .875 r
.56819 .84655 m .57094 .84769 L .56976 .84536 L F
.613 .833 .984 r
.51282 .88065 m .50941 .88042 L .51142 .8805 L F
.336 0 0 r
.5142 .88161 m .51282 .88065 L .51142 .8805 L F
.5142 .88161 m .51509 .88051 L .51282 .88065 L F
.806 .667 .71 r
.5243 .86174 m .5256 .86434 L .52646 .86258 L F
.882 .852 .808 r
.55259 .83825 m .55081 .84053 L .55297 .84029 L F
.998 .812 .467 r
.55081 .84053 m .55134 .84347 L .55297 .84029 L F
.716 .753 .882 r
.65266 .72937 m .65423 .72995 L .65061 .72972 L F
.74 .591 .689 r
.654 .73234 m .65061 .72972 L .65423 .72995 L F
.388 .087 .327 r
.36609 .78815 m .3672 .78773 L .36851 .78747 L F
0 0 0 r
.36825 .78733 m .3672 .78773 L .36556 .78891 L F
.479 .898 .843 r
.36851 .78747 m .3672 .78773 L .3691 .78683 L F
0 0 0 r
.3691 .78683 m .3672 .78773 L .36825 .78733 L F
.388 .087 .327 r
.36521 .7884 m .3672 .78773 L .36609 .78815 L F
.281 .699 .97 r
.3691 .78683 m .37042 .78755 L .36851 .78747 L F
.531 .385 .628 r
.45681 .85166 m .45881 .85141 L .45869 .84884 L F
.574 .455 .68 r
.45707 .85406 m .45881 .85141 L .45681 .85166 L F
.953 .674 .469 r
.67043 .71871 m .66896 .71584 L .66997 .71656 L F
.67043 .71871 m .66896 .71584 L .66997 .71656 L F
.405 .648 .956 r
.42211 .74289 m .42289 .74167 L .42091 .74189 L F
.42211 .74289 m .42385 .74287 L .42289 .74167 L F
.786 .62 .675 r
.58179 .79537 m .57867 .79567 L .57897 .79311 L F
.849 .667 .656 r
.58179 .79537 m .57872 .79779 L .57867 .79567 L F
.58179 .79537 m .5806 .79852 L .57872 .79779 L F
.513 .592 .871 r
.56398 .8413 m .56524 .84383 L .56688 .84267 L F
.463 .49 .801 r
.56524 .84383 m .56794 .8453 L .56688 .84267 L F
.978 .679 .326 r
.38047 .88307 m .38168 .8863 L .38069 .88439 L F
.386 .748 .992 r
.38168 .8863 m .38235 .88541 L .38069 .88439 L F
.38168 .8863 m .38389 .88627 L .38235 .88541 L F
.781 .863 .911 r
.49117 .8251 m .49238 .82668 L .49467 .82483 L F
.532 .508 .775 r
.44431 .74834 m .44281 .74993 L .44232 .74861 L F
.44431 .74834 m .44532 .74974 L .44281 .74993 L F
.594 .215 .293 r
.38019 .72338 m .38191 .72259 L .38027 .72111 L F
.347 .466 .839 r
.70355 .72186 m .70478 .72449 L .70605 .72317 L F
.392 .538 .882 r
.70478 .72449 m .70852 .72588 L .70605 .72317 L F
.591 .607 .837 r
.70151 .72227 m .70478 .72449 L .70355 .72186 L F
.537 0 0 r
.47784 .88223 m .47881 .88314 L .4767 .88162 L F
.109 0 0 r
.6785 .71053 m .68189 .71074 L .67985 .71056 L F
.404 .853 .908 r
.6785 .71053 m .67985 .71056 L .67751 .71098 L F
.6785 .71053 m .67985 .71056 L .67751 .71098 L F
.582 .363 .548 r
.44495 .75872 m .44514 .76068 L .44361 .76071 L F
.583 .369 .556 r
.44707 .75855 m .44514 .76068 L .44495 .75872 L F
.976 .69 .302 r
.67357 .73241 m .67306 .73395 L .67259 .73168 L F
.67357 .73241 m .67381 .7347 L .67306 .73395 L F
.678 .348 .408 r
.50264 .84529 m .5049 .84347 L .50128 .84373 L F
.50264 .84529 m .50327 .84555 L .5049 .84347 L F
.725 .408 .443 r
.50327 .84555 m .50639 .846 L .5049 .84347 L F
.588 .757 .959 r
.43711 .73561 m .4338 .73498 L .43588 .73461 L F
.655 .798 .951 r
.43918 .73494 m .43711 .73561 L .43588 .73461 L F
.6 .774 .963 r
.64952 .62766 m .65041 .6289 L .64814 .62935 L F
.073 .496 .896 r
.68166 .72441 m .68554 .72651 L .684 .72625 L F
.448 .39 .701 r
.32109 .68187 m .31983 .67942 L .32036 .68142 L F
.435 .371 .687 r
.32048 .6821 m .32109 .68187 L .32036 .68142 L F
.395 .508 .855 r
.42875 .74816 m .42899 .74566 L .42731 .74535 L F
.42875 .74816 m .42994 .7476 L .42899 .74566 L F
.268 .196 .588 r
.42875 .74816 m .43032 .75041 L .42994 .7476 L F
.245 .189 .593 r
.42914 .75046 m .43032 .75041 L .42875 .74816 L F
.405 .176 .451 r
.50705 .85412 m .50852 .85593 L .50934 .8543 L F
.50705 .85412 m .50643 .85668 L .50852 .85593 L F
.163 .697 .844 r
.412 .74242 m .40994 .74231 L .40782 .74242 L F
.439 0 0 r
.412 .74242 m .41328 .74281 L .40994 .74231 L F
.637 .805 .964 r
.58257 .84622 m .58271 .8436 L .57909 .84462 L F
.58257 .84622 m .58499 .84514 L .58271 .8436 L F
.803 .616 .649 r
.56071 .80916 m .56071 .81163 L .56206 .80917 L F
.424 .234 .516 r
.50725 .84073 m .50894 .841 L .50923 .83809 L F
.389 .381 .729 r
.50725 .84073 m .5092 .84274 L .50894 .841 L F
.949 .634 .202 r
.47697 .87226 m .47555 .87012 L .4735 .87028 L F
.47697 .87226 m .47674 .87293 L .47555 .87012 L F
.628 .724 .916 r
.34551 .67705 m .34416 .67863 L .34264 .6765 L F
.529 .57 .84 r
.34551 .67705 m .34685 .67973 L .34416 .67863 L F
.589 .705 .923 r
.4065 .72513 m .40446 .72557 L .40314 .72395 L F
.571 .455 .682 r
.63322 .73786 m .6355 .73755 L .63509 .73417 L F
.679 .631 .795 r
.63359 .73993 m .6355 .73755 L .63322 .73786 L F
.442 .317 .614 r
.46056 .84347 m .4624 .84533 L .46254 .8433 L F
.46056 .84347 m .46086 .84574 L .4624 .84533 L F
.593 .062 0 r
.48314 .86888 m .48219 .86767 L .48091 .86713 L F
.48314 .86888 m .48413 .8696 L .48219 .86767 L F
.711 .536 .65 r
.59956 .80096 m .60297 .79873 L .59956 .79853 L F
.59956 .80096 m .60287 .80115 L .60297 .79873 L F
.77 .696 .78 r
.58792 .8222 m .58771 .82431 L .58576 .82482 L F
.748 .586 .675 r
.58771 .82431 m .58668 .82906 L .58576 .82482 L F
.133 .259 .729 r
.53366 .81425 m .53472 .8171 L .53575 .81611 L F
0 0 .523 r
.53472 .8171 m .53602 .81719 L .53575 .81611 L F
.439 .273 .558 r
.66299 .7346 m .66487 .73453 L .6648 .73218 L F
.657 .541 .711 r
.66299 .7346 m .66595 .7374 L .66487 .73453 L F
.66299 .7346 m .66411 .73853 L .66595 .7374 L F
.573 .238 .364 r
.54116 .83997 m .5393 .83814 L .54148 .83764 L F
.821 .929 .904 r
.52105 .87082 m .51908 .8726 L .51792 .8721 L F
.934 .563 .264 r
.51792 .8721 m .51908 .8726 L .51938 .87439 L F
0 .543 .809 r
.39988 .72319 m .40314 .72395 L .40158 .72372 L F
.313 .791 .915 r
.52301 .87377 m .52452 .87411 L .52465 .87398 L F
.703 .733 .874 r
.52743 .87306 m .52805 .87516 L .52577 .87569 L F
.68 .54 .688 r
.52577 .87569 m .52805 .87516 L .52594 .87811 L F
.672 .902 .56 r
.35108 .70858 m .35172 .70745 L .3532 .7059 L F
.598 .431 .627 r
.3532 .7059 m .35342 .70868 L .35108 .70858 L F
.433 .726 .987 r
.35108 .70858 m .35342 .70868 L .35172 .70745 L F
.466 .054 .173 r
.35987 .72939 m .36202 .72934 L .36337 .72746 L F
.453 .04 .165 r
.36337 .72746 m .36202 .72934 L .36492 .72826 L F
.458 .03 .137 r
.36337 .72746 m .36492 .72826 L .36559 .72738 L F
.244 .312 .736 r
.45352 .87506 m .45424 .87785 L .4552 .87645 L F
.436 .576 .895 r
.45424 .87785 m .45628 .87812 L .4552 .87645 L F
.762 .498 .535 r
.54485 .80386 m .54394 .80444 L .54221 .80356 L F
.877 .948 .855 r
.53368 .83197 m .53338 .83417 L .53507 .83328 L F
.53368 .83197 m .53139 .83441 L .53338 .83417 L F
.361 .444 .811 r
.51762 .82997 m .52072 .83246 L .52005 .83032 L F
.325 0 .117 r
.47448 .84859 m .47765 .84621 L .47476 .84641 L F
.47448 .84859 m .47639 .84815 L .47765 .84621 L F
.595 .591 .818 r
.47765 .84621 m .47855 .84296 L .47691 .84326 L F
.47765 .84621 m .47986 .84628 L .47855 .84296 L F
.598 .232 .319 r
.47639 .84815 m .47986 .84628 L .47765 .84621 L F
.74 .98 .747 r
.67068 .72343 m .669 .72565 L .66969 .72501 L F
.351 .15 .461 r
.32807 .70585 m .32692 .70833 L .32626 .70857 L F
.33 .106 .414 r
.32626 .70857 m .32692 .70833 L .32605 .70964 L F
.437 .338 .646 r
.3207 .68456 m .32109 .68187 L .32048 .6821 L F
.52 .802 .997 r
.39492 .74524 m .39575 .74406 L .39361 .74452 L F
.39492 .74524 m .39698 .74485 L .39575 .74406 L F
.77 .706 .791 r
.57656 .83043 m .57396 .83292 L .57282 .82921 L F
.576 .387 .589 r
.57787 .83036 m .57396 .83292 L .57656 .83043 L F
.637 .637 .834 r
.69622 .72865 m .69494 .73187 L .69432 .72988 L F
.69622 .72865 m .69765 .73135 L .69494 .73187 L F
.525 .049 .067 r
.41648 .74249 m .41559 .74318 L .41328 .74281 L F
.161 0 0 r
.41847 .74227 m .41559 .74318 L .41648 .74249 L F
0 0 .349 r
.55947 .82512 m .55904 .82409 L .55786 .82188 L F
.988 .895 .59 r
.55966 .82706 m .55904 .82409 L .55947 .82512 L F
.491 .212 .419 r
.42777 .76938 m .42729 .7715 L .42514 .77178 L F
.522 .241 .429 r
.42945 .77109 m .42777 .76938 L .42986 .76908 L F
.42945 .77109 m .42729 .7715 L .42777 .76938 L F
.438 .112 .315 r
.6588 .71619 m .66037 .71786 L .66024 .71602 L F
.6588 .71619 m .65834 .71888 L .66037 .71786 L F
.78 .623 .685 r
.58873 .79 m .58968 .79303 L .59141 .79017 L F
.679 .631 .795 r
.63359 .73993 m .63679 .74064 L .6355 .73755 L F
.855 .942 .877 r
.68164 .69384 m .67848 .6952 L .68054 .69449 L F
0 .305 .77 r
.68277 .69413 m .68164 .69384 L .68054 .69449 L F
.517 .195 .36 r
.54514 .83422 m .5457 .83541 L .5438 .83546 L F
.511 .192 .363 r
.54627 .83448 m .5457 .83541 L .54514 .83422 L F
.741 .91 .951 r
.47453 .85593 m .4747 .85705 L .47637 .85619 L F
.935 .861 .43 r
.47453 .85593 m .47389 .85883 L .4747 .85705 L F
.53 .297 .507 r
.51537 .8513 m .51643 .85132 L .51698 .84872 L F
.497 .263 .489 r
.51643 .85132 m .51857 .84923 L .51698 .84872 L F
.45 .505 .824 r
.50977 .84461 m .51122 .8426 L .5092 .84274 L F
.50977 .84461 m .51263 .84551 L .51122 .8426 L F
.573 .439 .661 r
.65563 .61546 m .6537 .61832 L .65343 .61591 L F
.65563 .61546 m .6537 .61832 L .65343 .61591 L F
.406 .123 .368 r
.37381 .80085 m .37628 .79863 L .3755 .80033 L F
.387 .105 .358 r
.3755 .80033 m .37628 .79863 L .37807 .79809 L F
.196 .243 .685 r
.65176 .73355 m .65178 .73591 L .65299 .73392 L F
.446 .218 .473 r
.65178 .73591 m .65433 .73495 L .65299 .73392 L F
.65178 .73591 m .65187 .73727 L .65433 .73495 L F
.567 .769 .973 r
.70275 .72077 m .70355 .72186 L .70151 .72227 L F
.70151 .72227 m .70355 .72186 L .70275 .72077 L F
.547 .361 .58 r
.69465 .69063 m .69686 .69198 L .69693 .68971 L F
.64 .895 .985 r
.69465 .69063 m .69693 .68971 L .69686 .69198 L F
.321 0 .071 r
.40078 .77216 m .4015 .77348 L .40282 .77178 L F
.40078 .77216 m .39949 .7739 L .4015 .77348 L F
.772 .449 .441 r
.51337 .86644 m .51667 .86743 L .51493 .86465 L F
.976 .736 .51 r
.69686 .69198 m .69804 .69309 L .69693 .68971 L F
.589 .292 .433 r
.65498 .62627 m .65845 .62595 L .65785 .62392 L F
.686 .348 .398 r
.65845 .62595 m .6603 .62588 L .65785 .62392 L F
.616 .477 .669 r
.45506 .85674 m .45737 .85656 L .45707 .85406 L F
.576 .409 .619 r
.4553 .8591 m .45737 .85656 L .45506 .85674 L F
.494 .353 .618 r
.35518 .70789 m .3532 .7059 L .35528 .70545 L F
.35518 .70789 m .35342 .70868 L .3532 .7059 L F
.776 .554 .599 r
.35172 .70745 m .35528 .70545 L .3532 .7059 L F
.302 0 .026 r
.56036 .78241 m .55693 .78452 L .55697 .78268 L F
.56036 .78241 m .55913 .7841 L .55693 .78452 L F
.469 0 0 r
.56248 .78318 m .55913 .7841 L .56036 .78241 L F
.002 0 0 r
.36288 .80579 m .36613 .80344 L .36475 .80511 L F
.272 0 0 r
.36822 .80292 m .36766 .80369 L .36613 .80344 L F
.273 0 .001 r
.36613 .80344 m .36665 .80461 L .36475 .80511 L F
.36613 .80344 m .36766 .80369 L .36665 .80461 L F
.57 .488 .723 r
.44058 .74232 m .44118 .74547 L .43912 .74581 L F
.918 .968 .667 r
.71138 .73574 m .71077 .73816 L .71252 .73501 L F
.44 .297 .589 r
.57415 .8063 m .57578 .80843 L .57585 .80607 L F
.331 .267 .633 r
.57463 .80838 m .57578 .80843 L .57415 .8063 L F
.684 .314 .341 r
.65352 .72066 m .65061 .7194 L .65425 .71907 L F
0 0 0 r
.65555 .72008 m .65352 .72066 L .65425 .71907 L F
.398 0 0 r
.56569 .78281 m .56452 .78382 L .56248 .78318 L F
.605 .05 0 r
.56894 .78525 m .56777 .78464 L .56569 .78281 L F
0 .101 .605 r
.56569 .78281 m .56777 .78464 L .56697 .78375 L F
.56569 .78281 m .56697 .78375 L .56452 .78382 L F
.372 .785 .98 r
.53812 .82454 m .5392 .82505 L .53588 .82474 L F
.983 .734 .478 r
.53827 .82214 m .5392 .82505 L .53812 .82454 L F
.339 .006 .245 r
.47968 .82959 m .48039 .83161 L .48165 .82979 L F
.47968 .82959 m .4786 .83206 L .48039 .83161 L F
.576 .615 .854 r
.31983 .67942 m .32018 .67656 L .31915 .67701 L F
.31983 .67942 m .32168 .67841 L .32018 .67656 L F
.448 .39 .701 r
.32109 .68187 m .32168 .67841 L .31983 .67942 L F
.464 .138 .328 r
.40082 .78502 m .3997 .78767 L .39771 .78794 L F
.481 .162 .348 r
.40287 .78469 m .3997 .78767 L .40082 .78502 L F
.808 .649 .685 r
.58312 .80096 m .58 .80072 L .5806 .79852 L F
.804 .683 .731 r
.58312 .80096 m .58118 .80368 L .58 .80072 L F
.708 .881 .961 r
.68442 .73425 m .68554 .73189 L .68345 .73246 L F
.68442 .73425 m .68667 .73284 L .68554 .73189 L F
.759 .846 .916 r
.68442 .73425 m .68105 .73425 L .68274 .73526 L F
.68442 .73425 m .68345 .73246 L .68105 .73425 L F
.683 .569 .721 r
.52649 .85457 m .52662 .85693 L .52446 .85717 L F
.475 .008 .064 r
.36352 .75343 m .36199 .75476 L .36013 .75403 L F
0 0 0 r
.36472 .75304 m .36352 .75343 L .36525 .75257 L F
.36472 .75304 m .36199 .75476 L .36352 .75343 L F
.804 .808 .855 r
.51633 .88353 m .51664 .88035 L .51548 .88323 L F
.589 .853 .994 r
.7074 .73829 m .70741 .73872 L .71077 .73816 L F
.843 .873 .863 r
.64484 .72259 m .64835 .71948 L .6473 .71837 L F
.693 .182 .015 r
.65061 .7194 m .6473 .71837 L .64835 .71948 L F
.988 .866 .509 r
.68092 .7165 m .67978 .71851 L .68085 .71903 L F
.68092 .7165 m .68033 .71599 L .67978 .71851 L F
.809 .586 .6 r
.4967 .87409 m .49435 .87723 L .49432 .87521 L F
.4967 .87409 m .49745 .87797 L .49435 .87723 L F
.574 .432 .65 r
.49842 .87626 m .4967 .87409 L .49828 .8746 L F
.49842 .87626 m .49745 .87797 L .4967 .87409 L F
.479 .224 .449 r
.65794 .63682 m .66006 .63826 L .65751 .63926 L F
.65794 .63682 m .66017 .63625 L .66006 .63826 L F
.781 .859 .414 r
.68454 .75284 m .68563 .75088 L .68569 .75335 L F
.68454 .75284 m .68584 .75001 L .68563 .75088 L F
.339 .613 .951 r
.68584 .75001 m .68685 .74996 L .68563 .75088 L F
.393 .719 .988 r
.68685 .74996 m .68831 .75096 L .68563 .75088 L F
.756 .705 .804 r
.68831 .75096 m .68569 .75335 L .68563 .75088 L F
.289 .761 .937 r
.4004 .74504 m .39906 .74469 L .39698 .74485 L F
.232 .726 .917 r
.40224 .74495 m .39906 .74469 L .4004 .74504 L F
.444 .131 .34 r
.55363 .7863 m .55251 .784 L .55496 .78395 L F
.55363 .7863 m .55139 .78683 L .55251 .784 L F
.264 .75 .922 r
.54538 .84075 m .54604 .8406 L .54805 .84085 L F
.025 .092 .596 r
.54592 .84352 m .54604 .8406 L .54538 .84075 L F
.706 .169 0 r
.54592 .84352 m .54825 .84577 L .5466 .84487 L F
.54592 .84352 m .5466 .84487 L .54691 .84263 L F
.566 .15 .213 r
.37235 .7869 m .37468 .7871 L .37601 .78535 L F
.171 0 0 r
.37601 .78535 m .37647 .78647 L .37815 .7852 L F
.37601 .78535 m .37468 .7871 L .37647 .78647 L F
.401 .272 .589 r
.45273 .87282 m .45436 .86983 L .45253 .87038 L F
.98 .725 .475 r
.56169 .83366 m .56081 .83475 L .56064 .83196 L F
.791 .662 .721 r
.52233 .86444 m .5256 .86434 L .5243 .86174 L F
.876 .741 .71 r
.4965 .88649 m .4977 .88896 L .49428 .88849 L F
.673 .209 .143 r
.49428 .88849 m .4977 .88896 L .49647 .89011 L F
.497 .002 .011 r
.49647 .89011 m .4977 .88896 L .49968 .88968 L F
.507 .135 .268 r
.4977 .88896 m .50096 .88802 L .49968 .88968 L F
.586 .024 0 r
.48531 .85683 m .48761 .8587 L .48643 .85813 L F
.701 .487 .595 r
.53496 .83033 m .53762 .83145 L .53747 .82969 L F
0 0 0 r
.53747 .82969 m .53599 .8302 L .53496 .83033 L F
.931 .674 .527 r
.53368 .83197 m .53507 .83328 L .53496 .83033 L F
.701 .487 .595 r
.53496 .83033 m .53507 .83328 L .53762 .83145 L F
.931 .674 .527 r
.53368 .83197 m .53496 .83033 L .53599 .8302 L F
.615 .87 .99 r
.51784 .85883 m .51827 .85962 L .51597 .85976 L F
.94 .582 .302 r
.51827 .85962 m .51792 .86161 L .51597 .85976 L F
.51827 .85962 m .51901 .86183 L .51792 .86161 L F
.871 .967 .854 r
.52106 .85652 m .51827 .85962 L .51784 .85883 L F
.761 .46 .476 r
.70314 .7299 m .70278 .73198 L .70603 .73207 L F
.427 .065 .246 r
.35003 .73427 m .35206 .73394 L .3532 .73173 L F
.333 0 .196 r
.3532 .73173 m .354 .73337 L .35497 .73133 L F
.3532 .73173 m .35206 .73394 L .354 .73337 L F
.428 .087 .284 r
.42269 .77268 m .42221 .77411 L .42017 .77447 L F
.466 .127 .307 r
.42514 .77178 m .42221 .77411 L .42269 .77268 L F
.867 .42 .071 r
.54733 .85395 m .5483 .85426 L .54659 .85281 L F
.54659 .85281 m .5483 .85426 L .54733 .85395 L F
.533 .447 .704 r
.5303 .84744 m .53271 .84898 L .53054 .84904 L F
.407 .462 .805 r
.53401 .84756 m .5303 .84744 L .53392 .8454 L F
.53401 .84756 m .53271 .84898 L .5303 .84744 L F
.384 .167 .456 r
.52594 .87811 m .52805 .87516 L .52758 .87727 L F
.52594 .87811 m .52805 .87516 L .52758 .87727 L F
.572 .65 .888 r
.52953 .87422 m .52805 .87516 L .52743 .87306 L F
.266 .062 .406 r
.52758 .87727 m .52805 .87516 L .52953 .87422 L F
0 0 0 r
.52447 .87967 m .52594 .87811 L .52758 .87727 L F
.085 0 0 r
.37308 .80157 m .37381 .80085 L .3755 .80033 L F
.799 .668 .72 r
.69164 .71627 m .68974 .71701 L .68848 .71598 L F
.69164 .71627 m .68848 .71598 L .69043 .71629 L F
.407 .334 .662 r
.68974 .71701 m .6895 .7193 L .69133 .71764 L F
.571 .605 .848 r
.6895 .7193 m .69179 .71933 L .69133 .71764 L F
.292 .787 .77 r
.69179 .71933 m .69179 .71906 L .69133 .71764 L F
.737 .239 .049 r
.69179 .71906 m .69043 .71629 L .69133 .71764 L F
.69179 .71906 m .69164 .71627 L .69043 .71629 L F
.77 .706 .791 r
.57656 .83043 m .57282 .82921 L .57572 .82935 L F
.549 .542 .8 r
.44319 .74523 m .44232 .74861 L .44118 .74547 L F
.44319 .74523 m .44431 .74834 L .44232 .74861 L F
.352 .796 .958 r
.58801 .84574 m .58926 .84527 L .58722 .84593 L F
.58801 .84574 m .59079 .8456 L .58926 .84527 L F
.673 .352 .423 r
.54648 .80634 m .54501 .80702 L .54338 .80659 L F
.492 0 .013 r
.54501 .80702 m .54844 .80667 L .54648 .80634 L F
.721 .416 .463 r
.51466 .84029 m .5166 .84047 L .51439 .83796 L F
.603 .432 .623 r
.51439 .83796 m .51646 .83791 L .51653 .83554 L F
.601 .416 .603 r
.51439 .83796 m .5166 .84047 L .51646 .83791 L F
.575 .567 .807 r
.69907 .72941 m .6982 .73285 L .69765 .73135 L F
.69907 .72941 m .70055 .73244 L .6982 .73285 L F
.609 .553 .766 r
.70078 .73457 m .6982 .73285 L .70055 .73244 L F
.853 .671 .656 r
.64383 .63895 m .64538 .63983 L .64516 .64215 L F
.892 .487 .066 r
.50192 .86447 m .49944 .86468 L .50064 .86447 L F
.50192 .86447 m .50197 .86653 L .49944 .86468 L F
.50192 .86447 m .5028 .86679 L .50197 .86653 L F
.50197 .86653 m .5028 .86679 L .50192 .86447 L F
.671 .453 .582 r
.5028 .86679 m .50626 .8644 L .50192 .86447 L F
.892 .487 .066 r
.50197 .86653 m .50192 .86447 L .50244 .86382 L F
0 0 0 r
.49968 .88968 m .50096 .88802 L .502 .88781 L F
.433 .236 .512 r
.32797 .70797 m .32807 .70585 L .32818 .70578 L F
.32797 .70797 m .32692 .70833 L .32807 .70585 L F
.883 .837 .796 r
.68387 .69656 m .6849 .69771 L .68675 .69505 L F
.485 .19 .389 r
.65322 .64017 m .65288 .64179 L .65063 .64219 L F
.337 .019 .27 r
.65527 .63966 m .65288 .64179 L .65322 .64017 L F
.427 .392 .717 r
.33532 .66738 m .33378 .66918 L .33324 .66584 L F
.522 .497 .769 r
.33532 .66738 m .33447 .67108 L .33378 .66918 L F
.906 .623 .496 r
.67249 .72111 m .67059 .72094 L .67043 .71871 L F
.964 .782 .609 r
.67249 .72111 m .67068 .72343 L .67059 .72094 L F
.67249 .72111 m .67187 .72407 L .67068 .72343 L F
.854 .791 .789 r
.54805 .84085 m .54604 .8406 L .54777 .83834 L F
.33 .812 .875 r
.34998 .79573 m .34804 .7962 L .3469 .79612 L F
.581 .303 .461 r
.66785 .63181 m .66772 .63358 L .66554 .63368 L F
.572 .296 .459 r
.66785 .63181 m .67 .63341 L .66772 .63358 L F
.565 .381 .591 r
.6704 .62902 m .67013 .63138 L .66785 .63181 L F
.541 .31 .514 r
.67013 .63138 m .67 .63341 L .66785 .63181 L F
.133 .259 .729 r
.53366 .81425 m .53575 .81611 L .53707 .81432 L F
.782 .424 .378 r
.53575 .81611 m .53889 .81676 L .53707 .81432 L F
.706 .559 .685 r
.53054 .84904 m .52868 .85171 L .52745 .84865 L F
.53054 .84904 m .53091 .8513 L .52868 .85171 L F
.596 .526 .746 r
.53271 .84898 m .53091 .8513 L .53054 .84904 L F
.966 .666 .404 r
.56894 .78525 m .56926 .78752 L .56777 .78464 L F
.764 .716 .807 r
.42184 .73014 m .41868 .7298 L .42046 .72868 L F
.623 .687 .889 r
.42294 .72801 m .42184 .73014 L .42046 .72868 L F
.539 .584 .848 r
.42294 .72801 m .42389 .72997 L .42184 .73014 L F
.48 .167 .358 r
.41482 .77739 m .41233 .77918 L .41285 .77756 L F
.587 .486 .707 r
.71564 .72436 m .71802 .72412 L .71726 .72073 L F
.313 0 .073 r
.34072 .7378 m .34131 .73916 L .3429 .73754 L F
.34072 .7378 m .33945 .73955 L .34131 .73916 L F
.511 .269 .484 r
.47235 .84892 m .47448 .84859 L .47476 .84641 L F
.684 .974 .91 r
.48593 .88303 m .48773 .88271 L .4858 .88374 L F
.297 0 0 r
.37132 .75055 m .37146 .75092 L .36966 .75085 L F
.37132 .75055 m .37266 .75115 L .37146 .75092 L F
.837 .689 .699 r
.60189 .81378 m .6031 .81678 L .60488 .81368 L F
.56 .589 .839 r
.42589 .72935 m .42508 .73253 L .42389 .72997 L F
.42589 .72935 m .42722 .73231 L .42508 .73253 L F
.947 .925 .752 r
.6537 .61832 m .65205 .622 L .65111 .62031 L F
.6537 .61832 m .65111 .62031 L .65225 .61914 L F
.784 .707 .779 r
.65192 .62087 m .6538 .62076 L .65225 .61914 L F
.546 .786 .987 r
.65017 .62039 m .65205 .622 L .64869 .62052 L F
.65133 .62071 m .65205 .622 L .65017 .62039 L F
.784 .707 .779 r
.65149 .62311 m .65332 .62125 L .65192 .62087 L F
.65332 .62125 m .6538 .62076 L .65192 .62087 L F
.546 .786 .987 r
.65111 .62031 m .65133 .62071 L .65017 .62039 L F
.845 .71 .715 r
.60495 .83195 m .60687 .83025 L .60509 .82982 L F
.492 0 .013 r
.54501 .80702 m .54753 .80785 L .54844 .80667 L F
.86 .451 .254 r
.54753 .80785 m .54963 .80869 L .54844 .80667 L F
.295 0 .27 r
.38603 .78021 m .38527 .78193 L .38769 .77956 L F
.466 .683 .96 r
.58504 .84585 m .58611 .8449 L .58499 .84514 L F
.58504 .84585 m .58722 .84593 L .58611 .8449 L F
.835 .68 .69 r
.58604 .78696 m .58873 .79 L .58839 .78793 L F
.741 .91 .951 r
.47453 .85593 m .47637 .85619 L .47563 .85408 L F
.805 .844 .88 r
.47563 .85408 m .47637 .85619 L .47898 .85381 L F
.958 .73 .552 r
.6732 .72709 m .6717 .72862 L .67162 .72636 L F
.6732 .72709 m .67307 .72953 L .6717 .72862 L F
.7 .636 .781 r
.70382 .73466 m .70189 .73577 L .70078 .73457 L F
.645 .49 .659 r
.45148 .75307 m .45181 .75596 L .44951 .75614 L F
.628 .767 .946 r
.45384 .7525 m .45148 .75307 L .45014 .75158 L F
.636 .637 .835 r
.45399 .75255 m .45148 .75307 L .45384 .7525 L F
.649 .493 .659 r
.45428 .75505 m .45148 .75307 L .45399 .75255 L F
.45428 .75505 m .45181 .75596 L .45148 .75307 L F
.622 .078 0 r
.57463 .80838 m .57579 .80937 L .57665 .80897 L F
.117 .61 .908 r
.57665 .80897 m .57578 .80843 L .57463 .80838 L F
.996 .78 .489 r
.57585 .80607 m .57665 .80897 L .57904 .80643 L F
.57585 .80607 m .57578 .80843 L .57665 .80897 L F
.753 .58 .662 r
.59627 .79824 m .59956 .80096 L .59956 .79853 L F
.551 0 0 r
.41334 .72816 m .41521 .72887 L .41582 .72857 L F
.617 .08 0 r
.41521 .72887 m .41868 .7298 L .41582 .72857 L F
.061 .427 .87 r
.411 .72533 m .41094 .72631 L .4083 .72489 L F
.411 .72533 m .41182 .72651 L .41094 .72631 L F
.522 .497 .769 r
.33532 .66738 m .33629 .67074 L .33447 .67108 L F
.584 .535 .766 r
.33745 .67386 m .33447 .67108 L .33629 .67074 L F
.818 .57 .564 r
.6648 .73218 m .66487 .73453 L .66771 .73482 L F
.812 .715 .758 r
.66487 .73453 m .66595 .7374 L .66771 .73482 L F
.473 .715 .975 r
.5132 .8468 m .51448 .84548 L .51263 .84551 L F
.5132 .8468 m .51608 .84692 L .51448 .84548 L F
.642 .466 .629 r
.46787 .84091 m .47031 .84078 L .47018 .83813 L F
.664 .536 .698 r
.47031 .84078 m .47251 .8378 L .47018 .83813 L F
.721 .562 .674 r
.54221 .80356 m .54394 .80444 L .54209 .80111 L F
.68 .531 .676 r
.54209 .80111 m .53996 .80393 L .54221 .80356 L F
0 0 .226 r
.55064 .84329 m .55065 .84295 L .54987 .84179 L F
.998 .847 .525 r
.55065 .84295 m .5502 .84526 L .55134 .84347 L F
.858 .904 .492 r
.5512 .84376 m .5502 .84526 L .55049 .84529 L F
.55117 .84373 m .5502 .84526 L .5512 .84376 L F
0 0 .226 r
.55119 .84437 m .5502 .84526 L .55065 .84295 L F
.55119 .84437 m .55085 .84346 L .55064 .84329 L F
.55085 .84346 m .55065 .84295 L .55064 .84329 L F
.858 .904 .492 r
.55134 .84347 m .55117 .84373 L .5512 .84376 L F
.998 .812 .467 r
.55081 .84053 m .55065 .84295 L .55134 .84347 L F
.893 .984 .716 r
.52488 .85951 m .52662 .85693 L .52475 .85871 L F
.699 .582 .72 r
.5287 .85399 m .52662 .85693 L .52649 .85457 L F
.511 .107 .211 r
.52475 .85871 m .52662 .85693 L .52918 .85771 L F
.98 .694 .322 r
.56514 .82651 m .56586 .82504 L .5654 .82426 L F
.56514 .82651 m .56606 .82735 L .56586 .82504 L F
.864 .902 .859 r
.47734 .83764 m .48077 .8357 L .47956 .83506 L F
.839 .889 .876 r
.47956 .83506 m .48077 .8357 L .48344 .83325 L F
.459 .27 .536 r
.33015 .70286 m .32994 .70534 L .32818 .70578 L F
.492 .29 .534 r
.32978 .70746 m .32818 .70578 L .32994 .70534 L F
.32978 .70746 m .32797 .70797 L .32818 .70578 L F
.164 0 .111 r
.33897 .69495 m .33643 .69721 L .33733 .69578 L F
.748 .527 .596 r
.58972 .79533 m .59302 .79317 L .58968 .79303 L F
.58972 .79533 m .59309 .79565 L .59302 .79317 L F
.345 .616 .951 r
.31915 .67701 m .31928 .67564 L .31884 .67655 L F
.31915 .67701 m .31947 .67566 L .31928 .67564 L F
.31915 .67701 m .32018 .67656 L .31947 .67566 L F
.516 .307 .535 r
.42731 .75602 m .42943 .75565 L .42953 .75341 L F
.482 .508 .808 r
.42953 .75341 m .43032 .75041 L .42914 .75046 L F
.42953 .75341 m .43133 .75305 L .43032 .75041 L F
.589 .446 .655 r
.42943 .75565 m .43133 .75305 L .42953 .75341 L F
.442 .745 .992 r
.48597 .82926 m .485 .83023 L .48381 .82931 L F
.815 .432 .33 r
.37661 .75104 m .37509 .75238 L .37266 .75115 L F
0 0 0 r
.3769 .75117 m .37661 .75104 L .37898 .75119 L F
.3769 .75117 m .37509 .75238 L .37661 .75104 L F
.694 .858 .961 r
.64067 .73571 m .63777 .73707 L .64103 .73709 L F
.692 .76 .904 r
.64103 .73709 m .64224 .73409 L .64067 .73571 L F
.64103 .73709 m .64341 .73558 L .64224 .73409 L F
.446 .344 .646 r
.50508 .85899 m .50643 .85668 L .50473 .85727 L F
.44 .731 .988 r
.57697 .80272 m .57775 .80393 L .57574 .80375 L F
.626 .339 .462 r
.57775 .80393 m .57851 .80533 L .57574 .80375 L F
.286 .451 .85 r
.57574 .80375 m .57851 .80533 L .57697 .80272 L F
.592 .376 .557 r
.57574 .80375 m .57585 .80607 L .57851 .80533 L F
.566 .355 .553 r
.50923 .83809 m .50894 .841 L .511 .84029 L F
.747 .579 .666 r
.59273 .79813 m .5963 .79588 L .59309 .79565 L F
.59273 .79813 m .59627 .79824 L .5963 .79588 L F
.757 .408 .392 r
.57001 .77955 m .57201 .78206 L .57321 .77995 L F
.834 .507 .436 r
.57321 .77995 m .57201 .78206 L .57342 .78166 L F
.76 .624 .709 r
.52799 .86428 m .5295 .8675 L .52996 .86464 L F
0 0 0 r
.34856 .81169 m .34935 .8112 L .34793 .81225 L F
.565 .309 .486 r
.41775 .7638 m .41996 .76356 L .42029 .76155 L F
.49 .242 .466 r
.42029 .76155 m .42198 .76317 L .42228 .76127 L F
.42029 .76155 m .41996 .76356 L .42198 .76317 L F
.739 .649 .76 r
.58576 .82482 m .58205 .8227 L .58476 .82207 L F
.58576 .82482 m .5827 .82489 L .58205 .8227 L F
.714 .565 .685 r
.58576 .82482 m .58159 .8257 L .5827 .82489 L F
.58576 .82482 m .58387 .82772 L .58159 .8257 L F
.805 .755 .807 r
.58792 .8222 m .58576 .82482 L .58476 .82207 L F
0 .182 .706 r
.69504 .7441 m .69523 .74557 L .69534 .74437 L F
0 0 .327 r
.69523 .74557 m .69593 .74648 L .69534 .74437 L F
.69523 .74557 m .69567 .74775 L .69593 .74648 L F
.695 .635 .785 r
.68925 .72951 m .68646 .72966 L .68886 .72783 L F
.581 .584 .821 r
.69037 .73142 m .68646 .72966 L .68925 .72951 L F
.779 .52 .544 r
.49863 .84289 m .50264 .84529 L .50128 .84373 L F
0 0 0 r
.5184 .88169 m .52064 .88125 L .51912 .88163 L F
.684 .974 .91 r
.48593 .88303 m .4858 .88374 L .48499 .88355 L F
.669 .692 .863 r
.32996 .66413 m .32646 .66261 L .3286 .66213 L F
.332 .601 .945 r
.33025 .66259 m .32996 .66413 L .3286 .66213 L F
.33025 .66259 m .33153 .66426 L .32996 .66413 L F
.594 .372 .55 r
.44951 .75614 m .44927 .75843 L .44707 .75855 L F
.603 .367 .532 r
.45181 .75596 m .44927 .75843 L .44951 .75614 L F
.356 0 0 r
.50322 .88779 m .50525 .88833 L .502 .88781 L F
.706 .289 .253 r
.54672 .81012 m .5433 .81047 L .54354 .80874 L F
.54672 .81012 m .54689 .81107 L .5433 .81047 L F
.778 .345 .221 r
.48885 .85934 m .48892 .86144 L .48761 .8587 L F
.48885 .85934 m .49074 .86149 L .48892 .86144 L F
.668 .38 .474 r
.49068 .85952 m .49074 .86149 L .48885 .85934 L F
.551 .216 .354 r
.38968 .77918 m .3929 .77684 L .39072 .77676 L F
.564 .296 .468 r
.43232 .767 m .43203 .76897 L .42986 .76908 L F
.57 .305 .474 r
.43497 .76586 m .43203 .76897 L .43232 .767 L F
.528 .322 .544 r
.42516 .75861 m .42722 .75828 L .42731 .75602 L F
.551 .357 .572 r
.42722 .75828 m .42943 .75565 L .42731 .75602 L F
.774 .665 .742 r
.68116 .74505 m .68158 .743 L .6797 .74251 L F
.74 .591 .689 r
.654 .73234 m .65095 .73246 L .65061 .72972 L F
.359 .061 .317 r
.33209 .70202 m .33015 .70286 L .33269 .70065 L F
.296 .086 .415 r
.33416 .69982 m .33269 .70065 L .33458 .69777 L F
.475 .264 .513 r
.33416 .69982 m .33209 .70202 L .33269 .70065 L F
.446 .344 .646 r
.50508 .85899 m .50686 .85907 L .50643 .85668 L F
.354 .425 .797 r
.50508 .85899 m .50749 .8608 L .50686 .85907 L F
0 0 0 r
.47674 .87293 m .47771 .87273 L .48007 .8723 L F
0 .241 .755 r
.49856 .84801 m .49821 .846 L .49584 .84629 L F
.49856 .84801 m .49926 .84842 L .49821 .846 L F
.486 .266 .505 r
.34082 .76399 m .34034 .76606 L .33862 .76663 L F
.406 .171 .441 r
.34287 .76323 m .34034 .76606 L .34082 .76399 L F
.408 .77 .995 r
.64645 .72863 m .6504 .72925 L .64787 .72961 L F
.388 .776 .989 r
.6504 .72925 m .65061 .72972 L .64787 .72961 L F
.566 .412 .632 r
.45869 .84884 m .46092 .8509 L .46066 .84852 L F
.45869 .84884 m .45881 .85141 L .46092 .8509 L F
.79 .592 .632 r
.64289 .63395 m .64575 .63423 L .64553 .63636 L F
.764 .905 .516 r
.56071 .81163 m .55949 .81319 L .5596 .81365 L F
.85 .645 .105 r
.55949 .81319 m .5599 .81627 L .5596 .81365 L F
.574 .455 .68 r
.45707 .85406 m .45918 .85376 L .45881 .85141 L F
.57 .444 .669 r
.45707 .85406 m .45947 .85623 L .45918 .85376 L F
.45707 .85406 m .45737 .85656 L .45947 .85623 L F
.714 .788 .91 r
.51679 .85716 m .52106 .85652 L .5203 .85466 L F
.871 .967 .854 r
.52106 .85652 m .51784 .85883 L .52021 .85904 L F
.587 .592 .825 r
.52106 .85652 m .52322 .85638 L .52215 .85378 L F
.552 .294 .479 r
.52337 .85886 m .52106 .85652 L .52021 .85904 L F
.52337 .85886 m .52322 .85638 L .52106 .85652 L F
.361 0 0 r
.66666 .62865 m .66878 .62906 L .6704 .62902 L F
0 .146 .685 r
.67153 .6295 m .67226 .63083 L .6704 .62902 L F
.519 .341 .58 r
.67226 .63083 m .67013 .63138 L .6704 .62902 L F
0 .146 .685 r
.67153 .6295 m .6704 .62902 L .66878 .62906 L F
.653 .86 .978 r
.68178 .69772 m .6849 .69771 L .68387 .69656 L F
.464 .067 .202 r
.38006 .78474 m .38216 .78465 L .38356 .78261 L F
.447 .108 .298 r
.38216 .78465 m .38527 .78193 L .38356 .78261 L F
.582 .642 .875 r
.43481 .73242 m .4338 .73498 L .43244 .73256 L F
.43481 .73242 m .43588 .73461 L .4338 .73498 L F
.844 .443 .284 r
.54386 .8193 m .54549 .82193 L .54693 .82193 L F
.843 .478 .361 r
.54549 .82193 m .54857 .82446 L .54693 .82193 L F
.587 .827 .99 r
.67857 .69741 m .67961 .69835 L .68178 .69772 L F
.746 .601 .696 r
.52528 .85083 m .52649 .85457 L .52361 .85407 L F
.683 .569 .721 r
.52649 .85457 m .52322 .85638 L .52361 .85407 L F
.694 .56 .699 r
.52868 .85171 m .52649 .85457 L .52528 .85083 L F
.52868 .85171 m .5287 .85399 L .52649 .85457 L F
.427 .392 .717 r
.33532 .66738 m .33324 .66584 L .33495 .66553 L F
.709 .573 .699 r
.53091 .8513 m .5287 .85399 L .52868 .85171 L F
.438 .209 .467 r
.531 .85389 m .5287 .85399 L .53091 .8513 L F
.596 .526 .746 r
.53271 .84898 m .53312 .85096 L .53091 .8513 L F
.698 .408 .48 r
.53091 .8513 m .53341 .85365 L .531 .85389 L F
.577 .424 .637 r
.53312 .85096 m .53341 .85365 L .53091 .8513 L F
.317 .784 .667 r
.35295 .79487 m .3538 .79444 L .35563 .7937 L F
.415 .85 .729 r
.35563 .7937 m .35581 .79339 L .35759 .79324 L F
.35563 .7937 m .3538 .79444 L .35581 .79339 L F
.678 .637 .802 r
.49222 .87599 m .49432 .87521 L .49319 .87151 L F
.554 .312 .503 r
.49435 .87723 m .49432 .87521 L .49222 .87599 L F
.453 .884 .868 r
.49222 .87599 m .49432 .87521 L .49435 .87723 L F
.6 .107 .056 r
.57845 .78273 m .58092 .78404 L .58201 .78291 L F
.715 .248 .141 r
.58092 .78404 m .58397 .78462 L .58201 .78291 L F
.535 .167 .289 r
.49399 .85945 m .49074 .86149 L .49068 .85952 L F
.49399 .85945 m .49292 .86158 L .49074 .86149 L F
.654 .294 .349 r
.49635 .8613 m .49292 .86158 L .49399 .85945 L F
.359 0 0 r
.52726 .82866 m .53031 .82874 L .52871 .8282 L F
.396 .048 .254 r
.52871 .8282 m .53031 .82874 L .53107 .82757 L F
.478 .286 .541 r
.33162 .70478 m .33015 .70286 L .33209 .70202 L F
.33162 .70478 m .32994 .70534 L .33015 .70286 L F
.855 .573 .51 r
.54174 .81695 m .54215 .81963 L .54386 .8193 L F
.762 .261 .023 r
.54215 .81963 m .54549 .82193 L .54386 .8193 L F
.608 .792 .969 r
.57851 .80533 m .57904 .80643 L .58122 .80579 L F
.418 .774 .996 r
.69115 .75303 m .69435 .75358 L .6934 .75287 L F
.457 .795 .999 r
.69435 .75358 m .69668 .7533 L .6934 .75287 L F
.009 0 0 r
.65803 .72652 m .65979 .72594 L .66048 .72426 L F
0 0 .488 r
.66041 .72415 m .66024 .72363 L .6591 .72195 L F
.862 .784 .285 r
.65979 .72594 m .66006 .72308 L .66024 .72363 L F
0 .06 .625 r
.6591 .72195 m .66024 .72363 L .66013 .7223 L F
.862 .784 .285 r
.66006 .72308 m .66013 .7223 L .66024 .72363 L F
0 0 .488 r
.66048 .72426 m .66024 .72363 L .66041 .72415 L F
.912 .819 .353 r
.66048 .72426 m .65979 .72594 L .66024 .72363 L F
.316 .803 .875 r
.66188 .62571 m .66262 .62534 L .66328 .62556 L F
.754 .494 .54 r
.66262 .62534 m .6655 .62372 L .66328 .62556 L F
.66262 .62534 m .66512 .62647 L .6655 .62372 L F
.474 .643 .931 r
.66409 .62422 m .66512 .62647 L .66262 .62534 L F
.472 .234 .471 r
.66161 .62704 m .66349 .62491 L .66262 .62534 L F
.66349 .62491 m .66409 .62422 L .66262 .62534 L F
.316 .803 .875 r
.6603 .62588 m .66262 .62534 L .66188 .62571 L F
.821 .929 .904 r
.52105 .87082 m .51792 .8721 L .52038 .87133 L F
.706 .582 .714 r
.52745 .84865 m .52868 .85171 L .52528 .85083 L F
.902 .513 .274 r
.55075 .83182 m .55142 .83017 L .55031 .82946 L F
.55075 .83182 m .55153 .8324 L .55142 .83017 L F
0 0 0 r
.65527 .72765 m .65733 .72683 L .65803 .72652 L F
.514 .315 .549 r
.65733 .72683 m .65979 .72594 L .65803 .72652 L F
.575 .368 .563 r
.42499 .76029 m .42722 .75828 L .42516 .75861 L F
.887 .584 .468 r
.52394 .8511 m .52418 .85343 L .52528 .85083 L F
.07 0 .077 r
.52653 .85067 m .52745 .84865 L .52528 .85083 L F
.462 .112 .285 r
.52528 .85083 m .52641 .85286 L .52653 .85067 L F
.52528 .85083 m .52418 .85343 L .52641 .85286 L F
.631 .387 .531 r
.44361 .76071 m .4418 .76371 L .43952 .76365 L F
.581 .331 .502 r
.44514 .76068 m .4418 .76371 L .44361 .76071 L F
.585 .353 .531 r
.69622 .72402 m .69611 .7265 L .69398 .72635 L F
.45 .736 .989 r
.69829 .72378 m .69622 .72402 L .6949 .72304 L F
.473 .262 .511 r
.69829 .72378 m .69611 .7265 L .69622 .72402 L F
.57 .38 .584 r
.35075 .75869 m .35069 .76116 L .34848 .76135 L F
.368 .218 .542 r
.35215 .76046 m .35075 .75869 L .35241 .75819 L F
.35215 .76046 m .35069 .76116 L .35075 .75869 L F
.016 0 0 r
.3858 .79558 m .38177 .79685 L .38364 .79557 L F
.437 .338 .646 r
.3207 .68456 m .32237 .68388 L .32109 .68187 L F
.611 .513 .719 r
.32074 .68692 m .32237 .68388 L .3207 .68456 L F
.564 .549 .796 r
.69104 .7288 m .68925 .72951 L .68886 .72783 L F
.659 .578 .753 r
.69104 .7288 m .69037 .73142 L .68925 .72951 L F
.74 .549 .636 r
.59956 .80096 m .60286 .8035 L .60287 .80115 L F
.839 .889 .876 r
.47956 .83506 m .48344 .83325 L .48204 .8331 L F
.751 .955 .94 r
.48355 .83195 m .48204 .8331 L .48334 .83324 L F
.72 .328 .307 r
.48355 .83195 m .48039 .83161 L .48204 .8331 L F
.706 .62 .758 r
.4786 .83206 m .47956 .83506 L .48204 .8331 L F
.4786 .83206 m .48204 .8331 L .48039 .83161 L F
.72 .328 .307 r
.48355 .83195 m .48226 .83366 L .48039 .83161 L F
.853 .929 .546 r
.48355 .83195 m .48226 .83366 L .48375 .83068 L F
.562 .36 .565 r
.48597 .82926 m .48355 .83195 L .48381 .82931 L F
.439 .645 .945 r
.48311 .83074 m .48355 .83195 L .48383 .83051 L F
.853 .929 .546 r
.48355 .83195 m .48375 .83068 L .48383 .83051 L F
.751 .955 .94 r
.48355 .83195 m .48334 .83324 L .48344 .83325 L F
.412 .243 .539 r
.47691 .84326 m .47696 .83987 L .47567 .84095 L F
.47691 .84326 m .47914 .84073 L .47696 .83987 L F
.47691 .84326 m .47855 .84296 L .47914 .84073 L F
.463 .195 .421 r
.34034 .76606 m .33802 .76872 L .33862 .76663 L F
.865 .725 .706 r
.68195 .73713 m .68274 .73526 L .68105 .73425 L F
.317 .784 .667 r
.35295 .79487 m .35196 .79529 L .3538 .79444 L F
.708 .903 .965 r
.69668 .7533 m .6994 .75289 L .6985 .75222 L F
.812 .883 .896 r
.6985 .75222 m .6994 .75289 L .70206 .75084 L F
.762 .536 .59 r
.55737 .80892 m .56071 .81163 L .56071 .80916 L F
.423 .856 .934 r
.64082 .63924 m .64184 .63954 L .64198 .64172 L F
.64082 .63924 m .64383 .63895 L .64184 .63954 L F
.792 .648 .702 r
.64383 .63895 m .64198 .64172 L .64184 .63954 L F
.959 .751 .578 r
.50064 .86447 m .49944 .86468 L .49962 .86159 L F
.33 .683 .979 r
.59079 .8456 m .59137 .84484 L .58926 .84527 L F
.59079 .8456 m .59258 .84575 L .59137 .84484 L F
.603 .223 .296 r
.34848 .76135 m .34704 .76327 L .34502 .76305 L F
.55 .163 .26 r
.34999 .76274 m .34848 .76135 L .35069 .76116 L F
.34999 .76274 m .34704 .76327 L .34848 .76135 L F
0 .239 .702 r
.55489 .81864 m .55526 .81863 L .55281 .81703 L F
0 .096 .631 r
.55489 .81864 m .55709 .821 L .55526 .81863 L F
.753 .58 .662 r
.59627 .79824 m .59783 .80122 L .59956 .80096 L F
.751 .572 .653 r
.59783 .80122 m .59757 .80351 L .59956 .80096 L F
.73 .541 .637 r
.59757 .80351 m .59965 .80353 L .59956 .80096 L F
.74 .549 .636 r
.59956 .80096 m .59965 .80353 L .60286 .8035 L F
.465 .415 .717 r
.531 .85389 m .53108 .85627 L .5287 .85399 L F
.596 .609 .835 r
.69115 .75303 m .68888 .75289 L .68831 .75096 L F
.023 0 0 r
.68886 .75401 m .68888 .75289 L .69115 .75303 L F
.68886 .75401 m .68812 .75418 L .68888 .75289 L F
.756 .705 .804 r
.68831 .75096 m .68888 .75289 L .68569 .75335 L F
.572 .151 .203 r
.68888 .75289 m .68812 .75418 L .68569 .75335 L F
.216 .479 .891 r
.53762 .83145 m .53893 .83083 L .53747 .82969 L F
.479 0 0 r
.53747 .82969 m .53893 .83083 L .53599 .8302 L F
.927 .755 .65 r
.58341 .81658 m .58415 .82014 L .58233 .81961 L F
.557 .38 .597 r
.58355 .82133 m .58233 .81961 L .58415 .82014 L F
.905 .51 .25 r
.58415 .82014 m .58476 .82207 L .58355 .82133 L F
.78 .442 .414 r
.58792 .8222 m .58476 .82207 L .58415 .82014 L F
.049 0 .067 r
.52885 .84817 m .52745 .84865 L .52653 .85067 L F
.597 .859 .993 r
.59258 .84575 m .59563 .84579 L .59436 .8449 L F
.778 .897 .927 r
.59563 .84579 m .59725 .84316 L .59436 .8449 L F
.59563 .84579 m .59854 .84389 L .59725 .84316 L F
.458 .232 .482 r
.33643 .69721 m .33416 .69982 L .33458 .69777 L F
.716 .6 .725 r
.58387 .82772 m .5807 .82729 L .58159 .8257 L F
.573 .439 .661 r
.65563 .61546 m .65614 .61816 L .6537 .61832 L F
.535 .267 .455 r
.6537 .61832 m .65576 .61993 L .6538 .62076 L F
.65576 .61993 m .6537 .61832 L .65225 .61914 L F
.65576 .61993 m .65614 .61816 L .6537 .61832 L F
.573 .439 .661 r
.65563 .61546 m .65614 .61816 L .6537 .61832 L F
.535 .267 .455 r
.6537 .61832 m .65614 .61816 L .65576 .61993 L F
.589 .853 .994 r
.7074 .73829 m .71077 .73816 L .70959 .73745 L F
.807 .871 .895 r
.70959 .73745 m .71077 .73816 L .71138 .73574 L F
.855 .556 .481 r
.54338 .80659 m .54354 .80874 L .54204 .80784 L F
.42 .662 .961 r
.54422 .80545 m .54501 .80702 L .54338 .80659 L F
.674 .415 .521 r
.54501 .80702 m .54354 .80874 L .54338 .80659 L F
.047 0 0 r
.50525 .88833 m .50834 .88751 L .50757 .88831 L F
.165 0 0 r
.50757 .88831 m .50834 .88751 L .51037 .88697 L F
.733 .65 .767 r
.58118 .80368 m .57775 .80393 L .58 .80072 L F
.781 .545 .578 r
.58118 .80368 m .57851 .80533 L .57775 .80393 L F
.58118 .80368 m .58122 .80579 L .57851 .80533 L F
.716 .6 .725 r
.58387 .82772 m .58162 .8303 L .5807 .82729 L F
.45 .509 .828 r
.55786 .82188 m .55883 .81923 L .55709 .821 L F
.55786 .82188 m .55973 .82167 L .55883 .81923 L F
.691 .25 0 r
.55786 .82188 m .55852 .82312 L .55845 .82324 L F
.55852 .82312 m .55904 .82409 L .55845 .82324 L F
.99 .735 .437 r
.55845 .82324 m .55846 .82608 L .55775 .82328 L F
.164 0 0 r
.55845 .82324 m .55775 .82328 L .55841 .82331 L F
.55845 .82324 m .55841 .82331 L .56074 .82344 L F
.691 .25 0 r
.55786 .82188 m .55845 .82324 L .55973 .82167 L F
.504 0 0 r
.4767 .88162 m .47774 .88256 L .47552 .88143 L F
.4767 .88162 m .47881 .88314 L .47774 .88256 L F
.807 .63 .663 r
.60103 .80605 m .60418 .80649 L .60286 .8035 L F
.841 .636 .626 r
.60103 .80605 m .60377 .80869 L .60418 .80649 L F
.733 .666 .784 r
.48076 .84395 m .47986 .84628 L .48291 .84579 L F
.622 .281 .371 r
.47986 .84628 m .4818 .848 L .48291 .84579 L F
.289 .688 .973 r
.48291 .84579 m .48413 .8453 L .48076 .84395 L F
.48291 .84579 m .48536 .84625 L .48413 .8453 L F
.451 .102 .281 r
.48291 .84579 m .48401 .84744 L .48536 .84625 L F
.48291 .84579 m .4818 .848 L .48401 .84744 L F
.176 .102 .528 r
.5028 .86679 m .5017 .87006 L .50331 .86869 L F
.42 .45 .785 r
.5017 .87006 m .50412 .87143 L .50331 .86869 L F
.603 .719 .926 r
.31986 .65855 m .31787 .65903 L .31641 .65738 L F
.171 .447 .877 r
.47662 .86434 m .47548 .8651 L .47428 .8643 L F
.47662 .86434 m .47735 .86569 L .47548 .8651 L F
.218 .434 .857 r
.66156 .73041 m .6626 .7294 L .66035 .72948 L F
.886 .719 .669 r
.68158 .743 m .68045 .74002 L .6797 .74251 L F
.414 .042 .221 r
.36013 .75403 m .3599 .75508 L .35779 .75544 L F
.47 .091 .236 r
.36013 .75403 m .36199 .75476 L .3599 .75508 L F
.57 .305 .474 r
.43497 .76586 m .43422 .76886 L .43203 .76897 L F
.541 .313 .518 r
.43743 .7638 m .43735 .76556 L .43497 .76586 L F
.57 .321 .5 r
.43735 .76556 m .43422 .76886 L .43497 .76586 L F
.815 .6 .612 r
.57897 .79311 m .57618 .79284 L .57626 .79031 L F
.899 .708 .637 r
.57708 .79487 m .57618 .79284 L .57897 .79311 L F
.769 .604 .675 r
.57897 .79311 m .57867 .79567 L .57708 .79487 L F
.901 .709 .634 r
.55105 .83716 m .55332 .83561 L .55239 .83394 L F
.55105 .83716 m .55259 .83825 L .55332 .83561 L F
.796 .811 .864 r
.68974 .71701 m .68634 .71865 L .6895 .7193 L F
.723 .258 0 r
.47258 .84625 m .47235 .84892 L .47192 .84574 L F
.154 .312 .772 r
.47229 .84456 m .47238 .84476 L .47258 .84625 L F
.723 .258 0 r
.47258 .84625 m .47448 .84859 L .47293 .84883 L F
.47258 .84625 m .47416 .84847 L .47448 .84859 L F
.826 .968 .652 r
.47406 .84843 m .47307 .84995 L .47448 .84859 L F
.723 .258 0 r
.47416 .84847 m .47441 .84882 L .47448 .84859 L F
.154 .312 .772 r
.47419 .84838 m .47441 .84882 L .47416 .84847 L F
.47352 .84703 m .47419 .84838 L .47249 .84558 L F
.826 .968 .652 r
.47428 .8481 m .47406 .84843 L .47416 .84847 L F
.47431 .84817 m .47416 .84847 L .47448 .84859 L F
.622 .574 .78 r
.47485 .84723 m .47419 .84838 L .47229 .84456 L F
.826 .968 .652 r
.47428 .8481 m .47419 .84838 L .47431 .84817 L F
.47419 .84838 m .47416 .84847 L .47431 .84817 L F
.47485 .84723 m .47428 .8481 L .47448 .84859 L F
.622 .574 .78 r
.47485 .84723 m .47441 .84882 L .47419 .84838 L F
.676 .39 .48 r
.47307 .84995 m .47639 .84815 L .47448 .84859 L F
.47307 .84995 m .47648 .85104 L .47639 .84815 L F
.642 .51 .686 r
.47428 .8481 m .47551 .8504 L .47307 .84995 L F
.688 .717 .198 r
.47448 .84859 m .47441 .84882 L .47485 .84723 L F
.642 .51 .686 r
.47485 .84723 m .47535 .84962 L .47428 .8481 L F
.47535 .84962 m .47551 .8504 L .47428 .8481 L F
.154 .312 .772 r
.47249 .84558 m .47419 .84838 L .47258 .84625 L F
.47238 .84476 m .47352 .84703 L .47249 .84558 L F
.47419 .84838 m .47416 .84847 L .47258 .84625 L F
.723 .258 0 r
.47258 .84625 m .47293 .84883 L .47235 .84892 L F
.476 .258 .503 r
.5353 .83512 m .53762 .83145 L .53507 .83328 L F
.5353 .83512 m .53723 .83496 L .53762 .83145 L F
.216 .479 .891 r
.53762 .83145 m .53974 .83231 L .53893 .83083 L F
.506 .266 .485 r
.53723 .83496 m .53974 .83231 L .53762 .83145 L F
.645 .499 .67 r
.45385 .86467 m .45412 .86707 L .45618 .86446 L F
.631 .541 .734 r
.44209 .73697 m .44021 .73768 L .43918 .73494 L F
.499 .333 .586 r
.44209 .73697 m .44007 .74026 L .44021 .73768 L F
.792 .846 .892 r
.49946 .88555 m .4965 .88649 L .49878 .88624 L F
.075 0 0 r
.50142 .88502 m .50235 .88387 L .49946 .88555 L F
.897 .733 .67 r
.50028 .88749 m .49946 .88555 L .49878 .88624 L F
.50028 .88749 m .50142 .88502 L .49946 .88555 L F
.846 .911 .879 r
.66378 .73147 m .6648 .73218 L .66704 .7299 L F
0 .367 .833 r
.38213 .75179 m .38232 .75056 L .38051 .7501 L F
.38213 .75179 m .38388 .75263 L .38232 .75056 L F
.576 .409 .619 r
.4553 .8591 m .4574 .859 L .45737 .85656 L F
.47 .353 .637 r
.45582 .86202 m .4574 .859 L .4553 .8591 L F
.386 .397 .749 r
.45273 .87282 m .45352 .87506 L .45498 .87476 L F
.244 .312 .736 r
.45352 .87506 m .4552 .87645 L .45498 .87476 L F
.466 .127 .307 r
.42514 .77178 m .42432 .77378 L .42221 .77411 L F
.609 .335 .476 r
.42729 .7715 m .42432 .77378 L .42514 .77178 L F
.547 .299 .492 r
.43952 .76365 m .43735 .76556 L .43743 .7638 L F
.943 .881 .743 r
.66605 .72923 m .669 .72565 L .66806 .72611 L F
.66605 .72923 m .66704 .7299 L .669 .72565 L F
.74 .98 .747 r
.67068 .72343 m .66806 .72611 L .669 .72565 L F
.448 .39 .701 r
.32109 .68187 m .32207 .68158 L .32168 .67841 L F
.431 .336 .647 r
.32109 .68187 m .32237 .68388 L .32207 .68158 L F
.549 .884 .987 r
.6504 .72925 m .65266 .72937 L .65061 .72972 L F
.573 .186 .27 r
.65061 .72972 m .65263 .73076 L .65266 .72937 L F
.57 .44 .665 r
.65266 .72937 m .65437 .7308 L .65527 .72765 L F
.569 .035 0 r
.65263 .73076 m .65437 .7308 L .65266 .72937 L F
.429 .359 .677 r
.49097 .82396 m .49117 .8251 L .48918 .82492 L F
.48918 .82492 m .49117 .8251 L .49097 .82396 L F
.076 0 0 r
.35744 .80809 m .36101 .80633 L .35952 .80724 L F
.002 0 0 r
.35952 .80724 m .36101 .80633 L .36288 .80579 L F
.701 .49 .599 r
.40702 .76637 m .4096 .76813 L .41029 .76645 L F
.532 .21 .367 r
.4096 .76813 m .41245 .76647 L .41029 .76645 L F
.468 0 0 r
.51274 .87387 m .51424 .87438 L .51256 .87358 L F
.459 0 0 r
.51574 .87527 m .51424 .87438 L .51274 .87387 L F
.469 .641 .932 r
.50412 .87143 m .50502 .87296 L .50611 .87146 L F
.393 .534 .879 r
.50611 .87146 m .50502 .87296 L .50747 .87346 L F
.434 0 0 r
.40994 .74231 m .40658 .74334 L .40782 .74242 L F
.079 0 0 r
.3957 .77496 m .39449 .77622 L .39743 .77426 L F
.792 .648 .702 r
.64383 .63895 m .64516 .64215 L .64198 .64172 L F
.803 .612 .643 r
.64516 .64215 m .64192 .64405 L .64198 .64172 L F
.64516 .64215 m .64511 .64467 L .64192 .64405 L F
.359 .748 .987 r
.48758 .84606 m .4884 .84674 L .48536 .84625 L F
.491 .823 .999 r
.49075 .84649 m .4884 .84674 L .48758 .84606 L F
.434 .227 .497 r
.32797 .70797 m .32605 .70964 L .32692 .70833 L F
.758 .389 .356 r
.54174 .81695 m .54084 .81707 L .53889 .81676 L F
.967 .653 .366 r
.54083 .81863 m .54174 .81695 L .53889 .81676 L F
.54083 .81863 m .54215 .81963 L .54174 .81695 L F
.608 .229 .3 r
.50852 .85593 m .51128 .85587 L .50934 .8543 L F
.545 .259 .431 r
.50934 .8543 m .51128 .85587 L .51155 .85404 L F
.585 .787 .976 r
.43042 .73286 m .42722 .73231 L .42932 .73145 L F
.534 .727 .963 r
.43126 .73133 m .43042 .73286 L .42932 .73145 L F
.43126 .73133 m .43244 .73256 L .43042 .73286 L F
.984 .882 .648 r
.52321 .86115 m .52488 .85951 L .52475 .85871 L F
.52321 .86115 m .5243 .86174 L .52488 .85951 L F
.934 .643 .465 r
.50302 .88228 m .5042 .88046 L .50314 .87988 L F
.50302 .88228 m .50443 .88221 L .5042 .88046 L F
.702 .908 .968 r
.5062 .87889 m .5042 .88046 L .50314 .87988 L F
.464 .384 .681 r
.5042 .88046 m .50652 .88328 L .5062 .87889 L F
.934 .643 .465 r
.5042 .88046 m .50302 .88228 L .50314 .87988 L F
.5042 .88046 m .50443 .88221 L .50302 .88228 L F
.655 .798 .951 r
.43918 .73494 m .43588 .73461 L .43795 .73402 L F
.547 .737 .964 r
.44009 .7334 m .43918 .73494 L .43795 .73402 L F
.44009 .7334 m .44126 .7346 L .43918 .73494 L F
.631 .541 .734 r
.44209 .73697 m .43918 .73494 L .44126 .7346 L F
.662 .584 .757 r
.69864 .73941 m .69532 .73682 L .69616 .73698 L F
.932 .94 .592 r
.6504 .72925 m .6495 .73124 L .65061 .72972 L F
.573 .186 .27 r
.65061 .72972 m .6495 .73124 L .65263 .73076 L F
.386 .643 .958 r
.45955 .87901 m .46079 .87796 L .45821 .87771 L F
.45955 .87901 m .4618 .87953 L .46079 .87796 L F
0 .047 .589 r
.31884 .67655 m .31825 .67362 L .31798 .67375 L F
0 .441 .84 r
.31928 .67564 m .31947 .67566 L .31945 .67564 L F
0 .047 .589 r
.31866 .67564 m .31928 .67564 L .31825 .67362 L F
.742 .419 .435 r
.31825 .67362 m .31928 .67564 L .31674 .67541 L F
0 .441 .84 r
.31928 .67564 m .31945 .67564 L .31865 .67495 L F
0 .047 .589 r
.31884 .67655 m .31928 .67564 L .31866 .67564 L F
.453 .168 .389 r
.65063 .64219 m .6503 .6438 L .64838 .64421 L F
.483 .186 .384 r
.65063 .64219 m .65237 .64335 L .6503 .6438 L F
.65063 .64219 m .65288 .64179 L .65237 .64335 L F
.781 .863 .911 r
.49117 .8251 m .49467 .82483 L .49352 .82461 L F
.462 .871 .953 r
.49467 .82483 m .49352 .82461 L .4956 .82403 L F
.49467 .82483 m .49352 .82461 L .4956 .82403 L F
.863 .423 .15 r
.66561 .71109 m .66499 .71204 L .66617 .71238 L F
.779 .634 .7 r
.66617 .71238 m .6685 .7105 L .66561 .71109 L F
.187 0 0 r
.41328 .74281 m .41198 .74268 L .40994 .74231 L F
.116 0 0 r
.41328 .74281 m .41411 .74295 L .41198 .74268 L F
.41328 .74281 m .41559 .74318 L .41411 .74295 L F
.401 .272 .589 r
.45273 .87282 m .45462 .87324 L .45436 .86983 L F
.341 .39 .767 r
.45273 .87282 m .45498 .87476 L .45462 .87324 L F
.187 0 0 r
.37249 .7255 m .3746 .72524 L .37617 .72431 L F
.375 .156 .449 r
.37825 .72151 m .37617 .72431 L .37802 .72327 L F
.566 .202 .309 r
.3746 .72524 m .37802 .72327 L .37617 .72431 L F
.349 .371 .743 r
.4772 .87665 m .47559 .87803 L .47463 .87723 L F
.4772 .87665 m .47792 .87986 L .47559 .87803 L F
.299 0 .134 r
.39527 .78942 m .39579 .78857 L .39771 .78794 L F
.207 .667 .944 r
.692 .74375 m .69357 .74331 L .69059 .74292 L F
.692 .74375 m .69504 .7441 L .69357 .74331 L F
.643 .834 .974 r
.57094 .84769 m .57399 .84756 L .57285 .84602 L F
.76 .987 .898 r
.57399 .84756 m .57527 .84562 L .57285 .84602 L F
.57399 .84756 m .57625 .84586 L .57527 .84562 L F
.434 .227 .497 r
.32797 .70797 m .3259 .71073 L .32605 .70964 L F
.454 .124 .316 r
.4054 .78297 m .40494 .78436 L .40287 .78469 L F
.482 .154 .334 r
.40758 .78265 m .40494 .78436 L .4054 .78297 L F
.439 .349 .657 r
.63509 .73417 m .6368 .73399 L .63649 .73184 L F
.628 .496 .683 r
.63509 .73417 m .63777 .73707 L .6368 .73399 L F
.63509 .73417 m .6355 .73755 L .63777 .73707 L F
.535 .916 .934 r
.5084 .88245 m .50758 .88335 L .50652 .88328 L F
.383 .769 .99 r
.39172 .74469 m .39228 .74386 L .39024 .74442 L F
.39172 .74469 m .39361 .74452 L .39228 .74386 L F
.707 .304 .282 r
.55176 .81006 m .55403 .81139 L .55526 .81047 L F
0 .397 .81 r
.55526 .81047 m .55698 .81099 L .55726 .81142 L F
.311 0 0 r
.55403 .81139 m .55698 .81099 L .55526 .81047 L F
.967 .72 .51 r
.60499 .82743 m .60372 .82444 L .60371 .82673 L F
.896 .666 .582 r
.60284 .82954 m .60499 .82743 L .60371 .82673 L F
.60284 .82954 m .60509 .82982 L .60499 .82743 L F
0 .427 .717 r
.44532 .74974 m .44666 .75009 L .44813 .75056 L F
.037 .419 .864 r
.44855 .74982 m .44813 .75056 L .44666 .75009 L F
.44855 .74982 m .45014 .75158 L .44813 .75056 L F
.47 .353 .637 r
.45582 .86202 m .45761 .8618 L .4574 .859 L F
.547 .43 .672 r
.45582 .86202 m .45819 .8641 L .45761 .8618 L F
.45582 .86202 m .45618 .86446 L .45819 .8641 L F
.746 .56 .643 r
.59273 .79813 m .5943 .80097 L .59627 .79824 L F
.763 .584 .655 r
.5943 .80097 m .59783 .80122 L .59627 .79824 L F
.384 0 .125 r
.36492 .72826 m .36839 .72612 L .36559 .72738 L F
.36492 .72826 m .36692 .72797 L .36839 .72612 L F
.266 0 .048 r
.36839 .72612 m .36891 .72743 L .37046 .72577 L F
.36839 .72612 m .36692 .72797 L .36891 .72743 L F
.519 .876 .643 r
.3823 .8816 m .38047 .88307 L .38152 .88214 L F
.353 .334 .699 r
.38069 .88439 m .38152 .88214 L .38047 .88307 L F
.13 .245 .716 r
.52277 .83802 m .52284 .83474 L .52067 .83502 L F
.52277 .83802 m .52363 .83772 L .52284 .83474 L F
.516 .186 .346 r
.66554 .63368 m .6624 .63601 L .66257 .63452 L F
.507 .2 .38 r
.66257 .63452 m .6624 .63601 L .66017 .63625 L F
.882 .805 .768 r
.51458 .86185 m .51597 .85976 L .51437 .85857 L F
.569 .029 0 r
.51437 .85857 m .51597 .85976 L .51792 .86161 L F
.585 .185 .251 r
.50261 .84763 m .50135 .84885 L .49926 .84842 L F
.542 .475 .73 r
.50281 .84712 m .50462 .84877 L .50261 .84763 L F
0 0 0 r
.50322 .84784 m .50135 .84885 L .50261 .84763 L F
0 .281 .703 r
.50261 .84763 m .50462 .84877 L .50322 .84784 L F
.738 .531 .613 r
.59965 .80353 m .60103 .80605 L .60286 .8035 L F
.232 0 0 r
.51556 .85711 m .51679 .85716 L .51709 .85352 L F
.738 .715 .83 r
.51679 .85716 m .51907 .85301 L .51709 .85352 L F
.51679 .85716 m .5203 .85466 L .51907 .85301 L F
.834 .505 .43 r
.58495 .80661 m .58782 .80855 L .58659 .80801 L F
.357 .693 .982 r
.58782 .80855 m .58761 .80787 L .58659 .80801 L F
.58782 .80855 m .58985 .80888 L .58761 .80787 L F
.645 .658 .848 r
.59106 .8139 m .58934 .81501 L .58912 .81454 L F
.58993 .81326 m .58912 .81454 L .588 .81214 L F
.59106 .8139 m .58912 .81454 L .58993 .81326 L F
.95 .826 .688 r
.59138 .81098 m .59187 .81178 L .59194 .81062 L F
.681 .356 .419 r
.58908 .81504 m .5924 .81545 L .59174 .81451 L F
.645 .658 .848 r
.59106 .8139 m .588 .81214 L .58815 .81228 L F
.58962 .81319 m .58815 .81228 L .58862 .81269 L F
.59106 .8139 m .58815 .81228 L .58962 .81319 L F
.813 .607 .624 r
.58559 .81472 m .58868 .81273 L .58864 .81271 L F
.645 .658 .848 r
.58875 .81277 m .58862 .81269 L .58864 .81271 L F
.681 .356 .419 r
.58908 .81504 m .59034 .81364 L .58868 .81273 L F
.645 .658 .848 r
.58877 .81278 m .58868 .81273 L .58875 .81277 L F
.58868 .81273 m .58862 .81269 L .58875 .81277 L F
.813 .607 .624 r
.58559 .81472 m .58908 .81504 L .58868 .81273 L F
.58864 .81271 m .58868 .81273 L .58867 .81269 L F
.645 .658 .848 r
.59106 .8139 m .58862 .81269 L .58877 .81278 L F
.681 .356 .419 r
.5888 .81275 m .58883 .81272 L .58867 .81269 L F
.609 .048 0 r
.58883 .81272 m .58864 .81271 L .58867 .81269 L F
.95 .826 .688 r
.58909 .81273 m .59106 .8139 L .59147 .81282 L F
.681 .356 .419 r
.58868 .81273 m .5888 .81275 L .58867 .81269 L F
.5888 .81275 m .59079 .81314 L .58883 .81272 L F
.609 .048 0 r
.59079 .81314 m .58864 .81271 L .58883 .81272 L F
.95 .826 .688 r
.58892 .81263 m .58909 .81273 L .59187 .81178 L F
.58909 .81273 m .59147 .81282 L .59187 .81178 L F
.58864 .81271 m .58877 .81278 L .58892 .81263 L F
.58877 .81278 m .59106 .8139 L .58892 .81263 L F
.681 .356 .419 r
.59034 .81364 m .59174 .81451 L .59079 .81314 L F
.58908 .81504 m .59174 .81451 L .59034 .81364 L F
.59034 .81364 m .59079 .81314 L .58868 .81273 L F
.95 .826 .688 r
.58864 .81271 m .59065 .81213 L .59138 .81098 L F
.59065 .81213 m .59187 .81178 L .59138 .81098 L F
.623 .291 .387 r
.58985 .80888 m .58864 .81271 L .58782 .80855 L F
.58985 .80888 m .58864 .81271 L .58782 .80855 L F
.46 .034 .142 r
.55693 .78452 m .55363 .7863 L .55496 .78395 L F
0 0 .556 r
.47425 .87614 m .47303 .87452 L .47184 .87418 L F
.588 .655 .883 r
.47374 .87461 m .47425 .87614 L .47282 .87473 L F
.47531 .8744 m .47425 .87614 L .47374 .87461 L F
0 0 .556 r
.47425 .87614 m .47463 .87723 L .47457 .87714 L F
.47425 .87614 m .47457 .87714 L .47303 .87452 L F
.907 .733 .234 r
.55737 .80892 m .55698 .81099 L .55726 .81142 L F
.762 .536 .59 r
.55737 .80892 m .55726 .81142 L .56071 .81163 L F
.792 .494 .484 r
.57249 .82147 m .57626 .82176 L .57397 .82199 L F
.648 .61 .797 r
.57725 .82321 m .57397 .82199 L .57626 .82176 L F
.496 .288 .527 r
.3882 .74483 m .3859 .74774 L .38618 .74502 L F
.781 .728 .804 r
.69869 .74213 m .69744 .74446 L .69711 .7421 L F
.315 0 .118 r
.39401 .79183 m .39329 .79036 L .39527 .78942 L F
.39401 .79183 m .39206 .79229 L .39329 .79036 L F
.269 .384 .796 r
.65794 .72094 m .65834 .71888 L .65555 .72008 L F
.65794 .72094 m .6591 .72195 L .65834 .71888 L F
.578 .336 .514 r
.42221 .77411 m .41988 .77617 L .42017 .77447 L F
.634 .541 .731 r
.47094 .84366 m .47311 .84158 L .47031 .84078 L F
.47094 .84366 m .4734 .84386 L .47311 .84158 L F
.525 .421 .678 r
.46066 .84852 m .4624 .84533 L .46086 .84574 L F
0 0 0 r
.50443 .88221 m .50235 .88387 L .50142 .88502 L F
.415 .112 .34 r
.33305 .74262 m .33495 .74221 L .33565 .74053 L F
.667 .761 .277 r
.33565 .74053 m .33566 .74044 L .33748 .74003 L F
.661 .82 .96 r
.3322 .74175 m .33291 .74302 L .33152 .74207 L F
.413 .108 .335 r
.33291 .74302 m .33495 .74221 L .33305 .74262 L F
.661 .82 .96 r
.3322 .74175 m .33495 .74221 L .33291 .74302 L F
.679 .816 .949 r
.33352 .74123 m .33495 .74221 L .3322 .74175 L F
.636 .806 .965 r
.33566 .74044 m .33495 .74221 L .33352 .74123 L F
.601 .293 .419 r
.33207 .74331 m .33531 .74129 L .33352 .74123 L F
.667 .761 .277 r
.33565 .74053 m .33495 .74221 L .33558 .74064 L F
.601 .293 .419 r
.33531 .74129 m .3366 .74047 L .33554 .74073 L F
.33531 .74129 m .33554 .74073 L .33352 .74123 L F
.667 .761 .277 r
.33565 .74045 m .33558 .74064 L .33566 .74044 L F
.33565 .74053 m .33558 .74064 L .33565 .74045 L F
.825 .646 .66 r
.58873 .79 m .58671 .79265 L .58968 .79303 L F
.785 .593 .641 r
.58671 .79265 m .58972 .79533 L .58968 .79303 L F
0 0 0 r
.6685 .7105 m .66943 .71004 L .6711 .70803 L F
.66943 .71004 m .67317 .70819 L .6711 .70803 L F
.688 .748 .897 r
.64641 .73602 m .64893 .73521 L .64542 .73452 L F
.441 .52 .844 r
.34806 .67825 m .34685 .67973 L .34551 .67705 L F
.513 .525 .806 r
.34806 .67825 m .34743 .68158 L .34685 .67973 L F
.596 .402 .59 r
.37802 .72327 m .38027 .72111 L .37825 .72151 L F
0 0 .063 r
.64665 .62832 m .64701 .62792 L .64709 .6262 L F
.444 .54 .859 r
.34188 .6746 m .34086 .67627 L .33923 .6736 L F
.34188 .6746 m .34264 .6765 L .34086 .67627 L F
.834 .362 .027 r
.67551 .71015 m .67614 .70967 L .67317 .70819 L F
.454 .061 .203 r
.34661 .73642 m .35003 .73427 L .348 .73462 L F
.583 .369 .556 r
.44707 .75855 m .44689 .76048 L .44514 .76068 L F
.515 .262 .47 r
.44927 .75843 m .44689 .76048 L .44707 .75855 L F
.812 .883 .896 r
.6985 .75222 m .70206 .75084 L .70099 .75005 L F
.598 .232 .319 r
.47639 .84815 m .47858 .84835 L .47986 .84628 L F
.733 .665 .784 r
.47855 .84296 m .47986 .84628 L .48076 .84395 L F
.636 .275 .342 r
.47986 .84628 m .47858 .84835 L .4818 .848 L F
.77 .261 0 r
.5117 .87763 m .51509 .88051 L .51457 .88069 L F
0 0 0 r
.51457 .88069 m .51509 .88051 L .51664 .88035 L F
.97 .653 .335 r
.51548 .88323 m .51509 .88051 L .5142 .88161 L F
.596 .81 .982 r
.70278 .7049 m .70024 .70546 L .70165 .70388 L F
.57 .369 .568 r
.70278 .7049 m .70276 .70758 L .70024 .70546 L F
.981 .73 .478 r
.70276 .70758 m .70165 .70388 L .70024 .70546 L F
.903 .644 .138 r
.51029 .87174 m .51068 .87235 L .51007 .86946 L F
.468 0 0 r
.51274 .87387 m .51256 .87358 L .51068 .87235 L F
0 .199 .695 r
.51274 .87387 m .51068 .87235 L .51029 .87174 L F
.112 0 .124 r
.55325 .78177 m .55587 .77957 L .55367 .77962 L F
.55325 .78177 m .55503 .78179 L .55587 .77957 L F
.087 0 0 r
.55325 .78177 m .55213 .78326 L .55503 .78179 L F
.922 .704 .59 r
.70346 .74127 m .70505 .74005 L .70354 .73944 L F
.70346 .74127 m .70484 .74234 L .70505 .74005 L F
.792 .834 .883 r
.70354 .73944 m .70505 .74005 L .7074 .73829 L F
.447 .813 .995 r
.65174 .62792 m .65041 .6289 L .64952 .62766 L F
.65174 .62792 m .65284 .62863 L .65041 .6289 L F
.086 0 0 r
.52943 .83491 m .52629 .83524 L .5272 .83503 L F
.036 0 0 r
.66024 .71602 m .66244 .71505 L .66321 .71341 L F
0 0 0 r
.66321 .71341 m .66244 .71505 L .66499 .71204 L F
.911 .654 .536 r
.53812 .82454 m .53665 .82441 L .53827 .82214 L F
.665 .877 .506 r
.52218 .86448 m .5243 .86174 L .52321 .86115 L F
.52218 .86448 m .52233 .86444 L .5243 .86174 L F
.491 .27 .506 r
.52072 .83246 m .5229 .82987 L .52005 .83032 L F
.512 .489 .768 r
.33835 .67033 m .33745 .67386 L .33629 .67074 L F
.33835 .67033 m .33923 .6736 L .33745 .67386 L F
.593 .441 .645 r
.4574 .859 m .45947 .85623 L .45737 .85656 L F
.036 0 0 r
.36289 .79031 m .3632 .79106 L .36453 .7898 L F
.36289 .79031 m .36138 .79185 L .3632 .79106 L F
0 0 0 r
.36521 .7884 m .36289 .79031 L .36453 .7898 L F
.997 .84 .559 r
.48543 .87217 m .48396 .87457 L .48218 .87223 L F
.48543 .87217 m .4849 .87531 L .48396 .87457 L F
.701 .675 .821 r
.48765 .87064 m .48543 .87217 L .48413 .8696 L F
.841 .636 .626 r
.60103 .80605 m .60097 .80857 L .60377 .80869 L F
.81 .635 .665 r
.60067 .81076 m .60377 .80869 L .60097 .80857 L F
.60067 .81076 m .60241 .81161 L .60377 .80869 L F
.181 0 .283 r
.66024 .71602 m .66037 .71786 L .66244 .71505 L F
.541 .304 .504 r
.5438 .83546 m .54352 .83755 L .54148 .83764 L F
.55 .312 .506 r
.5457 .83541 m .54352 .83755 L .5438 .83546 L F
.835 .68 .69 r
.58604 .78696 m .58533 .78974 L .58873 .79 L F
.836 .664 .669 r
.58533 .78974 m .58671 .79265 L .58873 .79 L F
.871 .683 .645 r
.58368 .81427 m .58341 .81658 L .58209 .81319 L F
.222 .377 .808 r
.51039 .8749 m .5117 .87763 L .51294 .87688 L F
.192 .312 .758 r
.5117 .87763 m .51457 .88069 L .51294 .87688 L F
.54 .384 .618 r
.51537 .8513 m .51508 .85356 L .51643 .85132 L F
.784 .626 .685 r
.60295 .8193 m .60485 .81998 L .6031 .81678 L F
.871 .732 .706 r
.60273 .82151 m .60485 .81998 L .60295 .8193 L F
.60273 .82151 m .60422 .82206 L .60485 .81998 L F
.48 .139 .311 r
.389 .72394 m .3911 .72382 L .39205 .72168 L F
.603 .367 .532 r
.45181 .75596 m .45163 .75862 L .44927 .75843 L F
.543 .317 .522 r
.45373 .75812 m .45181 .75596 L .45428 .75505 L F
.45373 .75812 m .45163 .75862 L .45181 .75596 L F
.407 .334 .662 r
.68974 .71701 m .69043 .71629 L .68848 .71598 L F
.68974 .71701 m .69133 .71764 L .69043 .71629 L F
.292 .549 .922 r
.41429 .72759 m .41334 .72816 L .41182 .72651 L F
.41429 .72759 m .41521 .72887 L .41334 .72816 L F
.74 .679 .792 r
.69317 .73761 m .69398 .74049 L .69101 .73987 L F
.585 .584 .818 r
.69612 .7399 m .69398 .74049 L .69317 .73761 L F
.574 .527 .765 r
.69612 .7399 m .69711 .7421 L .69398 .74049 L F
.805 .844 .88 r
.47563 .85408 m .47898 .85381 L .47779 .85319 L F
.641 .081 0 r
.48024 .8546 m .47779 .85319 L .47898 .85381 L F
.452 .834 .988 r
.70278 .73198 m .70512 .73156 L .70603 .73207 L F
.822 .957 .902 r
.70603 .73207 m .70669 .73039 L .70834 .73154 L F
.70603 .73207 m .70512 .73156 L .70669 .73039 L F
.891 .928 .838 r
.58 .80072 m .57775 .80393 L .57697 .80272 L F
.454 .244 .504 r
.46353 .74495 m .46313 .7475 L .46525 .74482 L F
.46353 .74495 m .46313 .7475 L .46525 .74482 L F
.737 .582 .683 r
.71726 .72073 m .71802 .72412 L .71914 .72099 L F
.658 .421 .549 r
.64944 .71507 m .65173 .71339 L .6497 .71396 L F
.513 .525 .806 r
.34806 .67825 m .34924 .68134 L .34743 .68158 L F
.487 .374 .651 r
.34924 .68134 m .3478 .68439 L .34743 .68158 L F
.646 .642 .831 r
.69907 .72941 m .69765 .73135 L .69622 .72865 L F
.388 .087 .327 r
.36521 .7884 m .36453 .7898 L .3672 .78773 L F
.644 .64 .832 r
.4618 .87953 m .46281 .88097 L .46494 .88032 L F
.761 .581 .653 r
.59419 .80326 m .59783 .80122 L .5943 .80097 L F
.59419 .80326 m .59757 .80351 L .59783 .80122 L F
.746 .565 .65 r
.64331 .72845 m .643 .72391 L .64084 .72402 L F
.592 .653 .879 r
.50941 .88042 m .50646 .87882 L .50846 .87795 L F
.446 .51 .831 r
.51142 .8805 m .50941 .88042 L .50846 .87795 L F
.715 .655 .788 r
.57927 .82192 m .57725 .82321 L .57626 .82176 L F
.114 0 .067 r
.40553 .76957 m .40455 .77103 L .40698 .76885 L F
.921 .747 .65 r
.68065 .73707 m .68195 .73713 L .68105 .73425 L F
.911 .816 .74 r
.68045 .74002 m .68195 .73713 L .68065 .73707 L F
.346 .616 .951 r
.66438 .6109 m .66359 .61199 L .66205 .61152 L F
.66438 .6109 m .66545 .61219 L .66359 .61199 L F
.875 .499 .328 r
.54986 .81397 m .54689 .81107 L .55048 .81387 L F
.785 .3 .067 r
.54422 .80545 m .54753 .80785 L .54501 .80702 L F
.629 .8 .965 r
.35172 .70745 m .35342 .70868 L .35518 .70789 L F
.401 .036 .226 r
.35497 .73133 m .35675 .73165 L .35783 .72962 L F
.389 .003 .181 r
.35675 .73165 m .35987 .72939 L .35783 .72962 L F
.175 .302 .755 r
.49319 .87151 m .49432 .87521 L .49585 .8748 L F
.081 0 .401 r
.49585 .8748 m .49432 .87521 L .49435 .87723 L F
.525 .624 .892 r
.47674 .87293 m .47908 .8731 L .47904 .87302 L F
0 0 0 r
.47674 .87293 m .48007 .8723 L .47898 .87302 L F
.525 .624 .892 r
.47674 .87293 m .47904 .87302 L .47817 .87096 L F
.183 0 0 r
.47882 .87312 m .47908 .8731 L .47674 .87293 L F
0 0 0 r
.47674 .87293 m .47898 .87302 L .47882 .87312 L F
.37 0 0 r
.48007 .8723 m .48148 .87332 L .47882 .87312 L F
.48007 .8723 m .48218 .87223 L .48148 .87332 L F
.609 .394 .564 r
.41538 .76588 m .41761 .76582 L .41775 .7638 L F
.552 .327 .527 r
.41761 .76582 m .41996 .76356 L .41775 .7638 L F
.313 0 .219 r
.53325 .82509 m .53506 .82458 L .53588 .82474 L F
.229 .739 .881 r
.53588 .82474 m .53665 .82441 L .53812 .82454 L F
.804 .538 .536 r
.57867 .79567 m .57872 .79779 L .57708 .79487 L F
.469 0 0 r
.56248 .78318 m .56128 .78426 L .55913 .7841 L F
.41 0 0 r
.56452 .78382 m .56128 .78426 L .56248 .78318 L F
.499 .333 .586 r
.44209 .73697 m .44213 .73986 L .44007 .74026 L F
.454 .35 .647 r
.44213 .73986 m .44058 .74232 L .44007 .74026 L F
.846 .911 .879 r
.66378 .73147 m .66704 .7299 L .66605 .72923 L F
.925 .627 .459 r
.54627 .83448 m .54584 .83751 L .5457 .83541 L F
.54627 .83448 m .54777 .83834 L .54584 .83751 L F
.693 .182 .015 r
.65061 .7194 m .65035 .72097 L .6473 .71837 L F
.732 .226 .023 r
.65061 .7194 m .65256 .72126 L .65035 .72097 L F
.684 .314 .341 r
.65352 .72066 m .65256 .72126 L .65061 .7194 L F
.332 .099 .402 r
.45412 .86707 m .45574 .86699 L .45618 .86446 L F
.363 .375 .738 r
.45412 .86707 m .4564 .86953 L .45574 .86699 L F
.547 .412 .649 r
.45436 .86983 m .4564 .86953 L .45412 .86707 L F
.589 .705 .923 r
.4065 .72513 m .40314 .72395 L .40514 .72437 L F
.157 .666 .901 r
.40514 .72437 m .4083 .72489 L .4065 .72513 L F
0 0 .5 r
.48403 .87961 m .48459 .88033 L .48296 .87838 L F
.795 .376 0 r
.48513 .88216 m .48459 .88033 L .48403 .87961 L F
.384 0 0 r
.48463 .88185 m .48513 .88216 L .4841 .88152 L F
.795 .376 0 r
.48513 .88216 m .48593 .88303 L .48565 .88248 L F
.721 .913 .961 r
.48499 .88355 m .48593 .88303 L .48513 .88216 L F
.686 .641 .799 r
.487 .88328 m .48648 .88502 L .48513 .88216 L F
.384 0 0 r
.48646 .883 m .48513 .88216 L .48463 .88185 L F
.795 .376 0 r
.48513 .88216 m .48565 .88248 L .48459 .88033 L F
.681 .268 .255 r
.55726 .81142 m .55949 .81319 L .56071 .81163 L F
.653 .424 .559 r
.36826 .89356 m .36833 .89539 L .36888 .89321 L F
.36888 .89321 m .36833 .89539 L .36826 .89356 L F
.979 .793 .584 r
.36888 .89321 m .36833 .89539 L .36715 .89539 L F
.483 .26 .499 r
.36888 .89321 m .36833 .89539 L .37063 .89323 L F
.979 .793 .584 r
.36888 .89321 m .36833 .89539 L .36715 .89539 L F
.483 .26 .499 r
.37063 .89323 m .36833 .89539 L .36888 .89321 L F
0 0 .465 r
.49747 .85789 m .49641 .85646 L .49505 .85604 L F
.49747 .85789 m .49808 .85913 L .49641 .85646 L F
.559 .86 .997 r
.38584 .88544 m .38235 .88541 L .38389 .88627 L F
.961 .749 .302 r
.67381 .7347 m .67332 .73614 L .67306 .73395 L F
.67381 .7347 m .6738 .73696 L .67332 .73614 L F
.988 .895 .59 r
.55966 .82706 m .55826 .82663 L .55904 .82409 L F
.873 .562 .047 r
.55966 .82706 m .55972 .82892 L .55826 .82663 L F
.55966 .82706 m .56041 .83041 L .55972 .82892 L F
.516 .186 .346 r
.66554 .63368 m .66468 .63579 L .6624 .63601 L F
.574 .252 .386 r
.66772 .63358 m .66468 .63579 L .66554 .63368 L F
.398 .853 .882 r
.3662 .75192 m .36525 .75257 L .36705 .75177 L F
0 0 0 r
.3662 .75192 m .36472 .75304 L .36525 .75257 L F
.711 .268 .197 r
.48758 .84606 m .48413 .8453 L .48536 .84625 L F
.141 0 0 r
.48401 .84744 m .48758 .84606 L .48536 .84625 L F
.379 .742 .991 r
.48536 .84625 m .48758 .84606 L .48413 .8453 L F
.551 .216 .354 r
.38968 .77918 m .39198 .77918 L .3929 .77684 L F
.144 0 .093 r
.3929 .77684 m .39429 .77651 L .39449 .77622 L F
.416 .085 .294 r
.3929 .77684 m .39391 .77875 L .39429 .77651 L F
.3929 .77684 m .39198 .77918 L .39391 .77875 L F
0 0 0 r
.66943 .71004 m .67246 .70864 L .67317 .70819 L F
.834 .362 .027 r
.67551 .71015 m .67317 .70819 L .67319 .71067 L F
.553 .38 .601 r
.6886 .72773 m .68554 .72651 L .68784 .72701 L F
.837 .453 .323 r
.68522 .72571 m .68784 .72701 L .68554 .72651 L F
.68522 .72571 m .68587 .72723 L .68784 .72701 L F
.073 .496 .896 r
.68166 .72441 m .68522 .72571 L .68554 .72651 L F
.429 .475 .806 r
.68343 .723 m .68522 .72571 L .68166 .72441 L F
.544 .498 .755 r
.68571 .72262 m .68522 .72571 L .68343 .723 L F
.68571 .72262 m .68694 .72568 L .68522 .72571 L F
.837 .453 .323 r
.68587 .72723 m .68607 .72768 L .68645 .72754 L F
.68587 .72723 m .68645 .72754 L .68784 .72701 L F
.68607 .72768 m .68618 .72794 L .68631 .72787 L F
.532 .319 .536 r
.68694 .72568 m .68618 .72794 L .68522 .72571 L F
.506 .695 .954 r
.6837 .72607 m .68646 .72672 L .68459 .72473 L F
.68349 .72639 m .68451 .7265 L .6837 .72607 L F
.68451 .7265 m .68646 .72672 L .6837 .72607 L F
.837 .453 .323 r
.68607 .72768 m .68631 .72787 L .68784 .72701 L F
.538 .49 .75 r
.68432 .72836 m .68563 .72735 L .68349 .72639 L F
.68563 .72735 m .68646 .72672 L .68451 .7265 L F
.68563 .72735 m .68451 .7265 L .68349 .72639 L F
.982 .849 .635 r
.68784 .72701 m .68618 .72794 L .68682 .72604 L F
.68784 .72701 m .68682 .72604 L .68694 .72568 L F
.553 .38 .601 r
.68886 .72783 m .6886 .72773 L .68784 .72701 L F
.698 .852 .956 r
.69094 .72678 m .68886 .72783 L .68784 .72701 L F
.564 .549 .796 r
.69104 .7288 m .68886 .72783 L .69094 .72678 L F
.659 .578 .753 r
.69104 .7288 m .69165 .73279 L .69037 .73142 L F
.866 .431 .168 r
.69165 .73279 m .68878 .73258 L .69037 .73142 L F
.69165 .73279 m .69061 .73318 L .68878 .73258 L F
.69165 .73279 m .69234 .73427 L .69061 .73318 L F
.652 .573 .754 r
.69432 .72988 m .69165 .73279 L .69104 .7288 L F
.79 .592 .632 r
.64289 .63395 m .64553 .63636 L .64299 .63622 L F
.822 .734 .768 r
.64299 .63622 m .64553 .63636 L .64383 .63895 L F
.862 .642 .602 r
.57626 .79031 m .57415 .79221 L .57423 .78992 L F
.57626 .79031 m .57618 .79284 L .57415 .79221 L F
.775 .659 .735 r
.69398 .72635 m .69094 .72678 L .69271 .7259 L F
.694 .502 .624 r
.69398 .72635 m .69104 .7288 L .69094 .72678 L F
.69398 .72635 m .69432 .72988 L .69104 .7288 L F
.653 .472 .626 r
.69622 .72865 m .69398 .72635 L .69611 .7265 L F
.69622 .72865 m .69432 .72988 L .69398 .72635 L F
.419 .842 .958 r
.48175 .8836 m .4827 .88409 L .48499 .88355 L F
.53 .258 .447 r
.43163 .77077 m .42986 .76908 L .43203 .76897 L F
.43163 .77077 m .42945 .77109 L .42986 .76908 L F
.856 .892 .862 r
.59725 .84316 m .59854 .84389 L .59932 .84231 L F
.56 .226 .36 r
.6386 .73157 m .64096 .73163 L .64121 .72903 L F
0 0 0 r
.64356 .72878 m .64331 .72845 L .64121 .72903 L F
.307 .023 .308 r
.64121 .72903 m .64096 .73163 L .64356 .72878 L F
.136 0 0 r
.3695 .80304 m .36822 .80292 L .37005 .80243 L F
.3695 .80304 m .36766 .80369 L .36822 .80292 L F
.594 .215 .293 r
.38019 .72338 m .38241 .72357 L .38362 .72186 L F
.722 .217 .031 r
.38362 .72186 m .38432 .72302 L .38457 .72308 L F
.38472 .72244 m .38457 .72308 L .38708 .72367 L F
.38362 .72186 m .38457 .72308 L .38472 .72244 L F
.256 0 0 r
.38198 .72462 m .38405 .72421 L .38438 .7239 L F
.68 .848 .963 r
.38708 .72367 m .38432 .72302 L .3856 .72276 L F
.256 0 0 r
.38452 .72331 m .38438 .7239 L .3856 .72276 L F
.38198 .72462 m .38438 .7239 L .38452 .72331 L F
.539 .153 .258 r
.38362 .72186 m .3856 .72276 L .38432 .72302 L F
.38362 .72186 m .38241 .72357 L .3856 .72276 L F
.658 .369 .47 r
.64511 .64467 m .64838 .64421 L .64754 .64674 L F
.466 .198 .423 r
.64838 .64421 m .65005 .64633 L .64754 .64674 L F
.64838 .64421 m .6503 .6438 L .65005 .64633 L F
.452 .515 .832 r
.31798 .67375 m .31825 .67362 L .31789 .67356 L F
.779 .634 .7 r
.66617 .71238 m .6694 .71364 L .6685 .7105 L F
.798 .595 .627 r
.66896 .71584 m .6694 .71364 L .66617 .71238 L F
.078 0 .439 r
.66941 .71152 m .6685 .7105 L .6694 .71364 L F
.798 .595 .627 r
.66896 .71584 m .66617 .71238 L .66795 .71511 L F
.949 .951 .649 r
.66795 .71511 m .6694 .71364 L .66896 .71584 L F
.66795 .71511 m .66941 .71152 L .6694 .71364 L F
.841 .685 .689 r
.5806 .79852 m .58 .80072 L .57872 .79779 L F
.86 .768 .76 r
.70605 .72317 m .70915 .72142 L .7084 .72072 L F
.994 .76 .405 r
.7084 .72072 m .70912 .72127 L .7085 .71848 L F
.197 .057 .452 r
.7084 .72072 m .7085 .71848 L .71023 .71786 L F
.7084 .72072 m .71023 .71786 L .70946 .7196 L F
.558 .88 .991 r
.70764 .72014 m .7084 .72072 L .70946 .7196 L F
.70725 .72026 m .7084 .72072 L .70764 .72014 L F
.994 .76 .405 r
.7084 .72072 m .70915 .72142 L .70912 .72127 L F
.916 .662 .539 r
.71031 .72672 m .70921 .72778 L .70928 .72593 L F
.71031 .72672 m .70998 .7295 L .70921 .72778 L F
.556 .771 .978 r
.71164 .72537 m .71031 .72672 L .70928 .72593 L F
.71164 .72537 m .71255 .72633 L .71031 .72672 L F
.621 .421 .589 r
.71255 .72633 m .70998 .7295 L .71031 .72672 L F
.556 .83 .997 r
.37235 .7869 m .37042 .78755 L .3691 .78683 L F
.613 .824 .981 r
.57052 .81941 m .56486 .81886 L .56772 .81959 L F
.81 .739 .786 r
.56772 .81959 m .5684 .82206 L .57052 .81941 L F
.632 .446 .613 r
.5684 .82206 m .56842 .82443 L .57111 .82416 L F
.475 .097 .242 r
.69037 .73142 m .68878 .73258 L .68667 .73284 L F
.339 .637 .963 r
.70657 .72192 m .70355 .72186 L .70275 .72077 L F
.831 .935 .897 r
.4965 .88649 m .49428 .88849 L .49413 .88723 L F
.073 0 0 r
.49803 .88653 m .4965 .88649 L .49504 .88779 L F
.059 .318 .801 r
.49454 .88774 m .49428 .88849 L .49647 .89011 L F
.49418 .8877 m .49428 .88849 L .49454 .88774 L F
.782 .45 .426 r
.4921 .88918 m .49293 .88838 L .49529 .89007 L F
.49293 .88838 m .49329 .88803 L .49499 .88934 L F
.49329 .88803 m .49425 .88754 L .49499 .88934 L F
.327 0 .042 r
.4911 .88799 m .49331 .88743 L .49262 .88843 L F
.49331 .88743 m .49413 .88723 L .49329 .88803 L F
.49331 .88743 m .49329 .88803 L .4921 .88918 L F
.782 .45 .426 r
.49329 .88803 m .49413 .88723 L .49425 .88754 L F
.073 0 0 r
.49803 .88653 m .49504 .88779 L .49556 .88785 L F
.059 .318 .801 r
.49413 .88723 m .49418 .8877 L .49454 .88774 L F
.49413 .88723 m .49647 .89011 L .49583 .89009 L F
.49499 .88934 m .49583 .89009 L .49529 .89007 L F
.49413 .88723 m .49583 .89009 L .49499 .88934 L F
.831 .935 .897 r
.4965 .88649 m .49413 .88723 L .49414 .8883 L F
.4965 .88649 m .49414 .8883 L .49444 .88834 L F
.165 0 0 r
.49189 .88828 m .49413 .88723 L .4911 .88799 L F
.584 .655 .885 r
.49277 .88829 m .49286 .88829 L .49277 .8883 L F
.495 .057 .136 r
.49328 .88848 m .49261 .88838 L .49328 .88838 L F
.49328 .88848 m .49328 .88838 L .49624 .88838 L F
.49261 .88838 m .49189 .88828 L .49277 .8883 L F
.49261 .88838 m .49277 .8883 L .49624 .88838 L F
.49414 .8886 m .49414 .8883 L .49189 .88828 L F
.49414 .8883 m .49413 .88723 L .49189 .88828 L F
.584 .655 .885 r
.49279 .88812 m .49344 .8882 L .49286 .88829 L F
.49279 .88812 m .49286 .88829 L .49277 .88829 L F
.073 0 0 r
.49556 .88785 m .49504 .88779 L .49444 .88834 L F
.49487 .88821 m .49444 .88834 L .49414 .8886 L F
.49556 .88785 m .49444 .88834 L .49487 .88821 L F
.811 .669 .706 r
.49489 .88603 m .49803 .88653 L .49487 .88821 L F
.49489 .88603 m .49487 .88821 L .49438 .88777 L F
.49489 .88603 m .49438 .88777 L .49624 .88838 L F
.584 .655 .885 r
.49505 .88799 m .49519 .88804 L .49328 .88831 L F
.49581 .88795 m .49624 .88838 L .49442 .88834 L F
.49581 .88795 m .49442 .88834 L .49328 .88831 L F
.831 .935 .897 r
.49444 .88834 m .49414 .8883 L .49414 .8886 L F
.811 .669 .706 r
.49438 .88777 m .49487 .88821 L .49414 .8886 L F
.495 .057 .136 r
.49414 .8886 m .49328 .88848 L .49624 .88838 L F
.811 .669 .706 r
.49438 .88777 m .49414 .8886 L .49624 .88838 L F
.584 .655 .885 r
.49572 .88787 m .49581 .88795 L .49519 .88804 L F
.49572 .88787 m .49519 .88804 L .49505 .88799 L F
.49305 .88521 m .49572 .88787 L .49466 .88802 L F
.49341 .88688 m .49466 .88802 L .49369 .88817 L F
.49305 .88521 m .49466 .88802 L .49341 .88688 L F
.4934 .88791 m .49369 .88817 L .49344 .8882 L F
.49305 .88521 m .49369 .88817 L .4934 .88791 L F
.49305 .88521 m .49344 .8882 L .49279 .88812 L F
.49572 .88787 m .49328 .88831 L .49277 .8883 L F
.327 0 .042 r
.49163 .88861 m .49262 .88843 L .4921 .88918 L F
.4911 .88799 m .49262 .88843 L .49163 .88861 L F
.782 .45 .426 r
.49293 .88838 m .49499 .88934 L .49529 .89007 L F
.584 .655 .885 r
.49202 .88795 m .49277 .8883 L .49189 .88828 L F
.49305 .88521 m .49277 .8883 L .49202 .88795 L F
.314 .412 .802 r
.68358 .7196 m .68085 .71903 L .67978 .71851 L F
.68358 .7196 m .68336 .72066 L .68085 .71903 L F
.442 .291 .581 r
.45918 .85376 m .46092 .8509 L .45881 .85141 L F
.628 .933 .966 r
.5768 .84465 m .57625 .84586 L .5778 .84493 L F
.67 .967 .925 r
.57527 .84562 m .57625 .84586 L .5768 .84465 L F
.882 .805 .768 r
.51458 .86185 m .51437 .85857 L .51251 .86158 L F
.906 .709 .625 r
.51251 .86158 m .5139 .86425 L .51458 .86185 L F
0 0 .115 r
.38545 .88289 m .38445 .88488 L .38561 .88296 L F
.735 .964 .69 r
.3857 .883 m .38545 .88289 L .38623 .88193 L F
0 0 .115 r
.38545 .88289 m .38561 .88296 L .38623 .88193 L F
0 .316 .656 r
.385 .88271 m .38545 .88289 L .3857 .883 L F
.3823 .8816 m .38545 .88289 L .385 .88271 L F
.909 .855 .777 r
.38623 .88193 m .38584 .88544 L .3857 .883 L F
.333 0 0 r
.47792 .87986 m .48011 .87965 L .48154 .87849 L F
.162 0 0 r
.48218 .87915 m .48154 .87849 L .48011 .87965 L F
.48218 .87915 m .48296 .87838 L .48154 .87849 L F
.565 .34 .534 r
.4624 .84533 m .46494 .84302 L .46254 .8433 L F
.525 .421 .678 r
.46066 .84852 m .46307 .84836 L .4624 .84533 L F
.523 .362 .604 r
.46066 .84852 m .46308 .8505 L .46307 .84836 L F
.46066 .84852 m .46092 .8509 L .46308 .8505 L F
.776 .554 .599 r
.35172 .70745 m .35518 .70789 L .35528 .70545 L F
.687 .281 .271 r
.57342 .78166 m .57551 .78338 L .57676 .78196 L F
.532 .028 .003 r
.57551 .78338 m .57845 .78273 L .57676 .78196 L F
.43 .772 .997 r
.39698 .74485 m .39775 .74392 L .39575 .74406 L F
.39698 .74485 m .39906 .74469 L .39775 .74392 L F
.456 .188 .418 r
.41054 .77956 m .40953 .78228 L .40758 .78265 L F
.486 .205 .412 r
.41233 .77918 m .40953 .78228 L .41054 .77956 L F
0 .381 .705 r
.68569 .75335 m .68705 .75375 L .68454 .75284 L F
.68569 .75335 m .68812 .75418 L .68705 .75375 L F
.664 .536 .698 r
.47031 .84078 m .47311 .84158 L .47251 .8378 L F
.594 .36 .532 r
.54352 .83755 m .54116 .83997 L .54148 .83764 L F
.581 .331 .502 r
.44514 .76068 m .44411 .76362 L .4418 .76371 L F
.524 .273 .476 r
.44614 .76319 m .44514 .76068 L .44689 .76048 L F
.44614 .76319 m .44411 .76362 L .44514 .76068 L F
.537 .424 .673 r
.67625 .69783 m .67857 .69741 L .67848 .6952 L F
.517 .401 .661 r
.65614 .61816 m .65815 .61734 L .65563 .61546 L F
.65614 .61816 m .65815 .61734 L .65563 .61546 L F
.504 .56 .846 r
.57111 .82416 m .574 .82855 L .57509 .8271 L F
.546 .285 .471 r
.45618 .86446 m .45798 .86653 L .45819 .8641 L F
.45618 .86446 m .45574 .86699 L .45798 .86653 L F
0 .407 .725 r
.3856 .72276 m .389 .72394 L .38708 .72367 L F
.618 .538 .742 r
.32137 .68944 m .32293 .68723 L .32074 .68692 L F
.32137 .68944 m .32367 .68924 L .32293 .68723 L F
.614 .494 .693 r
.32139 .68961 m .32367 .68924 L .32137 .68944 L F
0 .532 .811 r
.31789 .67356 m .31825 .67362 L .31718 .67331 L F
.253 .764 .775 r
.5502 .84526 m .54825 .84577 L .55049 .84529 L F
.804 .686 .734 r
.54825 .84577 m .54921 .8485 L .55049 .84529 L F
.161 0 0 r
.41847 .74227 m .41774 .7428 L .41559 .74318 L F
.124 .672 .717 r
.42091 .74189 m .41954 .74208 L .41847 .74227 L F
0 0 0 r
.41954 .74208 m .41774 .7428 L .41847 .74227 L F
.14 0 0 r
.52064 .88125 m .52129 .88194 L .51912 .88163 L F
.52064 .88125 m .52286 .88053 L .52129 .88194 L F
.297 0 .044 r
.40282 .77178 m .40346 .77307 L .40455 .77103 L F
.40282 .77178 m .4015 .77348 L .40346 .77307 L F
.953 .674 .469 r
.67043 .71871 m .66915 .71811 L .66896 .71584 L F
.914 .675 .562 r
.67059 .72094 m .66915 .71811 L .67043 .71871 L F
.953 .674 .469 r
.67043 .71871 m .66915 .71811 L .66896 .71584 L F
.914 .675 .562 r
.66915 .71811 m .67059 .72094 L .67043 .71871 L F
.423 .856 .934 r
.64082 .63924 m .64316 .63862 L .64383 .63895 L F
.967 .697 .272 r
.64383 .63895 m .64316 .63862 L .64299 .63622 L F
.628 .767 .946 r
.45384 .7525 m .45014 .75158 L .45225 .75154 L F
.633 .639 .839 r
.45415 .75165 m .45399 .75255 L .45384 .7525 L F
.545 .451 .698 r
.45604 .75445 m .45399 .75255 L .45415 .75165 L F
.473 .467 .77 r
.45732 .75235 m .45604 .75445 L .45415 .75165 L F
.633 .639 .839 r
.45415 .75165 m .45384 .7525 L .4552 .75172 L F
.309 .712 .978 r
.4552 .75172 m .45384 .7525 L .45225 .75154 L F
.877 .756 .725 r
.58139 .81168 m .58237 .81147 L .58001 .81118 L F
.87 .851 .822 r
.58154 .81151 m .58237 .81147 L .58139 .81168 L F
.853 .677 .662 r
.58147 .81147 m .58131 .81143 L .58197 .81142 L F
.58131 .81143 m .58001 .81118 L .58111 .81131 L F
.58131 .81143 m .58111 .81131 L .58197 .81142 L F
.775 .745 .826 r
.5831 .80795 m .58146 .81153 L .58014 .80766 L F
.58146 .81153 m .58139 .81168 L .58131 .81143 L F
.58146 .81153 m .58131 .81143 L .58014 .80766 L F
.855 .784 .781 r
.58014 .80766 m .58131 .81143 L .58001 .81118 L F
.58131 .81143 m .58139 .81168 L .58001 .81118 L F
.853 .677 .662 r
.58042 .81157 m .58001 .81118 L .58147 .81147 L F
.58154 .81151 m .58197 .81142 L .58237 .81147 L F
.58042 .81157 m .58197 .81142 L .58154 .81151 L F
.87 .851 .822 r
.58494 .80767 m .58154 .81151 L .5831 .80795 L F
.58154 .81151 m .58139 .81168 L .58146 .81153 L F
.58154 .81151 m .58146 .81153 L .5831 .80795 L F
.58494 .80767 m .58237 .81147 L .58154 .81151 L F
.853 .677 .662 r
.58209 .81319 m .58042 .81157 L .58237 .81147 L F
.523 .368 .613 r
.32173 .69213 m .32367 .68924 L .32139 .68961 L F
.882 .706 .659 r
.60372 .82444 m .60422 .82206 L .60273 .82151 L F
.545 .451 .698 r
.45604 .75445 m .45428 .75505 L .45399 .75255 L F
.792 .834 .883 r
.70354 .73944 m .7074 .73829 L .70642 .73721 L F
.632 .824 .974 r
.70642 .73721 m .7074 .73829 L .70959 .73745 L F
.561 .225 .357 r
.35779 .75544 m .35678 .75771 L .35454 .75781 L F
.498 .177 .354 r
.3599 .75508 m .35678 .75771 L .35779 .75544 L F
.32 0 0 r
.7096 .73547 m .70846 .73607 L .71138 .73574 L F
.771 .709 .793 r
.648 .73246 m .65176 .73355 L .6495 .73124 L F
.648 .73246 m .64893 .73521 L .65176 .73355 L F
.235 .193 .605 r
.65176 .73355 m .65263 .73076 L .6495 .73124 L F
.65176 .73355 m .65299 .73392 L .65263 .73076 L F
.551 .621 .875 r
.37052 .89598 m .37289 .89684 L .3709 .8948 L F
.282 .328 .733 r
.37052 .89598 m .37183 .89794 L .3709 .8948 L F
.511 .894 .72 r
.576 .82641 m .57509 .8271 L .57497 .82733 L F
.918 .892 .789 r
.57572 .82935 m .576 .82641 L .57497 .82733 L F
.565 .523 .768 r
.44234 .74213 m .44118 .74547 L .44058 .74232 L F
.44234 .74213 m .44319 .74523 L .44118 .74547 L F
.63 .659 .86 r
.56976 .84536 m .57094 .84769 L .57285 .84602 L F
.481 .162 .348 r
.40287 .78469 m .40177 .78736 L .3997 .78767 L F
.536 .217 .374 r
.40433 .78586 m .40287 .78469 L .40494 .78436 L F
.40433 .78586 m .40177 .78736 L .40287 .78469 L F
0 .154 .692 r
.67516 .7397 m .67599 .73945 L .6738 .73696 L F
0 .228 .748 r
.67516 .7397 m .67696 .74154 L .67599 .73945 L F
0 0 0 r
.37815 .7852 m .37827 .78581 L .38006 .78474 L F
.37815 .7852 m .37647 .78647 L .37827 .78581 L F
.671 .453 .582 r
.5028 .86679 m .50637 .86626 L .50626 .8644 L F
.701 .618 .76 r
.50626 .8644 m .50792 .86438 L .50749 .8608 L F
.713 .5 .599 r
.50637 .86626 m .50792 .86438 L .50626 .8644 L F
.845 .562 .509 r
.58397 .78462 m .58604 .78696 L .58572 .78473 L F
.731 .722 .842 r
.48966 .87043 m .48927 .87286 L .48765 .87064 L F
.48966 .87043 m .49094 .87234 L .48927 .87286 L F
.925 .663 .522 r
.5486 .82672 m .55031 .82946 L .54974 .82747 L F
.395 .428 .777 r
.52126 .86417 m .5217 .86576 L .52067 .86366 L F
.52126 .86417 m .52067 .86366 L .52024 .8628 L F
.71 .173 0 r
.51792 .86161 m .5184 .86171 L .52126 .86417 L F
.5184 .86171 m .51901 .86183 L .52126 .86417 L F
.767 .359 .278 r
.49435 .87723 m .49745 .87797 L .49627 .87948 L F
.619 .176 .176 r
.49627 .87948 m .49745 .87797 L .49954 .87935 L F
.617 .483 .677 r
.49842 .87626 m .50049 .87786 L .49745 .87797 L F
.566 .255 .4 r
.49745 .87797 m .50049 .87786 L .49954 .87935 L F
.353 .334 .699 r
.38069 .88439 m .38235 .88541 L .38152 .88214 L F
.5 .291 .527 r
.65967 .61294 m .65994 .61188 L .65777 .61277 L F
.328 .516 .888 r
.65928 .61344 m .65967 .61294 L .65777 .61277 L F
.735 .747 .862 r
.6797 .74251 m .67959 .73958 L .67696 .74154 L F
.96 .898 .719 r
.68045 .74002 m .67959 .73958 L .6797 .74251 L F
.997 .86 .544 r
.67307 .72953 m .67198 .73086 L .6717 .72862 L F
.6726 .73163 m .67259 .73168 L .67198 .73086 L F
0 0 .465 r
.67198 .73086 m .67312 .73332 L .67294 .73207 L F
.67198 .73086 m .67294 .73207 L .67134 .73006 L F
.67198 .73086 m .67134 .73006 L .67126 .72995 L F
.997 .86 .544 r
.67307 .72953 m .6726 .73163 L .67198 .73086 L F
.78 .494 .502 r
.64511 .64467 m .64202 .64615 L .64192 .64405 L F
.64511 .64467 m .64525 .64665 L .64202 .64615 L F
.658 .369 .47 r
.64511 .64467 m .64754 .64674 L .64525 .64665 L F
.713 .523 .63 r
.59746 .80589 m .59965 .80353 L .59757 .80351 L F
.59746 .80589 m .60103 .80605 L .59965 .80353 L F
.713 .5 .599 r
.50637 .86626 m .50808 .8665 L .50792 .86438 L F
.679 .602 .762 r
.50749 .8608 m .50792 .86438 L .5103 .8619 L F
.763 .501 .538 r
.51214 .86752 m .50792 .86438 L .50808 .8665 L F
.944 .736 .592 r
.54825 .84577 m .54921 .8485 L .54784 .84804 L F
.939 .647 .461 r
.54921 .8485 m .54807 .8503 L .54784 .84804 L F
.944 .736 .592 r
.54825 .84577 m .54921 .8485 L .54784 .84804 L F
.939 .647 .461 r
.54921 .8485 m .54807 .8503 L .54784 .84804 L F
.454 .35 .647 r
.44213 .73986 m .44234 .74213 L .44058 .74232 L F
.375 .549 .898 r
.42659 .74383 m .42731 .74535 L .42832 .74406 L F
.355 .521 .883 r
.42731 .74535 m .42899 .74566 L .42832 .74406 L F
.832 .687 .703 r
.60045 .81632 m .6031 .81678 L .60189 .81378 L F
.835 .671 .68 r
.60295 .8193 m .6031 .81678 L .60045 .81632 L F
.513 .287 .508 r
.67219 .63294 m .67013 .63138 L .67226 .63083 L F
.67219 .63294 m .67 .63341 L .67013 .63138 L F
.577 .79 .98 r
.31404 .6576 m .31641 .65738 L .31441 .65787 L F
.589 .518 .742 r
.44342 .73387 m .44209 .73697 L .44126 .7346 L F
.44342 .73387 m .44424 .73672 L .44209 .73697 L F
.563 .381 .593 r
.44424 .73672 m .44213 .73986 L .44209 .73697 L F
.611 .513 .719 r
.32074 .68692 m .32293 .68723 L .32237 .68388 L F
.625 .316 .427 r
.41245 .76647 m .41444 .76831 L .41538 .76588 L F
.471 .122 .293 r
.41444 .76831 m .41761 .76582 L .41538 .76588 L F
.085 0 0 r
.37308 .80157 m .3755 .80033 L .37501 .80088 L F
.387 .105 .358 r
.3755 .80033 m .37807 .79809 L .37677 .79995 L F
0 0 0 r
.37501 .80088 m .3755 .80033 L .37677 .79995 L F
.329 0 .09 r
.48165 .82979 m .48311 .83074 L .48381 .82931 L F
.48165 .82979 m .48039 .83161 L .48311 .83074 L F
.48 .167 .358 r
.41482 .77739 m .41422 .77905 L .41233 .77918 L F
.409 .046 .233 r
.41711 .77728 m .41422 .77905 L .41482 .77739 L F
0 0 .326 r
.56174 .8379 m .56175 .83741 L .56081 .83475 L F
0 0 .475 r
.56174 .8379 m .56312 .84034 L .56175 .83741 L F
.538 .289 .485 r
.45574 .75761 m .45428 .75505 L .45604 .75445 L F
.45574 .75761 m .45373 .75812 L .45428 .75505 L F
.769 .358 .271 r
.58494 .80767 m .58122 .80579 L .58495 .80661 L F
.557 .403 .627 r
.58495 .80661 m .58659 .80801 L .58494 .80767 L F
.686 .721 .875 r
.57764 .81962 m .57927 .82192 L .57626 .82176 L F
.534 .624 .887 r
.57903 .82003 m .57927 .82192 L .57764 .81962 L F
.57903 .82003 m .58141 .82179 L .57927 .82192 L F
.646 .637 .826 r
.58205 .8227 m .57927 .82192 L .58141 .82179 L F
.593 .631 .859 r
.32703 .65961 m .32646 .66261 L .32504 .66007 L F
.32703 .65961 m .3286 .66213 L .32646 .66261 L F
.36 .821 .92 r
.58033 .81626 m .57818 .81676 L .5767 .81666 L F
.5767 .81666 m .57818 .81676 L .58033 .81626 L F
.303 .143 .491 r
.5353 .83512 m .5367 .83695 L .53723 .83496 L F
.5353 .83512 m .53517 .83771 L .5367 .83695 L F
.413 .012 .166 r
.34131 .73916 m .34478 .73697 L .3429 .73754 L F
.192 0 .014 r
.37677 .79995 m .37807 .79809 L .37985 .79744 L F
.301 0 0 r
.49151 .84239 m .49438 .84085 L .49272 .84087 L F
.611 .121 .065 r
.49531 .84239 m .49438 .84085 L .49362 .84213 L F
.49531 .84239 m .49752 .84256 L .49438 .84085 L F
.453 0 0 r
.49438 .84085 m .49752 .84256 L .49863 .84289 L F
.701 .49 .599 r
.40702 .76637 m .40698 .76885 L .4096 .76813 L F
.022 0 0 r
.69286 .75292 m .69115 .75303 L .6934 .75287 L F
.954 .744 .58 r
.67187 .72407 m .67034 .72569 L .67068 .72343 L F
.67187 .72407 m .67162 .72636 L .67034 .72569 L F
.899 .708 .637 r
.57708 .79487 m .57581 .79502 L .57618 .79284 L F
.84 .564 .52 r
.57872 .79779 m .57581 .79502 L .57708 .79487 L F
.491 .823 .999 r
.49075 .84649 m .48758 .84606 L .48918 .84509 L F
.617 .707 .909 r
.49264 .84549 m .49075 .84649 L .48918 .84509 L F
.565 .554 .8 r
.49075 .84649 m .49325 .84875 L .49264 .84549 L F
0 .139 .585 r
.6785 .71053 m .68148 .71268 L .68189 .71074 L F
.532 .27 .463 r
.66017 .63625 m .6621 .63779 L .66006 .63826 L F
.66017 .63625 m .6624 .63601 L .6621 .63779 L F
.774 .644 .718 r
.58979 .7979 m .59273 .79813 L .59309 .79565 L F
.776 .578 .631 r
.58979 .7979 m .59109 .80053 L .59273 .79813 L F
.768 .567 .626 r
.59109 .80053 m .5943 .80097 L .59273 .79813 L F
.534 0 0 r
.41521 .72887 m .41671 .72967 L .41868 .7298 L F
.776 .961 .927 r
.42046 .72868 m .41868 .7298 L .41918 .72823 L F
.746 .935 .949 r
.41868 .7298 m .41671 .72967 L .41918 .72823 L F
0 0 .436 r
.56926 .78752 m .56945 .78753 L .56777 .78464 L F
.907 .503 .211 r
.5706 .78784 m .56945 .78753 L .56926 .78752 L F
.078 0 .439 r
.66941 .71152 m .66943 .71004 L .6685 .7105 L F
.885 .952 .845 r
.42046 .72868 m .42138 .72563 L .41982 .72787 L F
.623 .687 .889 r
.41991 .72787 m .42046 .72868 L .41982 .72787 L F
.885 .952 .845 r
.42066 .72802 m .41999 .72772 L .42138 .72563 L F
.41991 .72787 m .4199 .72785 L .42066 .72802 L F
.4199 .72785 m .41972 .7276 L .41999 .72772 L F
.4199 .72785 m .41999 .72772 L .42066 .72802 L F
.678 .607 .769 r
.42138 .72563 m .42472 .7279 L .41989 .72787 L F
.42138 .72563 m .41989 .72787 L .41982 .72787 L F
.789 .311 .09 r
.42138 .72563 m .42472 .7279 L .41989 .72787 L F
.42138 .72563 m .41989 .72787 L .41982 .72787 L F
.885 .952 .845 r
.41999 .72772 m .41972 .7276 L .42138 .72563 L F
.42046 .72868 m .41991 .72787 L .42066 .72802 L F
.18 .703 .872 r
.41991 .72787 m .42472 .7279 L .42294 .72801 L F
.41982 .72787 m .41989 .72787 L .41991 .72787 L F
.41989 .72787 m .42472 .7279 L .41991 .72787 L F
.623 .687 .889 r
.42294 .72801 m .42046 .72868 L .41991 .72787 L F
.885 .952 .845 r
.42046 .72868 m .41918 .72823 L .41972 .7276 L F
.845 .71 .715 r
.60495 .83195 m .60509 .82982 L .60341 .83239 L F
.835 .685 .696 r
.60341 .83239 m .60463 .83547 L .60495 .83195 L F
.745 .339 .282 r
.56633 .82923 m .56957 .82948 L .56973 .82744 L F
.56633 .82923 m .56753 .83026 L .56957 .82948 L F
.56957 .82948 m .56753 .83026 L .56633 .82923 L F
.374 0 0 r
.56501 .83039 m .56685 .83073 L .56855 .82956 L F
.621 .932 .695 r
.56855 .82956 m .56685 .83073 L .56807 .82966 L F
.745 .339 .282 r
.56907 .82944 m .56633 .82923 L .56855 .82956 L F
.621 .932 .695 r
.56855 .82956 m .56807 .82966 L .56964 .8283 L F
.745 .339 .282 r
.56957 .82948 m .56907 .82944 L .56855 .82956 L F
.248 .601 .952 r
.57055 .82872 m .56957 .82948 L .56855 .82956 L F
.57055 .82872 m .57233 .82997 L .56957 .82948 L F
.232 .137 .536 r
.68336 .72066 m .68343 .723 L .68166 .72441 L F
.431 .663 .958 r
.42289 .74167 m .42385 .74287 L .42479 .74168 L F
.373 .577 .92 r
.42385 .74287 m .42659 .74383 L .42479 .74168 L F
.41 0 0 r
.68878 .73258 m .68554 .73189 L .68667 .73284 L F
.434 .227 .497 r
.32797 .70797 m .32758 .71012 L .3259 .71073 L F
.456 .25 .511 r
.32758 .71012 m .3256 .71293 L .3259 .71073 L F
.504 .496 .781 r
.56794 .8453 m .56915 .84249 L .56688 .84267 L F
.56794 .8453 m .56976 .84536 L .56915 .84249 L F
.781 .825 .353 r
.52218 .86448 m .52233 .86444 L .5217 .86576 L F
.5 0 0 r
.40224 .74495 m .4013 .74536 L .39906 .74469 L F
0 0 0 r
.40416 .74384 m .40339 .74459 L .40224 .74495 L F
.40339 .74459 m .4013 .74536 L .40224 .74495 L F
.715 .748 .878 r
.56048 .80061 m .55866 .80164 L .5573 .80026 L F
.5573 .80026 m .55866 .80164 L .56048 .80061 L F
.124 0 0 r
.50693 .87955 m .50646 .87882 L .5062 .87889 L F
.50693 .87955 m .50846 .87795 L .50646 .87882 L F
.774 .644 .718 r
.58979 .7979 m .59309 .79565 L .58972 .79533 L F
.763 .552 .612 r
.51128 .85587 m .51508 .85356 L .51155 .85404 L F
.51128 .85587 m .51556 .85711 L .51508 .85356 L F
.686 .566 .714 r
.51508 .85356 m .51709 .85352 L .51643 .85132 L F
.232 0 0 r
.51556 .85711 m .51709 .85352 L .51508 .85356 L F
.589 .041 0 r
.46939 .88192 m .46699 .87996 L .46872 .88182 L F
0 0 0 r
.52447 .87967 m .52758 .87727 L .52704 .8775 L F
.266 .062 .406 r
.52758 .87727 m .52773 .87632 L .52704 .8775 L F
.52758 .87727 m .52953 .87422 L .52773 .87632 L F
.532 .21 .367 r
.4096 .76813 m .41217 .7682 L .41245 .76647 L F
.644 .31 .391 r
.41217 .7682 m .41444 .76831 L .41245 .76647 L F
.33 .812 .875 r
.34998 .79573 m .3469 .79612 L .34855 .795 L F
.505 .824 1 r
.35196 .79529 m .34998 .79573 L .34855 .795 L F
.958 .718 .532 r
.49296 .84318 m .49264 .84549 L .49151 .84239 L F
.532 .288 .49 r
.65267 .71602 m .65173 .71339 L .65312 .71519 L F
.65267 .71602 m .65312 .71519 L .65275 .71581 L F
.389 .537 .883 r
.51886 .877 m .5178 .8778 L .51574 .87527 L F
.742 .694 .805 r
.64542 .73452 m .64893 .73521 L .648 .73246 L F
.78 .73 .806 r
.69869 .74213 m .69711 .7421 L .69864 .73941 L F
.575 .299 .46 r
.42499 .76029 m .42228 .76127 L .42198 .76317 L F
.595 .458 .666 r
.6473 .71837 m .64944 .71507 L .64805 .71633 L F
.627 .801 .966 r
.58355 .82133 m .58205 .8227 L .58141 .82179 L F
.58355 .82133 m .58476 .82207 L .58205 .8227 L F
.287 .474 .868 r
.50179 .87728 m .49842 .87626 L .49828 .8746 L F
.314 .462 .849 r
.50179 .87728 m .50049 .87786 L .49842 .87626 L F
.884 .555 .053 r
.68769 .73974 m .68874 .74271 L .6881 .74157 L F
.8 .344 .158 r
.69059 .74292 m .6881 .74157 L .68874 .74271 L F
.957 .669 .45 r
.48778 .84051 m .48906 .84304 L .48881 .84048 L F
.988 .792 .553 r
.66566 .62777 m .66666 .62865 L .66631 .62617 L F
.285 .66 .97 r
.66734 .62787 m .66666 .62865 L .66566 .62777 L F
.66734 .62787 m .66878 .62906 L .66666 .62865 L F
.071 0 .029 r
.38744 .79488 m .3858 .79558 L .38819 .79338 L F
.424 .041 .206 r
.38957 .79418 m .38819 .79338 L .39012 .79284 L F
.38957 .79418 m .38744 .79488 L .38819 .79338 L F
.35 .094 .377 r
.47251 .8378 m .47411 .83742 L .47468 .8355 L F
.254 .243 .653 r
.47251 .8378 m .47408 .83951 L .47411 .83742 L F
.47251 .8378 m .47311 .84158 L .47408 .83951 L F
.323 .432 .818 r
.52215 .85378 m .52322 .85638 L .52465 .85647 L F
.497 .499 .788 r
.58985 .80888 m .59095 .80532 L .58761 .80787 L F
.654 .322 .398 r
.58985 .80888 m .59194 .81062 L .59299 .8091 L F
.58985 .80888 m .58864 .81271 L .59194 .81062 L F
.59194 .81062 m .58864 .81271 L .58985 .80888 L F
.402 .594 .923 r
.56398 .8413 m .5652 .84022 L .56312 .84034 L F
.56398 .8413 m .56688 .84267 L .5652 .84022 L F
.525 .597 .869 r
.32387 .65794 m .32312 .66026 L .32193 .65837 L F
.32387 .65794 m .32504 .66007 L .32312 .66026 L F
.468 .127 .304 r
.354 .73337 m .35675 .73165 L .35497 .73133 L F
.83 .58 .561 r
.64289 .63395 m .63998 .63578 L .63959 .63331 L F
.64289 .63395 m .64299 .63622 L .63998 .63578 L F
.739 .399 .406 r
.5667 .77927 m .5686 .7815 L .57001 .77955 L F
.747 .409 .412 r
.5686 .7815 m .57201 .78206 L .57001 .77955 L F
.593 .654 .879 r
.4552 .87645 m .45628 .87812 L .45821 .87771 L F
.742 .419 .435 r
.31825 .67362 m .31674 .67541 L .31718 .67331 L F
.801 .655 .701 r
.58209 .81319 m .58341 .81658 L .58033 .81626 L F
.874 .718 .686 r
.58341 .81658 m .58052 .81871 L .58033 .81626 L F
.58341 .81658 m .58233 .81961 L .58052 .81871 L F
.337 .019 .27 r
.65527 .63966 m .6549 .64105 L .65288 .64179 L F
.488 .164 .344 r
.65751 .63926 m .6549 .64105 L .65527 .63966 L F
.532 .028 .003 r
.57551 .78338 m .5776 .78381 L .57845 .78273 L F
.599 .101 .042 r
.57845 .78273 m .5776 .78381 L .58092 .78404 L F
.55 .569 .826 r
.53401 .84756 m .53312 .85096 L .53271 .84898 L F
.53401 .84756 m .53519 .8507 L .53312 .85096 L F
.501 .368 .632 r
.53531 .85324 m .53312 .85096 L .53519 .8507 L F
.53531 .85324 m .53341 .85365 L .53312 .85096 L F
.175 .302 .755 r
.49319 .87151 m .49585 .8748 L .49636 .87229 L F
.708 .366 .397 r
.49828 .8746 m .49636 .87229 L .49585 .8748 L F
.349 .116 .413 r
.34512 .68911 m .34307 .69175 L .34354 .68971 L F
.613 .526 .732 r
.47311 .84158 m .4734 .84386 L .47567 .84095 L F
.452 .242 .503 r
.32917 .70967 m .32797 .70797 L .32978 .70746 L F
.32917 .70967 m .32758 .71012 L .32797 .70797 L F
.622 .742 .932 r
.58611 .8449 m .58722 .84593 L .58926 .84527 L F
.557 .547 .799 r
.44622 .74779 m .44431 .74834 L .44319 .74523 L F
.415 .36 .688 r
.44622 .74779 m .44532 .74974 L .44431 .74834 L F
.547 .299 .492 r
.43952 .76365 m .43931 .76566 L .43735 .76556 L F
.601 .346 .502 r
.43952 .76365 m .44152 .76559 L .43931 .76566 L F
.622 .343 .474 r
.4418 .76371 m .44152 .76559 L .43952 .76365 L F
.756 .571 .647 r
.59408 .80568 m .59757 .80351 L .59419 .80326 L F
.59408 .80568 m .59746 .80589 L .59757 .80351 L F
.43 .731 .989 r
.58271 .8436 m .58499 .84514 L .58611 .8449 L F
.463 .195 .421 r
.34034 .76606 m .33988 .76867 L .33802 .76872 L F
.406 .171 .441 r
.34287 .76323 m .34279 .76554 L .34034 .76606 L F
.474 .204 .424 r
.34178 .76815 m .34034 .76606 L .34279 .76554 L F
.34178 .76815 m .33988 .76867 L .34034 .76606 L F
.533 .424 .676 r
.50686 .85907 m .50852 .85593 L .50643 .85668 L F
.712 .611 .743 r
.56606 .82735 m .56973 .82744 L .56842 .82443 L F
.745 .339 .282 r
.56633 .82923 m .56973 .82744 L .56606 .82735 L F
.699 .638 .785 r
.56973 .82744 m .57111 .82416 L .56842 .82443 L F
.442 .291 .581 r
.45918 .85376 m .46095 .85355 L .46092 .8509 L F
.46 .397 .699 r
.45918 .85376 m .46144 .85582 L .46095 .85355 L F
.512 .4 .663 r
.45947 .85623 m .46144 .85582 L .45918 .85376 L F
.697 .753 .252 r
.37317 .89595 m .37289 .89684 L .37404 .89344 L F
.37317 .89595 m .37289 .89684 L .37404 .89344 L F
.886 .782 .741 r
.60341 .83239 m .60509 .82982 L .60284 .82954 L F
.878 .7 .657 r
.60299 .83477 m .60463 .83547 L .60341 .83239 L F
.868 .723 .7 r
.60393 .83742 m .60463 .83547 L .60299 .83477 L F
.835 .671 .68 r
.60295 .8193 m .60045 .81632 L .60027 .81868 L F
.891 .663 .587 r
.60033 .82101 m .60295 .8193 L .60027 .81868 L F
.60033 .82101 m .60273 .82151 L .60295 .8193 L F
.571 .289 .449 r
.51904 .84051 m .52093 .84201 L .52313 .83936 L F
.9 .702 .625 r
.57872 .79779 m .58 .80072 L .57846 .79977 L F
.891 .928 .838 r
.58 .80072 m .57697 .80272 L .57846 .79977 L F
.333 .053 .331 r
.65284 .62863 m .65495 .62788 L .65498 .62627 L F
.761 .582 .655 r
.65495 .62788 m .65845 .62595 L .65498 .62627 L F
.664 .644 .819 r
.42932 .73145 m .42722 .73231 L .42589 .72935 L F
.733 .665 .784 r
.47855 .84296 m .48076 .84395 L .48114 .84349 L F
.477 .49 .792 r
.48076 .84395 m .48268 .8423 L .48114 .84349 L F
.48076 .84395 m .48413 .8453 L .48268 .8423 L F
.328 .516 .888 r
.65928 .61344 m .66081 .61444 L .65967 .61294 L F
.722 .801 .914 r
.51448 .84548 m .51608 .84692 L .51763 .84593 L F
.073 0 0 r
.49803 .88653 m .49878 .88624 L .4965 .88649 L F
.497 .263 .489 r
.51643 .85132 m .51846 .85134 L .51857 .84923 L F
.288 .097 .439 r
.51857 .84923 m .52031 .84946 L .52087 .84926 L F
.51857 .84923 m .51846 .85134 L .52031 .84946 L F
.813 .87 .889 r
.69271 .7259 m .68994 .72596 L .69129 .72539 L F
.69271 .7259 m .69094 .72678 L .68994 .72596 L F
.845 .863 .856 r
.6949 .72304 m .69271 .7259 L .69129 .72539 L F
.659 .608 .786 r
.70278 .73198 m .70055 .73244 L .69907 .72941 L F
.487 .374 .651 r
.34924 .68134 m .34958 .68385 L .3478 .68439 L F
.373 .134 .418 r
.34905 .68576 m .3478 .68439 L .34958 .68385 L F
.34905 .68576 m .34735 .68636 L .3478 .68439 L F
.346 0 .117 r
.64196 .63132 m .64422 .63069 L .64535 .62929 L F
.792 .494 .484 r
.57249 .82147 m .57334 .82362 L .57626 .82176 L F
.838 .999 .82 r
.57626 .82176 m .5775 .81914 L .57764 .81962 L F
.57626 .82176 m .57334 .82362 L .5775 .81914 L F
.649 .687 .872 r
.51907 .85301 m .5203 .85466 L .52215 .85378 L F
.523 .368 .613 r
.32173 .69213 m .32369 .69135 L .32367 .68924 L F
.455 .327 .616 r
.32206 .69464 m .32369 .69135 L .32173 .69213 L F
.134 0 .114 r
.34307 .69175 m .34062 .69413 L .34147 .69268 L F
.473 .232 .468 r
.3471 .68863 m .3456 .68702 L .34735 .68636 L F
.3471 .68863 m .34512 .68911 L .3456 .68702 L F
.761 .495 .531 r
.47468 .8355 m .47734 .83764 L .47661 .83491 L F
.47468 .8355 m .47411 .83742 L .47734 .83764 L F
.875 .499 .328 r
.54986 .81397 m .54848 .814 L .54689 .81107 L F
.775 .281 0 r
.54986 .81397 m .55058 .81578 L .54848 .814 L F
.54986 .81397 m .55171 .81653 L .55058 .81578 L F
.73 .667 .788 r
.49264 .84549 m .49325 .84875 L .49584 .84629 L F
0 0 .565 r
.49317 .84745 m .49414 .85072 L .49325 .84875 L F
0 0 .378 r
.49317 .84745 m .49325 .84875 L .49264 .84549 L F
.774 .734 .816 r
.65013 .60667 m .64924 .61015 L .6479 .60936 L F
.65013 .60667 m .65117 .60802 L .64924 .61015 L F
.911 .718 .628 r
.64924 .61015 m .64923 .61246 L .6479 .60936 L F
.497 .378 .647 r
.64924 .61015 m .65111 .61153 L .64923 .61246 L F
.682 .58 .735 r
.65117 .60802 m .65178 .61037 L .64924 .61015 L F
.655 .307 .372 r
.64924 .61015 m .65178 .61037 L .65111 .61153 L F
.497 .378 .647 r
.64924 .61015 m .65111 .61153 L .64923 .61246 L F
.644 .566 .752 r
.50894 .841 m .5092 .84274 L .511 .84029 L F
.531 .413 .663 r
.5092 .84274 m .51122 .8426 L .511 .84029 L F
.016 0 0 r
.3858 .79558 m .38658 .79569 L .38177 .79685 L F
.029 0 0 r
.38598 .79582 m .38658 .79569 L .3858 .79558 L F
.38598 .79582 m .3858 .79558 L .38744 .79488 L F
.563 .492 .734 r
.51643 .85132 m .51709 .85352 L .51907 .85301 L F
.577 .604 .843 r
.42589 .72935 m .42389 .72997 L .42294 .72801 L F
.619 .662 .869 r
.43795 .73402 m .43588 .73461 L .43481 .73242 L F
0 0 0 r
.50443 .88221 m .50297 .88357 L .50218 .88486 L F
.50297 .88357 m .50142 .88502 L .50218 .88486 L F
.035 .139 .643 r
.50142 .88502 m .50296 .88703 L .50218 .88486 L F
.951 .624 .367 r
.50218 .88486 m .50296 .88703 L .50187 .88538 L F
.50218 .88486 m .50187 .88538 L .50148 .88479 L F
0 0 0 r
.50443 .88221 m .50218 .88486 L .50302 .88228 L F
.644 .13 .005 r
.5047 .88373 m .50443 .88221 L .50302 .88228 L F
.5047 .88373 m .50652 .88328 L .50443 .88221 L F
.323 0 0 r
.46939 .88192 m .47373 .88198 L .47206 .88191 L F
.346 .822 .875 r
.47206 .88191 m .47373 .88198 L .47552 .88143 L F
.505 .501 .786 r
.51643 .85132 m .51907 .85301 L .51846 .85134 L F
.911 .816 .74 r
.68045 .74002 m .68065 .73707 L .67959 .73958 L F
.817 .63 .649 r
.63951 .63928 m .6355 .64106 L .638 .63875 L F
.63951 .63928 m .63864 .64147 L .6355 .64106 L F
.235 .708 .94 r
.638 .63875 m .64082 .63924 L .63951 .63928 L F
.638 .63875 m .64082 .63924 L .63951 .63928 L F
.742 .357 .324 r
.58122 .80579 m .58014 .80766 L .57851 .80533 L F
.751 .368 .329 r
.58122 .80579 m .5831 .80795 L .58014 .80766 L F
.769 .358 .271 r
.58494 .80767 m .5831 .80795 L .58122 .80579 L F
.475 .264 .513 r
.33416 .69982 m .33392 .70184 L .33209 .70202 L F
.44 .25 .525 r
.33311 .70404 m .33209 .70202 L .33392 .70184 L F
.33311 .70404 m .33162 .70478 L .33209 .70202 L F
.555 .336 .537 r
.35215 .76046 m .34999 .76274 L .35069 .76116 L F
.044 0 0 r
.4735 .87028 m .47281 .87154 L .47108 .87195 L F
.309 .27 .652 r
.47281 .87154 m .47184 .87418 L .47108 .87195 L F
0 .262 .687 r
.55218 .81017 m .55176 .81006 L .55028 .80937 L F
.55218 .81017 m .55403 .81139 L .55176 .81006 L F
.402 .096 .327 r
.53315 .83839 m .53573 .83918 L .53517 .83771 L F
.917 .723 .624 r
.56514 .82651 m .56633 .82923 L .56606 .82735 L F
.491 .27 .506 r
.52072 .83246 m .52232 .83224 L .5229 .82987 L F
.282 .08 .418 r
.5229 .82987 m .52447 .83117 L .52495 .82909 L F
.5229 .82987 m .52232 .83224 L .52447 .83117 L F
.587 .827 .99 r
.67857 .69741 m .68178 .69772 L .68065 .6964 L F
.724 .777 .895 r
.68065 .6964 m .68178 .69772 L .68387 .69656 L F
.737 .829 .922 r
.46079 .87796 m .4618 .87953 L .46401 .87775 L F
.644 .64 .832 r
.4618 .87953 m .46494 .88032 L .46401 .87775 L F
.415 .36 .688 r
.44622 .74779 m .44666 .75009 L .44532 .74974 L F
.449 0 0 r
.55281 .81703 m .55412 .81803 L .55171 .81653 L F
.55281 .81703 m .55526 .81863 L .55412 .81803 L F
0 .528 .793 r
.39988 .72319 m .40175 .72353 L .40314 .72395 L F
.091 .605 .887 r
.40175 .72353 m .40514 .72437 L .40314 .72395 L F
.018 0 0 r
.34793 .81225 m .3478 .81198 L .34651 .81258 L F
.34793 .81225 m .34935 .8112 L .34988 .81089 L F
.34808 .81214 m .34988 .81089 L .3478 .81198 L F
0 0 0 r
.34988 .81089 m .35096 .81077 L .3478 .81198 L F
.3478 .81198 m .3489 .81158 L .34765 .81189 L F
.3478 .81198 m .34765 .81189 L .34704 .81204 L F
.018 0 0 r
.34793 .81225 m .34808 .81214 L .3478 .81198 L F
.793 .666 .723 r
.66864 .61468 m .66979 .61793 L .66676 .61681 L F
.522 0 0 r
.66676 .61681 m .66932 .61776 L .66871 .61775 L F
.26 .348 .765 r
.67131 .61697 m .66979 .61793 L .66864 .61468 L F
.384 0 0 r
.66871 .61775 m .66513 .61715 L .66676 .61681 L F
.595 .087 0 r
.66411 .61592 m .665 .61689 L .66485 .61681 L F
.665 .61689 m .66542 .61735 L .66506 .61701 L F
.665 .61689 m .66506 .61701 L .66485 .61681 L F
.384 0 0 r
.66871 .61775 m .66731 .61782 L .66696 .61751 L F
.66871 .61775 m .66519 .61726 L .66513 .61715 L F
.567 .939 .869 r
.67032 .61637 m .66747 .61775 L .66871 .61775 L F
.66747 .61775 m .66731 .61782 L .66871 .61775 L F
0 0 0 r
.66902 .61711 m .6676 .61809 L .66731 .61782 L F
.6676 .61809 m .66706 .61846 L .66731 .61782 L F
.384 0 0 r
.66696 .61751 m .66731 .61782 L .66519 .61726 L F
.759 .382 .341 r
.66676 .61681 m .66542 .61735 L .66326 .615 L F
.159 .178 .63 r
.66408 .61697 m .66389 .61591 L .66542 .61735 L F
.921 .891 .784 r
.66603 .6171 m .66408 .61697 L .66542 .61735 L F
.66676 .61681 m .66408 .61697 L .66603 .6171 L F
.384 0 0 r
.66513 .61715 m .66519 .61726 L .66408 .61697 L F
.66513 .61715 m .66408 .61697 L .66494 .61692 L F
.66513 .61715 m .66494 .61692 L .66676 .61681 L F
.595 .087 0 r
.66326 .615 m .66411 .61592 L .66389 .61591 L F
.66411 .61592 m .66485 .61681 L .66389 .61591 L F
.522 0 0 r
.66932 .61776 m .66979 .61793 L .66871 .61775 L F
.471 .876 .953 r
.66871 .61775 m .66979 .61793 L .67131 .61697 L F
.603 .719 .926 r
.31986 .65855 m .31641 .65738 L .31827 .65739 L F
.457 .771 .997 r
.32038 .65741 m .31986 .65855 L .31827 .65739 L F
.32038 .65741 m .32193 .65837 L .31986 .65855 L F
.549 .284 .465 r
.34513 .76472 m .34287 .76323 L .34502 .76305 L F
.34513 .76472 m .34279 .76554 L .34287 .76323 L F
.841 .822 .83 r
.65299 .73392 m .65433 .73495 L .65666 .73241 L F
.549 .697 .937 r
.70275 .72077 m .70037 .72109 L .69969 .7195 L F
.551 .357 .572 r
.42722 .75828 m .4294 .75796 L .42943 .75565 L F
.589 .446 .655 r
.42943 .75565 m .43163 .75541 L .43133 .75305 L F
.642 .471 .636 r
.4294 .75796 m .43163 .75541 L .42943 .75565 L F
.701 .675 .821 r
.48765 .87064 m .48413 .8696 L .48674 .87069 L F
.674 .254 .239 r
.48674 .87069 m .48966 .87043 L .48765 .87064 L F
.515 .262 .47 r
.44927 .75843 m .44896 .76032 L .44689 .76048 L F
.494 .244 .464 r
.44927 .75843 m .45122 .76003 L .44896 .76032 L F
.572 .218 .33 r
.45163 .75862 m .45122 .76003 L .44927 .75843 L F
0 0 .186 r
.47914 .84073 m .47919 .84112 L .48078 .8401 L F
.47914 .84073 m .47855 .84296 L .47919 .84112 L F
.65 .212 .196 r
.38152 .88214 m .38545 .88289 L .3823 .8816 L F
.746 .642 .744 r
.47661 .83491 m .4786 .83206 L .4771 .83278 L F
.717 .324 .302 r
.52521 .84283 m .52906 .84342 L .52662 .84522 L F
.032 .434 .869 r
.52662 .84522 m .52735 .84491 L .52551 .84578 L F
.52662 .84522 m .52867 .84623 L .52735 .84491 L F
.575 .368 .563 r
.42499 .76029 m .42716 .76012 L .42722 .75828 L F
.584 .399 .596 r
.42716 .76012 m .4294 .75796 L .42722 .75828 L F
.165 0 0 r
.50757 .88831 m .51037 .88697 L .50955 .88771 L F
.446 .842 .639 r
.51037 .88697 m .51254 .88551 L .5119 .88587 L F
0 0 0 r
.51111 .88632 m .5119 .88587 L .51387 .88525 L F
.646 .957 .764 r
.50955 .88771 m .5119 .88587 L .51031 .88662 L F
0 0 0 r
.51031 .88662 m .5119 .88587 L .51111 .88632 L F
.446 .842 .639 r
.51254 .88551 m .51277 .88535 L .5119 .88587 L F
.575 .299 .46 r
.42499 .76029 m .42198 .76317 L .42411 .76284 L F
.496 .182 .364 r
.42411 .76284 m .42716 .76012 L .42499 .76029 L F
.318 .807 .84 r
.35759 .79324 m .3584 .79275 L .35959 .7927 L F
.35759 .79324 m .35581 .79339 L .3584 .79275 L F
.473 .42 .717 r
.32207 .68158 m .3232 .67807 L .32168 .67841 L F
.32207 .68158 m .32386 .68122 L .3232 .67807 L F
.513 .421 .689 r
.32237 .68388 m .32386 .68122 L .32207 .68158 L F
.571 .5 .736 r
.70998 .7295 m .71082 .73164 L .70834 .73154 L F
.072 .192 .685 r
.71007 .73352 m .70834 .73154 L .71082 .73164 L F
.304 0 0 r
.36891 .72743 m .37249 .7255 L .37046 .72577 L F
.248 0 .224 r
.38769 .77956 m .38527 .78193 L .38702 .78103 L F
.387 .049 .265 r
.38702 .78103 m .38968 .77918 L .38769 .77956 L F
.593 .441 .645 r
.4574 .859 m .45959 .85876 L .45947 .85623 L F
.543 .382 .613 r
.45761 .8618 m .45959 .85876 L .4574 .859 L F
.393 .519 .866 r
.50072 .86034 m .49962 .86159 L .49808 .85913 L F
.318 .404 .794 r
.50072 .86034 m .50244 .86382 L .49962 .86159 L F
.707 .745 .881 r
.59258 .84575 m .59355 .84278 L .59137 .84484 L F
.59258 .84575 m .59436 .8449 L .59355 .84278 L F
.751 .803 .894 r
.65724 .71781 m .65834 .71888 L .66037 .71786 L F
.65724 .71781 m .65834 .71888 L .66037 .71786 L F
.414 .491 .83 r
.65834 .71888 m .66069 .72018 L .66037 .71786 L F
.997 .832 .482 r
.66037 .71786 m .65991 .71882 L .65974 .71723 L F
.414 .491 .83 r
.65834 .71888 m .66022 .72071 L .66008 .71984 L F
.997 .832 .482 r
.65991 .71882 m .6594 .71987 L .6597 .71751 L F
.65991 .71882 m .6597 .71751 L .65974 .71723 L F
.414 .491 .83 r
.65834 .71888 m .6591 .72195 L .66022 .72071 L F
.66008 .71984 m .66022 .72071 L .66069 .72018 L F
0 .06 .625 r
.6591 .72195 m .66013 .7223 L .66069 .72018 L F
.296 0 0 r
.502 .88781 m .50525 .88833 L .50376 .88827 L F
.151 0 0 r
.50525 .88833 m .50546 .88874 L .50376 .88827 L F
.50525 .88833 m .50757 .88831 L .50546 .88874 L F
.292 .787 .77 r
.69179 .71933 m .69412 .71861 L .69179 .71906 L F
.707 .765 .898 r
.64341 .73558 m .64542 .73452 L .64224 .73409 L F
.613 .526 .732 r
.47311 .84158 m .47567 .84095 L .47408 .83951 L F
.648 .711 .893 r
.55526 .81863 m .55709 .821 L .55883 .81923 L F
.841 .822 .83 r
.65299 .73392 m .65666 .73241 L .65532 .73162 L F
.887 .946 .843 r
.65701 .7301 m .65666 .73241 L .65802 .73074 L F
.81 .884 .898 r
.65532 .73162 m .65666 .73241 L .65701 .7301 L F
.798 .762 .82 r
.69101 .73987 m .69193 .7363 L .69317 .73761 L F
.844 .634 .618 r
.50763 .8692 m .51007 .86946 L .50808 .8665 L F
.835 .559 .521 r
.51029 .87174 m .51007 .86946 L .50763 .8692 L F
.406 .153 .415 r
.51007 .86946 m .51214 .86752 L .51143 .86923 L F
.742 .493 .554 r
.51143 .86923 m .50808 .8665 L .51007 .86946 L F
.585 .623 .856 r
.53288 .85575 m .53198 .85899 L .53078 .85855 L F
.53288 .85575 m .53419 .85914 L .53198 .85899 L F
.385 .734 .991 r
.53198 .85899 m .53294 .85813 L .53078 .85855 L F
.53198 .85899 m .53419 .85914 L .53294 .85813 L F
.317 .21 .571 r
.45436 .86983 m .45592 .87132 L .4564 .86953 L F
.45436 .86983 m .45462 .87324 L .45592 .87132 L F
.678 .608 .77 r
.69576 .75004 m .69668 .7533 L .6985 .75222 L F
.005 .424 .86 r
.53761 .85828 m .53768 .85904 L .53806 .85874 L F
.264 .761 .896 r
.53806 .85874 m .53768 .85904 L .53769 .85878 L F
.498 .793 .998 r
.53294 .85813 m .53419 .85914 L .53288 .85575 L F
.53768 .85869 m .53769 .85878 L .53419 .85914 L F
.626 .402 .558 r
.53768 .85904 m .53968 .86124 L .5374 .86131 L F
.771 .263 0 r
.53803 .86023 m .53968 .86124 L .53768 .85904 L F
.744 .509 .575 r
.53419 .85914 m .53768 .85904 L .5374 .86131 L F
.53419 .85914 m .5374 .86131 L .5343 .86117 L F
.777 .332 .193 r
.53743 .86191 m .53766 .86337 L .53747 .86255 L F
.5374 .86131 m .53759 .86279 L .53743 .86191 L F
.53759 .86279 m .53766 .86337 L .53743 .86191 L F
.5374 .86131 m .53946 .86357 L .53843 .86346 L F
.53759 .86279 m .53843 .86346 L .53766 .86337 L F
.5374 .86131 m .53843 .86346 L .53759 .86279 L F
.621 .382 .534 r
.53968 .86124 m .53946 .86357 L .5374 .86131 L F
.67 .475 .612 r
.53522 .8609 m .53765 .86196 L .53789 .86009 L F
.521 0 0 r
.5343 .86117 m .5374 .86131 L .53743 .86191 L F
.67 .475 .612 r
.5343 .86117 m .53609 .86159 L .53522 .8609 L F
.53609 .86159 m .53765 .86196 L .53522 .8609 L F
.53743 .86191 m .53762 .86223 L .53765 .86196 L F
.5343 .86117 m .53748 .86218 L .53743 .86191 L F
.53748 .86218 m .53762 .86223 L .53743 .86191 L F
.46 0 0 r
.53747 .86255 m .53762 .86223 L .53722 .8621 L F
.53732 .86249 m .53722 .8621 L .5343 .86117 L F
.53747 .86255 m .53722 .8621 L .53732 .86249 L F
.701 .373 0 r
.53738 .86274 m .53766 .86337 L .53836 .86535 L F
.455 .349 .646 r
.5343 .86117 m .53431 .86365 L .53747 .86255 L F
.701 .373 0 r
.5372 .86227 m .53735 .86263 L .53738 .86274 L F
.53735 .86263 m .53766 .86337 L .53738 .86274 L F
.521 0 0 r
.5343 .86117 m .53743 .86191 L .53747 .86255 L F
.498 .793 .998 r
.53294 .85813 m .53715 .85863 L .53419 .85914 L F
.53715 .85863 m .53672 .85882 L .53419 .85914 L F
.264 .761 .896 r
.53769 .85878 m .53768 .85904 L .53419 .85914 L F
.67 .475 .612 r
.5343 .86117 m .53294 .85813 L .53419 .85914 L F
.5343 .86117 m .53773 .85895 L .53294 .85813 L F
.498 .793 .998 r
.53768 .85869 m .53806 .85874 L .53769 .85878 L F
.67 .475 .612 r
.53773 .85895 m .53806 .85874 L .53768 .85869 L F
.771 .263 0 r
.53773 .85895 m .53772 .85889 L .53772 .85889 L F
.498 .793 .998 r
.53715 .85863 m .53768 .85869 L .53672 .85882 L F
.771 .263 0 r
.53777 .85935 m .53769 .85878 L .5377 .85866 L F
.67 .475 .612 r
.53773 .85895 m .53768 .85869 L .53294 .85813 L F
.53773 .85895 m .53793 .85978 L .53806 .85874 L F
.348 .261 .615 r
.53793 .85978 m .53761 .85828 L .53806 .85874 L F
.771 .263 0 r
.53803 .86023 m .53773 .85895 L .5377 .85866 L F
.53773 .85895 m .53772 .85889 L .5377 .85866 L F
.53818 .86074 m .53803 .86023 L .5377 .85866 L F
.53803 .86023 m .53777 .85935 L .53772 .85889 L F
.67 .475 .612 r
.53712 .85935 m .53789 .86009 L .53793 .85978 L F
.771 .263 0 r
.53777 .85935 m .53768 .85904 L .53769 .85878 L F
.67 .475 .612 r
.53712 .85935 m .53793 .85978 L .53773 .85895 L F
.5343 .86117 m .53789 .86009 L .53712 .85935 L F
.771 .263 0 r
.53769 .85869 m .53768 .85904 L .53761 .85828 L F
.348 .261 .615 r
.53762 .86223 m .53761 .85828 L .53793 .85978 L F
.771 .263 0 r
.5377 .85866 m .53769 .85869 L .53761 .85828 L F
.348 .261 .615 r
.53762 .86223 m .53818 .86074 L .53764 .85842 L F
.683 .764 .275 r
.53747 .86255 m .53818 .86074 L .53762 .86223 L F
.976 .862 .474 r
.53818 .86074 m .53766 .86337 L .5372 .86227 L F
0 0 0 r
.53784 .86147 m .53818 .86074 L .5372 .86227 L F
.771 .263 0 r
.53818 .86074 m .53874 .86092 L .5383 .86049 L F
.53874 .86092 m .53968 .86124 L .53803 .86023 L F
.789 .924 .926 r
.54149 .85889 m .53968 .86124 L .53818 .86074 L F
0 0 0 r
.53934 .85959 m .53818 .86074 L .53784 .86147 L F
.771 .263 0 r
.53818 .86074 m .5383 .86049 L .53803 .86023 L F
.348 .261 .615 r
.53761 .85843 m .53764 .85842 L .53761 .85828 L F
.53762 .86223 m .53764 .85842 L .53761 .85843 L F
.435 .161 .396 r
.33835 .69662 m .33643 .69721 L .33897 .69495 L F
.431 .156 .394 r
.34035 .6961 m .33897 .69495 L .34062 .69413 L F
.34035 .6961 m .33835 .69662 L .33897 .69495 L F
.47 .574 .877 r
.32168 .67841 m .3232 .67807 L .32018 .67656 L F
.446 .272 .55 r
.3313 .70671 m .32994 .70534 L .33162 .70478 L F
.3313 .70671 m .32978 .70746 L .32994 .70534 L F
.581 .57 .806 r
.33705 .6672 m .33629 .67074 L .33532 .66738 L F
.33705 .6672 m .33835 .67033 L .33629 .67074 L F
0 0 0 r
.53107 .82757 m .53031 .82874 L .53191 .82685 L F
.867 .816 .797 r
.54777 .83834 m .54604 .8406 L .54584 .83751 L F
.434 0 0 r
.40994 .74231 m .4083 .7435 L .40658 .74334 L F
.065 0 0 r
.4106 .7428 m .40994 .74231 L .41198 .74268 L F
.4106 .7428 m .4083 .7435 L .40994 .74231 L F
.83 .7 .721 r
.70182 .74401 m .70484 .74234 L .70346 .74127 L F
.70182 .74401 m .70347 .74567 L .70484 .74234 L F
.572 .65 .888 r
.52953 .87422 m .52743 .87306 L .52902 .87214 L F
.041 .205 .708 r
.53053 .87378 m .52953 .87422 L .52902 .87214 L F
0 0 0 r
.52773 .87632 m .52953 .87422 L .53053 .87378 L F
.313 0 .219 r
.53325 .82509 m .53191 .82685 L .53506 .82458 L F
.955 .666 .228 r
.49821 .846 m .49926 .84842 L .49788 .84622 L F
.349 .644 .965 r
.49926 .84842 m .50135 .84885 L .49788 .84622 L F
.557 .393 .614 r
.52067 .83502 m .52232 .83224 L .52072 .83246 L F
.678 .619 .782 r
.54703 .78646 m .54942 .78737 L .54841 .78463 L F
.849 .923 .88 r
.54841 .78463 m .54621 .78688 L .54707 .78631 L F
.726 .645 .767 r
.54718 .78657 m .54942 .78737 L .54892 .786 L F
.54621 .78688 m .54712 .78702 L .54718 .78657 L F
.54712 .78702 m .54942 .78737 L .54718 .78657 L F
.618 .613 .823 r
.54718 .78657 m .54721 .78628 L .54707 .78631 L F
.607 .325 .464 r
.54621 .78688 m .54718 .78657 L .54707 .78631 L F
0 0 0 r
.54707 .78631 m .54773 .78595 L .54841 .78463 L F
.726 .645 .767 r
.54746 .78648 m .54892 .786 L .54841 .78463 L F
.572 .559 .801 r
.54841 .78463 m .54942 .78737 L .55139 .78683 L F
.54841 .78463 m .5493 .78529 L .55065 .78435 L F
.5493 .78529 m .55139 .78683 L .55065 .78435 L F
.54841 .78463 m .55139 .78683 L .55065 .78435 L F
.586 .262 .387 r
.5493 .78581 m .55185 .78351 L .55065 .78435 L F
.55185 .78351 m .55213 .78326 L .55065 .78435 L F
0 0 0 r
.54773 .78595 m .5493 .78581 L .55065 .78435 L F
.54707 .78631 m .54721 .78628 L .54773 .78595 L F
.54721 .78628 m .5493 .78581 L .54773 .78595 L F
.726 .645 .767 r
.54621 .78688 m .54634 .78684 L .54841 .78463 L F
.54634 .78684 m .54746 .78648 L .54773 .78595 L F
.54634 .78684 m .54773 .78595 L .54841 .78463 L F
0 0 0 r
.54773 .78595 m .55065 .78435 L .54841 .78463 L F
.702 .31 .302 r
.54942 .78737 m .54831 .78914 L .54621 .78688 L F
.618 .613 .823 r
.54831 .78914 m .5493 .78581 L .54721 .78628 L F
.54831 .78914 m .54721 .78628 L .54718 .78657 L F
.607 .325 .464 r
.54621 .78688 m .54831 .78914 L .54718 .78657 L F
.653 .361 .463 r
.55139 .78683 m .54831 .78914 L .54942 .78737 L F
.92 .722 .229 r
.56064 .83196 m .56041 .83041 L .56075 .83119 L F
.56064 .83196 m .5603 .83175 L .56041 .83041 L F
.702 .477 0 r
.56081 .83475 m .5603 .83175 L .56064 .83196 L F
.292 0 0 r
.41774 .7428 m .41411 .74295 L .41559 .74318 L F
.569 .035 0 r
.65263 .73076 m .65532 .73162 L .65437 .7308 L F
.303 .177 .538 r
.65527 .72765 m .65437 .7308 L .65701 .72732 L F
.35 .098 .385 r
.65437 .7308 m .65701 .7301 L .65701 .72732 L F
.65437 .7308 m .65532 .73162 L .65701 .7301 L F
.985 .884 .641 r
.55105 .83716 m .55081 .84053 L .55259 .83825 L F
0 0 0 r
.42289 .74167 m .41954 .74208 L .42091 .74189 L F
.612 .609 .824 r
.46401 .87775 m .46494 .88032 L .46699 .87996 L F
0 0 0 r
.37005 .80243 m .37119 .80222 L .3695 .80304 L F
.37005 .80243 m .37308 .80157 L .37119 .80222 L F
.459 .866 .958 r
.52829 .83468 m .52629 .83524 L .52943 .83491 L F
.627 .194 .199 r
.53139 .83441 m .52829 .83468 L .52943 .83491 L F
.934 .563 .264 r
.51792 .8721 m .51938 .87439 L .51788 .87566 L F
.832 .374 .127 r
.51938 .87439 m .52042 .87711 L .51788 .87566 L F
.782 .602 .656 r
.59114 .80293 m .5943 .80097 L .59109 .80053 L F
.59114 .80293 m .59419 .80326 L .5943 .80097 L F
.542 .491 .749 r
.65117 .60802 m .65354 .60945 L .65178 .61037 L F
.142 0 .076 r
.65178 .61037 m .65354 .60945 L .65111 .61153 L F
.536 .812 .997 r
.315 .65655 m .31404 .6576 L .31302 .65672 L F
.315 .65655 m .31641 .65738 L .31404 .6576 L F
.72 .639 .767 r
.51512 .86743 m .51538 .86888 L .51337 .86644 L F
.674 .547 .702 r
.51667 .86743 m .51841 .86964 L .51538 .86888 L F
.113 0 .17 r
.51664 .86857 m .51667 .86743 L .51538 .86888 L F
.934 .817 .706 r
.51841 .86964 m .51638 .87162 L .51538 .86888 L F
.22 .137 .545 r
.51664 .86857 m .51538 .86888 L .51638 .87162 L F
.741 .653 .762 r
.51512 .86743 m .51667 .86743 L .51538 .86888 L F
.681 .924 .972 r
.65701 .7301 m .65802 .73074 L .66035 .72948 L F
.57 .321 .5 r
.43735 .76556 m .43649 .76869 L .43422 .76886 L F
.563 .315 .498 r
.43945 .76741 m .43735 .76556 L .43931 .76566 L F
.43945 .76741 m .43649 .76869 L .43735 .76556 L F
.482 .154 .334 r
.40758 .78265 m .40694 .78413 L .40494 .78436 L F
.348 .025 .268 r
.40891 .7834 m .40758 .78265 L .40953 .78228 L F
.40891 .7834 m .40694 .78413 L .40758 .78265 L F
.574 .252 .386 r
.66772 .63358 m .66699 .63583 L .66468 .63579 L F
.558 .236 .38 r
.66989 .63462 m .66772 .63358 L .67 .63341 L F
.66989 .63462 m .66699 .63583 L .66772 .63358 L F
.519 0 0 r
.65357 .62943 m .65284 .62863 L .65174 .62792 L F
.65357 .62943 m .65485 .63041 L .65284 .62863 L F
.459 .328 .614 r
.65485 .63041 m .65495 .62788 L .65284 .62863 L F
.618 .931 .966 r
.37916 .75025 m .37898 .75119 L .38051 .7501 L F
.37916 .75025 m .3769 .75117 L .37898 .75119 L F
.002 0 0 r
.35952 .80724 m .36288 .80579 L .36143 .8068 L F
.119 0 0 r
.36411 .80592 m .36288 .80579 L .36475 .80511 L F
.36411 .80592 m .36143 .8068 L .36288 .80579 L F
.642 .579 .769 r
.6368 .73399 m .63777 .73707 L .64067 .73571 L F
.828 .646 .656 r
.5599 .81627 m .55883 .81923 L .56185 .81914 L F
.829 .722 .746 r
.55883 .81923 m .55973 .82167 L .56185 .81914 L F
.718 .544 .653 r
.55973 .82167 m .56235 .82216 L .56185 .81914 L F
.179 .714 .804 r
.56185 .81914 m .56397 .81886 L .56501 .81879 L F
.726 .55 .651 r
.56185 .81914 m .56575 .8219 L .56397 .81886 L F
.56185 .81914 m .56235 .82216 L .56575 .8219 L F
.303 .177 .538 r
.65527 .72765 m .65701 .72732 L .65733 .72683 L F
.717 .324 .302 r
.52521 .84283 m .52735 .84491 L .52906 .84342 L F
.52521 .84283 m .52735 .84491 L .52906 .84342 L F
.765 .539 .591 r
.52735 .84491 m .52968 .84212 L .52906 .84342 L F
0 .497 .792 r
.4552 .75172 m .45732 .75235 L .45415 .75165 L F
.882 .706 .659 r
.60372 .82444 m .60273 .82151 L .60245 .82395 L F
.963 .751 .57 r
.60235 .82589 m .60372 .82444 L .60245 .82395 L F
.60235 .82589 m .60371 .82673 L .60372 .82444 L F
.331 .677 .978 r
.70165 .70388 m .70374 .70406 L .70278 .7049 L F
.885 .884 .827 r
.70374 .70406 m .70276 .70758 L .70278 .7049 L F
.45 .252 .519 r
.65797 .61947 m .65614 .61816 L .65576 .61993 L F
.65797 .61947 m .65815 .61734 L .65614 .61816 L F
.65614 .61816 m .65797 .61947 L .65576 .61993 L F
.65614 .61816 m .65815 .61734 L .65797 .61947 L F
.458 .232 .482 r
.33643 .69721 m .33589 .69937 L .33416 .69982 L F
.451 .225 .479 r
.33795 .69861 m .33643 .69721 L .33835 .69662 L F
.33795 .69861 m .33589 .69937 L .33643 .69721 L F
.486 .205 .412 r
.41233 .77918 m .41161 .78196 L .40953 .78228 L F
.5 .219 .419 r
.41422 .77905 m .41161 .78196 L .41233 .77918 L F
.529 .261 .454 r
.44949 .7613 m .44689 .76048 L .44896 .76032 L F
.44949 .7613 m .44614 .76319 L .44689 .76048 L F
.355 .636 .96 r
.50462 .84877 m .50572 .84762 L .50322 .84784 L F
.50462 .84877 m .50681 .84835 L .50572 .84762 L F
.299 0 .134 r
.39527 .78942 m .39771 .78794 L .39737 .78921 L F
.552 .283 .461 r
.3997 .78767 m .39737 .78921 L .39771 .78794 L F
.313 .457 .845 r
.42994 .7476 m .43145 .74697 L .42899 .74566 L F
.58 .549 .784 r
.43032 .75041 m .43145 .74697 L .42994 .7476 L F
.706 .285 .244 r
.57201 .78206 m .57551 .78338 L .57342 .78166 L F
.112 0 0 r
.57282 .82921 m .57434 .82908 L .57572 .82935 L F
.57282 .82921 m .57233 .82997 L .57434 .82908 L F
.489 .285 .529 r
.33589 .69937 m .33392 .70184 L .33416 .69982 L F
.41 .156 .414 r
.65288 .64179 m .65458 .64304 L .65237 .64335 L F
.65288 .64179 m .6549 .64105 L .65458 .64304 L F
.552 .327 .527 r
.41761 .76582 m .41973 .7656 L .41996 .76356 L F
.512 .295 .522 r
.41973 .7656 m .42198 .76317 L .41996 .76356 L F
.645 .797 .956 r
.34516 .79497 m .34443 .79691 L .34305 .79642 L F
.34516 .79497 m .3469 .79612 L .34443 .79691 L F
.525 .624 .892 r
.47674 .87293 m .47817 .87096 L .47555 .87012 L F
.064 .476 .889 r
.41239 .72598 m .41182 .72651 L .411 .72533 L F
.41239 .72598 m .41429 .72759 L .41182 .72651 L F
.447 .108 .298 r
.38216 .78465 m .38429 .78431 L .38527 .78193 L F
.347 .014 .251 r
.38527 .78193 m .38619 .78365 L .38702 .78103 L F
.38527 .78193 m .38429 .78431 L .38619 .78365 L F
.493 .234 .45 r
.5457 .83541 m .54584 .83751 L .54352 .83755 L F
.609 .335 .476 r
.42729 .7715 m .42675 .77379 L .42432 .77378 L F
.417 .158 .411 r
.42863 .77322 m .42729 .7715 L .42945 .77109 L F
.42863 .77322 m .42675 .77379 L .42729 .7715 L F
.739 .658 .77 r
.64082 .63924 m .64198 .64172 L .63864 .64147 L F
.807 .606 .63 r
.64198 .64172 m .63888 .6436 L .63864 .64147 L F
.64198 .64172 m .64192 .64405 L .63888 .6436 L F
.606 .746 .944 r
.33342 .66343 m .33153 .66426 L .33025 .66259 L F
.407 .67 .968 r
.44208 .7335 m .44126 .7346 L .44009 .7334 L F
.585 .909 .979 r
.44342 .73387 m .44126 .7346 L .44208 .7335 L F
.742 .493 .554 r
.51143 .86923 m .51214 .86752 L .50808 .8665 L F
0 0 .132 r
.5139 .86425 m .51214 .86752 L .51337 .86644 L F
.221 0 .292 r
.51337 .86644 m .51214 .86752 L .51143 .86923 L F
.834 .696 .711 r
.6479 .60936 m .64923 .61246 L .64638 .61233 L F
.764 .376 .318 r
.64638 .61233 m .64923 .61246 L .6488 .61426 L F
.139 0 .04 r
.64923 .61246 m .65026 .61331 L .6488 .61426 L F
.64923 .61246 m .65111 .61153 L .65026 .61331 L F
.433 .092 .286 r
.39449 .77622 m .3961 .77616 L .39743 .77426 L F
.508 .15 .294 r
.39743 .77426 m .39884 .77571 L .39949 .7739 L F
.39743 .77426 m .3961 .77616 L .39884 .77571 L F
.527 .707 .953 r
.43331 .73098 m .43244 .73256 L .43126 .73133 L F
.43331 .73098 m .43481 .73242 L .43244 .73256 L F
.868 .723 .7 r
.60393 .83742 m .60299 .83477 L .6027 .83642 L F
.925 .871 .765 r
.60123 .83983 m .60393 .83742 L .6027 .83642 L F
.60123 .83983 m .6024 .84047 L .60393 .83742 L F
.797 .652 .702 r
.60067 .81076 m .60189 .81378 L .60241 .81161 L F
.869 .424 .08 r
.54659 .85281 m .54733 .85395 L .54593 .85298 L F
.54593 .85298 m .54733 .85395 L .54659 .85281 L F
.54659 .85281 m .54733 .85395 L .54593 .85298 L F
.927 .915 .528 r
.55698 .81099 m .55621 .81303 L .55726 .81142 L F
.673 .28 .293 r
.55621 .81303 m .55949 .81319 L .55726 .81142 L F
.273 0 .165 r
.39581 .79116 m .39527 .78942 L .39737 .78921 L F
.39581 .79116 m .39401 .79183 L .39527 .78942 L F
.455 .327 .616 r
.32206 .69464 m .32352 .69382 L .32369 .69135 L F
.445 .219 .476 r
.32154 .69671 m .32352 .69382 L .32206 .69464 L F
.722 .332 .31 r
.54689 .81107 m .54578 .81251 L .5433 .81047 L F
.845 .5 .402 r
.54689 .81107 m .54848 .814 L .54578 .81251 L F
.172 .615 .939 r
.47881 .88314 m .47935 .88248 L .47774 .88256 L F
.47881 .88314 m .48115 .88351 L .47935 .88248 L F
.32 .69 .979 r
.47827 .88185 m .47774 .88256 L .47935 .88248 L F
.717 .185 0 r
.47935 .88248 m .48008 .88385 L .47831 .88189 L F
.47935 .88248 m .47831 .88189 L .47827 .88185 L F
.172 .615 .939 r
.48115 .88351 m .48175 .8836 L .47935 .88248 L F
.974 .692 .43 r
.66803 .71741 m .66915 .71811 L .66896 .71584 L F
.66803 .71741 m .66915 .71811 L .66896 .71584 L F
.884 .827 .786 r
.54584 .83751 m .54604 .8406 L .54488 .83993 L F
.781 .47 .461 r
.54604 .8406 m .54361 .8422 L .54488 .83993 L F
.54604 .8406 m .54691 .84263 L .54361 .8422 L F
.768 .295 .117 r
.50747 .87346 m .51039 .8749 L .5093 .87381 L F
0 .199 .695 r
.51274 .87387 m .5102 .87192 L .51115 .87372 L F
.51274 .87387 m .51039 .8749 L .51115 .87372 L F
.51274 .87387 m .51121 .87385 L .51039 .8749 L F
.389 .4 .75 r
.51039 .8749 m .51271 .87671 L .51121 .87385 L F
.51039 .8749 m .51121 .87385 L .51115 .87372 L F
0 .199 .695 r
.51121 .87385 m .5093 .87381 L .51039 .8749 L F
.51274 .87387 m .50942 .87355 L .5093 .87381 L F
.51274 .87387 m .51115 .87372 L .51133 .87343 L F
.389 .4 .75 r
.51115 .87372 m .51294 .87688 L .51133 .87343 L F
.51271 .87671 m .51294 .87688 L .51115 .87372 L F
0 .199 .695 r
.51274 .87387 m .51029 .87174 L .5102 .87192 L F
.51115 .87372 m .5102 .87192 L .50942 .87355 L F
.398 .048 .25 r
.55587 .77957 m .55694 .78113 L .55801 .77888 L F
.55587 .77957 m .55503 .78179 L .55694 .78113 L F
.537 .398 .639 r
.45947 .85623 m .46164 .85828 L .46144 .85582 L F
.45947 .85623 m .45959 .85876 L .46164 .85828 L F
0 .031 .583 r
.51852 .86959 m .51841 .86964 L .51667 .86743 L F
.798 .362 .213 r
.51664 .86857 m .51852 .86959 L .51667 .86743 L F
.454 .061 .203 r
.34661 .73642 m .34871 .73623 L .35003 .73427 L F
.453 .076 .231 r
.34871 .73623 m .35206 .73394 L .35003 .73427 L F
.414 .642 .95 r
.68905 .73847 m .68954 .74061 L .68769 .73974 L F
.931 .674 .527 r
.53368 .83197 m .53599 .8302 L .53574 .83155 L F
.502 .338 .591 r
.53374 .82977 m .53574 .83155 L .53368 .83197 L F
.931 .674 .527 r
.53368 .83197 m .53574 .83155 L .53374 .82977 L F
.698 .852 .956 r
.69094 .72678 m .68784 .72701 L .68994 .72596 L F
.628 .724 .916 r
.34551 .67705 m .34264 .6765 L .3449 .6766 L F
.325 .527 .898 r
.34719 .67668 m .34551 .67705 L .3449 .6766 L F
.34719 .67668 m .34806 .67825 L .34551 .67705 L F
.559 .86 .997 r
.38584 .88544 m .38445 .88488 L .38235 .88541 L F
.909 .855 .777 r
.38623 .88193 m .38445 .88488 L .38584 .88544 L F
.87 .629 .099 r
.67996 .73363 m .68065 .73707 L .68105 .73425 L F
.712 .708 .845 r
.68105 .73425 m .68234 .73083 L .67996 .73363 L F
.68105 .73425 m .68345 .73246 L .68234 .73083 L F
.496 .288 .527 r
.3882 .74483 m .38783 .748 L .3859 .74774 L F
.002 0 .342 r
.38921 .74625 m .3882 .74483 L .39024 .74442 L F
.38921 .74625 m .38783 .748 L .3882 .74483 L F
.199 .449 .873 r
.33342 .66343 m .33559 .66448 L .33495 .66553 L F
.122 .343 .808 r
.33559 .66448 m .33705 .6672 L .33495 .66553 L F
.473 .389 .68 r
.33495 .66553 m .33705 .6672 L .33532 .66738 L F
.988 .792 .553 r
.66566 .62777 m .66631 .62617 L .66796 .62517 L F
.785 .593 .641 r
.58671 .79265 m .58651 .79502 L .58972 .79533 L F
.802 .633 .672 r
.5864 .79742 m .58972 .79533 L .58651 .79502 L F
.5864 .79742 m .58979 .7979 L .58972 .79533 L F
.235 .011 .356 r
.65568 .71443 m .65507 .71648 L .65701 .71295 L F
.578 .336 .514 r
.42221 .77411 m .42194 .7759 L .41988 .77617 L F
.534 .298 .503 r
.42432 .77378 m .42194 .7759 L .42221 .77411 L F
.522 .833 1 r
.39361 .74452 m .39444 .74338 L .39228 .74386 L F
.39361 .74452 m .39575 .74406 L .39444 .74338 L F
.622 .587 .793 r
.66081 .61444 m .66205 .61152 L .65967 .61294 L F
.985 .884 .641 r
.55105 .83716 m .55002 .84025 L .55081 .84053 L F
.996 .812 .451 r
.54987 .84179 m .55081 .84053 L .55002 .84025 L F
.54987 .84179 m .55065 .84295 L .55081 .84053 L F
.768 .574 .636 r
.59757 .80822 m .60103 .80605 L .59746 .80589 L F
.59757 .80822 m .60097 .80857 L .60103 .80605 L F
.39 .784 .987 r
.5573 .80026 m .55938 .80004 L .56048 .80061 L F
.5573 .80026 m .55938 .80004 L .56048 .80061 L F
0 .038 .593 r
.6738 .73696 m .67501 .73799 L .67332 .73614 L F
.6738 .73696 m .67599 .73945 L .67501 .73799 L F
.901 .882 .806 r
.5348 .8218 m .53355 .82119 L .53602 .81719 L F
.858 .666 .642 r
.57618 .79284 m .57581 .79502 L .57415 .79221 L F
.465 .648 .938 r
.41627 .7276 m .41521 .72887 L .41429 .72759 L F
.28 .373 .78 r
.41627 .7276 m .41671 .72967 L .41521 .72887 L F
.462 .43 .736 r
.51263 .84551 m .51339 .84242 L .51122 .8426 L F
.51263 .84551 m .51448 .84548 L .51339 .84242 L F
0 0 .38 r
.67306 .73395 m .67198 .73086 L .67259 .73168 L F
.54 .244 .414 r
.43389 .77046 m .43163 .77077 L .43203 .76897 L F
.55 .24 .396 r
.43422 .76886 m .43389 .77046 L .43203 .76897 L F
.701 .223 .111 r
.53575 .81611 m .53794 .8179 L .53889 .81676 L F
.718 .245 .123 r
.53794 .8179 m .54083 .81863 L .53889 .81676 L F
.745 .565 .651 r
.65013 .60667 m .65354 .60945 L .65117 .60802 L F
.597 .258 .366 r
.50475 .8688 m .5028 .86679 L .50331 .86869 L F
.50475 .8688 m .50637 .86626 L .5028 .86679 L F
.46 .034 .142 r
.55693 .78452 m .55582 .7862 L .55363 .7863 L F
.32 0 .064 r
.55817 .78567 m .55693 .78452 L .55913 .7841 L F
.55817 .78567 m .55582 .7862 L .55693 .78452 L F
.745 .468 .511 r
.56205 .77903 m .56359 .7798 L .56512 .77913 L F
.5 .07 .154 r
.56359 .7798 m .56423 .78067 L .56512 .77913 L F
.639 .236 .263 r
.56423 .78067 m .5667 .77927 L .56512 .77913 L F
.856 .892 .862 r
.59725 .84316 m .59932 .84231 L .59856 .84183 L F
.79 .907 .922 r
.59932 .84231 m .60123 .83983 L .59856 .84183 L F
.59932 .84231 m .6024 .84047 L .60123 .83983 L F
.799 .345 .164 r
.48148 .87332 m .48218 .87223 L .48396 .87457 L F
.539 .493 .753 r
.32293 .68723 m .32367 .68924 L .32561 .68876 L F
.516 .364 .612 r
.32367 .68924 m .32578 .69123 L .32561 .68876 L F
.32367 .68924 m .32369 .69135 L .32578 .69123 L F
.596 .402 .59 r
.37802 .72327 m .38019 .72338 L .38027 .72111 L F
.66 .571 .743 r
.69864 .73941 m .69711 .7421 L .69612 .7399 L F
.448 .184 .42 r
.65999 .62743 m .66262 .62534 L .6603 .62588 L F
.713 .428 .491 r
.65999 .62743 m .6603 .62588 L .65845 .62595 L F
.389 .003 .181 r
.35675 .73165 m .35869 .73129 L .35987 .72939 L F
.4 .015 .188 r
.35987 .72939 m .36131 .7302 L .36202 .72934 L F
.35987 .72939 m .35869 .73129 L .36131 .7302 L F
.586 .453 .667 r
.63649 .73184 m .63891 .7336 L .6386 .73157 L F
.63649 .73184 m .6368 .73399 L .63891 .7336 L F
.565 .34 .534 r
.4624 .84533 m .46456 .84522 L .46494 .84302 L F
.592 .484 .7 r
.38783 .748 m .38607 .75029 L .3859 .74774 L F
.621 .678 .883 r
.6538 .62076 m .65576 .61993 L .65225 .61914 L F
.584 .57 .803 r
.43133 .75305 m .43245 .75007 L .43032 .75041 L F
.43133 .75305 m .43363 .7528 L .43245 .75007 L F
.627 .508 .699 r
.43163 .75541 m .43363 .7528 L .43133 .75305 L F
.566 .202 .309 r
.3746 .72524 m .37675 .72545 L .37802 .72327 L F
.43 .021 .16 r
.37675 .72545 m .38019 .72338 L .37802 .72327 L F
.525 .617 .887 r
.56688 .84267 m .56727 .83972 L .5652 .84022 L F
.56688 .84267 m .56915 .84249 L .56727 .83972 L F
.853 .677 .662 r
.58209 .81319 m .5794 .81368 L .58001 .81118 L F
.861 .742 .73 r
.58209 .81319 m .58033 .81626 L .5794 .81368 L F
.658 .421 .549 r
.64944 .71507 m .65312 .71519 L .65173 .71339 L F
.471 .122 .293 r
.41444 .76831 m .41657 .76806 L .41761 .76582 L F
.415 .067 .265 r
.41761 .76582 m .4186 .76765 L .41973 .7656 L F
.41761 .76582 m .41657 .76806 L .4186 .76765 L F
0 0 .447 r
.68769 .73974 m .68845 .73939 L .68905 .73847 L F
.68769 .73974 m .6881 .74157 L .68845 .73939 L F
.324 0 .051 r
.50322 .84784 m .50639 .846 L .50327 .84555 L F
.50322 .84784 m .50572 .84762 L .50639 .846 L F
.68 .233 .185 r
.50572 .84762 m .50897 .84771 L .50639 .846 L F
.666 .382 .48 r
.51339 .84242 m .5166 .84047 L .51466 .84029 L F
.51339 .84242 m .51634 .84265 L .5166 .84047 L F
.594 .318 .468 r
.5166 .84047 m .51866 .84231 L .51904 .84051 L F
.5166 .84047 m .51634 .84265 L .51866 .84231 L F
.584 .14 .161 r
.33566 .74044 m .33945 .73955 L .33748 .74003 L F
.99 .729 .41 r
.70485 .71811 m .70553 .71984 L .70401 .71966 L F
.696 .588 .731 r
.70483 .72145 m .70401 .71966 L .70553 .71984 L F
.493 .078 .181 r
.40698 .76885 m .40894 .76892 L .4096 .76813 L F
.619 .33 .457 r
.40894 .76892 m .41217 .7682 L .4096 .76813 L F
.784 .707 .779 r
.65149 .62311 m .65225 .61914 L .65039 .62223 L F
.45 0 .075 r
.50931 .87923 m .50846 .87795 L .50693 .87955 L F
.446 .51 .831 r
.51142 .8805 m .50846 .87795 L .51066 .87798 L F
.45 0 .075 r
.50931 .87923 m .51066 .87798 L .50846 .87795 L F
.624 .811 .972 r
.69919 .69385 m .70239 .69419 L .70031 .69493 L F
.69919 .69385 m .70239 .69419 L .70031 .69493 L F
.535 .244 .419 r
.44411 .76362 m .44152 .76559 L .4418 .76371 L F
.721 .467 .541 r
.59418 .8078 m .59746 .80589 L .59408 .80568 L F
.59418 .8078 m .59757 .80822 L .59746 .80589 L F
.831 .625 .624 r
.56337 .82319 m .56575 .8219 L .56235 .82216 L F
.56337 .82319 m .5654 .82426 L .56575 .8219 L F
.733 .722 .841 r
.70709 .71584 m .7085 .71848 L .70485 .71811 L F
.353 .52 .883 r
.71023 .71786 m .7085 .71848 L .70709 .71584 L F
.598 .032 0 r
.48189 .86837 m .48091 .86713 L .48025 .86589 L F
.48189 .86837 m .48314 .86888 L .48125 .86739 L F
0 0 .383 r
.48262 .86948 m .48189 .86837 L .48314 .86797 L F
.826 .374 .155 r
.48322 .87077 m .48314 .86888 L .48189 .86837 L F
0 0 .383 r
.48261 .86949 m .48189 .86837 L .48262 .86948 L F
.598 .032 0 r
.48189 .86837 m .48125 .86739 L .48091 .86713 L F
.45 .736 .989 r
.69829 .72378 m .6949 .72304 L .69768 .72152 L F
.607 .437 .625 r
.69845 .72615 m .69611 .7265 L .69829 .72378 L F
.95 .682 .228 r
.69969 .7195 m .69829 .72378 L .69768 .72152 L F
.69969 .7195 m .70056 .72342 L .69829 .72378 L F
.504 .31 .551 r
.70056 .72342 m .69845 .72615 L .69829 .72378 L F
.687 .594 .746 r
.69845 .72615 m .69622 .72865 L .69611 .7265 L F
.566 .653 .895 r
.50749 .8608 m .50951 .86021 L .50686 .85907 L F
.50749 .8608 m .5103 .8619 L .50951 .86021 L F
.659 .608 .786 r
.70278 .73198 m .69907 .72941 L .70233 .73099 L F
.595 .702 .918 r
.70223 .73078 m .70278 .73198 L .70233 .73099 L F
.721 .59 .709 r
.70669 .73039 m .70512 .73156 L .70291 .73097 L F
.70264 .73075 m .70291 .73097 L .70223 .73078 L F
.70669 .73039 m .70291 .73097 L .70264 .73075 L F
.88 .923 .849 r
.70209 .72778 m .7023 .73047 L .70095 .72793 L F
.7023 .73047 m .70233 .73099 L .70198 .73022 L F
.7023 .73047 m .70198 .73022 L .70095 .72793 L F
.70302 .72766 m .70252 .7301 L .70209 .72778 L F
.70252 .7301 m .70233 .73099 L .70209 .72778 L F
.721 .59 .709 r
.70669 .73039 m .70264 .73075 L .70613 .72788 L F
.70264 .73075 m .70223 .73078 L .7026 .73051 L F
.70264 .73075 m .7026 .73051 L .70613 .72788 L F
.88 .923 .849 r
.70302 .72766 m .70223 .73078 L .70233 .73099 L F
.595 .702 .918 r
.70223 .73078 m .70512 .73156 L .70278 .73198 L F
.488 .427 .715 r
.32237 .68388 m .32293 .68723 L .32455 .6856 L F
.539 .493 .753 r
.32293 .68723 m .32561 .68876 L .32455 .6856 L F
.775 .643 .715 r
.59864 .81352 m .60189 .81378 L .60067 .81076 L F
.778 .613 .676 r
.60045 .81632 m .60189 .81378 L .59864 .81352 L F
0 0 0 r
.47432 .87069 m .4735 .87028 L .47555 .87012 L F
.47432 .87069 m .47281 .87154 L .4735 .87028 L F
.853 .693 .684 r
.54784 .84804 m .5466 .84487 L .54825 .84577 L F
.475 .274 .527 r
.5502 .84526 m .54784 .84804 L .54825 .84577 L F
.852 .573 .515 r
.54354 .80874 m .54209 .81047 L .54204 .80784 L F
.949 .754 .606 r
.5433 .81047 m .54209 .81047 L .54354 .80874 L F
.881 .705 .659 r
.70182 .74401 m .70279 .74721 L .70347 .74567 L F
.273 .469 .869 r
.50951 .86021 m .5103 .8619 L .51137 .86084 L F
.478 .802 1 r
.51137 .86084 m .5103 .8619 L .51251 .86158 L F
.368 .566 .913 r
.5103 .8619 m .5139 .86425 L .51251 .86158 L F
.806 .335 0 r
.66694 .71439 m .66617 .71238 L .66499 .71204 L F
.816 .77 .81 r
.66499 .71204 m .66244 .71505 L .66098 .71435 L F
.66499 .71204 m .66098 .71435 L .66362 .71208 L F
.703 .163 0 r
.66362 .71208 m .66587 .71419 L .66694 .71439 L F
.973 .878 .68 r
.66694 .71439 m .66587 .71419 L .666 .71379 L F
.806 .335 0 r
.66694 .71439 m .66787 .71498 L .66617 .71238 L F
.703 .163 0 r
.66362 .71208 m .66694 .71439 L .66499 .71204 L F
.973 .878 .68 r
.66694 .71439 m .666 .71379 L .6666 .71182 L F
.806 .335 0 r
.66694 .71439 m .66795 .71511 L .66787 .71498 L F
.934 .817 .706 r
.51841 .86964 m .51792 .8721 L .51638 .87162 L F
.547 .43 .672 r
.52038 .87133 m .51792 .8721 L .51841 .86964 L F
0 0 .36 r
.51792 .8721 m .51788 .87566 L .51894 .874 L F
.51792 .8721 m .51894 .874 L .51638 .87162 L F
.818 .602 .609 r
.47411 .83742 m .47696 .83987 L .47734 .83764 L F
.745 .65 .755 r
.47661 .83491 m .47734 .83764 L .47956 .83506 L F
.843 .478 .361 r
.54549 .82193 m .54795 .82566 L .54857 .82446 L F
.989 .722 .396 r
.54771 .82607 m .54857 .82446 L .54795 .82566 L F
.54771 .82607 m .5486 .82672 L .54857 .82446 L F
.482 .848 .606 r
.3672 .78773 m .36453 .7898 L .36556 .78891 L F
0 0 0 r
.36453 .7898 m .3632 .79106 L .36556 .78891 L F
.73 .667 .788 r
.49264 .84549 m .49584 .84629 L .49481 .84592 L F
.686 .351 .403 r
.49821 .846 m .49481 .84592 L .49584 .84629 L F
0 0 0 r
.52129 .88194 m .52286 .88053 L .52447 .87967 L F
.779 .52 .544 r
.49863 .84289 m .49997 .8454 L .50264 .84529 L F
.673 .252 .237 r
.50264 .84529 m .49997 .8454 L .50327 .84555 L F
.764 .272 .055 r
.5415 .82064 m .54215 .81963 L .54083 .81863 L F
.5415 .82064 m .54426 .82187 L .54215 .81963 L F
.762 .261 .023 r
.54215 .81963 m .54426 .82187 L .54549 .82193 L F
.513 .421 .689 r
.32237 .68388 m .32419 .68347 L .32386 .68122 L F
.488 .427 .715 r
.32237 .68388 m .32455 .6856 L .32419 .68347 L F
.487 .311 .568 r
.46095 .85355 m .46308 .8505 L .46092 .8509 L F
.386 .136 .408 r
.35454 .75781 m .35215 .76046 L .35241 .75819 L F
.84 .629 .618 r
.50475 .8688 m .50808 .8665 L .50637 .86626 L F
.564 .454 .686 r
.47855 .84296 m .48114 .84349 L .47919 .84112 L F
.969 .926 .608 r
.6785 .71053 m .67806 .70975 L .67746 .71145 L F
0 .139 .585 r
.6785 .71053 m .68098 .7123 L .68148 .71268 L F
.68 .22 .153 r
.67746 .71145 m .68098 .7123 L .6785 .71053 L F
.84 .629 .618 r
.50475 .8688 m .50763 .8692 L .50808 .8665 L F
.238 .739 .67 r
.37119 .80222 m .37308 .80157 L .37501 .80088 L F
.533 .424 .676 r
.50686 .85907 m .5088 .85925 L .50852 .85593 L F
.515 .504 .782 r
.50686 .85907 m .50951 .86021 L .5088 .85925 L F
.709 .746 .881 r
.59355 .84278 m .59436 .8449 L .59725 .84316 L F
.228 0 0 r
.39362 .74995 m .39478 .7502 L .3915 .74937 L F
.3915 .74937 m .39478 .7502 L .39362 .74995 L F
.58 .918 .968 r
.39362 .74995 m .39478 .7502 L .3955 .74915 L F
.3955 .74915 m .39478 .7502 L .39362 .74995 L F
.39362 .74995 m .39478 .7502 L .3955 .74915 L F
0 0 0 r
.65555 .72008 m .65504 .72028 L .65352 .72066 L F
.65504 .72028 m .65256 .72126 L .65352 .72066 L F
.609 .539 .75 r
.3709 .8948 m .37183 .89794 L .37317 .89595 L F
.905 .711 .629 r
.69234 .73427 m .69317 .73761 L .69193 .7363 L F
.691 .718 .87 r
.69532 .73682 m .69317 .73761 L .69193 .7363 L F
.69532 .73682 m .69317 .73761 L .69193 .7363 L F
.585 .584 .818 r
.69612 .7399 m .69317 .73761 L .69532 .73682 L F
.678 .608 .77 r
.69576 .75004 m .6985 .75222 L .69732 .75046 L F
.781 .789 .86 r
.69732 .75046 m .6985 .75222 L .70099 .75005 L F
0 .407 .725 r
.38706 .72326 m .3876 .7234 L .389 .72394 L F
.013 0 0 r
.38611 .72398 m .3883 .72358 L .3876 .7234 L F
.288 .744 .955 r
.38892 .72356 m .38979 .7233 L .3911 .72382 L F
.3876 .7234 m .38979 .7233 L .38892 .72356 L F
.3876 .7234 m .3911 .72382 L .389 .72394 L F
.013 0 0 r
.38611 .72398 m .38817 .72373 L .38979 .7233 L F
.22 0 0 r
.38817 .72373 m .39051 .72309 L .38979 .7233 L F
.39051 .72309 m .39126 .72288 L .38979 .7233 L F
.013 0 0 r
.3883 .72358 m .38979 .7233 L .3876 .7234 L F
0 .407 .725 r
.3856 .72276 m .3876 .7234 L .38706 .72326 L F
.662 .584 .757 r
.69864 .73941 m .69612 .7399 L .69532 .73682 L F
.41 0 0 r
.68878 .73258 m .6885 .733 L .68554 .73189 L F
.366 0 0 r
.69061 .73318 m .6885 .733 L .68878 .73258 L F
.445 .096 .278 r
.53786 .83104 m .53599 .8302 L .53893 .83083 L F
.53786 .83104 m .53574 .83155 L .53599 .8302 L F
.989 .73 .425 r
.67162 .72636 m .67079 .72788 L .67034 .72569 L F
.67162 .72636 m .6717 .72862 L .67079 .72788 L F
.157 .666 .901 r
.40514 .72437 m .40735 .72445 L .4083 .72489 L F
0 .555 .816 r
.40928 .72483 m .4083 .72489 L .40735 .72445 L F
.40928 .72483 m .411 .72533 L .4083 .72489 L F
.547 .43 .672 r
.52038 .87133 m .51841 .86964 L .51852 .86959 L F
.484 .564 .861 r
.34363 .67446 m .34264 .6765 L .34188 .6746 L F
.557 .653 .899 r
.34363 .67446 m .3449 .6766 L .34264 .6765 L F
.794 .717 .778 r
.51448 .84548 m .51763 .84593 L .51634 .84265 L F
.387 .484 .837 r
.51634 .84265 m .51763 .84593 L .51889 .84514 L F
.302 .797 .826 r
.36832 .75136 m .36705 .75177 L .36966 .75085 L F
.158 .698 .747 r
.37146 .75092 m .36832 .75136 L .36966 .75085 L F
.803 .619 .653 r
.5864 .79742 m .58777 .80024 L .58979 .7979 L F
.777 .578 .63 r
.58777 .80024 m .59109 .80053 L .58979 .7979 L F
.759 .718 .814 r
.68065 .6964 m .68387 .69656 L .68277 .69413 L F
.552 .439 .678 r
.4624 .84533 m .46509 .84764 L .46456 .84522 L F
.4624 .84533 m .46307 .84836 L .46509 .84764 L F
.482 .666 .944 r
.52382 .84944 m .52394 .8511 L .52338 .84969 L F
.944 .88 .471 r
.52335 .8516 m .52394 .8511 L .52382 .84944 L F
.972 .666 .291 r
.52335 .8516 m .52418 .85343 L .52394 .8511 L F
.461 .725 .982 r
.71164 .72537 m .71424 .72552 L .71255 .72633 L F
.529 .375 .617 r
.71496 .72829 m .71255 .72633 L .71424 .72552 L F
.954 .757 .598 r
.49024 .88505 m .4911 .88799 L .48976 .88781 L F
.165 0 0 r
.49189 .88828 m .4911 .88799 L .49024 .88505 L F
.327 0 .042 r
.4911 .88799 m .4921 .88918 L .48976 .88781 L F
.664 .644 .819 r
.42932 .73145 m .42589 .72935 L .42768 .72861 L F
.489 .658 .936 r
.4301 .72988 m .42932 .73145 L .42768 .72861 L F
.4301 .72988 m .43126 .73133 L .42932 .73145 L F
.8 .616 .652 r
.59095 .80532 m .59419 .80326 L .59114 .80293 L F
.59095 .80532 m .59408 .80568 L .59419 .80326 L F
.388 .098 .346 r
.65237 .64335 m .65005 .64633 L .6503 .6438 L F
.595 .458 .666 r
.6473 .71837 m .65019 .71983 L .64944 .71507 L F
.679 .244 .211 r
.6473 .71837 m .65035 .72097 L .65019 .71983 L F
.818 .797 .832 r
.64846 .72367 m .64672 .72386 L .64749 .72239 L F
.37 .382 .742 r
.65035 .72097 m .64846 .72367 L .64749 .72239 L F
.65035 .72097 m .65047 .7229 L .64846 .72367 L F
.489 .249 .477 r
.65047 .7229 m .64765 .72556 L .64846 .72367 L F
.774 .414 .375 r
.48314 .86888 m .48674 .87069 L .48413 .8696 L F
.653 .107 0 r
.69534 .74437 m .69357 .74331 L .69504 .7441 L F
.594 .36 .532 r
.54352 .83755 m .5436 .83992 L .54116 .83997 L F
.752 .485 .528 r
.54488 .83993 m .54352 .83755 L .54584 .83751 L F
.54488 .83993 m .5436 .83992 L .54352 .83755 L F
.749 .641 .741 r
.531 .85389 m .53341 .85365 L .53108 .85627 L F
.24 0 .274 r
.53108 .85627 m .53341 .85365 L .53288 .85575 L F
.399 .097 .333 r
.53288 .85575 m .53341 .85365 L .53531 .85324 L F
.458 .453 .765 r
.34076 .67208 m .33923 .6736 L .33835 .67033 L F
.517 .547 .826 r
.34076 .67208 m .34188 .6746 L .33923 .6736 L F
.687 .594 .746 r
.69845 .72615 m .69907 .72941 L .69622 .72865 L F
.603 .052 0 r
.51784 .85883 m .51556 .85711 L .51437 .85857 L F
.569 .029 0 r
.51437 .85857 m .51792 .86161 L .51784 .85883 L F
.54 .363 .589 r
.51784 .85883 m .51792 .86161 L .51995 .8609 L F
.647 .355 .461 r
.51995 .8609 m .52021 .85904 L .51784 .85883 L F
.842 .534 .468 r
.49709 .84474 m .49863 .84289 L .49752 .84256 L F
.49709 .84474 m .49997 .8454 L .49863 .84289 L F
.22 .62 .953 r
.67153 .6295 m .66878 .62906 L .66734 .62787 L F
.764 .614 .692 r
.58233 .81961 m .57903 .82003 L .58052 .81871 L F
.58233 .81961 m .58141 .82179 L .57903 .82003 L F
.557 .38 .597 r
.58355 .82133 m .58141 .82179 L .58233 .81961 L F
.513 .149 .286 r
.3393 .77039 m .33802 .76872 L .33988 .76867 L F
.3393 .77039 m .33723 .77034 L .33802 .76872 L F
.845 .863 .856 r
.6949 .72304 m .69129 .72539 L .69405 .72263 L F
.669 .949 .956 r
.69768 .72152 m .6949 .72304 L .69405 .72263 L F
.902 .726 .653 r
.60144 .8339 m .60341 .83239 L .60186 .83156 L F
.60144 .8339 m .60299 .83477 L .60341 .83239 L F
.886 .782 .741 r
.60341 .83239 m .60284 .82954 L .60186 .83156 L F
.593 .332 .491 r
.51122 .8426 m .51466 .84029 L .511 .84029 L F
.51122 .8426 m .51339 .84242 L .51466 .84029 L F
.746 .642 .744 r
.47661 .83491 m .47956 .83506 L .4786 .83206 L F
0 0 0 r
.52918 .85771 m .53108 .85627 L .53078 .85855 L F
.585 .623 .856 r
.53288 .85575 m .53078 .85855 L .53108 .85627 L F
.428 .739 .992 r
.56777 .78464 m .5689 .7836 L .56697 .78375 L F
0 .08 .623 r
.56777 .78464 m .56939 .78581 L .5689 .7836 L F
.56777 .78464 m .56945 .78753 L .56939 .78581 L F
.37 .48 .842 r
.68454 .75284 m .68372 .75082 L .68584 .75001 L F
.173 0 0 r
.68583 .75036 m .68584 .75001 L .68372 .75082 L F
.68583 .75036 m .68685 .74996 L .68584 .75001 L F
.956 .777 .619 r
.60284 .82954 m .60371 .82673 L .60235 .82589 L F
0 0 0 r
.56608 .81843 m .56486 .81886 L .56501 .81879 L F
.84 .564 .52 r
.57872 .79779 m .57626 .79737 L .57581 .79502 L F
.88 .63 .557 r
.57846 .79977 m .57626 .79737 L .57872 .79779 L F
.543 .382 .613 r
.45761 .8618 m .45966 .86158 L .45959 .85876 L F
.528 .44 .699 r
.45819 .8641 m .45966 .86158 L .45761 .8618 L F
.277 .137 .503 r
.47453 .85593 m .47489 .85899 L .47389 .85883 L F
.289 .326 .727 r
.47599 .85356 m .47453 .85593 L .47563 .85408 L F
.47599 .85356 m .47563 .85408 L .47725 .85341 L F
.47599 .85356 m .47725 .85341 L .47779 .85319 L F
.408 0 0 r
.47779 .85319 m .47599 .85356 L .47422 .85304 L F
.289 .326 .727 r
.47599 .85356 m .47779 .85319 L .47422 .85304 L F
.461 .316 .597 r
.47422 .85304 m .47599 .85356 L .47648 .85104 L F
0 .465 .815 r
.47502 .85305 m .47599 .85356 L .47422 .85304 L F
0 .032 .572 r
.47502 .85305 m .47547 .85362 L .47599 .85356 L F
.289 .326 .727 r
.47599 .85356 m .4766 .85505 L .47453 .85593 L F
0 .032 .572 r
.47547 .85362 m .4766 .85505 L .47599 .85356 L F
.316 .164 .51 r
.47686 .8575 m .47453 .85593 L .4766 .85505 L F
.47686 .8575 m .47489 .85899 L .47453 .85593 L F
.336 .724 .984 r
.39906 .74469 m .39972 .74392 L .39775 .74392 L F
.231 .58 .944 r
.39906 .74469 m .4013 .74536 L .39972 .74392 L F
.515 .306 .533 r
.66205 .61152 m .65994 .61188 L .65967 .61294 L F
.818 .602 .609 r
.47411 .83742 m .47408 .83951 L .47696 .83987 L F
.808 .703 .749 r
.47408 .83951 m .47567 .84095 L .47696 .83987 L F
.563 .381 .593 r
.44424 .73672 m .44426 .73954 L .44213 .73986 L F
.553 .557 .812 r
.44511 .7341 m .44424 .73672 L .44342 .73387 L F
.44511 .7341 m .44628 .73656 L .44424 .73672 L F
.596 .407 .596 r
.44649 .73901 m .44424 .73672 L .44628 .73656 L F
.44649 .73901 m .44426 .73954 L .44424 .73672 L F
.497 .002 .011 r
.49647 .89011 m .49968 .88968 L .49857 .8898 L F
.815 .862 .883 r
.49968 .88968 m .50028 .88749 L .49857 .8898 L F
.49968 .88968 m .502 .88781 L .50028 .88749 L F
0 0 0 r
.49954 .87935 m .50049 .87786 L .5015 .87741 L F
.49954 .87935 m .5015 .87741 L .50155 .8775 L F
.575 .475 .703 r
.50179 .87728 m .50173 .87891 L .49954 .87935 L F
.50173 .87891 m .50171 .87939 L .50134 .87938 L F
.50173 .87891 m .50134 .87938 L .49954 .87935 L F
.988 .828 .593 r
.5007 .87908 m .50171 .87939 L .50179 .87728 L F
.487 .894 .926 r
.50315 .87649 m .50384 .87671 L .50179 .87728 L F
.988 .828 .593 r
.5007 .87908 m .50179 .87728 L .50384 .87671 L F
.5007 .87908 m .50295 .87738 L .50315 .87649 L F
.50295 .87738 m .50384 .87671 L .50356 .87662 L F
.50295 .87738 m .50356 .87662 L .50315 .87649 L F
.609 .07 0 r
.49932 .87592 m .50159 .87756 L .49828 .8746 L F
.50159 .87756 m .50164 .87759 L .50158 .87754 L F
.50159 .87756 m .50158 .87754 L .49828 .8746 L F
0 0 0 r
.50155 .8775 m .5015 .87741 L .50179 .87728 L F
.855 .422 .189 r
.54426 .82187 m .54482 .82315 L .54549 .82193 L F
.872 .448 .2 r
.54482 .82315 m .54795 .82566 L .54549 .82193 L F
.79 .395 .304 r
.57423 .78992 m .57158 .78973 L .5706 .78784 L F
.794 .643 .695 r
.57415 .79221 m .57158 .78973 L .57423 .78992 L F
.282 .391 .797 r
.49499 .84937 m .49414 .85072 L .49317 .84745 L F
.49499 .84937 m .49576 .85095 L .49414 .85072 L F
.349 .147 .458 r
.49576 .85095 m .49384 .85314 L .49414 .85072 L F
.498 .177 .354 r
.3599 .75508 m .35892 .75746 L .35678 .75771 L F
.427 .079 .271 r
.36199 .75476 m .35892 .75746 L .3599 .75508 L F
.507 .57 .854 r
.50412 .87143 m .50475 .8688 L .50331 .86869 L F
.50412 .87143 m .50611 .87146 L .50475 .8688 L F
.761 .582 .655 r
.65495 .62788 m .65778 .6272 L .65845 .62595 L F
.713 .428 .491 r
.65999 .62743 m .65845 .62595 L .65778 .6272 L F
.56 .534 .783 r
.35009 .67783 m .34924 .68134 L .34806 .67825 L F
.35009 .67783 m .35138 .68086 L .34924 .68134 L F
.52 .368 .615 r
.35138 .68086 m .35127 .68318 L .34924 .68134 L F
.478 .368 .65 r
.35127 .68318 m .34958 .68385 L .34924 .68134 L F
.639 .236 .263 r
.56423 .78067 m .56558 .781 L .5667 .77927 L F
.767 .39 .341 r
.56558 .781 m .5686 .7815 L .5667 .77927 L F
.659 .739 .909 r
.66746 .61325 m .66864 .61468 L .66242 .61307 L F
.768 .624 .701 r
.66864 .61468 m .66676 .61681 L .66242 .61307 L F
.47 .658 .943 r
.66746 .61325 m .67024 .61328 L .66864 .61468 L F
.298 .355 .753 r
.67024 .61328 m .67131 .61697 L .66864 .61468 L F
.899 .483 .17 r
.48761 .8587 m .48765 .8609 L .48643 .85813 L F
.48761 .8587 m .48892 .86144 L .48765 .8609 L F
.73 .256 .123 r
.48892 .86144 m .49074 .86149 L .48933 .86205 L F
.369 0 0 r
.49074 .86149 m .49143 .8625 L .48933 .86205 L F
.49074 .86149 m .49292 .86158 L .49143 .8625 L F
.918 .892 .789 r
.57572 .82935 m .57434 .82908 L .576 .82641 L F
.452 .431 .745 r
.70095 .72793 m .69907 .72941 L .69845 .72615 L F
.538 .591 .855 r
.70095 .72793 m .70233 .73099 L .69907 .72941 L F
.35 .008 .237 r
.40694 .78413 m .40433 .78586 L .40494 .78436 L F
.907 .503 .211 r
.5706 .78784 m .57004 .78892 L .56945 .78753 L F
.846 .404 .17 r
.5706 .78784 m .57158 .78973 L .57004 .78892 L F
.403 .69 .978 r
.31697 .65621 m .31641 .65738 L .315 .65655 L F
.31697 .65621 m .31827 .65739 L .31641 .65738 L F
.54 .507 .768 r
.44514 .74392 m .44319 .74523 L .44234 .74213 L F
.531 .49 .755 r
.44506 .74477 m .44319 .74523 L .44514 .74392 L F
.557 .547 .799 r
.44622 .74779 m .44319 .74523 L .44506 .74477 L F
.632 .824 .974 r
.70642 .73721 m .70959 .73745 L .70846 .73607 L F
.771 .781 .861 r
.70846 .73607 m .70959 .73745 L .71138 .73574 L F
.817 .571 .568 r
.49788 .84622 m .50327 .84555 L .49997 .8454 L F
.691 .754 .9 r
.49788 .84622 m .50135 .84885 L .50236 .84831 L F
.49985 .84682 m .50236 .84831 L .50322 .84784 L F
.49788 .84622 m .50236 .84831 L .49985 .84682 L F
.955 .666 .228 r
.49821 .846 m .49788 .84622 L .49997 .8454 L F
.686 .351 .403 r
.49821 .846 m .49714 .84708 L .49481 .84592 L F
.532 .417 .668 r
.49709 .84474 m .49714 .84708 L .49821 .846 L F
.49709 .84474 m .49917 .84672 L .49714 .84708 L F
.725 .194 0 r
.49736 .84562 m .49917 .84672 L .49833 .84592 L F
.532 .417 .668 r
.49709 .84474 m .49821 .846 L .49997 .8454 L F
.725 .194 0 r
.49744 .84539 m .49833 .84592 L .49752 .84515 L F
.49736 .84562 m .49833 .84592 L .49744 .84539 L F
.49713 .84487 m .49752 .84515 L .49709 .84474 L F
.49736 .84562 m .49752 .84515 L .49713 .84487 L F
.817 .571 .568 r
.49885 .8461 m .50322 .84784 L .50327 .84555 L F
.49788 .84622 m .49985 .84682 L .49885 .8461 L F
.49985 .84682 m .50322 .84784 L .49885 .8461 L F
0 0 0 r
.40455 .77103 m .40576 .77055 L .40698 .76885 L F
.462 .055 .181 r
.40698 .76885 m .40787 .77019 L .40894 .76892 L F
.40698 .76885 m .40576 .77055 L .40787 .77019 L F
.898 .51 .071 r
.57851 .80533 m .57796 .80533 L .57697 .80272 L F
.794 .584 .617 r
.58014 .80766 m .57796 .80533 L .57851 .80533 L F
.528 .44 .699 r
.45819 .8641 m .46013 .86377 L .45966 .86158 L F
.6 .363 .528 r
.45819 .8641 m .46024 .86618 L .46013 .86377 L F
.45819 .8641 m .45798 .86653 L .46024 .86618 L F
.842 .666 .663 r
.5851 .79207 m .58671 .79265 L .58533 .78974 L F
.845 .649 .637 r
.5851 .79207 m .58651 .79502 L .58671 .79265 L F
.768 .676 .761 r
.64224 .73409 m .64542 .73452 L .64391 .73379 L F
.766 .748 .836 r
.64542 .73452 m .64647 .73099 L .64391 .73379 L F
.64542 .73452 m .648 .73246 L .64647 .73099 L F
.03 0 0 r
.67469 .71055 m .67551 .71015 L .67535 .71019 L F
.67469 .71055 m .67535 .71019 L .67319 .71067 L F
.67469 .71055 m .67319 .71067 L .67246 .70864 L F
.724 .299 .238 r
.67469 .71055 m .67551 .71015 L .67246 .70864 L F
.406 .383 .72 r
.67362 .70797 m .67469 .71055 L .67246 .70864 L F
.982 .895 .655 r
.67469 .71055 m .67384 .70953 L .67315 .71141 L F
.67469 .71055 m .67315 .71141 L .67308 .71158 L F
.852 .747 .748 r
.70295 .7363 m .70112 .73908 L .70354 .73944 L F
.795 .575 .603 r
.70064 .74104 m .70354 .73944 L .70112 .73908 L F
.70064 .74104 m .70346 .74127 L .70354 .73944 L F
.696 .648 .798 r
.70295 .7363 m .70354 .73944 L .70642 .73721 L F
.67 .134 0 r
.50028 .88749 m .49878 .88624 L .49803 .88653 L F
.48 .652 .935 r
.45065 .74956 m .45014 .75158 L .44855 .74982 L F
.45065 .74956 m .45225 .75154 L .45014 .75158 L F
.07 0 0 r
.38036 .78497 m .38006 .78474 L .37827 .78581 L F
.38036 .78497 m .38216 .78465 L .38006 .78474 L F
.308 .492 .876 r
.71928 .7258 m .72105 .72843 L .7184 .72735 L F
.71928 .7258 m .7184 .72735 L .71859 .72845 L F
.473 .467 .77 r
.45732 .75235 m .45806 .75404 L .45604 .75445 L F
.61 .457 .65 r
.45806 .75404 m .45574 .75761 L .45604 .75445 L F
.326 0 .05 r
.41988 .77617 m .41907 .77695 L .41711 .77728 L F
.503 .116 .239 r
.42194 .7759 m .41907 .77695 L .41988 .77617 L F
.409 .046 .233 r
.41711 .77728 m .41603 .77887 L .41422 .77905 L F
.516 .199 .368 r
.41907 .77695 m .41603 .77887 L .41711 .77728 L F
.913 .51 .153 r
.63959 .63331 m .63929 .63404 L .63878 .63332 L F
.768 .996 .854 r
.64054 .63141 m .63959 .63331 L .63878 .63332 L F
.64054 .63141 m .64196 .63132 L .63959 .63331 L F
.947 .62 .196 r
.63959 .63331 m .63998 .63578 L .63929 .63404 L F
.913 .51 .153 r
.63959 .63331 m .63929 .63404 L .63878 .63332 L F
.63 .498 .682 r
.67848 .6952 m .68065 .6964 L .68054 .69449 L F
.67848 .6952 m .67857 .69741 L .68065 .6964 L F
.623 .422 .589 r
.47919 .84112 m .48268 .8423 L .48078 .8401 L F
.603 .462 .662 r
.47919 .84112 m .48114 .84349 L .48268 .8423 L F
.459 0 0 r
.51574 .87527 m .51274 .87387 L .51466 .87486 L F
.468 0 0 r
.51678 .87637 m .51574 .87527 L .51466 .87486 L F
.389 .537 .883 r
.51886 .877 m .51574 .87527 L .51788 .87566 L F
.468 0 0 r
.51678 .87637 m .51788 .87566 L .51574 .87527 L F
.661 .221 .194 r
.55973 .82167 m .5617 .82343 L .56235 .82216 L F
.831 .625 .624 r
.56337 .82319 m .56235 .82216 L .5617 .82343 L F
.642 .579 .769 r
.6368 .73399 m .64067 .73571 L .63891 .7336 L F
.473 .173 .376 r
.66468 .63579 m .6621 .63779 L .6624 .63601 L F
.914 .675 .562 r
.67059 .72094 m .66911 .72042 L .66915 .71811 L F
.931 .69 .552 r
.67059 .72094 m .66919 .72271 L .66911 .72042 L F
.67059 .72094 m .67068 .72343 L .66919 .72271 L F
.914 .675 .562 r
.66915 .71811 m .66911 .72042 L .67059 .72094 L F
.931 .69 .552 r
.67059 .72094 m .66919 .72271 L .66911 .72042 L F
.67059 .72094 m .67068 .72343 L .66919 .72271 L F
.37 .57 .916 r
.32018 .67656 m .32067 .67535 L .31947 .67566 L F
.32018 .67656 m .3232 .67807 L .32067 .67535 L F
.72 .458 .528 r
.63864 .64147 m .63543 .64341 L .6355 .64106 L F
.63864 .64147 m .63888 .6436 L .63543 .64341 L F
.802 .57 .587 r
.64645 .72863 m .6495 .73124 L .6504 .72925 L F
0 0 0 r
.34988 .81089 m .35179 .81046 L .35096 .81077 L F
.658 .424 .554 r
.48078 .8401 m .48268 .8423 L .48288 .84022 L F
.467 .861 .972 r
.5778 .84493 m .57896 .84411 L .5768 .84465 L F
.5778 .84493 m .57909 .84462 L .57896 .84411 L F
.506 .266 .485 r
.53723 .83496 m .53936 .83462 L .53974 .83231 L F
.485 .362 .637 r
.53974 .83231 m .5413 .8294 L .53893 .83083 L F
.53974 .83231 m .54175 .83212 L .5413 .8294 L F
.405 .178 .453 r
.53974 .83231 m .54124 .83406 L .54175 .83212 L F
.53974 .83231 m .53936 .83462 L .54124 .83406 L F
.522 .29 .505 r
.40346 .77307 m .40576 .77055 L .40455 .77103 L F
.887 .793 .751 r
.51453 .88427 m .51548 .88323 L .5142 .88161 L F
.613 .469 .662 r
.44454 .74169 m .44213 .73986 L .44426 .73954 L F
.44454 .74169 m .44234 .74213 L .44213 .73986 L F
.419 .842 .958 r
.48175 .8836 m .48499 .88355 L .48373 .88403 L F
.721 .913 .961 r
.48499 .88355 m .48513 .88216 L .48373 .88403 L F
.576 .742 .955 r
.56608 .81843 m .56772 .81959 L .56486 .81886 L F
.727 .643 .765 r
.56397 .81886 m .56772 .81959 L .56608 .81843 L F
.297 0 0 r
.55845 .82324 m .5617 .82343 L .55973 .82167 L F
.353 .689 .981 r
.49209 .87065 m .49319 .87151 L .49425 .87085 L F
.49209 .87065 m .49319 .87151 L .49425 .87085 L F
.36 .463 .83 r
.32879 .65964 m .3286 .66213 L .32703 .65961 L F
.32879 .65964 m .33025 .66259 L .3286 .66213 L F
.845 .562 .509 r
.58397 .78462 m .58414 .78679 L .58604 .78696 L F
.856 .702 .691 r
.58414 .78679 m .58533 .78974 L .58604 .78696 L F
.85 .645 .105 r
.55949 .81319 m .55964 .81607 L .5599 .81627 L F
.792 .603 .646 r
.55768 .8187 m .5599 .81627 L .55964 .81607 L F
.55768 .8187 m .55883 .81923 L .5599 .81627 L F
.891 .659 .582 r
.60245 .82395 m .60273 .82151 L .60033 .82101 L F
.185 .671 .926 r
.44208 .7335 m .44511 .7341 L .44342 .73387 L F
.593 .654 .879 r
.4552 .87645 m .45821 .87771 L .4573 .87584 L F
.485 .606 .897 r
.45821 .87771 m .45944 .87639 L .4573 .87584 L F
.45821 .87771 m .46079 .87796 L .45944 .87639 L F
.318 0 0 r
.58867 .81269 m .588 .81214 L .58765 .81044 L F
.58867 .81269 m .58864 .81271 L .588 .81214 L F
.832 .56 .527 r
.69576 .75004 m .69323 .74873 L .69536 .75069 L F
.949 .865 .448 r
.69576 .75004 m .69536 .75069 L .69593 .74648 L F
0 0 0 r
.69678 .74947 m .69576 .75004 L .69732 .75046 L F
.69678 .74947 m .69466 .75174 L .69576 .75004 L F
.641 .081 0 r
.48024 .8546 m .47955 .85482 L .47779 .85319 L F
.844 .561 .509 r
.58135 .78597 m .58397 .78462 L .58092 .78404 L F
.58135 .78597 m .58414 .78679 L .58397 .78462 L F
0 .156 .647 r
.65846 .72748 m .65733 .72683 L .65701 .72732 L F
.514 .315 .549 r
.65733 .72683 m .65953 .72854 L .65979 .72594 L F
0 .156 .647 r
.65846 .72748 m .65953 .72854 L .65733 .72683 L F
.628 .603 .805 r
.45498 .87476 m .45592 .87132 L .45462 .87324 L F
.45498 .87476 m .45723 .87443 L .45592 .87132 L F
.597 .471 .678 r
.4552 .87645 m .45723 .87443 L .45498 .87476 L F
.87 .629 .099 r
.68033 .73544 m .68019 .73587 L .68065 .73707 L F
0 0 0 r
.68019 .73587 m .68194 .73531 L .67999 .7365 L F
.898 .968 .821 r
.68065 .73707 m .68019 .73587 L .67811 .73858 L F
0 0 0 r
.68019 .73587 m .67999 .7365 L .67909 .73705 L F
.87 .629 .099 r
.67996 .73363 m .68019 .73587 L .68033 .73544 L F
.898 .968 .821 r
.68065 .73707 m .67811 .73858 L .67959 .73958 L F
.081 0 .401 r
.49585 .8748 m .49435 .87723 L .49453 .87654 L F
.787 .338 .18 r
.49435 .87723 m .49627 .87948 L .49475 .87949 L F
.49435 .87723 m .49475 .87949 L .49453 .87654 L F
.489 .236 .458 r
.71829 .73317 m .71916 .73196 L .71941 .7319 L F
0 0 .15 r
.72053 .72888 m .7206 .73052 L .71941 .7319 L F
.538 .819 .469 r
.7206 .73052 m .71829 .73317 L .71941 .7319 L F
.623 .701 .901 r
.51907 .85301 m .52215 .85378 L .52127 .85241 L F
.556 .669 .913 r
.52127 .85241 m .52215 .85378 L .52418 .85343 L F
.323 .432 .818 r
.52215 .85378 m .52465 .85647 L .52418 .85343 L F
.595 .087 0 r
.66326 .615 m .66389 .61591 L .66242 .61307 L F
.577 .604 .843 r
.42589 .72935 m .42294 .72801 L .42472 .7279 L F
.394 .625 .946 r
.67318 .62941 m .67226 .63083 L .67153 .6295 L F
0 0 .41 r
.67318 .62941 m .67219 .63294 L .67226 .63083 L F
0 0 0 r
.51457 .88069 m .51596 .88046 L .51558 .87999 L F
.591 .548 .774 r
.51294 .87688 m .51457 .88069 L .51558 .87999 L F
.864 .502 .003 r
.51505 .87934 m .51558 .87999 L .51639 .88259 L F
.591 .548 .774 r
.51294 .87688 m .51558 .87999 L .51488 .87891 L F
.864 .502 .003 r
.51488 .87891 m .51558 .87999 L .51505 .87934 L F
0 0 0 r
.51596 .88046 m .51664 .88035 L .51558 .87999 L F
.635 .253 .303 r
.51664 .88035 m .51639 .88259 L .51558 .87999 L F
.555 .726 .954 r
.6667 .61068 m .66545 .61219 L .66438 .6109 L F
.387 .471 .825 r
.6667 .61068 m .66746 .61325 L .66545 .61219 L F
.796 .692 .751 r
.68575 .69421 m .68474 .69576 L .68277 .69413 L F
.68575 .69421 m .68277 .69413 L .68508 .69424 L F
.788 .73 .799 r
.68277 .69413 m .68575 .69421 L .68508 .69424 L F
.4 .839 .942 r
.6883 .69398 m .68508 .69424 L .68575 .69421 L F
.6883 .69398 m .68508 .69424 L .68575 .69421 L F
0 0 .14 r
.72105 .72843 m .7206 .73052 L .72053 .72888 L F
.488 .164 .344 r
.65751 .63926 m .65717 .64071 L .6549 .64105 L F
.545 .293 .484 r
.65751 .63926 m .65954 .64091 L .65717 .64071 L F
.65751 .63926 m .66006 .63826 L .65954 .64091 L F
.847 .485 .367 r
.49669 .86335 m .49944 .86468 L .49798 .86588 L F
.676 .236 .197 r
.49944 .86468 m .50197 .86653 L .49798 .86588 L F
.199 .583 .942 r
.54753 .80785 m .54939 .80824 L .55028 .80937 L F
.838 .552 .504 r
.54939 .80824 m .55218 .81017 L .55028 .80937 L F
.554 .926 .79 r
.69286 .75292 m .6934 .75287 L .69466 .75174 L F
.413 .012 .166 r
.34131 .73916 m .34351 .73894 L .34478 .73697 L F
.186 0 .036 r
.34478 .73697 m .34522 .73822 L .34661 .73642 L F
.34478 .73697 m .34351 .73894 L .34522 .73822 L F
.88 .692 .644 r
.69193 .7363 m .69061 .73318 L .69234 .73427 L F
0 0 0 r
.35952 .80724 m .35834 .80775 L .35744 .80809 L F
.35834 .80775 m .3565 .80856 L .35744 .80809 L F
.556 .83 .997 r
.37235 .7869 m .3691 .78683 L .3713 .78621 L F
.211 .633 .952 r
.3713 .78621 m .373 .78643 L .37235 .7869 L F
.263 .712 .958 r
.373 .78643 m .37468 .7871 L .37235 .7869 L F
.8 .344 .158 r
.69059 .74292 m .6905 .74396 L .6881 .74157 L F
.581 .242 .361 r
.69357 .74331 m .6905 .74396 L .69059 .74292 L F
.897 .733 .67 r
.50028 .88749 m .502 .88781 L .50142 .88502 L F
.035 .139 .643 r
.50142 .88502 m .502 .88781 L .50296 .88703 L F
.249 .532 .919 r
.50296 .88703 m .502 .88781 L .50376 .88827 L F
.764 .568 .633 r
.64202 .64615 m .63888 .6436 L .64192 .64405 L F
.126 .675 .786 r
.68847 .74949 m .69205 .74925 L .69323 .74873 L F
.68847 .74949 m .68906 .74939 L .69205 .74925 L F
.095 0 0 r
.39648 .72302 m .39844 .72316 L .39988 .72319 L F
0 .553 .75 r
.39844 .72316 m .40175 .72353 L .39988 .72319 L F
.549 .449 .693 r
.5062 .87889 m .50652 .88328 L .5084 .88245 L F
.588 .443 .651 r
.45966 .86158 m .46164 .85828 L .45959 .85876 L F
.541 .346 .566 r
.64299 .63622 m .64082 .63924 L .63998 .63578 L F
.64299 .63622 m .64316 .63862 L .64082 .63924 L F
.034 0 0 r
.39206 .79229 m .38957 .79418 L .39012 .79284 L F
.157 .698 .754 r
.3911 .72382 m .3931 .7235 L .39423 .72339 L F
.242 0 0 r
.3931 .7235 m .39648 .72302 L .39423 .72339 L F
.702 .477 0 r
.56081 .83475 m .56074 .83437 L .5603 .83175 L F
0 0 .273 r
.56081 .83475 m .56175 .83741 L .56074 .83437 L F
.337 .471 .848 r
.66679 .62273 m .66796 .62517 L .66773 .62285 L F
.849 .769 .774 r
.512 .85844 m .51556 .85711 L .51128 .85587 L F
.512 .85844 m .51437 .85857 L .51556 .85711 L F
.925 .663 .522 r
.5486 .82672 m .54874 .82907 L .55031 .82946 L F
.89 .569 .435 r
.54915 .83134 m .55031 .82946 L .54874 .82907 L F
.54915 .83134 m .55075 .83182 L .55031 .82946 L F
.192 0 .014 r
.37677 .79995 m .37985 .79744 L .37865 .79915 L F
.303 0 .059 r
.37865 .79915 m .37985 .79744 L .38177 .79685 L F
.511 .878 .979 r
.68148 .71268 m .67863 .71285 L .68033 .71599 L F
.81 .693 .736 r
.67738 .71487 m .68033 .71599 L .67863 .71285 L F
.833 .462 .35 r
.67908 .71703 m .68033 .71599 L .67738 .71487 L F
.989 .833 .595 r
.67978 .71851 m .68033 .71599 L .67908 .71703 L F
.769 .583 .647 r
.58777 .80024 m .59114 .80293 L .59109 .80053 L F
.622 .742 .932 r
.58611 .8449 m .58926 .84527 L .58849 .84557 L F
.614 .73 .928 r
.58926 .84527 m .59063 .84306 L .58849 .84557 L F
.58926 .84527 m .59137 .84484 L .59063 .84306 L F
.682 .534 .678 r
.49097 .82396 m .49117 .8251 L .49352 .82461 L F
.49352 .82461 m .49097 .82396 L .49225 .82363 L F
.49352 .82461 m .49117 .8251 L .49097 .82396 L F
.338 0 .002 r
.36202 .72934 m .36336 .72984 L .36492 .72826 L F
.227 0 0 r
.36336 .72984 m .36692 .72797 L .36492 .72826 L F
.692 .794 .928 r
.35065 .79411 m .35196 .79529 L .34855 .795 L F
.662 .785 .94 r
.3538 .79444 m .35196 .79529 L .35065 .79411 L F
.754 .627 .72 r
.48918 .84509 m .48758 .84606 L .48906 .84304 L F
.48918 .84509 m .48758 .84606 L .48906 .84304 L F
.711 .268 .197 r
.48583 .84568 m .48596 .84594 L .48413 .8453 L F
.48758 .84606 m .48596 .84594 L .48583 .84568 L F
.141 0 0 r
.48479 .84714 m .48628 .8469 L .48758 .84606 L F
.48401 .84744 m .48628 .8469 L .48479 .84714 L F
.467 .324 .603 r
.48628 .8469 m .48808 .84706 L .48815 .8466 L F
.799 .749 .806 r
.48758 .84606 m .48596 .84594 L .48918 .84509 L F
.48758 .84606 m .48596 .84594 L .48918 .84509 L F
.74 .331 .273 r
.48758 .84606 m .48628 .8469 L .48596 .84594 L F
.467 .324 .603 r
.48628 .8469 m .48815 .8466 L .48863 .84307 L F
.48628 .8469 m .48635 .84679 L .48596 .84594 L F
.48635 .84679 m .48863 .84307 L .48596 .84594 L F
.681 .608 .768 r
.49151 .84239 m .48918 .84509 L .48906 .84304 L F
.49151 .84239 m .49264 .84549 L .48918 .84509 L F
.721 .679 .809 r
.58659 .80801 m .58761 .80787 L .58886 .80604 L F
.638 .563 .754 r
.58886 .80604 m .58761 .80787 L .59095 .80532 L F
.496 .182 .364 r
.42411 .76284 m .42624 .76254 L .42716 .76012 L F
.584 .399 .596 r
.42716 .76012 m .42932 .76009 L .4294 .75796 L F
.54 .226 .384 r
.42716 .76012 m .4286 .76225 L .42932 .76009 L F
.42716 .76012 m .42624 .76254 L .4286 .76225 L F
.511 .878 .979 r
.68148 .71268 m .68098 .7123 L .67863 .71285 L F
.619 .662 .869 r
.43795 .73402 m .43481 .73242 L .43656 .73169 L F
.625 .662 .865 r
.44009 .7334 m .43795 .73402 L .43656 .73169 L F
.2 0 0 r
.4083 .7435 m .40728 .74366 L .40517 .74349 L F
0 .561 .756 r
.40517 .74349 m .40728 .74366 L .40501 .74343 L F
.40517 .74349 m .40501 .74343 L .40386 .74331 L F
0 0 0 r
.40517 .74349 m .40416 .74384 L .4054 .74358 L F
.40517 .74349 m .4054 .74358 L .40658 .74334 L F
.40517 .74349 m .40339 .74459 L .40416 .74384 L F
.421 .198 .467 r
.33069 .70902 m .32978 .70746 L .3313 .70671 L F
.33069 .70902 m .32917 .70967 L .32978 .70746 L F
.642 .471 .636 r
.4294 .75796 m .43173 .75781 L .43163 .75541 L F
.627 .508 .699 r
.43163 .75541 m .43388 .75516 L .43363 .7528 L F
.617 .451 .635 r
.43163 .75541 m .43173 .75781 L .43388 .75516 L F
.562 .262 .416 r
.45373 .75812 m .45122 .76003 L .45163 .75862 L F
.597 .471 .678 r
.4552 .87645 m .4573 .87584 L .45723 .87443 L F
.456 .25 .511 r
.32758 .71012 m .32733 .71198 L .3256 .71293 L F
.463 .257 .513 r
.32887 .71137 m .32758 .71012 L .32917 .70967 L F
.32887 .71137 m .32733 .71198 L .32758 .71012 L F
.742 .595 .693 r
.65314 .60743 m .65337 .60701 L .65013 .60667 L F
.157 0 0 r
.65314 .60743 m .6561 .60706 L .65337 .60701 L F
.745 .565 .651 r
.65013 .60667 m .65307 .60722 L .65303 .60733 L F
.65307 .60722 m .65338 .60728 L .65313 .60732 L F
.65307 .60722 m .65313 .60732 L .65303 .60733 L F
.65303 .60733 m .65338 .60728 L .65339 .60742 L F
.403 .435 .78 r
.65315 .60735 m .6532 .60743 L .65314 .60743 L F
.65315 .60735 m .65314 .60743 L .6531 .60732 L F
.758 .702 .799 r
.65303 .60733 m .6531 .60732 L .65314 .60743 L F
.65303 .60733 m .65314 .60743 L .65013 .60667 L F
.745 .565 .651 r
.65013 .60667 m .65339 .60742 L .65354 .60945 L F
.659 .381 .488 r
.65339 .6074 m .65565 .60886 L .65354 .60945 L F
.65337 .60701 m .65382 .60738 L .65339 .6074 L F
.65382 .60738 m .65565 .60886 L .65339 .6074 L F
.65382 .60738 m .6561 .60706 L .65565 .60886 L F
.65337 .60701 m .6561 .60706 L .65382 .60738 L F
.599 .619 .843 r
.65565 .60886 m .65624 .60739 L .65448 .60789 L F
.157 0 0 r
.65365 .6074 m .65591 .60745 L .65608 .60725 L F
.65591 .60745 m .65606 .60742 L .65608 .60725 L F
.65341 .60743 m .65605 .60745 L .65365 .6074 L F
.65339 .6074 m .65608 .60725 L .6561 .60706 L F
.65314 .60743 m .65608 .60725 L .65339 .6074 L F
.403 .435 .78 r
.6537 .60267 m .65596 .60725 L .6532 .60743 L F
.599 .619 .843 r
.65606 .60742 m .6561 .60704 L .6559 .60745 L F
.6561 .60704 m .65596 .60725 L .6559 .60745 L F
0 0 0 r
.65715 .60652 m .65676 .60608 L .65785 .60617 L F
.6561 .60706 m .65676 .60608 L .65715 .60652 L F
.621 .458 .641 r
.65785 .60617 m .65565 .60886 L .6561 .60706 L F
.65785 .60617 m .6581 .60894 L .65565 .60886 L F
.379 .839 .901 r
.65908 .60563 m .65785 .60617 L .65676 .60608 L F
.55 .406 .638 r
.66045 .6085 m .6581 .60894 L .65785 .60617 L F
.599 .619 .843 r
.65624 .60739 m .65621 .60713 L .65606 .60742 L F
.305 .379 .774 r
.65908 .60563 m .66045 .6085 L .65785 .60617 L F
.72 .704 .835 r
.65908 .60563 m .65689 .60695 L .65676 .60608 L F
.599 .619 .843 r
.65565 .60886 m .6572 .60891 L .65676 .60608 L F
.72 .704 .835 r
.65689 .60695 m .65605 .60745 L .65676 .60608 L F
.599 .619 .843 r
.6572 .60891 m .6581 .60894 L .65676 .60608 L F
.574 .524 .762 r
.65676 .60608 m .6537 .60267 L .65569 .60223 L F
.72 .68 .811 r
.65797 .60176 m .65908 .60563 L .65676 .60608 L F
.65797 .60176 m .65676 .60608 L .65569 .60223 L F
0 .312 .732 r
.65676 .60608 m .65902 .60724 L .65632 .60559 L F
.574 .524 .762 r
.65676 .60608 m .65596 .60725 L .6537 .60267 L F
0 .312 .732 r
.65676 .60608 m .65632 .60559 L .65601 .6054 L F
0 0 0 r
.6561 .60706 m .65606 .60742 L .65676 .60608 L F
.599 .619 .843 r
.65621 .60713 m .65615 .60656 L .65606 .60742 L F
.65624 .60739 m .65676 .60608 L .65615 .60656 L F
0 0 0 r
.65606 .60742 m .65605 .60745 L .65676 .60608 L F
.574 .524 .762 r
.65676 .60608 m .65605 .60745 L .65596 .60725 L F
.599 .619 .843 r
.6561 .60704 m .65615 .60656 L .65596 .60725 L F
.65624 .60739 m .65475 .60767 L .65448 .60789 L F
.157 0 0 r
.65591 .60745 m .65605 .60745 L .65606 .60742 L F
.403 .435 .78 r
.65596 .60725 m .65605 .60745 L .6559 .60745 L F
.157 0 0 r
.65314 .60743 m .65341 .60743 L .65365 .6074 L F
.403 .435 .78 r
.65596 .60725 m .6559 .60745 L .6532 .60743 L F
.599 .619 .843 r
.6559 .60745 m .65615 .60656 L .65475 .60767 L F
.745 .565 .651 r
.65286 .60718 m .65337 .60701 L .65338 .60728 L F
.403 .435 .78 r
.6537 .60267 m .6532 .60743 L .65315 .60735 L F
.6537 .60267 m .65315 .60735 L .65137 .60311 L F
.65315 .60735 m .6531 .60732 L .65137 .60311 L F
.745 .565 .651 r
.65013 .60667 m .65238 .60691 L .65286 .60718 L F
.65238 .60691 m .65337 .60701 L .65286 .60718 L F
.758 .702 .799 r
.64948 .60428 m .65137 .60311 L .6531 .60732 L F
.64948 .60428 m .6531 .60732 L .65303 .60733 L F
.64948 .60428 m .65303 .60733 L .65013 .60667 L F
.156 0 .029 r
.52447 .83117 m .52726 .82866 L .52495 .82909 L F
.87 .505 .013 r
.5854 .80551 m .58609 .80765 L .58659 .80801 L F
.721 .679 .809 r
.58659 .80801 m .58886 .80604 L .5854 .80551 L F
.874 .505 .344 r
.58591 .81012 m .58659 .80801 L .58609 .80765 L F
.58591 .81012 m .58796 .81083 L .58659 .80801 L F
.764 .635 .719 r
.60067 .81076 m .59757 .80822 L .59739 .81039 L F
.60067 .81076 m .60097 .80857 L .59757 .80822 L F
.782 .652 .72 r
.59739 .81039 m .59864 .81352 L .60067 .81076 L F
.13 .288 .758 r
.52616 .84194 m .52735 .84491 L .52521 .84283 L F
.421 .109 .328 r
.67219 .63294 m .66989 .63462 L .67 .63341 L F
.709 .468 .559 r
.49247 .8578 m .49345 .85706 L .494 .85489 L F
.983 .717 .441 r
.494 .85489 m .49505 .85604 L .49422 .85404 L F
.146 .368 .823 r
.49588 .85522 m .49505 .85604 L .494 .85489 L F
.709 .468 .559 r
.49345 .85706 m .49588 .85522 L .494 .85489 L F
.983 .717 .441 r
.494 .85489 m .49422 .85404 L .49384 .85314 L F
.146 .368 .823 r
.49588 .85522 m .49747 .85789 L .49505 .85604 L F
.612 .609 .824 r
.46401 .87775 m .46699 .87996 L .46591 .87695 L F
.373 .362 .718 r
.46699 .87996 m .4679 .87679 L .46591 .87695 L F
.46699 .87996 m .46852 .87992 L .4679 .87679 L F
.589 .041 0 r
.46939 .88192 m .46917 .88191 L .46699 .87996 L F
.373 .363 .719 r
.46699 .87996 m .46917 .88191 L .46852 .87992 L F
.757 .809 .894 r
.67696 .74154 m .67811 .73858 L .67599 .73945 L F
.67696 .74154 m .67959 .73958 L .67811 .73858 L F
.376 .238 .563 r
.57111 .82416 m .57267 .82378 L .57249 .82147 L F
.504 .56 .846 r
.57111 .82416 m .57509 .8271 L .57267 .82378 L F
.588 .385 .573 r
.50747 .87346 m .51029 .87174 L .50611 .87146 L F
.50747 .87346 m .5093 .87381 L .51029 .87174 L F
.881 .705 .659 r
.70182 .74401 m .7007 .74728 L .70279 .74721 L F
.899 .861 .794 r
.6999 .7492 m .70279 .74721 L .7007 .74728 L F
.6999 .7492 m .70099 .75005 L .70279 .74721 L F
.522 .359 .602 r
.64287 .62723 m .64145 .63125 L .63983 .62694 L F
0 0 0 r
.641 .63138 m .64422 .63069 L .64196 .63132 L F
.64074 .6314 m .6414 .63126 L .641 .63138 L F
.6414 .63126 m .64422 .63069 L .641 .63138 L F
.522 .359 .602 r
.64145 .63125 m .64368 .63061 L .64139 .6314 L F
.739 .99 .805 r
.64422 .63069 m .64316 .63094 L .64534 .62891 L F
.549 .376 .6 r
.64534 .62891 m .64368 .63061 L .64365 .63047 L F
.64534 .62891 m .64365 .63047 L .64287 .62723 L F
.739 .99 .805 r
.64365 .63047 m .6429 .631 L .64486 .62932 L F
.522 .359 .602 r
.64287 .62723 m .64365 .63047 L .64145 .63125 L F
.64368 .6306 m .64368 .63061 L .64145 .63125 L F
.64145 .63125 m .64135 .63127 L .63983 .62694 L F
.64365 .63047 m .64344 .63066 L .64145 .63125 L F
0 0 0 r
.64054 .63141 m .64273 .63098 L .64135 .63127 L F
.897 .7 .629 r
.64047 .62978 m .64132 .63127 L .64054 .63141 L F
0 0 0 r
.64073 .6314 m .64132 .63127 L .64074 .6314 L F
.64132 .63127 m .64133 .63127 L .64074 .6314 L F
.64054 .63141 m .64135 .63127 L .64073 .6314 L F
.897 .7 .629 r
.64132 .63127 m .64139 .6314 L .64054 .63141 L F
0 0 0 r
.64132 .63127 m .64135 .63127 L .64133 .63127 L F
.831 .692 .711 r
.63983 .62694 m .64135 .63127 L .64047 .62978 L F
.64135 .63127 m .64139 .6314 L .64132 .63127 L F
.64135 .63127 m .64132 .63127 L .64047 .62978 L F
0 0 0 r
.64273 .63098 m .64422 .63069 L .64074 .6314 L F
.64054 .63141 m .6429 .631 L .64422 .63069 L F
.522 .359 .602 r
.64145 .63125 m .64139 .6314 L .64135 .63127 L F
.339 0 0 r
.64368 .63061 m .64054 .63141 L .64139 .6314 L F
.6432 .63073 m .6429 .631 L .64054 .63141 L F
.939 .716 .574 r
.64214 .63164 m .6429 .631 L .64173 .63068 L F
.64315 .63398 m .6429 .631 L .64214 .63164 L F
.339 0 0 r
.64339 .63068 m .6429 .631 L .6432 .63073 L F
.739 .99 .805 r
.64316 .63094 m .64347 .63064 L .64348 .63063 L F
.64314 .63094 m .6429 .631 L .64365 .63047 L F
.339 0 0 r
.64368 .63061 m .6429 .631 L .64339 .63068 L F
.739 .99 .805 r
.64316 .63094 m .64314 .63094 L .64347 .63064 L F
.64348 .63063 m .64347 .63064 L .64365 .63047 L F
.64316 .63094 m .64486 .62932 L .64534 .62891 L F
.522 .359 .602 r
.64365 .63047 m .64368 .6306 L .64344 .63066 L F
.905 .666 .566 r
.57581 .79502 m .57406 .79461 L .57415 .79221 L F
.896 .594 .466 r
.57581 .79502 m .57453 .79686 L .57406 .79461 L F
.902 .604 .471 r
.57626 .79737 m .57453 .79686 L .57581 .79502 L F
.161 0 0 r
.52312 .84532 m .52551 .84578 L .52418 .84558 L F
.406 .228 .525 r
.32352 .69382 m .32578 .69123 L .32369 .69135 L F
.428 .215 .485 r
.32733 .71198 m .32532 .71514 L .3256 .71293 L F
.498 0 0 r
.5433 .81047 m .54484 .81184 L .54209 .81047 L F
.5433 .81047 m .54578 .81251 L .54484 .81184 L F
.237 .019 .366 r
.53517 .83771 m .53573 .83918 L .53599 .83839 L F
.5364 .8371 m .53599 .83839 L .53642 .83709 L F
.53517 .83771 m .53599 .83839 L .5364 .8371 L F
.509 .515 .798 r
.53599 .83839 m .53747 .84325 L .53611 .83835 L F
.779 .558 .601 r
.53573 .83918 m .53377 .83909 L .53599 .83839 L F
.509 .515 .798 r
.53377 .83909 m .53524 .84074 L .53599 .83839 L F
.779 .558 .601 r
.53573 .83918 m .53599 .83839 L .53611 .83835 L F
.509 .515 .798 r
.53524 .84074 m .53747 .84325 L .53599 .83839 L F
.237 .019 .366 r
.53642 .83709 m .53573 .83918 L .5367 .83695 L F
.432 .473 .802 r
.42659 .74383 m .42725 .74112 L .42479 .74168 L F
.42659 .74383 m .42832 .74406 L .42725 .74112 L F
.43 .731 .989 r
.58271 .8436 m .58611 .8449 L .58345 .84359 L F
.64 .713 .9 r
.58382 .84187 m .58345 .84359 L .58684 .8423 L F
.671 .681 .851 r
.58382 .84187 m .58611 .84219 L .58494 .83841 L F
.58617 .84238 m .587 .84228 L .58494 .83841 L F
.707 .696 .837 r
.58706 .84221 m .58715 .84239 L .59063 .84306 L F
.58714 .84239 m .58872 .8453 L .59063 .84306 L F
.58706 .84221 m .59063 .84306 L .58939 .84152 L F
.609 .913 .98 r
.58706 .84221 m .58939 .84152 L .58926 .84075 L F
.58706 .84221 m .58926 .84075 L .58722 .84254 L F
.442 .545 .865 r
.58611 .8449 m .58801 .84543 L .58706 .84221 L F
.609 .913 .98 r
.58706 .84221 m .58722 .84254 L .58717 .84258 L F
.525 .607 .878 r
.58717 .84245 m .58717 .84256 L .58722 .84254 L F
.609 .913 .98 r
.58706 .84221 m .58717 .84258 L .58717 .84259 L F
.525 .607 .878 r
.58717 .84256 m .58717 .84259 L .58717 .84258 L F
.58717 .84256 m .58717 .84258 L .58722 .84254 L F
.442 .545 .865 r
.58801 .84543 m .58849 .84557 L .58714 .84239 L F
.58717 .84258 m .58714 .84239 L .58706 .84221 L F
.58801 .84543 m .58714 .84239 L .58717 .84258 L F
.707 .696 .837 r
.58706 .84221 m .58714 .84239 L .58715 .84239 L F
.58714 .84239 m .58849 .84557 L .58872 .8453 L F
.525 .607 .878 r
.58732 .8397 m .58717 .84245 L .58926 .84075 L F
.58717 .84245 m .58722 .84254 L .58926 .84075 L F
.442 .545 .865 r
.58611 .8449 m .58704 .84227 L .58699 .84229 L F
.58552 .84461 m .58699 .84229 L .58345 .84359 L F
.58611 .8449 m .58699 .84229 L .58552 .84461 L F
.525 .607 .878 r
.58494 .83841 m .587 .84228 L .58702 .84215 L F
.442 .545 .865 r
.58704 .84227 m .58706 .84221 L .58684 .8423 L F
.525 .607 .878 r
.587 .84228 m .58702 .84232 L .58703 .84222 L F
.64 .713 .9 r
.58382 .84187 m .58684 .8423 L .58703 .84222 L F
.58382 .84187 m .58703 .84222 L .58704 .84221 L F
.671 .681 .851 r
.58382 .84187 m .58617 .84238 L .58611 .84219 L F
.58617 .84238 m .58717 .84259 L .587 .84228 L F
.442 .545 .865 r
.58704 .84227 m .58684 .8423 L .58345 .84359 L F
.66 .691 .868 r
.58704 .84221 m .58717 .84259 L .58382 .84187 L F
.64 .713 .9 r
.58704 .84221 m .58703 .84222 L .58706 .84221 L F
.66 .691 .868 r
.58706 .84221 m .58717 .84259 L .58704 .84221 L F
.525 .607 .878 r
.58592 .83894 m .58702 .84215 L .58732 .8397 L F
.58494 .83841 m .58702 .84215 L .58592 .83894 L F
.587 .84228 m .58703 .84222 L .58732 .8397 L F
.58702 .84232 m .58717 .84259 L .58732 .8397 L F
.565 .018 0 r
.64525 .64665 m .64487 .64759 L .64202 .64615 L F
.548 .044 .009 r
.64525 .64665 m .6462 .64812 L .64487 .64759 L F
.64525 .64665 m .64778 .6478 L .6462 .64812 L F
.555 .139 .207 r
.64754 .64674 m .64778 .6478 L .64525 .64665 L F
.77 .724 .81 r
.6626 .7294 m .66378 .73147 L .66605 .72923 L F
.634 .353 .475 r
.48268 .8423 m .48524 .84219 L .48735 .8398 L F
.756 .562 .634 r
.48524 .84219 m .48778 .84051 L .48735 .8398 L F
.37 .818 .943 r
.53229 .86636 m .53313 .86666 L .52997 .86681 L F
.53229 .86636 m .53313 .86666 L .52997 .86681 L F
.27 .773 .761 r
.50546 .88874 m .50757 .88831 L .50955 .88771 L F
.918 .632 .484 r
.55218 .81017 m .55279 .81296 L .55403 .81139 L F
.681 .29 .299 r
.55403 .81139 m .55279 .81296 L .55621 .81303 L F
.564 .368 .574 r
.55403 .81139 m .55621 .81303 L .55698 .81099 L F
.652 .669 .853 r
.56976 .84536 m .57077 .84212 L .56915 .84249 L F
.56976 .84536 m .57293 .84548 L .57077 .84212 L F
.672 .609 .777 r
.56976 .84536 m .57285 .84602 L .57293 .84548 L F
.645 .597 .786 r
.49151 .84239 m .48906 .84304 L .48778 .84051 L F
.181 0 .2 r
.53368 .83197 m .53311 .83423 L .53139 .83441 L F
.455 .112 .295 r
.53538 .83382 m .53368 .83197 L .53574 .83155 L F
.53538 .83382 m .53311 .83423 L .53368 .83197 L F
.341 .28 .643 r
.64944 .71507 m .65142 .71805 L .65312 .71519 L F
.64944 .71507 m .65019 .71983 L .65142 .71805 L F
.761 .616 .699 r
.51995 .8609 m .52337 .85886 L .52021 .85904 L F
.528 .285 .491 r
.42932 .76009 m .43173 .75781 L .4294 .75796 L F
.413 .86 .804 r
.5084 .88245 m .50652 .88328 L .5047 .88373 L F
.121 0 0 r
.36665 .80461 m .36766 .80369 L .3695 .80304 L F
.607 .561 .777 r
.51907 .85301 m .52031 .84946 L .51846 .85134 L F
.51907 .85301 m .52127 .85241 L .52031 .84946 L F
.524 .496 .768 r
.51347 .88023 m .51142 .8805 L .51066 .87798 L F
.421 0 0 r
.51265 .88132 m .5142 .88161 L .51142 .8805 L F
.51265 .88132 m .51142 .8805 L .51347 .88023 L F
.773 .679 .759 r
.52284 .83474 m .52629 .83524 L .52501 .83421 L F
.52284 .83474 m .52363 .83772 L .52629 .83524 L F
.588 .798 .98 r
.52501 .83421 m .52629 .83524 L .52829 .83468 L F
.766 .697 .786 r
.63998 .63578 m .64082 .63924 L .638 .63875 L F
.681 .369 .44 r
.65706 .62971 m .65778 .6272 L .65495 .62788 L F
.63 .318 .423 r
.65999 .62743 m .65778 .6272 L .65706 .62971 L F
.36 .821 .92 r
.58033 .81626 m .5767 .81666 L .5794 .81368 L F
.5767 .81666 m .58033 .81626 L .57855 .81812 L F
.839 .593 .568 r
.58033 .81626 m .58052 .81871 L .57855 .81812 L F
.227 0 0 r
.55801 .77888 m .56001 .77905 L .56205 .77903 L F
.756 .382 .347 r
.56001 .77905 m .56359 .7798 L .56205 .77903 L F
.665 .596 .768 r
.53207 .84043 m .53377 .83909 L .53173 .83933 L F
.562 .495 .738 r
.52997 .84202 m .53309 .83988 L .53051 .84183 L F
.53087 .84134 m .53309 .83988 L .52997 .84202 L F
.52968 .84212 m .53173 .83933 L .53309 .83988 L F
.665 .596 .768 r
.53321 .84407 m .53376 .83916 L .53207 .84043 L F
.53376 .83916 m .53377 .83909 L .53207 .84043 L F
.562 .495 .738 r
.52968 .84212 m .53087 .84134 L .52997 .84202 L F
.181 .711 .719 r
.69179 .71906 m .69412 .71861 L .69621 .71813 L F
.674 .254 .239 r
.48674 .87069 m .48877 .87168 L .48966 .87043 L F
.321 0 .03 r
.48966 .87043 m .48877 .87168 L .49085 .87139 L F
.405 .088 .311 r
.43057 .77277 m .42945 .77109 L .43163 .77077 L F
.43057 .77277 m .42863 .77322 L .42945 .77109 L F
.988 .754 .489 r
.54204 .80784 m .54077 .80847 L .54076 .806 L F
.985 .714 .345 r
.54204 .80784 m .54129 .80946 L .54077 .80847 L F
.54204 .80784 m .54209 .81035 L .54129 .80946 L F
.973 .737 .522 r
.54076 .806 m .54077 .80847 L .53995 .80645 L F
0 0 .484 r
.54077 .80847 m .54129 .80946 L .53995 .80645 L F
.949 .599 .219 r
.53995 .80645 m .54129 .80946 L .54023 .8084 L F
0 .399 .836 r
.54129 .80946 m .54213 .80911 L .54039 .80846 L F
.54129 .80946 m .54039 .80846 L .54023 .8084 L F
.985 .714 .345 r
.54209 .81035 m .54209 .81047 L .54129 .80946 L F
.8 .809 .86 r
.54422 .80545 m .54204 .80784 L .54076 .806 L F
.725 .599 .715 r
.59095 .80532 m .59418 .8078 L .59408 .80568 L F
.46 .045 .165 r
.53256 .8363 m .53088 .83709 L .53139 .83441 L F
.951 .935 .741 r
.53082 .83711 m .5309 .83674 L .53214 .83682 L F
.627 .194 .199 r
.53139 .83441 m .53089 .83706 L .52829 .83468 L F
.53089 .83706 m .53088 .83709 L .53086 .83708 L F
.53089 .83706 m .53086 .83708 L .52829 .83468 L F
.951 .935 .741 r
.53043 .83894 m .52946 .83875 L .53008 .83759 L F
.787 .537 .558 r
.5295 .83457 m .53055 .83684 L .5309 .83674 L F
.53173 .83583 m .5309 .83674 L .53256 .8363 L F
.5295 .83457 m .5309 .83674 L .53173 .83583 L F
.627 .194 .199 r
.53088 .83709 m .53057 .83716 L .52829 .83468 L F
0 .121 .644 r
.52829 .83468 m .53064 .83723 L .5295 .83457 L F
.951 .935 .741 r
.53043 .83894 m .53008 .83759 L .53082 .83711 L F
.627 .194 .199 r
.53088 .83709 m .53082 .83743 L .53057 .83716 L F
0 .121 .644 r
.53064 .83723 m .53082 .83743 L .53063 .83703 L F
.53064 .83723 m .53063 .83703 L .5295 .83457 L F
.951 .935 .741 r
.5309 .83674 m .53063 .83702 L .53113 .83563 L F
.53063 .83702 m .53008 .83759 L .53063 .83656 L F
.53063 .83702 m .53063 .83656 L .53113 .83563 L F
.53082 .83711 m .53017 .83754 L .5309 .83674 L F
.53017 .83754 m .53008 .83759 L .5309 .83674 L F
.5309 .83674 m .53113 .83563 L .53186 .83649 L F
.5309 .83674 m .53186 .83649 L .53214 .83682 L F
.46 .045 .165 r
.53256 .8363 m .53082 .83743 L .53088 .83709 L F
.787 .537 .558 r
.53055 .83684 m .53082 .83743 L .53256 .8363 L F
.951 .935 .741 r
.53214 .83682 m .53195 .83659 L .53256 .8363 L F
.53195 .83659 m .53113 .83563 L .53256 .8363 L F
.53043 .83894 m .53082 .83711 L .53214 .83682 L F
.46 .045 .165 r
.53256 .8363 m .53139 .83441 L .53311 .83423 L F
.653 .107 0 r
.69534 .74437 m .69469 .74435 L .69357 .74331 L F
.928 .554 .154 r
.69593 .74648 m .69469 .74435 L .69534 .74437 L F
.53 .788 .992 r
.32245 .65694 m .32193 .65837 L .32038 .65741 L F
.32245 .65694 m .32387 .65794 L .32193 .65837 L F
.781 .789 .86 r
.69732 .75046 m .70099 .75005 L .6999 .7492 L F
.418 .22 .502 r
.33311 .70404 m .3313 .70671 L .33162 .70478 L F
.557 .393 .614 r
.52067 .83502 m .52284 .83474 L .52232 .83224 L F
.959 .728 .279 r
.56041 .83041 m .55989 .83102 L .55972 .82892 L F
.56041 .83041 m .5603 .83175 L .55989 .83102 L F
0 .181 .702 r
.5358 .84998 m .53519 .8507 L .53401 .84756 L F
.517 .364 .612 r
.53519 .8507 m .53732 .8529 L .53531 .85324 L F
.712 .178 0 r
.53603 .85233 m .53732 .8529 L .53703 .8526 L F
.53603 .85233 m .53703 .8526 L .53519 .8507 L F
.53603 .85233 m .53519 .8507 L .5358 .84998 L F
.382 .831 .935 r
.53513 .85209 m .53603 .85233 L .53721 .85172 L F
.89 .913 .835 r
.53287 .85158 m .53394 .85222 L .5358 .84998 L F
.3 0 0 r
.53287 .85158 m .53603 .85233 L .53478 .85215 L F
.53287 .85158 m .53603 .85233 L .53478 .85215 L F
.382 .831 .935 r
.53478 .85215 m .53603 .85233 L .53513 .85209 L F
.595 .633 .859 r
.32703 .65961 m .32504 .66007 L .32387 .65794 L F
.527 .92 .895 r
.35959 .7927 m .36024 .79188 L .36138 .79185 L F
.35959 .7927 m .3584 .79275 L .36024 .79188 L F
.223 .308 .741 r
.47489 .85899 m .47543 .86055 L .47389 .85883 L F
.624 .393 .547 r
.47543 .86055 m .47325 .86103 L .47389 .85883 L F
.482 .202 .412 r
.53723 .83496 m .5367 .83695 L .53936 .83462 L F
.333 0 0 r
.49917 .85971 m .49808 .85913 L .49747 .85789 L F
.49917 .85971 m .50072 .86034 L .49808 .85913 L F
.044 0 0 r
.53317 .86928 m .53642 .86929 L .53566 .86932 L F
.53317 .86928 m .53642 .86929 L .53566 .86932 L F
.502 .909 .858 r
.53566 .86932 m .53642 .86929 L .53739 .86844 L F
.53739 .86844 m .53642 .86929 L .53566 .86932 L F
.622 .477 .665 r
.65263 .73076 m .65299 .73392 L .65532 .73162 L F
.541 .545 .808 r
.44787 .74641 m .44622 .74779 L .44506 .74477 L F
.504 .443 .721 r
.44787 .74641 m .44666 .75009 L .44622 .74779 L F
.533 .409 .656 r
.49481 .84592 m .49317 .84745 L .49264 .84549 L F
.387 .049 .265 r
.38702 .78103 m .38862 .7814 L .38968 .77918 L F
.437 .057 .218 r
.38862 .7814 m .39198 .77918 L .38968 .77918 L F
.583 .41 .613 r
.52232 .83224 m .52501 .83421 L .52447 .83117 L F
.52232 .83224 m .52284 .83474 L .52501 .83421 L F
.593 .306 .45 r
.34704 .76327 m .34513 .76472 L .34502 .76305 L F
.544 .384 .615 r
.46307 .84836 m .46472 .84971 L .46509 .84764 L F
.46307 .84836 m .46308 .8505 L .46472 .84971 L F
.511 .107 .211 r
.52475 .85871 m .52918 .85771 L .52625 .85739 L F
.56 0 0 r
.52918 .85771 m .52822 .85781 L .52625 .85739 L F
.52918 .85771 m .53078 .85855 L .52822 .85781 L F
.586 .156 .192 r
.49569 .86279 m .49292 .86158 L .49635 .8613 L F
.967 .653 .366 r
.49635 .8613 m .49669 .86335 L .49569 .86279 L F
.659 .717 .891 r
.47531 .8744 m .47463 .87723 L .47425 .87614 L F
.47531 .8744 m .4772 .87665 L .47463 .87723 L F
.779 .749 .826 r
.64647 .73099 m .648 .73246 L .6495 .73124 L F
.58 .549 .784 r
.43032 .75041 m .43245 .75007 L .43145 .74697 L F
.853 .752 .751 r
.51251 .86158 m .51437 .85857 L .512 .85844 L F
.725 .809 .917 r
.34855 .795 m .3469 .79612 L .34516 .79497 L F
.571 .289 .449 r
.51904 .84051 m .51866 .84231 L .52093 .84201 L F
.778 .613 .676 r
.60045 .81632 m .59864 .81352 L .59852 .81595 L F
.807 .597 .618 r
.60027 .81868 m .60045 .81632 L .59852 .81595 L F
.439 .445 .769 r
.33898 .66689 m .33835 .67033 L .33705 .6672 L F
.33898 .66689 m .33994 .67011 L .33835 .67033 L F
.458 .453 .765 r
.34076 .67208 m .33835 .67033 L .33994 .67011 L F
.618 .519 .72 r
.64889 .62762 m .65075 .62717 L .64952 .62766 L F
.636 .261 .315 r
.64791 .62815 m .65014 .62738 L .64889 .62762 L F
.65014 .62738 m .65075 .62717 L .64889 .62762 L F
.245 .758 .841 r
.6477 .62785 m .64889 .62762 L .64952 .62766 L F
.64701 .62792 m .64889 .62762 L .6477 .62785 L F
.378 .634 .955 r
.65075 .62717 m .65174 .62792 L .64952 .62766 L F
.85 .844 .838 r
.38232 .75056 m .38388 .75263 L .38607 .75029 L F
.532 .478 .741 r
.7128 .7309 m .71082 .73164 L .70998 .7295 L F
.85 .844 .838 r
.38232 .75056 m .38607 .75029 L .38457 .74943 L F
.592 .484 .7 r
.38783 .748 m .38831 .75028 L .38607 .75029 L F
.286 .716 .968 r
.38831 .75028 m .38457 .74943 L .38607 .75029 L F
.813 .618 .639 r
.60039 .83671 m .60299 .83477 L .60144 .8339 L F
.60039 .83671 m .6027 .83642 L .60299 .83477 L F
.532 .353 .583 r
.62233 .63283 m .62018 .63329 L .62031 .63566 L F
.62233 .63283 m .62018 .63329 L .62031 .63566 L F
.241 .455 .867 r
.42899 .74566 m .43054 .74544 L .42832 .74406 L F
.42899 .74566 m .43145 .74697 L .43054 .74544 L F
.626 .548 .747 r
.45574 .86699 m .4564 .86953 L .45798 .86653 L F
.589 .503 .725 r
.4564 .86953 m .45849 .86946 L .45798 .86653 L F
.543 .264 .441 r
.4564 .86953 m .45823 .87086 L .45849 .86946 L F
.4564 .86953 m .45592 .87132 L .45823 .87086 L F
.504 .31 .551 r
.70056 .72342 m .70065 .72576 L .69845 .72615 L F
.452 .431 .745 r
.70095 .72793 m .69845 .72615 L .70065 .72576 L F
.534 .222 .385 r
.43649 .76869 m .43389 .77046 L .43422 .76886 L F
.433 .092 .286 r
.39449 .77622 m .39429 .77651 L .3961 .77616 L F
.304 0 0 r
.36891 .72743 m .37098 .7271 L .37249 .7255 L F
.402 0 .075 r
.37098 .7271 m .3746 .72524 L .37249 .7255 L F
.503 .017 .035 r
.38232 .75056 m .37916 .75025 L .38051 .7501 L F
0 0 0 r
.66713 .72774 m .66605 .72923 L .66806 .72611 L F
.854 .559 .027 r
.66935 .72497 m .66936 .72632 L .66907 .72543 L F
0 0 0 r
.66964 .72449 m .66806 .72611 L .66935 .72497 L F
.66935 .72497 m .66806 .72611 L .67068 .72343 L F
.66935 .72497 m .66806 .72611 L .67068 .72343 L F
.66935 .72497 m .66713 .72774 L .66806 .72611 L F
.814 .753 .795 r
.66591 .72637 m .66713 .72774 L .66935 .72497 L F
.66591 .72637 m .66935 .72497 L .66862 .72405 L F
.854 .559 .027 r
.66935 .72497 m .66907 .72543 L .66862 .72405 L F
0 0 0 r
.67068 .72343 m .66964 .72449 L .66935 .72497 L F
.491 .249 .474 r
.34307 .69175 m .3426 .69372 L .34062 .69413 L F
.349 .116 .413 r
.34466 .69112 m .34307 .69175 L .34512 .68911 L F
.465 .225 .464 r
.34439 .6932 m .34307 .69175 L .34466 .69112 L F
.34439 .6932 m .3426 .69372 L .34307 .69175 L F
.982 .849 .635 r
.68784 .72701 m .68694 .72568 L .68994 .72596 L F
.739 .788 .892 r
.53366 .84428 m .5307 .84532 L .53392 .8454 L F
.652 .424 .56 r
.53158 .84746 m .53392 .8454 L .5307 .84532 L F
.53158 .84746 m .53401 .84756 L .53392 .8454 L F
.515 .319 .552 r
.53392 .8454 m .53587 .84543 L .53401 .84756 L F
.53392 .8454 m .53587 .84543 L .53401 .84756 L F
.665 .7 .872 r
.42768 .72861 m .42589 .72935 L .42472 .7279 L F
.765 .539 .591 r
.52735 .84491 m .5307 .84532 L .52968 .84212 L F
.562 .495 .738 r
.52968 .84212 m .53321 .84407 L .53173 .83933 L F
.681 .924 .972 r
.65701 .7301 m .66035 .72948 L .65953 .72854 L F
.53 .666 .923 r
.66035 .72948 m .66167 .72776 L .65953 .72854 L F
.66035 .72948 m .6626 .7294 L .66167 .72776 L F
.605 .808 .978 r
.49225 .82363 m .49352 .82461 L .4956 .82403 L F
.4956 .82403 m .49352 .82461 L .49225 .82363 L F
.49225 .82363 m .4956 .82403 L .49435 .82331 L F
.4956 .82403 m .49225 .82363 L .49435 .82331 L F
.579 .846 .995 r
.4956 .82403 m .49352 .82461 L .49435 .82331 L F
.228 0 0 r
.41411 .74295 m .4106 .7428 L .41198 .74268 L F
.391 0 .069 r
.52589 .83085 m .52807 .83063 L .52934 .82903 L F
.573 .822 .448 r
.52934 .82903 m .52807 .83063 L .52892 .82953 L F
.359 0 0 r
.52726 .82866 m .52934 .82903 L .52959 .82872 L F
.573 .822 .448 r
.52934 .82903 m .52892 .82953 L .53018 .8279 L F
.359 0 0 r
.52959 .82872 m .52934 .82903 L .53031 .82874 L F
.54 .922 .798 r
.53031 .82874 m .53118 .82793 L .53191 .82685 L F
.53031 .82874 m .52934 .82903 L .53118 .82793 L F
.555 .666 .911 r
.4786 .86378 m .47735 .86569 L .47662 .86434 L F
.4786 .86378 m .48025 .86589 L .47735 .86569 L F
.627 .618 .822 r
.68345 .73246 m .68507 .73012 L .68234 .73083 L F
.68345 .73246 m .68554 .73189 L .68507 .73012 L F
.737 .829 .922 r
.46079 .87796 m .46401 .87775 L .46255 .87679 L F
.695 .805 .933 r
.46255 .87679 m .46401 .87775 L .46591 .87695 L F
.438 .196 .447 r
.34661 .69043 m .34512 .68911 L .3471 .68863 L F
.34661 .69043 m .34466 .69112 L .34512 .68911 L F
.54 .507 .768 r
.44514 .74392 m .44234 .74213 L .44454 .74169 L F
.589 .621 .852 r
.47811 .87676 m .47792 .87986 L .4772 .87665 L F
.47811 .87676 m .48011 .87965 L .47792 .87986 L F
.696 .618 .765 r
.64067 .73571 m .64224 .73409 L .63891 .7336 L F
.623 .679 .882 r
.57285 .84602 m .57445 .84454 L .57293 .84548 L F
.57285 .84602 m .57527 .84562 L .57445 .84454 L F
.693 .29 .279 r
.56001 .77905 m .56423 .78067 L .56359 .7798 L F
.702 .409 .477 r
.54361 .8422 m .54116 .83997 L .5436 .83992 L F
.369 .104 .375 r
.7128 .7309 m .71007 .73352 L .71082 .73164 L F
.88 .63 .557 r
.57846 .79977 m .57615 .79981 L .57626 .79737 L F
.986 .798 .569 r
.57697 .80272 m .57615 .79981 L .57846 .79977 L F
.413 .22 .506 r
.34905 .68576 m .3471 .68863 L .34735 .68636 L F
.292 0 0 r
.41774 .7428 m .4159 .74318 L .41411 .74295 L F
.011 0 0 r
.41954 .74208 m .4159 .74318 L .41774 .7428 L F
.733 .63 .744 r
.5277 .86908 m .52902 .87214 L .52557 .87176 L F
0 .154 .685 r
.52949 .87168 m .52902 .87214 L .5277 .86908 L F
.429 .864 .921 r
.52949 .87168 m .53142 .87155 L .52902 .87214 L F
.579 .311 .473 r
.52902 .87214 m .53142 .87155 L .53053 .87378 L F
.538 .301 .503 r
.38235 .88541 m .38545 .88289 L .38152 .88214 L F
.812 .692 .732 r
.52337 .85886 m .52475 .85871 L .52465 .85647 L F
.81 .659 .696 r
.52321 .86115 m .52475 .85871 L .52337 .85886 L F
.433 .394 .716 r
.52465 .85647 m .52475 .85871 L .52625 .85739 L F
.934 .849 .736 r
.6468 .60842 m .6479 .60936 L .64638 .61233 L F
.777 .699 .777 r
.64699 .60627 m .6479 .60936 L .6468 .60842 L F
.64699 .60627 m .65013 .60667 L .6479 .60936 L F
.552 .283 .461 r
.3997 .78767 m .39933 .78926 L .39737 .78921 L F
.4 .145 .408 r
.4012 .78847 m .3997 .78767 L .40177 .78736 L F
.4012 .78847 m .39933 .78926 L .3997 .78767 L F
.906 .717 .636 r
.58394 .7891 m .58533 .78974 L .58414 .78679 L F
.933 .753 .635 r
.58369 .79115 m .58533 .78974 L .58394 .7891 L F
.58369 .79115 m .5851 .79207 L .58533 .78974 L F
.814 .601 .614 r
.56337 .82319 m .56514 .82651 L .5654 .82426 L F
.454 .215 .46 r
.33975 .6978 m .33835 .69662 L .34035 .6961 L F
.33975 .6978 m .33795 .69861 L .33835 .69662 L F
.868 .471 .281 r
.48218 .87915 m .48403 .87961 L .48296 .87838 L F
.354 .103 .388 r
.35127 .68318 m .34905 .68576 L .34958 .68385 L F
.57 .333 .516 r
.44105 .76717 m .43931 .76566 L .44152 .76559 L F
.44105 .76717 m .43945 .76741 L .43931 .76566 L F
.549 .697 .937 r
.70275 .72077 m .69969 .7195 L .70178 .72012 L F
.487 .464 .757 r
.70178 .72012 m .70056 .72342 L .70275 .72077 L F
.70178 .72012 m .70285 .72344 L .70056 .72342 L F
.61 .391 .559 r
.703 .72543 m .70056 .72342 L .70285 .72344 L F
.703 .72543 m .70065 .72576 L .70056 .72342 L F
.802 .57 .587 r
.64645 .72863 m .64647 .73099 L .6495 .73124 L F
.309 .27 .652 r
.47281 .87154 m .47282 .87473 L .47184 .87418 L F
0 .305 .79 r
.47282 .87473 m .47425 .87614 L .47184 .87418 L F
.535 .244 .419 r
.44411 .76362 m .44366 .76541 L .44152 .76559 L F
.591 .339 .503 r
.44614 .76319 m .44366 .76541 L .44411 .76362 L F
.536 .465 .724 r
.47543 .86055 m .47428 .8643 L .47325 .86103 L F
.47543 .86055 m .47662 .86434 L .47428 .8643 L F
.43 .021 .16 r
.37675 .72545 m .3788 .72528 L .38019 .72338 L F
.612 .222 .279 r
.38019 .72338 m .3788 .72528 L .38198 .72462 L F
.601 .236 .322 r
.38019 .72338 m .38198 .72462 L .38241 .72357 L F
0 0 0 r
.42289 .74167 m .42165 .74186 L .41954 .74208 L F
.021 0 0 r
.42479 .74168 m .42165 .74186 L .42289 .74167 L F
.653 .361 .463 r
.55139 .78683 m .55064 .78948 L .54831 .78914 L F
.607 .315 .447 r
.55521 .78848 m .55139 .78683 L .55363 .7863 L F
.55521 .78848 m .55064 .78948 L .55139 .78683 L F
.249 .727 .935 r
.68705 .75375 m .68812 .75418 L .68886 .75401 L F
.839 .701 .71 r
.70928 .72593 m .70921 .72778 L .70613 .72788 L F
.581 .676 .905 r
.64391 .73379 m .64096 .73163 L .64224 .73409 L F
.64391 .73379 m .64312 .7312 L .64096 .73163 L F
.655 .882 .981 r
.64647 .73099 m .64312 .7312 L .64391 .73379 L F
.39 .75 .992 r
.56312 .84034 m .56358 .84008 L .56175 .83741 L F
.56312 .84034 m .5652 .84022 L .56358 .84008 L F
.489 .285 .529 r
.33589 .69937 m .3355 .70153 L .33392 .70184 L F
.415 .181 .449 r
.3355 .70153 m .33311 .70404 L .33392 .70184 L F
.753 .745 .845 r
.7041 .71608 m .70485 .71811 L .70175 .71771 L F
.99 .729 .41 r
.70485 .71811 m .70401 .71966 L .70175 .71771 L F
.742 .739 .849 r
.70709 .71584 m .70485 .71811 L .7041 .71608 L F
.565 .303 .478 r
.47639 .84815 m .47648 .85104 L .4784 .84991 L F
.614 .289 .396 r
.47639 .84815 m .4784 .84991 L .47858 .84835 L F
.5 .219 .419 r
.41422 .77905 m .41358 .78169 L .41161 .78196 L F
.527 .244 .428 r
.41643 .7802 m .41422 .77905 L .41603 .77887 L F
.41643 .7802 m .41358 .78169 L .41422 .77905 L F
.378 .801 .614 r
.5119 .88587 m .51453 .88427 L .51387 .88525 L F
.887 .793 .751 r
.51453 .88427 m .51639 .88259 L .51618 .8848 L F
.51453 .88427 m .5142 .88161 L .51639 .88259 L F
.312 0 .008 r
.51387 .88525 m .51453 .88427 L .51618 .8848 L F
.534 .298 .503 r
.42432 .77378 m .42401 .77573 L .42194 .7759 L F
.451 .125 .322 r
.42675 .77379 m .42401 .77573 L .42432 .77378 L F
.501 .274 .501 r
.34225 .69563 m .34062 .69413 L .3426 .69372 L F
.34225 .69563 m .34035 .6961 L .34062 .69413 L F
.835 .559 .521 r
.51029 .87174 m .50763 .8692 L .50611 .87146 L F
.482 .169 .358 r
.39949 .7739 m .40083 .77529 L .4015 .77348 L F
.39949 .7739 m .39884 .77571 L .40083 .77529 L F
.618 .448 .629 r
.65039 .62223 m .65111 .62031 L .64869 .62052 L F
.931 .81 .704 r
.47817 .87096 m .47908 .8731 L .47882 .87312 L F
.504 .443 .721 r
.44787 .74641 m .44855 .74982 L .44666 .75009 L F
.455 .254 .517 r
.33711 .70035 m .33589 .69937 L .33795 .69861 L F
.33711 .70035 m .3355 .70153 L .33589 .69937 L F
.293 .79 .79 r
.57909 .84462 m .58207 .84356 L .57896 .84411 L F
.57909 .84462 m .58271 .8436 L .58207 .84356 L F
.512 .295 .522 r
.41973 .7656 m .42182 .76527 L .42198 .76317 L F
.627 .436 .605 r
.42182 .76527 m .42411 .76284 L .42198 .76317 L F
.819 .575 .57 r
.4552 .75172 m .45732 .75235 L .45769 .74995 L F
.049 0 .067 r
.52885 .84817 m .52653 .85067 L .52879 .85032 L F
.657 .551 .724 r
.52867 .84623 m .52885 .84817 L .53158 .84746 L F
.466 .257 .511 r
.52885 .84817 m .53069 .84991 L .53158 .84746 L F
.52885 .84817 m .52879 .85032 L .53069 .84991 L F
.845 .649 .637 r
.5851 .79207 m .584 .79481 L .58651 .79502 L F
.835 .651 .653 r
.584 .79481 m .5864 .79742 L .58651 .79502 L F
.453 .076 .231 r
.34871 .73623 m .35084 .73598 L .35206 .73394 L F
.445 .1 .285 r
.35084 .73598 m .354 .73337 L .35206 .73394 L F
.978 .737 .504 r
.66803 .71741 m .66911 .72042 L .66915 .71811 L F
.66915 .71811 m .66911 .72042 L .66803 .71741 L F
.548 .348 .562 r
.45122 .76003 m .44949 .7613 L .44896 .76032 L F
.427 .079 .271 r
.36199 .75476 m .36097 .75713 L .35892 .75746 L F
.187 0 .043 r
.36358 .75437 m .36199 .75476 L .36472 .75304 L F
.331 0 .225 r
.36281 .75657 m .36199 .75476 L .36358 .75437 L F
.36281 .75657 m .36097 .75713 L .36199 .75476 L F
.091 .605 .887 r
.40175 .72353 m .40389 .72384 L .40514 .72437 L F
.301 .693 .976 r
.4062 .72371 m .40514 .72437 L .40389 .72384 L F
.4062 .72371 m .40735 .72445 L .40514 .72437 L F
.684 .739 .892 r
.54149 .85889 m .54239 .86041 L .53968 .86124 L F
.54239 .86041 m .54179 .86139 L .53968 .86124 L F
.54239 .86041 m .54303 .86148 L .54179 .86139 L F
.97 .661 .283 r
.54217 .86092 m .54303 .86148 L .54251 .8606 L F
.54217 .86092 m .54251 .8606 L .54149 .85889 L F
.604 .867 .527 r
.54178 .86129 m .54217 .86092 L .54285 .85997 L F
.623 .168 .151 r
.53968 .86124 m .54303 .86148 L .54073 .86257 L F
.604 .867 .527 r
.54073 .86257 m .54217 .86092 L .54178 .86129 L F
0 0 0 r
.54217 .86092 m .54318 .85913 L .54285 .85997 L F
.54318 .85913 m .5438 .85803 L .54359 .85847 L F
.54318 .85913 m .54359 .85847 L .54285 .85997 L F
.917 .952 .802 r
.54073 .86257 m .54303 .86148 L .54217 .86092 L F
0 0 0 r
.39228 .74386 m .39101 .74439 L .39024 .74442 L F
.39101 .74439 m .38921 .74625 L .39024 .74442 L F
.917 .723 .624 r
.56514 .82651 m .56482 .82891 L .56633 .82923 L F
.996 .763 .443 r
.56482 .82891 m .56501 .83039 L .56633 .82923 L F
.374 0 0 r
.56501 .83039 m .56855 .82956 L .56633 .82923 L F
.395 .018 .2 r
.4186 .76765 m .42182 .76527 L .41973 .7656 L F
.212 .696 .93 r
.39775 .74392 m .39444 .74338 L .39575 .74406 L F
.386 .136 .408 r
.35454 .75781 m .35417 .76008 L .35215 .76046 L F
.601 .323 .468 r
.35634 .7597 m .35454 .75781 L .35678 .75771 L F
.35634 .7597 m .35417 .76008 L .35454 .75781 L F
.77 .724 .81 r
.6626 .7294 m .66605 .72923 L .66496 .72921 L F
.701 .97 .93 r
.66713 .72774 m .66496 .72921 L .66605 .72923 L F
0 0 0 r
.3691 .78683 m .36556 .78891 L .36739 .78806 L F
0 .498 .702 r
.37025 .78607 m .373 .78643 L .3713 .78621 L F
.652 .17 .095 r
.37046 .78564 m .373 .78643 L .37049 .7861 L F
.272 0 .119 r
.37017 .78606 m .37048 .78598 L .37046 .78564 L F
.37022 .78606 m .3705 .78597 L .37017 .78606 L F
.37014 .78609 m .37046 .78564 L .36977 .786 L F
.652 .17 .095 r
.37046 .78564 m .37049 .7861 L .36977 .786 L F
.272 0 .119 r
.37048 .78598 m .3705 .78597 L .37046 .78564 L F
.37014 .78609 m .37022 .78606 L .37017 .78606 L F
0 .498 .702 r
.37022 .78606 m .37049 .7861 L .37025 .78607 L F
.36977 .786 m .37049 .7861 L .37022 .78606 L F
.37049 .7861 m .37049 .7861 L .37022 .78606 L F
.37049 .7861 m .373 .78643 L .37025 .78607 L F
.221 0 .122 r
.37119 .78619 m .37071 .78787 L .37245 .78714 L F
.37077 .78587 m .37076 .78613 L .37119 .78619 L F
.37076 .78613 m .37071 .78787 L .37119 .78619 L F
.37046 .78564 m .3705 .78597 L .37077 .78587 L F
.479 .875 .963 r
.3691 .78683 m .3695 .78634 L .37101 .78629 L F
.37101 .78629 m .36977 .786 L .3713 .78621 L F
.221 0 .122 r
.3705 .78597 m .37071 .78787 L .37077 .78587 L F
.479 .875 .963 r
.3695 .78634 m .36954 .78628 L .36964 .78629 L F
.3695 .78634 m .36964 .78629 L .37101 .78629 L F
.36954 .78628 m .36977 .786 L .37014 .78609 L F
.36954 .78628 m .37014 .78609 L .37101 .78629 L F
.272 0 .119 r
.36922 .78742 m .37071 .78787 L .3705 .78597 L F
.36922 .78742 m .3705 .78597 L .37014 .78609 L F
.36922 .78742 m .37014 .78609 L .36977 .786 L F
.57 .896 .64 r
.3691 .78683 m .36739 .78806 L .36977 .786 L F
.555 .336 .537 r
.35215 .76046 m .35201 .76263 L .34999 .76274 L F
.447 .247 .514 r
.35373 .76187 m .35215 .76046 L .35417 .76008 L F
.35373 .76187 m .35201 .76263 L .35215 .76046 L F
.11 0 0 r
.36597 .80524 m .36475 .80511 L .36665 .80461 L F
.113 0 0 r
.36597 .80524 m .36411 .80592 L .36475 .80511 L F
.751 .748 .849 r
.64699 .60627 m .64948 .60428 L .65013 .60667 L F
.839 .701 .71 r
.70928 .72593 m .70613 .72788 L .70828 .72517 L F
.601 .826 .986 r
.71164 .72537 m .70928 .72593 L .70828 .72517 L F
.337 0 .016 r
.36202 .72934 m .36131 .7302 L .36336 .72984 L F
.388 .006 .187 r
.41161 .78196 m .40891 .7834 L .40953 .78228 L F
.764 .644 .729 r
.59545 .81329 m .59864 .81352 L .59739 .81039 L F
.767 .585 .651 r
.59852 .81595 m .59864 .81352 L .59545 .81329 L F
.568 .632 .875 r
.57077 .84212 m .57293 .84548 L .57445 .84454 L F
.585 .401 .599 r
.5088 .85925 m .51128 .85587 L .50852 .85593 L F
.494 .572 .863 r
.57267 .82378 m .57509 .8271 L .576 .82641 L F
.605 .274 .382 r
.55801 .77888 m .56057 .78066 L .56001 .77905 L F
.55801 .77888 m .55694 .78113 L .56057 .78066 L F
.445 .219 .476 r
.32154 .69671 m .324 .69705 L .32352 .69382 L F
.406 .228 .525 r
.32352 .69382 m .32567 .6936 L .32578 .69123 L F
.403 .191 .475 r
.32352 .69382 m .32527 .69572 L .32567 .6936 L F
.32352 .69382 m .324 .69705 L .32527 .69572 L F
.479 .599 .894 r
.34546 .6743 m .3449 .6766 L .34363 .67446 L F
.34546 .6743 m .34719 .67668 L .3449 .6766 L F
.638 .747 .927 r
.43656 .73169 m .43481 .73242 L .43331 .73098 L F
.561 .313 .497 r
.6621 .63779 m .65954 .64091 L .66006 .63826 L F
.638 .7 .891 r
.57855 .81812 m .57903 .82003 L .57764 .81962 L F
.743 .766 .872 r
.58052 .81871 m .57903 .82003 L .57855 .81812 L F
.726 .256 .132 r
.38783 .748 m .3915 .74937 L .38831 .75028 L F
0 0 0 r
.3915 .74937 m .39025 .74981 L .38831 .75028 L F
.726 .256 .132 r
.38783 .748 m .39025 .74981 L .3915 .74937 L F
.302 .783 .702 r
.39217 .74903 m .3915 .74937 L .39362 .74995 L F
.39217 .74903 m .39025 .74981 L .3915 .74937 L F
.39217 .74903 m .3915 .74937 L .39362 .74995 L F
.39217 .74903 m .39025 .74981 L .3915 .74937 L F
0 0 0 r
.65354 .60945 m .65285 .61088 L .65111 .61153 L F
.58 .794 .981 r
.65354 .60945 m .65565 .60886 L .65448 .60789 L F
.65354 .60945 m .65448 .60789 L .65285 .61088 L F
.917 .608 .129 r
.52494 .86906 m .52528 .86934 L .52441 .86646 L F
.979 .869 .493 r
.52494 .86906 m .52528 .86934 L .52491 .86994 L F
.991 .749 .462 r
.52528 .86934 m .52557 .87176 L .52491 .86994 L F
.917 .608 .129 r
.52494 .86906 m .52528 .86934 L .52441 .86646 L F
.979 .869 .493 r
.52494 .86906 m .52528 .86934 L .52491 .86994 L F
.425 .119 .341 r
.38702 .78103 m .38817 .78316 L .38862 .7814 L F
.38702 .78103 m .38619 .78365 L .38817 .78316 L F
.791 .681 .743 r
.70064 .74104 m .70182 .74401 L .70346 .74127 L F
.773 .4 .348 r
.50931 .87923 m .51347 .88023 L .51066 .87798 L F
.503 .116 .239 r
.42194 .7759 m .4207 .77823 L .41907 .77695 L F
.391 0 .155 r
.42401 .77573 m .4207 .77823 L .42194 .7759 L F
0 .441 .84 r
.31928 .67564 m .31633 .67546 L .31674 .67541 L F
.31928 .67564 m .31865 .67495 L .31633 .67546 L F
.538 .301 .503 r
.38235 .88541 m .38445 .88488 L .38545 .88289 L F
.853 .693 .684 r
.54784 .84804 m .54504 .84815 L .5466 .84487 L F
.434 .274 .563 r
.54784 .84804 m .54712 .85148 L .54504 .84815 L F
.54784 .84804 m .54807 .8503 L .54712 .85148 L F
0 0 0 r
.5502 .84526 m .5492 .8471 L .54784 .84804 L F
.54784 .84804 m .54724 .85011 L .54807 .8503 L F
.54784 .84804 m .5492 .8471 L .54724 .85011 L F
.657 .551 .724 r
.52867 .84623 m .53158 .84746 L .5307 .84532 L F
.544 .3 .497 r
.39391 .77875 m .3961 .77616 L .39429 .77651 L F
.835 .692 .706 r
.65039 .62223 m .65225 .61914 L .65111 .62031 L F
0 0 0 r
.53347 .82573 m .53191 .82685 L .53356 .82577 L F
.53191 .82685 m .53118 .82793 L .53356 .82577 L F
.803 .998 .85 r
.53291 .82636 m .53266 .82559 L .53356 .82577 L F
.53118 .82793 m .53266 .82559 L .53291 .82636 L F
.166 0 0 r
.53266 .82559 m .53545 .82619 L .53356 .82577 L F
.53266 .82559 m .53362 .8258 L .53356 .82577 L F
.53362 .8258 m .53545 .82619 L .53356 .82577 L F
0 0 0 r
.53506 .82458 m .53347 .82573 L .53356 .82577 L F
.788 .394 .309 r
.53506 .82458 m .53356 .82577 L .53495 .82595 L F
.763 .519 .565 r
.53495 .82595 m .53692 .82636 L .53665 .82441 L F
0 .154 .651 r
.53545 .82619 m .53495 .82595 L .53356 .82577 L F
.749 .696 .801 r
.53483 .82361 m .53545 .82619 L .53266 .82559 L F
0 .021 .583 r
.53266 .82559 m .53217 .82441 L .53483 .82361 L F
.623 .106 0 r
.53495 .82595 m .53653 .82716 L .53692 .82636 L F
0 .154 .651 r
.53545 .82619 m .53653 .82716 L .53495 .82595 L F
.466 0 0 r
.53653 .82716 m .53979 .82644 L .53692 .82636 L F
.53653 .82716 m .54014 .8288 L .53979 .82644 L F
0 .412 .813 r
.53817 .82774 m .53653 .82716 L .53545 .82619 L F
.623 .565 .768 r
.53692 .82636 m .53871 .82417 L .53665 .82441 L F
.431 .483 .813 r
.53759 .82514 m .53545 .82619 L .53485 .8237 L F
.53498 .8237 m .53485 .8237 L .53483 .82361 L F
.53759 .82514 m .53485 .8237 L .53498 .8237 L F
.53759 .82514 m .53483 .82361 L .53554 .82364 L F
.803 .998 .85 r
.53118 .82793 m .53018 .8279 L .53266 .82559 L F
.677 .957 .72 r
.53266 .82559 m .53018 .8279 L .53117 .82646 L F
.635 .964 .888 r
.53118 .82793 m .52934 .82903 L .53018 .8279 L F
.606 .432 .62 r
.53018 .8279 m .53235 .82969 L .53117 .82646 L F
.205 0 0 r
.53117 .82646 m .53267 .82637 L .53266 .82559 L F
.825 .727 .757 r
.53328 .82657 m .53316 .82622 L .53375 .8263 L F
.205 0 0 r
.53316 .82622 m .53375 .8263 L .53349 .82613 L F
.207 0 0 r
.53217 .82441 m .53442 .82428 L .53559 .82372 L F
.53217 .82441 m .53559 .82372 L .53524 .82371 L F
.02 .394 .851 r
.53707 .82636 m .53545 .82619 L .53759 .82514 L F
.53707 .82636 m .53817 .82774 L .53545 .82619 L F
.75 .712 .816 r
.53587 .8242 m .5336 .82627 L .53707 .82636 L F
0 .021 .583 r
.53352 .82615 m .53375 .8263 L .53322 .82566 L F
.53352 .82615 m .53322 .82566 L .53234 .82461 L F
.207 0 0 r
.53217 .82441 m .53554 .82364 L .53483 .82361 L F
.53442 .82428 m .53587 .8242 L .53577 .82401 L F
.429 0 0 r
.53222 .82336 m .53587 .8242 L .53217 .82441 L F
0 0 0 r
.53494 .82558 m .53328 .82657 L .53587 .8242 L F
0 .122 .67 r
.53217 .82441 m .53375 .8263 L .53222 .82336 L F
.825 .727 .757 r
.53316 .82622 m .53222 .82336 L .53375 .8263 L F
.205 0 0 r
.53267 .82637 m .53375 .8263 L .53316 .82622 L F
.53267 .82637 m .53349 .82613 L .53266 .82559 L F
.718 .701 .834 r
.53117 .82646 m .53235 .82969 L .53455 .8275 L F
.825 .727 .757 r
.53301 .82627 m .5311 .82675 L .53174 .82481 L F
.53328 .82657 m .53141 .82673 L .53301 .82627 L F
.718 .701 .834 r
.53117 .82646 m .53455 .8275 L .53328 .82657 L F
.29 0 0 r
.53328 .82657 m .5311 .82675 L .53117 .82646 L F
.825 .727 .757 r
.53141 .82673 m .5311 .82675 L .53301 .82627 L F
.53264 .82463 m .53174 .82481 L .53222 .82336 L F
0 .021 .583 r
.53266 .82559 m .53349 .82613 L .53234 .82461 L F
.53349 .82613 m .53352 .82615 L .53342 .82601 L F
.53349 .82613 m .53342 .82601 L .53234 .82461 L F
.53266 .82559 m .53234 .82461 L .53217 .82441 L F
.825 .727 .757 r
.53328 .82657 m .53174 .82481 L .53256 .82465 L F
.53274 .82493 m .53256 .82465 L .53264 .82463 L F
.53328 .82657 m .53256 .82465 L .53274 .82493 L F
.207 0 0 r
.53442 .82428 m .53577 .82401 L .53559 .82372 L F
.53524 .82371 m .53559 .82372 L .53554 .82364 L F
.75 .712 .816 r
.5336 .82627 m .53328 .82657 L .53377 .82654 L F
.5336 .82627 m .53377 .82654 L .53707 .82636 L F
.779 .66 .733 r
.52703 .8159 m .52817 .81872 L .5257 .81799 L F
.748 .298 .182 r
.52817 .81872 m .52692 .81904 L .5257 .81799 L F
.634 .589 .786 r
.53015 .8166 m .52817 .81872 L .52703 .8159 L F
.656 .251 .265 r
.53031 .81913 m .53023 .82012 L .52817 .81872 L F
0 .327 .812 r
.52817 .81872 m .53023 .82012 L .52983 .81942 L F
.52817 .81872 m .52983 .81942 L .52692 .81904 L F
.651 .616 .801 r
.53015 .8166 m .53031 .81913 L .52817 .81872 L F
.436 0 .041 r
.39737 .78921 m .3979 .79069 L .39581 .79116 L F
.39737 .78921 m .39933 .78926 L .3979 .79069 L F
.487 .311 .568 r
.46095 .85355 m .46281 .85324 L .46308 .8505 L F
.48 .391 .678 r
.46144 .85582 m .46281 .85324 L .46095 .85355 L F
.87 .476 .287 r
.48513 .88216 m .48403 .87961 L .48218 .87915 L F
.737 .8 .903 r
.65724 .71781 m .65834 .71888 L .65596 .71994 L F
.981 .73 .478 r
.70276 .70758 m .70165 .7068 L .70236 .70624 L F
.70236 .70624 m .70165 .7068 L .70165 .70388 L F
.885 .884 .827 r
.70374 .70406 m .70165 .7068 L .70276 .70758 L F
.191 0 0 r
.70409 .7069 m .70014 .70796 L .70165 .7068 L F
.70014 .70796 m .69981 .70805 L .70165 .7068 L F
0 0 .38 r
.67306 .73395 m .67312 .73332 L .67198 .73086 L F
0 0 .502 r
.67332 .73614 m .67312 .73332 L .67306 .73395 L F
.009 0 0 r
.46939 .88192 m .47112 .88193 L .46917 .88191 L F
.46939 .88192 m .47206 .88191 L .47112 .88193 L F
.522 .919 .868 r
.47852 .85244 m .47599 .85356 L .47779 .85319 L F
.043 .205 .707 r
.47779 .85319 m .47955 .85482 L .47852 .85244 L F
.753 .713 .814 r
.487 .88328 m .49024 .88505 L .48648 .88502 L F
.991 .808 .562 r
.49024 .88505 m .4889 .88658 L .48648 .88502 L F
.49024 .88505 m .48976 .88781 L .4889 .88658 L F
0 .295 .69 r
.49023 .88492 m .49024 .88505 L .487 .88328 L F
.887 .463 .08 r
.49004 .88647 m .49024 .88505 L .49023 .88492 L F
.49004 .88647 m .49189 .88828 L .49024 .88505 L F
.39 .771 .991 r
.31307 .6559 m .31302 .65672 L .31161 .65574 L F
.31307 .6559 m .315 .65655 L .31302 .65672 L F
0 0 0 r
.45948 .87167 m .45723 .87443 L .45832 .87315 L F
.776 .675 .752 r
.45948 .87167 m .45592 .87132 L .45823 .87086 L F
.45948 .87167 m .45723 .87443 L .45592 .87132 L F
.967 .717 .504 r
.45948 .87167 m .45832 .87315 L .45823 .87086 L F
.611 .068 0 r
.45823 .87086 m .45936 .87192 L .45948 .87167 L F
.45823 .87086 m .45936 .87192 L .45948 .87167 L F
.841 .81 .82 r
.55039 .83465 m .54912 .83691 L .55105 .83716 L F
.978 .915 .659 r
.54917 .8339 m .54895 .83638 L .54912 .83691 L F
.847 .82 .822 r
.54917 .8339 m .54912 .83691 L .55039 .83465 L F
.818 .837 .864 r
.55105 .83716 m .54912 .83691 L .54895 .83638 L F
.985 .903 .611 r
.54925 .83955 m .55105 .83716 L .54895 .83638 L F
.54925 .83955 m .55002 .84025 L .55105 .83716 L F
.841 .81 .82 r
.55039 .83465 m .55105 .83716 L .55239 .83394 L F
.492 .211 .414 r
.65717 .64071 m .65458 .64304 L .6549 .64105 L F
.662 .61 .786 r
.43245 .75007 m .43363 .7528 L .4359 .75241 L F
.65 .525 .699 r
.43363 .7528 m .43388 .75516 L .4359 .75241 L F
.753 .261 .061 r
.65256 .72126 m .65124 .72178 L .65035 .72097 L F
.546 .916 .749 r
.65419 .71983 m .65256 .72126 L .65504 .72028 L F
.65419 .71983 m .65124 .72178 L .65256 .72126 L F
.65 .538 .714 r
.68054 .69449 m .68065 .6964 L .68277 .69413 L F
.584 .14 .161 r
.33566 .74044 m .33818 .74065 L .33945 .73955 L F
.246 0 0 r
.33818 .74065 m .34131 .73916 L .33945 .73955 L F
.597 .034 0 r
.51133 .87343 m .51466 .87486 L .51274 .87387 L F
.97 .688 .277 r
.6717 .72862 m .67126 .72995 L .67079 .72788 L F
.6717 .72862 m .67198 .73086 L .67126 .72995 L F
.862 .872 .845 r
.59725 .84316 m .59856 .84183 L .59807 .83982 L F
.761 .82 .898 r
.59807 .83982 m .59856 .84183 L .60123 .83983 L F
.769 .583 .647 r
.58777 .80024 m .58771 .80278 L .59114 .80293 L F
.646 .594 .782 r
.58771 .80278 m .59095 .80532 L .59114 .80293 L F
.723 .436 .491 r
.4784 .84991 m .4818 .848 L .47858 .84835 L F
.4784 .84991 m .48199 .85005 L .4818 .848 L F
.743 .568 .657 r
.48199 .85005 m .48401 .84744 L .4818 .848 L F
.513 .392 .652 r
.46456 .84522 m .46704 .84717 L .4668 .8454 L F
.46456 .84522 m .46509 .84764 L .46704 .84717 L F
.615 .434 .614 r
.52641 .85286 m .52879 .85032 L .52653 .85067 L F
.471 .102 .256 r
.53242 .8184 m .53575 .81611 L .53602 .81719 L F
0 .178 .7 r
.53355 .82119 m .53242 .8184 L .53602 .81719 L F
.8 .465 .422 r
.53665 .81993 m .53794 .8179 L .53673 .81776 L F
.53639 .8184 m .53673 .81776 L .53627 .8177 L F
.53665 .81993 m .53673 .81776 L .53639 .8184 L F
.471 .102 .256 r
.53242 .8184 m .53644 .8183 L .53575 .81611 L F
.53644 .8183 m .5365 .8183 L .53648 .81823 L F
.53644 .8183 m .53648 .81823 L .53575 .81611 L F
.722 .371 0 r
.53575 .81611 m .5365 .8183 L .53627 .8177 L F
.53575 .81611 m .53627 .8177 L .53794 .8179 L F
.83 .715 .738 r
.50475 .8688 m .50611 .87146 L .50763 .8692 L F
.562 .848 .997 r
.37647 .78647 m .37468 .7871 L .373 .78643 L F
.776 .786 .861 r
.6712 .70677 m .67246 .70864 L .66943 .71004 L F
.406 .383 .72 r
.67362 .70797 m .67246 .70864 L .6712 .70677 L F
.499 .751 .985 r
.3232 .67807 m .32371 .67665 L .32067 .67535 L F
.3232 .67807 m .32505 .67774 L .32371 .67665 L F
.587 .497 .719 r
.3232 .67807 m .32588 .6808 L .32505 .67774 L F
.3232 .67807 m .32386 .68122 L .32588 .6808 L F
.839 .887 .875 r
.54014 .8288 m .53893 .83083 L .5413 .8294 L F
0 0 .487 r
.5413 .8294 m .54246 .82831 L .54014 .8288 L F
.5413 .8294 m .54245 .83076 L .54246 .82831 L F
.5413 .8294 m .54299 .83176 L .54245 .83076 L F
.357 .273 .623 r
.54175 .83212 m .54299 .83176 L .5413 .8294 L F
.453 .615 .919 r
.68436 .71919 m .68336 .72066 L .68358 .7196 L F
.68436 .71919 m .68522 .72028 L .68336 .72066 L F
.586 .498 .722 r
.68522 .72028 m .68343 .723 L .68336 .72066 L F
0 0 0 r
.65111 .61153 m .65285 .61088 L .65026 .61331 L F
.585 .401 .599 r
.5088 .85925 m .512 .85844 L .51128 .85587 L F
.977 .813 .613 r
.64597 .72801 m .64647 .73099 L .64645 .72863 L F
.606 .69 .902 r
.35009 .67783 m .34806 .67825 L .34719 .67668 L F
.844 .703 .707 r
.70064 .74104 m .69912 .74398 L .70182 .74401 L F
.824 .636 .648 r
.69873 .74632 m .70182 .74401 L .69912 .74398 L F
.69873 .74632 m .7007 .74728 L .70182 .74401 L F
.528 .285 .491 r
.42932 .76009 m .43145 .75981 L .43173 .75781 L F
.422 .198 .467 r
.43173 .75781 m .43361 .75734 L .43388 .75516 L F
.474 .342 .621 r
.43173 .75781 m .43371 .75975 L .43361 .75734 L F
.593 .343 .507 r
.43145 .75981 m .43371 .75975 L .43173 .75781 L F
.575 .465 .692 r
.32386 .68122 m .32625 .68306 L .32588 .6808 L F
.32386 .68122 m .32419 .68347 L .32625 .68306 L F
.302 .39 .787 r
.45723 .87443 m .45944 .87639 L .45832 .87315 L F
.533 .42 .671 r
.4573 .87584 m .45944 .87639 L .45723 .87443 L F
.88 .692 .644 r
.69193 .7363 m .68983 .73642 L .69061 .73318 L F
.908 .945 .816 r
.69193 .7363 m .68905 .73847 L .68983 .73642 L F
.256 0 0 r
.38198 .72462 m .3856 .72276 L .38241 .72357 L F
.097 0 0 r
.38405 .72421 m .3876 .7234 L .3856 .72276 L F
.343 0 .14 r
.65005 .64633 m .64778 .6478 L .64754 .64674 L F
.855 .784 .781 r
.58014 .80766 m .58001 .81118 L .57862 .8107 L F
.714 .63 .762 r
.5794 .81368 m .5767 .81666 L .57655 .81618 L F
.5778 .81347 m .57705 .8151 L .57674 .81334 L F
.5794 .81368 m .57655 .81618 L .5778 .81347 L F
.5794 .81368 m .57562 .8132 L .57705 .81368 L F
.022 .122 .63 r
.57656 .81027 m .57705 .81368 L .57662 .81268 L F
.57624 .81049 m .57662 .81268 L .5758 .81077 L F
.57656 .81027 m .57662 .81268 L .57624 .81049 L F
.714 .63 .762 r
.57674 .81334 m .57655 .81618 L .57562 .8132 L F
.57705 .8151 m .57655 .81618 L .57674 .81334 L F
.783 .601 .654 r
.57901 .81084 m .57705 .81368 L .57862 .8107 L F
.58001 .81118 m .57812 .81278 L .57901 .81084 L F
.57812 .81278 m .57705 .81368 L .57901 .81084 L F
.58001 .81118 m .5794 .81368 L .57705 .81368 L F
.346 .822 .875 r
.47206 .88191 m .47552 .88143 L .47445 .88128 L F
.287 .531 .911 r
.47552 .88143 m .47701 .88124 L .47445 .88128 L F
.47552 .88143 m .47774 .88256 L .47701 .88124 L F
.303 0 .059 r
.37865 .79915 m .38177 .79685 L .3806 .79887 L F
.261 0 0 r
.38177 .79685 m .38658 .79569 L .38339 .79718 L F
.267 0 .1 r
.38177 .79685 m .38254 .79835 L .3806 .79887 L F
.38177 .79685 m .38339 .79718 L .38254 .79835 L F
.597 .349 .511 r
.43388 .75516 m .43361 .75734 L .43588 .75708 L F
.592 .448 .654 r
.43388 .75516 m .43605 .75487 L .4359 .75241 L F
.568 .351 .546 r
.43388 .75516 m .43588 .75708 L .43605 .75487 L F
.388 .098 .346 r
.65237 .64335 m .65201 .64565 L .65005 .64633 L F
.489 .204 .407 r
.65458 .64304 m .65201 .64565 L .65237 .64335 L F
0 0 0 r
.67068 .72343 m .66935 .72497 L .66919 .72271 L F
.986 .802 .573 r
.67068 .72343 m .66935 .72497 L .66919 .72271 L F
.67068 .72343 m .67034 .72569 L .66935 .72497 L F
.709 .746 .881 r
.59355 .84278 m .59725 .84316 L .59583 .84225 L F
.862 .872 .845 r
.59725 .84316 m .59807 .83982 L .59583 .84225 L F
.638 .7 .891 r
.57855 .81812 m .57764 .81962 L .5775 .81914 L F
.564 .377 .586 r
.57249 .82147 m .57267 .82378 L .57328 .82369 L F
.57409 .82281 m .57486 .82346 L .57334 .82362 L F
.57409 .82281 m .57337 .82359 L .57486 .82346 L F
.494 .766 .992 r
.5734 .82359 m .57486 .82346 L .57528 .82268 L F
.5734 .82359 m .57528 .82268 L .57501 .8226 L F
.57334 .82362 m .57486 .82346 L .5734 .82359 L F
0 0 0 r
.57409 .82281 m .57334 .82362 L .57344 .82352 L F
.564 .377 .586 r
.57249 .82147 m .57409 .82281 L .57334 .82362 L F
.57249 .82147 m .57328 .82369 L .57409 .82281 L F
0 0 0 r
.57409 .82281 m .57344 .82352 L .57642 .82037 L F
.5775 .81914 m .57334 .82362 L .57734 .81932 L F
.494 .766 .992 r
.57334 .82362 m .57547 .82231 L .57642 .82037 L F
.793 .644 .697 r
.5716 .82164 m .57434 .82364 L .57091 .82303 L F
.57249 .81989 m .57363 .82221 L .5716 .82164 L F
.57363 .82221 m .57434 .82364 L .5716 .82164 L F
.494 .766 .992 r
.57501 .8226 m .57528 .82268 L .57547 .82231 L F
.564 .377 .586 r
.57337 .82359 m .57328 .82369 L .57486 .82346 L F
0 0 0 r
.57734 .81932 m .57409 .82281 L .57642 .82037 L F
.719 .634 .762 r
.5854 .80551 m .58886 .80604 L .58771 .80278 L F
.646 .594 .782 r
.58771 .80278 m .58886 .80604 L .59095 .80532 L F
.853 .752 .751 r
.51251 .86158 m .512 .85844 L .51137 .86084 L F
.507 .465 .745 r
.52418 .85343 m .52465 .85647 L .5267 .8553 L F
.433 .394 .716 r
.52465 .85647 m .52625 .85739 L .5267 .8553 L F
.297 0 .242 r
.3662 .75192 m .36358 .75437 L .36472 .75304 L F
.599 .258 .365 r
.34999 .76274 m .34888 .7649 L .34704 .76327 L F
.564 .244 .385 r
.35201 .76263 m .34888 .7649 L .34999 .76274 L F
.238 .739 .67 r
.37119 .80222 m .37501 .80088 L .37316 .80173 L F
.38 .823 .688 r
.37316 .80173 m .37501 .80088 L .37677 .79995 L F
.606 .746 .944 r
.33342 .66343 m .33025 .66259 L .33231 .66229 L F
.283 .448 .849 r
.33433 .6621 m .33342 .66343 L .33231 .66229 L F
.33433 .6621 m .33559 .66448 L .33342 .66343 L F
.02 0 0 r
.65999 .62743 m .66161 .62704 L .66262 .62534 L F
0 0 0 r
.6587 .62836 m .66161 .62704 L .65999 .62743 L F
.63 .318 .423 r
.65999 .62743 m .65706 .62971 L .6587 .62836 L F
.802 .744 .798 r
.69129 .72539 m .6882 .72525 L .69108 .72302 L F
.69129 .72539 m .68994 .72596 L .6882 .72525 L F
.794 .864 .901 r
.69405 .72263 m .69129 .72539 L .69108 .72302 L F
.551 .344 .553 r
.65142 .71805 m .65275 .71581 L .65312 .71519 L F
.895 .657 .571 r
.6905 .74396 m .68845 .73939 L .6881 .74157 L F
.318 0 0 r
.58867 .81269 m .58765 .81044 L .58796 .81083 L F
.992 .815 .565 r
.54691 .84263 m .5454 .84395 L .54361 .8422 L F
.54691 .84263 m .5466 .84487 L .5454 .84395 L F
.855 .997 .807 r
.48383 .83051 m .48355 .83195 L .48597 .82926 L F
.931 .81 .704 r
.47817 .87096 m .47882 .87312 L .48148 .87332 L F
.756 .562 .634 r
.48524 .84219 m .49028 .84252 L .48778 .84051 L F
.645 .597 .786 r
.49151 .84239 m .48778 .84051 L .49098 .84202 L F
.16 .458 .885 r
.49028 .84252 m .49098 .84202 L .48778 .84051 L F
.698 .646 .794 r
.70295 .7363 m .70642 .73721 L .70527 .73571 L F
.686 .643 .801 r
.70527 .73571 m .70642 .73721 L .70846 .73607 L F
.48 .391 .678 r
.46144 .85582 m .46321 .85556 L .46281 .85324 L F
.574 .491 .723 r
.46164 .85828 m .46321 .85556 L .46144 .85582 L F
.915 .742 .653 r
.58252 .79438 m .5851 .79207 L .58369 .79115 L F
.58252 .79438 m .584 .79481 L .5851 .79207 L F
.877 .658 .603 r
.55075 .83182 m .55239 .83394 L .55153 .8324 L F
.55075 .83182 m .55039 .83465 L .55239 .83394 L F
.593 .306 .45 r
.34704 .76327 m .34681 .76494 L .34513 .76472 L F
.553 .271 .442 r
.34704 .76327 m .34888 .7649 L .34681 .76494 L F
.654 .286 .334 r
.56128 .78426 m .55817 .78567 L .55913 .7841 L F
.565 .519 .762 r
.48524 .84219 m .48863 .84307 L .49028 .84252 L F
.649 .442 .589 r
.48863 .84307 m .49098 .84202 L .49028 .84252 L F
.346 0 0 r
.49569 .86279 m .49143 .8625 L .49292 .86158 L F
.681 .29 .299 r
.40787 .77019 m .41105 .77069 L .40894 .76892 L F
.619 .33 .457 r
.40894 .76892 m .41105 .77069 L .41217 .7682 L F
.741 .783 .887 r
.70613 .72788 m .70223 .73078 L .70302 .72766 L F
.352 .64 .963 r
.68062 .71728 m .67978 .71851 L .67908 .71703 L F
.68062 .71728 m .68358 .7196 L .67978 .71851 L F
.442 .673 .961 r
.41502 .72608 m .41429 .72759 L .41239 .72598 L F
.41502 .72608 m .41627 .7276 L .41429 .72759 L F
.685 .643 .802 r
.63891 .7336 m .64224 .73409 L .64096 .73163 L F
.687 .592 .744 r
.52301 .87377 m .52498 .87275 L .52476 .87268 L F
.446 .165 .393 r
.52527 .87236 m .52557 .87176 L .52301 .87377 L F
.687 .592 .744 r
.52301 .87377 m .52476 .87268 L .52038 .87133 L F
.446 .165 .393 r
.52416 .8746 m .52527 .87236 L .52301 .87377 L F
.194 0 .28 r
.5277 .86908 m .52557 .87176 L .52697 .87209 L F
.059 .25 .744 r
.52491 .86994 m .52557 .87176 L .52697 .87209 L F
.246 .198 .604 r
.32561 .68876 m .32655 .6855 L .32455 .6856 L F
.32561 .68876 m .32681 .68862 L .32655 .6855 L F
.259 .303 .718 r
.32561 .68876 m .32757 .69071 L .32681 .68862 L F
.468 .337 .619 r
.32578 .69123 m .32757 .69071 L .32561 .68876 L F
.82 .46 .374 r
.53012 .87338 m .53142 .87155 L .52949 .87168 L F
.453 .094 .265 r
.4012 .78847 m .40433 .78586 L .40331 .7878 L F
.4012 .78847 m .40177 .78736 L .40433 .78586 L F
.35 .008 .237 r
.40694 .78413 m .40603 .78652 L .40433 .78586 L F
.362 0 .168 r
.40433 .78586 m .40603 .78652 L .40331 .7878 L F
.687 .592 .744 r
.52301 .87377 m .52038 .87133 L .52254 .87346 L F
.446 .165 .393 r
.52416 .8746 m .52301 .87377 L .52254 .87346 L F
.978 .738 .506 r
.57562 .8132 m .5767 .81666 L .57549 .81604 L F
.109 .349 .816 r
.5767 .81666 m .57759 .81625 L .57549 .81604 L F
.5767 .81666 m .57855 .81812 L .57759 .81625 L F
.822 .672 .698 r
.60123 .83983 m .6027 .83642 L .60039 .83671 L F
.794 .643 .695 r
.57415 .79221 m .57123 .79207 L .57158 .78973 L F
.988 .771 .379 r
.57415 .79221 m .57334 .79155 L .57123 .79207 L F
.57415 .79221 m .57344 .79387 L .57334 .79155 L F
.57415 .79221 m .57406 .79461 L .57344 .79387 L F
0 0 0 r
.52129 .88194 m .52447 .87967 L .52321 .87904 L F
.796 .79 .847 r
.52447 .87967 m .52557 .87634 L .52321 .87904 L F
.52447 .87967 m .52704 .8775 L .52557 .87634 L F
.685 .643 .802 r
.63891 .7336 m .64096 .73163 L .6386 .73157 L F
.202 .73 .815 r
.49647 .89011 m .4974 .8898 L .49529 .89007 L F
.49647 .89011 m .49857 .8898 L .4974 .8898 L F
.488 .531 .827 r
.34363 .67446 m .34188 .6746 L .34076 .67208 L F
.601 .21 .274 r
.5689 .7836 m .57201 .78206 L .5686 .7815 L F
.5689 .7836 m .57102 .78385 L .57201 .78206 L F
.688 .308 .321 r
.57102 .78385 m .5744 .78407 L .57201 .78206 L F
.706 .285 .244 r
.57201 .78206 m .5744 .78407 L .57551 .78338 L F
.473 .173 .376 r
.66468 .63579 m .66461 .63747 L .6621 .63779 L F
.544 .165 .273 r
.66468 .63579 m .66695 .63722 L .66461 .63747 L F
.66468 .63579 m .66699 .63583 L .66695 .63722 L F
.546 .533 .792 r
.53242 .8184 m .53027 .81846 L .53015 .8166 L F
.524 0 0 r
.53134 .8177 m .53242 .8184 L .53015 .8166 L F
.341 .745 .982 r
.53134 .8177 m .53641 .81829 L .53242 .8184 L F
0 .178 .7 r
.53355 .82119 m .53454 .82076 L .53242 .8184 L F
.601 .091 0 r
.53242 .8184 m .53454 .82076 L .53335 .81966 L F
.766 .498 .53 r
.53335 .81966 m .53665 .81993 L .53637 .81828 L F
.53561 .81814 m .53637 .81828 L .53627 .8177 L F
.341 .745 .982 r
.53641 .81829 m .53647 .8183 L .53242 .8184 L F
.53647 .8183 m .53649 .8183 L .53242 .8184 L F
.53647 .8183 m .5365 .8183 L .53649 .8183 L F
.546 .533 .792 r
.53242 .8184 m .53031 .81913 L .53027 .81846 L F
.297 0 .216 r
.53242 .8184 m .53023 .82012 L .53031 .81913 L F
.53242 .8184 m .53023 .82012 L .53031 .81913 L F
.828 .856 .867 r
.52983 .81942 m .53242 .8184 L .53134 .8177 L F
.52983 .81942 m .53023 .82012 L .53242 .8184 L F
.601 .091 0 r
.53242 .8184 m .53335 .81966 L .53134 .8177 L F
.682 .342 .392 r
.53134 .8177 m .53335 .81966 L .5365 .8183 L F
.766 .498 .53 r
.53335 .81966 m .53637 .81828 L .53561 .81814 L F
0 .054 .547 r
.69424 .74958 m .69323 .74873 L .69205 .74925 L F
.69424 .74958 m .69536 .75069 L .69323 .74873 L F
.988 .895 .609 r
.69593 .74648 m .69536 .75069 L .69426 .74959 L F
.789 .766 .832 r
.69426 .74958 m .69446 .74979 L .69496 .74926 L F
.69424 .74958 m .69426 .74959 L .69426 .74958 L F
.69426 .74959 m .69446 .74979 L .69426 .74958 L F
.988 .895 .609 r
.69426 .74957 m .69426 .74959 L .69425 .74959 L F
.69593 .74648 m .69426 .74959 L .69426 .74957 L F
0 .054 .547 r
.69425 .74959 m .69426 .74959 L .69424 .74958 L F
.69426 .74959 m .69536 .75069 L .69424 .74958 L F
.789 .766 .832 r
.69336 .74998 m .69358 .75073 L .69446 .74979 L F
.69336 .74998 m .69446 .74979 L .69424 .74958 L F
0 .054 .547 r
.69424 .74958 m .69323 .74873 L .69424 .74958 L F
.188 .169 .603 r
.6935 .74663 m .69424 .74957 L .69205 .74925 L F
.789 .766 .832 r
.69424 .74958 m .69496 .74926 L .69429 .74937 L F
0 .054 .547 r
.69425 .74959 m .69424 .74958 L .69424 .74958 L F
.188 .169 .603 r
.69424 .74957 m .69425 .74959 L .69424 .74958 L F
.69424 .74957 m .69424 .74958 L .69205 .74925 L F
.789 .766 .832 r
.69429 .74937 m .69496 .74926 L .6958 .74836 L F
.69336 .74998 m .69424 .74958 L .69429 .74937 L F
.988 .895 .609 r
.69593 .74648 m .69425 .74959 L .69522 .74604 L F
.629 .447 .618 r
.69522 .74604 m .69425 .74959 L .6935 .74663 L F
.789 .766 .832 r
.6929 .74836 m .69336 .74998 L .6958 .74836 L F
.496 .853 .991 r
.3911 .72382 m .39126 .72288 L .3931 .7235 L F
.3911 .72382 m .38979 .7233 L .39126 .72288 L F
.669 .949 .956 r
.69768 .72152 m .69405 .72263 L .69662 .72066 L F
.844 .876 .865 r
.69969 .7195 m .69768 .72152 L .69662 .72066 L F
.153 0 .149 r
.40768 .78544 m .40694 .78413 L .40891 .7834 L F
.40768 .78544 m .40603 .78652 L .40694 .78413 L F
.577 .184 .26 r
.33135 .74324 m .33152 .74207 L .33004 .74307 L F
.33135 .74324 m .3322 .74175 L .33152 .74207 L F
.011 .584 .757 r
.47817 .87096 m .47432 .87069 L .47555 .87012 L F
0 0 0 r
.55119 .84437 m .5492 .8471 L .5502 .84526 L F
.79 .822 .878 r
.59063 .84306 m .59137 .84484 L .59355 .84278 L F
.953 .687 .494 r
.54741 .8284 m .5486 .82672 L .54771 .82607 L F
.54741 .8284 m .54874 .82907 L .5486 .82672 L F
0 0 0 r
.49481 .84592 m .49375 .84712 L .49317 .84745 L F
0 .218 .74 r
.49375 .84712 m .49499 .84937 L .49317 .84745 L F
.523 .173 .315 r
.41105 .77069 m .41444 .76831 L .41217 .7682 L F
.498 .719 .971 r
.64497 .62224 m .64831 .6232 L .6475 .62205 L F
.853 .929 .546 r
.48383 .83051 m .48226 .83366 L .48355 .83195 L F
.995 .754 .416 r
.66941 .71152 m .66882 .71142 L .66943 .71004 L F
.776 .786 .861 r
.6712 .70677 m .66943 .71004 L .66951 .70957 L F
.756 .808 .329 r
.66882 .71142 m .66951 .70957 L .66943 .71004 L F
.998 .796 .503 r
.5758 .81077 m .57562 .8132 L .5747 .81251 L F
.636 .451 .616 r
.5758 .81077 m .57705 .81368 L .57562 .8132 L F
.022 .122 .63 r
.57656 .81027 m .5758 .81077 L .5747 .81251 L F
.71 .173 0 r
.51792 .86161 m .52024 .8628 L .51995 .8609 L F
.51792 .86161 m .52126 .86417 L .52024 .8628 L F
.579 .385 .583 r
.51137 .86084 m .5088 .85925 L .50951 .86021 L F
.51137 .86084 m .512 .85844 L .5088 .85925 L F
.562 .262 .416 r
.45373 .75812 m .4533 .75983 L .45122 .76003 L F
.641 .401 .539 r
.45574 .75761 m .4533 .75983 L .45373 .75812 L F
.625 .503 .694 r
.44649 .73901 m .44454 .74169 L .44426 .73954 L F
.623 .168 .151 r
.53968 .86124 m .54073 .86257 L .53946 .86357 L F
.922 .621 .457 r
.52322 .86829 m .52494 .86906 L .52441 .86646 L F
.984 .752 .508 r
.52322 .86829 m .52441 .86646 L .52329 .86591 L F
.922 .621 .457 r
.52322 .86829 m .52494 .86906 L .52441 .86646 L F
.984 .752 .508 r
.52322 .86829 m .52441 .86646 L .52329 .86591 L F
.766 .56 .619 r
.54488 .83993 m .54361 .8422 L .5436 .83992 L F
0 0 0 r
.36017 .80699 m .35952 .80724 L .36143 .8068 L F
.36017 .80699 m .35834 .80775 L .35952 .80724 L F
.95 .826 .688 r
.58864 .81271 m .59194 .81062 L .59303 .81272 L F
.853 .837 .829 r
.59299 .8091 m .59194 .81062 L .59418 .8078 L F
.666 .533 .692 r
.59194 .81062 m .59502 .81201 L .59418 .8078 L F
.654 .574 .753 r
.59303 .81272 m .59502 .81201 L .59194 .81062 L F
.538 .421 .668 r
.32455 .6856 m .32625 .68306 L .32419 .68347 L F
.37 .48 .842 r
.68454 .75284 m .68423 .75123 L .68372 .75082 L F
0 .158 .682 r
.68454 .75284 m .68535 .7517 L .68423 .75123 L F
.287 .527 .908 r
.68454 .75284 m .68552 .7519 L .68535 .7517 L F
.68454 .75284 m .68705 .75375 L .68552 .7519 L F
.483 .308 .567 r
.46308 .8505 m .46503 .85247 L .46472 .84971 L F
.46308 .8505 m .46281 .85324 L .46503 .85247 L F
.588 .443 .651 r
.45966 .86158 m .46201 .86129 L .46164 .85828 L F
.587 .479 .698 r
.45966 .86158 m .4623 .86347 L .46201 .86129 L F
.45966 .86158 m .46013 .86377 L .4623 .86347 L F
.448 .882 .863 r
.35261 .80978 m .35179 .81046 L .35311 .80988 L F
.464 .875 .733 r
.35096 .81077 m .35179 .81046 L .35261 .80978 L F
.157 .698 .757 r
.38251 .78447 m .38216 .78465 L .38036 .78497 L F
.38251 .78447 m .38429 .78431 L .38216 .78465 L F
.863 .843 .823 r
.66679 .62273 m .66512 .62647 L .66409 .62422 L F
.743 .646 .753 r
.66368 .62634 m .6664 .6271 L .6657 .62341 L F
.703 .394 0 r
.66593 .62576 m .6664 .6271 L .66368 .62634 L F
.66593 .62576 m .6664 .62716 L .6664 .6271 L F
.94 .58 .189 r
.6664 .6271 m .66734 .62787 L .66566 .62777 L F
.703 .394 0 r
.6664 .62716 m .66693 .62875 L .6664 .6271 L F
0 0 0 r
.6664 .62693 m .6664 .6271 L .66566 .62777 L F
.66796 .62517 m .6664 .6271 L .6664 .62693 L F
.215 .729 .69 r
.68583 .75036 m .68906 .74939 L .68685 .74996 L F
.337 .471 .848 r
.66679 .62273 m .66937 .62397 L .66796 .62517 L F
0 0 0 r
.66937 .62397 m .6664 .6271 L .66796 .62517 L F
.869 .865 .832 r
.68906 .74939 m .69028 .74601 L .69205 .74925 L F
.188 .169 .603 r
.6935 .74663 m .69205 .74925 L .69028 .74601 L F
.8 .809 .86 r
.54422 .80545 m .54076 .806 L .54365 .80544 L F
.349 .825 .811 r
.54422 .80545 m .54365 .80544 L .54576 .80475 L F
.563 .071 0 r
.54502 .80644 m .54422 .80545 L .54365 .80544 L F
.54502 .80644 m .54621 .80768 L .54422 .80545 L F
.785 .3 .067 r
.54422 .80545 m .54621 .80768 L .54753 .80785 L F
.693 .807 .936 r
.46567 .87616 m .46255 .87679 L .46591 .87695 L F
.468 .734 .985 r
.46591 .87695 m .46745 .8759 L .46567 .87616 L F
.46591 .87695 m .4679 .87679 L .46745 .8759 L F
.95 .826 .688 r
.58864 .81271 m .59303 .81272 L .59079 .81314 L F
.671 .355 .43 r
.59079 .81314 m .5924 .81545 L .59303 .81272 L F
.654 .574 .753 r
.59303 .81272 m .59545 .81329 L .59502 .81201 L F
.789 .475 .456 r
.5924 .81545 m .59539 .81565 L .59303 .81272 L F
.686 .477 .598 r
.59539 .81565 m .59545 .81329 L .59303 .81272 L F
.455 0 0 r
.54848 .814 m .5478 .81376 L .54578 .81251 L F
0 .117 .62 r
.54848 .814 m .54967 .81479 L .5478 .81376 L F
.54848 .814 m .55058 .81578 L .54967 .81479 L F
.319 .783 .94 r
.49151 .84239 m .49098 .84202 L .49362 .84213 L F
.419 .216 .496 r
.52218 .86448 m .5217 .86576 L .52329 .86591 L F
.31 .424 .816 r
.52042 .87711 m .51886 .877 L .51788 .87566 L F
.633 .13 .037 r
.51678 .87637 m .52042 .87711 L .51788 .87566 L F
.294 .425 .823 r
.51788 .87566 m .52042 .87711 L .51894 .874 L F
.721 .779 .898 r
.35559 .6755 m .35247 .67515 L .3546 .67413 L F
.537 .301 .504 r
.35559 .6755 m .3531 .67846 L .35247 .67515 L F
.35559 .6755 m .35468 .67833 L .3531 .67846 L F
0 0 .076 r
.35654 .67227 m .35559 .6755 L .3546 .67413 L F
.35654 .67227 m .35624 .67431 L .35559 .6755 L F
.018 0 .242 r
.35644 .67647 m .35559 .6755 L .35624 .67431 L F
.35644 .67647 m .35468 .67833 L .35559 .6755 L F
.101 .432 .873 r
.47811 .87676 m .4772 .87665 L .47531 .8744 L F
.724 .571 .681 r
.59418 .8078 m .59739 .81039 L .59757 .80822 L F
.395 .15 .42 r
.32122 .69889 m .324 .69705 L .32154 .69671 L F
.576 .602 .842 r
.4474 .73438 m .44628 .73656 L .44511 .7341 L F
.4474 .73438 m .44837 .73625 L .44628 .73656 L F
.579 .444 .662 r
.44837 .73625 m .44649 .73901 L .44628 .73656 L F
.698 .681 .83 r
.69799 .71564 m .69939 .71825 L .69621 .71813 L F
.634 .089 0 r
.69969 .7195 m .69621 .71813 L .69939 .71825 L F
.664 .666 .842 r
.70175 .71771 m .69939 .71825 L .69799 .71564 L F
.543 .369 .595 r
.70175 .71771 m .69969 .7195 L .69939 .71825 L F
.319 .556 .92 r
.57077 .84212 m .56727 .83972 L .56915 .84249 L F
.678 .552 .705 r
.51339 .84242 m .51448 .84548 L .51634 .84265 L F
.392 .728 .99 r
.53408 .86823 m .53566 .86932 L .53317 .86928 L F
.53317 .86928 m .53566 .86932 L .53408 .86823 L F
.521 .886 .976 r
.66438 .6109 m .66205 .61152 L .66322 .61052 L F
.66438 .6109 m .66205 .61152 L .66322 .61052 L F
.934 .622 .163 r
.66205 .61152 m .66242 .61307 L .66438 .6109 L F
.648 .711 .893 r
.55526 .81863 m .55883 .81923 L .55768 .8187 L F
.482 .248 .482 r
.64422 .63069 m .6464 .63008 L .64701 .62792 L F
.739 .99 .805 r
.64422 .63069 m .64534 .62891 L .6464 .63008 L F
.143 .368 .824 r
.6759 .69998 m .67629 .70054 L .67749 .70092 L F
.333 .362 .742 r
.67749 .70092 m .67583 .7009 L .67654 .70036 L F
.836 .806 .823 r
.67575 .70206 m .67381 .70236 L .6759 .69998 L F
.499 .305 .548 r
.67768 .69868 m .67761 .69948 L .6759 .69998 L F
.67761 .69948 m .67749 .70092 L .67654 .70036 L F
.67761 .69948 m .67654 .70036 L .6759 .69998 L F
0 0 0 r
.67648 .7004 m .67448 .70214 L .6772 .69991 L F
.67645 .70043 m .67637 .7005 L .67648 .7004 L F
.67637 .7005 m .67448 .70214 L .67648 .7004 L F
.67629 .70054 m .67618 .70064 L .67645 .70043 L F
.67618 .70064 m .67448 .70214 L .67645 .70043 L F
.333 .362 .742 r
.67749 .70092 m .67575 .70206 L .67583 .7009 L F
.67606 .70072 m .67583 .7009 L .6759 .69998 L F
.742 .639 .745 r
.6759 .69998 m .67381 .70236 L .67606 .70071 L F
.6759 .69998 m .67606 .70071 L .67629 .70054 L F
.333 .362 .742 r
.67654 .70036 m .67606 .70072 L .6759 .69998 L F
.052 0 .262 r
.67749 .70092 m .67584 .70383 L .67575 .70206 L F
.51 .158 .307 r
.67575 .70206 m .6733 .70405 L .67381 .70236 L F
.67575 .70206 m .67584 .70383 L .6733 .70405 L F
.827 .627 .632 r
.58629 .79975 m .58777 .80024 L .5864 .79742 L F
.811 .626 .653 r
.58629 .79975 m .58771 .80278 L .58777 .80024 L F
.986 .798 .569 r
.57697 .80272 m .57584 .80213 L .57615 .79981 L F
.871 .544 .43 r
.57697 .80272 m .57568 .80451 L .57584 .80213 L F
.57697 .80272 m .57796 .80533 L .57568 .80451 L F
.431 .119 .334 r
.42932 .76009 m .43056 .76178 L .43145 .75981 L F
.42932 .76009 m .4286 .76225 L .43056 .76178 L F
.547 .43 .672 r
.52038 .87133 m .51852 .86959 L .51922 .87104 L F
.774 .303 .122 r
.52076 .8734 m .52038 .87133 L .51922 .87104 L F
.617 .61 .821 r
.51894 .874 m .52042 .87711 L .52261 .87624 L F
.51986 .8747 m .52261 .87624 L .52122 .87573 L F
.51894 .874 m .51974 .87448 L .51986 .8747 L F
.51974 .87448 m .52261 .87624 L .51986 .8747 L F
.611 .092 0 r
.51905 .87813 m .52042 .87711 L .51678 .87637 L F
0 0 0 r
.52261 .87624 m .52104 .87707 L .52122 .87573 L F
.52104 .87707 m .51905 .87813 L .52064 .87637 L F
.52104 .87707 m .52064 .87637 L .52122 .87573 L F
.557 .359 .569 r
.51894 .874 m .51922 .87104 L .51638 .87162 L F
.55 .353 .567 r
.52076 .8734 m .51922 .87104 L .51901 .87325 L F
.51933 .87387 m .51901 .87325 L .51894 .874 L F
.52076 .8734 m .51901 .87325 L .51933 .87387 L F
.667 .271 0 r
.51867 .87287 m .51978 .87472 L .52015 .87552 L F
.51978 .87472 m .5198 .87476 L .51983 .87482 L F
.51978 .87472 m .51983 .87482 L .52015 .87552 L F
.771 .593 .658 r
.51905 .87813 m .52092 .87815 L .52122 .87573 L F
.667 .271 0 r
.51909 .87367 m .52015 .87552 L .52077 .87688 L F
.51867 .87287 m .52015 .87552 L .51909 .87367 L F
.229 0 .331 r
.5198 .87476 m .51988 .87472 L .52077 .87688 L F
.51988 .87472 m .52098 .87409 L .52082 .87631 L F
.51988 .87472 m .52082 .87631 L .52077 .87688 L F
.774 .303 .122 r
.52097 .87341 m .52254 .87346 L .52093 .87187 L F
.922 .652 .509 r
.52261 .87624 m .52254 .87346 L .52076 .8734 L F
.52261 .87624 m .52076 .8734 L .52122 .87573 L F
.229 0 .331 r
.52098 .87409 m .52104 .87633 L .5209 .87663 L F
.52078 .87675 m .5209 .87663 L .52077 .87688 L F
.52098 .87409 m .5209 .87663 L .52078 .87675 L F
.52098 .87409 m .52259 .87317 L .52109 .87622 L F
.774 .303 .122 r
.52076 .8734 m .52097 .87341 L .52038 .87133 L F
.52097 .87341 m .52093 .87187 L .52038 .87133 L F
.815 .583 .587 r
.52261 .87624 m .52416 .8746 L .52254 .87346 L F
.921 .713 .605 r
.52092 .87815 m .52261 .87624 L .52122 .87573 L F
.736 .62 .729 r
.51859 .87233 m .52076 .8734 L .5198 .87476 L F
.229 0 .331 r
.5198 .87476 m .52076 .8734 L .52259 .87317 L F
.551 .671 .917 r
.52005 .87211 m .52076 .8734 L .51859 .87233 L F
.298 .519 .9 r
.52259 .87317 m .52076 .8734 L .52005 .87211 L F
.766 .656 .741 r
.51881 .8697 m .52262 .87003 L .52005 .87211 L F
.298 .519 .9 r
.52259 .87317 m .52005 .87211 L .52262 .87003 L F
.469 .264 .518 r
.52259 .87317 m .52262 .87003 L .52455 .86975 L F
.52259 .87317 m .52455 .86975 L .52406 .87216 L F
.369 .364 .723 r
.52113 .87621 m .52139 .8761 L .52139 .87609 L F
.087 0 .116 r
.52129 .87614 m .52259 .87317 L .52406 .87216 L F
.52121 .87617 m .52259 .87317 L .52129 .87614 L F
.5209 .87663 m .52259 .87317 L .52159 .87536 L F
.52092 .8766 m .52159 .87536 L .52111 .8764 L F
.5209 .87663 m .52159 .87536 L .52092 .8766 L F
.667 .271 0 r
.52113 .87621 m .52077 .87688 L .52166 .87693 L F
.229 0 .331 r
.52104 .87625 m .52109 .87622 L .52104 .87633 L F
.667 .271 0 r
.51867 .87287 m .52077 .87688 L .52113 .87621 L F
.229 0 .331 r
.52098 .87409 m .52109 .87622 L .52104 .87625 L F
.762 .921 .553 r
.52145 .87582 m .52406 .87216 L .52345 .87274 L F
.369 .364 .723 r
.52113 .87621 m .52139 .87609 L .52113 .87621 L F
.52113 .87621 m .52166 .87693 L .52139 .8761 L F
.087 0 .116 r
.52111 .8764 m .52121 .87617 L .52129 .87614 L F
.762 .921 .553 r
.52077 .87688 m .52129 .87614 L .52145 .87582 L F
.696 .558 .695 r
.51989 .87159 m .52136 .87601 L .52345 .87274 L F
.762 .921 .553 r
.52129 .87614 m .52166 .87554 L .52136 .87601 L F
.696 .558 .695 r
.52136 .87601 m .52139 .87609 L .52345 .87274 L F
.762 .921 .553 r
.52129 .87614 m .52406 .87216 L .52166 .87554 L F
.52136 .87601 m .52166 .87554 L .52145 .87582 L F
.369 .364 .723 r
.52113 .87621 m .52129 .87614 L .51989 .87159 L F
.52129 .87614 m .52139 .87609 L .52136 .87601 L F
.52129 .87614 m .52136 .87601 L .51989 .87159 L F
.087 0 .116 r
.52077 .87688 m .5209 .87663 L .52111 .8764 L F
.696 .558 .695 r
.52139 .87609 m .52139 .8761 L .52141 .87607 L F
.52139 .87609 m .52141 .87607 L .52345 .87274 L F
.809 .748 .796 r
.52321 .87904 m .52261 .87624 L .52237 .87869 L F
.52321 .87904 m .52557 .87634 L .52261 .87624 L F
.921 .713 .605 r
.52092 .87815 m .52237 .87869 L .52261 .87624 L F
.593 .771 .965 r
.52263 .87678 m .52211 .87764 L .52426 .87716 L F
.696 .558 .695 r
.5216 .87675 m .52174 .87675 L .52182 .87656 L F
.52171 .87654 m .52182 .87656 L .52253 .87489 L F
.5216 .87675 m .52182 .87656 L .52171 .87654 L F
.52139 .8761 m .52152 .87648 L .52253 .87489 L F
.52152 .87648 m .5216 .87675 L .52171 .87654 L F
.52152 .87648 m .52171 .87654 L .52253 .87489 L F
.762 .921 .553 r
.52095 .8766 m .52109 .87639 L .52174 .87675 L F
.696 .558 .695 r
.52139 .8761 m .52253 .87489 L .52345 .87274 L F
.762 .921 .553 r
.52109 .87639 m .52345 .87274 L .52182 .87656 L F
.52109 .87639 m .52182 .87656 L .52174 .87675 L F
.593 .771 .965 r
.52426 .87716 m .52211 .87764 L .52115 .87644 L F
.52391 .87712 m .52115 .87644 L .52277 .877 L F
.52426 .87716 m .52263 .87678 L .52391 .87712 L F
.52139 .87674 m .52211 .87764 L .52263 .87678 L F
.52263 .87678 m .52115 .87644 L .52391 .87712 L F
.52115 .87644 m .52134 .87667 L .52263 .87678 L F
.52134 .87667 m .52139 .87674 L .52174 .87675 L F
.52134 .87667 m .52174 .87675 L .52263 .87678 L F
.762 .921 .553 r
.52077 .87688 m .52095 .8766 L .52166 .87693 L F
.696 .558 .695 r
.5216 .87675 m .52166 .87693 L .52174 .87675 L F
.762 .921 .553 r
.52095 .8766 m .52174 .87675 L .52166 .87693 L F
.593 .771 .965 r
.52115 .87644 m .52263 .87678 L .52277 .877 L F
.52263 .87678 m .52426 .87716 L .52391 .87712 L F
.52263 .87678 m .52391 .87712 L .52277 .877 L F
.715 .331 0 r
.51859 .87233 m .5198 .87476 L .51867 .87287 L F
.112 0 0 r
.52005 .87211 m .51859 .87233 L .51867 .87287 L F
.369 .364 .723 r
.51867 .87287 m .52113 .87621 L .51989 .87159 L F
.662 .785 .94 r
.3538 .79444 m .35065 .79411 L .35253 .79386 L F
.688 .893 .972 r
.35581 .79339 m .3538 .79444 L .35253 .79386 L F
.754 .45 .469 r
.52697 .87209 m .52949 .87168 L .5277 .86908 L F
.567 .939 .869 r
.67032 .61637 m .66871 .61775 L .67131 .61697 L F
.454 .839 .985 r
.65174 .62792 m .65453 .62743 L .65495 .62788 L F
.675 .288 .305 r
.65174 .62792 m .65495 .62788 L .65357 .62943 L F
.959 .942 .644 r
.65495 .62788 m .65453 .62743 L .65357 .62943 L F
.546 .399 .633 r
.65485 .63041 m .65706 .62971 L .65495 .62788 L F
.556 .319 .512 r
.64701 .62792 m .6464 .63008 L .64889 .62762 L F
.761 .616 .699 r
.51995 .8609 m .52321 .86115 L .52337 .85886 L F
.242 0 0 r
.3931 .7235 m .39527 .72346 L .39635 .72304 L F
.631 .126 .032 r
.39126 .72288 m .39527 .72346 L .3931 .7235 L F
.39126 .72288 m .39356 .72412 L .39527 .72346 L F
.39356 .72412 m .39372 .72421 L .39527 .72346 L F
.242 0 0 r
.39635 .72304 m .39527 .72346 L .39648 .72302 L F
.266 .771 .863 r
.39527 .72346 m .39844 .72316 L .39648 .72302 L F
.816 .524 .495 r
.54668 .80948 m .54753 .80785 L .54621 .80768 L F
.54668 .80948 m .54939 .80824 L .54753 .80785 L F
.625 .662 .865 r
.44009 .7334 m .43656 .73169 L .43878 .73254 L F
.287 .695 .973 r
.44081 .73272 m .44009 .7334 L .43878 .73254 L F
.44081 .73272 m .44208 .7335 L .44009 .7334 L F
.158 .698 .747 r
.37146 .75092 m .3705 .75099 L .36832 .75136 L F
.239 .604 .953 r
.37266 .75115 m .37382 .75133 L .37146 .75092 L F
0 .573 .763 r
.37382 .75133 m .3705 .75099 L .37146 .75092 L F
.634 .089 0 r
.69969 .7195 m .69856 .71972 L .69621 .71813 L F
.844 .876 .865 r
.69969 .7195 m .69662 .72066 L .69856 .71972 L F
.543 .369 .595 r
.70175 .71771 m .70178 .72012 L .69969 .7195 L F
.647 .773 .94 r
.39972 .74392 m .4013 .74536 L .40339 .74459 L F
.551 .724 .954 r
.43212 .72974 m .43126 .73133 L .4301 .72988 L F
.43212 .72974 m .43331 .73098 L .43126 .73133 L F
.239 .604 .953 r
.37266 .75115 m .37509 .75238 L .37382 .75133 L F
.741 .809 .906 r
.37382 .75133 m .37509 .75238 L .3769 .75117 L F
.428 .215 .485 r
.32733 .71198 m .32659 .71404 L .32532 .71514 L F
.431 .21 .476 r
.32887 .71137 m .32659 .71404 L .32733 .71198 L F
.934 .849 .736 r
.6468 .60842 m .64638 .61233 L .64518 .61152 L F
.749 .407 .404 r
.64638 .61233 m .64473 .61351 L .64518 .61152 L F
.64638 .61233 m .6488 .61426 L .64473 .61351 L F
.605 .729 .932 r
.42701 .72739 m .42768 .72861 L .42472 .7279 L F
.489 .663 .939 r
.42895 .7273 m .42768 .72861 L .42701 .72739 L F
.383 .491 .845 r
.42895 .7273 m .4301 .72988 L .42768 .72861 L F
.725 .809 .917 r
.34855 .795 m .34516 .79497 L .34713 .79404 L F
.691 .822 .945 r
.35065 .79411 m .34855 .795 L .34713 .79404 L F
.516 .199 .368 r
.41907 .77695 m .41904 .77916 L .41603 .77887 L F
.44 .14 .359 r
.4207 .77823 m .41904 .77916 L .41907 .77695 L F
.531 .289 .493 r
.34513 .76472 m .34178 .76815 L .34279 .76554 L F
.682 .599 .756 r
.48413 .8453 m .48524 .84219 L .48268 .8423 L F
.48413 .8453 m .48596 .84594 L .48524 .84219 L F
.727 .323 .283 r
.48413 .8453 m .48628 .8469 L .48596 .84594 L F
.48413 .8453 m .48628 .8469 L .48596 .84594 L F
.835 .651 .653 r
.584 .79481 m .58341 .79702 L .5864 .79742 L F
.836 .634 .63 r
.58341 .79702 m .58629 .79975 L .5864 .79742 L F
.468 .127 .304 r
.354 .73337 m .35607 .7331 L .35675 .73165 L F
.434 .094 .287 r
.35607 .7331 m .35869 .73129 L .35675 .73165 L F
.696 .336 .36 r
.49627 .87948 m .49954 .87935 L .49837 .88153 L F
.161 .682 .884 r
.49954 .87935 m .50171 .87939 L .5007 .87908 L F
.49954 .87935 m .5007 .87908 L .49837 .88153 L F
.666 .749 .912 r
.57434 .82908 m .57233 .82997 L .57055 .82872 L F
.591 .204 .278 r
.53275 .8495 m .53158 .84746 L .53069 .84991 L F
.53275 .8495 m .53401 .84756 L .53158 .84746 L F
.767 .585 .651 r
.59852 .81595 m .59545 .81329 L .59539 .81565 L F
.797 .57 .594 r
.59843 .8184 m .59852 .81595 L .59539 .81565 L F
.807 .597 .618 r
.60027 .81868 m .59852 .81595 L .59843 .8184 L F
.587 .452 .664 r
.44671 .7413 m .44454 .74169 L .44649 .73901 L F
.584 .463 .68 r
.44671 .7413 m .44514 .74392 L .44454 .74169 L F
.945 .614 .37 r
.58407 .80491 m .5845 .80705 L .5854 .80551 L F
.854 .887 .861 r
.58407 .80491 m .5854 .80551 L .58771 .80278 L F
.915 .559 .347 r
.5845 .80705 m .58609 .80765 L .5854 .80551 L F
.513 .228 .418 r
.44366 .76541 m .44105 .76717 L .44152 .76559 L F
.399 .097 .333 r
.53288 .85575 m .53531 .85324 L .53508 .85545 L F
.491 .276 .514 r
.53531 .85324 m .53732 .8529 L .53508 .85545 L F
.227 0 0 r
.36336 .72984 m .36545 .72943 L .36692 .72797 L F
.398 0 .1 r
.36545 .72943 m .36891 .72743 L .36692 .72797 L F
.891 .659 .582 r
.60245 .82395 m .60033 .82101 L .60037 .82355 L F
.873 .648 .596 r
.60001 .82585 m .60245 .82395 L .60037 .82355 L F
.60001 .82585 m .60235 .82589 L .60245 .82395 L F
.407 .433 .775 r
.38921 .74625 m .39025 .74981 L .38783 .748 L F
.719 .684 .815 r
.41918 .72823 m .41671 .72967 L .41627 .7276 L F
.181 .711 .719 r
.69621 .71813 m .69179 .71906 L .69553 .7171 L F
.69179 .71906 m .69621 .71813 L .69553 .7171 L F
.843 .928 .886 r
.69799 .71564 m .69621 .71813 L .69553 .7171 L F
.653 .184 .127 r
.69621 .71813 m .69536 .71941 L .69553 .7171 L F
.69621 .71813 m .69856 .71972 L .69536 .71941 L F
.267 0 0 r
.38957 .79418 m .38598 .79582 L .38744 .79488 L F
.2 0 0 r
.4083 .7435 m .40517 .74349 L .40658 .74334 L F
.417 .677 .969 r
.59575 .83655 m .59819 .83751 L .59646 .83637 L F
.774 .477 .483 r
.59807 .83982 m .59819 .83751 L .59575 .83655 L F
.951 .87 .721 r
.5999 .83475 m .60144 .8339 L .60036 .83339 L F
.656 .737 .91 r
.59819 .83751 m .60029 .83675 L .59646 .83637 L F
.60029 .83675 m .60028 .8367 L .59646 .83637 L F
.811 .667 .704 r
.59807 .83982 m .60039 .83671 L .59819 .83751 L F
.951 .87 .721 r
.59891 .83769 m .59906 .83747 L .59897 .83752 L F
.207 0 0 r
.5985 .83816 m .60039 .83671 L .59891 .83769 L F
.927 .909 .515 r
.5985 .83816 m .59891 .83769 L .59891 .83758 L F
.634 .196 .192 r
.59827 .83796 m .59892 .83757 L .5985 .83816 L F
.59646 .83637 m .60028 .8367 L .59906 .83747 L F
.59824 .83793 m .59906 .83747 L .59827 .83796 L F
.59646 .83637 m .59902 .83745 L .59824 .83793 L F
.936 .929 .567 r
.59903 .83518 m .59891 .83758 L .60036 .83339 L F
.59891 .83758 m .59891 .83769 L .59897 .83752 L F
.59891 .83758 m .59897 .83752 L .60036 .83339 L F
.634 .196 .192 r
.59902 .83745 m .59906 .83747 L .59897 .83751 L F
.59902 .83745 m .59897 .83751 L .59824 .83793 L F
.656 .737 .91 r
.60029 .83675 m .60039 .83671 L .60028 .8367 L F
.634 .196 .192 r
.60028 .8367 m .60039 .83671 L .59827 .83796 L F
.951 .87 .721 r
.59906 .83747 m .60039 .83671 L .60144 .8339 L F
.59891 .83769 m .60039 .83671 L .59906 .83747 L F
.927 .909 .515 r
.5985 .83816 m .59891 .83758 L .59903 .83518 L F
.634 .196 .192 r
.59892 .83757 m .60039 .83671 L .5985 .83816 L F
.951 .87 .721 r
.59897 .83752 m .60012 .83587 L .5999 .83475 L F
.59906 .83747 m .60012 .83587 L .59897 .83752 L F
.60012 .83587 m .60144 .8339 L .5999 .83475 L F
.748 .789 .886 r
.52557 .87634 m .52704 .8775 L .52773 .87632 L F
.565 .519 .762 r
.48524 .84219 m .48596 .84594 L .48863 .84307 L F
.441 .781 .998 r
.31947 .67566 m .32067 .67535 L .31865 .67495 L F
.784 .747 .819 r
.7019 .73376 m .69997 .73605 L .70295 .7363 L F
.805 .675 .721 r
.69997 .73605 m .70112 .73908 L .70295 .7363 L F
.703 .708 .852 r
.7019 .73376 m .70295 .7363 L .70527 .73571 L F
.564 .921 .953 r
.52735 .84491 m .52418 .84558 L .52551 .84578 L F
.418 .22 .502 r
.33311 .70404 m .33356 .70666 L .3313 .70671 L F
.412 .197 .475 r
.33356 .70666 m .33069 .70902 L .3313 .70671 L F
.538 .421 .668 r
.32455 .6856 m .32655 .6855 L .32625 .68306 L F
.523 .173 .315 r
.41105 .77069 m .41333 .77061 L .41444 .76831 L F
.42 .07 .263 r
.41444 .76831 m .41556 .77014 L .41657 .76806 L F
.41444 .76831 m .41333 .77061 L .41556 .77014 L F
0 .553 .75 r
.39844 .72316 m .40058 .72336 L .40175 .72353 L F
.243 .714 .942 r
.40058 .72336 m .40389 .72384 L .40175 .72353 L F
.793 .349 .192 r
.51922 .87104 m .51852 .86959 L .51664 .86857 L F
.837 .598 .578 r
.59848 .82073 m .60027 .81868 L .59843 .8184 L F
.59848 .82073 m .60033 .82101 L .60027 .81868 L F
.577 .184 .26 r
.33135 .74324 m .33352 .74123 L .3322 .74175 L F
.662 .61 .786 r
.43245 .75007 m .4359 .75241 L .43454 .74971 L F
.533 .586 .854 r
.43454 .74971 m .4359 .75241 L .43717 .75078 L F
.453 .472 .789 r
.4359 .75241 m .43777 .75246 L .43717 .75078 L F
.605 .535 .749 r
.43605 .75487 m .43777 .75246 L .4359 .75241 L F
.674 .544 .698 r
.51294 .87688 m .51466 .87486 L .51133 .87343 L F
.705 .359 .389 r
.49716 .8764 m .49828 .8746 L .49585 .8748 L F
.609 .07 0 r
.49932 .87592 m .49828 .8746 L .49716 .8764 L F
.287 .474 .868 r
.50179 .87728 m .49828 .8746 L .50164 .87759 L F
.445 .694 .972 r
.31891 .65606 m .31827 .65739 L .31697 .65621 L F
.31891 .65606 m .32038 .65741 L .31827 .65739 L F
.725 .599 .715 r
.59095 .80532 m .59299 .8091 L .59418 .8078 L F
.724 .571 .681 r
.59418 .8078 m .59502 .81201 L .59739 .81039 L F
.782 .757 .83 r
.68994 .72596 m .68694 .72568 L .6882 .72525 L F
.99 .852 .489 r
.60144 .8339 m .60186 .83156 L .6012 .83122 L F
.941 .963 .693 r
.6012 .83122 m .60186 .83156 L .60284 .82954 L F
.668 .566 .731 r
.3531 .67846 m .35138 .68086 L .35009 .67783 L F
.3531 .67846 m .3537 .68069 L .35138 .68086 L F
.51 .273 .492 r
.3537 .68069 m .35127 .68318 L .35138 .68086 L F
.451 .125 .322 r
.42675 .77379 m .42608 .77544 L .42401 .77573 L F
.52 .253 .45 r
.42863 .77322 m .42608 .77544 L .42675 .77379 L F
.543 .369 .596 r
.46024 .86618 m .4623 .86347 L .46013 .86377 L F
.956 .777 .619 r
.60284 .82954 m .60235 .82589 L .60169 .82893 L F
.941 .963 .693 r
.6012 .83122 m .60284 .82954 L .60169 .82893 L F
.628 .465 .642 r
.65035 .72097 m .65142 .71805 L .65019 .71983 L F
.555 .22 .355 r
.43389 .77046 m .43057 .77277 L .43163 .77077 L F
.034 0 0 r
.39206 .79229 m .39067 .79421 L .38957 .79418 L F
.1 0 0 r
.39251 .79331 m .39206 .79229 L .39401 .79183 L F
.39251 .79331 m .39067 .79421 L .39206 .79229 L F
.687 .66 .818 r
.63665 .6356 m .638 .63875 L .63426 .63796 L F
.725 .586 .699 r
.638 .63875 m .6355 .64106 L .63426 .63796 L F
.767 .698 .786 r
.63998 .63578 m .638 .63875 L .63665 .6356 L F
.752 .627 .722 r
.59502 .81201 m .59545 .81329 L .59739 .81039 L F
.156 0 .029 r
.52447 .83117 m .52589 .83085 L .52726 .82866 L F
.391 0 .069 r
.52589 .83085 m .52934 .82903 L .52726 .82866 L F
.995 .863 .539 r
.66037 .71786 m .66019 .71474 L .66244 .71505 L F
.66037 .71786 m .65974 .71723 L .66019 .71474 L F
.945 .654 .458 r
.66069 .72018 m .6594 .71987 L .66037 .71786 L F
.862 .784 .285 r
.65979 .72594 m .6596 .72555 L .66013 .7223 L F
.978 .753 .529 r
.65979 .72594 m .65846 .72748 L .6596 .72555 L F
.65979 .72594 m .65953 .72854 L .65846 .72748 L F
.306 .408 .802 r
.55171 .81653 m .55303 .81509 L .55058 .81578 L F
.55171 .81653 m .55412 .81803 L .55303 .81509 L F
.591 .534 .759 r
.44688 .74361 m .44506 .74477 L .44514 .74392 L F
.44688 .74361 m .44787 .74641 L .44506 .74477 L F
.442 .875 .799 r
.64749 .72239 m .64854 .7216 L .65035 .72097 L F
.765 .664 .75 r
.64644 .72454 m .64854 .7216 L .64749 .72239 L F
0 .328 .747 r
.41116 .72511 m .411 .72533 L .40928 .72483 L F
.41116 .72511 m .41239 .72598 L .411 .72533 L F
.424 .22 .496 r
.33069 .70902 m .32887 .71137 L .32917 .70967 L F
.437 .057 .218 r
.38862 .7814 m .39064 .7812 L .39198 .77918 L F
.458 .079 .231 r
.39198 .77918 m .39338 .78019 L .39391 .77875 L F
.39198 .77918 m .39064 .7812 L .39338 .78019 L F
.764 .568 .633 r
.64202 .64615 m .63876 .64594 L .63888 .6436 L F
.708 .333 .335 r
.64202 .64615 m .64106 .64795 L .63876 .64594 L F
.59 .187 .247 r
.64202 .64615 m .64316 .64802 L .64106 .64795 L F
.64202 .64615 m .64487 .64759 L .64316 .64802 L F
.585 .343 .517 r
.34178 .76815 m .3393 .77039 L .33988 .76867 L F
.4 .839 .942 r
.6883 .69398 m .68756 .6937 L .68508 .69424 L F
.6883 .69398 m .68756 .6937 L .68508 .69424 L F
.571 .925 .95 r
.68954 .69282 m .68756 .6937 L .6883 .69398 L F
.6883 .69398 m .68756 .6937 L .68954 .69282 L F
.68954 .69282 m .68756 .6937 L .6883 .69398 L F
.2 .334 .776 r
.50287 .86333 m .50244 .86382 L .50072 .86034 L F
.142 .027 .451 r
.50287 .86333 m .50197 .86653 L .50244 .86382 L F
.654 .743 .915 r
.51074 .84872 m .51228 .85026 L .51011 .84967 L F
.788 .564 .596 r
.51228 .85026 m .51212 .8531 L .51011 .84967 L F
.41 .824 .973 r
.51315 .84942 m .51228 .85026 L .51074 .84872 L F
.51315 .84942 m .51477 .84984 L .51228 .85026 L F
.518 .333 .569 r
.51437 .85249 m .51228 .85026 L .51477 .84984 L F
.51437 .85249 m .51212 .8531 L .51228 .85026 L F
.517 .253 .453 r
.35678 .75771 m .35839 .7594 L .35634 .7597 L F
.526 .253 .443 r
.35892 .75746 m .35839 .7594 L .35678 .75771 L F
.574 .491 .723 r
.46164 .85828 m .46398 .85802 L .46321 .85556 L F
.563 .424 .65 r
.46201 .86129 m .46398 .85802 L .46164 .85828 L F
.546 .382 .61 r
.52127 .85241 m .52335 .8516 L .52338 .84969 L F
.556 .669 .913 r
.52127 .85241 m .52418 .85343 L .52335 .8516 L F
.685 .647 .805 r
.55526 .81863 m .55665 .81518 L .55412 .81803 L F
.55526 .81863 m .55768 .8187 L .55665 .81518 L F
.415 .181 .449 r
.3355 .70153 m .33557 .70387 L .33311 .70404 L F
.411 .208 .491 r
.33557 .70387 m .33356 .70666 L .33311 .70404 L F
.982 .815 .601 r
.50148 .88479 m .50302 .88228 L .50218 .88486 L F
.629 .293 .383 r
.5047 .88373 m .50302 .88228 L .50148 .88479 L F
.507 .465 .745 r
.52418 .85343 m .5267 .8553 L .52641 .85286 L F
.534 .222 .385 r
.43649 .76869 m .43601 .77034 L .43389 .77046 L F
.539 .249 .422 r
.43945 .76741 m .43601 .77034 L .43649 .76869 L F
.434 .444 .77 r
.68554 .73189 m .68708 .7299 L .68507 .73012 L F
.68554 .73189 m .6885 .733 L .68708 .7299 L F
.746 .634 .735 r
.71859 .72845 m .71496 .72829 L .71424 .72552 L F
.644 .672 .861 r
.71928 .7258 m .71859 .72845 L .71598 .72479 L F
.546 .625 .882 r
.3376 .66452 m .33705 .6672 L .33559 .66448 L F
.3376 .66452 m .33898 .66689 L .33705 .6672 L F
.541 .361 .586 r
.64497 .62224 m .6475 .62205 L .64709 .61962 L F
.421 .109 .328 r
.67219 .63294 m .6721 .63406 L .66989 .63462 L F
0 0 .41 r
.67318 .62941 m .67321 .63173 L .67219 .63294 L F
0 0 .179 r
.67261 .6344 m .67219 .63294 L .67321 .63173 L F
.67261 .6344 m .6721 .63406 L .67219 .63294 L F
.725 .869 .949 r
.57527 .84562 m .57605 .84402 L .57445 .84454 L F
.57527 .84562 m .5768 .84465 L .57605 .84402 L F
.851 .744 .744 r
.66244 .71505 m .66019 .71474 L .66098 .71435 L F
.409 0 .126 r
.34522 .73822 m .34871 .73623 L .34661 .73642 L F
.618 .523 .724 r
.45798 .86653 m .45849 .86946 L .46096 .86901 L F
.452 .13 .327 r
.45823 .87086 m .46096 .86901 L .45849 .86946 L F
.502 .624 .904 r
.45284 .7492 m .45225 .75154 L .45065 .74956 L F
.45284 .7492 m .45432 .75155 L .45225 .75154 L F
.309 .712 .978 r
.4552 .75172 m .45225 .75154 L .45432 .75155 L F
.549 .323 .525 r
.66461 .63747 m .66196 .64062 L .6621 .63779 L F
.561 .313 .497 r
.6621 .63779 m .66196 .64062 L .65954 .64091 L F
.648 .559 .74 r
.49576 .85095 m .49635 .85321 L .49384 .85314 L F
.009 .249 .754 r
.49384 .85314 m .49467 .85252 L .49266 .85249 L F
.637 .381 .515 r
.49635 .85321 m .49588 .85522 L .49384 .85314 L F
.009 .249 .754 r
.49384 .85314 m .49588 .85522 L .49467 .85252 L F
.936 .747 .621 r
.58264 .7885 m .58414 .78679 L .58135 .78597 L F
.58264 .7885 m .58394 .7891 L .58414 .78679 L F
.541 .113 .177 r
.56452 .78382 m .56409 .78459 L .56128 .78426 L F
.323 .776 .954 r
.56697 .78375 m .56573 .78335 L .56452 .78382 L F
0 0 0 r
.56573 .78335 m .56409 .78459 L .56452 .78382 L F
.806 .563 .571 r
.57626 .79737 m .57387 .79929 L .57453 .79686 L F
.57626 .79737 m .57615 .79981 L .57387 .79929 L F
.688 .903 .551 r
.38756 .74798 m .38691 .74886 L .3867 .74945 L F
.286 .716 .968 r
.38655 .74988 m .3867 .74945 L .38457 .74943 L F
.458 0 .075 r
.3867 .74945 m .38557 .75067 L .38321 .75074 L F
.688 .903 .551 r
.38691 .74886 m .38557 .75067 L .3867 .74945 L F
.286 .716 .968 r
.38831 .75028 m .3867 .74945 L .38655 .74988 L F
.639 .877 .985 r
.38874 .74867 m .38831 .75028 L .39025 .74981 L F
.38874 .74867 m .3867 .74945 L .38831 .75028 L F
.595 .633 .859 r
.32703 .65961 m .32387 .65794 L .32601 .65789 L F
.563 .655 .898 r
.32793 .65755 m .32703 .65961 L .32601 .65789 L F
.489 .568 .862 r
.32793 .65755 m .32879 .65964 L .32703 .65961 L F
.918 .729 .632 r
.56079 .82564 m .56337 .82319 L .56074 .82344 L F
.792 .455 .418 r
.5617 .82343 m .56074 .82344 L .56337 .82319 L F
.918 .729 .632 r
.56079 .82564 m .56219 .82664 L .56337 .82319 L F
.814 .601 .614 r
.56337 .82319 m .56219 .82664 L .56514 .82651 L F
.751 .557 .633 r
.63888 .6436 m .63546 .64573 L .63543 .64341 L F
.63888 .6436 m .63876 .64594 L .63546 .64573 L F
.27 .773 .761 r
.50546 .88874 m .50955 .88771 L .50862 .88767 L F
.625 .958 .906 r
.50862 .88767 m .50955 .88771 L .51031 .88662 L F
.567 .8 .987 r
.52501 .83421 m .52829 .83468 L .52725 .83373 L F
0 .121 .644 r
.52829 .83468 m .5295 .83457 L .52725 .83373 L F
.572 .438 .659 r
.53078 .85855 m .53124 .85447 L .52822 .85781 L F
.53078 .85855 m .53288 .85575 L .53124 .85447 L F
.53078 .85855 m .53294 .85813 L .53288 .85575 L F
.717 .887 .497 r
.5257 .81799 m .52596 .81731 L .52703 .8159 L F
.634 .589 .786 r
.53015 .8166 m .52703 .8159 L .52901 .81621 L F
.404 0 .028 r
.52596 .81731 m .52901 .81621 L .52703 .8159 L F
.413 .86 .804 r
.5084 .88245 m .5047 .88373 L .50639 .88328 L F
.149 .346 .804 r
.50693 .87955 m .5084 .88245 L .50923 .88151 L F
.577 .936 .788 r
.50923 .88151 m .5084 .88245 L .50639 .88328 L F
.729 .379 .386 r
.5776 .78381 m .57965 .78597 L .58092 .78404 L F
.806 .479 .435 r
.58092 .78404 m .57965 .78597 L .58135 .78597 L F
.591 .339 .503 r
.44614 .76319 m .44595 .76535 L .44366 .76541 L F
.543 .299 .495 r
.44813 .76492 m .44614 .76319 L .44949 .7613 L F
.44813 .76492 m .44595 .76535 L .44614 .76319 L F
.957 .692 .247 r
.6667 .61068 m .66691 .61303 L .66746 .61325 L F
.508 .599 .879 r
.66847 .61076 m .66746 .61325 L .66691 .61303 L F
.66847 .61076 m .67024 .61328 L .66746 .61325 L F
.668 .636 .809 r
.55665 .81518 m .55768 .8187 L .55964 .81607 L F
.302 .797 .826 r
.36832 .75136 m .3662 .75192 L .36705 .75177 L F
.67 .679 .85 r
.67863 .71285 m .68098 .7123 L .67746 .71145 L F
.817 .704 .74 r
.67738 .71487 m .67863 .71285 L .67746 .71145 L F
.723 .884 .955 r
.7004 .70341 m .70118 .70459 L .70003 .70343 L F
0 0 0 r
.70165 .70388 m .70118 .70459 L .70277 .70332 L F
.723 .884 .955 r
.70277 .70332 m .70118 .70459 L .7004 .70341 L F
.981 .797 .583 r
.70165 .7053 m .70118 .70459 L .70165 .70388 L F
.70165 .7068 m .70118 .70459 L .70165 .7053 L F
.264 .678 .967 r
.70277 .70332 m .70374 .70406 L .70165 .70388 L F
.442 .782 .998 r
.49654 .82305 m .4956 .82403 L .49435 .82331 L F
.49654 .82305 m .49788 .82382 L .4956 .82403 L F
.49654 .82305 m .4956 .82403 L .49435 .82331 L F
.49654 .82305 m .49788 .82382 L .4956 .82403 L F
.834 .401 0 r
.49669 .86335 m .49717 .86527 L .49569 .86279 L F
.49669 .86335 m .49798 .86588 L .49717 .86527 L F
.387 .484 .837 r
.51634 .84265 m .51889 .84514 L .51866 .84231 L F
.56 .089 .093 r
.57551 .78338 m .5744 .78407 L .5776 .78381 L F
0 0 .175 r
.48075 .8631 m .48002 .86559 L .4786 .86378 L F
.548 .442 .686 r
.47819 .86123 m .4786 .86378 L .47662 .86434 L F
.958 .69 .246 r
.47818 .86336 m .4786 .86378 L .47819 .86123 L F
.718 .352 .356 r
.47879 .8633 m .47902 .86364 L .48075 .8631 L F
.857 .894 .862 r
.48075 .8631 m .47879 .86395 L .47902 .86364 L F
.44 .286 .575 r
.47879 .86395 m .47918 .86387 L .47902 .86364 L F
.605 .218 .283 r
.48075 .8631 m .4793 .86521 L .47879 .86395 L F
.718 .352 .356 r
.47845 .86382 m .4786 .86405 L .48075 .8631 L F
.47898 .86393 m .4793 .86521 L .48049 .86348 L F
.956 .774 .617 r
.4769 .8643 m .47777 .86562 L .47818 .86336 L F
.47619 .86483 m .47703 .86525 L .4769 .8643 L F
.47703 .86525 m .47777 .86562 L .4769 .8643 L F
.563 .557 .805 r
.47849 .8611 m .47819 .86123 L .47543 .86055 L F
.548 .442 .686 r
.47819 .86123 m .47662 .86434 L .47543 .86055 L F
.564 .556 .803 r
.47686 .8575 m .47849 .8611 L .47543 .86055 L F
.471 .505 .811 r
.47999 .86047 m .47849 .8611 L .47686 .8575 L F
.307 .787 .705 r
.47999 .86047 m .47819 .86123 L .47849 .8611 L F
.958 .69 .246 r
.47818 .86336 m .47819 .86123 L .47999 .86047 L F
.878 .822 .789 r
.47651 .86232 m .47999 .86047 L .47792 .85942 L F
.47651 .86232 m .47818 .86336 L .47999 .86047 L F
.945 .738 .593 r
.47651 .86232 m .47619 .86483 L .47818 .86336 L F
.354 .353 .72 r
.47774 .86099 m .47744 .86451 L .47669 .86274 L F
.47661 .86221 m .47669 .86274 L .47651 .86232 L F
.47774 .86099 m .47669 .86274 L .47661 .86221 L F
.438 .267 .55 r
.47846 .86409 m .47777 .86562 L .4793 .86521 L F
.47813 .86365 m .47803 .86418 L .47846 .86409 L F
.47803 .86418 m .47777 .86562 L .47846 .86409 L F
.761 .302 .161 r
.47846 .86409 m .4793 .86521 L .47744 .86451 L F
.47879 .86395 m .4793 .86521 L .47846 .86409 L F
.438 .267 .55 r
.47818 .86336 m .47813 .86365 L .47846 .86409 L F
.4786 .86406 m .47846 .86409 L .4793 .86521 L F
.47818 .86336 m .47846 .86409 L .4786 .86406 L F
.761 .302 .161 r
.47879 .86395 m .47846 .86409 L .47898 .86393 L F
.47846 .86409 m .47826 .86417 L .4786 .86406 L F
.47846 .86409 m .4786 .86406 L .47898 .86393 L F
.718 .352 .356 r
.47871 .86424 m .4793 .86521 L .47904 .86417 L F
.47871 .86424 m .47904 .86417 L .47898 .86393 L F
.4786 .86406 m .47871 .86424 L .47898 .86393 L F
0 0 .175 r
.48075 .8631 m .48025 .86589 L .48002 .86559 L F
.48075 .8631 m .48069 .86543 L .48025 .86589 L F
.652 .433 .574 r
.48337 .86521 m .48069 .86543 L .48075 .8631 L F
.761 .302 .161 r
.47932 .86391 m .47744 .86451 L .48089 .86378 L F
.47898 .86393 m .47871 .86403 L .47932 .86391 L F
.47871 .86403 m .47744 .86451 L .47932 .86391 L F
.47826 .86417 m .47744 .86451 L .47898 .86393 L F
.718 .352 .356 r
.4786 .86405 m .4786 .86406 L .47898 .86393 L F
.761 .302 .161 r
.47879 .86395 m .47898 .86393 L .47918 .86387 L F
.718 .352 .356 r
.4786 .86405 m .48049 .86348 L .48075 .8631 L F
.761 .302 .161 r
.47918 .86387 m .48089 .86378 L .48097 .86353 L F
.47898 .86393 m .48089 .86378 L .47918 .86387 L F
.857 .894 .862 r
.48075 .8631 m .47902 .86364 L .48168 .85997 L F
.48075 .8631 m .48168 .85997 L .48173 .8599 L F
.48075 .8631 m .48173 .8599 L .48345 .86315 L F
.652 .433 .574 r
.48337 .86521 m .48075 .8631 L .48345 .86315 L F
.44 .286 .575 r
.47902 .86364 m .48097 .86353 L .48173 .8599 L F
.47918 .86387 m .48097 .86353 L .47902 .86364 L F
.718 .352 .356 r
.47818 .86336 m .47845 .86382 L .47902 .86364 L F
.47818 .86336 m .47902 .86364 L .47879 .8633 L F
0 .021 .594 r
.48069 .86543 m .48189 .86837 L .48025 .86589 L F
.618 .523 .724 r
.45798 .86653 m .46096 .86901 L .46024 .86618 L F
.703 .708 .852 r
.7019 .73376 m .70527 .73571 L .70418 .73317 L F
.658 .722 .896 r
.70418 .73317 m .70527 .73571 L .7078 .7342 L F
.686 .643 .801 r
.70527 .73571 m .70846 .73607 L .7078 .7342 L F
.065 .409 .861 r
.53355 .82119 m .53723 .82378 L .53571 .82207 L F
.422 .615 .93 r
.53665 .82441 m .53791 .82303 L .53782 .82289 L F
.065 .409 .861 r
.53718 .82372 m .53774 .82414 L .53554 .82181 L F
.422 .615 .93 r
.53767 .82429 m .53871 .82417 L .53723 .82378 L F
.065 .409 .861 r
.53723 .82378 m .53774 .82414 L .53718 .82372 L F
.422 .615 .93 r
.53665 .82441 m .53767 .82429 L .53723 .82378 L F
.346 .495 .865 r
.53665 .82441 m .53774 .82414 L .53723 .82378 L F
.347 .506 .874 r
.53718 .82372 m .53774 .82414 L .53665 .82441 L F
.422 .615 .93 r
.53723 .82378 m .53871 .82417 L .53791 .82303 L F
.347 .506 .874 r
.53782 .82289 m .53774 .82414 L .53718 .82372 L F
.065 .409 .861 r
.53723 .82378 m .53554 .82181 L .53454 .82076 L F
.346 .495 .865 r
.53665 .82441 m .53723 .82378 L .53355 .82119 L F
.466 .617 .915 r
.53454 .82076 m .53774 .82414 L .53782 .82289 L F
.694 .327 .346 r
.53554 .82364 m .53759 .82514 L .53777 .82337 L F
.53729 .82306 m .53777 .82337 L .53782 .82289 L F
.53554 .82364 m .53777 .82337 L .53729 .82306 L F
.065 .409 .861 r
.534 .821 m .53571 .82207 L .53454 .82076 L F
.53355 .82119 m .53571 .82207 L .534 .821 L F
.839 .678 .684 r
.54504 .84815 m .54712 .85148 L .54568 .85108 L F
.849 .603 .566 r
.54568 .85108 m .54712 .85148 L .54461 .85237 L F
.853 .991 .843 r
.54712 .85148 m .54724 .85011 L .54461 .85237 L F
.54712 .85148 m .54807 .8503 L .54724 .85011 L F
.57 .614 .856 r
.48218 .87915 m .48011 .87965 L .47811 .87676 L F
.651 .321 .4 r
.56057 .78066 m .56222 .78095 L .56001 .77905 L F
.693 .29 .279 r
.56001 .77905 m .56222 .78095 L .56423 .78067 L F
.442 .22 .48 r
.32659 .71404 m .32493 .71729 L .32532 .71514 L F
.38 .373 .726 r
.59646 .83637 m .59807 .83982 L .59575 .83655 L F
.058 0 0 r
.59646 .83637 m .59575 .83655 L .59488 .83729 L F
.59646 .83637 m .59575 .83655 L .59488 .83729 L F
.601 .826 .986 r
.71164 .72537 m .70828 .72517 L .71097 .72319 L F
.597 .581 .806 r
.71219 .722 m .71164 .72537 L .71097 .72319 L F
.71219 .722 m .71424 .72552 L .71164 .72537 L F
.848 .802 .805 r
.7078 .7342 m .70846 .73607 L .71007 .73352 L F
.52 .911 .929 r
.36138 .79185 m .36212 .79101 L .3632 .79106 L F
.531 .92 .907 r
.36138 .79185 m .36024 .79188 L .36212 .79101 L F
.537 .201 .346 r
.66913 .63704 m .66699 .63583 L .66989 .63462 L F
.588 .311 .465 r
.6721 .63406 m .66913 .63704 L .66989 .63462 L F
.947 .838 .703 r
.5466 .84487 m .54404 .84765 L .5454 .84395 L F
.5466 .84487 m .54504 .84815 L .54404 .84765 L F
.402 0 .075 r
.37098 .7271 m .37302 .72694 L .3746 .72524 L F
.309 0 .011 r
.3746 .72524 m .37518 .72652 L .37675 .72545 L F
.3746 .72524 m .37302 .72694 L .37518 .72652 L F
.477 .323 .593 r
.46472 .84971 m .46704 .84717 L .46509 .84764 L F
.623 .574 .779 r
.43145 .74697 m .43245 .75007 L .43484 .74728 L F
.577 .506 .738 r
.43245 .75007 m .43454 .74971 L .43484 .74728 L F
.669 .912 .977 r
.63426 .63796 m .63153 .63805 L .63331 .6372 L F
.717 .582 .703 r
.63426 .63796 m .63227 .64082 L .63153 .63805 L F
.63426 .63796 m .6355 .64106 L .63227 .64082 L F
.921 .94 .798 r
.63426 .63796 m .63546 .63415 L .63665 .6356 L F
.63426 .63796 m .63331 .6372 L .63546 .63415 L F
.644 .48 .646 r
.67551 .71015 m .67673 .7097 L .67469 .71055 L F
.737 .796 .899 r
.34375 .79385 m .34305 .79642 L .3417 .79494 L F
.34375 .79385 m .34516 .79497 L .34305 .79642 L F
.781 .621 .682 r
.6355 .64106 m .63216 .64296 L .63227 .64082 L F
.6355 .64106 m .63543 .64341 L .63216 .64296 L F
.565 .39 .603 r
.66242 .61307 m .66691 .61303 L .66438 .6109 L F
.556 .332 .531 r
.66242 .61307 m .66389 .61591 L .66691 .61303 L F
.719 .355 .36 r
.5794 .81368 m .57853 .81547 L .57705 .81368 L F
.975 .68 .297 r
.66832 .71973 m .66911 .72042 L .66803 .71741 L F
.66832 .71973 m .66911 .72042 L .66803 .71741 L F
.618 .448 .629 r
.65039 .62223 m .64709 .61962 L .6475 .62205 L F
.923 .974 .752 r
.66694 .71439 m .66941 .71152 L .66795 .71511 L F
.509 .485 .766 r
.52093 .84201 m .52418 .84558 L .52559 .84182 L F
0 0 .411 r
.52559 .84182 m .52616 .84194 L .52617 .83957 L F
.551 .371 .591 r
.52418 .84558 m .52616 .84194 L .52559 .84182 L F
.657 .201 0 r
.54861 .83879 m .54877 .83901 L .54925 .83955 L F
.04 .227 .728 r
.54925 .83955 m .54987 .84179 L .55001 .84041 L F
.54925 .83955 m .55065 .84156 L .54987 .84179 L F
.657 .201 0 r
.54877 .83901 m .55065 .84156 L .54925 .83955 L F
.04 .227 .728 r
.54925 .83955 m .55001 .84041 L .55002 .84025 L F
.267 0 0 r
.38957 .79418 m .38888 .79503 L .38598 .79582 L F
.033 0 0 r
.39067 .79421 m .38888 .79503 L .38957 .79418 L F
.456 .254 .516 r
.46704 .84717 m .46904 .84474 L .4668 .8454 L F
.789 .311 .09 r
.42138 .72563 m .42184 .72701 L .42472 .7279 L F
.386 .799 .978 r
.42184 .72701 m .42701 .72739 L .42472 .7279 L F
0 0 0 r
.36665 .80461 m .3695 .80304 L .36779 .80443 L F
.36779 .80443 m .3695 .80304 L .37119 .80222 L F
.912 .729 .642 r
.69061 .73318 m .6882 .73547 L .6885 .733 L F
.69061 .73318 m .68983 .73642 L .6882 .73547 L F
.471 .708 .972 r
.32431 .65647 m .32387 .65794 L .32245 .65694 L F
.32431 .65647 m .32601 .65789 L .32387 .65794 L F
.743 .568 .657 r
.48199 .85005 m .48408 .85035 L .48401 .84744 L F
.662 .542 .708 r
.48408 .85035 m .48628 .8469 L .48401 .84744 L F
.259 0 .18 r
.53936 .83462 m .5367 .83695 L .53861 .83621 L F
.659 .46 .604 r
.53861 .83621 m .54124 .83406 L .53936 .83462 L F
.709 .679 .819 r
.45944 .87639 m .46079 .87796 L .46255 .87679 L F
.024 .31 .8 r
.5257 .81799 m .52692 .81904 L .52596 .81731 L F
.627 .436 .605 r
.42182 .76527 m .42414 .76525 L .42411 .76284 L F
.511 .345 .592 r
.42411 .76284 m .4261 .76481 L .42624 .76254 L F
.42411 .76284 m .42414 .76525 L .4261 .76481 L F
0 0 0 r
.51367 .87638 m .51466 .87486 L .51294 .87688 L F
0 .207 .731 r
.51294 .87688 m .51488 .87891 L .51367 .87638 L F
.507 .273 .495 r
.64096 .73163 m .64312 .7312 L .64356 .72878 L F
.561 .364 .57 r
.64312 .7312 m .64597 .72801 L .64356 .72878 L F
.461 .316 .597 r
.47422 .85304 m .47648 .85104 L .47533 .85067 L F
.47388 .85213 m .47533 .85067 L .47307 .84995 L F
.47422 .85304 m .47533 .85067 L .47388 .85213 L F
.663 .507 .662 r
.47648 .85104 m .47852 .85244 L .4784 .84991 L F
.47648 .85104 m .47599 .85356 L .47852 .85244 L F
.214 0 .345 r
.47712 .85129 m .47502 .85305 L .47549 .8505 L F
.47557 .85043 m .47549 .8505 L .47551 .8504 L F
.47712 .85129 m .47549 .8505 L .47557 .85043 L F
.461 .316 .597 r
.47422 .85304 m .47307 .84995 L .47502 .85305 L F
.742 .739 .849 r
.70709 .71584 m .7041 .71608 L .70626 .71516 L F
.721 .866 .95 r
.7094 .71493 m .70709 .71584 L .70626 .71516 L F
.353 .52 .883 r
.71023 .71786 m .70709 .71584 L .7094 .71493 L F
.413 .184 .454 r
.33711 .70035 m .33557 .70387 L .3355 .70153 L F
.584 .463 .68 r
.44671 .7413 m .44688 .74361 L .44514 .74392 L F
.736 .545 .635 r
.56174 .82839 m .56514 .82651 L .56219 .82664 L F
.56174 .82839 m .56482 .82891 L .56514 .82651 L F
.793 .349 .192 r
.51922 .87104 m .51664 .86857 L .51638 .87162 L F
.965 .636 .3 r
.67034 .72569 m .66979 .72715 L .66935 .72497 L F
.67034 .72569 m .67079 .72788 L .66979 .72715 L F
0 0 0 r
.39311 .74378 m .39228 .74386 L .39444 .74338 L F
.39311 .74378 m .39101 .74439 L .39228 .74386 L F
.45 .489 .808 r
.56175 .83741 m .56358 .84008 L .56323 .83641 L F
.664 .655 .831 r
.56323 .83641 m .56358 .84008 L .56626 .83679 L F
.617 .668 .876 r
.56358 .84008 m .56727 .83972 L .56626 .83679 L F
.56358 .84008 m .5652 .84022 L .56727 .83972 L F
.578 .61 .848 r
.33131 .66011 m .33025 .66259 L .32879 .65964 L F
.33131 .66011 m .33231 .66229 L .33025 .66259 L F
.79 .892 .477 r
.4904 .87333 m .49209 .87065 L .49085 .87139 L F
.4904 .87333 m .49018 .87444 L .49209 .87065 L F
.914 .979 .722 r
.49209 .87065 m .49272 .86827 L .49425 .87085 L F
.646 .161 .087 r
.49249 .87272 m .49209 .87065 L .49425 .87085 L F
.49249 .87272 m .49085 .87139 L .49209 .87065 L F
.7 .62 .764 r
.68234 .73083 m .68432 .72836 L .6814 .7281 L F
.665 .568 .736 r
.68234 .73083 m .68507 .73012 L .68432 .72836 L F
.82 .681 .71 r
.67919 .72988 m .68234 .73083 L .6814 .7281 L F
.277 .353 .761 r
.67919 .72988 m .67996 .73363 L .68234 .73083 L F
.51 .273 .492 r
.3537 .68069 m .35331 .68283 L .35127 .68318 L F
.534 .482 .744 r
.35558 .68014 m .3537 .68069 L .3531 .67846 L F
.453 .222 .473 r
.35517 .68225 m .3537 .68069 L .35558 .68014 L F
.35517 .68225 m .35331 .68283 L .3537 .68069 L F
.41 .861 .845 r
.34651 .81258 m .34585 .81244 L .3453 .81264 L F
.34651 .81258 m .34704 .81204 L .34581 .81243 L F
.281 0 .115 r
.34509 .81272 m .34692 .81208 L .34607 .81253 L F
.34692 .81208 m .34704 .81204 L .34703 .81205 L F
.34692 .81208 m .34703 .81205 L .34607 .81253 L F
.41 .861 .845 r
.34585 .81244 m .34581 .81243 L .34549 .81256 L F
.34585 .81244 m .34549 .81256 L .3453 .81264 L F
.34651 .81258 m .3478 .81198 L .34704 .81204 L F
.613 .637 .851 r
.63126 .63823 m .63227 .64082 L .62893 .64031 L F
.63126 .63823 m .63153 .63805 L .63227 .64082 L F
.795 .552 .569 r
.62893 .64031 m .63227 .64082 L .63216 .64296 L F
.531 .289 .493 r
.34513 .76472 m .34407 .76795 L .34178 .76815 L F
.509 .267 .483 r
.34576 .76745 m .34513 .76472 L .34681 .76494 L F
.34576 .76745 m .34407 .76795 L .34513 .76472 L F
.259 .02 .349 r
.54175 .83212 m .54124 .83406 L .54299 .83176 L F
.599 .675 .893 r
.6626 .7294 m .66392 .72723 L .66167 .72776 L F
.6626 .7294 m .66496 .72921 L .66392 .72723 L F
.586 .498 .722 r
.68522 .72028 m .68571 .72262 L .68343 .723 L F
.778 .428 .394 r
.53275 .8495 m .5358 .84998 L .53401 .84756 L F
.645 .238 .259 r
.42165 .74186 m .42011 .74338 L .41812 .74273 L F
0 .394 .707 r
.41812 .74273 m .42011 .74338 L .41838 .74279 L F
.41812 .74273 m .41838 .74279 L .41684 .74227 L F
.011 0 0 r
.41771 .74263 m .41812 .74273 L .4159 .74318 L F
.41954 .74208 m .41812 .74273 L .41771 .74263 L F
.645 .238 .259 r
.42165 .74186 m .41812 .74273 L .41954 .74208 L F
.654 .286 .334 r
.56128 .78426 m .5605 .78601 L .55817 .78567 L F
.45 .079 .241 r
.5631 .78547 m .56128 .78426 L .56409 .78459 L F
.5631 .78547 m .5605 .78601 L .56128 .78426 L F
.544 .3 .497 r
.39391 .77875 m .39607 .77853 L .3961 .77616 L F
.458 .165 .38 r
.39607 .77853 m .39884 .77571 L .3961 .77616 L F
.548 .348 .562 r
.45122 .76003 m .45115 .76143 L .44949 .7613 L F
.514 .261 .469 r
.45015 .76455 m .44949 .7613 L .45115 .76143 L F
.45015 .76455 m .44813 .76492 L .44949 .7613 L F
.534 .523 .79 r
.68696 .74563 m .68583 .75036 L .68491 .74641 L F
.68696 .74563 m .68756 .74983 L .68583 .75036 L F
.215 .729 .69 r
.68583 .75036 m .68756 .74983 L .68906 .74939 L F
.773 .757 .838 r
.68275 .74877 m .68583 .75036 L .68372 .75082 L F
.68275 .74877 m .68491 .74641 L .68583 .75036 L F
.638 .747 .927 r
.43656 .73169 m .43331 .73098 L .43542 .73064 L F
.35 .52 .884 r
.43737 .73033 m .43656 .73169 L .43542 .73064 L F
.43737 .73033 m .43878 .73254 L .43656 .73169 L F
.443 .474 .797 r
.56074 .83437 m .56175 .83741 L .56323 .83641 L F
.758 .245 0 r
.48892 .86144 m .48863 .86207 L .48765 .8609 L F
.48892 .86144 m .48933 .86205 L .48863 .86207 L F
.428 .247 .531 r
.32578 .69123 m .32726 .693 L .32757 .69071 L F
.32578 .69123 m .32567 .6936 L .32726 .693 L F
.967 .659 .382 r
.65357 .62943 m .65385 .63153 L .65485 .63041 L F
.252 0 .03 r
.65616 .63125 m .65485 .63041 L .65385 .63153 L F
.65616 .63125 m .65706 .62971 L .65485 .63041 L F
.814 .694 .732 r
.48513 .88216 m .48648 .88502 L .48373 .88403 L F
.777 .312 .14 r
.48373 .88403 m .48648 .88502 L .48499 .88503 L F
.647 .111 0 r
.4889 .88658 m .48499 .88503 L .48648 .88502 L F
.782 .6 .654 r
.50681 .84835 m .50897 .84771 L .50572 .84762 L F
.50681 .84835 m .50875 .85003 L .50897 .84771 L F
.50897 .84771 m .50875 .85003 L .50681 .84835 L F
.548 .393 .622 r
.50897 .84771 m .50875 .85003 L .51074 .84872 L F
.654 .743 .915 r
.51074 .84872 m .50875 .85003 L .50897 .84771 L F
.811 .667 .704 r
.59807 .83982 m .60123 .83983 L .60039 .83671 L F
.949 .728 .569 r
.56148 .79731 m .56047 .79764 L .56035 .79426 L F
.682 .199 .096 r
.56148 .79731 m .55985 .79809 L .56047 .79764 L F
.211 .158 .576 r
.56252 .79383 m .56148 .79731 L .56035 .79426 L F
.56252 .79383 m .56309 .7969 L .56148 .79731 L F
.186 0 0 r
.56309 .7969 m .55985 .79809 L .56148 .79731 L F
.429 .239 .519 r
.34879 .68797 m .3471 .68863 L .34905 .68576 L F
.453 .191 .425 r
.34843 .68991 m .3471 .68863 L .34879 .68797 L F
.34843 .68991 m .34661 .69043 L .3471 .68863 L F
.342 0 .137 r
.55665 .81518 m .55949 .81319 L .55621 .81303 L F
.55665 .81518 m .55839 .81511 L .55949 .81319 L F
.94 .734 .261 r
.56073 .81243 m .56104 .81433 L .55949 .81319 L F
.526 .355 .592 r
.56104 .81433 m .55964 .81607 L .55949 .81319 L F
0 0 0 r
.55949 .81319 m .55839 .81511 L .56073 .81243 L F
.084 0 .234 r
.53656 .83313 m .53574 .83155 L .53786 .83104 L F
.53656 .83313 m .53538 .83382 L .53574 .83155 L F
0 0 .502 r
.67332 .73614 m .67373 .73538 L .67312 .73332 L F
0 .188 .719 r
.67332 .73614 m .67501 .73799 L .67373 .73538 L F
0 .525 .785 r
.41627 .7276 m .4179 .72786 L .41918 .72823 L F
.41627 .7276 m .4179 .72786 L .41918 .72823 L F
.126 0 .193 r
.42138 .72563 m .41918 .72823 L .42083 .72701 L F
.355 0 0 r
.4179 .72786 m .42083 .72701 L .41918 .72823 L F
.371 .204 .521 r
.55582 .7862 m .55521 .78848 L .55363 .7863 L F
.251 .146 .534 r
.52338 .84969 m .52335 .8516 L .52382 .84944 L F
.939 .723 .584 r
.54917 .8339 m .55075 .83182 L .54915 .83134 L F
.54917 .8339 m .55039 .83465 L .55075 .83182 L F
.913 .633 .139 r
.5603 .83175 m .56074 .83437 L .55989 .83102 L F
.817 .704 .74 r
.67738 .71487 m .67746 .71145 L .67622 .71451 L F
.818 .47 .398 r
.67634 .71668 m .67738 .71487 L .67622 .71451 L F
.67634 .71668 m .67908 .71703 L .67738 .71487 L F
.79 .684 .747 r
.56558 .781 m .56697 .78375 L .5686 .7815 L F
.501 .294 .531 r
.56697 .78375 m .5689 .7836 L .5686 .7815 L F
.467 .243 .49 r
.344 .69475 m .3426 .69372 L .34439 .6932 L F
.344 .69475 m .34225 .69563 L .3426 .69372 L F
.731 .872 .947 r
.69678 .74947 m .69732 .75046 L .6999 .7492 L F
.664 .666 .842 r
.70175 .71771 m .69799 .71564 L .70212 .71733 L F
.005 0 0 r
.70175 .71771 m .70339 .71722 L .7041 .71608 L F
.321 .781 .945 r
.70212 .71733 m .70339 .71722 L .70175 .71771 L F
.555 .378 .596 r
.70401 .71966 m .70178 .72012 L .70175 .71771 L F
.321 .781 .945 r
.70212 .71733 m .70339 .71722 L .70175 .71771 L F
.577 .184 .26 r
.33135 .74324 m .33207 .74331 L .33352 .74123 L F
.636 .806 .965 r
.33566 .74044 m .33352 .74123 L .3366 .74047 L F
.165 .474 .894 r
.50296 .88703 m .50376 .88827 L .50546 .88874 L F
.811 .626 .653 r
.58629 .79975 m .58485 .80262 L .58771 .80278 L F
.854 .887 .861 r
.58407 .80491 m .58771 .80278 L .58485 .80262 L F
.923 .974 .752 r
.66694 .71439 m .66882 .71142 L .66941 .71152 L F
.79 .822 .878 r
.59063 .84306 m .59355 .84278 L .59241 .84218 L F
.363 .83 .896 r
.59355 .84278 m .59492 .84214 L .59241 .84218 L F
.59355 .84278 m .59583 .84225 L .59492 .84214 L F
0 0 0 r
.36665 .80461 m .36779 .80443 L .36597 .80524 L F
.839 .887 .875 r
.54014 .8288 m .53786 .83104 L .53893 .83083 L F
.199 0 .118 r
.40083 .77529 m .40346 .77307 L .4015 .77348 L F
.579 .444 .662 r
.44837 .73625 m .4486 .73863 L .44649 .73901 L F
.584 .45 .664 r
.4488 .74086 m .44649 .73901 L .4486 .73863 L F
.4488 .74086 m .44671 .7413 L .44649 .73901 L F
.53 .255 .443 r
.33723 .77034 m .33838 .7705 L .33714 .77068 L F
.513 .149 .286 r
.3393 .77039 m .33838 .7705 L .33723 .77034 L F
.12 .412 .86 r
.47701 .88124 m .47774 .88256 L .47827 .88185 L F
.669 .224 .185 r
.51678 .87637 m .51466 .87486 L .51367 .87638 L F
.017 0 0 r
.3979 .79069 m .39933 .78926 L .4012 .78847 L F
.754 .418 .416 r
.48373 .88403 m .47935 .88248 L .48175 .8836 L F
.848 .802 .805 r
.7078 .7342 m .71007 .73352 L .70966 .73311 L F
.585 .401 .599 r
.7128 .7309 m .71284 .73323 L .71007 .73352 L F
.543 .911 .954 r
.71214 .73222 m .70966 .73311 L .71007 .73352 L F
.535 .775 .986 r
.71007 .73352 m .71284 .73323 L .71214 .73222 L F
.641 .401 .539 r
.45574 .75761 m .45559 .7599 L .4533 .75983 L F
.61 .457 .65 r
.45806 .75404 m .45871 .75763 L .45574 .75761 L F
.621 .384 .537 r
.45895 .7587 m .45574 .75761 L .45871 .75763 L F
.45895 .7587 m .45559 .7599 L .45574 .75761 L F
.747 .529 .599 r
.63543 .64341 m .63196 .64551 L .63216 .64296 L F
.63543 .64341 m .63546 .64573 L .63196 .64551 L F
.826 .374 .155 r
.48322 .87077 m .48499 .87129 L .48314 .86888 L F
.774 .414 .375 r
.48314 .86888 m .48499 .87129 L .48674 .87069 L F
.277 .353 .761 r
.67919 .72988 m .68144 .7325 L .67996 .73363 L F
.238 .187 .596 r
.68144 .7325 m .68019 .73587 L .67996 .73363 L F
.605 .535 .749 r
.43605 .75487 m .43828 .75455 L .43777 .75246 L F
.579 .368 .559 r
.43588 .75708 m .43828 .75455 L .43605 .75487 L F
.606 .69 .902 r
.35009 .67783 m .34719 .67668 L .34887 .67669 L F
.481 .056 .155 r
.34887 .67669 m .35247 .67515 L .35009 .67783 L F
.699 .597 .739 r
.35247 .67515 m .3531 .67846 L .35009 .67783 L F
.566 .706 .935 r
.66522 .60875 m .66438 .6109 L .66322 .61052 L F
.66522 .60875 m .6667 .61068 L .66438 .6109 L F
.732 .246 .088 r
.66438 .6109 m .66522 .61284 L .66322 .61052 L F
.697 .961 .714 r
.66691 .61303 m .66507 .6139 L .66522 .61284 L F
0 0 0 r
.66516 .61369 m .66522 .61284 L .66507 .6139 L F
.732 .246 .088 r
.6653 .61167 m .66691 .61303 L .66522 .61284 L F
0 0 0 r
.66631 .61101 m .66522 .61284 L .66516 .61369 L F
.732 .246 .088 r
.66438 .6109 m .6653 .61167 L .66522 .61284 L F
.847 .693 .691 r
.69949 .73817 m .70112 .73908 L .69997 .73605 L F
.873 .721 .69 r
.69949 .73817 m .70064 .74104 L .70112 .73908 L F
.534 .482 .744 r
.35558 .68014 m .3531 .67846 L .35468 .67833 L F
.492 .211 .414 r
.65717 .64071 m .65688 .64256 L .65458 .64304 L F
.421 .037 .203 r
.65954 .64091 m .65688 .64256 L .65717 .64071 L F
.673 .243 .218 r
.48499 .87129 m .48877 .87168 L .48674 .87069 L F
.426 .158 .402 r
.34225 .69563 m .33975 .6978 L .34035 .6961 L F
.873 .721 .69 r
.69949 .73817 m .69815 .74096 L .70064 .74104 L F
.938 .851 .73 r
.69797 .74331 m .70064 .74104 L .69815 .74096 L F
.69797 .74331 m .69912 .74398 L .70064 .74104 L F
.554 .173 .274 r
.66695 .63722 m .66699 .63583 L .66913 .63704 L F
.185 .671 .926 r
.44208 .7335 m .44408 .73364 L .44511 .7341 L F
.259 .669 .966 r
.44628 .73361 m .44511 .7341 L .44408 .73364 L F
.44628 .73361 m .4474 .73438 L .44511 .7341 L F
.539 .249 .422 r
.43945 .76741 m .43817 .77019 L .43601 .77034 L F
.524 .229 .409 r
.44105 .76717 m .43817 .77019 L .43945 .76741 L F
.391 0 .155 r
.42401 .77573 m .42289 .77773 L .4207 .77823 L F
.566 .222 .346 r
.42608 .77544 m .42289 .77773 L .42401 .77573 L F
.767 .698 .786 r
.63998 .63578 m .63665 .6356 L .63929 .63404 L F
.55 .501 .753 r
.32588 .6808 m .32699 .67739 L .32505 .67774 L F
.32588 .6808 m .3278 .6805 L .32699 .67739 L F
.559 .46 .699 r
.32625 .68306 m .3278 .6805 L .32588 .6808 L F
.764 .369 .306 r
.51265 .88132 m .51347 .88023 L .50931 .87923 L F
.991 .755 .478 r
.57562 .8132 m .57451 .81476 L .5747 .81251 L F
.57562 .8132 m .57549 .81604 L .57451 .81476 L F
.643 .433 .584 r
.57705 .81368 m .57549 .81604 L .57562 .8132 L F
.477 .323 .593 r
.46472 .84971 m .46701 .84984 L .46704 .84717 L F
.498 .303 .547 r
.46472 .84971 m .46712 .85177 L .46701 .84984 L F
.46472 .84971 m .46503 .85247 L .46712 .85177 L F
.839 .564 .522 r
.54482 .82315 m .54771 .82607 L .54795 .82566 L F
.445 .1 .285 r
.35084 .73598 m .35294 .73563 L .354 .73337 L F
.39 .046 .257 r
.354 .73337 m .3549 .73515 L .35607 .7331 L F
.354 .73337 m .35294 .73563 L .3549 .73515 L F
.864 .656 .62 r
.64461 .60581 m .64699 .60627 L .6468 .60842 L F
.864 .653 .616 r
.64612 .60695 m .64699 .60627 L .64461 .60581 L F
.735 .71 .828 r
.64802 .60273 m .64699 .60627 L .64612 .60695 L F
.64802 .60273 m .64948 .60428 L .64699 .60627 L F
.67 .134 0 r
.50028 .88749 m .49803 .88653 L .50048 .88739 L F
0 0 0 r
.49857 .8898 m .50028 .88749 L .50048 .88739 L F
.222 .689 .944 r
.50119 .85982 m .50072 .86034 L .49917 .85971 L F
.50119 .85982 m .5026 .86038 L .50072 .86034 L F
.2 .334 .776 r
.50287 .86333 m .50072 .86034 L .5026 .86038 L F
.388 .006 .187 r
.41161 .78196 m .41101 .78307 L .40891 .7834 L F
.431 .051 .217 r
.41358 .78169 m .41101 .78307 L .41161 .78196 L F
0 .358 .828 r
.4889 .88658 m .48976 .88781 L .4921 .88918 L F
.017 .193 .703 r
.42725 .74112 m .42832 .74406 L .42902 .74309 L F
.178 .43 .863 r
.42832 .74406 m .43054 .74544 L .42902 .74309 L F
.564 .556 .803 r
.47686 .8575 m .47543 .86055 L .47489 .85899 L F
.582 .791 .978 r
.67901 .72829 m .67962 .72692 L .67878 .72782 L F
.67901 .72829 m .6814 .7281 L .67962 .72692 L F
.888 .538 .379 r
.67804 .72989 m .67901 .72829 L .67878 .72782 L F
.67804 .72989 m .67919 .72988 L .67901 .72829 L F
.82 .681 .71 r
.67919 .72988 m .6814 .7281 L .67901 .72829 L F
.184 0 0 r
.42083 .72701 m .42184 .72701 L .42138 .72563 L F
.768 .565 .623 r
.49531 .84239 m .49709 .84474 L .49752 .84256 L F
.721 .866 .95 r
.7094 .71493 m .70626 .71516 L .70836 .71401 L F
.401 .724 .989 r
.71058 .71399 m .7094 .71493 L .70836 .71401 L F
.173 .306 .759 r
.71058 .71399 m .71172 .71707 L .7094 .71493 L F
.413 .348 .676 r
.71172 .71707 m .71023 .71786 L .7094 .71493 L F
.741 .809 .906 r
.37382 .75133 m .3769 .75117 L .37597 .75065 L F
.053 0 0 r
.37916 .75025 m .37597 .75065 L .3769 .75117 L F
.655 .882 .981 r
.64647 .73099 m .64541 .73032 L .64312 .7312 L F
.977 .813 .613 r
.64597 .72801 m .64541 .73032 L .64647 .73099 L F
.836 .634 .63 r
.58341 .79702 m .58331 .79944 L .58629 .79975 L F
.83 .651 .661 r
.58307 .80183 m .58629 .79975 L .58331 .79944 L F
.58307 .80183 m .58485 .80262 L .58629 .79975 L F
.423 .239 .525 r
.34618 .69249 m .34466 .69112 L .34661 .69043 L F
.34618 .69249 m .34439 .6932 L .34466 .69112 L F
.496 .305 .551 r
.703 .72543 m .70095 .72793 L .70065 .72576 L F
.529 .304 .517 r
.41875 .77939 m .41603 .77887 L .41904 .77916 L F
.41875 .77939 m .41643 .7802 L .41603 .77887 L F
.395 .018 .2 r
.4186 .76765 m .42061 .76728 L .42182 .76527 L F
.623 .259 .333 r
.42182 .76527 m .42356 .76675 L .42414 .76525 L F
.42182 .76527 m .42061 .76728 L .42356 .76675 L F
.613 .686 .895 r
.58271 .8436 m .58382 .84187 L .58207 .84356 L F
.58271 .8436 m .58345 .84359 L .58382 .84187 L F
.767 .607 .681 r
.58591 .81012 m .58867 .81269 L .58796 .81083 L F
.639 .521 .703 r
.65701 .72732 m .65953 .72854 L .65846 .72748 L F
.65701 .72732 m .65701 .7301 L .65953 .72854 L F
.724 .2 0 r
.48148 .87332 m .48396 .87457 L .48274 .8744 L F
.553 .017 0 r
.48396 .87457 m .48578 .87638 L .48274 .8744 L F
.48396 .87457 m .48617 .87658 L .48578 .87638 L F
.393 .15 .422 r
.33975 .6978 m .33711 .70035 L .33795 .69861 L F
.868 .802 .783 r
.52322 .86829 m .52491 .86994 L .52494 .86906 L F
.52322 .86829 m .52491 .86994 L .52494 .86906 L F
.422 0 0 r
.51512 .88227 m .5142 .88161 L .51265 .88132 L F
.51512 .88227 m .51639 .88259 L .5142 .88161 L F
.691 .312 .324 r
.49714 .84708 m .49375 .84712 L .49481 .84592 L F
.869 .865 .832 r
.68906 .74939 m .68756 .74983 L .69028 .74601 L F
.864 .711 .691 r
.57158 .78973 m .57123 .79207 L .57004 .78892 L F
.968 .691 .456 r
.56558 .781 m .56573 .78335 L .56697 .78375 L F
.212 .696 .93 r
.39775 .74392 m .39639 .74342 L .39444 .74338 L F
.344 .724 .985 r
.39775 .74392 m .39843 .74312 L .39639 .74342 L F
.39775 .74392 m .39972 .74392 L .39843 .74312 L F
.494 .484 .775 r
.33994 .67011 m .34246 .67172 L .34076 .67208 L F
.488 .531 .827 r
.34363 .67446 m .34076 .67208 L .34246 .67172 L F
.246 0 0 r
.33818 .74065 m .34003 .7403 L .34131 .73916 L F
0 0 0 r
.34131 .73916 m .34187 .73934 L .34351 .73894 L F
.34131 .73916 m .34003 .7403 L .3416 .73948 L F
.879 .93 .852 r
.33818 .74065 m .33968 .73805 L .34003 .7403 L F
.33818 .74065 m .33749 .74059 L .33968 .73805 L F
.573 .342 .526 r
.33983 .73902 m .34142 .73957 L .34003 .7403 L F
.33968 .73805 m .34082 .73905 L .33983 .73902 L F
.34082 .73905 m .34142 .73957 L .33983 .73902 L F
.435 .126 .342 r
.34082 .73905 m .34095 .73905 L .34105 .73894 L F
.576 .4 .606 r
.33968 .73805 m .34082 .73905 L .34105 .73894 L F
.662 .332 .403 r
.34105 .73894 m .34115 .73914 L .33968 .73805 L F
0 0 0 r
.34181 .73932 m .3416 .73948 L .34187 .73934 L F
.34131 .73916 m .3416 .73948 L .34181 .73932 L F
.573 .342 .526 r
.33968 .73805 m .3416 .73948 L .34142 .73957 L F
.504 .201 .386 r
.33844 .74188 m .34158 .73998 L .34115 .73914 L F
.34095 .73905 m .34115 .73914 L .34105 .73894 L F
.33844 .74188 m .34115 .73914 L .34095 .73905 L F
.573 .342 .526 r
.33968 .73805 m .34187 .73934 L .34173 .73941 L F
.34115 .73914 m .34173 .73941 L .3416 .73948 L F
.33968 .73805 m .34173 .73941 L .34115 .73914 L F
.435 .126 .342 r
.33749 .74059 m .33812 .74144 L .34095 .73905 L F
.33812 .74144 m .3401 .74 L .34095 .73905 L F
.33749 .74059 m .34095 .73905 L .34082 .73905 L F
.662 .332 .403 r
.34115 .73914 m .3414 .73963 L .33968 .73805 L F
.573 .342 .526 r
.3414 .73906 m .34158 .73998 L .34187 .73934 L F
.576 .4 .606 r
.33968 .73805 m .33749 .74059 L .34082 .73905 L F
.662 .332 .403 r
.3414 .73963 m .34131 .73971 L .33968 .73805 L F
.573 .342 .526 r
.33968 .73805 m .34098 .73937 L .3414 .73906 L F
.662 .332 .403 r
.3414 .73963 m .34158 .73998 L .34131 .73971 L F
.573 .342 .526 r
.34098 .73937 m .34158 .73998 L .3414 .73906 L F
.435 .126 .342 r
.33812 .74144 m .33844 .74188 L .3401 .74 L F
.508 .297 .528 r
.35101 .68532 m .34905 .68576 L .35127 .68318 L F
.431 .231 .506 r
.35294 .68466 m .35127 .68318 L .35331 .68283 L F
.35294 .68466 m .35101 .68532 L .35127 .68318 L F
.744 .559 .643 r
.71406 .71841 m .71246 .71999 L .71479 .71678 L F
.71406 .71841 m .71587 .72025 L .71246 .71999 L F
.587 .53 .758 r
.71753 .71645 m .71406 .71841 L .71479 .71678 L F
.561 .51 .755 r
.71753 .71645 m .71587 .72025 L .71406 .71841 L F
.691 .822 .945 r
.35065 .79411 m .34713 .79404 L .34924 .79302 L F
.477 .758 .992 r
.3511 .79293 m .35065 .79411 L .34924 .79302 L F
.3511 .79293 m .35253 .79386 L .35065 .79411 L F
.625 .625 .83 r
.4595 .75212 m .45806 .75404 L .45732 .75235 L F
.4595 .75212 m .46062 .75429 L .45806 .75404 L F
.599 .45 .651 r
.46066 .757 m .45806 .75404 L .46062 .75429 L F
.46066 .757 m .45871 .75763 L .45806 .75404 L F
.749 .98 .735 r
.64889 .62762 m .6464 .63008 L .64791 .62815 L F
.618 .519 .72 r
.64889 .62762 m .65045 .62447 L .65075 .62717 L F
.64889 .62762 m .65045 .62447 L .65075 .62717 L F
.978 .774 .561 r
.58227 .79051 m .58394 .7891 L .58264 .7885 L F
.58227 .79051 m .58369 .79115 L .58394 .7891 L F
.564 .244 .385 r
.35201 .76263 m .35127 .76498 L .34888 .7649 L F
.214 0 .241 r
.35283 .76405 m .35201 .76263 L .35373 .76187 L F
.35283 .76405 m .35127 .76498 L .35201 .76263 L F
.763 .655 .744 r
.71756 .73216 m .71284 .73323 L .7128 .7309 L F
.71756 .73216 m .71611 .7338 L .71284 .73323 L F
.562 .359 .563 r
.71916 .73196 m .71611 .7338 L .71756 .73216 L F
.563 .343 .539 r
.48039 .83161 m .48226 .83366 L .48311 .83074 L F
.442 .249 .523 r
.35058 .68736 m .34905 .68576 L .35101 .68532 L F
.35058 .68736 m .34879 .68797 L .34905 .68576 L F
.611 .576 .791 r
.65266 .62402 m .65174 .62792 L .65075 .62717 L F
.65266 .62402 m .65453 .62743 L .65174 .62792 L F
.65 .837 .972 r
.39217 .74903 m .39362 .74995 L .3955 .74915 L F
.39217 .74903 m .39362 .74995 L .3955 .74915 L F
.806 .465 .412 r
.53794 .8179 m .5415 .82064 L .54083 .81863 L F
.22 .62 .953 r
.67153 .6295 m .66734 .62787 L .6697 .62792 L F
.432 .492 .821 r
.67247 .62668 m .67153 .6295 L .6697 .62792 L F
.67247 .62668 m .67318 .62941 L .67153 .6295 L F
.021 0 0 r
.42479 .74168 m .42392 .74178 L .42165 .74186 L F
.279 .781 .786 r
.42552 .74134 m .42479 .74168 L .42725 .74112 L F
.42552 .74134 m .42392 .74178 L .42479 .74168 L F
.097 0 0 r
.38405 .72421 m .38611 .72398 L .3876 .7234 L F
.592 .537 .762 r
.47432 .87069 m .47282 .87473 L .47281 .87154 L F
.47432 .87069 m .47531 .8744 L .47282 .87473 L F
.38 .823 .688 r
.37316 .80173 m .37677 .79995 L .37511 .80131 L F
0 0 0 r
.37511 .80131 m .37677 .79995 L .37865 .79915 L F
.297 0 .242 r
.3662 .75192 m .36526 .75413 L .36358 .75437 L F
.507 .178 .345 r
.36745 .75361 m .3662 .75192 L .36832 .75136 L F
.36745 .75361 m .36526 .75413 L .3662 .75192 L F
.582 .168 .223 r
.51639 .88259 m .51912 .88163 L .5172 .88322 L F
.269 0 0 r
.51912 .88163 m .52066 .88212 L .5172 .88322 L F
.51912 .88163 m .52129 .88194 L .52066 .88212 L F
.654 .743 .915 r
.51074 .84872 m .51011 .84967 L .50875 .85003 L F
.767 .559 .617 r
.51011 .84967 m .50887 .85283 L .50875 .85003 L F
.51011 .84967 m .51212 .8531 L .50887 .85283 L F
.686 .591 .743 r
.51889 .84514 m .52093 .84201 L .51866 .84231 L F
.838 .552 .504 r
.54939 .80824 m .55051 .81118 L .55218 .81017 L F
.844 .622 .601 r
.55051 .81118 m .55279 .81296 L .55218 .81017 L F
.991 .75 .378 r
.7128 .7309 m .71284 .73323 L .71214 .73222 L F
.494 .572 .863 r
.57267 .82378 m .576 .82641 L .57457 .82392 L F
.797 .688 .744 r
.576 .82641 m .57278 .82647 L .57457 .82392 L F
.576 .82641 m .57434 .82908 L .57278 .82647 L F
.249 .727 .935 r
.68705 .75375 m .68886 .75401 L .68876 .75375 L F
.483 .89 .935 r
.68876 .75375 m .68886 .75401 L .69286 .75292 L F
.442 .22 .48 r
.32659 .71404 m .32685 .71703 L .32493 .71729 L F
.431 .21 .476 r
.32887 .71137 m .32904 .71425 L .32659 .71404 L F
.414 .191 .464 r
.32904 .71425 m .32685 .71703 L .32659 .71404 L F
.875 .672 .624 r
.60169 .82893 m .60235 .82589 L .60001 .82585 L F
.99 .852 .489 r
.60144 .8339 m .6012 .83122 L .60036 .83339 L F
.67 .971 .8 r
.57457 .82392 m .57486 .82346 L .57267 .82378 L F
.345 .751 .982 r
.31358 .65588 m .315 .65655 L .31307 .6559 L F
.467 .811 .999 r
.31358 .65588 m .31697 .65621 L .315 .65655 L F
.31358 .65588 m .31697 .65621 L .315 .65655 L F
.788 .539 .561 r
.5415 .82064 m .54482 .82315 L .54426 .82187 L F
.615 .434 .614 r
.52641 .85286 m .52894 .85267 L .52879 .85032 L F
.49 .337 .601 r
.52894 .85267 m .53069 .84991 L .52879 .85032 L F
.513 .472 .748 r
.49803 .85255 m .49635 .85321 L .49576 .85095 L F
.622 .46 .642 r
.49803 .85255 m .49588 .85522 L .49635 .85321 L F
.172 .646 .931 r
.45432 .75155 m .45732 .75235 L .4552 .75172 L F
.255 0 0 r
.45432 .75155 m .45624 .75212 L .45732 .75235 L F
.205 .727 .858 r
.45855 .75202 m .45732 .75235 L .45624 .75212 L F
.45855 .75202 m .4595 .75212 L .45732 .75235 L F
.483 0 0 r
.71611 .7338 m .71514 .73398 L .71284 .73323 L F
.489 .236 .458 r
.71829 .73317 m .71611 .7338 L .71916 .73196 L F
0 0 0 r
.71829 .73317 m .71514 .73398 L .71611 .7338 L F
.923 .604 .135 r
.57406 .79461 m .57453 .79686 L .57344 .79387 L F
.789 .427 .37 r
.48643 .85813 m .48519 .86019 L .4832 .85754 L F
.832 .484 .396 r
.48643 .85813 m .48765 .8609 L .48519 .86019 L F
.61 .413 .59 r
.33838 .7705 m .33696 .77297 L .33714 .77068 L F
.777 .699 .777 r
.49266 .85249 m .49036 .8555 L .494 .85489 L F
.696 .386 .448 r
.49036 .8555 m .49247 .8578 L .494 .85489 L F
.041 .436 .871 r
.54484 .81184 m .54129 .80946 L .54209 .81047 L F
.524 0 0 r
.53134 .8177 m .53015 .8166 L .52901 .81621 L F
.909 .515 .108 r
.54741 .8284 m .54915 .83134 L .54874 .82907 L F
.576 .35 .536 r
.4533 .75983 m .45115 .76143 L .45122 .76003 L F
.365 0 0 r
.31865 .67495 m .31482 .67629 L .31633 .67546 L F
.696 .436 .527 r
.71587 .72025 m .71219 .722 L .71246 .71999 L F
.71587 .72025 m .71599 .72252 L .71219 .722 L F
.561 .51 .755 r
.71753 .71645 m .71795 .71988 L .71587 .72025 L F
.648 .399 .529 r
.71872 .72202 m .71599 .72252 L .71587 .72025 L F
.551 .453 .697 r
.71795 .71988 m .71872 .72202 L .71587 .72025 L F
.71795 .71988 m .71872 .72202 L .71587 .72025 L F
0 .296 .793 r
.72091 .72709 m .72105 .72843 L .71928 .7258 L F
.889 .808 .327 r
.7206 .72841 m .72105 .72843 L .72091 .72709 L F
.7206 .72841 m .7206 .73052 L .72105 .72843 L F
.585 .41 .612 r
.5267 .8553 m .52894 .85267 L .52641 .85286 L F
.52 .75 .979 r
.53515 .84383 m .53615 .84432 L .53321 .84407 L F
.629 .357 .487 r
.49453 .87654 m .49716 .8764 L .49585 .8748 L F
.652 .375 .487 r
.47551 .8504 m .47502 .85305 L .47307 .84995 L F
.562 .848 .997 r
.37647 .78647 m .373 .78643 L .37528 .78649 L F
.096 0 0 r
.37528 .78649 m .37827 .78581 L .37647 .78647 L F
.405 .851 .918 r
.67673 .7097 m .67929 .70905 L .67806 .70975 L F
.67806 .70975 m .67673 .7097 L .67746 .71145 L F
.67806 .70975 m .67929 .70905 L .67673 .7097 L F
.543 .369 .596 r
.46024 .86618 m .46232 .86588 L .4623 .86347 L F
.479 .417 .71 r
.46024 .86618 m .46272 .8684 L .46232 .86588 L F
.46024 .86618 m .46096 .86901 L .46272 .8684 L F
0 0 0 r
.49857 .8898 m .50048 .88739 L .49952 .88936 L F
.286 .785 .85 r
.4974 .8898 m .49857 .8898 L .49952 .88936 L F
.549 .463 .71 r
.45002 .74603 m .44855 .74982 L .44787 .74641 L F
.45002 .74603 m .45065 .74956 L .44855 .74982 L F
.802 .686 .736 r
.57004 .78892 m .57123 .79207 L .56839 .79098 L F
.728 .218 .009 r
.57123 .79207 m .57097 .7933 L .56839 .79098 L F
.819 .421 .298 r
.57344 .79387 m .57123 .79207 L .57334 .79155 L F
.57344 .79387 m .57097 .7933 L .57123 .79207 L F
.385 .655 .965 r
.68436 .71919 m .68358 .7196 L .68062 .71728 L F
.138 0 .101 r
.4907 .87566 m .48852 .87663 L .49018 .87444 L F
.8 .67 .721 r
.69873 .74632 m .6999 .7492 L .7007 .74728 L F
.779 .558 .601 r
.53573 .83918 m .53611 .83835 L .5367 .83695 L F
.45 .266 .54 r
.53611 .83835 m .53861 .83621 L .5367 .83695 L F
.688 .893 .972 r
.35581 .79339 m .35253 .79386 L .35439 .7931 L F
.52 .882 .98 r
.3584 .79275 m .35581 .79339 L .35439 .7931 L F
.884 .685 .628 r
.6744 .7124 m .67569 .71175 L .67469 .71055 L F
.748 .4 .393 r
.67468 .71388 m .67569 .71175 L .6744 .7124 L F
.651 .454 .604 r
.67622 .71451 m .67569 .71175 L .67468 .71388 L F
.67622 .71451 m .67746 .71145 L .67569 .71175 L F
.563 .424 .65 r
.46201 .86129 m .46408 .86099 L .46398 .85802 L F
.558 .452 .689 r
.46201 .86129 m .4643 .86313 L .46408 .86099 L F
.46201 .86129 m .4623 .86347 L .4643 .86313 L F
.621 .932 .695 r
.56855 .82956 m .56964 .8283 L .57055 .82872 L F
.522 .484 .755 r
.34094 .66652 m .33994 .67011 L .33898 .66689 L F
.34094 .66652 m .34185 .6697 L .33994 .67011 L F
.522 .481 .752 r
.34185 .6697 m .34246 .67172 L .33994 .67011 L F
.719 .67 .801 r
.53124 .85447 m .53288 .85575 L .53193 .85337 L F
.666 .611 .784 r
.53288 .85575 m .53394 .85222 L .53193 .85337 L F
.53288 .85575 m .53508 .85545 L .53394 .85222 L F
.651 .5 .666 r
.53294 .85813 m .53508 .85545 L .53288 .85575 L F
.498 .793 .998 r
.53294 .85813 m .53288 .85575 L .53508 .85545 L F
.462 .344 .633 r
.46321 .85556 m .46503 .85247 L .46281 .85324 L F
.559 .46 .699 r
.32625 .68306 m .32824 .68265 L .3278 .6805 L F
.551 .43 .668 r
.32655 .6855 m .32824 .68265 L .32625 .68306 L F
.332 .806 .734 r
.35311 .80988 m .35383 .80944 L .35261 .80978 L F
.627 .757 .94 r
.45944 .87639 m .46255 .87679 L .46141 .87567 L F
.703 .779 .911 r
.46141 .87567 m .46255 .87679 L .46567 .87616 L F
0 0 .108 r
.49825 .85511 m .49747 .85789 L .49588 .85522 L F
.49825 .85511 m .49799 .85736 L .49747 .85789 L F
0 .143 .688 r
.49799 .85736 m .49917 .85971 L .49747 .85789 L F
.398 .38 .723 r
.4679 .87679 m .46852 .87992 L .47016 .8788 L F
.487 .472 .767 r
.46917 .88191 m .47016 .8788 L .46852 .87992 L F
.555 .22 .355 r
.43389 .77046 m .43282 .77268 L .43057 .77277 L F
.547 .222 .368 r
.43601 .77034 m .43282 .77268 L .43389 .77046 L F
.598 .827 .987 r
.57605 .84402 m .5768 .84465 L .57896 .84411 L F
.58 .521 .753 r
.4494 .7439 m .44787 .74641 L .44688 .74361 L F
.4494 .7439 m .45002 .74603 L .44787 .74641 L F
.748 .789 .886 r
.52557 .87634 m .52773 .87632 L .52725 .87547 L F
.835 .943 .894 r
.52725 .87547 m .52773 .87632 L .53053 .87378 L F
.255 .765 .773 r
.36213 .80647 m .36143 .8068 L .36411 .80592 L F
.36213 .80647 m .36017 .80699 L .36143 .8068 L F
0 .339 .746 r
.54578 .81251 m .54664 .81267 L .54484 .81184 L F
0 .282 .74 r
.54578 .81251 m .5478 .81376 L .54664 .81267 L F
.718 .444 .51 r
.63876 .64594 m .63554 .64793 L .63546 .64573 L F
.63876 .64594 m .63887 .64775 L .63554 .64793 L F
.627 .374 .516 r
.63876 .64594 m .64106 .64795 L .63887 .64775 L F
.424 .22 .496 r
.33069 .70902 m .33122 .71158 L .32887 .71137 L F
.419 .201 .475 r
.33084 .71371 m .32887 .71137 L .33122 .71158 L F
.33084 .71371 m .32904 .71425 L .32887 .71137 L F
.754 .497 .544 r
.49837 .88153 m .49475 .87949 L .49627 .87948 L F
.803 .7 .751 r
.57004 .78892 m .56939 .78581 L .56945 .78753 L F
.368 0 .161 r
.40971 .78502 m .40891 .7834 L .41101 .78307 L F
.40971 .78502 m .40768 .78544 L .40891 .7834 L F
.355 0 0 r
.50048 .88739 m .49803 .88653 L .49489 .88603 L F
.744 .522 .592 r
.48199 .85005 m .484 .85277 L .48408 .85035 L F
.662 .542 .708 r
.48408 .85035 m .487 .85048 L .48628 .8469 L F
.75 .527 .592 r
.48408 .85035 m .48714 .85288 L .487 .85048 L F
.48408 .85035 m .484 .85277 L .48714 .85288 L F
.723 .664 .792 r
.57278 .82647 m .57434 .82908 L .57055 .82872 L F
.036 0 0 r
.7041 .71608 m .70524 .71627 L .70626 .71516 L F
.7041 .71608 m .70339 .71722 L .70524 .71627 L F
.647 .773 .94 r
.39972 .74392 m .40339 .74459 L .40183 .74395 L F
.587 .87 .994 r
.40386 .74331 m .40339 .74459 L .40517 .74349 L F
.40386 .74331 m .40183 .74395 L .40339 .74459 L F
.236 .445 .861 r
.68372 .75082 m .68423 .75123 L .68275 .74877 L F
.511 .779 .993 r
.32505 .67774 m .32568 .67645 L .32371 .67665 L F
.32505 .67774 m .32699 .67739 L .32568 .67645 L F
0 .11 .648 r
.54361 .8422 m .54523 .84378 L .54503 .84317 L F
.54523 .84378 m .5454 .84395 L .54503 .84317 L F
.17 .513 .914 r
.54503 .84317 m .54538 .84263 L .54485 .84261 L F
0 .11 .648 r
.54361 .8422 m .54503 .84317 L .54238 .84352 L F
.17 .513 .914 r
.54503 .84317 m .54485 .84261 L .54303 .84254 L F
.602 .484 .691 r
.4488 .74086 m .44688 .74361 L .44671 .7413 L F
.568 .632 .875 r
.57077 .84212 m .57445 .84454 L .57229 .84228 L F
.546 .689 .933 r
.57229 .84228 m .57445 .84454 L .57605 .84402 L F
.343 0 .14 r
.65005 .64633 m .64933 .64741 L .64778 .6478 L F
.251 0 .084 r
.65005 .64633 m .65201 .64565 L .64933 .64741 L F
.853 .968 .872 r
.65632 .7178 m .65504 .72028 L .65724 .71781 L F
.65632 .7178 m .65419 .71983 L .65504 .72028 L F
.513 .228 .418 r
.44366 .76541 m .44382 .76679 L .44105 .76717 L F
.569 .267 .416 r
.44366 .76541 m .44571 .76695 L .44382 .76679 L F
.57 .266 .413 r
.44595 .76535 m .44571 .76695 L .44366 .76541 L F
.642 .587 .777 r
.49797 .85015 m .49576 .85095 L .49499 .84937 L F
.598 .458 .661 r
.49797 .85015 m .49803 .85255 L .49576 .85095 L F
.266 .771 .863 r
.39527 .72346 m .39715 .72312 L .39844 .72316 L F
.378 .793 .978 r
.39715 .72312 m .40058 .72336 L .39844 .72316 L F
.494 .477 .767 r
.68432 .72836 m .68507 .73012 L .68708 .7299 L F
.496 .305 .551 r
.703 .72543 m .70302 .72766 L .70095 .72793 L F
.703 .779 .911 r
.46141 .87567 m .46567 .87616 L .46363 .87397 L F
.431 .501 .831 r
.46567 .87616 m .46573 .87299 L .46363 .87397 L F
.46567 .87616 m .46745 .8759 L .46573 .87299 L F
.481 .056 .155 r
.34887 .67669 m .35077 .6769 L .35247 .67515 L F
.2 0 0 r
.35247 .67515 m .35273 .67627 L .3546 .67413 L F
.35247 .67515 m .35077 .6769 L .35273 .67627 L F
.782 .492 .497 r
.55279 .81296 m .55665 .81518 L .55621 .81303 L F
.432 .047 .206 r
.43056 .76178 m .43371 .75975 L .43145 .75981 L F
.933 .678 .528 r
.50875 .85003 m .50887 .85283 L .50764 .8529 L F
.488 .21 .418 r
.50764 .8529 m .51074 .84872 L .50875 .85003 L F
.915 .743 .654 r
.58252 .79438 m .58341 .79702 L .584 .79481 L F
.236 .618 .956 r
.40811 .72384 m .40735 .72445 L .4062 .72371 L F
.40811 .72384 m .40928 .72483 L .40735 .72445 L F
.794 .864 .901 r
.69405 .72263 m .69108 .72302 L .69296 .72145 L F
.766 .785 .869 r
.69662 .72066 m .69405 .72263 L .69296 .72145 L F
.787 .553 .582 r
.69593 .74648 m .6999 .7492 L .69873 .74632 L F
.69593 .74648 m .69678 .74947 L .6999 .7492 L F
.389 .85 .855 r
.38619 .78365 m .38429 .78431 L .38251 .78447 L F
0 0 .11 r
.67381 .70236 m .67448 .70214 L .67629 .70054 L F
.839 .588 .559 r
.59856 .82302 m .60033 .82101 L .59848 .82073 L F
.59856 .82302 m .60037 .82355 L .60033 .82101 L F
.712 .706 .843 r
.43054 .74544 m .43145 .74697 L .43354 .74623 L F
.623 .574 .779 r
.43145 .74697 m .43484 .74728 L .43354 .74623 L F
.797 .57 .594 r
.59843 .8184 m .59539 .81565 L .59541 .81797 L F
.784 .548 .579 r
.59546 .82047 m .59843 .8184 L .59541 .81797 L F
.59546 .82047 m .59848 .82073 L .59843 .8184 L F
.436 .5 .827 r
.34753 .67383 m .34719 .67668 L .34546 .6743 L F
.34753 .67383 m .34887 .67669 L .34719 .67668 L F
.657 .328 .404 r
.38339 .79718 m .38658 .79569 L .38598 .79582 L F
.358 .481 .848 r
.44954 .73524 m .44837 .73625 L .4474 .73438 L F
.519 .503 .778 r
.44954 .73524 m .4486 .73863 L .44837 .73625 L F
.434 .094 .287 r
.35607 .7331 m .3581 .73273 L .35869 .73129 L F
.497 .161 .327 r
.3581 .73273 m .36131 .7302 L .35869 .73129 L F
.487 .472 .767 r
.46917 .88191 m .47112 .88193 L .47016 .8788 L F
.75 .634 .732 r
.6712 .70677 m .6733 .70405 L .67362 .70797 L F
0 0 .126 r
.67584 .70383 m .67362 .70797 L .6733 .70405 L F
.67584 .70383 m .6752 .70601 L .67362 .70797 L F
.961 .637 .245 r
.6752 .70601 m .67469 .71055 L .67362 .70797 L F
.33 .113 .425 r
.46232 .86588 m .4643 .86313 L .4623 .86347 L F
.585 .343 .517 r
.34178 .76815 m .34161 .77022 L .3393 .77039 L F
.487 .262 .498 r
.34345 .76981 m .34178 .76815 L .34407 .76795 L F
.34345 .76981 m .34161 .77022 L .34178 .76815 L F
.689 .653 .809 r
.6814 .7281 m .68432 .72836 L .68349 .72639 L F
.538 .49 .75 r
.68432 .72836 m .68618 .72794 L .68646 .72672 L F
.533 .466 .726 r
.68432 .72836 m .68708 .7299 L .68618 .72794 L F
.349 .533 .895 r
.41701 .72607 m .41627 .7276 L .41502 .72608 L F
.41701 .72607 m .4179 .72786 L .41627 .7276 L F
.452 .13 .327 r
.45823 .87086 m .46014 .87083 L .46096 .86901 L F
.649 .464 .62 r
.46014 .87083 m .46272 .8684 L .46096 .86901 L F
.594 .529 .752 r
.52447 .83117 m .52501 .83421 L .52725 .83373 L F
.773 .86 .915 r
.6814 .7281 m .68236 .72523 L .67962 .72692 L F
.6814 .7281 m .68349 .72639 L .68236 .72523 L F
.318 .805 .79 r
.40928 .74301 m .4083 .7435 L .4106 .7428 L F
.40928 .74301 m .40728 .74366 L .4083 .7435 L F
.996 .763 .443 r
.56482 .82891 m .56484 .83161 L .56501 .83039 L F
.673 .405 .508 r
.56484 .83161 m .56517 .83364 L .56501 .83039 L F
.403 .203 .491 r
.56501 .83039 m .56517 .83364 L .56685 .83073 L F
.324 0 .178 r
.41657 .76806 m .41744 .76957 L .4186 .76765 L F
.41657 .76806 m .41556 .77014 L .41744 .76957 L F
.622 .574 .78 r
.47485 .84723 m .47229 .84456 L .47355 .84525 L F
.327 .545 .91 r
.47355 .84525 m .4766 .84688 L .47485 .84723 L F
.094 .134 .612 r
.47661 .84848 m .47485 .84723 L .4766 .84688 L F
.47661 .84848 m .47551 .8504 L .47485 .84723 L F
.698 .443 .534 r
.6488 .61426 m .64674 .6163 L .64473 .61351 L F
.6488 .61426 m .6484 .61617 L .64674 .6163 L F
.241 .029 .378 r
.65026 .61331 m .6484 .61617 L .6488 .61426 L F
.622 .557 .76 r
.52625 .85739 m .52862 .85529 L .5267 .8553 L F
.52625 .85739 m .52822 .85781 L .52862 .85529 L F
0 0 .11 r
.67381 .70236 m .6733 .70405 L .67448 .70214 L F
.797 .647 .695 r
.63878 .63332 m .63929 .63404 L .63546 .63415 L F
.793 .72 .783 r
.63546 .63415 m .63929 .63404 L .63665 .6356 L F
.53 .04 .038 r
.5744 .78407 m .57666 .78505 L .5776 .78381 L F
.778 .334 .194 r
.57666 .78505 m .57965 .78597 L .5776 .78381 L F
0 .37 .837 r
.4679 .87679 m .46847 .87633 L .46745 .8759 L F
0 .255 .767 r
.4679 .87679 m .47016 .8788 L .46847 .87633 L F
.413 .184 .454 r
.33711 .70035 m .33731 .70336 L .33557 .70387 L F
.393 .15 .422 r
.33975 .6978 m .3394 .70077 L .33711 .70035 L F
.401 .175 .452 r
.33906 .7028 m .33711 .70035 L .3394 .70077 L F
.33906 .7028 m .33731 .70336 L .33711 .70035 L F
.705 .706 .849 r
.67599 .73945 m .67811 .73858 L .67501 .73799 L F
.589 .771 .967 r
.68632 .69248 m .68756 .6937 L .68508 .69424 L F
.68632 .69248 m .68756 .6937 L .68508 .69424 L F
.875 .651 .596 r
.56285 .83041 m .56482 .82891 L .56174 .82839 L F
.56285 .83041 m .56484 .83161 L .56482 .82891 L F
.703 .498 .608 r
.49098 .84202 m .49273 .8441 L .49362 .84213 L F
.729 .427 .468 r
.49273 .8441 m .49559 .84488 L .49362 .84213 L F
.813 .421 .312 r
.49362 .84213 m .49709 .84474 L .49531 .84239 L F
.49362 .84213 m .49559 .84488 L .49709 .84474 L F
.364 .827 .75 r
.35383 .80944 m .3565 .80856 L .35834 .80775 L F
.483 .89 .935 r
.68876 .75375 m .69286 .75292 L .6916 .75192 L F
.726 .88 .952 r
.6916 .75192 m .69286 .75292 L .69466 .75174 L F
.412 .197 .475 r
.33356 .70666 m .33331 .70878 L .33069 .70902 L F
.388 .197 .496 r
.33283 .71099 m .33069 .70902 L .33331 .70878 L F
.33283 .71099 m .33122 .71158 L .33069 .70902 L F
.586 .262 .387 r
.5493 .78581 m .55155 .7859 L .55213 .78326 L F
.52 .226 .408 r
.55213 .78326 m .55635 .78338 L .55503 .78179 L F
.611 .361 .514 r
.55155 .7859 m .55635 .78338 L .55213 .78326 L F
.061 .297 .784 r
.68535 .7517 m .68275 .74877 L .68423 .75123 L F
.011 .584 .757 r
.47817 .87096 m .47642 .8708 L .47432 .87069 L F
.605 .324 .464 r
.47817 .87096 m .47736 .87366 L .47642 .8708 L F
.47817 .87096 m .4799 .87321 L .47736 .87366 L F
.931 .81 .704 r
.47817 .87096 m .48148 .87332 L .4799 .87321 L F
.705 .792 .918 r
.34713 .79404 m .34516 .79497 L .34375 .79385 L F
.484 .213 .427 r
.36097 .75713 m .35839 .7594 L .35892 .75746 L F
.45 .266 .54 r
.53611 .83835 m .53851 .83854 L .53861 .83621 L F
.47 .369 .658 r
.53611 .83835 m .53913 .84222 L .53851 .83854 L F
.53611 .83835 m .53747 .84325 L .53913 .84222 L F
.733 .72 .839 r
.70735 .72281 m .70828 .72517 L .70493 .72486 L F
.759 .647 .738 r
.70828 .72517 m .70613 .72788 L .70493 .72486 L F
.698 .701 .85 r
.71097 .72319 m .70828 .72517 L .70735 .72281 L F
.626 .46 .638 r
.43361 .75734 m .43371 .75975 L .43588 .75708 L F
.576 .351 .537 r
.57705 .81368 m .57853 .81547 L .57549 .81604 L F
.57705 .81368 m .57853 .81547 L .57549 .81604 L F
.767 .684 .771 r
.57862 .8107 m .57705 .81368 L .57656 .81027 L F
.863 .843 .823 r
.66679 .62273 m .66409 .62422 L .6657 .62341 L F
0 .418 .85 r
.66797 .62269 m .66937 .62397 L .66679 .62273 L F
.66797 .62269 m .66679 .62273 L .6657 .62341 L F
.754 .851 .923 r
.64791 .62815 m .6464 .63008 L .64534 .62891 L F
.794 .584 .617 r
.58014 .80766 m .57712 .80759 L .57796 .80533 L F
.783 .644 .708 r
.58014 .80766 m .57656 .81027 L .57712 .80759 L F
.58014 .80766 m .57862 .8107 L .57656 .81027 L F
.584 .675 .902 r
.43436 .72911 m .43331 .73098 L .43212 .72974 L F
.43436 .72911 m .43542 .73064 L .43331 .73098 L F
.618 .613 .823 r
.54831 .78914 m .55064 .78948 L .5493 .78581 L F
.601 .172 .198 r
.55064 .78948 m .55057 .79177 L .54831 .78914 L F
.55064 .78948 m .55057 .79177 L .54831 .78914 L F
.564 .921 .953 r
.52735 .84491 m .52631 .84471 L .52418 .84558 L F
0 .115 .66 r
.527 .84247 m .52735 .84491 L .52616 .84194 L F
.942 .929 .762 r
.527 .84247 m .52631 .84471 L .52735 .84491 L F
.805 .658 .7 r
.54504 .84815 m .54568 .85108 L .54176 .84945 L F
.834 .579 .553 r
.54176 .84945 m .54548 .851 L .54461 .85237 L F
.54176 .84945 m .54461 .85237 L .54347 .85443 L F
.822 .902 .896 r
.54461 .85237 m .54597 .84936 L .54407 .85321 L F
.54461 .85237 m .54407 .85321 L .54347 .85443 L F
.834 .579 .553 r
.54548 .851 m .54568 .85108 L .54461 .85237 L F
.953 .771 .619 r
.66069 .72018 m .66013 .7223 L .6594 .71987 L F
.895 .657 .571 r
.6905 .74396 m .68756 .74343 L .68845 .73939 L F
.779 .536 .568 r
.6905 .74396 m .68696 .74563 L .68756 .74343 L F
.6905 .74396 m .69028 .74601 L .68696 .74563 L F
.581 .242 .361 r
.69357 .74331 m .69323 .74447 L .6905 .74396 L F
.664 .515 .672 r
.69323 .74447 m .69028 .74601 L .6905 .74396 L F
.053 0 0 r
.37916 .75025 m .3779 .75055 L .37597 .75065 L F
.472 0 0 r
.37916 .75025 m .38137 .75136 L .3779 .75055 L F
.503 .017 .035 r
.38232 .75056 m .38137 .75136 L .37916 .75025 L F
.696 .588 .731 r
.70483 .72145 m .70285 .72344 L .70178 .72012 L F
.615 .5 .699 r
.70493 .72486 m .70285 .72344 L .70483 .72145 L F
.70493 .72486 m .703 .72543 L .70285 .72344 L F
.524 .229 .409 r
.44105 .76717 m .44034 .76997 L .43817 .77019 L F
.507 .214 .402 r
.44382 .76679 m .44034 .76997 L .44105 .76717 L F
.94 .58 .189 r
.6664 .6271 m .66693 .62875 L .66734 .62787 L F
0 0 0 r
.66734 .62787 m .66895 .62633 L .6697 .62792 L F
.66734 .62787 m .66693 .62875 L .66895 .62633 L F
.409 0 .126 r
.34522 .73822 m .34747 .73798 L .34871 .73623 L F
.147 0 0 r
.34871 .73623 m .3492 .73732 L .35084 .73598 L F
.34871 .73623 m .34747 .73798 L .3492 .73732 L F
.303 .791 .742 r
.36213 .80647 m .36411 .80592 L .36597 .80524 L F
.084 .331 .807 r
.47276 .84365 m .47355 .84525 L .47229 .84456 L F
.228 0 0 r
.41411 .74295 m .41264 .74304 L .4106 .7428 L F
.143 .68 .847 r
.4159 .74318 m .41264 .74304 L .41411 .74295 L F
.487 .894 .926 r
.50315 .87649 m .50179 .87728 L .50164 .87759 L F
.657 .328 .404 r
.38339 .79718 m .38598 .79582 L .38541 .7968 L F
0 0 0 r
.38598 .79582 m .38708 .79592 L .38541 .7968 L F
.38598 .79582 m .38888 .79503 L .38708 .79592 L F
.53 .282 .484 r
.36526 .75413 m .36281 .75657 L .36358 .75437 L F
.497 .161 .327 r
.3581 .73273 m .36022 .73254 L .36131 .7302 L F
.376 .042 .266 r
.36131 .7302 m .36216 .73201 L .36336 .72984 L F
.36131 .7302 m .36022 .73254 L .36216 .73201 L F
.602 .484 .691 r
.4488 .74086 m .4494 .7439 L .44688 .74361 L F
.517 .552 .831 r
.34417 .67139 m .34363 .67446 L .34246 .67172 L F
.34417 .67139 m .34546 .6743 L .34363 .67446 L F
.628 .356 .488 r
.47852 .85244 m .48199 .85005 L .4784 .84991 L F
.47852 .85244 m .4806 .85216 L .48199 .85005 L F
.759 .523 .576 r
.4806 .85216 m .484 .85277 L .48199 .85005 L F
.395 .15 .42 r
.32122 .69889 m .32304 .69823 L .324 .69705 L F
.504 .359 .617 r
.32124 .70125 m .32304 .69823 L .32122 .69889 L F
.806 .75 .8 r
.64223 .62437 m .64287 .62723 L .63983 .62694 L F
.223 .717 .919 r
.64213 .62358 m .64309 .62339 L .64413 .62376 L F
.64052 .62344 m .64309 .62339 L .64213 .62358 L F
.633 .927 .972 r
.64413 .62376 m .64513 .62243 L .64309 .62339 L F
.64413 .62376 m .64513 .62243 L .64309 .62339 L F
.465 0 0 r
.64053 .62146 m .64513 .62243 L .64309 .62339 L F
.837 .958 .89 r
.64413 .62376 m .64309 .62339 L .64267 .62379 L F
.223 .717 .919 r
.64052 .62344 m .64413 .62376 L .64223 .62437 L F
.837 .958 .89 r
.64413 .62376 m .64267 .62379 L .64263 .62458 L F
.591 .4 .592 r
.64413 .62376 m .64327 .62636 L .64223 .62437 L F
.359 0 .105 r
.64513 .62243 m .6443 .62411 L .64202 .6245 L F
.465 0 0 r
.64053 .62146 m .64511 .62273 L .64513 .62243 L F
.64511 .62273 m .64536 .6228 L .64513 .62243 L F
.239 .626 .958 r
.64523 .62272 m .64536 .6228 L .64514 .62274 L F
0 0 .009 r
.64536 .6228 m .64664 .62191 L .64513 .62243 L F
.635 .767 .943 r
.64516 .62268 m .64664 .62191 L .64536 .6228 L F
.27 .775 .781 r
.64513 .62243 m .64559 .62219 L .64511 .62275 L F
.635 .767 .943 r
.64314 .62149 m .6459 .62182 L .64516 .62268 L F
.6459 .62182 m .64664 .62191 L .64559 .62219 L F
.27 .775 .781 r
.64559 .62219 m .64664 .62191 L .64589 .62203 L F
.64513 .62243 m .64664 .62191 L .64559 .62219 L F
.635 .767 .943 r
.64559 .62219 m .64664 .62191 L .64516 .62268 L F
.27 .775 .781 r
.64511 .62275 m .64589 .62203 L .64507 .6231 L F
.64559 .62219 m .64589 .62203 L .64511 .62275 L F
.239 .626 .958 r
.64314 .62149 m .64516 .62268 L .64053 .62146 L F
.64516 .62268 m .64523 .62272 L .64515 .6227 L F
.64516 .62268 m .64515 .6227 L .64053 .62146 L F
.27 .775 .781 r
.64491 .62288 m .64507 .6231 L .6443 .62411 L F
.64513 .62243 m .64511 .62273 L .64491 .62288 L F
.64511 .62273 m .64507 .6231 L .64491 .62288 L F
.239 .626 .958 r
.64523 .62272 m .64514 .62274 L .64053 .62146 L F
.359 0 .105 r
.64406 .62293 m .64395 .62322 L .64309 .62339 L F
.64513 .62243 m .6445 .62285 L .64406 .62293 L F
.6445 .62285 m .64395 .62322 L .64406 .62293 L F
.64395 .62322 m .64202 .6245 L .64309 .62339 L F
0 .034 .594 r
.64223 .62437 m .64261 .62509 L .64257 .62588 L F
.64261 .62509 m .64327 .62636 L .64257 .62588 L F
.687 .941 .654 r
.64078 .6256 m .64223 .62437 L .63983 .62694 L F
.808 .474 .423 r
.64078 .6256 m .64327 .62636 L .64223 .62437 L F
.837 .958 .89 r
.64413 .62376 m .64078 .6256 L .64223 .62437 L F
.64263 .62458 m .64267 .62379 L .64078 .6256 L F
0 .034 .594 r
.64257 .62588 m .64327 .62636 L .64287 .62723 L F
.549 .376 .6 r
.64534 .62891 m .64287 .62723 L .64327 .62636 L F
.458 .165 .38 r
.39607 .77853 m .39807 .77816 L .39884 .77571 L F
.454 .162 .378 r
.39884 .77571 m .40015 .77768 L .40083 .77529 L F
.39884 .77571 m .39807 .77816 L .40015 .77768 L F
.694 .355 .398 r
.69357 .74331 m .69469 .74435 L .69323 .74447 L F
.634 .196 .192 r
.59646 .83637 m .5985 .83816 L .59807 .83982 L F
.75 .604 .695 r
.6882 .72525 m .68571 .72262 L .68789 .72215 L F
.6882 .72525 m .68694 .72568 L .68571 .72262 L F
.668 .646 .819 r
.69108 .72302 m .6882 .72525 L .68789 .72215 L F
.495 .167 .339 r
.39338 .78019 m .39546 .77993 L .39391 .77875 L F
.496 .166 .337 r
.39391 .77875 m .39546 .77993 L .39607 .77853 L F
.489 .204 .407 r
.65458 .64304 m .65421 .64528 L .65201 .64565 L F
.488 .201 .404 r
.65458 .64304 m .65641 .64485 L .65421 .64528 L F
.65458 .64304 m .65688 .64256 L .65641 .64485 L F
.584 .655 .885 r
.49305 .88521 m .49189 .88828 L .49004 .88647 L F
.992 .882 .573 r
.5775 .81914 m .57759 .81625 L .57855 .81812 L F
.686 .641 .799 r
.487 .88328 m .48513 .88216 L .48833 .88408 L F
.382 0 0 r
.48833 .88408 m .49023 .88492 L .487 .88328 L F
.656 .834 .968 r
.53739 .86844 m .53566 .86932 L .53408 .86823 L F
.53739 .86844 m .53566 .86932 L .53408 .86823 L F
.462 .344 .633 r
.46321 .85556 m .46509 .85556 L .46503 .85247 L F
.46 .444 .754 r
.46321 .85556 m .4657 .85747 L .46509 .85556 L F
.498 .444 .727 r
.46321 .85556 m .46398 .85802 L .4657 .85747 L F
.545 .229 .383 r
.55503 .78179 m .55635 .78338 L .55689 .78306 L F
.508 .252 .461 r
.55503 .78179 m .55689 .78306 L .55694 .78113 L F
.562 .286 .455 r
.3485 .76713 m .34681 .76494 L .34888 .7649 L F
.3485 .76713 m .34576 .76745 L .34681 .76494 L F
.864 .891 .853 r
.55713 .79185 m .55798 .78852 L .55945 .79151 L F
.55713 .79185 m .55576 .79118 L .55798 .78852 L F
.598 .046 0 r
.55713 .79185 m .55806 .79307 L .55576 .79118 L F
.55713 .79185 m .5592 .7937 L .55806 .79307 L F
.615 .061 0 r
.56035 .79426 m .55713 .79185 L .55945 .79151 L F
.56035 .79426 m .5592 .7937 L .55713 .79185 L F
.616 .608 .82 r
.46169 .7517 m .46062 .75429 L .4595 .75212 L F
.46169 .7517 m .46289 .75433 L .46062 .75429 L F
.566 .352 .549 r
.46289 .75433 m .46066 .757 L .46062 .75429 L F
.73 .506 .587 r
.59225 .81772 m .59539 .81565 L .5924 .81545 L F
.59225 .81772 m .59541 .81797 L .59539 .81565 L F
.623 .565 .768 r
.53692 .82636 m .53979 .82644 L .53871 .82417 L F
.788 .539 .56 r
.70613 .72788 m .703 .72543 L .70493 .72486 L F
.70613 .72788 m .70302 .72766 L .703 .72543 L F
.57 .569 .813 r
.71598 .72479 m .71424 .72552 L .71219 .722 L F
.947 .595 .296 r
.55826 .82663 m .55972 .82892 L .5585 .82792 L F
.798 .834 .879 r
.5585 .82792 m .55972 .82892 L .56219 .82664 L F
.654 .448 .593 r
.55972 .82892 m .55989 .83102 L .56174 .82839 L F
.707 .641 .781 r
.56219 .82664 m .55972 .82892 L .56174 .82839 L F
.654 .448 .593 r
.55972 .82892 m .55989 .83102 L .56174 .82839 L F
.601 .58 .802 r
.45832 .87315 m .45944 .87639 L .46141 .87567 L F
.551 .344 .553 r
.65142 .71805 m .65423 .71767 L .65275 .71581 L F
.667 .359 .442 r
.65423 .71767 m .65632 .7178 L .65275 .71581 L F
.591 .02 0 r
.65275 .71581 m .65632 .7178 L .65724 .71781 L F
0 .073 .617 r
.67155 .61509 m .67131 .61697 L .67024 .61328 L F
.796 .943 .922 r
.67032 .61637 m .67131 .61697 L .67155 .61509 L F
.472 0 .047 r
.37518 .72652 m .3788 .72528 L .37675 .72545 L F
0 0 0 r
.55904 .82409 m .55826 .82663 L .55846 .82608 L F
.55904 .82409 m .55846 .82608 L .55845 .82324 L F
.398 0 .1 r
.36545 .72943 m .36753 .72924 L .36891 .72743 L F
.494 .106 .233 r
.36753 .72924 m .37098 .7271 L .36891 .72743 L F
.39 .682 .976 r
.44286 .73243 m .44208 .7335 L .44081 .73272 L F
.44286 .73243 m .44408 .73364 L .44208 .7335 L F
.87 .676 .638 r
.57796 .80533 m .57712 .80759 L .57568 .80451 L F
.992 .882 .573 r
.5775 .81914 m .57642 .82037 L .57759 .81625 L F
.764 .709 .801 r
.49714 .84708 m .49499 .84937 L .49375 .84712 L F
.642 .587 .777 r
.49797 .85015 m .49499 .84937 L .49714 .84708 L F
.797 .647 .695 r
.63878 .63332 m .63546 .63415 L .63753 .63166 L F
.897 .7 .629 r
.64047 .62978 m .63878 .63332 L .63753 .63166 L F
.64047 .62978 m .64054 .63141 L .63878 .63332 L F
.848 .497 .389 r
.53766 .86337 m .53946 .86357 L .53836 .86535 L F
0 0 0 r
.54067 .86269 m .53946 .86357 L .54073 .86257 L F
.53836 .86535 m .53946 .86357 L .54067 .86269 L F
.52 .717 .962 r
.64846 .63376 m .64733 .63516 L .64636 .63395 L F
.64846 .63376 m .64733 .63516 L .64636 .63395 L F
.725 .75 .872 r
.31865 .67495 m .32067 .67535 L .32091 .67394 L F
.313 .351 .741 r
.32091 .67394 m .32067 .67535 L .32218 .67386 L F
.427 .535 .864 r
.32067 .67535 m .32371 .67665 L .32258 .6746 L F
.457 .759 .994 r
.32371 .67665 m .32263 .67562 L .32218 .67386 L F
.32371 .67665 m .32568 .67645 L .32263 .67562 L F
.785 .416 .358 r
.32485 .67622 m .3241 .67807 L .32263 .67562 L F
.32568 .67645 m .32547 .67666 L .32485 .67622 L F
.32547 .67666 m .3241 .67807 L .32485 .67622 L F
.427 .535 .864 r
.32192 .67412 m .32258 .6746 L .32218 .67386 L F
.32067 .67535 m .32258 .6746 L .32192 .67412 L F
.522 .644 .91 r
.52692 .81904 m .5281 .81732 L .52596 .81731 L F
.52692 .81904 m .52983 .81942 L .5281 .81732 L F
.762 .714 .806 r
.64802 .60273 m .65137 .60311 L .64948 .60428 L F
.938 .697 .548 r
.5845 .80705 m .58591 .81012 L .58609 .80765 L F
.578 .782 .976 r
.50315 .87649 m .50164 .87759 L .49932 .87592 L F
.009 0 0 r
.50197 .86653 m .49845 .86864 L .49798 .86588 L F
.713 .282 .224 r
.50029 .86793 m .49922 .8694 L .49898 .86914 L F
.009 0 0 r
.50151 .86681 m .50029 .86793 L .49845 .86864 L F
.473 .334 .611 r
.49845 .86864 m .4966 .86889 L .49798 .86588 L F
.713 .282 .224 r
.50029 .86793 m .49743 .86745 L .49845 .86864 L F
.50029 .86793 m .49898 .86914 L .49743 .86745 L F
.009 0 0 r
.50197 .86653 m .50029 .86793 L .50151 .86681 L F
.142 .027 .451 r
.50287 .86333 m .50253 .86626 L .50197 .86653 L F
.762 .489 .52 r
.50253 .86626 m .50029 .86793 L .50197 .86653 L F
.835 .943 .894 r
.52725 .87547 m .53053 .87378 L .53012 .87338 L F
.875 .901 .846 r
.53508 .85545 m .53603 .85233 L .53394 .85222 L F
.53508 .85545 m .53732 .8529 L .53603 .85233 L F
.864 .656 .62 r
.64461 .60581 m .6468 .60842 L .64585 .6085 L F
.344 .343 .715 r
.64518 .61152 m .64585 .6085 L .6468 .60842 L F
.551 .43 .668 r
.32655 .6855 m .32852 .6852 L .32824 .68265 L F
.449 .352 .653 r
.32655 .6855 m .3284 .68749 L .32852 .6852 L F
.32655 .6855 m .32681 .68862 L .3284 .68749 L F
.225 .717 .921 r
.64802 .60273 m .65135 .60278 L .65137 .60311 L F
.683 .893 .974 r
.65135 .60278 m .6537 .60267 L .65137 .60311 L F
.492 .211 .415 r
.42356 .76675 m .4261 .76481 L .42414 .76525 L F
.484 .217 .434 r
.35634 .7597 m .35373 .76187 L .35417 .76008 L F
.705 .642 .784 r
.48714 .85288 m .49046 .85289 L .48921 .85016 L F
.779 .602 .66 r
.48707 .85518 m .49046 .85289 L .48714 .85288 L F
.48707 .85518 m .49036 .8555 L .49046 .85289 L F
.639 .61 .805 r
.48921 .85016 m .49046 .85289 L .49266 .85249 L F
.614 .463 .653 r
.49046 .85289 m .49036 .8555 L .49266 .85249 L F
.57 .777 .976 r
.32087 .65581 m .32038 .65741 L .31891 .65606 L F
.32087 .65581 m .32245 .65694 L .32038 .65741 L F
.712 .706 .843 r
.43054 .74544 m .43354 .74623 L .43285 .74348 L F
.69 .423 0 r
.43285 .74348 m .43354 .74623 L .43311 .74449 L F
.699 .572 .708 r
.43354 .74623 m .43583 .74346 L .43311 .74449 L F
.43354 .74623 m .43634 .74669 L .43583 .74346 L F
.778 .599 .656 r
.43484 .74728 m .43634 .74669 L .43354 .74623 L F
.457 .823 .994 r
.53603 .85233 m .53732 .8529 L .53939 .85251 L F
.53603 .85233 m .53732 .8529 L .53939 .85251 L F
0 0 0 r
.54014 .8288 m .53836 .83063 L .53786 .83104 L F
.53836 .83063 m .53656 .83313 L .53786 .83104 L F
.76 .681 .775 r
.6861 .71154 m .68322 .71226 L .68513 .71013 L F
.467 .02 .103 r
.6861 .71154 m .68558 .71235 L .68322 .71226 L F
.554 .621 .873 r
.68739 .71009 m .6861 .71154 L .68513 .71013 L F
.68739 .71009 m .68826 .71126 L .6861 .71154 L F
.588 .275 .405 r
.68826 .71126 m .68558 .71235 L .6861 .71154 L F
.421 .037 .203 r
.65954 .64091 m .65955 .64195 L .65688 .64256 L F
.476 .078 .205 r
.65954 .64091 m .6617 .64166 L .65955 .64195 L F
.475 .1 .248 r
.66196 .64062 m .6617 .64166 L .65954 .64091 L F
.664 .808 .952 r
.65953 .72854 m .66167 .72776 L .65846 .72748 L F
.785 .735 .806 r
.71172 .71707 m .71246 .71999 L .70946 .7196 L F
.852 .638 .612 r
.71246 .71999 m .70969 .72215 L .70946 .7196 L F
.71246 .71999 m .71219 .722 L .70969 .72215 L F
.82 .755 .791 r
.71479 .71678 m .71246 .71999 L .71172 .71707 L F
.395 0 .143 r
.39581 .79116 m .39251 .79331 L .39401 .79183 L F
.698 .723 .869 r
.66392 .72723 m .66496 .72921 L .66713 .72774 L F
.579 .437 .651 r
.46398 .85802 m .46592 .86048 L .4657 .85747 L F
.46398 .85802 m .46408 .86099 L .46592 .86048 L F
.608 .143 .125 r
.56423 .78067 m .56222 .78095 L .56558 .781 L F
.61 .413 .59 r
.33838 .7705 m .33805 .77286 L .33696 .77297 L F
.679 .493 .628 r
.3393 .77039 m .33805 .77286 L .33838 .7705 L F
.689 .294 .294 r
.51212 .8531 m .50912 .85415 L .50887 .85283 L F
.51212 .8531 m .511 .85492 L .50912 .85415 L F
.307 0 .088 r
.51437 .85249 m .511 .85492 L .51212 .8531 L F
.381 .411 .767 r
.55989 .83102 m .56074 .83437 L .56216 .83356 L F
.406 .468 .812 r
.56074 .83437 m .56323 .83641 L .56216 .83356 L F
.52 .253 .45 r
.42863 .77322 m .4282 .77517 L .42608 .77544 L F
.531 .297 .505 r
.43057 .77277 m .4282 .77517 L .42863 .77322 L F
.785 .735 .806 r
.71172 .71707 m .70946 .7196 L .71023 .71786 L F
.928 .554 .154 r
.69593 .74648 m .69522 .74604 L .69469 .74435 L F
.859 .962 .869 r
.69797 .74331 m .69593 .74648 L .69873 .74632 L F
.69797 .74331 m .69522 .74604 L .69593 .74648 L F
.958 .62 .247 r
.6958 .74836 m .69593 .74648 L .69522 .74604 L F
.6958 .74836 m .69678 .74947 L .69593 .74648 L F
.663 .482 .629 r
.69593 .74648 m .69678 .74947 L .69873 .74632 L F
.746 .484 .535 r
.484 .85277 m .48707 .85518 L .48714 .85288 L F
.617 .516 .717 r
.487 .85048 m .48714 .85288 L .48921 .85016 L F
.616 .512 .713 r
.48628 .8469 m .48921 .85016 L .48808 .84706 L F
.48628 .8469 m .487 .85048 L .48921 .85016 L F
.839 .756 .771 r
.69874 .7353 m .69949 .73817 L .69997 .73605 L F
.844 .867 .859 r
.69874 .7353 m .69997 .73605 L .7019 .73376 L F
.44 .875 .896 r
.65724 .71781 m .65894 .71691 L .65974 .71723 L F
.65724 .71781 m .65632 .7178 L .65894 .71691 L F
.65724 .71781 m .65894 .71691 L .65974 .71723 L F
.65724 .71781 m .65632 .7178 L .65894 .71691 L F
.959 .745 .294 r
.56035 .79426 m .55996 .79641 L .5592 .7937 L F
.56035 .79426 m .56047 .79764 L .55996 .79641 L F
.796 .74 .802 r
.56139 .79103 m .56035 .79426 L .55945 .79151 L F
.56139 .79103 m .56252 .79383 L .56035 .79426 L F
.965 .807 .637 r
.69797 .74331 m .69873 .74632 L .69912 .74398 L F
.792 .997 .789 r
.59644 .84079 m .59583 .84225 L .59807 .83982 L F
.768 .989 .892 r
.59492 .84214 m .59583 .84225 L .59644 .84079 L F
.636 .261 .315 r
.64791 .62815 m .6506 .629 L .65075 .62717 L F
.413 .286 .597 r
.65075 .62717 m .65266 .62402 L .65045 .62447 L F
.914 .787 .707 r
.65357 .62943 m .65303 .62678 L .65284 .62761 L F
.65303 .62678 m .65303 .62677 L .65301 .62685 L F
.65303 .62678 m .65301 .62685 L .65284 .62761 L F
.65357 .62943 m .65453 .62743 L .65303 .62677 L F
.409 .268 .576 r
.65284 .62779 m .65351 .62679 L .65301 .62685 L F
.65283 .62757 m .65301 .62685 L .6528 .62688 L F
.65284 .62779 m .65301 .62685 L .65283 .62757 L F
.65278 .62777 m .6528 .62688 L .65075 .62717 L F
.65283 .62757 m .6528 .62688 L .65278 .62777 L F
.914 .787 .707 r
.65283 .62757 m .65303 .62677 L .65239 .62649 L F
.65284 .62761 m .65301 .62685 L .65283 .62757 L F
.65301 .62685 m .65303 .62677 L .65283 .62757 L F
.409 .268 .576 r
.65284 .62779 m .65283 .62757 L .65278 .62777 L F
.914 .787 .707 r
.65286 .62784 m .65284 .62777 L .65284 .62779 L F
.65284 .62777 m .65239 .62649 L .65284 .62779 L F
.65357 .62943 m .65284 .62761 L .65286 .62784 L F
.65284 .62761 m .65239 .62649 L .65286 .62784 L F
.413 .286 .597 r
.65262 .62408 m .65301 .62685 L .65266 .62402 L F
.65075 .62717 m .6528 .62688 L .65262 .62408 L F
.6528 .62688 m .65301 .62685 L .65262 .62408 L F
.65301 .62685 m .65304 .62685 L .65303 .62677 L F
.65301 .62685 m .65303 .62677 L .65266 .62402 L F
.936 .656 .483 r
.65239 .62649 m .65303 .62677 L .65266 .62402 L F
.65303 .62677 m .65453 .62743 L .65266 .62402 L F
.413 .286 .597 r
.65304 .62685 m .65351 .62679 L .65266 .62402 L F
.409 .268 .576 r
.65284 .62779 m .65075 .62717 L .6506 .629 L F
.611 .576 .791 r
.65266 .62402 m .65075 .62717 L .65045 .62447 L F
.582 .372 .561 r
.51678 .85205 m .51437 .85249 L .51477 .84984 L F
.675 .634 .801 r
.51315 .84942 m .51437 .85249 L .51599 .85138 L F
.51315 .84942 m .51599 .85138 L .51477 .84984 L F
.51599 .85138 m .51648 .85172 L .51568 .85084 L F
.51599 .85138 m .51568 .85084 L .51477 .84984 L F
.872 .99 .82 r
.51678 .85205 m .51472 .85391 L .51437 .85249 L F
.392 .135 .401 r
.51472 .85391 m .51611 .8516 L .51437 .85249 L F
.675 .634 .801 r
.51608 .85154 m .51644 .85107 L .51678 .85205 L F
.392 .135 .401 r
.51608 .85154 m .51644 .85107 L .51599 .85138 L F
.675 .634 .801 r
.51315 .84942 m .51599 .85138 L .51644 .85107 L F
.392 .135 .401 r
.51611 .8516 m .51599 .85138 L .51437 .85249 L F
.675 .634 .801 r
.51598 .85138 m .51678 .85205 L .51648 .85172 L F
.51315 .84942 m .51608 .85154 L .51598 .85138 L F
.51608 .85154 m .51678 .85205 L .51598 .85138 L F
.872 .99 .82 r
.51678 .85205 m .51573 .85328 L .51472 .85391 L F
.392 .135 .401 r
.51472 .85391 m .51538 .85458 L .51622 .85179 L F
.51611 .8516 m .51622 .85179 L .51644 .85107 L F
.51472 .85391 m .51622 .85179 L .51611 .8516 L F
.675 .634 .801 r
.51315 .84942 m .51644 .85107 L .51608 .85154 L F
.392 .135 .401 r
.51611 .8516 m .51644 .85107 L .51608 .85154 L F
.594 .38 .56 r
.4261 .76481 m .4286 .76225 L .42624 .76254 L F
.98 .711 .317 r
.66919 .72271 m .66935 .72497 L .66862 .72405 L F
.66919 .72271 m .66935 .72497 L .66862 .72405 L F
.95 .666 .217 r
.66767 .71875 m .66803 .71741 L .66709 .71665 L F
.66767 .71875 m .66832 .71973 L .66803 .71741 L F
.66767 .71875 m .66803 .71741 L .66709 .71665 L F
.66767 .71875 m .66832 .71973 L .66803 .71741 L F
.55 .414 .649 r
.3584 .66939 m .35654 .67227 L .35626 .66996 L F
.3584 .66939 m .35654 .67227 L .35626 .66996 L F
.754 .987 .897 r
.66098 .71435 m .66019 .71474 L .66047 .71373 L F
.284 0 0 r
.66047 .71373 m .66362 .71208 L .66098 .71435 L F
.361 0 0 r
.3788 .72528 m .38095 .72533 L .38198 .72462 L F
.233 0 0 r
.38095 .72533 m .38405 .72421 L .38198 .72462 L F
0 0 0 r
.56174 .82839 m .55989 .83102 L .56109 .82983 L F
.805 .403 .288 r
.56109 .82983 m .56285 .83041 L .56174 .82839 L F
.866 .692 .665 r
.53962 .80327 m .54076 .806 L .53844 .80346 L F
.932 .621 .429 r
.54076 .806 m .53995 .80645 L .53844 .80346 L F
.392 .45 .801 r
.54191 .80421 m .54076 .806 L .53962 .80327 L F
.763 .985 .748 r
.54191 .80421 m .53995 .80645 L .54076 .806 L F
.566 .177 .265 r
.53995 .80645 m .54365 .80544 L .54076 .806 L F
.631 .771 .947 r
.54365 .80544 m .54076 .806 L .54191 .80421 L F
.843 .928 .886 r
.69799 .71564 m .69553 .7171 L .69691 .71567 L F
.458 .586 .893 r
.6997 .7148 m .70212 .71733 L .69799 .71564 L F
.143 0 0 r
.69661 .71589 m .69685 .71667 L .69886 .71572 L F
.609 .462 .656 r
.69731 .71526 m .69553 .7171 L .69651 .7159 L F
.143 0 0 r
.69651 .7159 m .69653 .71595 L .69661 .71589 L F
.69653 .71595 m .69685 .71667 L .69661 .71589 L F
.843 .928 .886 r
.6974 .71531 m .69691 .71567 L .69731 .71526 L F
.69799 .71564 m .69691 .71567 L .6974 .71531 L F
.458 .586 .893 r
.6997 .7148 m .69799 .71564 L .69731 .71526 L F
.221 0 .122 r
.37046 .78564 m .37245 .78714 L .37363 .78664 L F
.099 0 0 r
.37363 .78664 m .373 .78643 L .37046 .78564 L F
.799 .931 .92 r
.43285 .74348 m .43583 .74346 L .43467 .74123 L F
.43285 .74348 m .43467 .74123 L .43358 .7422 L F
.43285 .74348 m .43311 .74449 L .43583 .74346 L F
.597 .664 .886 r
.43045 .74324 m .43054 .74544 L .43285 .74348 L F
.518 .136 .256 r
.43304 .74306 m .43327 .74426 L .43188 .74372 L F
.597 .664 .886 r
.42902 .74309 m .43285 .74348 L .43022 .74308 L F
.799 .931 .92 r
.43358 .7422 m .43467 .74123 L .43442 .74074 L F
.601 .341 .495 r
.43478 .74208 m .43285 .74348 L .43442 .74074 L F
.518 .136 .256 r
.43478 .74208 m .43022 .74308 L .43285 .74348 L F
.43337 .74239 m .43188 .74372 L .43022 .74308 L F
.43478 .74208 m .43188 .74372 L .43337 .74239 L F
.326 .405 .79 r
.43051 .74278 m .43327 .74426 L .43188 .74138 L F
.43022 .74308 m .43046 .74317 L .43051 .74278 L F
.43046 .74317 m .43327 .74426 L .43051 .74278 L F
.597 .664 .886 r
.43001 .74319 m .43029 .74439 L .43045 .74324 L F
.43029 .74439 m .43054 .74544 L .43045 .74324 L F
.42902 .74309 m .42911 .74323 L .43001 .74319 L F
.42911 .74323 m .43054 .74544 L .43001 .74319 L F
.518 .136 .256 r
.43478 .74208 m .43413 .74302 L .43304 .74306 L F
.43413 .74302 m .43327 .74426 L .43304 .74306 L F
.741 .226 0 r
.4382 .74304 m .43442 .74074 L .43583 .74346 L F
.196 .21 .648 r
.43583 .74346 m .43761 .74559 L .4382 .74304 L F
.43583 .74346 m .43634 .74669 L .43761 .74559 L F
.778 .599 .656 r
.43484 .74728 m .43687 .74912 L .43634 .74669 L F
0 .029 .56 r
.43634 .74669 m .43765 .74796 L .43761 .74559 L F
.43634 .74669 m .43687 .74912 L .43765 .74796 L F
.415 .4 .734 r
.35679 .67918 m .35468 .67833 L .35644 .67647 L F
.35679 .67918 m .35558 .68014 L .35468 .67833 L F
.69 .609 .761 r
.43484 .74728 m .43454 .74971 L .43687 .74912 L F
.533 .586 .854 r
.43454 .74971 m .43717 .75078 L .43687 .74912 L F
.896 .961 .828 r
.57055 .82872 m .57169 .82567 L .57278 .82647 L F
.57055 .82872 m .56964 .8283 L .57169 .82567 L F
.534 .565 .833 r
.43094 .72701 m .4301 .72988 L .42895 .7273 L F
.43094 .72701 m .43212 .72974 L .4301 .72988 L F
.522 .29 .505 r
.40346 .77307 m .4055 .77275 L .40576 .77055 L F
.6 .358 .522 r
.4055 .77275 m .40787 .77019 L .40576 .77055 L F
.798 .827 .874 r
.71479 .71678 m .71172 .71707 L .71351 .71575 L F
.589 .555 .785 r
.71641 .71328 m .71479 .71678 L .71351 .71575 L F
.71641 .71328 m .71753 .71645 L .71479 .71678 L F
.386 .799 .978 r
.42184 .72701 m .42542 .72686 L .42701 .72739 L F
.356 .746 .986 r
.42752 .72654 m .42701 .72739 L .42542 .72686 L F
.42752 .72654 m .42895 .7273 L .42701 .72739 L F
.596 .065 0 r
.49143 .8625 m .48863 .86207 L .48933 .86205 L F
.566 .616 .862 r
.33965 .66397 m .33898 .66689 L .3376 .66452 L F
.33965 .66397 m .34094 .66652 L .33898 .66689 L F
.725 .194 0 r
.49736 .84562 m .49709 .84474 L .49559 .84488 L F
.371 .204 .521 r
.55582 .7862 m .55582 .78916 L .55521 .78848 L F
.563 .354 .555 r
.55798 .78852 m .55582 .7862 L .55817 .78567 L F
.55798 .78852 m .55582 .78916 L .55582 .7862 L F
.141 0 0 r
.38321 .75074 m .38232 .75056 L .38457 .74943 L F
.458 0 .075 r
.3867 .74945 m .38321 .75074 L .38457 .74943 L F
.489 .249 .477 r
.65047 .7229 m .64983 .72513 L .64765 .72556 L F
.387 .395 .746 r
.65124 .72178 m .65047 .7229 L .65035 .72097 L F
0 0 0 r
.65077 .72275 m .65047 .7229 L .65124 .72178 L F
.65077 .72275 m .64983 .72513 L .65047 .7229 L F
.243 .714 .942 r
.40058 .72336 m .40268 .72329 L .40389 .72384 L F
.185 .693 .902 r
.40268 .72329 m .4062 .72371 L .40389 .72384 L F
.038 .1 .599 r
.50384 .86232 m .50287 .86333 L .5026 .86038 L F
.044 0 .405 r
.50391 .86532 m .50287 .86333 L .50384 .86232 L F
.50391 .86532 m .50253 .86626 L .50287 .86333 L F
.696 .588 .731 r
.70483 .72145 m .70178 .72012 L .70401 .71966 L F
.496 .9 .925 r
.3632 .79106 m .36408 .79025 L .36556 .78891 L F
.3632 .79106 m .36212 .79101 L .36408 .79025 L F
.621 .431 .605 r
.70483 .72145 m .70735 .72281 L .70725 .72026 L F
.588 .455 .667 r
.70735 .72281 m .70493 .72486 L .70483 .72145 L F
.495 .317 .568 r
.45823 .87086 m .46006 .87336 L .46014 .87083 L F
.45 .305 .591 r
.45832 .87315 m .46006 .87336 L .45823 .87086 L F
.805 .658 .7 r
.54504 .84815 m .54176 .84945 L .54404 .84765 L F
.519 .793 .995 r
.64765 .72556 m .64983 .72513 L .64644 .72454 L F
.804 .605 .633 r
.57615 .79981 m .57584 .80213 L .57387 .79929 L F
.882 .869 .427 r
.68694 .72568 m .68647 .72708 L .68646 .72672 L F
.674 .125 0 r
.68834 .72689 m .68643 .72579 L .68646 .72672 L F
.68643 .72579 m .68459 .72473 L .68646 .72672 L F
.882 .869 .427 r
.68647 .72708 m .68618 .72794 L .68646 .72672 L F
.576 .35 .536 r
.4533 .75983 m .45325 .76173 L .45115 .76143 L F
.586 .358 .537 r
.4533 .75983 m .45534 .76182 L .45325 .76173 L F
.631 .353 .479 r
.45559 .7599 m .45534 .76182 L .4533 .75983 L F
.816 .524 .495 r
.54668 .80948 m .54845 .80992 L .54939 .80824 L F
.836 .551 .506 r
.54845 .80992 m .55051 .81118 L .54939 .80824 L F
0 0 0 r
.51031 .88662 m .51387 .88525 L .51215 .88573 L F
.51387 .88525 m .51423 .88532 L .51215 .88573 L F
.51387 .88525 m .51618 .8848 L .51423 .88532 L F
.834 .758 .779 r
.64415 .60543 m .64612 .60695 L .64461 .60581 L F
.64415 .60543 m .64491 .6026 L .64612 .60695 L F
.804 .743 .795 r
.64491 .6026 m .64802 .60273 L .64612 .60695 L F
.945 .858 .724 r
.68845 .73939 m .68766 .73763 L .68905 .73847 L F
.68845 .73939 m .68628 .74063 L .68766 .73763 L F
.781 .533 .562 r
.68845 .73939 m .68584 .74268 L .68628 .74063 L F
.68845 .73939 m .68756 .74343 L .68584 .74268 L F
.49 .608 .897 r
.32974 .65775 m .32879 .65964 L .32793 .65755 L F
.32974 .65775 m .33131 .66011 L .32879 .65964 L F
0 .108 .658 r
.42773 .74145 m .42552 .74134 L .42725 .74112 L F
.017 .193 .703 r
.42725 .74112 m .42902 .74309 L .42773 .74145 L F
.47 .521 .828 r
.455 .74865 m .45432 .75155 L .45284 .7492 L F
.455 .74865 m .45624 .75212 L .45432 .75155 L F
.404 0 .028 r
.52596 .81731 m .5281 .81732 L .52901 .81621 L F
.649 .206 .184 r
.5281 .81732 m .53134 .8177 L .52901 .81621 L F
.98 .86 .648 r
.58159 .79393 m .58369 .79115 L .58227 .79051 L F
.58159 .79393 m .58252 .79438 L .58369 .79115 L F
.565 .298 .47 r
.45325 .76173 m .45015 .76455 L .45115 .76143 L F
.741 .992 .855 r
.67804 .71888 m .68062 .71728 L .67908 .71703 L F
.803 .427 .343 r
.67804 .71888 m .67908 .71703 L .67634 .71668 L F
.583 .898 .986 r
.49502 .86823 m .4966 .86889 L .49361 .86921 L F
.521 .274 .481 r
.4966 .86889 m .49425 .87085 L .49361 .86921 L F
.4966 .86889 m .4963 .87102 L .49425 .87085 L F
.933 .911 .775 r
.49798 .86588 m .4966 .86889 L .49502 .86823 L F
.437 .202 .458 r
.49845 .86864 m .4963 .87102 L .4966 .86889 L F
.539 .908 .957 r
.47112 .88193 m .47445 .88128 L .4733 .88139 L F
.47112 .88193 m .47206 .88191 L .47445 .88128 L F
.043 0 0 r
.47701 .88124 m .4733 .88139 L .47445 .88128 L F
.297 0 0 r
.55845 .82324 m .56074 .82344 L .5617 .82343 L F
.905 .777 .709 r
.68983 .73642 m .68766 .73763 L .6882 .73547 L F
.68983 .73642 m .68905 .73847 L .68766 .73763 L F
.579 .368 .559 r
.43588 .75708 m .43812 .75685 L .43828 .75455 L F
.565 .509 .752 r
.43777 .75246 m .43828 .75455 L .44038 .75411 L F
.542 .352 .572 r
.43812 .75685 m .44038 .75411 L .43828 .75455 L F
.222 .649 .955 r
.31187 .65506 m .31161 .65574 L .31022 .65436 L F
.31187 .65506 m .31307 .6559 L .31161 .65574 L F
.214 0 .345 r
.47712 .85129 m .47551 .8504 L .47661 .84848 L F
.519 .503 .778 r
.44954 .73524 m .45059 .73845 L .4486 .73863 L F
.611 .473 .669 r
.45121 .74036 m .4486 .73863 L .45059 .73845 L F
.45121 .74036 m .4488 .74086 L .4486 .73863 L F
.463 .23 .474 r
.3546 .67413 m .35624 .67431 L .35654 .67227 L F
.739 .375 .363 r
.3546 .67413 m .35644 .67647 L .35624 .67431 L F
.3546 .67413 m .35273 .67627 L .35644 .67647 L F
.742 .487 .545 r
.63546 .64573 m .63209 .64772 L .63196 .64551 L F
.63546 .64573 m .63554 .64793 L .63209 .64772 L F
0 0 0 r
.36556 .78891 m .36592 .78938 L .36739 .78806 L F
.36556 .78891 m .36408 .79025 L .36592 .78938 L F
.326 .55 .914 r
.57122 .84175 m .57212 .84227 L .57077 .84212 L F
.479 .568 .868 r
.5678 .83952 m .57212 .84227 L .56931 .83896 L F
.56753 .83962 m .57122 .84175 L .5678 .83952 L F
.57122 .84175 m .57212 .84227 L .5678 .83952 L F
.191 .433 .863 r
.56931 .83896 m .57212 .84227 L .57192 .84117 L F
.326 .55 .914 r
.57192 .84117 m .57212 .84227 L .57122 .84175 L F
.32 .539 .908 r
.57122 .84175 m .57229 .84228 L .57192 .84117 L F
.319 .556 .92 r
.57077 .84212 m .57212 .84227 L .57159 .842 L F
.32 .539 .908 r
.57077 .84212 m .57159 .842 L .57122 .84175 L F
.319 .556 .92 r
.57077 .84212 m .57159 .842 L .56727 .83972 L F
.32 .539 .908 r
.57077 .84212 m .57197 .84224 L .57159 .842 L F
.57197 .84224 m .57229 .84228 L .57122 .84175 L F
.479 .568 .868 r
.56727 .83972 m .57212 .84227 L .56753 .83962 L F
.453 .865 .954 r
.5662 .82596 m .56817 .82552 L .56729 .82619 L F
.587 .341 .51 r
.56817 .82552 m .5662 .82596 L .56729 .82619 L F
.49 .545 .84 r
.33668 .66259 m .33559 .66448 L .33433 .6621 L F
.33668 .66259 m .3376 .66452 L .33559 .66448 L F
.585 .41 .612 r
.5267 .8553 m .52862 .85529 L .52894 .85267 L F
.149 .346 .804 r
.50693 .87955 m .50923 .88151 L .50931 .87923 L F
.21 0 0 r
.39639 .74342 m .39311 .74378 L .39444 .74338 L F
.52 .882 .98 r
.3584 .79275 m .35439 .7931 L .35693 .79213 L F
.652 .896 .982 r
.36024 .79188 m .3584 .79275 L .35693 .79213 L F
.27 .423 .832 r
.65676 .60608 m .6581 .60894 L .65902 .60724 L F
.547 .772 .982 r
.65902 .60724 m .6581 .60894 L .66045 .6085 L F
.458 .542 .854 r
.33314 .66013 m .33231 .66229 L .33131 .66011 L F
.536 .629 .891 r
.33314 .66013 m .33433 .6621 L .33231 .66229 L F
.594 .529 .752 r
.52447 .83117 m .52725 .83373 L .52589 .83085 L F
.426 .158 .402 r
.34225 .69563 m .34177 .69822 L .33975 .6978 L F
.404 .159 .425 r
.3412 .70018 m .33975 .6978 L .34177 .69822 L F
.3412 .70018 m .3394 .70077 L .33975 .6978 L F
.803 .79 .841 r
.52862 .85529 m .53124 .85447 L .53193 .85337 L F
.799 .724 .782 r
.52822 .85781 m .53124 .85447 L .52862 .85529 L F
.799 .655 .704 r
.55689 .78306 m .56185 .78429 L .56057 .78066 L F
.529 0 0 r
.55934 .78424 m .56185 .78429 L .55689 .78306 L F
.275 .348 .757 r
.56057 .78066 m .56185 .78429 L .5628 .78268 L F
.577 .218 .324 r
.55934 .78424 m .5628 .78268 L .56185 .78429 L F
.982 .895 .655 r
.67469 .71055 m .67308 .71158 L .6744 .7124 L F
.961 .637 .245 r
.6752 .70601 m .67673 .7097 L .67469 .71055 L F
.717 .824 .932 r
.67673 .7097 m .67384 .70953 L .67469 .71055 L F
.259 .055 .401 r
.48311 .83074 m .48226 .83366 L .48383 .83051 L F
0 .119 .67 r
.67126 .72995 m .66979 .72715 L .67079 .72788 L F
.53 .772 .986 r
.67501 .73799 m .67811 .73858 L .6771 .73759 L F
.187 0 0 r
.68019 .73587 m .6771 .73759 L .67811 .73858 L F
.739 .307 .225 r
.48148 .87332 m .48174 .87541 L .4799 .87321 L F
.48148 .87332 m .48274 .8744 L .48174 .87541 L F
.981 .797 .583 r
.70165 .7068 m .70066 .7071 L .70118 .70459 L F
.975 .758 .546 r
.70165 .7068 m .69981 .70805 L .70066 .7071 L F
.449 .239 .5 r
.70374 .70406 m .70314 .70671 L .70165 .7068 L F
.191 0 0 r
.70409 .7069 m .70165 .7068 L .70314 .70671 L F
.554 .426 .661 r
.68765 .71981 m .68571 .72262 L .68522 .72028 L F
.68765 .71981 m .68789 .72215 L .68571 .72262 L F
.364 0 .134 r
.67074 .70624 m .6733 .70405 L .6712 .70677 L F
.821 .949 .599 r
.66999 .70793 m .6712 .70677 L .66951 .70957 L F
.563 .391 .606 r
.66999 .70793 m .67125 .70857 L .6715 .70643 L F
.364 0 .134 r
.67074 .70624 m .67157 .70642 L .67221 .70554 L F
.67115 .70588 m .67221 .70554 L .6733 .70405 L F
.67074 .70624 m .67221 .70554 L .67115 .70588 L F
.67157 .70642 m .67283 .70612 L .6733 .70405 L F
0 0 0 r
.6733 .70405 m .67302 .70528 L .67448 .70214 L F
.364 0 .134 r
.67157 .70642 m .67225 .70657 L .67283 .70612 L F
.67225 .70657 m .67271 .70665 L .67283 .70612 L F
.341 .203 .544 r
.67171 .70471 m .67225 .70657 L .67074 .70624 L F
.597 .205 .27 r
.67244 .70721 m .67171 .70471 L .67201 .70812 L F
0 0 0 r
.67302 .70528 m .67271 .70665 L .67312 .7056 L F
0 0 .125 r
.67719 .7029 m .6752 .70601 L .67584 .70383 L F
.597 .205 .27 r
.67373 .70601 m .67617 .70448 L .67338 .70463 L F
.67396 .70696 m .67441 .70646 L .67373 .70601 L F
.67441 .70646 m .67617 .70448 L .67373 .70601 L F
0 0 0 r
.67338 .70463 m .67312 .7056 L .6738 .70388 L F
.67302 .70528 m .67312 .7056 L .67338 .70463 L F
.67271 .70665 m .67272 .70661 L .6738 .70388 L F
.597 .205 .27 r
.67301 .70601 m .67338 .70463 L .67171 .70471 L F
0 0 0 r
.67302 .70528 m .6738 .70388 L .6742 .70285 L F
.67415 .70285 m .6742 .70285 L .67448 .70214 L F
.67302 .70528 m .6742 .70285 L .67415 .70285 L F
0 0 .125 r
.67719 .7029 m .67681 .70479 L .6752 .70601 L F
0 .189 .671 r
.67445 .70287 m .67617 .70448 L .67681 .70479 L F
.685 .732 .886 r
.67171 .70471 m .67448 .70214 L .6738 .70388 L F
.67171 .70471 m .67338 .70463 L .67341 .70404 L F
.67171 .70471 m .67349 .70209 L .67448 .70214 L F
.67338 .70463 m .67424 .70308 L .67349 .70209 L F
.67171 .70471 m .6738 .70388 L .67311 .70562 L F
.67171 .70471 m .67341 .70404 L .67349 .70209 L F
0 .189 .671 r
.67349 .70209 m .67436 .70286 L .67445 .70287 L F
.67436 .70286 m .67617 .70448 L .67445 .70287 L F
.685 .732 .886 r
.67171 .70471 m .67311 .70562 L .67272 .70661 L F
.597 .205 .27 r
.67396 .70696 m .67338 .70463 L .67301 .70601 L F
.67272 .70661 m .67171 .70471 L .67244 .70721 L F
.67396 .70696 m .67301 .70601 L .67201 .70812 L F
0 0 0 r
.67271 .70665 m .6727 .70666 L .67272 .70661 L F
.685 .732 .886 r
.67171 .70471 m .67272 .70661 L .6727 .70666 L F
.597 .205 .27 r
.67301 .70601 m .67171 .70471 L .67272 .70661 L F
.364 0 .134 r
.67225 .70657 m .6727 .70666 L .67271 .70665 L F
.341 .203 .544 r
.67171 .70471 m .6727 .70666 L .67225 .70657 L F
.597 .205 .27 r
.67201 .70812 m .67187 .7065 L .67125 .70857 L F
.67187 .7065 m .67171 .70471 L .6715 .70643 L F
.67187 .7065 m .6715 .70643 L .67125 .70857 L F
.685 .732 .886 r
.67338 .70463 m .67534 .70452 L .67424 .70308 L F
.67534 .70452 m .67617 .70448 L .67599 .70431 L F
.67534 .70452 m .67599 .70431 L .67349 .70209 L F
.563 .391 .606 r
.67069 .70663 m .6715 .70643 L .67171 .70471 L F
.969 .92 .588 r
.66999 .70793 m .67074 .70624 L .6712 .70677 L F
.563 .391 .606 r
.66999 .70793 m .6715 .70643 L .67069 .70663 L F
.728 .79 .306 r
.66886 .71125 m .66951 .70957 L .66882 .71142 L F
.66886 .71125 m .66999 .70793 L .66951 .70957 L F
.807 .688 .733 r
.54276 .85505 m .5438 .85803 L .54087 .85811 L F
.783 .792 .86 r
.54087 .85811 m .5438 .85803 L .54149 .85889 L F
.787 .465 0 r
.54356 .85773 m .5438 .85803 L .54276 .85505 L F
.9 .87 .431 r
.54285 .85997 m .5438 .85803 L .54356 .85773 L F
.473 .052 .159 r
.42392 .74178 m .42011 .74338 L .42165 .74186 L F
.645 .668 .857 r
.68634 .71874 m .68522 .72028 L .68436 .71919 L F
.68634 .71874 m .68765 .71981 L .68522 .72028 L F
.397 .177 .459 r
.34618 .69249 m .344 .69475 L .34439 .6932 L F
.742 .422 .441 r
.53012 .87338 m .52949 .87168 L .52697 .87209 L F
.87 .476 .287 r
.48513 .88216 m .48218 .87915 L .4841 .88152 L F
0 .431 .733 r
.48649 .88307 m .48646 .883 L .48508 .88286 L F
.48752 .88322 m .48851 .88359 L .48765 .88334 L F
.48752 .88322 m .48765 .88334 L .48646 .883 L F
.384 0 0 r
.48646 .883 m .48833 .88408 L .48642 .88293 L F
.283 .693 .972 r
.48851 .88359 m .48833 .88408 L .48646 .883 L F
0 .431 .733 r
.48752 .88322 m .48646 .883 L .48649 .88307 L F
.597 .03 0 r
.48508 .88286 m .48646 .883 L .4841 .88152 L F
.48508 .88286 m .4841 .88152 L .48409 .88061 L F
0 0 .487 r
.48409 .88061 m .48316 .87838 L .48495 .87845 L F
.774 .847 .393 r
.48495 .87845 m .48407 .88006 L .48409 .88061 L F
0 0 .354 r
.48407 .88006 m .48508 .88286 L .48409 .88061 L F
.163 .259 .716 r
.48316 .87838 m .4841 .88152 L .48218 .87915 L F
.946 .743 .597 r
.48407 .88006 m .48365 .8825 L .48508 .88286 L F
.48407 .88006 m .48365 .8825 L .48508 .88286 L F
.706 .306 .288 r
.48365 .8825 m .48752 .88322 L .48508 .88286 L F
.48365 .8825 m .48588 .88452 L .48752 .88322 L F
.604 .908 .638 r
.48752 .88322 m .48588 .88452 L .4874 .8831 L F
.964 .896 .71 r
.48832 .88135 m .48851 .88359 L .48752 .88322 L F
.604 .908 .638 r
.48752 .88322 m .48826 .88229 L .48832 .88135 L F
.48752 .88322 m .4874 .8831 L .48826 .88229 L F
.384 0 0 r
.48646 .883 m .48642 .88293 L .48513 .88216 L F
.795 .552 .569 r
.62893 .64031 m .63216 .64296 L .62895 .64273 L F
.776 .597 .656 r
.63216 .64296 m .6288 .64489 L .62895 .64273 L F
.63216 .64296 m .63196 .64551 L .6288 .64489 L F
.588 .311 .465 r
.6721 .63406 m .67148 .63686 L .66913 .63704 L F
.36 .106 .387 r
.6734 .63614 m .6721 .63406 L .67261 .6344 L F
.6734 .63614 m .67148 .63686 L .6721 .63406 L F
.25 .06 .416 r
.70534 .70549 m .70314 .70671 L .70374 .70406 L F
.70534 .70549 m .70374 .70406 L .70277 .70332 L F
.108 0 0 r
.3366 .74047 m .33818 .74065 L .33566 .74044 L F
0 0 0 r
.36779 .80443 m .37119 .80222 L .36952 .8036 L F
.158 0 0 r
.36952 .8036 m .37119 .80222 L .37316 .80173 L F
.609 .633 .849 r
.49361 .86921 m .49425 .87085 L .49272 .86827 L F
.299 .673 .974 r
.49425 .87085 m .49458 .87011 L .49249 .87272 L F
.49425 .87085 m .4963 .87102 L .49458 .87011 L F
.538 .748 .973 r
.32677 .65638 m .32601 .65789 L .32431 .65647 L F
.32677 .65638 m .32793 .65755 L .32601 .65789 L F
0 .573 .763 r
.37382 .75133 m .37235 .75113 L .3705 .75099 L F
.465 .873 .952 r
.37597 .75065 m .37235 .75113 L .37382 .75133 L F
.57 .614 .856 r
.48218 .87915 m .47811 .87676 L .48088 .87845 L F
.44 .778 .998 r
.48316 .87838 m .48218 .87915 L .48088 .87845 L F
.923 .964 .781 r
.52129 .88194 m .52321 .87904 L .52237 .87869 L F
.577 .639 .876 r
.68705 .75375 m .6882 .75125 L .68552 .7519 L F
.68705 .75375 m .68876 .75375 L .6882 .75125 L F
.983 .722 .45 r
.62679 .643 m .62577 .64444 L .62571 .64208 L F
.722 .937 .616 r
.62771 .64139 m .62679 .643 L .62571 .64208 L F
.62771 .64139 m .62893 .64031 L .62679 .643 L F
.77 .361 .276 r
.62679 .643 m .6288 .64489 L .62577 .64444 L F
.64 .488 .661 r
.62893 .64031 m .62895 .64273 L .62679 .643 L F
.627 .431 .597 r
.62895 .64273 m .6288 .64489 L .62679 .643 L F
.642 .178 .137 r
.48942 .87239 m .48877 .87168 L .48499 .87129 L F
.706 .41 .472 r
.48723 .87548 m .48942 .87239 L .4854 .87303 L F
.692 .876 .487 r
.48911 .87263 m .48942 .87239 L .48723 .87548 L F
.48951 .87203 m .48942 .87239 L .48911 .87263 L F
.665 .114 0 r
.4904 .87333 m .48945 .87237 L .48942 .87239 L F
.48945 .87237 m .48877 .87168 L .48942 .87239 L F
.79 .892 .477 r
.4904 .87333 m .49085 .87139 L .48877 .87168 L F
.353 .594 .937 r
.66847 .61076 m .6667 .61068 L .66522 .60875 L F
.441 .291 .58 r
.66847 .61076 m .66691 .61303 L .6667 .61068 L F
.975 .8 .602 r
.55065 .84156 m .55119 .84437 L .54987 .84179 L F
.679 .493 .628 r
.3393 .77039 m .33944 .77307 L .33805 .77286 L F
.485 .282 .528 r
.34161 .77022 m .33944 .77307 L .3393 .77039 L F
.376 .116 .386 r
.34347 .69762 m .34225 .69563 L .344 .69475 L F
.34347 .69762 m .34177 .69822 L .34225 .69563 L F
.101 .432 .873 r
.47811 .87676 m .47531 .8744 L .47735 .87628 L F
.2 .443 .868 r
.47971 .87624 m .47811 .87676 L .47735 .87628 L F
.47971 .87624 m .48088 .87845 L .47811 .87676 L F
.815 .583 .587 r
.52261 .87624 m .52557 .87634 L .52416 .8746 L F
.562 .544 .792 r
.52416 .8746 m .52557 .87634 L .52725 .87547 L F
.49 .337 .601 r
.52894 .85267 m .53077 .85196 L .53069 .84991 L F
.803 .79 .841 r
.52862 .85529 m .53077 .85196 L .52894 .85267 L F
.199 0 .244 r
.52697 .87209 m .52416 .8746 L .52676 .87322 L F
.562 .544 .792 r
.52416 .8746 m .52725 .87547 L .52676 .87322 L F
.459 .495 .809 r
.56626 .83679 m .56727 .83972 L .56931 .83896 L F
0 0 0 r
.65706 .62971 m .65862 .62863 L .6587 .62836 L F
.148 .013 .428 r
.65848 .63083 m .65706 .62971 L .65616 .63125 L F
.65848 .63083 m .65862 .62863 L .65706 .62971 L F
.466 0 0 r
.53653 .82716 m .53931 .82858 L .54014 .8288 L F
.929 .966 .761 r
.54014 .8288 m .53836 .83063 L .53931 .82858 L F
.621 .556 .76 r
.53979 .82644 m .54014 .8288 L .54246 .82831 L F
.588 .551 .78 r
.39217 .74903 m .39025 .74981 L .38921 .74625 L F
.632 .804 .965 r
.38874 .74867 m .39025 .74981 L .39217 .74903 L F
.358 0 .186 r
.35607 .7331 m .35682 .73471 L .3581 .73273 L F
.35607 .7331 m .3549 .73515 L .35682 .73471 L F
.187 0 0 r
.68019 .73587 m .67909 .73705 L .6771 .73759 L F
.238 .187 .596 r
.68144 .7325 m .68194 .73531 L .68019 .73587 L F
.431 .051 .217 r
.41358 .78169 m .41314 .78278 L .41101 .78307 L F
.511 .183 .348 r
.41643 .7802 m .41314 .78278 L .41358 .78169 L F
.766 .785 .869 r
.69662 .72066 m .69296 .72145 L .69536 .71941 L F
.702 .783 .914 r
.69856 .71972 m .69662 .72066 L .69536 .71941 L F
.484 .217 .434 r
.35634 .7597 m .35585 .76158 L .35373 .76187 L F
.484 .203 .412 r
.35839 .7594 m .35585 .76158 L .35634 .7597 L F
.839 .756 .771 r
.69874 .7353 m .69684 .73804 L .69949 .73817 L F
.853 .693 .683 r
.69649 .74033 m .69949 .73817 L .69684 .73804 L F
.69649 .74033 m .69815 .74096 L .69949 .73817 L F
.55 .414 .649 r
.3584 .66939 m .35893 .67194 L .35654 .67227 L F
.511 .271 .488 r
.35893 .67194 m .35624 .67431 L .35654 .67227 L F
.351 .135 .438 r
.35735 .67305 m .35654 .67227 L .35893 .67194 L F
.35735 .67305 m .35624 .67431 L .35654 .67227 L F
.55 .414 .649 r
.3584 .66939 m .35893 .67194 L .35654 .67227 L F
.351 .135 .438 r
.35654 .67227 m .35735 .67305 L .35893 .67194 L F
.35654 .67227 m .35624 .67431 L .35735 .67305 L F
.67 .971 .8 r
.57457 .82392 m .57434 .82364 L .57486 .82346 L F
.57457 .82392 m .57169 .82567 L .57434 .82364 L F
.9 .855 .789 r
.57457 .82392 m .57278 .82647 L .57169 .82567 L F
.589 .417 .616 r
.46066 .757 m .45895 .7587 L .45871 .75763 L F
.456 .254 .516 r
.46704 .84717 m .4688 .84695 L .46904 .84474 L F
.443 .296 .585 r
.46704 .84717 m .46885 .8493 L .4688 .84695 L F
.46704 .84717 m .46701 .84984 L .46885 .8493 L F
.685 .558 .705 r
.50023 .84986 m .49714 .84708 L .49917 .84672 L F
.50023 .84986 m .49797 .85015 L .49714 .84708 L F
.404 .121 .367 r
.38862 .7814 m .39011 .78251 L .39064 .7812 L F
.38862 .7814 m .38817 .78316 L .39011 .78251 L F
.185 .57 .937 r
.71284 .73323 m .71388 .73276 L .71214 .73222 L F
.71284 .73323 m .71514 .73398 L .71388 .73276 L F
.305 .415 .81 r
.5493 .78581 m .55064 .78948 L .55188 .78838 L F
.799 .617 .656 r
.55582 .78916 m .55539 .78935 L .55521 .78848 L F
.157 .337 .794 r
.55529 .78928 m .55535 .78943 L .55538 .78934 L F
.799 .617 .656 r
.55525 .78925 m .55367 .78972 L .5547 .78889 L F
.55529 .78928 m .55507 .78934 L .55525 .78925 L F
.55507 .78934 m .55367 .78972 L .55525 .78925 L F
.022 0 0 r
.55263 .79057 m .55535 .78943 L .55507 .78934 L F
.799 .617 .656 r
.55539 .78935 m .55263 .79057 L .55367 .78972 L F
.777 .694 .772 r
.55507 .78934 m .55535 .78943 L .55529 .78928 L F
.799 .617 .656 r
.55539 .78935 m .55367 .78972 L .55529 .78928 L F
.498 .088 .193 r
.55367 .78972 m .55064 .78948 L .55427 .78868 L F
.55367 .78972 m .55427 .78868 L .5547 .78889 L F
.55263 .79057 m .55211 .79029 L .55367 .78972 L F
.55211 .79029 m .55064 .78948 L .55367 .78972 L F
.022 0 0 r
.55263 .79057 m .55507 .78934 L .55188 .78838 L F
.777 .694 .772 r
.55488 .78928 m .55507 .78934 L .55523 .78916 L F
.55507 .78934 m .55529 .78928 L .55523 .78916 L F
.799 .617 .656 r
.55539 .78935 m .5547 .78889 L .55521 .78848 L F
.157 .337 .794 r
.55523 .78916 m .55529 .78928 L .55542 .78925 L F
.55529 .78928 m .55538 .78934 L .55542 .78925 L F
.55373 .78585 m .55523 .78916 L .55605 .78743 L F
.55523 .78916 m .55542 .78925 L .55605 .78743 L F
.498 .088 .193 r
.5547 .78889 m .55427 .78868 L .55521 .78848 L F
.777 .694 .772 r
.55188 .78838 m .55488 .78928 L .55373 .78585 L F
.55488 .78928 m .55523 .78916 L .55373 .78585 L F
.498 .088 .193 r
.55064 .78948 m .55263 .79057 L .55188 .78838 L F
.55064 .78948 m .55057 .79177 L .55263 .79057 L F
.55263 .79057 m .55057 .79177 L .55064 .78948 L F
.401 .194 .481 r
.32567 .6936 m .32688 .69522 L .32726 .693 L F
.32567 .6936 m .32527 .69572 L .32688 .69522 L F
.4 0 0 r
.56622 .7851 m .56409 .78459 L .56573 .78335 L F
.56622 .7851 m .5631 .78547 L .56409 .78459 L F
.298 0 .052 r
.64778 .6478 m .64851 .64895 L .6462 .64812 L F
.64778 .6478 m .64933 .64741 L .64851 .64895 L F
.174 .365 .813 r
.43687 .74912 m .4389 .75055 L .43765 .74796 L F
.486 .586 .879 r
.43717 .75078 m .4389 .75055 L .43687 .74912 L F
.298 .05 .359 r
.32685 .71703 m .32465 .71951 L .32493 .71729 L F
.549 .323 .525 r
.66461 .63747 m .66416 .64008 L .66196 .64062 L F
.588 .359 .536 r
.66695 .63918 m .66461 .63747 L .66695 .63722 L F
.66695 .63918 m .66416 .64008 L .66461 .63747 L F
0 0 0 r
.62893 .64031 m .63024 .63916 L .63126 .63823 L F
.62771 .64139 m .63024 .63916 L .62893 .64031 L F
.668 .636 .809 r
.55665 .81518 m .55964 .81607 L .55839 .81511 L F
.841 .833 .839 r
.55884 .81498 m .55964 .81607 L .56104 .81433 L F
.55839 .81511 m .56104 .81433 L .56064 .81474 L F
.94 .734 .261 r
.56073 .81243 m .56064 .81474 L .56104 .81433 L F
.471 .262 .514 r
.56266 .81213 m .56064 .81474 L .56072 .81285 L F
.56114 .81237 m .56072 .81285 L .56073 .81243 L F
.56266 .81213 m .56072 .81285 L .56114 .81237 L F
.841 .833 .839 r
.55839 .81511 m .55859 .81527 L .55884 .81498 L F
.55859 .81527 m .55964 .81607 L .55884 .81498 L F
.017 0 0 r
.3979 .79069 m .4012 .78847 L .39976 .79035 L F
.243 0 0 r
.40331 .7878 m .40262 .78875 L .4012 .78847 L F
.243 0 .064 r
.4012 .78847 m .40209 .7898 L .39976 .79035 L F
.4012 .78847 m .40262 .78875 L .40209 .7898 L F
.923 .964 .781 r
.52129 .88194 m .52237 .87869 L .52173 .88025 L F
.862 .976 .672 r
.52066 .88212 m .52129 .88194 L .52173 .88025 L F
.989 .869 .621 r
.64518 .61152 m .64473 .61351 L .64383 .61259 L F
.308 0 0 r
.64513 .61028 m .64758 .6095 L .64639 .60983 L F
.64758 .6095 m .64811 .60933 L .64639 .60983 L F
.344 .343 .715 r
.6455 .61007 m .64639 .60983 L .64585 .6085 L F
.64518 .61152 m .64639 .60983 L .6455 .61007 L F
.706 .946 .654 r
.64383 .61259 m .64639 .60983 L .64518 .61152 L F
.416 .709 .984 r
.41349 .72493 m .41239 .72598 L .41116 .72511 L F
.41349 .72493 m .41502 .72608 L .41239 .72598 L F
.627 .154 0 r
.36021 .8811 m .36055 .88156 L .36087 .88188 L F
.973 .928 .649 r
.36087 .88188 m .36055 .88156 L .36014 .88257 L F
.797 .4 .301 r
.56222 .78095 m .56573 .78335 L .56558 .781 L F
.767 .679 .766 r
.5822 .79666 m .58341 .79702 L .58252 .79438 L F
.829 .615 .613 r
.5822 .79666 m .58331 .79944 L .58341 .79702 L F
.589 .555 .784 r
.43717 .75078 m .43777 .75246 L .43957 .75184 L F
.565 .509 .752 r
.43777 .75246 m .44038 .75411 L .43957 .75184 L F
.782 .492 .497 r
.55279 .81296 m .55303 .81509 L .55665 .81518 L F
.801 .698 .752 r
.55303 .81509 m .55412 .81803 L .55665 .81518 L F
.598 .827 .987 r
.57605 .84402 m .57896 .84411 L .57821 .84341 L F
.524 .546 .82 r
.57896 .84411 m .58072 .84174 L .57821 .84341 L F
.57896 .84411 m .58207 .84356 L .58072 .84174 L F
.628 .465 .642 r
.65035 .72097 m .65219 .72103 L .65142 .71805 L F
.609 .453 .645 r
.65142 .71805 m .65419 .71983 L .65423 .71767 L F
.65142 .71805 m .65219 .72103 L .65419 .71983 L F
.672 .974 .814 r
.37363 .78664 m .37245 .78714 L .37297 .78672 L F
.37363 .78664 m .37297 .78672 L .37424 .7857 L F
.099 0 0 r
.37363 .78664 m .37528 .78649 L .37483 .78648 L F
.37363 .78664 m .37483 .78648 L .373 .78643 L F
.199 0 .118 r
.40083 .77529 m .4024 .77507 L .40346 .77307 L F
.435 .072 .248 r
.4024 .77507 m .4055 .77275 L .40346 .77307 L F
.978 .915 .659 r
.54917 .8339 m .54805 .83676 L .54895 .83638 L F
.98 .705 .318 r
.54861 .83879 m .54895 .83638 L .54805 .83676 L F
.54861 .83879 m .54925 .83955 L .54895 .83638 L F
.54 .369 .598 r
.70969 .72215 m .70725 .72026 L .70946 .7196 L F
.70969 .72215 m .70735 .72281 L .70725 .72026 L F
.679 .521 .665 r
.50023 .84986 m .49803 .85255 L .49797 .85015 L F
.547 .354 .571 r
.43371 .75975 m .43582 .75943 L .43588 .75708 L F
.519 .298 .518 r
.43582 .75943 m .43812 .75685 L .43588 .75708 L F
.646 .825 .969 r
.34713 .79404 m .34375 .79385 L .34577 .79313 L F
.699 .836 .949 r
.34924 .79302 m .34713 .79404 L .34577 .79313 L F
.716 .956 .676 r
.57486 .82346 m .57434 .82364 L .57547 .82231 L F
.435 .217 .482 r
.35039 .68893 m .34879 .68797 L .35058 .68736 L F
.35039 .68893 m .34843 .68991 L .34879 .68797 L F
.629 .385 .53 r
.44813 .76492 m .44571 .76695 L .44595 .76535 L F
.844 .622 .601 r
.55051 .81118 m .54957 .81241 L .55279 .81296 L F
.755 .472 .504 r
.54967 .81479 m .55279 .81296 L .54957 .81241 L F
.54967 .81479 m .55303 .81509 L .55279 .81296 L F
.511 .183 .348 r
.41643 .7802 m .41513 .78262 L .41314 .78278 L F
.368 .025 .247 r
.41875 .77939 m .41513 .78262 L .41643 .7802 L F
.406 .249 .554 r
.35679 .67918 m .35517 .68225 L .35558 .68014 L F
.716 .318 .292 r
.48707 .85518 m .48915 .85721 L .49036 .8555 L F
.756 .367 .318 r
.48915 .85721 m .49247 .8578 L .49036 .8555 L F
.432 .047 .206 r
.43056 .76178 m .43261 .76154 L .43371 .75975 L F
.486 .123 .275 r
.43261 .76154 m .43582 .75943 L .43371 .75975 L F
.495 .226 .437 r
.35487 .68422 m .35331 .68283 L .35517 .68225 L F
.35487 .68422 m .35294 .68466 L .35331 .68283 L F
.127 .076 .525 r
.32757 .69071 m .3284 .68749 L .32681 .68862 L F
.534 .497 .761 r
.3278 .6805 m .32893 .67716 L .32699 .67739 L F
.3278 .6805 m .32979 .68033 L .32893 .67716 L F
.576 .472 .698 r
.3278 .6805 m .3303 .68224 L .32979 .68033 L F
.3278 .6805 m .32824 .68265 L .3303 .68224 L F
.851 .55 .48 r
.57965 .78597 m .58264 .7885 L .58135 .78597 L F
.766 .69 .778 r
.69028 .74601 m .68756 .74983 L .68696 .74563 L F
.8 .465 .422 r
.53665 .81993 m .53961 .8204 L .53794 .8179 L F
.806 .465 .412 r
.53794 .8179 m .53961 .8204 L .5415 .82064 L F
.769 .356 .268 r
.68358 .71022 m .68513 .71013 L .68322 .71226 L F
0 0 0 r
.68513 .71013 m .68649 .70928 L .68739 .71009 L F
.68513 .71013 m .68467 .71087 L .68649 .70928 L F
.77 .277 0 r
.68558 .71235 m .68441 .7111 L .68322 .71226 L F
.68558 .71235 m .68513 .71281 L .68434 .71149 L F
.68441 .7111 m .68358 .71022 L .68325 .7121 L F
.769 .356 .268 r
.68358 .71022 m .6841 .71178 L .68436 .71137 L F
.77 .277 0 r
.68441 .7111 m .68436 .71137 L .68358 .71022 L F
.769 .356 .268 r
.68358 .71022 m .68436 .71137 L .68513 .71013 L F
.77 .277 0 r
.68436 .71137 m .68434 .71149 L .68358 .71022 L F
.68558 .71235 m .68434 .71149 L .68441 .7111 L F
0 0 0 r
.68467 .71087 m .68436 .71137 L .68641 .70937 L F
.68436 .71137 m .6841 .71178 L .68433 .71154 L F
0 0 .461 r
.68358 .71022 m .68434 .71149 L .68383 .71002 L F
.68434 .71149 m .68513 .71281 L .68455 .71156 L F
0 0 0 r
.68436 .71137 m .68434 .71149 L .68641 .70937 L F
.68434 .71149 m .68437 .7115 L .68641 .70937 L F
.68467 .71087 m .68641 .70937 L .68649 .70928 L F
.836 .819 .832 r
.68649 .70928 m .68437 .7115 L .68383 .71002 L F
0 0 .461 r
.68434 .71149 m .68437 .7115 L .68383 .71002 L F
0 0 0 r
.68434 .71149 m .68433 .71154 L .68437 .7115 L F
.836 .819 .832 r
.68437 .7115 m .6841 .71178 L .68383 .71002 L F
0 0 .461 r
.68437 .7115 m .68455 .71156 L .68383 .71002 L F
.77 .277 0 r
.68441 .7111 m .68325 .7121 L .68322 .71226 L F
.756 .528 .587 r
.67611 .70064 m .67749 .70092 L .67768 .69868 L F
.443 .209 .463 r
.3526 .68666 m .35101 .68532 L .35294 .68466 L F
.3526 .68666 m .35058 .68736 L .35101 .68532 L F
.488 .21 .418 r
.50764 .8529 m .51009 .85212 L .51074 .84872 L F
.734 .548 .64 r
.51009 .85212 m .51315 .84942 L .51074 .84872 L F
.365 .027 .252 r
.35489 .76339 m .35373 .76187 L .35585 .76158 L F
.35489 .76339 m .35283 .76405 L .35373 .76187 L F
.547 .222 .368 r
.43601 .77034 m .43503 .77256 L .43282 .77268 L F
.501 .175 .345 r
.43746 .77207 m .43601 .77034 L .43817 .77019 L F
.43746 .77207 m .43503 .77256 L .43601 .77034 L F
.469 .246 .493 r
.3479 .69145 m .34661 .69043 L .34843 .68991 L F
.3479 .69145 m .34618 .69249 L .34661 .69043 L F
.566 .222 .346 r
.42608 .77544 m .42512 .77759 L .42289 .77773 L F
.416 .073 .272 r
.42715 .77718 m .42608 .77544 L .4282 .77517 L F
.42715 .77718 m .42512 .77759 L .42608 .77544 L F
.561 .364 .57 r
.64312 .7312 m .64541 .73032 L .64597 .72801 L F
0 0 .216 r
.66019 .71474 m .6604 .71574 L .66047 .71373 L F
.66019 .71474 m .65974 .71723 L .6604 .71574 L F
.812 .679 .717 r
.58307 .80183 m .58407 .80491 L .58485 .80262 L F
.777 .701 .779 r
.69914 .73313 m .7019 .73376 L .70096 .73236 L F
.844 .867 .859 r
.69874 .7353 m .7019 .73376 L .69914 .73313 L F
.639 .655 .85 r
.70096 .73236 m .7019 .73376 L .70418 .73317 L F
.627 .381 .526 r
.40787 .77019 m .41053 .77172 L .41105 .77069 L F
.396 0 .129 r
.41053 .77172 m .41253 .77148 L .41105 .77069 L F
.424 0 .042 r
.41105 .77069 m .41253 .77148 L .41333 .77061 L F
0 0 0 r
.71829 .73317 m .71667 .73369 L .71514 .73398 L F
.346 .099 .39 r
.7199 .73234 m .71829 .73317 L .7206 .73052 L F
.384 .838 .754 r
.71992 .73228 m .71829 .73317 L .7199 .73234 L F
.71992 .73228 m .71667 .73369 L .71829 .73317 L F
0 0 0 r
.3705 .75099 m .36745 .75361 L .36832 .75136 L F
.803 .7 .751 r
.57004 .78892 m .56685 .78908 L .56939 .78581 L F
.804 .689 .738 r
.57004 .78892 m .56839 .79098 L .56685 .78908 L F
.009 0 0 r
.39527 .72346 m .39576 .72375 L .39715 .72312 L F
.39527 .72346 m .39372 .72421 L .39576 .72375 L F
.933 .911 .775 r
.49798 .86588 m .49502 .86823 L .49743 .86745 L F
.98 .7 .319 r
.49798 .86588 m .49743 .86745 L .49717 .86527 L F
.589 .475 .692 r
.45157 .7434 m .4488 .74086 L .45121 .74036 L F
.45157 .7434 m .4494 .7439 L .4488 .74086 L F
.355 0 0 r
.4179 .72786 m .42013 .72773 L .42083 .72701 L F
.184 0 0 r
.42083 .72701 m .42205 .72725 L .42184 .72701 L F
.42083 .72701 m .42013 .72773 L .42205 .72725 L F
.658 .722 .896 r
.70418 .73317 m .7078 .7342 L .70644 .73247 L F
.676 .719 .881 r
.70644 .73247 m .7078 .7342 L .70966 .73311 L F
.932 .559 .265 r
.54502 .80644 m .54668 .80948 L .54621 .80768 L F
.258 .496 .893 r
.44855 .7337 m .4474 .73438 L .44628 .73361 L F
.44855 .7337 m .44954 .73524 L .4474 .73438 L F
.551 .51 .764 r
.47736 .87366 m .47531 .8744 L .47432 .87069 L F
.505 .381 .645 r
.47736 .87366 m .47735 .87628 L .47531 .8744 L F
.712 .386 .425 r
.57549 .81604 m .57319 .81808 L .57451 .81476 L F
.57549 .81604 m .57701 .81783 L .57319 .81808 L F
.627 .545 .742 r
.57549 .81604 m .57853 .81547 L .57759 .81625 L F
.634 .386 .526 r
.57759 .81625 m .57701 .81783 L .57549 .81604 L F
.627 .545 .742 r
.57549 .81604 m .57853 .81547 L .57759 .81625 L F
.659 .46 .604 r
.53861 .83621 m .54123 .83637 L .54124 .83406 L F
.618 .464 .651 r
.54124 .83406 m .54381 .83383 L .54299 .83176 L F
.591 .393 .582 r
.54123 .83637 m .54381 .83383 L .54124 .83406 L F
.709 .689 .829 r
.59063 .84306 m .59241 .84218 L .58939 .84152 L F
.108 0 0 r
.3366 .74047 m .33749 .74059 L .33818 .74065 L F
.6 .358 .522 r
.4055 .77275 m .40771 .77282 L .40787 .77019 L F
.627 .381 .526 r
.40787 .77019 m .40771 .77282 L .41053 .77172 L F
.541 .335 .551 r
.33805 .77286 m .33687 .77531 L .33696 .77297 L F
.469 0 0 r
.4921 .88918 m .49495 .88998 L .4942 .89005 L F
.261 .769 .781 r
.49334 .89013 m .4942 .89005 L .49623 .88951 L F
.534 0 0 r
.4921 .88918 m .4942 .89005 L .49277 .89026 L F
.261 .769 .781 r
.49277 .89026 m .4942 .89005 L .49334 .89013 L F
.469 0 0 r
.49495 .88998 m .49529 .89007 L .4942 .89005 L F
.322 .788 .936 r
.49529 .89007 m .49623 .88951 L .4942 .89005 L F
.49529 .89007 m .4974 .8898 L .49623 .88951 L F
.839 .564 .522 r
.54482 .82315 m .54489 .8258 L .54771 .82607 L F
.858 .644 .612 r
.54489 .8258 m .54741 .8284 L .54771 .82607 L F
.641 .813 .966 r
.35439 .7931 m .35253 .79386 L .3511 .79293 L F
.583 .848 .499 r
.70626 .71516 m .70742 .71369 L .70836 .71401 L F
.70626 .71516 m .70524 .71627 L .70742 .71369 L F
.402 .271 .586 r
.47047 .84199 m .46904 .84474 L .47057 .84418 L F
.359 .173 .487 r
.46904 .84474 m .4688 .84695 L .47057 .84418 L F
.674 .793 .938 r
.31562 .65503 m .31697 .65621 L .31358 .65588 L F
.574 .761 .967 r
.31784 .65461 m .31697 .65621 L .31562 .65503 L F
.504 .674 .941 r
.31784 .65461 m .31891 .65606 L .31697 .65621 L F
0 0 0 r
.37511 .80131 m .37865 .79915 L .37708 .80061 L F
.231 0 0 r
.3806 .79887 m .37708 .80061 L .37865 .79915 L F
.127 .076 .525 r
.32757 .69071 m .32835 .69023 L .3284 .68749 L F
.339 .166 .495 r
.32757 .69071 m .32865 .69243 L .32835 .69023 L F
.32757 .69071 m .32726 .693 L .32865 .69243 L F
.566 .352 .549 r
.46289 .75433 m .46291 .75671 L .46066 .757 L F
.581 .6 .837 r
.46282 .75184 m .46289 .75433 L .46169 .7517 L F
.46282 .75184 m .465 .75406 L .46289 .75433 L F
.655 .422 .555 r
.46517 .75647 m .46289 .75433 L .465 .75406 L F
.46517 .75647 m .46291 .75671 L .46289 .75433 L F
.601 .293 .419 r
.33207 .74331 m .33419 .74332 L .3366 .74047 L F
.499 .168 .337 r
.3366 .74047 m .33663 .74281 L .33749 .74059 L F
.3366 .74047 m .33419 .74332 L .33663 .74281 L F
.799 .655 .704 r
.55689 .78306 m .56057 .78066 L .55694 .78113 L F
.798 .834 .879 r
.5585 .82792 m .56219 .82664 L .56079 .82564 L F
.423 .343 .662 r
.46408 .86099 m .46573 .86239 L .46592 .86048 L F
.46408 .86099 m .4643 .86313 L .46573 .86239 L F
.803 .79 .841 r
.52862 .85529 m .53193 .85337 L .53077 .85196 L F
.732 .701 .821 r
.53193 .85337 m .53394 .85222 L .53077 .85196 L F
.506 .695 .954 r
.68349 .72639 m .68459 .72473 L .68236 .72523 L F
.385 .844 .789 r
.34351 .73894 m .34187 .73934 L .34522 .73822 L F
.426 .696 .977 r
.39972 .74392 m .40048 .74275 L .39843 .74312 L F
.39972 .74392 m .40183 .74395 L .40048 .74275 L F
.468 .59 .892 r
.43925 .73046 m .43878 .73254 L .43737 .73033 L F
.43925 .73046 m .44081 .73272 L .43878 .73254 L F
.591 .401 .592 r
.50023 .84986 m .50026 .85233 L .49803 .85255 L F
.63 .596 .797 r
.50279 .84901 m .50023 .84986 L .49917 .84672 L F
.647 .787 .949 r
.50279 .84901 m .50269 .84949 L .50023 .84986 L F
.61 .394 .564 r
.50269 .84949 m .50026 .85233 L .50023 .84986 L F
.885 .99 .79 r
.59644 .84079 m .59807 .83982 L .5985 .83816 L F
.773 .731 .814 r
.57387 .79929 m .57343 .79625 L .57453 .79686 L F
.982 .733 .48 r
.57453 .79686 m .57343 .79625 L .57344 .79387 L F
.961 .651 .242 r
.64383 .61259 m .64473 .61351 L .64548 .61688 L F
.744 .544 .625 r
.64473 .61351 m .64674 .6163 L .64548 .61688 L F
.789 .924 .926 r
.54149 .85889 m .53818 .86074 L .54087 .85811 L F
0 0 0 r
.7206 .72841 m .7199 .73234 L .7206 .73052 L F
.754 .418 .416 r
.48373 .88403 m .48205 .88455 L .47935 .88248 L F
.714 .293 .246 r
.48499 .88503 m .48205 .88455 L .48373 .88403 L F
.658 .485 .638 r
.49453 .87654 m .49475 .87949 L .49716 .8764 L F
.509 .206 .388 r
.45895 .7587 m .45534 .76182 L .45559 .7599 L F
0 0 0 r
.3478 .81198 m .35096 .81077 L .3489 .81158 L F
.492 .896 .769 r
.3489 .81158 m .35096 .81077 L .35261 .80978 L F
.947 .595 .296 r
.55826 .82663 m .5585 .82792 L .55846 .82608 L F
.764 .369 .306 r
.51265 .88132 m .50931 .87923 L .50923 .88151 L F
.875 .672 .624 r
.60169 .82893 m .60001 .82585 L .5999 .82825 L F
.883 .706 .657 r
.5999 .82825 m .6012 .83122 L .60169 .82893 L F
.686 .415 .506 r
.56216 .83356 m .56484 .83161 L .56285 .83041 L F
.56216 .83356 m .56517 .83364 L .56484 .83161 L F
.096 0 0 r
.37528 .78649 m .37767 .78616 L .37827 .78581 L F
.278 .764 .677 r
.37827 .78581 m .37931 .78536 L .38036 .78497 L F
0 0 0 r
.37827 .78581 m .37767 .78616 L .37931 .78536 L F
.33 .113 .425 r
.46232 .86588 m .46374 .86554 L .4643 .86313 L F
.396 .309 .64 r
.46232 .86588 m .46421 .86799 L .46374 .86554 L F
.395 .309 .64 r
.46272 .8684 m .46421 .86799 L .46232 .86588 L F
.645 .46 .619 r
.5689 .7836 m .56939 .78581 L .57102 .78385 L F
.755 .935 .589 r
.63126 .63823 m .6322 .63636 L .63331 .6372 L F
.63126 .63823 m .63024 .63916 L .6322 .63636 L F
.688 .869 .967 r
.63331 .6372 m .63153 .63805 L .63126 .63823 L F
.376 0 0 r
.57342 .78454 m .5744 .78407 L .57102 .78385 L F
.69 .249 .198 r
.57342 .78454 m .57666 .78505 L .5744 .78407 L F
.757 .573 .649 r
.4806 .85216 m .48182 .85645 L .484 .85277 L F
.924 .825 .73 r
.484 .85277 m .48545 .85507 L .48386 .8554 L F
.746 .484 .535 r
.484 .85277 m .48386 .8554 L .48707 .85518 L F
0 0 .513 r
.66946 .61204 m .67024 .61328 L .66847 .61076 L F
0 .001 .578 r
.67061 .61279 m .67024 .61328 L .66946 .61204 L F
.67061 .61279 m .67155 .61509 L .67024 .61328 L F
.504 .359 .617 r
.32124 .70125 m .3233 .7003 L .32304 .69823 L F
.454 .305 .588 r
.32136 .70367 m .3233 .7003 L .32124 .70125 L F
.574 .447 .669 r
.32824 .68265 m .33063 .68474 L .3303 .68224 L F
.32824 .68265 m .32852 .6852 L .33063 .68474 L F
.708 .86 .954 r
.3417 .7934 m .3417 .79494 L .34031 .7944 L F
.737 .796 .899 r
.34375 .79385 m .3417 .79494 L .34358 .79396 L F
.708 .86 .954 r
.3417 .7934 m .34358 .79396 L .3417 .79494 L F
.538 .454 .708 r
.45157 .7434 m .45002 .74603 L .4494 .7439 L F
.45157 .7434 m .45198 .74581 L .45002 .74603 L F
.569 .489 .724 r
.45198 .74581 m .45065 .74956 L .45002 .74603 L F
.751 .617 .711 r
.49475 .87949 m .4989 .88007 L .49716 .8764 L F
.754 .497 .544 r
.49837 .88153 m .4989 .88007 L .49475 .87949 L F
.57 .534 .775 r
.49716 .8764 m .4989 .88007 L .5007 .87908 L F
.316 .054 .348 r
.5007 .87908 m .4989 .88007 L .49837 .88153 L F
.909 .515 .108 r
.54741 .8284 m .54829 .83078 L .54915 .83134 L F
.978 .724 .479 r
.54804 .83332 m .54915 .83134 L .54829 .83078 L F
.54804 .83332 m .54917 .8339 L .54915 .83134 L F
.639 .61 .805 r
.48921 .85016 m .49266 .85249 L .4915 .84959 L F
.47 .491 .798 r
.49266 .85249 m .49351 .8496 L .4915 .84959 L F
.49266 .85249 m .49467 .85252 L .49351 .8496 L F
.899 .717 .647 r
.58263 .80411 m .58407 .80491 L .58307 .80183 L F
.784 .604 .656 r
.58263 .80411 m .5845 .80705 L .58407 .80491 L F
.976 .673 .344 r
.54381 .83383 m .54245 .83076 L .54299 .83176 L F
.365 0 0 r
.31865 .67495 m .3168 .67628 L .31482 .67629 L F
.859 .963 .869 r
.31896 .67308 m .31865 .67495 L .32091 .67394 L F
.31896 .67308 m .31727 .67485 L .31865 .67495 L F
.967 .838 .663 r
.31727 .67485 m .3168 .67628 L .31865 .67495 L F
.767 .607 .681 r
.58591 .81012 m .58553 .8126 L .58867 .81269 L F
.813 .607 .624 r
.58559 .81472 m .58867 .81269 L .58553 .8126 L F
.726 .88 .952 r
.6916 .75192 m .69466 .75174 L .69358 .75073 L F
.829 .835 .852 r
.69358 .75073 m .69466 .75174 L .69678 .74947 L F
.369 .067 .316 r
.40083 .77529 m .402 .77707 L .4024 .77507 L F
.40083 .77529 m .40015 .77768 L .402 .77707 L F
.629 .293 .383 r
.5047 .88373 m .50148 .88479 L .50389 .88432 L F
.007 0 0 r
.50639 .88328 m .5047 .88373 L .50389 .88432 L F
.944 .657 .465 r
.67512 .71632 m .67622 .71451 L .67468 .71388 L F
.67512 .71632 m .67634 .71668 L .67622 .71451 L F
.147 .193 .654 r
.719 .7189 m .71795 .71988 L .71753 .71645 L F
0 .043 .582 r
.71941 .72122 m .71795 .71988 L .719 .7189 L F
.71941 .72122 m .71984 .72189 L .71795 .71988 L F
.298 .305 .699 r
.71795 .71988 m .71984 .72189 L .71872 .72202 L F
.595 .361 .532 r
.53538 .83382 m .53256 .8363 L .53311 .83423 L F
.858 .846 .831 r
.53856 .80194 m .53962 .80327 L .53844 .80346 L F
0 .378 .757 r
.53874 .80258 m .53962 .80327 L .53856 .80194 L F
.53874 .80258 m .54191 .80421 L .53962 .80327 L F
.443 .857 .695 r
.53747 .84325 m .53697 .84358 L .53913 .84222 L F
.043 0 0 r
.47701 .88124 m .47542 .88136 L .4733 .88139 L F
.53 0 0 r
.47701 .88124 m .47827 .88185 L .47542 .88136 L F
.991 .886 .585 r
.56047 .79764 m .55985 .79809 L .55996 .79641 L F
.404 .041 .23 r
.36216 .73201 m .36545 .72943 L .36336 .72984 L F
.425 .278 .577 r
.6596 .72555 m .66079 .72508 L .66013 .7223 L F
.416 .412 .747 r
.66013 .7223 m .66145 .71925 L .6594 .71987 L F
.66013 .7223 m .66203 .72253 L .66145 .71925 L F
.641 .413 .558 r
.66013 .7223 m .66275 .72436 L .66203 .72253 L F
.66013 .7223 m .66079 .72508 L .66275 .72436 L F
.346 0 0 r
.49569 .86279 m .49367 .86287 L .49143 .8625 L F
.847 .406 .173 r
.49569 .86279 m .49565 .86479 L .49367 .86287 L F
.49569 .86279 m .49717 .86527 L .49565 .86479 L F
.854 .683 .669 r
.50148 .88479 m .50296 .88703 L .50097 .88705 L F
.8 .454 .401 r
.50097 .88705 m .50296 .88703 L .50162 .88901 L F
.721 .351 .348 r
.50162 .88901 m .50296 .88703 L .50496 .88924 L F
.165 .474 .894 r
.50296 .88703 m .50546 .88874 L .50496 .88924 L F
.486 .586 .879 r
.43717 .75078 m .43957 .75184 L .4389 .75055 L F
.796 .74 .802 r
.56139 .79103 m .55922 .79362 L .56252 .79383 L F
.564 .554 .802 r
.56337 .79032 m .56252 .79383 L .55922 .79362 L F
.56337 .79032 m .56493 .79423 L .56252 .79383 L F
.414 .294 .607 r
.56459 .79593 m .56252 .79383 L .56493 .79423 L F
.56459 .79593 m .56309 .7969 L .56252 .79383 L F
.675 .588 .75 r
.55775 .82328 m .56079 .82564 L .56074 .82344 L F
.709 .468 .559 r
.49247 .8578 m .49724 .85838 L .49588 .85522 L F
.622 .46 .642 r
.49588 .85522 m .49676 .85148 L .49467 .85252 L F
.49588 .85522 m .49803 .85255 L .49676 .85148 L F
.49588 .85522 m .49825 .85511 L .49803 .85255 L F
.236 .055 .42 r
.49724 .85838 m .49825 .85511 L .49588 .85522 L F
.622 .46 .642 r
.49803 .85255 m .49825 .85511 L .49588 .85522 L F
.758 .44 .447 r
.67817 .73218 m .67919 .72988 L .67804 .72989 L F
0 .405 .748 r
.68105 .73231 m .68415 .73339 L .68144 .7325 L F
.419 .312 .625 r
.68144 .7325 m .68415 .73339 L .68194 .73531 L F
.488 .421 .708 r
.68131 .73321 m .68415 .73339 L .68105 .73231 L F
.68194 .73531 m .68263 .73471 L .68131 .73321 L F
.68263 .73471 m .68415 .73339 L .68131 .73321 L F
.758 .44 .447 r
.67892 .73049 m .68144 .7325 L .67919 .72988 L F
.67817 .73218 m .68061 .73242 L .67892 .73049 L F
.68061 .73242 m .68144 .7325 L .67892 .73049 L F
.732 .478 .545 r
.63196 .64551 m .63093 .6475 L .6288 .64489 L F
.63196 .64551 m .63209 .64772 L .63093 .6475 L F
.275 .348 .757 r
.56057 .78066 m .5628 .78268 L .56222 .78095 L F
.801 .554 .565 r
.59552 .82265 m .59848 .82073 L .59546 .82047 L F
.59552 .82265 m .59856 .82302 L .59848 .82073 L F
.752 .522 .583 r
.50119 .85982 m .50384 .86232 L .5026 .86038 L F
.436 .802 .995 r
.53077 .85196 m .53275 .8495 L .53069 .84991 L F
.496 .5 .791 r
.53871 .82417 m .53979 .82644 L .54128 .82584 L F
.621 .556 .76 r
.53979 .82644 m .54246 .82831 L .54128 .82584 L F
.298 .045 .351 r
.53979 .82644 m .53931 .82858 L .54128 .82584 L F
.569 .489 .724 r
.45198 .74581 m .45284 .7492 L .45065 .74956 L F
.85 .804 .806 r
.71219 .722 m .71097 .72319 L .70969 .72215 L F
.57 .569 .813 r
.71598 .72479 m .71219 .722 L .71599 .72252 L F
.622 .402 .562 r
.65035 .72097 m .65124 .72178 L .65219 .72103 L F
.076 0 0 r
.65035 .72097 m .65102 .72113 L .65124 .72178 L F
.65035 .72097 m .64854 .7216 L .65102 .72113 L F
.754 .72 .821 r
.65846 .72748 m .66167 .72776 L .66079 .72508 L F
.635 .652 .85 r
.66079 .72508 m .66167 .72776 L .66392 .72723 L F
.788 .539 .561 r
.5415 .82064 m .54135 .82327 L .54482 .82315 L F
.493 .163 .335 r
.54128 .82584 m .54482 .82315 L .54135 .82327 L F
.54128 .82584 m .54295 .82562 L .54482 .82315 L F
.763 .501 .537 r
.54295 .82562 m .54489 .8258 L .54482 .82315 L F
.364 .827 .75 r
.35383 .80944 m .35834 .80775 L .35564 .80872 L F
.319 .795 .714 r
.35564 .80872 m .35834 .80775 L .36017 .80699 L F
.389 .85 .855 r
.38619 .78365 m .38251 .78447 L .3841 .78419 L F
.303 .792 .749 r
.38619 .78365 m .3872 .78317 L .38817 .78316 L F
.38619 .78365 m .3841 .78419 L .3872 .78317 L F
.434 .442 .768 r
.52725 .83373 m .52807 .83063 L .52589 .83085 L F
.52725 .83373 m .5295 .83457 L .52807 .83063 L F
.473 .402 .696 r
.34375 .66919 m .34246 .67172 L .34185 .6697 L F
.34375 .66919 m .34417 .67139 L .34246 .67172 L F
.551 .371 .591 r
.52418 .84558 m .52631 .84471 L .52616 .84194 L F
.15 .23 .693 r
.52715 .84164 m .52732 .84194 L .52616 .84194 L F
.016 0 .308 r
.52732 .84194 m .527 .84247 L .52616 .84194 L F
0 0 .304 r
.52731 .84364 m .52631 .84471 L .527 .84247 L F
.016 0 .308 r
.52732 .84194 m .52731 .84364 L .527 .84247 L F
0 0 .423 r
.52616 .84194 m .52731 .84364 L .52715 .84164 L F
.52616 .84194 m .52631 .84471 L .52731 .84364 L F
.261 .697 .963 r
.32893 .67716 m .32568 .67645 L .32699 .67739 L F
.602 .813 .981 r
.54967 .81479 m .55058 .81578 L .55303 .81509 L F
.509 .206 .388 r
.45895 .7587 m .45749 .76156 L .45534 .76182 L F
.589 .417 .616 r
.46066 .757 m .46073 .75902 L .45895 .7587 L F
.609 .314 .444 r
.4624 .75987 m .45895 .7587 L .46073 .75902 L F
.4624 .75987 m .45749 .76156 L .45895 .7587 L F
.95 .854 .711 r
.58252 .79438 m .58016 .7956 L .5822 .79666 L F
.961 .849 .685 r
.58016 .7956 m .58048 .79915 L .5822 .79666 L F
.829 .615 .613 r
.5822 .79666 m .58048 .79915 L .58331 .79944 L F
.594 .38 .56 r
.4261 .76481 m .42836 .7647 L .4286 .76225 L F
.556 .365 .577 r
.42836 .7647 m .43056 .76178 L .4286 .76225 L F
.89 .913 .835 r
.53287 .85158 m .5358 .84998 L .53275 .8495 L F
.844 .437 .27 r
.50764 .8529 m .50887 .85283 L .50912 .85415 L F
.547 .617 .873 r
.6771 .73759 m .67373 .73538 L .67501 .73799 L F
0 .055 .61 r
.67308 .71158 m .67468 .71388 L .6744 .7124 L F
.607 .654 .871 r
.49803 .85255 m .49878 .84949 L .49676 .85148 L F
.49803 .85255 m .50026 .85233 L .49878 .84949 L F
.524 .346 .581 r
.50026 .85233 m .49825 .85511 L .49803 .85255 L F
.50026 .85233 m .49825 .85511 L .49803 .85255 L F
0 0 0 r
.35084 .73598 m .35125 .7364 L .35294 .73563 L F
.35084 .73598 m .3492 .73732 L .35125 .7364 L F
.543 .273 .456 r
.35053 .76669 m .34888 .7649 L .35127 .76498 L F
.35053 .76669 m .3485 .76713 L .34888 .7649 L F
.378 .793 .978 r
.39715 .72312 m .3993 .72283 L .40058 .72336 L F
.327 0 0 r
.3993 .72283 m .40268 .72329 L .40058 .72336 L F
.914 .606 .448 r
.48008 .88385 m .48205 .88455 L .48067 .88617 L F
0 0 .317 r
.48008 .88385 m .48067 .88617 L .48035 .88447 L F
.717 .185 0 r
.47954 .88263 m .48205 .88455 L .48008 .88385 L F
0 0 .317 r
.48008 .88385 m .48035 .88447 L .48006 .88287 L F
.717 .185 0 r
.47935 .88248 m .47954 .88263 L .48008 .88385 L F
.704 .459 .55 r
.53782 .82289 m .5415 .82064 L .53961 .8204 L F
.53782 .82289 m .53955 .82318 L .5415 .82064 L F
.718 .478 .561 r
.53955 .82318 m .54135 .82327 L .5415 .82064 L F
.391 .414 .765 r
.55989 .83102 m .56216 .83356 L .56109 .82983 L F
.358 0 .21 r
.64933 .64741 m .65201 .64565 L .65135 .64689 L F
.341 0 .137 r
.65421 .64528 m .65135 .64689 L .65201 .64565 L F
0 0 0 r
.38708 .79592 m .38888 .79503 L .39067 .79421 L F
.35 0 .142 r
.41183 .78451 m .41101 .78307 L .41314 .78278 L F
.41183 .78451 m .40971 .78502 L .41101 .78307 L F
.269 .059 .399 r
.4643 .86313 m .46561 .86455 L .46573 .86239 L F
.4643 .86313 m .46374 .86554 L .46561 .86455 L F
.357 .821 .913 r
.46169 .7517 m .4595 .75212 L .45855 .75202 L F
.832 .606 .596 r
.57387 .79929 m .57584 .80213 L .57424 .80173 L F
.81 .618 .642 r
.57568 .80451 m .57424 .80173 L .57584 .80213 L F
.563 .679 .917 r
.43652 .72877 m .43542 .73064 L .43436 .72911 L F
.43652 .72877 m .43737 .73033 L .43542 .73064 L F
.5 .822 .513 r
.54087 .85811 m .53818 .86074 L .53934 .85959 L F
.651 .505 .673 r
.69522 .74604 m .69323 .74447 L .69469 .74435 L F
.653 .272 .312 r
.63887 .64775 m .63784 .64961 L .63554 .64793 L F
.659 .313 .375 r
.64106 .64795 m .63784 .64961 L .63887 .64775 L F
.389 0 .172 r
.41744 .76957 m .42061 .76728 L .4186 .76765 L F
.569 .784 .98 r
.69892 .70894 m .6963 .70935 L .69388 .70894 L F
0 .505 .735 r
.69388 .70894 m .6963 .70935 L .69323 .70882 L F
.506 .118 .239 r
.6963 .70935 m .69316 .7113 L .69323 .70882 L F
.6963 .70935 m .69532 .71127 L .69316 .7113 L F
.608 .224 .29 r
.69838 .71075 m .69532 .71127 L .6963 .70935 L F
.545 .283 .469 r
.69892 .70894 m .69838 .71075 L .6963 .70935 L F
.712 .651 .788 r
.68459 .60292 m .68062 .60034 L .68284 .59965 L F
.68459 .60292 m .68236 .60312 L .68062 .60034 L F
.698 .503 .621 r
.68459 .60292 m .68186 .60533 L .68236 .60312 L F
.689 .489 .611 r
.6843 .6051 m .68186 .60533 L .68459 .60292 L F
.44 .462 .786 r
.6851 .59915 m .68459 .60292 L .68284 .59965 L F
.6851 .59915 m .68604 .60232 L .68459 .60292 L F
.591 .493 .712 r
.68604 .60232 m .6843 .6051 L .68459 .60292 L F
.566 .177 .265 r
.53995 .80645 m .5419 .80712 L .54365 .80544 L F
.65 .846 .975 r
.54576 .80475 m .54365 .80544 L .54405 .80387 L F
.614 .238 .307 r
.54365 .80544 m .5419 .80712 L .54502 .80644 L F
.536 .289 .488 r
.54576 .80475 m .54502 .80644 L .54365 .80544 L F
.152 .319 .779 r
.54365 .80544 m .54502 .80644 L .54405 .80387 L F
.657 .958 .938 r
.6666 .71182 m .66886 .71125 L .66882 .71142 L F
.973 .878 .68 r
.66694 .71439 m .6666 .71182 L .66882 .71142 L F
.436 .802 .995 r
.53077 .85196 m .53394 .85222 L .53287 .85158 L F
.773 .705 .788 r
.53377 .83909 m .53043 .83894 L .53256 .8363 L F
.679 .248 .219 r
.53377 .83909 m .53244 .84074 L .53043 .83894 L F
.937 .754 .63 r
.53256 .8363 m .53255 .83939 L .53377 .83909 L F
.822 .437 .325 r
.53255 .83939 m .53244 .84074 L .53377 .83909 L F
.141 0 0 r
.38321 .75074 m .38137 .75136 L .38232 .75056 L F
.782 .687 .759 r
.56839 .79098 m .56489 .79143 L .56685 .78908 L F
.569 .478 .712 r
.56709 .79376 m .56489 .79143 L .56839 .79098 L F
.325 0 0 r
.57097 .7933 m .56709 .79376 L .56839 .79098 L F
.65 .594 .779 r
.48808 .84706 m .48921 .85016 L .4915 .84959 L F
.593 .477 .691 r
.47955 .85482 m .4806 .85216 L .47852 .85244 L F
.47955 .85482 m .48182 .85645 L .4806 .85216 L F
.429 .1 .304 r
.39607 .77853 m .39546 .77993 L .39807 .77816 L F
.541 .335 .551 r
.33805 .77286 m .3389 .77496 L .33687 .77531 L F
.676 .401 .498 r
.33944 .77307 m .3389 .77496 L .33805 .77286 L F
.755 .665 .762 r
.68062 .60034 m .68236 .60312 L .67886 .60266 L F
.769 .575 .636 r
.68236 .60312 m .67873 .605 L .67886 .60266 L F
.68236 .60312 m .68186 .60533 L .67873 .605 L F
.864 .502 .003 r
.51488 .87891 m .51639 .88259 L .51654 .88118 L F
.048 .238 .736 r
.5172 .88322 m .51639 .88259 L .51654 .88118 L F
.359 .243 .583 r
.5172 .88322 m .51618 .8848 L .51639 .88259 L F
.595 .023 0 r
.5172 .88322 m .51639 .88259 L .51512 .88227 L F
.719 .597 .719 r
.71872 .72202 m .71928 .7258 L .71598 .72479 L F
.289 .287 .683 r
.72088 .72418 m .71872 .72202 L .71984 .72189 L F
.919 .522 .174 r
.71969 .72347 m .71984 .7219 L .71941 .72122 L F
.71984 .7219 m .71984 .72189 L .71983 .72188 L F
.71984 .7219 m .71983 .72188 L .71941 .72122 L F
.289 .287 .683 r
.7202 .7235 m .71928 .7258 L .71872 .72202 L F
.72088 .72418 m .72045 .72461 L .7202 .7235 L F
.72045 .72461 m .71928 .7258 L .7202 .7235 L F
0 .152 .643 r
.72013 .72627 m .71928 .7258 L .72088 .72418 L F
.72013 .72627 m .72091 .72709 L .71928 .7258 L F
.828 .705 .729 r
.57712 .80759 m .57656 .81027 L .57367 .80954 L F
.825 .71 .738 r
.57656 .81027 m .5747 .81251 L .57367 .80954 L F
.792 .669 .729 r
.63983 .62694 m .64047 .62978 L .63641 .62873 L F
.786 .68 .747 r
.63641 .62873 m .64047 .62978 L .63753 .63166 L F
.511 .521 .803 r
.56019 .78801 m .55945 .79151 L .55798 .78852 L F
.56019 .78801 m .56139 .79103 L .55945 .79151 L F
.662 .798 .947 r
.68632 .69248 m .68756 .6937 L .68954 .69282 L F
.68632 .69248 m .68756 .6937 L .68954 .69282 L F
.649 .442 .589 r
.48863 .84307 m .49026 .84433 L .49098 .84202 L F
.703 .498 .608 r
.49098 .84202 m .49026 .84433 L .49273 .8441 L F
.61 .328 .464 r
.66416 .64008 m .6617 .64166 L .66196 .64062 L F
.61 .453 .644 r
.48863 .84307 m .48808 .84706 L .49026 .84433 L F
.603 .75 .948 r
.58939 .84152 m .59241 .84218 L .59146 .84095 L F
.541 .721 .957 r
.59146 .84095 m .59241 .84218 L .59359 .84079 L F
.519 .687 .943 r
.59241 .84218 m .59492 .84214 L .59359 .84079 L F
.24 .621 .957 r
.40811 .72384 m .40996 .72413 L .40928 .72483 L F
.248 .632 .96 r
.40996 .72413 m .41116 .72511 L .40928 .72483 L F
.83 .658 .669 r
.59856 .82302 m .60001 .82585 L .60037 .82355 L F
.695 .719 .868 r
.6882 .75125 m .68876 .75375 L .6916 .75192 L F
.59 .328 .488 r
.34565 .76935 m .34407 .76795 L .34576 .76745 L F
.34565 .76935 m .34345 .76981 L .34407 .76795 L F
.56 .508 .754 r
.34375 .66919 m .34185 .6697 L .34094 .66652 L F
.601 .58 .802 r
.45832 .87315 m .46141 .87567 L .46006 .87336 L F
.716 .516 .619 r
.59316 .81989 m .59541 .81797 L .59225 .81772 L F
.59316 .81989 m .59546 .82047 L .59541 .81797 L F
.579 .317 .483 r
.53851 .83854 m .54123 .83637 L .53861 .83621 L F
.664 .515 .672 r
.69323 .74447 m .6935 .74663 L .69028 .74601 L F
.658 .67 .85 r
.68897 .71695 m .68765 .71981 L .68634 .71874 L F
.68897 .71695 m .68993 .7198 L .68765 .71981 L F
.477 .247 .486 r
.68993 .7198 m .68789 .72215 L .68765 .71981 L F
.504 .201 .386 r
.65688 .64256 m .65866 .64441 L .65641 .64485 L F
.65688 .64256 m .65955 .64195 L .65866 .64441 L F
.502 .417 .692 r
.6594 .71987 m .6604 .71574 L .65974 .71723 L F
.859 .63 .59 r
.69553 .7171 m .69685 .71667 L .69651 .7159 L F
.69553 .7171 m .69536 .71941 L .69369 .71829 L F
.69553 .7171 m .69369 .71829 L .69685 .71667 L F
.284 0 0 r
.66047 .71373 m .66269 .71333 L .66362 .71208 L F
.729 .287 .201 r
.66269 .71333 m .66587 .71419 L .66362 .71208 L F
.546 .689 .933 r
.57229 .84228 m .57605 .84402 L .57517 .84332 L F
.549 .857 .997 r
.57517 .84332 m .57605 .84402 L .57821 .84341 L F
.472 0 .047 r
.37518 .72652 m .37734 .72662 L .3788 .72528 L F
.348 0 0 r
.37734 .72662 m .38095 .72533 L .3788 .72528 L F
.759 .453 .467 r
.4832 .85754 m .48173 .8599 L .48141 .85785 L F
.815 .827 .859 r
.4832 .85754 m .48141 .85785 L .48386 .8554 L F
.742 .431 .456 r
.4832 .85754 m .48519 .86019 L .48173 .8599 L F
0 .032 .572 r
.47502 .85305 m .47666 .8548 L .4766 .85505 L F
0 .002 .551 r
.47666 .8548 m .47867 .85747 L .4766 .85505 L F
.464 .356 .646 r
.4766 .85505 m .47867 .85747 L .47686 .8575 L F
.669 .694 .864 r
.46006 .87336 m .46141 .87567 L .46363 .87397 L F
.61 .394 .564 r
.50269 .84949 m .50321 .85245 L .50026 .85233 L F
.071 .199 .692 r
.50279 .84901 m .5034 .84949 L .50269 .84949 L F
.295 .224 .604 r
.5034 .84949 m .50321 .85245 L .50269 .84949 L F
.762 .777 .865 r
.67393 .61999 m .67403 .62181 L .67159 .62131 L F
.812 .71 .752 r
.67403 .62181 m .67236 .62387 L .67159 .62131 L F
.712 .554 .673 r
.67403 .62181 m .67467 .62394 L .67236 .62387 L F
.332 .428 .81 r
.67542 .62039 m .67403 .62181 L .67393 .61999 L F
.448 .617 .922 r
.67542 .62039 m .67609 .62206 L .67403 .62181 L F
.707 .687 .829 r
.67609 .62206 m .67467 .62394 L .67403 .62181 L F
.303 .079 .399 r
.51678 .87637 m .51488 .87891 L .51625 .87875 L F
.798 .736 .794 r
.51367 .87638 m .51488 .87891 L .51678 .87637 L F
.347 .274 .631 r
.51625 .87875 m .51488 .87891 L .51654 .88118 L F
.301 0 0 r
.41264 .74304 m .40928 .74301 L .4106 .7428 L F
.369 .062 .307 r
.36097 .75713 m .36023 .75896 L .35839 .7594 L F
.443 .132 .342 r
.36231 .7585 m .36097 .75713 L .36281 .75657 L F
.36231 .7585 m .36023 .75896 L .36097 .75713 L F
.551 .419 .654 r
.46509 .85556 m .46712 .85177 L .46503 .85247 L F
.411 .208 .491 r
.33557 .70387 m .33526 .70622 L .33356 .70666 L F
.192 .017 .4 r
.33449 .70804 m .33356 .70666 L .33526 .70622 L F
.33449 .70804 m .33331 .70878 L .33356 .70666 L F
.777 .506 .526 r
.64461 .60581 m .64266 .60766 L .64415 .60543 L F
.64461 .60581 m .64585 .6085 L .64266 .60766 L F
.773 .731 .814 r
.57387 .79929 m .57102 .799 L .57343 .79625 L F
.818 .596 .602 r
.57387 .79929 m .57125 .80115 L .57102 .799 L F
.57387 .79929 m .57424 .80173 L .57125 .80115 L F
.707 .687 .829 r
.67609 .62206 m .67768 .62412 L .67467 .62394 L F
.599 .442 .641 r
.67684 .62593 m .67467 .62394 L .67768 .62412 L F
0 .257 .766 r
.67609 .62206 m .67759 .62342 L .67768 .62412 L F
.218 .119 .522 r
.67759 .62342 m .67684 .62593 L .67768 .62412 L F
.615 .46 .648 r
.46291 .75671 m .46073 .75902 L .46066 .757 L F
.884 .512 .331 r
.4854 .87303 m .48499 .87129 L .48322 .87077 L F
.642 .178 .137 r
.48942 .87239 m .48499 .87129 L .4854 .87303 L F
.406 .359 .693 r
.68646 .72672 m .68618 .72794 L .68834 .72689 L F
0 0 .21 r
.68708 .7299 m .68834 .72689 L .68618 .72794 L F
.762 .489 .52 r
.50253 .86626 m .50361 .86818 L .50029 .86793 L F
.2 .258 .699 r
.50509 .8675 m .50253 .86626 L .50391 .86532 L F
.50444 .86718 m .50361 .86818 L .50253 .86626 L F
.834 .509 .437 r
.50299 .86726 m .50389 .86535 L .50259 .86435 L F
.50389 .86535 m .50391 .86532 L .50388 .8653 L F
.50389 .86535 m .50388 .8653 L .50259 .86435 L F
.2 .258 .699 r
.50509 .8675 m .50459 .86772 L .50444 .86718 L F
.50459 .86772 m .50361 .86818 L .50444 .86718 L F
.354 0 0 r
.64828 .61837 m .64674 .6163 L .6484 .61617 L F
0 0 0 r
.65026 .61331 m .64981 .61487 L .6484 .61617 L F
0 0 .288 r
.6484 .61617 m .64943 .61704 L .64828 .61837 L F
.6484 .61617 m .64981 .61487 L .64943 .61704 L F
.791 .651 .708 r
.57568 .80451 m .57712 .80759 L .57434 .80737 L F
.828 .705 .729 r
.57712 .80759 m .57367 .80954 L .57434 .80737 L F
.693 .555 .694 r
.71872 .72202 m .71598 .72479 L .71599 .72252 L F
.851 .55 .48 r
.57965 .78597 m .57986 .78808 L .58264 .7885 L F
.872 .445 .189 r
.57986 .78808 m .58227 .79051 L .58264 .7885 L F
.689 .731 .882 r
.66392 .72723 m .66713 .72774 L .66591 .72637 L F
.143 .68 .847 r
.4159 .74318 m .41473 .74299 L .41264 .74304 L F
.511 .894 .958 r
.41684 .74227 m .4159 .74318 L .41812 .74273 L F
.41684 .74227 m .41473 .74299 L .4159 .74318 L F
.698 .701 .85 r
.71097 .72319 m .70735 .72281 L .70969 .72215 L F
.604 .867 .527 r
.54073 .86257 m .54285 .85997 L .54067 .86269 L F
.829 .835 .852 r
.69358 .75073 m .69678 .74947 L .6958 .74836 L F
.818 .661 .688 r
.58048 .79915 m .58307 .80183 L .58331 .79944 L F
.571 .587 .831 r
.67519 .62852 m .67318 .62941 L .67247 .62668 L F
.147 0 .339 r
.67519 .62852 m .67321 .63173 L .67318 .62941 L F
.95 .754 .604 r
.70118 .70459 m .69908 .70592 L .70003 .70343 L F
.70118 .70459 m .70066 .7071 L .69908 .70592 L F
.294 .523 .903 r
.32091 .67394 m .32134 .67249 L .31896 .67308 L F
.32091 .67394 m .32218 .67386 L .32134 .67249 L F
.499 .793 .998 r
.65299 .60156 m .65569 .60223 L .6537 .60267 L F
.683 .893 .974 r
.65135 .60278 m .65299 .60156 L .6537 .60267 L F
.57 .534 .775 r
.49716 .8764 m .5007 .87908 L .49932 .87592 L F
.917 .576 .377 r
.49489 .88603 m .49305 .88521 L .49509 .88446 L F
.49489 .88603 m .49624 .88838 L .49305 .88521 L F
.355 0 0 r
.49482 .88373 m .49509 .88446 L .49411 .8828 L F
.4959 .88512 m .49509 .88446 L .49482 .88373 L F
.574 .82 .991 r
.49867 .88478 m .49559 .8858 L .49509 .88446 L F
.49559 .8858 m .49489 .88603 L .49509 .88446 L F
.355 0 0 r
.50048 .88739 m .49489 .88603 L .49867 .88478 L F
.692 .706 .858 r
.5281 .81732 m .52983 .81942 L .53134 .8177 L F
.772 .506 .532 r
.48852 .87663 m .48664 .87849 L .48617 .87658 L F
.48852 .87663 m .48935 .87901 L .48664 .87849 L F
.561 .477 .718 r
.4907 .87566 m .48935 .87901 L .48852 .87663 L F
.296 .785 .735 r
.50546 .88874 m .50862 .88767 L .5066 .88826 L F
.579 .943 .854 r
.5066 .88826 m .50862 .88767 L .51031 .88662 L F
.815 .688 .724 r
.64491 .6026 m .64698 .59938 L .64802 .60273 L F
.607 .569 .786 r
.64937 .59899 m .64802 .60273 L .64698 .59938 L F
.64937 .59899 m .65135 .60278 L .64802 .60273 L F
.498 .3 .541 r
.32304 .69823 m .32527 .69572 L .324 .69705 L F
.53 .348 .578 r
.3284 .68749 m .33063 .68474 L .32852 .6852 L F
.466 .501 .81 r
.53871 .82417 m .53955 .82318 L .53782 .82289 L F
.53871 .82417 m .54128 .82584 L .53955 .82318 L F
.854 .559 .027 r
.66935 .72497 m .66979 .72715 L .66936 .72632 L F
.385 .655 .965 r
.68436 .71919 m .68062 .71728 L .68261 .71873 L F
.659 .781 .939 r
.68582 .71667 m .68436 .71919 L .68261 .71873 L F
.68582 .71667 m .68634 .71874 L .68436 .71919 L F
.303 .791 .742 r
.36213 .80647 m .36597 .80524 L .36419 .80563 L F
0 0 0 r
.36779 .80443 m .36419 .80563 L .36597 .80524 L F
.57 .777 .977 r
.32431 .65647 m .32245 .65694 L .32087 .65581 L F
.485 .282 .528 r
.34161 .77022 m .34133 .77279 L .33944 .77307 L F
.636 .412 .562 r
.34267 .77219 m .34161 .77022 L .34345 .76981 L F
.34267 .77219 m .34133 .77279 L .34161 .77022 L F
.494 .106 .233 r
.36753 .72924 m .36967 .72909 L .37098 .7271 L F
.449 .057 .202 r
.36967 .72909 m .37302 .72694 L .37098 .7271 L F
.829 .752 .778 r
.69212 .71899 m .69296 .72145 L .68998 .72175 L F
.824 .787 .817 r
.69296 .72145 m .69108 .72302 L .68998 .72175 L F
.72 .697 .827 r
.69536 .71941 m .69296 .72145 L .69212 .71899 L F
.265 .754 .663 r
.3453 .81264 m .34581 .81243 L .34509 .81272 L F
.397 .177 .459 r
.34618 .69249 m .34607 .69513 L .344 .69475 L F
.486 .239 .464 r
.34607 .69513 m .34347 .69762 L .344 .69475 L F
.454 .186 .417 r
.34133 .77279 m .3389 .77496 L .33944 .77307 L F
.788 .296 .028 r
.54967 .81479 m .54664 .81267 L .5478 .81376 L F
.714 .293 .246 r
.48499 .88503 m .48408 .88653 L .48205 .88455 L F
.656 .226 .214 r
.48499 .88503 m .48735 .88664 L .48408 .88653 L F
.647 .111 0 r
.4889 .88658 m .48735 .88664 L .48499 .88503 L F
.458 .7 .972 r
.44492 .73226 m .44408 .73364 L .44286 .73243 L F
.44492 .73226 m .44628 .73361 L .44408 .73364 L F
.09 0 0 r
.69651 .7159 m .6997 .7148 L .69731 .71526 L F
.69651 .7159 m .69886 .71572 L .6997 .7148 L F
.569 .867 .56 r
.39101 .74439 m .38988 .74541 L .38921 .74625 L F
.588 .551 .78 r
.39217 .74903 m .38921 .74625 L .38874 .74867 L F
.876 .896 .843 r
.38988 .74541 m .38874 .74867 L .38921 .74625 L F
.924 .975 .721 r
.54179 .85545 m .54276 .85505 L .54087 .85811 L F
.874 .528 .028 r
.54246 .85566 m .54276 .85505 L .54179 .85545 L F
.54246 .85566 m .54356 .85773 L .54276 .85505 L F
.652 .896 .982 r
.36024 .79188 m .35693 .79213 L .35881 .79116 L F
.657 .874 .98 r
.36212 .79101 m .36024 .79188 L .35881 .79116 L F
.551 .51 .764 r
.47736 .87366 m .47432 .87069 L .47642 .8708 L F
.696 .639 .789 r
.56216 .83356 m .56323 .83641 L .56517 .83364 L F
.681 .618 .778 r
.56323 .83641 m .56626 .83679 L .56517 .83364 L F
.767 .654 .737 r
.58251 .80969 m .58591 .81012 L .5845 .80705 L F
.828 .666 .682 r
.58258 .8121 m .58591 .81012 L .58251 .80969 L F
.58258 .8121 m .58553 .8126 L .58591 .81012 L F
.382 .183 .481 r
.33689 .70553 m .33557 .70387 L .33731 .70336 L F
.33689 .70553 m .33526 .70622 L .33557 .70387 L F
.507 .214 .402 r
.44382 .76679 m .4424 .76967 L .44034 .76997 L F
.571 .281 .437 r
.44571 .76695 m .4424 .76967 L .44382 .76679 L F
.238 0 0 r
.64674 .6163 m .64581 .61734 L .64548 .61688 L F
.354 0 0 r
.64828 .61837 m .64581 .61734 L .64674 .6163 L F
.573 .94 .892 r
.48723 .87548 m .48617 .87658 L .48578 .87638 L F
.67 .77 .925 r
.67247 .62668 m .6697 .62792 L .66895 .62633 L F
.86 .415 .133 r
.4889 .88658 m .48924 .88906 L .48735 .88664 L F
.4889 .88658 m .49062 .88951 L .48924 .88906 L F
0 .358 .828 r
.4889 .88658 m .4921 .88918 L .49062 .88951 L F
.752 .406 .397 r
.5628 .78268 m .56404 .78343 L .56222 .78095 L F
.797 .4 .301 r
.56222 .78095 m .56404 .78343 L .56573 .78335 L F
.803 .712 .765 r
.66767 .71875 m .66817 .722 L .66832 .71973 L F
.26 .317 .732 r
.66817 .722 m .66767 .71875 L .66832 .71973 L F
.337 0 .104 r
.65135 .64689 m .64851 .64895 L .64933 .64741 L F
.811 .668 .705 r
.58559 .81472 m .5868 .81748 L .58908 .81504 L F
.755 .574 .651 r
.5868 .81748 m .59016 .81792 L .58908 .81504 L F
.697 .545 .678 r
.59016 .81792 m .5924 .81545 L .58908 .81504 L F
.992 .882 .572 r
.57759 .81625 m .57642 .82037 L .57701 .81783 L F
.754 .377 .339 r
.35986 .88148 m .36055 .88156 L .36021 .8811 L F
.595 .595 .823 r
.34753 .67383 m .34546 .6743 L .34417 .67139 L F
.472 .234 .471 r
.66161 .62704 m .66368 .62634 L .66409 .62422 L F
.743 .646 .753 r
.66368 .62634 m .6657 .62341 L .66409 .62422 L F
.81 .699 .743 r
.54246 .82831 m .53931 .82858 L .54128 .82584 L F
.668 .442 .569 r
.54246 .82831 m .53836 .83063 L .53931 .82858 L F
.54246 .82831 m .54245 .83076 L .53836 .83063 L F
.709 .757 .89 r
.65448 .60789 m .65587 .60644 L .65171 .60807 L F
.709 .762 .893 r
.65171 .60807 m .65587 .60644 L .65261 .60435 L F
.409 .69 .977 r
.65261 .60435 m .65587 .60644 L .65601 .6054 L F
.65261 .60435 m .65587 .60644 L .65601 .6054 L F
.779 .988 .893 r
.65601 .6054 m .65587 .60644 L .65448 .60789 L F
.65601 .6054 m .65448 .60789 L .65676 .60608 L F
.731 .599 .709 r
.65171 .60807 m .65285 .61088 L .65448 .60789 L F
.296 .785 .735 r
.50546 .88874 m .5066 .88826 L .50496 .88924 L F
.782 .76 .833 r
.65284 .62779 m .6506 .629 L .65357 .62943 L F
.413 .035 .211 r
.6501 .63327 m .65317 .63325 L .65385 .63153 L F
.6501 .63327 m .65385 .63153 L .65152 .63286 L F
.678 .447 .563 r
.65152 .63286 m .65357 .62943 L .6506 .629 L F
.65152 .63286 m .65385 .63153 L .65357 .62943 L F
.583 .898 .986 r
.49502 .86823 m .49361 .86921 L .49272 .86827 L F
.498 .3 .541 r
.32304 .69823 m .32494 .69791 L .32527 .69572 L F
.493 .338 .599 r
.3233 .7003 m .32494 .69791 L .32304 .69823 L F
.7 .256 .193 r
.48274 .8744 m .48578 .87638 L .48174 .87541 L F
.741 .226 0 r
.4382 .74304 m .43643 .74273 L .43442 .74074 L F
.128 .665 .852 r
.4382 .74304 m .43978 .74299 L .43643 .74273 L F
.397 .164 .439 r
.4382 .74304 m .43761 .74559 L .43978 .74299 L F
.389 .747 .992 r
.31215 .65505 m .31307 .6559 L .31187 .65506 L F
.31215 .65505 m .31358 .65588 L .31307 .6559 L F
.492 .211 .415 r
.42356 .76675 m .42562 .76646 L .4261 .76481 L F
.534 .251 .431 r
.42562 .76646 m .42791 .76625 L .4261 .76481 L F
.556 .243 .393 r
.4261 .76481 m .42791 .76625 L .42836 .7647 L F
.945 .586 .213 r
.6885 .733 m .68785 .73279 L .68708 .7299 L F
.955 .766 .609 r
.6885 .733 m .68697 .73476 L .68785 .73279 L F
.6885 .733 m .6882 .73547 L .68697 .73476 L F
.822 .902 .896 r
.54461 .85237 m .54724 .85011 L .54597 .84936 L F
.526 .243 .429 r
.32993 .74344 m .33135 .74324 L .33004 .74307 L F
.395 0 .143 r
.39581 .79116 m .39456 .79303 L .39251 .79331 L F
.337 0 .109 r
.39655 .7926 m .39581 .79116 L .3979 .79069 L F
.39655 .7926 m .39456 .79303 L .39581 .79116 L F
.586 .846 .493 r
.56939 .78581 m .56994 .78504 L .57102 .78385 L F
.28 0 0 r
.56994 .78504 m .57342 .78454 L .57102 .78385 L F
.152 0 .344 r
.67719 .7029 m .67584 .70383 L .67749 .70092 L F
.233 0 0 r
.38095 .72533 m .38302 .72499 L .38405 .72421 L F
.263 0 0 r
.38302 .72499 m .38611 .72398 L .38405 .72421 L F
.452 .211 .457 r
.51905 .87813 m .51678 .87637 L .51625 .87875 L F
.779 .495 .505 r
.65266 .62402 m .65351 .62679 L .65239 .62649 L F
.595 .329 .483 r
.65239 .62649 m .65528 .62411 L .65266 .62402 L F
.699 .836 .949 r
.34924 .79302 m .34577 .79313 L .34794 .79243 L F
.375 .756 .99 r
.34967 .7922 m .34924 .79302 L .34794 .79243 L F
.34967 .7922 m .3511 .79293 L .34924 .79302 L F
0 .119 .67 r
.67126 .72995 m .67163 .72936 L .66979 .72715 L F
0 .122 .672 r
.67126 .72995 m .67294 .73207 L .67163 .72936 L F
.443 .28 .564 r
.46701 .84984 m .46886 .85147 L .46885 .8493 L F
.46701 .84984 m .46712 .85177 L .46886 .85147 L F
.531 .297 .505 r
.43057 .77277 m .43029 .77484 L .4282 .77517 L F
.515 .283 .5 r
.43057 .77277 m .43242 .77454 L .43029 .77484 L F
.574 .277 .426 r
.43282 .77268 m .43242 .77454 L .43057 .77277 L F
.185 .697 .895 r
.70742 .71369 m .71058 .71399 L .70836 .71401 L F
.868 .959 .862 r
.51423 .88532 m .51618 .8848 L .5172 .88322 L F
.651 .505 .673 r
.69522 .74604 m .6935 .74663 L .69323 .74447 L F
.477 .247 .486 r
.68993 .7198 m .68998 .72175 L .68789 .72215 L F
.605 .639 .857 r
.69212 .71899 m .68993 .7198 L .68897 .71695 L F
.829 .752 .778 r
.69212 .71899 m .68998 .72175 L .68993 .7198 L F
.812 .783 .826 r
.65026 .61331 m .65285 .61088 L .64973 .61034 L F
.65026 .61331 m .64973 .61034 L .65036 .6128 L F
.712 .728 .208 r
.65036 .6128 m .64981 .61487 L .65026 .61331 L F
.721 .508 .602 r
.67524 .62634 m .67236 .62387 L .67467 .62394 L F
.599 .442 .641 r
.67684 .62593 m .67524 .62634 L .67467 .62394 L F
.925 .737 .629 r
.51315 .84942 m .51277 .85205 L .51437 .85249 L F
.307 0 .088 r
.51437 .85249 m .51333 .85434 L .511 .85492 L F
.911 .585 .413 r
.51277 .85205 m .51333 .85434 L .51437 .85249 L F
.107 0 .422 r
.48337 .86521 m .48189 .86837 L .48069 .86543 L F
.48337 .86521 m .48314 .86797 L .48189 .86837 L F
.611 .384 .548 r
.48566 .86749 m .48494 .86968 L .48261 .86949 L F
0 .536 .716 r
.48261 .86949 m .48378 .86957 L .48246 .86909 L F
0 0 .383 r
.48261 .86949 m .48284 .87008 L .48189 .86837 L F
.643 .293 .363 r
.48226 .8673 m .4792 .86983 L .48261 .86949 L F
.48226 .8673 m .48246 .86857 L .48176 .86883 L F
.48246 .86857 m .48261 .86949 L .48176 .86883 L F
0 .536 .716 r
.48261 .86949 m .48246 .86909 L .48176 .86883 L F
.611 .384 .548 r
.48566 .86749 m .48261 .86949 L .48314 .86797 L F
.435 0 0 r
.48176 .86883 m .48378 .86957 L .48124 .86902 L F
.48176 .86883 m .48124 .86902 L .48027 .8688 L F
0 0 .383 r
.48261 .86949 m .48322 .87077 L .48284 .87008 L F
.824 .72 .75 r
.58072 .84174 m .58382 .84187 L .58267 .83875 L F
.827 .62 .623 r
.58207 .84356 m .58382 .84187 L .58072 .84174 L F
.671 .681 .851 r
.58382 .84187 m .58494 .83841 L .58267 .83875 L F
.886 .706 .654 r
.5995 .83073 m .6012 .83122 L .5999 .82825 L F
.878 .733 .697 r
.60036 .83339 m .6012 .83122 L .5995 .83073 L F
.249 0 0 r
.40461 .78818 m .40331 .7878 L .40603 .78652 L F
.40461 .78818 m .40262 .78875 L .40331 .7878 L F
.771 .641 .718 r
.49015 .84656 m .49375 .84712 L .49273 .8441 L F
.495 .256 .482 r
.4915 .84959 m .49375 .84712 L .49015 .84656 L F
.4915 .84959 m .49351 .8496 L .49375 .84712 L F
.493 .32 .575 r
.49375 .84712 m .49559 .84488 L .49273 .8441 L F
.49375 .84712 m .49645 .84712 L .49559 .84488 L F
.552 .305 .494 r
.49375 .84712 m .49552 .84901 L .49645 .84712 L F
.49375 .84712 m .49351 .8496 L .49552 .84901 L F
.739 .612 .716 r
.59225 .81772 m .5924 .81545 L .59016 .81792 L F
.723 .541 .643 r
.59007 .82026 m .59225 .81772 L .59016 .81792 L F
.59007 .82026 m .59316 .81989 L .59225 .81772 L F
.249 .466 .874 r
.4187 .7267 m .4179 .72786 L .41701 .72607 L F
.465 .761 .994 r
.4187 .7267 m .42013 .72773 L .4179 .72786 L F
.772 .682 .764 r
.69751 .73234 m .70096 .73236 L .69988 .72953 L F
.69751 .73234 m .69914 .73313 L .70096 .73236 L F
.685 .671 .83 r
.69988 .72953 m .70096 .73236 L .70323 .73058 L F
.639 .655 .85 r
.70096 .73236 m .70418 .73317 L .70323 .73058 L F
.567 .376 .581 r
.56019 .78801 m .55798 .78852 L .55817 .78567 L F
.676 .382 .468 r
.5605 .78601 m .56019 .78801 L .55817 .78567 L F
.565 .298 .47 r
.45325 .76173 m .45234 .76442 L .45015 .76455 L F
.58 .313 .476 r
.45678 .76381 m .45325 .76173 L .45534 .76182 L F
.45678 .76381 m .45234 .76442 L .45325 .76173 L F
.588 .275 .405 r
.68826 .71126 m .68869 .71434 L .68558 .71235 L F
.627 .07 0 r
.68739 .71009 m .69096 .71165 L .68826 .71126 L F
.385 .138 .412 r
.69006 .71324 m .68826 .71126 L .69096 .71165 L F
.69006 .71324 m .68869 .71434 L .68826 .71126 L F
.578 .594 .832 r
.34163 .66325 m .34094 .66652 L .33965 .66397 L F
.34163 .66325 m .34293 .66611 L .34094 .66652 L F
.56 .508 .754 r
.34375 .66919 m .34094 .66652 L .34293 .66611 L F
.647 .571 .755 r
.47016 .8788 m .47112 .88193 L .4733 .88139 L F
.901 .874 .801 r
.63546 .63415 m .6322 .63636 L .63422 .63302 L F
.63546 .63415 m .63331 .6372 L .6322 .63636 L F
.834 .82 .835 r
.63481 .63174 m .63546 .63415 L .63422 .63302 L F
.63481 .63174 m .63753 .63166 L .63546 .63415 L F
.517 .494 .77 r
.56626 .83679 m .56725 .8333 L .56517 .83364 L F
.56626 .83679 m .568 .83661 L .56725 .8333 L F
.459 .495 .809 r
.56626 .83679 m .56931 .83896 L .568 .83661 L F
0 0 .21 r
.68708 .7299 m .68802 .72912 L .68834 .72689 L F
.938 .587 .329 r
.68708 .7299 m .68785 .73279 L .68628 .73185 L F
.68708 .7299 m .68628 .73185 L .68802 .72912 L F
.497 .52 .81 r
.34944 .67361 m .34887 .67669 L .34753 .67383 L F
.34944 .67361 m .35077 .6769 L .34887 .67669 L F
.864 .659 .623 r
.69649 .74033 m .69797 .74331 L .69815 .74096 L F
.562 .573 .822 r
.45702 .74831 m .45624 .75212 L .455 .74865 L F
.45702 .74831 m .45855 .75202 L .45624 .75212 L F
.737 .669 .784 r
.67236 .62387 m .66937 .62397 L .67159 .62131 L F
.651 .274 .317 r
.67236 .62387 m .67129 .6256 L .66937 .62397 L F
.956 .7 .508 r
.67236 .62387 m .67247 .62668 L .67129 .6256 L F
.721 .508 .602 r
.67524 .62634 m .67247 .62668 L .67236 .62387 L F
.76 .733 .827 r
.6835 .74531 m .68275 .74877 L .6822 .74792 L F
.6835 .74531 m .68491 .74641 L .68275 .74877 L F
.554 .007 0 r
.68275 .74877 m .68404 .75012 L .6822 .74792 L F
.061 .297 .784 r
.68535 .7517 m .68525 .75094 L .68275 .74877 L F
.554 .007 0 r
.68275 .74877 m .68525 .75094 L .68404 .75012 L F
.649 .464 .62 r
.46014 .87083 m .46252 .87089 L .46272 .8684 L F
.542 .371 .6 r
.46272 .8684 m .46457 .87022 L .46421 .86799 L F
.46272 .8684 m .46252 .87089 L .46457 .87022 L F
.629 .385 .53 r
.44813 .76492 m .44772 .76728 L .44571 .76695 L F
.563 .341 .536 r
.45015 .76455 m .44772 .76728 L .44813 .76492 L F
.854 .65 .627 r
.64973 .61034 m .65285 .61088 L .65171 .60807 L F
.858 .644 .612 r
.54489 .8258 m .54474 .82819 L .54741 .8284 L F
.823 .481 .409 r
.54474 .82819 m .54632 .83046 L .54741 .8284 L F
.846 .512 .421 r
.54741 .8284 m .54632 .83046 L .54829 .83078 L F
.519 .298 .518 r
.43582 .75943 m .43789 .75906 L .43812 .75685 L F
.542 .352 .572 r
.43812 .75685 m .44028 .75654 L .44038 .75411 L F
.464 .251 .504 r
.43812 .75685 m .43984 .75852 L .44028 .75654 L F
.43812 .75685 m .43789 .75906 L .43984 .75852 L F
.441 .583 .899 r
.33314 .66013 m .33131 .66011 L .32974 .65775 L F
.454 .305 .588 r
.32136 .70367 m .32355 .70132 L .3233 .7003 L F
.462 .329 .614 r
.32153 .70611 m .32355 .70132 L .32136 .70367 L F
.368 .025 .247 r
.41875 .77939 m .41709 .7822 L .41513 .78262 L F
.595 .4 .588 r
.4207 .77823 m .41875 .77939 L .41904 .77916 L F
.4207 .77823 m .42051 .78 L .41875 .77939 L F
.452 .112 .298 r
.41909 .78171 m .41875 .77939 L .42051 .78 L F
.41909 .78171 m .41709 .7822 L .41875 .77939 L F
.484 .203 .412 r
.35839 .7594 m .35776 .76146 L .35585 .76158 L F
.548 .322 .524 r
.36023 .75896 m .35776 .76146 L .35839 .7594 L F
.943 .913 .758 r
.58159 .79393 m .58016 .7956 L .58252 .79438 L F
.349 0 .154 r
.38254 .79835 m .38339 .79718 L .38541 .7968 L F
.668 .646 .819 r
.69108 .72302 m .68789 .72215 L .68998 .72175 L F
.466 .196 .42 r
.36977 .786 m .36739 .78806 L .36922 .78742 L F
.697 .961 .714 r
.66691 .61303 m .66391 .61552 L .66507 .6139 L F
.66691 .61303 m .66389 .61591 L .66391 .61552 L F
.566 .522 .765 r
.45322 .7399 m .45121 .74036 L .45059 .73845 L F
.585 .473 .692 r
.45322 .7399 m .45157 .7434 L .45121 .74036 L F
.286 0 .185 r
.65219 .72103 m .65124 .72178 L .65419 .71983 L F
.821 .587 .584 r
.54845 .80992 m .54957 .81241 L .55051 .81118 L F
.589 .631 .86 r
.70195 .71438 m .70212 .71733 L .6997 .7148 L F
.70195 .71438 m .70339 .71722 L .70212 .71733 L F
.508 .179 .344 r
.70339 .71722 m .70303 .7177 L .70212 .71733 L F
.70339 .71722 m .70303 .7177 L .70212 .71733 L F
.659 .626 .806 r
.70323 .73058 m .70418 .73317 L .70644 .73247 L F
.49 .786 .997 r
.43007 .72608 m .42895 .7273 L .42752 .72654 L F
.43007 .72608 m .43094 .72701 L .42895 .7273 L F
.781 .309 .117 r
.48765 .8609 m .48707 .86195 L .48519 .86019 L F
.48765 .8609 m .48863 .86207 L .48707 .86195 L F
0 0 0 r
.37522 .78667 m .37528 .78649 L .37363 .78664 L F
.37522 .78667 m .37767 .78616 L .37528 .78649 L F
.502 .464 .747 r
.44038 .75411 m .44213 .75363 L .43957 .75184 L F
.487 .306 .561 r
.44038 .75411 m .44214 .75601 L .44213 .75363 L F
.44038 .75411 m .44028 .75654 L .44214 .75601 L F
.906 .67 .571 r
.59846 .82521 m .60001 .82585 L .59856 .82302 L F
.876 .66 .606 r
.59821 .82761 m .60001 .82585 L .59846 .82521 L F
.59821 .82761 m .5999 .82825 L .60001 .82585 L F
.591 .393 .582 r
.54123 .83637 m .54359 .83632 L .54381 .83383 L F
.929 .779 .675 r
.54359 .83632 m .54207 .836 L .54281 .83334 L F
.788 .851 .398 r
.54207 .836 m .54258 .83449 L .54281 .83334 L F
.976 .673 .344 r
.54381 .83383 m .54281 .83334 L .54305 .83212 L F
.788 .851 .398 r
.54258 .83449 m .54349 .83183 L .54281 .83334 L F
.976 .673 .344 r
.54305 .83212 m .54281 .83334 L .54245 .83076 L F
.929 .779 .675 r
.54359 .83632 m .54281 .83334 L .54381 .83383 L F
.647 .627 .816 r
.43436 .72911 m .43212 .72974 L .43094 .72701 L F
.509 .444 .719 r
.46592 .86048 m .46745 .85729 L .4657 .85747 L F
.46592 .86048 m .46734 .86029 L .46745 .85729 L F
.462 .262 .522 r
.46573 .86239 m .46734 .86029 L .46592 .86048 L F
.35 .121 .42 r
.6596 .72555 m .65846 .72748 L .66079 .72508 L F
.77 .85 .912 r
.34375 .79385 m .34358 .79396 L .3417 .7934 L F
0 0 .286 r
.71641 .71328 m .71741 .71593 L .71753 .71645 L F
.832 .364 0 r
.71785 .71808 m .71753 .71645 L .71741 .71593 L F
.71785 .71808 m .719 .7189 L .71753 .71645 L F
.818 .661 .688 r
.58048 .79915 m .58002 .80149 L .58307 .80183 L F
.81 .636 .666 r
.58002 .80149 m .58263 .80411 L .58307 .80183 L F
.573 .633 .873 r
.4389 .75055 m .43957 .75184 L .44115 .75049 L F
.479 .465 .764 r
.43957 .75184 m .44213 .75363 L .44115 .75049 L F
.158 0 0 r
.36952 .8036 m .37316 .80173 L .37127 .80306 L F
.101 0 0 r
.37511 .80131 m .37127 .80306 L .37316 .80173 L F
.765 .664 .75 r
.64644 .72454 m .64983 .72513 L .64854 .7216 L F
.543 .541 .802 r
.64854 .7216 m .64983 .72513 L .65077 .72275 L F
.586 .14 .158 r
.5113 .88201 m .51265 .88132 L .50923 .88151 L F
.652 .231 .232 r
.51344 .88385 m .51265 .88132 L .5113 .88201 L F
.662 .217 .184 r
.51344 .88404 m .5113 .88201 L .51026 .88335 L F
.714 .699 .835 r
.51289 .88398 m .51279 .88498 L .51405 .88412 L F
.662 .217 .184 r
.51375 .88411 m .51371 .88408 L .51344 .88404 L F
.51371 .88408 m .5113 .88201 L .51344 .88404 L F
.652 .231 .232 r
.51362 .88379 m .51265 .88132 L .51344 .88385 L F
.51374 .88408 m .51512 .88227 L .51265 .88132 L F
.51375 .88411 m .51377 .88408 L .51374 .88408 L F
.51377 .88408 m .51512 .88227 L .51374 .88408 L F
.51375 .88411 m .51362 .88379 L .51344 .88385 L F
.626 .2 .214 r
.51663 .88335 m .51512 .88227 L .51377 .88408 L F
.51386 .88408 m .51377 .88408 L .51375 .88411 L F
.51663 .88335 m .51377 .88408 L .51386 .88408 L F
.714 .699 .835 r
.51371 .88408 m .51377 .88408 L .51562 .88304 L F
.51377 .88408 m .51408 .8841 L .51409 .88409 L F
.626 .2 .214 r
.51663 .88335 m .51386 .88408 L .51562 .88304 L F
.714 .699 .835 r
.51377 .88408 m .51386 .88408 L .51562 .88304 L F
.626 .2 .214 r
.51386 .88408 m .51375 .88411 L .51562 .88304 L F
.714 .699 .835 r
.51386 .88408 m .51409 .88409 L .51562 .88304 L F
.51344 .88404 m .51371 .88408 L .51336 .88382 L F
.513 .88283 m .51289 .88398 L .51562 .88304 L F
.662 .217 .184 r
.51375 .88411 m .51344 .88404 L .513 .88283 L F
.51344 .88404 m .51026 .88335 L .513 .88283 L F
.714 .699 .835 r
.51336 .88382 m .51371 .88408 L .51562 .88304 L F
.51289 .88398 m .51344 .88404 L .51336 .88382 L F
.51371 .88408 m .51405 .88412 L .51408 .8841 L F
.831 .847 .858 r
.51149 .8837 m .51208 .88428 L .513 .88283 L F
.51208 .88428 m .51279 .88498 L .51288 .88403 L F
.51208 .88428 m .51288 .88403 L .513 .88283 L F
.396 .562 .9 r
.32824 .65563 m .32793 .65755 L .32677 .65638 L F
.32824 .65563 m .32974 .65775 L .32793 .65755 L F
.77 .85 .912 r
.34375 .79385 m .3417 .7934 L .3425 .79242 L F
.653 .732 .907 r
.34577 .79313 m .34375 .79385 L .3425 .79242 L F
.444 .052 .201 r
.35682 .73471 m .36022 .73254 L .3581 .73273 L F
.534 0 0 r
.4921 .88918 m .49277 .89026 L .49062 .88951 L F
.588 .551 .78 r
.39217 .74903 m .38874 .74867 L .39079 .74815 L F
.632 .804 .965 r
.38874 .74867 m .39217 .74903 L .39079 .74815 L F
.388 .394 .744 r
.54176 .84945 m .54347 .85443 L .54343 .84983 L F
.665 .625 .799 r
.54343 .84983 m .54347 .85443 L .54597 .84936 L F
.819 .922 .904 r
.6666 .71182 m .66815 .71016 L .66886 .71125 L F
.836 .893 .471 r
.66901 .70989 m .66886 .71125 L .66815 .71016 L F
.66901 .70989 m .66999 .70793 L .66886 .71125 L F
.514 .164 .311 r
.39011 .78251 m .39338 .78019 L .39064 .7812 L F
.472 .393 .686 r
.4657 .85747 m .46721 .8556 L .46509 .85556 L F
.4657 .85747 m .46745 .85729 L .46721 .8556 L F
.042 0 0 r
.69323 .70882 m .69476 .70852 L .69388 .70894 L F
.569 .784 .98 r
.69892 .70894 m .69388 .70894 L .69785 .7063 L F
0 0 0 r
.69388 .70894 m .69665 .70749 L .69785 .7063 L F
.69388 .70894 m .69476 .70852 L .69665 .70749 L F
.778 .671 .745 r
.49272 .86827 m .49085 .87139 L .49213 .87007 L F
.5 .254 .474 r
.49213 .87007 m .49085 .87139 L .49249 .87272 L F
.528 .426 .682 r
.49213 .87007 m .49502 .86823 L .49272 .86827 L F
.49213 .87007 m .49458 .87011 L .49502 .86823 L F
.512 .263 .474 r
.49213 .87007 m .49249 .87272 L .49458 .87011 L F
.408 .192 .471 r
.49338 .87133 m .49249 .87272 L .49213 .87007 L F
.435 .096 .291 r
.40768 .78544 m .40461 .78818 L .40603 .78652 L F
0 .399 .836 r
.54129 .80946 m .54517 .81155 L .54213 .80911 L F
.041 .436 .871 r
.54484 .81184 m .54517 .81155 L .54129 .80946 L F
0 .025 .529 r
.48837 .85639 m .48915 .85721 L .48707 .85518 L F
.48837 .85639 m .48707 .85518 L .48564 .85532 L F
.558 .406 .631 r
.32494 .69791 m .32688 .69522 L .32527 .69572 L F
.159 .7 .772 r
.39639 .74342 m .39505 .7435 L .39311 .74378 L F
0 0 0 r
.39843 .74312 m .39505 .7435 L .39639 .74342 L F
.484 .617 .907 r
.335 .66014 m .33433 .6621 L .33314 .66013 L F
.335 .66014 m .33668 .66259 L .33433 .6621 L F
.389 .709 .986 r
.71514 .73398 m .71624 .73319 L .71388 .73276 L F
.71514 .73398 m .71667 .73369 L .71624 .73319 L F
.185 .693 .902 r
.40268 .72329 m .40451 .72329 L .4062 .72371 L F
.268 .677 .968 r
.40676 .723 m .4062 .72371 L .40451 .72329 L F
.40676 .723 m .40811 .72384 L .4062 .72371 L F
.515 .178 .335 r
.43979 .77169 m .43817 .77019 L .44034 .76997 L F
.43979 .77169 m .43746 .77207 L .43817 .77019 L F
.827 .774 .802 r
.65171 .60807 m .65023 .60503 L .64861 .60724 L F
.869 .677 .641 r
.64973 .61034 m .65171 .60807 L .64861 .60724 L F
.709 .762 .893 r
.65171 .60807 m .65261 .60435 L .65023 .60503 L F
.106 0 0 r
.65862 .62863 m .66161 .62704 L .6587 .62836 L F
.65862 .62863 m .66055 .62807 L .66161 .62704 L F
.456 .051 .181 r
.66055 .62807 m .66368 .62634 L .66161 .62704 L F
.579 .317 .483 r
.53851 .83854 m .54069 .8386 L .54123 .83637 L F
.32 0 .2 r
.54069 .8386 m .54359 .83632 L .54123 .83637 L F
.742 .422 .441 r
.53012 .87338 m .52697 .87209 L .52676 .87322 L F
.645 .306 .383 r
.42061 .76728 m .42258 .76911 L .42356 .76675 L F
.584 .286 .429 r
.42258 .76911 m .42562 .76646 L .42356 .76675 L F
.514 .164 .311 r
.39011 .78251 m .39226 .78246 L .39338 .78019 L F
.348 0 .224 r
.39338 .78019 m .39421 .78188 L .39546 .77993 L F
.39338 .78019 m .39226 .78246 L .39421 .78188 L F
.572 .524 .763 r
.66228 .60748 m .66045 .6085 L .65908 .60563 L F
.663 .814 .956 r
.65902 .60724 m .66045 .6085 L .66228 .60748 L F
.423 .009 .145 r
.41253 .77148 m .41556 .77014 L .41333 .77061 L F
.737 .711 .827 r
.48519 .86019 m .48345 .86315 L .48173 .8599 L F
.66 .608 .786 r
.48547 .86245 m .48345 .86315 L .48519 .86019 L F
.362 .1 .377 r
.48547 .86245 m .48337 .86521 L .48345 .86315 L F
.637 .393 .532 r
.66695 .63722 m .66915 .63895 L .66695 .63918 L F
.66695 .63722 m .66913 .63704 L .66915 .63895 L F
.281 0 .115 r
.34509 .81272 m .34607 .81253 L .34365 .81335 L F
.34509 .81272 m .34581 .81243 L .34704 .81204 L F
.78 .513 .533 r
.58238 .81449 m .58553 .8126 L .58258 .8121 L F
.58238 .81449 m .58559 .81472 L .58553 .8126 L F
.543 .541 .802 r
.64854 .7216 m .65077 .72275 L .65124 .72178 L F
.64854 .7216 m .65124 .72178 L .65115 .72254 L F
.828 .605 .054 r
.65102 .72113 m .65115 .72254 L .65124 .72178 L F
.663 .317 .377 r
.63554 .64793 m .63243 .64956 L .63209 .64772 L F
.63554 .64793 m .63607 .6492 L .63243 .64956 L F
.627 .3 .397 r
.63554 .64793 m .63784 .64961 L .63607 .6492 L F
.435 .072 .248 r
.4024 .77507 m .40447 .77477 L .4055 .77275 L F
.508 .145 .287 r
.4055 .77275 m .40447 .77477 L .40728 .77374 L F
.525 .113 .203 r
.4055 .77275 m .40728 .77374 L .40771 .77282 L F
0 0 0 r
.39159 .7444 m .39101 .74439 L .39311 .74378 L F
.39159 .7444 m .38988 .74541 L .39101 .74439 L F
.681 .715 .875 r
.70644 .73247 m .70966 .73311 L .7088 .73177 L F
.673 .712 .877 r
.7088 .73177 m .70966 .73311 L .71214 .73222 L F
.45 .039 .167 r
.36592 .78938 m .36922 .78742 L .36739 .78806 L F
.725 .455 .518 r
.64487 .64759 m .6462 .64812 L .64316 .64802 L F
.866 .812 .794 r
.56939 .78581 m .56564 .78801 L .56787 .78501 L F
.56939 .78581 m .56685 .78908 L .56564 .78801 L F
.336 .722 .984 r
.56787 .78501 m .56994 .78504 L .56939 .78581 L F
.528 .859 .995 r
.58926 .84075 m .58939 .84152 L .59146 .84095 L F
.792 .669 .729 r
.63983 .62694 m .63641 .62873 L .63895 .62582 L F
.809 .751 .798 r
.64052 .62344 m .63983 .62694 L .63895 .62582 L F
.236 .055 .42 r
.49724 .85838 m .49799 .85736 L .49825 .85511 L F
.524 .346 .581 r
.50026 .85233 m .50029 .85478 L .49825 .85511 L F
.374 .168 .467 r
.49973 .85555 m .49825 .85511 L .50029 .85478 L F
.49973 .85555 m .49799 .85736 L .49825 .85511 L F
.524 .346 .581 r
.50026 .85233 m .50029 .85478 L .49825 .85511 L F
.374 .168 .467 r
.49825 .85511 m .49973 .85555 L .50029 .85478 L F
.49825 .85511 m .49799 .85736 L .49973 .85555 L F
.776 .358 .256 r
.56404 .78343 m .565 .78442 L .56573 .78335 L F
.89 .522 .337 r
.565 .78442 m .56622 .7851 L .56573 .78335 L F
.471 .505 .811 r
.47999 .86047 m .47686 .8575 L .47867 .85747 L F
.688 .903 .551 r
.38756 .74798 m .3867 .74945 L .38874 .74867 L F
.587 .238 .344 r
.64534 .62891 m .64727 .62933 L .64791 .62815 L F
.582 .501 .728 r
.65064 .63097 m .64791 .62815 L .64727 .62933 L F
.65064 .63097 m .6506 .629 L .64791 .62815 L F
.417 .201 .476 r
.70534 .70549 m .70409 .7069 L .70314 .70671 L F
.891 .619 .519 r
.64052 .62344 m .64223 .62437 L .64078 .6256 L F
.486 .123 .275 r
.43261 .76154 m .43476 .76137 L .43582 .75943 L F
.371 .008 .212 r
.43582 .75943 m .43688 .7609 L .43789 .75906 L F
.43582 .75943 m .43476 .76137 L .43688 .7609 L F
.473 .052 .159 r
.42392 .74178 m .42248 .74335 L .42011 .74338 L F
.155 0 0 r
.42493 .7415 m .42392 .74178 L .42552 .74134 L F
.42493 .7415 m .42248 .74335 L .42392 .74178 L F
.436 .802 .995 r
.53077 .85196 m .53287 .85158 L .53275 .8495 L F
.707 .811 .93 r
.68897 .71695 m .68634 .71874 L .68582 .71667 L F
.629 .451 .623 r
.32984 .74577 m .33135 .74324 L .32993 .74344 L F
.666 .852 .971 r
.31562 .65503 m .31358 .65588 L .31215 .65505 L F
.511 .168 .322 r
.43029 .77484 m .42715 .77718 L .4282 .77517 L F
.524 .762 .983 r
.6772 .69991 m .67749 .70092 L .67611 .70064 L F
.6772 .69991 m .67749 .70092 L .67611 .70064 L F
0 0 .182 r
.67813 .7017 m .67749 .70092 L .6772 .69991 L F
.67813 .7017 m .67719 .7029 L .67749 .70092 L F
.795 .682 .74 r
.71419 .70904 m .71651 .71163 L .71297 .7113 L F
.749 .545 .619 r
.71651 .71163 m .71288 .71316 L .71297 .7113 L F
.71651 .71163 m .71641 .71328 L .71288 .71316 L F
.278 .508 .897 r
.71756 .71063 m .71651 .71163 L .71419 .70904 L F
0 0 .064 r
.71666 .71214 m .71651 .71163 L .71756 .71063 L F
.71666 .71214 m .71641 .71328 L .71651 .71163 L F
.796 .601 .637 r
.54209 .85632 m .54356 .85773 L .54246 .85566 L F
.924 .975 .721 r
.54179 .85545 m .54087 .85811 L .54167 .85779 L F
.796 .601 .637 r
.54085 .85855 m .54167 .85779 L .54099 .85831 L F
.5415 .85835 m .54356 .85773 L .54323 .85742 L F
.54198 .85672 m .54323 .85742 L .54209 .85632 L F
.5415 .85835 m .54323 .85742 L .54198 .85672 L F
.54099 .85831 m .54167 .85779 L .54209 .85632 L F
.924 .975 .721 r
.54197 .85669 m .54167 .85779 L .54198 .85672 L F
.54179 .85545 m .54168 .85757 L .54197 .85669 L F
.54168 .85757 m .54167 .85779 L .54197 .85669 L F
.927 .596 .393 r
.54044 .85648 m .5409 .85613 L .54128 .8566 L F
.89 .916 .836 r
.54044 .85648 m .54085 .85855 L .54189 .85668 L F
.927 .596 .393 r
.54044 .85648 m .54128 .8566 L .5421 .85761 L F
.924 .975 .721 r
.54198 .85672 m .54167 .85779 L .5421 .85761 L F
.927 .596 .393 r
.5409 .85613 m .54198 .85672 L .5421 .85761 L F
.89 .916 .836 r
.54044 .85648 m .54189 .85668 L .54209 .85632 L F
.54229 .85573 m .54209 .85632 L .54246 .85566 L F
.927 .596 .393 r
.5409 .85613 m .54179 .85545 L .54198 .85672 L F
.89 .916 .836 r
.54044 .85648 m .54209 .85632 L .54229 .85573 L F
.796 .601 .637 r
.54085 .85855 m .5415 .85835 L .54167 .85779 L F
.653 .782 .943 r
.5421 .85761 m .54085 .85855 L .54083 .85843 L F
.771 .617 .688 r
.54084 .85843 m .5421 .85761 L .54167 .85779 L F
.653 .782 .943 r
.5421 .85761 m .54083 .85843 L .54044 .85648 L F
.771 .617 .688 r
.53934 .85959 m .5421 .85761 L .54084 .85843 L F
.53945 .85949 m .54167 .85779 L .54087 .85811 L F
.53934 .85959 m .54167 .85779 L .53945 .85949 L F
.928 .748 .638 r
.57367 .80954 m .5747 .81251 L .57325 .81189 L F
.795 .675 .732 r
.57451 .81476 m .57325 .81189 L .5747 .81251 L F
.458 .202 .438 r
.54343 .84983 m .54404 .84765 L .54176 .84945 L F
0 .117 .661 r
.48951 .87203 m .4904 .87333 L .48942 .87239 L F
.48951 .87203 m .4904 .87333 L .48942 .87239 L F
.809 .62 .646 r
.58743 .81964 m .59016 .81792 L .5868 .81748 L F
.58743 .81964 m .59007 .82026 L .59016 .81792 L F
.749 .678 .782 r
.52725 .87547 m .53012 .87338 L .52676 .87322 L F
.433 .205 .468 r
.35039 .68893 m .3479 .69145 L .34843 .68991 L F
.838 .738 .217 r
.4901 .8844 m .49023 .88492 L .48833 .88408 L F
.4901 .8844 m .49004 .88647 L .49023 .88492 L F
.977 .86 .656 r
.67962 .72692 m .67864 .72615 L .67878 .72782 L F
.936 .959 .756 r
.67878 .72782 m .6769 .72911 L .67804 .72989 L F
.67878 .72782 m .67864 .72615 L .6769 .72911 L F
.909 .894 .802 r
.54724 .85011 m .5492 .8471 L .548 .84653 L F
.895 .901 .823 r
.548 .84653 m .5492 .8471 L .55119 .84437 L F
.961 .651 .242 r
.64383 .61259 m .64548 .61688 L .64214 .61516 L F
.454 0 0 r
.64548 .61688 m .64306 .61697 L .64214 .61516 L F
.64548 .61688 m .64581 .61734 L .64306 .61697 L F
.567 .359 .558 r
.3389 .77496 m .3366 .77757 L .33687 .77531 L F
.659 .313 .375 r
.64106 .64795 m .6413 .64932 L .63784 .64961 L F
.612 .28 .385 r
.64106 .64795 m .64329 .64955 L .6413 .64932 L F
.607 .284 .396 r
.64316 .64802 m .64329 .64955 L .64106 .64795 L F
.525 .547 .82 r
.47502 .84344 m .47355 .84525 L .47276 .84365 L F
.47502 .84344 m .4766 .84688 L .47355 .84525 L F
.93 .764 .654 r
.54405 .80387 m .54502 .80644 L .54576 .80475 L F
.65 .594 .779 r
.48808 .84706 m .4915 .84959 L .49015 .84656 L F
.641 .437 .591 r
.46014 .87083 m .46192 .87221 L .46252 .87089 L F
.46014 .87083 m .46006 .87336 L .46192 .87221 L F
.861 .881 .851 r
.64173 .63068 m .6429 .631 L .64368 .63061 L F
.847 .93 .883 r
.64534 .62891 m .6429 .631 L .64368 .63061 L F
.925 .625 .455 r
.66389 .61591 m .66324 .6182 L .66391 .61552 L F
.466 .054 .174 r
.66731 .61782 m .66471 .61868 L .66408 .61697 L F
.159 .178 .63 r
.66408 .61697 m .66471 .61868 L .66389 .61591 L F
.925 .625 .455 r
.66389 .61591 m .66471 .61868 L .66324 .6182 L F
.961 .637 .245 r
.67597 .70786 m .67574 .70841 L .67673 .7097 L F
.6752 .70601 m .67574 .70841 L .67597 .70786 L F
.531 .39 .634 r
.67646 .7073 m .67533 .70937 L .67574 .70841 L F
.717 .824 .932 r
.67673 .7097 m .67574 .70841 L .67384 .70953 L F
.531 .39 .634 r
.67533 .70937 m .67497 .71002 L .67574 .70841 L F
.633 .765 .942 r
.67673 .7097 m .67788 .70772 L .67574 .70841 L F
.67673 .7097 m .67929 .70905 L .67788 .70772 L F
.67673 .7097 m .67788 .70772 L .67574 .70841 L F
.67673 .7097 m .67929 .70905 L .67788 .70772 L F
.551 .419 .654 r
.46509 .85556 m .46721 .8556 L .46712 .85177 L F
.744 .657 .765 r
.6853 .61015 m .68312 .61075 L .68505 .60843 L F
.574 .483 .713 r
.68557 .61268 m .68312 .61075 L .6853 .61015 L F
.634 .58 .777 r
.68789 .60959 m .6853 .61015 L .68505 .60843 L F
.453 .221 .471 r
.68789 .60959 m .68557 .61268 L .6853 .61015 L F
.551 .087 .107 r
.37597 .75065 m .37468 .75155 L .37235 .75113 L F
.138 0 0 r
.3779 .75055 m .37468 .75155 L .37597 .75065 L F
.263 .293 .706 r
.46745 .8759 m .46784 .87284 L .46573 .87299 L F
.46745 .8759 m .46847 .87633 L .46784 .87284 L F
.729 .549 .647 r
.5631 .78547 m .56019 .78801 L .5605 .78601 L F
.641 .813 .966 r
.35439 .7931 m .3511 .79293 L .35321 .79186 L F
.66 .842 .97 r
.35524 .7913 m .35439 .7931 L .35321 .79186 L F
.35524 .7913 m .35693 .79213 L .35439 .7931 L F
.858 .495 .362 r
.57666 .78505 m .57986 .78808 L .57965 .78597 L F
.975 .8 .602 r
.55065 .84156 m .55006 .84383 L .55119 .84437 L F
.895 .901 .823 r
.548 .84653 m .55119 .84437 L .55006 .84383 L F
.801 .647 .691 r
.36014 .88257 m .36055 .88156 L .35986 .88148 L F
.435 .126 .342 r
.33749 .74059 m .33663 .74281 L .33844 .74188 L F
.298 .05 .359 r
.32685 .71703 m .32634 .71898 L .32465 .71951 L F
.054 0 .178 r
.32634 .71898 m .32426 .72167 L .32465 .71951 L F
.579 .536 .77 r
.45164 .73483 m .45059 .73845 L .44954 .73524 L F
.45164 .73483 m .45268 .73808 L .45059 .73845 L F
.566 .522 .765 r
.45322 .7399 m .45059 .73845 L .45268 .73808 L F
.287 .77 .681 r
.38036 .78497 m .38124 .78458 L .38251 .78447 L F
.38036 .78497 m .37931 .78536 L .38124 .78458 L F
.46 .245 .498 r
.32726 .693 m .32869 .69474 L .32865 .69243 L F
.32726 .693 m .32688 .69522 L .32869 .69474 L F
0 0 0 r
.66522 .60875 m .66322 .61052 L .66472 .6094 L F
.282 .364 .77 r
.66322 .61052 m .66522 .61284 L .66472 .6094 L F
.777 .623 .689 r
.69559 .735 m .69914 .73313 L .69751 .73234 L F
.69559 .735 m .69874 .7353 L .69914 .73313 L F
.856 .71 .7 r
.63641 .62873 m .63753 .63166 L .63481 .63174 L F
.585 .597 .831 r
.66191 .60468 m .65908 .60563 L .65797 .60176 L F
.572 .524 .763 r
.66228 .60748 m .65908 .60563 L .66191 .60468 L F
.357 .821 .913 r
.46169 .7517 m .45855 .75202 L .46069 .75152 L F
.138 .638 .908 r
.46201 .75134 m .46169 .7517 L .46069 .75152 L F
.46201 .75134 m .46282 .75184 L .46169 .7517 L F
.548 .36 .578 r
.4226 .77935 m .4207 .77823 L .42289 .77773 L F
.4226 .77935 m .42051 .78 L .4207 .77823 L F
.775 .547 .59 r
.6288 .64489 m .62572 .64676 L .62577 .64444 L F
.6288 .64489 m .6275 .6473 L .62572 .64676 L F
.767 .538 .586 r
.6288 .64489 m .63093 .6475 L .6275 .6473 L F
.715 .45 .523 r
.49552 .84901 m .49917 .84672 L .49736 .84562 L F
.49552 .84901 m .49878 .84949 L .49917 .84672 L F
.721 .455 .524 r
.49917 .84672 m .49878 .84949 L .50067 .84884 L F
.63 .596 .797 r
.50279 .84901 m .49917 .84672 L .50067 .84884 L F
.909 .894 .802 r
.54724 .85011 m .548 .84653 L .54597 .84936 L F
.81 .618 .642 r
.57568 .80451 m .57253 .80411 L .57424 .80173 L F
.886 .778 .737 r
.57568 .80451 m .57265 .8066 L .57253 .80411 L F
.57568 .80451 m .57434 .80737 L .57265 .8066 L F
.87 .7 .669 r
.50148 .88479 m .49867 .88478 L .50057 .88356 L F
.50148 .88479 m .50048 .88739 L .49867 .88478 L F
.50148 .88479 m .50097 .88705 L .50048 .88739 L F
.553 .773 .98 r
.50389 .88432 m .50148 .88479 L .50057 .88356 L F
0 .375 .809 r
.54484 .81184 m .54532 .81163 L .54517 .81155 L F
.54484 .81184 m .54664 .81267 L .54532 .81163 L F
0 0 0 r
.64415 .63704 m .64636 .63395 L .64315 .63398 L F
.64415 .63704 m .64564 .63607 L .64636 .63395 L F
.334 .459 .838 r
.64564 .63607 m .64488 .63453 L .64488 .63422 L F
.307 0 0 r
.64487 .63396 m .64488 .63422 L .64315 .63398 L F
.253 .635 .962 r
.64315 .63398 m .64488 .63422 L .64427 .63328 L F
.334 .459 .838 r
.64488 .63453 m .64427 .63328 L .64488 .63422 L F
.307 0 0 r
.64636 .63395 m .64488 .63422 L .64487 .63396 L F
.864 .499 .357 r
.64636 .63395 m .64564 .63607 L .64488 .63422 L F
.635 .652 .85 r
.66079 .72508 m .66392 .72723 L .66275 .72436 L F
.659 .609 .788 r
.66275 .72436 m .66392 .72723 L .66591 .72637 L F
.379 .162 .454 r
.34764 .69451 m .34618 .69249 L .3479 .69145 L F
.34764 .69451 m .34607 .69513 L .34618 .69249 L F
.745 .543 .622 r
.68186 .60533 m .67865 .60737 L .67873 .605 L F
.68186 .60533 m .68188 .60767 L .67865 .60737 L F
.741 .576 .67 r
.6843 .6051 m .68188 .60767 L .68186 .60533 L F
.406 .249 .554 r
.35679 .67918 m .35658 .68178 L .35517 .68225 L F
.459 .233 .483 r
.35675 .68347 m .35517 .68225 L .35658 .68178 L F
.35675 .68347 m .35487 .68422 L .35517 .68225 L F
.67 .557 .718 r
.55846 .82608 m .5585 .82792 L .56079 .82564 L F
.601 .204 .262 r
.6462 .64812 m .64329 .64955 L .64316 .64802 L F
.6462 .64812 m .64654 .64915 L .64329 .64955 L F
.499 .146 .3 r
.6462 .64812 m .64851 .64895 L .64654 .64915 L F
.683 .854 .964 r
.68404 .75012 m .68525 .75094 L .68693 .75117 L F
.093 .638 .84 r
.68693 .75117 m .68525 .75094 L .6882 .75125 L F
.576 .811 .988 r
.6882 .75125 m .68525 .75094 L .68552 .7519 L F
.968 .891 .517 r
.68552 .7519 m .68525 .75094 L .68535 .7517 L F
.858 .846 .831 r
.53856 .80194 m .53844 .80346 L .53745 .80252 L F
.919 .534 .135 r
.53844 .80346 m .5388 .80542 L .53745 .80252 L F
.53844 .80346 m .53995 .80645 L .5388 .80542 L F
.819 .421 .298 r
.57344 .79387 m .57188 .79383 L .57097 .7933 L F
.848 .491 .377 r
.57344 .79387 m .57235 .79562 L .57188 .79383 L F
.983 .735 .476 r
.57344 .79387 m .57343 .79625 L .57235 .79562 L F
.597 .603 .828 r
.33965 .66397 m .3376 .66452 L .33668 .66259 L F
.61 .452 .643 r
.49026 .84433 m .48808 .84706 L .49015 .84656 L F
0 0 0 r
.7206 .72841 m .71992 .73228 L .7199 .73234 L F
.492 .896 .769 r
.3489 .81158 m .35261 .80978 L .3509 .81117 L F
0 0 0 r
.3509 .81117 m .35261 .80978 L .35383 .80944 L F
.596 .065 0 r
.49143 .8625 m .49032 .86279 L .48863 .86207 L F
.405 0 0 r
.49143 .8625 m .49367 .86287 L .49032 .86279 L F
.607 .556 .771 r
.50026 .85233 m .50067 .84884 L .49878 .84949 L F
.50026 .85233 m .50321 .85245 L .50067 .84884 L F
.483 .313 .575 r
.50026 .85233 m .50222 .8543 L .50321 .85245 L F
.50026 .85233 m .50029 .85478 L .50222 .8543 L F
.50026 .85233 m .50222 .8543 L .50321 .85245 L F
.50026 .85233 m .50029 .85478 L .50222 .8543 L F
.558 0 0 r
.68558 .71235 m .68869 .71434 L .68513 .71281 L F
.437 .198 .452 r
.34187 .73934 m .34341 .73921 L .34522 .73822 L F
.188 0 0 r
.34341 .73921 m .34747 .73798 L .34522 .73822 L F
.816 .765 .805 r
.49458 .87011 m .4963 .87102 L .49845 .86864 L F
.623 .354 .489 r
.43442 .74074 m .43643 .74273 L .43478 .74208 L F
.172 .44 .872 r
.46282 .75184 m .46584 .75336 L .465 .75406 L F
.392 .803 .979 r
.46584 .75336 m .46698 .75375 L .465 .75406 L F
.649 .491 .656 r
.46741 .75618 m .465 .75406 L .46698 .75375 L F
.46741 .75618 m .46517 .75647 L .465 .75406 L F
.595 .062 0 r
.50067 .84884 m .5034 .84949 L .50279 .84901 L F
.337 .181 .517 r
.5454 .84395 m .54404 .84765 L .54554 .84665 L F
.099 .498 .903 r
.5454 .84395 m .54662 .8438 L .54503 .84317 L F
.662 .639 .816 r
.54554 .84665 m .54662 .8438 L .5454 .84395 L F
.73 .648 .768 r
.71351 .71575 m .71172 .71707 L .71058 .71399 L F
.741 .576 .67 r
.6843 .6051 m .68505 .60843 L .68188 .60767 L F
.591 .493 .712 r
.68604 .60232 m .68675 .60442 L .6843 .6051 L F
.624 .501 .693 r
.68717 .6078 m .6843 .6051 L .68675 .60442 L F
.68717 .6078 m .68505 .60843 L .6843 .6051 L F
.816 .765 .805 r
.49458 .87011 m .49845 .86864 L .49743 .86745 L F
0 0 0 r
.4974 .8898 m .49874 .88975 L .49623 .88951 L F
.4974 .8898 m .49952 .88936 L .49874 .88975 L F
.615 .46 .648 r
.46291 .75671 m .4629 .75907 L .46073 .75902 L F
.604 .365 .527 r
.4629 .75907 m .4624 .75987 L .46073 .75902 L F
.561 .489 .731 r
.3303 .68224 m .33182 .67969 L .32979 .68033 L F
.3303 .68224 m .33228 .68183 L .33182 .67969 L F
.514 .391 .65 r
.33063 .68474 m .33228 .68183 L .3303 .68224 L F
.456 .336 .627 r
.35644 .67647 m .35816 .67617 L .35624 .67431 L F
.35644 .67647 m .35816 .67617 L .35624 .67431 L F
.816 .627 .646 r
.57424 .80173 m .57253 .80411 L .57125 .80115 L F
.771 .664 .745 r
.6657 .62341 m .6664 .6271 L .66937 .62397 L F
.6657 .62341 m .66937 .62397 L .66895 .62633 L F
.822 .819 .847 r
.67159 .62131 m .66937 .62397 L .66797 .62269 L F
.549 .314 .512 r
.67129 .6256 m .66895 .62633 L .66937 .62397 L F
.598 .387 .565 r
.34817 .7689 m .34576 .76745 L .3485 .76713 L F
.34817 .7689 m .34565 .76935 L .34576 .76745 L F
.826 .892 .888 r
.5388 .80542 m .53995 .80645 L .54191 .80421 L F
.949 .599 .219 r
.53995 .80645 m .54023 .8084 L .5419 .80712 L F
.799 .617 .656 r
.55582 .78926 m .55576 .79118 L .55367 .79078 L F
.55529 .78948 m .55367 .79078 L .55263 .79057 L F
.55582 .78926 m .55367 .79078 L .55529 .78948 L F
0 0 0 r
.55536 .78942 m .55433 .79034 L .55563 .78936 L F
.55535 .78943 m .55529 .78948 L .55536 .78942 L F
.55529 .78948 m .55433 .79034 L .55536 .78942 L F
.022 0 0 r
.55263 .79057 m .55433 .79034 L .55529 .78948 L F
.55263 .79057 m .55529 .78948 L .55535 .78943 L F
.799 .617 .656 r
.55582 .78916 m .55582 .78926 L .55263 .79057 L F
.599 .449 .649 r
.55798 .78852 m .55576 .79118 L .55582 .78916 L F
.231 0 0 r
.3806 .79887 m .379 .80022 L .37708 .80061 L F
.077 0 0 r
.38087 .79967 m .3806 .79887 L .38254 .79835 L F
.38087 .79967 m .379 .80022 L .3806 .79887 L F
.771 .641 .718 r
.49015 .84656 m .49273 .8441 L .49026 .84433 L F
.675 .588 .75 r
.55775 .82328 m .55846 .82608 L .56079 .82564 L F
.22 0 0 r
.38817 .72373 m .39031 .72356 L .39126 .72288 L F
.623 .101 0 r
.39031 .72356 m .39372 .72421 L .39126 .72288 L F
.365 .523 .881 r
.46847 .87633 m .47016 .8788 L .47172 .87796 L F
.316 .404 .794 r
.47147 .87966 m .47211 .87918 L .47172 .87796 L F
.318 .487 .869 r
.47246 .88031 m .47189 .8793 L .47172 .87796 L F
.559 .516 .763 r
.47172 .87796 m .47189 .8793 L .4739 .87797 L F
.485 .881 .716 r
.4739 .87797 m .47237 .87899 L .47457 .87741 L F
.47237 .87899 m .47189 .8793 L .47279 .87867 L F
.47237 .87899 m .47279 .87867 L .47457 .87741 L F
.316 .404 .794 r
.47016 .8788 m .47147 .87966 L .47172 .87796 L F
.47147 .87966 m .47246 .88031 L .47211 .87918 L F
.647 .571 .755 r
.47016 .8788 m .4733 .88139 L .47246 .88031 L F
.502 .417 .692 r
.6594 .71987 m .66145 .71925 L .6604 .71574 L F
0 0 0 r
.55535 .78943 m .55563 .78936 L .55605 .78743 L F
.037 0 0 r
.39576 .72375 m .3993 .72283 L .39715 .72312 L F
.608 .379 .544 r
.49559 .84488 m .49645 .84712 L .49736 .84562 L F
.627 .07 0 r
.68739 .71009 m .69074 .71213 L .69096 .71165 L F
.56 .402 .624 r
.69323 .70882 m .69316 .7113 L .69096 .71165 L F
0 0 0 r
.69096 .71165 m .69212 .71032 L .69323 .70882 L F
.69096 .71165 m .69074 .71213 L .69212 .71032 L F
.274 0 0 r
.69264 .71201 m .69096 .71165 L .69316 .7113 L F
.69264 .71201 m .69006 .71324 L .69096 .71165 L F
.67 .365 .448 r
.59007 .82026 m .59224 .82237 L .59316 .81989 L F
.767 .503 .535 r
.59224 .82237 m .59546 .82047 L .59316 .81989 L F
.807 .654 .693 r
.68312 .61075 m .68338 .61339 L .67984 .6126 L F
.724 .461 .528 r
.68338 .61339 m .68137 .61496 L .67984 .6126 L F
.68338 .61339 m .68309 .6154 L .68137 .61496 L F
.574 .483 .713 r
.68557 .61268 m .68338 .61339 L .68312 .61075 L F
.606 .412 .593 r
.68557 .61268 m .68309 .6154 L .68338 .61339 L F
.69 .555 .697 r
.65423 .71767 m .65419 .71983 L .65632 .7178 L F
.53 .282 .484 r
.36526 .75413 m .36489 .75628 L .36281 .75657 L F
.583 .335 .507 r
.36745 .75361 m .36489 .75628 L .36526 .75413 L F
0 0 0 r
.3705 .75099 m .3689 .75302 L .36745 .75361 L F
.484 .087 .211 r
.37114 .75275 m .3705 .75099 L .37235 .75113 L F
.37114 .75275 m .3689 .75302 L .3705 .75099 L F
.485 .131 .29 r
.35776 .76146 m .35489 .76339 L .35585 .76158 L F
.373 .189 .498 r
.47057 .84418 m .4688 .84695 L .47025 .84648 L F
.237 .124 .515 r
.4688 .84695 m .46955 .84898 L .47025 .84648 L F
.4688 .84695 m .46885 .8493 L .46955 .84898 L F
.812 .757 .801 r
.68062 .60034 m .67886 .60266 L .67724 .60199 L F
.872 .667 .622 r
.67886 .60266 m .67873 .605 L .67724 .60199 L F
.281 .047 .37 r
.34443 .73305 m .34383 .73498 L .34583 .73231 L F
.34443 .73305 m .34383 .73498 L .34583 .73231 L F
.524 .639 .905 r
.41547 .72399 m .41502 .72608 L .41349 .72493 L F
.41547 .72399 m .41701 .72607 L .41502 .72608 L F
.494 .293 .536 r
.3526 .68666 m .35039 .68893 L .35058 .68736 L F
.595 .61 .837 r
.55839 .81511 m .55949 .81229 L .56073 .81243 L F
.235 .749 .861 r
.55949 .81229 m .56266 .81213 L .56073 .81243 L F
.578 .525 .76 r
.32893 .67716 m .32979 .68033 L .33182 .67969 L F
.595 .361 .532 r
.53538 .83382 m .53492 .83626 L .53256 .8363 L F
.159 0 .371 r
.53656 .83313 m .53492 .83626 L .53538 .83382 L F
.246 0 0 r
.42184 .72701 m .42205 .72725 L .42542 .72686 L F
.214 0 .331 r
.54554 .84665 m .54404 .84765 L .54343 .84983 L F
.805 .662 .704 r
.68188 .60767 m .68312 .61075 L .68022 .6103 L F
.807 .654 .693 r
.68312 .61075 m .67984 .6126 L .68022 .6103 L F
.722 .624 .747 r
.68505 .60843 m .68312 .61075 L .68188 .60767 L F
.389 .56 .901 r
.57229 .84228 m .574 .84126 L .57192 .84117 L F
.57229 .84228 m .57517 .84332 L .574 .84126 L F
.878 .733 .697 r
.60036 .83339 m .5995 .83073 L .59924 .83309 L F
.936 .929 .567 r
.59903 .83518 m .60036 .83339 L .59924 .83309 L F
.61 .328 .464 r
.66416 .64008 m .66393 .64195 L .6617 .64166 L F
.557 .286 .461 r
.66695 .63918 m .66393 .64195 L .66416 .64008 L F
.767 .503 .535 r
.59224 .82237 m .59552 .82265 L .59546 .82047 L F
.723 .428 .478 r
.64023 .63655 m .64085 .63441 L .64019 .63267 L F
.64023 .63655 m .64151 .63605 L .64085 .63441 L F
.939 .716 .574 r
.64315 .63398 m .64019 .63267 L .64085 .63441 L F
.802 .666 .713 r
.64151 .63605 m .64315 .63398 L .64085 .63441 L F
.6 .364 .53 r
.66913 .63704 m .67146 .63888 L .66915 .63895 L F
.603 .363 .525 r
.66913 .63704 m .67148 .63686 L .67146 .63888 L F
.831 .689 .705 r
.56489 .79143 m .56493 .79423 L .56337 .79032 L F
.569 .478 .712 r
.56709 .79376 m .56493 .79423 L .56489 .79143 L F
.456 .162 .377 r
.56709 .79376 m .56459 .79593 L .56493 .79423 L F
.829 .693 .713 r
.49322 .85942 m .49724 .85838 L .49247 .8578 L F
.49333 .85965 m .49499 .85911 L .49322 .85942 L F
.49499 .85911 m .49724 .85838 L .49322 .85942 L F
.796 .701 .761 r
.49595 .85993 m .49917 .85971 L .49855 .85847 L F
.829 .693 .713 r
.49333 .85965 m .49595 .85993 L .49724 .85838 L F
.722 .934 .608 r
.49724 .85838 m .49595 .85993 L .49799 .85736 L F
.796 .701 .761 r
.49687 .85877 m .49855 .85847 L .49799 .85736 L F
.49595 .85993 m .49855 .85847 L .49687 .85877 L F
.567 .225 .349 r
.49579 .86228 m .49917 .85971 L .49595 .85993 L F
.49579 .86228 m .49794 .86224 L .49917 .85971 L F
.767 .535 .582 r
.49794 .86224 m .50119 .85982 L .49917 .85971 L F
.915 .791 .709 r
.54653 .83524 m .54917 .8339 L .54804 .83332 L F
.54653 .83524 m .54805 .83676 L .54917 .8339 L F
.73 .648 .768 r
.71351 .71575 m .71058 .71399 L .71288 .71316 L F
.744 .672 .78 r
.71641 .71328 m .71351 .71575 L .71288 .71316 L F
.417 .117 .345 r
.35227 .76603 m .35127 .76498 L .35283 .76405 L F
.35227 .76603 m .35053 .76669 L .35127 .76498 L F
.503 .755 .986 r
.31952 .65471 m .31891 .65606 L .31784 .65461 L F
.31952 .65471 m .32087 .65581 L .31891 .65606 L F
.585 .473 .692 r
.45322 .7399 m .45372 .74311 L .45157 .7434 L F
.572 .469 .698 r
.45372 .74311 m .45198 .74581 L .45157 .7434 L F
.773 .654 .73 r
.69559 .735 m .69684 .73804 L .69874 .7353 L F
.94 .801 .68 r
.6882 .73547 m .68766 .73763 L .68697 .73476 L F
.707 .709 .85 r
.67962 .72692 m .68236 .72523 L .67918 .72417 L F
.977 .86 .656 r
.67962 .72692 m .67918 .72417 L .67864 .72615 L F
.503 .402 .673 r
.33085 .74864 m .33021 .74574 L .32988 .74599 L F
.33085 .74864 m .33235 .74537 L .33021 .74574 L F
.33085 .74864 m .33251 .74812 L .33235 .74537 L F
.606 .402 .58 r
.33028 .75074 m .33251 .74812 L .33085 .74864 L F
.793 .705 .767 r
.56685 .78908 m .56337 .79032 L .56564 .78801 L F
.56685 .78908 m .56489 .79143 L .56337 .79032 L F
.53 .348 .578 r
.3284 .68749 m .33065 .68716 L .33063 .68474 L F
.399 .296 .622 r
.3284 .68749 m .33029 .68929 L .33065 .68716 L F
.3284 .68749 m .32835 .69023 L .33029 .68929 L F
.981 .868 .496 r
.67233 .63283 m .67261 .6344 L .67321 .63173 L F
.147 0 .339 r
.67519 .62852 m .6749 .6309 L .67321 .63173 L F
0 0 0 r
.67321 .63173 m .6749 .6309 L .67233 .63283 L F
.706 .299 .274 r
.48205 .88455 m .48408 .88653 L .48067 .88617 L F
.903 .754 .687 r
.69409 .74552 m .69522 .74604 L .69462 .74302 L F
.806 .622 .654 r
.69409 .74552 m .6958 .74836 L .69522 .74604 L F
.753 .665 .764 r
.69462 .74302 m .69522 .74604 L .69797 .74331 L F
.327 .764 .967 r
.40728 .74366 m .40592 .74316 L .40386 .74331 L F
.497 .849 .994 r
.408 .74267 m .40728 .74366 L .40928 .74301 L F
.408 .74267 m .40592 .74316 L .40728 .74366 L F
.633 .781 .952 r
.40048 .74275 m .40183 .74395 L .40386 .74331 L F
.802 .666 .713 r
.64151 .63605 m .64415 .63704 L .64315 .63398 L F
.62 .057 0 r
.64337 .63756 m .64415 .63704 L .64151 .63605 L F
0 0 0 r
.64337 .63756 m .64564 .63607 L .64415 .63704 L F
.146 .508 .911 r
.4733 .88139 m .47409 .88085 L .47246 .88031 L F
.283 .736 .957 r
.4733 .88139 m .47542 .88136 L .47409 .88085 L F
.357 .455 .824 r
.68884 .70838 m .68739 .71009 L .68649 .70928 L F
.68884 .70838 m .69074 .71213 L .68739 .71009 L F
.319 .795 .714 r
.35564 .80872 m .36017 .80699 L .3591 .80743 L F
0 0 0 r
.3591 .80743 m .36017 .80699 L .36213 .80647 L F
.708 .333 .336 r
.35125 .7364 m .3549 .73515 L .35294 .73563 L F
.556 .365 .577 r
.42836 .7647 m .43054 .76435 L .43056 .76178 L F
.502 .321 .569 r
.43056 .76178 m .43248 .76391 L .43261 .76154 L F
.43056 .76178 m .43054 .76435 L .43248 .76391 L F
.549 .376 .6 r
.64534 .62891 m .64327 .62636 L .64409 .6282 L F
.537 .06 .071 r
.64664 .63048 m .64534 .62891 L .64409 .6282 L F
.64664 .63048 m .64727 .62933 L .64534 .62891 L F
.803 .576 .595 r
.59846 .82521 m .59856 .82302 L .59552 .82265 L F
.462 .329 .614 r
.32153 .70611 m .32294 .70505 L .32355 .70132 L F
.322 .073 .372 r
.32092 .70815 m .32294 .70505 L .32153 .70611 L F
.58 .831 .992 r
.4805 .85676 m .48141 .85785 L .47867 .85747 L F
.802 .677 .725 r
.48141 .85785 m .47999 .86047 L .47867 .85747 L F
.426 .225 .502 r
.48173 .8599 m .47999 .86047 L .48141 .85785 L F
.844 .923 .884 r
.48386 .8554 m .48141 .85785 L .4805 .85676 L F
.81 .693 .736 r
.53665 .81993 m .53782 .82289 L .53961 .8204 L F
.715 .83 .936 r
.7004 .70744 m .69994 .70801 L .70409 .7069 L F
.315 .174 .525 r
.7004 .70744 m .69838 .71075 L .69875 .7095 L F
.7004 .70744 m .69875 .7095 L .69892 .70894 L F
.715 .83 .936 r
.7004 .70744 m .69981 .70805 L .69994 .70801 L F
0 0 0 r
.7004 .70744 m .69892 .70894 L .69981 .70805 L F
.798 .758 .816 r
.70066 .7071 m .69892 .70894 L .69785 .7063 L F
.414 .191 .464 r
.32904 .71425 m .32861 .71656 L .32685 .71703 L F
.388 .13 .396 r
.32861 .71656 m .32634 .71898 L .32685 .71703 L F
.741 .648 .756 r
.49932 .87592 m .5007 .87908 L .50315 .87649 L F
.572 .469 .698 r
.45372 .74311 m .45408 .74544 L .45198 .74581 L F
.609 .514 .721 r
.455 .74865 m .45198 .74581 L .45408 .74544 L F
.455 .74865 m .45284 .7492 L .45198 .74581 L F
0 .412 .813 r
.53817 .82774 m .53931 .82858 L .53929 .82857 L F
.53817 .82774 m .53929 .82857 L .53653 .82716 L F
1 .8 .476 r
.53831 .83023 m .53707 .82636 L .53455 .8275 L F
.53831 .83023 m .53817 .82774 L .53707 .82636 L F
.982 .725 .463 r
.53817 .82774 m .53729 .82947 L .53711 .82696 L F
.53817 .82774 m .53711 .82696 L .53707 .82636 L F
.886 .879 .822 r
.53931 .82858 m .53836 .83063 L .53817 .82774 L F
0 0 0 r
.53836 .83063 m .53788 .83269 L .53656 .83313 L F
.886 .879 .822 r
.53931 .82858 m .53836 .83063 L .53817 .82774 L F
.154 0 0 r
.54169 .83214 m .53788 .83269 L .53836 .83063 L F
.536 .071 .097 r
.54245 .83076 m .54169 .83214 L .53836 .83063 L F
.539 .525 .788 r
.31105 .65181 m .31022 .65436 L .30949 .65273 L F
.31105 .65181 m .31187 .65506 L .31022 .65436 L F
.597 .635 .859 r
.70524 .71627 m .70339 .71722 L .70195 .71438 L F
.16 0 .091 r
.70524 .71627 m .70303 .7177 L .70339 .71722 L F
.70339 .71722 m .70303 .7177 L .70524 .71627 L F
.784 .604 .656 r
.58263 .80411 m .58124 .80685 L .5845 .80705 L F
.779 .672 .746 r
.58124 .80685 m .58251 .80969 L .5845 .80705 L F
.524 .176 .32 r
.65955 .64195 m .66085 .64393 L .65866 .64441 L F
.65955 .64195 m .6617 .64166 L .66085 .64393 L F
.493 .338 .599 r
.3233 .7003 m .32512 .70014 L .32494 .69791 L F
.464 .285 .552 r
.32355 .70132 m .32512 .70014 L .3233 .7003 L F
.503 .283 .513 r
.35391 .68566 m .35294 .68466 L .35487 .68422 L F
.35391 .68566 m .3526 .68666 L .35294 .68466 L F
.438 .021 .148 r
.41513 .78262 m .41183 .78451 L .41314 .78278 L F
.305 .415 .81 r
.5493 .78581 m .55188 .78838 L .55155 .7859 L F
.377 .159 .451 r
.33029 .71581 m .32904 .71425 L .33084 .71371 L F
.33029 .71581 m .32861 .71656 L .32904 .71425 L F
.566 .642 .885 r
.44209 .73075 m .44081 .73272 L .43925 .73046 L F
.44209 .73075 m .44286 .73243 L .44081 .73272 L F
.563 .862 .996 r
.39011 .78251 m .38817 .78316 L .38893 .78197 L F
.668 .974 .89 r
.38817 .78316 m .3872 .78317 L .38893 .78197 L F
.582 .374 .564 r
.61367 .63701 m .61124 .64001 L .61384 .63924 L F
.61367 .63701 m .61124 .64001 L .61384 .63924 L F
.675 .508 .652 r
.46517 .75647 m .4629 .75907 L .46291 .75671 L F
.701 .816 .936 r
.64579 .59822 m .64698 .59938 L .64363 .59923 L F
.787 .646 .707 r
.64363 .59923 m .64698 .59938 L .64491 .6026 L F
.717 .709 .841 r
.64579 .59822 m .64937 .59899 L .64698 .59938 L F
.769 .675 .759 r
.67971 .59731 m .68062 .60034 L .67779 .59974 L F
.812 .757 .801 r
.68062 .60034 m .67724 .60199 L .67779 .59974 L F
.68 .625 .786 r
.68284 .59965 m .68062 .60034 L .67971 .59731 L F
.681 .251 .221 r
.50029 .86793 m .50361 .86818 L .50245 .86966 L F
0 0 0 r
.50245 .86966 m .50361 .86818 L .50509 .8675 L F
.715 .706 .841 r
.69369 .71829 m .69536 .71941 L .69212 .71899 L F
.316 0 0 r
.41264 .74304 m .41144 .7433 L .40928 .74301 L F
.252 .762 .85 r
.41473 .74299 m .41144 .7433 L .41264 .74304 L F
.496 .282 .519 r
.4799 .87321 m .47735 .87628 L .47736 .87366 L F
.731 .437 .482 r
.67473 .71863 m .67634 .71668 L .67512 .71632 L F
.67473 .71863 m .67804 .71888 L .67634 .71668 L F
.805 .727 .778 r
.64285 .60175 m .64491 .6026 L .64415 .60543 L F
.64285 .60175 m .64415 .60543 L .64379 .60372 L F
.743 .899 .948 r
.64207 .60476 m .64415 .60543 L .64266 .60766 L F
.64207 .60476 m .64379 .60372 L .64415 .60543 L F
.541 .361 .586 r
.56685 .83073 m .56517 .83364 L .56725 .8333 L F
.028 0 .414 r
.56685 .83073 m .56833 .82763 L .56964 .8283 L F
.56685 .83073 m .56826 .82999 L .56833 .82763 L F
.183 .157 .592 r
.56725 .8333 m .56826 .82999 L .56685 .83073 L F
.812 .673 .71 r
.56109 .82983 m .56216 .83356 L .56285 .83041 L F
.805 .591 .612 r
.54668 .80948 m .54957 .81241 L .54845 .80992 L F
.345 .549 .908 r
.43826 .72906 m .43737 .73033 L .43652 .72877 L F
.405 .632 .947 r
.43826 .72906 m .43925 .73046 L .43737 .73033 L F
.773 .669 .748 r
.68584 .74268 m .68696 .74563 L .6835 .74531 L F
.749 .733 .838 r
.68696 .74563 m .68491 .74641 L .6835 .74531 L F
.709 .637 .775 r
.68756 .74343 m .68696 .74563 L .68584 .74268 L F
.389 0 .172 r
.41744 .76957 m .41935 .76925 L .42061 .76728 L F
.665 .298 .339 r
.42061 .76728 m .41935 .76925 L .42258 .76911 L F
.341 0 .137 r
.65421 .64528 m .6534 .64705 L .65135 .64689 L F
.363 0 .12 r
.65421 .64528 m .65554 .64655 L .6534 .64705 L F
.65421 .64528 m .65641 .64485 L .65554 .64655 L F
.601 .291 .416 r
.53043 .83894 m .53244 .84074 L .53027 .84054 L F
.595 .313 .459 r
.43503 .77256 m .43242 .77454 L .43282 .77268 L F
.333 .296 .668 r
.6429 .631 m .64409 .6282 L .64173 .63068 L F
.6429 .631 m .64442 .63048 L .64409 .6282 L F
0 0 0 r
.64234 .63183 m .6429 .631 L .64315 .63398 L F
.64234 .63183 m .64442 .63048 L .6429 .631 L F
.761 .627 .713 r
.69462 .74302 m .69797 .74331 L .69649 .74033 L F
0 .108 .658 r
.42773 .74145 m .42785 .7412 L .42552 .74134 L F
.42773 .74145 m .42902 .74309 L .42785 .7412 L F
.353 .594 .937 r
.66847 .61076 m .66522 .60875 L .66806 .60938 L F
.09 .244 .73 r
.67032 .6112 m .66847 .61076 L .66806 .60938 L F
.67032 .6112 m .66946 .61204 L .66847 .61076 L F
.031 .586 .82 r
.47542 .88136 m .47827 .88185 L .47705 .88153 L F
0 .176 .709 r
.47827 .88185 m .48006 .88287 L .47705 .88153 L F
.47827 .88185 m .48008 .88385 L .48006 .88287 L F
0 0 0 r
.50798 .88292 m .50923 .88151 L .50639 .88328 L F
.58 .123 .131 r
.51026 .88335 m .50923 .88151 L .50798 .88292 L F
.51026 .88335 m .5113 .88201 L .50923 .88151 L F
.404 .041 .23 r
.36216 .73201 m .3642 .73162 L .36545 .72943 L F
.491 .139 .296 r
.3642 .73162 m .36753 .72924 L .36545 .72943 L F
.659 .626 .806 r
.70323 .73058 m .70644 .73247 L .70536 .7298 L F
.676 .661 .828 r
.70536 .7298 m .70644 .73247 L .7088 .73177 L F
0 0 0 r
.38708 .79592 m .39067 .79421 L .38896 .7953 L F
.38896 .7953 m .39067 .79421 L .39251 .79331 L F
.81 .636 .666 r
.58002 .80149 m .57982 .80397 L .58263 .80411 L F
.81 .638 .669 r
.57982 .80397 m .58124 .80685 L .58263 .80411 L F
.579 .311 .475 r
.42791 .76625 m .43054 .76435 L .42836 .7647 L F
.57 .378 .582 r
.53287 .85158 m .53478 .85215 L .53275 .8495 L F
.775 .45 .437 r
.51573 .85328 m .51623 .85632 L .51472 .85391 L F
.51 .361 .614 r
.51757 .85193 m .51573 .85328 L .51678 .85205 L F
.51754 .85231 m .51573 .85328 L .51757 .85193 L F
.51852 .85178 m .51892 .85423 L .51573 .85328 L F
.609 .399 .572 r
.51892 .85423 m .51623 .85632 L .51573 .85328 L F
.663 .397 .508 r
.51644 .85107 m .51538 .85458 L .51738 .85438 L F
.51753 .85246 m .51738 .85438 L .51892 .85423 L F
.51644 .85107 m .51738 .85438 L .51753 .85246 L F
.51 .361 .614 r
.51852 .85178 m .51754 .85231 L .51757 .85193 L F
.61 .589 .804 r
.48174 .87541 m .48088 .87845 L .47971 .87624 L F
.48174 .87541 m .48316 .87838 L .48088 .87845 L F
.405 .375 .712 r
.35816 .67788 m .35679 .67918 L .35644 .67647 L F
.461 .35 .641 r
.35816 .67788 m .35658 .68178 L .35679 .67918 L F
0 0 .313 r
.68358 .71022 m .6841 .71178 L .68383 .71002 L F
.766 .498 .53 r
.53335 .81966 m .53627 .8177 L .5365 .8183 L F
.897 .736 .675 r
.57434 .80737 m .57199 .80902 L .57265 .8066 L F
.57434 .80737 m .57367 .80954 L .57199 .80902 L F
.579 .943 .854 r
.5066 .88826 m .51031 .88662 L .50961 .88718 L F
0 0 0 r
.51163 .8863 m .51031 .88662 L .51215 .88573 L F
.50961 .88718 m .51031 .88662 L .51163 .8863 L F
.634 .58 .777 r
.68789 .60959 m .68505 .60843 L .68717 .6078 L F
.362 .1 .377 r
.48547 .86245 m .48536 .86473 L .48337 .86521 L F
.317 .349 .736 r
.48519 .86019 m .48707 .86195 L .48547 .86245 L F
.183 0 .334 r
.48707 .86195 m .48536 .86473 L .48547 .86245 L F
.478 .438 .735 r
.51644 .85107 m .51852 .85178 L .51678 .85205 L F
.663 .397 .508 r
.51644 .85107 m .51892 .85423 L .51852 .85178 L F
.571 .281 .437 r
.44571 .76695 m .44469 .76965 L .4424 .76967 L F
.549 .259 .427 r
.44752 .76843 m .44571 .76695 L .44772 .76728 L F
.44752 .76843 m .44469 .76965 L .44571 .76695 L F
.571 .587 .831 r
.67519 .62852 m .67247 .62668 L .67524 .62634 L F
.51 .333 .577 r
.67684 .62593 m .67519 .62852 L .67524 .62634 L F
.549 .857 .997 r
.57517 .84332 m .57821 .84341 L .57722 .84238 L F
.751 .884 .94 r
.57722 .84238 m .57821 .84341 L .58072 .84174 L F
.801 .469 .425 r
.58743 .81964 m .58894 .82212 L .59007 .82026 L F
.708 .351 .369 r
.58894 .82212 m .59224 .82237 L .59007 .82026 L F
.547 .617 .873 r
.6771 .73759 m .67609 .73522 L .67373 .73538 L F
.601 .587 .809 r
.6771 .73759 m .67824 .73429 L .67609 .73522 L F
.6771 .73759 m .67909 .73705 L .67824 .73429 L F
.285 .082 .42 r
.33228 .71299 m .33122 .71158 L .33283 .71099 L F
.33228 .71299 m .33084 .71371 L .33122 .71158 L F
.803 .712 .765 r
.66767 .71875 m .66505 .7218 L .66817 .722 L F
.693 .615 .765 r
.66505 .7218 m .66862 .72405 L .66817 .722 L F
.26 .317 .732 r
.66817 .722 m .66954 .72082 L .66767 .71875 L F
.218 .189 .611 r
.66862 .72405 m .66954 .72082 L .66817 .722 L F
.343 0 .202 r
.39807 .77816 m .39546 .77993 L .39744 .77935 L F
.258 0 .07 r
.39744 .77935 m .40015 .77768 L .39807 .77816 L F
.657 .874 .98 r
.36212 .79101 m .35881 .79116 L .36083 .79008 L F
.635 .823 .973 r
.36408 .79025 m .36212 .79101 L .36083 .79008 L F
.793 .588 .623 r
.50565 .85216 m .50222 .8543 L .50321 .85245 L F
.50565 .85216 m .50577 .85462 L .50222 .8543 L F
.615 .449 .634 r
.50565 .85216 m .50906 .85424 L .50577 .85462 L F
.686 .16 0 r
.50418 .85203 m .50906 .85424 L .50565 .85216 L F
.708 .635 .773 r
.46192 .87221 m .46457 .87022 L .46252 .87089 L F
.007 0 0 r
.50639 .88328 m .50389 .88432 L .50602 .88394 L F
0 0 0 r
.50798 .88292 m .50639 .88328 L .50602 .88394 L F
.815 .686 .722 r
.58064 .8092 m .58251 .80969 L .58124 .80685 L F
.802 .571 .588 r
.57963 .81146 m .58251 .80969 L .58064 .8092 L F
.57963 .81146 m .58258 .8121 L .58251 .80969 L F
.754 .349 .284 r
.55576 .79118 m .5548 .79281 L .55263 .79057 L F
.698 .282 .253 r
.55806 .79307 m .5548 .79281 L .55576 .79118 L F
.782 .698 .772 r
.66386 .71637 m .66709 .71665 L .66587 .71419 L F
.704 .466 .56 r
.66393 .71865 m .66709 .71665 L .66386 .71637 L F
.66393 .71865 m .66767 .71875 L .66709 .71665 L F
.41 .51 .85 r
.66709 .71665 m .66895 .71571 L .66587 .71419 L F
.151 .069 .501 r
.66767 .71875 m .66895 .71571 L .66709 .71665 L F
.821 .674 .7 r
.69559 .735 m .69362 .73818 L .69684 .73804 L F
.781 .673 .744 r
.69362 .73818 m .69649 .74033 L .69684 .73804 L F
.677 .395 .486 r
.63209 .64772 m .63052 .64858 L .63093 .6475 L F
.63209 .64772 m .63243 .64956 L .63052 .64858 L F
.514 .391 .65 r
.33063 .68474 m .33267 .68432 L .33228 .68183 L F
.496 .321 .573 r
.33063 .68474 m .3323 .68664 L .33267 .68432 L F
.33063 .68474 m .33065 .68716 L .3323 .68664 L F
.186 0 0 r
.56309 .7969 m .5619 .79776 L .55985 .79809 L F
0 0 0 r
.56459 .79593 m .5619 .79776 L .56309 .7969 L F
.798 .758 .816 r
.70066 .7071 m .69785 .7063 L .69908 .70592 L F
.595 .61 .837 r
.55839 .81511 m .56064 .81474 L .55949 .81229 L F
.741 .992 .855 r
.67804 .71888 m .68008 .7172 L .68062 .71728 L F
.29 .472 .866 r
.68214 .71651 m .68062 .71728 L .68008 .7172 L F
.68214 .71651 m .68261 .71873 L .68062 .71728 L F
.915 .846 .762 r
.56982 .79804 m .57102 .799 L .57076 .79837 L F
.955 .681 .235 r
.57102 .799 m .57125 .80115 L .57076 .79837 L F
.84 .865 .862 r
.57343 .79625 m .57102 .799 L .56982 .79804 L F
.759 .595 .674 r
.57701 .81783 m .57249 .81989 L .57319 .81808 L F
.57701 .81783 m .57642 .82037 L .57249 .81989 L F
.901 .51 .269 r
.71591 .7155 m .71641 .71328 L .71666 .71214 L F
.71591 .7155 m .71741 .71593 L .71641 .71328 L F
.449 .057 .202 r
.36967 .72909 m .37178 .7289 L .37302 .72694 L F
.446 .07 .232 r
.37178 .7289 m .37518 .72652 L .37302 .72694 L F
.595 .023 0 r
.5172 .88322 m .51512 .88227 L .51663 .88335 L F
.048 .238 .736 r
.5172 .88322 m .51654 .88118 L .51663 .88335 L F
.868 .959 .862 r
.51423 .88532 m .5172 .88322 L .51663 .88335 L F
.662 .884 .98 r
.5172 .88322 m .51912 .88137 L .51663 .88335 L F
.5172 .88322 m .52066 .88212 L .51912 .88137 L F
.492 .353 .619 r
.53913 .84222 m .54069 .8386 L .53851 .83854 L F
.231 .069 .444 r
.47057 .84418 m .4721 .84547 L .47276 .84365 L F
.47057 .84418 m .47025 .84648 L .4721 .84547 L F
.382 .831 .935 r
.53478 .85215 m .53603 .85233 L .53721 .85172 L F
.517 .477 .75 r
.34551 .66763 m .34375 .66919 L .34293 .66611 L F
.48 .41 .701 r
.34551 .66763 m .34417 .67139 L .34375 .66919 L F
.629 .451 .623 r
.32984 .74577 m .33021 .74574 L .33135 .74324 L F
.66 .486 .639 r
.33135 .74324 m .33235 .74537 L .33207 .74331 L F
.33135 .74324 m .33021 .74574 L .33235 .74537 L F
.466 .054 .174 r
.66731 .61782 m .66706 .61846 L .66471 .61868 L F
0 0 0 r
.66902 .61711 m .66731 .61782 L .67032 .61637 L F
.647 .627 .816 r
.43436 .72911 m .43094 .72701 L .43318 .72665 L F
.62 .057 0 r
.43318 .72665 m .43652 .72877 L .43436 .72911 L F
.909 .829 .755 r
.50048 .88739 m .50097 .88705 L .49952 .88936 L F
.8 .454 .401 r
.50097 .88705 m .50162 .88901 L .49952 .88936 L F
0 0 .541 r
.67312 .73332 m .67373 .73538 L .67294 .73207 L F
.628 .918 .978 r
.55648 .82294 m .55775 .82328 L .55843 .82208 L F
.55648 .82294 m .55775 .82328 L .55843 .82208 L F
.743 .507 .573 r
.63093 .6475 m .62747 .64921 L .6275 .6473 L F
.63093 .6475 m .63052 .64858 L .62747 .64921 L F
.823 .672 .696 r
.58419 .81703 m .5868 .81748 L .58559 .81472 L F
.82 .525 .491 r
.58419 .81703 m .58547 .81966 L .5868 .81748 L F
.843 .557 .504 r
.5868 .81748 m .58547 .81966 L .58743 .81964 L F
.348 0 0 r
.37734 .72662 m .37946 .72651 L .38095 .72533 L F
.322 0 0 r
.37946 .72651 m .38302 .72499 L .38095 .72533 L F
.615 .423 .599 r
.46517 .75647 m .46515 .75896 L .4629 .75907 L F
.596 .386 .566 r
.46741 .75618 m .46515 .75896 L .46517 .75647 L F
.887 .708 .654 r
.59715 .82954 m .5999 .82825 L .59821 .82761 L F
.59715 .82954 m .5995 .83073 L .5999 .82825 L F
.354 0 0 r
.64828 .61837 m .64765 .61818 L .64581 .61734 L F
.643 .965 .9 r
.64943 .61704 m .64765 .61818 L .64828 .61837 L F
.608 .464 .661 r
.46712 .85177 m .46868 .85454 L .46886 .85147 L F
.46712 .85177 m .46721 .8556 L .46868 .85454 L F
.57 .777 .977 r
.32431 .65647 m .32087 .65581 L .32304 .65566 L F
.464 .764 .995 r
.32503 .65535 m .32431 .65647 L .32304 .65566 L F
.32503 .65535 m .32677 .65638 L .32431 .65647 L F
.042 0 0 r
.69323 .70882 m .69212 .71032 L .69476 .70852 L F
.684 .724 .88 r
.49305 .88521 m .49004 .88647 L .4901 .8844 L F
.07 .55 .897 r
.54094 .84126 m .54238 .84352 L .54113 .84117 L F
.53913 .84222 m .5399 .84253 L .54094 .84126 L F
.5399 .84253 m .54238 .84352 L .54094 .84126 L F
.419 .794 .993 r
.54238 .84352 m .54303 .84254 L .54121 .84114 L F
.54238 .84352 m .54121 .84114 L .54108 .84109 L F
.299 .21 .585 r
.54094 .84126 m .54094 .84132 L .54217 .83978 L F
.54094 .84132 m .54098 .84168 L .54139 .84103 L F
.54094 .84132 m .54139 .84103 L .54217 .83978 L F
.54217 .83978 m .5413 .84117 L .54267 .84018 L F
.4 .401 .745 r
.54104 .84101 m .54121 .84114 L .54267 .84018 L F
.54121 .84114 m .54303 .84254 L .54267 .84018 L F
.419 .794 .993 r
.54108 .84109 m .54121 .84114 L .54104 .84101 L F
.299 .21 .585 r
.5413 .84117 m .54098 .84168 L .54148 .84124 L F
.5413 .84117 m .54148 .84124 L .54267 .84018 L F
.54069 .8386 m .54094 .84126 L .54217 .83978 L F
.492 .353 .619 r
.53913 .84222 m .54098 .84168 L .54094 .84126 L F
.53913 .84222 m .54094 .84126 L .54069 .8386 L F
.07 .55 .897 r
.53913 .84222 m .54113 .84117 L .54104 .84101 L F
.419 .794 .993 r
.54238 .84352 m .54503 .84317 L .54303 .84254 L F
.128 .435 .874 r
.46482 .75184 m .46282 .75184 L .46201 .75134 L F
.46482 .75184 m .46584 .75336 L .46282 .75184 L F
.264 0 0 r
.42785 .7412 m .42493 .7415 L .42552 .74134 L F
.526 .164 .295 r
.67155 .61509 m .66902 .61711 L .67032 .61637 L F
0 0 0 r
.36779 .80443 m .36622 .80511 L .36419 .80563 L F
.17 0 0 r
.36952 .8036 m .36622 .80511 L .36779 .80443 L F
.93 .678 .196 r
.68766 .73763 m .68724 .73726 L .68697 .73476 L F
.923 .911 .79 r
.68628 .74063 m .68724 .73726 L .68766 .73763 L F
.732 .752 .869 r
.59359 .84079 m .59492 .84214 L .59644 .84079 L F
.594 .683 .904 r
.45164 .73483 m .44954 .73524 L .44855 .7337 L F
.491 .294 .539 r
.45738 .76342 m .45534 .76182 L .45749 .76156 L F
.45738 .76342 m .45678 .76381 L .45534 .76182 L F
.848 .386 .054 r
.5592 .7937 m .55925 .79527 L .55806 .79307 L F
0 0 .474 r
.5592 .7937 m .55996 .79641 L .56017 .79581 L F
.848 .386 .054 r
.5592 .7937 m .56017 .79581 L .55925 .79527 L F
.904 .873 .796 r
.54128 .82584 m .53817 .82774 L .53995 .82493 L F
.54128 .82584 m .53931 .82858 L .53817 .82774 L F
.724 .599 .716 r
.53955 .82318 m .54128 .82584 L .54135 .82327 L F
.636 .1 0 r
.54066 .8267 m .54128 .82584 L .53995 .82493 L F
.54066 .8267 m .54353 .82742 L .54128 .82584 L F
.543 .293 .486 r
.54128 .82584 m .54353 .82742 L .54295 .82562 L F
.646 .495 .664 r
.3456 .77161 m .34345 .76981 L .34565 .76935 L F
.3456 .77161 m .34267 .77219 L .34345 .76981 L F
.695 .719 .868 r
.6882 .75125 m .6916 .75192 L .6904 .75067 L F
.768 .766 .851 r
.6904 .75067 m .6916 .75192 L .69358 .75073 L F
.509 .226 .42 r
.36489 .75628 m .36231 .7585 L .36281 .75657 L F
0 .221 .698 r
.32642 .67301 m .32912 .67514 L .3279 .67404 L F
.32912 .67514 m .32909 .67507 L .32817 .67426 L F
.538 .345 .566 r
.32642 .67301 m .32797 .67409 L .329 .67475 L F
.772 .413 .375 r
.3316 .67491 m .32852 .67394 L .32964 .67555 L F
.32852 .67394 m .32738 .67357 L .32797 .67409 L F
.32852 .67394 m .32797 .67409 L .32964 .67555 L F
0 .277 .748 r
.32964 .67555 m .329 .67475 L .32797 .67409 L F
.538 .345 .566 r
.32797 .67409 m .32883 .67484 L .32895 .67477 L F
0 .221 .698 r
.32912 .67514 m .32817 .67426 L .32809 .67421 L F
.538 .345 .566 r
.32797 .67409 m .32694 .67593 L .32883 .67484 L F
.32642 .67301 m .32668 .67446 L .32797 .67409 L F
.32668 .67446 m .32694 .67593 L .32797 .67409 L F
.32797 .67409 m .32895 .67477 L .329 .67475 L F
0 .277 .748 r
.32797 .67409 m .329 .67475 L .32738 .67357 L F
0 .221 .698 r
.32809 .67421 m .32817 .67426 L .32738 .67357 L F
.261 .697 .963 r
.3277 .67689 m .32771 .67652 L .32568 .67645 L F
.129 0 0 r
.32595 .67744 m .32568 .67645 L .32771 .67652 L F
.465 .219 .455 r
.32694 .67593 m .32595 .67744 L .32896 .67478 L F
.32895 .67477 m .32896 .67478 L .329 .67475 L F
.32694 .67593 m .32896 .67478 L .32895 .67477 L F
0 .221 .698 r
.32642 .67301 m .3279 .67404 L .32738 .67357 L F
.32912 .67514 m .32964 .67555 L .32909 .67507 L F
.715 .98 .777 r
.32897 .67479 m .32774 .67587 L .32771 .67652 L F
.329 .67475 m .32896 .67478 L .32897 .67479 L F
.32896 .67478 m .32774 .67587 L .32897 .67479 L F
.32774 .67587 m .32595 .67744 L .32771 .67652 L F
.261 .697 .963 r
.32893 .67716 m .32771 .67652 L .3277 .67689 L F
.696 .881 .967 r
.32964 .67555 m .32893 .67716 L .33106 .67647 L F
.32964 .67555 m .32771 .67652 L .32893 .67716 L F
.578 .525 .76 r
.32893 .67716 m .33182 .67969 L .33106 .67647 L F
.584 .881 .992 r
.62668 .64083 m .62771 .64139 L .62571 .64208 L F
.991 .736 .385 r
.62571 .64208 m .62577 .64444 L .62495 .64376 L F
.62571 .64208 m .62495 .64376 L .62668 .64083 L F
.693 .482 .597 r
.55635 .78338 m .55688 .78541 L .55689 .78306 L F
.549 .366 .585 r
.55689 .78306 m .55688 .78541 L .55934 .78424 L F
.451 .681 .963 r
.31482 .67629 m .31561 .67495 L .31339 .67563 L F
.31482 .67629 m .3168 .67628 L .31561 .67495 L F
.139 .359 .818 r
.67797 .62199 m .67609 .62206 L .67542 .62039 L F
.67797 .62199 m .67759 .62342 L .67609 .62206 L F
.856 .696 .682 r
.47792 .85942 m .47999 .86047 L .47867 .85747 L F
.47792 .85942 m .47999 .86047 L .47867 .85747 L F
.584 .593 .827 r
.4389 .75055 m .43965 .74751 L .43765 .74796 L F
.4389 .75055 m .44115 .75049 L .43965 .74751 L F
.595 .595 .823 r
.34753 .67383 m .34417 .67139 L .34596 .6711 L F
.53 .592 .861 r
.34791 .67074 m .34753 .67383 L .34596 .6711 L F
.34791 .67074 m .34944 .67361 L .34753 .67383 L F
.696 .455 .554 r
.51331 .8628 m .51635 .86528 L .51333 .86499 L F
.51331 .8628 m .51635 .86528 L .51333 .86499 L F
.603 .113 0 r
.66979 .72715 m .67019 .72774 L .66936 .72632 L F
.66979 .72715 m .67163 .72936 L .67019 .72774 L F
.336 .239 .594 r
.32835 .69023 m .33009 .69164 L .33029 .68929 L F
.32835 .69023 m .32865 .69243 L .33009 .69164 L F
.526 .449 .712 r
.46421 .86799 m .46561 .86455 L .46374 .86554 L F
.564 .217 .339 r
.40728 .77374 m .41053 .77172 L .40771 .77282 L F
.40728 .77374 m .40937 .77395 L .41053 .77172 L F
.396 0 .129 r
.41053 .77172 m .41188 .77223 L .41253 .77148 L F
.321 0 .171 r
.40937 .77395 m .41188 .77223 L .41053 .77172 L F
.426 .306 .614 r
.47712 .85129 m .47666 .8548 L .47502 .85305 L F
.468 .744 .989 r
.41204 .72387 m .41116 .72511 L .40996 .72413 L F
.41204 .72387 m .41349 .72493 L .41116 .72511 L F
.496 .359 .624 r
.53134 .8177 m .53335 .81966 L .53181 .81897 L F
.976 .808 .609 r
.53181 .81897 m .53122 .82002 L .53096 .81983 L F
.53122 .82002 m .53006 .82208 L .53096 .81983 L F
.447 .842 .979 r
.53117 .81866 m .53335 .81966 L .53134 .8177 L F
0 0 0 r
.53194 .81901 m .53181 .81897 L .53335 .81966 L F
.447 .842 .979 r
.53151 .81979 m .53335 .81966 L .53194 .81901 L F
0 0 0 r
.53247 .81921 m .53194 .81901 L .53335 .81966 L F
.447 .842 .979 r
.53151 .81979 m .53247 .81921 L .53335 .81966 L F
0 0 0 r
.53247 .81921 m .5306 .82143 L .53194 .81901 L F
.447 .842 .979 r
.53096 .81983 m .53247 .81921 L .53151 .81979 L F
0 0 0 r
.53194 .81901 m .53143 .81984 L .53181 .81897 L F
.53143 .81984 m .53006 .82208 L .53126 .81994 L F
.53143 .81984 m .53126 .81994 L .53181 .81897 L F
.5306 .82143 m .53006 .82208 L .53194 .81901 L F
.447 .842 .979 r
.53096 .81983 m .53151 .81979 L .53117 .81866 L F
.53151 .81979 m .53194 .81901 L .53117 .81866 L F
.467 .793 .999 r
.53096 .81983 m .53247 .81921 L .52988 .81908 L F
.53096 .81983 m .52988 .81908 L .52859 .81902 L F
.659 .609 .788 r
.66275 .72436 m .66591 .72637 L .66647 .72518 L F
.71 .663 .802 r
.66647 .72518 m .66591 .72637 L .66862 .72405 L F
.825 .73 .759 r
.70277 .70332 m .70003 .70343 L .70073 .70056 L F
.522 .675 .934 r
.70439 .70175 m .70277 .70332 L .70073 .70056 L F
.70439 .70175 m .70473 .70308 L .70277 .70332 L F
.25 .06 .416 r
.70534 .70549 m .70277 .70332 L .70473 .70308 L F
.653 .732 .907 r
.34577 .79313 m .3425 .79242 L .34448 .79221 L F
.568 .882 .991 r
.3463 .79198 m .34577 .79313 L .34448 .79221 L F
.3463 .79198 m .34794 .79243 L .34577 .79313 L F
.647 .763 .933 r
.64927 .60149 m .65299 .60156 L .65135 .60278 L F
.639 .352 .467 r
.47489 .83886 m .47695 .84091 L .47706 .83911 L F
.47489 .83886 m .47695 .84091 L .47706 .83911 L F
.822 .819 .847 r
.67159 .62131 m .66797 .62269 L .67069 .6208 L F
.828 .943 .9 r
.67159 .62131 m .67273 .61888 L .67393 .61999 L F
.67159 .62131 m .67069 .6208 L .67273 .61888 L F
.781 .68 .753 r
.69446 .73198 m .69751 .73234 L .69665 .72927 L F
.786 .654 .716 r
.69446 .73198 m .69559 .735 L .69751 .73234 L F
.727 .649 .772 r
.69665 .72927 m .69751 .73234 L .69988 .72953 L F
.708 .635 .773 r
.46192 .87221 m .46573 .87299 L .46457 .87022 L F
.725 .597 .713 r
.46192 .87221 m .46363 .87397 L .46573 .87299 L F
.544 .53 .79 r
.46573 .87299 m .4668 .86985 L .46457 .87022 L F
.46573 .87299 m .46784 .87284 L .4668 .86985 L F
.005 .549 .835 r
.64585 .6085 m .64525 .60814 L .64266 .60766 L F
.221 .532 .922 r
.64585 .6085 m .6468 .60783 L .64525 .60814 L F
.64585 .6085 m .64811 .60933 L .6468 .60783 L F
.52 .441 .707 r
.64639 .60983 m .64811 .60933 L .64585 .6085 L F
.922 .581 .374 r
.5619 .79776 m .55996 .79641 L .55985 .79809 L F
.496 .282 .519 r
.4799 .87321 m .47971 .87624 L .47735 .87628 L F
.677 .434 .547 r
.48174 .87541 m .47971 .87624 L .4799 .87321 L F
.101 0 0 r
.35273 .67627 m .35495 .67645 L .35644 .67647 L F
.514 .908 .926 r
.35644 .67647 m .35684 .67565 L .35816 .67617 L F
.35644 .67647 m .35495 .67645 L .35684 .67565 L F
.405 .375 .712 r
.35816 .67788 m .35644 .67647 L .35816 .67617 L F
.753 .397 .38 r
.48664 .87849 m .48935 .87901 L .48859 .88065 L F
.561 .477 .718 r
.4907 .87566 m .49137 .88016 L .48935 .87901 L F
.788 .561 .594 r
.49137 .88016 m .48859 .88065 L .48935 .87901 L F
.639 .811 .966 r
.5675 .82428 m .56817 .82552 L .5662 .82596 L F
.689 .256 .216 r
.5662 .82596 m .56513 .82741 L .5675 .82428 L F
.5662 .82596 m .56833 .82763 L .56513 .82741 L F
.587 .341 .51 r
.56817 .82552 m .56833 .82763 L .5662 .82596 L F
.673 .712 .877 r
.7088 .73177 m .71214 .73222 L .71168 .73132 L F
.042 .409 .86 r
.71214 .73222 m .71294 .73182 L .71168 .73132 L F
.1 .524 .909 r
.71214 .73222 m .71388 .73276 L .71294 .73182 L F
.563 .341 .536 r
.45015 .76455 m .45001 .76708 L .44772 .76728 L F
.564 .342 .536 r
.45218 .76676 m .45015 .76455 L .45234 .76442 L F
.45218 .76676 m .45001 .76708 L .45015 .76455 L F
.781 .543 .576 r
.67495 .7319 m .67804 .72989 L .6769 .72911 L F
.67495 .7319 m .67817 .73218 L .67804 .72989 L F
.564 .554 .802 r
.56337 .79032 m .55922 .79362 L .56139 .79103 L F
.263 0 0 r
.38302 .72499 m .38502 .72473 L .38611 .72398 L F
.242 0 0 r
.38502 .72473 m .38817 .72373 L .38611 .72398 L F
.787 .537 .558 r
.5295 .83457 m .53256 .8363 L .53113 .83563 L F
.612 .486 .684 r
.53492 .83626 m .53255 .83939 L .53256 .8363 L F
.48 .41 .701 r
.34551 .66763 m .34596 .6711 L .34417 .67139 L F
.363 0 .131 r
.4226 .77935 m .41909 .78171 L .42051 .78 L F
.733 .636 .75 r
.49351 .8496 m .49676 .85148 L .49552 .84901 L F
.49351 .8496 m .49467 .85252 L .49676 .85148 L F
.678 .665 .83 r
.49676 .85148 m .49878 .84949 L .49552 .84901 L F
.433 .205 .468 r
.35039 .68893 m .35001 .69201 L .3479 .69145 L F
.465 .22 .458 r
.35001 .69201 m .34764 .69451 L .3479 .69145 L F
0 0 .487 r
.48409 .88061 m .4841 .88152 L .48316 .87838 L F
.219 0 .037 r
.39851 .79183 m .3979 .79069 L .39976 .79035 L F
.39851 .79183 m .39655 .7926 L .3979 .79069 L F
.45 .039 .167 r
.36592 .78938 m .36791 .78939 L .36922 .78742 L F
.277 0 .067 r
.36922 .78742 m .36791 .78939 L .37071 .78787 L F
.583 .335 .507 r
.36745 .75361 m .36713 .75614 L .36489 .75628 L F
.536 .294 .496 r
.36938 .7557 m .36745 .75361 L .3689 .75302 L F
.36938 .7557 m .36713 .75614 L .36745 .75361 L F
.558 .534 .785 r
.67373 .73538 m .67495 .7319 L .67294 .73207 L F
.67373 .73538 m .67609 .73522 L .67495 .7319 L F
.876 .896 .843 r
.38988 .74541 m .38756 .74798 L .38874 .74867 L F
.35 .141 .449 r
.3344 .71032 m .33331 .70878 L .33449 .70804 L F
.3344 .71032 m .33283 .71099 L .33331 .70878 L F
.462 .262 .522 r
.46573 .86239 m .46777 .86258 L .46734 .86029 L F
.497 .256 .478 r
.46561 .86455 m .46777 .86258 L .46573 .86239 L F
.659 .864 .977 r
.35321 .79186 m .3511 .79293 L .34967 .7922 L F
.466 .617 .915 r
.53454 .82076 m .53782 .82289 L .53665 .81993 L F
.426 0 .119 r
.6551 .63284 m .65385 .63153 L .65317 .63325 L F
.6551 .63284 m .65616 .63125 L .65385 .63153 L F
.666 .852 .971 r
.31562 .65503 m .31215 .65505 L .31408 .65425 L F
.52 .822 1 r
.31408 .65425 m .31784 .65461 L .31562 .65503 L F
.772 .757 .839 r
.6904 .75067 m .69358 .75073 L .6929 .74836 L F
.611 .361 .514 r
.55155 .7859 m .55373 .78585 L .55635 .78338 L F
.693 .482 .597 r
.55635 .78338 m .55373 .78585 L .55688 .78541 L F
.448 .81 .996 r
.68105 .73231 m .68144 .7325 L .67817 .73218 L F
.717 .642 .773 r
.69988 .72953 m .70323 .73058 L .70212 .7277 L F
.612 .586 .8 r
.70212 .7277 m .70323 .73058 L .70536 .7298 L F
.568 .803 .988 r
.42205 .72725 m .42013 .72773 L .4187 .7267 L F
.557 .286 .461 r
.66695 .63918 m .66621 .64178 L .66393 .64195 L F
.54 .256 .432 r
.66915 .63895 m .66621 .64178 L .66695 .63918 L F
.337 0 .104 r
.65135 .64689 m .65064 .64846 L .64851 .64895 L F
.335 0 .103 r
.65135 .64689 m .6534 .64705 L .65064 .64846 L F
.873 .871 .832 r
.57169 .82567 m .56964 .8283 L .56833 .82763 L F
.844 .923 .884 r
.48386 .8554 m .4805 .85676 L .48261 .85689 L F
.493 .086 .196 r
.48261 .85689 m .48564 .85532 L .48386 .8554 L F
.517 .314 .543 r
.33235 .74537 m .33419 .74332 L .33207 .74331 L F
.68 .625 .786 r
.68284 .59965 m .67971 .59731 L .68189 .5964 L F
.603 .57 .789 r
.68422 .59597 m .68284 .59965 L .68189 .5964 L F
.68422 .59597 m .6851 .59915 L .68284 .59965 L F
.982 .896 .653 r
.67308 .71158 m .67384 .70953 L .67251 .71015 L F
.618 .372 .523 r
.67251 .71015 m .67481 .71208 L .6743 .71302 L F
.379 0 .152 r
.67439 .71263 m .6743 .71302 L .67481 .71208 L F
0 .055 .61 r
.67308 .71158 m .6743 .71302 L .67425 .71327 L F
0 .111 .663 r
.67251 .71015 m .6743 .71302 L .67308 .71158 L F
.379 0 .152 r
.67271 .71481 m .6743 .71302 L .67439 .71263 L F
0 .055 .61 r
.67425 .71327 m .6743 .71302 L .67468 .71388 L F
.11 .214 .692 r
.6743 .71302 m .67512 .71632 L .67468 .71388 L F
.359 0 .138 r
.39546 .77993 m .39619 .78148 L .39744 .77935 L F
.39546 .77993 m .39421 .78188 L .39619 .78148 L F
.77 .612 .683 r
.68188 .60767 m .6786 .60975 L .67865 .60737 L F
.68188 .60767 m .68022 .6103 L .6786 .60975 L F
.969 .81 .63 r
.72013 .72627 m .7206 .72841 L .72091 .72709 L F
.251 .626 .96 r
.66694 .60837 m .66806 .60938 L .66522 .60875 L F
.66694 .60837 m .66522 .60875 L .66472 .6094 L F
.805 .591 .612 r
.54668 .80948 m .54822 .81262 L .54957 .81241 L F
.788 .296 .028 r
.54967 .81479 m .54831 .81446 L .54664 .81267 L F
.755 .442 .455 r
.54822 .81262 m .54831 .81446 L .54957 .81241 L F
.952 .739 .577 r
.54957 .81241 m .54831 .81446 L .54967 .81479 L F
.935 .665 .503 r
.54653 .83524 m .54861 .83879 L .54805 .83676 L F
.669 .694 .864 r
.46006 .87336 m .46363 .87397 L .46192 .87221 L F
0 0 0 r
.6997 .7148 m .70105 .71372 L .70195 .71438 L F
.6997 .7148 m .69886 .71572 L .70105 .71372 L F
.46 .459 .77 r
.34365 .66266 m .34293 .66611 L .34163 .66325 L F
.34365 .66266 m .34473 .66596 L .34293 .66611 L F
.517 .477 .75 r
.34551 .66763 m .34293 .66611 L .34473 .66596 L F
.734 .548 .64 r
.51009 .85212 m .51277 .85205 L .51315 .84942 L F
.603 .348 .504 r
.34267 .77219 m .34306 .7743 L .34133 .77279 L F
.647 .413 .551 r
.3456 .77161 m .34306 .7743 L .34267 .77219 L F
.011 0 0 r
.53745 .80252 m .53766 .80295 L .53856 .80194 L F
0 0 .303 r
.53745 .80252 m .5388 .80542 L .53766 .80295 L F
.795 .675 .732 r
.57451 .81476 m .57131 .81448 L .57325 .81189 L F
.882 .745 .706 r
.57451 .81476 m .57153 .8171 L .57131 .81448 L F
.57451 .81476 m .57319 .81808 L .57153 .8171 L F
.842 .66 .656 r
.67724 .60199 m .67873 .605 L .67599 .60425 L F
.853 .663 .644 r
.67873 .605 m .67793 .6053 L .67599 .60425 L F
.67873 .605 m .67865 .60737 L .67793 .6053 L F
.915 .591 .117 r
.61111 .64081 m .61124 .64001 L .61122 .63996 L F
.32 0 .2 r
.54069 .8386 m .5431 .83821 L .54359 .83632 L F
.9 .544 .358 r
.54359 .83632 m .5431 .83821 L .54207 .836 L F
.558 .406 .631 r
.32494 .69791 m .32708 .69762 L .32688 .69522 L F
.43 .226 .5 r
.32512 .70014 m .32708 .69762 L .32494 .69791 L F
.728 .297 .225 r
.48915 .85721 m .49126 .8592 L .49247 .8578 L F
.785 .373 .269 r
.49126 .8592 m .49333 .85965 L .49247 .8578 L F
.444 .052 .201 r
.35682 .73471 m .35895 .73447 L .36022 .73254 L F
.464 .112 .283 r
.35895 .73447 m .36216 .73201 L .36022 .73254 L F
.57 .365 .563 r
.64854 .7216 m .65115 .72254 L .65102 .72113 L F
.67 .77 .925 r
.67247 .62668 m .66895 .62633 L .67129 .6256 L F
.796 .601 .637 r
.54085 .85855 m .54285 .85997 L .54356 .85773 L F
.491 .68 .95 r
.447 .73194 m .44628 .73361 L .44492 .73226 L F
.447 .73194 m .44855 .7337 L .44628 .73361 L F
.479 .221 .445 r
.34133 .77279 m .34113 .77473 L .3389 .77496 L F
.622 .343 .473 r
.34306 .7743 m .34113 .77473 L .34133 .77279 L F
.517 .191 .354 r
.44206 .77134 m .43979 .77169 L .44034 .76997 L F
.501 .197 .383 r
.4424 .76967 m .44206 .77134 L .44034 .76997 L F
.781 .673 .744 r
.69362 .73818 m .69345 .74 L .69649 .74033 L F
.784 .662 .728 r
.69345 .74 m .69462 .74302 L .69649 .74033 L F
.612 .484 .681 r
.6501 .63327 m .65064 .63097 L .64846 .63376 L F
.6501 .63327 m .65152 .63286 L .65064 .63097 L F
.517 .106 .2 r
.64846 .63376 m .6512 .63483 L .6501 .63327 L F
.472 .251 .496 r
.65298 .63534 m .6501 .63327 L .6512 .63483 L F
.65298 .63534 m .65317 .63325 L .6501 .63327 L F
.938 .719 .581 r
.54353 .82742 m .54489 .8258 L .54295 .82562 L F
.54353 .82742 m .54474 .82819 L .54489 .8258 L F
.582 .501 .728 r
.65064 .63097 m .64727 .62933 L .64961 .63038 L F
.896 .961 .828 r
.65064 .63097 m .64912 .63122 L .64846 .63376 L F
.65064 .63097 m .64961 .63038 L .64912 .63122 L F
.483 .42 .71 r
.65064 .63097 m .65152 .63286 L .6506 .629 L F
.362 0 0 r
.42205 .72725 m .42439 .7274 L .42542 .72686 L F
.02 0 0 r
.42542 .72686 m .42641 .72694 L .42752 .72654 L F
.42542 .72686 m .42439 .7274 L .42641 .72694 L F
.773 .734 .817 r
.3384 .66034 m .33668 .66259 L .335 .66014 L F
.597 .603 .828 r
.33965 .66397 m .33668 .66259 L .3384 .66034 L F
.558 .14 .204 r
.5419 .80712 m .54432 .80846 L .54502 .80644 L F
.919 .558 .329 r
.54432 .80846 m .54604 .80939 L .54502 .80644 L F
.932 .559 .265 r
.54502 .80644 m .54604 .80939 L .54668 .80948 L F
.453 .221 .471 r
.68789 .60959 m .68754 .61215 L .68557 .61268 L F
.538 .53 .795 r
.68926 .60768 m .68789 .60959 L .68717 .6078 L F
.68926 .60768 m .69021 .60911 L .68789 .60959 L F
.588 .338 .505 r
.69014 .61176 m .68789 .60959 L .69021 .60911 L F
.69014 .61176 m .68754 .61215 L .68789 .60959 L F
.587 .383 .572 r
.43984 .75852 m .44214 .75601 L .44028 .75654 L F
.466 0 .061 r
.66471 .61868 m .66144 .61997 L .66324 .6182 L F
.66471 .61868 m .66348 .61993 L .66144 .61997 L F
.477 .011 .068 r
.66685 .61944 m .66348 .61993 L .66471 .61868 L F
.48 .082 .208 r
.66706 .61846 m .66685 .61944 L .66471 .61868 L F
.604 .365 .527 r
.4629 .75907 m .46287 .76075 L .4624 .75987 L F
.58 .345 .525 r
.4629 .75907 m .46495 .76099 L .46287 .76075 L F
.597 .343 .503 r
.4629 .75907 m .46515 .75896 L .46495 .76099 L F
.406 .091 .315 r
.42465 .74277 m .42248 .74335 L .42493 .7415 L F
.264 0 0 r
.42785 .7412 m .42646 .74212 L .42493 .7415 L F
.215 0 .041 r
.42646 .74212 m .42465 .74277 L .42493 .7415 L F
.515 .449 .72 r
.46745 .85729 m .46734 .86029 L .47003 .85957 L F
.487 .278 .521 r
.46734 .86029 m .46991 .86194 L .47003 .85957 L F
.46734 .86029 m .46777 .86258 L .46991 .86194 L F
.513 .233 .426 r
.42512 .77759 m .4226 .77935 L .42289 .77773 L F
.729 .549 .647 r
.5631 .78547 m .564 .78916 L .56019 .78801 L F
.636 .491 .669 r
.56564 .78801 m .5631 .78547 L .56622 .7851 L F
.56564 .78801 m .564 .78916 L .5631 .78547 L F
.646 .567 .752 r
.66203 .72253 m .66275 .72436 L .66505 .7218 L F
.668 .603 .772 r
.66275 .72436 m .66647 .72518 L .66505 .7218 L F
0 0 .389 r
.54245 .83076 m .54281 .83334 L .54349 .83183 L F
.54245 .83076 m .54349 .83183 L .54169 .83214 L F
0 0 0 r
.63943 .62608 m .63895 .62582 L .63641 .62873 L F
.996 .805 .533 r
.63943 .62608 m .64052 .62344 L .63895 .62582 L F
.282 0 .288 r
.33689 .70553 m .33449 .70804 L .33526 .70622 L F
0 0 0 r
.61122 .63996 m .61053 .6434 L .61111 .64081 L F
.61111 .64081 m .61053 .6434 L .61122 .63996 L F
.101 0 0 r
.37511 .80131 m .37439 .80196 L .37127 .80306 L F
0 0 0 r
.37708 .80061 m .37622 .80124 L .37511 .80131 L F
.37622 .80124 m .37439 .80196 L .37511 .80131 L F
.618 .754 .943 r
.42902 .74309 m .43023 .74143 L .42785 .7412 L F
.42902 .74309 m .43022 .74308 L .43023 .74143 L F
.393 0 .112 r
.65261 .60435 m .65569 .60223 L .65299 .60156 L F
.65261 .60435 m .65472 .60344 L .65569 .60223 L F
.69 .449 .552 r
.65472 .60344 m .65797 .60176 L .65569 .60223 L F
.464 .304 .578 r
.51654 .88118 m .51512 .88227 L .51663 .88335 L F
.412 .212 .496 r
.67146 .63888 m .67148 .63686 L .6734 .63614 L F
.939 .716 .574 r
.64315 .63398 m .64173 .63068 L .64019 .63267 L F
.253 .635 .962 r
.64315 .63398 m .64427 .63328 L .64234 .63183 L F
.09 .506 .903 r
.67454 .61943 m .67393 .61999 L .67273 .61888 L F
.67454 .61943 m .67542 .62039 L .67393 .61999 L F
.64 .526 .708 r
.32988 .74599 m .33021 .74574 L .32984 .74577 L F
.092 0 0 r
.39505 .7435 m .39159 .7444 L .39311 .74378 L F
.706 .687 .829 r
.57091 .82303 m .57169 .82567 L .56817 .82552 L F
.873 .871 .832 r
.57169 .82567 m .56833 .82763 L .56817 .82552 L F
.763 .72 .812 r
.57434 .82364 m .57169 .82567 L .57091 .82303 L F
.071 .265 .755 r
.4773 .84553 m .4766 .84688 L .47502 .84344 L F
0 .05 .592 r
.4773 .84553 m .47797 .84863 L .4766 .84688 L F
.311 .149 .492 r
.4766 .84688 m .47797 .84863 L .47661 .84848 L F
.402 .177 .455 r
.33906 .7028 m .33689 .70553 L .33731 .70336 L F
.57 .018 0 r
.43007 .72608 m .43318 .72665 L .43094 .72701 L F
.726 .682 .808 r
.65239 .62649 m .65351 .62679 L .65284 .62779 L F
.816 .793 .831 r
.53073 .83747 m .53255 .83939 L .53492 .83626 L F
.203 .343 .784 r
.53073 .83747 m .53244 .84074 L .53255 .83939 L F
0 0 .318 r
.50912 .85415 m .51009 .85212 L .50764 .8529 L F
.525 0 0 r
.511 .85492 m .50957 .85464 L .50912 .85415 L F
0 0 .318 r
.50912 .85415 m .50957 .85464 L .51009 .85212 L F
.652 .771 .936 r
.68112 .70816 m .67929 .70905 L .67788 .70772 L F
.68112 .70816 m .67929 .70905 L .67788 .70772 L F
.327 0 0 r
.3993 .72283 m .40123 .72334 L .40268 .72329 L F
.017 0 0 r
.40268 .72329 m .40123 .72334 L .40451 .72329 L F
.563 .391 .606 r
.66999 .70793 m .67171 .70471 L .67074 .70624 L F
.497 .533 .824 r
.30892 .6514 m .31105 .65181 L .30949 .65273 L F
.464 .285 .552 r
.32355 .70132 m .32497 .7023 L .32512 .70014 L F
.357 .209 .54 r
.32294 .70505 m .32497 .7023 L .32355 .70132 L F
.52 .483 .755 r
.45268 .73808 m .45504 .73949 L .45322 .7399 L F
.556 .453 .692 r
.45573 .74268 m .45322 .7399 L .45504 .73949 L F
.45573 .74268 m .45372 .74311 L .45322 .7399 L F
.59 .579 .809 r
.45926 .74792 m .45855 .75202 L .45702 .74831 L F
.45926 .74792 m .46069 .75152 L .45855 .75202 L F
0 0 0 r
.34607 .81253 m .34704 .81204 L .3489 .81158 L F
.389 .132 .399 r
.34299 .69956 m .34177 .69822 L .34347 .69762 L F
.34299 .69956 m .3412 .70018 L .34177 .69822 L F
.342 0 .068 r
.66393 .64195 m .66085 .64393 L .6617 .64166 L F
.51 .333 .577 r
.67684 .62593 m .67655 .62815 L .67519 .62852 L F
.446 .192 .434 r
.67744 .63007 m .67519 .62852 L .67655 .62815 L F
.67744 .63007 m .6749 .6309 L .67519 .62852 L F
.605 .639 .857 r
.69212 .71899 m .68897 .71695 L .69107 .71624 L F
.709 .682 .822 r
.69369 .71829 m .69212 .71899 L .69107 .71624 L F
.686 .618 .774 r
.56337 .79032 m .56139 .79103 L .56019 .78801 L F
.663 .591 .765 r
.57547 .82231 m .57249 .81989 L .57642 .82037 L F
.364 .818 .705 r
.64276 .61143 m .64639 .60983 L .64383 .61259 L F
.64276 .61143 m .64513 .61028 L .64639 .60983 L F
.511 .168 .322 r
.43029 .77484 m .42928 .77701 L .42715 .77718 L F
.567 .268 .42 r
.43242 .77454 m .42928 .77701 L .43029 .77484 L F
.567 .359 .558 r
.3389 .77496 m .33879 .77741 L .3366 .77757 L F
.585 .417 .621 r
.34113 .77473 m .33879 .77741 L .3389 .77496 L F
.706 .848 .95 r
.35881 .79116 m .35693 .79213 L .35524 .7913 L F
.172 .248 .702 r
.56725 .8333 m .568 .83661 L .56919 .83536 L F
.315 .476 .86 r
.568 .83661 m .57084 .83837 L .56919 .83536 L F
.479 .478 .778 r
.568 .83661 m .56931 .83896 L .57084 .83837 L F
.481 .899 .862 r
.37931 .78536 m .37767 .78616 L .37522 .78667 L F
.518 0 0 r
.48863 .86207 m .49032 .86279 L .48707 .86195 L F
.435 .096 .291 r
.40768 .78544 m .40665 .78791 L .40461 .78818 L F
.357 .022 .254 r
.40858 .78738 m .40768 .78544 L .40971 .78502 L F
.40858 .78738 m .40665 .78791 L .40768 .78544 L F
.456 .051 .181 r
.66055 .62807 m .66324 .62794 L .66368 .62634 L F
0 0 0 r
.66368 .62634 m .66457 .62668 L .66593 .62576 L F
.66368 .62634 m .66324 .62794 L .66457 .62668 L F
.846 .696 .696 r
.63641 .62873 m .63322 .63052 L .63538 .62761 L F
.63641 .62873 m .63481 .63174 L .63322 .63052 L F
0 0 0 r
.63943 .62608 m .63641 .62873 L .63538 .62761 L F
.596 .577 .802 r
.35273 .67627 m .35077 .6769 L .34944 .67361 L F
.191 .433 .863 r
.56931 .83896 m .57192 .84117 L .57084 .83837 L F
0 0 0 r
.39843 .74312 m .3972 .74327 L .39505 .7435 L F
.298 .794 .844 r
.40048 .74275 m .3972 .74327 L .39843 .74312 L F
.455 .613 .917 r
.43023 .74143 m .43022 .74308 L .43188 .74138 L F
.528 .859 .995 r
.58926 .84075 m .59146 .84095 L .59054 .84139 L F
.148 .69 .812 r
.59146 .84095 m .59359 .84079 L .59258 .8407 L F
0 0 0 r
.59054 .84139 m .59146 .84095 L .59258 .8407 L F
.584 .286 .429 r
.42258 .76911 m .42477 .76919 L .42562 .76646 L F
.404 .115 .357 r
.42562 .76646 m .4268 .76855 L .42791 .76625 L F
.42562 .76646 m .42477 .76919 L .4268 .76855 L F
.423 .009 .145 r
.41253 .77148 m .41464 .77131 L .41556 .77014 L F
.359 0 .103 r
.41556 .77014 m .4167 .77093 L .41744 .76957 L F
.41556 .77014 m .41464 .77131 L .4167 .77093 L F
.676 .661 .828 r
.70536 .7298 m .7088 .73177 L .70759 .72922 L F
.579 .663 .896 r
.7088 .73177 m .7095 .72918 L .70759 .72922 L F
.7088 .73177 m .71168 .73132 L .7095 .72918 L F
.961 .849 .685 r
.58016 .7956 m .57955 .79902 L .58048 .79915 L F
.923 .808 .714 r
.57955 .79902 m .58002 .80149 L .58048 .79915 L F
.763 .669 .758 r
.7095 .71088 m .71058 .71399 L .70742 .71369 L F
.739 .656 .768 r
.71297 .7113 m .71058 .71399 L .7095 .71088 L F
.698 .592 .733 r
.71297 .7113 m .71288 .71316 L .71058 .71399 L F
.444 .458 .779 r
.6869 .59915 m .68604 .60232 L .6851 .59915 L F
.6869 .59915 m .68765 .6027 L .68604 .60232 L F
.463 .431 .737 r
.68765 .6027 m .6886 .60403 L .68604 .60232 L F
.48 .429 .722 r
.6886 .60403 m .68675 .60442 L .68604 .60232 L F
.683 .854 .964 r
.68404 .75012 m .68693 .75117 L .68638 .74765 L F
.742 .78 .884 r
.68638 .74765 m .68693 .75117 L .68944 .74785 L F
.639 .54 .726 r
.68693 .75117 m .6904 .75067 L .68944 .74785 L F
.68693 .75117 m .6882 .75125 L .6904 .75067 L F
.911 .753 .674 r
.52173 .88025 m .52237 .87869 L .52092 .87815 L F
.826 .892 .888 r
.5388 .80542 m .54191 .80421 L .53874 .80258 L F
.884 .512 .331 r
.4854 .87303 m .48322 .87077 L .48407 .87258 L F
.447 .355 .658 r
.4854 .87303 m .48578 .87638 L .48723 .87548 L F
.783 .288 0 r
.48599 .87464 m .4854 .87303 L .48407 .87258 L F
.58 .481 .706 r
.48538 .87492 m .48601 .8749 L .48599 .87464 L F
.783 .288 0 r
.48599 .87464 m .48723 .87548 L .48588 .87368 L F
.932 .966 .753 r
.48835 .8719 m .48951 .87203 L .48853 .87352 L F
.48767 .87407 m .48853 .87352 L .48723 .87548 L F
.48835 .8719 m .48853 .87352 L .48767 .87407 L F
.58 .481 .706 r
.48601 .8749 m .4864 .87489 L .48599 .87464 L F
.932 .966 .753 r
.48835 .8719 m .48723 .87548 L .48599 .87464 L F
.58 .481 .706 r
.4864 .87489 m .48793 .87484 L .48667 .87471 L F
.4864 .87489 m .48667 .87471 L .48599 .87464 L F
.783 .288 0 r
.48599 .87464 m .48588 .87368 L .4854 .87303 L F
.767 .535 .582 r
.49794 .86224 m .50115 .86248 L .50119 .85982 L F
.752 .522 .583 r
.50119 .85982 m .50115 .86248 L .50384 .86232 L F
.218 .119 .522 r
.67759 .62342 m .67764 .62554 L .67684 .62593 L F
.181 .049 .453 r
.67764 .62554 m .67655 .62815 L .67684 .62593 L F
.845 .671 .667 r
.64363 .59923 m .64491 .6026 L .64285 .60175 L F
.596 .386 .566 r
.46741 .75618 m .46739 .75873 L .46515 .75896 L F
.641 .564 .753 r
.46997 .7556 m .46741 .75618 L .46698 .75375 L F
.602 .398 .577 r
.46997 .7556 m .46739 .75873 L .46741 .75618 L F
.431 .083 .273 r
.43688 .7609 m .43984 .75852 L .43789 .75906 L F
.755 .534 .597 r
.70935 .70851 m .70622 .71072 L .70835 .70783 L F
.70935 .70851 m .7095 .71088 L .70622 .71072 L F
.669 .731 .897 r
.70987 .70614 m .70935 .70851 L .70835 .70783 L F
.70987 .70614 m .71164 .70808 L .70935 .70851 L F
.75 .603 .694 r
.71164 .70808 m .7095 .71088 L .70935 .70851 L F
.902 .489 .127 r
.5494 .84081 m .55065 .84156 L .54861 .83879 L F
.98 .809 .601 r
.5494 .84081 m .55006 .84383 L .55065 .84156 L F
.639 .59 .782 r
.6604 .71574 m .66269 .71333 L .66047 .71373 L F
.6604 .71574 m .66386 .71637 L .66269 .71333 L F
.666 .515 .67 r
.6604 .71574 m .66145 .71925 L .66386 .71637 L F
.671 .58 .744 r
.52807 .83063 m .5295 .83457 L .5314 .8333 L F
.569 .388 .596 r
.5295 .83457 m .53113 .83563 L .5314 .8333 L F
.899 .848 .784 r
.57955 .84097 m .58267 .83875 L .58166 .83869 L F
.57955 .84097 m .58072 .84174 L .58267 .83875 L F
.358 .808 .946 r
.58267 .83875 m .58338 .83818 L .58166 .83869 L F
.58267 .83875 m .58494 .83841 L .58338 .83818 L F
.554 .336 .538 r
.35053 .76669 m .34817 .7689 L .3485 .76713 L F
.519 .389 .643 r
.34775 .77091 m .34565 .76935 L .34817 .7689 L F
.34775 .77091 m .3456 .77161 L .34565 .76935 L F
.7 .326 .336 r
.49367 .86287 m .49241 .86467 L .49032 .86279 L F
.702 .328 .338 r
.49367 .86287 m .49565 .86479 L .49241 .86467 L F
.424 .201 .47 r
.3412 .70018 m .33906 .7028 L .3394 .70077 L F
.527 .376 .619 r
.48536 .86473 m .48314 .86797 L .48337 .86521 L F
.804 .688 .737 r
.57325 .81189 m .57199 .80902 L .57367 .80954 L F
0 0 .177 r
.67681 .70479 m .67574 .70841 L .6752 .70601 L F
.55 .369 .589 r
.36097 .71131 m .36317 .71099 L .3631 .70848 L F
.36097 .71131 m .36317 .71099 L .3631 .70848 L F
.877 .885 .836 r
.51912 .88137 m .52066 .88212 L .52173 .88025 L F
.648 .576 .761 r
.66145 .71925 m .66203 .72253 L .66505 .7218 L F
.494 .293 .536 r
.3526 .68666 m .35124 .68833 L .35039 .68893 L F
.477 .247 .486 r
.35124 .68833 m .35001 .69201 L .35039 .68893 L F
.84 .865 .862 r
.57343 .79625 m .56982 .79804 L .57235 .79562 L F
.742 .67 .78 r
.66895 .62633 m .66693 .62875 L .66593 .62576 L F
.663 .814 .956 r
.65902 .60724 m .66228 .60748 L .66146 .60699 L F
.999 .797 .484 r
.66146 .60699 m .66228 .60748 L .66191 .60468 L F
.31 0 .103 r
.38254 .79835 m .38541 .7968 L .38439 .79791 L F
.025 0 0 r
.38439 .79791 m .38541 .7968 L .38708 .79592 L F
.452 0 .058 r
.37468 .75155 m .37114 .75275 L .37235 .75113 L F
.777 .694 .772 r
.55188 .78838 m .55373 .78585 L .55155 .7859 L F
.236 .745 .88 r
.47276 .84365 m .47393 .84321 L .47502 .84344 L F
.249 .028 .37 r
.4721 .84547 m .47393 .84321 L .47276 .84365 L F
.872 .445 .189 r
.57986 .78808 m .58083 .79011 L .58227 .79051 L F
.993 .854 .596 r
.5806 .7921 m .58227 .79051 L .58083 .79011 L F
.5806 .7921 m .58159 .79393 L .58227 .79051 L F
.523 .462 .729 r
.45396 .73436 m .45268 .73808 L .45164 .73483 L F
.45396 .73436 m .45461 .73776 L .45268 .73808 L F
.526 .482 .75 r
.45461 .73776 m .45504 .73949 L .45268 .73808 L F
.428 .378 .701 r
.68886 .60595 m .68717 .6078 L .68675 .60442 L F
.518 .514 .791 r
.68886 .60595 m .68926 .60768 L .68717 .6078 L F
.454 .26 .527 r
.38253 .75895 m .38235 .76139 L .38431 .75853 L F
.38253 .75895 m .38235 .76139 L .38431 .75853 L F
.295 .224 .604 r
.50321 .85245 m .5034 .84949 L .50067 .84884 L F
.50321 .85245 m .50418 .85203 L .5034 .84949 L F
.619 .453 .636 r
.50222 .8543 m .50418 .85203 L .50321 .85245 L F
.295 .224 .604 r
.5034 .84949 m .50418 .85203 L .50321 .85245 L F
.129 0 0 r
.32595 .67744 m .3241 .67807 L .32568 .67645 L F
.317 0 .166 r
.50029 .85478 m .49973 .85555 L .50222 .8543 L F
.50029 .85478 m .49973 .85555 L .50222 .8543 L F
.362 0 0 r
.53856 .80194 m .53766 .80295 L .53874 .80258 L F
.523 .446 .712 r
.54104 .84101 m .54098 .84168 L .53913 .84222 L F
.663 .591 .765 r
.57547 .82231 m .57434 .82364 L .57249 .81989 L F
.042 0 0 r
.49874 .88975 m .49952 .88936 L .50162 .88901 L F
0 0 .463 r
.67233 .63283 m .6734 .63614 L .67261 .6344 L F
.9 .67 .58 r
.59924 .83309 m .5995 .83073 L .59715 .82954 L F
.764 .83 .903 r
.33957 .79289 m .34031 .7944 L .33894 .79321 L F
.33957 .79289 m .3417 .7934 L .34031 .7944 L F
.163 .258 .716 r
.3403 .66225 m .33965 .66397 L .3384 .66034 L F
.647 .809 .961 r
.34163 .66325 m .33965 .66397 L .3403 .66225 L F
.693 .615 .765 r
.66505 .7218 m .66647 .72518 L .66862 .72405 L F
.548 .322 .524 r
.36023 .75896 m .35976 .76121 L .35776 .76146 L F
.413 .161 .42 r
.36231 .7585 m .35976 .76121 L .36023 .75896 L F
.862 .606 .549 r
.54532 .81163 m .54668 .80948 L .54604 .80939 L F
.54532 .81163 m .54822 .81262 L .54668 .80948 L F
.787 .879 .913 r
.57091 .82303 m .56817 .82552 L .5675 .82428 L F
.489 .131 .285 r
.45001 .76708 m .44752 .76843 L .44772 .76728 L F
.959 .924 .724 r
.49645 .84712 m .49552 .84901 L .49736 .84562 L F
.996 .805 .533 r
.63943 .62608 m .6396 .62252 L .64052 .62344 L F
.514 .654 .922 r
.64053 .62146 m .64052 .62344 L .6396 .62252 L F
.64053 .62146 m .64309 .62339 L .64052 .62344 L F
.833 .683 .696 r
.69345 .74 m .69226 .74287 L .69462 .74302 L F
.875 .68 .636 r
.69226 .74287 m .69409 .74552 L .69462 .74302 L F
.715 .516 .619 r
.50577 .85462 m .50594 .85726 L .50327 .85709 L F
.488 .259 .493 r
.50906 .85424 m .50594 .85726 L .50577 .85462 L F
.544 .405 .642 r
.505 .8558 m .50768 .85474 L .50686 .85396 L F
.686 .16 0 r
.50418 .85203 m .50777 .85461 L .50906 .85424 L F
.719 .341 .332 r
.507 .85568 m .50906 .85424 L .50862 .85345 L F
.686 .16 0 r
.50777 .85461 m .50786 .85467 L .50906 .85424 L F
.719 .341 .332 r
.50644 .85607 m .507 .85568 L .50756 .85486 L F
.462 .176 .393 r
.50766 .85476 m .50644 .85607 L .50786 .85467 L F
.50452 .85614 m .50644 .85607 L .50766 .85476 L F
.719 .341 .332 r
.50644 .85607 m .50756 .85486 L .50772 .85463 L F
.50755 .85468 m .50772 .85463 L .50858 .85338 L F
.50644 .85607 m .50772 .85463 L .50755 .85468 L F
.507 .85568 m .50862 .85345 L .50858 .85338 L F
.544 .405 .642 r
.50768 .85474 m .50786 .85467 L .50777 .85461 L F
.50768 .85474 m .50777 .85461 L .50686 .85396 L F
0 0 0 r
.50577 .85462 m .50327 .85709 L .50396 .85657 L F
.50577 .85462 m .50396 .85657 L .50431 .85626 L F
.50577 .85462 m .50417 .85641 L .50475 .85587 L F
.50577 .85462 m .50452 .85614 L .50222 .8543 L F
.544 .405 .642 r
.50497 .85566 m .50686 .85396 L .50418 .85203 L F
.505 .8558 m .50686 .85396 L .50497 .85566 L F
0 0 0 r
.50431 .85626 m .50396 .85657 L .50417 .85641 L F
.50475 .85587 m .50417 .85641 L .50452 .85614 L F
.619 .453 .636 r
.50222 .8543 m .50489 .85574 L .50418 .85203 L F
.50489 .85574 m .505 .8558 L .50497 .85566 L F
.50489 .85574 m .50497 .85566 L .50418 .85203 L F
.847 .697 .696 r
.57125 .80115 m .56982 .79804 L .57076 .79837 L F
.725 .446 .505 r
.6405 .62798 m .64327 .62636 L .64078 .6256 L F
.6405 .62798 m .64409 .6282 L .64327 .62636 L F
.188 0 0 r
.34341 .73921 m .34418 .73914 L .34747 .73798 L F
.34418 .73914 m .34603 .73888 L .34747 .73798 L F
.603 .214 .278 r
.34603 .73888 m .3492 .73732 L .34747 .73798 L F
.34588 .73897 m .34627 .73878 L .34603 .73888 L F
.34627 .73878 m .3492 .73732 L .34603 .73888 L F
.836 .699 .712 r
.3492 .73732 m .34615 .73736 L .34786 .73422 L F
.603 .214 .278 r
.34588 .73897 m .34783 .73914 L .3492 .73732 L F
.782 .438 .404 r
.3492 .73732 m .34783 .73914 L .34615 .73736 L F
.6 .46 .662 r
.34615 .73736 m .34715 .73842 L .34743 .73593 L F
.34715 .73842 m .3474 .73868 L .3474 .73831 L F
.34715 .73842 m .3474 .73831 L .34743 .73593 L F
.3474 .73868 m .34783 .73914 L .34777 .73863 L F
.3474 .73868 m .34777 .73863 L .34743 .73593 L F
.188 0 0 r
.34418 .73914 m .34588 .73897 L .34603 .73888 L F
.697 .39 .452 r
.63052 .64858 m .62926 .65142 L .62747 .64921 L F
.681 .37 .442 r
.63243 .64956 m .62926 .65142 L .63052 .64858 L F
.721 .7 .83 r
.67918 .72417 m .68236 .72523 L .6815 .72357 L F
.609 .65 .866 r
.68236 .72523 m .68409 .72317 L .6815 .72357 L F
.68236 .72523 m .68459 .72473 L .68409 .72317 L F
.843 .679 .678 r
.69446 .73198 m .69274 .73515 L .69559 .735 L F
.82 .671 .699 r
.69228 .73704 m .69559 .735 L .69274 .73515 L F
.69228 .73704 m .69362 .73818 L .69559 .735 L F
.595 .313 .459 r
.43503 .77256 m .43469 .77446 L .43242 .77454 L F
.582 .322 .488 r
.43746 .77207 m .43469 .77446 L .43503 .77256 L F
.697 .785 .919 r
.53335 .81966 m .53454 .82076 L .53665 .81993 L F
.881 .826 .789 r
.68584 .74268 m .68523 .74013 L .68628 .74063 L F
.923 .911 .79 r
.68628 .74063 m .68523 .74013 L .68724 .73726 L F
.452 .211 .457 r
.51905 .87813 m .51625 .87875 L .51808 .87851 L F
.044 .051 .54 r
.51625 .87875 m .51774 .88033 L .51808 .87851 L F
.51625 .87875 m .51654 .88118 L .51774 .88033 L F
.514 .041 .07 r
.64969 .6354 m .6512 .63483 L .64846 .63376 L F
.64969 .6354 m .64846 .63376 L .64912 .63122 L F
.646 .488 .656 r
.33879 .77741 m .33652 .77992 L .3366 .77757 L F
.158 0 .062 r
.67384 .70953 m .67497 .71002 L .67251 .71015 L F
.67384 .70953 m .67574 .70841 L .67497 .71002 L F
.805 .627 .66 r
.58238 .81449 m .58419 .81703 L .58559 .81472 L F
.168 .615 .937 r
.40866 .7233 m .40811 .72384 L .40676 .723 L F
.40866 .7233 m .40996 .72413 L .40811 .72384 L F
.428 .378 .701 r
.68886 .60595 m .68675 .60442 L .6886 .60403 L F
.3 .185 .551 r
.46886 .85147 m .46955 .84898 L .46885 .8493 L F
.629 .354 .482 r
.4624 .75987 m .45947 .7636 L .45749 .76156 L F
.564 .257 .406 r
.46287 .76075 m .45947 .7636 L .4624 .75987 L F
.633 .781 .952 r
.40048 .74275 m .40386 .74331 L .40251 .74277 L F
.126 .658 .865 r
.40592 .74316 m .40251 .74277 L .40386 .74331 L F
.02 0 .483 r
.6657 .62341 m .6671 .62444 L .66797 .62269 L F
.771 .664 .745 r
.6657 .62341 m .66895 .62633 L .66593 .62576 L F
.02 0 .483 r
.6657 .62341 m .66593 .62576 L .6671 .62444 L F
.569 .496 .734 r
.4562 .745 m .455 .74865 L .45408 .74544 L F
.4562 .745 m .45702 .74831 L .455 .74865 L F
.5 .351 .61 r
.32688 .69522 m .32881 .69704 L .32869 .69474 L F
.483 .351 .624 r
.32688 .69522 m .32708 .69762 L .32881 .69704 L F
.534 .397 .641 r
.46745 .85729 m .46868 .85454 L .46721 .8556 L F
.709 .682 .822 r
.69369 .71829 m .69107 .71624 L .69337 .71551 L F
.683 .702 .861 r
.69685 .71667 m .69369 .71829 L .69337 .71551 L F
.56 .372 .584 r
.43761 .74559 m .43974 .74531 L .43978 .74299 L F
.582 .415 .621 r
.43761 .74559 m .43965 .74751 L .43974 .74531 L F
.43761 .74559 m .43765 .74796 L .43965 .74751 L F
.758 .482 .515 r
.43643 .74273 m .43327 .74426 L .43478 .74208 L F
.578 .44 .657 r
.47964 .8386 m .47706 .83911 L .47921 .83578 L F
0 0 0 r
.47921 .83578 m .47706 .83911 L .47808 .83763 L F
.547 .295 .486 r
.47964 .8386 m .47695 .84091 L .47706 .83911 L F
.584 .558 .791 r
.47695 .84091 m .47808 .83763 L .47706 .83911 L F
.462 .41 .714 r
.44213 .75363 m .44325 .75027 L .44115 .75049 L F
.44213 .75363 m .44382 .7534 L .44325 .75027 L F
.606 .425 .61 r
.44213 .75363 m .44437 .75574 L .44382 .7534 L F
.44213 .75363 m .44214 .75601 L .44437 .75574 L F
.294 0 0 r
.69316 .7113 m .69432 .71189 L .69264 .71201 L F
.69316 .7113 m .69532 .71127 L .69432 .71189 L F
.806 .622 .654 r
.69409 .74552 m .6929 .74836 L .6958 .74836 L F
.577 .218 .324 r
.55934 .78424 m .56116 .78482 L .5628 .78268 L F
.734 .413 .438 r
.5628 .78268 m .565 .78442 L .56404 .78343 L F
.5628 .78268 m .56116 .78482 L .565 .78442 L F
.72 .671 .801 r
.69665 .72927 m .69988 .72953 L .69885 .72665 L F
.735 .678 .796 r
.69885 .72665 m .69988 .72953 L .70212 .7277 L F
.803 .576 .595 r
.59846 .82521 m .59552 .82265 L .59572 .82503 L F
.814 .625 .648 r
.59562 .82733 m .59846 .82521 L .59572 .82503 L F
.59562 .82733 m .59821 .82761 L .59846 .82521 L F
.981 .766 .54 r
.54692 .83265 m .54829 .83078 L .54632 .83046 L F
.54692 .83265 m .54804 .83332 L .54829 .83078 L F
.579 .473 .698 r
.4562 .745 m .45372 .74311 L .45573 .74268 L F
.4562 .745 m .45408 .74544 L .45372 .74311 L F
.441 .583 .899 r
.33314 .66013 m .32974 .65775 L .33155 .65763 L F
.457 .591 .898 r
.33333 .65763 m .33314 .66013 L .33155 .65763 L F
.33333 .65763 m .335 .66014 L .33314 .66013 L F
.546 .458 .707 r
.33228 .68183 m .33389 .67917 L .33182 .67969 L F
.33228 .68183 m .33422 .6814 L .33389 .67917 L F
.313 .155 .499 r
.33267 .68432 m .33422 .6814 L .33228 .68183 L F
.622 .678 .883 r
.49249 .87272 m .4904 .87333 L .48951 .87203 L F
.293 .235 .62 r
.49188 .87556 m .4904 .87333 L .49249 .87272 L F
.49188 .87556 m .4907 .87566 L .4904 .87333 L F
.919 .522 .174 r
.71969 .72347 m .72088 .72418 L .71984 .72189 L F
.777 .965 .664 r
.59644 .84079 m .5985 .83816 L .59806 .83819 L F
.927 .909 .515 r
.5985 .83816 m .59903 .83518 L .59806 .83819 L F
.438 .021 .148 r
.41513 .78262 m .41387 .78444 L .41183 .78451 L F
.339 0 .089 r
.41592 .78402 m .41513 .78262 L .41709 .7822 L F
.41592 .78402 m .41387 .78444 L .41513 .78262 L F
.824 .662 .683 r
.48226 .8673 m .47913 .86767 L .4793 .86521 L F
.946 .775 .637 r
.4793 .86521 m .47913 .86767 L .47856 .86618 L F
.863 .619 .568 r
.47856 .86618 m .48226 .8673 L .4793 .86521 L F
.981 .702 .323 r
.47913 .86767 m .4792 .86983 L .47856 .86618 L F
0 0 .338 r
.4793 .86785 m .4792 .86983 L .47913 .86767 L F
.861 .643 .606 r
.47929 .86808 m .4792 .86983 L .48125 .86813 L F
.47889 .86806 m .48125 .86813 L .47963 .86789 L F
0 0 .338 r
.4793 .86785 m .47913 .86767 L .47963 .86789 L F
.643 .293 .363 r
.48226 .8673 m .47963 .86789 L .47913 .86767 L F
.861 .643 .606 r
.47856 .86618 m .47889 .86806 L .48226 .8673 L F
0 0 .338 r
.48027 .8688 m .4792 .86983 L .4793 .86785 L F
.861 .643 .606 r
.47889 .86806 m .4792 .86983 L .47929 .86808 L F
.47963 .86789 m .48125 .86813 L .48226 .8673 L F
0 0 .338 r
.48027 .8688 m .4793 .86785 L .48176 .86883 L F
.4793 .86785 m .47963 .86789 L .48176 .86883 L F
.643 .293 .363 r
.48226 .8673 m .48176 .86883 L .47963 .86789 L F
.505 .507 .792 r
.67294 .73207 m .67387 .72882 L .67163 .72936 L F
.67294 .73207 m .67495 .7319 L .67387 .72882 L F
.549 .368 .588 r
.65848 .63083 m .66055 .62807 L .65862 .62863 L F
.879 .64 .573 r
.43978 .74299 m .43789 .74391 L .43643 .74273 L F
.43978 .74299 m .43974 .74531 L .43789 .74391 L F
.485 .24 .467 r
.48578 .87638 m .48316 .87838 L .48174 .87541 L F
.48578 .87638 m .48495 .87845 L .48316 .87838 L F
.555 .682 .923 r
.71428 .70764 m .71419 .70904 L .71164 .70808 L F
.726 .592 .706 r
.71164 .70808 m .71419 .70904 L .71297 .7113 L F
.348 0 0 r
.71599 .70997 m .71756 .71063 L .7171 .71041 L F
.71599 .70997 m .71615 .70996 L .71419 .70904 L F
.71599 .70997 m .71419 .70904 L .71428 .70764 L F
.791 .407 .328 r
.71305 .70935 m .71599 .70997 L .71428 .70764 L F
.809 .546 0 r
.7157 .70948 m .71599 .70997 L .71465 .70943 L F
.7157 .70948 m .71582 .70997 L .71599 .70997 L F
.71582 .70997 m .71633 .71208 L .71599 .70997 L F
.348 0 0 r
.71599 .70997 m .7171 .71041 L .71615 .70996 L F
.809 .546 0 r
.71465 .70943 m .71599 .70997 L .71305 .70935 L F
.517 .314 .543 r
.33235 .74537 m .33409 .74504 L .33419 .74332 L F
.479 .384 .669 r
.33235 .74537 m .3344 .74717 L .33409 .74504 L F
.33235 .74537 m .33251 .74812 L .3344 .74717 L F
.881 .826 .789 r
.68584 .74268 m .68365 .74229 L .68523 .74013 L F
.865 .847 .825 r
.6835 .74531 m .68365 .74229 L .68584 .74268 L F
.913 .665 .55 r
.49743 .86745 m .49565 .86479 L .49717 .86527 L F
.269 .462 .865 r
.41729 .72432 m .41701 .72607 L .41547 .72399 L F
.41729 .72432 m .4187 .7267 L .41701 .72607 L F
.396 .13 .389 r
.35675 .68347 m .35391 .68566 L .35487 .68422 L F
.428 0 .092 r
.38439 .79791 m .38087 .79967 L .38254 .79835 L F
.851 .749 .75 r
.3425 .79242 m .33957 .79289 L .34127 .79184 L F
.3425 .79242 m .3417 .7934 L .33957 .79289 L F
.44 .745 .992 r
.34369 .79181 m .3425 .79242 L .34127 .79184 L F
.34369 .79181 m .34448 .79221 L .3425 .79242 L F
.715 .785 .907 r
.68582 .71667 m .68261 .71873 L .68214 .71651 L F
.851 .817 .816 r
.67971 .59731 m .67779 .59974 L .67657 .59892 L F
.907 .785 .715 r
.67779 .59974 m .67724 .60199 L .67657 .59892 L F
.873 .761 .736 r
.67865 .60737 m .67545 .60908 L .67793 .6053 L F
.67865 .60737 m .67649 .61028 L .67545 .60908 L F
.746 .562 .645 r
.6786 .60975 m .67649 .61028 L .67865 .60737 L F
.057 .181 .679 r
.66472 .6094 m .66522 .61284 L .66631 .61101 L F
.606 .412 .593 r
.68557 .61268 m .6857 .61559 L .68309 .6154 L F
.483 .318 .581 r
.68758 .61475 m .68557 .61268 L .68754 .61215 L F
.68758 .61475 m .6857 .61559 L .68557 .61268 L F
.152 .348 .805 r
.67032 .6112 m .67061 .61279 L .66946 .61204 L F
.683 .246 .205 r
.50029 .86793 m .50245 .86966 L .49922 .8694 L F
.686 .618 .774 r
.56337 .79032 m .56019 .78801 L .564 .78916 L F
.713 .644 .778 r
.56564 .78801 m .56337 .79032 L .564 .78916 L F
.087 .638 .819 r
.50162 .88901 m .50496 .88924 L .50389 .88905 L F
.651 .952 .947 r
.50389 .88905 m .50496 .88924 L .5066 .88826 L F
.595 .817 .985 r
.32964 .67555 m .33106 .67647 L .33317 .67595 L F
.576 .48 .709 r
.33182 .67969 m .33317 .67595 L .33106 .67647 L F
.466 .685 .961 r
.32218 .67386 m .32298 .67258 L .32134 .67249 L F
.32218 .67386 m .3239 .67327 L .32298 .67258 L F
0 0 .28 r
.32263 .67562 m .3239 .67327 L .32218 .67386 L F
.922 .581 .374 r
.5619 .79776 m .56017 .79581 L .55996 .79641 L F
.138 0 0 r
.3779 .75055 m .37677 .75119 L .37468 .75155 L F
.167 0 0 r
.3779 .75055 m .3784 .7507 L .37677 .75119 L F
0 .498 .769 r
.3779 .75055 m .38137 .75136 L .37984 .75095 L F
.167 0 0 r
.3779 .75055 m .37984 .75095 L .3784 .7507 L F
.344 0 .062 r
.67349 .70209 m .6772 .69991 L .67448 .70214 L F
.968 .785 .603 r
.57838 .80296 m .58002 .80149 L .57805 .80108 L F
.57838 .80296 m .57982 .80397 L .58002 .80149 L F
.923 .808 .714 r
.57955 .79902 m .57805 .80108 L .58002 .80149 L F
.348 .662 .972 r
.40928 .74301 m .41001 .74203 L .408 .74267 L F
.40928 .74301 m .41144 .7433 L .41001 .74203 L F
.173 .709 .77 r
.3841 .78419 m .38251 .78447 L .38124 .78458 L F
.322 .073 .372 r
.32092 .70815 m .32259 .708 L .32294 .70505 L F
.357 .209 .54 r
.32294 .70505 m .32531 .70573 L .32497 .7023 L F
.416 .149 .398 r
.32294 .70505 m .32447 .70716 L .32531 .70573 L F
.32294 .70505 m .32259 .708 L .32447 .70716 L F
.829 .449 .333 r
.48235 .8725 m .48322 .87077 L .48261 .86949 L F
.48235 .8725 m .48407 .87258 L .48322 .87077 L F
.553 .773 .98 r
.50389 .88432 m .50057 .88356 L .50189 .88601 L F
.457 .124 .313 r
.5039 .88776 m .50389 .88432 L .50189 .88601 L F
.5039 .88776 m .50602 .88394 L .50389 .88432 L F
.56 .084 .082 r
.64664 .63048 m .64961 .63038 L .64727 .62933 L F
.576 .48 .709 r
.33182 .67969 m .33389 .67917 L .33317 .67595 L F
.851 .817 .816 r
.67971 .59731 m .67657 .59892 L .67834 .59603 L F
.736 .71 .827 r
.68189 .5964 m .67971 .59731 L .67834 .59603 L F
.665 .697 .87 r
.3395 .65875 m .34068 .66067 L .3384 .66034 L F
.163 .258 .716 r
.3403 .66225 m .3384 .66034 L .34068 .66067 L F
.51 .624 .899 r
.34278 .65965 m .34068 .66067 L .3395 .65875 L F
.76 .658 .75 r
.34278 .65965 m .3403 .66225 L .34068 .66067 L F
0 .337 .732 r
.565 .78442 m .56649 .78509 L .56622 .7851 L F
.63 .463 .638 r
.56787 .78501 m .56564 .78801 L .56622 .7851 L F
.665 .822 .959 r
.59359 .84079 m .59644 .84079 L .59547 .84026 L F
.777 .965 .664 r
.59644 .84079 m .59806 .83819 L .59547 .84026 L F
0 0 0 r
.3591 .80743 m .36213 .80647 L .36115 .80693 L F
.36317 .80622 m .36213 .80647 L .36419 .80563 L F
.36115 .80693 m .36213 .80647 L .36317 .80622 L F
.794 .831 .88 r
.63673 .6329 m .64019 .63267 L .6392 .63086 L F
0 .317 .805 r
.63673 .6329 m .64023 .63655 L .64019 .63267 L F
.83 .843 .857 r
.64019 .63267 m .64173 .63068 L .6392 .63086 L F
.878 .771 .74 r
.67724 .60199 m .67516 .60167 L .67657 .59892 L F
.892 .729 .673 r
.67599 .60425 m .67516 .60167 L .67724 .60199 L F
.62 .399 .56 r
.33419 .74332 m .3364 .74413 L .33663 .74281 L F
.33419 .74332 m .33409 .74504 L .3364 .74413 L F
.484 .606 .898 r
.3308 .656 m .32974 .65775 L .32824 .65563 L F
.3308 .656 m .33155 .65763 L .32974 .65775 L F
.706 .186 0 r
.48664 .87849 m .48743 .87988 L .48495 .87845 L F
.48664 .87849 m .48859 .88065 L .48743 .87988 L F
.517 .306 .532 r
.43261 .76154 m .43453 .76352 L .43476 .76137 L F
.43261 .76154 m .43248 .76391 L .43453 .76352 L F
.489 .233 .453 r
.4024 .77507 m .40403 .7767 L .40447 .77477 L F
.4024 .77507 m .402 .77707 L .40403 .7767 L F
.756 .716 .814 r
.55047 .79347 m .54834 .79358 L .54935 .79155 L F
.54947 .79155 m .54935 .79155 L .54941 .79142 L F
.55047 .79347 m .54935 .79155 L .54947 .79155 L F
.54834 .79358 m .54901 .79181 L .54941 .79142 L F
.65 .252 .278 r
.55047 .79347 m .55 .79581 L .54713 .79365 L F
.383 .017 .214 r
.55129 .79447 m .55 .79581 L .55047 .79347 L F
.676 .574 .733 r
.54941 .79142 m .54713 .79365 L .549 .79141 L F
.748 .487 .536 r
.54911 .79155 m .55 .79581 L .55129 .79447 L F
.549 .79141 m .54904 .79155 L .54911 .79155 L F
.54904 .79155 m .55 .79581 L .54911 .79155 L F
.277 .455 .857 r
.55151 .79243 m .55047 .79347 L .54941 .79142 L F
.191 .315 .761 r
.55151 .79243 m .55192 .79356 L .55047 .79347 L F
.55192 .79356 m .55262 .79547 L .55089 .79386 L F
.55192 .79356 m .55089 .79386 L .55047 .79347 L F
.383 .017 .214 r
.55129 .79447 m .55047 .79347 L .551 .79397 L F
.55129 .79447 m .551 .79397 L .55262 .79547 L F
.841 .713 .722 r
.55035 .79764 m .55129 .79447 L .55262 .79547 L F
.383 .149 .431 r
.55083 .7966 m .55187 .79551 L .55129 .79447 L F
.752 .657 .757 r
.5548 .79281 m .55262 .79547 L .55198 .79371 L F
.55298 .7926 m .55198 .79371 L .55151 .79243 L F
.5548 .79281 m .55198 .79371 L .55298 .7926 L F
.383 .149 .431 r
.55187 .79551 m .55313 .79418 L .55129 .79447 L F
.55129 .79447 m .55129 .79447 L .55129 .79447 L F
.55187 .79551 m .55129 .79447 L .55129 .79447 L F
.026 0 .172 r
.55129 .79447 m .55313 .79418 L .55333 .79316 L F
.614 .796 .969 r
.5536 .7918 m .5548 .79281 L .55151 .79243 L F
.026 0 .172 r
.55213 .79351 m .55333 .79316 L .5536 .7918 L F
.55129 .79447 m .55333 .79316 L .55213 .79351 L F
.748 .487 .536 r
.54914 .79146 m .55129 .79447 L .55151 .79243 L F
.549 .79141 m .54911 .79155 L .54914 .79146 L F
.54911 .79155 m .55129 .79447 L .54914 .79146 L F
.756 .716 .814 r
.54834 .79358 m .54713 .79365 L .54901 .79181 L F
.694 .828 .947 r
.37984 .75095 m .38137 .75136 L .38321 .75074 L F
.456 .162 .377 r
.56709 .79376 m .56668 .79553 L .56459 .79593 L F
.325 0 0 r
.57097 .7933 m .56924 .79364 L .56709 .79376 L F
.628 .358 .49 r
.56924 .79364 m .56668 .79553 L .56709 .79376 L F
.461 .35 .641 r
.35816 .67788 m .35896 .68186 L .35658 .68178 L F
.489 .333 .596 r
.35896 .68186 m .35675 .68347 L .35658 .68178 L F
.75 .603 .694 r
.71164 .70808 m .71297 .7113 L .7095 .71088 L F
.717 .709 .841 r
.64579 .59822 m .64819 .59633 L .64937 .59899 L F
.48 .44 .736 r
.65026 .59659 m .64937 .59899 L .64819 .59633 L F
.65026 .59659 m .65123 .5986 L .64937 .59899 L F
.437 .277 .564 r
.64937 .59899 m .65123 .5986 L .64927 .60149 L F
.534 .397 .641 r
.46745 .85729 m .46944 .85709 L .46868 .85454 L F
.515 .449 .72 r
.46745 .85729 m .47003 .85957 L .46944 .85709 L F
.448 .81 .996 r
.68105 .73231 m .67817 .73218 L .67824 .73429 L F
.671 .531 .686 r
.67909 .73705 m .68105 .73231 L .67824 .73429 L F
.67909 .73705 m .68194 .73531 L .68105 .73231 L F
.477 .247 .486 r
.35124 .68833 m .35199 .69165 L .35001 .69201 L F
.439 .209 .467 r
.35391 .68566 m .35124 .68833 L .3526 .68666 L F
.35391 .68566 m .3543 .68872 L .35124 .68833 L F
.456 .245 .503 r
.3543 .68872 m .35199 .69165 L .35124 .68833 L F
.495 .741 .982 r
.3215 .65441 m .32087 .65581 L .31952 .65471 L F
.3215 .65441 m .32304 .65566 L .32087 .65581 L F
.526 .449 .712 r
.46421 .86799 m .46627 .86776 L .46561 .86455 L F
.569 .498 .736 r
.46457 .87022 m .46627 .86776 L .46421 .86799 L F
.858 .781 .775 r
.64207 .60476 m .64266 .60766 L .64113 .60722 L F
.817 .372 .182 r
.64266 .60766 m .64222 .60893 L .64113 .60722 L F
0 .523 .793 r
.64266 .60766 m .64398 .60771 L .64222 .60893 L F
.64266 .60766 m .64525 .60814 L .64398 .60771 L F
.943 .651 .457 r
.42011 .74338 m .41849 .74301 L .41684 .74227 L F
.42011 .74338 m .42007 .74516 L .41849 .74301 L F
.479 .25 .488 r
.4219 .74471 m .42011 .74338 L .42248 .74335 L F
.4219 .74471 m .42007 .74516 L .42011 .74338 L F
.659 .309 .368 r
.63607 .6492 m .63466 .65136 L .63243 .64956 L F
.656 .319 .389 r
.63784 .64961 m .63466 .65136 L .63607 .6492 L F
.751 .884 .94 r
.57722 .84238 m .58072 .84174 L .57955 .84097 L F
.333 0 0 r
.30743 .65158 m .31105 .65181 L .30892 .6514 L F
.054 0 .178 r
.32634 .71898 m .32486 .72134 L .32426 .72167 L F
.091 0 .25 r
.32426 .72167 m .32486 .72134 L .32388 .72305 L F
.754 .672 .771 r
.53836 .86535 m .54067 .86269 L .5372 .86227 L F
.892 .657 .576 r
.5796 .80602 m .58124 .80685 L .57982 .80397 L F
.936 .759 .638 r
.5796 .80602 m .58064 .8092 L .58124 .80685 L F
.038 .606 .759 r
.46584 .75336 m .46896 .75345 L .46698 .75375 L F
.641 .564 .753 r
.46997 .7556 m .46698 .75375 L .46896 .75345 L F
.513 .233 .426 r
.42512 .77759 m .42469 .77936 L .4226 .77935 L F
.535 .283 .479 r
.42715 .77718 m .42469 .77936 L .42512 .77759 L F
.647 .413 .551 r
.3456 .77161 m .34594 .7746 L .34306 .7743 L F
.578 .363 .553 r
.34797 .77422 m .3456 .77161 L .34775 .77091 L F
.34797 .77422 m .34594 .7746 L .3456 .77161 L F
.485 .344 .613 r
.66791 .7141 m .6666 .71182 L .66587 .71419 L F
.66791 .7141 m .66815 .71016 L .6666 .71182 L F
.485 .131 .29 r
.35776 .76146 m .35696 .76327 L .35489 .76339 L F
.505 .164 .322 r
.35976 .76121 m .35696 .76327 L .35776 .76146 L F
.481 .813 1 r
.4793 .86521 m .47777 .86562 L .47619 .86483 L F
.266 0 .131 r
.47777 .86562 m .47856 .86618 L .4793 .86521 L F
.737 .594 .697 r
.57125 .80115 m .57253 .80411 L .5691 .80396 L F
.716 .426 .484 r
.57253 .80411 m .57097 .80594 L .5691 .80396 L F
.849 .624 .597 r
.57253 .80411 m .57265 .8066 L .57097 .80594 L F
0 0 .033 r
.67813 .7017 m .67681 .70479 L .67719 .7029 L F
.734 .794 .9 r
.3384 .66034 m .335 .66014 L .33737 .65898 L F
.729 .792 .903 r
.3395 .65875 m .3384 .66034 L .33737 .65898 L F
.87 .661 .617 r
.67793 .6053 m .67453 .60387 L .67599 .60425 L F
.67793 .6053 m .67591 .60697 L .67453 .60387 L F
.927 .805 .706 r
.67793 .6053 m .67545 .60908 L .67591 .60697 L F
.708 .333 .336 r
.35125 .7364 m .35367 .73691 L .3549 .73515 L F
.263 0 .059 r
.3549 .73515 m .35562 .73642 L .35682 .73471 L F
.3549 .73515 m .35367 .73691 L .35562 .73642 L F
.924 .797 .701 r
.68785 .73279 m .68697 .73476 L .68628 .73185 L F
.303 .323 .716 r
.46784 .87284 m .46847 .87633 L .46992 .87506 L F
.418 .521 .856 r
.46847 .87633 m .47172 .87796 L .46992 .87506 L F
.858 .495 .362 r
.57666 .78505 m .57835 .78794 L .57986 .78808 L F
.855 .486 .351 r
.57835 .78794 m .57881 .78968 L .57986 .78808 L F
.82 .436 .327 r
.57881 .78968 m .58083 .79011 L .57986 .78808 L F
.733 .715 .834 r
.6807 .59385 m .68189 .5964 L .67834 .59603 L F
.579 .612 .849 r
.68274 .59326 m .68189 .5964 L .6807 .59385 L F
.68274 .59326 m .68422 .59597 L .68189 .5964 L F
.299 .21 .585 r
.54069 .8386 m .54267 .84018 L .5431 .83821 L F
.936 .759 .638 r
.5796 .80602 m .57891 .80912 L .58064 .8092 L F
.943 .781 .651 r
.57891 .80912 m .57963 .81146 L .58064 .8092 L F
.07 .607 .856 r
.47542 .88136 m .47609 .88117 L .47409 .88085 L F
.47542 .88136 m .47705 .88153 L .47609 .88117 L F
.821 .813 .842 r
.68156 .74497 m .68365 .74229 L .6835 .74531 L F
0 .136 .654 r
.6822 .74792 m .68156 .74497 L .6835 .74531 L F
.553 .691 .931 r
.71428 .70764 m .71164 .70808 L .70987 .70614 L F
.447 .208 .457 r
.35489 .76339 m .35227 .76603 L .35283 .76405 L F
.883 .564 .441 r
.49333 .85965 m .49579 .86228 L .49595 .85993 L F
.54 .256 .432 r
.66915 .63895 m .66891 .64156 L .66621 .64178 L F
.162 0 .072 r
.67146 .63888 m .66891 .64156 L .66915 .63895 L F
.467 .816 .998 r
.52807 .83063 m .53031 .83036 L .52894 .82971 L F
.671 .58 .744 r
.52807 .83063 m .5314 .8333 L .53031 .83036 L F
.526 .164 .295 r
.67155 .61509 m .67177 .61686 L .66902 .61711 L F
.093 .284 .765 r
.67061 .61279 m .67218 .61477 L .67155 .61509 L F
0 0 .262 r
.67218 .61477 m .67177 .61686 L .67155 .61509 L F
.725 .431 .481 r
.64024 .6387 m .64151 .63605 L .64023 .63655 L F
.528 .215 .381 r
.64024 .6387 m .64337 .63756 L .64151 .63605 L F
.967 .696 .466 r
.67435 .72268 m .67509 .72131 L .67383 .72011 L F
.785 .968 .918 r
.67465 .72208 m .67509 .72131 L .67435 .72268 L F
.969 .648 .295 r
.67473 .71863 m .67509 .72131 L .67557 .72049 L F
.74 .652 .763 r
.67603 .7215 m .67804 .71888 L .67473 .71863 L F
.785 .968 .918 r
.67569 .71998 m .67509 .72131 L .67465 .72208 L F
.969 .648 .295 r
.67557 .72049 m .67509 .72131 L .67603 .7215 L F
.527 .701 .95 r
.67707 .71983 m .67603 .7215 L .67509 .72131 L F
.497 .318 .568 r
.67603 .7215 m .67807 .72116 L .67804 .71888 L F
.527 .701 .95 r
.67707 .71983 m .67807 .72116 L .67603 .7215 L F
.768 .616 .69 r
.68022 .6103 m .67984 .6126 L .6786 .60975 L F
.707 .811 .93 r
.68897 .71695 m .68582 .71667 L .68776 .71551 L F
.638 .732 .916 r
.69107 .71624 m .68897 .71695 L .68776 .71551 L F
0 0 0 r
.38896 .7953 m .39251 .79331 L .3909 .79471 L F
.153 0 0 r
.393 .79413 m .39251 .79331 L .39456 .79303 L F
.393 .79413 m .3909 .79471 L .39251 .79331 L F
.606 .432 .62 r
.53018 .8279 m .53031 .83036 L .53235 .82969 L F
.579 .311 .475 r
.42791 .76625 m .43008 .76628 L .43054 .76435 L F
.454 .196 .432 r
.43054 .76435 m .43008 .76628 L .43248 .76391 L F
.838 .716 .729 r
.64383 .61259 m .64052 .61443 L .64276 .61143 L F
.64383 .61259 m .64214 .61516 L .64052 .61443 L F
.847 .697 .696 r
.57125 .80115 m .56832 .80124 L .56982 .79804 L F
.842 .762 .773 r
.57125 .80115 m .5691 .80396 L .56832 .80124 L F
.672 .569 .73 r
.49502 .86823 m .49458 .87011 L .49743 .86745 L F
.91 .875 .79 r
.49338 .87133 m .49249 .87272 L .49458 .87011 L F
.876 .66 .607 r
.58061 .81347 m .58258 .8121 L .57963 .81146 L F
.58061 .81347 m .58238 .81449 L .58258 .8121 L F
.77 .611 .683 r
.67984 .6126 m .68137 .61496 L .67828 .61472 L F
.752 .454 .48 r
.68137 .61496 m .67991 .6171 L .67828 .61472 L F
.451 .014 .116 r
.68309 .6154 m .67991 .6171 L .68137 .61496 L F
.569 .498 .736 r
.46457 .87022 m .4668 .86985 L .46627 .86776 L F
.875 .68 .636 r
.69226 .74287 m .6917 .74515 L .69409 .74552 L F
.873 .707 .674 r
.6917 .74515 m .6929 .74836 L .69409 .74552 L F
.363 .224 .554 r
.32865 .69243 m .33029 .69392 L .33009 .69164 L F
.32865 .69243 m .32869 .69474 L .33029 .69392 L F
.771 .567 .622 r
.6275 .6473 m .62747 .64921 L .62572 .64676 L F
.631 .458 .63 r
.53027 .84054 m .52715 .84164 L .52946 .83875 L F
0 0 0 r
.52946 .83875 m .52715 .84164 L .52876 .84001 L F
.631 .458 .63 r
.53027 .84054 m .52732 .84194 L .52715 .84164 L F
.226 .01 .362 r
.52867 .84258 m .52732 .84194 L .53027 .84054 L F
.273 .078 .424 r
.52715 .84164 m .52867 .84258 L .52876 .84001 L F
.226 .01 .362 r
.52867 .84258 m .52731 .84364 L .52732 .84194 L F
.273 .078 .424 r
.52715 .84164 m .52731 .84364 L .52867 .84258 L F
.037 0 0 r
.39635 .7236 m .39781 .72341 L .3993 .72283 L F
.326 .786 .944 r
.39647 .72316 m .39925 .72323 L .39781 .72341 L F
.428 0 0 r
.3993 .72283 m .39781 .72341 L .40123 .72334 L F
.326 .786 .944 r
.39925 .72323 m .39984 .72324 L .39781 .72341 L F
.037 0 0 r
.39576 .72375 m .39781 .72341 L .39635 .7236 L F
.316 0 .069 r
.65866 .64441 m .65554 .64655 L .65641 .64485 L F
.502 .844 .996 r
.51333 .85434 m .50957 .85464 L .511 .85492 L F
.335 .275 .641 r
.5314 .8333 m .53235 .82969 L .53031 .83036 L F
.5314 .8333 m .53244 .83515 L .53235 .82969 L F
.53 .35 .58 r
.53113 .83563 m .53244 .83515 L .5314 .8333 L F
0 0 .495 r
.67797 .62199 m .67764 .62554 L .67759 .62342 L F
.718 .795 .912 r
.54664 .81267 m .54822 .81262 L .54532 .81163 L F
.511 .61 .888 r
.44387 .73055 m .44286 .73243 L .44209 .73075 L F
.532 .637 .899 r
.44387 .73055 m .44492 .73226 L .44286 .73243 L F
.635 .823 .973 r
.36408 .79025 m .36083 .79008 L .3628 .78992 L F
0 0 0 r
.3628 .78992 m .36592 .78938 L .36408 .79025 L F
.606 .402 .58 r
.33028 .75074 m .33248 .75043 L .33251 .74812 L F
.531 .387 .631 r
.33248 .75043 m .3344 .74717 L .33251 .74812 L F
.935 .79 .675 r
.31561 .67495 m .31727 .67485 L .31896 .67308 L F
.31561 .67495 m .3168 .67628 L .31727 .67485 L F
.451 .014 .116 r
.68309 .6154 m .68246 .61714 L .67991 .6171 L F
0 0 0 r
.6857 .61559 m .68246 .61714 L .68309 .6154 L F
.961 .821 .659 r
.64253 .59832 m .64363 .59923 L .64285 .60175 L F
.748 .817 .906 r
.64253 .59832 m .64579 .59822 L .64363 .59923 L F
.736 .256 .105 r
.47666 .8548 m .4805 .85676 L .47867 .85747 L F
.252 .762 .85 r
.41473 .74299 m .41358 .74293 L .41144 .7433 L F
.561 .891 .986 r
.41547 .7419 m .41473 .74299 L .41684 .74227 L F
.62 .951 .928 r
.41547 .7419 m .41358 .74293 L .41473 .74299 L F
.491 .139 .296 r
.3642 .73162 m .36633 .73144 L .36753 .72924 L F
.378 0 .157 r
.36633 .73144 m .36967 .72909 L .36753 .72924 L F
.218 .189 .611 r
.66862 .72405 m .67006 .72342 L .66954 .72082 L F
0 .04 .56 r
.66862 .72405 m .66972 .72495 L .67006 .72342 L F
.66862 .72405 m .66936 .72632 L .66972 .72495 L F
.69 .249 .198 r
.57342 .78454 m .57515 .78535 L .57666 .78505 L F
.87 .492 .325 r
.57609 .787 m .57666 .78505 L .57515 .78535 L F
.57609 .787 m .57835 .78794 L .57666 .78505 L F
.334 .755 .976 r
.38893 .78197 m .39226 .78246 L .39011 .78251 L F
.687 .492 .617 r
.51009 .85212 m .51333 .85434 L .51277 .85205 L F
.308 0 .094 r
.40209 .7898 m .40262 .78875 L .40461 .78818 L F
0 .077 .633 r
.51472 .85391 m .51623 .85632 L .51538 .85458 L F
.592 .122 .107 r
.51472 .85391 m .51538 .85458 L .51333 .85434 L F
.874 .753 .726 r
.57319 .81808 m .57249 .81989 L .57153 .8171 L F
.24 0 .334 r
.48723 .87548 m .48495 .87845 L .48578 .87638 L F
.605 .365 .527 r
.46739 .75873 m .46495 .76099 L .46515 .75896 L F
.958 .723 .541 r
.50259 .86435 m .50384 .86232 L .50115 .86248 L F
.50259 .86435 m .50391 .86532 L .50384 .86232 L F
.684 .724 .88 r
.49305 .88521 m .4901 .8844 L .49201 .88319 L F
.577 .583 .823 r
.49411 .8828 m .49305 .88521 L .49201 .88319 L F
.49411 .8828 m .49509 .88446 L .49305 .88521 L F
.748 .495 .549 r
.59227 .82474 m .59552 .82265 L .59224 .82237 L F
.59227 .82474 m .59572 .82503 L .59552 .82265 L F
.816 .793 .831 r
.53073 .83747 m .53492 .83626 L .53378 .83547 L F
.917 .9 .795 r
.53445 .83491 m .53492 .83626 L .53656 .83313 L F
.535 .142 .243 r
.53443 .83503 m .5346 .83502 L .53445 .83491 L F
.917 .9 .795 r
.53378 .83547 m .53427 .83581 L .53445 .83491 L F
.535 .142 .243 r
.53244 .83515 m .53378 .83547 L .5346 .83502 L F
.917 .9 .795 r
.53378 .83547 m .53445 .83491 L .5346 .83502 L F
.53445 .83491 m .53656 .83313 L .5346 .83502 L F
.535 .142 .243 r
.53445 .83491 m .5346 .83502 L .53482 .83307 L F
.53482 .83307 m .5346 .83502 L .53549 .83249 L F
.53244 .83515 m .53443 .83503 L .53482 .83307 L F
.917 .9 .795 r
.53427 .83581 m .53492 .83626 L .53445 .83491 L F
.547 .279 .461 r
.45678 .76381 m .45218 .76676 L .45234 .76442 L F
.804 .499 .473 r
.58547 .81966 m .58894 .82212 L .58743 .81964 L F
.534 .315 .529 r
.33065 .68716 m .33217 .68868 L .3323 .68664 L F
.33065 .68716 m .33029 .68929 L .33217 .68868 L F
.322 0 0 r
.37946 .72651 m .38157 .72629 L .38302 .72499 L F
.314 0 0 r
.38157 .72629 m .38502 .72473 L .38302 .72499 L F
.577 .168 .23 r
.69838 .71075 m .69797 .71281 L .69532 .71127 L F
.315 .174 .525 r
.7004 .70744 m .70063 .71004 L .69838 .71075 L F
.386 .003 .184 r
.70029 .71142 m .69838 .71075 L .70063 .71004 L F
.70029 .71142 m .69797 .71281 L .69838 .71075 L F
.783 .767 .838 r
.62869 .63806 m .62771 .64139 L .62668 .64083 L F
.62869 .63806 m .63024 .63916 L .62771 .64139 L F
.598 .532 .752 r
.46955 .84898 m .4721 .84547 L .47025 .84648 L F
.788 .7 .768 r
.55949 .81229 m .56064 .81474 L .56266 .81213 L F
.235 .749 .861 r
.55949 .81229 m .56154 .81202 L .56266 .81213 L F
.788 .7 .768 r
.55949 .81229 m .56266 .81213 L .56154 .81202 L F
.901 .957 .823 r
.56154 .81202 m .56064 .81474 L .56266 .81213 L F
.586 .882 .992 r
.52099 .86696 m .52234 .86758 L .51874 .86767 L F
.772 .594 .658 r
.52234 .86758 m .51881 .8697 L .51874 .86767 L F
.52234 .86758 m .52262 .87003 L .51881 .8697 L F
.309 .747 .966 r
.5242 .86743 m .52234 .86758 L .52099 .86696 L F
.503 .399 .67 r
.52455 .86975 m .52234 .86758 L .5242 .86743 L F
.52455 .86975 m .52262 .87003 L .52234 .86758 L F
.757 .549 .614 r
.67396 .70696 m .67681 .70479 L .67617 .70448 L F
.872 .969 .853 r
.56266 .81213 m .56463 .80937 L .56451 .80977 L F
.56266 .81213 m .56154 .81202 L .56463 .80937 L F
.771 .76 .843 r
.56469 .81044 m .56266 .81213 L .56451 .80977 L F
.261 .689 .964 r
.56266 .81213 m .56388 .81154 L .56154 .81202 L F
.606 .449 .643 r
.56469 .81044 m .56523 .81242 L .56266 .81213 L F
.261 .689 .964 r
.56266 .81213 m .56523 .81242 L .56388 .81154 L F
.564 .141 .198 r
.6551 .63284 m .65842 .6325 L .65616 .63125 L F
.52 .222 .401 r
.65616 .63125 m .65842 .6325 L .65848 .63083 L F
.623 .354 .489 r
.45749 .76156 m .45947 .7636 L .45738 .76342 L F
.594 .176 .218 r
.6413 .64932 m .64011 .65074 L .63784 .64961 L F
.523 .04 .051 r
.6413 .64932 m .64229 .65075 L .64011 .65074 L F
.6413 .64932 m .64329 .64955 L .64229 .65075 L F
.755 .614 .701 r
.57097 .7933 m .57188 .79383 L .56924 .79364 L F
.708 .406 .463 r
.57188 .79383 m .56885 .79547 L .56924 .79364 L F
.57188 .79383 m .57235 .79562 L .56885 .79547 L F
.398 .343 .679 r
.46886 .85147 m .46868 .85454 L .47081 .8535 L F
.499 .433 .713 r
.46944 .85709 m .47081 .8535 L .46868 .85454 L F
.363 0 .131 r
.4226 .77935 m .42195 .78141 L .41909 .78171 L F
.578 .201 .291 r
.42469 .77936 m .42195 .78141 L .4226 .77935 L F
.446 .07 .232 r
.37178 .7289 m .37388 .72865 L .37518 .72652 L F
.356 0 .179 r
.37518 .72652 m .37587 .72817 L .37734 .72662 L F
.37518 .72652 m .37388 .72865 L .37587 .72817 L F
.258 0 .07 r
.39744 .77935 m .3988 .77971 L .40015 .77768 L F
.262 0 .072 r
.40015 .77768 m .40064 .77918 L .402 .77707 L F
.40015 .77768 m .3988 .77971 L .40064 .77918 L F
.911 .753 .674 r
.52173 .88025 m .52092 .87815 L .52079 .87943 L F
.877 .885 .836 r
.51912 .88137 m .52173 .88025 L .52079 .87943 L F
.763 .642 .727 r
.69342 .72901 m .69665 .72927 L .69557 .72622 L F
.69342 .72901 m .69485 .72994 L .69665 .72927 L F
.781 .68 .753 r
.69446 .73198 m .69665 .72927 L .69485 .72994 L F
.728 .683 .807 r
.69557 .72622 m .69665 .72927 L .69885 .72665 L F
.157 .337 .794 r
.55373 .78585 m .55605 .78743 L .55688 .78541 L F
.439 .113 .316 r
.55605 .78743 m .55934 .78424 L .55688 .78541 L F
.714 .569 .69 r
.66393 .71865 m .66505 .7218 L .66767 .71875 L F
.151 .069 .501 r
.66767 .71875 m .66904 .71748 L .66895 .71571 L F
.319 .334 .719 r
.66954 .72082 m .66904 .71748 L .66767 .71875 L F
.62 .883 .989 r
.32705 .65511 m .32677 .65638 L .32503 .65535 L F
.32705 .65511 m .32824 .65563 L .32677 .65638 L F
.718 .874 .955 r
.71624 .73319 m .71667 .73369 L .71992 .73228 L F
.509 .226 .42 r
.36489 .75628 m .36445 .75816 L .36231 .7585 L F
.562 .275 .437 r
.36489 .75628 m .36664 .75798 L .36445 .75816 L F
.565 .275 .434 r
.36713 .75614 m .36664 .75798 L .36489 .75628 L F
.686 .641 .8 r
.43965 .74751 m .44115 .75049 L .44295 .74794 L F
.558 .467 .707 r
.44115 .75049 m .44325 .75027 L .44295 .74794 L F
.713 .697 .833 r
.69885 .72665 m .70212 .7277 L .70188 .72593 L F
.467 .514 .823 r
.70188 .72593 m .70212 .7277 L .70368 .72556 L F
.58 .675 .905 r
.70368 .72556 m .70212 .7277 L .70394 .72718 L F
.612 .586 .8 r
.70212 .7277 m .70536 .7298 L .70394 .72718 L F
.171 .31 .764 r
.57084 .83837 m .57192 .84117 L .57251 .83979 L F
.411 .598 .922 r
.57192 .84117 m .574 .84126 L .57251 .83979 L F
.142 0 .011 r
.54023 .8084 m .54137 .80829 L .5419 .80712 L F
.56 .132 .186 r
.54137 .80829 m .54432 .80846 L .5419 .80712 L F
.868 .444 .206 r
.54484 .82972 m .54474 .82819 L .54353 .82742 L F
.54484 .82972 m .54632 .83046 L .54474 .82819 L F
.594 .683 .904 r
.45164 .73483 m .44855 .7337 L .45059 .73336 L F
.608 .713 .919 r
.45396 .73436 m .45164 .73483 L .45059 .73336 L F
.753 .648 .745 r
.66386 .71637 m .66587 .71419 L .66269 .71333 L F
.517 .485 .76 r
.66587 .71419 m .66895 .71571 L .66791 .7141 L F
.831 .712 .733 r
.3912 .90272 m .3901 .90379 L .39196 .90512 L F
0 0 0 r
.53934 .85959 m .5372 .86227 L .54067 .86269 L F
.763 .663 .752 r
.54067 .86269 m .54285 .85997 L .53934 .85959 L F
.356 .791 .966 r
.34967 .7922 m .34794 .79243 L .3463 .79198 L F
.629 .636 .839 r
.57517 .84332 m .57609 .84044 L .574 .84126 L F
.57517 .84332 m .57722 .84238 L .57609 .84044 L F
.214 0 .331 r
.54554 .84665 m .54343 .84983 L .54597 .84936 L F
.662 .639 .816 r
.54554 .84665 m .548 .84653 L .54662 .8438 L F
.662 .503 .659 r
.54597 .84936 m .548 .84653 L .54554 .84665 L F
.183 .157 .592 r
.56725 .8333 m .56866 .83246 L .56826 .82999 L F
.236 .264 .688 r
.56725 .8333 m .56919 .83536 L .56866 .83246 L F
.771 .617 .688 r
.53934 .85959 m .54285 .85997 L .54085 .85855 L F
.302 .344 .74 r
.55305 .79101 m .5548 .79281 L .55433 .79034 L F
.951 .777 .63 r
.55433 .79034 m .5548 .79281 L .5536 .7918 L F
0 0 .107 r
.55433 .79034 m .5536 .7918 L .55519 .78989 L F
.55433 .79034 m .55519 .78989 L .55563 .78936 L F
.302 .344 .74 r
.55263 .79057 m .55305 .79101 L .55433 .79034 L F
.073 0 .099 r
.66902 .61711 m .66685 .61944 L .66706 .61846 L F
.705 .572 .703 r
.66386 .71637 m .66145 .71925 L .66393 .71865 L F
.706 .848 .95 r
.35881 .79116 m .35524 .7913 L .35747 .79066 L F
.713 .908 .964 r
.36083 .79008 m .35881 .79116 L .35747 .79066 L F
.804 .688 .737 r
.57325 .81189 m .57031 .81166 L .57199 .80902 L F
.213 .331 .768 r
.57031 .81166 m .57131 .81448 L .57325 .81189 L F
.523 .349 .586 r
.51654 .88118 m .51912 .88137 L .51774 .88033 L F
.51654 .88118 m .51663 .88335 L .51912 .88137 L F
.597 .635 .859 r
.70524 .71627 m .70195 .71438 L .70402 .71483 L F
.799 .74 .797 r
.70742 .71369 m .70524 .71627 L .70402 .71483 L F
.804 .63 .667 r
.6786 .60975 m .67984 .6126 L .67685 .61194 L F
.96 .648 .389 r
.67828 .61472 m .67685 .61194 L .67984 .6126 L F
.788 .561 .594 r
.49137 .88016 m .4919 .88102 L .48859 .88065 L F
.682 .314 .343 r
.49253 .87778 m .4948 .87987 L .4943 .87971 L F
.288 .279 .675 r
.49253 .87778 m .49137 .88016 L .49073 .87581 L F
0 0 .433 r
.49195 .88088 m .49137 .88016 L .49253 .87778 L F
.974 .793 .597 r
.49164 .87886 m .49195 .88088 L .49253 .87778 L F
.682 .314 .343 r
.49253 .87778 m .4943 .87971 L .49164 .87886 L F
.288 .279 .675 r
.49253 .87778 m .49073 .87581 L .4907 .87566 L F
0 0 .433 r
.49195 .88088 m .4919 .88102 L .49137 .88016 L F
.694 .828 .947 r
.37984 .75095 m .38321 .75074 L .38178 .75108 L F
.47 0 0 r
.38557 .75067 m .38178 .75108 L .38321 .75074 L F
.396 .13 .389 r
.35675 .68347 m .35618 .68615 L .35391 .68566 L F
.318 .127 .457 r
.35573 .68805 m .35391 .68566 L .35618 .68615 L F
.35573 .68805 m .3543 .68872 L .35391 .68566 L F
.969 .81 .63 r
.72013 .72627 m .71943 .72934 L .7206 .72841 L F
.948 .796 .66 r
.71866 .73139 m .7206 .72841 L .71943 .72934 L F
.71866 .73139 m .71992 .73228 L .7206 .72841 L F
.554 .336 .538 r
.35053 .76669 m .34998 .76862 L .34817 .7689 L F
.466 .237 .482 r
.35227 .76603 m .34998 .76862 L .35053 .76669 L F
.17 0 0 r
.36952 .8036 m .36876 .80429 L .36622 .80511 L F
.109 0 0 r
.37127 .80306 m .37081 .8037 L .36952 .8036 L F
.37081 .8037 m .36876 .80429 L .36952 .8036 L F
.648 .576 .761 r
.66145 .71925 m .66505 .7218 L .66393 .71865 L F
.43 .226 .5 r
.32512 .70014 m .32678 .69979 L .32708 .69762 L F
.475 .306 .572 r
.32497 .7023 m .32678 .69979 L .32512 .70014 L F
.881 .764 .729 r
.62577 .64444 m .62269 .64654 L .62495 .64376 L F
.62577 .64444 m .62392 .64704 L .62269 .64654 L F
.816 .657 .686 r
.62572 .64676 m .62392 .64704 L .62577 .64444 L F
.911 .75 .668 r
.57838 .80296 m .5796 .80602 L .57982 .80397 L F
.935 .79 .675 r
.31561 .67495 m .31896 .67308 L .31739 .67504 L F
.773 .542 .585 r
.32134 .67249 m .31739 .67504 L .31896 .67308 L F
.602 .914 .979 r
.49563 .8673 m .49502 .86823 L .49743 .86745 L F
.425 .012 .15 r
.41253 .77148 m .41188 .77223 L .41464 .77131 L F
0 0 0 r
.47921 .83578 m .47808 .83763 L .4775 .83497 L F
.356 0 0 r
.4775 .83497 m .48123 .83554 L .47921 .83578 L F
.464 .36 .651 r
.48135 .83802 m .47921 .83578 L .48123 .83554 L F
.672 .841 .424 r
.48099 .83579 m .48003 .83736 L .48107 .83578 L F
.48118 .83559 m .48107 .83578 L .48123 .83554 L F
.48099 .83579 m .48107 .83578 L .48118 .83559 L F
.464 .36 .651 r
.48135 .83802 m .47964 .8386 L .4796 .83833 L F
.48037 .83699 m .4796 .83833 L .47921 .83578 L F
.48135 .83802 m .4796 .83833 L .48037 .83699 L F
.783 .566 .606 r
.67824 .73429 m .67817 .73218 L .67495 .7319 L F
.181 .049 .453 r
.67764 .62554 m .67751 .6278 L .67655 .62815 L F
.192 .077 .484 r
.67751 .6278 m .67744 .63007 L .67655 .62815 L F
.259 .035 .372 r
.33228 .71299 m .33029 .71581 L .33084 .71371 L F
.824 .575 .562 r
.69049 .72974 m .69446 .73198 L .69485 .72994 L F
.69049 .72974 m .69141 .73162 L .69446 .73198 L F
.888 .745 .697 r
.69144 .73403 m .69446 .73198 L .69141 .73162 L F
.69144 .73403 m .69274 .73515 L .69446 .73198 L F
.091 0 .11 r
.32771 .71815 m .32634 .71898 L .32861 .71656 L F
.305 0 .244 r
.32958 .71738 m .32861 .71656 L .33029 .71581 L F
.32958 .71738 m .32771 .71815 L .32861 .71656 L F
.418 0 0 r
.64329 .64955 m .64654 .64915 L .64549 .64969 L F
.356 0 0 r
.64654 .64915 m .64804 .64964 L .64549 .64969 L F
.64654 .64915 m .64851 .64895 L .64804 .64964 L F
.503 .682 .947 r
.44032 .72885 m .43925 .73046 L .43826 .72906 L F
.44032 .72885 m .44209 .73075 L .43925 .73046 L F
.539 .525 .788 r
.31105 .65181 m .31215 .65505 L .31187 .65506 L F
.505 0 0 r
.48408 .88653 m .48735 .88664 L .48662 .88768 L F
.78 .278 0 r
.48735 .88664 m .48805 .88858 L .48662 .88768 L F
.48735 .88664 m .48924 .88906 L .48805 .88858 L F
.298 0 0 r
.54246 .85566 m .54179 .85545 L .54044 .85648 L F
.73 .206 0 r
.49142 .87728 m .49253 .87778 L .4907 .87566 L F
.49142 .87728 m .4907 .87566 L .49188 .87556 L F
.897 .761 .704 r
.57153 .8171 m .57249 .81989 L .57089 .81945 L F
.872 .752 .727 r
.57249 .81989 m .56936 .82198 L .57089 .81945 L F
.57249 .81989 m .57091 .82303 L .56936 .82198 L F
.546 .323 .527 r
.34998 .76862 m .34775 .77091 L .34817 .7689 L F
.392 .552 .894 r
.36463 .90763 m .36475 .90765 L .36466 .90768 L F
.123 0 .208 r
.36466 .90768 m .36475 .90765 L .36462 .90781 L F
0 0 .116 r
.5806 .7921 m .58016 .7956 L .58159 .79393 L F
.585 .597 .831 r
.66191 .60468 m .65797 .60176 L .66016 .60351 L F
.555 .774 .98 r
.66185 .60347 m .66191 .60468 L .66016 .60351 L F
.999 .797 .484 r
.66146 .60699 m .66191 .60468 L .66185 .60347 L F
.602 .398 .577 r
.46997 .7556 m .4716 .7577 L .46739 .75873 L F
.321 .424 .811 r
.46896 .75345 m .47139 .75511 L .46997 .7556 L F
.652 .596 .779 r
.47139 .75511 m .4716 .7577 L .46997 .7556 L F
.568 .803 .988 r
.42205 .72725 m .4187 .7267 L .42079 .72633 L F
.449 .687 .967 r
.42282 .72583 m .42205 .72725 L .42079 .72633 L F
.42282 .72583 m .42439 .7274 L .42205 .72725 L F
.508 .173 .334 r
.44469 .76965 m .44206 .77134 L .4424 .76967 L F
.552 .352 .563 r
.65115 .72254 m .65317 .72347 L .65102 .72113 L F
.65115 .72254 m .65317 .72347 L .65102 .72113 L F
.539 .035 .007 r
.56649 .78509 m .56994 .78504 L .56787 .78501 L F
.342 0 .068 r
.66393 .64195 m .66306 .64352 L .66085 .64393 L F
.241 0 0 r
.66621 .64178 m .66306 .64352 L .66393 .64195 L F
.964 .669 .254 r
.64912 .61018 m .65036 .6128 L .64973 .61034 L F
.862 .656 .623 r
.64797 .61362 m .65036 .6128 L .64912 .61018 L F
.64797 .61362 m .64981 .61487 L .65036 .6128 L F
.554 .896 .659 r
.67813 .7186 m .68008 .7172 L .67804 .71888 L F
.613 .877 .544 r
.67707 .71983 m .67813 .7186 L .67804 .71888 L F
.984 .726 .453 r
.67804 .71888 m .67807 .72116 L .67707 .71983 L F
.869 .677 .641 r
.64973 .61034 m .64861 .60724 L .64811 .60933 L F
.964 .669 .254 r
.64912 .61018 m .64973 .61034 L .64811 .60933 L F
.651 .397 .523 r
.66901 .70989 m .67125 .70857 L .66999 .70793 L F
.871 .591 .512 r
.7169 .72047 m .719 .7189 L .71785 .71808 L F
.7169 .72047 m .71941 .72122 L .719 .7189 L F
.18 0 0 r
.36435 .90757 m .36475 .90765 L .36463 .90763 L F
.243 0 .324 r
.32563 .72089 m .32486 .72134 L .32634 .71898 L F
.334 .08 .372 r
.32721 .72001 m .32634 .71898 L .32771 .71815 L F
.32721 .72001 m .32563 .72089 L .32634 .71898 L F
.625 .614 .82 r
.70394 .72718 m .70536 .7298 L .70759 .72922 L F
.551 .884 .989 r
.51215 .88573 m .51279 .88498 L .51163 .8863 L F
.51215 .88573 m .51423 .88532 L .51279 .88498 L F
.244 0 0 r
.48924 .88906 m .49062 .88951 L .49277 .89026 L F
.88 .677 .624 r
.59558 .82977 m .59821 .82761 L .59562 .82733 L F
.59558 .82977 m .59715 .82954 L .59821 .82761 L F
.52 .822 1 r
.31408 .65425 m .31629 .65379 L .31784 .65461 L F
.2 .655 .944 r
.31629 .65379 m .31952 .65471 L .31784 .65461 L F
0 .136 .654 r
.6822 .74792 m .68318 .74728 L .68156 .74497 L F
.026 .202 .709 r
.6822 .74792 m .68404 .75012 L .68318 .74728 L F
.355 .404 .775 r
.68652 .59749 m .6851 .59915 L .68422 .59597 L F
.447 .541 .86 r
.68652 .59749 m .6869 .59915 L .6851 .59915 L F
.75 .612 .705 r
.62747 .64921 m .62392 .64704 L .62572 .64676 L F
.885 .781 .742 r
.5691 .80396 m .56746 .80358 L .56832 .80124 L F
.9 .617 .498 r
.5691 .80396 m .56782 .80577 L .56746 .80358 L F
.758 .411 .396 r
.57097 .80594 m .56782 .80577 L .5691 .80396 L F
.81 .58 .591 r
.49201 .88319 m .48859 .88065 L .4919 .88102 L F
.913 .522 .252 r
.49195 .88088 m .49411 .8828 L .4919 .88102 L F
.556 .417 .647 r
.4919 .88102 m .49411 .8828 L .49201 .88319 L F
.799 .74 .797 r
.70742 .71369 m .70402 .71483 L .70691 .71352 L F
0 0 0 r
.7095 .71088 m .70742 .71369 L .7086 .71243 L F
.619 .959 .873 r
.70742 .71369 m .70691 .71352 L .7086 .71243 L F
.874 .776 .75 r
.70734 .70479 m .70835 .70783 L .70564 .70742 L F
.933 .937 .778 r
.70835 .70783 m .70555 .70982 L .70564 .70742 L F
.70835 .70783 m .70622 .71072 L .70555 .70982 L F
.634 .65 .849 r
.70987 .70614 m .70835 .70783 L .70734 .70479 L F
0 0 0 r
.3509 .81117 m .35383 .80944 L .3512 .81152 L F
.175 0 0 r
.3558 .80911 m .35383 .80944 L .35564 .80872 L F
.3512 .81152 m .35383 .80944 L .3558 .80911 L F
.804 .63 .667 r
.6786 .60975 m .67685 .61194 L .67649 .61028 L F
.935 .665 .503 r
.54653 .83524 m .54727 .83874 L .54861 .83879 L F
.866 .468 .28 r
.54727 .83874 m .54785 .84031 L .54861 .83879 L F
.882 .491 .289 r
.54785 .84031 m .5494 .84081 L .54861 .83879 L F
.304 .262 .645 r
.47797 .84863 m .47712 .85129 L .47661 .84848 L F
.735 .286 .184 r
.49032 .86279 m .48923 .86405 L .48707 .86195 L F
.732 .281 .182 r
.49032 .86279 m .49241 .86467 L .48923 .86405 L F
.677 .393 .483 r
.56459 .79593 m .56132 .79817 L .5619 .79776 L F
.56459 .79593 m .56433 .79829 L .56132 .79817 L F
.637 .427 .581 r
.56668 .79553 m .56433 .79829 L .56459 .79593 L F
.825 .718 .747 r
.63422 .63302 m .63139 .63341 L .63322 .63052 L F
.825 .735 .765 r
.63422 .63302 m .6322 .63636 L .63139 .63341 L F
.811 .712 .756 r
.63322 .63052 m .63481 .63174 L .63422 .63302 L F
.687 .492 .617 r
.51009 .85212 m .50957 .85464 L .51333 .85434 L F
.843 .807 .815 r
.36435 .90757 m .36475 .90765 L .36462 .90781 L F
.885 .717 .669 r
.69174 .7394 m .69345 .74 L .69228 .73704 L F
.945 .839 .708 r
.69111 .74201 m .69345 .74 L .69174 .7394 L F
.69111 .74201 m .69226 .74287 L .69345 .74 L F
.789 .68 .744 r
.69228 .73704 m .69345 .74 L .69362 .73818 L F
.313 .155 .499 r
.33267 .68432 m .33406 .68369 L .33422 .6814 L F
.612 .518 .723 r
.3323 .68664 m .33406 .68369 L .33267 .68432 L F
.242 0 0 r
.38502 .72473 m .3866 .72492 L .38817 .72373 L F
.191 0 0 r
.3866 .72492 m .39031 .72356 L .38817 .72373 L F
.62 .057 0 r
.43318 .72665 m .43499 .72816 L .43652 .72877 L F
.121 .587 .918 r
.43703 .72828 m .43652 .72877 L .43499 .72816 L F
.43703 .72828 m .43826 .72906 L .43652 .72877 L F
.152 .654 .908 r
.5182 .86471 m .51874 .8651 L .51638 .86466 L F
.325 .118 .437 r
.51722 .86603 m .51635 .86528 L .51595 .86773 L F
.724 .341 .325 r
.51682 .86474 m .51874 .8651 L .51802 .86599 L F
.51693 .8651 m .51802 .86599 L .51745 .86668 L F
.325 .118 .437 r
.5182 .86471 m .51722 .86603 L .51754 .86693 L F
.51722 .86603 m .51595 .86773 L .51754 .86693 L F
.724 .341 .325 r
.51722 .86603 m .51745 .86668 L .51743 .86671 L F
.51693 .8651 m .51745 .86668 L .51722 .86603 L F
.51682 .86474 m .51802 .86599 L .51693 .8651 L F
.152 .654 .908 r
.51693 .8651 m .51638 .86466 L .51635 .86528 L F
.5182 .86471 m .51638 .86466 L .51693 .8651 L F
.325 .118 .437 r
.5182 .86471 m .51693 .8651 L .51722 .86603 L F
.51693 .8651 m .51635 .86528 L .51722 .86603 L F
.724 .341 .325 r
.51743 .86671 m .51874 .8651 L .51754 .86693 L F
.51638 .86466 m .51682 .86474 L .51743 .86671 L F
.985 .885 .541 r
.51754 .86693 m .51874 .8651 L .5182 .86471 L F
.493 .086 .196 r
.48261 .85689 m .48513 .85672 L .48564 .85532 L F
.577 .167 .227 r
.48564 .85532 m .48513 .85672 L .48837 .85639 L F
.695 .447 .544 r
.51595 .86773 m .51635 .86528 L .51333 .86499 L F
.68 .634 .797 r
.51333 .86499 m .51635 .86528 L .51638 .86466 L F
.655 .449 .592 r
.51638 .86466 m .51595 .86773 L .51333 .86499 L F
.344 0 .062 r
.67349 .70209 m .67571 .7017 L .6772 .69991 L F
.73 .35 .332 r
.6772 .69991 m .67571 .7017 L .67813 .7017 L F
.313 .07 .377 r
.3344 .71032 m .33228 .71299 L .33283 .71099 L F
.856 .706 .694 r
.6392 .63086 m .64173 .63068 L .6405 .62798 L F
.729 .656 .777 r
.64173 .63068 m .64409 .6282 L .6405 .62798 L F
.773 .635 .708 r
.6582 .60654 m .66146 .60699 L .66057 .60461 L F
.69 .449 .552 r
.65472 .60344 m .66017 .6048 L .65797 .60176 L F
.66017 .6048 m .66023 .60477 L .65797 .60176 L F
.462 .394 .695 r
.65797 .60176 m .66023 .60477 L .66016 .60351 L F
.773 .635 .708 r
.66023 .60477 m .66057 .60461 L .66016 .60351 L F
.462 .394 .695 r
.66023 .60477 m .66028 .60483 L .66016 .60351 L F
.646 .421 .563 r
.65601 .6054 m .66016 .60485 L .65472 .60344 L F
.773 .635 .708 r
.6582 .60654 m .66057 .60461 L .66026 .60476 L F
.646 .421 .563 r
.65601 .6054 m .6582 .60654 L .66016 .60485 L F
.773 .635 .708 r
.6582 .60654 m .66026 .60476 L .65893 .60541 L F
.646 .421 .563 r
.66016 .60485 m .6582 .60654 L .66028 .60483 L F
.66016 .60485 m .66028 .60483 L .66017 .6048 L F
.66016 .60485 m .66017 .6048 L .65472 .60344 L F
.773 .635 .708 r
.65893 .60541 m .66017 .6048 L .66016 .60351 L F
.66017 .6048 m .66023 .60477 L .66022 .60458 L F
.66017 .6048 m .66022 .60458 L .66016 .60351 L F
.69 .449 .552 r
.66017 .6048 m .66028 .60483 L .66023 .60477 L F
0 0 0 r
.42752 .72654 m .42842 .72656 L .43007 .72608 L F
.42752 .72654 m .42641 .72694 L .42842 .72656 L F
.262 .324 .739 r
.54023 .8084 m .54213 .80911 L .54137 .80829 L F
.554 .7 .937 r
.44908 .73157 m .44855 .7337 L .447 .73194 L F
.44908 .73157 m .45059 .73336 L .44855 .7337 L F
0 .266 .635 r
.54517 .81155 m .5451 .81152 L .54213 .80911 L F
.54517 .81155 m .54532 .81163 L .5451 .81152 L F
.596 .366 .537 r
.32998 .75297 m .33248 .75043 L .33028 .75074 L F
.805 .627 .66 r
.58238 .81449 m .58231 .81713 L .58419 .81703 L F
.799 .519 .514 r
.58239 .81919 m .58419 .81703 L .58231 .81713 L F
.58239 .81919 m .58547 .81966 L .58419 .81703 L F
0 0 0 r
.53788 .83269 m .5346 .83502 L .53656 .83313 L F
.432 .228 .5 r
.32708 .69762 m .32678 .69979 L .32881 .69704 L F
.248 0 0 r
.40209 .7898 m .39851 .79183 L .39976 .79035 L F
.606 .899 .987 r
.31408 .65425 m .31215 .65505 L .31271 .65383 L F
0 .158 .677 r
.31271 .65383 m .31215 .65505 L .31105 .65181 L F
.564 .257 .406 r
.46287 .76075 m .46168 .76352 L .45947 .7636 L F
.565 .258 .407 r
.46587 .76206 m .46287 .76075 L .46495 .76099 L F
.46587 .76206 m .46168 .76352 L .46287 .76075 L F
.464 .556 .865 r
.35068 .67226 m .34944 .67361 L .34791 .67074 L F
.459 .549 .86 r
.35068 .67226 m .35086 .67435 L .34944 .67361 L F
.596 .577 .802 r
.35273 .67627 m .34944 .67361 L .35086 .67435 L F
.838 .653 .109 r
.68758 .72707 m .68737 .7283 L .68698 .72751 L F
.674 .125 0 r
.68806 .72672 m .68758 .72707 L .68459 .72473 L F
.406 .408 .749 r
.68459 .72473 m .68758 .72707 L .6864 .72328 L F
.838 .653 .109 r
.68758 .72707 m .68698 .72751 L .68595 .72544 L F
.674 .125 0 r
.68834 .72689 m .68758 .72707 L .68806 .72672 L F
.674 .966 .762 r
.68916 .72564 m .68758 .72707 L .68834 .72689 L F
.996 .808 .45 r
.68834 .72689 m .68758 .72707 L .68916 .72564 L F
.68834 .72689 m .68802 .72912 L .68758 .72707 L F
.736 .682 .799 r
.68944 .74785 m .6904 .75067 L .6929 .74836 L F
.254 0 .119 r
.39744 .77935 m .39619 .78148 L .3988 .77971 L F
.418 .863 .895 r
.59258 .8407 m .59359 .84079 L .59547 .84026 L F
.827 .757 .786 r
.6322 .63636 m .63024 .63916 L .62869 .63806 L F
.308 .444 .835 r
.70668 .70245 m .70473 .70308 L .70439 .70175 L F
.788 .761 .829 r
.70879 .70235 m .70734 .70479 L .70668 .70245 L F
.82 .573 .566 r
.7059 .7031 m .70756 .70199 L .70668 .70245 L F
.788 .761 .829 r
.70879 .70235 m .70668 .70245 L .70878 .70116 L F
.82 .573 .566 r
.70756 .70199 m .70878 .70116 L .70668 .70245 L F
.308 .444 .835 r
.70668 .70245 m .70734 .70479 L .70507 .7033 L F
.70668 .70245 m .70507 .7033 L .70473 .70308 L F
.543 .429 .673 r
.70734 .70479 m .70534 .70549 L .70473 .70308 L F
0 0 0 r
.7095 .71088 m .7086 .71243 L .70622 .71072 L F
.437 .198 .452 r
.34187 .73934 m .34158 .73998 L .34341 .73921 L F
.367 .492 .853 r
.56451 .80977 m .56708 .81184 L .56469 .81044 L F
.528 .266 .463 r
.56708 .81184 m .56523 .81242 L .56469 .81044 L F
.866 .755 .739 r
.63139 .63341 m .6322 .63636 L .6307 .63531 L F
.827 .757 .786 r
.6322 .63636 m .62869 .63806 L .6307 .63531 L F
.574 .82 .991 r
.49867 .88478 m .49509 .88446 L .49806 .88467 L F
.78 .918 .931 r
.49925 .8831 m .49867 .88478 L .49806 .88467 L F
.49925 .8831 m .50057 .88356 L .49867 .88478 L F
.495 0 0 r
.48134 .85985 m .48057 .86023 L .47792 .85942 L F
.295 0 0 r
.48057 .86023 m .47774 .86099 L .47792 .85942 L F
.48057 .86023 m .47901 .86126 L .47774 .86099 L F
.887 .985 .716 r
.48111 .85858 m .47934 .86084 L .48057 .86023 L F
.47934 .86084 m .47901 .86126 L .48057 .86023 L F
.495 0 0 r
.48173 .8599 m .48057 .86023 L .48134 .85985 L F
.76 .643 .733 r
.69049 .72974 m .69485 .72994 L .69342 .72901 L F
.802 .918 .916 r
.51279 .88498 m .51423 .88532 L .51663 .88335 L F
.429 .633 .941 r
.70348 .71318 m .70195 .71438 L .70105 .71372 L F
.70348 .71318 m .70402 .71483 L .70195 .71438 L F
.665 .118 0 r
.48928 .85784 m .48915 .85721 L .48837 .85639 L F
.48928 .85784 m .49126 .8592 L .48915 .85721 L F
.393 .436 .786 r
.4668 .86985 m .46784 .87284 L .46932 .87274 L F
.303 .323 .716 r
.46784 .87284 m .46992 .87506 L .46932 .87274 L F
.317 0 0 r
.39081 .72444 m .39313 .72376 L .39241 .72381 L F
.441 .837 .98 r
.39372 .72421 m .39241 .72381 L .39442 .72338 L F
.317 0 0 r
.39313 .72376 m .39442 .72338 L .39241 .72381 L F
.057 .6 .847 r
.39179 .72384 m .39241 .72381 L .39372 .72421 L F
.39031 .72356 m .39241 .72381 L .39179 .72384 L F
.441 .837 .98 r
.39372 .72421 m .39442 .72338 L .39576 .72375 L F
.025 .59 .791 r
.47393 .84321 m .47626 .84346 L .47502 .84344 L F
.071 .265 .755 r
.4773 .84553 m .47502 .84344 L .47626 .84346 L F
.582 .322 .488 r
.43746 .77207 m .4369 .77444 L .43469 .77446 L F
.526 .269 .469 r
.43908 .77403 m .43746 .77207 L .43979 .77169 L F
.43908 .77403 m .4369 .77444 L .43746 .77207 L F
.681 .37 .442 r
.63243 .64956 m .63281 .65096 L .62926 .65142 L F
.62 .334 .462 r
.63243 .64956 m .63466 .65136 L .63281 .65096 L F
.547 .516 .772 r
.64581 .61734 m .64617 .61428 L .64306 .61697 L F
.64581 .61734 m .64765 .61818 L .64617 .61428 L F
.464 .112 .283 r
.35895 .73447 m .36112 .73419 L .36216 .73201 L F
.395 .045 .248 r
.36216 .73201 m .36309 .73374 L .3642 .73162 L F
.36216 .73201 m .36112 .73419 L .36309 .73374 L F
.531 .39 .634 r
.67646 .7073 m .67713 .70952 L .67497 .71002 L F
.952 .601 .243 r
.67578 .70758 m .67648 .70858 L .67646 .7073 L F
.67648 .70858 m .67713 .70952 L .67646 .7073 L F
0 0 .177 r
.67644 .70604 m .67646 .7073 L .67574 .70841 L F
.67681 .70479 m .67646 .7073 L .67644 .70604 L F
.659 .864 .977 r
.35321 .79186 m .34967 .7922 L .35173 .79153 L F
.528 .871 .99 r
.35414 .79093 m .35321 .79186 L .35173 .79153 L F
.35414 .79093 m .35524 .7913 L .35321 .79186 L F
.436 .051 .21 r
.4268 .76855 m .43008 .76628 L .42791 .76625 L F
.614 .8 .971 r
.34365 .66266 m .34163 .66325 L .3403 .66225 L F
.436 .319 .622 r
.32038 .71023 m .32259 .708 L .32092 .70815 L F
.468 .679 .957 r
.71388 .73276 m .71557 .73148 L .71294 .73182 L F
.71388 .73276 m .71624 .73319 L .71557 .73148 L F
.412 .542 .877 r
.35353 .67466 m .35273 .67627 L .35086 .67435 L F
.485 .631 .918 r
.35353 .67466 m .35495 .67645 L .35273 .67627 L F
0 0 0 r
.66797 .62269 m .66968 .62208 L .67069 .6208 L F
.33 0 .094 r
.66797 .62269 m .66927 .62394 L .66968 .62208 L F
.66797 .62269 m .6671 .62444 L .66927 .62394 L F
.47 .844 .988 r
.55006 .84383 m .54662 .8438 L .548 .84653 L F
.55006 .84383 m .54892 .84335 L .54662 .8438 L F
.98 .809 .601 r
.5494 .84081 m .54892 .84335 L .55006 .84383 L F
.695 .818 .941 r
.41547 .72399 m .41349 .72493 L .41204 .72387 L F
.79 .728 .795 r
.68628 .73185 m .68697 .73476 L .68415 .73339 L F
0 .13 .668 r
.68724 .73726 m .68415 .73339 L .68697 .73476 L F
.452 0 .058 r
.37468 .75155 m .37336 .75268 L .37114 .75275 L F
.422 0 .116 r
.37677 .75119 m .37336 .75268 L .37468 .75155 L F
.559 .319 .507 r
.50594 .85726 m .50338 .85962 L .50327 .85709 L F
.50594 .85726 m .50563 .85951 L .50338 .85962 L F
.488 .259 .493 r
.50906 .85424 m .50802 .85688 L .50594 .85726 L F
.137 0 .159 r
.50802 .85688 m .50563 .85951 L .50594 .85726 L F
.81 .65 .684 r
.53244 .84074 m .52939 .84223 L .53027 .84054 L F
.53244 .84074 m .52943 .84345 L .52867 .84258 L F
.203 .343 .784 r
.53073 .83747 m .53362 .84011 L .53244 .84074 L F
.62 .5 .695 r
.53116 .83825 m .52982 .84227 L .53362 .84011 L F
.52982 .84227 m .52943 .84345 L .53082 .84235 L F
0 0 0 r
.53362 .84011 m .52943 .84345 L .53244 .84074 L F
.62 .5 .695 r
.52982 .84227 m .53082 .84235 L .53362 .84011 L F
.81 .65 .684 r
.52939 .84223 m .52867 .84258 L .52897 .8422 L F
.52939 .84223 m .52897 .8422 L .53027 .84054 L F
.486 .239 .464 r
.34607 .69513 m .34552 .69731 L .34347 .69762 L F
.373 .135 .419 r
.34724 .69657 m .34607 .69513 L .34764 .69451 L F
.34724 .69657 m .34552 .69731 L .34607 .69513 L F
.534 .496 .76 r
.46147 .74732 m .46069 .75152 L .45926 .74792 L F
.46147 .74732 m .46201 .75134 L .46069 .75152 L F
.311 0 .189 r
.41051 .7867 m .40971 .78502 L .41183 .78451 L F
.41051 .7867 m .40858 .78738 L .40971 .78502 L F
0 0 0 r
.379 .80022 m .37622 .80124 L .37708 .80061 L F
.11 .214 .692 r
.6743 .71302 m .67651 .71408 L .67512 .71632 L F
.676 .91 .579 r
.67512 .71632 m .67367 .7178 L .67473 .71863 L F
.67512 .71632 m .67651 .71408 L .67367 .7178 L F
.656 .319 .389 r
.63784 .64961 m .63696 .65183 L .63466 .65136 L F
.579 .239 .356 r
.63784 .64961 m .64011 .65074 L .63696 .65183 L F
.587 .383 .572 r
.43984 .75852 m .44206 .75833 L .44214 .75601 L F
.564 .346 .543 r
.44206 .75833 m .44437 .75574 L .44214 .75601 L F
0 .362 .781 r
.65601 .6054 m .65902 .60724 L .6582 .60654 L F
.439 .792 .997 r
.65902 .60724 m .66146 .60699 L .6582 .60654 L F
.783 .566 .606 r
.67824 .73429 m .67495 .7319 L .67609 .73522 L F
0 0 .072 r
.47774 .86099 m .47651 .86232 L .47792 .85942 L F
.318 .487 .869 r
.47246 .88031 m .47409 .88085 L .47189 .8793 L F
.298 .794 .844 r
.40048 .74275 m .39913 .74281 L .3972 .74327 L F
.299 .779 .919 r
.40251 .74277 m .39913 .74281 L .40048 .74275 L F
0 .045 .577 r
.58494 .83841 m .58621 .83951 L .58338 .83818 L F
.525 .607 .878 r
.58494 .83841 m .58926 .84075 L .58705 .84061 L F
0 .045 .577 r
.58494 .83841 m .58705 .84061 L .58621 .83951 L F
.062 0 0 r
.43023 .74143 m .42646 .74212 L .42785 .7412 L F
.3 .185 .551 r
.46886 .85147 m .47014 .85174 L .46955 .84898 L F
.244 .308 .731 r
.46886 .85147 m .47081 .8535 L .47014 .85174 L F
.75 .612 .705 r
.62747 .64921 m .62372 .64934 L .62392 .64704 L F
.708 .459 .546 r
.62747 .64921 m .62373 .6516 L .62372 .64934 L F
.62747 .64921 m .62567 .65159 L .62373 .6516 L F
.654 .388 .505 r
.62747 .64921 m .62926 .65142 L .62567 .65159 L F
0 0 .478 r
.64214 .61516 m .6413 .61737 L .64052 .61443 L F
.64214 .61516 m .64306 .61697 L .64313 .61647 L F
.64214 .61516 m .64313 .61647 L .6413 .61737 L F
.283 .693 .972 r
.48851 .88359 m .4901 .8844 L .48833 .88408 L F
.775 .675 .753 r
.57131 .81448 m .56847 .81428 L .57031 .81166 L F
.765 .542 .596 r
.57131 .81448 m .56816 .81669 L .56847 .81428 L F
.57131 .81448 m .57153 .8171 L .56816 .81669 L F
.213 .331 .768 r
.57031 .81166 m .5725 .81365 L .57131 .81448 L F
.57031 .81166 m .5725 .81365 L .57131 .81448 L F
.536 .335 .554 r
.3364 .74413 m .33844 .74188 L .33663 .74281 L F
.411 .043 .225 r
.41744 .76957 m .4167 .77093 L .41935 .76925 L F
.366 0 0 r
.40123 .72334 m .4033 .72367 L .40451 .72329 L F
0 0 0 r
.40451 .72329 m .40534 .7232 L .40676 .723 L F
.40451 .72329 m .4033 .72367 L .40534 .7232 L F
.622 .678 .883 r
.49249 .87272 m .48951 .87203 L .49338 .87133 L F
.26 0 0 r
.49027 .87258 m .49338 .87133 L .48951 .87203 L F
0 0 0 r
.49269 .87288 m .49249 .87272 L .49338 .87133 L F
0 0 .019 r
.49188 .87556 m .49249 .87272 L .49269 .87288 L F
.731 .341 .312 r
.49269 .87288 m .49338 .87133 L .49027 .87258 L F
.57 .018 0 r
.43007 .72608 m .43139 .72665 L .43318 .72665 L F
.544 0 0 r
.43379 .72743 m .43318 .72665 L .43139 .72665 L F
.43379 .72743 m .43499 .72816 L .43318 .72665 L F
.092 0 0 r
.39505 .7435 m .39363 .74412 L .39159 .7444 L F
0 0 0 r
.3972 .74327 m .39363 .74412 L .39505 .7435 L F
.504 .332 .582 r
.54713 .79365 m .55 .79581 L .549 .79141 L F
.771 .617 .688 r
.53934 .85959 m .54085 .85855 L .5421 .85761 L F
.913 .665 .55 r
.49743 .86745 m .49563 .8673 L .49565 .86479 L F
.718 .279 .207 r
.49743 .86745 m .49633 .86895 L .49563 .8673 L F
.49743 .86745 m .49922 .8694 L .49633 .86895 L F
0 .317 .805 r
.63721 .63341 m .63926 .63468 L .64023 .63655 L F
.63673 .6329 m .63888 .63396 L .63926 .63468 L F
.63673 .6329 m .63926 .63468 L .63721 .63341 L F
.909 .909 .809 r
.64023 .63655 m .63898 .63416 L .63688 .63805 L F
.705 .547 .671 r
.63878 .6342 m .63888 .63396 L .63788 .63377 L F
.909 .909 .809 r
.63898 .63416 m .63888 .63396 L .63878 .6342 L F
.476 .297 .558 r
.64096 .63448 m .63793 .63694 L .63888 .63396 L F
.705 .547 .671 r
.64041 .63498 m .63888 .63396 L .63878 .6342 L F
.909 .909 .809 r
.63878 .6342 m .63888 .63396 L .63877 .6342 L F
.63898 .63416 m .63877 .6342 L .63688 .63805 L F
.867 .842 .818 r
.63688 .63805 m .63877 .6342 L .63793 .63694 L F
.679 .195 .093 r
.63877 .6342 m .63878 .6342 L .63878 .6342 L F
.867 .842 .818 r
.63877 .6342 m .63888 .63396 L .63881 .6342 L F
.63877 .6342 m .63881 .6342 L .63793 .63694 L F
.679 .195 .093 r
.63711 .63576 m .64041 .63498 L .63878 .6342 L F
.63711 .63576 m .63878 .6342 L .63877 .6342 L F
.63763 .63442 m .63878 .6342 L .63788 .63377 L F
.63711 .63576 m .63878 .6342 L .63763 .63442 L F
.476 .297 .558 r
.64008 .63519 m .64126 .63648 L .63793 .63694 L F
.64096 .63448 m .64117 .63587 L .64008 .63519 L F
.64117 .63587 m .64126 .63648 L .64008 .63519 L F
.725 .431 .481 r
.64024 .6387 m .64023 .63655 L .63782 .63766 L F
0 0 0 r
.64126 .63648 m .64122 .63656 L .63793 .63694 L F
.805 .375 .224 r
.63782 .63766 m .63991 .63959 L .64024 .6387 L F
.787 .427 .375 r
.63922 .64014 m .63991 .63959 L .63782 .63766 L F
0 0 0 r
.64122 .63656 m .63922 .64014 L .63818 .63756 L F
.909 .909 .809 r
.64023 .63655 m .63735 .63784 L .63782 .63766 L F
0 0 0 r
.64122 .63656 m .63818 .63756 L .63793 .63694 L F
.909 .909 .809 r
.63735 .63784 m .63688 .63805 L .63749 .63779 L F
.63735 .63784 m .63749 .63779 L .63782 .63766 L F
.481 .899 .862 r
.37931 .78536 m .37522 .78667 L .37843 .78546 L F
.412 .862 .838 r
.37931 .78536 m .38023 .78472 L .38124 .78458 L F
.37931 .78536 m .37843 .78546 L .38023 .78472 L F
.567 .268 .42 r
.43242 .77454 m .43155 .777 L .42928 .77701 L F
.473 .133 .308 r
.43469 .77446 m .43155 .777 L .43242 .77454 L F
.586 .552 .783 r
.50338 .85962 m .50452 .85614 L .50327 .85709 L F
.758 .482 .515 r
.43643 .74273 m .43609 .74523 L .43327 .74426 L F
.633 .366 .497 r
.43789 .74391 m .43609 .74523 L .43643 .74273 L F
.628 .358 .49 r
.56924 .79364 m .56885 .79547 L .56668 .79553 L F
.721 .761 .884 r
.67896 .72242 m .67918 .72417 L .6815 .72357 L F
.227 .218 .64 r
.67896 .72242 m .67864 .72615 L .67918 .72417 L F
0 0 .259 r
.66391 .61552 m .66487 .61603 L .66507 .6139 L F
.66391 .61552 m .66324 .6182 L .66487 .61603 L F
.646 .488 .656 r
.33879 .77741 m .33789 .77982 L .33652 .77992 L F
.593 .376 .556 r
.33789 .77982 m .33639 .78225 L .33652 .77992 L F
.935 .943 .773 r
.64078 .6256 m .63795 .62772 L .6405 .62798 L F
.696 .704 .853 r
.63606 .62476 m .63924 .626 L .63538 .62761 L F
.63924 .626 m .63943 .62608 L .6391 .6262 L F
.63924 .626 m .6391 .6262 L .63538 .62761 L F
.922 .732 .628 r
.6381 .62205 m .6396 .62252 L .63945 .62572 L F
.63935 .62584 m .63945 .62572 L .63943 .62608 L F
.6381 .62205 m .63945 .62572 L .63935 .62584 L F
.6381 .62205 m .63943 .62608 L .63606 .62476 L F
.649 .863 .485 r
.63985 .6251 m .63888 .62624 L .63807 .62753 L F
.63848 .62699 m .63807 .62753 L .63795 .62772 L F
.63985 .6251 m .63807 .62753 L .63848 .62699 L F
.63995 .62497 m .63992 .62501 L .63985 .6251 L F
.63992 .62501 m .63888 .62624 L .63985 .6251 L F
.935 .943 .773 r
.64078 .6256 m .63995 .62497 L .63795 .62772 L F
0 0 0 r
.64309 .62339 m .64202 .6245 L .64078 .6256 L F
.519 .858 .995 r
.64202 .6245 m .63995 .62497 L .64078 .6256 L F
.583 .058 0 r
.69532 .71127 m .69797 .71281 L .69432 .71189 L F
0 0 .28 r
.32263 .67562 m .32342 .67517 L .3239 .67327 L F
.134 .184 .65 r
.32263 .67562 m .3241 .67807 L .32342 .67517 L F
.959 .86 .698 r
.70003 .70343 m .69832 .7044 L .69841 .70221 L F
.70003 .70343 m .69908 .70592 L .69832 .7044 L F
.815 .719 .759 r
.70073 .70056 m .70003 .70343 L .69841 .70221 L F
.8 .697 .751 r
.65023 .60503 m .64756 .60646 L .64861 .60724 L F
.952 .841 .697 r
.64811 .60933 m .64756 .60646 L .6468 .60783 L F
.6477 .60717 m .64811 .60687 L .64756 .60646 L F
.62 .648 .857 r
.64925 .60597 m .6468 .60783 L .64756 .60646 L F
.64925 .60597 m .6461 .60832 L .64644 .60809 L F
.504 0 0 r
.6468 .60783 m .64398 .60771 L .64525 .60814 L F
.6468 .60783 m .6461 .60832 L .64398 .60771 L F
.62 .648 .857 r
.64706 .60763 m .64644 .60809 L .6468 .60783 L F
.64925 .60597 m .64644 .60809 L .64706 .60763 L F
.952 .841 .697 r
.64811 .60933 m .64861 .60724 L .64811 .60687 L F
.64811 .60933 m .64811 .60687 L .6477 .60717 L F
.489 .131 .285 r
.45001 .76708 m .44996 .76838 L .44752 .76843 L F
.531 .165 .289 r
.45001 .76708 m .4518 .7683 L .44996 .76838 L F
.505 .185 .358 r
.45218 .76676 m .4518 .7683 L .45001 .76708 L F
.595 .817 .985 r
.32964 .67555 m .33317 .67595 L .3316 .67491 L F
.553 .796 .989 r
.3316 .67491 m .33317 .67595 L .33529 .6755 L F
.615 .506 .706 r
.33317 .67595 m .33571 .67857 L .33529 .6755 L F
.33317 .67595 m .33389 .67917 L .33571 .67857 L F
.17 .513 .914 r
.54503 .84317 m .54662 .8438 L .54538 .84263 L F
.45 .481 .799 r
.34473 .66596 m .34705 .66739 L .34551 .66763 L F
.549 .495 .747 r
.34705 .66739 m .34596 .6711 L .34551 .66763 L F
.308 0 0 r
.64513 .61028 m .6472 .61031 L .64811 .60933 L F
.168 0 0 r
.6472 .61031 m .64912 .61018 L .64811 .60933 L F
.597 .91 .65 r
.6671 .62444 m .66593 .62576 L .66457 .62668 L F
.469 .829 .995 r
.68988 .70197 m .69212 .70157 L .69096 .70256 L F
.68988 .70197 m .69212 .70157 L .69096 .70256 L F
.718 .874 .955 r
.71624 .73319 m .71992 .73228 L .71866 .73139 L F
.706 .555 .68 r
.33879 .77741 m .3389 .77996 L .33789 .77982 L F
.585 .417 .621 r
.34113 .77473 m .34089 .77698 L .33879 .77741 L F
.638 .522 .705 r
.34089 .77698 m .3389 .77996 L .33879 .77741 L F
.478 .217 .439 r
.34552 .69731 m .34299 .69956 L .34347 .69762 L F
.558 .789 .985 r
.3602 .67574 m .35816 .67617 L .35884 .67472 L F
.661 .904 .98 r
.35816 .67617 m .35684 .67565 L .35884 .67472 L F
.62 .502 .696 r
.36085 .67595 m .35816 .67617 L .3602 .67574 L F
.36085 .67595 m .35816 .67788 L .35816 .67617 L F
.039 .481 .883 r
.66857 .60886 m .66806 .60938 L .66694 .60837 L F
0 .093 .56 r
.66933 .61038 m .66806 .60938 L .66857 .60886 L F
.66933 .61038 m .67032 .6112 L .66806 .60938 L F
.26 0 0 r
.49027 .87258 m .48951 .87203 L .48835 .8719 L F
.885 .988 .733 r
.50906 .85424 m .50786 .85467 L .50858 .85338 L F
.393 .164 .443 r
.50977 .85632 m .50802 .85688 L .50906 .85424 L F
.719 .341 .332 r
.50644 .85607 m .50977 .85632 L .50906 .85424 L F
.042 0 0 r
.49874 .88975 m .50162 .88901 L .50054 .889 L F
.301 .723 .973 r
.50162 .88901 m .50255 .88838 L .50054 .889 L F
.50162 .88901 m .50389 .88905 L .50255 .88838 L F
.721 .761 .884 r
.67896 .72242 m .6815 .72357 L .6803 .72077 L F
.586 .735 .946 r
.6815 .72357 m .68165 .72085 L .6803 .72077 L F
.6815 .72357 m .68409 .72317 L .68165 .72085 L F
.833 .673 .685 r
.57265 .8066 m .57199 .80902 L .57097 .80594 L F
.943 .815 .689 r
.71924 .72571 m .72088 .72418 L .71969 .72347 L F
.71924 .72571 m .72013 .72627 L .72088 .72418 L F
.252 .136 .521 r
.66791 .7141 m .66901 .70989 L .66815 .71016 L F
.162 0 .072 r
.67146 .63888 m .67085 .64056 L .66891 .64156 L F
.077 0 .211 r
.67332 .6379 m .67146 .63888 L .6734 .63614 L F
.486 .261 .497 r
.67332 .6379 m .67085 .64056 L .67146 .63888 L F
.757 .551 .617 r
.65261 .60435 m .65299 .60156 L .65109 .60193 L F
.657 .301 .357 r
.65109 .60193 m .65299 .60156 L .64927 .60149 L F
.9 .67 .58 r
.59924 .83309 m .59715 .82954 L .59817 .83236 L F
.984 .752 .505 r
.59903 .83518 m .59924 .83309 L .59817 .83236 L F
.549 .495 .747 r
.34705 .66739 m .34791 .67074 L .34596 .6711 L F
.261 .769 .781 r
.49277 .89026 m .49557 .88966 L .4948 .89 L F
.414 .79 .993 r
.4948 .89 m .4959 .88921 L .49413 .89031 L F
.101 .656 .72 r
.4916 .89037 m .49277 .89026 L .4948 .89 L F
.4916 .89037 m .4948 .89 L .49375 .89054 L F
.414 .79 .993 r
.4948 .89 m .49413 .89031 L .49375 .89054 L F
.261 .769 .781 r
.49557 .88966 m .49623 .88951 L .4948 .89 L F
.181 0 0 r
.49623 .88951 m .49702 .88983 L .4948 .89 L F
.49623 .88951 m .49874 .88975 L .49702 .88983 L F
.5 .58 .867 r
.68409 .72317 m .68459 .72473 L .6864 .72328 L F
.838 .372 .077 r
.50189 .88601 m .50057 .88356 L .49925 .8831 L F
.325 0 0 r
.64549 .64969 m .64229 .65075 L .64329 .64955 L F
.596 .698 .914 r
.43789 .74391 m .43974 .74531 L .44188 .74493 L F
.7 .603 .745 r
.43965 .74751 m .44188 .74493 L .43974 .74531 L F
.748 .817 .906 r
.64253 .59832 m .64519 .59631 L .64579 .59822 L F
.732 .744 .861 r
.64685 .59528 m .64579 .59822 L .64519 .59631 L F
.64685 .59528 m .64819 .59633 L .64579 .59822 L F
.735 .393 .402 r
.49794 .86224 m .49992 .86445 L .50115 .86248 L F
.69 .338 .374 r
.49992 .86445 m .50259 .86435 L .50115 .86248 L F
.5 .278 .509 r
.3344 .74717 m .3364 .74413 L .33409 .74504 L F
0 0 0 r
.34607 .81253 m .3489 .81158 L .34822 .8121 L F
.179 .712 .737 r
.3489 .81158 m .3509 .81117 L .35 .81131 L F
0 0 0 r
.34822 .8121 m .3489 .81158 L .35 .81131 L F
.506 .375 .635 r
.53066 .8618 m .52871 .86223 L .52846 .85968 L F
.52846 .85968 m .52871 .86223 L .53066 .8618 L F
.53066 .8618 m .52871 .86223 L .52846 .85968 L F
.555 .413 .643 r
.36081 .68041 m .35816 .67788 L .36085 .67595 L F
.36081 .68041 m .35896 .68186 L .35816 .67788 L F
.896 .968 .651 r
.69785 .7063 m .69832 .7044 L .69908 .70592 L F
.69785 .7063 m .69665 .70749 L .69832 .7044 L F
.057 0 0 r
.68214 .71651 m .68008 .7172 L .67813 .7186 L F
.367 .1 .37 r
.33689 .70553 m .33601 .70767 L .33449 .70804 L F
.377 .147 .433 r
.33858 .70477 m .33689 .70553 L .33906 .7028 L F
.487 .26 .495 r
.33858 .70477 m .33601 .70767 L .33689 .70553 L F
.961 .821 .659 r
.64253 .59832 m .64285 .60175 L .64205 .60127 L F
.873 .443 .036 r
.64285 .60175 m .64275 .60291 L .64205 .60127 L F
.64285 .60175 m .64379 .60372 L .64275 .60291 L F
.651 .952 .947 r
.50389 .88905 m .5066 .88826 L .50558 .88792 L F
.58 .928 .951 r
.5066 .88826 m .5074 .88731 L .50558 .88792 L F
.5066 .88826 m .50961 .88718 L .5074 .88731 L F
.504 .201 .386 r
.33844 .74188 m .34026 .74229 L .34158 .73998 L F
.526 .226 .4 r
.34158 .73998 m .34325 .74145 L .34341 .73921 L F
.34158 .73998 m .34026 .74229 L .34325 .74145 L F
.413 .161 .42 r
.36231 .7585 m .3616 .76112 L .35976 .76121 L F
.53 .27 .465 r
.3641 .7602 m .36231 .7585 L .36445 .75816 L F
.3641 .7602 m .3616 .76112 L .36231 .7585 L F
.9 .986 .753 r
.54804 .83332 m .54604 .83493 L .54653 .83524 L F
.958 .844 .687 r
.54692 .83265 m .54604 .83493 L .54804 .83332 L F
.53 0 0 r
.53587 .8242 m .53759 .82514 L .53554 .82364 L F
.326 .119 .438 r
.53113 .83563 m .52946 .83875 L .53073 .83747 L F
.53 .35 .58 r
.53113 .83563 m .53378 .83547 L .53244 .83515 L F
.518 .292 .511 r
.53113 .83563 m .53073 .83747 L .53378 .83547 L F
.897 .82 .763 r
.67834 .59603 m .67529 .59796 L .67704 .595 L F
.67834 .59603 m .67657 .59892 L .67529 .59796 L F
.787 .839 .891 r
.6807 .59385 m .67834 .59603 L .67704 .595 L F
.025 0 0 r
.38439 .79791 m .38708 .79592 L .3858 .79789 L F
.254 0 .071 r
.3858 .79789 m .38708 .79592 L .38896 .7953 L F
.28 0 0 r
.56994 .78504 m .57199 .78501 L .57342 .78454 L F
.689 .242 .186 r
.57199 .78501 m .57515 .78535 L .57342 .78454 L F
.598 .532 .752 r
.46955 .84898 m .4725 .84935 L .4721 .84547 L F
.467 .187 .405 r
.47014 .85174 m .4725 .84935 L .46955 .84898 L F
.527 .376 .619 r
.48536 .86473 m .48566 .86749 L .48314 .86797 L F
.112 0 0 r
.52005 .87211 m .51867 .87287 L .51881 .8697 L F
.724 .341 .325 r
.51638 .86466 m .51754 .86693 L .51595 .86773 L F
.96 .648 .389 r
.67828 .61472 m .67734 .61431 L .67685 .61194 L F
.843 .443 .288 r
.67828 .61472 m .6775 .61601 L .67734 .61431 L F
.67828 .61472 m .67976 .61687 L .6775 .61601 L F
.67976 .61687 m .67962 .61697 L .6775 .61601 L F
.67976 .61687 m .67991 .6171 L .67962 .61697 L F
.8 .499 0 r
.67964 .61698 m .67964 .61645 L .6775 .61601 L F
.67991 .6171 m .67964 .61645 L .67964 .61698 L F
.895 .975 .677 r
.67964 .61645 m .67965 .61477 L .6775 .61601 L F
.67964 .61645 m .67803 .61763 L .67961 .61484 L F
.67964 .61645 m .67961 .61484 L .67965 .61477 L F
.78 .885 .467 r
.67898 .61743 m .67803 .61763 L .67964 .61645 L F
.6766 .62099 m .67773 .61833 L .67898 .61743 L F
.67773 .61833 m .67803 .61763 L .67898 .61743 L F
.443 .18 .418 r
.40447 .77477 m .40599 .77616 L .40728 .77374 L F
.362 .007 .221 r
.40728 .77374 m .408 .77564 L .40937 .77395 L F
.40728 .77374 m .40599 .77616 L .408 .77564 L F
.688 .308 .323 r
.56116 .78482 m .56336 .78673 L .565 .78442 L F
.57 .18 .264 r
.56336 .78673 m .56649 .78509 L .565 .78442 L F
.8 .697 .751 r
.65023 .60503 m .64718 .60361 L .64756 .60646 L F
.65023 .60503 m .64983 .60363 L .64718 .60361 L F
.606 .506 .714 r
.65023 .60503 m .65109 .60193 L .64983 .60363 L F
.65023 .60503 m .65261 .60435 L .65109 .60193 L F
.588 .523 .749 r
.4567 .7375 m .45504 .73949 L .45461 .73776 L F
.595 .533 .755 r
.4574 .73906 m .45504 .73949 L .4567 .7375 L F
.562 .478 .717 r
.45778 .74224 m .45504 .73949 L .4574 .73906 L F
.45778 .74224 m .45573 .74268 L .45504 .73949 L F
0 0 0 r
.36419 .80563 m .36493 .80546 L .36317 .80622 L F
.36419 .80563 m .36622 .80511 L .36493 .80546 L F
.327 .083 .383 r
.34063 .70213 m .33906 .7028 L .3412 .70018 L F
.402 .169 .443 r
.34042 .70395 m .33906 .7028 L .34063 .70213 L F
.34042 .70395 m .33858 .70477 L .33906 .7028 L F
.715 .83 .936 r
.7004 .70744 m .70409 .7069 L .70199 .707 L F
.369 0 0 r
.70409 .7069 m .70564 .70742 L .70199 .707 L F
.417 .201 .476 r
.70534 .70549 m .70564 .70742 L .70409 .7069 L F
.489 .333 .596 r
.35896 .68186 m .35871 .68309 L .35675 .68347 L F
.493 .238 .456 r
.35871 .68309 m .35618 .68615 L .35675 .68347 L F
.605 .365 .527 r
.46739 .75873 m .46714 .76114 L .46495 .76099 L F
.62 .405 .568 r
.4716 .7577 m .46714 .76114 L .46739 .75873 L F
.81 .58 .591 r
.49201 .88319 m .48851 .88359 L .48859 .88065 L F
.801 .843 .882 r
.49201 .88319 m .4901 .8844 L .48851 .88359 L F
.431 .083 .273 r
.43688 .7609 m .43883 .76065 L .43984 .75852 L F
.573 .227 .345 r
.43984 .75852 m .44164 .76009 L .44206 .75833 L F
.43984 .75852 m .43883 .76065 L .44164 .76009 L F
.315 .099 .418 r
.32563 .72089 m .32388 .72305 L .32486 .72134 L F
.603 .519 .732 r
.45926 .74792 m .45702 .74831 L .4562 .745 L F
.922 .581 .374 r
.5619 .79776 m .56132 .79817 L .56017 .79581 L F
.241 .674 .959 r
.64927 .60149 m .64814 .60076 L .64718 .60361 L F
.64927 .60149 m .64817 .60066 L .64814 .60076 L F
.799 .589 .618 r
.64718 .60361 m .64983 .60363 L .64927 .60149 L F
.478 .092 .23 r
.65123 .5986 m .64817 .60066 L .64927 .60149 L F
.657 .301 .357 r
.65109 .60193 m .64927 .60149 L .64983 .60363 L F
.378 0 .157 r
.36633 .73144 m .36838 .73107 L .36967 .72909 L F
.352 0 .093 r
.36838 .73107 m .37178 .7289 L .36967 .72909 L F
.83 .648 .656 r
.57931 .8165 m .58238 .81449 L .58061 .81347 L F
.57931 .8165 m .58231 .81713 L .58238 .81449 L F
0 0 .495 r
.67797 .62199 m .67824 .62483 L .67764 .62554 L F
0 0 .249 r
.67832 .62654 m .67764 .62554 L .67824 .62483 L F
.67832 .62654 m .67751 .6278 L .67764 .62554 L F
.45 .462 .78 r
.68956 .6005 m .68765 .6027 L .6869 .59915 L F
.504 .503 .789 r
.68956 .6005 m .6886 .60403 L .68765 .6027 L F
.961 .638 .355 r
.67383 .72011 m .67473 .71863 L .67367 .7178 L F
.67383 .72011 m .67509 .72131 L .67473 .71863 L F
.452 .286 .564 r
.33601 .70767 m .3344 .71032 L .33449 .70804 L F
.713 .908 .964 r
.36083 .79008 m .35747 .79066 L .35938 .78975 L F
.587 .904 .983 r
.36083 .79008 m .3615 .78896 L .3628 .78992 L F
.36083 .79008 m .35938 .78975 L .3615 .78896 L F
.489 .253 .483 r
.43476 .76137 m .43657 .76308 L .43688 .7609 L F
.43476 .76137 m .43453 .76352 L .43657 .76308 L F
.962 .662 .416 r
.67649 .61028 m .67685 .61194 L .67545 .60908 L F
.505 .164 .322 r
.35976 .76121 m .35904 .76319 L .35696 .76327 L F
.475 .173 .373 r
.3616 .76112 m .35904 .76319 L .35976 .76121 L F
.413 .168 .43 r
.34299 .69956 m .34063 .70213 L .3412 .70018 L F
.219 0 .172 r
.50798 .88292 m .50602 .88394 L .5039 .88776 L F
.387 .344 .688 r
.33389 .67917 m .33569 .6808 L .33571 .67857 L F
.33389 .67917 m .33422 .6814 L .33569 .6808 L F
.564 .006 0 r
.58926 .84075 m .59054 .84139 L .58705 .84061 L F
.575 .493 .724 r
.45778 .74224 m .4562 .745 L .45573 .74268 L F
.038 .606 .759 r
.46584 .75336 m .46777 .75338 L .46896 .75345 L F
0 .274 .752 r
.47032 .75399 m .46896 .75345 L .46777 .75338 L F
.47032 .75399 m .47139 .75511 L .46896 .75345 L F
.418 .863 .895 r
.59258 .8407 m .59547 .84026 L .59431 .83988 L F
.737 .793 .897 r
.59547 .84026 m .59649 .83727 L .59431 .83988 L F
.59547 .84026 m .59806 .83819 L .59649 .83727 L F
.547 .295 .486 r
.47964 .8386 m .47921 .84075 L .47695 .84091 L F
.37 .138 .426 r
.48135 .83802 m .47921 .84075 L .47964 .8386 L F
0 0 0 r
.35564 .80872 m .3591 .80743 L .35732 .80816 L F
.3591 .80743 m .35899 .8076 L .35732 .80816 L F
.3591 .80743 m .36115 .80693 L .35899 .8076 L F
.762 .817 .896 r
.69024 .72866 m .69342 .72901 L .69227 .72593 L F
.69024 .72866 m .69049 .72974 L .69342 .72901 L F
.741 .681 .793 r
.69227 .72593 m .69342 .72901 L .69557 .72622 L F
.787 .879 .913 r
.57091 .82303 m .5675 .82428 L .56936 .82198 L F
.241 .326 .751 r
.67471 .63486 m .6734 .63614 L .67233 .63283 L F
0 0 .192 r
.67436 .63696 m .6734 .63614 L .67471 .63486 L F
.67436 .63696 m .67332 .6379 L .6734 .63614 L F
.152 0 0 r
.38178 .75108 m .3784 .7507 L .37984 .75095 L F
.537 .06 .071 r
.64664 .63048 m .64409 .6282 L .64442 .63048 L F
.648 .428 .571 r
.36938 .7557 m .36664 .75798 L .36713 .75614 L F
.5 .278 .509 r
.3344 .74717 m .33622 .74688 L .3364 .74413 L F
.536 .335 .554 r
.3364 .74413 m .3389 .74432 L .33844 .74188 L F
.573 .363 .557 r
.33622 .74688 m .3389 .74432 L .3364 .74413 L F
.575 .493 .724 r
.45778 .74224 m .45821 .74457 L .4562 .745 L F
.603 .519 .732 r
.45926 .74792 m .4562 .745 L .45821 .74457 L F
.435 .509 .836 r
.35231 .67187 m .35086 .67435 L .35068 .67226 L F
.35231 .67187 m .35353 .67466 L .35086 .67435 L F
.415 .864 .857 r
.34365 .81335 m .34231 .81366 L .34224 .81369 L F
.34365 .81335 m .34347 .81294 L .34231 .81366 L F
.34365 .81335 m .34607 .81253 L .34347 .81294 L F
.721 .662 .791 r
.69006 .71324 m .69107 .71624 L .68776 .71551 L F
.618 .517 .717 r
.69264 .71201 m .69107 .71624 L .69006 .71324 L F
.69264 .71201 m .69337 .71551 L .69107 .71624 L F
.304 .262 .645 r
.47797 .84863 m .47864 .85114 L .47712 .85129 L F
.114 .034 .478 r
.47818 .85329 m .47712 .85129 L .47864 .85114 L F
.47818 .85329 m .47666 .8548 L .47712 .85129 L F
.425 .286 .587 r
.33406 .68369 m .33569 .6808 L .33422 .6814 L F
.787 .69 .758 r
.53766 .80295 m .5388 .80542 L .53874 .80258 L F
.942 .749 .613 r
.67991 .6171 m .6811 .6201 L .68032 .61847 L F
.811 .59 .603 r
.6811 .6201 m .67797 .62199 L .68032 .61847 L F
.6811 .6201 m .68111 .62253 L .67797 .62199 L F
.603 .641 .861 r
.68246 .61714 m .6811 .6201 L .67991 .6171 L F
.68246 .61714 m .6836 .61961 L .6811 .6201 L F
.746 .658 .764 r
.6836 .61961 m .68111 .62253 L .6811 .6201 L F
.683 .702 .861 r
.69685 .71667 m .69337 .71551 L .69569 .71568 L F
.652 .862 .979 r
.69886 .71572 m .69685 .71667 L .69569 .71568 L F
.428 0 .092 r
.38439 .79791 m .38404 .79872 L .38087 .79967 L F
.116 0 0 r
.3858 .79789 m .38404 .79872 L .38439 .79791 L F
.126 .658 .865 r
.40592 .74316 m .40452 .74283 L .40251 .74277 L F
.281 0 0 r
.408 .74267 m .40452 .74283 L .40592 .74316 L F
.883 .564 .441 r
.49333 .85965 m .49465 .86281 L .49579 .86228 L F
.65 .272 .314 r
.49465 .86281 m .49794 .86224 L .49579 .86228 L F
.681 .503 .639 r
.34306 .7743 m .34089 .77698 L .34113 .77473 L F
.443 .18 .418 r
.40447 .77477 m .40403 .7767 L .40599 .77616 L F
.47 0 0 r
.38557 .75067 m .38387 .75158 L .38178 .75108 L F
0 0 .129 r
.38756 .74798 m .38664 .75002 L .38557 .75067 L F
.456 .081 .238 r
.38664 .75002 m .38387 .75158 L .38557 .75067 L F
.834 .509 .437 r
.50299 .86726 m .50509 .8675 L .50391 .86532 L F
.892 .729 .673 r
.67599 .60425 m .67453 .60387 L .67516 .60167 L F
.593 .376 .556 r
.33789 .77982 m .33864 .78201 L .33639 .78225 L F
.705 .436 .515 r
.3389 .77996 m .33864 .78201 L .33789 .77982 L F
.4 .401 .745 r
.54104 .84101 m .54267 .84018 L .54098 .84168 L F
.351 .238 .582 r
.32869 .69474 m .33016 .69638 L .33029 .69392 L F
.32869 .69474 m .32881 .69704 L .33016 .69638 L F
.406 .091 .315 r
.42465 .74277 m .4219 .74471 L .42248 .74335 L F
.549 .368 .588 r
.65848 .63083 m .66084 .63032 L .66055 .62807 L F
.54 .343 .561 r
.66089 .63282 m .65848 .63083 L .65842 .6325 L F
.66089 .63282 m .66084 .63032 L .65848 .63083 L F
.177 0 0 r
.37734 .72662 m .37786 .72759 L .37946 .72651 L F
.37734 .72662 m .37587 .72817 L .37786 .72759 L F
.227 .218 .64 r
.67896 .72242 m .68054 .72557 L .67864 .72615 L F
0 0 0 r
.67864 .72615 m .68054 .72557 L .6785 .72642 L F
.67864 .72615 m .67635 .72835 L .6769 .72911 L F
.67864 .72615 m .6785 .72642 L .67635 .72835 L F
.568 .399 .613 r
.3389 .74432 m .34026 .74229 L .33844 .74188 L F
.542 .51 .77 r
.34629 .66542 m .34473 .66596 L .34365 .66266 L F
.53 .469 .732 r
.34629 .66542 m .34705 .66739 L .34473 .66596 L F
.638 .522 .705 r
.34089 .77698 m .34136 .77984 L .3389 .77996 L F
.655 .391 .508 r
.3408 .78137 m .3389 .77996 L .34136 .77984 L F
.3408 .78137 m .33864 .78201 L .3389 .77996 L F
.443 .406 .722 r
.45585 .73554 m .45461 .73776 L .45396 .73436 L F
.588 .523 .749 r
.4567 .7375 m .45461 .73776 L .45585 .73554 L F
.691 .342 .379 r
.50222 .8543 m .50452 .85614 L .505 .8558 L F
.586 .552 .783 r
.50338 .85962 m .50563 .85951 L .50452 .85614 L F
.844 .566 .517 r
.71529 .71772 m .71741 .71593 L .71591 .7155 L F
.71529 .71772 m .71785 .71808 L .71741 .71593 L F
.533 .552 .821 r
.35125 .7364 m .3492 .73732 L .34786 .73422 L F
.055 .409 .86 r
.71168 .73132 m .71223 .73065 L .7095 .72918 L F
.71168 .73132 m .71294 .73182 L .71223 .73065 L F
.489 .471 .763 r
.56463 .80937 m .56639 .80926 L .56451 .80977 L F
.499 .516 .805 r
.56639 .80926 m .56708 .81184 L .56451 .80977 L F
.222 .379 .81 r
.68926 .60768 m .69128 .60896 L .69021 .60911 L F
.494 .34 .601 r
.69226 .61103 m .69021 .60911 L .69128 .60896 L F
.69226 .61103 m .69014 .61176 L .69021 .60911 L F
.955 .625 .353 r
.68383 .71002 m .68264 .70989 L .68373 .70937 L F
.704 .488 0 r
.6835 .70779 m .68388 .71029 L .68383 .71002 L F
.836 .819 .832 r
.68649 .70928 m .68383 .71002 L .68408 .70934 L F
.736 .769 .879 r
.68422 .70717 m .68275 .70856 L .68109 .70641 L F
.68507 .70738 m .6841 .70787 L .68422 .70717 L F
.23 .063 .436 r
.68507 .70738 m .68415 .7092 L .6835 .70779 L F
.253 0 .123 r
.68395 .70877 m .6835 .70779 L .68379 .70973 L F
.721 .709 .838 r
.68686 .70611 m .68532 .70789 L .68507 .70738 L F
.68532 .70789 m .68416 .70925 L .68475 .70803 L F
.68532 .70789 m .68475 .70803 L .68507 .70738 L F
.253 0 .123 r
.68467 .70892 m .68424 .70851 L .68427 .70945 L F
.68424 .70851 m .68394 .70822 L .68418 .70911 L F
.68424 .70851 m .68418 .70911 L .68427 .70945 L F
.721 .709 .838 r
.68532 .70789 m .68415 .70931 L .68416 .70925 L F
.68686 .70611 m .68538 .70787 L .68532 .70789 L F
.68538 .70787 m .68415 .70931 L .68532 .70789 L F
.253 0 .123 r
.68394 .70822 m .6835 .70779 L .68415 .7092 L F
.68424 .70851 m .68325 .70839 L .68394 .70822 L F
.68467 .70892 m .68398 .70866 L .68424 .70851 L F
.23 .063 .436 r
.68415 .7092 m .68408 .70934 L .6835 .70779 L F
.253 0 .123 r
.68398 .70866 m .68325 .70839 L .68424 .70851 L F
.68467 .70892 m .68264 .70989 L .68289 .70928 L F
.68398 .70866 m .68289 .70928 L .68325 .70839 L F
.68394 .70822 m .68415 .7092 L .68427 .70945 L F
.68467 .70892 m .68289 .70928 L .68398 .70866 L F
.721 .709 .838 r
.68538 .70787 m .68815 .70779 L .68415 .70931 L F
.68686 .70611 m .68735 .70674 L .68538 .70787 L F
.68735 .70674 m .68815 .70779 L .68538 .70787 L F
.253 0 .123 r
.68427 .70945 m .68395 .70877 L .68383 .71002 L F
.721 .709 .838 r
.68416 .70925 m .68415 .70931 L .68408 .70934 L F
.253 0 .123 r
.68394 .70822 m .68325 .70839 L .6835 .70779 L F
.721 .709 .838 r
.68416 .70925 m .68408 .70934 L .68415 .7092 L F
.68416 .70925 m .68415 .7092 L .68507 .70738 L F
.954 .646 .413 r
.6835 .70779 m .68264 .70989 L .68275 .70856 L F
0 0 0 r
.6835 .70779 m .68275 .70856 L .68507 .70738 L F
.736 .769 .879 r
.6841 .70787 m .68275 .70856 L .68422 .70717 L F
.253 0 .123 r
.68395 .70877 m .68379 .70973 L .68383 .71002 L F
.955 .625 .353 r
.68383 .71002 m .68373 .70937 L .68467 .70892 L F
.704 .488 0 r
.68388 .71029 m .6841 .71178 L .68383 .71002 L F
.73 .505 .586 r
.589 .82491 m .59224 .82237 L .58894 .82212 L F
.589 .82491 m .59227 .82474 L .59224 .82237 L F
.715 .98 .777 r
.329 .67475 m .32771 .67652 L .32964 .67555 L F
0 0 0 r
.3912 .90272 m .3901 .90379 L .39264 .90185 L F
.3912 .90272 m .3901 .90379 L .39264 .90185 L F
.466 .237 .482 r
.35227 .76603 m .35227 .76835 L .34998 .76862 L F
.447 .208 .457 r
.35489 .76339 m .35415 .76589 L .35227 .76603 L F
.581 .389 .586 r
.35415 .76589 m .35227 .76835 L .35227 .76603 L F
.854 .511 .403 r
.56982 .79804 m .56668 .79553 L .56885 .79547 L F
.56982 .79804 m .56759 .79791 L .56668 .79553 L F
.86 .715 .7 r
.56982 .79804 m .56679 .80021 L .56759 .79791 L F
.56982 .79804 m .56832 .80124 L .56679 .80021 L F
.723 .663 .789 r
.57235 .79562 m .56982 .79804 L .56885 .79547 L F
.539 .603 .866 r
.56919 .83536 m .57084 .83837 L .57276 .83793 L F
.171 .31 .764 r
.57084 .83837 m .57251 .83979 L .57276 .83793 L F
0 0 .406 r
.68449 .62486 m .68484 .62542 L .68455 .62269 L F
.68449 .62486 m .68484 .62542 L .68455 .62269 L F
.666 .619 .792 r
.69212 .71032 m .69074 .71213 L .68884 .70838 L F
.315 .099 .418 r
.32563 .72089 m .32373 .72377 L .32388 .72305 L F
0 .223 .665 r
.6766 .62099 m .67542 .62039 L .67454 .61943 L F
.6766 .62099 m .67797 .62199 L .67542 .62039 L F
.524 .767 .985 r
.41144 .7433 m .41207 .74182 L .41001 .74203 L F
.41144 .7433 m .41358 .74293 L .41207 .74182 L F
.708 .542 .661 r
.34356 .77646 m .34089 .77698 L .34306 .7743 L F
.596 .418 .611 r
.34594 .7746 m .34356 .77646 L .34306 .7743 L F
.709 .714 .853 r
.69557 .72622 m .69885 .72665 L .69802 .72441 L F
.714 .717 .851 r
.69802 .72441 m .69885 .72665 L .70188 .72593 L F
.527 .744 .974 r
.3235 .65405 m .32304 .65566 L .3215 .65441 L F
.3235 .65405 m .32503 .65535 L .32304 .65566 L F
.417 .275 .579 r
.66055 .62807 m .66254 .62958 L .66324 .62794 L F
.66055 .62807 m .66084 .63032 L .66254 .62958 L F
.748 .653 .755 r
.68944 .74785 m .6929 .74836 L .6917 .74515 L F
.874 .776 .75 r
.70734 .70479 m .70564 .70742 L .70534 .70549 L F
0 .405 .821 r
.41684 .74227 m .4174 .74207 L .41547 .7419 L F
.41684 .74227 m .41849 .74301 L .4174 .74207 L F
.439 .113 .316 r
.55605 .78743 m .55812 .78702 L .55934 .78424 L F
.486 .128 .283 r
.55812 .78702 m .56116 .78482 L .55934 .78424 L F
0 .112 .663 r
.67229 .61373 m .67061 .61279 L .67032 .6112 L F
.67229 .61373 m .67218 .61477 L .67061 .61279 L F
.527 .907 .949 r
.68884 .70838 m .68649 .70928 L .68408 .70934 L F
.85 .846 .383 r
.5451 .81152 m .54604 .80939 L .54432 .80846 L F
.5451 .81152 m .54532 .81163 L .54604 .80939 L F
.911 .722 .634 r
.69032 .7442 m .69226 .74287 L .69111 .74201 L F
.69032 .7442 m .6917 .74515 L .69226 .74287 L F
.592 .078 0 r
.48067 .88617 m .48408 .88653 L .48175 .88684 L F
.313 0 0 r
.48408 .88653 m .48514 .88706 L .48175 .88684 L F
.48408 .88653 m .48662 .88768 L .48514 .88706 L F
0 .428 .839 r
.47705 .88153 m .47906 .88197 L .47609 .88117 L F
.47705 .88153 m .48006 .88287 L .47906 .88197 L F
.308 0 .094 r
.40209 .7898 m .40461 .78818 L .40381 .7896 L F
.424 .073 .262 r
.40461 .78818 m .40665 .78791 L .40381 .7896 L F
0 0 0 r
.6857 .61559 m .68472 .61627 L .68246 .61714 L F
.68661 .61512 m .6857 .61559 L .68758 .61475 L F
.68661 .61512 m .68472 .61627 L .6857 .61559 L F
.553 .919 .947 r
.5074 .88731 m .50961 .88718 L .51163 .8863 L F
0 0 0 r
.37265 .80293 m .37127 .80306 L .37439 .80196 L F
.37265 .80293 m .37081 .8037 L .37127 .80306 L F
.493 .861 .63 r
.64617 .61428 m .64313 .61647 L .64306 .61697 L F
.556 .305 .491 r
.64234 .63183 m .64427 .63328 L .64442 .63048 L F
.268 0 0 r
.64538 .63143 m .64707 .63157 L .64631 .63136 L F
.64707 .63157 m .64887 .63171 L .64631 .63136 L F
.771 .993 .879 r
.6444 .63086 m .64631 .63136 L .64442 .63048 L F
.64427 .63328 m .64631 .63136 L .6444 .63086 L F
.419 .014 .162 r
.64442 .63048 m .64631 .63136 L .64664 .63048 L F
.535 .283 .479 r
.42715 .77718 m .4268 .77921 L .42469 .77936 L F
.521 .27 .475 r
.42715 .77718 m .42892 .77888 L .4268 .77921 L F
.548 .267 .442 r
.42928 .77701 m .42892 .77888 L .42715 .77718 L F
.171 0 0 r
.39655 .7926 m .393 .79413 L .39456 .79303 L F
.089 .628 .854 r
.38893 .78197 m .39072 .78207 L .39226 .78246 L F
.388 0 0 r
.39072 .78207 m .39421 .78188 L .39226 .78246 L F
.943 .781 .651 r
.57891 .80912 m .57829 .81123 L .57963 .81146 L F
.84 .632 .621 r
.57829 .81123 m .58061 .81347 L .57963 .81146 L F
.245 0 0 r
.65064 .64846 m .64804 .64964 L .64851 .64895 L F
.546 .323 .527 r
.34998 .76862 m .34998 .77147 L .34775 .77091 L F
.472 .264 .516 r
.35173 .77015 m .34998 .76862 L .35227 .76835 L F
.35173 .77015 m .34998 .77147 L .34998 .76862 L F
.808 .757 .806 r
.50678 .87098 m .50901 .8729 L .50628 .87242 L F
.77 .343 .237 r
.50628 .87242 m .50901 .8729 L .50963 .87398 L F
.26 .583 .945 r
.50985 .87214 m .50901 .8729 L .50678 .87098 L F
.622 .456 .637 r
.50991 .87311 m .50901 .8729 L .50985 .87214 L F
.50991 .87311 m .50963 .87398 L .50901 .8729 L F
.596 .366 .537 r
.32998 .75297 m .33238 .7524 L .33248 .75043 L F
.531 .387 .631 r
.33248 .75043 m .33451 .75019 L .3344 .74717 L F
.574 .385 .587 r
.33238 .7524 m .33451 .75019 L .33248 .75043 L F
.314 0 0 r
.38157 .72629 m .38373 .72602 L .38502 .72473 L F
.202 0 0 r
.38502 .72473 m .38569 .72557 L .3866 .72492 L F
.38502 .72473 m .38373 .72602 L .38569 .72557 L F
.429 .366 .685 r
.69099 .60593 m .68926 .60768 L .68886 .60595 L F
.69099 .60593 m .69128 .60896 L .68926 .60768 L F
.736 .75 .863 r
.67387 .72882 m .6769 .72911 L .67635 .72835 L F
.775 .659 .735 r
.67495 .7319 m .6769 .72911 L .67387 .72882 L F
0 0 0 r
.35682 .73471 m .35728 .73557 L .358 .73525 L F
.35682 .73471 m .35562 .73642 L .35728 .73557 L F
.285 0 0 r
.35682 .73471 m .358 .73525 L .35895 .73447 L F
.651 .444 .591 r
.69056 .61386 m .68754 .61215 L .69014 .61176 L F
.69056 .61386 m .68758 .61475 L .68754 .61215 L F
.606 .217 .279 r
.549 .79141 m .55151 .79243 L .54941 .79142 L F
.761 .715 .81 r
.51808 .87851 m .52092 .87815 L .51905 .87813 L F
.837 .647 .646 r
.51774 .88033 m .52092 .87815 L .51808 .87851 L F
.51774 .88033 m .52079 .87943 L .52092 .87815 L F
.316 0 .069 r
.65866 .64441 m .65784 .64603 L .65554 .64655 L F
.03 0 0 r
.66085 .64393 m .65784 .64603 L .65866 .64441 L F
.611 .933 .961 r
.3872 .78317 m .38324 .78409 L .3859 .7825 L F
.3872 .78317 m .3841 .78419 L .38324 .78409 L F
.739 .911 .952 r
.38893 .78197 m .3872 .78317 L .3859 .7825 L F
.574 .345 .531 r
.35696 .76327 m .35415 .76589 L .35489 .76339 L F
.815 .719 .759 r
.70073 .70056 m .69841 .70221 L .70084 .69933 L F
.348 .625 .956 r
.70299 .70019 m .70073 .70056 L .70084 .69933 L F
.70299 .70019 m .70439 .70175 L .70073 .70056 L F
.499 .433 .713 r
.46944 .85709 m .47127 .85735 L .47081 .8535 L F
.486 .469 .764 r
.46944 .85709 m .47219 .85916 L .47127 .85735 L F
.566 .465 .699 r
.46944 .85709 m .47003 .85957 L .47219 .85916 L F
.87 .812 .329 r
.57957 .79732 m .57955 .79902 L .58016 .7956 L F
.94 .965 .714 r
.57802 .80019 m .57955 .79902 L .57957 .79732 L F
.57802 .80019 m .57805 .80108 L .57955 .79902 L F
.612 .518 .723 r
.3323 .68664 m .33461 .68654 L .33406 .68369 L F
.615 .416 .59 r
.3323 .68664 m .33454 .68781 L .33461 .68654 L F
.3323 .68664 m .33217 .68868 L .33454 .68781 L F
.238 .704 .946 r
.40866 .7233 m .41204 .72387 L .40996 .72413 L F
0 0 0 r
.35564 .80872 m .35732 .80816 L .3558 .80911 L F
.497 .134 .28 r
.53478 .85215 m .53721 .85172 L .53656 .85369 L F
.382 .831 .935 r
.53478 .85215 m .53721 .85172 L .53656 .85369 L F
.62 .401 .563 r
.66324 .6182 m .66348 .61993 L .66144 .61997 L F
.639 .34 .448 r
.66685 .61944 m .66373 .62176 L .66348 .61993 L F
0 0 .45 r
.66373 .61841 m .66365 .6203 L .66465 .6193 L F
.66373 .61841 m .66465 .6193 L .66395 .61867 L F
0 0 .261 r
.66324 .6182 m .66373 .61841 L .66339 .61801 L F
0 0 .45 r
.66373 .61841 m .66395 .61867 L .66203 .61698 L F
0 0 .261 r
.66339 .61801 m .66373 .61841 L .66487 .61603 L F
.66324 .6182 m .66348 .61993 L .66373 .61841 L F
.773 .542 .585 r
.32134 .67249 m .3208 .67544 L .31739 .67504 L F
0 0 0 r
.32298 .67258 m .3208 .67544 L .32134 .67249 L F
.591 .146 .162 r
.41935 .76925 m .42111 .77063 L .42258 .76911 L F
.413 0 0 r
.42111 .77063 m .42477 .76919 L .42258 .76911 L F
.125 0 .032 r
.52946 .83875 m .53116 .83825 L .53073 .83747 L F
.52946 .83875 m .52876 .84001 L .53116 .83825 L F
.497 .256 .478 r
.46561 .86455 m .46763 .8643 L .46777 .86258 L F
.606 .422 .607 r
.46763 .8643 m .46991 .86194 L .46777 .86258 L F
.802 .918 .916 r
.51279 .88498 m .51663 .88335 L .51562 .88304 L F
.333 0 .122 r
.41805 .78349 m .41709 .7822 L .41909 .78171 L F
.41805 .78349 m .41592 .78402 L .41709 .7822 L F
.192 .296 .742 r
.56523 .81242 m .5661 .81061 L .56388 .81154 L F
.528 .266 .463 r
.56708 .81184 m .56709 .81384 L .56523 .81242 L F
.192 .296 .742 r
.56523 .81242 m .56709 .81384 L .5661 .81061 L F
.579 .384 .582 r
.55806 .79307 m .55651 .79702 L .5548 .79281 L F
.55806 .79307 m .55849 .79617 L .55651 .79702 L F
.747 .735 .841 r
.55922 .79839 m .55594 .79831 L .55849 .79617 L F
.574 .471 .7 r
.56017 .79581 m .55922 .79839 L .55849 .79617 L F
.56017 .79581 m .56132 .79817 L .55922 .79839 L F
.753 .503 .553 r
.56023 .79741 m .55805 .79877 L .55844 .79857 L F
.572 .069 .021 r
.55844 .79857 m .55696 .79944 L .55422 .79822 L F
.753 .503 .553 r
.55805 .79877 m .55696 .79944 L .55844 .79857 L F
.223 0 0 r
.55879 .79838 m .55844 .79857 L .55594 .79831 L F
.55922 .79839 m .55844 .79857 L .55879 .79838 L F
.519 .343 .582 r
.55925 .79527 m .55849 .79617 L .55806 .79307 L F
.545 .923 .793 r
.56023 .79741 m .55922 .79839 L .56132 .79817 L F
.56023 .79741 m .55844 .79857 L .55922 .79839 L F
.972 .69 .436 r
.56387 .81967 m .56272 .81916 L .56272 .81691 L F
0 0 .14 r
.56511 .81688 m .56387 .81967 L .56272 .81691 L F
.735 .49 0 r
.56644 .81912 m .56671 .82094 L .56463 .81923 L F
0 .157 .673 r
.56463 .81923 m .56567 .81976 L .56522 .8195 L F
0 0 .14 r
.56511 .81688 m .56463 .81923 L .56416 .81901 L F
0 .157 .673 r
.56463 .81923 m .56522 .8195 L .5634 .81842 L F
0 0 .14 r
.56416 .81901 m .56463 .81923 L .56387 .81967 L F
.251 .714 .949 r
.56387 .81967 m .56463 .81923 L .56272 .81916 L F
.608 .713 .919 r
.45396 .73436 m .45059 .73336 L .45278 .73292 L F
.387 .566 .907 r
.45471 .73289 m .45396 .73436 L .45278 .73292 L F
.45471 .73289 m .45575 .73435 L .45396 .73436 L F
.443 .406 .722 r
.45585 .73554 m .45396 .73436 L .45575 .73435 L F
.545 .53 .789 r
.48097 .86353 m .48267 .85939 L .48057 .86023 L F
.48097 .86353 m .48457 .86367 L .48267 .85939 L F
.802 .69 .741 r
.48089 .86378 m .48457 .86367 L .48097 .86353 L F
.475 .306 .572 r
.32497 .7023 m .32671 .70208 L .32678 .69979 L F
.49 .305 .556 r
.32497 .7023 m .32671 .70457 L .32671 .70208 L F
.32497 .7023 m .32531 .70573 L .32671 .70457 L F
.613 .508 .71 r
.46561 .86455 m .46846 .86735 L .46763 .8643 L F
.46561 .86455 m .46627 .86776 L .46846 .86735 L F
.861 .409 .07 r
.51158 .87559 m .51231 .87554 L .50991 .87311 L F
0 .217 .722 r
.51234 .87499 m .51231 .87554 L .50991 .87311 L F
.578 .942 .834 r
.51158 .87559 m .51231 .87554 L .51234 .87499 L F
0 0 0 r
.48625 .87789 m .48495 .87845 L .48743 .87988 L F
.48625 .87789 m .48407 .88006 L .48495 .87845 L F
.819 .981 .888 r
.67273 .61888 m .67069 .6208 L .67134 .61899 L F
.01 0 0 r
.67069 .6208 m .67142 .62124 L .67134 .61899 L F
.67069 .6208 m .66968 .62208 L .67142 .62124 L F
.413 0 .047 r
.30896 .65348 m .31105 .65181 L .30743 .65158 L F
.30896 .65348 m .3093 .65349 L .31105 .65181 L F
0 .158 .677 r
.31271 .65383 m .31105 .65181 L .31239 .65174 L F
.772 .54 .584 r
.31239 .65174 m .3093 .65349 L .31105 .65181 L F
.714 .717 .851 r
.69802 .72441 m .70188 .72593 L .7 .72346 L F
.469 .542 .849 r
.70188 .72593 m .70227 .72281 L .7 .72346 L F
.70188 .72593 m .70368 .72556 L .70227 .72281 L F
.998 .821 .473 r
.70622 .71072 m .70533 .7119 L .70555 .70982 L F
.674 .219 .164 r
.70622 .71072 m .7086 .71243 L .70533 .7119 L F
.58 .626 .862 r
.41849 .74301 m .42007 .74516 L .4219 .74471 L F
.576 .414 .625 r
.33009 .69164 m .33217 .68868 L .33029 .68929 L F
.841 .677 .679 r
.57199 .80902 m .56898 .80892 L .57097 .80594 L F
.836 .735 .754 r
.57199 .80902 m .57031 .81166 L .56898 .80892 L F
.508 .173 .334 r
.44469 .76965 m .44423 .77113 L .44206 .77134 L F
.576 .274 .42 r
.44752 .76843 m .44423 .77113 L .44469 .76965 L F
.651 .397 .523 r
.66901 .70989 m .67251 .71015 L .67125 .70857 L F
.512 .515 .796 r
.67497 .71002 m .67125 .70857 L .67251 .71015 L F
.67497 .71002 m .67396 .70696 L .67125 .70857 L F
.526 .648 .911 r
.34489 .78981 m .34448 .79221 L .34369 .79181 L F
.34489 .78981 m .3463 .79198 L .34448 .79221 L F
.611 .319 .45 r
.36421 .88366 m .36691 .88362 L .36614 .88573 L F
.476 .004 .055 r
.36711 .88372 m .36691 .88362 L .36421 .88366 L F
.412 .757 .995 r
.36481 .8826 m .36711 .88372 L .36421 .88366 L F
.386 .726 .99 r
.36481 .8826 m .36421 .88366 L .36444 .88285 L F
.611 .319 .45 r
.36421 .88366 m .36614 .88573 L .36444 .88285 L F
.746 .658 .764 r
.6836 .61961 m .68455 .62269 L .68111 .62253 L F
.754 .52 .577 r
.68455 .62269 m .68109 .62483 L .68111 .62253 L F
.68455 .62269 m .68484 .62542 L .68109 .62483 L F
.138 .262 .73 r
.68549 .62148 m .68455 .62269 L .6836 .61961 L F
0 0 .425 r
.68567 .62373 m .68455 .62269 L .68549 .62148 L F
.68567 .62373 m .68484 .62542 L .68455 .62269 L F
0 0 0 r
.3628 .78992 m .36485 .78961 L .36592 .78938 L F
.139 0 0 r
.36592 .78938 m .36485 .78961 L .36791 .78939 L F
.545 .585 .845 r
.47172 .87796 m .4739 .87797 L .47183 .87475 L F
.193 .398 .835 r
.47183 .87475 m .4739 .87797 L .47457 .87741 L F
.224 .464 .878 r
.47189 .8793 m .47499 .87993 L .47457 .87741 L F
.47189 .8793 m .47409 .88085 L .47499 .87993 L F
.533 .42 .671 r
.4668 .86985 m .46846 .86735 L .46627 .86776 L F
.4668 .86985 m .46881 .86971 L .46846 .86735 L F
.393 .436 .786 r
.4668 .86985 m .46932 .87274 L .46881 .86971 L F
.717 .707 .839 r
.33737 .65898 m .335 .66014 L .33333 .65763 L F
.728 .839 .933 r
.71557 .73148 m .71624 .73319 L .71866 .73139 L F
.321 .026 .3 r
.43248 .76391 m .43008 .76628 L .43193 .76556 L F
.418 .1 .317 r
.43193 .76556 m .43453 .76352 L .43248 .76391 L F
.789 .628 .681 r
.47744 .86451 m .4793 .86521 L .47619 .86483 L F
.669 .768 .925 r
.64819 .59633 m .65179 .59581 L .65026 .59659 L F
.688 .684 .84 r
.64901 .59276 m .65128 .59524 L .64819 .59633 L F
.65128 .59524 m .65179 .59581 L .65096 .59593 L F
.65128 .59524 m .65096 .59593 L .64819 .59633 L F
.568 .548 .792 r
.65347 .59454 m .65123 .5986 L .65046 .59702 L F
.65082 .59623 m .65046 .59702 L .65026 .59659 L F
.494 .57 .862 r
.65106 .59216 m .65179 .59581 L .64901 .59276 L F
.65106 .59216 m .65347 .59454 L .65179 .59581 L F
.62 .937 .959 r
.65179 .59581 m .65347 .59454 L .65026 .59659 L F
.568 .548 .792 r
.65347 .59454 m .65046 .59702 L .65082 .59623 L F
.563 .878 .992 r
.31399 .67463 m .31339 .67563 L .31561 .67495 L F
.31399 .67463 m .31263 .67552 L .31339 .67563 L F
.685 .721 .877 r
.64617 .61428 m .64981 .61487 L .64797 .61362 L F
.753 .533 .597 r
.64943 .61704 m .64981 .61487 L .64617 .61428 L F
.715 .785 .907 r
.68582 .71667 m .68214 .71651 L .68496 .71569 L F
.772 .873 .921 r
.68776 .71551 m .68582 .71667 L .68496 .71569 L F
.911 .75 .668 r
.57838 .80296 m .57773 .80593 L .5796 .80602 L F
.928 .75 .64 r
.57736 .80832 m .5796 .80602 L .57773 .80593 L F
.57736 .80832 m .57891 .80912 L .5796 .80602 L F
.241 0 0 r
.66621 .64178 m .66528 .64307 L .66306 .64352 L F
.132 0 0 r
.66736 .64236 m .66621 .64178 L .66825 .6422 L F
.66736 .64236 m .66528 .64307 L .66621 .64178 L F
.346 0 0 r
.66891 .64156 m .66825 .6422 L .66621 .64178 L F
.509 .213 .4 r
.44206 .77134 m .43908 .77403 L .43979 .77169 L F
.979 .762 .347 r
.56833 .82763 m .56782 .82852 L .56513 .82741 L F
.56833 .82763 m .56826 .82999 L .56782 .82852 L F
.231 .321 .751 r
.66936 .72632 m .67019 .72774 L .66972 .72495 L F
.152 0 .18 r
.38988 .74541 m .38833 .74793 L .38756 .74798 L F
.409 .119 .358 r
.39174 .74569 m .38988 .74541 L .39159 .7444 L F
.39174 .74569 m .38833 .74793 L .38988 .74541 L F
.173 .709 .77 r
.3841 .78419 m .38124 .78458 L .38324 .78409 L F
.736 .256 .105 r
.47666 .8548 m .47916 .85695 L .4805 .85676 L F
.338 .378 .756 r
.47818 .85329 m .47916 .85695 L .47666 .8548 L F
.551 .521 .775 r
.56154 .81202 m .56256 .80807 L .56463 .80937 L F
.381 .717 .988 r
.5646 .8079 m .56463 .80937 L .56256 .80807 L F
.5646 .8079 m .56639 .80926 L .56463 .80937 L F
.893 .741 .686 r
.62392 .64704 m .62372 .64934 L .62269 .64654 L F
.267 .465 .868 r
.33225 .65635 m .33155 .65763 L .3308 .656 L F
.384 .614 .942 r
.33225 .65635 m .33333 .65763 L .33155 .65763 L F
.375 .501 .858 r
.68558 .59458 m .68422 .59597 L .68274 .59326 L F
.314 .404 .795 r
.68558 .59458 m .68652 .59749 L .68422 .59597 L F
.356 .791 .966 r
.34967 .7922 m .3463 .79198 L .34832 .79155 L F
.625 .813 .972 r
.35068 .79031 m .34967 .7922 L .34832 .79155 L F
.35068 .79031 m .35173 .79153 L .34967 .7922 L F
.788 .851 .398 r
.54207 .836 m .54209 .83548 L .54349 .83183 L F
.79 .901 .496 r
.54207 .836 m .54098 .8375 L .54209 .83548 L F
.887 .544 .393 r
.54207 .836 m .5431 .83821 L .54098 .8375 L F
.98 .826 .619 r
.71837 .72869 m .72013 .72627 L .71924 .72571 L F
.71837 .72869 m .71943 .72934 L .72013 .72627 L F
.625 .614 .82 r
.70394 .72718 m .70759 .72922 L .70729 .72795 L F
.385 .556 .9 r
.70729 .72795 m .70759 .72922 L .70897 .72803 L F
.467 .706 .972 r
.70759 .72922 m .7095 .72918 L .70897 .72803 L F
.797 .484 .46 r
.54349 .83183 m .54632 .83046 L .54484 .82972 L F
.54349 .83183 m .54692 .83265 L .54632 .83046 L F
.878 .807 .776 r
.64207 .60476 m .64113 .60722 L .63918 .60631 L F
.737 .372 .361 r
.64113 .60722 m .63837 .60824 L .63918 .60631 L F
.64113 .60722 m .64222 .60893 L .63837 .60824 L F
.718 .673 .805 r
.57609 .84044 m .57722 .84238 L .57955 .84097 L F
.7 .603 .745 r
.43965 .74751 m .44295 .74794 L .44188 .74493 L F
.563 .682 .92 r
.4459 .73039 m .44492 .73226 L .44387 .73055 L F
.4459 .73039 m .447 .73194 L .44492 .73226 L F
.646 .697 .883 r
.67163 .72936 m .67274 .7265 L .67019 .72774 L F
.67163 .72936 m .67387 .72882 L .67274 .7265 L F
.729 .792 .903 r
.3395 .65875 m .33737 .65898 L .33954 .65823 L F
.17 .608 .938 r
.34112 .6586 m .3395 .65875 L .33954 .65823 L F
.34112 .6586 m .34278 .65965 L .3395 .65875 L F
.506 .634 .91 r
.44232 .72841 m .44209 .73075 L .44032 .72885 L F
.44232 .72841 m .44387 .73055 L .44209 .73075 L F
.197 .648 .945 r
.3291 .65512 m .32824 .65563 L .32705 .65511 L F
.3291 .65512 m .3308 .656 L .32824 .65563 L F
.778 .485 .491 r
.57929 .81876 m .58231 .81713 L .57931 .8165 L F
.57929 .81876 m .58239 .81919 L .58231 .81713 L F
.557 .531 .782 r
.44295 .74794 m .44384 .74458 L .44188 .74493 L F
.44295 .74794 m .44486 .74754 L .44384 .74458 L F
.541 .448 .699 r
.44295 .74794 m .4452 .74978 L .44486 .74754 L F
.533 .448 .705 r
.44295 .74794 m .44325 .75027 L .4452 .74978 L F
.83 .717 .74 r
.62269 .64654 m .62372 .64934 L .62107 .64929 L F
.749 .523 .588 r
.62372 .64934 m .62034 .65127 L .62107 .64929 L F
.62372 .64934 m .62373 .6516 L .62034 .65127 L F
.934 .864 .746 r
.67657 .59892 m .67416 .60072 L .67529 .59796 L F
.67657 .59892 m .67516 .60167 L .67416 .60072 L F
.55 .388 .615 r
.35023 .77375 m .34775 .77091 L .34998 .77147 L F
.35023 .77375 m .34797 .77422 L .34775 .77091 L F
.753 .533 .597 r
.64943 .61704 m .64617 .61428 L .64765 .61818 L F
.651 .541 .717 r
.44325 .75027 m .44382 .7534 L .44632 .75286 L F
.617 .495 .692 r
.44437 .75574 m .44632 .75286 L .44382 .7534 L F
.695 .818 .941 r
.41547 .72399 m .41204 .72387 L .41408 .72305 L F
.231 .596 .949 r
.41599 .72319 m .41547 .72399 L .41408 .72305 L F
.41599 .72319 m .41729 .72432 L .41547 .72399 L F
.584 .558 .791 r
.47695 .84091 m .47921 .84075 L .47808 .83763 L F
.74 .576 .671 r
.34127 .79184 m .33797 .79016 L .34057 .79057 L F
.34127 .79184 m .33863 .79286 L .33797 .79016 L F
.34127 .79184 m .33957 .79289 L .33863 .79286 L F
.613 .698 .905 r
.34274 .79025 m .34127 .79184 L .34057 .79057 L F
.34274 .79025 m .34369 .79181 L .34127 .79184 L F
.473 .133 .308 r
.43469 .77446 m .43341 .7769 L .43155 .777 L F
.511 .172 .329 r
.43619 .77601 m .43469 .77446 L .4369 .77444 L F
.43619 .77601 m .43341 .7769 L .43469 .77446 L F
.393 .637 .953 r
.70394 .72718 m .70551 .72606 L .70368 .72556 L F
.70394 .72718 m .70729 .72795 L .70551 .72606 L F
.564 .346 .543 r
.44206 .75833 m .44424 .75804 L .44437 .75574 L F
.617 .495 .692 r
.44437 .75574 m .44685 .7557 L .44632 .75286 L F
.572 .353 .544 r
.44437 .75574 m .44643 .75774 L .44685 .7557 L F
.44437 .75574 m .44424 .75804 L .44643 .75774 L F
.576 .274 .42 r
.44752 .76843 m .44644 .7711 L .44423 .77113 L F
.567 .286 .448 r
.44996 .76838 m .44644 .7711 L .44752 .76843 L F
.547 .279 .461 r
.45678 .76381 m .45433 .76649 L .45218 .76676 L F
.523 .248 .44 r
.45694 .76506 m .45678 .76381 L .45738 .76342 L F
.45694 .76506 m .45433 .76649 L .45678 .76381 L F
.504 .503 .789 r
.68956 .6005 m .69043 .60365 L .6886 .60403 L F
.534 .453 .71 r
.69043 .60365 m .68886 .60595 L .6886 .60403 L F
.876 .587 .494 r
.48235 .8725 m .48261 .87461 L .48407 .87258 L F
.715 .363 .38 r
.48261 .87461 m .48599 .87464 L .48407 .87258 L F
0 0 0 r
.68628 .73185 m .68528 .73436 L .68764 .73038 L F
0 .13 .668 r
.68724 .73726 m .68508 .73435 L .68491 .73434 L F
.68724 .73726 m .68704 .7364 L .68508 .73435 L F
.68704 .7364 m .68703 .73636 L .68697 .7363 L F
.68704 .7364 m .68697 .7363 L .68508 .73435 L F
.761 .744 .837 r
.68757 .73324 m .68593 .7348 L .6881 .73594 L F
0 .13 .668 r
.68491 .73434 m .68508 .73435 L .68415 .73339 L F
.78 .332 .182 r
.68415 .73339 m .68697 .7363 L .68502 .73566 L F
.68697 .7363 m .68703 .73636 L .68502 .73566 L F
.761 .744 .837 r
.68593 .7348 m .68502 .73566 L .68663 .73581 L F
.68593 .7348 m .68663 .73581 L .6881 .73594 L F
0 0 0 r
.68528 .73436 m .68493 .73524 L .68542 .73436 L F
.68528 .73436 m .68542 .73436 L .68764 .73038 L F
.68724 .73726 m .68523 .74013 L .68656 .73873 L F
.68724 .73726 m .68656 .73873 L .68703 .73636 L F
.651 .541 .717 r
.44325 .75027 m .44632 .75286 L .4452 .74978 L F
.234 0 .298 r
.38833 .74793 m .38664 .75002 L .38756 .74798 L F
.379 0 .152 r
.67271 .71481 m .67651 .71408 L .6743 .71302 L F
.686 .645 .803 r
.53235 .82969 m .53831 .83023 L .53455 .8275 L F
.528 .431 .688 r
.53235 .82969 m .53549 .83249 L .53831 .83023 L F
.53235 .82969 m .53244 .83515 L .53549 .83249 L F
.375 0 .151 r
.402 .77707 m .40282 .7787 L .40403 .7767 L F
.402 .77707 m .40064 .77918 L .40282 .7787 L F
.632 .316 .418 r
.41148 .77333 m .41464 .77131 L .41188 .77223 L F
.41148 .77333 m .41372 .77374 L .41464 .77131 L F
.507 .203 .386 r
.41372 .77374 m .4167 .77093 L .41464 .77131 L F
.844 .748 .757 r
.69144 .73403 m .68963 .73679 L .69228 .73704 L F
.813 .686 .724 r
.68963 .73679 m .69174 .7394 L .69228 .73704 L F
.862 .757 .745 r
.69144 .73403 m .69228 .73704 L .69274 .73515 L F
.967 .79 .611 r
.53096 .81983 m .52874 .82118 L .52859 .81902 L F
.53096 .81983 m .53006 .82208 L .52874 .82118 L F
.467 .793 .999 r
.52859 .81902 m .53247 .81921 L .53096 .81983 L F
.87 .812 .329 r
.57957 .79732 m .58016 .7956 L .58031 .79537 L F
0 0 .116 r
.5806 .7921 m .58031 .79537 L .58016 .7956 L F
.409 .69 .977 r
.65261 .60435 m .65601 .6054 L .65472 .60344 L F
.321 0 .171 r
.40937 .77395 m .41148 .77333 L .41188 .77223 L F
.685 .601 .757 r
.48532 .86157 m .48457 .86367 L .48645 .86249 L F
.48267 .85939 m .48449 .8635 L .48532 .86157 L F
.48449 .8635 m .48457 .86367 L .48532 .86157 L F
.184 0 0 r
.48707 .86195 m .48426 .86406 L .48536 .86473 L F
.48426 .86406 m .48366 .8645 L .48404 .86455 L F
.48426 .86406 m .48404 .86455 L .48536 .86473 L F
0 0 .201 r
.48579 .86644 m .48566 .86749 L .48536 .86473 L F
.48579 .86644 m .48536 .86473 L .48366 .8645 L F
.477 .582 .881 r
.41959 .72476 m .4187 .7267 L .41729 .72432 L F
.575 .698 .926 r
.41959 .72476 m .42079 .72633 L .4187 .7267 L F
.877 .814 .784 r
.53995 .82493 m .53817 .82774 L .53707 .82636 L F
.53995 .82493 m .53707 .82636 L .53908 .82621 L F
.887 .502 .3 r
.53995 .82493 m .53908 .82621 L .54066 .8267 L F
.55 .36 .577 r
.47003 .85957 m .4723 .8614 L .47219 .85916 L F
.47003 .85957 m .46991 .86194 L .4723 .8614 L F
.893 .756 .704 r
.63795 .62772 m .6392 .63086 L .6405 .62798 L F
.672 .725 .889 r
.70533 .7119 m .70402 .71483 L .70348 .71318 L F
.70533 .7119 m .70691 .71352 L .70402 .71483 L F
.81 .514 .489 r
.48111 .85858 m .4805 .85676 L .47916 .85695 L F
.48111 .85858 m .48261 .85689 L .4805 .85676 L F
.964 .679 .444 r
.5457 .83741 m .54653 .83524 L .54604 .83493 L F
.5457 .83741 m .54727 .83874 L .54653 .83524 L F
.771 .565 .62 r
.47744 .86451 m .47619 .86483 L .47651 .86232 L F
.892 .68 .609 r
.67685 .61194 m .6753 .61168 L .67545 .60908 L F
.847 .469 .334 r
.67597 .61341 m .6753 .61168 L .67685 .61194 L F
.954 .645 .408 r
.67685 .61194 m .67734 .61431 L .67597 .61341 L F
.585 .406 .605 r
.34356 .77646 m .34136 .77984 L .34089 .77698 L F
.34356 .77646 m .344 .77969 L .34136 .77984 L F
.596 .418 .611 r
.34594 .7746 m .34595 .77676 L .34356 .77646 L F
.595 .413 .605 r
.34555 .77911 m .34356 .77646 L .34595 .77676 L F
.34555 .77911 m .344 .77969 L .34356 .77646 L F
.723 .318 .28 r
.57199 .78501 m .57409 .78692 L .57515 .78535 L F
.743 .343 .293 r
.57515 .78535 m .57409 .78692 L .57609 .787 L F
.603 .397 .575 r
.33996 .78716 m .33775 .78766 L .33704 .78494 L F
.33996 .78716 m .3381 .78763 L .33775 .78766 L F
.613 .444 .628 r
.33775 .78766 m .3381 .78763 L .33777 .78815 L F
.436 .051 .21 r
.4268 .76855 m .42896 .76828 L .43008 .76628 L F
.356 0 .166 r
.43008 .76628 m .43095 .76785 L .43193 .76556 L F
.43008 .76628 m .42896 .76828 L .43095 .76785 L F
0 0 .368 r
.71993 .72219 m .71969 .72347 L .71953 .72219 L F
.71993 .72219 m .71953 .72219 L .71941 .72122 L F
.74 .599 .7 r
.71636 .72113 m .71651 .72568 L .71993 .72219 L F
0 0 0 r
.71993 .72219 m .71761 .72229 L .72042 .72219 L F
.71993 .72219 m .72042 .72219 L .72084 .72217 L F
0 0 .368 r
.71993 .72219 m .71941 .72122 L .7169 .72047 L F
.436 .131 .348 r
.67233 .63283 m .6749 .6309 L .67487 .63322 L F
.403 .106 .344 r
.67487 .63322 m .6749 .6309 L .67744 .63007 L F
.578 .201 .291 r
.42469 .77936 m .42354 .78134 L .42195 .78141 L F
.532 .176 .309 r
.4268 .77921 m .42354 .78134 L .42469 .77936 L F
.86 .773 .764 r
.51912 .88137 m .52079 .87943 L .51774 .88033 L F
.753 .538 .605 r
.59227 .82474 m .59332 .82896 L .59572 .82503 L F
.875 .711 .675 r
.59572 .82503 m .59332 .82896 L .59562 .82733 L F
.301 .155 .51 r
.70199 .707 m .70063 .71004 L .7004 .70744 L F
0 0 0 r
.37443 .80217 m .37439 .80196 L .37622 .80124 L F
.37443 .80217 m .37265 .80293 L .37439 .80196 L F
.355 0 0 r
.4959 .88512 m .49806 .88467 L .49509 .88446 L F
1 .8 .476 r
.53831 .83023 m .53729 .82947 L .53817 .82774 L F
0 0 0 r
.53831 .83023 m .5373 .83112 L .53729 .82947 L F
.53831 .83023 m .53549 .83249 L .5373 .83112 L F
.839 .671 .674 r
.6413 .61737 m .63877 .61741 L .64052 .61443 L F
.788 .618 .67 r
.6413 .61737 m .63849 .61941 L .63877 .61741 L F
.6413 .61737 m .64053 .62146 L .63849 .61941 L F
0 0 .224 r
.64148 .61901 m .6413 .61737 L .64313 .61647 L F
.64148 .61901 m .64053 .62146 L .6413 .61737 L F
.69 .751 .899 r
.33863 .79286 m .33957 .79289 L .33894 .79321 L F
.561 .884 .99 r
.35747 .79066 m .35524 .7913 L .35414 .79093 L F
.455 .84 .984 r
.31408 .65425 m .31271 .65383 L .31629 .65379 L F
.604 .439 .631 r
.66144 .61997 m .6617 .62227 L .65929 .62267 L F
.583 .383 .576 r
.65936 .62492 m .6617 .62227 L .65929 .62267 L F
.604 .439 .631 r
.66144 .61997 m .6617 .62227 L .65929 .62267 L F
.769 .66 .742 r
.6617 .62227 m .65936 .62492 L .65929 .62267 L F
.836 .549 .503 r
.49141 .86145 m .49333 .85965 L .49126 .8592 L F
.49141 .86145 m .49465 .86281 L .49333 .85965 L F
.469 .261 .514 r
.5285 .86451 m .52871 .86223 L .53066 .8618 L F
.53066 .8618 m .52871 .86223 L .5285 .86451 L F
.191 0 0 r
.3866 .72492 m .38872 .7246 L .39031 .72356 L F
.153 0 0 r
.38872 .7246 m .39241 .72381 L .39031 .72356 L F
.576 .744 .956 r
.42641 .72694 m .42439 .7274 L .42282 .72583 L F
.609 .399 .572 r
.51623 .85632 m .51892 .85423 L .51538 .85458 L F
.184 0 0 r
.48679 .8626 m .48625 .86383 L .48672 .86222 L F
.838 .734 .75 r
.48745 .86369 m .48512 .86462 L .48625 .86383 L F
.629 .167 .139 r
.48745 .86369 m .48625 .86383 L .48707 .86195 L F
.838 .734 .75 r
.48745 .86369 m .48625 .86383 L .48628 .86381 L F
.629 .167 .139 r
.48745 .86369 m .48602 .86435 L .48625 .86383 L F
.184 0 0 r
.48625 .86383 m .48602 .86435 L .48618 .86388 L F
.48625 .86383 m .48618 .86388 L .48672 .86222 L F
.838 .734 .75 r
.48745 .86369 m .48579 .86644 L .48512 .86462 L F
0 0 .458 r
.48579 .86644 m .48585 .86584 L .48535 .86487 L F
.184 0 0 r
.48492 .8644 m .48602 .86435 L .48494 .86442 L F
.48619 .86383 m .48602 .86435 L .48373 .86445 L F
.48373 .86445 m .48492 .8644 L .48366 .8645 L F
.48492 .8644 m .48494 .86442 L .48366 .8645 L F
.48672 .86222 m .48619 .86383 L .48373 .86445 L F
.219 0 .121 r
.48366 .8645 m .48545 .86439 L .4857 .86393 L F
.48375 .86444 m .4857 .86393 L .48645 .86249 L F
.48366 .8645 m .4857 .86393 L .48375 .86444 L F
.717 .296 .246 r
.48645 .86249 m .48615 .86381 L .48745 .86369 L F
.294 .79 .859 r
.48628 .86381 m .48606 .86383 L .48619 .8638 L F
.48628 .86381 m .48619 .8638 L .48636 .86379 L F
.717 .296 .246 r
.48615 .86381 m .48602 .86435 L .48745 .86369 L F
.294 .79 .859 r
.48636 .86379 m .48619 .8638 L .48697 .86364 L F
.219 0 .121 r
.48545 .86439 m .48617 .86373 L .48645 .86249 L F
.294 .79 .859 r
.48606 .86383 m .48487 .86395 L .48657 .8637 L F
.48606 .86383 m .48657 .8637 L .48697 .86364 L F
.838 .734 .75 r
.48606 .86383 m .48512 .86462 L .48487 .86395 L F
.48628 .86381 m .48545 .86439 L .48606 .86383 L F
.48545 .86439 m .48512 .86462 L .48606 .86383 L F
.219 0 .121 r
.48545 .86439 m .48602 .86435 L .48617 .86373 L F
0 0 .458 r
.48512 .86462 m .48535 .86487 L .48487 .86395 L F
.48579 .86644 m .48535 .86487 L .48512 .86462 L F
.294 .79 .859 r
.48697 .86364 m .48487 .86395 L .48656 .86359 L F
.48745 .86369 m .48628 .86381 L .48697 .86364 L F
.717 .296 .246 r
.48645 .86249 m .48685 .86297 L .48656 .86359 L F
.48685 .86297 m .48745 .86369 L .48697 .86364 L F
.48685 .86297 m .48697 .86364 L .48656 .86359 L F
.184 0 0 r
.48707 .86195 m .48679 .8626 L .48672 .86222 L F
.629 .167 .139 r
.48745 .86369 m .48707 .86195 L .48923 .86405 L F
.211 .736 .778 r
.34607 .81253 m .3469 .8122 L .34347 .81294 L F
.34607 .81253 m .34822 .8121 L .3469 .8122 L F
.502 .429 .706 r
.46368 .74694 m .46201 .75134 L .46147 .74732 L F
.46368 .74694 m .46407 .75101 L .46201 .75134 L F
.512 .499 .779 r
.46407 .75101 m .46482 .75184 L .46201 .75134 L F
.76 .658 .75 r
.34278 .65965 m .34365 .66266 L .3403 .66225 L F
.495 .629 .911 r
.34493 .66101 m .34365 .66266 L .34278 .65965 L F
.34493 .66101 m .34531 .66245 L .34365 .66266 L F
.542 .51 .77 r
.34629 .66542 m .34365 .66266 L .34531 .66245 L F
.845 .702 .703 r
.51874 .86767 m .51881 .8697 L .51553 .8693 L F
.84 .56 .514 r
.51553 .8693 m .51881 .8697 L .51867 .87287 L F
.576 .826 .992 r
.48743 .87988 m .48859 .88065 L .48869 .87922 L F
.859 .695 .166 r
.48859 .88065 m .48832 .88135 L .48869 .87922 L F
.48859 .88065 m .48851 .88359 L .48832 .88135 L F
.833 .651 .656 r
.68776 .71551 m .68513 .71281 L .68869 .71434 L F
.68776 .71551 m .68496 .71569 L .68513 .71281 L F
.577 .43 .645 r
.69006 .71324 m .68776 .71551 L .68869 .71434 L F
.356 0 0 r
.4775 .83497 m .48099 .83579 L .48123 .83554 L F
.974 .719 .486 r
.48003 .83736 m .48135 .83802 L .48123 .83554 L F
.809 .988 .73 r
.68175 .74389 m .68365 .74229 L .68156 .74497 L F
0 .061 .622 r
.68156 .74497 m .68318 .74728 L .68175 .74389 L F
.932 .555 .236 r
.69032 .73097 m .69049 .72974 L .69024 .72866 L F
.69032 .73097 m .69141 .73162 L .69049 .72974 L F
.582 .252 .376 r
.46714 .76114 m .46587 .76206 L .46495 .76099 L F
.863 .778 .766 r
.63322 .63052 m .62998 .63233 L .63213 .62957 L F
.63322 .63052 m .63139 .63341 L .62998 .63233 L F
.883 .87 .82 r
.63538 .62761 m .63322 .63052 L .63213 .62957 L F
.719 .69 .821 r
.57031 .81166 m .56708 .81184 L .56898 .80892 L F
.937 .617 .406 r
.56847 .81428 m .56708 .81184 L .57031 .81166 L F
.545 .585 .845 r
.47172 .87796 m .47183 .87475 L .46992 .87506 L F
.315 .099 .418 r
.32563 .72089 m .32493 .72319 L .32373 .72377 L F
.485 .23 .453 r
.32493 .72319 m .32297 .72575 L .32373 .72377 L F
.883 .87 .82 r
.63538 .62761 m .63213 .62957 L .63424 .6269 L F
.696 .704 .853 r
.63606 .62476 m .63538 .62761 L .63424 .6269 L F
.858 .538 .444 r
.57609 .787 m .57881 .78968 L .57835 .78794 L F
.568 .548 .792 r
.65347 .59454 m .6533 .5979 L .65123 .5986 L F
.272 0 .142 r
.6533 .5979 m .65068 .60019 L .65123 .5986 L F
.478 .092 .23 r
.65123 .5986 m .65068 .60019 L .64817 .60066 L F
.937 .617 .406 r
.56847 .81428 m .56709 .81384 L .56708 .81184 L F
.952 .744 .586 r
.56847 .81428 m .56816 .81669 L .56709 .81384 L F
.609 .399 .572 r
.51623 .85632 m .51853 .85653 L .51892 .85423 L F
.51892 .85423 m .51853 .85653 L .51623 .85632 L F
.697 .566 .704 r
.33996 .78716 m .33777 .78815 L .3381 .78763 L F
.381 .159 .448 r
.32721 .72001 m .32493 .72319 L .32563 .72089 L F
.769 .66 .742 r
.6617 .62227 m .6626 .62529 L .65936 .62492 L F
.132 .662 .87 r
.6626 .62529 m .66204 .62503 L .65936 .62492 L F
.504 .366 .627 r
.66373 .62176 m .66144 .61997 L .66348 .61993 L F
.66373 .62176 m .6617 .62227 L .66144 .61997 L F
.66373 .62176 m .66144 .61997 L .66348 .61993 L F
.66373 .62176 m .6617 .62227 L .66144 .61997 L F
.639 .34 .448 r
.66685 .61944 m .66603 .62198 L .66373 .62176 L F
.65 .415 .55 r
.66603 .62198 m .66717 .62435 L .66459 .62241 L F
.6652 .6219 m .66459 .62241 L .66373 .62176 L F
.66603 .62198 m .66459 .62241 L .6652 .6219 L F
.11 .383 .841 r
.66373 .62176 m .66717 .62435 L .6669 .62401 L F
.66397 .6216 m .6669 .62401 L .66462 .62114 L F
.66373 .62176 m .6669 .62401 L .66397 .6216 L F
.466 .476 .784 r
.6617 .62227 m .6626 .62529 L .66459 .62219 L F
.66459 .62219 m .6626 .62529 L .6617 .62227 L F
.818 .999 .836 r
.66428 .62267 m .66204 .62503 L .6626 .62529 L F
.66459 .62219 m .66377 .6231 L .66428 .62267 L F
.66377 .6231 m .66204 .62503 L .66428 .62267 L F
.411 .38 .714 r
.33529 .6755 m .33571 .67857 L .33748 .67768 L F
.513 .395 .656 r
.33569 .6808 m .33748 .67768 L .33571 .67857 L F
.778 .511 .533 r
.59332 .82896 m .59558 .82977 L .59562 .82733 L F
.615 .1 0 r
.52364 .86843 m .5242 .86743 L .52099 .86696 L F
.429 .351 .667 r
.52631 .86952 m .52455 .86975 L .5242 .86743 L F
.751 .261 .069 r
.52631 .86952 m .5242 .86743 L .52364 .86843 L F
.519 .53 .807 r
.67019 .72774 m .67219 .72477 L .66972 .72495 L F
.67019 .72774 m .67274 .7265 L .67219 .72477 L F
.553 .691 .931 r
.71428 .70764 m .71263 .70707 L .71296 .70702 L F
.791 .407 .328 r
.71305 .70935 m .71428 .70764 L .71296 .70702 L F
.557 .569 .822 r
.71424 .70626 m .71305 .70935 L .71296 .70702 L F
.71355 .70693 m .71296 .70702 L .71275 .70772 L F
.71424 .70626 m .71296 .70702 L .71355 .70693 L F
.553 .691 .931 r
.71263 .70707 m .70987 .70614 L .71296 .70702 L F
.795 .562 .585 r
.49565 .86479 m .4925 .86681 L .49241 .86467 L F
.49565 .86479 m .49563 .8673 L .4925 .86681 L F
.697 .566 .704 r
.33996 .78716 m .33797 .79016 L .33777 .78815 L F
.508 .35 .602 r
.37114 .75275 m .36938 .7557 L .3689 .75302 L F
.539 .035 .007 r
.56649 .78509 m .56897 .78615 L .56994 .78504 L F
.54 .219 .372 r
.57245 .78633 m .56994 .78504 L .56897 .78615 L F
.57245 .78633 m .57199 .78501 L .56994 .78504 L F
.565 .266 .42 r
.45433 .76649 m .4518 .7683 L .45218 .76676 L F
.878 .807 .776 r
.64207 .60476 m .63918 .60631 L .64075 .6039 L F
.744 .889 .945 r
.64275 .60291 m .64207 .60476 L .64075 .6039 L F
.64275 .60291 m .64379 .60372 L .64207 .60476 L F
.541 .395 .632 r
.3344 .74717 m .33641 .74967 L .33622 .74688 L F
.3344 .74717 m .33451 .75019 L .33641 .74967 L F
.543 .238 .399 r
.45947 .7636 m .45694 .76506 L .45738 .76342 L F
.804 .499 .473 r
.58547 .81966 m .58583 .82176 L .58894 .82212 L F
.825 .6 .598 r
.58584 .82408 m .58894 .82212 L .58583 .82176 L F
.58584 .82408 m .589 .82491 L .58894 .82212 L F
.772 .37 .292 r
.54066 .8267 m .54172 .82742 L .54353 .82742 L F
.822 .378 .18 r
.54172 .82742 m .54484 .82972 L .54353 .82742 L F
.42 .223 .506 r
.33199 .71505 m .33029 .71581 L .33228 .71299 L F
.396 .098 .337 r
.33122 .71687 m .33029 .71581 L .33199 .71505 L F
.33122 .71687 m .32958 .71738 L .33029 .71581 L F
0 0 0 r
.379 .80022 m .37818 .80066 L .37622 .80124 L F
.38004 .79991 m .379 .80022 L .38087 .79967 L F
.38004 .79991 m .37818 .80066 L .379 .80022 L F
.27 .761 .91 r
.39442 .72338 m .39781 .72341 L .39576 .72375 L F
.705 .43 .506 r
.58234 .8217 m .58547 .81966 L .58239 .81919 L F
.58234 .8217 m .58583 .82176 L .58547 .81966 L F
.637 .427 .581 r
.56668 .79553 m .5672 .79879 L .56433 .79829 L F
.538 .36 .587 r
.56759 .79791 m .5672 .79879 L .56668 .79553 L F
.252 .136 .521 r
.66791 .7141 m .66935 .71207 L .66901 .70989 L F
.377 .354 .707 r
.66895 .71571 m .66935 .71207 L .66791 .7141 L F
.646 .561 .744 r
.33864 .78201 m .33704 .78494 L .33656 .78371 L F
.33864 .78201 m .33971 .78539 L .33704 .78494 L F
.603 .397 .575 r
.33996 .78716 m .33704 .78494 L .33971 .78539 L F
.517 .34 .58 r
.32678 .69979 m .32671 .70208 L .32744 .70191 L F
.32779 .70078 m .32744 .70191 L .32867 .70165 L F
.32678 .69979 m .32744 .70191 L .32779 .70078 L F
.681 .318 .352 r
.32678 .69979 m .32779 .70078 L .32787 .7011 L F
.32779 .70078 m .32867 .70165 L .32787 .7011 L F
.202 .037 .421 r
.32888 .69715 m .32787 .7011 L .32967 .69856 L F
.32881 .69704 m .32848 .69847 L .32888 .69715 L F
.32848 .69847 m .32787 .7011 L .32888 .69715 L F
.493 .303 .551 r
.32678 .69979 m .32787 .7011 L .32881 .69704 L F
.557 .492 .738 r
.36249 .67527 m .36085 .67595 L .3602 .67574 L F
.36249 .67527 m .36273 .67786 L .36085 .67595 L F
.606 .442 .634 r
.36223 .6799 m .36085 .67595 L .36273 .67786 L F
.36223 .6799 m .36081 .68041 L .36085 .67595 L F
.65 .272 .314 r
.49465 .86281 m .49646 .8642 L .49794 .86224 L F
.745 .39 .381 r
.49646 .8642 m .49992 .86445 L .49794 .86224 L F
.736 .694 .81 r
.69227 .72593 m .69557 .72622 L .69457 .72338 L F
.688 .668 .825 r
.69457 .72338 m .69557 .72622 L .69802 .72441 L F
.542 .614 .874 r
.46694 .75157 m .46584 .75336 L .46482 .75184 L F
.46694 .75157 m .46777 .75338 L .46584 .75336 L F
.534 .453 .71 r
.69043 .60365 m .69099 .60593 L .68886 .60595 L F
.317 .784 .936 r
.42842 .72656 m .43139 .72665 L .43007 .72608 L F
.412 .03 .201 r
.36309 .73374 m .36633 .73144 L .3642 .73162 L F
.845 .702 .703 r
.51874 .86767 m .51595 .86773 L .51754 .86693 L F
.51874 .86767 m .51553 .8693 L .51595 .86773 L F
.592 .716 .93 r
.45278 .73292 m .45059 .73336 L .44908 .73157 L F
.763 .613 .692 r
.57089 .81945 m .56816 .81669 L .57153 .8171 L F
.417 .344 .667 r
.67487 .63322 m .67471 .63486 L .67233 .63283 L F
.986 .785 .388 r
.68802 .72912 m .68772 .72923 L .68758 .72707 L F
0 0 0 r
.68802 .72912 m .68628 .73185 L .68764 .73038 L F
.68802 .72912 m .68764 .73038 L .68772 .72923 L F
.634 .473 .647 r
.344 .77969 m .3408 .78137 L .34136 .77984 L F
.447 .061 .213 r
.6062 .64654 m .60312 .64861 L .6057 .64558 L F
.6062 .64654 m .60569 .64831 L .60312 .64861 L F
.643 .299 .375 r
.6057 .64558 m .60835 .64384 L .6062 .64654 L F
.147 .328 .788 r
.6062 .64654 m .6057 .64558 L .60569 .64831 L F
.6062 .64654 m .60672 .64567 L .6057 .64558 L F
.696 .568 .706 r
.60835 .64384 m .60937 .64632 L .6062 .64654 L F
.638 .327 .427 r
.60937 .64632 m .60843 .64836 L .6062 .64654 L F
.147 .328 .788 r
.6062 .64654 m .60843 .64836 L .60672 .64567 L F
.524 .335 .566 r
.32958 .71738 m .32721 .72001 L .32771 .71815 L F
.717 .707 .839 r
.33737 .65898 m .33333 .65763 L .33579 .65783 L F
.57 .794 .984 r
.33954 .65823 m .33737 .65898 L .33579 .65783 L F
.574 .471 .7 r
.56017 .79581 m .55849 .79617 L .55925 .79527 L F
.787 .839 .891 r
.6807 .59385 m .67704 .595 L .67969 .59257 L F
.624 .78 .956 r
.68195 .59204 m .6807 .59385 L .67969 .59257 L F
.68195 .59204 m .68274 .59326 L .6807 .59385 L F
.688 .684 .84 r
.64901 .59276 m .64819 .59633 L .64685 .59528 L F
.675 .8 .942 r
.66694 .60837 m .66472 .6094 L .6657 .60725 L F
.174 .204 .652 r
.6657 .60725 m .66472 .6094 L .66631 .61101 L F
.284 0 .122 r
.41253 .78596 m .41183 .78451 L .41387 .78444 L F
.41253 .78596 m .41051 .7867 L .41183 .78451 L F
.784 .923 .549 r
.71633 .71208 m .71666 .71214 L .71756 .71063 L F
.915 .711 .613 r
.71429 .71475 m .71666 .71214 L .71633 .71208 L F
.71429 .71475 m .71591 .7155 L .71666 .71214 L F
.801 .618 .654 r
.57097 .80594 m .56898 .80892 L .56782 .80577 L F
.465 .22 .458 r
.35001 .69201 m .34965 .69407 L .34764 .69451 L F
.368 .136 .425 r
.35134 .69339 m .35001 .69201 L .35199 .69165 L F
.35134 .69339 m .34965 .69407 L .35001 .69201 L F
.445 .089 .266 r
.4167 .77093 m .41881 .77077 L .41935 .76925 L F
.543 .181 .304 r
.41881 .77077 m .42111 .77063 L .41935 .76925 L F
.875 .577 .481 r
.59609 .83245 m .59715 .82954 L .59558 .82977 L F
.59609 .83245 m .59817 .83236 L .59715 .82954 L F
.648 .336 .43 r
.44164 .76009 m .44407 .76029 L .44206 .75833 L F
.564 .347 .543 r
.44206 .75833 m .44407 .76029 L .44424 .75804 L F
.672 .974 .814 r
.37363 .78664 m .37452 .78431 L .37522 .78667 L F
.37363 .78664 m .37424 .7857 L .37452 .78431 L F
.472 .857 .979 r
.32493 .67265 m .3239 .67327 L .32642 .67301 L F
.666 .43 .553 r
.32342 .67517 m .32642 .67301 L .3239 .67327 L F
.32342 .67517 m .32694 .67593 L .32642 .67301 L F
0 .221 .7 r
.32642 .67301 m .32653 .67275 L .32493 .67265 L F
.32642 .67301 m .32738 .67357 L .32653 .67275 L F
.718 .673 .805 r
.57609 .84044 m .57955 .84097 L .57833 .84053 L F
.634 .904 .597 r
.58033 .83987 m .57955 .84097 L .58166 .83869 L F
.573 .883 .992 r
.58033 .83987 m .57833 .84053 L .57955 .84097 L F
.427 .853 .947 r
.38124 .78458 m .38199 .78387 L .38324 .78409 L F
.478 .897 .847 r
.38124 .78458 m .38023 .78472 L .38199 .78387 L F
0 0 0 r
.66631 .61101 m .66507 .6139 L .66701 .61331 L F
.134 0 .221 r
.66701 .61331 m .66507 .6139 L .66487 .61603 L F
.819 .981 .888 r
.67273 .61888 m .66902 .61711 L .67177 .61686 L F
.67273 .61888 m .67134 .61899 L .66902 .61711 L F
.181 .549 .93 r
.67374 .61837 m .67273 .61888 L .67177 .61686 L F
.67374 .61837 m .67454 .61943 L .67273 .61888 L F
.615 .477 .671 r
.33639 .78225 m .33864 .78201 L .33656 .78371 L F
.801 .575 .594 r
.63435 .63146 m .63532 .6321 L .63613 .63194 L F
.717 .65 .782 r
.63673 .6329 m .6392 .63086 L .63792 .6293 L F
.458 0 0 r
.63788 .63377 m .63673 .6329 L .63613 .63194 L F
.801 .575 .594 r
.63532 .6321 m .63788 .63377 L .63613 .63194 L F
.717 .65 .782 r
.63673 .6329 m .63711 .63175 L .63613 .63194 L F
.63711 .63175 m .63792 .6293 L .63613 .63194 L F
.458 0 0 r
.63788 .63377 m .63888 .63396 L .63673 .6329 L F
.604 .046 0 r
.35 .81131 m .3509 .81117 L .3512 .81152 L F
.17 .704 .833 r
.39781 .72341 m .39984 .72324 L .40123 .72334 L F
.251 .725 .94 r
.39984 .72324 m .4033 .72367 L .40123 .72334 L F
.897 .783 .727 r
.63958 .61151 m .64052 .61443 L .63918 .61347 L F
.871 .718 .69 r
.64052 .61443 m .63754 .6165 L .63918 .61347 L F
.64052 .61443 m .63877 .61741 L .63754 .6165 L F
.817 .748 .787 r
.64276 .61143 m .64052 .61443 L .63958 .61151 L F
.379 .142 .424 r
.33007 .75539 m .33238 .7524 L .32998 .75297 L F
.213 .737 .762 r
.40676 .723 m .40735 .72275 L .40866 .7233 L F
.40676 .723 m .40534 .7232 L .40735 .72275 L F
.891 .562 .418 r
.57881 .78968 m .5806 .7921 L .58083 .79011 L F
.096 .127 .603 r
.58341 .83607 m .58338 .83818 L .58475 .83714 L F
.008 .05 .556 r
.58341 .83607 m .58338 .83818 L .58365 .83592 L F
.096 .127 .603 r
.58341 .83607 m .58366 .83627 L .58377 .83556 L F
.008 .05 .556 r
.58341 .83607 m .58365 .83592 L .58366 .83571 L F
.58341 .83607 m .58366 .83571 L .58368 .83512 L F
.096 .127 .603 r
.58341 .83607 m .58377 .83556 L .58392 .83457 L F
.58366 .83627 m .58475 .83714 L .58405 .83498 L F
.58366 .83627 m .58405 .83498 L .58392 .83457 L F
.716 .938 .623 r
.58365 .83592 m .58166 .83869 L .58304 .83828 L F
.58358 .83651 m .58304 .83828 L .58338 .83818 L F
.58365 .83592 m .58304 .83828 L .58358 .83651 L F
.58365 .83592 m .58033 .83987 L .58166 .83869 L F
.677 .631 .796 r
.56898 .80892 m .56708 .81184 L .56639 .80926 L F
.58 .405 .609 r
.34773 .77598 m .34594 .7746 L .34797 .77422 L F
.34773 .77598 m .34595 .77676 L .34594 .7746 L F
.609 .585 .801 r
.54662 .8438 m .54785 .84031 L .54538 .84263 L F
.54662 .8438 m .54892 .84335 L .54785 .84031 L F
.596 .698 .914 r
.43789 .74391 m .44188 .74493 L .44057 .74336 L F
.544 .6 .86 r
.44188 .74493 m .44226 .74195 L .44057 .74336 L F
.44188 .74493 m .44384 .74458 L .44226 .74195 L F
.202 .037 .421 r
.32881 .69704 m .32967 .69856 L .33016 .69638 L F
.912 .593 .427 r
.71633 .71208 m .71756 .71063 L .71599 .70997 L F
.643 .299 .375 r
.6057 .64558 m .60672 .64567 L .60835 .64384 L F
.693 .635 .787 r
.61053 .6434 m .60937 .64632 L .60835 .64384 L F
.691 .464 .574 r
.60672 .64567 m .61053 .6434 L .60835 .64384 L F
1 .832 .526 r
.67453 .60387 m .67416 .60072 L .67516 .60167 L F
.352 .808 .69 r
.6439 .61079 m .64276 .61143 L .64222 .60893 L F
0 .036 .592 r
.64276 .61143 m .64247 .60937 L .64222 .60893 L F
.817 .748 .787 r
.64276 .61143 m .63958 .61151 L .64247 .60937 L F
.352 .808 .69 r
.6439 .61079 m .64513 .61028 L .64276 .61143 L F
.519 .45 .719 r
.69569 .71568 m .69264 .71201 L .69432 .71189 L F
.69569 .71568 m .69337 .71551 L .69264 .71201 L F
.526 .845 .546 r
.56272 .81916 m .56511 .81688 L .56272 .81691 L F
.062 0 0 r
.43023 .74143 m .42854 .74191 L .42858 .74173 L F
.363 .829 .764 r
.43051 .74108 m .42854 .74191 L .43023 .74143 L F
.612 .253 .336 r
.43051 .74108 m .4285 .74211 L .42854 .74191 L F
.4285 .74211 m .42706 .74285 L .42854 .74191 L F
.062 0 0 r
.42858 .74173 m .42854 .74191 L .42646 .74212 L F
.363 .829 .764 r
.43051 .74108 m .43023 .74143 L .43188 .74138 L F
.382 0 0 r
.64631 .63136 m .64912 .63122 L .64961 .63038 L F
.64631 .63136 m .64887 .63171 L .64912 .63122 L F
.464 .245 .496 r
.64887 .63171 m .64969 .6354 L .64912 .63122 L F
.689 .473 .589 r
.66935 .71207 m .67251 .71015 L .66901 .70989 L F
.786 .687 .755 r
.68858 .74695 m .68638 .74765 L .68944 .74785 L F
.769 .686 .772 r
.68858 .74695 m .68944 .74785 L .6917 .74515 L F
.525 .167 .302 r
.408 .77564 m .41148 .77333 L .40937 .77395 L F
.649 .557 .738 r
.46147 .74732 m .45926 .74792 L .45821 .74457 L F
.628 .692 .89 r
.35684 .67565 m .35495 .67645 L .35353 .67466 L F
.738 .222 0 r
.53116 .83825 m .53362 .84011 L .53073 .83747 L F
.564 .299 .472 r
.36664 .75798 m .3641 .7602 L .36445 .75816 L F
.575 .777 .975 r
.53754 .85 m .53931 .85123 L .53721 .85172 L F
.871 .969 .648 r
.53754 .85 m .53721 .85172 L .53573 .85307 L F
.464 .18 .397 r
.53721 .85172 m .53769 .85345 L .53656 .85369 L F
.53721 .85172 m .53931 .85123 L .53769 .85345 L F
.901 .572 .416 r
.53573 .85307 m .53721 .85172 L .53656 .85369 L F
.591 .801 .98 r
.36249 .67527 m .3602 .67574 L .35884 .67472 L F
.576 .414 .625 r
.33009 .69164 m .33193 .69152 L .33217 .68868 L F
.543 .381 .611 r
.33009 .69164 m .33174 .6931 L .33193 .69152 L F
.33009 .69164 m .33029 .69392 L .33174 .6931 L F
.422 0 .116 r
.37677 .75119 m .37561 .75237 L .37336 .75268 L F
.257 0 0 r
.37794 .75175 m .37677 .75119 L .3784 .7507 L F
.37794 .75175 m .37561 .75237 L .37677 .75119 L F
.693 .635 .787 r
.61053 .6434 m .61165 .64647 L .60937 .64632 L F
.3 0 0 r
.61165 .64647 m .60843 .64836 L .60937 .64632 L F
0 0 0 r
.3972 .74327 m .39564 .74374 L .3952 .74375 L F
.471 .882 .94 r
.39785 .74304 m .39642 .74294 L .39564 .74374 L F
.439 .458 .783 r
.39642 .74294 m .39628 .74372 L .39564 .74374 L F
.39628 .74372 m .396 .74523 L .39564 .74374 L F
0 0 0 r
.3952 .74375 m .39564 .74374 L .39363 .74412 L F
.224 .734 .689 r
.39785 .74304 m .3972 .74327 L .39913 .74281 L F
.39785 .74304 m .39564 .74374 L .3972 .74327 L F
.377 .354 .707 r
.66895 .71571 m .67062 .71497 L .66935 .71207 L F
.357 .248 .591 r
.66904 .71748 m .67062 .71497 L .66895 .71571 L F
.553 .796 .989 r
.3316 .67491 m .33529 .6755 L .33379 .67429 L F
.252 .49 .891 r
.33529 .6755 m .33589 .67423 L .33379 .67429 L F
.33529 .6755 m .3364 .67542 L .33589 .67423 L F
.411 .38 .714 r
.33529 .6755 m .33748 .67768 L .3364 .67542 L F
.509 .311 .548 r
.33423 .71252 m .33228 .71299 L .3344 .71032 L F
.456 .255 .517 r
.33367 .7144 m .33228 .71299 L .33423 .71252 L F
.33367 .7144 m .33199 .71505 L .33228 .71299 L F
.325 0 0 r
.64549 .64969 m .64452 .65066 L .64229 .65075 L F
.446 0 0 r
.64804 .64964 m .64452 .65066 L .64549 .64969 L F
.493 .861 .63 r
.64617 .61428 m .6451 .61493 L .64313 .61647 L F
.24 0 0 r
.64797 .61362 m .6451 .61493 L .64617 .61428 L F
.653 .574 .753 r
.66016 .60351 m .66146 .60699 L .66185 .60347 L F
.593 .747 .95 r
.67635 .72835 m .67274 .7265 L .67387 .72882 L F
.67635 .72835 m .6751 .72623 L .67274 .7265 L F
.759 .958 .936 r
.67635 .72835 m .67706 .72602 L .6751 .72623 L F
.67635 .72835 m .6785 .72642 L .67706 .72602 L F
.543 .33 .541 r
.34325 .74145 m .34588 .73897 L .34341 .73921 L F
.866 .987 .716 r
.68523 .74013 m .68365 .74229 L .68398 .74088 L F
.588 .917 .687 r
.68523 .74013 m .68398 .74088 L .68656 .73873 L F
0 0 0 r
.5675 .82428 m .56513 .82741 L .56607 .8263 L F
.5675 .82428 m .56607 .8263 L .56564 .82381 L F
.953 .873 .719 r
.5675 .82428 m .56701 .8222 L .56936 .82198 L F
.5675 .82428 m .56564 .82381 L .56701 .8222 L F
.169 0 0 r
.6534 .64705 m .65238 .64842 L .65064 .64846 L F
.16 0 0 r
.65554 .64655 m .65238 .64842 L .6534 .64705 L F
.551 .436 .676 r
.69226 .61103 m .69056 .61386 L .69014 .61176 L F
.923 .727 .62 r
.63849 .61941 m .6396 .62252 L .6381 .62205 L F
.681 .619 .779 r
.63849 .61941 m .64053 .62146 L .6396 .62252 L F
.105 .605 .9 r
.31629 .65379 m .31809 .65406 L .31952 .65471 L F
.353 .774 .976 r
.31809 .65406 m .3215 .65441 L .31952 .65471 L F
.3 0 0 r
.61165 .64647 m .61061 .64793 L .60843 .64836 L F
.87 .543 .03 r
.61053 .6434 m .61113 .64575 L .61165 .64647 L F
.989 .866 .51 r
.61113 .64575 m .61061 .64793 L .61165 .64647 L F
.946 .68 .501 r
.69841 .70221 m .69728 .70393 L .69776 .70192 L F
.69841 .70221 m .69832 .7044 L .69728 .70393 L F
.416 0 0 r
.69871 .70061 m .7001 .70082 L .69982 .70096 L F
.492 .026 .076 r
.69982 .70096 m .70208 .70111 L .70299 .70019 L F
.416 0 0 r
.7001 .70082 m .70208 .70111 L .69982 .70096 L F
0 0 0 r
.69918 .7013 m .69982 .70096 L .70084 .69933 L F
.69841 .70221 m .69982 .70096 L .69918 .7013 L F
.554 .926 .929 r
.69841 .70221 m .69776 .70192 L .69982 .70096 L F
.507 .566 .85 r
.47901 .86126 m .47744 .86451 L .47774 .86099 L F
.47901 .86126 m .48089 .86378 L .47744 .86451 L F
.8 .499 0 r
.67991 .6171 m .68032 .61847 L .67964 .61645 L F
.895 .783 .729 r
.68032 .61847 m .6766 .62099 L .67964 .61645 L F
.68032 .61847 m .67797 .62199 L .6766 .62099 L F
.824 .481 .407 r
.6864 .72328 m .68165 .72085 L .68409 .72317 L F
.389 .848 .803 r
.49874 .88975 m .4988 .8894 L .49702 .88983 L F
.49874 .88975 m .50054 .889 L .4988 .8894 L F
.695 .633 .783 r
.70879 .70235 m .70987 .70614 L .70734 .70479 L F
.287 .365 .768 r
.71027 .70457 m .70987 .70614 L .70879 .70235 L F
.466 0 0 r
.70969 .70671 m .70987 .70614 L .71027 .70457 L F
.70969 .70671 m .71296 .70702 L .70987 .70614 L F
.717 .584 .706 r
.68109 .62483 m .67797 .62199 L .68111 .62253 L F
.49 .265 .5 r
.65298 .63534 m .6551 .63284 L .65317 .63325 L F
.266 .765 .723 r
.36622 .80511 m .36692 .80479 L .36493 .80546 L F
.36622 .80511 m .36876 .80429 L .36692 .80479 L F
.299 .779 .919 r
.40251 .74277 m .40116 .74253 L .39913 .74281 L F
.243 0 0 r
.40452 .74283 m .40116 .74253 L .40251 .74277 L F
.322 .206 .563 r
.36839 .88287 m .36691 .88362 L .36711 .88372 L F
.146 0 .231 r
.36614 .88573 m .36691 .88362 L .36839 .88287 L F
.89 .864 .807 r
.6255 .6399 m .62869 .63806 L .62668 .64083 L F
.6255 .6399 m .62765 .63683 L .62869 .63806 L F
.868 .843 .817 r
.62921 .63469 m .62869 .63806 L .62765 .63683 L F
.62921 .63469 m .6307 .63531 L .62869 .63806 L F
.984 .752 .505 r
.59903 .83518 m .59817 .83236 L .59806 .83435 L F
.873 .743 .716 r
.59649 .83727 m .59903 .83518 L .59806 .83435 L F
.59649 .83727 m .59806 .83819 L .59903 .83518 L F
.693 .399 .473 r
.62926 .65142 m .63281 .65096 L .63135 .65365 L F
.675 .403 .501 r
.63466 .65136 m .63135 .65365 L .63281 .65096 L F
.352 0 .093 r
.36838 .73107 m .37042 .73071 L .37178 .7289 L F
.365 0 .083 r
.37042 .73071 m .37388 .72865 L .37178 .7289 L F
0 0 0 r
.43789 .74391 m .4349 .7461 L .43609 .74523 L F
.43789 .74391 m .43665 .74519 L .4349 .7461 L F
.43871 .74293 m .43789 .74391 L .44057 .74336 L F
.43871 .74293 m .4379 .74442 L .43789 .74391 L F
.4379 .74442 m .43653 .74531 L .43789 .74391 L F
.819 .788 .823 r
.43599 .74304 m .43789 .74441 L .43871 .74293 L F
.43789 .74441 m .4379 .74442 L .43792 .7444 L F
.43789 .74441 m .43792 .7444 L .43871 .74293 L F
0 0 0 r
.43665 .74519 m .43653 .74531 L .43618 .74548 L F
.43665 .74519 m .43618 .74548 L .4349 .7461 L F
.906 .807 .739 r
.63139 .63341 m .62921 .63469 L .62998 .63233 L F
.63139 .63341 m .6307 .63531 L .62921 .63469 L F
.452 .286 .564 r
.33601 .70767 m .33607 .70994 L .3344 .71032 L F
.477 .284 .54 r
.33599 .71188 m .3344 .71032 L .33607 .70994 L F
.33599 .71188 m .33423 .71252 L .3344 .71032 L F
.418 .18 .444 r
.34901 .69595 m .34764 .69451 L .34965 .69407 L F
.34901 .69595 m .34724 .69657 L .34764 .69451 L F
.608 .696 .905 r
.34489 .78981 m .34369 .79181 L .34274 .79025 L F
.137 0 .159 r
.50802 .85688 m .50728 .85835 L .50563 .85951 L F
.31 0 .259 r
.50977 .85632 m .50728 .85835 L .50802 .85688 L F
.582 .53 .762 r
.44632 .75286 m .44747 .74925 L .4452 .74978 L F
.44632 .75286 m .44846 .75249 L .44747 .74925 L F
.568 .462 .694 r
.44632 .75286 m .44893 .7551 L .44846 .75249 L F
.44632 .75286 m .44685 .7557 L .44893 .7551 L F
.709 .688 .828 r
.57251 .83979 m .574 .84126 L .57609 .84044 L F
.59 .076 0 r
.69094 .70829 m .69476 .70852 L .69212 .71032 L F
.69094 .70829 m .69353 .7094 L .69476 .70852 L F
.807 .969 .659 r
.69476 .70852 m .69556 .70655 L .69665 .70749 L F
.69476 .70852 m .69353 .7094 L .69556 .70655 L F
0 0 .035 r
.67244 .61548 m .67218 .61477 L .67229 .61373 L F
.67244 .61548 m .67177 .61686 L .67218 .61477 L F
.666 .619 .792 r
.69212 .71032 m .68884 .70838 L .69094 .70829 L F
.566 .37 .575 r
.66902 .61711 m .67063 .61939 L .66685 .61944 L F
.751 .65 .749 r
.67063 .61939 m .66603 .62198 L .66685 .61944 L F
.789 .919 .536 r
.54532 .81163 m .54438 .81269 L .5451 .81152 L F
.54532 .81163 m .54438 .81269 L .5451 .81152 L F
.813 .686 .724 r
.68963 .73679 m .68915 .73946 L .69174 .7394 L F
.925 .727 .616 r
.68957 .74118 m .69174 .7394 L .68915 .73946 L F
.68957 .74118 m .69111 .74201 L .69174 .7394 L F
.62 .405 .568 r
.4716 .7577 m .46956 .76096 L .46714 .76114 L F
.652 .596 .779 r
.47139 .75511 m .47249 .75761 L .4716 .7577 L F
.579 .355 .54 r
.47296 .76002 m .4716 .7577 L .47249 .75761 L F
.47296 .76002 m .46956 .76096 L .4716 .7577 L F
.976 .729 .498 r
.69032 .73097 m .69144 .73403 L .69141 .73162 L F
.572 .372 .571 r
.67134 .61899 m .67063 .61939 L .66902 .61711 L F
.691 .684 .839 r
.53549 .83249 m .5346 .83502 L .53788 .83269 L F
.763 .613 .692 r
.57089 .81945 m .56768 .81929 L .56816 .81669 L F
.763 .612 .691 r
.57089 .81945 m .56936 .82198 L .56768 .81929 L F
.393 .423 .773 r
.4567 .7375 m .459 .73915 L .4574 .73906 L F
.577 .536 .773 r
.459 .73915 m .45778 .74224 L .4574 .73906 L F
.376 .136 .417 r
.52406 .87216 m .52455 .86975 L .52631 .86952 L F
.825 .707 .734 r
.56832 .80124 m .56474 .80277 L .56679 .80021 L F
.56832 .80124 m .56746 .80358 L .56474 .80277 L F
.248 0 0 r
.40209 .7898 m .40055 .79122 L .39851 .79183 L F
.319 0 0 r
.40381 .7896 m .40055 .79122 L .40209 .7898 L F
.152 0 0 r
.38178 .75108 m .38099 .75109 L .3784 .7507 L F
.283 0 0 r
.38387 .75158 m .38099 .75109 L .38178 .75108 L F
.648 .428 .571 r
.36938 .7557 m .36923 .75793 L .36664 .75798 L F
.508 .35 .602 r
.37114 .75275 m .37128 .75534 L .36938 .7557 L F
.322 .087 .394 r
.37128 .75534 m .36923 .75793 L .36938 .7557 L F
.769 .686 .772 r
.68858 .74695 m .6917 .74515 L .69032 .7442 L F
.422 .468 .803 r
.68852 .59744 m .6869 .59915 L .68652 .59749 L F
.68852 .59744 m .68956 .6005 L .6869 .59915 L F
.467 .187 .405 r
.47014 .85174 m .4724 .85141 L .4725 .84935 L F
.31 .311 .699 r
.4721 .84547 m .4725 .84935 L .47396 .84748 L F
.608 .499 .703 r
.4724 .85141 m .47396 .84748 L .4725 .84935 L F
.558 .23 .369 r
.42195 .78141 m .41805 .78349 L .41909 .78171 L F
.477 .504 .807 r
.66954 .72082 m .67062 .71774 L .66904 .71748 L F
.66954 .72082 m .67165 .72045 L .67062 .71774 L F
.444 .316 .611 r
.67166 .72283 m .67165 .72045 L .66954 .72082 L F
.4 .313 .641 r
.67006 .72342 m .67166 .72283 L .66954 .72082 L F
0 0 0 r
.64462 .63676 m .64564 .63607 L .64337 .63756 L F
.334 .459 .838 r
.64564 .63607 m .6466 .63457 L .64427 .63328 L F
.511 .36 .612 r
.64462 .63676 m .6466 .63457 L .64564 .63607 L F
.417 .666 .964 r
.32298 .67258 m .3239 .67327 L .32493 .67265 L F
0 0 .304 r
.67828 .62883 m .67751 .6278 L .67832 .62654 L F
.67828 .62883 m .67744 .63007 L .67751 .6278 L F
.254 0 .071 r
.3858 .79789 m .38896 .7953 L .38755 .79709 L F
.194 0 0 r
.38935 .79649 m .38896 .7953 L .3909 .79471 L F
.38935 .79649 m .38755 .79709 L .38896 .7953 L F
.913 .522 .252 r
.49195 .88088 m .49342 .8842 L .49411 .8828 L F
.764 .68 .769 r
.49471 .88218 m .4959 .88512 L .49411 .8828 L F
0 0 0 r
.49411 .8828 m .49342 .8842 L .49471 .88218 L F
.697 .566 .704 r
.33996 .78716 m .34057 .79057 L .33797 .79016 L F
.452 .76 .995 r
.58705 .84061 m .59054 .84139 L .58921 .8404 L F
.611 .827 .983 r
.58921 .8404 m .59054 .84139 L .59258 .8407 L F
.403 .266 .579 r
.33217 .68868 m .334 .69053 L .33454 .68781 L F
.33217 .68868 m .33193 .69152 L .334 .69053 L F
.739 .911 .952 r
.38893 .78197 m .3859 .7825 L .38761 .78107 L F
.401 .638 .952 r
.38904 .78 m .38893 .78197 L .38761 .78107 L F
.38904 .78 m .39072 .78207 L .38893 .78197 L F
.522 .244 .434 r
.43101 .77855 m .42928 .77701 L .43155 .777 L F
.43101 .77855 m .42892 .77888 L .42928 .77701 L F
.413 0 0 r
.42111 .77063 m .42334 .77053 L .42477 .76919 L F
.431 .013 .143 r
.42334 .77053 m .4268 .76855 L .42477 .76919 L F
.558 .481 .724 r
.33406 .68369 m .33461 .68654 L .33647 .68572 L F
.525 .378 .624 r
.33454 .68781 m .33647 .68572 L .33461 .68654 L F
0 0 .27 r
.48006 .88287 m .48067 .88617 L .4805 .88473 L F
0 .315 .804 r
.48067 .88617 m .48124 .88567 L .4805 .88473 L F
.48067 .88617 m .48175 .88684 L .48124 .88567 L F
.26 .712 .956 r
.43703 .72828 m .44032 .72885 L .43826 .72906 L F
0 0 0 r
.36115 .80693 m .36086 .80707 L .35899 .8076 L F
.36115 .80693 m .36317 .80622 L .36086 .80707 L F
.583 .516 .746 r
.34984 .6702 m .34791 .67074 L .34705 .66739 L F
.464 .556 .865 r
.35068 .67226 m .34791 .67074 L .34984 .6702 L F
.859 .987 .846 r
.67453 .60387 m .67218 .60648 L .67314 .60454 L F
.701 .595 .735 r
.67453 .60387 m .67591 .60697 L .67218 .60648 L F
.911 .787 .712 r
.67591 .60697 m .67408 .60873 L .67218 .60648 L F
0 0 .486 r
.67218 .60648 m .67319 .60759 L .67314 .60454 L F
.67218 .60648 m .67408 .60873 L .67319 .60759 L F
.498 .419 .697 r
.45849 .73672 m .4567 .7375 L .45585 .73554 L F
.45849 .73672 m .459 .73915 L .4567 .7375 L F
.745 .618 .718 r
.59227 .82674 m .589 .82491 L .58933 .82626 L F
.59227 .82674 m .59227 .82474 L .589 .82491 L F
.65 .354 .455 r
.58943 .82946 m .59227 .82674 L .58933 .82626 L F
.58943 .82946 m .59247 .82916 L .59227 .82674 L F
.296 .25 .636 r
.59227 .82674 m .59332 .82896 L .59227 .82474 L F
.805 .473 .428 r
.59227 .82674 m .59247 .82916 L .59332 .82896 L F
.935 .641 .458 r
.56746 .80358 m .56616 .80496 L .56474 .80277 L F
.56746 .80358 m .56782 .80577 L .56616 .80496 L F
.918 .734 .637 r
.54785 .84031 m .54892 .84335 L .5494 .84081 L F
.611 .528 .736 r
.3419 .78466 m .33996 .78716 L .33971 .78539 L F
.625 .548 .748 r
.34208 .78681 m .33996 .78716 L .3419 .78466 L F
.552 .439 .678 r
.34208 .78681 m .34057 .79057 L .33996 .78716 L F
.841 .713 .722 r
.55035 .79764 m .55262 .79547 L .55263 .79801 L F
.692 .567 .709 r
.5548 .79281 m .55651 .79702 L .55262 .79547 L F
.767 .681 .768 r
.55651 .79702 m .55263 .79801 L .55262 .79547 L F
.324 .014 .276 r
.3448 .69882 m .34299 .69956 L .34552 .69731 L F
.381 .07 .307 r
.3468 .69814 m .34552 .69731 L .34724 .69657 L F
.3468 .69814 m .3448 .69882 L .34552 .69731 L F
.573 .491 .724 r
.46002 .74197 m .45821 .74457 L .45778 .74224 L F
.629 .567 .765 r
.46032 .7439 m .45821 .74457 L .46002 .74197 L F
.649 .557 .738 r
.46147 .74732 m .45821 .74457 L .46032 .7439 L F
.978 .783 .573 r
.6415 .59715 m .64253 .59832 L .64205 .60127 L F
.742 .796 .896 r
.64404 .59511 m .64253 .59832 L .6415 .59715 L F
.64404 .59511 m .64519 .59631 L .64253 .59832 L F
.331 0 0 r
.37786 .72759 m .38157 .72629 L .37946 .72651 L F
.767 .681 .768 r
.55651 .79702 m .55594 .79831 L .55263 .79801 L F
.17 0 0 r
.55594 .79831 m .55422 .79822 L .55263 .79801 L F
.643 .534 .715 r
.55849 .79617 m .55594 .79831 L .55651 .79702 L F
.572 .069 .021 r
.55844 .79857 m .55422 .79822 L .55594 .79831 L F
.911 .787 .712 r
.67591 .60697 m .67545 .60908 L .67408 .60873 L F
.509 .213 .4 r
.44206 .77134 m .44122 .77385 L .43908 .77403 L F
.514 .212 .391 r
.44423 .77113 m .44122 .77385 L .44206 .77134 L F
.721 .969 .934 r
.5046 .88764 m .50389 .88905 L .50558 .88792 L F
.625 .866 .988 r
.50255 .88838 m .50389 .88905 L .5046 .88764 L F
.281 0 0 r
.408 .74267 m .40632 .74311 L .40452 .74283 L F
.357 .826 .772 r
.40885 .74215 m .408 .74267 L .41001 .74203 L F
.40885 .74215 m .40632 .74311 L .408 .74267 L F
.338 .644 .966 r
.47409 .88085 m .47609 .88117 L .47499 .87993 L F
.968 .755 .561 r
.67545 .60908 m .67402 .61142 L .67408 .60873 L F
.67545 .60908 m .6753 .61168 L .67402 .61142 L F
.425 .286 .587 r
.33406 .68369 m .33574 .68344 L .33569 .6808 L F
.558 .481 .724 r
.33406 .68369 m .33647 .68572 L .33574 .68344 L F
.487 .26 .495 r
.33858 .70477 m .33756 .70829 L .33601 .70767 L F
.522 .293 .509 r
.34177 .70611 m .33858 .70477 L .34042 .70395 L F
.34177 .70611 m .33756 .70829 L .33858 .70477 L F
.838 .617 .602 r
.50245 .86966 m .49994 .87169 L .49922 .8694 L F
.50245 .86966 m .50235 .87233 L .49994 .87169 L F
.495 .328 .583 r
.50415 .86925 m .50235 .87233 L .50245 .86966 L F
0 0 0 r
.50245 .86966 m .50509 .8675 L .50415 .86925 L F
.613 .612 .825 r
.50563 .85951 m .50644 .85607 L .50452 .85614 L F
.50563 .85951 m .50728 .85835 L .50644 .85607 L F
.518 .356 .6 r
.36081 .68041 m .35871 .68309 L .35896 .68186 L F
.819 .459 .376 r
.50299 .86726 m .50354 .86897 L .50509 .8675 L F
.98 .915 .644 r
.50354 .86897 m .50415 .86925 L .50509 .8675 L F
.577 .536 .773 r
.459 .73915 m .46002 .74197 L .45778 .74224 L F
.851 .651 .631 r
.7169 .72047 m .71785 .71808 L .71529 .71772 L F
.339 .11 .413 r
.34786 .73422 m .34615 .73736 L .34743 .73593 L F
.533 .552 .821 r
.35125 .7364 m .34786 .73422 L .35006 .73386 L F
.601 .392 .57 r
.34743 .73593 m .35006 .73386 L .34786 .73422 L F
.552 .439 .678 r
.34208 .78681 m .34274 .79025 L .34057 .79057 L F
.248 0 .283 r
.51754 .86693 m .51595 .86773 L .51553 .8693 L F
.81 .514 .489 r
.48111 .85858 m .48267 .85939 L .48261 .85689 L F
.593 .339 .501 r
.48261 .85689 m .48267 .85939 L .4847 .85866 L F
.592 .34 .503 r
.48261 .85689 m .4847 .85866 L .48513 .85672 L F
.44 .849 .968 r
.49352 .87481 m .49513 .87509 L .49188 .87556 L F
0 0 .019 r
.49188 .87556 m .49269 .87288 L .49352 .87481 L F
.965 .651 .372 r
.49142 .87728 m .49253 .87778 L .49188 .87556 L F
.644 .472 .636 r
.49513 .87509 m .49253 .87778 L .49188 .87556 L F
.475 .179 .383 r
.68415 .73339 m .68493 .73524 L .68628 .73185 L F
.84 .632 .621 r
.57829 .81123 m .57799 .81358 L .58061 .81347 L F
.846 .692 .691 r
.57799 .81358 m .57931 .8165 L .58061 .81347 L F
.482 .793 .999 r
.36347 .78883 m .3628 .78992 L .3615 .78896 L F
.36347 .78883 m .36485 .78961 L .3628 .78992 L F
.438 .482 .807 r
.36444 .91211 m .36529 .91237 L .36462 .91256 L F
.275 .005 .31 r
.36462 .91256 m .36529 .91237 L .36439 .91329 L F
.539 .131 .217 r
.358 .73525 m .36112 .73419 L .35895 .73447 L F
.652 .862 .979 r
.69886 .71572 m .69569 .71568 L .69745 .71455 L F
.789 .784 .848 r
.70105 .71372 m .69886 .71572 L .69745 .71455 L F
.555 .473 .717 r
.46846 .86735 m .46975 .86418 L .46763 .8643 L F
.46846 .86735 m .47042 .86707 L .46975 .86418 L F
.544 .41 .649 r
.46846 .86735 m .47075 .86945 L .47042 .86707 L F
.518 .409 .67 r
.46881 .86971 m .47075 .86945 L .46846 .86735 L F
.586 .606 .839 r
.47335 .75523 m .47249 .75761 L .47139 .75511 L F
.47335 .75523 m .47468 .75804 L .47249 .75761 L F
.625 .356 .49 r
.47468 .75804 m .47296 .76002 L .47249 .75761 L F
.927 .797 .697 r
.71744 .73028 m .71943 .72934 L .71837 .72869 L F
.71744 .73028 m .71866 .73139 L .71943 .72934 L F
.5 .499 .787 r
.34793 .6638 m .34629 .66542 L .34531 .66245 L F
.521 .493 .766 r
.34793 .6638 m .34705 .66739 L .34629 .66542 L F
.382 0 0 r
.64631 .63136 m .64961 .63038 L .64664 .63048 L F
.397 .232 .538 r
.66254 .62958 m .66084 .63032 L .66089 .63282 L F
0 0 .151 r
.66348 .61993 m .66365 .6203 L .66373 .61841 L F
.66348 .61993 m .66373 .62176 L .66365 .6203 L F
.865 .993 .749 r
.68398 .74088 m .68365 .74229 L .68175 .74389 L F
.202 .72 .69 r
.36692 .80479 m .36876 .80429 L .37081 .8037 L F
.005 .254 .759 r
.68246 .61714 m .68441 .61879 L .6836 .61961 L F
0 .217 .732 r
.68441 .61879 m .68549 .62148 L .6836 .61961 L F
.492 .026 .076 r
.69982 .70096 m .70299 .70019 L .70084 .69933 L F
.391 .174 .461 r
.43688 .7609 m .43841 .76244 L .43883 .76065 L F
.43688 .7609 m .43657 .76308 L .43841 .76244 L F
.615 .542 .75 r
.3419 .78466 m .33971 .78539 L .33864 .78201 L F
.436 .319 .622 r
.32038 .71023 m .32195 .70923 L .32259 .708 L F
.32038 .71023 m .32118 .70996 L .32195 .70923 L F
.221 0 .133 r
.3202 .71055 m .32118 .70996 L .32038 .71023 L F
.527 .907 .949 r
.68884 .70838 m .68408 .70934 L .68815 .70779 L F
.514 .678 .939 r
.69009 .70677 m .68884 .70838 L .68815 .70779 L F
.69009 .70677 m .69094 .70829 L .68884 .70838 L F
.022 .415 .86 r
.70299 .70019 m .70494 .70123 L .70439 .70175 L F
.097 .527 .909 r
.70494 .70123 m .70668 .70245 L .70439 .70175 L F
.067 .618 .827 r
.31561 .67495 m .31739 .67504 L .31399 .67463 L F
.245 0 0 r
.65064 .64846 m .64983 .64962 L .64804 .64964 L F
.166 0 0 r
.65064 .64846 m .65238 .64842 L .64983 .64962 L F
.608 .824 .983 r
.36839 .88287 m .36711 .88372 L .36481 .8826 L F
.413 .168 .43 r
.34299 .69956 m .34263 .70167 L .34063 .70213 L F
.49 .234 .454 r
.34439 .70107 m .34299 .69956 L .3448 .69882 L F
.34439 .70107 m .34263 .70167 L .34299 .69956 L F
.692 .398 .472 r
.62373 .6516 m .62567 .65159 L .62598 .65376 L F
.651 .378 .494 r
.62567 .65159 m .63017 .65354 L .62598 .65376 L F
.62567 .65159 m .62926 .65142 L .63017 .65354 L F
.171 0 0 r
.39655 .7926 m .39497 .79369 L .393 .79413 L F
.077 0 0 r
.39703 .7931 m .39655 .7926 L .39851 .79183 L F
.39703 .7931 m .39497 .79369 L .39655 .7926 L F
.489 .741 .984 r
.50561 .88223 m .50686 .88257 L .50695 .88339 L F
.16 0 0 r
.50905 .88317 m .50798 .88292 L .50695 .88339 L F
.489 .741 .984 r
.50686 .88257 m .50905 .88317 L .50695 .88339 L F
.219 0 .172 r
.50798 .88292 m .50702 .88405 L .50695 .88339 L F
.50702 .88405 m .5039 .88776 L .50695 .88339 L F
.16 0 0 r
.50905 .88317 m .51026 .88335 L .50798 .88292 L F
.59 .389 .578 r
.44643 .75774 m .44893 .7551 L .44685 .7557 L F
.53 .167 .295 r
.43852 .77579 m .43619 .77601 L .4369 .77444 L F
.489 .18 .369 r
.43908 .77403 m .43852 .77579 L .4369 .77444 L F
.553 .919 .947 r
.5074 .88731 m .51163 .8863 L .51033 .88587 L F
.831 .847 .858 r
.51149 .8837 m .51163 .8863 L .51279 .88498 L F
.918 .9 .792 r
.51033 .88587 m .51163 .8863 L .51149 .8837 L F
.574 .345 .531 r
.35696 .76327 m .35827 .76614 L .35415 .76589 L F
.364 .247 .585 r
.3587 .76507 m .35696 .76327 L .35904 .76319 L F
.3587 .76507 m .35827 .76614 L .35696 .76327 L F
.468 .298 .567 r
.33753 .70944 m .33601 .70767 L .33756 .70829 L F
.33753 .70944 m .33607 .70994 L .33601 .70767 L F
.481 .263 .506 r
.34222 .70349 m .34063 .70213 L .34263 .70167 L F
.34222 .70349 m .34042 .70395 L .34063 .70213 L F
.543 .238 .399 r
.45947 .7636 m .45958 .765 L .45694 .76506 L F
.564 .252 .399 r
.45947 .7636 m .46152 .76509 L .45958 .765 L F
.562 .253 .402 r
.46168 .76352 m .46152 .76509 L .45947 .7636 L F
.937 .773 .652 r
.57688 .81061 m .57891 .80912 L .57736 .80832 L F
.57688 .81061 m .57829 .81123 L .57891 .80912 L F
.715 .68 .814 r
.57251 .83979 m .57609 .84044 L .57493 .83774 L F
.525 .507 .779 r
.57609 .84044 m .57729 .83734 L .57493 .83774 L F
.57609 .84044 m .57833 .84053 L .57729 .83734 L F
.927 .901 .779 r
.62668 .64083 m .6239 .64289 L .6255 .6399 L F
.62668 .64083 m .62495 .64376 L .6239 .64289 L F
.233 .643 .959 r
.54267 .84018 m .54098 .8375 L .5431 .83821 L F
.537 .757 .978 r
.32547 .6538 m .32503 .65535 L .3235 .65405 L F
.32547 .6538 m .32705 .65511 L .32503 .65535 L F
.863 .584 .515 r
.56334 .80021 m .56023 .79741 L .56132 .79817 L F
.817 .612 .626 r
.56433 .79829 m .56334 .80021 L .56132 .79817 L F
.482 .259 .498 r
.37336 .75268 m .37128 .75534 L .37114 .75275 L F
.602 .802 .977 r
.35414 .79093 m .35173 .79153 L .35068 .79031 L F
.473 0 0 r
.36384 .91227 m .36529 .91237 L .36444 .91211 L F
.602 .619 .841 r
.63792 .6293 m .6392 .63086 L .63795 .62772 L F
.868 .947 .864 r
.49925 .8831 m .49806 .88467 L .4959 .88512 L F
.401 .379 .72 r
.46881 .86971 m .46932 .87274 L .47082 .87152 L F
.528 .431 .689 r
.46932 .87274 m .47183 .87475 L .47082 .87152 L F
.46932 .87274 m .46992 .87506 L .47183 .87475 L F
.561 .884 .99 r
.35747 .79066 m .35414 .79093 L .3561 .79025 L F
.66 .913 .978 r
.35938 .78975 m .35747 .79066 L .3561 .79025 L F
.622 .456 .637 r
.50991 .87311 m .51158 .87559 L .50963 .87398 L F
.068 .318 .8 r
.51242 .87415 m .50991 .87311 L .50985 .87214 L F
.51242 .87415 m .51234 .87499 L .50991 .87311 L F
0 0 0 r
.66306 .64352 m .65983 .64518 L .66085 .64393 L F
.03 0 0 r
.66085 .64393 m .65983 .64518 L .65784 .64603 L F
.239 .626 .958 r
.64314 .62149 m .64053 .62146 L .64148 .61901 L F
.803 .806 .854 r
.42058 .74361 m .42465 .74277 L .42248 .74241 L F
.42058 .74361 m .4219 .74471 L .42465 .74277 L F
0 0 0 r
.42646 .74212 m .42248 .74241 L .42465 .74277 L F
.762 .62 .701 r
.66028 .60483 m .6582 .60654 L .66016 .60351 L F
.474 .682 .957 r
.67991 .6171 m .68246 .61714 L .68119 .61576 L F
.67991 .6171 m .68246 .61714 L .68119 .61576 L F
0 .212 .652 r
.34353 .65998 m .34278 .65965 L .34112 .6586 L F
.34353 .65998 m .34493 .66101 L .34278 .65965 L F
.388 0 0 r
.39072 .78207 m .39317 .78232 L .39421 .78188 L F
0 0 0 r
.39421 .78188 m .39317 .78232 L .39537 .78181 L F
.711 .27 .202 r
.39121 .78109 m .39537 .78181 L .39317 .78232 L F
.39121 .78109 m .3936 .78278 L .39537 .78181 L F
.333 0 .027 r
.3936 .78278 m .3949 .78206 L .39537 .78181 L F
0 0 0 r
.39421 .78188 m .39537 .78181 L .39586 .78155 L F
.333 0 .027 r
.3949 .78206 m .39711 .78083 L .39537 .78181 L F
0 0 0 r
.39586 .78155 m .39537 .78181 L .39619 .78148 L F
.82 .766 .802 r
.69214 .61572 m .69016 .61796 L .68909 .61695 L F
.69214 .61572 m .68909 .61695 L .69135 .61654 L F
.479 .099 .241 r
.69076 .61647 m .68661 .61512 L .68758 .61475 L F
.455 .06 .201 r
.69056 .61386 m .69076 .61647 L .68758 .61475 L F
.606 .443 .635 r
.4775 .83497 m .47808 .83763 L .48099 .83579 L F
.521 .493 .766 r
.34793 .6638 m .34891 .6671 L .34705 .66739 L F
.583 .516 .746 r
.34984 .6702 m .34705 .66739 L .34891 .6671 L F
.493 .238 .456 r
.35871 .68309 m .3581 .68577 L .35618 .68615 L F
.42 .207 .481 r
.36271 .68076 m .3623 .6849 L .35918 .68361 L F
.36271 .68076 m .35918 .68361 L .3609 .68285 L F
.518 .356 .6 r
.36081 .68041 m .3609 .68285 L .35871 .68309 L F
.759 .493 .531 r
.35918 .68361 m .35871 .68309 L .3609 .68285 L F
.35918 .68361 m .3581 .68577 L .35871 .68309 L F
.247 .545 .926 r
.41849 .74301 m .41943 .74206 L .4174 .74207 L F
.41849 .74301 m .42058 .74361 L .41943 .74206 L F
.58 .626 .862 r
.41849 .74301 m .4219 .74471 L .42058 .74361 L F
.615 .542 .75 r
.3419 .78466 m .33864 .78201 L .3408 .78137 L F
.634 .473 .647 r
.344 .77969 m .34382 .78284 L .3408 .78137 L F
.63 .485 .667 r
.34398 .78428 m .3408 .78137 L .34382 .78284 L F
.34398 .78428 m .3419 .78466 L .3408 .78137 L F
.379 .142 .424 r
.33007 .75539 m .33181 .75475 L .33238 .7524 L F
.574 .385 .587 r
.33238 .7524 m .33434 .75211 L .33451 .75019 L F
.509 .246 .452 r
.33181 .75475 m .33434 .75211 L .33238 .7524 L F
.583 .383 .576 r
.65936 .62492 m .66204 .62503 L .6617 .62227 L F
.461 .297 .572 r
.66459 .62219 m .6617 .62227 L .66373 .62176 L F
.66459 .62219 m .66204 .62503 L .6617 .62227 L F
.466 .476 .784 r
.6617 .62227 m .66459 .62219 L .66373 .62176 L F
.861 .465 .29 r
.54599 .83932 m .54727 .83874 L .5457 .83741 L F
.54599 .83932 m .54785 .84031 L .54727 .83874 L F
.611 .415 .592 r
.39363 .74412 m .39174 .74569 L .39159 .7444 L F
.952 .743 .583 r
.53587 .8242 m .53707 .82636 L .53759 .82514 L F
.78 .332 .182 r
.68415 .73339 m .68502 .73566 L .68493 .73524 L F
.057 0 0 r
.68214 .71651 m .67813 .7186 L .68169 .71578 L F
.658 .786 .943 r
.6836 .71465 m .68214 .71651 L .68169 .71578 L F
.6836 .71465 m .68496 .71569 L .68214 .71651 L F
.781 .661 .731 r
.68487 .74672 m .68858 .74695 L .6874 .74425 L F
.68487 .74672 m .68638 .74765 L .68858 .74695 L F
.805 .798 .845 r
.6874 .74425 m .68858 .74695 L .69032 .7442 L F
.73 .621 .737 r
.71804 .62038 m .71631 .62139 L .71477 .61869 L F
.544 .543 .804 r
.71659 .61968 m .71659 .6197 L .71477 .61869 L F
.398 0 0 r
.71659 .6197 m .71745 .62021 L .71477 .61869 L F
.73 .621 .737 r
.71767 .62027 m .71477 .61869 L .71745 .62021 L F
.71804 .62038 m .71604 .61935 L .71767 .62027 L F
.71604 .61935 m .7149 .61876 L .71658 .61968 L F
.71604 .61935 m .71658 .61968 L .71767 .62027 L F
.59 .548 .776 r
.7166 .61969 m .71745 .62021 L .71659 .6197 L F
.71869 .61652 m .71745 .62021 L .7166 .61969 L F
.533 .535 .803 r
.71869 .61652 m .7166 .61969 L .71564 .61505 L F
.7166 .61969 m .71659 .6197 L .71659 .61968 L F
.7166 .61969 m .71659 .61968 L .71564 .61505 L F
.73 .621 .737 r
.7149 .61876 m .71477 .61869 L .71659 .61968 L F
.7149 .61876 m .71659 .61968 L .71767 .62027 L F
.544 .543 .804 r
.71564 .61505 m .71659 .61968 L .71477 .61869 L F
.162 .694 .852 r
.71745 .62021 m .71771 .62022 L .71804 .62038 L F
.805 .983 .708 r
.71927 .61964 m .7185 .62061 L .71804 .62038 L F
.589 .418 .618 r
.71927 .61964 m .71961 .62205 L .71712 .62233 L F
.008 .008 .506 r
.72077 .6203 m .7194 .62058 L .71927 .61964 L F
.72117 .61984 m .72041 .62038 L .72124 .62037 L F
.72116 .61974 m .72105 .61983 L .72117 .61984 L F
.72105 .61983 m .72041 .62038 L .72117 .61984 L F
.162 .694 .852 r
.72057 .62034 m .72078 .62029 L .72124 .62037 L F
.008 .008 .506 r
.72078 .6203 m .72057 .62034 L .72077 .6203 L F
.72078 .6203 m .71961 .62205 L .7194 .62058 L F
.162 .694 .852 r
.72057 .62034 m .72073 .62035 L .72041 .62038 L F
.72073 .62035 m .72124 .62037 L .7207 .62038 L F
.72073 .62035 m .7207 .62038 L .72041 .62038 L F
.383 .332 .677 r
.72078 .6203 m .71887 .62332 L .71961 .62205 L F
.585 .894 .988 r
.72202 .6198 m .72116 .61974 L .72124 .62037 L F
.879 .651 .59 r
.72202 .6198 m .72183 .62281 L .72122 .62001 L F
.72202 .6198 m .72122 .62001 L .72116 .61974 L F
0 0 .101 r
.72205 .6202 m .72203 .61992 L .7213 .61999 L F
.584 .929 .953 r
.72124 .62037 m .7206 .62026 L .72202 .6198 L F
.383 .332 .677 r
.72105 .6199 m .72107 .61996 L .72098 .62002 L F
.72105 .6199 m .72098 .62002 L .72107 .61986 L F
.584 .929 .953 r
.72087 .62018 m .7211 .61994 L .72202 .6198 L F
.383 .332 .677 r
.72107 .61986 m .72096 .62005 L .7208 .62027 L F
.008 .008 .506 r
.72116 .61974 m .72078 .6203 L .72059 .62022 L F
.584 .929 .953 r
.7206 .62026 m .72098 .62002 L .72087 .62018 L F
.72098 .62002 m .7211 .61994 L .72087 .62018 L F
.383 .332 .677 r
.7208 .62027 m .72083 .62025 L .72078 .6203 L F
.72096 .62005 m .72083 .62025 L .7208 .62027 L F
.72098 .62002 m .72083 .62025 L .72096 .62005 L F
.72098 .62002 m .72096 .62005 L .72107 .61986 L F
.008 .008 .506 r
.72116 .61974 m .71804 .62038 L .72041 .62038 L F
.72116 .61974 m .72059 .62022 L .71927 .61964 L F
.584 .929 .953 r
.7206 .62026 m .71982 .62013 L .72103 .61995 L F
.72098 .62002 m .72103 .61995 L .7211 .61994 L F
.7206 .62026 m .72103 .61995 L .72098 .62002 L F
.383 .332 .677 r
.72098 .62002 m .72183 .62281 L .71887 .62332 L F
.72107 .61996 m .72183 .62281 L .72098 .62002 L F
.72116 .61974 m .72122 .62001 L .72105 .6199 L F
.72122 .62001 m .72183 .62281 L .72105 .6199 L F
0 0 .101 r
.72111 .62004 m .72122 .62001 L .72099 .62002 L F
.72122 .62001 m .7213 .61999 L .7212 .62 L F
.72122 .62001 m .7212 .62 L .72099 .62002 L F
.72205 .6202 m .7213 .61999 L .72111 .62004 L F
.72091 .62016 m .72099 .62002 L .71982 .62013 L F
.72205 .6202 m .72099 .62002 L .72091 .62016 L F
.383 .332 .677 r
.72116 .61974 m .72105 .6199 L .72107 .61986 L F
.72083 .62025 m .71887 .62332 L .72078 .6203 L F
0 0 .101 r
.72217 .62151 m .72183 .62281 L .72202 .6198 L F
.72217 .62151 m .72205 .6202 L .71982 .62013 L F
.72203 .61992 m .72202 .6198 L .72152 .61987 L F
.72203 .61992 m .72152 .61987 L .71982 .62013 L F
.008 .008 .506 r
.72057 .62034 m .7194 .62058 L .72077 .6203 L F
.162 .694 .852 r
.71745 .62021 m .71982 .62013 L .72078 .62029 L F
.71745 .62021 m .72078 .62029 L .72057 .62034 L F
.71771 .62022 m .72057 .62034 L .71804 .62038 L F
.72057 .62034 m .72041 .62038 L .71804 .62038 L F
.805 .983 .708 r
.7185 .62061 m .71712 .62233 L .71804 .62038 L F
.784 .663 .729 r
.71887 .62332 m .71712 .62233 L .71961 .62205 L F
.71887 .62332 m .71804 .62038 L .71712 .62233 L F
.244 0 0 r
.48924 .88906 m .49277 .89026 L .4916 .89037 L F
.383 .168 .458 r
.6803 .72077 m .68001 .72323 L .67896 .72242 L F
.174 .192 .638 r
.68001 .72323 m .68039 .72493 L .67896 .72242 L F
.68039 .72493 m .6803 .72509 L .67896 .72242 L F
.21 .216 .647 r
.68083 .72425 m .68054 .72557 L .68001 .72323 L F
.624 .632 .838 r
.6785 .72642 m .68077 .72431 L .67706 .72602 L F
.68077 .72431 m .68083 .72425 L .68079 .72427 L F
.68077 .72431 m .68079 .72427 L .67706 .72602 L F
.174 .192 .638 r
.68039 .72493 m .68054 .72557 L .6803 .72509 L F
0 0 0 r
.36791 .78939 m .36892 .7891 L .37071 .78787 L F
.524 .878 .642 r
.37071 .78787 m .37057 .78777 L .37245 .78714 L F
.37071 .78787 m .36892 .7891 L .37057 .78777 L F
.551 .521 .775 r
.56154 .81202 m .56388 .81154 L .56256 .80807 L F
.782 .762 .836 r
.69142 .72316 m .68916 .72564 L .69227 .72593 L F
.987 .718 .406 r
.68916 .72564 m .69024 .72866 L .69227 .72593 L F
.772 .757 .84 r
.69142 .72316 m .69227 .72593 L .69457 .72338 L F
.7 .819 .939 r
.41207 .74182 m .41358 .74293 L .41547 .7419 L F
.743 .475 .525 r
.62034 .65127 m .62373 .6516 L .62374 .65339 L F
.658 .406 .527 r
.62373 .6516 m .62598 .65376 L .62374 .65339 L F
.462 .176 .393 r
.50452 .85614 m .50786 .85467 L .505 .8558 L F
.523 .603 .875 r
.36339 .67517 m .36273 .67786 L .36249 .67527 L F
.36339 .67517 m .36456 .67703 L .36273 .67786 L F
.513 .372 .627 r
.36456 .67703 m .36223 .6799 L .36273 .67786 L F
.308 0 .118 r
.40381 .7896 m .40665 .78791 L .40561 .789 L F
.107 0 0 r
.40858 .78738 m .40561 .789 L .40665 .78791 L F
.486 .128 .283 r
.55812 .78702 m .56001 .78675 L .56116 .78482 L F
.664 .324 .388 r
.56116 .78482 m .56001 .78675 L .56336 .78673 L F
.24 0 0 r
.64797 .61362 m .647 .61467 L .6451 .61493 L F
.115 .08 .537 r
.64944 .61041 m .64797 .61362 L .64912 .61018 L F
.64944 .61041 m .64977 .61294 L .64797 .61362 L F
0 0 0 r
.64797 .61362 m .64977 .61294 L .647 .61467 L F
.237 .425 .844 r
.56826 .82999 m .56936 .82909 L .56782 .82852 L F
.172 .308 .762 r
.56826 .82999 m .5705 .83205 L .56936 .82909 L F
.466 .356 .644 r
.56866 .83246 m .5705 .83205 L .56826 .82999 L F
.582 .252 .376 r
.46714 .76114 m .46705 .7625 L .46587 .76206 L F
.619 .283 .38 r
.46714 .76114 m .4691 .76277 L .46705 .7625 L F
.589 .296 .44 r
.46956 .76096 m .4691 .76277 L .46714 .76114 L F
.859 .987 .846 r
.67453 .60387 m .67314 .60454 L .67379 .60333 L F
.951 .647 .422 r
.67314 .60454 m .67319 .60759 L .67198 .60719 L F
.74 .412 .427 r
.67104 .60441 m .67379 .60333 L .67314 .60454 L F
.951 .647 .422 r
.67314 .60454 m .67198 .60719 L .67104 .60441 L F
.74 .412 .427 r
.67104 .60441 m .6723 .60635 L .67379 .60333 L F
.681 .799 .339 r
.67379 .60333 m .6723 .60635 L .67241 .60612 L F
.67379 .60333 m .67241 .60612 L .67453 .60161 L F
1 .832 .526 r
.67434 .60223 m .67379 .60333 L .67416 .60072 L F
.67453 .60387 m .67379 .60333 L .67434 .60223 L F
.817 .612 .626 r
.56433 .79829 m .56457 .80055 L .56334 .80021 L F
.668 .504 .653 r
.56679 .80021 m .56433 .79829 L .5672 .79879 L F
.56679 .80021 m .56457 .80055 L .56433 .79829 L F
0 0 .256 r
.57802 .80019 m .57838 .80296 L .57805 .80108 L F
0 0 0 r
.48565 .86849 m .48566 .86749 L .48579 .86644 L F
.48565 .86849 m .48494 .86968 L .48566 .86749 L F
.941 .64 .441 r
.49241 .86467 m .49107 .86637 L .48923 .86405 L F
.49241 .86467 m .4925 .86681 L .49107 .86637 L F
.293 .545 .919 r
.56513 .82741 m .56782 .82852 L .56607 .8263 L F
.619 .554 .759 r
.46368 .74694 m .46147 .74732 L .46032 .7439 L F
.418 .1 .317 r
.43193 .76556 m .43392 .76515 L .43453 .76352 L F
.457 .137 .334 r
.43453 .76352 m .43607 .76476 L .43657 .76308 L F
.43453 .76352 m .43392 .76515 L .43607 .76476 L F
.485 .291 .543 r
.33434 .75211 m .33641 .74967 L .33451 .75019 L F
.887 .985 .716 r
.48111 .85858 m .48057 .86023 L .48267 .85939 L F
.525 .378 .624 r
.33454 .68781 m .33646 .68786 L .33647 .68572 L F
.499 .226 .431 r
.334 .69053 m .33646 .68786 L .33454 .68781 L F
.709 .172 0 r
.54213 .80911 m .54432 .80846 L .54137 .80829 L F
.008 .008 .506 r
.72116 .61974 m .71927 .61964 L .71804 .62038 L F
0 0 .093 r
.66457 .62668 m .66324 .62794 L .66254 .62958 L F
0 .189 .671 r
.67349 .70209 m .67681 .70479 L .67571 .7017 L F
.77 .343 .237 r
.50628 .87242 m .50963 .87398 L .50654 .87504 L F
.716 .414 .466 r
.50963 .87398 m .50773 .87704 L .50654 .87504 L F
.747 .394 .384 r
.50963 .87398 m .51047 .87717 L .50773 .87704 L F
.50963 .87398 m .51158 .87559 L .51047 .87717 L F
.644 .098 0 r
.71223 .73065 m .70897 .72803 L .7095 .72918 L F
.632 .348 .469 r
.30685 .65359 m .30896 .65348 L .30743 .65158 L F
.757 .652 .746 r
.47808 .83763 m .47921 .84075 L .48135 .83802 L F
.47808 .83763 m .48135 .83802 L .48003 .83736 L F
.606 .422 .607 r
.46763 .8643 m .46975 .86418 L .46991 .86194 L F
.57 .399 .61 r
.46975 .86418 m .4723 .8614 L .46991 .86194 L F
.75 .736 .839 r
.54282 .84654 m .54461 .84859 L .5413 .84835 L F
.717 .33 .316 r
.5413 .84835 m .54461 .84859 L .54348 .85044 L F
.282 .543 .92 r
.54516 .84752 m .54461 .84859 L .54282 .84654 L F
.717 .33 .316 r
.5413 .84835 m .54348 .85044 L .54191 .85146 L F
.32 .545 .912 r
.54452 .84639 m .54559 .8477 L .54282 .84654 L F
.801 .726 .782 r
.54348 .85044 m .54449 .84651 L .5421 .84962 L F
.54449 .84651 m .54452 .84639 L .54446 .84647 L F
.54449 .84651 m .54446 .84647 L .5421 .84962 L F
.282 .543 .92 r
.54559 .8477 m .5454 .84788 L .54516 .84752 L F
.5454 .84788 m .54461 .84859 L .54516 .84752 L F
0 0 0 r
.54348 .85044 m .54461 .84859 L .54559 .8477 L F
.695 .82 .942 r
.53328 .82657 m .53455 .8275 L .53707 .82636 L F
.507 .203 .386 r
.41372 .77374 m .41582 .7735 L .4167 .77093 L F
.554 .25 .406 r
.4167 .77093 m .41858 .77218 L .41881 .77077 L F
.4167 .77093 m .41582 .7735 L .41858 .77218 L F
.57 .18 .264 r
.56336 .78673 m .56578 .78687 L .56649 .78509 L F
.546 .156 .254 r
.56649 .78509 m .56578 .78687 L .56897 .78615 L F
.251 .304 .723 r
.47918 .84756 m .47797 .84863 L .4773 .84553 L F
.117 .141 .609 r
.47955 .85013 m .47797 .84863 L .47918 .84756 L F
.47955 .85013 m .47864 .85114 L .47797 .84863 L F
0 0 .443 r
.64814 .60076 m .64756 .60646 L .64718 .60361 L F
0 0 0 r
.67085 .64056 m .66825 .6422 L .66891 .64156 L F
.317 .784 .936 r
.42842 .72656 m .43049 .72628 L .43139 .72665 L F
.065 .489 .893 r
.43254 .72632 m .43139 .72665 L .43049 .72628 L F
.43254 .72632 m .43379 .72743 L .43139 .72665 L F
.817 .584 .587 r
.56936 .82198 m .56644 .81912 L .56768 .81929 L F
.56936 .82198 m .56701 .8222 L .56644 .81912 L F
.707 .651 .791 r
.56816 .81669 m .56511 .81688 L .56709 .81384 L F
.837 .575 .543 r
.56644 .81912 m .56511 .81688 L .56816 .81669 L F
.732 .583 .688 r
.56816 .81669 m .56768 .81929 L .56644 .81912 L F
.361 .465 .831 r
.6775 .61601 m .67597 .61341 L .67734 .61431 L F
.614 .677 .887 r
.34709 .78934 m .3463 .79198 L .34489 .78981 L F
.34709 .78934 m .34832 .79155 L .3463 .79198 L F
.893 .974 .822 r
.62495 .64376 m .62294 .6449 L .6239 .64289 L F
.62495 .64376 m .62269 .64654 L .62294 .6449 L F
.526 .845 .546 r
.56291 .81898 m .5634 .81842 L .56511 .81688 L F
.251 .46 .868 r
.5634 .81842 m .56507 .81768 L .56389 .81788 L F
.88 .967 .845 r
.5634 .81842 m .56496 .81528 L .56559 .81494 L F
.5634 .81842 m .56246 .81811 L .56496 .81528 L F
.251 .46 .868 r
.5634 .81842 m .56389 .81788 L .56246 .81811 L F
.526 .845 .546 r
.56272 .81916 m .5634 .81842 L .56291 .81898 L F
.839 .986 .708 r
.56709 .81384 m .56511 .81688 L .56559 .81494 L F
.836 .965 .638 r
.56511 .81688 m .5634 .81842 L .56559 .81494 L F
.837 .575 .543 r
.56644 .81912 m .56463 .81923 L .56511 .81688 L F
.55 .255 .42 r
.64217 .64016 m .64024 .6387 L .63991 .63959 L F
.64217 .64016 m .64337 .63756 L .64024 .6387 L F
.238 .704 .946 r
.40866 .7233 m .41067 .72336 L .41204 .72387 L F
.315 0 0 r
.41067 .72336 m .41408 .72305 L .41204 .72387 L F
.346 0 0 r
.36485 .78961 m .36698 .78982 L .36791 .78939 L F
0 0 0 r
.36791 .78939 m .36698 .78982 L .36892 .7891 L F
.576 .689 .918 r
.44908 .73157 m .447 .73194 L .4459 .73039 L F
.563 .878 .992 r
.31399 .67463 m .31315 .6749 L .31263 .67552 L F
.611 .946 .934 r
.31263 .67552 m .31315 .6749 L .31193 .67553 L F
.551 .436 .676 r
.69226 .61103 m .69197 .61402 L .69056 .61386 L F
.615 .179 .19 r
.69214 .61572 m .69056 .61386 L .69197 .61402 L F
.69214 .61572 m .69076 .61647 L .69056 .61386 L F
.565 .266 .42 r
.45433 .76649 m .45401 .76823 L .4518 .7683 L F
.462 .175 .391 r
.45606 .7678 m .45433 .76649 L .45694 .76506 L F
.45606 .7678 m .45401 .76823 L .45433 .76649 L F
.539 .603 .866 r
.56919 .83536 m .57276 .83793 L .5717 .83539 L F
.57 .543 .786 r
.57276 .83793 m .57384 .8346 L .5717 .83539 L F
.57276 .83793 m .57493 .83774 L .57384 .8346 L F
.556 .403 .628 r
.57276 .83793 m .57251 .83979 L .57493 .83774 L F
.544 .384 .615 r
.32988 .75768 m .33181 .75475 L .33007 .75539 L F
.527 .338 .568 r
.35023 .77375 m .34773 .77598 L .34797 .77422 L F
.865 .77 .755 r
.62269 .64654 m .61945 .64836 L .62096 .64701 L F
.62269 .64654 m .62107 .64929 L .61945 .64836 L F
.872 .962 .856 r
.62269 .64654 m .62096 .64701 L .62294 .6449 L F
.805 .693 .741 r
.67571 .7017 m .67681 .70479 L .67813 .7017 L F
.644 .472 .636 r
.49513 .87509 m .49535 .87807 L .49253 .87778 L F
.683 .155 0 r
.49477 .87537 m .49513 .87509 L .49352 .87481 L F
.461 .334 .621 r
.49702 .87717 m .49535 .87807 L .49513 .87509 L F
.632 .334 .448 r
.49253 .87778 m .49535 .87807 L .4948 .87987 L F
0 0 .055 r
.4936 .87871 m .49477 .87902 L .49592 .87661 L F
.683 .155 0 r
.49573 .87614 m .49702 .87717 L .49544 .87544 L F
.365 .623 .951 r
.49896 .87706 m .49702 .87717 L .49657 .87681 L F
.49779 .87659 m .49657 .87681 L .49477 .87537 L F
.49896 .87706 m .49657 .87681 L .49779 .87659 L F
.49896 .87706 m .49843 .87684 L .4982 .87696 L F
.49843 .87684 m .49576 .87577 L .49607 .87592 L F
.861 .812 .8 r
.49702 .87717 m .4948 .87987 L .49535 .87807 L F
.49702 .87717 m .49623 .87975 L .4948 .87987 L F
.514 .495 .773 r
.49896 .87706 m .49623 .87975 L .49702 .87717 L F
.49896 .87706 m .49961 .87946 L .49623 .87975 L F
.615 .316 .44 r
.49647 .87612 m .49477 .87902 L .49836 .8784 L F
.49627 .87587 m .49621 .876 L .49647 .87612 L F
.49621 .876 m .49477 .87902 L .49647 .87612 L F
.49647 .87612 m .49836 .8784 L .4982 .87696 L F
.365 .623 .951 r
.49825 .87694 m .49534 .87564 L .4982 .87696 L F
.49834 .87689 m .49633 .87605 L .49825 .87694 L F
.49633 .87605 m .49534 .87564 L .49825 .87694 L F
.49843 .87684 m .49591 .87586 L .49834 .87689 L F
.49591 .87586 m .49534 .87564 L .49834 .87689 L F
.647 .459 .616 r
.4925 .8758 m .49591 .87586 L .49477 .87537 L F
.683 .155 0 r
.49573 .87614 m .49544 .87544 L .49513 .87509 L F
.365 .623 .951 r
.49576 .87577 m .49477 .87537 L .49607 .87592 L F
.683 .155 0 r
.49477 .87537 m .49573 .87614 L .49513 .87509 L F
.647 .459 .616 r
.49591 .87586 m .49627 .87587 L .49477 .87537 L F
.615 .316 .44 r
.49627 .87587 m .49647 .87612 L .4982 .87696 L F
.365 .623 .951 r
.49607 .87592 m .49477 .87537 L .49534 .87564 L F
0 0 .055 r
.4936 .87871 m .49618 .87596 L .4925 .8758 L F
.49618 .87596 m .49627 .87587 L .49591 .87586 L F
.49618 .87596 m .49591 .87586 L .4925 .8758 L F
.936 .951 .766 r
.50106 .87421 m .49896 .87706 L .4982 .87696 L F
.49959 .87626 m .4982 .87696 L .4994 .87652 L F
.50106 .87421 m .49878 .8764 L .49959 .87626 L F
.49878 .8764 m .4982 .87696 L .49959 .87626 L F
0 0 .055 r
.49581 .87635 m .49592 .87661 L .49627 .87587 L F
.4936 .87871 m .49592 .87661 L .49581 .87635 L F
.74 .417 .436 r
.68109 .62483 m .68484 .62542 L .68368 .62577 L F
.427 .365 .685 r
.68567 .62373 m .68368 .62577 L .68484 .62542 L F
.758 .701 .798 r
.68318 .74728 m .68404 .75012 L .68638 .74765 L F
.431 .173 .421 r
.35965 .68714 m .3581 .68577 L .35918 .68361 L F
.479 .198 .408 r
.3623 .6849 m .35965 .68714 L .35918 .68361 L F
.466 .168 .375 r
.35918 .68361 m .35965 .68714 L .3581 .68577 L F
0 0 0 r
.37622 .80124 m .37631 .80162 L .37443 .80217 L F
.37622 .80124 m .37818 .80066 L .37631 .80162 L F
.955 .625 .353 r
.68383 .71002 m .68417 .71247 L .68264 .70989 L F
.946 .617 .372 r
.68383 .71002 m .68513 .71281 L .68417 .71247 L F
.841 .713 .722 r
.55035 .79764 m .54935 .79809 L .55129 .79447 L F
0 0 0 r
.55129 .79447 m .54935 .79809 L .55083 .7966 L F
.026 0 .172 r
.55129 .79447 m .5536 .7918 L .55151 .79243 L F
.412 0 0 r
.48805 .88858 m .48924 .88906 L .4916 .89037 L F
.157 0 .38 r
.68198 .72191 m .6803 .72077 L .68165 .72085 L F
.68198 .72191 m .68001 .72323 L .6803 .72077 L F
.757 .549 .614 r
.67396 .70696 m .67646 .7073 L .67681 .70479 L F
.689 .473 .589 r
.66935 .71207 m .67273 .71284 L .67251 .71015 L F
.618 .372 .523 r
.67481 .71208 m .67251 .71015 L .67273 .71284 L F
.67481 .71208 m .67497 .71002 L .67251 .71015 L F
.67251 .71015 m .67497 .71002 L .67481 .71208 L F
.503 .45 .73 r
.47127 .85735 m .47256 .85343 L .47081 .8535 L F
.47127 .85735 m .4737 .85864 L .47256 .85343 L F
.478 .492 .794 r
.47219 .85916 m .4737 .85864 L .47127 .85735 L F
.557 .637 .886 r
.44486 .74754 m .44619 .74619 L .44384 .74458 L F
.44486 .74754 m .44692 .7472 L .44619 .74619 L F
.545 .451 .699 r
.44486 .74754 m .4452 .74978 L .44692 .7472 L F
.722 .318 .282 r
.57245 .78633 m .57409 .78692 L .57199 .78501 L F
.723 .854 .944 r
.36903 .91137 m .36994 .91238 L .36675 .9125 L F
.36903 .91137 m .36994 .91238 L .36675 .9125 L F
.208 .58 .943 r
.37053 .91167 m .36994 .91238 L .36903 .91137 L F
.36903 .91137 m .36994 .91238 L .37053 .91167 L F
.544 .355 .575 r
.34773 .77598 m .34555 .77911 L .34595 .77676 L F
.598 .708 .921 r
.42282 .72583 m .42079 .72633 L .41959 .72476 L F
.696 .399 .468 r
.62926 .65142 m .63135 .65365 L .63017 .65354 L F
.532 .176 .309 r
.4268 .77921 m .42564 .78143 L .42354 .78134 L F
.41 .052 .243 r
.42782 .78097 m .4268 .77921 L .42892 .77888 L F
.42782 .78097 m .42564 .78143 L .4268 .77921 L F
.215 0 .067 r
.40403 .7767 m .40467 .77799 L .40599 .77616 L F
.40403 .7767 m .40282 .7787 L .40467 .77799 L F
.401 .379 .72 r
.46881 .86971 m .47082 .87152 L .47075 .86945 L F
.789 .784 .848 r
.70105 .71372 m .69745 .71455 L .70029 .71142 L F
.594 .565 .79 r
.70348 .71318 m .70105 .71372 L .70029 .71142 L F
.736 .424 .453 r
.51971 .8692 m .52099 .86696 L .51754 .86693 L F
.606 .272 .377 r
.52364 .86843 m .52099 .86696 L .51971 .8692 L F
.461 .889 .858 r
.3469 .8122 m .34822 .8121 L .35 .81131 L F
.742 .338 .285 r
.43609 .74523 m .4349 .7461 L .43327 .74426 L F
0 0 .069 r
.54756 .80033 m .55035 .79764 L .54929 .80005 L F
.54756 .80033 m .54935 .79809 L .55035 .79764 L F
.576 .365 .557 r
.54929 .80005 m .54746 .80097 L .54756 .80033 L F
0 0 .069 r
.54756 .80033 m .54746 .80097 L .54935 .79809 L F
.382 .229 .546 r
.32671 .70208 m .32813 .70359 L .32867 .70165 L F
.32671 .70208 m .32671 .70457 L .32813 .70359 L F
.171 .708 .788 r
.47469 .85318 m .47412 .85328 L .47741 .85296 L F
.567 .493 .731 r
.47256 .85343 m .47538 .85519 L .47741 .85296 L F
.444 0 0 r
.47741 .85296 m .47623 .85373 L .47469 .85318 L F
.391 .318 .655 r
.47469 .85318 m .47623 .85373 L .47615 .85294 L F
.47469 .85318 m .47615 .85294 L .47573 .84879 L F
.171 .708 .788 r
.47469 .85318 m .47256 .85343 L .47412 .85328 L F
.472 .377 .666 r
.47538 .85519 m .47623 .85373 L .47741 .85296 L F
.788 .621 .673 r
.47921 .87222 m .48261 .86949 L .4792 .86983 L F
.47921 .87222 m .48235 .8725 L .48261 .86949 L F
0 .536 .716 r
.48261 .86949 m .48494 .86968 L .48378 .86957 L F
.478 .492 .794 r
.47219 .85916 m .4739 .85879 L .4737 .85864 L F
.297 .126 .473 r
.4723 .8614 m .4739 .85879 L .47219 .85916 L F
.352 0 .177 r
.31882 .71179 m .32118 .70996 L .3202 .71055 L F
.564 .299 .472 r
.36664 .75798 m .36641 .76007 L .3641 .7602 L F
.651 .374 .487 r
.36664 .75798 m .36877 .76016 L .36641 .76007 L F
.636 .376 .507 r
.36923 .75793 m .36877 .76016 L .36664 .75798 L F
.974 .793 .597 r
.49164 .87886 m .49253 .87778 L .49142 .87728 L F
.682 .314 .343 r
.49253 .87778 m .49164 .87886 L .49142 .87728 L F
.573 .363 .557 r
.33622 .74688 m .33841 .74688 L .3389 .74432 L F
.568 .399 .613 r
.3389 .74432 m .34094 .74426 L .34026 .74229 L F
.583 .372 .56 r
.3389 .74432 m .34081 .74642 L .34094 .74426 L F
.3389 .74432 m .33841 .74688 L .34081 .74642 L F
.581 .389 .586 r
.35415 .76589 m .35435 .77035 L .35227 .76835 L F
.512 .336 .579 r
.35633 .76889 m .35415 .76589 L .35827 .76614 L F
.35633 .76889 m .35435 .77035 L .35415 .76589 L F
.207 .665 .945 r
.71557 .73148 m .71223 .73065 L .71294 .73182 L F
.357 .248 .591 r
.66904 .71748 m .67062 .71774 L .67062 .71497 L F
.287 .486 .878 r
.58338 .83818 m .58621 .83951 L .58475 .83714 L F
.241 .501 .901 r
.68373 .59236 m .68274 .59326 L .68195 .59204 L F
.68373 .59236 m .68558 .59458 L .68274 .59326 L F
.808 .417 .314 r
.54017 .83255 m .53884 .83552 L .53801 .83315 L F
.154 0 0 r
.53938 .83247 m .54017 .83255 L .53788 .83269 L F
.81 .867 .424 r
.54349 .83183 m .5424 .8339 L .54017 .83255 L F
0 0 0 r
.54184 .8327 m .54017 .83255 L .5424 .8339 L F
.154 0 0 r
.54153 .83217 m .54017 .83255 L .54018 .83236 L F
.54169 .83214 m .54017 .83255 L .54153 .83217 L F
0 0 0 r
.54349 .83183 m .54017 .83255 L .54169 .83214 L F
.54112 .83115 m .54017 .83255 L .54184 .8327 L F
.54112 .83115 m .54012 .83307 L .54017 .83255 L F
.54012 .83307 m .53884 .83552 L .54017 .83255 L F
.154 0 0 r
.54018 .83236 m .54017 .83255 L .53938 .83247 L F
.808 .417 .314 r
.54017 .83255 m .5373 .83112 L .53788 .83269 L F
.54017 .83255 m .53801 .83315 L .5373 .83112 L F
0 0 0 r
.65239 .60227 m .65215 .60269 L .65071 .60495 L F
.65252 .60206 m .65215 .60269 L .65239 .60227 L F
.298 0 .189 r
.65215 .60269 m .64954 .60522 L .65071 .60495 L F
0 0 .443 r
.64794 .60271 m .64925 .60597 L .64756 .60646 L F
.64814 .60076 m .64876 .60369 L .64794 .60271 L F
.64876 .60369 m .64925 .60597 L .64794 .60271 L F
.824 .478 .401 r
.64712 .60211 m .64925 .60597 L .64814 .60076 L F
.64635 .60313 m .64643 .60321 L .64712 .60211 L F
.64643 .60321 m .64925 .60597 L .64712 .60211 L F
.616 .417 .589 r
.64705 .60327 m .64954 .60522 L .64635 .60313 L F
.811 .998 .846 r
.64954 .60522 m .64925 .60597 L .64643 .60321 L F
.64653 .60325 m .64643 .60321 L .64635 .60313 L F
.64954 .60522 m .64643 .60321 L .64653 .60325 L F
.546 .146 .235 r
.64613 .60531 m .64698 .60342 L .64635 .60334 L F
.64698 .60342 m .64705 .60327 L .64669 .60331 L F
.64698 .60342 m .64669 .60331 L .64635 .60334 L F
.64567 .60443 m .64635 .60334 L .64517 .60347 L F
.64613 .60531 m .64635 .60334 L .64567 .60443 L F
.341 0 .202 r
.64982 .60507 m .65165 .60348 L .65071 .60495 L F
.07 0 0 r
.64912 .60568 m .65184 .60397 L .64982 .60507 L F
.64912 .60568 m .64982 .60507 L .64954 .60522 L F
.811 .998 .846 r
.64954 .60522 m .65071 .60495 L .64925 .60597 L F
.341 0 .202 r
.64931 .60559 m .64982 .60507 L .65071 .60495 L F
.64982 .60507 m .65215 .60269 L .65165 .60348 L F
.298 0 .189 r
.65215 .60269 m .64982 .60507 L .64954 .60522 L F
.341 0 .202 r
.64912 .60568 m .65215 .60269 L .64931 .60559 L F
.298 0 .189 r
.65215 .60269 m .65184 .60397 L .64982 .60507 L F
.341 0 .202 r
.64984 .60497 m .6511 .60434 L .65215 .60269 L F
.6511 .60434 m .65128 .60425 L .65215 .60269 L F
.65128 .60425 m .65184 .60397 L .65215 .60269 L F
.64912 .60568 m .64998 .60514 L .64984 .60497 L F
.64998 .60514 m .65184 .60397 L .64984 .60497 L F
.51 .667 .933 r
.44403 .72862 m .44387 .73055 L .44232 .72841 L F
.44403 .72862 m .4459 .73039 L .44387 .73055 L F
.381 .159 .448 r
.32721 .72001 m .32712 .72288 L .32493 .72319 L F
.524 .335 .566 r
.32958 .71738 m .3293 .7216 L .32721 .72001 L F
.36 0 .191 r
.3293 .7216 m .32712 .72288 L .32721 .72001 L F
.752 .524 .586 r
.58584 .82408 m .58933 .82626 L .589 .82491 L F
.577 .377 .573 r
.34094 .74426 m .34325 .74145 L .34026 .74229 L F
.691 .73 .88 r
.7086 .71243 m .70691 .71352 L .70533 .7119 L F
.582 .367 .554 r
.44407 .76029 m .44643 .75774 L .44424 .75804 L F
.543 .463 .715 r
.32342 .67517 m .32595 .67744 L .32694 .67593 L F
.32342 .67517 m .3241 .67807 L .32595 .67744 L F
.375 .078 .328 r
.32259 .708 m .32195 .70923 L .32447 .70716 L F
.576 .744 .956 r
.42641 .72694 m .42282 .72583 L .42488 .72561 L F
.56 .766 .975 r
.42842 .72656 m .42641 .72694 L .42488 .72561 L F
.73 .463 .523 r
.48793 .86129 m .49126 .8592 L .48928 .85784 L F
.48793 .86129 m .49141 .86145 L .49126 .8592 L F
.785 .968 .918 r
.67569 .71998 m .67707 .71983 L .67509 .72131 L F
.581 .29 .439 r
.45958 .765 m .45606 .7678 L .45694 .76506 L F
.249 .028 .37 r
.4721 .84547 m .47325 .84552 L .47393 .84321 L F
.31 .311 .699 r
.4721 .84547 m .47396 .84748 L .47325 .84552 L F
.455 .364 .664 r
.47081 .8535 m .4724 .85141 L .47014 .85174 L F
.075 .513 .9 r
.33094 .65529 m .3308 .656 L .3291 .65512 L F
.33094 .65529 m .33225 .65635 L .3308 .656 L F
.412 .03 .201 r
.36309 .73374 m .36509 .73344 L .36633 .73144 L F
.439 .07 .239 r
.36509 .73344 m .36838 .73107 L .36633 .73144 L F
.753 .793 .885 r
.37657 .78395 m .37843 .78546 L .37522 .78667 L F
.614 .766 .952 r
.38023 .78472 m .37843 .78546 L .37657 .78395 L F
.475 .173 .373 r
.3616 .76112 m .36107 .76283 L .35904 .76319 L F
.589 .327 .488 r
.3641 .7602 m .36107 .76283 L .3616 .76112 L F
.499 .889 .956 r
.5046 .88764 m .50558 .88792 L .5074 .88731 L F
.631 .564 .761 r
.4452 .74978 m .44747 .74925 L .44692 .7472 L F
.728 .839 .933 r
.71557 .73148 m .71866 .73139 L .71744 .73028 L F
.682 .419 .518 r
.4847 .85866 m .48837 .85639 L .48513 .85672 L F
.4847 .85866 m .48826 .85907 L .48837 .85639 L F
.722 .453 .52 r
.48837 .85639 m .48826 .85907 L .48928 .85784 L F
.926 .736 .626 r
.68513 .71281 m .6836 .71465 L .68417 .71247 L F
.68513 .71281 m .68496 .71569 L .6836 .71465 L F
.59 .641 .869 r
.469 .75147 m .46777 .75338 L .46694 .75157 L F
.472 .484 .789 r
.469 .75147 m .47032 .75399 L .46777 .75338 L F
.702 .933 .964 r
.43871 .74293 m .44057 .74336 L .44226 .74195 L F
.455 .364 .664 r
.47081 .8535 m .47256 .85343 L .4724 .85141 L F
.035 .605 .731 r
.31271 .65383 m .31478 .65378 L .31629 .65379 L F
.48 .817 .999 r
.31478 .65378 m .31809 .65406 L .31629 .65379 L F
.833 .769 .792 r
.71993 .72219 m .71924 .72571 L .71969 .72347 L F
.71993 .72219 m .71651 .72568 L .71924 .72571 L F
0 0 0 r
.71886 .72726 m .71837 .72869 L .71894 .72674 L F
.71886 .72726 m .71894 .72674 L .71924 .72571 L F
.369 0 0 r
.71886 .72726 m .71892 .72788 L .71877 .72783 L F
.85 .927 .879 r
.71886 .72726 m .71744 .73028 L .71837 .72869 L F
.71886 .72726 m .71638 .72972 L .71744 .73028 L F
.759 .695 .791 r
.71588 .72693 m .71638 .72972 L .71886 .72726 L F
.622 .124 .049 r
.71588 .72693 m .7179 .72775 L .71886 .72726 L F
.967 .926 .696 r
.71886 .72726 m .7179 .72775 L .71811 .72739 L F
.369 0 0 r
.71886 .72726 m .71884 .72736 L .71853 .72731 L F
.71886 .72726 m .71853 .72731 L .71588 .72693 L F
.71884 .72736 m .71797 .72739 L .71588 .72693 L F
.589 .464 .677 r
.71797 .72739 m .7179 .72775 L .71588 .72693 L F
.369 0 0 r
.71797 .72739 m .71742 .72741 L .71588 .72693 L F
0 0 0 r
.71886 .72726 m .71924 .72571 L .71651 .72568 L F
.646 .167 .102 r
.71588 .72693 m .71886 .72726 L .71651 .72568 L F
.589 .464 .677 r
.71849 .72491 m .71797 .72739 L .71588 .72693 L F
.967 .926 .696 r
.71886 .72726 m .71811 .72739 L .72086 .72265 L F
.93 .809 .704 r
.72086 .72265 m .71811 .72739 L .71849 .72491 L F
.71811 .72739 m .71793 .72769 L .71797 .72739 L F
0 .441 .802 r
.71636 .72684 m .71892 .72788 L .71647 .72681 L F
.71588 .72693 m .71742 .72741 L .71636 .72684 L F
.71742 .72741 m .71892 .72788 L .71636 .72684 L F
.93 .809 .704 r
.71793 .72769 m .7179 .72775 L .71791 .72768 L F
.71793 .72769 m .71791 .72768 L .71797 .72739 L F
.71811 .72739 m .71797 .72739 L .71849 .72491 L F
.369 0 0 r
.71884 .72736 m .71877 .72783 L .71742 .72741 L F
.153 0 0 r
.38872 .7246 m .39081 .72444 L .39241 .72381 L F
.473 .114 .275 r
.55263 .79801 m .54929 .80005 L .55035 .79764 L F
.675 .403 .501 r
.63466 .65136 m .63473 .65322 L .63135 .65365 L F
.59 .336 .501 r
.63466 .65136 m .63686 .65307 L .63473 .65322 L F
.652 .299 .361 r
.63696 .65183 m .63686 .65307 L .63466 .65136 L F
0 0 0 r
.3224 .67458 m .32139 .67467 L .32145 .67459 L F
.685 .245 .199 r
.3208 .67544 m .31879 .67637 L .31739 .67504 L F
.47 .295 .561 r
.31879 .67637 m .31728 .67747 L .31739 .67504 L F
.63 .078 0 r
.31739 .67504 m .31837 .67596 L .31768 .67582 L F
.31837 .67596 m .31879 .67637 L .31768 .67582 L F
.524 .919 .88 r
.31842 .67496 m .31697 .67568 L .31768 .67582 L F
.956 .718 .538 r
.31739 .67504 m .31728 .67747 L .31589 .6762 L F
.63 .078 0 r
.31739 .67504 m .31768 .67582 L .31589 .6762 L F
.524 .919 .88 r
.31697 .67568 m .31657 .67588 L .31768 .67582 L F
.783 .926 .93 r
.31768 .67582 m .32145 .67459 L .31993 .67479 L F
0 0 0 r
.32139 .67467 m .31993 .67479 L .32145 .67459 L F
.32151 .67451 m .32145 .67459 L .3208 .67544 L F
.32298 .67258 m .32145 .67459 L .32151 .67451 L F
.386 0 .091 r
.32493 .67265 m .32145 .67459 L .32298 .67258 L F
.32 .14 .473 r
.33016 .69638 m .33174 .6931 L .33029 .69392 L F
.586 .939 .784 r
.32145 .67459 m .31879 .67637 L .3208 .67544 L F
.729 .96 .943 r
.38324 .78409 m .38361 .78278 L .3859 .7825 L F
.38324 .78409 m .38199 .78387 L .38361 .78278 L F
.977 .832 .633 r
.5767 .80502 m .57838 .80296 L .57811 .8028 L F
.5767 .80502 m .57773 .80593 L .57838 .80296 L F
.885 .676 .156 r
.57802 .80019 m .57811 .8028 L .57838 .80296 L F
.473 .343 .622 r
.33174 .6931 m .334 .69053 L .33193 .69152 L F
.485 .23 .453 r
.32493 .72319 m .32511 .72563 L .32297 .72575 L F
.373 .151 .443 r
.3268 .72493 m .32493 .72319 L .32712 .72288 L F
.3268 .72493 m .32511 .72563 L .32493 .72319 L F
0 0 0 r
.38087 .79967 m .38404 .79872 L .38206 .7994 L F
.38 .834 .743 r
.38206 .7994 m .38404 .79872 L .3858 .79789 L F
.688 .668 .825 r
.69457 .72338 m .69802 .72441 L .69697 .72273 L F
.662 .637 .815 r
.69697 .72273 m .69802 .72441 L .7 .72346 L F
.168 0 0 r
.6472 .61031 m .64944 .61041 L .64912 .61018 L F
.909 .844 .768 r
.67704 .595 m .67417 .59695 L .67607 .59415 L F
.67704 .595 m .67529 .59796 L .67417 .59695 L F
.823 .925 .902 r
.67969 .59257 m .67704 .595 L .67607 .59415 L F
.822 .378 .18 r
.54172 .82742 m .54286 .82953 L .54484 .82972 L F
.934 .794 .682 r
.54286 .82953 m .54349 .83183 L .54484 .82972 L F
.319 0 0 r
.40381 .7896 m .40326 .79038 L .40055 .79122 L F
.162 0 0 r
.40525 .7897 m .40381 .7896 L .40561 .789 L F
.40525 .7897 m .40326 .79038 L .40381 .7896 L F
.591 .801 .98 r
.36249 .67527 m .35884 .67472 L .36106 .6742 L F
.066 .536 .897 r
.36288 .67477 m .36249 .67527 L .36106 .6742 L F
.36288 .67477 m .36339 .67517 L .36249 .67527 L F
.567 .286 .448 r
.44996 .76838 m .44869 .77108 L .44644 .7711 L F
.534 .236 .408 r
.4518 .7683 m .44869 .77108 L .44996 .76838 L F
.604 .046 0 r
.35 .81131 m .3512 .81152 L .3518 .81058 L F
0 0 0 r
.3512 .81152 m .3558 .80911 L .35576 .80914 L F
.35327 .81065 m .35576 .80914 L .35395 .81037 L F
.3512 .81152 m .35576 .80914 L .35327 .81065 L F
.3512 .81152 m .35395 .81037 L .3518 .81058 L F
.181 0 .021 r
.35045 .8124 m .35 .81131 L .3518 .81058 L F
.35045 .8124 m .3518 .81058 L .35031 .81241 L F
.535 .249 .428 r
.3518 .81058 m .35245 .81115 L .35031 .81241 L F
.35245 .81115 m .3535 .81208 L .35039 .81241 L F
.35245 .81115 m .35039 .81241 L .35031 .81241 L F
.753 .793 .885 r
.37657 .78395 m .37522 .78667 L .37452 .78431 L F
0 0 0 r
.35395 .81037 m .3558 .80911 L .35732 .80816 L F
.425 .694 .976 r
.47204 .75399 m .47139 .75511 L .47032 .75399 L F
.398 .66 .965 r
.47204 .75399 m .47335 .75523 L .47139 .75511 L F
.263 .739 .937 r
.54303 .84254 m .54294 .84241 L .54267 .84018 L F
.54303 .84254 m .54538 .84263 L .54294 .84241 L F
.649 .237 .249 r
.64969 .6354 m .65298 .63534 L .6512 .63483 L F
.904 .84 .771 r
.56782 .80577 m .56639 .80926 L .5646 .8079 L F
.671 .553 .713 r
.56898 .80892 m .56639 .80926 L .56782 .80577 L F
.771 .424 .398 r
.49563 .8673 m .49456 .86951 L .4925 .86681 L F
.769 .422 .397 r
.49633 .86895 m .49456 .86951 L .49563 .8673 L F
.495 .365 .632 r
.33622 .74688 m .3382 .74917 L .33841 .74688 L F
.33622 .74688 m .33641 .74967 L .3382 .74917 L F
.275 .694 .969 r
.43379 .72743 m .43703 .72828 L .43499 .72816 L F
.836 .42 .25 r
.53908 .82621 m .54172 .82742 L .54066 .8267 L F
.481 .104 .247 r
.64011 .65074 m .63686 .65307 L .63696 .65183 L F
.64011 .65074 m .6391 .65292 L .63686 .65307 L F
.494 .116 .252 r
.64011 .65074 m .64136 .65273 L .6391 .65292 L F
.64011 .65074 m .64229 .65075 L .64136 .65273 L F
.569 .536 .779 r
.56919 .83536 m .5705 .83205 L .56866 .83246 L F
.56919 .83536 m .5717 .83539 L .5705 .83205 L F
.82 .724 .76 r
.6358 .61921 m .63754 .6165 L .63849 .61941 L F
.828 .63 .635 r
.6358 .61921 m .63849 .61941 L .6381 .62205 L F
.843 .735 .745 r
.63754 .6165 m .63877 .61741 L .63849 .61941 L F
.625 .531 .727 r
.45788 .73371 m .45585 .73554 L .45575 .73435 L F
.45788 .73371 m .45849 .73672 L .45585 .73554 L F
.27 .761 .91 r
.39449 .72339 m .39647 .72316 L .39781 .72341 L F
.326 .786 .944 r
.39647 .72316 m .39854 .7229 L .39984 .72324 L F
.331 0 0 r
.39513 .7244 m .39846 .72294 L .39647 .72316 L F
.39846 .72294 m .39854 .7229 L .39647 .72316 L F
.27 .761 .91 r
.39442 .72338 m .39647 .72316 L .39449 .72339 L F
.539 .467 .723 r
.66972 .72495 m .67166 .72283 L .67006 .72342 L F
.746 .585 .676 r
.64217 .64016 m .64462 .63676 L .64337 .63756 L F
.725 .611 .73 r
.50415 .86925 m .50628 .87242 L .50235 .87233 L F
.695 .389 .453 r
.50628 .87242 m .50463 .87446 L .50235 .87233 L F
0 0 0 r
.50664 .87172 m .50678 .87098 L .50628 .87242 L F
.50664 .87172 m .50628 .87242 L .50415 .86925 L F
.832 .582 .562 r
.50628 .87242 m .50654 .87504 L .50463 .87446 L F
.625 .356 .49 r
.47468 .75804 m .47465 .76001 L .47296 .76002 L F
.718 .671 .804 r
.47675 .75579 m .47468 .75804 L .47335 .75523 L F
.645 .555 .738 r
.47675 .75579 m .47696 .75777 L .47468 .75804 L F
.679 .453 .572 r
.47696 .75777 m .47465 .76001 L .47468 .75804 L F
.592 .716 .93 r
.45278 .73292 m .44908 .73157 L .45107 .73115 L F
.46 .654 .944 r
.45321 .73113 m .45278 .73292 L .45107 .73115 L F
.45321 .73113 m .45471 .73289 L .45278 .73292 L F
.824 .442 .33 r
.49141 .86145 m .49324 .86379 L .49465 .86281 L F
.677 .225 .172 r
.49324 .86379 m .49646 .8642 L .49465 .86281 L F
.633 .546 .739 r
.34398 .78428 m .34208 .78681 L .3419 .78466 L F
.34398 .78428 m .34477 .7869 L .34208 .78681 L F
.574 .418 .633 r
.34477 .7869 m .34274 .79025 L .34208 .78681 L F
.063 .484 .891 r
.66857 .60886 m .66694 .60837 L .6657 .60725 L F
.759 .697 .793 r
.36439 .91329 m .36529 .91237 L .36384 .91227 L F
.216 .155 .57 r
.43327 .74426 m .43425 .74087 L .43188 .74138 L F
.43327 .74426 m .43471 .74403 L .43425 .74087 L F
.239 .284 .708 r
.43327 .74426 m .4349 .7461 L .43471 .74403 L F
.729 .453 .51 r
.35125 .7364 m .35312 .73885 L .35367 .73691 L F
0 0 .044 r
.35367 .73691 m .35412 .73736 L .35562 .73642 L F
.629 .562 .76 r
.35641 .73665 m .35675 .73765 L .35399 .7374 L F
0 0 .044 r
.35412 .73736 m .35413 .73737 L .35418 .73734 L F
.35412 .73736 m .35418 .73734 L .35562 .73642 L F
.629 .562 .76 r
.35399 .7374 m .35675 .73765 L .35373 .73773 L F
0 0 .044 r
.35413 .73737 m .35422 .73736 L .35562 .73642 L F
0 0 0 r
.35562 .73642 m .35428 .73731 L .35728 .73557 L F
.629 .562 .76 r
.35627 .73623 m .35641 .73665 L .35428 .73731 L F
0 0 0 r
.35428 .73731 m .35415 .7374 L .35455 .73717 L F
.35428 .73731 m .35455 .73717 L .35728 .73557 L F
.579 .849 .995 r
.35728 .73557 m .35428 .73573 L .35586 .735 L F
.629 .562 .76 r
.35586 .735 m .3546 .73709 L .35399 .7374 L F
.35586 .735 m .35415 .7374 L .35455 .73717 L F
.35586 .735 m .35455 .73717 L .35728 .73557 L F
.35586 .735 m .35627 .73623 L .3546 .73709 L F
.35627 .73623 m .35428 .73731 L .35399 .7374 L F
.41 .266 .572 r
.35428 .73573 m .35381 .73744 L .35586 .735 L F
0 0 .044 r
.35367 .73691 m .35312 .73885 L .35415 .7374 L F
.41 .266 .572 r
.35381 .73744 m .35373 .73773 L .35399 .7374 L F
.35381 .73744 m .35399 .7374 L .35586 .735 L F
0 0 .044 r
.35413 .73737 m .35415 .7374 L .35422 .73736 L F
.118 .299 .772 r
.67244 .61548 m .67374 .61837 L .67177 .61686 L F
.987 .718 .406 r
.68916 .72564 m .68946 .72893 L .69024 .72866 L F
.99 .729 .417 r
.68946 .72893 m .69032 .73097 L .69024 .72866 L F
.407 .516 .856 r
.70729 .72795 m .70801 .72536 L .70551 .72606 L F
.70729 .72795 m .70897 .72803 L .70801 .72536 L F
.772 .54 .584 r
.31239 .65174 m .31271 .65383 L .3093 .65349 L F
.834 .789 .808 r
.64404 .59511 m .64607 .59248 L .64685 .59528 L F
.824 .808 .835 r
.64404 .59511 m .64685 .59528 L .64519 .59631 L F
.753 .752 .852 r
.64802 .59149 m .64685 .59528 L .64607 .59248 L F
.64802 .59149 m .64901 .59276 L .64685 .59528 L F
.513 .395 .656 r
.33569 .6808 m .33789 .6803 L .33748 .67768 L F
0 0 .44 r
.33569 .6808 m .33674 .68208 L .33789 .6803 L F
.33569 .6808 m .33574 .68344 L .33674 .68208 L F
.465 .468 .776 r
.34984 .6702 m .35231 .67187 L .35068 .67226 L F
.872 .711 .68 r
.59609 .83245 m .59806 .83435 L .59817 .83236 L F
.868 .947 .864 r
.49925 .8831 m .4959 .88512 L .49906 .88495 L F
.769 .266 0 r
.49967 .88444 m .49925 .8831 L .49906 .88495 L F
.49967 .88444 m .50029 .88472 L .49925 .8831 L F
.378 0 0 r
.49974 .88448 m .50029 .88472 L .49967 .88444 L F
.838 .372 .077 r
.50189 .88601 m .50102 .88505 L .50029 .88472 L F
0 .228 .739 r
.50205 .88551 m .50189 .88601 L .50029 .88472 L F
.378 0 0 r
.50188 .88554 m .50029 .88472 L .49974 .88448 L F
.838 .372 .077 r
.50102 .88505 m .49925 .8831 L .50029 .88472 L F
.45 0 0 r
.65905 .63347 m .65842 .6325 L .65744 .63442 L F
.65905 .63347 m .66089 .63282 L .65842 .6325 L F
.616 .245 .317 r
.65744 .63442 m .65842 .6325 L .6551 .63284 L F
.809 .596 .614 r
.49991 .86671 m .50259 .86435 L .49992 .86445 L F
.49991 .86671 m .50299 .86726 L .50259 .86435 L F
.565 .414 .636 r
.34604 .78201 m .344 .77969 L .34555 .77911 L F
.34604 .78201 m .34382 .78284 L .344 .77969 L F
.234 0 .298 r
.38833 .74793 m .38823 .74975 L .38664 .75002 L F
.511 .183 .347 r
.39061 .7481 m .38833 .74793 L .39174 .74569 L F
.39061 .7481 m .38823 .74975 L .38833 .74793 L F
.735 .49 0 r
.56644 .81912 m .56701 .8222 L .56671 .82094 L F
.523 .263 .462 r
.55563 .78936 m .55812 .78702 L .55605 .78743 L F
.361 .646 .964 r
.58621 .83951 m .58705 .84061 L .58811 .83965 L F
.434 .768 .997 r
.58811 .83965 m .58705 .84061 L .58921 .8404 L F
.563 .391 .606 r
.36271 .68076 m .36081 .68041 L .36223 .6799 L F
.36271 .68076 m .3609 .68285 L .36081 .68041 L F
.6 .458 .659 r
.35435 .77035 m .35173 .77015 L .35227 .76835 L F
.772 .413 .375 r
.3316 .67491 m .329 .67475 L .32738 .67357 L F
.522 0 0 r
.3316 .67491 m .32949 .67559 L .329 .67475 L F
.715 .346 .348 r
.33379 .67429 m .32949 .67559 L .3316 .67491 L F
.612 .54 .749 r
.46227 .7417 m .46032 .7439 L .46002 .74197 L F
.46227 .7417 m .46323 .74499 L .46032 .7439 L F
.619 .554 .759 r
.46368 .74694 m .46032 .7439 L .46323 .74499 L F
.737 .428 .459 r
.68187 .616 m .68661 .61512 L .68565 .61255 L F
.68187 .616 m .68472 .61627 L .68661 .61512 L F
.149 0 .327 r
.68661 .61512 m .68927 .61347 L .68565 .61255 L F
.599 .935 .951 r
.68682 .6178 m .68701 .61761 L .68909 .61695 L F
.735 .761 .874 r
.69016 .61796 m .68682 .6178 L .68909 .61695 L F
.68909 .61695 m .68682 .6178 L .69016 .61796 L F
.479 .099 .241 r
.69076 .61647 m .68752 .61755 L .68748 .61744 L F
.69051 .61639 m .68898 .61692 L .68661 .61512 L F
.68898 .61692 m .68735 .61711 L .68661 .61512 L F
.303 .783 .918 r
.68909 .61695 m .68898 .61692 L .68963 .61685 L F
.6897 .61684 m .68963 .61685 L .68974 .61683 L F
.68909 .61695 m .68963 .61685 L .6897 .61684 L F
.599 .935 .951 r
.68909 .61695 m .6889 .6169 L .68682 .6178 L F
.6889 .6169 m .68766 .61734 L .68682 .6178 L F
.68766 .61734 m .68707 .61755 L .68705 .61756 L F
.68766 .61734 m .68705 .61756 L .68682 .6178 L F
.479 .099 .241 r
.69076 .61647 m .68941 .61687 L .69051 .61639 L F
.599 .935 .951 r
.68701 .61761 m .68898 .61692 L .68909 .61695 L F
.479 .099 .241 r
.68941 .61687 m .68748 .61744 L .68898 .61692 L F
.68941 .61687 m .68898 .61692 L .69051 .61639 L F
.303 .783 .918 r
.68898 .61692 m .68887 .61689 L .68974 .61683 L F
.659 .474 .622 r
.68776 .61698 m .68787 .61697 L .69101 .61251 L F
.479 .099 .241 r
.68898 .61692 m .68748 .61744 L .68735 .61711 L F
.659 .474 .622 r
.6876 .61736 m .68766 .61734 L .68792 .61697 L F
.68787 .61697 m .68792 .61697 L .69101 .61251 L F
.6876 .61736 m .68792 .61697 L .68787 .61697 L F
.681 .503 .638 r
.69101 .61251 m .68792 .61697 L .68947 .6167 L F
.69101 .61251 m .68947 .6167 L .69078 .61623 L F
.68792 .61697 m .68963 .61685 L .69076 .61647 L F
.303 .783 .918 r
.68988 .61681 m .68799 .61664 L .69135 .61654 L F
.68909 .61695 m .68887 .61689 L .68988 .61681 L F
.68887 .61689 m .68799 .61664 L .68988 .61681 L F
.68887 .61689 m .68799 .61664 L .68966 .61683 L F
.68887 .61689 m .68966 .61683 L .68974 .61683 L F
.659 .474 .622 r
.68927 .61347 m .68776 .61698 L .69101 .61251 L F
.68776 .61698 m .6876 .61736 L .68787 .61697 L F
.6876 .61736 m .68752 .61755 L .68766 .61734 L F
.681 .503 .638 r
.6889 .6169 m .68752 .61755 L .68963 .61685 L F
.68792 .61697 m .68766 .61734 L .6889 .6169 L F
.599 .935 .951 r
.68701 .61761 m .68707 .61755 L .68898 .61692 L F
.68707 .61755 m .6889 .6169 L .68898 .61692 L F
.681 .503 .638 r
.68766 .61734 m .68752 .61755 L .6889 .6169 L F
.599 .935 .951 r
.68707 .61755 m .68799 .61664 L .6889 .6169 L F
.6889 .6169 m .68799 .61664 L .68707 .61755 L F
.681 .503 .638 r
.69078 .61623 m .68947 .6167 L .69076 .61647 L F
.303 .783 .918 r
.68974 .61683 m .68799 .61664 L .69135 .61654 L F
.149 0 .327 r
.68661 .61512 m .68752 .61755 L .68927 .61347 L F
.585 .799 .981 r
.47575 .84264 m .47626 .84346 L .47393 .84321 L F
.47575 .84264 m .47626 .84346 L .47393 .84321 L F
0 .183 .716 r
.47575 .84264 m .4773 .84553 L .47626 .84346 L F
.291 .51 .895 r
.34643 .66146 m .34531 .66245 L .34493 .66101 L F
.34643 .66146 m .34793 .6638 L .34531 .66245 L F
.456 .081 .238 r
.38664 .75002 m .3858 .75097 L .38387 .75158 L F
.146 0 .003 r
.38823 .74975 m .3858 .75097 L .38664 .75002 L F
.66 .156 0 r
.67229 .61373 m .67032 .6112 L .66933 .61038 L F
.711 .34 .345 r
.70564 .70742 m .70431 .70907 L .70199 .707 L F
.967 .755 .564 r
.70564 .70742 m .70555 .70982 L .70431 .70907 L F
.985 .903 .595 r
.63795 .62772 m .63702 .62912 L .63792 .6293 L F
.787 .998 .846 r
.63792 .6293 m .63435 .63146 L .63613 .63194 L F
.63792 .6293 m .63702 .62912 L .63435 .63146 L F
.434 .018 .148 r
.41592 .78402 m .41253 .78596 L .41387 .78444 L F
.174 .305 .759 r
.35006 .73386 m .35222 .73621 L .35125 .7364 L F
.587 .337 .505 r
.34976 .73698 m .35125 .7364 L .35312 .73885 L F
.34976 .73698 m .35222 .73621 L .35125 .7364 L F
.965 .706 .271 r
.57933 .79207 m .58031 .79537 L .5806 .7921 L F
.57933 .79207 m .57961 .79457 L .58031 .79537 L F
.937 .819 .367 r
.57961 .79457 m .57957 .79732 L .58031 .79537 L F
.186 .624 .944 r
.41839 .72391 m .41729 .72432 L .41599 .72319 L F
.41839 .72391 m .41959 .72476 L .41729 .72432 L F
.889 .72 .667 r
.68995 .73297 m .69144 .73403 L .69032 .73097 L F
.846 .752 .759 r
.6881 .73594 m .69144 .73403 L .68995 .73297 L F
.6881 .73594 m .68963 .73679 L .69144 .73403 L F
.483 .167 .354 r
.43095 .76785 m .43392 .76515 L .43193 .76556 L F
.657 .463 .61 r
.34588 .73897 m .34783 .73914 L .34615 .73736 L F
.872 .764 .741 r
.62107 .64929 m .62034 .65127 L .61945 .64836 L F
.912 .547 .327 r
.54349 .83183 m .54604 .83493 L .54692 .83265 L F
.893 .486 .228 r
.67402 .61142 m .6753 .61168 L .67597 .61341 L F
.542 .333 .546 r
.33367 .7144 m .33122 .71687 L .33199 .71505 L F
.818 .594 .599 r
.56474 .80277 m .56334 .80021 L .56457 .80055 L F
.661 .474 .621 r
.56679 .80021 m .56474 .80277 L .56457 .80055 L F
.691 .464 .574 r
.60672 .64567 m .61113 .64575 L .61053 .6434 L F
.464 .477 .787 r
.69238 .60214 m .69043 .60365 L .68956 .6005 L F
.484 .513 .812 r
.69238 .60214 m .69337 .6055 L .69043 .60365 L F
.598 .494 .707 r
.69043 .60365 m .69337 .6055 L .69099 .60593 L F
.469 .821 .997 r
.36384 .91227 m .36529 .91237 L .36532 .91159 L F
.36384 .91227 m .36529 .91237 L .36532 .91159 L F
.302 .672 .975 r
.36532 .91159 m .36529 .91237 L .36675 .9125 L F
.363 .053 .299 r
.43286 .778 m .43155 .777 L .43341 .7769 L F
.43286 .778 m .43101 .77855 L .43155 .777 L F
.842 .648 .641 r
.57944 .82146 m .58239 .81919 L .57929 .81876 L F
.57944 .82146 m .58234 .8217 L .58239 .81919 L F
.272 0 .142 r
.6533 .5979 m .65257 .59966 L .65068 .60019 L F
.246 .263 .681 r
.65473 .59696 m .6533 .5979 L .65347 .59454 L F
.291 0 .15 r
.65452 .5991 m .6533 .5979 L .65473 .59696 L F
.65452 .5991 m .65257 .59966 L .6533 .5979 L F
.851 .879 .86 r
.52874 .82118 m .53006 .82208 L .53247 .81921 L F
.618 .696 .9 r
.35561 .67405 m .35684 .67565 L .35353 .67466 L F
.671 .716 .882 r
.35884 .67472 m .35684 .67565 L .35561 .67405 L F
.446 0 0 r
.64804 .64964 m .64686 .65076 L .64452 .65066 L F
.22 0 0 r
.64804 .64964 m .64983 .64962 L .64686 .65076 L F
.232 0 0 r
.51149 .8837 m .51026 .88335 L .50905 .88317 L F
.831 .847 .858 r
.51149 .8837 m .513 .88283 L .51026 .88335 L F
.757 .649 .742 r
.52867 .84258 m .52943 .84345 L .53116 .83825 L F
.773 .716 .799 r
.61945 .64836 m .62034 .65127 L .6172 .65093 L F
.712 .502 .604 r
.62034 .65127 m .61889 .65362 L .6172 .65093 L F
.62034 .65127 m .62034 .65374 L .61889 .65362 L F
.743 .475 .525 r
.62034 .65127 m .62374 .65339 L .62034 .65374 L F
.176 0 0 r
.40116 .74253 m .39785 .74304 L .39913 .74281 L F
.838 .653 .109 r
.68758 .72707 m .68772 .72923 L .68737 .7283 L F
.932 .863 .75 r
.68764 .73038 m .68737 .7283 L .68772 .72923 L F
.352 .192 .521 r
.33129 .71971 m .32958 .71738 L .33122 .71687 L F
.33129 .71971 m .3293 .7216 L .32958 .71738 L F
.918 .711 .216 r
.47886 .87182 m .47921 .87222 L .4792 .86983 L F
.47886 .87182 m .4792 .86983 L .48027 .8688 L F
.403 .106 .344 r
.67487 .63322 m .67744 .63007 L .67691 .63149 L F
0 0 0 r
.67691 .63149 m .67744 .63007 L .67828 .62883 L F
.769 .667 .75 r
.68318 .74728 m .68638 .74765 L .68487 .74672 L F
.923 .708 .595 r
.57779 .81595 m .57931 .8165 L .57799 .81358 L F
.901 .656 .558 r
.57765 .81829 m .57931 .8165 L .57779 .81595 L F
.57765 .81829 m .57929 .81876 L .57931 .8165 L F
.74 .714 .828 r
.54294 .84241 m .54538 .84263 L .54785 .84031 L F
.834 .806 .824 r
.5413 .84835 m .53931 .85123 L .53754 .85 L F
.579 .441 .657 r
.5413 .84835 m .54191 .85146 L .53931 .85123 L F
.68 .526 .67 r
.54191 .85146 m .53769 .85345 L .53931 .85123 L F
.57 .415 .632 r
.35215 .77326 m .34998 .77147 L .35173 .77015 L F
.35215 .77326 m .35023 .77375 L .34998 .77147 L F
.352 0 .177 r
.31882 .71179 m .32195 .70923 L .32118 .70996 L F
.365 0 .083 r
.37042 .73071 m .37249 .7304 L .37388 .72865 L F
.398 0 .153 r
.37249 .7304 m .37587 .72817 L .37388 .72865 L F
.482 .259 .498 r
.37336 .75268 m .37312 .75499 L .37128 .75534 L F
.569 .33 .513 r
.37561 .75237 m .37312 .75499 L .37336 .75268 L F
.191 .622 .946 r
.64814 .60076 m .64668 .59987 L .64617 .60169 L F
.64814 .60076 m .64817 .60066 L .64668 .59987 L F
.824 .478 .401 r
.64635 .60313 m .64814 .60076 L .64617 .60169 L F
.945 .739 .594 r
.57688 .81061 m .57799 .81358 L .57829 .81123 L F
.408 .168 .435 r
.33599 .71188 m .33367 .7144 L .33423 .71252 L F
.267 .769 .747 r
.4988 .8894 m .50054 .889 L .50255 .88838 L F
.482 .699 .964 r
.33416 .65641 m .33333 .65763 L .33225 .65635 L F
.33416 .65641 m .33579 .65783 L .33333 .65763 L F
.514 .212 .391 r
.44423 .77113 m .44331 .77359 L .44122 .77385 L F
.546 .243 .405 r
.44601 .77295 m .44423 .77113 L .44644 .7711 L F
.44601 .77295 m .44331 .77359 L .44423 .77113 L F
.539 .467 .723 r
.66972 .72495 m .67219 .72477 L .67166 .72283 L F
.726 .605 .721 r
.64247 .60937 m .63837 .60824 L .64222 .60893 L F
.7 .941 .961 r
.64222 .60893 m .64398 .60771 L .64286 .60739 L F
.041 .179 .682 r
.64222 .60893 m .6439 .61079 L .64247 .60937 L F
.64222 .60893 m .64286 .60739 L .6439 .61079 L F
.352 .808 .69 r
.6439 .61079 m .64222 .60893 L .64247 .60937 L F
.836 .42 .25 r
.53908 .82621 m .54087 .82884 L .54172 .82742 L F
.803 .375 .229 r
.54087 .82884 m .54286 .82953 L .54172 .82742 L F
.301 .155 .51 r
.70199 .707 m .70218 .70968 L .70063 .71004 L F
.445 .376 .686 r
.70218 .70968 m .70029 .71142 L .70063 .71004 L F
.74 .933 .952 r
.51375 .88411 m .51428 .88271 L .513 .88283 L F
.714 .699 .835 r
.513 .88283 m .51422 .88293 L .51428 .88271 L F
.51422 .88293 m .51562 .88304 L .51428 .88271 L F
.035 .05 .543 r
.51541 .88167 m .51428 .88271 L .51501 .8809 L F
.535 .909 .741 r
.51439 .88234 m .51428 .88271 L .51541 .88167 L F
.182 .696 .89 r
.51152 .88239 m .513 .88283 L .51428 .88271 L F
.705 .242 .148 r
.51152 .88239 m .51428 .88271 L .51261 .8835 L F
.535 .909 .741 r
.51261 .8835 m .51428 .88271 L .51439 .88234 L F
.74 .933 .952 r
.51375 .88411 m .51562 .88304 L .51428 .88271 L F
.598 .305 .443 r
.47361 .76166 m .46956 .76096 L .47296 .76002 L F
.47361 .76166 m .4691 .76277 L .46956 .76096 L F
.316 .791 .701 r
.36086 .80707 m .36317 .80622 L .36493 .80546 L F
.277 .429 .834 r
.70227 .72281 m .70368 .72556 L .70453 .72438 L F
.3 .461 .854 r
.70368 .72556 m .70551 .72606 L .70453 .72438 L F
.437 .373 .688 r
.44846 .75249 m .44958 .74916 L .44747 .74925 L F
.44846 .75249 m .45026 .75237 L .44958 .74916 L F
.54 .441 .691 r
.44846 .75249 m .45076 .7544 L .45026 .75237 L F
.44846 .75249 m .44893 .7551 L .45076 .7544 L F
.798 .488 .465 r
.47921 .87222 m .48261 .87461 L .48235 .8725 L F
.79 .405 0 r
.4805 .88473 m .47906 .88197 L .48006 .88287 L F
.251 .725 .94 r
.39984 .72324 m .40192 .7232 L .4033 .72367 L F
.226 .737 .88 r
.40192 .7232 m .40534 .7232 L .4033 .72367 L F
.904 .84 .771 r
.56782 .80577 m .5646 .8079 L .56616 .80496 L F
.464 .397 .697 r
.35108 .66652 m .34984 .6702 L .34891 .6671 L F
.35108 .66652 m .35172 .66994 L .34984 .6702 L F
.473 .467 .771 r
.35172 .66994 m .35231 .67187 L .34984 .6702 L F
.473 .114 .275 r
.55263 .79801 m .5517 .79989 L .54929 .80005 L F
.606 .278 .388 r
.55422 .79822 m .5517 .79989 L .55263 .79801 L F
.16 0 0 r
.65554 .64655 m .65458 .64778 L .65238 .64842 L F
.079 0 0 r
.65554 .64655 m .65655 .64691 L .65458 .64778 L F
.65554 .64655 m .65784 .64603 L .65655 .64691 L F
.456 .245 .503 r
.3543 .68872 m .35389 .69113 L .35199 .69165 L F
.366 .074 .33 r
.3532 .69276 m .35199 .69165 L .35389 .69113 L F
.3532 .69276 m .35134 .69339 L .35199 .69165 L F
.605 .459 .657 r
.67569 .71998 m .67813 .7186 L .67707 .71983 L F
.678 .701 .864 r
.45788 .73371 m .45575 .73435 L .45471 .73289 L F
.6 .309 .446 r
.46587 .76206 m .46152 .76509 L .46168 .76352 L F
.128 0 0 r
.393 .79413 m .38935 .79649 L .3909 .79471 L F
0 0 0 r
.65298 .63534 m .65446 .63424 L .6551 .63284 L F
.65349 .63541 m .65446 .63424 L .65196 .63665 L F
.257 .105 .474 r
.65349 .63541 m .65401 .63475 L .65446 .63424 L F
.643 .171 .117 r
.65446 .63424 m .65548 .6331 L .6551 .63284 L F
.257 .105 .474 r
.65401 .63475 m .65544 .63292 L .65446 .63424 L F
.643 .171 .117 r
.65446 .63424 m .65744 .63442 L .65548 .6331 L F
0 .186 .674 r
.6743 .6189 m .67454 .61943 L .67374 .61837 L F
.6743 .6189 m .6766 .62099 L .67454 .61943 L F
.482 .406 .695 r
.6935 .60779 m .69099 .60593 L .69337 .6055 L F
.6935 .60779 m .69128 .60896 L .69099 .60593 L F
.611 .827 .983 r
.58921 .8404 m .59258 .8407 L .5914 .83969 L F
.663 .823 .961 r
.59258 .8407 m .59431 .83988 L .5914 .83969 L F
.832 .51 .444 r
.49994 .87169 m .50235 .87233 L .50106 .87421 L F
.728 .371 .374 r
.50235 .87233 m .50463 .87446 L .50106 .87421 L F
.322 .087 .394 r
.37128 .75534 m .37084 .75736 L .36923 .75793 L F
.327 .097 .405 r
.37084 .75736 m .36877 .76016 L .36923 .75793 L F
.709 .172 0 r
.54213 .80911 m .5451 .81152 L .54289 .81031 L F
.54213 .80911 m .54289 .81031 L .54432 .80846 L F
.886 .601 .501 r
.54289 .81031 m .5451 .81152 L .54432 .80846 L F
.945 .61 .358 r
.63856 .62402 m .63888 .62624 L .63995 .62497 L F
.597 .803 .978 r
.63856 .62402 m .63995 .62497 L .64202 .6245 L F
.421 .214 .491 r
.35565 .69042 m .3543 .68872 L .35573 .68805 L F
.35565 .69042 m .35389 .69113 L .3543 .68872 L F
.353 .774 .976 r
.31809 .65406 m .32018 .65389 L .3215 .65441 L F
.445 .821 .991 r
.32018 .65389 m .3235 .65405 L .3215 .65441 L F
.569 .939 .881 r
.41075 .74111 m .41001 .74203 L .41207 .74182 L F
.41075 .74111 m .40885 .74215 L .41001 .74203 L F
.757 .649 .742 r
.52867 .84258 m .53116 .83825 L .52876 .84001 L F
.628 .546 .743 r
.6864 .72328 m .68758 .72707 L .68916 .72564 L F
.748 .774 .874 r
.68916 .72564 m .68758 .72707 L .68595 .72544 L F
0 0 0 r
.38087 .79967 m .38206 .7994 L .38004 .79991 L F
.689 .616 .769 r
.67805 .71516 m .68169 .71578 L .67813 .7186 L F
0 0 .372 r
.67813 .7186 m .67839 .71678 L .67805 .71516 L F
.605 .459 .657 r
.67569 .71998 m .67839 .71678 L .67813 .7186 L F
.397 .344 .681 r
.6935 .60779 m .69226 .61103 L .69128 .60896 L F
.885 .454 .124 r
.70883 .7037 m .71027 .70457 L .70879 .70235 L F
.70883 .7037 m .70879 .70235 L .70878 .70116 L F
.544 .355 .575 r
.34773 .77598 m .34771 .77979 L .34555 .77911 L F
.527 .338 .568 r
.35023 .77375 m .34989 .77576 L .34773 .77598 L F
.597 .422 .616 r
.34989 .77576 m .34771 .77979 L .34773 .77598 L F
.752 .362 .313 r
.49922 .8694 m .49808 .87104 L .49633 .86895 L F
.892 .559 .411 r
.49922 .8694 m .49994 .87169 L .49808 .87104 L F
.66 .913 .978 r
.35938 .78975 m .3561 .79025 L .35809 .78948 L F
.616 .888 .989 r
.3615 .78896 m .35938 .78975 L .36001 .78846 L F
.667 .94 .965 r
.35938 .78975 m .35809 .78948 L .36001 .78846 L F
.897 .778 .722 r
.68957 .74118 m .69032 .7442 L .69111 .74201 L F
.6 .309 .446 r
.46587 .76206 m .46361 .7652 L .46152 .76509 L F
.648 .388 .511 r
.46705 .7625 m .46361 .7652 L .46587 .76206 L F
.601 .392 .57 r
.34743 .73593 m .34976 .73698 L .35006 .73386 L F
.617 .406 .573 r
.35006 .73386 m .34976 .73698 L .35222 .73621 L F
.436 .509 .836 r
.44384 .74458 m .44429 .74156 L .44226 .74195 L F
.44384 .74458 m .44565 .74445 L .44429 .74156 L F
.439 .467 .792 r
.44384 .74458 m .44619 .74619 L .44565 .74445 L F
.59 .502 .723 r
.46574 .74657 m .46407 .75101 L .46368 .74694 L F
.46574 .74657 m .46692 .75008 L .46407 .75101 L F
.639 .525 .708 r
.46694 .75157 m .46407 .75101 L .46692 .75008 L F
.46694 .75157 m .46482 .75184 L .46407 .75101 L F
.525 .167 .302 r
.408 .77564 m .4102 .77561 L .41148 .77333 L F
.314 0 0 r
.4102 .77561 m .41372 .77374 L .41148 .77333 L F
.458 .047 .171 r
.38099 .75109 m .37794 .75175 L .3784 .7507 L F
.952 .601 .243 r
.67578 .70758 m .67497 .71002 L .67557 .7099 L F
.67578 .70758 m .67396 .70696 L .67497 .71002 L F
.738 .3 .212 r
.67713 .70952 m .67497 .71002 L .67481 .71208 L F
.487 .262 .498 r
.67497 .71002 m .67713 .70952 L .67481 .71208 L F
.738 .3 .212 r
.67713 .70952 m .67557 .7099 L .67497 .71002 L F
0 .183 .716 r
.47575 .84264 m .47775 .84476 L .4773 .84553 L F
.274 .743 .943 r
.47624 .84731 m .4773 .84553 L .47775 .84476 L F
.47632 .84717 m .47918 .84756 L .4773 .84553 L F
.47643 .84732 m .47918 .84756 L .47632 .84717 L F
.47674 .84735 m .47823 .84712 L .47918 .84756 L F
.47624 .84731 m .47823 .84712 L .47674 .84735 L F
.523 .627 .896 r
.47921 .84436 m .47918 .84756 L .47823 .84712 L F
.47921 .84436 m .48121 .84733 L .47918 .84756 L F
.52 .405 .664 r
.48121 .84733 m .47955 .85013 L .47918 .84756 L F
.358 .235 .573 r
.47823 .84712 m .47968 .84925 L .47955 .84692 L F
.47823 .84712 m .47955 .84692 L .47955 .84678 L F
.426 .272 .568 r
.47688 .84803 m .47806 .84941 L .47823 .84712 L F
.47573 .84879 m .47772 .84932 L .47688 .84803 L F
.47772 .84932 m .47806 .84941 L .47688 .84803 L F
.274 .743 .943 r
.47624 .84731 m .47643 .84732 L .47632 .84717 L F
.962 .934 .615 r
.67529 .59796 m .67365 .5998 L .67417 .59695 L F
.67529 .59796 m .67416 .60072 L .67365 .5998 L F
.243 0 0 r
.40452 .74283 m .40339 .74295 L .40116 .74253 L F
.66 .201 .152 r
.40632 .74311 m .40339 .74295 L .40452 .74283 L F
.329 .716 .982 r
.40934 .72253 m .40866 .7233 L .40735 .72275 L F
.40934 .72253 m .41067 .72336 L .40866 .7233 L F
.495 .885 .959 r
.4326 .74041 m .43188 .74138 L .43425 .74087 L F
.4326 .74041 m .43051 .74108 L .43188 .74138 L F
.717 .584 .706 r
.68109 .62483 m .67824 .62483 L .67797 .62199 L F
.34 .1 .397 r
.67939 .62508 m .67824 .62483 L .68109 .62483 L F
0 .532 .755 r
.68368 .62577 m .67939 .62508 L .68109 .62483 L F
.509 .246 .452 r
.33181 .75475 m .33368 .75453 L .33434 .75211 L F
.485 .291 .543 r
.33434 .75211 m .33625 .75209 L .33641 .74967 L F
.635 .444 .607 r
.33368 .75453 m .33625 .75209 L .33434 .75211 L F
.916 .879 .784 r
.69832 .7044 m .69665 .70749 L .69556 .70655 L F
.959 .892 .718 r
.56759 .79791 m .56679 .80021 L .5672 .79879 L F
.331 0 0 r
.37786 .72759 m .37998 .72746 L .38157 .72629 L F
.473 .018 .09 r
.37998 .72746 m .38373 .72602 L .38157 .72629 L F
.772 .406 .362 r
.59247 .82916 m .59558 .82977 L .59332 .82896 L F
.751 .472 .509 r
.59243 .83177 m .59558 .82977 L .59247 .82916 L F
.59243 .83177 m .59609 .83245 L .59558 .82977 L F
.858 .538 .444 r
.57609 .787 m .57733 .78965 L .57881 .78968 L F
.856 .531 .436 r
.57733 .78965 m .57763 .79158 L .57881 .78968 L F
.866 .546 .443 r
.57763 .79158 m .57933 .79207 L .57881 .78968 L F
.891 .562 .418 r
.57881 .78968 m .57933 .79207 L .5806 .7921 L F
.786 .726 .797 r
.69352 .72053 m .69142 .72316 L .69457 .72338 L F
.708 .687 .827 r
.69352 .72053 m .69457 .72338 L .69697 .72273 L F
.559 .531 .78 r
.33647 .68572 m .33793 .68314 L .33574 .68344 L F
.33647 .68572 m .33893 .68545 L .33793 .68314 L F
.455 .266 .535 r
.33646 .68786 m .33893 .68545 L .33647 .68572 L F
.564 .433 .661 r
.34743 .73593 m .34783 .73914 L .34976 .73698 L F
.479 .215 .436 r
.3581 .68577 m .35573 .68805 L .35618 .68615 L F
.487 .425 .713 r
.32787 .7011 m .33017 .70085 L .32967 .69856 L F
.32787 .7011 m .32867 .70165 L .33017 .70085 L F
.781 .665 .735 r
.70029 .71142 m .69745 .71455 L .69797 .71281 L F
.445 .376 .686 r
.70218 .70968 m .70196 .71141 L .70029 .71142 L F
.594 .565 .79 r
.70348 .71318 m .70029 .71142 L .70196 .71141 L F
.848 .729 .732 r
.68656 .73873 m .68915 .73946 L .6881 .73594 L F
.715 .391 .429 r
.68612 .74099 m .68915 .73946 L .68656 .73873 L F
.68612 .74099 m .68957 .74118 L .68915 .73946 L F
.864 .737 .72 r
.6881 .73594 m .68915 .73946 L .68963 .73679 L F
.25 0 0 r
.6439 .61079 m .6472 .61031 L .64513 .61028 L F
.727 .511 .598 r
.58243 .82391 m .58583 .82176 L .58234 .8217 L F
.58243 .82391 m .58584 .82408 L .58583 .82176 L F
.361 .118 .404 r
.32531 .70573 m .32447 .70716 L .32671 .70457 L F
.315 0 0 r
.41067 .72336 m .41285 .72347 L .41408 .72305 L F
.128 .677 .763 r
.41285 .72347 m .41599 .72319 L .41408 .72305 L F
.916 .879 .784 r
.69832 .7044 m .69556 .70655 L .69728 .70393 L F
.39 .088 .329 r
.44056 .77527 m .43908 .77403 L .44122 .77385 L F
.44056 .77527 m .43852 .77579 L .43908 .77403 L F
.539 .131 .217 r
.358 .73525 m .36021 .73542 L .36112 .73419 L F
.485 .127 .282 r
.36021 .73542 m .36309 .73374 L .36112 .73419 L F
.337 .075 .362 r
.35134 .69339 m .34901 .69595 L .34965 .69407 L F
.57 .399 .61 r
.46975 .86418 m .47229 .86416 L .4723 .8614 L F
.417 .289 .598 r
.47042 .86707 m .47229 .86416 L .46975 .86418 L F
.771 .993 .879 r
.64427 .63328 m .64538 .63143 L .64631 .63136 L F
.365 .457 .822 r
.64427 .63328 m .6466 .63457 L .64538 .63143 L F
.7 .819 .939 r
.41207 .74182 m .41547 .7419 L .41416 .74127 L F
.378 .64 .958 r
.41547 .7419 m .41623 .74074 L .41416 .74127 L F
.41547 .7419 m .4174 .74207 L .41623 .74074 L F
.427 .147 .383 r
.47808 .83763 m .48003 .83736 L .48099 .83579 L F
.978 .783 .573 r
.6415 .59715 m .64205 .60127 L .64093 .60048 L F
.84 .505 .421 r
.64205 .60127 m .6408 .60322 L .64093 .60048 L F
.64205 .60127 m .64275 .60291 L .6408 .60322 L F
.577 .523 .759 r
.46467 .74271 m .46368 .74694 L .46323 .74499 L F
.46467 .74271 m .46574 .74657 L .46368 .74694 L F
.369 .672 .975 r
.32766 .65394 m .32705 .65511 L .32547 .6538 L F
.32766 .65394 m .3291 .65512 L .32705 .65511 L F
.626 .119 .025 r
.50664 .87172 m .50985 .87214 L .50678 .87098 L F
.73 .37 .369 r
.50345 .87157 m .50415 .86925 L .50354 .86897 L F
.50345 .87157 m .50664 .87172 L .50415 .86925 L F
0 .532 .755 r
.68368 .62577 m .68245 .62547 L .67939 .62508 L F
.948 .789 .65 r
.68368 .62577 m .68058 .62832 L .68245 .62547 L F
.68368 .62577 m .68171 .6291 L .68058 .62832 L F
.818 .581 .581 r
.68496 .6292 m .68171 .6291 L .68368 .62577 L F
.427 .365 .685 r
.68567 .62373 m .68604 .62636 L .68368 .62577 L F
.449 .402 .714 r
.68604 .62636 m .68496 .6292 L .68368 .62577 L F
.904 .743 .671 r
.71429 .71475 m .71529 .71772 L .71591 .7155 L F
.33 .568 .925 r
.47609 .88117 m .47697 .87992 L .47499 .87993 L F
.47609 .88117 m .47906 .88197 L .47697 .87992 L F
.465 .213 .447 r
.37312 .75499 m .37084 .75736 L .37128 .75534 L F
.513 .372 .627 r
.36456 .67703 m .36428 .68004 L .36223 .6799 L F
.507 .321 .563 r
.36428 .68004 m .36271 .68076 L .36223 .6799 L F
.592 .128 .122 r
.65196 .63665 m .65298 .63534 L .64969 .6354 L F
0 0 0 r
.65196 .63665 m .65446 .63424 L .65298 .63534 L F
.762 .445 .448 r
.49021 .87456 m .49269 .87288 L .49027 .87258 L F
.49021 .87456 m .49352 .87481 L .49269 .87288 L F
.477 .602 .898 r
.68782 .59586 m .68652 .59749 L .68558 .59458 L F
.68782 .59586 m .68852 .59744 L .68652 .59749 L F
.609 .608 .825 r
.35561 .67405 m .35353 .67466 L .35231 .67187 L F
.576 .404 .612 r
.34804 .78142 m .34555 .77911 L .34771 .77979 L F
.34804 .78142 m .34604 .78201 L .34555 .77911 L F
.592 .394 .583 r
.54935 .79809 m .54746 .80097 L .54929 .80005 L F
.169 .107 .539 r
.54929 .80005 m .55083 .7966 L .54935 .79809 L F
.669 .553 .714 r
.67271 .71481 m .66935 .71207 L .67062 .71497 L F
.67271 .71481 m .67273 .71284 L .66935 .71207 L F
.34 .1 .397 r
.67939 .62508 m .67832 .62654 L .67824 .62483 L F
.235 0 0 r
.40055 .79122 m .39703 .7931 L .39851 .79183 L F
.344 .731 .985 r
.56272 .81916 m .56463 .81923 L .5634 .81842 L F
.115 .137 .606 r
.47955 .85013 m .47992 .85308 L .47864 .85114 L F
.448 .249 .517 r
.47864 .85114 m .47992 .85308 L .47818 .85329 L F
.802 .69 .741 r
.48089 .86378 m .48366 .8645 L .48457 .86367 L F
.219 0 .121 r
.48366 .8645 m .48645 .86249 L .48457 .86367 L F
.761 .692 .785 r
.50644 .85607 m .50728 .85835 L .50977 .85632 L F
.63 .566 .764 r
.46227 .7417 m .46002 .74197 L .459 .73915 L F
.431 .013 .143 r
.42334 .77053 m .42549 .77033 L .4268 .76855 L F
.46 .06 .193 r
.42549 .77033 m .42896 .76828 L .4268 .76855 L F
.553 .299 .485 r
.36107 .76283 m .3587 .76507 L .35904 .76319 L F
.674 .552 .708 r
.69745 .71455 m .69432 .71189 L .69797 .71281 L F
.69745 .71455 m .69569 .71568 L .69432 .71189 L F
.233 .643 .959 r
.54267 .84018 m .54121 .83919 L .54098 .8375 L F
.54267 .84018 m .54348 .83944 L .54121 .83919 L F
0 0 .436 r
.54267 .84018 m .54294 .84241 L .54348 .83944 L F
.397 .344 .681 r
.6935 .60779 m .69389 .61058 L .69226 .61103 L F
.398 .302 .629 r
.69429 .61291 m .69226 .61103 L .69389 .61058 L F
.69429 .61291 m .69197 .61402 L .69226 .61103 L F
.433 .268 .557 r
.33766 .71087 m .33607 .70994 L .33753 .70944 L F
.33766 .71087 m .33599 .71188 L .33607 .70994 L F
.493 .267 .499 r
.47325 .84552 m .47575 .84264 L .47393 .84321 L F
.417 .289 .598 r
.47042 .86707 m .47186 .86693 L .47229 .86416 L F
.427 .327 .639 r
.47042 .86707 m .47235 .86916 L .47186 .86693 L F
.47042 .86707 m .47075 .86945 L .47235 .86916 L F
.485 .794 .999 r
.36556 .78855 m .36485 .78961 L .36347 .78883 L F
.391 .673 .972 r
.36556 .78855 m .36698 .78982 L .36485 .78961 L F
.737 .621 .731 r
.48261 .87461 m .48538 .87492 L .48599 .87464 L F
.465 .275 .537 r
.48599 .87464 m .48793 .87484 L .48835 .8719 L F
.32 .14 .473 r
.33016 .69638 m .33195 .69584 L .33174 .6931 L F
.473 .343 .622 r
.33174 .6931 m .33416 .69326 L .334 .69053 L F
.465 .239 .487 r
.33195 .69584 m .33416 .69326 L .33174 .6931 L F
.602 .802 .977 r
.35414 .79093 m .35068 .79031 L .35252 .7893 L F
.623 .739 .93 r
.3561 .79025 m .35414 .79093 L .35252 .7893 L F
.469 .821 .997 r
.36384 .91227 m .36532 .91159 L .36468 .91177 L F
.36384 .91227 m .36532 .91159 L .36468 .91177 L F
.412 .814 .599 r
.39619 .78148 m .39711 .78083 L .3988 .77971 L F
0 0 0 r
.3988 .77971 m .39906 .77999 L .40064 .77918 L F
.3988 .77971 m .39711 .78083 L .39906 .77999 L F
.202 .72 .69 r
.36692 .80479 m .37081 .8037 L .36895 .80454 L F
0 0 0 r
.36895 .80454 m .37081 .8037 L .37265 .80293 L F
.992 .811 .559 r
.57638 .80785 m .57773 .80593 L .5767 .80502 L F
.57638 .80785 m .57736 .80832 L .57773 .80593 L F
.219 .68 .946 r
.48175 .88684 m .48372 .8863 L .48124 .88567 L F
.48175 .88684 m .48514 .88706 L .48372 .8863 L F
0 0 .198 r
.34222 .70349 m .34177 .70611 L .34042 .70395 L F
.774 .634 .706 r
.7137 .71982 m .7169 .72047 L .71529 .71772 L F
.767 .419 .396 r
.7137 .71982 m .71636 .72113 L .7169 .72047 L F
.755 .403 .387 r
.71636 .72113 m .71993 .72219 L .7169 .72047 L F
.59 .389 .578 r
.44643 .75774 m .44856 .75749 L .44893 .7551 L F
.625 .421 .586 r
.44893 .7551 m .45122 .75705 L .45076 .7544 L F
.44893 .7551 m .44856 .75749 L .45122 .75705 L F
.389 .283 .611 r
.69429 .61291 m .69427 .61501 L .69197 .61402 L F
.227 0 .302 r
.69429 .61291 m .69214 .61572 L .69197 .61402 L F
.98 .717 .458 r
.69122 .63242 m .69018 .63432 L .69016 .63169 L F
.69122 .63242 m .69123 .63477 L .69018 .63432 L F
.462 .805 .999 r
.69016 .63169 m .69339 .63207 L .69122 .63242 L F
.52 .327 .56 r
.69339 .63207 m .69123 .63477 L .69122 .63242 L F
.57 .794 .984 r
.33954 .65823 m .33579 .65783 L .33783 .65763 L F
.111 .605 .906 r
.33783 .65763 m .34112 .6586 L .33954 .65823 L F
.534 .236 .408 r
.4518 .7683 m .45068 .77095 L .44869 .77108 L F
.571 .275 .426 r
.45434 .76987 m .4518 .7683 L .45401 .76823 L F
.45434 .76987 m .45068 .77095 L .4518 .7683 L F
.589 .327 .488 r
.3641 .7602 m .36321 .76268 L .36107 .76283 L F
.629 .368 .505 r
.36597 .7624 m .3641 .7602 L .36641 .76007 L F
.36597 .7624 m .36321 .76268 L .3641 .7602 L F
.179 .504 .91 r
.39121 .78109 m .39072 .78207 L .38904 .78 L F
.35 .71 .985 r
.39121 .78109 m .39317 .78232 L .39072 .78207 L F
.679 .453 .572 r
.47696 .75777 m .47674 .76009 L .47465 .76001 L F
.672 .575 .737 r
.4802 .75593 m .47696 .75777 L .47675 .75579 L F
.613 .395 .562 r
.47941 .75959 m .47696 .75777 L .4802 .75593 L F
.47941 .75959 m .47674 .76009 L .47696 .75777 L F
0 0 .315 r
.53707 .82636 m .53785 .8279 L .53908 .82621 L F
.53707 .82636 m .53729 .82947 L .53785 .8279 L F
.78 .663 .734 r
.58368 .83512 m .58341 .83607 L .58193 .83357 L F
.69 .169 0 r
.5812 .83307 m .58282 .83441 L .58193 .83357 L F
.58282 .83441 m .58368 .83512 L .58193 .83357 L F
.565 .58 .827 r
.58193 .83357 m .58341 .83607 L .5836 .83549 L F
.771 .671 .752 r
.5812 .83307 m .58365 .83592 L .58366 .83557 L F
.58282 .83441 m .58366 .83557 L .58368 .83512 L F
.565 .58 .827 r
.58193 .83357 m .5836 .83549 L .58282 .83441 L F
.771 .671 .752 r
.5812 .83307 m .58366 .83557 L .58282 .83441 L F
.565 .58 .827 r
.58282 .83441 m .5836 .83549 L .58369 .83524 L F
.58193 .83357 m .58369 .83524 L .58392 .83457 L F
.486 .252 .484 r
.34901 .69595 m .3468 .69814 L .34724 .69657 L F
.574 .418 .633 r
.34477 .7869 m .34489 .78981 L .34274 .79025 L F
.665 .702 .874 r
.35068 .79031 m .34832 .79155 L .34709 .78934 L F
.577 .377 .573 r
.34094 .74426 m .34303 .74402 L .34325 .74145 L F
.543 .33 .541 r
.34325 .74145 m .34533 .74133 L .34588 .73897 L F
.553 .356 .568 r
.34325 .74145 m .34495 .74359 L .34533 .74133 L F
.34325 .74145 m .34303 .74402 L .34495 .74359 L F
.26 .712 .956 r
.43703 .72828 m .43914 .72832 L .44032 .72885 L F
.411 .818 .979 r
.43914 .72832 m .44232 .72841 L .44032 .72885 L F
.795 .678 .734 r
.63801 .61055 m .63918 .61347 L .63663 .61314 L F
.63801 .61055 m .63958 .61151 L .63918 .61347 L F
.996 .762 .431 r
.63754 .6165 m .63663 .61314 L .63918 .61347 L F
.764 .5 .535 r
.63793 .63694 m .63764 .63728 L .63688 .63805 L F
.735 .659 .775 r
.63454 .64043 m .63742 .64023 L .63688 .63805 L F
.764 .5 .535 r
.63764 .63728 m .63581 .63944 L .63688 .63805 L F
.735 .659 .775 r
.63451 .64043 m .63454 .64043 L .63688 .63805 L F
.661 .32 .385 r
.63451 .64043 m .63679 .64229 L .63742 .64023 L F
.787 .427 .375 r
.63922 .64014 m .63688 .63805 L .63742 .64023 L F
.365 .042 .277 r
.63742 .64023 m .63894 .64162 L .63922 .64014 L F
.63742 .64023 m .63679 .64229 L .63894 .64162 L F
.824 .481 .407 r
.6864 .72328 m .68328 .72283 L .68165 .72085 L F
.753 .48 .52 r
.6864 .72328 m .6827 .72503 L .68328 .72283 L F
.6864 .72328 m .68595 .72544 L .6827 .72503 L F
.628 .546 .743 r
.6864 .72328 m .68916 .72564 L .68595 .72544 L F
.215 0 .349 r
.68774 .72253 m .68595 .72544 L .6864 .72328 L F
.628 .546 .743 r
.6864 .72328 m .68595 .72544 L .68774 .72253 L F
.314 .109 .434 r
.32967 .69856 m .33195 .69584 L .33016 .69638 L F
.807 .651 .689 r
.67062 .71774 m .67367 .7178 L .67271 .71481 L F
.627 .428 .593 r
.67165 .72045 m .67367 .7178 L .67062 .71774 L F
.67165 .72045 m .67383 .72011 L .67367 .7178 L F
.585 .527 .756 r
.67367 .7178 m .67651 .71408 L .67271 .71481 L F
.823 .741 .773 r
.68957 .74118 m .6874 .74425 L .69032 .7442 L F
.572 .412 .625 r
.60312 .64861 m .60569 .64831 L .6057 .64558 L F
.523 .3 .518 r
.60312 .64861 m .60519 .65026 L .60569 .64831 L F
.60312 .64861 m .603 .6507 L .60519 .65026 L F
.60312 .64861 m .60519 .65026 L .60569 .64831 L F
.60312 .64861 m .603 .6507 L .60519 .65026 L F
.708 .687 .827 r
.69352 .72053 m .69697 .72273 L .69571 .71981 L F
.63 .642 .843 r
.69697 .72273 m .69817 .71927 L .69571 .71981 L F
.69697 .72273 m .69945 .72243 L .69817 .71927 L F
.626 .669 .871 r
.69697 .72273 m .7 .72346 L .69945 .72243 L F
.832 .531 .48 r
.57437 .78882 m .57609 .787 L .57409 .78692 L F
.57437 .78882 m .57733 .78965 L .57609 .787 L F
.543 .658 .911 r
.48625 .87789 m .48743 .87988 L .48869 .87922 L F
.872 .711 .68 r
.59609 .83245 m .59569 .83448 L .59806 .83435 L F
.869 .776 .757 r
.59569 .83448 m .59649 .83727 L .59806 .83435 L F
.726 .605 .721 r
.64247 .60937 m .63958 .61151 L .63837 .60824 L F
.823 .925 .902 r
.67969 .59257 m .67607 .59415 L .67869 .59182 L F
.545 .834 .998 r
.68091 .59129 m .68195 .59204 L .67969 .59257 L F
.546 .834 .998 r
.68091 .59129 m .67969 .59257 L .67869 .59182 L F
.691 .684 .839 r
.53549 .83249 m .53788 .83269 L .5373 .83112 L F
.851 .879 .86 r
.52874 .82118 m .53247 .81921 L .52859 .81902 L F
.62 .315 .431 r
.43883 .76065 m .44067 .76229 L .44164 .76009 L F
.43883 .76065 m .43841 .76244 L .44067 .76229 L F
.368 .399 .762 r
.48086 .85559 m .47916 .85695 L .47818 .85329 L F
.955 .797 .351 r
.48086 .85559 m .48111 .85858 L .47916 .85695 L F
0 .435 .844 r
.69238 .70846 m .69094 .70829 L .69009 .70677 L F
.69238 .70846 m .69353 .7094 L .69094 .70829 L F
.196 .048 .441 r
.34224 .81369 m .34231 .81366 L .34217 .81446 L F
.423 .85 .711 r
.39619 .78148 m .39537 .78181 L .39711 .78083 L F
0 0 0 r
.66306 .64352 m .66183 .64424 L .65983 .64518 L F
.66396 .6434 m .66306 .64352 L .66528 .64307 L F
.66396 .6434 m .66183 .64424 L .66306 .64352 L F
.471 .258 .508 r
.34604 .70047 m .3448 .69882 L .3468 .69814 L F
.34604 .70047 m .34439 .70107 L .3448 .69882 L F
.543 .273 .456 r
.34533 .74133 m .34783 .73914 L .34588 .73897 L F
.828 .553 .522 r
.49681 .86608 m .49992 .86445 L .49646 .8642 L F
.49681 .86608 m .49991 .86671 L .49992 .86445 L F
.863 .584 .515 r
.56334 .80021 m .5605 .79987 L .56023 .79741 L F
.785 .656 .721 r
.56232 .80255 m .5605 .79987 L .56334 .80021 L F
.818 .594 .599 r
.56474 .80277 m .56232 .80255 L .56334 .80021 L F
.611 .415 .592 r
.39363 .74412 m .3936 .7468 L .39174 .74569 L F
.443 .28 .564 r
.396 .74523 m .39363 .74412 L .39564 .74374 L F
.396 .74523 m .3936 .7468 L .39363 .74412 L F
.403 .029 .211 r
.3936 .7468 m .39061 .7481 L .39174 .74569 L F
.737 .634 .745 r
.57944 .82146 m .58243 .82391 L .58234 .8217 L F
.617 .948 .936 r
.48378 .86957 m .48494 .86968 L .48565 .86849 L F
.831 .783 .806 r
.62935 .6294 m .62998 .63233 L .62814 .63167 L F
.847 .701 .701 r
.62998 .63233 m .62678 .63432 L .62814 .63167 L F
.62998 .63233 m .62921 .63469 L .62678 .63432 L F
.832 .784 .806 r
.62935 .6294 m .63213 .62957 L .62998 .63233 L F
.821 .75 .785 r
.54025 .84696 m .5413 .84835 L .53858 .84841 L F
.834 .806 .824 r
.5413 .84835 m .53754 .85 L .53858 .84841 L F
.749 .745 .848 r
.54025 .84696 m .54282 .84654 L .5413 .84835 L F
.653 .682 .864 r
.69945 .72243 m .7 .72346 L .70227 .72281 L F
.527 .352 .587 r
.33625 .75209 m .3382 .74917 L .33641 .74967 L F
.624 .632 .838 r
.6785 .72642 m .68054 .72557 L .68083 .72425 L F
.586 .47 .688 r
.44747 .74925 m .44931 .74681 L .44692 .7472 L F
.44747 .74925 m .44958 .74916 L .44931 .74681 L F
.661 .618 .796 r
.64817 .60066 m .64928 .59687 L .64668 .59987 L F
.64817 .60066 m .65068 .60019 L .64928 .59687 L F
.658 .284 .325 r
.51158 .87559 m .51322 .87709 L .51047 .87717 L F
.332 .31 .684 r
.51234 .87499 m .51322 .87709 L .51158 .87559 L F
.51234 .87499 m .51322 .87709 L .51158 .87559 L F
.335 .33 .705 r
.45992 .73567 m .45849 .73672 L .45788 .73371 L F
.574 .558 .798 r
.45992 .73567 m .459 .73915 L .45849 .73672 L F
.609 .382 .547 r
.70431 .70907 m .70218 .70968 L .70199 .707 L F
.151 0 .362 r
.66254 .62958 m .66089 .63282 L .6622 .63131 L F
.78 .998 .84 r
.6622 .63131 m .66089 .63282 L .65905 .63347 L F
0 0 0 r
.42646 .74212 m .42505 .74226 L .42248 .74241 L F
.56 .053 .006 r
.42854 .74191 m .42505 .74226 L .42646 .74212 L F
.581 .458 .677 r
.34605 .7839 m .34382 .78284 L .34604 .78201 L F
.34605 .7839 m .34398 .78428 L .34382 .78284 L F
.952 .601 .243 r
.67578 .70758 m .67646 .7073 L .67396 .70696 L F
.67578 .70758 m .67713 .70952 L .67646 .7073 L F
.827 .652 .666 r
.63837 .60824 m .63958 .61151 L .63801 .61055 L F
.918 .976 .766 r
.64075 .6039 m .63918 .60631 L .63925 .60515 L F
.606 .945 .931 r
.6408 .60322 m .64075 .6039 L .63925 .60515 L F
.6408 .60322 m .64275 .60291 L .64075 .6039 L F
.827 .919 .898 r
.38761 .78107 m .3859 .7825 L .38361 .78278 L F
.656 .361 .46 r
.44164 .76009 m .44377 .76214 L .44407 .76029 L F
.44164 .76009 m .44067 .76229 L .44377 .76214 L F
.966 .766 .584 r
.70555 .70982 m .70533 .7119 L .70431 .70907 L F
.817 .492 .44 r
.48089 .86378 m .4826 .86644 L .48366 .8645 L F
.693 .339 .372 r
.48366 .8645 m .4826 .86644 L .48579 .86644 L F
.41 .132 .377 r
.32511 .72563 m .32251 .72789 L .32297 .72575 L F
0 .228 .739 r
.50205 .88551 m .5039 .88776 L .50189 .88601 L F
.577 .904 .98 r
.34237 .8128 m .34231 .81366 L .34347 .81294 L F
.751 .706 .169 r
.34217 .81446 m .34231 .81366 L .34237 .8128 L F
.799 .67 .721 r
.6349 .62099 m .63606 .62476 L .63319 .62397 L F
.788 .691 .758 r
.63319 .62397 m .63606 .62476 L .63424 .6269 L F
.746 .642 .744 r
.6349 .62099 m .6381 .62205 L .63606 .62476 L F
.912 .547 .327 r
.54349 .83183 m .54476 .83451 L .54604 .83493 L F
.995 .801 .535 r
.54488 .83664 m .54604 .83493 L .54476 .83451 L F
.54488 .83664 m .5457 .83741 L .54604 .83493 L F
.582 .367 .554 r
.44407 .76029 m .44629 .76005 L .44643 .75774 L F
.584 .368 .554 r
.44629 .76005 m .44856 .75749 L .44643 .75774 L F
.787 .427 .375 r
.63922 .64014 m .63782 .63766 L .63688 .63805 L F
.615 .547 .755 r
.34605 .7839 m .34477 .7869 L .34398 .78428 L F
.34605 .7839 m .34701 .78679 L .34477 .7869 L F
.597 .437 .635 r
.34709 .78934 m .34477 .7869 L .34701 .78679 L F
.34709 .78934 m .34489 .78981 L .34477 .7869 L F
.751 .65 .749 r
.67063 .61939 m .66968 .62208 L .66603 .62198 L F
.603 .395 .572 r
.66761 .62382 m .66968 .62208 L .66927 .62394 L F
.66761 .62382 m .66603 .62198 L .66922 .62207 L F
.66761 .62382 m .66717 .62435 L .66603 .62198 L F
.019 .229 .736 r
.66817 .62278 m .66761 .62382 L .66712 .62084 L F
.787 .662 .726 r
.66728 .62237 m .66761 .62382 L .66817 .62278 L F
.66462 .62114 m .66761 .62382 L .66728 .62237 L F
.66462 .62114 m .66717 .62435 L .66761 .62382 L F
.674 .908 .574 r
.66728 .62418 m .66717 .62435 L .66761 .62382 L F
.467 .507 .816 r
.66462 .62114 m .66728 .62237 L .66678 .62045 L F
.878 .66 .604 r
.66712 .62084 m .66714 .62109 L .66707 .62098 L F
.467 .507 .816 r
.66728 .62237 m .66719 .62159 L .66642 .61909 L F
.878 .66 .604 r
.66712 .62084 m .66707 .62098 L .6669 .62011 L F
.045 .246 .744 r
.66642 .61909 m .66712 .62084 L .66667 .61911 L F
.878 .66 .604 r
.66712 .62084 m .6669 .62011 L .66681 .61967 L F
.045 .246 .744 r
.66642 .61909 m .6669 .62011 L .66712 .62084 L F
.6669 .62011 m .66817 .62278 L .66712 .62084 L F
.467 .507 .816 r
.66719 .62159 m .66706 .62044 L .6669 .62011 L F
.66719 .62159 m .6669 .62011 L .66642 .61909 L F
.66617 .61937 m .66678 .62045 L .66642 .61909 L F
.66462 .62114 m .66678 .62045 L .66617 .61937 L F
.878 .66 .604 r
.66681 .61967 m .66576 .62463 L .66667 .61911 L F
.66707 .62098 m .66576 .62463 L .66681 .61967 L F
.816 .615 .631 r
.66643 .62588 m .66927 .62394 L .6671 .62444 L F
.878 .66 .604 r
.66707 .62098 m .6673 .62453 L .66576 .62463 L F
.66714 .62109 m .6673 .62453 L .66707 .62098 L F
.849 .654 .115 r
.66712 .62084 m .66761 .62382 L .66717 .62188 L F
.467 .507 .816 r
.66728 .62237 m .66817 .62278 L .66706 .62044 L F
.849 .654 .115 r
.66717 .62188 m .66728 .62237 L .6673 .62453 L F
.66728 .62237 m .66761 .62382 L .66748 .62411 L F
.66728 .62237 m .66748 .62411 L .6673 .62453 L F
.674 .908 .574 r
.66817 .62278 m .66728 .62418 L .66761 .62382 L F
.603 .395 .572 r
.66761 .62382 m .66922 .62207 L .66968 .62208 L F
.444 .32 .616 r
.67142 .62124 m .66968 .62208 L .67063 .61939 L F
.318 .078 .384 r
.66968 .62208 m .66927 .62394 L .67142 .62124 L F
.66968 .62208 m .66927 .62394 L .67142 .62124 L F
.969 .934 .671 r
.63918 .60631 m .63757 .60793 L .63925 .60515 L F
.63918 .60631 m .63837 .60824 L .63757 .60793 L F
.248 0 .283 r
.51754 .86693 m .51553 .8693 L .5184 .86866 L F
.732 .426 .462 r
.5184 .86866 m .51971 .8692 L .51754 .86693 L F
0 0 .41 r
.5661 .81061 m .56709 .81384 L .56686 .81244 L F
.962 .942 .682 r
.56686 .81244 m .56709 .81384 L .56559 .81494 L F
.762 .639 .725 r
.68175 .74389 m .68487 .74672 L .68404 .74372 L F
.68175 .74389 m .68318 .74728 L .68487 .74672 L F
.713 .718 .853 r
.68404 .74372 m .68487 .74672 L .6874 .74425 L F
.107 0 0 r
.40858 .78738 m .40716 .78897 L .40561 .789 L F
.103 0 0 r
.40716 .78897 m .40525 .7897 L .40561 .789 L F
.839 .764 .78 r
.63132 .62683 m .63213 .62957 L .62935 .6294 L F
.812 .751 .795 r
.63132 .62683 m .63424 .6269 L .63213 .62957 L F
.583 .019 0 r
.54234 .84061 m .5398 .83938 L .54121 .83919 L F
.54327 .84178 m .54148 .84055 L .54234 .84061 L F
.54148 .84055 m .5398 .83938 L .54234 .84061 L F
.813 .906 .905 r
.54348 .83944 m .54326 .84068 L .54599 .83932 L F
.54326 .84068 m .54294 .84241 L .54455 .84078 L F
.54326 .84068 m .54455 .84078 L .54599 .83932 L F
.74 .714 .828 r
.54294 .84241 m .54785 .84031 L .54599 .83932 L F
.297 .126 .473 r
.4723 .8614 m .4736 .86117 L .4739 .85879 L F
.48 .327 .595 r
.4723 .8614 m .47421 .86366 L .4736 .86117 L F
.4723 .8614 m .47229 .86416 L .47421 .86366 L F
.915 .768 .683 r
.48826 .85907 m .48793 .86129 L .48928 .85784 L F
.555 .932 .83 r
.37245 .78714 m .37316 .78629 L .37424 .7857 L F
.37245 .78714 m .37057 .78777 L .37316 .78629 L F
.686 .412 .501 r
.62374 .65339 m .62063 .65571 L .62034 .65374 L F
.62374 .65339 m .62273 .65605 L .62063 .65571 L F
.633 .344 .461 r
.62598 .65376 m .62273 .65605 L .62374 .65339 L F
.6 .458 .659 r
.35435 .77035 m .3543 .77043 L .35173 .77015 L F
.525 .341 .574 r
.3543 .77043 m .35215 .77326 L .35173 .77015 L F
.718 .671 .804 r
.47675 .75579 m .47335 .75523 L .47547 .75535 L F
.721 .889 .957 r
.47906 .75472 m .47675 .75579 L .47547 .75535 L F
.672 .575 .737 r
.4802 .75593 m .47675 .75579 L .47906 .75472 L F
.678 .701 .864 r
.45788 .73371 m .45471 .73289 L .45662 .73269 L F
.53 .73 .966 r
.45875 .73225 m .45788 .73371 L .45662 .73269 L F
.45875 .73225 m .45974 .73326 L .45788 .73371 L F
.482 .347 .621 r
.45974 .73326 m .45992 .73567 L .45788 .73371 L F
.797 .447 .395 r
.49977 .86723 m .50299 .86726 L .49991 .86671 L F
.49977 .86723 m .50354 .86897 L .50299 .86726 L F
.352 0 .177 r
.31882 .71179 m .32075 .71139 L .32195 .70923 L F
.208 0 .143 r
.32447 .70716 m .32195 .70923 L .32354 .70851 L F
.224 0 .107 r
.32195 .70923 m .32251 .71072 L .32354 .70851 L F
.32195 .70923 m .32075 .71139 L .32251 .71072 L F
.604 .409 .591 r
.43607 .76476 m .43841 .76244 L .43657 .76308 L F
.828 .63 .635 r
.6358 .61921 m .6381 .62205 L .6349 .62099 L F
.414 .79 .993 r
.4948 .89 m .49702 .88983 L .4959 .88921 L F
.576 .689 .918 r
.44908 .73157 m .4459 .73039 L .44786 .73045 L F
.57 .766 .971 r
.45107 .73115 m .44908 .73157 L .44786 .73045 L F
.499 .889 .956 r
.5046 .88764 m .5074 .88731 L .50667 .88683 L F
.617 .948 .936 r
.5074 .88731 m .50814 .88613 L .50667 .88683 L F
.5074 .88731 m .51033 .88587 L .50814 .88613 L F
.544 .384 .615 r
.32988 .75768 m .33197 .75712 L .33181 .75475 L F
.585 .424 .63 r
.32985 .76005 m .33197 .75712 L .32988 .75768 L F
.078 0 .137 r
.32671 .70457 m .32447 .70716 L .32587 .70612 L F
.235 0 .245 r
.32354 .70851 m .32587 .70612 L .32447 .70716 L F
.27 0 .145 r
.42969 .78029 m .42892 .77888 L .43101 .77855 L F
.42969 .78029 m .42782 .78097 L .42892 .77888 L F
.598 .708 .921 r
.42282 .72583 m .41959 .72476 L .42155 .72506 L F
.429 .783 .997 r
.42359 .72491 m .42282 .72583 L .42155 .72506 L F
.42359 .72491 m .42488 .72561 L .42282 .72583 L F
.363 0 .05 r
.31399 .67463 m .31193 .67553 L .31315 .6749 L F
.31399 .67463 m .3104 .6766 L .31193 .67553 L F
.694 .264 .223 r
.31739 .67504 m .31589 .6762 L .31399 .67463 L F
.385 .841 .908 r
.65753 .59709 m .65802 .59725 L .6568 .59756 L F
.65576 .59782 m .65802 .59725 L .65753 .59709 L F
.65753 .59709 m .65802 .59725 L .65576 .59782 L F
.493 .177 .358 r
.65753 .59709 m .65672 .59938 L .65452 .5991 L F
.701 .982 .887 r
.65905 .59574 m .65802 .59725 L .65753 .59709 L F
.526 .208 .372 r
.65753 .59709 m .65959 .59743 L .65905 .59574 L F
.65753 .59709 m .65672 .59938 L .65959 .59743 L F
0 0 0 r
.6582 .59666 m .65753 .59709 L .65641 .5986 L F
.65905 .59574 m .65753 .59709 L .6582 .59666 L F
.385 .841 .908 r
.65753 .59709 m .6568 .59756 L .65576 .59782 L F
.431 .757 .995 r
.65753 .59709 m .65576 .59782 L .65473 .59696 L F
.81 .867 .424 r
.54349 .83183 m .54209 .83548 L .5424 .8339 L F
.855 .944 .58 r
.54098 .8375 m .5424 .8339 L .54209 .83548 L F
.442 .804 .996 r
.3093 .65349 m .31126 .65319 L .31271 .65383 L F
.377 .744 .991 r
.31322 .65289 m .31271 .65383 L .31126 .65319 L F
.31322 .65289 m .31478 .65378 L .31271 .65383 L F
.587 .395 .588 r
.34081 .74642 m .34303 .74402 L .34094 .74426 L F
.644 .583 .771 r
.57493 .83774 m .57735 .83575 L .57384 .8346 L F
.57493 .83774 m .57729 .83734 L .57735 .83575 L F
.821 .707 .739 r
.63319 .62397 m .63424 .6269 L .63132 .62683 L F
.771 .403 .357 r
.56474 .80277 m .56363 .80455 L .56232 .80255 L F
.813 .458 .383 r
.56616 .80496 m .56363 .80455 L .56474 .80277 L F
.461 .889 .858 r
.3469 .8122 m .35 .81131 L .35045 .8124 L F
.203 0 0 r
.40912 .78841 m .40858 .78738 L .41051 .7867 L F
.40912 .78841 m .40716 .78897 L .40858 .78738 L F
.997 .825 .552 r
.37452 .78431 m .37479 .78511 L .37657 .78395 L F
.37452 .78431 m .37424 .7857 L .37316 .78629 L F
.37452 .78431 m .37316 .78629 L .37479 .78511 L F
.851 .768 .77 r
.59377 .83717 m .59649 .83727 L .59569 .83448 L F
.846 .781 .788 r
.59431 .83988 m .59649 .83727 L .59377 .83717 L F
.534 .337 .559 r
.35215 .77326 m .34989 .77576 L .35023 .77375 L F
.245 0 0 r
.38569 .72557 m .38872 .7246 L .3866 .72492 L F
0 0 0 r
.37631 .80162 m .37818 .80066 L .38004 .79991 L F
.983 .754 .35 r
.67408 .60873 m .67329 .60971 L .67319 .60759 L F
.67408 .60873 m .67404 .6108 L .67329 .60971 L F
.978 .722 .313 r
.67319 .60759 m .67329 .60971 L .67262 .60877 L F
0 .042 .57 r
.67329 .60971 m .67502 .61037 L .67267 .60879 L F
.67329 .60971 m .67267 .60879 L .67262 .60877 L F
.983 .754 .35 r
.67404 .6108 m .67402 .61142 L .67329 .60971 L F
.685 .601 .757 r
.48267 .85939 m .48645 .86249 L .4847 .85866 L F
.592 .549 .775 r
.4847 .85866 m .48645 .86249 L .48793 .86129 L F
.717 .296 .246 r
.48645 .86249 m .48656 .86359 L .48793 .86129 L F
.589 .526 .752 r
.46467 .74271 m .46323 .74499 L .46227 .7417 L F
.841 .739 .751 r
.6151 .6536 m .61228 .65302 L .61404 .65082 L F
.844 .515 .43 r
.6151 .6536 m .61331 .65498 L .61228 .65302 L F
.77 .708 .793 r
.6172 .65093 m .6151 .6536 L .61404 .65082 L F
.759 .378 .334 r
.6151 .6536 m .61688 .65582 L .61331 .65498 L F
.689 .584 .732 r
.6172 .65093 m .61889 .65362 L .6151 .6536 L F
.664 .383 .485 r
.61889 .65362 m .61688 .65582 L .6151 .6536 L F
.827 .919 .898 r
.38761 .78107 m .38361 .78278 L .38617 .78078 L F
.602 .922 .971 r
.38904 .78 m .38761 .78107 L .38617 .78078 L F
.955 .775 .621 r
.70883 .7037 m .70969 .70671 L .71027 .70457 L F
.744 .559 .645 r
.67062 .71774 m .67271 .71481 L .67062 .71497 L F
.379 0 .152 r
.67271 .71481 m .67481 .71208 L .67273 .71284 L F
.625 .558 .759 r
.35108 .66652 m .34891 .6671 L .34793 .6638 L F
.486 .261 .497 r
.67332 .6379 m .67289 .64007 L .67085 .64056 L F
.093 0 .336 r
.67436 .63696 m .67289 .64007 L .67332 .6379 L F
.598 .482 .692 r
.51553 .8693 m .51784 .87121 L .5184 .86866 L F
.84 .56 .514 r
.51553 .8693 m .51867 .87287 L .51784 .87121 L F
.283 0 0 r
.38387 .75158 m .3825 .75147 L .38099 .75109 L F
.063 0 0 r
.3858 .75097 m .3825 .75147 L .38387 .75158 L F
.56 .766 .975 r
.42842 .72656 m .42488 .72561 L .42709 .7256 L F
.5 .746 .983 r
.42897 .72502 m .42842 .72656 L .42709 .7256 L F
.42897 .72502 m .43049 .72628 L .42842 .72656 L F
0 0 0 r
.63451 .64043 m .63688 .63805 L .63581 .63944 L F
.309 .362 .754 r
.63581 .63944 m .63679 .64229 L .63451 .64043 L F
.361 .465 .831 r
.6775 .61601 m .67965 .61477 L .67597 .61341 L F
.386 .726 .99 r
.36481 .8826 m .36444 .88285 L .36614 .88573 L F
.608 .824 .983 r
.36839 .88287 m .36481 .8826 L .36705 .88248 L F
.58 .59 .827 r
.36614 .88573 m .36705 .88248 L .36481 .8826 L F
.146 0 .231 r
.36614 .88573 m .36839 .88287 L .36813 .88529 L F
.58 .59 .827 r
.36614 .88573 m .36813 .88529 L .36705 .88248 L F
.015 .109 .619 r
.49164 .87886 m .49342 .8842 L .49195 .88088 L F
.303 .042 .342 r
.32587 .70612 m .32813 .70359 L .32671 .70457 L F
.813 .329 .012 r
.329 .67475 m .32653 .67275 L .32738 .67357 L F
.463 0 0 r
.70969 .70671 m .71275 .70772 L .71296 .70702 L F
.976 .68 .39 r
.68275 .70856 m .68264 .70989 L .68109 .70641 L F
.161 .698 .717 r
.67046 .64175 m .66825 .6422 L .67085 .64056 L F
.129 0 0 r
.67289 .64007 m .67046 .64175 L .67085 .64056 L F
.198 0 .333 r
.66254 .62958 m .66446 .6289 L .66457 .62668 L F
0 0 0 r
.6622 .63131 m .66446 .6289 L .66254 .62958 L F
.514 .31 .541 r
.52406 .87216 m .52631 .86952 L .52626 .87187 L F
.751 .261 .069 r
.52631 .86952 m .52364 .86843 L .52495 .86818 L F
.545 .382 .612 r
.52626 .87187 m .52814 .87383 L .52628 .87431 L F
.186 0 0 r
.52623 .87335 m .52626 .87187 L .52677 .87377 L F
.52616 .8733 m .52616 .8733 L .52623 .87335 L F
.52616 .8733 m .52626 .87187 L .52623 .87335 L F
.52616 .8733 m .52677 .87377 L .52677 .87377 L F
.209 .29 .729 r
.52623 .87335 m .52677 .87377 L .52746 .87371 L F
.52588 .87325 m .52677 .87377 L .52623 .87335 L F
.651 .458 .609 r
.52865 .8692 m .52626 .87187 L .52631 .86952 L F
.52865 .8692 m .52889 .87191 L .52626 .87187 L F
.638 .384 .517 r
.52626 .87187 m .52889 .87191 L .52814 .87383 L F
.209 .29 .729 r
.52591 .8731 m .52746 .87371 L .52627 .87116 L F
.52588 .87325 m .52623 .87335 L .52591 .8731 L F
.52623 .87335 m .52746 .87371 L .52591 .8731 L F
.549 .038 0 r
.52345 .87274 m .52677 .87377 L .52588 .87325 L F
.186 0 0 r
.52615 .87358 m .52616 .8733 L .52677 .87377 L F
0 0 .478 r
.52582 .87293 m .52588 .87325 L .52591 .8731 L F
.644 .469 .631 r
.52345 .87274 m .52588 .87325 L .52582 .87293 L F
.186 0 0 r
.52345 .87274 m .52543 .87213 L .52582 .87293 L F
.52543 .87213 m .52626 .87187 L .52615 .87358 L F
.52345 .87274 m .52406 .87216 L .52518 .87201 L F
.52543 .87213 m .52518 .87201 L .52626 .87187 L F
.52345 .87274 m .52518 .87201 L .52543 .87213 L F
.644 .469 .631 r
.52345 .87274 m .52582 .87293 L .52495 .86818 L F
.186 0 0 r
.52345 .87274 m .52582 .87293 L .52615 .87358 L F
0 0 .478 r
.5257 .87225 m .52582 .87293 L .52604 .87241 L F
.52582 .87293 m .52591 .8731 L .52604 .87241 L F
.52495 .86818 m .5257 .87225 L .52627 .87116 L F
.5257 .87225 m .52604 .87241 L .52627 .87116 L F
.574 .558 .798 r
.45992 .73567 m .46108 .73882 L .459 .73915 L F
.63 .566 .764 r
.46227 .7417 m .459 .73915 L .46108 .73882 L F
.607 .558 .773 r
.57729 .83734 m .57833 .84053 L .58033 .83987 L F
.451 .878 .915 r
.58033 .83987 m .57949 .83972 L .57833 .84053 L F
.643 .787 .951 r
.68119 .61576 m .68184 .61586 L .68187 .616 L F
.821 .897 .895 r
.68228 .61402 m .68187 .616 L .68565 .61255 L F
.68155 .61433 m .68184 .61586 L .68228 .61402 L F
.68184 .61586 m .68187 .616 L .68228 .61402 L F
.643 .787 .951 r
.68184 .61586 m .68472 .61627 L .68187 .616 L F
.686 .765 .912 r
.68246 .61714 m .68472 .61627 L .68184 .61586 L F
.68173 .61635 m .68184 .61586 L .68119 .61576 L F
.68246 .61714 m .68184 .61586 L .68173 .61635 L F
.821 .897 .895 r
.68088 .61462 m .68187 .616 L .68155 .61433 L F
0 .103 .599 r
.68346 .61784 m .68246 .61714 L .68119 .61576 L F
.68346 .61784 m .68441 .61879 L .68246 .61714 L F
.499 .226 .431 r
.334 .69053 m .336 .69015 L .33646 .68786 L F
.455 .266 .535 r
.33646 .68786 m .33857 .68776 L .33893 .68545 L F
.55 .329 .533 r
.336 .69015 m .33857 .68776 L .33646 .68786 L F
0 .364 .819 r
.3364 .67542 m .33677 .67495 L .33589 .67423 L F
.3364 .67542 m .3391 .67706 L .33677 .67495 L F
.498 .477 .764 r
.3364 .67542 m .33748 .67768 L .3391 .67706 L F
.68 .511 .651 r
.33748 .67768 m .34008 .68009 L .3391 .67706 L F
.33748 .67768 m .33789 .6803 L .34008 .68009 L F
.54 .728 .961 r
.33574 .68344 m .33793 .68314 L .33674 .68208 L F
.11 .383 .841 r
.66373 .62176 m .66462 .62114 L .66365 .6203 L F
.369 .364 .723 r
.51867 .87287 m .51989 .87159 L .51784 .87121 L F
.569 .33 .513 r
.37561 .75237 m .37558 .75467 L .37312 .75499 L F
.374 .176 .479 r
.37719 .75389 m .37561 .75237 L .37794 .75175 L F
.37719 .75389 m .37558 .75467 L .37561 .75237 L F
.742 .735 .845 r
.52745 .86737 m .52631 .86952 L .52495 .86818 L F
.628 .589 .791 r
.52745 .86737 m .52865 .8692 L .52631 .86952 L F
.971 .749 .546 r
.36705 .88248 m .36813 .88529 L .36839 .88287 L F
.255 .019 .35 r
.32813 .70359 m .33017 .70085 L .32867 .70165 L F
.064 0 0 r
.40599 .77616 m .40654 .77706 L .408 .77564 L F
.40599 .77616 m .40467 .77799 L .40654 .77706 L F
.502 .184 .36 r
.44644 .7711 m .44814 .7726 L .44601 .77295 L F
.532 .177 .31 r
.44869 .77108 m .44814 .7726 L .44644 .7711 L F
.489 .502 .797 r
.69032 .59732 m .68956 .6005 L .68852 .59744 L F
.69032 .59732 m .69144 .60021 L .68956 .6005 L F
.487 .473 .768 r
.69144 .60021 m .69238 .60214 L .68956 .6005 L F
.563 .352 .553 r
.3382 .74917 m .34081 .74642 L .33841 .74688 L F
.576 .365 .557 r
.54746 .80097 m .54959 .80235 L .54929 .80005 L F
.54929 .80005 m .54959 .80235 L .54746 .80097 L F
.547 .268 .444 r
.41858 .77218 m .42111 .77063 L .41881 .77077 L F
.728 .687 .811 r
.70533 .7119 m .70348 .71318 L .70196 .71141 L F
.439 .07 .239 r
.36509 .73344 m .36728 .73309 L .36838 .73107 L F
.389 .015 .202 r
.36728 .73309 m .37042 .73071 L .36838 .73107 L F
.995 .84 .573 r
.63837 .60824 m .63701 .60937 L .63757 .60793 L F
.63837 .60824 m .63801 .61055 L .63701 .60937 L F
.413 .317 .637 r
.56782 .82852 m .56931 .82654 L .56607 .8263 L F
.56782 .82852 m .56936 .82909 L .56931 .82654 L F
0 0 .159 r
.67416 .60072 m .67453 .60161 L .67365 .5998 L F
.67416 .60072 m .67379 .60333 L .67453 .60161 L F
.671 .716 .882 r
.35884 .67472 m .35561 .67405 L .35792 .67347 L F
.213 0 0 r
.35792 .67347 m .36106 .6742 L .35884 .67472 L F
.554 .22 .358 r
.48923 .86405 m .48579 .86644 L .48745 .86369 L F
.48923 .86405 m .48805 .86635 L .48579 .86644 L F
.545 .361 .582 r
.49212 .86425 m .49107 .86637 L .48923 .86405 L F
.29 0 .212 r
.48998 .86576 m .48805 .86635 L .48923 .86405 L F
.48998 .86576 m .48923 .86405 L .48745 .86369 L F
0 0 0 r
.6671 .62444 m .66457 .62668 L .66643 .62588 L F
.751 .706 .169 r
.34217 .81446 m .34084 .8154 L .34117 .81563 L F
.34217 .81446 m .34237 .8128 L .34084 .8154 L F
.674 .683 .85 r
.44619 .74619 m .44692 .7472 L .44931 .74681 L F
.79 .912 .52 r
.57831 .799 m .57802 .80019 L .57957 .79732 L F
.979 .713 .454 r
.57691 .80207 m .57802 .80019 L .57831 .799 L F
.57691 .80207 m .57811 .8028 L .57802 .80019 L F
.317 0 0 r
.39081 .72444 m .39294 .72437 L .39442 .72338 L F
.442 0 .031 r
.39294 .72437 m .39647 .72316 L .39442 .72338 L F
.593 .582 .811 r
.71545 .71626 m .71529 .71772 L .71429 .71475 L F
.874 .801 .775 r
.71216 .71968 m .71529 .71772 L .71545 .71626 L F
.71216 .71968 m .7137 .71982 L .71529 .71772 L F
.808 .734 .783 r
.68764 .73038 m .69032 .73097 L .68946 .72893 L F
.877 .649 .588 r
.68764 .73038 m .68995 .73297 L .69032 .73097 L F
.846 .916 .881 r
.68844 .72444 m .68916 .72564 L .69142 .72316 L F
.645 .838 .974 r
.68844 .72444 m .68595 .72544 L .68916 .72564 L F
.984 .714 .43 r
.68825 .72724 m .68916 .72564 L .68844 .72444 L F
.68825 .72724 m .68946 .72893 L .68916 .72564 L F
.442 0 0 r
.4959 .88512 m .49835 .88553 L .49906 .88495 L F
.456 .817 .551 r
.49906 .88495 m .49835 .88553 L .49967 .88444 L F
.601 .566 .787 r
.56564 .82381 m .56671 .82094 L .56701 .8222 L F
.596 .391 .574 r
.48793 .87484 m .49021 .87456 L .48835 .8719 L F
.727 .415 .452 r
.48835 .8719 m .49021 .87456 L .49027 .87258 L F
.935 .738 .612 r
.57655 .81301 m .57799 .81358 L .57688 .81061 L F
.966 .754 .565 r
.57656 .8152 m .57799 .81358 L .57655 .81301 L F
.57656 .8152 m .57779 .81595 L .57799 .81358 L F
.543 .273 .456 r
.34533 .74133 m .3474 .74104 L .34783 .73914 L F
.571 .443 .667 r
.34783 .73914 m .35019 .73912 L .34976 .73698 L F
.448 .186 .424 r
.34783 .73914 m .34942 .74045 L .35019 .73912 L F
.34783 .73914 m .3474 .74104 L .34942 .74045 L F
.534 .332 .553 r
.60843 .64836 m .61113 .64575 L .60672 .64567 L F
.60843 .64836 m .61061 .64793 L .61113 .64575 L F
.832 .751 .775 r
.62678 .63432 m .62921 .63469 L .62765 .63683 L F
.495 .308 .557 r
.34389 .70285 m .34263 .70167 L .34439 .70107 L F
.34389 .70285 m .34222 .70349 L .34263 .70167 L F
.444 .32 .616 r
.67142 .62124 m .67063 .61939 L .67134 .61899 L F
.793 .654 .709 r
.48069 .8768 m .4834 .87755 L .48261 .87461 L F
.79 .416 .348 r
.48069 .8768 m .48289 .87939 L .4834 .87755 L F
.737 .621 .731 r
.48261 .87461 m .4834 .87755 L .48538 .87492 L F
.825 .915 .899 r
.48289 .87939 m .48538 .87492 L .4834 .87755 L F
.691 .403 .481 r
.49623 .87975 m .49471 .88218 L .4948 .87987 L F
.49623 .87975 m .49716 .88284 L .49471 .88218 L F
.701 .567 .7 r
.49961 .87946 m .49716 .88284 L .49623 .87975 L F
.662 .583 .756 r
.56256 .80807 m .56388 .81154 L .5661 .81061 L F
.739 .679 .793 r
.54587 .81136 m .54708 .81392 L .54438 .81269 L F
.813 .416 .301 r
.54708 .81392 m .54615 .81539 L .54438 .81269 L F
.32 .449 .835 r
.54854 .81281 m .54708 .81392 L .54587 .81136 L F
0 0 0 r
.54854 .81281 m .54615 .81539 L .54708 .81392 L F
.314 0 0 r
.4102 .77561 m .41228 .77528 L .41372 .77374 L F
.201 0 0 r
.41372 .77374 m .4143 .77474 L .41582 .7735 L F
.41372 .77374 m .41228 .77528 L .4143 .77474 L F
.825 .915 .899 r
.48289 .87939 m .48625 .87789 L .48538 .87492 L F
.58 .481 .706 r
.48538 .87492 m .48808 .87695 L .48793 .87484 L F
.66 .462 .605 r
.48538 .87492 m .48625 .87789 L .48808 .87695 L F
.831 .385 .172 r
.4925 .86681 m .49456 .86951 L .49271 .86864 L F
.4925 .86681 m .49271 .86864 L .49333 .86606 L F
.581 .29 .439 r
.45958 .765 m .45825 .76771 L .45606 .7678 L F
.583 .297 .447 r
.46152 .76509 m .45825 .76771 L .45958 .765 L F
.893 .939 .836 r
.50786 .85467 m .50644 .85607 L .50858 .85338 L F
.841 .765 .779 r
.63887 .59704 m .64058 .59455 L .6415 .59715 L F
.852 .689 .68 r
.63887 .59704 m .6415 .59715 L .64093 .60048 L F
.721 .707 .836 r
.64058 .59455 m .64404 .59511 L .6415 .59715 L F
.545 .328 .536 r
.36903 .91137 m .36867 .91281 L .36675 .9125 L F
.36675 .9125 m .36867 .91281 L .36903 .91137 L F
.36903 .91137 m .36867 .91281 L .36675 .9125 L F
.23 .633 .957 r
.36675 .9125 m .36867 .91281 L .36532 .91159 L F
.36675 .9125 m .36867 .91281 L .36532 .91159 L F
.545 .385 .615 r
.33181 .75475 m .33388 .75664 L .33368 .75453 L F
.33181 .75475 m .33197 .75712 L .33388 .75664 L F
.521 .359 .602 r
.71519 .7297 m .71475 .73039 L .71467 .73087 L F
.207 .665 .945 r
.71462 .73124 m .71467 .73087 L .71223 .73065 L F
.644 .098 0 r
.71223 .73065 m .71112 .73006 L .70897 .72803 L F
.398 0 .028 r
.71467 .73087 m .71112 .73006 L .71223 .73065 L F
.71467 .73087 m .71129 .73225 L .71112 .73006 L F
.71467 .73087 m .71372 .73198 L .71129 .73225 L F
.521 .359 .602 r
.71475 .73039 m .71372 .73198 L .71467 .73087 L F
.207 .665 .945 r
.71557 .73148 m .71467 .73087 L .71462 .73124 L F
.762 .937 .941 r
.71638 .72972 m .71557 .73148 L .71744 .73028 L F
.71638 .72972 m .71467 .73087 L .71557 .73148 L F
.324 .026 .296 r
.34177 .70611 m .33753 .70944 L .33756 .70829 L F
.633 .102 0 r
.71636 .72113 m .71761 .72229 L .71993 .72219 L F
.694 .648 .8 r
.46892 .74927 m .46694 .75157 L .46692 .75008 L F
.59 .641 .869 r
.469 .75147 m .46694 .75157 L .46892 .74927 L F
.38 .834 .743 r
.38206 .7994 m .3858 .79789 L .38405 .79907 L F
0 0 0 r
.38405 .79907 m .3858 .79789 L .38755 .79709 L F
.507 .161 .315 r
.64229 .65075 m .64365 .65285 L .64136 .65273 L F
.64229 .65075 m .64452 .65066 L .64365 .65285 L F
.79 .405 0 r
.4805 .88473 m .48018 .88476 L .47906 .88197 L F
.64 .129 0 r
.4805 .88473 m .48124 .88567 L .48018 .88476 L F
.614 .766 .952 r
.38023 .78472 m .37657 .78395 L .37858 .78373 L F
.653 .836 .971 r
.38199 .78387 m .38023 .78472 L .37858 .78373 L F
.623 .334 .458 r
.44377 .76214 m .44608 .76222 L .44407 .76029 L F
.574 .34 .523 r
.44407 .76029 m .44608 .76222 L .44629 .76005 L F
.578 .512 .745 r
.47082 .87152 m .47235 .86916 L .47075 .86945 L F
.764 .5 .535 r
.63793 .63694 m .63922 .64014 L .63581 .63944 L F
.619 .824 .42 r
.63795 .62772 m .63782 .62784 L .63702 .62912 L F
.63795 .62772 m .63888 .62624 L .63782 .62784 L F
.709 .412 .472 r
.50654 .87504 m .50423 .87705 L .50463 .87446 L F
.50654 .87504 m .50773 .87704 L .50423 .87705 L F
.063 0 0 r
.3858 .75097 m .38457 .75133 L .3825 .75147 L F
.462 .013 .097 r
.38823 .74975 m .38457 .75133 L .3858 .75097 L F
.48 .817 .999 r
.31478 .65378 m .31663 .65339 L .31809 .65406 L F
.379 .775 .987 r
.3187 .65322 m .31809 .65406 L .31663 .65339 L F
.3187 .65322 m .32018 .65389 L .31809 .65406 L F
.696 .427 .513 r
.62063 .65571 m .61889 .65362 L .62034 .65374 L F
.638 .472 .641 r
.67166 .72283 m .67383 .72011 L .67165 .72045 L F
.597 .803 .978 r
.63856 .62402 m .64202 .6245 L .64188 .62377 L F
.546 0 0 r
.6443 .62411 m .64188 .62377 L .64202 .6245 L F
.715 .346 .348 r
.33379 .67429 m .33215 .67639 L .32949 .67559 L F
.501 .109 .229 r
.33589 .67423 m .33215 .67639 L .33379 .67429 L F
.937 .819 .367 r
.57961 .79457 m .57924 .79705 L .57957 .79732 L F
.915 .931 .56 r
.57924 .79705 m .57831 .799 L .57957 .79732 L F
.504 .703 .96 r
.33633 .65629 m .33579 .65783 L .33416 .65641 L F
.33633 .65629 m .33783 .65763 L .33579 .65783 L F
.405 .799 .987 r
.39854 .7229 m .40192 .7232 L .39984 .72324 L F
.434 .018 .148 r
.41592 .78402 m .41458 .78589 L .41253 .78596 L F
.354 0 .099 r
.41665 .78552 m .41592 .78402 L .41805 .78349 L F
.41665 .78552 m .41458 .78589 L .41592 .78402 L F
.696 .427 .513 r
.62063 .65571 m .61688 .65582 L .61889 .65362 L F
.823 .571 .558 r
.57782 .82036 m .57929 .81876 L .57765 .81829 L F
.57782 .82036 m .57944 .82146 L .57929 .81876 L F
.454 .271 .542 r
.55563 .78936 m .5536 .7918 L .55573 .79092 L F
0 0 0 r
.55313 .79418 m .55573 .79092 L .5536 .7918 L F
.633 .418 .573 r
.47465 .76001 m .47361 .76166 L .47296 .76002 L F
.579 .863 .995 r
.65193 .59169 m .64901 .59276 L .64802 .59149 L F
.65193 .59169 m .65106 .59216 L .64901 .59276 L F
.542 .333 .546 r
.33367 .7144 m .33511 .71626 L .33122 .71687 L F
.353 .143 .449 r
.33285 .71909 m .33122 .71687 L .33511 .71626 L F
.33285 .71909 m .33129 .71971 L .33122 .71687 L F
.392 .67 .97 r
.44675 .72926 m .4459 .73039 L .44403 .72862 L F
.44675 .72926 m .44786 .73045 L .4459 .73039 L F
.592 .539 .764 r
.47183 .87475 m .47323 .87148 L .47082 .87152 L F
.47183 .87475 m .47413 .87446 L .47323 .87148 L F
.193 .398 .835 r
.47183 .87475 m .47457 .87741 L .47413 .87446 L F
.82 .573 .566 r
.7059 .7031 m .70668 .70245 L .70494 .70123 L F
.629 .756 .938 r
.41943 .74206 m .42058 .74361 L .42248 .74241 L F
.507 .321 .563 r
.36428 .68004 m .36353 .68088 L .36271 .68076 L F
.44 .223 .487 r
.3642 .68432 m .36271 .68076 L .36353 .68088 L F
.3642 .68432 m .3623 .6849 L .36271 .68076 L F
.523 .263 .462 r
.55563 .78936 m .55785 .78907 L .55812 .78702 L F
.598 .328 .479 r
.55812 .78702 m .56024 .78886 L .56001 .78675 L F
.55812 .78702 m .55785 .78907 L .56024 .78886 L F
.408 .168 .435 r
.33599 .71188 m .33486 .71463 L .33367 .7144 L F
0 0 .318 r
.33486 .71463 m .33511 .71626 L .33367 .7144 L F
.606 .278 .388 r
.55422 .79822 m .55646 .79965 L .5517 .79989 L F
.521 .341 .577 r
.55696 .79944 m .55646 .79965 L .55422 .79822 L F
0 0 0 r
.35395 .81037 m .35732 .80816 L .35595 .80998 L F
.155 0 0 r
.35595 .80998 m .35732 .80816 L .35899 .8076 L F
.573 .565 .807 r
.46418 .74128 m .46227 .7417 L .46108 .73882 L F
.589 .526 .752 r
.46467 .74271 m .46227 .7417 L .46418 .74128 L F
.617 .601 .812 r
.6751 .72623 m .67219 .72477 L .67274 .7265 L F
.386 0 .091 r
.32493 .67265 m .32337 .67434 L .32145 .67459 L F
.6 .196 .249 r
.32724 .67365 m .32337 .67434 L .32493 .67265 L F
.813 .329 .012 r
.329 .67475 m .32789 .67448 L .32724 .67365 L F
.6 .196 .249 r
.32811 .67402 m .32741 .67407 L .32724 .67365 L F
.32741 .67407 m .32337 .67434 L .32724 .67365 L F
.813 .329 .012 r
.32704 .67316 m .32724 .67365 L .32653 .67275 L F
.329 .67475 m .32724 .67365 L .32704 .67316 L F
.547 .097 .134 r
.32741 .67407 m .32527 .67532 L .32337 .67434 L F
.813 .329 .012 r
.32789 .67448 m .32744 .6742 L .32735 .67379 L F
.547 .097 .134 r
.32811 .67402 m .32744 .6742 L .32741 .67407 L F
.6 .196 .249 r
.32724 .67365 m .32493 .67265 L .32653 .67275 L F
.813 .329 .012 r
.32735 .67379 m .32744 .6742 L .32653 .67275 L F
.6 .196 .249 r
.32811 .67402 m .32724 .67365 L .32653 .67275 L F
.687 .332 .367 r
.32653 .67275 m .32744 .6742 L .32811 .67402 L F
.32744 .6742 m .32756 .6744 L .32811 .67402 L F
.547 .097 .134 r
.32811 .67402 m .32746 .67432 L .32744 .6742 L F
.32746 .67432 m .32527 .67532 L .32741 .67407 L F
.813 .329 .012 r
.32789 .67448 m .32756 .6744 L .32744 .6742 L F
.559 .839 .997 r
.5914 .83969 m .59431 .83988 L .59327 .8392 L F
.846 .781 .788 r
.59431 .83988 m .59377 .83717 L .59327 .8392 L F
.849 .759 .763 r
.62486 .63717 m .62678 .63432 L .62765 .63683 L F
.847 .781 .788 r
.62486 .63717 m .62765 .63683 L .6255 .6399 L F
.464 .245 .496 r
.64887 .63171 m .6466 .63457 L .64969 .6354 L F
.761 .364 .301 r
.64848 .6367 m .64969 .6354 L .6466 .63457 L F
.591 .149 .168 r
.64848 .6367 m .65196 .63665 L .64969 .6354 L F
.401 0 0 r
.60071 .65316 m .60184 .65392 L .5993 .65222 L F
.512 .034 .058 r
.6031 .65327 m .60184 .65392 L .60071 .65316 L F
.829 .874 .877 r
.603 .6507 m .60071 .65316 L .5993 .65222 L F
0 0 .464 r
.603 .6507 m .6031 .65327 L .60071 .65316 L F
.031 .567 .852 r
.43379 .72743 m .43572 .72776 L .43703 .72828 L F
.321 .72 .98 r
.43782 .72755 m .43703 .72828 L .43572 .72776 L F
.43782 .72755 m .43914 .72832 L .43703 .72828 L F
.312 .757 .962 r
.36347 .78883 m .3615 .78896 L .36001 .78846 L F
.648 .388 .511 r
.46705 .7625 m .46704 .76531 L .46361 .7652 L F
.619 .364 .51 r
.46912 .76468 m .46705 .7625 L .4691 .76277 L F
.46912 .76468 m .46704 .76531 L .46705 .7625 L F
.926 .574 .343 r
.67839 .71678 m .67651 .71408 L .67805 .71516 L F
.452 0 0 r
.67805 .71516 m .67651 .71408 L .67702 .71447 L F
.67805 .71516 m .67702 .71447 L .67705 .71221 L F
.309 0 .031 r
.67657 .7111 m .67705 .71221 L .67628 .71089 L F
.829 .808 .831 r
.68028 .71202 m .67824 .7149 L .67705 .71221 L F
.68028 .71202 m .67705 .71221 L .67932 .7113 L F
.309 0 .031 r
.67867 .71263 m .67932 .7113 L .67705 .71221 L F
.67867 .71263 m .67705 .71221 L .67657 .7111 L F
.829 .808 .831 r
.67824 .7149 m .67805 .71516 L .67705 .71221 L F
.694 .602 .749 r
.68028 .71202 m .68169 .71578 L .67805 .71516 L F
.43 .032 .182 r
.43619 .77601 m .43286 .778 L .43341 .7769 L F
.685 .602 .757 r
.5705 .83205 m .5717 .83539 L .57384 .8346 L F
.721 .889 .957 r
.47906 .75472 m .47547 .75535 L .47779 .75505 L F
0 .353 .787 r
.47984 .75472 m .47906 .75472 L .47779 .75505 L F
.47984 .75472 m .48214 .7564 L .47906 .75472 L F
.4 .489 .835 r
.48214 .7564 m .4802 .75593 L .47906 .75472 L F
.48214 .7564 m .48204 .75735 L .4802 .75593 L F
.686 .507 .639 r
.48204 .75735 m .47941 .75959 L .4802 .75593 L F
.558 .23 .369 r
.42195 .78141 m .4202 .78368 L .41805 .78349 L F
.309 0 .186 r
.42212 .783 m .42195 .78141 L .42354 .78134 L F
.42212 .783 m .4202 .78368 L .42195 .78141 L F
.824 .57 .555 r
.68496 .6292 m .68185 .63106 L .68171 .6291 L F
.68496 .6292 m .68453 .63149 L .68185 .63106 L F
.449 .402 .714 r
.68604 .62636 m .68627 .62975 L .68496 .6292 L F
.528 .326 .55 r
.68496 .6292 m .68669 .63187 L .68453 .63149 L F
.68496 .6292 m .68627 .62975 L .68669 .63187 L F
.492 .418 .7 r
.65068 .60019 m .65255 .5975 L .64928 .59687 L F
.65068 .60019 m .65257 .59966 L .65255 .5975 L F
.65 .578 .761 r
.6836 .71465 m .68169 .71578 L .68028 .71202 L F
.916 .929 .806 r
.63473 .61859 m .63754 .6165 L .6358 .61921 L F
.63473 .61859 m .63668 .61576 L .63754 .6165 L F
.996 .762 .431 r
.63754 .6165 m .63668 .61576 L .63663 .61314 L F
.574 .615 .855 r
.69419 .60188 m .69337 .6055 L .69238 .60214 L F
.69419 .60188 m .69558 .60501 L .69337 .6055 L F
.519 .351 .593 r
.69558 .60501 m .6935 .60779 L .69337 .6055 L F
.267 .769 .747 r
.4988 .8894 m .50255 .88838 L .50138 .88823 L F
.4 .856 .845 r
.50255 .88838 m .5035 .88775 L .50138 .88823 L F
.50255 .88838 m .5046 .88764 L .5035 .88775 L F
.447 .684 .966 r
.47204 .75399 m .47547 .75535 L .47335 .75523 L F
.954 .634 .379 r
.69101 .70141 m .69221 .70401 L .69212 .70157 L F
.746 .585 .676 r
.64217 .64016 m .64511 .63997 L .64462 .63676 L F
.511 .36 .612 r
.64462 .63676 m .64681 .63687 L .6466 .63457 L F
.51 .324 .565 r
.64702 .6396 m .64462 .63676 L .64511 .63997 L F
.64702 .6396 m .64681 .63687 L .64462 .63676 L F
.608 .499 .703 r
.4724 .85141 m .47456 .85105 L .47396 .84748 L F
.69 .543 .681 r
.4724 .85141 m .47469 .85318 L .47456 .85105 L F
.4724 .85141 m .47256 .85343 L .47469 .85318 L F
.38 .14 .42 r
.33752 .71382 m .33599 .71188 L .33766 .71087 L F
.33752 .71382 m .33486 .71463 L .33599 .71188 L F
.633 .344 .461 r
.62598 .65376 m .62625 .65542 L .62273 .65605 L F
.661 .396 .508 r
.62598 .65376 m .62827 .65601 L .62625 .65542 L F
.62598 .65376 m .63017 .65354 L .62827 .65601 L F
.771 .671 .752 r
.5812 .83307 m .57897 .83753 L .58365 .83592 L F
.761 .631 .717 r
.57897 .83753 m .58033 .83987 L .58365 .83592 L F
.312 0 0 r
.30623 .6552 m .30685 .65359 L .30575 .65496 L F
.30623 .6552 m .30896 .65348 L .30685 .65359 L F
.253 .015 .347 r
.66457 .62668 m .66586 .62803 L .66643 .62588 L F
.66457 .62668 m .66446 .6289 L .66586 .62803 L F
.805 .705 .755 r
.53573 .85307 m .53656 .85369 L .53769 .85345 L F
.55 .364 .582 r
.53769 .85345 m .53674 .85574 L .53573 .85307 L F
.53769 .85345 m .53916 .856 L .53674 .85574 L F
.68 .526 .67 r
.54191 .85146 m .54039 .85565 L .53769 .85345 L F
.417 .513 .85 r
.53769 .85345 m .54039 .85565 L .5402 .85252 L F
.253 .07 .427 r
.53769 .85345 m .53971 .85441 L .53916 .856 L F
.53769 .85345 m .5402 .85252 L .53971 .85441 L F
.77 .708 .793 r
.6172 .65093 m .61404 .65082 L .61609 .64997 L F
.34 0 0 r
.61609 .64997 m .61945 .64836 L .6172 .65093 L F
.848 .782 .787 r
.6255 .6399 m .62287 .63989 L .62486 .63717 L F
.824 .681 .705 r
.6255 .6399 m .6224 .64201 L .62287 .63989 L F
.6255 .6399 m .6239 .64289 L .6224 .64201 L F
.176 0 0 r
.40116 .74253 m .39981 .74301 L .39785 .74304 L F
.142 0 0 r
.40339 .74295 m .39981 .74301 L .40116 .74253 L F
.928 .586 .365 r
.4782 .87388 m .47921 .87222 L .47886 .87182 L F
.4782 .87388 m .47959 .87462 L .47921 .87222 L F
.798 .488 .465 r
.47921 .87222 m .47959 .87462 L .48261 .87461 L F
.226 .737 .88 r
.40192 .7232 m .4041 .72301 L .40534 .7232 L F
.292 .785 .883 r
.4041 .72301 m .40735 .72275 L .40534 .7232 L F
.567 .493 .731 r
.47256 .85343 m .4737 .85864 L .47538 .85519 L F
.652 .478 .636 r
.4737 .85864 m .47486 .85862 L .47538 .85519 L F
.4737 .85864 m .4739 .85879 L .47486 .85862 L F
.398 0 .153 r
.37249 .7304 m .37458 .73009 L .37587 .72817 L F
.368 0 .136 r
.37587 .72817 m .37667 .72969 L .37786 .72759 L F
.37587 .72817 m .37458 .73009 L .37667 .72969 L F
.483 .167 .354 r
.43095 .76785 m .43307 .76754 L .43392 .76515 L F
.467 .152 .347 r
.43392 .76515 m .43517 .76713 L .43607 .76476 L F
.43392 .76515 m .43307 .76754 L .43517 .76713 L F
.65 .335 .426 r
.63473 .65322 m .63365 .65548 L .63135 .65365 L F
.589 .282 .416 r
.63686 .65307 m .63365 .65548 L .63473 .65322 L F
.169 .107 .539 r
.54929 .80005 m .55115 .79905 L .55083 .7966 L F
.532 .324 .543 r
.5517 .79989 m .54959 .80235 L .54929 .80005 L F
.579 .561 .798 r
.54959 .80235 m .55115 .79905 L .54929 .80005 L F
.736 .769 .879 r
.68507 .70738 m .68109 .70641 L .68126 .70481 L F
.657 .732 .905 r
.68686 .70611 m .68507 .70738 L .68126 .70481 L F
.161 .698 .717 r
.67046 .64175 m .66736 .64236 L .66825 .6422 L F
.524 .155 .282 r
.53328 .82657 m .53 .82869 L .5311 .82675 L F
.53328 .82657 m .5323 .82883 L .53 .82869 L F
.632 .474 .651 r
.53494 .82558 m .5323 .82883 L .53328 .82657 L F
.51 .662 .93 r
.45522 .73091 m .45471 .73289 L .45321 .73113 L F
.45522 .73091 m .45662 .73269 L .45471 .73289 L F
.954 .777 .625 r
.57559 .80999 m .57736 .80832 L .57638 .80785 L F
.57559 .80999 m .57688 .81061 L .57736 .80832 L F
0 .157 .673 r
.56463 .81923 m .56671 .82094 L .56567 .81976 L F
.173 .616 .939 r
.41839 .72391 m .42155 .72506 L .41959 .72476 L F
.767 .481 .501 r
.43472 .74022 m .4326 .74041 L .43425 .74087 L F
.453 .749 .992 r
.43425 .74087 m .43626 .74075 L .43472 .74022 L F
.301 .214 .588 r
.43425 .74087 m .43599 .74304 L .43626 .74075 L F
.61 .769 .956 r
.43472 .74022 m .43626 .74075 L .43831 .74014 L F
.819 .788 .823 r
.43599 .74304 m .43831 .74014 L .43626 .74075 L F
.66 .409 .529 r
.43831 .74014 m .43508 .74229 L .43472 .74022 L F
.867 .989 .831 r
.4362 .74148 m .43508 .74229 L .43611 .74161 L F
.43707 .74092 m .43611 .74161 L .43831 .74014 L F
.4362 .74148 m .43611 .74161 L .43707 .74092 L F
.301 .214 .588 r
.4353 .74218 m .43471 .74403 L .43599 .74304 L F
.43425 .74087 m .43452 .74273 L .4353 .74218 L F
.43452 .74273 m .43471 .74403 L .4353 .74218 L F
.934 .794 .682 r
.54286 .82953 m .54229 .83164 L .54349 .83183 L F
.865 .546 .446 r
.5424 .8339 m .54349 .83183 L .54229 .83164 L F
.5424 .8339 m .54476 .83451 L .54349 .83183 L F
.723 .899 .52 r
.64313 .61647 m .64199 .61782 L .64236 .61766 L F
0 0 0 r
.64347 .6168 m .64199 .61782 L .64313 .61647 L F
.109 0 0 r
.64347 .6168 m .64169 .61795 L .64199 .61782 L F
.64169 .61795 m .64074 .61857 L .64199 .61782 L F
.723 .899 .52 r
.64236 .61766 m .64199 .61782 L .64148 .61901 L F
.924 .656 .513 r
.63978 .62038 m .64148 .61901 L .64199 .61782 L F
.63978 .62038 m .64127 .62127 L .64148 .61901 L F
.239 .626 .958 r
.64314 .62149 m .64148 .61901 L .64127 .62127 L F
.732 .68 .8 r
.70431 .70907 m .70533 .7119 L .70196 .71141 L F
.633 .852 .983 r
.58921 .8404 m .5914 .83969 L .58811 .83965 L F
.682 .503 .638 r
.58243 .82391 m .5859 .8263 L .58584 .82408 L F
.796 .536 .545 r
.5859 .8263 m .58749 .82714 L .58584 .82408 L F
.752 .524 .586 r
.58584 .82408 m .58749 .82714 L .58933 .82626 L F
.69 .169 0 r
.5812 .83307 m .58193 .83357 L .58144 .83193 L F
.424 .589 .91 r
.58193 .83357 m .58378 .83348 L .58144 .83193 L F
.58193 .83357 m .58392 .83457 L .58378 .83348 L F
.605 .036 0 r
.329 .67475 m .32818 .67506 L .32756 .6744 L F
.329 .67475 m .32949 .67559 L .32818 .67506 L F
.556 .592 .845 r
.34844 .66056 m .34793 .6638 L .34643 .66146 L F
.34844 .66056 m .34986 .66344 L .34793 .6638 L F
.625 .558 .759 r
.35108 .66652 m .34793 .6638 L .34986 .66344 L F
.596 .368 .541 r
.45606 .7678 m .45434 .76987 L .45401 .76823 L F
.235 0 0 r
.40055 .79122 m .39979 .79217 L .39703 .7931 L F
.061 0 0 r
.40055 .79122 m .40326 .79038 L .40157 .7914 L F
.033 0 0 r
.40157 .7914 m .39979 .79217 L .40055 .79122 L F
.689 .466 .578 r
.48745 .86369 m .49141 .86145 L .48793 .86129 L F
.48745 .86369 m .49212 .86425 L .49141 .86145 L F
.673 .456 .583 r
.49141 .86145 m .49212 .86425 L .49324 .86379 L F
.591 .704 .922 r
.69945 .72243 m .69993 .71947 L .69817 .71927 L F
.69945 .72243 m .70238 .72222 L .69993 .71947 L F
.653 .682 .864 r
.69945 .72243 m .70227 .72281 L .70238 .72222 L F
0 .218 .649 r
.48662 .88768 m .48695 .88781 L .48514 .88706 L F
.48662 .88768 m .48805 .88858 L .48695 .88781 L F
.306 .243 .62 r
.68198 .72191 m .68083 .72425 L .68001 .72323 L F
.368 .399 .762 r
.48086 .85559 m .47818 .85329 L .47992 .85308 L F
0 0 0 r
.64313 .61647 m .6451 .61493 L .64317 .61646 L F
.64347 .6168 m .64313 .61647 L .64317 .61646 L F
.723 .521 .617 r
.4736 .86117 m .47486 .85862 L .4739 .85879 L F
.541 .453 .705 r
.67632 .63399 m .67471 .63486 L .67487 .63322 L F
.258 .085 .446 r
.67648 .63625 m .67471 .63486 L .67632 .63399 L F
.67648 .63625 m .67436 .63696 L .67471 .63486 L F
.592 .549 .775 r
.4847 .85866 m .48793 .86129 L .48826 .85907 L F
.749 .745 .848 r
.54025 .84696 m .54246 .84489 L .54282 .84654 L F
.32 .545 .912 r
.54452 .84639 m .54282 .84654 L .54246 .84489 L F
.674 .683 .85 r
.44619 .74619 m .44931 .74681 L .44767 .74644 L F
.562 .572 .822 r
.44931 .74681 m .4501 .74344 L .44767 .74644 L F
.44931 .74681 m .45132 .74644 L .4501 .74344 L F
.563 .464 .7 r
.44958 .74916 m .45132 .74644 L .44931 .74681 L F
.775 .35 .24 r
.49633 .86895 m .49622 .87123 L .49456 .86951 L F
.49633 .86895 m .49808 .87104 L .49622 .87123 L F
.882 .825 .786 r
.50561 .88223 m .50695 .88339 L .5039 .88776 L F
.445 .821 .991 r
.32018 .65389 m .32206 .65354 L .3235 .65405 L F
.407 .799 .988 r
.32419 .65323 m .3235 .65405 L .32206 .65354 L F
.32419 .65323 m .32547 .6538 L .3235 .65405 L F
.877 .649 .588 r
.68764 .73038 m .68757 .73324 L .68995 .73297 L F
.886 .817 .775 r
.68757 .73324 m .6881 .73594 L .68995 .73297 L F
.473 .018 .09 r
.37998 .72746 m .38216 .72754 L .38373 .72602 L F
.449 .035 .16 r
.38216 .72754 m .38569 .72557 L .38373 .72602 L F
.753 .669 .768 r
.48869 .87922 m .49164 .87886 L .49142 .87728 L F
.342 .082 .368 r
.48869 .87922 m .49003 .88128 L .49164 .87886 L F
.644 .618 .809 r
.49164 .87886 m .4925 .8758 L .49142 .87728 L F
.49164 .87886 m .4936 .87871 L .4925 .8758 L F
.585 .459 .675 r
.49471 .88218 m .49164 .87886 L .4948 .87987 L F
.49471 .88218 m .49342 .8842 L .49187 .87955 L F
.49216 .87942 m .49187 .87955 L .49164 .87886 L F
.49471 .88218 m .49187 .87955 L .49216 .87942 L F
.69 .405 .486 r
.49252 .88045 m .49477 .87902 L .49371 .87874 L F
.49353 .87882 m .49371 .87874 L .4936 .87871 L F
.49252 .88045 m .49371 .87874 L .49353 .87882 L F
.166 0 0 r
.49164 .87886 m .49252 .88045 L .4936 .87871 L F
.49164 .87886 m .49003 .88128 L .49252 .88045 L F
.89 .845 .794 r
.47913 .87727 m .48261 .87461 L .47959 .87462 L F
.47913 .87727 m .48069 .8768 L .48261 .87461 L F
.81 .715 .76 r
.36529 .67502 m .36456 .67703 L .36339 .67517 L F
.394 .267 .588 r
.36529 .67502 m .36428 .68004 L .36456 .67703 L F
.511 .688 .947 r
.70238 .72222 m .70227 .72281 L .70386 .72164 L F
.39 .44 .792 r
.70227 .72281 m .70453 .72438 L .70386 .72164 L F
.935 .893 .763 r
.63473 .61859 m .6358 .61921 L .6349 .62099 L F
.479 .215 .436 r
.3581 .68577 m .35775 .68765 L .35573 .68805 L F
.431 .173 .421 r
.35965 .68714 m .35775 .68765 L .3581 .68577 L F
0 .395 .68 r
.64398 .60771 m .6461 .60832 L .64286 .60739 L F
.879 .713 .673 r
.63801 .61055 m .63512 .61227 L .63701 .60937 L F
.63801 .61055 m .63663 .61314 L .63512 .61227 L F
.905 .584 .428 r
.54121 .83919 m .5398 .83938 L .54098 .8375 L F
.855 .944 .58 r
.54098 .8375 m .54075 .83719 L .5424 .8339 L F
.878 .905 .494 r
.54098 .8375 m .5398 .83938 L .54075 .83719 L F
.905 .584 .428 r
.54121 .83919 m .5398 .83938 L .54098 .8375 L F
.316 .791 .701 r
.36086 .80707 m .36493 .80546 L .36244 .8066 L F
.194 0 0 r
.36692 .80479 m .36244 .8066 L .36493 .80546 L F
.724 .64 .765 r
.68264 .70989 m .68417 .71247 L .68028 .71202 L F
.65 .578 .761 r
.6836 .71465 m .68028 .71202 L .68417 .71247 L F
.382 .214 .526 r
.54191 .85146 m .54348 .85044 L .54039 .85565 L F
.79 .617 .665 r
.71216 .71968 m .71636 .72113 L .7137 .71982 L F
.226 0 0 r
.42414 .78237 m .42354 .78134 L .42564 .78143 L F
.42414 .78237 m .42212 .783 L .42354 .78134 L F
.128 0 0 r
.393 .79413 m .3922 .795 L .38935 .79649 L F
.229 0 0 r
.39497 .79369 m .39414 .79453 L .393 .79413 L F
.219 0 0 r
.393 .79413 m .39414 .79453 L .3922 .795 L F
.671 .3 .334 r
.35728 .73557 m .36021 .73542 L .358 .73525 L F
.483 .861 .981 r
.64664 .62191 m .64903 .62116 L .64965 .6217 L F
.557 .901 .977 r
.64965 .6217 m .64589 .62203 L .64664 .62191 L F
.3 .795 .794 r
.64589 .62203 m .64903 .62116 L .64664 .62191 L F
.557 .901 .977 r
.64965 .6217 m .64903 .62116 L .64589 .62203 L F
.649 .21 .193 r
.70208 .70111 m .70494 .70123 L .70299 .70019 L F
.514 .218 .403 r
.36877 .76016 m .36597 .7624 L .36641 .76007 L F
.604 .257 .355 r
.50659 .87414 m .50985 .87214 L .50664 .87172 L F
.50659 .87414 m .50894 .8744 L .50985 .87214 L F
.671 .328 .383 r
.50985 .87214 m .50894 .8744 L .51242 .87415 L F
.85 .696 .691 r
.5451 .81152 m .54438 .81269 L .54289 .81031 L F
.5451 .81152 m .54438 .81269 L .54289 .81031 L F
.752 .616 .708 r
.58714 .82936 m .58943 .82946 L .58933 .82626 L F
.719 .501 .593 r
.58746 .83152 m .58943 .82946 L .58714 .82936 L F
.58746 .83152 m .58994 .83046 L .58943 .82946 L F
.676 .459 .584 r
.58994 .83046 m .59247 .82916 L .58943 .82946 L F
.609 .608 .825 r
.35561 .67405 m .35231 .67187 L .35425 .67147 L F
.586 .617 .849 r
.35792 .67347 m .35561 .67405 L .35425 .67147 L F
0 0 0 r
.65784 .64603 m .65836 .64629 L .65655 .64691 L F
.65784 .64603 m .65983 .64518 L .65836 .64629 L F
.587 .337 .505 r
.34976 .73698 m .35312 .73885 L .35019 .73912 L F
.26 0 0 r
.34942 .74045 m .35312 .73885 L .35019 .73912 L F
.34942 .74045 m .35165 .74012 L .35312 .73885 L F
.657 .867 .979 r
.35415 .7374 m .35312 .73885 L .35373 .73773 L F
.641 .481 .651 r
.35165 .74012 m .35373 .73773 L .35312 .73885 L F
.584 .368 .554 r
.44629 .76005 m .44852 .75982 L .44856 .75749 L F
.6 .381 .556 r
.44856 .75749 m .45112 .75892 L .45122 .75705 L F
.44856 .75749 m .44852 .75982 L .45112 .75892 L F
.72 .708 .838 r
.57266 .83139 m .57606 .83181 L .57476 .82927 L F
.75 .638 .736 r
.57266 .83139 m .57384 .8346 L .57606 .83181 L F
.683 .539 .683 r
.57384 .8346 m .57735 .83575 L .57606 .83181 L F
.589 .624 .854 r
.57606 .83181 m .57699 .82877 L .57476 .82927 L F
.57606 .83181 m .57846 .83156 L .57699 .82877 L F
.652 .521 .692 r
.57606 .83181 m .57957 .83495 L .57846 .83156 L F
.57606 .83181 m .57735 .83575 L .57957 .83495 L F
.43 .032 .182 r
.43619 .77601 m .43445 .77822 L .43286 .778 L F
.434 .037 .185 r
.43732 .7775 m .43619 .77601 L .43852 .77579 L F
.43732 .7775 m .43445 .77822 L .43619 .77601 L F
.578 .512 .745 r
.47082 .87152 m .47323 .87148 L .47235 .86916 L F
.676 .459 .584 r
.58994 .83046 m .59243 .83177 L .59247 .82916 L F
.485 .127 .282 r
.36021 .73542 m .3623 .73524 L .36309 .73374 L F
.337 0 .203 r
.36309 .73374 m .36433 .73465 L .36509 .73344 L F
.36309 .73374 m .3623 .73524 L .36433 .73465 L F
.669 .693 .864 r
.69009 .70677 m .68815 .70779 L .68686 .70611 L F
.307 0 0 r
.41416 .74127 m .41075 .74111 L .41207 .74182 L F
.517 .162 .303 r
.44331 .77359 m .44056 .77527 L .44122 .77385 L F
.935 .893 .763 r
.63473 .61859 m .6349 .62099 L .63229 .62108 L F
.854 .749 .747 r
.63229 .62108 m .6349 .62099 L .63319 .62397 L F
.174 .204 .652 r
.6657 .60725 m .66631 .61101 L .66591 .61015 L F
.801 .479 0 r
.66631 .61101 m .66701 .61331 L .66591 .61015 L F
.411 .818 .979 r
.43914 .72832 m .44119 .72799 L .44232 .72841 L F
.236 .654 .96 r
.44293 .72778 m .44232 .72841 L .44119 .72799 L F
.44293 .72778 m .44403 .72862 L .44232 .72841 L F
.588 .47 .685 r
.57729 .83734 m .57957 .83495 L .57735 .83575 L F
.57729 .83734 m .57897 .83753 L .57957 .83495 L F
.607 .558 .773 r
.57729 .83734 m .58033 .83987 L .57897 .83753 L F
.625 .546 .745 r
.34809 .78349 m .34701 .78679 L .34605 .7839 L F
.34809 .78349 m .34921 .78658 L .34701 .78679 L F
.61 .44 .627 r
.34921 .78658 m .34709 .78934 L .34701 .78679 L F
.599 .538 .757 r
.46755 .74426 m .46574 .74657 L .46467 .74271 L F
.651 .613 .798 r
.46755 .74426 m .46801 .74611 L .46574 .74657 L F
.66 .542 .709 r
.46892 .74927 m .46574 .74657 L .46801 .74611 L F
.46892 .74927 m .46692 .75008 L .46574 .74657 L F
.553 .299 .485 r
.36107 .76283 m .36095 .76489 L .3587 .76507 L F
.621 .356 .495 r
.36107 .76283 m .3629 .76486 L .36095 .76489 L F
.597 .356 .522 r
.36321 .76268 m .3629 .76486 L .36107 .76283 L F
.955 .797 .351 r
.48086 .85559 m .48063 .85797 L .48111 .85858 L F
0 0 0 r
.48054 .86028 m .47901 .86126 L .48111 .85858 L F
.48054 .86028 m .48111 .85858 L .48063 .85797 L F
.617 .318 .44 r
.63135 .65365 m .62827 .65601 L .63017 .65354 L F
.63135 .65365 m .63166 .65528 L .62827 .65601 L F
.646 .337 .434 r
.63135 .65365 m .63365 .65548 L .63166 .65528 L F
.395 .025 .214 r
.39061 .7481 m .38974 .75051 L .38823 .74975 L F
.403 .029 .211 r
.3936 .7468 m .39226 .74887 L .39061 .7481 L F
.435 .076 .256 r
.39226 .74887 m .38974 .75051 L .39061 .7481 L F
.761 .533 .588 r
.33674 .68208 m .34008 .68009 L .33789 .6803 L F
.46 .06 .193 r
.42549 .77033 m .42773 .77018 L .42896 .76828 L F
.363 0 .136 r
.42896 .76828 m .42977 .76974 L .43095 .76785 L F
.42896 .76828 m .42773 .77018 L .42977 .76974 L F
.324 .026 .296 r
.34177 .70611 m .34002 .70874 L .33753 .70944 L F
.427 .251 .537 r
.34002 .70874 m .33766 .71087 L .33753 .70944 L F
.633 .418 .573 r
.47465 .76001 m .47488 .7622 L .47361 .76166 L F
.686 .456 .569 r
.47465 .76001 m .4766 .76248 L .47488 .7622 L F
.679 .456 .575 r
.47674 .76009 m .4766 .76248 L .47465 .76001 L F
.82 .759 .795 r
.69728 .70393 m .69659 .70085 L .69776 .70192 L F
.661 .825 .962 r
.69982 .70096 m .69776 .70192 L .69659 .70085 L F
.375 .687 .98 r
.33287 .6553 m .33225 .65635 L .33094 .65529 L F
.33287 .6553 m .33416 .65641 L .33225 .65635 L F
.79 .617 .665 r
.71216 .71968 m .71237 .72202 L .71636 .72113 L F
.799 .658 .707 r
.71237 .72202 m .71323 .72506 L .71636 .72113 L F
.783 .633 .695 r
.71323 .72506 m .71651 .72568 L .71636 .72113 L F
.792 .675 .735 r
.58549 .82879 m .58933 .82626 L .58749 .82714 L F
.58549 .82879 m .58714 .82936 L .58933 .82626 L F
.313 .723 .977 r
.41129 .72263 m .41067 .72336 L .40934 .72253 L F
.41129 .72263 m .41285 .72347 L .41067 .72336 L F
.893 .486 .228 r
.67402 .61142 m .67597 .61341 L .67505 .61245 L F
.729 .356 .344 r
.67965 .61477 m .67505 .61245 L .67597 .61341 L F
.723 .521 .617 r
.4736 .86117 m .47454 .86247 L .47486 .85862 L F
.313 .225 .593 r
.47486 .85862 m .4772 .85506 L .47538 .85519 L F
.47486 .85862 m .47736 .85788 L .4772 .85506 L F
.645 .453 .608 r
.47486 .85862 m .47933 .86051 L .47736 .85788 L F
.47486 .85862 m .47454 .86247 L .47933 .86051 L F
.717 .391 .425 r
.56897 .78615 m .57103 .78857 L .57245 .78633 L F
.749 .437 .456 r
.57103 .78857 m .57409 .78692 L .57245 .78633 L F
.685 .602 .757 r
.5705 .83205 m .57384 .8346 L .57266 .83139 L F
.753 .503 .553 r
.56023 .79741 m .5605 .79987 L .55696 .79944 L F
.662 .583 .756 r
.56256 .80807 m .5661 .81061 L .5646 .8079 L F
.852 .689 .68 r
.63887 .59704 m .64093 .60048 L .63875 .59944 L F
.822 .545 .519 r
.64093 .60048 m .63833 .60181 L .63875 .59944 L F
.64093 .60048 m .6408 .60322 L .63833 .60181 L F
.623 .739 .93 r
.3561 .79025 m .35252 .7893 L .35459 .7889 L F
.65 .77 .936 r
.35809 .78948 m .3561 .79025 L .35459 .7889 L F
.314 .012 .283 r
.35565 .69042 m .3532 .69276 L .35389 .69113 L F
.947 .957 .72 r
.5373 .83112 m .53785 .8279 L .53729 .82947 L F
.851 .677 .666 r
.57899 .82372 m .58028 .82647 L .58034 .82443 L F
.57899 .82372 m .57737 .8263 L .58028 .82647 L F
.706 .532 .651 r
.57737 .8263 m .57878 .82786 L .58028 .82647 L F
.736 .629 .74 r
.58034 .82443 m .58028 .82647 L .58243 .82391 L F
.699 .324 .335 r
.57878 .82786 m .58242 .82872 L .58028 .82647 L F
.637 .482 .656 r
.58028 .82647 m .58431 .82829 L .58243 .82391 L F
.694 .326 .345 r
.58028 .82647 m .58242 .82872 L .58431 .82829 L F
.312 0 0 r
.30623 .6552 m .3093 .65349 L .30896 .65348 L F
.181 .466 .888 r
.6863 .59362 m .68558 .59458 L .68373 .59236 L F
.153 .426 .865 r
.6863 .59362 m .68782 .59586 L .68558 .59458 L F
.573 .122 .143 r
.64217 .64016 m .64427 .64117 L .64511 .63997 L F
.095 0 0 r
.64427 .64117 m .64702 .6396 L .64511 .63997 L F
.825 .915 .899 r
.48289 .87939 m .48407 .88006 L .48625 .87789 L F
.975 .836 .429 r
.48323 .88164 m .48407 .88006 L .48289 .87939 L F
.48323 .88164 m .48365 .8825 L .48407 .88006 L F
.541 .453 .705 r
.67632 .63399 m .67487 .63322 L .67691 .63149 L F
0 .47 .855 r
.34496 .66049 m .34493 .66101 L .34353 .65998 L F
.34496 .66049 m .34643 .66146 L .34493 .66101 L F
.889 .479 .063 r
.49929 .87146 m .49867 .87184 L .49808 .87104 L F
.842 .38 .085 r
.49808 .87104 m .49822 .87165 L .49622 .87123 L F
.49822 .87165 m .49811 .87185 L .49622 .87123 L F
.49828 .87191 m .49793 .87219 L .49622 .87123 L F
.49793 .87219 m .49761 .87245 L .49734 .87222 L F
.49793 .87219 m .49734 .87222 L .49622 .87123 L F
.49851 .87234 m .49929 .87313 L .49861 .87333 L F
.49929 .87313 m .50066 .87453 L .4996 .87391 L F
.49929 .87313 m .4996 .87391 L .49861 .87333 L F
.49946 .8729 m .50066 .87453 L .49834 .87217 L F
.889 .479 .063 r
.49944 .87175 m .50002 .87307 L .49867 .87184 L F
.49994 .87169 m .50066 .87453 L .49944 .87175 L F
.526 .352 .588 r
.50106 .87421 m .50002 .87307 L .50066 .87453 L F
.889 .479 .063 r
.50034 .87325 m .50106 .87421 L .50066 .87453 L F
.49994 .87169 m .50106 .87421 L .50034 .87325 L F
.526 .352 .588 r
.50002 .87307 m .50016 .87301 L .49919 .87216 L F
.50016 .87301 m .50345 .87157 L .49949 .87212 L F
.50016 .87301 m .49949 .87212 L .49919 .87216 L F
.50106 .87421 m .50139 .87384 L .50002 .87307 L F
.50139 .87384 m .50345 .87157 L .50002 .87307 L F
.889 .479 .063 r
.50002 .87307 m .50066 .87453 L .49927 .87265 L F
.50002 .87307 m .49927 .87265 L .49867 .87184 L F
.526 .352 .588 r
.50002 .87307 m .49919 .87216 L .50066 .87453 L F
.738 .552 .643 r
.50106 .87421 m .50121 .87696 L .49896 .87706 L F
.084 .637 .818 r
.5031 .87424 m .50463 .87446 L .50416 .87443 L F
.5031 .87424 m .50416 .87443 L .50106 .87421 L F
.526 .352 .588 r
.50106 .87421 m .5031 .87424 L .50345 .87157 L F
0 0 0 r
.50307 .87424 m .50176 .87382 L .5031 .87424 L F
.50106 .87421 m .50176 .87382 L .50307 .87424 L F
.084 .637 .818 r
.5031 .87424 m .50463 .87446 L .50106 .87421 L F
.742 .524 .598 r
.50463 .87446 m .50121 .87696 L .50106 .87421 L F
0 0 0 r
.50106 .87421 m .4994 .87652 L .50176 .87382 L F
.894 .494 .248 r
.49861 .87333 m .50066 .87453 L .49919 .87216 L F
.03 0 .459 r
.4994 .87652 m .50046 .8734 L .50176 .87382 L F
.50046 .8734 m .5005 .8733 L .50176 .87382 L F
.696 .161 0 r
.502 .87404 m .5031 .87424 L .50176 .87382 L F
.742 .524 .598 r
.50463 .87446 m .50423 .87705 L .50121 .87696 L F
.696 .161 0 r
.50352 .87544 m .5031 .87424 L .502 .87404 L F
.03 0 .459 r
.49997 .87483 m .50063 .87543 L .5005 .8733 L F
.4994 .87652 m .50032 .8757 L .49997 .87483 L F
.50032 .8757 m .50063 .87543 L .49997 .87483 L F
.894 .494 .248 r
.49861 .87333 m .49919 .87216 L .4985 .87227 L F
.49861 .87333 m .4985 .87227 L .49786 .87238 L F
.842 .38 .085 r
.49834 .87217 m .49851 .87234 L .49861 .87333 L F
.49808 .87104 m .49867 .87184 L .49828 .87191 L F
.895 .691 .62 r
.49795 .87197 m .49977 .86723 L .49875 .86836 L F
.4979 .87222 m .49799 .87196 L .49795 .87197 L F
.49799 .87196 m .49977 .86723 L .49795 .87197 L F
.842 .38 .085 r
.49828 .87191 m .49946 .8729 L .49834 .87217 L F
.49867 .87184 m .49946 .8729 L .49828 .87191 L F
.895 .691 .62 r
.49848 .87226 m .49919 .87216 L .4992 .87213 L F
.49786 .87238 m .4985 .87227 L .49848 .87226 L F
.4985 .87227 m .49919 .87216 L .49848 .87226 L F
.842 .38 .085 r
.49822 .87165 m .49828 .87191 L .49811 .87185 L F
.889 .479 .063 r
.49994 .87169 m .49867 .87184 L .49929 .87146 L F
.895 .691 .62 r
.49793 .87219 m .4992 .87213 L .49977 .86723 L F
.49786 .87238 m .4992 .87213 L .49793 .87219 L F
.914 .851 .404 r
.49791 .87087 m .49786 .87227 L .49875 .86836 L F
.49786 .87227 m .49786 .87238 L .4979 .87222 L F
.49786 .87227 m .4979 .87222 L .49875 .86836 L F
.895 .691 .62 r
.49787 .87233 m .49792 .8722 L .4979 .87222 L F
.49786 .87238 m .49788 .87232 L .49787 .87233 L F
.493 .196 .39 r
.49861 .87333 m .5005 .8733 L .49786 .87238 L F
.894 .494 .248 r
.49861 .87333 m .49786 .87238 L .5005 .8733 L F
.493 .196 .39 r
.49861 .87333 m .49786 .87238 L .49786 .87227 L F
.842 .38 .085 r
.49828 .87191 m .49861 .87333 L .49785 .87225 L F
.895 .691 .62 r
.49792 .8722 m .49977 .86723 L .4979 .87222 L F
.49788 .87232 m .49977 .86723 L .49787 .87233 L F
.493 .196 .39 r
.49861 .87333 m .49786 .87227 L .49791 .87087 L F
.842 .38 .085 r
.49785 .87225 m .49861 .87333 L .49761 .87245 L F
.967 .696 .466 r
.67435 .72268 m .67383 .72011 L .67166 .72283 L F
.597 .422 .616 r
.34989 .77576 m .34981 .78049 L .34771 .77979 L F
.534 .337 .559 r
.35215 .77326 m .35197 .7754 L .34989 .77576 L F
.539 .376 .608 r
.35269 .77883 m .34989 .77576 L .35197 .7754 L F
.35269 .77883 m .34981 .78049 L .34989 .77576 L F
.493 .267 .499 r
.47325 .84552 m .47554 .84533 L .47575 .84264 L F
.599 .356 .52 r
.47575 .84264 m .47554 .84533 L .47775 .84476 L F
.391 .318 .655 r
.47469 .85318 m .47573 .84879 L .47456 .85105 L F
.65 .232 .236 r
.63922 .64014 m .64217 .64016 L .63991 .63959 L F
0 0 0 r
.40157 .7914 m .40326 .79038 L .40525 .7897 L F
.558 .499 .746 r
.35351 .66836 m .35231 .67187 L .35172 .66994 L F
.35351 .66836 m .35425 .67147 L .35231 .67187 L F
.189 .136 .563 r
.70897 .72803 m .71008 .72479 L .70801 .72536 L F
.70897 .72803 m .7103 .72764 L .71008 .72479 L F
.722 .317 .279 r
.70897 .72803 m .71006 .72868 L .7103 .72764 L F
.70897 .72803 m .71112 .73006 L .708 .72969 L F
.70897 .72803 m .708 .72969 L .71006 .72868 L F
.743 .342 0 r
.5661 .81061 m .56575 .81025 L .5646 .8079 L F
.936 .722 .587 r
.56686 .81244 m .56575 .81025 L .5661 .81061 L F
.738 .3 .212 r
.67713 .70952 m .67628 .71089 L .67557 .7099 L F
.481 .619 .91 r
.67876 .70892 m .67713 .70952 L .67578 .70758 L F
.48 .137 .306 r
.67876 .70892 m .67628 .71089 L .67713 .70952 L F
.563 .464 .7 r
.44958 .74916 m .4517 .74894 L .45132 .74644 L F
.6 .482 .691 r
.44958 .74916 m .4524 .75182 L .4517 .74894 L F
.44958 .74916 m .45026 .75237 L .4524 .75182 L F
.555 .379 .598 r
.71323 .72506 m .71588 .72693 L .71651 .72568 L F
.337 .052 .324 r
.37266 .75676 m .37084 .75736 L .37312 .75499 L F
.591 .282 .415 r
.37312 .75499 m .37489 .75674 L .37266 .75676 L F
.554 .286 .463 r
.37558 .75467 m .37489 .75674 L .37312 .75499 L F
0 0 .198 r
.34222 .70349 m .34201 .7064 L .34177 .70611 L F
.449 .213 .464 r
.34397 .70581 m .34222 .70349 L .34389 .70285 L F
.34397 .70581 m .34201 .7064 L .34222 .70349 L F
.394 .267 .588 r
.36529 .67502 m .36638 .67927 L .36428 .68004 L F
.446 .23 .49 r
.36869 .67653 m .36638 .67927 L .36529 .67502 L F
.81 .715 .76 r
.36529 .67502 m .36339 .67517 L .36584 .67512 L F
0 .373 .771 r
.36584 .67512 m .36869 .67653 L .36529 .67502 L F
.702 .933 .964 r
.43871 .74293 m .44226 .74195 L .44147 .74059 L F
.511 .656 .924 r
.44147 .74059 m .44226 .74195 L .44429 .74156 L F
0 .362 .831 r
.65374 .5941 m .65347 .59454 L .65106 .59216 L F
.65374 .5941 m .65399 .59491 L .65347 .59454 L F
.246 .263 .681 r
.65473 .59696 m .65347 .59454 L .65399 .59491 L F
.649 .64 .828 r
.44619 .74619 m .44787 .74394 L .44565 .74445 L F
.44619 .74619 m .44767 .74644 L .44787 .74394 L F
.547 .268 .444 r
.41858 .77218 m .42073 .77209 L .42111 .77063 L F
.49 .162 .338 r
.42073 .77209 m .42334 .77053 L .42111 .77063 L F
.172 .354 .804 r
.68441 .61879 m .68632 .62036 L .68549 .62148 L F
.306 .314 .704 r
.68632 .62036 m .68567 .62373 L .68549 .62148 L F
0 0 0 r
.36895 .80454 m .37265 .80293 L .37093 .80415 L F
.37093 .80415 m .37265 .80293 L .37443 .80217 L F
.749 .437 .456 r
.57103 .78857 m .57437 .78882 L .57409 .78692 L F
.846 .916 .881 r
.68844 .72444 m .69142 .72316 L .69021 .72204 L F
.774 .706 .788 r
.69021 .72204 m .69142 .72316 L .69352 .72053 L F
.886 .753 .71 r
.54488 .83664 m .54599 .83932 L .5457 .83741 L F
.599 .471 .678 r
.34804 .78142 m .34605 .7839 L .34604 .78201 L F
.737 .634 .745 r
.57944 .82146 m .58034 .82443 L .58243 .82391 L F
.682 .503 .638 r
.58243 .82391 m .58431 .82829 L .5859 .8263 L F
.594 .54 .764 r
.45026 .75237 m .45076 .7544 L .45289 .75399 L F
.584 .467 .685 r
.45122 .75705 m .45289 .75399 L .45076 .7544 L F
.34 0 0 r
.61609 .64997 m .61837 .64968 L .61945 .64836 L F
.835 .938 .894 r
.62096 .64701 m .61945 .64836 L .62015 .64679 L F
.793 .918 .534 r
.61945 .64836 m .61837 .64968 L .62015 .64679 L F
.501 .286 .519 r
.36903 .91137 m .37053 .91167 L .36867 .91281 L F
.36903 .91137 m .37053 .91167 L .36867 .91281 L F
.408 .281 .594 r
.47229 .86416 m .47401 .86591 L .47421 .86366 L F
.47229 .86416 m .47186 .86693 L .47401 .86591 L F
.124 .587 .92 r
.68373 .59236 m .68195 .59204 L .68091 .59129 L F
.575 .562 .802 r
.35206 .66303 m .35108 .66652 L .34986 .66344 L F
.35206 .66303 m .35314 .66618 L .35108 .66652 L F
.548 .455 .701 r
.35351 .66836 m .35108 .66652 L .35314 .66618 L F
.35351 .66836 m .35172 .66994 L .35108 .66652 L F
.547 .34 .551 r
.55563 .78936 m .55573 .79092 L .55785 .78907 L F
0 0 .464 r
.603 .6507 m .6034 .65319 L .6031 .65327 L F
0 0 0 r
.6031 .65327 m .6034 .65319 L .60184 .65392 L F
.407 .153 .413 r
.34495 .74359 m .3474 .74104 L .34533 .74133 L F
.63 .773 .949 r
.36892 .7891 m .36698 .78982 L .36556 .78855 L F
.529 .47 .734 r
.47227 .75308 m .47032 .75399 L .469 .75147 L F
.47227 .75308 m .47204 .75399 L .47032 .75399 L F
.587 .395 .588 r
.34081 .74642 m .34287 .74633 L .34303 .74402 L F
.494 .289 .53 r
.34287 .74633 m .34495 .74359 L .34303 .74402 L F
.111 .605 .906 r
.33783 .65763 m .33966 .6579 L .34112 .6586 L F
.077 .392 .851 r
.34164 .65779 m .34112 .6586 L .33966 .6579 L F
.34164 .65779 m .34353 .65998 L .34112 .6586 L F
.761 .533 .588 r
.33674 .68208 m .33981 .68241 L .34008 .68009 L F
.319 .379 .768 r
.3391 .67706 m .34008 .68009 L .34132 .67893 L F
.226 .07 .449 r
.34008 .68009 m .34129 .68116 L .34132 .67893 L F
.34008 .68009 m .33981 .68241 L .34129 .68116 L F
.893 .79 .739 r
.66465 .60499 m .6657 .60725 L .664 .60688 L F
.877 .637 .572 r
.66591 .61015 m .664 .60688 L .6657 .60725 L F
.596 .625 .851 r
.66692 .60436 m .6657 .60725 L .66465 .60499 L F
.66692 .60436 m .66846 .607 L .6657 .60725 L F
.063 .484 .891 r
.66857 .60886 m .6657 .60725 L .66846 .607 L F
.556 .381 .6 r
.68175 .74389 m .68404 .74372 L .68398 .74088 L F
.585 .424 .63 r
.32985 .76005 m .33196 .7597 L .33197 .75712 L F
.557 .357 .566 r
.32973 .76238 m .33196 .7597 L .32985 .76005 L F
.541 .314 .52 r
.56001 .78675 m .56246 .78841 L .56336 .78673 L F
.263 .767 .867 r
.56246 .78841 m .56532 .78804 L .56336 .78673 L F
.523 .07 .118 r
.56336 .78673 m .56532 .78804 L .56578 .78687 L F
.905 .874 .796 r
.50922 .88535 m .51033 .88587 L .51149 .8837 L F
.50814 .88613 m .50882 .88605 L .50922 .88535 L F
.50814 .88613 m .51149 .8837 L .51114 .88478 L F
.232 0 0 r
.51149 .8837 m .50905 .88317 L .51114 .88478 L F
.524 .365 .607 r
.51152 .88239 m .51114 .88478 L .51002 .88392 L F
.51074 .88264 m .51002 .88392 L .50905 .88317 L F
.51152 .88239 m .51002 .88392 L .51074 .88264 L F
.905 .874 .796 r
.50882 .88605 m .51033 .88587 L .50922 .88535 L F
.53 .333 .558 r
.67219 .72477 m .67435 .72268 L .67166 .72283 L F
.647 .428 .572 r
.48058 .76101 m .47674 .76009 L .47941 .75959 L F
.48058 .76101 m .4766 .76248 L .47674 .76009 L F
0 0 0 r
.69248 .6335 m .69123 .63477 L .69339 .63207 L F
.576 .89 .989 r
.69018 .63432 m .69123 .63477 L .69248 .6335 L F
.542 .683 .931 r
.58378 .83348 m .58392 .83457 L .58588 .83359 L F
.64 .532 .715 r
.58475 .83714 m .58588 .83359 L .58392 .83457 L F
.525 .341 .574 r
.3543 .77043 m .3542 .77281 L .35215 .77326 L F
.556 .374 .589 r
.3542 .77281 m .35197 .7754 L .35215 .77326 L F
0 0 0 r
.64573 .6106 m .64617 .61046 L .6439 .61079 L F
.481 .65 .933 r
.6439 .61079 m .64567 .60955 L .64573 .6106 L F
.943 .879 .468 r
.64573 .6106 m .64567 .60955 L .64536 .61071 L F
.64573 .6106 m .64536 .61071 L .64502 .61199 L F
0 0 0 r
.64573 .6106 m .6472 .61031 L .64617 .61046 L F
.511 .083 .164 r
.64851 .61196 m .6472 .61031 L .64573 .6106 L F
.64851 .61196 m .64944 .61041 L .6472 .61031 L F
.32 0 .049 r
.43188 .77983 m .43101 .77855 L .43286 .778 L F
.43188 .77983 m .42969 .78029 L .43101 .77855 L F
.665 .702 .874 r
.35068 .79031 m .34709 .78934 L .34936 .78875 L F
.674 .638 .805 r
.35252 .7893 m .35068 .79031 L .34936 .78875 L F
.496 .035 .088 r
.39906 .77999 m .40282 .7787 L .40064 .77918 L F
.546 .556 .816 r
.53076 .86885 m .52865 .8692 L .52745 .86737 L F
.375 .254 .585 r
.53025 .87121 m .52865 .8692 L .53076 .86885 L F
.53025 .87121 m .52889 .87191 L .52865 .8692 L F
.363 0 .05 r
.31399 .67463 m .31139 .67645 L .3104 .6766 L F
.31399 .67463 m .3124 .67632 L .31139 .67645 L F
.681 .283 .287 r
.31589 .6762 m .3124 .67632 L .31399 .67463 L F
.82 .759 .795 r
.69728 .70393 m .69447 .70347 L .69659 .70085 L F
.84 .709 .719 r
.69728 .70393 m .69556 .70655 L .69447 .70347 L F
.952 .806 .661 r
.68703 .73636 m .68538 .73809 L .68502 .73566 L F
.68703 .73636 m .68656 .73873 L .68538 .73809 L F
.922 .848 .753 r
.68538 .73809 m .6881 .73594 L .68502 .73566 L F
.68538 .73809 m .68656 .73873 L .6881 .73594 L F
.832 .674 .688 r
.53573 .85307 m .53674 .85574 L .53432 .85604 L F
.466 .117 .29 r
.53674 .85574 m .5337 .85821 L .53432 .85604 L F
.53674 .85574 m .53598 .85785 L .5337 .85821 L F
.78 .986 .899 r
.53916 .856 m .53598 .85785 L .53674 .85574 L F
.814 .5 .459 r
.57469 .79106 m .57733 .78965 L .57437 .78882 L F
.57469 .79106 m .57763 .79158 L .57733 .78965 L F
.404 .03 .212 r
.39642 .7469 m .3936 .7468 L .396 .74523 L F
.39642 .7469 m .39226 .74887 L .3936 .7468 L F
.81 .43 .335 r
.53785 .8279 m .54087 .82884 L .53908 .82621 L F
.801 .506 .49 r
.67104 .60441 m .67198 .60719 L .67173 .60709 L F
.481 .515 .816 r
.67082 .60623 m .66857 .60886 L .66846 .607 L F
.67092 .60632 m .66857 .60886 L .67082 .60623 L F
.071 .187 .679 r
.67025 .60931 m .66857 .60886 L .67068 .60658 L F
.67025 .60931 m .67068 .60658 L .67084 .60669 L F
.67025 .60931 m .67092 .60632 L .67095 .60668 L F
.801 .506 .49 r
.67104 .60441 m .66993 .60556 L .66946 .60393 L F
.493 .575 .866 r
.66998 .60566 m .66846 .607 L .66692 .60436 L F
.67017 .60574 m .67006 .60582 L .66998 .60566 L F
.801 .506 .49 r
.67104 .60441 m .67173 .60709 L .67002 .60547 L F
.493 .575 .866 r
.67109 .60614 m .67082 .60623 L .67017 .60574 L F
.67006 .60582 m .66846 .607 L .66998 .60566 L F
.67082 .60623 m .66846 .607 L .67017 .60574 L F
.801 .506 .49 r
.67016 .60574 m .67092 .60632 L .66936 .60616 L F
.67082 .60623 m .67092 .60632 L .66993 .60556 L F
.493 .575 .866 r
.67109 .60614 m .67017 .60574 L .66936 .60616 L F
.67017 .60574 m .66692 .60436 L .66936 .60616 L F
.801 .506 .49 r
.66993 .60556 m .67016 .60574 L .66936 .60616 L F
.66993 .60556 m .66936 .60616 L .66943 .60458 L F
.66993 .60556 m .66943 .60458 L .66946 .60393 L F
.67002 .60547 m .67082 .60623 L .66993 .60556 L F
.071 .187 .679 r
.67084 .60669 m .67068 .60658 L .67092 .60632 L F
.67095 .60668 m .67092 .60632 L .67109 .60614 L F
.771 .645 .722 r
.66936 .60616 m .67025 .60931 L .67095 .60668 L F
.801 .506 .49 r
.67092 .60632 m .67095 .60668 L .66936 .60616 L F
.481 .515 .816 r
.67109 .60614 m .67092 .60632 L .67082 .60623 L F
.771 .645 .722 r
.66936 .60616 m .67095 .60668 L .67109 .60614 L F
.801 .506 .49 r
.67095 .60668 m .67096 .60679 L .66936 .60616 L F
.372 .394 .754 r
.67212 .60767 m .66936 .60616 L .67096 .60679 L F
.67212 .60767 m .67262 .60877 L .67191 .60737 L F
.67212 .60767 m .67191 .60737 L .67118 .60597 L F
.67211 .60766 m .6721 .60765 L .67198 .60719 L F
.6721 .60765 m .67096 .60679 L .67169 .60708 L F
.6721 .60765 m .67169 .60708 L .67198 .60719 L F
.67212 .60767 m .67096 .60679 L .67211 .60766 L F
.801 .506 .49 r
.67092 .60632 m .67173 .60709 L .67096 .60679 L F
.071 .187 .679 r
.67025 .60931 m .66933 .61038 L .66857 .60886 L F
.563 .352 .553 r
.3382 .74917 m .3407 .74906 L .34081 .74642 L F
.569 .358 .554 r
.34081 .74642 m .34281 .74858 L .34287 .74633 L F
.34081 .74642 m .3407 .74906 L .34281 .74858 L F
.664 .653 .83 r
.44787 .74394 m .44767 .74644 L .4501 .74344 L F
.486 .252 .484 r
.34901 .69595 m .34869 .69779 L .3468 .69814 L F
.446 .23 .491 r
.34872 .6993 m .3468 .69814 L .34869 .69779 L F
.34872 .6993 m .34604 .70047 L .3468 .69814 L F
.371 .118 .395 r
.35134 .69339 m .35084 .69538 L .34901 .69595 L F
.487 .292 .54 r
.35084 .69538 m .34869 .69779 L .34901 .69595 L F
.53 .333 .558 r
.67219 .72477 m .67445 .72406 L .67435 .72268 L F
.617 .601 .812 r
.6751 .72623 m .67445 .72406 L .67219 .72477 L F
.587 .337 .505 r
.34976 .73698 m .35165 .74012 L .35222 .73621 L F
.34976 .73698 m .35165 .74012 L .35222 .73621 L F
.418 .188 .455 r
.34604 .70047 m .34389 .70285 L .34439 .70107 L F
.314 .109 .434 r
.32967 .69856 m .33166 .69794 L .33195 .69584 L F
.168 .066 .486 r
.33017 .70085 m .33166 .69794 L .32967 .69856 L F
.312 0 0 r
.30623 .6552 m .30776 .655 L .3093 .65349 L F
0 0 0 r
.3093 .65349 m .30949 .65365 L .31126 .65319 L F
.3093 .65349 m .30776 .655 L .30949 .65365 L F
.457 .196 .428 r
.35282 .69467 m .35134 .69339 L .3532 .69276 L F
.35282 .69467 m .35084 .69538 L .35134 .69339 L F
.465 .289 .557 r
.35748 .68981 m .35573 .68805 L .35775 .68765 L F
.35748 .68981 m .35565 .69042 L .35573 .68805 L F
.82 .573 .566 r
.7059 .7031 m .70883 .7037 L .70878 .70116 L F
.484 .499 .798 r
.58621 .83951 m .58695 .83657 L .58475 .83714 L F
.58621 .83951 m .58811 .83965 L .58695 .83657 L F
.412 0 0 r
.48805 .88858 m .4916 .89037 L .49041 .89028 L F
0 .532 .706 r
.4916 .89037 m .49375 .89054 L .49041 .89028 L F
.456 .474 .788 r
.33793 .68314 m .33893 .68545 L .34023 .68475 L F
.443 .298 .588 r
.33857 .68776 m .34023 .68475 L .33893 .68545 L F
.541 .749 .972 r
.41943 .74206 m .42037 .74056 L .41834 .74127 L F
.357 0 .011 r
.42037 .74056 m .4192 .74109 L .41834 .74127 L F
.354 .721 .987 r
.4174 .74207 m .41943 .74206 L .41834 .74127 L F
.357 0 .011 r
.4192 .74109 m .41695 .74211 L .41834 .74127 L F
.354 .721 .987 r
.41696 .74156 m .41834 .74127 L .41623 .74074 L F
.4174 .74207 m .41834 .74127 L .41696 .74156 L F
0 0 0 r
.69248 .6335 m .69339 .63207 L .69016 .63169 L F
.87 .744 .721 r
.70883 .7037 m .70831 .70662 L .70969 .70671 L F
.848 .529 .448 r
.7092 .7084 m .70969 .70671 L .70859 .70664 L F
.7092 .7084 m .70906 .70808 L .70969 .70671 L F
.696 .449 .545 r
.70906 .70808 m .70906 .7081 L .7125 .71042 L F
.752 .493 .54 r
.7092 .7084 m .70919 .71133 L .70906 .70808 L F
.696 .449 .545 r
.70907 .70812 m .70907 .70826 L .7091 .70819 L F
.70907 .70826 m .70919 .71133 L .7091 .70829 L F
.70907 .70826 m .7091 .70829 L .7091 .70819 L F
.7091 .70819 m .70919 .71133 L .71005 .71109 L F
.588 .093 0 r
.70628 .70527 m .70815 .70742 L .70919 .70839 L F
.70628 .70527 m .70919 .70839 L .70917 .70837 L F
.70628 .70527 m .70917 .70837 L .70831 .70662 L F
.891 .766 .717 r
.70628 .70527 m .70831 .70662 L .70883 .7037 L F
.70628 .70527 m .70883 .7037 L .7059 .7031 L F
.832 .71 .73 r
.70996 .7048 m .70723 .70646 L .70698 .70457 L F
.778 .336 .199 r
.70628 .70703 m .70823 .70751 L .70628 .70527 L F
.832 .71 .73 r
.70723 .70646 m .70628 .70703 L .70663 .70582 L F
.70723 .70646 m .70663 .70582 L .70698 .70457 L F
.588 .093 0 r
.70815 .70742 m .70823 .70751 L .70829 .70757 L F
.70815 .70742 m .70829 .70757 L .70919 .70839 L F
.70917 .70837 m .70919 .70839 L .7092 .7084 L F
.70917 .70837 m .7092 .7084 L .7091 .70819 L F
.70917 .70837 m .7091 .70819 L .70831 .70662 L F
.696 .449 .545 r
.70906 .7081 m .70907 .70812 L .7091 .70819 L F
.70906 .7081 m .71005 .71109 L .7125 .71042 L F
.848 .529 .448 r
.7091 .70819 m .70859 .70664 L .70831 .70662 L F
.7092 .7084 m .70859 .70664 L .7091 .70819 L F
.479 0 0 r
.71193 .70789 m .70969 .70671 L .70906 .70808 L F
.71193 .70789 m .71275 .70772 L .70969 .70671 L F
.494 .837 .559 r
.53952 .84755 m .54025 .84696 L .53858 .84841 L F
.705 .977 .773 r
.54192 .84486 m .54025 .84696 L .53952 .84755 L F
.54192 .84486 m .54246 .84489 L .54025 .84696 L F
.864 .762 .748 r
.71473 .71513 m .71545 .71626 L .71429 .71475 L F
.71473 .71513 m .71157 .71699 L .71545 .71626 L F
.863 .795 .783 r
.71157 .71699 m .71216 .71968 L .71545 .71626 L F
.341 .127 .436 r
.36638 .67927 m .36353 .68088 L .36428 .68004 L F
.36638 .67927 m .36603 .68136 L .36353 .68088 L F
.345 .153 .47 r
.36576 .68353 m .36353 .68088 L .36603 .68136 L F
.36576 .68353 m .3642 .68432 L .36353 .68088 L F
.496 .83 .999 r
.4959 .88921 m .49702 .88983 L .4988 .8894 L F
.59 .554 .782 r
.47396 .84748 m .47554 .84533 L .47325 .84552 L F
.994 .782 .411 r
.43653 .74531 m .43471 .74403 L .4349 .7461 L F
.576 .551 .789 r
.4349 .7461 m .43653 .74531 L .43471 .74403 L F
.682 .361 .425 r
.49333 .86606 m .49646 .8642 L .49324 .86379 L F
.49333 .86606 m .49681 .86608 L .49646 .8642 L F
.687 .625 .781 r
.56936 .82909 m .5705 .83205 L .57266 .83139 L F
.641 .37 .492 r
.4691 .76277 m .47117 .76489 L .46912 .76468 L F
.627 .371 .511 r
.47361 .76166 m .47117 .76489 L .4691 .76277 L F
.128 .677 .763 r
.41285 .72347 m .41513 .72322 L .41599 .72319 L F
.172 .553 .93 r
.41743 .72293 m .41599 .72319 L .41513 .72322 L F
.41743 .72293 m .41839 .72391 L .41599 .72319 L F
.614 .427 .606 r
.68398 .74088 m .68404 .74372 L .68612 .74099 L F
.436 .064 .233 r
.41582 .7735 m .41737 .77445 L .41858 .77218 L F
.571 .228 .348 r
.41737 .77445 m .42073 .77209 L .41858 .77218 L F
0 0 .544 r
.51242 .87415 m .51322 .87709 L .51234 .87499 L F
.63 .514 .703 r
.34809 .78349 m .34605 .7839 L .34804 .78142 L F
.514 .218 .403 r
.36877 .76016 m .36779 .76216 L .36597 .7624 L F
.276 .039 .362 r
.37036 .75924 m .36877 .76016 L .37084 .75736 L F
.155 0 .186 r
.37036 .75924 m .36779 .76216 L .36877 .76016 L F
.916 .693 .586 r
.57579 .81726 m .57779 .81595 L .57656 .8152 L F
.57579 .81726 m .57765 .81829 L .57779 .81595 L F
0 0 0 r
.48832 .88135 m .48826 .88229 L .48869 .87922 L F
.183 0 0 r
.66736 .64236 m .66396 .6434 L .66528 .64307 L F
.57 .766 .971 r
.45107 .73115 m .44786 .73045 L .44995 .73011 L F
.47 .68 .957 r
.45202 .72975 m .45107 .73115 L .44995 .73011 L F
.45202 .72975 m .45321 .73113 L .45107 .73115 L F
.635 .444 .607 r
.33368 .75453 m .33637 .75439 L .33625 .75209 L F
.527 .352 .587 r
.33625 .75209 m .33847 .75181 L .3382 .74917 L F
.559 .386 .603 r
.33625 .75209 m .33853 .754 L .33847 .75181 L F
.33625 .75209 m .33637 .75439 L .33853 .754 L F
.558 .412 .639 r
.35633 .76889 m .3543 .77043 L .35435 .77035 L F
.35633 .76889 m .35632 .77013 L .3543 .77043 L F
.531 .34 .567 r
.35632 .77013 m .3542 .77281 L .3543 .77043 L F
.639 .356 .474 r
.42939 .74302 m .42907 .74491 L .42706 .74285 L F
.166 .287 .744 r
.42706 .74285 m .42907 .74491 L .42873 .74388 L F
.56 .053 .006 r
.42854 .74191 m .42706 .74285 L .42597 .74217 L F
.612 .253 .336 r
.43051 .74108 m .42939 .74302 L .42706 .74285 L F
.166 .287 .744 r
.42706 .74285 m .42873 .74388 L .428 .74172 L F
.56 .053 .006 r
.42597 .74217 m .42706 .74285 L .42505 .74226 L F
.751 .642 .74 r
.57899 .82372 m .58034 .82443 L .57944 .82146 L F
.937 .565 .218 r
.57897 .83753 m .57949 .83972 L .58033 .83987 L F
.481 .238 .468 r
.35853 .76796 m .35827 .76614 L .3587 .76507 L F
.35853 .76796 m .35633 .76889 L .35827 .76614 L F
.528 .385 .63 r
.334 .69053 m .33604 .69267 L .336 .69015 L F
.334 .69053 m .33416 .69326 L .33604 .69267 L F
.834 .921 .892 r
.68264 .70989 m .68028 .71202 L .67932 .7113 L F
.784 .663 .729 r
.71887 .62332 m .71631 .62367 L .71804 .62038 L F
.68 .321 .359 r
.71887 .62332 m .71862 .62555 L .71631 .62367 L F
.584 .42 .626 r
.72183 .62281 m .71862 .62555 L .71887 .62332 L F
.909 .885 .796 r
.39915 .74683 m .39981 .74301 L .39959 .7456 L F
.39915 .74683 m .39754 .74678 L .39981 .74301 L F
.423 .032 .191 r
.39959 .7456 m .39754 .74678 L .39915 .74683 L F
.541 .314 .52 r
.56001 .78675 m .56024 .78886 L .56246 .78841 L F
0 0 .264 r
.65374 .5941 m .65473 .59696 L .65399 .59491 L F
.675 .411 .513 r
.58746 .83152 m .58913 .83395 L .58994 .83046 L F
.763 .553 .612 r
.58913 .83395 m .59243 .83177 L .58994 .83046 L F
.829 .874 .877 r
.603 .6507 m .5993 .65222 L .60194 .65216 L F
.965 .677 .437 r
.60194 .65216 m .6034 .65319 L .603 .6507 L F
.872 .927 .858 r
.62294 .6449 m .62096 .64701 L .62015 .64679 L F
.454 .228 .481 r
.37266 .75676 m .37036 .75924 L .37084 .75736 L F
.532 .375 .613 r
.33196 .7597 m .33388 .75664 L .33197 .75712 L F
.465 .772 .997 r
.48298 .83372 m .48462 .83465 L .48205 .83481 L F
.48205 .83481 m .48462 .83465 L .48298 .83372 L F
.997 .808 .453 r
.6938 .62404 m .69347 .62546 L .69437 .62404 L F
.425 .869 .834 r
.6938 .62404 m .69599 .62314 L .69437 .62404 L F
.516 .275 .489 r
.69599 .62314 m .69347 .62546 L .69437 .62404 L F
.859 .828 .816 r
.54039 .85565 m .5421 .84962 L .5402 .85252 L F
.54039 .85565 m .54348 .85044 L .5421 .84962 L F
.719 .665 .796 r
.48808 .87695 m .49142 .87728 L .49021 .87456 L F
.753 .669 .768 r
.48869 .87922 m .49142 .87728 L .48808 .87695 L F
.996 .864 .572 r
.48793 .86129 m .48656 .86359 L .48745 .86369 L F
.62 .615 .824 r
.49021 .87456 m .49142 .87728 L .4925 .8758 L F
.804 .318 0 r
.68165 .72085 m .68328 .72283 L .68198 .72191 L F
.882 .753 .715 r
.62294 .6449 m .6224 .64201 L .6239 .64289 L F
.62294 .6449 m .62047 .64484 L .6224 .64201 L F
.872 .927 .858 r
.62294 .6449 m .62015 .64679 L .62047 .64484 L F
.615 .488 .684 r
.47128 .74885 m .469 .75147 L .46892 .74927 L F
.47128 .74885 m .47227 .75308 L .469 .75147 L F
.471 .106 .263 r
.45068 .77095 m .44814 .7726 L .44869 .77108 L F
.674 .557 .714 r
.51784 .87121 m .51971 .8692 L .5184 .86866 L F
.593 .436 .638 r
.51784 .87121 m .51989 .87159 L .51971 .8692 L F
.596 .471 .68 r
.39333 .9893 m .39388 .99217 L .39149 .99221 L F
.39149 .99221 m .39388 .99217 L .39333 .9893 L F
.39333 .9893 m .39388 .99217 L .39149 .99221 L F
.62 .615 .824 r
.49021 .87456 m .4925 .8758 L .49352 .87481 L F
.647 .459 .616 r
.4925 .8758 m .49477 .87537 L .49352 .87481 L F
.78 .998 .84 r
.6622 .63131 m .65905 .63347 L .66217 .63168 L F
0 0 0 r
.6622 .63131 m .66217 .63168 L .66446 .6289 L F
.686 .507 .639 r
.48204 .75735 m .48216 .75979 L .47941 .75959 L F
.167 .265 .721 r
.48214 .7564 m .48314 .75675 L .48204 .75735 L F
.389 .831 .943 r
.48204 .75735 m .48314 .75675 L .48456 .75702 L F
.661 .488 .639 r
.48563 .75845 m .48204 .75735 L .48456 .75702 L F
.48563 .75845 m .48216 .75979 L .48204 .75735 L F
.59 .554 .782 r
.47396 .84748 m .47624 .84731 L .47554 .84533 L F
.568 .47 .704 r
.47396 .84748 m .47573 .84879 L .47624 .84731 L F
.47396 .84748 m .47456 .85105 L .47573 .84879 L F
.429 0 0 r
.53222 .82336 m .5338 .82384 L .53587 .8242 L F
.809 .433 .343 r
.5338 .82384 m .53494 .82558 L .53587 .8242 L F
.821 .598 .601 r
.58538 .83128 m .58714 .82936 L .58549 .82879 L F
.58538 .83128 m .58746 .83152 L .58714 .82936 L F
.583 .297 .447 r
.46152 .76509 m .46045 .76779 L .45825 .76771 L F
.592 .306 .452 r
.46376 .76677 m .46152 .76509 L .46361 .7652 L F
.46376 .76677 m .46045 .76779 L .46152 .76509 L F
.561 .32 .508 r
.44608 .76222 m .44852 .75982 L .44629 .76005 L F
.245 0 0 r
.38569 .72557 m .38767 .7253 L .38872 .7246 L F
.317 0 0 r
.38872 .7246 m .38767 .7253 L .39081 .72444 L F
.838 .742 .758 r
.63319 .62397 m .63046 .62389 L .63229 .62108 L F
.814 .696 .735 r
.63319 .62397 m .62995 .62571 L .63046 .62389 L F
.63319 .62397 m .63132 .62683 L .62995 .62571 L F
.605 .459 .657 r
.67569 .71998 m .67866 .72105 L .67839 .71678 L F
.534 .234 .405 r
.67628 .72229 m .67866 .72105 L .67569 .71998 L F
.785 .968 .918 r
.67569 .71998 m .67435 .72268 L .67628 .72229 L F
.464 .245 .496 r
.6466 .63457 m .64887 .63171 L .64538 .63143 L F
.6466 .63457 m .64869 .63407 L .64887 .63171 L F
.64887 .63171 m .64869 .63407 L .6466 .63457 L F
.507 .28 .505 r
.64887 .63171 m .65092 .63134 L .64869 .63407 L F
.64869 .63407 m .65092 .63134 L .64887 .63171 L F
.882 .825 .786 r
.50561 .88223 m .5039 .88776 L .50205 .88551 L F
.543 .658 .911 r
.48625 .87789 m .48869 .87922 L .48808 .87695 L F
.342 .082 .368 r
.48869 .87922 m .48826 .88229 L .49003 .88128 L F
0 .292 .784 r
.48805 .88858 m .48934 .88894 L .48695 .88781 L F
.48805 .88858 m .49041 .89028 L .48934 .88894 L F
.577 .393 .596 r
.33847 .75181 m .3407 .74906 L .3382 .74917 L F
.495 .614 .899 r
.69032 .59732 m .68852 .59744 L .68782 .59586 L F
.874 .644 .587 r
.57763 .79158 m .57961 .79457 L .57933 .79207 L F
.336 .658 .972 r
.43254 .72632 m .43453 .72651 L .43379 .72743 L F
.309 .619 .958 r
.43453 .72651 m .43572 .72776 L .43379 .72743 L F
.867 .923 .862 r
.54438 .81269 m .54499 .81025 L .54587 .81136 L F
.54438 .81269 m .54308 .81238 L .54499 .81025 L F
0 .029 .601 r
.54438 .81269 m .54615 .81539 L .54569 .81381 L F
.54438 .81269 m .54569 .81381 L .54308 .81238 L F
.756 .639 .731 r
.71334 .71146 m .71429 .71475 L .71633 .71208 L F
.622 .592 .798 r
.7176 .70847 m .71633 .71208 L .7157 .70948 L F
.7176 .70847 m .71885 .71172 L .71633 .71208 L F
.26 .369 .785 r
.72023 .71043 m .71885 .71172 L .7176 .70847 L F
.491 .371 .644 r
.71633 .71208 m .71939 .71123 L .71522 .71203 L F
.577 .352 .539 r
.71885 .71172 m .71868 .71388 L .71633 .71208 L F
.277 .397 .805 r
.72023 .71043 m .72135 .71355 L .71915 .71194 L F
.72023 .71043 m .71915 .71194 L .71885 .71172 L F
.467 .252 .503 r
.72213 .70805 m .72023 .71043 L .72003 .70837 L F
.646 .883 .533 r
.72213 .70805 m .72107 .70919 L .72023 .71043 L F
.53 .492 .758 r
.72107 .70919 m .72105 .70929 L .72023 .71043 L F
.505 .547 .833 r
.72356 .71315 m .72135 .71355 L .72023 .71043 L F
.72356 .71315 m .72023 .71043 L .72055 .71212 L F
.53 .492 .758 r
.72105 .70929 m .72055 .71212 L .72023 .71043 L F
.601 .373 .543 r
.71885 .71172 m .72135 .71355 L .71868 .71388 L F
.491 .371 .644 r
.71633 .71208 m .71868 .71388 L .71939 .71123 L F
.957 .75 .583 r
.71939 .71123 m .71599 .71243 L .71522 .71203 L F
.71599 .71243 m .71448 .71297 L .71522 .71203 L F
.756 .639 .731 r
.71334 .71146 m .71467 .71174 L .71522 .71203 L F
.71467 .71174 m .71633 .71208 L .71522 .71203 L F
.49 .731 .978 r
.37735 .78264 m .37657 .78395 L .37479 .78511 L F
.37735 .78264 m .37858 .78373 L .37657 .78395 L F
0 0 0 r
.37631 .80162 m .38004 .79991 L .37824 .80109 L F
.1 0 0 r
.37824 .80109 m .38004 .79991 L .38206 .7994 L F
.277 .486 .881 r
.67706 .72602 m .67445 .72406 L .6751 .72623 L F
.753 .642 .737 r
.64267 .59182 m .64404 .59511 L .64058 .59455 L F
.741 .636 .743 r
.64267 .59182 m .64607 .59248 L .64404 .59511 L F
.406 .315 .639 r
.47186 .86693 m .47409 .86833 L .47401 .86591 L F
.47186 .86693 m .47235 .86916 L .47409 .86833 L F
.774 .706 .788 r
.69021 .72204 m .69352 .72053 L .69247 .71922 L F
.72 .777 .897 r
.69352 .72053 m .6948 .71842 L .69247 .71922 L F
.69352 .72053 m .69571 .71981 L .6948 .71842 L F
.36 0 .191 r
.3293 .7216 m .32914 .72253 L .32712 .72288 L F
.149 0 .14 r
.33069 .72172 m .3293 .7216 L .33129 .71971 L F
.33069 .72172 m .32914 .72253 L .3293 .7216 L F
.679 .589 .748 r
.70431 .70907 m .70196 .71141 L .70218 .70968 L F
.702 .585 .721 r
.57846 .83156 m .58144 .83193 L .58031 .8317 L F
.57846 .83156 m .5812 .83307 L .58144 .83193 L F
.229 .46 .874 r
.58144 .83193 m .58261 .83115 L .58031 .8317 L F
.58144 .83193 m .58378 .83348 L .58261 .83115 L F
.352 .738 .986 r
.42574 .72483 m .42488 .72561 L .42359 .72491 L F
.42574 .72483 m .42709 .7256 L .42488 .72561 L F
.235 0 .245 r
.32354 .70851 m .3251 .70861 L .32587 .70612 L F
.226 0 .133 r
.32354 .70851 m .32251 .71072 L .3251 .70861 L F
.589 .282 .416 r
.63686 .65307 m .63619 .65552 L .63365 .65548 L F
.519 .199 .364 r
.63686 .65307 m .63944 .65472 L .63619 .65552 L F
.63686 .65307 m .6391 .65292 L .63944 .65472 L F
.781 .694 .768 r
.69214 .61572 m .69309 .61832 L .69016 .61796 L F
.339 0 0 r
.69309 .61832 m .69281 .61897 L .69016 .61796 L F
.596 .54 .762 r
.69427 .61501 m .69309 .61832 L .69214 .61572 L F
.69427 .61501 m .69545 .61825 L .69309 .61832 L F
.089 0 0 r
.69502 .61844 m .69309 .61832 L .69545 .61825 L F
.69502 .61844 m .69281 .61897 L .69309 .61832 L F
.157 0 0 r
.41105 .78769 m .41051 .7867 L .41253 .78596 L F
.41105 .78769 m .40912 .78841 L .41051 .7867 L F
.144 .384 .836 r
.47901 .86126 m .48155 .86315 L .48089 .86378 L F
.039 .204 .708 r
.48155 .86315 m .4826 .86644 L .48089 .86378 L F
.835 .991 .859 r
.64668 .59987 m .64377 .60154 L .64617 .60169 L F
.64668 .59987 m .64611 .59921 L .64377 .60154 L F
.364 0 .114 r
.64928 .59687 m .64611 .59921 L .64668 .59987 L F
.498 .807 1 r
.31514 .65257 m .31478 .65378 L .31322 .65289 L F
.31514 .65257 m .31663 .65339 L .31478 .65378 L F
.764 .68 .769 r
.49471 .88218 m .49256 .88501 L .4959 .88512 L F
.705 .33 .335 r
.49256 .88501 m .49495 .88699 L .4959 .88512 L F
.18 .634 .94 r
.49701 .88473 m .49835 .88553 L .4959 .88512 L F
.49701 .88473 m .4959 .88512 L .49495 .88699 L F
.594 .54 .764 r
.45026 .75237 m .45289 .75399 L .4524 .75182 L F
.554 .551 .805 r
.46621 .74073 m .46467 .74271 L .46418 .74128 L F
.46621 .74073 m .46755 .74426 L .46467 .74271 L F
.762 .726 .82 r
.66388 .61411 m .66487 .61603 L .6617 .61532 L F
.803 .64 .681 r
.6617 .61532 m .66487 .61603 L .66373 .61841 L F
.81 .744 .791 r
.66701 .61331 m .66487 .61603 L .66388 .61411 L F
.584 .447 .66 r
.3501 .78096 m .34771 .77979 L .34981 .78049 L F
.3501 .78096 m .34804 .78142 L .34771 .77979 L F
.303 .042 .342 r
.32587 .70612 m .32764 .70602 L .32813 .70359 L F
.407 .092 .316 r
.32587 .70612 m .32711 .70809 L .32764 .70602 L F
.32587 .70612 m .3251 .70861 L .32711 .70809 L F
.535 .249 .428 r
.3518 .81058 m .35395 .81037 L .3535 .81208 L F
.487 .319 .579 r
.50463 .87446 m .50345 .87157 L .5031 .87424 L F
.50463 .87446 m .50664 .87172 L .50345 .87157 L F
.50463 .87446 m .50659 .87414 L .50664 .87172 L F
.683 .308 .33 r
.5031 .87424 m .50659 .87414 L .50463 .87446 L F
.744 .622 .723 r
.68612 .74099 m .6874 .74425 L .68957 .74118 L F
.416 .425 .761 r
.6529 .59076 m .65374 .5941 L .65125 .59229 L F
.564 .719 .946 r
.65172 .59165 m .65106 .59216 L .65193 .59169 L F
.416 .425 .761 r
.65172 .59165 m .65125 .59229 L .65106 .59216 L F
.61 .701 .908 r
.65172 .59165 m .65193 .59169 L .6517 .59168 L F
.54 .676 .926 r
.6529 .59076 m .65193 .59169 L .64908 .58872 L F
.564 .719 .946 r
.6529 .59076 m .65172 .59165 L .65193 .59169 L F
.416 .425 .761 r
.6529 .59076 m .65125 .59229 L .65172 .59165 L F
.61 .701 .908 r
.64824 .59093 m .65172 .59165 L .64802 .59149 L F
.65172 .59165 m .6517 .59168 L .64802 .59149 L F
.64908 .58872 m .65193 .59169 L .64824 .59093 L F
.761 .364 .301 r
.64848 .6367 m .6466 .63457 L .64681 .63687 L F
.785 .656 .721 r
.56232 .80255 m .55998 .80234 L .5605 .79987 L F
.714 .475 .562 r
.56363 .80455 m .55998 .80234 L .56232 .80255 L F
.579 .509 .74 r
.46225 .73489 m .46108 .73882 L .45992 .73567 L F
.46225 .73489 m .46319 .73845 L .46108 .73882 L F
.573 .565 .807 r
.46418 .74128 m .46108 .73882 L .46319 .73845 L F
.965 .772 .594 r
.57532 .81234 m .57688 .81061 L .57559 .80999 L F
.57532 .81234 m .57655 .81301 L .57688 .81061 L F
.708 .53 .646 r
.51989 .87159 m .52364 .86843 L .51971 .8692 L F
.51989 .87159 m .52345 .87274 L .52364 .86843 L F
.644 .469 .631 r
.52345 .87274 m .52495 .86818 L .52364 .86843 L F
.423 .213 .487 r
.67445 .72406 m .67628 .72229 L .67435 .72268 L F
.443 0 0 r
.4143 .77474 m .41737 .77445 L .41582 .7735 L F
.584 .467 .685 r
.45122 .75705 m .4534 .75684 L .45289 .75399 L F
.575 .357 .547 r
.45112 .75892 m .4534 .75684 L .45122 .75705 L F
.457 .409 .717 r
.47413 .87446 m .47457 .87741 L .4764 .87632 L F
.525 .421 .678 r
.47457 .87741 m .47697 .87992 L .4764 .87632 L F
.47457 .87741 m .47499 .87993 L .47697 .87992 L F
.653 .55 .726 r
.47082 .74679 m .46892 .74927 L .46801 .74611 L F
.664 .567 .735 r
.47128 .74885 m .46892 .74927 L .47082 .74679 L F
.389 .015 .202 r
.36728 .73309 m .36933 .7327 L .37042 .73071 L F
.362 0 .187 r
.37042 .73071 m .37131 .73223 L .37249 .7304 L F
.37042 .73071 m .36933 .7327 L .37131 .73223 L F
.763 .256 0 r
.48175 .8788 m .48069 .8768 L .47913 .87727 L F
.48175 .8788 m .48289 .87939 L .48069 .8768 L F
.482 0 0 r
.6743 .6189 m .67643 .62085 L .6766 .62099 L F
.78 .885 .467 r
.6766 .62099 m .67643 .62085 L .67803 .61763 L F
.792 .403 .318 r
.49681 .86608 m .49875 .86836 L .49991 .86671 L F
.773 .378 .305 r
.49991 .86671 m .49875 .86836 L .49977 .86723 L F
.739 .639 .748 r
.64513 .59151 m .64607 .59248 L .64267 .59182 L F
.675 .738 .898 r
.64513 .59151 m .64802 .59149 L .64607 .59248 L F
.455 .865 .957 r
.48456 .75702 m .48519 .75617 L .4865 .75678 L F
.48456 .75702 m .48314 .75675 L .48519 .75617 L F
.239 .116 .503 r
.4865 .75678 m .48563 .75845 L .48456 .75702 L F
.658 .412 .535 r
.47505 .76392 m .47361 .76166 L .47488 .7622 L F
.47505 .76392 m .47117 .76489 L .47361 .76166 L F
.577 .36 .55 r
.33388 .75664 m .33637 .75439 L .33368 .75453 L F
.578 .368 .559 r
.36081 .76732 m .3587 .76507 L .36095 .76489 L F
.36081 .76732 m .35853 .76796 L .3587 .76507 L F
.644 .22 .222 r
.64126 .64165 m .64217 .64016 L .63922 .64014 L F
.573 .141 .182 r
.64126 .64165 m .64427 .64117 L .64217 .64016 L F
.159 .252 .712 r
.71334 .71146 m .71473 .71513 L .71429 .71475 L F
.877 .555 .437 r
.63732 .62547 m .63856 .62402 L .63745 .62311 L F
.63732 .62547 m .63888 .62624 L .63856 .62402 L F
.63 .617 .819 r
.63856 .62402 m .63978 .62038 L .63745 .62311 L F
.63856 .62402 m .64188 .62377 L .63978 .62038 L F
.573 .339 .523 r
.63856 .62402 m .63888 .62624 L .64095 .62572 L F
.63856 .62402 m .63888 .62624 L .64095 .62572 L F
.742 .735 .845 r
.52745 .86737 m .52495 .86818 L .52726 .86628 L F
0 .464 .861 r
.52839 .8673 m .52745 .86737 L .52726 .86628 L F
.52825 .86731 m .53076 .86885 L .52745 .86737 L F
.52876 .86754 m .53076 .86885 L .52825 .86731 L F
.984 .848 .466 r
.53025 .87121 m .53076 .86885 L .53017 .86849 L F
.53025 .87121 m .53017 .86849 L .53001 .86939 L F
.521 .335 .57 r
.52999 .86837 m .52986 .86928 L .53066 .86882 L F
.52986 .86928 m .52958 .87121 L .53031 .8696 L F
.52986 .86928 m .53031 .8696 L .53066 .86882 L F
.984 .848 .466 r
.53025 .87121 m .53001 .86939 L .53153 .87047 L F
.53001 .86939 m .53017 .86849 L .52987 .8683 L F
.521 .335 .57 r
.53066 .86882 m .52975 .87084 L .53153 .87047 L F
.984 .848 .466 r
.53001 .86939 m .52987 .8683 L .53153 .87047 L F
.521 .335 .57 r
.52975 .87084 m .52958 .87121 L .52969 .87117 L F
.52975 .87084 m .52969 .87117 L .53153 .87047 L F
.411 0 0 r
.5302 .86851 m .53029 .86857 L .52964 .86813 L F
.53029 .86857 m .53076 .86885 L .52964 .86813 L F
.521 .335 .57 r
.53008 .86773 m .52999 .86837 L .53066 .86882 L F
.411 0 0 r
.52964 .86813 m .52971 .86818 L .52876 .86754 L F
.52971 .86818 m .53076 .86885 L .52917 .86781 L F
.52971 .86818 m .52917 .86781 L .52876 .86754 L F
.676 .476 .607 r
.52627 .87116 m .52964 .86813 L .52606 .86806 L F
.52964 .86813 m .53008 .86773 L .52915 .86781 L F
.52964 .86813 m .52915 .86781 L .52606 .86806 L F
.52627 .87116 m .53002 .86812 L .52977 .868 L F
0 .464 .861 r
.52839 .8673 m .52876 .86754 L .52825 .86731 L F
.746 .493 .549 r
.52606 .86806 m .52915 .86781 L .52839 .8673 L F
.411 0 0 r
.5302 .86851 m .52876 .86754 L .52839 .8673 L F
.746 .493 .549 r
.52915 .86781 m .53008 .86773 L .52839 .8673 L F
.411 0 0 r
.52987 .8683 m .53017 .86849 L .52839 .8673 L F
.53017 .86849 m .5302 .86851 L .52839 .8673 L F
.676 .476 .607 r
.52627 .87116 m .52958 .87121 L .52999 .86837 L F
.52984 .86827 m .52999 .86837 L .53002 .86812 L F
.52627 .87116 m .52999 .86837 L .52984 .86827 L F
.52977 .868 m .53002 .86812 L .53008 .86773 L F
.919 .738 .641 r
.66591 .61015 m .66701 .61331 L .66555 .61217 L F
.81 .744 .791 r
.66701 .61331 m .66388 .61411 L .66555 .61217 L F
.557 .569 .822 r
.71424 .70626 m .7157 .70948 L .71305 .70935 L F
.886 .753 .71 r
.54488 .83664 m .54348 .83944 L .54599 .83932 L F
.376 .636 .956 r
.32985 .65397 m .3291 .65512 L .32766 .65394 L F
.32985 .65397 m .33094 .65529 L .3291 .65512 L F
.746 .731 .838 r
.51783 .8211 m .51471 .82133 L .51651 .81933 L F
.164 0 0 r
.51783 .8211 m .51741 .82135 L .51471 .82133 L F
0 0 .463 r
.51651 .81933 m .518 .82123 L .51783 .8211 L F
0 0 0 r
.51783 .8211 m .518 .82123 L .51741 .82135 L F
.816 .615 .631 r
.66643 .62588 m .66761 .62382 L .66927 .62394 L F
.129 0 0 r
.67289 .64007 m .67204 .64161 L .67046 .64175 L F
0 0 .228 r
.67435 .63907 m .67289 .64007 L .67436 .63696 L F
0 0 0 r
.67435 .63907 m .67204 .64161 L .67289 .64007 L F
.604 .602 .823 r
.44429 .74156 m .44565 .74445 L .44787 .74394 L F
.676 .771 .922 r
.33674 .68208 m .33793 .68314 L .33981 .68241 L F
.456 .474 .788 r
.33793 .68314 m .34023 .68475 L .33981 .68241 L F
.255 .019 .35 r
.32813 .70359 m .32999 .70307 L .33017 .70085 L F
.366 .095 .364 r
.32813 .70359 m .32943 .70546 L .32999 .70307 L F
.32813 .70359 m .32764 .70602 L .32943 .70546 L F
.889 .989 .792 r
.68936 .71929 m .68774 .72253 L .69021 .72204 L F
.68936 .71929 m .68732 .72197 L .68774 .72253 L F
.524 .346 .581 r
.68774 .72253 m .68595 .72544 L .68844 .72444 L F
.924 .72 .608 r
.68732 .72197 m .68844 .72444 L .68774 .72253 L F
.846 .916 .881 r
.68844 .72444 m .69021 .72204 L .68774 .72253 L F
.629 .843 .982 r
.38199 .78387 m .37858 .78373 L .38072 .78304 L F
.153 0 0 r
.38072 .78304 m .38361 .78278 L .38199 .78387 L F
.46 .088 .246 r
.44056 .77527 m .43732 .7775 L .43852 .77579 L F
0 0 0 r
.53754 .85 m .53952 .84755 L .53858 .84841 L F
.52726 .86628 m .52495 .86818 L .52606 .86806 L F
0 0 .478 r
.52495 .86818 m .52627 .87116 L .52606 .86806 L F
.613 .627 .841 r
.70453 .72438 m .70551 .72606 L .70801 .72536 L F
.742 .785 .888 r
.58811 .83965 m .5914 .83969 L .59001 .83853 L F
.603 .755 .951 r
.59001 .83853 m .5914 .83969 L .59327 .8392 L F
.625 .593 .798 r
.46966 .74383 m .46801 .74611 L .46755 .74426 L F
.46966 .74383 m .47082 .74679 L .46801 .74611 L F
.461 .076 .223 r
.64686 .65076 m .64365 .65285 L .64452 .65066 L F
.283 .071 .405 r
.32824 .72419 m .32712 .72288 L .32914 .72253 L F
.32824 .72419 m .3268 .72493 L .32712 .72288 L F
.461 0 .071 r
.40654 .77706 m .4102 .77561 L .408 .77564 L F
.644 .388 .517 r
.35222 .73621 m .35373 .73773 L .35428 .73573 L F
.35222 .73621 m .35165 .74012 L .35373 .73773 L F
.35222 .73621 m .35373 .73773 L .35428 .73573 L F
.35222 .73621 m .35165 .74012 L .35373 .73773 L F
.786 .623 .679 r
.59244 .83421 m .59609 .83245 L .59243 .83177 L F
.59244 .83421 m .59569 .83448 L .59609 .83245 L F
.66 .201 .152 r
.40632 .74311 m .40526 .74325 L .40339 .74295 L F
.622 .324 .444 r
.40885 .74215 m .40526 .74325 L .40632 .74311 L F
.801 .575 .594 r
.63435 .63146 m .63454 .63422 L .63788 .63377 L F
.586 .115 .104 r
.63454 .63422 m .63711 .63576 L .63788 .63377 L F
.641 .879 .985 r
.5046 .88764 m .50533 .88625 L .5035 .88775 L F
.5046 .88764 m .50667 .88683 L .50533 .88625 L F
.687 .625 .781 r
.56936 .82909 m .57266 .83139 L .57131 .82899 L F
.738 .741 .854 r
.57131 .82899 m .57266 .83139 L .57476 .82927 L F
.757 .628 .716 r
.68404 .74372 m .6874 .74425 L .68612 .74099 L F
.981 .737 .492 r
.72746 .72538 m .72635 .72495 L .7264 .72221 L F
.587 .569 .8 r
.72908 .72128 m .72746 .72538 L .7264 .72221 L F
.72908 .72128 m .73019 .72523 L .72746 .72538 L F
.389 .794 .983 r
.73019 .72523 m .72635 .72495 L .72746 .72538 L F
.448 .106 .291 r
.38099 .75109 m .37719 .75389 L .37794 .75175 L F
.539 .78 .987 r
.68119 .61576 m .68187 .616 L .68088 .61462 L F
.721 .396 .428 r
.56532 .78804 m .56897 .78615 L .56578 .78687 L F
.56532 .78804 m .56771 .78834 L .56897 .78615 L F
.717 .391 .426 r
.56771 .78834 m .57103 .78857 L .56897 .78615 L F
.916 .96 .799 r
.67783 .62555 m .67939 .62508 L .67768 .62474 L F
.67783 .62555 m .67832 .62654 L .67939 .62508 L F
.125 0 0 r
.67939 .62508 m .68002 .62524 L .67768 .62474 L F
.67939 .62508 m .68245 .62547 L .68002 .62524 L F
0 0 .034 r
.53754 .85 m .53573 .85307 L .53695 .85223 L F
.53754 .85 m .53695 .85223 L .53741 .85021 L F
0 0 0 r
.53754 .85 m .53895 .84962 L .53952 .84755 L F
.53754 .85 m .53741 .85021 L .53895 .84962 L F
.771 .46 .46 r
.68595 .72544 m .68378 .7275 L .6827 .72503 L F
.68595 .72544 m .68737 .7283 L .68378 .7275 L F
.664 .416 .535 r
.36584 .76459 m .36321 .76268 L .36597 .7624 L F
.36584 .76459 m .3629 .76486 L .36321 .76268 L F
.418 0 0 r
.64589 .62203 m .64664 .62191 L .64314 .62149 L F
.618 .762 .948 r
.69571 .71981 m .69728 .71783 L .6948 .71842 L F
.69571 .71981 m .69817 .71927 L .69728 .71783 L F
.834 .921 .892 r
.68264 .70989 m .67932 .7113 L .68162 .7089 L F
.641 .603 .795 r
.68109 .70641 m .68264 .70989 L .68467 .70892 L F
.686 .852 .962 r
.68467 .70892 m .68264 .70989 L .68162 .7089 L F
.775 .705 .786 r
.62776 .62846 m .62814 .63167 L .62572 .63128 L F
.62776 .62846 m .62935 .6294 L .62814 .63167 L F
.845 .722 .727 r
.62572 .63128 m .62814 .63167 L .62678 .63432 L F
.41 .132 .377 r
.32511 .72563 m .32437 .72759 L .32251 .72789 L F
.361 .085 .353 r
.32616 .72689 m .32511 .72563 L .3268 .72493 L F
.32616 .72689 m .32437 .72759 L .32511 .72563 L F
.442 0 .031 r
.39294 .72437 m .39513 .7244 L .39647 .72316 L F
.469 .702 .97 r
.46083 .73213 m .45974 .73326 L .45875 .73225 L F
.635 .463 .632 r
.46225 .73489 m .45974 .73326 L .46083 .73213 L F
.46225 .73489 m .45992 .73567 L .45974 .73326 L F
.916 .882 .786 r
.68825 .72724 m .68764 .73038 L .68946 .72893 L F
.308 0 .099 r
.32251 .72789 m .32437 .72759 L .32214 .72843 L F
.577 .904 .98 r
.34237 .8128 m .34347 .81294 L .34278 .81266 L F
.44 .847 .97 r
.3448 .81216 m .34347 .81294 L .3469 .8122 L F
.3448 .81216 m .34278 .81266 L .34347 .81294 L F
.839 .68 .686 r
.57782 .82036 m .57899 .82372 L .57944 .82146 L F
.57782 .82036 m .5759 .82337 L .57899 .82372 L F
.84 .661 .659 r
.5759 .82337 m .57737 .8263 L .57899 .82372 L F
.879 .452 .053 r
.68493 .73524 m .68402 .73495 L .68415 .73261 L F
.68493 .73524 m .68502 .73566 L .68402 .73495 L F
.889 .848 .797 r
.68764 .73038 m .68493 .73524 L .68415 .73261 L F
0 0 0 r
.56616 .80496 m .5646 .8079 L .56553 .80678 L F
.56616 .80496 m .56553 .80678 L .56363 .80455 L F
.363 .684 .979 r
.4311 .7252 m .43049 .72628 L .42897 .72502 L F
.4311 .7252 m .43254 .72632 L .43049 .72628 L F
0 .15 .693 r
.67329 .60971 m .67402 .61142 L .67505 .61245 L F
.771 .774 .855 r
.70957 .60523 m .70647 .60478 L .70867 .60297 L F
.818 .666 .695 r
.70957 .60523 m .70701 .60802 L .70647 .60478 L F
.732 .527 .615 r
.70953 .60755 m .70701 .60802 L .70957 .60523 L F
.618 .692 .897 r
.71187 .60463 m .70957 .60523 L .70867 .60297 L F
.561 .39 .607 r
.71187 .60463 m .70953 .60755 L .70957 .60523 L F
.213 .445 .867 r
.54677 .81031 m .54587 .81136 L .54499 .81025 L F
.54677 .81031 m .54854 .81281 L .54587 .81136 L F
.88 .843 .804 r
.57691 .80207 m .5767 .80502 L .57811 .8028 L F
.378 .351 .702 r
.47413 .87446 m .47506 .87106 L .47323 .87148 L F
.47413 .87446 m .47603 .87469 L .47506 .87106 L F
.36 .401 .769 r
.47413 .87446 m .4764 .87632 L .47603 .87469 L F
.519 .351 .593 r
.69558 .60501 m .69557 .60732 L .6935 .60779 L F
.248 .111 .49 r
.69557 .60732 m .69389 .61058 L .6935 .60779 L F
.952 .817 .376 r
.67417 .59695 m .67344 .59851 L .67327 .5961 L F
.67417 .59695 m .67365 .5998 L .67344 .59851 L F
.908 .916 .812 r
.67607 .59415 m .67417 .59695 L .67327 .5961 L F
.308 0 .066 r
.64983 .64962 m .65238 .64842 L .65173 .64916 L F
.286 0 .077 r
.65238 .64842 m .65381 .64936 L .65173 .64916 L F
.65238 .64842 m .65458 .64778 L .65381 .64936 L F
.215 0 .217 r
.34148 .70807 m .34177 .70611 L .34201 .7064 L F
.34148 .70807 m .34002 .70874 L .34177 .70611 L F
.707 .575 .703 r
.34936 .78875 m .34709 .78934 L .34921 .78658 L F
.614 .54 .747 r
.35135 .78624 m .34921 .78658 L .34809 .78349 L F
.687 .614 .768 r
.35135 .78624 m .34936 .78875 L .34921 .78658 L F
.953 .803 .657 r
.68538 .73809 m .68612 .74099 L .68656 .73873 L F
.68538 .73809 m .68612 .74099 L .68656 .73873 L F
0 0 0 r
.53573 .85307 m .53432 .85604 L .53501 .85502 L F
.588 .476 .693 r
.53501 .85502 m .53695 .85223 L .53573 .85307 L F
.908 .916 .812 r
.67607 .59415 m .67327 .5961 L .67493 .59356 L F
.814 .848 .875 r
.67764 .5907 m .67607 .59415 L .67493 .59356 L F
.67764 .5907 m .67869 .59182 L .67607 .59415 L F
0 0 0 r
.38405 .79907 m .38755 .79709 L .38592 .79841 L F
.08 0 0 r
.38806 .7978 m .38755 .79709 L .38935 .79649 L F
.38806 .7978 m .38592 .79841 L .38755 .79709 L F
.201 0 0 r
.39632 .79403 m .39497 .79369 L .39703 .7931 L F
.39632 .79403 m .39414 .79453 L .39497 .79369 L F
.378 0 0 r
.50188 .88554 m .50205 .88551 L .50029 .88472 L F
.719 .665 .796 r
.48808 .87695 m .49021 .87456 L .48793 .87484 L F
0 0 0 r
.6461 .60832 m .6439 .61079 L .64286 .60739 L F
.6461 .60832 m .64567 .60955 L .6439 .61079 L F
.6461 .60832 m .647 .60807 L .64567 .60955 L F
.6461 .60832 m .64876 .6074 L .647 .60807 L F
.62 .648 .857 r
.64925 .60597 m .64876 .6074 L .6461 .60832 L F
.687 .614 .768 r
.35135 .78624 m .35252 .7893 L .34936 .78875 L F
.213 0 0 r
.35792 .67347 m .35939 .67386 L .36106 .6742 L F
.087 .526 .905 r
.36128 .67357 m .36106 .6742 L .35939 .67386 L F
.36128 .67357 m .36288 .67477 L .36106 .6742 L F
.699 .579 .718 r
.57957 .83495 m .57897 .83753 L .5812 .83307 L F
.168 .066 .486 r
.33017 .70085 m .33165 .70024 L .33166 .69794 L F
.205 0 .336 r
.33017 .70085 m .3313 .70244 L .33165 .70024 L F
.33017 .70085 m .32999 .70307 L .3313 .70244 L F
.301 0 0 r
.4202 .78368 m .41665 .78552 L .41805 .78349 L F
.252 .388 .806 r
.67503 .61712 m .67374 .61837 L .67244 .61548 L F
0 .045 .607 r
.6752 .61953 m .67374 .61837 L .67503 .61712 L F
.6752 .61953 m .6743 .6189 L .67374 .61837 L F
.994 .782 .411 r
.43599 .74304 m .43653 .74531 L .4379 .74442 L F
.813 .691 .73 r
.61404 .65082 m .61097 .65227 L .61239 .65143 L F
.61404 .65082 m .61228 .65302 L .61097 .65227 L F
.79 .963 .919 r
.61239 .65143 m .61609 .64997 L .61404 .65082 L F
0 0 .413 r
.6797 .62752 m .67832 .62654 L .67783 .62555 L F
.6797 .62752 m .67828 .62883 L .67832 .62654 L F
.738 .51 .583 r
.49919 .87216 m .50354 .86897 L .49977 .86723 L F
.49919 .87216 m .50345 .87157 L .50354 .86897 L F
.701 .509 .626 r
.48216 .75979 m .48058 .76101 L .47941 .75959 L F
.092 .22 .705 r
.6712 .61247 m .66933 .61038 L .67025 .60931 L F
.117 .116 .58 r
.6721 .61302 m .67199 .61333 L .6712 .61247 L F
.66 .156 0 r
.67229 .61373 m .67023 .6114 L .6712 .61247 L F
.998 .799 .508 r
.6716 .61447 m .67229 .61373 L .6712 .61247 L F
.117 .116 .58 r
.67199 .61333 m .6716 .61447 L .6712 .61247 L F
.66 .156 0 r
.67023 .6114 m .66933 .61038 L .6712 .61247 L F
.501 .109 .229 r
.33589 .67423 m .33444 .67623 L .33215 .67639 L F
.388 0 .161 r
.33677 .67495 m .33444 .67623 L .33589 .67423 L F
.531 .532 .802 r
.46621 .74073 m .46418 .74128 L .46319 .73845 L F
.947 .957 .72 r
.5373 .83112 m .53613 .83134 L .53785 .8279 L F
.713 .366 .388 r
.5373 .83112 m .53546 .83355 L .53613 .83134 L F
.5373 .83112 m .53884 .83552 L .53546 .83355 L F
.604 .409 .591 r
.43607 .76476 m .43839 .76475 L .43841 .76244 L F
.653 .444 .589 r
.43839 .76475 m .44067 .76229 L .43841 .76244 L F
.389 0 .057 r
.64686 .65076 m .64983 .64962 L .64918 .65053 L F
.365 0 .105 r
.65173 .64916 m .64918 .65053 L .64983 .64962 L F
.768 .294 .113 r
.48656 .86359 m .48998 .86576 L .48745 .86369 L F
.476 .813 .999 r
.32073 .6528 m .32018 .65389 L .3187 .65322 L F
.32073 .6528 m .32206 .65354 L .32018 .65389 L F
.462 .013 .097 r
.38823 .74975 m .38659 .7513 L .38457 .75133 L F
.425 0 .068 r
.38974 .75051 m .38659 .7513 L .38823 .74975 L F
.61 .701 .908 r
.64908 .58872 m .64802 .59149 L .64698 .58934 L F
.675 .738 .898 r
.64513 .59151 m .64698 .58934 L .64802 .59149 L F
.64 .585 .776 r
.64928 .59687 m .65255 .5975 L .65149 .59505 L F
.112 0 .136 r
.65149 .59505 m .65114 .5963 L .64928 .59687 L F
.477 .198 .412 r
.65114 .5963 m .64838 .59873 L .64928 .59687 L F
.364 0 .114 r
.64928 .59687 m .64838 .59873 L .64611 .59921 L F
.193 0 .278 r
.67648 .63625 m .67435 .63907 L .67436 .63696 L F
.593 .562 .788 r
.35459 .7889 m .35252 .7893 L .35135 .78624 L F
.743 .611 .711 r
.5859 .8263 m .58549 .82879 L .58749 .82714 L F
.705 .547 .671 r
.64041 .63498 m .64096 .63448 L .63888 .63396 L F
.879 .865 .821 r
.69556 .70655 m .69353 .7094 L .69238 .70846 L F
.748 .666 .771 r
.56607 .8263 m .56931 .82654 L .56812 .82414 L F
.678 .636 .801 r
.56812 .82414 m .56931 .82654 L .57154 .82635 L F
.483 .271 .515 r
.56936 .82909 m .57154 .82635 L .56931 .82654 L F
.535 .743 .971 r
.3391 .67706 m .34015 .67555 L .33677 .67495 L F
.3391 .67706 m .34108 .67669 L .34015 .67555 L F
.319 .379 .768 r
.3391 .67706 m .34132 .67893 L .34108 .67669 L F
.761 .559 .625 r
.69101 .61251 m .69429 .61291 L .69389 .61058 L F
.69101 .61251 m .69389 .61058 L .69499 .6119 L F
.248 .111 .49 r
.69557 .60732 m .69551 .61007 L .69389 .61058 L F
.335 .369 .749 r
.69551 .61007 m .69499 .6119 L .69389 .61058 L F
.291 .278 .672 r
.68823 .62785 m .68627 .62975 L .68604 .62636 L F
.172 .096 .522 r
.68669 .63187 m .68627 .62975 L .68823 .62785 L F
.546 0 0 r
.6443 .62411 m .64299 .62467 L .64188 .62377 L F
.418 0 0 r
.64589 .62203 m .64335 .62302 L .6443 .62411 L F
.995 .803 .533 r
.64335 .62302 m .64299 .62467 L .6443 .62411 L F
.68 .654 .818 r
.47429 .75223 m .47547 .75535 L .47204 .75399 L F
.604 .576 .795 r
.47643 .7512 m .47547 .75535 L .47429 .75223 L F
.47643 .7512 m .47779 .75505 L .47547 .75535 L F
.708 .645 .784 r
.68909 .7036 m .69009 .70677 L .68686 .70611 L F
.66 .616 .795 r
.69224 .7063 m .69009 .70677 L .68909 .7036 L F
0 .435 .844 r
.69238 .70846 m .69009 .70677 L .69224 .7063 L F
.508 .665 .933 r
.70238 .72222 m .70252 .71938 L .69993 .71947 L F
.70238 .72222 m .70386 .72164 L .70252 .71938 L F
.671 .3 .334 r
.35728 .73557 m .35957 .73594 L .36021 .73542 L F
.411 0 .092 r
.36021 .73542 m .35957 .73594 L .3623 .73524 L F
.736 .789 .895 r
.6414 .59075 m .64513 .59151 L .64267 .59182 L F
.6414 .59075 m .6441 .58898 L .64513 .59151 L F
.665 .721 .89 r
.64595 .58779 m .64513 .59151 L .6441 .58898 L F
.64595 .58779 m .64698 .58934 L .64513 .59151 L F
.797 .694 .751 r
.63132 .62683 m .62776 .62846 L .62995 .62571 L F
.63132 .62683 m .62935 .6294 L .62776 .62846 L F
.405 .799 .987 r
.39854 .7229 m .40055 .72269 L .40192 .7232 L F
.199 0 0 r
.40055 .72269 m .4041 .72301 L .40192 .7232 L F
.869 .607 .54 r
.5424 .8339 m .54488 .83664 L .54476 .83451 L F
.776 .767 .845 r
.71374 .62199 m .71079 .62382 L .71304 .62119 L F
0 0 0 r
.71304 .62119 m .71079 .62382 L .71242 .62233 L F
.51 .235 .433 r
.71093 .62373 m .71318 .62638 L .71079 .62382 L F
.71318 .62638 m .71318 .62638 L .71079 .62382 L F
.71345 .62431 m .71319 .62639 L .71093 .62373 L F
.71318 .62638 m .71319 .62639 L .71318 .62638 L F
.71374 .62199 m .71345 .62431 L .71093 .62373 L F
.264 .209 .606 r
.71079 .62382 m .71319 .62639 L .71242 .62233 L F
.632 .341 .457 r
.71553 .62537 m .71319 .62639 L .71374 .62199 L F
.718 .514 .613 r
.71242 .62233 m .71319 .62639 L .71553 .62537 L F
.792 .935 .925 r
.71533 .62528 m .71205 .62666 L .71499 .62511 L F
.71553 .62537 m .7141 .6259 L .71533 .62528 L F
.7141 .6259 m .71205 .62666 L .71533 .62528 L F
.632 .341 .457 r
.71553 .62537 m .71374 .62199 L .71631 .62367 L F
.718 .514 .613 r
.71242 .62233 m .71474 .6246 L .71408 .6222 L F
.71474 .6246 m .71553 .62537 L .71523 .62472 L F
.71474 .6246 m .71523 .62472 L .71408 .6222 L F
.387 .595 .928 r
.33852 .65634 m .33783 .65763 L .33633 .65629 L F
.33852 .65634 m .33966 .6579 L .33783 .65763 L F
.702 .585 .721 r
.57846 .83156 m .57957 .83495 L .5812 .83307 L F
0 .108 .659 r
.67702 .71447 m .67651 .71408 L .67839 .71678 L F
.504 .608 .89 r
.67702 .71447 m .67839 .71678 L .68044 .71662 L F
.728 .631 .75 r
.67866 .72105 m .68044 .71662 L .67839 .71678 L F
.312 .757 .962 r
.36347 .78883 m .36001 .78846 L .36216 .7876 L F
.559 .708 .94 r
.3645 .78721 m .36347 .78883 L .36216 .7876 L F
.3645 .78721 m .36556 .78855 L .36347 .78883 L F
.601 .566 .787 r
.56564 .82381 m .56812 .82414 L .56671 .82094 L F
.626 .472 .654 r
.56564 .82381 m .56607 .8263 L .56812 .82414 L F
.49 .162 .338 r
.42073 .77209 m .42286 .77187 L .42334 .77053 L F
.534 .22 .382 r
.42286 .77187 m .42549 .77033 L .42334 .77053 L F
.934 .665 .19 r
.63833 .60181 m .63925 .60515 L .63849 .6039 L F
.884 .754 .713 r
.63925 .60515 m .63627 .60626 L .63849 .6039 L F
.63925 .60515 m .63757 .60793 L .63627 .60626 L F
.689 .662 .819 r
.6408 .60322 m .63925 .60515 L .63833 .60181 L F
.57 .488 .723 r
.63925 .60515 m .64186 .60456 L .6408 .60322 L F
.528 .825 .999 r
.63925 .60515 m .64186 .60456 L .6408 .60387 L F
.975 .696 .435 r
.64064 .60581 m .64186 .60456 L .63925 .60515 L F
.405 .175 .449 r
.6408 .60387 m .64064 .60581 L .63925 .60515 L F
.665 .586 .758 r
.3501 .78096 m .34809 .78349 L .34804 .78142 L F
.517 .012 0 r
.47697 .87992 m .47906 .88197 L .47886 .88182 L F
.721 .361 0 r
.47906 .88197 m .48018 .88476 L .47886 .88182 L F
.517 .162 .303 r
.44331 .77359 m .44282 .77506 L .44056 .77527 L F
.635 .347 .464 r
.44601 .77295 m .44282 .77506 L .44331 .77359 L F
.292 .785 .883 r
.4041 .72301 m .4062 .72264 L .40735 .72275 L F
.228 .743 .865 r
.4062 .72264 m .40934 .72253 L .40735 .72275 L F
.541 .216 .366 r
.43517 .76713 m .43839 .76475 L .43607 .76476 L F
.608 .388 .556 r
.64096 .63448 m .6433 .63647 L .64126 .63648 L F
.615 .386 .547 r
.64349 .63426 m .6433 .63647 L .64096 .63448 L F
.286 .772 .912 r
.64276 .63393 m .64096 .63448 L .64041 .63498 L F
.64276 .63393 m .64349 .63426 L .64096 .63448 L F
0 0 .216 r
.67676 .63374 m .67632 .63399 L .67691 .63149 L F
0 0 .234 r
.67676 .63374 m .67648 .63625 L .67632 .63399 L F
.665 .586 .758 r
.3501 .78096 m .35124 .78391 L .34809 .78349 L F
.614 .54 .747 r
.35135 .78624 m .34809 .78349 L .35124 .78391 L F
.5 .406 .68 r
.39333 .9893 m .3956 .99155 L .39388 .99217 L F
.39388 .99217 m .3956 .99155 L .39333 .9893 L F
.798 .758 .816 r
.68936 .71929 m .69021 .72204 L .69247 .71922 L F
.813 .714 .756 r
.53222 .82336 m .5311 .82675 L .52858 .82581 L F
.837 .675 .682 r
.5311 .82675 m .53 .82869 L .52858 .82581 L F
.702 .557 .688 r
.71804 .62038 m .71631 .62367 L .71631 .62139 L F
.46 .775 .997 r
.39156 .8762 m .39359 .8772 L .39099 .87741 L F
.35 .65 .967 r
.39099 .87741 m .39242 .87693 L .39156 .8762 L F
.341 .779 .966 r
.39359 .8772 m .39242 .87693 L .39099 .87741 L F
.427 .251 .537 r
.34002 .70874 m .33973 .71138 L .33766 .71087 L F
.348 .13 .435 r
.33914 .71315 m .33766 .71087 L .33973 .71138 L F
.33914 .71315 m .33752 .71382 L .33766 .71087 L F
.388 .792 .983 r
.41355 .72257 m .41513 .72322 L .41285 .72347 L F
.297 0 0 r
.41217 .72297 m .41543 .72244 L .41355 .72257 L F
.335 .772 .967 r
.41355 .72257 m .41583 .72238 L .41743 .72293 L F
.297 0 0 r
.41543 .72244 m .41583 .72238 L .41355 .72257 L F
.388 .792 .983 r
.41355 .72257 m .41285 .72347 L .41146 .72272 L F
.41355 .72257 m .41146 .72272 L .41129 .72263 L F
.48 .81 1 r
.43987 .72728 m .43914 .72832 L .43782 .72755 L F
.43987 .72728 m .44119 .72799 L .43914 .72832 L F
.446 .747 .993 r
.36489 .67449 m .36339 .67517 L .36288 .67477 L F
.36489 .67449 m .36584 .67512 L .36339 .67517 L F
.782 .659 .726 r
.59244 .83421 m .59377 .83717 L .59569 .83448 L F
.429 0 .042 r
.42782 .78097 m .42414 .78237 L .42564 .78143 L F
.418 .11 .334 r
.31865 .71224 m .32075 .71139 L .31882 .71179 L F
.501 .057 .125 r
.67046 .64175 m .66958 .64253 L .66736 .64236 L F
.097 0 0 r
.67204 .64161 m .66958 .64253 L .67046 .64175 L F
.307 0 0 r
.41416 .74127 m .41275 .74145 L .41075 .74111 L F
.566 .13 .171 r
.41623 .74074 m .41275 .74145 L .41416 .74127 L F
.702 .557 .688 r
.71631 .62139 m .71374 .62199 L .71304 .62119 L F
.71631 .62139 m .71631 .62367 L .71374 .62199 L F
.728 .655 .776 r
.69447 .70347 m .69556 .70655 L .69224 .7063 L F
.879 .865 .821 r
.69556 .70655 m .69238 .70846 L .69224 .7063 L F
.721 .676 .806 r
.71431 .6289 m .71527 .63178 L .71184 .63111 L F
.642 .144 .053 r
.71527 .63178 m .7141 .63271 L .71184 .63111 L F
.545 .572 .832 r
.71612 .63025 m .71527 .63178 L .71431 .6289 L F
.347 .013 .249 r
.71612 .63025 m .7141 .63271 L .71527 .63178 L F
.65 .77 .936 r
.35809 .78948 m .35459 .7889 L .35663 .78841 L F
.702 .815 .935 r
.36001 .78846 m .35809 .78948 L .35663 .78841 L F
.596 .368 .541 r
.45606 .7678 m .45597 .76987 L .45434 .76987 L F
.549 .33 .534 r
.45606 .7678 m .45803 .76966 L .45597 .76987 L F
.591 .326 .483 r
.45825 .76771 m .45803 .76966 L .45606 .7678 L F
.36 0 .185 r
.37786 .72759 m .3786 .72923 L .37998 .72746 L F
.37786 .72759 m .37667 .72969 L .3786 .72923 L F
.603 .533 .749 r
.47299 .74641 m .47128 .74885 L .47082 .74679 L F
.47299 .74641 m .4735 .74867 L .47128 .74885 L F
.609 .484 .685 r
.47429 .75223 m .47128 .74885 L .4735 .74867 L F
.47429 .75223 m .47227 .75308 L .47128 .74885 L F
.679 .195 .093 r
.63711 .63576 m .64136 .63648 L .64041 .63498 L F
.857 .826 .816 r
.64136 .63648 m .64276 .63393 L .64041 .63498 L F
.765 .633 .714 r
.71631 .62139 m .71304 .62119 L .71477 .61869 L F
.194 0 0 r
.36692 .80479 m .36588 .80541 L .36244 .8066 L F
.146 0 0 r
.36895 .80454 m .36588 .80541 L .36692 .80479 L F
.407 .153 .413 r
.34495 .74359 m .34677 .7433 L .3474 .74104 L F
.396 .143 .408 r
.3474 .74104 m .34874 .74249 L .34942 .74045 L F
.3474 .74104 m .34677 .7433 L .34874 .74249 L F
.449 .035 .16 r
.38216 .72754 m .38434 .72739 L .38569 .72557 L F
.333 0 .087 r
.38569 .72557 m .38726 .72601 L .38767 .7253 L F
.38569 .72557 m .38434 .72739 L .38726 .72601 L F
.335 .694 .981 r
.32606 .65286 m .32547 .6538 L .32419 .65323 L F
.32606 .65286 m .32766 .65394 L .32547 .6538 L F
.932 .863 .75 r
.68764 .73038 m .6865 .73001 L .68737 .7283 L F
.889 .848 .797 r
.68764 .73038 m .68415 .73261 L .6865 .73001 L F
.916 .882 .786 r
.68825 .72724 m .6865 .73001 L .68764 .73038 L F
.838 .614 .599 r
.68586 .73202 m .68764 .73038 L .6865 .73001 L F
.68586 .73202 m .68757 .73324 L .68764 .73038 L F
.667 .409 .521 r
.58588 .83359 m .58746 .83152 L .58538 .83128 L F
.58588 .83359 m .58913 .83395 L .58746 .83152 L F
.317 .141 .477 r
.47454 .86247 m .47732 .86225 L .47933 .86051 L F
.47454 .86247 m .4755 .86324 L .47732 .86225 L F
0 .15 .693 r
.4736 .86117 m .4755 .86324 L .47454 .86247 L F
.362 .31 .665 r
.47421 .86366 m .4755 .86324 L .4736 .86117 L F
.566 .374 .58 r
.37719 .75389 m .37489 .75674 L .37558 .75467 L F
.964 .659 .399 r
.54087 .82884 m .54229 .83164 L .54286 .82953 L F
.494 .289 .53 r
.34287 .74633 m .34485 .7461 L .34495 .74359 L F
.537 .365 .596 r
.34485 .7461 m .34677 .7433 L .34495 .74359 L F
.678 .475 .604 r
.70476 .60884 m .70194 .60998 L .70406 .60712 L F
.70476 .60884 m .70425 .6107 L .70194 .60998 L F
.607 .523 .734 r
.70647 .60478 m .70476 .60884 L .70406 .60712 L F
.70647 .60478 m .70701 .60802 L .70476 .60884 L F
.318 .127 .457 r
.70659 .60929 m .70476 .60884 L .70701 .60802 L F
.70659 .60929 m .70425 .6107 L .70476 .60884 L F
.539 .78 .987 r
.68119 .61576 m .68088 .61462 L .68019 .61492 L F
.252 .469 .875 r
.68019 .61492 m .68346 .61784 L .68119 .61576 L F
.701 .509 .626 r
.48216 .75979 m .48212 .76233 L .48058 .76101 L F
.657 .474 .624 r
.48459 .762 m .48216 .75979 L .48563 .75845 L F
.48459 .762 m .48212 .76233 L .48216 .75979 L F
.709 .42 .484 r
.62067 .65764 m .61688 .65582 L .62063 .65571 L F
.606 .369 .532 r
.62063 .65571 m .6228 .65766 L .62067 .65764 L F
.676 .348 .411 r
.62273 .65605 m .6228 .65766 L .62063 .65571 L F
.994 .782 .411 r
.43653 .74531 m .43599 .74304 L .43471 .74403 L F
.49 .548 .843 r
.43471 .74403 m .43653 .74531 L .43599 .74304 L F
.377 .661 .969 r
.44675 .72926 m .44868 .72938 L .44786 .73045 L F
.484 .806 1 r
.44868 .72938 m .44995 .73011 L .44786 .73045 L F
.557 .357 .566 r
.32973 .76238 m .33181 .76213 L .33196 .7597 L F
.532 .375 .613 r
.33196 .7597 m .33392 .75933 L .33388 .75664 L F
.537 .35 .575 r
.33181 .76213 m .33392 .75933 L .33196 .7597 L F
.451 .477 .795 r
.69306 .59871 m .69238 .60214 L .69144 .60021 L F
.69306 .59871 m .69419 .60188 L .69238 .60214 L F
.419 .46 .796 r
.69306 .59871 m .69144 .60021 L .69032 .59732 L F
.418 .188 .455 r
.34604 .70047 m .3461 .70315 L .34389 .70285 L F
.393 .171 .455 r
.34569 .70512 m .34389 .70285 L .3461 .70315 L F
.34569 .70512 m .34397 .70581 L .34389 .70285 L F
.534 .18 .313 r
.36433 .73465 m .36728 .73309 L .36509 .73344 L F
.877 .477 .27 r
.48323 .88164 m .48588 .88452 L .48365 .8825 L F
.532 .324 .543 r
.5517 .79989 m .55168 .80202 L .54959 .80235 L F
.566 .269 .423 r
.55646 .79965 m .55168 .80202 L .5517 .79989 L F
.466 .433 .737 r
.57846 .83156 m .57878 .82786 L .57699 .82877 L F
.57846 .83156 m .58031 .8317 L .57878 .82786 L F
.448 .106 .291 r
.38099 .75109 m .37916 .75367 L .37719 .75389 L F
.549 .206 .339 r
.3825 .75147 m .37916 .75367 L .38099 .75109 L F
.712 .458 .538 r
.51322 .87709 m .51 .87927 L .51047 .87717 L F
.51322 .87709 m .51501 .8809 L .51 .87927 L F
.93 .652 .175 r
.51269 .87607 m .51322 .87709 L .51242 .87415 L F
.762 .477 .502 r
.51414 .8803 m .51322 .87709 L .51269 .87607 L F
.51414 .8803 m .51501 .8809 L .51322 .87709 L F
.155 0 0 r
.35595 .80998 m .35899 .8076 L .3581 .80965 L F
0 0 0 r
.35899 .8076 m .36086 .80707 L .36039 .80741 L F
.114 0 .101 r
.3581 .80965 m .35899 .8076 L .36039 .80741 L F
.684 .656 .816 r
.3513 .66088 m .34986 .66344 L .34844 .66056 L F
.572 .515 .752 r
.3513 .66088 m .35206 .66303 L .34986 .66344 L F
.562 .356 .56 r
.36779 .76216 m .36584 .76459 L .36597 .7624 L F
.578 .577 .816 r
.69658 .60126 m .69558 .60501 L .69419 .60188 L F
.69658 .60126 m .69769 .60437 L .69558 .60501 L F
.603 .418 .604 r
.69806 .60668 m .69558 .60501 L .69769 .60437 L F
.69806 .60668 m .69557 .60732 L .69558 .60501 L F
0 0 0 r
.55313 .79418 m .55403 .79351 L .55573 .79092 L F
.55403 .79351 m .55801 .79167 L .55573 .79092 L F
.621 .454 .634 r
.55573 .79092 m .55801 .79167 L .55785 .78907 L F
.011 .462 .87 r
.48514 .88706 m .48427 .88621 L .48372 .8863 L F
.48514 .88706 m .48695 .88781 L .48427 .88621 L F
.806 .59 .61 r
.58431 .82829 m .58549 .82879 L .5859 .8263 L F
.465 .239 .487 r
.33195 .69584 m .33371 .69555 L .33416 .69326 L F
.603 .416 .601 r
.33371 .69555 m .33604 .69267 L .33416 .69326 L F
.799 .64 .685 r
.57763 .79158 m .57762 .79453 L .57961 .79457 L F
.777 .492 .504 r
.57762 .79453 m .5774 .79656 L .57961 .79457 L F
.895 .706 .639 r
.57961 .79457 m .5774 .79656 L .57924 .79705 L F
.88 .843 .804 r
.57691 .80207 m .57447 .80431 L .5767 .80502 L F
.94 .739 .603 r
.57469 .80673 m .5767 .80502 L .57447 .80431 L F
.57469 .80673 m .57638 .80785 L .5767 .80502 L F
.968 .684 .439 r
.64851 .61196 m .64977 .61294 L .64944 .61041 L F
.596 .425 .62 r
.34281 .74858 m .34485 .7461 L .34287 .74633 L F
.583 .019 0 r
.54327 .84178 m .54121 .83919 L .54348 .83944 L F
.653 .444 .589 r
.43839 .76475 m .44079 .76492 L .44067 .76229 L F
.537 .256 .437 r
.44079 .76492 m .44377 .76214 L .44067 .76229 L F
.806 .59 .61 r
.58431 .82829 m .58242 .82872 L .58549 .82879 L F
.83 .567 .54 r
.58242 .82872 m .58538 .83128 L .58549 .82879 L F
.615 .299 .411 r
.64517 .60347 m .64617 .60169 L .64377 .60154 L F
.64517 .60347 m .64635 .60313 L .64617 .60169 L F
0 0 .318 r
.33486 .71463 m .33538 .71666 L .33511 .71626 L F
.385 .17 .46 r
.33706 .71597 m .33486 .71463 L .33752 .71382 L F
.33706 .71597 m .33538 .71666 L .33486 .71463 L F
.72 .373 .389 r
.54097 .84684 m .54246 .84489 L .54192 .84486 L F
.54097 .84684 m .54452 .84639 L .54246 .84489 L F
.622 .324 .444 r
.40885 .74215 m .408 .74411 L .40526 .74325 L F
.136 0 .192 r
.4098 .74274 m .40885 .74215 L .41075 .74111 L F
.4098 .74274 m .408 .74411 L .40885 .74215 L F
.79 .502 .501 r
.67628 .72229 m .68083 .72425 L .67813 .72161 L F
.67628 .72229 m .67631 .72443 L .68083 .72425 L F
.804 .787 .837 r
.68083 .72425 m .67631 .72443 L .67706 .72602 L F
.642 .639 .831 r
.67813 .72161 m .68083 .72425 L .68198 .72191 L F
.642 .617 .809 r
.4501 .74344 m .45132 .74644 L .45364 .74602 L F
.635 .519 .705 r
.4517 .74894 m .45364 .74602 L .45132 .74644 L F
.666 .572 .739 r
.51 .87927 m .51501 .8809 L .51152 .88239 L F
.783 .342 .201 r
.51414 .8803 m .51541 .88167 L .51501 .8809 L F
0 .229 .744 r
.51512 .87978 m .51541 .88167 L .51462 .88081 L F
.51448 .88012 m .51462 .88081 L .51414 .8803 L F
.51512 .87978 m .51462 .88081 L .51448 .88012 L F
.715 .831 .937 r
.51466 .88105 m .51428 .88271 L .51152 .88239 L F
.51501 .8809 m .51475 .88154 L .51466 .88105 L F
.51475 .88154 m .51428 .88271 L .51466 .88105 L F
.661 .825 .962 r
.69982 .70096 m .69659 .70085 L .69871 .70061 L F
.558 .405 .629 r
.35853 .76796 m .35632 .77013 L .35633 .76889 L F
.605 .704 .914 r
.45875 .73225 m .45662 .73269 L .45522 .73091 L F
.977 .869 .663 r
.68328 .72283 m .68181 .72422 L .68198 .72191 L F
.68328 .72283 m .6827 .72503 L .68181 .72422 L F
.181 .591 .941 r
.44545 .72823 m .44403 .72862 L .44293 .72778 L F
.44545 .72823 m .44675 .72926 L .44403 .72862 L F
.678 .636 .801 r
.56812 .82414 m .57154 .82635 L .57034 .8235 L F
.483 .271 .515 r
.56936 .82909 m .57131 .82899 L .57154 .82635 L F
.498 .445 .728 r
.57154 .82635 m .57261 .82287 L .57034 .8235 L F
.57154 .82635 m .57369 .82595 L .57261 .82287 L F
.443 .238 .506 r
.57154 .82635 m .57131 .82899 L .57369 .82595 L F
.57154 .82635 m .57131 .82899 L .57369 .82595 L F
.621 .319 .437 r
.46361 .7652 m .46566 .76708 L .46376 .76677 L F
.63 .316 .419 r
.46704 .76531 m .46566 .76708 L .46361 .7652 L F
.783 .926 .93 r
.31768 .67582 m .31879 .67637 L .32145 .67459 L F
.791 .697 .761 r
.62572 .63128 m .62678 .63432 L .62363 .63398 L F
.796 .676 .732 r
.62363 .63398 m .62678 .63432 L .62486 .63717 L F
.306 .314 .704 r
.68632 .62036 m .68709 .62281 L .68567 .62373 L F
.42 .551 .882 r
.68709 .62281 m .68754 .62389 L .68567 .62373 L F
.631 .512 .699 r
.689 .62522 m .68567 .62373 L .68754 .62389 L F
.689 .62522 m .68604 .62636 L .68567 .62373 L F
.911 .66 .545 r
.71089 .71336 m .71334 .71146 L .7125 .71042 L F
.71089 .71336 m .71473 .71513 L .71334 .71146 L F
.805 .341 .128 r
.71522 .71203 m .7125 .71042 L .71334 .71146 L F
.717 .561 .676 r
.49212 .86425 m .49107 .86637 L .49324 .86379 L F
.57 .356 .55 r
.49107 .86637 m .49333 .86606 L .49324 .86379 L F
.899 .671 .586 r
.63663 .61314 m .63668 .61576 L .63512 .61227 L F
.738 .46 .509 r
.48241 .86828 m .48579 .86644 L .4826 .86644 L F
.48241 .86828 m .48565 .86849 L .48579 .86644 L F
.718 .322 .296 r
.48579 .86644 m .48449 .8682 L .48585 .86584 L F
.48579 .86644 m .48788 .86854 L .48449 .8682 L F
.594 .352 .519 r
.48805 .86635 m .48788 .86854 L .48579 .86644 L F
.783 .537 .565 r
.50773 .87704 m .50473 .87925 L .50423 .87705 L F
.50773 .87704 m .50766 .87968 L .50473 .87925 L F
.65 .426 .565 r
.50773 .87704 m .51 .87927 L .50766 .87968 L F
.67 .423 .539 r
.50773 .87704 m .51047 .87717 L .51 .87927 L F
.51 .473 .752 r
.47235 .86916 m .47323 .87148 L .47506 .87106 L F
.25 .057 .411 r
.33195 .69584 m .33328 .69693 L .33371 .69555 L F
.33195 .69584 m .33166 .69794 L .33328 .69693 L F
.725 .664 .789 r
.50766 .87968 m .50905 .88317 L .50561 .88223 L F
.593 .593 .821 r
.51152 .88239 m .50905 .88317 L .50766 .87968 L F
.391 .814 .633 r
.66183 .64424 m .65836 .64629 L .65983 .64518 L F
.852 .806 .805 r
.6414 .59075 m .64267 .59182 L .64058 .59455 L F
.352 0 0 r
.6451 .61493 m .647 .61467 L .64317 .61646 L F
.634 .365 .494 r
.4766 .76248 m .47505 .76392 L .47488 .7622 L F
.657 .732 .905 r
.68686 .70611 m .68126 .70481 L .68572 .70314 L F
.702 .635 .778 r
.68909 .7036 m .68686 .70611 L .68572 .70314 L F
.598 .488 .699 r
.45289 .75399 m .4547 .75139 L .4524 .75182 L F
.45289 .75399 m .45532 .75433 L .4547 .75139 L F
.565 .43 .656 r
.4534 .75684 m .45532 .75433 L .45289 .75399 L F
.6 .58 .802 r
.47299 .74641 m .47082 .74679 L .46966 .74383 L F
.992 .745 .444 r
.54961 .80523 m .5486 .80475 L .54959 .80235 L F
.579 .561 .798 r
.54959 .80235 m .55168 .80202 L .55115 .79905 L F
.51 .323 .564 r
.55168 .80202 m .54961 .80523 L .54959 .80235 L F
.18 0 .109 r
.54959 .80235 m .55054 .8037 L .55168 .80202 L F
.54959 .80235 m .5486 .80475 L .55054 .8037 L F
.603 .726 .932 r
.68026 .58997 m .67869 .59182 L .67764 .5907 L F
.68026 .58997 m .68091 .59129 L .67869 .59182 L F
.705 .288 .252 r
.71862 .62555 m .71553 .62537 L .71631 .62367 L F
.827 .652 .666 r
.57457 .82037 m .57765 .81829 L .57579 .81726 L F
.57457 .82037 m .57782 .82036 L .57765 .81829 L F
.677 .793 .937 r
.65827 .63186 m .65744 .63442 L .65624 .63224 L F
.65827 .63186 m .65905 .63347 L .65744 .63442 L F
.756 .753 .85 r
.65446 .63424 m .65624 .63224 L .65744 .63442 L F
.759 .636 .725 r
.71008 .72479 m .71323 .72506 L .71237 .72202 L F
.732 .544 .638 r
.71008 .72479 m .71346 .72744 L .71323 .72506 L F
.555 .379 .598 r
.71323 .72506 m .71346 .72744 L .71588 .72693 L F
.803 .64 .681 r
.66245 .61648 m .66373 .61841 L .66203 .61698 L F
0 .235 .746 r
.66203 .61698 m .66432 .619 L .66387 .61792 L F
.66432 .619 m .66465 .6193 L .66387 .61792 L F
.838 .969 .884 r
.66343 .61675 m .66341 .61678 L .66387 .61792 L F
0 .235 .746 r
.66203 .61698 m .66387 .61792 L .6612 .61797 L F
.193 0 0 r
.66387 .61792 m .65967 .61871 L .66068 .61798 L F
.66387 .61792 m .66194 .61853 L .65967 .61871 L F
.838 .969 .884 r
.66341 .61678 m .66194 .61853 L .66387 .61792 L F
0 .235 .746 r
.66203 .61698 m .6612 .61797 L .66068 .61798 L F
.803 .64 .681 r
.6617 .61532 m .66245 .61648 L .66203 .61698 L F
.66 .664 .844 r
.71255 .71398 m .71473 .71513 L .71089 .71336 L F
.714 .71474 m .71157 .71699 L .71473 .71513 L F
.71194 .71586 m .71157 .71699 L .714 .71474 L F
.748 .729 .834 r
.71127 .71798 m .71216 .71968 L .71157 .71699 L F
.835 .796 .814 r
.70995 .71625 m .71127 .71798 L .71157 .71699 L F
.66 .664 .844 r
.71255 .71398 m .71194 .71586 L .714 .71474 L F
.71255 .71398 m .71419 .71619 L .71157 .71699 L F
.694 .375 .432 r
.71419 .71619 m .71229 .71825 L .71043 .71667 L F
.71419 .71619 m .70995 .71625 L .71157 .71699 L F
.71124 .71623 m .71043 .71667 L .70995 .71625 L F
.71419 .71619 m .71043 .71667 L .71124 .71623 L F
.556 .374 .589 r
.3542 .77281 m .35439 .77579 L .35197 .7754 L F
.603 .413 .598 r
.35431 .77785 m .35197 .7754 L .35439 .77579 L F
.35431 .77785 m .35269 .77883 L .35197 .7754 L F
.499 .134 .278 r
.42977 .76974 m .43307 .76754 L .43095 .76785 L F
.474 .475 .779 r
.47235 .86916 m .47506 .87106 L .47409 .86833 L F
.564 .521 .765 r
.63894 .64162 m .63581 .63944 L .63922 .64014 L F
0 0 0 r
.64126 .63648 m .64045 .63869 L .63922 .64014 L F
.63922 .64014 m .63886 .64104 L .63894 .64162 L F
.644 .22 .222 r
.64126 .64165 m .63922 .64014 L .63894 .64162 L F
0 0 0 r
.63922 .64014 m .64045 .63869 L .63886 .64104 L F
.763 .553 .612 r
.58913 .83395 m .59244 .83421 L .59243 .83177 L F
.696 .338 .365 r
.64127 .62127 m .64335 .62302 L .64314 .62149 L F
.418 0 0 r
.64589 .62203 m .64314 .62149 L .64335 .62302 L F
.543 .366 .591 r
.32976 .76478 m .33181 .76213 L .32973 .76238 L F
.472 .377 .666 r
.47538 .85519 m .4772 .85506 L .47623 .85373 L F
.823 .89 .891 r
.51651 .81933 m .51471 .82133 L .51343 .82035 L F
.524 .576 .85 r
.51471 .82133 m .51532 .81996 L .51343 .82035 L F
.51471 .82133 m .51741 .82135 L .51532 .81996 L F
.819 .788 .823 r
.43599 .74304 m .43871 .74293 L .43831 .74014 L F
.735 .653 .768 r
.43831 .74014 m .43871 .74293 L .44147 .74059 L F
.842 .422 0 r
.5646 .8079 m .56426 .80867 L .56553 .80678 L F
.5646 .8079 m .56575 .81025 L .56426 .80867 L F
.537 .256 .437 r
.44079 .76492 m .44297 .76469 L .44377 .76214 L F
.611 .33 .466 r
.44377 .76214 m .44563 .76386 L .44608 .76222 L F
.44377 .76214 m .44297 .76469 L .44563 .76386 L F
.858 .644 .611 r
.68453 .63149 m .68237 .63325 L .68185 .63106 L F
.68453 .63149 m .68481 .63424 L .68237 .63325 L F
.763 .706 .798 r
.68669 .63187 m .68481 .63424 L .68453 .63149 L F
.458 .795 .999 r
.49182 .75902 m .49308 .75977 L .48984 .75934 L F
.487 .808 1 r
.49182 .75902 m .49519 .75943 L .49308 .75977 L F
.49308 .75977 m .49519 .75943 L .49182 .75902 L F
.868 .813 .793 r
.63932 .59356 m .64058 .59455 L .63887 .59704 L F
.852 .806 .805 r
.6414 .59075 m .64058 .59455 L .63932 .59356 L F
.008 .581 .76 r
.3469 .8122 m .34688 .81211 L .3448 .81216 L F
.3469 .8122 m .35045 .8124 L .34688 .81211 L F
.066 .628 .777 r
.39981 .74301 m .39642 .74294 L .39785 .74304 L F
.638 .444 .604 r
.69016 .63169 m .68804 .63329 L .68669 .63187 L F
.69016 .63169 m .69018 .63432 L .68804 .63329 L F
.69016 .63169 m .68669 .63187 L .68927 .63302 L F
.696 .251 .191 r
.68927 .63302 m .69248 .6335 L .69016 .63169 L F
.801 .726 .782 r
.54348 .85044 m .54559 .8477 L .54452 .84639 L F
.577 .36 .55 r
.33388 .75664 m .33612 .75644 L .33637 .75439 L F
.542 .33 .542 r
.33612 .75644 m .33853 .754 L .33637 .75439 L F
.442 .212 .468 r
.34872 .6993 m .3461 .70315 L .34604 .70047 L F
.63 .773 .949 r
.36892 .7891 m .36556 .78855 L .36752 .78838 L F
.785 .88 .916 r
.37057 .78777 m .36892 .7891 L .36752 .78838 L F
.792 .761 .825 r
.70194 .60998 m .69874 .60975 L .70107 .60722 L F
.81 .71 .755 r
.70194 .60998 m .69976 .61289 L .69874 .60975 L F
.651 .477 .636 r
.70194 .60998 m .70262 .61317 L .69976 .61289 L F
.82 .775 .81 r
.70406 .60712 m .70194 .60998 L .70107 .60722 L F
.669 .487 .629 r
.70425 .6107 m .70262 .61317 L .70194 .60998 L F
.365 .425 .791 r
.48054 .86028 m .48155 .86315 L .47901 .86126 L F
.561 .32 .508 r
.44608 .76222 m .44827 .76202 L .44852 .75982 L F
.563 .314 .497 r
.44827 .76202 m .45112 .75892 L .44852 .75982 L F
.55 .329 .533 r
.336 .69015 m .33842 .68972 L .33857 .68776 L F
.443 .298 .588 r
.33857 .68776 m .34029 .68726 L .34023 .68475 L F
.307 .089 .41 r
.33842 .68972 m .34029 .68726 L .33857 .68776 L F
.496 .035 .088 r
.39906 .77999 m .40124 .78016 L .40282 .7787 L F
.431 .03 .176 r
.40124 .78016 m .40467 .77799 L .40282 .7787 L F
.907 .732 .654 r
.6804 .70328 m .67969 .7065 L .6781 .70376 L F
0 0 .573 r
.6781 .70376 m .67939 .70483 L .6804 .70328 L F
.67896 .70525 m .67969 .7065 L .67939 .70483 L F
.481 .619 .91 r
.67813 .70863 m .67578 .70758 L .67852 .70657 L F
0 0 .347 r
.67578 .70758 m .67677 .70805 L .67774 .70686 L F
.589 .561 .79 r
.67868 .7057 m .67852 .70657 L .67677 .70805 L F
.67939 .70483 m .67852 .70657 L .67868 .7057 L F
.481 .619 .91 r
.67876 .70892 m .67813 .70863 L .67852 .70657 L F
0 0 0 r
.67939 .70483 m .67831 .70631 L .67981 .70441 L F
.67939 .70483 m .67981 .70441 L .68046 .70359 L F
0 0 .573 r
.6781 .70376 m .67896 .70525 L .67939 .70483 L F
.153 0 0 r
.38072 .78304 m .38295 .78304 L .38361 .78278 L F
.639 .939 .699 r
.38361 .78278 m .38536 .78088 L .38617 .78078 L F
.38361 .78278 m .38295 .78304 L .38536 .78088 L F
.58 .897 .986 r
.53222 .82336 m .52897 .82366 L .53146 .82294 L F
.813 .714 .756 r
.53222 .82336 m .52858 .82581 L .52897 .82366 L F
.848 .488 .371 r
.53146 .82294 m .5338 .82384 L .53222 .82336 L F
.635 .519 .705 r
.4517 .74894 m .45415 .74925 L .45364 .74602 L F
.647 .533 .711 r
.4517 .74894 m .4547 .75139 L .45415 .74925 L F
.4517 .74894 m .4524 .75182 L .4547 .75139 L F
.553 .401 .629 r
.55785 .78907 m .56011 .79125 L .56024 .78886 L F
.55785 .78907 m .55799 .79131 L .56011 .79125 L F
.602 .41 .595 r
.56011 .79125 m .56246 .78841 L .56024 .78886 L F
.56011 .79125 m .56237 .79124 L .56246 .78841 L F
.737 .331 .28 r
.55894 .79088 m .56195 .7912 L .56011 .79125 L F
.56195 .7912 m .56237 .79124 L .56011 .79125 L F
.553 .401 .629 r
.55799 .79131 m .55801 .79167 L .56011 .79125 L F
.614 .536 .743 r
.35658 .67081 m .35425 .67147 L .35351 .66836 L F
.586 .617 .849 r
.35792 .67347 m .35425 .67147 L .35658 .67081 L F
.222 0 .307 r
.52814 .87383 m .52889 .87191 L .53025 .87121 L F
.521 .441 .706 r
.65255 .5975 m .65257 .59966 L .65452 .5991 L F
.62 .453 .634 r
.65452 .5991 m .65252 .60206 L .65257 .59966 L F
.125 0 .417 r
.65257 .59966 m .65368 .60039 L .65452 .5991 L F
.65257 .59966 m .65252 .60206 L .65368 .60039 L F
.82 .856 .875 r
.60184 .65392 m .6034 .65319 L .60194 .65216 L F
.272 0 0 r
.48124 .88567 m .48279 .88626 L .48018 .88476 L F
.48124 .88567 m .48372 .8863 L .48279 .88626 L F
.426 .272 .568 r
.47573 .84879 m .47823 .84712 L .47624 .84731 L F
.339 .279 .643 r
.47573 .84879 m .47817 .85181 L .47806 .84941 L F
.47573 .84879 m .47623 .85373 L .47817 .85181 L F
.471 .106 .263 r
.45068 .77095 m .45041 .77222 L .44814 .7726 L F
.525 .173 .313 r
.45434 .76987 m .45041 .77222 L .45068 .77095 L F
.291 .278 .672 r
.68823 .62785 m .68604 .62636 L .68873 .62533 L F
.172 .096 .522 r
.68669 .63187 m .68823 .62785 L .68793 .63016 L F
.942 .795 .337 r
.68793 .62938 m .68823 .62785 L .68792 .62664 L F
.68793 .63016 m .68823 .62785 L .68793 .62938 L F
.291 .278 .672 r
.68823 .62785 m .68873 .62533 L .689 .62522 L F
.65 .354 .457 r
.62625 .65542 m .6228 .65766 L .62273 .65605 L F
.43 .391 .714 r
.33981 .68241 m .34206 .6843 L .34129 .68116 L F
.502 .392 .662 r
.34023 .68475 m .34206 .6843 L .33981 .68241 L F
.239 .116 .503 r
.4865 .75678 m .48655 .75888 L .48563 .75845 L F
.655 .473 .626 r
.48765 .76167 m .48563 .75845 L .48655 .75888 L F
.48765 .76167 m .48459 .762 L .48563 .75845 L F
.716 .424 .481 r
.61688 .65582 m .6136 .65752 L .61331 .65498 L F
.61688 .65582 m .61731 .65775 L .6136 .65752 L F
.709 .42 .484 r
.62067 .65764 m .61731 .65775 L .61688 .65582 L F
0 0 0 r
.40157 .7914 m .40525 .7897 L .40363 .79094 L F
.40363 .79094 m .40525 .7897 L .40716 .78897 L F
.39 0 0 r
.41839 .72391 m .42029 .72475 L .42155 .72506 L F
.355 .77 .979 r
.42234 .72433 m .42155 .72506 L .42029 .72475 L F
.42234 .72433 m .42359 .72491 L .42155 .72506 L F
.628 .594 .796 r
.46966 .74383 m .46755 .74426 L .46621 .74073 L F
.345 .415 .791 r
.35823 .6707 m .35792 .67347 L .35658 .67081 L F
.35823 .6707 m .35939 .67386 L .35792 .67347 L F
.52 .405 .664 r
.48121 .84733 m .4818 .84987 L .47955 .85013 L F
.249 .116 .495 r
.4818 .84987 m .47992 .85308 L .47955 .85013 L F
.559 .625 .874 r
.3536 .66321 m .35314 .66618 L .35206 .66303 L F
.3536 .66321 m .35509 .66579 L .35314 .66618 L F
.588 .504 .726 r
.35509 .66579 m .35351 .66836 L .35314 .66618 L F
.943 .693 .529 r
.57515 .81467 m .57655 .81301 L .57532 .81234 L F
.57515 .81467 m .57656 .8152 L .57655 .81301 L F
.65 .354 .457 r
.62625 .65542 m .6277 .65752 L .6228 .65766 L F
.622 .349 .482 r
.62625 .65542 m .62836 .65743 L .6277 .65752 L F
.691 .328 .354 r
.62827 .65601 m .62836 .65743 L .62625 .65542 L F
.571 .228 .348 r
.41737 .77445 m .41962 .77455 L .42073 .77209 L F
.456 .105 .28 r
.41962 .77455 m .42286 .77187 L .42073 .77209 L F
.525 .831 1 r
.49041 .89028 m .49375 .89054 L .4925 .88982 L F
.721 .892 .958 r
.4925 .88982 m .49375 .89054 L .4959 .88921 L F
.423 .213 .487 r
.67445 .72406 m .67631 .72443 L .67628 .72229 L F
.277 .486 .881 r
.67706 .72602 m .67631 .72443 L .67445 .72406 L F
.647 .59 .776 r
.47429 .75223 m .47204 .75399 L .47227 .75308 L F
.778 .5 .514 r
.61228 .65302 m .61153 .65419 L .61097 .65227 L F
.61228 .65302 m .61331 .65498 L .61153 .65419 L F
.852 .614 .578 r
.63182 .63378 m .63435 .63146 L .63361 .6308 L F
.63182 .63378 m .63454 .63422 L .63435 .63146 L F
.843 .961 .884 r
.63702 .62912 m .63361 .6308 L .63435 .63146 L F
.485 .735 .982 r
.3349 .65508 m .33416 .65641 L .33287 .6553 L F
.3349 .65508 m .33633 .65629 L .33416 .65641 L F
.763 .706 .798 r
.68669 .63187 m .68804 .63329 L .68481 .63424 L F
.656 .375 .481 r
.68481 .63424 m .68804 .63329 L .68727 .6363 L F
.674 .394 .49 r
.69018 .63432 m .68727 .6363 L .68804 .63329 L F
0 0 .479 r
.6827 .72503 m .68372 .72635 L .68181 .72422 L F
.6827 .72503 m .68378 .7275 L .68372 .72635 L F
.827 .663 .679 r
.57457 .82037 m .5759 .82337 L .57782 .82036 L F
.568 .396 .609 r
.336 .69015 m .33845 .69222 L .33842 .68972 L F
.336 .69015 m .33604 .69267 L .33845 .69222 L F
.921 .679 .556 r
.63978 .62038 m .64188 .62377 L .64127 .62127 L F
.449 .391 .7 r
.64188 .62377 m .64335 .62302 L .64127 .62127 L F
.151 .245 .707 r
.66465 .6193 m .66365 .6203 L .66462 .62114 L F
.832 .677 .69 r
.59212 .83627 m .59377 .83717 L .59244 .83421 L F
.603 .755 .951 r
.59001 .83853 m .59377 .83717 L .59212 .83627 L F
.59001 .83853 m .59327 .8392 L .59377 .83717 L F
.917 .59 .409 r
.62664 .62098 m .62557 .62219 L .62511 .62034 L F
.566 .573 .82 r
.62797 .61773 m .62664 .62098 L .62511 .62034 L F
.62797 .61773 m .62894 .62057 L .62664 .62098 L F
.781 .603 .659 r
.62894 .62057 m .62557 .62219 L .62664 .62098 L F
.249 .116 .495 r
.4818 .84987 m .48164 .85241 L .47992 .85308 L F
.31 .264 .643 r
.48164 .85241 m .48153 .85523 L .47992 .85308 L F
.14 .206 .671 r
.47992 .85308 m .48153 .85523 L .48086 .85559 L F
.629 .756 .938 r
.41943 .74206 m .42248 .74241 L .42148 .74178 L F
.452 .775 .998 r
.42248 .74241 m .42374 .74162 L .42148 .74178 L F
.42248 .74241 m .42505 .74226 L .42374 .74162 L F
0 0 0 r
.37093 .80415 m .37443 .80217 L .37286 .8035 L F
.104 0 0 r
.37286 .8035 m .37443 .80217 L .37631 .80162 L F
.478 .223 .448 r
.35519 .69229 m .3532 .69276 L .35565 .69042 L F
.46 .206 .442 r
.35716 .69173 m .35565 .69042 L .35748 .68981 L F
.35716 .69173 m .35519 .69229 L .35565 .69042 L F
.868 .813 .793 r
.63932 .59356 m .63887 .59704 L .63806 .59629 L F
.998 .78 .463 r
.63887 .59704 m .63798 .59851 L .63806 .59629 L F
.63887 .59704 m .63875 .59944 L .63798 .59851 L F
.677 .268 .264 r
.70208 .70111 m .70426 .70282 L .70494 .70123 L F
.824 .44 .327 r
.70494 .70123 m .70426 .70282 L .7059 .7031 L F
.118 .302 .775 r
.48185 .75367 m .48214 .7564 L .47984 .75472 L F
.48185 .75367 m .48314 .75675 L .48214 .7564 L F
.678 .593 .754 r
.35352 .78349 m .35124 .78391 L .3501 .78096 L F
.666 .527 .685 r
.35352 .78349 m .35135 .78624 L .35124 .78391 L F
.531 .34 .567 r
.35632 .77013 m .35633 .77287 L .3542 .77281 L F
.587 .397 .591 r
.3563 .77531 m .3542 .77281 L .35633 .77287 L F
.3563 .77531 m .35439 .77579 L .3542 .77281 L F
.851 .587 .539 r
.55998 .80234 m .55696 .79944 L .5605 .79987 L F
.55998 .80234 m .55721 .80217 L .55696 .79944 L F
.759 .507 .552 r
.55998 .80234 m .55842 .8041 L .55721 .80217 L F
.55998 .80234 m .56036 .80504 L .55842 .8041 L F
.714 .475 .562 r
.56363 .80455 m .56036 .80504 L .55998 .80234 L F
.83 .723 .746 r
.6224 .64201 m .61936 .64166 L .62128 .63884 L F
.838 .68 .687 r
.6224 .64201 m .62047 .64484 L .61936 .64166 L F
.808 .712 .76 r
.62287 .63989 m .6224 .64201 L .62128 .63884 L F
.798 .678 .732 r
.71127 .71798 m .71237 .72202 L .71216 .71968 L F
.96 .655 .405 r
.68413 .73729 m .68538 .73809 L .68502 .73566 L F
.824 .915 .899 r
.68402 .73495 m .68502 .73566 L .68757 .73324 L F
.96 .655 .405 r
.68413 .73729 m .68538 .73809 L .68502 .73566 L F
.73 .664 .785 r
.65255 .5975 m .65473 .59696 L .65374 .5941 L F
.521 .441 .706 r
.65255 .5975 m .65452 .5991 L .65473 .59696 L F
.493 .177 .358 r
.65753 .59709 m .65452 .5991 L .65473 .59696 L F
.513 .047 .084 r
.65641 .5986 m .65473 .59696 L .65452 .5991 L F
.65641 .5986 m .65753 .59709 L .65473 .59696 L F
.354 .149 .458 r
.64702 .6396 m .64848 .6367 L .64681 .63687 L F
.513 .36 .611 r
.33388 .75664 m .33587 .75871 L .33612 .75644 L F
.33388 .75664 m .33392 .75933 L .33587 .75871 L F
.634 .365 .494 r
.4766 .76248 m .47663 .76436 L .47505 .76392 L F
.606 .341 .49 r
.48058 .76101 m .47663 .76436 L .4766 .76248 L F
.558 .405 .629 r
.35853 .76796 m .35836 .76994 L .35632 .77013 L F
.565 .367 .571 r
.35826 .77238 m .35632 .77013 L .35836 .76994 L F
.35826 .77238 m .35633 .77287 L .35632 .77013 L F
.964 .659 .399 r
.54087 .82884 m .54112 .83115 L .54229 .83164 L F
.969 .681 .431 r
.54112 .83115 m .5424 .8339 L .54229 .83164 L F
.994 .782 .411 r
.43653 .74531 m .43589 .74565 L .43599 .74304 L F
.43599 .74304 m .43589 .74565 L .43653 .74531 L F
.104 0 .214 r
.4939 .88447 m .49256 .88501 L .49471 .88218 L F
.33 .387 .77 r
.4939 .88447 m .49495 .88699 L .49256 .88501 L F
.66 .616 .795 r
.69224 .7063 m .68909 .7036 L .69221 .70401 L F
.693 .601 .749 r
.69447 .70347 m .69224 .7063 L .69221 .70401 L F
0 0 0 r
.6673 .62453 m .66761 .62382 L .66643 .62588 L F
.129 0 0 r
.31791 .71369 m .32075 .71139 L .31865 .71224 L F
.606 .341 .49 r
.48058 .76101 m .47874 .76448 L .47663 .76436 L F
.675 .422 .53 r
.48253 .76392 m .48058 .76101 L .48212 .76233 L F
.48253 .76392 m .47874 .76448 L .48058 .76101 L F
.616 .629 .841 r
.70453 .72438 m .70569 .72128 L .70386 .72164 L F
.70453 .72438 m .70661 .72465 L .70569 .72128 L F
.621 .621 .829 r
.70453 .72438 m .70801 .72536 L .70661 .72465 L F
.728 .631 .75 r
.67866 .72105 m .68132 .72157 L .68044 .71662 L F
.424 0 0 r
.67813 .72161 m .68132 .72157 L .67866 .72105 L F
.67813 .72161 m .68198 .72191 L .68132 .72157 L F
.373 .38 .738 r
.68044 .71662 m .68132 .72157 L .68285 .71849 L F
.185 .157 .591 r
.68198 .72191 m .68285 .71849 L .68132 .72157 L F
.487 .292 .54 r
.35084 .69538 m .35036 .69772 L .34869 .69779 L F
.477 .222 .449 r
.35036 .69772 m .34872 .6993 L .34869 .69779 L F
.803 .741 .795 r
.68936 .71929 m .69247 .71922 L .69139 .71661 L F
.656 .669 .851 r
.69139 .71661 m .69247 .71922 L .6948 .71842 L F
.331 .81 .765 r
.31126 .65319 m .31207 .65273 L .31322 .65289 L F
.31126 .65319 m .30949 .65365 L .31207 .65273 L F
.843 .961 .884 r
.63702 .62912 m .63636 .62788 L .63361 .6308 L F
.814 .954 .908 r
.63689 .62765 m .63702 .62912 L .63782 .62784 L F
.63689 .62765 m .63636 .62788 L .63702 .62912 L F
0 0 0 r
.67691 .63149 m .67828 .62883 L .6782 .62907 L F
0 0 .216 r
.67676 .63374 m .67691 .63149 L .6782 .62907 L F
.496 .83 .999 r
.4959 .88921 m .4988 .8894 L .49771 .88917 L F
.618 .947 .938 r
.4988 .8894 m .50058 .88797 L .49771 .88917 L F
.4988 .8894 m .50138 .88823 L .50058 .88797 L F
.466 .255 .508 r
.35965 .68714 m .35748 .68981 L .35775 .68765 L F
.366 .262 .602 r
.49456 .86951 m .49653 .8683 L .49271 .86864 L F
.49456 .86951 m .49622 .87123 L .49653 .8683 L F
.73 .664 .785 r
.65255 .5975 m .65374 .5941 L .65149 .59505 L F
.274 .743 .943 r
.47624 .84731 m .47775 .84476 L .47554 .84533 L F
.936 .722 .587 r
.56686 .81244 m .56526 .8124 L .56575 .81025 L F
.106 .218 .698 r
.56559 .81494 m .56526 .8124 L .56686 .81244 L F
.183 0 0 r
.66736 .64236 m .66624 .64319 L .66396 .6434 L F
.022 0 0 r
.66958 .64253 m .66624 .64319 L .66736 .64236 L F
.583 .058 0 r
.40526 .74325 m .40161 .74306 L .40339 .74295 L F
.823 .592 .588 r
.40526 .74325 m .40174 .74546 L .40161 .74306 L F
.40526 .74325 m .40548 .74675 L .40174 .74546 L F
.82 .589 .589 r
.40633 .74639 m .40548 .74675 L .40526 .74325 L F
.61 .478 .677 r
.40848 .74591 m .40526 .74325 L .408 .74411 L F
.40848 .74591 m .40633 .74639 L .40526 .74325 L F
.961 .668 .431 r
.68171 .6291 m .68078 .6304 L .68058 .62832 L F
.68171 .6291 m .68185 .63106 L .68078 .6304 L F
.554 .268 .435 r
.3535 .81208 m .35395 .81037 L .35564 .81199 L F
.501 .272 .498 r
.35564 .81199 m .35395 .81037 L .35595 .80998 L F
.589 .758 .959 r
.48027 .8688 m .48378 .86957 L .48241 .86828 L F
.665 .783 .936 r
.48241 .86828 m .48378 .86957 L .48565 .86849 L F
.578 .78 .975 r
.43831 .74014 m .44147 .74059 L .44051 .73942 L F
.238 0 0 r
.44357 .74025 m .44051 .73942 L .44147 .74059 L F
.511 .656 .924 r
.44147 .74059 m .44429 .74156 L .44357 .74025 L F
.578 .233 .348 r
.43445 .77822 m .43188 .77983 L .43286 .778 L F
0 0 0 r
.71477 .61869 m .71414 .61981 L .71405 .61719 L F
.71477 .61869 m .71304 .62119 L .71414 .61981 L F
.544 .543 .804 r
.71564 .61505 m .71477 .61869 L .71405 .61719 L F
.752 .639 .735 r
.69101 .61251 m .69214 .61572 L .69429 .61291 L F
.655 .499 .66 r
.69429 .61291 m .69214 .61572 L .69427 .61501 L F
.69429 .61291 m .69214 .61572 L .69427 .61501 L F
.056 0 .15 r
.69427 .61501 m .69652 .61244 L .69429 .61291 L F
.648 .54 .718 r
.69652 .61244 m .69427 .61501 L .69429 .61291 L F
.57 .524 .765 r
.69751 .61767 m .69545 .61825 L .69427 .61501 L F
.31 0 0 r
.69751 .61767 m .69502 .61844 L .69545 .61825 L F
.635 .347 .464 r
.44601 .77295 m .44508 .77523 L .44282 .77506 L F
.481 .189 .392 r
.44736 .77481 m .44601 .77295 L .44814 .7726 L F
.44736 .77481 m .44508 .77523 L .44601 .77295 L F
.655 .398 .518 r
.4326 .74041 m .42939 .74302 L .43051 .74108 L F
.288 0 .161 r
.32437 .72759 m .32158 .72979 L .32214 .72843 L F
.564 .521 .765 r
.63894 .64162 m .63679 .64229 L .63581 .63944 L F
.441 0 .073 r
.38767 .7253 m .38941 .72598 L .39081 .72444 L F
.515 .093 .177 r
.38941 .72598 m .39294 .72437 L .39081 .72444 L F
.596 .867 .993 r
.50533 .88625 m .50667 .88683 L .50814 .88613 L F
.543 .221 .373 r
.64136 .65273 m .63944 .65472 L .6391 .65292 L F
.43 .756 .995 r
.48501 .83352 m .48462 .83465 L .48298 .83372 L F
.48298 .83372 m .48462 .83465 L .48501 .83352 L F
.829 .69 .71 r
.62363 .63398 m .62486 .63717 L .62341 .63598 L F
.807 .713 .761 r
.62486 .63717 m .62128 .63884 L .62341 .63598 L F
.62486 .63717 m .62287 .63989 L .62128 .63884 L F
.207 .489 .899 r
.52677 .87377 m .52628 .87431 L .52746 .87371 L F
.342 .82 .87 r
.52628 .87431 m .52814 .87383 L .52746 .87371 L F
.754 .927 .946 r
.34117 .81563 m .34084 .8154 L .3407 .81549 L F
0 0 .014 r
.70828 .60736 m .70701 .60802 L .70953 .60755 L F
.234 .697 .947 r
.71198 .60812 m .70828 .60736 L .70953 .60755 L F
.561 .39 .607 r
.71187 .60463 m .71164 .60796 L .70953 .60755 L F
.293 0 0 r
.71164 .60796 m .71198 .60812 L .70953 .60755 L F
.648 .392 .519 r
.35675 .73765 m .35728 .73557 L .35586 .735 L F
.35675 .73765 m .35921 .7377 L .35728 .73557 L F
.692 .389 .458 r
.35728 .73557 m .35921 .7377 L .35957 .73594 L F
.755 .64 .734 r
.40633 .74639 m .40794 .74885 L .40645 .74886 L F
.733 .462 .518 r
.40645 .74886 m .40794 .74885 L .40699 .75143 L F
.667 .633 .806 r
.40848 .74591 m .40794 .74885 L .40633 .74639 L F
.40848 .74591 m .41021 .74917 L .40794 .74885 L F
.597 .122 .098 r
.40794 .74885 m .40833 .75031 L .40699 .75143 L F
.40794 .74885 m .41021 .74917 L .40833 .75031 L F
.853 .784 .784 r
.68287 .61236 m .68565 .61255 L .68427 .61012 L F
.821 .897 .895 r
.68088 .61462 m .68565 .61255 L .68287 .61236 L F
.448 .753 .994 r
.68565 .61255 m .68658 .61113 L .68427 .61012 L F
.68565 .61255 m .68806 .61271 L .68658 .61113 L F
.645 .572 .758 r
.68565 .61255 m .68927 .61347 L .68806 .61271 L F
0 0 0 r
.3224 .67458 m .32145 .67459 L .32337 .67434 L F
.602 .922 .971 r
.38904 .78 m .38617 .78078 L .38838 .77995 L F
0 .387 .803 r
.39023 .78034 m .38904 .78 L .38838 .77995 L F
.39023 .78034 m .38998 .78048 L .38904 .78 L F
.578 .902 .982 r
.38838 .77995 m .38617 .78078 L .38711 .77957 L F
0 .484 .753 r
.38711 .77957 m .39023 .78034 L .38838 .77995 L F
.671 .165 .033 r
.38711 .77957 m .38867 .78092 L .39023 .78034 L F
0 .312 .788 r
.39064 .7801 m .39023 .78034 L .38867 .78092 L F
.39076 .78005 m .39023 .78034 L .39064 .7801 L F
0 .387 .803 r
.39023 .78034 m .39121 .78109 L .38998 .78048 L F
.376 0 0 r
.41253 .78596 m .41315 .78729 L .41105 .78769 L F
.41253 .78596 m .41458 .78589 L .41315 .78729 L F
.641 .603 .795 r
.68109 .70641 m .68467 .70892 L .68162 .7089 L F
.588 .504 .726 r
.35509 .66579 m .35571 .66918 L .35351 .66836 L F
.614 .536 .743 r
.35658 .67081 m .35351 .66836 L .35571 .66918 L F
.837 .957 .89 r
.69597 .63864 m .69476 .63945 L .69647 .63791 L F
.686 .444 .55 r
.69597 .63864 m .69455 .64055 L .69476 .63945 L F
.69597 .63864 m .69708 .64167 L .69455 .64055 L F
.538 .499 .76 r
.69647 .63791 m .69917 .63876 L .69597 .63864 L F
.504 .32 .565 r
.69917 .63876 m .69708 .64167 L .69597 .63864 L F
.554 .43 .665 r
.4916 .86873 m .49271 .86864 L .49107 .86637 L F
.49107 .86637 m .49271 .86864 L .4916 .86873 L F
.4916 .86873 m .49271 .86864 L .49107 .86637 L F
.575 .357 .547 r
.45112 .75892 m .45332 .7588 L .4534 .75684 L F
.565 .43 .656 r
.4534 .75684 m .45557 .75669 L .45532 .75433 L F
.656 .497 .657 r
.45332 .7588 m .45557 .75669 L .4534 .75684 L F
.681 .503 .638 r
.69101 .61251 m .69076 .61647 L .69214 .61572 L F
.632 .229 .261 r
.69135 .61654 m .69427 .61501 L .69214 .61572 L F
.687 .834 .953 r
.66345 .60256 m .6623 .60242 L .66462 .60186 L F
.76 .565 .633 r
.66345 .60256 m .66143 .60446 L .6623 .60242 L F
.66345 .60256 m .66465 .60499 L .66143 .60446 L F
.082 0 0 r
.66462 .60186 m .66569 .6017 L .66345 .60256 L F
.621 .508 .703 r
.66692 .60436 m .66345 .60256 L .66569 .6017 L F
.66692 .60436 m .66465 .60499 L .66345 .60256 L F
.478 .244 .48 r
.35485 .69399 m .3532 .69276 L .35519 .69229 L F
.35485 .69399 m .35282 .69467 L .3532 .69276 L F
.68 .547 .696 r
.35403 .78565 m .35135 .78624 L .35352 .78349 L F
.593 .562 .788 r
.35459 .7889 m .35135 .78624 L .35403 .78565 L F
.282 0 .205 r
.33462 .71843 m .33511 .71626 L .33538 .71666 L F
.33462 .71843 m .33285 .71909 L .33511 .71626 L F
.769 .858 .916 r
.70406 .60712 m .70107 .60722 L .70324 .60587 L F
.817 .872 .887 r
.70647 .60478 m .70406 .60712 L .70324 .60587 L F
.461 .076 .223 r
.64686 .65076 m .64618 .65174 L .64365 .65285 L F
.336 0 0 r
.64686 .65076 m .64825 .65175 L .64618 .65174 L F
.64686 .65076 m .64918 .65053 L .64825 .65175 L F
.761 .685 .778 r
.69874 .60975 m .69976 .61289 L .69652 .61244 L F
.677 .556 .71 r
.69974 .6149 m .69652 .61244 L .69976 .61289 L F
.23 .076 .455 r
.70164 .61314 m .69974 .6149 L .69976 .61289 L F
.719 .575 .693 r
.70033 .61302 m .69976 .61472 L .70083 .6135 L F
.69818 .61089 m .699 .61289 L .70033 .61302 L F
.699 .61289 m .69976 .61472 L .70033 .61302 L F
.23 .076 .455 r
.70173 .61314 m .69976 .61289 L .70262 .61317 L F
.70164 .61314 m .7015 .61312 L .70173 .61314 L F
.7015 .61312 m .69976 .61289 L .70173 .61314 L F
.1 0 0 r
.37824 .80109 m .38206 .7994 L .37999 .80053 L F
.106 0 0 r
.38405 .79907 m .37999 .80053 L .38206 .7994 L F
.989 .781 .392 r
.64276 .63393 m .6433 .63647 L .64349 .63426 L F
.185 .233 .679 r
.69016 .61796 m .69135 .61654 L .68909 .61695 L F
.69016 .61796 m .69281 .61897 L .69135 .61654 L F
.295 .087 .418 r
.64188 .62377 m .64299 .62467 L .64335 .62302 L F
.583 .378 .568 r
.36291 .76697 m .36095 .76489 L .3629 .76486 L F
.36291 .76697 m .36081 .76732 L .36095 .76489 L F
.472 .345 .626 r
.47401 .86591 m .4755 .86324 L .47421 .86366 L F
.461 0 .071 r
.40654 .77706 m .40871 .77709 L .4102 .77561 L F
.031 0 0 r
.4102 .77561 m .41082 .77616 L .41228 .77528 L F
.4102 .77561 m .40871 .77709 L .41082 .77616 L F
.554 .896 .981 r
.65202 .63009 m .65333 .63051 L .65092 .63134 L F
.65202 .63009 m .65333 .63051 L .65092 .63134 L F
.816 .791 .829 r
.58261 .83115 m .58378 .83348 L .58538 .83128 L F
.542 .683 .931 r
.58378 .83348 m .58588 .83359 L .58538 .83128 L F
.525 .173 .313 r
.45434 .76987 m .45256 .77214 L .45041 .77222 L F
.59 .259 .377 r
.45597 .76987 m .45256 .77214 L .45434 .76987 L F
.68 .765 .915 r
.71072 .62771 m .71184 .63111 L .7089 .63079 L F
.67 .446 .572 r
.71217 .63301 m .7089 .63079 L .71184 .63111 L F
.788 .824 .88 r
.71431 .6289 m .71184 .63111 L .71072 .62771 L F
.567 .267 .42 r
.7141 .63271 m .71217 .63301 L .71184 .63111 L F
.28 .559 .93 r
.69728 .71783 m .69817 .71927 L .69993 .71947 L F
.567 .441 .669 r
.35217 .78056 m .34981 .78049 L .35269 .77883 L F
.35217 .78056 m .3501 .78096 L .34981 .78049 L F
.746 .493 .549 r
.52606 .86806 m .52839 .8673 L .52726 .86628 L F
.798 .678 .732 r
.71127 .71798 m .70891 .72161 L .71237 .72202 L F
.795 .693 .753 r
.70891 .72161 m .71008 .72479 L .71237 .72202 L F
.728 .797 .906 r
.7264 .72221 m .72326 .72182 L .7251 .7197 L F
.768 .543 .593 r
.7264 .72221 m .72331 .72439 L .72326 .72182 L F
.7264 .72221 m .72635 .72495 L .72331 .72439 L F
.611 .738 .936 r
.72908 .72128 m .7264 .72221 L .7251 .7197 L F
.597 .528 .748 r
.5337 .85821 m .53501 .85502 L .53432 .85604 L F
.553 .447 .687 r
.46462 .73543 m .46319 .73845 L .46225 .73489 L F
.46462 .73543 m .46521 .73815 L .46319 .73845 L F
.531 .532 .802 r
.46621 .74073 m .46319 .73845 L .46521 .73815 L F
0 0 .347 r
.67578 .70758 m .67557 .7099 L .67677 .70805 L F
.666 .377 .473 r
.49471 .88218 m .49701 .88473 L .4939 .88447 L F
.69 .375 .437 r
.49716 .88284 m .49701 .88473 L .49471 .88218 L F
.767 .481 .501 r
.43472 .74022 m .43508 .74229 L .4326 .74041 L F
.541 .749 .972 r
.41943 .74206 m .42148 .74178 L .42037 .74056 L F
.877 .637 .572 r
.66591 .61015 m .66418 .60973 L .664 .60688 L F
.868 .689 .657 r
.66555 .61217 m .66418 .60973 L .66591 .61015 L F
.816 .936 .908 r
.51926 .86164 m .52199 .86094 L .51734 .86331 L F
.569 .227 .349 r
.52199 .86094 m .51951 .86356 L .51734 .86331 L F
.486 0 0 r
.52091 .86217 m .52199 .86094 L .51926 .86164 L F
0 0 0 r
.52091 .86217 m .51951 .86356 L .52199 .86094 L F
.346 0 .132 r
.37249 .7304 m .37325 .73174 L .37458 .73009 L F
.37249 .7304 m .37131 .73223 L .37325 .73174 L F
.577 .393 .596 r
.33847 .75181 m .34045 .75153 L .3407 .74906 L F
.533 .355 .586 r
.3407 .74906 m .34267 .75104 L .34281 .74858 L F
.3407 .74906 m .34045 .75153 L .34267 .75104 L F
.744 .722 .831 r
.69003 .60977 m .69499 .6119 L .69225 .60889 L F
.69003 .60977 m .69101 .61251 L .69499 .6119 L F
.673 .725 .888 r
.69225 .60889 m .69499 .6119 L .69551 .61007 L F
.518 .722 .966 r
.45404 .72962 m .45321 .73113 L .45202 .72975 L F
.45404 .72962 m .45522 .73091 L .45321 .73113 L F
.919 .768 .678 r
.4782 .87388 m .47913 .87727 L .47959 .87462 L F
.613 .309 .43 r
.62827 .65601 m .6304 .65768 L .62836 .65743 L F
.62827 .65601 m .63166 .65528 L .6304 .65768 L F
.72 .423 .473 r
.50121 .87696 m .50423 .87705 L .50473 .87925 L F
.754 .694 .794 r
.72084 .72217 m .71761 .72229 L .71979 .71962 L F
.075 0 .446 r
.72084 .72217 m .72086 .72265 L .71761 .72229 L F
.72084 .72217 m .721 .72468 L .72086 .72265 L F
.573 .608 .85 r
.72203 .71961 m .72084 .72217 L .71979 .71962 L F
.72203 .71961 m .72326 .72182 L .72084 .72217 L F
.648 .409 .543 r
.72331 .72439 m .72084 .72217 L .72326 .72182 L F
.72331 .72439 m .721 .72468 L .72084 .72217 L F
.418 .139 .38 r
.35957 .73594 m .36115 .73715 L .3623 .73524 L F
.35957 .73594 m .35921 .7377 L .36115 .73715 L F
.612 .464 .656 r
.33853 .754 m .34045 .75153 L .33847 .75181 L F
.653 .375 .486 r
.63166 .65528 m .63366 .65729 L .6304 .65768 L F
.63166 .65528 m .63365 .65548 L .63366 .65729 L F
.678 .593 .754 r
.35352 .78349 m .3501 .78096 L .35217 .78056 L F
.534 .488 .751 r
.35424 .77979 m .35352 .78349 L .35217 .78056 L F
.35424 .77979 m .35542 .78318 L .35352 .78349 L F
.492 .405 .686 r
.35542 .78318 m .35403 .78565 L .35352 .78349 L F
0 .243 .752 r
.41069 .74758 m .41021 .74917 L .40848 .74591 L F
.769 .988 .756 r
.40833 .75031 m .41021 .74917 L .41069 .74758 L F
.124 .587 .92 r
.68373 .59236 m .68091 .59129 L .68302 .5912 L F
.321 .472 .855 r
.68501 .59121 m .68373 .59236 L .68302 .5912 L F
.68501 .59121 m .6863 .59362 L .68373 .59236 L F
.604 .602 .823 r
.44429 .74156 m .44787 .74394 L .4464 .74126 L F
.663 .64 .818 r
.4464 .74126 m .44787 .74394 L .4501 .74344 L F
.764 .678 .768 r
.57131 .82899 m .57476 .82927 L .57369 .82595 L F
.583 .419 .624 r
.57476 .82927 m .57737 .8263 L .57369 .82595 L F
.57476 .82927 m .57699 .82877 L .57737 .8263 L F
.946 .594 .207 r
.52858 .82581 m .53 .82869 L .52906 .82797 L F
.52858 .82581 m .53 .82869 L .52906 .82797 L F
.238 .696 .951 r
.53 .82869 m .53096 .82814 L .52906 .82797 L F
.53 .82869 m .5323 .82883 L .53096 .82814 L F
.438 .749 .994 r
.31725 .65219 m .31663 .65339 L .31514 .65257 L F
.31725 .65219 m .3187 .65322 L .31663 .65339 L F
.907 .732 .654 r
.6804 .70328 m .68109 .70641 L .67969 .7065 L F
.783 .362 .248 r
.68109 .70641 m .6807 .70807 L .67969 .7065 L F
.542 .505 .764 r
.68126 .70481 m .68109 .70641 L .6804 .70328 L F
.967 .646 .277 r
.68109 .70641 m .68162 .7089 L .6807 .70807 L F
.457 .136 .333 r
.46045 .76779 m .45803 .76966 L .45825 .76771 L F
.563 .314 .497 r
.44827 .76202 m .45054 .76173 L .45112 .75892 L F
.537 .291 .489 r
.45112 .75892 m .45272 .76128 L .45332 .7588 L F
.45112 .75892 m .45054 .76173 L .45272 .76128 L F
.685 .614 .771 r
.58695 .83657 m .58811 .83965 L .59001 .83853 L F
.142 0 0 r
.40339 .74295 m .40161 .74306 L .39981 .74301 L F
.1 0 0 r
.3922 .795 m .39079 .79645 L .38935 .79649 L F
.053 0 0 r
.39256 .79577 m .3922 .795 L .39414 .79453 L F
.39256 .79577 m .39079 .79645 L .3922 .795 L F
.213 .084 .479 r
.47933 .86051 m .48063 .85797 L .47736 .85788 L F
.47933 .86051 m .48054 .86028 L .48063 .85797 L F
.744 .531 .606 r
.47732 .86225 m .48054 .86028 L .47933 .86051 L F
.889 .757 .71 r
.62015 .64679 m .61896 .6439 L .62047 .64484 L F
.62015 .64679 m .61747 .64673 L .61896 .6439 L F
.89 .748 .699 r
.62015 .64679 m .61837 .64968 L .61747 .64673 L F
.888 .714 .66 r
.57507 .79352 m .57763 .79158 L .57469 .79106 L F
.57507 .79352 m .57762 .79453 L .57763 .79158 L F
.155 0 .186 r
.37036 .75924 m .3695 .76146 L .36779 .76216 L F
.454 .228 .481 r
.37266 .75676 m .37234 .75894 L .37036 .75924 L F
.559 .293 .468 r
.37234 .75894 m .3695 .76146 L .37036 .75924 L F
.78 .986 .899 r
.53916 .856 m .53684 .85713 L .53598 .85785 L F
.826 .966 .895 r
.53971 .85441 m .53684 .85713 L .53916 .856 L F
.771 .695 .779 r
.62889 .62261 m .62995 .62571 L .62673 .62535 L F
.779 .667 .741 r
.62995 .62571 m .62776 .62846 L .62673 .62535 L F
.773 .696 .778 r
.62889 .62261 m .63046 .62389 L .62995 .62571 L F
.848 .488 .371 r
.53146 .82294 m .53311 .82575 L .5338 .82384 L F
.803 .433 .356 r
.5338 .82384 m .53311 .82575 L .53494 .82558 L F
.864 .476 0 r
.71461 .72923 m .71464 .72929 L .71519 .7297 L F
.521 .359 .602 r
.71519 .7297 m .71467 .73087 L .71578 .73012 L F
.71519 .7297 m .71591 .73159 L .71372 .73198 L F
.864 .476 0 r
.71464 .72929 m .71591 .73159 L .71519 .7297 L F
.521 .359 .602 r
.71519 .7297 m .71578 .73012 L .71638 .72972 L F
.669 .487 .629 r
.70425 .6107 m .70492 .61323 L .70262 .61317 L F
.148 .157 .612 r
.70581 .61157 m .70425 .6107 L .70659 .60929 L F
.848 .66 .648 r
.70353 .61131 m .70558 .60996 L .70475 .60873 L F
.70558 .60996 m .70659 .60929 L .70546 .60895 L F
.70558 .60996 m .70546 .60895 L .70475 .60873 L F
.148 .157 .612 r
.70577 .61155 m .70492 .61323 L .70425 .6107 L F
.70581 .61157 m .70578 .61162 L .70577 .61155 L F
.70578 .61162 m .70492 .61323 L .70577 .61155 L F
0 .184 .679 r
.68346 .61784 m .68632 .62036 L .68441 .61879 L F
.577 .84 .995 r
.42897 .72502 m .42709 .7256 L .42574 .72483 L F
.442 .686 .968 r
.67864 .6278 m .67828 .62883 L .6797 .62752 L F
0 0 0 r
.6782 .62907 m .67828 .62883 L .67864 .6278 L F
.617 .32 .442 r
.46912 .76468 m .46566 .76708 L .46704 .76531 L F
.579 .635 .871 r
.44429 .74156 m .44574 .73983 L .44357 .74025 L F
.44429 .74156 m .4464 .74126 L .44574 .73983 L F
.82 .856 .875 r
.60184 .65392 m .60194 .65216 L .5993 .65222 L F
.649 .591 .776 r
.56671 .82094 m .56812 .82414 L .57034 .8235 L F
.495 .614 .899 r
.69032 .59732 m .68782 .59586 L .68997 .59568 L F
.459 .575 .884 r
.69189 .5957 m .69032 .59732 L .68997 .59568 L F
.391 .465 .817 r
.69189 .5957 m .69306 .59871 L .69032 .59732 L F
.646 .79 .951 r
.38072 .78304 m .37858 .78373 L .37735 .78264 L F
.818 .699 .733 r
.7055 .6284 m .70658 .63148 L .70364 .62984 L F
.781 .282 .011 r
.70658 .63148 m .70556 .63134 L .70364 .62984 L F
0 .058 .609 r
.72265 .70553 m .72289 .70618 L .72086 .70341 L F
.72265 .70553 m .72289 .70618 L .72086 .70341 L F
.353 0 .165 r
.72289 .70618 m .72003 .70837 L .72265 .70553 L F
.72289 .70618 m .72213 .70805 L .72003 .70837 L F
.676 .626 .791 r
.7089 .63079 m .70658 .63148 L .7055 .6284 L F
.736 .28 .17 r
.70658 .63148 m .70597 .63297 L .70556 .63134 L F
.70658 .63148 m .70893 .63344 L .70597 .63297 L F
.605 .394 .569 r
.7089 .63079 m .70893 .63344 L .70658 .63148 L F
.531 .849 .998 r
.72471 .70738 m .72289 .70618 L .72265 .70553 L F
.72471 .70738 m .72213 .70805 L .72289 .70618 L F
.485 .17 .357 r
.44563 .76386 m .44827 .76202 L .44608 .76222 L F
.534 .234 .405 r
.67628 .72229 m .67813 .72161 L .67866 .72105 L F
.486 .291 .54 r
.35216 .69617 m .35084 .69538 L .35282 .69467 L F
.35216 .69617 m .35036 .69772 L .35084 .69538 L F
.946 .655 .203 r
.48193 .86578 m .4826 .86644 L .48155 .86315 L F
.972 .805 .617 r
.48193 .86578 m .48241 .86828 L .4826 .86644 L F
.215 .728 .881 r
.34496 .66049 m .34844 .66056 L .34643 .66146 L F
.757 .482 .518 r
.57108 .79076 m .57437 .78882 L .57103 .78857 L F
.57108 .79076 m .57469 .79106 L .57437 .78882 L F
.891 .728 .673 r
.5774 .79656 m .57831 .799 L .57924 .79705 L F
.618 .692 .897 r
.71187 .60463 m .70867 .60297 L .71046 .60217 L F
.564 .651 .893 r
.71235 .60207 m .71187 .60463 L .71046 .60217 L F
.71235 .60207 m .71401 .60417 L .71187 .60463 L F
.631 .451 .62 r
.71478 .6072 m .71187 .60463 L .71401 .60417 L F
.71478 .6072 m .71164 .60796 L .71187 .60463 L F
.541 .216 .366 r
.43517 .76713 m .43759 .76693 L .43839 .76475 L F
.268 0 0 r
.43759 .76693 m .4402 .76626 L .43839 .76475 L F
.608 .241 .321 r
.43839 .76475 m .4402 .76626 L .44079 .76492 L F
.474 .757 .992 r
.43652 .72656 m .43572 .72776 L .43453 .72651 L F
.43652 .72656 m .43782 .72755 L .43572 .72776 L F
.494 .667 .94 r
.68848 .59394 m .68782 .59586 L .6863 .59362 L F
.68848 .59394 m .68997 .59568 L .68782 .59586 L F
0 0 0 r
.39703 .7931 m .39799 .79311 L .39632 .79403 L F
.39703 .7931 m .39979 .79217 L .39799 .79311 L F
.566 .269 .423 r
.55646 .79965 m .55406 .80177 L .55168 .80202 L F
.682 .46 .578 r
.55696 .79944 m .55406 .80177 L .55646 .79965 L F
.807 .886 .902 r
.49967 .88444 m .49835 .88553 L .49701 .88473 L F
.785 .88 .916 r
.37057 .78777 m .36752 .78838 L .36923 .78742 L F
.722 .938 .957 r
.37316 .78629 m .37057 .78777 L .36923 .78742 L F
.73 .788 .898 r
.36001 .78846 m .35663 .78841 L .35885 .78727 L F
.692 .745 .893 r
.36063 .78555 m .36001 .78846 L .35885 .78727 L F
.36063 .78555 m .36216 .7876 L .36001 .78846 L F
.877 .973 .844 r
.6617 .61532 m .66301 .61247 L .66388 .61411 L F
.6617 .61532 m .66098 .61508 L .66301 .61247 L F
.66098 .61508 m .66128 .6146 L .66301 .61247 L F
.687 .584 .734 r
.66301 .61247 m .66091 .61505 L .6615 .61418 L F
0 0 .057 r
.66158 .6141 m .66163 .61553 L .66305 .6127 L F
.6615 .61418 m .6615 .61423 L .66158 .6141 L F
.6615 .61423 m .66163 .61553 L .66158 .6141 L F
.877 .973 .844 r
.66098 .61508 m .66091 .61505 L .66128 .6146 L F
.967 .642 .306 r
.6617 .61532 m .66203 .61698 L .66091 .61505 L F
.851 .48 .348 r
.68237 .63325 m .68481 .63424 L .6849 .63573 L F
.656 .375 .481 r
.68481 .63424 m .68727 .6363 L .6849 .63573 L F
.636 .964 .835 r
.38617 .78078 m .38536 .78088 L .38711 .77957 L F
.718 .587 .709 r
.69101 .70141 m .69221 .70401 L .68909 .7036 L F
.687 .573 .722 r
.69447 .70347 m .69221 .70401 L .69101 .70141 L F
0 0 0 r
.71304 .62119 m .71242 .62233 L .71414 .61981 L F
.845 .867 .858 r
.66555 .61217 m .66388 .61411 L .66301 .61247 L F
.591 .65 .877 r
.46291 .73188 m .46225 .73489 L .46083 .73213 L F
.46291 .73188 m .46453 .73436 L .46225 .73489 L F
.589 .612 .842 r
.46453 .73436 m .46462 .73543 L .46225 .73489 L F
.423 .032 .191 r
.39959 .7456 m .3995 .74711 L .39754 .74678 L F
.373 .226 .549 r
.40161 .74306 m .39959 .7456 L .39981 .74301 L F
.40161 .74306 m .40174 .74546 L .39959 .7456 L F
.297 0 .175 r
.40174 .74546 m .3995 .74711 L .39959 .7456 L F
.469 .318 .593 r
.34023 .68475 m .34206 .68667 L .34206 .6843 L F
.34023 .68475 m .34029 .68726 L .34206 .68667 L F
.365 0 .105 r
.65173 .64916 m .65156 .64999 L .64918 .65053 L F
.299 0 .09 r
.65173 .64916 m .65381 .64936 L .65156 .64999 L F
.998 .799 .508 r
.6716 .61447 m .67244 .61548 L .67229 .61373 L F
0 .248 .706 r
.67358 .61598 m .67244 .61548 L .6716 .61447 L F
.67358 .61598 m .67503 .61712 L .67244 .61548 L F
.492 .405 .686 r
.35542 .78318 m .35566 .78534 L .35403 .78565 L F
.587 .493 .715 r
.35663 .78841 m .35403 .78565 L .35566 .78534 L F
.35663 .78841 m .35459 .7889 L .35403 .78565 L F
.617 .32 .442 r
.46912 .76468 m .46782 .76732 L .46566 .76708 L F
.623 .326 .445 r
.47141 .76643 m .46912 .76468 L .47117 .76489 L F
.47141 .76643 m .46782 .76732 L .46912 .76468 L F
.642 .617 .809 r
.4501 .74344 m .45364 .74602 L .45211 .74334 L F
.585 .641 .873 r
.45364 .74602 m .45429 .74296 L .45211 .74334 L F
.45364 .74602 m .4557 .74561 L .45429 .74296 L F
.577 .484 .712 r
.45415 .74925 m .4557 .74561 L .45364 .74602 L F
.301 0 0 r
.4202 .78368 m .41873 .78519 L .41665 .78552 L F
.248 0 0 r
.4208 .78472 m .4202 .78368 L .42212 .783 L F
.4208 .78472 m .41873 .78519 L .4202 .78368 L F
.41 .266 .572 r
.35428 .73573 m .35373 .73773 L .35586 .735 L F
.804 .69 .739 r
.63229 .62108 m .62894 .62057 L .63094 .61993 L F
.63229 .62108 m .62889 .62261 L .62894 .62057 L F
.63229 .62108 m .63046 .62389 L .62889 .62261 L F
.741 .653 .762 r
.63113 .61778 m .63229 .62108 L .63094 .61993 L F
.63113 .61778 m .63473 .61859 L .63229 .62108 L F
.401 .526 .868 r
.40487 .74789 m .40174 .74546 L .40548 .74675 L F
.98 .805 .596 r
.40633 .74639 m .40487 .74789 L .40548 .74675 L F
.331 .317 .692 r
.40589 .74448 m .40487 .74789 L .40635 .74664 L F
.40589 .74448 m .40541 .74767 L .40487 .74789 L F
.98 .805 .596 r
.40526 .74749 m .40645 .74886 L .40487 .74789 L F
.40633 .74639 m .40641 .74801 L .40526 .74749 L F
.40641 .74801 m .40645 .74886 L .40526 .74749 L F
.954 .861 .708 r
.40487 .74789 m .40645 .74886 L .40521 .75059 L F
.733 .462 .518 r
.40645 .74886 m .40699 .75143 L .40521 .75059 L F
.517 .38 .633 r
.40487 .74789 m .407 .74948 L .40635 .74664 L F
.401 .526 .868 r
.40487 .74789 m .40541 .74767 L .40174 .74546 L F
.463 0 0 r
.40174 .74546 m .40461 .74719 L .40285 .74635 L F
.40461 .74719 m .40541 .74767 L .40352 .7467 L F
.40461 .74719 m .40352 .7467 L .40285 .74635 L F
.51 .182 .347 r
.36115 .73715 m .36433 .73465 L .3623 .73524 L F
.612 .913 .645 r
.50561 .88223 m .50188 .88554 L .50483 .88187 L F
.50561 .88223 m .50205 .88551 L .50188 .88554 L F
.866 .982 .845 r
.50766 .87968 m .50561 .88223 L .50483 .88187 L F
.703 .583 .718 r
.70661 .72465 m .70801 .72536 L .71008 .72479 L F
.736 .395 .404 r
.48212 .76233 m .48433 .76468 L .48253 .76392 L F
.64 .41 .554 r
.48459 .762 m .48433 .76468 L .48212 .76233 L F
.786 .636 .696 r
.53436 .86192 m .53486 .86366 L .53347 .86377 L F
.658 .884 .981 r
.53347 .86377 m .53486 .86366 L .53369 .86299 L F
.715 .596 .722 r
.53436 .86192 m .5372 .86093 L .53486 .86366 L F
.729 .649 .769 r
.53598 .85785 m .5372 .86093 L .53436 .86192 L F
.876 .985 .828 r
.53486 .86366 m .5363 .86071 L .53369 .86299 L F
.53486 .86366 m .5372 .86093 L .5363 .86071 L F
.542 .305 .505 r
.37449 .75852 m .37266 .75676 L .37489 .75674 L F
.37449 .75852 m .37234 .75894 L .37266 .75676 L F
.733 .702 .821 r
.70569 .72128 m .70661 .72465 L .70891 .72161 L F
.703 .583 .718 r
.70661 .72465 m .71008 .72479 L .70891 .72161 L F
.632 .229 .261 r
.69135 .61654 m .69366 .6169 L .69427 .61501 L F
.648 .54 .718 r
.69652 .61244 m .69755 .61547 L .69427 .61501 L F
.056 0 .15 r
.69427 .61501 m .69578 .61441 L .69652 .61244 L F
.57 .524 .765 r
.69751 .61767 m .69427 .61501 L .69755 .61547 L F
.603 .39 .566 r
.69366 .6169 m .69578 .61441 L .69427 .61501 L F
.517 .463 .735 r
.47869 .75073 m .47779 .75505 L .47643 .7512 L F
.47869 .75073 m .47984 .75472 L .47779 .75505 L F
.439 .458 .783 r
.39642 .74294 m .39754 .74678 L .396 .74523 L F
.673 .299 .329 r
.39754 .74678 m .39642 .7469 L .396 .74523 L F
.673 .562 .722 r
.53207 .86131 m .53347 .86377 L .52981 .86321 L F
.657 .289 .335 r
.53347 .86377 m .53202 .86402 L .52981 .86321 L F
.615 .465 .655 r
.52981 .86321 m .53202 .86402 L .53207 .86131 L F
.331 0 0 r
.39513 .7244 m .39723 .72415 L .39854 .7229 L F
.356 0 0 r
.39723 .72415 m .40055 .72269 L .39854 .7229 L F
.611 .11 .036 r
.49627 .87587 m .4982 .87696 L .49477 .87537 L F
.583 .789 .977 r
.50138 .88823 m .50218 .88672 L .50058 .88797 L F
.50138 .88823 m .5035 .88775 L .50218 .88672 L F
.64 .532 .715 r
.58475 .83714 m .58695 .83657 L .58588 .83359 L F
.744 .596 .693 r
.5337 .85821 m .53436 .86192 L .53207 .86131 L F
.729 .649 .769 r
.53598 .85785 m .53436 .86192 L .5337 .85821 L F
.236 .023 .372 r
.53427 .85903 m .5337 .85821 L .53207 .86131 L F
.597 .528 .748 r
.5337 .85821 m .53598 .85785 L .53501 .85502 L F
.391 0 .117 r
.53466 .85973 m .5337 .85821 L .53427 .85903 L F
.53466 .85973 m .53598 .85785 L .5337 .85821 L F
0 .106 .599 r
.60759 .65413 m .60893 .65548 L .60755 .65418 L F
.704 .454 .543 r
.60893 .65548 m .60634 .6575 L .60755 .65418 L F
.60893 .65548 m .60862 .65746 L .60634 .6575 L F
.901 .89 .81 r
.61097 .65227 m .60893 .65548 L .60759 .65413 L F
.633 .491 .672 r
.61153 .65419 m .60893 .65548 L .61097 .65227 L F
.67 .483 .624 r
.61153 .65419 m .60862 .65746 L .60893 .65548 L F
.534 .22 .382 r
.42286 .77187 m .42502 .77182 L .42549 .77033 L F
.445 .136 .347 r
.42502 .77182 m .42712 .77141 L .42549 .77033 L F
.482 .109 .255 r
.42549 .77033 m .42712 .77141 L .42773 .77018 L F
.764 .661 .749 r
.69101 .70141 m .68787 .70054 L .69013 .70022 L F
.69101 .70141 m .68909 .7036 L .68787 .70054 L F
.539 .748 .973 r
.69249 .6998 m .69101 .70141 L .69013 .70022 L F
.69249 .6998 m .69373 .70093 L .69101 .70141 L F
.687 .573 .722 r
.69447 .70347 m .69101 .70141 L .69373 .70093 L F
.364 .327 .684 r
.4772 .85506 m .47817 .85181 L .47623 .85373 L F
.431 .515 .844 r
.3582 .89514 m .35906 .89536 L .35841 .89556 L F
.24 0 .293 r
.35841 .89556 m .35906 .89536 L .35815 .89638 L F
0 0 0 r
.647 .61467 m .64347 .6168 L .64317 .61646 L F
.647 .61467 m .64647 .61521 L .64347 .6168 L F
.64977 .61294 m .64865 .61433 L .647 .61467 L F
.647 .61467 m .64865 .61433 L .64647 .61521 L F
.436 .351 .661 r
.48153 .85523 m .48063 .85797 L .48086 .85559 L F
.924 .72 .608 r
.68732 .72197 m .6871 .72414 L .68844 .72444 L F
.924 .724 .615 r
.6871 .72414 m .68825 .72724 L .68844 .72444 L F
.389 .794 .983 r
.73019 .72523 m .72933 .72458 L .72635 .72495 L F
.968 .925 .693 r
.73086 .72137 m .73019 .72523 L .72908 .72128 L F
.73086 .72137 m .72933 .72458 L .73019 .72523 L F
.732 .544 .638 r
.71008 .72479 m .7103 .72764 L .71346 .72744 L F
.865 .578 .501 r
.57507 .79594 m .57762 .79453 L .57507 .79352 L F
.57507 .79594 m .5774 .79656 L .57762 .79453 L F
.089 0 0 r
.38935 .79649 m .39079 .79645 L .38806 .7978 L F
.79 .963 .919 r
.61239 .65143 m .61346 .65076 L .61609 .64997 L F
.301 .781 .919 r
.61575 .64967 m .61837 .64968 L .61609 .64997 L F
.589 .946 .898 r
.61346 .65076 m .61575 .64967 L .61609 .64997 L F
.301 .781 .919 r
.61575 .64967 m .61837 .64968 L .61609 .64997 L F
.537 .489 .75 r
.47547 .74815 m .4735 .74867 L .47299 .74641 L F
.625 .5 .689 r
.47643 .7512 m .4735 .74867 L .47547 .74815 L F
.47643 .7512 m .47429 .75223 L .4735 .74867 L F
.921 .698 .583 r
.69455 .64055 m .69372 .63847 L .69476 .63945 L F
.793 .772 .834 r
.69647 .63791 m .69476 .63945 L .69372 .63847 L F
.562 .356 .56 r
.36779 .76216 m .36783 .76445 L .36584 .76459 L F
.378 .215 .53 r
.36962 .76381 m .36779 .76216 L .3695 .76146 L F
.36962 .76381 m .36783 .76445 L .36779 .76216 L F
.692 .639 .791 r
.7176 .70847 m .7157 .70948 L .71424 .70626 L F
.62 .528 .728 r
.45415 .74925 m .4547 .75139 L .45701 .7511 L F
.59 .468 .682 r
.45532 .75433 m .45701 .7511 L .4547 .75139 L F
.549 .206 .339 r
.3825 .75147 m .38144 .75376 L .37916 .75367 L F
.412 .046 .23 r
.38457 .75133 m .38144 .75376 L .3825 .75147 L F
.406 .196 .478 r
.48998 .86576 m .48788 .86854 L .48805 .86635 L F
.713 .661 .797 r
.4764 .87632 m .47913 .87727 L .4782 .87388 L F
.137 .601 .924 r
.4781 .8765 m .47833 .87699 L .4764 .87632 L F
.4781 .8765 m .4764 .87632 L .47697 .87992 L F
.294 .165 .529 r
.47776 .87758 m .4779 .87607 L .4781 .8765 L F
.4779 .87607 m .47791 .87593 L .4781 .8765 L F
.137 .601 .924 r
.4781 .8765 m .47913 .87727 L .47833 .87699 L F
0 .253 .684 r
.48175 .8788 m .47913 .87727 L .4781 .8765 L F
.765 .601 .675 r
.70855 .6154 m .70492 .61323 L .70732 .61333 L F
.70855 .6154 m .70545 .61537 L .70492 .61323 L F
.056 0 0 r
.70855 .6154 m .70768 .61543 L .70545 .61537 L F
.383 .554 .899 r
.70984 .6141 m .70855 .6154 L .70732 .61333 L F
.612 .956 .882 r
.70984 .6141 m .70768 .61543 L .70855 .6154 L F
.263 .568 .937 r
.32985 .65397 m .33149 .65426 L .33094 .65529 L F
.377 .707 .986 r
.33149 .65426 m .33287 .6553 L .33094 .65529 L F
.729 .432 .477 r
.72086 .72265 m .71849 .72491 L .71761 .72229 L F
.967 .926 .696 r
.71886 .72726 m .72086 .72265 L .721 .72468 L F
.777 .505 .525 r
.721 .72468 m .71849 .72491 L .72086 .72265 L F
.729 .432 .477 r
.72086 .72265 m .71849 .72491 L .71761 .72229 L F
.106 0 0 r
.65374 .5941 m .65114 .5963 L .65149 .59505 L F
.498 .779 .995 r
.32253 .65217 m .32206 .65354 L .32073 .6528 L F
.32253 .65217 m .32419 .65323 L .32206 .65354 L F
.978 .722 .313 r
.67319 .60759 m .67262 .60877 L .67198 .60719 L F
.98 .687 .354 r
.5363 .86071 m .5372 .86093 L .53598 .85785 L F
.898 .796 .739 r
.66465 .60499 m .66189 .60635 L .66143 .60446 L F
.66465 .60499 m .664 .60688 L .66189 .60635 L F
.703 .632 .774 r
.68787 .70054 m .68909 .7036 L .68572 .70314 L F
.975 .696 .435 r
.64064 .60581 m .64269 .60726 L .64186 .60456 L F
.542 .813 .996 r
.64256 .60714 m .64286 .60739 L .64064 .60581 L F
.511 .801 .998 r
.64064 .60581 m .64103 .60571 L .64256 .60714 L F
.991 .823 .577 r
.64256 .60714 m .64103 .60571 L .64082 .60742 L F
.64227 .6073 m .64082 .60742 L .64073 .60817 L F
.64256 .60714 m .64082 .60742 L .64227 .6073 L F
.975 .696 .435 r
.64269 .60726 m .64286 .60739 L .64282 .60725 L F
.64269 .60726 m .64282 .60725 L .64186 .60456 L F
.049 0 .272 r
.64286 .60739 m .64517 .60347 L .64186 .60456 L F
.64286 .60739 m .64448 .60637 L .64517 .60347 L F
.018 0 .214 r
.64443 .60696 m .64448 .60637 L .64286 .60739 L F
.64443 .60696 m .64286 .60739 L .64256 .60714 L F
.187 0 .051 r
.65458 .64778 m .6557 .64864 L .65381 .64936 L F
.65458 .64778 m .65655 .64691 L .6557 .64864 L F
.722 .492 .577 r
.69874 .60975 m .69557 .60732 L .69806 .60668 L F
.69874 .60975 m .69551 .61007 L .69557 .60732 L F
.867 .724 .703 r
.63701 .60937 m .63627 .60626 L .63757 .60793 L F
.683 .308 .33 r
.5031 .87424 m .50534 .8761 L .50659 .87414 L F
.686 .357 .412 r
.50534 .8761 m .50894 .8744 L .50659 .87414 L F
.577 .484 .712 r
.45415 .74925 m .45633 .74913 L .4557 .74561 L F
.62 .528 .728 r
.45415 .74925 m .45701 .7511 L .45633 .74913 L F
.752 .622 .716 r
.63512 .61227 m .63668 .61576 L .63316 .61512 L F
.749 .63 .728 r
.63316 .61512 m .63668 .61576 L .63473 .61859 L F
0 .339 .797 r
.41743 .72293 m .41892 .72369 L .41839 .72391 L F
0 .41 .825 r
.41892 .72369 m .42029 .72475 L .41839 .72391 L F
.786 .636 .696 r
.53436 .86192 m .53347 .86377 L .53207 .86131 L F
.743 .649 .756 r
.62673 .62535 m .62776 .62846 L .62439 .62815 L F
.749 .613 .708 r
.62439 .62815 m .62776 .62846 L .62572 .63128 L F
.641 .481 .651 r
.35165 .74012 m .35389 .74009 L .35373 .73773 L F
.629 .562 .76 r
.35586 .735 m .35373 .73773 L .35415 .7374 L F
.393 .06 .277 r
.35389 .74009 m .35675 .73765 L .35373 .73773 L F
.843 .61 .587 r
.664 .60688 m .66155 .60896 L .66189 .60635 L F
.664 .60688 m .66418 .60973 L .66155 .60896 L F
.574 .223 .336 r
.41275 .74145 m .4098 .74274 L .41075 .74111 L F
.574 .616 .857 r
.67628 .71089 m .67677 .70805 L .67557 .7099 L F
.199 0 0 r
.40055 .72269 m .40256 .72304 L .4041 .72301 L F
.502 0 0 r
.40256 .72304 m .4062 .72264 L .4041 .72301 L F
.454 .019 .121 r
.3786 .72923 m .38216 .72754 L .37998 .72746 L F
.48 .137 .306 r
.67876 .70892 m .67902 .71063 L .67628 .71089 L F
.417 .549 .881 r
.67852 .70657 m .6807 .70807 L .67876 .70892 L F
.164 0 .31 r
.6807 .70807 m .67902 .71063 L .67876 .70892 L F
.967 .71 .278 r
.57469 .80673 m .57559 .80999 L .57638 .80785 L F
0 0 0 r
.43894 .74022 m .43831 .74014 L .44051 .73942 L F
.43894 .74022 m .4362 .74148 L .43831 .74014 L F
.117 .116 .58 r
.6721 .61302 m .6712 .61247 L .67367 .61138 L F
.887 .479 .052 r
.67337 .60991 m .67505 .61245 L .67393 .61129 L F
.117 .116 .58 r
.67373 .61164 m .67367 .61138 L .67441 .61106 L F
.6721 .61302 m .67367 .61138 L .67373 .61164 L F
.887 .479 .052 r
.67329 .60971 m .67335 .6098 L .67337 .60991 L F
.67335 .6098 m .67505 .61245 L .67337 .60991 L F
.712 .187 0 r
.67505 .61245 m .67546 .61345 L .67393 .61129 L F
.67505 .61245 m .67698 .6146 L .67546 .61345 L F
.729 .356 .344 r
.67965 .61477 m .67698 .6146 L .67505 .61245 L F
.5 .7 .959 r
.36623 .78709 m .36556 .78855 L .3645 .78721 L F
.36623 .78709 m .36752 .78838 L .36556 .78855 L F
0 0 .014 r
.70828 .60736 m .70659 .60929 L .70701 .60802 L F
.823 .89 .891 r
.51651 .81933 m .51343 .82035 L .51532 .81996 L F
.67 .356 .433 r
.51532 .81996 m .518 .82123 L .51651 .81933 L F
.828 .478 .393 r
.7016 .70149 m .70319 .70453 L .70426 .70282 L F
.416 0 0 r
.70131 .70147 m .7016 .70149 L .70208 .70111 L F
.645 .086 0 r
.7016 .70149 m .70426 .70282 L .70208 .70111 L F
.416 0 0 r
.7016 .70149 m .70183 .70151 L .70208 .70111 L F
.645 .086 0 r
.70146 .70142 m .7016 .70149 L .70208 .70111 L F
.828 .478 .393 r
.70146 .70142 m .70149 .70148 L .7016 .70149 L F
.70149 .70148 m .70319 .70453 L .7016 .70149 L F
.416 0 0 r
.69871 .70061 m .70131 .70147 L .70208 .70111 L F
.70131 .70147 m .70176 .70162 L .70183 .70151 L F
.645 .086 0 r
.70146 .70142 m .70208 .70111 L .70176 .70162 L F
.281 .323 .728 r
.48715 .75588 m .4865 .75678 L .48519 .75617 L F
.48715 .75588 m .48655 .75888 L .4865 .75678 L F
.701 .567 .7 r
.49961 .87946 m .49967 .8844 L .49716 .88284 L F
.717 .456 .529 r
.49896 .87706 m .5013 .87911 L .49961 .87946 L F
.341 .276 .638 r
.50143 .8814 m .49961 .87946 L .5013 .87911 L F
.5004 .8803 m .49963 .88132 L .49961 .87946 L F
.868 .541 .431 r
.49981 .88098 m .5013 .87911 L .49956 .87895 L F
.76 .596 .674 r
.49981 .88098 m .50193 .87824 L .50157 .87873 L F
.72 .423 .473 r
.50121 .87696 m .50473 .87925 L .5013 .87911 L F
.717 .456 .529 r
.49896 .87706 m .50121 .87696 L .5013 .87911 L F
.256 .481 .884 r
.4994 .87652 m .5013 .87911 L .50193 .87824 L F
.76 .596 .674 r
.5011 .87936 m .50157 .87873 L .5013 .87911 L F
.49981 .88098 m .50157 .87873 L .5011 .87936 L F
.341 .276 .638 r
.50143 .8814 m .49967 .8844 L .49963 .88132 L F
.50143 .8814 m .49963 .88132 L .5004 .8803 L F
.543 .366 .591 r
.32976 .76478 m .33178 .76467 L .33181 .76213 L F
.596 .427 .623 r
.32964 .76712 m .33178 .76467 L .32976 .76478 L F
.869 .607 .54 r
.5424 .8339 m .54245 .83618 L .54488 .83664 L F
.969 .922 .695 r
.54311 .83816 m .54488 .83664 L .54245 .83618 L F
.54311 .83816 m .54348 .83944 L .54488 .83664 L F
.119 .177 .649 r
.55403 .79351 m .55532 .79434 L .55552 .79308 L F
.55403 .79351 m .55552 .79308 L .55561 .79251 L F
0 0 0 r
.55403 .79351 m .55536 .79313 L .55539 .79312 L F
.55403 .79351 m .55539 .79312 L .55801 .79167 L F
.472 .865 .676 r
.55801 .79167 m .55894 .79088 L .56011 .79125 L F
.55801 .79167 m .55536 .79313 L .55894 .79088 L F
.251 .46 .868 r
.5634 .81842 m .56567 .81976 L .56507 .81768 L F
.814 .747 .79 r
.69659 .70085 m .69447 .70347 L .69373 .70093 L F
.566 .13 .171 r
.41623 .74074 m .41486 .74232 L .41275 .74145 L F
.236 0 0 r
.41834 .74127 m .41486 .74232 L .41623 .74074 L F
.759 .634 .723 r
.57369 .82595 m .57737 .8263 L .5759 .82337 L F
.706 .532 .651 r
.57737 .8263 m .57699 .82877 L .57878 .82786 L F
.699 .512 .632 r
.48984 .75934 m .48765 .76167 L .48655 .75888 L F
.612 .094 0 r
.48655 .75888 m .4889 .7601 L .48984 .75934 L F
.699 .512 .632 r
.48984 .75934 m .4897 .76198 L .48765 .76167 L F
.384 .194 .495 r
.49182 .75902 m .4897 .76198 L .48984 .75934 L F
.989 .774 .524 r
.49057 .7606 m .48984 .75934 L .4889 .7601 L F
.49057 .7606 m .49182 .75902 L .48984 .75934 L F
.814 .747 .79 r
.69659 .70085 m .69373 .70093 L .69568 .69961 L F
.521 .758 .982 r
.69811 .69949 m .69659 .70085 L .69568 .69961 L F
.69811 .69949 m .69871 .70061 L .69659 .70085 L F
.686 .445 .552 r
.36584 .76459 m .36291 .76697 L .3629 .76486 L F
.757 .625 .713 r
.34237 .8128 m .34062 .81539 L .33935 .81391 L F
.34237 .8128 m .34033 .81373 L .34278 .81266 L F
.34237 .8128 m .33935 .81391 L .34033 .81373 L F
.34237 .8128 m .34084 .8154 L .34062 .81539 L F
.31 .058 .36 r
.33285 .71909 m .33069 .72172 L .33129 .71971 L F
.682 .46 .578 r
.55696 .79944 m .55721 .80217 L .55406 .80177 L F
.404 .774 .994 r
.43987 .72728 m .44293 .72778 L .44119 .72799 L F
.901 .89 .81 r
.61097 .65227 m .60759 .65413 L .60994 .65406 L F
0 0 0 r
.61097 .65227 m .61195 .65127 L .61239 .65143 L F
.61097 .65227 m .60994 .65406 L .61195 .65127 L F
.559 .406 .629 r
.36064 .76953 m .35853 .76796 L .36081 .76732 L F
.36064 .76953 m .35836 .76994 L .35853 .76796 L F
.576 .26 .396 r
.30563 .65526 m .30623 .6552 L .30575 .65496 L F
.401 0 .091 r
.64876 .63849 m .65196 .63665 L .64848 .6367 L F
.64876 .63849 m .65105 .6382 L .65196 .63665 L F
0 0 0 r
.65105 .6382 m .65349 .63541 L .65196 .63665 L F
.751 .631 .727 r
.63316 .61512 m .63473 .61859 L .63113 .61778 L F
.796 .472 .44 r
.49967 .88444 m .49716 .88284 L .49967 .8844 L F
.49967 .88444 m .49701 .88473 L .49716 .88284 L F
.364 .793 .969 r
.36363 .67411 m .36288 .67477 L .36128 .67357 L F
.36363 .67411 m .36489 .67449 L .36288 .67477 L F
.798 .889 .47 r
.47909 .87067 m .47886 .87182 L .48027 .8688 L F
0 0 0 r
.47865 .87284 m .47886 .87182 L .47909 .87067 L F
.838 .998 .823 r
.48024 .87406 m .47791 .87593 L .47783 .8753 L F
.69 .628 .782 r
.47603 .87469 m .4764 .87632 L .4782 .87388 L F
.659 .53 .695 r
.47506 .87106 m .4782 .87388 L .47688 .87095 L F
.47506 .87106 m .47603 .87469 L .4782 .87388 L F
.838 .998 .823 r
.47849 .87328 m .47783 .8753 L .4775 .87284 L F
.48024 .87406 m .47783 .8753 L .47849 .87328 L F
0 0 0 r
.47868 .87269 m .4782 .87388 L .47886 .87182 L F
.47865 .87284 m .47857 .87301 L .47868 .87269 L F
.47857 .87301 m .4782 .87388 L .47868 .87269 L F
.46 .088 .246 r
.44056 .77527 m .43941 .77726 L .43732 .7775 L F
.225 0 0 r
.44282 .77506 m .43941 .77726 L .44056 .77527 L F
.696 .449 .545 r
.70906 .70808 m .7125 .71042 L .71193 .70789 L F
.739 .619 .725 r
.58913 .83395 m .59212 .83627 L .59244 .83421 L F
.492 .171 .349 r
.63619 .65552 m .63366 .65729 L .63365 .65548 L F
.511 .031 .052 r
.3579 .89537 m .35906 .89536 L .3582 .89514 L F
.161 0 .16 r
.33069 .72172 m .32824 .72419 L .32914 .72253 L F
.826 .905 .894 r
.68658 .61113 m .68806 .61271 L .69003 .60977 L F
.697 .552 .686 r
.68806 .61271 m .69101 .61251 L .69003 .60977 L F
.68806 .61271 m .68927 .61347 L .69101 .61251 L F
.83 .567 .54 r
.58242 .82872 m .58261 .83115 L .58538 .83128 L F
.628 .594 .796 r
.46966 .74383 m .46621 .74073 L .46832 .74063 L F
.58 .59 .827 r
.47017 .74009 m .46966 .74383 L .46832 .74063 L F
.47017 .74009 m .4718 .74355 L .46966 .74383 L F
.6 .58 .802 r
.47299 .74641 m .46966 .74383 L .4718 .74355 L F
.236 0 .322 r
.32824 .72419 m .32616 .72689 L .3268 .72493 L F
.805 .741 .793 r
.68572 .70314 m .68245 .70297 L .68467 .70018 L F
.759 .815 .897 r
.68572 .70314 m .68126 .70481 L .68245 .70297 L F
.757 .717 .815 r
.68787 .70054 m .68572 .70314 L .68467 .70018 L F
.465 .433 .738 r
.50143 .8814 m .49967 .88444 L .49967 .8844 L F
.50143 .8814 m .50188 .88554 L .49967 .88444 L F
.824 .915 .899 r
.68402 .73495 m .68757 .73324 L .68586 .73202 L F
.441 0 .064 r
.38726 .72601 m .38941 .72598 L .38767 .7253 L F
.793 .772 .834 r
.69647 .63791 m .69372 .63847 L .69598 .638 L F
.351 0 0 r
.69598 .638 m .69917 .63876 L .69647 .63791 L F
.968 .683 .438 r
.64851 .61196 m .64865 .61433 L .64977 .61294 L F
.403 .672 .969 r
.34015 .67555 m .34108 .67669 L .34165 .67546 L F
.053 .235 .732 r
.34108 .67669 m .34292 .67855 L .34165 .67546 L F
.426 .317 .627 r
.34132 .67893 m .34292 .67855 L .34108 .67669 L F
.605 .704 .914 r
.45875 .73225 m .45522 .73091 L .45768 .73096 L F
.5 .657 .931 r
.45985 .73071 m .45875 .73225 L .45768 .73096 L F
.45985 .73071 m .46083 .73213 L .45875 .73225 L F
.228 .743 .865 r
.4062 .72264 m .40794 .72243 L .40934 .72253 L F
.191 0 0 r
.41012 .72293 m .40934 .72253 L .40794 .72243 L F
.41012 .72293 m .41129 .72263 L .40934 .72253 L F
.534 .18 .313 r
.36433 .73465 m .3665 .73457 L .36728 .73309 L F
.305 0 .188 r
.36728 .73309 m .36841 .73398 L .36933 .7327 L F
.36728 .73309 m .3665 .73457 L .36841 .73398 L F
.429 0 .042 r
.42782 .78097 m .42633 .78243 L .42414 .78237 L F
.228 0 0 r
.42838 .78195 m .42782 .78097 L .42969 .78029 L F
.42838 .78195 m .42633 .78243 L .42782 .78097 L F
0 0 0 r
.36039 .80741 m .36086 .80707 L .36244 .8066 L F
.805 .568 .579 r
.53785 .8279 m .54112 .83115 L .54087 .82884 L F
.199 0 0 r
.31589 .6762 m .31452 .67645 L .3124 .67632 L F
.253 .763 .762 r
.31657 .67588 m .31589 .6762 L .31768 .67582 L F
.31657 .67588 m .31452 .67645 L .31589 .6762 L F
.106 .218 .698 r
.56559 .81494 m .56687 .81454 L .56526 .8124 L F
0 0 0 r
.56559 .81494 m .56496 .81528 L .56687 .81454 L F
.472 .304 .571 r
.4915 .87129 m .49271 .86864 L .4916 .86873 L F
.598 .443 .643 r
.49271 .86864 m .4915 .87129 L .4916 .86873 L F
0 0 0 r
.32818 .67506 m .32811 .67402 L .32756 .6744 L F
.32818 .67506 m .32527 .67532 L .32811 .67402 L F
.652 .874 .981 r
.66462 .60186 m .6623 .60242 L .66293 .60138 L F
0 0 .137 r
.6623 .60242 m .66284 .60323 L .66293 .60138 L F
.6623 .60242 m .66143 .60446 L .66284 .60323 L F
.449 .586 .898 r
.36705 .67402 m .36584 .67512 L .36489 .67449 L F
.36705 .67402 m .36869 .67653 L .36584 .67512 L F
.146 0 0 r
.36895 .80454 m .36801 .80511 L .36588 .80541 L F
0 0 0 r
.37093 .80415 m .36801 .80511 L .36895 .80454 L F
.847 .594 .557 r
.51048 .87677 m .51242 .87415 L .50894 .8744 L F
.51048 .87677 m .51269 .87607 L .51242 .87415 L F
.752 .541 .61 r
.6413 .63649 m .64045 .63869 L .64136 .63648 L F
0 0 0 r
.64136 .63634 m .64045 .63869 L .64126 .63648 L F
.752 .541 .61 r
.63683 .63772 m .64045 .63869 L .6413 .63649 L F
0 0 0 r
.64137 .63633 m .64045 .63869 L .64136 .63634 L F
0 .344 .75 r
.68754 .62389 m .69123 .62591 L .689 .62522 L F
.24 0 .309 r
.69039 .62528 m .689 .62522 L .69123 .62591 L F
0 .344 .75 r
.68754 .62389 m .69039 .62528 L .69123 .62591 L F
.24 0 .309 r
.69039 .62528 m .68823 .62785 L .689 .62522 L F
.885 .942 .846 r
.64925 .60597 m .65071 .60495 L .64876 .6074 L F
.858 .997 .786 r
.64876 .6074 m .65071 .60495 L .64912 .60568 L F
.844 .996 .833 r
.647 .60807 m .64876 .6074 L .64912 .60568 L F
0 0 0 r
.39799 .79311 m .39979 .79217 L .40157 .7914 L F
.899 .978 .807 r
.66446 .6289 m .66217 .63168 L .66271 .62936 L F
.526 .919 .826 r
.66586 .62803 m .66446 .6289 L .66271 .62936 L F
.779 .664 .736 r
.67804 .60376 m .68109 .60463 L .68021 .60157 L F
.753 .313 .206 r
.68011 .60581 m .68109 .60463 L .67804 .60376 L F
.273 .342 .752 r
.68021 .60157 m .68109 .60463 L .68249 .6037 L F
0 0 0 r
.68249 .6037 m .68109 .60463 L .68011 .60581 L F
.367 0 .149 r
.48241 .86828 m .47909 .87067 L .48027 .8688 L F
.089 .496 .9 r
.52176 .87592 m .52115 .87644 L .52277 .877 L F
.52176 .87592 m .52115 .87644 L .52277 .877 L F
0 .104 .608 r
.6752 .61953 m .67643 .62085 L .6743 .6189 L F
.515 .464 .738 r
.47412 .74277 m .47299 .74641 L .4718 .74355 L F
.47412 .74277 m .47501 .74634 L .47299 .74641 L F
.514 .491 .768 r
.47501 .74634 m .47547 .74815 L .47299 .74641 L F
.685 .614 .771 r
.58695 .83657 m .59001 .83853 L .59041 .83717 L F
.758 .67 .765 r
.59041 .83717 m .59001 .83853 L .59212 .83627 L F
.545 .346 .561 r
.34942 .74045 m .3515 .74029 L .35165 .74012 L F
.542 .268 .45 r
.34874 .74249 m .3515 .74029 L .34942 .74045 L F
.35 0 .077 r
.3104 .6766 m .31139 .67645 L .31036 .67664 L F
.766 .912 .938 r
.66108 .63087 m .65905 .63347 L .65827 .63186 L F
.66108 .63087 m .66217 .63168 L .65905 .63347 L F
.868 .689 .657 r
.66555 .61217 m .66301 .61247 L .66418 .60973 L F
.733 .553 .649 r
.71129 .73225 m .708 .72969 L .71112 .73006 L F
.59 .468 .682 r
.45532 .75433 m .45774 .75401 L .45701 .7511 L F
.598 .454 .657 r
.45532 .75433 m .45777 .75635 L .45774 .75401 L F
.45532 .75433 m .45557 .75669 L .45777 .75635 L F
.686 .445 .552 r
.36584 .76459 m .36526 .7671 L .36291 .76697 L F
.603 .365 .528 r
.36767 .76676 m .36584 .76459 L .36783 .76445 L F
.36767 .76676 m .36526 .7671 L .36584 .76459 L F
.333 0 .027 r
.3936 .78278 m .39569 .78245 L .39711 .78083 L F
.153 0 0 r
.39711 .78083 m .39755 .78187 L .39906 .77999 L F
.39711 .78083 m .39569 .78245 L .39755 .78187 L F
.803 .325 .08 r
.71346 .72744 m .71638 .72972 L .71588 .72693 L F
.71346 .72744 m .71519 .7297 L .71638 .72972 L F
.648 .417 .555 r
.4874 .76382 m .48459 .762 L .48765 .76167 L F
.4874 .76382 m .48433 .76468 L .48459 .762 L F
.139 .07 .509 r
.48233 .84429 m .48121 .84733 L .47921 .84436 L F
.48233 .84429 m .48205 .84747 L .48121 .84733 L F
.449 .274 .551 r
.4841 .84602 m .4834 .84692 L .48205 .84747 L F
.957 .623 .235 r
.48205 .84747 m .48257 .84947 L .48145 .84771 L F
.088 .117 .596 r
.48131 .84776 m .48257 .84947 L .4818 .84987 L F
.48121 .84733 m .48145 .84771 L .48131 .84776 L F
.48145 .84771 m .48257 .84947 L .48131 .84776 L F
.449 .274 .551 r
.4834 .84692 m .48324 .84713 L .48205 .84747 L F
.957 .623 .235 r
.48205 .84747 m .48183 .84893 L .48257 .84947 L F
.449 .274 .551 r
.48324 .84713 m .48183 .84893 L .48204 .84752 L F
.48324 .84713 m .48204 .84752 L .48205 .84747 L F
.957 .623 .235 r
.48205 .84747 m .48145 .84771 L .48121 .84733 L F
.288 0 .161 r
.32437 .72759 m .32337 .72957 L .32158 .72979 L F
.212 0 .121 r
.32506 .7289 m .32437 .72759 L .32616 .72689 L F
.32506 .7289 m .32337 .72957 L .32437 .72759 L F
.537 .35 .575 r
.33181 .76213 m .33399 .76176 L .33392 .75933 L F
.549 .375 .597 r
.33178 .76467 m .33399 .76176 L .33181 .76213 L F
.529 .778 .989 r
.4508 .72877 m .44995 .73011 L .44868 .72938 L F
.4508 .72877 m .45202 .72975 L .44995 .73011 L F
.603 .416 .601 r
.33371 .69555 m .33592 .69526 L .33604 .69267 L F
.591 .406 .6 r
.33604 .69267 m .3379 .69421 L .33845 .69222 L F
.33604 .69267 m .33592 .69526 L .3379 .69421 L F
.453 .484 .801 r
.3571 .66753 m .35658 .67081 L .35571 .66918 L F
.3571 .66753 m .35823 .6707 L .35658 .67081 L F
.833 .71 .728 r
.63782 .62784 m .63888 .62624 L .63732 .62547 L F
.63 .346 .468 r
.47505 .76392 m .47322 .76693 L .47117 .76489 L F
.47633 .76658 m .47505 .76392 L .47663 .76436 L F
.47633 .76658 m .47322 .76693 L .47505 .76392 L F
.146 0 0 r
.71006 .72868 m .71346 .72744 L .7103 .72764 L F
.71006 .72868 m .71355 .728 L .71346 .72744 L F
.621 .121 0 r
.71355 .728 m .71519 .7297 L .71346 .72744 L F
.644 .912 .609 r
.65544 .63292 m .65624 .63224 L .65446 .63424 L F
.642 .489 .66 r
.49333 .86606 m .49653 .8683 L .49681 .86608 L F
.677 .425 .533 r
.49653 .8683 m .49875 .86836 L .49681 .86608 L F
.574 .413 .625 r
.33399 .76176 m .33587 .75871 L .33392 .75933 L F
.233 .249 .672 r
.67133 .60119 m .67104 .60441 L .66946 .60393 L F
.67133 .60119 m .6723 .60635 L .67104 .60441 L F
.59 .259 .377 r
.45597 .76987 m .45477 .77231 L .45256 .77214 L F
.553 .241 .393 r
.45803 .76966 m .45477 .77231 L .45597 .76987 L F
.989 .722 .392 r
.70799 .70987 m .7092 .7084 L .70823 .70751 L F
.70799 .70987 m .70919 .71133 L .7092 .7084 L F
.512 .638 .91 r
.33904 .65546 m .33966 .6579 L .33852 .65634 L F
.33904 .65546 m .34164 .65779 L .33966 .6579 L F
.463 .305 .581 r
.34148 .70807 m .33973 .71138 L .34002 .70874 L F
.307 .663 .973 r
.43331 .72548 m .43254 .72632 L .4311 .7252 L F
.43331 .72548 m .43453 .72651 L .43254 .72632 L F
.724 .734 .859 r
.3407 .81549 m .34084 .8154 L .34062 .81539 L F
.335 .772 .967 r
.41355 .72257 m .41743 .72293 L .41513 .72322 L F
.676 .626 .791 r
.7089 .63079 m .7055 .6284 L .70776 .62795 L F
.56 .606 .856 r
.71072 .62771 m .7089 .63079 L .70776 .62795 L F
.67 .446 .572 r
.71217 .63301 m .70893 .63344 L .7089 .63079 L F
.129 0 0 r
.31791 .71369 m .31954 .71315 L .32075 .71139 L F
.272 0 .078 r
.32075 .71139 m .32134 .71271 L .32251 .71072 L F
.32075 .71139 m .31954 .71315 L .32134 .71271 L F
.924 .736 .248 r
.63833 .60181 m .63798 .59851 L .63875 .59944 L F
.974 .68 .294 r
.70492 .61323 m .70164 .61314 L .70262 .61317 L F
.674 .394 .49 r
.69018 .63432 m .69035 .63723 L .68727 .6363 L F
.171 .028 .432 r
.69196 .63503 m .69018 .63432 L .69248 .6335 L F
.69196 .63503 m .69035 .63723 L .69018 .63432 L F
.889 .761 .714 r
.57515 .81467 m .57579 .81726 L .57656 .8152 L F
.499 .134 .278 r
.42977 .76974 m .43199 .76952 L .43307 .76754 L F
.567 .206 .315 r
.43307 .76754 m .43199 .76952 L .43483 .76894 L F
.502 .233 .438 r
.43307 .76754 m .43483 .76894 L .43517 .76713 L F
.817 .872 .887 r
.70647 .60478 m .70324 .60587 L .70513 .60392 L F
.79 .829 .882 r
.70867 .60297 m .70647 .60478 L .70513 .60392 L F
.663 .64 .818 r
.4464 .74126 m .4501 .74344 L .44838 .74096 L F
.52 .593 .867 r
.4501 .74344 m .45061 .74064 L .44838 .74096 L F
.4501 .74344 m .45211 .74334 L .45061 .74064 L F
.809 .685 .727 r
.5421 .84962 m .54452 .84639 L .54097 .84684 L F
.517 .174 .325 r
.56277 .80519 m .56036 .80504 L .56363 .80455 L F
.035 .465 .879 r
.56553 .80678 m .56277 .80519 L .56363 .80455 L F
.189 0 .212 r
.47921 .84436 m .47775 .84476 L .48005 .84283 L F
.38 .306 .647 r
.47823 .84712 m .47921 .84436 L .47775 .84476 L F
.189 0 .212 r
.48005 .84283 m .47775 .84476 L .47921 .84436 L F
.523 .627 .896 r
.47921 .84436 m .47823 .84712 L .47775 .84476 L F
.983 .712 .428 r
.65614 .61789 m .65627 .62029 L .65517 .61937 L F
.587 .394 .587 r
.65841 .6172 m .65627 .62029 L .65614 .61789 L F
.038 0 0 r
.65614 .61789 m .65774 .61764 L .65841 .6172 L F
0 0 0 r
.65782 .61816 m .65627 .62029 L .65841 .6172 L F
.65739 .61887 m .65695 .61943 L .65782 .61816 L F
.65695 .61943 m .65627 .62029 L .65782 .61816 L F
.724 .693 .82 r
.66203 .61698 m .65841 .6172 L .66091 .61505 L F
.605 .2 .249 r
.66203 .61698 m .66068 .61798 L .65841 .6172 L F
.284 .555 .927 r
.66022 .61676 m .66068 .61798 L .65841 .6172 L F
.383 .137 .413 r
.65833 .61743 m .65967 .61871 L .66022 .61676 L F
0 0 0 r
.65739 .61887 m .65841 .6172 L .65774 .61764 L F
.383 .137 .413 r
.65774 .61764 m .65806 .61782 L .65833 .61743 L F
.65806 .61782 m .65967 .61871 L .65833 .61743 L F
0 0 0 r
.65739 .61887 m .65614 .61789 L .65517 .61937 L F
.65739 .61887 m .65774 .61764 L .65614 .61789 L F
.529 .087 .143 r
.3124 .67632 m .31036 .67664 L .31139 .67645 L F
.3124 .67632 m .30885 .67777 L .31036 .67664 L F
.542 .33 .542 r
.33612 .75644 m .33828 .75622 L .33853 .754 L F
.612 .464 .656 r
.33853 .754 m .34063 .75375 L .34045 .75153 L F
.568 .341 .531 r
.33828 .75622 m .34063 .75375 L .33853 .754 L F
.532 .801 .995 r
.39396 .87648 m .39359 .8772 L .39156 .8762 L F
.599 .877 .992 r
.39396 .87648 m .39242 .87693 L .39359 .8772 L F
.514 .675 .937 r
.68232 .5897 m .68091 .59129 L .68026 .58997 L F
.508 .666 .933 r
.68302 .5912 m .68091 .59129 L .68232 .5897 L F
.193 .685 .922 r
.66293 .60138 m .66569 .6017 L .66462 .60186 L F
0 0 .176 r
.4833 .88118 m .48323 .88164 L .48289 .87939 L F
.4833 .88118 m .48289 .87939 L .48175 .8788 L F
.656 .669 .851 r
.69139 .71661 m .6948 .71842 L .69373 .716 L F
.592 .616 .845 r
.69373 .716 m .6948 .71842 L .69728 .71783 L F
.739 .619 .725 r
.58913 .83395 m .59041 .83717 L .59212 .83627 L F
.754 .54 .607 r
.6136 .65752 m .61153 .65419 L .61331 .65498 L F
.575 .378 .577 r
.33587 .75871 m .33828 .75622 L .33612 .75644 L F
.383 .149 .431 r
.55083 .7966 m .55253 .79625 L .55313 .79418 L F
.295 .196 .569 r
.55083 .7966 m .55249 .79829 L .55253 .79625 L F
.55083 .7966 m .55115 .79905 L .55249 .79829 L F
.391 .814 .633 r
.66183 .64424 m .66134 .6445 L .65836 .64629 L F
.436 .875 .878 r
.66396 .6434 m .66316 .64341 L .66183 .64424 L F
.384 .81 .632 r
.66316 .64341 m .66134 .6445 L .66183 .64424 L F
.326 .787 .942 r
.6804 .70328 m .6803 .70289 L .68245 .70297 L F
.828 .887 .46 r
.6804 .70328 m .67939 .70483 L .6803 .70289 L F
.542 .505 .764 r
.68126 .70481 m .6804 .70328 L .68245 .70297 L F
.51 .323 .564 r
.55168 .80202 m .55165 .80481 L .54961 .80523 L F
.939 .951 .631 r
.55168 .80202 m .55249 .79829 L .55115 .79905 L F
.55168 .80202 m .5512 .80152 L .55249 .79829 L F
.963 .882 .493 r
.55168 .80202 m .55054 .8037 L .5512 .80152 L F
.707 .483 .583 r
.55494 .80458 m .55168 .80202 L .55406 .80177 L F
.55494 .80458 m .55165 .80481 L .55168 .80202 L F
.361 .465 .832 r
.68793 .63016 m .68927 .63302 L .68669 .63187 L F
.516 .275 .489 r
.69347 .62546 m .69599 .62314 L .6938 .62404 L F
.291 .79 .834 r
.39643 .87956 m .39826 .87909 L .39595 .87959 L F
.39643 .87956 m .39826 .87909 L .39595 .87959 L F
.137 .601 .924 r
.4781 .8765 m .47697 .87992 L .47751 .87916 L F
.014 .248 .753 r
.47697 .87992 m .47886 .88182 L .47751 .87916 L F
.479 .198 .408 r
.3623 .6849 m .3617 .68675 L .35965 .68714 L F
.38 .105 .365 r
.36351 .68605 m .3623 .6849 L .3642 .68432 L F
.36351 .68605 m .3617 .68675 L .3623 .6849 L F
0 .091 .632 r
.35246 .66158 m .35206 .66303 L .3513 .66088 L F
.278 .512 .9 r
.35246 .66158 m .3536 .66321 L .35206 .66303 L F
.489 .361 .633 r
.53207 .86131 m .53369 .86299 L .53427 .85903 L F
.53207 .86131 m .53202 .86402 L .53369 .86299 L F
.929 .971 .71 r
.54075 .83719 m .5403 .83691 L .5424 .8339 L F
0 0 .031 r
.54075 .83719 m .5398 .83938 L .54103 .83828 L F
.54075 .83719 m .54103 .83828 L .5403 .83691 L F
.599 .292 .421 r
.4402 .76626 m .44297 .76469 L .44079 .76492 L F
.728 .448 .503 r
.62074 .65987 m .61731 .65775 L .62067 .65764 L F
.623 .392 .547 r
.6228 .65766 m .62074 .65987 L .62067 .65764 L F
.752 .615 .706 r
.62439 .62815 m .62572 .63128 L .62233 .6309 L F
.749 .631 .73 r
.62233 .6309 m .62572 .63128 L .62363 .63398 L F
.721 .892 .958 r
.4925 .88982 m .4959 .88921 L .49495 .88699 L F
.435 .72 .985 r
.4959 .88921 m .49691 .88829 L .49495 .88699 L F
.4959 .88921 m .49771 .88917 L .49691 .88829 L F
.448 .189 .428 r
.34397 .70581 m .34148 .70807 L .34201 .7064 L F
.658 .884 .981 r
.53347 .86377 m .53369 .86299 L .53202 .86402 L F
.354 0 .183 r
.64377 .60154 m .6408 .60387 L .64186 .60456 L F
.679 .577 .734 r
.64186 .60456 m .64517 .60347 L .64377 .60154 L F
.666 .546 .708 r
.58588 .83359 m .58695 .83657 L .58913 .83395 L F
0 .423 .822 r
.34539 .81381 m .34312 .8126 L .34364 .81246 L F
0 0 0 r
.34364 .81246 m .34278 .81266 L .34412 .81233 L F
.34364 .81246 m .34033 .81373 L .34278 .81266 L F
.735 .991 .822 r
.34162 .8118 m .34033 .81373 L .34364 .81246 L F
0 .423 .822 r
.34312 .8126 m .34162 .8118 L .34364 .81246 L F
0 0 0 r
.34364 .81246 m .34412 .81233 L .3448 .81216 L F
.35 .72 .986 r
.32809 .65301 m .32766 .65394 L .32606 .65286 L F
.32809 .65301 m .32985 .65397 L .32766 .65394 L F
.66 .34 .42 r
.47117 .76489 m .47322 .76693 L .47141 .76643 L F
.549 .907 .966 r
.30423 .65556 m .30623 .6552 L .30563 .65526 L F
0 0 0 r
.63182 .63378 m .63195 .6338 L .63454 .63422 L F
.93 .879 .764 r
.63059 .63311 m .63094 .63552 L .63182 .63378 L F
.926 .882 .771 r
.63059 .63311 m .63182 .63378 L .63233 .63292 L F
.63059 .63311 m .63233 .63292 L .63361 .6308 L F
.125 0 0 r
.62885 .63321 m .62934 .63324 L .63059 .63311 L F
0 0 0 r
.63182 .63378 m .63094 .63552 L .63195 .6338 L F
.661 .624 .802 r
.63067 .63692 m .63457 .63832 L .63338 .63626 L F
.63173 .63435 m .63338 .63626 L .63195 .6338 L F
.63067 .63692 m .63338 .63626 L .63173 .63435 L F
.457 .558 .87 r
.63087 .63336 m .63094 .63552 L .63062 .63334 L F
.926 .882 .771 r
.63059 .63311 m .63361 .6308 L .63267 .63 L F
.575 .415 .628 r
.63112 .6325 m .63173 .63341 L .63059 .63311 L F
.457 .558 .87 r
.63178 .63342 m .63172 .63434 L .63087 .63336 L F
.63224 .63355 m .63172 .63434 L .63178 .63342 L F
.52 0 0 r
.63195 .6338 m .63264 .63406 L .63454 .63422 L F
.661 .624 .802 r
.63067 .63692 m .63195 .6338 L .63094 .63552 L F
.74 .627 .734 r
.63683 .63772 m .63195 .6338 L .63457 .63832 L F
.63683 .63772 m .63711 .63576 L .63195 .6338 L F
.855 .926 .875 r
.63189 .63407 m .63067 .63692 L .63094 .63552 L F
.6323 .63346 m .63198 .63413 L .63189 .63407 L F
.63198 .63413 m .63067 .63692 L .63189 .63407 L F
.575 .415 .628 r
.63202 .63384 m .63185 .63403 L .63059 .63311 L F
.855 .926 .875 r
.63185 .63392 m .63179 .63398 L .63207 .63396 L F
.457 .558 .87 r
.63172 .63434 m .63094 .63552 L .63087 .63336 L F
.855 .926 .875 r
.63179 .63398 m .62815 .63775 L .63193 .63409 L F
.63179 .63398 m .63193 .63409 L .63207 .63396 L F
.759 .693 .789 r
.62725 .63513 m .62815 .63775 L .63179 .63398 L F
.575 .415 .628 r
.63173 .63341 m .63202 .63384 L .63059 .63311 L F
.759 .693 .789 r
.63146 .63374 m .63179 .63398 L .6323 .63346 L F
.62725 .63513 m .63179 .63398 L .63146 .63374 L F
0 .142 .595 r
.63059 .63311 m .63185 .63403 L .63179 .63398 L F
.63146 .63374 m .63136 .63365 L .63101 .63337 L F
.759 .693 .789 r
.62725 .63513 m .63146 .63374 L .63115 .63346 L F
.457 .558 .87 r
.6323 .63346 m .63224 .63355 L .63178 .63342 L F
.759 .693 .789 r
.63146 .63374 m .6323 .63346 L .63115 .63346 L F
.125 0 0 r
.63096 .63336 m .63115 .63346 L .6323 .63346 L F
0 .142 .595 r
.63059 .63311 m .63179 .63398 L .63082 .63325 L F
.125 0 0 r
.62885 .63321 m .63115 .63346 L .63096 .63336 L F
.62934 .63324 m .63199 .63344 L .63059 .63311 L F
.63199 .63344 m .6323 .63346 L .63175 .63335 L F
.63199 .63344 m .63175 .63335 L .63059 .63311 L F
.914 .669 .171 r
.63183 .63134 m .63225 .63354 L .63112 .6325 L F
.855 .926 .875 r
.6323 .63346 m .63204 .63373 L .63207 .63396 L F
.63204 .63373 m .63185 .63392 L .632 .63395 L F
.63204 .63373 m .632 .63395 L .63207 .63396 L F
.914 .669 .171 r
.63225 .63354 m .63243 .63445 L .63202 .63384 L F
.63209 .63348 m .63202 .63384 L .63167 .63332 L F
.63225 .63354 m .63202 .63384 L .63209 .63348 L F
.63225 .63354 m .63167 .63332 L .63112 .6325 L F
0 .142 .595 r
.63082 .63325 m .63097 .63337 L .63101 .63337 L F
.63097 .63337 m .63146 .63374 L .63106 .63341 L F
.63097 .63337 m .63106 .63341 L .63101 .63337 L F
.63146 .63374 m .63179 .63398 L .63136 .63365 L F
.63101 .63337 m .6314 .63367 L .63115 .63346 L F
.6314 .63367 m .63208 .6342 L .63147 .63371 L F
.6314 .63367 m .63147 .63371 L .63115 .63346 L F
.63185 .63403 m .63208 .6342 L .63101 .63337 L F
.575 .415 .628 r
.63202 .63384 m .63243 .63445 L .63185 .63403 L F
0 .142 .595 r
.63208 .6342 m .63243 .63445 L .63221 .63428 L F
.63208 .6342 m .63221 .63428 L .6312 .6335 L F
.63118 .63349 m .6312 .6335 L .63115 .63346 L F
.63208 .6342 m .6312 .6335 L .63118 .63349 L F
.855 .926 .875 r
.63207 .63396 m .63055 .63543 L .63067 .63692 L F
.63055 .63543 m .62815 .63775 L .62851 .63763 L F
.63055 .63543 m .62851 .63763 L .63067 .63692 L F
.827 .576 .559 r
.63243 .63445 m .63235 .6366 L .6298 .63575 L F
.63243 .63445 m .6298 .63575 L .63115 .63346 L F
0 0 .525 r
.63196 .63325 m .63235 .6366 L .63243 .63445 L F
.63196 .63325 m .63292 .63608 L .63235 .6366 L F
.736 .473 .532 r
.63005 .63579 m .63292 .63608 L .63233 .63433 L F
.63157 .63377 m .63233 .63433 L .63196 .63325 L F
.63005 .63579 m .63233 .63433 L .63157 .63377 L F
0 0 0 r
.6298 .63575 m .63005 .63579 L .63157 .63377 L F
.63153 .63375 m .63157 .63377 L .63196 .63325 L F
.6298 .63575 m .63157 .63377 L .63153 .63375 L F
.52 0 0 r
.63264 .63406 m .63711 .63576 L .63494 .63446 L F
.63264 .63406 m .63494 .63446 L .63454 .63422 L F
.359 .207 .534 r
.68798 .60538 m .68735 .6063 L .68694 .60476 L F
.381 .076 .317 r
.4492 .77428 m .44814 .7726 L .45041 .77222 L F
.4492 .77428 m .44736 .77481 L .44814 .7726 L F
.817 .743 .783 r
.71663 .71917 m .71761 .72229 L .71575 .72143 L F
.816 .478 .416 r
.71761 .72229 m .71723 .72428 L .71575 .72143 L F
.71761 .72229 m .71849 .72491 L .71723 .72428 L F
.77 .719 .805 r
.71979 .71962 m .71761 .72229 L .71663 .71917 L F
.368 .459 .822 r
.34357 .6574 m .34353 .65998 L .34164 .65779 L F
.34357 .6574 m .34496 .66049 L .34353 .65998 L F
.967 .902 .702 r
.54961 .80523 m .54876 .80632 L .5486 .80475 L F
.394 .045 .251 r
.55165 .80481 m .54876 .80632 L .54961 .80523 L F
.892 .684 .615 r
.71296 .62757 m .71431 .6289 L .71072 .62771 L F
.724 .71 .837 r
.71626 .62806 m .71431 .6289 L .71296 .62757 L F
.545 .572 .832 r
.71612 .63025 m .71431 .6289 L .71626 .62806 L F
.515 .317 .55 r
.48487 .86395 m .48585 .86584 L .48656 .86359 L F
.717 .54 .648 r
.71902 .70228 m .71858 .70283 L .71952 .70304 L F
.781 .737 .812 r
.71561 .70215 m .71858 .70283 L .71529 .70255 L F
.71858 .70283 m .71952 .70304 L .71839 .70291 L F
.71858 .70283 m .71839 .70291 L .71529 .70255 L F
.804 .667 .713 r
.71952 .70304 m .71644 .70549 L .71529 .70255 L F
.717 .54 .648 r
.71858 .70283 m .71644 .70549 L .71952 .70304 L F
.71858 .70283 m .72011 .70608 L .71644 .70549 L F
.71902 .70228 m .71911 .70259 L .71858 .70283 L F
.781 .737 .812 r
.71755 .69976 m .71922 .70255 L .71561 .70215 L F
.71922 .70255 m .71952 .70304 L .71853 .70282 L F
.71922 .70255 m .71853 .70282 L .71561 .70215 L F
.648 .464 .621 r
.72086 .70341 m .72011 .70608 L .71911 .70259 L F
.438 .586 .902 r
.71984 .70292 m .71902 .70228 L .71952 .70304 L F
.648 .464 .621 r
.71937 .70249 m .71932 .70251 L .71902 .70228 L F
.72011 .70294 m .71911 .70259 L .71937 .70249 L F
.72086 .70341 m .71981 .70292 L .72011 .70294 L F
.71981 .70292 m .71911 .70259 L .72011 .70294 L F
.438 .586 .902 r
.72157 .70227 m .72086 .70341 L .71902 .70228 L F
.72157 .70227 m .71902 .70228 L .71984 .70292 L F
.478 .789 .999 r
.7205 .70136 m .72157 .70227 L .71984 .70292 L F
.7196 .7029 m .71984 .70292 L .71952 .70304 L F
.7205 .70136 m .71984 .70292 L .7196 .7029 L F
.648 .464 .621 r
.71932 .70251 m .71922 .70255 L .71902 .70228 L F
.478 .789 .999 r
.7205 .70136 m .7196 .7029 L .71755 .69976 L F
.7196 .7029 m .71952 .70304 L .71922 .70255 L F
.7196 .7029 m .71922 .70255 L .71755 .69976 L F
.648 .464 .621 r
.71922 .70255 m .71911 .70259 L .71906 .7024 L F
.71922 .70255 m .71906 .7024 L .71902 .70228 L F
.717 .54 .648 r
.71911 .70259 m .72011 .70608 L .71858 .70283 L F
.692 .639 .791 r
.7176 .70847 m .71424 .70626 L .71644 .70549 L F
.619 .529 .73 r
.72011 .70608 m .7176 .70847 L .71644 .70549 L F
.72011 .70608 m .72003 .70837 L .7176 .70847 L F
.26 .369 .785 r
.72023 .71043 m .7176 .70847 L .72003 .70837 L F
0 0 0 r
.40363 .79094 m .40716 .78897 L .40563 .79045 L F
.155 0 0 r
.40563 .79045 m .40716 .78897 L .40912 .78841 L F
.61 .599 .814 r
.46739 .73798 m .46621 .74073 L .46521 .73815 L F
.46739 .73798 m .46832 .74063 L .46621 .74073 L F
.77 .527 .567 r
.67365 .5998 m .67133 .60119 L .67344 .59851 L F
.67365 .5998 m .67453 .60161 L .67133 .60119 L F
.538 .346 .568 r
.58031 .8317 m .58242 .82872 L .57878 .82786 L F
.659 .104 0 r
.48427 .88621 m .48695 .88781 L .48573 .88744 L F
0 .432 .855 r
.48695 .88781 m .48839 .88799 L .48573 .88744 L F
.48695 .88781 m .48934 .88894 L .48839 .88799 L F
.456 .105 .28 r
.41962 .77455 m .42174 .77424 L .42286 .77187 L F
.509 .157 .304 r
.42174 .77424 m .42502 .77182 L .42286 .77187 L F
.307 .089 .41 r
.33842 .68972 m .33986 .68931 L .34029 .68726 L F
.399 .26 .574 r
.33842 .68972 m .33993 .69165 L .33986 .68931 L F
.33842 .68972 m .33845 .69222 L .33993 .69165 L F
.566 .374 .58 r
.37719 .75389 m .3776 .75689 L .37489 .75674 L F
.353 .225 .564 r
.37872 .75584 m .37719 .75389 L .37916 .75367 L F
.37872 .75584 m .3776 .75689 L .37719 .75389 L F
.574 .777 .975 r
.49041 .89028 m .49135 .88879 L .48934 .88894 L F
.49041 .89028 m .4925 .88982 L .49135 .88879 L F
.47 .518 .825 r
.46629 .7343 m .46462 .73543 L .46453 .73436 L F
.544 .501 .759 r
.46629 .7343 m .46521 .73815 L .46462 .73543 L F
.553 .562 .817 r
.69977 .60394 m .69769 .60437 L .69658 .60126 L F
.643 .576 .763 r
.69977 .60394 m .69806 .60668 L .69769 .60437 L F
.504 .608 .89 r
.67702 .71447 m .68044 .71662 L .67896 .71435 L F
.109 .378 .838 r
.67896 .71435 m .68044 .71662 L .68086 .71556 L F
.592 .025 0 r
.68044 .71662 m .68285 .71849 L .68139 .71774 L F
.68044 .71662 m .68139 .71774 L .68086 .71556 L F
.354 .149 .458 r
.64702 .6396 m .64876 .63849 L .64848 .6367 L F
.543 .221 .373 r
.64136 .65273 m .64112 .65416 L .63944 .65472 L F
.492 .177 .36 r
.64136 .65273 m .6434 .65372 L .64112 .65416 L F
.521 .099 .179 r
.64365 .65285 m .6434 .65372 L .64136 .65273 L F
.947 .735 .585 r
.56575 .81025 m .56393 .81006 L .56426 .80867 L F
.56575 .81025 m .56526 .8124 L .56393 .81006 L F
.596 .425 .62 r
.34281 .74858 m .34502 .74837 L .34485 .7461 L F
.597 .379 .556 r
.34281 .74858 m .34477 .75061 L .34502 .74837 L F
.34281 .74858 m .34267 .75104 L .34477 .75061 L F
.764 .61 .688 r
.62341 .63598 m .62024 .63357 L .62363 .63398 L F
.62341 .63598 m .6217 .63684 L .62024 .63357 L F
.787 .674 .739 r
.62341 .63598 m .62128 .63884 L .6217 .63684 L F
.872 .812 .788 r
.6338 .61119 m .63512 .61227 L .63316 .61512 L F
.862 .904 .861 r
.6338 .61119 m .63701 .60937 L .63512 .61227 L F
.997 .815 .537 r
.67705 .71221 m .67618 .71353 L .67628 .71089 L F
.67705 .71221 m .67702 .71447 L .67618 .71353 L F
.649 .591 .776 r
.56671 .82094 m .57034 .8235 L .56891 .82104 L F
.706 .68 .823 r
.56891 .82104 m .57034 .8235 L .57261 .82287 L F
.534 .513 .779 r
.56671 .82094 m .56816 .81764 L .56567 .81976 L F
.56671 .82094 m .56891 .82104 L .56816 .81764 L F
.745 .63 .731 r
.62233 .6309 m .62363 .63398 L .62024 .63357 L F
0 0 0 r
.71405 .61719 m .7161 .61441 L .71564 .61505 L F
.5 .544 .832 r
.71762 .61355 m .71869 .61652 L .71564 .61505 L F
0 0 0 r
.71405 .61719 m .71528 .61637 L .7161 .61441 L F
.389 .367 .713 r
.71414 .61981 m .71528 .61637 L .71405 .61719 L F
.684 .656 .816 r
.3513 .66088 m .34844 .66056 L .35056 .66003 L F
0 .091 .632 r
.35246 .66158 m .3513 .66088 L .35056 .66003 L F
.84 .994 .847 r
.68162 .7089 m .67932 .7113 L .67902 .71063 L F
.942 .83 .387 r
.67902 .71063 m .67932 .7113 L .67867 .71263 L F
.704 .602 .739 r
.58695 .83657 m .59041 .83717 L .58913 .83395 L F
.661 .381 .485 r
.33328 .69693 m .33592 .69526 L .33371 .69555 L F
.215 .728 .881 r
.34496 .66049 m .34695 .66035 L .34844 .66056 L F
.233 0 0 r
.34695 .66035 m .35056 .66003 L .34844 .66056 L F
.591 .701 .92 r
.3628 .7852 m .36216 .7876 L .36063 .78555 L F
.3628 .7852 m .3645 .78721 L .36216 .7876 L F
.97 .883 .504 r
.52897 .82366 m .52858 .82581 L .52817 .8243 L F
.721 .456 0 r
.52858 .82581 m .52906 .82797 L .52817 .8243 L F
.357 .34 .703 r
.3571 .66753 m .35571 .66918 L .35509 .66579 L F
.431 .03 .176 r
.40124 .78016 m .4034 .77992 L .40467 .77799 L F
.441 .109 .305 r
.4034 .77992 m .40654 .77706 L .40467 .77799 L F
.67 .483 .624 r
.61153 .65419 m .61209 .6577 L .60862 .65746 L F
.754 .54 .607 r
.6136 .65752 m .61209 .6577 L .61153 .65419 L F
.106 0 0 r
.65374 .5941 m .65305 .5955 L .65114 .5963 L F
.528 .501 .77 r
.65505 .59127 m .65374 .5941 L .6529 .59076 L F
0 0 0 r
.65469 .59369 m .65374 .5941 L .65505 .59127 L F
.65469 .59369 m .65305 .5955 L .65374 .5941 L F
.642 .489 .66 r
.49333 .86606 m .49271 .86864 L .49653 .8683 L F
.537 .365 .596 r
.34485 .7461 m .34693 .74594 L .34677 .7433 L F
.64 .518 .699 r
.34502 .74837 m .34693 .74594 L .34485 .7461 L F
.54 .357 .581 r
.36061 .77195 m .35836 .76994 L .36064 .76953 L F
.36061 .77195 m .35826 .77238 L .35836 .76994 L F
.216 .671 .948 r
.32527 .67532 m .3224 .67458 L .32337 .67434 L F
.022 0 0 r
.66958 .64253 m .66858 .64289 L .66624 .64319 L F
.411 .844 .711 r
.67036 .64184 m .66958 .64253 L .67204 .64161 L F
.67036 .64184 m .66858 .64289 L .66958 .64253 L F
.457 .686 .965 r
.33703 .65482 m .33633 .65629 L .3349 .65508 L F
.33703 .65482 m .33852 .65634 L .33633 .65629 L F
.977 .816 .406 r
.57559 .80999 m .5748 .81187 L .57532 .81234 L F
.967 .71 .278 r
.57469 .80673 m .57499 .80939 L .57559 .80999 L F
.989 .798 .41 r
.57499 .80939 m .5748 .81187 L .57559 .80999 L F
.347 .013 .249 r
.71612 .63025 m .71585 .63226 L .7141 .63271 L F
.396 .158 .431 r
.71955 .62755 m .71612 .63025 L .71626 .62806 L F
.71955 .62755 m .71886 .63009 L .71612 .63025 L F
.355 .019 .251 r
.71886 .63009 m .71585 .63226 L .71612 .63025 L F
.845 .997 .77 r
.52814 .87383 m .52958 .87121 L .52746 .87371 L F
.52814 .87383 m .53025 .87121 L .52958 .87121 L F
.418 .73 .99 r
.67618 .71353 m .67702 .71447 L .67896 .71435 L F
.549 .907 .966 r
.30423 .65556 m .30776 .655 L .30623 .6552 L F
.805 .341 .128 r
.71522 .71203 m .71448 .71297 L .7125 .71042 L F
.379 .596 .931 r
.42505 .74226 m .42602 .74149 L .42374 .74162 L F
.42505 .74226 m .42706 .74285 L .42602 .74149 L F
.54 .683 .932 r
.70252 .71938 m .70386 .72164 L .70569 .72128 L F
.826 .81 .835 r
.54499 .81025 m .54308 .81238 L .54272 .81056 L F
0 .365 .809 r
.54308 .81238 m .54355 .81212 L .54272 .81056 L F
.54308 .81238 m .54569 .81381 L .54355 .81212 L F
.378 .745 .991 r
.4243 .72402 m .42359 .72491 L .42234 .72433 L F
.4243 .72402 m .42574 .72483 L .42359 .72491 L F
.498 .347 .607 r
.34063 .75375 m .34267 .75104 L .34045 .75153 L F
.534 .242 .417 r
.37489 .75674 m .37669 .75827 L .37449 .75852 L F
.545 .239 .4 r
.3776 .75689 m .37669 .75827 L .37489 .75674 L F
.827 .918 .898 r
.66271 .62936 m .66217 .63168 L .66108 .63087 L F
0 .216 .687 r
.39259 .78183 m .39121 .78109 L .39023 .78034 L F
.39259 .78183 m .3936 .78278 L .39121 .78109 L F
.829 .419 .265 r
.7211 .72838 m .71892 .72788 L .71886 .72726 L F
.622 .509 .703 r
.721 .72468 m .72161 .72731 L .71886 .72726 L F
.561 .195 .304 r
.72161 .72731 m .7211 .72838 L .71886 .72726 L F
.673 .299 .329 r
.39754 .74678 m .39741 .74751 L .39642 .7469 L F
.77 .663 .744 r
.39981 .74301 m .39754 .74678 L .39642 .74294 L F
.431 .085 .276 r
.39754 .74678 m .3995 .74711 L .39741 .74751 L F
.538 .346 .568 r
.58031 .8317 m .58261 .83115 L .58242 .82872 L F
0 0 0 r
.69652 .61244 m .69818 .61089 L .69874 .60975 L F
.677 .556 .71 r
.69974 .6149 m .69755 .61547 L .69652 .61244 L F
.678 .556 .709 r
.69578 .61441 m .69818 .61089 L .69652 .61244 L F
.472 .345 .626 r
.47401 .86591 m .47581 .86556 L .4755 .86324 L F
.604 .513 .725 r
.47409 .86833 m .47581 .86556 L .47401 .86591 L F
0 0 0 r
.6782 .62907 m .67864 .6278 L .67727 .62896 L F
.67727 .63319 m .67676 .63374 L .6782 .62907 L F
.67727 .63319 m .6782 .62907 L .67727 .62896 L F
.27 .09 .443 r
.33166 .69794 m .33275 .69934 L .33328 .69693 L F
.173 .07 .488 r
.33166 .69794 m .33165 .70024 L .33275 .69934 L F
.722 .938 .957 r
.37316 .78629 m .36923 .78742 L .37201 .786 L F
.751 .95 .943 r
.37479 .78511 m .37316 .78629 L .37365 .78473 L F
.766 .963 .93 r
.37365 .78473 m .37316 .78629 L .37201 .786 L F
.97 .883 .504 r
.52897 .82366 m .52817 .8243 L .52802 .82276 L F
.606 .889 .99 r
.53146 .82294 m .52897 .82366 L .52956 .82268 L F
.439 .683 .968 r
.52956 .82268 m .52897 .82366 L .52802 .82276 L F
.52956 .82268 m .52897 .82366 L .52802 .82276 L F
0 0 .042 r
.6673 .62453 m .66643 .62588 L .66586 .62803 L F
.515 .093 .177 r
.38941 .72598 m .39156 .72611 L .39294 .72437 L F
.384 0 .033 r
.39156 .72611 m .39513 .7244 L .39294 .72437 L F
.866 .982 .845 r
.50766 .87968 m .50483 .88187 L .50473 .87925 L F
.593 .593 .821 r
.51152 .88239 m .50766 .87968 L .51 .87927 L F
.038 0 0 r
.64073 .60817 m .64443 .60696 L .64256 .60714 L F
.846 .85 .846 r
.54569 .81381 m .54615 .81539 L .54854 .81281 L F
.963 .657 .399 r
.63833 .60181 m .63728 .60235 L .63794 .60115 L F
.63833 .60181 m .63849 .6039 L .63728 .60235 L F
.924 .736 .248 r
.63833 .60181 m .63794 .60115 L .63798 .59851 L F
.498 .574 .863 r
.35549 .66285 m .35509 .66579 L .3536 .66321 L F
.35549 .66285 m .35671 .66539 L .35509 .66579 L F
.449 .345 .644 r
.35671 .66539 m .3571 .66753 L .35509 .66579 L F
.655 .398 .518 r
.4326 .74041 m .43337 .74309 L .42939 .74302 L F
.596 .363 .534 r
.43532 .74267 m .43337 .74309 L .4326 .74041 L F
.527 0 0 r
.43599 .74304 m .4326 .74041 L .43508 .74229 L F
.867 .989 .831 r
.4362 .74148 m .43599 .74304 L .43508 .74229 L F
.4362 .74148 m .43532 .74267 L .43599 .74304 L F
.526 .321 .544 r
.43648 .74369 m .43532 .74267 L .43613 .74165 L F
.964 .735 .545 r
.43453 .74489 m .43599 .74304 L .43532 .74267 L F
.43453 .74489 m .43589 .74565 L .43599 .74304 L F
.43453 .74489 m .43599 .74304 L .43532 .74267 L F
.43453 .74489 m .43589 .74565 L .43599 .74304 L F
.526 .321 .544 r
.43662 .74447 m .43532 .74267 L .43648 .74369 L F
.527 0 0 r
.43397 .74147 m .43532 .74267 L .4326 .74041 L F
.43599 .74304 m .43532 .74267 L .43397 .74147 L F
.867 .724 .703 r
.63701 .60937 m .63458 .61023 L .63627 .60626 L F
.862 .904 .861 r
.6338 .61119 m .63458 .61023 L .63701 .60937 L F
.705 .612 .75 r
.57261 .82287 m .5759 .82337 L .57457 .82037 L F
.716 .567 .685 r
.57261 .82287 m .57369 .82595 L .5759 .82337 L F
.435 .284 .577 r
.51261 .8835 m .51114 .88478 L .51152 .88239 L F
.843 .698 .702 r
.68654 .72654 m .68825 .72724 L .6871 .72414 L F
.894 .799 .748 r
.68737 .7283 m .68509 .72922 L .68378 .7275 L F
.88 .811 .777 r
.68509 .72922 m .68825 .72724 L .68654 .72654 L F
.894 .799 .748 r
.68737 .7283 m .6865 .73001 L .68509 .72922 L F
.88 .811 .777 r
.68509 .72922 m .6865 .73001 L .68825 .72724 L F
.873 .501 .339 r
.66143 .60446 m .66189 .60635 L .66113 .60699 L F
.66143 .60446 m .66113 .60699 L .66284 .60323 L F
.81 .668 .706 r
.61936 .64166 m .62047 .64484 L .61896 .6439 L F
.457 .136 .333 r
.46045 .76779 m .46015 .76931 L .45803 .76966 L F
.568 .247 .385 r
.46376 .76677 m .46015 .76931 L .46045 .76779 L F
.974 .68 .294 r
.70492 .61323 m .70445 .61426 L .70164 .61314 L F
.70492 .61323 m .70545 .61537 L .70445 .61426 L F
.713 .557 .676 r
.70581 .61157 m .70732 .61333 L .70492 .61323 L F
.104 0 0 r
.37286 .8035 m .37631 .80162 L .37492 .80273 L F
.102 0 0 r
.37824 .80109 m .3777 .80166 L .37631 .80162 L F
.106 0 0 r
.37631 .80162 m .3777 .80166 L .37492 .80273 L F
.842 .738 .749 r
.62329 .625 m .62439 .62815 L .62193 .62755 L F
.62329 .625 m .62471 .62609 L .62439 .62815 L F
.846 .765 .772 r
.62193 .62755 m .62439 .62815 L .62233 .6309 L F
.743 .649 .756 r
.62673 .62535 m .62439 .62815 L .62471 .62609 L F
.724 .71 .837 r
.71626 .62806 m .71296 .62757 L .71553 .62537 L F
.772 .744 .827 r
.71862 .62555 m .71626 .62806 L .71553 .62537 L F
.617 .49 .684 r
.71862 .62555 m .71955 .62755 L .71626 .62806 L F
.696 .578 .719 r
.35815 .89638 m .35906 .89536 L .3579 .89537 L F
.835 .796 .814 r
.70995 .71625 m .70797 .71867 L .71127 .71798 L F
.836 .735 .753 r
.70797 .71867 m .70891 .72161 L .71127 .71798 L F
.753 .655 .752 r
.53695 .85223 m .53895 .84962 L .53741 .85021 L F
0 0 .265 r
.698 .61583 m .69755 .61547 L .69974 .6149 L F
.698 .61583 m .69751 .61767 L .69755 .61547 L F
.777 .512 0 r
.67741 .62411 m .67768 .62474 L .67928 .62433 L F
.67741 .62411 m .67783 .62555 L .67768 .62474 L F
.175 .578 .937 r
.67768 .62474 m .68002 .62524 L .67928 .62433 L F
.833 .71 .728 r
.63782 .62784 m .63732 .62547 L .63689 .62765 L F
.967 .654 .366 r
.68185 .63106 m .68129 .63274 L .68078 .6304 L F
.68185 .63106 m .68237 .63325 L .68129 .63274 L F
.646 .79 .951 r
.38072 .78304 m .37735 .78264 L .3793 .7826 L F
.11 0 0 r
.38133 .7833 m .38072 .78304 L .3793 .7826 L F
.38133 .7833 m .38295 .78304 L .38072 .78304 L F
.534 .363 .595 r
.34677 .7433 m .34892 .74535 L .34874 .74249 L F
.34677 .7433 m .34693 .74594 L .34892 .74535 L F
.826 .752 .781 r
.71868 .71388 m .71591 .71411 L .71939 .71123 L F
.71868 .71388 m .71662 .71644 L .71591 .71411 L F
.689 .537 .674 r
.71868 .71388 m .71948 .71689 L .71662 .71644 L F
.502 .42 .696 r
.7214 .71658 m .71868 .71388 L .72135 .71355 L F
.7214 .71658 m .71948 .71689 L .71868 .71388 L F
.446 .23 .49 r
.36869 .67653 m .36824 .67878 L .36638 .67927 L F
.438 .21 .469 r
.36824 .67878 m .36603 .68136 L .36638 .67927 L F
.65 .495 .66 r
.47688 .87095 m .47409 .86833 L .47506 .87106 L F
.473 .167 .366 r
.35595 .80998 m .35744 .81133 L .35564 .81199 L F
.35595 .80998 m .3581 .80965 L .35744 .81133 L F
.829 .728 .753 r
.6364 .62219 m .63732 .62547 L .63745 .62311 L F
.802 .982 .896 r
.63978 .62038 m .6364 .62219 L .63745 .62311 L F
.238 0 0 r
.44357 .74025 m .44221 .73993 L .44163 .73973 L F
.39 .826 .953 r
.44425 .73954 m .44221 .73993 L .44357 .74025 L F
.517 .087 .162 r
.44425 .73954 m .44282 .74015 L .44221 .73993 L F
.44282 .74015 m .44085 .74099 L .44221 .73993 L F
.238 0 0 r
.44163 .73973 m .44221 .73993 L .44051 .73942 L F
.39 .826 .953 r
.44425 .73954 m .44357 .74025 L .44574 .73983 L F
.482 .275 .522 r
.35936 .68932 m .35748 .68981 L .35965 .68714 L F
.491 .263 .495 r
.35908 .69128 m .35748 .68981 L .35936 .68932 L F
.35908 .69128 m .35716 .69173 L .35748 .68981 L F
.752 .849 .405 r
.57728 .80082 m .57691 .80207 L .57831 .799 L F
.708 .381 0 r
.5774 .79656 m .57817 .79875 L .57831 .799 L F
.829 .874 .434 r
.57817 .79875 m .57728 .80082 L .57831 .799 L F
.921 .698 .583 r
.69455 .64055 m .69367 .64126 L .69372 .63847 L F
.864 .579 .505 r
.69455 .64055 m .69386 .64354 L .69367 .64126 L F
.599 .246 .343 r
.69708 .64167 m .69386 .64354 L .69455 .64055 L F
.706 .68 .823 r
.56891 .82104 m .57261 .82287 L .57139 .81997 L F
.733 .655 .772 r
.57139 .81997 m .57261 .82287 L .57457 .82037 L F
.674 .618 .785 r
.72955 .71395 m .72752 .71662 L .7267 .71428 L F
0 0 .468 r
.7267 .71428 m .72752 .71662 L .72735 .7155 L F
.635 .561 .755 r
.72955 .71395 m .72989 .71678 L .72752 .71662 L F
.611 .277 .379 r
.72752 .71662 m .72989 .71678 L .7299 .7182 L F
.064 .347 .822 r
.72735 .7155 m .72752 .71662 L .7299 .7182 L F
.656 .497 .657 r
.45332 .7588 m .45574 .75907 L .45557 .75669 L F
.512 .18 .341 r
.45272 .76128 m .45574 .75907 L .45332 .7588 L F
.679 .3 .321 r
.64502 .61199 m .64851 .61196 L .64573 .6106 L F
.799 .75 .807 r
.63025 .615 m .63251 .61247 L .63316 .61512 L F
.808 .72 .768 r
.63025 .615 m .63316 .61512 L .63113 .61778 L F
.872 .812 .788 r
.6338 .61119 m .63316 .61512 L .63251 .61247 L F
.285 .53 .911 r
.51741 .82135 m .518 .82123 L .51532 .81996 L F
.124 0 0 r
.64918 .65053 m .65025 .65097 L .64825 .65175 L F
.64918 .65053 m .65156 .64999 L .65025 .65097 L F
.501 .025 .057 r
.64268 .64295 m .64427 .64117 L .64126 .64165 L F
.132 0 0 r
.64622 .64036 m .64702 .6396 L .64427 .64117 L F
.699 .642 .79 r
.64402 .64182 m .64268 .64295 L .64241 .64237 L F
.296 .188 .557 r
.6426 .64316 m .64402 .64182 L .64241 .64237 L F
.64306 .64509 m .64381 .64253 L .6426 .64316 L F
.105 0 0 r
.64415 .64236 m .64427 .64117 L .643 .64259 L F
.6437 .64254 m .643 .64259 L .64268 .64295 L F
.64415 .64236 m .643 .64259 L .6437 .64254 L F
.296 .188 .557 r
.64306 .64509 m .64507 .64478 L .64426 .6425 L F
.105 0 0 r
.64508 .64198 m .64501 .64192 L .64415 .64236 L F
.699 .642 .79 r
.64402 .64182 m .64508 .64198 L .64268 .64295 L F
.296 .188 .557 r
.64381 .64253 m .64426 .6425 L .64402 .64182 L F
.64306 .64509 m .64426 .6425 L .64381 .64253 L F
.64381 .64253 m .64402 .64182 L .6426 .64316 L F
.105 0 0 r
.64501 .64192 m .64427 .64117 L .64415 .64236 L F
.64508 .64198 m .64622 .64036 L .64427 .64117 L F
.643 .576 .763 r
.69977 .60394 m .70107 .60722 L .69806 .60668 L F
.658 .535 .703 r
.70107 .60722 m .69874 .60975 L .69806 .60668 L F
.505 .265 .484 r
.55313 .79418 m .55467 .79586 L .55403 .79351 L F
.55313 .79418 m .55253 .79625 L .55467 .79586 L F
.49 .255 .484 r
.35716 .69173 m .35485 .69399 L .35519 .69229 L F
.643 .383 .511 r
.4897 .76198 m .4874 .76382 L .48765 .76167 L F
.672 .509 .655 r
.56771 .78834 m .57108 .79076 L .57103 .78857 L F
.607 .456 .651 r
.3563 .77531 m .35431 .77785 L .35439 .77579 L F
.615 .299 .411 r
.64517 .60347 m .64705 .60327 L .64635 .60313 L F
.62 .453 .634 r
.65452 .5991 m .65494 .60153 L .65252 .60206 L F
.497 .369 .636 r
.65672 .59938 m .65494 .60153 L .65452 .5991 L F
.097 0 .03 r
.65452 .5991 m .65368 .60039 L .65641 .5986 L F
.106 0 0 r
.38405 .79907 m .38316 .79964 L .37999 .80053 L F
.077 0 0 r
.38592 .79841 m .38316 .79964 L .38405 .79907 L F
.597 .453 .655 r
.45557 .75669 m .45574 .75907 L .45777 .75635 L F
.353 0 0 r
.41082 .77616 m .4143 .77474 L .41228 .77528 L F
.477 .222 .449 r
.35036 .69772 m .3504 .7 L .34872 .6993 L F
.37 .142 .433 r
.352 .69942 m .35036 .69772 L .35216 .69617 L F
.352 .69942 m .3504 .7 L .35036 .69772 L F
.781 .603 .659 r
.62894 .62057 m .62889 .62261 L .62557 .62219 L F
.783 .641 .704 r
.62797 .61773 m .63094 .61993 L .62894 .62057 L F
.521 .604 .877 r
.70545 .61537 m .70658 .61361 L .70445 .61426 L F
.70545 .61537 m .70768 .61543 L .70658 .61361 L F
.53 .678 .932 r
.42148 .74178 m .42237 .73992 L .42037 .74056 L F
.42148 .74178 m .42374 .74162 L .42237 .73992 L F
.244 .731 .926 r
.55561 .78546 m .5523 .78516 L .55367 .78558 L F
.55561 .78546 m .5523 .78516 L .55367 .78558 L F
.485 .17 .357 r
.44563 .76386 m .44793 .76362 L .44827 .76202 L F
.635 .307 .399 r
.44793 .76362 m .45022 .76388 L .44827 .76202 L F
.565 .319 .503 r
.44827 .76202 m .45022 .76388 L .45054 .76173 L F
.568 .617 .861 r
.66946 .60393 m .66692 .60436 L .66569 .6017 L F
.544 .41 .649 r
.66946 .60393 m .66936 .60616 L .66692 .60436 L F
.449 .247 .513 r
.36117 .68881 m .35965 .68714 L .3617 .68675 L F
.36117 .68881 m .35936 .68932 L .35965 .68714 L F
.705 .977 .773 r
.54192 .84486 m .53952 .84755 L .54097 .84684 L F
.781 .673 .744 r
.53895 .84962 m .54097 .84684 L .53952 .84755 L F
.46 .473 .785 r
.6895 .62224 m .68754 .62389 L .68709 .62281 L F
.6895 .62224 m .69039 .62528 L .68754 .62389 L F
.31 0 0 r
.69751 .61767 m .6965 .61839 L .69502 .61844 L F
.867 .972 .66 r
.698 .61583 m .6965 .61839 L .69751 .61767 L F
.691 .779 .919 r
.65202 .63009 m .65528 .63047 L .65333 .63051 L F
.59 .049 0 r
.65544 .63292 m .65333 .63051 L .65528 .63047 L F
.65544 .63292 m .65202 .63009 L .65333 .63051 L F
.678 .451 .57 r
.5424 .8339 m .5403 .83691 L .54245 .83618 L F
.267 0 0 r
.41315 .78729 m .41458 .78589 L .41665 .78552 L F
.686 .357 .412 r
.50534 .8761 m .50987 .87597 L .50894 .8744 L F
.831 .377 .14 r
.50987 .87597 m .51048 .87677 L .50894 .8744 L F
.568 .247 .385 r
.46376 .76677 m .46233 .76925 L .46015 .76931 L F
.61 .291 .405 r
.46566 .76708 m .46233 .76925 L .46376 .76677 L F
.532 .448 .705 r
.34129 .68116 m .34292 .67855 L .34132 .67893 L F
.773 .617 .685 r
.62128 .63884 m .61827 .63633 L .6217 .63684 L F
.62128 .63884 m .61806 .63857 L .61827 .63633 L F
.772 .635 .71 r
.62128 .63884 m .61936 .64166 L .61806 .63857 L F
.185 .157 .591 r
.68198 .72191 m .68408 .72212 L .68285 .71849 L F
0 0 0 r
.68181 .72422 m .68408 .72212 L .68198 .72191 L F
.542 .374 .603 r
.35826 .77238 m .3563 .77531 L .35633 .77287 L F
.591 .544 .771 r
.45633 .74913 m .45701 .7511 L .45916 .7506 L F
.668 .517 .67 r
.45701 .7511 m .45993 .75362 L .45916 .7506 L F
.45701 .7511 m .45774 .75401 L .45993 .75362 L F
.516 .152 .287 r
.37325 .73174 m .37667 .72969 L .37458 .73009 L F
.467 .507 .816 r
.66462 .62114 m .66642 .61909 L .66465 .6193 L F
.35 0 0 r
.31207 .65273 m .31514 .65257 L .31322 .65289 L F
.977 .724 .484 r
.5259 .84997 m .52475 .84956 L .52473 .84701 L F
.5259 .84997 m .52475 .84956 L .52473 .84701 L F
.385 .149 .428 r
.33986 .68931 m .34206 .68667 L .34029 .68726 L F
.397 .854 .833 r
.52958 .87121 m .53025 .87121 L .53153 .87047 L F
.761 .568 .637 r
.4772 .85506 m .48063 .85797 L .47861 .85532 L F
.4772 .85506 m .47736 .85788 L .48063 .85797 L F
0 .174 .702 r
.48063 .85797 m .48069 .85725 L .47861 .85532 L F
.389 .222 .53 r
.48222 .85755 m .48054 .86028 L .48063 .85797 L F
.466 .533 .842 r
.48054 .86028 m .48069 .85725 L .48063 .85797 L F
.436 .351 .661 r
.48153 .85523 m .48222 .85755 L .48063 .85797 L F
.741 .717 .829 r
.73149 .71389 m .73332 .7165 L .72989 .71678 L F
.742 .59 .686 r
.72989 .71678 m .73332 .7165 L .73143 .71885 L F
.546 .321 .524 r
.73332 .7165 m .73318 .71927 L .73143 .71885 L F
.288 .541 .917 r
.73149 .71389 m .7345 .71616 L .73332 .7165 L F
.533 .31 .522 r
.73555 .71823 m .73332 .7165 L .7345 .71616 L F
.73555 .71823 m .73318 .71927 L .73332 .7165 L F
.846 .85 .846 r
.54569 .81381 m .54854 .81281 L .54731 .81295 L F
.649 .465 .622 r
.54677 .81031 m .55016 .81119 L .54854 .81281 L F
.54934 .81246 m .54946 .81256 L .55016 .81119 L F
0 0 0 r
.55016 .81119 m .54946 .81256 L .55006 .81144 L F
.55016 .81119 m .55142 .80891 L .55258 .81179 L F
.55016 .81119 m .55006 .81144 L .55142 .80891 L F
.124 .673 .728 r
.54987 .81207 m .54982 .8121 L .55016 .81119 L F
.54943 .81232 m .54854 .81281 L .55016 .81119 L F
.649 .465 .622 r
.54677 .81031 m .54934 .81246 L .55016 .81119 L F
.807 .723 .772 r
.55142 .80891 m .55006 .81144 L .5477 .8087 L F
.55006 .81144 m .54946 .81256 L .5494 .81242 L F
.124 .673 .728 r
.55006 .81144 m .54943 .81232 L .55016 .81119 L F
.54948 .81229 m .54943 .81232 L .55006 .81144 L F
.807 .723 .772 r
.55006 .81144 m .5494 .81242 L .5477 .8087 L F
.124 .673 .728 r
.54982 .8121 m .54948 .81229 L .55006 .81144 L F
.28 .432 .836 r
.5477 .8087 m .5494 .81242 L .54677 .81031 L F
.5494 .81242 m .54946 .81256 L .54934 .81246 L F
.5494 .81242 m .54934 .81246 L .54677 .81031 L F
.124 .673 .728 r
.5497 .81259 m .54896 .81273 L .54987 .81207 L F
.54896 .81273 m .54854 .81281 L .54987 .81207 L F
.5497 .81259 m .54731 .81295 L .54854 .81281 L F
.826 .81 .835 r
.54499 .81025 m .54272 .81056 L .54401 .80942 L F
.302 .684 .976 r
.54401 .80942 m .54677 .81031 L .54499 .81025 L F
.596 .867 .993 r
.50533 .88625 m .50814 .88613 L .50755 .88479 L F
.693 .937 .964 r
.50814 .88613 m .50991 .88443 L .50755 .88479 L F
.50814 .88613 m .51114 .88478 L .50991 .88443 L F
.578 .382 .579 r
.36291 .76697 m .36064 .76953 L .36081 .76732 L F
.778 .658 .731 r
.6865 .73001 m .68415 .73261 L .68274 .72969 L F
.894 .799 .747 r
.68509 .72922 m .68586 .73202 L .6865 .73001 L F
.824 .915 .899 r
.68402 .73495 m .68586 .73202 L .68415 .73261 L F
.894 .799 .747 r
.68509 .72922 m .68586 .73202 L .6865 .73001 L F
.432 .187 .441 r
.35485 .69399 m .35216 .69617 L .35282 .69467 L F
.353 .423 .795 r
.36891 .67334 m .36869 .67653 L .36705 .67402 L F
.36891 .67334 m .36986 .6759 L .36869 .67653 L F
.482 .262 .503 r
.37022 .67826 m .36869 .67653 L .36986 .6759 L F
.37022 .67826 m .36824 .67878 L .36869 .67653 L F
.79 .829 .882 r
.70867 .60297 m .70513 .60392 L .70794 .60192 L F
.663 .846 .97 r
.71046 .60217 m .70867 .60297 L .70794 .60192 L F
.313 .123 .456 r
.71193 .70789 m .71424 .70626 L .71275 .70772 L F
.84 .994 .847 r
.68162 .7089 m .67902 .71063 L .6807 .70807 L F
.598 .443 .643 r
.49271 .86864 m .49464 .87105 L .4915 .87129 L F
.664 .49 .639 r
.4915 .87129 m .49376 .87128 L .49464 .87105 L F
.202 0 0 r
.49464 .87105 m .49376 .87128 L .4915 .87129 L F
.49464 .87105 m .49376 .87128 L .4915 .87129 L F
.472 .304 .571 r
.4915 .87129 m .49376 .87128 L .49271 .86864 L F
.781 .455 .436 r
.49271 .86864 m .49376 .87128 L .49464 .87105 L F
.371 .675 .975 r
.32949 .67559 m .33205 .67552 L .32818 .67506 L F
.32949 .67559 m .33215 .67639 L .33205 .67552 L F
.957 .75 .583 r
.71939 .71123 m .71655 .71028 L .71448 .71297 L F
.27 0 0 r
.71448 .71297 m .71939 .71123 L .71591 .71411 L F
.71448 .71297 m .71698 .71269 L .71939 .71123 L F
.957 .75 .583 r
.71939 .71123 m .71698 .71269 L .71655 .71028 L F
0 0 0 r
.67493 .59356 m .67327 .5961 L .67458 .59492 L F
.67493 .59356 m .67458 .59492 L .674 .59289 L F
.864 .945 .868 r
.67764 .5907 m .67493 .59356 L .674 .59289 L F
.888 .896 .829 r
.68627 .72126 m .68732 .72197 L .68936 .71929 L F
.983 .785 .56 r
.68627 .72126 m .6871 .72414 L .68732 .72197 L F
.648 .464 .621 r
.72086 .70341 m .72265 .70553 L .72011 .70608 L F
0 .123 .67 r
.72254 .70461 m .72086 .70341 L .72157 .70227 L F
.72254 .70461 m .72265 .70553 L .72086 .70341 L F
.542 .928 .876 r
.70364 .62984 m .70455 .62909 L .7055 .6284 L F
.173 0 0 r
.7055 .6284 m .70675 .62885 L .70776 .62795 L F
.7055 .6284 m .70455 .62909 L .70675 .62885 L F
.857 .97 .868 r
.6382 .59266 m .6414 .59075 L .63932 .59356 L F
.6382 .59266 m .64062 .59014 L .6414 .59075 L F
.752 .883 .939 r
.64286 .5882 m .6414 .59075 L .64062 .59014 L F
.64286 .5882 m .6441 .58898 L .6414 .59075 L F
.364 .327 .684 r
.4772 .85506 m .47861 .85532 L .47817 .85181 L F
.696 .372 .423 r
.56036 .80504 m .557 .80658 L .55842 .8041 L F
.56036 .80504 m .55926 .80712 L .557 .80658 L F
.517 .174 .325 r
.56277 .80519 m .55926 .80712 L .56036 .80504 L F
.144 0 0 r
.72635 .72495 m .72517 .72475 L .72331 .72439 L F
.479 .888 .935 r
.72833 .72375 m .72635 .72495 L .72933 .72458 L F
.72833 .72375 m .72517 .72475 L .72635 .72495 L F
.544 .501 .759 r
.46629 .7343 m .46739 .73798 L .46521 .73815 L F
.577 .84 .995 r
.42897 .72502 m .42574 .72483 L .42771 .72444 L F
.204 .669 .942 r
.42987 .72457 m .42897 .72502 L .42771 .72444 L F
.42987 .72457 m .4311 .7252 L .42897 .72502 L F
.756 .754 .85 r
.62673 .62535 m .62329 .625 L .62557 .62219 L F
.62673 .62535 m .62471 .62609 L .62329 .625 L F
.764 .685 .775 r
.62889 .62261 m .62673 .62535 L .62557 .62219 L F
.795 .736 .798 r
.71662 .71644 m .71419 .71619 L .71591 .71411 L F
.817 .575 .572 r
.71662 .71644 m .7138 .71811 L .71419 .71619 L F
.71662 .71644 m .71663 .71917 L .7138 .71811 L F
.596 .394 .578 r
.71889 .71849 m .71663 .71917 L .71662 .71644 L F
.684 .372 .44 r
.71662 .71644 m .71948 .71689 L .71889 .71849 L F
.776 .704 .783 r
.63025 .615 m .63113 .61778 L .62797 .61773 L F
.783 .641 .704 r
.62797 .61773 m .63113 .61778 L .63094 .61993 L F
.802 .982 .896 r
.63978 .62038 m .63898 .62003 L .6364 .62219 L F
.754 .969 .691 r
.64199 .61782 m .64074 .61857 L .63978 .62038 L F
.738 .973 .927 r
.63978 .62038 m .64074 .61857 L .63898 .62003 L F
.643 .383 .511 r
.4897 .76198 m .48964 .76403 L .4874 .76382 L F
.384 .194 .495 r
.49182 .75902 m .49148 .76154 L .4897 .76198 L F
.375 .17 .468 r
.49148 .76154 m .48964 .76403 L .4897 .76198 L F
.443 .012 .124 r
.71478 .6072 m .71198 .60812 L .71164 .60796 L F
.751 .65 .75 r
.55842 .8041 m .55494 .80458 L .55721 .80217 L F
.531 .42 .673 r
.557 .80658 m .55494 .80458 L .55842 .8041 L F
.509 .704 .958 r
.45612 .72936 m .45522 .73091 L .45404 .72962 L F
.45612 .72936 m .45768 .73096 L .45522 .73091 L F
.253 0 .184 r
.64622 .64036 m .64876 .63849 L .64702 .6396 L F
.546 .146 .235 r
.64613 .60531 m .64517 .60347 L .64448 .60637 L F
.467 .119 .292 r
.65494 .60153 m .65215 .60269 L .65252 .60206 L F
.65494 .60153 m .65429 .60347 L .65215 .60269 L F
.456 .16 .374 r
.65215 .60269 m .65395 .60507 L .65184 .60397 L F
.65222 .60278 m .65429 .60347 L .65395 .60507 L F
.65215 .60269 m .65224 .60272 L .65222 .60278 L F
.65224 .60272 m .65429 .60347 L .65222 .60278 L F
0 0 0 r
.65254 .60203 m .65184 .60397 L .65368 .60039 L F
.65252 .60206 m .65249 .60214 L .65254 .60203 L F
.65249 .60214 m .65184 .60397 L .65254 .60203 L F
.857 .826 .816 r
.64136 .63648 m .64137 .63633 L .64276 .63393 L F
.811 .756 .801 r
.64137 .63633 m .6433 .63647 L .64276 .63393 L F
.322 .807 .868 r
.6455 .63595 m .64464 .6359 L .6433 .63647 L F
.599 .188 .235 r
.69874 .60975 m .69818 .61089 L .69551 .61007 L F
.667 .574 .742 r
.35885 .78727 m .35663 .78841 L .35566 .78534 L F
.66 .524 .687 r
.35431 .77785 m .35217 .78056 L .35269 .77883 L F
.714 .773 .899 r
.68787 .70054 m .68467 .70018 L .6871 .69914 L F
.567 .72 .945 r
.68877 .69896 m .68787 .70054 L .6871 .69914 L F
.68877 .69896 m .69013 .70022 L .68787 .70054 L F
.285 .188 .566 r
.4098 .74274 m .40848 .74591 L .408 .74411 L F
.529 .692 .943 r
.4464 .74126 m .44752 .7399 L .44574 .73983 L F
.4464 .74126 m .44838 .74096 L .44752 .7399 L F
.673 .408 .512 r
.61731 .65775 m .61387 .65965 L .6136 .65752 L F
.61731 .65775 m .61756 .65998 L .61387 .65965 L F
.728 .448 .503 r
.62074 .65987 m .61756 .65998 L .61731 .65775 L F
.356 0 0 r
.39723 .72415 m .39937 .72397 L .40055 .72269 L F
.403 0 .021 r
.40055 .72269 m .39937 .72397 L .40256 .72304 L F
.717 .33 .315 r
.63846 .64292 m .63894 .64162 L .63886 .64104 L F
.63846 .64292 m .64126 .64165 L .63894 .64162 L F
.442 .212 .468 r
.34872 .6993 m .34793 .70268 L .3461 .70315 L F
.464 .232 .476 r
.34996 .70216 m .34872 .6993 L .3504 .7 L F
.34996 .70216 m .34793 .70268 L .34872 .6993 L F
.225 0 0 r
.44282 .77506 m .44102 .77705 L .43941 .77726 L F
.267 0 0 r
.44351 .7764 m .44282 .77506 L .44508 .77523 L F
.44351 .7764 m .44102 .77705 L .44282 .77506 L F
.366 .21 .534 r
.48315 .85187 m .4818 .84987 L .48257 .84947 L F
.48315 .85187 m .48164 .85241 L .4818 .84987 L F
.888 .896 .829 r
.68627 .72126 m .68936 .71929 L .68843 .71862 L F
.993 .797 .54 r
.68859 .71606 m .68936 .71929 L .69139 .71661 L F
.68859 .71606 m .68843 .71862 L .68936 .71929 L F
.696 .161 0 r
.50352 .87544 m .50534 .8761 L .5031 .87424 L F
.982 .855 .638 r
.54311 .83816 m .54327 .84178 L .54348 .83944 L F
.263 .767 .867 r
.56246 .78841 m .56439 .78805 L .56532 .78804 L F
.668 .465 .601 r
.56246 .78841 m .56588 .79073 L .56439 .78805 L F
.56246 .78841 m .56237 .79124 L .56588 .79073 L F
.254 .68 .963 r
.44741 .72862 m .44675 .72926 L .44545 .72823 L F
.44741 .72862 m .44868 .72938 L .44675 .72926 L F
.671 .54 .696 r
.35424 .77979 m .35217 .78056 L .35431 .77785 L F
.435 .076 .256 r
.39226 .74887 m .39178 .75023 L .38974 .75051 L F
.487 .146 .314 r
.39642 .7469 m .39178 .75023 L .39226 .74887 L F
.966 .921 .586 r
.4915 .87129 m .49061 .87231 L .49067 .87365 L F
.664 .49 .639 r
.49067 .87365 m .49134 .87271 L .4915 .87129 L F
.4915 .87129 m .49134 .87271 L .49067 .87365 L F
.474 .251 .494 r
.49067 .87365 m .49125 .87624 L .49134 .87271 L F
.49067 .87365 m .49125 .87624 L .49134 .87271 L F
.966 .921 .586 r
.49067 .87365 m .4915 .87129 L .49376 .87128 L F
.49067 .87365 m .49061 .87231 L .4915 .87129 L F
.664 .49 .639 r
.4915 .87129 m .49067 .87365 L .49376 .87128 L F
.47 .288 .551 r
.49376 .87128 m .49067 .87365 L .4915 .87129 L F
.622 .884 .554 r
.70083 .6135 m .69974 .6149 L .70164 .61314 L F
.70083 .6135 m .69976 .61472 L .69974 .6149 L F
.508 .89 .709 r
.69976 .61472 m .698 .61583 L .69974 .6149 L F
.931 .852 .742 r
.6382 .59266 m .63932 .59356 L .63806 .59629 L F
.65 .596 .781 r
.69658 .60126 m .69419 .60188 L .69306 .59871 L F
.673 .775 .926 r
.67675 .60112 m .68021 .60157 L .67865 .60016 L F
.765 .64 .723 r
.67675 .60112 m .67804 .60376 L .68021 .60157 L F
.569 .594 .839 r
.68021 .60157 m .68111 .59806 L .67865 .60016 L F
.68021 .60157 m .68224 .60115 L .68111 .59806 L F
.273 .342 .752 r
.68021 .60157 m .68249 .6037 L .68224 .60115 L F
.599 .315 .457 r
.47874 .76448 m .47633 .76658 L .47663 .76436 L F
.744 .602 .699 r
.62024 .63357 m .6217 .63684 L .61827 .63633 L F
.354 0 .183 r
.64377 .60154 m .64332 .60343 L .6408 .60387 L F
.74 .636 .744 r
.64485 .59976 m .64391 .59491 L .64175 .59772 L F
.353 .368 .736 r
.64485 .59976 m .64619 .59668 L .64391 .59491 L F
.061 .033 .509 r
.64515 .59977 m .64619 .59668 L .64485 .59976 L F
.664 .94 .675 r
.64553 .5998 m .64515 .59976 L .64497 .60034 L F
.64611 .59921 m .64537 .59964 L .64553 .5998 L F
.64537 .59964 m .64515 .59976 L .64553 .5998 L F
0 .29 .683 r
.64288 .59819 m .64518 .59945 L .64175 .59772 L F
.061 .033 .509 r
.64582 .59979 m .64594 .59873 L .64515 .59977 L F
0 .29 .683 r
.64518 .59945 m .64582 .59979 L .64523 .59949 L F
.64518 .59945 m .64523 .59949 L .64175 .59772 L F
.061 .033 .509 r
.64594 .59873 m .64619 .59668 L .64515 .59977 L F
.664 .94 .675 r
.64515 .59976 m .64515 .59976 L .64515 .59977 L F
.64515 .59976 m .64515 .59977 L .64497 .60034 L F
.019 .449 .87 r
.64175 .59772 m .64523 .59949 L .64485 .59976 L F
.211 0 0 r
.64611 .59921 m .64731 .59983 L .6457 .59989 L F
.019 .449 .87 r
.64515 .59976 m .64518 .59977 L .64515 .59977 L F
.211 0 0 r
.64515 .59976 m .6457 .59989 L .64488 .59992 L F
.64611 .59921 m .6457 .59989 L .64515 .59976 L F
.019 .449 .87 r
.64523 .59949 m .64582 .59979 L .64518 .59977 L F
.64523 .59949 m .64518 .59977 L .64515 .59976 L F
.64523 .59949 m .64515 .59977 L .64485 .59976 L F
.664 .94 .675 r
.64497 .60034 m .64488 .59992 L .64377 .60154 L F
.64515 .59976 m .64488 .59992 L .64497 .60034 L F
0 0 .218 r
.64377 .60154 m .64462 .60202 L .64332 .60343 L F
.64377 .60154 m .64488 .59992 L .64462 .60202 L F
.777 .834 .896 r
.50218 .88672 m .5035 .88775 L .50533 .88625 L F
.492 .171 .349 r
.63619 .65552 m .63583 .65697 L .63366 .65729 L F
.251 0 .057 r
.63944 .65472 m .63583 .65697 L .63619 .65552 L F
.487 .146 .314 r
.39642 .7469 m .39395 .7499 L .39178 .75023 L F
.382 0 .142 r
.39741 .74751 m .39395 .7499 L .39642 .7469 L F
.048 .338 .817 r
.70426 .70282 m .70628 .70527 L .7059 .7031 L F
.78 .621 .684 r
.57342 .80389 m .57691 .80207 L .57608 .80214 L F
.57342 .80389 m .57447 .80431 L .57691 .80207 L F
.78 .998 .821 r
.57728 .80082 m .57608 .80214 L .57691 .80207 L F
.226 0 .247 r
.32337 .72957 m .32102 .73189 L .32158 .72979 L F
.393 .06 .277 r
.35389 .74009 m .35582 .73975 L .35675 .73765 L F
.298 0 .229 r
.35675 .73765 m .35758 .73915 L .35921 .7377 L F
.35675 .73765 m .35582 .73975 L .35758 .73915 L F
.365 .114 .394 r
.32764 .70602 m .32885 .7074 L .32943 .70546 L F
.32764 .70602 m .32711 .70809 L .32885 .7074 L F
.714 .666 .802 r
.53598 .85785 m .53748 .8546 L .53501 .85502 L F
.53598 .85785 m .53684 .85713 L .53748 .8546 L F
.932 .645 .475 r
.53466 .85973 m .5363 .86071 L .53598 .85785 L F
.77 .719 .805 r
.71979 .71962 m .71663 .71917 L .71889 .71849 L F
.377 .744 .991 r
.72145 .7189 m .71979 .71962 L .71889 .71849 L F
.72145 .7189 m .72203 .71961 L .71979 .71962 L F
.465 .07 .205 r
.64618 .65174 m .6434 .65372 L .64365 .65285 L F
.64618 .65174 m .6455 .65354 L .6434 .65372 L F
.265 0 .127 r
.64618 .65174 m .64825 .65175 L .6455 .65354 L F
.922 .912 .792 r
.68245 .62547 m .6797 .62752 L .68002 .62524 L F
.68245 .62547 m .68058 .62832 L .6797 .62752 L F
.955 .698 .247 r
.67344 .59851 m .67291 .59816 L .67327 .5961 L F
0 0 .022 r
.67327 .5961 m .67291 .59816 L .67458 .59492 L F
.178 .308 .76 r
.5323 .82883 m .5332 .82772 L .53096 .82814 L F
.632 .474 .651 r
.53494 .82558 m .53532 .8292 L .5323 .82883 L F
.616 .282 .382 r
.53532 .8292 m .53474 .83081 L .5323 .82883 L F
.178 .308 .76 r
.5323 .82883 m .53474 .83081 L .5332 .82772 L F
.285 .188 .566 r
.4098 .74274 m .40973 .74538 L .40848 .74591 L F
.314 .257 .633 r
.40973 .74538 m .41069 .74758 L .40848 .74591 L F
.762 .477 .502 r
.51414 .8803 m .5137 .87902 L .51394 .8777 L F
.5137 .87902 m .51269 .87607 L .51394 .8777 L F
.589 .125 .119 r
.51394 .8777 m .51048 .87677 L .513 .87814 L F
.779 .546 .583 r
.513 .87814 m .51398 .87749 L .51394 .8777 L F
.51398 .87749 m .51629 .87596 L .51394 .8777 L F
.589 .125 .119 r
.51394 .8777 m .51269 .87607 L .51048 .87677 L F
.55 .558 .815 r
.35997 .67041 m .35939 .67386 L .35823 .6707 L F
.35997 .67041 m .36128 .67357 L .35939 .67386 L F
0 .093 .65 r
.33215 .67639 m .33249 .67584 L .33205 .67552 L F
.587 .333 .499 r
.33444 .67623 m .33405 .67826 L .33215 .67639 L F
0 .169 .706 r
.33215 .67639 m .33405 .67826 L .33249 .67584 L F
.569 .27 .422 r
.42712 .77141 m .42977 .76974 L .42773 .77018 L F
.262 .757 .692 r
.36302 .8064 m .36303 .8064 L .36378 .80611 L F
.36303 .8064 m .36588 .80541 L .36378 .80611 L F
0 0 .205 r
.36514 .80548 m .36378 .80611 L .36502 .80563 L F
0 0 .131 r
.36504 .80562 m .36378 .80611 L .36514 .80548 L F
.152 0 0 r
.36588 .80541 m .36415 .80675 L .36378 .80611 L F
0 0 .205 r
.36502 .80563 m .36378 .80611 L .36415 .80675 L F
0 0 .131 r
.36332 .80815 m .36378 .80611 L .36504 .80562 L F
.262 .757 .692 r
.36244 .8066 m .36302 .8064 L .36378 .80611 L F
.152 0 0 r
.36588 .80541 m .36801 .80511 L .36415 .80675 L F
.173 0 0 r
.39457 .79535 m .39414 .79453 L .39632 .79403 L F
.39457 .79535 m .39256 .79577 L .39414 .79453 L F
0 .042 .57 r
.67329 .60971 m .67393 .61129 L .67502 .61037 L F
0 0 0 r
.65841 .6172 m .66022 .61676 L .66091 .61505 L F
.65841 .6172 m .65774 .61764 L .66022 .61676 L F
.284 .555 .927 r
.66022 .61676 m .65841 .6172 L .65774 .61764 L F
.573 .149 .2 r
.35031 .81241 m .3535 .81208 L .35256 .81296 L F
.317 0 0 r
.3535 .81208 m .35497 .81261 L .35256 .81296 L F
.3535 .81208 m .35564 .81199 L .35497 .81261 L F
.581 .599 .835 r
.4557 .74561 m .45643 .74226 L .45429 .74296 L F
.4557 .74561 m .45786 .74534 L .45643 .74226 L F
.503 .431 .709 r
.4557 .74561 m .45791 .74741 L .45786 .74534 L F
.4557 .74561 m .45633 .74913 L .45791 .74741 L F
.097 0 .428 r
.67782 .63469 m .67676 .63374 L .67727 .63319 L F
.67782 .63469 m .67648 .63625 L .67676 .63374 L F
.611 .649 .863 r
.64823 .58699 m .64698 .58934 L .64595 .58779 L F
.64823 .58699 m .64908 .58872 L .64698 .58934 L F
.818 .746 .785 r
.61949 .63074 m .62193 .62755 L .62233 .6309 L F
.818 .746 .784 r
.61949 .63074 m .62233 .6309 L .62024 .63357 L F
.781 .673 .744 r
.53895 .84962 m .5421 .84962 L .54097 .84684 L F
.781 .667 .737 r
.53895 .84962 m .5402 .85252 L .5421 .84962 L F
.505 .872 .982 r
.64613 .60531 m .64954 .60522 L .64705 .60327 L F
.454 .019 .121 r
.3786 .72923 m .38081 .72916 L .38216 .72754 L F
.397 0 .069 r
.38081 .72916 m .38434 .72739 L .38216 .72754 L F
.421 .027 .183 r
.42414 .78237 m .4208 .78472 L .42212 .783 L F
.671 .6 .768 r
.47756 .74767 m .47643 .7512 L .47547 .74815 L F
.47756 .74767 m .47869 .75073 L .47643 .7512 L F
.568 .341 .531 r
.33828 .75622 m .34042 .75604 L .34063 .75375 L F
.498 .347 .607 r
.34063 .75375 m .34252 .7534 L .34267 .75104 L F
.596 .422 .617 r
.34042 .75604 m .34252 .7534 L .34063 .75375 L F
.701 .357 .39 r
.5332 .82772 m .53494 .82558 L .53311 .82575 L F
.701 .525 .646 r
.53785 .8279 m .53532 .8292 L .53494 .82558 L F
.701 .357 .39 r
.5332 .82772 m .53645 .82786 L .53494 .82558 L F
.701 .525 .646 r
.53785 .8279 m .53494 .82558 L .53645 .82786 L F
.825 .768 .799 r
.65649 .60832 m .65664 .60929 L .65493 .60878 L F
.861 .524 .413 r
.65664 .60929 m .6562 .61135 L .65501 .60896 L F
.65664 .60929 m .65501 .60896 L .65515 .60885 L F
.559 .588 .84 r
.65885 .60803 m .65664 .60929 L .65649 .60832 L F
.482 .844 .992 r
.6562 .61135 m .65323 .61018 L .65493 .60878 L F
.273 0 0 r
.65649 .60832 m .65405 .60971 L .65885 .60803 L F
.65405 .60971 m .65323 .61018 L .65366 .61001 L F
.65405 .60971 m .65366 .61001 L .65885 .60803 L F
.861 .524 .413 r
.65515 .60885 m .65501 .60896 L .65493 .60878 L F
.559 .588 .84 r
.65885 .60803 m .65925 .60879 L .65664 .60929 L F
.257 0 .259 r
.65876 .60956 m .65664 .60929 L .65925 .60879 L F
.65876 .60956 m .6562 .61135 L .65664 .60929 L F
.912 .927 .811 r
.48372 .8863 m .48427 .88621 L .48279 .88626 L F
.643 .084 0 r
.48427 .88621 m .48449 .88701 L .48279 .88626 L F
.48427 .88621 m .48573 .88744 L .48449 .88701 L F
.546 .495 .75 r
.35738 .7828 m .35542 .78318 L .35424 .77979 L F
.632 .566 .762 r
.35738 .7828 m .35566 .78534 L .35542 .78318 L F
.633 .637 .836 r
.7251 .7197 m .72326 .72182 L .72203 .71961 L F
.678 .534 .682 r
.55721 .80217 m .55494 .80458 L .55406 .80177 L F
.412 .046 .23 r
.38457 .75133 m .38363 .75337 L .38144 .75376 L F
.335 0 .193 r
.38555 .7527 m .38457 .75133 L .38659 .7513 L F
.38555 .7527 m .38363 .75337 L .38457 .75133 L F
.912 .75 .667 r
.66418 .60973 m .66168 .61111 L .66155 .60896 L F
.66418 .60973 m .66301 .61247 L .66168 .61111 L F
.526 .75 .978 r
.43862 .7261 m .43782 .72755 L .43652 .72656 L F
.43862 .7261 m .43987 .72728 L .43782 .72755 L F
.769 .62 .695 r
.67453 .60161 m .6723 .60635 L .67133 .60119 L F
.636 .744 .927 r
.67373 .60004 m .67453 .60161 L .67675 .60112 L F
.585 .122 0 r
.67524 .6026 m .67453 .60161 L .67373 .60004 L F
.67524 .6026 m .67635 .60396 L .67453 .60161 L F
.866 .671 .637 r
.67635 .60396 m .67675 .60112 L .67453 .60161 L F
.789 .696 .762 r
.67965 .61477 m .67803 .61763 L .67503 .61712 L F
.914 .851 .766 r
.67803 .61763 m .6752 .61953 L .67503 .61712 L F
.67803 .61763 m .67643 .62085 L .6752 .61953 L F
.733 .488 .558 r
.34754 .83959 m .35032 .83837 L .34656 .83894 L F
.34754 .83959 m .35032 .83837 L .34656 .83894 L F
0 0 .493 r
.35002 .83778 m .35032 .83837 L .34754 .83959 L F
.35002 .83778 m .35092 .83936 L .35032 .83837 L F
.886 .507 .316 r
.35032 .83837 m .34934 .83929 L .34754 .83959 L F
.35032 .83837 m .35092 .83936 L .34934 .83929 L F
.808 .741 .789 r
.62024 .63357 m .61696 .63369 L .61949 .63074 L F
.813 .705 .746 r
.62024 .63357 m .61827 .63633 L .61696 .63369 L F
.533 .558 .826 r
.48212 .85991 m .48155 .86315 L .48054 .86028 L F
.48212 .85991 m .48326 .86284 L .48155 .86315 L F
.269 .273 .679 r
.48255 .86234 m .48054 .86028 L .48212 .85991 L F
0 0 .13 r
.48227 .86241 m .48155 .86315 L .48326 .86284 L F
.269 .273 .679 r
.48227 .86241 m .48227 .86241 L .48054 .86028 L F
.48227 .86241 m .48149 .86276 L .48149 .86276 L F
.48227 .86241 m .48149 .86276 L .48054 .86028 L F
.415 .807 .987 r
.48227 .86241 m .48148 .86208 L .48226 .86241 L F
0 0 .326 r
.48427 .85963 m .48326 .86284 L .48212 .85991 L F
.48427 .85963 m .48421 .862 L .48326 .86284 L F
.415 .807 .987 r
.48421 .862 m .48382 .86201 L .48306 .86275 L F
.48382 .86201 m .48226 .86241 L .48306 .86275 L F
.477 .354 .634 r
.48421 .862 m .48264 .86286 L .48255 .86234 L F
.48421 .862 m .48255 .86234 L .48212 .85991 L F
.415 .807 .987 r
.48382 .86201 m .48314 .86203 L .48234 .86238 L F
.269 .273 .679 r
.48227 .86241 m .48054 .86028 L .48255 .86234 L F
.415 .807 .987 r
.48255 .86234 m .48234 .86238 L .48227 .86241 L F
.48382 .86201 m .48234 .86238 L .48255 .86234 L F
.48314 .86203 m .48148 .86208 L .48227 .86241 L F
0 0 .13 r
.48148 .86208 m .48153 .86274 L .48227 .86241 L F
.48153 .86274 m .48155 .86315 L .48227 .86241 L F
.269 .273 .679 r
.48264 .86286 m .48192 .86388 L .48149 .86276 L F
.48264 .86286 m .48149 .86276 L .48227 .86241 L F
.48264 .86286 m .48227 .86241 L .48255 .86234 L F
.415 .807 .987 r
.48347 .86264 m .48306 .86275 L .48326 .86284 L F
.48421 .862 m .48306 .86275 L .48347 .86264 L F
.533 .558 .826 r
.48155 .86315 m .48155 .86315 L .48155 .86315 L F
.48155 .86315 m .48155 .86315 L .48054 .86028 L F
.744 .531 .606 r
.47732 .86225 m .48167 .86379 L .48054 .86028 L F
.48167 .86379 m .48192 .86388 L .48155 .86291 L F
.48167 .86379 m .48155 .86291 L .48054 .86028 L F
0 0 .13 r
.48153 .86276 m .48193 .86578 L .48155 .86315 L F
.457 .063 .203 r
.47771 .86569 m .4817 .86397 L .47732 .86225 L F
.4817 .86397 m .48192 .86388 L .48167 .86379 L F
.4817 .86397 m .48167 .86379 L .47732 .86225 L F
.47771 .86569 m .48008 .86541 L .48171 .86405 L F
.4817 .86397 m .48171 .86405 L .48192 .86388 L F
.47771 .86569 m .48171 .86405 L .4817 .86397 L F
.934 .913 .773 r
.48192 .86388 m .48171 .86405 L .48148 .86208 L F
0 0 .13 r
.48148 .86208 m .4817 .86399 L .48167 .86379 L F
.48175 .86425 m .4817 .86399 L .48167 .86379 L F
.48153 .86271 m .48167 .86379 L .48153 .86276 L F
.48148 .86208 m .48167 .86379 L .48153 .86271 L F
.934 .913 .773 r
.48171 .86405 m .48008 .86541 L .48148 .86208 L F
0 0 .13 r
.48148 .86208 m .48175 .86425 L .4817 .86399 L F
.48175 .86425 m .48179 .8646 L .4817 .86399 L F
.48179 .8646 m .48193 .86578 L .48153 .86276 L F
.889 .761 .714 r
.57515 .81467 m .57372 .81769 L .57579 .81726 L F
.89 .793 .747 r
.57372 .81769 m .57457 .82037 L .57579 .81726 L F
.404 .186 .466 r
.32999 .70307 m .33119 .70484 L .3313 .70244 L F
.32999 .70307 m .32943 .70546 L .33119 .70484 L F
.704 .832 .943 r
.69372 .63847 m .6904 .63842 L .69299 .63718 L F
.796 .59 .622 r
.69372 .63847 m .6904 .64079 L .6904 .63842 L F
.69372 .63847 m .69367 .64126 L .6904 .64079 L F
0 .517 .807 r
.69299 .63718 m .69598 .638 L .69372 .63847 L F
.623 .392 .547 r
.6228 .65766 m .62283 .65975 L .62074 .65987 L F
.67 .429 .547 r
.6228 .65766 m .62501 .65994 L .62283 .65975 L F
.6228 .65766 m .6277 .65752 L .62501 .65994 L F
.591 .544 .771 r
.45633 .74913 m .45916 .7506 L .45791 .74741 L F
.596 .427 .623 r
.32964 .76712 m .33194 .76694 L .33178 .76467 L F
.643 .481 .649 r
.32962 .7695 m .33194 .76694 L .32964 .76712 L F
.95 .607 .323 r
.62511 .62034 m .62416 .62073 L .62474 .61937 L F
.62511 .62034 m .62557 .62219 L .62416 .62073 L F
.911 .978 .781 r
.62511 .62034 m .62666 .61659 L .62797 .61773 L F
.62511 .62034 m .62474 .61937 L .62666 .61659 L F
.797 .705 .763 r
.61747 .64673 m .61837 .64968 L .61575 .64967 L F
.864 .945 .868 r
.67764 .5907 m .674 .59289 L .67659 .58964 L F
.648 .81 .961 r
.67928 .58841 m .67764 .5907 L .67659 .58964 L F
.67928 .58841 m .68026 .58997 L .67764 .5907 L F
.556 .762 .974 r
.31932 .65149 m .3187 .65322 L .31725 .65219 L F
.31932 .65149 m .32073 .6528 L .3187 .65322 L F
.65 .495 .66 r
.47688 .87095 m .4781 .87085 L .47409 .86833 L F
.665 .543 .706 r
.47581 .86556 m .47797 .87054 L .47966 .86981 L F
.604 .513 .725 r
.47767 .87058 m .4781 .87085 L .47783 .87056 L F
.653 .52 .688 r
.47783 .87056 m .4781 .87085 L .47688 .87095 L F
.47966 .86981 m .4781 .87085 L .47783 .87056 L F
.604 .513 .725 r
.47783 .87056 m .4781 .87085 L .47797 .87054 L F
.665 .543 .706 r
.47797 .87054 m .4781 .87085 L .47966 .86981 L F
.653 .52 .688 r
.47932 .87032 m .4772 .87086 L .47909 .87067 L F
.4772 .87086 m .47688 .87095 L .47707 .87092 L F
.4772 .87086 m .47707 .87092 L .47909 .87067 L F
.47966 .86981 m .47783 .87056 L .47932 .87032 L F
.47783 .87056 m .47688 .87095 L .47932 .87032 L F
.604 .513 .725 r
.47409 .86833 m .47767 .87058 L .47581 .86556 L F
.47767 .87058 m .47797 .87054 L .47581 .86556 L F
.4 .089 .319 r
.71889 .71849 m .71948 .71689 L .7214 .71658 L F
.313 .123 .456 r
.71193 .70789 m .71314 .7056 L .71424 .70626 L F
.697 .773 .91 r
.71644 .70549 m .71424 .70626 L .71314 .7056 L F
.684 .563 .713 r
.35682 .7774 m .35431 .77785 L .3563 .77531 L F
.653 .503 .667 r
.35682 .7774 m .35424 .77979 L .35431 .77785 L F
.532 .448 .705 r
.34129 .68116 m .34341 .68082 L .34292 .67855 L F
.615 .549 .757 r
.34206 .6843 m .34341 .68082 L .34129 .68116 L F
.954 .861 .708 r
.40487 .74789 m .40521 .75059 L .40515 .75014 L F
.716 .364 .379 r
.40699 .75143 m .40552 .75214 L .40521 .75059 L F
0 0 .153 r
.40521 .75059 m .40552 .75214 L .40515 .75014 L F
.779 .726 .803 r
.68859 .71606 m .69139 .71661 L .69051 .71405 L F
.68 .652 .815 r
.69139 .71661 m .69258 .71305 L .69051 .71405 L F
.69139 .71661 m .69373 .716 L .69258 .71305 L F
.578 .233 .348 r
.43445 .77822 m .43391 .78013 L .43188 .77983 L F
.352 .028 .269 r
.43602 .77934 m .43445 .77822 L .43732 .7775 L F
.43602 .77934 m .43391 .78013 L .43445 .77822 L F
.588 .476 .693 r
.53501 .85502 m .53748 .8546 L .53695 .85223 L F
.309 0 .063 r
.6579 .63266 m .65624 .63224 L .65544 .63292 L F
.6579 .63266 m .65827 .63186 L .65624 .63224 L F
.453 .583 .893 r
.46629 .7343 m .46453 .73436 L .46291 .73188 L F
.741 .686 .799 r
.70569 .72128 m .70891 .72161 L .70797 .71867 L F
.999 .816 .519 r
.64299 .62467 m .6421 .62496 L .64335 .62302 L F
.281 .323 .728 r
.48715 .75588 m .48774 .75836 L .48655 .75888 L F
.325 .448 .831 r
.48774 .75836 m .4889 .7601 L .48655 .75888 L F
.597 .607 .832 r
.48519 .75617 m .48314 .75675 L .48185 .75367 L F
0 0 .454 r
.47886 .88182 m .48018 .88476 L .47978 .88362 L F
.587 .021 0 r
.48018 .88476 m .48279 .88626 L .48126 .88615 L F
.48018 .88476 m .48126 .88615 L .47978 .88362 L F
.502 0 0 r
.40256 .72304 m .40464 .72347 L .4062 .72264 L F
.28 0 0 r
.40464 .72347 m .40794 .72243 L .4062 .72264 L F
.576 .909 .675 r
.51199 .88381 m .51114 .88478 L .51261 .8835 L F
.519 .881 .981 r
.50991 .88443 m .51114 .88478 L .51199 .88381 L F
.792 .472 .447 r
.70059 .70411 m .70142 .70155 L .70027 .70156 L F
.70142 .70155 m .70146 .70142 L .70132 .70144 L F
.70142 .70155 m .70132 .70144 L .70027 .70156 L F
.728 .223 .028 r
.69811 .69949 m .7012 .70129 L .69871 .70061 L F
.792 .472 .447 r
.70059 .70411 m .70319 .70453 L .70146 .70142 L F
.728 .223 .028 r
.70132 .70144 m .70176 .70162 L .70136 .70149 L F
.514 0 0 r
.70176 .70162 m .70027 .70156 L .70132 .70144 L F
.70176 .70162 m .70132 .70144 L .70146 .70142 L F
.728 .223 .028 r
.7012 .70129 m .70176 .70162 L .70132 .70144 L F
.7012 .70129 m .70136 .70149 L .69871 .70061 L F
.54 .676 .926 r
.6529 .59076 m .64908 .58872 L .65176 .5904 L F
.16 .671 .898 r
.65441 .59068 m .6529 .59076 L .65176 .5904 L F
.528 .501 .77 r
.65505 .59127 m .6529 .59076 L .65441 .59068 L F
.51 .182 .347 r
.36115 .73715 m .36331 .73697 L .36433 .73465 L F
.405 .079 .295 r
.36433 .73465 m .36529 .7365 L .3665 .73457 L F
.36433 .73465 m .36331 .73697 L .36529 .7365 L F
.674 .74 .9 r
.68024 .61308 m .68019 .61492 L .68088 .61462 L F
.252 .469 .875 r
.68019 .61492 m .6841 .61801 L .68346 .61784 L F
.493 0 0 r
.68095 .61566 m .6841 .61801 L .68097 .61553 L F
.68095 .61566 m .68097 .61553 L .68019 .61492 L F
.848 .868 .856 r
.68166 .61157 m .68088 .61462 L .68287 .61236 L F
0 0 .218 r
.68095 .61566 m .68078 .61493 L .6825 .61212 L F
.68095 .61566 m .6825 .61212 L .68113 .61518 L F
0 0 0 r
.68094 .61576 m .68095 .61566 L .68113 .61518 L F
.972 .659 .298 r
.6804 .61737 m .68154 .61898 L .68095 .61566 L F
0 0 0 r
.6804 .61737 m .68095 .61566 L .68094 .61576 L F
.493 0 0 r
.68095 .61566 m .68019 .61492 L .68024 .61308 L F
.388 0 .161 r
.33677 .67495 m .33648 .67598 L .33444 .67623 L F
.397 .843 .928 r
.34015 .67555 m .33648 .67598 L .33677 .67495 L F
.71 .704 .842 r
.57139 .81997 m .57457 .82037 L .57372 .81769 L F
.718 .524 .627 r
.60862 .65746 m .60658 .65979 L .60634 .6575 L F
.60862 .65746 m .60895 .66041 L .60658 .65979 L F
.693 .506 .63 r
.61197 .66003 m .60862 .65746 L .61209 .6577 L F
.61197 .66003 m .60895 .66041 L .60862 .65746 L F
.541 .557 .82 r
.47017 .74009 m .46832 .74063 L .46739 .73798 L F
.468 .599 .9 r
.34292 .82839 m .34326 .82841 L .343 .8285 L F
.076 0 0 r
.343 .8285 m .34326 .82841 L .34291 .8286 L F
.653 .503 .667 r
.35682 .7774 m .35721 .78044 L .35424 .77979 L F
.546 .495 .75 r
.35738 .7828 m .35424 .77979 L .35721 .78044 L F
.809 .686 .728 r
.60755 .65418 m .60563 .6553 L .60759 .65413 L F
.631 .587 .787 r
.60563 .6553 m .60634 .6575 L .60565 .65685 L F
0 0 0 r
.60744 .65511 m .60595 .65655 L .6041 .65839 L F
.60595 .65655 m .60565 .65685 L .6055 .65699 L F
.833 .604 .593 r
.60565 .65685 m .60383 .65967 L .60212 .65894 L F
0 0 0 r
.60595 .65655 m .6055 .65699 L .6041 .65839 L F
.809 .686 .728 r
.60755 .65418 m .60709 .65544 L .60563 .6553 L F
.60709 .65544 m .60634 .6575 L .60601 .65649 L F
.60709 .65544 m .60601 .65649 L .60563 .6553 L F
0 0 0 r
.65105 .6382 m .65273 .63695 L .65349 .63541 L F
.257 .105 .474 r
.65349 .63541 m .65549 .63514 L .65544 .63292 L F
.134 0 0 r
.65273 .63695 m .65549 .63514 L .65349 .63541 L F
.632 .566 .762 r
.35738 .7828 m .35853 .78607 L .35566 .78534 L F
.667 .574 .742 r
.35885 .78727 m .35566 .78534 L .35853 .78607 L F
.821 .488 .424 r
.52988 .82489 m .53146 .82294 L .52956 .82268 L F
.52988 .82489 m .53311 .82575 L .53146 .82294 L F
.519 0 0 r
.35045 .8124 m .35031 .81241 L .34688 .81211 L F
.415 .237 .529 r
.36969 .76606 m .36783 .76445 L .36962 .76381 L F
.36969 .76606 m .36767 .76676 L .36783 .76445 L F
.36 .133 .428 r
.31741 .71581 m .31954 .71315 L .31791 .71369 L F
.522 .642 .909 r
.7152 .60256 m .71401 .60417 L .71235 .60207 L F
.7152 .60256 m .71612 .60389 L .71401 .60417 L F
.659 .595 .773 r
.71612 .60389 m .71478 .6072 L .71401 .60417 L F
.481 .794 .999 r
.32465 .65199 m .32419 .65323 L .32253 .65217 L F
.32465 .65199 m .32606 .65286 L .32419 .65323 L F
.737 .69 .806 r
.53748 .8546 m .53684 .85713 L .53971 .85441 L F
.583 .019 0 r
.54327 .84178 m .54227 .84137 L .5398 .83938 L F
.209 .344 .783 r
.5398 .83938 m .54227 .84137 L .54103 .83828 L F
0 .05 .59 r
.6792 .62669 m .67783 .62555 L .67741 .62411 L F
.6792 .62669 m .6797 .62752 L .67783 .62555 L F
.789 .696 .762 r
.67965 .61477 m .67503 .61712 L .67698 .6146 L F
.982 .693 .358 r
.68058 .62832 m .67985 .62967 L .6797 .62752 L F
.68058 .62832 m .68078 .6304 L .67985 .62967 L F
.661 .381 .485 r
.33328 .69693 m .33561 .69719 L .33592 .69526 L F
.468 .209 .438 r
.33592 .69526 m .33757 .69678 L .3379 .69421 L F
.33592 .69526 m .33561 .69719 L .33757 .69678 L F
.459 .106 .279 r
.65836 .64629 m .6557 .64864 L .65655 .64691 L F
.753 .655 .752 r
.53695 .85223 m .5402 .85252 L .53895 .84962 L F
.761 .556 .621 r
.53971 .85441 m .5402 .85252 L .53695 .85223 L F
.38 .306 .647 r
.47823 .84712 m .47955 .84678 L .47921 .84436 L F
.396 .247 .559 r
.47806 .84941 m .47968 .84925 L .47823 .84712 L F
.67 .635 .806 r
.47412 .74277 m .4718 .74355 L .47017 .74009 L F
.548 .677 .923 r
.51663 .87855 m .51414 .8803 L .51394 .8777 L F
0 .229 .744 r
.51512 .87978 m .51414 .8803 L .51663 .87855 L F
.614 .293 .404 r
.45256 .77214 m .4492 .77428 L .45041 .77222 L F
.615 .549 .757 r
.34206 .6843 m .34438 .68405 L .34341 .68082 L F
.505 .34 .591 r
.34206 .6843 m .34399 .68619 L .34438 .68405 L F
.34206 .6843 m .34206 .68667 L .34399 .68619 L F
.291 0 .277 r
.48005 .84283 m .47865 .84149 L .482 .8417 L F
.78 .635 .7 r
.48166 .83981 m .482 .8417 L .4799 .84157 L F
.47968 .84092 m .4799 .84157 L .47865 .84149 L F
.48166 .83981 m .4799 .84157 L .47968 .84092 L F
.725 .468 .538 r
.48233 .84429 m .48005 .84283 L .482 .8417 L F
.291 0 .277 r
.48018 .84241 m .48125 .84342 L .48051 .84129 L F
.48005 .84283 m .48037 .84299 L .48018 .84241 L F
.48037 .84299 m .48125 .84342 L .48018 .84241 L F
.48005 .84283 m .48051 .84129 L .47865 .84149 L F
.725 .468 .538 r
.48233 .84429 m .47921 .84436 L .48005 .84283 L F
.291 0 .277 r
.48005 .84283 m .47921 .84436 L .48125 .84342 L F
.819 .655 .679 r
.61936 .64166 m .61654 .64144 L .61806 .63857 L F
.808 .665 .706 r
.61936 .64166 m .61593 .64348 L .61654 .64144 L F
.61936 .64166 m .61896 .6439 L .61593 .64348 L F
.549 .375 .597 r
.33178 .76467 m .33407 .76443 L .33399 .76176 L F
.615 .441 .624 r
.33178 .76467 m .3342 .76664 L .33407 .76443 L F
.33178 .76467 m .33194 .76694 L .3342 .76664 L F
.512 .18 .341 r
.45272 .76128 m .45464 .76103 L .45574 .75907 L F
.601 .277 .393 r
.45574 .75907 m .45771 .76077 L .45793 .75884 L F
.45574 .75907 m .45464 .76103 L .45771 .76077 L F
.581 .431 .643 r
.45574 .75907 m .45793 .75884 L .45777 .75635 L F
0 0 .568 r
.67969 .7065 m .6807 .70807 L .67939 .70483 L F
.817 .621 .638 r
.708 .72969 m .70491 .73163 L .707 .72893 L F
.708 .72969 m .70804 .73252 L .70491 .73163 L F
.708 .887 .963 r
.71006 .72868 m .708 .72969 L .707 .72893 L F
.733 .553 .649 r
.71129 .73225 m .70804 .73252 L .708 .72969 L F
.676 .577 .736 r
.72265 .70553 m .72003 .70837 L .72011 .70608 L F
.529 .922 .867 r
.31993 .67479 m .31842 .67496 L .31768 .67582 L F
.372 0 0 r
.56532 .78804 m .56439 .78805 L .56771 .78834 L F
.762 .573 .641 r
.56588 .79073 m .56771 .78834 L .56439 .78805 L F
.56588 .79073 m .56807 .79128 L .56771 .78834 L F
.672 .509 .655 r
.56771 .78834 m .56807 .79128 L .57108 .79076 L F
.211 0 0 r
.64611 .59921 m .64838 .59873 L .64731 .59983 L F
.39 .661 .967 r
.34354 .82728 m .34292 .82839 L .34158 .82677 L F
.34354 .82728 m .34326 .82841 L .34292 .82839 L F
.742 .59 .686 r
.72989 .71678 m .73143 .71885 L .7299 .7182 L F
.104 .562 .913 r
.73143 .71885 m .73198 .71845 L .7299 .7182 L F
.73143 .71885 m .73318 .71927 L .73198 .71845 L F
.931 .852 .742 r
.6382 .59266 m .63806 .59629 L .63654 .59539 L F
.95 .708 .537 r
.63654 .59539 m .63806 .59629 L .63798 .59851 L F
.851 .948 .88 r
.37735 .78264 m .37479 .78511 L .37365 .78473 L F
.126 .66 .862 r
.72778 .72101 m .73086 .72137 L .72908 .72128 L F
.949 .863 .721 r
.72833 .72375 m .73086 .72137 L .72778 .72101 L F
.027 .019 .51 r
.72927 .72258 m .72833 .72375 L .72778 .72101 L F
.72905 .72237 m .72778 .72101 L .72686 .72026 L F
.72927 .72258 m .72778 .72101 L .72905 .72237 L F
.611 .738 .936 r
.72908 .72128 m .72741 .72062 L .72778 .72101 L F
.72741 .72062 m .7251 .7197 L .72778 .72101 L F
.478 .179 .379 r
.44297 .76469 m .44463 .76603 L .44563 .76386 L F
.577 .264 .402 r
.44463 .76603 m .44793 .76362 L .44563 .76386 L F
.59 .548 .776 r
.71869 .61652 m .71982 .62013 L .71745 .62021 L F
.584 .42 .626 r
.72183 .62281 m .72134 .62519 L .71862 .62555 L F
.391 .214 .517 r
.72134 .62519 m .71955 .62755 L .71862 .62555 L F
0 0 0 r
.72465 .72298 m .72331 .72439 L .72517 .72475 L F
.72465 .72298 m .72272 .72542 L .72331 .72439 L F
.575 .219 .328 r
.72331 .72439 m .72237 .72616 L .721 .72468 L F
.95 .902 .518 r
.72331 .72439 m .72213 .72616 L .72237 .72616 L F
0 0 0 r
.72272 .72542 m .72213 .72616 L .72242 .72573 L F
.72272 .72542 m .72242 .72573 L .72331 .72439 L F
.115 .165 .637 r
.72237 .72616 m .72161 .72731 L .72147 .72671 L F
.72219 .72597 m .72147 .72671 L .721 .72468 L F
.72237 .72616 m .72147 .72671 L .72219 .72597 L F
.553 .241 .393 r
.45803 .76966 m .45708 .77222 L .45477 .77231 L F
.543 .23 .388 r
.46006 .77136 m .45803 .76966 L .46015 .76931 L F
.46006 .77136 m .45708 .77222 L .45803 .76966 L F
.492 .746 .985 r
.33347 .65392 m .33287 .6553 L .33149 .65426 L F
.33347 .65392 m .3349 .65508 L .33287 .6553 L F
0 0 0 r
.32251 .71072 m .32385 .71 L .3251 .70861 L F
.169 0 0 r
.32385 .71 m .32711 .70809 L .3251 .70861 L F
.877 .477 .27 r
.48323 .88164 m .48557 .88513 L .48588 .88452 L F
0 0 .543 r
.4833 .88118 m .48557 .88513 L .48323 .88164 L F
.761 .505 .547 r
.57108 .79076 m .57294 .79328 L .57469 .79106 L F
.802 .565 .579 r
.57469 .79106 m .57294 .79328 L .57507 .79352 L F
.524 .515 .787 r
.67441 .61106 m .6712 .61247 L .67025 .60931 L F
.866 .671 .637 r
.67635 .60396 m .67804 .60376 L .67675 .60112 L F
.792 .44 .39 r
.67692 .60567 m .67804 .60376 L .67635 .60396 L F
.718 .348 .347 r
.67692 .60567 m .68011 .60581 L .67804 .60376 L F
.559 .293 .468 r
.37234 .75894 m .37161 .76131 L .3695 .76146 L F
.523 .257 .454 r
.37449 .75852 m .37161 .76131 L .37234 .75894 L F
.829 .728 .753 r
.6364 .62219 m .63461 .62483 L .63732 .62547 L F
.889 .611 .51 r
.63461 .62483 m .63689 .62765 L .63732 .62547 L F
.574 .223 .336 r
.41275 .74145 m .41297 .74287 L .4098 .74274 L F
.561 .214 .338 r
.41486 .74232 m .41297 .74287 L .41275 .74145 L F
.765 .595 .667 r
.6136 .65752 m .61197 .66003 L .61209 .6577 L F
.682 .484 .612 r
.61387 .65965 m .61197 .66003 L .6136 .65752 L F
.64 .518 .699 r
.34502 .74837 m .34729 .74819 L .34693 .74594 L F
.499 .239 .451 r
.34477 .75061 m .34729 .74819 L .34502 .74837 L F
.595 .461 .669 r
.45774 .75401 m .45997 .75599 L .45993 .75362 L F
.45774 .75401 m .45777 .75635 L .45997 .75599 L F
.116 0 .11 r
.51734 .86331 m .51936 .86245 L .51926 .86164 L F
.486 .645 .928 r
.51734 .86331 m .51951 .86356 L .51936 .86245 L F
.432 .187 .441 r
.35485 .69399 m .35439 .69694 L .35216 .69617 L F
.447 .193 .435 r
.35395 .6989 m .35216 .69617 L .35439 .69694 L F
.35395 .6989 m .352 .69942 L .35216 .69617 L F
.699 .77 .907 r
.36923 .78742 m .36752 .78838 L .36623 .78709 L F
.599 .292 .421 r
.4402 .76626 m .44251 .7664 L .44297 .76469 L F
.478 .179 .379 r
.44297 .76469 m .44251 .7664 L .44463 .76603 L F
.688 .599 .751 r
.70324 .60587 m .70107 .60722 L .69977 .60394 L F
.464 .366 .659 r
.47581 .86556 m .47732 .86225 L .4755 .86324 L F
.574 .616 .857 r
.67628 .71089 m .67902 .71063 L .67677 .70805 L F
.573 .368 .565 r
.67628 .71089 m .67618 .71353 L .67867 .71263 L F
.557 .373 .588 r
.67628 .71089 m .67867 .71263 L .67902 .71063 L F
.598 .337 .493 r
.43483 .76894 m .43759 .76693 L .43517 .76713 L F
0 0 0 r
.37093 .80415 m .37005 .80454 L .36801 .80511 L F
.373 .84 .85 r
.37286 .8035 m .37185 .80357 L .37093 .80415 L F
.382 .822 .68 r
.37185 .80357 m .37005 .80454 L .37093 .80415 L F
.826 .595 .589 r
.60658 .65979 m .60565 .65685 L .60634 .6575 L F
.741 .717 .829 r
.73149 .71389 m .72989 .71678 L .72955 .71395 L F
.703 .627 .77 r
.68274 .72969 m .68415 .73261 L .6807 .73231 L F
.811 .654 .688 r
.68415 .73261 m .68168 .7338 L .6807 .73231 L F
.68415 .73261 m .68402 .73495 L .68168 .7338 L F
.955 .685 .486 r
.68274 .72969 m .68415 .73261 L .68305 .73189 L F
.811 .654 .688 r
.68168 .7338 m .68415 .73261 L .68305 .73189 L F
.68168 .7338 m .68402 .73495 L .68415 .73261 L F
.525 .192 .345 r
.36841 .73398 m .37131 .73223 L .36933 .7327 L F
.954 .947 .646 r
.57532 .81234 m .57386 .8138 L .57515 .81467 L F
.57532 .81234 m .5748 .81187 L .57386 .8138 L F
.439 .612 .922 r
.69133 .59424 m .68997 .59568 L .68848 .59394 L F
.69133 .59424 m .69189 .5957 L .68997 .59568 L F
.529 .087 .143 r
.3124 .67632 m .3104 .67784 L .30885 .67777 L F
.3124 .67632 m .31097 .6779 L .3104 .67784 L F
0 0 0 r
.31241 .67703 m .3124 .67632 L .31452 .67645 L F
.31241 .67703 m .31097 .6779 L .3124 .67632 L F
.48588 .88452 m .48839 .8833 L .48826 .88229 L F
.48588 .88452 m .48557 .88513 L .48839 .8833 L F
.39799 .79311 m .40157 .7914 L .40003 .79272 L F
.198 0 0 r
.40003 .79272 m .40157 .7914 L .40363 .79094 L F
.597 .545 .767 r
.47729 .74592 m .47547 .74815 L .47501 .74634 L F
.631 .595 .795 r
.47729 .74592 m .47756 .74767 L .47547 .74815 L F
.367 0 .149 r
.48241 .86828 m .48111 .87035 L .47909 .87067 L F
.972 .805 .617 r
.48193 .86578 m .48122 .86797 L .48241 .86828 L F
.973 .74 .524 r
.48122 .86797 m .48111 .87035 L .48241 .86828 L F
.455 .318 .605 r
.3379 .69421 m .33993 .69165 L .33845 .69222 L F
.404 .774 .994 r
.43987 .72728 m .44214 .72712 L .44293 .72778 L F
.386 .61 .938 r
.44408 .7265 m .44293 .72778 L .44214 .72712 L F
.44408 .7265 m .44545 .72823 L .44293 .72778 L F
0 0 0 r
.32818 .67506 m .32731 .67515 L .32527 .67532 L F
.162 .653 .919 r
.32818 .67506 m .32934 .6747 L .32731 .67515 L F
.32818 .67506 m .33205 .67552 L .32934 .6747 L F
.811 .646 .678 r
.61896 .6439 m .61747 .64673 L .61593 .64348 L F
.693 .945 .959 r
.34291 .8286 m .34354 .82728 L .3415 .82847 L F
.34291 .8286 m .34326 .82841 L .34354 .82728 L F
0 .184 .679 r
.68346 .61784 m .68424 .61845 L .68508 .61927 L F
.68424 .61845 m .68567 .61957 L .68508 .61927 L F
.692 .266 .231 r
.6826 .61923 m .68567 .61957 L .68346 .61784 L F
.437 0 .092 r
.6841 .61801 m .6826 .61923 L .68346 .61784 L F
.969 .659 .365 r
.68095 .61566 m .6826 .61923 L .68393 .61815 L F
.68274 .61699 m .68393 .61815 L .6841 .61801 L F
.68095 .61566 m .68393 .61815 L .68274 .61699 L F
0 .184 .679 r
.68508 .61927 m .68567 .61957 L .68632 .62036 L F
.917 .585 .118 r
.68567 .61957 m .68709 .62281 L .68632 .62036 L F
.557 .482 .727 r
.35885 .77688 m .35682 .7774 L .3563 .77531 L F
.593 .46 .669 r
.35927 .78007 m .35682 .7774 L .35885 .77688 L F
.35927 .78007 m .35721 .78044 L .35682 .7774 L F
.542 .268 .45 r
.34874 .74249 m .35106 .74263 L .3515 .74029 L F
.553 .256 .417 r
.35106 .74263 m .35389 .74009 L .3515 .74029 L F
.641 .481 .651 r
.35165 .74012 m .3515 .74029 L .35389 .74009 L F
.962 .69 .475 r
.35031 .81241 m .34895 .81449 L .34688 .81211 L F
.35031 .81241 m .35033 .81488 L .34895 .81449 L F
.573 .149 .2 r
.35031 .81241 m .35256 .81296 L .35033 .81488 L F
.298 .007 .291 r
.33706 .71597 m .33462 .71843 L .33538 .71666 L F
.542 .374 .603 r
.35826 .77238 m .35831 .77491 L .3563 .77531 L F
.557 .482 .727 r
.35885 .77688 m .3563 .77531 L .35831 .77491 L F
.833 .604 .593 r
.60565 .65685 m .60212 .65894 L .6041 .65839 L F
.826 .595 .589 r
.60658 .65979 m .60383 .65967 L .60565 .65685 L F
.578 .544 .78 r
.60563 .6553 m .60565 .65685 L .60744 .65511 L F
.989 .774 .524 r
.49057 .7606 m .49148 .76154 L .49182 .75902 L F
.53 .332 .557 r
.48585 .86584 m .48828 .86558 L .48656 .86359 L F
.768 .294 .113 r
.48656 .86359 m .48828 .86558 L .48998 .86576 L F
.516 .275 .489 r
.69347 .62546 m .69572 .625 L .69599 .62314 L F
.69599 .62314 m .69572 .625 L .69347 .62546 L F
.398 .174 .454 r
.69788 .6223 m .69572 .625 L .69599 .62314 L F
.69788 .6223 m .69572 .625 L .69599 .62314 L F
.463 .305 .581 r
.34148 .70807 m .34158 .71083 L .33973 .71138 L F
.276 .002 .305 r
.3407 .71249 m .33973 .71138 L .34158 .71083 L F
.3407 .71249 m .33914 .71315 L .33973 .71138 L F
.209 0 0 r
.35921 .7377 m .35965 .73868 L .36115 .73715 L F
.35921 .7377 m .35758 .73915 L .35965 .73868 L F
.64 .734 .917 r
.69225 .60889 m .69551 .61007 L .69444 .6082 L F
.653 .74 .914 r
.69444 .6082 m .69551 .61007 L .6967 .60776 L F
.482 .528 .828 r
.69551 .61007 m .69818 .61089 L .6967 .60776 L F
.867 .505 .008 r
.47688 .87095 m .4782 .87388 L .4775 .87284 L F
.3 0 .032 r
.43047 .78149 m .42969 .78029 L .43188 .77983 L F
.43047 .78149 m .42838 .78195 L .42969 .78029 L F
.536 .393 .634 r
.68274 .72969 m .68305 .73189 L .6807 .73231 L F
.529 .368 .607 r
.6807 .73231 m .68168 .7338 L .68305 .73189 L F
.718 .649 .781 r
.68274 .72969 m .6807 .73231 L .67961 .72929 L F
.896 .498 .251 r
.68237 .63325 m .68178 .63423 L .68129 .63274 L F
.68237 .63325 m .6837 .6359 L .68178 .63423 L F
.851 .48 .348 r
.68237 .63325 m .6849 .63573 L .6837 .6359 L F
0 .044 .571 r
.48288 .84085 m .482 .8417 L .48166 .83981 L F
0 .115 .633 r
.48288 .84085 m .48321 .84229 L .482 .8417 L F
.523 .618 .889 r
.48321 .84229 m .48233 .84429 L .482 .8417 L F
0 0 .26 r
.49061 .87231 m .49125 .87624 L .49067 .87365 L F
.49067 .87365 m .49125 .87624 L .49061 .87231 L F
.637 .603 .799 r
.36063 .78555 m .35885 .78727 L .35853 .78607 L F
.785 .934 .929 r
.71296 .62757 m .71072 .62771 L .71205 .62666 L F
.792 .935 .925 r
.71553 .62537 m .71296 .62757 L .71205 .62666 L F
.858 .835 .822 r
.49135 .88879 m .49495 .88699 L .49303 .88746 L F
.49135 .88879 m .4925 .88982 L .49495 .88699 L F
.673 .58 .742 r
.49701 .88473 m .49495 .88699 L .4939 .88447 L F
.603 .034 0 r
.49495 .88699 m .49489 .88783 L .49303 .88746 L F
.49495 .88699 m .49691 .88829 L .49489 .88783 L F
.601 .267 .376 r
.54876 .80632 m .54646 .80698 L .5486 .80475 L F
.54876 .80632 m .54696 .80703 L .54646 .80698 L F
0 0 .35 r
.5477 .8087 m .54696 .80703 L .54876 .80632 L F
.757 .783 .874 r
.5486 .80475 m .54876 .80632 L .55165 .80481 L F
.386 .496 .848 r
.5502 .80567 m .54876 .80632 L .5486 .80475 L F
.741 .343 .297 r
.55142 .80891 m .54876 .80632 L .5502 .80567 L F
.55142 .80891 m .5477 .8087 L .54876 .80632 L F
.982 .855 .638 r
.54311 .83816 m .54227 .84137 L .54327 .84178 L F
.451 .734 .988 r
.45287 .7286 m .45202 .72975 L .4508 .72877 L F
.45287 .7286 m .45404 .72962 L .45202 .72975 L F
.549 .907 .966 r
.30423 .65556 m .30637 .6548 L .30776 .655 L F
.457 .868 .955 r
.30776 .655 m .30864 .65419 L .30949 .65365 L F
.30776 .655 m .30637 .6548 L .30864 .65419 L F
.561 .812 .992 r
.65517 .61937 m .65627 .62029 L .65739 .61887 L F
.368 .145 .438 r
.33871 .71529 m .33752 .71382 L .33914 .71315 L F
.33871 .71529 m .33706 .71597 L .33752 .71382 L F
.709 .663 .803 r
.72537 .71045 m .7267 .71428 L .72482 .71331 L F
.801 .369 .22 r
.7267 .71428 m .72735 .7155 L .72482 .71331 L F
.673 .643 .812 r
.72867 .71106 m .7267 .71428 L .72537 .71045 L F
.674 .644 .813 r
.72955 .71395 m .7267 .71428 L .72867 .71106 L F
.591 .465 .677 r
.72356 .71315 m .7214 .71658 L .72135 .71355 L F
.443 0 0 r
.4143 .77474 m .41638 .77494 L .41737 .77445 L F
.418 0 0 r
.41737 .77445 m .41638 .77494 L .41962 .77455 L F
.711 .284 .234 r
.69196 .63503 m .69248 .6335 L .68927 .63302 L F
.177 0 0 r
.48449 .8682 m .48788 .86854 L .48626 .86844 L F
0 0 0 r
.48899 .86756 m .48788 .86854 L .48998 .86576 L F
.512 .889 .968 r
.48626 .86844 m .48788 .86854 L .48899 .86756 L F
.574 .413 .625 r
.33399 .76176 m .33619 .76155 L .33587 .75871 L F
.616 .427 .603 r
.33399 .76176 m .33626 .76403 L .33619 .76155 L F
.33399 .76176 m .33407 .76443 L .33626 .76403 L F
.468 .844 .988 r
.36705 .67402 m .36489 .67449 L .36363 .67411 L F
.599 .246 .343 r
.69708 .64167 m .69592 .64363 L .69386 .64354 L F
.677 .335 .389 r
.69708 .64167 m .69951 .64374 L .69592 .64363 L F
.526 .377 .622 r
.69923 .64105 m .69951 .64374 L .69708 .64167 L F
.504 .32 .565 r
.69917 .63876 m .69923 .64105 L .69708 .64167 L F
.526 .377 .622 r
.69923 .64105 m .69951 .64374 L .69708 .64167 L F
.557 .452 .69 r
.48127 .75056 m .47984 .75472 L .47869 .75073 L F
.48127 .75056 m .48185 .75367 L .47984 .75472 L F
.589 .464 .677 r
.71849 .72491 m .71588 .72693 L .71468 .72692 L F
0 .441 .802 r
.71588 .72693 m .71647 .72681 L .71468 .72692 L F
.987 .841 .611 r
.55494 .80458 m .55466 .80738 L .55357 .80613 L F
.73 .415 .448 r
.55466 .80738 m .55142 .80891 L .55357 .80613 L F
.55466 .80738 m .5548 .80924 L .55142 .80891 L F
.531 .42 .673 r
.557 .80658 m .55466 .80738 L .55494 .80458 L F
.644 .47 .633 r
.557 .80658 m .5548 .80924 L .55466 .80738 L F
.987 .841 .611 r
.55494 .80458 m .55357 .80613 L .55165 .80481 L F
0 0 0 r
.48839 .8833 m .49003 .88128 L .48826 .88229 L F
.674 .74 .9 r
.68024 .61308 m .68088 .61462 L .68166 .61157 L F
.747 .447 .475 r
.71129 .73225 m .70833 .73379 L .70804 .73252 L F
.71129 .73225 m .71146 .73402 L .70833 .73379 L F
.685 .401 .486 r
.71129 .73225 m .71415 .7345 L .71146 .73402 L F
.612 .431 .613 r
.71372 .73198 m .71415 .7345 L .71129 .73225 L F
.241 0 0 r
.44588 .77603 m .44508 .77523 L .44713 .77589 L F
.44588 .77603 m .44351 .7764 L .44508 .77523 L F
.484 .196 .4 r
.44736 .77481 m .44713 .77589 L .44508 .77523 L F
.206 0 0 r
.41012 .72293 m .41355 .72257 L .41129 .72263 L F
.789 .697 .763 r
.61696 .63369 m .61827 .63633 L .61513 .63585 L F
.805 .645 .685 r
.61827 .63633 m .61488 .6382 L .61513 .63585 L F
.61827 .63633 m .61806 .63857 L .61488 .6382 L F
.538 .383 .618 r
.68224 .60115 m .68474 .60315 L .68539 .60132 L F
.3 0 0 r
.68539 .60132 m .68504 .60145 L .68224 .60115 L F
.455 .179 .405 r
.68474 .60315 m .68739 .60081 L .68539 .60132 L F
0 0 0 r
.68539 .60132 m .68739 .60081 L .68504 .60145 L F
.638 .392 .53 r
.6277 .65752 m .62833 .65922 L .62501 .65994 L F
.6277 .65752 m .62836 .65743 L .62833 .65922 L F
.64 .583 .775 r
.48049 .74839 m .47869 .75073 L .47756 .74767 L F
.637 .579 .773 r
.48049 .74839 m .48127 .75056 L .47869 .75073 L F
.509 .157 .304 r
.42174 .77424 m .42394 .77413 L .42502 .77182 L F
.421 .069 .26 r
.42502 .77182 m .42601 .77375 L .42712 .77141 L F
.42502 .77182 m .42394 .77413 L .42601 .77375 L F
.031 .237 .74 r
.35181 .83898 m .35092 .83936 L .35002 .83778 L F
.262 .767 .871 r
.34934 .83929 m .35092 .83936 L .35181 .83898 L F
.61 .291 .405 r
.46566 .76708 m .4663 .76968 L .46233 .76925 L F
.541 .249 .42 r
.46779 .7687 m .4663 .76968 L .46566 .76708 L F
.592 .219 .303 r
.46782 .76732 m .46779 .7687 L .46566 .76708 L F
.877 .854 .815 r
.63577 .60418 m .63627 .60626 L .63381 .60628 L F
.852 .705 .699 r
.63627 .60626 m .63301 .60841 L .63381 .60628 L F
.63627 .60626 m .63458 .61023 L .63301 .60841 L F
.814 .823 .856 r
.63849 .6039 m .63627 .60626 L .63577 .60418 L F
.575 .378 .577 r
.33587 .75871 m .33827 .75887 L .33828 .75622 L F
.613 .409 .581 r
.33828 .75622 m .34044 .75854 L .34042 .75604 L F
.33828 .75622 m .33827 .75887 L .34044 .75854 L F
0 0 0 r
.72237 .72616 m .7211 .72838 L .72161 .72731 L F
0 0 .493 r
.35002 .83778 m .34754 .83959 L .34942 .83613 L F
.031 .237 .74 r
.35181 .83898 m .35002 .83778 L .34942 .83613 L F
.812 .906 .502 r
.71143 .71207 m .7125 .71042 L .70919 .71133 L F
.71143 .71207 m .71089 .71336 L .7125 .71042 L F
.414 .421 .758 r
.71374 .70796 m .71421 .70855 L .71453 .7082 L F
.583 .359 .542 r
.71549 .70724 m .71571 .70892 L .7158 .7072 L F
.71338 .7075 m .71453 .7082 L .71549 .70724 L F
.71453 .7082 m .71571 .70892 L .71549 .70724 L F
.414 .421 .758 r
.71193 .70789 m .7125 .71042 L .71421 .70855 L F
.727 .379 .39 r
.7125 .71042 m .71191 .7109 L .71405 .7087 L F
.7125 .71042 m .71405 .7087 L .7144 .70833 L F
.71421 .70855 m .7144 .70833 L .71453 .7082 L F
.7125 .71042 m .7144 .70833 L .71421 .70855 L F
.583 .359 .542 r
.71333 .70747 m .71338 .7075 L .7158 .7072 L F
.564 .299 .472 r
.71333 .70747 m .7158 .7072 L .71314 .7056 L F
.502 .806 .999 r
.71333 .70747 m .7158 .7072 L .71462 .70633 L F
.25 .359 .78 r
.71462 .70633 m .71506 .70758 L .71338 .7075 L F
.414 .421 .758 r
.71374 .70796 m .71453 .7082 L .71415 .70798 L F
.71193 .70789 m .71421 .70855 L .71374 .70796 L F
.42 .216 .495 r
.71415 .70798 m .71191 .7109 L .71193 .70789 L F
.583 .359 .542 r
.71415 .70798 m .7144 .70833 L .71452 .7082 L F
.71413 .70812 m .7144 .70833 L .71415 .70798 L F
.414 .421 .758 r
.71415 .70798 m .71453 .7082 L .71472 .708 L F
.42 .216 .495 r
.71472 .708 m .71448 .70825 L .71415 .70798 L F
.25 .359 .78 r
.71506 .70758 m .71448 .70825 L .71338 .7075 L F
.71448 .70825 m .7144 .70833 L .71413 .70812 L F
.42 .216 .495 r
.71448 .70825 m .71413 .70812 L .71415 .70798 L F
.71472 .708 m .71193 .70789 L .71333 .70747 L F
.414 .421 .758 r
.71193 .70789 m .71472 .708 L .71333 .70747 L F
.583 .359 .542 r
.71338 .7075 m .71413 .70812 L .71415 .70798 L F
.25 .359 .78 r
.71448 .70825 m .71413 .70812 L .71338 .7075 L F
.42 .216 .495 r
.71448 .70825 m .71405 .7087 L .71413 .70812 L F
.71405 .7087 m .71191 .7109 L .71415 .70798 L F
.583 .359 .542 r
.71548 .70878 m .71569 .70937 L .71571 .70892 L F
.25 .359 .78 r
.71506 .70758 m .71569 .70937 L .7144 .70833 L F
.727 .379 .39 r
.71453 .7082 m .71405 .7087 L .71472 .708 L F
.25 .359 .78 r
.71334 .70746 m .71338 .7075 L .71333 .70747 L F
.71462 .70633 m .71338 .7075 L .71334 .70746 L F
.727 .379 .39 r
.7125 .71042 m .71143 .71207 L .71191 .7109 L F
.7125 .71042 m .71448 .71297 L .71143 .71207 L F
.634 .928 .972 r
.49771 .88917 m .49865 .88789 L .49691 .88829 L F
.49771 .88917 m .50058 .88797 L .49865 .88789 L F
.609 .438 .625 r
.33587 .75871 m .33836 .76125 L .33827 .75887 L F
.33587 .75871 m .33619 .76155 L .33836 .76125 L F
.327 0 .072 r
.47865 .84149 m .48051 .84129 L .48166 .83981 L F
.408 0 .124 r
.48166 .83981 m .48051 .84129 L .48288 .84085 L F
.337 .108 .411 r
.32774 .72603 m .32616 .72689 L .32824 .72419 L F
.166 0 .078 r
.32671 .72819 m .32616 .72689 L .32774 .72603 L F
.32671 .72819 m .32506 .7289 L .32616 .72689 L F
.526 .919 .826 r
.66586 .62803 m .66271 .62936 L .66587 .62746 L F
0 0 .042 r
.6673 .62453 m .66586 .62803 L .66587 .62746 L F
.443 .012 .124 r
.71478 .6072 m .7144 .60812 L .71198 .60812 L F
.659 .595 .773 r
.71612 .60389 m .71697 .60707 L .71478 .6072 L F
.728 .436 .484 r
.71697 .60707 m .7144 .60812 L .71478 .6072 L F
.752 .81 .898 r
.56507 .81768 m .56567 .81976 L .56816 .81764 L F
.742 .708 .819 r
.71392 .69757 m .71536 .69999 L .71201 .69979 L F
.782 .581 .629 r
.71536 .69999 m .71215 .7021 L .71201 .69979 L F
.71536 .69999 m .71529 .70255 L .71215 .7021 L F
.508 .723 .97 r
.71694 .69857 m .71536 .69999 L .71392 .69757 L F
.71694 .69857 m .71755 .69976 L .71536 .69999 L F
.781 .737 .812 r
.71755 .69976 m .71529 .70255 L .71536 .69999 L F
.851 .948 .88 r
.37735 .78264 m .37365 .78473 L .37628 .78258 L F
.884 .981 .825 r
.37735 .78264 m .37784 .7804 L .3793 .7826 L F
.37735 .78264 m .37628 .78258 L .37784 .7804 L F
.93 .778 .671 r
.68577 .72321 m .6871 .72414 L .68627 .72126 L F
.805 .726 .777 r
.68577 .72321 m .68654 .72654 L .6871 .72414 L F
.356 0 .082 r
.39906 .77999 m .39969 .78149 L .40124 .78016 L F
.39906 .77999 m .39755 .78187 L .39969 .78149 L F
.719 .2 0 r
.68181 .72422 m .68372 .72635 L .68245 .72559 L F
.68181 .72422 m .68245 .72559 L .6832 .72314 L F
.961 .857 .692 r
.6832 .72314 m .68245 .72559 L .68234 .72424 L F
0 0 0 r
.68181 .72422 m .6832 .72314 L .68379 .72239 L F
.68379 .72239 m .6832 .72314 L .68408 .72212 L F
.767 .622 .699 r
.68349 .7222 m .6832 .72314 L .67979 .72269 L F
.68408 .72212 m .6832 .72314 L .68349 .7222 L F
.961 .857 .692 r
.6832 .72314 m .68221 .72276 L .67979 .72269 L F
.68221 .72276 m .68245 .72558 L .6832 .72314 L F
.68245 .72558 m .68245 .72559 L .6832 .72314 L F
.6832 .72314 m .68234 .72424 L .68221 .72276 L F
.705 .442 .524 r
.48253 .76392 m .47887 .7664 L .47874 .76448 L F
.48253 .76392 m .48088 .76653 L .47887 .7664 L F
.66 .386 .495 r
.4843 .76622 m .48253 .76392 L .48433 .76468 L F
.4843 .76622 m .48088 .76653 L .48253 .76392 L F
.467 .117 .288 r
.50473 .87925 m .50143 .8814 L .5013 .87911 L F
.727 .629 .748 r
.50483 .88187 m .50188 .88554 L .50145 .88158 L F
.50172 .88144 m .50145 .88158 L .50143 .8814 L F
.50483 .88187 m .50145 .88158 L .50172 .88144 L F
.416 .062 .254 r
.50572 .88084 m .50473 .87925 L .50483 .88187 L F
.727 .629 .748 r
.50483 .88187 m .50143 .8814 L .50301 .88186 L F
.416 .062 .254 r
.50572 .88084 m .50301 .88186 L .50411 .88019 L F
.50502 .87971 m .50411 .88019 L .50473 .87925 L F
.50572 .88084 m .50411 .88019 L .50502 .87971 L F
.467 .117 .288 r
.50473 .87925 m .50301 .88186 L .50143 .8814 L F
.805 .568 .579 r
.53785 .8279 m .53949 .83122 L .54112 .83115 L F
.962 .859 .691 r
.53911 .83293 m .54112 .83115 L .53949 .83122 L F
.53911 .83293 m .53884 .83552 L .54112 .83115 L F
.543 .78 .986 r
.42234 .72433 m .42029 .72475 L .41892 .72369 L F
.287 .096 .438 r
.65695 .60053 m .65494 .60153 L .65672 .59938 L F
.373 .033 .254 r
.65637 .60225 m .65494 .60153 L .65695 .60053 L F
.65637 .60225 m .65429 .60347 L .65494 .60153 L F
.535 .363 .594 r
.36061 .77195 m .35831 .77491 L .35826 .77238 L F
.582 .348 .525 r
.62836 .65743 m .63052 .65911 L .62833 .65922 L F
.649 .313 .391 r
.6304 .65768 m .63052 .65911 L .62836 .65743 L F
.549 .665 .914 r
.4619 .73032 m .46083 .73213 L .45985 .73071 L F
.4619 .73032 m .46291 .73188 L .46083 .73213 L F
.717 .33 .315 r
.63846 .64292 m .64086 .64305 L .64126 .64165 L F
0 .051 .611 r
.64241 .64237 m .64268 .64295 L .64126 .64165 L F
.64241 .64237 m .64126 .64165 L .64086 .64305 L F
.012 .215 .724 r
.68378 .7275 m .68509 .72922 L .68372 .72635 L F
.367 .589 .929 r
.42602 .74149 m .42706 .74285 L .428 .74172 L F
.777 .834 .896 r
.50218 .88672 m .50533 .88625 L .50416 .8845 L F
.728 .82 .922 r
.50533 .88625 m .50651 .88381 L .50416 .8845 L F
.50533 .88625 m .50755 .88479 L .50651 .88381 L F
.808 .381 .232 r
.57507 .79594 m .57659 .79797 L .5774 .79656 L F
.916 .543 .303 r
.57659 .79797 m .57817 .79875 L .5774 .79656 L F
.777 .817 .884 r
.69568 .69961 m .69373 .70093 L .69249 .6998 L F
.578 .382 .579 r
.36291 .76697 m .36276 .76934 L .36064 .76953 L F
.668 .458 .592 r
.3649 .76915 m .36291 .76697 L .36526 .7671 L F
.3649 .76915 m .36276 .76934 L .36291 .76697 L F
.197 0 .258 r
.33221 .72081 m .33069 .72172 L .33285 .71909 L F
.434 .146 .374 r
.33432 .72023 m .33285 .71909 L .33462 .71843 L F
.33432 .72023 m .33221 .72081 L .33285 .71909 L F
.658 .771 .933 r
.39156 .8762 m .39242 .87693 L .39396 .87648 L F
.668 .601 .771 r
.68735 .6063 m .68874 .60738 L .68798 .60538 L F
.894 .577 .44 r
.68892 .60885 m .68874 .60738 L .68735 .6063 L F
.68892 .60885 m .69003 .60977 L .68874 .60738 L F
.582 .553 .787 r
.68798 .60538 m .68874 .60738 L .69124 .60569 L F
.651 .515 .685 r
.68874 .60738 m .69225 .60889 L .69124 .60569 L F
.68874 .60738 m .69003 .60977 L .69225 .60889 L F
.567 .658 .898 r
.3426 .65567 m .34164 .65779 L .33904 .65546 L F
.3426 .65567 m .34357 .6574 L .34164 .65779 L F
.439 0 0 r
.44221 .73993 m .43894 .74022 L .44051 .73942 L F
.384 0 .033 r
.39156 .72611 m .39367 .72595 L .39513 .7244 L F
.433 0 .106 r
.39367 .72595 m .39723 .72415 L .39513 .7244 L F
.542 .928 .876 r
.70364 .62984 m .70236 .63021 L .70455 .62909 L F
.654 .111 0 r
.70556 .63134 m .70236 .63021 L .70364 .62984 L F
.087 0 .359 r
.33165 .70024 m .3313 .70244 L .33275 .69934 L F
0 .5 .768 r
.69598 .638 m .69855 .63853 L .69917 .63876 L F
.979 .73 .323 r
.69855 .63853 m .69923 .64105 L .69917 .63876 L F
.692 .98 .891 r
.69917 .63876 m .69855 .63853 L .70026 .63735 L F
.318 .422 .811 r
.70026 .63735 m .70193 .6408 L .69917 .63876 L F
.613 .405 .575 r
.69917 .63876 m .70193 .6408 L .69923 .64105 L F
.312 .027 .31 r
.32983 .72357 m .32824 .72419 L .33069 .72172 L F
.367 .082 .341 r
.33179 .72302 m .33069 .72172 L .33221 .72081 L F
.33179 .72302 m .32983 .72357 L .33069 .72172 L F
.323 0 .23 r
.54401 .80942 m .54646 .80698 L .54392 .80703 L F
.768 .612 .685 r
.54645 .80703 m .54401 .80942 L .54392 .80703 L F
.54696 .80703 m .54618 .80766 L .54645 .80703 L F
.529 .412 .664 r
.54642 .8071 m .54645 .80703 L .54646 .80698 L F
.768 .612 .685 r
.54618 .80766 m .54401 .80942 L .54642 .8071 L F
.54696 .80703 m .54677 .81031 L .5452 .8098 L F
.54618 .80766 m .5452 .8098 L .54401 .80942 L F
.54696 .80703 m .5452 .8098 L .54618 .80766 L F
.529 .412 .664 r
.54577 .809 m .54622 .8081 L .54644 .8071 L F
.5464 .8072 m .54644 .8071 L .54645 .80703 L F
.54577 .809 m .54644 .8071 L .5464 .8072 L F
.323 0 .23 r
.54401 .80942 m .54577 .809 L .54642 .8071 L F
.54401 .80942 m .54642 .8071 L .54646 .80698 L F
.768 .612 .685 r
.54642 .8071 m .54401 .80942 L .54645 .80703 L F
.529 .412 .664 r
.54577 .809 m .54645 .80703 L .54642 .8071 L F
.512 .037 .063 r
.54646 .80698 m .54696 .80703 L .54645 .80703 L F
.727 .98 .758 r
.5486 .80475 m .54646 .80698 L .54777 .80502 L F
.529 .412 .664 r
.54622 .8081 m .54777 .80502 L .54646 .80698 L F
.512 .037 .063 r
.54646 .80698 m .54645 .80703 L .54392 .80703 L F
.393 .228 .535 r
.71242 .62233 m .71408 .6222 L .71414 .61981 L F
.587 .685 .909 r
.69373 .716 m .69422 .71343 L .69258 .71305 L F
.69373 .716 m .69638 .71581 L .69422 .71343 L F
.592 .616 .845 r
.69373 .716 m .69728 .71783 L .69638 .71581 L F
.476 .651 .936 r
.36623 .78709 m .3645 .78721 L .3628 .7852 L F
.557 .494 .74 r
.45993 .75362 m .46125 .75025 L .45916 .7506 L F
.45993 .75362 m .46198 .75331 L .46125 .75025 L F
.53 .36 .595 r
.45993 .75362 m .45997 .75599 L .46198 .75331 L F
.28 .559 .93 r
.69728 .71783 m .69993 .71947 L .6993 .7182 L F
.51 .686 .947 r
.69993 .71947 m .70146 .71809 L .6993 .7182 L F
.69993 .71947 m .70252 .71938 L .70146 .71809 L F
.322 .803 .896 r
.3224 .67458 m .31842 .67496 L .31993 .67479 L F
.461 .667 .952 r
.68415 .58977 m .68302 .5912 L .68232 .5897 L F
.68415 .58977 m .68501 .59121 L .68302 .5912 L F
.635 .962 .826 r
.40833 .75031 m .40552 .75214 L .40699 .75143 L F
.736 .636 .748 r
.71644 .70549 m .71314 .7056 L .71529 .70255 L F
.506 .271 .492 r
.32134 .71271 m .32385 .71 L .32251 .71072 L F
.527 .084 .14 r
.65493 .60878 m .65323 .61018 L .65649 .60832 L F
.713 .557 .676 r
.70581 .61157 m .70658 .61361 L .70732 .61333 L F
.495 0 0 r
.70658 .61361 m .70984 .6141 L .70732 .61333 L F
.577 .428 .643 r
.45777 .75635 m .45999 .75844 L .45997 .75599 L F
.45777 .75635 m .45793 .75884 L .45999 .75844 L F
0 0 0 r
.48899 .86756 m .48998 .86576 L .48828 .86558 L F
.236 0 0 r
.41834 .74127 m .41695 .74211 L .41486 .74232 L F
.349 .116 .412 r
.34734 .7045 m .3461 .70315 L .34793 .70268 L F
.34734 .7045 m .34569 .70512 L .3461 .70315 L F
.382 0 .142 r
.39741 .74751 m .39613 .74948 L .39395 .7499 L F
.48 .106 .253 r
.3995 .74711 m .39613 .74948 L .39741 .74751 L F
.501 .101 .215 r
.63366 .65729 m .63052 .65911 L .6304 .65768 L F
.63366 .65729 m .63274 .65909 L .63052 .65911 L F
.411 .002 .15 r
.63366 .65729 m .635 .65873 L .63274 .65909 L F
.63366 .65729 m .63583 .65697 L .635 .65873 L F
.829 .467 .371 r
.6849 .63573 m .68379 .63736 L .6837 .6359 L F
.523 .823 .999 r
.68731 .63763 m .68379 .63736 L .6849 .63573 L F
.688 .311 .326 r
.68727 .6363 m .68731 .63763 L .6849 .63573 L F
.547 .617 .874 r
.68784 .61989 m .68709 .62281 L .68567 .61957 L F
.68784 .61989 m .6895 .62224 L .68709 .62281 L F
.654 .111 0 r
.70556 .63134 m .70414 .63122 L .70236 .63021 L F
.866 .473 .293 r
.70556 .63134 m .70597 .63297 L .70414 .63122 L F
.413 .526 .863 r
.68773 .59205 m .6863 .59362 L .68501 .59121 L F
.442 .572 .889 r
.68848 .59394 m .6863 .59362 L .68773 .59205 L F
.3 .052 .361 r
.32983 .72357 m .32774 .72603 L .32824 .72419 L F
.271 .231 .629 r
.48323 .85419 m .48153 .85523 L .48164 .85241 L F
.551 .535 .79 r
.48323 .85419 m .48222 .85755 L .48153 .85523 L F
.233 0 .108 r
.38144 .75376 m .37872 .75584 L .37916 .75367 L F
.889 .741 .691 r
.56526 .8124 m .56451 .81273 L .56393 .81006 L F
.73 .546 .643 r
.56526 .8124 m .5619 .81484 L .56451 .81273 L F
.56526 .8124 m .56496 .81528 L .5619 .81484 L F
.513 .354 .602 r
.56687 .81454 m .56496 .81528 L .56526 .8124 L F
.583 .356 .538 r
.45022 .76388 m .45272 .76128 L .45054 .76173 L F
0 0 0 r
.65905 .59574 m .65641 .5986 L .65808 .5973 L F
.414 .584 .91 r
.66049 .59448 m .66073 .59598 L .65905 .59574 L F
.387 .384 .734 r
.66213 .598 m .65905 .59574 L .66073 .59598 L F
.66213 .598 m .65959 .59743 L .65905 .59574 L F
0 0 0 r
.65905 .59574 m .65808 .5973 L .66049 .59448 L F
.65 .596 .781 r
.69658 .60126 m .69306 .59871 L .69661 .60135 L F
.483 .531 .83 r
.69845 .60037 m .69851 .60109 L .69658 .60126 L F
.69845 .60037 m .69658 .60126 L .69661 .60135 L F
.553 .562 .817 r
.69977 .60394 m .69658 .60126 L .69851 .60109 L F
.957 .693 .493 r
.53613 .83134 m .53532 .8292 L .53785 .8279 L F
.53613 .83134 m .53474 .83081 L .53532 .8292 L F
.947 .807 .672 r
.53613 .83134 m .53546 .83355 L .53474 .83081 L F
.155 0 0 r
.40563 .79045 m .40912 .78841 L .40764 .78994 L F
.422 .022 .173 r
.41105 .78769 m .40764 .78994 L .40912 .78841 L F
.587 .654 .883 r
.45211 .74334 m .45331 .74146 L .45061 .74064 L F
.45211 .74334 m .45429 .74296 L .45331 .74146 L F
.451 .012 .112 r
.3448 .81216 m .34539 .81381 L .34364 .81246 L F
.3448 .81216 m .34688 .81211 L .34539 .81381 L F
.919 .582 .385 r
.53717 .82996 m .53785 .8279 L .53645 .82786 L F
.53717 .82996 m .53949 .83122 L .53785 .8279 L F
.896 .713 .647 r
.49956 .87895 m .5013 .87911 L .4994 .87652 L F
.595 .312 .457 r
.65959 .59743 m .65938 .60001 L .65672 .59938 L F
.585 .402 .601 r
.66213 .598 m .65938 .60001 L .65959 .59743 L F
0 0 0 r
.37929 .80068 m .37824 .80109 L .37999 .80053 L F
.37929 .80068 m .3777 .80166 L .37824 .80109 L F
.565 .204 .314 r
.38974 .75051 m .38815 .75319 L .38659 .7513 L F
.44 .072 .241 r
.38982 .75343 m .3897 .75168 L .3913 .75103 L F
.393 .467 .817 r
.38965 .75341 m .39054 .75465 L .38821 .75323 L F
.39005 .75346 m .39005 .75347 L .38965 .75341 L F
.39005 .75347 m .39054 .75465 L .38965 .75341 L F
.44 .072 .241 r
.38965 .75341 m .38815 .75319 L .38974 .75051 L F
.393 .467 .817 r
.38982 .75343 m .38821 .75323 L .38815 .75319 L F
.39005 .75346 m .38982 .75343 L .38982 .75343 L F
.38982 .75343 m .38821 .75323 L .38982 .75343 L F
.67 .833 .409 r
.39071 .75179 m .3903 .75256 L .39178 .75023 L F
.39156 .75058 m .38982 .75343 L .39178 .75023 L F
.39019 .75274 m .38994 .75321 L .39156 .75058 L F
.38994 .75321 m .38982 .75343 L .39156 .75058 L F
.44 .072 .241 r
.38964 .75374 m .38815 .75319 L .38965 .75341 L F
.38965 .75341 m .3897 .75168 L .38982 .75343 L F
.313 .297 .681 r
.38806 .75182 m .38885 .75277 L .38928 .75162 L F
.393 .467 .817 r
.38928 .75162 m .38958 .75233 L .38885 .75277 L F
.38958 .75233 m .39005 .75346 L .38815 .75319 L F
.313 .297 .681 r
.38885 .75277 m .38964 .75374 L .38928 .75162 L F
.393 .467 .817 r
.38928 .75162 m .38885 .75277 L .38815 .75319 L F
.313 .297 .681 r
.38885 .75277 m .38815 .75319 L .38964 .75374 L F
.38806 .75182 m .38815 .75319 L .38885 .75277 L F
.213 .45 .871 r
.39054 .75465 m .38988 .75578 L .38815 .75319 L F
.96 .725 .538 r
.38928 .75162 m .38914 .75396 L .3894 .75409 L F
.67 .833 .409 r
.39019 .75274 m .38964 .75374 L .38982 .75343 L F
.96 .725 .538 r
.38994 .75321 m .3894 .75409 L .39054 .75465 L F
.44 .072 .241 r
.38964 .75374 m .38965 .75341 L .38982 .75343 L F
.57 .528 .768 r
.38928 .75162 m .38964 .75374 L .38982 .75339 L F
.96 .725 .538 r
.38928 .75162 m .38982 .75339 L .38994 .75321 L F
.57 .528 .768 r
.38928 .75162 m .38982 .75339 L .39071 .75179 L F
.96 .725 .538 r
.38928 .75162 m .3894 .75409 L .38982 .75339 L F
0 0 0 r
.39494 .74983 m .39071 .75179 L .39373 .75003 L F
.67 .833 .409 r
.39071 .75179 m .39178 .75023 L .39395 .7499 L F
.798 .945 .92 r
.39121 .75084 m .39071 .75179 L .39494 .74983 L F
.3909 .75093 m .39071 .75179 L .39121 .75084 L F
.67 .833 .409 r
.39071 .75179 m .39019 .75274 L .3903 .75256 L F
0 0 0 r
.39406 .74989 m .39373 .75003 L .39395 .7499 L F
.39494 .74983 m .39373 .75003 L .39406 .74989 L F
.44 .072 .241 r
.3913 .75103 m .38974 .75051 L .39178 .75023 L F
.3897 .75168 m .38974 .75051 L .3913 .75103 L F
.862 .751 .739 r
.54097 .84684 m .54192 .84486 L .53995 .8439 L F
.54097 .84684 m .54192 .84486 L .53995 .8439 L F
.127 0 0 r
.65156 .64999 m .65254 .65059 L .65025 .65097 L F
.65156 .64999 m .65381 .64936 L .65254 .65059 L F
.455 .318 .605 r
.3379 .69421 m .34006 .69425 L .33993 .69165 L F
.515 .275 .489 r
.33757 .69678 m .34006 .69425 L .3379 .69421 L F
.448 .189 .428 r
.34397 .70581 m .34338 .70773 L .34148 .70807 L F
.466 .241 .487 r
.34569 .70512 m .34338 .70773 L .34397 .70581 L F
.57 .591 .835 r
.34563 .65746 m .34496 .66049 L .34357 .6574 L F
.34563 .65746 m .34695 .66035 L .34496 .66049 L F
.409 .264 .571 r
.34315 .71 m .34148 .70807 L .34338 .70773 L F
.34315 .71 m .34158 .71083 L .34148 .70807 L F
.724 .475 .551 r
.70893 .63344 m .70565 .63536 L .70597 .63297 L F
.70893 .63344 m .70907 .63566 L .70565 .63536 L F
.443 .119 .319 r
.71217 .63301 m .70907 .63566 L .70893 .63344 L F
.881 .951 .85 r
.68609 .60621 m .68735 .6063 L .68798 .60538 L F
.787 .659 .722 r
.68609 .60621 m .68892 .60885 L .68735 .6063 L F
.757 .783 .874 r
.5486 .80475 m .55165 .80481 L .55054 .8037 L F
.614 .17 .173 r
.55165 .80481 m .55357 .80613 L .5502 .80567 L F
.956 .859 .703 r
.55165 .80481 m .5502 .80567 L .55054 .8037 L F
.599 .315 .457 r
.47874 .76448 m .47887 .7664 L .47633 .76658 L F
.043 .554 .875 r
.43331 .72548 m .43652 .72656 L .43453 .72651 L F
.048 .338 .817 r
.70547 .70429 m .70698 .70457 L .70628 .70527 L F
.70426 .70282 m .70531 .70349 L .70547 .70429 L F
.70531 .70349 m .70698 .70457 L .70547 .70429 L F
.612 .212 .261 r
.70319 .70453 m .70698 .70457 L .70426 .70282 L F
.87 .95 .861 r
.70499 .70194 m .70319 .70453 L .70259 .70343 L F
.70564 .70153 m .70505 .70225 L .70499 .70194 L F
.70505 .70225 m .70319 .70453 L .70499 .70194 L F
.778 .336 .199 r
.70628 .70703 m .70628 .70527 L .70698 .70457 L F
.73 .612 .726 r
.57114 .81791 m .56891 .82104 L .57139 .81997 L F
.71 .704 .842 r
.57139 .81997 m .57372 .81769 L .57114 .81791 L F
.598 .399 .583 r
.36266 .77171 m .36064 .76953 L .36276 .76934 L F
.36266 .77171 m .36061 .77195 L .36064 .76953 L F
.466 .556 .863 r
.69728 .71783 m .69773 .71546 L .69638 .71581 L F
.69728 .71783 m .6993 .7182 L .69773 .71546 L F
.811 .644 .675 r
.61806 .63857 m .61465 .64028 L .61488 .6382 L F
.61806 .63857 m .61654 .64144 L .61465 .64028 L F
.663 .846 .97 r
.71046 .60217 m .70794 .60192 L .7098 .6006 L F
.558 .639 .886 r
.71197 .60017 m .71046 .60217 L .7098 .6006 L F
.71197 .60017 m .71235 .60207 L .71046 .60217 L F
.592 .515 .736 r
.47729 .74592 m .47501 .74634 L .47412 .74277 L F
.233 0 0 r
.34695 .66035 m .34917 .66039 L .35056 .66003 L F
0 .166 .671 r
.35143 .66039 m .35056 .66003 L .34917 .66039 L F
.35143 .66039 m .35246 .66158 L .35056 .66003 L F
.595 .741 .945 r
.69966 .62939 m .70012 .63073 L .69692 .63001 L F
.69966 .62939 m .70012 .63073 L .69692 .63001 L F
.603 .746 .945 r
.69966 .62939 m .70012 .63073 L .70236 .63021 L F
.69966 .62939 m .70012 .63073 L .70236 .63021 L F
.637 .41 .557 r
.36734 .76873 m .36526 .7671 L .36767 .76676 L F
.36734 .76873 m .3649 .76915 L .36526 .7671 L F
.24 0 .284 r
.36576 .68353 m .36351 .68605 L .3642 .68432 L F
.641 .136 .032 r
.52839 .8673 m .53008 .86773 L .52987 .8683 L F
.521 .335 .57 r
.53008 .86773 m .53153 .87047 L .52987 .8683 L F
.688 .599 .751 r
.70324 .60587 m .69977 .60394 L .70216 .60394 L F
.736 .65 .764 r
.70513 .60392 m .70324 .60587 L .70216 .60394 L F
.663 .367 .46 r
.49791 .87087 m .49653 .8683 L .49622 .87123 L F
.49791 .87087 m .49875 .86836 L .49653 .8683 L F
.294 0 0 r
.41583 .72238 m .41892 .72369 L .41743 .72293 L F
.492 .247 .47 r
.33648 .67598 m .33405 .67826 L .33444 .67623 L F
.717 .472 .554 r
.4874 .76382 m .4843 .76622 L .48433 .76468 L F
.422 .485 .82 r
.69479 .59729 m .69306 .59871 L .69189 .5957 L F
.458 .55 .863 r
.69479 .59729 m .69661 .60135 L .69306 .59871 L F
.511 .129 .252 r
.43941 .77726 m .43602 .77934 L .43732 .7775 L F
.959 .621 .294 r
.71575 .72143 m .7138 .71811 L .71663 .71917 L F
.71575 .72143 m .7146 .7209 L .7138 .71811 L F
.837 .417 0 r
.71575 .72143 m .71587 .72279 L .7146 .7209 L F
.71575 .72143 m .71723 .72428 L .71587 .72279 L F
.737 .617 .724 r
.6812 .60912 m .68427 .61012 L .68341 .60714 L F
.893 .854 .797 r
.68166 .61157 m .68427 .61012 L .6812 .60912 L F
.68166 .61157 m .68287 .61236 L .68427 .61012 L F
.596 .553 .777 r
.68427 .61012 m .68609 .60621 L .68341 .60714 L F
.68427 .61012 m .68714 .60936 L .68609 .60621 L F
.532 .338 .564 r
.68427 .61012 m .68658 .61113 L .68714 .60936 L F
.805 .726 .777 r
.68577 .72321 m .68372 .72635 L .68654 .72654 L F
.816 .656 .684 r
.68372 .72635 m .68509 .72922 L .68654 .72654 L F
.391 .214 .517 r
.72134 .62519 m .72109 .62738 L .71955 .62755 L F
.37 .134 .42 r
.72109 .62738 m .71886 .63009 L .71955 .62755 L F
.319 .545 .913 r
.33029 .65266 m .32985 .65397 L .32809 .65301 L F
.33029 .65266 m .33149 .65426 L .32985 .65397 L F
.503 .422 .698 r
.34693 .74594 m .34911 .74768 L .34892 .74535 L F
.34693 .74594 m .34729 .74819 L .34911 .74768 L F
.35 0 .11 r
.38434 .72739 m .38575 .72793 L .38726 .72601 L F
.262 0 0 r
.38575 .72793 m .38941 .72598 L .38726 .72601 L F
.8 .811 .86 r
.53369 .86299 m .53466 .85973 L .53427 .85903 L F
.511 .307 .539 r
.34252 .7534 m .34477 .75061 L .34267 .75104 L F
.797 .729 .788 r
.68245 .70297 m .6803 .70289 L .68101 .70185 L F
.798 .729 .788 r
.68467 .70018 m .68245 .70297 L .68101 .70185 L F
.47 .88 .943 r
.64286 .5882 m .64595 .58779 L .6441 .58898 L F
.094 0 .081 r
.3581 .80965 m .36039 .80741 L .35887 .80978 L F
.315 0 .227 r
.35887 .80978 m .36039 .80741 L .36224 .80678 L F
0 0 0 r
.36039 .80741 m .36244 .8066 L .36224 .80678 L F
.443 .119 .319 r
.71217 .63301 m .71131 .63518 L .70907 .63566 L F
.262 0 .233 r
.71336 .63436 m .71217 .63301 L .7141 .63271 L F
.71336 .63436 m .71131 .63518 L .71217 .63301 L F
.668 .376 .469 r
.48943 .8308 m .4868 .83084 L .48727 .82832 L F
.279 0 .228 r
.48719 .83048 m .48727 .82832 L .4868 .83084 L F
.668 .376 .469 r
.48943 .8308 m .48727 .82832 L .48924 .82761 L F
.279 0 .228 r
.48719 .83048 m .48924 .82761 L .48727 .82832 L F
.501 .034 .078 r
.51936 .86245 m .52091 .86217 L .51926 .86164 L F
.656 .767 .931 r
.33904 .65546 m .33852 .65634 L .33703 .65482 L F
.794 .8 .857 r
.63361 .6308 m .63476 .62699 L .63267 .63 L F
.63361 .6308 m .63636 .62788 L .63476 .62699 L F
.615 .389 .551 r
.52817 .8243 m .52956 .82268 L .52802 .82276 L F
0 0 0 r
.67435 .63907 m .67342 .64059 L .67204 .64161 L F
.5 .907 .824 r
.67342 .64059 m .67036 .64184 L .67204 .64161 L F
.717 .472 .554 r
.4874 .76382 m .4862 .76666 L .4843 .76622 L F
.665 .414 .531 r
.48966 .76614 m .4874 .76382 L .48964 .76403 L F
.48966 .76614 m .4862 .76666 L .4874 .76382 L F
0 0 0 r
.38517 .78105 m .38295 .78304 L .3843 .78183 L F
.688 .98 .876 r
.3843 .78183 m .38295 .78304 L .38133 .7833 L F
.3843 .78183 m .38133 .7833 L .38249 .78346 L F
.3843 .78183 m .38249 .78346 L .38351 .78359 L F
0 0 0 r
.38536 .78088 m .38517 .78105 L .3843 .78183 L F
.949 .863 .721 r
.72833 .72375 m .72933 .72458 L .73086 .72137 L F
.636 .744 .927 r
.67373 .60004 m .67675 .60112 L .67565 .59799 L F
.643 .649 .841 r
.67565 .59799 m .67675 .60112 L .67865 .60016 L F
0 0 0 r
.66091 .61505 m .66163 .61553 L .6615 .61418 L F
.66091 .61505 m .66022 .61676 L .66163 .61553 L F
.477 .198 .412 r
.65114 .5963 m .65066 .5982 L .64838 .59873 L F
.322 .06 .352 r
.65305 .5955 m .65066 .5982 L .65114 .5963 L F
.788 .699 .767 r
.69035 .63723 m .68731 .63763 L .68727 .6363 L F
.54 .683 .932 r
.70252 .71938 m .70569 .72128 L .70486 .7185 L F
.775 .745 .826 r
.70486 .7185 m .70569 .72128 L .70797 .71867 L F
.63 .565 .762 r
.36063 .78555 m .35853 .78607 L .35738 .7828 L F
.507 .544 .828 r
.35891 .66758 m .35823 .6707 L .3571 .66753 L F
.35891 .66758 m .35997 .67041 L .35823 .6707 L F
.365 0 0 r
.66624 .64319 m .66316 .64341 L .66396 .6434 L F
.627 .675 .877 r
.70089 .60077 m .69977 .60394 L .69851 .60109 L F
.70089 .60077 m .70216 .60394 L .69977 .60394 L F
.767 .666 .751 r
.56816 .81764 m .56891 .82104 L .57114 .81791 L F
.699 .561 .694 r
.62055 .66157 m .61756 .65998 L .62074 .65987 L F
.594 .354 .524 r
.62283 .65975 m .62055 .66157 L .62074 .65987 L F
.523 .618 .889 r
.48321 .84229 m .48436 .8439 L .48233 .84429 L F
.223 .141 .547 r
.4841 .84602 m .48233 .84429 L .48436 .8439 L F
.4841 .84602 m .48205 .84747 L .48233 .84429 L F
.085 0 .173 r
.35744 .81133 m .3581 .80965 L .35887 .80978 L F
0 0 .084 r
.67573 .63792 m .67435 .63907 L .67648 .63625 L F
0 0 0 r
.67711 .63655 m .67648 .63625 L .67782 .63469 L F
.67711 .63655 m .67573 .63792 L .67648 .63625 L F
.57 .554 .797 r
.37328 .89259 m .37418 .88897 L .37543 .88968 L F
.54 .357 .581 r
.37543 .88968 m .37542 .89233 L .37328 .89259 L F
.57 .554 .797 r
.37328 .89259 m .37542 .89233 L .37418 .88897 L F
.279 .384 .791 r
.72867 .71106 m .73064 .71316 L .72955 .71395 L F
.464 .763 .995 r
.73064 .71316 m .73149 .71389 L .72955 .71395 L F
.077 0 0 r
.38592 .79841 m .38516 .79906 L .38316 .79964 L F
.139 0 0 r
.38806 .7978 m .38732 .79852 L .38592 .79841 L F
.127 0 0 r
.38592 .79841 m .38732 .79852 L .38516 .79906 L F
.711 .876 .958 r
.69568 .69961 m .69249 .6998 L .69533 .69843 L F
.798 .419 .338 r
.69533 .69843 m .69811 .69949 L .69568 .69961 L F
.06 .615 .819 r
.44574 .73983 m .44752 .7399 L .44425 .73954 L F
.67 .635 .806 r
.47412 .74277 m .47017 .74009 L .47263 .73985 L F
.565 .604 .851 r
.47466 .73937 m .47412 .74277 L .47263 .73985 L F
.47466 .73937 m .47617 .74242 L .47412 .74277 L F
.592 .515 .736 r
.47729 .74592 m .47412 .74277 L .47617 .74242 L F
.576 .55 .789 r
.45916 .7506 m .46067 .74844 L .45791 .74741 L F
.45916 .7506 m .46125 .75025 L .46067 .74844 L F
.087 .116 .595 r
.38659 .7513 m .38815 .75319 L .38806 .75182 L F
.38659 .7513 m .38806 .75182 L .38555 .7527 L F
.752 .541 .61 r
.63683 .63772 m .64136 .63648 L .63711 .63576 L F
.983 .908 .615 r
.64136 .63648 m .64045 .63869 L .64137 .63633 L F
.49 .255 .484 r
.35716 .69173 m .35692 .69329 L .35485 .69399 L F
.74 .643 .753 r
.35908 .69128 m .35692 .69329 L .35716 .69173 L F
.481 .254 .493 r
.36351 .68605 m .36117 .68881 L .3617 .68675 L F
.742 .73 .84 r
.56816 .81764 m .57114 .81791 L .5712 .81692 L F
.591 .656 .882 r
.57114 .81791 m .57234 .81642 L .5712 .81692 L F
.57114 .81791 m .57372 .81769 L .57234 .81642 L F
.305 .752 .961 r
.4243 .72402 m .42771 .72444 L .42574 .72483 L F
.253 0 .184 r
.64622 .64036 m .64814 .64049 L .64876 .63849 L F
.224 0 0 r
.64508 .64198 m .64814 .64049 L .64622 .64036 L F
.389 .222 .53 r
.48222 .85755 m .48212 .85991 L .48054 .86028 L F
.466 .533 .842 r
.48054 .86028 m .48212 .85991 L .48069 .85725 L F
0 0 .35 r
.5477 .8087 m .54677 .81031 L .54696 .80703 L F
.441 .109 .305 r
.4034 .77992 m .40542 .77956 L .40654 .77706 L F
.488 .133 .289 r
.40542 .77956 m .40871 .77709 L .40654 .77706 L F
.516 .152 .287 r
.37325 .73174 m .37548 .73167 L .37667 .72969 L F
.438 .07 .241 r
.37667 .72969 m .37801 .73069 L .3786 .72923 L F
.37667 .72969 m .37548 .73167 L .37801 .73069 L F
.708 .887 .963 r
.71006 .72868 m .707 .72893 L .70961 .72713 L F
.604 .651 .869 r
.71146 .72592 m .71006 .72868 L .70961 .72713 L F
.71146 .72592 m .71355 .728 L .71006 .72868 L F
0 0 0 r
.67484 .63961 m .67435 .63907 L .67573 .63792 L F
.67484 .63961 m .67342 .64059 L .67435 .63907 L F
.426 .168 .417 r
.35692 .69329 m .35439 .69694 L .35485 .69399 L F
.593 .734 .942 r
.64093 .61471 m .64304 .61412 L .64101 .61324 L F
.64093 .61471 m .64304 .61412 L .64101 .61324 L F
.49 .724 .975 r
.68232 .5897 m .68026 .58997 L .67928 .58841 L F
.972 .723 .501 r
.37418 .88897 m .37542 .89233 L .37543 .88968 L F
.267 0 0 r
.41315 .78729 m .41665 .78552 L .41514 .78698 L F
.223 0 0 r
.41665 .78552 m .41721 .78639 L .41514 .78698 L F
.41665 .78552 m .41873 .78519 L .41721 .78639 L F
.742 .239 .029 r
.70833 .73379 m .70491 .73163 L .70804 .73252 L F
.785 .612 .666 r
.57342 .80389 m .57469 .80673 L .57447 .80431 L F
.472 .259 .509 r
.36112 .69062 m .35936 .68932 L .36117 .68881 L F
.36112 .69062 m .35908 .69128 L .35936 .68932 L F
.568 .436 .661 r
.35948 .78244 m .35721 .78044 L .35927 .78007 L F
.35948 .78244 m .35738 .7828 L .35721 .78044 L F
.862 .784 .773 r
.67133 .60119 m .66849 .60151 L .67082 .6003 L F
.67133 .60119 m .66946 .60393 L .66849 .60151 L F
.891 .97 .829 r
.67344 .59851 m .67133 .60119 L .67082 .6003 L F
.722 .471 .547 r
.56588 .79073 m .56773 .79314 L .56807 .79128 L F
.671 .38 .47 r
.56807 .79128 m .57116 .79277 L .57108 .79076 L F
.56807 .79128 m .56773 .79314 L .57116 .79277 L F
.499 .239 .451 r
.34477 .75061 m .34682 .75028 L .34729 .74819 L F
.52 .258 .458 r
.34729 .74819 m .34892 .74994 L .34911 .74768 L F
.34729 .74819 m .34682 .75028 L .34892 .74994 L F
.798 .729 .788 r
.68467 .70018 m .68101 .70185 L .68359 .69928 L F
.712 .847 .947 r
.6871 .69914 m .68467 .70018 L .68359 .69928 L F
.709 .663 .803 r
.72537 .71045 m .72482 .71331 L .72356 .71315 L F
.513 .874 .984 r
.72735 .7155 m .72356 .71315 L .72482 .71331 L F
.834 .81 .826 r
.63025 .615 m .62797 .61773 L .62666 .61659 L F
.431 .868 .909 r
.35641 .81133 m .35564 .81199 L .35744 .81133 L F
0 0 0 r
.35497 .81261 m .35564 .81199 L .35641 .81133 L F
.372 .394 .754 r
.67212 .60767 m .67198 .60719 L .67262 .60877 L F
.377 .758 .99 r
.48934 .88894 m .49026 .88808 L .48839 .88799 L F
.48934 .88894 m .49135 .88879 L .49026 .88808 L F
.54 .622 .882 r
.71762 .61355 m .71564 .61505 L .7161 .61441 L F
.68 .264 .251 r
.49464 .87105 m .49622 .87123 L .49376 .87128 L F
.371 .376 .734 r
.49622 .87123 m .49861 .87333 L .49791 .87087 L F
.559 .015 0 r
.72348 .70653 m .72265 .70553 L .72254 .70461 L F
.72348 .70653 m .72471 .70738 L .72265 .70553 L F
.728 .436 .484 r
.71697 .60707 m .71631 .60855 L .7144 .60812 L F
.012 0 .454 r
.71804 .60352 m .71697 .60707 L .71612 .60389 L F
.489 .804 1 r
.71769 .60824 m .71631 .60855 L .71697 .60707 L F
.172 .103 .532 r
.71926 .60611 m .71769 .60824 L .71804 .60352 L F
.489 .804 1 r
.71769 .60824 m .71874 .60781 L .71631 .60855 L F
.055 0 0 r
.71631 .60855 m .71788 .60807 L .71658 .60868 L F
.419 .434 .769 r
.71926 .60611 m .71874 .60781 L .71769 .60824 L F
.055 0 0 r
.71788 .60807 m .71874 .60781 L .71805 .60809 L F
.71788 .60807 m .71805 .60809 L .71658 .60868 L F
.012 0 .454 r
.71804 .60352 m .7177 .60806 L .71697 .60707 L F
.7177 .60806 m .71769 .60824 L .71757 .60804 L F
.7177 .60806 m .71757 .60804 L .71697 .60707 L F
.418 .73 .99 r
.67618 .71353 m .67896 .71435 L .67867 .71263 L F
0 .325 .805 r
.67896 .71435 m .6798 .71445 L .67867 .71263 L F
.67896 .71435 m .68086 .71556 L .6798 .71445 L F
.54 .748 .972 r
.45832 .72927 m .45768 .73096 L .45612 .72936 L F
.45832 .72927 m .45985 .73071 L .45768 .73096 L F
.553 .256 .417 r
.35106 .74263 m .35322 .74243 L .35389 .74009 L F
.514 .218 .403 r
.35389 .74009 m .35533 .742 L .35582 .73975 L F
.35389 .74009 m .35322 .74243 L .35533 .742 L F
.578 .544 .78 r
.60563 .6553 m .60744 .65511 L .60759 .65413 L F
.429 0 0 r
.67311 .61562 m .67358 .61598 L .6716 .61447 L F
.67311 .61562 m .6716 .61447 L .6721 .61302 L F
.35 0 0 r
.31207 .65273 m .31362 .6531 L .31514 .65257 L F
.165 .703 .745 r
.31559 .6524 m .31514 .65257 L .31362 .6531 L F
0 0 0 r
.31559 .6524 m .31472 .65293 L .31585 .65229 L F
.306 .791 .735 r
.31559 .6524 m .31631 .65203 L .31781 .65158 L F
0 0 0 r
.31559 .6524 m .31585 .65229 L .31631 .65203 L F
.165 .703 .745 r
.31559 .6524 m .31725 .65219 L .31523 .65256 L F
.31559 .6524 m .31523 .65256 L .31514 .65257 L F
0 0 0 r
.33962 .8137 m .33935 .81391 L .34033 .81373 L F
.33962 .8137 m .33837 .8144 L .33935 .81391 L F
.636 .458 .625 r
.55249 .79829 m .55467 .79586 L .55253 .79625 L F
.271 .231 .629 r
.48323 .85419 m .48164 .85241 L .48315 .85187 L F
.761 .556 .621 r
.53971 .85441 m .53695 .85223 L .53748 .8546 L F
.286 0 0 r
.70429 .60423 m .70513 .60392 L .70216 .60394 L F
.564 .924 .752 r
.70794 .60192 m .70513 .60392 L .70429 .60423 L F
.546 .389 .62 r
.34892 .74535 m .35106 .74263 L .34874 .74249 L F
.353 0 0 r
.41082 .77616 m .41286 .77604 L .4143 .77474 L F
.393 0 0 r
.41286 .77604 m .41638 .77494 L .4143 .77474 L F
.763 .544 .6 r
.69386 .64354 m .6904 .64079 L .69367 .64126 L F
.374 0 .058 r
.70902 .62846 m .71116 .62828 L .71167 .62736 L F
.543 .896 .677 r
.71072 .62771 m .71095 .62742 L .71205 .62666 L F
.374 0 .058 r
.71074 .62744 m .71095 .62742 L .71205 .62666 L F
.543 .896 .677 r
.71095 .62742 m .71109 .62724 L .71205 .62666 L F
.374 0 .058 r
.71095 .62742 m .71167 .62736 L .71205 .62666 L F
.56 .606 .856 r
.71072 .62771 m .71019 .62775 L .71074 .62744 L F
.71072 .62771 m .71074 .62744 L .71095 .62742 L F
.374 0 .058 r
.70902 .62846 m .71167 .62736 L .71074 .62744 L F
.56 .606 .856 r
.71095 .62742 m .71074 .62744 L .71109 .62724 L F
.71019 .62775 m .70776 .62795 L .71109 .62724 L F
.374 0 .058 r
.70902 .62846 m .71074 .62744 L .71109 .62724 L F
.71074 .62744 m .71205 .62666 L .71109 .62724 L F
.459 .128 .317 r
.70675 .62885 m .71109 .62724 L .70776 .62795 L F
.531 .849 .998 r
.72471 .70738 m .72526 .70808 L .72213 .70805 L F
.676 .272 .273 r
.72526 .70808 m .72439 .70991 L .72213 .70805 L F
.988 .82 .436 r
.72471 .70738 m .72439 .70991 L .72526 .70808 L F
.58 .384 .579 r
.72526 .70808 m .72758 .70967 L .72537 .71045 L F
.692 .226 .141 r
.5403 .83691 m .54311 .83816 L .54245 .83618 L F
.397 .843 .928 r
.34015 .67555 m .33826 .67549 L .33648 .67598 L F
.099 .654 .786 r
.34165 .67546 m .33826 .67549 L .34015 .67555 L F
.155 .201 .658 r
.6615 .61418 m .66168 .61111 L .66301 .61247 L F
.6615 .61418 m .66305 .6127 L .66168 .61111 L F
.234 .697 .947 r
.71198 .60812 m .71077 .60759 L .70828 .60736 L F
.475 .694 .964 r
.71198 .60812 m .71344 .60698 L .71077 .60759 L F
.71198 .60812 m .7144 .60812 L .71344 .60698 L F
.207 .194 .622 r
.72217 .62151 m .72134 .62519 L .72183 .62281 L F
0 0 0 r
.3665 .73457 m .36681 .73557 L .36841 .73398 L F
.3665 .73457 m .36529 .7365 L .36681 .73557 L F
.472 .489 .794 r
.52906 .82797 m .52988 .82489 L .52817 .8243 L F
.52906 .82797 m .53096 .82814 L .52988 .82489 L F
.577 .502 .734 r
.47817 .85181 m .47968 .84925 L .47806 .84941 L F
.975 .879 .506 r
.61239 .65143 m .61575 .64967 L .61346 .65076 L F
.814 .823 .856 r
.63849 .6039 m .63577 .60418 L .63728 .60235 L F
.04 0 .426 r
.64676 .63259 m .6455 .63595 L .64464 .6359 L F
.64676 .63259 m .6469 .63501 L .6455 .63595 L F
.473 .892 .902 r
.6455 .63595 m .6469 .63501 L .64464 .6359 L F
.84 .716 .727 r
.70475 .60873 m .70659 .60929 L .70537 .60604 L F
.848 .66 .648 r
.70353 .61131 m .70581 .61157 L .70659 .60929 L F
.664 .63 .805 r
.70537 .60604 m .70659 .60929 L .70828 .60736 L F
.643 .481 .649 r
.32962 .7695 m .33205 .76934 L .33194 .76694 L F
.666 .495 .644 r
.32964 .77191 m .33205 .76934 L .32962 .7695 L F
.619 .463 .648 r
.33194 .76694 m .33205 .76934 L .3342 .76664 L F
.251 0 .057 r
.63944 .65472 m .63848 .65601 L .63583 .65697 L F
.437 .043 .193 r
.63944 .65472 m .64027 .65592 L .63848 .65601 L F
.63944 .65472 m .64112 .65416 L .64027 .65592 L F
.8 .811 .86 r
.53369 .86299 m .5363 .86071 L .53466 .85973 L F
.581 .627 .863 r
.69119 .69732 m .69013 .70022 L .68877 .69896 L F
.69119 .69732 m .69249 .6998 L .69013 .70022 L F
.569 .27 .422 r
.42712 .77141 m .42937 .77144 L .42977 .76974 L F
.58 .299 .455 r
.42937 .77144 m .43199 .76952 L .42977 .76974 L F
.773 .683 .764 r
.71215 .7021 m .71314 .7056 L .70996 .7048 L F
.313 .123 .456 r
.71314 .7056 m .71193 .70789 L .70996 .7048 L F
.71314 .7056 m .71333 .70747 L .71193 .70789 L F
.71193 .70789 m .71333 .70747 L .71314 .7056 L F
.765 .678 .767 r
.71529 .70255 m .71314 .7056 L .71215 .7021 L F
.81 .677 .717 r
.71193 .70789 m .70823 .70751 L .70996 .7048 L F
.761 .489 .522 r
.71193 .70789 m .70799 .70987 L .70823 .70751 L F
.71193 .70789 m .71191 .7109 L .70799 .70987 L F
.351 .103 .39 r
.36777 .68075 m .36603 .68136 L .36824 .67878 L F
.453 .269 .541 r
.36777 .68075 m .36576 .68353 L .36603 .68136 L F
.881 .951 .85 r
.68609 .60621 m .68798 .60538 L .68782 .60481 L F
.425 .7 .979 r
.68798 .60538 m .68994 .60448 L .68782 .60481 L F
.68798 .60538 m .69124 .60569 L .68994 .60448 L F
.461 .2 .431 r
.36974 .6802 m .36824 .67878 L .37022 .67826 L F
.36974 .6802 m .36777 .68075 L .36824 .67878 L F
.397 0 .069 r
.38081 .72916 m .38286 .72902 L .38434 .72739 L F
.358 0 .042 r
.38434 .72739 m .38286 .72902 L .38575 .72793 L F
0 0 0 r
.37872 .75584 m .37669 .75827 L .3776 .75689 L F
.58 .226 .333 r
.47141 .76643 m .46779 .7687 L .46782 .76732 L F
.47141 .76643 m .46984 .76867 L .46779 .7687 L F
.643 .293 .364 r
.47322 .76693 m .46984 .76867 L .47141 .76643 L F
.771 .695 .779 r
.71591 .71411 m .71419 .71619 L .71255 .71398 L F
.844 .598 .567 r
.7138 .71811 m .71229 .71825 L .71419 .71619 L F
.563 .726 .951 r
.42374 .74162 m .42435 .7397 L .42237 .73992 L F
.42374 .74162 m .42602 .74149 L .42435 .7397 L F
.758 .587 .665 r
.60594 .66146 m .60383 .65967 L .60658 .65979 L F
.688 .405 .488 r
.60658 .65979 m .60866 .66199 L .60594 .66146 L F
.721 .398 .431 r
.60895 .66041 m .60866 .66199 L .60658 .65979 L F
.826 .905 .894 r
.68658 .61113 m .69003 .60977 L .68892 .60885 L F
.662 .669 .847 r
.70658 .61361 m .70768 .61543 L .70984 .6141 L F
.737 .331 .28 r
.55894 .79088 m .56101 .79263 L .56237 .79124 L F
.73 .322 .275 r
.56101 .79263 m .56427 .79312 L .56237 .79124 L F
.633 .36 .486 r
.56237 .79124 m .56427 .79312 L .56588 .79073 L F
.328 0 .205 r
.64392 .61556 m .64535 .61369 L .64304 .61412 L F
.685 .313 .336 r
.6459 .61262 m .64842 .61442 L .64613 .61218 L F
.463 .286 .555 r
.65043 .61313 m .64865 .61433 L .64851 .61196 L F
.461 .855 .656 r
.64979 .61356 m .64842 .61442 L .64865 .61433 L F
0 0 0 r
.64647 .61521 m .64865 .61433 L .64731 .61512 L F
.461 .855 .656 r
.64842 .61442 m .64731 .61512 L .64843 .61446 L F
.64842 .61442 m .64843 .61446 L .64865 .61433 L F
0 .153 .606 r
.64665 .6131 m .64842 .61442 L .6459 .61262 L F
.685 .313 .336 r
.64842 .61442 m .6485 .61448 L .64843 .61441 L F
0 .153 .606 r
.64842 .61442 m .6485 .61448 L .64842 .61442 L F
.64842 .61442 m .64842 .61442 L .6459 .61262 L F
.685 .313 .336 r
.64574 .6125 m .6459 .61262 L .64592 .61198 L F
.328 0 .205 r
.64535 .61369 m .64608 .61273 L .64567 .61272 L F
.64608 .61273 m .64639 .61233 L .64589 .6126 L F
0 .153 .606 r
.64608 .61273 m .6459 .61262 L .64574 .6125 L F
.328 0 .205 r
.64608 .61273 m .64589 .6126 L .64567 .61272 L F
.685 .313 .336 r
.64502 .61199 m .64574 .6125 L .64592 .61198 L F
0 .153 .606 r
.64589 .6126 m .64574 .6125 L .64502 .61199 L F
.541 .315 .521 r
.64304 .61412 m .64589 .6126 L .64502 .61199 L F
.685 .313 .336 r
.6459 .61262 m .64613 .61218 L .64592 .61198 L F
.541 .315 .521 r
.64589 .6126 m .64639 .61233 L .64502 .61199 L F
0 .153 .606 r
.64608 .61273 m .64589 .6126 L .64502 .61199 L F
.64665 .6131 m .64608 .61273 L .64502 .61199 L F
.724 .578 .691 r
.64608 .61273 m .64665 .6131 L .64639 .61233 L F
.64535 .61369 m .64665 .6131 L .64608 .61273 L F
.64392 .61556 m .64479 .61477 L .64535 .61369 L F
.64479 .61477 m .64665 .6131 L .64535 .61369 L F
.685 .313 .336 r
.64842 .61442 m .64843 .61441 L .64592 .61198 L F
.461 .855 .656 r
.64756 .61496 m .64731 .61512 L .64979 .61356 L F
.685 .313 .336 r
.64592 .61198 m .64844 .61442 L .64851 .61196 L F
.64844 .61442 m .6485 .61448 L .6485 .61437 L F
.64844 .61442 m .6485 .61437 L .64851 .61196 L F
.489 .863 .643 r
.6485 .61437 m .65043 .61313 L .64851 .61196 L F
.461 .855 .656 r
.65043 .61313 m .6485 .61437 L .64979 .61356 L F
.489 .863 .643 r
.6485 .61448 m .65043 .61313 L .6485 .61437 L F
.671 .694 .863 r
.64665 .6131 m .6503 .61312 L .64996 .61338 L F
.461 .855 .656 r
.65043 .61313 m .64858 .61431 L .6485 .61437 L F
.64858 .61431 m .64835 .61446 L .6485 .61437 L F
.671 .694 .863 r
.64842 .61442 m .64996 .61338 L .6485 .61448 L F
.64665 .6131 m .64994 .61337 L .64842 .61442 L F
.64994 .61337 m .64858 .61431 L .64842 .61442 L F
.461 .855 .656 r
.6486 .61429 m .6503 .61312 L .64739 .61506 L F
.65043 .61313 m .6503 .61312 L .6486 .61429 L F
.671 .694 .863 r
.64994 .61337 m .64996 .61338 L .64858 .61431 L F
.461 .855 .656 r
.64858 .61431 m .64756 .61496 L .64835 .61446 L F
.64756 .61496 m .64739 .61506 L .64731 .61512 L F
.65043 .61313 m .64739 .61506 L .64756 .61496 L F
.328 0 .205 r
.64535 .61369 m .64567 .61272 L .64304 .61412 L F
.699 .77 .907 r
.36923 .78742 m .36623 .78709 L .36794 .78655 L F
.721 .788 .905 r
.37035 .78473 m .36923 .78742 L .36794 .78655 L F
.37035 .78473 m .37201 .786 L .36923 .78742 L F
.421 .027 .183 r
.42414 .78237 m .42288 .7845 L .4208 .78472 L F
.33 0 .133 r
.42489 .78395 m .42414 .78237 L .42633 .78243 L F
.42489 .78395 m .42288 .7845 L .42414 .78237 L F
.77 .645 .724 r
.43337 .74309 m .42907 .74491 L .42939 .74302 L F
.314 0 .078 r
.6434 .65372 m .64027 .65592 L .64112 .65416 L F
.109 0 0 r
.64347 .6168 m .64252 .61807 L .64074 .61857 L F
0 0 0 r
.64347 .6168 m .64647 .61521 L .64552 .61617 L F
.64347 .6168 m .64552 .61617 L .64252 .61807 L F
.464 .366 .659 r
.47581 .86556 m .47771 .86569 L .47732 .86225 L F
.665 .543 .706 r
.47581 .86556 m .47966 .86981 L .47771 .86569 L F
.803 .746 .8 r
.6812 .60912 m .68341 .60714 L .68173 .60496 L F
.57 .549 .792 r
.68341 .60714 m .6858 .6036 L .68385 .60425 L F
.68196 .60525 m .68385 .60425 L .68173 .60496 L F
.68341 .60714 m .68385 .60425 L .68196 .60525 L F
.763 .984 .905 r
.68526 .6035 m .68701 .60246 L .68474 .60315 L F
.57 .549 .792 r
.6858 .6036 m .68614 .60309 L .68519 .60349 L F
.6858 .6036 m .68519 .60349 L .68173 .60496 L F
.68341 .60714 m .68609 .60621 L .68614 .60309 L F
.014 .068 .574 r
.68614 .60309 m .68609 .60621 L .6869 .60462 L F
.763 .984 .905 r
.6869 .60462 m .68701 .60258 L .68526 .6035 L F
.68701 .60258 m .68701 .60246 L .68526 .6035 L F
.638 .149 .074 r
.6869 .60462 m .68526 .6035 L .68365 .60423 L F
.68526 .6035 m .68474 .60315 L .68451 .60338 L F
0 0 0 r
.68173 .60496 m .68519 .60349 L .68365 .60423 L F
.638 .149 .074 r
.68526 .6035 m .68519 .60349 L .68365 .60423 L F
0 0 0 r
.68519 .60349 m .68614 .60309 L .68365 .60423 L F
.638 .149 .074 r
.68519 .60349 m .68451 .60338 L .68365 .60423 L F
.79 .603 .647 r
.61197 .66003 m .60866 .66199 L .60895 .66041 L F
.889 .99 .751 r
.67492 .61284 m .67546 .61345 L .67358 .61598 L F
0 0 .023 r
.67492 .61284 m .67387 .61547 L .67475 .6144 L F
.67492 .61284 m .67475 .6144 L .67467 .6126 L F
.624 .172 0 r
.67419 .61169 m .67523 .61313 L .67492 .61284 L F
.67439 .61194 m .67546 .61345 L .67419 .61169 L F
.67393 .61129 m .67439 .61194 L .67419 .61169 L F
.67393 .61129 m .67492 .61284 L .67502 .61037 L F
0 0 .023 r
.67492 .61284 m .67467 .6126 L .67463 .61181 L F
.624 .172 0 r
.67523 .61313 m .67546 .61345 L .67492 .61284 L F
.797 .946 .921 r
.67026 .61247 m .6721 .61302 L .67397 .61143 L F
.67383 .61126 m .67397 .61143 L .67441 .61106 L F
.67026 .61247 m .67397 .61143 L .67383 .61126 L F
.975 .879 .506 r
.61239 .65143 m .61241 .64953 L .61575 .64967 L F
.61239 .65143 m .61195 .65127 L .61241 .64953 L F
.372 .394 .754 r
.67212 .60767 m .67025 .60931 L .66936 .60616 L F
.313 .55 .918 r
.67294 .60883 m .67025 .60931 L .67212 .60767 L F
.67294 .60883 m .67441 .61106 L .67025 .60931 L F
.591 .885 .991 r
.64538 .62482 m .6421 .62496 L .64299 .62467 L F
.6421 .62496 m .64538 .62482 L .64299 .62467 L F
.79 .603 .647 r
.61197 .66003 m .61192 .66245 L .60866 .66199 L F
.708 .533 .651 r
.61524 .66219 m .61197 .66003 L .61387 .65965 L F
.61524 .66219 m .61192 .66245 L .61197 .66003 L F
.994 .773 .491 r
.70799 .70987 m .7086 .71481 L .70919 .71133 L F
.812 .906 .502 r
.71143 .71207 m .70919 .71133 L .7086 .71481 L F
.831 .985 .874 r
.67727 .62896 m .67864 .6278 L .67593 .62896 L F
0 0 0 r
.67593 .62896 m .67864 .6278 L .6797 .62752 L F
.825 .744 .774 r
.67698 .6146 m .67358 .61598 L .67546 .61345 L F
.67698 .6146 m .67503 .61712 L .67358 .61598 L F
.891 .97 .829 r
.67344 .59851 m .67082 .6003 L .67291 .59816 L F
.708 .671 .811 r
.6818 .72704 m .68274 .72969 L .67961 .72929 L F
0 .523 .731 r
.67961 .72929 m .6823 .72961 L .68274 .72969 L F
.567 .589 .835 r
.68363 .72758 m .68274 .72969 L .6818 .72704 L F
.888 .988 .738 r
.68363 .72758 m .6823 .72961 L .68274 .72969 L F
.614 .293 .404 r
.45256 .77214 m .45162 .77457 L .4492 .77428 L F
.482 .161 .346 r
.45404 .77373 m .45256 .77214 L .45477 .77231 L F
.45404 .77373 m .45162 .77457 L .45256 .77214 L F
.569 .571 .815 r
.45786 .74534 m .45857 .74174 L .45643 .74226 L F
.45786 .74534 m .45988 .7449 L .45857 .74174 L F
.611 .508 .712 r
.45791 .74741 m .45988 .7449 L .45786 .74534 L F
.385 .149 .428 r
.33986 .68931 m .34163 .68887 L .34206 .68667 L F
.562 .454 .689 r
.33993 .69165 m .34163 .68887 L .33986 .68931 L F
.02 .417 .861 r
.65025 .58874 m .64908 .58872 L .64823 .58699 L F
.65025 .58874 m .65176 .5904 L .64908 .58872 L F
.394 .205 .503 r
.54272 .81056 m .54355 .81212 L .54401 .80942 L F
.695 .557 .694 r
.61756 .65998 m .61524 .66219 L .61387 .65965 L F
.597 .412 .602 r
.48449 .8682 m .48626 .86844 L .48585 .86584 L F
.545 .376 .603 r
.48585 .86584 m .48899 .86756 L .48828 .86558 L F
.48585 .86584 m .48626 .86844 L .48899 .86756 L F
.57 .641 .882 r
.72287 .71686 m .72203 .71961 L .72145 .7189 L F
.72287 .71686 m .72425 .71931 L .72203 .71961 L F
.633 .637 .836 r
.7251 .7197 m .72203 .71961 L .72425 .71931 L F
.633 .591 .789 r
.4794 .74534 m .47756 .74767 L .47729 .74592 L F
.4794 .74534 m .48049 .74839 L .47756 .74767 L F
.512 .582 .862 r
.35814 .66374 m .35671 .66539 L .35549 .66285 L F
.45 .406 .717 r
.35814 .66374 m .3571 .66753 L .35671 .66539 L F
.439 .438 .761 r
.34341 .68082 m .34438 .68405 L .34582 .68336 L F
.267 .068 .414 r
.34438 .68405 m .34399 .68619 L .34582 .68336 L F
.346 .108 .404 r
.66293 .60138 m .66484 .601 L .66569 .6017 L F
.66293 .60138 m .66284 .60323 L .66484 .601 L F
.398 0 .146 r
.39799 .79311 m .39457 .79535 L .39632 .79403 L F
0 0 0 r
.38711 .77957 m .38536 .78088 L .3843 .78183 L F
.828 .771 .798 r
.62416 .62073 m .62557 .62219 L .62329 .625 L F
.834 .81 .826 r
.63025 .615 m .62666 .61659 L .62907 .61407 L F
.829 .808 .831 r
.63115 .61137 m .63025 .615 L .62907 .61407 L F
.63115 .61137 m .63251 .61247 L .63025 .615 L F
.615 .954 .815 r
.51261 .8835 m .51469 .88175 L .51199 .88381 L F
.51261 .8835 m .51541 .88167 L .51469 .88175 L F
.565 .309 .487 r
.34206 .68667 m .34387 .68847 L .34399 .68619 L F
.34206 .68667 m .34163 .68887 L .34387 .68847 L F
.502 .299 .537 r
.37161 .76131 m .36962 .76381 L .3695 .76146 L F
.649 .854 .978 r
.71889 .71849 m .71663 .71917 L .71789 .71765 L F
.821 .667 .692 r
.57234 .81642 m .57515 .81467 L .57386 .8138 L F
.57234 .81642 m .57372 .81769 L .57515 .81467 L F
.519 .842 .999 r
.69692 .63001 m .69966 .62939 L .6984 .62864 L F
.69692 .63001 m .69966 .62939 L .6984 .62864 L F
.296 .648 .969 r
.43205 .72444 m .4311 .7252 L .42987 .72457 L F
.43205 .72444 m .43331 .72548 L .4311 .7252 L F
.803 .805 .853 r
.62186 .62388 m .62329 .625 L .62066 .62502 L F
.829 .705 .727 r
.62066 .62502 m .62329 .625 L .62193 .62755 L F
.828 .771 .798 r
.62416 .62073 m .62329 .625 L .62186 .62388 L F
.878 .642 .577 r
.57342 .80389 m .57328 .80664 L .57469 .80673 L F
.865 .573 .492 r
.57328 .80664 m .57345 .80876 L .57469 .80673 L F
.942 .699 .541 r
.57345 .80876 m .57499 .80939 L .57469 .80673 L F
.632 .62 .821 r
.68224 .60115 m .68344 .59743 L .68111 .59806 L F
.68224 .60115 m .68504 .60145 L .68344 .59743 L F
.538 .383 .618 r
.68224 .60115 m .68249 .6037 L .68474 .60315 L F
.78 .519 .542 r
.50301 .88186 m .50572 .88084 L .50483 .88187 L F
.468 .754 .992 r
.4407 .72607 m .43987 .72728 L .43862 .7261 L F
.4407 .72607 m .44214 .72712 L .43987 .72728 L F
.28 0 0 r
.40464 .72347 m .40676 .72337 L .40794 .72243 L F
.43 0 0 r
.40794 .72243 m .40676 .72337 L .41012 .72293 L F
.575 .619 .859 r
.69845 .60037 m .69661 .60135 L .69479 .59729 L F
.598 .337 .493 r
.43483 .76894 m .43711 .76905 L .43759 .76693 L F
.268 0 0 r
.43759 .76693 m .43958 .76664 L .4402 .76626 L F
.5 .23 .436 r
.43711 .76905 m .43958 .76664 L .43759 .76693 L F
.9 .79 .73 r
.53474 .83081 m .53546 .83355 L .53407 .83262 L F
.887 .883 .824 r
.53546 .83355 m .53214 .83564 L .53407 .83262 L F
.53546 .83355 m .53333 .83634 L .53214 .83564 L F
.555 .37 .585 r
.53546 .83355 m .53547 .83603 L .53333 .83634 L F
.678 .533 .681 r
.53884 .83552 m .53547 .83603 L .53546 .83355 L F
.692 .226 .141 r
.5403 .83691 m .54103 .83828 L .54311 .83816 L F
.582 .553 .788 r
.48258 .74804 m .48127 .75056 L .48049 .74839 L F
.48258 .74804 m .48337 .75013 L .48127 .75056 L F
.64 .508 .687 r
.484 .75299 m .48127 .75056 L .48337 .75013 L F
.484 .75299 m .48185 .75367 L .48127 .75056 L F
.886 .708 .657 r
.5711 .80302 m .57342 .80389 L .57284 .80286 L F
.939 .639 .444 r
.5711 .80302 m .57328 .80664 L .57342 .80389 L F
.768 .449 .446 r
.57608 .80214 m .57284 .80286 L .57342 .80389 L F
.373 .452 .814 r
.36242 .67202 m .36128 .67357 L .35997 .67041 L F
.477 .6 .896 r
.36242 .67202 m .36363 .67411 L .36128 .67357 L F
.784 .683 .753 r
.61427 .6464 m .61575 .64967 L .61241 .64953 L F
.78 .681 .754 r
.61747 .64673 m .61575 .64967 L .61427 .6464 L F
.771 .695 .779 r
.71591 .71411 m .71255 .71398 L .71448 .71297 L F
.689 .545 .684 r
.4775 .87284 m .47909 .87067 L .47688 .87095 L F
.749 .504 .561 r
.57116 .79277 m .57294 .79328 L .57108 .79076 L F
.497 .025 .064 r
.4402 .76626 m .43958 .76664 L .44251 .7664 L F
0 .312 .788 r
.39076 .78005 m .39259 .78183 L .39023 .78034 L F
.408 .234 .531 r
.71591 .73159 m .71415 .7345 L .71372 .73198 L F
.361 .831 .795 r
.30949 .65365 m .31031 .65311 L .31207 .65273 L F
.388 .802 .599 r
.30949 .65365 m .30864 .65419 L .31031 .65311 L F
.964 .679 .445 r
.67727 .63319 m .67727 .62896 L .67593 .62896 L F
.355 0 0 r
.64999 .63956 m .64876 .63849 L .64814 .64049 L F
.64999 .63956 m .65105 .6382 L .64876 .63849 L F
0 .173 .707 r
.47751 .87916 m .47886 .88182 L .47902 .88122 L F
0 .095 .638 r
.47886 .88182 m .48059 .88323 L .47902 .88122 L F
.47886 .88182 m .47978 .88362 L .48059 .88323 L F
.579 .05 0 r
.53547 .83603 m .53214 .83564 L .53333 .83634 L F
.606 .395 .568 r
.68033 .61052 m .68052 .61051 L .68103 .60836 L F
.803 .746 .8 r
.6812 .60912 m .68161 .60593 L .68103 .60836 L F
.718 .476 0 r
.68166 .61157 m .6812 .60912 L .68103 .60836 L F
.68166 .61157 m .68103 .60836 L .68308 .61037 L F
.606 .395 .568 r
.68052 .61051 m .68308 .61037 L .68103 .60836 L F
.803 .746 .8 r
.68161 .60593 m .68173 .60496 L .68103 .60836 L F
.565 .773 .976 r
.44838 .74096 m .44967 .73977 L .44752 .7399 L F
.44838 .74096 m .45061 .74064 L .44967 .73977 L F
.288 .541 .917 r
.73149 .71389 m .73477 .71525 L .7345 .71616 L F
.992 .747 .387 r
.73477 .71525 m .73555 .71823 L .7345 .71616 L F
.617 .457 .642 r
.41297 .74287 m .40973 .74538 L .4098 .74274 L F
.523 .257 .454 r
.37449 .75852 m .37381 .76125 L .37161 .76131 L F
.504 .223 .421 r
.37669 .75827 m .37381 .76125 L .37449 .75852 L F
.226 0 0 r
.39259 .78183 m .39569 .78245 L .3936 .78278 L F
.983 .852 .632 r
.64502 .61199 m .64567 .60955 L .64407 .61054 L F
.76 .988 .766 r
.647 .60807 m .6464 .60806 L .64567 .60955 L F
.758 .982 .736 r
.64567 .60955 m .6464 .60806 L .64407 .61054 L F
.53 .706 .951 r
.35436 .66161 m .3536 .66321 L .35246 .66158 L F
.35436 .66161 m .35549 .66285 L .3536 .66321 L F
.451 .288 .568 r
.34942 .83613 m .34754 .83959 L .34934 .83929 L F
.597 .534 .755 r
.46949 .73739 m .46739 .73798 L .46629 .7343 L F
.541 .557 .82 r
.47017 .74009 m .46739 .73798 L .46949 .73739 L F
.85 .751 .754 r
.63115 .61137 m .63301 .60841 L .6338 .61119 L F
.839 .807 .82 r
.63115 .61137 m .6338 .61119 L .63251 .61247 L F
.757 .702 .8 r
.63301 .60841 m .63458 .61023 L .6338 .61119 L F
.623 .41 .572 r
.45771 .76077 m .45999 .75844 L .45793 .75884 L F
.568 .617 .861 r
.66946 .60393 m .66569 .6017 L .66849 .60151 L F
.274 0 .09 r
.71585 .63226 m .71623 .63265 L .7141 .63271 L F
.293 0 .173 r
.7141 .63271 m .71548 .63409 L .71336 .63436 L F
.7141 .63271 m .71623 .63265 L .71548 .63409 L F
.844 .609 .584 r
.57296 .7953 m .57507 .79352 L .57294 .79328 L F
.57296 .7953 m .57507 .79594 L .57507 .79352 L F
.95 .708 .537 r
.63654 .59539 m .63798 .59851 L .63643 .59766 L F
.948 .716 .554 r
.63798 .59851 m .63637 .59992 L .63643 .59766 L F
.63798 .59851 m .63794 .60115 L .63637 .59992 L F
.652 .294 .351 r
.41638 .77494 m .41845 .77671 L .41962 .77455 L F
.464 .1 .263 r
.41845 .77671 m .42174 .77424 L .41962 .77455 L F
.364 .832 .884 r
.36801 .80511 m .36719 .80481 L .36415 .80675 L F
.36801 .80511 m .37005 .80454 L .36719 .80481 L F
.443 .721 .984 r
.66465 .6193 m .66612 .61805 L .66387 .61792 L F
.66465 .6193 m .66642 .61909 L .66612 .61805 L F
.389 .367 .713 r
.71414 .61981 m .7163 .61906 L .71528 .61637 L F
.174 .056 .469 r
.71414 .61981 m .71585 .62076 L .7163 .61906 L F
.71414 .61981 m .71408 .6222 L .71585 .62076 L F
.771 .83 .899 r
.50058 .88797 m .5004 .88629 L .49865 .88789 L F
.50058 .88797 m .50218 .88672 L .5004 .88629 L F
.773 .604 .671 r
.71201 .69979 m .70881 .69749 L .71189 .69818 L F
.71201 .69979 m .70861 .69962 L .70881 .69749 L F
.775 .548 .591 r
.71201 .69979 m .7089 .70177 L .70861 .69962 L F
.71201 .69979 m .71215 .7021 L .7089 .70177 L F
.637 .543 .731 r
.71392 .69757 m .71201 .69979 L .71189 .69818 L F
.944 .619 .389 r
.68078 .6304 m .67983 .6319 L .67985 .62967 L F
.68078 .6304 m .68129 .63274 L .67983 .6319 L F
.599 .779 .967 r
.32253 .65217 m .32073 .6528 L .31932 .65149 L F
.597 .607 .832 r
.48519 .75617 m .48185 .75367 L .484 .75299 L F
.521 .469 .739 r
.48622 .7525 m .48519 .75617 L .484 .75299 L F
.48622 .7525 m .48715 .75588 L .48519 .75617 L F
.45 .013 .116 r
.65066 .5982 m .64731 .59983 L .64838 .59873 L F
.788 .638 .695 r
.61593 .64348 m .61747 .64673 L .61427 .6464 L F
.774 .476 .483 r
.49836 .8784 m .49956 .87895 L .4982 .87696 L F
.495 .407 .686 r
.4982 .87696 m .49956 .87895 L .4994 .87652 L F
.985 .777 .542 r
.56393 .81006 m .56451 .81273 L .56268 .81153 L F
.739 .68 .793 r
.56031 .81392 m .56451 .81273 L .5619 .81484 L F
.56031 .81392 m .56268 .81153 L .56451 .81273 L F
.599 .303 .437 r
.56277 .80519 m .56283 .80738 L .55926 .80712 L F
.035 .465 .879 r
.56553 .80678 m .56569 .80634 L .56277 .80519 L F
.56 .272 .436 r
.56569 .80634 m .56283 .80738 L .56277 .80519 L F
.43 .254 .539 r
.36969 .76606 m .36734 .76873 L .36767 .76676 L F
.769 .636 .714 r
.5619 .81484 m .56246 .81811 L .55932 .81735 L F
.509 .766 .989 r
.55932 .81735 m .56246 .81811 L .56151 .81706 L F
.721 .604 .726 r
.56496 .81528 m .56246 .81811 L .5619 .81484 L F
.557 .55 .802 r
.56246 .81811 m .56374 .8159 L .56151 .81706 L F
.56246 .81811 m .56507 .81768 L .56374 .8159 L F
.606 .4 .576 r
.65184 .60397 m .65429 .60347 L .65368 .60039 L F
.59 .495 .715 r
.65368 .60039 m .65683 .60051 L .65641 .5986 L F
.532 .314 .529 r
.65429 .60347 m .65683 .60051 L .65368 .60039 L F
.584 .843 .994 r
.4508 .72877 m .44868 .72938 L .44741 .72862 L F
.722 .471 .547 r
.56588 .79073 m .56427 .79312 L .56773 .79314 L F
.788 .699 .767 r
.69035 .63723 m .6904 .63842 L .68731 .63763 L F
.845 .618 .595 r
.6904 .63842 m .68753 .64017 L .68731 .63763 L F
.6904 .63842 m .6904 .64079 L .68753 .64017 L F
.654 .594 .776 r
.69299 .63718 m .6904 .63842 L .69035 .63723 L F
.405 .175 .449 r
.6408 .60387 m .64103 .60571 L .64064 .60581 L F
.451 .206 .45 r
.6408 .60387 m .64332 .60343 L .64103 .60571 L F
.63 .565 .762 r
.36063 .78555 m .35738 .7828 L .35948 .78244 L F
.986 .708 .377 r
.67429 .61863 m .6752 .61953 L .67503 .61712 L F
.67429 .61863 m .6752 .61953 L .67503 .61712 L F
.456 .74 .989 r
.66719 .60068 m .66569 .6017 L .66484 .601 L F
.66719 .60068 m .66849 .60151 L .66569 .6017 L F
.451 .357 .657 r
.47921 .84436 m .48128 .84668 L .48125 .84342 L F
.47921 .84436 m .47955 .84678 L .48128 .84668 L F
0 0 .46 r
.56426 .80867 m .56467 .80861 L .56553 .80678 L F
.507 .911 .887 r
.56677 .80581 m .56569 .80634 L .56553 .80678 L F
.689 .624 .778 r
.56677 .80581 m .56777 .80593 L .56921 .80366 L F
.56777 .80593 m .57011 .80622 L .56932 .80397 L F
.56777 .80593 m .56932 .80397 L .56921 .80366 L F
.886 .708 .657 r
.5711 .80302 m .57284 .80286 L .57081 .80074 L F
.886 .643 .565 r
.56935 .80066 m .5711 .80302 L .57081 .80074 L F
.56935 .80066 m .56921 .80366 L .5711 .80302 L F
.656 .442 .582 r
.57011 .80622 m .5711 .80302 L .56921 .80366 L F
.661 .632 .811 r
.57081 .80074 m .57284 .80286 L .57317 .80109 L F
.768 .449 .446 r
.57608 .80214 m .57317 .80109 L .57284 .80286 L F
.524 .696 .947 r
.5701 .80293 m .57341 .80246 L .5714 .80146 L F
0 0 0 r
.5714 .80146 m .56923 .80435 L .56995 .80317 L F
.57051 .80247 m .56995 .80317 L .5701 .80293 L F
.5714 .80146 m .56995 .80317 L .57051 .80247 L F
.685 .627 .785 r
.56799 .80485 m .56796 .80487 L .56677 .80581 L F
.704 .298 .275 r
.56553 .80678 m .56793 .8088 L .56677 .80581 L F
.56553 .80678 m .56467 .80861 L .56793 .8088 L F
.613 .59 .803 r
.56677 .80581 m .56793 .8088 L .57021 .80839 L F
.56677 .80581 m .57021 .80839 L .57011 .80622 L F
.685 .627 .785 r
.56796 .80487 m .5654 .80725 L .56677 .80581 L F
.704 .298 .275 r
.56553 .80678 m .56553 .80678 L .56677 .80581 L F
.448 .486 .806 r
.70321 .6002 m .70216 .60394 L .70089 .60077 L F
.70321 .6002 m .70429 .60423 L .70216 .60394 L F
.749 .839 .919 r
.52091 .86217 m .51951 .86356 L .51936 .86245 L F
.414 .623 .938 r
.65453 .62907 m .65647 .62919 L .65528 .63047 L F
0 0 .467 r
.65647 .62919 m .65544 .63292 L .65528 .63047 L F
.691 .779 .919 r
.65202 .63009 m .65453 .62907 L .65528 .63047 L F
.244 .323 .746 r
.72102 .61846 m .71982 .62013 L .71869 .61652 L F
.299 .4 .798 r
.72102 .61846 m .72217 .62151 L .71982 .62013 L F
.511 .307 .539 r
.34252 .7534 m .34459 .75312 L .34477 .75061 L F
.552 .341 .548 r
.34477 .75061 m .34666 .75269 L .34682 .75028 L F
.34477 .75061 m .34459 .75312 L .34666 .75269 L F
.594 .354 .524 r
.62283 .65975 m .62277 .6617 L .62055 .66157 L F
.629 .384 .527 r
.62283 .65975 m .62509 .6618 L .62277 .6617 L F
.66 .376 .477 r
.62501 .65994 m .62509 .6618 L .62283 .65975 L F
.662 .536 .701 r
.49231 .76372 m .48964 .76403 L .49148 .76154 L F
.685 .484 .609 r
.49231 .76372 m .48966 .76614 L .48964 .76403 L F
.216 .374 .807 r
.69067 .63245 m .68927 .63302 L .68793 .63016 L F
.222 .392 .821 r
.69067 .63245 m .69196 .63503 L .68927 .63302 L F
.899 .636 .531 r
.53717 .82996 m .53911 .83293 L .53949 .83122 L F
.935 .748 .626 r
.48008 .86541 m .48193 .86578 L .48148 .86208 L F
.48008 .86541 m .48122 .86797 L .48193 .86578 L F
.971 .925 .613 r
.51469 .88175 m .51541 .88167 L .51512 .87978 L F
.482 .442 .736 r
.34292 .67855 m .34403 .67515 L .34165 .67546 L F
.34292 .67855 m .34464 .67816 L .34403 .67515 L F
.529 .472 .736 r
.34341 .68082 m .34464 .67816 L .34292 .67855 L F
.881 .951 .85 r
.68792 .62664 m .69002 .62573 L .69008 .62546 L F
.754 .654 .751 r
.687 .62469 m .69039 .62528 L .6895 .62224 L F
.881 .951 .85 r
.68792 .62664 m .69039 .62528 L .687 .62469 L F
.733 .618 .73 r
.6895 .62224 m .69027 .62484 L .687 .62469 L F
.345 .286 .647 r
.68934 .62613 m .687 .62469 L .69027 .62484 L F
0 0 .444 r
.69031 .62285 m .69027 .62484 L .6895 .62224 L F
.697 .66 .81 r
.69031 .62285 m .68934 .62613 L .69018 .62498 L F
.69028 .62449 m .69018 .62498 L .69027 .62484 L F
.69031 .62285 m .69018 .62498 L .69028 .62449 L F
.881 .951 .85 r
.68792 .62664 m .68823 .62785 L .69002 .62573 L F
.69008 .62546 m .69002 .62573 L .69039 .62528 L F
.551 .535 .79 r
.48323 .85419 m .48422 .85719 L .48222 .85755 L F
.561 .388 .605 r
.48422 .85719 m .48212 .85991 L .48222 .85755 L F
.764 .371 .31 r
.56374 .8159 m .56649 .81679 L .56496 .81528 L F
.539 .417 .662 r
.56496 .81528 m .56649 .81679 L .56687 .81454 L F
.365 .105 .381 r
.32943 .70546 m .32885 .7074 L .33119 .70484 L F
.375 .839 .791 r
.64997 .6222 m .65215 .62133 L .65065 .62211 L F
.64997 .6222 m .65215 .62133 L .65065 .62211 L F
.967 .816 .642 r
.66189 .60635 m .66037 .60823 L .66113 .60699 L F
.66189 .60635 m .66155 .60896 L .66037 .60823 L F
.712 .779 .905 r
.54569 .81381 m .54604 .81138 L .54355 .81212 L F
.54569 .81381 m .54731 .81295 L .54604 .81138 L F
.596 .422 .617 r
.34042 .75604 m .34263 .75578 L .34252 .7534 L F
.597 .422 .617 r
.34252 .7534 m .34482 .75549 L .34459 .75312 L F
.34252 .7534 m .34263 .75578 L .34482 .75549 L F
.889 .611 .51 r
.63461 .62483 m .63476 .62699 L .63689 .62765 L F
.851 .776 .778 r
.63476 .62699 m .63636 .62788 L .63689 .62765 L F
.815 .797 .835 r
.68704 .71549 m .68859 .71606 L .69051 .71405 L F
.977 .78 .571 r
.68733 .71772 m .68859 .71606 L .68704 .71549 L F
.68733 .71772 m .68843 .71862 L .68859 .71606 L F
.604 .424 .611 r
.34042 .75604 m .34266 .75818 L .34263 .75578 L F
.34042 .75604 m .34044 .75854 L .34266 .75818 L F
.707 .421 .488 r
.50777 .87875 m .50987 .87597 L .50534 .8761 L F
.815 .41 .28 r
.51012 .87815 m .50987 .87597 L .50777 .87875 L F
.51012 .87815 m .51048 .87677 L .50987 .87597 L F
0 0 0 r
.33275 .69934 m .33561 .69719 L .33328 .69693 L F
0 .378 .825 r
.65441 .59068 m .6575 .59247 L .65505 .59127 L F
.537 .25 .427 r
.65505 .59127 m .6575 .59247 L .65469 .59369 L F
0 0 0 r
.65836 .64629 m .66127 .64455 L .66017 .64537 L F
.537 .871 .604 r
.65903 .64622 m .66017 .64537 L .66127 .64424 L F
.026 0 .137 r
.65836 .64629 m .66017 .64537 L .65924 .64714 L F
.537 .871 .604 r
.65878 .64644 m .66017 .64537 L .65903 .64622 L F
0 0 0 r
.66127 .64455 m .66134 .6445 L .66017 .64537 L F
.026 0 .137 r
.65836 .64629 m .65924 .64714 L .65817 .64825 L F
.459 .106 .279 r
.65836 .64629 m .65817 .64825 L .6557 .64864 L F
.778 .752 .235 r
.4781 .8765 m .47751 .87916 L .47776 .87758 L F
.838 .998 .823 r
.48024 .87406 m .4781 .8765 L .47791 .87593 L F
.711 .628 .763 r
.48024 .87406 m .48075 .87597 L .4781 .8765 L F
0 .253 .684 r
.48175 .8788 m .4781 .8765 L .48075 .87597 L F
.701 .68 .827 r
.71104 .69643 m .71189 .69818 L .70881 .69749 L F
.666 .734 .9 r
.71338 .69602 m .71189 .69818 L .71104 .69643 L F
.71338 .69602 m .71392 .69757 L .71189 .69818 L F
.61 .82 .981 r
.34495 .82814 m .34598 .82653 L .34354 .82728 L F
.34495 .82814 m .34723 .82758 L .34598 .82653 L F
.34598 .82653 m .34495 .82814 L .34354 .82728 L F
.34598 .82653 m .34723 .82758 L .34495 .82814 L F
.189 .322 .769 r
.67961 .72929 m .67854 .7264 L .6818 .72704 L F
.67961 .72929 m .6809 .72843 L .67854 .7264 L F
.363 .683 .979 r
.67961 .72929 m .6823 .72961 L .6809 .72843 L F
.602 .901 .986 r
.64716 .58646 m .64823 .58699 L .64595 .58779 L F
.63 .951 .937 r
.6452 .58753 m .64716 .58646 L .64595 .58779 L F
.47 .88 .943 r
.64286 .5882 m .6452 .58753 L .64595 .58779 L F
.207 .194 .622 r
.72217 .62151 m .7229 .62414 L .72134 .62519 L F
0 0 .288 r
.72224 .62604 m .72134 .62519 L .7229 .62414 L F
.72224 .62604 m .72109 .62738 L .72134 .62519 L F
.621 .121 0 r
.71355 .728 m .71461 .72923 L .71459 .72907 L F
.734 .708 .827 r
.71389 .72367 m .71468 .72692 L .71146 .72592 L F
.766 .674 .762 r
.71468 .72692 m .71355 .728 L .71146 .72592 L F
0 0 .29 r
.71514 .72705 m .71461 .72923 L .71468 .72692 L F
.71557 .72717 m .7151 .72817 L .71514 .72705 L F
.7151 .72817 m .71461 .72923 L .71514 .72705 L F
.704 .389 .442 r
.71494 .72861 m .71509 .72856 L .71497 .72854 L F
.71509 .72856 m .71509 .7285 L .71499 .72848 L F
.57 .361 .558 r
.71468 .72692 m .71461 .72923 L .71355 .728 L F
.704 .389 .442 r
.71497 .72854 m .71499 .72848 L .7106 .7276 L F
.71509 .72856 m .71499 .72848 L .71497 .72854 L F
.621 .121 0 r
.71459 .72907 m .71461 .72923 L .71519 .7297 L F
.704 .389 .442 r
.71494 .72861 m .71436 .73026 L .71522 .72852 L F
.734 .219 0 r
.71488 .72876 m .71491 .72869 L .7149 .72872 L F
.71462 .72937 m .71499 .72848 L .71488 .72876 L F
.71463 .72944 m .71462 .72937 L .71488 .72876 L F
.71462 .72937 m .71461 .72923 L .71521 .72795 L F
0 0 .508 r
.71494 .72984 m .71597 .73107 L .71591 .73159 L F
.71461 .72923 m .71491 .72964 L .71494 .72984 L F
.71491 .72964 m .71597 .73107 L .71494 .72984 L F
.704 .389 .442 r
.71509 .72856 m .71522 .72852 L .71509 .7285 L F
.734 .219 0 r
.71511 .7282 m .71521 .72795 L .71557 .72717 L F
.589 .464 .677 r
.71849 .72491 m .71468 .72692 L .71723 .72428 L F
.85 .775 .778 r
.71723 .72428 m .71468 .72692 L .71389 .72367 L F
0 0 .29 r
.71557 .72717 m .71468 .72692 L .71647 .72681 L F
.534 .596 .862 r
.7127 .72492 m .71506 .7283 L .71557 .72717 L F
.71506 .7283 m .71522 .72852 L .71557 .72717 L F
.734 .219 0 r
.7149 .72872 m .71511 .7282 L .71557 .72717 L F
.839 .879 .443 r
.71522 .72852 m .71485 .72927 L .71557 .72717 L F
.734 .219 0 r
.71436 .73026 m .71597 .73107 L .71491 .72964 L F
.71436 .73026 m .71491 .72964 L .71461 .72923 L F
.839 .879 .443 r
.71485 .72927 m .71436 .73026 L .71482 .72909 L F
.736 .67 .786 r
.71499 .72848 m .71522 .72852 L .71506 .7283 L F
.839 .879 .443 r
.71485 .72927 m .71482 .72909 L .71557 .72717 L F
.734 .219 0 r
.71436 .73026 m .71461 .72923 L .71464 .72954 L F
.704 .389 .442 r
.7107 .72991 m .71436 .73026 L .71494 .72861 L F
.734 .219 0 r
.71491 .72869 m .71521 .72795 L .7149 .72872 L F
.71499 .72848 m .71521 .72795 L .71488 .72876 L F
.71464 .72954 m .71463 .72944 L .71557 .72717 L F
.71463 .72944 m .71488 .72876 L .71557 .72717 L F
.704 .389 .442 r
.7107 .72991 m .71494 .72861 L .7106 .7276 L F
.71494 .72861 m .71497 .72854 L .7106 .7276 L F
.736 .67 .786 r
.7106 .7276 m .71499 .72848 L .7127 .72492 L F
.71499 .72848 m .71506 .7283 L .7127 .72492 L F
.118 0 0 r
.40148 .74614 m .3995 .74711 L .40174 .74546 L F
.463 0 0 r
.40174 .74546 m .40285 .74635 L .40148 .74614 L F
0 0 .519 r
.48212 .87826 m .48175 .8788 L .48075 .87597 L F
0 .016 .589 r
.48212 .87826 m .4833 .88118 L .48175 .8788 L F
.198 0 0 r
.40003 .79272 m .40363 .79094 L .40203 .7922 L F
.134 0 0 r
.40203 .7922 m .40363 .79094 L .40563 .79045 L F
.519 .916 .885 r
.37372 .80267 m .37286 .8035 L .37492 .80273 L F
.37372 .80267 m .37185 .80357 L .37286 .8035 L F
.431 0 .05 r
.39969 .78149 m .4034 .77992 L .40124 .78016 L F
.593 .317 .468 r
.46015 .76931 m .46218 .77115 L .46006 .77136 L F
.59 .318 .473 r
.46233 .76925 m .46218 .77115 L .46015 .76931 L F
.535 .363 .594 r
.36061 .77195 m .36057 .77463 L .35831 .77491 L F
.548 .423 .661 r
.36057 .77463 m .36047 .77649 L .35831 .77491 L F
.492 .43 .715 r
.35831 .77491 m .36047 .77649 L .35885 .77688 L F
.712 .847 .947 r
.6871 .69914 m .68359 .69928 L .68591 .69818 L F
.561 .581 .831 r
.68813 .69611 m .6871 .69914 L .68591 .69818 L F
.68813 .69611 m .68877 .69896 L .6871 .69914 L F
.651 .485 .646 r
.33619 .76155 m .33858 .76365 L .33836 .76125 L F
.33619 .76155 m .33626 .76403 L .33858 .76365 L F
.62 .583 .791 r
.69124 .60569 m .69225 .60889 L .69444 .6082 L F
.509 .379 .639 r
.48233 .87327 m .48075 .87597 L .48024 .87406 L F
.48233 .87327 m .48261 .87627 L .48075 .87597 L F
0 0 .519 r
.48212 .87826 m .48075 .87597 L .48261 .87627 L F
.525 .192 .345 r
.36841 .73398 m .37069 .73382 L .37131 .73223 L F
.622 .369 .513 r
.37069 .73382 m .37325 .73174 L .37131 .73223 L F
.223 .626 .955 r
.48573 .88744 m .48676 .88687 L .48449 .88701 L F
.48573 .88744 m .48839 .88799 L .48676 .88687 L F
.266 .387 .8 r
.71408 .6222 m .71553 .62537 L .71606 .62357 L F
.867 .996 .788 r
.71553 .62537 m .71499 .62511 L .71606 .62357 L F
.735 .641 .754 r
.56687 .81454 m .5712 .81692 L .56906 .81426 L F
.56687 .81454 m .56816 .81764 L .5712 .81692 L F
.537 .663 .917 r
.56906 .81426 m .5712 .81692 L .57234 .81642 L F
.637 .505 .685 r
.33407 .76443 m .3342 .76664 L .33626 .76403 L F
.201 0 0 r
.66001 .63199 m .65827 .63186 L .6579 .63266 L F
.66001 .63199 m .66108 .63087 L .65827 .63186 L F
.169 0 0 r
.32385 .71 m .32552 .70957 L .32711 .70809 L F
.484 .124 .278 r
.32552 .70957 m .32885 .7074 L .32711 .70809 L F
.611 .508 .712 r
.45791 .74741 m .46067 .74844 L .45988 .7449 L F
.639 .755 .932 r
.72112 .61567 m .72187 .61705 L .71869 .61652 L F
.244 .323 .746 r
.72102 .61846 m .71869 .61652 L .72187 .61705 L F
.436 .639 .942 r
.72112 .61567 m .72318 .61574 L .72187 .61705 L F
0 0 0 r
.72318 .61574 m .72102 .61846 L .72187 .61705 L F
.637 .502 .681 r
.46198 .75331 m .45997 .75599 L .46211 .75556 L F
.642 .472 .638 r
.45997 .75599 m .46183 .75814 L .46211 .75556 L F
.45997 .75599 m .45999 .75844 L .46183 .75814 L F
.595 .289 .42 r
.65938 .60001 m .65695 .60053 L .65672 .59938 L F
.49 .761 .991 r
.33551 .65377 m .3349 .65508 L .33347 .65392 L F
.33551 .65377 m .33703 .65482 L .3349 .65508 L F
.617 .423 .597 r
.34934 .83929 m .35181 .83898 L .34942 .83613 L F
.792 .686 .747 r
.70486 .7185 m .70797 .71867 L .70684 .71564 L F
.764 .673 .762 r
.70684 .71564 m .70797 .71867 L .70995 .71625 L F
0 0 0 r
.66017 .64537 m .66134 .6445 L .66316 .64341 L F
.407 .838 .952 r
.73555 .71823 m .73198 .71845 L .73318 .71927 L F
.279 0 0 r
.43391 .78013 m .43047 .78149 L .43188 .77983 L F
.583 .356 .538 r
.45022 .76388 m .45242 .76384 L .45272 .76128 L F
.54 .304 .507 r
.45242 .76384 m .45464 .76103 L .45272 .76128 L F
.543 .819 .997 r
.50755 .88479 m .50868 .88364 L .50651 .88381 L F
.50755 .88479 m .50991 .88443 L .50868 .88364 L F
0 0 0 r
.48839 .8833 m .48864 .88313 L .49003 .88128 L F
.35 0 .103 r
.49114 .88309 m .49438 .88096 L .49145 .8808 L F
.229 .735 .68 r
.49153 .88078 m .49003 .88128 L .49145 .8808 L F
0 0 0 r
.49003 .88128 m .48864 .88313 L .49145 .8808 L F
.705 .561 .689 r
.49145 .8808 m .48864 .88313 L .49114 .88309 L F
.968 .819 .642 r
.49145 .8808 m .48996 .88213 L .48769 .88016 L F
.49145 .8808 m .49114 .88309 L .49093 .88293 L F
.49058 .88157 m .49093 .88293 L .48996 .88213 L F
.49145 .8808 m .49093 .88293 L .49058 .88157 L F
.48 .546 .846 r
.48804 .87769 m .49016 .88001 L .48769 .88016 L F
.601 .094 .02 r
.48769 .88016 m .49047 .88119 L .49032 .8806 L F
.968 .819 .642 r
.49055 .8816 m .49114 .88309 L .49145 .8808 L F
.48996 .88213 m .49085 .88286 L .49055 .8816 L F
.49085 .88286 m .49114 .88309 L .49055 .8816 L F
.601 .094 .02 r
.49078 .88068 m .49163 .88161 L .49145 .8808 L F
.48 .546 .846 r
.49016 .88001 m .49094 .88086 L .49047 .88119 L F
.49094 .88086 m .49163 .88161 L .49073 .88128 L F
.49094 .88086 m .49073 .88128 L .49047 .88119 L F
.968 .819 .642 r
.48996 .88213 m .49055 .8816 L .49094 .88086 L F
.506 .555 .839 r
.49123 .8803 m .49094 .88086 L .49016 .88001 L F
.968 .819 .642 r
.49119 .88037 m .49094 .88086 L .49123 .8803 L F
.48996 .88213 m .49094 .88086 L .49119 .88037 L F
.49055 .8816 m .49145 .8808 L .49123 .8803 L F
.506 .555 .839 r
.49123 .8803 m .49163 .88161 L .49094 .88086 L F
.48999 .87929 m .49016 .88001 L .48804 .87769 L F
.49123 .8803 m .49016 .88001 L .48999 .87929 L F
.48 .546 .846 r
.49016 .88001 m .49047 .88119 L .48769 .88016 L F
.732 .437 0 r
.49145 .8808 m .49163 .88161 L .49138 .88081 L F
.49145 .8808 m .49138 .88081 L .49123 .8803 L F
.229 .735 .68 r
.49252 .88045 m .49153 .88078 L .49145 .8808 L F
.577 .264 .402 r
.44463 .76603 m .4469 .76614 L .44793 .76362 L F
.406 .006 .165 r
.4469 .76614 m .45022 .76388 L .44793 .76362 L F
.411 .661 .963 r
.3267 .65142 m .32606 .65286 L .32465 .65199 L F
.3267 .65142 m .32809 .65301 L .32606 .65286 L F
.695 .557 .694 r
.61756 .65998 m .6173 .66259 L .61524 .66219 L F
.699 .561 .694 r
.62055 .66157 m .6173 .66259 L .61756 .65998 L F
.529 .472 .736 r
.34341 .68082 m .34528 .68052 L .34464 .67816 L F
.439 .438 .761 r
.34341 .68082 m .34582 .68336 L .34528 .68052 L F
.688 .44 .543 r
.61524 .66219 m .61197 .66457 L .61192 .66245 L F
.61524 .66219 m .61415 .66474 L .61197 .66457 L F
.648 .397 .525 r
.61737 .66434 m .61524 .66219 L .6173 .66259 L F
.61737 .66434 m .61415 .66474 L .61524 .66219 L F
.356 .476 .844 r
.65885 .60803 m .66037 .60823 L .65925 .60879 L F
0 0 0 r
.66037 .60823 m .65876 .60956 L .65925 .60879 L F
.424 .133 .364 r
.65885 .60803 m .65876 .60956 L .66037 .60823 L F
.826 .961 .632 r
.66037 .60823 m .65872 .60978 L .66045 .60726 L F
.66037 .60823 m .66045 .60726 L .66089 .60661 L F
.45 .793 .998 r
.66037 .60823 m .66155 .60896 L .66031 .60887 L F
.66037 .60823 m .66031 .60887 L .65925 .60879 L F
.974 .686 .416 r
.66155 .60896 m .66168 .61111 L .66037 .60823 L F
.468 .844 .988 r
.36705 .67402 m .36363 .67411 L .36588 .67371 L F
.56 .899 .979 r
.36891 .67334 m .36705 .67402 L .36588 .67371 L F
.666 .495 .644 r
.32964 .77191 m .33124 .77184 L .33205 .76934 L F
.637 .465 .633 r
.33205 .76934 m .33124 .77184 L .33209 .77173 L F
.621 .465 .649 r
.3342 .76664 m .33205 .76934 L .33427 .76906 L F
.601 .436 .63 r
.33205 .76934 m .33433 .77139 L .33427 .76906 L F
.33205 .76934 m .33209 .77173 L .33433 .77139 L F
.6 .528 .746 r
.36173 .78209 m .36063 .78555 L .35948 .78244 L F
.36173 .78209 m .3628 .7852 L .36063 .78555 L F
.73 .342 .316 r
.34688 .81211 m .34895 .81449 L .34539 .81381 L F
.603 .39 .566 r
.69366 .6169 m .69582 .61687 L .69578 .61441 L F
.678 .556 .709 r
.69578 .61441 m .69976 .61472 L .69818 .61089 L F
.659 .435 .568 r
.69578 .61441 m .698 .61583 L .69976 .61472 L F
.69578 .61441 m .69582 .61687 L .698 .61583 L F
.986 .832 .445 r
.68002 .62524 m .6792 .62669 L .67928 .62433 L F
.68002 .62524 m .6797 .62752 L .6792 .62669 L F
.643 .293 .364 r
.47322 .76693 m .4721 .76901 L .46984 .76867 L F
.551 .193 .314 r
.47538 .76833 m .4721 .76901 L .47322 .76693 L F
.56 .181 .279 r
.47633 .76658 m .47538 .76833 L .47322 .76693 L F
.589 .561 .79 r
.67939 .70483 m .6807 .70807 L .67852 .70657 L F
.308 0 .155 r
.63583 .65697 m .63718 .6582 L .635 .65873 L F
.63583 .65697 m .63848 .65601 L .63718 .6582 L F
.815 .741 .783 r
.61981 .62703 m .62193 .62755 L .61949 .63074 L F
.829 .705 .727 r
.62066 .62502 m .62193 .62755 L .61981 .62703 L F
.674 .475 .609 r
.36512 .77152 m .36276 .76934 L .3649 .76915 L F
.36512 .77152 m .36266 .77171 L .36276 .76934 L F
.675 .593 .756 r
.47861 .85532 m .48006 .85121 L .47817 .85181 L F
.47861 .85532 m .48211 .85538 L .48006 .85121 L F
.652 .364 .47 r
.47861 .85532 m .48069 .85725 L .48211 .85538 L F
.57 .56 .803 r
.55932 .81735 m .56031 .81392 L .5619 .81484 L F
.579 .506 .737 r
.36047 .77649 m .35927 .78007 L .35885 .77688 L F
.626 .626 .831 r
.47165 .73743 m .47017 .74009 L .46949 .73739 L F
.47165 .73743 m .47263 .73985 L .47017 .74009 L F
.728 .756 .874 r
.48455 .87174 m .48552 .87307 L .48233 .87327 L F
.764 .568 .633 r
.48514 .87471 m .48233 .87327 L .48552 .87307 L F
.53 .64 .903 r
.48676 .87155 m .48552 .87307 L .48455 .87174 L F
.48676 .87155 m .48777 .87325 L .48552 .87307 L F
.601 .455 .654 r
.48777 .87325 m .48514 .87471 L .48552 .87307 L F
0 0 0 r
.31657 .67588 m .31241 .67703 L .31452 .67645 L F
.612 .784 .964 r
.70684 .71564 m .70995 .71625 L .70936 .71505 L F
.737 .23 .016 r
.70995 .71625 m .71009 .71767 L .70936 .71505 L F
.70995 .71625 m .71229 .71825 L .71009 .71767 L F
.577 .502 .734 r
.47817 .85181 m .48006 .85121 L .47968 .84925 L F
.84 .974 .879 r
.35033 .81488 m .35256 .81296 L .35038 .81311 L F
.244 .755 .862 r
.35256 .81296 m .35296 .81267 L .35038 .81311 L F
.35256 .81296 m .35497 .81261 L .35296 .81267 L F
.778 .994 .876 r
.71889 .71849 m .7214 .71658 L .72034 .71635 L F
.3 0 .071 r
.7214 .71658 m .72376 .71585 L .72287 .71686 L F
0 .465 .708 r
.72034 .71635 m .7214 .71658 L .72287 .71686 L F
.591 .465 .677 r
.72356 .71315 m .72376 .71585 L .7214 .71658 L F
.489 .246 .472 r
.4492 .77428 m .44713 .77589 L .44736 .77481 L F
.815 .797 .835 r
.68704 .71549 m .69051 .71405 L .68934 .71285 L F
.736 .774 .883 r
.68934 .71285 m .69051 .71405 L .69258 .71305 L F
.787 .659 .722 r
.68609 .60621 m .68714 .60936 L .68892 .60885 L F
.767 .584 .651 r
.68714 .60936 m .68658 .61113 L .68892 .60885 L F
.226 0 .247 r
.32337 .72957 m .32261 .73135 L .32102 .73189 L F
.145 0 .067 r
.32102 .73189 m .32261 .73135 L .32043 .7329 L F
.773 .484 .497 r
.68285 .71849 m .68025 .72059 L .68139 .71774 L F
.68285 .71849 m .68408 .72212 L .68025 .72059 L F
.423 .617 .931 r
.69422 .71343 m .69638 .71581 L .69773 .71546 L F
0 0 0 r
.64647 .61521 m .64731 .61512 L .64552 .61617 L F
.841 .805 .815 r
.61949 .63074 m .61593 .6324 L .61815 .62974 L F
.61949 .63074 m .61696 .63369 L .61593 .6324 L F
.815 .741 .783 r
.61981 .62703 m .61949 .63074 L .61815 .62974 L F
.77 .645 .724 r
.43337 .74309 m .43245 .74522 L .42907 .74491 L F
.527 .321 .544 r
.43532 .74267 m .43245 .74522 L .43337 .74309 L F
.433 0 .106 r
.39367 .72595 m .39584 .72586 L .39723 .72415 L F
.322 0 0 r
.39584 .72586 m .39937 .72397 L .39723 .72415 L F
.526 .813 .998 r
.72165 .73667 m .72035 .73745 L .717 .73708 L F
.723 .422 .468 r
.72054 .73885 m .717 .73708 L .72035 .73745 L F
.503 .818 1 r
.71825 .73584 m .71909 .7369 L .717 .73708 L F
.71835 .73573 m .71841 .73583 L .71825 .73584 L F
.71841 .73583 m .71909 .7369 L .71825 .73584 L F
.71875 .73583 m .72165 .73667 L .72075 .73675 L F
.71891 .73583 m .72165 .73667 L .71875 .73583 L F
.71846 .73577 m .72075 .73675 L .71909 .7369 L F
.71841 .73567 m .72075 .73675 L .71846 .73577 L F
.71983 .73598 m .72165 .73667 L .71841 .73567 L F
.489 .819 1 r
.72136 .7364 m .72035 .73745 L .72165 .73667 L F
.72136 .7364 m .72185 .73717 L .72035 .73745 L F
.698 .34 .364 r
.72035 .73745 m .72261 .73913 L .72054 .73885 L F
.688 .45 .557 r
.71912 .73583 m .71871 .73801 L .72108 .7378 L F
.71857 .73528 m .7186 .73583 L .71912 .73583 L F
.7186 .73583 m .71871 .73801 L .71912 .73583 L F
.71857 .73528 m .7186 .73583 L .71912 .73583 L F
.503 .818 1 r
.71841 .73567 m .71891 .73583 L .71875 .73583 L F
.71841 .73567 m .71909 .7369 L .71835 .73573 L F
.723 .422 .468 r
.72054 .73885 m .71933 .73918 L .717 .73708 L F
.937 .653 .475 r
.71745 .73744 m .71871 .73801 L .7186 .73583 L F
.71834 .73572 m .7186 .73583 L .71857 .73528 L F
.71745 .73744 m .7186 .73583 L .71834 .73572 L F
.688 .45 .557 r
.71912 .73583 m .71871 .73801 L .72108 .7378 L F
.7186 .73583 m .71871 .73801 L .71912 .73583 L F
.937 .653 .475 r
.71745 .73744 m .71834 .73572 L .71815 .73573 L F
.503 .818 1 r
.7183 .73541 m .717 .73708 L .71583 .73456 L F
.937 .653 .475 r
.71835 .73571 m .71857 .73528 L .71832 .73555 L F
.503 .818 1 r
.71858 .7355 m .71835 .73573 L .71832 .73555 L F
.71835 .73573 m .717 .73708 L .7183 .73541 L F
.937 .653 .475 r
.71835 .73571 m .71832 .73555 L .71827 .7356 L F
.023 0 0 r
.71858 .7355 m .71815 .73573 L .71832 .73555 L F
.71858 .7355 m .71832 .73555 L .71857 .73528 L F
.503 .818 1 r
.71858 .7355 m .71832 .73555 L .7183 .73541 L F
.937 .653 .475 r
.71834 .73572 m .71835 .73571 L .71827 .7356 L F
.71834 .73572 m .71827 .7356 L .71815 .73573 L F
.503 .818 1 r
.71858 .7355 m .71983 .73598 L .71841 .73567 L F
.048 .544 .884 r
.71857 .73528 m .72165 .73667 L .71983 .73598 L F
.71857 .73528 m .72136 .7364 L .72165 .73667 L F
.688 .45 .557 r
.71857 .73528 m .71912 .73583 L .7209 .73621 L F
.048 .544 .884 r
.71857 .73528 m .71983 .73598 L .71858 .7355 L F
.688 .45 .557 r
.7209 .73621 m .72094 .73661 L .72136 .7364 L F
.72094 .73661 m .72108 .7378 L .72128 .73679 L F
.72094 .73661 m .72128 .73679 L .72136 .7364 L F
.71912 .73583 m .72108 .7378 L .7209 .73621 L F
.554 .418 .651 r
.72185 .73717 m .72261 .73913 L .72035 .73745 L F
.379 0 .018 r
.35965 .73868 m .36331 .73697 L .36115 .73715 L F
.573 .549 .79 r
.48152 .74493 m .48049 .74839 L .4794 .74534 L F
.48152 .74493 m .48258 .74804 L .48049 .74839 L F
.453 .583 .893 r
.46629 .7343 m .46291 .73188 L .46512 .73127 L F
.592 .575 .803 r
.46722 .73082 m .46629 .7343 L .46512 .73127 L F
.46722 .73082 m .46842 .73392 L .46629 .7343 L F
.597 .534 .755 r
.46949 .73739 m .46629 .7343 L .46842 .73392 L F
.691 .441 .541 r
.61192 .66245 m .60849 .6645 L .60866 .66199 L F
.61192 .66245 m .61197 .66457 L .60849 .6645 L F
.516 .625 .898 r
.71415 .60001 m .71235 .60207 L .71197 .60017 L F
.71415 .60001 m .7152 .60256 L .71235 .60207 L F
.233 0 .108 r
.38144 .75376 m .38042 .75549 L .37872 .75584 L F
.401 .024 .203 r
.38363 .75337 m .38042 .75549 L .38144 .75376 L F
.366 .448 .813 r
.49269 .76014 m .49148 .76154 L .49057 .7606 L F
.49269 .76014 m .49406 .76315 L .49148 .76154 L F
.483 .438 .731 r
.49406 .76315 m .49231 .76372 L .49148 .76154 L F
0 .517 .807 r
.69299 .63718 m .69491 .63758 L .69598 .638 L F
.07 .58 .884 r
.69774 .63801 m .69598 .638 L .69491 .63758 L F
.69774 .63801 m .69855 .63853 L .69598 .638 L F
.845 .8 .806 r
.61696 .63369 m .61382 .63512 L .61593 .6324 L F
.61696 .63369 m .61513 .63585 L .61382 .63512 L F
.681 .544 .692 r
.52746 .87371 m .52958 .87121 L .52627 .87116 L F
0 .374 .743 r
.73339 .71452 m .73149 .71389 L .73064 .71316 L F
.73339 .71452 m .73477 .71525 L .73149 .71389 L F
.791 .66 .719 r
.61654 .64144 m .61593 .64348 L .61465 .64028 L F
.654 .594 .776 r
.69299 .63718 m .69035 .63723 L .69196 .63503 L F
.593 .304 .447 r
.6173 .66259 m .61965 .66425 L .61737 .66434 L F
.594 .303 .445 r
.62055 .66157 m .61965 .66425 L .6173 .66259 L F
.873 .483 .296 r
.67569 .60518 m .67635 .60396 L .67524 .6026 L F
.67569 .60518 m .67692 .60567 L .67635 .60396 L F
.357 0 .011 r
.42037 .74056 m .41914 .74186 L .41695 .74211 L F
.197 0 0 r
.42108 .74135 m .42037 .74056 L .42237 .73992 L F
.42108 .74135 m .41914 .74186 L .42037 .74056 L F
.632 .355 .479 r
.62833 .65922 m .62509 .6618 L .62501 .65994 L F
.309 0 .212 r
.42712 .77141 m .42796 .77307 L .42937 .77144 L F
.42712 .77141 m .42601 .77375 L .42796 .77307 L F
.551 .58 .837 r
.34811 .65788 m .34695 .66035 L .34563 .65746 L F
.563 .594 .842 r
.34811 .65788 m .34917 .66039 L .34695 .66035 L F
.56 .608 .858 r
.71839 .60238 m .71612 .60389 L .7152 .60256 L F
.71839 .60238 m .71804 .60352 L .71612 .60389 L F
.666 .546 .709 r
.33626 .76403 m .3342 .76664 L .33668 .76642 L F
.605 .418 .601 r
.33427 .76906 m .33668 .76642 L .3342 .76664 L F
.505 .872 .982 r
.64613 .60531 m .64881 .60471 L .64954 .60522 L F
.773 .451 .441 r
.69135 .61654 m .69502 .61844 L .69366 .6169 L F
.69135 .61654 m .69281 .61897 L .69502 .61844 L F
.355 .779 .974 r
.43245 .74522 m .43095 .74462 L .42907 .74491 L F
.527 .321 .544 r
.43532 .74267 m .43453 .74489 L .43245 .74522 L F
.343 .785 .961 r
.43453 .74489 m .43095 .74462 L .43245 .74522 L F
.739 .671 .784 r
.6364 .62219 m .63546 .61916 L .63349 .62192 L F
.751 .613 .705 r
.63349 .62192 m .63461 .62483 L .6364 .62219 L F
.603 .061 0 r
.63898 .62003 m .63546 .61916 L .6364 .62219 L F
.526 .726 .965 r
.45498 .72813 m .45404 .72962 L .45287 .7286 L F
.45498 .72813 m .45612 .72936 L .45404 .72962 L F
.48 .106 .253 r
.3995 .74711 m .39827 .74942 L .39613 .74948 L F
.667 .415 .529 r
.40148 .74614 m .39827 .74942 L .3995 .74711 L F
.647 .492 .659 r
.33827 .75887 m .34065 .76091 L .34044 .75854 L F
.33827 .75887 m .33836 .76125 L .34065 .76091 L F
.543 .78 .986 r
.42234 .72433 m .41892 .72369 L .42096 .72362 L F
.49 .785 .997 r
.42304 .72316 m .42234 .72433 L .42096 .72362 L F
.42304 .72316 m .4243 .72402 L .42234 .72433 L F
.262 0 0 r
.38575 .72793 m .3878 .72753 L .38941 .72598 L F
.128 0 0 r
.3878 .72753 m .39156 .72611 L .38941 .72598 L F
.632 .355 .479 r
.62833 .65922 m .62761 .66205 L .62509 .6618 L F
.564 .289 .457 r
.6304 .66113 m .62833 .65922 L .63052 .65911 L F
.6304 .66113 m .62761 .66205 L .62833 .65922 L F
.808 .673 .715 r
.56649 .81679 m .56816 .81764 L .56687 .81454 L F
.752 .81 .898 r
.56507 .81768 m .56816 .81764 L .56649 .81679 L F
.676 .615 .779 r
.47771 .86569 m .47966 .86981 L .48122 .86797 L F
.514 .334 .574 r
.47909 .87067 m .48122 .86797 L .47966 .86981 L F
.528 .379 .622 r
.70164 .64295 m .69923 .64105 L .70193 .6408 L F
.70164 .64295 m .69951 .64374 L .69923 .64105 L F
.511 .129 .252 r
.43941 .77726 m .43823 .77942 L .43602 .77934 L F
.412 .062 .258 r
.44102 .77705 m .43823 .77942 L .43941 .77726 L F
.647 .387 .511 r
.62277 .6617 m .61965 .66425 L .62055 .66157 L F
.594 .628 .854 r
.68504 .60145 m .68549 .59732 L .68344 .59743 L F
.68504 .60145 m .68739 .60081 L .68549 .59732 L F
.83 .367 0 r
.67677 .70805 m .67902 .71063 L .67775 .70965 L F
.93 .644 .169 r
.67867 .71263 m .67775 .70965 L .67902 .71063 L F
.673 .611 .777 r
.52988 .82489 m .5332 .82772 L .53311 .82575 L F
.777 .938 .934 r
.34895 .81449 m .35033 .81488 L .35038 .81311 L F
.778 .994 .876 r
.71889 .71849 m .72034 .71635 L .71789 .71765 L F
.492 .567 .859 r
.72034 .71635 m .71889 .71849 L .71789 .71765 L F
.72034 .71635 m .72145 .7189 L .71889 .71849 L F
.505 0 0 r
.70236 .63021 m .70414 .63122 L .70378 .63143 L F
.70236 .63021 m .70378 .63143 L .70455 .62909 L F
.906 .951 .818 r
.68101 .70185 m .6803 .70289 L .67945 .70203 L F
0 0 0 r
.6803 .70289 m .68046 .70359 L .67945 .70203 L F
.6803 .70289 m .67939 .70483 L .68046 .70359 L F
.423 .163 .413 r
.33644 .71791 m .33462 .71843 L .33706 .71597 L F
.418 .184 .449 r
.33871 .71529 m .33644 .71791 L .33706 .71597 L F
.3 .052 .361 r
.32983 .72357 m .32945 .72618 L .32774 .72603 L F
.276 0 .158 r
.32849 .72756 m .32774 .72603 L .32945 .72618 L F
.32849 .72756 m .32671 .72819 L .32774 .72603 L F
.818 .672 .701 r
.61593 .64348 m .61294 .64321 L .61465 .64028 L F
.817 .678 .71 r
.61593 .64348 m .61427 .6464 L .61294 .64321 L F
.45 .406 .717 r
.35814 .66374 m .35891 .66758 L .3571 .66753 L F
.518 .582 .859 r
.48839 .8833 m .48557 .88513 L .4833 .88118 L F
.85 .775 .778 r
.71723 .72428 m .71389 .72367 L .71587 .72279 L F
.058 0 .337 r
.3313 .70244 m .33236 .7018 L .33275 .69934 L F
.253 .121 .5 r
.3313 .70244 m .33253 .70395 L .33236 .7018 L F
.3313 .70244 m .33119 .70484 L .33253 .70395 L F
.646 .71 .894 r
.46512 .73127 m .46291 .73188 L .4619 .73032 L F
.631 .553 .748 r
.4794 .74534 m .47729 .74592 L .47617 .74242 L F
.579 .506 .737 r
.36047 .77649 m .36139 .77982 L .35927 .78007 L F
.66 .49 .643 r
.36173 .78209 m .35927 .78007 L .36139 .77982 L F
.36173 .78209 m .35948 .78244 L .35927 .78007 L F
.662 .686 .862 r
.45331 .74146 m .45429 .74296 L .45643 .74226 L F
.395 .561 .9 r
.34434 .65583 m .34357 .6574 L .3426 .65567 L F
.479 .663 .943 r
.34434 .65583 m .34563 .65746 L .34357 .6574 L F
.908 .74 .661 r
.61513 .63585 m .61488 .6382 L .61382 .63512 L F
.597 .586 .811 r
.69502 .61844 m .69582 .61687 L .69366 .6169 L F
.69502 .61844 m .6965 .61839 L .69582 .61687 L F
.513 .279 .497 r
.36734 .76873 m .36512 .77152 L .3649 .76915 L F
.488 .133 .289 r
.40542 .77956 m .40762 .77939 L .40871 .77709 L F
.409 .055 .25 r
.40871 .77709 m .40969 .77903 L .41082 .77616 L F
.40871 .77709 m .40762 .77939 L .40969 .77903 L F
.593 .41 .603 r
.36255 .77405 m .36061 .77195 L .36266 .77171 L F
.36255 .77405 m .36057 .77463 L .36061 .77195 L F
.36 .133 .428 r
.31741 .71581 m .31911 .71536 L .31954 .71315 L F
.059 0 0 r
.31697 .71617 m .31911 .71536 L .31741 .71581 L F
.561 .552 .801 r
.37165 .67507 m .36986 .6759 L .36891 .67334 L F
.384 .312 .652 r
.37177 .67744 m .36986 .6759 L .37165 .67507 L F
.37177 .67744 m .37022 .67826 L .36986 .6759 L F
.193 0 .23 r
.7161 .61441 m .71743 .61536 L .71762 .61355 L F
.7161 .61441 m .71528 .61637 L .71743 .61536 L F
.422 .022 .173 r
.41105 .78769 m .40976 .7897 L .40764 .78994 L F
.229 0 .062 r
.41161 .78901 m .41105 .78769 L .41315 .78729 L F
.41161 .78901 m .40976 .7897 L .41105 .78769 L F
0 0 0 r
.33275 .69934 m .33387 .69852 L .33561 .69719 L F
.254 0 0 r
.33561 .69719 m .33601 .69818 L .33757 .69678 L F
.33561 .69719 m .33387 .69852 L .33601 .69818 L F
.834 .398 .195 r
.72287 .71686 m .72686 .72026 L .72425 .71931 L F
0 .442 .839 r
.72686 .72026 m .7251 .7197 L .72429 .71932 L F
.72686 .72026 m .72429 .71932 L .7243 .71932 L F
.834 .398 .195 r
.72536 .71898 m .72553 .72011 L .72686 .72026 L F
.72287 .71686 m .72553 .72011 L .72536 .71898 L F
0 .442 .839 r
.72686 .72026 m .72778 .72101 L .7251 .7197 L F
.802 .516 0 r
.72505 .71881 m .72568 .72113 L .72553 .72011 L F
.72568 .72113 m .72594 .72209 L .72553 .72011 L F
0 .11 .662 r
.72524 .71933 m .72489 .71933 L .72287 .71686 L F
0 0 0 r
.72505 .71881 m .72372 .71938 L .72548 .71883 L F
.908 .572 .395 r
.72553 .72011 m .72594 .72209 L .72686 .72026 L F
.741 .349 .308 r
.72594 .72209 m .72927 .72258 L .72686 .72026 L F
.276 .323 .731 r
.72642 .71853 m .72727 .72107 L .72505 .71881 L F
0 0 0 r
.72505 .71881 m .72548 .71883 L .72642 .71853 L F
0 .11 .662 r
.72505 .71881 m .72524 .71933 L .72473 .7188 L F
.72505 .71881 m .72473 .7188 L .72287 .71686 L F
.72524 .71933 m .72553 .72011 L .72489 .71933 L F
0 .442 .839 r
.7243 .71932 m .72429 .71932 L .72425 .71931 L F
.617 .457 .642 r
.41297 .74287 m .41224 .74512 L .40973 .74538 L F
.669 .433 .554 r
.41261 .74739 m .40973 .74538 L .41224 .74512 L F
.41261 .74739 m .41069 .74758 L .40973 .74538 L F
.785 .823 .883 r
.5004 .88629 m .50218 .88672 L .50416 .8845 L F
.941 .72 .574 r
.57345 .80876 m .5748 .81187 L .57499 .80939 L F
.764 .568 .633 r
.48514 .87471 m .48261 .87627 L .48233 .87327 L F
.454 .119 .307 r
.48514 .87471 m .48212 .87826 L .48261 .87627 L F
.48514 .87471 m .48457 .87833 L .48212 .87826 L F
.601 .455 .654 r
.48777 .87325 m .48759 .87597 L .48514 .87471 L F
.685 .267 .248 r
.48514 .87471 m .4864 .87763 L .48457 .87833 L F
.48514 .87471 m .48759 .87597 L .4864 .87763 L F
.643 .649 .841 r
.67565 .59799 m .67865 .60016 L .67793 .59787 L F
.692 .644 .797 r
.67793 .59787 m .67865 .60016 L .68111 .59806 L F
.58 .467 .689 r
.47968 .84925 m .48128 .84668 L .47955 .84678 L F
.546 .389 .62 r
.34892 .74535 m .35109 .74496 L .35106 .74263 L F
.576 .448 .669 r
.34911 .74768 m .35109 .74496 L .34892 .74535 L F
.079 0 0 r
.30342 .65638 m .30637 .6548 L .30423 .65556 L F
.686 .257 .224 r
.72213 .70805 m .72439 .70991 L .72107 .70919 L F
.63 .541 .736 r
.46125 .75025 m .46198 .75331 L .46424 .75285 L F
.682 .578 .732 r
.46211 .75556 m .46424 .75285 L .46198 .75331 L F
.513 .874 .984 r
.72735 .7155 m .72376 .71585 L .72356 .71315 L F
.72735 .7155 m .7256 .7152 L .72376 .71585 L F
0 .122 .594 r
.72735 .7155 m .72753 .71553 L .7256 .7152 L F
.72735 .7155 m .72923 .71697 L .72753 .71553 L F
.064 .347 .822 r
.72735 .7155 m .7299 .7182 L .72923 .71697 L F
.74 .643 .753 r
.35908 .69128 m .35864 .69247 L .35692 .69329 L F
.45 .189 .425 r
.3582 .69595 m .35692 .69329 L .35864 .69247 L F
.353 .128 .427 r
.36112 .69062 m .35864 .69247 L .35908 .69128 L F
.36112 .69062 m .36076 .6935 L .35864 .69247 L F
.414 .124 .36 r
.36022 .69542 m .35864 .69247 L .36076 .6935 L F
.36022 .69542 m .3582 .69595 L .35864 .69247 L F
.383 .561 .904 r
.38042 .78144 m .3793 .7826 L .37784 .7804 L F
.305 .435 .828 r
.38042 .78144 m .38133 .7833 L .3793 .7826 L F
.671 .544 .701 r
.3299 .7733 m .33124 .77184 L .32964 .77191 L F
.801 .463 .416 r
.71694 .69857 m .7205 .70136 L .71755 .69976 L F
.172 0 .166 r
.34315 .71 m .3407 .71249 L .34158 .71083 L F
.562 .454 .689 r
.33993 .69165 m .34194 .69129 L .34163 .68887 L F
.498 .351 .612 r
.33993 .69165 m .34195 .69367 L .34194 .69129 L F
.33993 .69165 m .34006 .69425 L .34195 .69367 L F
.314 .803 .794 r
.37999 .80053 m .38316 .79964 L .38118 .79999 L F
0 0 0 r
.38316 .79964 m .38324 .79964 L .38118 .79999 L F
.38316 .79964 m .38516 .79906 L .38324 .79964 L F
.492 .22 .429 r
.43199 .76952 m .43368 .77112 L .43483 .76894 L F
.459 .06 .193 r
.43368 .77112 m .43711 .76905 L .43483 .76894 L F
.216 .671 .948 r
.32527 .67532 m .32413 .67468 L .3224 .67458 L F
.4 .78 .992 r
.32527 .67532 m .32731 .67515 L .32413 .67468 L F
.53 .142 .25 r
.54777 .80502 m .55054 .8037 L .5486 .80475 L F
.386 .496 .848 r
.5502 .80567 m .5486 .80475 L .55054 .8037 L F
.685 .484 .609 r
.49231 .76372 m .49211 .76657 L .48966 .76614 L F
.673 .474 .608 r
.49514 .76618 m .49231 .76372 L .49406 .76315 L F
.49514 .76618 m .49211 .76657 L .49231 .76372 L F
.541 .315 .521 r
.64304 .61412 m .64502 .61199 L .64407 .61054 L F
0 .153 .606 r
.64665 .6131 m .64502 .61199 L .64639 .61233 L F
.569 .362 .56 r
.54401 .80942 m .54604 .81138 L .54577 .809 L F
.54401 .80942 m .54355 .81212 L .54604 .81138 L F
.327 0 0 r
.31207 .65273 m .31031 .65311 L .31362 .6531 L F
.58 .299 .455 r
.42937 .77144 m .43159 .77149 L .43199 .76952 L F
.492 .22 .429 r
.43199 .76952 m .43159 .77149 L .43368 .77112 L F
.823 .985 .881 r
.68101 .70185 m .68283 .69887 L .68359 .69928 L F
.68101 .70185 m .67945 .70203 L .68283 .69887 L F
.326 .497 .874 r
.66215 .59472 m .66073 .59598 L .66049 .59448 L F
.66215 .59472 m .66377 .5973 L .66073 .59598 L F
.567 .382 .589 r
.66073 .59598 m .66377 .5973 L .66213 .598 L F
.842 .793 .804 r
.68529 .72077 m .68577 .72321 L .68627 .72126 L F
.917 .926 .803 r
.68733 .71772 m .68627 .72126 L .68843 .71862 L F
.68733 .71772 m .68529 .72077 L .68627 .72126 L F
.746 .79 .888 r
.37365 .78473 m .37201 .786 L .37035 .78473 L F
0 0 0 r
.60744 .65511 m .60994 .65406 L .60759 .65413 L F
.31 .094 .415 r
.35151 .70137 m .3504 .7 L .352 .69942 L F
.35151 .70137 m .34996 .70216 L .3504 .7 L F
.039 0 0 r
.38909 .79782 m .38806 .7978 L .39079 .79645 L F
0 0 0 r
.39089 .7971 m .39079 .79645 L .39256 .79577 L F
.39089 .7971 m .38909 .79782 L .39079 .79645 L F
.65 .894 .983 r
.72107 .70919 m .71897 .70988 L .72023 .71043 L F
.199 .085 .49 r
.55561 .79251 m .55536 .79313 L .55403 .79351 L F
.119 .177 .649 r
.55403 .79351 m .55467 .79586 L .55532 .79434 L F
.206 0 0 r
.41012 .72293 m .41217 .72297 L .41355 .72257 L F
.839 .673 .676 r
.60383 .65967 m .60222 .65995 L .60212 .65894 L F
.383 .19 .492 r
.60222 .65995 m .60411 .65982 L .6041 .65839 L F
.942 .933 .583 r
.60411 .65982 m .60345 .66017 L .60403 .6589 L F
.60411 .65982 m .60463 .65761 L .6041 .65839 L F
.60444 .65839 m .60403 .6589 L .60463 .65761 L F
.60411 .65982 m .60403 .6589 L .60444 .65839 L F
0 0 0 r
.60744 .65511 m .6058 .65673 L .60551 .65738 L F
.6058 .65673 m .6041 .65839 L .60493 .65779 L F
.6058 .65673 m .60493 .65779 L .60551 .65738 L F
.60744 .65511 m .60826 .65521 L .60994 .65406 L F
.60551 .65738 m .60826 .65521 L .60744 .65511 L F
.751 .507 .563 r
.47887 .7664 m .47538 .76833 L .47633 .76658 L F
.351 .547 .904 r
.68756 .59088 m .68501 .59121 L .68415 .58977 L F
.68756 .59088 m .68773 .59205 L .68501 .59121 L F
.561 0 0 r
.428 .74172 m .42435 .7397 L .42602 .74149 L F
.984 .769 .535 r
.70861 .69962 m .70774 .69598 L .70881 .69749 L F
.714 .736 .868 r
.71104 .69643 m .70881 .69749 L .70774 .69598 L F
.501 .275 .504 r
.33644 .71791 m .33432 .72023 L .33462 .71843 L F
.266 .489 .886 r
.693 .59477 m .69189 .5957 L .69133 .59424 L F
.262 .482 .882 r
.693 .59477 m .69479 .59729 L .69189 .5957 L F
.589 .428 .631 r
.33004 .7745 m .33124 .77184 L .3299 .7733 L F
.967 .651 .274 r
.48183 .84893 m .48315 .85187 L .48257 .84947 L F
.736 .601 .707 r
.63886 .64104 m .64045 .63869 L .63683 .63772 L F
.305 .752 .961 r
.4243 .72402 m .42652 .72394 L .42771 .72444 L F
.249 .688 .96 r
.42851 .72384 m .42771 .72444 L .42652 .72394 L F
.42851 .72384 m .42987 .72457 L .42771 .72444 L F
.279 0 .228 r
.48719 .83048 m .48759 .83075 L .48924 .82761 L F
.282 .717 .966 r
.48924 .82761 m .49028 .82707 L .49071 .82765 L F
.112 0 .129 r
.48924 .82761 m .491 .82841 L .49071 .82765 L F
.568 .398 .611 r
.491 .82841 m .48943 .8308 L .48924 .82761 L F
.112 0 .129 r
.48924 .82761 m .48984 .82874 L .491 .82841 L F
.48924 .82761 m .48759 .83075 L .48984 .82874 L F
.568 .398 .611 r
.491 .82841 m .48924 .82761 L .49071 .82765 L F
.476 .651 .936 r
.36623 .78709 m .3628 .7852 L .36506 .78467 L F
.586 .564 .796 r
.3671 .78408 m .36623 .78709 L .36506 .78467 L F
.3671 .78408 m .36794 .78655 L .36623 .78709 L F
.189 0 .259 r
.64443 .60696 m .64613 .60531 L .64448 .60637 L F
.656 .767 .931 r
.33904 .65546 m .33703 .65482 L .33895 .65435 L F
.504 .705 .961 r
.341 .65407 m .33904 .65546 L .33895 .65435 L F
.341 .65407 m .3426 .65567 L .33904 .65546 L F
.393 0 0 r
.41286 .77604 m .41501 .7761 L .41638 .77494 L F
.698 .244 .17 r
.41501 .7761 m .41845 .77671 L .41638 .77494 L F
.413 .146 .397 r
.65549 .63514 m .6579 .63266 L .65544 .63292 L F
.65549 .63514 m .65752 .63447 L .6579 .63266 L F
.916 .611 .451 r
.65669 .63172 m .65711 .63421 L .65705 .63414 L F
0 0 .467 r
.65637 .62957 m .65669 .63172 L .65544 .63292 L F
.59 .049 0 r
.65544 .63292 m .65441 .63231 L .65202 .63009 L F
.519 .868 .99 r
.65544 .63292 m .65669 .63172 L .65441 .63231 L F
.916 .611 .451 r
.65669 .63172 m .65705 .63414 L .6554 .6322 L F
0 0 .467 r
.65647 .62919 m .65669 .63172 L .65637 .62957 L F
.748 .677 .782 r
.40515 .75014 m .40552 .75214 L .40833 .75031 L F
.399 .182 .464 r
.34044 .71468 m .33914 .71315 L .3407 .71249 L F
.34044 .71468 m .33871 .71529 L .33914 .71315 L F
.25 0 0 r
.34182 .82699 m .34158 .82677 L .3402 .82584 L F
.34182 .82699 m .34354 .82728 L .34158 .82677 L F
.735 .991 .822 r
.34162 .8118 m .33962 .8137 L .34033 .81373 L F
.557 .57 .822 r
.6967 .60776 m .69818 .61089 L .70027 .61034 L F
.719 .575 .693 r
.69818 .61089 m .70083 .6135 L .70027 .61034 L F
.426 .168 .417 r
.35692 .69329 m .35622 .69651 L .35439 .69694 L F
.45 .189 .425 r
.3582 .69595 m .35622 .69651 L .35692 .69329 L F
.127 0 0 r
.6557 .64864 m .65254 .65059 L .65381 .64936 L F
.841 .723 .733 r
.70353 .61131 m .70445 .61426 L .70581 .61157 L F
.713 .557 .676 r
.70581 .61157 m .70445 .61426 L .70658 .61361 L F
.726 .375 .383 r
.71146 .73402 m .71054 .73596 L .70833 .73379 L F
.785 .533 .556 r
.71415 .7345 m .71054 .73596 L .71146 .73402 L F
.306 .012 .29 r
.3243 .73065 m .32337 .72957 L .32506 .7289 L F
.3243 .73065 m .32261 .73135 L .32337 .72957 L F
.492 .093 .212 r
.45668 .7733 m .45404 .77373 L .45477 .77231 L F
.493 .09 .204 r
.45708 .77222 m .45668 .7733 L .45477 .77231 L F
.875 .716 .681 r
.54103 .83828 m .54227 .84137 L .54311 .83816 L F
.425 .142 .377 r
.34924 .70397 m .34793 .70268 L .34996 .70216 L F
.34924 .70397 m .34734 .7045 L .34793 .70268 L F
.851 .488 .363 r
.6837 .6359 m .68159 .63634 L .68178 .63423 L F
.6837 .6359 m .68379 .63736 L .68159 .63634 L F
.657 .63 .811 r
.70027 .61034 m .70083 .6135 L .70353 .61131 L F
.639 .612 .806 r
.70164 .61314 m .70353 .61131 L .70083 .6135 L F
.829 .419 .265 r
.7211 .72838 m .72039 .72901 L .71892 .72788 L F
0 0 0 r
.72195 .72797 m .7211 .72838 L .72237 .72616 L F
.72195 .72797 m .72039 .72901 L .7211 .72838 L F
.885 .458 .073 r
.72156 .70391 m .72157 .70227 L .7205 .70136 L F
.72156 .70391 m .72254 .70461 L .72157 .70227 L F
.6 .586 .809 r
.71143 .71207 m .71255 .71398 L .71089 .71336 L F
0 .047 .596 r
.47978 .88362 m .48126 .88615 L .48059 .88323 L F
.314 .803 .794 r
.37999 .80053 m .38118 .79999 L .37929 .80068 L F
.807 .778 .826 r
.67082 .6003 m .67373 .60004 L .67291 .59816 L F
.678 .264 .253 r
.67082 .6003 m .67271 .60207 L .67373 .60004 L F
.773 .764 .844 r
.67291 .59816 m .67373 .60004 L .67565 .59799 L F
.807 .418 .317 r
.67271 .60207 m .67524 .6026 L .67373 .60004 L F
.879 .743 .708 r
.62815 .63775 m .62926 .64068 L .63067 .63692 L F
.757 .596 .678 r
.63067 .63692 m .62926 .64068 L .63236 .64076 L F
.658 .498 .656 r
.63236 .64076 m .63457 .63832 L .63067 .63692 L F
0 0 0 r
.66271 .62936 m .66108 .63087 L .66001 .63199 L F
.917 .941 .803 r
.64912 .60568 m .6464 .60806 L .647 .60807 L F
.838 .998 .823 r
.48024 .87406 m .4775 .87284 L .47865 .87284 L F
.709 .639 .777 r
.48233 .87327 m .48024 .87406 L .47865 .87284 L F
.644 .47 .633 r
.557 .80658 m .55716 .80923 L .5548 .80924 L F
.739 .542 .627 r
.56029 .80919 m .557 .80658 L .55926 .80712 L F
.56029 .80919 m .55716 .80923 L .557 .80658 L F
.658 .498 .656 r
.63236 .64076 m .63475 .64112 L .63457 .63832 L F
.733 .6 .708 r
.63475 .64112 m .63683 .63772 L .63457 .63832 L F
.668 .824 .958 r
.69171 .71199 m .68934 .71285 L .69258 .71305 L F
.442 .712 .981 r
.69258 .71305 m .69381 .71194 L .69171 .71199 L F
.318 .494 .875 r
.69258 .71305 m .69422 .71343 L .69381 .71194 L F
.517 .38 .633 r
.40487 .74789 m .40515 .75014 L .407 .74948 L F
.564 .924 .752 r
.70794 .60192 m .70429 .60423 L .70654 .60303 L F
.837 .978 .681 r
.70794 .60192 m .70884 .5999 L .7098 .6006 L F
.70794 .60192 m .70654 .60303 L .70884 .5999 L F
.415 .646 .953 r
.54604 .81138 m .54731 .81295 L .5497 .81259 L F
.582 .168 .221 r
.513 .87814 m .51048 .87677 L .51012 .87815 L F
.848 .98 .867 r
.6351 .59454 m .6382 .59266 L .63654 .59539 L F
.6351 .59454 m .63753 .59208 L .6382 .59266 L F
.843 .986 .863 r
.63753 .59208 m .64062 .59014 L .6382 .59266 L F
.345 .089 .375 r
.33124 .72545 m .32983 .72357 L .33179 .72302 L F
.33124 .72545 m .32945 .72618 L .32983 .72357 L F
.596 .822 .986 r
.40515 .75014 m .40833 .75031 L .407 .74948 L F
.725 .617 .736 r
.40635 .74664 m .40905 .74819 L .40806 .74428 L F
.40905 .74819 m .40933 .74835 L .40924 .74806 L F
.40905 .74819 m .40924 .74806 L .40806 .74428 L F
.491 .477 .769 r
.40806 .74428 m .40924 .74806 L .41005 .74529 L F
.40924 .74806 m .40933 .74835 L .40957 .74731 L F
.40924 .74806 m .40957 .74731 L .41005 .74529 L F
.808 .854 .884 r
.40909 .74841 m .40833 .75031 L .41069 .74758 L F
.40767 .74914 m .40828 .75022 L .40909 .74841 L F
.40828 .75022 m .40833 .75031 L .40909 .74841 L F
.407 .74948 m .40709 .74954 L .40767 .74914 L F
.40709 .74954 m .40833 .75031 L .40767 .74914 L F
.495 .141 .296 r
.70907 .63566 m .70599 .63796 L .70565 .63536 L F
.70907 .63566 m .70858 .63775 L .70599 .63796 L F
.338 0 .195 r
.71131 .63518 m .70858 .63775 L .70907 .63566 L F
.39 .57 .909 r
.44628 .72701 m .44545 .72823 L .44408 .7265 L F
.44628 .72701 m .44741 .72862 L .44545 .72823 L F
.259 .047 .389 r
.31954 .71315 m .32071 .71417 L .32134 .71271 L F
.31954 .71315 m .31911 .71536 L .32071 .71417 L F
.88 .61 .088 r
.57659 .79797 m .57728 .80082 L .57817 .79875 L F
.49 .635 .918 r
.6993 .7182 m .70053 .71667 L .69773 .71546 L F
.6993 .7182 m .70146 .71809 L .70053 .71667 L F
0 0 0 r
.5512 .80152 m .55166 .80067 L .55249 .79829 L F
.55054 .8037 m .55166 .80067 L .5512 .80152 L F
.549 .756 .973 r
.46046 .72895 m .45985 .73071 L .45832 .72927 L F
.46046 .72895 m .4619 .73032 L .45985 .73071 L F
.615 .389 .551 r
.52817 .8243 m .52988 .82489 L .52956 .82268 L F
.262 .757 .692 r
.36244 .8066 m .36378 .80611 L .36224 .80678 L F
.606 .519 .729 r
.48724 .8331 m .48501 .83352 L .4868 .83084 L F
.48724 .8331 m .48501 .83352 L .4868 .83084 L F
.48 .212 .431 r
.43958 .76664 m .44128 .76829 L .44251 .7664 L F
.217 0 .046 r
.44251 .7664 m .44322 .7676 L .44463 .76603 L F
.44251 .7664 m .44128 .76829 L .44322 .7676 L F
.771 .471 .479 r
.64829 .59172 m .65176 .5904 L .65025 .58874 L F
.64829 .59172 m .65166 .59214 L .65176 .5904 L F
.323 .102 .415 r
.65176 .5904 m .65384 .59148 L .65441 .59068 L F
.65176 .5904 m .65166 .59214 L .65384 .59148 L F
.684 .44 .547 r
.62885 .64306 m .63236 .64076 L .62926 .64068 L F
.62885 .64306 m .63236 .64344 L .63236 .64076 L F
.588 .363 .542 r
.63236 .64076 m .63457 .64295 L .63475 .64112 L F
.63236 .64076 m .63236 .64344 L .63457 .64295 L F
.466 .241 .487 r
.34569 .70512 m .34531 .70728 L .34338 .70773 L F
.368 .155 .453 r
.34734 .7045 m .34531 .70728 L .34569 .70512 L F
.421 .093 .301 r
.3786 .72923 m .38011 .7302 L .38081 .72916 L F
.3786 .72923 m .37801 .73069 L .38011 .7302 L F
.505 .51 .795 r
.48006 .85121 m .48211 .85538 L .48323 .85419 L F
0 0 0 r
.48211 .85538 m .48165 .8562 L .48323 .85419 L F
.48211 .85538 m .48069 .85725 L .48165 .8562 L F
.479 .275 .525 r
.34531 .70728 m .34315 .71 L .34338 .70773 L F
.502 .299 .537 r
.37161 .76131 m .37175 .76355 L .36962 .76381 L F
.334 .109 .416 r
.37175 .76355 m .36969 .76606 L .36962 .76381 L F
.446 .427 .744 r
.48967 .75765 m .4889 .7601 L .48774 .75836 L F
.48967 .75765 m .49057 .7606 L .4889 .7601 L F
.655 .901 .981 r
.7098 .6006 m .71064 .59917 L .71197 .60017 L F
.7098 .6006 m .70884 .5999 L .71064 .59917 L F
.468 .229 .467 r
.33373 .72204 m .33221 .72081 L .33432 .72023 L F
.33373 .72204 m .33179 .72302 L .33221 .72081 L F
.321 .167 .51 r
.37314 .76288 m .37161 .76131 L .37381 .76125 L F
.37314 .76288 m .37175 .76355 L .37161 .76131 L F
.578 .551 .789 r
.46067 .74844 m .46125 .75025 L .46328 .74983 L F
.63 .541 .736 r
.46125 .75025 m .46424 .75285 L .46328 .74983 L F
.934 .913 .773 r
.48192 .86388 m .48148 .86208 L .48264 .86286 L F
.572 .457 .684 r
.68166 .61157 m .68078 .61493 L .68024 .61308 L F
.724 .429 0 r
.68024 .61308 m .68078 .61493 L .68095 .61566 L F
.528 .397 .646 r
.60001 .65924 m .60222 .65995 L .60212 .65894 L F
.60001 .65924 m .60222 .65995 L .60212 .65894 L F
.158 0 0 r
.41721 .78639 m .41873 .78519 L .4208 .78472 L F
.314 0 .078 r
.6434 .65372 m .64245 .6554 L .64027 .65592 L F
.351 0 0 r
.6434 .65372 m .64483 .65473 L .64245 .6554 L F
.6434 .65372 m .6455 .65354 L .64483 .65473 L F
.668 .417 .531 r
.50193 .87824 m .50534 .8761 L .50352 .87544 L F
.50193 .87824 m .50573 .87869 L .50534 .8761 L F
.707 .421 .488 r
.50777 .87875 m .50534 .8761 L .50573 .87869 L F
.685 .75 .901 r
.70252 .71938 m .70394 .71726 L .70146 .71809 L F
.70252 .71938 m .70486 .7185 L .70394 .71726 L F
.774 .688 .768 r
.33249 .67584 m .33405 .67826 L .33648 .67598 L F
.33249 .67584 m .33648 .67598 L .33513 .67602 L F
.267 .773 .786 r
.33648 .67598 m .33678 .6757 L .33513 .67602 L F
.33648 .67598 m .33826 .67549 L .33678 .6757 L F
.043 .554 .875 r
.43331 .72548 m .43523 .72589 L .43652 .72656 L F
.426 .813 .989 r
.43523 .72589 m .43862 .7261 L .43652 .72656 L F
.575 .241 .365 r
.65323 .61018 m .65876 .60956 L .65885 .60803 L F
.609 .707 .914 r
.56409 .80973 m .56393 .81006 L .56029 .80919 L F
.985 .777 .542 r
.56393 .81006 m .56268 .81153 L .56029 .80919 L F
0 0 .46 r
.56426 .80867 m .56393 .81006 L .56409 .80973 L F
.066 .308 .792 r
.71486 .69689 m .71392 .69757 L .71338 .69602 L F
.879 .443 .124 r
.71486 .69689 m .71694 .69857 L .71392 .69757 L F
.306 0 0 r
.39937 .72397 m .40138 .72379 L .40256 .72304 L F
.396 0 0 r
.40138 .72379 m .40464 .72347 L .40256 .72304 L F
.468 .01 .081 r
.7299 .7182 m .73198 .71845 L .73112 .7195 L F
.7299 .7182 m .73112 .7195 L .72923 .71697 L F
.802 .636 .676 r
.63129 .62464 m .63461 .62483 L .63349 .62192 L F
.681 .448 .563 r
.63139 .62683 m .63461 .62483 L .63129 .62464 L F
.63139 .62683 m .63476 .62699 L .63461 .62483 L F
.76 .36 .294 r
.50063 .87543 m .50176 .87382 L .5005 .8733 L F
.50063 .87543 m .50352 .87544 L .50176 .87382 L F
.589 .428 .631 r
.33004 .7745 m .33209 .77173 L .33124 .77184 L F
.481 .254 .493 r
.36351 .68605 m .36346 .68844 L .36117 .68881 L F
.442 .217 .476 r
.36576 .68353 m .36578 .68549 L .36351 .68605 L F
.51 .278 .498 r
.36573 .68787 m .36351 .68605 L .36578 .68549 L F
.36573 .68787 m .36346 .68844 L .36351 .68605 L F
.846 .716 .72 r
.61382 .63512 m .61488 .6382 L .61234 .6378 L F
.844 .676 .674 r
.61465 .64028 m .61234 .6378 L .61488 .6382 L F
.682 .578 .732 r
.46211 .75556 m .4652 .75592 L .46424 .75285 L F
.699 .542 .671 r
.46183 .75814 m .4652 .75592 L .46211 .75556 L F
0 0 0 r
.67659 .58964 m .674 .59289 L .67488 .59234 L F
.601 .795 .973 r
.67459 .59046 m .67467 .59216 L .67528 .59194 L F
.6766 .59076 m .67528 .59194 L .67797 .59096 L F
0 0 0 r
.67608 .59098 m .67507 .59213 L .67594 .59135 L F
.67659 .58964 m .67488 .59234 L .67608 .59098 L F
.67659 .58964 m .67594 .59135 L .67556 .58904 L F
.601 .795 .973 r
.67459 .59046 m .67528 .59194 L .67594 .59135 L F
0 0 0 r
.67594 .59135 m .67578 .59178 L .67573 .59114 L F
.67594 .59135 m .67573 .59114 L .67556 .58904 L F
.92 .566 .346 r
.67459 .59046 m .67556 .58904 L .67573 .59114 L F
.67459 .59046 m .67573 .59114 L .67578 .59178 L F
.601 .795 .973 r
.67511 .59054 m .67573 .59114 L .6766 .59076 L F
.67573 .59114 m .67594 .59135 L .67599 .5913 L F
.67573 .59114 m .67599 .5913 L .6766 .59076 L F
.67459 .59046 m .67594 .59135 L .67511 .59054 L F
0 0 0 r
.67594 .59135 m .67488 .59234 L .67578 .59178 L F
.648 .667 .855 r
.67685 .59435 m .67797 .59096 L .67528 .59194 L F
0 0 0 r
.67507 .59213 m .67488 .59234 L .67491 .59231 L F
.67507 .59213 m .67491 .59231 L .67528 .59194 L F
.648 .667 .855 r
.67486 .59236 m .67528 .59194 L .67467 .59216 L F
.67685 .59435 m .67528 .59194 L .67489 .59234 L F
.67685 .59435 m .67489 .59234 L .67488 .59237 L F
.671 .613 .782 r
.67458 .59492 m .67685 .59435 L .67486 .59236 L F
.67458 .59492 m .67578 .59178 L .67489 .59234 L F
.67439 .59426 m .67489 .59234 L .674 .59289 L F
.67458 .59492 m .67489 .59234 L .67439 .59426 L F
.648 .667 .855 r
.67488 .59237 m .67489 .59234 L .67486 .59236 L F
0 0 0 r
.67528 .59194 m .67491 .59231 L .67594 .59135 L F
.671 .613 .782 r
.67465 .59259 m .67486 .59236 L .67467 .59216 L F
.67458 .59492 m .67486 .59236 L .67465 .59259 L F
.628 .902 .985 r
.67928 .58841 m .67659 .58964 L .67556 .58904 L F
.561 .474 .713 r
.33626 .76403 m .33849 .76594 L .33858 .76365 L F
.33626 .76403 m .33668 .76642 L .33849 .76594 L F
.315 0 .227 r
.35887 .80978 m .36224 .80678 L .36098 .80843 L F
.079 0 0 r
.36098 .80843 m .36224 .80678 L .36378 .80611 L F
.5 .23 .436 r
.43711 .76905 m .43921 .76871 L .43958 .76664 L F
.48 .212 .431 r
.43958 .76664 m .43921 .76871 L .44128 .76829 L F
.623 .618 .825 r
.72112 .61567 m .71869 .61652 L .71762 .61355 L F
.406 .006 .165 r
.4469 .76614 m .44904 .76583 L .45022 .76388 L F
.348 0 .048 r
.44904 .76583 m .45242 .76384 L .45022 .76388 L F
.548 .876 .605 r
.68148 .60441 m .68249 .6037 L .68011 .60581 L F
.021 0 0 r
.68474 .60315 m .68249 .6037 L .68148 .60441 L F
.733 .6 .708 r
.63475 .64112 m .63886 .64104 L .63683 .63772 L F
0 0 0 r
.63846 .64292 m .637 .64449 L .63824 .64487 L F
.63802 .64346 m .63846 .64292 L .63886 .64104 L F
.63785 .64396 m .63846 .64292 L .63802 .64346 L F
.772 .504 .529 r
.64024 .64558 m .64086 .64305 L .63846 .64292 L F
.64024 .64558 m .63846 .64292 L .63824 .64487 L F
0 0 0 r
.63785 .64396 m .63936 .64222 L .63846 .64292 L F
.63846 .64292 m .63871 .64272 L .63816 .64329 L F
.63846 .64292 m .63816 .64329 L .637 .64449 L F
.632 .335 .45 r
.63457 .64295 m .63762 .64389 L .63475 .64112 L F
.605 .435 .625 r
.637 .64449 m .63763 .64388 L .63785 .64396 L F
.632 .335 .45 r
.63763 .64388 m .63785 .64396 L .63769 .64381 L F
.669 .321 .375 r
.63769 .64381 m .63785 .64396 L .63802 .64346 L F
.605 .435 .625 r
.63763 .64388 m .63936 .64222 L .63785 .64396 L F
.632 .335 .45 r
.63762 .64389 m .63785 .64396 L .63763 .64388 L F
.63762 .64389 m .63769 .64381 L .63475 .64112 L F
0 0 0 r
.63769 .64381 m .63936 .64222 L .63765 .64386 L F
.63871 .64272 m .63889 .64258 L .63769 .64381 L F
.63889 .64258 m .63936 .64222 L .63769 .64381 L F
.63871 .64272 m .63765 .64386 L .637 .64449 L F
.669 .321 .375 r
.63475 .64112 m .63769 .64381 L .63886 .64104 L F
.63769 .64381 m .63802 .64346 L .63886 .64104 L F
0 0 .391 r
.67118 .60597 m .67262 .60877 L .67212 .60767 L F
.398 0 0 r
.67345 .60932 m .67502 .61037 L .67393 .60965 L F
.67262 .60877 m .67413 .60977 L .67345 .60932 L F
.67413 .60977 m .67502 .61037 L .67345 .60932 L F
.797 .946 .921 r
.67026 .61247 m .67441 .61106 L .67313 .60911 L F
.398 0 0 r
.67262 .60877 m .67393 .60965 L .67212 .60767 L F
.797 .946 .921 r
.67287 .60894 m .67313 .60911 L .67294 .60883 L F
.67026 .61247 m .67313 .60911 L .67287 .60894 L F
.589 .428 .631 r
.33004 .7745 m .33213 .77416 L .33209 .77173 L F
.608 .459 .653 r
.3302 .77697 m .33213 .77416 L .33004 .7745 L F
.664 .63 .805 r
.70537 .60604 m .70828 .60736 L .70756 .60569 L F
.552 .666 .912 r
.70828 .60736 m .7095 .6051 L .70756 .60569 L F
.70828 .60736 m .71077 .60759 L .7095 .6051 L F
.673 .573 .734 r
.48604 .75037 m .484 .75299 L .48337 .75013 L F
.619 .496 .691 r
.48622 .7525 m .484 .75299 L .48604 .75037 L F
.553 .598 .852 r
.4782 .74213 m .47617 .74242 L .47466 .73937 L F
.631 .553 .748 r
.4794 .74534 m .47617 .74242 L .4782 .74213 L F
0 0 0 r
.43613 .74165 m .43532 .74267 L .4362 .74148 L F
.526 .321 .544 r
.43662 .74447 m .43453 .74489 L .43532 .74267 L F
.513 .279 .497 r
.36734 .76873 m .36738 .77113 L .36512 .77152 L F
.43 .254 .539 r
.36969 .76606 m .36955 .76857 L .36734 .76873 L F
.445 .24 .507 r
.36955 .76857 m .36738 .77113 L .36734 .76873 L F
.439 0 0 r
.44221 .73993 m .44085 .74099 L .43894 .74022 L F
.605 .418 .601 r
.33427 .76906 m .33653 .76888 L .33668 .76642 L F
.572 .389 .596 r
.33668 .76642 m .33866 .76849 L .33849 .76594 L F
.33668 .76642 m .33653 .76888 L .33866 .76849 L F
.473 0 0 r
.33205 .67552 m .33249 .67584 L .32934 .6747 L F
.63 .464 .639 r
.37872 .75584 m .37908 .75841 L .37669 .75827 L F
.37872 .75584 m .37908 .75841 L .37669 .75827 L F
.407 .326 .653 r
.38042 .75549 m .38065 .75748 L .37872 .75584 L F
.435 .326 .631 r
.38065 .75748 m .37908 .75841 L .37872 .75584 L F
.923 .946 .793 r
.72537 .71045 m .72272 .71275 L .72439 .70991 L F
.72537 .71045 m .72356 .71315 L .72272 .71275 L F
.5 .901 .925 r
.7267 .70948 m .72758 .70967 L .72537 .71045 L F
.479 .836 .995 r
.72439 .70991 m .7267 .70948 L .72537 .71045 L F
.668 .65 .822 r
.72758 .70967 m .72867 .71106 L .72537 .71045 L F
.791 .34 .174 r
.64101 .61324 m .64304 .61412 L .64201 .61441 L F
.276 .307 .714 r
.64101 .61324 m .64201 .61441 L .64193 .61405 L F
.688 .149 0 r
.64101 .61324 m .64195 .61417 L .64206 .61416 L F
.64101 .61324 m .64193 .61405 L .64304 .61412 L F
.722 .609 .731 r
.64193 .61405 m .64407 .61054 L .64105 .61013 L F
.64201 .61441 m .64215 .61416 L .64193 .61405 L F
.64215 .61416 m .64407 .61054 L .64193 .61405 L F
.688 .149 0 r
.64193 .61405 m .64206 .61416 L .64215 .61416 L F
.64193 .61405 m .64215 .61416 L .64304 .61412 L F
.276 .307 .714 r
.64101 .61324 m .64193 .61405 L .64105 .61013 L F
.541 .315 .521 r
.64304 .61412 m .64407 .61054 L .64215 .61416 L F
.64304 .61412 m .64215 .61416 L .64201 .61441 L F
.688 .149 0 r
.64195 .61417 m .64247 .61469 L .64304 .61412 L F
.591 .885 .991 r
.64538 .62482 m .64436 .62421 L .6421 .62496 L F
.6421 .62496 m .64436 .62421 L .64538 .62482 L F
.328 0 .205 r
.64392 .61556 m .64304 .61412 L .64247 .61469 L F
.577 .879 .993 r
.64538 .62482 m .64655 .62353 L .64436 .62421 L F
.64538 .62482 m .64655 .62353 L .64436 .62421 L F
.591 .885 .991 r
.64538 .62482 m .64436 .62421 L .6421 .62496 L F
.639 .612 .806 r
.70164 .61314 m .70445 .61426 L .70353 .61131 L F
.636 .458 .625 r
.55249 .79829 m .55483 .79872 L .55467 .79586 L F
.268 .354 .767 r
.55467 .79586 m .55699 .79828 L .55532 .79434 L F
.585 .419 .623 r
.55467 .79586 m .55483 .79872 L .55699 .79828 L F
.458 .656 .946 r
.68975 .59252 m .68848 .59394 L .68773 .59205 L F
.68975 .59252 m .69133 .59424 L .68848 .59394 L F
.7 .661 .808 r
.48111 .87035 m .48233 .87327 L .47865 .87284 L F
.688 .655 .812 r
.48455 .87174 m .48233 .87327 L .48111 .87035 L F
.504 .223 .421 r
.37669 .75827 m .37595 .76092 L .37381 .76125 L F
.564 .28 .443 r
.37813 .7599 m .37669 .75827 L .37908 .75841 L F
.37813 .7599 m .37595 .76092 L .37669 .75827 L F
.898 .887 .813 r
.68245 .72559 m .68372 .72635 L .68577 .72321 L F
0 0 0 r
.63721 .62044 m .63838 .61978 L .63712 .62122 L F
.63721 .62044 m .63712 .62122 L .63671 .62168 L F
.603 .061 0 r
.63731 .61962 m .63721 .62044 L .63546 .61916 L F
.63898 .62003 m .63721 .62044 L .63731 .61962 L F
.436 .846 .968 r
.64252 .61807 m .64211 .61779 L .64074 .61857 L F
0 0 0 r
.64074 .61857 m .64211 .61779 L .64038 .619 L F
.722 .889 .957 r
.64038 .619 m .64211 .61779 L .64054 .61779 L F
.63997 .61829 m .64054 .61779 L .63969 .61779 L F
.64038 .619 m .64054 .61779 L .63997 .61829 L F
0 0 0 r
.64074 .61857 m .63809 .61998 L .63898 .62003 L F
.63809 .61998 m .63721 .62044 L .6377 .62033 L F
.63809 .61998 m .6377 .62033 L .63898 .62003 L F
.387 .645 .959 r
.45061 .74064 m .45176 .73977 L .44967 .73977 L F
.45061 .74064 m .45331 .74146 L .45176 .73977 L F
.753 .49 .534 r
.56987 .795 m .57294 .79328 L .57116 .79277 L F
.56987 .795 m .57296 .7953 L .57294 .79328 L F
.641 .126 0 r
.72954 .71225 m .72867 .71106 L .72758 .70967 L F
.72954 .71225 m .73064 .71316 L .72867 .71106 L F
.456 .819 .995 r
.49691 .88829 m .49754 .88738 L .49489 .88783 L F
.49691 .88829 m .49865 .88789 L .49754 .88738 L F
.623 .41 .572 r
.45771 .76077 m .45989 .76089 L .45999 .75844 L F
.604 .385 .557 r
.45989 .76089 m .46183 .75814 L .45999 .75844 L F
.846 .71 .712 r
.70996 .7048 m .70698 .70457 L .7089 .70177 L F
.832 .71 .73 r
.70996 .7048 m .70823 .70751 L .70628 .70703 L F
.767 .672 .759 r
.71215 .7021 m .70996 .7048 L .7089 .70177 L F
.365 0 0 r
.66624 .64319 m .66555 .64355 L .66316 .64341 L F
.188 0 0 r
.66858 .64289 m .66555 .64355 L .66624 .64319 L F
.651 .511 .679 r
.33836 .76125 m .33858 .76365 L .34065 .76091 L F
.57 .56 .803 r
.55932 .81735 m .56151 .81706 L .56031 .81392 L F
.656 .482 .637 r
.5548 .80924 m .55258 .81179 L .55142 .80891 L F
.5548 .80924 m .55488 .81179 L .55258 .81179 L F
.624 .357 .493 r
.55716 .80923 m .55696 .81124 L .5548 .80924 L F
.508 .366 .623 r
.55696 .81124 m .55488 .81179 L .5548 .80924 L F
.453 .269 .541 r
.36777 .68075 m .36757 .68316 L .36576 .68353 L F
.546 .297 .489 r
.36739 .68523 m .36576 .68353 L .36757 .68316 L F
.36739 .68523 m .36578 .68549 L .36576 .68353 L F
.689 .545 .684 r
.4775 .87284 m .47865 .87284 L .47909 .87067 L F
.514 .334 .574 r
.47909 .87067 m .48111 .87035 L .48122 .86797 L F
.871 .817 .337 r
.47909 .87067 m .48017 .8704 L .48111 .87035 L F
.47909 .87067 m .47865 .87284 L .47839 .87247 L F
.7 .661 .808 r
.48111 .87035 m .47865 .87284 L .47909 .87067 L F
.871 .817 .337 r
.47909 .87067 m .47839 .87247 L .48017 .8704 L F
.522 .165 .302 r
.4663 .76968 m .46218 .77115 L .46233 .76925 L F
.597 .946 .804 r
.65105 .6382 m .65229 .63694 L .65273 .63695 L F
0 0 0 r
.64999 .63956 m .65229 .63694 L .65105 .6382 L F
.829 .598 .589 r
.6904 .64079 m .68752 .64242 L .68753 .64017 L F
.6904 .64079 m .69043 .64334 L .68752 .64242 L F
.763 .544 .6 r
.69386 .64354 m .69043 .64334 L .6904 .64079 L F
0 0 0 r
.38711 .77957 m .3843 .78183 L .38619 .78149 L F
.467 .049 .161 r
.38619 .78149 m .38867 .78092 L .38711 .77957 L F
.666 .644 .818 r
.56283 .80738 m .56029 .80919 L .55926 .80712 L F
.197 0 0 r
.30885 .67777 m .3104 .67784 L .3083 .67789 L F
.926 .971 .693 r
.63728 .60235 m .63646 .60224 L .63794 .60115 L F
.953 .689 .5 r
.63794 .60115 m .63646 .60224 L .63637 .59992 L F
.725 .356 .352 r
.55258 .81179 m .5497 .81259 L .55016 .81119 L F
.69 .405 .486 r
.49252 .88045 m .49438 .88096 L .49477 .87902 L F
.679 .432 .541 r
.49438 .88096 m .49836 .8784 L .49477 .87902 L F
0 .335 .777 r
.65577 .59118 m .6575 .59247 L .65688 .59211 L F
.65549 .59108 m .65688 .59211 L .65441 .59068 L F
.65577 .59118 m .65688 .59211 L .65549 .59108 L F
.864 .687 .661 r
.65411 .59006 m .65384 .59148 L .65261 .59048 L F
.65479 .59057 m .65384 .59148 L .65411 .59006 L F
.683 .847 .961 r
.65373 .58891 m .65476 .58925 L .6536 .5888 L F
.6548 .58926 m .65579 .5896 L .65482 .58924 L F
.6548 .58926 m .6548 .58926 L .65475 .58922 L F
.951 .602 .233 r
.65483 .58915 m .65479 .58925 L .65474 .5892 L F
.65479 .58925 m .65476 .58922 L .65474 .5892 L F
.683 .847 .961 r
.6548 .58926 m .65482 .58924 L .65476 .58922 L F
.6548 .58926 m .65476 .58922 L .65475 .58922 L F
.648 .845 .976 r
.65838 .58838 m .65579 .5896 L .65481 .58927 L F
.683 .847 .961 r
.65476 .58925 m .6548 .58926 L .65475 .58922 L F
.65476 .58925 m .65475 .58922 L .6536 .5888 L F
.648 .845 .976 r
.65838 .58838 m .65475 .58879 L .65773 .58712 L F
.65475 .58879 m .6547 .58872 L .65773 .58712 L F
0 .239 .748 r
.65401 .58759 m .65484 .58915 L .65493 .58912 L F
.648 .845 .976 r
.65838 .58838 m .65498 .58923 L .65493 .58912 L F
.65529 .58873 m .65493 .58912 L .65475 .58879 L F
.65838 .58838 m .65493 .58912 L .65529 .58873 L F
.864 .687 .661 r
.65579 .5896 m .65515 .58978 L .6548 .58927 L F
.988 .802 .412 r
.65474 .5892 m .65484 .58915 L .65392 .58747 L F
.675 .835 .96 r
.65443 .58859 m .65373 .58891 L .6538 .5872 L F
.988 .802 .412 r
.65424 .58816 m .65392 .58747 L .65379 .58724 L F
.65474 .5892 m .65392 .58747 L .65424 .58816 L F
0 .239 .748 r
.65401 .58759 m .65493 .58912 L .65481 .58891 L F
.65458 .58853 m .65481 .58891 L .65475 .58879 L F
.65401 .58759 m .65481 .58891 L .65458 .58853 L F
.675 .835 .96 r
.65773 .58712 m .65458 .58853 L .6538 .5872 L F
.988 .802 .412 r
.65379 .58724 m .65484 .58915 L .6538 .5872 L F
.675 .835 .96 r
.65458 .58853 m .65443 .58859 L .6538 .5872 L F
.648 .845 .976 r
.65475 .58879 m .65481 .58924 L .65433 .58884 L F
.951 .602 .233 r
.65479 .58925 m .65479 .58925 L .65476 .58922 L F
.65479 .58925 m .65476 .58923 L .65476 .58922 L F
.648 .845 .976 r
.65481 .58924 m .65481 .58927 L .65476 .58923 L F
.864 .687 .661 r
.65482 .58924 m .65481 .58925 L .65476 .58922 L F
.65481 .58925 m .65476 .58923 L .65476 .58922 L F
.648 .845 .976 r
.65481 .58924 m .65476 .58923 L .65433 .58884 L F
.65475 .58922 m .65481 .58927 L .65476 .58925 L F
.864 .687 .661 r
.65476 .58923 m .65476 .58923 L .65476 .58922 L F
.648 .845 .976 r
.65474 .5892 m .65476 .58923 L .65475 .58922 L F
.65476 .58923 m .65481 .58927 L .65475 .58922 L F
.864 .687 .661 r
.65515 .58978 m .65479 .59057 L .65411 .59006 L F
0 0 0 r
.65482 .58924 m .65399 .59167 L .65492 .58913 L F
.6548 .58926 m .6548 .58927 L .65482 .58924 L F
.6548 .58927 m .65399 .59167 L .65482 .58924 L F
.864 .687 .661 r
.65479 .58928 m .65261 .59048 L .65476 .58923 L F
.65515 .58978 m .65432 .59001 L .65479 .58928 L F
.65432 .59001 m .65261 .59048 L .65479 .58928 L F
.65515 .58978 m .65476 .58923 L .65476 .58923 L F
.951 .602 .233 r
.65479 .58925 m .65479 .58927 L .65476 .58923 L F
.864 .687 .661 r
.65481 .58925 m .6548 .58927 L .65476 .58923 L F
.65579 .5896 m .6548 .58927 L .65482 .58924 L F
0 .335 .777 r
.65577 .59118 m .65441 .59068 L .65384 .59148 L F
0 0 0 r
.65493 .58912 m .65399 .59167 L .65597 .58884 L F
.65492 .58913 m .65492 .58914 L .65493 .58912 L F
.65492 .58914 m .65399 .59167 L .65493 .58912 L F
0 .239 .748 r
.65475 .58879 m .65493 .58912 L .65495 .58912 L F
0 0 0 r
.65484 .58915 m .6548 .58926 L .65492 .58913 L F
.951 .602 .233 r
.65484 .58915 m .65483 .58916 L .65483 .58915 L F
.648 .845 .976 r
.65498 .58923 m .65481 .58927 L .65475 .58879 L F
.988 .802 .412 r
.65452 .5888 m .65474 .5892 L .65436 .58841 L F
.648 .845 .976 r
.65453 .58882 m .65443 .58859 L .65773 .58712 L F
0 .239 .748 r
.6538 .5872 m .65401 .58759 L .65597 .58884 L F
.65401 .58759 m .65495 .58912 L .65597 .58884 L F
.648 .845 .976 r
.65475 .58879 m .65453 .58882 L .6547 .58872 L F
.65453 .58882 m .65373 .58891 L .65443 .58859 L F
.988 .802 .412 r
.65378 .5874 m .65452 .5888 L .65379 .58724 L F
.65452 .5888 m .65436 .58841 L .65379 .58724 L F
.648 .845 .976 r
.65433 .58884 m .65474 .5892 L .65373 .58891 L F
.6545 .58913 m .65476 .58925 L .65373 .58891 L F
.65474 .5892 m .65475 .58922 L .6545 .58913 L F
.65475 .58922 m .65476 .58925 L .6545 .58913 L F
.864 .687 .661 r
.65476 .58922 m .65476 .58923 L .6536 .5888 L F
.65476 .58923 m .65261 .59048 L .65359 .5888 L F
.65476 .58923 m .65359 .5888 L .6536 .5888 L F
.988 .802 .412 r
.6536 .58979 m .65474 .5892 L .65378 .5874 L F
.65474 .5892 m .65474 .5892 L .65378 .5874 L F
.951 .602 .233 r
.65474 .5892 m .65399 .59167 L .6536 .58979 L F
.65479 .58927 m .65399 .59167 L .65474 .5892 L F
.65483 .58916 m .65399 .59167 L .65483 .58915 L F
.864 .687 .661 r
.65579 .5896 m .6553 .59007 L .65515 .58978 L F
.6553 .59007 m .65479 .59057 L .65515 .58978 L F
.768 .449 .446 r
.57608 .80214 m .57426 .80359 L .57317 .80109 L F
.548 .881 .62 r
.57564 .80234 m .57608 .80214 L .57728 .80082 L F
.57564 .80234 m .57426 .80359 L .57608 .80214 L F
.188 0 0 r
.6918 .63704 m .69299 .63718 L .69196 .63503 L F
.6918 .63704 m .69491 .63758 L .69299 .63718 L F
.597 .424 .618 r
.34263 .75578 m .34266 .75818 L .34482 .75549 L F
.538 .309 .516 r
.41486 .74232 m .41224 .74512 L .41297 .74287 L F
.41486 .74232 m .41458 .74395 L .41237 .74506 L F
.41232 .74503 m .41237 .74506 L .41224 .74512 L F
.41486 .74232 m .41237 .74506 L .41232 .74503 L F
.491 .477 .769 r
.40806 .74428 m .41005 .74529 L .41244 .7451 L F
.41242 .74509 m .41244 .7451 L .41247 .7451 L F
.40806 .74428 m .41244 .7451 L .41242 .74509 L F
.728 .752 .871 r
.40806 .74428 m .41242 .74509 L .40988 .74211 L F
.41242 .74509 m .41247 .7451 L .41245 .74508 L F
.41242 .74509 m .41245 .74508 L .40988 .74211 L F
.538 .309 .516 r
.41458 .74395 m .41438 .74517 L .41236 .74513 L F
.374 .606 .939 r
.40988 .74211 m .41245 .74508 L .41273 .74315 L F
.41245 .74508 m .41247 .7451 L .41247 .74508 L F
.41245 .74508 m .41247 .74508 L .41273 .74315 L F
.538 .309 .516 r
.41236 .74506 m .41236 .74513 L .41224 .74512 L F
.41458 .74395 m .41245 .74508 L .41236 .74506 L F
.41245 .74508 m .41236 .74513 L .41236 .74506 L F
0 0 .258 r
.41559 .74366 m .41486 .74232 L .41695 .74211 L F
.199 0 0 r
.41752 .74315 m .41559 .74366 L .41695 .74211 L F
.559 .763 .973 r
.41625 .74293 m .41559 .74366 L .41752 .74315 L F
0 0 .258 r
.41559 .74366 m .41441 .74498 L .41486 .74232 L F
.559 .763 .973 r
.41437 .7426 m .41559 .74366 L .41625 .74293 L F
0 0 .258 r
.41559 .74366 m .41438 .74517 L .41441 .74498 L F
.984 .769 .535 r
.70861 .69962 m .70742 .69903 L .70774 .69598 L F
.925 .563 .135 r
.7089 .70177 m .70742 .69903 L .70861 .69962 L F
.502 .805 .999 r
.64933 .58577 m .64823 .58699 L .64716 .58646 L F
.64933 .58577 m .65045 .5866 L .64823 .58699 L F
.02 .417 .861 r
.65025 .58874 m .64823 .58699 L .65045 .5866 L F
0 .005 .536 r
.7146 .7209 m .71229 .71825 L .7138 .71811 L F
.498 .329 .581 r
.37177 .67744 m .36974 .6802 L .37022 .67826 L F
0 0 .488 r
.47902 .88122 m .47776 .87758 L .47751 .87916 L F
.57 .401 .612 r
.33427 .76906 m .33634 .77103 L .33653 .76888 L F
.33427 .76906 m .33433 .77139 L .33634 .77103 L F
.726 .606 .722 r
.70597 .63297 m .70565 .63536 L .70364 .63555 L F
.603 .396 .574 r
.70565 .63536 m .70364 .63791 L .70364 .63555 L F
.70565 .63536 m .70599 .63796 L .70364 .63791 L F
.507 .305 .54 r
.36328 .68987 m .36117 .68881 L .36346 .68844 L F
.36328 .68987 m .36112 .69062 L .36117 .68881 L F
.622 .466 .649 r
.33213 .77416 m .33433 .77139 L .33209 .77173 L F
.79 .65 .708 r
.70229 .60572 m .70475 .60873 L .70537 .60604 L F
.70229 .60572 m .70198 .6085 L .70475 .60873 L F
.788 .589 .632 r
.70176 .61002 m .70475 .60873 L .70198 .6085 L F
.70176 .61002 m .70353 .61131 L .70475 .60873 L F
.785 .533 .556 r
.71415 .7345 m .71378 .73658 L .71054 .73596 L F
.408 .234 .531 r
.71591 .73159 m .71583 .73456 L .71415 .7345 L F
.751 .714 .817 r
.71583 .73456 m .71378 .73658 L .71415 .7345 L F
.537 .531 .796 r
.47029 .73405 m .46949 .73739 L .46842 .73392 L F
.47029 .73405 m .47165 .73743 L .46949 .73739 L F
.519 .782 .992 r
.34598 .82653 m .34723 .82758 L .34869 .82715 L F
.34598 .82653 m .34723 .82758 L .34869 .82715 L F
0 0 0 r
.63349 .62192 m .63243 .62349 L .63129 .62464 L F
.589 .463 .676 r
.63349 .62192 m .63546 .61916 L .63553 .62061 L F
0 0 0 r
.63553 .62061 m .63243 .62349 L .63349 .62192 L F
.675 .618 .783 r
.71448 .71297 m .71255 .71398 L .71143 .71207 L F
.385 0 .106 r
.56029 .80919 m .55696 .81124 L .55716 .80923 L F
.56029 .80919 m .55915 .81094 L .55696 .81124 L F
.666 .644 .818 r
.56283 .80738 m .56409 .80973 L .56029 .80919 L F
.706 .309 .293 r
.56029 .80919 m .56268 .81153 L .55915 .81094 L F
.335 .5 .873 r
.4994 .87652 m .50193 .87824 L .50063 .87543 L F
.621 .385 .538 r
.57509 .79721 m .57507 .79594 L .57296 .7953 L F
.57509 .79721 m .57659 .79797 L .57507 .79594 L F
.509 .545 .828 r
.36165 .66889 m .35997 .67041 L .35891 .66758 L F
.454 .451 .766 r
.36165 .66889 m .36242 .67202 L .35997 .67041 L F
.54 .304 .507 r
.45242 .76384 m .45461 .76353 L .45464 .76103 L F
.612 .362 .515 r
.45464 .76103 m .45753 .76236 L .45771 .76077 L F
.45464 .76103 m .45461 .76353 L .45753 .76236 L F
0 .467 .787 r
.72272 .71275 m .72356 .71315 L .72055 .71212 L F
0 0 .391 r
.4775 .87284 m .47809 .87403 L .47865 .87284 L F
.4775 .87284 m .47791 .87593 L .47809 .87403 L F
.875 .439 .14 r
.67311 .61562 m .6721 .61302 L .67026 .61247 L F
.719 .507 .602 r
.38351 .78359 m .38619 .78149 L .3843 .78183 L F
.942 .71 .559 r
.63654 .59539 m .63643 .59766 L .6351 .59454 L F
.373 .84 .843 r
.31932 .65149 m .31725 .65219 L .31559 .6524 L F
.766 .687 .776 r
.70229 .60572 m .70537 .60604 L .70429 .60423 L F
.603 .637 .857 r
.70537 .60604 m .70654 .60303 L .70429 .60423 L F
.70537 .60604 m .70756 .60569 L .70654 .60303 L F
.579 .05 0 r
.53547 .83603 m .53539 .8377 L .53214 .83564 L F
.48 0 0 r
.53644 .83738 m .53547 .83603 L .53761 .83797 L F
.53644 .83738 m .53539 .8377 L .53547 .83603 L F
.678 .533 .681 r
.53884 .83552 m .53824 .83664 L .53547 .83603 L F
.677 .316 .353 r
.53824 .83664 m .53761 .83797 L .53547 .83603 L F
.798 .419 .338 r
.69533 .69843 m .69655 .69958 L .69811 .69949 L F
.807 .44 .361 r
.69655 .69958 m .69697 .70112 L .69811 .69949 L F
.695 .295 .286 r
.69697 .70112 m .70027 .70156 L .69811 .69949 L F
.728 .223 .028 r
.69811 .69949 m .70027 .70156 L .70176 .70162 L F
.549 .583 .841 r
.70089 .60077 m .69851 .60109 L .69845 .60037 L F
.855 .991 .84 r
.63577 .60418 m .63646 .60224 L .63728 .60235 L F
.843 .986 .863 r
.63753 .59208 m .63978 .58987 L .64062 .59014 L F
.634 .944 .722 r
.64171 .58882 m .64286 .5882 L .64062 .59014 L F
.641 .951 .944 r
.63978 .58987 m .64171 .58882 L .64062 .59014 L F
.67 .887 .978 r
.49026 .88808 m .49135 .88879 L .49303 .88746 L F
.842 .793 .804 r
.68529 .72077 m .6832 .72314 L .68577 .72321 L F
.898 .887 .813 r
.68245 .72559 m .68577 .72321 L .6832 .72314 L F
.565 .646 .889 r
.36588 .67371 m .36363 .67411 L .36242 .67202 L F
0 0 0 r
.72195 .72797 m .72237 .72616 L .72213 .72616 L F
.115 0 0 r
.72276 .72824 m .72039 .72901 L .72195 .72797 L F
0 0 .517 r
.72195 .72797 m .72276 .72824 L .72213 .72616 L F
.115 0 0 r
.72195 .72797 m .72039 .72901 L .72276 .72824 L F
0 0 .517 r
.72213 .72616 m .72276 .72824 L .72195 .72797 L F
.927 .869 .762 r
.70491 .73163 m .70568 .7279 L .707 .72893 L F
.70491 .73163 m .70363 .73155 L .70568 .7279 L F
.585 .014 0 r
.70716 .73372 m .70363 .73155 L .70491 .73163 L F
.742 .239 .029 r
.70833 .73379 m .70716 .73372 L .70491 .73163 L F
.512 .889 .968 r
.48626 .86844 m .48899 .86756 L .48869 .87 L F
.627 .209 .23 r
.48626 .86844 m .48727 .86883 L .48899 .86756 L F
.48626 .86844 m .48869 .87 L .4855 .87071 L F
.48626 .86844 m .4855 .87071 L .48727 .86883 L F
.114 0 0 r
.48626 .86844 m .48727 .86883 L .48899 .86756 L F
.73 .38 .387 r
.67886 .60744 m .68011 .60581 L .67692 .60567 L F
.823 .656 .675 r
.67886 .60744 m .68148 .60441 L .68011 .60581 L F
.559 .515 .763 r
.48967 .75765 m .48774 .75836 L .48715 .75588 L F
.302 0 .253 r
.55249 .79829 m .5535 .79994 L .55483 .79872 L F
.55249 .79829 m .55166 .80067 L .5535 .79994 L F
.407 .838 .952 r
.73555 .71823 m .73479 .71789 L .73198 .71845 L F
.992 .747 .387 r
.73477 .71525 m .73479 .71789 L .73555 .71823 L F
.619 .482 .673 r
.34044 .75854 m .34065 .76091 L .34266 .75818 L F
.532 .559 .828 r
.34737 .8545 m .34804 .85449 L .34742 .85462 L F
.274 0 .041 r
.34742 .85462 m .34804 .85449 L .34736 .8547 L F
.893 .738 .682 r
.70598 .72595 m .707 .72893 L .70568 .7279 L F
.711 .652 .789 r
.70961 .72713 m .707 .72893 L .70598 .72595 L F
.676 .395 .487 r
.56773 .79314 m .56987 .795 L .57116 .79277 L F
.253 0 0 r
.42489 .78395 m .42633 .78243 L .42838 .78195 L F
.256 0 0 r
.71631 .60855 m .71658 .60868 L .7144 .60812 L F
.567 .372 .576 r
.65441 .63231 m .65453 .62907 L .65202 .63009 L F
.692 .68 .834 r
.69533 .69843 m .69249 .6998 L .69119 .69732 L F
.559 .667 .91 r
.33347 .65392 m .33149 .65426 L .33029 .65266 L F
.528 .274 .473 r
.35582 .73975 m .35746 .74162 L .35758 .73915 L F
.35582 .73975 m .35533 .742 L .35746 .74162 L F
.66 .735 .905 r
.66375 .62862 m .66241 .62978 L .66108 .62821 L F
0 0 0 r
.66424 .6287 m .66271 .62936 L .66241 .62978 L F
.66 .735 .905 r
.66424 .6287 m .66241 .62978 L .66375 .62862 L F
0 0 0 r
.66271 .62936 m .66122 .63081 L .66241 .62978 L F
.66122 .63081 m .66001 .63199 L .66241 .62978 L F
.66424 .6287 m .66587 .62746 L .66271 .62936 L F
.226 0 0 r
.39259 .78183 m .39494 .78235 L .39569 .78245 L F
.32 .801 .897 r
.39569 .78245 m .3967 .782 L .39755 .78187 L F
.39569 .78245 m .39494 .78235 L .3967 .782 L F
.656 .477 .631 r
.35106 .74263 m .3534 .74467 L .35322 .74243 L F
.35106 .74263 m .35109 .74496 L .3534 .74467 L F
.699 .542 .671 r
.46183 .75814 m .46541 .7583 L .4652 .75592 L F
.633 .55 .743 r
.46424 .75285 m .4652 .75592 L .46739 .7555 L F
.542 .425 .669 r
.4652 .75592 m .4675 .75762 L .46739 .7555 L F
.4652 .75592 m .46541 .7583 L .4675 .75762 L F
.168 .702 .839 r
.3406 .67507 m .33826 .67549 L .34165 .67546 L F
.539 .805 .995 r
.34165 .67546 m .34403 .67515 L .3423 .67441 L F
.952 .667 .462 r
.3423 .67441 m .34073 .675 L .34165 .67546 L F
.34073 .675 m .34057 .67506 L .34065 .67509 L F
.34073 .675 m .34065 .67509 L .34165 .67546 L F
.3423 .67441 m .34268 .67695 L .34097 .67541 L F
.34073 .675 m .34097 .67541 L .34057 .67506 L F
.3423 .67441 m .34097 .67541 L .34073 .675 L F
.509 .796 .997 r
.34403 .67515 m .34571 .67465 L .3423 .67441 L F
.416 .396 .729 r
.34403 .67515 m .34464 .67816 L .34588 .67686 L F
.34403 .67515 m .34588 .67686 L .34571 .67465 L F
.78 .55 .587 r
.34588 .67686 m .3423 .67441 L .34571 .67465 L F
.34588 .67686 m .34268 .67695 L .3423 .67441 L F
.444 .521 .842 r
.3414 .67552 m .343 .67531 L .34205 .6734 L F
.34144 .67413 m .34205 .6734 L .3415 .67231 L F
.3414 .67552 m .34205 .6734 L .34144 .67413 L F
.245 .583 .945 r
.34057 .67506 m .34268 .67695 L .3414 .67552 L F
.34057 .67506 m .3414 .67552 L .34105 .67556 L F
.34057 .67506 m .34105 .67556 L .33985 .6757 L F
.945 .704 .543 r
.34132 .67585 m .34216 .67942 L .34067 .67533 L F
.34268 .67695 m .34262 .67723 L .34132 .67585 L F
.34262 .67723 m .34216 .67942 L .34132 .67585 L F
.34133 .67574 m .34067 .67533 L .34057 .67506 L F
.34268 .67695 m .34067 .67533 L .34133 .67574 L F
.367 .716 .987 r
.34028 .6751 m .33985 .6757 L .34105 .67556 L F
.945 .704 .543 r
.34268 .67695 m .34216 .67942 L .34069 .67539 L F
.34228 .67659 m .34069 .67539 L .34057 .67506 L F
.34268 .67695 m .34069 .67539 L .34228 .67659 L F
.367 .716 .987 r
.33954 .67436 m .3414 .67552 L .33984 .67431 L F
.168 .702 .839 r
.34057 .67506 m .34047 .67508 L .3406 .67507 L F
.367 .716 .987 r
.34032 .67511 m .3414 .67552 L .33823 .67354 L F
.444 .521 .842 r
.3414 .67552 m .3415 .67231 L .33875 .67346 L F
.086 .298 .779 r
.3415 .67231 m .34227 .67386 L .34343 .67395 L F
.34227 .67386 m .343 .67531 L .34343 .67395 L F
.601 .771 .961 r
.34343 .67395 m .34686 .67458 L .34554 .67341 L F
.271 0 0 r
.34554 .67341 m .34426 .67402 L .34343 .67395 L F
.348 .601 .942 r
.343 .67531 m .34482 .67541 L .34343 .67395 L F
0 0 0 r
.34767 .67424 m .34588 .67686 L .34571 .67465 L F
.587 .519 .745 r
.34588 .67686 m .34767 .67424 L .34571 .67465 L F
.679 .737 .895 r
.34343 .67395 m .34482 .67541 L .34686 .67458 L F
.271 0 0 r
.34426 .67402 m .3418 .67518 L .34343 .67395 L F
.262 0 0 r
.34343 .67395 m .33969 .67541 L .3425 .67388 L F
.34264 .67386 m .3425 .67388 L .34256 .67385 L F
.34343 .67395 m .3425 .67388 L .34264 .67386 L F
.367 .716 .987 r
.33823 .67354 m .33954 .67436 L .33875 .67346 L F
.33954 .67436 m .33984 .67431 L .33875 .67346 L F
.33674 .67376 m .34032 .67511 L .33823 .67354 L F
.34032 .67511 m .34105 .67556 L .3414 .67552 L F
.34028 .6751 m .34105 .67556 L .34032 .67511 L F
.33674 .67376 m .33919 .67529 L .34028 .6751 L F
.138 .682 .723 r
.33919 .67529 m .33826 .67549 L .34047 .67508 L F
.168 .702 .839 r
.34047 .67508 m .33826 .67549 L .3406 .67507 L F
.367 .716 .987 r
.33919 .67529 m .33985 .6757 L .33936 .67526 L F
.138 .682 .723 r
.33678 .6757 m .33731 .67562 L .33919 .67529 L F
.33731 .67562 m .33826 .67549 L .33919 .67529 L F
.33678 .6757 m .34047 .67508 L .34057 .67506 L F
.524 .784 .992 r
.33678 .6757 m .33985 .6757 L .33919 .67529 L F
.138 .682 .723 r
.33678 .6757 m .33936 .67526 L .33985 .6757 L F
.33936 .67526 m .34057 .67506 L .33985 .6757 L F
.367 .716 .987 r
.33936 .67526 m .33985 .6757 L .34028 .6751 L F
.524 .784 .992 r
.33678 .6757 m .33919 .67529 L .33897 .67515 L F
.33677 .67526 m .33897 .67515 L .33674 .67376 L F
.33678 .6757 m .33897 .67515 L .33677 .67526 L F
.464 .1 .263 r
.41845 .77671 m .42059 .77648 L .42174 .77424 L F
.391 .028 .224 r
.42174 .77424 m .42265 .77605 L .42394 .77413 L F
.42174 .77424 m .42059 .77648 L .42265 .77605 L F
.576 .448 .669 r
.34911 .74768 m .35121 .74735 L .35109 .74496 L F
.545 .337 .548 r
.34892 .74994 m .35121 .74735 L .34911 .74768 L F
.681 .326 .365 r
.36681 .73557 m .37069 .73382 L .36841 .73398 L F
.584 .843 .994 r
.4508 .72877 m .44741 .72862 L .44957 .72733 L F
.532 .652 .912 r
.452 .72708 m .4508 .72877 L .44957 .72733 L F
.452 .72708 m .45287 .7286 L .4508 .72877 L F
.723 .432 .485 r
.49891 .88053 m .49956 .87895 L .49836 .8784 L F
.49891 .88053 m .49981 .88098 L .49956 .87895 L F
.673 .608 .775 r
.57081 .80074 m .57103 .79793 L .56935 .80066 L F
.57081 .80074 m .57317 .80109 L .57103 .79793 L F
.341 0 0 r
.34737 .8545 m .34804 .85449 L .34728 .85456 L F
.665 .607 .78 r
.4849 .74736 m .48337 .75013 L .48258 .74804 L F
.4849 .74736 m .48604 .75037 L .48337 .75013 L F
.037 0 0 r
.38988 .75578 m .38726 .75706 L .38965 .75613 L F
.865 .456 0 r
.38988 .75578 m .38943 .75571 L .38815 .75319 L F
.783 .568 .61 r
.38815 .75319 m .38943 .75571 L .38509 .75465 L F
.38943 .75571 m .38907 .75594 L .38509 .75465 L F
.682 .974 .797 r
.38945 .75571 m .38726 .75706 L .38988 .75578 L F
.716 .531 .639 r
.38726 .75706 m .38509 .75465 L .38907 .75594 L F
.682 .974 .797 r
.38916 .75566 m .38726 .75706 L .38945 .75571 L F
.716 .531 .639 r
.38726 .75706 m .38907 .75594 L .38965 .75613 L F
.783 .568 .61 r
.38943 .75571 m .38965 .75613 L .38907 .75594 L F
.682 .974 .797 r
.39054 .75465 m .38916 .75566 L .38943 .75571 L F
.39023 .75518 m .38943 .75571 L .38988 .75578 L F
.39054 .75465 m .38943 .75571 L .39023 .75518 L F
.865 .456 0 r
.38988 .75578 m .38965 .75613 L .38943 .75571 L F
.49 .724 .975 r
.68232 .5897 m .67928 .58841 L .68175 .58863 L F
.332 .65 .969 r
.68325 .58876 m .68232 .5897 L .68175 .58863 L F
.345 .67 .975 r
.68415 .58977 m .68232 .5897 L .68325 .58876 L F
.397 .589 .92 r
.7144 .60812 m .71551 .60698 L .71344 .60698 L F
.7144 .60812 m .71658 .60868 L .71551 .60698 L F
.597 .839 .99 r
.50991 .88443 m .51199 .88381 L .50868 .88364 L F
.351 .399 .772 r
.45988 .7449 m .46038 .74164 L .45857 .74174 L F
.45988 .7449 m .46141 .74486 L .46038 .74164 L F
.591 .568 .796 r
.46067 .74844 m .46141 .74486 L .45988 .7449 L F
.495 .352 .616 r
.47809 .87403 m .47839 .87247 L .47865 .87284 L F
.67 .242 .223 r
.69386 .64354 m .6929 .64511 L .69043 .64334 L F
.667 .239 .222 r
.69386 .64354 m .69619 .64525 L .6929 .64511 L F
.616 .302 .415 r
.69592 .64363 m .69619 .64525 L .69386 .64354 L F
.398 0 .146 r
.39799 .79311 m .39669 .79506 L .39457 .79535 L F
.247 0 .058 r
.39861 .79443 m .39799 .79311 L .40003 .79272 L F
.39861 .79443 m .39669 .79506 L .39799 .79311 L F
0 .428 .848 r
.48279 .88626 m .48338 .886 L .48126 .88615 L F
.48279 .88626 m .48449 .88701 L .48338 .886 L F
0 0 0 r
.67593 .62896 m .6797 .62752 L .6792 .62669 L F
.923 .679 .189 r
.6797 .62752 m .67942 .62899 L .6792 .62669 L F
.6797 .62752 m .67985 .62967 L .67942 .62899 L F
.808 .746 .795 r
.70597 .63297 m .70225 .63468 L .70414 .63122 L F
.70597 .63297 m .70364 .63555 L .70225 .63468 L F
.227 .174 .586 r
.513 .87012 m .51214 .87064 L .51181 .86797 L F
.513 .87012 m .51214 .87064 L .51181 .86797 L F
.121 0 .014 r
.71886 .63009 m .71623 .63265 L .71585 .63226 L F
.71886 .63009 m .71822 .63165 L .71623 .63265 L F
0 0 0 r
.72109 .62738 m .72044 .62904 L .71886 .63009 L F
.72044 .62904 m .71822 .63165 L .71886 .63009 L F
.93 .644 .169 r
.67867 .71263 m .67812 .71212 L .67775 .70965 L F
.829 .459 .354 r
.67867 .71263 m .67754 .71468 L .67812 .71212 L F
.67867 .71263 m .6798 .71445 L .67754 .71468 L F
.755 .663 .76 r
.69582 .61687 m .6965 .61839 L .698 .61583 L F
.825 .742 .773 r
.61427 .6464 m .61241 .64953 L .61061 .64812 L F
.89 .705 .645 r
.61241 .64953 m .61195 .65127 L .61061 .64812 L F
.101 .374 .836 r
.68984 .62095 m .6895 .62224 L .68784 .61989 L F
0 0 .444 r
.69031 .62285 m .6895 .62224 L .68984 .62095 L F
0 0 0 r
.43749 .74072 m .4362 .74148 L .43894 .74022 L F
.354 0 0 r
.44085 .74099 m .43749 .74072 L .43894 .74022 L F
.209 .734 .766 r
.6532 .60356 m .65429 .60347 L .65184 .60397 L F
.6532 .60356 m .65184 .60397 L .65395 .60507 L F
0 0 .267 r
.6825 .61212 m .68078 .61493 L .68166 .61157 L F
.76 .591 .668 r
.70364 .63555 m .70026 .63735 L .70225 .63468 L F
.70364 .63555 m .70364 .63791 L .70026 .63735 L F
.397 .22 .52 r
.34399 .68619 m .34567 .68565 L .34582 .68336 L F
.438 .322 .625 r
.34399 .68619 m .34587 .68806 L .34567 .68565 L F
.516 .328 .564 r
.34387 .68847 m .34587 .68806 L .34399 .68619 L F
.531 .75 .976 r
.68994 .60448 m .69124 .60569 L .69338 .60535 L F
.62 .583 .791 r
.69124 .60569 m .69444 .6082 L .69338 .60535 L F
.082 .249 .737 r
.5332 .82772 m .53527 .82964 L .53645 .82786 L F
.862 .519 .402 r
.53645 .82786 m .53527 .82964 L .53717 .82996 L F
.689 .534 .671 r
.52407 .77119 m .52148 .77171 L .5236 .76905 L F
.05 0 .12 r
.52148 .77171 m .52253 .77155 L .5236 .76905 L F
.482 .347 .62 r
.52574 .76869 m .52407 .77119 L .5236 .76905 L F
.52574 .76869 m .52589 .77094 L .52407 .77119 L F
.679 .364 .433 r
.5236 .76905 m .52589 .77094 L .52574 .76869 L F
.675 .513 .658 r
.52457 .77359 m .52148 .77171 L .52407 .77119 L F
.632 .476 .653 r
.52534 .77189 m .52457 .77359 L .52407 .77119 L F
.679 .364 .433 r
.5236 .76905 m .52253 .77155 L .52589 .77094 L F
.679 .432 .541 r
.49438 .88096 m .49891 .88053 L .49836 .8784 L F
.623 .695 .896 r
.68233 .72643 m .6818 .72704 L .67854 .7264 L F
.665 .819 .957 r
.67976 .72515 m .68233 .72643 L .68245 .72559 L F
.721 .868 .951 r
.68245 .72559 m .6818 .72704 L .68233 .72643 L F
.024 .537 .867 r
.68238 .72691 m .6818 .72704 L .68245 .72559 L F
.68238 .72691 m .68363 .72758 L .6818 .72704 L F
.504 .781 .995 r
.67976 .72515 m .68233 .72643 L .67854 .7264 L F
.224 .329 .761 r
.67854 .7264 m .6809 .72843 L .67976 .72515 L F
.572 .595 .838 r
.47466 .73937 m .47263 .73985 L .47165 .73743 L F
.396 .851 .799 r
.37492 .80273 m .37589 .8021 L .37372 .80267 L F
.37492 .80273 m .3777 .80166 L .37589 .8021 L F
.347 .82 .772 r
.44722 .73912 m .44581 .73966 L .4462 .73974 L F
0 .53 .724 r
.44636 .73977 m .4462 .73974 L .44425 .73954 L F
0 0 0 r
.44474 .74007 m .44425 .73954 L .4462 .73974 L F
.347 .82 .772 r
.44581 .73966 m .44474 .74007 L .4462 .73974 L F
0 .53 .724 r
.44752 .7399 m .4462 .73974 L .44636 .73977 L F
.106 .657 .805 r
.44967 .73977 m .4462 .73974 L .44752 .7399 L F
.714 .736 .868 r
.71104 .69643 m .70774 .69598 L .71017 .69524 L F
.529 .796 .994 r
.71252 .69505 m .71104 .69643 L .71017 .69524 L F
.71252 .69505 m .71338 .69602 L .71104 .69643 L F
.222 .039 .408 r
.33275 .69934 m .33399 .7008 L .33387 .69852 L F
.33275 .69934 m .33236 .7018 L .33399 .7008 L F
.774 .685 .766 r
.52191 .7759 m .51925 .77694 L .52139 .77406 L F
.516 .234 .425 r
.52191 .7759 m .51933 .77921 L .51925 .77694 L F
.52191 .7759 m .52157 .77892 L .51933 .77921 L F
.451 .249 .514 r
.52457 .77359 m .52191 .7759 L .52139 .77406 L F
.52457 .77359 m .52422 .77674 L .52191 .7759 L F
.414 .149 .401 r
.52351 .77837 m .52191 .7759 L .52422 .77674 L F
.52351 .77837 m .52157 .77892 L .52191 .7759 L F
.085 0 .173 r
.35744 .81133 m .35822 .8114 L .35641 .81133 L F
.35744 .81133 m .35887 .80978 L .35822 .8114 L F
.377 .391 .748 r
.71408 .6222 m .71606 .62357 L .71585 .62076 L F
.789 .666 .728 r
.61294 .64321 m .61427 .6464 L .61251 .64543 L F
.825 .742 .773 r
.61427 .6464 m .61061 .64812 L .61251 .64543 L F
.345 .286 .647 r
.68934 .62613 m .68792 .62664 L .687 .62469 L F
.62 .644 .852 r
.34728 .85456 m .34804 .85449 L .34736 .8547 L F
0 0 0 r
.72224 .62604 m .72044 .62904 L .72109 .62738 L F
.622 .369 .513 r
.37069 .73382 m .37301 .73392 L .37325 .73174 L F
.487 .208 .415 r
.37301 .73392 m .37548 .73167 L .37325 .73174 L F
.648 .175 .117 r
.6826 .61923 m .68491 .62076 L .68567 .61957 L F
0 0 0 r
.68491 .62076 m .68784 .61989 L .68567 .61957 L F
.939 .639 .444 r
.5711 .80302 m .57162 .80639 L .57328 .80664 L F
.924 .533 .2 r
.57162 .80639 m .57345 .80876 L .57328 .80664 L F
.754 .357 .301 r
.68813 .69611 m .69119 .69732 L .68877 .69896 L F
.758 .587 .665 r
.60594 .66146 m .60324 .66211 L .60383 .65967 L F
.699 .59 .73 r
.60658 .66459 m .60324 .66211 L .60594 .66146 L F
.683 .525 .666 r
.60866 .66199 m .60658 .66459 L .60594 .66146 L F
.247 .645 .962 r
.6774 .62332 m .67741 .62411 L .67928 .62433 L F
.756 .403 .386 r
.67561 .62614 m .67741 .62411 L .6774 .62332 L F
.67561 .62614 m .6792 .62669 L .67741 .62411 L F
.075 .367 .834 r
.48488 .84298 m .48436 .8439 L .48321 .84229 L F
.662 .623 .8 r
.48488 .84298 m .4841 .84602 L .48436 .8439 L F
.657 .609 .788 r
.69444 .6082 m .69674 .60579 L .69338 .60535 L F
.69444 .6082 m .6967 .60776 L .69674 .60579 L F
.571 .796 .984 r
.44408 .7265 m .44214 .72712 L .4407 .72607 L F
.262 .542 .923 r
.64912 .60568 m .651 .60503 L .64881 .60471 L F
.64912 .60568 m .651 .60503 L .64881 .60471 L F
.917 .941 .803 r
.64912 .60568 m .64881 .60471 L .6464 .60806 L F
.707 .453 .539 r
.48088 .76653 m .48076 .76877 L .47887 .7664 L F
.665 .417 .536 r
.48486 .76803 m .48088 .76653 L .4843 .76622 L F
.48486 .76803 m .48076 .76877 L .48088 .76653 L F
0 0 0 r
.65249 .59631 m .65223 .59643 L .65305 .5955 L F
.982 .872 .648 r
.65215 .59524 m .65249 .59631 L .65305 .5955 L F
.088 .331 .806 r
.65215 .59524 m .65338 .59591 L .65249 .59631 L F
.65338 .59591 m .65401 .59625 L .65249 .59631 L F
0 0 0 r
.65249 .59631 m .65066 .5982 L .65223 .59643 L F
.764 .995 .809 r
.65384 .59389 m .65305 .5955 L .65469 .59369 L F
.721 .966 .938 r
.65384 .59389 m .65215 .59524 L .65305 .5955 L F
.725 .356 .352 r
.55258 .81179 m .55148 .81346 L .5497 .81259 L F
.207 0 0 r
.55488 .81179 m .55148 .81346 L .55258 .81179 L F
.599 .779 .967 r
.32253 .65217 m .31932 .65149 L .32164 .65051 L F
.368 .772 .984 r
.3231 .65126 m .32253 .65217 L .32164 .65051 L F
.3231 .65126 m .32465 .65199 L .32253 .65217 L F
0 0 .46 r
.56426 .80867 m .56409 .80973 L .56467 .80861 L F
.299 .447 .842 r
.56467 .80861 m .56409 .80973 L .56283 .80738 L F
.615 .838 .985 r
.56793 .8088 m .56409 .80973 L .56467 .80861 L F
.63 .939 .96 r
.36719 .80481 m .37005 .80454 L .37185 .80357 L F
0 0 0 r
.67711 .63655 m .67484 .63961 L .67573 .63792 L F
.548 .677 .923 r
.51663 .87855 m .51394 .8777 L .51629 .87596 L F
.779 .546 .583 r
.513 .87814 m .51663 .87855 L .51629 .87596 L F
.067 .534 .897 r
.724 .73729 m .72185 .73717 L .72136 .7364 L F
.724 .73729 m .72521 .73813 L .72303 .73751 L F
.619 .798 .968 r
.72521 .73813 m .72261 .73913 L .72185 .73717 L F
0 0 0 r
.724 .73729 m .72324 .73798 L .72498 .73707 L F
.724 .73729 m .72523 .73694 L .72652 .73739 L F
.724 .73729 m .72498 .73707 L .72523 .73694 L F
.067 .534 .897 r
.724 .73729 m .72303 .73751 L .72185 .73717 L F
.844 .676 .674 r
.61465 .64028 m .61183 .64017 L .61234 .6378 L F
.843 .707 .714 r
.61465 .64028 m .61294 .64321 L .61183 .64017 L F
.45 .013 .116 r
.65066 .5982 m .64971 .59973 L .64731 .59983 L F
.403 .085 .309 r
.65249 .59631 m .64971 .59973 L .65066 .5982 L F
.537 .359 .588 r
.34065 .76091 m .33858 .76365 L .34057 .76323 L F
.619 .481 .672 r
.33849 .76594 m .34057 .76323 L .33858 .76365 L F
.676 .615 .779 r
.47771 .86569 m .48122 .86797 L .48008 .86541 L F
.664 .463 .603 r
.36504 .77362 m .36266 .77171 L .36512 .77152 L F
.36504 .77362 m .36255 .77405 L .36266 .77171 L F
.039 0 0 r
.38909 .79782 m .38732 .79852 L .38806 .7978 L F
.591 .568 .796 r
.46067 .74844 m .46261 .74805 L .46141 .74486 L F
.578 .551 .789 r
.46067 .74844 m .46328 .74983 L .46261 .74805 L F
.662 .686 .862 r
.45331 .74146 m .45643 .74226 L .45531 .74092 L F
.616 .732 .929 r
.45531 .74092 m .45643 .74226 L .45857 .74174 L F
.47 .249 .496 r
.34666 .75269 m .34892 .74994 L .34682 .75028 L F
.922 .825 .732 r
.70414 .63122 m .70108 .63369 L .70378 .63143 L F
.70414 .63122 m .70225 .63468 L .70108 .63369 L F
.591 .596 .826 r
.48013 .74192 m .4794 .74534 L .4782 .74213 L F
.48013 .74192 m .48152 .74493 L .4794 .74534 L F
.751 .507 .563 r
.47887 .7664 m .47878 .76843 L .47538 .76833 L F
.687 .452 .561 r
.47887 .7664 m .48076 .76877 L .47878 .76843 L F
.747 .647 .75 r
.70364 .63791 m .70193 .6408 L .70026 .63735 L F
.284 .09 .432 r
.70348 .6398 m .70193 .6408 L .70364 .63791 L F
.70348 .6398 m .70193 .6408 L .70364 .63791 L F
.283 .089 .431 r
.70348 .6398 m .70164 .64295 L .70193 .6408 L F
.658 .697 .875 r
.72465 .72298 m .72517 .72475 L .72833 .72375 L F
.431 0 .05 r
.39969 .78149 m .40188 .78143 L .4034 .77992 L F
.388 0 .067 r
.40188 .78143 m .40542 .77956 L .4034 .77992 L F
.673 .611 .777 r
.52988 .82489 m .53096 .82814 L .5332 .82772 L F
.279 0 0 r
.43391 .78013 m .43256 .78128 L .43047 .78149 L F
0 0 0 r
.43463 .78038 m .43391 .78013 L .43602 .77934 L F
.43463 .78038 m .43256 .78128 L .43391 .78013 L F
.935 .607 .389 r
.68129 .63274 m .68016 .63386 L .67983 .6319 L F
.68129 .63274 m .68178 .63423 L .68016 .63386 L F
.736 .803 .905 r
.37214 .78374 m .37365 .78473 L .37035 .78473 L F
.807 .855 .886 r
.37467 .78175 m .37365 .78473 L .37214 .78374 L F
.37467 .78175 m .37628 .78258 L .37365 .78473 L F
.776 .723 .804 r
.56569 .81208 m .56399 .81448 L .56687 .81454 L F
.566 .527 .77 r
.56687 .81454 m .56797 .8112 L .56569 .81208 L F
.56687 .81454 m .56906 .81426 L .56797 .8112 L F
.78 .708 .784 r
.56399 .81448 m .56374 .8159 L .56687 .81454 L F
.561 .388 .605 r
.48422 .85719 m .48427 .85963 L .48212 .85991 L F
.536 .759 .979 r
.48212 .85991 m .48345 .85849 L .48069 .85725 L F
.48212 .85991 m .48427 .85963 L .48345 .85849 L F
.477 .354 .634 r
.48421 .862 m .48212 .85991 L .48427 .85963 L F
.942 .795 .337 r
.68793 .63016 m .68934 .62613 L .68985 .62878 L F
.68793 .63016 m .68792 .62664 L .68934 .62613 L F
.398 .407 .753 r
.68985 .62878 m .69067 .63245 L .68793 .63016 L F
.989 .813 .576 r
.67393 .62091 m .6752 .61953 L .67429 .61863 L F
.67393 .62091 m .6752 .61953 L .67429 .61863 L F
.56 .899 .979 r
.36891 .67334 m .36588 .67371 L .3678 .67326 L F
.193 .722 .827 r
.36967 .67302 m .36891 .67334 L .3678 .67326 L F
.36967 .67302 m .37103 .67305 L .36891 .67334 L F
.561 .552 .801 r
.37165 .67507 m .36891 .67334 L .37103 .67305 L F
.663 .407 .523 r
.4843 .76622 m .48623 .76849 L .48486 .76803 L F
.714 .406 .455 r
.4862 .76666 m .48623 .76849 L .4843 .76622 L F
.707 .834 .393 r
.57317 .80109 m .57509 .79721 L .57103 .79793 L F
.57317 .80109 m .57353 .80002 L .57509 .79721 L F
.788 .389 0 r
.57317 .80109 m .57341 .80246 L .57353 .80002 L F
.57317 .80109 m .57426 .80359 L .57341 .80246 L F
.751 .714 .817 r
.71583 .73456 m .717 .73708 L .71378 .73658 L F
.253 0 0 r
.717 .73708 m .7166 .73723 L .71378 .73658 L F
.081 .499 .899 r
.71933 .73918 m .7166 .73723 L .717 .73708 L F
.666 .566 .732 r
.36506 .78467 m .3628 .7852 L .36173 .78209 L F
.761 .605 .684 r
.56374 .8159 m .56507 .81768 L .56649 .81679 L F
.864 .828 .811 r
.55894 .79088 m .55536 .79313 L .55561 .79251 L F
.55894 .79088 m .55561 .79251 L .55786 .79176 L F
.73 .344 .319 r
.55786 .79176 m .56101 .79263 L .55894 .79088 L F
.174 0 0 r
.41626 .72345 m .41806 .72336 L .41759 .72314 L F
.294 0 0 r
.4172 .72296 m .41759 .72314 L .41892 .72369 L F
.084 .625 .848 r
.41759 .72314 m .42096 .72362 L .41892 .72369 L F
.174 0 0 r
.41806 .72336 m .4196 .72328 L .41759 .72314 L F
.294 0 0 r
.41583 .72238 m .41759 .72314 L .4172 .72296 L F
.604 .385 .557 r
.45989 .76089 m .46138 .76122 L .46183 .75814 L F
.605 .386 .557 r
.46183 .75814 m .46467 .75884 L .46541 .7583 L F
.46183 .75814 m .46138 .76122 L .46467 .75884 L F
.463 .259 .517 r
.36974 .6802 m .36757 .68316 L .36777 .68075 L F
.566 .335 .524 r
.56427 .79312 m .56647 .79488 L .56773 .79314 L F
.725 .362 .362 r
.56773 .79314 m .56647 .79488 L .56987 .795 L F
0 0 0 r
.43749 .74072 m .43613 .74165 L .4362 .74148 L F
.886 .979 .825 r
.63381 .60628 m .63413 .60474 L .63577 .60418 L F
.855 .991 .84 r
.63577 .60418 m .63413 .60474 L .63646 .60224 L F
.828 .745 .772 r
.70405 .71536 m .70684 .71564 L .70555 .71295 L F
0 0 0 r
.70595 .71711 m .70486 .7185 L .70684 .71564 L F
.783 .393 .316 r
.70595 .71711 m .70684 .71564 L .70405 .71536 L F
.379 .514 .868 r
.70555 .71295 m .70684 .71564 L .70759 .71496 L F
.561 .847 .997 r
.70684 .71564 m .70936 .71505 L .70759 .71496 L F
.458 .599 .904 r
.35636 .66128 m .35549 .66285 L .35436 .66161 L F
.35636 .66128 m .35814 .66374 L .35549 .66285 L F
.641 .578 .768 r
.46328 .74983 m .46424 .75285 L .46674 .75215 L F
.633 .55 .743 r
.46424 .75285 m .46739 .7555 L .46674 .75215 L F
0 0 0 r
.66017 .64537 m .66316 .64341 L .66218 .64351 L F
.016 .586 .769 r
.66316 .64341 m .66399 .64333 L .66218 .64351 L F
.66316 .64341 m .66555 .64355 L .66399 .64333 L F
.322 .803 .896 r
.3224 .67458 m .32044 .67456 L .31842 .67496 L F
.19 .71 .874 r
.32413 .67468 m .32044 .67456 L .3224 .67458 L F
.681 .644 .807 r
.48006 .85121 m .48315 .85187 L .48183 .84893 L F
.505 .51 .795 r
.48006 .85121 m .48323 .85419 L .48315 .85187 L F
.612 .663 .875 r
.48387 .84862 m .48315 .85187 L .48183 .84893 L F
.48387 .84862 m .48553 .85161 L .48315 .85187 L F
.101 .293 .771 r
.48315 .85187 m .48398 .85098 L .48183 .84893 L F
.585 .399 .596 r
.48553 .85161 m .48323 .85419 L .48315 .85187 L F
.578 .595 .833 r
.48323 .85419 m .48398 .85098 L .48315 .85187 L F
.889 .99 .751 r
.67492 .61284 m .67358 .61598 L .67311 .61562 L F
.575 .241 .365 r
.65323 .61018 m .6562 .61135 L .65876 .60956 L F
.65323 .61018 m .65908 .60985 L .6562 .61135 L F
.482 .844 .992 r
.6562 .61135 m .65529 .61067 L .65323 .61018 L F
.6562 .61135 m .65273 .61124 L .65529 .61067 L F
.65529 .61067 m .65273 .61124 L .6562 .61135 L F
.579 .892 .988 r
.65908 .60985 m .65529 .61067 L .6562 .61135 L F
.487 .18 .371 r
.63274 .65909 m .6304 .66113 L .63052 .65911 L F
.646 .71 .894 r
.46512 .73127 m .4619 .73032 L .46398 .72978 L F
.588 .722 .936 r
.46722 .73082 m .46512 .73127 L .46398 .72978 L F
.658 .361 .457 r
.49038 .76833 m .4862 .76666 L .48966 .76614 L F
.49038 .76833 m .48623 .76849 L .4862 .76666 L F
.662 .386 .493 r
.48966 .76614 m .49171 .76837 L .49038 .76833 L F
.681 .385 .465 r
.49211 .76657 m .49171 .76837 L .48966 .76614 L F
.132 .018 .446 r
.71754 .73284 m .71591 .73159 L .71597 .73107 L F
.71754 .73284 m .71583 .73456 L .71591 .73159 L F
.303 .699 .977 r
.35299 .66077 m .35246 .66158 L .35143 .66039 L F
.35299 .66077 m .35436 .66161 L .35246 .66158 L F
.549 .411 .646 r
.41438 .74517 m .41261 .74739 L .41224 .74512 L F
.164 0 0 r
.72376 .71585 m .7256 .7152 L .72287 .71686 L F
.083 .364 .831 r
.48867 .87276 m .48777 .87325 L .48676 .87155 L F
0 0 .073 r
.48787 .87497 m .48777 .87325 L .48867 .87276 L F
.48787 .87497 m .48759 .87597 L .48777 .87325 L F
.854 .947 .589 r
.53896 .83495 m .53884 .83552 L .53911 .83293 L F
.53896 .83495 m .53824 .83664 L .53884 .83552 L F
.839 .673 .676 r
.60383 .65967 m .60324 .66211 L .60222 .65995 L F
.619 .798 .968 r
.72521 .73813 m .72601 .73941 L .72261 .73913 L F
.481 .041 .126 r
.72601 .73941 m .7227 .74115 L .72261 .73913 L F
.72601 .73941 m .72554 .74103 L .7227 .74115 L F
.979 .898 .554 r
.72631 .73778 m .72608 .73818 L .72652 .73739 L F
.146 .492 .904 r
.72608 .73818 m .72601 .73941 L .72568 .73888 L F
.979 .898 .554 r
.7252 .73986 m .72554 .74103 L .72608 .73818 L F
.7252 .73986 m .72608 .73818 L .72631 .73778 L F
.146 .492 .904 r
.72608 .73818 m .72568 .73888 L .72521 .73813 L F
.777 .744 .223 r
.72608 .73818 m .72554 .74103 L .72601 .73941 L F
.134 0 0 r
.40203 .7922 m .40563 .79045 L .40411 .79185 L F
.171 0 0 r
.40411 .79185 m .40563 .79045 L .40764 .78994 L F
.786 .69 .759 r
.67458 .59492 m .67291 .59816 L .67565 .59799 L F
.696 .655 .805 r
.67565 .59799 m .67685 .59435 L .67458 .59492 L F
.67565 .59799 m .67793 .59787 L .67685 .59435 L F
.558 .934 .85 r
.37589 .8021 m .3777 .80166 L .37929 .80068 L F
.399 0 .016 r
.42796 .77307 m .43159 .77149 L .42937 .77144 L F
.379 0 .018 r
.35965 .73868 m .36177 .7385 L .36331 .73697 L F
.297 0 0 r
.36177 .7385 m .36529 .7365 L .36331 .73697 L F
.886 .861 .81 r
.62666 .61659 m .62349 .61851 L .62532 .61557 L F
.62666 .61659 m .62474 .61937 L .62349 .61851 L F
.824 .821 .846 r
.62907 .61407 m .62666 .61659 L .62532 .61557 L F
.922 .885 .778 r
.63193 .60751 m .63301 .60841 L .63115 .61137 L F
.888 .98 .821 r
.63193 .60751 m .63381 .60628 L .63301 .60841 L F
0 0 .299 r
.52148 .77171 m .5222 .7723 L .52253 .77155 L F
.675 .513 .658 r
.52457 .77359 m .52139 .77406 L .52148 .77171 L F
0 0 .299 r
.52148 .77171 m .52139 .77406 L .5222 .7723 L F
.818 .604 .614 r
.68086 .71556 m .67849 .71743 L .6798 .71445 L F
.68086 .71556 m .68139 .71774 L .67849 .71743 L F
.681 .644 .807 r
.48006 .85121 m .48183 .84893 L .47968 .84925 L F
.089 0 0 r
.31587 .71617 m .31911 .71536 L .31697 .71617 L F
.3155 .71617 m .31645 .71596 L .31587 .71617 L F
.31645 .71596 m .31911 .71536 L .31587 .71617 L F
.3155 .71617 m .31714 .71608 L .31911 .71536 L F
.064 0 0 r
.31714 .71608 m .32071 .71417 L .31911 .71536 L F
.31714 .71608 m .31887 .71561 L .32018 .71459 L F
.31939 .71488 m .32018 .71459 L .32071 .71417 L F
.31714 .71608 m .32018 .71459 L .31939 .71488 L F
.859 .817 .807 r
.62416 .62073 m .62349 .61851 L .62474 .61937 L F
.441 .186 .43 r
.69829 .64455 m .69592 .64363 L .69951 .64374 L F
0 0 0 r
.70164 .64295 m .69829 .64455 L .69951 .64374 L F
.265 0 0 r
.44889 .77622 m .44588 .77603 L .44713 .77589 L F
.489 .246 .472 r
.4492 .77428 m .44889 .77622 L .44713 .77589 L F
.734 .924 .955 r
.3415 .82847 m .34182 .82699 L .34008 .82812 L F
.3415 .82847 m .34354 .82728 L .34182 .82699 L F
.562 .406 .628 r
.34065 .76091 m .34272 .76056 L .34266 .75818 L F
.592 .405 .597 r
.34065 .76091 m .34281 .76291 L .34272 .76056 L F
.34065 .76091 m .34057 .76323 L .34281 .76291 L F
.537 .663 .917 r
.56906 .81426 m .57234 .81642 L .57127 .81372 L F
.791 .742 .807 r
.57127 .81372 m .57234 .81642 L .57386 .8138 L F
.128 0 0 r
.3878 .72753 m .39002 .72712 L .39156 .72611 L F
.342 0 0 r
.39002 .72712 m .39367 .72595 L .39156 .72611 L F
.69 .796 .328 r
.53896 .83495 m .53761 .83797 L .53824 .83664 L F
.647 .387 .511 r
.62277 .6617 m .62194 .66442 L .61965 .66425 L F
.612 .351 .499 r
.62514 .66341 m .62277 .6617 L .62509 .6618 L F
.62514 .66341 m .62194 .66442 L .62277 .6617 L F
.49 .518 .813 r
.42907 .74491 m .42994 .74189 L .428 .74172 L F
.42907 .74491 m .43095 .74462 L .42994 .74189 L F
.846 .731 .737 r
.62756 .64013 m .62926 .64068 L .62815 .63775 L F
.847 .676 .67 r
.62756 .64013 m .62885 .64306 L .62926 .64068 L F
.079 0 0 r
.30342 .65638 m .30483 .65615 L .30637 .6548 L F
.303 0 0 r
.30637 .6548 m .30787 .65498 L .30864 .65419 L F
.30637 .6548 m .30483 .65615 L .30787 .65498 L F
.358 .338 .7 r
.65641 .5986 m .65882 .59769 L .65808 .5973 L F
.65641 .5986 m .65683 .60051 L .65782 .5991 L F
.65641 .5986 m .65782 .5991 L .65794 .59802 L F
.333 .059 .34 r
.658 .59745 m .65616 .59948 L .65401 .59625 L F
.65817 .5975 m .65798 .59769 L .658 .59745 L F
.65798 .59769 m .65616 .59948 L .658 .59745 L F
.358 .338 .7 r
.65794 .59802 m .65782 .5991 L .65882 .59769 L F
.646 .601 .789 r
.48717 .74681 m .48604 .75037 L .4849 .74736 L F
.48717 .74681 m .48834 .74996 L .48604 .75037 L F
.627 .499 .687 r
.48834 .74996 m .48622 .7525 L .48604 .75037 L F
.601 .494 .704 r
.41005 .74529 m .41273 .74315 L .41247 .7451 L F
.483 .28 .527 r
.64464 .6359 m .6469 .63501 L .64676 .63259 L F
.532 .316 .532 r
.6469 .63501 m .64916 .63242 L .64676 .63259 L F
.6469 .63501 m .64916 .63242 L .64676 .63259 L F
.446 .078 .244 r
.46467 .75884 m .4675 .75762 L .46541 .7583 L F
.829 .7 .722 r
.62066 .62502 m .61711 .62661 L .61896 .62377 L F
.62066 .62502 m .61981 .62703 L .61711 .62661 L F
.788 .763 .831 r
.61896 .62377 m .62186 .62388 L .62066 .62502 L F
0 0 .267 r
.6825 .61212 m .68166 .61157 L .68308 .61037 L F
0 0 0 r
.48557 .85418 m .48422 .85719 L .48323 .85419 L F
.48557 .85418 m .48479 .85606 L .48422 .85719 L F
.651 .81 .373 r
.48479 .85606 m .48345 .85849 L .48422 .85719 L F
.994 .752 .409 r
.48345 .85849 m .48427 .85963 L .48422 .85719 L F
.521 .376 .624 r
.34482 .75549 m .34666 .75269 L .34459 .75312 L F
.543 .359 .581 r
.36738 .77113 m .36504 .77362 L .36512 .77152 L F
.609 .325 .461 r
.45753 .76236 m .45989 .76089 L .45771 .76077 L F
.515 .275 .489 r
.33757 .69678 m .33965 .69634 L .34006 .69425 L F
.51 .299 .528 r
.33965 .69634 m .34195 .69367 L .34006 .69425 L F
0 0 0 r
.67939 .70483 m .67677 .70805 L .67831 .70631 L F
.666 .113 0 r
.71054 .73596 m .70716 .73372 L .70833 .73379 L F
0 0 0 r
.39494 .74983 m .39395 .7499 L .39613 .74948 L F
.681 .56 .711 r
.55357 .80613 m .55142 .80891 L .5502 .80567 L F
.281 .59 .947 r
.43406 .72458 m .43331 .72548 L .43205 .72444 L F
.43406 .72458 m .43523 .72589 L .43331 .72548 L F
.523 .823 .999 r
.68731 .63763 m .68616 .63705 L .68379 .63736 L F
.502 .814 1 r
.68731 .63763 m .68836 .63675 L .68616 .63705 L F
.874 .607 .532 r
.68731 .63763 m .68616 .63705 L .68836 .63675 L F
.68731 .63763 m .68624 .63959 L .68616 .63705 L F
.68731 .63763 m .68753 .64017 L .68624 .63959 L F
.725 .508 .597 r
.64407 .61054 m .64443 .60696 L .64073 .60817 L F
.517 .363 .612 r
.64443 .60696 m .6464 .60806 L .64613 .60531 L F
.541 .347 .566 r
.64407 .61054 m .6464 .60806 L .64443 .60696 L F
.459 .06 .193 r
.43368 .77112 m .43589 .77094 L .43711 .76905 L F
.464 .084 .233 r
.43589 .77094 m .43921 .76871 L .43711 .76905 L F
.58 .443 .659 r
.34194 .69129 m .34387 .68847 L .34163 .68887 L F
.582 .502 .729 r
.36353 .77956 m .36173 .78209 L .36139 .77982 L F
.67 .623 .793 r
.36353 .77956 m .3648 .78246 L .36173 .78209 L F
.666 .566 .732 r
.36506 .78467 m .36173 .78209 L .3648 .78246 L F
0 .016 .587 r
.66642 .61909 m .66662 .61849 L .66612 .61805 L F
0 0 .211 r
.66667 .61911 m .66662 .61849 L .66642 .61909 L F
.673 .641 .81 r
.67685 .59435 m .67793 .59787 L .6798 .59522 L F
.686 .66 .819 r
.67793 .59787 m .68111 .59806 L .6798 .59522 L F
.462 .441 .748 r
.46896 .73058 m .46842 .73392 L .46722 .73082 L F
.46896 .73058 m .47029 .73405 L .46842 .73392 L F
.577 .505 .737 r
.48925 .75543 m .48715 .75588 L .48622 .7525 L F
.559 .515 .763 r
.48967 .75765 m .48715 .75588 L .48925 .75543 L F
.759 .679 .774 r
.64024 .64558 m .64241 .64237 L .64086 .64305 L F
.902 .611 .485 r
.68571 .71691 m .68704 .71549 L .68601 .71467 L F
.68571 .71691 m .68733 .71772 L .68704 .71549 L F
.864 .9 .858 r
.68601 .71467 m .68704 .71549 L .68934 .71285 L F
.298 .114 .454 r
.65697 .60054 m .65637 .60225 L .65695 .60053 L F
.65834 .60188 m .65688 .60122 L .65697 .60054 L F
.281 .131 .492 r
.65683 .60051 m .65688 .60122 L .65834 .60188 L F
.65688 .60122 m .657 .60294 L .65834 .60188 L F
.298 .114 .454 r
.65834 .60188 m .65675 .60218 L .65688 .60122 L F
.65675 .60218 m .65637 .60225 L .65697 .60054 L F
.462 .165 .375 r
.6557 .60304 m .65429 .60347 L .65637 .60225 L F
.65395 .60507 m .65429 .60347 L .6557 .60304 L F
.6557 .60304 m .65633 .60305 L .65624 .60471 L F
.6557 .60304 m .65637 .60225 L .65633 .60305 L F
.532 .314 .529 r
.65429 .60347 m .65645 .6028 L .65683 .60051 L F
.65645 .6028 m .65666 .60274 L .65669 .6023 L F
.276 .045 .371 r
.65664 .60241 m .65637 .60225 L .65675 .60218 L F
.532 .314 .529 r
.65645 .6028 m .65669 .6023 L .65683 .60051 L F
.65664 .60301 m .657 .60294 L .65692 .60183 L F
.65675 .60218 m .65692 .60183 L .65688 .60122 L F
.65664 .60301 m .65692 .60183 L .65675 .60218 L F
.026 0 0 r
.6568 .60302 m .657 .60294 L .65639 .60307 L F
.567 .927 .763 r
.65834 .60188 m .657 .60294 L .6568 .60302 L F
.026 0 0 r
.65639 .60307 m .657 .60294 L .65641 .60306 L F
.276 .045 .371 r
.65633 .60307 m .65633 .60305 L .65682 .60301 L F
.65633 .60307 m .65682 .60301 L .6568 .60302 L F
.65633 .60305 m .65664 .60241 L .65755 .60295 L F
.65755 .60295 m .65664 .60241 L .65834 .60188 L F
.026 0 0 r
.65514 .60374 m .6568 .60302 L .65639 .60307 L F
.462 .165 .375 r
.65395 .60507 m .65552 .60324 L .65624 .60471 L F
.65552 .60324 m .65575 .60319 L .65624 .60471 L F
.532 .314 .529 r
.65664 .60301 m .65688 .60122 L .65683 .60051 L F
.567 .927 .763 r
.65834 .60188 m .6568 .60302 L .65514 .60374 L F
.276 .045 .371 r
.6568 .60302 m .65682 .60301 L .65755 .60295 L F
.65633 .60305 m .65637 .60225 L .65664 .60241 L F
.65664 .60241 m .65675 .60218 L .65834 .60188 L F
.65624 .60471 m .65633 .60307 L .65755 .60295 L F
.026 0 0 r
.65433 .60349 m .65641 .60306 L .65429 .60347 L F
.65514 .60374 m .65641 .60306 L .65433 .60349 L F
.532 .314 .529 r
.65429 .60347 m .65641 .60306 L .6557 .60304 L F
.462 .165 .375 r
.65552 .60324 m .6557 .60304 L .65575 .60319 L F
.532 .314 .529 r
.6557 .60304 m .65664 .60301 L .65666 .60274 L F
.65641 .60306 m .65664 .60301 L .6557 .60304 L F
.298 .114 .454 r
.65834 .60188 m .65695 .60053 L .65938 .60001 L F
.281 .131 .492 r
.65683 .60051 m .65834 .60188 L .65882 .59769 L F
.608 .459 .653 r
.3302 .77697 m .33282 .77706 L .33213 .77416 L F
.612 .448 .636 r
.33029 .77941 m .33282 .77706 L .3302 .77697 L F
0 0 0 r
.33962 .8137 m .33915 .81399 L .33837 .8144 L F
.382 .838 .756 r
.33837 .8144 m .33915 .81399 L .33789 .81455 L F
.859 .817 .807 r
.62416 .62073 m .62142 .62129 L .62349 .61851 L F
.86 .807 .797 r
.62186 .62388 m .62142 .62129 L .62416 .62073 L F
.737 .971 .93 r
.68359 .69928 m .68524 .6972 L .68591 .69818 L F
.68359 .69928 m .68283 .69887 L .68524 .6972 L F
.573 .215 .323 r
.42435 .7397 m .42108 .74135 L .42237 .73992 L F
.339 0 .208 r
.70455 .62909 m .70596 .63068 L .70675 .62885 L F
.70455 .62909 m .70378 .63143 L .70596 .63068 L F
.632 .476 .653 r
.52534 .77189 m .52407 .77119 L .52589 .77094 L F
.066 .181 .675 r
.67677 .70805 m .67867 .70831 L .67831 .70631 L F
.67677 .70805 m .67775 .70965 L .67867 .70831 L F
.658 .703 .88 r
.68111 .59806 m .68196 .59491 L .6798 .59522 L F
.68111 .59806 m .68344 .59743 L .68196 .59491 L F
.331 0 .203 r
.70599 .63796 m .70348 .6398 L .70364 .63791 L F
.863 .831 .814 r
.6809 .72843 m .6823 .72961 L .68363 .72758 L F
.575 .619 .859 r
.69845 .60037 m .69479 .59729 L .69651 .59718 L F
.567 .666 .905 r
.69877 .59696 m .69845 .60037 L .69651 .59718 L F
.69877 .59696 m .70049 .5998 L .69845 .60037 L F
.549 .583 .841 r
.70089 .60077 m .69845 .60037 L .70049 .5998 L F
.082 .249 .737 r
.5332 .82772 m .53474 .83081 L .53527 .82964 L F
.665 .933 .969 r
.53474 .83081 m .53319 .83061 L .53527 .82964 L F
.705 .774 .285 r
.53474 .83081 m .53473 .83068 L .53319 .83061 L F
.93 .968 .754 r
.53407 .83262 m .53201 .83449 L .5343 .83129 L F
.53458 .83113 m .5343 .83129 L .53473 .83068 L F
.53407 .83262 m .5343 .83129 L .53458 .83113 L F
.741 .294 .19 r
.53344 .83177 m .53391 .83151 L .53319 .83061 L F
.861 .851 .831 r
.53201 .83449 m .5321 .83152 L .5343 .83129 L F
.741 .294 .19 r
.53425 .83192 m .53442 .83151 L .53319 .83061 L F
.861 .851 .831 r
.5343 .83129 m .5321 .83152 L .53473 .83068 L F
.741 .294 .19 r
.5321 .83152 m .53344 .83177 L .53336 .83139 L F
.5321 .83152 m .53336 .83139 L .53319 .83061 L F
.53344 .83177 m .53425 .83192 L .53391 .83151 L F
.53425 .83192 m .53525 .83211 L .53442 .83151 L F
.705 .774 .285 r
.53474 .83081 m .53407 .83262 L .53458 .83113 L F
.53474 .83075 m .53458 .83113 L .53473 .83068 L F
.53474 .83081 m .53458 .83113 L .53474 .83075 L F
.781 .418 0 r
.49028 .82707 m .491 .82841 L .49071 .82765 L F
.923 .787 .693 r
.70394 .71726 m .70486 .7185 L .70405 .71536 L F
.58 .467 .689 r
.47968 .84925 m .48183 .84893 L .48128 .84668 L F
.814 .689 .726 r
.57144 .81152 m .5748 .81187 L .57345 .80876 L F
.805 .664 .707 r
.57144 .81152 m .57386 .8138 L .5748 .81187 L F
.833 .789 .81 r
.40285 .74635 m .40541 .74767 L .40589 .74448 L F
.322 0 0 r
.39584 .72586 m .39793 .72553 L .39937 .72397 L F
.335 0 0 r
.39793 .72553 m .40138 .72379 L .39937 .72397 L F
.485 .53 .828 r
.34998 .65767 m .34917 .66039 L .34811 .65788 L F
.34998 .65767 m .35143 .66039 L .34917 .66039 L F
.812 .906 .502 r
.71143 .71207 m .7086 .71481 L .71191 .7109 L F
.714 .57 .692 r
.60849 .6645 m .60658 .66459 L .60866 .66199 L F
0 0 0 r
.31657 .67588 m .31505 .67633 L .31241 .67703 L F
.108 0 0 r
.31681 .6762 m .31657 .67588 L .31842 .67496 L F
.31681 .6762 m .31505 .67633 L .31657 .67588 L F
0 0 .557 r
.72906 .71116 m .72758 .70967 L .7267 .70948 L F
.72906 .71116 m .72954 .71225 L .72758 .70967 L F
.963 .702 .493 r
.66168 .61111 m .66045 .61078 L .66037 .60823 L F
0 .158 .614 r
.66305 .6127 m .66045 .61078 L .66168 .61111 L F
.567 .824 .994 r
.33754 .65348 m .33703 .65482 L .33551 .65377 L F
.33754 .65348 m .33895 .65435 L .33703 .65482 L F
.817 .91 .508 r
.6673 .62453 m .66587 .62746 L .6662 .62601 L F
.838 .985 .708 r
.6662 .62601 m .66587 .62746 L .66424 .6287 L F
.079 0 .108 r
.33119 .70484 m .32885 .7074 L .33028 .70661 L F
.331 .006 .253 r
.33119 .70484 m .33202 .70607 L .33253 .70395 L F
.33119 .70484 m .33028 .70661 L .33202 .70607 L F
.619 .483 .675 r
.36255 .77405 m .36047 .77649 L .36057 .77463 L F
.599 .639 .862 r
.71644 .59933 m .7152 .60256 L .71415 .60001 L F
.71644 .59933 m .71839 .60238 L .7152 .60256 L F
.584 .739 .95 r
.45176 .73977 m .45331 .74146 L .45531 .74092 L F
0 0 0 r
.71561 .71235 m .71448 .71297 L .71655 .71028 L F
.334 0 0 r
.71585 .71393 m .71698 .71269 L .71448 .71297 L F
.71585 .71393 m .71448 .71297 L .71561 .71235 L F
.558 .613 .864 r
.40282 .76038 m .40353 .75742 L .40405 .75823 L F
0 0 .207 r
.40353 .75742 m .40282 .76038 L .40405 .75823 L F
.656 .598 .778 r
.4849 .74736 m .48258 .74804 L .48152 .74493 L F
.487 .109 .247 r
.46006 .77136 m .45668 .7733 L .45708 .77222 L F
.432 .343 .655 r
.34582 .68336 m .3474 .68009 L .34528 .68052 L F
.34582 .68336 m .34727 .68291 L .3474 .68009 L F
.513 .36 .61 r
.34567 .68565 m .34727 .68291 L .34582 .68336 L F
.627 .499 .687 r
.48834 .74996 m .48861 .75228 L .48622 .7525 L F
.577 .505 .737 r
.48925 .75543 m .48622 .7525 L .48861 .75228 L F
.612 .717 .919 r
.32865 .65063 m .32809 .65301 L .3267 .65142 L F
.32865 .65063 m .33029 .65266 L .32809 .65301 L F
.817 .91 .508 r
.6673 .62453 m .6662 .62601 L .66576 .62463 L F
.387 .006 .188 r
.38272 .75499 m .38042 .75549 L .38363 .75337 L F
.506 .126 .253 r
.38509 .75465 m .38272 .75499 L .38363 .75337 L F
.429 .141 .372 r
.38555 .7527 m .38509 .75465 L .38363 .75337 L F
.763 .984 .905 r
.6869 .60462 m .68609 .60621 L .68782 .60481 L F
.701 .661 .807 r
.70865 .72399 m .70961 .72713 L .70598 .72595 L F
.674 .645 .813 r
.71146 .72592 m .70961 .72713 L .70865 .72399 L F
.578 .47 .694 r
.36261 .77608 m .36139 .77982 L .36047 .77649 L F
.36261 .77608 m .36353 .77956 L .36139 .77982 L F
.484 .124 .278 r
.32552 .70957 m .32761 .70949 L .32885 .7074 L F
.464 .102 .266 r
.32885 .7074 m .32993 .70913 L .33028 .70661 L F
.32885 .7074 m .32761 .70949 L .32993 .70913 L F
.184 0 0 r
.64404 .58865 m .64286 .5882 L .64171 .58882 L F
.64404 .58865 m .6452 .58753 L .64286 .5882 L F
.532 .42 .671 r
.48125 .84342 m .48288 .84085 L .48051 .84129 L F
.48125 .84342 m .48318 .84323 L .48288 .84085 L F
.612 .497 .698 r
.48128 .84668 m .48318 .84323 L .48125 .84342 L F
.547 .522 .779 r
.34528 .68052 m .34647 .67797 L .34464 .67816 L F
.34528 .68052 m .3474 .68009 L .34647 .67797 L F
.932 .952 .624 r
.66284 .60323 m .66113 .60699 L .66156 .6045 L F
.868 .954 .863 r
.66484 .601 m .66284 .60323 L .66198 .60227 L F
.992 .88 .592 r
.66198 .60227 m .66284 .60323 L .66156 .6045 L F
.441 .186 .43 r
.69829 .64455 m .69619 .64525 L .69592 .64363 L F
.343 .785 .961 r
.43453 .74489 m .43308 .74444 L .43095 .74462 L F
.192 .716 .861 r
.43662 .74447 m .43308 .74444 L .43453 .74489 L F
.764 .644 .728 r
.60324 .66211 m .60322 .66485 L .60107 .66454 L F
.769 .499 .527 r
.60322 .66485 m .60318 .667 L .60107 .66454 L F
.699 .59 .73 r
.60658 .66459 m .60322 .66485 L .60324 .66211 L F
.71 .449 .529 r
.60663 .66683 m .60322 .66485 L .60658 .66459 L F
.60663 .66683 m .60318 .667 L .60322 .66485 L F
.496 .252 .474 r
.45114 .77571 m .4492 .77428 L .45162 .77457 L F
.45114 .77571 m .44889 .77622 L .4492 .77428 L F
0 0 0 r
.38516 .79906 m .3854 .79931 L .38324 .79964 L F
.38516 .79906 m .38732 .79852 L .3854 .79931 L F
.281 0 .267 r
.38065 .75748 m .37813 .7599 L .37908 .75841 L F
.788 .763 .831 r
.61896 .62377 m .62142 .62129 L .62186 .62388 L F
.207 0 0 r
.55488 .81179 m .5537 .81299 L .55148 .81346 L F
.425 0 .116 r
.55696 .81124 m .5537 .81299 L .55488 .81179 L F
.201 0 0 r
.41395 .78824 m .41315 .78729 L .41514 .78698 L F
.41395 .78824 m .41161 .78901 L .41315 .78729 L F
.684 .621 .779 r
.37035 .78473 m .36794 .78655 L .3671 .78408 L F
.317 .251 .623 r
.63546 .61916 m .63721 .62044 L .63553 .62061 L F
.785 .823 .883 r
.5004 .88629 m .50416 .8845 L .50351 .88403 L F
.643 .897 .984 r
.50351 .88403 m .50416 .8845 L .50651 .88381 L F
.823 .656 .675 r
.67886 .60744 m .68173 .60496 L .68148 .60441 L F
.67886 .60744 m .68103 .60836 L .68173 .60496 L F
0 0 0 r
.68173 .60496 m .68365 .60423 L .68148 .60441 L F
.403 .616 .938 r
.48839 .88799 m .48877 .88625 L .48676 .88687 L F
.48839 .88799 m .49026 .88808 L .48877 .88625 L F
.631 .729 .918 r
.71077 .60759 m .71226 .60477 L .7095 .6051 L F
.71077 .60759 m .71344 .60698 L .71226 .60477 L F
.475 .487 .79 r
.34464 .67816 m .34647 .67797 L .34588 .67686 L F
.93 .968 .754 r
.53407 .83262 m .53214 .83564 L .53201 .83449 L F
.372 .761 .988 r
.42497 .72319 m .4243 .72402 L .42304 .72316 L F
.42497 .72319 m .42652 .72394 L .4243 .72402 L F
.733 .436 .477 r
.49507 .76848 m .49211 .76657 L .49514 .76618 L F
.49507 .76848 m .49171 .76837 L .49211 .76657 L F
.702 .582 .719 r
.4868 .83084 m .48724 .8331 L .48943 .8308 L F
.48943 .8308 m .48724 .8331 L .4868 .83084 L F
.372 .055 .293 r
.41082 .77616 m .41163 .77841 L .41286 .77604 L F
.41082 .77616 m .40969 .77903 L .41163 .77841 L F
.827 .708 .733 r
.61711 .62661 m .61981 .62703 L .61815 .62974 L F
.464 .725 .982 r
.45699 .72813 m .45612 .72936 L .45498 .72813 L F
.45699 .72813 m .45832 .72927 L .45612 .72936 L F
.753 .957 .939 r
.70026 .63735 m .69855 .63853 L .69774 .63801 L F
.421 0 .11 r
.63848 .65601 m .63934 .65751 L .63718 .6582 L F
.63848 .65601 m .64027 .65592 L .63934 .65751 L F
.622 .466 .649 r
.33213 .77416 m .33448 .77403 L .33433 .77139 L F
.615 .463 .653 r
.33213 .77416 m .33469 .77666 L .33448 .77403 L F
.33213 .77416 m .33282 .77706 L .33469 .77666 L F
0 0 0 r
.66858 .64289 m .66775 .64313 L .66555 .64355 L F
.493 .905 .869 r
.66984 .64196 m .66858 .64289 L .67036 .64184 L F
.477 .89 .777 r
.66984 .64196 m .66775 .64313 L .66858 .64289 L F
.841 .847 .849 r
.37784 .7804 m .37628 .78258 L .37467 .78175 L F
.863 .831 .814 r
.6809 .72843 m .68363 .72758 L .68238 .72691 L F
.58 .443 .659 r
.34194 .69129 m .3441 .69104 L .34387 .68847 L F
.464 .245 .496 r
.34195 .69367 m .3441 .69104 L .34194 .69129 L F
.716 .506 .604 r
.60956 .6667 m .60658 .66459 L .60849 .6645 L F
.632 .4 .549 r
.61197 .66457 m .60956 .6667 L .60849 .6645 L F
.729 .663 .786 r
.49722 .76599 m .49514 .76618 L .49697 .76454 L F
.705 .508 .619 r
.49722 .76599 m .49507 .76848 L .49514 .76618 L F
.49722 .76599 m .49715 .76897 L .49507 .76848 L F
.496 .5 .79 r
.49697 .76454 m .49935 .76557 L .49722 .76599 L F
.696 .5 .619 r
.5005 .76854 m .49722 .76599 L .49935 .76557 L F
.5005 .76854 m .49715 .76897 L .49722 .76599 L F
.421 .459 .794 r
.7198 .60195 m .71804 .60352 L .71839 .60238 L F
.047 .046 .533 r
.71958 .60406 m .71804 .60352 L .7198 .60195 L F
.71958 .60406 m .71926 .60611 L .71804 .60352 L F
.253 .01 .338 r
.35822 .8114 m .35887 .80978 L .36098 .80843 L F
.816 .77 .81 r
.51806 .7748 m .51925 .77694 L .51755 .77567 L F
.796 .539 .549 r
.51925 .77694 m .51612 .77889 L .51755 .77567 L F
.51925 .77694 m .51933 .77921 L .51612 .77889 L F
.828 .773 .801 r
.52139 .77406 m .51925 .77694 L .51806 .7748 L F
.642 .626 .819 r
.36565 .77913 m .3648 .78246 L .36353 .77956 L F
.36565 .77913 m .36701 .78209 L .3648 .78246 L F
.63 .52 .71 r
.36701 .78209 m .36506 .78467 L .3648 .78246 L F
.222 0 .076 r
.6455 .65354 m .64825 .65175 L .6476 .65333 L F
.257 0 .205 r
.6455 .65354 m .64696 .65471 L .64483 .65473 L F
.6455 .65354 m .6476 .65333 L .64696 .65471 L F
.993 .874 .6 r
.60994 .65406 m .61012 .65035 L .61195 .65127 L F
.60994 .65406 m .6092 .65329 L .61012 .65035 L F
.968 .915 .701 r
.60994 .65406 m .60826 .65521 L .6092 .65329 L F
.075 0 0 r
.65025 .65097 m .6476 .65333 L .64825 .65175 L F
.688 .655 .812 r
.48455 .87174 m .48111 .87035 L .48337 .87112 L F
.454 .785 .998 r
.48557 .87064 m .48455 .87174 L .48337 .87112 L F
.48557 .87064 m .48676 .87155 L .48455 .87174 L F
.174 0 .098 r
.32261 .73135 m .31995 .73374 L .32043 .7329 L F
.824 .821 .846 r
.62907 .61407 m .62532 .61557 L .62798 .61327 L F
.882 .887 .832 r
.6301 .61052 m .62907 .61407 L .62798 .61327 L F
.6301 .61052 m .63115 .61137 L .62907 .61407 L F
.557 .145 .216 r
.66145 .60063 m .65834 .60188 L .65938 .60001 L F
.585 .402 .601 r
.66213 .598 m .66145 .60063 L .65938 .60001 L F
.568 .024 0 r
.32731 .67515 m .32596 .67543 L .32413 .67468 L F
.5 .044 .101 r
.32934 .6747 m .32596 .67543 L .32731 .67515 L F
.541 .704 .946 r
.34632 .65561 m .34563 .65746 L .34434 .65583 L F
.34632 .65561 m .3477 .65706 L .34563 .65746 L F
.551 .58 .837 r
.34811 .65788 m .34563 .65746 L .3477 .65706 L F
.276 .307 .714 r
.64101 .61324 m .64105 .61013 L .63862 .61322 L F
.683 .192 .075 r
.64075 .61467 m .64101 .61324 L .63862 .61322 L F
.64075 .61467 m .64247 .61469 L .64101 .61324 L F
.627 .515 .707 r
.36701 .78209 m .3671 .78408 L .36506 .78467 L F
.655 .536 .707 r
.36261 .77608 m .36047 .77649 L .36255 .77405 L F
.965 .813 .642 r
.63139 .62683 m .63129 .62464 L .62988 .6257 L F
.881 .738 .7 r
.62798 .62872 m .63139 .62683 L .62988 .6257 L F
.62798 .62872 m .62927 .62931 L .63139 .62683 L F
.817 .626 .644 r
.62927 .62931 m .63267 .63 L .63139 .62683 L F
.685 .566 .714 r
.63267 .63 m .63476 .62699 L .63139 .62683 L F
.667 .415 .529 r
.40148 .74614 m .40077 .74993 L .39827 .74942 L F
.815 .56 .553 r
.40433 .75023 m .40148 .74614 L .40285 .74635 L F
.40433 .75023 m .40077 .74993 L .40148 .74614 L F
.74 .46 .506 r
.56109 .7948 m .56427 .79312 L .56101 .79263 L F
.56109 .7948 m .56451 .79516 L .56427 .79312 L F
.566 .335 .524 r
.56427 .79312 m .56451 .79516 L .56647 .79488 L F
.762 .345 .257 r
.62927 .62931 m .63183 .63134 L .63267 .63 L F
.245 0 .32 r
.63267 .63 m .63059 .63311 L .63112 .6325 L F
.615 .806 .386 r
.63183 .63134 m .63112 .6325 L .63267 .63 L F
.63183 .63134 m .63112 .6325 L .63267 .63 L F
.632 .4 .549 r
.61197 .66457 m .61197 .66671 L .60956 .6667 L F
.651 .416 .55 r
.61197 .66457 m .61423 .66672 L .61197 .66671 L F
.682 .409 .502 r
.61415 .66474 m .61423 .66672 L .61197 .66457 L F
.316 0 0 r
.33601 .69818 m .33817 .69758 L .33757 .69678 L F
.259 0 0 r
.33757 .69678 m .33817 .69758 L .33965 .69634 L F
.716 .506 .604 r
.60956 .6667 m .60663 .66683 L .60658 .66459 L F
.348 0 .048 r
.44904 .76583 m .45117 .7655 L .45242 .76384 L F
.432 0 .106 r
.45117 .7655 m .45407 .76459 L .45242 .76384 L F
.414 .01 .161 r
.45242 .76384 m .45407 .76459 L .45461 .76353 L F
.888 .98 .821 r
.63193 .60751 m .63413 .60474 L .63381 .60628 L F
.724 .664 .79 r
.69674 .60579 m .6967 .60776 L .69888 .60521 L F
.661 .566 .737 r
.6967 .60776 m .70026 .60856 L .69888 .60521 L F
.557 .57 .822 r
.6967 .60776 m .70027 .61034 L .70026 .60856 L F
.386 0 .117 r
.38011 .7302 m .3822 .72995 L .38081 .72916 L F
.399 0 .072 r
.38081 .72916 m .3822 .72995 L .38286 .72902 L F
.614 .447 .632 r
.34482 .75549 m .34266 .75818 L .34494 .7579 L F
.571 .388 .595 r
.34272 .76056 m .34494 .7579 L .34266 .75818 L F
.462 .246 .5 r
.35121 .74735 m .3534 .74467 L .35109 .74496 L F
0 0 .211 r
.66667 .61911 m .66699 .62006 L .66662 .61849 L F
.986 .824 .599 r
.66667 .61911 m .66576 .62463 L .66442 .62319 L F
.66667 .61911 m .66442 .62319 L .66699 .62006 L F
.739 .663 .775 r
.47308 .75789 m .47631 .75774 L .47515 .7551 L F
.561 .368 .576 r
.47308 .75789 m .47524 .76008 L .47631 .75774 L F
.525 .552 .825 r
.47515 .7551 m .47631 .75774 L .47802 .75656 L F
.531 .194 .342 r
.47631 .75774 m .47865 .75926 L .47802 .75656 L F
.47631 .75774 m .47524 .76008 L .47865 .75926 L F
.702 .582 .719 r
.4868 .83084 m .48759 .83075 L .48719 .83048 L F
.4868 .83084 m .48943 .8308 L .48759 .83075 L F
.625 .452 .629 r
.33634 .77103 m .33866 .76849 L .33653 .76888 L F
.548 .881 .62 r
.57564 .80234 m .57728 .80082 L .57696 .80048 L F
.88 .61 .088 r
.57659 .79797 m .57696 .80048 L .57728 .80082 L F
.506 .271 .492 r
.32134 .71271 m .3234 .71232 L .32385 .71 L F
.465 .234 .478 r
.32385 .71 m .32533 .71186 L .32552 .70957 L F
.32385 .71 m .3234 .71232 L .32533 .71186 L F
.54 .489 .748 r
.46739 .7555 m .46847 .75208 L .46674 .75215 L F
.46739 .7555 m .46964 .75536 L .46847 .75208 L F
.526 .355 .593 r
.46739 .7555 m .4675 .75762 L .46964 .75536 L F
.863 .891 .466 r
.49861 .87333 m .49746 .87551 L .49812 .8738 L F
.229 0 0 r
.49861 .87333 m .49812 .8738 L .5005 .8733 L F
.824 .683 .708 r
.61061 .64812 m .61195 .65127 L .61012 .65035 L F
.521 .376 .624 r
.34482 .75549 m .34678 .7551 L .34666 .75269 L F
.534 .385 .626 r
.34482 .75549 m .3469 .75749 L .34678 .7551 L F
.34482 .75549 m .34494 .7579 L .3469 .75749 L F
.754 .888 .483 r
.4864 .87763 m .48759 .87597 L .48787 .87497 L F
.026 0 0 r
.65514 .60374 m .65429 .60347 L .6532 .60356 L F
.53 .142 .25 r
.54777 .80502 m .54935 .80602 L .55054 .8037 L F
0 0 0 r
.55054 .8037 m .55095 .80298 L .55166 .80067 L F
.55054 .8037 m .54935 .80602 L .55095 .80298 L F
.784 .765 .836 r
.68636 .7123 m .68934 .71285 L .68852 .71168 L F
.864 .9 .858 r
.68601 .71467 m .68934 .71285 L .68636 .7123 L F
.597 .113 .077 r
.69171 .71199 m .68852 .71168 L .68934 .71285 L F
.57 .422 .64 r
.33448 .77403 m .33634 .77103 L .33433 .77139 L F
.986 .719 .42 r
.73015 .73408 m .73026 .73647 L .72915 .7335 L F
.529 0 0 r
.72915 .7335 m .73242 .7337 L .73015 .73408 L F
.551 .365 .582 r
.73242 .7337 m .73026 .73647 L .73015 .73408 L F
.513 .307 .538 r
.67082 .6003 m .67025 .60272 L .67271 .60207 L F
.08 0 .342 r
.67088 .60121 m .67025 .60272 L .67067 .60091 L F
.67088 .60121 m .67067 .60091 L .67082 .6003 L F
.332 .435 .816 r
.67189 .6022 m .67025 .60272 L .67088 .60121 L F
.533 .033 .014 r
.66774 .60298 m .67161 .60225 L .67088 .60121 L F
.67161 .60225 m .67189 .6022 L .67088 .60121 L F
.08 0 .342 r
.67088 .60121 m .67082 .6003 L .66849 .60151 L F
.67088 .60121 m .66849 .60151 L .66719 .60068 L F
.564 .937 .858 r
.71215 .62661 m .71341 .62545 L .71499 .62511 L F
0 0 0 r
.71341 .62545 m .71606 .62357 L .71499 .62511 L F
.71341 .62545 m .71524 .62432 L .71606 .62357 L F
.613 .955 .894 r
.71461 .62419 m .71524 .62432 L .71341 .62545 L F
.247 .021 .361 r
.71341 .62545 m .71513 .62673 L .71464 .62432 L F
.71341 .62545 m .71464 .62432 L .71461 .62419 L F
.564 .937 .858 r
.71205 .62666 m .71341 .62545 L .71215 .62661 L F
0 0 0 r
.71205 .62666 m .71116 .62828 L .71341 .62545 L F
.922 .885 .778 r
.63193 .60751 m .63115 .61137 L .6301 .61052 L F
.527 .04 .042 r
.55483 .79872 m .5535 .79994 L .55679 .79968 L F
.492 .178 .361 r
.55483 .79872 m .55679 .79968 L .55699 .79828 L F
0 0 0 r
.63553 .62061 m .6342 .62242 L .63243 .62349 L F
.295 0 .045 r
.63721 .62044 m .6342 .62242 L .63553 .62061 L F
.809 .401 0 r
.68159 .63634 m .68016 .63386 L .68178 .63423 L F
.818 .623 .638 r
.68139 .71774 m .68025 .72059 L .67849 .71743 L F
.72 .616 .74 r
.57296 .7953 m .57103 .79793 L .57509 .79721 L F
.501 .142 .29 r
.57509 .79721 m .57509 .79931 L .57659 .79797 L F
.57509 .79721 m .57353 .80002 L .57509 .79931 L F
.334 .109 .416 r
.37175 .76355 m .37116 .76567 L .36969 .76606 L F
.358 .195 .519 r
.37102 .76798 m .36969 .76606 L .37116 .76567 L F
.37102 .76798 m .36955 .76857 L .36969 .76606 L F
.809 .904 .907 r
.48984 .82874 m .48943 .8308 L .491 .82841 L F
.48984 .82874 m .48759 .83075 L .48943 .8308 L F
.455 .179 .405 r
.68474 .60315 m .68701 .60246 L .68739 .60081 L F
.575 .618 .858 r
.68549 .59732 m .68739 .60081 L .68929 .60002 L F
.391 .123 .382 r
.68739 .60081 m .68916 .60206 L .68929 .60002 L F
.68739 .60081 m .68701 .60246 L .68916 .60206 L F
.828 .773 .801 r
.52139 .77406 m .51806 .7748 L .52044 .77385 L F
.757 .987 .899 r
.52139 .77406 m .52044 .77385 L .5222 .7723 L F
.396 0 0 r
.40138 .72379 m .40305 .72436 L .40464 .72347 L F
.133 0 0 r
.40305 .72436 m .40676 .72337 L .40464 .72347 L F
.74 .61 .713 r
.71191 .7109 m .7086 .71481 L .70799 .70987 L F
.834 .981 .877 r
.71472 .708 m .71191 .7109 L .71245 .70911 L F
.649 .812 .962 r
.51135 .77141 m .50932 .77125 L .51138 .77077 L F
.31 0 0 r
.50932 .77125 m .51058 .7714 L .51138 .77077 L F
.908 .981 .775 r
.51138 .77077 m .51058 .7714 L .51145 .76956 L F
.51138 .77077 m .51145 .76956 L .51238 .76759 L F
.649 .812 .962 r
.51265 .77151 m .51135 .77141 L .51138 .77077 L F
.74 .402 .41 r
.51265 .77151 m .51119 .77333 L .50932 .77125 L F
.538 .783 .988 r
.51381 .77025 m .51265 .77151 L .51138 .77077 L F
.713 .609 .74 r
.51381 .77025 m .51119 .77333 L .51265 .77151 L F
.759 .887 .936 r
.35296 .81267 m .35497 .81261 L .35641 .81133 L F
0 0 .488 r
.47902 .88122 m .47882 .87794 L .47776 .87758 L F
.47902 .88122 m .4795 .88209 L .47882 .87794 L F
.781 .279 0 r
.47902 .88122 m .48059 .88323 L .4795 .88209 L F
.786 .357 .23 r
.65669 .63172 m .65464 .63083 L .65441 .63231 L F
.65464 .63083 m .65389 .6305 L .65441 .63231 L F
.65669 .63172 m .6554 .6322 L .65467 .63138 L F
.65464 .63083 m .65465 .63103 L .65389 .6305 L F
.946 .682 .506 r
.65481 .63018 m .65476 .63001 L .65464 .63083 L F
.65481 .63018 m .65464 .63083 L .65465 .63103 L F
.65476 .63001 m .65453 .62907 L .65441 .63231 L F
.65481 .63018 m .65465 .63103 L .65389 .6305 L F
.65465 .63103 m .65464 .63083 L .65441 .63231 L F
.65465 .63103 m .65441 .63231 L .65389 .6305 L F
.786 .357 .23 r
.65465 .63103 m .65467 .63138 L .65389 .6305 L F
.65669 .63172 m .65467 .63138 L .65464 .63083 L F
.946 .682 .506 r
.65481 .63018 m .65647 .62919 L .65453 .62907 L F
.234 .56 .935 r
.38049 .91684 m .38167 .91721 L .38319 .91858 L F
.38049 .91684 m .38167 .91721 L .38319 .91858 L F
.776 .704 .784 r
.56399 .81448 m .56151 .81706 L .56374 .8159 L F
.489 .566 .86 r
.68016 .63386 m .67782 .63469 L .67727 .63319 L F
.234 0 .224 r
.68016 .63386 m .67711 .63655 L .67782 .63469 L F
.579 .442 .659 r
.3534 .74467 m .35533 .742 L .35322 .74243 L F
.411 0 .007 r
.44322 .7676 m .4469 .76614 L .44463 .76603 L F
.687 .588 .739 r
.49697 .76454 m .49514 .76618 L .49406 .76315 L F
.53 .492 .758 r
.72107 .70919 m .72272 .71275 L .72055 .71212 L F
.403 .138 .393 r
.6579 .63266 m .65752 .63447 L .66001 .63199 L F
.338 0 .195 r
.71131 .63518 m .71071 .63714 L .70858 .63775 L F
.44 .065 .23 r
.71349 .63569 m .71131 .63518 L .71336 .63436 L F
.71349 .63569 m .71071 .63714 L .71131 .63518 L F
.645 .38 .503 r
.61723 .66631 m .61415 .66474 L .61737 .66434 L F
.61723 .66631 m .61423 .66672 L .61415 .66474 L F
.501 .275 .504 r
.33644 .71791 m .33621 .71978 L .33432 .72023 L F
.418 .184 .449 r
.33871 .71529 m .33822 .7175 L .33644 .71791 L F
.438 .222 .487 r
.33777 .71905 m .33644 .71791 L .33822 .7175 L F
.33777 .71905 m .33621 .71978 L .33644 .71791 L F
.471 .502 .809 r
.67124 .60427 m .67118 .60597 L .67025 .60272 L F
.424 .471 .804 r
.6713 .60449 m .67146 .60567 L .67196 .60515 L F
.67138 .60449 m .67196 .60515 L .67264 .60442 L F
.6713 .60449 m .67196 .60515 L .67138 .60449 L F
0 0 .297 r
.67212 .60767 m .67264 .60442 L .67118 .60597 L F
.67212 .60767 m .6728 .60663 L .67264 .60442 L F
0 0 .53 r
.6713 .60449 m .67246 .60726 L .67212 .60767 L F
.67124 .60427 m .67128 .60436 L .6713 .60449 L F
.67128 .60436 m .67246 .60726 L .6713 .60449 L F
.424 .471 .804 r
.6713 .60449 m .67118 .60597 L .67146 .60567 L F
0 0 .53 r
.67124 .60427 m .6713 .60449 L .67118 .60597 L F
.851 .506 .399 r
.67122 .60429 m .67128 .60436 L .67124 .60427 L F
.424 .471 .804 r
.67025 .60272 m .67093 .60507 L .67137 .60352 L F
.67125 .60394 m .67134 .60396 L .67137 .60352 L F
.67132 .60402 m .67134 .60396 L .67125 .60394 L F
.67219 .60221 m .67264 .60442 L .67271 .60207 L F
.67025 .60272 m .67148 .60359 L .67219 .60221 L F
.67148 .60359 m .67264 .60442 L .67219 .60221 L F
.332 .435 .816 r
.67189 .6022 m .67132 .60402 L .67025 .60272 L F
.67132 .60402 m .67124 .60427 L .67025 .60272 L F
.851 .506 .399 r
.66907 .60657 m .671 .60452 L .67189 .6022 L F
.424 .471 .804 r
.67093 .60507 m .67132 .60402 L .67125 .60394 L F
.851 .506 .399 r
.671 .60452 m .67122 .60429 L .67138 .60378 L F
.671 .60452 m .67138 .60378 L .67189 .6022 L F
.67122 .60429 m .67124 .60427 L .67132 .60402 L F
.424 .471 .804 r
.67093 .60507 m .67118 .60597 L .67134 .60396 L F
.851 .506 .399 r
.67122 .60429 m .67132 .60402 L .67189 .6022 L F
0 0 .53 r
.6713 .60449 m .67212 .60767 L .67118 .60597 L F
.851 .506 .399 r
.66907 .60657 m .67246 .60726 L .67128 .60436 L F
.66907 .60657 m .67128 .60436 L .67122 .60429 L F
.424 .471 .804 r
.67137 .60352 m .6713 .60449 L .67264 .60442 L F
.692 .68 .834 r
.69533 .69843 m .69119 .69732 L .69389 .69829 L F
.797 .318 .079 r
.69389 .69829 m .69655 .69958 L .69533 .69843 L F
.746 .615 .712 r
.60324 .66211 m .59984 .66411 L .5993 .66374 L F
.60324 .66211 m .5993 .66374 L .59937 .66365 L F
.60028 .66306 m .59924 .6637 L .59973 .66323 L F
.60324 .66211 m .59991 .66344 L .60028 .66306 L F
.59991 .66344 m .59924 .6637 L .60028 .66306 L F
.60324 .66211 m .59973 .66323 L .60222 .65995 L F
0 0 .07 r
.60312 .66011 m .6013 .66282 L .60345 .66017 L F
.60222 .65995 m .60169 .66159 L .60312 .66011 L F
.60169 .66159 m .6013 .66282 L .60312 .66011 L F
.611 .89 .989 r
.5993 .66374 m .59788 .66427 L .59924 .6637 L F
.59866 .66421 m .59788 .66427 L .5993 .66374 L F
.72 .54 .646 r
.59984 .66411 m .59777 .66676 L .59788 .66427 L F
.18 .016 .408 r
.59785 .66505 m .59919 .66372 L .59788 .66427 L F
.59919 .66372 m .59972 .6632 L .59788 .66427 L F
.47 .856 .649 r
.59892 .66349 m .59788 .66427 L .59994 .6628 L F
.611 .89 .989 r
.59924 .6637 m .59788 .66427 L .59892 .66349 L F
.59984 .66411 m .59866 .66421 L .5993 .66374 L F
.72 .54 .646 r
.59984 .66411 m .60133 .66626 L .59777 .66676 L F
.18 .016 .408 r
.59777 .66676 m .59912 .66635 L .59981 .66337 L F
.59961 .66352 m .59981 .66337 L .59989 .66302 L F
.59777 .66676 m .59981 .66337 L .59961 .66352 L F
.746 .615 .712 r
.59973 .66323 m .59972 .6632 L .60222 .65995 L F
.59972 .6632 m .59972 .66263 L .59997 .66236 L F
.59972 .6632 m .59997 .66236 L .60222 .65995 L F
.18 .016 .408 r
.59972 .6632 m .59989 .66302 L .59994 .6628 L F
.59968 .66327 m .59971 .66324 L .59972 .6632 L F
.59971 .66324 m .59989 .66302 L .59972 .6632 L F
.59777 .66676 m .59989 .66302 L .59968 .66327 L F
.746 .615 .712 r
.59937 .66365 m .5993 .66374 L .59924 .6637 L F
.18 .016 .408 r
.59972 .6632 m .59972 .66295 L .59788 .66427 L F
.746 .615 .712 r
.59973 .66323 m .59924 .6637 L .59892 .66349 L F
.18 .016 .408 r
.59777 .66676 m .59968 .66327 L .59785 .66505 L F
.59968 .66327 m .59972 .6632 L .59785 .66505 L F
.59972 .6632 m .59994 .6628 L .59972 .66295 L F
.746 .615 .712 r
.59973 .66323 m .59892 .66349 L .59972 .66263 L F
.60324 .66211 m .60107 .66454 L .59984 .66411 L F
.572 .599 .841 r
.37343 .67397 m .37165 .67507 L .37103 .67305 L F
.559 .439 .673 r
.37343 .67397 m .37177 .67744 L .37165 .67507 L F
.426 .813 .989 r
.43523 .72589 m .43733 .72557 L .43862 .7261 L F
.354 .759 .983 r
.43733 .72557 m .4407 .72607 L .43862 .7261 L F
.158 0 0 r
.41721 .78639 m .4208 .78472 L .41922 .78596 L F
.269 0 0 r
.4208 .78472 m .42128 .78562 L .41922 .78596 L F
.4208 .78472 m .42288 .7845 L .42128 .78562 L F
.425 .191 .452 r
.33998 .7169 m .33871 .71529 L .34044 .71468 L F
.33998 .7169 m .33822 .7175 L .33871 .71529 L F
.791 .747 .813 r
.701 .60436 m .70429 .60423 L .7035 .60317 L F
.701 .60436 m .70229 .60572 L .70429 .60423 L F
.564 .564 .812 r
.70654 .60303 m .70429 .60423 L .70321 .6002 L F
.976 .716 .306 r
.7035 .60317 m .70429 .60423 L .70321 .6002 L F
.634 .857 .984 r
.7035 .60317 m .70429 .60423 L .70654 .60303 L F
.78 .519 .542 r
.50301 .88186 m .50651 .88381 L .50572 .88084 L F
.50301 .88186 m .50351 .88403 L .50651 .88381 L F
.557 .594 .846 r
.50651 .88381 m .50755 .88086 L .50572 .88084 L F
.50651 .88381 m .50868 .88364 L .50755 .88086 L F
.422 .18 .44 r
.3558 .69835 m .35439 .69694 L .35622 .69651 L F
.3558 .69835 m .35395 .6989 L .35439 .69694 L F
.012 0 .184 r
.51186 .87203 m .51214 .87064 L .513 .87012 L F
.513 .87012 m .51214 .87064 L .51186 .87203 L F
.76 .596 .674 r
.49981 .88098 m .50301 .88186 L .50193 .87824 L F
.842 .772 .784 r
.50063 .87543 m .50193 .87824 L .50352 .87544 L F
.646 .531 .709 r
.50193 .87824 m .50572 .88084 L .50573 .87869 L F
.50193 .87824 m .50301 .88186 L .50572 .88084 L F
.299 0 0 r
.31097 .6779 m .3083 .67789 L .3104 .67784 L F
.31097 .6779 m .30732 .67851 L .3083 .67789 L F
0 0 0 r
.64103 .60571 m .64332 .60343 L .64212 .60476 L F
.291 .142 .5 r
.64488 .59992 m .64623 .60138 L .64462 .60202 L F
.715 .575 .696 r
.64623 .60138 m .64568 .60086 L .64479 .60251 L F
.64568 .60086 m .64288 .59819 L .64459 .60206 L F
.64568 .60086 m .64459 .60206 L .64479 .60251 L F
.3 0 .218 r
.64462 .60202 m .64346 .60329 L .64332 .60343 L F
.64346 .60329 m .64212 .60476 L .64262 .60421 L F
.64346 .60329 m .64262 .60421 L .64332 .60343 L F
.998 .835 .548 r
.64073 .60817 m .64103 .60571 L .63977 .60707 L F
.427 .175 .427 r
.64212 .60476 m .63977 .60707 L .64103 .60571 L F
.601 .555 .775 r
.46261 .74805 m .46328 .74983 L .46556 .74931 L F
.641 .578 .768 r
.46328 .74983 m .46674 .75215 L .46556 .74931 L F
.18 0 0 r
.39089 .7971 m .39256 .79577 L .39457 .79535 L F
.619 .481 .672 r
.33849 .76594 m .3408 .76573 L .34057 .76323 L F
.583 .406 .608 r
.33866 .76849 m .3408 .76573 L .33849 .76594 L F
.587 .772 .968 r
.46398 .72978 m .4619 .73032 L .46046 .72895 L F
.925 .563 .135 r
.7089 .70177 m .70804 .70117 L .70742 .69903 L F
.816 .663 .693 r
.7089 .70177 m .70564 .70153 L .70804 .70117 L F
.7089 .70177 m .70698 .70457 L .70564 .70153 L F
.868 .954 .863 r
.66484 .601 m .66145 .60063 L .6643 .59926 L F
.66484 .601 m .66198 .60227 L .66145 .60063 L F
.558 .678 .919 r
.66606 .59905 m .66484 .601 L .6643 .59926 L F
.66606 .59905 m .66719 .60068 L .66484 .601 L F
.818 .695 .729 r
.61294 .64321 m .61251 .64543 L .60942 .64503 L F
.82 .687 .717 r
.61251 .64543 m .61061 .64812 L .60942 .64503 L F
.87 .711 .682 r
.61262 .63202 m .61382 .63512 L .61209 .63411 L F
.867 .748 .729 r
.61382 .63512 m .61066 .63703 L .61209 .63411 L F
.61382 .63512 m .61234 .6378 L .61066 .63703 L F
.764 .666 .754 r
.61593 .6324 m .61382 .63512 L .61262 .63202 L F
.298 0 .033 r
.41115 .74828 m .40933 .74835 L .41069 .74758 L F
.422 .408 .738 r
.41106 .74802 m .40933 .74835 L .41115 .74828 L F
.808 .854 .884 r
.40913 .74838 m .41069 .74758 L .40933 .74835 L F
.298 0 .033 r
.41115 .74828 m .41069 .74758 L .41261 .74739 L F
.422 .408 .738 r
.41005 .74529 m .40933 .74835 L .41106 .74802 L F
.808 .854 .884 r
.407 .74948 m .40913 .74838 L .40933 .74835 L F
.832 .685 .7 r
.6351 .59454 m .63643 .59766 L .63374 .5975 L F
.755 .622 .712 r
.63637 .59992 m .63374 .5975 L .63643 .59766 L F
.127 0 0 r
.6557 .64864 m .65465 .64991 L .65254 .65059 L F
.108 .659 .699 r
.6557 .64864 m .65647 .64852 L .65465 .64991 L F
.6557 .64864 m .65817 .64825 L .65647 .64852 L F
.517 .087 .162 r
.44425 .73954 m .44312 .74116 L .44085 .74099 L F
0 0 0 r
.44474 .74007 m .44312 .74116 L .44425 .73954 L F
.844 .7 .703 r
.56987 .795 m .56822 .79769 L .57103 .79793 L F
.932 .873 .756 r
.56839 .79977 m .57103 .79793 L .56822 .79769 L F
.56839 .79977 m .56935 .80066 L .57103 .79793 L F
.749 .658 .76 r
.56987 .795 m .57103 .79793 L .57296 .7953 L F
.323 .618 .955 r
.34318 .6545 m .3426 .65567 L .341 .65407 L F
.34318 .6545 m .34434 .65583 L .3426 .65567 L F
0 0 0 r
.64391 .59491 m .64294 .59626 L .64175 .59772 L F
0 .29 .683 r
.64288 .59819 m .64175 .59772 L .64294 .59626 L F
.854 .984 .856 r
.49865 .88789 m .5004 .88629 L .49967 .88561 L F
.745 .967 .934 r
.49967 .88561 m .5004 .88629 L .50351 .88403 L F
.799 .393 .283 r
.69043 .64334 m .68951 .64481 L .68752 .64242 L F
.672 .237 .208 r
.69043 .64334 m .6929 .64511 L .68951 .64481 L F
.809 .931 .558 r
.66113 .60699 m .66089 .60661 L .66156 .6045 L F
.66113 .60699 m .66037 .60823 L .66089 .60661 L F
.304 .369 .765 r
.72348 .70653 m .72439 .70991 L .72471 .70738 L F
.758 .684 .78 r
.61489 .62944 m .61593 .6324 L .61262 .63202 L F
.771 .691 .774 r
.61489 .62944 m .61815 .62974 L .61593 .6324 L F
.677 .727 .888 r
.69888 .60521 m .70229 .60572 L .701 .60436 L F
.743 .606 .705 r
.69888 .60521 m .70026 .60856 L .70229 .60572 L F
.745 .609 .707 r
.70026 .60856 m .70198 .6085 L .70229 .60572 L F
.284 0 .255 r
.33621 .71978 m .33373 .72204 L .33432 .72023 L F
.487 .109 .247 r
.46006 .77136 m .4588 .77328 L .45668 .7733 L F
.612 .275 .375 r
.46218 .77115 m .4588 .77328 L .46006 .77136 L F
.435 .179 .425 r
.34255 .71201 m .3407 .71249 L .34315 .71 L F
.411 .19 .465 r
.34491 .70933 m .34315 .71 L .34531 .70728 L F
.453 .22 .469 r
.34491 .70933 m .34255 .71201 L .34315 .71 L F
.323 .807 .878 r
.41012 .72293 m .40676 .72337 L .40885 .7229 L F
.466 0 0 r
.40885 .7229 m .41217 .72297 L .41012 .72293 L F
.297 0 0 r
.41217 .72297 m .41425 .72299 L .41583 .72238 L F
.58 .079 .03 r
.41583 .72238 m .41425 .72299 L .41759 .72314 L F
.969 .659 .365 r
.68095 .61566 m .68154 .61898 L .6826 .61923 L F
.078 .347 .82 r
.68379 .61878 m .6826 .61923 L .68154 .61898 L F
.68379 .61878 m .68491 .62076 L .6826 .61923 L F
.823 .897 .893 r
.70774 .69598 m .70477 .69657 L .70677 .69495 L F
.853 .63 .599 r
.70774 .69598 m .70497 .69853 L .70477 .69657 L F
.70774 .69598 m .70742 .69903 L .70497 .69853 L F
.543 .878 .99 r
.70908 .69469 m .70774 .69598 L .70677 .69495 L F
.70908 .69469 m .71017 .69524 L .70774 .69598 L F
.232 0 .278 r
.35151 .70137 m .34924 .70397 L .34996 .70216 L F
0 0 .223 r
.39997 .76299 m .40083 .75976 L .40162 .76118 L F
.761 .585 .659 r
.40162 .76118 m .4025 .76382 L .39997 .76299 L F
.558 .613 .864 r
.40282 .76038 m .40162 .76118 L .40083 .75976 L F
.842 .948 .888 r
.40315 .76024 m .40162 .76118 L .40282 .76038 L F
.40315 .76024 m .40239 .76159 L .40162 .76118 L F
.40315 .76024 m .40257 .76075 L .40239 .76159 L F
.055 .155 .652 r
.40239 .76159 m .40214 .76273 L .40162 .76118 L F
.842 .948 .888 r
.40257 .76075 m .40049 .76262 L .40239 .76159 L F
.055 .155 .652 r
.40239 .76159 m .4025 .76382 L .40214 .76273 L F
0 .161 .607 r
.67569 .60518 m .67886 .60744 L .67692 .60567 L F
.623 .618 .825 r
.72112 .61567 m .71762 .61355 L .71983 .61336 L F
.503 .514 .801 r
.72207 .6126 m .72112 .61567 L .71983 .61336 L F
.72207 .6126 m .72318 .61574 L .72112 .61567 L F
.7 .399 .463 r
.7227 .74115 m .72054 .73885 L .72261 .73913 L F
.656 .442 .582 r
.57011 .80622 m .57162 .80639 L .5711 .80302 L F
.733 .697 .817 r
.72287 .71686 m .72145 .7189 L .72034 .71635 L F
.428 .865 .915 r
.34422 .82659 m .34354 .82728 L .34598 .82653 L F
.34422 .82659 m .34354 .82728 L .34598 .82653 L F
.472 .211 .437 r
.3535 .70091 m .352 .69942 L .35395 .6989 L F
.3535 .70091 m .35151 .70137 L .352 .69942 L F
.425 .227 .506 r
.52598 .77595 m .52457 .77359 L .52534 .77189 L F
.373 .113 .386 r
.52824 .77089 m .52534 .77189 L .52589 .77094 L F
.52824 .77089 m .52753 .77306 L .52534 .77189 L F
.481 .274 .521 r
.528 .77547 m .52534 .77189 L .52753 .77306 L F
.528 .77547 m .52598 .77595 L .52534 .77189 L F
.397 .165 .44 r
.36248 .69296 m .36112 .69062 L .36328 .68987 L F
.36248 .69296 m .36076 .6935 L .36112 .69062 L F
.652 .556 .733 r
.41438 .74517 m .41487 .74742 L .41261 .74739 L F
.507 .251 .461 r
.41487 .74742 m .41255 .74974 L .41261 .74739 L F
.614 .323 .451 r
.46779 .7687 m .46434 .77106 L .4663 .76968 L F
.46779 .7687 m .46659 .77122 L .46434 .77106 L F
.59 .297 .439 r
.46989 .77052 m .46779 .7687 L .46984 .76867 L F
.46989 .77052 m .46659 .77122 L .46779 .7687 L F
.62 .437 .614 r
.70027 .61034 m .70198 .6085 L .70026 .60856 L F
.70027 .61034 m .70176 .61002 L .70198 .6085 L F
.55 .579 .837 r
.34609 .85147 m .34812 .85133 L .34619 .85168 L F
.378 .018 .221 r
.34607 .8519 m .34812 .85133 L .34619 .85168 L F
.577 .036 0 r
.53214 .83564 m .53539 .8377 L .53311 .83711 L F
.53214 .83564 m .53311 .83711 L .53201 .83449 L F
.232 .704 .941 r
.42851 .72384 m .43205 .72444 L .42987 .72457 L F
.544 .601 .861 r
.70654 .60303 m .70756 .60569 L .70932 .60413 L F
.459 .454 .765 r
.70756 .60569 m .7095 .6051 L .70932 .60413 L F
.813 .694 .734 r
.61294 .64321 m .61016 .643 L .61183 .64017 L F
.818 .695 .729 r
.61294 .64321 m .60942 .64503 L .61016 .643 L F
.899 .636 .531 r
.53717 .82996 m .53731 .83275 L .53911 .83293 L F
.891 .714 .656 r
.53731 .83275 m .53896 .83495 L .53911 .83293 L F
.515 0 0 r
.73075 .71382 m .73064 .71316 L .72954 .71225 L F
.73075 .71382 m .73339 .71452 L .73064 .71316 L F
.681 .326 .365 r
.36681 .73557 m .36948 .73583 L .37069 .73382 L F
.037 0 0 r
.37069 .73382 m .37121 .73491 L .37301 .73392 L F
.37069 .73382 m .36948 .73583 L .37121 .73491 L F
.262 .558 .932 r
.39333 .78099 m .39259 .78183 L .39076 .78005 L F
.341 .674 .977 r
.39333 .78099 m .39494 .78235 L .39259 .78183 L F
.143 .659 .892 r
.67502 .61037 m .67809 .61098 L .67698 .61059 L F
.67502 .61037 m .67809 .61098 L .67698 .61059 L F
.588 .537 .764 r
.67809 .61098 m .67886 .60744 L .67698 .61059 L F
.67809 .61098 m .68033 .61052 L .67886 .60744 L F
0 0 0 r
.67959 .61069 m .68033 .61052 L .67809 .61098 L F
.67959 .61069 m .67809 .61098 L .67698 .61059 L F
.551 .291 .474 r
.62509 .6618 m .62747 .66333 L .62514 .66341 L F
.604 .238 .321 r
.62761 .66205 m .62747 .66333 L .62509 .6618 L F
.847 .676 .67 r
.62756 .64013 m .62613 .64264 L .62885 .64306 L F
.79 .574 .609 r
.62598 .64491 m .62885 .64306 L .62613 .64264 L F
.62598 .64491 m .6289 .64525 L .62885 .64306 L F
.749 .632 .73 r
.6289 .64525 m .63236 .64344 L .62885 .64306 L F
.805 .664 .707 r
.57144 .81152 m .57127 .81372 L .57386 .8138 L F
.199 0 0 r
.41752 .74315 m .41695 .74211 L .41914 .74186 L F
.542 .878 .989 r
.73914 .73022 m .73694 .73086 L .73785 .73138 L F
.73914 .73022 m .73694 .73086 L .73785 .73138 L F
.403 .085 .309 r
.65249 .59631 m .65177 .59912 L .64971 .59973 L F
.768 .433 .419 r
.65616 .59948 m .65249 .59631 L .65385 .59626 L F
.65616 .59948 m .65385 .59626 L .65424 .59659 L F
.65616 .59948 m .65177 .59912 L .65249 .59631 L F
.465 0 0 r
.65616 .59948 m .65454 .60039 L .65177 .59912 L F
.333 .059 .34 r
.65817 .5975 m .65882 .59769 L .65616 .59948 L F
.65817 .5975 m .65882 .59769 L .65616 .59948 L F
.757 .434 .438 r
.65882 .59769 m .65454 .60039 L .65616 .59948 L F
.715 .321 .301 r
.65454 .60039 m .65624 .60045 L .65297 .60028 L F
.757 .434 .438 r
.65457 .60036 m .65624 .60045 L .65454 .60039 L F
.048 0 0 r
.65299 .60028 m .65624 .60045 L .65513 .6004 L F
.471 0 0 r
.65177 .59912 m .65454 .60039 L .65297 .60028 L F
.048 0 0 r
.65297 .60028 m .65624 .60045 L .65299 .60028 L F
.757 .434 .438 r
.65692 .59888 m .65624 .60045 L .65457 .60036 L F
.65882 .59769 m .65736 .59926 L .65692 .59888 L F
.65736 .59926 m .65624 .60045 L .65692 .59888 L F
.768 .433 .419 r
.65424 .59659 m .65385 .59626 L .65401 .59625 L F
.491 .165 .342 r
.3753 .76251 m .37381 .76125 L .37595 .76092 L F
.3753 .76251 m .37314 .76288 L .37381 .76125 L F
.148 .649 .909 r
.33244 .67547 m .33305 .67529 L .33076 .67512 L F
.33513 .67602 m .33305 .67529 L .33244 .67547 L F
0 0 0 r
.33569 .67438 m .33305 .67529 L .33537 .67495 L F
.33569 .67438 m .3341 .675 L .33305 .67529 L F
.148 .649 .909 r
.33513 .67602 m .33076 .67512 L .33249 .67584 L F
0 0 0 r
.3341 .675 m .33207 .67578 L .33305 .67529 L F
.127 0 0 r
.33305 .67529 m .33185 .67544 L .33076 .67512 L F
0 .432 .76 r
.32944 .67473 m .33249 .67584 L .33076 .67512 L F
.127 0 0 r
.33185 .67544 m .33094 .67556 L .33076 .67512 L F
0 .432 .76 r
.32934 .6747 m .32944 .67473 L .33076 .67512 L F
.393 .184 .474 r
.34692 .7067 m .34531 .70728 L .34734 .7045 L F
.447 .222 .478 r
.34665 .70876 m .34531 .70728 L .34692 .7067 L F
.34665 .70876 m .34491 .70933 L .34531 .70728 L F
0 .005 .536 r
.7146 .7209 m .71443 .72048 L .71229 .71825 L F
.725 .253 0 r
.7146 .7209 m .71587 .72279 L .7151 .72208 L F
.7146 .7209 m .7151 .72208 L .71443 .72048 L F
.277 0 .28 r
.32671 .72819 m .3243 .73065 L .32506 .7289 L F
.529 .412 .664 r
.54577 .809 m .5477 .8087 L .54777 .80502 L F
.545 .422 .663 r
.54604 .81138 m .5477 .8087 L .54577 .809 L F
.384 0 .146 r
.42265 .77605 m .42601 .77375 L .42394 .77413 L F
.553 .548 .802 r
.49035 .7496 m .48834 .74996 L .48717 .74681 L F
.591 .503 .724 r
.49035 .7496 m .48861 .75228 L .48834 .74996 L F
.423 .617 .931 r
.69422 .71343 m .69773 .71546 L .69826 .71511 L F
.42 .53 .863 r
.69773 .71546 m .70053 .71667 L .69925 .7143 L F
0 0 0 r
.69925 .7143 m .69826 .71511 L .69773 .71546 L F
.731 .774 .888 r
.50868 .88364 m .51199 .88381 L .5106 .88279 L F
.774 .766 .845 r
.51199 .88381 m .51284 .88049 L .5106 .88279 L F
.51199 .88381 m .51469 .88175 L .51284 .88049 L F
.434 .104 .306 r
.32071 .71417 m .3234 .71232 L .32134 .71271 L F
.494 .596 .885 r
.71321 .5996 m .71197 .60017 L .71064 .59917 L F
.71321 .5996 m .71415 .60001 L .71197 .60017 L F
.691 .247 .191 r
.64391 .59491 m .64619 .59668 L .64294 .59626 L F
0 0 .52 r
.47791 .87593 m .47882 .87794 L .47809 .87403 L F
.294 .165 .529 r
.47776 .87758 m .47882 .87794 L .47791 .87593 L F
0 0 0 r
.64074 .61857 m .64038 .619 L .63721 .62044 L F
.545 .337 .548 r
.34892 .74994 m .35103 .74961 L .35121 .74735 L F
.462 .246 .5 r
.35121 .74735 m .35311 .74694 L .3534 .74467 L F
.592 .43 .632 r
.35103 .74961 m .35311 .74694 L .35121 .74735 L F
.021 0 0 r
.68474 .60315 m .68148 .60441 L .68365 .60423 L F
.657 .63 .811 r
.70027 .61034 m .70353 .61131 L .70176 .61002 L F
.489 .863 .643 r
.6485 .61448 m .6503 .61312 L .65043 .61313 L F
.717 .266 .18 r
.50216 .88305 m .50301 .88186 L .49981 .88098 L F
.951 .621 .358 r
.50216 .88305 m .50351 .88403 L .50301 .88186 L F
.371 0 .04 r
.34598 .85159 m .34812 .85133 L .34609 .85147 L F
.493 .9 .915 r
.65476 .63513 m .65752 .63447 L .65549 .63514 L F
.687 .98 .839 r
.65229 .63694 m .65549 .63514 L .65273 .63695 L F
.65229 .63694 m .65476 .63513 L .65549 .63514 L F
.727 .402 .429 r
.71229 .71825 m .70929 .71984 L .71009 .71767 L F
.71229 .71825 m .71309 .72063 L .70929 .71984 L F
.308 .176 .532 r
.71229 .71825 m .71443 .72048 L .71309 .72063 L F
.579 .442 .659 r
.3534 .74467 m .35551 .74437 L .35533 .742 L F
.525 .29 .502 r
.35311 .74694 m .35551 .74437 L .3534 .74467 L F
.725 .427 .474 r
.72054 .73885 m .71949 .74134 L .71933 .73918 L F
.7 .399 .463 r
.7227 .74115 m .71949 .74134 L .72054 .73885 L F
.425 .227 .506 r
.52598 .77595 m .52422 .77674 L .52457 .77359 L F
.465 .26 .516 r
.34236 .71411 m .3407 .71249 L .34255 .71201 L F
.34236 .71411 m .34044 .71468 L .3407 .71249 L F
.749 .632 .73 r
.6289 .64525 m .63262 .64553 L .63236 .64344 L F
.751 .61 .701 r
.6289 .64525 m .63049 .64827 L .63262 .64553 L F
.725 .572 .681 r
.63049 .64827 m .63355 .64856 L .63262 .64553 L F
.645 .558 .741 r
.63236 .64344 m .63262 .64553 L .63457 .64295 L F
.688 .619 .774 r
.63262 .64553 m .63559 .64603 L .63457 .64295 L F
.709 .565 .689 r
.63355 .64856 m .63559 .64603 L .63262 .64553 L F
.553 .598 .852 r
.4782 .74213 m .47466 .73937 L .47693 .73908 L F
.517 .508 .785 r
.47916 .73869 m .4782 .74213 L .47693 .73908 L F
.47916 .73869 m .48013 .74192 L .4782 .74213 L F
.594 .332 .49 r
.61965 .66425 m .61723 .66631 L .61737 .66434 L F
.736 .724 .84 r
.44957 .72733 m .44741 .72862 L .44628 .72701 L F
.524 .528 .801 r
.46674 .75215 m .46759 .74899 L .46556 .74931 L F
.46674 .75215 m .46847 .75208 L .46759 .74899 L F
.609 .325 .461 r
.45753 .76236 m .45983 .76253 L .45989 .76089 L F
.635 .364 .491 r
.45983 .76253 m .46138 .76122 L .45989 .76089 L F
.487 .208 .415 r
.37301 .73392 m .3751 .73354 L .37548 .73167 L F
.427 .155 .396 r
.37548 .73167 m .37703 .733 L .37801 .73069 L F
.37548 .73167 m .3751 .73354 L .37703 .733 L F
.079 0 0 r
.36098 .80843 m .36378 .80611 L .36332 .80815 L F
.946 .735 .268 r
.67942 .62899 m .67985 .62967 L .67983 .6319 L F
.773 .681 .762 r
.61711 .62661 m .61815 .62974 L .61489 .62944 L F
.383 .19 .492 r
.60222 .65995 m .6041 .65839 L .60212 .65894 L F
.137 0 .299 r
.66022 .61676 m .65967 .61871 L .66163 .61553 L F
.511 .872 .984 r
.64742 .60428 m .64881 .60471 L .64613 .60531 L F
.909 .905 .808 r
.6464 .60806 m .64742 .60428 L .64613 .60531 L F
.617 .453 .638 r
.36504 .77362 m .36261 .77608 L .36255 .77405 L F
.36504 .77362 m .36543 .7767 L .36261 .77608 L F
.588 .476 .693 r
.36565 .77913 m .36261 .77608 L .36543 .7767 L F
.36565 .77913 m .36353 .77956 L .36261 .77608 L F
.253 0 0 r
.42489 .78395 m .42838 .78195 L .42704 .78304 L F
.163 0 0 r
.42704 .78304 m .42838 .78195 L .43047 .78149 L F
.373 .84 .843 r
.31932 .65149 m .31559 .6524 L .31781 .65158 L F
.615 .942 .947 r
.31932 .65149 m .3197 .65085 L .32164 .65051 L F
.632 .956 .924 r
.31932 .65149 m .31781 .65158 L .3197 .65085 L F
.749 .656 .759 r
.56031 .81392 m .56151 .81706 L .56399 .81448 L F
.745 .651 .756 r
.7049 .72284 m .70598 .72595 L .70262 .72577 L F
.813 .544 .533 r
.70568 .7279 m .70262 .72577 L .70598 .72595 L F
.68 .616 .777 r
.70865 .72399 m .70598 .72595 L .7049 .72284 L F
.993 .744 .41 r
.73393 .717 m .73477 .71525 L .73339 .71452 L F
.73393 .717 m .73479 .71789 L .73477 .71525 L F
.709 .565 .689 r
.63355 .64856 m .63602 .64826 L .63559 .64603 L F
.452 .476 .793 r
.63559 .64603 m .637 .64449 L .63457 .64295 L F
.36 .331 .691 r
.63602 .64826 m .637 .64449 L .63559 .64603 L F
.64 .457 .62 r
.6643 .59926 m .66213 .598 L .66377 .5973 L F
.6643 .59926 m .66145 .60063 L .66213 .598 L F
.241 0 0 r
.73479 .71789 m .73112 .7195 L .73198 .71845 L F
.944 .724 .573 r
.68925 .63405 m .69196 .63503 L .69067 .63245 L F
.737 .482 .543 r
.68836 .63675 m .69196 .63503 L .68925 .63405 L F
.68836 .63675 m .6918 .63704 L .69196 .63503 L F
.462 .408 .712 r
.49504 .76015 m .49406 .76315 L .49269 .76014 L F
.49504 .76015 m .49578 .76348 L .49406 .76315 L F
.687 .588 .739 r
.49697 .76454 m .49406 .76315 L .49578 .76348 L F
.705 .502 .611 r
.60107 .66454 m .60133 .66626 L .59984 .66411 L F
.60107 .66454 m .60318 .667 L .60133 .66626 L F
.412 .062 .258 r
.44102 .77705 m .44036 .77899 L .43823 .77942 L F
.289 0 .208 r
.44222 .77814 m .44102 .77705 L .44351 .7764 L F
.44222 .77814 m .44036 .77899 L .44102 .77705 L F
.564 .414 .636 r
.37314 .76288 m .37116 .76567 L .37175 .76355 L F
.585 .399 .596 r
.48553 .85161 m .48557 .85418 L .48323 .85419 L F
.907 .659 .553 r
.48642 .85092 m .48503 .84967 L .48553 .85161 L F
.48503 .84967 m .48387 .84862 L .48421 .84924 L F
.48503 .84967 m .48421 .84924 L .48553 .85161 L F
.48653 .85083 m .48508 .84962 L .48642 .85092 L F
.526 .335 .565 r
.48503 .84967 m .48614 .84828 L .48387 .84862 L F
.907 .659 .553 r
.48508 .84962 m .48387 .84862 L .4848 .84946 L F
.48508 .84962 m .4848 .84946 L .48642 .85092 L F
.4853 .84981 m .48614 .84828 L .48387 .84862 L F
.48653 .85083 m .48614 .84828 L .4853 .84981 L F
.526 .335 .565 r
.48483 .85067 m .48607 .85071 L .48608 .85022 L F
.48398 .85098 m .48471 .85089 L .48483 .85067 L F
.48471 .85089 m .48607 .85071 L .48483 .85067 L F
.907 .659 .553 r
.48653 .85083 m .48607 .85071 L .48614 .84828 L F
.566 .368 .572 r
.48614 .84828 m .48608 .85022 L .4878 .84952 L F
.48608 .85022 m .48607 .85071 L .48646 .85044 L F
.48608 .85022 m .48646 .85044 L .4878 .84952 L F
.526 .335 .565 r
.48503 .84967 m .48608 .85022 L .48614 .84828 L F
.48398 .85098 m .48608 .85022 L .48503 .84967 L F
.48398 .85098 m .48503 .84967 L .48387 .84862 L F
.449 .293 .576 r
.48731 .85363 m .48553 .85161 L .48653 .85083 L F
.48731 .85363 m .48557 .85418 L .48553 .85161 L F
.543 .416 .657 r
.3441 .69104 m .34587 .68806 L .34387 .68847 L F
.578 .595 .833 r
.48323 .85419 m .48557 .85418 L .48398 .85098 L F
.669 .279 .297 r
.48323 .85419 m .48479 .85606 L .48557 .85418 L F
.48323 .85419 m .48165 .8562 L .48479 .85606 L F
0 0 0 r
.30267 .65676 m .30483 .65615 L .30342 .65638 L F
.267 0 .277 r
.71762 .61355 m .71923 .61447 L .71983 .61336 L F
.71762 .61355 m .71743 .61536 L .71923 .61447 L F
.753 .957 .939 r
.70026 .63735 m .69774 .63801 L .69937 .63666 L F
.948 .926 .75 r
.70026 .63735 m .70108 .63369 L .70225 .63468 L F
.70026 .63735 m .69937 .63666 L .70108 .63369 L F
.384 .18 .476 r
.48318 .84323 m .48488 .84298 L .48321 .84229 L F
.612 .53 .738 r
.49269 .76014 m .49057 .7606 L .48967 .75765 L F
.616 .732 .929 r
.45531 .74092 m .45857 .74174 L .45735 .74036 L F
.444 .608 .917 r
.45857 .74174 m .45964 .74029 L .45735 .74036 L F
.45857 .74174 m .46038 .74164 L .45964 .74029 L F
.612 .448 .636 r
.33029 .77941 m .33275 .77934 L .33282 .77706 L F
.642 .481 .65 r
.33034 .78184 m .33275 .77934 L .33029 .77941 L F
.612 .497 .698 r
.48128 .84668 m .4841 .84602 L .48318 .84323 L F
.449 .274 .551 r
.48183 .84893 m .4841 .84602 L .48128 .84668 L F
.763 .984 .905 r
.6869 .60462 m .68782 .60481 L .68701 .60246 L F
.608 .672 .885 r
.68782 .60481 m .68916 .60206 L .68701 .60246 L F
.68782 .60481 m .68994 .60448 L .68916 .60206 L F
.557 .888 .632 r
.63129 .62464 m .63243 .62349 L .62988 .6257 L F
.712 .589 .717 r
.47072 .75785 m .47308 .75789 L .47324 .75556 L F
.724 .503 .591 r
.47073 .75978 m .47308 .75789 L .47072 .75785 L F
.47073 .75978 m .47299 .76052 L .47308 .75789 L F
.739 .663 .775 r
.47308 .75789 m .47515 .7551 L .47324 .75556 L F
.561 .368 .576 r
.47308 .75789 m .47299 .76052 L .47524 .76008 L F
.598 .507 .723 r
.36095 .66691 m .35891 .66758 L .35814 .66374 L F
.509 .545 .828 r
.36165 .66889 m .35891 .66758 L .36095 .66691 L F
.174 0 .098 r
.32261 .73135 m .32148 .73357 L .31995 .73374 L F
.114 0 .067 r
.32313 .73262 m .32261 .73135 L .3243 .73065 L F
.32313 .73262 m .32148 .73357 L .32261 .73135 L F
.549 .931 .87 r
.4821 .86939 m .48111 .87035 L .48017 .8704 L F
.293 .53 .909 r
.4821 .86939 m .48337 .87112 L .48111 .87035 L F
.415 .523 .859 r
.49822 .76282 m .49697 .76454 L .49578 .76348 L F
.49822 .76282 m .49935 .76557 L .49697 .76454 L F
.54 .822 .998 r
.65095 .58569 m .65045 .5866 L .64933 .58577 L F
0 0 .205 r
.65095 .58569 m .65025 .58874 L .65045 .5866 L F
.656 .598 .778 r
.4849 .74736 m .48152 .74493 L .48368 .74438 L F
.641 .612 .805 r
.48717 .74681 m .4849 .74736 L .48368 .74438 L F
.52 .526 .802 r
.46141 .74486 m .46261 .74805 L .46416 .74635 L F
.601 .555 .775 r
.46261 .74805 m .46556 .74931 L .46416 .74635 L F
.496 .608 .894 r
.68344 .59743 m .68481 .59572 L .68196 .59491 L F
.68344 .59743 m .68549 .59732 L .68481 .59572 L F
.994 .76 .463 r
.64114 .62342 m .6421 .62496 L .64127 .62593 L F
.641 .816 .967 r
.64224 .624 m .6421 .62496 L .64114 .62342 L F
.64224 .624 m .64355 .62448 L .6421 .62496 L F
.163 0 0 r
.6421 .62496 m .64436 .62421 L .64334 .62541 L F
.732 .215 0 r
.64224 .624 m .64334 .62541 L .64146 .62371 L F
.64224 .624 m .64146 .62371 L .64114 .62342 L F
.641 .816 .967 r
.64224 .624 m .64436 .62421 L .64355 .62448 L F
.163 0 0 r
.6421 .62496 m .64334 .62541 L .64127 .62593 L F
.854 .984 .856 r
.49865 .88789 m .49967 .88561 L .49754 .88738 L F
.427 .215 .486 r
.34897 .70598 m .34734 .7045 L .34924 .70397 L F
.34897 .70598 m .34692 .7067 L .34734 .7045 L F
.47 .249 .496 r
.34666 .75269 m .3486 .75232 L .34892 .74994 L F
.571 .337 .523 r
.34892 .74994 m .35082 .75201 L .35103 .74961 L F
.34892 .74994 m .3486 .75232 L .35082 .75201 L F
.569 .033 0 r
.49145 .8808 m .49438 .88096 L .49252 .88045 L F
.58 .588 .826 r
.65013 .59276 m .65166 .59214 L .64829 .59172 L F
.65013 .59276 m .64939 .59483 L .65166 .59214 L F
.624 .455 .633 r
.64939 .59483 m .65215 .59524 L .65166 .59214 L F
.481 .666 .944 r
.65384 .59148 m .65166 .59214 L .65261 .59048 L F
.416 .345 .67 r
.65166 .59214 m .65384 .59389 L .65384 .59148 L F
.609 .597 .814 r
.65384 .59389 m .65261 .59048 L .65166 .59214 L F
.463 .343 .631 r
.65166 .59214 m .65215 .59524 L .65384 .59389 L F
.299 .447 .842 r
.56467 .80861 m .56283 .80738 L .56569 .80634 L F
.299 0 0 r
.31097 .6779 m .30926 .67865 L .30732 .67851 L F
.329 0 .003 r
.31241 .67703 m .30926 .67865 L .31097 .6779 L F
.565 .135 .183 r
.68524 .6972 m .68813 .69611 L .68591 .69818 L F
.194 0 .288 r
.33267 .72448 m .33179 .72302 L .33373 .72204 L F
.33267 .72448 m .33124 .72545 L .33179 .72302 L F
.727 .661 .785 r
.4675 .75762 m .47072 .75785 L .46964 .75536 L F
.719 .419 .469 r
.4675 .75762 m .46937 .76005 L .47072 .75785 L F
.76 .676 .77 r
.46964 .75536 m .47072 .75785 L .47324 .75556 L F
.847 .588 .547 r
.47072 .75785 m .46937 .76005 L .47073 .75978 L F
.246 0 0 r
.40058 .79391 m .40003 .79272 L .40203 .7922 L F
.40058 .79391 m .39861 .79443 L .40003 .79272 L F
.634 .743 .927 r
.48148 .86208 m .48264 .86286 L .48421 .862 L F
.42 .556 .885 r
.35835 .66129 m .35814 .66374 L .35636 .66128 L F
.35835 .66129 m .35978 .66367 L .35814 .66374 L F
.598 .507 .723 r
.36095 .66691 m .35814 .66374 L .35978 .66367 L F
.522 .165 .302 r
.4663 .76968 m .46434 .77106 L .46218 .77115 L F
.841 .847 .849 r
.37784 .7804 m .37467 .78175 L .37713 .78004 L F
.324 .562 .923 r
.3785 .77934 m .37784 .7804 L .37713 .78004 L F
.3785 .77934 m .38042 .78144 L .37784 .7804 L F
.519 .782 .992 r
.34598 .82653 m .34869 .82715 L .34796 .82648 L F
.34598 .82653 m .34869 .82715 L .34796 .82648 L F
.756 .598 .68 r
.4025 .76382 m .40123 .76533 L .39997 .76299 L F
.885 .829 .786 r
.40239 .76159 m .40123 .76533 L .4025 .76382 L F
0 .142 .595 r
.63059 .63311 m .63115 .63346 L .62885 .63321 L F
.559 .667 .91 r
.33347 .65392 m .33029 .65266 L .33266 .65226 L F
.343 .517 .884 r
.33419 .65241 m .33347 .65392 L .33266 .65226 L F
.498 .704 .962 r
.33419 .65241 m .33551 .65377 L .33347 .65392 L F
.261 .483 .884 r
.48069 .85725 m .48345 .85849 L .48165 .8562 L F
.58 .588 .826 r
.65013 .59276 m .65215 .59524 L .64939 .59483 L F
.444 .405 .72 r
.71528 .61637 m .71779 .61807 L .71743 .61536 L F
.452 .404 .713 r
.71528 .61637 m .7163 .61906 L .71779 .61807 L F
.487 .18 .371 r
.63274 .65909 m .6317 .66103 L .6304 .66113 L F
.277 0 .131 r
.635 .65873 m .6317 .66103 L .63274 .65909 L F
.399 0 .016 r
.42796 .77307 m .43015 .77296 L .43159 .77149 L F
.456 .029 .139 r
.43015 .77296 m .43368 .77112 L .43159 .77149 L F
.973 .741 .527 r
.70146 .71809 m .70049 .71912 L .70053 .71667 L F
.692 .729 .879 r
.70053 .71667 m .70146 .71809 L .70394 .71726 L F
.739 .68 .793 r
.56031 .81392 m .56399 .81448 L .56268 .81153 L F
.75 .685 .788 r
.56268 .81153 m .56399 .81448 L .56569 .81208 L F
.792 .613 .658 r
.51284 .88049 m .51663 .87855 L .513 .87814 L F
.51284 .88049 m .51512 .87978 L .51663 .87855 L F
.558 .407 .632 r
.52789 .76833 m .52589 .77094 L .52574 .76869 L F
.52789 .76833 m .52589 .77094 L .52574 .76869 L F
.596 .54 .762 r
.34607 .8519 m .34812 .85133 L .34598 .85159 L F
.737 .991 .829 r
.37004 .80379 m .37095 .80368 L .37238 .80233 L F
.63 .939 .96 r
.36719 .80481 m .37184 .80357 L .37095 .80368 L F
0 0 0 r
.36719 .80481 m .37095 .80368 L .36888 .80452 L F
.737 .991 .829 r
.36888 .80452 m .37095 .80368 L .37004 .80379 L F
.63 .939 .96 r
.37184 .80357 m .37185 .80357 L .37095 .80368 L F
.633 .919 .978 r
.37238 .80233 m .37185 .80357 L .37372 .80267 L F
.737 .992 .829 r
.37095 .80368 m .37185 .80357 L .37238 .80233 L F
.579 .435 .65 r
.3408 .76573 m .34281 .76291 L .34057 .76323 L F
.561 0 0 r
.428 .74172 m .42654 .74118 L .42602 .74063 L F
.294 .636 .965 r
.428 .74172 m .42862 .7408 L .42654 .74118 L F
.369 0 .1 r
.42862 .7408 m .42707 .74176 L .42654 .74118 L F
.42707 .74176 m .42521 .74291 L .42654 .74118 L F
.561 0 0 r
.42602 .74063 m .42654 .74118 L .42435 .7397 L F
.294 .636 .965 r
.428 .74172 m .42994 .74189 L .42862 .7408 L F
.76 .676 .77 r
.46964 .75536 m .47324 .75556 L .47163 .75463 L F
.672 .742 .903 r
.47163 .75463 m .47324 .75556 L .47515 .7551 L F
.31 .406 .799 r
.72102 .61846 m .7236 .62031 L .72217 .62151 L F
0 .041 .561 r
.72373 .62265 m .72217 .62151 L .7236 .62031 L F
.72373 .62265 m .7229 .62414 L .72217 .62151 L F
0 .559 .804 r
.71378 .73658 m .71292 .7363 L .71054 .73596 L F
.266 .57 .938 r
.71378 .73658 m .71508 .73577 L .71292 .7363 L F
.71378 .73658 m .7166 .73723 L .71508 .73577 L F
.913 .778 .699 r
.67754 .71468 m .6798 .71445 L .67849 .71743 L F
.606 .395 .568 r
.68033 .61052 m .68103 .60836 L .67886 .60744 L F
.652 .754 .924 r
.71658 .60868 m .71774 .60641 L .71551 .60698 L F
.71658 .60868 m .71874 .60781 L .71774 .60641 L F
.716 .326 .31 r
.56467 .80861 m .56683 .81064 L .56793 .8088 L F
.992 .762 .488 r
.56793 .8088 m .56683 .81064 L .56797 .8112 L F
.688 .573 .721 r
.56797 .8112 m .57021 .80839 L .56793 .8088 L F
.609 .571 .787 r
.4737 .73683 m .47165 .73743 L .47029 .73405 L F
.572 .595 .838 r
.47466 .73937 m .47165 .73743 L .4737 .73683 L F
.591 .503 .724 r
.49035 .7496 m .49131 .75279 L .48861 .75228 L F
.565 .444 .674 r
.49131 .75279 m .48925 .75543 L .48861 .75228 L F
.628 .902 .985 r
.67928 .58841 m .67556 .58904 L .67808 .5902 L F
.668 .631 .804 r
.67797 .59096 m .68058 .59028 L .68052 .59009 L F
.513 .068 .131 r
.67961 .59015 m .67928 .58841 L .67808 .5902 L F
.68017 .59013 m .6801 .59 L .67961 .59015 L F
.6801 .59 m .67928 .58841 L .67961 .59015 L F
.68052 .59009 m .67928 .58841 L .68014 .59008 L F
.68076 .59006 m .68062 .5899 L .68052 .59009 L F
.68062 .5899 m .67928 .58841 L .68052 .59009 L F
.68029 .59012 m .68014 .59008 L .68017 .59013 L F
.68052 .59009 m .68014 .59008 L .68029 .59012 L F
.68062 .5899 m .68142 .5886 L .67928 .58841 L F
.604 .588 .808 r
.67956 .58718 m .68017 .59013 L .67808 .5902 L F
.668 .631 .804 r
.6783 .59016 m .68015 .59008 L .67956 .58718 L F
.68015 .59008 m .68052 .59007 L .67956 .58718 L F
.992 .741 .437 r
.67956 .58718 m .68052 .59007 L .68047 .59003 L F
.604 .588 .808 r
.67956 .58718 m .6805 .59012 L .68017 .59013 L F
.992 .741 .437 r
.67956 .58718 m .68047 .59003 L .67943 .589 L F
.668 .631 .804 r
.67821 .59039 m .68052 .59009 L .68052 .59007 L F
.992 .741 .437 r
.68052 .59007 m .68052 .59009 L .68051 .59008 L F
.513 .068 .131 r
.68081 .59011 m .68076 .59006 L .68017 .59013 L F
.604 .588 .808 r
.67956 .58718 m .68081 .59011 L .6805 .59012 L F
.992 .741 .437 r
.68052 .59007 m .68051 .59008 L .67943 .589 L F
.513 .068 .131 r
.68076 .59006 m .68175 .58863 L .68142 .5886 L F
.68076 .59006 m .68142 .5886 L .68062 .5899 L F
.68081 .59011 m .68085 .59005 L .68076 .59006 L F
.68085 .59005 m .68175 .58863 L .68076 .59006 L F
.668 .631 .804 r
.67821 .59039 m .68052 .59007 L .6783 .59016 L F
.992 .741 .437 r
.68052 .59009 m .68048 .59016 L .67943 .589 L F
.439 0 .091 r
.68325 .58876 m .68175 .58863 L .68081 .59011 L F
.68325 .58876 m .68081 .59011 L .68289 .58759 L F
.776 .673 .749 r
.68289 .58759 m .68081 .59011 L .67956 .58718 L F
.149 .539 .923 r
.67943 .589 m .68048 .59016 L .68205 .59049 L F
.68048 .59016 m .68058 .59028 L .68142 .5904 L F
.992 .741 .437 r
.68052 .59009 m .68058 .59028 L .68048 .59016 L F
.149 .539 .923 r
.68048 .59016 m .68142 .5904 L .68205 .59049 L F
.312 .438 .829 r
.67808 .5902 m .67556 .58904 L .67688 .58775 L F
.604 .588 .808 r
.67956 .58718 m .67808 .5902 L .67688 .58775 L F
.668 .631 .804 r
.67797 .59096 m .67956 .58718 L .67688 .58775 L F
.67797 .59096 m .67688 .58775 L .67943 .589 L F
.707 .915 .966 r
.67697 .59025 m .67765 .59074 L .67943 .589 L F
.67765 .59074 m .67797 .59096 L .67827 .59055 L F
.67765 .59074 m .67827 .59055 L .67943 .589 L F
.668 .631 .804 r
.67797 .59096 m .68052 .59009 L .67821 .59039 L F
.4 0 .042 r
.63259 .64995 m .63602 .64826 L .63355 .64856 L F
.63259 .64995 m .63488 .64977 L .63602 .64826 L F
.36 .331 .691 r
.63602 .64826 m .6376 .64737 L .637 .64449 L F
.551 .265 .434 r
.63488 .64977 m .6376 .64737 L .63602 .64826 L F
.177 .503 .909 r
.693 .59477 m .69133 .59424 L .68975 .59252 L F
.754 .424 .426 r
.70759 .71496 m .70936 .71505 L .70864 .71689 L F
.829 .513 .455 r
.70864 .71689 m .70936 .71505 L .71009 .71767 L F
.612 .558 .77 r
.49144 .75506 m .48967 .75765 L .48925 .75543 L F
.49144 .75506 m .49368 .76018 L .48967 .75765 L F
.612 .53 .738 r
.49269 .76014 m .48967 .75765 L .49368 .76018 L F
.788 .313 .099 r
.68379 .63736 m .68351 .63862 L .68159 .63634 L F
.878 .676 .626 r
.68616 .63705 m .68351 .63862 L .68379 .63736 L F
.643 .913 .981 r
.33789 .81455 m .33669 .8159 L .3364 .81561 L F
.33789 .81455 m .33843 .81606 L .33669 .8159 L F
.33789 .81455 m .33915 .81399 L .33853 .81324 L F
.33789 .81455 m .33853 .81324 L .33843 .81606 L F
.574 .417 .63 r
.34666 .75269 m .3489 .75475 L .3486 .75232 L F
.34666 .75269 m .34678 .7551 L .3489 .75475 L F
.601 .688 .904 r
.45498 .72813 m .45287 .7286 L .452 .72708 L F
.421 .551 .881 r
.69633 .59593 m .69479 .59729 L .693 .59477 L F
.69633 .59593 m .69651 .59718 L .69479 .59729 L F
.622 .613 .821 r
.48368 .74438 m .48152 .74493 L .48013 .74192 L F
.247 .664 .963 r
.7158 .7072 m .71705 .70708 L .71462 .70633 L F
.282 .116 .471 r
.7158 .7072 m .71569 .70937 L .71705 .70708 L F
.543 .359 .581 r
.36738 .77113 m .36738 .77336 L .36504 .77362 L F
.581 .427 .638 r
.36748 .77636 m .36504 .77362 L .36738 .77336 L F
.36748 .77636 m .36543 .7767 L .36504 .77362 L F
.208 .715 .899 r
.34409 .81923 m .34453 .81949 L .34113 .81929 L F
.686 .29 .291 r
.34113 .81929 m .34453 .81949 L .343 .82137 L F
.374 .828 .929 r
.34403 .81909 m .34453 .81949 L .34409 .81923 L F
.921 .944 .594 r
.343 .82137 m .34453 .81949 L .34403 .81909 L F
.813 .544 .533 r
.70568 .7279 m .70279 .72793 L .70262 .72577 L F
.831 .713 .735 r
.70568 .7279 m .70363 .73155 L .70279 .72793 L F
.674 .645 .813 r
.71146 .72592 m .70865 .72399 L .71056 .72287 L F
.668 .588 .756 r
.71389 .72367 m .71146 .72592 L .71056 .72287 L F
.388 0 .067 r
.40188 .78143 m .40402 .78121 L .40542 .77956 L F
.349 0 .011 r
.40402 .78121 m .40762 .77939 L .40542 .77956 L F
.407 0 0 r
.71379 .69638 m .71338 .69602 L .71252 .69505 L F
.71379 .69638 m .71486 .69689 L .71338 .69602 L F
.688 .613 .766 r
.36915 .78158 m .3671 .78408 L .36701 .78209 L F
.36915 .78158 m .37035 .78473 L .3671 .78408 L F
.461 .598 .902 r
.69422 .71343 m .69584 .71172 L .69381 .71194 L F
.69422 .71343 m .69826 .71511 L .69584 .71172 L F
.421 .782 .996 r
.65967 .61871 m .65854 .61796 L .65739 .61887 L F
.65967 .61871 m .65854 .61796 L .65739 .61887 L F
.009 0 0 r
.40433 .75023 m .40052 .75064 L .40077 .74993 L F
.40433 .75023 m .40179 .75057 L .40052 .75064 L F
0 0 .228 r
.40572 .74782 m .40476 .74869 L .40518 .74612 L F
.512 .899 .74 r
.40572 .74782 m .4053 .74807 L .40476 .74869 L F
0 .104 .654 r
.40476 .74869 m .40405 .74951 L .40285 .74635 L F
.40476 .74869 m .40285 .74635 L .40518 .74612 L F
.512 .899 .74 r
.4053 .74807 m .40278 .74963 L .40476 .74869 L F
0 .104 .654 r
.40476 .74869 m .40433 .75023 L .40405 .74951 L F
.706 .982 .897 r
.40476 .74869 m .40179 .75057 L .40433 .75023 L F
.673 .287 .307 r
.63049 .64827 m .63259 .64995 L .63355 .64856 L F
.497 .584 .873 r
.48901 .86767 m .48899 .86756 L .48727 .86883 L F
.48901 .86767 m .48869 .87 L .48899 .86756 L F
.637 .624 .82 r
.36915 .78158 m .36701 .78209 L .36565 .77913 L F
.985 .707 .353 r
.63977 .60707 m .64105 .61013 L .64073 .60817 L F
.725 .508 .597 r
.64407 .61054 m .64073 .60817 L .64105 .61013 L F
.729 .418 .453 r
.47878 .76843 m .47735 .77064 L .47538 .76833 L F
.657 .33 .407 r
.48091 .77028 m .47878 .76843 L .48076 .76877 L F
.48091 .77028 m .47735 .77064 L .47878 .76843 L F
.106 .657 .805 r
.44967 .73977 m .44901 .73967 L .4462 .73974 L F
.189 .695 .904 r
.44967 .73977 m .45017 .73938 L .44901 .73967 L F
.44967 .73977 m .45176 .73977 L .45017 .73938 L F
.658 .697 .875 r
.72465 .72298 m .72833 .72375 L .7269 .72312 L F
.591 .844 .993 r
.7269 .72312 m .72833 .72375 L .72927 .72258 L F
.242 0 .183 r
.59994 .6628 m .60222 .65995 L .59892 .66349 L F
.59994 .6628 m .6013 .66282 L .60222 .65995 L F
0 0 .07 r
.60222 .65995 m .60345 .66017 L .60411 .65982 L F
.372 .037 .262 r
.37801 .73069 m .37897 .73251 L .38011 .7302 L F
.37801 .73069 m .37703 .733 L .37897 .73251 L F
.308 .795 .889 r
.66555 .64355 m .66599 .64294 L .66399 .64333 L F
.66555 .64355 m .66775 .64313 L .66599 .64294 L F
.531 .75 .976 r
.68994 .60448 m .69338 .60535 L .69223 .60243 L F
.684 .661 .821 r
.69223 .60243 m .69338 .60535 L .69571 .6045 L F
.679 .641 .805 r
.69338 .60535 m .69674 .60579 L .69571 .6045 L F
.331 0 .203 r
.70599 .63796 m .70568 .63907 L .70348 .6398 L F
.395 0 0 r
.70599 .63796 m .70778 .63903 L .70568 .63907 L F
.70599 .63796 m .70775 .6386 L .70778 .63903 L F
.401 0 .057 r
.70858 .63775 m .70775 .6386 L .70599 .63796 L F
.736 .324 .268 r
.6918 .63704 m .69426 .63932 L .69491 .63758 L F
.177 0 0 r
.69544 .63781 m .69491 .63758 L .69426 .63932 L F
.863 .939 .869 r
.69544 .63781 m .69338 .63856 L .69393 .6377 L F
.69544 .63781 m .69393 .6377 L .69526 .63562 L F
.177 0 0 r
.69544 .63781 m .69774 .63801 L .69739 .63796 L F
.69544 .63781 m .69739 .63796 L .69491 .63758 L F
.565 .646 .889 r
.36588 .67371 m .36242 .67202 L .36418 .67177 L F
.553 .679 .922 r
.3678 .67326 m .36588 .67371 L .36418 .67177 L F
.463 .259 .517 r
.36974 .6802 m .36961 .68276 L .36757 .68316 L F
.565 .382 .592 r
.3691 .68333 m .36757 .68316 L .36961 .68276 L F
.3691 .68333 m .36739 .68523 L .36757 .68316 L F
.76 .41 .391 r
.69379 .70084 m .69655 .69958 L .69389 .69829 L F
.69379 .70084 m .69697 .70112 L .69655 .69958 L F
.676 .362 .435 r
.60956 .6667 m .60877 .66887 L .60663 .66683 L F
.666 .351 .431 r
.61192 .66871 m .60956 .6667 L .61197 .66671 L F
.61192 .66871 m .60877 .66887 L .60956 .6667 L F
.498 .329 .581 r
.37177 .67744 m .37175 .67979 L .36974 .6802 L F
.508 .296 .526 r
.37043 .68218 m .36974 .6802 L .37175 .67979 L F
.37043 .68218 m .36961 .68276 L .36974 .6802 L F
.574 .717 .94 r
.33058 .65032 m .33029 .65266 L .32865 .65063 L F
.33058 .65032 m .33266 .65226 L .33029 .65266 L F
.678 .607 .769 r
.37214 .78374 m .37035 .78473 L .36915 .78158 L F
.147 0 .02 r
.64624 .58825 m .6452 .58753 L .64404 .58865 L F
.64624 .58825 m .64716 .58646 L .6452 .58753 L F
.57 .422 .64 r
.33448 .77403 m .33685 .77412 L .33634 .77103 L F
.532 .372 .609 r
.33469 .77666 m .33685 .77412 L .33448 .77403 L F
.525 .642 .907 r
.48449 .88701 m .48552 .88528 L .48338 .886 L F
.48449 .88701 m .48676 .88687 L .48552 .88528 L F
.571 .557 .8 r
.47578 .73626 m .47466 .73937 L .4737 .73683 L F
.47578 .73626 m .47693 .73908 L .47466 .73937 L F
.53 .195 .344 r
.45404 .77373 m .45114 .77571 L .45162 .77457 L F
.559 .358 .565 r
.35758 .73915 m .35958 .74119 L .35965 .73868 L F
.35758 .73915 m .35746 .74162 L .35958 .74119 L F
.385 0 .075 r
.3822 .72995 m .38575 .72793 L .38286 .72902 L F
.3822 .72995 m .38441 .72971 L .38575 .72793 L F
.544 .171 .284 r
.38441 .72971 m .3878 .72753 L .38575 .72793 L F
.913 .981 .745 r
.65577 .59118 m .65469 .59369 L .6575 .59247 L F
.65577 .59118 m .65384 .59389 L .65469 .59369 L F
.588 .722 .936 r
.46722 .73082 m .46398 .72978 L .46598 .72967 L F
.542 .76 .978 r
.46808 .72929 m .46722 .73082 L .46598 .72967 L F
.46808 .72929 m .46948 .73044 L .46722 .73082 L F
.351 .808 .939 r
.46722 .73082 m .46948 .73044 L .46896 .73058 L F
.434 0 0 r
.68668 .62032 m .68379 .61878 L .6839 .61818 L F
0 0 0 r
.68712 .6201 m .68785 .61994 L .68784 .61989 L F
.68519 .62068 m .68686 .62022 L .68712 .6201 L F
.68686 .62022 m .68785 .61994 L .68712 .6201 L F
.68491 .62076 m .68533 .62065 L .68519 .62068 L F
.68533 .62065 m .68785 .61994 L .68519 .62068 L F
.345 0 0 r
.68785 .61994 m .68984 .62095 L .68784 .61989 L F
.758 .495 .535 r
.68729 .62259 m .68984 .62095 L .68785 .61994 L F
0 0 .06 r
.68782 .62091 m .68717 .62119 L .68841 .61901 L F
.791 .693 .757 r
.68566 .62185 m .68723 .62048 L .68669 .62078 L F
.68723 .62048 m .68785 .61994 L .68713 .62046 L F
.68723 .62048 m .68713 .62046 L .68669 .62078 L F
.68566 .62185 m .68729 .62259 L .68785 .61994 L F
0 0 .06 r
.68717 .62119 m .68669 .62078 L .68701 .62045 L F
.13 0 0 r
.6872 .62052 m .68785 .61994 L .68702 .62054 L F
.68702 .62054 m .68785 .61994 L .68625 .62039 L F
.68649 .6206 m .68625 .62039 L .68491 .62076 L F
.68702 .62054 m .68625 .62039 L .68649 .6206 L F
.68706 .62045 m .68491 .62076 L .68379 .61878 L F
.6872 .62052 m .68702 .62054 L .68706 .62045 L F
.68702 .62054 m .68491 .62076 L .68706 .62045 L F
.791 .693 .757 r
.68712 .62034 m .68785 .61994 L .68841 .61901 L F
.434 0 0 r
.6866 .62039 m .68672 .62028 L .68654 .62036 L F
.791 .693 .757 r
.68669 .62078 m .68706 .62045 L .68701 .62045 L F
.434 0 0 r
.68728 .62078 m .68689 .62043 L .6866 .62039 L F
.68689 .62043 m .68672 .62028 L .6866 .62039 L F
.791 .693 .757 r
.68669 .62078 m .68702 .62054 L .68706 .62045 L F
.68701 .62045 m .68706 .62045 L .68712 .62034 L F
.68702 .62054 m .68785 .61994 L .68712 .62034 L F
.434 0 0 r
.68712 .62054 m .6872 .62052 L .68706 .62045 L F
.68724 .62064 m .6872 .62052 L .68712 .62054 L F
.728 .956 .667 r
.68841 .61901 m .68785 .61994 L .6872 .62052 L F
0 0 0 r
.68841 .61901 m .6872 .62052 L .68724 .62064 L F
0 0 .06 r
.6874 .62079 m .68724 .62064 L .68841 .61901 L F
0 0 0 r
.68841 .61901 m .68724 .62064 L .68728 .62078 L F
0 0 .06 r
.68724 .62064 m .68701 .62045 L .68841 .61901 L F
.68717 .62119 m .68701 .62045 L .6874 .62079 L F
.434 0 0 r
.68728 .62078 m .68724 .62064 L .68712 .62054 L F
.68689 .62043 m .68706 .62045 L .68672 .62028 L F
.68728 .62078 m .68706 .62045 L .68689 .62043 L F
0 0 .06 r
.68717 .62119 m .68566 .62185 L .68669 .62078 L F
.434 0 0 r
.68654 .62036 m .68672 .62028 L .68379 .61878 L F
.68728 .62078 m .68654 .62036 L .68668 .62032 L F
.68654 .62036 m .68379 .61878 L .68668 .62032 L F
.731 .613 .726 r
.407 .74948 m .40933 .74835 L .40635 .74664 L F
.121 0 0 r
.30864 .65419 m .30981 .65416 L .31031 .65311 L F
.30864 .65419 m .30787 .65498 L .30981 .65416 L F
.435 .451 .777 r
.48493 .87996 m .4833 .88118 L .48212 .87826 L F
.48493 .87996 m .48526 .88129 L .4833 .88118 L F
.518 .582 .859 r
.48839 .8833 m .48562 .88214 L .48637 .88347 L F
.48562 .88214 m .4833 .88118 L .48637 .88347 L F
.527 .914 .928 r
.48839 .8833 m .48637 .88347 L .48864 .88313 L F
.719 .543 .651 r
.48552 .88528 m .48864 .88313 L .48637 .88347 L F
0 0 .254 r
.48679 .8842 m .48637 .88347 L .48727 .88272 L F
.719 .543 .651 r
.48552 .88528 m .48877 .88625 L .48864 .88313 L F
0 0 .254 r
.48654 .88498 m .48637 .88347 L .48679 .8842 L F
.452 .284 .562 r
.48526 .88129 m .48637 .88347 L .4833 .88118 L F
.571 .388 .595 r
.34272 .76056 m .34485 .76024 L .34494 .7579 L F
.567 .403 .619 r
.34281 .76291 m .34485 .76024 L .34272 .76056 L F
.346 .662 .973 r
.72753 .71553 m .72923 .71697 L .72673 .71591 L F
.763 .259 .005 r
.73112 .7195 m .72673 .71591 L .72923 .71697 L F
.858 .613 .566 r
.66037 .60823 m .65908 .60985 L .65872 .60978 L F
.66037 .60823 m .66045 .61078 L .65908 .60985 L F
.04 0 0 r
.3967 .782 m .39969 .78149 L .39755 .78187 L F
.157 0 0 r
.43823 .77942 m .43463 .78038 L .43602 .77934 L F
.821 .755 .79 r
.51284 .88049 m .51469 .88175 L .51512 .87978 L F
.477 0 0 r
.31031 .65311 m .31254 .65357 L .31362 .6531 L F
0 0 0 r
.31362 .6531 m .31472 .65293 L .31559 .6524 L F
.31362 .6531 m .31254 .65357 L .31472 .65293 L F
.342 0 0 r
.39002 .72712 m .39218 .72704 L .39367 .72595 L F
.476 0 .043 r
.39218 .72704 m .39584 .72586 L .39367 .72595 L F
.42 .604 .923 r
.68899 .59069 m .68773 .59205 L .68756 .59088 L F
.373 .529 .882 r
.68975 .59252 m .68773 .59205 L .68899 .59069 L F
.722 .651 .778 r
.69571 .6045 m .69674 .60579 L .69888 .60521 L F
.455 .757 .994 r
.33963 .65315 m .33895 .65435 L .33754 .65348 L F
.33963 .65315 m .341 .65407 L .33895 .65435 L F
.191 0 0 r
.39827 .74942 m .39494 .74983 L .39613 .74948 L F
.507 .251 .461 r
.41487 .74742 m .41464 .74942 L .41255 .74974 L F
.531 .475 .738 r
.41706 .74688 m .41487 .74742 L .41438 .74517 L F
.438 .193 .444 r
.41706 .74688 m .41464 .74942 L .41487 .74742 L F
.619 .305 .416 r
.46984 .76867 m .47193 .77049 L .46989 .77052 L F
.643 .294 .365 r
.46984 .76867 m .4721 .76901 L .47193 .77049 L F
.722 .651 .778 r
.69571 .6045 m .69888 .60521 L .6979 .60368 L F
.679 .743 .899 r
.6979 .60368 m .69888 .60521 L .701 .60436 L F
.553 .353 .564 r
.36682 .68684 m .36578 .68549 L .36739 .68523 L F
.36682 .68684 m .36573 .68787 L .36578 .68549 L F
.562 .381 .594 r
.34494 .7579 m .34701 .7599 L .3469 .75749 L F
.34494 .7579 m .34485 .76024 L .34701 .7599 L F
.696 .917 .969 r
.71696 .71704 m .71789 .71765 L .72034 .71635 L F
.694 .366 .417 r
.71696 .71704 m .72034 .71635 L .71789 .71765 L F
.258 0 0 r
.3197 .65085 m .3223 .65092 L .32164 .65051 L F
.368 .772 .984 r
.3231 .65126 m .32164 .65051 L .3223 .65092 L F
.627 .46 .638 r
.33282 .77706 m .3349 .77901 L .33469 .77666 L F
.33282 .77706 m .33275 .77934 L .3349 .77901 L F
0 0 0 r
.5654 .80725 m .56569 .80634 L .56677 .80581 L F
.5654 .80725 m .56467 .80861 L .56569 .80634 L F
.891 .714 .656 r
.53731 .83275 m .53679 .83501 L .53896 .83495 L F
.948 .852 .713 r
.53644 .83738 m .53896 .83495 L .53679 .83501 L F
.53644 .83738 m .53761 .83797 L .53896 .83495 L F
.671 .613 .782 r
.67458 .59492 m .67467 .59216 L .67578 .59178 L F
.641 .57 .759 r
.56797 .8112 m .56906 .81426 L .57127 .81372 L F
.754 .357 .301 r
.68813 .69611 m .69021 .69837 L .69119 .69732 L F
.603 .166 .183 r
.69119 .69732 m .69021 .69837 L .69389 .69829 L F
.612 .275 .375 r
.46218 .77115 m .46101 .77339 L .4588 .77328 L F
.573 .248 .379 r
.46434 .77106 m .46101 .77339 L .46218 .77115 L F
.674 .233 .196 r
.3231 .65126 m .3267 .65142 L .32465 .65199 L F
.879 .443 .124 r
.71486 .69689 m .71574 .69817 L .71694 .69857 L F
.853 .459 .297 r
.71602 .70016 m .71694 .69857 L .71574 .69817 L F
.71602 .70016 m .7187 .70143 L .71694 .69857 L F
.801 .463 .416 r
.71694 .69857 m .7187 .70143 L .7205 .70136 L F
.571 .796 .984 r
.44408 .7265 m .4407 .72607 L .44282 .7257 L F
.321 .648 .969 r
.44511 .72567 m .44408 .7265 L .44282 .7257 L F
.44511 .72567 m .44628 .72701 L .44408 .7265 L F
.084 .625 .848 r
.41812 .72321 m .4196 .72328 L .42096 .72362 L F
.121 0 0 r
.4196 .72328 m .42304 .72316 L .42096 .72362 L F
.334 0 0 r
.41835 .72354 m .42187 .72338 L .4196 .72328 L F
.42187 .72338 m .42191 .72338 L .4196 .72328 L F
.084 .625 .848 r
.41759 .72314 m .4196 .72328 L .41812 .72321 L F
.658 .366 .465 r
.49438 .88096 m .49657 .88303 L .49891 .88053 L F
.235 0 0 r
.49657 .88303 m .49981 .88098 L .49891 .88053 L F
.736 .724 .84 r
.44957 .72733 m .44628 .72701 L .4481 .72586 L F
.524 .752 .979 r
.45009 .72564 m .44957 .72733 L .4481 .72586 L F
.45009 .72564 m .452 .72708 L .44957 .72733 L F
.89 .73 .676 r
.66049 .59448 m .6586 .59476 L .65912 .59161 L F
0 0 0 r
.66049 .59448 m .65808 .5973 L .65981 .59607 L F
.66049 .59448 m .65981 .59607 L .6586 .59476 L F
.408 .436 .778 r
.66124 .59128 m .66049 .59448 L .65912 .59161 L F
.66124 .59128 m .66215 .59472 L .66049 .59448 L F
.444 .341 .643 r
.50572 .88084 m .50755 .88086 L .50573 .87869 L F
.666 .372 .465 r
.50573 .87869 m .50755 .88086 L .50777 .87875 L F
.444 .341 .643 r
.50572 .88084 m .50755 .88086 L .50573 .87869 L F
.288 .176 .548 r
.65882 .59769 m .65981 .59607 L .65808 .5973 L F
.517 .315 .545 r
.36573 .68787 m .36328 .68987 L .36346 .68844 L F
.349 0 0 r
.32044 .67456 m .31681 .6762 L .31842 .67496 L F
.884 .72 .673 r
.61234 .6378 m .61183 .64017 L .61066 .63703 L F
.171 0 0 r
.40411 .79185 m .40764 .78994 L .40615 .79161 L F
.264 0 0 r
.40764 .78994 m .40813 .79094 L .40615 .79161 L F
.40764 .78994 m .40976 .7897 L .40813 .79094 L F
.588 .33 .494 r
.38275 .91619 m .38167 .91721 L .38049 .91684 L F
.658 .867 .978 r
.38049 .91684 m .38275 .91619 L .38228 .9161 L F
.563 .404 .624 r
.38228 .9161 m .38167 .91721 L .38049 .91684 L F
.854 .778 .776 r
.38233 .916 m .38228 .9161 L .38275 .91619 L F
.38093 .91582 m .38167 .91721 L .38275 .91619 L F
.65 .816 .963 r
.38399 .91539 m .38275 .91619 L .38058 .91516 L F
.658 .867 .978 r
.38228 .9161 m .38275 .91619 L .38399 .91539 L F
.563 .404 .624 r
.38399 .91539 m .38167 .91721 L .38228 .9161 L F
.854 .778 .776 r
.38058 .91516 m .38093 .91582 L .38228 .9161 L F
.38058 .91516 m .38228 .9161 L .38233 .916 L F
.631 .676 .875 r
.70318 .59992 m .70089 .60077 L .70049 .5998 L F
.70318 .59992 m .70321 .6002 L .70089 .60077 L F
.323 .533 .903 r
.71892 .72788 m .72039 .72901 L .71945 .72752 L F
.616 .691 .897 r
.71945 .72752 m .72039 .72901 L .72276 .72824 L F
.449 .274 .551 r
.48183 .84893 m .48387 .84862 L .4841 .84602 L F
.473 .372 .66 r
.48183 .84893 m .48398 .85098 L .48387 .84862 L F
.449 .274 .551 r
.4841 .84602 m .48387 .84862 L .48183 .84893 L F
.924 .533 .2 r
.57162 .80639 m .57237 .80824 L .57345 .80876 L F
.761 .609 .689 r
.57021 .80839 m .57345 .80876 L .57237 .80824 L F
.57021 .80839 m .57144 .81152 L .57345 .80876 L F
.824 .575 .563 r
.53525 .83211 m .53717 .82996 L .53527 .82964 L F
.53525 .83211 m .53731 .83275 L .53717 .82996 L F
.335 0 0 r
.39793 .72553 m .39999 .7253 L .40138 .72379 L F
.409 0 .039 r
.40138 .72379 m .39999 .7253 L .40305 .72436 L F
.783 .568 .61 r
.38815 .75319 m .38555 .7527 L .38806 .75182 L F
.38815 .75319 m .38509 .75465 L .38555 .7527 L F
.297 0 0 r
.36177 .7385 m .36381 .73812 L .36529 .7365 L F
.533 .91 .947 r
.36529 .7365 m .36594 .73561 L .36681 .73557 L F
.584 .85 .505 r
.36529 .7365 m .36381 .73812 L .36594 .73561 L F
.27 .589 .947 r
.6854 .58905 m .68415 .58977 L .68325 .58876 L F
.6854 .58905 m .68756 .59088 L .68415 .58977 L F
.558 .934 .85 r
.37589 .8021 m .37929 .80068 L .37772 .80207 L F
.029 0 0 r
.37772 .80207 m .37929 .80068 L .38118 .79999 L F
.665 .368 .459 r
.49507 .76848 m .49171 .77061 L .49171 .76837 L F
.49507 .76848 m .494 .77103 L .49171 .77061 L F
.682 .387 .467 r
.49715 .7707 m .494 .77103 L .49507 .76848 L F
.705 .383 .429 r
.49715 .76897 m .49715 .7707 L .49507 .76848 L F
.981 .869 .652 r
.6748 .62891 m .67593 .62896 L .67561 .62614 L F
.985 .704 .368 r
.6752 .63079 m .67593 .62896 L .6748 .62891 L F
.6752 .63079 m .67613 .63193 L .67593 .62896 L F
.964 .679 .445 r
.67727 .63319 m .67593 .62896 L .67613 .63193 L F
.738 .726 .84 r
.67593 .62896 m .6792 .62669 L .67561 .62614 L F
.82 .631 .647 r
.62741 .64774 m .63049 .64827 L .6289 .64525 L F
.592 .255 .367 r
.62713 .65011 m .63049 .64827 L .62741 .64774 L F
.62713 .65011 m .62949 .65086 L .63049 .64827 L F
.646 .311 .39 r
.63049 .64827 m .62949 .65086 L .63259 .64995 L F
.323 .533 .903 r
.71892 .72788 m .71945 .72752 L .71647 .72681 L F
.464 .084 .233 r
.43589 .77094 m .4381 .77073 L .43921 .76871 L F
.404 .025 .201 r
.43921 .76871 m .44016 .77044 L .44128 .76829 L F
.43921 .76871 m .4381 .77073 L .44016 .77044 L F
.35 0 .103 r
.49114 .88309 m .49313 .88283 L .49438 .88096 L F
.719 .337 .326 r
.49438 .88096 m .49313 .88283 L .49657 .88303 L F
.838 .969 .884 r
.66343 .61675 m .66387 .61792 L .66612 .61805 L F
.619 .304 .414 r
.48486 .76803 m .48283 .77058 L .48076 .76877 L F
.685 .387 .465 r
.48634 .7705 m .48486 .76803 L .48623 .76849 L F
.48634 .7705 m .48283 .77058 L .48486 .76803 L F
.565 .444 .674 r
.49131 .75279 m .49144 .75506 L .48925 .75543 L F
.627 .195 .201 r
.35822 .8114 m .35795 .81181 L .35641 .81133 L F
.253 .01 .338 r
.35822 .8114 m .36098 .80843 L .3613 .81137 L F
.487 .154 .327 r
.35822 .8114 m .36022 .81284 L .35795 .81181 L F
.35822 .8114 m .3613 .81137 L .36022 .81284 L F
.651 .261 .293 r
.33935 .82693 m .34182 .82699 L .3402 .82584 L F
.487 .507 .804 r
.36302 .6687 m .36242 .67202 L .36165 .66889 L F
.36302 .6687 m .36418 .67177 L .36242 .67202 L F
.752 .52 0 r
.67775 .70965 m .67785 .71101 L .67867 .70831 L F
.67775 .70965 m .67812 .71212 L .67785 .71101 L F
0 .181 .706 r
.36354 .93359 m .36409 .93424 L .36392 .93446 L F
.554 .842 .511 r
.36392 .93446 m .36409 .93424 L .36348 .93491 L F
.938 .757 .285 r
.67928 .62433 m .67871 .6258 L .6774 .62332 L F
.67928 .62433 m .6792 .62669 L .67871 .6258 L F
0 0 0 r
.70164 .64295 m .70035 .64382 L .69829 .64455 L F
.074 0 .265 r
.70348 .6398 m .70329 .64213 L .70164 .64295 L F
.117 0 0 r
.70329 .64213 m .70035 .64382 L .70164 .64295 L F
.437 .307 .605 r
.33236 .7018 m .3341 .70317 L .33399 .7008 L F
.33236 .7018 m .33253 .70395 L .3341 .70317 L F
.182 0 0 r
.67342 .64059 m .66984 .64196 L .67036 .64184 L F
.67342 .64059 m .6721 .64158 L .67223 .64105 L F
.43 .028 .174 r
.67484 .63961 m .67455 .64131 L .6721 .64158 L F
.67484 .63961 m .6721 .64158 L .67342 .64059 L F
.521 .76 .984 r
.6721 .64158 m .67455 .64131 L .67323 .64025 L F
.6721 .64158 m .67323 .64025 L .67193 .64224 L F
.6721 .64158 m .67193 .64224 L .67131 .64321 L F
.182 0 0 r
.67223 .64105 m .6721 .64158 L .66984 .64196 L F
.597 .113 .077 r
.69171 .71199 m .69016 .71233 L .68852 .71168 L F
.848 .915 .879 r
.69278 .70896 m .69171 .71199 L .69381 .71194 L F
.69278 .70896 m .69016 .71233 L .69171 .71199 L F
0 0 .057 r
.71698 .71269 m .71867 .71155 L .71897 .70988 L F
.04 0 .293 r
.71816 .7136 m .71698 .71269 L .71585 .71393 L F
.71816 .7136 m .71867 .71155 L .71698 .71269 L F
.728 .612 .728 r
.71655 .71028 m .71698 .71269 L .71897 .70988 L F
.853 .779 .779 r
.72073 .72575 m .72213 .72616 L .72157 .72344 L F
.616 .691 .897 r
.71945 .72752 m .72213 .72616 L .72073 .72575 L F
.71945 .72752 m .72276 .72824 L .72213 .72616 L F
.82 .76 .797 r
.72157 .72344 m .72213 .72616 L .72465 .72298 L F
.636 .297 .38 r
.48076 .76877 m .48283 .77058 L .48091 .77028 L F
0 0 0 r
.3854 .79931 m .38732 .79852 L .38909 .79782 L F
.41 .483 .824 r
.41559 .74366 m .41706 .74688 L .41438 .74517 L F
.41559 .74366 m .41706 .74688 L .41438 .74517 L F
.701 .394 .454 r
.607 .66851 m .60318 .667 L .60663 .66683 L F
.638 .372 .499 r
.60663 .66683 m .60877 .66887 L .607 .66851 L F
.538 .77 .983 r
.3967 .782 m .39494 .78235 L .39333 .78099 L F
.545 .422 .663 r
.54604 .81138 m .5481 .8111 L .5477 .8087 L F
.415 .646 .953 r
.54604 .81138 m .5497 .81259 L .5481 .8111 L F
.581 .444 .659 r
.35533 .742 m .35551 .74437 L .35746 .74162 L F
.485 0 0 r
.35813 .83598 m .35905 .83551 L .3555 .83528 L F
.35813 .83598 m .35905 .83551 L .3555 .83528 L F
.35 .795 .641 r
.35966 .83516 m .35905 .83551 L .35813 .83598 L F
.35966 .83516 m .35905 .83551 L .35813 .83598 L F
.258 .008 .332 r
.3597 .83657 m .35905 .83551 L .36078 .83562 L F
.69 .37 .429 r
.5006 .77046 m .49715 .76897 L .5005 .76854 L F
.659 .609 .788 r
.50308 .76834 m .5005 .76854 L .49935 .76557 L F
.675 .463 .591 r
.50308 .76834 m .5006 .77046 L .5005 .76854 L F
.52 .585 .861 r
.71344 .60698 m .71432 .60429 L .71226 .60477 L F
.71344 .60698 m .71551 .60698 L .71432 .60429 L F
.081 .499 .899 r
.71933 .73918 m .71871 .73801 L .7166 .73723 L F
.965 .64 .322 r
.71933 .73918 m .71835 .74047 L .71871 .73801 L F
.71933 .73918 m .71949 .74134 L .71835 .74047 L F
.316 0 .065 r
.64245 .6554 m .63934 .65751 L .64027 .65592 L F
.722 .497 .584 r
.5701 .80293 m .56921 .80366 L .56935 .80066 L F
.5701 .80293 m .56935 .80066 L .56839 .79977 L F
.638 .566 .757 r
.55532 .79434 m .55699 .79828 L .55896 .79536 L F
.618 .539 .743 r
.55699 .79828 m .55933 .79799 L .55896 .79536 L F
.338 0 0 r
.55679 .79968 m .55933 .79799 L .55699 .79828 L F
.623 .334 .458 r
.50777 .87875 m .50957 .88013 L .51012 .87815 L F
.50777 .87875 m .50755 .88086 L .50957 .88013 L F
.445 .24 .507 r
.36955 .76857 m .36923 .77077 L .36738 .77113 L F
.478 .307 .571 r
.36907 .77286 m .36738 .77113 L .36923 .77077 L F
.36907 .77286 m .36738 .77336 L .36738 .77113 L F
.788 .669 .733 r
.62486 .6396 m .62756 .64013 L .62815 .63775 L F
.801 .612 .646 r
.62486 .6396 m .62613 .64264 L .62756 .64013 L F
.446 .078 .244 r
.46467 .75884 m .46641 .75939 L .4675 .75762 L F
.747 .419 .427 r
.46641 .75939 m .46937 .76005 L .4675 .75762 L F
.817 .685 .719 r
.60942 .64503 m .61061 .64812 L .60782 .64776 L F
.818 .677 .708 r
.60782 .64776 m .61061 .64812 L .61012 .65035 L F
.767 .622 .699 r
.68408 .72212 m .67979 .72269 L .68025 .72059 L F
.625 .452 .629 r
.33634 .77103 m .339 .77101 L .33866 .76849 L F
.583 .406 .608 r
.33866 .76849 m .34117 .76874 L .3408 .76573 L F
.574 .41 .621 r
.339 .77101 m .34117 .76874 L .33866 .76849 L F
.579 .435 .65 r
.3408 .76573 m .34302 .76577 L .34281 .76291 L F
.563 .392 .608 r
.3408 .76573 m .34311 .76808 L .34302 .76577 L F
.3408 .76573 m .34117 .76874 L .34311 .76808 L F
.628 .723 .915 r
.65912 .59161 m .6575 .59247 L .65577 .59118 L F
.65912 .59161 m .6575 .59247 L .65577 .59118 L F
.845 .777 .785 r
.68383 .71972 m .68733 .71772 L .68571 .71691 L F
.68383 .71972 m .68529 .72077 L .68733 .71772 L F
.565 .135 .183 r
.68524 .6972 m .68718 .6978 L .68813 .69611 L F
.758 .354 .286 r
.68718 .6978 m .69021 .69837 L .68813 .69611 L F
.045 .236 .735 r
.39997 .76299 m .40123 .76533 L .40049 .76262 L F
.856 .794 .79 r
.40049 .76262 m .40123 .76533 L .40239 .76159 L F
.82 .76 .797 r
.72157 .72344 m .72465 .72298 L .72363 .72249 L F
.369 .68 .978 r
.72465 .72298 m .72594 .72209 L .72363 .72249 L F
.72465 .72298 m .7269 .72312 L .72594 .72209 L F
.866 .652 .61 r
.68753 .64017 m .68752 .64242 L .68624 .63959 L F
.546 .3 .494 r
.46188 .763 m .46467 .75884 L .46138 .76122 L F
.46188 .763 m .46424 .76372 L .46467 .75884 L F
.514 .273 .487 r
.46467 .75884 m .4665 .76311 L .46641 .75939 L F
.46467 .75884 m .46424 .76372 L .4665 .76311 L F
.19 .71 .874 r
.32413 .67468 m .32241 .67446 L .32044 .67456 L F
.327 0 0 r
.32413 .67468 m .32391 .67472 L .32241 .67446 L F
.32413 .67468 m .32596 .67543 L .32391 .67472 L F
.752 .691 .793 r
.71569 .70937 m .71897 .70988 L .71705 .70708 L F
.731 .724 .844 r
.71569 .70937 m .71655 .71028 L .71897 .70988 L F
.693 .673 .826 r
.71705 .70708 m .71897 .70988 L .72107 .70919 L F
.742 .689 .145 r
.71897 .70988 m .71912 .70852 L .72107 .70919 L F
.71897 .70988 m .71867 .71155 L .71912 .70852 L F
.622 .208 .235 r
.37121 .73491 m .3751 .73354 L .37301 .73392 L F
.464 .245 .496 r
.34195 .69367 m .34384 .69322 L .3441 .69104 L F
.543 .416 .657 r
.3441 .69104 m .34622 .69063 L .34587 .68806 L F
.48 .25 .487 r
.34384 .69322 m .34622 .69063 L .3441 .69104 L F
.56 .415 .641 r
.33634 .77103 m .33893 .77366 L .339 .77101 L F
.33634 .77103 m .33685 .77412 L .33893 .77366 L F
.455 .603 .909 r
.38161 .78157 m .38133 .7833 L .38042 .78144 L F
.38161 .78157 m .38351 .78359 L .38133 .7833 L F
.69 .37 .429 r
.5006 .77046 m .49715 .7707 L .49715 .76897 L F
.884 .609 .517 r
.57509 .79931 m .57696 .80048 L .57659 .79797 L F
.359 .516 .877 r
.66494 .59595 m .66377 .5973 L .66215 .59472 L F
.265 .373 .787 r
.66494 .59595 m .66606 .59905 L .66377 .5973 L F
.456 .381 .684 r
.66606 .59905 m .6643 .59926 L .66377 .5973 L F
0 0 .223 r
.39997 .76299 m .40049 .76262 L .40083 .75976 L F
.192 .716 .861 r
.43662 .74447 m .43537 .74431 L .43308 .74444 L F
0 .082 .604 r
.43742 .74339 m .43662 .74447 L .43613 .74165 L F
.58 .923 .961 r
.43742 .74339 m .43537 .74431 L .43662 .74447 L F
.235 0 0 r
.49657 .88303 m .49796 .88307 L .49981 .88098 L F
.063 .627 .757 r
.49796 .88307 m .50216 .88305 L .49981 .88098 L F
.513 .36 .61 r
.34567 .68565 m .34753 .6852 L .34727 .68291 L F
.435 .284 .576 r
.34587 .68806 m .34753 .6852 L .34567 .68565 L F
.672 .742 .903 r
.47163 .75463 m .47515 .7551 L .474 .75214 L F
.618 .563 .771 r
.47515 .7551 m .4764 .75191 L .474 .75214 L F
.47515 .7551 m .47735 .75466 L .4764 .75191 L F
.525 .552 .825 r
.47515 .7551 m .47802 .75656 L .47735 .75466 L F
.51 .299 .528 r
.33965 .69634 m .34172 .69589 L .34195 .69367 L F
.355 .169 .484 r
.34195 .69367 m .34332 .69523 L .34384 .69322 L F
.34195 .69367 m .34172 .69589 L .34332 .69523 L F
.186 0 .116 r
.71623 .63265 m .71822 .63165 L .71548 .63409 L F
.609 .313 .443 r
.6304 .66113 m .62747 .66333 L .62761 .66205 L F
0 0 0 r
.72287 .71686 m .7256 .7152 L .72447 .71609 L F
.369 0 0 r
.72447 .71609 m .7256 .7152 L .72753 .71553 L F
.779 .903 .928 r
.48869 .87 m .48676 .87155 L .48629 .87119 L F
.48869 .87 m .48629 .87119 L .48681 .87039 L F
.083 .364 .831 r
.48867 .87276 m .48676 .87155 L .48869 .87 L F
.779 .903 .928 r
.48681 .87039 m .48629 .87119 L .48557 .87064 L F
.48869 .87 m .48557 .87064 L .4855 .87071 L F
.437 .114 .319 r
.48785 .86879 m .48875 .87144 L .48879 .86872 L F
.48727 .86883 m .48753 .86928 L .48785 .86879 L F
.48753 .86928 m .48875 .87144 L .48785 .86879 L F
.889 .924 .839 r
.68221 .72276 m .68529 .72077 L .68383 .71972 L F
.68221 .72276 m .6832 .72314 L .68529 .72077 L F
.473 .313 .583 r
.38272 .75499 m .38065 .75748 L .38042 .75549 L F
.929 .566 .308 r
.72156 .70391 m .72348 .70653 L .72254 .70461 L F
.199 0 .326 r
.7163 .61906 m .71585 .62076 L .71779 .61807 L F
.417 .443 .78 r
.71881 .59868 m .71839 .60238 L .71644 .59933 L F
.71881 .59868 m .7198 .60195 L .71839 .60238 L F
.817 .722 .76 r
.62533 .63755 m .62815 .63775 L .62725 .63513 L F
.788 .669 .733 r
.62486 .6396 m .62815 .63775 L .62533 .63755 L F
.525 .499 .771 r
.35 .65631 m .34811 .65788 L .3477 .65706 L F
.35 .65631 m .34998 .65767 L .34811 .65788 L F
.307 0 0 r
.41721 .78639 m .41395 .78824 L .41514 .78698 L F
.411 0 .007 r
.44322 .7676 m .44544 .76754 L .4469 .76614 L F
.311 0 0 r
.44544 .76754 m .44904 .76583 L .4469 .76614 L F
.584 .739 .95 r
.45176 .73977 m .45531 .74092 L .4541 .73938 L F
.59 .764 .962 r
.4541 .73938 m .45531 .74092 L .45735 .74036 L F
.714 .35 .357 r
.50932 .77125 m .50814 .77309 L .506 .77106 L F
.652 .207 .181 r
.506 .77106 m .50828 .77167 L .50932 .77125 L F
.753 .398 .381 r
.51119 .77333 m .50814 .77309 L .50932 .77125 L F
.31 0 0 r
.50932 .77125 m .50828 .77167 L .51058 .7714 L F
.814 .707 .747 r
.70321 .72389 m .70262 .72577 L .69973 .72515 L F
.85 .574 .519 r
.70262 .72577 m .70019 .7269 L .69973 .72515 L F
.70262 .72577 m .70279 .72793 L .70019 .7269 L F
.694 .575 .717 r
.7049 .72284 m .70262 .72577 L .70321 .72389 L F
.327 .733 .98 r
.34539 .81381 m .34895 .81449 L .34744 .81375 L F
.762 .879 .931 r
.34744 .81375 m .34895 .81449 L .35038 .81311 L F
.594 .332 .49 r
.61965 .66425 m .61961 .66618 L .61723 .66631 L F
.597 .335 .49 r
.61965 .66425 m .62193 .66606 L .61961 .66618 L F
.633 .318 .42 r
.62194 .66442 m .62193 .66606 L .61965 .66425 L F
.969 .72 .504 r
.40083 .75976 m .40049 .76262 L .39924 .75957 L F
.836 .621 .612 r
.40209 .75752 m .40353 .75742 L .40315 .75632 L F
.4014 .75831 m .40147 .75828 L .40209 .75752 L F
.40147 .75828 m .40353 .75742 L .40209 .75752 L F
.4014 .75831 m .40315 .75632 L .40313 .75626 L F
.663 .577 .748 r
.40313 .75626 m .40228 .75758 L .40209 .75752 L F
.40313 .75626 m .40209 .75752 L .39982 .75679 L F
.672 .565 .725 r
.40209 .75752 m .40077 .75902 L .40228 .75758 L F
.39982 .75679 m .40077 .75902 L .40209 .75752 L F
.836 .621 .612 r
.40137 .75833 m .4014 .75831 L .40313 .75626 L F
.569 .923 .953 r
.40083 .75976 m .40195 .75808 L .40353 .75742 L F
.836 .621 .612 r
.40077 .75902 m .40195 .75808 L .40137 .75833 L F
.569 .923 .953 r
.40195 .75808 m .40077 .75902 L .40228 .75758 L F
.40083 .75976 m .40077 .75902 L .40195 .75808 L F
.836 .621 .612 r
.40077 .75902 m .40353 .75742 L .40195 .75808 L F
.569 .923 .953 r
.40195 .75808 m .40228 .75758 L .40353 .75742 L F
.40083 .75976 m .39924 .75957 L .40077 .75902 L F
.558 .613 .864 r
.40282 .76038 m .40083 .75976 L .40353 .75742 L F
.113 .586 .914 r
.67908 .63316 m .67727 .63319 L .67613 .63193 L F
.67908 .63316 m .68016 .63386 L .67727 .63319 L F
.291 .142 .5 r
.64488 .59992 m .64692 .59922 L .64623 .60138 L F
.134 0 .084 r
.41286 .77604 m .4134 .7774 L .41501 .7761 L F
.41286 .77604 m .41163 .77841 L .4134 .7774 L F
.558 .216 .344 r
.45407 .76459 m .45753 .76236 L .45461 .76353 L F
.575 .241 .365 r
.65323 .61018 m .65529 .61067 L .65908 .60985 L F
.23 0 0 r
.33965 .69634 m .33817 .69758 L .34172 .69589 L F
.135 0 0 r
.31995 .73374 m .32148 .73357 L .31885 .73513 L F
.97 .927 .683 r
.63369 .59544 m .6351 .59454 L .63374 .5975 L F
.772 .993 .781 r
.63605 .59276 m .63753 .59208 L .6351 .59454 L F
.766 .981 .728 r
.63369 .59544 m .63605 .59276 L .6351 .59454 L F
.759 .887 .936 r
.35296 .81267 m .35641 .81133 L .35453 .81226 L F
0 .406 .71 r
.35641 .81133 m .35795 .81181 L .35816 .81181 L F
.35641 .81133 m .35816 .81181 L .35453 .81226 L F
.737 .78 .888 r
.36078 .83562 m .36225 .83809 L .3597 .83657 L F
.895 .516 .306 r
.3597 .83657 m .36225 .83809 L .36096 .83808 L F
.062 .377 .842 r
.36328 .83785 m .36225 .83809 L .36078 .83562 L F
.158 .698 .8 r
.36096 .83808 m .36225 .83809 L .36328 .83785 L F
.511 .775 .992 r
.35503 .6603 m .35436 .66161 L .35299 .66077 L F
.35503 .6603 m .35636 .66128 L .35436 .66161 L F
.767 .645 .727 r
.56268 .81153 m .56569 .81208 L .56467 .80861 L F
.286 .341 .745 r
.56467 .80861 m .56651 .81105 L .56622 .81007 L F
.56467 .80861 m .56569 .81208 L .56651 .81105 L F
.56622 .81007 m .56651 .81105 L .56683 .81064 L F
.702 .336 .352 r
.56683 .81064 m .56392 .81078 L .56467 .80861 L F
.959 .628 .338 r
.5654 .80725 m .56683 .81064 L .56467 .80861 L F
.938 .638 .18 r
.5648 .80745 m .56573 .81025 L .5654 .80726 L F
.56539 .80725 m .5654 .80726 L .5654 .80725 L F
.5648 .80745 m .5654 .80726 L .56539 .80725 L F
.677 .928 .971 r
.56683 .81064 m .56569 .81208 L .56797 .8112 L F
.701 .529 .653 r
.55786 .79176 m .56109 .7948 L .56101 .79263 L F
0 .465 .708 r
.72034 .71635 m .72287 .71686 L .72251 .71652 L F
.733 .697 .817 r
.72287 .71686 m .72034 .71635 L .72251 .71652 L F
0 0 0 r
.72287 .71686 m .72447 .71609 L .72251 .71652 L F
0 .11 .662 r
.72505 .71881 m .72287 .71686 L .72251 .71652 L F
.818 .677 .708 r
.60782 .64776 m .61012 .65035 L .60728 .65005 L F
.838 .647 .643 r
.61012 .65035 m .6092 .65329 L .60728 .65005 L F
.356 0 0 r
.42497 .72319 m .42851 .72384 L .42652 .72394 L F
.843 .524 0 r
.70259 .70343 m .70319 .70453 L .70059 .70411 L F
.70259 .70343 m .70363 .70645 L .70319 .70453 L F
.70319 .70453 m .70363 .70645 L .70259 .70343 L F
.698 .613 .757 r
.70564 .70153 m .70698 .70457 L .70319 .70453 L F
.791 .59 .63 r
.62598 .64491 m .62741 .64774 L .6289 .64525 L F
.28 .015 .321 r
.70507 .64114 m .70348 .6398 L .70568 .63907 L F
.70507 .64114 m .70329 .64213 L .70348 .6398 L F
.658 .349 .438 r
.60133 .66626 m .6 .66875 L .59777 .66676 L F
.709 .4 .452 r
.60318 .667 m .6 .66875 L .60133 .66626 L F
.489 .113 .252 r
.70596 .63068 m .70902 .62846 L .70675 .62885 L F
.459 .128 .317 r
.70675 .62885 m .70902 .62846 L .71109 .62724 L F
.559 .439 .673 r
.37343 .67397 m .37378 .67702 L .37177 .67744 L F
.525 .35 .586 r
.37374 .6788 m .37177 .67744 L .37378 .67702 L F
.37374 .6788 m .37175 .67979 L .37177 .67744 L F
.393 .467 .817 r
.38928 .75162 m .38815 .75319 L .38806 .75182 L F
.558 .216 .344 r
.45407 .76459 m .45634 .76471 L .45753 .76236 L F
.617 .289 .393 r
.45634 .76471 m .45983 .76253 L .45753 .76236 L F
.438 .011 .13 r
.64402 .64182 m .64814 .64049 L .64508 .64198 L F
.64402 .64182 m .64768 .64119 L .64814 .64049 L F
.242 0 .198 r
.64944 .6407 m .64814 .64049 L .64768 .64119 L F
.64944 .6407 m .64999 .63956 L .64814 .64049 L F
.692 .729 .879 r
.70053 .71667 m .70394 .71726 L .70405 .71536 L F
.759 .679 .774 r
.64024 .64558 m .64306 .64509 L .64241 .64237 L F
.595 .219 .3 r
.64003 .64692 m .64306 .64509 L .64024 .64558 L F
.64003 .64692 m .64284 .64709 L .64306 .64509 L F
.218 0 .226 r
.64306 .64509 m .64284 .64709 L .64507 .64478 L F
.635 .364 .491 r
.45983 .76253 m .46188 .763 L .46138 .76122 L F
.815 .656 .686 r
.56664 .797 m .56987 .795 L .56647 .79488 L F
.56664 .797 m .56822 .79769 L .56987 .795 L F
.373 .379 .737 r
.71754 .73284 m .71858 .7355 L .71583 .73456 L F
.662 .623 .8 r
.4841 .84602 m .48488 .84298 L .48318 .84323 L F
.678 .607 .769 r
.37214 .78374 m .36915 .78158 L .37134 .78094 L F
.688 .636 .792 r
.37467 .78175 m .37214 .78374 L .37134 .78094 L F
.725 .617 .736 r
.40635 .74664 m .40806 .74428 L .40589 .74448 L F
0 0 0 r
.64252 .61807 m .64552 .61617 L .64441 .61733 L F
.652 .851 .976 r
.64552 .61617 m .64731 .61512 L .64392 .61556 L F
.89 .513 .316 r
.64441 .61733 m .64552 .61617 L .64392 .61556 L F
.573 .215 .323 r
.42435 .7397 m .42328 .74145 L .42108 .74135 L F
.666 .32 .379 r
.42654 .74118 m .42328 .74145 L .42435 .7397 L F
.477 .802 1 r
.43602 .72482 m .43523 .72589 L .43406 .72458 L F
.43602 .72482 m .43733 .72557 L .43523 .72589 L F
0 0 0 r
.71561 .71235 m .71655 .71028 L .71569 .70937 L F
.693 .934 .965 r
.33853 .81324 m .33915 .81399 L .33962 .8137 L F
.557 .145 .216 r
.66145 .60063 m .66009 .60169 L .65834 .60188 L F
.746 .406 .407 r
.66145 .60063 m .66198 .60227 L .66009 .60169 L F
.747 .702 .81 r
.70929 .71984 m .71056 .72287 L .70719 .72239 L F
.759 .676 .77 r
.71056 .72287 m .70865 .72399 L .70719 .72239 L F
.614 .551 .76 r
.71309 .72063 m .71056 .72287 L .70929 .71984 L F
.71309 .72063 m .71387 .72333 L .71056 .72287 L F
.438 .7 .976 r
.71387 .72333 m .71389 .72367 L .71056 .72287 L F
.673 .641 .81 r
.67685 .59435 m .6798 .59522 L .67933 .59361 L F
.54 .655 .91 r
.6798 .59522 m .68131 .59359 L .67933 .59361 L F
.6798 .59522 m .68196 .59491 L .68131 .59359 L F
.737 .65 .763 r
.70177 .72104 m .70321 .72389 L .69988 .7229 L F
.814 .707 .747 r
.70321 .72389 m .69973 .72515 L .69988 .7229 L F
.725 .645 .769 r
.7049 .72284 m .70321 .72389 L .70177 .72104 L F
.807 .624 .655 r
.67264 .60442 m .67524 .6026 L .67271 .60207 L F
.67264 .60442 m .67569 .60518 L .67524 .6026 L F
.99 .888 .574 r
.61199 .63142 m .61262 .63202 L .61209 .63411 L F
.864 .904 .859 r
.61386 .6287 m .61262 .63202 L .61199 .63142 L F
.61386 .6287 m .61489 .62944 L .61262 .63202 L F
.996 .862 .573 r
.70382 .71107 m .7053 .70944 L .70526 .70966 L F
.996 .862 .572 r
.70382 .71107 m .70458 .71182 L .70526 .70966 L F
.996 .862 .573 r
.70382 .71107 m .70458 .71182 L .7053 .70944 L F
.996 .865 .569 r
.7053 .70944 m .70458 .71182 L .70526 .70966 L F
.075 0 0 r
.65025 .65097 m .64946 .65241 L .6476 .65333 L F
.171 0 0 r
.65025 .65097 m .65109 .65157 L .64946 .65241 L F
.65025 .65097 m .65254 .65059 L .65109 .65157 L F
.936 .674 .199 r
.70363 .73155 m .70312 .73136 L .70279 .72793 L F
.585 .014 0 r
.70716 .73372 m .70624 .73349 L .70363 .73155 L F
0 .186 .669 r
.70363 .73155 m .70624 .73349 L .70529 .73252 L F
.70363 .73155 m .70529 .73252 L .70312 .73136 L F
.755 .622 .712 r
.63637 .59992 m .63299 .59967 L .63374 .5975 L F
.772 .54 .583 r
.63637 .59992 m .6331 .6018 L .63299 .59967 L F
.63637 .59992 m .63646 .60224 L .6331 .6018 L F
.767 .862 .92 r
.68691 .71048 m .68636 .7123 L .68852 .71168 L F
.448 .494 .813 r
.68852 .71168 m .68948 .70855 L .68691 .71048 L F
.68852 .71168 m .69016 .71233 L .68948 .70855 L F
.124 0 0 r
.41501 .7761 m .41698 .77645 L .41845 .77671 L F
.238 0 0 r
.41698 .77645 m .42059 .77648 L .41845 .77671 L F
.678 .363 .433 r
.36327 .93423 m .36409 .93424 L .36354 .93359 L F
0 .532 .794 r
.64742 .60428 m .651 .60503 L .64881 .60471 L F
.64742 .60428 m .651 .60503 L .64881 .60471 L F
.414 .051 .236 r
.64881 .60471 m .651 .60503 L .64875 .60579 L F
.909 .905 .808 r
.6464 .60806 m .64881 .60471 L .64742 .60428 L F
.867 .458 .252 r
.64881 .60471 m .64875 .60579 L .64786 .60618 L F
.775 .681 .76 r
.72915 .7335 m .73026 .73647 L .73242 .7337 L F
.347 .82 .772 r
.44722 .73912 m .4462 .73974 L .44901 .73967 L F
.72 .583 .7 r
.72439 .70991 m .72272 .71275 L .72107 .70919 L F
.304 .369 .765 r
.72348 .70653 m .72577 .70839 L .72439 .70991 L F
.566 .782 .98 r
.72577 .70839 m .7267 .70948 L .72439 .70991 L F
0 0 .329 r
.71606 .62357 m .71638 .62344 L .71585 .62076 L F
0 0 0 r
.71606 .62357 m .71524 .62432 L .71638 .62344 L F
.775 .681 .76 r
.72915 .7335 m .73242 .7337 L .73158 .73512 L F
.529 0 0 r
.72939 .73351 m .7312 .73413 L .73242 .7337 L F
.823 .408 .258 r
.7312 .73413 m .73158 .73512 L .73242 .7337 L F
.433 .514 .842 r
.73275 .73209 m .73432 .73518 L .7312 .73413 L F
.73432 .73518 m .73456 .73565 L .7312 .73413 L F
.529 0 0 r
.72915 .7335 m .7312 .73413 L .72939 .73351 L F
.702 .614 .754 r
.65838 .58838 m .65577 .59118 L .65579 .5896 L F
.754 .497 .544 r
.65577 .59118 m .65384 .59148 L .65579 .5896 L F
.509 .125 .247 r
.33094 .67556 m .32921 .67788 L .33049 .67671 L F
.71 .33 .327 r
.33094 .67556 m .33049 .67671 L .33025 .67663 L F
.33094 .67556 m .33025 .67663 L .32923 .67628 L F
.087 0 0 r
.32988 .67715 m .32921 .67788 L .33016 .6766 L F
.32968 .67753 m .33016 .6766 L .33025 .67663 L F
.93 .794 .689 r
.33028 .67672 m .32921 .67788 L .32818 .67674 L F
.33049 .67671 m .32921 .67788 L .33028 .67672 L F
.087 0 0 r
.32968 .67753 m .32921 .67788 L .32988 .67715 L F
.33025 .67663 m .33016 .6766 L .33094 .67556 L F
0 .38 .696 r
.32923 .67628 m .33025 .67663 L .32975 .67646 L F
.33025 .67663 m .33049 .67671 L .3303 .67665 L F
.33025 .67663 m .3303 .67665 L .32975 .67646 L F
.5 .044 .101 r
.32934 .6747 m .32923 .67628 L .32637 .67534 L F
0 .38 .696 r
.32923 .67628 m .32975 .67646 L .32674 .67539 L F
.5 .044 .101 r
.32637 .67534 m .32923 .67628 L .32596 .67543 L F
0 .465 .776 r
.32596 .67543 m .32923 .67628 L .32674 .67539 L F
.93 .794 .689 r
.3303 .67665 m .32818 .67674 L .32674 .67539 L F
.33049 .67671 m .33028 .67672 L .3303 .67665 L F
.33028 .67672 m .32818 .67674 L .3303 .67665 L F
.087 0 0 r
.33207 .67578 m .33014 .6772 L .33094 .67556 L F
.33014 .6772 m .32968 .67753 L .33033 .67651 L F
.33014 .6772 m .33033 .67651 L .33094 .67556 L F
.71 .33 .327 r
.33094 .67556 m .32934 .6747 L .33076 .67512 L F
.33094 .67556 m .32923 .67628 L .32934 .6747 L F
.567 .692 .925 r
.70092 .59684 m .70049 .5998 L .69877 .59696 L F
.70092 .59684 m .70318 .59992 L .70049 .5998 L F
.338 .811 .739 r
.72753 .71553 m .72673 .71591 L .72688 .71568 L F
0 .182 .698 r
.72673 .71591 m .72993 .71815 L .72688 .71568 L F
.763 .259 .005 r
.73112 .7195 m .72976 .71941 L .72673 .71591 L F
0 .182 .698 r
.72673 .71591 m .72976 .71941 L .72993 .71815 L F
.524 .772 .988 r
.45905 .72794 m .45832 .72927 L .45699 .72813 L F
.45905 .72794 m .46046 .72895 L .45832 .72927 L F
.688 .573 .721 r
.56797 .8112 m .57144 .81152 L .57021 .80839 L F
.641 .57 .759 r
.56797 .8112 m .57127 .81372 L .57144 .81152 L F
.629 .168 0 r
.67255 .60846 m .67294 .60883 L .67212 .60767 L F
.048 .225 .724 r
.67212 .60767 m .67393 .60965 L .6728 .60663 L F
.629 .168 0 r
.67255 .60846 m .67212 .60767 L .67246 .60726 L F
.532 .086 .136 r
.52589 .77094 m .5222 .7723 L .52441 .77198 L F
.52589 .77094 m .52253 .77155 L .5222 .7723 L F
.558 .407 .632 r
.52789 .76833 m .52824 .77089 L .52589 .77094 L F
.118 0 0 r
.52441 .77198 m .52824 .77089 L .52589 .77094 L F
.558 .407 .632 r
.52789 .76833 m .52824 .77089 L .52589 .77094 L F
.705 .455 .542 r
.51933 .77921 m .51585 .78115 L .51612 .77889 L F
.51933 .77921 m .51909 .78136 L .51585 .78115 L F
.497 .272 .503 r
.52113 .78089 m .51933 .77921 L .52157 .77892 L F
.52113 .78089 m .51909 .78136 L .51933 .77921 L F
.866 .459 .257 r
.70555 .71295 m .70759 .71496 L .70533 .71446 L F
.912 .811 .734 r
.70759 .71496 m .70595 .71711 L .70533 .71446 L F
.754 .424 .426 r
.70759 .71496 m .70864 .71689 L .70595 .71711 L F
.684 .661 .821 r
.69223 .60243 m .69571 .6045 L .69446 .60194 L F
.64 .779 .947 r
.69571 .6045 m .69665 .60213 L .69446 .60194 L F
.69571 .6045 m .6979 .60368 L .69665 .60213 L F
.579 .638 .873 r
.41255 .74974 m .41346 .74717 L .41115 .74828 L F
.41255 .74974 m .41464 .74942 L .41346 .74717 L F
.745 .388 .377 r
.68365 .60423 m .68614 .60309 L .6869 .60462 L F
.53 .195 .344 r
.45404 .77373 m .45328 .77569 L .45114 .77571 L F
.184 0 0 r
.45668 .7733 m .45328 .77569 L .45404 .77373 L F
.699 .435 .521 r
.47538 .76833 m .47193 .77049 L .4721 .76901 L F
.67 .887 .978 r
.49026 .88808 m .49303 .88746 L .49221 .88634 L F
.621 .59 .798 r
.49303 .88746 m .49445 .88558 L .49221 .88634 L F
.49303 .88746 m .49489 .88783 L .49445 .88558 L F
.437 .733 .989 r
.66442 .62319 m .66576 .62463 L .66377 .62381 L F
.847 .45 0 r
.66576 .62463 m .6654 .62509 L .66433 .62437 L F
.66444 .62408 m .66433 .62437 L .66305 .62351 L F
.66576 .62463 m .66433 .62437 L .66444 .62408 L F
.725 .653 .778 r
.66309 .62557 m .66424 .6287 L .66108 .62821 L F
.769 .676 .76 r
.6662 .62601 m .66424 .6287 L .66309 .62557 L F
.6662 .62601 m .66309 .62557 L .6654 .62509 L F
0 0 0 r
.66309 .62557 m .66205 .62684 L .66415 .62481 L F
.437 .733 .989 r
.66442 .62319 m .66377 .62381 L .66305 .62351 L F
.418 .357 .682 r
.66442 .62319 m .66305 .62351 L .6654 .62509 L F
0 0 0 r
.66309 .62557 m .66475 .62422 L .6654 .62509 L F
.66421 .62467 m .66415 .62481 L .66475 .62422 L F
.66309 .62557 m .66415 .62481 L .66421 .62467 L F
.991 .78 .396 r
.6654 .62509 m .66502 .62262 L .66442 .62319 L F
.814 .985 .713 r
.66699 .62006 m .66661 .62052 L .66492 .622 L F
.66661 .62052 m .66442 .62319 L .66492 .622 L F
.991 .78 .396 r
.66502 .62262 m .66492 .622 L .66442 .62319 L F
.882 .636 .562 r
.66492 .622 m .66475 .62422 L .6634 .62334 L F
.66492 .622 m .6634 .62334 L .66309 .62313 L F
.847 .45 0 r
.66576 .62463 m .6662 .62601 L .6654 .62509 L F
.719 .507 .602 r
.38351 .78359 m .38616 .78333 L .38619 .78149 L F
.467 .049 .161 r
.38619 .78149 m .38841 .7818 L .38867 .78092 L F
.238 .121 .511 r
.38619 .78149 m .38748 .78376 L .38841 .7818 L F
.38619 .78149 m .38616 .78333 L .38748 .78376 L F
.925 .921 .789 r
.61896 .62377 m .61633 .62578 L .61817 .62315 L F
.61896 .62377 m .61711 .62661 L .61633 .62578 L F
.841 .899 .879 r
.62038 .62047 m .61896 .62377 L .61817 .62315 L F
.62038 .62047 m .62142 .62129 L .61896 .62377 L F
.545 .561 .821 r
.46556 .74931 m .46619 .7461 L .46416 .74635 L F
.46556 .74931 m .46759 .74899 L .46619 .7461 L F
.648 .667 .855 r
.67685 .59435 m .67933 .59361 L .67797 .59096 L F
.414 .863 .829 r
.36967 .67302 m .37313 .67199 L .37103 .67305 L F
.572 .599 .841 r
.37343 .67397 m .37103 .67305 L .37313 .67199 L F
.677 .247 .221 r
.44889 .77622 m .44757 .7775 L .44588 .77603 L F
.073 0 0 r
.45008 .77627 m .44889 .77622 L .45114 .77571 L F
.45008 .77627 m .44757 .7775 L .44889 .77622 L F
.381 .199 .505 r
.37102 .76798 m .36923 .77077 L .36955 .76857 L F
.608 .44 .629 r
.637 .64449 m .63785 .64396 L .63457 .64295 L F
.641 .612 .805 r
.48717 .74681 m .48368 .74438 L .48578 .74416 L F
.572 .619 .86 r
.48787 .74381 m .48717 .74681 L .48578 .74416 L F
.48787 .74381 m .48923 .74648 L .48717 .74681 L F
.553 .548 .802 r
.49035 .7496 m .48717 .74681 L .48923 .74648 L F
.642 .481 .65 r
.33034 .78184 m .33279 .78171 L .33275 .77934 L F
.575 .781 .977 r
.33041 .78428 m .33279 .78171 L .33034 .78184 L F
.606 .425 .611 r
.65025 .58874 m .65136 .5919 L .64913 .59044 L F
.609 .597 .814 r
.65384 .59389 m .65122 .59207 L .65306 .59174 L F
.65122 .59207 m .65103 .59193 L .65136 .5919 L F
.65122 .59207 m .65136 .5919 L .65306 .59174 L F
.457 .343 .636 r
.65261 .59048 m .65136 .5919 L .65025 .58874 L F
.606 .425 .611 r
.65136 .5919 m .65103 .59193 L .64913 .59044 L F
.609 .597 .814 r
.65306 .59174 m .65103 .59193 L .65261 .59048 L F
.457 .343 .636 r
.65261 .59048 m .65151 .59232 L .65136 .5919 L F
.606 .425 .611 r
.65136 .5919 m .65151 .59232 L .65103 .59193 L F
.609 .597 .814 r
.65384 .59389 m .65013 .59276 L .65103 .59193 L F
.533 .435 .69 r
.65261 .59048 m .65103 .59193 L .65151 .59232 L F
.65103 .59193 m .65013 .59276 L .65151 .59232 L F
.606 .425 .611 r
.64913 .59044 m .65151 .59232 L .64829 .59172 L F
.534 .526 .793 r
.65157 .58526 m .65025 .58874 L .65095 .58569 L F
.65157 .58526 m .6536 .5888 L .65025 .58874 L F
.457 .343 .636 r
.65261 .59048 m .65025 .58874 L .6536 .5888 L F
.626 .358 .492 r
.61423 .66672 m .61192 .66871 L .61197 .66671 L F
.609 .557 .771 r
.49488 .75816 m .49368 .76018 L .49144 .75506 L F
.7 .676 .823 r
.49269 .76014 m .49368 .76018 L .49488 .75816 L F
.622 .796 .965 r
.40253 .74413 m .40589 .74448 L .40453 .74337 L F
.833 .789 .81 r
.40285 .74635 m .40589 .74448 L .40518 .74612 L F
.7 .301 .288 r
.40253 .74413 m .40518 .74612 L .40589 .74448 L F
.652 .805 .956 r
.40511 .74352 m .40589 .74448 L .40806 .74428 L F
.40453 .74337 m .40806 .74428 L .40532 .74311 L F
.733 .761 .875 r
.40532 .74311 m .40806 .74428 L .40988 .74211 L F
.40532 .74311 m .40988 .74211 L .40858 .7414 L F
.348 .189 .519 r
.40748 .74251 m .40616 .74541 L .40538 .74327 L F
.40567 .74301 m .40538 .74327 L .40532 .74311 L F
.40748 .74251 m .40538 .74327 L .40567 .74301 L F
.652 .805 .956 r
.40453 .74337 m .40492 .74368 L .40511 .74352 L F
.40492 .74368 m .40589 .74448 L .40511 .74352 L F
.68 .616 .777 r
.70865 .72399 m .7049 .72284 L .70719 .72239 L F
.725 .645 .769 r
.7049 .72284 m .70177 .72104 L .70385 .72007 L F
.635 .639 .836 r
.70719 .72239 m .7049 .72284 L .70385 .72007 L F
.848 .51 .413 r
.71921 .70313 m .7205 .70136 L .7187 .70143 L F
.71921 .70313 m .72156 .70391 L .7205 .70136 L F
.448 .346 .646 r
.54777 .80502 m .54964 .80752 L .54935 .80602 L F
.54777 .80502 m .5477 .8087 L .54964 .80752 L F
.418 .209 .486 r
.32552 .70957 m .32714 .71117 L .32761 .70949 L F
.32552 .70957 m .32533 .71186 L .32714 .71117 L F
.317 .39 .779 r
.3474 .68009 m .34848 .6795 L .34647 .67797 L F
.202 .148 .57 r
.34727 .68291 m .34848 .6795 L .3474 .68009 L F
.894 .632 .533 r
.4991 .87436 m .50063 .87543 L .5005 .8733 L F
.4991 .87436 m .50063 .87543 L .5005 .8733 L F
.624 .206 .23 r
.49812 .8738 m .4991 .87436 L .5005 .8733 L F
.284 0 .255 r
.33621 .71978 m .33535 .72231 L .33373 .72204 L F
.18 0 .209 r
.3369 .72137 m .33621 .71978 L .33777 .71905 L F
.3369 .72137 m .33535 .72231 L .33621 .71978 L F
.72 .592 .712 r
.70322 .71521 m .70555 .71295 L .70458 .71182 L F
.70322 .71521 m .70405 .71536 L .70555 .71295 L F
.866 .459 .257 r
.70555 .71295 m .70533 .71446 L .70458 .71182 L F
.809 .689 .733 r
.61066 .63703 m .61183 .64017 L .60881 .6398 L F
.831 .721 .743 r
.61183 .64017 m .60833 .64196 L .60881 .6398 L F
.61183 .64017 m .61016 .643 L .60833 .64196 L F
.733 .507 .586 r
.49038 .76833 m .48634 .7705 L .48623 .76849 L F
.584 .435 .645 r
.3469 .75749 m .3489 .75475 L .34678 .7551 L F
.202 .148 .57 r
.34727 .68291 m .34872 .68189 L .34848 .6795 L F
.374 .259 .593 r
.34727 .68291 m .34938 .68439 L .34872 .68189 L F
.34727 .68291 m .34753 .6852 L .34938 .68439 L F
.284 0 .211 r
.33535 .72231 m .33267 .72448 L .33373 .72204 L F
.775 .546 .588 r
.55915 .81094 m .55916 .81331 L .55586 .8129 L F
.551 .563 .82 r
.55586 .8129 m .55812 .81286 L .55811 .81283 L F
.425 0 .116 r
.55696 .81124 m .55586 .8129 L .55375 .81296 L F
.775 .546 .588 r
.55915 .81094 m .55586 .8129 L .55696 .81124 L F
.551 .563 .82 r
.55586 .8129 m .55811 .81283 L .55686 .80974 L F
.425 0 .116 r
.55375 .81296 m .55586 .8129 L .5537 .81299 L F
.668 .511 .662 r
.55532 .79434 m .55786 .79176 L .55561 .79251 L F
.55532 .79434 m .55896 .79536 L .55786 .79176 L F
.701 .529 .653 r
.55786 .79176 m .55896 .79536 L .56109 .7948 L F
.649 .583 .767 r
.49488 .75816 m .49504 .76015 L .49269 .76014 L F
.094 0 0 r
.42128 .78562 m .42288 .7845 L .42489 .78395 L F
.596 .545 .768 r
.43095 .74462 m .43206 .74105 L .42994 .74189 L F
.43095 .74462 m .43308 .74444 L .43206 .74105 L F
.24 .739 .905 r
.33958 .81897 m .34065 .81929 L .33898 .81872 L F
.33958 .81897 m .34113 .81929 L .34065 .81929 L F
.455 .276 .548 r
.34065 .81929 m .33958 .81897 L .33898 .81872 L F
.34065 .81929 m .34031 .82169 L .34091 .82162 L F
.34091 .82162 m .34031 .82169 L .34065 .81929 L F
.34065 .81929 m .34091 .82162 L .33958 .81897 L F
.34091 .82162 m .34065 .81929 L .34113 .81929 L F
.566 .629 .873 r
.34148 .81607 m .34113 .81929 L .33958 .81897 L F
.34148 .81607 m .34409 .81923 L .34113 .81929 L F
.686 .29 .291 r
.34113 .81929 m .343 .82137 L .34091 .82162 L F
.442 .545 .866 r
.46948 .73044 m .47123 .73053 L .46896 .73058 L F
.563 .545 .793 r
.47123 .73053 m .47029 .73405 L .46896 .73058 L F
.692 .729 .879 r
.70053 .71667 m .70405 .71536 L .70322 .71521 L F
.786 .615 .668 r
.67849 .71743 m .68025 .72059 L .67709 .72008 L F
.866 .442 .204 r
.67979 .72269 m .67709 .72008 L .68025 .72059 L F
.62 .464 .649 r
.33275 .77934 m .33503 .78141 L .3349 .77901 L F
.33275 .77934 m .33279 .78171 L .33503 .78141 L F
.587 .772 .968 r
.46398 .72978 m .46046 .72895 L .46237 .7285 L F
.462 .696 .968 r
.46449 .72831 m .46398 .72978 L .46237 .7285 L F
.46449 .72831 m .46598 .72967 L .46398 .72978 L F
.709 .4 .452 r
.60318 .667 m .60342 .66874 L .6 .66875 L F
.701 .394 .454 r
.607 .66851 m .60342 .66874 L .60318 .667 L F
.692 .78 .919 r
.5923 .67101 m .59346 .6721 L .59017 .67175 L F
.7 .278 .241 r
.59346 .6721 m .59238 .67361 L .59017 .67175 L F
.574 .744 .957 r
.59593 .67112 m .59346 .6721 L .5923 .67101 L F
.447 0 .087 r
.59568 .67155 m .59346 .6721 L .59593 .67112 L F
.574 .744 .957 r
.59593 .67112 m .5923 .67101 L .59501 .66832 L F
.672 .522 .673 r
.59501 .66832 m .59503 .6716 L .59628 .67098 L F
.59501 .66832 m .59725 .66989 L .59637 .66847 L F
.755 .695 .795 r
.6 .66875 m .59794 .67101 L .59637 .66847 L F
.672 .522 .673 r
.59725 .66989 m .59777 .67026 L .59637 .66847 L F
.753 .585 .668 r
.59729 .67023 m .59501 .66832 L .59715 .66996 L F
.59778 .67118 m .59669 .67006 L .59729 .67023 L F
.59669 .67006 m .59501 .66832 L .59729 .67023 L F
.755 .695 .795 r
.59794 .67101 m .59778 .67118 L .59715 .66996 L F
.447 0 .087 r
.59459 .67337 m .5942 .67292 L .59568 .67155 L F
.753 .585 .668 r
.59778 .67118 m .59593 .67112 L .59501 .66832 L F
.698 .44 .53 r
.59789 .67336 m .59636 .67161 L .59778 .67118 L F
.59636 .67161 m .59593 .67112 L .59681 .67115 L F
.59636 .67161 m .59681 .67115 L .59778 .67118 L F
.59789 .67336 m .59459 .67337 L .59593 .67112 L F
0 0 0 r
.5955 .67248 m .59606 .67211 L .59777 .67026 L F
.59459 .67337 m .59476 .67322 L .5955 .67248 L F
.59476 .67322 m .59606 .67211 L .5955 .67248 L F
.59459 .67337 m .59768 .67034 L .59503 .6716 L F
.59768 .67034 m .59777 .67026 L .59762 .67033 L F
.59768 .67034 m .59762 .67033 L .59503 .6716 L F
.672 .522 .673 r
.59725 .66989 m .59628 .67098 L .59737 .66998 L F
.59501 .66832 m .59613 .67067 L .59725 .66989 L F
.59613 .67067 m .59628 .67098 L .59725 .66989 L F
.755 .695 .795 r
.59725 .66989 m .59715 .66996 L .59637 .66847 L F
.59794 .67101 m .59715 .66996 L .59725 .66989 L F
.753 .585 .668 r
.59715 .66996 m .59501 .66832 L .59637 .66847 L F
.672 .522 .673 r
.59737 .66998 m .59728 .67006 L .59777 .67026 L F
.59728 .67006 m .59628 .67098 L .59762 .67033 L F
.59728 .67006 m .59762 .67033 L .59777 .67026 L F
.447 0 .087 r
.5942 .67292 m .59346 .6721 L .59568 .67155 L F
.59459 .67337 m .59238 .67361 L .59346 .6721 L F
0 0 0 r
.38867 .78092 m .38918 .7807 L .39076 .78005 L F
.38867 .78092 m .38841 .7818 L .38918 .7807 L F
.133 0 0 r
.40305 .72436 m .40526 .7241 L .40676 .72337 L F
.554 .116 .162 r
.40526 .7241 m .40885 .7229 L .40676 .72337 L F
.18 0 0 r
.39089 .7971 m .39457 .79535 L .39253 .79642 L F
.07 0 0 r
.39669 .79506 m .39253 .79642 L .39457 .79535 L F
.281 0 .267 r
.38065 .75748 m .37992 .75983 L .37813 .7599 L F
.473 .313 .583 r
.38272 .75499 m .38275 .75723 L .38065 .75748 L F
.498 .178 .356 r
.38233 .75931 m .38065 .75748 L .38275 .75723 L F
.38233 .75931 m .37992 .75983 L .38065 .75748 L F
.878 .676 .626 r
.68616 .63705 m .68624 .63959 L .68351 .63862 L F
.493 .817 1 r
.68836 .63675 m .68738 .63595 L .68616 .63705 L F
.68836 .63675 m .68738 .63595 L .68616 .63705 L F
.532 .372 .609 r
.33469 .77666 m .33679 .77631 L .33685 .77412 L F
.55 .418 .653 r
.3349 .77901 m .33679 .77631 L .33469 .77666 L F
.459 .128 .316 r
.37813 .7599 m .3753 .76251 L .37595 .76092 L F
.37813 .7599 m .3774 .7622 L .3753 .76251 L F
.442 .175 .411 r
.37992 .75983 m .3774 .7622 L .37813 .7599 L F
.95 .769 .624 r
.71912 .70852 m .7175 .70875 L .71782 .70837 L F
.693 .673 .826 r
.71705 .70708 m .72 .70863 L .71912 .70852 L F
.275 .479 .877 r
.71705 .70708 m .71912 .70852 L .71902 .70693 L F
.95 .769 .624 r
.71912 .70852 m .71782 .70837 L .71902 .70693 L F
.693 .673 .826 r
.72 .70863 m .72107 .70919 L .71912 .70852 L F
.757 .759 .854 r
.68916 .60206 m .68994 .60448 L .69223 .60243 L F
.845 .958 .884 r
.65924 .64714 m .65647 .64852 L .65817 .64825 L F
.585 .789 .977 r
.34843 .65552 m .3477 .65706 L .34632 .65561 L F
.34843 .65552 m .35 .65631 L .3477 .65706 L F
.143 0 0 r
.42108 .74135 m .41752 .74315 L .41914 .74186 L F
.762 .991 .779 r
.63845 .59042 m .63978 .58987 L .63753 .59208 L F
.762 .991 .781 r
.63605 .59276 m .63845 .59042 L .63753 .59208 L F
.525 .29 .502 r
.35311 .74694 m .35519 .74659 L .35551 .74437 L F
.506 .274 .497 r
.35551 .74437 m .35519 .74659 L .35724 .74619 L F
.585 .449 .663 r
.35551 .74437 m .35778 .74412 L .35746 .74162 L F
.54 .275 .463 r
.35551 .74437 m .35724 .74619 L .35778 .74412 L F
.563 .545 .793 r
.47123 .73053 m .47257 .7339 L .47029 .73405 L F
.609 .571 .787 r
.4737 .73683 m .47029 .73405 L .47257 .7339 L F
.409 .437 .779 r
.46038 .74164 m .46141 .74486 L .46279 .7434 L F
.47 .533 .84 r
.46141 .74486 m .46416 .74635 L .46279 .7434 L F
.734 .755 .869 r
.69925 .7143 m .70322 .71521 L .70151 .71195 L F
.781 .703 .778 r
.69925 .7143 m .70053 .71667 L .70322 .71521 L F
.84 .794 .806 r
.70151 .71195 m .70322 .71521 L .70458 .71182 L F
.872 .801 .777 r
.70884 .5999 m .70552 .60176 L .70793 .59901 L F
.70884 .5999 m .70654 .60303 L .70552 .60176 L F
.793 .44 .389 r
.70793 .59901 m .71064 .59917 L .70884 .5999 L F
.567 .403 .619 r
.34281 .76291 m .34489 .7626 L .34485 .76024 L F
.54 .391 .627 r
.34302 .76577 m .34489 .7626 L .34281 .76291 L F
.517 .315 .545 r
.36573 .68787 m .3649 .68957 L .36328 .68987 L F
.45 .184 .417 r
.36447 .69242 m .36328 .68987 L .3649 .68957 L F
.36447 .69242 m .36248 .69296 L .36328 .68987 L F
.713 .679 .816 r
.50755 .88086 m .50868 .88364 L .5106 .88279 L F
.8 .95 .918 r
.33853 .81324 m .33962 .8137 L .34162 .8118 L F
.91 .92 .812 r
.62349 .61851 m .62456 .61493 L .62532 .61557 L F
.867 .969 .858 r
.62532 .61557 m .62687 .61239 L .62798 .61327 L F
.62532 .61557 m .62456 .61493 L .62687 .61239 L F
.484 0 0 r
.70716 .73372 m .70856 .73498 L .70624 .73349 L F
.70716 .73372 m .70951 .73572 L .70856 .73498 L F
.666 .113 0 r
.71054 .73596 m .70951 .73572 L .70716 .73372 L F
.642 .375 .499 r
.67264 .60442 m .6728 .60663 L .67453 .605 L F
.904 .964 .815 r
.67453 .605 m .67249 .60557 L .67297 .60481 L F
.642 .375 .499 r
.67264 .60442 m .67453 .605 L .67544 .60512 L F
.904 .964 .815 r
.67453 .605 m .67297 .60481 L .67394 .60325 L F
.642 .375 .499 r
.67544 .60512 m .67453 .605 L .67569 .60518 L F
.045 .271 .766 r
.67767 .60529 m .67569 .60518 L .67453 .605 L F
.67767 .60529 m .67762 .60651 L .67569 .60518 L F
.828 .775 .269 r
.67767 .60529 m .67745 .60633 L .67762 .60651 L F
.67745 .60633 m .67708 .60806 L .67762 .60651 L F
0 .161 .607 r
.67779 .60667 m .67762 .60651 L .67886 .60744 L F
.67569 .60518 m .67762 .60651 L .67779 .60667 L F
.637 .624 .82 r
.36915 .78158 m .36565 .77913 L .36776 .77872 L F
.657 .691 .871 r
.36978 .77841 m .36915 .78158 L .36776 .77872 L F
.36978 .77841 m .37134 .78094 L .36915 .78158 L F
.624 .578 .783 r
.36312 .6664 m .36095 .66691 L .35978 .66367 L F
.335 .184 .523 r
.36312 .6664 m .36165 .66889 L .36095 .66691 L F
.193 0 .093 r
.33124 .72545 m .32849 .72756 L .32945 .72618 L F
.466 0 0 r
.40885 .7229 m .41065 .72361 L .41217 .72297 L F
.319 0 0 r
.41065 .72361 m .41425 .72299 L .41217 .72297 L F
.089 0 0 r
.70908 .69469 m .71252 .69505 L .71017 .69524 L F
.699 .435 .521 r
.47538 .76833 m .47532 .76991 L .47193 .77049 L F
.682 .421 .521 r
.47538 .76833 m .47735 .77064 L .47532 .76991 L F
0 0 0 r
.67688 .58775 m .67556 .58904 L .67459 .59046 L F
.352 .809 .692 r
.71873 .72567 m .71647 .72681 L .71945 .72752 L F
.71873 .72567 m .71557 .72717 L .71647 .72681 L F
.733 .507 .586 r
.49038 .76833 m .48822 .77094 L .48634 .7705 L F
.704 .477 .577 r
.49171 .76837 m .48822 .77094 L .49038 .76833 L F
.609 .313 .443 r
.6304 .66113 m .62971 .66341 L .62747 .66333 L F
.404 .095 .324 r
.6317 .66103 m .62971 .66341 L .6304 .66113 L F
.602 .415 .601 r
.3691 .68333 m .36682 .68684 L .36739 .68523 L F
.628 .819 .974 r
.64224 .624 m .64655 .62353 L .64436 .62421 L F
.64224 .624 m .64655 .62353 L .64436 .62421 L F
.291 .352 .754 r
.59777 .66676 m .6 .66875 L .59912 .66635 L F
.044 .323 .807 r
.37196 .67048 m .37267 .67161 L .37189 .67223 L F
.414 .863 .829 r
.37164 .67243 m .37189 .67223 L .37313 .67199 L F
.464 .859 .972 r
.37313 .67199 m .37395 .67129 L .37529 .6715 L F
.451 .163 .384 r
.37189 .67223 m .37395 .67129 L .37313 .67199 L F
.551 .41 .642 r
.37529 .6715 m .37343 .67397 L .37313 .67199 L F
.451 .163 .384 r
.37189 .67223 m .37363 .67315 L .37395 .67129 L F
.044 .323 .807 r
.37267 .67161 m .37363 .67315 L .37189 .67223 L F
.414 .863 .829 r
.36967 .67302 m .37189 .67223 L .37164 .67243 L F
.517 .131 .248 r
.68239 .61234 m .68033 .61052 L .67959 .61069 L F
.68239 .61234 m .68308 .61037 L .68033 .61052 L F
.659 .609 .788 r
.50308 .76834 m .49935 .76557 L .50146 .76525 L F
.675 .463 .591 r
.50308 .76834 m .50275 .77126 L .5006 .77046 L F
.528 .587 .857 r
.50482 .76783 m .50308 .76834 L .50146 .76525 L F
.754 .535 .599 r
.506 .77106 m .50308 .76834 L .50482 .76783 L F
.506 .77106 m .50275 .77126 L .50308 .76834 L F
.412 .764 .995 r
.48126 .88615 m .48235 .88527 L .48059 .88323 L F
.48126 .88615 m .48338 .886 L .48235 .88527 L F
.737 .233 .028 r
.66606 .59905 m .67088 .60121 L .66719 .60068 L F
.66606 .59905 m .66728 .60099 L .67088 .60121 L F
.533 .033 .014 r
.66774 .60298 m .67088 .60121 L .66728 .60099 L F
.738 .646 .758 r
.67976 .72515 m .68238 .72691 L .68245 .72559 L F
.991 .876 .609 r
.57341 .80246 m .57362 .80483 L .57426 .80359 L F
.005 0 .084 r
.57564 .80234 m .57362 .80483 L .57426 .80359 L F
.778 .755 .832 r
.68283 .69887 m .67945 .70203 L .68065 .69958 L F
.371 .271 .609 r
.67945 .70203 m .68046 .70359 L .68065 .69958 L F
.413 0 0 r
.64294 .59626 m .64625 .5974 L .64414 .59712 L F
.64625 .5974 m .64654 .5975 L .64622 .59745 L F
.64625 .5974 m .64622 .59745 L .64414 .59712 L F
.807 .483 0 r
.64731 .59983 m .64692 .59922 L .64634 .59719 L F
.64635 .59715 m .64634 .59719 L .64619 .59668 L F
.64731 .59983 m .64634 .59719 L .64635 .59715 L F
.955 .921 .568 r
.64731 .59983 m .64692 .59922 L .64623 .60138 L F
.343 0 .021 r
.64971 .59973 m .64623 .60138 L .64731 .59983 L F
.807 .483 0 r
.64731 .59983 m .64692 .59922 L .64619 .59668 L F
.338 0 0 r
.55679 .79968 m .56013 .80052 L .55933 .79799 L F
.55679 .79968 m .55901 .80037 L .56013 .80052 L F
0 0 .124 r
.56013 .80052 m .56224 .79769 L .55933 .79799 L F
.56013 .80052 m .56134 .80014 L .56224 .79769 L F
.549 .237 .392 r
.55901 .80037 m .56134 .80014 L .56013 .80052 L F
.744 .757 .864 r
.48877 .88625 m .49026 .88808 L .49221 .88634 L F
.546 .901 .972 r
.35038 .81311 m .35296 .81267 L .3515 .81205 L F
.333 .788 .95 r
.3515 .81205 m .35296 .81267 L .35453 .81226 L F
0 0 0 r
.34422 .82659 m .34598 .82653 L .34796 .82648 L F
.34422 .82659 m .34598 .82653 L .34796 .82648 L F
.887 .9 .833 r
.61711 .62661 m .61489 .62944 L .61386 .6287 L F
0 .545 .741 r
.56109 .7948 m .56369 .79503 L .56451 .79516 L F
.56451 .79516 m .56369 .79503 L .56109 .7948 L F
.606 .405 .583 r
.56224 .79769 m .56451 .79516 L .56109 .7948 L F
.56224 .79769 m .5645 .7975 L .56451 .79516 L F
.613 .955 .902 r
.56451 .79516 m .56369 .79503 L .56537 .79405 L F
.56451 .79516 m .56369 .79503 L .56537 .79405 L F
.642 .434 .586 r
.56451 .79516 m .56664 .797 L .56647 .79488 L F
.56451 .79516 m .5645 .7975 L .56664 .797 L F
.724 .92 .959 r
.7151 .72208 m .71389 .72367 L .71387 .72333 L F
.713 .901 .963 r
.71587 .72279 m .71389 .72367 L .7151 .72208 L F
.978 .919 .644 r
.65924 .64714 m .66017 .64537 L .65878 .64644 L F
.528 .855 .57 r
.66017 .64537 m .66218 .64351 L .66127 .64424 L F
.946 .735 .268 r
.67942 .62899 m .67983 .6319 L .67908 .63112 L F
.965 .642 .344 r
.67983 .6319 m .67908 .63316 L .67908 .63112 L F
.67983 .6319 m .68016 .63386 L .67908 .63316 L F
.73 .541 .637 r
.50957 .88013 m .513 .87814 L .51012 .87815 L F
.745 .967 .934 r
.49967 .88561 m .50351 .88403 L .50216 .88305 L F
.384 0 .146 r
.42265 .77605 m .42475 .77571 L .42601 .77375 L F
.359 0 .131 r
.42601 .77375 m .42681 .77531 L .42796 .77307 L F
.42601 .77375 m .42475 .77571 L .42681 .77531 L F
.419 .169 .425 r
.35766 .69777 m .35622 .69651 L .3582 .69595 L F
.35766 .69777 m .3558 .69835 L .35622 .69651 L F
.434 .104 .306 r
.32071 .71417 m .32263 .71377 L .3234 .71232 L F
.385 .055 .277 r
.3234 .71232 m .32263 .71377 L .32533 .71186 L F
.615 .909 .983 r
.67302 .71754 m .67502 .71686 L .67445 .71614 L F
.562 .318 .503 r
.67502 .71686 m .67562 .71876 L .67302 .71754 L F
.354 .447 .818 r
.67302 .71754 m .67562 .71876 L .67445 .71614 L F
.701 .579 .716 r
.46847 .75208 m .46964 .75536 L .47163 .75463 L F
.335 .184 .523 r
.36312 .6664 m .36302 .6687 L .36165 .66889 L F
.908 .981 .775 r
.51138 .77077 m .51238 .76759 L .51381 .77025 L F
.354 .759 .983 r
.43733 .72557 m .43936 .72546 L .4407 .72607 L F
.154 .683 .867 r
.43936 .72546 m .44282 .7257 L .4407 .72607 L F
.535 .572 .839 r
.48398 .85098 m .48557 .85418 L .48731 .85363 L F
.346 .062 .332 r
.48731 .85363 m .48479 .85606 L .48557 .85418 L F
.48731 .85363 m .48479 .85606 L .48557 .85418 L F
0 0 .207 r
.40353 .75742 m .40315 .76024 L .40282 .76038 L F
.679 .743 .899 r
.6979 .60368 m .701 .60436 L .70024 .60265 L F
.679 .792 .934 r
.701 .60436 m .70237 .60172 L .70024 .60265 L F
.701 .60436 m .7035 .60317 L .70237 .60172 L F
.985 .707 .353 r
.63977 .60707 m .6399 .6091 L .64105 .61013 L F
.737 .909 .953 r
.64105 .61013 m .63785 .61039 L .63862 .61322 L F
.64105 .61013 m .6399 .6091 L .63785 .61039 L F
.662 .623 .8 r
.4841 .84602 m .48617 .84589 L .48488 .84298 L F
.644 .442 .594 r
.48614 .84828 m .4841 .84602 L .48617 .84589 L F
.48614 .84828 m .48387 .84862 L .4841 .84602 L F
.662 .623 .8 r
.48488 .84298 m .48617 .84589 L .4841 .84602 L F
.644 .442 .594 r
.4841 .84602 m .48614 .84828 L .48617 .84589 L F
.4841 .84602 m .48387 .84862 L .48614 .84828 L F
.887 .9 .833 r
.61711 .62661 m .61386 .6287 L .61633 .62578 L F
.423 .182 .442 r
.3558 .69835 m .3535 .70091 L .35395 .6989 L F
.937 .708 .566 r
.67283 .61781 m .67429 .61863 L .67311 .61562 L F
.929 .739 .625 r
.67283 .61781 m .67393 .62091 L .67429 .61863 L F
.67429 .61863 m .67393 .62091 L .67283 .61781 L F
.704 .682 .826 r
.67754 .71468 m .67849 .71743 L .67502 .71686 L F
.868 .728 .705 r
.67849 .71743 m .67562 .71876 L .67502 .71686 L F
.67849 .71743 m .67709 .72008 L .67562 .71876 L F
.609 .597 .814 r
.65384 .59389 m .65215 .59524 L .65013 .59276 L F
.403 .248 .555 r
.65384 .59389 m .65401 .59625 L .65215 .59524 L F
.575 .618 .858 r
.68549 .59732 m .68929 .60002 L .68785 .59716 L F
.588 .637 .867 r
.68785 .59716 m .68929 .60002 L .69122 .59919 L F
.376 .131 .41 r
.68929 .60002 m .68916 .60206 L .69122 .59919 L F
.602 .415 .601 r
.3691 .68333 m .3677 .68767 L .36682 .68684 L F
.732 .888 .952 r
.37022 .68244 m .3691 .68333 L .36961 .68276 L F
.325 .137 .465 r
.37022 .68244 m .3677 .68767 L .3691 .68333 L F
.483 .864 .979 r
.37238 .80233 m .37372 .80267 L .37589 .8021 L F
.664 .404 .517 r
.62514 .66341 m .62193 .66606 L .62194 .66442 L F
.586 .459 .674 r
.36776 .77872 m .36543 .7767 L .36748 .77636 L F
.36776 .77872 m .36565 .77913 L .36543 .7767 L F
.915 .631 .489 r
.57021 .80839 m .56829 .80911 L .56873 .80838 L F
.351 .827 .848 r
.57237 .80824 m .56829 .80911 L .57021 .80839 L F
.592 .43 .632 r
.35103 .74961 m .35321 .74935 L .35311 .74694 L F
.561 .349 .55 r
.35103 .74961 m .35299 .75163 L .35321 .74935 L F
.35103 .74961 m .35082 .75201 L .35299 .75163 L F
.134 .206 .674 r
.47882 .87794 m .4795 .88209 L .48059 .8804 L F
.095 .217 .701 r
.48059 .88323 m .48059 .8804 L .4795 .88209 L F
0 0 0 r
.72299 .62438 m .7229 .62414 L .72373 .62265 L F
.72299 .62438 m .72224 .62604 L .7229 .62414 L F
.622 .613 .821 r
.48368 .74438 m .48013 .74192 L .4824 .74156 L F
.556 .554 .807 r
.48459 .74099 m .48368 .74438 L .4824 .74156 L F
.48459 .74099 m .48578 .74416 L .48368 .74438 L F
.413 .396 .731 r
.35205 .65717 m .35143 .66039 L .34998 .65767 L F
.35205 .65717 m .35299 .66077 L .35143 .66039 L F
.137 0 0 r
.71292 .7363 m .70951 .73572 L .71054 .73596 L F
.316 0 0 r
.63845 .59042 m .64171 .58882 L .63978 .58987 L F
.453 .22 .469 r
.34491 .70933 m .34425 .71169 L .34255 .71201 L F
.467 .241 .487 r
.34665 .70876 m .34425 .71169 L .34491 .70933 L F
.572 .381 .583 r
.70742 .69903 m .70564 .70153 L .70497 .69853 L F
.70742 .69903 m .70804 .70117 L .70564 .70153 L F
.74 .74 .851 r
.38058 .91516 m .38167 .91721 L .38399 .91539 L F
.552 .234 .383 r
.64706 .64392 m .64402 .64182 L .64507 .64478 L F
.589 .902 .984 r
.6447 .64529 m .64507 .64478 L .64436 .64569 L F
.64639 .64329 m .64706 .64392 L .64507 .64478 L F
.64639 .64329 m .64545 .64435 L .6447 .64529 L F
.64545 .64435 m .64507 .64478 L .6447 .64529 L F
.552 .234 .383 r
.64625 .64336 m .64768 .64119 L .64402 .64182 L F
.64706 .64392 m .64756 .64172 L .64625 .64336 L F
.64756 .64172 m .64768 .64119 L .64625 .64336 L F
.593 .586 .814 r
.47578 .73626 m .4737 .73683 L .47257 .7339 L F
.232 .704 .941 r
.42851 .72384 m .43068 .72387 L .43205 .72444 L F
.152 0 0 r
.43068 .72387 m .43406 .72458 L .43205 .72444 L F
.163 0 0 r
.42704 .78304 m .43047 .78149 L .4291 .78282 L F
.321 0 0 r
.43047 .78149 m .4312 .78259 L .4291 .78282 L F
.43047 .78149 m .43256 .78128 L .4312 .78259 L F
.704 .477 .577 r
.49171 .76837 m .49171 .77061 L .48822 .77094 L F
0 0 0 r
.56921 .80366 m .56799 .80485 L .56677 .80581 L F
.442 .203 .455 r
.33028 .70661 m .33201 .70858 L .33202 .70607 L F
.33028 .70661 m .32993 .70913 L .33201 .70858 L F
.521 .389 .641 r
.34647 .67797 m .34825 .6772 L .34588 .67686 L F
.34647 .67797 m .34848 .6795 L .34825 .6772 L F
.379 .14 .421 r
.34236 .71411 m .33998 .7169 L .34044 .71468 L F
.701 .579 .716 r
.46847 .75208 m .47163 .75463 L .46987 .75264 L F
.724 .626 .748 r
.46987 .75264 m .47163 .75463 L .474 .75214 L F
.726 .459 .522 r
.46937 .76005 m .47288 .76205 L .47073 .75978 L F
.728 .376 .383 r
.47073 .75978 m .47288 .76205 L .47299 .76052 L F
.99 .888 .574 r
.61199 .63142 m .61209 .63411 L .61093 .63309 L F
.883 .757 .718 r
.61209 .63411 m .60911 .63608 L .61093 .63309 L F
.61209 .63411 m .61066 .63703 L .60911 .63608 L F
.71 .644 .781 r
.46759 .74899 m .46847 .75208 L .47069 .74966 L F
.622 .506 .7 r
.46847 .75208 m .46987 .75264 L .47069 .74966 L F
.866 .736 .717 r
.64624 .58825 m .64933 .58577 L .64716 .58646 L F
.946 .682 .506 r
.65481 .63018 m .65669 .63172 L .65647 .62919 L F
.564 .544 .791 r
.65151 .59232 m .65013 .59276 L .64829 .59172 L F
.681 .578 .733 r
.62798 .62872 m .63183 .63134 L .62927 .62931 L F
.262 0 .304 r
.33998 .7169 m .33777 .71905 L .33822 .7175 L F
.902 .97 .661 r
.65752 .63447 m .65884 .63105 L .66001 .63199 L F
.844 .891 .872 r
.66241 .62978 m .66001 .63199 L .65884 .63105 L F
0 .082 .604 r
.43742 .74339 m .43613 .74165 L .43749 .74072 L F
.96 .944 .658 r
.68925 .63405 m .69067 .63245 L .6894 .63315 L F
.614 .556 .765 r
.69299 .63157 m .69067 .63245 L .68985 .62878 L F
0 0 0 r
.6894 .63315 m .69067 .63245 L .69299 .63157 L F
.786 .636 .695 r
.51755 .77567 m .51737 .7728 L .51806 .7748 L F
.51755 .77567 m .51481 .77363 L .51737 .7728 L F
.51755 .77567 m .51653 .7765 L .51481 .77363 L F
.752 .573 .653 r
.51755 .77567 m .51612 .77889 L .51653 .7765 L F
.232 .549 .93 r
.5497 .81259 m .55045 .81234 L .5481 .8111 L F
.5497 .81259 m .55148 .81346 L .55045 .81234 L F
.981 .7 .406 r
.6792 .62669 m .6782 .62798 L .67871 .6258 L F
.6792 .62669 m .67942 .62899 L .6782 .62798 L F
.438 .34 .647 r
.5481 .8111 m .54964 .80752 L .5477 .8087 L F
.417 .213 .493 r
.33202 .70607 m .3341 .70317 L .33253 .70395 L F
.922 .661 .524 r
.68752 .64242 m .68622 .64239 L .68624 .63959 L F
.808 .366 .194 r
.68752 .64242 m .6868 .64364 L .68622 .64239 L F
.813 .373 .197 r
.68752 .64242 m .68951 .64481 L .6868 .64364 L F
.909 .513 .111 r
.57093 .80657 m .57173 .80818 L .57237 .80824 L F
.57054 .80612 m .57091 .80676 L .57093 .80657 L F
.57091 .80676 m .57173 .80818 L .57093 .80657 L F
.871 .476 .011 r
.57097 .80617 m .57011 .80622 L .56873 .80838 L F
.57108 .80606 m .57162 .80639 L .57011 .80622 L F
.57108 .80606 m .57098 .80608 L .57097 .80617 L F
.57098 .80608 m .57011 .80622 L .57097 .80617 L F
.241 0 0 r
.73479 .71789 m .73213 .71957 L .73112 .7195 L F
.923 .905 .788 r
.73393 .717 m .73213 .71957 L .73479 .71789 L F
.513 .168 .319 r
.6376 .64737 m .64024 .64558 L .63824 .64487 L F
.6376 .64737 m .64003 .64692 L .64024 .64558 L F
.474 .264 .514 r
.34417 .71336 m .34255 .71201 L .34425 .71169 L F
.34417 .71336 m .34236 .71411 L .34255 .71201 L F
.681 .835 .957 r
.4481 .72586 m .44628 .72701 L .44511 .72567 L F
.435 .284 .576 r
.34587 .68806 m .34759 .6876 L .34753 .6852 L F
.477 .369 .652 r
.34587 .68806 m .34795 .69004 L .34759 .6876 L F
.34587 .68806 m .34622 .69063 L .34795 .69004 L F
.753 .791 .884 r
.71774 .60641 m .71874 .60781 L .71926 .60611 L F
.575 .413 .625 r
.34489 .7626 m .34701 .7599 L .34485 .76024 L F
.365 .776 .98 r
.71863 .61817 m .72014 .6179 L .72102 .61846 L F
.71779 .61807 m .72014 .6179 L .72102 .61846 L F
0 0 0 r
.72318 .61574 m .72232 .61716 L .72102 .61846 L F
.578 .887 .99 r
.72102 .61846 m .72014 .6179 L .72232 .61716 L F
.72102 .61846 m .72014 .6179 L .72232 .61716 L F
.648 .959 .772 r
.71942 .61908 m .7216 .61764 L .72014 .6179 L F
.7216 .61764 m .72232 .61716 L .72014 .6179 L F
.365 .776 .98 r
.71779 .61807 m .72014 .6179 L .71863 .61817 L F
.292 .405 .805 r
.72232 .61716 m .7236 .62031 L .72102 .61846 L F
.617 .565 .774 r
.49143 .74595 m .49035 .7496 L .48923 .74648 L F
.49143 .74595 m .49256 .74916 L .49035 .7496 L F
.607 .513 .722 r
.49256 .74916 m .49131 .75279 L .49035 .7496 L F
.458 .052 .18 r
.34588 .67686 m .34216 .67942 L .34268 .67695 L F
.34588 .67686 m .34457 .67919 L .34216 .67942 L F
.587 .519 .745 r
.34588 .67686 m .34825 .6772 L .34767 .67424 L F
0 0 0 r
.34767 .67424 m .3468 .67601 L .34588 .67686 L F
.315 0 .106 r
.34588 .67686 m .34649 .67869 L .3468 .67601 L F
.34588 .67686 m .34457 .67919 L .34649 .67869 L F
.564 .414 .636 r
.37314 .76288 m .37324 .76541 L .37116 .76567 L F
.46 .23 .478 r
.37324 .76541 m .37102 .76798 L .37116 .76567 L F
.65 .626 .812 r
.49489 .88783 m .49699 .88522 L .49445 .88558 L F
.49489 .88783 m .49754 .88738 L .49699 .88522 L F
.456 .029 .139 r
.43015 .77296 m .43231 .77288 L .43368 .77112 L F
.514 .115 .221 r
.43231 .77288 m .43589 .77094 L .43368 .77112 L F
.947 .957 .724 r
.67711 .60892 m .67886 .60744 L .67762 .60651 L F
.67711 .60892 m .67698 .61059 L .67886 .60744 L F
0 0 .016 r
.56467 .80861 m .56392 .81078 L .56268 .81153 L F
.642 .393 .527 r
.47288 .76205 m .47524 .76008 L .47299 .76052 L F
.573 .248 .379 r
.46434 .77106 m .46323 .77354 L .46101 .77339 L F
.535 .208 .361 r
.46558 .77272 m .46323 .77354 L .46434 .77106 L F
.585 .217 .31 r
.46659 .77122 m .46558 .77272 L .46434 .77106 L F
.839 .714 .726 r
.61016 .643 m .60942 .64503 L .60833 .64196 L F
.626 .358 .492 r
.61423 .66672 m .61424 .66868 L .61192 .66871 L F
.63 .354 .48 r
.61723 .66631 m .61424 .66868 L .61423 .66672 L F
.315 0 0 r
.41425 .72299 m .41626 .72345 L .41759 .72314 L F
.73 .541 .637 r
.50957 .88013 m .51284 .88049 L .513 .87814 L F
.601 .688 .904 r
.45498 .72813 m .452 .72708 L .45391 .72684 L F
.255 .567 .937 r
.45391 .72684 m .45576 .72725 L .45498 .72813 L F
.356 .712 .986 r
.45576 .72725 m .45699 .72813 L .45498 .72813 L F
.209 .734 .766 r
.6532 .60356 m .65395 .60507 L .651 .60503 L F
.759 .527 .582 r
.65395 .60507 m .65073 .60741 L .651 .60503 L F
.65395 .60507 m .65402 .60732 L .65073 .60741 L F
.04 0 .449 r
.6553 .60638 m .65395 .60507 L .65624 .60471 L F
.6553 .60638 m .65402 .60732 L .65395 .60507 L F
.406 .171 .441 r
.35099 .70345 m .34924 .70397 L .35151 .70137 L F
.484 .235 .46 r
.35088 .70554 m .34924 .70397 L .35099 .70345 L F
.35088 .70554 m .34897 .70598 L .34924 .70397 L F
.713 .679 .816 r
.50755 .88086 m .5106 .88279 L .50957 .88013 L F
.713 .646 .782 r
.50957 .88013 m .5106 .88279 L .51284 .88049 L F
.537 .635 .895 r
.69584 .71172 m .69826 .71511 L .69925 .7143 L F
.383 .654 .964 r
.48312 .87727 m .48457 .87833 L .48212 .87826 L F
.285 .494 .885 r
.48312 .87727 m .48493 .87996 L .48212 .87826 L F
.349 0 .011 r
.40402 .78121 m .40617 .78095 L .40762 .77939 L F
.264 0 0 r
.40762 .77939 m .40828 .7805 L .40969 .77903 L F
.40762 .77939 m .40617 .78095 L .40828 .7805 L F
.308 .229 .602 r
.52962 .76965 m .52824 .77089 L .52789 .76833 L F
.497 .187 .372 r
.53017 .76803 m .52962 .76965 L .52789 .76833 L F
.308 .229 .602 r
.52962 .76965 m .52824 .77089 L .52789 .76833 L F
.497 .187 .372 r
.53017 .76803 m .52962 .76965 L .52789 .76833 L F
.493 .9 .915 r
.65476 .63513 m .65711 .63421 L .65752 .63447 L F
.902 .97 .661 r
.65752 .63447 m .65711 .63421 L .65884 .63105 L F
.254 0 0 r
.6929 .64511 m .69619 .64525 L .69492 .64549 L F
0 0 0 r
.69829 .64455 m .69492 .64549 L .69619 .64525 L F
.844 .891 .872 r
.66241 .62978 m .65884 .63105 L .66108 .62821 L F
.664 .404 .517 r
.62514 .66341 m .62444 .66631 L .62193 .66606 L F
.586 .343 .515 r
.62747 .66333 m .62444 .66631 L .62514 .66341 L F
.431 .238 .515 r
.34874 .70782 m .34692 .7067 L .34897 .70598 L F
.34874 .70782 m .34665 .70876 L .34692 .7067 L F
.628 .464 .641 r
.513 .87012 m .51398 .8725 L .51186 .87203 L F
.51186 .87203 m .51398 .8725 L .513 .87012 L F
0 .31 .688 r
.35816 .81181 m .35795 .81181 L .36022 .81284 L F
.089 0 0 r
.66127 .64424 m .66218 .64351 L .66399 .64333 L F
.893 .892 .822 r
.62349 .61851 m .62038 .62047 L .62254 .61781 L F
.62349 .61851 m .62142 .62129 L .62038 .62047 L F
.91 .92 .812 r
.62349 .61851 m .62254 .61781 L .62456 .61493 L F
.245 .484 .888 r
.67578 .59178 m .67467 .59216 L .67459 .59046 L F
.439 .795 .997 r
.33513 .67602 m .33537 .67495 L .33305 .67529 L F
.33513 .67602 m .33678 .6757 L .33537 .67495 L F
.184 0 0 r
.45668 .7733 m .45511 .77522 L .45328 .77569 L F
.407 0 .103 r
.45742 .77487 m .45668 .7733 L .4588 .77328 L F
.45742 .77487 m .45511 .77522 L .45668 .7733 L F
.969 .825 .646 r
.68496 .71385 m .68636 .7123 L .68691 .71048 L F
.68496 .71385 m .68601 .71467 L .68636 .7123 L F
.277 0 .131 r
.635 .65873 m .63433 .66052 L .6317 .66103 L F
.129 0 .073 r
.63611 .65954 m .635 .65873 L .63718 .6582 L F
.63611 .65954 m .63433 .66052 L .635 .65873 L F
.712 .376 .407 r
.68836 .63675 m .69102 .63937 L .6918 .63704 L F
.695 .358 .401 r
.6918 .63704 m .69102 .63937 L .69426 .63932 L F
.317 .558 .922 r
.38088 .78016 m .38042 .78144 L .3785 .77934 L F
.229 .456 .871 r
.38161 .78157 m .38042 .78144 L .38088 .78016 L F
.244 0 0 r
.40251 .79338 m .40203 .7922 L .40411 .79185 L F
.40251 .79338 m .40058 .79391 L .40203 .7922 L F
.696 .917 .969 r
.71696 .71704 m .72034 .71635 L .71875 .71612 L F
.694 .366 .417 r
.71696 .71704 m .71978 .719 L .72034 .71635 L F
.49 .637 .919 r
.72034 .71635 m .72161 .71475 L .71875 .71612 L F
.72034 .71635 m .72251 .71652 L .72161 .71475 L F
.281 0 .128 r
.71978 .719 m .72251 .71652 L .72034 .71635 L F
.551 .41 .642 r
.37529 .6715 m .37578 .67373 L .37343 .67397 L F
.508 .402 .669 r
.37542 .67651 m .37343 .67397 L .37578 .67373 L F
.37542 .67651 m .37378 .67702 L .37343 .67397 L F
.484 .118 .268 r
.65854 .61796 m .66163 .61553 L .65967 .61871 L F
.275 .728 .956 r
.66194 .61853 m .65854 .61796 L .65967 .61871 L F
.464 .215 .451 r
.3535 .70091 m .35099 .70345 L .35151 .70137 L F
.241 0 .244 r
.32671 .72819 m .32586 .7301 L .3243 .73065 L F
0 0 0 r
.32849 .72756 m .32586 .7301 L .32671 .72819 L F
.56 .406 .629 r
.35311 .74694 m .35321 .74935 L .35519 .74659 L F
.372 0 .085 r
.44588 .77603 m .44222 .77814 L .44351 .7764 L F
.715 .612 .74 r
.36348 .93491 m .36409 .93424 L .36327 .93423 L F
.607 .513 .722 r
.49256 .74916 m .49349 .75241 L .49131 .75279 L F
.627 .492 .678 r
.49368 .75455 m .49131 .75279 L .49349 .75241 L F
.49368 .75455 m .49144 .75506 L .49131 .75279 L F
.756 .659 .755 r
.72554 .61331 m .72318 .61574 L .72207 .6126 L F
.284 .137 .497 r
.72459 .61409 m .72439 .61438 L .72381 .61342 L F
.556 .854 .539 r
.72439 .61438 m .72318 .61574 L .72414 .61475 L F
0 0 0 r
.72439 .61438 m .72232 .61716 L .72318 .61574 L F
.522 .337 .571 r
.72232 .61716 m .72411 .61727 L .72439 .61438 L F
.72439 .61438 m .72411 .61727 L .72232 .61716 L F
0 0 0 r
.72383 .61561 m .72455 .61406 L .72381 .61342 L F
.377 0 0 r
.72207 .6126 m .72511 .61349 L .72554 .61331 L F
.17 .121 .555 r
.72207 .6126 m .72371 .61146 L .72511 .61349 L F
.512 .883 .675 r
.72511 .61349 m .72711 .61212 L .72554 .61331 L F
0 0 0 r
.727 .61207 m .72554 .61331 L .72711 .61212 L F
.512 .883 .675 r
.72511 .61349 m .727 .61207 L .72711 .61212 L F
.739 .657 .769 r
.72371 .61146 m .72549 .61276 L .727 .61207 L F
.739 .929 .952 r
.72549 .61276 m .727 .61207 L .72511 .61349 L F
.739 .657 .769 r
.72549 .61276 m .72589 .61305 L .727 .61207 L F
.739 .929 .952 r
.72581 .61213 m .727 .61207 L .72549 .61276 L F
.72581 .61213 m .72549 .61276 L .72371 .61146 L F
.739 .657 .769 r
.72371 .61146 m .727 .61207 L .72458 .6122 L F
.739 .929 .952 r
.7263 .61119 m .72581 .61213 L .72371 .61146 L F
.739 .657 .769 r
.72458 .6122 m .72581 .61213 L .72519 .61271 L F
.72581 .61213 m .727 .61207 L .72635 .6123 L F
.72581 .61213 m .72635 .6123 L .72519 .61271 L F
.739 .929 .952 r
.7263 .61119 m .727 .61207 L .72581 .61213 L F
.72549 .61276 m .72511 .61349 L .72371 .61146 L F
0 0 0 r
.727 .61207 m .72439 .61438 L .72554 .61331 L F
.739 .657 .769 r
.72371 .61146 m .72439 .61438 L .72589 .61305 L F
0 0 0 r
.72455 .61406 m .72519 .61271 L .72381 .61342 L F
.284 .137 .497 r
.72459 .61409 m .72459 .61409 L .72381 .61342 L F
.72646 .6157 m .72439 .61438 L .72459 .61409 L F
.556 .854 .539 r
.72439 .61438 m .72414 .61475 L .72554 .61331 L F
.74 .567 .659 r
.69745 .70387 m .70027 .70156 L .69697 .70112 L F
.69745 .70387 m .70059 .70411 L .70027 .70156 L F
.521 .474 .745 r
.34539 .81381 m .34744 .81375 L .34682 .81049 L F
.34539 .81381 m .34682 .81049 L .3457 .81371 L F
0 .423 .822 r
.34539 .81381 m .3457 .81371 L .34162 .8118 L F
.34 0 0 r
.34318 .6545 m .34632 .65561 L .34434 .65583 L F
.284 0 0 r
.30483 .65615 m .30692 .65585 L .30787 .65498 L F
.414 .037 .211 r
.30692 .65585 m .30981 .65416 L .30787 .65498 L F
0 0 0 r
.64252 .61807 m .64441 .61733 L .64211 .61779 L F
.916 .815 .732 r
.63374 .5975 m .63163 .59864 L .63369 .59544 L F
.63374 .5975 m .63299 .59967 L .63163 .59864 L F
.437 .522 .847 r
.70447 .59857 m .70321 .6002 L .70318 .59992 L F
.249 .42 .836 r
.70554 .60034 m .70321 .6002 L .70447 .59857 L F
.70554 .60034 m .70552 .60176 L .70321 .6002 L F
.744 .814 .907 r
.70479 .60067 m .70552 .60176 L .70554 .60034 L F
.564 .564 .812 r
.70614 .60269 m .70321 .6002 L .70552 .60176 L F
.744 .814 .907 r
.70237 .60172 m .70552 .60176 L .70479 .60067 L F
.564 .564 .812 r
.70654 .60303 m .70614 .60269 L .70552 .60176 L F
.355 .253 .598 r
.36267 .81076 m .36098 .80843 L .36332 .80815 L F
.36267 .81076 m .3613 .81137 L .36098 .80843 L F
.708 .602 .737 r
.55896 .79536 m .55933 .79799 L .56224 .79769 L F
0 0 0 r
.32452 .73154 m .3243 .73065 L .32586 .7301 L F
.32452 .73154 m .32313 .73262 L .3243 .73065 L F
.521 .771 .988 r
.33607 .6524 m .33551 .65377 L .33419 .65241 L F
.33607 .6524 m .33754 .65348 L .33551 .65377 L F
.574 .41 .621 r
.339 .77101 m .34097 .77076 L .34117 .76874 L F
.575 .38 .579 r
.339 .77101 m .34105 .77316 L .34097 .77076 L F
.339 .77101 m .33893 .77366 L .34105 .77316 L F
.631 .912 .982 r
.51911 .77344 m .51806 .7748 L .51737 .7728 L F
.51911 .77344 m .52044 .77385 L .51806 .7748 L F
.04 0 0 r
.39812 .78176 m .39843 .78178 L .39969 .78149 L F
0 .534 .738 r
.39957 .78185 m .39843 .78178 L .39706 .78154 L F
.135 0 0 r
.39969 .78149 m .39843 .78178 L .40015 .78192 L F
0 .534 .738 r
.40015 .78192 m .39843 .78178 L .39957 .78185 L F
.04 0 0 r
.3967 .782 m .39843 .78178 L .39812 .78176 L F
.135 0 0 r
.39969 .78149 m .40015 .78192 L .40188 .78143 L F
.793 .719 .783 r
.70497 .69853 m .70564 .70153 L .7032 .70121 L F
.87 .95 .861 r
.70564 .70153 m .70259 .70343 L .7032 .70121 L F
.566 .535 .78 r
.50032 .76218 m .49935 .76557 L .49822 .76282 L F
.50032 .76218 m .50146 .76525 L .49935 .76557 L F
.497 .584 .873 r
.48901 .86767 m .49023 .86988 L .48869 .87 L F
.494 .36 .627 r
.49023 .86988 m .49085 .87244 L .48869 .87 L F
.308 .787 .917 r
.49085 .87244 m .48867 .87276 L .48869 .87 L F
.19 0 .139 r
.38011 .7302 m .38081 .73169 L .3822 .72995 L F
.38011 .7302 m .37897 .73251 L .38081 .73169 L F
.809 .401 0 r
.68159 .63634 m .68186 .63771 L .68016 .63386 L F
.781 .28 0 r
.68159 .63634 m .68226 .63819 L .68186 .63771 L F
.68159 .63634 m .68351 .63862 L .68226 .63819 L F
.654 .97 .886 r
.60551 .65738 m .6041 .65839 L .60463 .65761 L F
.708 .602 .737 r
.55896 .79536 m .56224 .79769 L .56109 .7948 L F
.712 .403 .453 r
.56224 .79769 m .56447 .80004 L .5645 .7975 L F
.56224 .79769 m .56134 .80014 L .56447 .80004 L F
.889 .987 .729 r
.71064 .59917 m .71217 .59577 L .71321 .5996 L F
.612 .641 .855 r
.7149 .59538 m .71321 .5996 L .71217 .59577 L F
.7149 .59538 m .71529 .5969 L .71321 .5996 L F
.634 .541 .731 r
.71644 .59933 m .71321 .5996 L .71529 .5969 L F
.71644 .59933 m .71415 .60001 L .71321 .5996 L F
.914 .669 .171 r
.63183 .63134 m .63196 .63325 L .63243 .63445 L F
.752 .64 .737 r
.70049 .71912 m .69953 .71659 L .70053 .71667 L F
.664 .626 .802 r
.70294 .71698 m .70049 .71912 L .70053 .71667 L F
.108 0 0 r
.69953 .71659 m .70294 .71698 L .70053 .71667 L F
.476 0 .043 r
.39218 .72704 m .39433 .72719 L .39584 .72586 L F
.356 0 0 r
.39433 .72719 m .39793 .72553 L .39584 .72586 L F
.565 .119 .15 r
.31193 .65413 m .31031 .65311 L .30981 .65416 L F
.31193 .65413 m .31254 .65357 L .31031 .65311 L F
.954 .692 .499 r
.68624 .63959 m .68472 .64166 L .68351 .63862 L F
.68624 .63959 m .68622 .64239 L .68472 .64166 L F
.831 .37 .117 r
.66045 .61078 m .65973 .61153 L .65908 .60985 L F
0 .158 .614 r
.66305 .6127 m .66246 .61221 L .66045 .61078 L F
.663 .142 0 r
.66045 .61078 m .66246 .61221 L .65973 .61153 L F
.808 .7 .746 r
.60942 .64503 m .60643 .64478 L .60833 .64196 L F
.812 .679 .717 r
.60942 .64503 m .60782 .64776 L .60643 .64478 L F
.561 .477 .717 r
.49688 .75734 m .49504 .76015 L .49488 .75816 L F
.49688 .75734 m .49717 .7598 L .49504 .76015 L F
.546 .465 .715 r
.49822 .76282 m .49504 .76015 L .49717 .7598 L F
.49822 .76282 m .49578 .76348 L .49504 .76015 L F
.723 .61 .731 r
.47069 .74966 m .474 .75214 L .47311 .74878 L F
.47069 .74966 m .46987 .75264 L .474 .75214 L F
.654 .599 .781 r
.47311 .74878 m .474 .75214 L .4764 .75191 L F
.738 .646 .758 r
.67976 .72515 m .6809 .72843 L .68238 .72691 L F
.579 .565 .802 r
.48103 .73838 m .48013 .74192 L .47916 .73869 L F
.48103 .73838 m .4824 .74156 L .48013 .74192 L F
.12 0 0 r
.30173 .6578 m .30483 .65615 L .30267 .65676 L F
.63 .354 .48 r
.61723 .66631 m .6166 .66871 L .61424 .66868 L F
.591 .316 .467 r
.61953 .66805 m .61723 .66631 L .61961 .66618 L F
.61953 .66805 m .6166 .66871 L .61723 .66631 L F
.484 .318 .58 r
.35965 .73868 m .36149 .74065 L .36177 .7385 L F
.35965 .73868 m .35958 .74119 L .36149 .74065 L F
.756 .672 .768 r
.6984 .7201 m .69988 .7229 L .69653 .72214 L F
.819 .609 .618 r
.69988 .7229 m .69712 .72451 L .69653 .72214 L F
.69988 .7229 m .69973 .72515 L .69712 .72451 L F
.747 .668 .773 r
.70177 .72104 m .69988 .7229 L .6984 .7201 L F
.842 .663 .66 r
.68301 .7167 m .68601 .71467 L .68496 .71385 L F
.68301 .7167 m .68571 .71691 L .68601 .71467 L F
.188 0 0 r
.71071 .63714 m .70775 .6386 L .70858 .63775 L F
.329 0 .003 r
.31241 .67703 m .3112 .67846 L .30926 .67865 L F
0 0 0 r
.31505 .67633 m .31364 .67673 L .31241 .67703 L F
.455 .13 .325 r
.31364 .67673 m .3112 .67846 L .31241 .67703 L F
.3 0 .218 r
.64462 .60202 m .64415 .60389 L .64212 .60476 L F
.825 .659 .677 r
.64119 .60122 m .64479 .60251 L .64288 .59819 L F
.685 .498 .628 r
.64415 .60389 m .64623 .60138 L .64479 .60251 L F
.775 .632 .703 r
.64623 .60138 m .64415 .60389 L .64434 .60314 L F
.64536 .60173 m .64434 .60314 L .64462 .60202 L F
.64623 .60138 m .64434 .60314 L .64536 .60173 L F
.211 .33 .768 r
.72652 .73739 m .72521 .73813 L .724 .73729 L F
.72652 .73739 m .72608 .73818 L .72521 .73813 L F
.575 .781 .977 r
.33041 .78428 m .33281 .7841 L .33279 .78171 L F
.615 .443 .625 r
.33279 .78171 m .33281 .7841 L .33503 .78141 L F
.708 .699 .839 r
.34008 .82812 m .34182 .82699 L .33935 .82693 L F
.157 0 0 r
.43823 .77942 m .43681 .78015 L .43463 .78038 L F
.469 0 .056 r
.44036 .77899 m .43681 .78015 L .43823 .77942 L F
.867 .591 .518 r
.63299 .59967 m .63133 .60096 L .63163 .59864 L F
.63299 .59967 m .6331 .6018 L .63133 .60096 L F
.345 0 0 r
.72108 .7378 m .724 .73729 L .72136 .7364 L F
.544 .171 .284 r
.38441 .72971 m .38661 .72971 L .3878 .72753 L F
.516 .179 .334 r
.38661 .72971 m .39002 .72712 L .3878 .72753 L F
.656 .26 .284 r
.506 .77106 m .50485 .77235 L .50275 .77126 L F
.629 .598 .8 r
.50707 .76748 m .506 .77106 L .50482 .76783 L F
.50707 .76748 m .50828 .77167 L .506 .77106 L F
.721 .345 .336 r
.506 .77106 m .50814 .77309 L .50485 .77235 L F
.644 .578 .766 r
.4764 .75191 m .47735 .75466 L .47921 .75227 L F
.618 .54 .745 r
.47735 .75466 m .47974 .75434 L .47921 .75227 L F
.561 .449 .683 r
.47802 .75656 m .47974 .75434 L .47735 .75466 L F
.902 .929 .824 r
.62893 .60957 m .63193 .60751 L .6301 .61052 L F
.62893 .60957 m .63103 .60678 L .63193 .60751 L F
.912 .926 .811 r
.63193 .60751 m .63293 .60407 L .63413 .60474 L F
.63193 .60751 m .63103 .60678 L .63293 .60407 L F
.627 .95 .939 r
.66599 .64294 m .66775 .64313 L .66984 .64196 L F
.617 .289 .393 r
.45634 .76471 m .45862 .76496 L .45983 .76253 L F
.585 .254 .376 r
.45983 .76253 m .46175 .76405 L .46188 .763 L F
.45983 .76253 m .45862 .76496 L .46175 .76405 L F
.495 .352 .616 r
.47809 .87403 m .48077 .87458 L .47839 .87247 L F
.47809 .87403 m .47862 .87588 L .48077 .87458 L F
.441 .396 .712 r
.47882 .87794 m .47862 .87588 L .47809 .87403 L F
.484 .118 .268 r
.65854 .61796 m .66072 .61795 L .66163 .61553 L F
0 0 .324 r
.66163 .61553 m .66246 .61221 L .66305 .6127 L F
.66163 .61553 m .66254 .61472 L .66246 .61221 L F
0 0 0 r
.66163 .61553 m .66072 .61795 L .66254 .61472 L F
.557 .352 .559 r
.35746 .74162 m .35939 .7435 L .35958 .74119 L F
.443 .347 .652 r
.35746 .74162 m .35778 .74412 L .35939 .7435 L F
.768 .676 .761 r
.71245 .70911 m .71569 .70937 L .71462 .70633 L F
.519 0 0 r
.71245 .70911 m .71484 .70979 L .71569 .70937 L F
.989 .752 .486 r
.71484 .70979 m .71561 .71235 L .71569 .70937 L F
.547 .393 .624 r
.49298 .87186 m .49085 .87244 L .49023 .86988 L F
0 0 0 r
.49222 .87173 m .49085 .87244 L .49246 .872 L F
.49222 .87173 m .49246 .872 L .49298 .87186 L F
.547 .393 .624 r
.49298 .87186 m .49023 .86988 L .49205 .86864 L F
.986 .712 .354 r
.49205 .86864 m .49222 .87173 L .49298 .87186 L F
.49205 .86864 m .49222 .87173 L .49298 .87186 L F
0 0 .258 r
.49265 .8704 m .49222 .87173 L .49205 .86864 L F
.463 .341 .629 r
.49265 .8704 m .49199 .87147 L .49222 .87173 L F
0 0 0 r
.49222 .87173 m .49207 .87188 L .49085 .87244 L F
.308 .787 .917 r
.49085 .87244 m .49202 .87266 L .49026 .87271 L F
.48867 .87276 m .49202 .87266 L .49085 .87244 L F
.217 .729 .884 r
.49438 .8725 m .49202 .87266 L .49085 .87244 L F
.49438 .8725 m .49202 .87266 L .49085 .87244 L F
.49438 .8725 m .49085 .87244 L .49298 .87186 L F
.49438 .8725 m .49085 .87244 L .49298 .87186 L F
0 0 0 r
.49207 .87188 m .48985 .87412 L .49085 .87244 L F
.463 .341 .629 r
.49199 .87147 m .49109 .87292 L .49222 .87173 L F
.308 .787 .917 r
.49085 .87244 m .49026 .87271 L .48867 .87276 L F
.158 .609 .933 r
.33149 .65082 m .33266 .65226 L .33058 .65032 L F
.422 .815 .986 r
.3325 .65108 m .33336 .65069 L .3348 .6512 L F
.494 .788 .997 r
.33149 .65082 m .3348 .6512 L .33419 .65241 L F
.593 .094 .039 r
.33149 .65082 m .33135 .65102 L .3348 .6512 L F
.422 .815 .986 r
.33135 .65102 m .33238 .65085 L .3325 .65108 L F
.33238 .65085 m .33336 .65069 L .3325 .65108 L F
.158 .609 .933 r
.33149 .65082 m .33275 .65156 L .33266 .65226 L F
.33275 .65156 m .33419 .65241 L .33314 .65231 L F
.33275 .65156 m .33314 .65231 L .33266 .65226 L F
.561 .449 .683 r
.47802 .75656 m .48032 .75777 L .47974 .75434 L F
.674 .528 .679 r
.47865 .75926 m .48032 .75777 L .47802 .75656 L F
.592 .397 .587 r
.56164 .81188 m .55916 .81331 L .55915 .81094 L F
.819 .951 .906 r
.5599 .81186 m .55812 .81286 L .55916 .81331 L F
.592 .397 .587 r
.56118 .81171 m .55915 .81094 L .56268 .81153 L F
.819 .951 .906 r
.56045 .81079 m .55915 .81195 L .5599 .81186 L F
.55915 .81195 m .55812 .81286 L .5599 .81186 L F
.592 .397 .587 r
.56164 .81188 m .56118 .81171 L .56268 .81153 L F
.56118 .81171 m .56268 .81153 L .56268 .81153 L F
.414 .855 .757 r
.56392 .81078 m .56164 .81188 L .56268 .81153 L F
.191 0 0 r
.39827 .74942 m .39642 .74998 L .39494 .74983 L F
.232 .704 .941 r
.40052 .75064 m .39642 .74998 L .39827 .74942 L F
.613 .165 .163 r
.40077 .74993 m .40052 .75064 L .39827 .74942 L F
0 0 0 r
.40813 .79094 m .40976 .7897 L .41161 .78901 L F
.55 .418 .653 r
.3349 .77901 m .33698 .77867 L .33679 .77631 L F
.577 .425 .638 r
.3349 .77901 m .33714 .78105 L .33698 .77867 L F
.3349 .77901 m .33503 .78141 L .33714 .78105 L F
.498 .314 .561 r
.49028 .82707 m .48759 .83075 L .48984 .82874 L F
.515 .533 .812 r
.3555 .83528 m .35813 .83598 L .35678 .8337 L F
.3555 .83528 m .35813 .83598 L .35678 .8337 L F
.534 .416 .664 r
.36907 .77286 m .36748 .77636 L .36738 .77336 L F
.614 .442 .625 r
.71548 .63409 m .71349 .63569 L .71336 .63436 L F
.561 .349 .551 r
.67812 .71212 m .67891 .71129 L .67785 .71101 L F
.67812 .71212 m .68 .71383 L .67891 .71129 L F
.67812 .71212 m .67754 .71468 L .68 .71383 L F
.584 .435 .645 r
.3469 .75749 m .34904 .75718 L .3489 .75475 L F
.56 .403 .624 r
.3469 .75749 m .34907 .75954 L .34904 .75718 L F
.3469 .75749 m .34701 .7599 L .34907 .75954 L F
.209 0 0 r
.32071 .71417 m .32197 .71445 L .32263 .71377 L F
.32071 .71417 m .31887 .71561 L .32197 .71445 L F
.596 .447 .65 r
.33679 .77631 m .33893 .77366 L .33685 .77412 L F
.722 .497 .584 r
.56977 .80232 m .56839 .79977 L .5706 .80153 L F
.454 .096 .268 r
.56839 .79977 m .56775 .8013 L .5706 .80153 L F
.484 .804 1 r
.56775 .8013 m .5707 .80143 L .5706 .80153 L F
.5707 .80143 m .5714 .80146 L .5706 .80153 L F
.722 .497 .584 r
.5701 .80293 m .56977 .80232 L .5706 .80153 L F
.019 0 0 r
.56923 .80435 m .56921 .80366 L .5701 .80293 L F
.565 .762 .971 r
.5714 .80146 m .5701 .80293 L .5706 .80153 L F
.349 0 0 r
.32044 .67456 m .31884 .67598 L .31681 .6762 L F
.156 0 0 r
.32084 .67544 m .32044 .67456 L .32241 .67446 L F
.32084 .67544 m .31884 .67598 L .32044 .67456 L F
.785 .722 .793 r
.65582 .59407 m .65817 .5975 L .65401 .59625 L F
.569 .644 .885 r
.65981 .59607 m .65817 .5975 L .65582 .59407 L F
.288 .176 .548 r
.65981 .59607 m .65882 .59769 L .65817 .5975 L F
.452 .715 .98 r
.64288 .59819 m .64692 .59922 L .64582 .59979 L F
.897 .98 .805 r
.40353 .75742 m .40228 .75758 L .40313 .75626 L F
.836 .621 .612 r
.40077 .75902 m .40315 .76024 L .40353 .75742 L F
.121 0 0 r
.4196 .72328 m .42191 .72338 L .42304 .72316 L F
.616 .137 .094 r
.42191 .72338 m .42497 .72319 L .42304 .72316 L F
.409 .596 .921 r
.47031 .72896 m .46948 .73044 L .46808 .72929 L F
.47031 .72896 m .47123 .73053 L .46948 .73044 L F
.46 .241 .494 r
.36682 .68684 m .3649 .68957 L .36573 .68787 L F
.176 .712 .762 r
.36904 .84837 m .36682 .84877 L .36562 .84887 L F
.36904 .84837 m .36682 .84877 L .36562 .84887 L F
.643 .597 .787 r
.47916 .73869 m .47693 .73908 L .47578 .73626 L F
.471 0 0 r
.53473 .83068 m .5321 .83152 L .53319 .83061 L F
.634 .857 .984 r
.7035 .60317 m .70654 .60303 L .70552 .60176 L F
.587 .834 .991 r
.70654 .60303 m .70775 .60174 L .70552 .60176 L F
.70654 .60303 m .70806 .60251 L .70775 .60174 L F
.544 .601 .861 r
.70654 .60303 m .70932 .60413 L .70806 .60251 L F
.793 .44 .389 r
.70793 .59901 m .70949 .60009 L .71064 .59917 L F
.889 .987 .729 r
.71064 .59917 m .70949 .60009 L .71217 .59577 L F
.871 .476 .011 r
.57108 .80606 m .57237 .80824 L .57162 .80639 L F
.595 .471 .681 r
.3486 .75232 m .35109 .75438 L .35082 .75201 L F
.3486 .75232 m .3489 .75475 L .35109 .75438 L F
.783 .973 .915 r
.67754 .71468 m .67502 .71686 L .67445 .71614 L F
.855 .822 .816 r
.62486 .6396 m .62427 .63702 L .62226 .63914 L F
.895 .757 .7 r
.62175 .64144 m .62486 .6396 L .62226 .63914 L F
.62175 .64144 m .62293 .64212 L .62486 .6396 L F
.813 .616 .637 r
.62293 .64212 m .62613 .64264 L .62486 .6396 L F
.969 .913 .698 r
.62486 .6396 m .62519 .63574 L .62427 .63702 L F
.62486 .6396 m .62533 .63755 L .62519 .63574 L F
.513 .168 .319 r
.6376 .64737 m .63824 .64487 L .637 .64449 L F
.777 .634 .703 r
.51481 .77363 m .51653 .7765 L .51293 .77606 L F
.808 .628 .658 r
.51653 .7765 m .51277 .77849 L .51293 .77606 L F
.51653 .7765 m .51612 .77889 L .51277 .77849 L F
0 0 0 r
.39431 .78218 m .39442 .78193 L .39445 .78188 L F
.538 .77 .983 r
.3967 .782 m .39467 .78139 L .39446 .78186 L F
.436 .47 .797 r
.39445 .78188 m .39442 .78193 L .39442 .78185 L F
.211 .282 .72 r
.39442 .78185 m .39442 .78193 L .39333 .78099 L F
.659 .105 0 r
.39333 .78099 m .39442 .78193 L .39431 .78218 L F
.538 .77 .983 r
.39478 .78215 m .39333 .78099 L .39431 .78218 L F
0 0 0 r
.39431 .78218 m .39445 .78188 L .39598 .77961 L F
.538 .77 .983 r
.39446 .78186 m .39333 .78099 L .39442 .78185 L F
.39467 .78139 m .39333 .78099 L .39446 .78186 L F
.3949 .78214 m .39442 .78185 L .39478 .78215 L F
.3967 .782 m .39442 .78185 L .3949 .78214 L F
.436 .47 .797 r
.39598 .77961 m .39445 .78188 L .39428 .77959 L F
.39445 .78188 m .39442 .78185 L .39428 .77959 L F
.211 .282 .72 r
.39428 .77959 m .39442 .78185 L .39333 .78099 L F
.229 .745 .855 r
.39706 .78154 m .3967 .782 L .39431 .78218 L F
.39706 .78154 m .39843 .78178 L .3967 .782 L F
.403 .551 .889 r
.3914 .77841 m .39076 .78005 L .38918 .7807 L F
.3914 .77841 m .39333 .78099 L .39076 .78005 L F
.669 .352 .428 r
.38351 .78359 m .38571 .78453 L .38616 .78333 L F
.3 0 .263 r
.38616 .78333 m .38571 .78453 L .38748 .78376 L F
.428 0 .12 r
.30732 .67851 m .30926 .67865 L .30662 .67935 L F
.52 .623 .894 r
.68481 .59572 m .68549 .59732 L .68696 .59555 L F
.538 .65 .907 r
.68549 .59732 m .68785 .59716 L .68696 .59555 L F
.531 .675 .93 r
.70447 .59857 m .70318 .59992 L .70092 .59684 L F
.427 .759 .996 r
.45261 .72593 m .452 .72708 L .45009 .72564 L F
.45261 .72593 m .45391 .72684 L .452 .72708 L F
.232 0 .126 r
.44128 .76829 m .44206 .76965 L .44322 .7676 L F
.44128 .76829 m .44016 .77044 L .44206 .76965 L F
.532 .402 .649 r
.40453 .74337 m .40518 .74612 L .40253 .74413 L F
.553 .679 .922 r
.3678 .67326 m .36418 .67177 L .36635 .67129 L F
.522 .626 .896 r
.36823 .67097 m .3678 .67326 L .36635 .67129 L F
.36823 .67097 m .36967 .67302 L .3678 .67326 L F
0 0 .563 r
.66612 .61805 m .66588 .61555 L .66343 .61675 L F
.66612 .61805 m .66662 .61849 L .66588 .61555 L F
.609 .557 .771 r
.49488 .75816 m .49144 .75506 L .49368 .75455 L F
.546 .336 .547 r
.55095 .80298 m .5535 .79994 L .55166 .80067 L F
.519 .773 .989 r
.45176 .73977 m .45277 .73846 L .45017 .73938 L F
.45176 .73977 m .4541 .73938 L .45277 .73846 L F
.575 .781 .977 r
.33041 .78428 m .33265 .78412 L .33281 .7841 L F
.589 .354 .528 r
.33021 .7866 m .33265 .78412 L .33041 .78428 L F
.645 .678 .867 r
.37303 .7795 m .37467 .78175 L .37134 .78094 L F
.791 .851 .896 r
.37525 .77918 m .37467 .78175 L .37303 .7795 L F
.37525 .77918 m .37713 .78004 L .37467 .78175 L F
.46 .241 .494 r
.36682 .68684 m .36736 .68947 L .3649 .68957 L F
.441 .16 .39 r
.3677 .68767 m .36736 .68947 L .36682 .68684 L F
.54 .391 .627 r
.34302 .76577 m .34536 .76553 L .34489 .7626 L F
.541 .37 .599 r
.34311 .76808 m .34536 .76553 L .34302 .76577 L F
.747 .668 .773 r
.70177 .72104 m .6984 .7201 L .70049 .71912 L F
.664 .626 .801 r
.70385 .72007 m .70177 .72104 L .70049 .71912 L F
.444 .226 .486 r
.37374 .6788 m .37043 .68218 L .37175 .67979 L F
.874 .863 .826 r
.62893 .60957 m .62798 .61327 L .62687 .61239 L F
.62893 .60957 m .6301 .61052 L .62798 .61327 L F
.674 .233 .196 r
.3231 .65126 m .32529 .65231 L .3267 .65142 L F
.562 .906 .684 r
.3267 .65142 m .32707 .65083 L .32865 .65063 L F
.3267 .65142 m .32529 .65231 L .32707 .65083 L F
.838 .594 .57 r
.56664 .797 m .56839 .79977 L .56822 .79769 L F
.581 .424 .634 r
.3753 .76251 m .37324 .76541 L .37314 .76288 L F
.972 .745 .536 r
.6331 .6018 m .63413 .60474 L .63293 .60407 L F
.757 .672 .768 r
.63646 .60224 m .63413 .60474 L .6331 .6018 L F
.58 .754 .96 r
.55148 .81346 m .55276 .81223 L .55045 .81234 L F
.55148 .81346 m .5537 .81299 L .55276 .81223 L F
.866 .442 .204 r
.67979 .72269 m .67879 .72267 L .67709 .72008 L F
.414 .742 .993 r
.67979 .72269 m .681 .72187 L .67879 .72267 L F
.67979 .72269 m .68221 .72276 L .681 .72187 L F
.175 0 0 r
.31485 .71688 m .31714 .71608 L .3155 .71617 L F
.622 .208 .235 r
.37121 .73491 m .37365 .73521 L .3751 .73354 L F
.327 0 .076 r
.37365 .73521 m .37703 .733 L .3751 .73354 L F
.778 .755 .832 r
.68283 .69887 m .68065 .69958 L .68188 .69992 L F
.687 .979 .886 r
.68524 .6972 m .68283 .69887 L .68387 .69747 L F
.545 .483 .737 r
.68188 .69992 m .68387 .69747 L .68283 .69887 L F
.487 .633 .918 r
.45964 .74029 m .46038 .74164 L .46155 .74021 L F
.352 .433 .805 r
.46038 .74164 m .46279 .7434 L .46155 .74021 L F
.807 .662 .702 r
.62598 .64491 m .62613 .64264 L .62293 .64212 L F
.635 .639 .836 r
.70719 .72239 m .70385 .72007 L .70609 .71949 L F
.703 .633 .776 r
.70929 .71984 m .70719 .72239 L .70609 .71949 L F
.597 .672 .892 r
.48676 .88687 m .48877 .88625 L .48552 .88528 L F
.402 .805 .983 r
.64158 .64185 m .64241 .64237 L .63936 .64222 L F
.63936 .64222 m .64241 .64237 L .64158 .64185 L F
.465 .151 .348 r
.52564 .778 m .52422 .77674 L .52598 .77595 L F
.52564 .778 m .52351 .77837 L .52422 .77674 L F
0 .465 .776 r
.32596 .67543 m .32674 .67539 L .32391 .67472 L F
.316 0 .065 r
.64245 .6554 m .64153 .65701 L .63934 .65751 L F
.149 0 0 r
.64391 .65539 m .64245 .6554 L .64483 .65473 L F
.64391 .65539 m .64153 .65701 L .64245 .6554 L F
.811 .976 .68 r
.6749 .63894 m .67484 .63961 L .67711 .63655 L F
.731 .676 .129 r
.6749 .63894 m .67455 .64131 L .67484 .63961 L F
.887 .875 .819 r
.71873 .72567 m .71945 .72752 L .72073 .72575 L F
.732 .257 .119 r
.73161 .74424 m .73041 .74505 L .72853 .74335 L F
.713 .22 .069 r
.72853 .74335 m .73086 .74473 L .73161 .74424 L F
.824 .973 .667 r
.73161 .74424 m .73287 .74159 L .73364 .74343 L F
.73161 .74424 m .73086 .74473 L .73287 .74159 L F
0 0 0 r
.73254 .74423 m .73161 .74424 L .73364 .74343 L F
.73254 .74423 m .73041 .74505 L .73161 .74424 L F
0 0 .131 r
.36332 .80815 m .3645 .80642 L .36377 .80793 L F
.604 .947 .794 r
.36415 .80675 m .36672 .80473 L .36514 .80548 L F
0 0 .131 r
.3645 .80642 m .36514 .80548 L .36475 .80618 L F
.3645 .80642 m .36475 .80618 L .36377 .80793 L F
.604 .947 .794 r
.36416 .80675 m .36719 .80481 L .36672 .80473 L F
.36415 .80675 m .36416 .80675 L .36416 .80675 L F
.36416 .80675 m .36719 .80481 L .36416 .80675 L F
0 0 0 r
.36719 .80481 m .36888 .80452 L .36672 .80473 L F
.732 .215 0 r
.64114 .62342 m .64334 .62541 L .64224 .624 L F
.807 .662 .702 r
.62598 .64491 m .62293 .64212 L .62269 .64448 L F
.801 .608 .642 r
.62617 .64726 m .62598 .64491 L .62269 .64448 L F
.765 .582 .65 r
.62617 .64726 m .62741 .64774 L .62598 .64491 L F
.923 .939 .582 r
.72061 .72443 m .72073 .72575 L .72157 .72344 L F
.887 .875 .819 r
.71873 .72567 m .72073 .72575 L .72061 .72443 L F
.788 .832 .886 r
.34969 .81211 m .34744 .81375 L .35038 .81311 L F
.546 .901 .972 r
.35038 .81311 m .3515 .81205 L .34969 .81211 L F
.311 0 0 r
.44544 .76754 m .44755 .76726 L .44904 .76583 L F
.495 .074 .17 r
.44755 .76726 m .45117 .7655 L .44904 .76583 L F
.702 .614 .754 r
.65838 .58838 m .65912 .59161 L .65577 .59118 L F
.838 .677 .682 r
.65912 .59161 m .65582 .59407 L .65577 .59118 L F
.65912 .59161 m .6586 .59476 L .65582 .59407 L F
.558 .519 .768 r
.66124 .59128 m .65912 .59161 L .65838 .58838 L F
.914 .742 .654 r
.67502 .61037 m .67492 .61284 L .67393 .60965 L F
.477 .744 .987 r
.67502 .61037 m .67698 .61059 L .67393 .60965 L F
.833 .692 .708 r
.69088 .60094 m .69223 .60243 L .69122 .59919 L F
.757 .759 .854 r
.68916 .60206 m .69223 .60243 L .69088 .60094 L F
.614 .633 .846 r
.69223 .60243 m .69303 .59929 L .69122 .59919 L F
.69223 .60243 m .69446 .60194 L .69303 .59929 L F
.372 0 .085 r
.44588 .77603 m .44438 .77785 L .44222 .77814 L F
.154 0 0 r
.44757 .7775 m .44438 .77785 L .44588 .77603 L F
.836 .75 .768 r
.6365 .61149 m .63862 .61322 L .63785 .61039 L F
.79 .298 0 r
.6365 .61149 m .6378 .61313 L .63862 .61322 L F
.533 .708 .952 r
.6378 .61313 m .64075 .61467 L .63862 .61322 L F
.86 .731 .719 r
.57509 .79931 m .57564 .80234 L .57696 .80048 L F
.438 .34 .647 r
.5481 .8111 m .54994 .811 L .54964 .80752 L F
.437 .502 .828 r
.5481 .8111 m .55045 .81234 L .54994 .811 L F
0 0 0 r
.48422 .87116 m .48557 .87064 L .48337 .87112 L F
.48422 .87116 m .48337 .87112 L .4821 .86939 L F
.65 .689 .873 r
.37303 .7795 m .37134 .78094 L .36978 .77841 L F
.811 .976 .68 r
.6749 .63894 m .67711 .63655 L .67627 .63562 L F
.82 .865 .881 r
.67627 .63562 m .67711 .63655 L .68016 .63386 L F
.7 .397 .459 r
.5006 .77046 m .49912 .77286 L .49715 .7707 L F
.603 .235 .318 r
.50275 .77126 m .49912 .77286 L .5006 .77046 L F
.659 .46 .604 r
.38499 .75709 m .38272 .75499 L .38509 .75465 L F
.38499 .75709 m .38275 .75723 L .38272 .75499 L F
.815 .631 .654 r
.53525 .83211 m .53679 .83501 L .53731 .83275 L F
.517 .288 .507 r
.65577 .59118 m .65582 .59407 L .65384 .59389 L F
0 0 0 r
.41501 .7761 m .41579 .7761 L .41698 .77645 L F
.41501 .7761 m .4134 .7774 L .41579 .7761 L F
.464 .569 .876 r
.67797 .59096 m .67933 .59361 L .68131 .59359 L F
.695 .803 .932 r
.72207 .6126 m .71983 .61336 L .71887 .61237 L F
.753 .43 .437 r
.69793 .70578 m .69745 .70387 L .69581 .70352 L F
.721 .439 .499 r
.69554 .70504 m .69793 .70578 L .69581 .70352 L F
.714 .663 .798 r
.6971 .7037 m .69793 .70578 L .69586 .70526 L F
.756 .584 .663 r
.69581 .70352 m .69745 .70387 L .69697 .70112 L F
.714 .663 .798 r
.69835 .70214 m .69815 .70382 L .6971 .7037 L F
.991 .771 .389 r
.69917 .70392 m .70059 .70411 L .69745 .70387 L F
.69982 .70394 m .70023 .70404 L .69917 .70392 L F
.69982 .70394 m .69745 .70387 L .69793 .70578 L F
.714 .663 .798 r
.69815 .70382 m .69793 .70578 L .6971 .7037 L F
.991 .771 .389 r
.70023 .70404 m .70059 .70411 L .69917 .70392 L F
.69982 .70394 m .70039 .70611 L .70059 .70411 L F
.843 .524 0 r
.70259 .70343 m .70059 .70411 L .70039 .70611 L F
.487 .592 .884 r
.36078 .66186 m .35978 .66367 L .35835 .66129 L F
.426 .515 .846 r
.36078 .66186 m .36166 .66386 L .35978 .66367 L F
.624 .578 .783 r
.36312 .6664 m .35978 .66367 L .36166 .66386 L F
.875 .439 .14 r
.67311 .61562 m .67026 .61247 L .67054 .61493 L F
.831 .371 0 r
.67054 .61493 m .67283 .61781 L .67311 .61562 L F
.235 .016 .363 r
.67311 .61562 m .67387 .61547 L .67492 .61284 L F
.323 .345 .728 r
.67311 .61562 m .67523 .61734 L .67387 .61547 L F
.543 .336 .549 r
.67283 .61781 m .67523 .61734 L .67311 .61562 L F
.404 .095 .324 r
.6317 .66103 m .63184 .66284 L .62971 .66341 L F
.348 .057 .321 r
.6317 .66103 m .63433 .66052 L .63184 .66284 L F
.533 .358 .59 r
.34097 .77076 m .34311 .76808 L .34117 .76874 L F
.486 .318 .578 r
.37542 .67651 m .37374 .6788 L .37378 .67702 L F
.732 .888 .952 r
.37022 .68244 m .36961 .68276 L .37043 .68218 L F
.59 .764 .962 r
.4541 .73938 m .45735 .74036 L .45604 .73803 L F
.559 .602 .852 r
.45735 .74036 m .45827 .73757 L .45604 .73803 L F
.45735 .74036 m .45964 .74029 L .45827 .73757 L F
.029 0 0 r
.37772 .80207 m .38118 .79999 L .37953 .80128 L F
0 0 0 r
.38324 .79964 m .37953 .80128 L .38118 .79999 L F
.406 .28 .594 r
.34759 .6876 m .34938 .68439 L .34753 .6852 L F
.336 .371 .75 r
.71349 .72059 m .71387 .72333 L .71309 .72063 L F
.71424 .72147 m .71387 .72333 L .71349 .72059 L F
.604 .411 .593 r
.7151 .72208 m .7127 .72492 L .71497 .72425 L F
0 0 0 r
.71403 .72366 m .7127 .72492 L .7151 .72208 L F
.71403 .72366 m .71495 .72231 L .71284 .72169 L F
.71495 .72231 m .7151 .72208 L .7147 .72201 L F
.71495 .72231 m .7147 .72201 L .71284 .72169 L F
.336 .371 .75 r
.71443 .72048 m .71424 .72147 L .71349 .72059 L F
.742 .311 0 r
.72906 .71116 m .73075 .71382 L .72954 .71225 L F
.177 .503 .909 r
.693 .59477 m .68975 .59252 L .6923 .59336 L F
.359 .586 .93 r
.69436 .59369 m .693 .59477 L .6923 .59336 L F
.69436 .59369 m .69633 .59593 L .693 .59477 L F
.567 .38 .588 r
.33615 .69572 m .33387 .69852 L .33601 .69818 L F
.903 .926 .822 r
.6894 .63315 m .68836 .63675 L .68925 .63405 L F
.6894 .63315 m .68738 .63595 L .68836 .63675 L F
0 .007 .504 r
.68964 .63802 m .68836 .63675 L .68738 .63595 L F
.726 .747 .869 r
.69426 .63932 m .69012 .63849 L .69338 .63856 L F
.69012 .63849 m .68892 .63824 L .68995 .63832 L F
.69012 .63849 m .68995 .63832 L .69338 .63856 L F
0 .007 .504 r
.69015 .63851 m .69102 .63937 L .69054 .6389 L F
.726 .747 .869 r
.69012 .63849 m .69102 .63937 L .68892 .63824 L F
.69426 .63932 m .69102 .63937 L .69012 .63849 L F
.424 .771 .996 r
.69254 .63778 m .68976 .63813 L .68964 .63802 L F
.68976 .63813 m .68892 .63824 L .68964 .63802 L F
0 .007 .504 r
.68963 .638 m .68973 .6381 L .68836 .63675 L F
.68973 .6381 m .69054 .6389 L .69033 .63869 L F
.424 .771 .996 r
.69254 .63778 m .69338 .63856 L .68995 .63832 L F
0 .007 .504 r
.68976 .63813 m .69033 .63869 L .68972 .63809 L F
.424 .771 .996 r
.68976 .63813 m .68995 .63832 L .68892 .63824 L F
.69254 .63778 m .68995 .63832 L .68976 .63813 L F
0 .007 .504 r
.68972 .63809 m .69033 .63869 L .68836 .63675 L F
.68973 .6381 m .68976 .63813 L .68972 .63809 L F
.68964 .63802 m .69102 .63937 L .69015 .63851 L F
.68964 .63802 m .69054 .6389 L .68963 .638 L F
.781 .896 .925 r
.69937 .63666 m .69774 .63801 L .69544 .63781 L F
.468 .388 .683 r
.69381 .71194 m .6954 .70875 L .69278 .70896 L F
.69381 .71194 m .69584 .71172 L .6954 .70875 L F
.929 .566 .308 r
.72156 .70391 m .72224 .70609 L .72348 .70653 L F
.464 0 0 r
.72484 .70768 m .72348 .70653 L .72224 .70609 L F
.72484 .70768 m .72577 .70839 L .72348 .70653 L F
.48 .25 .487 r
.34384 .69322 m .34583 .69277 L .34622 .69063 L F
.214 .02 .388 r
.34622 .69063 m .34724 .69192 L .34795 .69004 L F
.34622 .69063 m .34583 .69277 L .34724 .69192 L F
.611 .65 .864 r
.71551 .60698 m .71663 .60389 L .71432 .60429 L F
.71551 .60698 m .71774 .60641 L .71663 .60389 L F
.111 0 .038 r
.33817 .69758 m .33991 .69698 L .34172 .69589 L F
.411 0 .093 r
.33991 .69698 m .34332 .69523 L .34172 .69589 L F
0 0 0 r
.3854 .79931 m .38909 .79782 L .38729 .7989 L F
.38729 .7989 m .38909 .79782 L .39089 .7971 L F
.469 .277 .537 r
.33399 .7008 m .33601 .69818 L .33387 .69852 L F
.798 .639 .684 r
.60728 .65005 m .6092 .65329 L .60704 .65238 L F
.829 .678 .695 r
.6092 .65329 m .60562 .65517 L .60704 .65238 L F
.6092 .65329 m .60826 .65521 L .60562 .65517 L F
.726 .691 .816 r
.68948 .70855 m .69016 .71233 L .69278 .70896 L F
.692 .376 .436 r
.7227 .74115 m .72187 .7435 L .71949 .74134 L F
.764 .572 .637 r
.72554 .74103 m .72187 .7435 L .7227 .74115 L F
.897 .884 .813 r
.62519 .63574 m .62725 .63513 L .62626 .63399 L F
.62519 .63574 m .62533 .63755 L .62725 .63513 L F
.651 .804 .957 r
.62626 .63399 m .62725 .63513 L .63115 .63346 L F
.238 0 0 r
.41698 .77645 m .41904 .77678 L .42059 .77648 L F
.253 0 0 r
.41904 .77678 m .42265 .77605 L .42059 .77648 L F
.368 .822 .714 r
.64038 .619 m .63838 .61978 L .63721 .62044 L F
.722 .889 .957 r
.64038 .619 m .63969 .61779 L .63838 .61978 L F
.287 .072 .403 r
.71779 .61807 m .71585 .62076 L .71732 .62 L F
0 0 .182 r
.71638 .62344 m .71732 .62 L .71585 .62076 L F
0 0 .157 r
.6908 .70031 m .69379 .70084 L .69058 .70016 L F
.809 .651 .686 r
.69383 .70324 m .69664 .70134 L .69379 .70084 L F
0 0 .157 r
.6941 .70254 m .694 .7028 L .69379 .70084 L F
.694 .7028 m .69383 .70324 L .69383 .70313 L F
.694 .7028 m .69383 .70313 L .69379 .70084 L F
.809 .651 .686 r
.69664 .70134 m .69697 .70112 L .69379 .70084 L F
.807 .649 .686 r
.69828 .70002 m .69498 .70189 L .695 .69966 L F
.573 .938 .816 r
.69599 .70074 m .6947 .70169 L .69498 .70189 L F
.57 .904 .665 r
.69498 .70189 m .69427 .70228 L .69599 .70074 L F
.69427 .70228 m .69374 .70257 L .6944 .70203 L F
.887 .712 .198 r
.69498 .70189 m .6947 .70169 L .695 .69966 L F
.57 .904 .665 r
.69427 .70228 m .6944 .70203 L .69599 .70074 L F
0 0 .157 r
.6941 .70254 m .69379 .70084 L .6908 .70031 L F
.809 .651 .686 r
.69383 .70324 m .69581 .70352 L .69697 .70112 L F
.489 .113 .252 r
.70596 .63068 m .70829 .63052 L .70902 .62846 L F
.698 .427 .511 r
.70829 .63052 m .71116 .62828 L .70902 .62846 L F
.369 .601 .937 r
.34157 .65277 m .341 .65407 L .33963 .65315 L F
.34157 .65277 m .34318 .6545 L .341 .65407 L F
.461 0 0 r
.7047 .62326 m .70689 .62377 L .70797 .62357 L F
.267 0 0 r
.70797 .62357 m .70716 .62365 L .7047 .62326 L F
.571 .852 .996 r
.70729 .62366 m .70689 .62377 L .70677 .62362 L F
.267 0 0 r
.70716 .62365 m .70702 .62367 L .70677 .62362 L F
.70716 .62365 m .70677 .62362 L .7047 .62326 L F
.571 .852 .996 r
.70975 .62304 m .70713 .6222 L .7079 .62187 L F
.814 .999 .837 r
.70759 .62226 m .70762 .62236 L .70975 .62304 L F
.70762 .62236 m .70797 .62357 L .70975 .62304 L F
.571 .852 .996 r
.70975 .62304 m .70729 .62366 L .70716 .62357 L F
.70722 .62282 m .70716 .62357 L .70599 .6227 L F
.70729 .62366 m .70677 .62362 L .70599 .6227 L F
.726 .828 .929 r
.70599 .6227 m .70664 .6237 L .70722 .62282 L F
.571 .852 .996 r
.70725 .62278 m .70599 .6227 L .70762 .62236 L F
.726 .828 .929 r
.70599 .6227 m .70722 .62282 L .70725 .62278 L F
.571 .852 .996 r
.70722 .62281 m .70599 .6227 L .70725 .62278 L F
.726 .828 .929 r
.70599 .6227 m .70725 .62278 L .70759 .62226 L F
.571 .852 .996 r
.70722 .62281 m .70722 .62282 L .70599 .6227 L F
.814 .999 .837 r
.70762 .62236 m .70721 .62292 L .70797 .62357 L F
.70721 .62292 m .70716 .62365 L .70797 .62357 L F
.571 .852 .996 r
.70975 .62304 m .70716 .62357 L .70722 .62281 L F
.814 .999 .837 r
.70721 .62292 m .70664 .6237 L .70716 .62365 L F
.70759 .62226 m .70725 .62278 L .70762 .62236 L F
.70725 .62278 m .70664 .6237 L .70762 .62236 L F
.571 .852 .996 r
.70762 .62236 m .70599 .6227 L .70713 .6222 L F
.70975 .62304 m .70722 .62281 L .70762 .62236 L F
.231 .637 .958 r
.70599 .6227 m .70677 .62362 L .7047 .62326 L F
.70677 .62362 m .70689 .62377 L .7047 .62326 L F
.267 0 0 r
.70702 .62367 m .70664 .6237 L .7047 .62326 L F
.237 .752 .758 r
.70797 .62357 m .70689 .62377 L .70975 .62304 L F
.696 .802 .93 r
.42862 .7408 m .42994 .74189 L .43206 .74105 L F
.69 .635 .789 r
.51058 .7714 m .50828 .77167 L .50707 .76748 L F
.425 .566 .892 r
.73034 .73206 m .72915 .7335 L .72824 .73266 L F
.73034 .73206 m .7312 .73413 L .72915 .7335 L F
.81 .434 .344 r
.73158 .73512 m .72824 .73266 L .72915 .7335 L F
.262 0 .304 r
.33998 .7169 m .33954 .71921 L .33777 .71905 L F
.255 0 .179 r
.33954 .71921 m .3369 .72137 L .33777 .71905 L F
.512 .576 .857 r
.36337 .66342 m .36312 .6664 L .36166 .66386 L F
.36337 .66342 m .36482 .66589 L .36312 .6664 L F
.441 .318 .616 r
.36482 .66589 m .36499 .66824 L .36312 .6664 L F
.504 .321 .566 r
.36312 .6664 m .36499 .66824 L .36302 .6687 L F
.138 .24 .708 r
.43206 .74105 m .43308 .74444 L .43399 .74322 L F
.508 .769 .99 r
.43308 .74444 m .43537 .74431 L .43399 .74322 L F
.41 .683 .974 r
.35705 .66007 m .35636 .66128 L .35503 .6603 L F
.35705 .66007 m .35835 .66129 L .35636 .66128 L F
.354 0 0 r
.44085 .74099 m .43961 .74105 L .43749 .74072 L F
.189 0 0 r
.44312 .74116 m .43961 .74105 L .44085 .74099 L F
.853 .915 .873 r
.65465 .64991 m .65109 .65157 L .65254 .65059 L F
.579 .426 .638 r
.34904 .75718 m .35109 .75438 L .3489 .75475 L F
.656 .489 .646 r
.60533 .67129 m .60342 .66874 L .607 .66851 L F
.635 .38 .516 r
.60903 .67084 m .607 .66851 L .60877 .66887 L F
.60903 .67084 m .60533 .67129 L .607 .66851 L F
.611 .645 .859 r
.7095 .6051 m .71116 .60356 L .70932 .60413 L F
.7095 .6051 m .71226 .60477 L .71116 .60356 L F
.124 .64 .89 r
.43602 .72482 m .43936 .72546 L .43733 .72557 L F
0 .222 .704 r
.7283 .71031 m .7267 .70948 L .72577 .70839 L F
.7283 .71031 m .72906 .71116 L .7267 .70948 L F
.576 .349 .535 r
.59017 .67175 m .59238 .67361 L .5923 .67101 L F
.71 .644 .781 r
.46759 .74899 m .47069 .74966 L .46934 .74877 L F
.699 .84 .95 r
.46934 .74877 m .47069 .74966 L .47311 .74878 L F
.774 .633 .705 r
.48877 .88625 m .49221 .88634 L .49114 .88309 L F
.695 .591 .735 r
.49114 .88309 m .49221 .88634 L .49445 .88558 L F
.724 .559 .666 r
.49812 .8738 m .49746 .87551 L .49543 .87457 L F
.614 .295 .406 r
.49543 .87457 m .49701 .87482 L .49812 .8738 L F
.724 .734 .859 r
.49746 .87551 m .50063 .87543 L .49915 .8744 L F
.49746 .87551 m .49915 .8744 L .49901 .87443 L F
.524 .342 .575 r
.49746 .87551 m .4991 .87436 L .49812 .8738 L F
.724 .734 .859 r
.49901 .87443 m .49915 .8744 L .4991 .87436 L F
.401 .149 .412 r
.4991 .87516 m .4991 .87436 L .49746 .87551 L F
.614 .295 .406 r
.49701 .87482 m .4991 .87516 L .49863 .8745 L F
.49701 .87482 m .49863 .8745 L .49812 .8738 L F
.971 .686 .432 r
.70279 .72793 m .70209 .72946 L .70019 .7269 L F
.70279 .72793 m .70312 .73136 L .70209 .72946 L F
.725 .263 .154 r
.64075 .61467 m .64392 .61556 L .64247 .61469 L F
.412 .558 .89 r
.38459 .78259 m .38351 .78359 L .38161 .78157 L F
.38459 .78259 m .38571 .78453 L .38351 .78359 L F
0 0 .245 r
.67393 .60965 m .67492 .61284 L .67463 .61181 L F
.459 .199 .431 r
.34384 .69322 m .34332 .69523 L .34583 .69277 L F
.866 .736 .717 r
.64624 .58825 m .64944 .5876 L .64933 .58577 L F
0 0 0 r
.64855 .58789 m .64944 .5876 L .64624 .58825 L F
0 0 .524 r
.64933 .58577 m .64944 .5876 L .65078 .58737 L F
0 0 0 r
.65078 .58737 m .64944 .5876 L .64855 .58789 L F
.85 .754 .757 r
.61066 .63703 m .60727 .63888 L .60911 .63608 L F
.61066 .63703 m .60881 .6398 L .60727 .63888 L F
.46 .206 .442 r
.52319 .78035 m .52157 .77892 L .52351 .77837 L F
.52319 .78035 m .52113 .78089 L .52157 .77892 L F
.582 .436 .647 r
.37732 .66889 m .37769 .67151 L .37529 .6715 L F
.6 .908 .982 r
.37529 .6715 m .37634 .67041 L .37732 .66889 L F
.37529 .6715 m .37395 .67129 L .37634 .67041 L F
.254 .008 .335 r
.37769 .67151 m .37578 .67373 L .37529 .6715 L F
.8 .736 .792 r
.41346 .74717 m .41706 .74688 L .41547 .74601 L F
.41346 .74717 m .41464 .74942 L .41706 .74688 L F
.958 .71 .521 r
.41547 .74601 m .41706 .74688 L .41559 .74366 L F
.353 .822 .759 r
.31781 .65158 m .31957 .65089 L .3197 .65085 L F
.31 .663 .973 r
.32202 .65052 m .3223 .65092 L .3197 .65085 L F
.14 0 0 r
.31957 .65089 m .32202 .65052 L .3197 .65085 L F
.832 .743 .766 r
.68301 .7167 m .68383 .71972 L .68571 .71691 L F
.745 .615 .715 r
.62713 .65011 m .62617 .64726 L .62385 .64981 L F
.62713 .65011 m .62741 .64774 L .62617 .64726 L F
.522 .13 .239 r
.62394 .65212 m .62713 .65011 L .62385 .64981 L F
.62394 .65212 m .62646 .6515 L .62713 .65011 L F
.564 .173 .259 r
.62646 .6515 m .62922 .65141 L .62713 .65011 L F
.579 .142 .174 r
.62713 .65011 m .62922 .65141 L .62949 .65086 L F
.637 .845 .98 r
.3785 .77934 m .37713 .78004 L .37525 .77918 L F
.307 0 0 r
.41721 .78639 m .4158 .78792 L .41395 .78824 L F
.295 0 0 r
.41791 .78756 m .41721 .78639 L .41922 .78596 L F
.41791 .78756 m .4158 .78792 L .41721 .78639 L F
.436 .16 .395 r
.36736 .68947 m .36447 .69242 L .3649 .68957 L F
.702 .59 .728 r
.69159 .62606 m .68985 .62878 L .68934 .62613 L F
.881 .986 .716 r
.69015 .62702 m .68985 .62878 L .69159 .62606 L F
.682 .283 .284 r
.68849 .63032 m .68985 .62878 L .69015 .62702 L F
.68849 .63032 m .69227 .63104 L .68985 .62878 L F
.614 .556 .765 r
.69299 .63157 m .68985 .62878 L .69227 .63104 L F
.625 .549 .748 r
.49688 .75734 m .49488 .75816 L .49368 .75455 L F
.84 .794 .806 r
.70151 .71195 m .70458 .71182 L .70382 .71107 L F
.85 .531 .447 r
.70458 .71182 m .70345 .7131 L .70382 .71107 L F
.70458 .71182 m .70533 .71446 L .70345 .7131 L F
.613 .858 .99 r
.6979 .60368 m .69913 .602 L .69665 .60213 L F
.6979 .60368 m .70024 .60265 L .69913 .602 L F
.769 .628 .705 r
.73251 .72269 m .72927 .72258 L .73112 .7195 L F
.171 .698 .863 r
.73251 .72269 m .73168 .72247 L .72927 .72258 L F
0 0 0 r
.73346 .71879 m .73277 .71967 L .73213 .71957 L F
.322 0 0 r
.73213 .71957 m .73274 .72074 L .73112 .7195 L F
.303 .198 .566 r
.73213 .71957 m .73274 .72074 L .73112 .7195 L F
.034 .207 .711 r
.73274 .72074 m .73251 .72269 L .73133 .71998 L F
.73274 .72074 m .73133 .71998 L .73166 .71991 L F
.322 0 0 r
.73213 .71957 m .73065 .72054 L .73274 .72074 L F
0 0 0 r
.73277 .71967 m .73208 .72055 L .73212 .71981 L F
.73277 .71967 m .73212 .71981 L .73213 .71957 L F
.034 .207 .711 r
.73166 .71991 m .73133 .71998 L .73112 .7195 L F
.886 .985 .812 r
.73274 .72074 m .73168 .72247 L .73251 .72269 L F
.095 .217 .701 r
.48059 .88323 m .48162 .88242 L .48059 .8804 L F
.092 .212 .697 r
.48059 .88323 m .48235 .88527 L .48162 .88242 L F
.861 .851 .831 r
.53201 .83449 m .52978 .83445 L .5321 .83152 L F
.894 .471 .139 r
.53201 .83449 m .53193 .83652 L .52978 .83445 L F
.53201 .83449 m .53311 .83711 L .53193 .83652 L F
.325 .137 .465 r
.37022 .68244 m .37095 .68637 L .3677 .68767 L F
.43 .197 .457 r
.37351 .68177 m .37022 .68244 L .37043 .68218 L F
.37351 .68177 m .373 .68392 L .37022 .68244 L F
.274 .015 .328 r
.373 .68392 m .37095 .68637 L .37022 .68244 L F
.332 .074 .363 r
.6825 .61212 m .68308 .61037 L .68482 .60959 L F
.68482 .60959 m .68308 .61037 L .6825 .61212 L F
.806 .757 .807 r
.70595 .71711 m .70294 .71698 L .70533 .71446 L F
.818 .713 .749 r
.70595 .71711 m .70385 .72007 L .70294 .71698 L F
.667 .496 .644 r
.70609 .71949 m .70385 .72007 L .70595 .71711 L F
.716 .578 .7 r
.70864 .71689 m .70609 .71949 L .70595 .71711 L F
.765 .691 .781 r
.7036 .69484 m .70477 .69657 L .70145 .69626 L F
.742 .519 .592 r
.70477 .69657 m .70138 .69804 L .70145 .69626 L F
.70477 .69657 m .70497 .69853 L .70138 .69804 L F
.752 .688 .789 r
.70677 .69495 m .70477 .69657 L .7036 .69484 L F
.897 .883 .812 r
.70042 .63187 m .70108 .63369 L .69902 .63369 L F
.928 .868 .76 r
.70108 .63369 m .69833 .63579 L .69902 .63369 L F
.70108 .63369 m .69937 .63666 L .69833 .63579 L F
.787 .841 .893 r
.70378 .63143 m .70108 .63369 L .70042 .63187 L F
.844 .829 .833 r
.65103 .63586 m .65229 .63694 L .64999 .63956 L F
.265 .194 .586 r
.64944 .6407 m .65012 .6386 L .64999 .63956 L F
.64944 .6407 m .6513 .6406 L .65012 .6386 L F
.741 .355 .322 r
.65012 .6386 m .6513 .6406 L .6492 .64053 L F
.65012 .6386 m .6492 .64053 L .64836 .6405 L F
.844 .829 .833 r
.65103 .63586 m .65046 .63788 L .65012 .6386 L F
.65046 .63788 m .64999 .63956 L .65012 .6386 L F
.786 .622 .678 r
.71009 .71767 m .70929 .71984 L .70864 .71689 L F
.382 0 .1 r
.46989 .77052 m .46558 .77272 L .46659 .77122 L F
.289 0 .212 r
.70778 .63903 m .70507 .64114 L .70568 .63907 L F
.975 .751 .537 r
.62791 .6308 m .62885 .63321 L .62798 .62872 L F
.681 .578 .733 r
.62798 .62872 m .62885 .63321 L .63183 .63134 L F
.777 .526 .555 r
.63115 .63346 m .63183 .63134 L .62885 .63321 L F
.689 .514 .646 r
.62791 .6308 m .63115 .63346 L .62885 .63321 L F
.564 .38 .591 r
.35232 .65535 m .34998 .65767 L .35 .65631 L F
.35232 .65535 m .35205 .65717 L .34998 .65767 L F
.001 .177 .692 r
.67709 .72008 m .67772 .71938 L .67562 .71876 L F
.67709 .72008 m .67879 .72267 L .67772 .71938 L F
.78 .667 .739 r
.60643 .64478 m .60782 .64776 L .60446 .64735 L F
.796 .62 .663 r
.60728 .65005 m .60446 .64735 L .60782 .64776 L F
.019 0 0 r
.56923 .80435 m .56799 .80485 L .56921 .80366 L F
.437 .564 .884 r
.69782 .59562 m .69651 .59718 L .69633 .59593 L F
.53 .705 .951 r
.69782 .59562 m .69877 .59696 L .69651 .59718 L F
.654 .599 .781 r
.47311 .74878 m .4764 .75191 L .47495 .74863 L F
.62 .624 .833 r
.47495 .74863 m .4764 .75191 L .47795 .74959 L F
.622 .626 .834 r
.4764 .75191 m .47921 .75227 L .47795 .74959 L F
.583 .794 .979 r
.46237 .7285 m .46046 .72895 L .45905 .72794 L F
.405 .655 .96 r
.68899 .59069 m .68756 .59088 L .6854 .58905 L F
.407 .526 .866 r
.69075 .59055 m .68975 .59252 L .68899 .59069 L F
.69075 .59055 m .6923 .59336 L .68975 .59252 L F
.241 0 .023 r
.64836 .64232 m .64768 .64119 L .64706 .64392 L F
.64836 .64232 m .64944 .6407 L .64768 .64119 L F
.708 .662 .802 r
.49754 .88738 m .49967 .88561 L .49699 .88522 L F
.094 0 0 r
.42128 .78562 m .42489 .78395 L .42343 .78531 L F
.011 0 0 r
.42343 .78531 m .42489 .78395 L .42704 .78304 L F
.575 .413 .625 r
.34489 .7626 m .34709 .76243 L .34701 .7599 L F
.558 .403 .627 r
.34489 .7626 m .34711 .76511 L .34709 .76243 L F
.34489 .7626 m .34536 .76553 L .34711 .76511 L F
.317 .071 .374 r
.35778 .74412 m .35724 .74619 L .35939 .7435 L F
.934 .949 .772 r
.67505 .62546 m .6774 .62332 L .67599 .62396 L F
0 0 .521 r
.67579 .62196 m .67599 .62396 L .67606 .62409 L F
.934 .949 .772 r
.67609 .62451 m .67615 .6253 L .6774 .62332 L F
.785 .421 .367 r
.6774 .62332 m .67724 .62648 L .67599 .62396 L F
0 0 .521 r
.67594 .62243 m .67606 .62409 L .67724 .62648 L F
.67579 .62196 m .67606 .62409 L .67594 .62243 L F
.934 .949 .772 r
.67505 .62546 m .67561 .62614 L .67615 .6253 L F
.67505 .62546 m .67615 .6253 L .67609 .62451 L F
.785 .421 .367 r
.6774 .62332 m .67871 .6258 L .67724 .62648 L F
.614 .582 .794 r
.36635 .67129 m .36418 .67177 L .36302 .6687 L F
.444 .226 .486 r
.37374 .6788 m .37351 .68177 L .37043 .68218 L F
.946 .709 .242 r
.71621 .63209 m .71644 .6331 L .71675 .63286 L F
.517 .851 .571 r
.71548 .63409 m .71741 .63237 L .71675 .63286 L F
.043 .026 .51 r
.71677 .63456 m .71548 .63409 L .71675 .63286 L F
.946 .709 .242 r
.71644 .6331 m .71677 .63456 L .71675 .63286 L F
.517 .851 .571 r
.71741 .63237 m .71822 .63165 L .71675 .63286 L F
.585 .851 .504 r
.72044 .62904 m .71932 .63024 L .71822 .63165 L F
.62 .904 .609 r
.71822 .63165 m .71932 .63024 L .71675 .63286 L F
.9 .897 .816 r
.66953 .61112 m .67294 .60883 L .67255 .60846 L F
.66953 .61112 m .67026 .61247 L .67294 .60883 L F
.989 .722 .403 r
.67533 .63303 m .67613 .63193 L .6752 .63079 L F
.594 .119 .095 r
.67533 .63303 m .67908 .63316 L .67613 .63193 L F
0 .205 .655 r
.67711 .60892 m .67959 .61069 L .67698 .61059 L F
.316 0 0 r
.63845 .59042 m .64071 .5901 L .64171 .58882 L F
.277 0 0 r
.64292 .58957 m .64171 .58882 L .64071 .5901 L F
.64292 .58957 m .64404 .58865 L .64171 .58882 L F
.381 .199 .505 r
.37102 .76798 m .37082 .77028 L .36923 .77077 L F
.565 .457 .69 r
.37082 .77028 m .36907 .77286 L .36923 .77077 L F
.57 .419 .637 r
.35519 .74659 m .35321 .74935 L .35535 .74901 L F
.586 .362 .543 r
.35321 .74935 m .3552 .75134 L .35535 .74901 L F
.35321 .74935 m .35299 .75163 L .3552 .75134 L F
.621 .808 .972 r
.72594 .72209 m .7269 .72312 L .72927 .72258 L F
.554 .116 .162 r
.40526 .7241 m .4074 .72441 L .40885 .7229 L F
.496 .05 .119 r
.40885 .7229 m .4074 .72441 L .41065 .72361 L F
.8 .95 .918 r
.33853 .81324 m .34162 .8118 L .34147 .81063 L F
.473 .569 .872 r
.34162 .8118 m .34271 .8102 L .34147 .81063 L F
.34162 .8118 m .3457 .81371 L .34271 .8102 L F
.982 .708 .425 r
.53671 .84855 m .53566 .84828 L .53545 .84544 L F
.372 .451 .813 r
.53728 .8464 m .53671 .84855 L .53545 .84544 L F
.88 .967 .846 r
.53728 .8464 m .53566 .84828 L .53671 .84855 L F
.56 .276 .441 r
.32714 .71117 m .32993 .70913 L .32761 .70949 L F
.648 .7 .884 r
.48998 .74354 m .48923 .74648 L .48787 .74381 L F
.48998 .74354 m .49143 .74595 L .48923 .74648 L F
.571 .563 .805 r
.46416 .74635 m .46492 .74307 L .46279 .7434 L F
.46416 .74635 m .46619 .7461 L .46492 .74307 L F
.977 .745 .521 r
.64114 .62342 m .64127 .62593 L .64008 .62314 L F
.591 .915 .975 r
.64008 .62314 m .64247 .62222 L .64114 .62342 L F
.526 .814 .998 r
.64127 .62593 m .64334 .62541 L .64216 .62532 L F
.66 .779 .937 r
.64426 .62266 m .64585 .62471 L .64334 .62541 L F
.64426 .62266 m .64334 .62541 L .64247 .62222 L F
.528 .153 .273 r
.64585 .62471 m .64216 .62532 L .64334 .62541 L F
.64345 .62511 m .64509 .62671 L .64216 .62532 L F
.64585 .62471 m .64535 .62602 L .64345 .62511 L F
.64535 .62602 m .64509 .62671 L .64345 .62511 L F
.292 .361 .763 r
.64114 .62342 m .64247 .62222 L .64323 .625 L F
.64251 .62466 m .64323 .625 L .64334 .62541 L F
.64114 .62342 m .64323 .625 L .64251 .62466 L F
.534 .416 .664 r
.36907 .77286 m .36955 .77599 L .36748 .77636 L F
.548 .436 .678 r
.36955 .77599 m .36776 .77872 L .36748 .77636 L F
.584 .289 .434 r
.4991 .87516 m .4991 .87436 L .49812 .8738 L F
.811 .428 .33 r
.73245 .71617 m .73339 .71452 L .73075 .71382 L F
.935 .613 .405 r
.73245 .71617 m .73393 .717 L .73339 .71452 L F
.263 .011 .331 r
.36186 .69448 m .36076 .6935 L .36248 .69296 L F
.36186 .69448 m .36022 .69542 L .36076 .6935 L F
.356 0 0 r
.42497 .72319 m .42724 .72386 L .42851 .72384 L F
.37 0 0 r
.42724 .72386 m .43068 .72387 L .42851 .72384 L F
.69 .635 .789 r
.51058 .7714 m .50707 .76748 L .5093 .76716 L F
.688 .667 .824 r
.51238 .76759 m .51058 .7714 L .5093 .76716 L F
.786 .565 .602 r
.69058 .70016 m .69389 .69829 L .69021 .69837 L F
.69058 .70016 m .69379 .70084 L .69389 .69829 L F
.07 0 0 r
.39669 .79506 m .39397 .79628 L .39253 .79642 L F
0 0 0 r
.39572 .79583 m .39669 .79506 L .39861 .79443 L F
.39572 .79583 m .39397 .79628 L .39669 .79506 L F
.376 .414 .773 r
.66369 .59293 m .66215 .59472 L .66124 .59128 L F
.436 .503 .83 r
.66369 .59293 m .66494 .59595 L .66215 .59472 L F
.135 0 0 r
.45328 .77569 m .45008 .77627 L .45114 .77571 L F
0 0 .045 r
.72224 .62604 m .72188 .62791 L .72044 .62904 L F
0 0 0 r
.72188 .62791 m .71932 .63024 L .72044 .62904 L F
.86 .731 .719 r
.57509 .79931 m .57341 .80246 L .57564 .80234 L F
.848 .807 .81 r
.57564 .80234 m .57362 .80483 L .57341 .80246 L F
.601 .494 .704 r
.41005 .74529 m .41346 .74717 L .41273 .74315 L F
.585 .502 .727 r
.41005 .74529 m .41115 .74828 L .41346 .74717 L F
.119 .604 .912 r
.71462 .70633 m .71705 .70708 L .71675 .7067 L F
.275 .479 .877 r
.71705 .70708 m .71902 .70693 L .71675 .7067 L F
.747 .897 .946 r
.65103 .63586 m .65476 .63513 L .65229 .63694 L F
.695 .591 .735 r
.49114 .88309 m .49445 .88558 L .49313 .88283 L F
.768 .706 .794 r
.49313 .88283 m .49445 .88558 L .49657 .88303 L F
.616 .476 .668 r
.49445 .88558 m .49699 .88522 L .49657 .88303 L F
.335 .155 .481 r
.59994 .6628 m .60128 .66516 L .6013 .66282 L F
.59994 .6628 m .59912 .66635 L .60128 .66516 L F
.824 .983 .701 r
.65909 .60884 m .65872 .60978 L .65908 .60985 L F
.805 .951 .611 r
.66089 .60661 m .65872 .60978 L .65909 .60884 L F
0 0 .336 r
.65908 .60985 m .65973 .61153 L .65909 .60884 L F
.343 0 .021 r
.64971 .59973 m .64902 .60097 L .64623 .60138 L F
.058 0 0 r
.65076 .60023 m .64971 .59973 L .65177 .59912 L F
.65076 .60023 m .64902 .60097 L .64971 .59973 L F
.668 .895 .546 r
.72302 .72133 m .72157 .72344 L .72363 .72249 L F
.72302 .72133 m .72061 .72443 L .72157 .72344 L F
.442 .237 .505 r
.47839 .87247 m .47977 .87326 L .48017 .8704 L F
.063 .324 .805 r
.47839 .87247 m .48077 .87458 L .47977 .87326 L F
.569 .448 .675 r
.68046 .70359 m .68188 .69992 L .68065 .69958 L F
.713 .609 .74 r
.51381 .77025 m .51481 .77363 L .51119 .77333 L F
.779 .637 .704 r
.51481 .77363 m .51115 .77572 L .51119 .77333 L F
.51481 .77363 m .51293 .77606 L .51115 .77572 L F
.655 .576 .754 r
.51737 .7728 m .51481 .77363 L .51381 .77025 L F
.724 .578 .691 r
.64392 .61556 m .64731 .61512 L .64665 .6131 L F
.695 .563 .701 r
.64731 .61512 m .6503 .61312 L .64665 .6131 L F
.295 0 .045 r
.63721 .62044 m .63671 .62168 L .6342 .62242 L F
.752 .688 .789 r
.70677 .69495 m .7036 .69484 L .70582 .6944 L F
.375 .789 .979 r
.70815 .69421 m .70677 .69495 L .70582 .6944 L F
.70815 .69421 m .70908 .69469 L .70677 .69495 L F
.118 0 0 r
.52441 .77198 m .52655 .77159 L .52824 .77089 L F
.008 0 .202 r
.52962 .76965 m .52753 .77306 L .52824 .77089 L F
.52962 .76965 m .52753 .77306 L .52824 .77089 L F
.34 .785 .958 r
.44722 .73912 m .44901 .73967 L .45017 .73938 L F
.319 0 0 r
.41065 .72361 m .41283 .72371 L .41425 .72299 L F
.443 0 0 r
.41283 .72371 m .41626 .72345 L .41425 .72299 L F
.602 .219 .289 r
.47532 .76991 m .47372 .77243 L .47193 .77049 L F
.654 .278 .32 r
.47602 .77247 m .47532 .76991 L .47735 .77064 L F
.47602 .77247 m .47372 .77243 L .47532 .76991 L F
.905 .778 .71 r
.68301 .7167 m .68228 .71925 L .68383 .71972 L F
.919 .84 .75 r
.681 .72187 m .68383 .71972 L .68228 .71925 L F
.681 .72187 m .68221 .72276 L .68383 .71972 L F
.545 .571 .831 r
.70932 .60413 m .71116 .60356 L .70806 .60251 L F
.589 .354 .528 r
.33021 .7866 m .33281 .7841 L .33265 .78412 L F
.727 .256 0 r
.64689 .59792 m .64619 .59668 L .64692 .59922 L F
.64689 .59792 m .64654 .5975 L .64619 .59668 L F
.583 .053 0 r
.64619 .59668 m .64654 .5975 L .64294 .59626 L F
.516 .31 .539 r
.33281 .7841 m .33482 .78374 L .33503 .78141 L F
.33281 .7841 m .33482 .78374 L .33503 .78141 L F
.53 .322 .542 r
.33503 .78141 m .33687 .7834 L .33714 .78105 L F
.33503 .78141 m .33482 .78374 L .33687 .7834 L F
.64 .608 .802 r
.49349 .74549 m .49256 .74916 L .49143 .74595 L F
.49349 .74549 m .49505 .74897 L .49256 .74916 L F
.578 .462 .685 r
.49505 .74897 m .49349 .75241 L .49256 .74916 L F
.735 .516 .595 r
.5645 .7975 m .56839 .79977 L .56664 .797 L F
.5645 .7975 m .56447 .80004 L .56839 .79977 L F
.697 .66 .81 r
.69031 .62285 m .69159 .62606 L .68934 .62613 L F
.845 .958 .884 r
.65924 .64714 m .65878 .64644 L .65647 .64852 L F
.12 0 0 r
.30173 .6578 m .30341 .65745 L .30483 .65615 L F
.139 0 0 r
.30341 .65745 m .30692 .65585 L .30483 .65615 L F
.676 .315 .354 r
.5535 .79994 m .55567 .8019 L .55679 .79968 L F
.645 .28 .339 r
.55679 .79968 m .55878 .80159 L .55901 .80037 L F
.55679 .79968 m .55567 .8019 L .55878 .80159 L F
.598 .757 .954 r
.65884 .63105 m .65669 .63172 L .65481 .63018 L F
.505 .331 .579 r
.65884 .63105 m .65711 .63421 L .65669 .63172 L F
.838 .691 .7 r
.51612 .77889 m .51272 .78091 L .51277 .77849 L F
.51612 .77889 m .51585 .78115 L .51272 .78091 L F
.611 .821 .981 r
.73914 .73022 m .73694 .73086 L .73651 .72988 L F
.73914 .73022 m .73694 .73086 L .73651 .72988 L F
.57 .599 .843 r
.68196 .59491 m .68363 .59292 L .68131 .59359 L F
.68196 .59491 m .68481 .59572 L .68363 .59292 L F
.536 0 0 r
.68951 .64481 m .6929 .64511 L .69192 .64588 L F
.347 0 0 r
.69192 .64588 m .6929 .64511 L .69492 .64549 L F
.631 .582 .781 r
.48757 .87972 m .48526 .88129 L .48493 .87996 L F
.39 .257 .577 r
.48727 .88272 m .48526 .88129 L .48757 .87972 L F
.48727 .88272 m .48637 .88347 L .48526 .88129 L F
.569 .644 .885 r
.65981 .59607 m .65582 .59407 L .6586 .59476 L F
.801 .608 .642 r
.62617 .64726 m .62269 .64448 L .62439 .64747 L F
.803 .669 .715 r
.62385 .64981 m .62617 .64726 L .62439 .64747 L F
.682 .351 .409 r
.51909 .78136 m .51616 .78301 L .51585 .78115 L F
.51909 .78136 m .51826 .78364 L .51616 .78301 L F
.512 .209 .39 r
.52113 .78089 m .51826 .78364 L .51909 .78136 L F
.594 .325 .479 r
.61961 .66618 m .62185 .66795 L .61953 .66805 L F
.61961 .66618 m .62193 .66606 L .62185 .66795 L F
.853 .446 .265 r
.71602 .70016 m .71921 .70313 L .7187 .70143 L F
.852 .568 .032 r
.66953 .61112 m .67054 .61493 L .67026 .61247 L F
.143 0 0 r
.42108 .74135 m .41992 .74263 L .41752 .74315 L F
.644 .154 .075 r
.42298 .7429 m .41992 .74263 L .42108 .74135 L F
.576 .223 .333 r
.42328 .74145 m .42298 .7429 L .42108 .74135 L F
.589 .354 .528 r
.33021 .7866 m .33245 .78636 L .33281 .7841 L F
.462 .223 .465 r
.33245 .78636 m .33482 .78374 L .33281 .7841 L F
.881 .986 .716 r
.69015 .62702 m .69159 .62606 L .6906 .62515 L F
.774 .698 .779 r
.69374 .62333 m .69159 .62606 L .69031 .62285 L F
.67 .541 .7 r
.69374 .62333 m .69438 .62502 L .69371 .62527 L F
.69223 .62526 m .69371 .62527 L .69159 .62606 L F
.69374 .62333 m .69371 .62527 L .69223 .62526 L F
.69438 .62502 m .69397 .62541 L .69159 .62606 L F
.118 .67 .75 r
.69566 .62309 m .69374 .62333 L .693 .62337 L F
.294 0 0 r
.69282 .62337 m .69374 .62333 L .69031 .62285 L F
.118 .67 .75 r
.69382 .62327 m .693 .62337 L .69282 .62337 L F
.69566 .62309 m .693 .62337 L .69382 .62327 L F
.775 .719 .8 r
.69566 .62309 m .69557 .62433 L .69374 .62333 L F
.69566 .62309 m .69628 .62473 L .69557 .62433 L F
.69628 .62473 m .69651 .62533 L .6961 .62489 L F
.69628 .62473 m .6961 .62489 L .69557 .62433 L F
.69549 .62545 m .69534 .62757 L .69451 .62537 L F
.602 .318 .458 r
.69159 .62606 m .69422 .62542 L .69397 .62541 L F
.67 .541 .7 r
.69447 .62527 m .69451 .62537 L .69159 .62606 L F
.69419 .62564 m .69534 .62757 L .69303 .62664 L F
.602 .318 .458 r
.69159 .62606 m .69419 .62564 L .69422 .62542 L F
.417 .16 .414 r
.69422 .62542 m .69419 .62564 L .69444 .62543 L F
.67 .541 .7 r
.69451 .62537 m .69303 .62664 L .69159 .62606 L F
.686 .211 .117 r
.69159 .62606 m .69534 .62757 L .69392 .62786 L F
.602 .318 .458 r
.69159 .62606 m .69392 .62786 L .69419 .62564 L F
.67 .541 .7 r
.69451 .62537 m .69459 .62558 L .69419 .62564 L F
.69459 .62558 m .69534 .62757 L .69419 .62564 L F
.417 .16 .414 r
.69444 .62543 m .69405 .62678 L .69549 .62545 L F
.69419 .62564 m .69405 .62678 L .69444 .62543 L F
.69444 .62536 m .69549 .62545 L .6961 .62489 L F
.69422 .62542 m .69549 .62545 L .69444 .62536 L F
.565 .668 .908 r
.69444 .62536 m .6961 .62489 L .69557 .62433 L F
.775 .719 .8 r
.69557 .62433 m .69549 .62545 L .69449 .62532 L F
.69549 .62545 m .69451 .62537 L .69449 .62532 L F
.69557 .62433 m .69691 .62639 L .69534 .62757 L F
.69651 .62533 m .69691 .62639 L .69557 .62433 L F
0 .224 .744 r
.69566 .62309 m .69693 .62466 L .6971 .62464 L F
.284 .422 .825 r
.6971 .62464 m .69707 .62492 L .69566 .62309 L F
.813 .828 .862 r
.69675 .62499 m .69691 .62639 L .69693 .62466 L F
.284 .422 .825 r
.69673 .62483 m .69675 .62499 L .69628 .62473 L F
.69675 .62499 m .69691 .62639 L .69669 .62582 L F
.69675 .62499 m .69669 .62582 L .69628 .62473 L F
.813 .828 .862 r
.69534 .62757 m .69675 .62499 L .69392 .62786 L F
.69675 .62499 m .69693 .62466 L .69676 .62484 L F
.69675 .62499 m .69676 .62484 L .69392 .62786 L F
.69534 .62757 m .69691 .62639 L .69675 .62499 L F
0 0 .506 r
.69693 .62466 m .69691 .62639 L .6971 .62464 L F
.284 .422 .825 r
.69707 .62492 m .69691 .62639 L .69673 .62483 L F
.417 .16 .414 r
.6965 .62478 m .69676 .62484 L .69693 .62466 L F
.284 .422 .825 r
.69649 .62416 m .69628 .62473 L .69566 .62309 L F
.565 .668 .908 r
.69557 .62433 m .6965 .62455 L .69613 .62382 L F
.6965 .62455 m .69693 .62466 L .69649 .6242 L F
.6965 .62455 m .69649 .6242 L .69613 .62382 L F
.284 .422 .825 r
.6965 .62478 m .69628 .62473 L .69649 .62416 L F
.565 .668 .908 r
.6961 .62489 m .69693 .62466 L .69557 .62433 L F
.284 .422 .825 r
.69707 .62492 m .6965 .62478 L .69649 .62416 L F
.417 .16 .414 r
.6961 .62489 m .69392 .62786 L .69676 .62484 L F
.6961 .62489 m .69676 .62484 L .6965 .62478 L F
.69405 .62678 m .69392 .62786 L .6961 .62489 L F
.775 .719 .8 r
.69557 .62433 m .69449 .62532 L .69374 .62333 L F
.565 .668 .908 r
.69422 .62542 m .69444 .62536 L .69544 .62309 L F
.69444 .62536 m .69613 .62382 L .69544 .62309 L F
.118 .67 .75 r
.69566 .62309 m .69282 .62337 L .69514 .62279 L F
.565 .668 .908 r
.69502 .62314 m .69544 .62309 L .69514 .62279 L F
.69422 .62542 m .69544 .62309 L .69502 .62314 L F
.69411 .62527 m .69514 .62279 L .69282 .62337 L F
.69422 .62542 m .69427 .62527 L .69411 .62527 L F
.806 .794 .841 r
.69397 .62541 m .69422 .62542 L .69411 .62527 L F
.67 .541 .7 r
.69438 .62502 m .69447 .62527 L .69397 .62541 L F
.565 .668 .908 r
.69427 .62527 m .69514 .62279 L .69411 .62527 L F
.806 .794 .841 r
.6906 .62515 m .69397 .62541 L .69282 .62337 L F
.69397 .62541 m .69411 .62527 L .69282 .62337 L F
.602 .318 .458 r
.69159 .62606 m .69397 .62541 L .6906 .62515 L F
.82 .865 .881 r
.67627 .63562 m .68016 .63386 L .67908 .63316 L F
.895 .474 .133 r
.68016 .63386 m .6808 .63682 L .67908 .63316 L F
.68016 .63386 m .68186 .63771 L .6808 .63682 L F
0 0 0 r
.389 .75626 m .38726 .75706 L .39054 .75465 L F
.389 .75626 m .39054 .75465 L .38914 .75396 L F
.649 .521 .694 r
.42868 .73839 m .43173 .73922 L .43084 .73577 L F
.085 0 .181 r
.43084 .73577 m .42976 .73852 L .42868 .73839 L F
.775 .526 .559 r
.42868 .73839 m .43206 .74105 L .43173 .73922 L F
.42868 .73839 m .42862 .7408 L .43206 .74105 L F
0 0 .229 r
.42917 .73933 m .42868 .73839 L .42976 .73852 L F
.42917 .73933 m .42862 .7408 L .42868 .73839 L F
.596 .447 .65 r
.33679 .77631 m .33893 .77604 L .33893 .77366 L F
.634 .481 .658 r
.33679 .77631 m .33925 .77837 L .33893 .77604 L F
.33679 .77631 m .33698 .77867 L .33925 .77837 L F
.643 .597 .787 r
.47916 .73869 m .47578 .73626 L .47792 .73576 L F
.532 .515 .782 r
.48009 .73524 m .47916 .73869 L .47792 .73576 L F
.48009 .73524 m .48103 .73838 L .47916 .73869 L F
.57 .517 .757 r
.71779 .61807 m .71923 .61447 L .71743 .61536 L F
.71779 .61807 m .72014 .6179 L .71923 .61447 L F
0 0 0 r
.71732 .62 m .72014 .6179 L .71779 .61807 L F
.703 .53 .652 r
.48864 .88313 m .48877 .88625 L .49114 .88309 L F
.377 .77 .987 r
.6839 .61818 m .68154 .61898 L .6804 .61737 L F
.6839 .61818 m .68379 .61878 L .68154 .61898 L F
.465 .356 .645 r
.46759 .74899 m .46934 .74635 L .46619 .7461 L F
.46759 .74899 m .46934 .74877 L .46934 .74635 L F
.154 .683 .867 r
.43936 .72546 m .4415 .72546 L .44282 .7257 L F
.293 .727 .968 r
.44382 .72509 m .44282 .7257 L .4415 .72546 L F
.44382 .72509 m .44511 .72567 L .44282 .7257 L F
.778 .935 .933 r
.5222 .7723 m .52044 .77385 L .51911 .77344 L F
.441 .396 .712 r
.47882 .87794 m .48054 .87803 L .47862 .87588 L F
.447 .314 .606 r
.47882 .87794 m .48059 .8804 L .48054 .87803 L F
.804 .452 .39 r
.69973 .72515 m .69859 .72689 L .69712 .72451 L F
.872 .549 .436 r
.70019 .7269 m .69859 .72689 L .69973 .72515 L F
.578 .462 .685 r
.49505 .74897 m .49562 .75196 L .49349 .75241 L F
.593 .489 .704 r
.49584 .75412 m .49349 .75241 L .49562 .75196 L F
.49584 .75412 m .49368 .75455 L .49349 .75241 L F
.983 .781 .553 r
.6782 .62798 m .67942 .62899 L .67908 .63112 L F
.77 .688 .773 r
.48165 .8562 m .48345 .85849 L .48479 .85606 L F
.82 .59 .591 r
.51119 .77333 m .50806 .77525 L .50814 .77309 L F
.51119 .77333 m .51115 .77572 L .50806 .77525 L F
.614 .574 .785 r
.47461 .73321 m .47257 .7339 L .47123 .73053 L F
.593 .586 .814 r
.47578 .73626 m .47257 .7339 L .47461 .73321 L F
.777 .795 .868 r
.35232 .65535 m .34843 .65552 L .35046 .65497 L F
.35232 .65535 m .35 .65631 L .34843 .65552 L F
.177 .708 .844 r
.35046 .65497 m .35386 .65494 L .35232 .65535 L F
.565 .462 .696 r
.35386 .65494 m .35205 .65717 L .35232 .65535 L F
.792 .429 .371 r
.51272 .78091 m .51585 .78115 L .51616 .78301 L F
.512 0 0 r
.71967 .61242 m .72381 .61384 L .72207 .6126 L F
.72125 .61308 m .72381 .61384 L .71967 .61242 L F
.17 .121 .555 r
.72207 .6126 m .72381 .61384 L .72371 .61146 L F
.604 .369 .533 r
.72142 .61403 m .72381 .61384 L .71887 .61237 L F
.627 .475 .656 r
.72371 .61146 m .72381 .61384 L .72142 .61403 L F
.501 .301 .54 r
.722 .61339 m .72381 .61342 L .72371 .61146 L F
.72142 .61403 m .72274 .61369 L .722 .61339 L F
.72274 .61369 m .72381 .61342 L .722 .61339 L F
.512 0 0 r
.71887 .61237 m .72125 .61308 L .71967 .61242 L F
.514 .115 .221 r
.43231 .77288 m .43454 .77293 L .43589 .77094 L F
.487 .086 .205 r
.43589 .77094 m .43454 .77293 L .43741 .77192 L F
.471 .101 .254 r
.43589 .77094 m .43741 .77192 L .4381 .77073 L F
.441 .068 .233 r
.71349 .63569 m .71284 .63693 L .71071 .63714 L F
.614 .442 .625 r
.71548 .63409 m .71567 .63598 L .71349 .63569 L F
.043 0 0 r
.71567 .63598 m .71284 .63693 L .71349 .63569 L F
.642 .393 .527 r
.47288 .76205 m .47505 .7623 L .47524 .76008 L F
.511 .282 .503 r
.47524 .76008 m .47714 .76187 L .47865 .75926 L F
.47524 .76008 m .47505 .7623 L .47714 .76187 L F
.573 .19 .279 r
.46175 .76405 m .46382 .76425 L .46188 .763 L F
.556 .211 .338 r
.46188 .763 m .46382 .76425 L .46424 .76372 L F
.625 .549 .748 r
.49688 .75734 m .49368 .75455 L .49584 .75412 L F
.556 .396 .62 r
.34709 .76243 m .34907 .75954 L .34701 .7599 L F
0 0 0 r
.6894 .63315 m .69299 .63157 L .69227 .63104 L F
.429 .156 .396 r
.36022 .69542 m .35766 .69777 L .3582 .69595 L F
.546 .491 .745 r
.34767 .67424 m .34825 .6772 L .34977 .6768 L F
.293 .221 .602 r
.34825 .6772 m .34988 .67892 L .34977 .6768 L F
.34825 .6772 m .34848 .6795 L .34988 .67892 L F
.54 .822 .998 r
.65095 .58569 m .64933 .58577 L .65157 .58526 L F
0 0 .524 r
.64933 .58577 m .65078 .58737 L .65157 .58526 L F
.744 .814 .907 r
.70237 .60172 m .7035 .60317 L .70552 .60176 L F
.752 .64 .737 r
.70049 .71912 m .69729 .7173 L .69953 .71659 L F
.70049 .71912 m .6984 .7201 L .69729 .7173 L F
.664 .626 .802 r
.70294 .71698 m .70385 .72007 L .70049 .71912 L F
0 0 0 r
.62988 .6257 m .62925 .62743 L .62798 .62872 L F
.63243 .62349 m .63161 .62499 L .62988 .6257 L F
.62988 .6257 m .63161 .62499 L .62925 .62743 L F
.668 .348 .422 r
.49187 .77237 m .48822 .77094 L .49171 .77061 L F
.635 .337 .448 r
.49171 .77061 m .49382 .77261 L .49187 .77237 L F
.659 .33 .403 r
.494 .77103 m .49382 .77261 L .49171 .77061 L F
.544 .32 .527 r
.3858 .70885 m .38327 .71147 L .38333 .70909 L F
.38327 .71147 m .3858 .70885 L .38333 .70909 L F
.483 .864 .979 r
.37238 .80233 m .37589 .8021 L .37446 .80187 L F
.166 .687 .881 r
.37589 .8021 m .3765 .80178 L .37446 .80187 L F
.37589 .8021 m .37772 .80207 L .3765 .80178 L F
.441 .16 .39 r
.3677 .68767 m .36908 .68936 L .36736 .68947 L F
.438 .27 .555 r
.37095 .68637 m .36908 .68936 L .3677 .68767 L F
.5 .856 .991 r
.34626 .82609 m .34796 .82648 L .34422 .82659 L F
.34626 .82609 m .34796 .82648 L .34422 .82659 L F
0 .029 .565 r
.34403 .81909 m .34409 .81923 L .34148 .81607 L F
.43 .055 .225 r
.65624 .60471 m .65766 .60623 L .6553 .60638 L F
.65624 .60471 m .65854 .6042 L .65766 .60623 L F
.276 .045 .371 r
.65624 .60471 m .65834 .60188 L .65854 .6042 L F
.289 .598 .95 r
.40988 .74211 m .41073 .74135 L .40858 .7414 L F
.40988 .74211 m .41273 .74315 L .41073 .74135 L F
.957 .829 .676 r
.67406 .62689 m .6748 .62891 L .67561 .62614 L F
.931 .95 .777 r
.67406 .62689 m .67561 .62614 L .67505 .62546 L F
.533 .358 .59 r
.34097 .77076 m .3431 .77058 L .34311 .76808 L F
.593 .4 .59 r
.34097 .77076 m .34321 .77287 L .3431 .77058 L F
.34097 .77076 m .34105 .77316 L .34321 .77287 L F
.467 .241 .487 r
.34665 .70876 m .34594 .71145 L .34425 .71169 L F
.427 .211 .481 r
.34874 .70782 m .34594 .71145 L .34665 .70876 L F
0 0 0 r
.72299 .62438 m .72188 .62791 L .72224 .62604 L F
.656 .871 .98 r
.48338 .886 m .48552 .88528 L .48235 .88527 L F
.48338 .886 m .48552 .88528 L .48235 .88527 L F
.607 .58 .797 r
.47792 .73576 m .47578 .73626 L .47461 .73321 L F
.872 .574 .48 r
.71379 .69638 m .71574 .69817 L .71486 .69689 L F
0 0 0 r
.73112 .7195 m .73031 .72084 L .73065 .72054 L F
.73031 .72084 m .72927 .72258 L .73065 .72054 L F
.322 0 0 r
.73213 .71957 m .73208 .72055 L .73065 .72054 L F
.145 .664 .886 r
.73065 .72054 m .73208 .72055 L .73086 .72036 L F
0 0 0 r
.73112 .7195 m .73065 .72054 L .72976 .71941 L F
.046 .235 .734 r
.72976 .71941 m .73039 .72021 L .72993 .71815 L F
.73039 .72021 m .73065 .72054 L .73056 .72025 L F
.73039 .72021 m .73056 .72025 L .72993 .71815 L F
.185 0 0 r
.73208 .72055 m .73254 .72072 L .73222 .72066 L F
.145 .664 .886 r
.73056 .72025 m .72942 .72013 L .72993 .71815 L F
.73065 .72054 m .72942 .72013 L .73056 .72025 L F
.185 0 0 r
.73123 .72041 m .73222 .72066 L .72942 .72013 L F
.73208 .72055 m .73222 .72066 L .73123 .72041 L F
.145 .664 .886 r
.73065 .72054 m .73086 .72036 L .72942 .72013 L F
.603 .235 .318 r
.50275 .77126 m .50274 .7727 L .49912 .77286 L F
.654 .277 .318 r
.50485 .77235 m .50274 .7727 L .50275 .77126 L F
.355 .789 .613 r
.65323 .60758 m .65346 .60745 L .6553 .60638 L F
.323 0 0 r
.65073 .60741 m .65346 .60745 L .65221 .60817 L F
.355 .789 .613 r
.65221 .60817 m .65346 .60745 L .65323 .60758 L F
.108 0 0 r
.65073 .60741 m .65367 .60732 L .65346 .60745 L F
.65367 .60732 m .65402 .60732 L .65346 .60745 L F
.467 .88 .747 r
.65346 .60745 m .65402 .60732 L .6553 .60638 L F
.716 .531 .639 r
.38726 .75706 m .38499 .75709 L .38509 .75465 L F
.46 .23 .478 r
.37324 .76541 m .37294 .76757 L .37102 .76798 L F
.581 .424 .634 r
.3753 .76251 m .37556 .76517 L .37324 .76541 L F
.522 .284 .495 r
.37503 .76721 m .37324 .76541 L .37556 .76517 L F
.37503 .76721 m .37294 .76757 L .37324 .76541 L F
.571 .725 .946 r
.46672 .72775 m .46598 .72967 L .46449 .72831 L F
.46672 .72775 m .46808 .72929 L .46598 .72967 L F
.02 0 0 r
.4312 .78259 m .43256 .78128 L .43463 .78038 L F
.069 0 0 r
.40213 .78179 m .40188 .78143 L .40015 .78192 L F
.532 0 0 r
.39909 .78158 m .40213 .78179 L .40015 .78192 L F
.39909 .78158 m .4012 .78217 L .40213 .78179 L F
.324 .79 .678 r
.40213 .78179 m .4012 .78217 L .40144 .78206 L F
.069 0 0 r
.40213 .78179 m .40344 .78127 L .40188 .78143 L F
.324 .79 .678 r
.40213 .78179 m .40144 .78206 L .40311 .7813 L F
.069 0 0 r
.40213 .78179 m .40402 .78121 L .40344 .78127 L F
.623 .253 .321 r
.48091 .77028 m .47941 .77234 L .47735 .77064 L F
.567 .168 .246 r
.48283 .77058 m .47941 .77234 L .48091 .77028 L F
.746 .486 .537 r
.46641 .75939 m .46951 .76212 L .46937 .76005 L F
.726 .459 .522 r
.46937 .76005 m .46951 .76212 L .47288 .76205 L F
.724 .588 .703 r
.66198 .60227 m .66156 .6045 L .66009 .60169 L F
.681 .396 .483 r
.61192 .66871 m .61102 .67098 L .60877 .66887 L F
.63 .341 .461 r
.61414 .67067 m .61192 .66871 L .61424 .66868 L F
.61414 .67067 m .61102 .67098 L .61192 .66871 L F
.429 .327 .637 r
.37924 .67075 m .37769 .67151 L .37732 .66889 L F
.672 .308 .346 r
.37634 .67041 m .37924 .67075 L .37732 .66889 L F
.875 .731 .699 r
.60881 .6398 m .60833 .64196 L .60727 .63888 L F
.382 0 .1 r
.46989 .77052 m .46895 .77238 L .46558 .77272 L F
.484 .054 .147 r
.47095 .77208 m .46989 .77052 L .47193 .77049 L F
.47095 .77208 m .46895 .77238 L .46989 .77052 L F
.552 .464 .709 r
.47974 .75434 m .48136 .75171 L .47921 .75227 L F
.47974 .75434 m .48179 .75393 L .48136 .75171 L F
.587 .467 .683 r
.47974 .75434 m .48242 .75723 L .48179 .75393 L F
.47974 .75434 m .48032 .75777 L .48242 .75723 L F
.561 .534 .782 r
.34091 .82162 m .3421 .82054 L .33958 .81897 L F
.34091 .82162 m .343 .82137 L .3421 .82054 L F
.48 .546 .846 r
.48804 .87769 m .48769 .88016 L .48757 .87972 L F
.718 .481 .567 r
.48996 .88213 m .48757 .87972 L .48769 .88016 L F
.806 .79 .838 r
.60562 .65517 m .60826 .65521 L .60551 .65738 L F
0 0 0 r
.32707 .65083 m .33058 .65032 L .32865 .65063 L F
.995 .767 .474 r
.7198 .60195 m .71877 .60312 L .71958 .60406 L F
.032 0 .431 r
.72117 .5984 m .7198 .60195 L .71881 .59868 L F
.72117 .5984 m .72119 .60084 L .7198 .60195 L F
0 0 0 r
.72119 .60084 m .71877 .60312 L .7198 .60195 L F
.695 .388 .451 r
.49715 .7707 m .49382 .77261 L .494 .77103 L F
.49715 .7707 m .4969 .77288 L .49382 .77261 L F
.705 .396 .452 r
.49715 .7707 m .49912 .77286 L .4969 .77288 L F
.579 .003 0 r
.71529 .5969 m .71881 .59868 L .71644 .59933 L F
.979 .698 .415 r
.71949 .74134 m .7186 .74286 L .71835 .74047 L F
.745 .328 .258 r
.71949 .74134 m .72187 .7435 L .7186 .74286 L F
.514 .641 .912 r
.49543 .87457 m .49746 .87551 L .4991 .87516 L F
.09 0 0 r
.32263 .71377 m .32395 .71372 L .32533 .71186 L F
.233 0 .027 r
.32533 .71186 m .32588 .71308 L .32714 .71117 L F
.32533 .71186 m .32395 .71372 L .32588 .71308 L F
.629 .633 .835 r
.6554 .6322 m .65476 .63513 L .65378 .63413 L F
.6554 .6322 m .65711 .63421 L .65476 .63513 L F
.747 .897 .946 r
.65103 .63586 m .65378 .63413 L .65476 .63513 L F
.798 .945 .92 r
.3909 .75093 m .39494 .74983 L .39311 .75051 L F
.353 .826 .877 r
.39642 .74998 m .39311 .75051 L .39494 .74983 L F
.155 0 0 r
.4991 .87516 m .49746 .87551 L .49622 .87688 L F
.699 .84 .95 r
.46934 .74877 m .47311 .74878 L .47158 .74598 L F
.543 .532 .793 r
.47311 .74878 m .47382 .74555 L .47158 .74598 L F
.47311 .74878 m .47495 .74863 L .47382 .74555 L F
.377 .643 .96 r
.65931 .58717 m .65838 .58838 L .65773 .58712 L F
.404 .679 .973 r
.66011 .58828 m .65838 .58838 L .65931 .58717 L F
.558 .519 .768 r
.66124 .59128 m .65838 .58838 L .66011 .58828 L F
.159 .113 .552 r
.62925 .62743 m .62791 .6308 L .62798 .62872 L F
.716 .578 .7 r
.70864 .71689 m .70929 .71984 L .70609 .71949 L F
.54 .376 .607 r
.35519 .74659 m .35726 .74858 L .35724 .74619 L F
.513 .375 .631 r
.35519 .74659 m .35535 .74901 L .35726 .74858 L F
.654 .97 .886 r
.60551 .65738 m .60463 .65761 L .60562 .65517 L F
.592 .46 .67 r
.35082 .75201 m .35109 .75438 L .35299 .75163 L F
.08 0 .038 r
.36022 .81284 m .3613 .81137 L .36267 .81076 L F
.405 .2 .485 r
.35939 .7435 m .36149 .74065 L .35958 .74119 L F
.796 .62 .663 r
.60728 .65005 m .60415 .64969 L .60446 .64735 L F
.825 .626 .633 r
.60704 .65238 m .60415 .64969 L .60728 .65005 L F
.444 .226 .487 r
.47977 .87326 m .4821 .86939 L .48017 .8704 L F
.453 .662 .951 r
.6845 .58736 m .68325 .58876 L .68289 .58759 L F
.408 .591 .918 r
.6845 .58736 m .6854 .58905 L .68325 .58876 L F
.352 .102 .388 r
.6476 .65333 m .64901 .65419 L .64696 .65471 L F
.6476 .65333 m .64946 .65241 L .64901 .65419 L F
.551 .265 .434 r
.63488 .64977 m .63721 .64964 L .6376 .64737 L F
.502 .196 .38 r
.63721 .64964 m .64003 .64692 L .6376 .64737 L F
.057 0 0 r
.47862 .87588 m .48173 .87437 L .48077 .87458 L F
.687 .643 .801 r
.48054 .87803 m .48173 .87437 L .47862 .87588 L F
.637 .494 .671 r
.5923 .67101 m .59503 .6716 L .59501 .66832 L F
.618 .382 .538 r
.5923 .67101 m .59459 .67337 L .59503 .6716 L F
.5923 .67101 m .59238 .67361 L .59459 .67337 L F
.381 0 .152 r
.42681 .77531 m .43015 .77296 L .42796 .77307 L F
.835 .548 .504 r
.69653 .72214 m .69521 .72432 L .69487 .72212 L F
.853 .746 .744 r
.69653 .72214 m .69573 .71996 L .6984 .7201 L F
.69653 .72214 m .69487 .72212 L .69573 .71996 L F
.858 .581 .518 r
.69712 .72451 m .69521 .72432 L .69653 .72214 L F
.769 .604 .674 r
.66009 .60169 m .66156 .6045 L .65854 .6042 L F
.969 .817 .639 r
.66156 .6045 m .65979 .60565 L .65854 .6042 L F
.66156 .6045 m .66089 .60661 L .65979 .60565 L F
.519 .334 .569 r
.65582 .59407 m .65401 .59625 L .65384 .59389 L F
.65582 .59407 m .65401 .59625 L .65384 .59389 L F
.137 0 0 r
.71292 .7363 m .71206 .73617 L .70951 .73572 L F
.428 0 0 r
.71508 .73577 m .71206 .73617 L .71292 .7363 L F
.379 .14 .421 r
.34236 .71411 m .34203 .7168 L .33998 .7169 L F
.266 0 .306 r
.34116 .71836 m .33998 .7169 L .34203 .7168 L F
.34116 .71836 m .33954 .71921 L .33998 .7169 L F
.531 .111 .188 r
.42654 .74118 m .42298 .7429 L .42328 .74145 L F
.42654 .74118 m .42521 .74291 L .42298 .7429 L F
.574 .54 .779 r
.48681 .74045 m .48578 .74416 L .48459 .74099 L F
.48681 .74045 m .48787 .74381 L .48578 .74416 L F
.478 .28 .533 r
.37294 .76757 m .37082 .77028 L .37102 .76798 L F
.37294 .76757 m .37082 .77028 L .37102 .76798 L F
.586 .343 .515 r
.62747 .66333 m .6274 .66551 L .62444 .66631 L F
.556 .279 .451 r
.62971 .66341 m .6274 .66551 L .62747 .66333 L F
.863 .641 .601 r
.53492 .83444 m .53679 .83501 L .53525 .83211 L F
.674 .234 .198 r
.53311 .83711 m .53679 .83501 L .53492 .83444 L F
.53311 .83711 m .53644 .83738 L .53679 .83501 L F
.089 0 0 r
.70908 .69469 m .71127 .69493 L .71252 .69505 L F
.793 .307 .054 r
.71127 .69493 m .71379 .69638 L .71252 .69505 L F
.548 .436 .678 r
.36955 .77599 m .36978 .77841 L .36776 .77872 L F
.516 .292 .513 r
.36149 .74065 m .36381 .73812 L .36177 .7385 L F
.517 .731 .971 r
.63936 .64222 m .64158 .64185 L .64059 .64109 L F
.63936 .64222 m .64158 .64185 L .64059 .64109 L F
.61 .565 .779 r
.43173 .73922 m .43206 .74105 L .4342 .74051 L F
.138 .24 .708 r
.43206 .74105 m .43399 .74322 L .4342 .74051 L F
.411 .682 .973 r
.3414 .67552 m .34268 .67695 L .343 .67531 L F
0 0 .075 r
.34268 .67695 m .34317 .6773 L .343 .67531 L F
.34268 .67695 m .34216 .67942 L .34317 .6773 L F
.105 0 0 r
.46033 .77477 m .45742 .77487 L .4588 .77328 L F
.592 .215 .297 r
.46101 .77339 m .46033 .77477 L .4588 .77328 L F
.535 .572 .839 r
.48398 .85098 m .48653 .85083 L .48607 .85071 L F
.48398 .85098 m .48731 .85363 L .48653 .85083 L F
.432 0 .106 r
.45117 .7655 m .45333 .76536 L .45407 .76459 L F
.509 .082 .164 r
.45407 .76459 m .45333 .76536 L .45634 .76471 L F
0 .386 .732 r
.7166 .73723 m .71815 .73573 L .71508 .73577 L F
.7166 .73723 m .71745 .73744 L .71815 .73573 L F
.7166 .73723 m .71871 .73801 L .71745 .73744 L F
.531 .3 .509 r
.64211 .61779 m .64392 .61556 L .64075 .61467 L F
.64211 .61779 m .64441 .61733 L .64392 .61556 L F
.417 .213 .493 r
.33202 .70607 m .33399 .70596 L .3341 .70317 L F
.286 .095 .437 r
.33202 .70607 m .33342 .70779 L .33399 .70596 L F
.33202 .70607 m .33201 .70858 L .33342 .70779 L F
0 0 0 r
.71462 .70633 m .71375 .7079 L .71245 .70911 L F
.399 .6 .928 r
.71375 .7079 m .71484 .70979 L .71245 .70911 L F
.275 .728 .956 r
.66194 .61853 m .66072 .61795 L .65854 .61796 L F
.761 .933 .942 r
.66189 .61711 m .66194 .61853 L .66343 .61675 L F
.66189 .61711 m .66072 .61795 L .66194 .61853 L F
.16 0 .057 r
.33124 .72545 m .3301 .727 L .32849 .72756 L F
.178 0 .142 r
.33267 .72448 m .3301 .727 L .33124 .72545 L F
.106 0 .341 r
.48985 .87412 m .48867 .87276 L .49085 .87244 L F
.48985 .87412 m .48787 .87497 L .48867 .87276 L F
.353 .822 .759 r
.31781 .65158 m .31631 .65203 L .31957 .65089 L F
.452 .22 .47 r
.35535 .7004 m .3535 .70091 L .3558 .69835 L F
.437 .206 .464 r
.35728 .69977 m .3558 .69835 L .35766 .69777 L F
.35728 .69977 m .35535 .7004 L .3558 .69835 L F
.488 .29 .538 r
.67831 .70631 m .68029 .70633 L .68046 .70359 L F
.697 .567 .705 r
.67867 .70831 m .68029 .70633 L .67831 .70631 L F
.579 .426 .638 r
.34904 .75718 m .35122 .75687 L .35109 .75438 L F
.562 .385 .6 r
.34907 .75954 m .35122 .75687 L .34904 .75718 L F
.769 .604 .674 r
.66009 .60169 m .65854 .6042 L .65834 .60188 L F
.043 .026 .51 r
.71677 .63456 m .71567 .63598 L .71548 .63409 L F
.165 0 0 r
.31472 .65293 m .31254 .65357 L .31193 .65413 L F
.267 0 0 r
.63934 .65751 m .63611 .65954 L .63718 .6582 L F
.466 0 0 r
.68387 .69747 m .68718 .6978 L .68524 .6972 L F
.359 .123 .415 r
.34373 .71601 m .34236 .71411 L .34417 .71336 L F
.34373 .71601 m .34203 .7168 L .34236 .71411 L F
.135 .604 .922 r
.49728 .88262 m .49796 .88307 L .49657 .88303 L F
.49728 .88262 m .49796 .88307 L .49657 .88303 L F
.681 .701 .862 r
.49699 .88522 m .49796 .88307 L .49657 .88303 L F
.777 .526 .555 r
.63115 .63346 m .63196 .63325 L .63183 .63134 L F
.838 .524 .459 r
.71967 .70537 m .72156 .70391 L .71921 .70313 L F
.71967 .70537 m .72224 .70609 L .72156 .70391 L F
.464 .215 .451 r
.3535 .70091 m .35321 .70308 L .35099 .70345 L F
.485 .233 .457 r
.35496 .70221 m .3535 .70091 L .35535 .7004 L F
.35496 .70221 m .35321 .70308 L .3535 .70091 L F
.482 .597 .891 r
.70806 .60251 m .7103 .60106 L .70775 .60174 L F
.70806 .60251 m .71116 .60356 L .7103 .60106 L F
.511 .767 .989 r
.33963 .65315 m .33754 .65348 L .33607 .6524 L F
.666 .4 .509 r
.60877 .66887 m .61102 .67098 L .60903 .67084 L F
.721 .439 .499 r
.69554 .70504 m .69581 .70352 L .69383 .70324 L F
.174 0 0 r
.41626 .72345 m .41835 .72354 L .4196 .72328 L F
.585 .086 .037 r
.72153 .71871 m .72372 .71938 L .72505 .71881 L F
.213 .591 .946 r
.72153 .71871 m .72372 .71938 L .72246 .71873 L F
.281 0 .128 r
.72013 .71868 m .72153 .71871 L .72251 .71652 L F
.585 .086 .037 r
.72153 .71871 m .72505 .71881 L .72251 .71652 L F
.213 .591 .946 r
.72153 .71871 m .72246 .71873 L .72055 .71774 L F
.281 0 .128 r
.71978 .719 m .72153 .71871 L .72013 .71868 L F
.573 .684 .916 r
.72161 .71475 m .72251 .71652 L .72447 .71609 L F
.199 0 0 r
.62922 .65141 m .63259 .64995 L .62949 .65086 L F
.62922 .65141 m .63131 .65101 L .63259 .64995 L F
.331 .807 .744 r
.63131 .65101 m .63488 .64977 L .63259 .64995 L F
.567 .927 .763 r
.65834 .60188 m .65514 .60374 L .65728 .60288 L F
0 0 .354 r
.65882 .59769 m .65834 .60188 L .65929 .60024 L F
.706 .918 .577 r
.65929 .60024 m .65834 .60188 L .65728 .60288 L F
.405 .177 .452 r
.34594 .71145 m .34417 .71336 L .34425 .71169 L F
.781 .896 .925 r
.69937 .63666 m .69544 .63781 L .69833 .63579 L F
.744 .659 .766 r
.39924 .75957 m .40049 .76262 L .40315 .76024 L F
.528 .587 .857 r
.50482 .76783 m .50146 .76525 L .50478 .76592 L F
.664 .555 .721 r
.50694 .76521 m .50482 .76783 L .50478 .76592 L F
.61 .478 .676 r
.50707 .76748 m .50482 .76783 L .50694 .76521 L F
.356 0 0 r
.39433 .72719 m .39649 .72696 L .39793 .72553 L F
.368 0 .019 r
.39649 .72696 m .39999 .7253 L .39793 .72553 L F
0 0 0 r
.40615 .79161 m .40251 .79338 L .40411 .79185 L F
.746 .921 .56 r
.70497 .69853 m .7032 .70121 L .70374 .69994 L F
.957 .798 .642 r
.7032 .70121 m .70148 .70234 L .70374 .69994 L F
.7032 .70121 m .70259 .70343 L .70148 .70234 L F
.469 .277 .537 r
.33399 .7008 m .33584 .70044 L .33601 .69818 L F
.466 .365 .656 r
.3341 .70317 m .33584 .70044 L .33399 .7008 L F
.687 .359 .414 r
.56447 .80004 m .56681 .80225 L .56839 .79977 L F
.454 .096 .268 r
.56839 .79977 m .56681 .80225 L .56775 .8013 L F
.842 .66 .656 r
.51482 .82666 m .51286 .82645 L .51305 .82543 L F
.513 0 0 r
.51482 .82666 m .51516 .82748 L .51286 .82645 L F
.474 .67 .949 r
.5166 .82606 m .51482 .82666 L .51305 .82543 L F
.796 .562 .583 r
.5166 .82606 m .51516 .82748 L .51482 .82666 L F
.778 .739 .817 r
.48457 .87833 m .4864 .87763 L .48312 .87727 L F
.785 .724 .795 r
.48312 .87727 m .4864 .87763 L .48493 .87996 L F
.631 .582 .781 r
.48757 .87972 m .48493 .87996 L .4864 .87763 L F
.588 .637 .867 r
.68785 .59716 m .69122 .59919 L .68975 .59684 L F
.757 .616 .703 r
.69122 .59919 m .68916 .60206 L .69088 .60094 L F
.69122 .59919 m .68916 .60206 L .69088 .60094 L F
.414 .573 .902 r
.68975 .59684 m .69122 .59919 L .69303 .59929 L F
.749 .463 .497 r
.71675 .7067 m .71375 .7079 L .71462 .70633 L F
.581 .438 .652 r
.71875 .71612 m .71978 .719 L .71696 .71704 L F
0 0 0 r
.69829 .64455 m .69766 .64473 L .69492 .64549 L F
.70035 .64382 m .69992 .64415 L .69829 .64455 L F
.69829 .64455 m .69992 .64415 L .69766 .64473 L F
.566 .368 .572 r
.48614 .84828 m .48607 .85071 L .4878 .84952 L F
.001 0 0 r
.40969 .77903 m .41002 .77975 L .41163 .77841 L F
.40969 .77903 m .40828 .7805 L .41002 .77975 L F
.681 .835 .957 r
.4481 .72586 m .44511 .72567 L .44661 .72496 L F
.287 .764 .93 r
.44919 .72529 m .4481 .72586 L .44661 .72496 L F
.44919 .72529 m .45009 .72564 L .4481 .72586 L F
.79 .658 .717 r
.69729 .7173 m .6984 .7201 L .69573 .71996 L F
.623 .627 .833 r
.47795 .74959 m .47921 .75227 L .48136 .75171 L F
.353 .773 .976 r
.35171 .82618 m .35311 .82671 L .34978 .82638 L F
.35171 .82618 m .35311 .82671 L .34978 .82638 L F
.726 .392 .414 r
.48822 .77094 m .48836 .77264 L .48634 .7705 L F
.668 .348 .422 r
.49187 .77237 m .48836 .77264 L .48822 .77094 L F
.699 .526 .65 r
.60342 .66874 m .60107 .67034 L .6 .66875 L F
.60342 .66874 m .60328 .6716 L .60107 .67034 L F
.656 .489 .646 r
.60533 .67129 m .60328 .6716 L .60342 .66874 L F
0 0 0 r
.32849 .72756 m .32722 .72945 L .32586 .7301 L F
.203 0 .031 r
.32901 .72885 m .32849 .72756 L .3301 .727 L F
.32901 .72885 m .32722 .72945 L .32849 .72756 L F
.065 0 0 r
.32263 .71377 m .32197 .71445 L .32395 .71372 L F
.351 .827 .848 r
.57237 .80824 m .57173 .80818 L .56829 .80911 L F
.718 .648 .779 r
.57108 .80606 m .56873 .80838 L .56799 .80485 L F
.57108 .80606 m .5686 .80747 L .5697 .80712 L F
.57108 .80606 m .56799 .80485 L .5686 .80747 L F
.895 .988 .752 r
.57108 .80606 m .5697 .80712 L .57054 .80612 L F
.963 .634 .313 r
.57054 .80612 m .57237 .80824 L .57108 .80606 L F
0 0 0 r
.63298 .6236 m .63243 .62349 L .6342 .62242 L F
.63298 .6236 m .63161 .62499 L .63243 .62349 L F
.48 .35 .626 r
.37733 .7645 m .3753 .76251 L .3774 .7622 L F
.37733 .7645 m .37556 .76517 L .3753 .76251 L F
.391 0 0 r
.43068 .72387 m .42927 .72422 L .43267 .72429 L F
.374 .815 .953 r
.43146 .7242 m .43212 .72418 L .43267 .72429 L F
.152 0 0 r
.43068 .72387 m .43267 .72429 L .43324 .72441 L F
.374 .815 .953 r
.43212 .72418 m .43471 .72414 L .43267 .72429 L F
.152 0 0 r
.43324 .72441 m .43267 .72429 L .43406 .72458 L F
.388 .77 .991 r
.43267 .72429 m .43602 .72482 L .43406 .72458 L F
.636 .298 .381 r
.38081 .73169 m .38441 .72971 L .3822 .72995 L F
.807 .702 .748 r
.60833 .64196 m .6053 .64174 L .60727 .63888 L F
.808 .699 .745 r
.60833 .64196 m .60643 .64478 L .6053 .64174 L F
.088 .11 .587 r
.40616 .74541 m .40453 .74337 L .40532 .74311 L F
0 0 0 r
.40858 .7414 m .40748 .74251 L .40532 .74311 L F
.486 .318 .578 r
.37542 .67651 m .37524 .67823 L .37374 .6788 L F
.46 .238 .49 r
.37538 .68115 m .37374 .6788 L .37524 .67823 L F
.37538 .68115 m .37351 .68177 L .37374 .6788 L F
.722 .599 .718 r
.72993 .71815 m .72734 .71564 L .72688 .71568 L F
.369 0 0 r
.72656 .71571 m .72753 .71553 L .72688 .71568 L F
.722 .599 .718 r
.72734 .71564 m .72631 .71464 L .72688 .71568 L F
.369 0 0 r
.72447 .71609 m .72656 .71571 L .72688 .71568 L F
.466 .365 .656 r
.3341 .70317 m .33613 .70292 L .33584 .70044 L F
.492 .273 .509 r
.3341 .70317 m .33597 .70545 L .33613 .70292 L F
.3341 .70317 m .33399 .70596 L .33597 .70545 L F
.771 .515 .548 r
.68718 .6978 m .69058 .70016 L .69021 .69837 L F
.572 .428 .647 r
.33893 .77366 m .3411 .77567 L .34105 .77316 L F
.33893 .77366 m .33893 .77604 L .3411 .77567 L F
.569 .448 .675 r
.68046 .70359 m .68277 .70326 L .68188 .69992 L F
.541 .334 .549 r
.68046 .70359 m .68029 .70633 L .68277 .70326 L F
0 .249 .762 r
.63245 .6385 m .6298 .63575 L .63235 .6366 L F
0 0 .432 r
.63284 .63649 m .63307 .63808 L .63245 .6385 L F
.63292 .63608 m .63307 .63808 L .63284 .63649 L F
.461 .271 .536 r
.63307 .63808 m .63289 .63845 L .63245 .6385 L F
0 .249 .762 r
.63245 .6385 m .63283 .63871 L .63259 .63848 L F
.371 .088 .349 r
.63245 .6385 m .63172 .64085 L .63283 .63871 L F
.808 .358 .169 r
.63259 .63858 m .63283 .63871 L .6326 .63864 L F
.461 .271 .536 r
.63259 .63848 m .63172 .64085 L .63245 .6385 L F
.808 .358 .169 r
.63256 .63845 m .63259 .63848 L .63259 .63858 L F
.63259 .63848 m .63283 .63871 L .63259 .63858 L F
.964 .672 .427 r
.63172 .64085 m .63041 .63793 L .63259 .63864 L F
.63172 .64085 m .63259 .63864 L .63283 .63871 L F
.461 .271 .536 r
.63289 .63845 m .63257 .63911 L .63259 .63864 L F
.63265 .63848 m .63259 .63864 L .63259 .63848 L F
.63289 .63845 m .63259 .63864 L .63265 .63848 L F
.63257 .63911 m .63172 .64085 L .63259 .63848 L F
0 .249 .762 r
.63245 .6385 m .63259 .63848 L .6298 .63575 L F
.808 .358 .169 r
.63256 .63845 m .6326 .63864 L .63041 .63793 L F
.461 .271 .536 r
.63307 .63808 m .63346 .63997 L .63172 .64085 L F
0 .351 .804 r
.63041 .63793 m .63333 .63988 L .63315 .63863 L F
.63257 .63805 m .63315 .63863 L .63307 .63808 L F
.808 .358 .169 r
.6298 .63575 m .63256 .63845 L .63041 .63793 L F
0 0 .432 r
.63251 .63817 m .63245 .6385 L .6324 .63756 L F
0 .351 .804 r
.63041 .63793 m .63315 .63863 L .63257 .63805 L F
.63333 .63988 m .63346 .63997 L .63307 .63808 L F
0 0 .432 r
.63292 .63608 m .63251 .63817 L .63235 .6366 L F
.63251 .63817 m .6324 .63756 L .63235 .6366 L F
.446 .556 .874 r
.48901 .86767 m .49205 .86864 L .49023 .86988 L F
.606 .494 .701 r
.43084 .73577 m .43231 .73719 L .43322 .73715 L F
.43231 .73719 m .43383 .73866 L .43322 .73715 L F
.597 .539 .76 r
.43322 .73715 m .43588 .7383 L .43533 .73682 L F
0 0 0 r
.43533 .73682 m .43516 .73705 L .43322 .73715 L F
.606 .494 .701 r
.43084 .73577 m .43173 .73922 L .43383 .73866 L F
.61 .565 .779 r
.43173 .73922 m .4342 .74051 L .43383 .73866 L F
.597 .539 .76 r
.43322 .73715 m .43383 .73866 L .43588 .7383 L F
0 0 0 r
.43516 .73705 m .4328 .74004 L .43322 .73715 L F
.668 .373 .464 r
.43322 .73715 m .42976 .73852 L .43084 .73577 L F
.758 .495 .535 r
.68729 .62259 m .69031 .62285 L .68984 .62095 L F
.627 .414 .574 r
.69031 .62285 m .69282 .62337 L .68984 .62095 L F
.294 0 0 r
.69282 .62337 m .69031 .62285 L .68984 .62095 L F
.212 .376 .81 r
.64127 .62593 m .64196 .62458 L .64008 .62314 L F
.526 .814 .998 r
.64127 .62593 m .64142 .62542 L .64196 .62458 L F
.64127 .62593 m .64216 .62532 L .64142 .62542 L F
.498 .499 .788 r
.51472 .76691 m .51381 .77025 L .51238 .76759 L F
.51472 .76691 m .51572 .77015 L .51381 .77025 L F
.655 .576 .754 r
.51737 .7728 m .51381 .77025 L .51572 .77015 L F
.541 .37 .599 r
.34311 .76808 m .34524 .76776 L .34536 .76553 L F
.57 .387 .595 r
.34311 .76808 m .34524 .77021 L .34524 .76776 L F
.34311 .76808 m .3431 .77058 L .34524 .77021 L F
.546 .491 .745 r
.34767 .67424 m .34977 .6768 L .34999 .6738 L F
.312 0 .189 r
.34874 .67543 m .34767 .67424 L .34999 .6738 L F
.34874 .67543 m .3468 .67601 L .34767 .67424 L F
.414 .037 .211 r
.30692 .65585 m .30902 .65546 L .30981 .65416 L F
.285 0 0 r
.30902 .65546 m .31193 .65413 L .30981 .65416 L F
.34 0 0 r
.34318 .6545 m .345 .65524 L .34632 .65561 L F
.369 .752 .989 r
.34708 .65477 m .34632 .65561 L .345 .65524 L F
.34708 .65477 m .34843 .65552 L .34632 .65561 L F
.288 .176 .548 r
.65981 .59607 m .65999 .5985 L .65882 .59769 L F
0 0 .354 r
.65882 .59769 m .65929 .60024 L .65999 .5985 L F
.756 .539 .602 r
.65999 .5985 m .65624 .60045 L .65882 .59769 L F
.288 .176 .548 r
.65882 .59769 m .65999 .5985 L .65981 .59607 L F
.323 0 0 r
.36681 .73557 m .36594 .73561 L .36948 .73583 L F
.206 0 0 r
.36594 .73561 m .36805 .7359 L .36948 .73583 L F
.56 .694 .93 r
.37121 .73491 m .36948 .73583 L .37074 .73457 L F
.638 .382 .514 r
.36805 .7359 m .37074 .73457 L .36948 .73583 L F
.524 .784 .992 r
.33678 .6757 m .33674 .67376 L .33537 .67495 L F
.356 .829 .805 r
.6494 .6054 m .64875 .60579 L .64786 .60618 L F
.6494 .6054 m .651 .60503 L .64875 .60579 L F
.789 .325 .136 r
.64875 .60579 m .64975 .60825 L .64786 .60618 L F
.64875 .60579 m .65073 .60741 L .64975 .60825 L F
.636 .511 .694 r
.651 .60503 m .65073 .60741 L .64875 .60579 L F
.684 .601 .757 r
.50346 .76469 m .50146 .76525 L .50032 .76218 L F
.688 .623 .777 r
.50346 .76469 m .50478 .76592 L .50146 .76525 L F
.627 .95 .939 r
.66599 .64294 m .66984 .64196 L .66936 .64272 L F
.366 0 .091 r
.66984 .64196 m .67131 .64321 L .66936 .64272 L F
.66984 .64196 m .6721 .64158 L .67131 .64321 L F
.682 .622 .782 r
.50694 .76521 m .50478 .76592 L .50346 .76469 L F
.693 .414 .496 r
.48634 .7705 m .48482 .77299 L .48283 .77058 L F
.683 .402 .49 r
.48836 .77264 m .48482 .77299 L .48634 .7705 L F
0 0 0 r
.38918 .7807 m .38841 .7818 L .38748 .78376 L F
.05 0 0 r
.32391 .67472 m .32084 .67544 L .32241 .67446 L F
.753 .791 .884 r
.71774 .60641 m .71926 .60611 L .71958 .60406 L F
0 0 0 r
.40813 .79094 m .41161 .78901 L .41002 .79075 L F
.201 0 0 r
.41214 .79014 m .41161 .78901 L .41395 .78824 L F
.41214 .79014 m .41002 .79075 L .41161 .78901 L F
.825 .626 .633 r
.60704 .65238 m .60635 .65289 L .60415 .64969 L F
.848 .676 .668 r
.60704 .65238 m .60562 .65517 L .60635 .65289 L F
.628 .553 .75 r
.49904 .75694 m .49717 .7598 L .49688 .75734 L F
.49904 .75694 m .5001 .76034 L .49717 .7598 L F
.689 .537 .674 r
.50032 .76218 m .49717 .7598 L .5001 .76034 L F
.50032 .76218 m .49822 .76282 L .49717 .7598 L F
.469 0 .056 r
.44036 .77899 m .43886 .78035 L .43681 .78015 L F
.53 .164 .29 r
.44222 .77814 m .43886 .78035 L .44036 .77899 L F
.537 .635 .895 r
.69584 .71172 m .69925 .7143 L .69816 .7132 L F
.632 .677 .875 r
.69953 .71659 m .69816 .7132 L .69925 .7143 L F
.052 0 .163 r
.70108 .71282 m .69925 .7143 L .70151 .71195 L F
.616 .382 .539 r
.70145 .71562 m .69925 .7143 L .70108 .71282 L F
.70145 .71562 m .69953 .71659 L .69925 .7143 L F
.602 .387 .561 r
.66494 .59595 m .66724 .59705 L .66606 .59905 L F
.66716 .59778 m .66778 .59828 L .66724 .59705 L F
0 0 .408 r
.66718 .59775 m .66716 .59777 L .66724 .59705 L F
.66716 .59777 m .66606 .59905 L .66724 .59705 L F
.602 .387 .561 r
.66494 .59595 m .66716 .59778 L .66724 .59705 L F
0 0 .408 r
.66698 .60039 m .66718 .59775 L .66778 .59828 L F
.66718 .59775 m .66724 .59705 L .66778 .59828 L F
.496 .336 .594 r
.66896 .59599 m .66778 .59828 L .66724 .59705 L F
.728 .612 .727 r
.6695 .59511 m .66778 .59828 L .66942 .59509 L F
.462 .293 .565 r
.67009 .59529 m .6699 .59554 L .6695 .59511 L F
.6699 .59554 m .66778 .59828 L .6695 .59511 L F
.665 .288 .321 r
.67003 .59581 m .67034 .59599 L .6695 .59511 L F
.496 .336 .594 r
.66982 .59546 m .66778 .59828 L .66896 .59599 L F
.6699 .59554 m .66778 .59828 L .66982 .59546 L F
.67009 .59529 m .66978 .5957 L .66973 .59552 L F
.665 .288 .321 r
.6699 .59554 m .66993 .59556 L .6695 .59511 L F
.66993 .59556 m .67169 .59681 L .67001 .59551 L F
.66993 .59556 m .67001 .59551 L .6695 .59511 L F
0 .12 .589 r
.6695 .59511 m .66996 .59547 L .66996 .59547 L F
.281 .209 .594 r
.66993 .59544 m .66968 .59534 L .66964 .59522 L F
.496 .336 .594 r
.66996 .59547 m .6699 .59554 L .66989 .59541 L F
.281 .209 .594 r
.67019 .59563 m .66992 .59548 L .66993 .59544 L F
.66992 .59548 m .66968 .59534 L .66993 .59544 L F
.496 .336 .594 r
.66973 .59552 m .66778 .59828 L .66724 .59705 L F
.728 .612 .727 r
.66942 .59509 m .66778 .59828 L .66624 .5943 L F
0 0 0 r
.66825 .59661 m .66995 .59539 L .66835 .59591 L F
.66995 .59539 m .67009 .59529 L .66998 .59533 L F
.66995 .59539 m .66998 .59533 L .66835 .59591 L F
.496 .336 .594 r
.66978 .5957 m .66778 .59828 L .66973 .59552 L F
0 0 0 r
.66807 .59783 m .66984 .59561 L .66825 .59661 L F
.496 .336 .594 r
.6699 .59553 m .6699 .59554 L .6699 .59553 L F
.6699 .59553 m .6699 .59553 L .66982 .59546 L F
.66989 .59541 m .6699 .59553 L .66982 .59546 L F
0 .12 .589 r
.6695 .59511 m .66999 .59549 L .66964 .59522 L F
.449 0 0 r
.6695 .59511 m .66998 .59533 L .67009 .59529 L F
.281 .209 .594 r
.67149 .59417 m .67031 .59549 L .6695 .59511 L F
.67103 .59392 m .6695 .59511 L .66873 .59266 L F
.67149 .59417 m .67052 .59463 L .67103 .59392 L F
.67052 .59463 m .6695 .59511 L .67103 .59392 L F
.616 .576 .787 r
.66975 .59028 m .6712 .59352 L .66873 .59266 L F
.6712 .59352 m .67149 .59417 L .67103 .59392 L F
.6712 .59352 m .67103 .59392 L .66873 .59266 L F
.271 .378 .789 r
.67218 .59217 m .67149 .59417 L .66975 .59028 L F
.692 .844 .956 r
.67174 .59292 m .67015 .59561 L .67062 .59511 L F
.67174 .59292 m .67062 .59511 L .67149 .59417 L F
.67218 .59217 m .67174 .59292 L .67149 .59417 L F
.67015 .59561 m .67019 .59563 L .67149 .59417 L F
.496 .336 .594 r
.67009 .59529 m .66996 .59547 L .66989 .59541 L F
0 0 0 r
.66996 .59546 m .67009 .59529 L .66995 .59539 L F
.281 .209 .594 r
.66998 .59533 m .66993 .59544 L .6695 .59511 L F
0 0 0 r
.66993 .59544 m .66995 .59539 L .66991 .59542 L F
.66996 .59546 m .66995 .59539 L .66993 .59544 L F
.281 .209 .594 r
.67031 .59549 m .67019 .59563 L .66993 .59544 L F
0 0 0 r
.66996 .59546 m .66996 .59547 L .67009 .59529 L F
.281 .209 .594 r
.67031 .59549 m .66993 .59544 L .66998 .59533 L F
0 .12 .589 r
.66954 .59514 m .66964 .59522 L .67066 .59594 L F
.66964 .59522 m .67006 .59555 L .67012 .59559 L F
.66964 .59522 m .67012 .59559 L .67066 .59594 L F
.67006 .59555 m .6716 .59674 L .67066 .59594 L F
0 .274 .721 r
.67066 .59594 m .67023 .59585 L .67031 .59571 L F
.67066 .59594 m .67031 .59571 L .67174 .59292 L F
.665 .288 .321 r
.67034 .59599 m .67066 .59619 L .6699 .59554 L F
.281 .209 .594 r
.67019 .59563 m .67003 .59581 L .66968 .59534 L F
.692 .844 .956 r
.67015 .59561 m .67003 .59581 L .67019 .59563 L F
0 .12 .589 r
.67033 .59575 m .67031 .59574 L .67006 .59555 L F
.67006 .59554 m .67006 .59555 L .66998 .59548 L F
.67033 .59575 m .67006 .59555 L .67006 .59554 L F
0 .274 .721 r
.67023 .59585 m .67003 .59581 L .67015 .59561 L F
.6703 .5957 m .67015 .59561 L .67075 .59459 L F
.67023 .59585 m .67015 .59561 L .6703 .5957 L F
.67023 .59585 m .67075 .59459 L .67174 .59292 L F
.67207 .59247 m .67174 .59292 L .67218 .59217 L F
.67066 .59594 m .67174 .59292 L .67207 .59247 L F
0 .12 .589 r
.66999 .59549 m .67033 .59575 L .66998 .59548 L F
.67033 .59575 m .6716 .59674 L .67031 .59574 L F
.66999 .59549 m .66998 .59548 L .66964 .59522 L F
0 0 0 r
.66984 .59561 m .66996 .59546 L .66825 .59661 L F
.66996 .59546 m .66991 .59542 L .66825 .59661 L F
.281 .209 .594 r
.66964 .59522 m .66968 .59534 L .6695 .59511 L F
.449 0 0 r
.6695 .59511 m .66986 .59538 L .66998 .59533 L F
0 .12 .589 r
.6695 .59511 m .66964 .59522 L .66956 .59515 L F
.6695 .59511 m .66956 .59515 L .66954 .59514 L F
.449 0 0 r
.6695 .59511 m .66835 .59591 L .66986 .59538 L F
0 0 0 r
.66807 .59783 m .66778 .59828 L .66996 .59547 L F
.66807 .59783 m .66996 .59547 L .66996 .59546 L F
0 .12 .589 r
.66996 .59547 m .67169 .59681 L .6716 .59674 L F
.66996 .59547 m .67169 .59681 L .66996 .59547 L F
.665 .288 .321 r
.67066 .59619 m .67169 .59681 L .6699 .59554 L F
.34 .391 .768 r
.66624 .5943 m .66743 .59737 L .66562 .59634 L F
.66504 .59582 m .66562 .59634 L .66494 .59595 L F
.66624 .5943 m .66562 .59634 L .66504 .59582 L F
.66743 .59737 m .66778 .59828 L .66716 .59778 L F
.66743 .59737 m .66716 .59778 L .66494 .59595 L F
0 0 .408 r
.66698 .60039 m .6662 .59925 L .66718 .59775 L F
.6662 .59925 m .66606 .59905 L .66718 .59775 L F
.66698 .60039 m .66728 .60099 L .66606 .59905 L F
.047 0 0 r
.38499 .75709 m .38233 .75931 L .38275 .75723 L F
.702 .608 .749 r
.60107 .67034 m .59778 .67118 L .6 .66875 L F
.658 .41 .532 r
.60107 .67034 m .59789 .67336 L .59778 .67118 L F
.64 .598 .791 r
.48459 .74099 m .4824 .74156 L .48103 .73838 L F
.783 .973 .915 r
.67754 .71468 m .67445 .71614 L .67753 .71186 L F
.658 .629 .81 r
.68 .71383 m .67754 .71468 L .67753 .71186 L F
.505 .293 .526 r
.3523 .70512 m .35099 .70345 L .35321 .70308 L F
.3523 .70512 m .35088 .70554 L .35099 .70345 L F
.254 .008 .335 r
.37769 .67151 m .3771 .67346 L .37578 .67373 L F
.42 .295 .604 r
.37746 .67563 m .37578 .67373 L .3771 .67346 L F
.37746 .67563 m .37542 .67651 L .37578 .67373 L F
.681 .701 .862 r
.49699 .88522 m .49967 .88561 L .49796 .88307 L F
.782 .734 .808 r
.49796 .88307 m .49967 .88561 L .50216 .88305 L F
.788 .571 .606 r
.51293 .77606 m .51277 .77849 L .51115 .77572 L F
.744 .659 .766 r
.39924 .75957 m .40315 .76024 L .40077 .75902 L F
.864 .577 .5 r
.5321 .83152 m .53492 .83444 L .53525 .83211 L F
.764 .572 .637 r
.72554 .74103 m .72509 .7438 L .72187 .7435 L F
.55 0 0 r
.72531 .74147 m .72554 .74103 L .7252 .73986 L F
.735 .543 .634 r
.72853 .74335 m .72509 .7438 L .72554 .74103 L F
.55 0 0 r
.72531 .74147 m .72722 .74199 L .72554 .74103 L F
.735 .543 .634 r
.72733 .74242 m .72554 .74103 L .72722 .74199 L F
.601 .894 .989 r
.72696 .741 m .72722 .74199 L .72531 .74147 L F
.72864 .74052 m .72722 .74199 L .72696 .741 L F
.735 .543 .634 r
.72853 .74335 m .72733 .74242 L .72722 .74199 L F
.661 .321 .387 r
.48422 .87116 m .48727 .86883 L .4855 .87071 L F
.48422 .87116 m .4855 .87071 L .48557 .87064 L F
.48422 .87116 m .48653 .87188 L .48727 .86883 L F
.051 0 .017 r
.48727 .86883 m .48879 .86872 L .48901 .86767 L F
.437 .114 .319 r
.48727 .86883 m .48653 .87188 L .48875 .87144 L F
.486 .75 .988 r
.45788 .7269 m .45699 .72813 L .45576 .72725 L F
.45788 .7269 m .45905 .72794 L .45699 .72813 L F
.638 .242 .277 r
.47941 .77234 m .47602 .77247 L .47735 .77064 L F
.602 .464 .665 r
.33698 .77867 m .3393 .78077 L .33925 .77837 L F
.33698 .77867 m .33714 .78105 L .3393 .78077 L F
.769 .712 .799 r
.36156 .83203 m .36324 .83479 L .35966 .83516 L F
.761 .583 .655 r
.35966 .83516 m .36324 .83479 L .36078 .83562 L F
.062 .377 .842 r
.36328 .83785 m .36078 .83562 L .36324 .83479 L F
.97 .658 .352 r
.36219 .8348 m .36324 .83479 L .36156 .83203 L F
.519 .352 .595 r
.36514 .837 m .36328 .83785 L .36324 .83479 L F
.628 .626 .829 r
.36219 .8348 m .36514 .837 L .36324 .83479 L F
.831 .626 .625 r
.63293 .60407 m .63133 .60096 L .6331 .6018 L F
.652 .21 .189 r
.47193 .77049 m .47372 .77243 L .47095 .77208 L F
.565 .457 .69 r
.37082 .77028 m .37083 .77256 L .36907 .77286 L F
.586 .452 .665 r
.37139 .77561 m .36907 .77286 L .37083 .77256 L F
.37139 .77561 m .36955 .77599 L .36907 .77286 L F
.659 .66 .84 r
.7175 .70875 m .71561 .71235 L .71484 .70979 L F
.7175 .70875 m .71867 .71155 L .71561 .71235 L F
.572 .342 .529 r
.71816 .7136 m .71561 .71235 L .71585 .71393 L F
.71816 .7136 m .71867 .71155 L .71561 .71235 L F
.872 .574 .48 r
.71379 .69638 m .714 .69776 L .71574 .69817 L F
.896 .549 .381 r
.714 .69776 m .71602 .70016 L .71574 .69817 L F
.573 .501 .736 r
.35503 .6603 m .35299 .66077 L .35205 .65717 L F
.656 .824 .964 r
.43399 .74322 m .43537 .74431 L .43742 .74339 L F
.59 .54 .766 r
.49904 .75694 m .49688 .75734 L .49584 .75412 L F
.498 .874 .977 r
.36457 .81016 m .36332 .80815 L .36377 .80793 L F
.36457 .81016 m .36267 .81076 L .36332 .80815 L F
.694 .85 .957 r
.6538 .5872 m .65373 .58891 L .6536 .5888 L F
.278 .445 .847 r
.69303 .59929 m .69446 .60194 L .69562 .60078 L F
.402 .648 .957 r
.69446 .60194 m .69665 .60213 L .69562 .60078 L F
.988 .717 .388 r
.70344 .62131 m .70398 .62353 L .7047 .62326 L F
.70344 .62131 m .70398 .62353 L .7047 .62326 L F
.231 .637 .958 r
.70599 .6227 m .7047 .62326 L .70398 .62353 L F
.182 .508 .912 r
.7047 .62326 m .70599 .6227 L .70398 .62353 L F
.7047 .62326 m .70664 .6237 L .70599 .6227 L F
.516 .179 .334 r
.38661 .72971 m .3888 .72955 L .39002 .72712 L F
.445 .08 .249 r
.3888 .72955 m .39218 .72704 L .39002 .72712 L F
.287 0 0 r
.42128 .78562 m .41791 .78756 L .41922 .78596 L F
.787 .841 .893 r
.70378 .63143 m .70042 .63187 L .70273 .63153 L F
.379 .844 .843 r
.70596 .63068 m .70378 .63143 L .70273 .63153 L F
.663 .787 .94 r
.4342 .74051 m .43749 .74072 L .43656 .73948 L F
.769 .529 .571 r
.4342 .74051 m .43742 .74339 L .43749 .74072 L F
.402 .704 .983 r
.43749 .74072 m .43798 .73978 L .43656 .73948 L F
.43749 .74072 m .43961 .74105 L .43798 .73978 L F
.65 .452 .602 r
.43749 .74072 m .43742 .74339 L .43961 .74105 L F
.071 .592 .876 r
.72594 .72209 m .72302 .72133 L .72363 .72249 L F
.746 .486 .537 r
.46641 .75939 m .4665 .76311 L .46951 .76212 L F
.773 .686 .767 r
.33901 .81099 m .34147 .81063 L .33941 .80751 L F
.8 .95 .918 r
.33853 .81324 m .34147 .81063 L .33901 .81099 L F
.411 .536 .872 r
.33941 .80751 m .34147 .81063 L .34271 .8102 L F
.582 .669 .898 r
.49349 .74549 m .49143 .74595 L .48998 .74354 L F
.153 0 0 r
.70778 .63903 m .70775 .6386 L .71071 .63714 L F
.70778 .63903 m .71071 .63714 L .7093 .63782 L F
0 0 0 r
.71071 .63714 m .71146 .63718 L .7093 .63782 L F
.71071 .63714 m .71284 .63693 L .71146 .63718 L F
.842 .566 .521 r
.64415 .60389 m .64479 .60251 L .64119 .60122 L F
.746 .921 .56 r
.70497 .69853 m .70374 .69994 L .70138 .69804 L F
.316 0 0 r
.33601 .69818 m .33826 .69784 L .33817 .69758 L F
.496 .276 .51 r
.33584 .70044 m .33826 .69784 L .33601 .69818 L F
.406 .28 .594 r
.34759 .6876 m .34921 .68707 L .34938 .68439 L F
.428 .339 .654 r
.34759 .6876 m .34954 .6893 L .34921 .68707 L F
.423 .339 .657 r
.34759 .6876 m .34795 .69004 L .34954 .6893 L F
.052 .317 .801 r
.51572 .77015 m .51805 .77202 L .51737 .7728 L F
0 0 .055 r
.51803 .76759 m .51774 .77073 L .51816 .76762 L F
.51816 .76762 m .51774 .77073 L .51803 .76759 L F
.094 .306 .784 r
.51657 .76917 m .51881 .77107 L .51805 .77202 L F
.708 .298 .267 r
.51868 .77123 m .51805 .77202 L .51881 .77107 L F
.158 .481 .899 r
.51805 .77202 m .51742 .77282 L .51737 .7728 L F
.708 .298 .267 r
.51672 .7737 m .51805 .77202 L .51868 .77123 L F
.158 .481 .899 r
.51805 .77202 m .51911 .77344 L .51742 .77282 L F
.674 .528 .679 r
.47865 .75926 m .4805 .75965 L .48032 .75777 L F
.673 .395 .491 r
.47865 .75926 m .48049 .76168 L .4805 .75965 L F
.47865 .75926 m .47714 .76187 L .48049 .76168 L F
.427 .221 .495 r
.33039 .78909 m .33245 .78636 L .33021 .7866 L F
.531 .382 .624 r
.35299 .75163 m .35109 .75438 L .35306 .754 L F
.551 .412 .646 r
.35122 .75687 m .35306 .754 L .35109 .75438 L F
.526 .672 .929 r
.5537 .81299 m .55489 .81191 L .55276 .81223 L F
.5537 .81299 m .55586 .8129 L .55489 .81191 L F
.692 .591 .739 r
.34682 .81049 m .34744 .81375 L .34969 .81211 L F
.088 .11 .587 r
.40616 .74541 m .40518 .74612 L .40453 .74337 L F
.53 .611 .878 r
.72927 .72258 m .73168 .72247 L .73065 .72054 L F
.509 .298 .528 r
.35088 .70554 m .34874 .70782 L .34897 .70598 L F
.78 .57 .615 r
.66907 .60657 m .67255 .60846 L .67246 .60726 L F
.592 .556 .783 r
.49629 .74689 m .49505 .74897 L .49349 .74549 L F
.49629 .74689 m .4969 .74841 L .49505 .74897 L F
.645 .507 .68 r
.49786 .75153 m .49505 .74897 L .4969 .74841 L F
.49786 .75153 m .49562 .75196 L .49505 .74897 L F
.63 .569 .767 r
.36078 .83562 m .36096 .83808 L .3597 .83657 L F
.595 .606 .834 r
.36096 .83808 m .36219 .8348 L .35966 .83516 L F
.36096 .83808 m .36328 .83785 L .36219 .8348 L F
.495 .074 .17 r
.44755 .76726 m .44973 .7673 L .45117 .7655 L F
.535 .118 .197 r
.45117 .7655 m .44973 .7673 L .4529 .7667 L F
.502 .147 .296 r
.45117 .7655 m .4529 .7667 L .45333 .76536 L F
.643 .505 .679 r
.48032 .75777 m .48274 .75925 L .48242 .75723 L F
.48032 .75777 m .4805 .75965 L .48274 .75925 L F
.567 .168 .246 r
.48283 .77058 m .48136 .77245 L .47941 .77234 L F
.761 .407 .385 r
.48283 .77058 m .48482 .77299 L .48136 .77245 L F
.601 .659 .879 r
.38748 .78376 m .38571 .78453 L .38459 .78259 L F
.953 .621 .351 r
.674 .63001 m .6748 .62891 L .67406 .62689 L F
.674 .63001 m .6752 .63079 L .6748 .62891 L F
.603 .327 .471 r
.61424 .66868 m .6165 .67047 L .61414 .67067 L F
.621 .318 .435 r
.6166 .66871 m .6165 .67047 L .61424 .66868 L F
.95 .769 .624 r
.71912 .70852 m .71867 .71155 L .7175 .70875 L F
.492 .733 .979 r
.36419 .84015 m .3667 .84019 L .36485 .83898 L F
.36419 .84015 m .3667 .84019 L .36485 .83898 L F
.604 .413 .596 r
.36419 .84015 m .3667 .84019 L .36423 .84274 L F
.36419 .84015 m .3667 .84019 L .36423 .84274 L F
.798 .789 .844 r
.7036 .69484 m .70032 .69514 L .70252 .69442 L F
.7036 .69484 m .70145 .69626 L .70032 .69514 L F
.474 .864 .974 r
.7036 .69484 m .70486 .69382 L .70582 .6944 L F
.7036 .69484 m .70252 .69442 L .70486 .69382 L F
.565 .462 .696 r
.35386 .65494 m .35413 .65676 L .35205 .65717 L F
.573 .501 .736 r
.35503 .6603 m .35205 .65717 L .35413 .65676 L F
.658 .41 .532 r
.60107 .67034 m .60015 .67347 L .59789 .67336 L F
.648 .399 .529 r
.60411 .67299 m .60107 .67034 L .60328 .6716 L F
.60411 .67299 m .60015 .67347 L .60107 .67034 L F
.831 .371 0 r
.67054 .61493 m .67179 .61709 L .67283 .61781 L F
.134 .375 .831 r
.67179 .61709 m .67358 .6197 L .67283 .61781 L F
.528 .349 .581 r
.67358 .6197 m .67523 .61734 L .67283 .61781 L F
.19 0 0 r
.38726 .75706 m .38706 .75731 L .38499 .75709 L F
0 0 0 r
.389 .75626 m .38706 .75731 L .38726 .75706 L F
0 0 .426 r
.34848 .6795 m .34923 .68075 L .34988 .67892 L F
.34848 .6795 m .34872 .68189 L .34923 .68075 L F
0 .378 .774 r
.33958 .81897 m .33898 .81872 L .33804 .81803 L F
.33804 .81803 m .33898 .81872 L .33958 .81897 L F
.614 .582 .794 r
.36635 .67129 m .36302 .6687 L .36499 .66824 L F
.506 .223 .419 r
.4417 .74262 m .43961 .74105 L .44312 .74116 L F
.696 .919 .969 r
.44366 .73961 m .44312 .74116 L .44474 .74007 L F
.799 .945 .595 r
.44366 .73961 m .4417 .74262 L .44312 .74116 L F
.601 .105 .046 r
.48235 .88527 m .48552 .88528 L .4835 .88642 L F
0 0 .254 r
.48654 .88498 m .48552 .88528 L .48637 .88347 L F
0 0 0 r
.48434 .88595 m .48552 .88528 L .48654 .88498 L F
.583 .535 .767 r
.48485 .88572 m .48654 .88498 L .48698 .88301 L F
.48474 .88586 m .48654 .88498 L .48485 .88572 L F
.48471 .8858 m .48698 .88301 L .48464 .88565 L F
.48474 .88586 m .48485 .88572 L .48471 .8858 L F
.48485 .88572 m .48698 .88301 L .48471 .8858 L F
.575 .112 .116 r
.4835 .88642 m .48474 .88586 L .48461 .88583 L F
0 0 0 r
.4835 .88642 m .48434 .88595 L .4846 .88583 L F
.575 .112 .116 r
.4835 .88642 m .48461 .88583 L .48235 .88527 L F
0 0 0 r
.4835 .88642 m .4846 .88583 L .48485 .88572 L F
.48396 .8862 m .48485 .88572 L .48654 .88498 L F
.4835 .88642 m .48485 .88572 L .48396 .8862 L F
.771 .682 .765 r
.6053 .64174 m .60643 .64478 L .60319 .64444 L F
.777 .662 .736 r
.60643 .64478 m .60446 .64735 L .60319 .64444 L F
.648 .369 .484 r
.62193 .66606 m .62416 .66813 L .62185 .66795 L F
.658 .367 .467 r
.62444 .66631 m .62416 .66813 L .62193 .66606 L F
.422 .235 .52 r
.48804 .87769 m .4864 .87763 L .48787 .87497 L F
0 0 .412 r
.48939 .87647 m .48787 .87497 L .48985 .87412 L F
.48939 .87647 m .48804 .87769 L .48787 .87497 L F
0 0 0 r
.38225 .80016 m .38233 .80007 L .38431 .7995 L F
.38239 .80002 m .38233 .80007 L .37953 .80128 L F
.363 .823 .732 r
.37953 .80128 m .38233 .80007 L .38049 .80071 L F
0 0 0 r
.38049 .80071 m .38233 .80007 L .38225 .80016 L F
.38324 .79964 m .38233 .80007 L .38239 .80002 L F
.271 .758 .666 r
.38415 .79955 m .38431 .7995 L .38621 .79874 L F
0 0 0 r
.38049 .80071 m .38431 .7995 L .38265 .80015 L F
.271 .758 .666 r
.38265 .80015 m .38431 .7995 L .38415 .79955 L F
0 0 0 r
.38448 .79945 m .38431 .7995 L .38324 .79964 L F
.3854 .79931 m .38431 .7995 L .38448 .79945 L F
.38431 .7995 m .38233 .80007 L .38324 .79964 L F
.837 .377 .114 r
.68622 .64239 m .68545 .6432 L .68472 .64166 L F
.68622 .64239 m .6868 .64364 L .68545 .6432 L F
.583 .794 .979 r
.46237 .7285 m .45905 .72794 L .46131 .72772 L F
.472 .759 .993 r
.46336 .7273 m .46237 .7285 L .46131 .72772 L F
.46336 .7273 m .46449 .72831 L .46237 .7285 L F
.453 0 .046 r
.31631 .65203 m .31863 .65218 L .31957 .65089 L F
.14 0 0 r
.31957 .65089 m .3205 .65132 L .32202 .65052 L F
.048 0 0 r
.31957 .65089 m .31863 .65218 L .3205 .65132 L F
.779 .664 .736 r
.68073 .70833 m .68414 .70887 L .68266 .7054 L F
.753 .513 .568 r
.68064 .7105 m .68414 .70887 L .68073 .70833 L F
.68064 .7105 m .68365 .71086 L .68414 .70887 L F
.855 .623 .585 r
.68365 .71086 m .68571 .71204 L .68414 .70887 L F
.669 .612 .782 r
.68266 .7054 m .68414 .70887 L .68615 .70604 L F
.641 .573 .763 r
.68414 .70887 m .68766 .70955 L .68615 .70604 L F
.65 .549 .726 r
.68414 .70887 m .68691 .71048 L .68766 .70955 L F
.68414 .70887 m .68571 .71204 L .68691 .71048 L F
.113 0 .161 r
.65884 .63105 m .66075 .63039 L .66108 .62821 L F
.594 .836 .464 r
.66309 .62557 m .66108 .62821 L .66205 .62684 L F
0 0 0 r
.66108 .62821 m .66129 .62874 L .66205 .62684 L F
.66108 .62821 m .66075 .63039 L .66129 .62874 L F
.352 0 .167 r
.44322 .7676 m .44409 .76918 L .44544 .76754 L F
.44322 .7676 m .44206 .76965 L .44409 .76918 L F
.684 .601 .757 r
.50346 .76469 m .50032 .76218 L .50265 .7619 L F
.641 .594 .786 r
.50576 .76233 m .50346 .76469 L .50265 .7619 L F
.682 .622 .782 r
.50694 .76521 m .50346 .76469 L .50576 .76233 L F
.632 .584 .783 r
.35966 .83516 m .35813 .83598 L .35678 .8337 L F
.35966 .83516 m .35813 .83598 L .35678 .8337 L F
.843 .662 .657 r
.63969 .61779 m .64211 .61779 L .64075 .61467 L F
.483 .304 .561 r
.63977 .60707 m .6419 .60642 L .6399 .6091 L F
.427 .175 .427 r
.64212 .60476 m .6419 .60642 L .63977 .60707 L F
.483 .304 .561 r
.63977 .60707 m .6419 .60642 L .6399 .6091 L F
.999 .791 .483 r
.64428 .61987 m .64441 .61733 L .64211 .61779 L F
.563 .394 .61 r
.64211 .61779 m .64428 .61987 L .64441 .61733 L F
.127 0 0 r
.33305 .67529 m .33207 .67578 L .33094 .67556 L F
.327 0 .076 r
.37365 .73521 m .37563 .73485 L .37703 .733 L F
.415 .029 .195 r
.37563 .73485 m .37897 .73251 L .37703 .733 L F
.486 .696 .962 r
.68481 .59572 m .68637 .59415 L .68363 .59292 L F
.68481 .59572 m .68696 .59555 L .68637 .59415 L F
.665 .828 .962 r
.71958 .60406 m .71663 .60389 L .71774 .60641 L F
.777 .607 .669 r
.62276 .64678 m .62439 .64747 L .62269 .64448 L F
.763 .627 .71 r
.62385 .64981 m .62439 .64747 L .62276 .64678 L F
.716 .54 .65 r
.57353 .80002 m .57341 .80246 L .57509 .79931 L F
.343 .347 .72 r
.65389 .6305 m .6554 .6322 L .65481 .63018 L F
.23 0 .249 r
.36377 .80793 m .36514 .80548 L .36672 .80473 L F
.616 .137 .094 r
.42191 .72338 m .42382 .72414 L .42497 .72319 L F
.524 .029 .021 r
.42497 .72319 m .42382 .72414 L .42724 .72386 L F
.689 .215 0 r
.67387 .61547 m .67435 .61647 L .67475 .6144 L F
.67387 .61547 m .67523 .61734 L .67435 .61647 L F
.524 .539 .813 r
.36697 .66782 m .36635 .67129 L .36499 .66824 L F
.36697 .66782 m .36823 .67097 L .36635 .67129 L F
.977 .682 .309 r
.6728 .60663 m .67393 .60965 L .67304 .60871 L F
.936 .567 .188 r
.67393 .60965 m .67352 .61087 L .67304 .60871 L F
.67393 .60965 m .67463 .61181 L .67352 .61087 L F
.291 0 0 r
.64483 .65473 m .64579 .65543 L .64391 .65539 L F
.64483 .65473 m .64696 .65471 L .64579 .65543 L F
.39 0 .01 r
.39999 .7253 m .40166 .72581 L .40305 .72436 L F
.468 .038 .138 r
.40166 .72581 m .40526 .7241 L .40305 .72436 L F
.499 .119 .251 r
.46271 .77448 m .46101 .77339 L .46323 .77354 L F
.46271 .77448 m .46033 .77477 L .46101 .77339 L F
.527 .644 .908 r
.68696 .59555 m .68785 .59716 L .68975 .59684 L F
.637 .845 .98 r
.3785 .77934 m .37525 .77918 L .37752 .77873 L F
.347 .555 .912 r
.37926 .77782 m .3785 .77934 L .37752 .77873 L F
.37926 .77782 m .38088 .78016 L .3785 .77934 L F
.742 .812 .907 r
.37021 .67055 m .36967 .67302 L .36823 .67097 L F
.37021 .67055 m .37189 .67223 L .36967 .67302 L F
.48 .546 .846 r
.48804 .87769 m .48757 .87972 L .4864 .87763 L F
.663 .332 .404 r
.72853 .74335 m .72542 .74517 L .72509 .7438 L F
.72853 .74335 m .72757 .74609 L .72542 .74517 L F
.502 .53 .818 r
.72965 .74104 m .72853 .74335 L .72722 .74199 L F
.72965 .74104 m .73086 .74473 L .72853 .74335 L F
.667 .336 .405 r
.73041 .74505 m .72757 .74609 L .72853 .74335 L F
.176 .712 .762 r
.36904 .84837 m .36562 .84887 L .36744 .84775 L F
.36904 .84837 m .36562 .84887 L .36744 .84775 L F
.538 .433 .683 r
.54964 .80752 m .55135 .80502 L .54935 .80602 L F
.54964 .80752 m .55141 .80718 L .55135 .80502 L F
.554 .434 .67 r
.54994 .811 m .55141 .80718 L .54964 .80752 L F
.674 .661 .83 r
.71116 .60356 m .71226 .60477 L .71432 .60429 L F
.31 .663 .973 r
.32202 .65052 m .3231 .65126 L .3223 .65092 L F
.346 .534 .896 r
.32378 .6502 m .3231 .65126 L .32202 .65052 L F
.32378 .6502 m .32529 .65231 L .3231 .65126 L F
.713 .987 .864 r
.65201 .60377 m .6532 .60356 L .651 .60503 L F
.199 0 0 r
.65514 .60374 m .6532 .60356 L .65201 .60377 L F
.938 .748 .62 r
.70145 .69626 m .70138 .69804 L .70032 .69514 L F
.546 .336 .547 r
.55095 .80298 m .55355 .80271 L .5535 .79994 L F
.561 .348 .549 r
.5535 .79994 m .55355 .80271 L .55567 .8019 L F
.461 .222 .465 r
.528 .77547 m .52564 .778 L .52598 .77595 L F
.14 .315 .779 r
.6538 .5872 m .6536 .5888 L .65157 .58526 L F
.418 .167 .424 r
.64212 .60476 m .64415 .60389 L .6419 .60642 L F
.044 .323 .807 r
.37196 .67048 m .37189 .67223 L .37021 .67055 L F
.504 .617 .897 r
.73275 .73209 m .7312 .73413 L .73034 .73206 L F
.211 .282 .72 r
.39428 .77959 m .39333 .78099 L .3914 .77841 L F
.672 .123 0 r
.6868 .64364 m .68951 .64481 L .68892 .64531 L F
.348 0 0 r
.69192 .64588 m .68892 .64531 L .68951 .64481 L F
.063 .627 .757 r
.49796 .88307 m .5013 .88301 L .50216 .88305 L F
.782 .734 .808 r
.49796 .88307 m .50216 .88305 L .5013 .88301 L F
.827 .668 .686 r
.68496 .71385 m .68571 .71204 L .68365 .71086 L F
.304 .099 .428 r
.68691 .71048 m .68571 .71204 L .68496 .71385 L F
0 0 0 r
.32148 .73357 m .31857 .73544 L .31885 .73513 L F
.047 0 0 r
.38499 .75709 m .38367 .7589 L .38233 .75931 L F
0 0 0 r
.38634 .7562 m .38499 .75709 L .38706 .75731 L F
.38634 .7562 m .38367 .7589 L .38499 .75709 L F
.186 0 0 r
.73481 .73564 m .73456 .73565 L .73158 .73512 L F
.73481 .73564 m .73456 .73565 L .73158 .73512 L F
.603 .922 .684 r
.73481 .73564 m .73456 .73565 L .73553 .73468 L F
.73481 .73564 m .73456 .73565 L .73553 .73468 L F
.492 .62 .905 r
.45964 .74029 m .4601 .738 L .45827 .73757 L F
.45964 .74029 m .46155 .74021 L .4601 .738 L F
.464 .333 .617 r
.37746 .67563 m .37524 .67823 L .37542 .67651 L F
.785 .832 .888 r
.45277 .73846 m .4541 .73938 L .45604 .73803 L F
.011 0 0 r
.42343 .78531 m .42704 .78304 L .42564 .78488 L F
.368 0 .076 r
.42564 .78488 m .42704 .78304 L .4291 .78282 L F
.6 .64 .863 r
.55045 .81234 m .5522 .81071 L .54994 .811 L F
.55045 .81234 m .55276 .81223 L .5522 .81071 L F
.357 .113 .401 r
.71116 .62828 m .71298 .62778 L .71341 .62545 L F
.247 .021 .361 r
.71341 .62545 m .71298 .62778 L .71513 .62673 L F
.175 0 0 r
.31485 .71688 m .31641 .71675 L .31714 .71608 L F
.251 0 0 r
.31395 .71755 m .31641 .71675 L .31485 .71688 L F
.763 .627 .71 r
.62385 .64981 m .62276 .64678 L .62073 .64944 L F
.752 .511 .568 r
.62047 .65183 m .62385 .64981 L .62073 .64944 L F
.62047 .65183 m .62394 .65212 L .62385 .64981 L F
.826 .743 .772 r
.70939 .72482 m .70768 .72729 L .7106 .7276 L F
.76 .625 .71 r
.70768 .72729 m .7107 .72991 L .7106 .7276 L F
.766 .718 .808 r
.70939 .72482 m .7106 .7276 L .7127 .72492 L F
.416 .465 .803 r
.66289 .58968 m .66124 .59128 L .66011 .58828 L F
.384 .414 .769 r
.66289 .58968 m .66369 .59293 L .66124 .59128 L F
.56 .276 .441 r
.32714 .71117 m .32936 .71107 L .32993 .70913 L F
.433 .157 .392 r
.32993 .70913 m .33131 .71056 L .33201 .70858 L F
.32993 .70913 m .32936 .71107 L .33131 .71056 L F
.545 .483 .737 r
.68188 .69992 m .68513 .70087 L .68387 .69747 L F
.593 .463 .672 r
.68188 .69992 m .68507 .70284 L .68513 .70087 L F
.68188 .69992 m .68277 .70326 L .68507 .70284 L F
.532 .752 .977 r
.41273 .74315 m .41559 .74366 L .41437 .7426 L F
.612 .502 .704 r
.41273 .74315 m .41547 .74601 L .41559 .74366 L F
.481 .291 .545 r
.41559 .74366 m .41547 .74601 L .41752 .74315 L F
.958 .71 .521 r
.41547 .74601 m .41559 .74366 L .41752 .74315 L F
.262 .31 .724 r
.3364 .81561 m .33853 .81324 L .33566 .81321 L F
.3364 .81561 m .33786 .81481 L .33853 .81324 L F
.3364 .81561 m .33669 .8159 L .33786 .81481 L F
.904 .964 .815 r
.67453 .605 m .6728 .60663 L .67249 .60557 L F
.417 .484 .822 r
.67641 .60253 m .67453 .605 L .67394 .60325 L F
.67641 .60253 m .67767 .60529 L .67453 .605 L F
.386 .581 .919 r
.4722 .7292 m .47123 .73053 L .47031 .72896 L F
.466 .693 .966 r
.4722 .7292 m .47339 .73048 L .47123 .73053 L F
.614 .574 .785 r
.47461 .73321 m .47123 .73053 L .47339 .73048 L F
.668 .643 .816 r
.50918 .7649 m .50694 .76521 L .50576 .76233 L F
.576 .402 .609 r
.50918 .7649 m .50707 .76748 L .50694 .76521 L F
.912 .763 .683 r
.62138 .64335 m .62269 .64448 L .62175 .64144 L F
.848 .712 .712 r
.62138 .64335 m .62276 .64678 L .62269 .64448 L F
.895 .757 .701 r
.62269 .64448 m .62293 .64212 L .62175 .64144 L F
.556 .396 .62 r
.34709 .76243 m .34923 .76214 L .34907 .75954 L F
.523 .365 .609 r
.34709 .76243 m .34908 .7644 L .34923 .76214 L F
.34709 .76243 m .34711 .76511 L .34908 .7644 L F
.253 0 0 r
.41904 .77678 m .421 .7768 L .42265 .77605 L F
.582 .14 .165 r
.421 .7768 m .42475 .77571 L .42265 .77605 L F
0 0 0 r
.38729 .7989 m .39089 .7971 L .38861 .79841 L F
.39253 .79642 m .39196 .79693 L .39089 .7971 L F
.39196 .79693 m .38861 .79841 L .39089 .7971 L F
.567 .392 .604 r
.34536 .76553 m .34714 .76743 L .34711 .76511 L F
.34536 .76553 m .34524 .76776 L .34714 .76743 L F
.134 .566 .925 r
.45454 .7263 m .45391 .72684 L .45261 .72593 L F
.45454 .7263 m .45576 .72725 L .45391 .72684 L F
0 0 0 r
.32722 .72945 m .32452 .73154 L .32586 .7301 L F
.879 .942 .853 r
.70717 .59988 m .70552 .60176 L .70554 .60034 L F
.822 .377 .175 r
.70775 .60174 m .70554 .60034 L .70552 .60176 L F
.262 .768 .76 r
.70554 .60034 m .70145 .60138 L .70237 .60172 L F
.809 .381 .228 r
.70554 .60034 m .70603 .60248 L .70369 .60087 L F
.70554 .60034 m .70369 .60087 L .70356 .60079 L F
.879 .942 .853 r
.70793 .59901 m .70717 .59988 L .70554 .60034 L F
.502 .196 .38 r
.63721 .64964 m .63949 .64926 L .64003 .64692 L F
.485 .87 .672 r
.63949 .64926 m .64284 .64709 L .64003 .64692 L F
.578 .382 .579 r
.35535 .74901 m .35747 .75103 L .35726 .74858 L F
.35535 .74901 m .3552 .75134 L .35747 .75103 L F
.455 .237 .492 r
.30926 .67865 m .30694 .68189 L .30662 .67935 L F
.257 .729 .941 r
.55916 .81331 m .55812 .81286 L .55586 .8129 L F
.819 .951 .906 r
.56045 .81079 m .55916 .81331 L .56164 .81188 L F
.544 .32 .527 r
.3858 .70885 m .38545 .71129 L .38327 .71147 L F
.38327 .71147 m .38545 .71129 L .3858 .70885 L F
.462 .249 .503 r
.38736 .7106 m .3858 .70885 L .38744 .70829 L F
.38736 .7106 m .38545 .71129 L .3858 .70885 L F
.3858 .70885 m .38736 .7106 L .38744 .70829 L F
.3858 .70885 m .38545 .71129 L .38736 .7106 L F
.544 .32 .527 r
.3858 .70885 m .38545 .71129 L .38327 .71147 L F
.27 .023 .342 r
.37924 .67075 m .3771 .67346 L .37769 .67151 L F
.111 0 .038 r
.33817 .69758 m .33826 .69784 L .33991 .69698 L F
.581 .469 .691 r
.33893 .77604 m .33925 .77837 L .3411 .77567 L F
.485 .581 .876 r
.38284 .77994 m .38161 .78157 L .38088 .78016 L F
.38284 .77994 m .38459 .78259 L .38161 .78157 L F
.333 .475 .853 r
.41785 .77482 m .41698 .77645 L .41579 .7761 L F
.41785 .77482 m .41904 .77678 L .41698 .77645 L F
.685 .627 .785 r
.56799 .80485 m .56873 .80838 L .5654 .80725 L F
.644 .084 0 r
.56829 .80911 m .5654 .80725 L .56873 .80838 L F
.556 .279 .451 r
.62971 .66341 m .62917 .66505 L .6274 .66551 L F
.242 0 .185 r
.63184 .66284 m .62917 .66505 L .62971 .66341 L F
.694 .404 .479 r
.48049 .76168 m .48257 .76182 L .4805 .75965 L F
.617 .41 .578 r
.4805 .75965 m .48257 .76182 L .48274 .75925 L F
.952 .897 .734 r
.6253 .63331 m .62791 .6308 L .62719 .63107 L F
.6253 .63331 m .62626 .63399 L .62791 .6308 L F
.689 .514 .646 r
.62791 .6308 m .62626 .63399 L .63115 .63346 L F
.159 .113 .552 r
.62925 .62743 m .62953 .63028 L .62791 .6308 L F
0 0 0 r
.62791 .6308 m .62953 .63028 L .62719 .63107 L F
.337 .516 .885 r
.73287 .74159 m .73531 .74272 L .73364 .74343 L F
0 0 0 r
.73531 .74272 m .73254 .74423 L .73364 .74343 L F
.135 0 0 r
.45328 .77569 m .45214 .77612 L .45008 .77627 L F
.377 0 .012 r
.45511 .77522 m .45214 .77612 L .45328 .77569 L F
.569 .216 .33 r
.55878 .80159 m .56108 .80169 L .55901 .80037 L F
.549 .237 .392 r
.55901 .80037 m .56108 .80169 L .56134 .80014 L F
.611 .38 .542 r
.33714 .78105 m .3391 .78317 L .3393 .78077 L F
.33714 .78105 m .33687 .7834 L .3391 .78317 L F
0 .034 .605 r
.51286 .82645 m .51124 .82363 L .5132 .82348 L F
.51286 .82645 m .5132 .82348 L .51305 .82543 L F
.112 .617 .899 r
.51449 .82544 m .5166 .82606 L .51305 .82543 L F
.481 .293 .549 r
.51124 .82363 m .51322 .82629 L .5132 .82348 L F
0 .034 .605 r
.51286 .82645 m .51322 .82629 L .51124 .82363 L F
.853 .915 .873 r
.65465 .64991 m .65365 .64914 L .65109 .65157 L F
.809 .826 .864 r
.65647 .64852 m .65365 .64914 L .65465 .64991 L F
.924 .919 .791 r
.61105 .63071 m .61199 .63142 L .61093 .63309 L F
.914 .943 .808 r
.61291 .6283 m .61199 .63142 L .61105 .63071 L F
.61291 .6283 m .61386 .6287 L .61199 .63142 L F
.124 .64 .89 r
.43602 .72482 m .43801 .72499 L .43936 .72546 L F
.184 .689 .906 r
.43801 .72499 m .4415 .72546 L .43936 .72546 L F
.043 0 0 r
.71567 .63598 m .71537 .63635 L .71284 .63693 L F
.564 .817 .445 r
.71677 .63456 m .71537 .63635 L .71567 .63598 L F
.963 .691 .47 r
.53545 .84544 m .53566 .84828 L .53432 .84745 L F
.637 .243 .282 r
.53545 .84544 m .53432 .84745 L .53728 .8464 L F
.781 .663 .734 r
.60319 .64444 m .60446 .64735 L .6012 .64723 L F
.77 .595 .662 r
.60446 .64735 m .60081 .64932 L .6012 .64723 L F
.60446 .64735 m .60415 .64969 L .60081 .64932 L F
.755 .695 .795 r
.6 .66875 m .59637 .66847 L .59903 .66793 L F
.966 .646 .273 r
.59912 .66635 m .6 .66875 L .59903 .66793 L F
.886 .954 .844 r
.61633 .62578 m .61386 .6287 L .61291 .6283 L F
.171 0 0 r
.64516 .58918 m .64404 .58865 L .64292 .58957 L F
.64516 .58918 m .64624 .58825 L .64404 .58865 L F
0 0 0 r
.32148 .73357 m .31984 .73516 L .31857 .73544 L F
.32159 .73431 m .32148 .73357 L .32313 .73262 L F
.32159 .73431 m .31984 .73516 L .32148 .73357 L F
.698 .427 .511 r
.70829 .63052 m .71086 .62941 L .71116 .62828 L F
.302 .056 .364 r
.71116 .62828 m .71292 .62975 L .71298 .62778 L F
.71116 .62828 m .71086 .62941 L .71292 .62975 L F
.816 .764 .804 r
.70259 .70343 m .70039 .70611 L .69982 .70394 L F
.999 .804 .471 r
.64288 .59819 m .64292 .59686 L .64195 .59782 L F
.366 0 .025 r
.64414 .59712 m .64089 .59889 L .64195 .59782 L F
.577 .861 .535 r
.64195 .59782 m .6408 .59894 L .63945 .60056 L F
.366 0 .025 r
.64089 .59889 m .6408 .59894 L .64195 .59782 L F
.999 .804 .471 r
.64292 .59686 m .64294 .59626 L .64195 .59782 L F
.413 0 0 r
.64294 .59626 m .64414 .59712 L .64195 .59782 L F
.857 .755 .749 r
.69729 .7173 m .69414 .7189 L .69622 .7157 L F
.69729 .7173 m .69573 .71996 L .69414 .7189 L F
.632 .677 .875 r
.69953 .71659 m .69729 .7173 L .69622 .7157 L F
.692 .351 .394 r
.46951 .76212 m .4716 .76421 L .47288 .76205 L F
.523 .127 .232 r
.4716 .76421 m .47505 .7623 L .47288 .76205 L F
.579 .003 0 r
.71529 .5969 m .71848 .59881 L .71881 .59868 L F
.07 0 0 r
.72105 .59867 m .71881 .59868 L .71848 .59881 L F
.72105 .59867 m .72117 .5984 L .71881 .59868 L F
.65 .689 .873 r
.37303 .7795 m .36978 .77841 L .37183 .77806 L F
.576 .734 .95 r
.3739 .77773 m .37303 .7795 L .37183 .77806 L F
.3739 .77773 m .37525 .77918 L .37303 .7795 L F
.692 .591 .739 r
.34682 .81049 m .34969 .81211 L .34818 .8103 L F
.443 .552 .872 r
.34969 .81211 m .35019 .81001 L .34818 .8103 L F
.34969 .81211 m .3515 .81205 L .35019 .81001 L F
0 .205 .655 r
.67711 .60892 m .67955 .61046 L .67959 .61069 L F
0 .333 .786 r
.68043 .61069 m .67959 .61069 L .67955 .61046 L F
.68043 .61069 m .68239 .61234 L .67959 .61069 L F
.514 .832 .523 r
.34332 .69523 m .34419 .69434 L .34583 .69277 L F
.182 0 0 r
.34583 .69277 m .34619 .69379 L .34724 .69192 L F
.34583 .69277 m .34419 .69434 L .34619 .69379 L F
.412 .692 .977 r
.3348 .6512 m .33607 .6524 L .33419 .65241 L F
.455 .237 .492 r
.30926 .67865 m .30868 .68118 L .30694 .68189 L F
.44 .2 .453 r
.3112 .67846 m .30868 .68118 L .30926 .67865 L F
.477 .502 .805 r
.66588 .61555 m .66662 .61849 L .66855 .61658 L F
.865 .97 .65 r
.66699 .62006 m .66855 .61658 L .66662 .61849 L F
.8 .612 .648 r
.5714 .80146 m .57341 .80246 L .57353 .80002 L F
.671 .616 .785 r
.46492 .74307 m .46619 .7461 L .46815 .74358 L F
.672 .617 .786 r
.46619 .7461 m .46934 .74635 L .46815 .74358 L F
.45 .806 .997 r
.73914 .73022 m .7383 .72955 L .73651 .72988 L F
.73914 .73022 m .7383 .72955 L .73651 .72988 L F
.766 .618 .695 r
.60415 .64969 m .60635 .65289 L .60249 .65232 L F
.776 .593 .652 r
.60635 .65289 m .60217 .65468 L .60249 .65232 L F
.60635 .65289 m .60562 .65517 L .60217 .65468 L F
.333 .788 .95 r
.3515 .81205 m .35453 .81226 L .35349 .81225 L F
.378 .81 .964 r
.35453 .81226 m .35515 .81158 L .35349 .81225 L F
.35453 .81226 m .35816 .81181 L .35515 .81158 L F
.568 .413 .632 r
.55095 .80298 m .54935 .80602 L .55135 .80502 L F
.617 .539 .744 r
.50232 .75986 m .50032 .76218 L .5001 .76034 L F
.653 .594 .776 r
.50232 .75986 m .50265 .7619 L .50032 .76218 L F
.171 0 0 r
.64836 .64232 m .6513 .6406 L .64944 .6407 L F
.715 .575 .696 r
.64623 .60138 m .64692 .59922 L .64288 .59819 L F
.969 .843 .433 r
.64667 .60023 m .64689 .59792 L .64692 .59922 L F
.6463 .60175 m .64692 .59922 L .64623 .60138 L F
.6463 .60175 m .64672 .599 L .64667 .60023 L F
.64672 .599 m .64689 .59792 L .64667 .60023 L F
.213 .11 .514 r
.64902 .60097 m .64742 .60428 L .64659 .60227 L F
.64663 .60132 m .64659 .60227 L .64623 .60138 L F
.64902 .60097 m .64659 .60227 L .64663 .60132 L F
.64813 .60281 m .64893 .60337 L .64742 .60428 L F
.703 .661 .806 r
.64911 .60326 m .6487 .6042 L .64742 .60428 L F
.6487 .6042 m .64786 .60618 L .64753 .60473 L F
.6487 .6042 m .64753 .60473 L .64742 .60428 L F
.213 .11 .514 r
.64902 .60097 m .64893 .60337 L .64813 .60281 L F
.775 .632 .703 r
.64623 .60138 m .64742 .60428 L .64415 .60389 L F
.703 .661 .806 r
.6487 .6042 m .6494 .6054 L .64786 .60618 L F
.64903 .60344 m .64929 .60459 L .6487 .6042 L F
.64929 .60459 m .6494 .6054 L .6487 .6042 L F
.589 .388 .577 r
.64786 .60618 m .64975 .60825 L .64742 .60837 L F
.773 .843 .905 r
.65083 .60249 m .6494 .6054 L .64911 .60326 L F
.398 .044 .243 r
.6478 .60686 m .64999 .60411 L .64788 .60395 L F
.64688 .60439 m .64788 .60395 L .64668 .60386 L F
.705 .423 .494 r
.64742 .60428 m .64421 .60562 L .64415 .60389 L F
.64742 .60428 m .64786 .60618 L .64421 .60562 L F
.71 .504 .608 r
.64421 .60562 m .64786 .60618 L .64742 .60837 L F
.398 .044 .243 r
.6478 .60686 m .64788 .60395 L .64688 .60439 L F
.703 .661 .806 r
.64911 .60326 m .64913 .60339 L .64903 .60344 L F
.64913 .60339 m .64929 .60459 L .64903 .60344 L F
.407 .626 .942 r
.64706 .60311 m .64959 .60381 L .64766 .60196 L F
.64668 .60386 m .64814 .60383 L .64706 .60311 L F
.64814 .60383 m .64959 .60381 L .64706 .60311 L F
.64959 .60381 m .65024 .6038 L .65 .60362 L F
.213 .11 .514 r
.64902 .60097 m .64911 .60326 L .64893 .60337 L F
.398 .25 .561 r
.65083 .60249 m .64911 .60326 L .64902 .60097 L F
.407 .626 .942 r
.64959 .60381 m .65 .60362 L .64766 .60196 L F
.398 .044 .243 r
.64999 .60411 m .65024 .6038 L .64956 .60381 L F
.64999 .60411 m .64956 .60381 L .64668 .60386 L F
.63 .255 .314 r
.65766 .60623 m .65854 .6042 L .65979 .60565 L F
.773 .678 .758 r
.34271 .8102 m .34682 .81049 L .34486 .80747 L F
.778 .65 .721 r
.34271 .8102 m .3457 .81371 L .34682 .81049 L F
.156 .698 .788 r
.34682 .81049 m .34703 .80805 L .34486 .80747 L F
.365 .676 .976 r
.34703 .80805 m .34773 .80802 L .34486 .80747 L F
.149 0 0 r
.34486 .80747 m .34766 .80801 L .34469 .80747 L F
.459 .399 .703 r
.349 .8069 m .34773 .80802 L .34703 .80805 L F
.149 0 0 r
.34766 .80801 m .34773 .80802 L .3476 .808 L F
.34766 .80801 m .3476 .808 L .34469 .80747 L F
.841 .86 .857 r
.34544 .80764 m .34621 .8089 L .34522 .8082 L F
.715 .913 .963 r
.34469 .80747 m .34773 .80802 L .349 .8069 L F
.607 .554 .769 r
.34192 .80494 m .34273 .80779 L .34486 .80747 L F
.34192 .80494 m .34486 .80747 L .34322 .80447 L F
.149 0 0 r
.34486 .80747 m .34469 .80747 L .34322 .80447 L F
.715 .913 .963 r
.34469 .80747 m .349 .8069 L .34696 .80512 L F
.841 .86 .857 r
.3461 .80592 m .34617 .80776 L .34544 .80764 L F
.34617 .80776 m .34621 .8089 L .34544 .80764 L F
.156 .698 .788 r
.34682 .81049 m .34682 .81033 L .34691 .80931 L F
.34683 .81047 m .34691 .80931 L .34703 .80805 L F
.34682 .81049 m .34691 .80931 L .34683 .81047 L F
.261 .037 .373 r
.349 .8069 m .34703 .80805 L .34682 .81033 L F
.567 .745 .961 r
.34696 .80512 m .349 .8069 L .35103 .80647 L F
.34696 .80512 m .35103 .80647 L .34918 .80458 L F
.407 .53 .869 r
.34817 .80521 m .34832 .80552 L .3475 .80756 L F
.905 .877 .798 r
.349 .8069 m .34727 .80815 L .3475 .80756 L F
.349 .8069 m .34682 .81033 L .34621 .8089 L F
.775 .638 .71 r
.34963 .80959 m .35103 .80647 L .349 .8069 L F
0 0 .429 r
.34989 .80867 m .34963 .80959 L .349 .8069 L F
.34989 .80867 m .349 .8069 L .3475 .80756 L F
.407 .53 .869 r
.34832 .80552 m .34989 .80867 L .3475 .80756 L F
.905 .877 .798 r
.34727 .80815 m .34698 .80835 L .3475 .80756 L F
.34698 .80835 m .34621 .8089 L .347 .80808 L F
.34698 .80835 m .347 .80808 L .3475 .80756 L F
.156 .698 .788 r
.34682 .81049 m .34818 .8103 L .34682 .81033 L F
.924 .919 .791 r
.61105 .63071 m .61093 .63309 L .60992 .63218 L F
.905 .853 .78 r
.61093 .63309 m .60792 .63513 L .60992 .63218 L F
.61093 .63309 m .60911 .63608 L .60792 .63513 L F
.694 .284 .265 r
.60328 .6716 m .60544 .67334 L .60411 .67299 L F
.613 .347 .491 r
.60533 .67129 m .60544 .67334 L .60328 .6716 L F
.674 .234 .198 r
.53311 .83711 m .53539 .8377 L .53644 .83738 L F
.591 .601 .83 r
.47672 .73275 m .47461 .73321 L .47339 .73048 L F
.607 .58 .797 r
.47792 .73576 m .47461 .73321 L .47672 .73275 L F
.753 .595 .68 r
.68948 .70855 m .69278 .70896 L .69244 .70875 L F
.702 .623 .766 r
.69244 .70875 m .69278 .70896 L .69524 .70662 L F
.697 .615 .761 r
.69278 .70896 m .6954 .70875 L .69524 .70662 L F
.983 .781 .553 r
.6782 .62798 m .67908 .63112 L .67799 .63025 L F
.986 .731 .458 r
.67799 .63025 m .67908 .63112 L .67908 .63316 L F
.879 .942 .853 r
.70793 .59901 m .70554 .60034 L .70668 .59802 L F
.575 .57 .811 r
.70893 .59539 m .70793 .59901 L .70668 .59802 L F
.70893 .59539 m .70949 .60009 L .70793 .59901 L F
.588 .913 .671 r
.6366 .61119 m .6365 .61149 L .63785 .61039 L F
0 0 0 r
.63785 .61039 m .63798 .61045 L .6366 .61119 L F
.63785 .61039 m .6399 .6091 L .63798 .61045 L F
.648 .765 .291 r
.68178 .61371 m .68113 .61518 L .6825 .61212 L F
0 0 0 r
.68178 .61371 m .6825 .61212 L .6842 .61125 L F
.68239 .61234 m .6825 .61212 L .6842 .61125 L F
.6825 .61212 m .68482 .60959 L .6842 .61125 L F
.374 .839 .879 r
.41273 .74315 m .41477 .74214 L .41073 .74135 L F
.41273 .74315 m .41437 .7426 L .41477 .74214 L F
.612 .502 .704 r
.41273 .74315 m .41346 .74717 L .41547 .74601 L F
.778 .935 .933 r
.5222 .7723 m .51911 .77344 L .52152 .77297 L F
.271 .77 .884 r
.52343 .77183 m .52441 .77198 L .5222 .7723 L F
0 0 0 r
.5222 .7723 m .52152 .77297 L .52343 .77183 L F
.652 .54 .714 r
.49786 .75153 m .49584 .75412 L .49562 .75196 L F
.644 .528 .707 r
.49786 .75153 m .49827 .7539 L .49584 .75412 L F
.59 .54 .766 r
.49904 .75694 m .49584 .75412 L .49827 .7539 L F
0 .029 .565 r
.34403 .81909 m .34148 .81607 L .34386 .81859 L F
.7 .538 .665 r
.3421 .82054 m .34403 .81909 L .34386 .81859 L F
.3421 .82054 m .343 .82137 L .34403 .81909 L F
.715 .977 .918 r
.65201 .60377 m .651 .60503 L .6494 .6054 L F
.819 .708 .743 r
.70138 .69804 m .69841 .69765 L .70032 .69514 L F
.772 .531 .569 r
.70138 .69804 m .69828 .70002 L .69841 .69765 L F
.70138 .69804 m .70147 .70035 L .69828 .70002 L F
.558 .363 .572 r
.70138 .69804 m .70374 .69994 L .70147 .70035 L F
.959 .628 .338 r
.5654 .80725 m .56573 .81025 L .56683 .81064 L F
.644 .084 0 r
.56829 .80911 m .56776 .80928 L .5654 .80725 L F
.052 .245 .741 r
.5654 .80725 m .56776 .80928 L .56651 .8064 L F
.438 .85 .681 r
.56651 .8064 m .5648 .80745 L .5654 .80725 L F
.129 .604 .919 r
.70951 .73572 m .71147 .73562 L .70856 .73498 L F
.70951 .73572 m .71206 .73617 L .71147 .73562 L F
.132 0 0 r
.72161 .71475 m .72101 .71579 L .71875 .71612 L F
0 .053 .588 r
.71875 .71612 m .72055 .71774 L .72101 .71579 L F
.71875 .71612 m .71978 .719 L .72055 .71774 L F
.471 0 0 r
.65177 .59912 m .65297 .60028 L .65076 .60023 L F
.821 .592 .591 r
.51103 .77817 m .50806 .77525 L .51115 .77572 L F
.797 .573 .597 r
.51115 .77572 m .51277 .77849 L .51103 .77817 L F
.563 .41 .632 r
.55095 .80298 m .55135 .80502 L .55355 .80271 L F
.307 .395 .79 r
.70624 .73349 m .70763 .73193 L .70529 .73252 L F
.70624 .73349 m .70856 .73498 L .70763 .73193 L F
.033 0 .13 r
.48173 .87437 m .48344 .87352 L .48422 .87116 L F
.48173 .87437 m .48422 .87116 L .48261 .87357 L F
.444 .226 .487 r
.47977 .87326 m .48261 .87357 L .4821 .86939 L F
.58 .321 .488 r
.4821 .86939 m .48261 .87357 L .48422 .87116 L F
.497 .066 .152 r
.56108 .80169 m .56447 .80004 L .56134 .80014 L F
.56108 .80169 m .5634 .80156 L .56447 .80004 L F
.729 .331 .295 r
.5634 .80156 m .56681 .80225 L .56447 .80004 L F
.323 0 0 r
.65073 .60741 m .65221 .60817 L .64975 .60825 L F
.217 0 .256 r
.34795 .69004 m .34724 .69192 L .34954 .6893 L F
.57 .528 .768 r
.38928 .75162 m .39071 .75179 L .3909 .75093 L F
0 0 .24 r
.38989 .75288 m .38928 .75162 L .3909 .75093 L F
.38989 .75288 m .38914 .75396 L .38928 .75162 L F
.886 .954 .844 r
.61633 .62578 m .61291 .6283 L .61556 .62491 L F
.911 .93 .812 r
.61817 .62315 m .61633 .62578 L .61556 .62491 L F
.61817 .62315 m .61556 .62491 L .61731 .62246 L F
.885 .944 .846 r
.61731 .62246 m .62038 .62047 L .61817 .62315 L F
.73 .705 .827 r
.68948 .70855 m .69244 .70875 L .6908 .70497 L F
.786 .731 .801 r
.6908 .70497 m .69244 .70875 L .69554 .70504 L F
.702 .623 .766 r
.69244 .70875 m .69524 .70662 L .69554 .70504 L F
.805 .951 .611 r
.66089 .60661 m .65909 .60884 L .65979 .60565 L F
.023 0 0 r
.70044 .597 m .70092 .59684 L .69877 .59696 L F
.70009 .59682 m .69877 .59696 L .69782 .59562 L F
.70044 .597 m .70031 .597 L .70009 .59682 L F
.70031 .597 m .69877 .59696 L .70009 .59682 L F
.574 .168 .235 r
.69708 .59715 m .70044 .597 L .69782 .59562 L F
.689 .577 .725 r
.69992 .59513 m .69708 .59715 L .69782 .59562 L F
.11 0 0 r
.69782 .59562 m .69791 .59614 L .69992 .59513 L F
.604 .563 .781 r
.69992 .59513 m .69876 .59571 L .6959 .59141 L F
.69876 .59571 m .69791 .59614 L .69716 .59438 L F
.69876 .59571 m .69716 .59438 L .6959 .59141 L F
.785 .832 .888 r
.45277 .73846 m .45604 .73803 L .45479 .73754 L F
.587 .892 .989 r
.45684 .7368 m .45604 .73803 L .45827 .73757 L F
.45684 .7368 m .45479 .73754 L .45604 .73803 L F
.076 0 0 r
.3998 .79454 m .39861 .79443 L .40058 .79391 L F
.3998 .79454 m .39572 .79583 L .39861 .79443 L F
.495 .817 1 r
.33566 .81321 m .33853 .81324 L .33774 .81262 L F
.972 .873 .677 r
.33774 .81262 m .33853 .81324 L .33901 .81099 L F
.674 .647 .815 r
.34034 .81374 m .33843 .81606 L .33853 .81324 L F
.504 .104 .215 r
.34034 .81374 m .33853 .81324 L .33786 .81481 L F
0 0 0 r
.6804 .61737 m .68113 .61518 L .68178 .61371 L F
.816 .764 .804 r
.70259 .70343 m .69982 .70394 L .70148 .70234 L F
.494 .255 .481 r
.52518 .77979 m .52351 .77837 L .52564 .778 L F
.52518 .77979 m .52319 .78035 L .52351 .77837 L F
.449 .507 .827 r
.67562 .71876 m .67662 .71636 L .67445 .71614 L F
.67562 .71876 m .67772 .71938 L .67662 .71636 L F
.678 .133 0 r
.69436 .59369 m .69782 .59562 L .69633 .59593 L F
.598 .492 .703 r
.3411 .77567 m .33925 .77837 L .34142 .77802 L F
.605 .442 .635 r
.33925 .77837 m .34159 .78041 L .34142 .77802 L F
.33925 .77837 m .3393 .78077 L .34159 .78041 L F
.425 .338 .654 r
.34999 .6738 m .34977 .6768 L .35198 .67571 L F
.575 .441 .661 r
.34988 .67892 m .35198 .67571 L .34977 .6768 L F
.279 .553 .927 r
.34373 .65343 m .34318 .6545 L .34157 .65277 L F
.225 .485 .893 r
.34373 .65343 m .345 .65524 L .34318 .6545 L F
.411 .04 .22 r
.4381 .77073 m .43741 .77192 L .44016 .77044 L F
.628 .621 .825 r
.46279 .7434 m .46367 .73979 L .46155 .74021 L F
.46279 .7434 m .46492 .74307 L .46367 .73979 L F
.32 .361 .748 r
.72411 .61727 m .7236 .62031 L .72232 .61716 L F
.72411 .61727 m .72532 .61941 L .7236 .62031 L F
0 0 .436 r
.72492 .62128 m .7236 .62031 L .72532 .61941 L F
.72492 .62128 m .72373 .62265 L .7236 .62031 L F
.535 .402 .646 r
.71923 .61447 m .72142 .61403 L .71887 .61237 L F
.562 .385 .6 r
.34907 .75954 m .35124 .75928 L .35122 .75687 L F
.552 .393 .62 r
.34907 .75954 m .35113 .76171 L .35124 .75928 L F
.34907 .75954 m .34923 .76214 L .35113 .76171 L F
.555 .274 .443 r
.62444 .66631 m .62682 .66799 L .62416 .66813 L F
.62444 .66631 m .6274 .66551 L .62682 .66799 L F
.615 .822 .98 r
.34626 .82609 m .34978 .82638 L .34867 .82528 L F
.34626 .82609 m .34978 .82638 L .34867 .82528 L F
.451 .743 .991 r
.34867 .82528 m .34978 .82638 L .35171 .82618 L F
.35171 .82618 m .34978 .82638 L .34867 .82528 L F
.929 .616 .427 r
.71229 .69672 m .71379 .69638 L .71127 .69493 L F
.71229 .69672 m .714 .69776 L .71379 .69638 L F
.617 .595 .806 r
.48009 .73524 m .47792 .73576 L .47672 .73275 L F
.519 .692 .947 r
.35911 .65961 m .35835 .66129 L .35705 .66007 L F
.35911 .65961 m .36 .66071 L .35835 .66129 L F
.487 .592 .884 r
.36078 .66186 m .35835 .66129 L .36 .66071 L F
.555 .372 .588 r
.35306 .754 m .3552 .75134 L .35299 .75163 L F
.02 0 0 r
.4312 .78259 m .43463 .78038 L .43326 .78224 L F
.393 0 .122 r
.43463 .78038 m .43535 .78209 L .43326 .78224 L F
.43463 .78038 m .43681 .78015 L .43535 .78209 L F
.576 .402 .609 r
.50918 .7649 m .5093 .76716 L .50707 .76748 L F
.536 .507 .771 r
.43742 .74339 m .43798 .73978 L .43961 .74105 L F
.435 .164 .402 r
.43961 .74105 m .43937 .74301 L .43742 .74339 L F
.506 .223 .419 r
.4417 .74262 m .43937 .74301 L .43961 .74105 L F
.06 .254 .747 r
.70019 .7269 m .70209 .72946 L .70085 .72649 L F
.355 .821 .911 r
.70085 .72649 m .69859 .72689 L .70019 .7269 L F
.139 0 0 r
.30341 .65745 m .30539 .65699 L .30692 .65585 L F
.203 0 0 r
.30539 .65699 m .30902 .65546 L .30692 .65585 L F
.848 .712 .712 r
.62138 .64335 m .61964 .64646 L .62276 .64678 L F
.848 .717 .718 r
.61964 .64646 m .62073 .64944 L .62276 .64678 L F
.523 .481 .751 r
.69524 .70662 m .6954 .70875 L .69784 .70844 L F
.214 .203 .63 r
.6954 .70875 m .69677 .71009 L .69784 .70844 L F
.6954 .70875 m .69584 .71172 L .69677 .71009 L F
.737 .991 .829 r
.36888 .80452 m .37238 .80233 L .37154 .80421 L F
.455 .844 .981 r
.37308 .80148 m .37238 .80233 L .37446 .80187 L F
0 0 0 r
.37154 .80421 m .37238 .80233 L .37308 .80148 L F
.499 .383 .653 r
.71436 .73026 m .71754 .73284 L .71597 .73107 L F
.498 .874 .977 r
.36457 .81016 m .36593 .81041 L .36267 .81076 L F
.36267 .81076 m .36593 .81041 L .36457 .81016 L F
.23 .709 .935 r
.36657 .80997 m .36593 .81041 L .36457 .81016 L F
.36657 .80997 m .3685 .81057 L .36593 .81041 L F
0 .185 .716 r
.36593 .81041 m .36657 .80997 L .36457 .81016 L F
.637 .386 .522 r
.36593 .81041 m .3685 .81057 L .3679 .81264 L F
0 .185 .716 r
.36593 .81041 m .3679 .81264 L .36657 .80997 L F
.684 .443 .552 r
.61953 .66805 m .6165 .67047 L .6166 .66871 L F
.345 0 0 r
.72108 .7378 m .72324 .73798 L .72302 .73746 L F
.337 .635 .962 r
.722 .73661 m .72324 .73798 L .72108 .7378 L F
.854 .409 .004 r
.722 .73661 m .72339 .73833 L .72324 .73798 L F
.72339 .73833 m .72382 .73886 L .72324 .73798 L F
.345 0 0 r
.72302 .73746 m .72324 .73798 L .724 .73729 L F
.852 .568 .032 r
.66953 .61112 m .67018 .61488 L .67054 .61493 L F
.273 .518 .905 r
.67018 .61488 m .67179 .61709 L .67054 .61493 L F
.476 .859 .98 r
.56683 .81064 m .56573 .81025 L .56392 .81078 L F
.65 .927 .973 r
.56776 .80928 m .56573 .81025 L .56683 .81064 L F
.56776 .80928 m .56573 .81025 L .56683 .81064 L F
.844 .741 .75 r
.71377 .71957 m .71284 .72169 L .7151 .72208 L F
.522 .573 .848 r
.7151 .72208 m .71602 .71934 L .71377 .71957 L F
.7151 .72208 m .71725 .72183 L .71602 .71934 L F
.631 .433 .596 r
.7151 .72208 m .71744 .72355 L .71725 .72183 L F
.7151 .72208 m .71497 .72425 L .71744 .72355 L F
.512 .209 .39 r
.52113 .78089 m .52036 .78341 L .51826 .78364 L F
.502 .2 .386 r
.52259 .78153 m .52113 .78089 L .52319 .78035 L F
.52259 .78153 m .52036 .78341 L .52113 .78089 L F
0 0 .182 r
.71638 .62344 m .71726 .62228 L .71732 .62 L F
0 0 0 r
.71732 .62 m .71942 .61908 L .72014 .6179 L F
.523 .345 .581 r
.71726 .62228 m .71942 .61908 L .71732 .62 L F
.227 0 .059 r
.30105 .65881 m .30341 .65745 L .30173 .6578 L F
0 .378 .774 r
.33958 .81897 m .33669 .8159 L .33843 .81606 L F
.33958 .81897 m .33804 .81803 L .33669 .8159 L F
.499 .333 .586 r
.33669 .8159 m .33828 .81807 L .33786 .81481 L F
.33669 .8159 m .33804 .81803 L .33828 .81807 L F
.555 .425 .659 r
.37139 .77561 m .36978 .77841 L .36955 .77599 L F
.935 .805 .693 r
.66254 .61472 m .66189 .61711 L .66343 .61675 L F
.682 .713 .872 r
.66254 .61472 m .66343 .61675 L .66588 .61555 L F
.14 .315 .779 r
.6538 .5872 m .65157 .58526 L .6538 .58487 L F
.767 .544 .596 r
.65078 .58737 m .6538 .58487 L .65157 .58526 L F
.462 .223 .465 r
.33245 .78636 m .33451 .78599 L .33482 .78374 L F
.634 .374 .507 r
.33482 .78374 m .33451 .78599 L .33683 .78578 L F
.546 .375 .6 r
.33482 .78374 m .33683 .78578 L .33687 .7834 L F
0 0 0 r
.40429 .78124 m .40402 .78121 L .40213 .78179 L F
.40429 .78124 m .40617 .78095 L .40402 .78121 L F
.579 .317 .483 r
.37767 .7663 m .37556 .76517 L .37733 .7645 L F
.37767 .7663 m .37503 .76721 L .37556 .76517 L F
.533 .708 .952 r
.6378 .61313 m .64011 .61324 L .64075 .61467 L F
0 0 .06 r
.64075 .61467 m .64067 .61627 L .63969 .61779 L F
.096 0 .435 r
.64201 .60953 m .64075 .61467 L .64011 .61324 L F
.64201 .60953 m .64214 .61415 L .64075 .61467 L F
.244 0 .324 r
.64214 .61415 m .64067 .61627 L .64075 .61467 L F
.718 .481 .567 r
.48996 .88213 m .48727 .88272 L .48757 .87972 L F
.966 .646 .273 r
.59912 .66635 m .59903 .66793 L .60128 .66516 L F
.631 .46 .632 r
.34105 .77316 m .34335 .77527 L .34321 .77287 L F
.34105 .77316 m .3411 .77567 L .34335 .77527 L F
.676 .131 0 r
.34999 .6738 m .3503 .67489 L .34874 .67543 L F
.34999 .6738 m .35198 .67571 L .3503 .67489 L F
.879 .805 .773 r
.73245 .71617 m .73213 .71957 L .73393 .717 L F
.427 .221 .495 r
.33039 .78909 m .3322 .78873 L .33245 .78636 L F
.479 .405 .695 r
.3305 .7897 m .3322 .78873 L .33039 .78909 L F
.791 .727 .793 r
.71217 .59577 m .70949 .60009 L .70893 .59539 L F
.716 .643 .774 r
.68766 .70955 m .68691 .71048 L .68948 .70855 L F
.495 .817 1 r
.33566 .81321 m .33774 .81262 L .33512 .81251 L F
.534 .596 .862 r
.7127 .72492 m .71557 .72717 L .71497 .72425 L F
.682 .616 .776 r
.71497 .72425 m .71557 .72717 L .71873 .72567 L F
.784 .528 .551 r
.6908 .70497 m .69383 .70324 L .6941 .70254 L F
.6908 .70497 m .69554 .70504 L .69383 .70324 L F
.609 .552 .765 r
.43383 .73866 m .4342 .74051 L .43656 .73948 L F
.769 .529 .571 r
.4342 .74051 m .43399 .74322 L .43742 .74339 L F
.717 .497 .59 r
.50806 .77525 m .50485 .77235 L .50814 .77309 L F
.381 0 .152 r
.42681 .77531 m .4289 .77496 L .43015 .77296 L F
.489 .094 .218 r
.4289 .77496 m .43231 .77288 L .43015 .77296 L F
.885 .944 .846 r
.61731 .62246 m .6195 .61984 L .62038 .62047 L F
.876 .945 .855 r
.62038 .62047 m .62182 .61725 L .62254 .61781 L F
.62038 .62047 m .6195 .61984 L .62182 .61725 L F
.664 .971 .811 r
.71461 .62419 m .71638 .62344 L .71524 .62432 L F
.71461 .62419 m .71726 .62228 L .71638 .62344 L F
.917 .683 .187 r
.66246 .61221 m .66207 .61318 L .65973 .61153 L F
.66246 .61221 m .66254 .61472 L .66207 .61318 L F
.773 .686 .767 r
.33901 .81099 m .33941 .80751 L .33769 .81051 L F
.972 .873 .677 r
.33774 .81262 m .33901 .81099 L .33769 .81051 L F
.649 .683 .869 r
.71116 .60356 m .71432 .60429 L .71348 .60274 L F
.588 .638 .868 r
.71432 .60429 m .71582 .60229 L .71348 .60274 L F
.71432 .60429 m .71663 .60389 L .71582 .60229 L F
.464 .569 .876 r
.67797 .59096 m .68131 .59359 L .68058 .59028 L F
.64 .678 .87 r
.68131 .59359 m .68205 .59049 L .68058 .59028 L F
.68131 .59359 m .68363 .59292 L .68205 .59049 L F
0 0 .017 r
.63163 .59864 m .63325 .59742 L .63369 .59544 L F
.071 0 .15 r
.63369 .59544 m .63546 .59499 L .63605 .59276 L F
.052 0 .082 r
.63325 .59742 m .63546 .59499 L .63369 .59544 L F
.64 .598 .791 r
.48459 .74099 m .48103 .73838 L .48306 .73784 L F
.633 .648 .847 r
.48681 .74045 m .48459 .74099 L .48306 .73784 L F
.63 .078 0 r
.69859 .72689 m .69521 .72432 L .69712 .72451 L F
.411 0 .093 r
.33991 .69698 m .34194 .69687 L .34332 .69523 L F
0 0 0 r
.34332 .69523 m .34194 .69687 L .34419 .69434 L F
.479 .405 .695 r
.3305 .7897 m .33258 .79129 L .3322 .78873 L F
.514 .402 .664 r
.33072 .79166 m .33258 .79129 L .3305 .7897 L F
.684 .579 .732 r
.34148 .81607 m .33958 .81897 L .33843 .81606 L F
.324 .569 .927 r
.33958 .81897 m .3421 .82054 L .34026 .81778 L F
.648 .745 .92 r
.34026 .81778 m .3421 .82054 L .34386 .81859 L F
.435 .536 .861 r
.36597 .66436 m .36482 .66589 L .36337 .66342 L F
.556 .523 .773 r
.36597 .66436 m .36499 .66824 L .36482 .66589 L F
.632 .29 .374 r
.4529 .7667 m .45634 .76471 L .45333 .76536 L F
.4529 .7667 m .4552 .76702 L .45634 .76471 L F
.592 .247 .354 r
.45634 .76471 m .45825 .76616 L .45862 .76496 L F
.45634 .76471 m .4552 .76702 L .45825 .76616 L F
.762 .922 .556 r
.59777 .67026 m .59903 .66793 L .59637 .66847 L F
.59777 .67026 m .59782 .66926 L .59903 .66793 L F
.764 .918 .545 r
.59777 .67026 m .59606 .67211 L .59782 .66926 L F
.618 .547 .752 r
.50232 .75986 m .5001 .76034 L .49904 .75694 L F
.561 .721 .948 r
.46886 .72744 m .46808 .72929 L .46672 .72775 L F
.46886 .72744 m .47031 .72896 L .46808 .72929 L F
.592 .909 .98 r
.30742 .68283 m .30694 .68189 L .30868 .68118 L F
.30742 .68283 m .30586 .68368 L .30694 .68189 L F
.717 .639 .77 r
.46815 .74358 m .47158 .74598 L .47027 .74309 L F
.46815 .74358 m .46934 .74635 L .47158 .74598 L F
.704 .55 .676 r
.46934 .74635 m .46934 .74877 L .47158 .74598 L F
.627 .617 .82 r
.47158 .74598 m .47231 .74256 L .47027 .74309 L F
.47158 .74598 m .47382 .74555 L .47231 .74256 L F
.953 .779 .63 r
.67533 .63303 m .67435 .63575 L .67627 .63562 L F
.971 .919 .687 r
.6741 .63827 m .67627 .63562 L .67435 .63575 L F
.6741 .63827 m .6749 .63894 L .67627 .63562 L F
.958 .691 .488 r
.67454 .63148 m .67533 .63303 L .6752 .63079 L F
0 0 .169 r
.67465 .63166 m .67533 .63303 L .67454 .63148 L F
.737 .699 .815 r
.67533 .63303 m .6765 .63542 L .67908 .63316 L F
0 0 .169 r
.67614 .63406 m .67533 .63303 L .67465 .63166 L F
.737 .699 .815 r
.67533 .63303 m .67627 .63562 L .6765 .63542 L F
.117 0 0 r
.70329 .64213 m .70233 .64317 L .70035 .64382 L F
0 0 0 r
.70507 .64114 m .70233 .64317 L .70329 .64213 L F
0 .378 .774 r
.33804 .81803 m .33958 .81897 L .33828 .81807 L F
.324 .569 .927 r
.33958 .81897 m .34026 .81778 L .33828 .81807 L F
.573 .686 .917 r
.36251 .6619 m .36166 .66386 L .36078 .66186 L F
.36251 .6619 m .36337 .66342 L .36166 .66386 L F
.668 .643 .816 r
.50918 .7649 m .50576 .76233 L .50776 .76156 L F
.696 .611 .758 r
.51116 .76213 m .50918 .7649 L .50776 .76156 L F
.605 .486 .691 r
.5117 .76437 m .50918 .7649 L .51116 .76213 L F
.715 .6 .726 r
.5117 .76437 m .5093 .76716 L .50918 .7649 L F
.551 .412 .646 r
.35122 .75687 m .35326 .75653 L .35306 .754 L F
.539 .367 .597 r
.35122 .75687 m .35327 .7588 L .35326 .75653 L F
.35122 .75687 m .35124 .75928 L .35327 .7588 L F
.814 .985 .713 r
.66699 .62006 m .66492 .622 L .66678 .61951 L F
.865 .97 .65 r
.66699 .62006 m .66678 .61951 L .66855 .61658 L F
.92 .96 .791 r
.62254 .61781 m .62381 .61428 L .62456 .61493 L F
.879 .961 .849 r
.62456 .61493 m .62602 .61173 L .62687 .61239 L F
.62456 .61493 m .62381 .61428 L .62602 .61173 L F
.498 .214 .414 r
.36447 .69242 m .36186 .69448 L .36248 .69296 L F
0 0 0 r
.63133 .60096 m .6315 .60044 L .63163 .59864 L F
0 0 .088 r
.63163 .59864 m .6315 .60044 L .63325 .59742 L F
.827 .668 .686 r
.68496 .71385 m .68365 .71086 L .68192 .71374 L F
.798 .696 .752 r
.68192 .71374 m .68301 .7167 L .68496 .71385 L F
.601 .795 .973 r
.67459 .59046 m .67797 .59096 L .67697 .59025 L F
.658 .629 .81 r
.68 .71383 m .67753 .71186 L .67846 .71553 L F
.531 .477 .741 r
.68 .71383 m .68064 .7105 L .67891 .71129 L F
.68 .71383 m .68192 .71374 L .68064 .7105 L F
.787 .652 .714 r
.67846 .71553 m .68192 .71374 L .68 .71383 L F
.769 .463 .469 r
.64201 .60953 m .6399 .6091 L .64196 .6091 L F
.096 0 .435 r
.64201 .60953 m .64011 .61324 L .64169 .61152 L F
.769 .463 .469 r
.64201 .60953 m .64169 .61152 L .6399 .6091 L F
.636 .528 .714 r
.64196 .6091 m .64416 .61202 L .64201 .60953 L F
.78 .535 .566 r
.64416 .61202 m .64214 .61415 L .64201 .60953 L F
.598 .757 .954 r
.65884 .63105 m .65481 .63018 L .65773 .63017 L F
.649 .789 .334 r
.65912 .63029 m .65925 .62888 L .66129 .62874 L F
.399 .735 .992 r
.65773 .63017 m .65912 .63027 L .65884 .63105 L F
.649 .789 .334 r
.65827 .63091 m .65912 .63027 L .65912 .63029 L F
.399 .735 .992 r
.65912 .63029 m .66075 .63039 L .6593 .63089 L F
.6 .575 .797 r
.66129 .62874 m .66075 .63039 L .65912 .63029 L F
.399 .735 .992 r
.65912 .63027 m .66075 .63039 L .65912 .63029 L F
.6 .575 .797 r
.65912 .63029 m .66075 .63039 L .65827 .63091 L F
.603 .598 .819 r
.65827 .63091 m .66075 .63039 L .65912 .63027 L F
.65827 .63091 m .65912 .63027 L .65773 .63017 L F
.649 .789 .334 r
.65827 .63091 m .65891 .62958 L .65912 .63027 L F
.65891 .62958 m .65925 .62888 L .65912 .63029 L F
.399 .735 .992 r
.65912 .63027 m .6593 .63089 L .65884 .63105 L F
.7 .859 .958 r
.56045 .81079 m .56164 .81188 L .56392 .81078 L F
.606 .54 .754 r
.71923 .61447 m .72014 .6179 L .72232 .61716 L F
.405 .177 .452 r
.34594 .71145 m .34613 .71367 L .34417 .71336 L F
.311 .056 .356 r
.34538 .71528 m .34417 .71336 L .34613 .71367 L F
.34538 .71528 m .34373 .71601 L .34417 .71336 L F
.594 .534 .758 r
.67879 .72267 m .67971 .71859 L .67772 .71938 L F
.67879 .72267 m .681 .72187 L .67971 .71859 L F
.159 .652 .918 r
.70815 .69421 m .71127 .69493 L .70908 .69469 L F
.37 0 0 r
.42724 .72386 m .42927 .72422 L .43068 .72387 L F
.93 .887 .768 r
.60727 .63888 m .60792 .63513 L .60911 .63608 L F
.442 .175 .411 r
.37992 .75983 m .37933 .76178 L .3774 .7622 L F
.552 .287 .467 r
.38233 .75931 m .37933 .76178 L .37992 .75983 L F
.112 .617 .899 r
.51449 .82544 m .51305 .82543 L .5132 .82348 L F
.623 .627 .833 r
.47795 .74959 m .48136 .75171 L .48004 .74915 L F
.614 .645 .857 r
.48004 .74915 m .48136 .75171 L .48355 .75136 L F
.644 .553 .737 r
.48179 .75393 m .48355 .75136 L .48136 .75171 L F
.863 .939 .869 r
.69544 .63781 m .69426 .63932 L .69338 .63856 L F
.331 .807 .744 r
.63131 .65101 m .63419 .64991 L .63488 .64977 L F
.633 .915 .98 r
.63419 .64991 m .63721 .64964 L .63488 .64977 L F
.204 0 0 r
.31714 .71608 m .31826 .71631 L .31887 .71561 L F
.31714 .71608 m .31641 .71675 L .31826 .71631 L F
.849 .99 .849 r
.64288 .59819 m .63945 .60056 L .64119 .60122 L F
.64288 .59819 m .64195 .59782 L .63945 .60056 L F
.92 .96 .791 r
.62254 .61781 m .62182 .61725 L .62381 .61428 L F
0 .348 .797 r
.70312 .73136 m .7039 .73015 L .70209 .72946 L F
.70312 .73136 m .70429 .73155 L .7039 .73015 L F
.70312 .73136 m .70529 .73252 L .70429 .73155 L F
0 0 0 r
.6298 .63575 m .63196 .63325 L .63115 .63346 L F
.67 .564 .726 r
.39982 .75679 m .39924 .75957 L .40077 .75902 L F
.742 .311 0 r
.72906 .71116 m .73033 .71342 L .73075 .71382 L F
.822 .342 0 r
.73125 .71557 m .73075 .71382 L .73033 .71342 L F
.73125 .71557 m .73245 .71617 L .73075 .71382 L F
.656 .38 .49 r
.60918 .67287 m .60533 .67129 L .60903 .67084 L F
.60918 .67287 m .60544 .67334 L .60533 .67129 L F
.037 .114 .616 r
.64639 .60363 m .6463 .60175 L .64623 .60138 L F
.685 .498 .628 r
.64415 .60389 m .64639 .60363 L .64623 .60138 L F
0 .428 .818 r
.33744 .82358 m .33762 .82365 L .3379 .82389 L F
.757 .941 .943 r
.3379 .82389 m .33762 .82365 L .33743 .82378 L F
.574 .392 .597 r
.35939 .7435 m .35724 .74619 L .35939 .74586 L F
.405 .2 .485 r
.35939 .7435 m .36127 .74299 L .36149 .74065 L F
.471 .325 .6 r
.35939 .74586 m .36127 .74299 L .35939 .7435 L F
.577 .406 .612 r
.35724 .74619 m .35726 .74858 L .35939 .74586 L F
.61 .441 .628 r
.3322 .78873 m .33451 .78599 L .33245 .78636 L F
.499 .383 .653 r
.71436 .73026 m .71627 .73207 L .71754 .73284 L F
.97 .71 .484 r
.71627 .73207 m .71815 .73573 L .71754 .73284 L F
.748 .584 .672 r
.71754 .73284 m .71815 .73573 L .71858 .7355 L F
.724 .374 .386 r
.72509 .7438 m .72204 .74499 L .72187 .7435 L F
.72509 .7438 m .72542 .74517 L .72204 .74499 L F
.405 .655 .96 r
.68899 .59069 m .6854 .58905 L .68844 .59034 L F
.459 .537 .85 r
.69084 .58932 m .68899 .59069 L .68844 .59034 L F
.69084 .58932 m .69075 .59055 L .68899 .59069 L F
.515 .504 .782 r
.48306 .73784 m .48103 .73838 L .48009 .73524 L F
.859 .754 .745 r
.69573 .71996 m .69487 .72212 L .69414 .7189 L F
.615 .574 .784 r
.47382 .74555 m .47495 .74863 L .47719 .74821 L F
.62 .624 .833 r
.47495 .74863 m .47795 .74959 L .47719 .74821 L F
.74 .658 .768 r
.70145 .71562 m .70294 .71698 L .69953 .71659 L F
.752 .657 .756 r
.70533 .71446 m .70294 .71698 L .70145 .71562 L F
.369 0 .1 r
.42862 .7408 m .42739 .74255 L .42521 .74291 L F
0 0 0 r
.42898 .74143 m .42862 .7408 L .42917 .73933 L F
.42898 .74143 m .42739 .74255 L .42862 .7408 L F
.464 .333 .617 r
.37746 .67563 m .37748 .67858 L .37524 .67823 L F
.498 .285 .521 r
.37748 .67858 m .37538 .68115 L .37524 .67823 L F
0 0 0 r
.31857 .73544 m .31984 .73516 L .3173 .73665 L F
.652 .705 .886 r
.7103 .60106 m .71116 .60356 L .71348 .60274 L F
.204 .344 .784 r
.34872 .68189 m .35088 .68378 L .34923 .68075 L F
.435 .382 .699 r
.34872 .68189 m .34938 .68439 L .35088 .68378 L F
.811 .725 .77 r
.60562 .65517 m .60463 .65761 L .60186 .657 L F
.834 .651 .655 r
.60463 .65761 m .60345 .66017 L .60186 .657 L F
.59 .913 .977 r
.3765 .80178 m .37772 .80207 L .37953 .80128 L F
0 0 0 r
.40615 .79161 m .40486 .79249 L .40251 .79338 L F
.298 0 0 r
.40813 .79094 m .40486 .79249 L .40615 .79161 L F
.676 .876 .974 r
.69913 .602 m .70024 .60265 L .70237 .60172 L F
.516 .292 .513 r
.36149 .74065 m .36355 .74033 L .36381 .73812 L F
.652 .502 .667 r
.36594 .73561 m .36381 .73812 L .3666 .73565 L F
.565 .352 .55 r
.36355 .74033 m .3666 .73565 L .36381 .73812 L F
.568 .545 .789 r
.48885 .74019 m .48787 .74381 L .48681 .74045 L F
.48885 .74019 m .48998 .74354 L .48787 .74381 L F
.554 .434 .67 r
.54994 .811 m .5522 .81071 L .55141 .80718 L F
.618 .724 .922 r
.7175 .70875 m .71484 .70979 L .71375 .7079 L F
.665 .828 .962 r
.71958 .60406 m .71877 .60312 L .71663 .60389 L F
.741 .686 .797 r
.49123 .8803 m .49313 .88283 L .48996 .88213 L F
.251 0 0 r
.49313 .88283 m .4923 .88274 L .48996 .88213 L F
.925 .537 .188 r
.49123 .8803 m .4923 .88274 L .49313 .88283 L F
.267 0 0 r
.63934 .65751 m .63831 .65902 L .63611 .65954 L F
.355 0 .07 r
.64153 .65701 m .63831 .65902 L .63934 .65751 L F
.446 .179 .414 r
.35958 .69728 m .35766 .69777 L .36022 .69542 L F
.467 .256 .51 r
.36186 .69448 m .35958 .69728 L .36022 .69542 L F
.165 0 0 r
.31472 .65293 m .31193 .65413 L .31395 .65374 L F
.339 .002 .238 r
.31395 .65374 m .31631 .65203 L .31472 .65293 L F
.928 .558 .29 r
.68351 .63862 m .68293 .64001 L .68226 .63819 L F
.68351 .63862 m .68472 .64166 L .68293 .64001 L F
.089 0 0 r
.66127 .64424 m .66399 .64333 L .66323 .64307 L F
.384 .811 .967 r
.66399 .64333 m .66533 .64267 L .66323 .64307 L F
.66399 .64333 m .66599 .64294 L .66533 .64267 L F
.644 .553 .737 r
.48179 .75393 m .48448 .75412 L .48355 .75136 L F
.529 .375 .617 r
.48242 .75723 m .48448 .75412 L .48179 .75393 L F
.604 .522 .736 r
.48242 .75723 m .48274 .75925 L .48498 .7587 L F
.734 .603 .711 r
.48257 .76182 m .48498 .7587 L .48274 .75925 L F
.609 .453 .645 r
.3431 .77058 m .34541 .77254 L .34524 .77021 L F
.3431 .77058 m .34321 .77287 L .34541 .77254 L F
.232 .704 .941 r
.40052 .75064 m .39924 .75017 L .39642 .74998 L F
.289 .733 .963 r
.40052 .75064 m .401 .75008 L .39924 .75017 L F
.40052 .75064 m .40179 .75057 L .401 .75008 L F
.768 .62 .696 r
.60415 .64969 m .60249 .65232 L .60081 .64932 L F
.973 .801 .61 r
.69487 .72212 m .69371 .72233 L .69414 .7189 L F
.921 .624 .144 r
.69487 .72212 m .69459 .72329 L .69371 .72233 L F
.69487 .72212 m .69521 .72432 L .69459 .72329 L F
.75 .639 .738 r
.33941 .80751 m .34273 .80779 L .34192 .80494 L F
.411 .536 .872 r
.33941 .80751 m .34271 .8102 L .34273 .80779 L F
.773 .678 .758 r
.34271 .8102 m .34486 .80747 L .34273 .80779 L F
.621 .467 .652 r
.37298 .76979 m .37082 .77028 L .37294 .76757 L F
.625 .501 .691 r
.37298 .76979 m .37083 .77256 L .37082 .77028 L F
.752 .657 .756 r
.70533 .71446 m .70145 .71562 L .70345 .7131 L F
.7 .602 .744 r
.68615 .70604 m .68766 .70955 L .68948 .70855 L F
0 0 0 r
.32707 .65083 m .32925 .6506 L .33058 .65032 L F
.514 .01 0 r
.32925 .6506 m .33149 .65082 L .33058 .65032 L F
.519 .388 .642 r
.36156 .83203 m .35966 .83516 L .36219 .8348 L F
0 0 0 r
.69677 .71009 m .69584 .71172 L .69513 .71307 L F
.725 .326 .293 r
.69584 .71172 m .69816 .7132 L .69513 .71307 L F
.755 .44 .452 r
.37395 .67129 m .3771 .67346 L .37634 .67041 L F
.37395 .67129 m .37363 .67315 L .3771 .67346 L F
.834 .712 .73 r
.68192 .71374 m .68055 .71675 L .68301 .7167 L F
.797 .654 .705 r
.67971 .71859 m .68301 .7167 L .68055 .71675 L F
.67971 .71859 m .68228 .71925 L .68301 .7167 L F
.88 .68 .628 r
.51277 .77849 m .51099 .78042 L .51103 .77817 L F
.51277 .77849 m .51272 .78091 L .51099 .78042 L F
.555 .425 .659 r
.37139 .77561 m .37183 .77806 L .36978 .77841 L F
.674 .647 .815 r
.34034 .81374 m .34148 .81607 L .33843 .81606 L F
.285 0 0 r
.30902 .65546 m .311 .65507 L .31193 .65413 L F
.245 0 0 r
.311 .65507 m .31395 .65374 L .31193 .65413 L F
.34 .785 .958 r
.44722 .73912 m .45017 .73938 L .44929 .73753 L F
.654 .712 .89 r
.44929 .73753 m .45017 .73938 L .45277 .73846 L F
.475 .235 .47 r
.3666 .73565 m .36805 .737 L .36805 .7359 L F
.3666 .73565 m .36805 .7359 L .36594 .73561 L F
.766 .718 .808 r
.70939 .72482 m .7127 .72492 L .71215 .72466 L F
.607 .947 .928 r
.71403 .72366 m .71215 .72466 L .7127 .72492 L F
.625 .501 .691 r
.37298 .76979 m .37358 .77259 L .37083 .77256 L F
.496 .322 .575 r
.37358 .77259 m .37139 .77561 L .37083 .77256 L F
.368 0 .019 r
.39649 .72696 m .39863 .72671 L .39999 .7253 L F
.391 0 .035 r
.39999 .7253 m .39863 .72671 L .40166 .72581 L F
.831 .626 .625 r
.63293 .60407 m .63029 .6037 L .63133 .60096 L F
.858 .804 .797 r
.63293 .60407 m .62958 .60583 L .63029 .6037 L F
.63293 .60407 m .63103 .60678 L .62958 .60583 L F
.585 .336 .506 r
.63589 .60324 m .63543 .60582 L .63293 .60407 L F
.63293 .60407 m .63543 .60582 L .63589 .60324 L F
.63589 .60324 m .63543 .60582 L .63293 .60407 L F
.445 .08 .249 r
.3888 .72955 m .39091 .72927 L .39218 .72704 L F
.419 .009 .152 r
.39091 .72927 m .39433 .72719 L .39218 .72704 L F
.414 .53 .866 r
.69362 .59185 m .6923 .59336 L .69075 .59055 L F
.427 .549 .877 r
.69436 .59369 m .6923 .59336 L .69362 .59185 L F
0 0 0 r
.64284 .64709 m .64436 .64569 L .64507 .64478 L F
.66 .462 .605 r
.68824 .62517 m .69031 .62285 L .68729 .62259 L F
.68824 .62517 m .6906 .62515 L .69031 .62285 L F
.624 .436 .607 r
.69031 .62285 m .6906 .62515 L .69282 .62337 L F
.467 .279 .542 r
.37933 .76178 m .37733 .7645 L .3774 .7622 L F
.937 .856 .736 r
.66842 .60539 m .67189 .6022 L .66774 .60298 L F
.66842 .60539 m .66907 .60657 L .67189 .6022 L F
.466 .435 .74 r
.52896 .76996 m .52753 .77306 L .52655 .77159 L F
.52896 .76996 m .5295 .77279 L .52753 .77306 L F
.459 .386 .688 r
.5295 .77279 m .52986 .77481 L .52753 .77306 L F
.492 .383 .658 r
.52986 .77481 m .528 .77547 L .52753 .77306 L F
.573 .684 .916 r
.72161 .71475 m .72447 .71609 L .72305 .7143 L F
.557 .791 .986 r
.72447 .71609 m .72616 .71473 L .72305 .7143 L F
.72447 .71609 m .72688 .71568 L .72616 .71473 L F
.247 0 .17 r
.33535 .72231 m .33439 .72394 L .33267 .72448 L F
.284 0 .26 r
.3369 .72137 m .33439 .72394 L .33535 .72231 L F
0 0 .228 r
.40572 .74782 m .40518 .74612 L .40616 .74541 L F
0 .056 .614 r
.6366 .61119 m .6378 .61313 L .6365 .61149 L F
.761 .542 .6 r
.50485 .77235 m .50295 .77491 L .50274 .7727 L F
.746 .521 .589 r
.50485 .77235 m .50485 .77532 L .50295 .77491 L F
.717 .497 .59 r
.50806 .77525 m .50485 .77532 L .50485 .77235 L F
.485 .87 .672 r
.63949 .64926 m .64123 .64799 L .64284 .64709 L F
.436 .842 .653 r
.64284 .64709 m .64441 .64598 L .64436 .64569 L F
.64284 .64709 m .64123 .64799 L .64441 .64598 L F
.53 .164 .29 r
.44222 .77814 m .44105 .78038 L .43886 .78035 L F
.354 0 .197 r
.44314 .77989 m .44222 .77814 L .44438 .77785 L F
.44314 .77989 m .44105 .78038 L .44222 .77814 L F
.636 .298 .381 r
.38081 .73169 m .38324 .73192 L .38441 .72971 L F
.409 .01 .168 r
.38324 .73192 m .38661 .72971 L .38441 .72971 L F
.851 .807 .806 r
.62958 .60583 m .63103 .60678 L .62893 .60957 L F
.864 .577 .5 r
.5321 .83152 m .53256 .83444 L .53492 .83444 L F
.916 .884 .786 r
.53193 .83652 m .53492 .83444 L .53256 .83444 L F
.53193 .83652 m .53311 .83711 L .53492 .83444 L F
.464 .249 .502 r
.35728 .69977 m .35496 .70221 L .35535 .7004 L F
.911 .91 .806 r
.62602 .61173 m .62893 .60957 L .62687 .61239 L F
.62602 .61173 m .628 .60878 L .62893 .60957 L F
.851 .807 .806 r
.62958 .60583 m .62893 .60957 L .628 .60878 L F
.523 .127 .232 r
.4716 .76421 m .47388 .76428 L .47505 .7623 L F
.563 .17 .254 r
.47505 .7623 m .47704 .76365 L .47714 .76187 L F
.47505 .7623 m .47388 .76428 L .47704 .76365 L F
.808 .358 .169 r
.6298 .63575 m .63041 .63793 L .63005 .63579 L F
.692 .552 .69 r
.69524 .70662 m .69793 .70578 L .69554 .70504 L F
.154 0 0 r
.44757 .7775 m .44655 .77782 L .44438 .77785 L F
.214 .725 .676 r
.44859 .77717 m .44757 .7775 L .45008 .77627 L F
.44859 .77717 m .44655 .77782 L .44757 .7775 L F
.864 .793 .78 r
.60727 .63888 m .60394 .64071 L .60622 .6381 L F
.60727 .63888 m .6053 .64174 L .60394 .64071 L F
.93 .887 .768 r
.60727 .63888 m .60622 .6381 L .60792 .63513 L F
.297 .053 .365 r
.64946 .65241 m .65109 .65157 L .64901 .65419 L F
.642 .593 .784 r
.50449 .75933 m .50265 .7619 L .50232 .75986 L F
.50449 .75933 m .50576 .76233 L .50265 .7619 L F
.296 0 .108 r
.32714 .71117 m .32781 .71258 L .32936 .71107 L F
.32714 .71117 m .32588 .71308 L .32781 .71258 L F
.927 .905 .782 r
.62423 .63488 m .62626 .63399 L .6253 .63331 L F
.62423 .63488 m .62519 .63574 L .62626 .63399 L F
.406 .484 .828 r
.66624 .5943 m .66494 .59595 L .66369 .59293 L F
.196 .083 .49 r
.48077 .87458 m .48261 .87357 L .47977 .87326 L F
.48077 .87458 m .48173 .87437 L .48261 .87357 L F
.074 0 0 r
.63671 .62168 m .63298 .6236 L .6342 .62242 L F
0 .31 .688 r
.35816 .81181 m .36022 .81284 L .35907 .81011 L F
.98 .729 .482 r
.35904 .81282 m .36022 .81284 L .35907 .81011 L F
.743 .678 .788 r
.36022 .81284 m .36267 .81076 L .35907 .81011 L F
.082 .274 .76 r
.36129 .81229 m .36022 .81284 L .35907 .81011 L F
.324 .809 .865 r
.35904 .81282 m .36022 .81284 L .36129 .81229 L F
.572 .367 .564 r
.36127 .74299 m .36355 .74033 L .36149 .74065 L F
.954 .689 .494 r
.70036 .61744 m .70078 .62014 L .69988 .61999 L F
.5 .379 .646 r
.70279 .61929 m .70078 .62014 L .70036 .61744 L F
.625 .342 .468 r
.70036 .61744 m .69988 .61999 L .70279 .61929 L F
.427 .211 .481 r
.34874 .70782 m .34836 .71084 L .34594 .71145 L F
.444 .205 .456 r
.34809 .71297 m .34594 .71145 L .34836 .71084 L F
.34809 .71297 m .34613 .71367 L .34594 .71145 L F
.478 .243 .479 r
.35947 .69907 m .35766 .69777 L .35958 .69728 L F
.35947 .69907 m .35728 .69977 L .35766 .69777 L F
0 .397 .823 r
.51286 .82645 m .51516 .82748 L .51322 .82629 L F
.582 .18 .245 r
.46604 .76366 m .46951 .76212 L .4665 .76311 L F
.46604 .76366 m .46824 .76396 L .46951 .76212 L F
.717 .339 .332 r
.46951 .76212 m .46824 .76396 L .4716 .76421 L F
0 0 0 r
.41163 .77841 m .41195 .77906 L .4134 .7774 L F
.41163 .77841 m .41002 .77975 L .41195 .77906 L F
.554 .437 .675 r
.50017 .74907 m .49786 .75153 L .4969 .74841 L F
.50017 .74907 m .49999 .7512 L .49786 .75153 L F
.601 .523 .738 r
.49999 .7512 m .49827 .7539 L .49786 .75153 L F
.665 .882 .979 r
.44661 .72496 m .44511 .72567 L .44382 .72509 L F
.664 .561 .729 r
.37503 .76721 m .37298 .76979 L .37294 .76757 L F
.511 .767 .989 r
.33963 .65315 m .33607 .6524 L .33819 .65263 L F
.389 .824 .955 r
.34041 .65239 m .33963 .65315 L .33819 .65263 L F
.34041 .65239 m .34157 .65277 L .33963 .65315 L F
.054 0 .353 r
.33114 .79426 m .33258 .79129 L .33072 .79166 L F
.84 .726 .738 r
.67325 .62126 m .67599 .62396 L .67538 .61955 L F
.86 .721 .708 r
.67505 .62546 m .67599 .62396 L .67504 .62302 L F
.67467 .62458 m .67504 .62302 L .67325 .62126 L F
.67505 .62546 m .67504 .62302 L .67467 .62458 L F
.67505 .62546 m .67325 .62126 L .67534 .62413 L F
.841 .971 .658 r
.67406 .62689 m .67505 .62546 L .67534 .62413 L F
.67411 .62693 m .67534 .62413 L .6746 .6273 L F
.67406 .62689 m .67419 .62661 L .67411 .62693 L F
.67419 .62661 m .67534 .62413 L .67411 .62693 L F
0 0 .183 r
.67538 .61955 m .67599 .62396 L .67579 .62196 L F
.725 .74 .863 r
.31681 .6762 m .31364 .67673 L .31505 .67633 L F
.396 0 .107 r
.31681 .6762 m .31323 .67819 L .31364 .67673 L F
.31681 .6762 m .31529 .67796 L .31323 .67819 L F
.251 0 0 r
.31884 .67598 m .31529 .67796 L .31681 .6762 L F
.609 .552 .765 r
.43383 .73866 m .43656 .73948 L .43588 .7383 L F
.529 .375 .617 r
.48242 .75723 m .48451 .757 L .48448 .75412 L F
.604 .522 .736 r
.48242 .75723 m .48498 .7587 L .48451 .757 L F
.911 .894 .48 r
.63133 .60096 m .63038 .60198 L .6315 .60044 L F
.63133 .60096 m .63029 .6037 L .63038 .60198 L F
.719 .579 .697 r
.68277 .70326 m .68029 .70633 L .68266 .7054 L F
.676 .598 .76 r
.68266 .7054 m .68507 .70284 L .68277 .70326 L F
.684 .443 .552 r
.61953 .66805 m .61873 .67059 L .6165 .67047 L F
.645 .421 .564 r
.62185 .66795 m .61873 .67059 L .61953 .66805 L F
.883 .914 .842 r
.62226 .63914 m .62427 .63702 L .6217 .63752 L F
.89 .904 .83 r
.6217 .63752 m .62427 .63702 L .62519 .63574 L F
.721 .662 .79 r
.73287 .74159 m .73086 .74473 L .72965 .74104 L F
.66 .559 .729 r
.39982 .75679 m .40077 .75902 L .40313 .75626 L F
.803 .772 .263 r
.67762 .60651 m .67708 .60806 L .67711 .60892 L F
.587 .42 .623 r
.34524 .76776 m .34742 .76978 L .34714 .76743 L F
.34524 .76776 m .34524 .77021 L .34742 .76978 L F
.592 .507 .728 r
.50121 .75651 m .49904 .75694 L .49827 .7539 L F
.618 .547 .752 r
.50232 .75986 m .49904 .75694 L .50121 .75651 L F
.509 .298 .528 r
.35088 .70554 m .35045 .70769 L .34874 .70782 L F
.473 .24 .48 r
.35045 .70769 m .34836 .71084 L .34874 .70782 L F
.565 .352 .55 r
.36355 .74033 m .36571 .74004 L .3666 .73565 L F
.558 .345 .548 r
.3666 .73565 m .36784 .7397 L .36805 .737 L F
.3666 .73565 m .36571 .74004 L .36784 .7397 L F
.178 0 .142 r
.33267 .72448 m .33171 .72664 L .3301 .727 L F
.262 0 .184 r
.33348 .726 m .33267 .72448 L .33439 .72394 L F
.33348 .726 m .33171 .72664 L .33267 .72448 L F
.366 .682 .978 r
.36805 .83978 m .3667 .84019 L .36485 .83898 L F
.36485 .83898 m .3667 .84019 L .36805 .83978 L F
.288 .277 .673 r
.36854 .84225 m .3667 .84019 L .36805 .83978 L F
.36854 .84225 m .3667 .84019 L .36805 .83978 L F
.366 .682 .978 r
.36485 .83898 m .3667 .84019 L .36805 .83978 L F
.604 .595 .815 r
.49887 .74698 m .4969 .74841 L .49629 .74689 L F
.49887 .74698 m .49941 .74866 L .4969 .74841 L F
.632 .467 .641 r
.49941 .74866 m .50017 .74907 L .4969 .74841 L F
.645 .099 0 r
.71967 .70537 m .72181 .70683 L .72224 .70609 L F
.62 .069 0 r
.72181 .70683 m .72484 .70768 L .72224 .70609 L F
.272 .312 .721 r
.71434 .73307 m .71815 .73573 L .71627 .73207 L F
.71434 .73307 m .71508 .73577 L .71815 .73573 L F
.7 .602 .744 r
.68615 .70604 m .68948 .70855 L .68842 .70548 L F
.73 .705 .827 r
.68948 .70855 m .6908 .70497 L .68842 .70548 L F
.523 .481 .751 r
.69524 .70662 m .69784 .70844 L .69793 .70578 L F
.536 .507 .771 r
.43742 .74339 m .43937 .74301 L .43798 .73978 L F
.582 .607 .843 r
.47719 .74821 m .47795 .74959 L .48004 .74915 L F
.601 .523 .738 r
.49999 .7512 m .5009 .75438 L .49827 .7539 L F
.592 .507 .728 r
.50121 .75651 m .49827 .7539 L .5009 .75438 L F
.125 0 0 r
.45214 .77612 m .44859 .77717 L .45008 .77627 L F
.392 .85 .813 r
.38621 .79874 m .3854 .79931 L .38729 .7989 L F
.38621 .79874 m .38431 .7995 L .3854 .79931 L F
.177 .708 .844 r
.35046 .65497 m .35256 .65481 L .35386 .65494 L F
.211 .644 .951 r
.3545 .65434 m .35386 .65494 L .35256 .65481 L F
.3545 .65434 m .35566 .65502 L .35386 .65494 L F
.559 .561 .812 r
.35566 .65502 m .35413 .65676 L .35386 .65494 L F
.468 .169 .374 r
.35803 .65915 m .35503 .6603 L .35413 .65676 L F
.35803 .65915 m .35705 .66007 L .35503 .6603 L F
.287 0 0 r
.42128 .78562 m .41994 .78723 L .41791 .78756 L F
.248 0 0 r
.42208 .7867 m .42128 .78562 L .42343 .78531 L F
.42208 .7867 m .41994 .78723 L .42128 .78562 L F
.665 .549 .714 r
.68387 .69747 m .6873 .70019 L .68718 .6978 L F
.771 .515 .548 r
.68718 .6978 m .6873 .70019 L .69058 .70016 L F
.258 .248 .657 r
.73346 .71879 m .73213 .71957 L .73245 .71617 L F
.317 0 .017 r
.41441 .78968 m .41395 .78824 L .4158 .78792 L F
.41441 .78968 m .41214 .79014 L .41395 .78824 L F
.606 .834 .987 r
.73034 .73206 m .72824 .73266 L .72899 .73136 L F
.81 .434 .344 r
.73158 .73512 m .73004 .73515 L .72824 .73266 L F
.98 .752 .522 r
.73004 .73515 m .72899 .73136 L .72824 .73266 L F
.498 .768 .992 r
.45992 .72668 m .45905 .72794 L .45788 .7269 L F
.45992 .72668 m .46131 .72772 L .45905 .72794 L F
.811 .725 .77 r
.60562 .65517 m .60186 .657 L .60217 .65468 L F
.597 .628 .853 r
.55276 .81223 m .55456 .81031 L .5522 .81071 L F
.55276 .81223 m .55489 .81191 L .55456 .81031 L F
.628 .626 .829 r
.36219 .8348 m .36328 .83785 L .36514 .837 L F
.749 .463 .497 r
.71675 .7067 m .7175 .70875 L .71375 .7079 L F
.552 .361 .576 r
.71902 .70693 m .7175 .70875 L .71675 .7067 L F
.781 .614 .673 r
.71081 .73234 m .71436 .73026 L .7107 .72991 L F
.71081 .73234 m .71434 .73307 L .71436 .73026 L F
.499 .383 .653 r
.71436 .73026 m .71434 .73307 L .71627 .73207 L F
.779 .664 .736 r
.68073 .70833 m .68266 .7054 L .68029 .70633 L F
.676 .598 .76 r
.68266 .7054 m .68615 .70604 L .68507 .70284 L F
.193 0 0 r
.44919 .72529 m .45261 .72593 L .45009 .72564 L F
0 .265 .767 r
.67708 .60806 m .67955 .61046 L .67711 .60892 L F
.802 .639 .68 r
.67971 .71859 m .681 .72187 L .68228 .71925 L F
.514 .133 .256 r
.46558 .77272 m .46271 .77448 L .46323 .77354 L F
.567 .842 .996 r
.35046 .65497 m .34843 .65552 L .34708 .65477 L F
.433 .303 .603 r
.34938 .68439 m .3512 .68597 L .35088 .68378 L F
.34938 .68439 m .34921 .68707 L .3512 .68597 L F
.787 .297 .05 r
.72484 .70768 m .7283 .71031 L .72577 .70839 L F
.119 .316 .786 r
.51803 .76759 m .51668 .76395 L .51972 .76469 L F
.565 .452 .684 r
.51972 .76469 m .52059 .7673 L .51803 .76759 L F
.119 .316 .786 r
.51803 .76759 m .51885 .76643 L .51668 .76395 L F
0 0 .055 r
.51803 .76759 m .51816 .76762 L .51885 .76643 L F
.51816 .76762 m .51803 .76759 L .52059 .7673 L F
.46 .043 .162 r
.44409 .76918 m .44755 .76726 L .44544 .76754 L F
.406 .175 .448 r
.3523 .70512 m .35045 .70769 L .35088 .70554 L F
.896 .549 .381 r
.714 .69776 m .71465 .7001 L .71602 .70016 L F
.841 .377 .003 r
.71668 .70233 m .71602 .70016 L .71465 .7001 L F
.71668 .70233 m .71775 .70286 L .71602 .70016 L F
.853 .446 .265 r
.71602 .70016 m .71775 .70286 L .71921 .70313 L F
.294 0 0 r
.49048 .8683 m .48901 .86767 L .48879 .86872 L F
.49048 .8683 m .49205 .86864 L .48901 .86767 L F
.557 .204 .324 r
.45862 .76496 m .46051 .76633 L .46175 .76405 L F
.547 .179 .294 r
.46051 .76633 m .46382 .76425 L .46175 .76405 L F
.89 .904 .83 r
.6217 .63752 m .62519 .63574 L .62423 .63488 L F
.687 .643 .801 r
.48054 .87803 m .48312 .87727 L .48173 .87437 L F
.309 .206 .572 r
.48054 .87803 m .48232 .87906 L .48312 .87727 L F
.48054 .87803 m .48059 .8804 L .48232 .87906 L F
.958 .691 .488 r
.67454 .63148 m .6752 .63079 L .674 .63001 L F
.998 .809 .524 r
.64972 .63638 m .65103 .63586 L .65012 .6386 L F
.64972 .63638 m .65012 .6351 L .65103 .63586 L F
.521 .907 .76 r
.65235 .63473 m .65103 .63586 L .65012 .6351 L F
.65235 .63473 m .65378 .63413 L .65103 .63586 L F
.078 .445 .879 r
.6624 .58864 m .66011 .58828 L .65931 .58717 L F
.6624 .58864 m .66289 .58968 L .66011 .58828 L F
.606 .54 .754 r
.71923 .61447 m .72232 .61716 L .72142 .61403 L F
.243 0 0 r
.70233 .64317 m .69992 .64415 L .70035 .64382 L F
.783 .523 .544 r
.43322 .73715 m .42957 .73932 L .42976 .73852 L F
.43322 .73715 m .4328 .74004 L .42957 .73932 L F
.533 .379 .617 r
.34714 .76743 m .34908 .7644 L .34711 .76511 L F
.496 .276 .51 r
.33584 .70044 m .33782 .70004 L .33826 .69784 L F
.537 .416 .662 r
.33613 .70292 m .33782 .70004 L .33584 .70044 L F
.714 .663 .798 r
.69835 .70214 m .69982 .70394 L .69793 .70578 L F
.939 .696 .543 r
.69793 .70578 m .69642 .70661 L .69586 .70526 L F
.69793 .70578 m .69784 .70844 L .69642 .70661 L F
.827 .735 .763 r
.60319 .64444 m .59961 .64618 L .6018 .64347 L F
.60319 .64444 m .6012 .64723 L .59961 .64618 L F
.845 .809 .815 r
.6053 .64174 m .60319 .64444 L .6018 .64347 L F
.264 0 .271 r
.63605 .59276 m .63801 .59244 L .63845 .59042 L F
.299 .076 .397 r
.63774 .59452 m .63605 .59276 L .63546 .59499 L F
.63774 .59452 m .63801 .59244 L .63605 .59276 L F
.379 .844 .843 r
.70596 .63068 m .70273 .63153 L .70495 .63188 L F
.201 .722 .865 r
.70772 .63031 m .70829 .63052 L .70596 .63068 L F
.70772 .63031 m .70596 .63068 L .70495 .63188 L F
0 .094 .652 r
.342 .81562 m .34148 .81607 L .34034 .81374 L F
0 .186 .719 r
.342 .81562 m .34386 .81859 L .34148 .81607 L F
.609 .401 .575 r
.3393 .78077 m .34133 .78283 L .34159 .78041 L F
.3393 .78077 m .3391 .78317 L .34133 .78283 L F
.134 .375 .831 r
.67179 .61709 m .67431 .61875 L .67358 .6197 L F
.528 .349 .581 r
.67358 .6197 m .67538 .61955 L .67523 .61734 L F
.84 .726 .738 r
.67325 .62126 m .67538 .61955 L .67358 .6197 L F
.884 .894 .833 r
.67431 .61875 m .67325 .62126 L .67358 .6197 L F
.281 .766 .681 r
.64901 .65419 m .64579 .65543 L .64696 .65471 L F
.455 .13 .325 r
.31364 .67673 m .31323 .67819 L .3112 .67846 L F
.264 0 .212 r
.62917 .66505 m .62682 .66799 L .6274 .66551 L F
.956 .619 .235 r
.71883 .70444 m .71921 .70313 L .71775 .70286 L F
.71883 .70444 m .71967 .70537 L .71921 .70313 L F
.071 .592 .876 r
.72594 .72209 m .72501 .72163 L .72302 .72133 L F
.715 .747 .878 r
.72628 .71763 m .72372 .71938 L .72609 .71643 L F
.72642 .71853 m .72624 .71859 L .72628 .71763 L F
.221 .309 .742 r
.72505 .71881 m .72618 .71997 L .72594 .72209 L F
.715 .747 .878 r
.72624 .71859 m .72372 .71938 L .72628 .71763 L F
.221 .309 .742 r
.72618 .71997 m .72727 .72107 L .7261 .72196 L F
.72618 .71997 m .7261 .72196 L .72594 .72209 L F
.5 .862 .988 r
.72727 .72107 m .72501 .72163 L .72594 .72209 L F
.05 0 0 r
.32391 .67472 m .32293 .67516 L .32084 .67544 L F
.364 0 0 r
.32391 .67472 m .32674 .67539 L .32293 .67516 L F
.316 0 0 r
.71745 .73744 m .72108 .7378 L .71871 .73801 L F
.71745 .73744 m .7191 .73779 L .72108 .7378 L F
.337 .635 .962 r
.722 .73661 m .72108 .7378 L .7191 .73779 L F
.495 .314 .565 r
.33782 .70004 m .33991 .69698 L .33826 .69784 L F
.956 .748 .582 r
.67323 .64025 m .6749 .63894 L .6741 .63827 L F
.67323 .64025 m .67455 .64131 L .6749 .63894 L F
.205 .731 .75 r
.71284 .63693 m .71182 .63701 L .71146 .63718 L F
.71284 .63693 m .71537 .63635 L .71182 .63701 L F
.582 .669 .898 r
.49349 .74549 m .48998 .74354 L .49226 .74355 L F
.614 .709 .913 r
.49438 .74275 m .49349 .74549 L .49226 .74355 L F
.49438 .74275 m .49597 .74531 L .49349 .74549 L F
.639 .597 .791 r
.49597 .74531 m .49629 .74689 L .49349 .74549 L F
.692 .607 .756 r
.55355 .80271 m .55135 .80502 L .55356 .80466 L F
.63 .471 .649 r
.55141 .80718 m .55356 .80466 L .55135 .80502 L F
.428 0 0 r
.71508 .73577 m .71431 .73665 L .71206 .73617 L F
.272 .312 .721 r
.71434 .73307 m .71683 .73515 L .71508 .73577 L F
0 0 0 r
.71683 .73515 m .71431 .73665 L .71508 .73577 L F
.514 .133 .256 r
.46558 .77272 m .46511 .77446 L .46271 .77448 L F
.58 .285 .431 r
.46895 .77238 m .46511 .77446 L .46558 .77272 L F
.657 .471 .621 r
.67785 .71101 m .67891 .71129 L .67867 .70831 L F
.697 .567 .705 r
.67867 .70831 m .68073 .70833 L .68029 .70633 L F
.715 .514 .617 r
.67867 .70831 m .68064 .7105 L .68073 .70833 L F
.67867 .70831 m .67891 .71129 L .68064 .7105 L F
.559 .561 .812 r
.35677 .65696 m .35803 .65915 L .35448 .65698 L F
.648 .6 .787 r
.35773 .6558 m .35803 .65915 L .35566 .65502 L F
.567 .483 .719 r
.35773 .6558 m .35705 .66007 L .35803 .65915 L F
.35755 .65695 m .35911 .65961 L .35705 .66007 L F
.35773 .6558 m .35815 .65694 L .35755 .65695 L F
.35815 .65694 m .35911 .65961 L .35755 .65695 L F
.559 .561 .812 r
.35566 .65502 m .35677 .65696 L .35413 .65676 L F
.35677 .65696 m .35448 .65698 L .35413 .65676 L F
.435 .005 .121 r
.71066 .63044 m .71086 .62941 L .70829 .63052 L F
.299 0 .092 r
.71292 .62975 m .71086 .62941 L .71066 .63044 L F
.405 .552 .888 r
.68653 .58733 m .6854 .58905 L .6845 .58736 L F
.68653 .58733 m .68844 .59034 L .6854 .58905 L F
.485 .28 .527 r
.67445 .71614 m .67662 .71636 L .67753 .71186 L F
.663 .447 .581 r
.67753 .71186 m .67662 .71636 L .67846 .71553 L F
.551 .563 .82 r
.55586 .8129 m .55686 .80974 L .55489 .81191 L F
.624 .367 .508 r
.61102 .67098 m .60918 .67287 L .60903 .67084 L F
.388 .77 .991 r
.43267 .72429 m .43471 .72414 L .43602 .72482 L F
.071 .593 .875 r
.43471 .72414 m .43801 .72499 L .43602 .72482 L F
.555 .372 .588 r
.35306 .754 m .35515 .75365 L .3552 .75134 L F
.554 .407 .636 r
.35326 .75653 m .35515 .75365 L .35306 .754 L F
.827 .835 .854 r
.65647 .64852 m .65878 .64644 L .65601 .64666 L F
.809 .826 .864 r
.65647 .64852 m .65601 .64666 L .65365 .64914 L F
.737 .463 .514 r
.6399 .6091 m .64169 .61152 L .63798 .61045 L F
.704 .599 .736 r
.6399 .6091 m .6419 .60642 L .64196 .6091 L F
.601 .894 .989 r
.72864 .74052 m .72965 .74104 L .72722 .74199 L F
.655 .889 .982 r
.37022 .80892 m .3685 .81057 L .36657 .80997 L F
0 0 .212 r
.3679 .81264 m .3685 .81057 L .37022 .80892 L F
.934 .557 .209 r
.51798 .87231 m .51772 .87272 L .51678 .87174 L F
.597 .947 .811 r
.51849 .87174 m .51798 .87231 L .51678 .87174 L F
0 0 0 r
.51948 .87115 m .51772 .87272 L .51798 .87231 L F
.814 .794 .833 r
.51678 .87174 m .51772 .87272 L .51882 .87174 L F
.597 .947 .811 r
.51849 .87174 m .51948 .87115 L .51798 .87231 L F
.814 .794 .833 r
.51678 .87174 m .51849 .87174 L .51948 .87115 L F
.597 .947 .811 r
.51914 .87102 m .51948 .87115 L .51849 .87174 L F
.814 .794 .833 r
.51849 .87174 m .51882 .87174 L .51948 .87115 L F
.51678 .87174 m .51948 .87115 L .51914 .87102 L F
.597 .947 .811 r
.51914 .87102 m .51849 .87174 L .51678 .87174 L F
.671 .684 .854 r
.32707 .65083 m .32529 .65231 L .32378 .6502 L F
.856 .62 .081 r
.67304 .60871 m .67249 .60557 L .6728 .60663 L F
.999 .791 .483 r
.64429 .61976 m .64334 .61874 L .64441 .61733 L F
.341 .211 .554 r
.64441 .61733 m .64612 .61893 L .64428 .61987 L F
.623 .175 .165 r
.64334 .61874 m .64612 .61893 L .64441 .61733 L F
.999 .791 .483 r
.64428 .61987 m .64334 .61874 L .64429 .61976 L F
.557 .802 .99 r
.64334 .61874 m .64612 .61893 L .64428 .61987 L F
.722 .659 .787 r
.64334 .61874 m .64565 .6164 L .64612 .61893 L F
.518 .547 .825 r
.64655 .62162 m .64334 .61874 L .64612 .61893 L F
.471 .254 .501 r
.64612 .61893 m .64803 .61973 L .64655 .62162 L F
.725 .665 .79 r
.64234 .61554 m .64334 .61874 L .64175 .61748 L F
.64234 .61554 m .64565 .6164 L .64334 .61874 L F
.607 .044 0 r
.64675 .62078 m .64281 .61818 L .64334 .61874 L F
.64281 .61818 m .64175 .61748 L .64334 .61874 L F
.436 .16 .395 r
.36736 .68947 m .36631 .69192 L .36447 .69242 L F
.539 .298 .498 r
.36908 .68936 m .36631 .69192 L .36736 .68947 L F
.639 .276 .34 r
.49187 .77237 m .49071 .77456 L .48836 .77264 L F
.718 .367 .382 r
.49424 .77466 m .49187 .77237 L .49382 .77261 L F
.49424 .77466 m .49071 .77456 L .49187 .77237 L F
.768 .785 .868 r
.69833 .63579 m .69544 .63781 L .69526 .63562 L F
.988 .746 .474 r
.67538 .61955 m .67435 .61647 L .67523 .61734 L F
.762 .59 .664 r
.71871 .73801 m .71529 .74006 L .71745 .73744 L F
.71871 .73801 m .71835 .74047 L .71529 .74006 L F
.06 .571 .881 r
.71745 .73744 m .7191 .73779 L .71871 .73801 L F
.845 .809 .815 r
.6053 .64174 m .6018 .64347 L .60394 .64071 L F
.635 .514 .699 r
.64421 .60562 m .64196 .6091 L .6419 .60642 L F
.64421 .60562 m .64527 .60881 L .64196 .6091 L F
.636 .528 .714 r
.64196 .6091 m .64527 .60881 L .64416 .61202 L F
.054 0 .353 r
.33114 .79426 m .33231 .79353 L .33258 .79129 L F
.116 .101 .562 r
.33148 .79683 m .33231 .79353 L .33114 .79426 L F
.671 .804 .946 r
.64008 .62314 m .64247 .62222 L .63895 .62192 L F
.777 .594 .651 r
.64196 .62458 m .63895 .62192 L .64008 .62314 L F
0 .412 .852 r
.71677 .59709 m .71529 .5969 L .7149 .59538 L F
.71677 .59709 m .71848 .59881 L .71529 .5969 L F
.591 .554 .782 r
.33512 .81251 m .33527 .80972 L .33374 .8112 L F
.33512 .81251 m .33654 .8097 L .33527 .80972 L F
.33512 .81251 m .33774 .81262 L .33654 .8097 L F
.741 .355 .322 r
.65012 .6386 m .64836 .6405 L .64972 .63638 L F
.85 .403 0 r
.72956 .71332 m .72906 .71116 L .7283 .71031 L F
.72956 .71332 m .73033 .71342 L .72906 .71116 L F
.531 .675 .93 r
.70447 .59857 m .70092 .59684 L .7041 .59744 L F
.378 .619 .946 r
.7041 .59744 m .70563 .59749 L .70447 .59857 L F
.519 .86 .993 r
.70447 .59857 m .70563 .59749 L .70668 .59802 L F
.568 .421 .641 r
.70668 .59802 m .70554 .60034 L .70447 .59857 L F
.754 .523 .582 r
.70151 .71195 m .70345 .7131 L .70108 .71282 L F
.84 .794 .806 r
.70151 .71195 m .70382 .71107 L .70345 .7131 L F
.653 .635 .82 r
.46367 .73979 m .46492 .74307 L .46673 .74089 L F
.657 .641 .823 r
.46492 .74307 m .46815 .74358 L .46673 .74089 L F
.673 .414 .52 r
.68742 .70239 m .69058 .70016 L .6873 .70019 L F
.68742 .70239 m .69101 .70313 L .69058 .70016 L F
.589 .355 .529 r
.69058 .70016 m .69101 .70313 L .6941 .70254 L F
.631 .902 .985 r
.44579 .73873 m .44474 .74007 L .44722 .73912 L F
.44579 .73873 m .44366 .73961 L .44474 .74007 L F
.952 .921 .74 r
.62226 .63914 m .6205 .64057 L .62175 .64144 L F
.62226 .63914 m .6217 .63752 L .6205 .64057 L F
.838 .811 .824 r
.65601 .64666 m .65878 .64644 L .65778 .64516 L F
.799 .804 .856 r
.65778 .64516 m .65878 .64644 L .66127 .64424 L F
.73 .698 .819 r
.35907 .81011 m .36267 .81076 L .36135 .80838 L F
.589 .634 .864 r
.36135 .80838 m .36267 .81076 L .36457 .81016 L F
.786 .774 .842 r
.52858 .83194 m .52978 .83445 L .52688 .83361 L F
.714 .201 .003 r
.52688 .83361 m .52885 .83472 L .52978 .83445 L F
.831 .79 .813 r
.5321 .83152 m .52978 .83445 L .52858 .83194 L F
.121 .287 .76 r
.52978 .83445 m .53091 .83371 L .52885 .83472 L F
.52978 .83445 m .53193 .83652 L .53091 .83371 L F
.564 .37 .576 r
.35515 .75365 m .35747 .75103 L .3552 .75134 L F
.754 .593 .677 r
.68064 .7105 m .68192 .71374 L .68365 .71086 L F
.63 .471 .649 r
.55141 .80718 m .55422 .80736 L .55356 .80466 L F
.578 .419 .63 r
.5522 .81071 m .55422 .80736 L .55141 .80718 L F
.633 .428 .587 r
.59238 .67361 m .59473 .6757 L .59459 .67337 L F
.59238 .67361 m .59241 .6759 L .59473 .6757 L F
.59473 .6757 m .59238 .67361 L .59459 .67337 L F
.59473 .6757 m .59241 .6759 L .59238 .67361 L F
.978 .689 .309 r
.67475 .6144 m .67352 .61087 L .67463 .61181 L F
.76 .625 .71 r
.70768 .72729 m .70767 .73018 L .7107 .72991 L F
.799 .553 .566 r
.70763 .73193 m .7107 .72991 L .70767 .73018 L F
.70763 .73193 m .71081 .73234 L .7107 .72991 L F
.601 .659 .879 r
.38748 .78376 m .38459 .78259 L .38624 .78232 L F
0 0 0 r
.38918 .7807 m .38748 .78376 L .38949 .78318 L F
.609 .699 .907 r
.38949 .78318 m .38748 .78376 L .38624 .78232 L F
.378 .687 .98 r
.68892 .63824 m .69102 .63937 L .68964 .63802 L F
.342 0 .183 r
.46424 .76372 m .46604 .76366 L .4665 .76311 L F
.46424 .76372 m .46382 .76425 L .46604 .76366 L F
.292 0 .152 r
.63801 .59244 m .64071 .5901 L .63845 .59042 L F
.585 .369 .554 r
.62413 .65477 m .62646 .6515 L .62394 .65212 L F
.62413 .65477 m .62667 .65452 L .62646 .6515 L F
.392 .098 .342 r
.62667 .65452 m .62922 .65141 L .62646 .6515 L F
.681 .827 .953 r
.71217 .59577 m .70893 .59539 L .71144 .59408 L F
.627 .657 .859 r
.71333 .59224 m .71217 .59577 L .71144 .59408 L F
.71333 .59224 m .7149 .59538 L .71217 .59577 L F
.06 .199 .696 r
.51617 .76868 m .51572 .77015 L .51472 .76691 L F
.634 .547 .739 r
.51472 .76691 m .51238 .76759 L .5117 .76437 L F
.51472 .76691 m .5117 .76437 L .51343 .76395 L F
.549 .557 .815 r
.51701 .76568 m .51472 .76691 L .51343 .76395 L F
.06 .199 .696 r
.51657 .76917 m .51637 .7694 L .51617 .76868 L F
.51637 .7694 m .51572 .77015 L .51617 .76868 L F
.726 .341 .32 r
.51331 .76878 m .51657 .76917 L .51472 .76691 L F
.51331 .76878 m .51472 .76691 L .51701 .76568 L F
.816 .703 .74 r
.51215 .76577 m .51331 .76878 L .51565 .76682 L F
.51533 .76571 m .51565 .76682 L .51701 .76568 L F
.51215 .76577 m .51565 .76682 L .51533 .76571 L F
.151 .344 .801 r
.51657 .76917 m .51805 .77202 L .51572 .77015 L F
.563 .415 .639 r
.34142 .77802 m .34335 .77527 L .3411 .77567 L F
.563 .2 .31 r
.45825 .76616 m .46051 .76633 L .45862 .76496 L F
.748 .636 .736 r
.70345 .7131 m .70145 .71562 L .70108 .71282 L F
.556 .523 .773 r
.36597 .66436 m .36697 .66782 L .36499 .66824 L F
.569 .804 .988 r
.46672 .72775 m .46449 .72831 L .46336 .7273 L F
.414 .573 .902 r
.68975 .59684 m .69303 .59929 L .69266 .59777 L F
.574 .595 .836 r
.69266 .59777 m .69303 .59929 L .69526 .59762 L F
.484 .425 .716 r
.69303 .59929 m .69562 .60078 L .69526 .59762 L F
.682 .616 .776 r
.71497 .72425 m .71873 .72567 L .71744 .72355 L F
.672 .61 .777 r
.71744 .72355 m .71873 .72567 L .72061 .72443 L F
.784 .378 .281 r
.73158 .73512 m .73087 .73671 L .73004 .73515 L F
.179 0 0 r
.73456 .73565 m .73087 .73671 L .73158 .73512 L F
.909 .941 .58 r
.5686 .80747 m .56829 .80911 L .57173 .80818 L F
.5686 .80747 m .56776 .80928 L .56829 .80911 L F
.609 .699 .907 r
.38949 .78318 m .38849 .7807 L .38918 .7807 L F
0 0 0 r
.3914 .77841 m .38918 .7807 L .3902 .77973 L F
.54 .927 .854 r
.38918 .7807 m .38849 .7807 L .3902 .77973 L F
.746 .645 .748 r
.50776 .76156 m .50449 .75933 L .50665 .75898 L F
.50776 .76156 m .50576 .76233 L .50449 .75933 L F
.661 .14 0 r
.50665 .75898 m .50997 .76004 L .50776 .76156 L F
.651 .682 .866 r
.50997 .76004 m .51116 .76213 L .50776 .76156 L F
.579 .566 .803 r
.49775 .74339 m .49629 .74689 L .49597 .74531 L F
.49775 .74339 m .49887 .74698 L .49629 .74689 L F
.694 .6 .747 r
.50997 .76004 m .51313 .7617 L .51116 .76213 L F
.519 .409 .669 r
.51313 .7617 m .51343 .76395 L .51116 .76213 L F
.488 .411 .695 r
.51116 .76213 m .51343 .76395 L .5117 .76437 L F
.648 .582 .766 r
.68507 .70284 m .68615 .70604 L .68842 .70548 L F
.774 .622 .692 r
.60249 .65232 m .59904 .65208 L .60081 .64932 L F
.747 .557 .639 r
.60249 .65232 m .59865 .65434 L .59904 .65208 L F
.60249 .65232 m .60217 .65468 L .59865 .65434 L F
.721 .469 .544 r
.49924 .77508 m .4969 .77288 L .49912 .77286 L F
.703 .451 .541 r
.50295 .77491 m .49912 .77286 L .50274 .7727 L F
.50295 .77491 m .49924 .77508 L .49912 .77286 L F
.756 .674 .771 r
.33941 .80512 m .34192 .80494 L .34035 .80174 L F
.75 .639 .738 r
.33941 .80751 m .34192 .80494 L .33941 .80512 L F
.392 .487 .837 r
.34035 .80174 m .34192 .80494 L .34322 .80447 L F
.874 .537 .409 r
.71243 .69898 m .714 .69776 L .71229 .69672 L F
.71243 .69898 m .71465 .7001 L .714 .69776 L F
.842 .566 .521 r
.64415 .60389 m .64119 .60122 L .64073 .60343 L F
.756 .639 .731 r
.6419 .60642 m .64415 .60389 L .64073 .60343 L F
.658 .489 .644 r
.6419 .60642 m .6435 .60462 L .64421 .60562 L F
.6435 .60462 m .64417 .60448 L .64421 .60562 L F
.6419 .60642 m .64415 .60389 L .64421 .60562 L F
.657 .464 .611 r
.64421 .60562 m .64639 .60363 L .64415 .60389 L F
.386 0 .035 r
.64317 .60587 m .64668 .60386 L .64421 .60562 L F
.71 .504 .608 r
.64421 .60562 m .64742 .60837 L .64527 .60881 L F
.386 0 .035 r
.64317 .60587 m .64568 .60612 L .64663 .60396 L F
.64641 .60401 m .64663 .60396 L .64668 .60386 L F
.657 .464 .611 r
.64421 .60562 m .64668 .60386 L .64639 .60363 L F
.386 0 .035 r
.64317 .60587 m .64663 .60396 L .64641 .60401 L F
.658 .489 .644 r
.6435 .60462 m .64415 .60389 L .64417 .60448 L F
.499 .075 .167 r
.41073 .74135 m .40748 .74251 L .40858 .7414 L F
.715 .6 .726 r
.5117 .76437 m .51238 .76759 L .5093 .76716 L F
.611 .464 .657 r
.34321 .77287 m .34335 .77527 L .34541 .77254 L F
.62 .704 .905 r
.37611 .77714 m .37525 .77918 L .3739 .77773 L F
.37611 .77714 m .37752 .77873 L .37525 .77918 L F
.935 .788 .673 r
.67871 .6258 m .67687 .62697 L .67724 .62648 L F
.67871 .6258 m .6782 .62798 L .67687 .62697 L F
.496 .322 .575 r
.37358 .77259 m .37351 .77529 L .37139 .77561 L F
.549 .44 .683 r
.37351 .77529 m .37183 .77806 L .37139 .77561 L F
.594 .43 .628 r
.34908 .7644 m .35113 .76171 L .34923 .76214 L F
.641 .56 .748 r
.55356 .80466 m .55567 .8019 L .55355 .80271 L F
.55356 .80466 m .55633 .80473 L .55567 .8019 L F
.574 .386 .589 r
.55422 .80736 m .55633 .80473 L .55356 .80466 L F
.582 .14 .165 r
.421 .7768 m .4233 .77723 L .42475 .77571 L F
.334 0 .019 r
.4233 .77723 m .42681 .77531 L .42475 .77571 L F
.873 .55 .436 r
.51099 .78042 m .51272 .78091 L .5114 .78255 L F
.803 .446 .38 r
.51272 .78091 m .51439 .78321 L .5114 .78255 L F
.792 .429 .371 r
.51272 .78091 m .51616 .78301 L .51439 .78321 L F
.489 .118 .261 r
.34457 .67919 m .34456 .6804 L .34216 .67942 L F
.329 .34 .721 r
.34216 .67942 m .34456 .6804 L .34317 .6773 L F
.468 .038 .138 r
.40166 .72581 m .40377 .72581 L .40526 .7241 L F
.225 0 0 r
.40377 .72581 m .4074 .72441 L .40526 .7241 L F
.936 .592 .162 r
.64216 .62532 m .64238 .62888 L .64142 .62542 L F
.468 .256 .508 r
.64216 .62532 m .64465 .62901 L .64238 .62888 L F
.64216 .62532 m .64509 .62671 L .64465 .62901 L F
.632 .677 .875 r
.69953 .71659 m .69622 .7157 L .69816 .7132 L F
.362 .801 .642 r
.32202 .65052 m .32237 .65029 L .32378 .6502 L F
.32202 .65052 m .3205 .65132 L .32237 .65029 L F
.986 .731 .458 r
.67799 .63025 m .67908 .63316 L .67814 .63255 L F
.887 .507 .31 r
.67908 .63316 m .67808 .63445 L .67814 .63255 L F
.67908 .63316 m .6808 .63682 L .67808 .63445 L F
.573 .149 .199 r
.33737 .82366 m .33762 .82365 L .33744 .82358 L F
.43 .195 .455 r
.35496 .70221 m .3523 .70512 L .35321 .70308 L F
.865 .709 .687 r
.6012 .64723 m .60081 .64932 L .59961 .64618 L F
.563 .415 .639 r
.34142 .77802 m .34351 .77768 L .34335 .77527 L F
.569 .432 .654 r
.34159 .78041 m .34351 .77768 L .34142 .77802 L F
0 0 0 r
.6804 .61737 m .68178 .61371 L .6822 .61599 L F
.459 .586 .893 r
.6822 .61599 m .6839 .61818 L .6804 .61737 L F
.766 .567 .629 r
.62051 .65421 m .62394 .65212 L .62047 .65183 L F
.62051 .65421 m .62413 .65477 L .62394 .65212 L F
.367 0 0 r
.4074 .72441 m .40951 .7244 L .41065 .72361 L F
.342 0 0 r
.40951 .7244 m .41283 .72371 L .41065 .72361 L F
.776 .673 .749 r
.68289 .58759 m .67956 .58718 L .68126 .58672 L F
.385 .751 .992 r
.6845 .58736 m .68289 .58759 L .68126 .58672 L F
.184 .689 .906 r
.43801 .72499 m .44024 .72496 L .4415 .72546 L F
.383 .805 .972 r
.4424 .72459 m .4415 .72546 L .44024 .72496 L F
.4424 .72459 m .44382 .72509 L .4415 .72546 L F
.415 .029 .195 r
.37563 .73485 m .37776 .73458 L .37897 .73251 L F
.521 .899 .958 r
.38081 .73169 m .37897 .73251 L .38015 .73175 L F
.307 0 .135 r
.37897 .73251 m .37978 .73393 L .38015 .73175 L F
.37897 .73251 m .37776 .73458 L .37978 .73393 L F
.657 .154 .039 r
.71081 .73234 m .71331 .73406 L .71434 .73307 L F
.687 .191 .062 r
.71331 .73406 m .71683 .73515 L .71434 .73307 L F
.44 .767 .997 r
.69665 .60213 m .69773 .60105 L .69562 .60078 L F
.69665 .60213 m .69913 .602 L .69773 .60105 L F
.923 .71 .597 r
.64414 .59712 m .64654 .5975 L .64689 .59792 L F
.194 .687 .921 r
.64689 .59792 m .64648 .59724 L .64414 .59712 L F
.442 .84 .978 r
.6499 .59707 m .6487 .59651 L .64689 .59792 L F
.464 .88 .934 r
.6487 .59651 m .64648 .59724 L .64689 .59792 L F
.638 .552 .741 r
.6463 .60175 m .6499 .59707 L .64689 .59792 L F
.664 .561 .729 r
.37503 .76721 m .37574 .76969 L .37298 .76979 L F
.542 .445 .695 r
.37546 .77219 m .37298 .76979 L .37574 .76969 L F
.37546 .77219 m .37358 .77259 L .37298 .76979 L F
.768 .672 .757 r
.68634 .6331 m .68738 .63595 L .6894 .63315 L F
.395 .367 .71 r
.68899 .63317 m .68738 .63595 L .68634 .6331 L F
.68899 .63317 m .68808 .63643 L .68738 .63595 L F
.481 .353 .629 r
.68808 .63643 m .68964 .63802 L .68738 .63595 L F
.368 0 .076 r
.42564 .78488 m .4291 .78282 L .42782 .78468 L F
.409 .004 .155 r
.4291 .78282 m .42986 .78463 L .42782 .78468 L F
.4291 .78282 m .4312 .78259 L .42986 .78463 L F
.542 .609 .869 r
.38624 .78232 m .38459 .78259 L .38284 .77994 L F
.575 .805 .986 r
.56799 .80373 m .56799 .80485 L .56923 .80435 L F
.874 .546 .427 r
.56651 .8064 m .56799 .80485 L .56799 .80373 L F
.56651 .8064 m .5686 .80747 L .56799 .80485 L F
.623 .556 .758 r
.48448 .75412 m .48572 .75094 L .48355 .75136 L F
.48448 .75412 m .48654 .75378 L .48572 .75094 L F
.576 .413 .624 r
.48448 .75412 m .48669 .75653 L .48654 .75378 L F
.48448 .75412 m .48451 .757 L .48669 .75653 L F
.144 0 .042 r
.33171 .72664 m .32901 .72885 L .3301 .727 L F
.037 .114 .616 r
.64639 .60363 m .64766 .60196 L .6463 .60175 L F
.407 .626 .942 r
.64668 .60386 m .64766 .60196 L .64639 .60363 L F
.903 .749 .679 r
.68459 .6239 m .68734 .62472 L .68729 .62259 L F
.836 .396 .186 r
.6879 .62646 m .68734 .62472 L .68459 .6239 L F
.693 .583 .728 r
.68734 .62472 m .68824 .62517 L .68729 .62259 L F
.764 .349 .263 r
.6879 .62646 m .68824 .62517 L .68734 .62472 L F
.661 .678 .856 r
.36413 .84692 m .36562 .84887 L .36744 .84775 L F
.36413 .84692 m .36562 .84887 L .36744 .84775 L F
.385 .159 .443 r
.63589 .60324 m .6376 .6031 L .63543 .60582 L F
.63543 .60582 m .6376 .6031 L .63589 .60324 L F
.617 .595 .806 r
.48009 .73524 m .47672 .73275 L .47903 .73203 L F
.548 .541 .799 r
.481 .73182 m .48009 .73524 L .47903 .73203 L F
.481 .73182 m .48212 .73495 L .48009 .73524 L F
.515 .504 .782 r
.48306 .73784 m .48009 .73524 L .48212 .73495 L F
.851 .672 .66 r
.6879 .62646 m .6906 .62515 L .68824 .62517 L F
.815 .709 .747 r
.71602 .71934 m .71978 .719 L .71869 .71886 L F
.71602 .71934 m .71725 .72183 L .71978 .719 L F
.71 .537 .653 r
.71978 .719 m .71725 .72183 L .71905 .7211 L F
.643 .961 .917 r
.72055 .71774 m .71869 .71886 L .71978 .719 L F
.422 .717 .986 r
.71978 .719 m .72153 .71871 L .72055 .71774 L F
.689 .662 .818 r
.71905 .7211 m .72153 .71871 L .71978 .719 L F
.624 .367 .508 r
.61102 .67098 m .61106 .67299 L .60918 .67287 L F
.663 .413 .531 r
.61414 .67067 m .61106 .67299 L .61102 .67098 L F
.886 .754 .711 r
.33834 .80461 m .33941 .80751 L .33941 .80512 L F
0 .193 .712 r
.34094 .80872 m .33941 .80751 L .33834 .80461 L F
.403 .179 .456 r
.33769 .81051 m .33941 .80751 L .3401 .80806 L F
.33769 .81051 m .3401 .80806 L .34033 .80905 L F
.34033 .80905 m .3401 .80806 L .34094 .80872 L F
.33769 .81051 m .34094 .80872 L .33654 .8097 L F
.634 .8 .962 r
.33337 .80836 m .33654 .8097 L .34094 .80872 L F
.769 .409 .374 r
.33784 .80901 m .34041 .80943 L .33992 .81155 L F
.34041 .80943 m .3413 .80958 L .34066 .81049 L F
.34041 .80943 m .34066 .81049 L .33992 .81155 L F
.831 .79 .813 r
.5321 .83152 m .52858 .83194 L .53093 .83109 L F
.914 .612 .459 r
.53091 .83371 m .5321 .83152 L .53093 .83109 L F
.53091 .83371 m .53256 .83444 L .5321 .83152 L F
.065 .617 .824 r
.70486 .69382 m .70815 .69421 L .70582 .6944 L F
.443 0 0 r
.41283 .72371 m .41492 .72403 L .41626 .72345 L F
.338 0 0 r
.41626 .72345 m .41492 .72403 L .41835 .72354 L F
.521 .313 .538 r
.67697 .59025 m .67688 .58775 L .67459 .59046 L F
.541 .328 .54 r
.67943 .589 m .67688 .58775 L .67697 .59025 L F
.69 .642 .797 r
.33743 .82378 m .33762 .82365 L .33737 .82366 L F
.821 .592 .591 r
.51103 .77817 m .50799 .77771 L .50806 .77525 L F
.858 .483 .338 r
.51099 .78042 m .50799 .77771 L .51103 .77817 L F
.765 .637 .72 r
.48589 .76447 m .48931 .76474 L .48835 .76165 L F
.727 .373 .379 r
.48589 .76447 m .48815 .76682 L .48931 .76474 L F
.617 .553 .76 r
.48835 .76165 m .48931 .76474 L .49142 .76444 L F
.694 .334 .361 r
.48931 .76474 m .48815 .76682 L .49143 .76677 L F
.577 .361 .55 r
.48931 .76474 m .49143 .76677 L .49142 .76444 L F
.635 .631 .829 r
.46673 .74089 m .46815 .74358 L .47027 .74309 L F
.633 .648 .847 r
.48681 .74045 m .48306 .73784 L .48528 .73753 L F
.547 .59 .849 r
.48748 .73718 m .48681 .74045 L .48528 .73753 L F
.48748 .73718 m .48885 .74019 L .48681 .74045 L F
0 0 0 r
.72258 .7146 m .72161 .71475 L .72305 .7143 L F
.72258 .7146 m .72101 .71579 L .72161 .71475 L F
.817 .519 .485 r
.51439 .78321 m .51616 .78301 L .51469 .78533 L F
.675 .3 .327 r
.51616 .78301 m .51777 .78487 L .51469 .78533 L F
.51616 .78301 m .51826 .78364 L .51777 .78487 L F
.881 .625 .547 r
.6013 .66282 m .59941 .66446 L .59958 .66201 L F
.6013 .66282 m .60128 .66516 L .59941 .66446 L F
.833 .817 .834 r
.60345 .66017 m .6013 .66282 L .59958 .66201 L F
.822 .377 .175 r
.70775 .60174 m .70701 .60268 L .70554 .60034 L F
0 0 0 r
.70874 .60164 m .70775 .60174 L .7103 .60106 L F
.70874 .60164 m .70701 .60268 L .70775 .60174 L F
.67 .637 .808 r
.47231 .74256 m .47382 .74555 L .47572 .74313 L F
.613 .554 .764 r
.47382 .74555 m .47608 .74525 L .47572 .74313 L F
.615 .574 .784 r
.47382 .74555 m .47719 .74821 L .47608 .74525 L F
.732 .708 .828 r
.73065 .72054 m .73168 .72247 L .73274 .72074 L F
.791 .741 .807 r
.69513 .71307 m .69622 .7157 L .69281 .71575 L F
.8 .661 .709 r
.69622 .7157 m .69414 .7189 L .69281 .71575 L F
.789 .74 .808 r
.69816 .7132 m .69622 .7157 L .69513 .71307 L F
0 0 0 r
.6554 .6322 m .65773 .63017 L .65481 .63018 L F
.917 .93 .803 r
.38989 .75288 m .389 .75626 L .38914 .75396 L F
.412 .159 .418 r
.52746 .77734 m .52564 .778 L .528 .77547 L F
.33 .066 .354 r
.52986 .77481 m .52746 .77734 L .528 .77547 L F
.628 .563 .762 r
.50449 .75933 m .50232 .75986 L .50121 .75651 L F
.879 .509 .337 r
.72187 .7435 m .71912 .74338 L .7186 .74286 L F
.72187 .7435 m .72204 .74499 L .71912 .74338 L F
.7 .859 .958 r
.56045 .81079 m .56392 .81078 L .56239 .80973 L F
.555 .798 .989 r
.56392 .81078 m .56573 .81025 L .56239 .80973 L F
.044 0 .009 r
.63184 .66284 m .63433 .66052 L .63352 .66156 L F
.359 .077 .343 r
.63611 .65954 m .63352 .66156 L .63433 .66052 L F
.119 .586 .918 r
.48235 .88527 m .48464 .88565 L .48162 .88242 L F
.48235 .88527 m .48474 .88586 L .48464 .88565 L F
.227 0 0 r
.64754 .58886 m .64624 .58825 L .64516 .58918 L F
.64754 .58886 m .64855 .58789 L .64624 .58825 L F
.559 .763 .973 r
.41437 .7426 m .41752 .74315 L .41626 .74228 L F
.487 .792 .999 r
.41752 .74315 m .41983 .74216 L .41626 .74228 L F
.41752 .74315 m .41992 .74263 L .41983 .74216 L F
.682 .713 .872 r
.66254 .61472 m .66504 .61534 L .66455 .6151 L F
.651 .112 0 r
.66455 .6151 m .66435 .61542 L .66353 .61461 L F
.66455 .6151 m .66207 .61318 L .66254 .61472 L F
.66455 .6151 m .66353 .61461 L .66207 .61318 L F
.682 .713 .872 r
.66504 .61534 m .66588 .61555 L .66455 .6151 L F
.489 .496 .791 r
.66588 .61555 m .66993 .61451 L .66455 .6151 L F
.66993 .61451 m .66992 .6145 L .66455 .6151 L F
.66588 .61555 m .66855 .61658 L .66998 .61449 L F
.867 .801 .783 r
.66855 .61658 m .66529 .61843 L .66998 .61449 L F
.489 .496 .791 r
.66993 .61451 m .66998 .61449 L .66992 .6145 L F
.757 .689 .786 r
.66998 .61449 m .66529 .61843 L .66435 .61542 L F
.913 .637 .143 r
.66923 .61481 m .66985 .61754 L .66961 .61548 L F
.66904 .61447 m .66915 .61488 L .66923 .61481 L F
.66915 .61488 m .66985 .61754 L .66923 .61481 L F
.065 0 0 r
.66957 .61454 m .66435 .61542 L .66455 .6151 L F
.66992 .6145 m .66954 .61456 L .66957 .61454 L F
.66954 .61456 m .66435 .61542 L .66957 .61454 L F
.66998 .61449 m .66991 .6145 L .66992 .6145 L F
.66991 .6145 m .66435 .61542 L .66992 .6145 L F
.99 .844 .477 r
.66904 .61447 m .66923 .61481 L .66981 .61436 L F
.66923 .61481 m .66961 .61548 L .66977 .61457 L F
.66923 .61481 m .66977 .61457 L .66981 .61436 L F
.66942 .61389 m .66981 .61436 L .67006 .61292 L F
.66904 .61447 m .66981 .61436 L .66942 .61389 L F
.771 .643 .72 r
.68634 .6331 m .6894 .63315 L .68849 .63032 L F
.698 .603 .746 r
.6894 .63315 m .69227 .63104 L .68849 .63032 L F
.498 .106 .227 r
.65235 .63473 m .6554 .6322 L .65378 .63413 L F
.65235 .63473 m .65488 .63461 L .6554 .6322 L F
0 0 0 r
.6554 .6322 m .65704 .63194 L .65773 .63017 L F
0 0 .086 r
.6554 .6322 m .65488 .63461 L .65704 .63194 L F
.591 .601 .83 r
.47672 .73275 m .47339 .73048 L .47552 .72996 L F
.662 .631 .809 r
.47903 .73203 m .47672 .73275 L .47552 .72996 L F
.552 .287 .467 r
.38233 .75931 m .38167 .76158 L .37933 .76178 L F
.21 0 .319 r
.38367 .7589 m .38167 .76158 L .38233 .75931 L F
.527 .652 .914 r
.38284 .77994 m .38088 .78016 L .37926 .77782 L F
.416 .568 .897 r
.68205 .59049 m .68363 .59292 L .6854 .59265 L F
.413 .441 .78 r
.68363 .59292 m .68637 .59415 L .6854 .59265 L F
.898 .985 .784 r
.69939 .63194 m .70042 .63187 L .69902 .63369 L F
.459 .848 .98 r
.70184 .63089 m .70042 .63187 L .69939 .63194 L F
.70184 .63089 m .70273 .63153 L .70042 .63187 L F
.203 0 0 r
.30539 .65699 m .30738 .65667 L .30902 .65546 L F
.067 0 0 r
.30738 .65667 m .311 .65507 L .30902 .65546 L F
.657 .304 .364 r
.48836 .77264 m .48509 .77425 L .48482 .77299 L F
.48836 .77264 m .48703 .77484 L .48509 .77425 L F
.635 .279 .351 r
.49071 .77456 m .48703 .77484 L .48836 .77264 L F
0 .389 .759 r
.39208 .77839 m .39428 .77959 L .3914 .77841 L F
.39208 .77839 m .3914 .77841 L .3902 .77973 L F
.188 .305 .753 r
.64073 .60343 m .64317 .60587 L .6419 .60642 L F
.385 0 .029 r
.64345 .60565 m .64317 .60587 L .6421 .60442 L F
.305 .792 .745 r
.64288 .60608 m .64317 .60587 L .64421 .60562 L F
.385 0 .029 r
.64468 .60676 m .64568 .60612 L .64317 .60587 L F
.64468 .60676 m .64317 .60587 L .64345 .60565 L F
.305 .792 .745 r
.6419 .60642 m .64317 .60587 L .64288 .60608 L F
.264 0 .212 r
.62917 .66505 m .62869 .66717 L .62682 .66799 L F
.242 0 .185 r
.63184 .66284 m .63141 .66474 L .62917 .66505 L F
.373 .084 .338 r
.63141 .66474 m .62869 .66717 L .62917 .66505 L F
.527 .644 .908 r
.68696 .59555 m .68975 .59684 L .68886 .59527 L F
.232 0 0 r
.68975 .59684 m .69198 .59755 L .69168 .59748 L F
.69198 .59755 m .69266 .59777 L .69168 .59748 L F
.472 .882 .747 r
.69279 .59659 m .69134 .5974 L .69168 .59748 L F
.489 0 0 r
.69168 .59748 m .69034 .59797 L .68821 .5971 L F
.472 .882 .747 r
.69134 .5974 m .69034 .59797 L .69168 .59748 L F
.232 0 0 r
.68975 .59684 m .69168 .59748 L .68886 .59527 L F
.676 .876 .974 r
.69913 .602 m .70237 .60172 L .70145 .60138 L F
.549 .368 .588 r
.35939 .74586 m .35726 .74858 L .35936 .74822 L F
.497 .336 .593 r
.35747 .75103 m .35936 .74822 L .35726 .74858 L F
.579 .682 .911 r
.46155 .74021 m .46231 .73768 L .4601 .738 L F
.46155 .74021 m .46367 .73979 L .46231 .73768 L F
.837 .712 .726 r
.61896 .64902 m .62073 .64944 L .61964 .64646 L F
.893 .707 .643 r
.61811 .65121 m .62073 .64944 L .61896 .64902 L F
.61811 .65121 m .62047 .65183 L .62073 .64944 L F
.936 .587 .164 r
.48173 .87437 m .48312 .87727 L .48236 .87658 L F
1 .807 .493 r
.48236 .87658 m .48312 .87727 L .48232 .87906 L F
.439 .057 .217 r
.52542 .77215 m .52789 .77189 L .52841 .77095 L F
.459 0 0 r
.52383 .77189 m .52655 .77159 L .52441 .77198 L F
.52456 .77174 m .52655 .77159 L .52383 .77189 L F
.52343 .77183 m .52456 .77174 L .52383 .77189 L F
.52343 .77183 m .52542 .77215 L .52655 .77159 L F
.439 .057 .217 r
.52542 .77215 m .52896 .76996 L .52655 .77159 L F
.52684 .77127 m .52841 .77095 L .52896 .76996 L F
.52542 .77215 m .52841 .77095 L .52684 .77127 L F
.742 .626 .73 r
.70032 .69514 m .69709 .69432 L .69937 .69385 L F
.70032 .69514 m .69803 .69648 L .69709 .69432 L F
.697 .526 .652 r
.70032 .69514 m .69841 .69765 L .69803 .69648 L F
.638 .767 .941 r
.70252 .69442 m .70032 .69514 L .69937 .69385 L F
.491 .7 .962 r
.68637 .59415 m .68696 .59555 L .68886 .59527 L F
.576 .57 .81 r
.36892 .6675 m .36823 .67097 L .36697 .66782 L F
.36892 .6675 m .37021 .67055 L .36823 .67097 L F
.531 .899 .706 r
.32452 .73154 m .3238 .7319 L .32313 .73262 L F
0 0 0 r
.3238 .7319 m .32159 .73431 L .32313 .73262 L F
.398 .044 .243 r
.6478 .60686 m .64668 .60386 L .64568 .60612 L F
.717 .532 .638 r
.56775 .8013 m .56923 .80435 L .5714 .80146 L F
.598 .45 .651 r
.35113 .76171 m .35327 .7588 L .35124 .75928 L F
.116 .101 .562 r
.33148 .79683 m .33252 .79606 L .33231 .79353 L F
.102 0 .407 r
.33115 .7991 m .33252 .79606 L .33148 .79683 L F
.856 .859 .842 r
.53432 .84745 m .53566 .84828 L .53728 .8464 L F
.728 .523 .614 r
.70147 .70035 m .69835 .70214 L .69828 .70002 L F
.70147 .70035 m .70148 .70234 L .69835 .70214 L F
.568 .394 .606 r
.70374 .69994 m .70148 .70234 L .70147 .70035 L F
.323 0 .008 r
.31826 .71631 m .32197 .71445 L .31887 .71561 L F
.31826 .71631 m .3203 .71603 L .32197 .71445 L F
.265 0 0 r
.32197 .71445 m .32321 .71483 L .32395 .71372 L F
.32197 .71445 m .3203 .71603 L .32321 .71483 L F
.614 .645 .857 r
.48004 .74915 m .48355 .75136 L .48282 .75024 L F
.603 .674 .891 r
.48282 .75024 m .48355 .75136 L .48572 .75094 L F
.537 .416 .662 r
.33613 .70292 m .3382 .70247 L .33782 .70004 L F
.504 .313 .556 r
.33613 .70292 m .33798 .70496 L .3382 .70247 L F
.33613 .70292 m .33597 .70545 L .33798 .70496 L F
.489 .094 .218 r
.4289 .77496 m .43111 .77495 L .43231 .77288 L F
.366 0 .152 r
.43231 .77288 m .43329 .77453 L .43454 .77293 L F
.43231 .77288 m .43111 .77495 L .43329 .77453 L F
.6 .753 .951 r
.47552 .72996 m .47339 .73048 L .4722 .7292 L F
.945 .8 .669 r
.62 .64234 m .62175 .64144 L .6205 .64057 L F
.62 .64234 m .62138 .64335 L .62175 .64144 L F
.429 .181 .435 r
.52638 .77886 m .52564 .778 L .52746 .77734 L F
.52638 .77886 m .52518 .77979 L .52564 .778 L F
0 0 .018 r
.63352 .66156 m .63141 .66474 L .63184 .66284 L F
.326 .515 .889 r
.45827 .73757 m .45916 .73629 L .45684 .7368 L F
.45827 .73757 m .4601 .738 L .45916 .73629 L F
.734 .603 .711 r
.48257 .76182 m .48594 .762 L .48498 .7587 L F
.76 .562 .63 r
.48251 .76427 m .48594 .762 L .48257 .76182 L F
.48251 .76427 m .48589 .76447 L .48594 .762 L F
.677 .57 .727 r
.48498 .7587 m .48594 .762 L .48835 .76165 L F
.765 .637 .72 r
.48589 .76447 m .48835 .76165 L .48594 .762 L F
.589 .634 .864 r
.36135 .80838 m .36271 .80913 L .36389 .80769 L F
.36271 .80913 m .36457 .81016 L .36394 .80787 L F
.36271 .80913 m .36394 .80787 L .36389 .80769 L F
.668 .26 .262 r
.36405 .80776 m .36192 .80903 L .36389 .80769 L F
.36648 .80894 m .36305 .80901 L .36405 .80776 L F
.36305 .80901 m .36192 .80903 L .36405 .80776 L F
.23 0 .249 r
.36441 .80731 m .36672 .80473 L .36546 .8063 L F
.36377 .80793 m .36489 .80671 L .36441 .80731 L F
.36489 .80671 m .36672 .80473 L .36441 .80731 L F
.36487 .80691 m .36546 .8063 L .36527 .80654 L F
.36377 .80793 m .36546 .8063 L .36487 .80691 L F
.979 .752 .525 r
.36888 .80452 m .36527 .80654 L .36672 .80473 L F
.511 .251 .457 r
.33342 .70779 m .33597 .70545 L .33399 .70596 L F
.685 .643 .802 r
.70085 .72649 m .70209 .72946 L .70427 .72691 L F
.582 .489 .714 r
.70209 .72946 m .7039 .73015 L .70427 .72691 L F
.733 .728 .846 r
.68399 .62218 m .68729 .62259 L .68566 .62185 L F
.903 .749 .679 r
.68459 .6239 m .68729 .62259 L .68399 .62218 L F
.347 0 0 r
.69192 .64588 m .69492 .64549 L .69403 .64535 L F
.583 .912 .976 r
.69492 .64549 m .6968 .64426 L .69403 .64535 L F
.69492 .64549 m .69766 .64473 L .6968 .64426 L F
.178 0 0 r
.51999 .774 m .52152 .77297 L .51911 .77344 L F
.51999 .774 m .51911 .77344 L .51805 .77202 L F
.335 0 0 r
.48996 .88213 m .49095 .88272 L .48853 .88251 L F
0 .521 .744 r
.49095 .88272 m .48918 .88244 L .48853 .88251 L F
.283 .037 .354 r
.48853 .88251 m .48788 .88258 L .48996 .88213 L F
0 .521 .744 r
.48918 .88244 m .48701 .8821 L .48853 .88251 L F
.283 .037 .354 r
.48853 .88251 m .48727 .88272 L .48788 .88258 L F
.335 0 0 r
.48996 .88213 m .4923 .88274 L .49095 .88272 L F
0 0 0 r
.72373 .62265 m .72304 .6245 L .72299 .62438 L F
.172 0 .093 r
.72495 .62351 m .72373 .62265 L .72492 .62128 L F
.72495 .62351 m .72304 .6245 L .72373 .62265 L F
.873 .749 .239 r
.66955 .60849 m .66953 .61112 L .67255 .60846 L F
.66955 .60849 m .66927 .61098 L .66953 .61112 L F
0 0 .257 r
.67006 .61292 m .66953 .61112 L .66927 .61098 L F
.67006 .61292 m .67018 .61488 L .66953 .61112 L F
.508 .396 .662 r
.34921 .68707 m .35138 .68878 L .3512 .68597 L F
.34921 .68707 m .34954 .6893 L .35138 .68878 L F
.417 .54 .873 r
.36 .66071 m .36251 .6619 L .36078 .66186 L F
.52 .333 .568 r
.72119 .60084 m .72335 .60013 L .72117 .5984 L F
.72117 .5984 m .72335 .60013 L .72119 .60084 L F
.72119 .60084 m .72117 .5984 L .72229 .59701 L F
0 0 0 r
.72229 .59701 m .72117 .5984 L .72105 .59867 L F
.799 .804 .856 r
.65778 .64516 m .66127 .64424 L .66021 .6428 L F
.7 .776 .911 r
.66021 .6428 m .66127 .64424 L .66323 .64307 L F
0 0 0 r
.40171 .79385 m .40058 .79391 L .40251 .79338 L F
.40171 .79385 m .3998 .79454 L .40058 .79391 L F
.65 .443 .59 r
.59801 .67516 m .59459 .67337 L .59789 .67336 L F
.689 .393 .468 r
.59789 .67336 m .60011 .67552 L .59801 .67516 L F
.657 .4 .52 r
.60015 .67347 m .60011 .67552 L .59789 .67336 L F
.44 .2 .453 r
.3112 .67846 m .311 .68096 L .30868 .68118 L F
.552 .293 .476 r
.31295 .68008 m .3112 .67846 L .31323 .67819 L F
.31295 .68008 m .311 .68096 L .3112 .67846 L F
.625 .439 .611 r
.33687 .7834 m .33897 .78559 L .3391 .78317 L F
.33687 .7834 m .33683 .78578 L .33897 .78559 L F
.645 .421 .564 r
.62185 .66795 m .62187 .67026 L .61873 .67059 L F
.593 .337 .498 r
.62416 .66813 m .62187 .67026 L .62185 .66795 L F
.204 0 .296 r
.33201 .70858 m .33131 .71056 L .33342 .70779 L F
.258 .738 .933 r
.37446 .80187 m .3765 .80178 L .37308 .80148 L F
.471 .325 .6 r
.35939 .74586 m .3613 .74543 L .36127 .74299 L F
.477 .344 .62 r
.35939 .74586 m .36136 .74783 L .3613 .74543 L F
.523 .347 .584 r
.35936 .74822 m .36136 .74783 L .35939 .74586 L F
0 0 0 r
.37055 .73704 m .37121 .73491 L .37074 .73457 L F
.37055 .73704 m .37365 .73521 L .37121 .73491 L F
.819 .691 .723 r
.60081 .64932 m .59797 .64915 L .59961 .64618 L F
.82 .688 .719 r
.60081 .64932 m .59904 .65208 L .59797 .64915 L F
.709 .454 .538 r
.4969 .77288 m .49568 .77524 L .49382 .77261 L F
.721 .469 .544 r
.49924 .77508 m .49568 .77524 L .4969 .77288 L F
.409 .01 .168 r
.38324 .73192 m .38533 .73162 L .38661 .72971 L F
.42 .007 .147 r
.38533 .73162 m .3888 .72955 L .38661 .72971 L F
.614 .575 .787 r
.47719 .74821 m .4789 .74581 L .47608 .74525 L F
.47719 .74821 m .47948 .74803 L .4789 .74581 L F
.582 .607 .843 r
.47719 .74821 m .48004 .74915 L .47948 .74803 L F
.317 0 .057 r
.31033 .68155 m .30868 .68118 L .311 .68096 L F
.31033 .68155 m .30742 .68283 L .30868 .68118 L F
.27 0 0 r
.37363 .67315 m .37589 .67353 L .3771 .67346 L F
.702 .577 .711 r
.37634 .67041 m .3771 .67346 L .37924 .67075 L F
.005 .274 .775 r
.37779 .6726 m .3771 .67346 L .37589 .67353 L F
.37779 .6726 m .37916 .67527 L .3771 .67346 L F
.457 .363 .661 r
.3771 .67346 m .37916 .67527 L .37746 .67563 L F
.633 .915 .98 r
.63419 .64991 m .63608 .64899 L .63721 .64964 L F
.23 0 0 r
.63818 .65043 m .63721 .64964 L .63608 .64899 L F
.63818 .65043 m .63949 .64926 L .63721 .64964 L F
.182 .714 .737 r
.40828 .7805 m .40617 .78095 L .40429 .78124 L F
.353 .826 .877 r
.39642 .74998 m .39509 .74995 L .39311 .75051 L F
.097 .638 .847 r
.39642 .74998 m .39719 .74971 L .39509 .74995 L F
.39642 .74998 m .39924 .75017 L .39719 .74971 L F
.367 .222 .549 r
.64067 .61627 m .63838 .61978 L .63969 .61779 L F
.648 .959 .772 r
.71942 .61908 m .72039 .61791 L .72232 .61716 L F
.503 .498 .784 r
.72142 .61403 m .72232 .61716 L .72383 .61561 L F
.677 .969 .775 r
.72232 .61716 m .72039 .61791 L .72383 .61561 L F
.506 .504 .788 r
.72383 .61561 m .72411 .61727 L .72232 .61716 L F
0 .202 .704 r
.6868 .64364 m .6881 .64431 L .68545 .6432 L F
.6868 .64364 m .68892 .64531 L .6881 .64431 L F
.95 .666 .466 r
.70078 .62014 m .70052 .62097 L .69988 .61999 L F
.292 0 .247 r
.70279 .61929 m .70052 .62097 L .70078 .62014 L F
.665 .882 .979 r
.44661 .72496 m .44382 .72509 L .44563 .72484 L F
.551 .03 0 r
.44563 .72484 m .44919 .72529 L .44661 .72496 L F
.675 .835 .96 r
.65773 .58712 m .6557 .58716 L .65658 .58713 L F
.247 0 .281 r
.65754 .58709 m .65658 .58713 L .65597 .58884 L F
.04 0 0 r
.65658 .58713 m .65931 .58717 L .65773 .58712 L F
.617 .832 .982 r
.65832 .58622 m .65931 .58717 L .65658 .58713 L F
.65832 .58622 m .65931 .58717 L .65658 .58713 L F
.247 0 .281 r
.65832 .58622 m .65658 .58713 L .65754 .58709 L F
.675 .835 .96 r
.6557 .58716 m .6538 .5872 L .65658 .58713 L F
.315 .667 .974 r
.33653 .65141 m .33607 .6524 L .3348 .6512 L F
.33653 .65141 m .33819 .65263 L .33607 .6524 L F
.776 .271 0 r
.7186 .74286 m .71529 .74006 L .71835 .74047 L F
.78 .535 .566 r
.64416 .61202 m .64583 .61561 L .64214 .61415 L F
.324 .102 .414 r
.64742 .60837 m .64416 .61202 L .64527 .60881 L F
.64742 .60837 m .64737 .61092 L .64416 .61202 L F
.296 .043 .35 r
.64416 .61202 m .64703 .61257 L .64583 .61561 L F
.64416 .61202 m .64737 .61092 L .64703 .61257 L F
.464 0 0 r
.65382 .60447 m .65514 .60374 L .65201 .60377 L F
0 0 0 r
.65709 .60297 m .65514 .60374 L .65382 .60447 L F
.65715 .60294 m .65514 .60374 L .65709 .60297 L F
.65728 .60288 m .65666 .60317 L .65607 .60394 L F
.65666 .60317 m .65382 .60447 L .65607 .60394 L F
.216 0 0 r
.65607 .60394 m .65343 .60523 L .65574 .60467 L F
.993 .744 .42 r
.65572 .6044 m .65607 .60394 L .65574 .60467 L F
.216 0 0 r
.65607 .60394 m .65382 .60447 L .65343 .60523 L F
.993 .744 .42 r
.65548 .60047 m .65607 .60394 L .65572 .6044 L F
.65548 .60047 m .65643 .60213 L .65615 .60353 L F
.65602 .60361 m .65615 .60353 L .65607 .60394 L F
.65548 .60047 m .65615 .60353 L .65602 .60361 L F
0 0 0 r
.65728 .60288 m .65715 .60294 L .65709 .60297 L F
.546 .902 .691 r
.36527 .80654 m .36389 .80769 L .36377 .80793 L F
.188 0 .029 r
.64347 .65629 m .64153 .65701 L .64391 .65539 L F
.053 0 0 r
.64579 .65543 m .64347 .65629 L .64391 .65539 L F
.575 .805 .986 r
.56799 .80373 m .56775 .8013 L .56681 .80225 L F
.56799 .80373 m .56923 .80435 L .56775 .8013 L F
.215 0 0 r
.43741 .77192 m .43884 .77217 L .44016 .77044 L F
.421 .045 .218 r
.43884 .77217 m .44206 .76965 L .44016 .77044 L F
.779 .767 .842 r
.69833 .63579 m .69526 .63562 L .69766 .63335 L F
.927 .836 .734 r
.69902 .63369 m .69833 .63579 L .69766 .63335 L F
.652 .705 .886 r
.7103 .60106 m .71348 .60274 L .7125 .6001 L F
.603 .596 .817 r
.71348 .60274 m .71485 .5997 L .7125 .6001 L F
.71348 .60274 m .71582 .60229 L .71485 .5997 L F
.927 .836 .734 r
.69902 .63369 m .69766 .63335 L .69939 .63194 L F
.747 .459 .494 r
.49382 .77261 m .49568 .77524 L .49424 .77466 L F
.573 .444 .667 r
.34524 .77021 m .34751 .77219 L .34742 .76978 L F
.34524 .77021 m .34541 .77254 L .34751 .77219 L F
.996 .765 .431 r
.65909 .60884 m .65973 .61153 L .6589 .6104 L F
.816 .486 .429 r
.66207 .61318 m .6589 .6104 L .65973 .61153 L F
.999 .803 .505 r
.6782 .62798 m .67716 .62949 L .67687 .62697 L F
.6782 .62798 m .67799 .63025 L .67716 .62949 L F
.767 .544 .596 r
.65078 .58737 m .6538 .5872 L .6538 .58487 L F
.573 .41 .623 r
.37546 .77219 m .37351 .77529 L .37358 .77259 L F
.663 .413 .531 r
.61414 .67067 m .61328 .67312 L .61106 .67299 L F
.666 .416 .533 r
.61653 .67276 m .61414 .67067 L .6165 .67047 L F
.61653 .67276 m .61328 .67312 L .61414 .67067 L F
.462 .542 .852 r
.43656 .73948 m .43699 .73705 L .43588 .7383 L F
.43656 .73948 m .43798 .73978 L .43699 .73705 L F
.715 .663 .797 r
.70148 .70234 m .69982 .70394 L .69835 .70214 L F
.655 .559 .734 r
.50029 .87934 m .49796 .88307 L .49728 .88262 L F
.50029 .87934 m .5013 .88301 L .49796 .88307 L F
.214 0 0 r
.5013 .88301 m .49728 .88262 L .49796 .88307 L F
.413 .542 .877 r
.36443 .6618 m .36337 .66342 L .36251 .6619 L F
.36443 .6618 m .36597 .66436 L .36337 .66342 L F
.392 .098 .342 r
.62667 .65452 m .62879 .65392 L .62922 .65141 L F
.208 0 .284 r
.62922 .65141 m .63044 .65278 L .63131 .65101 L F
.62922 .65141 m .62879 .65392 L .63044 .65278 L F
.469 0 .057 r
.43681 .78015 m .4375 .78173 L .43535 .78209 L F
.43681 .78015 m .43886 .78035 L .4375 .78173 L F
.518 .868 .989 r
.69766 .64473 m .69888 .64356 L .6968 .64426 L F
.69766 .64473 m .69992 .64415 L .69888 .64356 L F
.614 .58 .792 r
.48451 .757 m .48498 .7587 L .48669 .75653 L F
.603 .564 .783 r
.48498 .7587 m .48744 .75866 L .48669 .75653 L F
.677 .57 .727 r
.48498 .7587 m .48835 .76165 L .48744 .75866 L F
.507 .267 .486 r
.37522 .68339 m .37351 .68177 L .37538 .68115 L F
.37522 .68339 m .373 .68392 L .37351 .68177 L F
.65 .443 .59 r
.59801 .67516 m .59473 .6757 L .59459 .67337 L F
0 0 .139 r
.59459 .67337 m .59489 .67399 L .59606 .67211 L F
.59459 .67337 m .59473 .6757 L .59489 .67399 L F
.284 .137 .497 r
.72646 .6157 m .72411 .61727 L .72439 .61438 L F
.787 .573 .611 r
.69803 .69648 m .69546 .69736 L .69709 .69432 L F
.69803 .69648 m .69841 .69765 L .69546 .69736 L F
.993 .762 .48 r
.67325 .628 m .67406 .62689 L .67334 .62841 L F
.67314 .62815 m .674 .63001 L .67401 .62935 L F
.67343 .62833 m .67401 .62935 L .67406 .62689 L F
.841 .971 .658 r
.67406 .62689 m .6746 .6273 L .67343 .62833 L F
.67406 .62689 m .67343 .62833 L .67334 .62841 L F
.993 .762 .48 r
.67325 .628 m .67343 .62833 L .67406 .62689 L F
.69 .754 .9 r
.67325 .628 m .67334 .62841 L .67343 .62833 L F
.958 .689 .246 r
.67314 .62815 m .67334 .62841 L .67232 .62592 L F
.993 .762 .48 r
.67314 .62815 m .67325 .628 L .67334 .62841 L F
.67314 .62815 m .67401 .62935 L .67325 .628 L F
.69 .754 .9 r
.67285 .62624 m .67325 .628 L .6746 .6273 L F
.67325 .628 m .67343 .62833 L .6746 .6273 L F
.67232 .62592 m .67334 .62841 L .67285 .62624 L F
.334 0 0 r
.41835 .72354 m .42041 .72376 L .42191 .72338 L F
.595 .08 0 r
.42041 .72376 m .42382 .72414 L .42191 .72338 L F
.331 .305 .679 r
.48162 .88242 m .48232 .87906 L .48059 .8804 L F
.457 .094 .26 r
.39397 .79628 m .39196 .79693 L .39253 .79642 L F
.554 .407 .636 r
.35326 .75653 m .35532 .75619 L .35515 .75365 L F
.536 .364 .596 r
.35326 .75653 m .35527 .75839 L .35532 .75619 L F
.35326 .75653 m .35327 .7588 L .35527 .75839 L F
.727 .284 .201 r
.70815 .69421 m .71051 .69635 L .71127 .69493 L F
.848 .441 .267 r
.71051 .69635 m .71229 .69672 L .71127 .69493 L F
.908 .835 .762 r
.72382 .73886 m .72652 .73739 L .72523 .73694 L F
.72382 .73886 m .7252 .73986 L .72652 .73739 L F
.594 .589 .816 r
.50122 .7463 m .49941 .74866 L .49887 .74698 L F
.718 .711 .843 r
.50122 .7463 m .50017 .74907 L .49941 .74866 L F
.665 .681 .855 r
.71663 .60389 m .718 .60048 L .71582 .60229 L F
.71663 .60389 m .71877 .60312 L .718 .60048 L F
.419 .009 .152 r
.39091 .72927 m .39301 .72901 L .39433 .72719 L F
.457 .048 .175 r
.39433 .72719 m .39608 .72802 L .39649 .72696 L F
.39433 .72719 m .39301 .72901 L .39608 .72802 L F
.479 .238 .47 r
.52518 .77979 m .52259 .78153 L .52319 .78035 L F
.407 .564 .898 r
.47117 .72741 m .47031 .72896 L .46886 .72744 L F
.47117 .72741 m .4722 .7292 L .47031 .72896 L F
.696 .571 .71 r
.71744 .72355 m .71905 .7211 L .71725 .72183 L F
.71744 .72355 m .72061 .72443 L .71905 .7211 L F
.874 .751 .723 r
.61831 .64532 m .62138 .64335 L .62 .64234 L F
.61831 .64532 m .61964 .64646 L .62138 .64335 L F
.618 .558 .765 r
.63798 .61045 m .6378 .61313 L .6366 .61119 L F
.63798 .61045 m .64011 .61324 L .6378 .61313 L F
.507 .795 .997 r
.45662 .72604 m .45576 .72725 L .45454 .7263 L F
.45662 .72604 m .45788 .7269 L .45576 .72725 L F
.498 .214 .414 r
.36447 .69242 m .36392 .69422 L .36186 .69448 L F
.504 .247 .459 r
.36631 .69192 m .36392 .69422 L .36447 .69242 L F
.59 .913 .977 r
.3765 .80178 m .37953 .80128 L .37853 .80133 L F
.363 .823 .732 r
.37953 .80128 m .38049 .80071 L .37853 .80133 L F
.777 .952 .931 r
.401 .75008 m .40179 .75057 L .40476 .74869 L F
.014 0 0 r
.42382 .72414 m .42588 .72403 L .42724 .72386 L F
.214 .721 .897 r
.42588 .72403 m .42927 .72422 L .42724 .72386 L F
.851 .672 .66 r
.6879 .62646 m .69015 .62702 L .6906 .62515 L F
.796 .562 .583 r
.51516 .82748 m .5166 .82606 L .51449 .82544 L F
.51516 .82748 m .51657 .82884 L .5166 .82606 L F
.5166 .82606 m .51657 .82884 L .51516 .82748 L F
.678 .45 .568 r
.5132 .82348 m .51322 .82629 L .51449 .82544 L F
.598 .447 .647 r
.34541 .77254 m .34335 .77527 L .34556 .77497 L F
.568 .419 .639 r
.34335 .77527 m .34561 .77726 L .34556 .77497 L F
.34335 .77527 m .34351 .77768 L .34561 .77726 L F
.844 .691 .692 r
.64073 .60343 m .64119 .60122 L .63945 .60056 L F
.655 .325 .403 r
.35907 .81011 m .35515 .81158 L .35816 .81181 L F
0 0 0 r
.32936 .71107 m .32948 .71185 L .33131 .71056 L F
.32936 .71107 m .32781 .71258 L .32948 .71185 L F
.756 .674 .771 r
.33941 .80512 m .34035 .80174 L .33834 .80461 L F
.678 .738 .896 r
.49775 .74339 m .49597 .74531 L .49438 .74275 L F
.406 .175 .448 r
.3523 .70512 m .3525 .70752 L .35045 .70769 L F
.43 .195 .455 r
.35496 .70221 m .35476 .7051 L .3523 .70512 L F
.436 .2 .456 r
.35476 .7051 m .3525 .70752 L .3523 .70512 L F
.533 .379 .617 r
.34714 .76743 m .34928 .76738 L .34908 .7644 L F
.629 .46 .634 r
.34714 .76743 m .34971 .76951 L .34928 .76738 L F
.34714 .76743 m .34742 .76978 L .34971 .76951 L F
.675 .155 0 r
.48509 .77425 m .48136 .77245 L .48482 .77299 L F
.812 .644 .675 r
.60345 .66017 m .60048 .6599 L .60186 .657 L F
.833 .817 .834 r
.60345 .66017 m .59958 .66201 L .60048 .6599 L F
.547 .179 .294 r
.46051 .76633 m .46273 .76644 L .46382 .76425 L F
.455 .116 .301 r
.46273 .76644 m .46604 .76366 L .46382 .76425 L F
.939 .636 .438 r
.51899 .76649 m .52059 .7673 L .51972 .76469 L F
.817 .466 .391 r
.51668 .76395 m .51941 .76546 L .51972 .76469 L F
.51941 .76546 m .52045 .76603 L .51972 .76469 L F
.27 .256 .659 r
.51972 .76469 m .52045 .76603 L .52137 .76401 L F
.735 .803 .906 r
.52137 .76401 m .52045 .76603 L .51957 .76544 L F
.939 .636 .438 r
.51982 .76524 m .51972 .76469 L .52137 .76401 L F
.51935 .76542 m .51941 .76546 L .51972 .76469 L F
.51935 .76542 m .51972 .76469 L .51986 .76546 L F
.735 .803 .906 r
.52137 .76401 m .51957 .76544 L .51756 .76409 L F
.939 .636 .438 r
.51986 .76546 m .51982 .76524 L .52137 .76401 L F
.51885 .76643 m .51899 .76649 L .51941 .76546 L F
.51885 .76643 m .51941 .76546 L .51935 .76542 L F
.51885 .76643 m .51935 .76542 L .51986 .76546 L F
0 .421 .825 r
.51936 .76542 m .52045 .76603 L .51941 .76546 L F
.51756 .76409 m .51957 .76544 L .51936 .76542 L F
.51957 .76544 m .52045 .76603 L .51936 .76542 L F
.51734 .76406 m .51941 .76546 L .51668 .76395 L F
.51756 .76409 m .51941 .76546 L .51734 .76406 L F
.782 .924 .931 r
.69739 .62159 m .69566 .62309 L .69514 .62279 L F
.69739 .62159 m .69566 .62309 L .69514 .62279 L F
.411 .078 .288 r
.34315 .71793 m .34203 .7168 L .34373 .71601 L F
.34315 .71793 m .34116 .71836 L .34203 .7168 L F
.619 .776 .956 r
.7079 .62187 m .71187 .62215 L .70975 .62304 L F
.616 .823 .98 r
.70975 .62304 m .71187 .62215 L .70759 .62226 L F
.518 .547 .825 r
.64655 .62162 m .64675 .62078 L .64334 .61874 L F
.903 .937 .823 r
.64522 .62266 m .64675 .62078 L .64655 .62162 L F
.743 .666 .775 r
.64426 .62266 m .64544 .62335 L .64585 .62471 L F
.64426 .62266 m .64655 .62162 L .64746 .62451 L F
.903 .937 .823 r
.64404 .62359 m .64655 .62162 L .64426 .62266 L F
.64404 .62359 m .64515 .62245 L .64522 .62266 L F
.64515 .62245 m .64675 .62078 L .64522 .62266 L F
.743 .666 .775 r
.64544 .62335 m .64746 .62451 L .64589 .62471 L F
.64544 .62335 m .64589 .62471 L .64585 .62471 L F
.163 0 .053 r
.64746 .62451 m .64509 .62671 L .64585 .62471 L F
.506 .555 .839 r
.49123 .8803 m .48804 .87769 L .49044 .87999 L F
.236 .338 .765 r
.48939 .87647 m .49044 .87999 L .48804 .87769 L F
.377 0 .012 r
.45511 .77522 m .45403 .77611 L .45214 .77612 L F
.273 0 0 r
.45619 .77595 m .45511 .77522 L .45742 .77487 L F
.45619 .77595 m .45403 .77611 L .45511 .77522 L F
.251 0 0 r
.31884 .67598 m .31732 .67753 L .31529 .67796 L F
.57 .212 .322 r
.32084 .67544 m .31732 .67753 L .31884 .67598 L F
.339 0 0 r
.70044 .597 m .7041 .59744 L .70092 .59684 L F
.796 .676 .731 r
.70645 .7242 m .70939 .72482 L .70839 .72147 L F
.791 .688 .751 r
.70645 .7242 m .70768 .72729 L .70939 .72482 L F
.302 .366 .763 r
.70839 .72147 m .70939 .72482 L .71086 .72351 L F
.524 .76 .983 r
.70939 .72482 m .71215 .72466 L .71086 .72351 L F
.339 .002 .238 r
.31395 .65374 m .31573 .65318 L .31631 .65203 L F
.05 0 0 r
.31573 .65318 m .31863 .65218 L .31631 .65203 L F
.621 .496 .688 r
.37767 .7663 m .37574 .76969 L .37503 .76721 L F
.37767 .7663 m .37786 .76945 L .37574 .76969 L F
.558 .344 .545 r
.37786 .76945 m .37546 .77219 L .37574 .76969 L F
.991 .78 .396 r
.6654 .62509 m .66475 .62422 L .66492 .622 L F
.715 .665 .799 r
.67662 .71636 m .67772 .71938 L .67971 .71859 L F
.756 .539 .602 r
.65999 .5985 m .65929 .60024 L .65624 .60045 L F
.467 .279 .542 r
.37933 .76178 m .37918 .76412 L .37733 .7645 L F
.428 .299 .602 r
.37918 .76412 m .37767 .7663 L .37733 .7645 L F
.112 0 0 r
.34818 .8103 m .34822 .81092 L .34682 .81033 L F
.34818 .8103 m .35019 .81001 L .34822 .81092 L F
.689 .662 .818 r
.71905 .7211 m .72302 .72133 L .72153 .71871 L F
.707 .576 .705 r
.71905 .7211 m .72061 .72443 L .72302 .72133 L F
.624 .581 .786 r
.48744 .75866 m .48835 .76165 L .49027 .75925 L F
.601 .548 .767 r
.49027 .75925 m .48835 .76165 L .49053 .76121 L F
.617 .553 .76 r
.48835 .76165 m .49142 .76444 L .49053 .76121 L F
.654 .712 .89 r
.44929 .73753 m .45277 .73846 L .45154 .73678 L F
.677 .72 .882 r
.45154 .73678 m .45277 .73846 L .45479 .73754 L F
.39 .482 .833 r
.43533 .73682 m .43588 .7383 L .43699 .73705 L F
.47 .557 .862 r
.72153 .71871 m .72302 .72133 L .72449 .7198 L F
.464 .546 .856 r
.72302 .72133 m .72501 .72163 L .72449 .7198 L F
.569 .432 .654 r
.34159 .78041 m .3436 .78007 L .34351 .77768 L F
.659 .513 .673 r
.34133 .78283 m .3436 .78007 L .34159 .78041 L F
0 0 0 r
.31366 .7178 m .31395 .71755 L .31245 .7179 L F
.31366 .7178 m .31565 .71748 L .31395 .71755 L F
.251 0 0 r
.31395 .71755 m .31565 .71748 L .31641 .71675 L F
.665 .549 .714 r
.68387 .69747 m .68513 .70087 L .6873 .70019 L F
.595 .531 .752 r
.55567 .8019 m .55792 .80379 L .55878 .80159 L F
.65 .451 .602 r
.55792 .80379 m .56108 .80169 L .55878 .80159 L F
.617 .058 0 r
.41626 .74228 m .41477 .74214 L .41437 .7426 L F
.638 .382 .514 r
.36805 .7359 m .37055 .73704 L .37074 .73457 L F
.666 .551 .715 r
.68513 .70087 m .68507 .70284 L .6873 .70019 L F
.626 .494 .682 r
.6873 .70019 m .68507 .70284 L .68742 .70239 L F
.648 .582 .766 r
.68507 .70284 m .68842 .70548 L .68742 .70239 L F
.464 .249 .502 r
.35728 .69977 m .35665 .70185 L .35496 .70221 L F
.453 .215 .461 r
.35665 .70185 m .35476 .7051 L .35496 .70221 L F
.787 .652 .714 r
.67846 .71553 m .68055 .71675 L .68192 .71374 L F
.015 .425 .863 r
.72616 .71473 m .72688 .71568 L .72631 .71464 L F
.746 .485 .537 r
.50799 .77771 m .50485 .77532 L .50806 .77525 L F
.355 0 .07 r
.64153 .65701 m .64056 .65863 L .63831 .65902 L F
.195 0 0 r
.64254 .65785 m .64153 .65701 L .64347 .65629 L F
.64254 .65785 m .64056 .65863 L .64153 .65701 L F
.436 .826 .601 r
.688 .63185 m .68634 .6331 L .68849 .63032 L F
0 0 0 r
.68949 .62946 m .68849 .63032 L .69015 .62702 L F
.688 .63185 m .68849 .63032 L .68949 .62946 L F
.743 .61 .711 r
.70552 .72968 m .70767 .73018 L .70768 .72729 L F
.752 .425 .431 r
.70552 .72968 m .70763 .73193 L .70767 .73018 L F
.444 .686 .968 r
.73197 .73091 m .73034 .73206 L .72899 .73136 L F
.73197 .73091 m .73275 .73209 L .73034 .73206 L F
.549 .44 .683 r
.37351 .77529 m .3739 .77773 L .37183 .77806 L F
.433 .461 .789 r
.49136 .74229 m .48998 .74354 L .48885 .74019 L F
.514 .6 .877 r
.49136 .74229 m .49226 .74355 L .48998 .74354 L F
.721 .662 .79 r
.73287 .74159 m .72965 .74104 L .7323 .74113 L F
0 .316 .691 r
.73356 .74184 m .73287 .74159 L .7323 .74113 L F
.73356 .74184 m .73531 .74272 L .73287 .74159 L F
.567 .741 .958 r
.3456 .6534 m .345 .65524 L .34373 .65343 L F
.3456 .6534 m .34708 .65477 L .345 .65524 L F
.631 .575 .774 r
.68742 .70239 m .68842 .70548 L .6908 .70497 L F
.747 .49 .543 r
.48049 .76168 m .48251 .76427 L .48257 .76182 L F
0 0 0 r
.37055 .73704 m .37199 .73654 L .37365 .73521 L F
.319 0 0 r
.37199 .73654 m .37563 .73485 L .37365 .73521 L F
.485 .107 .247 r
.51777 .78487 m .51826 .78364 L .52002 .78477 L F
.474 .117 .28 r
.51826 .78364 m .52036 .78341 L .52002 .78477 L F
.074 0 0 r
.63671 .62168 m .63589 .62242 L .63298 .6236 L F
.573 .43 .648 r
.63838 .61978 m .63895 .62192 L .63671 .62168 L F
.666 .902 .979 r
.63895 .62192 m .63589 .62242 L .63671 .62168 L F
.245 0 0 r
.311 .65507 m .31311 .65462 L .31395 .65374 L F
.139 0 0 r
.31395 .65374 m .31504 .65402 L .31573 .65318 L F
.31395 .65374 m .31311 .65462 L .31504 .65402 L F
.777 .952 .931 r
.401 .75008 m .40476 .74869 L .40278 .74963 L F
.06 .573 .88 r
.70495 .63188 m .70273 .63153 L .70184 .63089 L F
0 0 0 r
.73041 .74505 m .72992 .74546 L .72757 .74609 L F
.522 .912 .927 r
.73254 .74423 m .73168 .7441 L .73041 .74505 L F
0 0 0 r
.73168 .7441 m .72992 .74546 L .73041 .74505 L F
.655 .399 .52 r
.60211 .67542 m .60015 .67347 L .60411 .67299 L F
.60211 .67542 m .60011 .67552 L .60015 .67347 L F
.709 .446 .526 r
.47704 .76365 m .48049 .76168 L .47714 .76187 L F
.47704 .76365 m .47938 .76438 L .48049 .76168 L F
.747 .49 .543 r
.48049 .76168 m .47938 .76438 L .48251 .76427 L F
.769 .608 .68 r
.60217 .65468 m .59866 .6565 L .59865 .65434 L F
.60217 .65468 m .60186 .657 L .59866 .6565 L F
.646 .535 .715 r
.50359 .75592 m .50121 .75651 L .5009 .75438 L F
.628 .563 .762 r
.50449 .75933 m .50121 .75651 L .50359 .75592 L F
.752 .67 .771 r
.70427 .72691 m .70768 .72729 L .70645 .7242 L F
.737 .628 .739 r
.70427 .72691 m .70552 .72968 L .70768 .72729 L F
.179 0 0 r
.73456 .73565 m .73301 .73648 L .73087 .73671 L F
.479 .54 .842 r
.73553 .73468 m .73456 .73565 L .73275 .73209 L F
.3 .261 .647 r
.73553 .73468 m .73625 .73687 L .73456 .73565 L F
0 0 0 r
.73475 .73601 m .73456 .73565 L .73553 .73468 L F
.73475 .73601 m .73301 .73648 L .73456 .73565 L F
.94 .946 .76 r
.7263 .61119 m .72519 .61271 L .727 .61207 L F
.611 .938 .732 r
.70778 .63903 m .70623 .63983 L .70507 .64114 L F
.59 .929 .727 r
.70908 .63766 m .70778 .63903 L .7093 .63782 L F
.70908 .63766 m .70623 .63983 L .70778 .63903 L F
.07 0 0 r
.70507 .64114 m .70234 .64349 L .70233 .64317 L F
.70507 .64114 m .70421 .64262 L .70234 .64349 L F
0 0 0 r
.70623 .63983 m .70421 .64262 L .70507 .64114 L F
.514 .631 .904 r
.3515 .81205 m .35188 .80985 L .35019 .81001 L F
.3515 .81205 m .35349 .81225 L .35188 .80985 L F
.6 .506 .72 r
.50228 .75069 m .5009 .75438 L .49999 .7512 L F
.50228 .75069 m .5031 .75395 L .5009 .75438 L F
.646 .535 .715 r
.50359 .75592 m .5009 .75438 L .5031 .75395 L F
.379 .012 .209 r
.30051 .65949 m .30341 .65745 L .30105 .65881 L F
.777 .601 .661 r
.69841 .69765 m .695 .69966 L .69546 .69736 L F
.69841 .69765 m .69828 .70002 L .695 .69966 L F
.054 .083 .572 r
.68894 .61746 m .68785 .61994 L .68841 .61901 L F
.749 .374 .343 r
.42298 .7429 m .42112 .74428 L .41992 .74263 L F
.24 0 0 r
.42387 .7436 m .42298 .7429 L .42521 .74291 L F
.42387 .7436 m .42112 .74428 L .42298 .7429 L F
0 .426 .742 r
.34217 .65282 m .34157 .65277 L .34041 .65239 L F
.34217 .65282 m .34373 .65343 L .34157 .65277 L F
0 0 .17 r
.72553 .7404 m .7252 .73986 L .72382 .73886 L F
.72553 .7404 m .72531 .74147 L .7252 .73986 L F
.676 .682 .848 r
.55456 .81031 m .55489 .81191 L .55686 .80974 L F
.36 .074 .337 r
.71298 .62778 m .71603 .62798 L .71513 .62673 L F
.71298 .62778 m .71292 .62975 L .71603 .62798 L F
.574 .386 .589 r
.55422 .80736 m .55654 .80733 L .55633 .80473 L F
.595 .531 .752 r
.55567 .8019 m .55633 .80473 L .55792 .80379 L F
.628 .472 .651 r
.55654 .80733 m .55792 .80379 L .55633 .80473 L F
.33 0 0 r
.43454 .77293 m .43676 .77273 L .43741 .77192 L F
.213 0 0 r
.43741 .77192 m .43676 .77273 L .43884 .77217 L F
.396 .095 .333 r
.33954 .71921 m .33879 .72097 L .3369 .72137 L F
.395 .094 .333 r
.34073 .72048 m .33954 .71921 L .34116 .71836 L F
.34073 .72048 m .33879 .72097 L .33954 .71921 L F
.578 .419 .63 r
.5522 .81071 m .55456 .81031 L .55422 .80736 L F
.069 .63 .78 r
.42927 .72422 m .43146 .7242 L .43267 .72429 L F
.549 .393 .621 r
.66254 .61472 m .66072 .61795 L .66189 .61711 L F
.265 0 .089 r
.44514 .7792 m .44438 .77785 L .44655 .77782 L F
.44514 .7792 m .44314 .77989 L .44438 .77785 L F
.909 .941 .58 r
.5686 .80747 m .57173 .80818 L .5697 .80712 L F
.803 .634 .673 r
.5697 .80712 m .57173 .80818 L .57054 .80612 L F
.567 .842 .996 r
.35046 .65497 m .34708 .65477 L .34901 .65405 L F
.447 .763 .996 r
.35102 .65384 m .35046 .65497 L .34901 .65405 L F
.35102 .65384 m .35256 .65481 L .35046 .65497 L F
0 0 .169 r
.67614 .63406 m .67435 .63575 L .67533 .63303 L F
.788 .556 .585 r
.34988 .67892 m .3468 .67601 L .34874 .67543 L F
.34988 .67892 m .34649 .67869 L .3468 .67601 L F
.878 .646 .583 r
.6179 .65335 m .62047 .65183 L .61811 .65121 L F
.6179 .65335 m .62051 .65421 L .62047 .65183 L F
.364 0 .074 r
.41791 .78756 m .41441 .78968 L .4158 .78792 L F
.862 .681 .655 r
.33654 .8097 m .33774 .81262 L .33769 .81051 L F
.399 .156 .426 r
.34724 .69192 m .34905 .69161 L .34954 .6893 L F
.465 .215 .45 r
.34954 .6893 m .35102 .69098 L .35138 .68878 L F
.34954 .6893 m .34905 .69161 L .35102 .69098 L F
.398 .25 .561 r
.65083 .60249 m .64902 .60097 L .65076 .60023 L F
.574 .431 .649 r
.34556 .77497 m .34751 .77219 L .34541 .77254 L F
.827 .677 .696 r
.7112 .7188 m .71377 .71957 L .71279 .71595 L F
.842 .738 .749 r
.71069 .72101 m .71377 .71957 L .7112 .7188 L F
.71069 .72101 m .71284 .72169 L .71377 .71957 L F
.006 .406 .854 r
.71357 .71794 m .71444 .71761 L .71415 .71765 L F
0 0 .505 r
.71279 .71595 m .71336 .71805 L .71357 .71794 L F
.71279 .71595 m .71357 .71794 L .71529 .71549 L F
.744 .671 .779 r
.70955 .71541 m .71279 .71595 L .71168 .71293 L F
.765 .593 .664 r
.70955 .71541 m .7112 .7188 L .71279 .71595 L F
.813 .455 .379 r
.71529 .71549 m .71168 .71293 L .71279 .71595 L F
.919 .824 .736 r
.71357 .71794 m .71206 .71546 L .71529 .71549 L F
.71357 .71794 m .71178 .71801 L .71206 .71546 L F
.006 .406 .854 r
.71357 .71794 m .71415 .71765 L .71178 .71801 L F
0 0 .505 r
.71336 .71805 m .71377 .71957 L .71357 .71794 L F
.439 .789 .997 r
.71377 .71957 m .71516 .71871 L .71357 .71794 L F
.71377 .71957 m .71602 .71934 L .71516 .71871 L F
.323 0 0 r
.71431 .73665 m .71147 .73562 L .71206 .73617 L F
.399 .28 .6 r
.69103 .6319 m .68808 .63643 L .68899 .63317 L F
.69103 .6319 m .69117 .63466 L .68808 .63643 L F
.399 .342 .677 r
.69077 .63622 m .68808 .63643 L .69117 .63466 L F
.69077 .63622 m .68964 .63802 L .68808 .63643 L F
.715 .665 .799 r
.67662 .71636 m .67971 .71859 L .67846 .71553 L F
.765 .666 .754 r
.67846 .71553 m .67971 .71859 L .68055 .71675 L F
.708 .495 .598 r
.34619 .69379 m .34905 .69161 L .34724 .69192 L F
.221 .337 .77 r
.69521 .72432 m .69757 .72536 L .69459 .72329 L F
.63 .078 0 r
.69859 .72689 m .69778 .72662 L .69521 .72432 L F
.221 .337 .77 r
.69521 .72432 m .69778 .72662 L .69757 .72536 L F
.593 .337 .498 r
.62416 .66813 m .62411 .67001 L .62187 .67026 L F
.426 .114 .33 r
.62682 .66799 m .62411 .67001 L .62416 .66813 L F
.572 .367 .564 r
.36127 .74299 m .3634 .74273 L .36355 .74033 L F
.592 .383 .567 r
.36355 .74033 m .36564 .7424 L .36571 .74004 L F
.36355 .74033 m .3634 .74273 L .36564 .7424 L F
.786 .669 .735 r
.6376 .6031 m .64073 .60343 L .63945 .60056 L F
.205 .708 .907 r
.63924 .60314 m .64073 .60343 L .6376 .6031 L F
.064 .427 .87 r
.63924 .60314 m .64317 .60587 L .64073 .60343 L F
.718 .711 .843 r
.50122 .7463 m .50201 .7484 L .50017 .74907 L F
.622 .497 .689 r
.50228 .75069 m .50017 .74907 L .50201 .7484 L F
.50228 .75069 m .49999 .7512 L .50017 .74907 L F
.57 .923 .736 r
.33569 .67438 m .33537 .67495 L .33674 .67376 L F
.473 .24 .48 r
.35045 .70769 m .35029 .71045 L .34836 .71084 L F
.514 .318 .553 r
.3525 .70752 m .35029 .71045 L .35045 .70769 L F
.777 .594 .651 r
.64196 .62458 m .64247 .62222 L .63895 .62192 L F
.012 0 .081 r
.64196 .62458 m .64426 .62266 L .64247 .62222 L F
.559 .409 .634 r
.38001 .67804 m .37746 .67563 L .37916 .67527 L F
.38001 .67804 m .37748 .67858 L .37746 .67563 L F
.895 .773 .719 r
.69709 .69432 m .69546 .69736 L .69401 .69682 L F
.69675 .6946 m .69401 .69682 L .69625 .69505 L F
.357 0 0 r
.69625 .69505 m .69532 .69574 L .69551 .69572 L F
.69625 .69505 m .69551 .69572 L .69857 .6955 L F
.895 .773 .719 r
.69709 .69432 m .69675 .6946 L .69625 .69505 L F
.424 0 .092 r
.69625 .69505 m .69937 .69385 L .69709 .69432 L F
.742 .393 .389 r
.62387 .65625 m .62413 .65477 L .62051 .65421 L F
.552 .262 .429 r
.62625 .65625 m .62413 .65477 L .62387 .65625 L F
.62625 .65625 m .62667 .65452 L .62413 .65477 L F
.467 .256 .51 r
.36186 .69448 m .36175 .6968 L .35958 .69728 L F
.518 .314 .543 r
.36175 .6968 m .35947 .69907 L .35958 .69728 L F
.61 .441 .628 r
.3322 .78873 m .33457 .78845 L .33451 .78599 L F
.622 .507 .701 r
.3322 .78873 m .33258 .79129 L .33457 .78845 L F
.655 .325 .403 r
.35907 .81011 m .35827 .81251 L .35515 .81158 L F
.653 .966 .804 r
.35975 .80902 m .35998 .80942 L .36135 .80838 L F
.464 0 .062 r
.36156 .80844 m .36192 .80903 L .35975 .80902 L F
.36389 .80769 m .36192 .80903 L .36156 .80844 L F
.743 .448 .483 r
.36648 .80894 m .3634 .81329 L .36192 .80903 L F
0 0 .408 r
.36192 .80903 m .3634 .81329 L .36278 .81042 L F
.36192 .80903 m .36278 .81042 L .36233 .80829 L F
.708 .281 .231 r
.36192 .80903 m .35963 .80881 L .35975 .80902 L F
.35963 .80881 m .3583 .80868 L .35975 .80902 L F
.653 .966 .804 r
.35975 .80902 m .35907 .81011 L .35998 .80942 L F
.561 .367 .575 r
.35907 .81011 m .36129 .81229 L .35904 .81282 L F
0 0 0 r
.35975 .80902 m .35827 .81251 L .35907 .81011 L F
.321 .755 .969 r
.70958 .62986 m .70829 .63052 L .70772 .63031 L F
.70958 .62986 m .71066 .63044 L .70829 .63052 L F
.105 0 0 r
.46033 .77477 m .45966 .77487 L .45742 .77487 L F
0 0 0 r
.46271 .77448 m .45966 .77487 L .46033 .77477 L F
.37 .773 .984 r
.69266 .59777 m .69372 .59688 L .69168 .59748 L F
.69266 .59777 m .69526 .59762 L .69372 .59688 L F
.63 .456 .629 r
.55422 .80736 m .55686 .80974 L .55654 .80733 L F
.55422 .80736 m .55456 .81031 L .55686 .80974 L F
.004 .123 .638 r
.49299 .88194 m .4923 .88274 L .49123 .8803 L F
.49299 .88194 m .49123 .8803 L .49044 .87999 L F
.925 .711 .595 r
.70344 .62131 m .70398 .62353 L .70263 .62118 L F
.70344 .62131 m .70398 .62353 L .70263 .62118 L F
.561 .601 .851 r
.70599 .6227 m .70398 .62353 L .70263 .62118 L F
.70599 .6227 m .70398 .62353 L .70263 .62118 L F
.881 .873 .824 r
.64639 .64329 m .64836 .64232 L .64706 .64392 L F
.532 .371 .609 r
.34876 .67855 m .34649 .67869 L .34988 .67892 L F
0 0 .207 r
.3503 .67489 m .34988 .67892 L .34874 .67543 L F
.3503 .67489 m .35032 .67741 L .34988 .67892 L F
.38 .162 .452 r
.35032 .67741 m .34876 .67855 L .34988 .67892 L F
.575 .441 .661 r
.34988 .67892 m .35244 .67819 L .35198 .67571 L F
.723 .37 .379 r
.34923 .68075 m .35244 .67819 L .34988 .67892 L F
.504 .104 .215 r
.34034 .81374 m .33786 .81481 L .33898 .81476 L F
.34034 .81374 m .33898 .81476 L .33915 .81229 L F
0 0 .497 r
.342 .81562 m .34034 .81374 L .33915 .81229 L F
.493 .528 .822 r
.36128 .65889 m .36 .66071 L .35911 .65961 L F
.36128 .65889 m .36251 .6619 L .36 .66071 L F
.78 .57 .615 r
.66907 .60657 m .66955 .60849 L .67255 .60846 L F
.749 .41 .409 r
.71086 .72351 m .71284 .72169 L .71069 .72101 L F
.71086 .72351 m .71403 .72366 L .71284 .72169 L F
.678 .133 0 r
.69436 .59369 m .69791 .59614 L .69782 .59562 L F
.524 .494 .765 r
.48572 .75094 m .48654 .75378 L .48855 .75354 L F
.573 .399 .607 r
.48654 .75378 m .48893 .75601 L .48855 .75354 L F
.48654 .75378 m .48669 .75653 L .48893 .75601 L F
.773 .843 .905 r
.65083 .60249 m .65201 .60377 L .6494 .6054 L F
.484 .245 .476 r
.38167 .76158 m .37918 .76412 L .37933 .76178 L F
.096 .094 .565 r
.67179 .61709 m .67251 .61671 L .67309 .61565 L F
.592 .598 .827 r
.67006 .61292 m .67245 .61662 L .67018 .61488 L F
.67245 .61662 m .67251 .61671 L .67244 .61666 L F
.67245 .61662 m .67244 .61666 L .67018 .61488 L F
.398 0 0 r
.67307 .61624 m .67244 .61666 L .67309 .61565 L F
.67244 .61666 m .67179 .61709 L .67265 .61613 L F
.67244 .61666 m .67265 .61613 L .67309 .61565 L F
.273 .518 .905 r
.67244 .61666 m .67251 .61671 L .67179 .61709 L F
.398 0 0 r
.67303 .61792 m .67179 .61709 L .67307 .61624 L F
.273 .518 .905 r
.67018 .61488 m .67244 .61666 L .67179 .61709 L F
.398 0 0 r
.67303 .61792 m .67431 .61875 L .67179 .61709 L F
.46 .043 .162 r
.44409 .76918 m .44631 .76912 L .44755 .76726 L F
.301 0 0 r
.44631 .76912 m .44973 .7673 L .44755 .76726 L F
.662 .482 .631 r
.33451 .78599 m .33457 .78845 L .33683 .78578 L F
.262 .768 .76 r
.70554 .60034 m .70356 .60079 L .70145 .60138 L F
.809 .381 .228 r
.70554 .60034 m .70701 .60268 L .70603 .60248 L F
.338 .744 .981 r
.45992 .72668 m .46336 .7273 L .46131 .72772 L F
.146 .243 .707 r
.66289 .58968 m .66499 .59194 L .66369 .59293 L F
.274 .483 .88 r
.66499 .59194 m .66624 .5943 L .66369 .59293 L F
.564 .37 .576 r
.35515 .75365 m .35736 .75333 L .35747 .75103 L F
.497 .336 .593 r
.35747 .75103 m .35936 .7506 L .35936 .74822 L F
.518 .332 .567 r
.35747 .75103 m .35935 .75291 L .35936 .7506 L F
.35747 .75103 m .35736 .75333 L .35935 .75291 L F
.329 .78 .955 r
.49338 .84181 m .49469 .84224 L .49125 .84204 L F
.49338 .84181 m .49469 .84224 L .49125 .84204 L F
.397 .78 .991 r
.49561 .8414 m .49469 .84224 L .49338 .84181 L F
.49561 .8414 m .49715 .84215 L .49469 .84224 L F
.088 .271 .755 r
.49469 .84224 m .49561 .8414 L .49338 .84181 L F
.592 .356 .528 r
.49715 .84215 m .4968 .84431 L .49469 .84224 L F
.088 .271 .755 r
.49469 .84224 m .4968 .84431 L .49561 .8414 L F
.283 .037 .354 r
.48853 .88251 m .48654 .88498 L .48727 .88272 L F
.662 .631 .809 r
.47903 .73203 m .47552 .72996 L .47774 .72893 L F
.512 .403 .667 r
.4809 .72938 m .47903 .73203 L .47774 .72893 L F
.4809 .72938 m .481 .73182 L .47903 .73203 L F
.569 .418 .637 r
.35515 .75365 m .35745 .75583 L .35736 .75333 L F
.35515 .75365 m .35532 .75619 L .35745 .75583 L F
.284 0 .26 r
.3369 .72137 m .33599 .72399 L .33439 .72394 L F
.405 .089 .313 r
.33792 .72342 m .3369 .72137 L .33879 .72097 L F
.33792 .72342 m .33599 .72399 L .3369 .72137 L F
.55 .324 .525 r
.36359 .69634 m .36186 .69448 L .36392 .69422 L F
.36359 .69634 m .36175 .6968 L .36186 .69448 L F
0 0 .434 r
.71477 .5933 m .7149 .59538 L .71333 .59224 L F
.595 .415 .607 r
.71144 .59408 m .71475 .59501 L .71333 .59224 L F
0 0 .434 r
.71523 .59433 m .7149 .59538 L .71477 .5933 L F
.71541 .59376 m .71546 .59479 L .7149 .59538 L F
.793 .648 .702 r
.71475 .59501 m .71546 .59479 L .71542 .59393 L F
.7137 .59669 m .71392 .59645 L .71459 .59528 L F
.7137 .59669 m .71459 .59528 L .7143 .59573 L F
.71392 .59645 m .71546 .59479 L .71475 .59501 L F
.565 .371 .576 r
.71459 .59528 m .7136 .5968 L .71497 .59508 L F
.71117 .59718 m .7136 .5968 L .71459 .59528 L F
.793 .648 .702 r
.7143 .59573 m .71459 .59528 L .71475 .59501 L F
.565 .371 .576 r
.71117 .59718 m .71459 .59528 L .71144 .59408 L F
.71459 .59528 m .71497 .59508 L .71475 .59501 L F
.71459 .59528 m .71475 .59501 L .71144 .59408 L F
.595 .415 .607 r
.71475 .59501 m .71497 .59508 L .71484 .59486 L F
.71475 .59501 m .71484 .59486 L .71333 .59224 L F
0 0 .434 r
.71541 .59376 m .71523 .59433 L .71477 .5933 L F
.566 .404 .62 r
.71333 .59224 m .71484 .59486 L .71541 .59376 L F
.793 .648 .702 r
.71484 .59486 m .71542 .59393 L .71541 .59376 L F
.566 .404 .62 r
.71484 .59486 m .71497 .59508 L .71541 .59376 L F
.793 .648 .702 r
.7137 .59669 m .71484 .59486 L .71541 .59376 L F
.7136 .5968 m .7137 .59669 L .71541 .59376 L F
.737 .68 .796 r
.71162 .58968 m .71333 .59224 L .71099 .59305 L F
.618 .351 .49 r
.71099 .59305 m .71333 .59224 L .71332 .59383 L F
.228 .607 .952 r
.71162 .58968 m .7157 .59155 L .71333 .59224 L F
.672 .622 .791 r
.71541 .59376 m .71333 .59224 L .7157 .59155 L F
.71541 .59376 m .71332 .59383 L .71333 .59224 L F
.772 .743 .827 r
.71332 .59383 m .71417 .59194 L .71142 .59055 L F
.228 .607 .952 r
.71162 .58968 m .71479 .59055 L .7157 .59155 L F
.772 .743 .827 r
.71417 .59194 m .71479 .59055 L .71355 .59055 L F
.71417 .59194 m .71355 .59055 L .71142 .59055 L F
0 .412 .852 r
.71677 .59709 m .7149 .59538 L .71546 .59479 L F
.298 0 0 r
.40813 .79094 m .40727 .79172 L .40486 .79249 L F
.318 0 0 r
.40884 .79198 m .40813 .79094 L .41002 .79075 L F
.40884 .79198 m .40727 .79172 L .40813 .79094 L F
.543 .638 .895 r
.48004 .74915 m .48122 .74756 L .47948 .74803 L F
.48004 .74915 m .48282 .75024 L .48122 .74756 L F
.484 .268 .51 r
.36032 .70062 m .35728 .69977 L .35947 .69907 L F
.36032 .70062 m .35665 .70185 L .35728 .69977 L F
.196 0 .061 r
.4134 .7774 m .41472 .77756 L .41579 .7761 L F
.198 0 .157 r
.41407 .779 m .4134 .7774 L .41195 .77906 L F
.41407 .779 m .41472 .77756 L .4134 .7774 L F
.594 .43 .628 r
.34908 .7644 m .35146 .76413 L .35113 .76171 L F
.547 .389 .619 r
.34908 .7644 m .35144 .7668 L .35146 .76413 L F
.34908 .7644 m .34928 .76738 L .35144 .7668 L F
.649 .754 .926 r
.6842 .61125 m .68239 .61234 L .68043 .61069 L F
.675 .513 .658 r
.33897 .78559 m .34133 .78283 L .3391 .78317 L F
.951 .697 .516 r
.69281 .71575 m .69414 .7189 L .69281 .71816 L F
.998 .843 .513 r
.69414 .7189 m .69291 .72097 L .69281 .71816 L F
.69414 .7189 m .69371 .72233 L .69291 .72097 L F
.366 .023 .245 r
.52002 .78477 m .52259 .78153 L .52224 .78466 L F
.52002 .78477 m .52036 .78341 L .52259 .78153 L F
.479 .238 .47 r
.52518 .77979 m .52523 .7828 L .52259 .78153 L F
.512 .186 .351 r
.52259 .78153 m .52435 .78434 L .52224 .78466 L F
.52259 .78153 m .52523 .7828 L .52435 .78434 L F
0 0 .327 r
.68472 .64166 m .68485 .64183 L .68293 .64001 L F
.68472 .64166 m .68545 .6432 L .68485 .64183 L F
.143 0 0 r
.31641 .71675 m .31743 .71696 L .31826 .71631 L F
.31641 .71675 m .31565 .71748 L .31743 .71696 L F
.746 .485 .537 r
.50485 .77532 m .50461 .77764 L .50295 .77491 L F
.50799 .77771 m .50461 .77764 L .50485 .77532 L F
.62 .461 .645 r
.59241 .6759 m .59265 .6785 L .59025 .67862 L F
.51 .112 .221 r
.59265 .6785 m .59229 .68013 L .59025 .67862 L F
.62 .461 .645 r
.59241 .6759 m .59265 .6785 L .59025 .67862 L F
.51 .112 .221 r
.59025 .67862 m .59229 .68013 L .59265 .6785 L F
.59265 .6785 m .59229 .68013 L .59025 .67862 L F
.225 0 0 r
.40377 .72581 m .40588 .72553 L .4074 .72441 L F
.262 0 0 r
.40588 .72553 m .40951 .7244 L .4074 .72441 L F
.557 .85 .998 r
.69943 .72571 m .69859 .72689 L .70085 .72649 L F
.64 .953 .941 r
.69943 .72571 m .69778 .72662 L .69859 .72689 L F
.634 .172 .138 r
.72542 .74517 m .72422 .74573 L .72204 .74499 L F
0 .37 .741 r
.72542 .74517 m .72757 .74609 L .72697 .74568 L F
.72542 .74517 m .72697 .74568 L .72422 .74573 L F
.618 .703 .905 r
.37926 .77782 m .37752 .77873 L .37611 .77714 L F
.988 .746 .474 r
.67538 .61955 m .67431 .61875 L .67435 .61647 L F
.849 .582 .534 r
.67538 .61955 m .6735 .62097 L .67431 .61875 L F
.67538 .61955 m .67579 .62196 L .6735 .62097 L F
0 0 .229 r
.42917 .73933 m .42976 .73852 L .42957 .73932 L F
.635 .631 .829 r
.46673 .74089 m .47027 .74309 L .46866 .74026 L F
.68 .668 .831 r
.46866 .74026 m .47027 .74309 L .47231 .74256 L F
.622 .506 .701 r
.33457 .78845 m .33258 .79129 L .33464 .79104 L F
.705 .524 .641 r
.33231 .79353 m .33464 .79104 L .33258 .79129 L F
.399 .19 .476 r
.70668 .59802 m .70898 .59635 L .70893 .59539 L F
.165 0 0 r
.7043 .59706 m .70448 .59709 L .70563 .59749 L F
.568 .193 .291 r
.70563 .59749 m .70898 .59635 L .70684 .5979 L F
.70563 .59749 m .70802 .59772 L .70898 .59635 L F
.165 0 0 r
.70448 .59709 m .70802 .59772 L .70563 .59749 L F
.568 .193 .291 r
.70563 .59749 m .70684 .5979 L .70668 .59802 L F
.453 .67 .956 r
.7191 .59685 m .71848 .59881 L .71677 .59709 L F
.7191 .59685 m .72105 .59867 L .71848 .59881 L F
.642 .577 .766 r
.49053 .76121 m .49142 .76444 L .49387 .7625 L F
.642 .576 .766 r
.49142 .76444 m .49373 .76449 L .49387 .7625 L F
.615 .377 .533 r
.49143 .76677 m .49373 .76449 L .49142 .76444 L F
.577 .511 .744 r
.50583 .75567 m .50449 .75933 L .50359 .75592 L F
.50583 .75567 m .50665 .75898 L .50449 .75933 L F
.638 .552 .741 r
.6463 .60175 m .65076 .60023 L .6499 .59707 L F
.79 .552 .577 r
.64766 .60196 m .65076 .60023 L .6463 .60175 L F
.483 .622 .911 r
.72305 .7143 m .72494 .71264 L .72258 .7146 L F
.72305 .7143 m .72616 .71473 L .72494 .71264 L F
.472 .793 .999 r
.66599 .64294 m .66779 .64222 L .66533 .64267 L F
.66599 .64294 m .66936 .64272 L .66779 .64222 L F
.379 .012 .209 r
.30051 .65949 m .3027 .65868 L .30341 .65745 L F
.39 .031 .23 r
.3027 .65868 m .30539 .65699 L .30341 .65745 L F
.281 .766 .681 r
.64901 .65419 m .64873 .65427 L .64579 .65543 L F
.734 .931 .592 r
.65109 .65157 m .64983 .65286 L .64901 .65419 L F
.687 .916 .584 r
.64983 .65286 m .64873 .65427 L .64901 .65419 L F
.856 .62 .081 r
.67304 .60871 m .67273 .60788 L .67249 .60557 L F
.986 .727 .349 r
.67352 .61087 m .67273 .60788 L .67304 .60871 L F
.658 .426 .557 r
.61873 .67059 m .61653 .67276 L .6165 .67047 L F
.737 .628 .739 r
.70427 .72691 m .7039 .73015 L .70552 .72968 L F
.747 .426 .44 r
.70429 .73155 m .70552 .72968 L .7039 .73015 L F
.70429 .73155 m .70763 .73193 L .70552 .72968 L F
.856 .727 .719 r
.69784 .70844 m .69677 .71009 L .69642 .70661 L F
.978 .689 .309 r
.67475 .6144 m .67383 .61359 L .67352 .61087 L F
.967 .753 .563 r
.67475 .6144 m .67309 .61565 L .67383 .61359 L F
.67475 .6144 m .67435 .61647 L .67309 .61565 L F
.789 .674 .737 r
.59904 .65208 m .59569 .65202 L .59797 .64915 L F
.761 .608 .688 r
.59904 .65208 m .59532 .65391 L .59569 .65202 L F
.59904 .65208 m .59865 .65434 L .59532 .65391 L F
.771 .593 .658 r
.60186 .657 m .60048 .6599 L .59866 .6565 L F
.524 .324 .55 r
.59473 .6757 m .59265 .6785 L .59241 .6759 L F
0 0 .432 r
.59241 .6759 m .59353 .677 L .59473 .6757 L F
.59241 .6759 m .59265 .6785 L .59353 .677 L F
.125 0 0 r
.45214 .77612 m .4507 .77688 L .44859 .77717 L F
.469 0 0 r
.45403 .77611 m .4507 .77688 L .45214 .77612 L F
.495 .314 .565 r
.33782 .70004 m .33976 .69962 L .33991 .69698 L F
.429 .296 .597 r
.3382 .70247 m .33976 .69962 L .33782 .70004 L F
.498 .581 .869 r
.50392 .74828 m .50201 .7484 L .50122 .7463 L F
.565 .461 .694 r
.50392 .74828 m .50228 .75069 L .50201 .7484 L F
.878 .498 .025 r
.73238 .71743 m .73245 .71617 L .73125 .71557 L F
.73238 .71743 m .73346 .71879 L .73245 .71617 L F
.733 .901 .954 r
.44806 .73742 m .44722 .73912 L .44929 .73753 L F
.44806 .73742 m .44579 .73873 L .44722 .73912 L F
.598 .45 .651 r
.35113 .76171 m .35338 .76169 L .35327 .7588 L F
.594 .427 .626 r
.35146 .76413 m .35338 .76169 L .35113 .76171 L F
.514 .137 .262 r
.34457 .67919 m .34624 .67944 L .34649 .67869 L F
.34457 .67919 m .34456 .6804 L .34624 .67944 L F
0 0 .018 r
.63352 .66156 m .6328 .66369 L .63141 .66474 L F
.359 .077 .343 r
.63611 .65954 m .63584 .66072 L .63352 .66156 L F
.289 0 .16 r
.63584 .66072 m .6328 .66369 L .63352 .66156 L F
.722 .423 .47 r
.48251 .76427 m .48589 .76605 L .48589 .76447 L F
.705 .381 .426 r
.48589 .76605 m .48815 .76682 L .48589 .76447 L F
.879 .865 .419 r
.62958 .60583 m .63038 .60198 L .63029 .6037 L F
.652 .379 .493 r
.60544 .67334 m .60211 .67542 L .60411 .67299 L F
0 0 0 r
.68949 .62946 m .69015 .62702 L .6879 .62646 L F
.428 .299 .602 r
.37918 .76412 m .37926 .76613 L .37767 .7663 L F
.547 .476 .727 r
.37926 .76613 m .37786 .76945 L .37767 .7663 L F
.671 .684 .854 r
.32707 .65083 m .32378 .6502 L .32591 .65007 L F
.47 .775 .997 r
.3281 .64985 m .32707 .65083 L .32591 .65007 L F
.3281 .64985 m .32925 .6506 L .32707 .65083 L F
.763 .269 0 r
.68186 .63771 m .6812 .63747 L .6808 .63682 L F
.68186 .63771 m .68226 .63819 L .6812 .63747 L F
.331 .305 .679 r
.48162 .88242 m .48318 .88333 L .48232 .87906 L F
.096 .331 .804 r
.48162 .88242 m .48464 .88565 L .48318 .88333 L F
.609 .699 .907 r
.38949 .78318 m .38624 .78232 L .38849 .7807 L F
.443 .863 .947 r
.38621 .79874 m .38729 .7989 L .38861 .79841 L F
.433 0 0 r
.68593 .63336 m .68504 .63315 L .68634 .6331 L F
.512 .913 .894 r
.68634 .6331 m .68504 .63315 L .68541 .63299 L F
.687 .6326 m .68541 .63299 L .688 .63185 L F
.68634 .6331 m .68541 .63299 L .687 .6326 L F
.924 .563 .323 r
.6854 .633 m .68504 .63315 L .68593 .63336 L F
.68321 .63152 m .68417 .63238 L .68423 .63221 L F
.68423 .63221 m .68504 .63315 L .6854 .633 L F
.68417 .63238 m .68504 .63315 L .68423 .63221 L F
.68417 .63238 m .68483 .63335 L .68504 .63315 L F
.68321 .63152 m .68392 .63232 L .68417 .63238 L F
.68392 .63232 m .68429 .63274 L .68417 .63238 L F
.68429 .63274 m .68453 .63291 L .68417 .63238 L F
.857 .665 .643 r
.68321 .63152 m .68539 .63299 L .68422 .63265 L F
.68321 .63152 m .68422 .63265 L .68353 .63245 L F
.697 .791 .923 r
.68353 .63245 m .68429 .63274 L .68383 .63241 L F
.852 .932 .878 r
.68355 .63223 m .68353 .63245 L .68371 .63227 L F
.924 .563 .323 r
.68321 .63152 m .68334 .63182 L .68483 .63335 L F
.697 .791 .923 r
.68353 .63245 m .68383 .63241 L .68371 .63227 L F
.924 .563 .323 r
.68334 .63182 m .68422 .63396 L .68471 .63348 L F
.68334 .63182 m .68471 .63348 L .68483 .63335 L F
.697 .791 .923 r
.68371 .63227 m .688 .63185 L .68687 .62888 L F
.68383 .63241 m .688 .63185 L .68371 .63227 L F
.857 .665 .643 r
.68539 .63299 m .6854 .633 L .68513 .63306 L F
.6854 .633 m .68593 .63336 L .68524 .6331 L F
.6854 .633 m .68524 .6331 L .68513 .63306 L F
.697 .791 .923 r
.6853 .63307 m .68593 .63336 L .68697 .63232 L F
.68697 .63232 m .68593 .63336 L .688 .63185 L F
.857 .665 .643 r
.68539 .63299 m .68513 .63306 L .68353 .63245 L F
.697 .791 .923 r
.68429 .63274 m .68524 .6331 L .68383 .63241 L F
.68524 .6331 m .68593 .63336 L .6853 .63307 L F
.68524 .6331 m .6853 .63307 L .68383 .63241 L F
.573 .245 .375 r
.68697 .63232 m .688 .63185 L .68504 .63315 L F
.68785 .63194 m .688 .63185 L .68697 .63232 L F
.68422 .63396 m .68697 .63232 L .68524 .6331 L F
.68483 .63335 m .68524 .6331 L .68497 .63322 L F
.68422 .63396 m .68524 .6331 L .68483 .63335 L F
.68422 .63396 m .68785 .63194 L .68697 .63232 L F
.68497 .63322 m .68697 .63232 L .68504 .63315 L F
.697 .791 .923 r
.68383 .63241 m .6853 .63307 L .688 .63185 L F
.924 .563 .323 r
.68429 .63274 m .68483 .63335 L .68453 .63291 L F
.852 .932 .878 r
.68366 .6307 m .68355 .63223 L .68451 .63141 L F
.68355 .63223 m .68371 .63227 L .68451 .63141 L F
.68502 .62993 m .68451 .63141 L .68687 .62888 L F
.68366 .6307 m .68451 .63141 L .68502 .62993 L F
.436 .826 .601 r
.688 .63185 m .68593 .63336 L .68634 .6331 L F
.512 .913 .894 r
.68634 .6331 m .688 .63185 L .68899 .63317 L F
.471 .548 .853 r
.69244 .5889 m .69075 .59055 L .69084 .58932 L F
.456 .523 .838 r
.69244 .5889 m .69362 .59185 L .69075 .59055 L F
.644 .368 .486 r
.36805 .737 m .37055 .73704 L .36805 .7359 L F
.632 .527 .717 r
.47608 .74525 m .47791 .74258 L .47572 .74313 L F
.47608 .74525 m .4789 .74581 L .47791 .74258 L F
.734 .931 .592 r
.65109 .65157 m .65094 .65143 L .64983 .65286 L F
.71 .97 .736 r
.65109 .65157 m .65224 .64987 L .65094 .65143 L F
.65109 .65157 m .65365 .64914 L .65224 .64987 L F
.99 .746 .374 r
.71529 .74006 m .71431 .73665 L .71745 .73744 L F
.71529 .74006 m .71449 .73933 L .71431 .73665 L F
.622 .122 0 r
.71529 .74006 m .71665 .74191 L .71449 .73933 L F
.71529 .74006 m .71744 .74258 L .71665 .74191 L F
.776 .271 0 r
.7186 .74286 m .71758 .74275 L .71529 .74006 L F
.762 .25 0 r
.71449 .73933 m .71665 .74191 L .71368 .73946 L F
.327 0 0 r
.71942 .74156 m .71598 .74135 L .71665 .74191 L F
.612 .073 0 r
.71665 .74191 m .7157 .74133 L .71368 .73946 L F
.327 0 0 r
.71598 .74135 m .7157 .74133 L .71665 .74191 L F
.622 .122 0 r
.71744 .74258 m .71758 .74275 L .71665 .74191 L F
.764 .467 .482 r
.63005 .63579 m .63307 .63808 L .63292 .63608 L F
.292 0 .152 r
.63801 .59244 m .64005 .59182 L .64071 .5901 L F
.322 0 .135 r
.64005 .59182 m .64292 .58957 L .64071 .5901 L F
.589 .902 .984 r
.64639 .64329 m .64436 .64569 L .64525 .64461 L F
0 0 0 r
.64441 .64598 m .64525 .64461 L .64436 .64569 L F
.624 .446 .621 r
.36127 .74299 m .36355 .74515 L .3634 .74273 L F
.36127 .74299 m .3613 .74543 L .36355 .74515 L F
.594 .538 .762 r
.43798 .73978 m .43937 .74301 L .4417 .74262 L F
.652 .379 .493 r
.60544 .67334 m .60564 .67529 L .60211 .67542 L F
.707 .466 .557 r
.60918 .67287 m .60564 .67529 L .60544 .67334 L F
.60918 .67287 m .60756 .67544 L .60564 .67529 L F
.66 .407 .526 r
.61108 .67511 m .60918 .67287 L .61106 .67299 L F
.61108 .67511 m .60756 .67544 L .60918 .67287 L F
.608 .569 .785 r
.48425 .73469 m .48306 .73784 L .48212 .73495 L F
.48425 .73469 m .48528 .73753 L .48306 .73784 L F
.193 0 0 r
.44919 .72529 m .4512 .72572 L .45261 .72593 L F
.158 0 0 r
.4512 .72572 m .45454 .7263 L .45261 .72593 L F
.033 0 0 r
.68399 .62218 m .68566 .62185 L .68504 .62232 L F
0 0 0 r
.68504 .62232 m .68566 .62185 L .68782 .62091 L F
.6 .166 .188 r
.47941 .77234 m .4783 .7738 L .47602 .77247 L F
.592 .175 .219 r
.48136 .77245 m .4783 .7738 L .47941 .77234 L F
.333 0 0 r
.33544 .81796 m .33804 .81803 L .33828 .81807 L F
.48 .494 .795 r
.6959 .59141 m .69436 .59369 L .69362 .59185 L F
.6959 .59141 m .69791 .59614 L .69436 .59369 L F
.071 .593 .875 r
.43471 .72414 m .43665 .72443 L .43801 .72499 L F
.264 .705 .961 r
.43894 .72438 m .43801 .72499 L .43665 .72443 L F
.43894 .72438 m .44024 .72496 L .43801 .72499 L F
.684 .385 .463 r
.50295 .77491 m .50124 .77735 L .49924 .77508 L F
.763 .489 .519 r
.50295 .77491 m .50461 .77764 L .50124 .77735 L F
.668 .192 .114 r
.72864 .74052 m .7323 .74113 L .72965 .74104 L F
.503 .498 .784 r
.72142 .61403 m .72383 .61561 L .72381 .61342 L F
.214 0 0 r
.5013 .88301 m .50017 .88304 L .49728 .88262 L F
0 0 .55 r
.50156 .88161 m .5013 .88301 L .50029 .87934 L F
.809 .988 .882 r
.50156 .88161 m .50017 .88304 L .5013 .88301 L F
.658 .426 .557 r
.61873 .67059 m .61869 .67283 L .61653 .67276 L F
.646 .417 .557 r
.6219 .67245 m .61873 .67059 L .62187 .67026 L F
.6219 .67245 m .61869 .67283 L .61873 .67059 L F
.623 .678 .881 r
.48122 .74756 m .48282 .75024 L .48484 .74849 L F
.603 .674 .891 r
.48282 .75024 m .48572 .75094 L .48484 .74849 L F
.578 .441 .659 r
.3436 .78007 m .34561 .77726 L .34351 .77768 L F
.367 .222 .549 r
.64067 .61627 m .64079 .61896 L .63838 .61978 L F
.1 0 0 r
.63838 .61978 m .63947 .6203 L .63895 .62192 L F
.63838 .61978 m .64079 .61896 L .63947 .6203 L F
0 0 0 r
.65773 .63017 m .65854 .63028 L .65827 .63091 L F
.649 .789 .334 r
.65827 .63091 m .65854 .63028 L .65925 .62888 L F
.705 .856 .954 r
.51885 .76643 m .51816 .76762 L .52059 .7673 L F
.716 .653 .786 r
.55686 .80974 m .55812 .81286 L .56045 .81079 L F
.755 .987 .762 r
.65365 .64914 m .65601 .64666 L .65466 .64742 L F
.751 .981 .738 r
.65365 .64914 m .65466 .64742 L .65224 .64987 L F
.828 .662 .677 r
.49622 .87688 m .49765 .87991 L .49574 .87976 L F
.975 .798 .601 r
.49765 .87991 m .49616 .8817 L .49574 .87976 L F
.49765 .87991 m .49728 .88262 L .49616 .8817 L F
.85 .809 .81 r
.49857 .87624 m .49765 .87991 L .49622 .87688 L F
.49857 .87624 m .49901 .87776 L .49765 .87991 L F
.691 .579 .725 r
.49901 .87776 m .50029 .87934 L .49765 .87991 L F
.655 .559 .734 r
.50029 .87934 m .49728 .88262 L .49765 .87991 L F
.585 .546 .777 r
.49976 .74254 m .49887 .74698 L .49775 .74339 L F
.49976 .74254 m .50122 .7463 L .49887 .74698 L F
.269 .368 .781 r
.70763 .73193 m .70989 .73375 L .71081 .73234 L F
.657 .205 .167 r
.70989 .73375 m .71331 .73406 L .71081 .73234 L F
.735 .208 0 r
.71883 .70444 m .72181 .70683 L .71967 .70537 L F
.751 .668 .769 r
.38634 .7562 m .38706 .75731 L .389 .75626 L F
.423 .817 .985 r
.389 .75626 m .38798 .75573 L .38634 .7562 L F
.917 .93 .803 r
.38989 .75288 m .38798 .75573 L .389 .75626 L F
0 .197 .727 r
.68293 .64001 m .6812 .63747 L .68226 .63819 L F
.807 .649 .686 r
.69828 .70002 m .69835 .70214 L .69498 .70189 L F
.271 0 .187 r
.39186 .75219 m .3909 .75093 L .39311 .75051 L F
.39186 .75219 m .38989 .75288 L .3909 .75093 L F
.537 .349 .574 r
.33991 .69698 m .3418 .69918 L .34194 .69687 L F
.33991 .69698 m .33976 .69962 L .3418 .69918 L F
.499 .075 .167 r
.41073 .74135 m .40972 .74264 L .40748 .74251 L F
.537 .117 .192 r
.41477 .74214 m .40972 .74264 L .41073 .74135 L F
.978 .704 .438 r
.67799 .63025 m .67698 .6318 L .67716 .62949 L F
.67799 .63025 m .67814 .63255 L .67698 .6318 L F
.818 .781 .818 r
.71675 .63286 m .7166 .62976 L .71621 .63209 L F
.71675 .63286 m .71932 .63024 L .7166 .62976 L F
.986 .873 .637 r
.65979 .60565 m .6582 .60752 L .65766 .60623 L F
.65979 .60565 m .65909 .60884 L .6582 .60752 L F
.903 .956 .82 r
.61117 .62867 m .61291 .6283 L .61105 .63071 L F
.895 .962 .829 r
.61556 .62491 m .61291 .6283 L .61324 .62601 L F
.895 .962 .828 r
.61324 .62601 m .61291 .6283 L .61117 .62867 L F
.707 .661 .802 r
.36657 .80997 m .3679 .81264 L .37022 .80892 L F
.697 .532 .661 r
.33683 .78578 m .33457 .78845 L .33695 .78835 L F
.587 .447 .658 r
.33683 .78578 m .33902 .78789 L .33897 .78559 L F
.33683 .78578 m .33695 .78835 L .33902 .78789 L F
.405 .846 .933 r
.68126 .58672 m .67956 .58718 L .67875 .58688 L F
.993 .757 .398 r
.67875 .58688 m .67956 .58718 L .67943 .589 L F
.253 0 0 r
.42564 .78488 m .42208 .7867 L .42343 .78531 L F
.569 .804 .988 r
.46672 .72775 m .46336 .7273 L .4655 .72696 L F
.49 .798 .999 r
.46759 .72666 m .46672 .72775 L .4655 .72696 L F
.46759 .72666 m .46886 .72744 L .46672 .72775 L F
.033 0 0 r
.68403 .62231 m .68375 .62364 L .68459 .6239 L F
.739 .507 .577 r
.68433 .62563 m .68459 .6239 L .68375 .62364 L F
.923 .775 .678 r
.68375 .62364 m .68324 .62659 L .68433 .62563 L F
0 0 0 r
.68356 .62451 m .68375 .62364 L .68504 .62232 L F
.68361 .62447 m .68324 .62659 L .68375 .62364 L F
.6835 .62518 m .68337 .62591 L .68361 .62447 L F
.68337 .62591 m .68324 .62659 L .68361 .62447 L F
.756 .754 .85 r
.68504 .62232 m .68462 .62008 L .68395 .62251 L F
0 0 0 r
.6835 .62518 m .68361 .62447 L .6833 .6249 L F
.68361 .62447 m .68375 .62364 L .6833 .6249 L F
.6833 .6249 m .68375 .62364 L .68356 .62451 L F
.756 .754 .85 r
.68362 .62442 m .68395 .62251 L .6833 .6249 L F
.033 0 0 r
.68399 .62218 m .68375 .62364 L .68403 .62231 L F
.68399 .62218 m .68504 .62232 L .68375 .62364 L F
.756 .754 .85 r
.68504 .62232 m .68395 .62251 L .68362 .62442 L F
.477 .889 .928 r
.45154 .73678 m .4501 .73673 L .44929 .73753 L F
.475 .887 .931 r
.4501 .73673 m .44806 .73742 L .44929 .73753 L F
.694 .6 .747 r
.50997 .76004 m .51274 .76258 L .51313 .7617 L F
.047 .385 .847 r
.51111 .76011 m .51274 .76258 L .50997 .76004 L F
.849 .822 .821 r
.51421 .75831 m .51274 .76258 L .51111 .76011 L F
.946 .952 .738 r
.51313 .7617 m .51274 .76258 L .51421 .75831 L F
.334 0 .019 r
.4233 .77723 m .42541 .77693 L .42681 .77531 L F
.303 0 0 r
.42681 .77531 m .42749 .77655 L .4289 .77496 L F
.42681 .77531 m .42541 .77693 L .42749 .77655 L F
.42 .388 .717 r
.47948 .74803 m .48077 .7454 L .4789 .74581 L F
.47948 .74803 m .48122 .74756 L .48077 .7454 L F
.711 .58 .707 r
.63798 .61045 m .64169 .61152 L .64011 .61324 L F
.723 .37 .379 r
.34923 .68075 m .35302 .68141 L .35244 .67819 L F
.34923 .68075 m .35069 .6814 L .35302 .68141 L F
.617 .56 .768 r
.34923 .68075 m .35088 .68378 L .35069 .6814 L F
.537 .498 .761 r
.35088 .68378 m .35275 .68333 L .35069 .6814 L F
.554 .645 .894 r
.35151 .68135 m .35118 .68263 L .34992 .68277 L F
.35118 .68263 m .35088 .68378 L .35014 .683 L F
.35118 .68263 m .35014 .683 L .34992 .68277 L F
.759 .482 .513 r
.35069 .6814 m .35177 .68241 L .35302 .68141 L F
.35177 .68241 m .35275 .68333 L .35294 .68199 L F
.35177 .68241 m .35294 .68199 L .35302 .68141 L F
.565 .529 .773 r
.35244 .67819 m .35302 .68141 L .35446 .67896 L F
.605 .579 .798 r
.35302 .68141 m .35553 .68108 L .35446 .67896 L F
.519 .265 .469 r
.35302 .68141 m .35487 .68296 L .35553 .68108 L F
.35302 .68141 m .35275 .68333 L .35487 .68296 L F
.786 .751 .821 r
.718 .60048 m .71877 .60312 L .72119 .60084 L F
.536 .553 .819 r
.41994 .77446 m .41904 .77678 L .41785 .77482 L F
.41994 .77446 m .421 .7768 L .41904 .77678 L F
.904 .965 .814 r
.60992 .63218 m .60908 .6316 L .61105 .63071 L F
.91 .959 .809 r
.61105 .63071 m .60908 .6316 L .61117 .62867 L F
.855 .678 .662 r
.7166 .62976 m .71932 .63024 L .7178 .62955 L F
.746 .941 .948 r
.72188 .62791 m .7178 .62955 L .71932 .63024 L F
.269 .368 .781 r
.70763 .73193 m .70856 .73498 L .70989 .73375 L F
.4 .591 .921 r
.70856 .73498 m .71147 .73562 L .70989 .73375 L F
.342 0 0 r
.40951 .7244 m .41128 .72478 L .41283 .72371 L F
.233 0 0 r
.41128 .72478 m .41492 .72403 L .41283 .72371 L F
0 0 0 r
.43454 .77293 m .43506 .77349 L .43676 .77273 L F
.43454 .77293 m .43329 .77453 L .43506 .77349 L F
.542 .609 .869 r
.38624 .78232 m .38284 .77994 L .38643 .78111 L F
.675 .637 .804 r
.38849 .7807 m .38624 .78232 L .38643 .78111 L F
.738 .581 .68 r
.59866 .6565 m .59532 .65391 L .59865 .65434 L F
.348 0 0 r
.69192 .64588 m .69114 .64594 L .68892 .64531 L F
.457 .882 .912 r
.69403 .64535 m .69114 .64594 L .69192 .64588 L F
.573 .57 .812 r
.36776 .66444 m .36697 .66782 L .36597 .66436 L F
.36776 .66444 m .36892 .6675 L .36697 .66782 L F
.8 .7 .755 r
.69498 .70189 m .69835 .70214 L .69586 .70526 L F
.834 .989 .725 r
.62589 .6317 m .6253 .63331 L .62719 .63107 L F
.302 0 0 r
.62857 .63145 m .62719 .63107 L .62953 .63028 L F
.62857 .63145 m .62589 .6317 L .62719 .63107 L F
.638 .767 .941 r
.70252 .69442 m .69937 .69385 L .70164 .69355 L F
.186 0 0 r
.70164 .69355 m .70486 .69382 L .70252 .69442 L F
.56 .932 .815 r
.71677 .63456 m .71182 .63701 L .71537 .63635 L F
.921 .959 .79 r
.60792 .63513 m .60908 .6316 L .60992 .63218 L F
0 0 0 r
.52343 .77183 m .52152 .77297 L .51999 .774 L F
.675 .741 .9 r
.68846 .58724 m .68844 .59034 L .68653 .58733 L F
.68846 .58724 m .69084 .58932 L .68844 .59034 L F
.259 .74 .931 r
.32431 .64965 m .32378 .6502 L .32237 .65029 L F
.32431 .64965 m .32591 .65007 L .32378 .6502 L F
.487 .042 .118 r
.65382 .60447 m .65201 .60377 L .65095 .60526 L F
.342 0 0 r
.41492 .72403 m .41687 .72418 L .41835 .72354 L F
.277 0 0 r
.41687 .72418 m .42041 .72376 L .41835 .72354 L F
.355 .789 .613 r
.65221 .60817 m .6553 .60638 L .65429 .60749 L F
.54 .045 .029 r
.65429 .60749 m .6553 .60638 L .6582 .60752 L F
.548 .207 .342 r
.6553 .60638 m .65766 .60623 L .6582 .60752 L F
.632 .473 .649 r
.34742 .76978 m .34751 .77219 L .34971 .76951 L F
.459 .811 .997 r
.66021 .6428 m .66323 .64307 L .66237 .64242 L F
.482 .823 .998 r
.66237 .64242 m .66323 .64307 L .66533 .64267 L F
.362 0 .127 r
.42986 .78463 m .4312 .78259 L .43326 .78224 L F
.661 .483 .633 r
.5634 .80156 m .56494 .80278 L .56681 .80225 L F
.746 .407 .408 r
.56494 .80278 m .56799 .80373 L .56681 .80225 L F
.168 .381 .828 r
.33197 .80189 m .33235 .80143 L .33138 .80082 L F
.566 .875 .583 r
.33129 .80247 m .33235 .80143 L .33197 .80189 L F
.61 .661 .875 r
.48484 .74849 m .48572 .75094 L .48797 .75054 L F
.524 .494 .765 r
.48572 .75094 m .48855 .75354 L .48797 .75054 L F
.5 .181 .358 r
.32321 .71483 m .32588 .71308 L .32395 .71372 L F
.558 .344 .545 r
.37786 .76945 m .37778 .77208 L .37546 .77219 L F
.547 .476 .727 r
.37926 .76613 m .37999 .76924 L .37786 .76945 L F
.565 .349 .546 r
.38006 .77173 m .37786 .76945 L .37999 .76924 L F
.38006 .77173 m .37778 .77208 L .37786 .76945 L F
.626 .799 .965 r
.69913 .602 m .70043 .59998 L .69773 .60105 L F
.69913 .602 m .70145 .60138 L .70043 .59998 L F
.889 .483 .238 r
.70517 .71077 m .70539 .71216 L .70608 .71067 L F
.611 .955 .88 r
.70762 .70948 m .70608 .71067 L .70756 .70901 L F
.754 .53 .592 r
.70539 .71216 m .70707 .70972 L .70608 .71067 L F
.70707 .70972 m .70756 .70901 L .70608 .71067 L F
.652 .965 .912 r
.70647 .70926 m .70517 .71077 L .70707 .70972 L F
.754 .53 .592 r
.70707 .70972 m .70762 .70948 L .70756 .70901 L F
.652 .965 .912 r
.70753 .70925 m .70707 .70972 L .70791 .70925 L F
.70647 .70926 m .70707 .70972 L .70753 .70925 L F
.611 .955 .88 r
.70762 .70948 m .70695 .70983 L .70608 .71067 L F
.70695 .70983 m .70517 .71077 L .70608 .71067 L F
.70791 .70925 m .70707 .70972 L .70762 .70948 L F
.70707 .70972 m .70517 .71077 L .70762 .70948 L F
.754 .53 .592 r
.70539 .71216 m .70808 .71305 L .70762 .70948 L F
.70539 .71216 m .70762 .70948 L .70707 .70972 L F
.70808 .71305 m .70897 .71334 L .70756 .70901 L F
.659 .478 .629 r
.70756 .70901 m .70897 .71334 L .71071 .71219 L F
.70756 .70901 m .71071 .71219 L .70997 .70882 L F
.418 .179 .443 r
.70756 .70901 m .70997 .70882 L .70791 .70925 L F
.245 .759 .826 r
.70997 .70882 m .70928 .70891 L .70791 .70925 L F
.611 .955 .88 r
.70791 .70925 m .7076 .70933 L .70756 .70901 L F
.245 .759 .826 r
.70928 .70891 m .70647 .70926 L .70791 .70925 L F
.611 .955 .88 r
.70791 .70925 m .70762 .70948 L .7076 .70933 L F
.344 .801 .676 r
.48474 .88586 m .48654 .88498 L .4835 .88642 L F
.924 .71 .595 r
.67174 .63183 m .67454 .63148 L .674 .63001 L F
.619 .231 .287 r
.67123 .63409 m .67454 .63148 L .67174 .63183 L F
.67123 .63409 m .67614 .63406 L .67591 .63367 L F
.983 .847 .463 r
.67352 .63619 m .67435 .63575 L .67614 .63406 L F
.72 .593 .713 r
.67116 .63636 m .67614 .63406 L .67123 .63409 L F
.67116 .63636 m .67352 .63619 L .67614 .63406 L F
.563 0 0 r
.67635 .63396 m .67743 .63507 L .67545 .63384 L F
.67651 .63398 m .67666 .63417 L .67635 .63396 L F
.67666 .63417 m .67743 .63507 L .67635 .63396 L F
.619 .231 .287 r
.67364 .63219 m .67591 .63367 L .67454 .63148 L F
.67123 .63409 m .67591 .63367 L .67364 .63219 L F
.539 .298 .498 r
.36908 .68936 m .3687 .69178 L .36631 .69192 L F
.438 .27 .555 r
.37095 .68637 m .37084 .68886 L .36908 .68936 L F
.334 .121 .434 r
.37031 .69088 m .36908 .68936 L .37084 .68886 L F
.37031 .69088 m .3687 .69178 L .36908 .68936 L F
.569 .774 .976 r
.33882 .80079 m .34035 .80174 L .33902 .80059 L F
.652 .861 .478 r
.33862 .80397 m .34035 .80174 L .33882 .80079 L F
.33862 .80397 m .33834 .80461 L .34035 .80174 L F
.368 .681 .978 r
.33902 .80059 m .34035 .80174 L .34098 .80071 L F
.134 .371 .828 r
.34035 .80174 m .34344 .80419 L .34098 .80071 L F
.392 .487 .837 r
.34035 .80174 m .34322 .80447 L .34344 .80419 L F
.545 .383 .612 r
.35936 .7506 m .36136 .74783 L .35936 .74822 L F
.586 .494 .717 r
.50537 .7534 m .50359 .75592 L .5031 .75395 L F
.50537 .7534 m .50583 .75567 L .50359 .75592 L F
.587 .806 .983 r
.70429 .73155 m .70529 .73252 L .70763 .73193 L F
.77 .684 .768 r
.65929 .60024 m .65728 .60288 L .65624 .60045 L F
.982 .707 .419 r
.65624 .60045 m .65728 .60288 L .65643 .60213 L F
.983 .716 .436 r
.65643 .60213 m .65728 .60288 L .65607 .60394 L F
.333 0 0 r
.33544 .81796 m .33828 .81807 L .33534 .81763 L F
.56 .499 .744 r
.33786 .81481 m .33828 .81807 L .34026 .81778 L F
.42 .007 .147 r
.38533 .73162 m .38747 .73137 L .3888 .72955 L F
.44 .038 .18 r
.38747 .73137 m .39091 .72927 L .3888 .72955 L F
.099 0 .109 r
.33501 .72517 m .33439 .72394 L .33599 .72399 L F
.33501 .72517 m .33348 .726 L .33439 .72394 L F
.844 .952 .603 r
.62828 .60705 m .62958 .60583 L .628 .60878 L F
.62828 .60705 m .62936 .60544 L .62958 .60583 L F
.879 .865 .419 r
.62958 .60583 m .62936 .60544 L .63038 .60198 L F
.911 .831 .755 r
.59961 .64618 m .5967 .64828 L .59874 .64546 L F
.59961 .64618 m .59797 .64915 L .5967 .64828 L F
.889 .94 .841 r
.6018 .64347 m .59961 .64618 L .59874 .64546 L F
.631 .575 .774 r
.68742 .70239 m .6908 .70497 L .69101 .70313 L F
.067 0 0 r
.30738 .65667 m .30935 .65618 L .311 .65507 L F
0 0 0 r
.311 .65507 m .31127 .65554 L .31311 .65462 L F
.311 .65507 m .30935 .65618 L .31127 .65554 L F
.6 .753 .951 r
.47552 .72996 m .4722 .7292 L .47434 .72862 L F
.706 .779 .909 r
.47774 .72893 m .47552 .72996 L .47434 .72862 L F
.306 .743 .967 r
.39924 .75017 m .39949 .74942 L .39719 .74971 L F
.39924 .75017 m .401 .75008 L .39949 .74942 L F
.85 .434 0 r
.73045 .71486 m .73033 .71342 L .72956 .71332 L F
.73045 .71486 m .73125 .71557 L .73033 .71342 L F
0 0 .397 r
.3349 .81679 m .33534 .81763 L .33544 .81796 L F
.784 .992 .883 r
.33544 .81796 m .33534 .81763 L .33484 .81806 L F
.542 .403 .641 r
.35338 .76169 m .35527 .75839 L .35327 .7588 L F
0 0 0 r
.43533 .73682 m .43373 .73949 L .4328 .74004 L F
.537 .222 .381 r
.43699 .73705 m .43373 .73949 L .43533 .73682 L F
.243 0 0 r
.70233 .64317 m .70234 .64349 L .69992 .64415 L F
.184 0 0 r
.42739 .74255 m .42387 .7436 L .42521 .74291 L F
0 0 0 r
.65773 .63017 m .65704 .63194 L .65854 .63028 L F
.461 .196 .424 r
.72371 .61146 m .72519 .61271 L .7263 .61119 L F
.376 .207 .521 r
.72371 .61146 m .72381 .61342 L .72519 .61271 L F
.903 .786 .723 r
.61686 .6483 m .61964 .64646 L .61831 .64532 L F
.61686 .6483 m .61896 .64902 L .61964 .64646 L F
.746 .941 .948 r
.72188 .62791 m .72084 .62729 L .7178 .62955 L F
.823 .843 .379 r
.7224 .62543 m .72188 .62791 L .72299 .62438 L F
.858 .949 .873 r
.7224 .62543 m .72084 .62729 L .72188 .62791 L F
.682 .945 .961 r
.64049 .64755 m .63949 .64926 L .63818 .65043 L F
.64049 .64755 m .64123 .64799 L .63949 .64926 L F
.723 .667 .794 r
.69988 .61999 m .70052 .62097 L .70279 .61929 L F
.64 .651 .845 r
.43699 .73705 m .43798 .73978 L .43973 .73821 L F
.637 .646 .842 r
.43798 .73978 m .44174 .74024 L .43973 .73821 L F
.594 .538 .762 r
.43798 .73978 m .4417 .74262 L .44174 .74024 L F
.895 .988 .768 r
.61556 .62491 m .61563 .6234 L .61731 .62246 L F
.862 .985 .845 r
.61324 .62601 m .61563 .6234 L .61556 .62491 L F
.85 .996 .767 r
.60128 .66516 m .59903 .66793 L .59875 .66742 L F
.918 .941 .584 r
.59903 .66793 m .59782 .66926 L .59875 .66742 L F
.554 .645 .894 r
.35151 .68135 m .35275 .68333 L .35088 .68378 L F
.681 .142 0 r
.35088 .68378 m .35107 .68469 L .34992 .68277 L F
.169 .137 .576 r
.3512 .68597 m .35235 .68553 L .35159 .68462 L F
.35105 .68496 m .35159 .68462 L .35088 .68378 L F
.3512 .68597 m .35159 .68462 L .35105 .68496 L F
.842 .765 .777 r
.3535 .68352 m .35487 .68296 L .35381 .68334 L F
.529 .321 .543 r
.35487 .68296 m .3572 .68031 L .35553 .68108 L F
.35487 .68296 m .35697 .68258 L .3572 .68031 L F
.681 .142 0 r
.35088 .68378 m .35235 .68553 L .35107 .68469 L F
.842 .765 .777 r
.35107 .68469 m .35235 .68553 L .35487 .68296 L F
.654 .447 .591 r
.35487 .68296 m .35235 .68553 L .35482 .68528 L F
.49 .314 .569 r
.35487 .68296 m .35482 .68528 L .35674 .6848 L F
.564 0 0 r
.35674 .6848 m .35381 .68334 L .35487 .68296 L F
.35674 .6848 m .35535 .6845 L .35381 .68334 L F
.222 .231 .658 r
.35381 .68334 m .35535 .6845 L .35506 .68255 L F
.596 .665 .887 r
.35487 .68296 m .35275 .68333 L .35151 .68135 L F
.35487 .68296 m .35151 .68135 L .3536 .68071 L F
.548 .551 .809 r
.35446 .67896 m .35553 .68108 L .3572 .68031 L F
.585 .601 .834 r
.35561 .67952 m .35487 .68296 L .3536 .68071 L F
.222 .231 .658 r
.35381 .68334 m .35506 .68255 L .35479 .68065 L F
.842 .765 .777 r
.35305 .68371 m .3535 .68352 L .35381 .68334 L F
.35107 .68469 m .35258 .684 L .35305 .68371 L F
.35258 .684 m .35487 .68296 L .35305 .68371 L F
.434 .562 .884 r
.37467 .67175 m .37363 .67315 L .37196 .67048 L F
.465 .606 .906 r
.37467 .67175 m .37589 .67353 L .37363 .67315 L F
.68 .668 .831 r
.46866 .74026 m .47231 .74256 L .47094 .74007 L F
.725 .756 .877 r
.47094 .74007 m .47231 .74256 L .47451 .74047 L F
.666 .643 .817 r
.47231 .74256 m .47572 .74313 L .47451 .74047 L F
.574 .431 .649 r
.34556 .77497 m .3477 .77465 L .34751 .77219 L F
.552 .379 .6 r
.34561 .77726 m .3477 .77465 L .34556 .77497 L F
.946 .952 .738 r
.51313 .7617 m .51421 .75831 L .51519 .7614 L F
.528 .413 .666 r
.51519 .7614 m .51343 .76395 L .51313 .7617 L F
0 .099 .643 r
.50075 .87942 m .50029 .87934 L .49901 .87776 L F
0 0 .55 r
.50156 .88161 m .50029 .87934 L .50075 .87942 L F
.85 .996 .767 r
.60128 .66516 m .59875 .66742 L .59941 .66446 L F
.464 0 .062 r
.36389 .80769 m .35975 .80902 L .36135 .80838 L F
0 0 0 r
.65909 .60884 m .65904 .60931 L .6582 .60752 L F
.65909 .60884 m .6589 .6104 L .65904 .60931 L F
.049 .083 .575 r
.48173 .87437 m .4833 .87556 L .48344 .87352 L F
.48173 .87437 m .48236 .87658 L .4833 .87556 L F
.653 .635 .82 r
.46367 .73979 m .46673 .74089 L .46575 .73951 L F
.611 .701 .908 r
.46575 .73951 m .46673 .74089 L .46866 .74026 L F
.856 .997 .795 r
.61779 .6207 m .6195 .61984 L .61731 .62246 L F
.859 .996 .775 r
.61563 .6234 m .61779 .6207 L .61731 .62246 L F
0 0 .258 r
.49255 .87031 m .49205 .86864 L .49048 .8683 L F
.49263 .87034 m .49205 .86864 L .49255 .87031 L F
.191 .071 .477 r
.48879 .86872 m .49022 .86963 L .49048 .8683 L F
.48879 .86872 m .48876 .8707 L .49024 .86971 L F
.608 .369 .528 r
.49173 .87027 m .49048 .8683 L .49015 .87001 L F
.191 .071 .477 r
.49022 .86963 m .49024 .86971 L .49028 .86966 L F
.48879 .86872 m .49024 .86971 L .49022 .86963 L F
.608 .369 .528 r
.49022 .86963 m .49 .86879 L .489 .86983 L F
.49022 .86963 m .49048 .8683 L .49 .86879 L F
.191 .071 .477 r
.49022 .86963 m .49028 .86966 L .49048 .8683 L F
.722 .361 .366 r
.489 .86983 m .49048 .8683 L .49028 .86966 L F
.496 .892 .743 r
.489 .86983 m .48999 .86897 L .49103 .86975 L F
.49033 .87004 m .49103 .86975 L .49173 .87027 L F
.191 .071 .477 r
.48876 .8707 m .48875 .87144 L .48974 .87029 L F
.48876 .8707 m .48974 .87029 L .49024 .86971 L F
.895 .982 .707 r
.48875 .87144 m .489 .86983 L .49024 .86971 L F
.608 .369 .528 r
.49015 .87001 m .49021 .86971 L .489 .86983 L F
.49021 .86971 m .49022 .86963 L .489 .86983 L F
.895 .982 .707 r
.49024 .86971 m .489 .86983 L .49028 .86966 L F
.496 .892 .743 r
.489 .86983 m .49103 .86975 L .49033 .87004 L F
.608 .369 .528 r
.49173 .87027 m .49265 .8704 L .49048 .8683 L F
.355 .743 .987 r
.48999 .86897 m .49283 .86958 L .49201 .87009 L F
.49091 .86966 m .49201 .87009 L .49173 .87027 L F
.48999 .86897 m .49201 .87009 L .49091 .86966 L F
0 0 .258 r
.49265 .8704 m .49263 .87034 L .49255 .87031 L F
.863 .627 .58 r
.61633 .65057 m .61896 .64902 L .61686 .6483 L F
.61633 .65057 m .61811 .65121 L .61896 .64902 L F
.98 .752 .522 r
.73004 .73515 m .72879 .73469 L .72899 .73136 L F
.8 .341 0 r
.73004 .73515 m .72987 .73574 L .72879 .73469 L F
.73004 .73515 m .73087 .73671 L .72987 .73574 L F
0 0 0 r
.40486 .79249 m .40363 .7932 L .40251 .79338 L F
.40363 .7932 m .40171 .79385 L .40251 .79338 L F
.934 .618 .162 r
.66842 .60539 m .66955 .60849 L .66907 .60657 L F
.457 .544 .857 r
.71912 .74338 m .71758 .74275 L .7186 .74286 L F
.923 .872 .769 r
.60792 .63513 m .60512 .63727 L .60715 .63448 L F
.60792 .63513 m .60622 .6381 L .60512 .63727 L F
.921 .959 .79 r
.60792 .63513 m .60715 .63448 L .60908 .6316 L F
.807 .72 .769 r
.49387 .7625 m .49516 .76273 L .4958 .76116 L F
.49387 .7625 m .49373 .76449 L .49516 .76273 L F
.573 .344 .53 r
.49373 .76449 m .49568 .76549 L .49516 .76273 L F
.524 .502 .774 r
.49516 .76273 m .49776 .76096 L .4958 .76116 L F
.49516 .76273 m .49914 .76422 L .49776 .76096 L F
.673 .544 .699 r
.49568 .76549 m .49914 .76422 L .49516 .76273 L F
.453 .499 .816 r
.37155 .66886 m .37021 .67055 L .36892 .6675 L F
.461 .51 .823 r
.37155 .66886 m .37196 .67048 L .37021 .67055 L F
.514 .15 .286 r
.64742 .60837 m .6489 .61025 L .64737 .61092 L F
.64742 .60837 m .64975 .60825 L .6489 .61025 L F
.293 0 0 r
.45966 .77487 m .45619 .77595 L .45742 .77487 L F
.563 .503 .746 r
.53158 .77238 m .5295 .77279 L .52902 .77025 L F
.53158 .77238 m .52902 .77025 L .5292 .77018 L F
.53158 .77238 m .52896 .76996 L .53094 .76906 L F
.65 .505 .673 r
.53358 .77123 m .53158 .77238 L .53094 .76906 L F
.251 0 .137 r
.53116 .76938 m .53001 .77139 L .53196 .7706 L F
.53094 .76906 m .53075 .76955 L .53116 .76938 L F
.53075 .76955 m .53001 .77139 L .53116 .76938 L F
.563 .503 .746 r
.5292 .77018 m .52902 .77025 L .52896 .76996 L F
.522 .43 .692 r
.53169 .77383 m .5295 .77279 L .53158 .77238 L F
.53169 .77383 m .52986 .77481 L .5295 .77279 L F
0 0 .039 r
.65385 .58822 m .6536 .58979 L .6538 .5872 L F
.65385 .58822 m .6538 .5872 L .65078 .58737 L F
0 .239 .748 r
.6538 .5872 m .65597 .58884 L .65658 .58713 L F
0 .091 .632 r
.50031 .87875 m .49901 .87776 L .49857 .87624 L F
.50031 .87875 m .50075 .87942 L .49901 .87776 L F
0 0 0 r
.64951 .58797 m .64855 .58789 L .64754 .58886 L F
.64951 .58797 m .65078 .58737 L .64855 .58789 L F
.7 .342 .366 r
.49924 .77684 m .49568 .77524 L .49924 .77508 L F
.695 .384 .445 r
.49924 .77508 m .50124 .77735 L .49924 .77684 L F
.157 .65 .917 r
.69888 .64356 m .69992 .64415 L .70015 .64371 L F
.373 .838 .882 r
.69992 .64415 m .70234 .64349 L .70015 .64371 L F
.677 .72 .882 r
.45154 .73678 m .45479 .73754 L .45351 .73671 L F
.629 .846 .983 r
.45351 .73671 m .45479 .73754 L .45684 .7368 L F
.789 .666 .727 r
.70515 .72121 m .70839 .72147 L .70746 .7206 L F
.70515 .72121 m .70645 .7242 L .70839 .72147 L F
.483 .771 .995 r
.70746 .7206 m .70839 .72147 L .70979 .72035 L F
.267 .361 .774 r
.70839 .72147 m .71086 .72351 L .70979 .72035 L F
.184 0 .197 r
.48422 .87116 m .48488 .87293 L .48653 .87188 L F
.48422 .87116 m .48344 .87352 L .48488 .87293 L F
.065 .617 .824 r
.70486 .69382 m .70701 .69396 L .70815 .69421 L F
.709 .174 0 r
.70902 .6958 m .70815 .69421 L .70701 .69396 L F
.70902 .6958 m .71051 .69635 L .70815 .69421 L F
.624 .581 .785 r
.48744 .75866 m .48893 .75601 L .48669 .75653 L F
.48744 .75866 m .49027 .75925 L .48893 .75601 L F
0 0 0 r
.63161 .62499 m .63092 .62604 L .62925 .62743 L F
.343 .358 .732 r
.62925 .62743 m .63092 .62604 L .63153 .62943 L F
.506 .368 .627 r
.62925 .62743 m .63153 .62943 L .62953 .63028 L F
.55 .668 .915 r
.46231 .73768 m .46367 .73979 L .46575 .73951 L F
.355 .29 .645 r
.35198 .67571 m .35244 .67819 L .35372 .67749 L F
.754 .564 .639 r
.35372 .67749 m .3503 .67489 L .35198 .67571 L F
.756 .675 .771 r
.56239 .80973 m .56573 .81025 L .5648 .80745 L F
.325 .803 .737 r
.63276 .65033 m .63295 .65038 L .63131 .65101 L F
0 0 0 r
.63044 .65278 m .63276 .65033 L .63131 .65101 L F
.623 .903 .603 r
.6314 .65151 m .63256 .65029 L .63276 .65033 L F
.63256 .65029 m .63385 .64893 L .63276 .65033 L F
.325 .803 .737 r
.63276 .65033 m .63419 .64991 L .63295 .65038 L F
.65 .451 .602 r
.55792 .80379 m .56115 .80424 L .56108 .80169 L F
.635 .44 .601 r
.56108 .80169 m .56115 .80424 L .5634 .80156 L F
.561 .564 .813 r
.48306 .73173 m .48212 .73495 L .481 .73182 L F
.48306 .73173 m .48425 .73469 L .48212 .73495 L F
.782 .924 .931 r
.69739 .62159 m .69514 .62279 L .69742 .62207 L F
.69739 .62159 m .69514 .62279 L .69742 .62207 L F
.203 0 .019 r
.69742 .62207 m .69739 .62159 L .69953 .62118 L F
.69742 .62207 m .69739 .62159 L .69953 .62118 L F
.511 .251 .457 r
.33342 .70779 m .33551 .70745 L .33597 .70545 L F
.477 .22 .445 r
.33597 .70545 m .33752 .70703 L .33798 .70496 L F
.33597 .70545 m .33551 .70745 L .33752 .70703 L F
.764 .467 .482 r
.63005 .63579 m .63041 .63793 L .63307 .63808 L F
.566 .4 .615 r
.70898 .59635 m .71144 .59408 L .70893 .59539 L F
.652 .823 .399 r
.64142 .62542 m .64132 .62551 L .64196 .62458 L F
.012 0 .081 r
.64196 .62458 m .64404 .62359 L .64426 .62266 L F
.144 0 .374 r
.64343 .626 m .64196 .62458 L .64132 .62551 L F
.64343 .626 m .64404 .62359 L .64196 .62458 L F
.891 .979 .817 r
.73356 .74184 m .73254 .74423 L .73531 .74272 L F
.73356 .74184 m .73168 .7441 L .73254 .74423 L F
0 0 0 r
.32576 .73138 m .32452 .73154 L .32722 .72945 L F
.393 .021 .208 r
.32901 .72885 m .32576 .73138 L .32722 .72945 L F
.33 .066 .354 r
.52986 .77481 m .52961 .77714 L .52746 .77734 L F
.359 .107 .39 r
.5291 .7792 m .52746 .77734 L .52961 .77714 L F
.5291 .7792 m .52638 .77886 L .52746 .77734 L F
.62 .277 .368 r
.44973 .7673 m .45168 .76897 L .4529 .7667 L F
.474 .062 .177 r
.45168 .76897 m .4552 .76702 L .4529 .7667 L F
.755 .732 .831 r
.71683 .73515 m .71745 .73744 L .71431 .73665 L F
.519 .581 .857 r
.71832 .73637 m .71745 .73744 L .71683 .73515 L F
.5 .553 .841 r
.71832 .73637 m .7191 .73779 L .71745 .73744 L F
.614 .627 .84 r
.49105 .73969 m .48885 .74019 L .48748 .73718 L F
.433 .461 .789 r
.49136 .74229 m .48885 .74019 L .49105 .73969 L F
.485 .007 .044 r
.43702 .7181 m .436 .71876 L .43359 .71851 L F
.43359 .71851 m .436 .71876 L .43702 .7181 L F
0 0 0 r
.43702 .7181 m .436 .71876 L .43782 .71783 L F
.43782 .71783 m .436 .71876 L .43702 .7181 L F
.485 .007 .044 r
.43359 .71851 m .436 .71876 L .43702 .7181 L F
.889 .94 .841 r
.6018 .64347 m .59874 .64546 L .60074 .64268 L F
.89 .9 .829 r
.6018 .64347 m .60287 .6399 L .60394 .64071 L F
.6018 .64347 m .60074 .64268 L .60287 .6399 L F
.858 .483 .338 r
.51099 .78042 m .50931 .78031 L .50799 .77771 L F
.837 .525 .462 r
.51099 .78042 m .5087 .78185 L .50931 .78031 L F
.51099 .78042 m .5114 .78255 L .5087 .78185 L F
.79 .499 .496 r
.51439 .78321 m .51146 .78465 L .5114 .78255 L F
.51439 .78321 m .51469 .78533 L .51146 .78465 L F
.524 .133 .24 r
.39608 .72802 m .39812 .72809 L .39649 .72696 L F
.494 .156 .322 r
.39649 .72696 m .39812 .72809 L .39863 .72671 L F
.661 .14 0 r
.50665 .75898 m .50939 .76113 L .50997 .76004 L F
.50939 .76113 m .50963 .76115 L .50997 .76004 L F
.047 .385 .847 r
.51111 .76011 m .50997 .76004 L .50963 .76115 L F
.876 .769 .741 r
.50963 .76115 m .51028 .7612 L .51111 .76011 L F
.047 .385 .847 r
.51111 .76011 m .50963 .76115 L .50959 .76128 L F
.876 .769 .741 r
.50809 .76102 m .50939 .76113 L .50872 .76083 L F
.593 .022 0 r
.50792 .76048 m .50939 .76113 L .50665 .75898 L F
.876 .769 .741 r
.50792 .76048 m .50809 .76102 L .51111 .76011 L F
.593 .022 0 r
.50792 .76048 m .50959 .76128 L .50939 .76113 L F
.876 .769 .741 r
.50872 .76083 m .50963 .76115 L .51111 .76011 L F
.50939 .76113 m .50963 .76115 L .50872 .76083 L F
.50809 .76102 m .50879 .76317 L .51028 .7612 L F
.661 .14 0 r
.50939 .76113 m .50959 .76128 L .50963 .76115 L F
.574 .581 .822 r
.70085 .72649 m .70195 .72297 L .69943 .72571 L F
.70085 .72649 m .70379 .72671 L .70195 .72297 L F
.135 .655 .885 r
.70427 .72691 m .70379 .72671 L .70085 .72649 L F
.786 .751 .821 r
.718 .60048 m .72119 .60084 L .72006 .59921 L F
.84 .902 .881 r
.71985 .59746 m .72105 .59867 L .7191 .59685 L F
.72107 .59848 m .72105 .59867 L .71921 .59682 L F
.768 .754 .841 r
.7191 .59685 m .72006 .59921 L .72093 .59835 L F
.7191 .59685 m .72093 .59835 L .72229 .59701 L F
.84 .902 .881 r
.71921 .59682 m .71985 .59746 L .7191 .59685 L F
.768 .754 .841 r
.7191 .59685 m .72229 .59701 L .72132 .59614 L F
.84 .902 .881 r
.72132 .59614 m .72107 .59848 L .71921 .59682 L F
.52 .333 .568 r
.72119 .60084 m .7217 .59904 L .72006 .59921 L F
.7217 .59904 m .72229 .59701 L .72093 .59835 L F
.7217 .59904 m .72093 .59835 L .72006 .59921 L F
.792 .301 0 r
.7176 .70369 m .71775 .70286 L .71668 .70233 L F
.797 .309 0 r
.7176 .70369 m .71883 .70444 L .71775 .70286 L F
.648 .583 .768 r
.69101 .70313 m .6908 .70497 L .6941 .70254 L F
.7 .659 .807 r
.47451 .74047 m .47572 .74313 L .47791 .74258 L F
.662 .95 .713 r
.63298 .6236 m .63275 .62352 L .63161 .62499 L F
0 0 0 r
.63161 .62499 m .63275 .62352 L .63092 .62604 L F
.626 .609 .814 r
.71582 .60229 m .718 .60048 L .71485 .5997 L F
.327 .124 .445 r
.5268 .7819 m .52518 .77979 L .52638 .77886 L F
.5268 .7819 m .52523 .7828 L .52518 .77979 L F
.872 .902 .85 r
.60394 .64071 m .60512 .63727 L .60622 .6381 L F
.60394 .64071 m .60287 .6399 L .60512 .63727 L F
.971 .91 .691 r
.70486 .72369 m .70427 .72691 L .70645 .7242 L F
.70486 .72369 m .70379 .72671 L .70427 .72691 L F
.952 .745 .587 r
.34615 .8177 m .34708 .82059 L .34562 .82022 L F
.588 .599 .83 r
.34773 .81752 m .34708 .82059 L .34615 .8177 L F
.34773 .81752 m .34949 .82046 L .34708 .82059 L F
.172 .703 .848 r
.34708 .82059 m .34757 .82028 L .34562 .82022 L F
.34708 .82059 m .34949 .82046 L .34757 .82028 L F
.615 .377 .533 r
.49143 .76677 m .49374 .76657 L .49373 .76449 L F
.573 .344 .53 r
.49373 .76449 m .49374 .76657 L .49568 .76549 L F
.527 .652 .914 r
.38284 .77994 m .37926 .77782 L .3814 .77737 L F
.652 .678 .861 r
.38359 .77679 m .38284 .77994 L .3814 .77737 L F
.38359 .77679 m .38531 .77918 L .38284 .77994 L F
.643 .614 .806 r
.38531 .77918 m .38643 .78111 L .38284 .77994 L F
.524 .324 .55 r
.59473 .6757 m .59481 .67795 L .59265 .6785 L F
.875 .93 .548 r
.59473 .6757 m .59353 .677 L .59489 .67399 L F
.583 .369 .556 r
.59679 .67728 m .59473 .6757 L .59801 .67516 L F
.59679 .67728 m .59481 .67795 L .59473 .6757 L F
.794 .683 .742 r
.69677 .71009 m .69393 .71019 L .69642 .70661 L F
.794 .664 .72 r
.69677 .71009 m .69513 .71307 L .69393 .71019 L F
.795 .991 .753 r
.62182 .61725 m .6195 .61984 L .62026 .6182 L F
.796 .998 .799 r
.62026 .6182 m .6195 .61984 L .61779 .6207 L F
.842 .982 .87 r
.65778 .64516 m .65671 .6448 L .65601 .64666 L F
.82 .982 .885 r
.65927 .64254 m .65778 .64516 L .66021 .6428 L F
.65927 .64254 m .65671 .6448 L .65778 .64516 L F
.675 .513 .658 r
.33897 .78559 m .34198 .78554 L .34133 .78283 L F
.659 .513 .673 r
.34133 .78283 m .34415 .78292 L .3436 .78007 L F
.641 .477 .646 r
.34198 .78554 m .34415 .78292 L .34133 .78283 L F
.526 .306 .524 r
.31502 .67949 m .31323 .67819 L .31529 .67796 L F
.31502 .67949 m .31295 .68008 L .31323 .67819 L F
.408 0 0 r
.46271 .77448 m .46195 .77495 L .45966 .77487 L F
.402 0 0 r
.46511 .77446 m .46195 .77495 L .46271 .77448 L F
.182 .714 .737 r
.40828 .7805 m .40429 .78124 L .40619 .78112 L F
.251 .748 .676 r
.40619 .78112 m .41002 .77975 L .40828 .7805 L F
.082 .63 .834 r
.42168 .7239 m .42252 .72386 L .42382 .72414 L F
.06 0 0 r
.42098 .72412 m .42346 .72381 L .42252 .72386 L F
.293 .764 .937 r
.42252 .72386 m .42461 .72367 L .42588 .72403 L F
.06 0 0 r
.42346 .72381 m .42461 .72367 L .42252 .72386 L F
.082 .63 .834 r
.42041 .72376 m .42252 .72386 L .42168 .7239 L F
.293 .764 .937 r
.42252 .72386 m .42588 .72403 L .42382 .72414 L F
.763 .878 .93 r
.71109 .59894 m .7103 .60106 L .7125 .6001 L F
.727 .871 .949 r
.71109 .59894 m .7125 .6001 L .71477 .59816 L F
.611 .611 .826 r
.7125 .6001 m .71485 .5997 L .71477 .59816 L F
.429 .296 .597 r
.3382 .70247 m .33985 .70196 L .33976 .69962 L F
.486 .326 .589 r
.33798 .70496 m .33985 .70196 L .3382 .70247 L F
.292 0 .179 r
.63831 .65902 m .63584 .66072 L .63611 .65954 L F
.498 .285 .521 r
.37748 .67858 m .37723 .68086 L .37538 .68115 L F
.524 .307 .527 r
.38001 .67804 m .37723 .68086 L .37748 .67858 L F
.741 .4 .405 r
.37308 .80148 m .3765 .80178 L .37571 .80381 L F
.411 .065 .266 r
.37571 .80381 m .3765 .80178 L .37853 .80133 L F
.573 .41 .623 r
.37546 .77219 m .37576 .77507 L .37351 .77529 L F
.645 .508 .681 r
.37611 .77714 m .37351 .77529 L .37576 .77507 L F
.37611 .77714 m .3739 .77773 L .37351 .77529 L F
.747 .794 .891 r
.33527 .80972 m .33654 .8097 L .33337 .80836 L F
.24 .678 .958 r
.39598 .77961 m .39428 .77959 L .39208 .77839 L F
.519 .581 .857 r
.71832 .73637 m .71867 .7339 L .71961 .73473 L F
.477 .781 .998 r
.71867 .7339 m .72092 .73363 L .71961 .73473 L F
.638 .61 .805 r
.71847 .73619 m .72092 .73363 L .71961 .73473 L F
.71863 .73605 m .72092 .73363 L .71847 .73619 L F
.71863 .73605 m .722 .73661 L .72092 .73363 L F
.71832 .73637 m .71857 .73639 L .71863 .73605 L F
.71857 .73639 m .722 .73661 L .71863 .73605 L F
.387 .797 .98 r
.71867 .7339 m .72024 .7331 L .72092 .73363 L F
.427 .062 .239 r
.71899 .73374 m .72001 .73486 L .72024 .7331 L F
.71867 .7339 m .71893 .73408 L .71899 .73374 L F
.71893 .73408 m .72001 .73486 L .71899 .73374 L F
.72001 .73486 m .72039 .73514 L .72035 .73457 L F
.72001 .73486 m .72035 .73457 L .72024 .7331 L F
.638 .61 .805 r
.71832 .73637 m .71863 .73605 L .71847 .73619 L F
0 .032 .581 r
.69371 .72233 m .69459 .72329 L .69291 .72097 L F
0 .534 .738 r
.40015 .78192 m .39706 .78154 L .39909 .78158 L F
.185 0 0 r
.4424 .72459 m .44563 .72484 L .44382 .72509 L F
.842 .723 .732 r
.69498 .70189 m .69586 .70526 L .69331 .70446 L F
.837 .597 .576 r
.69642 .70661 m .69331 .70446 L .69586 .70526 L F
.394 .184 .471 r
.34977 .71237 m .34836 .71084 L .35029 .71045 L F
.34977 .71237 m .34809 .71297 L .34836 .71084 L F
.589 .42 .62 r
.35527 .75839 m .35745 .75583 L .35532 .75619 L F
.385 .751 .992 r
.6845 .58736 m .68126 .58672 L .68371 .58585 L F
.557 .7 .936 r
.68604 .5856 m .6845 .58736 L .68371 .58585 L F
.477 .575 .875 r
.68653 .58733 m .6845 .58736 L .68604 .5856 L F
.565 .461 .694 r
.50392 .74828 m .5044 .75028 L .50228 .75069 L F
.635 .529 .716 r
.50537 .7534 m .50228 .75069 L .5044 .75028 L F
.50537 .7534 m .5031 .75395 L .50228 .75069 L F
.989 .738 .452 r
.69281 .71575 m .69281 .71816 L .69175 .71494 L F
.866 .907 .858 r
.69513 .71307 m .69281 .71575 L .69175 .71494 L F
.596 .349 .512 r
.62187 .67026 m .62394 .67215 L .6219 .67245 L F
.62187 .67026 m .62411 .67001 L .62394 .67215 L F
0 0 0 r
.39431 .78218 m .39598 .77961 L .39706 .78154 L F
0 .182 .707 r
.34001 .80658 m .34094 .80872 L .33834 .80461 L F
0 .101 .656 r
.33862 .80397 m .34001 .80658 L .33834 .80461 L F
.924 .71 .595 r
.67174 .63183 m .674 .63001 L .67314 .62815 L F
.578 .441 .659 r
.3436 .78007 m .34594 .78048 L .34561 .77726 L F
.6 .473 .679 r
.3436 .78007 m .34631 .78259 L .34594 .78048 L F
.3436 .78007 m .34415 .78292 L .34631 .78259 L F
.658 .507 .667 r
.33464 .79104 m .33695 .78835 L .33457 .78845 L F
.661 .56 .731 r
.49053 .76121 m .4924 .7585 L .49027 .75925 L F
.49053 .76121 m .49387 .7625 L .4924 .7585 L F
.257 .01 .334 r
.53113 .77645 m .52986 .77481 L .53169 .77383 L F
.53113 .77645 m .52961 .77714 L .52986 .77481 L F
.102 0 .407 r
.33115 .7991 m .33241 .79865 L .33252 .79606 L F
.592 .021 0 r
.33138 .80082 m .33241 .79865 L .33115 .7991 L F
.353 0 0 r
.44105 .78038 m .4375 .78173 L .43886 .78035 L F
0 0 0 r
.32576 .73138 m .3238 .7319 L .32452 .73154 L F
.46 .455 .766 r
.72646 .6157 m .72698 .6185 L .72411 .61727 L F
.487 .441 .732 r
.72698 .6185 m .72532 .61941 L .72411 .61727 L F
.604 .433 .623 r
.37796 .77469 m .37546 .77219 L .37778 .77208 L F
.37796 .77469 m .37576 .77507 L .37546 .77219 L F
.264 0 0 r
.3545 .65434 m .35699 .65487 L .35566 .65502 L F
.648 .6 .787 r
.35773 .6558 m .35566 .65502 L .35699 .65487 L F
.423 0 0 r
.47602 .77247 m .47301 .77343 L .47372 .77243 L F
.47602 .77247 m .4749 .77366 L .47301 .77343 L F
.604 .118 .074 r
.4783 .7738 m .4749 .77366 L .47602 .77247 L F
.727 .199 0 r
.71243 .69898 m .71448 .70109 L .71465 .7001 L F
.757 .241 0 r
.71448 .70109 m .71668 .70233 L .71465 .7001 L F
.504 .247 .459 r
.36631 .69192 m .36596 .69388 L .36392 .69422 L F
.426 .179 .434 r
.36786 .69305 m .36631 .69192 L .3687 .69178 L F
.36786 .69305 m .36596 .69388 L .36631 .69192 L F
.887 .987 .727 r
.62182 .61725 m .62225 .61536 L .62381 .61428 L F
.846 .999 .799 r
.62602 .61173 m .62381 .61428 L .62436 .61251 L F
.849 .99 .728 r
.62381 .61428 m .62225 .61536 L .62436 .61251 L F
.823 .843 .379 r
.7224 .62543 m .72299 .62438 L .72304 .6245 L F
.401 .209 .503 r
.37692 .68279 m .37538 .68115 L .37723 .68086 L F
.37692 .68279 m .37522 .68339 L .37538 .68115 L F
.628 .472 .651 r
.55654 .80733 m .55893 .8071 L .55792 .80379 L F
.643 .48 .648 r
.55792 .80379 m .5612 .80655 L .56115 .80424 L F
.55792 .80379 m .55893 .8071 L .5612 .80655 L F
.68 .192 .084 r
.64583 .61561 m .64234 .61554 L .64214 .61415 L F
.64583 .61561 m .64565 .6164 L .64234 .61554 L F
.34 .393 .771 r
.64583 .61561 m .64775 .61555 L .64565 .6164 L F
.64583 .61561 m .64703 .61257 L .64775 .61555 L F
.868 .99 .826 r
.71109 .59894 m .70874 .60164 L .7103 .60106 L F
.862 .59 .525 r
.61779 .65568 m .62051 .65421 L .6179 .65335 L F
.61779 .65568 m .62067 .65654 L .62051 .65421 L F
.742 .393 .389 r
.62387 .65625 m .62051 .65421 L .62067 .65654 L F
.511 .106 .21 r
.4552 .76702 m .45746 .76715 L .45825 .76616 L F
.446 0 .075 r
.45746 .76715 m .46051 .76633 L .45825 .76616 L F
.603 .341 .493 r
.61328 .67312 m .61108 .67511 L .61106 .67299 L F
.695 .821 .943 r
.71086 .72351 m .71215 .72466 L .71403 .72366 L F
.705 .524 .641 r
.33231 .79353 m .33446 .79366 L .33464 .79104 L F
.658 .507 .667 r
.33464 .79104 m .3375 .79094 L .33695 .78835 L F
.645 .472 .635 r
.33464 .79104 m .33756 .79326 L .3375 .79094 L F
.33464 .79104 m .33446 .79366 L .33756 .79326 L F
.796 .562 .583 r
.51516 .82748 m .51449 .82544 L .51322 .82629 L F
.632 .452 .622 r
.63945 .60056 m .63924 .60314 L .6376 .6031 L F
.115 .08 .537 r
.6408 .59894 m .63924 .60314 L .63945 .60056 L F
.652 .694 .876 r
.35188 .80985 m .35349 .81225 L .35515 .81158 L F
.648 .745 .92 r
.34166 .81809 m .34386 .81859 L .34235 .81793 L F
.663 .633 .81 r
.34451 .81461 m .34386 .81859 L .342 .81562 L F
.646 .094 0 r
.34386 .81859 m .3443 .8196 L .34235 .81793 L F
.166 .309 .765 r
.34352 .81766 m .34235 .81793 L .3443 .8196 L F
.343 .81637 m .34235 .81793 L .34352 .81766 L F
.648 .745 .92 r
.34026 .81778 m .34166 .81809 L .34235 .81793 L F
.663 .633 .81 r
.34451 .81461 m .34615 .8177 L .34386 .81859 L F
.646 .094 0 r
.34386 .81859 m .34562 .82022 L .3443 .8196 L F
.952 .745 .587 r
.34615 .8177 m .34562 .82022 L .34386 .81859 L F
.898 .959 .827 r
.66678 .61951 m .66492 .622 L .66384 .62163 L F
.882 .636 .562 r
.66492 .622 m .66309 .62313 L .66384 .62163 L F
.358 0 .05 r
.39401 .75181 m .39311 .75051 L .39509 .74995 L F
.39401 .75181 m .39186 .75219 L .39311 .75051 L F
.592 .175 .219 r
.48136 .77245 m .48024 .77431 L .4783 .7738 L F
.658 .248 .256 r
.48366 .77425 m .48024 .77431 L .48136 .77245 L F
.675 .155 0 r
.48509 .77425 m .48366 .77425 L .48136 .77245 L F
.886 .99 .751 r
.62182 .61725 m .62026 .6182 L .62225 .61536 L F
.64 .521 .702 r
.3375 .79094 m .33902 .78789 L .33695 .78835 L F
.326 .735 .979 r
.45662 .72604 m .45992 .72668 L .45788 .7269 L F
.705 .348 .369 r
.50799 .77771 m .50688 .77991 L .50461 .77764 L F
.809 .474 .421 r
.50799 .77771 m .50931 .78031 L .50688 .77991 L F
.872 .484 .299 r
.59265 .6785 m .59149 .67992 L .59353 .677 L F
.59265 .6785 m .59229 .68013 L .59149 .67992 L F
.703 .294 .267 r
.59443 .68012 m .59265 .6785 L .59481 .67795 L F
.59443 .68012 m .59229 .68013 L .59265 .6785 L F
.617 .058 0 r
.41626 .74228 m .41511 .74243 L .41477 .74214 L F
.163 .701 .737 r
.41702 .74208 m .41626 .74228 L .41983 .74216 L F
.41702 .74208 m .41511 .74243 L .41626 .74228 L F
.435 .046 .201 r
.69254 .63778 m .69526 .63562 L .69338 .63856 L F
.781 .754 .829 r
.33374 .8112 m .33252 .80932 L .33237 .80968 L F
.33374 .8112 m .33527 .80972 L .33252 .80932 L F
.715 .266 .184 r
.4328 .74004 m .4309 .74072 L .42957 .73932 L F
.554 .247 .402 r
.43373 .73949 m .4309 .74072 L .4328 .74004 L F
.099 0 0 r
.34822 .81092 m .35019 .81001 L .35188 .80985 L F
.379 0 0 r
.38015 .73175 m .38324 .73192 L .38081 .73169 L F
.491 .7 .962 r
.68683 .59436 m .68886 .59527 L .68708 .59438 L F
.873 .52 .378 r
.68886 .59527 m .68821 .5971 L .68708 .59438 L F
.87 .467 .008 r
.68708 .59438 m .68821 .5971 L .68715 .59596 L F
.449 .161 .383 r
.68715 .59596 m .68879 .59456 L .68708 .59438 L F
.68879 .59456 m .68992 .59359 L .68708 .59438 L F
.491 .7 .962 r
.68637 .59415 m .68683 .59436 L .68708 .59438 L F
.724 .342 .327 r
.68886 .59527 m .69168 .59748 L .68821 .5971 L F
.556 .308 .495 r
.34809 .71297 m .34538 .71528 L .34613 .71367 L F
.303 .477 .866 r
.66038 .58584 m .65931 .58717 L .65832 .58622 L F
.66038 .58584 m .6624 .58864 L .65931 .58717 L F
.522 .341 .577 r
.36564 .7424 m .36766 .74202 L .36571 .74004 L F
.557 .342 .544 r
.36571 .74004 m .36766 .74202 L .36784 .7397 L F
.238 0 .213 r
.38545 .75785 m .38367 .7589 L .38634 .7562 L F
.31 0 .256 r
.3876 .75636 m .38634 .7562 L .38798 .75573 L F
.3876 .75636 m .38545 .75785 L .38634 .7562 L F
0 .092 .645 r
.66411 .59038 m .66289 .58968 L .6624 .58864 L F
.66411 .59038 m .66499 .59194 L .66289 .58968 L F
.729 .636 .754 r
.55686 .80974 m .56045 .81079 L .55893 .8071 L F
.665 .604 .777 r
.55893 .8071 m .56045 .81079 L .56239 .80973 L F
.698 .291 .272 r
.46824 .76396 m .4703 .76585 L .4716 .76421 L F
.585 .188 .257 r
.4703 .76585 m .47388 .76428 L .4716 .76421 L F
.979 .752 .525 r
.36888 .80452 m .36773 .80629 L .36527 .80654 L F
.36888 .80452 m .36879 .80696 L .36773 .80629 L F
.701 .509 .626 r
.37154 .80421 m .36879 .80696 L .36888 .80452 L F
.45 .734 .988 r
.34041 .65239 m .33819 .65263 L .33653 .65141 L F
.421 .045 .218 r
.43884 .77217 m .44096 .77185 L .44206 .76965 L F
.292 0 .154 r
.44206 .76965 m .4429 .77119 L .44409 .76918 L F
.44206 .76965 m .44096 .77185 L .4429 .77119 L F
.274 .015 .328 r
.373 .68392 m .37249 .68578 L .37095 .68637 L F
.464 .323 .603 r
.37249 .68578 m .37084 .68886 L .37095 .68637 L F
.365 0 .178 r
.52896 .76996 m .53001 .77139 L .53094 .76906 L F
.52896 .76996 m .52789 .77189 L .53001 .77139 L F
.921 .672 .545 r
.38112 .67031 m .37956 .67104 L .38003 .67009 L F
.38112 .67031 m .38144 .67275 L .37956 .67104 L F
.144 .27 .736 r
.38201 .66911 m .38112 .67031 L .38003 .67009 L F
.38201 .66911 m .38299 .67208 L .38112 .67031 L F
.417 .315 .631 r
.38299 .67208 m .38144 .67275 L .38112 .67031 L F
.48 .104 .249 r
.41579 .7761 m .41774 .77625 L .41785 .77482 L F
.41579 .7761 m .41472 .77756 L .41774 .77625 L F
.592 .909 .98 r
.30742 .68283 m .30604 .68341 L .30586 .68368 L F
.574 .888 .99 r
.30586 .68368 m .30604 .68341 L .30554 .68359 L F
.214 .721 .897 r
.42588 .72403 m .42795 .72393 L .42927 .72422 L F
.086 .638 .822 r
.42795 .72393 m .43146 .7242 L .42927 .72422 L F
.7 .659 .807 r
.47451 .74047 m .47791 .74258 L .47664 .73965 L F
.548 .543 .801 r
.47791 .74258 m .47892 .73901 L .47664 .73965 L F
.47791 .74258 m .48006 .74219 L .47892 .73901 L F
.521 .452 .72 r
.4789 .74581 m .48006 .74219 L .47791 .74258 L F
.907 .743 .667 r
.49622 .87688 m .49356 .87943 L .49462 .87629 L F
.49622 .87688 m .49574 .87976 L .49356 .87943 L F
.55 .871 .994 r
.49722 .87573 m .49622 .87688 L .49462 .87629 L F
.49722 .87573 m .49857 .87624 L .49622 .87688 L F
.906 .749 .675 r
.69546 .69736 m .695 .69966 L .69401 .69682 L F
.115 0 .217 r
.33342 .70779 m .33131 .71056 L .33283 .70947 L F
0 0 0 r
.33131 .71056 m .33139 .71084 L .33283 .70947 L F
.33131 .71056 m .32948 .71185 L .33139 .71084 L F
.894 .751 .696 r
.53091 .83371 m .53193 .83652 L .53256 .83444 L F
.549 .557 .815 r
.51701 .76568 m .51343 .76395 L .51668 .76395 L F
.346 0 0 r
.51512 .76395 m .51556 .76419 L .51668 .76395 L F
.51343 .76395 m .51556 .76419 L .51512 .76395 L F
.528 .413 .666 r
.51519 .7614 m .51556 .76419 L .51343 .76395 L F
.549 .557 .815 r
.51701 .76568 m .51668 .76395 L .51556 .76419 L F
0 .421 .825 r
.51756 .76409 m .51668 .76395 L .51556 .76419 L F
0 .252 .761 r
.51668 .76395 m .51756 .76409 L .51556 .76419 L F
.478 .677 .953 r
.51556 .76419 m .51756 .76409 L .51432 .7627 L F
.51556 .76419 m .51756 .76409 L .51432 .7627 L F
.815 .721 .762 r
.51432 .7627 m .51577 .76431 L .51556 .76419 L F
.51577 .76431 m .51701 .76568 L .51556 .76419 L F
.339 0 0 r
.70044 .597 m .70228 .59735 L .7041 .59744 L F
.369 .794 .972 r
.70228 .59735 m .70563 .59749 L .7041 .59744 L F
.837 .972 .66 r
.62664 .60993 m .628 .60878 L .62602 .61173 L F
.886 .973 .663 r
.62664 .60993 m .62828 .60705 L .628 .60878 L F
.408 .132 .379 r
.62625 .65625 m .62879 .65392 L .62667 .65452 L F
.56 .499 .744 r
.33786 .81481 m .34026 .81778 L .33898 .81476 L F
.647 .442 .592 r
.33902 .78789 m .34198 .78554 L .33897 .78559 L F
.517 .836 .999 r
.49561 .8414 m .49896 .8416 L .49715 .84215 L F
.427 .21 .48 r
.49896 .8416 m .4968 .84431 L .49715 .84215 L F
.674 .263 .258 r
.47372 .77243 m .47301 .77343 L .47095 .77208 L F
.158 0 .318 r
.42957 .73932 m .42898 .74143 L .42917 .73933 L F
.57 .212 .322 r
.32084 .67544 m .31973 .67749 L .31732 .67753 L F
.388 .009 .193 r
.32293 .67516 m .31973 .67749 L .32084 .67544 L F
.183 .476 .894 r
.35699 .65487 m .35985 .65634 L .35773 .6558 L F
.604 .503 .713 r
.36128 .65889 m .35773 .6558 L .35985 .65634 L F
.36128 .65889 m .35911 .65961 L .35773 .6558 L F
.701 .509 .626 r
.37154 .80421 m .37248 .80839 L .36879 .80696 L F
0 0 0 r
.37154 .80421 m .37308 .80148 L .37299 .80388 L F
.591 .44 .644 r
.37318 .80651 m .37154 .80421 L .37299 .80388 L F
.37318 .80651 m .37248 .80839 L .37154 .80421 L F
.58 .343 .521 r
.37522 .68339 m .37249 .68578 L .373 .68392 L F
.583 .854 .995 r
.72729 .73975 m .72531 .74147 L .72553 .7404 L F
.72729 .73975 m .72864 .74052 L .72531 .74147 L F
.669 .748 .91 r
.38723 .77908 m .38643 .78111 L .38531 .77918 L F
.38723 .77908 m .38849 .7807 L .38643 .78111 L F
.36 .113 .398 r
.5268 .7819 m .52638 .77886 L .5291 .7792 L F
.767 .675 .761 r
.52529 .83122 m .52307 .83408 L .52187 .83098 L F
.022 .592 .767 r
.52187 .83098 m .52459 .8311 L .52529 .83122 L F
.567 .581 .828 r
.52307 .83408 m .52459 .8311 L .52187 .83098 L F
.54 .356 .58 r
.52529 .83122 m .52523 .83383 L .52307 .83408 L F
.567 .581 .828 r
.52307 .83408 m .52523 .83383 L .52459 .8311 L F
.553 .923 .935 r
.49299 .88194 m .4923 .88274 L .49095 .88272 L F
.867 .801 .783 r
.66855 .61658 m .66678 .61951 L .66529 .61843 L F
.775 .465 .463 r
.47922 .76554 m .48251 .76427 L .47938 .76438 L F
.47922 .76554 m .48259 .76613 L .48251 .76427 L F
.722 .423 .47 r
.48251 .76427 m .48259 .76613 L .48589 .76605 L F
.435 .046 .201 r
.69254 .63778 m .69386 .63762 L .69526 .63562 L F
.709 .975 .758 r
.69766 .63335 m .69526 .63562 L .69635 .63408 L F
0 0 0 r
.69526 .63562 m .69386 .63762 L .69635 .63408 L F
.662 .394 .505 r
.33471 .81764 m .33534 .81763 L .3349 .81679 L F
.14 .632 .914 r
.49728 .88262 m .49853 .88231 L .49616 .8817 L F
.49728 .88262 m .50017 .88304 L .49853 .88231 L F
.876 .494 .313 r
.72204 .74499 m .7211 .74538 L .71912 .74338 L F
.003 .508 .862 r
.72204 .74499 m .72338 .74505 L .7211 .74538 L F
.72204 .74499 m .72422 .74573 L .72338 .74505 L F
.738 .581 .68 r
.59866 .6565 m .59661 .65764 L .59532 .65391 L F
.74 .586 .684 r
.59866 .6565 m .59659 .65931 L .59661 .65764 L F
.737 .581 .681 r
.59866 .6565 m .60048 .6599 L .59659 .65931 L F
.946 .709 .242 r
.71621 .63209 m .71631 .63447 L .71677 .63456 L F
.56 .932 .815 r
.71677 .63456 m .71631 .63447 L .71182 .63701 L F
.844 .999 .799 r
.62436 .61251 m .62664 .60993 L .62602 .61173 L F
.541 .35 .571 r
.34971 .76951 m .34751 .77219 L .34958 .77184 L F
.551 .414 .648 r
.34751 .77219 m .34969 .77426 L .34958 .77184 L F
.34751 .77219 m .3477 .77465 L .34969 .77426 L F
.301 0 0 r
.44631 .76912 m .44846 .76876 L .44973 .7673 L F
.672 .236 .204 r
.44846 .76876 m .45168 .76897 L .44973 .7673 L F
.86 .996 .767 r
.65601 .64666 m .65671 .6448 L .65466 .64742 L F
.453 .215 .461 r
.35665 .70185 m .35667 .70466 L .35476 .7051 L F
.392 .133 .397 r
.36032 .70062 m .35667 .70466 L .35665 .70185 L F
.814 .675 .711 r
.70486 .72369 m .70645 .7242 L .70515 .72121 L F
.88 .839 .801 r
.59797 .64915 m .59447 .65148 L .5967 .64828 L F
.59797 .64915 m .59569 .65202 L .59447 .65148 L F
.837 .604 .586 r
.52688 .83361 m .52803 .83082 L .52858 .83194 L F
.52688 .83361 m .52529 .83122 L .52803 .83082 L F
.52688 .83361 m .52523 .83383 L .52529 .83122 L F
.059 .47 .886 r
.52688 .83361 m .52767 .83345 L .52523 .83383 L F
.52688 .83361 m .52885 .83472 L .52767 .83345 L F
.888 .863 .809 r
.62407 .63281 m .62423 .63488 L .6253 .63331 L F
.729 .91 .957 r
.62589 .6317 m .62407 .63281 L .6253 .63331 L F
.58 .285 .431 r
.46895 .77238 m .46739 .77463 L .46511 .77446 L F
.36 .037 .275 r
.46931 .77401 m .46895 .77238 L .47095 .77208 L F
.46931 .77401 m .46739 .77463 L .46895 .77238 L F
.594 .427 .626 r
.35146 .76413 m .35364 .76392 L .35338 .76169 L F
.609 .41 .587 r
.35146 .76413 m .35363 .76633 L .35364 .76392 L F
.35146 .76413 m .35144 .7668 L .35363 .76633 L F
.906 .629 .507 r
.7107 .69851 m .71229 .69672 L .71051 .69635 L F
.7107 .69851 m .71243 .69898 L .71229 .69672 L F
.521 .452 .72 r
.4789 .74581 m .48077 .7454 L .48006 .74219 L F
.05 0 0 r
.31573 .65318 m .3169 .65323 L .31863 .65218 L F
.054 0 0 r
.31573 .65318 m .31504 .65402 L .3169 .65323 L F
.666 .902 .979 r
.63895 .62192 m .63723 .62079 L .63589 .62242 L F
.556 .853 .998 r
.63556 .61051 m .63779 .6099 L .6366 .61119 L F
.6366 .61119 m .63779 .6099 L .63556 .61051 L F
.671 .903 .977 r
.63947 .6203 m .63723 .62079 L .63895 .62192 L F
0 0 0 r
.31863 .65218 m .31886 .65259 L .3205 .65132 L F
.31863 .65218 m .3169 .65323 L .31886 .65259 L F
.409 .074 .284 r
.29968 .6614 m .3027 .65868 L .30051 .65949 L F
.592 .021 0 r
.33138 .80082 m .3303 .80091 L .33241 .79865 L F
.33138 .80082 m .33235 .80143 L .3303 .80091 L F
.187 0 .057 r
.33283 .70947 m .33551 .70745 L .33342 .70779 L F
.484 .245 .476 r
.38167 .76158 m .38112 .76379 L .37918 .76412 L F
.334 .117 .428 r
.38304 .76088 m .38167 .76158 L .38367 .7589 L F
.496 .299 .543 r
.38304 .76088 m .38112 .76379 L .38167 .76158 L F
.51 .407 .674 r
.34971 .76951 m .35144 .7668 L .34928 .76738 L F
.34971 .76951 m .35159 .76909 L .35144 .7668 L F
.559 .365 .574 r
.34971 .76951 m .3517 .77148 L .35159 .76909 L F
.34971 .76951 m .34958 .77184 L .3517 .77148 L F
0 0 .521 r
.67579 .62196 m .67724 .62648 L .67534 .62413 L F
.882 .679 .624 r
.67534 .62413 m .67724 .62648 L .67687 .62697 L F
.628 .463 .64 r
.3613 .74543 m .36136 .74783 L .36355 .74515 L F
.727 .659 .782 r
.43973 .73821 m .44174 .74024 L .44366 .73961 L F
.695 .541 .675 r
.44174 .74024 m .4417 .74262 L .44366 .73961 L F
.315 .062 .362 r
.34538 .71528 m .34315 .71793 L .34373 .71601 L F
.455 .116 .301 r
.46273 .76644 m .46488 .76611 L .46604 .76366 L F
.468 .076 .214 r
.46488 .76611 m .46824 .76396 L .46604 .76366 L F
.213 .591 .946 r
.72153 .71871 m .72372 .71938 L .72055 .71774 L F
.47 .557 .862 r
.72153 .71871 m .72449 .7198 L .72372 .71938 L F
.074 0 0 r
.31826 .71631 m .31942 .71639 L .3203 .71603 L F
.31826 .71631 m .31743 .71696 L .31942 .71639 L F
.898 .959 .827 r
.66678 .61951 m .66384 .62163 L .66529 .61843 L F
.727 .659 .782 r
.43973 .73821 m .44366 .73961 L .44254 .73854 L F
.667 .817 .955 r
.44254 .73854 m .44366 .73961 L .44579 .73873 L F
.989 .882 .549 r
.66853 .60867 m .66898 .60979 L .66949 .60779 L F
.26 .215 .616 r
.66864 .60871 m .66898 .60979 L .66853 .60867 L F
.944 .788 .328 r
.66898 .60979 m .66929 .61076 L .66955 .60849 L F
.836 .808 .32 r
.66949 .60779 m .66898 .60979 L .66955 .60849 L F
.971 .676 .406 r
.67277 .61006 m .67205 .61102 L .67204 .60879 L F
.67205 .61102 m .67176 .61141 L .67185 .61057 L F
.67205 .61102 m .67185 .61057 L .67204 .60879 L F
.26 .215 .616 r
.67137 .6095 m .66898 .60979 L .66864 .60871 L F
.67199 .60968 m .67146 .60971 L .67137 .6095 L F
.944 .788 .328 r
.66898 .60979 m .66927 .61098 L .66929 .61076 L F
0 0 .397 r
.66898 .60979 m .67006 .61292 L .66927 .61098 L F
.841 .523 0 r
.66898 .60979 m .66968 .61242 L .66985 .6123 L F
.26 .215 .616 r
.67204 .60969 m .66968 .61242 L .66898 .60979 L F
.996 .859 .57 r
.66938 .61263 m .66968 .61242 L .67204 .60969 L F
.66825 .61388 m .66968 .61242 L .66938 .61263 L F
.841 .523 0 r
.66985 .6123 m .66968 .61242 L .67006 .61292 L F
.26 .215 .616 r
.67199 .60969 m .67146 .60971 L .67199 .60968 L F
.67146 .60971 m .66898 .60979 L .67137 .6095 L F
.724 .377 .391 r
.66855 .60988 m .67197 .60969 L .66853 .60867 L F
.26 .215 .616 r
.67204 .60969 m .67199 .60969 L .67199 .60968 L F
.724 .377 .391 r
.67197 .60969 m .67204 .60969 L .67199 .60968 L F
.67197 .60969 m .67199 .60968 L .66853 .60867 L F
.99 .872 .528 r
.6717 .60899 m .67176 .60986 L .67126 .60954 L F
.864 .923 .865 r
.66714 .61318 m .66825 .61388 L .67197 .60977 L F
.67196 .60975 m .67197 .60977 L .67204 .60969 L F
.66714 .61318 m .67197 .60977 L .67196 .60975 L F
.99 .872 .528 r
.67197 .60963 m .67194 .60971 L .6717 .60899 L F
.864 .923 .865 r
.66714 .61318 m .67184 .60983 L .66886 .60998 L F
.765 .684 .137 r
.67204 .60879 m .67176 .61141 L .67178 .6104 L F
.67204 .60879 m .67178 .6104 L .67181 .61013 L F
.67204 .60879 m .67181 .61013 L .67238 .60815 L F
.67181 .61013 m .67179 .61028 L .67198 .60959 L F
.67181 .61013 m .67198 .60959 L .67238 .60815 L F
.864 .923 .865 r
.67184 .60983 m .67192 .60977 L .67185 .60971 L F
.67192 .60977 m .67204 .60969 L .67195 .6097 L F
.67192 .60977 m .67195 .6097 L .67185 .60971 L F
.67184 .60983 m .67185 .60971 L .66886 .60998 L F
.765 .684 .137 r
.67181 .61013 m .67178 .6104 L .67179 .61028 L F
.99 .872 .528 r
.67194 .60971 m .67179 .61028 L .67171 .60904 L F
.67194 .60971 m .67171 .60904 L .6717 .60899 L F
.67176 .60986 m .67179 .61028 L .67159 .61 L F
.67176 .60986 m .67159 .61 L .67126 .60954 L F
.67238 .60815 m .67197 .60963 L .6717 .60899 L F
0 0 .406 r
.66842 .60539 m .66949 .60779 L .66955 .60849 L F
.238 .753 .844 r
.52529 .83122 m .52459 .8311 L .52803 .83082 L F
.405 .69 .977 r
.43439 .71739 m .436 .71876 L .43359 .71851 L F
.43359 .71851 m .436 .71876 L .43439 .71739 L F
.691 .964 .939 r
.38785 .79824 m .38861 .79841 L .39196 .79693 L F
.38785 .79824 m .39196 .79693 L .38966 .79793 L F
.855 .736 .731 r
.39275 .7973 m .38966 .79793 L .39196 .79693 L F
.457 .094 .26 r
.39397 .79628 m .39429 .79657 L .39196 .79693 L F
.208 0 0 r
.39429 .79657 m .39275 .7973 L .39196 .79693 L F
.555 .402 .628 r
.35736 .75333 m .35946 .75539 L .35935 .75291 L F
.35736 .75333 m .35745 .75583 L .35946 .75539 L F
.319 0 0 r
.37199 .73654 m .37414 .73627 L .37563 .73485 L F
.105 0 0 r
.37563 .73485 m .37625 .73559 L .37776 .73458 L F
.37563 .73485 m .37414 .73627 L .37625 .73559 L F
.226 .656 .956 r
.34344 .80419 m .34322 .80447 L .34332 .80385 L F
0 0 .447 r
.34332 .80385 m .34322 .80447 L .34469 .80747 L F
.637 .765 .94 r
.34901 .65405 m .34708 .65477 L .3456 .6534 L F
.834 .695 .71 r
.56651 .8064 m .56776 .80928 L .5686 .80747 L F
.454 .521 .837 r
.36642 .66149 m .36597 .66436 L .36443 .6618 L F
.36642 .66149 m .36776 .66444 L .36597 .66436 L F
.754 .688 .788 r
.67584 .59956 m .67641 .60253 L .67885 .60018 L F
.547 .785 .987 r
.67728 .59899 m .67885 .60018 L .67584 .59956 L F
.67584 .59956 m .67885 .60018 L .67728 .59899 L F
.562 .791 .985 r
.67728 .59899 m .67773 .59933 L .67503 .59946 L F
.67773 .59933 m .67885 .60018 L .67588 .59962 L F
0 .05 .61 r
.67584 .59956 m .67586 .59963 L .67586 .59963 L F
.562 .791 .985 r
.67773 .59933 m .67588 .59962 L .67503 .59946 L F
0 .05 .61 r
.67586 .59963 m .67767 .60529 L .67641 .60253 L F
.67586 .59963 m .67767 .60529 L .67586 .59963 L F
.67584 .59956 m .67796 .60373 L .67767 .60529 L F
.982 .717 .448 r
.67503 .59946 m .67641 .60253 L .67511 .60172 L F
.978 .807 .602 r
.67584 .59956 m .67641 .60253 L .67511 .60172 L F
0 .138 .658 r
.67806 .60318 m .67827 .60435 L .67584 .59956 L F
.67806 .60318 m .67584 .59956 L .67511 .60172 L F
.356 .533 .893 r
.67629 .60039 m .67789 .60292 L .67511 .60172 L F
.67789 .60292 m .67806 .60318 L .67791 .60311 L F
.67789 .60292 m .67791 .60311 L .67511 .60172 L F
0 .05 .61 r
.67796 .60373 m .67827 .60435 L .67804 .60472 L F
.67796 .60373 m .67804 .60472 L .67767 .60529 L F
0 0 .269 r
.67856 .60663 m .67767 .60529 L .67827 .60435 L F
.67856 .60663 m .67708 .60806 L .67767 .60529 L F
.33 .309 .684 r
.69526 .59762 m .69562 .60078 L .69692 .59913 L F
.463 .496 .807 r
.69692 .59913 m .69562 .60078 L .69773 .60105 L F
.72 .373 .389 r
.49424 .77466 m .49258 .77658 L .49071 .77456 L F
.725 .379 .393 r
.49588 .77675 m .49424 .77466 L .49568 .77524 L F
.49588 .77675 m .49258 .77658 L .49424 .77466 L F
.329 .41 .794 r
.69393 .71019 m .69513 .71307 L .69425 .71075 L F
.866 .907 .858 r
.69513 .71307 m .69175 .71494 L .69425 .71075 L F
.149 .539 .923 r
.67943 .589 m .68205 .59049 L .68095 .58979 L F
.284 .623 .96 r
.68205 .59049 m .68343 .58988 L .68095 .58979 L F
.68205 .59049 m .68491 .59127 L .68343 .58988 L F
.416 .568 .897 r
.68205 .59049 m .6854 .59265 L .68491 .59127 L F
.426 .114 .33 r
.62682 .66799 m .62624 .66943 L .62411 .67001 L F
.295 0 .266 r
.62682 .66799 m .62869 .66717 L .62624 .66943 L F
0 .125 .59 r
.6841 .61827 m .6839 .61818 L .6822 .61599 L F
.6841 .61827 m .68728 .62078 L .6839 .61818 L F
.661 .134 0 r
.72355 .70777 m .72484 .70768 L .72181 .70683 L F
.747 .228 0 r
.72577 .70953 m .72484 .70768 L .72355 .70777 L F
.72577 .70953 m .72687 .70996 L .72484 .70768 L F
.787 .297 .05 r
.72484 .70768 m .72687 .70996 L .7283 .71031 L F
.539 .872 .992 r
.7093 .63782 m .71146 .63718 L .71077 .63665 L F
.529 .918 .806 r
.71077 .63665 m .70908 .63766 L .7093 .63782 L F
.693 .441 .537 r
.60011 .67552 m .59679 .67728 L .59801 .67516 L F
.753 .625 .718 r
.60048 .6599 m .59642 .66173 L .59659 .65931 L F
.60048 .6599 m .59958 .66201 L .59642 .66173 L F
.569 .814 .991 r
.72757 .74609 m .7289 .74457 L .72697 .74568 L F
.72757 .74609 m .72992 .74546 L .7289 .74457 L F
0 0 0 r
.66807 .59783 m .66698 .60039 L .66778 .59828 L F
.183 0 0 r
.41019 .79173 m .41002 .79075 L .41214 .79014 L F
.41019 .79173 m .40884 .79198 L .41002 .79075 L F
.884 .894 .833 r
.67431 .61875 m .67206 .62169 L .67325 .62126 L F
0 .214 .73 r
.6735 .62097 m .67534 .62413 L .67325 .62126 L F
.632 .495 .677 r
.55654 .80733 m .55686 .80974 L .55893 .8071 L F
.541 .84 .999 r
.71516 .71871 m .71602 .71934 L .71869 .71886 L F
.542 .403 .641 r
.35338 .76169 m .35574 .76159 L .35527 .75839 L F
.577 .415 .626 r
.35338 .76169 m .35576 .76361 L .35574 .76159 L F
.35338 .76169 m .35364 .76392 L .35576 .76361 L F
0 0 .462 r
.66785 .60205 m .66728 .60099 L .66698 .60039 L F
.66785 .60205 m .66774 .60298 L .66728 .60099 L F
.664 .489 .637 r
.36805 .737 m .36784 .7397 L .37055 .73704 L F
.881 .873 .824 r
.64639 .64329 m .64836 .6405 L .64836 .64232 L F
.773 .793 .869 r
.64836 .6405 m .6513 .6406 L .64836 .64232 L F
.312 0 .016 r
.44859 .77717 m .44514 .7792 L .44655 .77782 L F
.478 .839 .993 r
.35287 .6539 m .35256 .65481 L .35102 .65384 L F
.35287 .6539 m .3545 .65434 L .35256 .65481 L F
0 0 0 r
.31984 .73516 m .31674 .73693 L .3173 .73665 L F
.505 .566 .851 r
.36314 .65909 m .36251 .6619 L .36128 .65889 L F
.36314 .65909 m .36443 .6618 L .36251 .6619 L F
.49 .614 .901 r
.45916 .73629 m .4601 .738 L .46113 .73624 L F
.54 .678 .928 r
.4601 .738 m .46231 .73768 L .46113 .73624 L F
.7 .342 .366 r
.49924 .77684 m .49588 .77675 L .49568 .77524 L F
.603 .341 .493 r
.61328 .67312 m .6133 .67502 L .61108 .67511 L F
.655 .383 .495 r
.6166 .67472 m .61328 .67312 L .61653 .67276 L F
.6166 .67472 m .6133 .67502 L .61328 .67312 L F
.613 .463 .655 r
.3634 .74273 m .36355 .74515 L .36564 .7424 L F
.374 .815 .953 r
.43146 .7242 m .43344 .72384 L .43471 .72414 L F
.228 .699 .942 r
.43344 .72384 m .43665 .72443 L .43471 .72414 L F
.747 .794 .891 r
.33527 .80972 m .33337 .80836 L .33252 .80932 L F
.837 .782 .799 r
.59532 .65391 m .59255 .65396 L .59447 .65148 L F
.845 .747 .755 r
.59532 .65391 m .59337 .65665 L .59255 .65396 L F
.735 .58 .681 r
.59532 .65391 m .59661 .65764 L .59337 .65665 L F
.91 .809 .735 r
.59569 .65202 m .59532 .65391 L .59447 .65148 L F
.672 .492 .633 r
.5634 .80156 m .56115 .80424 L .56362 .80378 L F
.661 .483 .633 r
.5634 .80156 m .56362 .80378 L .56494 .80278 L F
.616 .648 .859 r
.72449 .7198 m .72501 .72163 L .72727 .72107 L F
.798 .808 .86 r
.32818 .67674 m .32921 .67788 L .33207 .67578 L F
.897 .813 .338 r
.41992 .74263 m .41961 .7423 L .41983 .74216 L F
.6 .144 0 r
.41992 .74263 m .42112 .74428 L .41961 .7423 L F
.545 .401 .636 r
.38112 .76379 m .37926 .76613 L .37918 .76412 L F
.728 .572 .679 r
.70759 .62226 m .71187 .62215 L .7079 .62187 L F
.758 .556 .624 r
.59958 .66201 m .59639 .66432 L .59642 .66173 L F
.59958 .66201 m .59941 .66446 L .59639 .66432 L F
.424 0 .092 r
.69625 .69505 m .69857 .6955 L .69937 .69385 L F
.35 0 .061 r
.69937 .69385 m .70081 .69393 L .70164 .69355 L F
.69937 .69385 m .69857 .6955 L .70081 .69393 L F
.647 .812 .962 r
.47774 .72893 m .47434 .72862 L .47644 .72785 L F
.57 .785 .98 r
.47976 .72847 m .47774 .72893 L .47644 .72785 L F
.588 .732 .943 r
.47976 .72847 m .4809 .72938 L .47774 .72893 L F
.621 .68 .884 r
.47434 .72862 m .4722 .7292 L .47117 .72741 L F
.602 .57 .791 r
.4864 .73425 m .48528 .73753 L .48425 .73469 L F
.4864 .73425 m .48748 .73718 L .48528 .73753 L F
.474 .27 .523 r
.3652 .69561 m .36392 .69422 L .36596 .69388 L F
.3652 .69561 m .36359 .69634 L .36392 .69422 L F
.565 .529 .773 r
.35244 .67819 m .35446 .67896 L .35372 .67749 L F
.661 .297 .344 r
.47301 .77343 m .46931 .77401 L .47095 .77208 L F
.357 .349 .713 r
.35138 .68878 m .35235 .68553 L .3512 .68597 L F
0 0 0 r
.41774 .77625 m .41994 .77446 L .41785 .77482 L F
.688 .68 .837 r
.53341 .76751 m .53367 .76916 L .53094 .76906 L F
.65 .505 .673 r
.53358 .77123 m .53094 .76906 L .53367 .76916 L F
.506 .693 .952 r
.53401 .76749 m .53367 .76916 L .53341 .76751 L F
.53448 .76801 m .53367 .76916 L .53401 .76749 L F
.53487 .76745 m .53617 .7685 L .53367 .76916 L F
.425 .262 .556 r
.53617 .7685 m .53358 .77123 L .53367 .76916 L F
.41 0 .072 r
.53196 .7706 m .53532 .76893 L .5321 .76859 L F
.53532 .76893 m .53617 .7685 L .53495 .76853 L F
.53532 .76893 m .53495 .76853 L .5321 .76859 L F
.506 .693 .952 r
.53487 .76745 m .53448 .76801 L .53401 .76749 L F
.888 .863 .809 r
.62407 .63281 m .62232 .63509 L .62423 .63488 L F
.899 .832 .772 r
.62423 .63488 m .62124 .63679 L .6217 .63752 L F
.62423 .63488 m .62232 .63509 L .62124 .63679 L F
.675 .398 .494 r
.61653 .67276 m .6188 .67492 L .6166 .67472 L F
.654 .403 .528 r
.61869 .67283 m .6188 .67492 L .61653 .67276 L F
.657 .748 .917 r
.48322 .72914 m .4809 .72938 L .47976 .72847 L F
.514 .312 .544 r
.48322 .72914 m .481 .73182 L .4809 .72938 L F
.905 .495 .181 r
.72779 .71152 m .7283 .71031 L .72687 .70996 L F
.72779 .71152 m .72956 .71332 L .7283 .71031 L F
.841 .622 .606 r
.67579 .62196 m .67534 .62413 L .6735 .62097 L F
.617 .715 .915 r
.66873 .59266 m .6695 .59511 L .66624 .5943 L F
0 .12 .589 r
.6695 .59511 m .67066 .59594 L .66835 .59591 L F
0 0 0 r
.53341 .76751 m .53094 .76906 L .5321 .76859 L F
.251 0 .137 r
.53094 .76906 m .53196 .7706 L .5321 .76859 L F
.364 0 .074 r
.41791 .78756 m .41636 .78938 L .41441 .78968 L F
.204 0 0 r
.41994 .78723 m .41636 .78938 L .41791 .78756 L F
.545 .873 .993 r
.71292 .62975 m .71066 .63044 L .70958 .62986 L F
.352 0 .094 r
.39812 .72809 m .40166 .72581 L .39863 .72671 L F
.39812 .72809 m .40024 .72774 L .40166 .72581 L F
.506 .1 .205 r
.40024 .72774 m .40377 .72581 L .40166 .72581 L F
.474 .062 .177 r
.45168 .76897 m .454 .76887 L .4552 .76702 L F
.356 0 .016 r
.454 .76887 m .45746 .76715 L .4552 .76702 L F
.708 .298 .267 r
.51672 .7737 m .51999 .774 L .51805 .77202 L F
.641 .477 .646 r
.34198 .78554 m .34429 .78536 L .34415 .78292 L F
.497 .367 .634 r
.34415 .78292 m .34617 .78494 L .34631 .78259 L F
.34415 .78292 m .34429 .78536 L .34617 .78494 L F
.707 .623 .761 r
.48893 .75601 m .49027 .75925 L .4924 .7585 L F
.634 .65 .849 r
.49438 .74275 m .49226 .74355 L .49136 .74229 L F
.262 0 0 r
.40588 .72553 m .40804 .72536 L .40951 .7244 L F
.429 0 0 r
.40804 .72536 m .41128 .72478 L .40951 .7244 L F
.053 0 0 r
.64579 .65543 m .64531 .65603 L .64347 .65629 L F
.135 0 0 r
.64347 .65629 m .64531 .65603 L .64254 .65785 L F
.911 .975 .788 r
.67394 .60325 m .67249 .60557 L .67259 .60374 L F
.863 .624 .09 r
.67249 .60557 m .67214 .60619 L .67259 .60374 L F
.67249 .60557 m .67273 .60788 L .67214 .60619 L F
0 0 0 r
.71461 .62419 m .71635 .62334 L .71726 .62228 L F
.523 .345 .581 r
.71726 .62228 m .71955 .62154 L .71942 .61908 L F
0 0 0 r
.71726 .62228 m .71828 .62194 L .71955 .62154 L F
.71726 .62228 m .71635 .62334 L .71828 .62194 L F
.678 .57 .726 r
.4924 .7585 m .49387 .7625 L .4958 .76116 L F
.071 .633 .765 r
.45351 .73671 m .4501 .73673 L .45154 .73678 L F
0 0 .423 r
.71461 .62419 m .71565 .62509 L .71635 .62334 L F
.71461 .62419 m .71513 .62673 L .71565 .62509 L F
.974 .753 .541 r
.64898 .63639 m .65012 .6351 L .64972 .63638 L F
.796 .959 .918 r
.64898 .63639 m .65235 .63473 L .65012 .6351 L F
.82 .719 .754 r
.70865 .71422 m .70832 .71719 L .70955 .71541 L F
.853 .62 .585 r
.70832 .71719 m .7112 .7188 L .70955 .71541 L F
.854 .886 .86 r
.70865 .71422 m .70955 .71541 L .71168 .71293 L F
.936 .586 .334 r
.50598 .7577 m .50583 .75567 L .50428 .75593 L F
.693 .409 .489 r
.50266 .75992 m .50629 .75874 L .50226 .75804 L F
.928 .641 .165 r
.50623 .75819 m .50635 .75893 L .50665 .75898 L F
.50598 .7577 m .50628 .75871 L .50623 .75819 L F
.50628 .75871 m .50635 .75893 L .50623 .75819 L F
.693 .409 .489 r
.50266 .75992 m .50552 .76068 L .50634 .75934 L F
.50629 .75874 m .50634 .75934 L .50682 .75857 L F
.50266 .75992 m .50634 .75934 L .50629 .75874 L F
.50629 .75874 m .50682 .75857 L .50622 .7585 L F
.50629 .75874 m .50622 .7585 L .50226 .75804 L F
.928 .641 .165 r
.50583 .75567 m .50597 .75758 L .50665 .75898 L F
.50597 .75758 m .50598 .7577 L .50603 .75778 L F
.50597 .75758 m .50603 .75778 L .50665 .75898 L F
.50598 .7577 m .50607 .75888 L .50635 .75893 L F
.781 .695 .768 r
.50226 .75804 m .50622 .7585 L .50428 .75593 L F
.50622 .7585 m .50682 .75857 L .50598 .7577 L F
.50622 .7585 m .50598 .7577 L .50428 .75593 L F
.936 .586 .334 r
.50682 .75857 m .50583 .75567 L .50598 .7577 L F
.928 .641 .165 r
.50583 .75567 m .506 .75887 L .50607 .75888 L F
.679 .132 0 r
.50652 .75983 m .50659 .75951 L .50552 .76068 L F
.593 .022 0 r
.50792 .76048 m .50665 .75898 L .50647 .75895 L F
.679 .132 0 r
.50659 .75951 m .50682 .75857 L .5065 .75909 L F
.50659 .75951 m .5065 .75909 L .50552 .76068 L F
.593 .022 0 r
.50656 .75934 m .50647 .75895 L .506 .75887 L F
.50792 .76048 m .50647 .75895 L .50656 .75934 L F
.654 .743 .915 r
.63493 .64763 m .63419 .64991 L .63276 .65033 L F
.63493 .64763 m .63608 .64899 L .63419 .64991 L F
.89 .98 .819 r
.66098 .64024 m .66021 .6428 L .66237 .64242 L F
.66098 .64024 m .65927 .64254 L .66021 .6428 L F
.633 .65 .85 r
.34317 .6773 m .34649 .67869 L .34482 .67541 L F
.768 .558 .614 r
.34317 .6773 m .34624 .67944 L .34649 .67869 L F
.54 .553 .817 r
.34649 .67869 m .34686 .67458 L .34482 .67541 L F
.34649 .67869 m .34876 .67855 L .34686 .67458 L F
.532 .371 .609 r
.34649 .67869 m .34624 .67944 L .34876 .67855 L F
.34876 .67855 m .34624 .67944 L .34649 .67869 L F
.338 .744 .981 r
.45992 .72668 m .46202 .72665 L .46336 .7273 L F
.488 .815 1 r
.46202 .72665 m .4655 .72696 L .46336 .7273 L F
.224 0 0 r
.40727 .79172 m .40363 .7932 L .40486 .79249 L F
.518 .314 .543 r
.36175 .6968 m .36112 .69884 L .35947 .69907 L F
.469 .232 .471 r
.36112 .69884 m .36032 .70062 L .35947 .69907 L F
.966 .72 .514 r
.67435 .61647 m .67303 .61792 L .67309 .61565 L F
.67435 .61647 m .67431 .61875 L .67303 .61792 L F
.357 .349 .713 r
.35138 .68878 m .35286 .68793 L .35235 .68553 L F
.453 .311 .597 r
.35102 .69098 m .35286 .68793 L .35138 .68878 L F
.65 .816 .963 r
.52767 .83345 m .52885 .83472 L .53091 .83371 L F
.484 .829 .998 r
.69526 .59762 m .69708 .59715 L .69372 .59688 L F
.33 .309 .684 r
.69526 .59762 m .69692 .59913 L .69708 .59715 L F
.798 .808 .86 r
.32818 .67674 m .33207 .67578 L .33024 .67593 L F
.5 .901 .929 r
.33569 .67438 m .33245 .6752 L .33207 .67578 L F
.197 0 0 r
.33245 .6752 m .33024 .67593 L .33207 .67578 L F
.743 .677 .786 r
.69401 .69682 m .695 .69966 L .69151 .69955 L F
.673 .28 .293 r
.695 .69966 m .6947 .70169 L .69151 .69955 L F
.458 .209 .448 r
.34266 .7199 m .34116 .71836 L .34315 .71793 L F
.34266 .7199 m .34073 .72048 L .34116 .71836 L F
.282 .054 .379 r
.72698 .6185 m .72492 .62128 L .72532 .61941 L F
.647 .442 .592 r
.33902 .78789 m .34184 .78795 L .34198 .78554 L F
.618 .418 .588 r
.34198 .78554 m .34413 .7877 L .34429 .78536 L F
.34198 .78554 m .34184 .78795 L .34413 .7877 L F
.348 .189 .519 r
.40748 .74251 m .40771 .74502 L .40616 .74541 L F
.058 0 .292 r
.40685 .74664 m .40616 .74541 L .40771 .74502 L F
.40685 .74664 m .40572 .74782 L .40616 .74541 L F
.39 .031 .23 r
.3027 .65868 m .30468 .65824 L .30539 .65699 L F
.315 0 .187 r
.30539 .65699 m .30654 .65766 L .30738 .65667 L F
.30539 .65699 m .30468 .65824 L .30654 .65766 L F
.485 .625 .913 r
.66936 .64272 m .67003 .64203 L .66779 .64222 L F
.66936 .64272 m .67131 .64321 L .67003 .64203 L F
.693 .441 .537 r
.60011 .67552 m .60016 .67764 L .59679 .67728 L F
.701 .447 .537 r
.60217 .67762 m .60011 .67552 L .60211 .67542 L F
.60217 .67762 m .60016 .67764 L .60011 .67552 L F
0 0 .424 r
.73238 .71743 m .73208 .72055 L .73346 .71879 L F
.612 .78 .961 r
.73508 .7315 m .73275 .73209 L .73197 .73091 L F
.479 .54 .842 r
.73553 .73468 m .73275 .73209 L .73508 .7315 L F
.428 .212 .482 r
.38545 .75785 m .38304 .76088 L .38367 .7589 L F
.552 .379 .6 r
.34561 .77726 m .34765 .77697 L .3477 .77465 L F
.541 .414 .656 r
.34561 .77726 m .34807 .78002 L .34765 .77697 L F
.34561 .77726 m .34594 .78048 L .34807 .78002 L F
.551 .03 0 r
.44563 .72484 m .44778 .72584 L .44919 .72529 L F
.456 0 0 r
.44919 .72529 m .44778 .72584 L .4512 .72572 L F
0 0 0 r
.31984 .73516 m .31814 .7364 L .31674 .73693 L F
.3197 .73541 m .31984 .73516 L .32159 .73431 L F
.3197 .73541 m .31814 .7364 L .31984 .73516 L F
.843 .768 .779 r
.61936 .63965 m .62 .64234 L .6205 .64057 L F
.917 .948 .803 r
.6217 .63752 m .61936 .63965 L .6205 .64057 L F
0 .293 .791 r
.68545 .6432 m .68597 .64236 L .68485 .64183 L F
.12 .487 .901 r
.68545 .6432 m .6881 .64431 L .68597 .64236 L F
.659 .744 .913 r
.3902 .77973 m .38849 .7807 L .38723 .77908 L F
.3902 .77973 m .38849 .7807 L .38723 .77908 L F
.376 .116 .387 r
.38015 .73175 m .38165 .73327 L .38324 .73192 L F
.475 .031 .112 r
.38165 .73327 m .38533 .73162 L .38324 .73192 L F
.545 .383 .612 r
.35936 .7506 m .36143 .75024 L .36136 .74783 L F
.534 .361 .593 r
.35936 .7506 m .36137 .7525 L .36143 .75024 L F
.35936 .7506 m .35935 .75291 L .36137 .7525 L F
.64 .521 .702 r
.3375 .79094 m .3398 .79071 L .33902 .78789 L F
.62 .439 .615 r
.33756 .79326 m .3398 .79071 L .3375 .79094 L F
.623 .922 .662 r
.71942 .61908 m .7205 .61773 L .72039 .61791 L F
.327 0 0 r
.7205 .61773 m .72383 .61561 L .72039 .61791 L F
.316 .19 .545 r
.71942 .61908 m .7214 .61998 L .7205 .61773 L F
.71942 .61908 m .71955 .62154 L .7214 .61998 L F
0 0 0 r
.70145 .60138 m .70278 .60124 L .70043 .59998 L F
.68 .135 0 r
.70356 .60079 m .70603 .60248 L .70278 .60124 L F
.017 .471 .874 r
.70328 .60119 m .70278 .60124 L .70409 .60164 L F
.70165 .60029 m .70278 .60124 L .70328 .60119 L F
0 0 0 r
.70145 .60138 m .7015 .60137 L .70278 .60124 L F
.7015 .60137 m .70356 .60079 L .70278 .60124 L F
.768 .558 .614 r
.34317 .6773 m .34456 .6804 L .34624 .67944 L F
.968 .701 .276 r
.70691 .58925 m .70782 .59226 L .70744 .59279 L F
.639 .547 .735 r
.70981 .59005 m .71099 .59305 L .70782 .59226 L F
.289 .645 .967 r
.70782 .59226 m .71036 .59289 L .70931 .59159 L F
0 .449 .722 r
.70782 .59226 m .71036 .59289 L .71099 .59305 L F
.289 .645 .967 r
.70782 .59226 m .70931 .59159 L .70655 .59352 L F
0 0 0 r
.70744 .59279 m .70782 .59226 L .70655 .59352 L F
.724 .683 .81 r
.70981 .59005 m .70782 .59226 L .70691 .58925 L F
.945 .695 .528 r
.68043 .61069 m .68036 .61326 L .68178 .61371 L F
.74 .638 .746 r
.68043 .61069 m .68178 .61371 L .6842 .61125 L F
.835 .406 0 r
.68036 .61326 m .6822 .61599 L .68178 .61371 L F
.327 0 0 r
.7205 .61773 m .72251 .61757 L .72383 .61561 L F
.628 .821 .407 r
.72383 .61561 m .72251 .61757 L .72473 .61405 L F
.72383 .61561 m .72382 .61562 L .72383 .61561 L F
.72382 .61562 m .72251 .61757 L .72383 .61561 L F
.284 .137 .497 r
.72536 .61313 m .72455 .61406 L .72519 .61271 L F
.72646 .6157 m .72471 .61419 L .72536 .61313 L F
.72471 .61419 m .72455 .61406 L .72536 .61313 L F
.72455 .61406 m .72381 .61342 L .72519 .61271 L F
0 0 0 r
.72383 .61561 m .72383 .61561 L .72519 .61271 L F
.72383 .61561 m .72473 .61405 L .72519 .61271 L F
.986 .727 .349 r
.67352 .61087 m .67277 .61006 L .67273 .60788 L F
.973 .687 .285 r
.67352 .61087 m .67302 .61255 L .67277 .61006 L F
.67352 .61087 m .67383 .61359 L .67302 .61255 L F
0 .252 .761 r
.51668 .76395 m .51885 .76643 L .51756 .76409 L F
.376 .116 .387 r
.38015 .73175 m .37978 .73393 L .38165 .73327 L F
.457 .882 .912 r
.69403 .64535 m .69339 .64515 L .69114 .64594 L F
.813 1 .827 r
.69538 .64291 m .69403 .64535 L .6968 .64426 L F
.69538 .64291 m .69339 .64515 L .69403 .64535 L F
.962 .72 .525 r
.37226 .8413 m .37371 .84189 L .37243 .83889 L F
.37243 .83889 m .37371 .84189 L .37226 .8413 L F
.741 .587 .684 r
.59661 .65764 m .59308 .65895 L .59337 .65665 L F
.59661 .65764 m .59659 .65931 L .59308 .65895 L F
.36 0 0 r
.48488 .87293 m .48875 .87144 L .48653 .87188 L F
.983 .847 .463 r
.67352 .63619 m .6741 .63827 L .67435 .63575 L F
.232 0 0 r
.64217 .5913 m .64516 .58918 L .64292 .58957 L F
.322 0 .135 r
.64005 .59182 m .64217 .5913 L .64292 .58957 L F
.476 .679 .954 r
.69244 .5889 m .69084 .58932 L .68846 .58724 L F
.755 .63 .722 r
.49616 .8817 m .49356 .87943 L .49574 .87976 L F
.74 .705 .818 r
.53093 .83109 m .52858 .83194 L .52803 .83082 L F
.776 .544 .584 r
.52767 .83345 m .53093 .83109 L .52803 .83082 L F
.52767 .83345 m .53091 .83371 L .53093 .83109 L F
.864 .576 .498 r
.70832 .71719 m .70979 .72035 L .7112 .7188 L F
.982 .865 .645 r
.7112 .7188 m .70979 .72035 L .71069 .72101 L F
.751 .664 .765 r
.73614 .72339 m .73726 .72649 L .7339 .72619 L F
.618 .405 .571 r
.73454 .72776 m .7339 .72619 L .73726 .72649 L F
.927 .608 .144 r
.73665 .72588 m .73726 .72649 L .73614 .72339 L F
.812 .973 .9 r
.73665 .72588 m .73454 .72776 L .73726 .72649 L F
.566 .4 .615 r
.70898 .59635 m .71117 .59718 L .71144 .59408 L F
.562 .15 .218 r
.70802 .59772 m .71117 .59718 L .70898 .59635 L F
.485 .239 .466 r
.62411 .67001 m .62592 .67167 L .62394 .67215 L F
.62411 .67001 m .62624 .66943 L .62592 .67167 L F
.374 .106 .373 r
.39616 .79586 m .39397 .79628 L .39572 .79583 L F
.39616 .79586 m .39429 .79657 L .39397 .79628 L F
.707 .623 .761 r
.48893 .75601 m .4924 .7585 L .4912 .75552 L F
.642 .616 .808 r
.4912 .75552 m .4924 .7585 L .49468 .75802 L F
.678 .57 .726 r
.4924 .7585 m .4958 .76116 L .49468 .75802 L F
.846 .856 .85 r
.7166 .62976 m .71602 .62837 L .71603 .62798 L F
.7166 .62976 m .7178 .62955 L .71602 .62837 L F
.736 .833 .925 r
.7178 .62955 m .71949 .6262 L .71602 .62837 L F
.7178 .62955 m .72084 .62729 L .71949 .6262 L F
.293 0 0 r
.45966 .77487 m .45845 .77593 L .45619 .77595 L F
.224 0 0 r
.46195 .77495 m .45845 .77593 L .45966 .77487 L F
.519 .081 .146 r
.30742 .68283 m .30554 .68359 L .30604 .68341 L F
.30742 .68283 m .30402 .68397 L .30554 .68359 L F
.891 .725 .67 r
.67808 .63445 m .67698 .6318 L .67814 .63255 L F
.633 .65 .85 r
.34317 .6773 m .34482 .67541 L .343 .67531 L F
.25 .593 .949 r
.68892 .64531 m .69002 .64471 L .6881 .64431 L F
.68892 .64531 m .69114 .64594 L .69002 .64471 L F
.668 .26 .262 r
.36648 .80894 m .36389 .80769 L .36527 .80654 L F
.253 0 0 r
.42564 .78488 m .42394 .78641 L .42208 .7867 L F
.285 0 0 r
.42607 .78604 m .42564 .78488 L .42782 .78468 L F
.42607 .78604 m .42394 .78641 L .42564 .78488 L F
.61 .661 .875 r
.48484 .74849 m .48797 .75054 L .48691 .74745 L F
.453 .439 .752 r
.48797 .75054 m .48891 .74711 L .48691 .74745 L F
.48797 .75054 m .48968 .75037 L .48891 .74711 L F
.582 .542 .775 r
.48855 .75354 m .48968 .75037 L .48797 .75054 L F
.185 0 0 r
.4424 .72459 m .44446 .72488 L .44563 .72484 L F
.455 0 0 r
.44446 .72488 m .44778 .72584 L .44563 .72484 L F
.69 .637 .791 r
.37796 .77469 m .37926 .77782 L .37611 .77714 L F
.597 .588 .813 r
.3814 .77737 m .37926 .77782 L .37796 .77469 L F
.352 .638 .961 r
.33011 .6497 m .32925 .6506 L .3281 .64985 L F
.514 .01 0 r
.32925 .6506 m .33135 .65102 L .33149 .65082 L F
.352 .638 .961 r
.33011 .6497 m .33135 .65102 L .32925 .6506 L F
.311 .712 .978 r
.3442 .6526 m .34373 .65343 L .34217 .65282 L F
.3442 .6526 m .3456 .6534 L .34373 .65343 L F
0 0 .459 r
.73508 .7315 m .73579 .73402 L .73553 .73468 L F
.692 .827 .387 r
.73579 .73402 m .73475 .73601 L .73553 .73468 L F
.926 .598 .399 r
.73475 .73601 m .73625 .73687 L .73553 .73468 L F
.585 .616 .849 r
.68491 .59127 m .6854 .59265 L .68731 .59084 L F
.508 .484 .765 r
.68637 .59415 m .68731 .59084 L .6854 .59265 L F
.244 0 .324 r
.64214 .61415 m .64234 .61554 L .64067 .61627 L F
.699 .637 .784 r
.48318 .88333 m .48464 .88565 L .48698 .88301 L F
.319 .443 .83 r
.65537 .58857 m .6536 .58979 L .65385 .58822 L F
.468 .28 .542 r
.65597 .58884 m .65399 .59167 L .6536 .58979 L F
.503 .899 .938 r
.65597 .58884 m .6536 .58979 L .65537 .58857 L F
.837 .597 .576 r
.69642 .70661 m .69326 .70738 L .69331 .70446 L F
.872 .812 .787 r
.69642 .70661 m .69393 .71019 L .69326 .70738 L F
.985 .709 .347 r
.65624 .60045 m .65548 .60047 L .65513 .6004 L F
.65624 .60045 m .65643 .60213 L .65548 .60047 L F
.776 .274 0 r
.67808 .63445 m .6808 .63682 L .6812 .63747 L F
.668 .192 .114 r
.72864 .74052 m .73068 .7417 L .7323 .74113 L F
.624 .131 .061 r
.7323 .74113 m .73068 .7417 L .73356 .74184 L F
.147 0 .189 r
.34419 .69434 m .34194 .69687 L .34355 .69612 L F
.32 .164 .506 r
.34194 .69687 m .3434 .69834 L .34355 .69612 L F
.34194 .69687 m .3418 .69918 L .3434 .69834 L F
.906 .792 .724 r
.67216 .63929 m .6741 .63827 L .67352 .63619 L F
.67216 .63929 m .67323 .64025 L .6741 .63827 L F
.591 .389 .576 r
.33252 .79606 m .33446 .79366 L .33231 .79353 L F
.196 .618 .947 r
.3351 .65046 m .3348 .6512 L .33336 .65069 L F
.3351 .65046 m .33653 .65141 L .3348 .6512 L F
.291 0 .221 r
.62953 .63028 m .63088 .63081 L .62857 .63145 L F
.62953 .63028 m .63153 .62943 L .63088 .63081 L F
.688 .32 .344 r
.48815 .76682 m .49016 .76869 L .49143 .76677 L F
.71 .347 .358 r
.49016 .76869 m .49345 .76885 L .49143 .76677 L F
.611 .365 .519 r
.49143 .76677 m .49345 .76885 L .49374 .76657 L F
.405 .846 .933 r
.68126 .58672 m .67875 .58688 L .67917 .58628 L F
.646 .803 .958 r
.68177 .58509 m .68126 .58672 L .67917 .58628 L F
.68177 .58509 m .68371 .58585 L .68126 .58672 L F
.425 .115 .334 r
.34011 .72285 m .33879 .72097 L .34073 .72048 L F
.34011 .72285 m .33792 .72342 L .33879 .72097 L F
.582 .542 .775 r
.48855 .75354 m .49076 .75339 L .48968 .75037 L F
.639 .487 .661 r
.48855 .75354 m .4912 .75552 L .49076 .75339 L F
.48855 .75354 m .48893 .75601 L .4912 .75552 L F
.344 .138 .451 r
.33985 .70196 m .3418 .69918 L .33976 .69962 L F
.882 .679 .624 r
.67534 .62413 m .67687 .62697 L .6746 .6273 L F
.973 .691 .435 r
.67687 .62697 m .67591 .62868 L .6746 .6273 L F
.67687 .62697 m .67716 .62949 L .67591 .62868 L F
.514 .312 .544 r
.48322 .72914 m .48306 .73173 L .481 .73182 L F
.447 .744 .992 r
.46978 .72636 m .46886 .72744 L .46759 .72666 L F
.46978 .72636 m .47117 .72741 L .46886 .72744 L F
.006 .406 .854 r
.71357 .71794 m .71516 .71871 L .71444 .71761 L F
.163 0 .053 r
.64746 .62451 m .64769 .62458 L .64509 .62671 L F
.492 .518 .812 r
.64861 .6214 m .64746 .62451 L .64655 .62162 L F
.64861 .6214 m .64927 .62304 L .64746 .62451 L F
.249 .113 .491 r
.64746 .62451 m .64891 .62471 L .64769 .62458 L F
.64746 .62451 m .64927 .62304 L .64891 .62471 L F
.726 .828 .929 r
.70599 .6227 m .70759 .62226 L .7079 .62187 L F
.591 .389 .576 r
.33252 .79606 m .33508 .79633 L .33446 .79366 L F
.258 .179 .572 r
.33446 .79366 m .33626 .7952 L .33756 .79326 L F
.33446 .79366 m .33508 .79633 L .33626 .7952 L F
.406 .23 .527 r
.4093 .74414 m .40748 .74251 L .40972 .74264 L F
.4093 .74414 m .40771 .74502 L .40748 .74251 L F
.545 .507 .764 r
.5072 .75283 m .50537 .7534 L .5044 .75028 L F
.836 .995 .847 r
.50582 .75435 m .50537 .7534 L .5072 .75283 L F
.50582 .75435 m .50583 .75567 L .50537 .7534 L F
.677 .466 .592 r
.60564 .67529 m .60217 .67762 L .60211 .67542 L F
.147 0 0 r
.31198 .68111 m .311 .68096 L .31295 .68008 L F
.31198 .68111 m .31033 .68155 L .311 .68096 L F
.501 .177 .35 r
.34419 .69434 m .3458 .69576 L .34619 .69379 L F
.34419 .69434 m .34355 .69612 L .3458 .69576 L F
.657 .748 .917 r
.48322 .72914 m .47976 .72847 L .48256 .72768 L F
.579 .698 .923 r
.4853 .72869 m .48322 .72914 L .48256 .72768 L F
.52 .319 .548 r
.4853 .72869 m .48306 .73173 L .48322 .72914 L F
.233 0 0 r
.41128 .72478 m .41345 .72473 L .41492 .72403 L F
.424 0 0 r
.41345 .72473 m .41687 .72418 L .41492 .72403 L F
.545 .138 .22 r
.47388 .76428 m .47572 .76546 L .47704 .76365 L F
.404 0 0 r
.47572 .76546 m .47922 .76554 L .47704 .76365 L F
.698 .303 .296 r
.47704 .76365 m .47922 .76554 L .47938 .76438 L F
.566 .26 .408 r
.64975 .60825 m .65207 .61024 L .6489 .61025 L F
.64975 .60825 m .65221 .60817 L .65207 .61024 L F
.469 0 0 r
.45403 .77611 m .45283 .77709 L .4507 .77688 L F
.224 0 0 r
.45619 .77595 m .45283 .77709 L .45403 .77611 L F
.665 .604 .777 r
.55893 .8071 m .56239 .80973 L .5612 .80655 L F
.735 .636 .749 r
.5612 .80655 m .56239 .80973 L .5648 .80745 L F
.23 0 0 r
.42749 .77655 m .43111 .77495 L .4289 .77496 L F
.68 .965 .751 r
.69766 .63335 m .69895 .6318 L .69939 .63194 L F
.69766 .63335 m .69635 .63408 L .69895 .6318 L F
.285 .021 .327 r
.39781 .79503 m .39572 .79583 L .3998 .79454 L F
.315 .8 .761 r
.39781 .79503 m .3998 .79454 L .40171 .79385 L F
.807 .882 .9 r
.72899 .73136 m .72713 .73102 L .72772 .73082 L F
.93 .699 .566 r
.72899 .73136 m .72708 .73343 L .72713 .73102 L F
.72899 .73136 m .72879 .73469 L .72708 .73343 L F
.574 .579 .821 r
.73073 .72808 m .72899 .73136 L .72772 .73082 L F
.73073 .72808 m .73197 .73091 L .72899 .73136 L F
.678 .738 .896 r
.49775 .74339 m .49438 .74275 L .4966 .74181 L F
.669 .683 .855 r
.49976 .74254 m .49775 .74339 L .4966 .74181 L F
.417 .16 .415 r
.63973 .59365 m .63801 .59244 L .63774 .59452 L F
.63973 .59365 m .64005 .59182 L .63801 .59244 L F
.224 0 0 r
.40727 .79172 m .40579 .79289 L .40363 .7932 L F
.05 0 0 r
.40774 .7923 m .40727 .79172 L .40884 .79198 L F
.40774 .7923 m .40579 .79289 L .40727 .79172 L F
.628 .548 .744 r
.37796 .77469 m .37611 .77714 L .37576 .77507 L F
.688 .599 .751 r
.33484 .81806 m .33534 .81763 L .33471 .81764 L F
.432 .485 .814 r
.37033 .66588 m .36892 .6675 L .36776 .66444 L F
.443 .501 .824 r
.37033 .66588 m .37155 .66886 L .36892 .6675 L F
.469 .231 .469 r
.36359 .69634 m .36112 .69884 L .36175 .6968 L F
.836 .995 .847 r
.50582 .75435 m .50428 .75593 L .50583 .75567 L F
.936 .586 .334 r
.50682 .75857 m .506 .75887 L .50583 .75567 L F
0 .508 .845 r
.65172 .58725 m .65078 .58737 L .64951 .58797 L F
.65172 .58725 m .65385 .58822 L .65078 .58737 L F
.619 .42 .591 r
.36784 .7397 m .37021 .73967 L .37055 .73704 L F
.587 .392 .584 r
.37055 .73704 m .37254 .73916 L .37199 .73654 L F
.37055 .73704 m .37021 .73967 L .37254 .73916 L F
.765 .577 .644 r
.59642 .66173 m .59308 .65895 L .59659 .65931 L F
.629 .846 .983 r
.45351 .73671 m .45684 .7368 L .4556 .73633 L F
.583 .891 .989 r
.45779 .73555 m .45684 .7368 L .45916 .73629 L F
.45779 .73555 m .4556 .73633 L .45684 .7368 L F
.186 0 0 r
.70164 .69355 m .7037 .69383 L .70486 .69382 L F
.091 0 0 r
.7037 .69383 m .70701 .69396 L .70486 .69382 L F
.621 .849 .473 r
.36879 .80696 m .36657 .80997 L .36744 .80865 L F
.38 0 0 r
.36657 .80997 m .36912 .80999 L .3672 .81106 L F
.655 .889 .982 r
.37022 .80892 m .36657 .80997 L .36879 .80696 L F
.707 .661 .802 r
.36657 .80997 m .37022 .80892 L .36912 .80999 L F
.38 0 0 r
.36657 .80997 m .3672 .81106 L .36744 .80865 L F
.802 .741 .796 r
.38144 .67275 m .37916 .67527 L .37779 .6726 L F
.468 .244 .49 r
.38144 .67275 m .38108 .67493 L .37916 .67527 L F
.531 .442 .699 r
.38184 .67743 m .37916 .67527 L .38108 .67493 L F
.38184 .67743 m .38001 .67804 L .37916 .67527 L F
.44 .038 .18 r
.38747 .73137 m .38968 .73114 L .39091 .72927 L F
.452 .058 .2 r
.38968 .73114 m .39301 .72901 L .39091 .72927 L F
.179 .287 .738 r
.48236 .87658 m .48428 .87895 L .4833 .87556 L F
1 .807 .493 r
.48236 .87658 m .48232 .87906 L .48428 .87895 L F
.232 .619 .955 r
.37022 .80892 m .37223 .80977 L .37068 .80866 L F
0 0 .497 r
.342 .81562 m .33915 .81229 L .33898 .81476 L F
.635 .619 .817 r
.722 .73661 m .7191 .73779 L .71832 .73637 L F
.589 .434 .64 r
.34765 .77697 m .34969 .77426 L .3477 .77465 L F
.79 .552 .577 r
.64766 .60196 m .65083 .60249 L .65076 .60023 L F
.582 .523 .754 r
.65076 .60023 m .65258 .59673 L .6499 .59707 L F
.65076 .60023 m .65297 .60028 L .65258 .59673 L F
.581 .386 .582 r
.65083 .60249 m .65297 .60028 L .65076 .60023 L F
.65083 .60249 m .65297 .60028 L .65076 .60023 L F
.821 .774 .808 r
.48698 .88301 m .48654 .88498 L .48853 .88251 L F
.483 0 0 r
.48509 .77425 m .48703 .77484 L .48366 .77425 L F
.652 .694 .876 r
.35188 .80985 m .35515 .81158 L .35435 .80973 L F
.544 .575 .837 r
.35515 .81158 m .35637 .80871 L .35435 .80973 L F
.35515 .81158 m .35827 .81251 L .35637 .80871 L F
.501 .554 .842 r
.34773 .81752 m .34615 .8177 L .34451 .81461 L F
.346 .016 .255 r
.33076 .72838 m .32901 .72885 L .33171 .72664 L F
0 0 0 r
.33348 .726 m .33076 .72838 L .33171 .72664 L F
0 0 .513 r
.66785 .60205 m .66842 .60539 L .66774 .60298 L F
.955 .806 .657 r
.67943 .589 m .67871 .58928 L .67875 .58688 L F
.379 0 .17 r
.67943 .589 m .6762 .59126 L .67871 .58928 L F
.67943 .589 m .67838 .59102 L .6762 .59126 L F
0 0 0 r
.67983 .58879 m .67943 .589 L .68095 .58979 L F
.67983 .58879 m .67838 .59102 L .67943 .589 L F
.654 .403 .528 r
.62187 .67462 m .61869 .67283 L .6219 .67245 L F
.62187 .67462 m .6188 .67492 L .61869 .67283 L F
.515 .426 .693 r
.4958 .76116 m .49754 .75902 L .49468 .75802 L F
.4958 .76116 m .49776 .76096 L .49754 .75902 L F
.709 .176 0 r
.41994 .77446 m .4233 .77723 L .421 .7768 L F
.644 .204 .189 r
.66499 .59194 m .66873 .59266 L .66624 .5943 L F
.802 .741 .796 r
.38144 .67275 m .37779 .6726 L .37956 .67104 L F
.325 .12 .441 r
.38299 .67208 m .38108 .67493 L .38144 .67275 L F
.475 .6 .898 r
.38723 .77908 m .38531 .77918 L .38359 .77679 L F
.115 .08 .537 r
.6408 .59894 m .64104 .60128 L .63924 .60314 L F
.328 .411 .795 r
.63924 .60314 m .64104 .60128 L .6421 .60442 L F
.064 .427 .87 r
.63924 .60314 m .6421 .60442 L .64317 .60587 L F
.735 .556 .649 r
.56494 .80278 m .56651 .8064 L .56799 .80373 L F
.447 .659 .951 r
.39729 .78008 m .39706 .78154 L .39598 .77961 L F
.39729 .78008 m .39909 .78158 L .39706 .78154 L F
.5 .181 .358 r
.32321 .71483 m .32525 .71457 L .32588 .71308 L F
.344 .029 .28 r
.32588 .71308 m .32705 .71397 L .32781 .71258 L F
.32588 .71308 m .32525 .71457 L .32705 .71397 L F
0 0 0 r
.68841 .61901 m .68728 .62078 L .6881 .61933 L F
.837 .931 .552 r
.68894 .61746 m .68841 .61901 L .6881 .61933 L F
.68894 .61746 m .68893 .61901 L .6903 .61847 L F
.265 0 .168 r
.68925 .61837 m .68893 .61861 L .68894 .61746 L F
.68893 .61861 m .68841 .61901 L .68894 .61746 L F
.68879 .6193 m .68841 .61901 L .68925 .61837 L F
.837 .931 .552 r
.68894 .61746 m .6881 .61933 L .68893 .61901 L F
.466 .066 .195 r
.68925 .61837 m .69162 .61851 L .68982 .62009 L F
.68894 .61746 m .69018 .61795 L .68925 .61837 L F
.59 .755 .956 r
.68962 .61763 m .6903 .61847 L .68893 .61901 L F
.531 .444 .702 r
.6903 .61847 m .69235 .61762 L .68894 .61746 L F
.588 .879 .993 r
.69051 .61803 m .69235 .61762 L .6903 .61847 L F
.466 .066 .195 r
.68894 .61746 m .69235 .61762 L .69097 .61793 L F
.68894 .61746 m .69192 .61815 L .69037 .61802 L F
.588 .879 .993 r
.69052 .61801 m .6903 .61847 L .68996 .61805 L F
.466 .066 .195 r
.68996 .61805 m .69162 .61851 L .68925 .61837 L F
.69018 .61795 m .69037 .61802 L .68996 .61805 L F
.69037 .61802 m .69162 .61851 L .68996 .61805 L F
.623 .577 .781 r
.69018 .61758 m .68982 .62009 L .69162 .61851 L F
.588 .879 .993 r
.69052 .61801 m .69037 .61802 L .68891 .61675 L F
.69037 .61802 m .68991 .61798 L .68891 .61675 L F
.59 .755 .956 r
.68891 .61675 m .68962 .61763 L .68875 .6186 L F
.623 .577 .781 r
.68891 .61675 m .68922 .61789 L .69018 .61758 L F
.588 .879 .993 r
.69037 .61802 m .68996 .61805 L .68991 .61798 L F
.623 .577 .781 r
.68922 .61789 m .68982 .62009 L .69018 .61758 L F
.588 .879 .993 r
.69081 .61737 m .69235 .61762 L .69051 .61803 L F
.69105 .61685 m .69154 .61714 L .69081 .61737 L F
.69154 .61714 m .69235 .61762 L .69081 .61737 L F
.466 .066 .195 r
.69097 .61793 m .69235 .61762 L .69192 .61815 L F
.69037 .61802 m .69192 .61815 L .69162 .61851 L F
.588 .879 .993 r
.69105 .61685 m .69052 .61801 L .68891 .61675 L F
.59 .755 .956 r
.68826 .61882 m .68875 .6186 L .6881 .61933 L F
.68891 .61675 m .68875 .6186 L .68826 .61882 L F
.68962 .61763 m .68893 .61901 L .6881 .61933 L F
.265 0 .168 r
.68982 .62009 m .68879 .6193 L .68925 .61837 L F
.68982 .62009 m .68782 .62091 L .68841 .61901 L F
.986 .71 .375 r
.70979 .72035 m .71086 .72351 L .71069 .72101 L F
.443 .863 .947 r
.38621 .79874 m .38861 .79841 L .38785 .79824 L F
.538 .915 .94 r
.70234 .64349 m .70421 .64262 L .70015 .64371 L F
0 0 0 r
.52343 .77183 m .51999 .774 L .52296 .77362 L F
.612 .268 .363 r
.52486 .77347 m .52343 .77183 L .52296 .77362 L F
.52486 .77347 m .52542 .77215 L .52343 .77183 L F
.482 .823 .998 r
.66237 .64242 m .66533 .64267 L .66461 .64221 L F
.551 .829 .997 r
.66533 .64267 m .66675 .64132 L .66461 .64221 L F
.66533 .64267 m .66779 .64222 L .66675 .64132 L F
.577 .57 .808 r
.69077 .63622 m .69254 .63778 L .68964 .63802 L F
.589 .42 .62 r
.35527 .75839 m .35738 .75813 L .35745 .75583 L F
.583 .431 .641 r
.35527 .75839 m .35756 .76101 L .35738 .75813 L F
.35527 .75839 m .35574 .76159 L .35756 .76101 L F
.708 .495 .598 r
.34619 .69379 m .34876 .69393 L .34905 .69161 L F
.478 .291 .547 r
.34905 .69161 m .35096 .6933 L .35102 .69098 L F
.34905 .69161 m .34876 .69393 L .35096 .6933 L F
.508 .484 .765 r
.68637 .59415 m .68708 .59438 L .68731 .59084 L F
.719 .338 .327 r
.50461 .77764 m .50345 .77955 L .50124 .77735 L F
.721 .34 .327 r
.50461 .77764 m .50688 .77991 L .50345 .77955 L F
.747 .61 .706 r
.5612 .80655 m .5648 .80745 L .56362 .80378 L F
.617 .537 .741 r
.56362 .80378 m .5648 .80745 L .56651 .8064 L F
.184 0 0 r
.42739 .74255 m .42573 .74338 L .42387 .7436 L F
.352 .799 .652 r
.42836 .742 m .42739 .74255 L .42898 .74143 L F
.42836 .742 m .42573 .74338 L .42739 .74255 L F
.616 .563 .772 r
.50324 .74534 m .50122 .7463 L .49976 .74254 L F
.498 .581 .869 r
.50392 .74828 m .50122 .7463 L .50324 .74534 L F
.683 .627 .787 r
.50649 .74761 m .50392 .74828 L .50324 .74534 L F
.658 .52 .684 r
.50649 .74761 m .5044 .75028 L .50392 .74828 L F
.548 .437 .68 r
.34026 .81778 m .342 .81562 L .33898 .81476 L F
.34026 .81778 m .34235 .81793 L .342 .81562 L F
.614 .627 .84 r
.49105 .73969 m .48748 .73718 L .48954 .7368 L F
.528 .567 .838 r
.49184 .73628 m .49105 .73969 L .48954 .7368 L F
.49184 .73628 m .49307 .73942 L .49105 .73969 L F
.662 .602 .777 r
.49307 .73942 m .49136 .74229 L .49105 .73969 L F
.652 .884 .982 r
.67511 .60172 m .67641 .60253 L .67394 .60325 L F
.706 .984 .826 r
.67511 .60172 m .67394 .60325 L .67259 .60374 L F
.747 .61 .706 r
.5612 .80655 m .56362 .80378 L .56115 .80424 L F
.561 .372 .583 r
.36355 .74515 m .36136 .74783 L .3635 .7475 L F
.621 .475 .662 r
.36355 .74515 m .36597 .74503 L .36564 .7424 L F
.511 .273 .49 r
.3635 .7475 m .36597 .74503 L .36355 .74515 L F
.634 .8 .962 r
.33337 .80836 m .34094 .80872 L .33784 .80901 L F
.783 .679 .75 r
.34001 .80658 m .3413 .80958 L .33784 .80901 L F
.095 .276 .757 r
.34216 .80872 m .3413 .80958 L .34001 .80658 L F
0 0 0 r
.33992 .81155 m .3413 .80958 L .34216 .80872 L F
.259 0 0 r
.32674 .67539 m .32488 .67541 L .32293 .67516 L F
.546 .018 0 r
.32674 .67539 m .32708 .67586 L .32488 .67541 L F
.32674 .67539 m .32818 .67674 L .32708 .67586 L F
0 0 0 r
.31366 .7178 m .31448 .7177 L .31565 .71748 L F
.626 .961 .885 r
.31565 .71748 m .31671 .7164 L .31743 .71696 L F
.31565 .71748 m .31448 .7177 L .31671 .7164 L F
0 0 0 r
.49109 .87292 m .48985 .87412 L .49222 .87173 L F
.262 .27 .679 r
.49109 .87292 m .49163 .87608 L .48985 .87412 L F
.561 .319 .505 r
.48985 .87412 m .49163 .87608 L .48939 .87647 L F
.48985 .87412 m .49163 .87608 L .48939 .87647 L F
.611 .701 .908 r
.46575 .73951 m .46866 .74026 L .46784 .73952 L F
.537 .672 .925 r
.46866 .74026 m .46993 .73881 L .46784 .73952 L F
.46866 .74026 m .47094 .74007 L .46993 .73881 L F
.863 .854 .832 r
.66129 .62874 m .66142 .62666 L .66205 .62684 L F
.992 .809 .432 r
.66205 .62684 m .66146 .62431 L .66475 .62422 L F
.66205 .62684 m .66142 .62666 L .66146 .62431 L F
.362 0 .127 r
.42986 .78463 m .43326 .78224 L .43182 .78419 L F
.362 0 0 r
.43326 .78224 m .43397 .78353 L .43182 .78419 L F
.43326 .78224 m .43535 .78209 L .43397 .78353 L F
.277 0 0 r
.41687 .72418 m .41882 .72442 L .42041 .72376 L F
0 0 0 r
.41882 .72442 m .42252 .72386 L .42041 .72376 L F
.824 .737 .768 r
.59337 .65665 m .59057 .65655 L .59255 .65396 L F
.767 .675 .761 r
.59308 .65895 m .59057 .65655 L .59337 .65665 L F
.527 .368 .61 r
.36136 .74783 m .36344 .74982 L .3635 .7475 L F
.36136 .74783 m .36143 .75024 L .36344 .74982 L F
.116 .64 .879 r
.4512 .72572 m .45325 .72588 L .45454 .7263 L F
.258 .747 .919 r
.45325 .72588 m .45662 .72604 L .45454 .7263 L F
.816 .486 .429 r
.66207 .61318 m .6604 .6131 L .6589 .6104 L F
.876 .767 .738 r
.6604 .6131 m .65904 .60931 L .6589 .6104 L F
.342 .19 .525 r
.64067 .61627 m .64175 .61748 L .64079 .61896 L F
.64067 .61627 m .64234 .61554 L .64175 .61748 L F
.647 .307 .383 r
.51469 .78533 m .51777 .78487 L .51682 .7872 L F
.532 .232 .403 r
.51777 .78487 m .5192 .78721 L .51682 .7872 L F
.51777 .78487 m .52002 .78477 L .5192 .78721 L F
.741 .4 .405 r
.37308 .80148 m .37571 .80381 L .37299 .80388 L F
.598 .666 .886 r
.69465 .58886 m .69362 .59185 L .69244 .5889 L F
.69465 .58886 m .6959 .59141 L .69362 .59185 L F
.249 .034 .379 r
.72055 .71774 m .72101 .71579 L .72258 .7146 L F
.917 .948 .803 r
.6217 .63752 m .62124 .63679 L .61936 .63965 L F
.854 .886 .86 r
.70865 .71422 m .71168 .71293 L .71071 .71219 L F
.925 .551 .281 r
.71168 .71293 m .71102 .71442 L .71071 .71219 L F
.71168 .71293 m .71206 .71546 L .71102 .71442 L F
.813 .455 .379 r
.71529 .71549 m .71206 .71546 L .71168 .71293 L F
.836 .396 .186 r
.6879 .62646 m .68459 .6239 L .68639 .62683 L F
.774 .425 .394 r
.68687 .62888 m .6879 .62646 L .68639 .62683 L F
.68687 .62888 m .68949 .62946 L .6879 .62646 L F
.409 .074 .284 r
.29968 .6614 m .30152 .66129 L .3027 .65868 L F
.408 .074 .283 r
.3027 .65868 m .30353 .66083 L .30468 .65824 L F
.3027 .65868 m .30152 .66129 L .30353 .66083 L F
.477 .832 .996 r
.39949 .74942 m .401 .75008 L .40278 .74963 L F
.652 .575 .756 r
.71485 .5997 m .71677 .59709 L .71477 .59816 L F
.71485 .5997 m .718 .60048 L .71677 .59709 L F
.975 .705 .454 r
.63172 .64085 m .6305 .6419 L .63059 .64146 L F
.271 .005 .313 r
.6305 .6419 m .63052 .64187 L .63059 .64146 L F
.964 .672 .427 r
.63172 .64085 m .63059 .64146 L .63098 .6392 L F
0 .351 .804 r
.63041 .63793 m .63297 .63922 L .63346 .63997 L F
.271 .005 .313 r
.63052 .64187 m .63297 .63922 L .63059 .64146 L F
.964 .672 .427 r
.63098 .6392 m .63059 .64146 L .63041 .63793 L F
.864 .979 .852 r
.63346 .63997 m .6305 .6419 L .63172 .64085 L F
.574 .48 .71 r
.33902 .78789 m .34188 .79034 L .34184 .78795 L F
.33902 .78789 m .3398 .79071 L .34188 .79034 L F
.821 .774 .808 r
.48698 .88301 m .48853 .88251 L .48701 .8821 L F
.313 .797 .746 r
.72616 .71473 m .72349 .71555 L .72494 .71264 L F
.72616 .71473 m .72631 .71464 L .72349 .71555 L F
.045 0 0 r
.31311 .65462 m .31333 .65508 L .31504 .65402 L F
.31311 .65462 m .31127 .65554 L .31333 .65508 L F
0 .197 .727 r
.68293 .64001 m .68334 .63948 L .6812 .63747 L F
0 .24 .756 r
.68293 .64001 m .68485 .64183 L .68334 .63948 L F
.402 0 0 r
.46511 .77446 m .46355 .77571 L .46195 .77495 L F
.296 0 0 r
.46739 .77463 m .46355 .77571 L .46511 .77446 L F
.626 .91 .982 r
.71635 .71418 m .71206 .71546 L .71529 .71549 L F
.446 0 .075 r
.45746 .76715 m .45921 .76786 L .46051 .76633 L F
.422 0 .02 r
.45921 .76786 m .46273 .76644 L .46051 .76633 L F
.353 0 0 r
.44105 .78038 m .4396 .78166 L .4375 .78173 L F
.454 .025 .134 r
.44314 .77989 m .4396 .78166 L .44105 .78038 L F
.622 .355 .491 r
.65754 .59471 m .65749 .5968 L .65509 .59479 L F
.65754 .59471 m .65749 .5968 L .65509 .59479 L F
.89 .692 .177 r
.63262 .62095 m .63298 .6236 L .63589 .62242 L F
.63262 .62095 m .63275 .62352 L .63298 .6236 L F
.428 .168 .416 r
.31732 .67753 m .31502 .67949 L .31529 .67796 L F
.261 0 0 r
.31502 .67949 m .31198 .68111 L .31295 .68008 L F
.581 .662 .893 r
.37467 .67175 m .37779 .6726 L .37589 .67353 L F
0 .072 .632 r
.34951 .81947 m .34949 .82046 L .34773 .81752 L F
.553 .909 .966 r
.34757 .82028 m .34949 .82046 L .34951 .81947 L F
.811 .818 .856 r
.3303 .80091 m .33129 .80247 L .32991 .80123 L F
.3303 .80091 m .33235 .80143 L .33129 .80247 L F
.94 .581 .297 r
.69393 .71019 m .69425 .71075 L .69317 .71164 L F
.844 .945 .585 r
.69317 .71164 m .69425 .71075 L .69381 .71148 L F
.277 .778 .866 r
.69317 .71164 m .69437 .71117 L .69271 .71176 L F
.843 .381 .087 r
.69169 .70949 m .69317 .71164 L .69243 .71186 L F
.277 .778 .866 r
.69317 .71164 m .69271 .71176 L .69243 .71186 L F
.844 .945 .585 r
.69317 .71164 m .69381 .71148 L .69175 .71494 L F
.36 0 0 r
.43506 .77349 m .43884 .77217 L .43676 .77273 L F
.296 .783 .721 r
.4309 .74072 m .42898 .74143 L .42957 .73932 L F
.617 .537 .741 r
.56362 .80378 m .56651 .8064 L .56494 .80278 L F
.57 .496 .732 r
.38131 .76586 m .37999 .76924 L .37926 .76613 L F
.38131 .76586 m .38199 .76909 L .37999 .76924 L F
.619 .419 .589 r
.38224 .77147 m .37999 .76924 L .38199 .76909 L F
.38224 .77147 m .38006 .77173 L .37999 .76924 L F
.458 .699 .971 r
.72422 .74573 m .72578 .74422 L .72338 .74505 L F
.72422 .74573 m .72697 .74568 L .72578 .74422 L F
.594 .445 .649 r
.35738 .75813 m .35946 .75539 L .35745 .75583 L F
.264 0 0 r
.3545 .65434 m .35669 .65495 L .35699 .65487 L F
.442 0 0 r
.35669 .65495 m .35985 .65634 L .35699 .65487 L F
.843 .768 .779 r
.61936 .63965 m .61736 .64248 L .62 .64234 L F
.844 .758 .768 r
.61736 .64248 m .61831 .64532 L .62 .64234 L F
.843 .797 .807 r
.69326 .70738 m .69393 .71019 L .69169 .70949 L F
.94 .581 .297 r
.69393 .71019 m .69317 .71164 L .69169 .70949 L F
.876 .675 .627 r
.66961 .61548 m .67251 .61671 L .67006 .61292 L F
.66961 .61548 m .67251 .61671 L .67006 .61292 L F
.66 .8 .95 r
.67309 .61565 m .67251 .61671 L .66961 .61548 L F
.545 .401 .636 r
.38112 .76379 m .38131 .76586 L .37926 .76613 L F
.766 .854 .917 r
.688 .63185 m .69103 .6319 L .68899 .63317 L F
.812 .673 .711 r
.70195 .72297 m .70515 .72121 L .70462 .71996 L F
.70195 .72297 m .70486 .72369 L .70515 .72121 L F
.659 .7 .877 r
.70462 .71996 m .70515 .72121 L .70746 .7206 L F
.37 .148 .442 r
.53358 .77123 m .53169 .77383 L .53158 .77238 L F
.808 .684 .728 r
.70195 .72297 m .70379 .72671 L .70486 .72369 L F
.621 .849 .473 r
.36879 .80696 m .36744 .80865 L .36773 .80629 L F
.72 .335 .319 r
.36879 .80696 m .37248 .80839 L .37068 .80866 L F
.335 .373 .752 r
.36879 .80696 m .37068 .80866 L .37001 .80603 L F
.086 .31 .789 r
.37068 .80866 m .37022 .80892 L .36879 .80696 L F
.797 .564 .584 r
.36773 .80629 m .37068 .80866 L .36879 .80696 L F
.765 .577 .644 r
.59642 .66173 m .59518 .66178 L .59308 .65895 L F
.76 .552 .614 r
.59642 .66173 m .59497 .66429 L .59518 .66178 L F
.772 .567 .621 r
.59642 .66173 m .59639 .66432 L .59497 .66429 L F
.665 .428 .552 r
.60756 .67544 m .60566 .67755 L .60564 .67529 L F
.60756 .67544 m .60777 .67773 L .60566 .67755 L F
.64 .409 .553 r
.61197 .67706 m .60756 .67544 L .61108 .67511 L F
.61197 .67706 m .60777 .67773 L .60756 .67544 L F
.548 .638 .892 r
.32642 .64755 m .32591 .65007 L .32431 .64965 L F
.32642 .64755 m .3281 .64985 L .32591 .65007 L F
.626 .258 .324 r
.62301 .65817 m .62387 .65625 L .62067 .65654 L F
.482 .019 .077 r
.62515 .65765 m .62387 .65625 L .62301 .65817 L F
.62515 .65765 m .62625 .65625 L .62387 .65625 L F
.556 .342 .544 r
.36784 .7397 m .36978 .74168 L .37021 .73967 L F
.36784 .7397 m .36766 .74202 L .36978 .74168 L F
.411 .065 .266 r
.37571 .80381 m .37853 .80133 L .37742 .80323 L F
.282 0 .1 r
.37742 .80323 m .37853 .80133 L .38049 .80071 L F
.571 .502 .739 r
.6499 .59707 m .65258 .59673 L .65111 .59529 L F
.518 .878 .982 r
.65089 .59585 m .6499 .59707 L .65111 .59529 L F
.65089 .59585 m .6487 .59651 L .6499 .59707 L F
.45 .387 .696 r
.48232 .87906 m .48486 .88081 L .48428 .87895 L F
.48232 .87906 m .48318 .88333 L .48486 .88081 L F
.55 .668 .915 r
.46231 .73768 m .46575 .73951 L .46443 .73706 L F
.5 .591 .877 r
.46575 .73951 m .46653 .73681 L .46443 .73706 L F
.46575 .73951 m .46784 .73952 L .46653 .73681 L F
.468 .076 .214 r
.46488 .76611 m .46704 .76603 L .46824 .76396 L F
.679 .306 .332 r
.46824 .76396 m .46704 .76603 L .4703 .76585 L F
.787 .68 .746 r
.33241 .79865 m .33508 .79633 L .33252 .79606 L F
.673 .292 .317 r
.48259 .76613 m .48459 .76799 L .48589 .76605 L F
.683 .295 .305 r
.48459 .76799 m .48815 .76682 L .48589 .76605 L F
.677 .466 .592 r
.60564 .67529 m .60566 .67755 L .60217 .67762 L F
.486 .331 .596 r
.34429 .78536 m .34618 .78735 L .34617 .78494 L F
.531 .335 .559 r
.34413 .7877 m .34618 .78735 L .34429 .78536 L F
.786 .677 .744 r
.67003 .64203 m .67323 .64025 L .67216 .63929 L F
.67003 .64203 m .67131 .64321 L .67323 .64025 L F
.486 .326 .589 r
.33798 .70496 m .33985 .70446 L .33985 .70196 L F
.314 .084 .397 r
.33798 .70496 m .33918 .70624 L .33985 .70446 L F
.33798 .70496 m .33752 .70703 L .33918 .70624 L F
.812 .327 .004 r
.50031 .87875 m .49857 .87624 L .49722 .87573 L F
.954 .793 .644 r
.61685 .64472 m .61831 .64532 L .61736 .64248 L F
.859 .698 .682 r
.61509 .64746 m .61831 .64532 L .61685 .64472 L F
.61509 .64746 m .61686 .6483 L .61831 .64532 L F
.585 .188 .257 r
.4703 .76585 m .47233 .76636 L .47388 .76428 L F
.543 .141 .229 r
.47388 .76428 m .47233 .76636 L .47572 .76546 L F
.725 .756 .877 r
.47094 .74007 m .47451 .74047 L .47333 .73954 L F
.686 .823 .949 r
.47333 .73954 m .47451 .74047 L .47664 .73965 L F
.595 .583 .809 r
.4864 .73425 m .48425 .73469 L .48306 .73173 L F
0 0 0 r
.37068 .80866 m .36912 .80999 L .37022 .80892 L F
.567 .425 .647 r
.51741 .75864 m .51519 .7614 L .51421 .75831 L F
.51741 .75864 m .5176 .76106 L .51519 .7614 L F
.381 0 .106 r
.51659 .7623 m .51519 .7614 L .5176 .76106 L F
.51659 .7623 m .51432 .7627 L .51519 .7614 L F
.289 0 .16 r
.63584 .66072 m .63476 .66301 L .6328 .66369 L F
.292 0 .179 r
.63831 .65902 m .63763 .66103 L .63584 .66072 L F
.292 0 .162 r
.63584 .66072 m .63763 .66103 L .63476 .66301 L F
.567 .537 .78 r
.49163 .87608 m .49044 .87999 L .48939 .87647 L F
.49163 .87608 m .49356 .87943 L .49044 .87999 L F
.547 .425 .664 r
.49356 .87943 m .49299 .88194 L .49044 .87999 L F
.147 .279 .743 r
.69281 .71816 m .69438 .71701 L .69175 .71494 L F
.125 .022 .456 r
.69281 .71816 m .69449 .71934 L .69438 .71701 L F
.69281 .71816 m .69291 .72097 L .69449 .71934 L F
.6 .418 .607 r
.35364 .76392 m .35585 .76603 L .35576 .76361 L F
.35364 .76392 m .35363 .76633 L .35585 .76603 L F
.539 .415 .66 r
.36564 .7424 m .36799 .74446 L .36766 .74202 L F
.36564 .7424 m .36597 .74503 L .36799 .74446 L F
.392 .799 .981 r
.42461 .72367 m .42795 .72393 L .42588 .72403 L F
.288 0 0 r
.63831 .65902 m .63931 .65998 L .63763 .66103 L F
.63831 .65902 m .64056 .65863 L .63931 .65998 L F
.669 .535 .692 r
.50649 .74761 m .50685 .75031 L .5044 .75028 L F
.545 .507 .764 r
.5072 .75283 m .5044 .75028 L .50685 .75031 L F
.674 .748 .906 r
.7011 .62918 m .69939 .63194 L .69895 .6318 L F
.7011 .62918 m .70184 .63089 L .69939 .63194 L F
.662 .602 .777 r
.49307 .73942 m .49438 .74275 L .49136 .74229 L F
0 0 .424 r
.73238 .71743 m .7329 .72001 L .73208 .72055 L F
0 0 .152 r
.7329 .72001 m .73254 .72072 L .73208 .72055 L F
.89 .692 .177 r
.63262 .62095 m .63589 .62242 L .63535 .62092 L F
.264 .289 .701 r
.63589 .62242 m .63702 .62017 L .63535 .62092 L F
.63589 .62242 m .63723 .62079 L .63702 .62017 L F
.64 .651 .845 r
.43699 .73705 m .43973 .73821 L .43952 .73789 L F
.244 0 0 r
.44254 .73854 m .43952 .73789 L .43973 .73821 L F
.856 .966 .64 r
.69498 .70189 m .69331 .70446 L .69374 .70257 L F
.008 .311 .801 r
.34621 .8089 m .34682 .81033 L .34822 .81092 L F
.779 .968 .921 r
.64441 .64598 m .64049 .64755 L .64228 .64631 L F
.64441 .64598 m .64123 .64799 L .64049 .64755 L F
.86 .941 .872 r
.64422 .64418 m .64441 .64598 L .64228 .64631 L F
.64422 .64418 m .64525 .64461 L .64441 .64598 L F
0 0 0 r
.69401 .69682 m .69151 .69955 L .6929 .69817 L F
.265 .41 .822 r
.69151 .69955 m .6947 .70169 L .6929 .69817 L F
.783 .679 .75 r
.33784 .80901 m .34094 .80872 L .34001 .80658 L F
.579 .436 .651 r
.38013 .77427 m .37778 .77208 L .38006 .77173 L F
.38013 .77427 m .37796 .77469 L .37778 .77208 L F
.62 .439 .615 r
.33756 .79326 m .33982 .79312 L .3398 .79071 L F
.415 .213 .495 r
.33982 .79312 m .34188 .79034 L .3398 .79071 L F
.324 .79 .678 r
.40213 .78179 m .40311 .7813 L .40429 .78124 L F
.556 .483 .729 r
.64775 .61555 m .64612 .61893 L .64565 .6164 L F
.64775 .61555 m .64842 .61823 L .64612 .61893 L F
.471 .254 .501 r
.64612 .61893 m .64842 .61823 L .64803 .61973 L F
.815 .721 .762 r
.51432 .7627 m .51215 .76577 L .51701 .76568 L F
.06 .573 .88 r
.70495 .63188 m .70184 .63089 L .70386 .63063 L F
.739 .743 .855 r
.70447 .62935 m .70495 .63188 L .70386 .63063 L F
.70447 .62935 m .70772 .63031 L .70495 .63188 L F
.464 .323 .603 r
.37249 .68578 m .3726 .68826 L .37084 .68886 L F
.377 .126 .402 r
.3726 .68826 m .37031 .69088 L .37084 .68886 L F
0 0 0 r
.63465 .59665 m .63546 .59499 L .63325 .59742 L F
.328 0 .107 r
.63465 .59665 m .63774 .59452 L .63546 .59499 L F
.717 .575 .694 r
.59679 .67728 m .59443 .68012 L .59481 .67795 L F
.323 0 0 r
.71431 .73665 m .71334 .73637 L .71147 .73562 L F
.974 .724 .493 r
.71331 .73406 m .71431 .73665 L .71683 .73515 L F
.71331 .73406 m .71334 .73637 L .71431 .73665 L F
.752 .948 .943 r
.71431 .73665 m .71589 .73486 L .71683 .73515 L F
.71431 .73665 m .71334 .73637 L .71589 .73486 L F
.978 .731 .494 r
.71449 .73933 m .71334 .73637 L .71431 .73665 L F
.566 .353 .551 r
.62394 .67215 m .62187 .67462 L .6219 .67245 L F
.667 .817 .955 r
.44254 .73854 m .44579 .73873 L .44464 .738 L F
.734 .898 .953 r
.44464 .738 m .44579 .73873 L .44806 .73742 L F
.829 .702 .724 r
.66309 .62313 m .66475 .62422 L .66146 .62431 L F
.759 .576 .649 r
.59941 .66446 m .59875 .66742 L .59639 .66432 L F
.546 .451 .699 r
.34631 .78259 m .34807 .78002 L .34594 .78048 L F
.524 .307 .527 r
.38001 .67804 m .37937 .68068 L .37723 .68086 L F
.374 .13 .41 r
.37864 .68211 m .37723 .68086 L .37937 .68068 L F
.37864 .68211 m .37692 .68279 L .37723 .68086 L F
.454 .243 .502 r
.38184 .67743 m .37937 .68068 L .38001 .67804 L F
.689 .151 0 r
.3572 .68031 m .35372 .67749 L .35446 .67896 L F
0 0 0 r
.63038 .60198 m .63062 .60206 L .6315 .60044 L F
.63325 .59742 m .6315 .60044 L .63255 .59896 L F
.375 .184 .489 r
.63062 .60206 m .63255 .59896 L .6315 .60044 L F
.393 .021 .208 r
.32901 .72885 m .32792 .73101 L .32576 .73138 L F
.074 0 .044 r
.32954 .72993 m .32901 .72885 L .33076 .72838 L F
.32954 .72993 m .32792 .73101 L .32901 .72885 L F
.541 .84 .999 r
.71516 .71871 m .71869 .71886 L .71734 .71837 L F
0 0 0 r
.72055 .71774 m .71734 .71837 L .71869 .71886 L F
.767 .675 .761 r
.59308 .65895 m .58971 .65863 L .59057 .65655 L F
.777 .602 .663 r
.59308 .65895 m .59163 .66167 L .58971 .65863 L F
.756 .576 .653 r
.59518 .66178 m .59163 .66167 L .59308 .65895 L F
0 .32 .799 r
.33582 .8272 m .33663 .82771 L .33678 .82826 L F
.782 .994 .874 r
.33678 .82826 m .33663 .82771 L .33576 .82846 L F
.514 .318 .553 r
.3525 .70752 m .35234 .71005 L .35029 .71045 L F
.436 .2 .456 r
.35476 .7051 m .35443 .707 L .3525 .70752 L F
.441 .248 .521 r
.35443 .707 m .35234 .71005 L .3525 .70752 L F
.349 .818 .75 r
.64579 .65543 m .647 .6548 L .64531 .65603 L F
.64579 .65543 m .64873 .65427 L .647 .6548 L F
.666 .381 .48 r
.61108 .67511 m .61332 .67722 L .61197 .67706 L F
.615 .391 .553 r
.6133 .67502 m .61332 .67722 L .61108 .67511 L F
.466 .382 .677 r
.72372 .71938 m .72625 .72018 L .72609 .71643 L F
.28 .5 .891 r
.72449 .7198 m .72625 .72018 L .72372 .71938 L F
.424 .162 .41 r
.35168 .71186 m .35029 .71045 L .35234 .71005 L F
.35168 .71186 m .34977 .71237 L .35029 .71045 L F
.616 .864 .99 r
.33575 .80053 m .33882 .80079 L .33902 .80059 L F
.759 .484 .517 r
.33713 .80306 m .33882 .80079 L .33575 .80053 L F
.33713 .80306 m .33862 .80397 L .33882 .80079 L F
.569 .143 .193 r
.49071 .77456 m .48942 .77605 L .48703 .77484 L F
.746 .362 .326 r
.49071 .77456 m .49258 .77658 L .48942 .77605 L F
.388 .009 .193 r
.32293 .67516 m .32178 .67714 L .31973 .67749 L F
.257 0 .12 r
.3235 .67652 m .32293 .67516 L .32488 .67541 L F
.3235 .67652 m .32178 .67714 L .32293 .67516 L F
.696 .441 .534 r
.49374 .76657 m .49687 .76843 L .49568 .76549 L F
.49374 .76657 m .49345 .76885 L .49687 .76843 L F
.252 0 .27 r
.63255 .59896 m .63465 .59665 L .63325 .59742 L F
.771 .576 .635 r
.7222 .74134 m .72553 .7404 L .72382 .73886 L F
.7222 .74134 m .72382 .73886 L .72419 .74023 L F
.854 .409 .004 r
.722 .73661 m .72318 .73855 L .72382 .73886 L F
.515 .779 .992 r
.72357 .73533 m .72427 .73629 L .722 .73661 L F
.888 .493 .271 r
.72142 .73849 m .72419 .74023 L .722 .73661 L F
.72142 .73849 m .722 .73661 L .72427 .73629 L F
.72192 .73777 m .72427 .73629 L .72357 .73533 L F
.72142 .73849 m .72216 .73792 L .72192 .73777 L F
.72216 .73792 m .72427 .73629 L .72192 .73777 L F
.854 .409 .004 r
.72318 .73855 m .72419 .74023 L .72385 .73897 L F
.72318 .73855 m .72385 .73897 L .72382 .73886 L F
.379 .37 .723 r
.68731 .59084 m .68708 .59438 L .68992 .59359 L F
.102 0 .062 r
.37031 .69088 m .36786 .69305 L .3687 .69178 L F
.619 .777 .957 r
.6968 .64426 m .69756 .64225 L .69538 .64291 L F
.6968 .64426 m .69888 .64356 L .69756 .64225 L F
.719 .188 0 r
.71957 .70598 m .71883 .70444 L .7176 .70369 L F
.71957 .70598 m .72071 .70646 L .71883 .70444 L F
.735 .208 0 r
.71883 .70444 m .72071 .70646 L .72181 .70683 L F
.334 .112 .421 r
.35603 .70641 m .35476 .7051 L .35667 .70466 L F
.35603 .70641 m .35443 .707 L .35476 .7051 L F
.838 .417 .236 r
.67708 .60806 m .68043 .61069 L .67955 .61046 L F
.67708 .60806 m .6784 .61011 L .68043 .61069 L F
.903 .655 .553 r
.67833 .61223 m .68043 .61069 L .6784 .61011 L F
.67833 .61223 m .68036 .61326 L .68043 .61069 L F
.596 .453 .658 r
.34969 .77426 m .3517 .77148 L .34958 .77184 L F
.683 .627 .787 r
.50649 .74761 m .50324 .74534 L .50518 .74511 L F
.632 .689 .885 r
.50735 .74477 m .50649 .74761 L .50518 .74511 L F
.50735 .74477 m .50914 .74708 L .50649 .74761 L F
.546 .407 .643 r
.50914 .74708 m .50685 .75031 L .50649 .74761 L F
.835 .586 .563 r
.66207 .61318 m .66049 .61526 L .6604 .6131 L F
.66207 .61318 m .6619 .61604 L .66049 .61526 L F
.601 .382 .555 r
.66435 .61542 m .6619 .61604 L .66207 .61318 L F
.58 .343 .521 r
.37522 .68339 m .37486 .68554 L .37249 .68578 L F
.343 .135 .446 r
.37644 .68481 m .37522 .68339 L .37692 .68279 L F
.37644 .68481 m .37486 .68554 L .37522 .68339 L F
.513 .292 .517 r
.52523 .83383 m .52803 .83082 L .52459 .8311 L F
.52523 .83383 m .52767 .83345 L .52803 .83082 L F
.37 .148 .442 r
.53358 .77123 m .53364 .77419 L .53169 .77383 L F
.373 .036 .259 r
.53169 .77383 m .53287 .7757 L .53113 .77645 L F
.53169 .77383 m .53364 .77419 L .53287 .7757 L F
.326 .735 .979 r
.45662 .72604 m .4587 .72601 L .45992 .72668 L F
.318 .735 .976 r
.4587 .72601 m .46202 .72665 L .45992 .72668 L F
.716 .64 .772 r
.33489 .79653 m .33572 .79937 L .33456 .79905 L F
.665 .593 .765 r
.3351 .79828 m .33456 .79905 L .33519 .79896 L F
.33489 .79653 m .33475 .79758 L .3351 .79828 L F
.33475 .79758 m .33456 .79905 L .3351 .79828 L F
.616 .864 .99 r
.33469 .79921 m .33519 .79896 L .33456 .79905 L F
.739 .348 .311 r
.33572 .79937 m .33575 .80053 L .33456 .79905 L F
.616 .864 .99 r
.33473 .79927 m .33486 .79919 L .33469 .79921 L F
.33486 .79919 m .33519 .79896 L .33469 .79921 L F
.787 .68 .746 r
.33241 .79865 m .33486 .79919 L .33489 .79653 L F
.33486 .79919 m .33519 .79896 L .33489 .79653 L F
.33522 .79926 m .33572 .79937 L .33489 .79653 L F
.625 .794 .963 r
.33427 .79784 m .33546 .7991 L .33241 .79865 L F
.33546 .7991 m .33572 .79937 L .33486 .79919 L F
.787 .68 .746 r
.33486 .79919 m .33522 .79926 L .33519 .79896 L F
.625 .794 .963 r
.33546 .7991 m .33486 .79919 L .33241 .79865 L F
.943 .583 .206 r
.33557 .79921 m .33573 .79952 L .33572 .79937 L F
.616 .864 .99 r
.33575 .80053 m .33846 .79851 L .33519 .79896 L F
.33575 .80053 m .33519 .79896 L .33473 .79927 L F
.943 .583 .206 r
.33427 .79784 m .33575 .80053 L .33573 .79952 L F
.665 .593 .765 r
.33489 .79653 m .33519 .79896 L .33846 .79851 L F
.943 .583 .206 r
.33427 .79784 m .33573 .79952 L .33557 .79921 L F
.251 .748 .676 r
.40619 .78112 m .40935 .77999 L .41002 .77975 L F
0 0 0 r
.41002 .77975 m .41141 .77946 L .41195 .77906 L F
.41002 .77975 m .40935 .77999 L .41141 .77946 L F
.556 .308 .495 r
.34809 .71297 m .34762 .71511 L .34538 .71528 L F
.375 .143 .429 r
.34977 .71237 m .34762 .71511 L .34809 .71297 L F
.156 .422 .861 r
.69291 .72097 m .69459 .72329 L .69542 .72246 L F
.173 .449 .877 r
.69459 .72329 m .69757 .72536 L .69542 .72246 L F
.637 .765 .94 r
.34901 .65405 m .3456 .6534 L .34764 .65327 L F
.469 .762 .994 r
.34963 .65285 m .34901 .65405 L .34764 .65327 L F
.34963 .65285 m .35102 .65384 L .34901 .65405 L F
.57 .923 .736 r
.33569 .67438 m .33674 .67376 L .33538 .67387 L F
.349 0 0 r
.33875 .67346 m .33538 .67387 L .33674 .67376 L F
.755 .532 .594 r
.61779 .65568 m .61986 .65802 L .62067 .65654 L F
.638 .241 .275 r
.61986 .65802 m .62301 .65817 L .62067 .65654 L F
.425 .262 .556 r
.53617 .7685 m .53612 .77135 L .53358 .77123 L F
.378 .155 .443 r
.53547 .77335 m .53358 .77123 L .53612 .77135 L F
.53547 .77335 m .53364 .77419 L .53358 .77123 L F
.471 0 0 r
.64769 .62458 m .64404 .62359 L .64343 .626 L F
.933 .615 .412 r
.64142 .62542 m .64133 .62809 L .64132 .62551 L F
.64142 .62542 m .64238 .62888 L .64133 .62809 L F
.807 .998 .847 r
.64133 .62809 m .64343 .626 L .64132 .62551 L F
.498 .907 .845 r
.6424 .62612 m .64476 .62495 L .64629 .62466 L F
.587 .928 .956 r
.64476 .62495 m .64569 .62478 L .64629 .62466 L F
.471 0 0 r
.64769 .62458 m .64629 .62466 L .64729 .62447 L F
.174 .71 .761 r
.64629 .62466 m .64768 .62441 L .64769 .62458 L F
.64629 .62466 m .64768 .62441 L .64769 .62458 L F
.587 .928 .956 r
.64569 .62478 m .64768 .62441 L .64629 .62466 L F
.471 0 0 r
.64729 .62447 m .64629 .62466 L .64404 .62359 L F
.48 .898 .84 r
.64343 .626 m .64629 .62466 L .64769 .62458 L F
.665 .448 .581 r
.64769 .62458 m .64465 .62901 L .64509 .62671 L F
.64769 .62458 m .64817 .62871 L .64465 .62901 L F
.693 .468 .578 r
.65012 .62843 m .64769 .62458 L .64891 .62471 L F
.65012 .62843 m .64817 .62871 L .64769 .62458 L F
.722 .599 .718 r
.72993 .71815 m .72642 .71853 L .72631 .71464 L F
.614 .532 .739 r
.72942 .72013 m .72642 .71853 L .72993 .71815 L F
.72942 .72013 m .72993 .71815 L .72891 .71894 L F
0 .256 .767 r
.72942 .72013 m .72891 .71894 L .72993 .71815 L F
.84 .902 .881 r
.72132 .59614 m .72229 .59701 L .72105 .59867 L F
.519 .581 .857 r
.71832 .73637 m .71683 .73515 L .71867 .7339 L F
.187 0 .057 r
.33283 .70947 m .33428 .70947 L .33551 .70745 L F
.205 0 .067 r
.33551 .70745 m .33605 .70875 L .33752 .70703 L F
.33551 .70745 m .33428 .70947 L .33605 .70875 L F
.285 0 .103 r
.44409 .76918 m .44488 .77058 L .44631 .76912 L F
.44409 .76918 m .4429 .77119 L .44488 .77058 L F
.756 .515 .568 r
.33626 .7952 m .33982 .79312 L .33756 .79326 L F
.958 .621 .248 r
.51291 .75564 m .51421 .75831 L .51326 .75717 L F
.849 .822 .821 r
.51421 .75831 m .51111 .76011 L .51339 .75973 L F
.51421 .75831 m .51339 .75973 L .51326 .75717 L F
.397 0 .087 r
.51326 .75717 m .51647 .75571 L .51421 .75831 L F
.673 .568 .728 r
.51647 .75571 m .51741 .75864 L .51421 .75831 L F
0 0 0 r
.39616 .79586 m .39275 .7973 L .39429 .79657 L F
.737 .68 .796 r
.71162 .58968 m .71099 .59305 L .70981 .59005 L F
.618 .351 .49 r
.71099 .59305 m .71332 .59383 L .71036 .59289 L F
.546 .451 .699 r
.34631 .78259 m .34832 .78222 L .34807 .78002 L F
.57 .367 .566 r
.34631 .78259 m .34834 .78463 L .34832 .78222 L F
.34631 .78259 m .34617 .78494 L .34834 .78463 L F
.333 0 .075 r
.31886 .65259 m .32237 .65029 L .3205 .65132 L F
.71 .248 .154 r
.51146 .78465 m .51469 .78533 L .51373 .78657 L F
.708 .246 .153 r
.51373 .78657 m .51469 .78533 L .51682 .7872 L F
.191 .252 .697 r
.66967 .60405 m .66842 .60539 L .66785 .60205 L F
.829 .42 0 r
.66859 .6067 m .66949 .60779 L .66842 .60539 L F
.66859 .6067 m .66842 .60539 L .66967 .60405 L F
.271 .758 .666 r
.38265 .80015 m .38621 .79874 L .38461 .80014 L F
.118 0 0 r
.38686 .79933 m .38621 .79874 L .38785 .79824 L F
.38686 .79933 m .38461 .80014 L .38621 .79874 L F
.737 .53 .614 r
.59518 .66178 m .5912 .66396 L .59163 .66167 L F
.59518 .66178 m .59497 .66429 L .5912 .66396 L F
.642 .616 .808 r
.4912 .75552 m .49468 .75802 L .49345 .75502 L F
.654 .604 .786 r
.49345 .75502 m .49468 .75802 L .49667 .75577 L F
.617 .547 .753 r
.49468 .75802 m .49754 .75902 L .49667 .75577 L F
.494 .555 .847 r
.37324 .66872 m .37196 .67048 L .37155 .66886 L F
.37324 .66872 m .37467 .67175 L .37196 .67048 L F
0 .274 .721 r
.67066 .59594 m .67169 .59681 L .67003 .59581 L F
.842 .638 .626 r
.61604 .65298 m .61811 .65121 L .61633 .65057 L F
.61604 .65298 m .6179 .65335 L .61811 .65121 L F
.821 .802 .834 r
.73325 .72364 m .7339 .72619 L .73287 .72546 L F
.763 .51 .551 r
.7339 .72619 m .73073 .72808 L .73287 .72546 L F
.7339 .72619 m .73418 .72862 L .73073 .72808 L F
.836 .81 .825 r
.73614 .72339 m .7339 .72619 L .73325 .72364 L F
.618 .405 .571 r
.73454 .72776 m .73418 .72862 L .7339 .72619 L F
0 0 0 r
.31674 .73693 m .31814 .7364 L .31578 .73746 L F
.823 .461 .371 r
.5114 .78255 m .51018 .78424 L .5087 .78185 L F
.959 .688 .48 r
.51146 .78465 m .51018 .78424 L .5114 .78255 L F
.537 .222 .381 r
.43699 .73705 m .43616 .73931 L .43373 .73949 L F
.58 .265 .4 r
.43952 .73789 m .43616 .73931 L .43699 .73705 L F
.981 .696 .399 r
.67095 .62065 m .67115 .6229 L .67206 .62169 L F
.645 .5 .671 r
.6735 .62097 m .67206 .62169 L .67431 .61875 L F
.981 .696 .399 r
.67095 .62065 m .67115 .6229 L .67206 .62169 L F
.086 .638 .822 r
.42795 .72393 m .43023 .72398 L .43146 .7242 L F
0 0 0 r
.43023 .72398 m .43344 .72384 L .43146 .7242 L F
.467 .834 .582 r
.69625 .69505 m .69401 .69682 L .69532 .69574 L F
.545 .212 .355 r
.39719 .74971 m .39401 .75181 L .39509 .74995 L F
.442 0 .081 r
.31942 .71639 m .32321 .71483 L .3203 .71603 L F
.31942 .71639 m .32158 .71641 L .32321 .71483 L F
.215 0 0 r
.32321 .71483 m .32353 .71596 L .32525 .71457 L F
.32321 .71483 m .32158 .71641 L .32353 .71596 L F
.642 .279 .34 r
.71589 .73486 m .71867 .7339 L .71683 .73515 L F
.729 .678 .8 r
.70813 .58723 m .70981 .59005 L .70691 .58925 L F
.565 .608 .855 r
.71172 .58836 m .70981 .59005 L .70813 .58723 L F
.56 .599 .85 r
.71172 .58836 m .71162 .58968 L .70981 .59005 L F
.536 .788 .991 r
.44108 .72369 m .44024 .72496 L .43894 .72438 L F
.44108 .72369 m .4424 .72459 L .44024 .72496 L F
.845 .726 .732 r
.37068 .80866 m .37248 .80839 L .37318 .80651 L F
.37068 .80866 m .37318 .80651 L .3731 .8073 L F
.604 .498 .707 r
.37571 .80381 m .37318 .80651 L .37299 .80388 L F
.37571 .80381 m .3761 .80709 L .37318 .80651 L F
.414 0 0 r
.37318 .80651 m .37552 .8073 L .3731 .8073 L F
.37318 .80651 m .3761 .80709 L .37552 .8073 L F
.589 .57 .799 r
.48851 .73391 m .48748 .73718 L .4864 .73425 L F
.48851 .73391 m .48954 .7368 L .48748 .73718 L F
.739 .507 .577 r
.68433 .62563 m .68639 .62683 L .68459 .6239 L F
.523 .35 .587 r
.71147 .73562 m .71331 .73406 L .70989 .73375 L F
.71147 .73562 m .71334 .73637 L .71331 .73406 L F
0 0 .538 r
.73045 .71486 m .73238 .71743 L .73125 .71557 L F
.621 .68 .884 r
.47434 .72862 m .47117 .72741 L .4733 .72709 L F
.65 .728 .906 r
.47644 .72785 m .47434 .72862 L .4733 .72709 L F
.725 .614 .734 r
.71677 .59709 m .72006 .59921 L .7191 .59685 L F
.71677 .59709 m .718 .60048 L .72006 .59921 L F
0 .076 .594 r
.71146 .63718 m .71217 .63584 L .71077 .63665 L F
.71146 .63718 m .71182 .63701 L .71217 .63584 L F
.312 0 .016 r
.44859 .77717 m .44724 .77881 L .44514 .7792 L F
.436 .014 .139 r
.4507 .77688 m .44724 .77881 L .44859 .77717 L F
.652 .788 .947 r
.43782 .71783 m .436 .71876 L .43439 .71739 L F
.43782 .71783 m .436 .71876 L .43439 .71739 L F
.699 .637 .784 r
.48318 .88333 m .48698 .88301 L .48486 .88081 L F
.828 .76 .788 r
.68949 .62946 m .69103 .6319 L .688 .63185 L F
.54 .648 .904 r
.69316 .63155 m .69103 .6319 L .68949 .62946 L F
.598 .433 .628 r
.69349 .63419 m .69103 .6319 L .69316 .63155 L F
.69349 .63419 m .69117 .63466 L .69103 .6319 L F
.574 .457 .682 r
.35144 .7668 m .35369 .76874 L .35363 .76633 L F
.35144 .7668 m .35159 .76909 L .35369 .76874 L F
.616 .648 .859 r
.72449 .7198 m .72727 .72107 L .72625 .72018 L F
.614 .532 .739 r
.72942 .72013 m .72727 .72107 L .72642 .71853 L F
.67 .859 .972 r
.72625 .72018 m .72727 .72107 L .72942 .72013 L F
.777 .763 .84 r
.48558 .74488 m .48336 .74728 L .48691 .74745 L F
.775 .766 .844 r
.48336 .74728 m .48484 .74849 L .48691 .74745 L F
.545 .555 .816 r
.48691 .74745 m .48737 .74427 L .48558 .74488 L F
.48691 .74745 m .48891 .74711 L .48737 .74427 L F
.741 .744 .854 r
.5321 .76859 m .53487 .76745 L .53341 .76751 L F
.435 .482 .809 r
.362 .65609 m .36128 .65889 L .35985 .65634 L F
.362 .65609 m .36314 .65909 L .36128 .65889 L F
0 0 .471 r
.668 .60121 m .66698 .60039 L .66807 .59783 L F
.66789 .60112 m .66785 .60205 L .66698 .60039 L F
.935 .611 .161 r
.66706 .60085 m .66795 .60235 L .66748 .60016 L F
.66744 .60006 m .66748 .60016 L .66745 .60004 L F
.66706 .60085 m .66748 .60016 L .66744 .60006 L F
0 0 .471 r
.668 .60121 m .66798 .60132 L .66789 .60112 L F
.66798 .60132 m .66785 .60205 L .66789 .60112 L F
.554 .762 .975 r
.68343 .58988 m .68491 .59127 L .68731 .59084 L F
.463 .597 .901 r
.71036 .59289 m .71142 .59055 L .70931 .59159 L F
.71036 .59289 m .71332 .59383 L .71142 .59055 L F
.224 0 0 r
.46195 .77495 m .46044 .77581 L .45845 .77593 L F
.008 0 0 r
.46355 .77571 m .46044 .77581 L .46195 .77495 L F
.736 .22 0 r
.71298 .70061 m .71243 .69898 L .7107 .69851 L F
.71298 .70061 m .71448 .70109 L .71243 .69898 L F
.496 .299 .543 r
.38304 .76088 m .38305 .76367 L .38112 .76379 L F
.428 .212 .482 r
.38545 .75785 m .38482 .76103 L .38304 .76088 L F
.547 .392 .622 r
.38482 .76103 m .38305 .76367 L .38304 .76088 L F
.469 .231 .469 r
.36359 .69634 m .36266 .69875 L .36112 .69884 L F
.403 .157 .424 r
.3652 .69561 m .36266 .69875 L .36359 .69634 L F
.773 .685 .766 r
.49561 .8414 m .4968 .84431 L .49896 .8416 L F
.543 .357 .58 r
.49896 .8416 m .49893 .84399 L .4968 .84431 L F
.589 .46 .672 r
.35946 .75539 m .36137 .7525 L .35935 .75291 L F
.673 .544 .699 r
.49568 .76549 m .49898 .76622 L .49914 .76422 L F
.684 .502 .635 r
.49568 .76549 m .49687 .76843 L .49898 .76622 L F
.58 .079 .029 r
.37776 .73458 m .37918 .73576 L .37978 .73393 L F
.37776 .73458 m .37625 .73559 L .37918 .73576 L F
.683 .295 .305 r
.48459 .76799 m .4869 .76847 L .48815 .76682 L F
.698 .314 .316 r
.4869 .76847 m .49016 .76869 L .48815 .76682 L F
.478 .282 .536 r
.63059 .64146 m .63297 .63922 L .63041 .63793 L F
.506 .1 .205 r
.40024 .72774 m .40246 .72773 L .40377 .72581 L F
.481 .097 .234 r
.40246 .72773 m .40588 .72553 L .40377 .72581 L F
.57 .785 .98 r
.47976 .72847 m .47644 .72785 L .47853 .72742 L F
.648 .814 .963 r
.48256 .72768 m .47976 .72847 L .47853 .72742 L F
.533 0 0 r
.48703 .77484 m .48632 .77565 L .48366 .77425 L F
.67 .172 .055 r
.48942 .77605 m .48632 .77565 L .48703 .77484 L F
.502 .778 .994 r
.73087 .73671 m .73204 .73558 L .72987 .73574 L F
.73087 .73671 m .73301 .73648 L .73204 .73558 L F
.344 .138 .451 r
.33985 .70196 m .34141 .70151 L .3418 .69918 L F
.411 .316 .637 r
.33985 .70196 m .34172 .70389 L .34141 .70151 L F
.484 .324 .588 r
.33985 .70196 m .33985 .70446 L .34172 .70389 L F
.64 .079 0 r
.72071 .70646 m .72355 .70777 L .72181 .70683 L F
.469 .232 .471 r
.36112 .69884 m .361 .70157 L .36032 .70062 L F
.46 .224 .469 r
.36293 .7012 m .36112 .69884 L .36266 .69875 L F
.36293 .7012 m .361 .70157 L .36112 .69884 L F
.698 .621 .767 r
.4966 .74181 m .49438 .74275 L .49307 .73942 L F
.547 .791 .989 r
.65853 .59297 m .6601 .59406 L .65754 .59471 L F
.377 .16 .453 r
.65883 .59577 m .65754 .59471 L .6601 .59406 L F
.65754 .59471 m .65883 .59577 L .65853 .59297 L F
.65754 .59471 m .65749 .5968 L .65883 .59577 L F
.65883 .59577 m .65749 .5968 L .65754 .59471 L F
.958 .689 .246 r
.67314 .62815 m .67232 .62592 L .67041 .62885 L F
.841 .645 .637 r
.66997 .631 m .67314 .62815 L .67041 .62885 L F
.66997 .631 m .67174 .63183 L .67314 .62815 L F
.546 .407 .643 r
.50914 .74708 m .50925 .75034 L .50685 .75031 L F
0 0 .069 r
.50925 .75034 m .5072 .75283 L .50685 .75031 L F
.793 .508 0 r
.66659 .59298 m .66807 .59783 L .66835 .59591 L F
.66659 .59298 m .66778 .5979 L .66807 .59783 L F
.924 .539 .153 r
.66745 .60004 m .66807 .59783 L .66778 .5979 L F
.66745 .60004 m .668 .60121 L .66807 .59783 L F
.62 .714 .913 r
.49869 .74115 m .49976 .74254 L .4966 .74181 L F
.637 .721 .908 r
.50196 .74197 m .49976 .74254 L .49869 .74115 L F
.616 .563 .772 r
.50324 .74534 m .49976 .74254 L .50196 .74197 L F
.268 .025 .349 r
.36664 .69475 m .36596 .69388 L .36786 .69305 L F
.36664 .69475 m .3652 .69561 L .36596 .69388 L F
.92 .834 .379 r
.71618 .62998 m .7166 .62976 L .71603 .62798 L F
.71618 .62998 m .71621 .63209 L .7166 .62976 L F
.922 .827 .735 r
.67431 .61875 m .6735 .62097 L .67303 .61792 L F
.67303 .61792 m .6735 .62097 L .67431 .61875 L F
.661 .248 .251 r
.49924 .77684 m .4981 .77828 L .49588 .77675 L F
.661 .244 .243 r
.50124 .77735 m .4981 .77828 L .49924 .77684 L F
.934 .75 .273 r
.72631 .71464 m .72642 .71853 L .72609 .71643 L F
.347 .81 .708 r
.31033 .68155 m .30831 .68233 L .30742 .68283 L F
0 0 0 r
.31198 .68111 m .30831 .68233 L .31033 .68155 L F
.527 .179 .32 r
.41774 .77625 m .41407 .779 L .41604 .77838 L F
.41774 .77625 m .41472 .77756 L .41407 .779 L F
0 0 0 r
.41774 .77625 m .41871 .77578 L .41994 .77446 L F
.41774 .77625 m .41604 .77838 L .41871 .77578 L F
.705 .872 .96 r
.70603 .60248 m .70701 .60268 L .70874 .60164 L F
.272 .607 .954 r
.28768 .60725 m .28829 .60736 L .28848 .60798 L F
.844 .974 .876 r
.28848 .60798 m .28829 .60736 L .28763 .60802 L F
.623 .678 .881 r
.48122 .74756 m .48484 .74849 L .48336 .74728 L F
.601 .435 .629 r
.37641 .72882 m .37891 .72904 L .37857 .7261 L F
.37641 .72882 m .37891 .72904 L .37857 .7261 L F
.369 .794 .972 r
.70228 .59735 m .7043 .59706 L .70563 .59749 L F
.955 .717 .263 r
.67273 .60788 m .67204 .60879 L .67214 .60619 L F
.67273 .60788 m .67277 .61006 L .67204 .60879 L F
.722 .299 .241 r
.73197 .73091 m .73438 .73315 L .73508 .7315 L F
.949 .612 .343 r
.73438 .73315 m .73579 .73402 L .73508 .7315 L F
.244 0 0 r
.52641 .77296 m .52542 .77215 L .52486 .77347 L F
.52641 .77296 m .52789 .77189 L .52542 .77215 L F
.787 .319 .124 r
.71513 .62673 m .71603 .62798 L .71435 .62739 L F
.797 .939 .582 r
.71513 .62673 m .71435 .62739 L .71565 .62509 L F
.572 .38 .582 r
.34188 .79034 m .34413 .7877 L .34184 .78795 L F
.966 .877 .696 r
.64898 .63639 m .64972 .63638 L .64836 .6405 L F
.451 .466 .783 r
.48006 .74219 m .4809 .73886 L .47892 .73901 L F
.48006 .74219 m .48195 .74196 L .4809 .73886 L F
.55 .514 .768 r
.48077 .7454 m .48195 .74196 L .48006 .74219 L F
.539 .468 .724 r
.48122 .74756 m .48283 .74498 L .48077 .7454 L F
.48122 .74756 m .48336 .74728 L .48283 .74498 L F
.835 .406 0 r
.68036 .61326 m .68125 .61517 L .6822 .61599 L F
.77 .392 .34 r
.6807 .61754 m .6822 .61599 L .68125 .61517 L F
.6807 .61754 m .6841 .61827 L .6822 .61599 L F
.523 .62 .89 r
.688 .58548 m .68653 .58733 L .68604 .5856 L F
.688 .58548 m .68846 .58724 L .68653 .58733 L F
.759 .545 .607 r
.63493 .64763 m .63818 .65043 L .63608 .64899 L F
.488 .815 1 r
.46202 .72665 m .46416 .72626 L .4655 .72696 L F
.311 .755 .963 r
.46416 .72626 m .46759 .72666 L .4655 .72696 L F
.083 .605 .878 r
.41871 .77578 m .42192 .77656 L .41994 .77446 L F
.126 .618 .91 r
.42071 .77605 m .42192 .77656 L .42062 .77604 L F
.709 .176 0 r
.41994 .77446 m .42192 .77656 L .42309 .77706 L F
.126 .618 .91 r
.42261 .77611 m .42192 .77656 L .42071 .77605 L F
.709 .176 0 r
.42309 .77706 m .42192 .77656 L .4233 .77723 L F
.713 .475 .563 r
.5135 .77121 m .51657 .76917 L .51331 .76878 L F
.5135 .77121 m .5177 .77182 L .51657 .76917 L F
.477 .361 .643 r
.51657 .76917 m .5177 .77182 L .51881 .77107 L F
.451 .219 .47 r
.3876 .75636 m .38482 .76103 L .38545 .75785 L F
.528 .164 .294 r
.39301 .72901 m .3947 .7303 L .39608 .72802 L F
.45 .056 .198 r
.3947 .7303 m .39812 .72809 L .39608 .72802 L F
.371 0 .068 r
.41441 .78968 m .41019 .79173 L .41214 .79014 L F
.649 .967 .824 r
.70344 .71148 m .70517 .71077 L .70647 .70926 L F
.79 .397 .31 r
.70344 .71148 m .70539 .71216 L .70517 .71077 L F
.356 0 .016 r
.454 .76887 m .45614 .76863 L .45746 .76715 L F
.446 0 .076 r
.45746 .76715 m .45614 .76863 L .45921 .76786 L F
.424 .04 .204 r
.31239 .71801 m .31366 .7178 L .31245 .7179 L F
.405 .607 .931 r
.48486 .88081 m .48698 .88301 L .48701 .8821 L F
0 .476 .814 r
.35529 .65428 m .3545 .65434 L .35287 .6539 L F
.35529 .65428 m .35669 .65495 L .3545 .65434 L F
.537 .894 .679 r
.64983 .65286 m .647 .6548 L .64873 .65427 L F
.24 .678 .958 r
.39598 .77961 m .39208 .77839 L .39477 .77842 L F
0 .439 .859 r
.39598 .77886 m .39598 .77961 L .39477 .77842 L F
0 .399 .839 r
.39598 .77886 m .39729 .78008 L .39598 .77961 L F
.399 .765 .993 r
.50348 .84966 m .5058 .84961 L .5044 .84879 L F
.5044 .84879 m .5058 .84961 L .50348 .84966 L F
.545 .873 .993 r
.71292 .62975 m .70958 .62986 L .71219 .62913 L F
.689 .937 .965 r
.71603 .62798 m .71292 .62975 L .71219 .62913 L F
.667 .674 .847 r
.69757 .72536 m .69778 .72662 L .69943 .72571 L F
.373 .084 .338 r
.63141 .66474 m .63065 .6664 L .62869 .66717 L F
.066 0 .161 r
.63141 .66474 m .6328 .66369 L .63065 .6664 L F
0 0 .347 r
.67856 .60663 m .6784 .61011 L .67708 .60806 L F
.589 .434 .64 r
.34765 .77697 m .3499 .77697 L .34969 .77426 L F
.513 .383 .641 r
.34765 .77697 m .34979 .77941 L .3499 .77697 L F
.34765 .77697 m .34807 .78002 L .34979 .77941 L F
.55 .514 .768 r
.48077 .7454 m .48283 .74498 L .48195 .74196 L F
0 0 0 r
.62775 .65534 m .62879 .65392 L .62625 .65625 L F
.63044 .65278 m .62879 .65392 L .62775 .65534 L F
.56 .444 .677 r
.38305 .76367 m .38131 .76586 L .38112 .76379 L F
.563 0 0 r
.67651 .63398 m .67862 .63535 L .67743 .63507 L F
0 .362 .826 r
.68009 .63667 m .67651 .63398 L .67808 .63445 L F
.776 .274 0 r
.67863 .63506 m .6812 .63747 L .68009 .63667 L F
0 .362 .826 r
.68009 .63667 m .68027 .63642 L .67651 .63398 L F
.563 0 0 r
.67862 .63535 m .68027 .63642 L .67862 .63563 L F
.67862 .63535 m .67862 .63563 L .67743 .63507 L F
.776 .274 0 r
.67808 .63445 m .67863 .63498 L .67863 .63506 L F
.67863 .63498 m .6812 .63747 L .67863 .63506 L F
.717 .249 .136 r
.6812 .63747 m .68025 .63846 L .68009 .63667 L F
.6812 .63747 m .68334 .63948 L .68025 .63846 L F
.689 .904 .553 r
.64983 .65286 m .65094 .65143 L .64966 .65279 L F
.516 .888 .69 r
.64966 .65279 m .65082 .65176 L .64947 .65271 L F
.64966 .65279 m .64947 .65271 L .64826 .65355 L F
.689 .904 .553 r
.64983 .65286 m .64983 .65286 L .64966 .65279 L F
0 0 0 r
.65224 .64987 m .64966 .65279 L .65094 .65143 L F
.475 .031 .112 r
.38165 .73327 m .38387 .73327 L .38533 .73162 L F
.367 0 .036 r
.38387 .73327 m .38747 .73137 L .38533 .73162 L F
.424 .145 .384 r
.65207 .61024 m .65221 .60817 L .65429 .60749 L F
.467 .338 .621 r
.37857 .7261 m .37891 .72904 L .38053 .72804 L F
.38053 .72804 m .37891 .72904 L .37857 .7261 L F
.519 .081 .146 r
.30742 .68283 m .30549 .68482 L .30402 .68397 L F
0 0 0 r
.30831 .68233 m .30549 .68482 L .30742 .68283 L F
.182 0 0 r
.42192 .77656 m .42541 .77693 L .4233 .77723 L F
.587 .444 .654 r
.3517 .77148 m .35369 .76874 L .35159 .76909 L F
.964 .722 .523 r
.37226 .8413 m .37243 .83889 L .37105 .83841 L F
.37105 .83841 m .37243 .83889 L .37226 .8413 L F
.802 .882 .904 r
.7289 .74457 m .72992 .74546 L .73168 .7441 L F
.616 .864 .99 r
.33575 .80053 m .33902 .80059 L .33846 .79851 L F
.511 .542 .824 r
.33902 .80059 m .33998 .79817 L .33846 .79851 L F
.33902 .80059 m .34098 .80071 L .33998 .79817 L F
.836 .81 .825 r
.73614 .72339 m .73325 .72364 L .7354 .72256 L F
.932 .612 .157 r
.73598 .72511 m .73614 .72339 L .7354 .72256 L F
.73598 .72511 m .73665 .72588 L .73614 .72339 L F
.237 0 0 r
.38723 .77908 m .38975 .7797 L .3902 .77973 L F
.54 .916 .763 r
.39208 .77839 m .3902 .77973 L .39105 .77886 L F
.538 .924 .823 r
.3902 .77973 m .38975 .7797 L .39105 .77886 L F
.863 .854 .832 r
.66129 .62874 m .65925 .62888 L .66142 .62666 L F
.823 .629 .64 r
.64648 .59724 m .64316 .59859 L .64414 .59712 L F
.366 0 .025 r
.64414 .59712 m .64316 .59859 L .6408 .59894 L F
0 .322 .767 r
.72826 .73993 m .72864 .74052 L .72729 .73975 L F
.72826 .73993 m .73068 .7417 L .72864 .74052 L F
.511 .273 .49 r
.3635 .7475 m .36555 .74716 L .36597 .74503 L F
.574 .375 .573 r
.36555 .74716 m .36799 .74446 L .36597 .74503 L F
.982 .84 .627 r
.71618 .62998 m .71631 .63447 L .71621 .63209 L F
.267 0 0 r
.41983 .74216 m .41961 .7423 L .41702 .74208 L F
.595 .232 .322 r
.33538 .67387 m .33245 .6752 L .33569 .67438 L F
.424 0 .049 r
.33538 .67387 m .33201 .67563 L .33245 .6752 L F
.33538 .67387 m .33467 .67542 L .33201 .67563 L F
.31 0 0 r
.33803 .67408 m .33467 .67542 L .33538 .67387 L F
.349 0 0 r
.33875 .67346 m .33803 .67408 L .33538 .67387 L F
.547 .188 .31 r
.70081 .69393 m .7037 .69383 L .70164 .69355 L F
.765 .722 .813 r
.70705 .62707 m .70772 .63031 L .70447 .62935 L F
.593 .608 .836 r
.70901 .62772 m .70772 .63031 L .70705 .62707 L F
.573 .584 .826 r
.70958 .62986 m .70772 .63031 L .70901 .62772 L F
.386 .106 .361 r
.62624 .66943 m .62869 .66717 L .6282 .6689 L F
0 0 0 r
.63065 .6664 m .6282 .6689 L .62869 .66717 L F
.204 0 0 r
.41994 .78723 m .4193 .78804 L .41636 .78938 L F
.152 0 0 r
.42208 .7867 m .42113 .78743 L .41994 .78723 L F
.151 0 0 r
.42113 .78743 m .4193 .78804 L .41994 .78723 L F
.417 .782 .995 r
.65356 .63371 m .65235 .63473 L .65115 .63422 L F
.65356 .63371 m .65488 .63461 L .65235 .63473 L F
.796 .959 .918 r
.64898 .63639 m .65115 .63422 L .65235 .63473 L F
.334 0 0 r
.69401 .69682 m .69525 .69772 L .69532 .69574 L F
.69401 .69682 m .6929 .69817 L .69525 .69772 L F
.675 .948 .958 r
.50156 .88161 m .49853 .88231 L .50017 .88304 L F
.496 .287 .525 r
.34538 .71528 m .34512 .71753 L .34315 .71793 L F
.252 0 .22 r
.34512 .71753 m .34266 .7199 L .34315 .71793 L F
.594 .445 .649 r
.35738 .75813 m .35959 .75793 L .35946 .75539 L F
.492 .309 .561 r
.35756 .76101 m .35959 .75793 L .35738 .75813 L F
.552 .389 .613 r
.36137 .7525 m .36344 .74982 L .36143 .75024 L F
.717 .575 .694 r
.59679 .67728 m .59798 .68032 L .59443 .68012 L F
.694 .563 .703 r
.60016 .67764 m .59798 .68032 L .59679 .67728 L F
.327 .623 .958 r
.33011 .6497 m .33188 .6499 L .33135 .65102 L F
.481 .8 1 r
.33135 .65102 m .33188 .6499 L .33336 .65069 L F
.934 .75 .273 r
.72631 .71464 m .72609 .71643 L .72349 .71555 L F
.228 .699 .942 r
.43363 .72387 m .43537 .72387 L .43665 .72443 L F
.258 .721 .949 r
.43537 .72387 m .43894 .72438 L .43665 .72443 L F
.43537 .72387 m .43763 .72383 L .43894 .72438 L F
0 0 0 r
.43421 .72442 m .43741 .72387 L .43537 .72387 L F
.43741 .72387 m .43763 .72383 L .43537 .72387 L F
.228 .699 .942 r
.43344 .72384 m .43537 .72387 L .43363 .72387 L F
.618 .953 .8 r
.7214 .61998 m .71955 .62154 L .71828 .62194 L F
.597 .588 .813 r
.3814 .77737 m .37796 .77469 L .38013 .77427 L F
.651 .612 .798 r
.38359 .77679 m .3814 .77737 L .38013 .77427 L F
0 0 0 r
.62515 .65765 m .62775 .65534 L .62625 .65625 L F
.896 .882 .813 r
.64524 .64236 m .64639 .64329 L .64525 .64461 L F
.848 .808 .811 r
.64701 .63942 m .64639 .64329 L .64524 .64236 L F
.64701 .63942 m .64836 .6405 L .64639 .64329 L F
.599 .877 .557 r
.33303 .80859 m .33252 .80932 L .33337 .80836 L F
0 0 0 r
.33237 .80968 m .33252 .80932 L .33303 .80859 L F
.438 .238 .509 r
.34691 .71688 m .34538 .71528 L .34762 .71511 L F
.34691 .71688 m .34512 .71753 L .34538 .71528 L F
.232 0 0 r
.64217 .5913 m .64426 .5907 L .64516 .58918 L F
.231 0 0 r
.64516 .58918 m .64641 .59004 L .64754 .58886 L F
.64516 .58918 m .64426 .5907 L .64641 .59004 L F
.932 .945 .604 r
.72304 .6245 m .72171 .62585 L .7224 .62543 L F
.355 0 0 r
.72459 .62511 m .72304 .6245 L .72495 .62351 L F
.109 0 0 r
.7224 .62543 m .71949 .6262 L .72084 .62729 L F
.355 0 0 r
.72459 .62511 m .72171 .62585 L .72304 .6245 L F
.686 .823 .949 r
.47333 .73954 m .47664 .73965 L .47539 .73864 L F
.645 .802 .958 r
.47539 .73864 m .47664 .73965 L .47892 .73901 L F
.582 .434 .645 r
.5191 .75542 m .51741 .75864 L .51647 .75571 L F
.5191 .75542 m .51964 .75837 L .51741 .75864 L F
.669 .502 .649 r
.52007 .76066 m .51741 .75864 L .51964 .75837 L F
.52007 .76066 m .5176 .76106 L .51741 .75864 L F
.435 .871 .799 r
.31091 .71906 m .31366 .7178 L .31239 .71801 L F
.481 .428 .721 r
.64803 .61973 m .64861 .6214 L .64655 .62162 L F
.681 .718 .877 r
.66779 .64222 m .66906 .63912 L .66675 .64132 L F
.66779 .64222 m .67003 .64203 L .66906 .63912 L F
.975 .747 .529 r
.67591 .62868 m .67716 .62949 L .67698 .6318 L F
.659 .7 .877 r
.70462 .71996 m .70746 .7206 L .70643 .71762 L F
.82 .717 .751 r
.70643 .71762 m .70746 .7206 L .70832 .71719 L F
.566 .456 .688 r
.70746 .7206 m .70979 .72035 L .70832 .71719 L F
.776 .702 .781 r
.51756 .76409 m .51885 .76643 L .52137 .76401 L F
.257 .705 .957 r
.46113 .73624 m .45779 .73555 L .45916 .73629 L F
.245 0 0 r
.33139 .71084 m .33428 .70947 L .33283 .70947 L F
.151 0 0 r
.42986 .78463 m .42607 .78604 L .42782 .78468 L F
.623 .526 .723 r
.49076 .75339 m .4912 .75552 L .49329 .75305 L F
.668 .592 .761 r
.4912 .75552 m .49345 .75502 L .49329 .75305 L F
.616 .335 .469 r
.65809 .63757 m .658 .63927 L .6557 .63744 L F
.65809 .63757 m .658 .63927 L .6557 .63744 L F
.578 .336 .513 r
.37486 .68554 m .37442 .68765 L .37249 .68578 L F
.483 .337 .606 r
.37442 .68765 m .3726 .68826 L .37249 .68578 L F
.452 .058 .2 r
.38968 .73114 m .39166 .73096 L .39301 .72901 L F
.543 .155 .257 r
.39301 .72901 m .39166 .73096 L .3947 .7303 L F
.63 .715 .908 r
.46113 .73624 m .46231 .73768 L .46443 .73706 L F
0 0 .03 r
.6282 .6689 m .62592 .67167 L .62624 .66943 L F
.988 .742 .47 r
.69331 .70446 m .69229 .70656 L .69374 .70257 L F
.69331 .70446 m .69326 .70738 L .69229 .70656 L F
.891 .725 .67 r
.67808 .63445 m .67651 .63398 L .67698 .6318 L F
0 0 0 r
.32307 .73296 m .32159 .73431 L .3238 .7319 L F
.085 0 0 r
.32576 .73138 m .32307 .73296 L .3238 .7319 L F
.735 .803 .906 r
.52137 .76401 m .51756 .76409 L .52007 .76066 L F
.776 .702 .781 r
.51756 .76409 m .52137 .76401 L .5203 .76339 L F
.979 .681 .353 r
.52007 .76066 m .5203 .76339 L .52137 .76401 L F
.553 .584 .839 r
.36503 .65851 m .36443 .6618 L .36314 .65909 L F
.36503 .65851 m .36642 .66149 L .36443 .6618 L F
.345 .159 .48 r
.34141 .70151 m .3434 .69834 L .3418 .69918 L F
.176 0 0 r
.30654 .65766 m .30935 .65618 L .30738 .65667 L F
.69 .754 .9 r
.67232 .62592 m .6746 .6273 L .67457 .62789 L F
.651 .107 0 r
.6746 .6273 m .67591 .62868 L .67457 .62789 L F
.45 .734 .988 r
.34041 .65239 m .33653 .65141 L .33906 .65158 L F
0 .331 .668 r
.33906 .65158 m .34217 .65282 L .34041 .65239 L F
.181 0 0 r
.68523 .58573 m .68604 .5856 L .68371 .58585 L F
.68523 .58573 m .68371 .58585 L .68177 .58509 L F
.619 .497 .691 r
.49076 .75339 m .4925 .75002 L .48968 .75037 L F
.49076 .75339 m .49329 .75305 L .4925 .75002 L F
.872 .544 .427 r
.5087 .78185 m .50688 .77991 L .50931 .78031 L F
.67 .513 .664 r
.60353 .67941 m .60016 .67764 L .60217 .67762 L F
.613 .37 .525 r
.60566 .67755 m .60353 .67941 L .60217 .67762 L F
.698 .621 .767 r
.4966 .74181 m .49307 .73942 L .49531 .73896 L F
.609 .617 .833 r
.49869 .74115 m .4966 .74181 L .49531 .73896 L F
.727 .871 .949 r
.71109 .59894 m .71477 .59816 L .7136 .5968 L F
.758 .754 .848 r
.7136 .5968 m .71477 .59816 L .71677 .59709 L F
.585 .453 .667 r
.35574 .76159 m .35786 .76327 L .35756 .76101 L F
.35574 .76159 m .35576 .76361 L .35786 .76327 L F
0 0 .498 r
.342 .81562 m .343 .81637 L .34451 .81461 L F
.342 .81562 m .34235 .81793 L .343 .81637 L F
.643 .426 .575 r
.36978 .74168 m .37254 .73916 L .37021 .73967 L F
.661 .244 .243 r
.50124 .77735 m .50006 .77907 L .4981 .77828 L F
.731 .329 .287 r
.50124 .77735 m .50345 .77955 L .50006 .77907 L F
0 0 0 r
.33237 .80968 m .33303 .80859 L .33097 .80872 L F
.81 .575 .583 r
.6881 .61933 m .68728 .62078 L .6841 .61827 L F
.813 .465 .398 r
.68462 .62008 m .6881 .61933 L .6841 .61827 L F
.68462 .62008 m .68782 .62091 L .6881 .61933 L F
.336 .032 .293 r
.6881 .61933 m .68982 .62009 L .68891 .61675 L F
.6881 .61933 m .68782 .62091 L .68982 .62009 L F
.997 .792 .506 r
.7157 .59155 m .71479 .59055 L .71541 .59376 L F
.516 .779 .992 r
.47193 .72608 m .47117 .72741 L .46978 .72636 L F
.47193 .72608 m .4733 .72709 L .47117 .72741 L F
0 .005 .562 r
.34098 .80071 m .34344 .80419 L .34332 .80385 L F
.356 .012 .236 r
.38798 .75573 m .38933 .7556 L .3876 .75636 L F
.38798 .75573 m .38862 .75589 L .38933 .7556 L F
.336 .117 .426 r
.38989 .75288 m .38862 .75589 L .38798 .75573 L F
.198 0 .342 r
.39095 .75445 m .38989 .75288 L .39186 .75219 L F
.39095 .75445 m .38862 .75589 L .38989 .75288 L F
.714 .277 .211 r
.47922 .76554 m .48108 .76646 L .48259 .76613 L F
.695 .227 .137 r
.48108 .76646 m .48459 .76799 L .48259 .76613 L F
.668 .488 .632 r
.59776 .68216 m .59443 .68012 L .59798 .68032 L F
.545 .308 .507 r
.59798 .68032 m .60001 .68206 L .59776 .68216 L F
.645 .493 .663 r
.60016 .67764 m .60022 .6806 L .59798 .68032 L F
.625 .282 .37 r
.60022 .6806 m .60001 .68206 L .59798 .68032 L F
.556 .636 .885 r
.66237 .64242 m .66316 .63977 L .66098 .64024 L F
.66237 .64242 m .66461 .64221 L .66316 .63977 L F
.49 .534 .83 r
.3683 .66139 m .36776 .66444 L .36642 .66149 L F
.3683 .66139 m .36922 .6644 L .36776 .66444 L F
.432 .485 .814 r
.37033 .66588 m .36776 .66444 L .36922 .6644 L F
.795 .705 .765 r
.73068 .7417 m .73168 .7441 L .73356 .74184 L F
0 0 .442 r
.65258 .59673 m .65297 .60028 L .65338 .59885 L F
.211 0 0 r
.65297 .60028 m .65513 .6004 L .65422 .60075 L F
.65297 .60028 m .65422 .60075 L .65338 .59885 L F
.049 0 0 r
.44778 .72584 m .44989 .72583 L .4512 .72572 L F
.241 .743 .898 r
.44989 .72583 m .45325 .72588 L .4512 .72572 L F
.665 .309 .361 r
.34619 .69379 m .34809 .69565 L .34876 .69393 L F
.444 .128 .334 r
.34809 .69565 m .35096 .6933 L .34876 .69393 L F
.567 .588 .833 r
.50405 .74226 m .50324 .74534 L .50196 .74197 L F
.50405 .74226 m .50518 .74511 L .50324 .74534 L F
.555 .398 .623 r
.65024 .6038 m .65083 .60249 L .64766 .60196 L F
.65024 .6038 m .65095 .60526 L .65083 .60249 L F
0 0 0 r
.32255 .73388 m .32159 .73431 L .32307 .73296 L F
.32255 .73388 m .3197 .73541 L .32159 .73431 L F
.697 .404 .475 r
.65809 .63757 m .65999 .63776 L .66144 .63747 L F
.447 .322 .617 r
.65999 .63776 m .66022 .63763 L .66144 .63747 L F
.66022 .63763 m .66281 .63613 L .66144 .63747 L F
.65999 .63776 m .66265 .63818 L .66265 .63814 L F
.363 0 0 r
.66144 .63747 m .66181 .63793 L .66156 .63791 L F
.66144 .63747 m .66156 .63791 L .66022 .63763 L F
0 0 .147 r
.66281 .63613 m .66181 .63793 L .66144 .63747 L F
.447 .322 .617 r
.66022 .63763 m .66156 .63791 L .66281 .63613 L F
.65999 .63776 m .66265 .63814 L .66022 .63763 L F
.363 0 0 r
.66022 .63763 m .66156 .63791 L .65953 .63771 L F
.66007 .63751 m .65999 .63761 L .65809 .63757 L F
.697 .404 .475 r
.65999 .63776 m .65809 .63757 L .65999 .63761 L F
.363 0 0 r
.66028 .63762 m .65953 .63771 L .65809 .63757 L F
.697 .404 .475 r
.65999 .63761 m .65809 .63757 L .66003 .63497 L F
.565 .573 .821 r
.65809 .63757 m .65988 .63775 L .66003 .63497 L F
.908 .812 .341 r
.65999 .63761 m .65988 .63775 L .65999 .63776 L F
.66003 .63497 m .65982 .63783 L .65999 .63761 L F
.363 0 0 r
.66144 .63747 m .66028 .63762 L .65999 .63761 L F
.66144 .63747 m .65999 .63761 L .66007 .63751 L F
.565 .573 .821 r
.65988 .63775 m .66156 .63791 L .66003 .63497 L F
.697 .404 .475 r
.65999 .63776 m .658 .63927 L .65809 .63757 L F
.65809 .63757 m .658 .63927 L .65999 .63776 L F
.908 .812 .341 r
.65988 .63775 m .65982 .63783 L .65988 .6378 L F
.65988 .63775 m .65988 .6378 L .65999 .63776 L F
.66003 .63497 m .65928 .63806 L .65982 .63783 L F
.565 .573 .821 r
.66156 .63791 m .66181 .63793 L .66173 .63781 L F
.66156 .63791 m .66173 .63781 L .66003 .63497 L F
.447 .322 .617 r
.66156 .63791 m .66265 .63814 L .66272 .63725 L F
.66156 .63791 m .66173 .63781 L .66281 .63613 L F
.681 .622 .783 r
.66003 .63497 m .66173 .63781 L .66281 .63613 L F
.66173 .63781 m .66181 .63793 L .66281 .63613 L F
.447 .322 .617 r
.66173 .63781 m .66272 .63725 L .66281 .63613 L F
.451 .125 .321 r
.41145 .74368 m .40972 .74264 L .41477 .74214 L F
.41145 .74368 m .4093 .74414 L .40972 .74264 L F
.704 .729 .87 r
.5191 .75542 m .51647 .75571 L .51875 .75525 L F
.526 .584 .856 r
.52188 .7553 m .5191 .75542 L .51875 .75525 L F
.52188 .7553 m .52032 .7559 L .5191 .75542 L F
.678 .498 .635 r
.52199 .75791 m .5191 .75542 L .52032 .7559 L F
.52187 .75781 m .51964 .75837 L .5191 .75542 L F
.52175 .75796 m .51964 .75837 L .52187 .75781 L F
.698 .585 .725 r
.52199 .75791 m .52007 .76066 L .51964 .75837 L F
.916 .939 .805 r
.52054 .75748 m .51872 .76002 L .51973 .7605 L F
.52017 .75995 m .51973 .7605 L .52007 .76066 L F
.52054 .75748 m .51973 .7605 L .52017 .75995 L F
.678 .498 .635 r
.52199 .75791 m .52175 .75796 L .52187 .75781 L F
.629 .812 .97 r
.69114 .64594 m .69223 .64411 L .69002 .64471 L F
.69114 .64594 m .69339 .64515 L .69223 .64411 L F
.625 .827 .978 r
.34757 .82028 m .34956 .82108 L .34951 .81947 L F
.553 .909 .966 r
.34757 .82028 m .34951 .81947 L .34956 .82108 L F
.594 .802 .979 r
.34951 .81947 m .34956 .82108 L .35187 .81907 L F
.34951 .81947 m .34956 .82108 L .35187 .81907 L F
.625 .827 .978 r
.34757 .82028 m .34956 .82108 L .34951 .81947 L F
.23 0 0 r
.42749 .77655 m .42958 .7762 L .43111 .77495 L F
.37 0 .012 r
.42958 .7762 m .43329 .77453 L .43111 .77495 L F
.975 .823 .628 r
.67875 .58688 m .67871 .58928 L .67718 .58776 L F
.854 .924 .875 r
.67871 .58928 m .675 .59049 L .67718 .58776 L F
.67871 .58928 m .6762 .59126 L .675 .59049 L F
.243 0 0 r
.45351 .73671 m .45219 .73693 L .4501 .73673 L F
0 0 0 r
.4556 .73633 m .45219 .73693 L .45351 .73671 L F
.772 .771 .852 r
.49369 .87429 m .49462 .87629 L .49163 .87608 L F
.808 .623 .653 r
.49462 .87629 m .49356 .87943 L .49163 .87608 L F
.587 .674 .9 r
.49592 .87358 m .49462 .87629 L .49369 .87429 L F
.49592 .87358 m .49722 .87573 L .49462 .87629 L F
.483 .493 .791 r
.48694 .87283 m .48917 .87351 L .48899 .87292 L F
.36 0 0 r
.48531 .87276 m .48694 .87283 L .48875 .87144 L F
.895 .982 .707 r
.48875 .87144 m .48694 .87283 L .489 .86983 L F
.483 .493 .791 r
.48694 .87283 m .48585 .8699 L .489 .86983 L F
.48694 .87283 m .48899 .87292 L .48814 .87007 L F
.36 0 0 r
.48488 .87293 m .48694 .87283 L .48531 .87276 L F
.606 .323 .461 r
.3458 .69576 m .34809 .69565 L .34619 .69379 L F
.583 .098 .069 r
.34256 .67385 m .33875 .67346 L .3415 .67231 L F
.164 .316 .773 r
.3415 .67231 m .34343 .67395 L .34256 .67385 L F
.073 .628 .81 r
.69372 .59688 m .69708 .59715 L .69656 .59698 L F
.689 .577 .725 r
.69992 .59513 m .69934 .59677 L .69708 .59715 L F
.564 .87 .995 r
.69708 .59715 m .69934 .59677 L .69838 .59571 L F
.62 .959 .853 r
.69656 .59698 m .69708 .59715 L .69838 .59571 L F
.687 .499 .627 r
.69692 .59913 m .70044 .597 L .69708 .59715 L F
.671 .436 .555 r
.6166 .67472 m .61332 .67722 L .6133 .67502 L F
.347 .129 .434 r
.72698 .6185 m .72691 .62053 L .72492 .62128 L F
.481 .338 .609 r
.72691 .62053 m .72495 .62351 L .72492 .62128 L F
.729 .638 .756 r
.51647 .75571 m .51291 .75564 L .51537 .75254 L F
.397 0 .087 r
.51647 .75571 m .51326 .75717 L .51291 .75564 L F
.51647 .75571 m .51528 .75722 L .51326 .75717 L F
.51326 .75717 m .51528 .75722 L .51647 .75571 L F
.701 .622 .766 r
.51875 .75525 m .51647 .75571 L .51537 .75254 L F
.772 .577 .635 r
.59639 .66432 m .59458 .66659 L .59497 .66429 L F
.59639 .66432 m .59875 .66742 L .59458 .66659 L F
.978 .731 .494 r
.71449 .73933 m .71333 .73874 L .71334 .73637 L F
.762 .25 0 r
.71449 .73933 m .71368 .73946 L .71333 .73874 L F
.901 .508 .26 r
.64994 .60618 m .65024 .6038 L .6478 .60686 L F
.64994 .60618 m .65095 .60526 L .65024 .6038 L F
.809 .787 .832 r
.66906 .63912 m .67003 .64203 L .67216 .63929 L F
.775 .638 .71 r
.34963 .80959 m .35188 .80985 L .35103 .80647 L F
.099 0 0 r
.34822 .81092 m .35188 .80985 L .34963 .80959 L F
.285 .318 .72 r
.35103 .80647 m .35188 .80985 L .35294 .80835 L F
.53 .656 .916 r
.35188 .80985 m .35435 .80973 L .35294 .80835 L F
.596 .453 .658 r
.34969 .77426 m .35198 .77401 L .3517 .77148 L F
.55 .405 .637 r
.34969 .77426 m .3519 .77659 L .35198 .77401 L F
.34969 .77426 m .3499 .77697 L .3519 .77659 L F
.438 .225 .491 r
.36344 .74982 m .36555 .74716 L .3635 .7475 L F
.67 .513 .664 r
.60353 .67941 m .60022 .6806 L .60016 .67764 L F
.373 0 0 r
.65343 .60523 m .65382 .60447 L .65095 .60526 L F
.973 .838 .43 r
.67309 .61565 m .67302 .61255 L .67383 .61359 L F
.673 .58 .743 r
.49776 .76096 m .49914 .76422 L .50118 .76352 L F
.657 .53 .697 r
.49914 .76422 m .49898 .76622 L .50118 .76352 L F
.793 .648 .702 r
.7136 .5968 m .71677 .59709 L .71546 .59479 L F
.422 0 .02 r
.45921 .76786 m .46135 .76784 L .46273 .76644 L F
.286 0 0 r
.46135 .76784 m .46488 .76611 L .46273 .76644 L F
.579 .698 .923 r
.4853 .72869 m .48256 .72768 L .48413 .72777 L F
.52 .319 .548 r
.4853 .72869 m .48516 .73132 L .48306 .73173 L F
.542 .337 .552 r
.48735 .73077 m .48516 .73132 L .4853 .72869 L F
.48735 .73077 m .4853 .72869 L .48413 .72777 L F
.634 .95 .748 r
.3672 .81106 m .36912 .80999 L .37068 .80866 L F
.769 .681 .766 r
.5099 .76639 m .50787 .76909 L .51108 .76922 L F
.755 .628 .719 r
.50787 .76909 m .51136 .77158 L .51108 .76922 L F
.657 .626 .807 r
.5099 .76639 m .51108 .76922 L .51331 .76878 L F
.642 .524 .704 r
.51108 .76922 m .51136 .77158 L .51331 .76878 L F
.966 .877 .696 r
.64898 .63639 m .64836 .6405 L .64701 .63942 L F
.757 .676 .772 r
.35637 .80871 m .35827 .81251 L .35975 .80902 L F
.453 .311 .597 r
.35102 .69098 m .35305 .69042 L .35286 .68793 L F
.436 .239 .513 r
.35102 .69098 m .35278 .69273 L .35305 .69042 L F
.35102 .69098 m .35096 .6933 L .35278 .69273 L F
.734 .898 .953 r
.44464 .738 m .44806 .73742 L .44657 .73773 L F
.002 0 0 r
.4501 .73673 m .44657 .73773 L .44806 .73742 L F
.261 0 0 r
.31502 .67949 m .31417 .68054 L .31198 .68111 L F
.428 .168 .416 r
.31732 .67753 m .31699 .67941 L .31502 .67949 L F
.161 0 0 r
.31699 .67941 m .31417 .68054 L .31502 .67949 L F
.716 .622 .752 r
.50115 .76585 m .50454 .76636 L .50463 .76479 L F
.686 .498 .626 r
.50115 .76585 m .50449 .76852 L .50454 .76636 L F
.63 .548 .744 r
.50463 .76479 m .50454 .76636 L .50653 .76376 L F
.668 .603 .773 r
.50454 .76636 m .50778 .76638 L .50653 .76376 L F
.739 .568 .661 r
.50449 .76852 m .50778 .76638 L .50454 .76636 L F
.329 .781 .954 r
.33024 .67593 m .32708 .67586 L .32818 .67674 L F
.315 .8 .761 r
.39781 .79503 m .40171 .79385 L .39977 .79459 L F
0 0 0 r
.39977 .79459 m .40171 .79385 L .40363 .7932 L F
.329 .49 .867 r
.34155 .80685 m .34001 .80658 L .33862 .80397 L F
.415 .355 .682 r
.34155 .80685 m .34216 .80872 L .34001 .80658 L F
.639 .604 .798 r
.34686 .67458 m .34876 .67855 L .35032 .67741 L F
.38 .162 .452 r
.34876 .67855 m .35008 .67949 L .35032 .67741 L F
.35032 .67741 m .35008 .67949 L .34876 .67855 L F
.718 .554 .667 r
.49687 .76843 m .499 .76854 L .49898 .76622 L F
.685 .571 .721 r
.50118 .76352 m .49898 .76622 L .50115 .76585 L F
.646 .479 .643 r
.499 .76854 m .50115 .76585 L .49898 .76622 L F
.571 .065 .011 r
.7037 .69383 m .70635 .69503 L .70701 .69396 L F
.755 .279 .111 r
.70635 .69503 m .70902 .6958 L .70701 .69396 L F
.68 .496 .631 r
.59443 .68012 m .5925 .6828 L .59229 .68013 L F
.59443 .68012 m .59464 .68306 L .5925 .6828 L F
.668 .488 .632 r
.59776 .68216 m .59464 .68306 L .59443 .68012 L F
.65 .678 .864 r
.41961 .7423 m .42112 .74428 L .42387 .7436 L F
.285 .021 .327 r
.39781 .79503 m .39616 .79586 L .39572 .79583 L F
.839 .722 .735 r
.73068 .7417 m .7289 .74457 L .73168 .7441 L F
.296 0 0 r
.46739 .77463 m .46583 .77564 L .46355 .77571 L F
.498 .058 .133 r
.46931 .77401 m .46583 .77564 L .46739 .77463 L F
.838 .714 .728 r
.66303 .61717 m .66149 .61818 L .6619 .61604 L F
.743 .512 .579 r
.66303 .61717 m .6617 .62044 L .66149 .61818 L F
.604 .599 .819 r
.66435 .61542 m .66303 .61717 L .6619 .61604 L F
.66435 .61542 m .66529 .61843 L .66303 .61717 L F
.823 .689 .716 r
.66529 .61843 m .6617 .62044 L .66303 .61717 L F
.652 .308 .377 r
.69857 .6955 m .70089 .69746 L .70081 .69393 L F
.547 .188 .31 r
.70081 .69393 m .70307 .69519 L .7037 .69383 L F
.633 .293 .377 r
.70081 .69393 m .70452 .69684 L .70307 .69519 L F
.70081 .69393 m .70089 .69746 L .70452 .69684 L F
.642 .279 .34 r
.71589 .73486 m .71777 .7359 L .71867 .7339 L F
.427 .062 .239 r
.71867 .7339 m .71777 .7359 L .72039 .73514 L F
0 0 .105 r
.62936 .60544 m .63062 .60206 L .63038 .60198 L F
.864 .979 .852 r
.63346 .63997 m .63297 .63922 L .6305 .6419 L F
.549 .237 .391 r
.52002 .78477 m .52154 .7871 L .5192 .78721 L F
.52002 .78477 m .52224 .78466 L .52154 .7871 L F
.755 .628 .719 r
.50787 .76909 m .50761 .77172 L .51136 .77158 L F
.816 .605 .617 r
.50779 .77354 m .51136 .77158 L .50761 .77172 L F
.50779 .77354 m .51095 .77419 L .51136 .77158 L F
.586 .45 .662 r
.51331 .76878 m .51136 .77158 L .5135 .77121 L F
.687 .48 .602 r
.51136 .77158 m .51422 .77367 L .5135 .77121 L F
.51136 .77158 m .51095 .77419 L .51422 .77367 L F
.606 .44 .63 r
.35363 .76633 m .35369 .76874 L .35585 .76603 L F
.896 .882 .813 r
.64524 .64236 m .64525 .64461 L .64422 .64418 L F
.645 .597 .785 r
.69773 .60105 m .70043 .59998 L .69692 .59913 L F
.559 .333 .53 r
.63092 .62604 m .63208 .62714 L .63153 .62943 L F
.449 .331 .627 r
.63208 .62714 m .63088 .63081 L .63153 .62943 L F
.318 .777 .947 r
.31671 .7164 m .31942 .71639 L .31743 .71696 L F
.472 .882 .747 r
.69279 .59659 m .69168 .59748 L .69372 .59688 L F
.279 .428 .832 r
.65111 .59529 m .65258 .59673 L .65302 .59599 L F
.438 0 0 r
.65302 .59599 m .65089 .59585 L .65111 .59529 L F
.671 .436 .555 r
.6166 .67472 m .61584 .67736 L .61332 .67722 L F
.622 .354 .491 r
.6188 .67492 m .61584 .67736 L .6166 .67472 L F
0 0 .069 r
.50925 .75034 m .50859 .75197 L .5072 .75283 L F
0 0 0 r
.50859 .75197 m .50582 .75435 L .5072 .75283 L F
.756 .515 .568 r
.33626 .7952 m .33969 .7955 L .33982 .79312 L F
.415 .213 .495 r
.33982 .79312 m .34161 .79288 L .34188 .79034 L F
.65 .53 .704 r
.33969 .7955 m .34161 .79288 L .33982 .79312 L F
.681 .24 .197 r
.34951 .81947 m .34773 .81752 L .34616 .81844 L F
.587 .114 .099 r
.34616 .81844 m .34773 .81752 L .34825 .81842 L F
.787 .426 .372 r
.343 .81637 m .34825 .81842 L .34451 .81461 L F
.501 .554 .842 r
.34773 .81752 m .34451 .81461 L .34825 .81842 L F
.626 .676 .878 r
.69698 .58834 m .6959 .59141 L .69465 .58886 L F
.69698 .58834 m .6982 .59086 L .6959 .59141 L F
.604 .563 .781 r
.69992 .59513 m .6959 .59141 L .6982 .59086 L F
.298 0 0 r
.43535 .78209 m .43616 .78323 L .43397 .78353 L F
.43535 .78209 m .4375 .78173 L .43616 .78323 L F
.735 .528 .612 r
.59875 .66742 m .59438 .66878 L .59458 .66659 L F
.59875 .66742 m .59782 .66926 L .59438 .66878 L F
.091 0 .384 r
.36773 .80629 m .36648 .80894 L .36527 .80654 L F
.36773 .80629 m .36744 .80865 L .36648 .80894 L F
.898 .955 .615 r
.366 .80816 m .36648 .80894 L .36744 .80865 L F
.366 .80816 m .3634 .81329 L .36648 .80894 L F
.909 .942 .815 r
.60074 .64268 m .59797 .6447 L .59983 .64198 L F
.60074 .64268 m .59874 .64546 L .59797 .6447 L F
.899 .931 .829 r
.60287 .6399 m .60074 .64268 L .59983 .64198 L F
.148 0 0 r
.71331 .73406 m .71493 .7343 L .71589 .73486 L F
.71331 .73406 m .71209 .73539 L .71493 .7343 L F
.297 .316 .712 r
.51839 .75116 m .51725 .75282 L .51705 .75205 L F
.51734 .75016 m .51705 .75205 L .51631 .74918 L F
.51839 .75116 m .51705 .75205 L .51734 .75016 L F
.402 .387 .729 r
.51631 .74918 m .51537 .75254 L .51406 .74987 L F
.51631 .74918 m .51725 .75282 L .51537 .75254 L F
.702 .654 .799 r
.51503 .74616 m .51631 .74918 L .51406 .74987 L F
.577 .588 .827 r
.51851 .74884 m .51631 .74918 L .51503 .74616 L F
.297 .316 .712 r
.51839 .75116 m .51631 .74918 L .51851 .74884 L F
.735 .507 .584 r
.51502 .7507 m .51746 .7494 L .517 .74797 L F
.51746 .7494 m .51851 .74884 L .51762 .74833 L F
.51746 .7494 m .51762 .74833 L .517 .74797 L F
.691 .926 .609 r
.51839 .75116 m .51773 .75196 L .51725 .75282 L F
.701 .622 .766 r
.51678 .75367 m .51537 .75254 L .51725 .75282 L F
.691 .926 .609 r
.51773 .75196 m .51627 .75372 L .51725 .75282 L F
.701 .622 .766 r
.51875 .75525 m .51678 .75367 L .51725 .75282 L F
.501 .675 .943 r
.51954 .75261 m .51875 .75525 L .51725 .75282 L F
.51954 .75261 m .52188 .7553 L .51875 .75525 L F
.425 .731 .99 r
.71758 .74275 m .71942 .74156 L .71665 .74191 L F
.71758 .74275 m .72028 .74251 L .71942 .74156 L F
.457 .544 .857 r
.71912 .74338 m .72028 .74251 L .71758 .74275 L F
.563 .776 .978 r
.37798 .81179 m .37754 .81199 L .37615 .8109 L F
.914 .955 .805 r
.59874 .64546 m .59596 .6477 L .59797 .6447 L F
.59874 .64546 m .5967 .64828 L .59596 .6477 L F
.424 0 0 r
.41345 .72473 m .41562 .72497 L .41687 .72418 L F
.482 0 .033 r
.41562 .72497 m .41882 .72442 L .41687 .72418 L F
.589 .46 .672 r
.35946 .75539 m .36176 .75509 L .36137 .7525 L F
.521 .354 .595 r
.35959 .75793 m .36176 .75509 L .35946 .75539 L F
.826 .806 .832 r
.582 .6743 m .57972 .67405 L .58171 .67207 L F
.764 .327 .213 r
.582 .6743 m .58148 .67601 L .57972 .67405 L F
.285 0 .267 r
.58456 .67207 m .582 .6743 L .58171 .67207 L F
.58456 .67207 m .58362 .67432 L .582 .6743 L F
.672 .399 .499 r
.58362 .67432 m .58148 .67601 L .582 .6743 L F
.562 .15 .218 r
.70802 .59772 m .71093 .59883 L .71117 .59718 L F
.574 .401 .61 r
.71117 .59718 m .71109 .59894 L .7136 .5968 L F
.846 .726 .73 r
.70319 .71732 m .70128 .7204 L .70462 .71996 L F
.843 .783 .793 r
.70128 .7204 m .70195 .72297 L .70462 .71996 L F
.72 .684 .814 r
.70319 .71732 m .70462 .71996 L .70643 .71762 L F
.451 .219 .47 r
.3876 .75636 m .3862 .76082 L .38482 .76103 L F
.307 .084 .402 r
.38856 .75931 m .3876 .75636 L .38933 .7556 L F
.38856 .75931 m .3862 .76082 L .3876 .75636 L F
0 0 .061 r
.6799 .58626 m .67917 .58628 L .67875 .58688 L F
0 0 0 r
.68177 .58509 m .67917 .58628 L .6799 .58626 L F
.405 .068 .278 r
.30468 .65824 m .30555 .66034 L .30654 .65766 L F
.30468 .65824 m .30353 .66083 L .30555 .66034 L F
.552 .399 .626 r
.35576 .76361 m .35792 .76567 L .35786 .76327 L F
.35576 .76361 m .35585 .76603 L .35792 .76567 L F
.151 0 .249 r
.34153 .7219 m .34073 .72048 L .34266 .7199 L F
.34153 .7219 m .34011 .72285 L .34073 .72048 L F
.804 .56 .569 r
.6162 .65526 m .6179 .65335 L .61604 .65298 L F
.6162 .65526 m .61779 .65568 L .6179 .65335 L F
.205 .675 .939 r
.3443 .8196 m .34562 .82022 L .34757 .82028 L F
.575 .138 .173 r
.47301 .77343 m .47149 .77438 L .46931 .77401 L F
.426 0 .009 r
.4749 .77366 m .47149 .77438 L .47301 .77343 L F
.581 .702 .925 r
.70162 .59449 m .70405 .59504 L .69992 .59513 L F
.69992 .59513 m .70405 .59504 L .70162 .59449 L F
.69992 .59513 m .70162 .59449 L .69934 .59677 L F
.798 .961 .916 r
.69838 .59571 m .69934 .59677 L .70162 .59449 L F
.689 .151 0 r
.3572 .68031 m .35561 .67952 L .35372 .67749 L F
.512 .832 1 r
.359 .67978 m .35561 .67952 L .3572 .68031 L F
.477 .277 .53 r
.3572 .68031 m .35889 .68208 L .359 .67978 L F
.3572 .68031 m .35697 .68258 L .35889 .68208 L F
.508 .454 .731 r
.38375 .76772 m .38199 .76909 L .38131 .76586 L F
.534 .434 .688 r
.38375 .76772 m .38224 .77147 L .38199 .76909 L F
.687 .499 .627 r
.69692 .59913 m .70043 .59998 L .70044 .597 L F
.537 .305 .511 r
.70043 .59998 m .70228 .59735 L .70044 .597 L F
.613 .37 .525 r
.60566 .67755 m .6059 .67937 L .60353 .67941 L F
.609 .367 .525 r
.60566 .67755 m .60788 .67954 L .6059 .67937 L F
.653 .356 .456 r
.60777 .67773 m .60788 .67954 L .60566 .67755 L F
.899 .931 .829 r
.60287 .6399 m .59983 .64198 L .60204 .63936 L F
.9 .96 .823 r
.60287 .6399 m .60418 .63657 L .60512 .63727 L F
.60287 .6399 m .60204 .63936 L .60418 .63657 L F
.36 0 0 r
.43506 .77349 m .43723 .77342 L .43884 .77217 L F
.211 0 0 r
.43723 .77342 m .44096 .77185 L .43884 .77217 L F
.103 0 0 r
.41376 .74313 m .41477 .74214 L .41511 .74243 L F
.41376 .74313 m .41145 .74368 L .41477 .74214 L F
.595 .583 .809 r
.4864 .73425 m .48306 .73173 L .48516 .73132 L F
.379 .425 .783 r
.72877 .61693 m .72698 .6185 L .72646 .6157 L F
.72877 .61693 m .72818 .61802 L .72698 .6185 L F
.591 .322 .477 r
.72927 .62021 m .72698 .6185 L .72818 .61802 L F
.72927 .62021 m .72691 .62053 L .72698 .6185 L F
.258 .747 .919 r
.45325 .72588 m .45531 .72573 L .45662 .72604 L F
.157 .682 .875 r
.45531 .72573 m .4587 .72601 L .45662 .72604 L F
.457 .544 .857 r
.71912 .74338 m .7211 .74538 L .72028 .74251 L F
.548 .606 .864 r
.72028 .74251 m .7211 .74538 L .72338 .74505 L F
.754 .564 .639 r
.35372 .67749 m .35032 .67741 L .3503 .67489 L F
.253 0 0 r
.35372 .67749 m .35008 .67949 L .35032 .67741 L F
.35372 .67749 m .35212 .67907 L .35008 .67949 L F
.641 .109 0 r
.35372 .67749 m .3543 .67858 L .35212 .67907 L F
.35372 .67749 m .35561 .67952 L .3543 .67858 L F
.823 .689 .716 r
.66529 .61843 m .66384 .62163 L .6617 .62044 L F
.305 0 .262 r
.32705 .71397 m .32948 .71185 L .32781 .71258 L F
.679 .132 0 r
.50652 .75983 m .506 .75887 L .50682 .75857 L F
.849 .532 .452 r
.71448 .70109 m .7176 .70369 L .71668 .70233 L F
.81 .715 .76 r
.70571 .58628 m .70691 .58925 L .70593 .58813 L F
.823 .623 .632 r
.70691 .58925 m .70389 .59115 L .70593 .58813 L F
.70691 .58925 m .70744 .59279 L .70389 .59115 L F
.777 .745 .824 r
.70794 .58554 m .70691 .58925 L .70571 .58628 L F
.70794 .58554 m .70813 .58723 L .70691 .58925 L F
.566 .353 .551 r
.62394 .67215 m .62392 .67431 L .62187 .67462 L F
.375 .154 .445 r
.62592 .67167 m .62392 .67431 L .62394 .67215 L F
.271 0 .052 r
.33792 .72342 m .33501 .72517 L .33599 .72399 L F
.515 .779 .992 r
.72357 .73533 m .722 .73661 L .72092 .73363 L F
.585 .601 .834 r
.35561 .67952 m .35697 .68258 L .35487 .68296 L F
.564 0 0 r
.35674 .6848 m .35487 .68296 L .35697 .68258 L F
.49 .314 .569 r
.35487 .68296 m .35674 .6848 L .35697 .68258 L F
.82 .719 .754 r
.70865 .71422 m .70643 .71762 L .70832 .71719 L F
.594 .148 .16 r
.62857 .63145 m .62817 .6329 L .62589 .6317 L F
.522 .173 .317 r
.63088 .63081 m .62817 .6329 L .62857 .63145 L F
.889 .614 .515 r
.70912 .69841 m .71051 .69635 L .70902 .6958 L F
.70912 .69841 m .7107 .69851 L .71051 .69635 L F
.78 .603 .66 r
.59163 .66167 m .58824 .66142 L .58971 .65863 L F
.742 .558 .645 r
.59163 .66167 m .58761 .66349 L .58824 .66142 L F
.59163 .66167 m .5912 .66396 L .58761 .66349 L F
.652 .485 .646 r
.38244 .77374 m .38006 .77173 L .38224 .77147 L F
.38244 .77374 m .38013 .77427 L .38006 .77173 L F
0 0 0 r
.72055 .71774 m .72015 .71791 L .71734 .71837 L F
.508 .298 .53 r
.72494 .71264 m .72349 .71555 L .72258 .7146 L F
.295 0 .187 r
.72398 .71563 m .72258 .7146 L .72349 .71555 L F
.72398 .71563 m .72195 .71671 L .72258 .7146 L F
0 0 0 r
.72398 .71563 m .72329 .71604 L .72195 .71671 L F
.354 .763 .982 r
.72195 .71671 m .72329 .71604 L .72307 .71605 L F
0 0 .006 r
.72258 .7146 m .72195 .71671 L .72076 .71741 L F
.354 .763 .982 r
.72195 .71671 m .72307 .71605 L .72096 .71612 L F
0 0 .006 r
.72076 .71741 m .72195 .71671 L .72055 .71774 L F
.445 .846 .652 r
.72195 .71671 m .72015 .71791 L .72055 .71774 L F
.566 .461 .694 r
.49754 .75902 m .49881 .75502 L .49667 .75577 L F
.49754 .75902 m .49997 .75835 L .49881 .75502 L F
.545 .433 .677 r
.49776 .76096 m .49997 .75835 L .49754 .75902 L F
.646 .362 .475 r
.31732 .67753 m .31938 .67955 L .31699 .67941 L F
.618 .366 .513 r
.31973 .67749 m .31938 .67955 L .31732 .67753 L F
.377 .181 .483 r
.38299 .67208 m .38276 .67448 L .38108 .67493 L F
.445 .382 .693 r
.38276 .67448 m .38322 .67681 L .38108 .67493 L F
.423 .38 .706 r
.38108 .67493 m .38322 .67681 L .38184 .67743 L F
.443 .741 .991 r
.34623 .65223 m .3456 .6534 L .3442 .6526 L F
.34623 .65223 m .34764 .65327 L .3456 .6534 L F
.603 .82 .983 r
.34895 .67395 m .34686 .67458 L .3503 .67489 L F
.639 .604 .798 r
.34686 .67458 m .35032 .67741 L .3503 .67489 L F
.445 .756 .995 r
.3503 .67489 m .35091 .67376 L .34895 .67395 L F
.501 .524 .812 r
.35032 .67741 m .35091 .67376 L .3503 .67489 L F
.916 .963 .795 r
.5967 .64828 m .59447 .65148 L .59489 .64917 L F
.928 .95 .784 r
.59596 .6477 m .5967 .64828 L .59489 .64917 L F
.317 .061 .358 r
.64737 .61092 m .6489 .61025 L .64703 .61257 L F
.515 .001 0 r
.72879 .73469 m .72859 .73455 L .72708 .73343 L F
.72879 .73469 m .72987 .73574 L .72859 .73455 L F
.537 .894 .679 r
.64983 .65286 m .64966 .65279 L .647 .6548 L F
.664 .793 .943 r
.69174 .61272 m .695 .6131 L .69412 .61187 L F
.69412 .61187 m .695 .6131 L .69174 .61272 L F
.465 .692 .966 r
.69627 .61179 m .695 .6131 L .69412 .61187 L F
.69412 .61187 m .695 .6131 L .69627 .61179 L F
.664 .793 .943 r
.69412 .61187 m .695 .6131 L .69174 .61272 L F
.787 .68 .746 r
.33241 .79865 m .33489 .79653 L .33508 .79633 L F
.641 .59 .781 r
.33508 .79633 m .33489 .79653 L .33739 .79624 L F
.665 .593 .765 r
.33489 .79653 m .33846 .79851 L .33739 .79624 L F
.634 .595 .792 r
.70356 .62858 m .70184 .63089 L .7011 .62918 L F
.70356 .62858 m .70386 .63063 L .70184 .63089 L F
.646 .479 .643 r
.499 .76854 m .50258 .76918 L .50115 .76585 L F
.716 .622 .752 r
.50115 .76585 m .50463 .76479 L .50118 .76352 L F
.686 .498 .626 r
.50115 .76585 m .50258 .76918 L .50449 .76852 L F
.576 .562 .802 r
.48735 .73077 m .4864 .73425 L .48516 .73132 L F
.48735 .73077 m .48851 .73391 L .4864 .73425 L F
.451 .19 .426 r
.63973 .59365 m .64217 .5913 L .64005 .59182 L F
.634 .8 .962 r
.33337 .80836 m .33784 .80901 L .33616 .80937 L F
.751 .398 .385 r
.33784 .80901 m .33639 .81099 L .33616 .80937 L F
.76 .411 .392 r
.33784 .80901 m .33992 .81155 L .33639 .81099 L F
.244 0 0 r
.44254 .73854 m .44121 .73835 L .43952 .73789 L F
.317 0 0 r
.44464 .738 m .44121 .73835 L .44254 .73854 L F
0 0 .061 r
.6799 .58626 m .67875 .58688 L .67791 .58565 L F
.977 .864 .66 r
.67791 .58565 m .67875 .58688 L .67718 .58776 L F
.729 .729 .851 r
.39386 .70903 m .39149 .7098 L .39367 .70757 L F
.612 .355 .503 r
.39386 .70903 m .39372 .71024 L .39149 .7098 L F
.588 .495 .716 r
.39149 .7098 m .39372 .71024 L .39367 .70757 L F
0 0 0 r
.41882 .72442 m .42098 .72412 L .42252 .72386 L F
.471 .598 .898 r
.40001 .7791 m .39909 .78158 L .39729 .78008 L F
.40001 .7791 m .4012 .78217 L .39909 .78158 L F
.462 .53 .842 r
.37183 .66572 m .37155 .66886 L .37033 .66588 L F
.37183 .66572 m .37324 .66872 L .37155 .66886 L F
.343 .707 .984 r
.68095 .58979 m .68195 .58891 L .67983 .58879 L F
.68095 .58979 m .68343 .58988 L .68195 .58891 L F
.572 .38 .582 r
.34188 .79034 m .34403 .79008 L .34413 .7877 L F
.599 .434 .629 r
.34403 .79008 m .34618 .78735 L .34413 .7877 L F
.844 .945 .585 r
.69317 .71164 m .69175 .71494 L .69326 .71396 L F
.231 .286 .714 r
.69175 .71494 m .69438 .71701 L .69326 .71396 L F
.659 .722 .895 r
.47094 .74007 m .47333 .73954 L .46993 .73881 L F
.857 .702 .689 r
.61509 .64746 m .61633 .65057 L .61686 .6483 L F
.226 0 0 r
.31333 .65508 m .3169 .65323 L .31504 .65402 L F
.766 .673 .76 r
.65505 .58582 m .65832 .58622 L .65597 .58884 L F
0 0 .538 r
.65505 .58582 m .65597 .58884 L .65574 .5869 L F
.968 .684 .268 r
.65505 .58582 m .65597 .58884 L .65537 .58857 L F
.976 .917 .604 r
.65537 .58857 m .65597 .58884 L .65574 .5869 L F
.65574 .5869 m .65597 .58884 L .65537 .58857 L F
.818 .98 .694 r
.63947 .6203 m .64079 .61896 L .64175 .61748 L F
.282 0 .1 r
.37742 .80323 m .38049 .80071 L .37847 .80303 L F
.252 0 0 r
.37847 .80303 m .38049 .80071 L .38265 .80015 L F
.669 .58 .746 r
.49345 .75502 m .49548 .75241 L .49329 .75305 L F
.49345 .75502 m .49667 .75577 L .49548 .75241 L F
.9 .984 .787 r
.62267 .63323 m .62232 .63509 L .62407 .63281 L F
.241 0 0 r
.62589 .6317 m .62267 .63323 L .62407 .63281 L F
.911 .907 .806 r
.60908 .6316 m .60617 .63371 L .60848 .63112 L F
.60908 .6316 m .60715 .63448 L .60617 .63371 L F
.872 .99 .823 r
.60908 .6316 m .61071 .62853 L .61117 .62867 L F
.60908 .6316 m .60848 .63112 L .61071 .62853 L F
.64 .801 .96 r
.65692 .5849 m .65832 .58622 L .65505 .58582 L F
.533 .758 .98 r
.66038 .58584 m .65832 .58622 L .65692 .5849 L F
.583 .098 .069 r
.34256 .67385 m .33803 .67408 L .33875 .67346 L F
.642 .198 .182 r
.34256 .67385 m .33969 .67541 L .33803 .67408 L F
.423 .825 .617 r
.64254 .65785 m .63931 .65998 L .64056 .65863 L F
.477 .832 .996 r
.39949 .74942 m .40278 .74963 L .40164 .74925 L F
.578 .167 .226 r
.40572 .74782 m .40164 .74925 L .40278 .74963 L F
.901 .966 .817 r
.59447 .65148 m .59255 .65396 L .59288 .65195 L F
.91 .959 .809 r
.59489 .64917 m .59447 .65148 L .59288 .65195 L F
.647 .197 .17 r
.49588 .77675 m .49456 .77784 L .49258 .77658 L F
0 .509 .71 r
.4981 .77828 m .49456 .77784 L .49588 .77675 L F
.56 .444 .677 r
.38305 .76367 m .38333 .76569 L .38131 .76586 L F
.508 .454 .731 r
.38375 .76772 m .38131 .76586 L .38333 .76569 L F
.685 .613 .77 r
.50118 .76352 m .50463 .76479 L .50345 .76155 L F
.648 .593 .779 r
.50345 .76155 m .50463 .76479 L .50653 .76376 L F
.096 .414 .863 r
.52174 .75382 m .52188 .7553 L .51954 .75261 L F
.489 .874 .972 r
.52188 .7553 m .52225 .75465 L .52032 .7559 L F
.584 .491 .715 r
.52421 .75745 m .52032 .7559 L .52225 .75465 L F
.52421 .75745 m .52199 .75791 L .52032 .7559 L F
.398 .305 .633 r
.33846 .79851 m .33969 .7955 L .33739 .79624 L F
.33846 .79851 m .33998 .79817 L .33969 .7955 L F
.217 .323 .759 r
.72696 .61212 m .72736 .61363 L .72519 .61271 L F
.72736 .61363 m .72775 .61512 L .72628 .61374 L F
.72736 .61363 m .72628 .61374 L .72519 .61271 L F
.348 .35 .72 r
.72519 .61271 m .72775 .61512 L .72646 .6157 L F
0 0 .319 r
.72739 .61364 m .72736 .61363 L .72696 .61212 L F
.653 .573 .753 r
.72696 .61212 m .72473 .61405 L .72739 .61364 L F
.72696 .61212 m .72739 .61364 L .72776 .61358 L F
0 0 .319 r
.72748 .61367 m .72739 .61364 L .72696 .61212 L F
.72743 .61345 m .72748 .61367 L .72696 .61212 L F
.009 .218 .728 r
.72953 .6151 m .72776 .61358 L .72744 .61365 L F
0 0 .319 r
.72744 .61365 m .72775 .61512 L .72736 .61363 L F
.7275 .61377 m .72775 .61512 L .72744 .61365 L F
.009 .218 .728 r
.72788 .6145 m .72744 .61365 L .72626 .61391 L F
0 .197 .718 r
.72759 .61384 m .72941 .61612 L .72877 .61693 L F
.093 0 .121 r
.7274 .61364 m .72744 .61365 L .72769 .6136 L F
0 .197 .718 r
.72743 .61345 m .72786 .61403 L .72759 .61384 L F
.72786 .61403 m .72941 .61612 L .72759 .61384 L F
.009 .218 .728 r
.72953 .6151 m .72744 .61365 L .72751 .61379 L F
.72953 .6151 m .72941 .61612 L .72786 .61403 L F
.72953 .6151 m .72786 .61403 L .72743 .61345 L F
.7294 .61505 m .72786 .61403 L .72788 .6145 L F
.72786 .61403 m .72751 .61379 L .72752 .61381 L F
.72786 .61403 m .72752 .61381 L .72788 .6145 L F
.72953 .6151 m .72751 .61379 L .7294 .61505 L F
0 0 .319 r
.72748 .61367 m .7275 .61377 L .72744 .61365 L F
.093 0 .121 r
.72473 .61405 m .72626 .61391 L .72744 .61365 L F
.72473 .61405 m .72744 .61365 L .7274 .61364 L F
.72761 .61361 m .72769 .6136 L .72776 .61358 L F
0 .197 .718 r
.72748 .61367 m .72877 .61693 L .72775 .61512 L F
.72743 .61345 m .72752 .61367 L .72748 .61367 L F
.72752 .61367 m .72877 .61693 L .72748 .61367 L F
.093 0 .121 r
.72723 .61367 m .72769 .6136 L .72761 .61361 L F
.72473 .61405 m .72725 .61367 L .72723 .61367 L F
.72725 .61367 m .72769 .6136 L .72723 .61367 L F
.217 .323 .759 r
.72696 .61212 m .72519 .61271 L .72473 .61405 L F
.86 .819 .807 r
.58971 .65863 m .58739 .65832 L .58827 .65748 L F
.888 .752 .707 r
.58971 .65863 m .58673 .66053 L .58739 .65832 L F
.58971 .65863 m .58824 .66142 L .58673 .66053 L F
.878 .814 .782 r
.59057 .65655 m .58971 .65863 L .58827 .65748 L F
0 .161 .697 r
.66816 .60098 m .66785 .60205 L .668 .60121 L F
.66816 .60098 m .66967 .60405 L .66785 .60205 L F
.21 .519 .916 r
.34918 .80458 m .35103 .80647 L .35173 .80561 L F
.031 .248 .749 r
.35103 .80647 m .35294 .80835 L .35173 .80561 L F
.531 .485 .751 r
.70065 .59042 m .69992 .59513 L .6982 .59086 L F
.70065 .59042 m .70162 .59449 L .69992 .59513 L F
.622 .354 .491 r
.6188 .67492 m .61882 .67692 L .61584 .67736 L F
.661 .399 .512 r
.62187 .67462 m .61882 .67692 L .6188 .67492 L F
0 0 0 r
.33348 .726 m .33211 .72794 L .33076 .72838 L F
.391 .064 .286 r
.33501 .72517 m .33211 .72794 L .33348 .726 L F
.717 .612 .739 r
.48891 .74711 m .4925 .75002 L .491 .74672 L F
.48891 .74711 m .48968 .75037 L .4925 .75002 L F
.593 .576 .804 r
.4925 .75002 m .49347 .74637 L .491 .74672 L F
.4925 .75002 m .49466 .74974 L .49347 .74637 L F
.684 .588 .743 r
.49329 .75305 m .49466 .74974 L .4925 .75002 L F
.545 .433 .677 r
.49776 .76096 m .5 .76065 L .49997 .75835 L F
.673 .58 .743 r
.49776 .76096 m .50118 .76352 L .5 .76065 L F
.537 .305 .511 r
.70043 .59998 m .70184 .60007 L .70228 .59735 L F
.232 .043 .406 r
.70228 .59735 m .70398 .59857 L .7043 .59706 L F
.70228 .59735 m .70184 .60007 L .70398 .59857 L F
.698 .913 .969 r
.70015 .64371 m .70421 .64262 L .70344 .64188 L F
.906 .943 .82 r
.70344 .64188 m .70421 .64262 L .70623 .63983 L F
.64 .079 0 r
.72071 .70646 m .72318 .70834 L .72355 .70777 L F
.647 .089 0 r
.72318 .70834 m .72577 .70953 L .72355 .70777 L F
.91 .926 .813 r
.59255 .65396 m .59057 .65655 L .59053 .65479 L F
.888 .958 .84 r
.59288 .65195 m .59255 .65396 L .59053 .65479 L F
.755 .63 .722 r
.49616 .8817 m .49299 .88194 L .49356 .87943 L F
.055 0 0 r
.49616 .8817 m .49497 .88189 L .49299 .88194 L F
.212 .564 .937 r
.49616 .8817 m .49711 .88104 L .49497 .88189 L F
.49616 .8817 m .49853 .88231 L .49711 .88104 L F
.981 .699 .328 r
.51199 .7528 m .51291 .75564 L .51193 .75463 L F
.948 .613 .199 r
.51291 .75564 m .51326 .75717 L .51193 .75463 L F
.737 .65 .763 r
.51537 .75254 m .51291 .75564 L .51199 .7528 L F
.911 .923 .811 r
.60512 .63727 m .60617 .63371 L .60715 .63448 L F
.60512 .63727 m .60418 .63657 L .60617 .63371 L F
.041 .37 .838 r
.5103 .74734 m .50914 .74708 L .50735 .74477 L F
0 .437 .835 r
.51037 .74741 m .50914 .74708 L .5103 .74734 L F
.607 .559 .774 r
.51037 .74741 m .50925 .75034 L .50914 .74708 L F
.537 .317 .527 r
.34188 .79034 m .34363 .79242 L .34403 .79008 L F
.34188 .79034 m .34161 .79288 L .34363 .79242 L F
.585 .547 .779 r
.71516 .71871 m .71717 .71583 L .71444 .71761 L F
.71516 .71871 m .71734 .71837 L .71717 .71583 L F
.335 .695 .981 r
.33702 .65046 m .33653 .65141 L .3351 .65046 L F
.33702 .65046 m .33906 .65158 L .33653 .65141 L F
.585 .358 .538 r
.38425 .6641 m .38412 .66625 L .38666 .66404 L F
.38425 .6641 m .38412 .66625 L .38666 .66404 L F
.641 .59 .781 r
.33508 .79633 m .33739 .79624 L .33626 .7952 L F
.467 0 .009 r
.32708 .67586 m .3235 .67652 L .32488 .67541 L F
.822 .988 .721 r
.61324 .62601 m .61117 .62867 L .61071 .62853 L F
.582 .492 .718 r
.69349 .63419 m .69077 .63622 L .69117 .63466 L F
0 0 .105 r
.62936 .60544 m .63029 .60384 L .63062 .60206 L F
0 0 .32 r
.63027 .60612 m .62936 .60544 L .62828 .60705 L F
.63027 .60612 m .63029 .60384 L .62936 .60544 L F
.587 .444 .654 r
.3517 .77148 m .35383 .77118 L .35369 .76874 L F
.546 .417 .656 r
.3517 .77148 m .35391 .77357 L .35383 .77118 L F
.3517 .77148 m .35198 .77401 L .35391 .77357 L F
.724 .676 .802 r
.49881 .75502 m .50215 .75543 L .5009 .75256 L F
.662 .515 .673 r
.49881 .75502 m .50226 .75804 L .50215 .75543 L F
.497 .481 .769 r
.50215 .75543 m .50312 .75199 L .5009 .75256 L F
.50215 .75543 m .50428 .75593 L .50312 .75199 L F
.554 .344 .55 r
.50215 .75543 m .50226 .75804 L .50428 .75593 L F
.476 .679 .954 r
.69244 .5889 m .68846 .58724 L .6923 .58821 L F
.554 .704 .94 r
.69394 .58737 m .69244 .5889 L .6923 .58821 L F
.475 .573 .873 r
.69465 .58886 m .69244 .5889 L .69394 .58737 L F
.608 .508 .714 r
.39588 .70664 m .39386 .70903 L .39367 .70757 L F
.39588 .70664 m .39599 .70905 L .39386 .70903 L F
0 0 .253 r
.39493 .70855 m .39386 .70903 L .39599 .70905 L F
.39493 .70855 m .39372 .71024 L .39386 .70903 L F
.582 .492 .718 r
.69349 .63419 m .69254 .63778 L .69077 .63622 L F
.392 .133 .397 r
.36032 .70062 m .35844 .70417 L .35667 .70466 L F
.465 .21 .443 r
.36051 .70367 m .36032 .70062 L .361 .70157 L F
.36051 .70367 m .35844 .70417 L .36032 .70062 L F
0 0 .002 r
.34992 .68277 m .35008 .67949 L .35151 .68135 L F
.34992 .68277 m .35 .68206 L .35008 .67949 L F
0 0 .513 r
.34992 .68277 m .35107 .68469 L .35 .68206 L F
.714 .667 .803 r
.5 .76065 m .50118 .76352 L .50345 .76155 L F
.392 .029 .224 r
.29935 .662 m .30152 .66129 L .29968 .6614 L F
.827 .696 .719 r
.66309 .62313 m .65991 .623 L .6617 .62044 L F
.66309 .62313 m .66146 .62431 L .65991 .623 L F
.785 .714 .786 r
.66384 .62163 m .66309 .62313 L .6617 .62044 L F
.454 .025 .134 r
.44314 .77989 m .44186 .78161 L .4396 .78166 L F
.172 0 0 r
.4438 .78089 m .44314 .77989 L .44514 .7792 L F
.4438 .78089 m .44186 .78161 L .44314 .77989 L F
.99 .844 .477 r
.66904 .61447 m .67006 .61292 L .66968 .61242 L F
.694 .503 .624 r
.59497 .66429 m .59093 .66627 L .5912 .66396 L F
.59497 .66429 m .59458 .66659 L .59093 .66627 L F
.669 .502 .65 r
.52007 .76066 m .51756 .76409 L .5176 .76106 L F
.655 .311 .377 r
.68433 .62563 m .68324 .62659 L .68322 .62806 L F
.733 .233 .043 r
.68553 .6277 m .68433 .62563 L .68322 .62806 L F
.68553 .6277 m .68639 .62683 L .68433 .62563 L F
.634 .629 .828 r
.49531 .73896 m .49307 .73942 L .49184 .73628 L F
.713 .485 .578 r
.49687 .76843 m .4991 .77156 L .499 .76854 L F
.718 .489 .577 r
.499 .76854 m .5023 .77115 L .50258 .76918 L F
.499 .76854 m .4991 .77156 L .5023 .77115 L F
.582 .492 .718 r
.69349 .63419 m .69386 .63762 L .69254 .63778 L F
.827 .351 .003 r
.72779 .71152 m .72687 .70996 L .72577 .70953 L F
.31 0 0 r
.32353 .71596 m .32705 .71397 L .32525 .71457 L F
.425 .25 .539 r
.36799 .74446 m .36978 .74168 L .36766 .74202 L F
.648 .814 .963 r
.48256 .72768 m .47853 .72742 L .48091 .72659 L F
.358 .557 .909 r
.48321 .72586 m .48256 .72768 L .48091 .72659 L F
.48321 .72586 m .48413 .72777 L .48256 .72768 L F
.396 .769 .992 r
.6762 .59126 m .67737 .59028 L .675 .59049 L F
.6762 .59126 m .67838 .59102 L .67737 .59028 L F
.988 .741 .465 r
.52845 .84985 m .5288 .85214 L .52783 .84956 L F
.782 .947 .929 r
.52783 .84956 m .52845 .84985 L .52954 .84825 L F
.52783 .84956 m .52845 .84985 L .52954 .84825 L F
.988 .741 .465 r
.52845 .84985 m .5288 .85214 L .52783 .84956 L F
.641 .663 .856 r
.37532 .66822 m .37467 .67175 L .37324 .66872 L F
.37532 .66822 m .37689 .67117 L .37467 .67175 L F
.637 .625 .822 r
.37689 .67117 m .37779 .6726 L .37467 .67175 L F
.817 .714 .752 r
.58456 .67207 m .58171 .67207 L .58359 .66906 L F
.395 .461 .81 r
.58559 .67116 m .58456 .67207 L .58359 .66906 L F
.647 .483 .647 r
.58559 .67116 m .58362 .67432 L .58456 .67207 L F
.906 .943 .82 r
.70344 .64188 m .70623 .63983 L .70574 .63949 L F
.742 .99 .881 r
.70729 .63817 m .70623 .63983 L .70908 .63766 L F
.70729 .63817 m .70574 .63949 L .70623 .63983 L F
.296 .783 .721 r
.4309 .74072 m .43012 .74093 L .42898 .74143 L F
0 0 0 r
.43012 .74093 m .42836 .742 L .42898 .74143 L F
.772 .672 .752 r
.37956 .67104 m .37856 .66994 L .38003 .67009 L F
.328 0 0 r
.37856 .66994 m .38201 .66911 L .38003 .67009 L F
.435 .871 .799 r
.31091 .71906 m .31448 .7177 L .31366 .7178 L F
.44 .751 .994 r
.32858 .64869 m .3281 .64985 L .32642 .64755 L F
.32858 .64869 m .33011 .6497 L .3281 .64985 L F
0 .305 .758 r
.68485 .64183 m .68393 .64089 L .68334 .63948 L F
.68485 .64183 m .68597 .64236 L .68393 .64089 L F
.578 .167 .226 r
.40572 .74782 m .40405 .74948 L .40164 .74925 L F
.255 0 0 r
.40627 .74894 m .40572 .74782 L .40685 .74664 L F
.40627 .74894 m .40405 .74948 L .40572 .74782 L F
.392 .799 .981 r
.42461 .72367 m .42663 .72337 L .42795 .72393 L F
.004 .567 .8 r
.42663 .72337 m .43023 .72398 L .42795 .72393 L F
.614 .532 .739 r
.72942 .72013 m .72891 .71894 L .72625 .72018 L F
0 .256 .767 r
.72942 .72013 m .73063 .72017 L .72891 .71894 L F
.939 .662 .487 r
.73254 .72072 m .73063 .72017 L .72942 .72013 L F
.403 .157 .424 r
.3652 .69561 m .36508 .69832 L .36266 .69875 L F
.502 .285 .517 r
.36664 .69475 m .36508 .69832 L .3652 .69561 L F
.418 .154 .404 r
.4093 .74414 m .40685 .74664 L .40771 .74502 L F
.667 .674 .847 r
.69757 .72536 m .69943 .72571 L .69892 .725 L F
.982 .89 .544 r
.69939 .72306 m .69943 .72571 L .70195 .72297 L F
.69939 .72306 m .69892 .725 L .69943 .72571 L F
.475 .6 .898 r
.38723 .77908 m .38359 .77679 L .38588 .77622 L F
.542 .526 .788 r
.38806 .77582 m .38723 .77908 L .38588 .77622 L F
.38806 .77582 m .38975 .7797 L .38723 .77908 L F
.54 .045 .029 r
.65429 .60749 m .6582 .60752 L .65653 .60745 L F
.789 .353 .214 r
.65653 .60745 m .6582 .60752 L .65904 .60931 L F
.637 .721 .908 r
.50196 .74197 m .49869 .74115 L .50084 .74071 L F
.515 .702 .955 r
.50294 .74082 m .50196 .74197 L .50084 .74071 L F
.398 .523 .867 r
.50294 .74082 m .50405 .74226 L .50196 .74197 L F
0 0 .101 r
.73553 .72746 m .73418 .72862 L .73454 .72776 L F
0 0 .26 r
.73598 .72511 m .73454 .72776 L .73665 .72588 L F
.73598 .72511 m .73553 .72746 L .73454 .72776 L F
.65 .728 .906 r
.47644 .72785 m .4733 .72709 L .47536 .72674 L F
.58 .761 .965 r
.47853 .72742 m .47644 .72785 L .47536 .72674 L F
.753 .648 .745 r
.63706 .64484 m .6382 .64793 L .63493 .64763 L F
.759 .545 .607 r
.63493 .64763 m .6382 .64793 L .63818 .65043 L F
.599 .541 .76 r
.6395 .64439 m .6382 .64793 L .63706 .64484 L F
.6395 .64439 m .64049 .64755 L .6382 .64793 L F
.568 .389 .599 r
.6382 .64793 m .64049 .64755 L .63818 .65043 L F
.739 .568 .661 r
.50449 .76852 m .50787 .76909 L .50778 .76638 L F
.626 .577 .779 r
.50778 .76638 m .50879 .76317 L .50653 .76376 L F
.50778 .76638 m .5099 .76639 L .50879 .76317 L F
.63 .481 .662 r
.50778 .76638 m .50787 .76909 L .5099 .76639 L F
.166 .7 .839 r
.40534 .781 m .40429 .78124 L .40311 .7813 L F
.40534 .781 m .40619 .78112 L .40429 .78124 L F
.774 .627 .698 r
.3761 .80709 m .37698 .8101 L .37497 .808 L F
.883 .577 .465 r
.37684 .81024 m .37698 .8101 L .37497 .808 L F
0 .05 .597 r
.3761 .80709 m .37698 .8101 L .37699 .80994 L F
.763 .607 .685 r
.37699 .80994 m .37783 .81141 L .37722 .81068 L F
.3761 .80709 m .37713 .80965 L .37699 .80994 L F
.37713 .80965 m .37783 .81141 L .37699 .80994 L F
.681 .568 .721 r
.37863 .80903 m .37798 .81179 L .3761 .80709 L F
.37863 .80903 m .3761 .80709 L .37815 .80685 L F
0 .05 .597 r
.3761 .80709 m .37699 .80994 L .37707 .80753 L F
.952 .952 .67 r
.37699 .80994 m .37698 .8101 L .37684 .81024 L F
.763 .607 .685 r
.3761 .80709 m .37722 .81068 L .37497 .808 L F
.37783 .81141 m .37798 .81179 L .37497 .808 L F
.892 .579 .45 r
.37497 .808 m .37798 .81179 L .37615 .8109 L F
.883 .577 .465 r
.37615 .8109 m .37684 .81024 L .37497 .808 L F
.952 .952 .67 r
.37707 .80753 m .37699 .80994 L .37615 .8109 L F
.37699 .80994 m .37684 .81024 L .37615 .8109 L F
0 .227 .747 r
.66262 .58781 m .6624 .58864 L .66038 .58584 L F
0 .164 .704 r
.66262 .58781 m .66411 .59038 L .6624 .58864 L F
.651 .612 .798 r
.38359 .77679 m .38013 .77427 L .38244 .77374 L F
.634 .583 .78 r
.38588 .77622 m .38359 .77679 L .38244 .77374 L F
0 0 .34 r
.38407 .66869 m .38299 .67208 L .38201 .66911 L F
.38407 .66869 m .38398 .67098 L .383 .67205 L F
.436 0 0 r
.38146 .66981 m .38398 .67098 L .38407 .66869 L F
.577 .379 .575 r
.38617 .67045 m .38398 .67098 L .38407 .66869 L F
.38617 .67045 m .38398 .67098 L .38407 .66869 L F
.195 .72 .855 r
.38249 .67046 m .38447 .67045 L .38398 .67098 L F
.38447 .67045 m .38617 .67045 L .38398 .67098 L F
0 0 .34 r
.383 .67205 m .38398 .67098 L .38299 .67208 L F
.545 .493 .749 r
.38398 .67098 m .38276 .67448 L .38299 .67208 L F
.633 .264 .327 r
.70659 .60015 m .70734 .59767 L .70619 .60022 L F
.44 .015 .135 r
.70824 .59956 m .70659 .60015 L .70619 .60022 L F
.619 .947 .94 r
.70676 .60008 m .70671 .60011 L .70824 .59956 L F
.70671 .60011 m .70409 .60164 L .70824 .59956 L F
.812 .994 .759 r
.70944 .59949 m .70874 .60164 L .71109 .59894 L F
.042 .208 .71 r
.70938 .60147 m .70874 .60164 L .70944 .59949 L F
.52 .868 .99 r
.70409 .60164 m .70938 .60147 L .70824 .59956 L F
.792 .881 .911 r
.70824 .59956 m .70938 .60147 L .70944 .59949 L F
.44 .015 .135 r
.70824 .59956 m .71044 .59951 L .70659 .60015 L F
.792 .881 .911 r
.70824 .59956 m .70944 .59949 L .71044 .59951 L F
.633 .264 .327 r
.71044 .59951 m .70948 .59894 L .70659 .60015 L F
.70948 .59894 m .70734 .59767 L .70659 .60015 L F
.619 .947 .94 r
.70338 .60128 m .70361 .60139 L .70676 .60008 L F
.70361 .60139 m .70409 .60164 L .70676 .60008 L F
.017 .471 .874 r
.70165 .60029 m .70409 .60164 L .70302 .6014 L F
.619 .947 .94 r
.70302 .6014 m .70409 .60164 L .70338 .60128 L F
0 .418 .745 r
.70278 .60124 m .70496 .60208 L .70409 .60164 L F
.70496 .60208 m .70603 .60248 L .70409 .60164 L F
.705 .872 .96 r
.70603 .60248 m .70874 .60164 L .70938 .60147 L F
.52 .868 .99 r
.70409 .60164 m .70603 .60248 L .70938 .60147 L F
.931 .591 .148 r
.50031 .87875 m .50156 .88161 L .50075 .87942 L F
.675 .948 .958 r
.50156 .88161 m .50061 .88125 L .49853 .88231 L F
.979 .686 .371 r
.50031 .87875 m .50061 .88125 L .50156 .88161 L F
.668 .362 .446 r
.49345 .76885 m .49551 .77092 L .49687 .76843 L F
.775 .491 .505 r
.49551 .77092 m .4991 .77156 L .49687 .76843 L F
.459 0 0 r
.33337 .80836 m .33616 .80937 L .33303 .80859 L F
.333 0 .075 r
.31886 .65259 m .32089 .65219 L .32237 .65029 L F
.416 .029 .195 r
.32089 .65219 m .32431 .64965 L .32237 .65029 L F
.675 .424 .534 r
.60353 .67941 m .60001 .68206 L .60022 .6806 L F
.822 .988 .721 r
.61324 .62601 m .61071 .62853 L .61293 .62581 L F
.582 .864 .539 r
.61446 .62452 m .61324 .62601 L .61293 .62581 L F
.61446 .62452 m .61563 .6234 L .61324 .62601 L F
.744 .666 .773 r
.73418 .72862 m .73197 .73091 L .73073 .72808 L F
0 0 0 r
.73406 .72875 m .7336 .73016 L .73197 .73091 L F
.984 .901 .642 r
.73357 .72863 m .73335 .73091 L .7336 .73016 L F
.245 .327 .75 r
.7336 .73016 m .73438 .73315 L .73197 .73091 L F
.984 .901 .642 r
.73335 .73091 m .7332 .73241 L .7336 .73016 L F
0 0 0 r
.73418 .72862 m .7336 .73016 L .73406 .72875 L F
.358 .746 .987 r
.69888 .64356 m .69972 .64277 L .69756 .64225 L F
.69888 .64356 m .70052 .64351 L .69972 .64277 L F
.157 .65 .917 r
.69888 .64356 m .70015 .64371 L .70052 .64351 L F
.373 .076 .326 r
.33985 .70446 m .33918 .70624 L .34172 .70389 L F
.772 .672 .752 r
.37956 .67104 m .37689 .67117 L .37856 .66994 L F
.37956 .67104 m .37779 .6726 L .37689 .67117 L F
.668 .422 .54 r
.61197 .67706 m .60788 .67954 L .60777 .67773 L F
.403 0 .073 r
.44488 .77058 m .44846 .76876 L .44631 .76912 L F
.322 .729 .979 r
.69757 .72536 m .69787 .72434 L .69542 .72246 L F
.69757 .72536 m .69892 .725 L .69787 .72434 L F
.636 .236 .27 r
.33542 .82769 m .33663 .82771 L .33582 .8272 L F
.328 0 .107 r
.63465 .59665 m .637 .5961 L .63774 .59452 L F
.243 0 .099 r
.637 .5961 m .63973 .59365 L .63774 .59452 L F
.561 .849 .997 r
.63556 .61051 m .63679 .60918 L .63779 .6099 L F
.63556 .61051 m .63679 .60918 L .63779 .6099 L F
.607 .044 0 r
.64675 .62078 m .64492 .62009 L .64175 .61748 L F
.969 .869 .683 r
.64494 .62258 m .64675 .62078 L .64404 .62359 L F
.64494 .62258 m .64492 .62009 L .64675 .62078 L F
.91 .979 .707 r
.62124 .63679 m .62232 .63509 L .62267 .63323 L F
.155 .587 .933 r
.6881 .64431 m .68906 .64387 L .68597 .64236 L F
.6881 .64431 m .69002 .64471 L .68906 .64387 L F
.773 .297 .107 r
.51373 .78657 m .51018 .78424 L .51146 .78465 L F
.855 .789 .785 r
.69939 .72306 m .70195 .72297 L .70128 .7204 L F
.118 0 .111 r
.52435 .78434 m .52523 .7828 L .5268 .7819 L F
0 .521 .744 r
.49095 .88272 m .48972 .88247 L .48701 .8821 L F
.238 0 0 r
.49299 .88194 m .48972 .88247 L .49095 .88272 L F
.518 .408 .668 r
.37254 .73916 m .37414 .73627 L .37199 .73654 L F
.876 .767 .738 r
.6604 .6131 m .65774 .61279 L .65904 .60931 L F
.785 .554 .586 r
.6604 .6131 m .65772 .61464 L .65774 .61279 L F
.6604 .6131 m .66049 .61526 L .65772 .61464 L F
.574 .554 .795 r
.49069 .73352 m .48954 .7368 L .48851 .73391 L F
.49069 .73352 m .49184 .73628 L .48954 .7368 L F
.598 .208 .275 r
.52239 .77446 m .52296 .77362 L .51999 .774 L F
.361 0 0 r
.52482 .77404 m .52296 .77362 L .52239 .77446 L F
.52482 .77404 m .52486 .77347 L .52296 .77362 L F
.454 .243 .502 r
.38184 .67743 m .3815 .68021 L .37937 .68068 L F
.311 .123 .456 r
.38298 .67907 m .38184 .67743 L .38322 .67681 L F
.38298 .67907 m .3815 .68021 L .38184 .67743 L F
.581 .407 .61 r
.34617 .78494 m .34618 .78735 L .34834 .78463 L F
.643 .669 .86 r
.46653 .73681 m .46784 .73952 L .46993 .73881 L F
.441 .248 .521 r
.35443 .707 m .35427 .70949 L .35234 .71005 L F
.345 .059 .327 r
.35336 .71123 m .35234 .71005 L .35427 .70949 L F
.35336 .71123 m .35168 .71186 L .35234 .71005 L F
.28 .052 .378 r
.5291 .7792 m .52961 .77714 L .53113 .77645 L F
.661 .399 .512 r
.62187 .67462 m .62109 .67705 L .61882 .67692 L F
.414 .112 .341 r
.62392 .67431 m .62109 .67705 L .62187 .67462 L F
.45 .056 .198 r
.3947 .7303 m .39687 .7301 L .39812 .72809 L F
.517 .164 .307 r
.39687 .7301 m .40024 .72774 L .39812 .72809 L F
.981 .802 .588 r
.65729 .64078 m .65999 .63776 L .65928 .63806 L F
.65729 .64078 m .65851 .64192 L .65999 .63776 L F
.997 .858 .561 r
.65999 .63776 m .65927 .64254 L .66098 .64024 L F
.65999 .63776 m .65851 .64192 L .65927 .64254 L F
.529 .415 .668 r
.65999 .63776 m .66316 .63977 L .66265 .63818 L F
.65999 .63776 m .66098 .64024 L .66316 .63977 L F
.452 0 0 r
.4783 .7738 m .47682 .77409 L .4749 .77366 L F
.557 .034 0 r
.48024 .77431 m .47682 .77409 L .4783 .7738 L F
.645 .802 .958 r
.47539 .73864 m .47892 .73901 L .47738 .73683 L F
.489 .563 .858 r
.47892 .73901 m .4797 .73632 L .47738 .73683 L F
.47892 .73901 m .4809 .73886 L .4797 .73632 L F
.606 .495 .701 r
.34807 .78002 m .35052 .7819 L .34979 .77941 L F
.34807 .78002 m .34832 .78222 L .35052 .7819 L F
.845 .737 .744 r
.37615 .8109 m .37798 .81179 L .37863 .80903 L F
.657 .626 .807 r
.5099 .76639 m .51331 .76878 L .51215 .76577 L F
.605 .947 .924 r
.72713 .73102 m .72743 .73017 L .72772 .73082 L F
.847 .977 .674 r
.72772 .73082 m .7294 .72741 L .73073 .72808 L F
.72772 .73082 m .72743 .73017 L .7294 .72741 L F
.353 .01 .237 r
.3815 .68021 m .37864 .68211 L .37937 .68068 L F
.553 .487 .735 r
.37742 .80323 m .3761 .80709 L .37571 .80381 L F
.611 .828 .983 r
.73204 .73558 m .73301 .73648 L .73475 .73601 L F
.829 .735 .761 r
.66906 .63912 m .67216 .63929 L .67116 .63636 L F
.719 .679 .811 r
.67116 .63636 m .67216 .63929 L .67352 .63619 L F
.746 .699 .807 r
.70036 .70508 m .69866 .70681 L .7017 .70642 L F
.694 .416 .498 r
.69866 .70681 m .70089 .70892 L .7017 .70642 L F
.008 .555 .832 r
.7017 .70642 m .70366 .70664 L .70036 .70508 L F
.7017 .70642 m .70412 .70695 L .70366 .70664 L F
.338 .069 .351 r
.7017 .70642 m .70366 .70664 L .70412 .70695 L F
.7017 .70642 m .70089 .70892 L .70366 .70664 L F
0 0 0 r
.33211 .72794 m .32954 .72993 L .33076 .72838 L F
.318 .735 .976 r
.4587 .72601 m .46075 .72599 L .46202 .72665 L F
.479 .819 .999 r
.46282 .72559 m .46202 .72665 L .46075 .72599 L F
.46282 .72559 m .46416 .72626 L .46202 .72665 L F
.878 .814 .782 r
.59057 .65655 m .58827 .65748 L .59053 .65479 L F
0 0 .442 r
.65258 .59673 m .65338 .59885 L .65302 .59599 L F
.623 .396 .553 r
.66961 .61548 m .6703 .61705 L .67309 .61565 L F
.973 .838 .43 r
.67309 .61565 m .67264 .61498 L .67302 .61255 L F
.811 .982 .892 r
.67309 .61565 m .6703 .61705 L .67264 .61498 L F
.165 0 0 r
.7043 .59706 m .70734 .59767 L .70802 .59772 L F
0 .422 .81 r
.70918 .59781 m .71093 .59883 L .70802 .59772 L F
.70918 .59781 m .70802 .59772 L .70734 .59767 L F
.477 .141 .317 r
.33605 .70875 m .33918 .70624 L .33752 .70703 L F
.268 .331 .744 r
.48428 .87895 m .48483 .87582 L .4833 .87556 L F
.48428 .87895 m .48571 .87925 L .48483 .87582 L F
.175 .431 .865 r
.48428 .87895 m .48724 .88081 L .48571 .87925 L F
.558 .628 .877 r
.48486 .88081 m .48724 .88081 L .48428 .87895 L F
.492 .309 .561 r
.35756 .76101 m .35977 .76056 L .35959 .75793 L F
.423 .279 .58 r
.35786 .76327 m .35977 .76056 L .35756 .76101 L F
.397 .711 .986 r
.35165 .65277 m .35102 .65384 L .34963 .65285 L F
.35165 .65277 m .35287 .6539 L .35102 .65384 L F
.333 .657 .971 r
.44327 .72378 m .4424 .72459 L .44108 .72369 L F
.44327 .72378 m .44446 .72488 L .4424 .72459 L F
.847 .553 .491 r
.67833 .61223 m .68125 .61517 L .68036 .61326 L F
.937 .566 .246 r
.68687 .62888 m .68639 .62683 L .68553 .6277 L F
.717 .649 .781 r
.63262 .62095 m .63535 .62092 L .63431 .61901 L F
.544 .571 .832 r
.63535 .62092 m .63702 .62017 L .63431 .61901 L F
.175 0 .088 r
.38966 .79793 m .38947 .79818 L .38785 .79824 L F
.13 0 0 r
.38785 .79824 m .38909 .79863 L .38686 .79933 L F
.38785 .79824 m .38947 .79818 L .38909 .79863 L F
.578 .563 .801 r
.73325 .72364 m .73287 .72546 L .73307 .7239 L F
.898 .834 .775 r
.73287 .72546 m .7294 .72741 L .73307 .7239 L F
.73287 .72546 m .73073 .72808 L .7294 .72741 L F
.689 .59 .74 r
.49548 .75241 m .49667 .75577 L .49881 .75502 L F
.837 .694 .705 r
.61509 .64746 m .61336 .6502 L .61633 .65057 L F
.798 .61 .647 r
.61301 .65249 m .61633 .65057 L .61336 .6502 L F
.61301 .65249 m .61604 .65298 L .61633 .65057 L F
.836 .995 .757 r
.34822 .81092 m .34963 .80959 L .34989 .80867 L F
0 0 0 r
.43023 .72398 m .43223 .72392 L .43344 .72384 L F
.468 0 0 r
.43223 .72392 m .43537 .72387 L .43344 .72384 L F
.8 .707 .762 r
.59149 .67992 m .5925 .6828 L .59112 .68178 L F
.789 .649 .708 r
.58992 .68414 m .5925 .6828 L .59256 .68515 L F
.58992 .68414 m .59112 .68178 L .5925 .6828 L F
.911 .751 .671 r
.59229 .68013 m .5925 .6828 L .59149 .67992 L F
.522 .249 .443 r
.59464 .68306 m .59256 .68515 L .5925 .6828 L F
.608 .115 .058 r
.44846 .76876 m .45027 .77006 L .45168 .76897 L F
.545 .089 .121 r
.45027 .77006 m .454 .76887 L .45168 .76897 L F
.861 .989 .838 r
.61936 .63965 m .61639 .64172 L .61736 .64248 L F
.61936 .63965 m .61866 .63926 L .61639 .64172 L F
.942 .961 .731 r
.62036 .63614 m .61936 .63965 L .62124 .63679 L F
.62036 .63614 m .61866 .63926 L .61936 .63965 L F
.553 .487 .735 r
.37742 .80323 m .37815 .80685 L .3761 .80709 L F
.235 0 0 r
.37707 .80753 m .3761 .80709 L .37552 .8073 L F
.37707 .80753 m .37815 .80685 L .3761 .80709 L F
0 .05 .597 r
.3761 .80709 m .37707 .80753 L .37815 .80685 L F
.412 .146 .397 r
.37918 .73576 m .38165 .73327 L .37978 .73393 L F
.436 .014 .139 r
.4507 .77688 m .44938 .77871 L .44724 .77881 L F
.238 0 0 r
.45283 .77709 m .44938 .77871 L .4507 .77688 L F
.687 .222 .142 r
.35008 .67949 m .3536 .68071 L .35151 .68135 L F
.461 0 0 r
.48366 .77425 m .48267 .77508 L .48024 .77431 L F
.504 0 0 r
.48632 .77565 m .48267 .77508 L .48366 .77425 L F
.589 .417 .616 r
.34832 .78222 m .34834 .78463 L .35052 .7819 L F
.672 .622 .791 r
.71541 .59376 m .71479 .59055 L .71332 .59383 L F
.71541 .59376 m .71479 .59055 L .71332 .59383 L F
.881 .687 .637 r
.68178 .61024 m .67856 .60663 L .68059 .60632 L F
.68178 .61024 m .67874 .60981 L .67856 .60663 L F
.282 0 .097 r
.68027 .60976 m .67874 .60981 L .68174 .61024 L F
0 0 0 r
.67841 .61075 m .6784 .61011 L .67874 .60981 L F
.676 .969 .923 r
.67956 .60953 m .67779 .61043 L .67841 .61075 L F
.67984 .60923 m .67941 .60948 L .67956 .60953 L F
.282 0 .097 r
.68076 .60974 m .67841 .61075 L .67874 .60981 L F
.676 .969 .923 r
.67941 .60948 m .67779 .61043 L .67956 .60953 L F
.282 0 .097 r
.68076 .60974 m .68027 .60976 L .68178 .61024 L F
.68027 .60976 m .68174 .61024 L .68178 .61024 L F
.487 .606 .896 r
.68394 .6087 m .68178 .61024 L .68059 .60632 L F
.449 .879 .905 r
.68264 .60905 m .68178 .61024 L .68394 .6087 L F
.68264 .60905 m .68076 .60974 L .68178 .61024 L F
.916 .939 .805 r
.52054 .75748 m .52007 .76066 L .52199 .75791 L F
.879 .591 .497 r
.51845 .762 m .52007 .76066 L .51872 .76002 L F
.51845 .762 m .5203 .76339 L .52007 .76066 L F
.562 .054 .005 r
.71142 .59055 m .71162 .58968 L .71172 .58836 L F
.71142 .59055 m .71479 .59055 L .71162 .58968 L F
.183 0 0 r
.28717 .60722 m .28829 .60736 L .28768 .60725 L F
.643 .426 .575 r
.36978 .74168 m .37252 .74185 L .37254 .73916 L F
.518 .408 .668 r
.37254 .73916 m .37454 .73883 L .37414 .73627 L F
.527 .334 .561 r
.37254 .73916 m .37429 .74149 L .37454 .73883 L F
.37254 .73916 m .37252 .74185 L .37429 .74149 L F
.39 .143 .415 r
.37212 .69002 m .37031 .69088 L .3726 .68826 L F
.403 .154 .42 r
.37442 .68765 m .37212 .69002 L .3726 .68826 L F
.384 .105 .361 r
.36965 .69213 m .36786 .69305 L .37031 .69088 L F
.494 .239 .456 r
.36965 .69213 m .36664 .69475 L .36786 .69305 L F
.552 .389 .613 r
.36137 .7525 m .36345 .75216 L .36344 .74982 L F
.543 .416 .657 r
.36176 .75509 m .36345 .75216 L .36137 .7525 L F
.792 .903 .92 r
.71631 .63447 m .71217 .63584 L .71182 .63701 L F
.186 .698 .895 r
.35975 .80902 m .3583 .80868 L .35693 .80876 L F
.708 .281 .231 r
.36192 .80903 m .36033 .81049 L .3583 .80868 L F
.425 .35 .668 r
.3583 .80868 m .36033 .81049 L .36008 .80857 L F
.3583 .80868 m .36008 .80857 L .36004 .80827 L F
.186 .698 .895 r
.35693 .80876 m .3583 .80868 L .35637 .80871 L F
0 0 0 r
.65671 .6448 m .65583 .64649 L .65466 .64742 L F
.65466 .64742 m .65583 .64649 L .65314 .6489 L F
.531 .839 .524 r
.65224 .64987 m .65466 .64742 L .65314 .6489 L F
.521 .354 .595 r
.35959 .75793 m .36163 .75796 L .36176 .75509 L F
.555 .356 .566 r
.35959 .75793 m .36166 .76001 L .36163 .75796 L F
.35959 .75793 m .35977 .76056 L .36166 .76001 L F
.266 .142 .518 r
.64949 .61557 m .64842 .61823 L .64775 .61555 L F
.64949 .61557 m .64891 .61799 L .64842 .61823 L F
.151 .01 .421 r
.64884 .61984 m .65012 .61739 L .64893 .61842 L F
.261 .131 .508 r
.64863 .61907 m .65012 .61739 L .64884 .61984 L F
.64842 .61823 m .64884 .61984 L .64803 .61973 L F
.8 .698 .752 r
.64803 .61973 m .64865 .61883 L .64516 .61706 L F
.64865 .61883 m .64893 .61842 L .6488 .61837 L F
.261 .131 .508 r
.64842 .61823 m .64884 .61827 L .64861 .61896 L F
.8 .698 .752 r
.64865 .61883 m .6488 .61837 L .64516 .61706 L F
.261 .131 .508 r
.64842 .61823 m .64884 .61826 L .64884 .61827 L F
.802 .696 .748 r
.64516 .61706 m .6488 .61837 L .64682 .61478 L F
.6488 .61837 m .64893 .61842 L .64884 .61826 L F
.261 .131 .508 r
.64842 .61823 m .64891 .61799 L .64884 .61826 L F
.802 .696 .748 r
.6488 .61837 m .64884 .61826 L .64682 .61478 L F
.261 .131 .508 r
.64884 .61827 m .64884 .61826 L .64884 .61827 L F
.151 .01 .421 r
.64884 .61984 m .64893 .61842 L .64865 .61883 L F
.261 .131 .508 r
.64861 .61896 m .64865 .61883 L .64863 .61907 L F
.64865 .61883 m .64867 .61893 L .64863 .61907 L F
.151 .01 .421 r
.64884 .61984 m .64865 .61883 L .64803 .61973 L F
.261 .131 .508 r
.64865 .61883 m .64884 .61827 L .64867 .61893 L F
.222 .118 .518 r
.64884 .61827 m .64891 .61799 L .64884 .61826 L F
.64893 .61842 m .65012 .61739 L .64949 .61557 L F
.261 .131 .508 r
.64891 .61799 m .65012 .61739 L .64863 .61907 L F
.4 .765 .994 r
.64682 .61478 m .64775 .61555 L .64703 .61257 L F
.64682 .61478 m .64949 .61557 L .64775 .61555 L F
.222 .118 .518 r
.64884 .61826 m .64949 .61557 L .64682 .61478 L F
.64891 .61799 m .64949 .61557 L .64884 .61826 L F
.64893 .61842 m .64949 .61557 L .64884 .61827 L F
.266 .142 .518 r
.64949 .61557 m .65012 .61739 L .64891 .61799 L F
.812 .994 .759 r
.70944 .59949 m .71109 .59894 L .71093 .59883 L F
.87 .678 .641 r
.51111 .76011 m .50959 .76128 L .50792 .76048 L F
.739 .551 .64 r
.50879 .76317 m .51213 .76338 L .51111 .76011 L F
.682 .52 .66 r
.51111 .76011 m .51432 .7627 L .51339 .75973 L F
.51111 .76011 m .51213 .76338 L .51432 .7627 L F
.481 .097 .234 r
.40246 .72773 m .40463 .72762 L .40588 .72553 L F
.377 0 .132 r
.40463 .72762 m .40804 .72536 L .40588 .72553 L F
.333 .115 .426 r
.37644 .68481 m .37442 .68765 L .37486 .68554 L F
.312 .143 .484 r
.35568 .70858 m .35443 .707 L .35603 .70641 L F
.35568 .70858 m .35427 .70949 L .35443 .707 L F
.362 .07 .327 r
.35844 .70417 m .35603 .70641 L .35667 .70466 L F
.942 .791 .665 r
.70389 .59115 m .7048 .59415 L .7043 .59474 L F
.70389 .59115 m .7043 .59474 L .70403 .59457 L F
.70389 .59115 m .70405 .59504 L .70162 .59449 L F
.514 .794 .996 r
.70258 .59364 m .70436 .59403 L .70331 .59298 L F
.70162 .59449 m .70343 .59419 L .70258 .59364 L F
.70343 .59419 m .70436 .59403 L .70258 .59364 L F
.942 .791 .665 r
.70403 .59457 m .7043 .59474 L .70405 .59504 L F
.861 .972 .657 r
.70436 .59403 m .7048 .59415 L .70405 .59504 L F
.799 .662 .712 r
.70563 .5927 m .70744 .59279 L .70655 .59352 L F
.70389 .59115 m .70605 .59215 L .70563 .5927 L F
.70605 .59215 m .70744 .59279 L .70563 .5927 L F
.70389 .59115 m .70655 .59352 L .7055 .59218 L F
.269 .389 .801 r
.7055 .59218 m .7048 .59415 L .70389 .59115 L F
.838 .979 .683 r
.70436 .59403 m .70458 .59409 L .7055 .59218 L F
.70458 .59409 m .7048 .59415 L .70503 .59349 L F
.70458 .59409 m .70503 .59349 L .7055 .59218 L F
.611 .452 .641 r
.34979 .77941 m .3519 .77659 L .3499 .77697 L F
.367 0 .036 r
.38387 .73327 m .38601 .73305 L .38747 .73137 L F
.189 0 0 r
.38601 .73305 m .38879 .73224 L .38747 .73137 L F
.385 0 .052 r
.38747 .73137 m .38879 .73224 L .38968 .73114 L F
.334 .175 .511 r
.48344 .87352 m .4833 .87556 L .48488 .87293 L F
0 0 .089 r
.61563 .6234 m .61732 .62253 L .61779 .6207 L F
0 0 0 r
.61446 .62452 m .61732 .62253 L .61563 .6234 L F
.371 0 .068 r
.41441 .78968 m .41363 .7906 L .41019 .79173 L F
.274 0 .004 r
.41561 .79016 m .41441 .78968 L .41636 .78938 L F
.41561 .79016 m .41363 .7906 L .41441 .78968 L F
.245 0 .242 r
.3303 .80091 m .3317 .80097 L .33241 .79865 L F
.679 .456 .576 r
.3317 .80097 m .33427 .79784 L .33241 .79865 L F
.255 .429 .842 r
.72779 .71152 m .73045 .71486 L .72956 .71332 L F
.542 .83 .998 r
.5044 .84879 m .50777 .84904 L .5058 .84961 L F
.5058 .84961 m .50777 .84904 L .5044 .84879 L F
.684 .588 .743 r
.49329 .75305 m .49548 .75241 L .49466 .74974 L F
.431 0 .087 r
.45619 .77595 m .45476 .7776 L .45283 .77709 L F
.407 0 .083 r
.45845 .77593 m .45476 .7776 L .45619 .77595 L F
.685 .98 .867 r
.71005 .63628 m .70908 .63766 L .71077 .63665 L F
.71005 .63628 m .70729 .63817 L .70908 .63766 L F
.492 .312 .565 r
.34355 .69612 m .34532 .69775 L .3458 .69576 L F
.34355 .69612 m .3434 .69834 L .34532 .69775 L F
.976 .736 .51 r
.3676 .83648 m .36897 .83861 L .36779 .83845 L F
.578 .676 .907 r
.36957 .83681 m .36897 .83861 L .3676 .83648 L F
.548 .643 .896 r
.36897 .83861 m .37105 .83841 L .36957 .83681 L F
.852 .967 .874 r
.36779 .83845 m .36897 .83861 L .36957 .83681 L F
.548 .643 .896 r
.36897 .83861 m .37105 .83841 L .36957 .83681 L F
.277 .758 .651 r
.39467 .79649 m .39275 .7973 L .39616 .79586 L F
.354 .809 .686 r
.39467 .79649 m .39616 .79586 L .39781 .79503 L F
0 0 .04 r
.63086 .62266 m .62966 .62514 L .63059 .62217 L F
.824 .783 .814 r
.63092 .62604 m .63275 .62352 L .63107 .62247 L F
0 0 .04 r
.63086 .62266 m .63086 .62269 L .63067 .62308 L F
.63086 .62266 m .63067 .62308 L .63062 .62315 L F
.824 .783 .814 r
.63067 .62308 m .63107 .62247 L .63059 .62217 L F
.63092 .62604 m .63107 .62247 L .63086 .62279 L F
.912 .704 .609 r
.63114 .6212 m .63146 .62165 L .63123 .62024 L F
.63146 .62165 m .63275 .62352 L .6317 .62127 L F
.63146 .62165 m .6317 .62127 L .63123 .62024 L F
.74 .885 .481 r
.63105 .62228 m .63086 .62266 L .63123 .62024 L F
.912 .704 .609 r
.6309 .62237 m .63275 .62352 L .63099 .62097 L F
.799 .793 .847 r
.63123 .62024 m .63262 .62095 L .63431 .61901 L F
.897 .702 .631 r
.63123 .62024 m .63275 .62352 L .63262 .62095 L F
.799 .793 .847 r
.63123 .62024 m .63431 .61901 L .63376 .61845 L F
.429 .822 .599 r
.63376 .61845 m .63254 .61927 L .63123 .62024 L F
.74 .885 .481 r
.63254 .61927 m .63105 .62228 L .63123 .62024 L F
.63254 .61927 m .63101 .62194 L .63089 .62253 L F
.63105 .62228 m .63089 .62253 L .63086 .62266 L F
.63254 .61927 m .63089 .62253 L .63105 .62228 L F
.996 .855 .573 r
.63123 .62024 m .63086 .62266 L .63059 .62217 L F
.912 .704 .609 r
.63099 .62097 m .63114 .6212 L .63123 .62024 L F
.63059 .62217 m .6309 .62237 L .63099 .62097 L F
.44 .287 .576 r
.63101 .62194 m .63087 .62422 L .63086 .62294 L F
.63088 .6227 m .63086 .62294 L .63086 .62279 L F
.63101 .62194 m .63086 .62294 L .63088 .6227 L F
.63088 .62257 m .63086 .62279 L .63086 .62266 L F
.63101 .62194 m .63086 .62279 L .63088 .62257 L F
.824 .783 .814 r
.63075 .62404 m .63086 .62279 L .63067 .62308 L F
.63092 .62604 m .63086 .62279 L .63075 .62404 L F
0 0 .04 r
.63062 .62315 m .63067 .62308 L .62966 .62514 L F
.824 .783 .814 r
.63092 .62604 m .63067 .62308 L .62966 .62514 L F
0 0 .04 r
.63086 .62269 m .63087 .62422 L .62966 .62514 L F
.824 .783 .814 r
.63067 .62308 m .63059 .62217 L .62966 .62514 L F
.671 .157 .009 r
.62974 .6271 m .63092 .62604 L .62966 .62514 L F
.559 .333 .53 r
.63092 .62604 m .63328 .62776 L .63208 .62714 L F
.449 .331 .627 r
.63186 .62781 m .6333 .63077 L .63088 .63081 L F
.63208 .62714 m .63231 .62782 L .63186 .62781 L F
.63231 .62782 m .6333 .63077 L .63186 .62781 L F
.521 .372 .619 r
.6344 .62844 m .63318 .62776 L .63426 .62813 L F
.351 0 .033 r
.63426 .62813 m .63355 .62786 L .63353 .62788 L F
0 .347 .784 r
.63208 .62714 m .63328 .62776 L .63426 .62813 L F
.521 .372 .619 r
.63318 .62776 m .63208 .62714 L .63426 .62813 L F
.63373 .62807 m .6333 .63077 L .63208 .62714 L F
.63491 .62873 m .63483 .62883 L .63373 .62807 L F
.63483 .62883 m .6333 .63077 L .63373 .62807 L F
.671 .157 .009 r
.62974 .6271 m .63328 .62776 L .6331 .62763 L F
.63087 .62608 m .6331 .62763 L .63092 .62604 L F
.62974 .6271 m .6331 .62763 L .63087 .62608 L F
.351 0 .033 r
.63426 .62813 m .63353 .62788 L .6315 .62961 L F
.739 .918 .953 r
.63396 .62744 m .63426 .62813 L .63248 .6288 L F
.63444 .627 m .63426 .62813 L .63396 .62744 L F
.521 .372 .619 r
.63491 .62873 m .6344 .62844 L .63426 .62813 L F
.351 0 .033 r
.63355 .62786 m .63328 .62776 L .63318 .62785 L F
.63355 .62786 m .63318 .62785 L .6315 .62961 L F
.37 .09 .352 r
.37219 .69054 m .37031 .69088 L .37212 .69002 L F
.37219 .69054 m .36965 .69213 L .37031 .69088 L F
.797 .564 .584 r
.36773 .80629 m .36744 .80865 L .37068 .80866 L F
.634 .95 .748 r
.3672 .81106 m .37068 .80866 L .36744 .80865 L F
.753 .753 .852 r
.37068 .80866 m .372 .8054 L .37001 .80603 L F
.37068 .80866 m .3731 .8073 L .372 .8054 L F
.73 .717 .838 r
.51537 .75254 m .51199 .7528 L .51406 .74987 L F
.48 0 .021 r
.41702 .74208 m .41376 .74313 L .41511 .74243 L F
.317 .446 .833 r
.65457 .58656 m .65385 .58822 L .65172 .58725 L F
.65457 .58656 m .65537 .58857 L .65385 .58822 L F
.675 .424 .534 r
.60353 .67941 m .60235 .68235 L .60001 .68206 L F
.62 .364 .509 r
.60658 .68136 m .60353 .67941 L .6059 .67937 L F
.60658 .68136 m .60235 .68235 L .60353 .67941 L F
.471 .257 .507 r
.36508 .69832 m .36293 .7012 L .36266 .69875 L F
.554 .247 .402 r
.43373 .73949 m .4335 .74126 L .4309 .74072 L F
.591 .308 .456 r
.43616 .73931 m .4335 .74126 L .43373 .73949 L F
.738 .95 .642 r
.65704 .63194 m .65488 .63461 L .6563 .63225 L F
.723 .907 .959 r
.6563 .63225 m .65488 .63461 L .65356 .63371 L F
.533 .375 .612 r
.35286 .68793 m .35482 .68528 L .35235 .68553 L F
.35286 .68793 m .35496 .68769 L .35482 .68528 L F
.372 .174 .477 r
.35305 .69042 m .35496 .68769 L .35286 .68793 L F
.922 .828 .734 r
.73438 .73315 m .73475 .73601 L .73579 .73402 L F
.635 .831 .426 r
.65851 .64192 m .65671 .6448 L .65927 .64254 L F
.65851 .64192 m .65666 .64479 L .65671 .6448 L F
.681 .803 .346 r
.65666 .64479 m .65583 .64649 L .65671 .6448 L F
.587 .414 .615 r
.35585 .76603 m .35369 .76874 L .35589 .76838 L F
.603 .461 .66 r
.35383 .77118 m .35589 .76838 L .35369 .76874 L F
.702 .812 .933 r
.72578 .74422 m .72697 .74568 L .7289 .74457 L F
.534 .434 .688 r
.38375 .76772 m .3843 .77118 L .38224 .77147 L F
.633 .487 .666 r
.38478 .77327 m .38224 .77147 L .3843 .77118 L F
.38478 .77327 m .38244 .77374 L .38224 .77147 L F
.779 .604 .662 r
.70539 .71216 m .70865 .71422 L .70897 .71334 L F
.70539 .71216 m .70528 .71458 L .70865 .71422 L F
.786 .669 .734 r
.70528 .71458 m .70643 .71762 L .70865 .71422 L F
.783 .749 .822 r
.70897 .71334 m .70865 .71422 L .71071 .71219 L F
0 0 0 r
.73553 .72746 m .7336 .73016 L .73418 .72862 L F
.386 .738 .991 r
.65264 .60423 m .65343 .60523 L .65095 .60526 L F
.65264 .60423 m .65095 .60526 L .64994 .60618 L F
.91 .979 .707 r
.62124 .63679 m .62267 .63323 L .62036 .63614 L F
.175 0 0 r
.42315 .78701 m .42208 .7867 L .42394 .78641 L F
.42315 .78701 m .42113 .78743 L .42208 .7867 L F
.845 .737 .744 r
.37615 .8109 m .37863 .80903 L .37806 .81027 L F
0 0 .475 r
.3788 .80817 m .37863 .80903 L .37815 .80685 L F
.758 .815 .341 r
.37806 .81027 m .37863 .80903 L .3788 .80817 L F
.311 .755 .963 r
.46416 .72626 m .46629 .72616 L .46759 .72666 L F
.38 .798 .976 r
.46629 .72616 m .46978 .72636 L .46759 .72666 L F
.39 .161 .442 r
.34936 .71445 m .34762 .71511 L .34977 .71237 L F
.254 0 .24 r
.34936 .71445 m .34691 .71688 L .34762 .71511 L F
.63 .715 .908 r
.46113 .73624 m .46443 .73706 L .46317 .73616 L F
.446 .747 .992 r
.46443 .73706 m .4654 .73603 L .46317 .73616 L F
.46443 .73706 m .46653 .73681 L .4654 .73603 L F
.554 .762 .975 r
.68343 .58988 m .68731 .59084 L .686 .58917 L F
.403 .641 .953 r
.686 .58917 m .68731 .59084 L .68913 .59078 L F
.379 .37 .723 r
.68731 .59084 m .68992 .59359 L .68913 .59078 L F
.372 .118 .394 r
.35168 .71186 m .34936 .71445 L .34977 .71237 L F
0 0 .353 r
.72713 .73102 m .72793 .73238 L .72743 .73017 L F
.72713 .73102 m .72708 .73343 L .72793 .73238 L F
.971 .676 .406 r
.67277 .61006 m .67302 .61255 L .67176 .61141 L F
.9 .657 .563 r
.59438 .66878 m .59606 .67211 L .59423 .67106 L F
.818 .687 .72 r
.59489 .67399 m .59423 .67106 L .59606 .67211 L F
.726 .608 .726 r
.59782 .66926 m .59606 .67211 L .59438 .66878 L F
.739 .593 .694 r
.5912 .66396 m .58946 .6665 L .58761 .66349 L F
.756 .618 .706 r
.59093 .66627 m .58946 .6665 L .5912 .66396 L F
0 0 0 r
.61779 .6207 m .61946 .61983 L .62026 .6182 L F
.444 .231 .494 r
.61732 .62253 m .61946 .61983 L .61779 .6207 L F
.741 .744 .854 r
.5321 .76859 m .53617 .7685 L .53487 .76745 L F
.41 0 .072 r
.53196 .7706 m .53422 .77044 L .53617 .7685 L F
.413 .657 .96 r
.53617 .7685 m .53747 .76818 L .53487 .76745 L F
.551 .122 .179 r
.53617 .7685 m .53693 .76996 L .53747 .76818 L F
0 0 .4 r
.53693 .76996 m .53612 .77135 L .53617 .7685 L F
.551 .122 .179 r
.53617 .7685 m .53422 .77044 L .53693 .76996 L F
.413 .657 .96 r
.53487 .76745 m .53747 .76818 L .53617 .7685 L F
0 0 .4 r
.53693 .76996 m .53617 .7685 L .53747 .76818 L F
.76 .633 .719 r
.50735 .76946 m .50761 .77172 L .50787 .76909 L F
.725 .528 0 r
.50735 .76946 m .50779 .77354 L .50761 .77172 L F
.792 .903 .92 r
.71631 .63447 m .71535 .63363 L .71217 .63584 L F
.982 .84 .627 r
.71618 .62998 m .71535 .63363 L .71631 .63447 L F
.975 .747 .529 r
.67591 .62868 m .67698 .6318 L .67544 .63096 L F
.913 .75 .666 r
.67698 .6318 m .67651 .63398 L .67544 .63096 L F
.845 .688 .688 r
.66149 .61818 m .66049 .61526 L .6619 .61604 L F
.66149 .61818 m .6588 .61785 L .66049 .61526 L F
.766 .528 .575 r
.66149 .61818 m .65887 .62042 L .6588 .61785 L F
.66149 .61818 m .6617 .62044 L .65887 .62042 L F
.973 .819 .63 r
.61575 .64388 m .61736 .64248 L .61639 .64172 L F
.61575 .64388 m .61685 .64472 L .61736 .64248 L F
.54 .378 .609 r
.35585 .76603 m .35791 .76801 L .35792 .76567 L F
.35585 .76603 m .35589 .76838 L .35791 .76801 L F
.944 .833 .704 r
.64175 .61748 m .64234 .61554 L .64109 .61625 L F
.303 .536 .911 r
.64175 .61748 m .64109 .61625 L .64234 .61554 L F
.175 .596 .94 r
.35846 .65534 m .35985 .65634 L .35669 .65495 L F
.458 .777 .998 r
.36054 .65526 m .35985 .65634 L .35846 .65534 L F
.36054 .65526 m .362 .65609 L .35985 .65634 L F
.363 .141 .437 r
.3212 .67867 m .31973 .67749 L .32178 .67714 L F
.3212 .67867 m .31938 .67955 L .31973 .67749 L F
.4 .435 .781 r
.69291 .72097 m .69542 .72246 L .69449 .71934 L F
.7 .393 .453 r
.49016 .76869 m .49355 .77036 L .49345 .76885 L F
.713 .346 .353 r
.49355 .77036 m .49551 .77092 L .49345 .76885 L F
.182 0 0 r
.42192 .77656 m .42393 .77686 L .42541 .77693 L F
0 0 0 r
.42393 .77686 m .42749 .77655 L .42541 .77693 L F
.587 .508 .733 r
.48891 .74711 m .4907 .74456 L .48737 .74427 L F
.48891 .74711 m .491 .74672 L .4907 .74456 L F
.397 .164 .44 r
.37831 .68418 m .37692 .68279 L .37864 .68211 L F
.37831 .68418 m .37644 .68481 L .37692 .68279 L F
.513 .684 .944 r
.69023 .5856 m .68846 .58724 L .688 .58548 L F
.69023 .5856 m .6923 .58821 L .68846 .58724 L F
0 0 0 r
.64754 .58886 m .64843 .58865 L .64951 .58797 L F
.64754 .58886 m .64641 .59004 L .64843 .58865 L F
.733 .664 .783 r
.70447 .62935 m .70386 .63063 L .70356 .62858 L F
0 0 0 r
.65224 .64987 m .65215 .65032 L .64966 .65279 L F
.65224 .64987 m .65314 .6489 L .65215 .65032 L F
.501 .524 .812 r
.35032 .67741 m .35239 .67789 L .35091 .67376 L F
.442 .126 .333 r
.35008 .67949 m .35239 .67789 L .35032 .67741 L F
.727 .536 .634 r
.59425 .66855 m .58946 .6665 L .59093 .66627 L F
.844 .691 .692 r
.59458 .66659 m .59425 .66855 L .59093 .66627 L F
.243 .62 .957 r
.71042 .58724 m .70813 .58723 L .70794 .58554 L F
.838 .734 .749 r
.70571 .58628 m .70593 .58813 L .70248 .58783 L F
.739 .638 .747 r
.70517 .58741 m .70857 .58804 L .70792 .58619 L F
.70703 .5858 m .70792 .58619 L .70761 .5853 L F
.70517 .58741 m .70792 .58619 L .70703 .5858 L F
.243 .62 .957 r
.71026 .58724 m .71172 .58836 L .70813 .58723 L F
.71042 .58724 m .71059 .58739 L .71026 .58724 L F
.71059 .58739 m .71172 .58836 L .71026 .58724 L F
.117 0 0 r
.41141 .77946 m .41407 .779 L .41195 .77906 L F
.689 .59 .74 r
.49548 .75241 m .49881 .75502 L .49923 .75368 L F
.702 .641 .785 r
.49923 .75368 m .49881 .75502 L .5009 .75256 L F
.662 .515 .673 r
.49881 .75502 m .49997 .75835 L .50226 .75804 L F
.626 .135 .066 r
.51672 .7737 m .51892 .77543 L .51999 .774 L F
.4 0 0 r
.51999 .774 m .52099 .77525 L .52239 .77446 L F
.51999 .774 m .51892 .77543 L .52099 .77525 L F
.738 .95 .642 r
.65704 .63194 m .6563 .63225 L .65577 .631 L F
.813 .956 .908 r
.65854 .63028 m .65704 .63194 L .65577 .631 L F
.379 .425 .783 r
.72877 .61693 m .72646 .6157 L .72775 .61512 L F
.004 0 0 r
.40744 .78107 m .40935 .77999 L .40619 .78112 L F
.06 0 0 r
.41141 .77946 m .40935 .77999 L .40744 .78107 L F
.145 .594 .929 r
.4309 .74072 m .4335 .74126 L .43228 .74045 L F
.4309 .74072 m .43228 .74045 L .43012 .74093 L F
.668 .717 .885 r
.46993 .73881 m .47333 .73954 L .47212 .73819 L F
.69 .723 .875 r
.47212 .73819 m .47333 .73954 L .47539 .73864 L F
.289 .715 .97 r
.68118 .5839 m .68523 .58573 L .68177 .58509 L F
.438 .58 .897 r
.69023 .5856 m .688 .58548 L .68939 .58398 L F
.389 .503 .853 r
.68939 .58398 m .688 .58548 L .68897 .58515 L F
.414 .779 .995 r
.68897 .58515 m .68523 .58573 L .68118 .5839 L F
.209 0 0 r
.688 .58548 m .68604 .5856 L .68523 .58573 L F
.688 .58548 m .68523 .58573 L .68897 .58515 L F
.435 .871 .799 r
.31091 .71906 m .31348 .71792 L .31448 .7177 L F
.482 .887 .746 r
.31448 .7177 m .31522 .71702 L .31671 .7164 L F
.473 .892 .809 r
.31448 .7177 m .31348 .71792 L .31522 .71702 L F
.663 .445 .578 r
.32848 .80276 m .3303 .80091 L .32991 .80123 L F
.109 0 0 r
.7224 .62543 m .72171 .62585 L .71949 .6262 L F
.603 .454 .652 r
.3519 .77659 m .35391 .77357 L .35198 .77401 L F
.628 .72 .913 r
.71076 .6276 m .70958 .62986 L .70901 .62772 L F
.71076 .6276 m .71219 .62913 L .70958 .62986 L F
.644 .204 .189 r
.66499 .59194 m .66788 .59326 L .66873 .59266 L F
0 .311 .681 r
.66636 .59249 m .66499 .59194 L .66411 .59038 L F
.66636 .59249 m .66788 .59326 L .66499 .59194 L F
.823 .629 .64 r
.64648 .59724 m .64594 .60094 L .64316 .59859 L F
.273 .131 .498 r
.64809 .59766 m .64648 .59724 L .6487 .59651 L F
.723 .653 .78 r
.64634 .60014 m .64594 .60094 L .6468 .60037 L F
.273 .131 .498 r
.64732 .59746 m .64594 .60094 L .64648 .59724 L F
.64766 .59754 m .64634 .60014 L .64732 .59746 L F
.64634 .60014 m .64594 .60094 L .64732 .59746 L F
.723 .653 .78 r
.64316 .59859 m .64594 .60094 L .64634 .60014 L F
.64316 .59859 m .64634 .60014 L .64448 .60229 L F
.768 .775 .858 r
.6468 .60037 m .64594 .60094 L .64619 .60056 L F
.723 .653 .78 r
.64634 .60014 m .6468 .60037 L .64619 .60056 L F
.768 .775 .858 r
.6468 .60037 m .64619 .60056 L .64809 .59766 L F
.723 .653 .78 r
.64619 .60056 m .6468 .60037 L .64602 .60101 L F
.64634 .60014 m .64602 .60101 L .64448 .60229 L F
.273 .131 .498 r
.64809 .59766 m .64594 .60094 L .64766 .59754 L F
.464 .855 .652 r
.56934 .68004 m .57046 .67912 L .57204 .67818 L F
.731 .726 .846 r
.57204 .67818 m .57191 .6793 L .56934 .68004 L F
.36 0 .018 r
.57191 .6793 m .57062 .68038 L .56934 .68004 L F
.166 .376 .824 r
.56934 .68004 m .57062 .68038 L .57046 .67912 L F
.424 .145 .384 r
.65207 .61024 m .65429 .60749 L .6539 .60966 L F
.645 .467 .628 r
.65653 .60745 m .6539 .60966 L .65429 .60749 L F
.522 .249 .443 r
.59464 .68306 m .59477 .68479 L .59256 .68515 L F
.599 .313 .454 r
.59776 .68216 m .59477 .68479 L .59464 .68306 L F
.404 0 0 r
.47572 .76546 m .47779 .76573 L .47922 .76554 L F
.612 .076 0 r
.47779 .76573 m .48108 .76646 L .47922 .76554 L F
0 .473 .767 r
.44446 .72488 m .44652 .72538 L .44778 .72584 L F
.451 .8 .998 r
.44652 .72538 m .44989 .72583 L .44778 .72584 L F
.297 .78 .911 r
.52421 .75745 m .52054 .75748 L .52199 .75791 L F
.65 .678 .864 r
.42125 .7428 m .42387 .7436 L .4214 .74304 L F
.506 .784 .995 r
.42387 .7436 m .42485 .74246 L .4214 .74304 L F
.001 0 0 r
.42327 .74274 m .4215 .7432 L .4214 .74304 L F
.4215 .7432 m .42118 .74328 L .4214 .74304 L F
.65 .678 .864 r
.41961 .7423 m .42125 .7428 L .4214 .74304 L F
.506 .784 .995 r
.42387 .7436 m .42573 .74338 L .42485 .74246 L F
.738 .581 .679 r
.50449 .76852 m .50735 .76946 L .50787 .76909 L F
.357 .212 .542 r
.57371 .67673 m .57191 .6793 L .57204 .67818 L F
.57371 .67673 m .57376 .6792 L .57191 .6793 L F
.21 0 0 r
.57191 .6793 m .57376 .6792 L .57062 .68038 L F
.187 .052 .453 r
.39095 .75445 m .38933 .7556 L .38862 .75589 L F
.673 .517 .665 r
.71497 .59508 m .7136 .5968 L .71541 .59376 L F
.699 .755 .895 r
.33626 .7952 m .33739 .79624 L .33969 .7955 L F
.114 0 .237 r
.62026 .6182 m .62195 .61747 L .62225 .61536 L F
.135 0 .285 r
.62154 .61925 m .62026 .6182 L .61946 .61983 L F
.62154 .61925 m .62195 .61747 L .62026 .6182 L F
.471 .147 .335 r
.52224 .78466 m .52369 .7868 L .52154 .7871 L F
.52224 .78466 m .52435 .78434 L .52369 .7868 L F
.574 .375 .573 r
.36555 .74716 m .36785 .7469 L .36799 .74446 L F
.425 .25 .539 r
.36799 .74446 m .36969 .74399 L .36978 .74168 L F
.436 .26 .543 r
.36799 .74446 m .3696 .74631 L .36969 .74399 L F
.36799 .74446 m .36785 .7469 L .3696 .74631 L F
.54 .648 .904 r
.69316 .63155 m .68949 .62946 L .69193 .62919 L F
.574 .661 .896 r
.6936 .63013 m .69316 .63155 L .69193 .62919 L F
.6948 .6308 m .69465 .63087 L .6936 .63013 L F
.69465 .63087 m .69316 .63155 L .6936 .63013 L F
.498 0 0 r
.69119 .63224 m .6948 .63098 L .69122 .63025 L F
.6948 .63098 m .69482 .63098 L .69479 .63097 L F
.6948 .63098 m .69479 .63097 L .69122 .63025 L F
.77 .828 .897 r
.6948 .6308 m .6948 .63078 L .69457 .62846 L F
.207 .376 .812 r
.69457 .62846 m .69482 .63098 L .69482 .63097 L F
.574 .661 .896 r
.69496 .62979 m .6948 .6308 L .69457 .62846 L F
.69536 .63111 m .69484 .63082 L .69496 .62979 L F
.69484 .63082 m .6948 .6308 L .69496 .62979 L F
.77 .828 .897 r
.69479 .63097 m .69482 .63098 L .6948 .63078 L F
.574 .661 .896 r
.69484 .63082 m .69477 .63123 L .6948 .6308 L F
.69536 .63111 m .69482 .63122 L .69484 .63082 L F
.412 0 0 r
.69482 .63097 m .69483 .63098 L .69483 .63095 L F
.69482 .63098 m .69482 .63098 L .69482 .63097 L F
.574 .661 .896 r
.69482 .63122 m .69477 .63123 L .69481 .63098 L F
.69482 .63122 m .69481 .63098 L .69483 .63098 L F
.709 .562 .687 r
.69635 .63408 m .69316 .63155 L .69536 .63111 L F
.69635 .63408 m .69349 .63419 L .69316 .63155 L F
.741 .668 .779 r
.69895 .6318 m .69635 .63408 L .69536 .63111 L F
.412 0 0 r
.69483 .63098 m .69352 .63255 L .6969 .63205 L F
.69482 .63098 m .69481 .63098 L .69483 .63098 L F
.69481 .63098 m .69352 .63255 L .69483 .63098 L F
.7 .668 .815 r
.69667 .62752 m .69536 .63111 L .69496 .62979 L F
.6949 .62831 m .69496 .62979 L .69457 .62846 L F
.69667 .62752 m .69496 .62979 L .6949 .62831 L F
.707 .715 .855 r
.69798 .63022 m .69895 .6318 L .69536 .63111 L F
.7 .668 .815 r
.69667 .62752 m .69798 .63022 L .69536 .63111 L F
.412 0 0 r
.695 .63065 m .6969 .63205 L .69602 .62883 L F
.69483 .63095 m .69501 .63105 L .695 .63065 L F
.69501 .63105 m .6969 .63205 L .695 .63065 L F
.207 .376 .812 r
.69457 .62846 m .6948 .6308 L .69602 .62883 L F
.6948 .6308 m .69482 .63097 L .69483 .63095 L F
.574 .661 .896 r
.69483 .63095 m .69482 .63091 L .69484 .63082 L F
.207 .376 .812 r
.6948 .6308 m .69483 .63095 L .69602 .62883 L F
.574 .661 .896 r
.69483 .63098 m .69481 .63098 L .69482 .63091 L F
.69483 .63098 m .69482 .63091 L .69483 .63095 L F
.412 0 0 r
.69483 .63098 m .6969 .63205 L .69483 .63095 L F
.69482 .63098 m .6969 .63205 L .69482 .63097 L F
.574 .661 .896 r
.6948 .6308 m .6948 .6308 L .69457 .62846 L F
.6948 .6308 m .69193 .62919 L .69457 .62846 L F
.77 .828 .897 r
.69479 .63097 m .6948 .6308 L .69457 .62846 L F
.69122 .63025 m .69479 .63097 L .69457 .62846 L F
.574 .661 .896 r
.69477 .63123 m .69316 .63155 L .69448 .63095 L F
.69477 .63123 m .69448 .63095 L .69479 .63098 L F
.498 0 0 r
.69119 .63224 m .69352 .63255 L .69481 .63098 L F
.6948 .63098 m .69481 .63098 L .69482 .63098 L F
.69119 .63224 m .69481 .63098 L .6948 .63098 L F
.574 .661 .896 r
.69479 .63098 m .69448 .63095 L .6948 .6308 L F
.238 0 0 r
.49299 .88194 m .49123 .88247 L .48972 .88247 L F
.344 .816 .752 r
.49388 .8814 m .49299 .88194 L .49497 .88189 L F
.49388 .8814 m .49123 .88247 L .49299 .88194 L F
.845 .688 .687 r
.70248 .58783 m .70593 .58813 L .70389 .59115 L F
.002 0 0 r
.4501 .73673 m .44869 .73732 L .44657 .73773 L F
.153 .695 .761 r
.45219 .73693 m .44869 .73732 L .4501 .73673 L F
.578 .22 .325 r
.70307 .69519 m .70635 .69503 L .7037 .69383 L F
.956 .858 .703 r
.71206 .71546 m .71178 .71801 L .71118 .71605 L F
.491 .778 .996 r
.71178 .71801 m .7133 .71671 L .71118 .71605 L F
.71178 .71801 m .71444 .71761 L .7133 .71671 L F
.609 .617 .833 r
.49869 .74115 m .49531 .73896 L .49756 .73845 L F
.601 .602 .824 r
.49975 .73805 m .49869 .74115 L .49756 .73845 L F
.49975 .73805 m .50084 .74071 L .49869 .74115 L F
.103 0 0 r
.53001 .77139 m .52789 .77189 L .52641 .77296 L F
0 0 0 r
.63065 .6664 m .62975 .668 L .6282 .6689 L F
.336 .104 .407 r
.63065 .6664 m .6328 .66369 L .63247 .66567 L F
.091 0 0 r
.63247 .66567 m .62975 .668 L .63065 .6664 L F
.989 .882 .549 r
.66853 .60867 m .66949 .60779 L .66859 .6067 L F
.151 0 0 r
.42986 .78463 m .42812 .78569 L .42607 .78604 L F
.279 0 0 r
.43182 .78419 m .42812 .78569 L .42986 .78463 L F
.801 .745 .8 r
.6468 .60037 m .64766 .60196 L .64448 .60229 L F
.547 .056 .042 r
.64448 .60229 m .64766 .60196 L .64655 .60307 L F
.482 .595 .89 r
.64899 .60041 m .64766 .60196 L .6468 .60037 L F
.568 .852 .523 r
.64655 .60307 m .64766 .60196 L .64899 .60041 L F
.2 0 0 r
.33188 .6499 m .3351 .65046 L .33336 .65069 L F
.476 .844 .99 r
.36773 .80629 m .37001 .80603 L .36797 .80535 L F
.948 .718 .558 r
.366 .80816 m .36773 .80629 L .36797 .80535 L F
.366 .80816 m .36744 .80865 L .36773 .80629 L F
.545 .212 .355 r
.39719 .74971 m .39618 .75184 L .39401 .75181 L F
.302 0 .228 r
.398 .75126 m .39719 .74971 L .39949 .74942 L F
.398 .75126 m .39618 .75184 L .39719 .74971 L F
.517 .681 .94 r
.3731 .8073 m .37364 .80524 L .372 .8054 L F
.3731 .8073 m .37552 .8073 L .37364 .80524 L F
.085 0 0 r
.32576 .73138 m .32434 .73304 L .32307 .73296 L F
0 0 0 r
.32606 .73215 m .32576 .73138 L .32792 .73101 L F
.32606 .73215 m .32434 .73304 L .32576 .73138 L F
.663 .445 .578 r
.32848 .80276 m .3317 .80097 L .3303 .80091 L F
.429 0 0 r
.40804 .72536 m .41021 .72546 L .41128 .72478 L F
.353 0 0 r
.41128 .72478 m .41021 .72546 L .41345 .72473 L F
.241 0 0 r
.62589 .6317 m .62488 .63286 L .62267 .63323 L F
.573 .031 0 r
.62589 .6317 m .62591 .63237 L .62488 .63286 L F
.62589 .6317 m .62817 .6329 L .62591 .63237 L F
.438 .225 .491 r
.36344 .74982 m .36528 .74942 L .36555 .74716 L F
.579 .459 .68 r
.36345 .75216 m .36528 .74942 L .36344 .74982 L F
.079 0 .191 r
.62225 .61536 m .62407 .61442 L .62436 .61251 L F
.336 .038 .303 r
.62225 .61536 m .62393 .61673 L .62407 .61442 L F
.62225 .61536 m .62195 .61747 L .62393 .61673 L F
.587 .575 .807 r
.50621 .74153 m .50518 .74511 L .50405 .74226 L F
.50621 .74153 m .50735 .74477 L .50518 .74511 L F
.612 .379 .539 r
.51422 .77367 m .5177 .77182 L .5135 .77121 L F
.682 .663 .825 r
.49548 .75241 m .49797 .75072 L .49466 .74974 L F
.49548 .75241 m .49804 .75203 L .49797 .75072 L F
.676 .573 .731 r
.49548 .75241 m .49923 .75368 L .49804 .75203 L F
.932 .739 .619 r
.33998 .79817 m .34098 .80071 L .3399 .79942 L F
.646 .568 .753 r
.34077 .80329 m .3399 .79942 L .34098 .80071 L F
0 .005 .562 r
.34098 .80071 m .34332 .80385 L .34077 .80329 L F
.252 0 .22 r
.34512 .71753 m .34434 .71977 L .34266 .7199 L F
.09 0 .147 r
.34578 .71883 m .34512 .71753 L .34691 .71688 L F
.34578 .71883 m .34434 .71977 L .34512 .71753 L F
.255 .434 .846 r
.68821 .5971 m .6894 .59564 L .68715 .59596 L F
.68821 .5971 m .69034 .59797 L .6894 .59564 L F
.668 .422 .54 r
.61197 .67706 m .61007 .67956 L .60788 .67954 L F
.681 .444 .555 r
.61332 .67722 m .61007 .67956 L .61197 .67706 L F
.872 .544 .427 r
.5087 .78185 m .50696 .7815 L .50688 .77991 L F
.815 .339 .072 r
.51018 .78424 m .50696 .7815 L .5087 .78185 L F
.868 .777 .758 r
.64635 .63641 m .64803 .63358 L .64898 .63639 L F
.869 .77 .75 r
.64635 .63641 m .64898 .63639 L .64701 .63942 L F
.687 .685 .843 r
.64803 .63358 m .65115 .63422 L .64898 .63639 L F
.758 .704 .801 r
.28763 .60802 m .28829 .60736 L .28717 .60722 L F
.612 .379 .539 r
.51422 .77367 m .51672 .7737 L .5177 .77182 L F
.244 0 .308 r
.5177 .77182 m .51672 .7737 L .51881 .77107 L F
.944 .833 .704 r
.64175 .61748 m .64109 .61625 L .63914 .6175 L F
.849 .754 .758 r
.63947 .6203 m .64175 .61748 L .63914 .6175 L F
.303 .536 .911 r
.64175 .61748 m .64345 .61659 L .64109 .61625 L F
0 .096 .575 r
.64175 .61748 m .64351 .61886 L .64345 .61659 L F
.64175 .61748 m .64492 .62009 L .64351 .61886 L F
.738 .581 .679 r
.50449 .76852 m .50438 .77094 L .50735 .76946 L F
.729 .485 .558 r
.50438 .77094 m .50779 .77354 L .50735 .76946 L F
.073 0 0 r
.70036 .70508 m .69743 .70615 L .69866 .70681 L F
.657 .424 .556 r
.69853 .70931 m .69866 .70681 L .69743 .70615 L F
.69853 .70931 m .70089 .70892 L .69866 .70681 L F
.604 .548 .764 r
.48195 .74196 m .48283 .74498 L .48414 .74412 L F
.641 .535 .718 r
.48283 .74498 m .48558 .74488 L .48414 .74412 L F
.48283 .74498 m .48336 .74728 L .48558 .74488 L F
.648 .593 .779 r
.50345 .76155 m .50653 .76376 L .50552 .76068 L F
.639 .597 .791 r
.50552 .76068 m .50653 .76376 L .50879 .76317 L F
.337 .743 .981 r
.47193 .72608 m .47536 .72674 L .4733 .72709 L F
.71 .587 .716 r
.69635 .63408 m .69386 .63762 L .69349 .63419 L F
0 .038 .607 r
.33427 .79784 m .33649 .80053 L .33575 .80053 L F
.534 .437 .692 r
.33598 .80053 m .33713 .80306 L .33575 .80053 L F
.33666 .80122 m .33713 .80306 L .33598 .80053 L F
.33649 .80053 m .33615 .80258 L .33713 .80306 L F
.875 .994 .786 r
.33713 .80306 m .33615 .80258 L .33832 .7998 L F
.249 0 .326 r
.33753 .8021 m .33615 .80258 L .33752 .80211 L F
.33832 .7998 m .33697 .80153 L .33753 .8021 L F
.33697 .80153 m .33615 .80258 L .33753 .8021 L F
.534 .437 .692 r
.33649 .80053 m .33666 .80122 L .33598 .80053 L F
.394 .47 .82 r
.37058 .66257 m .36922 .6644 L .3683 .66139 L F
.377 .446 .805 r
.37058 .66257 m .37183 .66572 L .36922 .6644 L F
.406 .44 .783 r
.36922 .6644 m .37183 .66572 L .37033 .66588 L F
.81 .854 .882 r
.69223 .64411 m .69339 .64515 L .69538 .64291 L F
.607 .559 .774 r
.51037 .74741 m .51108 .74971 L .50925 .75034 L F
.803 .681 .73 r
.51108 .74971 m .50859 .75197 L .50925 .75034 L F
.086 0 0 r
.32434 .73304 m .32255 .73388 L .32307 .73296 L F
.614 .676 .886 r
.51659 .7623 m .51756 .76409 L .51845 .762 L F
.622 .686 .889 r
.51845 .762 m .51756 .76409 L .5203 .76339 L F
.608 .673 .887 r
.51432 .7627 m .51756 .76409 L .51659 .7623 L F
.716 .65 .782 r
.33576 .82846 m .33663 .82771 L .33542 .82769 L F
.721 .723 .851 r
.70014 .58852 m .6982 .59086 L .69698 .58834 L F
.613 .556 .767 r
.70014 .58852 m .70065 .59042 L .6982 .59086 L F
.977 .704 .446 r
.71333 .73874 m .71209 .73539 L .71334 .73637 L F
.689 .937 .965 r
.71603 .62798 m .71219 .62913 L .71435 .62739 L F
0 0 .331 r
.71603 .62798 m .71602 .62837 L .71694 .62804 L F
.718 .541 0 r
.71615 .62981 m .71618 .62998 L .71603 .62798 L F
.71615 .62981 m .71603 .62798 L .71694 .62804 L F
.541 .398 .635 r
.70043 .59998 m .70278 .60124 L .70184 .60007 L F
0 0 0 r
.39977 .79459 m .40363 .7932 L .40177 .79405 L F
.004 0 0 r
.40363 .7932 m .40361 .7935 L .40177 .79405 L F
.40363 .7932 m .40579 .79289 L .40361 .7935 L F
0 0 0 r
.4556 .73633 m .45451 .73661 L .45219 .73693 L F
.315 .8 .76 r
.45779 .73555 m .4565 .73586 L .4556 .73633 L F
.317 .799 .742 r
.4565 .73586 m .45451 .73661 L .4556 .73633 L F
.714 .667 .803 r
.5 .76065 m .50345 .76155 L .50266 .75992 L F
.633 .593 .79 r
.50266 .75992 m .50345 .76155 L .50552 .76068 L F
.423 .279 .58 r
.35786 .76327 m .35961 .76297 L .35977 .76056 L F
.553 .384 .606 r
.35786 .76327 m .36001 .76531 L .35961 .76297 L F
.35786 .76327 m .35792 .76567 L .36001 .76531 L F
.65 .369 .48 r
.51095 .77419 m .51343 .7759 L .51422 .77367 L F
.6 .319 .462 r
.51343 .7759 m .51672 .7737 L .51422 .77367 L F
0 0 0 r
.63044 .65278 m .62775 .65534 L .63005 .65291 L F
.632 .907 .607 r
.6314 .65151 m .63276 .65033 L .63044 .65278 L F
.646 .928 .654 r
.63005 .65291 m .6314 .65151 L .63044 .65278 L F
.734 .644 .759 r
.70319 .71732 m .70643 .71762 L .70528 .71458 L F
.655 .593 .774 r
.50879 .76317 m .5099 .76639 L .51215 .76577 L F
.481 .338 .609 r
.72691 .62053 m .72695 .62291 L .72495 .62351 L F
.079 0 .033 r
.72695 .62291 m .72459 .62511 L .72495 .62351 L F
.049 0 .104 r
.62436 .61251 m .62619 .61172 L .62664 .60993 L F
.164 0 .364 r
.62584 .61374 m .62436 .61251 L .62407 .61442 L F
.62584 .61374 m .62619 .61172 L .62436 .61251 L F
.698 .913 .969 r
.70015 .64371 m .70344 .64188 L .70052 .64351 L F
.551 .321 .52 r
.36555 .74716 m .36743 .74904 L .36785 .7469 L F
.36555 .74716 m .36528 .74942 L .36743 .74904 L F
.56 .489 .732 r
.65134 .62057 m .64927 .62304 L .64861 .6214 L F
.65134 .62057 m .65132 .62266 L .64927 .62304 L F
.614 .507 .708 r
.65132 .62266 m .64891 .62471 L .64927 .62304 L F
.599 .313 .454 r
.59776 .68216 m .5969 .68474 L .59477 .68479 L F
.604 .318 .456 r
.60026 .68404 m .59776 .68216 L .60001 .68206 L F
.60026 .68404 m .5969 .68474 L .59776 .68216 L F
.187 .213 .656 r
.71071 .71219 m .71107 .70912 L .70997 .70882 L F
.71071 .71219 m .71217 .71113 L .71107 .70912 L F
.917 .963 .65 r
.71102 .71442 m .71217 .71113 L .71071 .71219 L F
0 .331 .668 r
.33906 .65158 m .34076 .65224 L .34217 .65282 L F
.386 .788 .985 r
.34076 .65224 m .3442 .6526 L .34217 .65282 L F
.771 .576 .635 r
.7222 .74134 m .72523 .74356 L .72553 .7404 L F
.244 .121 .506 r
.72553 .7404 m .72725 .74035 L .72729 .73975 L F
.657 .53 .698 r
.72595 .74299 m .72578 .74422 L .72813 .74186 L F
.244 .121 .506 r
.72553 .7404 m .72523 .74356 L .72624 .74195 L F
.437 .449 .774 r
.7222 .74134 m .7239 .74405 L .72523 .74356 L F
.657 .53 .698 r
.7239 .74405 m .7256 .7442 L .72595 .74299 L F
.7256 .7442 m .72578 .74422 L .72595 .74299 L F
.244 .121 .506 r
.7267 .74037 m .72624 .74195 L .72725 .74035 L F
.72553 .7404 m .72624 .74195 L .7267 .74037 L F
.796 .481 .456 r
.50795 .77562 m .51095 .77419 L .50779 .77354 L F
.50795 .77562 m .5111 .77614 L .51095 .77419 L F
.65 .369 .48 r
.51095 .77419 m .5111 .77614 L .51343 .7759 L F
.844 .691 .692 r
.59458 .66659 m .59438 .66878 L .59425 .66855 L F
.742 .873 .941 r
.7055 .59218 m .70655 .59352 L .70931 .59159 L F
.547 .392 .622 r
.38482 .76103 m .38529 .76361 L .38305 .76367 L F
.642 .575 .765 r
.38529 .76361 m .38333 .76569 L .38305 .76367 L F
.286 0 0 r
.46135 .76784 m .46347 .76752 L .46488 .76611 L F
.104 0 0 r
.46488 .76611 m .4655 .76687 L .46704 .76603 L F
.46488 .76611 m .46347 .76752 L .4655 .76687 L F
.176 0 0 r
.30654 .65766 m .30849 .65711 L .30935 .65618 L F
.461 .105 .275 r
.30849 .65711 m .31127 .65554 L .30935 .65618 L F
.472 .538 .843 r
.3675 .65946 m .36642 .66149 L .36503 .65851 L F
.502 .575 .862 r
.3675 .65946 m .3683 .66139 L .36642 .66149 L F
.841 .86 .857 r
.3461 .80592 m .3475 .80756 L .34621 .8089 L F
.807 .366 0 r
.34522 .8082 m .34621 .8089 L .34729 .81115 L F
.008 .311 .801 r
.34621 .8089 m .34822 .81092 L .34729 .81115 L F
.902 .938 .825 r
.69326 .70738 m .69169 .70949 L .69088 .70888 L F
.843 .381 .087 r
.69169 .70949 m .69243 .71186 L .69088 .70888 L F
.543 .416 .657 r
.36176 .75509 m .36372 .75468 L .36345 .75216 L F
.521 .352 .593 r
.36163 .75796 m .36372 .75468 L .36176 .75509 L F
.882 .791 .755 r
.72813 .74186 m .73068 .7417 L .72826 .73993 L F
.72813 .74186 m .7289 .74457 L .73068 .7417 L F
.571 .827 .461 r
.63276 .65033 m .63385 .64893 L .63493 .64763 L F
.319 0 .119 r
.29861 .66318 m .30152 .66129 L .29935 .662 L F
.197 0 0 r
.33245 .6752 m .33201 .67563 L .33024 .67593 L F
.651 .154 .056 r
.49258 .77658 m .49089 .77673 L .48942 .77605 L F
.502 0 0 r
.49456 .77784 m .49089 .77673 L .49258 .77658 L F
.462 .566 .875 r
.51326 .75717 m .51418 .75473 L .51193 .75463 L F
.51326 .75717 m .51528 .75722 L .51418 .75473 L F
.542 .415 .656 r
.51339 .75973 m .51528 .75722 L .51326 .75717 L F
.527 .288 .496 r
.64465 .62901 m .64246 .63138 L .64238 .62888 L F
.64465 .62901 m .64463 .63095 L .64246 .63138 L F
.731 .534 .625 r
.64817 .62871 m .64463 .63095 L .64465 .62901 L F
.632 .698 .893 r
.40311 .7813 m .4012 .78217 L .40001 .7791 L F
.287 0 .157 r
.6328 .66369 m .63414 .66485 L .63247 .66567 L F
.6328 .66369 m .63476 .66301 L .63414 .66485 L F
.803 .681 .73 r
.51108 .74971 m .51199 .7528 L .50859 .75197 L F
.982 .696 .334 r
.51199 .7528 m .51092 .75243 L .50859 .75197 L F
.51199 .7528 m .51193 .75463 L .51092 .75243 L F
.64 .587 .78 r
.51406 .74987 m .51199 .7528 L .51108 .74971 L F
0 0 0 r
.40979 .7918 m .40884 .79198 L .41019 .79173 L F
.40979 .7918 m .40774 .7923 L .40884 .79198 L F
.645 .678 .867 r
.66316 .63977 m .66461 .64221 L .66675 .64132 L F
.855 .736 .731 r
.39275 .7973 m .3905 .79826 L .38966 .79793 L F
.277 .758 .651 r
.39467 .79649 m .3905 .79826 L .39275 .7973 L F
.858 .69 .672 r
.66146 .62431 m .65919 .62469 L .65991 .623 L F
.66146 .62431 m .66142 .62666 L .65919 .62469 L F
0 0 0 r
.63493 .64763 m .63613 .64639 L .63706 .64484 L F
.63385 .64893 m .63613 .64639 L .63493 .64763 L F
.31198 .68111 m .31017 .68186 L .30831 .68233 L F
.009 0 0 r
.31405 .68077 m .31198 .68111 L .31417 .68054 L F
.31405 .68077 m .31017 .68186 L .31198 .68111 L F
.241 .743 .898 r
.44989 .72583 m .45204 .72563 L .45325 .72588 L F
.346 .794 .954 r
.45204 .72563 m .45531 .72573 L .45325 .72588 L F
.807 .741 .79 r
.58543 .6663 m .58251 .666 L .58466 .66333 L F
.819 .704 .738 r
.58543 .6663 m .58359 .66906 L .58251 .666 L F
.707 .545 .666 r
.58886 .66812 m .58359 .66906 L .58543 .6663 L F
.808 .742 .79 r
.58761 .66349 m .58543 .6663 L .58466 .66333 L F
.706 .583 .715 r
.58761 .66349 m .58946 .6665 L .58543 .6663 L F
.578 .404 .61 r
.58946 .6665 m .58886 .66812 L .58543 .6663 L F
.37 0 .012 r
.42958 .7762 m .43176 .77602 L .43329 .77453 L F
.256 0 0 r
.43329 .77453 m .43383 .7756 L .43506 .77349 L F
.43329 .77453 m .43176 .77602 L .43383 .7756 L F
.634 .583 .78 r
.38588 .77622 m .38244 .77374 L .38478 .77327 L F
.569 .563 .807 r
.36442 .65635 m .36314 .65909 L .362 .65609 L F
.564 .557 .805 r
.36442 .65635 m .36503 .65851 L .36314 .65909 L F
.344 .22 .563 r
.39778 .70627 m .39599 .70905 L .39588 .70664 L F
.39778 .70627 m .39792 .70871 L .39599 .70905 L F
.29 .753 .948 r
.39599 .70905 m .39792 .70871 L .39493 .70855 L F
.578 .404 .61 r
.58946 .6665 m .58921 .6689 L .58886 .66812 L F
.727 .536 .634 r
.59425 .66855 m .58921 .6689 L .58946 .6665 L F
.8 .482 .451 r
.50688 .77991 m .50404 .78099 L .50345 .77955 L F
.50688 .77991 m .50696 .7815 L .50404 .78099 L F
.902 .938 .825 r
.69326 .70738 m .69088 .70888 L .69229 .70656 L F
0 0 0 r
.63706 .64484 m .6388 .64407 L .6395 .64439 L F
.63706 .64484 m .63613 .64639 L .6388 .64407 L F
.616 .576 .787 r
.66975 .59028 m .66873 .59266 L .66788 .59326 L F
.389 0 0 r
.65513 .6004 m .65548 .60047 L .65422 .60075 L F
0 0 .184 r
.62664 .60993 m .62819 .60891 L .62828 .60705 L F
0 0 .187 r
.62764 .61077 m .62664 .60993 L .62619 .61172 L F
.62764 .61077 m .62819 .60891 L .62664 .60993 L F
.634 .629 .828 r
.49531 .73896 m .49184 .73628 L .49419 .73583 L F
.625 .588 .792 r
.49756 .73845 m .49531 .73896 L .49419 .73583 L F
.434 .3 .598 r
.35482 .68528 m .35663 .68711 L .35674 .6848 L F
.35482 .68528 m .35496 .68769 L .35663 .68711 L F
.411 .727 .99 r
.69372 .59688 m .69513 .5958 L .69279 .59659 L F
.69372 .59688 m .69656 .59698 L .69513 .5958 L F
.558 .628 .877 r
.48486 .88081 m .48701 .8821 L .48724 .88081 L F
.301 .374 .771 r
.48724 .88081 m .48701 .8821 L .48828 .88058 L F
.444 .586 .9 r
.48701 .8821 m .48972 .88247 L .48828 .88058 L F
.618 .776 .957 r
.34554 .67341 m .34686 .67458 L .34895 .67395 L F
.697 .488 .601 r
.59423 .67106 m .59425 .66855 L .59438 .66878 L F
0 0 0 r
.52641 .77296 m .52486 .77347 L .52482 .77404 L F
.257 .705 .957 r
.46113 .73624 m .45983 .73561 L .45779 .73555 L F
0 .48 .703 r
.46317 .73616 m .45983 .73561 L .46113 .73624 L F
.187 .052 .453 r
.39095 .75445 m .39095 .75611 L .38933 .7556 L F
.613 .468 .66 r
.39095 .75611 m .38856 .75931 L .38933 .7556 L F
.39 0 .016 r
.4375 .78173 m .43824 .78311 L .43616 .78323 L F
.4375 .78173 m .4396 .78166 L .43824 .78311 L F
0 0 0 r
.31814 .7364 m .31427 .73803 L .31578 .73746 L F
.831 .924 .896 r
.70528 .62705 m .70447 .62935 L .70356 .62858 L F
.70528 .62705 m .70705 .62707 L .70447 .62935 L F
.345 .159 .48 r
.34141 .70151 m .34305 .70091 L .3434 .69834 L F
.335 .261 .624 r
.34141 .70151 m .34313 .70321 L .34305 .70091 L F
.34141 .70151 m .34172 .70389 L .34313 .70321 L F
.681 .444 .555 r
.61332 .67722 m .6134 .67939 L .61007 .67956 L F
.676 .442 .56 r
.61584 .67736 m .6134 .67939 L .61332 .67722 L F
0 0 .348 r
.39367 .70757 m .39372 .71024 L .39428 .70825 L F
.677 .859 .969 r
.39428 .70825 m .39372 .71024 L .39493 .70855 L F
.623 .655 .86 r
.37856 .66994 m .37689 .67117 L .37532 .66822 L F
.188 .118 .541 r
.65505 .58582 m .65537 .58857 L .65574 .5869 L F
0 0 0 r
.65692 .5849 m .65505 .58582 L .65457 .58656 L F
.906 .815 .746 r
.6601 .59406 m .65883 .59577 L .65853 .59297 L F
.372 .124 .402 r
.43775 .74047 m .43616 .73931 L .43952 .73789 L F
.685 .33 .367 r
.44113 .74025 m .43952 .73789 L .44121 .73835 L F
.44113 .74025 m .43775 .74047 L .43952 .73789 L F
.498 .058 .133 r
.46931 .77401 m .46802 .77564 L .46583 .77564 L F
.497 .03 .076 r
.47149 .77438 m .46802 .77564 L .46931 .77401 L F
.242 0 .019 r
.33704 .72461 m .33501 .72517 L .33792 .72342 L F
.336 0 .075 r
.33889 .72419 m .33704 .72461 L .33792 .72342 L F
.317 0 .108 r
.34011 .72285 m .33889 .72419 L .33792 .72342 L F
.735 .54 .629 r
.61416 .65532 m .61604 .65298 L .61301 .65249 L F
.61416 .65532 m .6162 .65526 L .61604 .65298 L F
.619 .556 .761 r
.34394 .80556 m .34077 .80329 L .34332 .80385 L F
.687 .559 .704 r
.34332 .80385 m .34469 .80747 L .34696 .80512 L F
.567 .328 .512 r
.34332 .80385 m .3461 .80592 L .34394 .80556 L F
.687 .559 .704 r
.34332 .80385 m .34696 .80512 L .3461 .80592 L F
.876 .764 .735 r
.58824 .66142 m .58761 .66349 L .58673 .66053 L F
.611 .828 .983 r
.73204 .73558 m .73475 .73601 L .73438 .73315 L F
.407 .53 .869 r
.34817 .80521 m .3475 .80756 L .3461 .80592 L F
.959 .687 .478 r
.65548 .60047 m .65416 .60295 L .65422 .60075 L F
.65548 .60047 m .65574 .60467 L .65416 .60295 L F
.218 0 .107 r
.34338 .7212 m .34266 .7199 L .34434 .71977 L F
.34338 .7212 m .34153 .7219 L .34266 .7199 L F
0 0 .348 r
.39367 .70757 m .39428 .70825 L .39588 .70664 L F
.313 0 .007 r
.39428 .70825 m .39778 .70627 L .39588 .70664 L F
.525 .678 .934 r
.72987 .73574 m .73152 .7342 L .72859 .73455 L F
.72987 .73574 m .73204 .73558 L .73152 .7342 L F
0 0 .347 r
.67856 .60663 m .67874 .60981 L .6784 .61011 L F
0 0 0 r
.67841 .61075 m .67833 .61223 L .6784 .61011 L F
.603 .461 .66 r
.35383 .77118 m .35616 .7709 L .35589 .76838 L F
.607 .443 .634 r
.35391 .77357 m .35616 .7709 L .35383 .77118 L F
.811 .733 .778 r
.58761 .66349 m .58466 .66333 L .58673 .66053 L F
.401 0 0 r
.43763 .72383 m .44108 .72369 L .43894 .72438 L F
.66 .278 .309 r
.72039 .73514 m .72092 .73363 L .72024 .7331 L F
.72039 .73514 m .72357 .73533 L .72092 .73363 L F
0 0 .538 r
.73045 .71486 m .7323 .71708 L .73238 .71743 L F
0 0 .469 r
.73352 .7189 m .73238 .71743 L .7323 .71708 L F
.73352 .7189 m .7329 .72001 L .73238 .71743 L F
.548 .313 .511 r
.34363 .79242 m .34568 .79271 L .34403 .79008 L F
.599 .434 .629 r
.34403 .79008 m .34626 .78996 L .34618 .78735 L F
.575 .321 .494 r
.34403 .79008 m .34568 .79271 L .34626 .78996 L F
.597 .856 .507 r
.65086 .61391 m .64949 .61557 L .65037 .61435 L F
.705 .622 .762 r
.65213 .61238 m .65319 .61548 L .64949 .61557 L F
0 0 .476 r
.64949 .61557 m .65081 .61542 L .65037 .61435 L F
.874 .447 .034 r
.65037 .61435 m .6502 .61531 L .64996 .61472 L F
.65037 .61435 m .64996 .61472 L .64943 .61346 L F
.597 .856 .507 r
.65213 .61238 m .65086 .61391 L .65037 .61435 L F
.771 .412 .377 r
.6532 .61775 m .64949 .61557 L .65319 .61548 L F
.818 .94 .577 r
.64971 .61789 m .65012 .61739 L .64884 .61984 L F
.771 .412 .377 r
.65058 .61683 m .65012 .61739 L .64984 .61658 L F
.6532 .61775 m .64984 .61658 L .64992 .61582 L F
.64992 .61582 m .64984 .61658 L .64949 .61557 L F
0 0 .476 r
.64949 .61557 m .65012 .61739 L .65081 .61542 L F
.818 .94 .577 r
.65081 .61542 m .65012 .61739 L .64971 .61789 L F
.771 .412 .377 r
.6532 .61775 m .65012 .61739 L .65058 .61683 L F
.679 .48 .609 r
.6532 .61775 m .64884 .61984 L .65012 .61739 L F
.818 .94 .577 r
.65081 .61542 m .64971 .61789 L .64976 .61891 L F
.64971 .61789 m .64884 .61984 L .64959 .61909 L F
.64971 .61789 m .64959 .61909 L .64976 .61891 L F
.498 .697 .958 r
.67833 .58414 m .6799 .58626 L .67791 .58565 L F
.587 .742 .95 r
.68059 .58366 m .6799 .58626 L .67833 .58414 L F
.503 .481 .766 r
.67718 .58776 m .67785 .58566 L .67791 .58565 L F
.67785 .58566 m .67833 .58414 L .678 .58533 L F
.67785 .58566 m .678 .58533 L .67791 .58565 L F
.67718 .58776 m .67934 .58829 L .6787 .58564 L F
.362 .818 .711 r
.6789 .58562 m .678 .58566 L .67805 .58558 L F
.581 .533 .766 r
.6787 .58564 m .67934 .58829 L .67983 .58553 L F
.362 .818 .711 r
.67906 .58563 m .6787 .58564 L .6789 .58562 L F
.6787 .58564 m .678 .58566 L .6789 .58562 L F
0 0 0 r
.68177 .58509 m .6799 .58626 L .6802 .58513 L F
.581 .533 .766 r
.67983 .58553 m .67979 .58577 L .67999 .58568 L F
.503 .481 .766 r
.67718 .58776 m .6787 .58564 L .67785 .58566 L F
.581 .533 .766 r
.68032 .58551 m .68158 .58715 L .68096 .58549 L F
.67983 .58553 m .67999 .58568 L .68032 .58551 L F
.67999 .58568 m .68158 .58715 L .68032 .58551 L F
.362 .818 .711 r
.68024 .58552 m .67704 .5869 L .67748 .58632 L F
.68032 .58551 m .67704 .5869 L .68024 .58552 L F
.68032 .58551 m .68003 .5855 L .67704 .5869 L F
.68047 .58545 m .68032 .58551 L .68024 .58552 L F
.6804 .58548 m .68039 .58548 L .68032 .58551 L F
.68047 .58545 m .68046 .58545 L .6804 .58548 L F
0 0 0 r
.68137 .58461 m .6802 .58513 L .68059 .58366 L F
.523 .579 .853 r
.67932 .58492 m .68047 .58545 L .67805 .58558 L F
.68051 .5843 m .68048 .58526 L .67932 .58492 L F
.68048 .58526 m .68047 .58545 L .67932 .58492 L F
.362 .818 .711 r
.67932 .58551 m .67906 .58563 L .67805 .58558 L F
.581 .533 .766 r
.67909 .58485 m .6787 .58564 L .67983 .58553 L F
.523 .579 .853 r
.68051 .5843 m .67805 .58558 L .67833 .58414 L F
.581 .533 .766 r
.67833 .58414 m .67846 .58466 L .67909 .58485 L F
.67846 .58466 m .6787 .58564 L .67909 .58485 L F
.67983 .58553 m .68032 .58551 L .68051 .5843 L F
.362 .818 .711 r
.68046 .58545 m .68044 .58546 L .6804 .58548 L F
.68044 .58546 m .68039 .58548 L .6804 .58548 L F
.581 .533 .766 r
.68032 .58551 m .68096 .58549 L .68087 .58524 L F
0 0 0 r
.68177 .58509 m .6802 .58513 L .68137 .58461 L F
.581 .533 .766 r
.68057 .58539 m .68087 .58524 L .68079 .58504 L F
.68057 .5853 m .68079 .58504 L .68051 .5843 L F
.68057 .58539 m .68079 .58504 L .68057 .5853 L F
.289 .715 .97 r
.68118 .5839 m .68177 .58509 L .68059 .58366 L F
.642 .916 .623 r
.68057 .5853 m .68047 .58545 L .68051 .5843 L F
.68057 .5853 m .68044 .58546 L .68047 .58545 L F
.581 .533 .766 r
.68032 .58551 m .68057 .58539 L .68051 .5843 L F
.642 .916 .623 r
.68061 .58525 m .68044 .58546 L .68057 .5853 L F
.618 .586 .796 r
.68051 .5843 m .68316 .58489 L .68102 .58416 L F
.642 .916 .623 r
.68061 .58525 m .68057 .5853 L .68057 .58529 L F
.618 .586 .796 r
.68051 .5843 m .68109 .5847 L .6813 .58447 L F
.68109 .5847 m .68158 .58715 L .68372 .58655 L F
.68051 .5843 m .68079 .58504 L .68109 .5847 L F
.68079 .58504 m .68158 .58715 L .68109 .5847 L F
.642 .916 .623 r
.681 .58465 m .68003 .5855 L .68042 .58546 L F
.68051 .58536 m .68042 .58546 L .68044 .58546 L F
.414 .779 .995 r
.68897 .58515 m .68184 .58401 L .68524 .5856 L F
.68897 .58515 m .68524 .5856 L .68555 .5857 L F
.867 .916 .86 r
.68733 .58093 m .68906 .58357 L .68556 .58567 L F
.68554 .58558 m .68556 .58567 L .68549 .58571 L F
.68733 .58093 m .68556 .58567 L .68554 .58558 L F
.414 .779 .995 r
.68184 .58401 m .68169 .58412 L .68549 .58571 L F
.437 .568 .888 r
.68274 .58389 m .68362 .58448 L .68168 .58402 L F
.68204 .5839 m .68168 .58402 L .68118 .5839 L F
.68274 .58389 m .68168 .58402 L .68204 .5839 L F
.414 .779 .995 r
.68184 .58401 m .68118 .5839 L .68169 .58412 L F
.437 .568 .888 r
.68362 .58448 m .6851 .58555 L .68407 .58512 L F
.68331 .58441 m .68407 .58512 L .68118 .5839 L F
.68362 .58448 m .68407 .58512 L .68331 .58441 L F
.624 .616 .823 r
.6821 .58083 m .68275 .58367 L .68258 .58372 L F
.422 .71 .983 r
.68275 .58367 m .68118 .5839 L .68059 .58366 L F
.68275 .58367 m .68059 .58366 L .68051 .5843 L F
.624 .616 .823 r
.68132 .58254 m .68258 .58372 L .68051 .5843 L F
.6821 .58083 m .68258 .58372 L .68132 .58254 L F
.642 .916 .623 r
.6816 .58377 m .68051 .5843 L .68258 .58372 L F
.437 .568 .888 r
.68282 .58389 m .68118 .5839 L .68275 .58367 L F
.642 .916 .623 r
.68271 .58367 m .68258 .58372 L .68275 .58367 L F
.6816 .58377 m .68258 .58372 L .68271 .58367 L F
.618 .586 .796 r
.68102 .58416 m .68309 .58486 L .68282 .58389 L F
.68258 .58372 m .68282 .58389 L .68275 .58367 L F
.68102 .58416 m .68282 .58389 L .68258 .58372 L F
.437 .568 .888 r
.68362 .58448 m .68549 .58571 L .6851 .58555 L F
.414 .779 .995 r
.68555 .5857 m .68524 .5856 L .68549 .58571 L F
.437 .568 .888 r
.68348 .58398 m .68549 .58571 L .68274 .58389 L F
.68529 .58419 m .68544 .58536 L .68348 .58398 L F
.68544 .58536 m .68549 .58571 L .68348 .58398 L F
.292 .53 .909 r
.68335 .58389 m .68533 .58477 L .68529 .5846 L F
.68275 .58367 m .68348 .58398 L .68335 .58389 L F
.68348 .58398 m .68533 .58477 L .68335 .58389 L F
.481 .502 .802 r
.68275 .58367 m .68484 .58583 L .68515 .58469 L F
.437 .568 .888 r
.68526 .58388 m .68529 .58419 L .68348 .58398 L F
.68526 .58388 m .68348 .58398 L .68335 .58389 L F
.68526 .58388 m .68335 .58389 L .68275 .58367 L F
.292 .53 .909 r
.68302 .58366 m .68508 .58453 L .68467 .58358 L F
.68275 .58367 m .68335 .58389 L .68302 .58366 L F
.68335 .58389 m .68508 .58453 L .68302 .58366 L F
.437 .568 .888 r
.68335 .58389 m .68348 .58398 L .68274 .58389 L F
.481 .502 .802 r
.683 .58392 m .68372 .58655 L .68484 .58583 L F
.68275 .58367 m .68283 .58391 L .683 .58392 L F
.68283 .58391 m .68372 .58655 L .683 .58392 L F
.867 .916 .86 r
.68733 .58093 m .68554 .58558 L .6853 .58416 L F
.68554 .58558 m .68544 .58536 L .68526 .58388 L F
.481 .502 .802 r
.68515 .58469 m .68484 .58583 L .68602 .58506 L F
.867 .916 .86 r
.68546 .58358 m .6853 .58416 L .68526 .58388 L F
.68733 .58093 m .6853 .58416 L .68546 .58358 L F
.68554 .58558 m .68549 .58571 L .68544 .58536 L F
.292 .53 .909 r
.68467 .58358 m .68597 .58485 L .68566 .58353 L F
.68508 .58453 m .68597 .58485 L .68467 .58358 L F
.68529 .5846 m .68602 .58506 L .68597 .58485 L F
.68533 .58477 m .68602 .58506 L .68529 .5846 L F
.437 .568 .888 r
.68335 .58389 m .68282 .58389 L .68275 .58367 L F
.618 .586 .796 r
.68309 .58486 m .68316 .58489 L .68275 .58367 L F
.642 .916 .623 r
.6816 .58377 m .68057 .58527 L .68051 .5843 L F
.681 .58465 m .68042 .58546 L .68051 .58536 L F
.6816 .58377 m .68051 .58536 L .68061 .58525 L F
.68051 .58536 m .68044 .58546 L .68061 .58525 L F
.618 .586 .796 r
.6813 .58447 m .68372 .58655 L .68316 .58489 L F
.68109 .5847 m .68372 .58655 L .6813 .58447 L F
.642 .916 .623 r
.6816 .58377 m .68038 .58512 L .681 .58465 L F
.68038 .58512 m .68003 .5855 L .681 .58465 L F
.362 .818 .711 r
.68047 .58545 m .67748 .58632 L .67932 .58551 L F
.68044 .58546 m .68003 .5855 L .68039 .58548 L F
.68039 .58548 m .68003 .5855 L .68032 .58551 L F
.581 .533 .766 r
.67833 .58414 m .67983 .58553 L .68051 .5843 L F
.67999 .58568 m .67934 .58829 L .68158 .58715 L F
.67979 .58577 m .67934 .58829 L .67999 .58568 L F
.503 .481 .766 r
.67785 .58566 m .6787 .58564 L .67833 .58414 L F
.362 .818 .711 r
.67906 .58563 m .67756 .58628 L .678 .58566 L F
.67756 .58628 m .67748 .58632 L .67764 .58611 L F
.67756 .58628 m .67764 .58611 L .67805 .58558 L F
.661 .553 .722 r
.49369 .87429 m .49163 .87608 L .49109 .87292 L F
.582 .487 .712 r
.38749 .7738 m .38588 .77622 L .38478 .77327 L F
.38749 .7738 m .38806 .77582 L .38588 .77622 L F
.833 .661 .669 r
.66997 .631 m .67123 .63409 L .67174 .63183 L F
.68 .905 .975 r
.67123 .60327 m .67259 .60374 L .66967 .60405 L F
0 .032 .589 r
.67214 .60619 m .66967 .60405 L .67259 .60374 L F
.809 .91 .909 r
.67511 .60172 m .67259 .60374 L .67123 .60327 L F
.493 .866 .982 r
.37001 .80603 m .37014 .805 L .36797 .80535 L F
.37001 .80603 m .372 .8054 L .37014 .805 L F
.509 .886 .97 r
.38709 .81119 m .38528 .81186 L .38376 .81155 L F
.38376 .81155 m .38528 .81186 L .38709 .81119 L F
.641 .618 .811 r
.65437 .61198 m .65319 .61548 L .65213 .61238 L F
.65437 .61198 m .65547 .615 L .65319 .61548 L F
.611 .459 .652 r
.65547 .615 m .6532 .61775 L .65319 .61548 L F
.553 .703 .939 r
.69394 .58737 m .6923 .58821 L .69023 .5856 L F
.656 .315 .383 r
.33969 .7955 m .34144 .79727 L .34249 .79547 L F
0 0 0 r
.34249 .79547 m .34218 .79599 L .3423 .79588 L F
.62 .227 .276 r
.34249 .79547 m .3423 .79588 L .33969 .7955 L F
.65 .53 .704 r
.33969 .7955 m .3423 .79588 L .34161 .79288 L F
.62 .227 .276 r
.34249 .79547 m .34257 .79592 L .3423 .79588 L F
.65 .53 .704 r
.3423 .79588 m .34257 .79592 L .34249 .79569 L F
.3423 .79588 m .34249 .79569 L .34161 .79288 L F
0 0 0 r
.3423 .79588 m .34144 .79727 L .34187 .79682 L F
.34218 .79599 m .34144 .79727 L .3423 .79588 L F
.113 0 .309 r
.34378 .79479 m .34257 .79592 L .34249 .79547 L F
0 0 0 r
.34249 .79547 m .34234 .7958 L .34378 .79479 L F
.449 .41 .722 r
.34161 .79288 m .34249 .79569 L .34378 .79479 L F
.34249 .79569 m .34257 .79592 L .34378 .79479 L F
0 0 0 r
.34234 .7958 m .34187 .79682 L .34378 .79479 L F
.558 .673 .915 r
.63702 .62017 m .63376 .61845 L .63431 .61901 L F
.436 0 0 r
.38146 .66981 m .38407 .66869 L .38201 .66911 L F
0 .203 .724 r
.38142 .66894 m .38235 .67025 L .38146 .66981 L F
.436 0 0 r
.38146 .66981 m .38249 .67046 L .38398 .67098 L F
0 .203 .724 r
.38235 .67025 m .38249 .67046 L .38146 .66981 L F
.328 0 0 r
.3807 .66943 m .38146 .66981 L .38201 .66911 L F
.37856 .66994 m .38146 .66981 L .3807 .66943 L F
.727 .518 .607 r
.59425 .66855 m .58916 .67127 L .58921 .6689 L F
.59425 .66855 m .59349 .6722 L .58916 .67127 L F
.697 .488 .601 r
.59423 .67106 m .59349 .6722 L .59425 .66855 L F
.563 .589 .837 r
.35889 .68208 m .35697 .68258 L .35561 .67952 L F
.474 .27 .522 r
.35697 .68258 m .35674 .6848 L .35889 .68208 L F
.35697 .68258 m .35674 .6848 L .35889 .68208 L F
.423 .825 .617 r
.64254 .65785 m .64213 .65809 L .63931 .65998 L F
.523 .9 .723 r
.64531 .65603 m .64375 .65676 L .64254 .65785 L F
.498 .859 .615 r
.64254 .65785 m .64375 .65676 L .64213 .65809 L F
.717 .586 .708 r
.50258 .76918 m .5023 .77115 L .50449 .76852 L F
.681 .532 .677 r
.50449 .76852 m .5023 .77115 L .50438 .77094 L F
.817 .409 .273 r
.70912 .69841 m .70974 .69999 L .7107 .69851 L F
.732 .298 .219 r
.70974 .69999 m .71298 .70061 L .7107 .69851 L F
.989 .744 .47 r
.67544 .63096 m .67651 .63398 L .67545 .63384 L F
.623 .396 .553 r
.66961 .61548 m .66985 .61754 L .6703 .61705 L F
.795 .704 .764 r
.66142 .62666 m .65821 .62611 L .65919 .62469 L F
.66142 .62666 m .65925 .62888 L .65821 .62611 L F
.211 0 0 r
.43723 .77342 m .43935 .77306 L .44096 .77185 L F
.298 0 0 r
.43935 .77306 m .4429 .77119 L .44096 .77185 L F
.45 .294 .577 r
.38666 .66404 m .38837 .66557 L .38838 .66324 L F
.38666 .66404 m .38837 .66557 L .38838 .66324 L F
0 0 .03 r
.6282 .6689 m .62752 .67075 L .62592 .67167 L F
0 0 .018 r
.6282 .6689 m .62975 .668 L .62752 .67075 L F
.501 .213 .409 r
.36969 .74399 m .37252 .74185 L .36978 .74168 L F
.699 .634 .78 r
.49923 .75368 m .49979 .74944 L .49804 .75203 L F
.49923 .75368 m .5009 .75256 L .49979 .74944 L F
.41 .091 .31 r
.30654 .65766 m .30755 .65981 L .30849 .65711 L F
.30654 .65766 m .30555 .66034 L .30755 .65981 L F
.53 .002 0 r
.41961 .7423 m .41914 .74308 L .41702 .74208 L F
.302 0 0 r
.4214 .74304 m .41914 .74308 L .41961 .7423 L F
.61 .586 .802 r
.49347 .74637 m .49466 .74974 L .49621 .74726 L F
.609 .585 .801 r
.49466 .74974 m .49797 .75072 L .49621 .74726 L F
.095 0 .212 r
.62828 .60705 m .62819 .60891 L .63027 .60612 L F
.501 .115 .241 r
.30402 .68397 m .30549 .68482 L .30349 .68479 L F
.6 .517 .732 r
.64891 .62471 m .65249 .62629 L .65012 .62843 L F
.684 .665 .825 r
.65249 .62629 m .65316 .62846 L .65012 .62843 L F
.558 .363 .572 r
.65316 .62846 m .65095 .63139 L .65012 .62843 L F
.705 .514 .627 r
.65012 .62843 m .64828 .63127 L .64817 .62871 L F
.757 .583 .661 r
.65012 .62843 m .65095 .63139 L .64828 .63127 L F
.804 .574 .59 r
.6162 .65526 m .61772 .658 L .61779 .65568 L F
.755 .532 .594 r
.61779 .65568 m .61772 .658 L .61986 .65802 L F
0 0 0 r
.71694 .62804 m .71611 .62832 L .71949 .6262 L F
.71694 .62804 m .71949 .6262 L .71835 .62633 L F
0 0 .08 r
.71735 .62791 m .71694 .62804 L .71835 .62633 L F
.71615 .62981 m .71694 .62804 L .71735 .62791 L F
0 0 0 r
.71694 .62804 m .71602 .62837 L .71611 .62832 L F
.704 .68 .824 r
.49797 .75072 m .49804 .75203 L .49979 .74944 L F
.573 .245 .375 r
.68422 .63396 m .68746 .63377 L .688 .63185 L F
.093 0 .262 r
.68949 .62946 m .688 .63185 L .68944 .63099 L F
.765 .669 .756 r
.68687 .62888 m .688 .63185 L .68949 .62946 L F
.249 .013 .347 r
.68746 .63377 m .68944 .63099 L .688 .63185 L F
.614 .507 .708 r
.65132 .62266 m .65249 .62629 L .64891 .62471 L F
.414 .316 .636 r
.33969 .7955 m .33998 .79817 L .34144 .79727 L F
.438 0 0 r
.46704 .76603 m .46925 .76675 L .4703 .76585 L F
.683 .204 .108 r
.46925 .76675 m .47247 .76724 L .4703 .76585 L F
.596 .272 .39 r
.4703 .76585 m .47247 .76724 L .47233 .76636 L F
.738 .706 .821 r
.35435 .80973 m .35637 .80871 L .35294 .80835 L F
.91 .722 .635 r
.64133 .62809 m .64238 .62888 L .64246 .63138 L F
.619 .459 .643 r
.34618 .78735 m .34848 .78715 L .34834 .78463 L F
.566 .38 .588 r
.34626 .78996 m .34848 .78715 L .34618 .78735 L F
.318 .777 .947 r
.31671 .7164 m .31877 .71611 L .31942 .71639 L F
.529 0 0 r
.31877 .71611 m .32158 .71641 L .31942 .71639 L F
0 .295 .792 r
.49765 .87504 m .49722 .87573 L .49592 .87358 L F
.752 .348 .286 r
.49597 .87802 m .49949 .87826 L .49722 .87573 L F
.49597 .87802 m .49722 .87573 L .49765 .87504 L F
.812 .327 .004 r
.50031 .87875 m .49722 .87573 L .49949 .87826 L F
0 .32 .755 r
.71673 .73498 m .71589 .73486 L .71493 .7343 L F
.71673 .73498 m .71777 .7359 L .71589 .73486 L F
.655 .593 .774 r
.50879 .76317 m .51215 .76577 L .51213 .76338 L F
.687 .535 .674 r
.51213 .76338 m .51215 .76577 L .51432 .7627 L F
.678 .31 .343 r
.49914 .77257 m .5023 .77115 L .4991 .77156 L F
.49914 .77257 m .50096 .77312 L .5023 .77115 L F
.763 .417 .399 r
.50096 .77312 m .50459 .77368 L .5023 .77115 L F
.659 .432 .564 r
.5023 .77115 m .50459 .77368 L .50438 .77094 L F
.414 .112 .341 r
.62392 .67431 m .62347 .67637 L .62109 .67705 L F
.375 .154 .445 r
.62592 .67167 m .62609 .67404 L .62392 .67431 L F
.281 0 .295 r
.62527 .67554 m .62392 .67431 L .62609 .67404 L F
.62527 .67554 m .62347 .67637 L .62392 .67431 L F
.463 .341 .629 r
.49265 .8704 m .49288 .87251 L .49109 .87292 L F
.661 .553 .722 r
.49369 .87429 m .49109 .87292 L .49288 .87251 L F
.444 .128 .334 r
.34809 .69565 m .35014 .69524 L .35096 .6933 L F
.536 .285 .482 r
.35014 .69524 m .35278 .69273 L .35096 .6933 L F
.642 .575 .765 r
.38529 .76361 m .38622 .76549 L .38333 .76569 L F
.619 .47 .658 r
.38622 .76549 m .38375 .76772 L .38333 .76569 L F
.226 0 0 r
.31333 .65508 m .31529 .65466 L .3169 .65323 L F
.491 .101 .229 r
.31529 .65466 m .31886 .65259 L .3169 .65323 L F
.586 .57 .803 r
.48945 .73038 m .48851 .73391 L .48735 .73077 L F
.48945 .73038 m .49069 .73352 L .48851 .73391 L F
.541 .406 .646 r
.3862 .76082 m .38529 .76361 L .38482 .76103 L F
.747 .661 .765 r
.699 .71173 m .70242 .71235 L .70089 .70892 L F
.766 .486 .51 r
.70204 .71424 m .70242 .71235 L .699 .71173 L F
.626 .602 .806 r
.70089 .70892 m .70242 .71235 L .70344 .71148 L F
.782 .613 .671 r
.70204 .71424 m .70344 .71148 L .70242 .71235 L F
.109 .657 .823 r
.3931 .77825 m .39208 .77839 L .39105 .77886 L F
.3931 .77825 m .39477 .77842 L .39208 .77839 L F
.163 0 0 r
.6475 .62063 m .64884 .61984 L .64803 .61973 L F
.63 .575 .774 r
.64884 .61984 m .64861 .6214 L .64803 .61973 L F
.8 .698 .752 r
.64803 .61973 m .64516 .61706 L .64492 .62009 L F
.419 .082 .284 r
.64494 .62258 m .64803 .61973 L .64492 .62009 L F
.64494 .62258 m .6475 .62063 L .64803 .61973 L F
.317 0 0 r
.44464 .738 m .44321 .73846 L .44121 .73835 L F
.025 0 0 r
.44657 .73773 m .44321 .73846 L .44464 .738 L F
.777 .74 .819 r
.7011 .62918 m .69895 .6318 L .69798 .63022 L F
.878 .823 .79 r
.61375 .6465 m .61685 .64472 L .61575 .64388 L F
.61375 .6465 m .61509 .64746 L .61685 .64472 L F
.157 .682 .875 r
.45531 .72573 m .45764 .72573 L .4587 .72601 L F
.347 .781 .968 r
.45764 .72573 m .46075 .72599 L .4587 .72601 L F
.004 0 0 r
.40744 .78107 m .40619 .78112 L .40534 .781 L F
.936 .577 .169 r
.33616 .80937 m .33527 .80917 L .33303 .80859 L F
.445 .185 .424 r
.33639 .81099 m .33434 .81152 L .33616 .80937 L F
.936 .577 .169 r
.33616 .80937 m .33639 .81099 L .33527 .80917 L F
.643 .669 .86 r
.46653 .73681 m .46993 .73881 L .46873 .7358 L F
.658 .621 .8 r
.46873 .7358 m .46993 .73881 L .47212 .73819 L F
.918 .84 .752 r
.73307 .7239 m .731 .72185 L .73216 .72298 L F
.73307 .7239 m .72954 .72466 L .731 .72185 L F
.845 .84 .84 r
.7294 .72741 m .72954 .72466 L .73307 .7239 L F
.578 .563 .801 r
.73325 .72364 m .73307 .7239 L .73216 .72298 L F
.361 .051 .299 r
.39264 .75402 m .39186 .75219 L .39401 .75181 L F
.39264 .75402 m .39095 .75445 L .39186 .75219 L F
.593 .737 .944 r
.71734 .71837 m .71871 .71637 L .71717 .71583 L F
.71734 .71837 m .72015 .71791 L .71871 .71637 L F
.612 .076 0 r
.47779 .76573 m .47998 .76715 L .48108 .76646 L F
.693 .178 .004 r
.47998 .76715 m .48311 .76809 L .48108 .76646 L F
.695 .227 .137 r
.48108 .76646 m .48311 .76809 L .48459 .76799 L F
.395 .461 .81 r
.58559 .67116 m .58359 .66906 L .58886 .66812 L F
.656 .45 .593 r
.58921 .6689 m .58559 .67116 L .58886 .66812 L F
.624 .386 .536 r
.60788 .67954 m .60658 .68136 L .6059 .67937 L F
.731 .534 .625 r
.64817 .62871 m .64828 .63127 L .64463 .63095 L F
.532 .342 .568 r
.35052 .7819 m .34834 .78463 L .35039 .78427 L F
.623 .499 .69 r
.34848 .78715 m .35039 .78427 L .34834 .78463 L F
0 0 0 r
.31671 .7164 m .31707 .7163 L .31877 .71611 L F
.31671 .7164 m .31522 .71702 L .31707 .7163 L F
.781 .596 .649 r
.66049 .61526 m .6588 .61785 L .65772 .61464 L F
.906 .496 .161 r
.68336 .61917 m .6841 .61827 L .6807 .61754 L F
.68336 .61917 m .68462 .62008 L .6841 .61827 L F
.389 .416 .768 r
.64404 .62359 m .64629 .62466 L .64494 .62258 L F
.875 .994 .786 r
.33713 .80306 m .33832 .7998 L .3399 .79942 L F
.646 .568 .753 r
.34077 .80329 m .33713 .80306 L .3399 .79942 L F
.34077 .80329 m .33862 .80397 L .33713 .80306 L F
0 0 .408 r
.36192 .80903 m .36233 .80829 L .36033 .81049 L F
0 .433 .851 r
.70036 .70508 m .70366 .70664 L .70212 .70541 L F
.949 .92 .747 r
.70212 .70541 m .69969 .70775 L .70001 .70601 L F
.073 0 0 r
.70036 .70508 m .70102 .70557 L .69743 .70615 L F
.70102 .70557 m .70097 .70559 L .69743 .70615 L F
.949 .92 .747 r
.70212 .70541 m .70001 .70601 L .70178 .70523 L F
0 .433 .851 r
.70102 .70557 m .70212 .70541 L .70103 .70558 L F
.70036 .70508 m .70212 .70541 L .70102 .70557 L F
.812 .45 .371 r
.69844 .70281 m .70092 .70546 L .70212 .70541 L F
.949 .92 .747 r
.70129 .70545 m .70102 .70557 L .70095 .70546 L F
.812 .45 .371 r
.70092 .70546 m .70103 .70558 L .70212 .70541 L F
.949 .92 .747 r
.70178 .70523 m .70129 .70545 L .7003 .70443 L F
.70129 .70545 m .70095 .70546 L .7003 .70443 L F
.70102 .70557 m .70001 .70601 L .70007 .70571 L F
.453 .453 .768 r
.69743 .70615 m .70097 .70559 L .69844 .70281 L F
.949 .92 .747 r
.70102 .70557 m .70096 .70557 L .70089 .70537 L F
.073 0 0 r
.70102 .70557 m .70103 .70558 L .70097 .70559 L F
.453 .453 .768 r
.70097 .70559 m .70103 .70558 L .70092 .70546 L F
.70097 .70559 m .70092 .70546 L .69844 .70281 L F
.949 .92 .747 r
.70089 .70537 m .70007 .70571 L .7003 .70443 L F
.70096 .70557 m .70007 .70571 L .70089 .70537 L F
.793 .616 .661 r
.70344 .71148 m .70528 .71458 L .70539 .71216 L F
0 .41 .727 r
.72609 .71643 m .72398 .71563 L .72349 .71555 L F
.72609 .71643 m .72628 .71635 L .72398 .71563 L F
0 0 .538 r
.72609 .71643 m .72713 .71749 L .72628 .71635 L F
.63 .511 .699 r
.72609 .71643 m .72625 .72018 L .72891 .71894 L F
.72609 .71643 m .72891 .71894 L .72713 .71749 L F
.558 .363 .572 r
.65316 .62846 m .65325 .63091 L .65095 .63139 L F
.62 .565 .772 r
.65461 .6253 m .65316 .62846 L .65249 .62629 L F
.65461 .6253 m .65568 .62831 L .65316 .62846 L F
.519 .284 .498 r
.65568 .62831 m .65325 .63091 L .65316 .62846 L F
.506 .884 .688 r
.64531 .65603 m .64473 .65612 L .64375 .65676 L F
.64531 .65603 m .647 .6548 L .64473 .65612 L F
.605 .547 .763 r
.51339 .75973 m .51432 .7627 L .51659 .7623 L F
.184 .022 .413 r
.62737 .67286 m .62592 .67167 L .62752 .67075 L F
.62737 .67286 m .62609 .67404 L .62592 .67167 L F
.775 .823 .89 r
.70342 .58135 m .70469 .5826 L .70175 .58239 L F
.909 .933 .815 r
.70329 .58368 m .70241 .58571 L .70145 .58509 L F
.70469 .5826 m .70403 .5835 L .70329 .58368 L F
.70403 .5835 m .70241 .58571 L .70329 .58368 L F
.657 .44 .579 r
.70175 .58239 m .70216 .58395 L .70044 .58384 L F
.709 .574 .701 r
.70469 .5826 m .70571 .58628 L .70241 .58571 L F
.909 .933 .815 r
.70469 .5826 m .70329 .58368 L .70383 .58452 L F
.70329 .58368 m .70145 .58509 L .70262 .58481 L F
.70329 .58368 m .70262 .58481 L .70383 .58452 L F
.657 .44 .579 r
.70216 .58395 m .7024 .58487 L .70112 .5842 L F
.70216 .58395 m .70112 .5842 L .70044 .58384 L F
.757 .762 .856 r
.70044 .58384 m .7024 .58487 L .70227 .58412 L F
.909 .933 .815 r
.70469 .5826 m .70388 .5844 L .70175 .58239 L F
.70388 .5844 m .70367 .58437 L .70175 .58239 L F
.905 .606 .469 r
.70018 .58146 m .70175 .58239 L .70044 .58384 L F
.735 .686 .804 r
.70254 .57874 m .70175 .58239 L .70018 .58146 L F
.70254 .57874 m .70342 .58135 L .70175 .58239 L F
.657 .44 .579 r
.70175 .58239 m .70383 .58452 L .7024 .58487 L F
.757 .762 .856 r
.70045 .58381 m .70227 .58412 L .70163 .58026 L F
.70044 .58384 m .70227 .58412 L .70045 .58381 L F
.909 .933 .815 r
.70388 .5844 m .70383 .58452 L .70367 .58437 L F
.567 .638 .881 r
.7056 .57959 m .70469 .5826 L .70342 .58135 L F
.7056 .57959 m .70702 .58224 L .70469 .5826 L F
.69 .621 .774 r
.70702 .58224 m .70571 .58628 L .70469 .5826 L F
.849 .513 0 r
.67175 .62503 m .67232 .62592 L .67115 .6229 L F
.826 .698 .723 r
.66889 .62777 m .67232 .62592 L .67175 .62503 L F
.66889 .62777 m .67041 .62885 L .67232 .62592 L F
.849 .513 0 r
.67175 .62503 m .67232 .62592 L .67115 .6229 L F
.714 .218 .06 r
.67232 .62592 m .67457 .62789 L .67337 .62756 L F
.67232 .62592 m .67337 .62756 L .67175 .62503 L F
.58 .761 .965 r
.47853 .72742 m .47536 .72674 L .4775 .72633 L F
.648 .804 .958 r
.48091 .72659 m .47853 .72742 L .4775 .72633 L F
.738 .702 .817 r
.6418 .64412 m .64049 .64755 L .6395 .64439 L F
.6418 .64412 m .64228 .64631 L .64049 .64755 L F
.676 .145 0 r
.72173 .70819 m .72071 .70646 L .71957 .70598 L F
.72173 .70819 m .72318 .70834 L .72071 .70646 L F
.535 .797 .994 r
.34826 .65191 m .34764 .65327 L .34623 .65223 L F
.34826 .65191 m .34963 .65285 L .34764 .65327 L F
.06 0 0 r
.42098 .72412 m .42313 .72399 L .42461 .72367 L F
.281 0 0 r
.42313 .72399 m .42663 .72337 L .42461 .72367 L F
.734 .636 .75 r
.50226 .75804 m .5 .76065 L .50266 .75992 L F
.341 0 .059 r
.40032 .75079 m .39949 .74942 L .40164 .74925 L F
.40032 .75079 m .398 .75126 L .39949 .74942 L F
.72 .891 .958 r
.70052 .64351 m .70251 .64104 L .69972 .64277 L F
.70052 .64351 m .70344 .64188 L .70251 .64104 L F
.384 0 .106 r
.69122 .63025 m .68949 .62946 L .68944 .63099 L F
.69122 .63025 m .69193 .62919 L .68949 .62946 L F
.252 0 0 r
.37847 .80303 m .38265 .80015 L .38195 .80169 L F
.373 0 0 r
.38265 .80015 m .38266 .80142 L .38195 .80169 L F
.38265 .80015 m .38461 .80014 L .38266 .80142 L F
.426 0 .009 r
.4749 .77366 m .47348 .77498 L .47149 .77438 L F
.245 0 0 r
.47682 .77409 m .47348 .77498 L .4749 .77366 L F
.928 .874 .45 r
.59112 .68178 m .59062 .68147 L .59149 .67992 L F
.892 .98 .814 r
.58892 .6851 m .59062 .68147 L .59112 .68178 L F
.789 .649 .708 r
.58992 .68414 m .58892 .6851 L .59112 .68178 L F
.886 .566 .063 r
.6703 .61949 m .67095 .62065 L .66985 .61754 L F
.802 .589 .027 r
.67091 .62177 m .67095 .62065 L .6703 .61949 L F
.67091 .62177 m .67115 .6229 L .67095 .62065 L F
.886 .566 .063 r
.6703 .61949 m .67095 .62065 L .66985 .61754 L F
.802 .589 .027 r
.67091 .62177 m .67095 .62065 L .6703 .61949 L F
.67091 .62177 m .67115 .6229 L .67095 .62065 L F
.443 .035 .169 r
.44724 .77881 m .4438 .78089 L .44514 .7792 L F
.507 .394 .659 r
.35052 .7819 m .35232 .77926 L .34979 .77941 L F
.35052 .7819 m .35242 .78151 L .35232 .77926 L F
.544 .352 .57 r
.35052 .7819 m .35249 .78393 L .35242 .78151 L F
.35052 .7819 m .35039 .78427 L .35249 .78393 L F
.665 .53 .69 r
.49997 .75835 m .5 .76065 L .50226 .75804 L F
.588 .84 .478 r
.64703 .61257 m .6489 .61025 L .64747 .61195 L F
.765 .388 .341 r
.6489 .61025 m .65068 .61217 L .64747 .61195 L F
.847 .679 .673 r
.65207 .61024 m .65068 .61217 L .6489 .61025 L F
.67 .598 .766 r
.4809 .73886 m .48195 .74196 L .48426 .74145 L F
.604 .548 .764 r
.48195 .74196 m .48414 .74412 L .48426 .74145 L F
.494 .239 .456 r
.36965 .69213 m .36938 .6953 L .36664 .69475 L F
.487 .232 .454 r
.37146 .69486 m .36965 .69213 L .37219 .69054 L F
.37146 .69486 m .36938 .6953 L .36965 .69213 L F
.416 .029 .195 r
.32089 .65219 m .32304 .65191 L .32431 .64965 L F
.544 .368 .593 r
.32642 .64755 m .32431 .64965 L .32661 .64862 L F
.074 0 .013 r
.32431 .64965 m .32493 .65075 L .32661 .64862 L F
.32431 .64965 m .32304 .65191 L .32493 .65075 L F
.557 .034 0 r
.48024 .77431 m .47908 .77523 L .47682 .77409 L F
.593 .13 .123 r
.48267 .77508 m .47908 .77523 L .48024 .77431 L F
.979 .687 .324 r
.49949 .87826 m .50061 .88125 L .50031 .87875 L F
.49949 .87826 m .50061 .88125 L .50031 .87875 L F
.849 .532 .452 r
.71448 .70109 m .71601 .70375 L .7176 .70369 L F
.83 .482 .397 r
.71601 .70375 m .71638 .70549 L .7176 .70369 L F
.749 .374 .342 r
.71638 .70549 m .71957 .70598 L .7176 .70369 L F
.676 .442 .56 r
.61584 .67736 m .61543 .6796 L .6134 .67939 L F
.646 .428 .573 r
.61584 .67736 m .61871 .67913 L .61543 .6796 L F
.61584 .67736 m .61882 .67692 L .61871 .67913 L F
.563 .589 .837 r
.35889 .68208 m .35561 .67952 L .359 .67978 L F
.752 .671 .771 r
.35294 .80835 m .35637 .80871 L .35506 .80579 L F
0 .219 .731 r
.35506 .80579 m .35637 .80871 L .357 .80783 L F
.365 .727 .988 r
.35637 .80871 m .3583 .80868 L .357 .80783 L F
.795 .707 .768 r
.70204 .71424 m .69993 .7169 L .70319 .71732 L F
.904 .822 .756 r
.70001 .71929 m .70319 .71732 L .69993 .7169 L F
.70001 .71929 m .70128 .7204 L .70319 .71732 L F
.766 .694 .782 r
.70204 .71424 m .70319 .71732 L .70528 .71458 L F
.897 .791 .736 r
.61211 .64954 m .61509 .64746 L .61375 .6465 L F
.61211 .64954 m .61336 .6502 L .61509 .64746 L F
.69 .723 .875 r
.47212 .73819 m .47539 .73864 L .47413 .73609 L F
.697 .689 .839 r
.47413 .73609 m .47539 .73864 L .47738 .73683 L F
0 .126 .65 r
.68321 .63152 m .68353 .63245 L .68366 .6307 L F
.533 .758 .98 r
.66038 .58584 m .65692 .5849 L .65968 .58471 L F
0 .25 .762 r
.66207 .58638 m .66038 .58584 L .65968 .58471 L F
.66207 .58638 m .66262 .58781 L .66038 .58584 L F
.232 0 0 r
.41636 .78938 m .4193 .78804 L .4177 .78973 L F
.162 0 0 r
.4177 .78973 m .4193 .78804 L .42113 .78743 L F
.838 .734 .749 r
.70571 .58628 m .70248 .58783 L .70241 .58571 L F
.69 .621 .774 r
.70702 .58224 m .70794 .58554 L .70571 .58628 L F
.842 .696 .701 r
.64133 .62809 m .64246 .63138 L .63999 .63072 L F
.795 .457 .415 r
.64246 .63138 m .6411 .63322 L .63999 .63072 L F
.64246 .63138 m .64277 .63287 L .6411 .63322 L F
.569 .413 .63 r
.64246 .63138 m .64447 .6334 L .64277 .63287 L F
.64246 .63138 m .64463 .63095 L .64447 .6334 L F
.086 0 0 r
.34696 .80512 m .34817 .80521 L .3461 .80592 L F
.34696 .80512 m .34918 .80458 L .34817 .80521 L F
.978 .68 .338 r
.70241 .58571 m .70248 .58783 L .70145 .58509 L F
.238 0 0 r
.45283 .77709 m .45149 .77836 L .44938 .77871 L F
.462 0 .038 r
.45476 .7776 m .45149 .77836 L .45283 .77709 L F
.126 0 0 r
.64153 .59278 m .64426 .5907 L .64217 .5913 L F
.205 0 .178 r
.64153 .59278 m .64217 .5913 L .63973 .59365 L F
.522 .173 .317 r
.63088 .63081 m .63042 .63292 L .62817 .6329 L F
.423 .161 .41 r
.63088 .63081 m .63274 .63264 L .63042 .63292 L F
.63088 .63081 m .6333 .63077 L .63274 .63264 L F
.866 .755 .738 r
.66659 .59298 m .66835 .59591 L .66788 .59326 L F
.506 .678 .943 r
.66835 .59591 m .67025 .59457 L .66788 .59326 L F
.66835 .59591 m .67066 .59594 L .67025 .59457 L F
.738 .676 .79 r
.65821 .62611 m .65925 .62888 L .65568 .62831 L F
.644 .089 0 r
.65854 .63028 m .65568 .62831 L .65925 .62888 L F
.729 .485 .558 r
.50438 .77094 m .50459 .77368 L .50779 .77354 L F
.482 .382 .666 r
.37414 .73627 m .37628 .73821 L .37625 .73559 L F
.37414 .73627 m .37454 .73883 L .37628 .73821 L F
0 0 .039 r
.68322 .62806 m .68324 .62659 L .6835 .62518 L F
0 0 0 r
.70756 .62725 m .70705 .62707 L .70528 .62705 L F
.593 .608 .836 r
.70901 .62772 m .70705 .62707 L .70847 .62597 L F
0 0 0 r
.70756 .62725 m .70847 .62597 L .70705 .62707 L F
.403 0 .073 r
.44488 .77058 m .44701 .77045 L .44846 .76876 L F
.587 .16 .199 r
.44846 .76876 m .44701 .77045 L .45027 .77006 L F
.688 .952 .954 r
.71217 .63584 m .71005 .63628 L .71077 .63665 L F
.714 .891 .961 r
.70206 .62748 m .70356 .62858 L .7011 .62918 L F
.689 .884 .97 r
.70528 .62705 m .70356 .62858 L .70206 .62748 L F
.798 .961 .916 r
.69838 .59571 m .70162 .59449 L .69955 .59465 L F
.678 .582 .74 r
.70389 .59115 m .70162 .59449 L .70065 .59042 L F
.361 .388 .754 r
.70389 .59115 m .70511 .59014 L .70476 .58968 L F
.773 .675 .754 r
.70619 .59157 m .7077 .59023 L .70476 .58968 L F
.7077 .59023 m .70803 .58994 L .70476 .58968 L F
.845 .688 .687 r
.70248 .58783 m .70389 .59115 L .70476 .58968 L F
.617 .543 .748 r
.70248 .58783 m .70342 .58974 L .70065 .59042 L F
.418 .441 .778 r
.70476 .58968 m .70342 .58974 L .70248 .58783 L F
.73 .289 .203 r
.70156 .58905 m .70213 .5892 L .70476 .58968 L F
.361 .388 .754 r
.70511 .59014 m .70526 .59001 L .70476 .58968 L F
.773 .675 .754 r
.7055 .59218 m .70619 .59157 L .70511 .59014 L F
.361 .388 .754 r
.70389 .59115 m .7055 .59218 L .70511 .59014 L F
.773 .675 .754 r
.7055 .59218 m .70511 .59014 L .70476 .58968 L F
.361 .388 .754 r
.70511 .59014 m .7055 .59218 L .70526 .59001 L F
.323 .39 .776 r
.70389 .59115 m .7055 .59218 L .70476 .58968 L F
.361 .388 .754 r
.70389 .59115 m .70476 .58968 L .70342 .58974 L F
.73 .289 .203 r
.70213 .5892 m .70499 .58994 L .70476 .58968 L F
.70499 .58994 m .70526 .59001 L .70476 .58968 L F
.662 .351 .435 r
.6996 .59445 m .69955 .59465 L .70331 .59298 L F
.6996 .59445 m .70331 .59298 L .70183 .59378 L F
.943 .955 .743 r
.70183 .59378 m .70331 .59298 L .70526 .59001 L F
.70295 .59276 m .70526 .59001 L .70433 .59149 L F
.70183 .59378 m .70243 .59312 L .70295 .59276 L F
.70243 .59312 m .70526 .59001 L .70295 .59276 L F
.514 .794 .996 r
.70162 .59449 m .70331 .59298 L .70148 .5938 L F
.70036 .59459 m .70148 .5938 L .69955 .59465 L F
.70162 .59449 m .70148 .5938 L .70036 .59459 L F
.861 .972 .657 r
.70436 .59403 m .70405 .59504 L .70162 .59449 L F
.716 .628 .759 r
.48414 .74412 m .48737 .74427 L .48652 .74115 L F
.721 .572 .687 r
.48414 .74412 m .48558 .74488 L .48737 .74427 L F
.683 .609 .766 r
.48652 .74115 m .48737 .74427 L .48971 .74153 L F
.667 .583 .752 r
.48737 .74427 m .4907 .74456 L .48971 .74153 L F
.63 .575 .774 r
.64884 .61984 m .65134 .62057 L .64861 .6214 L F
.845 .547 .485 r
.68128 .63306 m .68321 .63152 L .68366 .6307 L F
.68128 .63306 m .68422 .63396 L .68321 .63152 L F
.305 0 .262 r
.32705 .71397 m .32859 .71436 L .32948 .71185 L F
0 0 0 r
.33139 .71084 m .32948 .71185 L .33118 .71103 L F
.317 .005 .267 r
.32948 .71185 m .33043 .71362 L .33118 .71103 L F
.32948 .71185 m .32859 .71436 L .33043 .71362 L F
.06 0 0 r
.41141 .77946 m .40744 .78107 L .4094 .78037 L F
0 0 0 r
.41152 .77958 m .41141 .77946 L .4094 .78037 L F
.41152 .77958 m .41341 .77925 L .41141 .77946 L F
.117 0 0 r
.41141 .77946 m .41341 .77925 L .41407 .779 L F
.725 .441 .497 r
.4869 .76847 m .49009 .77045 L .49016 .76869 L F
.7 .393 .453 r
.49016 .76869 m .49009 .77045 L .49355 .77036 L F
.493 .185 .373 r
.34532 .69775 m .34809 .69565 L .3458 .69576 L F
.545 .089 .121 r
.45027 .77006 m .45255 .77039 L .454 .76887 L F
.328 0 0 r
.45255 .77039 m .45614 .76863 L .454 .76887 L F
.48 0 .021 r
.41702 .74208 m .41568 .74337 L .41376 .74313 L F
.54 .059 .063 r
.41914 .74308 m .41568 .74337 L .41702 .74208 L F
.387 .236 .552 r
.4833 .87556 m .48483 .87582 L .48488 .87293 L F
.838 .712 .724 r
.58251 .666 m .58359 .66906 L .58173 .66812 L F
.872 .802 .778 r
.58359 .66906 m .58029 .67104 L .58173 .66812 L F
.58359 .66906 m .58171 .67207 L .58029 .67104 L F
.329 .49 .867 r
.34155 .80685 m .33862 .80397 L .34077 .80329 L F
.562 .754 .968 r
.40001 .7791 m .39729 .78008 L .39598 .77886 L F
.608 .347 .496 r
.59133 .68676 m .58992 .68414 L .59256 .68515 L F
.641 .244 .276 r
.59256 .68515 m .5947 .68683 L .59133 .68676 L F
.54 .3 .5 r
.59477 .68479 m .5947 .68683 L .59256 .68515 L F
0 .162 .617 r
.70979 .62682 m .71076 .6276 L .70847 .62597 L F
.455 .395 .701 r
.71076 .6276 m .70901 .62772 L .70847 .62597 L F
0 .162 .617 r
.70979 .62682 m .70847 .62597 L .70756 .62725 L F
.546 .419 .658 r
.35589 .76838 m .35812 .77043 L .35791 .76801 L F
.35589 .76838 m .35616 .7709 L .35812 .77043 L F
.619 .556 .761 r
.34394 .80556 m .34155 .80685 L .34077 .80329 L F
0 0 .49 r
.34245 .80758 m .34155 .80685 L .34394 .80556 L F
.34245 .80758 m .34216 .80872 L .34155 .80685 L F
.956 .858 .703 r
.71206 .71546 m .71118 .71605 L .71102 .71442 L F
.648 .902 .982 r
.71534 .71349 m .71206 .71546 L .71635 .71418 L F
.543 .014 0 r
.7133 .71671 m .71444 .71761 L .71206 .71546 L F
.678 .489 .623 r
.71206 .71546 m .71717 .71583 L .71635 .71418 L F
.71206 .71546 m .71444 .71761 L .71717 .71583 L F
.543 .014 0 r
.7133 .71671 m .71206 .71546 L .71534 .71349 L F
.548 .606 .864 r
.72028 .74251 m .72338 .74505 L .7222 .74134 L F
.437 .449 .774 r
.7222 .74134 m .72338 .74505 L .7239 .74405 L F
.61 .662 .875 r
.7239 .74405 m .72338 .74505 L .72578 .74422 L F
.26 .612 .956 r
.35408 .65315 m .35287 .6539 L .35165 .65277 L F
.35408 .65315 m .35529 .65428 L .35287 .6539 L F
.466 .262 .519 r
.3434 .69834 m .34506 .70025 L .34532 .69775 L F
.3434 .69834 m .34305 .70091 L .34506 .70025 L F
.754 .861 .927 r
.7354 .72256 m .73325 .72364 L .73216 .72298 L F
.31 0 0 r
.32353 .71596 m .32554 .71562 L .32705 .71397 L F
.084 0 0 r
.32554 .71562 m .32859 .71436 L .32705 .71397 L F
.329 .781 .954 r
.33024 .67593 m .32905 .67559 L .32708 .67586 L F
.077 0 0 r
.33201 .67563 m .32905 .67559 L .33024 .67593 L F
0 0 .087 r
.57378 .67633 m .57204 .67818 L .57046 .67912 L F
.57378 .67633 m .57371 .67673 L .57204 .67818 L F
.325 .624 .958 r
.33065 .64864 m .33011 .6497 L .32858 .64869 L F
.33065 .64864 m .33188 .6499 L .33011 .6497 L F
.004 .567 .8 r
.42663 .72337 m .4288 .72361 L .43023 .72398 L F
.35 0 0 r
.4288 .72361 m .43223 .72392 L .43023 .72398 L F
.143 .624 .921 r
.35529 .65428 m .35711 .65451 L .35669 .65495 L F
.107 .579 .912 r
.35711 .65451 m .35846 .65534 L .35669 .65495 L F
.235 0 0 r
.41636 .78938 m .4177 .78973 L .41561 .79016 L F
.502 .285 .517 r
.36664 .69475 m .36724 .69795 L .36508 .69832 L F
.44 .245 .518 r
.36896 .69744 m .36664 .69475 L .36938 .6953 L F
.36896 .69744 m .36724 .69795 L .36664 .69475 L F
.475 .075 .202 r
.70398 .59857 m .70734 .59767 L .7043 .59706 L F
.522 .516 .79 r
.39105 .77886 m .38975 .7797 L .38806 .77582 L F
.573 .421 .636 r
.65325 .63091 m .65115 .63422 L .65095 .63139 L F
.756 .561 .633 r
.64828 .63127 m .65095 .63139 L .65115 .63422 L F
.418 .154 .404 r
.4093 .74414 m .40878 .74609 L .40685 .74664 L F
.418 .122 .353 r
.41145 .74368 m .40878 .74609 L .4093 .74414 L F
.832 .585 .566 r
.70633 .69759 m .70902 .6958 L .70635 .69503 L F
.70633 .69759 m .70912 .69841 L .70902 .6958 L F
.976 .726 .49 r
.71142 .59055 m .71172 .58836 L .71042 .58724 L F
.397 .17 .449 r
.71355 .58771 m .71172 .58836 L .71142 .59055 L F
.562 .054 .005 r
.71142 .59055 m .71172 .58836 L .71355 .58771 L F
.586 .899 .63 r
.64703 .61257 m .64548 .61378 L .64682 .61478 L F
.64703 .61257 m .64747 .61195 L .64548 .61378 L F
.859 .769 .762 r
.64547 .63839 m .64701 .63942 L .64524 .64236 L F
.869 .77 .75 r
.64635 .63641 m .64701 .63942 L .64547 .63839 L F
.777 .738 .817 r
.72578 .74422 m .7289 .74457 L .72813 .74186 L F
.756 .754 .85 r
.68504 .62232 m .68782 .62091 L .68462 .62008 L F
.611 .452 .641 r
.34979 .77941 m .35232 .77926 L .3519 .77659 L F
.33 .083 .38 r
.36221 .70285 m .361 .70157 L .36293 .7012 L F
.36221 .70285 m .36051 .70367 L .361 .70157 L F
.818 .687 .72 r
.59489 .67399 m .59248 .67387 L .59423 .67106 L F
.957 .93 .727 r
.59489 .67399 m .59281 .67628 L .59248 .67387 L F
.59489 .67399 m .59353 .677 L .59281 .67628 L F
.634 .558 .751 r
.5009 .75256 m .50191 .74922 L .49979 .74944 L F
.5009 .75256 m .50312 .75199 L .50191 .74922 L F
.372 .174 .477 r
.35305 .69042 m .35465 .68986 L .35496 .68769 L F
.449 .259 .529 r
.35305 .69042 m .35461 .69221 L .35465 .68986 L F
.35305 .69042 m .35278 .69273 L .35461 .69221 L F
.619 .47 .658 r
.38622 .76549 m .38617 .7685 L .38375 .76772 L F
.619 .501 .696 r
.38617 .7685 m .3843 .77118 L .38375 .76772 L F
.591 .308 .456 r
.43616 .73931 m .43591 .74123 L .4335 .74126 L F
.372 .124 .402 r
.43775 .74047 m .43591 .74123 L .43616 .73931 L F
.255 .429 .842 r
.72779 .71152 m .73015 .71328 L .73045 .71486 L F
.138 .331 .794 r
.73045 .71486 m .73015 .71328 L .73122 .71369 L F
0 .132 .679 r
.7321 .71583 m .73045 .71486 L .73122 .71369 L F
.7321 .71583 m .7323 .71708 L .73045 .71486 L F
.728 .671 .793 r
.63947 .6203 m .63914 .6175 L .63702 .62017 L F
.74 .569 .662 r
.63702 .62017 m .63723 .62079 L .63947 .6203 L F
.836 .995 .757 r
.34822 .81092 m .34927 .81003 L .34729 .81115 L F
.34822 .81092 m .34989 .80867 L .34927 .81003 L F
.096 .414 .863 r
.52174 .75382 m .52225 .75465 L .52188 .7553 L F
.558 .176 .273 r
.38879 .73224 m .39166 .73096 L .38968 .73114 L F
.764 .388 .343 r
.51373 .78657 m .51682 .7872 L .51561 .78898 L F
.728 .342 .319 r
.51682 .7872 m .51904 .78937 L .51561 .78898 L F
.628 .376 .517 r
.51682 .7872 m .5192 .78721 L .51904 .78937 L F
.679 .48 .609 r
.6532 .61775 m .65134 .62057 L .64884 .61984 L F
.745 .567 .653 r
.6532 .61775 m .6536 .6203 L .65134 .62057 L F
.701 .59 .728 r
.65547 .615 m .65683 .61806 L .6532 .61775 L F
.67 .475 .613 r
.65683 .61806 m .6536 .6203 L .6532 .61775 L F
.767 .525 .568 r
.64104 .60128 m .64419 .60364 L .6421 .60442 L F
.542 .456 .707 r
.6421 .60442 m .64468 .60676 L .64223 .60646 L F
.6421 .60442 m .64419 .60364 L .64468 .60676 L F
.385 0 .029 r
.64468 .60676 m .6421 .60442 L .64223 .60646 L F
.814 .749 .791 r
.72142 .73849 m .7222 .74134 L .72419 .74023 L F
.517 .164 .307 r
.39687 .7301 m .3991 .73 L .40024 .72774 L F
.436 .081 .264 r
.40024 .72774 m .4012 .72963 L .40246 .72773 L F
.40024 .72774 m .3991 .73 L .4012 .72963 L F
.579 .459 .68 r
.36345 .75216 m .36563 .75182 L .36528 .74942 L F
.521 .371 .618 r
.36372 .75468 m .36563 .75182 L .36345 .75216 L F
.243 0 .099 r
.637 .5961 m .63907 .59535 L .63973 .59365 L F
0 0 0 r
.63907 .59535 m .64153 .59278 L .63973 .59365 L F
.539 .88 .63 r
.68127 .63551 m .68027 .63642 L .68009 .63667 L F
.045 0 .469 r
.68009 .63667 m .68154 .63751 L .68127 .63551 L F
.68009 .63667 m .68025 .63846 L .68154 .63751 L F
.377 0 .132 r
.40463 .72762 m .40672 .72726 L .40804 .72536 L F
.51 .105 .209 r
.40672 .72726 m .41021 .72546 L .40804 .72536 L F
.231 .706 .939 r
.46282 .72559 m .46629 .72616 L .46416 .72626 L F
.65 .587 .771 r
.38651 .77075 m .38478 .77327 L .3843 .77118 L F
.38651 .77075 m .38749 .7738 L .38478 .77327 L F
.76 .586 .661 r
.58893 .67358 m .5925 .67792 L .58716 .67629 L F
.884 .989 .737 r
.59235 .67824 m .59149 .67992 L .59168 .67894 L F
.59353 .677 m .59173 .67957 L .59235 .67824 L F
.59173 .67957 m .59149 .67992 L .59235 .67824 L F
.967 .922 .702 r
.59353 .677 m .59262 .67767 L .59281 .67628 L F
.55 .543 .799 r
.59281 .67628 m .59266 .67735 L .58893 .67358 L F
.59273 .67742 m .5925 .67792 L .58893 .67358 L F
.749 .525 .592 r
.5923 .67817 m .59123 .67939 L .58685 .67861 L F
.5924 .67805 m .58685 .67861 L .58716 .67629 L F
.5923 .67817 m .58685 .67861 L .5924 .67805 L F
.76 .586 .661 r
.5925 .67792 m .5924 .67805 L .58716 .67629 L F
.967 .922 .702 r
.59262 .67767 m .59182 .67825 L .59281 .67628 L F
.55 .543 .799 r
.59281 .67628 m .59273 .67742 L .59266 .67735 L F
.884 .989 .737 r
.59353 .677 m .5923 .67817 L .59245 .678 L F
.59282 .67752 m .5924 .67805 L .59282 .67752 L F
.55 .543 .799 r
.59273 .67742 m .59268 .67814 L .5925 .67792 L F
.749 .525 .592 r
.59268 .67814 m .59165 .67946 L .59123 .67939 L F
.59268 .67814 m .59123 .67939 L .5923 .67817 L F
.884 .989 .737 r
.59353 .677 m .59168 .67894 L .5923 .67817 L F
.59245 .678 m .5923 .67817 L .5924 .67805 L F
.59353 .677 m .5924 .67805 L .59282 .67752 L F
.749 .525 .592 r
.59268 .67814 m .5923 .67817 L .5924 .67805 L F
.76 .586 .661 r
.5925 .67792 m .59268 .67814 L .5924 .67805 L F
.884 .989 .737 r
.59282 .67752 m .59168 .67894 L .59182 .67825 L F
.716 .628 .759 r
.48414 .74412 m .48652 .74115 L .48426 .74145 L F
.588 .636 .866 r
.49288 .87251 m .49592 .87358 L .49369 .87429 L F
.809 .91 .909 r
.67511 .60172 m .67123 .60327 L .67409 .60085 L F
.356 .533 .893 r
.67629 .60039 m .67511 .60172 L .67409 .60085 L F
.535 .565 .833 r
.6929 .69817 m .6947 .70169 L .69599 .70074 L F
.611 .267 .363 r
.47247 .76724 m .47572 .76546 L .47233 .76636 L F
.47247 .76724 m .47446 .76792 L .47572 .76546 L F
.669 .332 .393 r
.47572 .76546 m .47777 .76729 L .47779 .76573 L F
.47572 .76546 m .47446 .76792 L .47777 .76729 L F
.449 .41 .722 r
.34161 .79288 m .34378 .79479 L .34363 .79242 L F
.607 .815 .98 r
.68343 .58988 m .68495 .58806 L .68195 .58891 L F
.68343 .58988 m .686 .58917 L .68495 .58806 L F
.773 .723 .806 r
.6418 .64412 m .64422 .64418 L .64228 .64631 L F
.205 .675 .939 r
.3443 .8196 m .34757 .82028 L .34616 .81844 L F
.625 .827 .978 r
.34757 .82028 m .34951 .81947 L .34616 .81844 L F
.603 .454 .652 r
.3519 .77659 m .35435 .77663 L .35391 .77357 L F
.67 .493 .636 r
.3519 .77659 m .35469 .77883 L .35435 .77663 L F
.3519 .77659 m .35232 .77926 L .35469 .77883 L F
.822 .657 .678 r
.67016 .6333 m .67123 .63409 L .66997 .631 L F
.777 .615 .68 r
.66789 .63605 m .67123 .63409 L .67016 .6333 L F
.66789 .63605 m .67116 .63636 L .67123 .63409 L F
.713 .613 .744 r
.50312 .75199 m .50428 .75593 L .50582 .75435 L F
.156 .549 .927 r
.44327 .72378 m .44519 .72431 L .44446 .72488 L F
.177 .582 .938 r
.44519 .72431 m .44652 .72538 L .44446 .72488 L F
.161 0 0 r
.31699 .67941 m .31595 .68009 L .31417 .68054 L F
.576 .025 0 r
.31848 .68093 m .31699 .67941 L .31938 .67955 L F
.31848 .68093 m .31595 .68009 L .31699 .67941 L F
.67 .475 .613 r
.65683 .61806 m .65667 .62027 L .6536 .6203 L F
.607 .501 .708 r
.65772 .61464 m .65683 .61806 L .65547 .615 L F
.65772 .61464 m .6588 .61785 L .65683 .61806 L F
.59 .406 .601 r
.6588 .61785 m .65667 .62027 L .65683 .61806 L F
.465 .111 .281 r
.62001 .66042 m .62301 .65817 L .61986 .65802 L F
.62001 .66042 m .62271 .66006 L .62301 .65817 L F
.035 0 .166 r
.62301 .65817 m .624 .65908 L .62515 .65765 L F
.62301 .65817 m .62271 .66006 L .624 .65908 L F
.38 0 .027 r
.34729 .81115 m .34927 .81003 L .34958 .811 L F
.388 0 0 r
.34989 .80867 m .34958 .811 L .34927 .81003 L F
.574 .593 .834 r
.37532 .66822 m .37324 .66872 L .37183 .66572 L F
.735 .881 .948 r
.42485 .74246 m .42573 .74338 L .42836 .742 L F
.392 .101 .346 r
.34172 .70389 m .33918 .70624 L .34111 .70574 L F
.542 .365 .59 r
.34111 .70574 m .34313 .70321 L .34172 .70389 L F
0 0 0 r
.41407 .779 m .41585 .77865 L .41604 .77838 L F
.41407 .779 m .41341 .77925 L .41585 .77865 L F
.251 0 0 r
.50359 .87031 m .50607 .87069 L .50694 .87056 L F
.50694 .87056 m .50607 .87069 L .50359 .87031 L F
.635 .964 .837 r
.50767 .86952 m .50607 .87069 L .50694 .87056 L F
.50694 .87056 m .50607 .87069 L .50767 .86952 L F
.85 .834 .83 r
.57972 .67405 m .58029 .67104 L .58171 .67207 L F
.57972 .67405 m .57808 .67371 L .58029 .67104 L F
.634 .365 .493 r
.57972 .67405 m .57872 .67586 L .57808 .67371 L F
.57972 .67405 m .58148 .67601 L .57872 .67586 L F
.639 .597 .791 r
.50552 .76068 m .50879 .76317 L .50792 .76048 L F
.579 .609 .847 r
.33097 .80872 m .33044 .80559 L .33029 .80599 L F
.33097 .80872 m .3315 .80601 L .33044 .80559 L F
.33097 .80872 m .33303 .80859 L .3315 .80601 L F
.655 .273 .308 r
.52099 .77525 m .52482 .77404 L .52239 .77446 L F
.293 .79 .859 r
.70997 .70882 m .7086 .70881 L .70647 .70926 L F
.856 .408 .014 r
.71107 .70912 m .7086 .70881 L .70997 .70882 L F
.618 .953 .8 r
.7214 .61998 m .71828 .62194 L .72102 .621 L F
.639 .629 .824 r
.7214 .61998 m .72251 .61757 L .7205 .61773 L F
.7214 .61998 m .72385 .62038 L .72251 .61757 L F
.475 .889 .923 r
.72102 .621 m .72385 .62038 L .7214 .61998 L F
0 0 0 r
.31814 .7364 m .31622 .73733 L .31427 .73803 L F
.364 0 .051 r
.3197 .73541 m .31622 .73733 L .31814 .7364 L F
.681 .442 .554 r
.61756 .66035 m .61986 .65802 L .61772 .658 L F
.61756 .66035 m .62001 .66042 L .61986 .65802 L F
.716 .496 .59 r
.59146 .67943 m .58693 .68099 L .58685 .67861 L F
.827 .867 .421 r
.59149 .67992 m .59078 .68118 L .59142 .67954 L F
.5917 .67886 m .59142 .67954 L .59172 .67876 L F
.59149 .67992 m .59142 .67954 L .5917 .67886 L F
.716 .496 .59 r
.59142 .67954 m .59062 .68147 L .58693 .68099 L F
.827 .867 .421 r
.59078 .68118 m .59062 .68147 L .59172 .67876 L F
.716 .496 .59 r
.59165 .67946 m .59062 .68147 L .59142 .67954 L F
.59165 .67946 m .59142 .67954 L .59146 .67943 L F
.59142 .67954 m .58693 .68099 L .59146 .67943 L F
.827 .867 .421 r
.59172 .67876 m .59062 .68147 L .59182 .67825 L F
0 0 0 r
.72927 .62021 m .72695 .62291 L .72691 .62053 L F
.639 .546 .733 r
.4907 .74456 m .491 .74672 L .49298 .74419 L F
.655 .569 .746 r
.49298 .74419 m .491 .74672 L .49347 .74637 L F
.208 .489 .898 r
.33957 .65064 m .33906 .65158 L .33702 .65046 L F
.33957 .65064 m .34076 .65224 L .33906 .65158 L F
.881 .614 .093 r
.37783 .80609 m .37808 .80648 L .37742 .80323 L F
.892 .79 .741 r
.37731 .80527 m .37783 .80609 L .378 .80492 L F
.37532 .80629 m .37783 .80609 L .37731 .80527 L F
.881 .614 .093 r
.37783 .80609 m .37815 .80685 L .37808 .80648 L F
.958 .934 .723 r
.37707 .80753 m .37815 .80685 L .37783 .80609 L F
.758 .357 .292 r
.37707 .80753 m .3788 .80817 L .37815 .80685 L F
.567 .307 .482 r
.58992 .68414 m .58919 .68701 L .58892 .6851 L F
.608 .347 .496 r
.59133 .68676 m .58919 .68701 L .58992 .68414 L F
.302 .342 .737 r
.7329 .72001 m .73427 .72189 L .73254 .72072 L F
.925 .541 .162 r
.73359 .72102 m .73427 .72189 L .73359 .72101 L F
.754 .861 .927 r
.73485 .72264 m .73216 .72298 L .73427 .72189 L F
.632 .17 .137 r
.73427 .72189 m .731 .72185 L .73254 .72072 L F
.712 .819 .931 r
.73427 .72189 m .73216 .72298 L .731 .72185 L F
.925 .541 .162 r
.73421 .72387 m .73427 .72189 L .73359 .72102 L F
.754 .861 .927 r
.7354 .72256 m .73485 .72264 L .73427 .72189 L F
.903 .52 .083 r
.73427 .72189 m .73598 .72511 L .7354 .72256 L F
.659 .262 .282 r
.49551 .77263 m .4991 .77156 L .49551 .77092 L F
.49551 .77263 m .49914 .77257 L .4991 .77156 L F
.314 0 .112 r
.42062 .77604 m .42169 .7773 L .42253 .7762 L F
.42062 .77604 m .42253 .7762 L .42261 .77611 L F
.083 .605 .878 r
.41935 .77593 m .42062 .77604 L .42192 .77656 L F
.41871 .77578 m .42062 .77604 L .41935 .77593 L F
.126 .618 .91 r
.42261 .77611 m .42393 .77686 L .42192 .77656 L F
.6 .319 .462 r
.51343 .7759 m .51616 .7758 L .51672 .7737 L F
.503 .227 .428 r
.51616 .7758 m .51892 .77543 L .51672 .7737 L F
.695 .618 .766 r
.49419 .73583 m .49184 .73628 L .49069 .73352 L F
.545 .493 .749 r
.38398 .67098 m .38466 .67424 L .38276 .67448 L F
.56 .472 .712 r
.38466 .67424 m .38322 .67681 L .38276 .67448 L F
.403 .154 .42 r
.37442 .68765 m .37381 .68934 L .37212 .69002 L F
.42 .179 .44 r
.37381 .68934 m .37219 .69054 L .37212 .69002 L F
.656 .45 .593 r
.58921 .6689 m .58916 .67127 L .58559 .67116 L F
.302 .333 .727 r
.72877 .61693 m .72927 .62021 L .72818 .61802 L F
.775 .654 .729 r
.6617 .62044 m .65991 .623 L .65887 .62042 L F
.135 0 .214 r
.40764 .74815 m .40685 .74664 L .40878 .74609 L F
.40764 .74815 m .40627 .74894 L .40685 .74664 L F
.995 .849 .583 r
.71508 .62425 m .71635 .62334 L .71565 .62509 L F
.678 .978 .871 r
.71828 .62194 m .71635 .62334 L .71746 .62188 L F
.645 .928 .656 r
.71746 .62188 m .71635 .62334 L .71508 .62425 L F
.319 0 .119 r
.29861 .66318 m .30051 .6629 L .30152 .66129 L F
.243 0 .028 r
.30051 .6629 m .30353 .66083 L .30152 .66129 L F
.782 .613 .671 r
.70204 .71424 m .70528 .71458 L .70344 .71148 L F
.854 .998 .794 r
.6416 .64173 m .6395 .64439 L .6388 .64407 L F
.578 .437 .653 r
.6416 .64173 m .6418 .64412 L .6395 .64439 L F
.241 .324 .748 r
.70923 .58417 m .70794 .58554 L .70702 .58224 L F
.609 .375 .537 r
.70857 .58804 m .71042 .58724 L .70794 .58554 L F
.70857 .58804 m .70794 .58554 L .70923 .58417 L F
.576 .369 .563 r
.61882 .67692 m .62102 .67884 L .61871 .67913 L F
.651 .35 .449 r
.62109 .67705 m .62102 .67884 L .61882 .67692 L F
.847 .679 .673 r
.65207 .61024 m .65213 .61238 L .65068 .61217 L F
.563 .453 .687 r
.65437 .61198 m .65207 .61024 L .6539 .60966 L F
.65437 .61198 m .65213 .61238 L .65207 .61024 L F
.408 .144 .399 r
.52435 .78434 m .5268 .7819 L .52612 .78385 L F
.363 .102 .378 r
.52612 .78385 m .5268 .7819 L .52859 .78122 L F
.36 .113 .398 r
.5268 .7819 m .5291 .7792 L .52859 .78122 L F
.542 .415 .656 r
.51339 .75973 m .51539 .75946 L .51528 .75722 L F
.605 .547 .763 r
.51339 .75973 m .51659 .7623 L .51539 .75946 L F
.731 .517 .602 r
.61416 .65532 m .61425 .65784 L .6162 .65526 L F
.763 .563 .627 r
.6162 .65526 m .61425 .65784 L .61772 .658 L F
.208 0 .315 r
.5291 .7792 m .53113 .77645 L .5305 .77841 L F
.231 .008 .354 r
.52859 .78122 m .5291 .7792 L .5305 .77841 L F
.63 .62 .821 r
.51297 .74713 m .51108 .74971 L .51037 .74741 L F
.51297 .74713 m .51406 .74987 L .51108 .74971 L F
.262 0 0 r
.34343 .67395 m .3418 .67518 L .33969 .67541 L F
.644 .089 0 r
.65854 .63028 m .65804 .63034 L .65568 .62831 L F
.813 .956 .908 r
.65854 .63028 m .65577 .631 L .65804 .63034 L F
.404 .759 .994 r
.49283 .86958 m .49265 .8704 L .49173 .87027 L F
.375 .184 .489 r
.63062 .60206 m .63241 .60108 L .63255 .59896 L F
.372 .142 .431 r
.63062 .60206 m .63214 .60316 L .63241 .60108 L F
.63062 .60206 m .63029 .60384 L .63214 .60316 L F
.945 .775 .639 r
.67591 .62868 m .67544 .63096 L .67457 .62789 L F
.575 .401 .608 r
.35792 .76567 m .36007 .76768 L .36001 .76531 L F
.35792 .76567 m .35791 .76801 L .36007 .76768 L F
.749 .677 .781 r
.51389 .73846 m .51509 .74147 L .51176 .74136 L F
.698 .331 .349 r
.51176 .74136 m .51509 .74147 L .51409 .74322 L F
.566 .579 .826 r
.51827 .74022 m .51509 .74147 L .51389 .73846 L F
.206 0 .079 r
.51409 .74322 m .51509 .74147 L .51827 .74022 L F
.81 .854 .882 r
.69223 .64411 m .69538 .64291 L .69414 .64269 L F
.485 .891 .934 r
.69538 .64291 m .69678 .64208 L .69414 .64269 L F
.69538 .64291 m .69756 .64225 L .69678 .64208 L F
.195 .706 .895 r
.37204 .83525 m .37318 .83557 L .36975 .8353 L F
.37204 .83525 m .37318 .83557 L .36975 .8353 L F
.391 .064 .286 r
.33501 .72517 m .33415 .72748 L .33211 .72794 L F
.185 0 .192 r
.33576 .72653 m .33501 .72517 L .33704 .72461 L F
.33576 .72653 m .33415 .72748 L .33501 .72517 L F
.646 .351 .457 r
.69525 .69772 m .69857 .6955 L .69532 .69574 L F
.69525 .69772 m .69866 .69785 L .69857 .6955 L F
.613 .326 .458 r
.69857 .6955 m .69866 .69785 L .70089 .69746 L F
.679 .456 .576 r
.3317 .80097 m .33502 .80108 L .33427 .79784 L F
.341 .241 .594 r
.33502 .80108 m .33649 .80053 L .33427 .79784 L F
.38 .798 .976 r
.46629 .72616 m .46852 .72588 L .46978 .72636 L F
.461 .826 .994 r
.46852 .72588 m .47193 .72608 L .46978 .72636 L F
.896 .92 .83 r
.67737 .59028 m .67838 .59102 L .67983 .58879 L F
.42 .773 .996 r
.50552 .76068 m .50792 .76048 L .50652 .75983 L F
.536 .363 .593 r
.32661 .64862 m .32858 .64869 L .32642 .64755 L F
0 0 0 r
.70398 .59857 m .70184 .60007 L .70165 .60029 L F
.67 .598 .766 r
.4809 .73886 m .48426 .74145 L .48312 .7381 L F
.663 .59 .763 r
.48312 .7381 m .48426 .74145 L .48627 .73957 L F
.674 .61 .775 r
.48627 .73957 m .48426 .74145 L .48652 .74115 L F
.434 .833 .979 r
.71635 .71418 m .71767 .71325 L .71534 .71349 L F
.71635 .71418 m .71909 .71372 L .71767 .71325 L F
.37 .176 .482 r
.71717 .71583 m .71909 .71372 L .71635 .71418 L F
.577 .052 0 r
.34918 .80458 m .35173 .80561 L .34817 .80521 L F
.468 0 0 r
.43223 .72392 m .43421 .72442 L .43537 .72387 L F
.28 .619 .959 r
.33029 .80599 m .33044 .80559 L .32969 .80546 L F
.982 .789 .57 r
.3399 .79942 m .33832 .7998 L .33998 .79817 L F
0 0 0 r
.33998 .79817 m .34032 .79878 L .34144 .79727 L F
.33998 .79817 m .33832 .7998 L .34032 .79878 L F
.616 .576 .787 r
.66975 .59028 m .66788 .59326 L .6675 .59084 L F
.96 .694 .487 r
.6675 .59084 m .66936 .59071 L .66975 .59028 L F
.6675 .59084 m .66788 .59326 L .66636 .59249 L F
.6675 .59084 m .66636 .59249 L .66936 .59071 L F
.952 .952 .67 r
.37707 .80753 m .37615 .8109 L .37806 .81027 L F
.583 .837 .993 r
.68906 .64387 m .69002 .64471 L .69223 .64411 L F
.319 .1 .415 r
.37603 .68671 m .37442 .68765 L .37644 .68481 L F
.379 .158 .448 r
.37603 .68671 m .37381 .68934 L .37442 .68765 L F
.606 .55 .765 r
.50304 .73894 m .50084 .74071 L .49975 .73805 L F
.50304 .73894 m .50294 .74082 L .50084 .74071 L F
0 0 0 r
.42393 .77686 m .4255 .77673 L .42749 .77655 L F
.566 .058 .005 r
.4255 .77673 m .42958 .7762 L .42749 .77655 L F
.713 .613 .744 r
.50312 .75199 m .50582 .75435 L .50529 .75157 L F
.733 .692 .811 r
.50529 .75157 m .50582 .75435 L .50859 .75197 L F
.297 .78 .911 r
.52421 .75745 m .52286 .75718 L .52054 .75748 L F
.299 .523 .902 r
.52421 .75745 m .52523 .7564 L .52225 .75465 L F
.548 .912 .958 r
.52523 .7564 m .52286 .75718 L .52421 .75745 L F
.501 .213 .409 r
.36969 .74399 m .37182 .74366 L .37252 .74185 L F
.477 .192 .401 r
.37182 .74366 m .37429 .74149 L .37252 .74185 L F
.607 .443 .634 r
.35391 .77357 m .35633 .77371 L .35616 .7709 L F
.582 .439 .653 r
.35391 .77357 m .35656 .77607 L .35633 .77371 L F
.35391 .77357 m .35435 .77663 L .35656 .77607 L F
.627 .378 .521 r
.65089 .59585 m .64809 .59766 L .6487 .59651 L F
.904 .843 .773 r
.64404 .64141 m .64524 .64236 L .64422 .64418 L F
.859 .769 .762 r
.64547 .63839 m .64524 .64236 L .64404 .64141 L F
.431 .582 .902 r
.48493 .72628 m .48413 .72777 L .48321 .72586 L F
.48493 .72628 m .4862 .7281 L .48413 .72777 L F
.542 .337 .552 r
.48735 .73077 m .48413 .72777 L .4862 .7281 L F
.138 0 0 r
.42607 .78604 m .42315 .78701 L .42394 .78641 L F
.939 .662 .487 r
.73254 .72072 m .731 .72185 L .73063 .72017 L F
.363 .052 .296 r
.52369 .7868 m .52435 .78434 L .52612 .78385 L F
.597 .856 .507 r
.65213 .61238 m .65037 .61435 L .65068 .61217 L F
.327 .482 .861 r
.72708 .73343 m .72859 .73455 L .72793 .73238 L F
.806 .528 .516 r
.71289 .70308 m .71448 .70109 L .71298 .70061 L F
.71289 .70308 m .71601 .70375 L .71448 .70109 L F
.252 0 .27 r
.63255 .59896 m .63428 .59818 L .63465 .59665 L F
.391 .036 .239 r
.63635 .59745 m .63465 .59665 L .63428 .59818 L F
.63635 .59745 m .637 .5961 L .63465 .59665 L F
.229 0 .179 r
.53287 .7757 m .53364 .77419 L .53547 .77335 L F
.827 .351 .003 r
.72779 .71152 m .72577 .70953 L .72854 .71184 L F
0 .203 .68 r
.72854 .71184 m .73015 .71328 L .72779 .71152 L F
.773 .646 .722 r
.66789 .63605 m .66906 .63912 L .67116 .63636 L F
.701 .651 .797 r
.65774 .61279 m .65547 .615 L .65437 .61198 L F
.692 .636 .788 r
.65772 .61464 m .65547 .615 L .65774 .61279 L F
.442 .254 .529 r
.35465 .68986 m .35663 .68711 L .35496 .68769 L F
.501 0 0 r
.72725 .74035 m .72826 .73993 L .72729 .73975 L F
.107 0 .164 r
.35568 .70858 m .35336 .71123 L .35427 .70949 L F
.657 .53 .698 r
.7239 .74405 m .72725 .74035 L .72523 .74356 L F
.617 .543 .748 r
.70248 .58783 m .70065 .59042 L .70014 .58852 L F
.678 .582 .74 r
.70389 .59115 m .70065 .59042 L .70342 .58974 L F
.497 .03 .076 r
.47149 .77438 m .47026 .77581 L .46802 .77564 L F
.428 0 .032 r
.47348 .77498 m .47026 .77581 L .47149 .77438 L F
.977 .704 .446 r
.71333 .73874 m .71224 .73833 L .71209 .73539 L F
0 .146 .608 r
.71368 .73946 m .71224 .73833 L .71333 .73874 L F
.642 .569 .757 r
.48971 .74153 m .4907 .74456 L .49298 .74419 L F
0 0 0 r
.53547 .77335 m .53612 .77135 L .53693 .76996 L F
.412 .146 .397 r
.37918 .73576 m .381 .73528 L .38165 .73327 L F
.394 .044 .248 r
.381 .73528 m .38387 .73327 L .38165 .73327 L F
.675 .615 .781 r
.49621 .74726 m .49797 .75072 L .49979 .74944 L F
.521 .346 .585 r
.37454 .73883 m .37665 .74089 L .37628 .73821 L F
.37454 .73883 m .37429 .74149 L .37665 .74089 L F
.044 .445 .875 r
.39522 .77793 m .39477 .77842 L .3931 .77825 L F
.39522 .77793 m .39598 .77886 L .39477 .77842 L F
.558 .673 .915 r
.63702 .62017 m .63587 .61799 L .63376 .61845 L F
.337 .612 .95 r
.63905 .61978 m .63702 .62017 L .63914 .6175 L F
.63905 .61978 m .63587 .61799 L .63702 .62017 L F
.899 .954 .827 r
.34431 .79726 m .345 .79819 L .34722 .79509 L F
.773 .38 .31 r
.34431 .79726 m .34464 .80005 L .345 .79819 L F
.664 .544 .707 r
.34722 .79509 m .345 .79819 L .34737 .79643 L F
.524 .272 .475 r
.345 .79819 m .34747 .79813 L .34737 .79643 L F
.345 .79819 m .34464 .80005 L .34747 .79813 L F
.736 .713 .83 r
.35 .68206 m .35107 .68469 L .35381 .68334 L F
.777 .74 .819 r
.7011 .62918 m .69798 .63022 L .69975 .6281 L F
.126 .334 .8 r
.7002 .62478 m .70077 .62574 L .69871 .62482 L F
.652 .81 .959 r
.70206 .62748 m .7011 .62918 L .70076 .6289 L F
.70206 .62748 m .70076 .6289 L .70076 .62783 L F
.119 0 0 r
.70063 .62803 m .70206 .62748 L .69975 .6281 L F
.744 .523 .594 r
.70068 .62801 m .70235 .6302 L .70206 .62748 L F
.119 0 0 r
.70206 .6279 m .70206 .62748 L .70063 .62803 L F
.744 .523 .594 r
.70061 .62792 m .70068 .62801 L .70206 .62748 L F
0 0 0 r
.70061 .62792 m .70206 .62748 L .69975 .6281 L F
.55 .885 .629 r
.70334 .62619 m .70206 .62748 L .70151 .62787 L F
.363 .398 .763 r
.69871 .62482 m .70174 .62762 L .69975 .6281 L F
.226 0 0 r
.70061 .62792 m .70206 .62748 L .70139 .62795 L F
.363 .398 .763 r
.70139 .62795 m .70139 .62796 L .70047 .62793 L F
.226 0 0 r
.70064 .62793 m .70139 .62795 L .70111 .62816 L F
.70061 .62792 m .70139 .62795 L .70064 .62793 L F
.652 .81 .959 r
.70076 .62783 m .70076 .6289 L .69975 .6281 L F
.363 .398 .763 r
.70047 .62793 m .70139 .62796 L .69975 .6281 L F
.70174 .62762 m .70139 .62795 L .70047 .62793 L F
.55 .885 .629 r
.70174 .62762 m .70151 .62787 L .70139 .62795 L F
.526 .364 .604 r
.70206 .62748 m .70235 .6302 L .70442 .6293 L F
.696 .23 .142 r
.70139 .62795 m .70442 .6293 L .70206 .62748 L F
.363 .398 .763 r
.70139 .62795 m .70206 .6279 L .7014 .62796 L F
.70139 .62795 m .7014 .62796 L .70139 .62796 L F
.696 .23 .142 r
.70111 .62816 m .70218 .62853 L .70139 .62795 L F
.70218 .62853 m .70442 .6293 L .70139 .62795 L F
.125 0 0 r
.70111 .62816 m .70139 .62795 L .70206 .6279 L F
.70139 .62795 m .70206 .62748 L .70206 .6279 L F
.363 .398 .763 r
.70174 .62762 m .70206 .6279 L .70139 .62795 L F
.55 .885 .629 r
.70184 .62751 m .70174 .62762 L .70111 .62816 L F
.70174 .62762 m .70139 .62795 L .70111 .62816 L F
.70334 .62619 m .70151 .62787 L .70183 .62752 L F
.689 .884 .97 r
.70528 .62705 m .70206 .62748 L .7034 .62663 L F
.533 .815 .998 r
.7034 .62663 m .70206 .62748 L .70334 .62619 L F
.656 .612 .793 r
.70334 .62619 m .70206 .6279 L .70183 .62752 L F
.70334 .62619 m .70183 .62752 L .7002 .62478 L F
.55 .885 .629 r
.70334 .62619 m .70183 .62752 L .70184 .62751 L F
.126 .334 .8 r
.70077 .62574 m .70183 .62752 L .70077 .62672 L F
.70183 .62752 m .70206 .6279 L .70174 .62762 L F
.70183 .62752 m .70174 .62762 L .70077 .62672 L F
.70077 .62574 m .70077 .62672 L .69871 .62482 L F
.658 .621 .8 r
.46873 .7358 m .47212 .73819 L .47183 .73662 L F
.652 .596 .779 r
.47183 .73662 m .47212 .73819 L .47413 .73609 L F
.625 .588 .792 r
.49756 .73845 m .49419 .73583 L .49613 .73558 L F
.709 .648 .787 r
.49958 .73588 m .49756 .73845 L .49613 .73558 L F
.579 .463 .684 r
.49958 .73588 m .49975 .73805 L .49756 .73845 L F
.782 .756 .83 r
.71435 .62739 m .71219 .62913 L .71076 .6276 L F
.609 .367 .525 r
.36785 .7469 m .3699 .74879 L .3696 .74631 L F
.36785 .7469 m .36743 .74904 L .3699 .74879 L F
.711 .28 .224 r
.50345 .77955 m .50208 .78088 L .50006 .77907 L F
.765 .353 .27 r
.50404 .78099 m .50208 .78088 L .50345 .77955 L F
.574 .335 .516 r
.3235 .67652 m .3212 .67867 L .32178 .67714 L F
.22 0 .181 r
.35769 .70579 m .35603 .70641 L .35844 .70417 L F
.425 .1 .308 r
.36051 .70367 m .35769 .70579 L .35844 .70417 L F
.695 .618 .766 r
.49419 .73583 m .49069 .73352 L .49288 .73295 L F
.565 .444 .674 r
.49622 .73321 m .49419 .73583 L .49288 .73295 L F
.49622 .73321 m .49613 .73558 L .49419 .73583 L F
.595 .429 .627 r
.6408 .59894 m .64316 .59859 L .64104 .60128 L F
.536 .18 .311 r
.32708 .67586 m .32327 .67869 L .3235 .67652 L F
.32708 .67586 m .32543 .67883 L .32327 .67869 L F
.698 .36 .401 r
.32876 .67856 m .32708 .67586 L .32905 .67559 L F
.32876 .67856 m .32543 .67883 L .32708 .67586 L F
.451 .8 .998 r
.44652 .72538 m .44859 .72506 L .44989 .72583 L F
.093 .628 .861 r
.44859 .72506 m .45204 .72563 L .44989 .72583 L F
.566 .38 .588 r
.34626 .78996 m .34841 .78983 L .34848 .78715 L F
.623 .499 .69 r
.34848 .78715 m .35092 .787 L .35039 .78427 L F
.618 .422 .595 r
.34848 .78715 m .35015 .78933 L .35092 .787 L F
.34848 .78715 m .34841 .78983 L .35015 .78933 L F
.521 .352 .593 r
.36163 .75796 m .36357 .75763 L .36372 .75468 L F
.541 .381 .613 r
.36166 .76001 m .36357 .75763 L .36163 .75796 L F
.537 .351 .576 r
.57589 .67636 m .57376 .6792 L .57371 .67673 L F
.57589 .67636 m .57376 .6792 L .57371 .67673 L F
0 0 .087 r
.57378 .67633 m .57376 .6792 L .57371 .67673 L F
.314 .802 .777 r
.64951 .58797 m .65114 .58728 L .65172 .58725 L F
0 0 0 r
.64951 .58797 m .64843 .58865 L .65114 .58728 L F
.191 0 0 r
.45983 .73561 m .4565 .73586 L .45779 .73555 L F
.442 .126 .333 r
.35008 .67949 m .35212 .67907 L .35239 .67789 L F
.511 .554 .837 r
.35239 .67789 m .35253 .67373 L .35091 .67376 L F
.35239 .67789 m .35289 .67795 L .35253 .67373 L F
.437 .122 .331 r
.35239 .67789 m .3543 .67858 L .35289 .67795 L F
.35239 .67789 m .35212 .67907 L .3543 .67858 L F
.56 .472 .712 r
.38466 .67424 m .38541 .67633 L .38322 .67681 L F
.504 .287 .518 r
.38541 .67633 m .38298 .67907 L .38322 .67681 L F
.488 .038 .108 r
.41021 .72546 m .41195 .72636 L .41345 .72473 L F
.386 0 0 r
.41195 .72636 m .41562 .72497 L .41345 .72473 L F
.67 .172 .055 r
.48942 .77605 m .48778 .77617 L .48632 .77565 L F
.622 .098 0 r
.49089 .77673 m .48778 .77617 L .48942 .77605 L F
0 0 .247 r
.378 .80492 m .37742 .80323 L .37847 .80303 L F
.378 .80492 m .37783 .80609 L .37742 .80323 L F
.55 .386 .612 r
.35977 .76056 m .36182 .76259 L .36166 .76001 L F
.35977 .76056 m .35961 .76297 L .36182 .76259 L F
.103 0 0 r
.53001 .77139 m .52641 .77296 L .52865 .77273 L F
.018 0 0 r
.53196 .7706 m .53001 .77139 L .52865 .77273 L F
.634 .685 .88 r
.69614 .58671 m .69465 .58886 L .69394 .58737 L F
.69614 .58671 m .69698 .58834 L .69465 .58886 L F
.619 .501 .696 r
.38617 .7685 m .38651 .77075 L .3843 .77118 L F
.551 .501 .753 r
.50839 .74079 m .50735 .74477 L .50621 .74153 L F
.50839 .74079 m .50947 .74421 L .50735 .74477 L F
.041 .37 .838 r
.5103 .74734 m .50735 .74477 L .50947 .74421 L F
.626 .602 .806 r
.70089 .70892 m .70344 .71148 L .70343 .71109 L F
.691 .981 .867 r
.70344 .71148 m .70516 .70933 L .70343 .71109 L F
.70344 .71148 m .70647 .70926 L .70516 .70933 L F
.372 .118 .394 r
.35168 .71186 m .35113 .71395 L .34936 .71445 L F
.428 .184 .439 r
.35336 .71123 m .35113 .71395 L .35168 .71186 L F
.337 .743 .981 r
.47193 .72608 m .47411 .726 L .47536 .72674 L F
.493 .823 .999 r
.47411 .726 m .4775 .72633 L .47536 .72674 L F
.279 0 0 r
.43182 .78419 m .43026 .78542 L .42812 .78569 L F
.207 0 0 r
.43397 .78353 m .43026 .78542 L .43182 .78419 L F
.31 0 0 r
.33803 .67408 m .33656 .6754 L .33467 .67542 L F
.64 .2 .189 r
.33969 .67541 m .33656 .6754 L .33803 .67408 L F
.477 .141 .317 r
.33605 .70875 m .33823 .7085 L .33918 .70624 L F
.408 .089 .31 r
.33823 .7085 m .34111 .70574 L .33918 .70624 L F
.768 .775 .858 r
.6468 .60037 m .64809 .59766 L .64899 .60041 L F
.354 .809 .686 r
.39467 .79649 m .39781 .79503 L .39679 .79573 L F
.064 0 0 r
.39977 .79459 m .39679 .79573 L .39781 .79503 L F
.236 0 0 r
.36054 .65526 m .36442 .65553 L .362 .65609 L F
.569 .563 .807 r
.36442 .65635 m .362 .65609 L .36442 .65553 L F
.153 .695 .761 r
.45219 .73693 m .45083 .73701 L .44869 .73732 L F
.143 .688 .758 r
.45451 .73661 m .45083 .73701 L .45219 .73693 L F
.607 .083 0 r
.33639 .81099 m .33992 .81155 L .33751 .81178 L F
.06 0 .145 r
.34138 .81018 m .33992 .81155 L .34216 .80872 L F
.779 .955 .928 r
.33751 .81178 m .33992 .81155 L .34138 .81018 L F
.365 .176 .486 r
.63241 .60108 m .63428 .59818 L .63255 .59896 L F
.666 .29 .324 r
.64468 .60676 m .6478 .60686 L .64568 .60612 L F
.995 .869 .584 r
.71462 .63293 m .71618 .62998 L .71615 .62981 L F
.71462 .63293 m .71535 .63363 L .71618 .62998 L F
.448 .233 .493 r
.37831 .68418 m .37603 .68671 L .37644 .68481 L F
.767 .871 .443 r
.34138 .81018 m .34216 .80872 L .34245 .80758 L F
.321 .072 .371 r
.5305 .77841 m .53113 .77645 L .53287 .7757 L F
.163 0 0 r
.6475 .62063 m .64935 .6211 L .64884 .61984 L F
0 0 .136 r
.64884 .61984 m .64935 .6211 L .64976 .61891 L F
.254 0 .118 r
.38065 .6815 m .37864 .68211 L .3815 .68021 L F
.488 .237 .46 r
.38298 .67907 m .38065 .6815 L .3815 .68021 L F
.968 .65 .279 r
.65887 .62042 m .65991 .623 L .659 .62138 L F
.869 .757 .736 r
.65991 .623 m .65821 .62611 L .65678 .62495 L F
.65991 .623 m .65678 .62495 L .65889 .62427 L F
.257 .03 .365 r
.65919 .62469 m .65821 .62611 L .65991 .623 L F
.513 .621 .896 r
.66113 .62141 m .65991 .623 L .659 .62138 L F
.571 .823 .451 r
.66113 .62141 m .65991 .623 L .65889 .62427 L F
.881 .787 .293 r
.67302 .61255 m .67276 .61177 L .67176 .61141 L F
.67302 .61255 m .67264 .61498 L .67276 .61177 L F
.509 .261 .474 r
.34626 .78996 m .34821 .79202 L .34841 .78983 L F
.34626 .78996 m .34568 .79271 L .34821 .79202 L F
.585 .447 .66 r
.35633 .77371 m .35812 .77043 L .35616 .7709 L F
.232 0 0 r
.65302 .59599 m .65312 .59613 L .65089 .59585 L F
.985 .712 .412 r
.65302 .59599 m .65338 .59885 L .65215 .59685 L F
.65302 .59599 m .65215 .59685 L .65312 .59613 L F
.904 .843 .773 r
.64404 .64141 m .64422 .64418 L .6418 .64412 L F
.763 .606 .684 r
.34616 .81844 m .34825 .81842 L .343 .81637 L F
.783 .887 .92 r
.71942 .74156 m .72028 .74251 L .7222 .74134 L F
.679 .132 0 r
.50652 .75983 m .50792 .76048 L .506 .75887 L F
.692 .672 .825 r
.4797 .73632 m .4809 .73886 L .48312 .7381 L F
.645 .467 .628 r
.65653 .60745 m .65603 .61078 L .6539 .60966 L F
.789 .353 .214 r
.65653 .60745 m .65904 .60931 L .65932 .6093 L F
.823 .701 .73 r
.65904 .60931 m .65774 .61279 L .65673 .61136 L F
.65698 .61082 m .65673 .61136 L .65657 .61112 L F
.65904 .60931 m .65673 .61136 L .65698 .61082 L F
.553 .383 .605 r
.65805 .60845 m .65603 .61078 L .65653 .60745 L F
.65932 .6093 m .65724 .61023 L .65805 .60845 L F
.65724 .61023 m .65603 .61078 L .65805 .60845 L F
.254 0 .24 r
.34936 .71445 m .34856 .71677 L .34691 .71688 L F
.379 .061 .295 r
.35044 .71617 m .34936 .71445 L .35113 .71395 L F
.35044 .71617 m .34856 .71677 L .34936 .71445 L F
.898 .955 .615 r
.366 .80816 m .36744 .80865 L .3672 .81106 L F
.567 .386 .595 r
.3672 .81106 m .36744 .80865 L .366 .80816 L F
.3672 .81106 m .36943 .81087 L .36744 .80865 L F
.634 .95 .748 r
.3672 .81106 m .36744 .80865 L .36943 .81087 L F
.707 .226 .103 r
.68025 .63846 m .68334 .63948 L .68264 .64037 L F
.913 .527 .264 r
.68334 .63948 m .68393 .64089 L .68264 .64037 L F
.344 .322 .691 r
.38675 .76355 m .38622 .76549 L .38529 .76361 L F
.38675 .76355 m .38748 .76495 L .38622 .76549 L F
.559 .421 .65 r
.38779 .76812 m .38622 .76549 L .38748 .76495 L F
.38779 .76812 m .38617 .7685 L .38622 .76549 L F
.493 .185 .373 r
.34532 .69775 m .3475 .69746 L .34809 .69565 L F
.487 .18 .37 r
.34809 .69565 m .34952 .69708 L .35014 .69524 L F
.34809 .69565 m .3475 .69746 L .34952 .69708 L F
.831 .695 .714 r
.66889 .62777 m .66997 .631 L .67041 .62885 L F
.619 .724 .921 r
.65416 .60295 m .65343 .60523 L .65264 .60423 L F
.65416 .60295 m .65574 .60467 L .65343 .60523 L F
.303 .574 .935 r
.37364 .80524 m .37552 .8073 L .37707 .80753 L F
.399 0 .09 r
.31595 .68009 m .31405 .68077 L .31417 .68054 L F
.722 .778 .897 r
.49853 .88231 m .50061 .88125 L .49711 .88104 L F
.475 .889 .923 r
.72102 .621 m .72332 .62013 L .72385 .62038 L F
.506 .558 .844 r
.72251 .61757 m .72385 .62038 L .72374 .61769 L F
.981 .869 .498 r
.72385 .62038 m .72332 .62013 L .72374 .61769 L F
.645 .678 .867 r
.66316 .63977 m .66675 .64132 L .6659 .63886 L F
.779 .733 .811 r
.6659 .63886 m .66675 .64132 L .66906 .63912 L F
.847 .553 .491 r
.67833 .61223 m .67943 .61476 L .68125 .61517 L F
.799 .63 .672 r
.67761 .617 m .68125 .61517 L .67943 .61476 L F
.67761 .617 m .6807 .61754 L .68125 .61517 L F
.456 .219 .465 r
.38043 .68334 m .37864 .68211 L .38065 .6815 L F
.38043 .68334 m .37831 .68418 L .37864 .68211 L F
.482 0 .033 r
.41562 .72497 m .41787 .72519 L .41882 .72442 L F
.265 0 0 r
.41882 .72442 m .41787 .72519 L .42098 .72412 L F
.831 .501 .43 r
.48311 .76809 m .48341 .76994 L .48459 .76799 L F
.767 .417 .391 r
.48341 .76994 m .48671 .7705 L .48459 .76799 L F
.708 .426 .495 r
.48459 .76799 m .48671 .7705 L .4869 .76847 L F
.624 .386 .536 r
.60788 .67954 m .60804 .68163 L .60658 .68136 L F
.703 .47 .568 r
.61007 .67956 m .60804 .68163 L .60788 .67954 L F
.806 .661 .702 r
.69543 .71124 m .699 .71173 L .69853 .70931 L F
.801 .686 .737 r
.69652 .71429 m .699 .71173 L .69543 .71124 L F
.723 .554 .661 r
.69652 .71429 m .69967 .71453 L .699 .71173 L F
.747 .661 .765 r
.699 .71173 m .70089 .70892 L .69853 .70931 L F
.766 .486 .51 r
.70204 .71424 m .699 .71173 L .69967 .71453 L F
.551 .524 .778 r
.38852 .77042 m .38749 .7738 L .38651 .77075 L F
.38852 .77042 m .38952 .77341 L .38749 .7738 L F
.459 .361 .656 r
.38952 .77341 m .38806 .77582 L .38749 .7738 L F
.849 .571 .033 r
.58892 .6851 m .58919 .68701 L .58847 .68419 L F
.892 .98 .814 r
.58892 .6851 m .58847 .68419 L .59062 .68147 L F
.612 .427 .607 r
.6536 .6203 m .65132 .62266 L .65134 .62057 L F
.6536 .6203 m .65398 .62258 L .65132 .62266 L F
.676 .477 .609 r
.65667 .62027 m .65398 .62258 L .6536 .6203 L F
.067 0 0 r
.63476 .66301 m .63763 .66103 L .63671 .66254 L F
0 0 0 r
.63763 .66103 m .63802 .66146 L .63671 .66254 L F
.63763 .66103 m .63931 .65998 L .63802 .66146 L F
.783 .626 .686 r
.61301 .65249 m .61112 .65505 L .61416 .65532 L F
.753 .535 .6 r
.61097 .65752 m .61416 .65532 L .61112 .65505 L F
.61097 .65752 m .61425 .65784 L .61416 .65532 L F
0 0 0 r
.40774 .7923 m .40361 .7935 L .40579 .79289 L F
.493 0 0 r
.6539 .60966 m .65657 .61112 L .65437 .61198 L F
.6539 .60966 m .65603 .61078 L .65657 .61112 L F
.647 .483 .647 r
.58559 .67116 m .58804 .67422 L .58362 .67432 L F
.712 .491 .588 r
.58893 .67358 m .58559 .67116 L .58916 .67127 L F
.58893 .67358 m .58804 .67422 L .58559 .67116 L F
0 0 0 r
.3212 .67867 m .31848 .68093 L .31938 .67955 L F
.618 .776 .957 r
.34554 .67341 m .34895 .67395 L .34778 .67285 L F
.422 .766 .996 r
.34895 .67395 m .34954 .67294 L .34778 .67285 L F
.34895 .67395 m .35091 .67376 L .34954 .67294 L F
.261 0 0 r
.45614 .76863 m .45751 .76901 L .45921 .76786 L F
.244 0 0 r
.45751 .76901 m .46135 .76784 L .45921 .76786 L F
.818 .689 .722 r
.66913 .62985 m .66997 .631 L .66889 .62777 L F
.852 .683 .672 r
.66913 .62985 m .67016 .6333 L .66997 .631 L F
.5 .228 .433 r
.62318 .67842 m .62109 .67705 L .62347 .67637 L F
.62318 .67842 m .62102 .67884 L .62109 .67705 L F
.812 .999 .799 r
.58827 .65748 m .58739 .65832 L .58783 .65706 L F
.834 .998 .775 r
.58827 .65748 m .59008 .65441 L .59053 .65479 L F
.58827 .65748 m .58783 .65706 L .59008 .65441 L F
.168 0 0 r
.4655 .76687 m .46925 .76675 L .46704 .76603 L F
.74 .834 .923 r
.71345 .62574 m .71435 .62739 L .71076 .6276 L F
.855 .874 .853 r
.71565 .62509 m .71435 .62739 L .71345 .62574 L F
.461 .105 .275 r
.30849 .65711 m .30997 .65808 L .31127 .65554 L F
.434 .079 .261 r
.31127 .65554 m .31268 .65627 L .31333 .65508 L F
.31127 .65554 m .30997 .65808 L .31268 .65627 L F
.402 .057 .263 r
.37628 .73821 m .37918 .73576 L .37625 .73559 L F
.37628 .73821 m .37822 .73786 L .37918 .73576 L F
.546 .261 .434 r
.37822 .73786 m .381 .73528 L .37918 .73576 L F
.731 .552 .65 r
.64463 .63095 m .64828 .63127 L .64803 .63358 L F
.756 .561 .633 r
.64828 .63127 m .65115 .63422 L .64803 .63358 L F
.9 .986 .758 r
.69968 .72141 m .69939 .72306 L .70128 .7204 L F
.96 .767 .599 r
.69968 .72141 m .70128 .7204 L .70001 .71929 L F
.37 .176 .482 r
.71717 .71583 m .71871 .71637 L .71909 .71372 L F
.601 .375 .546 r
.60001 .68206 m .60248 .68407 L .60026 .68404 L F
.663 .349 .431 r
.60235 .68235 m .60248 .68407 L .60001 .68206 L F
.437 .253 .532 r
.35769 .70579 m .35568 .70858 L .35603 .70641 L F
.521 .371 .618 r
.36372 .75468 m .36577 .75437 L .36563 .75182 L F
.499 .334 .588 r
.36372 .75468 m .36557 .7567 L .36577 .75437 L F
.36372 .75468 m .36357 .75763 L .36557 .7567 L F
0 0 0 r
.32786 .73147 m .32792 .73101 L .32954 .72993 L F
.32786 .73147 m .32606 .73215 L .32792 .73101 L F
.687 .586 .737 r
.65398 .62258 m .65249 .62629 L .65132 .62266 L F
.122 .67 .712 r
.71949 .6262 m .72082 .62597 L .71835 .62633 L F
.447 .822 .992 r
.72082 .62597 m .72213 .6251 L .72046 .62601 L F
.122 .67 .712 r
.71949 .6262 m .7213 .62591 L .72082 .62597 L F
.006 0 0 r
.71835 .62633 m .72082 .62597 L .72005 .62623 L F
.447 .822 .992 r
.72082 .62597 m .72046 .62601 L .72005 .62623 L F
.122 .67 .712 r
.7213 .62591 m .72171 .62585 L .72082 .62597 L F
.632 .698 .893 r
.40311 .7813 m .40001 .7791 L .40157 .77878 L F
.584 .663 .892 r
.40273 .77825 m .40311 .7813 L .40157 .77878 L F
.40273 .77825 m .40534 .781 L .40311 .7813 L F
.763 .606 .684 r
.34616 .81844 m .343 .81637 L .3443 .8196 L F
.634 .618 .817 r
.50621 .74153 m .50405 .74226 L .50294 .74082 L F
.852 .683 .672 r
.66913 .62985 m .66686 .63295 L .67016 .6333 L F
.842 .743 .755 r
.66686 .63295 m .66789 .63605 L .67016 .6333 L F
.327 0 .143 r
.34775 .71836 m .34691 .71688 L .34856 .71677 L F
.34775 .71836 m .34578 .71883 L .34691 .71688 L F
.852 .932 .878 r
.68366 .6307 m .68687 .62888 L .68553 .6277 L F
.531 .23 .401 r
.5192 .78721 m .521 .78883 L .51904 .78937 L F
.5192 .78721 m .52154 .7871 L .521 .78883 L F
.536 .303 .509 r
.64448 .60229 m .64655 .60307 L .64419 .60364 L F
.735 .628 .74 r
.64316 .59859 m .64448 .60229 L .64104 .60128 L F
.767 .525 .568 r
.64104 .60128 m .64448 .60229 L .64419 .60364 L F
.612 .387 .552 r
.35008 .67949 m .35 .68206 L .35222 .68085 L F
.687 .222 .142 r
.35008 .67949 m .35222 .68085 L .3536 .68071 L F
.282 .746 .947 r
.34281 .65214 m .3442 .6526 L .34076 .65224 L F
.422 .822 .981 r
.34623 .65223 m .3442 .6526 L .34281 .65214 L F
.725 .441 .497 r
.4869 .76847 m .48671 .7705 L .49009 .77045 L F
.407 0 .083 r
.45845 .77593 m .45695 .77741 L .45476 .7776 L F
.349 0 .005 r
.46044 .77581 m .45695 .77741 L .45845 .77593 L F
.346 .794 .954 r
.45204 .72563 m .45384 .72537 L .45531 .72573 L F
.175 0 0 r
.45384 .72537 m .45764 .72573 L .45531 .72573 L F
.66 .66 .84 r
.48652 .74115 m .48852 .73905 L .48627 .73957 L F
.48652 .74115 m .48971 .74153 L .48852 .73905 L F
.837 .761 .779 r
.72142 .73849 m .72057 .74111 L .7222 .74134 L F
.783 .887 .92 r
.71942 .74156 m .7222 .74134 L .72057 .74111 L F
.956 .695 .246 r
.64768 .62441 m .6475 .62063 L .64494 .62258 L F
.64768 .62441 m .64709 .62395 L .6475 .62063 L F
.123 0 .203 r
.64709 .62395 m .64935 .6211 L .6475 .62063 L F
.615 .299 .411 r
.39618 .75184 m .39264 .75402 L .39401 .75181 L F
.404 .759 .994 r
.49283 .86958 m .49465 .87022 L .49265 .8704 L F
.665 .586 .757 r
.49465 .87022 m .49288 .87251 L .49265 .8704 L F
.764 .911 .529 r
.59423 .67106 m .59248 .67387 L .59349 .6722 L F
.367 0 .166 r
.43506 .77349 m .43589 .77518 L .43723 .77342 L F
.43506 .77349 m .43383 .7756 L .43589 .77518 L F
.564 .378 .588 r
.48488 .87293 m .48703 .87532 L .48694 .87283 L F
.48488 .87293 m .48483 .87582 L .48703 .87532 L F
.751 .84 .919 r
.4654 .73603 m .46653 .73681 L .46873 .7358 L F
.674 .977 .855 r
.33411 .65035 m .33246 .65075 L .33309 .65029 L F
.2 0 0 r
.33188 .6499 m .33411 .65035 L .33467 .65038 L F
.421 .618 .932 r
.33277 .64845 m .33411 .65035 L .33188 .6499 L F
.674 .977 .855 r
.33411 .65035 m .33309 .65029 L .33466 .64914 L F
.2 0 0 r
.33467 .65038 m .33411 .65035 L .3351 .65046 L F
.237 .702 .946 r
.33605 .64993 m .3351 .65046 L .33411 .65035 L F
.33605 .64993 m .33702 .65046 L .3351 .65046 L F
.584 .594 .829 r
.48841 .72766 m .48735 .73077 L .4862 .7281 L F
.48841 .72766 m .48945 .73038 L .48735 .73077 L F
0 .509 .71 r
.4981 .77828 m .49683 .77812 L .49456 .77784 L F
.466 0 0 r
.4981 .77828 m .50006 .77907 L .49683 .77812 L F
.519 .284 .498 r
.65568 .62831 m .65577 .631 L .65325 .63091 L F
.783 .774 .845 r
.65678 .62495 m .65568 .62831 L .65461 .6253 L F
.65678 .62495 m .65821 .62611 L .65568 .62831 L F
.627 .367 .504 r
.65804 .63034 m .65577 .631 L .65568 .62831 L F
.24 .354 .779 r
.65568 .62831 m .65804 .63034 L .65692 .62733 L F
.907 .983 .767 r
.59797 .6447 m .59798 .64311 L .59983 .64198 L F
.882 .975 .836 r
.60204 .63936 m .59983 .64198 L .59916 .6414 L F
.941 .955 .748 r
.59983 .64198 m .59798 .64311 L .59916 .6414 L F
.736 .713 .83 r
.35 .68206 m .35381 .68334 L .35222 .68085 L F
.222 .231 .658 r
.35381 .68334 m .35479 .68065 L .35222 .68085 L F
.459 .361 .656 r
.38952 .77341 m .38978 .77574 L .38806 .77582 L F
.522 .516 .79 r
.39105 .77886 m .38806 .77582 L .38978 .77574 L F
.717 .67 .803 r
.35173 .80561 m .35294 .80835 L .34989 .80867 L F
.388 0 0 r
.34989 .80867 m .35294 .80835 L .35085 .80951 L F
.634 .493 .673 r
.35506 .80579 m .35571 .80708 L .35294 .80835 L F
0 0 0 r
.35294 .80835 m .354 .80856 L .35085 .80951 L F
.35294 .80835 m .35571 .80708 L .354 .80856 L F
.003 .275 .776 r
.72891 .71894 m .72987 .71857 L .72713 .71749 L F
.72891 .71894 m .73063 .72017 L .72987 .71857 L F
.339 .809 .728 r
.41162 .79101 m .41019 .79173 L .41363 .7906 L F
.41162 .79101 m .40979 .7918 L .41019 .79173 L F
.723 .53 .629 r
.61423 .66023 m .61772 .658 L .61425 .65784 L F
.61423 .66023 m .61756 .66035 L .61772 .658 L F
.797 .951 .614 r
.59797 .6447 m .59596 .6477 L .59653 .64618 L F
.925 .959 .641 r
.59653 .64618 m .59798 .64311 L .59797 .6447 L F
.162 .696 .702 r
.41162 .79101 m .41363 .7906 L .41561 .79016 L F
.896 .92 .83 r
.67737 .59028 m .67983 .58879 L .67934 .58829 L F
.459 .602 .906 r
.67983 .58879 m .68158 .58715 L .67934 .58829 L F
.67983 .58879 m .68195 .58891 L .68158 .58715 L F
.92 .53 .151 r
.67814 .61369 m .67833 .61223 L .67841 .61075 L F
.67814 .61369 m .67943 .61476 L .67833 .61223 L F
.285 0 0 r
.4396 .78166 m .44019 .78249 L .43824 .78311 L F
.4396 .78166 m .44186 .78161 L .44019 .78249 L F
.541 .271 .456 r
.47777 .76729 m .47998 .76715 L .47779 .76573 L F
.807 .998 .847 r
.64133 .62809 m .6424 .62612 L .64343 .626 L F
.498 .907 .845 r
.6424 .62612 m .64629 .62466 L .64343 .626 L F
.134 0 .099 r
.63476 .66301 m .63671 .66254 L .63414 .66485 L F
.8 .887 .908 r
.36672 .65507 m .36442 .65553 L .36616 .6543 L F
.704 .333 .342 r
.36672 .65507 m .3659 .65698 L .36442 .65553 L F
.443 .722 .984 r
.36672 .65507 m .3681 .65417 L .36616 .6543 L F
0 0 0 r
.3681 .65417 m .3659 .65698 L .36672 .65507 L F
.461 .514 .827 r
.35253 .67373 m .35289 .67795 L .35515 .67507 L F
.509 .483 .763 r
.3543 .67858 m .35515 .67507 L .35289 .67795 L F
.721 .723 .851 r
.70014 .58852 m .69698 .58834 L .69944 .58728 L F
.643 .591 .781 r
.70145 .58509 m .70014 .58852 L .69944 .58728 L F
.70145 .58509 m .70248 .58783 L .70014 .58852 L F
.565 .634 .878 r
.51219 .74641 m .51037 .74741 L .5103 .74734 L F
.51219 .74641 m .51297 .74713 L .51037 .74741 L F
.401 0 0 r
.43763 .72383 m .4397 .72421 L .44108 .72369 L F
.194 0 0 r
.4397 .72421 m .44327 .72378 L .44108 .72369 L F
.901 .906 .818 r
.6703 .61705 m .66971 .6162 L .66999 .61631 L F
.6703 .61705 m .66985 .61754 L .66971 .6162 L F
.887 .98 .69 r
.6703 .61705 m .67276 .61177 L .67264 .61498 L F
.6703 .61705 m .66999 .61631 L .67276 .61177 L F
.245 0 0 r
.33139 .71084 m .33334 .7104 L .33428 .70947 L F
.052 0 0 r
.33428 .70947 m .33334 .7104 L .33605 .70875 L F
.861 .756 .746 r
.61171 .65186 m .61301 .65249 L .61211 .64954 L F
.846 .726 .731 r
.60968 .65424 m .61301 .65249 L .61171 .65186 L F
.60968 .65424 m .61112 .65505 L .61301 .65249 L F
.909 .776 .702 r
.61211 .64954 m .61301 .65249 L .61336 .6502 L F
.703 .47 .568 r
.61007 .67956 m .61024 .68194 L .60804 .68163 L F
.64 .422 .572 r
.61362 .68137 m .61007 .67956 L .6134 .67939 L F
.61362 .68137 m .61024 .68194 L .61007 .67956 L F
.742 .873 .941 r
.7055 .59218 m .70931 .59159 L .70803 .58994 L F
.678 .692 .856 r
.70931 .59159 m .71142 .59055 L .70803 .58994 L F
.509 .886 .97 r
.38709 .81119 m .38586 .80868 L .38691 .80866 L F
.153 0 0 r
.38792 .80886 m .38691 .80866 L .38586 .80868 L F
.682 .544 .692 r
.38691 .80866 m .38948 .80874 L .38709 .81119 L F
.153 0 0 r
.38792 .80886 m .38948 .80874 L .38691 .80866 L F
0 .104 .657 r
.66262 .58781 m .6655 .59153 L .66411 .59038 L F
.536 .008 0 r
.66525 .5916 m .66636 .59249 L .66546 .59165 L F
.66525 .5916 m .66546 .59165 L .66411 .59038 L F
.66525 .5916 m .66411 .59038 L .6655 .59153 L F
.508 0 0 r
.66504 .59155 m .66525 .5916 L .66475 .59039 L F
.66515 .592 m .66525 .5916 L .66504 .59155 L F
.646 .119 0 r
.64109 .61625 m .6387 .6162 L .63914 .6175 L F
.64109 .61625 m .6401 .61736 L .6387 .6162 L F
.853 .781 .78 r
.64516 .61706 m .64682 .61478 L .64548 .61378 L F
.64516 .61706 m .64548 .61378 L .64345 .61659 L F
.943 .729 .585 r
.64351 .61886 m .64516 .61706 L .64345 .61659 L F
.512 .843 .553 r
.64548 .61378 m .64683 .61245 L .64451 .61074 L F
.64548 .61378 m .64747 .61195 L .64683 .61245 L F
.804 .847 .883 r
.64548 .61378 m .64241 .61367 L .64345 .61659 L F
.64548 .61378 m .64467 .61194 L .64241 .61367 L F
.572 .258 .397 r
.64467 .61194 m .64601 .61438 L .64348 .61705 L F
.6432 .61696 m .64348 .61705 L .64303 .61752 L F
.847 .761 .767 r
.64345 .61659 m .64262 .61678 L .64109 .61625 L F
.64262 .61678 m .6401 .61736 L .64106 .61629 L F
.64262 .61678 m .64106 .61629 L .64109 .61625 L F
.64345 .61659 m .64241 .61367 L .6401 .61736 L F
.572 .258 .397 r
.64467 .61194 m .64348 .61705 L .6432 .61696 L F
.928 .95 .784 r
.59596 .6477 m .59406 .64863 L .59653 .64618 L F
.59596 .6477 m .59489 .64917 L .59406 .64863 L F
.271 .378 .789 r
.67218 .59217 m .66975 .59028 L .67173 .59009 L F
.925 .613 .144 r
.67131 .59018 m .66975 .59028 L .66936 .59071 L F
.67131 .59018 m .67173 .59009 L .66975 .59028 L F
0 0 0 r
.72927 .62021 m .72852 .62173 L .72695 .62291 L F
.302 .333 .727 r
.72877 .61693 m .73108 .6192 L .72927 .62021 L F
0 0 0 r
.73108 .6192 m .72852 .62173 L .72927 .62021 L F
.836 .663 .669 r
.69433 .70822 m .69838 .70894 L .69743 .70615 L F
.806 .661 .702 r
.69543 .71124 m .69853 .70931 L .69838 .70894 L F
0 0 0 r
.69719 .71017 m .69543 .71124 L .69594 .71084 L F
.69719 .71017 m .69594 .71084 L .69838 .70894 L F
.69719 .71017 m .69838 .70894 L .69433 .70822 L F
.091 .019 .473 r
.69433 .70822 m .69554 .71036 L .69719 .71017 L F
.404 .858 .873 r
.69719 .71017 m .69554 .71036 L .69787 .7098 L F
.69719 .71017 m .69787 .7098 L .69901 .70953 L F
.255 .322 .74 r
.69838 .70894 m .69853 .70931 L .69743 .70615 L F
.541 .406 .646 r
.3862 .76082 m .38675 .76355 L .38529 .76361 L F
.901 .986 .751 r
.63934 .62942 m .64133 .62809 L .63999 .63072 L F
.63934 .62942 m .64073 .62776 L .64133 .62809 L F
.807 .998 .847 r
.64133 .62809 m .64073 .62776 L .6424 .62612 L F
.798 .658 .708 r
.66789 .63605 m .6659 .63886 L .66906 .63912 L F
.735 .881 .948 r
.42485 .74246 m .42836 .742 L .4264 .74248 L F
.57 .94 .862 r
.42929 .74098 m .42836 .742 L .43012 .74093 L F
.42929 .74098 m .4264 .74248 L .42836 .742 L F
.505 0 0 r
.68393 .64089 m .68597 .64236 L .68609 .64259 L F
0 .499 .853 r
.68906 .64387 m .68609 .64259 L .68597 .64236 L F
.64 .558 .746 r
.49347 .74637 m .49524 .74366 L .49298 .74419 L F
.49347 .74637 m .49621 .74726 L .49524 .74366 L F
.745 .709 .817 r
.35173 .80561 m .34989 .80867 L .34817 .80521 L F
.388 0 0 r
.34989 .80867 m .35085 .80951 L .34958 .811 L F
.41 .555 .888 r
.3659 .65698 m .36503 .65851 L .36442 .65635 L F
.3659 .65698 m .3675 .65946 L .36503 .65851 L F
.939 .694 .539 r
.72725 .74035 m .72813 .74186 L .72826 .73993 L F
.381 0 0 r
.72826 .73993 m .72896 .74067 L .72725 .74035 L F
.573 .421 .636 r
.65325 .63091 m .65356 .63371 L .65115 .63422 L F
.509 .303 .536 r
.3696 .74631 m .37182 .74366 L .36969 .74399 L F
.609 .583 .799 r
.50312 .75199 m .50416 .74863 L .50191 .74922 L F
.50312 .75199 m .50529 .75157 L .50416 .74863 L F
.917 .963 .65 r
.71102 .71442 m .71061 .71416 L .71217 .71113 L F
.993 .846 .589 r
.71118 .71605 m .71061 .71416 L .71102 .71442 L F
.315 .398 .789 r
.67962 .60318 m .67827 .60435 L .67806 .60318 L F
.531 .53 .8 r
.67962 .60318 m .67856 .60663 L .67827 .60435 L F
.854 .998 .794 r
.6416 .64173 m .6388 .64407 L .64028 .64249 L F
.708 .972 .747 r
.64028 .64249 m .64246 .64036 L .6416 .64173 L F
.51 .742 .979 r
.64246 .64036 m .64404 .64141 L .6416 .64173 L F
.904 .843 .773 r
.64404 .64141 m .6418 .64412 L .6416 .64173 L F
.615 .576 .787 r
.51539 .75946 m .51659 .7623 L .51845 .762 L F
.533 .393 .637 r
.36563 .75182 m .36743 .74904 L .36528 .74942 L F
.751 .712 .816 r
.34378 .79479 m .34722 .79509 L .34568 .79271 L F
.899 .954 .827 r
.34431 .79726 m .34722 .79509 L .34378 .79479 L F
.282 .296 .697 r
.34722 .79509 m .34821 .79202 L .34568 .79271 L F
.34722 .79509 m .34889 .79607 L .34821 .79202 L F
.238 .304 .729 r
.34722 .79509 m .3493 .79723 L .34889 .79607 L F
.387 .337 .68 r
.34737 .79643 m .3493 .79723 L .34722 .79509 L F
.688 .952 .954 r
.71217 .63584 m .71188 .63516 L .71005 .63628 L F
.784 .947 .928 r
.71217 .63584 m .71462 .63293 L .71188 .63516 L F
.71217 .63584 m .71535 .63363 L .71462 .63293 L F
.245 0 0 r
.47682 .77409 m .47573 .77488 L .47348 .77498 L F
.173 0 0 r
.47908 .77523 m .47573 .77488 L .47682 .77409 L F
.971 .839 .655 r
.69787 .72434 m .69939 .72306 L .69968 .72141 L F
.69787 .72434 m .69892 .725 L .69939 .72306 L F
.403 .641 .953 r
.686 .58917 m .68913 .59078 L .68873 .5888 L F
.366 .497 .858 r
.68873 .5888 m .68913 .59078 L .69052 .58946 L F
.319 .418 .806 r
.68913 .59078 m .69172 .59256 L .69052 .58946 L F
.5 .411 .686 r
.68913 .59078 m .68992 .59359 L .69172 .59256 L F
.42 .179 .44 r
.37381 .68934 m .37359 .69206 L .37219 .69054 L F
.495 .292 .533 r
.37359 .69206 m .37146 .69486 L .37219 .69054 L F
.562 .912 .704 r
.647 .6548 m .64966 .65279 L .64826 .65355 L F
.565 .915 .714 r
.647 .6548 m .64826 .65355 L .64473 .65612 L F
.882 .975 .836 r
.60204 .63936 m .59916 .6414 L .60009 .63998 L F
.898 .974 .814 r
.60418 .63657 m .60204 .63936 L .60227 .63733 L F
.891 .971 .828 r
.60227 .63733 m .60204 .63936 L .60009 .63998 L F
.964 .851 .682 r
.58739 .65832 m .58566 .65978 L .58783 .65706 L F
.58739 .65832 m .58673 .66053 L .58566 .65978 L F
.479 .43 .726 r
.28742 .61119 m .28943 .6114 L .28765 .61219 L F
.49 .429 .716 r
.28943 .6114 m .28815 .61483 L .28765 .61219 L F
0 0 0 r
.34153 .7219 m .33889 .72419 L .34011 .72285 L F
.458 .267 .533 r
.34737 .79643 m .34747 .79813 L .3493 .79723 L F
.44 .338 .643 r
.38876 .76116 m .3862 .76082 L .38856 .75931 L F
.38876 .76116 m .38675 .76355 L .3862 .76082 L F
.655 .376 .485 r
.6134 .67939 m .61563 .68143 L .61362 .68137 L F
.666 .373 .467 r
.61543 .6796 m .61563 .68143 L .6134 .67939 L F
.648 .804 .958 r
.48091 .72659 m .4775 .72633 L .47926 .72585 L F
.56 .828 .996 r
.48321 .72586 m .48091 .72659 L .47926 .72585 L F
.563 .032 0 r
.28591 .61097 m .28943 .6114 L .28742 .61119 L F
.102 .57 .911 r
.69756 .64225 m .69864 .64205 L .69678 .64208 L F
.69756 .64225 m .69972 .64277 L .69864 .64205 L F
.296 .345 .744 r
.48724 .88081 m .48726 .87768 L .48571 .87925 L F
.48724 .88081 m .48828 .88058 L .48726 .87768 L F
.683 .672 .833 r
.48852 .73905 m .48971 .74153 L .4921 .74082 L F
.642 .569 .757 r
.48971 .74153 m .49298 .74419 L .4921 .74082 L F
.965 .724 .524 r
.35674 .6848 m .35663 .68711 L .35535 .6845 L F
.542 .357 .579 r
.35674 .6848 m .35882 .6844 L .35889 .68208 L F
.35674 .6848 m .35882 .6844 L .35889 .68208 L F
.546 .158 .257 r
.32493 .65075 m .32858 .64869 L .32661 .64862 L F
.298 0 0 r
.43935 .77306 m .44148 .7727 L .4429 .77119 L F
.222 0 0 r
.4429 .77119 m .44352 .77221 L .44488 .77058 L F
.4429 .77119 m .44148 .7727 L .44352 .77221 L F
.626 .762 .944 r
.49497 .88189 m .49585 .87991 L .49388 .8814 L F
.49497 .88189 m .49711 .88104 L .49585 .87991 L F
.751 .84 .919 r
.4654 .73603 m .46873 .7358 L .46745 .73512 L F
.26 .759 .895 r
.47088 .73511 m .46745 .73512 L .46873 .7358 L F
.651 .653 .839 r
.46873 .7358 m .47183 .73662 L .47088 .73511 L F
.35 .474 .844 r
.36923 .65977 m .3683 .66139 L .3675 .65946 L F
.36923 .65977 m .37058 .66257 L .3683 .66139 L F
.672 .399 .499 r
.58362 .67432 m .58325 .67605 L .58148 .67601 L F
.695 .512 .636 r
.58804 .67422 m .58325 .67605 L .58362 .67432 L F
.864 .986 .712 r
.60617 .63371 m .60418 .63657 L .60471 .63466 L F
.858 .984 .852 r
.60617 .63371 m .60769 .63089 L .60848 .63112 L F
.60617 .63371 m .60557 .63315 L .60769 .63089 L F
.966 .938 .67 r
.60471 .63466 m .60557 .63315 L .60617 .63371 L F
.659 .656 .836 r
.47088 .73511 m .47183 .73662 L .47413 .73609 L F
.608 .471 .669 r
.30549 .68482 m .3024 .6861 L .30349 .68479 L F
.529 0 0 r
.31877 .71611 m .32059 .71675 L .32158 .71641 L F
.012 0 0 r
.32059 .71675 m .32353 .71596 L .32158 .71641 L F
.261 0 0 r
.65774 .58526 m .65692 .5849 L .65605 .58614 L F
0 0 0 r
.65654 .58543 m .65457 .58656 L .65605 .58614 L F
.65529 .586 m .65774 .58526 L .65605 .58614 L F
.65529 .586 m .65742 .58559 L .65771 .58529 L F
.65758 .58531 m .65771 .58529 L .65774 .58526 L F
.65529 .586 m .65771 .58529 L .65758 .58531 L F
.65692 .5849 m .65608 .58549 L .65654 .58543 L F
.65608 .58549 m .65457 .58656 L .65654 .58543 L F
.261 0 0 r
.65774 .58526 m .65968 .58471 L .65692 .5849 L F
0 .48 .703 r
.46317 .73616 m .46184 .73593 L .45983 .73561 L F
.261 0 0 r
.4654 .73603 m .46184 .73593 L .46317 .73616 L F
.491 .101 .229 r
.31529 .65466 m .31757 .65461 L .31886 .65259 L F
.352 0 .147 r
.31886 .65259 m .31964 .65414 L .32089 .65219 L F
.31886 .65259 m .31757 .65461 L .31964 .65414 L F
.832 .848 .859 r
.73152 .7342 m .73204 .73558 L .73438 .73315 L F
.607 .252 .342 r
.39117 .73234 m .3947 .7303 L .39166 .73096 L F
.39117 .73234 m .39361 .73241 L .3947 .7303 L F
.407 .024 .196 r
.39361 .73241 m .39687 .7301 L .3947 .7303 L F
.619 .588 .797 r
.49288 .73295 m .49069 .73352 L .48945 .73038 L F
.749 .46 .493 r
.50449 .77527 m .50779 .77354 L .50459 .77368 L F
.50449 .77527 m .50795 .77562 L .50779 .77354 L F
.815 .339 .072 r
.51018 .78424 m .50877 .78387 L .50696 .7815 L F
.787 .299 .055 r
.51218 .78642 m .50877 .78387 L .51018 .78424 L F
.773 .297 .107 r
.51373 .78657 m .51218 .78642 L .51018 .78424 L F
.716 .849 .945 r
.69513 .5958 m .69656 .59698 L .69838 .59571 L F
.79 .983 .9 r
.70574 .63949 m .70251 .64104 L .70344 .64188 L F
.898 .974 .814 r
.60418 .63657 m .60227 .63733 L .60333 .63615 L F
.823 .977 .89 r
.60418 .63657 m .60333 .63615 L .60471 .63466 L F
.564 0 0 r
.72562 .70995 m .72577 .70953 L .72318 .70834 L F
.62 .059 0 r
.72562 .70995 m .72854 .71184 L .72577 .70953 L F
.942 .774 .645 r
.67544 .63096 m .67416 .63105 L .67457 .62789 L F
.984 .755 .355 r
.67544 .63096 m .67481 .63212 L .67416 .63105 L F
.67544 .63096 m .67545 .63384 L .67481 .63212 L F
0 0 .557 r
.66971 .6162 m .66985 .61754 L .66904 .61447 L F
0 0 .284 r
.66985 .61754 m .6703 .61949 L .67035 .61845 L F
.805 .669 .714 r
.66971 .6162 m .6703 .61949 L .66985 .61754 L F
0 0 .284 r
.66985 .61754 m .67035 .61845 L .66971 .6162 L F
.757 .992 .878 r
.70366 .70664 m .70089 .70892 L .70081 .70812 L F
0 .089 .578 r
.70089 .70892 m .70191 .7097 L .70081 .70812 L F
.70089 .70892 m .70343 .71109 L .70191 .7097 L F
.559 .654 .9 r
.72859 .73455 m .73005 .73208 L .72793 .73238 L F
.72859 .73455 m .73152 .7342 L .73005 .73208 L F
.46 .886 .892 r
.38544 .7994 m .38461 .80014 L .38686 .79933 L F
.481 .858 .639 r
.38266 .80142 m .38461 .80014 L .38544 .7994 L F
.418 0 .085 r
.35222 .68085 m .35561 .67952 L .3536 .68071 L F
.099 0 0 r
.3536 .68071 m .35479 .68065 L .35561 .67952 L F
.691 .552 .692 r
.6588 .61785 m .65887 .62042 L .65667 .62027 L F
.298 0 0 r
.40405 .74948 m .40032 .75079 L .40164 .74925 L F
.608 .507 .714 r
.35092 .787 m .35249 .78393 L .35039 .78427 L F
.077 0 0 r
.33201 .67563 m .33094 .67568 L .32905 .67559 L F
.319 0 0 r
.33467 .67542 m .33094 .67568 L .33201 .67563 L F
.079 0 .033 r
.72695 .62291 m .72638 .62449 L .72459 .62511 L F
0 0 0 r
.72852 .62173 m .72638 .62449 L .72695 .62291 L F
.623 .655 .86 r
.37856 .66994 m .37532 .66822 L .37715 .66861 L F
.489 .765 .992 r
.37936 .66868 m .37856 .66994 L .37715 .66861 L F
.37936 .66868 m .38146 .66981 L .37856 .66994 L F
.679 .528 .673 r
.35232 .77926 m .35242 .78151 L .35469 .77883 L F
.456 .77 .997 r
.38966 .79793 m .3905 .79826 L .39149 .79765 L F
.451 .883 .837 r
.39149 .79765 m .3905 .79826 L .39467 .79649 L F
.731 .552 .65 r
.64463 .63095 m .64803 .63358 L .64447 .6334 L F
.763 .5 .536 r
.66789 .62496 m .67115 .6229 L .67091 .62177 L F
.874 .439 .047 r
.67337 .62756 m .67298 .62707 L .67175 .62503 L F
.763 .5 .536 r
.66789 .62496 m .67175 .62503 L .67066 .62321 L F
.764 .729 .82 r
.66789 .62496 m .66889 .62777 L .67175 .62503 L F
.603 .851 .991 r
.66789 .62496 m .67175 .62503 L .67066 .6242 L F
.874 .439 .047 r
.67298 .62707 m .67066 .6242 L .67175 .62503 L F
.763 .5 .536 r
.67066 .62321 m .67175 .62503 L .67115 .6229 L F
.947 .59 .231 r
.67115 .6229 m .67066 .6242 L .67091 .62177 L F
.67115 .6229 m .67175 .62503 L .67066 .6242 L F
.509 .886 .97 r
.38709 .81119 m .38376 .81155 L .38586 .80868 L F
.38376 .81155 m .38709 .81119 L .38585 .8107 L F
.866 .957 .865 r
.38709 .81119 m .38792 .80886 L .38585 .8107 L F
.38765 .81061 m .38948 .80874 L .38792 .80886 L F
.933 .884 .761 r
.38965 .80739 m .38948 .80874 L .38792 .80886 L F
.38792 .80886 m .38948 .80874 L .38965 .80739 L F
.38965 .80739 m .38792 .80886 L .39006 .80512 L F
.38792 .80886 m .38965 .80739 L .38959 .8092 L F
.8 .697 .751 r
.39006 .80512 m .38792 .80886 L .38694 .80653 L F
.246 .382 .803 r
.38809 .80769 m .38792 .80886 L .38959 .8092 L F
.38694 .80653 m .38792 .80886 L .38809 .80769 L F
.866 .957 .865 r
.38709 .81119 m .38765 .81061 L .38792 .80886 L F
.676 .477 .609 r
.65667 .62027 m .65655 .62262 L .65398 .62258 L F
.683 .427 .529 r
.65667 .62027 m .65887 .62042 L .659 .62138 L F
.709 .92 .579 r
.65829 .62002 m .65667 .62027 L .659 .62138 L F
.65829 .62002 m .65655 .62262 L .65667 .62027 L F
.673 .515 .663 r
.36779 .83845 m .36957 .83681 L .3676 .83648 L F
.762 .357 .286 r
.50696 .7815 m .50574 .78304 L .50404 .78099 L F
.783 .387 .303 r
.50696 .7815 m .50877 .78387 L .50574 .78304 L F
.901 .976 .684 r
.59053 .65479 m .5919 .65133 L .59288 .65195 L F
.59053 .65479 m .59008 .65441 L .5919 .65133 L F
.49 .429 .716 r
.28943 .6114 m .29016 .6139 L .28815 .61483 L F
.228 .093 .479 r
.29016 .6139 m .28838 .61732 L .28815 .61483 L F
.692 .672 .825 r
.4797 .73632 m .48312 .7381 L .48181 .73553 L F
.637 .667 .862 r
.48181 .73553 m .48312 .7381 L .48534 .73756 L F
.632 .606 .806 r
.48312 .7381 m .48627 .73957 L .48534 .73756 L F
.633 .865 .986 r
.66659 .59298 m .66788 .59326 L .66636 .59249 L F
.397 0 0 r
.66788 .59326 m .66903 .59403 L .66636 .59249 L F
.66788 .59326 m .67025 .59457 L .66903 .59403 L F
.661 .408 .528 r
.60658 .68136 m .60248 .68407 L .60235 .68235 L F
.687 .586 .737 r
.65398 .62258 m .65461 .6253 L .65249 .62629 L F
.697 .689 .839 r
.47413 .73609 m .47738 .73683 L .47631 .73551 L F
.618 .755 .944 r
.47738 .73683 m .47846 .7351 L .47631 .73551 L F
.47738 .73683 m .4797 .73632 L .47846 .7351 L F
.705 .774 .906 r
.71871 .71637 m .72015 .71791 L .72195 .71671 L F
.702 .654 .799 r
.51503 .74616 m .51406 .74987 L .51297 .74713 L F
.313 0 .007 r
.39428 .70825 m .39638 .70791 L .39778 .70627 L F
.957 .693 .495 r
.39778 .70627 m .39638 .70791 L .39792 .70871 L F
.475 .887 .931 r
.30944 .71863 m .31348 .71792 L .31091 .71906 L F
.996 .859 .57 r
.66825 .61388 m .66904 .61447 L .66968 .61242 L F
.604 .348 .502 r
.5969 .68474 m .5947 .68683 L .59477 .68479 L F
.219 .688 .942 r
.43591 .74123 m .43228 .74045 L .4335 .74126 L F
.617 .43 .607 r
.43591 .74123 m .4335 .7437 L .4335 .74126 L F
.432 .734 .99 r
.35019 .65169 m .34963 .65285 L .34826 .65191 L F
.35019 .65169 m .35165 .65277 L .34963 .65285 L F
.549 .531 .788 r
.51219 .74641 m .5103 .74734 L .50947 .74421 L F
.67 .654 .826 r
.69975 .6281 m .69798 .63022 L .69667 .62752 L F
.757 .709 .807 r
.51061 .73833 m .51176 .74136 L .50839 .74079 L F
.634 .551 .743 r
.51172 .74354 m .50839 .74079 L .51176 .74136 L F
.776 .718 .799 r
.51389 .73846 m .51176 .74136 L .51061 .73833 L F
.698 .331 .349 r
.51176 .74136 m .51409 .74322 L .51172 .74354 L F
.215 .286 .722 r
.357 .80783 m .35506 .80579 L .35753 .80555 L F
.357 .80783 m .35571 .80708 L .35506 .80579 L F
0 .219 .731 r
.35506 .80579 m .357 .80783 L .35753 .80555 L F
.657 .53 .698 r
.7239 .74405 m .72813 .74186 L .72725 .74035 L F
.429 .016 .151 r
.4012 .72963 m .40463 .72762 L .40246 .72773 L F
.091 0 0 r
.63247 .66567 m .63169 .66708 L .62975 .668 L F
0 0 0 r
.63414 .66485 m .63169 .66708 L .63247 .66567 L F
.277 .778 .866 r
.69363 .71156 m .69543 .71124 L .69437 .71117 L F
.746 .659 .764 r
.69326 .71396 m .69543 .71124 L .69317 .71164 L F
.69326 .71396 m .69652 .71429 L .69543 .71124 L F
.755 .238 0 r
.69437 .71117 m .69558 .71267 L .69391 .7119 L F
.69437 .71117 m .69391 .7119 L .69507 .7108 L F
.69437 .71117 m .69507 .7108 L .69554 .71036 L F
.277 .778 .866 r
.69317 .71164 m .69363 .71156 L .69437 .71117 L F
.946 .855 .719 r
.66754 .60573 m .66967 .60405 L .66816 .60098 L F
.66754 .60573 m .66859 .6067 L .66967 .60405 L F
0 .032 .589 r
.67214 .60619 m .67123 .60327 L .66967 .60405 L F
.162 0 0 r
.4177 .78973 m .42113 .78743 L .41975 .78916 L F
.293 0 .017 r
.41975 .78916 m .42113 .78743 L .42315 .78701 L F
.443 .035 .169 r
.44724 .77881 m .44599 .78077 L .4438 .78089 L F
.249 0 .059 r
.44798 .78007 m .44724 .77881 L .44938 .77871 L F
.44798 .78007 m .44599 .78077 L .44724 .77881 L F
.182 0 0 r
.489 .86983 m .48814 .87007 L .48585 .8699 L F
.496 .892 .743 r
.489 .86983 m .48814 .87007 L .48999 .86897 L F
.737 .571 .668 r
.69653 .71683 m .69967 .71453 L .69652 .71429 L F
.69653 .71683 m .69993 .7169 L .69967 .71453 L F
.675 .526 .675 r
.69967 .71453 m .69993 .7169 L .70204 .71424 L F
.798 .372 .235 r
.68357 .63546 m .68422 .63396 L .68128 .63306 L F
.616 .165 .158 r
.68681 .63544 m .68422 .63396 L .68357 .63546 L F
.992 .792 .536 r
.68681 .63544 m .68746 .63377 L .68422 .63396 L F
.555 .797 .989 r
.52521 .84556 m .52689 .84658 L .52293 .8461 L F
.52521 .84556 m .52689 .84658 L .52293 .8461 L F
.842 .457 .319 r
.50191 .74922 m .49805 .74691 L .49979 .74944 L F
.50191 .74922 m .50083 .74955 L .49805 .74691 L F
.847 .992 .845 r
.50306 .74628 m .50191 .74922 L .50416 .74863 L F
.50306 .74628 m .50083 .74955 L .50191 .74922 L F
.659 .909 .589 r
.61071 .62853 m .60848 .63112 L .60944 .62969 L F
.691 .975 .912 r
.60944 .62969 m .60848 .63112 L .60769 .63089 L F
.536 .097 .153 r
.44657 .73773 m .44551 .7396 L .44321 .73846 L F
.552 .179 .289 r
.44869 .73732 m .44551 .7396 L .44657 .73773 L F
.231 .728 .912 r
.37014 .805 m .372 .8054 L .37364 .80524 L F
.971 .662 .29 r
.67973 .61671 m .6807 .61754 L .67761 .617 L F
.67973 .61671 m .68096 .61966 L .6807 .61754 L F
.906 .496 .161 r
.68336 .61917 m .6807 .61754 L .68096 .61966 L F
.558 .176 .273 r
.38879 .73224 m .39117 .73234 L .39166 .73096 L F
.675 .615 .781 r
.49621 .74726 m .49979 .74944 L .49805 .74691 L F
.483 .9 .879 r
.71828 .62194 m .7196 .62096 L .72102 .621 L F
.71828 .62194 m .71746 .62188 L .7196 .62096 L F
.547 .45 .696 r
.38852 .77042 m .38617 .7685 L .38779 .76812 L F
.38852 .77042 m .38651 .77075 L .38617 .7685 L F
.008 0 0 r
.46355 .77571 m .46252 .77576 L .46044 .77581 L F
0 0 0 r
.46583 .77564 m .46252 .77576 L .46355 .77571 L F
.522 .507 .78 r
.48483 .87582 m .48571 .87925 L .48726 .87768 L F
.418 0 .085 r
.35222 .68085 m .35479 .68065 L .35561 .67952 L F
.323 .299 .678 r
.35479 .68065 m .3543 .67858 L .35561 .67952 L F
.79 .983 .9 r
.70574 .63949 m .70476 .63932 L .70251 .64104 L F
0 0 0 r
.70729 .63817 m .70476 .63932 L .70574 .63949 L F
.655 .565 .741 r
.65577 .631 m .65356 .63371 L .65325 .63091 L F
.437 .735 .99 r
.34848 .81632 m .35084 .81706 L .35081 .81626 L F
.35081 .81626 m .35084 .81706 L .34848 .81632 L F
0 0 .535 r
.35081 .81626 m .35187 .81907 L .35084 .81706 L F
.347 .781 .968 r
.45764 .72573 m .45965 .72542 L .46075 .72599 L F
0 .548 .707 r
.45965 .72542 m .46282 .72559 L .46075 .72599 L F
.238 .357 .782 r
.68025 .63846 m .68264 .64037 L .68154 .63751 L F
.544 .393 .626 r
.34363 .79242 m .34378 .79479 L .34568 .79271 L F
.64 .554 .742 r
.4921 .74082 m .49298 .74419 L .49524 .74366 L F
.077 .634 .801 r
.38238 .73045 m .38266 .73038 L .38044 .73037 L F
.38044 .73037 m .38266 .73038 L .38238 .73045 L F
0 0 0 r
.38457 .72959 m .38266 .73038 L .38238 .73045 L F
.38238 .73045 m .38266 .73038 L .38457 .72959 L F
.686 .486 .61 r
.70452 .69684 m .70635 .69503 L .70307 .69519 L F
.687 .751 .9 r
.50529 .75157 m .50859 .75197 L .50763 .75076 L F
.491 .5 .794 r
.50859 .75197 m .50943 .74865 L .50763 .75076 L F
.50859 .75197 m .51092 .75243 L .50943 .74865 L F
.871 .797 .774 r
.69635 .70505 m .69743 .70615 L .69607 .70326 L F
.836 .663 .669 r
.69433 .70822 m .69743 .70615 L .69635 .70505 L F
.453 .453 .768 r
.69743 .70615 m .69844 .70281 L .69607 .70326 L F
.772 .678 .76 r
.49711 .88104 m .50061 .88125 L .49949 .87826 L F
.328 0 0 r
.45255 .77039 m .45473 .77013 L .45614 .76863 L F
.236 0 0 r
.45614 .76863 m .45682 .76967 L .45751 .76901 L F
.45614 .76863 m .45473 .77013 L .45682 .76967 L F
.906 .927 .818 r
.59489 .64917 m .5919 .65133 L .59406 .64863 L F
.59489 .64917 m .59288 .65195 L .5919 .65133 L F
.823 .701 .73 r
.65904 .60931 m .65657 .61112 L .65932 .6093 L F
0 0 0 r
.66102 .60825 m .65904 .60931 L .65932 .6093 L F
.66102 .60825 m .65904 .60931 L .65932 .6093 L F
.418 .122 .353 r
.41145 .74368 m .4104 .74634 L .40878 .74609 L F
.517 .219 .4 r
.41314 .7456 m .41145 .74368 L .41376 .74313 L F
.41314 .7456 m .4104 .74634 L .41145 .74368 L F
.949 .861 .718 r
.58251 .666 m .58173 .66812 L .58058 .6673 L F
.893 .942 .836 r
.58466 .66333 m .58251 .666 L .58179 .66524 L F
.942 .929 .761 r
.58179 .66524 m .58251 .666 L .58058 .6673 L F
.697 .699 .848 r
.51418 .75473 m .51528 .75722 L .51765 .75643 L F
.663 .518 .678 r
.51539 .75946 m .51765 .75643 L .51528 .75722 L F
0 0 0 r
.61188 .62729 m .61293 .62581 L .61071 .62853 L F
.517 .268 .476 r
.60944 .62969 m .61188 .62729 L .61071 .62853 L F
.095 0 .015 r
.44321 .73846 m .44113 .74025 L .44121 .73835 L F
.188 .701 .893 r
.35613 .81355 m .35956 .81383 L .3582 .81348 L F
.35613 .81355 m .35956 .81383 L .3582 .81348 L F
.203 .117 .529 r
.67217 .59438 m .67066 .59594 L .67218 .59217 L F
.604 .745 .944 r
.67025 .59457 m .67066 .59594 L .67217 .59438 L F
.914 .903 .8 r
.69724 .72186 m .69968 .72141 L .69767 .71974 L F
.69688 .72361 m .69777 .72291 L .69724 .72186 L F
.69777 .72291 m .69968 .72141 L .69724 .72186 L F
.254 .335 .754 r
.69449 .71934 m .69542 .72246 L .69719 .72176 L F
0 0 .259 r
.69743 .72167 m .69688 .72361 L .69767 .71974 L F
.254 .335 .754 r
.69695 .72129 m .69719 .72176 L .69743 .72167 L F
.69449 .71934 m .69719 .72176 L .69695 .72129 L F
.446 0 0 r
.69542 .72246 m .69787 .72434 L .69688 .72361 L F
.69542 .72246 m .69688 .72361 L .69743 .72167 L F
.645 .372 .491 r
.61871 .67913 m .61563 .68143 L .61543 .6796 L F
.535 .123 .207 r
.34394 .80556 m .34558 .80721 L .34245 .80758 L F
.34394 .80556 m .3461 .80592 L .34558 .80721 L F
0 0 0 r
.51725 .75282 m .51839 .75252 L .51954 .75261 L F
.51725 .75282 m .51627 .75372 L .51839 .75252 L F
.56 .569 .819 r
.48534 .73756 m .48627 .73957 L .48741 .73729 L F
.602 .62 .842 r
.48627 .73957 m .48852 .73905 L .48741 .73729 L F
.622 .098 0 r
.49089 .77673 m .49004 .77762 L .48778 .77617 L F
.555 .021 0 r
.4934 .77792 m .49004 .77762 L .49089 .77673 L F
.502 0 0 r
.49456 .77784 m .4934 .77792 L .49089 .77673 L F
.577 .433 .649 r
.35812 .77043 m .36007 .76768 L .35791 .76801 L F
.702 .632 .776 r
.50506 .7381 m .50294 .74082 L .50304 .73894 L F
.662 .574 .745 r
.50506 .7381 m .50621 .74153 L .50294 .74082 L F
.51 .105 .209 r
.40672 .72726 m .40893 .72728 L .41021 .72546 L F
.476 .07 .189 r
.41021 .72546 m .40893 .72728 L .41195 .72636 L F
.755 .776 .87 r
.71209 .73539 m .70894 .73539 L .71068 .73352 L F
.905 .678 .172 r
.71209 .73539 m .71183 .73687 L .70894 .73539 L F
.71209 .73539 m .71224 .73833 L .71183 .73687 L F
.466 0 0 r
.71068 .73352 m .71493 .7343 L .71209 .73539 L F
.536 .441 .695 r
.33044 .80559 m .32848 .80276 L .32969 .80546 L F
.506 .38 .643 r
.35469 .77883 m .35656 .77607 L .35435 .77663 L F
.652 .269 .306 r
.49009 .77045 m .49225 .7722 L .49355 .77036 L F
.764 .436 .431 r
.49225 .7722 m .49551 .77092 L .49355 .77036 L F
.844 .391 0 r
.71673 .73498 m .71852 .73752 L .71777 .7359 L F
.858 .633 .597 r
.71852 .73752 m .72039 .73514 L .71777 .7359 L F
.414 .139 .385 r
.29801 .66523 m .30051 .6629 L .29861 .66318 L F
.779 .416 .37 r
.50795 .77562 m .50983 .77799 L .5111 .77614 L F
.899 .592 .456 r
.5111 .77614 m .50983 .77799 L .51103 .77822 L F
.732 .438 .482 r
.5111 .77614 m .51381 .77829 L .51343 .7759 L F
.5111 .77614 m .51103 .77822 L .51381 .77829 L F
.788 .73 .799 r
.70821 .6178 m .70956 .62014 L .70671 .61964 L F
.635 .109 0 r
.70671 .61964 m .70956 .62014 L .70856 .62073 L F
.337 .51 .88 r
.71108 .61933 m .70956 .62014 L .70821 .6178 L F
0 0 0 r
.70856 .62073 m .70956 .62014 L .71108 .61933 L F
.298 .66 .972 r
.50359 .87031 m .50453 .86956 L .50237 .86976 L F
.50359 .87031 m .50607 .87069 L .50453 .86956 L F
.50359 .87031 m .50453 .86956 L .50237 .86976 L F
.50359 .87031 m .50607 .87069 L .50453 .86956 L F
.782 .292 .048 r
.51561 .78898 m .51218 .78642 L .51373 .78657 L F
.892 .889 .821 r
.58673 .66053 m .58357 .66253 L .58566 .65978 L F
.58673 .66053 m .58466 .66333 L .58357 .66253 L F
.575 .382 .583 r
.35242 .78151 m .3546 .78122 L .35469 .77883 L F
.506 .38 .643 r
.35469 .77883 m .35661 .77846 L .35656 .77607 L F
.571 .418 .635 r
.3546 .78122 m .35661 .77846 L .35469 .77883 L F
.723 .58 .694 r
.59349 .6722 m .58893 .67358 L .58916 .67127 L F
.59349 .6722 m .59248 .67387 L .58893 .67358 L F
.556 .455 .694 r
.35961 .76297 m .36204 .76493 L .36182 .76259 L F
.35961 .76297 m .36001 .76531 L .36204 .76493 L F
.805 .708 .758 r
.66585 .62766 m .66913 .62985 L .66889 .62777 L F
.66585 .62766 m .66556 .63012 L .66913 .62985 L F
.797 .598 .632 r
.66556 .63012 m .66686 .63295 L .66913 .62985 L F
.893 .942 .836 r
.58466 .66333 m .58179 .66524 L .58357 .66253 L F
.425 .125 .351 r
.30849 .65711 m .30956 .65926 L .30997 .65808 L F
.30849 .65711 m .30755 .65981 L .30956 .65926 L F
.377 0 .007 r
.63587 .61799 m .63254 .61927 L .63376 .61845 L F
0 0 0 r
.64966 .65279 m .65215 .65032 L .65082 .65176 L F
.281 0 0 r
.42313 .72399 m .42529 .724 L .42663 .72337 L F
.395 0 0 r
.42529 .724 m .4288 .72361 L .42663 .72337 L F
.731 .581 .688 r
.64447 .6334 m .64803 .63358 L .64635 .63641 L F
.098 0 .205 r
.61397 .62674 m .61293 .62581 L .61188 .62729 L F
.61397 .62674 m .61446 .62452 L .61293 .62581 L F
.533 .393 .637 r
.36563 .75182 m .36757 .75147 L .36743 .74904 L F
.5 .355 .615 r
.36563 .75182 m .36766 .75381 L .36757 .75147 L F
.36563 .75182 m .36577 .75437 L .36766 .75381 L F
.536 .285 .482 r
.35014 .69524 m .35231 .69495 L .35278 .69273 L F
.459 .216 .457 r
.35278 .69273 m .35426 .69446 L .35461 .69221 L F
.35278 .69273 m .35231 .69495 L .35426 .69446 L F
.623 .446 .622 r
.33156 .80595 m .33419 .80717 L .33423 .80338 L F
.3315 .80601 m .33224 .80633 L .33156 .80595 L F
.33224 .80633 m .33419 .80717 L .33156 .80595 L F
.396 .508 .855 r
.33303 .80859 m .33527 .80917 L .33423 .80743 L F
.33372 .80715 m .33423 .80743 L .33387 .80683 L F
.33303 .80859 m .33423 .80743 L .33372 .80715 L F
.245 .543 .925 r
.33387 .80683 m .33419 .80717 L .3315 .80601 L F
.407 .521 .861 r
.3315 .80601 m .33303 .80859 L .33387 .80683 L F
.499 .518 .807 r
.51193 .75463 m .51292 .75139 L .51092 .75243 L F
.51193 .75463 m .51418 .75473 L .51292 .75139 L F
.529 .388 .634 r
.65246 .64869 m .65215 .65032 L .65314 .6489 L F
.65246 .64869 m .65082 .65176 L .65215 .65032 L F
.246 .448 .86 r
.70734 .5802 m .70702 .58224 L .7056 .57959 L F
.696 .273 .238 r
.70593 .58362 m .70702 .58224 L .70734 .5802 L F
.70593 .58362 m .70923 .58417 L .70702 .58224 L F
.425 .35 .668 r
.3583 .80868 m .36004 .80827 L .357 .80783 L F
.436 .871 .789 r
.65172 .58725 m .65303 .58635 L .65457 .58656 L F
.65172 .58725 m .65114 .58728 L .65303 .58635 L F
.993 .846 .589 r
.71118 .71605 m .71004 .71651 L .71061 .71416 L F
.08 .515 .902 r
.71118 .71605 m .71221 .71575 L .71004 .71651 L F
.71118 .71605 m .7133 .71671 L .71221 .71575 L F
.736 .578 .678 r
.69326 .71396 m .69653 .71683 L .69652 .71429 L F
.078 0 0 r
.72262 .62589 m .72171 .62585 L .72459 .62511 L F
0 0 0 r
.72459 .62511 m .72638 .62449 L .72262 .62589 L F
.563 .342 .538 r
.51381 .77829 m .51616 .7758 L .51343 .7759 L F
.101 .171 .651 r
.6387 .6162 m .63891 .6183 L .63914 .6175 L F
.63891 .6183 m .63905 .61978 L .63914 .61755 L F
.63891 .6183 m .63914 .61755 L .63914 .6175 L F
.6387 .6162 m .64002 .61801 L .63905 .61978 L F
.337 .612 .95 r
.63905 .61978 m .63911 .61903 L .63587 .61799 L F
.647 .236 .252 r
.63587 .61799 m .63872 .61891 L .63438 .61912 L F
.63872 .61891 m .63911 .61903 L .63868 .61904 L F
.63872 .61891 m .63868 .61904 L .63438 .61912 L F
.648 .587 .772 r
.66265 .63818 m .66316 .63977 L .6659 .63886 L F
.452 .723 .983 r
.35914 .65406 m .35846 .65534 L .35711 .65451 L F
.35914 .65406 m .36054 .65526 L .35846 .65534 L F
0 0 .107 r
.62036 .63614 m .61987 .63838 L .61866 .63926 L F
.017 0 .114 r
.62267 .63323 m .62202 .63523 L .62036 .63614 L F
.486 .281 .528 r
.62202 .63523 m .61987 .63838 L .62036 .63614 L F
.764 .436 .431 r
.49225 .7722 m .49551 .77263 L .49551 .77092 L F
.23 .746 .749 r
.41585 .77865 m .41341 .77925 L .41152 .77958 L F
.541 .381 .613 r
.36166 .76001 m .36376 .75989 L .36357 .75763 L F
.609 .418 .599 r
.36166 .76001 m .36401 .7622 L .36376 .75989 L F
.36166 .76001 m .36182 .76259 L .36401 .7622 L F
.38 .104 .365 r
.41871 .77578 m .41604 .77838 L .41775 .77798 L F
.224 0 .063 r
.41775 .77798 m .42062 .77604 L .41871 .77578 L F
.5 .288 .522 r
.34532 .69775 m .34735 .69969 L .3475 .69746 L F
.34532 .69775 m .34506 .70025 L .34735 .69969 L F
.531 .53 .8 r
.67962 .60318 m .68059 .60632 L .67856 .60663 L F
.166 0 0 r
.64489 .60697 m .6478 .60686 L .64468 .60676 L F
.497 .376 .645 r
.64655 .60307 m .64731 .60656 L .64468 .60676 L F
.439 .869 .925 r
.64994 .60618 m .64724 .6066 L .64897 .6057 L F
.496 .376 .645 r
.64897 .6057 m .64738 .60689 L .64731 .60656 L F
.64897 .6057 m .64731 .60656 L .64655 .60307 L F
.439 .869 .925 r
.64897 .6057 m .64896 .6057 L .64897 .6057 L F
.64896 .6057 m .64489 .60697 L .64897 .6057 L F
.497 .376 .645 r
.64731 .60656 m .64728 .60658 L .64468 .60676 L F
.64731 .60658 m .64651 .60685 L .64468 .60676 L F
.439 .869 .925 r
.64724 .6066 m .64489 .60697 L .64897 .6057 L F
.497 .376 .645 r
.64731 .60656 m .64731 .60658 L .64728 .60658 L F
.439 .869 .925 r
.64994 .60618 m .6478 .60686 L .64632 .60692 L F
.497 .376 .645 r
.64731 .60658 m .64738 .60689 L .64651 .60685 L F
.14 0 0 r
.64468 .60676 m .64651 .60685 L .64489 .60697 L F
.439 .869 .925 r
.64651 .60685 m .64632 .60692 L .64489 .60697 L F
.14 0 0 r
.64651 .60685 m .64738 .60689 L .64489 .60697 L F
.439 .869 .925 r
.64724 .6066 m .64651 .60685 L .64489 .60697 L F
.64994 .60618 m .64632 .60692 L .64724 .6066 L F
.074 .496 .897 r
.3378 .84548 m .33839 .84569 L .33849 .84607 L F
.86 .993 .745 r
.33849 .84607 m .33839 .84569 L .33775 .84653 L F
.681 .622 .783 r
.66003 .63497 m .66281 .63613 L .66293 .63553 L F
.57 .528 .769 r
.66108 .63083 m .66293 .63553 L .66343 .63253 L F
.644 .594 .784 r
.66281 .63613 m .66343 .63253 L .66293 .63553 L F
.66281 .63613 m .66434 .63583 L .66343 .63253 L F
.67 .538 .695 r
.66265 .63818 m .66434 .63583 L .66281 .63613 L F
.608 .507 .714 r
.35092 .787 m .35315 .78687 L .35249 .78393 L F
.7 .58 .717 r
.35015 .78933 m .35315 .78687 L .35092 .787 L F
.511 .323 .562 r
.35249 .78393 m .3546 .78122 L .35242 .78151 L F
.462 .203 .435 r
.38585 .8107 m .38586 .80868 L .38376 .81155 L F
.399 .48 .826 r
.38694 .80653 m .38586 .80868 L .38792 .80886 L F
0 0 .24 r
.38694 .80653 m .38586 .80868 L .38585 .8107 L F
.689 .586 .735 r
.57062 .68038 m .57378 .67633 L .57046 .67912 L F
.57062 .68038 m .57376 .6792 L .57378 .67633 L F
.969 .766 .577 r
.7332 .73241 m .73438 .73315 L .7336 .73016 L F
.832 .848 .859 r
.73152 .7342 m .73438 .73315 L .7332 .73241 L F
.969 .766 .577 r
.7332 .73241 m .73438 .73315 L .7336 .73016 L F
.471 .257 .507 r
.36508 .69832 m .36489 .70065 L .36293 .7012 L F
.432 .226 .497 r
.36677 .70003 m .36508 .69832 L .36724 .69795 L F
.36677 .70003 m .36489 .70065 L .36508 .69832 L F
.556 .501 .749 r
.65678 .62495 m .65461 .6253 L .65398 .62258 L F
.126 0 0 r
.64153 .59278 m .64357 .59227 L .64426 .5907 L F
0 0 0 r
.64426 .5907 m .64507 .59088 L .64641 .59004 L F
.64426 .5907 m .64357 .59227 L .64507 .59088 L F
.77 .386 .326 r
.70671 .6993 m .70912 .69841 L .70633 .69759 L F
.70671 .6993 m .70974 .69999 L .70912 .69841 L F
.77 .828 .897 r
.69122 .63025 m .69457 .62846 L .69193 .62919 L F
.701 .651 .797 r
.65774 .61279 m .65437 .61198 L .65657 .61112 L F
.929 .833 .729 r
.58173 .66812 m .57906 .67017 L .58058 .6673 L F
.58173 .66812 m .58029 .67104 L .57906 .67017 L F
.981 .854 .641 r
.61493 .64272 m .61575 .64388 L .61639 .64172 L F
.59 .87 .548 r
.61639 .64172 m .61866 .63926 L .61737 .6405 L F
.626 .93 .682 r
.61639 .64172 m .61737 .6405 L .61493 .64272 L F
.721 .591 .71 r
.49836 .73276 m .49958 .73588 L .49613 .73558 L F
.656 .558 .733 r
.50179 .73552 m .49958 .73588 L .49836 .73276 L F
.688 .572 .719 r
.50179 .73552 m .49975 .73805 L .49958 .73588 L F
.929 .674 .531 r
.67442 .59319 m .67618 .59587 L .67471 .59464 L F
.715 .491 .585 r
.67618 .59587 m .67285 .59786 L .67471 .59464 L F
.67618 .59587 m .67626 .59812 L .67285 .59786 L F
.545 .36 .581 r
.675 .59049 m .67737 .59028 L .67718 .58776 L F
.338 .488 .862 r
.67741 .59452 m .67618 .59587 L .67442 .59319 L F
.123 .039 .48 r
.67783 .59686 m .67618 .59587 L .67741 .59452 L F
.67783 .59686 m .67626 .59812 L .67618 .59587 L F
.552 .75 .969 r
.686 .58917 m .68692 .58751 L .68495 .58806 L F
.686 .58917 m .68873 .5888 L .68692 .58751 L F
.665 .586 .757 r
.49465 .87022 m .49592 .87358 L .49288 .87251 L F
.462 .172 .387 r
.30831 .68233 m .30727 .68478 L .30549 .68482 L F
.566 .321 .504 r
.31017 .68186 m .30727 .68478 L .30831 .68233 L F
.394 .044 .248 r
.381 .73528 m .38309 .7352 L .38387 .73327 L F
.367 .018 .236 r
.38387 .73327 m .38504 .73475 L .38601 .73305 L F
.38387 .73327 m .38309 .7352 L .38504 .73475 L F
.55 .543 .799 r
.59281 .67628 m .58893 .67358 L .59248 .67387 L F
.796 .458 .416 r
.64277 .63287 m .64168 .6351 L .6411 .63322 L F
.831 .503 .433 r
.64277 .63287 m .64442 .63555 L .64168 .6351 L F
.705 .482 .584 r
.64447 .6334 m .64442 .63555 L .64277 .63287 L F
.856 .408 .014 r
.71107 .70912 m .71103 .71031 L .7086 .70881 L F
.71107 .70912 m .71217 .71113 L .71103 .71031 L F
.231 .706 .939 r
.46282 .72559 m .46499 .72558 L .46629 .72616 L F
.391 .801 .98 r
.46499 .72558 m .46852 .72588 L .46629 .72616 L F
.204 .301 .742 r
.73352 .7189 m .73427 .72189 L .7329 .72001 L F
.6 .582 .805 r
.3931 .77825 m .39105 .77886 L .38978 .77574 L F
.587 .879 .993 r
.69418 .61678 m .69235 .61762 L .69105 .61685 L F
.075 0 0 r
.69162 .61851 m .69235 .61762 L .69418 .61678 L F
0 0 0 r
.62515 .65765 m .62655 .65677 L .62775 .65534 L F
.624 .65908 m .62655 .65677 L .62515 .65765 L F
.585 .447 .66 r
.35633 .77371 m .35859 .77356 L .35812 .77043 L F
.646 .468 .629 r
.35633 .77371 m .35883 .77574 L .35859 .77356 L F
.35633 .77371 m .35656 .77607 L .35883 .77574 L F
.469 .327 .605 r
.34305 .70091 m .34496 .70249 L .34506 .70025 L F
.34305 .70091 m .34313 .70321 L .34496 .70249 L F
.74 .636 .744 r
.49508 .73268 m .49622 .73321 L .49288 .73295 L F
.713 .654 .79 r
.49836 .73276 m .49622 .73321 L .49508 .73268 L F
.721 .591 .71 r
.49836 .73276 m .49613 .73558 L .49622 .73321 L F
.794 .472 .444 r
.64747 .61195 m .65068 .61217 L .65037 .61435 L F
.271 0 0 r
.34554 .67341 m .34381 .67493 L .3418 .67518 L F
.472 .05 .156 r
.34778 .67285 m .34381 .67493 L .34554 .67341 L F
.752 .739 .84 r
.69614 .58671 m .69944 .58728 L .69698 .58834 L F
.477 .192 .401 r
.37182 .74366 m .37387 .74329 L .37429 .74149 L F
.527 .276 .478 r
.37387 .74329 m .37665 .74089 L .37429 .74149 L F
.335 0 .228 r
.41604 .77838 m .41823 .77799 L .41775 .77798 L F
.41604 .77838 m .41585 .77865 L .41823 .77799 L F
.992 .792 .536 r
.68681 .63544 m .68782 .63622 L .68746 .63377 L F
.68746 .63377 m .68782 .63622 L .68681 .63544 L F
.505 .895 .95 r
.72156 .62001 m .72102 .621 L .7196 .62096 L F
.72156 .62001 m .72332 .62013 L .72102 .621 L F
.744 .748 .855 r
.69815 .58455 m .69944 .58728 L .69614 .58671 L F
.76 .755 .848 r
.70145 .58509 m .69944 .58728 L .69815 .58455 L F
.58 .553 .789 r
.49621 .74726 m .49721 .74348 L .49524 .74366 L F
.49621 .74726 m .49805 .74691 L .49721 .74348 L F
.538 .064 .077 r
.354 .80856 m .35571 .80708 L .357 .80783 L F
0 .135 .616 r
.68393 .64089 m .68463 .6413 L .68264 .64037 L F
.68393 .64089 m .68609 .64259 L .68463 .6413 L F
.714 .678 .813 r
.66434 .63583 m .66789 .63605 L .66686 .63295 L F
.732 .562 .662 r
.66434 .63583 m .6659 .63886 L .66789 .63605 L F
.379 .158 .448 r
.37603 .68671 m .37551 .68926 L .37381 .68934 L F
.496 .241 .457 r
.37541 .69154 m .37381 .68934 L .37551 .68926 L F
.37541 .69154 m .37359 .69206 L .37381 .68934 L F
.788 .453 .421 r
.71336 .70481 m .71601 .70375 L .71289 .70308 L F
.71336 .70481 m .71638 .70549 L .71601 .70375 L F
.755 .517 .573 r
.6967 .71895 m .69993 .7169 L .69653 .71683 L F
.6967 .71895 m .70001 .71929 L .69993 .7169 L F
.583 .837 .993 r
.68906 .64387 m .69223 .64411 L .6911 .64271 L F
.713 .735 .869 r
.6911 .64271 m .69223 .64411 L .69414 .64269 L F
.205 0 0 r
.49683 .77812 m .4934 .77792 L .49456 .77784 L F
.551 .598 .854 r
.36838 .81644 m .36972 .81502 L .36714 .81594 L F
.36838 .81644 m .37091 .81672 L .36972 .81502 L F
.36838 .81644 m .36972 .81502 L .36714 .81594 L F
.36838 .81644 m .37091 .81672 L .36972 .81502 L F
.661 .408 .528 r
.60658 .68136 m .60455 .684 L .60248 .68407 L F
.653 .399 .522 r
.60821 .68372 m .60658 .68136 L .60804 .68163 L F
.60821 .68372 m .60455 .684 L .60658 .68136 L F
.606 .258 .354 r
.62534 .63494 m .62267 .63323 L .62488 .63286 L F
.62534 .63494 m .62202 .63523 L .62267 .63323 L F
.254 0 0 r
.33118 .71103 m .33334 .7104 L .33139 .71084 L F
.683 .672 .833 r
.48852 .73905 m .4921 .74082 L .4906 .73833 L F
.51 .561 .844 r
.4921 .74082 m .4927 .73779 L .4906 .73833 L F
.4921 .74082 m .49401 .74062 L .4927 .73779 L F
.64 .554 .742 r
.4921 .74082 m .49524 .74366 L .49401 .74062 L F
.555 .368 .582 r
.67718 .58776 m .67737 .59028 L .67934 .58829 L F
.581 .441 .656 r
.36007 .76768 m .36204 .76493 L .36001 .76531 L F
.27 0 .195 r
.61987 .63838 m .61737 .6405 L .61866 .63926 L F
.645 .372 .491 r
.61871 .67913 m .61813 .68145 L .61563 .68143 L F
.57 .31 .483 r
.62102 .67884 m .61813 .68145 L .61871 .67913 L F
.627 .378 .521 r
.65089 .59585 m .65163 .59824 L .64809 .59766 L F
.764 .469 .486 r
.65338 .59885 m .6509 .60026 L .65165 .59821 L F
.388 .228 .539 r
.65215 .59685 m .6509 .60026 L .65172 .5985 L F
.627 .378 .521 r
.65163 .59824 m .65172 .5985 L .65147 .59844 L F
.65163 .59824 m .65147 .59844 L .64809 .59766 L F
.764 .469 .486 r
.6524 .59726 m .65165 .59821 L .65215 .59685 L F
.65338 .59885 m .65165 .59821 L .6524 .59726 L F
.65338 .59885 m .65422 .60075 L .6509 .60026 L F
.564 .662 .903 r
.48972 .88247 m .49034 .88041 L .48828 .88058 L F
.48972 .88247 m .49123 .88247 L .49034 .88041 L F
.713 .654 .79 r
.49836 .73276 m .49508 .73268 L .49726 .73006 L F
.658 .688 .867 r
.50063 .73201 m .49836 .73276 L .49726 .73006 L F
.649 .634 .821 r
.50063 .73201 m .50142 .73332 L .49836 .73276 L F
.656 .558 .733 r
.50179 .73552 m .49836 .73276 L .50142 .73332 L F
.875 .755 .727 r
.65843 .63507 m .66003 .63497 L .65936 .63346 L F
.778 .499 .514 r
.65598 .63763 m .66003 .63497 L .65843 .63507 L F
.65598 .63763 m .65928 .63806 L .66003 .63497 L F
.681 .622 .783 r
.66003 .63497 m .66293 .63553 L .65936 .63346 L F
.138 0 0 r
.42607 .78604 m .42526 .78662 L .42315 .78701 L F
.027 0 0 r
.42726 .78605 m .42607 .78604 L .42812 .78569 L F
.42726 .78605 m .42526 .78662 L .42607 .78604 L F
.81 .459 .392 r
.6315 .62961 m .63328 .62776 L .62974 .6271 L F
.814 .505 0 r
.66754 .60573 m .66853 .60867 L .66859 .6067 L F
.449 .161 .383 r
.68715 .59596 m .6894 .59564 L .68992 .59359 L F
.271 .005 .314 r
.68992 .59359 m .6894 .59564 L .69172 .59256 L F
.364 0 .051 r
.3197 .73541 m .31815 .73712 L .31622 .73733 L F
0 0 0 r
.32255 .73388 m .32098 .73527 L .3197 .73541 L F
.012 0 0 r
.32098 .73527 m .31815 .73712 L .3197 .73541 L F
.956 .695 .246 r
.64768 .62441 m .64494 .62258 L .64629 .62466 L F
.472 .224 .457 r
.65657 .61112 m .65603 .61078 L .65932 .6093 L F
0 0 0 r
.32268 .73458 m .32255 .73388 L .32434 .73304 L F
.32268 .73458 m .32098 .73527 L .32255 .73388 L F
.405 .088 .311 r
.36418 .70234 m .36293 .7012 L .36489 .70065 L F
.36418 .70234 m .36221 .70285 L .36293 .7012 L F
.759 .626 .713 r
.65936 .63346 m .66293 .63553 L .66108 .63083 L F
.762 .911 .53 r
.69229 .70656 m .69088 .70888 L .69122 .70784 L F
0 0 .187 r
.69374 .70257 m .69229 .70656 L .69338 .70473 L F
.389 .39 .739 r
.69229 .70656 m .69433 .70822 L .69338 .70473 L F
.718 .287 .225 r
.69229 .70656 m .69122 .70784 L .69433 .70822 L F
.155 0 0 r
.70647 .70926 m .70794 .70972 L .70516 .70933 L F
.70647 .70926 m .7086 .70881 L .70794 .70972 L F
.553 .703 .939 r
.69394 .58737 m .69023 .5856 L .69283 .58497 L F
.606 .635 .854 r
.69497 .58395 m .69394 .58737 L .69283 .58497 L F
.69497 .58395 m .69614 .58671 L .69394 .58737 L F
.731 .626 .742 r
.57872 .67586 m .57589 .67636 L .57808 .67371 L F
.653 .358 .459 r
.57872 .67586 m .57807 .67827 L .57589 .67636 L F
.722 .491 .576 r
.58148 .67601 m .57807 .67827 L .57872 .67586 L F
.386 0 0 r
.41195 .72636 m .41416 .72627 L .41562 .72497 L F
.562 .113 .143 r
.41416 .72627 m .41787 .72519 L .41562 .72497 L F
.506 0 0 r
.64343 .60761 m .64464 .6086 L .64223 .60646 L F
.69 .394 .47 r
.64223 .60646 m .64464 .6086 L .64468 .60676 L F
.506 0 0 r
.64343 .60761 m .64223 .60646 L .64468 .60676 L F
.695 .564 .702 r
.64223 .60646 m .64419 .60364 L .64468 .60676 L F
.504 0 0 r
.31707 .7163 m .32059 .71675 L .31877 .71611 L F
.243 0 .028 r
.30051 .6629 m .3023 .66241 L .30353 .66083 L F
.359 0 .128 r
.3023 .66241 m .30555 .66034 L .30353 .66083 L F
.46 .224 .469 r
.42747 .76786 m .425 .77041 L .42503 .768 L F
.425 .77041 m .42747 .76786 L .42503 .768 L F
.421 .618 .932 r
.33277 .64845 m .33188 .6499 L .33065 .64864 L F
.869 .906 .854 r
.70331 .59298 m .70436 .59403 L .7055 .59218 L F
.948 .913 .748 r
.59182 .67825 m .59268 .67814 L .59281 .67628 L F
.59182 .67825 m .59165 .67946 L .59268 .67814 L F
.045 0 0 r
.72082 .62597 m .72171 .62585 L .72262 .62589 L F
.535 .565 .833 r
.6929 .69817 m .69599 .70074 L .69525 .69772 L F
.718 .623 .751 r
.37707 .80753 m .37806 .81027 L .3788 .80817 L F
.574 .593 .834 r
.37532 .66822 m .37183 .66572 L .37393 .66525 L F
.451 .468 .785 r
.37594 .66489 m .37532 .66822 L .37393 .66525 L F
.37594 .66489 m .37715 .66861 L .37532 .66822 L F
.745 .403 .402 r
.50116 .77496 m .50459 .77368 L .50096 .77312 L F
.50116 .77496 m .50449 .77527 L .50459 .77368 L F
.399 0 .09 r
.31595 .68009 m .31618 .68071 L .31405 .68077 L F
.58 .072 .009 r
.31595 .68009 m .31773 .68127 L .31618 .68071 L F
.576 .025 0 r
.31848 .68093 m .31773 .68127 L .31595 .68009 L F
.662 .424 .549 r
.61447 .66269 m .61756 .66035 L .61423 .66023 L F
.61447 .66269 m .61751 .66244 L .61756 .66035 L F
.666 .427 .55 r
.61751 .66244 m .61986 .66255 L .61756 .66035 L F
.678 .425 .532 r
.61756 .66035 m .61986 .66255 L .62001 .66042 L F
.655 .273 .308 r
.52099 .77525 m .52374 .77545 L .52482 .77404 L F
.399 0 .135 r
.52482 .77404 m .52592 .77477 L .52641 .77296 L F
.52482 .77404 m .52374 .77545 L .52592 .77477 L F
0 .032 .589 r
.67214 .60619 m .67247 .60584 L .67123 .60327 L F
0 0 .184 r
.67204 .60879 m .67247 .60584 L .67214 .60619 L F
.461 .826 .994 r
.46852 .72588 m .47065 .7255 L .47193 .72608 L F
.298 .739 .964 r
.47065 .7255 m .47411 .726 L .47193 .72608 L F
.576 .514 .749 r
.3868 .67292 m .38466 .67424 L .38398 .67098 L F
.113 0 .43 r
.3868 .67292 m .38541 .67633 L .38466 .67424 L F
.307 .44 .833 r
.67817 .60053 m .67806 .60318 L .67629 .60039 L F
.67817 .60053 m .67962 .60318 L .67806 .60318 L F
.779 .955 .928 r
.33751 .81178 m .34138 .81018 L .34088 .81095 L F
.767 .871 .443 r
.34138 .81018 m .34245 .80758 L .3418 .80836 L F
.82 .859 .408 r
.3418 .80836 m .34088 .81095 L .34138 .81018 L F
.588 .544 .772 r
.37292 .66194 m .37183 .66572 L .37058 .66257 L F
.37292 .66194 m .37393 .66525 L .37183 .66572 L F
.497 .376 .645 r
.64655 .60307 m .64468 .60676 L .64419 .60364 L F
.228 .093 .479 r
.29016 .6139 m .28987 .61635 L .28838 .61732 L F
.441 .283 .57 r
.28987 .61635 m .28794 .61941 L .28838 .61732 L F
.084 0 0 r
.71044 .59951 m .70944 .59949 L .71028 .59912 L F
.71044 .59951 m .71028 .59912 L .71093 .59883 L F
.876 .44 .144 r
.71044 .59951 m .71187 .60177 L .71063 .6013 L F
.71044 .59951 m .71063 .6013 L .71057 .59983 L F
.084 0 0 r
.71044 .59951 m .71093 .59883 L .70918 .59781 L F
.743 .927 .951 r
.71052 .59847 m .71171 .59919 L .71044 .59951 L F
.876 .44 .144 r
.71044 .59951 m .71057 .59983 L .71052 .59847 L F
.688 .572 .719 r
.50179 .73552 m .50304 .73894 L .49975 .73805 L F
.198 .35 .792 r
.42471 .77518 m .42393 .77686 L .42261 .77611 L F
.42471 .77518 m .4255 .77673 L .42393 .77686 L F
.972 .75 .543 r
.71909 .71372 m .71871 .71637 L .71767 .71325 L F
.663 .518 .678 r
.51539 .75946 m .51872 .76002 L .51765 .75643 L F
.615 .576 .787 r
.51539 .75946 m .51845 .762 L .51872 .76002 L F
.566 .058 .005 r
.4255 .77673 m .42791 .77723 L .42958 .7762 L F
.437 0 0 r
.42791 .77723 m .43176 .77602 L .42958 .7762 L F
.914 .947 .807 r
.65665 .64262 m .65666 .64479 L .65851 .64192 L F
.94 .795 .672 r
.6547 .64541 m .65666 .64479 L .65665 .64262 L F
.6547 .64541 m .65583 .64649 L .65666 .64479 L F
.817 .754 .794 r
.66789 .62496 m .66585 .62766 L .66889 .62777 L F
.475 .887 .931 r
.30944 .71863 m .31137 .71792 L .31348 .71792 L F
.337 .815 .887 r
.31348 .71792 m .31327 .71747 L .31522 .71702 L F
.31348 .71792 m .31137 .71792 L .31327 .71747 L F
.659 .656 .836 r
.47088 .73511 m .47413 .73609 L .47301 .73457 L F
.639 .696 .887 r
.47301 .73457 m .47413 .73609 L .47631 .73551 L F
.731 .581 .688 r
.64447 .6334 m .64635 .63641 L .64442 .63555 L F
.626 .904 .603 r
.62887 .65389 m .63005 .65291 L .62775 .65534 L F
0 0 0 r
.62775 .65534 m .62832 .65571 L .62887 .65389 L F
.62775 .65534 m .62655 .65677 L .62832 .65571 L F
.6 .2 .256 r
.65312 .59613 m .65215 .59685 L .65089 .59585 L F
.426 .264 .557 r
.65215 .59685 m .65172 .5985 L .65089 .59585 L F
.771 .601 .668 r
.58893 .67358 m .58716 .67629 L .58804 .67422 L F
0 .146 .608 r
.71368 .73946 m .71469 .74014 L .71224 .73833 L F
0 .118 .633 r
.71368 .73946 m .7157 .74133 L .71469 .74014 L F
.414 .232 .523 r
.63214 .60316 m .63029 .60384 L .63027 .60612 L F
.639 .556 .744 r
.63682 .62682 m .63937 .62999 L .63491 .62873 L F
.868 .537 .423 r
.63999 .63072 m .63927 .63188 L .63939 .62953 L F
.639 .556 .744 r
.63937 .62999 m .63939 .63001 L .63937 .63001 L F
.63937 .62999 m .63937 .63001 L .63491 .62873 L F
.68 .32 .358 r
.63491 .62873 m .63937 .63001 L .63711 .63161 L F
.63937 .63001 m .63939 .63001 L .63935 .63004 L F
.63937 .63001 m .63935 .63004 L .63711 .63161 L F
.868 .537 .423 r
.63927 .63188 m .63881 .63264 L .63939 .62953 L F
.744 .541 .62 r
.63937 .62999 m .63934 .62942 L .63939 .63001 L F
.63682 .62682 m .63934 .62942 L .63937 .62999 L F
.868 .537 .423 r
.63939 .62953 m .63935 .62973 L .63934 .62942 L F
.93 .829 .723 r
.63711 .63161 m .63935 .63004 L .63934 .62942 L F
.868 .537 .423 r
.63935 .62973 m .63934 .62978 L .63934 .62942 L F
.93 .829 .723 r
.63935 .63004 m .63939 .63001 L .63934 .62942 L F
.868 .537 .423 r
.63934 .62978 m .63927 .6302 L .63934 .62942 L F
.63927 .6302 m .63881 .63264 L .63918 .63035 L F
.63927 .6302 m .63918 .63035 L .63934 .62942 L F
.63999 .63072 m .6411 .63322 L .63881 .63264 L F
.469 .793 .999 r
.44724 .72431 m .44652 .72538 L .44519 .72431 L F
.44724 .72431 m .44859 .72506 L .44652 .72538 L F
.697 .699 .848 r
.51418 .75473 m .51765 .75643 L .51627 .75372 L F
.637 .658 .854 r
.51627 .75372 m .51765 .75643 L .51981 .75488 L F
.611 .601 .817 r
.51765 .75643 m .52054 .75748 L .51981 .75488 L F
.683 .53 .672 r
.51765 .75643 m .51872 .76002 L .52054 .75748 L F
.733 .793 .9 r
.51389 .73846 m .51061 .73833 L .51259 .73737 L F
.693 .786 .922 r
.51623 .73768 m .51389 .73846 L .51259 .73737 L F
.566 .579 .826 r
.51827 .74022 m .51389 .73846 L .51623 .73768 L F
.765 .345 .253 r
.50006 .77907 m .49885 .78043 L .49683 .77812 L F
.713 .277 .213 r
.50006 .77907 m .50208 .78088 L .49885 .78043 L F
.802 .687 .738 r
.64442 .63555 m .64635 .63641 L .64547 .63839 L F
.252 .338 .758 r
.49465 .87022 m .49673 .87217 L .49592 .87358 L F
.629 .811 .387 r
.49592 .87358 m .49502 .875 L .49765 .87504 L F
.49592 .87358 m .49673 .87217 L .49502 .875 L F
.749 .35 .296 r
.70156 .58905 m .70476 .58968 L .70248 .58783 L F
.345 .43 .806 r
.70248 .58783 m .70476 .58968 L .70385 .5865 L F
.70248 .58783 m .70385 .5865 L .70156 .58905 L F
0 0 .053 r
.72473 .61405 m .72251 .61757 L .7243 .61602 L F
.093 0 .121 r
.72473 .61405 m .7243 .61602 L .72626 .61391 L F
.14 0 0 r
.64468 .60676 m .64464 .6086 L .64343 .60761 L F
.64468 .60676 m .64489 .60697 L .64464 .6086 L F
.166 0 0 r
.64489 .60697 m .64468 .60676 L .64464 .6086 L F
.736 .732 .847 r
.6894 .59564 m .69034 .59797 L .69279 .59659 L F
.556 .501 .749 r
.65678 .62495 m .65398 .62258 L .65655 .62262 L F
0 .046 .603 r
.69088 .70888 m .69243 .71186 L .69122 .70784 L F
.268 .324 .735 r
.36442 .65553 m .3659 .65698 L .36442 .65635 L F
.67 .538 .695 r
.66265 .63818 m .6659 .63886 L .66434 .63583 L F
.903 .52 .083 r
.73427 .72189 m .7352 .72453 L .73598 .72511 L F
.979 .803 .596 r
.73445 .72665 m .73598 .72511 L .7352 .72453 L F
.73445 .72665 m .73553 .72746 L .73598 .72511 L F
.701 .404 .469 r
.34841 .78983 m .35082 .79178 L .35015 .78933 L F
.34841 .78983 m .34821 .79202 L .35082 .79178 L F
.408 .022 .191 r
.69311 .7029 m .69599 .70074 L .69374 .70257 L F
0 0 .187 r
.69374 .70257 m .69338 .70473 L .69311 .7029 L F
.408 .022 .191 r
.69311 .7029 m .69556 .70243 L .69599 .70074 L F
.53 .378 .619 r
.69599 .70074 m .69866 .69785 L .69525 .69772 L F
.69599 .70074 m .69807 .70061 L .69866 .69785 L F
.789 .579 .617 r
.69556 .70243 m .69807 .70061 L .69599 .70074 L F
.855 .874 .853 r
.71565 .62509 m .71345 .62574 L .71508 .62425 L F
.881 .681 .628 r
.60968 .65424 m .61097 .65752 L .61112 .65505 L F
.741 .689 .802 r
.49508 .73268 m .4916 .73024 L .49384 .72961 L F
.49508 .73268 m .49288 .73295 L .4916 .73024 L F
.712 .736 .87 r
.49726 .73006 m .49508 .73268 L .49384 .72961 L F
.634 .353 .474 r
.4104 .74634 m .40764 .74815 L .40878 .74609 L F
.657 .571 .747 r
.50839 .74079 m .50621 .74153 L .50506 .7381 L F
.747 .601 .695 r
.6109 .65967 m .61425 .65784 L .61097 .65752 L F
.6109 .65967 m .61423 .66023 L .61425 .65784 L F
.574 .335 .516 r
.3235 .67652 m .32327 .67869 L .3212 .67867 L F
.23 .746 .749 r
.41585 .77865 m .41152 .77958 L .41361 .77958 L F
.498 .028 .07 r
.41361 .77958 m .41823 .77799 L .41585 .77865 L F
.604 .348 .502 r
.5969 .68474 m .59698 .68671 L .5947 .68683 L F
.623 .362 .502 r
.59931 .68647 m .5969 .68474 L .60026 .68404 L F
.59931 .68647 m .59698 .68671 L .5969 .68474 L F
.244 0 0 r
.45751 .76901 m .45981 .7688 L .46135 .76784 L F
.152 0 0 r
.45981 .7688 m .46347 .76752 L .46135 .76784 L F
.442 .254 .529 r
.35465 .68986 m .35647 .68939 L .35663 .68711 L F
.468 .307 .579 r
.35461 .69221 m .35647 .68939 L .35465 .68986 L F
.976 .726 .49 r
.71142 .59055 m .71042 .58724 L .70803 .58994 L F
.222 0 .123 r
.33125 .72906 m .32954 .72993 L .33211 .72794 L F
.086 0 0 r
.33415 .72748 m .33125 .72906 L .33211 .72794 L F
.358 .537 .895 r
.33527 .80917 m .33639 .81099 L .33747 .8105 L F
.263 .28 .691 r
.33639 .81099 m .33751 .81178 L .33747 .8105 L F
.207 0 0 r
.43397 .78353 m .43296 .78439 L .43026 .78542 L F
.255 0 0 r
.43397 .7847 m .43397 .78353 L .43616 .78323 L F
.43397 .7847 m .43296 .78439 L .43397 .78353 L F
.888 .722 .671 r
.64442 .63555 m .64547 .63839 L .64338 .63848 L F
.878 .75 .717 r
.64547 .63839 m .64246 .64036 L .64338 .63848 L F
.64547 .63839 m .64404 .64141 L .64246 .64036 L F
.943 .729 .585 r
.64351 .61886 m .64492 .62009 L .64516 .61706 L F
.298 0 0 r
.40405 .74948 m .40236 .75065 L .40032 .75079 L F
.4 0 .03 r
.40627 .74894 m .40236 .75065 L .40405 .74948 L F
.456 .77 .997 r
.38966 .79793 m .39149 .79765 L .38947 .79818 L F
.502 .253 .469 r
.61986 .66255 m .62271 .66006 L .62001 .66042 L F
.454 .722 .983 r
.62817 .6329 m .63042 .63292 L .62591 .63237 L F
.349 0 .005 r
.46044 .77581 m .45909 .77718 L .45695 .77741 L F
.314 0 0 r
.46252 .77576 m .45909 .77718 L .46044 .77581 L F
.294 0 .128 r
.31268 .65627 m .31529 .65466 L .31333 .65508 L F
.577 .433 .649 r
.35812 .77043 m .3603 .77011 L .36007 .76768 L F
.584 .446 .66 r
.35812 .77043 m .3607 .77309 L .3603 .77011 L F
.35812 .77043 m .35859 .77356 L .3607 .77309 L F
.576 .104 .097 r
.48671 .7705 m .48899 .77169 L .49009 .77045 L F
.512 0 0 r
.48899 .77169 m .49225 .7722 L .49009 .77045 L F
.964 .922 .711 r
.57589 .67636 m .57646 .67284 L .57808 .67371 L F
.57589 .67636 m .5751 .67639 L .57646 .67284 L F
.779 .474 .472 r
.57807 .67827 m .5751 .67639 L .57589 .67636 L F
.556 .682 .923 r
.34168 .65041 m .34076 .65224 L .33957 .65064 L F
.523 .642 .908 r
.34168 .65041 m .34281 .65214 L .34076 .65224 L F
.115 0 0 r
.64072 .59425 m .64357 .59227 L .64153 .59278 L F
0 0 0 r
.63907 .59535 m .64072 .59425 L .64153 .59278 L F
0 .245 .753 r
.72941 .61612 m .73108 .6192 L .72877 .61693 L F
.26 .759 .895 r
.47088 .73511 m .4696 .73488 L .46745 .73512 L F
.469 .878 .948 r
.47167 .73423 m .47088 .73511 L .47301 .73457 L F
.47167 .73423 m .4696 .73488 L .47088 .73511 L F
.363 .102 .378 r
.52612 .78385 m .52859 .78122 L .52872 .78278 L F
.231 .008 .354 r
.52859 .78122 m .5305 .77841 L .53007 .78088 L F
.376 .141 .425 r
.52872 .78278 m .52859 .78122 L .53007 .78088 L F
.281 0 .121 r
.33855 .7248 m .33704 .72461 L .33889 .72419 L F
.33855 .7248 m .33576 .72653 L .33704 .72461 L F
.541 .394 .631 r
.36376 .75989 m .36557 .7567 L .36357 .75763 L F
.479 .227 .453 r
.39758 .75358 m .39703 .75427 L .39618 .75184 L F
.631 .418 .576 r
.39758 .75358 m .39658 .75423 L .39703 .75427 L F
.39658 .75423 m .39491 .75532 L .39703 .75427 L F
.39658 .75423 m .3966 .75433 L .39491 .75532 L F
.671 .402 .505 r
.39491 .75532 m .39264 .75402 L .39674 .75425 L F
.39491 .75532 m .39674 .75425 L .39703 .75427 L F
.631 .418 .576 r
.3966 .75433 m .39726 .75668 L .39491 .75532 L F
.615 .299 .411 r
.39658 .75423 m .39703 .75427 L .39674 .75425 L F
.631 .418 .576 r
.39758 .75358 m .3975 .75434 L .39658 .75423 L F
.3975 .75434 m .39726 .75668 L .39658 .75423 L F
.615 .299 .411 r
.39277 .75394 m .39658 .75423 L .39264 .75402 L F
.39658 .75423 m .39674 .75425 L .39264 .75402 L F
.39618 .75184 m .39703 .75427 L .39277 .75394 L F
.479 .227 .453 r
.39758 .75358 m .39618 .75184 L .398 .75126 L F
.602 .581 .803 r
.50273 .72993 m .50142 .73332 L .50063 .73201 L F
.50273 .72993 m .50371 .73299 L .50142 .73332 L F
.592 .489 .706 r
.50371 .73299 m .50179 .73552 L .50142 .73332 L F
.954 .95 .663 r
.6261 .62954 m .62502 .63221 L .62591 .63237 L F
.721 .989 .858 r
.62591 .63237 m .62502 .63221 L .62488 .63286 L F
.737 .436 .472 r
.62591 .63237 m .62534 .63494 L .62488 .63286 L F
.62591 .63237 m .62783 .63414 L .62534 .63494 L F
.834 .372 0 r
.62502 .63221 m .62603 .6343 L .62591 .63237 L F
.158 0 .268 r
.62591 .63237 m .62969 .6291 L .6261 .62954 L F
.553 .901 .678 r
.62974 .6271 m .62969 .6291 L .6315 .62961 L F
.62974 .6271 m .62903 .62754 L .62969 .6291 L F
.62903 .62754 m .62873 .62773 L .62917 .62836 L F
.62903 .62754 m .62917 .62836 L .62969 .6291 L F
.158 0 .268 r
.62591 .63237 m .62682 .63215 L .62969 .6291 L F
.724 .665 .791 r
.6261 .62954 m .62969 .6291 L .62873 .62773 L F
.429 .318 .626 r
.63046 .62634 m .63071 .62906 L .62937 .62953 L F
.62925 .62883 m .62937 .62953 L .62882 .62973 L F
.63046 .62634 m .62937 .62953 L .62925 .62883 L F
.536 0 0 r
.62965 .62932 m .6315 .62961 L .62969 .6291 L F
.429 .318 .626 r
.63071 .62906 m .62973 .62984 L .62947 .62981 L F
.536 0 0 r
.62965 .62932 m .62969 .6291 L .62935 .63014 L F
.158 0 .268 r
.62682 .63215 m .62935 .63014 L .62946 .6298 L F
.62908 .62974 m .62946 .6298 L .62969 .6291 L F
.62682 .63215 m .62946 .6298 L .62908 .62974 L F
.117 0 0 r
.62882 .62973 m .62973 .62984 L .62955 .62988 L F
.62973 .62984 m .6308 .62997 L .6304 .62994 L F
.62973 .62984 m .6304 .62994 L .62955 .62988 L F
.429 .318 .626 r
.6296 .62945 m .62947 .62981 L .62882 .62973 L F
.536 0 0 r
.63048 .62975 m .63049 .62975 L .62965 .62932 L F
.63049 .62975 m .6315 .62961 L .62975 .62934 L F
.63049 .62975 m .62975 .62934 L .62965 .62932 L F
.818 .988 .877 r
.63049 .62975 m .63168 .62825 L .6315 .62961 L F
.388 .288 .618 r
.63168 .62825 m .63077 .6294 L .63046 .62634 L F
.63082 .62993 m .63079 .62992 L .63046 .62634 L F
.536 0 0 r
.62955 .62988 m .63048 .62975 L .62965 .62932 L F
.429 .318 .626 r
.63071 .62906 m .63075 .62942 L .63009 .62955 L F
.818 .988 .877 r
.63048 .62975 m .63075 .62942 L .63049 .62975 L F
.429 .318 .626 r
.63075 .62942 m .63079 .62992 L .63048 .62975 L F
.63075 .62942 m .63048 .62975 L .63009 .62955 L F
.818 .988 .877 r
.62955 .62988 m .63168 .62825 L .63075 .62942 L F
.429 .318 .626 r
.63009 .62955 m .6308 .62997 L .62973 .62984 L F
.818 .988 .877 r
.62955 .62988 m .63075 .62942 L .63048 .62975 L F
.388 .288 .618 r
.63168 .62825 m .63082 .62993 L .63077 .6294 L F
.63082 .62993 m .6308 .62997 L .63079 .62992 L F
.429 .318 .626 r
.63071 .62906 m .62947 .62981 L .6296 .62945 L F
.536 0 0 r
.62955 .62988 m .62965 .62932 L .62885 .63168 L F
.62965 .62932 m .62935 .63014 L .62885 .63168 L F
.429 .318 .626 r
.63079 .62992 m .6308 .62997 L .63009 .62955 L F
.158 0 .268 r
.62682 .63215 m .62885 .63168 L .62935 .63014 L F
.063 0 0 r
.62659 .63301 m .62591 .63237 L .62603 .6343 L F
.691 .328 .353 r
.62661 .63297 m .62603 .6343 L .62502 .63221 L F
.62681 .63307 m .62603 .6343 L .62661 .63297 L F
.063 0 0 r
.6272 .63358 m .62659 .63301 L .62603 .6343 L F
.594 .343 .505 r
.63042 .63292 m .62783 .63414 L .62591 .63237 L F
.063 0 0 r
.62658 .633 m .62677 .63287 L .62591 .63237 L F
.62677 .63287 m .62838 .63179 L .628 .63188 L F
.62708 .63262 m .62766 .63196 L .62591 .63237 L F
.925 .973 .704 r
.62882 .62973 m .62708 .63262 L .6261 .62954 L F
.62882 .62973 m .6273 .63012 L .62684 .6329 L F
.62708 .63262 m .62681 .63307 L .62677 .63287 L F
.62708 .63262 m .62684 .6329 L .62681 .63307 L F
.62882 .62973 m .62684 .6329 L .62708 .63262 L F
.063 0 0 r
.62677 .63287 m .62708 .63262 L .62591 .63237 L F
.62708 .63262 m .628 .63188 L .62766 .63196 L F
.925 .973 .704 r
.62708 .63262 m .62677 .63287 L .6261 .62954 L F
.613 .482 .678 r
.6261 .62954 m .62677 .63287 L .62502 .63221 L F
.62677 .63287 m .62681 .63307 L .62662 .63298 L F
.62677 .63287 m .62662 .63298 L .62502 .63221 L F
.063 0 0 r
.6272 .63358 m .62885 .63168 L .62838 .63179 L F
.6272 .63358 m .62838 .63179 L .62658 .633 L F
.363 .052 .296 r
.52369 .7868 m .52612 .78385 L .52568 .78613 L F
.339 .029 .285 r
.52568 .78613 m .52612 .78385 L .52872 .78278 L F
.722 .958 .678 r
.62887 .65389 m .6314 .65151 L .63005 .65291 L F
.536 .441 .695 r
.33044 .80559 m .33101 .80199 L .32848 .80276 L F
.33044 .80559 m .3315 .80601 L .33101 .80199 L F
0 0 0 r
.34952 .69708 m .35231 .69495 L .35014 .69524 L F
.774 .767 .846 r
.67142 .60044 m .67409 .60085 L .67123 .60327 L F
.67142 .60044 m .67123 .60327 L .67147 .60241 L F
.661 .285 0 r
.67123 .60327 m .67247 .60584 L .67197 .60489 L F
.67123 .60327 m .67197 .60489 L .67147 .60241 L F
.493 .823 .999 r
.47411 .726 m .476 .72559 L .4775 .72633 L F
.562 .851 .997 r
.4775 .72633 m .47834 .72498 L .47926 .72585 L F
.4775 .72633 m .476 .72559 L .47834 .72498 L F
.463 .373 .669 r
.38876 .76116 m .38748 .76495 L .38675 .76355 L F
.686 .486 .61 r
.70452 .69684 m .70633 .69759 L .70635 .69503 L F
.681 .568 .721 r
.50506 .7381 m .50304 .73894 L .50179 .73552 L F
.747 .605 .7 r
.6109 .65967 m .61204 .66282 L .61423 .66023 L F
.664 .483 .63 r
.61204 .66282 m .61447 .66269 L .61423 .66023 L F
.659 .85 .973 r
.50652 .75983 m .50792 .76048 L .50854 .75901 L F
.50652 .75983 m .50792 .76048 L .50854 .75901 L F
.425 .1 .308 r
.36051 .70367 m .35971 .70539 L .35769 .70579 L F
.486 .231 .452 r
.36221 .70285 m .35971 .70539 L .36051 .70367 L F
.448 .233 .493 r
.37831 .68418 m .37771 .68615 L .37603 .68671 L F
.322 .108 .425 r
.37749 .68844 m .37603 .68671 L .37771 .68615 L F
.37749 .68844 m .37551 .68926 L .37603 .68671 L F
.757 .992 .878 r
.70366 .70664 m .70081 .70812 L .70212 .70541 L F
.612 .357 .507 r
.31161 .68182 m .31021 .68507 L .31017 .68186 L F
.31161 .68182 m .31017 .68186 L .31255 .68187 L F
.465 .023 .113 r
.31405 .68077 m .31255 .68187 L .31017 .68186 L F
.033 0 0 r
.31618 .68071 m .31255 .68187 L .31405 .68077 L F
.331 .815 .851 r
.38747 .79885 m .38686 .79933 L .38909 .79863 L F
.38747 .79885 m .38544 .7994 L .38686 .79933 L F
.483 .493 .791 r
.48694 .87283 m .48814 .87007 L .48585 .8699 L F
.565 .377 .585 r
.48694 .87283 m .48703 .87532 L .48917 .87351 L F
.663 .445 .578 r
.32848 .80276 m .33101 .80199 L .3317 .80097 L F
.703 .542 .666 r
.33101 .80199 m .33502 .80108 L .3317 .80097 L F
.673 .612 .779 r
.66343 .63253 m .66434 .63583 L .66686 .63295 L F
.428 .184 .439 r
.35336 .71123 m .35308 .71353 L .35113 .71395 L F
.376 .138 .42 r
.35568 .70858 m .35528 .71084 L .35336 .71123 L F
.482 .271 .516 r
.35528 .71084 m .35308 .71353 L .35336 .71123 L F
.291 0 .187 r
.63635 .59745 m .63907 .59535 L .637 .5961 L F
.097 .641 .841 r
.72659 .72708 m .72751 .72712 L .7294 .72741 L F
.929 .931 .785 r
.7294 .72741 m .72671 .72864 L .72659 .72708 L F
.7294 .72741 m .72743 .73017 L .72671 .72864 L F
.845 .84 .84 r
.7294 .72741 m .72751 .72712 L .72954 .72466 L F
.018 0 0 r
.53196 .7706 m .52865 .77273 L .53146 .77146 L F
.491 .132 .284 r
.5335 .77264 m .53196 .7706 L .53146 .77146 L F
.5335 .77264 m .53422 .77044 L .53196 .7706 L F
.333 .072 .36 r
.38479 .67823 m .38298 .67907 L .38541 .67633 L F
.113 0 .43 r
.3868 .67292 m .38642 .676 L .38541 .67633 L F
.506 .368 .627 r
.38642 .676 m .38479 .67823 L .38541 .67633 L F
.024 .038 .534 r
.67814 .61369 m .67761 .617 L .67943 .61476 L F
.297 .312 .707 r
.39204 .80716 m .38965 .80739 L .39006 .80512 L F
.194 0 .104 r
.38959 .8092 m .38965 .80739 L .39204 .80716 L F
.397 0 .048 r
.41787 .72519 m .41952 .72577 L .42098 .72412 L F
.476 .045 .141 r
.41952 .72577 m .42313 .72399 L .42098 .72412 L F
.064 0 0 r
.39977 .79459 m .39897 .7951 L .39679 .79573 L F
0 0 0 r
.40111 .79449 m .39977 .79459 L .40177 .79405 L F
.40111 .79449 m .39897 .7951 L .39977 .79459 L F
.912 .829 .75 r
.61086 .64863 m .61375 .6465 L .6127 .64566 L F
.61086 .64863 m .61211 .64954 L .61375 .6465 L F
.887 .904 .834 r
.6127 .64566 m .61375 .6465 L .61575 .64388 L F
.234 .703 .943 r
.40609 .78051 m .40534 .781 L .40273 .77825 L F
.40609 .78051 m .40744 .78107 L .40534 .781 L F
0 0 .039 r
.68322 .62806 m .68488 .62681 L .68553 .6277 L F
.68322 .62806 m .6835 .62518 L .68488 .62681 L F
.892 .79 .741 r
.37532 .80629 m .37707 .80753 L .37783 .80609 L F
.563 .372 .581 r
.36757 .75147 m .3699 .74879 L .36743 .74904 L F
0 0 0 r
.45983 .73561 m .45845 .73576 L .4565 .73586 L F
.122 0 0 r
.46184 .73593 m .45845 .73576 L .45983 .73561 L F
.904 .538 .082 r
.72688 .7381 m .72672 .73927 L .72595 .73659 L F
.272 .326 .736 r
.72814 .73663 m .72688 .7381 L .72595 .73659 L F
.72814 .73663 m .72819 .73848 L .72688 .7381 L F
.292 .303 .7 r
.72819 .73848 m .72896 .74067 L .72688 .7381 L F
.804 .324 .071 r
.72688 .7381 m .72728 .74003 L .72672 .73927 L F
.72688 .7381 m .72896 .74067 L .72728 .74003 L F
.494 .514 .806 r
.49524 .74366 m .49604 .74035 L .49401 .74062 L F
.49524 .74366 m .49721 .74348 L .49604 .74035 L F
.525 .597 .868 r
.659 .62138 m .66009 .61864 L .65829 .62002 L F
.659 .62138 m .66113 .62141 L .66009 .61864 L F
.773 .38 .31 r
.34431 .79726 m .34747 .79813 L .34464 .80005 L F
.097 0 0 r
.33125 .72906 m .32786 .73147 L .32954 .72993 L F
.26 0 .013 r
.43723 .77342 m .43794 .77462 L .43935 .77306 L F
.43723 .77342 m .43589 .77518 L .43794 .77462 L F
.945 .853 .72 r
.65729 .64078 m .65665 .64262 L .65851 .64192 L F
.659 .583 .758 r
.50409 .73494 m .50179 .73552 L .50371 .73299 L F
.681 .568 .721 r
.50506 .7381 m .50179 .73552 L .50409 .73494 L F
.987 .898 .615 r
.6833 .62147 m .68462 .62008 L .68336 .61917 L F
.6833 .62147 m .6833 .6249 L .68462 .62008 L F
.669 .625 .796 r
.50529 .75157 m .50661 .74824 L .50416 .74863 L F
.50529 .75157 m .50763 .75076 L .50661 .74824 L F
.093 .628 .861 r
.44859 .72506 m .45071 .72524 L .45204 .72563 L F
.063 .625 .785 r
.45071 .72524 m .45384 .72537 L .45204 .72563 L F
.189 0 .342 r
.63387 .6001 m .63428 .59818 L .63241 .60108 L F
.473 .318 .589 r
.63214 .60316 m .63387 .6001 L .63241 .60108 L F
.488 .237 .46 r
.38298 .67907 m .38243 .68113 L .38065 .6815 L F
.5 .294 .532 r
.38479 .67823 m .38243 .68113 L .38298 .67907 L F
.721 .562 .673 r
.72039 .73514 m .72142 .73849 L .72357 .73533 L F
0 0 0 r
.40774 .7923 m .40419 .79334 L .40361 .7935 L F
.40865 .79209 m .40774 .7923 L .40979 .7918 L F
.40865 .79209 m .40419 .79334 L .40774 .7923 L F
.576 .588 .827 r
.48718 .72477 m .4862 .7281 L .48493 .72628 L F
.48718 .72477 m .48841 .72766 L .4862 .7281 L F
.66 .644 .823 r
.7056 .57959 m .70342 .58135 L .70254 .57874 L F
.035 .605 .726 r
.43775 .74047 m .4343 .74054 L .43591 .74123 L F
.43775 .74047 m .43624 .74049 L .4343 .74054 L F
.261 0 0 r
.43624 .74049 m .43589 .74058 L .4343 .74054 L F
.219 .688 .942 r
.43591 .74123 m .4343 .74054 L .43247 .74049 L F
.261 0 0 r
.43589 .74058 m .433 .74134 L .4343 .74054 L F
.219 .688 .942 r
.43247 .74049 m .4343 .74054 L .43228 .74045 L F
0 .375 .822 r
.73122 .71369 m .73015 .71328 L .72854 .71184 L F
.365 .834 .874 r
.43228 .74045 m .42929 .74098 L .43012 .74093 L F
.528 .826 .999 r
.52186 .84529 m .52293 .8461 L .52521 .84556 L F
.52186 .84529 m .52293 .8461 L .52521 .84556 L F
.6 .414 .601 r
.34144 .79727 m .34431 .79726 L .34378 .79479 L F
.178 0 0 r
.72251 .61757 m .72374 .61769 L .72378 .6179 L F
.72251 .61757 m .72378 .6179 L .7243 .61602 L F
.45 .178 .408 r
.53287 .7757 m .53547 .77335 L .53479 .77529 L F
0 0 .234 r
.53664 .77231 m .53547 .77335 L .53693 .76996 L F
0 0 .084 r
.53479 .77529 m .53547 .77335 L .53664 .77231 L F
.736 .578 .678 r
.69326 .71396 m .69438 .71701 L .69653 .71683 L F
.74 .615 .719 r
.69438 .71701 m .69449 .71934 L .69653 .71683 L F
.254 .335 .754 r
.69449 .71934 m .69743 .72167 L .6967 .71895 L F
.904 .549 .084 r
.6967 .71895 m .69743 .72167 L .69729 .72135 L F
.514 .303 .531 r
.69449 .71934 m .6967 .71895 L .69625 .71717 L F
.402 .794 .988 r
.69344 .71862 m .69604 .71835 L .6967 .71895 L F
.904 .549 .084 r
.6967 .71895 m .69604 .71835 L .69344 .71862 L F
.6967 .71895 m .69729 .72135 L .69604 .71835 L F
.514 .303 .531 r
.69625 .71717 m .6967 .71895 L .69653 .71683 L F
0 0 0 r
.70729 .63817 m .70692 .63842 L .70476 .63932 L F
.71005 .63628 m .70887 .6372 L .70729 .63817 L F
.70887 .6372 m .70692 .63842 L .70729 .63817 L F
.45 .153 .368 r
.521 .78883 m .52154 .7871 L .52369 .7868 L F
.591 .94 .779 r
.63931 .65998 m .64213 .65809 L .64053 .65872 L F
0 0 0 r
.63931 .65998 m .64053 .65872 L .63802 .66146 L F
.638 .771 .943 r
.67743 .63507 m .68027 .63642 L .68127 .63551 L F
.319 0 0 r
.33467 .67542 m .3331 .67581 L .33094 .67568 L F
.129 0 0 r
.33656 .6754 m .3331 .67581 L .33467 .67542 L F
.637 .667 .862 r
.48181 .73553 m .48534 .73756 L .484 .73482 L F
.56 .58 .831 r
.48534 .73756 m .4863 .73426 L .484 .73482 L F
.48534 .73756 m .48741 .73729 L .4863 .73426 L F
.807 .366 0 r
.34522 .8082 m .34729 .81115 L .3459 .81031 L F
.418 .768 .996 r
.34729 .81115 m .34795 .81017 L .3459 .81031 L F
.34729 .81115 m .34958 .811 L .34795 .81017 L F
.833 .798 .819 r
.58029 .67104 m .57808 .67371 L .57646 .67284 L F
.321 .072 .371 r
.5305 .77841 m .53287 .7757 L .53263 .77764 L F
.452 .247 .51 r
.53007 .78088 m .5305 .77841 L .53263 .77764 L F
.323 .81 .841 r
.45503 .73616 m .45298 .73672 L .45451 .73661 L F
.163 0 0 r
.45503 .73616 m .4545 .7365 L .45298 .73672 L F
.143 .688 .758 r
.45451 .73661 m .45298 .73672 L .45141 .73695 L F
.163 0 0 r
.4545 .7365 m .45119 .73857 L .45298 .73672 L F
.143 .688 .758 r
.45141 .73695 m .45298 .73672 L .45083 .73701 L F
.323 .81 .841 r
.45503 .73616 m .45451 .73661 L .4565 .73586 L F
.709 .92 .579 r
.65829 .62002 m .65678 .62206 L .65655 .62262 L F
0 0 .296 r
.65678 .62206 m .65678 .62495 L .65655 .62262 L F
.781 .579 .626 r
.34032 .79878 m .34431 .79726 L .34144 .79727 L F
.852 .516 .418 r
.71852 .73752 m .72027 .73993 L .72142 .73849 L F
.839 .408 .21 r
.71984 .73926 m .71994 .73934 L .72027 .73993 L F
.941 .937 .593 r
.72027 .73993 m .7207 .7407 L .72142 .73849 L F
.839 .408 .21 r
.71994 .73934 m .72288 .74189 L .72027 .73993 L F
.941 .937 .593 r
.72027 .73993 m .72057 .74111 L .7207 .7407 L F
.613 .432 .613 r
.72027 .73993 m .71942 .74156 L .72057 .74111 L F
.907 .687 .594 r
.71144 .70274 m .71298 .70061 L .70974 .69999 L F
.71144 .70274 m .71289 .70308 L .71298 .70061 L F
.538 .51 .772 r
.4904 .72673 m .48945 .73038 L .48841 .72766 L F
.4904 .72673 m .4916 .73024 L .48945 .73038 L F
.619 .588 .797 r
.49288 .73295 m .48945 .73038 L .4916 .73024 L F
.649 .817 .964 r
.39899 .77745 m .39598 .77886 L .39522 .77793 L F
.562 .754 .968 r
.40001 .7791 m .39598 .77886 L .39899 .77745 L F
0 0 0 r
.44019 .78249 m .44186 .78161 L .4438 .78089 L F
.509 .303 .536 r
.3696 .74631 m .37162 .74593 L .37182 .74366 L F
.505 .372 .633 r
.3699 .74879 m .37162 .74593 L .3696 .74631 L F
.427 .315 .624 r
.37628 .73821 m .37819 .74022 L .37822 .73786 L F
.37628 .73821 m .37665 .74089 L .37819 .74022 L F
.508 .296 .527 r
.37162 .74593 m .37387 .74329 L .37182 .74366 L F
.571 .851 .996 r
.63581 .6239 m .63698 .62469 L .63471 .62524 L F
0 0 0 r
.63444 .627 m .63471 .62524 L .63682 .62682 L F
.574 .376 .575 r
.63471 .62524 m .63698 .62469 L .63682 .62682 L F
0 0 0 r
.63444 .627 m .63581 .6239 L .63471 .62524 L F
.576 .514 .749 r
.3868 .67292 m .38398 .67098 L .38617 .67045 L F
.695 .512 .636 r
.58804 .67422 m .58716 .67629 L .58325 .67605 L F
.634 .551 .743 r
.51172 .74354 m .50947 .74421 L .50839 .74079 L F
.549 .531 .788 r
.51219 .74641 m .50947 .74421 L .51172 .74354 L F
.422 .822 .981 r
.34623 .65223 m .34281 .65214 L .34486 .65173 L F
.453 .806 .997 r
.34685 .65124 m .34623 .65223 L .34486 .65173 L F
.34685 .65124 m .34826 .65191 L .34623 .65223 L F
.408 .089 .31 r
.33823 .7085 m .34014 .70808 L .34111 .70574 L F
.542 .365 .59 r
.34111 .70574 m .34311 .7054 L .34313 .70321 L F
.484 .171 .359 r
.34014 .70808 m .34311 .7054 L .34111 .70574 L F
.205 0 0 r
.38909 .79863 m .38947 .79818 L .39149 .79765 L F
.646 .096 0 r
.66065 .58627 m .65968 .58471 L .65774 .58526 L F
.66065 .58627 m .66207 .58638 L .65968 .58471 L F
.437 .253 .532 r
.35769 .70579 m .35755 .70809 L .35568 .70858 L F
.507 .293 .523 r
.35755 .70809 m .35528 .71084 L .35568 .70858 L F
.941 .588 .314 r
.48175 .7678 m .48311 .76809 L .47998 .76715 L F
.48175 .7678 m .48341 .76994 L .48311 .76809 L F
.608 .471 .669 r
.30549 .68482 m .30304 .68645 L .3024 .6861 L F
.30549 .68482 m .30535 .68703 L .30304 .68645 L F
.30549 .68482 m .30594 .6871 L .30535 .68703 L F
.537 .423 .671 r
.30786 .68652 m .30549 .68482 L .30727 .68478 L F
.30786 .68652 m .30594 .6871 L .30549 .68482 L F
.534 .836 .999 r
.39051 .6651 m .38901 .66431 L .38837 .66557 L F
.38837 .66557 m .38901 .66431 L .39051 .6651 L F
.25 .681 .962 r
.35091 .67376 m .35156 .67312 L .34954 .67294 L F
.35091 .67376 m .35253 .67373 L .35156 .67312 L F
.249 .013 .347 r
.68746 .63377 m .68905 .63294 L .68944 .63099 L F
.992 .792 .536 r
.68746 .63377 m .68681 .63544 L .68905 .63294 L F
.572 .557 .799 r
.39053 .77012 m .38952 .77341 L .38852 .77042 L F
.39053 .77012 m .39167 .77311 L .38952 .77341 L F
.603 .467 .668 r
.392 .77519 m .38952 .77341 L .39167 .77311 L F
.392 .77519 m .38978 .77574 L .38952 .77341 L F
.389 .366 .712 r
.38948 .7668 m .38779 .76812 L .38748 .76495 L F
.523 .486 .757 r
.38948 .7668 m .38852 .77042 L .38779 .76812 L F
.522 .507 .78 r
.48483 .87582 m .48726 .87768 L .48703 .87532 L F
.67 .771 .926 r
.47846 .7351 m .4797 .73632 L .48181 .73553 L F
.887 .904 .834 r
.6127 .64566 m .61575 .64388 L .61493 .64272 L F
.683 .204 .108 r
.46925 .76675 m .471 .76763 L .47247 .76724 L F
.648 .19 .151 r
.471 .76763 m .47446 .76792 L .47247 .76724 L F
.655 .565 .741 r
.65577 .631 m .6563 .63225 L .65356 .63371 L F
.773 .38 .31 r
.34431 .79726 m .34567 .79931 L .34747 .79813 L F
.423 .01 .148 r
.34567 .79931 m .3493 .79723 L .34747 .79813 L F
.648 .418 .556 r
.60248 .68407 m .59931 .68647 L .60026 .68404 L F
.775 .665 .742 r
.70476 .58968 m .70803 .58994 L .70857 .58804 L F
.7 .586 .724 r
.70857 .58804 m .70803 .58994 L .71042 .58724 L F
0 0 0 r
.43421 .72442 m .43632 .7241 L .43763 .72383 L F
.341 0 0 r
.43763 .72383 m .43632 .7241 L .4397 .72421 L F
.645 .146 .049 r
.71638 .70549 m .71889 .70708 L .71957 .70598 L F
.77 .298 .12 r
.71889 .70708 m .72173 .70819 L .71957 .70598 L F
.785 .701 .771 r
.35535 .6845 m .35663 .68711 L .35882 .6844 L F
.625 .462 .642 r
.35663 .68711 m .3589 .68695 L .35882 .6844 L F
.564 .329 .517 r
.35647 .68939 m .3589 .68695 L .35663 .68711 L F
.45 .185 .42 r
.68944 .63099 m .69119 .63224 L .69122 .63025 L F
.68944 .63099 m .68905 .63294 L .69119 .63224 L F
.7 .58 .717 r
.35015 .78933 m .35365 .78938 L .35315 .78687 L F
.593 .418 .613 r
.35015 .78933 m .35345 .79136 L .35365 .78938 L F
.35015 .78933 m .35082 .79178 L .35345 .79136 L F
.407 .024 .196 r
.39361 .73241 m .39572 .73203 L .39687 .7301 L F
.423 .039 .205 r
.39687 .7301 m .39772 .73169 L .3991 .73 L F
.39687 .7301 m .39572 .73203 L .39772 .73169 L F
.546 .261 .434 r
.37822 .73786 m .38048 .7377 L .381 .73528 L F
.514 .27 .483 r
.38048 .7377 m .38309 .7352 L .381 .73528 L F
.705 .774 .906 r
.71871 .71637 m .72195 .71671 L .72096 .71612 L F
.409 .235 .531 r
.33073 .67718 m .32905 .67559 L .33094 .67568 L F
.33073 .67718 m .32876 .67856 L .32905 .67559 L F
.417 0 .086 r
.33334 .7104 m .33538 .71031 L .33605 .70875 L F
.271 0 .081 r
.33538 .71031 m .33823 .7085 L .33605 .70875 L F
.667 .424 .544 r
.60804 .68163 m .61013 .6839 L .60821 .68372 L F
.698 .422 .501 r
.61024 .68194 m .61013 .6839 L .60804 .68163 L F
.603 .181 .216 r
.31974 .68037 m .31808 .68259 L .31795 .68247 L F
0 0 0 r
.32115 .67871 m .31974 .68037 L .31848 .68093 L F
.31974 .68037 m .31773 .68127 L .31848 .68093 L F
.3161 .68085 m .31618 .68071 L .31773 .68127 L F
.603 .181 .216 r
.31974 .68037 m .3161 .68085 L .31773 .68127 L F
.31974 .68037 m .31795 .68247 L .3161 .68085 L F
0 0 0 r
.3212 .67867 m .31974 .68037 L .32115 .67871 L F
.785 .701 .771 r
.35556 .68449 m .35882 .6844 L .35751 .68406 L F
.519 .821 1 r
.35882 .6844 m .36091 .68398 L .35963 .68318 L F
.521 .337 .572 r
.35963 .68318 m .35751 .68406 L .35882 .6844 L F
.557 .409 .635 r
.3589 .68695 m .36091 .68398 L .35882 .6844 L F
.521 .337 .572 r
.35751 .68406 m .35943 .6856 L .3596 .6836 L F
.35751 .68406 m .3596 .6836 L .35963 .68318 L F
.785 .701 .771 r
.35535 .6845 m .35556 .68449 L .35751 .68406 L F
.162 .696 .702 r
.41162 .79101 m .41561 .79016 L .41381 .79053 L F
0 0 0 r
.41561 .79016 m .41588 .79026 L .41381 .79053 L F
.41561 .79016 m .4177 .78973 L .41588 .79026 L F
.858 .633 .597 r
.71852 .73752 m .72142 .73849 L .72039 .73514 L F
.748 .911 .948 r
.71345 .62574 m .71076 .6276 L .70979 .62682 L F
.912 .816 .739 r
.61086 .64863 m .61171 .65186 L .61211 .64954 L F
.61086 .64863 m .60929 .65172 L .61171 .65186 L F
.892 .84 .787 r
.60846 .65318 m .61171 .65186 L .60929 .65172 L F
.60846 .65318 m .60968 .65424 L .61171 .65186 L F
.253 .639 .962 r
.35574 .65347 m .35529 .65428 L .35408 .65315 L F
.35574 .65347 m .35711 .65451 L .35529 .65428 L F
.35 0 0 r
.4288 .72361 m .4308 .72404 L .43223 .72392 L F
.396 0 0 r
.4308 .72404 m .43421 .72442 L .43223 .72392 L F
.241 .755 .848 r
.65303 .58635 m .65605 .58614 L .65457 .58656 L F
.831 .67 .127 r
.66795 .60235 m .66816 .60098 L .668 .60121 L F
.722 .662 .11 r
.66766 .60458 m .66816 .60098 L .66795 .60235 L F
.66766 .60458 m .66754 .60573 L .66816 .60098 L F
.737 .986 .778 r
.57046 .67912 m .57143 .67759 L .57378 .67633 L F
.672 .58 .744 r
.50721 .73742 m .50506 .7381 L .50409 .73494 L F
.50721 .73742 m .50837 .73896 L .50506 .7381 L F
.657 .571 .747 r
.50839 .74079 m .50506 .7381 L .50837 .73896 L F
.581 .464 .684 r
.52054 .75748 m .52174 .75382 L .51981 .75488 L F
.52054 .75748 m .52225 .75465 L .52174 .75382 L F
.52054 .75748 m .52286 .75718 L .52225 .75465 L F
.563 .342 .538 r
.51381 .77829 m .51574 .77839 L .51616 .7758 L F
.578 .356 .542 r
.51616 .7758 m .5183 .77789 L .51892 .77543 L F
.51616 .7758 m .51574 .77839 L .5183 .77789 L F
.622 .952 .781 r
.64213 .65809 m .64338 .65673 L .64053 .65872 L F
.64213 .65809 m .64375 .65676 L .64338 .65673 L F
.289 .006 .298 r
.62154 .61925 m .62393 .61673 L .62195 .61747 L F
.833 .798 .819 r
.58029 .67104 m .57646 .67284 L .57906 .67017 L F
.805 .669 .714 r
.66971 .6162 m .6668 .61943 L .6703 .61949 L F
.721 .49 .575 r
.66649 .6217 m .6703 .61949 L .6668 .61943 L F
.66649 .6217 m .67091 .62177 L .6703 .61949 L F
.712 .429 0 r
.6703 .61949 m .6706 .6208 L .67035 .61845 L F
.6703 .61949 m .67091 .62177 L .6706 .6208 L F
.567 .418 .639 r
.36557 .7567 m .36766 .75381 L .36577 .75437 L F
.736 .732 .847 r
.6894 .59564 m .69279 .59659 L .69166 .5949 L F
.616 .754 .944 r
.69279 .59659 m .69399 .59436 L .69166 .5949 L F
.69279 .59659 m .69513 .5958 L .69399 .59436 L F
.421 .187 .451 r
.38043 .68334 m .37771 .68615 L .37831 .68418 L F
.745 .694 .802 r
.65804 .63034 m .66108 .63083 L .65971 .62816 L F
.767 .637 .717 r
.65804 .63034 m .65936 .63346 L .66108 .63083 L F
.648 .651 .839 r
.65971 .62816 m .66108 .63083 L .66348 .63026 L F
.57 .528 .769 r
.66108 .63083 m .66343 .63253 L .66348 .63026 L F
.194 0 0 r
.4397 .72421 m .44182 .7242 L .44327 .72378 L F
.439 0 0 r
.44327 .72378 m .44182 .7242 L .44519 .72431 L F
.254 0 0 r
.33118 .71103 m .33236 .71101 L .33334 .7104 L F
.389 .128 .392 r
.33118 .71103 m .33227 .71291 L .33236 .71101 L F
.33118 .71103 m .33043 .71362 L .33227 .71291 L F
.479 .803 1 r
.39792 .70871 m .39428 .70825 L .39493 .70855 L F
.39792 .70871 m .39638 .70791 L .39428 .70825 L F
.117 0 .234 r
.62527 .67554 m .62318 .67842 L .62347 .67637 L F
.095 0 .015 r
.44321 .73846 m .44206 .74037 L .44113 .74025 L F
.525 .142 .257 r
.44551 .7396 m .44206 .74037 L .44321 .73846 L F
.703 .542 .666 r
.33101 .80199 m .33423 .80338 L .33502 .80108 L F
.287 .115 .466 r
.33502 .80108 m .33423 .80338 L .33649 .80053 L F
.303 .574 .935 r
.37364 .80524 m .37707 .80753 L .37532 .80629 L F
.655 .714 .892 r
.49034 .88041 m .49123 .88247 L .49388 .8814 L F
.268 0 .086 r
.32089 .65219 m .3216 .65352 L .32304 .65191 L F
.32089 .65219 m .31964 .65414 L .3216 .65352 L F
.96 .749 .574 r
.49704 .86983 m .49673 .87217 L .49806 .87277 L F
.716 .849 .945 r
.69513 .5958 m .69838 .59571 L .69736 .59506 L F
0 0 .066 r
.69838 .59571 m .69955 .59465 L .6996 .59445 L F
.559 .864 .996 r
.6996 .59445 m .69736 .59506 L .69838 .59571 L F
0 0 .145 r
.63087 .62422 m .62974 .6271 L .62966 .62514 L F
.041 .597 .815 r
.7034 .62663 m .70756 .62725 L .70528 .62705 L F
.395 .182 .468 r
.357 .80783 m .35753 .80555 L .35871 .80617 L F
.703 .647 .791 r
.357 .80783 m .35871 .80617 L .35753 .80555 L F
.511 .323 .562 r
.35249 .78393 m .35448 .78356 L .3546 .78122 L F
.629 .521 .712 r
.35249 .78393 m .35538 .78656 L .35448 .78356 L F
.35249 .78393 m .35315 .78687 L .35538 .78656 L F
.631 .534 .726 r
.35315 .78687 m .35365 .78938 L .35538 .78656 L F
.664 .352 .435 r
.35345 .79136 m .35549 .79144 L .35365 .78938 L F
.607 .503 .71 r
.35365 .78938 m .35586 .78916 L .35538 .78656 L F
.576 .352 .538 r
.35365 .78938 m .35549 .79144 L .35586 .78916 L F
.249 0 .092 r
.61649 .62379 m .61732 .62253 L .61446 .62452 L F
.419 .084 .288 r
.61649 .62379 m .61931 .62192 L .61732 .62253 L F
.444 .231 .494 r
.61732 .62253 m .61931 .62192 L .61946 .61983 L F
0 0 0 r
.34578 .71883 m .34338 .7212 L .34434 .71977 L F
.429 .016 .151 r
.4012 .72963 m .40336 .72942 L .40463 .72762 L F
.493 .116 .253 r
.40336 .72942 m .40672 .72726 L .40463 .72762 L F
.495 .294 .535 r
.53287 .7757 m .53476 .77715 L .53263 .77764 L F
.53287 .7757 m .53479 .77529 L .53476 .77715 L F
.673 .444 .566 r
.61362 .68137 m .61013 .6839 L .61024 .68194 L F
.568 .852 .523 r
.64655 .60307 m .64899 .60041 L .64875 .60295 L F
.511 .466 .743 r
.6509 .60026 m .64899 .60041 L .64809 .59766 L F
.48 .263 .506 r
.64875 .60295 m .64899 .60041 L .6509 .60026 L F
0 0 0 r
.44488 .77058 m .44512 .77114 L .44701 .77045 L F
.44488 .77058 m .44352 .77221 L .44512 .77114 L F
.959 .947 .674 r
.64002 .61801 m .63911 .62205 L .63905 .61978 L F
.956 .801 .357 r
.63911 .61903 m .63911 .62205 L .63905 .61978 L F
.374 .466 .827 r
.36799 .65666 m .3675 .65946 L .3659 .65698 L F
.36799 .65666 m .36923 .65977 L .3675 .65946 L F
.643 .288 .355 r
.32327 .67869 m .31974 .68037 L .3212 .67867 L F
.383 .169 .461 r
.39264 .75402 m .39095 .75611 L .39095 .75445 L F
.814 .505 0 r
.66754 .60573 m .66855 .60988 L .66853 .60867 L F
.775 .665 .742 r
.70476 .58968 m .70857 .58804 L .70517 .58741 L F
.609 .375 .537 r
.70857 .58804 m .70923 .58417 L .70761 .5853 L F
0 .371 .835 r
.66636 .59249 m .66903 .59403 L .66659 .59298 L F
0 0 .234 r
.66754 .59651 m .66659 .59298 L .66903 .59403 L F
.66754 .59651 m .66778 .5979 L .66659 .59298 L F
.693 .786 .922 r
.51623 .73768 m .51259 .73737 L .51489 .73508 L F
.565 .543 .789 r
.51717 .73436 m .51623 .73768 L .51489 .73508 L F
.51717 .73436 m .51833 .73738 L .51623 .73768 L F
.656 .58 .757 r
.51833 .73738 m .51827 .74022 L .51623 .73768 L F
.447 .148 .362 r
.35253 .71571 m .35113 .71395 L .35308 .71353 L F
.35253 .71571 m .35044 .71617 L .35113 .71395 L F
.466 .304 .576 r
.34313 .70321 m .34476 .70459 L .34496 .70249 L F
.34313 .70321 m .34311 .7054 L .34476 .70459 L F
.236 0 0 r
.36054 .65526 m .36259 .65555 L .36442 .65553 L F
.569 .361 .558 r
.36442 .65553 m .3659 .65698 L .36616 .6543 L F
.106 .28 .758 r
.36515 .65496 m .36442 .65553 L .36259 .65555 L F
.36515 .65496 m .3659 .65698 L .36442 .65553 L F
.175 0 0 r
.45384 .72537 m .45614 .72571 L .45764 .72573 L F
.47 0 0 r
.45614 .72571 m .45965 .72542 L .45764 .72573 L F
.581 .441 .656 r
.36007 .76768 m .36222 .76739 L .36204 .76493 L F
.56 .409 .633 r
.3603 .77011 m .36222 .76739 L .36007 .76768 L F
.808 .644 .679 r
.60698 .66529 m .60979 .66555 L .60865 .66245 L F
.691 .418 .505 r
.60663 .66757 m .60979 .66555 L .60698 .66529 L F
.60663 .66757 m .60983 .66759 L .60979 .66555 L F
.604 .539 .754 r
.60865 .66245 m .60979 .66555 L .61209 .66515 L F
.543 .302 .5 r
.60979 .66555 m .60983 .66759 L .61209 .66515 L F
.314 .42 .811 r
.67545 .63384 m .67688 .63217 L .67481 .63212 L F
.67545 .63384 m .67743 .63507 L .67688 .63217 L F
0 0 0 r
.62737 .67286 m .62527 .67554 L .62609 .67404 L F
.511 .466 .743 r
.6509 .60026 m .64809 .59766 L .65172 .5985 L F
.875 .587 .497 r
.49283 .86958 m .49341 .8719 L .49465 .87022 L F
.699 .342 .368 r
.49341 .8719 m .49673 .87217 L .49465 .87022 L F
.572 .374 .574 r
.49465 .87022 m .49673 .87217 L .49704 .86983 L F
.591 .447 .655 r
.35656 .77607 m .35879 .77813 L .35883 .77574 L F
.35656 .77607 m .35661 .77846 L .35879 .77813 L F
.836 .767 .786 r
.66825 .61388 m .66971 .6162 L .66904 .61447 L F
.722 .491 .576 r
.58148 .67601 m .58149 .67864 L .57807 .67827 L F
.732 .5 .575 r
.58333 .67814 m .58148 .67601 L .58325 .67605 L F
.58333 .67814 m .58149 .67864 L .58148 .67601 L F
.465 .248 .499 r
.61946 .61983 m .61931 .62192 L .62154 .61925 L F
.976 .798 .599 r
.40158 .7763 m .40157 .77878 L .40066 .77802 L F
.7 .858 .958 r
.40066 .77802 m .40157 .77878 L .40001 .7791 L F
.416 .338 .661 r
.40332 .77774 m .40157 .77878 L .40158 .7763 L F
.226 0 .348 r
.40332 .77774 m .40273 .77825 L .40157 .77878 L F
.7 .644 .79 r
.39969 .77258 m .40158 .7763 L .3987 .77559 L F
.976 .798 .599 r
.40158 .7763 m .40066 .77802 L .3987 .77559 L F
.567 .58 .826 r
.40319 .77531 m .40158 .7763 L .39969 .77258 L F
.416 .338 .661 r
.40332 .77774 m .40158 .7763 L .40319 .77531 L F
.396 .213 .512 r
.62575 .61591 m .62407 .61442 L .62393 .61673 L F
.62575 .61591 m .62584 .61374 L .62407 .61442 L F
.578 .124 .137 r
.46583 .77564 m .46447 .77616 L .46252 .77576 L F
.541 .104 .158 r
.46802 .77564 m .46447 .77616 L .46583 .77564 L F
.566 .138 .188 r
.30594 .6871 m .30304 .68645 L .30535 .68703 L F
.293 .013 .306 r
.63387 .6001 m .63635 .59745 L .63428 .59818 L F
.623 .446 .622 r
.3315 .80601 m .33423 .80338 L .33101 .80199 L F
0 .203 .724 r
.38142 .66894 m .38146 .66981 L .37936 .66868 L F
.722 .592 .71 r
.60865 .66245 m .61204 .66282 L .6109 .65967 L F
.604 .539 .754 r
.60865 .66245 m .61209 .66515 L .61204 .66282 L F
.633 .42 .576 r
.61209 .66515 m .61447 .66269 L .61204 .66282 L F
.546 .158 .257 r
.32493 .65075 m .327 .65099 L .32858 .64869 L F
.311 .748 .967 r
.32858 .64869 m .3291 .64802 L .33065 .64864 L F
.52 .338 .573 r
.327 .65099 m .3291 .64802 L .32858 .64869 L F
.664 .559 .725 r
.51061 .73833 m .50839 .74079 L .50837 .73896 L F
.834 .791 .81 r
.49585 .87991 m .49949 .87826 L .49597 .87802 L F
.49585 .87991 m .49711 .88104 L .49949 .87826 L F
.302 0 0 r
.4214 .74304 m .42118 .74328 L .41914 .74308 L F
.001 0 0 r
.42327 .74274 m .4214 .74304 L .42485 .74246 L F
.513 .302 .53 r
.38239 .68265 m .38065 .6815 L .38243 .68113 L F
.38239 .68265 m .38043 .68334 L .38065 .6815 L F
.376 0 .033 r
.45149 .77836 m .44798 .78007 L .44938 .77871 L F
.431 0 0 r
.47446 .76792 m .47688 .76817 L .47777 .76729 L F
.094 0 0 r
.47688 .76817 m .47998 .76715 L .47777 .76729 L F
.504 0 0 r
.48632 .77565 m .4845 .77562 L .48267 .77508 L F
.707 .262 .192 r
.48632 .77565 m .48778 .77617 L .4845 .77562 L F
.012 0 0 r
.32059 .71675 m .32259 .71635 L .32353 .71596 L F
.277 0 0 r
.32259 .71635 m .32554 .71562 L .32353 .71596 L F
.877 .702 .661 r
.69719 .71017 m .69437 .71117 L .69543 .71124 L F
.985 .733 .464 r
.69896 .72739 m .69791 .72682 L .69787 .72434 L F
0 .319 .794 r
.69787 .72434 m .70123 .727 L .69896 .72739 L F
.684 .265 .244 r
.70123 .727 m .69791 .72682 L .69896 .72739 L F
.346 .723 .985 r
.33801 .64968 m .33702 .65046 L .33605 .64993 L F
.33801 .64968 m .33957 .65064 L .33702 .65046 L F
.869 .906 .854 r
.70331 .59298 m .7055 .59218 L .70526 .59001 L F
.286 0 0 r
.33658 .84516 m .3378 .84548 L .33638 .84502 L F
.33658 .84516 m .33839 .84569 L .3378 .84548 L F
.732 .352 .332 r
.51561 .78898 m .51904 .78937 L .51774 .79126 L F
.259 0 .044 r
.51774 .79126 m .51904 .78937 L .521 .78883 L F
.571 .418 .635 r
.3546 .78122 m .35672 .78093 L .35661 .77846 L F
.182 0 .23 r
.35448 .78356 m .35672 .78093 L .3546 .78122 L F
0 0 .184 r
.67204 .60879 m .67238 .60815 L .67247 .60584 L F
.709 .658 .798 r
.51219 .74641 m .51503 .74616 L .51297 .74713 L F
.903 .976 .803 r
.73357 .72863 m .7336 .73016 L .73553 .72746 L F
.293 0 .017 r
.41975 .78916 m .42315 .78701 L .42172 .78855 L F
.22 0 0 r
.42315 .78701 m .42371 .78794 L .42172 .78855 L F
.42315 .78701 m .42526 .78662 L .42371 .78794 L F
.659 .262 .282 r
.49551 .77263 m .49776 .77316 L .49914 .77257 L F
.673 .285 .302 r
.49914 .77257 m .49776 .77316 L .50096 .77312 L F
.83 .663 .675 r
.60968 .65424 m .6083 .65743 L .61097 .65752 L F
.799 .651 .699 r
.60756 .65947 m .61097 .65752 L .6083 .65743 L F
.60756 .65947 m .6109 .65967 L .61097 .65752 L F
.711 .54 .655 r
.58716 .67629 m .58333 .67814 L .58325 .67605 L F
.675 .197 .108 r
.48778 .77617 m .48671 .77729 L .4845 .77562 L F
.628 .14 .075 r
.48778 .77617 m .49004 .77762 L .48671 .77729 L F
.966 .686 .265 r
.67416 .63105 m .67337 .62756 L .67457 .62789 L F
.811 .962 .908 r
.68939 .58398 m .68897 .58515 L .68549 .58571 L F
.679 .641 .805 r
.71068 .73352 m .70894 .73539 L .70793 .73233 L F
.668 .635 .808 r
.70793 .73233 m .70894 .73539 L .70867 .73332 L F
.345 .458 .832 r
.70894 .73539 m .71054 .73381 L .70867 .73332 L F
.70894 .73539 m .71183 .73687 L .71054 .73381 L F
.658 .688 .867 r
.50063 .73201 m .49726 .73006 L .49934 .72933 L F
.674 .679 .846 r
.50273 .72993 m .50063 .73201 L .49934 .72933 L F
.652 .116 0 r
.72431 .71001 m .72318 .70834 L .72173 .70819 L F
.72431 .71001 m .72562 .70995 L .72318 .70834 L F
0 0 .533 r
.66378 .58896 m .66262 .58781 L .66207 .58638 L F
.66378 .58896 m .6655 .59153 L .66262 .58781 L F
.885 .653 .583 r
.42408 .77269 m .42499 .77292 L .425 .77041 L F
.42408 .77269 m .42499 .77292 L .425 .77041 L F
.46 .224 .469 r
.42747 .76786 m .42705 .76999 L .425 .77041 L F
.468 .311 .584 r
.42699 .77235 m .425 .77041 L .42705 .76999 L F
.42699 .77235 m .42499 .77292 L .425 .77041 L F
.46 .224 .469 r
.425 .77041 m .42705 .76999 L .42747 .76786 L F
.468 .311 .584 r
.425 .77041 m .42699 .77235 L .42705 .76999 L F
.425 .77041 m .42499 .77292 L .42699 .77235 L F
.42699 .77235 m .42499 .77292 L .425 .77041 L F
0 0 .234 r
.53664 .77231 m .53693 .76996 L .53422 .77044 L F
.76 .755 .848 r
.70145 .58509 m .69815 .58455 L .70044 .58384 L F
.563 .318 .503 r
.70385 .5865 m .70383 .58452 L .70145 .58509 L F
0 .343 .813 r
.70385 .5865 m .70145 .58509 L .70044 .58384 L F
.29 .637 .965 r
.35255 .65192 m .35165 .65277 L .35019 .65169 L F
.35255 .65192 m .35408 .65315 L .35165 .65277 L F
.878 .882 .833 r
.68023 .63246 m .68366 .6307 L .68281 .63079 L F
.68023 .63246 m .68128 .63306 L .68366 .6307 L F
0 0 0 r
.68501 .62932 m .68366 .6307 L .68553 .6277 L F
.605 .951 .821 r
.68281 .63079 m .68366 .6307 L .68501 .62932 L F
.791 .701 .765 r
.60756 .65947 m .60865 .66245 L .6109 .65967 L F
.745 .924 .95 r
.69972 .64277 m .70156 .64039 L .69864 .64205 L F
.69972 .64277 m .70251 .64104 L .70156 .64039 L F
.713 .735 .869 r
.6911 .64271 m .69414 .64269 L .69369 .64169 L F
.622 .846 .985 r
.69414 .64269 m .69559 .64111 L .69369 .64169 L F
.69414 .64269 m .69678 .64208 L .69559 .64111 L F
.971 .93 .652 r
.59182 .67825 m .59062 .68147 L .59165 .67946 L F
.562 .175 .265 r
.52865 .77273 m .53051 .77403 L .53146 .77146 L F
.41 .031 .205 r
.53146 .77146 m .53277 .77353 L .5335 .77264 L F
.53146 .77146 m .53051 .77403 L .53277 .77353 L F
.633 .732 .919 r
.68195 .58891 m .68372 .58655 L .68158 .58715 L F
.68195 .58891 m .68495 .58806 L .68372 .58655 L F
.158 0 .288 r
.63274 .63264 m .6333 .63077 L .63491 .62873 L F
.395 .167 .446 r
.42926 .76729 m .42705 .76999 L .42747 .76786 L F
.42926 .76729 m .42705 .76999 L .42747 .76786 L F
.024 .038 .534 r
.67787 .61541 m .67875 .61594 L .67761 .617 L F
.472 .795 .999 r
.67761 .617 m .67875 .61594 L .67973 .61671 L F
0 .521 .824 r
.67732 .61577 m .67999 .61668 L .67875 .61594 L F
0 .33 .812 r
.68161 .61723 m .67973 .61671 L .67875 .61594 L F
0 .521 .824 r
.67999 .61668 m .68161 .61723 L .67875 .61594 L F
.024 .038 .534 r
.67814 .61369 m .67875 .61594 L .67787 .61541 L F
.271 .378 .789 r
.67218 .59217 m .67173 .59009 L .67231 .59248 L F
.925 .613 .144 r
.67131 .59018 m .67231 .59248 L .67173 .59009 L F
.822 .642 .659 r
.67285 .59786 m .67409 .60085 L .67142 .60044 L F
.714 .487 .579 r
.67285 .59786 m .67629 .60039 L .67409 .60085 L F
.261 0 0 r
.4654 .73603 m .46405 .73628 L .46184 .73593 L F
.245 0 0 r
.46745 .73512 m .46405 .73628 L .4654 .73603 L F
.873 .736 .707 r
.58847 .68419 m .58919 .68701 L .58764 .68635 L F
.793 .587 .622 r
.58919 .68701 m .58603 .68901 L .58764 .68635 L F
.58919 .68701 m .58931 .68946 L .58603 .68901 L F
.614 .447 .633 r
.59124 .6892 m .58919 .68701 L .59133 .68676 L F
.59124 .6892 m .58931 .68946 L .58919 .68701 L F
.504 .305 .543 r
.3681 .65417 m .3659 .65698 L .36616 .6543 L F
0 .077 .637 r
.7321 .71583 m .73352 .7189 L .7323 .71708 L F
.674 .39 .482 r
.70089 .69746 m .70322 .69816 L .70452 .69684 L F
.563 .141 .199 r
.70322 .69816 m .70633 .69759 L .70452 .69684 L F
.16 .7 .79 r
.4264 .74248 m .42327 .74274 L .42485 .74246 L F
.628 .631 .834 r
.48741 .73729 m .48852 .73905 L .4906 .73833 L F
.709 .924 .964 r
.71005 .63628 m .71188 .63516 L .71104 .63453 L F
.738 .95 .643 r
.71104 .63453 m .70887 .6372 L .71005 .63628 L F
.7 .858 .958 r
.40066 .77802 m .40001 .7791 L .39899 .77745 L F
.446 .877 .907 r
.31427 .73803 m .31622 .73733 L .31411 .73803 L F
.533 .342 .568 r
.35971 .70539 m .35755 .70809 L .35769 .70579 L F
.748 .362 .323 r
.50404 .78099 m .50238 .78241 L .50208 .78088 L F
.50404 .78099 m .50574 .78304 L .50238 .78241 L F
.67 .579 .745 r
.51061 .73833 m .50837 .73896 L .50721 .73742 L F
.462 0 .038 r
.45476 .7776 m .45363 .77854 L .45149 .77836 L F
.347 0 0 r
.45695 .77741 m .45363 .77854 L .45476 .7776 L F
.861 .457 0 r
.72696 .61212 m .72743 .61345 L .72776 .61358 L F
.009 .218 .728 r
.72953 .6151 m .72743 .61345 L .72776 .61358 L F
.725 .618 .738 r
.6563 .63225 m .65936 .63346 L .65804 .63034 L F
.875 .755 .727 r
.65843 .63507 m .65936 .63346 L .6563 .63225 L F
.6 .582 .805 r
.3931 .77825 m .38978 .77574 L .392 .77519 L F
.487 .606 .896 r
.68394 .6087 m .68059 .60632 L .68275 .60686 L F
.33 .529 .898 r
.68275 .60686 m .68559 .60786 L .68394 .6087 L F
.363 .827 .756 r
.68559 .60786 m .68264 .60905 L .68394 .6087 L F
.539 0 0 r
.68137 .62385 m .6833 .6249 L .6833 .62147 L F
.68137 .62385 m .6835 .62518 L .6833 .6249 L F
.498 0 0 r
.44113 .74025 m .43964 .74147 L .43775 .74047 L F
.558 .162 .248 r
.44206 .74037 m .43964 .74147 L .44113 .74025 L F
0 .548 .707 r
.45965 .72542 m .4616 .72552 L .46282 .72559 L F
.215 0 0 r
.4616 .72552 m .46499 .72558 L .46282 .72559 L F
.577 .032 0 r
.48341 .76994 m .48589 .77124 L .48671 .7705 L F
.465 0 0 r
.48589 .77124 m .48899 .77169 L .48671 .7705 L F
.825 .829 .851 r
.65314 .6489 m .6547 .64541 L .65246 .64869 L F
.65314 .6489 m .65583 .64649 L .6547 .64541 L F
.741 .476 .529 r
.51103 .77822 m .51332 .78083 L .51381 .77829 L F
.557 .302 .485 r
.51332 .78083 m .51574 .77839 L .51381 .77829 L F
.979 .724 .32 r
.73359 .72101 m .73427 .72189 L .73352 .7189 L F
.925 .541 .162 r
.73421 .72387 m .7352 .72453 L .73427 .72189 L F
.189 0 0 r
.38601 .73305 m .38806 .73271 L .38879 .73224 L F
.453 0 0 r
.38879 .73224 m .38806 .73271 L .39117 .73234 L F
.57 .31 .483 r
.62102 .67884 m .62087 .68097 L .61813 .68145 L F
.271 0 .252 r
.62318 .67842 m .62087 .68097 L .62102 .67884 L F
.625 .559 .76 r
.50602 .73247 m .50409 .73494 L .50371 .73299 L F
.50602 .73247 m .50676 .73607 L .50409 .73494 L F
.672 .58 .744 r
.50721 .73742 m .50409 .73494 L .50676 .73607 L F
.899 .6 .099 r
.72743 .73017 m .72729 .7313 L .72671 .72864 L F
.72743 .73017 m .72793 .73238 L .72729 .7313 L F
.552 .179 .289 r
.44869 .73732 m .44745 .7397 L .44551 .7396 L F
.53 .186 .329 r
.45083 .73701 m .44745 .7397 L .44869 .73732 L F
.084 0 .017 r
.34153 .7219 m .34036 .72395 L .33889 .72419 L F
.184 0 .071 r
.34213 .72318 m .34153 .7219 L .34338 .7212 L F
.34213 .72318 m .34036 .72395 L .34153 .7219 L F
.306 .106 .436 r
.3475 .69746 m .34871 .69912 L .34952 .69708 L F
.3475 .69746 m .34735 .69969 L .34871 .69912 L F
.63 .502 .687 r
.36182 .76259 m .36204 .76493 L .36401 .7622 L F
.593 .13 .123 r
.48267 .77508 m .48114 .77575 L .47908 .77523 L F
.585 .119 .114 r
.4845 .77562 m .48114 .77575 L .48267 .77508 L F
.451 .883 .837 r
.39149 .79765 m .39467 .79649 L .39333 .79705 L F
.271 0 0 r
.39679 .79573 m .39333 .79705 L .39467 .79649 L F
.929 .752 .642 r
.60719 .66136 m .60865 .66245 L .60756 .65947 L F
.937 .854 .734 r
.60593 .6646 m .60865 .66245 L .60719 .66136 L F
.60593 .6646 m .60698 .66529 L .60865 .66245 L F
.714 .487 .579 r
.67285 .59786 m .67626 .59812 L .67629 .60039 L F
.111 .02 .462 r
.67629 .60039 m .67626 .59812 L .67783 .59686 L F
.59 .587 .817 r
.68336 .61917 m .68096 .61966 L .67973 .61671 L F
.466 0 0 r
.71068 .73352 m .71356 .73445 L .71493 .7343 L F
.47 0 0 r
.71356 .73445 m .71673 .73498 L .71493 .7343 L F
.722 .958 .678 r
.62887 .65389 m .63112 .65137 L .6314 .65151 L F
.908 .976 .794 r
.63112 .65137 m .63385 .64893 L .6314 .65151 L F
.698 .605 .748 r
.69871 .62482 m .69975 .6281 L .69667 .62752 L F
.566 .138 .188 r
.30594 .6871 m .30349 .68863 L .30304 .68645 L F
.30594 .6871 m .30449 .68869 L .30349 .68863 L F
.128 0 0 r
.30629 .68809 m .30594 .6871 L .30786 .68652 L F
.30629 .68809 m .30449 .68869 L .30594 .6871 L F
.59 .478 .694 r
.35859 .77356 m .36099 .77542 L .3607 .77309 L F
.35859 .77356 m .35883 .77574 L .36099 .77542 L F
.463 .373 .669 r
.38876 .76116 m .3897 .76644 L .38748 .76495 L F
.459 .374 .672 r
.3897 .76644 m .38948 .7668 L .38748 .76495 L F
.207 .376 .812 r
.69457 .62846 m .69607 .62672 L .69667 .62752 L F
.885 .974 .833 r
.69871 .62482 m .69667 .62752 L .69607 .62672 L F
.7 .644 .79 r
.39969 .77258 m .3987 .77559 L .39762 .77532 L F
.769 .448 .444 r
.3987 .77559 m .39736 .77767 L .39762 .77532 L F
.704 .271 .22 r
.39736 .77767 m .40066 .77802 L .39899 .77745 L F
.769 .448 .444 r
.3987 .77559 m .40066 .77802 L .39736 .77767 L F
.563 .372 .581 r
.36757 .75147 m .3698 .75123 L .3699 .74879 L F
.514 .349 .595 r
.36757 .75147 m .36961 .75343 L .3698 .75123 L F
.36757 .75147 m .36766 .75381 L .36961 .75343 L F
.903 .976 .803 r
.73357 .72863 m .73553 .72746 L .73445 .72665 L F
.472 .48 .785 r
.49721 .74348 m .49805 .74691 L .4998 .74516 L F
.502 .528 .816 r
.49805 .74691 m .50083 .74955 L .4998 .74516 L F
.639 .696 .887 r
.47301 .73457 m .47631 .73551 L .47514 .73426 L F
.573 .743 .957 r
.47514 .73426 m .47631 .73551 L .47846 .7351 L F
.585 .579 .813 r
.50942 .73545 m .50721 .73742 L .50676 .73607 L F
.67 .579 .745 r
.51061 .73833 m .50721 .73742 L .50942 .73545 L F
.538 .254 .432 r
.41568 .74337 m .41314 .7456 L .41376 .74313 L F
.505 .372 .633 r
.3699 .74879 m .37181 .74837 L .37162 .74593 L F
.517 .347 .59 r
.3698 .75123 m .37181 .74837 L .3699 .74879 L F
.623 .577 .781 r
.68891 .61675 m .69162 .61851 L .69105 .61685 L F
.378 .249 .576 r
.33423 .80338 m .3362 .80558 L .33615 .80258 L F
.607 .613 .831 r
.33457 .80708 m .33527 .80917 L .33702 .80793 L F
.378 .249 .576 r
.33423 .80338 m .33419 .80717 L .33549 .80615 L F
.33598 .80565 m .33549 .80615 L .33603 .80572 L F
.33423 .80338 m .33549 .80615 L .33598 .80565 L F
.614 .608 .822 r
.33476 .80688 m .33702 .80793 L .33568 .80693 L F
.378 .249 .576 r
.33618 .80557 m .33603 .80572 L .3362 .80558 L F
.608 .622 .84 r
.33387 .80683 m .3362 .80558 L .33419 .80717 L F
.614 .608 .822 r
.33387 .80683 m .33457 .80708 L .33476 .80688 L F
.33457 .80708 m .33702 .80793 L .33476 .80688 L F
.607 .613 .831 r
.33387 .80683 m .33421 .80741 L .33457 .80708 L F
.33421 .80741 m .33527 .80917 L .33457 .80708 L F
.378 .249 .576 r
.33423 .80338 m .33603 .80572 L .33618 .80557 L F
.534 .437 .692 r
.33649 .80053 m .33423 .80338 L .33615 .80258 L F
.223 .026 .389 r
.62584 .61374 m .62764 .61077 L .62619 .61172 L F
.578 .535 .77 r
.3941 .77465 m .3931 .77825 L .392 .77519 L F
.3941 .77465 m .39522 .77793 L .3931 .77825 L F
.667 .624 .797 r
.50661 .74824 m .50763 .75076 L .50943 .74865 L F
.785 .588 .634 r
.67442 .59319 m .67231 .59248 L .6738 .59194 L F
.67442 .59319 m .67217 .59438 L .67231 .59248 L F
.67442 .59319 m .67471 .59464 L .67217 .59438 L F
.548 0 0 r
.67453 .59403 m .67442 .59319 L .6738 .59194 L F
.67453 .59403 m .67741 .59452 L .67442 .59319 L F
.56 .828 .996 r
.48321 .72586 m .47926 .72585 L .48172 .72457 L F
.472 .626 .919 r
.4838 .72421 m .48321 .72586 L .48172 .72457 L F
.4838 .72421 m .48493 .72628 L .48321 .72586 L F
.224 0 .063 r
.41775 .77798 m .41958 .77776 L .42062 .77604 L F
.314 0 .112 r
.42062 .77604 m .41958 .77776 L .42169 .7773 L F
.681 .762 .274 r
.3461 .80592 m .34522 .8082 L .34558 .80721 L F
.711 .54 .655 r
.58716 .67629 m .58685 .67861 L .58333 .67814 L F
.656 .676 .857 r
.3713 .65932 m .37058 .66257 L .36923 .65977 L F
.3713 .65932 m .37292 .66194 L .37058 .66257 L F
.354 0 .125 r
.38504 .73475 m .38806 .73271 L .38601 .73305 L F
.836 .767 .786 r
.66825 .61388 m .66604 .61673 L .66971 .6162 L F
.837 .728 .743 r
.66604 .61673 m .6668 .61943 L .66971 .6162 L F
0 0 .522 r
.67011 .61536 m .66999 .61631 L .66971 .6162 L F
.839 .96 .626 r
.67276 .61177 m .66999 .61631 L .67011 .61536 L F
0 0 .067 r
.67035 .61845 m .67011 .61536 L .66971 .6162 L F
.625 .207 .23 r
.41914 .74308 m .4176 .74496 L .41568 .74337 L F
.346 0 0 r
.42118 .74328 m .4176 .74496 L .41914 .74308 L F
.577 .588 .827 r
.51851 .74884 m .51503 .74616 L .517 .74797 L F
.735 .507 .584 r
.51502 .7507 m .51839 .75116 L .51851 .74884 L F
.523 .486 .757 r
.38948 .7668 m .39053 .77012 L .38852 .77042 L F
.282 0 0 r
.67176 .61141 m .67143 .61144 L .67179 .61028 L F
.67176 .61141 m .67276 .61177 L .67143 .61144 L F
.496 .376 .645 r
.64897 .6057 m .64655 .60307 L .64875 .60295 L F
.202 0 0 r
.44701 .77045 m .44908 .77042 L .45027 .77006 L F
.323 0 0 r
.44908 .77042 m .45255 .77039 L .45027 .77006 L F
.255 0 .316 r
.62975 .668 m .62919 .67012 L .62752 .67075 L F
0 0 .158 r
.62919 .67012 m .62737 .67286 L .62752 .67075 L F
.383 .611 .94 r
.36115 .65379 m .36054 .65526 L .35914 .65406 L F
.36115 .65379 m .36259 .65555 L .36054 .65526 L F
.929 .769 .662 r
.67217 .59438 m .67285 .59786 L .6704 .5974 L F
.923 .797 .703 r
.6704 .5974 m .67285 .59786 L .67142 .60044 L F
.775 .681 .76 r
.67471 .59464 m .67285 .59786 L .67217 .59438 L F
.633 .42 .576 r
.61209 .66515 m .61454 .66496 L .61447 .66269 L F
.569 .3 .468 r
.61454 .66496 m .61751 .66244 L .61447 .66269 L F
.562 .113 .143 r
.41416 .72627 m .41643 .72663 L .41787 .72519 L F
.397 0 .024 r
.41787 .72519 m .41643 .72663 L .41952 .72577 L F
0 .499 .853 r
.68906 .64387 m .6883 .64329 L .68609 .64259 L F
.737 .961 .941 r
.6899 .64219 m .68906 .64387 L .6911 .64271 L F
.718 .941 .957 r
.6899 .64219 m .6883 .64329 L .68906 .64387 L F
.566 .321 .504 r
.31019 .68319 m .31021 .68507 L .3082 .68487 L F
.18 .231 .679 r
.30884 .68537 m .30727 .68478 L .31021 .68507 L F
.185 0 .099 r
.31161 .68182 m .30884 .68537 L .31021 .68507 L F
.31124 .68229 m .31046 .68491 L .30884 .68537 L F
.31161 .68182 m .31152 .68205 L .31124 .68229 L F
.31152 .68205 m .31046 .68491 L .31124 .68229 L F
.566 .321 .504 r
.31017 .68186 m .31019 .68319 L .30727 .68478 L F
.31019 .68319 m .3082 .68487 L .30727 .68478 L F
.146 .509 .912 r
.72713 .71749 m .72866 .71752 L .72628 .71635 L F
.72713 .71749 m .72987 .71857 L .72866 .71752 L F
.677 .482 .614 r
.59467 .68894 m .59133 .68676 L .5947 .68683 L F
.614 .376 .533 r
.5947 .68683 m .59701 .68885 L .59467 .68894 L F
.612 .376 .536 r
.59698 .68671 m .59701 .68885 L .5947 .68683 L F
.242 0 .267 r
.63169 .66708 m .62919 .67012 L .62975 .668 L F
.729 .825 .924 r
.50453 .86956 m .50607 .87069 L .50767 .86952 L F
.50767 .86952 m .50607 .87069 L .50453 .86956 L F
.50453 .86956 m .50607 .87069 L .50767 .86952 L F
.602 .619 .841 r
.36972 .81502 m .37091 .81672 L .3725 .81577 L F
.3725 .81577 m .37091 .81672 L .36972 .81502 L F
.884 .642 .568 r
.67805 .58558 m .67506 .58374 L .67735 .58331 L F
.67805 .58558 m .67504 .58605 L .67506 .58374 L F
.561 .037 0 r
.67805 .58558 m .67704 .5869 L .67504 .58605 L F
.892 .905 .828 r
.67833 .58414 m .67805 .58558 L .67735 .58331 L F
.541 .394 .631 r
.36376 .75989 m .36588 .75953 L .36557 .7567 L F
.549 .422 .66 r
.36401 .7622 m .36588 .75953 L .36376 .75989 L F
.978 .731 .319 r
.68501 .62932 m .68553 .6277 L .68488 .62681 L F
.428 .741 .992 r
.42143 .7542 m .42382 .75419 L .42221 .75313 L F
.42143 .7542 m .42382 .75419 L .42221 .75313 L F
.709 .603 .736 r
.51409 .74322 m .51503 .74616 L .51219 .74641 L F
.02 .158 .668 r
.51567 .7451 m .51503 .74616 L .51409 .74322 L F
.718 .316 .284 r
.51384 .74785 m .51503 .74616 L .51567 .7451 L F
.51384 .74785 m .517 .74797 L .51503 .74616 L F
.709 .603 .736 r
.51409 .74322 m .51219 .74641 L .51172 .74354 L F
.614 .951 .794 r
.65264 .60423 m .64994 .60618 L .65113 .60488 L F
.592 .905 .983 r
.65113 .60488 m .64994 .60618 L .64897 .6057 L F
.573 .39 .595 r
.35883 .77574 m .36094 .77782 L .36099 .77542 L F
.35883 .77574 m .35879 .77813 L .36094 .77782 L F
.682 .917 .59 r
.70821 .6178 m .70671 .61964 L .70737 .61849 L F
.212 .422 .849 r
.70671 .61964 m .70856 .62073 L .70737 .61849 L F
.709 .323 .316 r
.50449 .77527 m .50671 .77721 L .50795 .77562 L F
.692 .195 0 r
.50874 .77702 m .50795 .77562 L .50671 .77721 L F
.50874 .77702 m .50983 .77799 L .50795 .77562 L F
0 0 0 r
.64641 .59004 m .64788 .58936 L .64843 .58865 L F
.64641 .59004 m .64507 .59088 L .64788 .58936 L F
.481 .241 .473 r
.37107 .69698 m .36938 .6953 L .37146 .69486 L F
.37107 .69698 m .36896 .69744 L .36938 .6953 L F
.673 .444 .566 r
.61362 .68137 m .61372 .68379 L .61013 .6839 L F
.669 .441 .567 r
.61563 .68143 m .61372 .68379 L .61362 .68137 L F
.417 0 .086 r
.33334 .7104 m .33236 .71101 L .33538 .71031 L F
.458 .31 .592 r
.69866 .69785 m .70064 .69859 L .70089 .69746 L F
.69866 .69785 m .69807 .70061 L .70064 .69859 L F
.563 .032 0 r
.28591 .61097 m .2862 .6111 L .28943 .6114 L F
.027 .594 .783 r
.2862 .6111 m .28788 .61119 L .28943 .6114 L F
0 .196 .712 r
.2898 .61116 m .28943 .6114 L .28788 .61119 L F
.2898 .61116 m .29162 .6133 L .28943 .6114 L F
.44 .398 .715 r
.28943 .6114 m .29162 .6133 L .29016 .6139 L F
.476 .188 .396 r
.61397 .62674 m .61649 .62379 L .61446 .62452 L F
.042 0 0 r
.34036 .72395 m .33855 .7248 L .33889 .72419 L F
.715 .986 .881 r
.31522 .71702 m .31474 .71615 L .31707 .7163 L F
.31522 .71702 m .31327 .71747 L .31474 .71615 L F
.838 .661 .662 r
.64442 .63555 m .64124 .63731 L .64168 .6351 L F
.64442 .63555 m .64338 .63848 L .64124 .63731 L F
.809 .691 .734 r
.36233 .80829 m .366 .80816 L .36458 .80748 L F
.36233 .80829 m .3634 .81329 L .366 .80816 L F
.878 .87 .826 r
.36458 .80748 m .366 .80816 L .36797 .80535 L F
.58 .422 .631 r
.35672 .78093 m .35879 .77813 L .35661 .77846 L F
.749 .719 .824 r
.69338 .70473 m .69635 .70505 L .69607 .70326 L F
.775 .632 .702 r
.69338 .70473 m .69433 .70822 L .69635 .70505 L F
.391 .801 .98 r
.46499 .72558 m .46703 .7253 L .46852 .72588 L F
.483 .845 .992 r
.46852 .72588 m .46915 .72483 L .47065 .7255 L F
.46852 .72588 m .46703 .7253 L .46915 .72483 L F
.73 .233 0 r
.71469 .74014 m .71183 .73687 L .71224 .73833 L F
.001 0 0 r
.31622 .73733 m .31276 .73854 L .31411 .73803 L F
.605 .467 .668 r
.36401 .7622 m .36204 .76493 L .36428 .76461 L F
.576 .423 .636 r
.36222 .76739 m .36428 .76461 L .36204 .76493 L F
.802 .601 .63 r
.69767 .71974 m .70001 .71929 L .6967 .71895 L F
.69767 .71974 m .69968 .72141 L .70001 .71929 L F
.327 0 0 r
.71942 .74156 m .71813 .7418 L .7157 .74133 L F
.613 .432 .613 r
.72027 .73993 m .71813 .7418 L .71942 .74156 L F
.954 .808 .661 r
.72374 .61769 m .72332 .62013 L .72156 .62001 L F
.72374 .61769 m .72156 .62001 L .72378 .6179 L F
.558 .538 .789 r
.37481 .66162 m .37393 .66525 L .37292 .66194 L F
.37481 .66162 m .37594 .66489 L .37393 .66525 L F
.377 0 .007 r
.63587 .61799 m .63438 .61912 L .63254 .61927 L F
.472 .05 .156 r
.34778 .67285 m .346 .67487 L .34381 .67493 L F
0 0 0 r
.34762 .6737 m .34778 .67285 L .34954 .67294 L F
.34762 .6737 m .346 .67487 L .34778 .67285 L F
.655 .714 .892 r
.49103 .88015 m .49388 .8814 L .49251 .87961 L F
0 0 0 r
.48828 .88058 m .49091 .88036 L .48726 .87768 L F
.655 .714 .892 r
.49034 .88041 m .4908 .88053 L .49103 .88015 L F
.4908 .88053 m .49388 .8814 L .49103 .88015 L F
0 0 0 r
.49091 .88036 m .49094 .88035 L .49092 .88034 L F
.49091 .88036 m .49092 .88034 L .48726 .87768 L F
.48828 .88058 m .49034 .88041 L .49094 .88035 L F
.359 0 .128 r
.3023 .66241 m .3043 .66209 L .30555 .66034 L F
.336 0 .127 r
.3043 .66209 m .30755 .65981 L .30555 .66034 L F
.468 .307 .579 r
.35461 .69221 m .35644 .69174 L .35647 .68939 L F
.433 .215 .48 r
.35461 .69221 m .35426 .69446 L .35644 .69174 L F
.622 .586 .792 r
.65562 .62371 m .65678 .62495 L .65678 .62206 L F
.717 .486 .575 r
.65337 .62709 m .65678 .62495 L .65562 .62371 L F
.65337 .62709 m .65692 .62733 L .65678 .62495 L F
.516 .333 .572 r
.65678 .62495 m .65692 .62733 L .65889 .62427 L F
.703 .278 .235 r
.7332 .73241 m .73005 .73208 L .73152 .7342 L F
.564 .329 .517 r
.35647 .68939 m .3587 .68909 L .3589 .68695 L F
.557 .409 .635 r
.3589 .68695 m .36123 .68662 L .36091 .68398 L F
.463 .243 .495 r
.3589 .68695 m .36063 .68859 L .36123 .68662 L F
.3589 .68695 m .3587 .68909 L .36063 .68859 L F
.448 0 0 r
.72398 .71563 m .72628 .71635 L .72329 .71604 L F
.303 .068 .383 r
.36838 .69919 m .36724 .69795 L .36896 .69744 L F
.36838 .69919 m .36677 .70003 L .36724 .69795 L F
.605 .666 .882 r
.69165 .58346 m .69023 .5856 L .68939 .58398 L F
.69165 .58346 m .69283 .58497 L .69023 .5856 L F
.181 0 0 r
.43026 .78542 m .42726 .78605 L .42812 .78569 L F
0 0 0 r
.32449 .73369 m .32434 .73304 L .32606 .73215 L F
.32449 .73369 m .32268 .73458 L .32434 .73304 L F
.831 .614 .609 r
.65422 .60075 m .65102 .60243 L .6509 .60026 L F
.65422 .60075 m .65416 .60295 L .65102 .60243 L F
.587 .879 .993 r
.69418 .61678 m .69105 .61685 L .69318 .61593 L F
.799 .899 .913 r
.69162 .61851 m .69318 .61593 L .69105 .61685 L F
.69162 .61851 m .69418 .61678 L .69318 .61593 L F
.437 0 0 r
.42791 .77723 m .43021 .77728 L .43176 .77602 L F
.371 0 .007 r
.43021 .77728 m .43383 .7756 L .43176 .77602 L F
0 0 .313 r
.62502 .63221 m .62534 .63494 L .62488 .63286 L F
.314 0 0 r
.46252 .77576 m .46122 .77704 L .45909 .77718 L F
.507 .012 .014 r
.46447 .77616 m .46122 .77704 L .46252 .77576 L F
.114 .503 .906 r
.68873 .5888 m .68962 .58837 L .68692 .58751 L F
.68873 .5888 m .69052 .58946 L .68962 .58837 L F
0 0 0 r
.63027 .60612 m .62819 .60891 L .62939 .60777 L F
.212 .027 .399 r
.62764 .61077 m .62939 .60777 L .62819 .60891 L F
.712 .691 .828 r
.69815 .58455 m .69614 .58671 L .69497 .58395 L F
.674 .977 .855 r
.33411 .65035 m .33466 .64914 L .33605 .64993 L F
.637 .114 0 r
.70794 .70972 m .7086 .70881 L .71103 .71031 L F
.604 .134 .11 r
.33969 .67541 m .33867 .67611 L .33656 .6754 L F
.201 0 0 r
.3418 .67518 m .33867 .67611 L .33969 .67541 L F
.859 .823 .812 r
.33775 .84653 m .33658 .84516 L .33636 .8455 L F
.33775 .84653 m .33839 .84569 L .33658 .84516 L F
.734 .369 .36 r
.49776 .77316 m .50116 .77496 L .50096 .77312 L F
.72 .353 .353 r
.49683 .77812 m .49544 .78015 L .4934 .77792 L F
.728 .362 .358 r
.49683 .77812 m .49885 .78043 L .49544 .78015 L F
.562 .904 .976 r
.6899 .64219 m .6911 .64271 L .69369 .64169 L F
.195 .72 .855 r
.38249 .67046 m .38483 .67024 L .38617 .67045 L F
.502 .816 1 r
.38689 .66901 m .38855 .67006 L .38617 .67045 L F
.649 .958 .933 r
.38617 .67045 m .38483 .67024 L .38689 .66901 L F
.577 .481 .709 r
.38879 .67224 m .38617 .67045 L .38855 .67006 L F
.38879 .67224 m .3868 .67292 L .38617 .67045 L F
.72 .654 .783 r
.5222 .74052 m .51949 .74066 L .52152 .73881 L F
.517 .226 .411 r
.5222 .74052 m .51938 .74305 L .51949 .74066 L F
.5222 .74052 m .52159 .74281 L .51938 .74305 L F
.6 .559 .78 r
.52351 .7378 m .5222 .74052 L .52152 .73881 L F
.52351 .7378 m .5248 .73946 L .5222 .74052 L F
0 0 .083 r
.52316 .74046 m .5222 .74052 L .5248 .73946 L F
.52316 .74046 m .52159 .74281 L .5222 .74052 L F
.097 0 0 r
.33125 .72906 m .32949 .73097 L .32786 .73147 L F
.086 0 0 r
.33415 .72748 m .33262 .72915 L .33125 .72906 L F
.085 0 0 r
.33262 .72915 m .32949 .73097 L .33125 .72906 L F
.641 .502 .678 r
.52523 .7564 m .52286 .75718 L .52225 .75465 L F
.785 .73 .802 r
.70517 .58741 m .70383 .58452 L .70385 .5865 L F
.70517 .58741 m .70593 .58362 L .70383 .58452 L F
.70517 .58741 m .70761 .5853 L .70593 .58362 L F
.933 .78 .669 r
.70385 .5865 m .70476 .58968 L .70517 .58741 L F
.865 .512 .38 r
.71195 .70497 m .71289 .70308 L .71144 .70274 L F
.71195 .70497 m .71336 .70481 L .71289 .70308 L F
.908 .976 .794 r
.63112 .65137 m .63305 .64862 L .63385 .64893 L F
.959 .758 .588 r
.6315 .64338 m .63286 .64369 L .63225 .64571 L F
.539 .561 .825 r
.6315 .64338 m .6345 .64626 L .63225 .64571 L F
.869 .912 .857 r
.63407 .64767 m .63613 .64639 L .63385 .64893 L F
.539 .561 .825 r
.6345 .64626 m .63458 .64635 L .63442 .64652 L F
.63458 .64635 m .6345 .64655 L .63442 .64652 L F
.6345 .64626 m .63442 .64652 L .63225 .64571 L F
.391 .61 .937 r
.63225 .64571 m .6345 .64655 L .63436 .64603 L F
.539 .561 .825 r
.6315 .64338 m .63485 .64546 L .63458 .64635 L F
.869 .912 .857 r
.63436 .64603 m .63466 .64609 L .6345 .64655 L F
.63466 .64609 m .63468 .64609 L .63458 .64635 L F
.63466 .64609 m .63458 .64635 L .6345 .64655 L F
.539 .561 .825 r
.6315 .64338 m .6347 .64398 L .63485 .64546 L F
.869 .912 .857 r
.63468 .64609 m .63613 .64639 L .63407 .64767 L F
.539 .561 .825 r
.63458 .64635 m .63485 .64546 L .63498 .64673 L F
.63458 .64635 m .63498 .64673 L .6345 .64655 L F
.391 .61 .937 r
.6345 .64655 m .63498 .64673 L .63436 .64603 L F
.869 .912 .857 r
.63436 .64603 m .6345 .64655 L .63407 .64767 L F
.63436 .64603 m .63407 .64767 L .63305 .64862 L F
.63407 .64767 m .63385 .64893 L .63371 .64887 L F
.63407 .64767 m .63371 .64887 L .63305 .64862 L F
.688 .553 .696 r
.66343 .63253 m .66556 .63012 L .66348 .63026 L F
.66343 .63253 m .66686 .63295 L .66556 .63012 L F
.206 0 .079 r
.51409 .74322 m .51827 .74022 L .51688 .7436 L F
.656 .58 .757 r
.51833 .73738 m .51949 .74066 L .51827 .74022 L F
.728 .524 .615 r
.51949 .74066 m .51688 .7436 L .51827 .74022 L F
.478 .29 .547 r
.34496 .70249 m .34735 .69969 L .34506 .70025 L F
.257 .742 .926 r
.37014 .805 m .37364 .80524 L .37204 .80482 L F
.007 .357 .831 r
.37364 .80524 m .37411 .80446 L .37204 .80482 L F
.37364 .80524 m .37532 .80629 L .37411 .80446 L F
.563 .141 .199 r
.70322 .69816 m .70533 .69925 L .70633 .69759 L F
.867 .511 .375 r
.70633 .69759 m .70533 .69925 L .70671 .6993 L F
.56 .409 .633 r
.3603 .77011 m .36254 .7698 L .36222 .76739 L F
.581 .447 .663 r
.3603 .77011 m .3628 .77266 L .36254 .7698 L F
.3603 .77011 m .3607 .77309 L .3628 .77266 L F
.654 .673 .855 r
.50416 .74863 m .50498 .74516 L .50306 .74628 L F
.50416 .74863 m .50661 .74824 L .50498 .74516 L F
.69 .718 .871 r
.70593 .58362 m .70761 .5853 L .70923 .58417 L F
.189 .693 .908 r
.31707 .7163 m .31912 .71631 L .32059 .71675 L F
.522 .872 .988 r
.32059 .71675 m .3211 .71571 L .32259 .71635 L F
.32059 .71675 m .31912 .71631 L .3211 .71571 L F
.616 .594 .805 r
.51092 .75243 m .51158 .74828 L .50943 .74865 L F
.51092 .75243 m .51292 .75139 L .51158 .74828 L F
.611 .635 .85 r
.37684 .8212 m .37817 .82499 L .37498 .82404 L F
0 0 0 r
.37684 .8212 m .37498 .82404 L .37573 .82312 L F
.464 .811 .998 r
.37361 .82342 m .37498 .82404 L .37573 .82312 L F
.341 .642 .965 r
.37498 .82404 m .37751 .82461 L .37573 .82312 L F
.464 .811 .998 r
.37361 .82342 m .37498 .82404 L .37573 .82312 L F
.168 .613 .937 r
.37751 .82461 m .37817 .82499 L .37498 .82404 L F
.554 .93 .91 r
.37847 .80303 m .38195 .80169 L .38056 .8016 L F
.321 .807 .868 r
.38056 .8016 m .38195 .80169 L .38266 .80142 L F
.664 .775 .932 r
.47846 .7351 m .48181 .73553 L .48053 .73434 L F
.667 .776 .931 r
.48053 .73434 m .48181 .73553 L .484 .73482 L F
.895 .749 .693 r
.6067 .65649 m .60968 .65424 L .60846 .65318 L F
.6067 .65649 m .6083 .65743 L .60968 .65424 L F
.966 .686 .265 r
.67416 .63105 m .67328 .63019 L .67337 .62756 L F
.708 .25 0 r
.67416 .63105 m .67358 .63057 L .67328 .63019 L F
.67416 .63105 m .67481 .63212 L .67358 .63057 L F
.928 .668 .524 r
.65482 .63225 m .6563 .63225 L .65577 .631 L F
.834 .582 .558 r
.65469 .63454 m .6563 .63225 L .65482 .63225 L F
.65469 .63454 m .65843 .63507 L .6563 .63225 L F
.321 0 .213 r
.52592 .77477 m .52865 .77273 L .52641 .77296 L F
.845 .965 .881 r
.63581 .6239 m .63911 .62205 L .63698 .62469 L F
.595 .448 .652 r
.63911 .62205 m .63982 .62425 L .63698 .62469 L F
.722 .618 .742 r
.63982 .62425 m .63682 .62682 L .63698 .62469 L F
.632 .6 .799 r
.50602 .73247 m .50371 .73299 L .50273 .72993 L F
0 0 0 r
.34952 .69708 m .35076 .69648 L .35231 .69495 L F
.852 .978 .865 r
.35231 .69495 m .35246 .69291 L .35426 .69446 L F
.35231 .69495 m .35169 .69416 L .35246 .69291 L F
.395 0 .104 r
.35325 .69597 m .35231 .69495 L .35169 .69416 L F
.35325 .69597 m .35076 .69648 L .35231 .69495 L F
.341 .039 .299 r
.36677 .70003 m .36418 .70234 L .36489 .70065 L F
.236 .333 .76 r
.68173 .60516 m .68059 .60632 L .67962 .60318 L F
.409 .613 .933 r
.68173 .60516 m .68275 .60686 L .68059 .60632 L F
.569 .3 .468 r
.61454 .66496 m .61687 .66475 L .61751 .66244 L F
.646 .338 .435 r
.61942 .66431 m .61751 .66244 L .61687 .66475 L F
.61942 .66431 m .61986 .66255 L .61751 .66244 L F
.432 0 0 r
.62767 .63423 m .62772 .63563 L .62597 .63512 L F
.62783 .63414 m .62781 .63444 L .62767 .63423 L F
.62781 .63444 m .62772 .63563 L .62767 .63423 L F
.62783 .63414 m .62597 .63512 L .62646 .63458 L F
.591 .227 .319 r
.62783 .63414 m .62938 .63683 L .62772 .63563 L F
.494 .594 .883 r
.62772 .63563 m .62938 .63683 L .6272 .63358 L F
.599 .17 0 r
.62862 .6357 m .62872 .63586 L .6272 .63358 L F
.62938 .63683 m .62886 .63607 L .62862 .6357 L F
.62886 .63607 m .62872 .63586 L .62862 .6357 L F
.432 0 0 r
.62646 .63458 m .62597 .63512 L .62534 .63494 L F
0 0 .211 r
.62603 .6343 m .62534 .63494 L .62772 .63563 L F
.62603 .6343 m .62454 .63612 L .62534 .63494 L F
.62603 .6343 m .62457 .6373 L .62454 .63612 L F
.845 .933 .555 r
.62505 .63528 m .62476 .63648 L .62603 .6343 L F
.62476 .63648 m .62457 .6373 L .62521 .63597 L F
.62476 .63648 m .62521 .63597 L .62603 .6343 L F
.594 .343 .505 r
.63042 .63292 m .63048 .63482 L .62783 .63414 L F
.591 .227 .319 r
.62783 .63414 m .63048 .63482 L .62938 .63683 L F
.715 .626 .757 r
.66585 .62766 m .66348 .63026 L .66556 .63012 L F
.712 .688 .825 r
.51259 .73737 m .51061 .73833 L .50942 .73545 L F
.24 0 0 r
.70064 .69859 m .70322 .69816 L .70089 .69746 L F
.677 .482 .614 r
.59467 .68894 m .59124 .6892 L .59133 .68676 L F
.848 .96 .88 r
.65311 .62396 m .65562 .62371 L .65678 .62206 L F
.924 .844 .746 r
.65206 .62585 m .65562 .62371 L .65311 .62396 L F
.65206 .62585 m .65337 .62709 L .65562 .62371 L F
.414 .139 .385 r
.29801 .66523 m .29992 .66479 L .30051 .6629 L F
.404 .13 .38 r
.30051 .6629 m .30179 .66425 L .3023 .66241 L F
.30051 .6629 m .29992 .66479 L .30179 .66425 L F
.527 .276 .478 r
.37387 .74329 m .37607 .74296 L .37665 .74089 L F
.394 .152 .424 r
.37665 .74089 m .37785 .74245 L .37819 .74022 L F
.37665 .74089 m .37607 .74296 L .37785 .74245 L F
.985 .792 .564 r
.35888 .67858 m .35956 .68089 L .36022 .679 L F
.602 .78 .966 r
.36038 .67701 m .36022 .679 L .36179 .67815 L F
.829 .957 .897 r
.36038 .67701 m .35888 .67858 L .36022 .679 L F
.985 .792 .564 r
.35888 .67858 m .35956 .68089 L .36022 .679 L F
.658 .508 .669 r
.35956 .68089 m .36179 .67815 L .36022 .679 L F
.685 .239 .187 r
.70978 .62 m .70821 .6178 L .70737 .61849 L F
.70978 .62 m .71108 .61933 L .70821 .6178 L F
.70978 .62 m .71108 .61933 L .70821 .6178 L F
.084 0 0 r
.32554 .71562 m .3273 .71515 L .32859 .71436 L F
0 0 0 r
.32859 .71436 m .3273 .71515 L .33043 .71362 L F
.152 0 0 r
.45981 .7688 m .46207 .76844 L .46347 .76752 L F
.523 .104 .188 r
.46207 .76844 m .4655 .76687 L .46347 .76752 L F
.658 .801 .353 r
.71202 .71143 m .71061 .71416 L .71135 .71262 L F
.524 .331 .561 r
.71061 .71416 m .71221 .71575 L .71135 .71262 L F
.891 .497 .055 r
.7117 .71407 m .71108 .71311 L .71135 .71262 L F
.71108 .71311 m .71024 .71181 L .71135 .71262 L F
.658 .801 .353 r
.71217 .71113 m .71202 .71143 L .71135 .71262 L F
.974 .674 .386 r
.71103 .71031 m .71217 .71113 L .71135 .71262 L F
.71103 .71031 m .71217 .71113 L .71135 .71262 L F
.899 .856 .79 r
.71221 .71575 m .7133 .71671 L .71534 .71349 L F
.477 0 0 r
.71791 .71631 m .71475 .71505 L .7166 .71422 L F
.71791 .71631 m .71673 .71618 L .71475 .71505 L F
0 .334 .814 r
.71475 .71505 m .71673 .71618 L .71668 .71575 L F
.71475 .71505 m .71668 .71575 L .71636 .71569 L F
.899 .856 .79 r
.71221 .71575 m .71373 .71465 L .71475 .71505 L F
.771 .485 0 r
.71135 .71262 m .7117 .71388 L .7117 .71407 L F
.7117 .71388 m .71221 .71575 L .7117 .71407 L F
.62 .708 .909 r
.7117 .71407 m .71221 .71575 L .71435 .71516 L F
.7117 .71407 m .71435 .71516 L .71475 .71505 L F
.772 .29 .09 r
.71327 .71503 m .71169 .71452 L .7117 .71407 L F
.71169 .71452 m .71124 .71437 L .7117 .71407 L F
0 .334 .814 r
.71475 .71505 m .71636 .71569 L .71327 .71503 L F
.899 .856 .79 r
.71373 .71465 m .71534 .71349 L .71475 .71505 L F
.635 .189 .173 r
.7166 .71422 m .71534 .71349 L .71767 .71325 L F
.7166 .71422 m .71475 .71505 L .71534 .71349 L F
.453 .312 .599 r
.29162 .6133 m .28987 .61635 L .29016 .6139 L F
.837 .631 .624 r
.65469 .63454 m .65598 .63763 L .65843 .63507 L F
.969 .77 .58 r
.68023 .63246 m .68127 .63551 L .68128 .63306 L F
.798 .372 .235 r
.68357 .63546 m .68128 .63306 L .68127 .63551 L F
.648 .418 .556 r
.60248 .68407 m .60268 .68633 L .59931 .68647 L F
.701 .478 .582 r
.60455 .684 m .60268 .68633 L .60248 .68407 L F
.723 .417 .46 r
.6411 .63322 m .63812 .63484 L .63881 .63264 L F
.6411 .63322 m .64168 .6351 L .63812 .63484 L F
.627 .613 .817 r
.4998 .74516 m .50083 .74955 L .50306 .74628 L F
.39 .827 .952 r
.47382 .73381 m .47301 .73457 L .47514 .73426 L F
.47382 .73381 m .47167 .73423 L .47301 .73457 L F
.612 .357 .506 r
.63042 .63292 m .63272 .63486 L .63048 .63482 L F
.58 .365 .553 r
.63274 .63264 m .63272 .63486 L .63042 .63292 L F
0 0 0 r
.70398 .59857 m .70165 .60029 L .7043 .59923 L F
.783 .55 .583 r
.7043 .59923 m .70734 .59767 L .70398 .59857 L F
.613 .468 .66 r
.39095 .75611 m .39086 .75918 L .38856 .75931 L F
.687 .559 .704 r
.39086 .75918 m .38876 .76116 L .38856 .75931 L F
.648 .651 .839 r
.65971 .62816 m .66348 .63026 L .6625 .62741 L F
.77 .719 .805 r
.6625 .62741 m .66348 .63026 L .66585 .62766 L F
.928 .668 .524 r
.65482 .63225 m .65577 .631 L .65562 .63022 L F
.728 .792 .903 r
.65562 .63022 m .65577 .631 L .65804 .63034 L F
.669 .441 .567 r
.61563 .68143 m .6157 .68368 L .61372 .68379 L F
.634 .397 .541 r
.61813 .68145 m .6157 .68368 L .61563 .68143 L F
.653 .505 .67 r
.48726 .87768 m .48976 .87475 L .48703 .87532 L F
.48726 .87768 m .49094 .88035 L .48976 .87475 L F
.294 0 .128 r
.31268 .65627 m .31402 .6568 L .31529 .65466 L F
.233 0 0 r
.31402 .6568 m .31757 .65461 L .31529 .65466 L F
.376 .533 .885 r
.41823 .77799 m .41958 .77776 L .41775 .77798 L F
.148 .686 .696 r
.45748 .73565 m .4565 .73586 L .45845 .73576 L F
.45748 .73565 m .45503 .73616 L .4565 .73586 L F
.728 .524 .615 r
.51949 .74066 m .51938 .74305 L .51688 .7436 L F
.688 .597 .749 r
.52152 .73881 m .51949 .74066 L .51833 .73738 L F
.736 .692 .809 r
.36385 .80538 m .36797 .80535 L .36675 .80293 L F
.878 .87 .826 r
.36458 .80748 m .36797 .80535 L .36385 .80538 L F
.616 .621 .833 r
.36797 .80535 m .36886 .80223 L .36675 .80293 L F
.36797 .80535 m .37014 .805 L .36886 .80223 L F
0 0 .234 r
.53664 .77231 m .53422 .77044 L .53618 .7705 L F
.437 .083 .264 r
.53618 .7705 m .53422 .77044 L .5335 .77264 L F
.874 .439 .047 r
.67337 .62756 m .67215 .62749 L .67066 .6242 L F
.962 .688 .254 r
.67337 .62756 m .67256 .62837 L .67215 .62749 L F
.67337 .62756 m .67328 .63019 L .67256 .62837 L F
.783 .678 .749 r
.65692 .62733 m .65562 .63022 L .65804 .63034 L F
.712 .643 .779 r
.65692 .62733 m .65804 .63034 L .65971 .62816 L F
.693 .628 .779 r
.51292 .75139 m .51418 .75473 L .51627 .75372 L F
.541 .104 .158 r
.46802 .77564 m .4667 .77725 L .46447 .77616 L F
.313 0 0 r
.47026 .77581 m .4667 .77725 L .46802 .77564 L F
.158 0 .288 r
.63274 .63264 m .63491 .62873 L .63488 .63206 L F
.639 .556 .744 r
.63682 .62682 m .63491 .62873 L .63426 .62813 L F
.68 .32 .358 r
.63491 .62873 m .63711 .63161 L .63488 .63206 L F
.408 .421 .762 r
.35448 .78356 m .35538 .78656 L .35656 .78506 L F
.501 .554 .842 r
.35538 .78656 m .35724 .78631 L .35656 .78506 L F
.609 .505 .71 r
.35538 .78656 m .35808 .78873 L .35724 .78631 L F
.35538 .78656 m .35586 .78916 L .35808 .78873 L F
.012 0 .164 r
.38056 .8016 m .378 .80492 L .37847 .80303 L F
.693 .888 .969 r
.48172 .72457 m .47926 .72585 L .47834 .72498 L F
.809 .989 .88 r
.63613 .64639 m .63644 .64493 L .6388 .64407 L F
.67 .634 .805 r
.63605 .64199 m .63521 .64572 L .6347 .64398 L F
.73 .935 .955 r
.63464 .64609 m .63638 .64522 L .63613 .64639 L F
.63445 .64605 m .63521 .64572 L .63464 .64609 L F
.63521 .64572 m .63638 .64522 L .63464 .64609 L F
.63436 .64603 m .63644 .64493 L .63638 .64522 L F
.67 .634 .805 r
.63521 .64572 m .63644 .64493 L .63498 .64673 L F
.63605 .64199 m .63644 .64493 L .63521 .64572 L F
.63521 .64572 m .63498 .64673 L .63489 .64586 L F
.63521 .64572 m .63489 .64586 L .6347 .64398 L F
.73 .935 .955 r
.63436 .64603 m .63638 .64522 L .63445 .64605 L F
.476 .045 .141 r
.41952 .72577 m .42173 .72578 L .42313 .72399 L F
.501 .084 .18 r
.42173 .72578 m .42529 .724 L .42313 .72399 L F
.461 .293 .565 r
.38843 .67454 m .3868 .67292 L .38879 .67224 L F
.38843 .67454 m .38642 .676 L .3868 .67292 L F
0 0 .181 r
.63027 .60612 m .63156 .6053 L .63214 .60316 L F
.341 .119 .424 r
.62939 .60777 m .63156 .6053 L .63027 .60612 L F
.814 .636 .662 r
.52221 .84039 m .52039 .84036 L .52067 .83754 L F
.811 .6 .618 r
.52049 .84103 m .52039 .84036 L .52221 .84039 L F
.814 .636 .662 r
.52067 .83754 m .52039 .84036 L .52221 .84039 L F
.811 .6 .618 r
.52221 .84039 m .52039 .84036 L .52049 .84103 L F
.814 .636 .662 r
.52221 .84039 m .52039 .84036 L .52067 .83754 L F
.907 .615 .119 r
.64451 .61074 m .64467 .61194 L .64548 .61378 L F
.127 .622 .909 r
.44724 .72431 m .45071 .72524 L .44859 .72506 L F
.524 .305 .523 r
.69172 .59256 m .6894 .59564 L .69166 .5949 L F
.449 .501 .82 r
.69052 .58946 m .69172 .59256 L .6935 .59198 L F
.602 .479 .685 r
.69166 .5949 m .6935 .59198 L .69172 .59256 L F
.637 .658 .854 r
.51627 .75372 m .51981 .75488 L .51839 .75252 L F
.681 .469 .592 r
.51839 .75252 m .52174 .75382 L .51954 .75261 L F
.64 .533 .717 r
.51839 .75252 m .51981 .75488 L .52174 .75382 L F
.528 .546 .818 r
.49401 .74062 m .4949 .73741 L .4927 .73779 L F
.49401 .74062 m .49604 .74035 L .4949 .73741 L F
.567 .418 .639 r
.36557 .7567 m .3676 .75703 L .36766 .75381 L F
.564 .411 .632 r
.36557 .7567 m .36788 .75909 L .3676 .75703 L F
.36557 .7567 m .36588 .75953 L .36788 .75909 L F
.645 .106 0 r
.73005 .73208 m .72729 .7313 L .72793 .73238 L F
.203 .117 .529 r
.67217 .59438 m .67218 .59217 L .67231 .59248 L F
.501 .612 .894 r
.6738 .59194 m .67231 .59248 L .67131 .59018 L F
.348 .825 .85 r
.40361 .7935 m .40283 .7935 L .40177 .79405 L F
0 0 0 r
.40283 .7935 m .40111 .79449 L .40177 .79405 L F
.712 .623 .756 r
.48917 .87351 m .48703 .87532 L .48976 .87475 L F
.545 .762 .978 r
.69864 .64205 m .69559 .64111 L .69678 .64208 L F
.421 .187 .451 r
.38043 .68334 m .37984 .68636 L .37771 .68615 L F
.41 .128 .371 r
.37984 .68636 m .37749 .68844 L .37771 .68615 L F
.313 0 .145 r
.29761 .66587 m .29992 .66479 L .29801 .66523 L F
.306 .581 .938 r
.7157 .74133 m .71722 .74052 L .71469 .74014 L F
.7157 .74133 m .71813 .7418 L .71722 .74052 L F
.847 .741 .747 r
.69925 .57843 m .70018 .58146 L .6973 .58137 L F
.833 .551 .511 r
.6973 .58137 m .70018 .58146 L .70044 .58384 L F
.778 .706 .784 r
.70254 .57874 m .70018 .58146 L .69925 .57843 L F
.783 .55 .583 r
.7043 .59923 m .70619 .60022 L .70734 .59767 L F
.633 .264 .327 r
.71044 .59951 m .70918 .59781 L .70734 .59767 L F
.02 .158 .668 r
.51567 .7451 m .51409 .74322 L .51688 .7436 L F
.137 0 0 r
.31454 .68142 m .31161 .68182 L .31255 .68187 L F
.033 0 0 r
.31543 .68095 m .31454 .68142 L .31255 .68187 L F
.31618 .68071 m .31454 .68142 L .31543 .68095 L F
.137 0 0 r
.31454 .68142 m .31488 .68141 L .31445 .68146 L F
.31454 .68142 m .31445 .68146 L .31161 .68182 L F
.579 .256 .386 r
.31488 .68141 m .31046 .68491 L .31161 .68182 L F
.298 .739 .964 r
.47065 .7255 m .47273 .72538 L .47411 .726 L F
.348 .789 .962 r
.47273 .72538 m .476 .72559 L .47411 .726 L F
.532 .495 .761 r
.50889 .73455 m .50676 .73607 L .50602 .73247 L F
.585 .579 .813 r
.50942 .73545 m .50676 .73607 L .50889 .73455 L F
.473 .06 .176 r
.3991 .73 m .40061 .73105 L .4012 .72963 L F
.3991 .73 m .39772 .73169 L .40061 .73105 L F
.704 .529 .649 r
.58333 .67814 m .58125 .68095 L .58149 .67864 L F
.58333 .67814 m .58509 .68118 L .58125 .68095 L F
.712 .532 .644 r
.58685 .67861 m .58509 .68118 L .58333 .67814 L F
.963 .78 .608 r
.38901 .66431 m .38819 .66709 L .39051 .6651 L F
.867 .714 .69 r
.49467 .8774 m .49765 .87504 L .49502 .875 L F
.49467 .8774 m .49597 .87802 L .49765 .87504 L F
.723 .576 .689 r
.35549 .79144 m .35808 .78873 L .35586 .78916 L F
.74 .662 .773 r
.71767 .71325 m .71871 .71637 L .7166 .71422 L F
.857 .402 .055 r
.71871 .71637 m .71791 .71631 L .7166 .71422 L F
.299 .794 .85 r
.72003 .71582 m .71871 .71637 L .72096 .71612 L F
.72003 .71582 m .71791 .71631 L .71871 .71637 L F
.572 .784 .979 r
.69829 .62462 m .6979 .62525 L .69746 .6257 L F
.69928 .62332 m .6979 .62525 L .69829 .62462 L F
.885 .974 .833 r
.69871 .62482 m .69773 .62553 L .6979 .62525 L F
.69773 .62553 m .69607 .62672 L .6979 .62525 L F
.126 .334 .8 r
.7002 .62478 m .69871 .62482 L .6979 .62525 L F
.395 0 0 r
.42529 .724 m .42742 .72423 L .4288 .72361 L F
.48 0 0 r
.4288 .72361 m .42742 .72423 L .4308 .72404 L F
.528 .476 .742 r
.48976 .87475 m .49148 .87396 L .48917 .87351 L F
.48976 .87475 m .49171 .87439 L .49148 .87396 L F
.564 .447 .678 r
.48976 .87475 m .49252 .87858 L .49171 .87439 L F
.48976 .87475 m .49094 .88035 L .49252 .87858 L F
.4 0 .03 r
.40627 .74894 m .4045 .75057 L .40236 .75065 L F
.454 .093 .26 r
.40764 .74815 m .4045 .75057 L .40627 .74894 L F
.741 .572 .665 r
.58693 .68099 m .58509 .68118 L .58685 .67861 L F
.572 .709 .935 r
.34366 .65022 m .34281 .65214 L .34168 .65041 L F
.34366 .65022 m .34486 .65173 L .34281 .65214 L F
.633 .676 .873 r
.70163 .58026 m .7024 .58487 L .70542 .58253 L F
.649 .757 .928 r
.70383 .58452 m .70542 .58253 L .7024 .58487 L F
.27 0 0 r
.43935 .77306 m .44003 .77419 L .44148 .7727 L F
.43935 .77306 m .43794 .77462 L .44003 .77419 L F
.365 .834 .874 r
.43228 .74045 m .4305 .74063 L .42929 .74098 L F
.434 0 0 r
.4343 .74054 m .4305 .74063 L .43228 .74045 L F
.06 0 0 r
.43824 .78311 m .43397 .7847 L .43616 .78323 L F
.815 .345 .099 r
.50983 .77799 m .51332 .78083 L .51103 .77822 L F
.789 .579 .617 r
.69556 .70243 m .69844 .70281 L .69807 .70061 L F
.446 .319 .613 r
.69844 .70281 m .70064 .69859 L .69807 .70061 L F
.555 .887 .987 r
.4094 .78037 m .40744 .78107 L .40817 .77997 L F
.528 .856 .996 r
.40817 .77997 m .40744 .78107 L .40609 .78051 L F
.089 .208 .694 r
.34558 .80721 m .34522 .8082 L .34657 .80743 L F
.536 .387 .626 r
.34522 .8082 m .34795 .81017 L .34657 .80743 L F
.34522 .8082 m .3459 .81031 L .34795 .81017 L F
.037 .586 .835 r
.44935 .72457 m .4516 .72484 L .45291 .72523 L F
.232 0 0 r
.4516 .72484 m .45258 .72515 L .45291 .72523 L F
.45258 .72515 m .45488 .72587 L .45291 .72523 L F
.063 .625 .785 r
.45338 .72535 m .45291 .72523 L .45384 .72537 L F
.45071 .72524 m .45291 .72523 L .45338 .72535 L F
.454 0 0 r
.45291 .72523 m .45614 .72571 L .45384 .72537 L F
.502 .253 .469 r
.61986 .66255 m .62222 .66211 L .62271 .66006 L F
.134 0 .314 r
.62271 .66006 m .62222 .66211 L .624 .65908 L F
.377 .838 .777 r
.40865 .79209 m .40979 .7918 L .41162 .79101 L F
.701 .478 .582 r
.60455 .684 m .6049 .68656 L .60268 .68633 L F
.632 .43 .59 r
.60905 .68615 m .60455 .684 L .60821 .68372 L F
.60905 .68615 m .6049 .68656 L .60455 .684 L F
.349 .053 .314 r
.30997 .65808 m .31145 .65847 L .31268 .65627 L F
.482 .175 .369 r
.31145 .65847 m .31402 .6568 L .31268 .65627 L F
.205 0 0 r
.38909 .79863 m .39149 .79765 L .39054 .79848 L F
.139 0 0 r
.39054 .79848 m .39149 .79765 L .39333 .79705 L F
.745 .316 .233 r
.71336 .70481 m .71552 .70696 L .71638 .70549 L F
.646 .201 .179 r
.71638 .70549 m .71552 .70696 L .71889 .70708 L F
.547 .532 .79 r
.37791 .66458 m .37715 .66861 L .37594 .66489 L F
.37791 .66458 m .37936 .66868 L .37715 .66861 L F
.484 .171 .359 r
.34014 .70808 m .34234 .70783 L .34311 .7054 L F
.352 .049 .305 r
.34311 .7054 m .34422 .70708 L .34476 .70459 L F
.34311 .7054 m .34234 .70783 L .34422 .70708 L F
.338 .819 .83 r
.38966 .7982 m .38909 .79863 L .39054 .79848 L F
.38966 .7982 m .38747 .79885 L .38909 .79863 L F
.044 0 0 r
.3344 .72837 m .33415 .72748 L .33576 .72653 L F
.3344 .72837 m .33262 .72915 L .33415 .72748 L F
.781 .579 .626 r
.34032 .79878 m .34355 .79954 L .34431 .79726 L F
.553 .337 .541 r
.34355 .79954 m .34567 .79931 L .34431 .79726 L F
.122 0 0 r
.46184 .73593 m .46049 .73596 L .45845 .73576 L F
.037 .601 .79 r
.46405 .73628 m .46049 .73596 L .46184 .73593 L F
.775 .362 .267 r
.50877 .78387 m .50771 .78533 L .50574 .78304 L F
.767 .352 .262 r
.50877 .78387 m .51055 .78593 L .50771 .78533 L F
.787 .299 .055 r
.51218 .78642 m .51055 .78593 L .50877 .78387 L F
.549 .422 .66 r
.36401 .7622 m .36605 .76184 L .36588 .75953 L F
.563 .444 .675 r
.36428 .76461 m .36605 .76184 L .36401 .7622 L F
.441 .283 .57 r
.28987 .61635 m .28962 .61913 L .28794 .61941 L F
.431 .261 .548 r
.28962 .61913 m .28784 .62171 L .28794 .61941 L F
.649 .757 .928 r
.70383 .58452 m .70593 .58362 L .70542 .58253 L F
.687 .234 .17 r
.49225 .7722 m .49467 .7741 L .49551 .77263 L F
.722 .274 .188 r
.49467 .7741 m .49783 .77478 L .49551 .77263 L F
.672 .319 .367 r
.49551 .77263 m .49783 .77478 L .49776 .77316 L F
.358 .537 .895 r
.33527 .80917 m .33747 .8105 L .33702 .80793 L F
.722 .541 .644 r
.58929 .69146 m .58603 .68901 L .58931 .68946 L F
.654 .425 .56 r
.59124 .6892 m .58929 .69146 L .58931 .68946 L F
.837 .604 .586 r
.73063 .72017 m .72813 .72118 L .72987 .71857 L F
.73063 .72017 m .731 .72185 L .72813 .72118 L F
.495 .563 .854 r
.37908 .8235 m .37817 .82499 L .37684 .8212 L F
.696 .831 .947 r
.37751 .82461 m .37817 .82499 L .37908 .8235 L F
.407 .815 .979 r
.67025 .59457 m .67217 .59438 L .66903 .59403 L F
.356 0 0 r
.47348 .77498 m .47241 .77572 L .47026 .77581 L F
.476 .034 .118 r
.47573 .77488 m .47241 .77572 L .47348 .77498 L F
.524 .331 .561 r
.71061 .71416 m .71004 .71651 L .71221 .71575 L F
.728 .295 .222 r
.70092 .59026 m .70433 .59149 L .70156 .58905 L F
.70351 .59129 m .70433 .59149 L .70092 .59026 L F
.671 .598 .765 r
.69843 .5906 m .69865 .59123 L .70289 .58999 L F
.728 .295 .222 r
.70074 .59061 m .70351 .59129 L .70092 .59026 L F
.444 0 .086 r
.70092 .59026 m .70123 .58968 L .70289 .58999 L F
.70146 .58924 m .70156 .58905 L .70289 .58999 L F
.671 .598 .765 r
.69715 .587 m .69788 .58905 L .70289 .58999 L F
.69788 .58905 m .69843 .5906 L .70092 .59026 L F
.69788 .58905 m .70092 .59026 L .70289 .58999 L F
.444 0 .086 r
.70074 .59061 m .70092 .59026 L .70289 .58999 L F
.70074 .59061 m .7009 .59057 L .69865 .59123 L F
.7009 .59057 m .70289 .58999 L .70145 .59041 L F
.7009 .59057 m .70145 .59041 L .69865 .59123 L F
.73 .289 .203 r
.70402 .58969 m .70433 .59149 L .70526 .59001 L F
.70156 .58905 m .7027 .59006 L .70402 .58969 L F
.7027 .59006 m .70433 .59149 L .70402 .58969 L F
.508 .296 .527 r
.37162 .74593 m .37365 .74555 L .37387 .74329 L F
.527 .312 .531 r
.37387 .74329 m .37575 .74517 L .37607 .74296 L F
.37387 .74329 m .37365 .74555 L .37575 .74517 L F
.643 .288 .355 r
.32327 .67869 m .32214 .68091 L .31974 .68037 L F
.242 0 .146 r
.32416 .68007 m .32327 .67869 L .32543 .67883 L F
.32416 .68007 m .32214 .68091 L .32327 .67869 L F
.609 .837 .987 r
.7043 .59923 m .70165 .60029 L .70322 .59857 L F
0 0 .014 r
.70302 .6014 m .70322 .59857 L .70165 .60029 L F
.571 .823 .451 r
.66113 .62141 m .65889 .62427 L .6612 .62411 L F
.794 .747 .809 r
.66009 .61864 m .66113 .62141 L .66326 .61895 L F
.667 .542 .703 r
.66113 .62141 m .66456 .62186 L .66326 .61895 L F
.679 .474 .601 r
.6612 .62411 m .66456 .62186 L .66113 .62141 L F
.794 .472 .444 r
.64747 .61195 m .65037 .61435 L .64943 .61346 L F
.597 .028 0 r
.64683 .61245 m .64747 .61195 L .64943 .61346 L F
.509 .483 .763 r
.3543 .67858 m .35692 .68011 L .35515 .67507 L F
.697 .326 .342 r
.3543 .67858 m .35613 .68057 L .35692 .68011 L F
.323 .299 .678 r
.35479 .68065 m .35613 .68057 L .3543 .67858 L F
.582 .541 .775 r
.36091 .68398 m .35956 .68089 L .35963 .68318 L F
.36091 .68398 m .3622 .68081 L .35956 .68089 L F
.36091 .68398 m .36305 .68362 L .3622 .68081 L F
.425 .313 .623 r
.36091 .68398 m .3628 .68587 L .36305 .68362 L F
.36091 .68398 m .36123 .68662 L .3628 .68587 L F
.168 0 .05 r
.61942 .66431 m .62222 .66211 L .61986 .66255 L F
.703 .647 .791 r
.357 .80783 m .36004 .80827 L .35871 .80617 L F
.537 .627 .889 r
.36004 .80827 m .36119 .80568 L .35871 .80617 L F
.36004 .80827 m .36233 .80829 L .36119 .80568 L F
.571 .455 .683 r
.36004 .80827 m .36033 .81049 L .36233 .80829 L F
.423 .01 .148 r
.34567 .79931 m .34788 .79918 L .3493 .79723 L F
0 0 .126 r
.3493 .79723 m .35116 .79322 L .34889 .79607 L F
.3493 .79723 m .35025 .79651 L .35116 .79322 L F
0 0 0 r
.3493 .79723 m .34788 .79918 L .35025 .79651 L F
.798 .507 .497 r
.70866 .70225 m .70974 .69999 L .70671 .6993 L F
.805 .516 .5 r
.70866 .70225 m .71144 .70274 L .70974 .69999 L F
.637 .551 .741 r
.34821 .79202 m .35116 .79322 L .35082 .79178 L F
.317 0 .242 r
.35116 .79322 m .35345 .79136 L .35082 .79178 L F
0 0 0 r
.44019 .78249 m .4438 .78089 L .44228 .78217 L F
.3 0 0 r
.4438 .78089 m .44444 .78187 L .44228 .78217 L F
.4438 .78089 m .44599 .78077 L .44444 .78187 L F
.824 .984 .705 r
.60009 .63998 m .59916 .6414 L .59969 .63984 L F
.894 .978 .688 r
.59916 .6414 m .59767 .64263 L .59969 .63984 L F
.59916 .6414 m .59798 .64311 L .59767 .64263 L F
.91 .591 .43 r
.51218 .78642 m .51099 .78809 L .51055 .78593 L F
.745 .353 .309 r
.51218 .78642 m .51405 .78858 L .51099 .78809 L F
.782 .292 .048 r
.51561 .78898 m .51405 .78858 L .51218 .78642 L F
.652 .651 .836 r
.70505 .57792 m .7056 .57959 L .70254 .57874 L F
.518 .568 .845 r
.70719 .57771 m .7056 .57959 L .70505 .57792 L F
.31 .424 .816 r
.70719 .57897 m .7056 .57959 L .70719 .57771 L F
.70719 .57897 m .70734 .5802 L .7056 .57959 L F
.587 .928 .956 r
.64476 .62495 m .64709 .62395 L .64768 .62441 L F
.271 0 .081 r
.33538 .71031 m .33689 .71044 L .33823 .7085 L F
.23 0 .057 r
.33823 .7085 m .33874 .70989 L .34014 .70808 L F
.33823 .7085 m .33689 .71044 L .33874 .70989 L F
.622 .617 .825 r
.4863 .73426 m .48741 .73729 L .48972 .73663 L F
.625 .633 .838 r
.48741 .73729 m .4906 .73833 L .48972 .73663 L F
.576 .423 .636 r
.36222 .76739 m .36447 .76722 L .36428 .76461 L F
.497 .365 .63 r
.36222 .76739 m .36432 .76937 L .36447 .76722 L F
.36222 .76739 m .36254 .7698 L .36432 .76937 L F
.694 .743 .889 r
.48718 .72477 m .48493 .72628 L .4838 .72421 L F
.927 .797 .329 r
.66745 .60004 m .66778 .5979 L .66754 .59651 L F
0 0 0 r
.41588 .79026 m .4177 .78973 L .41975 .78916 L F
.664 .634 .811 r
.4904 .72673 m .48841 .72766 L .48718 .72477 L F
.245 0 0 r
.46745 .73512 m .46598 .73611 L .46405 .73628 L F
.125 0 0 r
.4682 .73564 m .46745 .73512 L .4696 .73488 L F
.4682 .73564 m .46598 .73611 L .46745 .73512 L F
.811 .968 .904 r
.34985 .8093 m .34958 .811 L .35085 .80951 L F
.663 .852 .972 r
.34795 .81017 m .34958 .811 L .34985 .8093 L F
.372 .784 .98 r
.34876 .65115 m .34826 .65191 L .34685 .65124 L F
.34876 .65115 m .35019 .65169 L .34826 .65191 L F
.638 .771 .943 r
.67743 .63507 m .68127 .63551 L .68023 .63246 L F
.551 .353 .565 r
.68127 .63551 m .68154 .63751 L .68357 .63546 L F
.73 .598 .709 r
.66649 .6217 m .66789 .62496 L .67091 .62177 L F
.967 .787 .354 r
.67091 .62177 m .67022 .62356 L .6706 .6208 L F
.67091 .62177 m .67066 .6242 L .67022 .62356 L F
.764 .738 .829 r
.70254 .57874 m .69925 .57843 L .70147 .57613 L F
.655 .673 .855 r
.70358 .57525 m .70254 .57874 L .70147 .57613 L F
.70358 .57525 m .70505 .57792 L .70254 .57874 L F
.486 .231 .452 r
.36221 .70285 m .36172 .70499 L .35971 .70539 L F
.443 .185 .426 r
.36418 .70234 m .36172 .70499 L .36221 .70285 L F
.507 .358 .613 r
.37181 .74837 m .37365 .74555 L .37162 .74593 L F
.8 .82 .867 r
.70251 .64104 m .7033 .6377 L .70156 .64039 L F
.70251 .64104 m .70476 .63932 L .7033 .6377 L F
.696 .517 .642 r
.60983 .66759 m .6123 .66761 L .61209 .66515 L F
.576 .384 .585 r
.6123 .66761 m .61454 .66496 L .61209 .66515 L F
.376 .141 .425 r
.52872 .78278 m .53007 .78088 L .53074 .78159 L F
.452 .247 .51 r
.53007 .78088 m .53263 .77764 L .53226 .78056 L F
0 .111 .658 r
.53183 .78231 m .53007 .78088 L .53226 .78056 L F
.53183 .78231 m .53074 .78159 L .53007 .78088 L F
.913 .979 .771 r
.72659 .72708 m .72792 .72368 L .72751 .72712 L F
.72659 .72708 m .72597 .7266 L .72792 .72368 L F
.88 .679 .627 r
.72671 .72864 m .72597 .7266 L .72659 .72708 L F
.648 .19 .151 r
.471 .76763 m .47321 .76916 L .47446 .76792 L F
.376 0 0 r
.47321 .76916 m .47688 .76817 L .47446 .76792 L F
.426 .273 .569 r
.35647 .68939 m .35644 .69174 L .35814 .69116 L F
.548 .281 .463 r
.35647 .68939 m .35814 .69116 L .3587 .68909 L F
.426 .273 .569 r
.35647 .68939 m .35644 .69174 L .35814 .69116 L F
.383 .169 .461 r
.39264 .75402 m .39256 .75604 L .39095 .75611 L F
.62 .554 .759 r
.39256 .75604 m .39086 .75918 L .39095 .75611 L F
.634 .592 .79 r
.39383 .77268 m .39167 .77311 L .39053 .77012 L F
.621 .514 .711 r
.39383 .77268 m .392 .77519 L .39167 .77311 L F
.378 .042 .264 r
.34973 .71784 m .34856 .71677 L .35044 .71617 L F
.34973 .71784 m .34775 .71836 L .34856 .71677 L F
.637 .551 .741 r
.34821 .79202 m .34889 .79607 L .35116 .79322 L F
.406 .091 .315 r
.63778 .59667 m .63907 .59535 L .63635 .59745 L F
0 0 0 r
.63778 .59667 m .64072 .59425 L .63907 .59535 L F
.712 .688 .825 r
.51259 .73737 m .50942 .73545 L .51156 .73497 L F
.78 .784 .856 r
.51489 .73508 m .51259 .73737 L .51156 .73497 L F
.956 .801 .357 r
.63911 .61903 m .63875 .62117 L .63911 .62205 L F
.845 .965 .881 r
.63581 .6239 m .63875 .62117 L .63911 .62205 L F
.959 .947 .674 r
.64002 .61801 m .63875 .62117 L .63911 .62205 L F
0 .144 .678 r
.63875 .62117 m .63982 .62425 L .63911 .62205 L F
.456 .284 .557 r
.37822 .73786 m .38003 .73967 L .38048 .7377 L F
.37822 .73786 m .37819 .74022 L .38003 .73967 L F
.866 .935 .866 r
.64028 .64249 m .6388 .64407 L .63786 .64327 L F
.901 .931 .825 r
.6388 .64407 m .63644 .64493 L .63786 .64327 L F
.473 .318 .589 r
.63214 .60316 m .63409 .60234 L .63387 .6001 L F
.452 .193 .43 r
.63156 .6053 m .63409 .60234 L .63214 .60316 L F
.554 .341 .545 r
.40032 .75079 m .39758 .75358 L .398 .75126 L F
.591 .474 .688 r
.3941 .77465 m .392 .77519 L .39383 .77268 L F
0 0 0 r
.3161 .68085 m .31454 .68142 L .31618 .68071 L F
.667 .442 .57 r
.59931 .68647 m .59701 .68885 L .59698 .68671 L F
.493 .116 .253 r
.40336 .72942 m .40558 .72933 L .40672 .72726 L F
.498 .12 .255 r
.40672 .72726 m .40558 .72933 L .40856 .72825 L F
.508 .1 .202 r
.40672 .72726 m .40856 .72825 L .40893 .72728 L F
.748 .911 .948 r
.71345 .62574 m .70979 .62682 L .71238 .62521 L F
.658 .947 .704 r
.71462 .62432 m .71345 .62574 L .71238 .62521 L F
.71462 .62432 m .71508 .62425 L .71345 .62574 L F
.641 .285 .353 r
.38806 .73271 m .38989 .73431 L .39117 .73234 L F
.643 .287 .353 r
.39117 .73234 m .38989 .73431 L .393 .73415 L F
.621 .292 .393 r
.39117 .73234 m .393 .73415 L .39361 .73241 L F
.19 .694 .908 r
.70654 .62686 m .70756 .62725 L .7034 .62663 L F
.451 .839 .984 r
.70902 .62631 m .70756 .62725 L .70654 .62686 L F
.70902 .62631 m .70979 .62682 L .70756 .62725 L F
.774 .39 .326 r
.70867 .73332 m .70471 .73213 L .70793 .73233 L F
.70867 .73332 m .7053 .73372 L .70471 .73213 L F
.239 0 0 r
.70867 .73332 m .70941 .73381 L .7053 .73372 L F
0 0 .481 r
.70935 .73337 m .70867 .73332 L .71054 .73381 L F
.70935 .73337 m .70941 .73381 L .70867 .73332 L F
.606 .2 .247 r
.3024 .6861 m .30304 .68645 L .30211 .68645 L F
.175 .687 .895 r
.43089 .72405 m .43288 .72406 L .43421 .72442 L F
.049 .616 .758 r
.43288 .72406 m .43501 .72404 L .43632 .7241 L F
.296 0 0 r
.43144 .72459 m .43484 .72407 L .43288 .72406 L F
.43484 .72407 m .43501 .72404 L .43288 .72406 L F
.175 .687 .895 r
.4308 .72404 m .43288 .72406 L .43089 .72405 L F
.049 .616 .758 r
.43288 .72406 m .43632 .7241 L .43421 .72442 L F
.495 .253 .476 r
.38188 .68602 m .38043 .68334 L .38239 .68265 L F
.38188 .68602 m .37984 .68636 L .38043 .68334 L F
.619 .905 .985 r
.64375 .65676 m .64474 .65545 L .64338 .65673 L F
.64375 .65676 m .64473 .65612 L .64474 .65545 L F
.5 .294 .532 r
.38479 .67823 m .38525 .6807 L .38243 .68113 L F
.506 .368 .627 r
.38642 .676 m .38691 .67831 L .38479 .67823 L F
.598 .359 .524 r
.38681 .68021 m .38479 .67823 L .38691 .67831 L F
.38681 .68021 m .38525 .6807 L .38479 .67823 L F
.615 .865 .99 r
.33751 .81178 m .33977 .81054 L .33747 .8105 L F
.33751 .81178 m .34088 .81095 L .33977 .81054 L F
.528 .356 .592 r
.69243 .71186 m .69433 .70822 L .69122 .70784 L F
.69243 .71186 m .69437 .71117 L .69433 .70822 L F
.091 .019 .473 r
.69433 .70822 m .69437 .71117 L .69554 .71036 L F
.372 0 0 r
.43775 .74047 m .43881 .74113 L .43624 .74049 L F
.43775 .74047 m .43964 .74147 L .43881 .74113 L F
.816 .912 .904 r
.71188 .63516 m .71063 .6335 L .71104 .63453 L F
.71188 .63516 m .71462 .63293 L .71063 .6335 L F
.881 .597 .502 r
.42499 .77292 m .42471 .77518 L .42408 .77269 L F
.42499 .77292 m .42471 .77518 L .42408 .77269 L F
.409 .168 .434 r
.42699 .77235 m .42471 .77518 L .42499 .77292 L F
.42699 .77235 m .42471 .77518 L .42499 .77292 L F
.468 .267 .523 r
.38377 .68128 m .38243 .68113 L .38525 .6807 L F
.38377 .68128 m .38239 .68265 L .38243 .68113 L F
.58 .503 .732 r
.48917 .87351 m .48999 .86897 L .48814 .87007 L F
.48917 .87351 m .49148 .87396 L .48999 .86897 L F
.634 .397 .541 r
.61813 .68145 m .61836 .68366 L .6157 .68368 L F
.467 .203 .429 r
.62087 .68097 m .61836 .68366 L .61813 .68145 L F
.761 .67 .762 r
.73237 .74061 m .72896 .74067 L .73123 .73747 L F
.508 0 0 r
.73237 .74061 m .73028 .7412 L .72896 .74067 L F
.214 .336 .773 r
.73309 .73907 m .73237 .74061 L .73123 .73747 L F
.766 .984 .906 r
.73309 .73907 m .73028 .7412 L .73237 .74061 L F
.527 .6 .87 r
.37331 .65893 m .37292 .66194 L .3713 .65932 L F
.37331 .65893 m .37481 .66162 L .37292 .66194 L F
0 0 .24 r
.38694 .80653 m .38585 .8107 L .38792 .80886 L F
.599 .575 .799 r
.35535 .6845 m .35613 .68057 L .35479 .68065 L F
.35535 .6845 m .35751 .68406 L .35613 .68057 L F
0 0 0 r
.71746 .62188 m .71508 .62425 L .7163 .6231 L F
.543 .91 .731 r
.7163 .6231 m .71508 .62425 L .71462 .62432 L F
.526 .035 .034 r
.44512 .77114 m .44908 .77042 L .44701 .77045 L F
.801 .619 .656 r
.58693 .68099 m .58847 .68419 L .58516 .6836 L F
.838 .636 .63 r
.58764 .68635 m .58516 .6836 L .58847 .68419 L F
.71 .585 .713 r
.59062 .68147 m .58847 .68419 L .58693 .68099 L F
.679 .641 .805 r
.71068 .73352 m .70793 .73233 L .71054 .73381 L F
.399 0 0 r
.71054 .73381 m .71356 .73445 L .71068 .73352 L F
.986 .737 .471 r
.64464 .6086 m .64451 .61074 L .64343 .60761 L F
.64464 .6086 m .64451 .61074 L .64343 .60761 L F
.703 .278 .235 r
.7332 .73241 m .73245 .73403 L .73005 .73208 L F
.984 .901 .642 r
.73357 .72863 m .73251 .73169 L .7332 .73241 L F
.992 .77 .394 r
.73251 .73169 m .73245 .73403 L .7332 .73241 L F
.282 .722 .964 r
.33801 .64968 m .34168 .65041 L .33957 .65064 L F
.182 0 .23 r
.35448 .78356 m .35603 .78311 L .35672 .78093 L F
.58 .422 .631 r
.35672 .78093 m .3589 .78067 L .35879 .77813 L F
.643 .325 .418 r
.35672 .78093 m .35864 .78287 L .3589 .78067 L F
.35672 .78093 m .35603 .78311 L .35864 .78287 L F
.76 .332 .234 r
.51561 .78898 m .51461 .79039 L .51405 .78858 L F
.51561 .78898 m .51774 .79126 L .51461 .79039 L F
.693 .628 .779 r
.51292 .75139 m .51627 .75372 L .51502 .7507 L F
.722 .628 .753 r
.51502 .7507 m .51627 .75372 L .51839 .75116 L F
.627 .903 .6 r
.60557 .63315 m .60662 .63195 L .60769 .63089 L F
.028 0 .171 r
.60471 .63466 m .60662 .63195 L .60557 .63315 L F
.168 0 0 r
.4655 .76687 m .46775 .76692 L .46925 .76675 L F
.674 .179 .064 r
.46775 .76692 m .471 .76763 L .46925 .76675 L F
.22 .741 .837 r
.32876 .67856 m .32741 .67853 L .32543 .67883 L F
.225 0 0 r
.32899 .67894 m .32876 .67856 L .33073 .67718 L F
.32899 .67894 m .32741 .67853 L .32876 .67856 L F
.538 .064 .077 r
.354 .80856 m .357 .80783 L .3559 .80734 L F
.395 .182 .468 r
.357 .80783 m .35792 .80553 L .3559 .80734 L F
.357 .80783 m .35871 .80617 L .35792 .80553 L F
.942 .748 .278 r
.67247 .60584 m .67196 .60746 L .67197 .60489 L F
.67247 .60584 m .67238 .60815 L .67196 .60746 L F
.123 0 0 r
.32304 .65191 m .32347 .65285 L .32493 .65075 L F
.32304 .65191 m .3216 .65352 L .32347 .65285 L F
.945 .683 .508 r
.69604 .71835 m .69767 .71974 L .6967 .71895 L F
.914 .903 .8 r
.69688 .72361 m .69787 .72434 L .69968 .72141 L F
.512 0 0 r
.69924 .72555 m .69787 .72434 L .69791 .72682 L F
0 .319 .794 r
.69787 .72434 m .70127 .72658 L .70123 .727 L F
.512 0 0 r
.69924 .72555 m .70127 .72658 L .69787 .72434 L F
.73 .69 .813 r
.49251 .87961 m .49388 .8814 L .49585 .87991 L F
.77 .719 .805 r
.6625 .62741 m .66585 .62766 L .66418 .62637 L F
.793 .715 .778 r
.66418 .62637 m .66585 .62766 L .66789 .62496 L F
.353 .771 .978 r
.3291 .64802 m .33277 .64845 L .33065 .64864 L F
.094 0 0 r
.47688 .76817 m .47911 .76772 L .47998 .76715 L F
.46 0 0 r
.47911 .76772 m .48175 .7678 L .47998 .76715 L F
.22 0 .108 r
.521 .78883 m .52369 .7868 L .52275 .78834 L F
.281 0 .144 r
.52275 .78834 m .52369 .7868 L .52568 .78613 L F
.599 .833 .988 r
.31004 .7172 m .30944 .71863 L .30803 .71735 L F
.31004 .7172 m .31137 .71792 L .30944 .71863 L F
.611 .553 .765 r
.49384 .72961 m .4916 .73024 L .4904 .72673 L F
.627 .634 .838 r
.48972 .73663 m .4906 .73833 L .4927 .73779 L F
0 0 .084 r
.53479 .77529 m .53664 .77231 L .53692 .77458 L F
.355 .183 .505 r
.53476 .77715 m .53479 .77529 L .53692 .77458 L F
.8 .697 .751 r
.39006 .80512 m .38694 .80653 L .38926 .80695 L F
.668 .338 .405 r
.38926 .80695 m .39204 .80716 L .39006 .80512 L F
.665 .403 .515 r
.61027 .68593 m .60821 .68372 L .61013 .6839 L F
.61027 .68593 m .60905 .68615 L .60821 .68372 L F
.653 .969 .888 r
.66936 .59071 m .66805 .59149 L .66799 .59088 L F
.66805 .59149 m .66695 .59214 L .66799 .59088 L F
.715 .465 0 r
.66799 .59088 m .66818 .59204 L .66791 .59004 L F
.743 .99 .882 r
.66799 .59088 m .66788 .58981 L .67016 .58911 L F
.715 .465 0 r
.66799 .59088 m .66791 .59004 L .66788 .58981 L F
.653 .969 .888 r
.66695 .59214 m .66636 .59249 L .66673 .59212 L F
.66695 .59214 m .66673 .59212 L .66799 .59088 L F
.367 .417 .782 r
.66636 .59249 m .66903 .59403 L .66799 .59088 L F
0 .315 .758 r
.66525 .5916 m .66903 .59403 L .66636 .59249 L F
.66869 .59382 m .66851 .59344 L .66903 .59403 L F
.66525 .5916 m .66851 .59344 L .66869 .59382 L F
.846 .816 .332 r
.668 .59448 m .66851 .59344 L .66515 .592 L F
0 0 0 r
.66851 .59344 m .66834 .59439 L .66824 .59288 L F
.66851 .59344 m .66824 .59288 L .66818 .59204 L F
.508 0 0 r
.66515 .592 m .66851 .59344 L .66606 .59206 L F
.66516 .59197 m .66606 .59206 L .66525 .5916 L F
.66515 .592 m .66606 .59206 L .66516 .59197 L F
.667 .842 .967 r
.70476 .63932 m .70564 .63728 L .7033 .6377 L F
.70476 .63932 m .70692 .63842 L .70564 .63728 L F
.906 .896 .807 r
.58357 .66253 m .58179 .66524 L .58069 .66442 L F
.958 .905 .725 r
.58058 .6673 m .58069 .66442 L .58179 .66524 L F
.722 .618 .742 r
.63982 .62425 m .64073 .62776 L .63682 .62682 L F
.744 .541 .62 r
.63682 .62682 m .64073 .62776 L .63934 .62942 L F
.196 .504 .909 r
.63982 .62425 m .6424 .62612 L .64073 .62776 L F
.467 .139 .326 r
.34952 .69708 m .35086 .69872 L .35076 .69648 L F
.34952 .69708 m .34871 .69912 L .35086 .69872 L F
.394 .728 .99 r
.35448 .78356 m .35603 .78311 L .35511 .78255 L F
.35448 .78356 m .35603 .78311 L .35511 .78255 L F
.408 .421 .762 r
.35448 .78356 m .35656 .78506 L .35603 .78311 L F
.866 .935 .866 r
.64028 .64249 m .63786 .64327 L .63991 .64036 L F
.805 .835 .874 r
.63991 .64036 m .64246 .64036 L .64028 .64249 L F
.277 0 0 r
.32259 .71635 m .32476 .71618 L .32554 .71562 L F
0 0 0 r
.32554 .71562 m .32671 .71551 L .3273 .71515 L F
.32554 .71562 m .32476 .71618 L .32671 .71551 L F
.906 .896 .807 r
.58357 .66253 m .58069 .66442 L .58264 .66191 L F
.878 .942 .854 r
.58357 .66253 m .58494 .65933 L .58566 .65978 L F
.58357 .66253 m .58264 .66191 L .58494 .65933 L F
.688 .597 .749 r
.52152 .73881 m .51833 .73738 L .52056 .737 L F
.664 .666 .842 r
.52056 .737 m .52351 .7378 L .52152 .73881 L F
.902 .98 .796 r
.60227 .63733 m .60157 .63692 L .60333 .63615 L F
.657 .967 .803 r
.60333 .63615 m .60426 .63496 L .60471 .63466 L F
.60333 .63615 m .60157 .63692 L .60426 .63496 L F
.18 .231 .679 r
.30884 .68537 m .30786 .68652 L .30727 .68478 L F
.509 .577 .859 r
.28713 .60916 m .28591 .61097 L .28455 .60836 L F
.28713 .60916 m .2862 .6111 L .28591 .61097 L F
.518 .274 .485 r
.53476 .77715 m .53226 .78056 L .53263 .77764 L F
.866 .768 .752 r
.72489 .73427 m .72595 .73659 L .72328 .73659 L F
.914 .555 .34 r
.72595 .73659 m .72492 .73788 L .72328 .73659 L F
.72595 .73659 m .72672 .73927 L .72492 .73788 L F
.507 .599 .88 r
.72587 .73361 m .72595 .73659 L .72489 .73427 L F
.72587 .73361 m .72814 .73663 L .72595 .73659 L F
.562 .281 .448 r
.33094 .67568 m .33282 .67728 L .33073 .67718 L F
.592 .271 .395 r
.3331 .67581 m .33282 .67728 L .33094 .67568 L F
.715 .319 .296 r
.50116 .77496 m .5033 .77695 L .50449 .77527 L F
.714 .318 .296 r
.50449 .77527 m .5033 .77695 L .50671 .77721 L F
.569 .461 .691 r
.3607 .77309 m .36307 .77506 L .3628 .77266 L F
.3607 .77309 m .36099 .77542 L .36307 .77506 L F
.767 .721 .81 r
.50498 .74516 m .50661 .74824 L .50873 .74532 L F
.68 .592 .751 r
.50661 .74824 m .50943 .74865 L .50873 .74532 L F
.339 .029 .285 r
.52568 .78613 m .52872 .78278 L .52745 .78535 L F
.29 0 .259 r
.52872 .78278 m .5293 .78462 L .52745 .78535 L F
.52872 .78278 m .53074 .78159 L .5293 .78462 L F
.541 .046 .03 r
.4845 .77562 m .48341 .77678 L .48114 .77575 L F
.674 .202 .122 r
.4845 .77562 m .48671 .77729 L .48341 .77678 L F
.438 .253 .532 r
.37764 .69079 m .37551 .68926 L .37749 .68844 L F
.37764 .69079 m .37541 .69154 L .37551 .68926 L F
.801 .619 .656 r
.58693 .68099 m .58516 .6836 L .58509 .68118 L F
.519 .379 .63 r
.36766 .75381 m .36983 .75584 L .36961 .75343 L F
.36766 .75381 m .3676 .75703 L .36983 .75584 L F
.599 .544 .765 r
.52057 .73543 m .51833 .73738 L .51717 .73436 L F
.52057 .73543 m .52056 .737 L .51833 .73738 L F
.905 .975 .801 r
.58566 .65978 m .587 .65649 L .58783 .65706 L F
.58566 .65978 m .58494 .65933 L .587 .65649 L F
.342 .425 .802 r
.68154 .63751 m .68264 .64037 L .68429 .63947 L F
.359 .465 .832 r
.68264 .64037 m .68463 .6413 L .68429 .63947 L F
.498 .028 .07 r
.41361 .77958 m .41587 .77982 L .41823 .77799 L F
.257 0 0 r
.41587 .77982 m .41958 .77776 L .41823 .77799 L F
.349 .254 .604 r
.6387 .6162 m .6401 .61736 L .64002 .61801 L F
.351 0 .033 r
.63426 .62813 m .6315 .62961 L .63248 .6288 L F
.739 .918 .953 r
.63444 .627 m .63682 .62682 L .63426 .62813 L F
.089 0 0 r
.43632 .7241 m .43847 .72422 L .4397 .72421 L F
.235 .743 .884 r
.43847 .72422 m .44182 .7242 L .4397 .72421 L F
.413 0 .037 r
.45556 .77893 m .45363 .77854 L .45695 .77741 L F
.377 0 .03 r
.45909 .77718 m .45556 .77893 L .45695 .77741 L F
.081 0 0 r
.64843 .58865 m .65002 .58863 L .65114 .58728 L F
.07 0 0 r
.64843 .58865 m .64788 .58936 L .65002 .58863 L F
.271 0 0 r
.39679 .79573 m .3955 .79674 L .39333 .79705 L F
0 0 0 r
.3973 .79599 m .39679 .79573 L .39795 .79539 L F
.916 .741 .649 r
.398 .79498 m .39672 .79651 L .3973 .79599 L F
.124 0 0 r
.3973 .79599 m .39368 .79722 L .3955 .79674 L F
.3973 .79599 m .39664 .79661 L .39368 .79722 L F
.916 .741 .649 r
.39672 .79651 m .39664 .79661 L .3973 .79599 L F
0 0 0 r
.3973 .79599 m .39795 .79539 L .39897 .7951 L F
.3973 .79599 m .3955 .79674 L .39679 .79573 L F
.684 .265 .244 r
.70123 .727 m .70053 .72874 L .69791 .72682 L F
.751 .819 .35 r
.70123 .727 m .70127 .72658 L .70163 .72556 L F
.725 .779 .288 r
.70163 .72556 m .70053 .72874 L .70123 .727 L F
.643 .765 .937 r
.69399 .59436 m .69513 .5958 L .69736 .59506 L F
.376 0 .033 r
.45149 .77836 m .45014 .7799 L .44798 .78007 L F
.318 0 0 r
.45363 .77854 m .45014 .7799 L .45149 .77836 L F
.369 0 0 r
.65742 .58559 m .66065 .58627 L .65774 .58526 L F
.812 .691 .731 r
.66267 .61586 m .66009 .61864 L .66326 .61895 L F
.644 .581 .769 r
.66267 .61586 m .66326 .61895 L .66604 .61673 L F
.671 .633 .803 r
.66326 .61895 m .6668 .61943 L .66604 .61673 L F
.718 .59 .713 r
.66456 .62186 m .6668 .61943 L .66326 .61895 L F
.941 .96 .672 r
.7146 .63113 m .71615 .62981 L .71575 .62926 L F
.7146 .63113 m .71462 .63293 L .71615 .62981 L F
0 0 .08 r
.71615 .62981 m .71785 .62699 L .71575 .62926 L F
.71615 .62981 m .71835 .62633 L .71785 .62699 L F
.806 .63 .663 r
.66477 .6245 m .66789 .62496 L .66649 .6217 L F
.793 .715 .778 r
.66418 .62637 m .66789 .62496 L .66477 .6245 L F
.793 .758 .821 r
.65102 .60243 m .65264 .60423 L .65113 .60488 L F
.65102 .60243 m .65416 .60295 L .65264 .60423 L F
.933 .924 .778 r
.5919 .65133 m .58916 .65373 L .59119 .65129 L F
.5919 .65133 m .59008 .65441 L .58916 .65373 L F
.905 .983 .727 r
.5919 .65133 m .59321 .64805 L .59406 .64863 L F
.5919 .65133 m .59119 .65129 L .59321 .64805 L F
.703 .659 .804 r
.50699 .72669 m .50818 .72967 L .50493 .72911 L F
.729 .595 .706 r
.50818 .72967 m .50602 .73247 L .50493 .72911 L F
.663 .5 .655 r
.50836 .73218 m .50602 .73247 L .50818 .72967 L F
.663 .638 .815 r
.51063 .72929 m .50818 .72967 L .50699 .72669 L F
.615 .447 .632 r
.51063 .72929 m .50836 .73218 L .50818 .72967 L F
.173 0 0 r
.47908 .77523 m .47771 .77516 L .47573 .77488 L F
.167 0 0 r
.48114 .77575 m .47771 .77516 L .47908 .77523 L F
.522 .82 .999 r
.35777 .65329 m .35711 .65451 L .35574 .65347 L F
.35777 .65329 m .35914 .65406 L .35711 .65451 L F
.968 .807 .629 r
.60593 .6646 m .60663 .66757 L .60698 .66529 L F
.507 .012 .014 r
.46447 .77616 m .46328 .77743 L .46122 .77704 L F
.542 .05 .037 r
.46447 .77616 m .4667 .77725 L .46328 .77743 L F
.323 0 0 r
.44908 .77042 m .45099 .77086 L .45255 .77039 L F
.131 0 0 r
.45099 .77086 m .45473 .77013 L .45255 .77039 L F
.557 .302 .485 r
.51332 .78083 m .51591 .78075 L .51574 .77839 L F
.335 .142 .463 r
.51574 .77839 m .51765 .77902 L .5183 .77789 L F
.51574 .77839 m .51591 .78075 L .51765 .77902 L F
.24 0 0 r
.70064 .69859 m .7023 .69887 L .70322 .69816 L F
.538 0 0 r
.7023 .69887 m .70533 .69925 L .70322 .69816 L F
.671 .402 .505 r
.39491 .75532 m .39256 .75604 L .39264 .75402 L F
.241 .755 .848 r
.65311 .58635 m .65529 .586 L .65605 .58614 L F
.16 0 0 r
.65441 .58753 m .65726 .5857 L .65529 .586 L F
.65726 .5857 m .65742 .58559 L .65529 .586 L F
.241 .755 .848 r
.65303 .58635 m .65529 .586 L .65311 .58635 L F
.749 .719 .824 r
.69338 .70473 m .69556 .70243 L .69311 .7029 L F
.896 .959 .829 r
.58783 .65706 m .58916 .65373 L .59008 .65441 L F
.58783 .65706 m .587 .65649 L .58916 .65373 L F
.538 .254 .432 r
.41568 .74337 m .41533 .74531 L .41314 .7456 L F
.536 .252 .431 r
.4176 .74496 m .41533 .74531 L .41568 .74337 L F
.589 .57 .8 r
.49604 .74035 m .49721 .74348 L .49934 .74298 L F
.472 .48 .785 r
.49721 .74348 m .4998 .74516 L .49934 .74298 L F
.207 .376 .812 r
.69457 .62846 m .69602 .62883 L .69607 .62672 L F
.271 0 .252 r
.62318 .67842 m .62286 .68055 L .62087 .68097 L F
.117 0 .234 r
.62527 .67554 m .62508 .67771 L .62318 .67842 L F
.031 0 .181 r
.62413 .67932 m .62318 .67842 L .62508 .67771 L F
.62413 .67932 m .62286 .68055 L .62318 .67842 L F
0 0 .356 r
.73308 .71783 m .73352 .7189 L .7321 .71583 L F
.001 0 .427 r
.73411 .71838 m .73352 .7189 L .73308 .71783 L F
.73411 .71838 m .73359 .72101 L .73352 .7189 L F
.384 .022 .221 r
.33227 .71291 m .33538 .71031 L .33236 .71101 L F
.921 .814 .724 r
.67779 .61043 m .67814 .61369 L .67841 .61075 L F
.676 .969 .923 r
.67984 .60923 m .67841 .61075 L .68076 .60974 L F
.734 .369 .36 r
.49776 .77316 m .49783 .77478 L .50116 .77496 L F
.76 .454 .469 r
.5751 .67639 m .57143 .67759 L .5733 .67466 L F
.5751 .67639 m .57476 .67797 L .57143 .67759 L F
.858 .761 .754 r
.57646 .67284 m .5751 .67639 L .5733 .67466 L F
.779 .474 .472 r
.57807 .67827 m .57476 .67797 L .5751 .67639 L F
.563 .444 .675 r
.36428 .76461 m .36638 .76426 L .36605 .76184 L F
.541 .396 .633 r
.36428 .76461 m .36646 .76682 L .36638 .76426 L F
.36428 .76461 m .36447 .76722 L .36646 .76682 L F
.667 .776 .931 r
.48053 .73434 m .484 .73482 L .48299 .73295 L F
.616 .733 .93 r
.48299 .73295 m .484 .73482 L .4863 .73426 L F
.559 .922 .946 r
.36242 .81298 m .36367 .81316 L .36434 .8122 L F
.36242 .81298 m .36367 .81316 L .36434 .8122 L F
.293 .013 .306 r
.63387 .6001 m .6361 .59962 L .63635 .59745 L F
0 0 .066 r
.6361 .59962 m .63778 .59667 L .63635 .59745 L F
.113 0 0 r
.42371 .78794 m .42526 .78662 L .42726 .78605 L F
.765 .613 .69 r
.49593 .7267 m .49726 .73006 L .49384 .72961 L F
.674 .624 .791 r
.49813 .72625 m .49726 .73006 L .49593 .7267 L F
.49813 .72625 m .49934 .72933 L .49726 .73006 L F
.289 .006 .298 r
.62154 .61925 m .62343 .61846 L .62393 .61673 L F
.288 .005 .298 r
.62343 .61846 m .62575 .61591 L .62393 .61673 L F
0 0 .145 r
.63087 .62422 m .63046 .62634 L .62974 .6271 L F
.553 .901 .678 r
.62974 .6271 m .63046 .62634 L .62873 .62773 L F
.749 .719 .824 r
.69338 .70473 m .69607 .70326 L .69556 .70243 L F
.712 .643 .779 r
.65692 .62733 m .65971 .62816 L .65907 .62647 L F
.633 .566 .761 r
.65907 .62647 m .65971 .62816 L .6625 .62741 L F
.726 .58 .69 r
.58125 .68095 m .57807 .67827 L .58149 .67864 L F
.122 0 .001 r
.60769 .63089 m .60865 .63145 L .60944 .62969 L F
.60769 .63089 m .60662 .63195 L .60865 .63145 L F
.407 .558 .892 r
.68609 .64259 m .68725 .64156 L .68463 .6413 L F
.68609 .64259 m .6883 .64329 L .68725 .64156 L F
.687 .559 .704 r
.39086 .75918 m .39366 .76222 L .38876 .76116 L F
.583 .456 .673 r
.392 .7653 m .38876 .76116 L .39366 .76222 L F
.392 .7653 m .3897 .76644 L .38876 .76116 L F
.517 .347 .59 r
.3698 .75123 m .3718 .7508 L .37181 .74837 L F
.529 .337 .565 r
.36961 .75343 m .3718 .7508 L .3698 .75123 L F
.871 .765 .743 r
.731 .72185 m .72792 .72368 L .72813 .72118 L F
.731 .72185 m .72954 .72466 L .72792 .72368 L F
.507 .293 .523 r
.35755 .70809 m .35734 .71044 L .35528 .71084 L F
.533 .342 .568 r
.35971 .70539 m .35961 .70772 L .35755 .70809 L F
.52 .304 .526 r
.35934 .70992 m .35755 .70809 L .35961 .70772 L F
.35934 .70992 m .35734 .71044 L .35755 .70809 L F
.634 .353 .474 r
.4104 .74634 m .41011 .74804 L .40764 .74815 L F
.496 .229 .439 r
.4124 .74757 m .4104 .74634 L .41314 .7456 L F
.4124 .74757 m .41011 .74804 L .4104 .74634 L F
.854 .959 .876 r
.59406 .64863 m .59567 .64556 L .59653 .64618 L F
.59406 .64863 m .59321 .64805 L .59567 .64556 L F
.713 .674 .811 r
.49282 .72517 m .49398 .72698 L .4904 .72673 L F
.611 .553 .765 r
.49384 .72961 m .4904 .72673 L .49398 .72698 L F
.701 .67 .817 r
.49593 .7267 m .49398 .72698 L .49282 .72517 L F
.679 .493 .628 r
.49593 .7267 m .49384 .72961 L .49398 .72698 L F
0 .105 .645 r
.48175 .7678 m .4836 .76945 L .48341 .76994 L F
0 .332 .771 r
.48483 .77021 m .48341 .76994 L .4836 .76945 L F
.48483 .77021 m .48589 .77124 L .48341 .76994 L F
.58 .41 .616 r
.49148 .87396 m .49283 .86958 L .48999 .86897 L F
.49148 .87396 m .49341 .8719 L .49283 .86958 L F
.612 .952 .915 r
.68097 .61677 m .68238 .61615 L .68161 .61723 L F
.721 .309 .267 r
.68199 .61666 m .68161 .61723 L .68238 .61615 L F
0 .33 .812 r
.68161 .61723 m .68127 .61773 L .67973 .61671 L F
.59 .587 .817 r
.68336 .61917 m .67973 .61671 L .68221 .61835 L F
.721 .309 .267 r
.68031 .61891 m .68161 .61723 L .68199 .61666 L F
0 .33 .812 r
.68161 .61723 m .68221 .61835 L .68127 .61773 L F
.565 .402 .619 r
.3589 .78067 m .36094 .77782 L .35879 .77813 L F
.259 0 .044 r
.51774 .79126 m .521 .78883 L .52083 .78976 L F
.331 .078 .371 r
.52083 .78976 m .521 .78883 L .52275 .78834 L F
.53 .186 .329 r
.45083 .73701 m .44967 .73963 L .44745 .7397 L F
.151 0 .141 r
.45119 .73857 m .45083 .73701 L .45298 .73672 L F
.45119 .73857 m .44967 .73963 L .45083 .73701 L F
.811 .456 0 r
.36327 .80442 m .36458 .80748 L .36385 .80538 L F
.813 .926 .91 r
.36327 .80442 m .36675 .80293 L .36544 .80174 L F
.652 .756 .926 r
.36675 .80293 m .36886 .80223 L .36544 .80174 L F
.741 .642 .749 r
.36544 .80174 m .36886 .80223 L .3676 .79895 L F
0 0 .092 r
.36516 .80373 m .36531 .80263 L .36611 .80072 L F
.36531 .80263 m .36544 .80174 L .36594 .80098 L F
.36531 .80263 m .36594 .80098 L .36611 .80072 L F
.813 .926 .91 r
.36327 .80442 m .36385 .80538 L .36448 .80484 L F
.36491 .80372 m .36448 .80484 L .36675 .80293 L F
.36327 .80442 m .36448 .80484 L .36491 .80372 L F
0 .113 .664 r
.70111 .62816 m .70235 .6302 L .70061 .62792 L F
.111 .02 .462 r
.67629 .60039 m .67783 .59686 L .67806 .59902 L F
.463 .63 .926 r
.67806 .59902 m .67817 .60053 L .67629 .60039 L F
.548 .36 .579 r
.51892 .77543 m .52097 .77728 L .52099 .77525 L F
.51892 .77543 m .5183 .77789 L .52097 .77728 L F
.807 .699 .746 r
.39969 .77258 m .39615 .77402 L .39796 .77204 L F
.39969 .77258 m .39762 .77532 L .39615 .77402 L F
.453 .837 .986 r
.39969 .77258 m .39796 .77204 L .40177 .77212 L F
.567 .58 .826 r
.40319 .77531 m .39969 .77258 L .40177 .77212 L F
0 .375 .822 r
.73122 .71369 m .72854 .71184 L .73044 .71316 L F
.906 .514 .095 r
.73117 .715 m .73122 .71369 L .73044 .71316 L F
.73117 .715 m .7321 .71583 L .73122 .71369 L F
.419 .084 .288 r
.61649 .62379 m .61879 .62391 L .61931 .62192 L F
.297 .043 .348 r
.61931 .62192 m .62116 .62104 L .62154 .61925 L F
.435 .161 .398 r
.61879 .62391 m .62116 .62104 L .61931 .62192 L F
.843 .839 .841 r
.57646 .67284 m .57392 .67295 L .5751 .6719 L F
.858 .761 .754 r
.57646 .67284 m .5733 .67466 L .57392 .67295 L F
.825 .842 .861 r
.57906 .67017 m .57646 .67284 L .5751 .6719 L F
.471 .806 .999 r
.68661 .62175 m .68883 .6214 L .68556 .62101 L F
.68661 .62175 m .68883 .6214 L .68556 .62101 L F
.589 .405 .6 r
.36099 .77542 m .36325 .77745 L .36307 .77506 L F
.36099 .77542 m .36094 .77782 L .36325 .77745 L F
.478 .29 .547 r
.34496 .70249 m .347 .70221 L .34735 .69969 L F
.395 .203 .498 r
.34476 .70459 m .347 .70221 L .34496 .70249 L F
.476 .258 .503 r
.64875 .60295 m .6509 .60026 L .65102 .60243 L F
.571 .189 .279 r
.33656 .6754 m .33282 .67728 L .3331 .67581 L F
.33656 .6754 m .33502 .6776 L .33282 .67728 L F
.111 0 0 r
.33685 .67667 m .33656 .6754 L .33867 .67611 L F
.33685 .67667 m .33502 .6776 L .33656 .6754 L F
.001 0 0 r
.31622 .73733 m .31385 .73841 L .31276 .73854 L F
.309 .797 .759 r
.31815 .73712 m .31385 .73841 L .31622 .73733 L F
.52 .331 .565 r
.36165 .70729 m .35971 .70539 L .36172 .70499 L F
.36165 .70729 m .35961 .70772 L .35971 .70539 L F
.718 .59 .713 r
.66456 .62186 m .66649 .6217 L .6668 .61943 L F
.701 .491 .599 r
.66477 .6245 m .66649 .6217 L .66456 .62186 L F
.395 .311 .642 r
.63594 .60174 m .63387 .6001 L .63409 .60234 L F
.63594 .60174 m .6361 .59962 L .63387 .6001 L F
.573 .743 .957 r
.47514 .73426 m .47846 .7351 L .47729 .73388 L F
.663 .784 .939 r
.47729 .73388 m .47846 .7351 L .48053 .73434 L F
.362 .141 .439 r
.62308 .62045 m .62154 .61925 L .62116 .62104 L F
.62308 .62045 m .62343 .61846 L .62154 .61925 L F
.561 .56 .809 r
.50943 .74865 m .5104 .74544 L .50873 .74532 L F
.50943 .74865 m .51158 .74828 L .5104 .74544 L F
.504 .825 1 r
.70793 .73233 m .70471 .73213 L .70814 .73161 L F
0 0 .116 r
.70814 .73161 m .70822 .73198 L .70793 .73233 L F
.8 .308 0 r
.70822 .73198 m .71054 .73381 L .70793 .73233 L F
.76 .471 0 r
.66768 .60684 m .66754 .60573 L .66766 .60458 L F
.66768 .60684 m .66855 .60988 L .66754 .60573 L F
0 0 0 r
.43142 .78531 m .43026 .78542 L .43296 .78439 L F
.151 0 0 r
.43397 .7847 m .43142 .78531 L .43296 .78439 L F
.72 .766 .89 r
.69556 .70243 m .69607 .70326 L .69844 .70281 L F
.446 .319 .613 r
.69844 .70281 m .69997 .70335 L .70064 .69859 L F
.812 .45 .371 r
.69844 .70281 m .69987 .70382 L .7003 .70443 L F
.69987 .70382 m .70212 .70541 L .7003 .70443 L F
.277 .038 .36 r
.70091 .70591 m .70115 .70565 L .7003 .70443 L F
.70115 .70565 m .70269 .70399 L .7003 .70443 L F
.372 .392 .752 r
.69844 .70281 m .7003 .70443 L .69997 .70335 L F
.074 0 .171 r
.62737 .67286 m .62703 .6749 L .62527 .67554 L F
.095 0 .228 r
.62703 .6749 m .62508 .67771 L .62527 .67554 L F
.468 .551 .858 r
.40373 .77262 m .40319 .77531 L .40177 .77212 L F
.40373 .77262 m .40482 .77494 L .40319 .77531 L F
.461 .347 .638 r
.40519 .7773 m .40319 .77531 L .40482 .77494 L F
.40519 .7773 m .40332 .77774 L .40319 .77531 L F
.943 .906 .756 r
.57906 .67017 m .57964 .66656 L .58058 .6673 L F
.958 .905 .725 r
.58058 .6673 m .57964 .66656 L .58069 .66442 L F
.667 .442 .57 r
.59931 .68647 m .59926 .6891 L .59701 .68885 L F
.653 .43 .569 r
.60257 .68823 m .59931 .68647 L .60268 .68633 L F
.60257 .68823 m .59926 .6891 L .59931 .68647 L F
.893 .707 .645 r
.67217 .59438 m .66913 .59625 L .66903 .59403 L F
.67217 .59438 m .6704 .5974 L .66913 .59625 L F
.5 .302 .543 r
.39762 .77532 m .39522 .77793 L .3941 .77465 L F
.649 .817 .964 r
.39899 .77745 m .39522 .77793 L .39736 .77767 L F
.5 .302 .543 r
.39762 .77532 m .39736 .77767 L .39522 .77793 L F
.726 .58 .69 r
.58125 .68095 m .57937 .68125 L .57807 .67827 L F
.72 .549 .657 r
.58125 .68095 m .57932 .68366 L .57937 .68125 L F
.711 .536 .651 r
.58428 .68285 m .57932 .68366 L .58125 .68095 L F
.6 .419 .608 r
.58509 .68118 m .58428 .68285 L .58125 .68095 L F
.457 .887 .852 r
.7196 .62096 m .71746 .62188 L .7189 .62094 L F
0 0 0 r
.7189 .62094 m .71746 .62188 L .7163 .6231 L F
.584 .84 .993 r
.68495 .58806 m .68569 .58683 L .68372 .58655 L F
.68495 .58806 m .68692 .58751 L .68569 .58683 L F
.032 .602 .754 r
.44182 .7242 m .44387 .72423 L .44519 .72431 L F
0 .568 .713 r
.44387 .72423 m .44724 .72431 L .44519 .72431 L F
.819 .683 .714 r
.64124 .63731 m .64338 .63848 L .64246 .64036 L F
.509 .577 .859 r
.28713 .60916 m .28788 .61119 L .2862 .6111 L F
.82 .791 .824 r
.72954 .72466 m .72751 .72712 L .72792 .72368 L F
.632 .6 .799 r
.50602 .73247 m .50273 .72993 L .50493 .72911 L F
.532 .495 .761 r
.50889 .73455 m .50602 .73247 L .50836 .73218 L F
.71 .758 .89 r
.68828 .63124 m .68905 .63294 L .6861 .63084 L F
.811 .749 .795 r
.6861 .63084 m .68905 .63294 L .68681 .63544 L F
.367 .553 .904 r
.69015 .63152 m .68905 .63294 L .68828 .63124 L F
.579 .859 .996 r
.69119 .63224 m .68905 .63294 L .69015 .63152 L F
.496 .25 .471 r
.34578 .71883 m .3453 .7209 L .34338 .7212 L F
.203 0 .206 r
.34775 .71836 m .3453 .7209 L .34578 .71883 L F
.701 .67 .817 r
.49593 .7267 m .49282 .72517 L .4948 .72428 L F
.564 .59 .839 r
.49691 .72333 m .49593 .7267 L .4948 .72428 L F
.49691 .72333 m .49813 .72625 L .49593 .7267 L F
.619 .407 .572 r
.30884 .68537 m .30629 .68809 L .30786 .68652 L F
.045 0 0 r
.72082 .62597 m .72262 .62589 L .72297 .62564 L F
.734 .813 .913 r
.72262 .62589 m .72638 .62449 L .72518 .62335 L F
.72262 .62589 m .72518 .62335 L .72297 .62564 L F
.515 .49 .767 r
.40519 .7773 m .40273 .77825 L .40332 .77774 L F
.40519 .7773 m .40609 .78051 L .40273 .77825 L F
.678 .414 .515 r
.61324 .68478 m .61013 .6839 L .61372 .68379 L F
.61324 .68478 m .61027 .68593 L .61013 .6839 L F
.356 .819 .733 r
.40111 .79449 m .3973 .79599 L .39897 .7951 L F
.416 .825 .976 r
.68681 .63544 m .68357 .63546 L .686 .63498 L F
.917 .911 .799 r
.68656 .63326 m .686 .63498 L .68498 .63428 L F
.68656 .63326 m .68498 .63428 L .68669 .6334 L F
.68656 .63326 m .68669 .6334 L .687 .63325 L F
.811 .749 .795 r
.6861 .63084 m .68645 .63313 L .68656 .63326 L F
.68645 .63313 m .68681 .63544 L .68656 .63326 L F
.942 .946 .756 r
.68681 .63544 m .686 .63498 L .68656 .63326 L F
.62 .554 .759 r
.39256 .75604 m .39395 .75907 L .39086 .75918 L F
0 0 0 r
.39395 .75907 m .39366 .76222 L .39086 .75918 L F
.482 .271 .516 r
.35528 .71084 m .35507 .71306 L .35308 .71353 L F
.337 .076 .362 r
.35428 .71504 m .35308 .71353 L .35507 .71306 L F
.35428 .71504 m .35253 .71571 L .35308 .71353 L F
.679 .474 .601 r
.6612 .62411 m .66477 .6245 L .66456 .62186 L F
.514 .381 .637 r
.33747 .8105 m .33944 .80722 L .33702 .80793 L F
.33747 .8105 m .33977 .81054 L .33944 .80722 L F
.405 .163 .43 r
.35734 .71044 m .35507 .71306 L .35528 .71084 L F
.805 .921 .915 r
.71063 .6335 m .71462 .63293 L .7146 .63113 L F
.354 0 .125 r
.38504 .73475 m .38693 .73451 L .38806 .73271 L F
.66 .274 .303 r
.38806 .73271 m .38693 .73451 L .38989 .73431 L F
.654 .425 .56 r
.59124 .6892 m .59148 .69143 L .58929 .69146 L F
.644 .418 .561 r
.59466 .69095 m .59124 .6892 L .59467 .68894 L F
.59466 .69095 m .59148 .69143 L .59124 .6892 L F
.587 .742 .95 r
.68059 .58366 m .67833 .58414 L .68051 .5843 L F
.707 .943 .958 r
.6821 .58083 m .67804 .58379 L .67755 .58307 L F
.67714 .58233 m .67755 .58307 L .67707 .58235 L F
.6821 .58083 m .67755 .58307 L .67714 .58233 L F
.291 .682 .974 r
.68051 .5843 m .67833 .58414 L .67797 .58384 L F
.624 .616 .823 r
.6821 .58083 m .68051 .5843 L .67804 .58379 L F
.291 .682 .974 r
.68051 .5843 m .67735 .58331 L .67804 .58379 L F
.311 .708 .978 r
.67707 .58235 m .67804 .58379 L .67735 .58331 L F
.291 .682 .974 r
.67775 .58343 m .67797 .58384 L .67735 .58331 L F
.68051 .5843 m .67797 .58384 L .67775 .58343 L F
.949 .92 .747 r
.70212 .70541 m .70081 .70812 L .69969 .70775 L F
.522 .545 .82 r
.3659 .65698 m .36721 .6545 L .36515 .65496 L F
.3659 .65698 m .36799 .65666 L .36721 .6545 L F
.6 .419 .608 r
.58509 .68118 m .58516 .6836 L .58428 .68285 L F
.874 .447 .034 r
.65037 .61435 m .65081 .61542 L .6502 .61531 L F
.278 .514 .901 r
.35253 .67373 m .35348 .67277 L .35156 .67312 L F
.35253 .67373 m .35515 .67507 L .35348 .67277 L F
.63 .378 .518 r
.393 .73415 m .39572 .73203 L .39361 .73241 L F
.453 .312 .599 r
.29162 .6133 m .2916 .61609 L .28987 .61635 L F
.326 .186 .532 r
.29129 .61806 m .28987 .61635 L .2916 .61609 L F
.29129 .61806 m .28962 .61913 L .28987 .61635 L F
.979 .74 .505 r
.68221 .61835 m .6833 .62147 L .68336 .61917 L F
.861 .773 .763 r
.6067 .65649 m .60487 .65914 L .60756 .65947 L F
.838 .709 .721 r
.60487 .65914 m .60719 .66136 L .60756 .65947 L F
.867 .776 .759 r
.6067 .65649 m .60756 .65947 L .6083 .65743 L F
.384 .022 .221 r
.33227 .71291 m .33429 .71246 L .33538 .71031 L F
0 0 .008 r
.33538 .71031 m .3356 .71159 L .33689 .71044 L F
.33538 .71031 m .33429 .71246 L .3356 .71159 L F
.793 .673 .732 r
.57807 .67827 m .57599 .68093 L .57476 .67797 L F
.733 .583 .687 r
.57807 .67827 m .57937 .68125 L .57599 .68093 L F
.547 .373 .597 r
.65113 .60488 m .64875 .60295 L .65102 .60243 L F
.65113 .60488 m .64897 .6057 L .64875 .60295 L F
.576 .384 .585 r
.6123 .66761 m .61468 .66732 L .61454 .66496 L F
.497 .268 .497 r
.61468 .66732 m .61687 .66475 L .61454 .66496 L F
.923 .797 .703 r
.6704 .5974 m .67142 .60044 L .67093 .59944 L F
.898 .698 .189 r
.67142 .60044 m .67099 .60074 L .67093 .59944 L F
.67142 .60044 m .67147 .60241 L .67099 .60074 L F
.196 .504 .909 r
.63982 .62425 m .64171 .62472 L .6424 .62612 L F
.723 .804 .915 r
.64171 .62472 m .64476 .62495 L .6424 .62612 L F
.921 .945 .797 r
.59653 .64618 m .59767 .64263 L .59798 .64311 L F
.577 .054 0 r
.4934 .77792 m .49196 .77821 L .49004 .77762 L F
.755 .239 0 r
.4934 .77792 m .49405 .7797 L .49196 .77821 L F
.4934 .77792 m .49544 .78015 L .49405 .7797 L F
.621 .853 .987 r
.71869 .60236 m .71611 .60299 L .71507 .60218 L F
.71507 .60218 m .71611 .60299 L .71869 .60236 L F
.838 .636 .63 r
.58764 .68635 m .5849 .68596 L .58516 .6836 L F
.829 .706 .728 r
.58764 .68635 m .58603 .68901 L .5849 .68596 L F
.671 .46 .591 r
.60663 .66757 m .60914 .66971 L .60983 .66759 L F
.71 .462 .549 r
.60914 .66971 m .61236 .66997 L .60983 .66759 L F
.689 .467 .58 r
.60983 .66759 m .61236 .66997 L .6123 .66761 L F
.495 .292 .533 r
.37359 .69206 m .3734 .69455 L .37146 .69486 L F
.47 .249 .495 r
.37541 .69154 m .3734 .69455 L .37359 .69206 L F
.692 .676 .83 r
.73123 .73747 m .72819 .73848 L .72814 .73663 L F
.65 .513 .683 r
.73123 .73747 m .72896 .74067 L .72819 .73848 L F
.736 .643 .757 r
.50493 .72911 m .50156 .72919 L .50361 .72625 L F
.50493 .72911 m .50273 .72993 L .50156 .72919 L F
.728 .7 .824 r
.50699 .72669 m .50493 .72911 L .50361 .72625 L F
.549 .372 .593 r
.63488 .63206 m .63272 .63486 L .63274 .63264 L F
.714 .728 .862 r
.70191 .7097 m .70343 .71109 L .70516 .70933 L F
.346 0 0 r
.42118 .74328 m .41977 .74468 L .4176 .74496 L F
.215 0 0 r
.42181 .74423 m .42118 .74328 L .42327 .74274 L F
.42181 .74423 m .41977 .74468 L .42118 .74328 L F
.697 .242 .169 r
.50208 .78088 m .50108 .78226 L .49885 .78043 L F
.89 .509 .307 r
.50238 .78241 m .50108 .78226 L .50208 .78088 L F
.799 .699 .755 r
.65337 .62919 m .65562 .63022 L .65692 .62733 L F
.841 .637 .627 r
.65337 .62919 m .65482 .63225 L .65562 .63022 L F
.181 0 0 r
.43026 .78542 m .42942 .78587 L .42726 .78605 L F
0 0 0 r
.43142 .78531 m .42942 .78587 L .43026 .78542 L F
0 .262 .695 r
.72719 .71086 m .72854 .71184 L .72562 .70995 L F
.492 0 0 r
.72864 .71212 m .72854 .71184 L .72719 .71086 L F
.72864 .71212 m .73044 .71316 L .72854 .71184 L F
.518 .309 .535 r
.33615 .80258 m .33782 .80435 L .33752 .80211 L F
.33615 .80258 m .3362 .80558 L .33782 .80435 L F
.563 .915 .963 r
.31707 .7163 m .31765 .71527 L .31912 .71631 L F
.31707 .7163 m .31474 .71615 L .31765 .71527 L F
.613 .916 .979 r
.51688 .7436 m .51938 .74305 L .51835 .74261 L F
.36 .794 .965 r
.51938 .74305 m .52159 .74281 L .51835 .74261 L F
0 0 .158 r
.62919 .67012 m .62888 .67193 L .62737 .67286 L F
0 0 .132 r
.62888 .67193 m .62703 .6749 L .62737 .67286 L F
.724 .597 .715 r
.65692 .62733 m .65907 .62647 L .65889 .62427 L F
.651 .538 .712 r
.65907 .62647 m .6612 .62411 L .65889 .62427 L F
.65907 .62647 m .6625 .62741 L .6612 .62411 L F
.747 .418 .427 r
.70081 .70812 m .69901 .70953 L .69969 .70775 L F
.70081 .70812 m .70191 .7097 L .69901 .70953 L F
.495 .473 .763 r
.37014 .805 m .37089 .80129 L .36886 .80223 L F
.37014 .805 m .37204 .80482 L .37089 .80129 L F
.585 .698 .92 r
.68133 .60128 m .67962 .60318 L .67817 .60053 L F
.68133 .60128 m .68064 .60251 L .67962 .60318 L F
0 .029 .518 r
.68053 .60403 m .67962 .60318 L .68064 .60251 L F
.881 .776 .741 r
.68004 .60313 m .6802 .60372 L .68053 .60403 L F
0 .029 .518 r
.68053 .60403 m .68094 .60442 L .67962 .60318 L F
.881 .776 .741 r
.6802 .60372 m .68086 .60624 L .68053 .60403 L F
0 .029 .518 r
.68053 .60403 m .68173 .60516 L .68094 .60442 L F
.727 .696 .821 r
.49251 .87961 m .49585 .87991 L .49467 .8774 L F
.844 .743 .752 r
.49467 .8774 m .49585 .87991 L .49597 .87802 L F
.39 .725 .99 r
.47157 .72447 m .47065 .7255 L .46915 .72483 L F
.47157 .72447 m .47273 .72538 L .47065 .7255 L F
.321 0 .213 r
.52592 .77477 m .52773 .77491 L .52865 .77273 L F
.545 .19 .317 r
.52865 .77273 m .52773 .77491 L .53051 .77403 L F
.372 .138 .424 r
.37283 .69627 m .37146 .69486 L .3734 .69455 L F
.37283 .69627 m .37107 .69698 L .37146 .69486 L F
.807 .986 .722 r
.60227 .63733 m .60009 .63998 L .59969 .63984 L F
.731 .662 .782 r
.6973 .58137 m .69815 .58455 L .69497 .58395 L F
.833 .551 .511 r
.6973 .58137 m .70044 .58384 L .69815 .58455 L F
.706 .458 .547 r
.52099 .77525 m .52337 .77767 L .52374 .77545 L F
.506 .276 .499 r
.52374 .77545 m .52578 .77717 L .52592 .77477 L F
.52374 .77545 m .52337 .77767 L .52578 .77717 L F
.744 .99 .882 r
.66936 .59071 m .67016 .58911 L .67131 .59018 L F
.66936 .59071 m .66799 .59088 L .67016 .58911 L F
.764 .549 .606 r
.57932 .68366 m .57599 .68093 L .57937 .68125 L F
.76 .742 .837 r
.67688 .63217 m .67743 .63507 L .68023 .63246 L F
.394 .219 .522 r
.62584 .61374 m .62763 .61296 L .62764 .61077 L F
.363 .155 .459 r
.62713 .61536 m .62584 .61374 L .62575 .61591 L F
.62713 .61536 m .62763 .61296 L .62584 .61374 L F
.807 .986 .722 r
.60227 .63733 m .59969 .63984 L .60157 .63692 L F
.313 0 0 r
.47026 .77581 m .46886 .77708 L .4667 .77725 L F
.53 .087 .141 r
.47241 .77572 m .46886 .77708 L .47026 .77581 L F
.848 .757 .763 r
.60486 .6669 m .60663 .66757 L .60593 .6646 L F
.829 .587 .574 r
.60379 .66928 m .60663 .66757 L .60486 .6669 L F
.60379 .66928 m .60669 .66988 L .60663 .66757 L F
.671 .46 .591 r
.60663 .66757 m .60669 .66988 L .60914 .66971 L F
.945 .683 .508 r
.69604 .71835 m .69743 .72167 L .69767 .71974 L F
0 0 .066 r
.6361 .59962 m .63761 .59844 L .63778 .59667 L F
0 0 0 r
.63778 .59667 m .63995 .59592 L .64072 .59425 L F
.037 0 .072 r
.63761 .59844 m .63995 .59592 L .63778 .59667 L F
.921 .945 .797 r
.59653 .64618 m .59567 .64556 L .59767 .64263 L F
.521 .335 .569 r
.6123 .66761 m .61453 .66949 L .61468 .66732 L F
.6123 .66761 m .61236 .66997 L .61453 .66949 L F
.713 .825 .935 r
.64489 .60697 m .64738 .60689 L .64897 .6057 L F
.336 0 .127 r
.3043 .66209 m .30647 .66156 L .30755 .65981 L F
.188 0 .044 r
.30755 .65981 m .30819 .66088 L .30956 .65926 L F
.30755 .65981 m .30647 .66156 L .30819 .66088 L F
.254 0 .213 r
.63414 .66485 m .63379 .66684 L .63169 .66708 L F
.097 0 .061 r
.63414 .66485 m .63671 .66254 L .63603 .66426 L F
.06 0 0 r
.63414 .66485 m .63509 .66548 L .63379 .66684 L F
.63414 .66485 m .63603 .66426 L .63509 .66548 L F
.748 .447 .473 r
.52097 .77728 m .52337 .77767 L .52099 .77525 L F
.507 .358 .613 r
.37181 .74837 m .37376 .74794 L .37365 .74555 L F
.509 .342 .589 r
.37181 .74837 m .37377 .75039 L .37376 .74794 L F
.37181 .74837 m .3718 .7508 L .37377 .75039 L F
.55 .423 .66 r
.36588 .75953 m .36811 .76145 L .36788 .75909 L F
.36588 .75953 m .36605 .76184 L .36811 .76145 L F
.691 .655 .81 r
.50156 .72919 m .50273 .72993 L .49934 .72933 L F
.211 .533 .923 r
.68439 .60643 m .68275 .60686 L .68173 .60516 L F
.68439 .60643 m .68559 .60786 L .68275 .60686 L F
.532 .307 .518 r
.33752 .80211 m .34032 .79878 L .33832 .7998 L F
.848 .96 .88 r
.65311 .62396 m .65678 .62206 L .65485 .62114 L F
.838 .84 .847 r
.65485 .62114 m .65678 .62206 L .65829 .62002 L F
.634 .403 .551 r
.30304 .68645 m .30195 .68875 L .30211 .68645 L F
.30304 .68645 m .30349 .68863 L .30195 .68875 L F
.349 .053 .314 r
.30997 .65808 m .30956 .65926 L .31145 .65847 L F
.331 0 .119 r
.29674 .66691 m .29992 .66479 L .29761 .66587 L F
0 .196 .613 r
.38689 .66901 m .38822 .66984 L .38855 .67006 L F
.463 .655 .943 r
.38822 .66984 m .38879 .67224 L .38855 .67006 L F
.514 .303 .531 r
.68137 .62385 m .68488 .62681 L .6835 .62518 L F
.678 .77 .92 r
.37573 .82312 m .37751 .82461 L .37908 .8235 L F
.47 0 0 r
.45614 .72571 m .45828 .72609 L .45965 .72542 L F
0 0 0 r
.45828 .72609 m .4616 .72552 L .45965 .72542 L F
.723 .576 .689 r
.35549 .79144 m .35871 .79149 L .35808 .78873 L F
.616 .591 .802 r
.35808 .78873 m .35942 .78603 L .35724 .78631 L F
.35808 .78873 m .36044 .78887 L .35942 .78603 L F
.642 .524 .704 r
.35808 .78873 m .36104 .79128 L .36044 .78887 L F
.35808 .78873 m .35871 .79149 L .36104 .79128 L F
.16 .7 .79 r
.4264 .74248 m .42537 .74248 L .42327 .74274 L F
.345 0 0 r
.42929 .74098 m .42537 .74248 L .4264 .74248 L F
.796 .531 .537 r
.63911 .61903 m .63525 .6204 L .63438 .61912 L F
.63911 .61903 m .63875 .62117 L .63525 .6204 L F
.233 0 .23 r
.63802 .66146 m .63603 .66426 L .63671 .66254 L F
.387 0 0 r
.71356 .73445 m .71572 .73504 L .71673 .73498 L F
.744 .236 0 r
.71572 .73504 m .71817 .73744 L .71673 .73498 L F
.844 .391 0 r
.71673 .73498 m .71817 .73744 L .71852 .73752 L F
.288 0 .119 r
.34407 .72258 m .34338 .7212 L .3453 .7209 L F
.34407 .72258 m .34213 .72318 L .34338 .7212 L F
.201 0 0 r
.3418 .67518 m .34084 .6758 L .33867 .67611 L F
.077 0 0 r
.343 .67529 m .3418 .67518 L .34381 .67493 L F
.343 .67529 m .34084 .6758 L .3418 .67518 L F
.371 0 .007 r
.43021 .77728 m .43243 .77707 L .43383 .7756 L F
0 0 0 r
.43383 .7756 m .4339 .77599 L .43589 .77518 L F
.43383 .7756 m .43243 .77707 L .4339 .77599 L F
.664 .634 .811 r
.4904 .72673 m .48718 .72477 L .48918 .724 L F
.713 .673 .81 r
.49282 .72517 m .4904 .72673 L .48918 .724 L F
.799 .699 .755 r
.65337 .62919 m .65692 .62733 L .65337 .62709 L F
.572 .205 .306 r
.40856 .72825 m .41195 .72636 L .40893 .72728 L F
.40856 .72825 m .41072 .72851 L .41195 .72636 L F
.47 .085 .227 r
.41072 .72851 m .41416 .72627 L .41195 .72636 L F
.826 .592 .584 r
.37908 .8235 m .37921 .82106 L .37684 .8212 L F
.495 .563 .854 r
.37908 .8235 m .37684 .8212 L .37921 .82106 L F
.196 .175 .607 r
.52559 .73783 m .5247 .74022 L .5248 .73946 L F
.52 0 0 r
.5247 .74022 m .52316 .74046 L .5248 .73946 L F
.5247 .74022 m .52647 .74143 L .52316 .74046 L F
.358 .352 .717 r
.52559 .73783 m .52765 .73938 L .5247 .74022 L F
.287 .136 .495 r
.5247 .74022 m .52765 .73938 L .52647 .74143 L F
.199 .35 .792 r
.36996 .65832 m .36923 .65977 L .36799 .65666 L F
.559 .794 .987 r
.36996 .65832 m .3713 .65932 L .36923 .65977 L F
.476 .188 .396 r
.61397 .62674 m .6162 .62627 L .61649 .62379 L F
.5 .242 .455 r
.6162 .62627 m .61879 .62391 L .61649 .62379 L F
.514 .27 .483 r
.38048 .7377 m .38269 .7373 L .38309 .7352 L F
.39 .16 .441 r
.38309 .7352 m .38445 .73671 L .38504 .73475 L F
.38309 .7352 m .38269 .7373 L .38445 .73671 L F
.718 .645 .775 r
.51158 .74828 m .51292 .75139 L .51502 .7507 L F
.538 .526 .79 r
.37678 .6613 m .37594 .66489 L .37481 .66162 L F
.37678 .6613 m .37791 .66458 L .37594 .66489 L F
.463 .803 .999 r
.3211 .71571 m .32476 .71618 L .32259 .71635 L F
.428 .045 .208 r
.65002 .58863 m .65303 .58635 L .65114 .58728 L F
.442 .786 .998 r
.33944 .80722 m .34245 .80758 L .34075 .8069 L F
.763 .564 .628 r
.33944 .80722 m .3418 .80836 L .34245 .80758 L F
.633 .692 .887 r
.34245 .80758 m .3435 .80465 L .34075 .8069 L F
.34245 .80758 m .34558 .80721 L .3435 .80465 L F
.839 .96 .626 r
.67276 .61177 m .67011 .61536 L .67143 .61144 L F
.828 .946 .9 r
.72852 .62173 m .72518 .62335 L .72638 .62449 L F
.401 .772 .993 r
.35792 .80553 m .35871 .80617 L .36119 .80568 L F
.517 .268 .476 r
.60944 .62969 m .61169 .62929 L .61188 .62729 L F
.454 .216 .462 r
.61188 .62729 m .61169 .62929 L .61397 .62674 L F
.113 0 0 r
.32642 .73302 m .32606 .73215 L .32786 .73147 L F
.32642 .73302 m .32449 .73369 L .32606 .73215 L F
0 .144 .678 r
.63875 .62117 m .64047 .62324 L .63982 .62425 L F
.184 .507 .911 r
.64047 .62324 m .64171 .62472 L .63982 .62425 L F
.634 .592 .79 r
.39383 .77268 m .39053 .77012 L .39279 .7696 L F
.509 .454 .731 r
.39509 .76918 m .39383 .77268 L .39279 .7696 L F
.39509 .76918 m .39585 .77243 L .39383 .77268 L F
.513 .514 .794 r
.39585 .77243 m .39615 .77402 L .39383 .77268 L F
.652 .695 .877 r
.39615 .77402 m .3941 .77465 L .39383 .77268 L F
0 0 0 r
.39395 .75907 m .39371 .7618 L .39366 .76222 L F
.316 .049 .341 r
.3936 .76393 m .39366 .76222 L .39371 .7618 L F
.3936 .76393 m .392 .7653 L .39366 .76222 L F
.604 .317 .455 r
.6157 .68368 m .61324 .68478 L .61372 .68379 L F
.579 .455 .674 r
.36254 .7698 m .36493 .77229 L .36432 .76937 L F
.36254 .7698 m .3628 .77266 L .36493 .77229 L F
.94 .72 .576 r
.51408 .73222 m .51489 .73508 L .51359 .73467 L F
.78 .784 .856 r
.51489 .73508 m .51156 .73497 L .51359 .73467 L F
.703 .599 .738 r
.51717 .73436 m .51489 .73508 L .51408 .73222 L F
.611 .363 .518 r
.59701 .68885 m .59466 .69095 L .59467 .68894 L F
.276 .027 .344 r
.36123 .68662 m .36063 .68859 L .3628 .68587 L F
.111 0 0 r
.71785 .62699 m .71835 .62633 L .72005 .62623 L F
.233 0 0 r
.31402 .6568 m .31586 .65635 L .31757 .65461 L F
.257 0 0 r
.31757 .65461 m .31881 .65499 L .31964 .65414 L F
.31757 .65461 m .31586 .65635 L .31881 .65499 L F
.952 .824 .681 r
.73331 .72584 m .7352 .72453 L .73421 .72387 L F
.73331 .72584 m .73445 .72665 L .7352 .72453 L F
.652 .695 .877 r
.39615 .77402 m .39762 .77532 L .3941 .77465 L F
.242 0 .267 r
.63169 .66708 m .63126 .66941 L .62919 .67012 L F
.233 0 .264 r
.63295 .66834 m .63169 .66708 L .63379 .66684 L F
.63295 .66834 m .63126 .66941 L .63169 .66708 L F
.463 .655 .943 r
.38822 .66984 m .39068 .67181 L .38879 .67224 L F
.564 .432 .659 r
.39068 .67181 m .38843 .67454 L .38879 .67224 L F
.331 .54 .906 r
.35491 .65193 m .35408 .65315 L .35255 .65192 L F
.35491 .65193 m .35574 .65347 L .35408 .65315 L F
.557 .402 .626 r
.38885 .67749 m .38642 .676 L .38843 .67454 L F
.38885 .67749 m .38691 .67831 L .38642 .676 L F
.847 .694 .693 r
.64124 .63731 m .64246 .64036 L .63991 .64036 L F
.663 .638 .815 r
.51063 .72929 m .50699 .72669 L .50924 .72579 L F
.615 .447 .632 r
.51063 .72929 m .51075 .73236 L .50836 .73218 L F
.635 .594 .79 r
.51261 .72676 m .51063 .72929 L .50924 .72579 L F
.594 .534 .757 r
.51263 .72886 m .51063 .72929 L .51261 .72676 L F
.741 .546 .63 r
.51408 .73222 m .51063 .72929 L .51263 .72886 L F
.51408 .73222 m .51075 .73236 L .51063 .72929 L F
.67 .513 .663 r
.58177 .68559 m .57932 .68366 L .58428 .68285 L F
.682 .492 .623 r
.58516 .6836 m .58177 .68559 L .58428 .68285 L F
.899 .817 .759 r
.33977 .81054 m .34088 .81095 L .3418 .80836 L F
.935 .708 .57 r
.33892 .81219 m .34088 .81095 L .33977 .81054 L F
.144 0 .201 r
.51075 .73236 m .50889 .73455 L .50836 .73218 L F
.486 .281 .528 r
.62202 .63523 m .6219 .63772 L .61987 .63838 L F
.634 .404 .551 r
.62454 .63612 m .62202 .63523 L .62534 .63494 L F
.62454 .63612 m .6219 .63772 L .62202 .63523 L F
.718 .645 .775 r
.51158 .74828 m .51502 .7507 L .51384 .74785 L F
.788 .735 .804 r
.51384 .74785 m .51502 .7507 L .517 .74797 L F
.777 .659 .733 r
.65598 .63763 m .65729 .64078 L .65928 .63806 L F
.828 .946 .9 r
.72852 .62173 m .72763 .62113 L .72518 .62335 L F
0 0 0 r
.73108 .6192 m .72991 .6205 L .72852 .62173 L F
.543 .863 .996 r
.72852 .62173 m .72991 .6205 L .72763 .62113 L F
.777 .864 .913 r
.68113 .62065 m .67868 .62379 L .68137 .62385 L F
.758 .512 .561 r
.67868 .62379 m .68118 .62664 L .68137 .62385 L F
.919 .738 .641 r
.68113 .62065 m .6833 .62147 L .68221 .61835 L F
.077 0 .341 r
.68359 .61923 m .68176 .62105 L .68188 .62029 L F
.6828 .61873 m .68188 .62029 L .68221 .61835 L F
.68359 .61923 m .68188 .62029 L .6828 .61873 L F
.83 .847 .859 r
.68157 .62082 m .68137 .62385 L .6833 .62147 L F
.68113 .62065 m .68119 .62146 L .68157 .62082 L F
.68119 .62146 m .68137 .62385 L .68157 .62082 L F
.514 .303 .531 r
.68137 .62385 m .68118 .62664 L .68347 .62602 L F
.691 .157 0 r
.67777 .62373 m .68118 .62664 L .67868 .62379 L F
.67777 .62373 m .68 .62606 L .68118 .62664 L F
.243 0 0 r
.68 .62606 m .68347 .62602 L .68118 .62664 L F
.68 .62606 m .68248 .62624 L .68347 .62602 L F
.235 .339 .767 r
.683 .62607 m .68347 .62602 L .68248 .62624 L F
.514 .303 .531 r
.68137 .62385 m .68347 .62602 L .68389 .62598 L F
.235 .339 .767 r
.68534 .62528 m .68347 .62602 L .683 .62607 L F
.514 .303 .531 r
.68389 .62598 m .68347 .62602 L .68488 .62681 L F
.693 .888 .969 r
.48172 .72457 m .47834 .72498 L .4805 .72428 L F
.423 .841 .964 r
.48172 .72457 m .48271 .7238 L .4838 .72421 L F
.48172 .72457 m .4805 .72428 L .48271 .7238 L F
.332 .13 .449 r
.63254 .61927 m .6326 .62209 L .63101 .62194 L F
.713 .865 .451 r
.63438 .61912 m .6326 .62209 L .63254 .61927 L F
.666 .741 .906 r
.36515 .65496 m .36259 .65555 L .36115 .65379 L F
.698 .662 .81 r
.49094 .88035 m .49251 .87961 L .49252 .87858 L F
.49094 .88035 m .49034 .88041 L .49251 .87961 L F
.215 0 0 r
.4616 .72552 m .46377 .72573 L .46499 .72558 L F
.086 0 0 r
.46377 .72573 m .46703 .7253 L .46499 .72558 L F
.775 .446 .43 r
.34032 .79878 m .34219 .80138 L .34355 .79954 L F
.718 .476 .559 r
.34219 .80138 m .34567 .79931 L .34355 .79954 L F
.693 .634 .786 r
.50156 .72919 m .49934 .72933 L .49813 .72625 L F
.608 .622 .84 r
.33387 .80683 m .33568 .80693 L .3362 .80558 L F
.811 .962 .908 r
.68939 .58398 m .68549 .58571 L .68906 .58357 L F
.686 .697 .855 r
.69286 .57989 m .69374 .58307 L .69206 .58338 L F
.69172 .58324 m .69206 .58338 L .69165 .58346 L F
.69286 .57989 m .69214 .58305 L .69178 .58305 L F
.69286 .57989 m .69178 .58305 L .69201 .58289 L F
.69178 .58305 m .69206 .58338 L .69172 .58324 L F
.69178 .58305 m .69165 .58346 L .69201 .58289 L F
.597 .8 .977 r
.68923 .58058 m .69201 .58289 L .69128 .58306 L F
.68909 .58309 m .69128 .58306 L .68906 .58357 L F
.68923 .58058 m .69128 .58306 L .68909 .58309 L F
.686 .697 .855 r
.69214 .58305 m .69206 .58338 L .69178 .58305 L F
.614 .666 .877 r
.69128 .58306 m .68939 .58398 L .68906 .58357 L F
.69201 .58289 m .69144 .58313 L .69128 .58306 L F
.69144 .58313 m .68939 .58398 L .69128 .58306 L F
.69201 .58289 m .69165 .58346 L .68939 .58398 L F
.743 .461 .503 r
.35549 .79144 m .3583 .79365 L .35871 .79149 L F
.44 .141 .36 r
.3583 .79365 m .36104 .79128 L .35871 .79149 L F
.77 .395 .346 r
.46773 .76817 m .471 .76763 L .46775 .76692 L F
.46773 .76817 m .46996 .76941 L .471 .76763 L F
.632 .233 .268 r
.46996 .76941 m .47321 .76916 L .471 .76763 L F
.65 .562 .742 r
.39279 .7696 m .39053 .77012 L .38948 .7668 L F
.721 .703 .833 r
.69165 .58346 m .69497 .58395 L .69283 .58497 L F
.469 .888 .796 r
.61411 .64465 m .6127 .64566 L .61493 .64272 L F
.127 0 .127 r
.61737 .6405 m .61658 .64247 L .61493 .64272 L F
.574 .327 .505 r
.61658 .64247 m .61411 .64465 L .61493 .64272 L F
.501 .084 .18 r
.42173 .72578 m .42395 .72582 L .42529 .724 L F
.352 0 0 r
.42395 .72582 m .42742 .72423 L .42529 .724 L F
.06 0 0 r
.43824 .78311 m .4372 .78372 L .43397 .7847 L F
.258 0 0 r
.44019 .78249 m .4372 .78372 L .43824 .78311 L F
.68 .141 0 r
.71889 .70708 m .7214 .70899 L .72173 .70819 L F
.653 .108 0 r
.7214 .70899 m .72431 .71001 L .72173 .70819 L F
.917 .544 .117 r
.66489 .59055 m .66475 .59039 L .66544 .58929 L F
.66446 .59152 m .66515 .592 L .66475 .59039 L F
.66446 .59152 m .66475 .59039 L .66489 .59055 L F
.955 .73 .274 r
.66475 .59039 m .6655 .59153 L .66467 .59029 L F
.66475 .59039 m .66467 .59029 L .66378 .58896 L F
.66475 .59039 m .66525 .5916 L .6655 .59153 L F
.959 .626 .248 r
.42471 .77518 m .4241 .77525 L .42408 .77269 L F
.848 .814 .817 r
.35644 .69174 m .35426 .69446 L .35246 .69291 L F
.431 .136 .362 r
.37037 .69869 m .36896 .69744 L .37107 .69698 L F
.37037 .69869 m .36838 .69919 L .36896 .69744 L F
.442 .568 .886 r
.67481 .63212 m .67569 .63056 L .67358 .63057 L F
.67481 .63212 m .67688 .63217 L .67569 .63056 L F
.167 0 .336 r
.52592 .77477 m .52705 .77647 L .52773 .77491 L F
.52592 .77477 m .52578 .77717 L .52705 .77647 L F
.446 .077 .243 r
.40061 .73105 m .40336 .72942 L .4012 .72963 L F
0 0 0 r
.34991 .67297 m .34954 .67294 L .35156 .67312 L F
.34991 .67297 m .34762 .6737 L .34954 .67294 L F
.431 .261 .548 r
.28962 .61913 m .2893 .62162 L .28784 .62171 L F
.279 .006 .308 r
.2893 .62162 m .28738 .6238 L .28784 .62171 L F
.703 .599 .738 r
.51717 .73436 m .51408 .73222 L .516 .73157 L F
.695 .679 .831 r
.51917 .73207 m .51717 .73436 L .516 .73157 L F
.621 .564 .768 r
.51917 .73207 m .52057 .73543 L .51717 .73436 L F
.331 .061 .346 r
.3023 .66241 m .30358 .66351 L .3043 .66209 L F
.3023 .66241 m .30179 .66425 L .30358 .66351 L F
0 0 0 r
.40361 .7935 m .4048 .79285 L .40283 .7935 L F
.40361 .7935 m .40419 .79334 L .4048 .79285 L F
.825 .842 .861 r
.57906 .67017 m .5751 .6719 L .57807 .66952 L F
.943 .906 .756 r
.57906 .67017 m .57807 .66952 L .57964 .66656 L F
.433 .174 .419 r
.3587 .68909 m .35814 .69116 L .36063 .68859 L F
.845 .931 .885 r
.61265 .64543 m .61086 .64863 L .6127 .64566 L F
.469 .888 .796 r
.61411 .64465 m .61265 .64543 L .6127 .64566 L F
.912 .746 .662 r
.65206 .62585 m .65337 .62919 L .65337 .62709 L F
0 0 0 r
.3273 .71515 m .32855 .71451 L .33043 .71362 L F
.45 .863 .707 r
.33043 .71362 m .33014 .7135 L .33227 .71291 L F
.33043 .71362 m .32855 .71451 L .33014 .7135 L F
.754 .693 .793 r
.70053 .58609 m .70156 .58905 L .70385 .5865 L F
0 .141 .677 r
.70289 .58999 m .70156 .58905 L .70053 .58609 L F
.682 .747 .901 r
.70358 .57525 m .70147 .57613 L .70035 .5748 L F
.748 .438 .458 r
.70035 .5748 m .70428 .57675 L .70358 .57525 L F
.727 .802 .911 r
.70314 .5739 m .70428 .57675 L .70238 .57368 L F
.306 .24 .617 r
.70358 .57525 m .70566 .57466 L .70509 .5746 L F
.433 .743 .993 r
.70446 .57654 m .70505 .57792 L .70358 .57525 L F
.793 .932 .924 r
.70469 .57641 m .70454 .57666 L .70446 .57654 L F
.70458 .57629 m .70446 .57654 L .70358 .57525 L F
.70469 .57641 m .70446 .57654 L .70458 .57629 L F
.306 .24 .617 r
.70358 .57525 m .70458 .57629 L .70566 .57466 L F
.727 .802 .911 r
.70566 .57466 m .70458 .57629 L .70541 .57458 L F
.793 .932 .924 r
.70564 .57475 m .70469 .57641 L .70358 .57525 L F
.70549 .57471 m .70358 .57525 L .70509 .5746 L F
.70564 .57475 m .70529 .57483 L .70549 .57471 L F
.70529 .57483 m .70358 .57525 L .70549 .57471 L F
.727 .802 .911 r
.70541 .57458 m .70528 .57484 L .70314 .5739 L F
.70528 .57484 m .70444 .57651 L .70401 .57565 L F
.70528 .57484 m .70401 .57565 L .70314 .5739 L F
.70458 .57629 m .70444 .57651 L .70541 .57458 L F
.306 .24 .617 r
.70358 .57525 m .70428 .57675 L .70458 .57629 L F
.727 .802 .911 r
.70444 .57651 m .70428 .57675 L .70314 .5739 L F
.433 .743 .993 r
.70454 .57666 m .70464 .57689 L .70446 .57654 L F
.70464 .57689 m .70505 .57792 L .70446 .57654 L F
.70454 .57666 m .70719 .57771 L .70505 .57792 L F
.986 .712 .359 r
.68962 .58837 m .69052 .58946 L .68982 .59089 L F
.338 .677 .978 r
.69052 .58946 m .69215 .58872 L .68962 .58837 L F
.69052 .58946 m .69301 .58974 L .69215 .58872 L F
.449 .501 .82 r
.69052 .58946 m .6935 .59198 L .69301 .58974 L F
.507 .363 .62 r
.347 .70221 m .34871 .69912 L .34735 .69969 L F
.321 .272 .647 r
.6326 .62209 m .63259 .62355 L .63101 .62194 L F
.44 .287 .576 r
.63101 .62194 m .63259 .62355 L .63087 .62422 L F
.877 .479 .273 r
.72896 .74067 m .72813 .74196 L .72728 .74003 L F
.079 0 0 r
.73028 .7412 m .72813 .74196 L .72896 .74067 L F
.604 .317 .455 r
.6157 .68368 m .61608 .68536 L .61324 .68478 L F
.656 .35 .442 r
.6157 .68368 m .61811 .68578 L .61608 .68536 L F
.626 .362 .498 r
.61836 .68366 m .61811 .68578 L .6157 .68368 L F
.308 .442 .834 r
.72941 .61612 m .73226 .61778 L .73108 .6192 L F
.557 .832 .485 r
.73226 .61778 m .72991 .6205 L .73108 .6192 L F
.548 .413 .649 r
.36788 .75909 m .36983 .75584 L .3676 .75703 L F
.827 .711 .737 r
.6315 .64338 m .63225 .64571 L .63 .64559 L F
.779 .55 .588 r
.63225 .64571 m .62963 .64786 L .63 .64559 L F
.63225 .64571 m .63305 .64862 L .62963 .64786 L F
.391 .61 .937 r
.63225 .64571 m .63436 .64603 L .63305 .64862 L F
.848 .814 .817 r
.35644 .69174 m .35246 .69291 L .3549 .69325 L F
.375 0 .004 r
.35644 .69174 m .35731 .69286 L .35814 .69116 L F
.35644 .69174 m .3549 .69325 L .35731 .69286 L F
.812 .734 .777 r
.58292 .68891 m .58379 .69174 L .58237 .69061 L F
.762 .568 .635 r
.58378 .69366 m .58237 .69061 L .58379 .69174 L F
.631 .631 .832 r
.58554 .69137 m .58379 .69174 L .58292 .68891 L F
.606 .365 .526 r
.58554 .69137 m .58378 .69366 L .58379 .69174 L F
0 0 0 r
.70856 .62073 m .71108 .61933 L .71007 .62041 L F
.70856 .62073 m .71007 .62041 L .70737 .61849 L F
.467 .203 .429 r
.62087 .68097 m .62051 .6833 L .61836 .68366 L F
.079 0 .294 r
.62177 .68214 m .62087 .68097 L .62286 .68055 L F
.62177 .68214 m .62051 .6833 L .62087 .68097 L F
.127 .622 .909 r
.44724 .72431 m .44935 .72457 L .45071 .72524 L F
.037 .586 .835 r
.44935 .72457 m .45291 .72523 L .45071 .72524 L F
.028 0 .171 r
.60471 .63466 m .60631 .63406 L .60662 .63195 L F
0 0 0 r
.60426 .63496 m .60631 .63406 L .60471 .63466 L F
.716 .245 0 r
.66288 .58809 m .66207 .58638 L .66065 .58627 L F
.14 0 0 r
.66288 .58809 m .66293 .58886 L .66303 .58883 L F
.716 .245 0 r
.66288 .58809 m .66378 .58896 L .66274 .5874 L F
.724 .255 0 r
.66288 .58809 m .66475 .59039 L .66378 .58896 L F
.213 .463 .88 r
.66288 .58809 m .66544 .58929 L .66475 .59039 L F
.14 0 0 r
.66288 .58809 m .66303 .58883 L .6644 .58841 L F
.716 .245 0 r
.66288 .58809 m .66274 .5874 L .66207 .58638 L F
.317 0 .242 r
.35116 .79322 m .35214 .7936 L .35345 .79136 L F
.704 .412 .479 r
.35345 .79136 m .35599 .79358 L .35549 .79144 L F
.35345 .79136 m .35214 .7936 L .35599 .79358 L F
.512 0 0 r
.48899 .77169 m .4909 .77231 L .49225 .7722 L F
.705 .228 .114 r
.4909 .77231 m .49467 .7741 L .49225 .7722 L F
.159 0 0 r
.46049 .73596 m .45748 .73565 L .45845 .73576 L F
.74 .219 0 r
.71443 .70679 m .71336 .70481 L .71195 .70497 L F
.71443 .70679 m .71552 .70696 L .71336 .70481 L F
.207 0 0 r
.44148 .7727 m .4421 .77368 L .44352 .77221 L F
.44148 .7727 m .44003 .77419 L .4421 .77368 L F
.234 0 0 r
.45751 .76901 m .45891 .76927 L .45981 .7688 L F
.45751 .76901 m .45682 .76967 L .45891 .76927 L F
.348 .789 .962 r
.47273 .72538 m .47467 .72516 L .476 .72559 L F
.54 .881 .987 r
.476 .72559 m .47695 .72447 L .47834 .72498 L F
.476 .72559 m .47467 .72516 L .47695 .72447 L F
.693 .634 .786 r
.50156 .72919 m .49813 .72625 L .50037 .7258 L F
.679 .63 .794 r
.50361 .72625 m .50156 .72919 L .50037 .7258 L F
.759 .742 .837 r
.50498 .74516 m .50873 .74532 L .50695 .74292 L F
.408 .495 .837 r
.50873 .74532 m .50925 .74234 L .50695 .74292 L F
.50873 .74532 m .5104 .74544 L .50925 .74234 L F
.739 .574 .669 r
.49502 .875 m .49673 .87217 L .49341 .8719 L F
.552 .559 .815 r
.66267 .61586 m .66458 .61534 L .66157 .61471 L F
0 .048 .567 r
.6613 .61424 m .66267 .61586 L .66157 .61471 L F
.855 .775 .772 r
.65921 .61595 m .66267 .61586 L .6613 .61424 L F
.65921 .61595 m .66009 .61864 L .66267 .61586 L F
.644 .581 .769 r
.66267 .61586 m .66604 .61673 L .66458 .61534 L F
.784 .67 .738 r
.57476 .67797 m .57599 .68093 L .57311 .68016 L F
.814 .583 .588 r
.57601 .68345 m .57311 .68016 L .57599 .68093 L F
.764 .549 .606 r
.57932 .68366 m .57601 .68345 L .57599 .68093 L F
.196 .175 .607 r
.52559 .73783 m .5248 .73946 L .52351 .7378 L F
.57 .893 .987 r
.41152 .77958 m .4094 .78037 L .40817 .77997 L F
.93 .829 .723 r
.63711 .63161 m .63934 .62942 L .63881 .63264 L F
.418 .207 .483 r
.37607 .74296 m .37575 .74517 L .37785 .74245 L F
.763 .564 .628 r
.33944 .80722 m .33977 .81054 L .3418 .80836 L F
.545 .762 .978 r
.69864 .64205 m .69842 .6407 L .69559 .64111 L F
.718 .851 .945 r
.69864 .64205 m .70034 .63941 L .69842 .6407 L F
.69864 .64205 m .70156 .64039 L .70034 .63941 L F
.54 .29 .485 r
.38003 .73967 m .38269 .7373 L .38048 .7377 L F
.617 .403 .569 r
.60268 .68633 m .60473 .6884 L .60257 .68823 L F
.689 .395 .471 r
.6049 .68656 m .60473 .6884 L .60268 .68633 L F
.212 .027 .399 r
.62764 .61077 m .62964 .60975 L .62939 .60777 L F
.339 .21 .555 r
.62763 .61296 m .62964 .60975 L .62764 .61077 L F
.395 .203 .498 r
.34476 .70459 m .34682 .70466 L .347 .70221 L F
.354 .069 .335 r
.34476 .70459 m .34606 .70641 L .34682 .70466 L F
.34476 .70459 m .34422 .70708 L .34606 .70641 L F
.51 .285 .51 r
.38377 .68128 m .38188 .68602 L .38239 .68265 L F
.471 .827 .996 r
.72329 .71604 m .72003 .71582 L .72096 .71612 L F
.562 .795 .986 r
.34541 .65021 m .34486 .65173 L .34366 .65022 L F
.34541 .65021 m .34685 .65124 L .34486 .65173 L F
.332 .791 .944 r
.47729 .73388 m .47382 .73381 L .47514 .73426 L F
.321 .807 .868 r
.38056 .8016 m .38266 .80142 L .38212 .80182 L F
.032 0 0 r
.38266 .80142 m .38418 .80121 L .38212 .80182 L F
.38266 .80142 m .38544 .7994 L .38418 .80121 L F
.523 .104 .188 r
.46207 .76844 m .46424 .7686 L .4655 .76687 L F
.459 .019 .115 r
.46424 .7686 m .46775 .76692 L .4655 .76687 L F
0 .048 .567 r
.6613 .61424 m .66157 .61471 L .66116 .61279 L F
.169 .621 .937 r
.66157 .61471 m .66332 .61441 L .66116 .61279 L F
.7 .976 .779 r
.6646 .61269 m .66333 .6138 L .66332 .61441 L F
.574 .33 .508 r
.66116 .61279 m .66332 .61441 L .6613 .61424 L F
.176 0 0 r
.66195 .61501 m .6613 .61424 L .66332 .61441 L F
.7 .976 .779 r
.66333 .6138 m .66195 .61501 L .66332 .61441 L F
.169 .621 .937 r
.66157 .61471 m .66331 .61507 L .66332 .61441 L F
.66331 .61507 m .66458 .61534 L .66332 .61441 L F
.622 .617 .825 r
.4863 .73426 m .48972 .73663 L .48823 .73422 L F
.639 .689 .881 r
.48823 .73422 m .48972 .73663 L .49188 .73463 L F
.627 .634 .838 r
.48972 .73663 m .4927 .73779 L .49188 .73463 L F
.562 .904 .976 r
.6899 .64219 m .69369 .64169 L .69263 .64117 L F
.539 .863 .995 r
.69369 .64169 m .69398 .64042 L .69263 .64117 L F
.69369 .64169 m .69559 .64111 L .69398 .64042 L F
.846 .791 .798 r
.65211 .64543 m .6547 .64541 L .65408 .64271 L F
.853 .761 .76 r
.65246 .64869 m .6547 .64541 L .65211 .64543 L F
.837 .786 .803 r
.65408 .64271 m .6547 .64541 L .65665 .64262 L F
.894 .857 .799 r
.70542 .58253 m .70593 .58362 L .70734 .5802 L F
0 0 0 r
.42742 .72423 m .42948 .72412 L .4308 .72404 L F
.351 0 0 r
.42948 .72412 m .43288 .72406 L .4308 .72404 L F
.27 0 .195 r
.61987 .63838 m .61935 .63962 L .61737 .6405 L F
.345 .001 .231 r
.61987 .63838 m .6219 .63772 L .61935 .63962 L F
.631 .642 .843 r
.70442 .6293 m .70235 .6302 L .70111 .62816 L F
0 0 0 r
.32597 .6789 m .32543 .67883 L .32741 .67853 L F
.32597 .6789 m .32416 .68007 L .32543 .67883 L F
.392 .104 .352 r
.36677 .70003 m .36608 .70185 L .36418 .70234 L F
.466 .239 .484 r
.36838 .69919 m .36608 .70185 L .36677 .70003 L F
.011 0 0 r
.33769 .7256 m .33576 .72653 L .33855 .7248 L F
.186 0 0 r
.33952 .725 m .33855 .7248 L .34036 .72395 L F
.33952 .725 m .33769 .7256 L .33855 .7248 L F
.565 .881 .992 r
.67984 .60923 m .68076 .60974 L .68264 .60905 L F
.815 .345 .099 r
.50983 .77799 m .51166 .78037 L .51332 .78083 L F
.919 .594 .411 r
.51166 .78037 m .51202 .78228 L .51332 .78083 L F
.128 0 0 r
.51332 .78083 m .51396 .78162 L .51591 .78075 L F
.51332 .78083 m .51202 .78228 L .51396 .78162 L F
.691 .639 .792 r
.52259 .73464 m .52351 .7378 L .52056 .737 L F
.502 .406 .678 r
.5252 .7339 m .52351 .7378 L .52259 .73464 L F
.5252 .7339 m .52559 .73783 L .52351 .7378 L F
.792 .479 .458 r
.70885 .70423 m .71144 .70274 L .70866 .70225 L F
.70885 .70423 m .71195 .70497 L .71144 .70274 L F
.167 0 0 r
.48114 .77575 m .4797 .77554 L .47771 .77516 L F
.389 0 0 r
.48341 .77678 m .4797 .77554 L .48114 .77575 L F
.551 .353 .565 r
.36447 .76722 m .36631 .769 L .36646 .76682 L F
.36447 .76722 m .36432 .76937 L .36631 .769 L F
.743 .461 .503 r
.35549 .79144 m .35599 .79358 L .3583 .79365 L F
.577 .578 .817 r
.4927 .73779 m .49368 .73438 L .49188 .73463 L F
.4927 .73779 m .4949 .73741 L .49368 .73438 L F
.838 .709 .721 r
.60487 .65914 m .60435 .66136 L .60719 .66136 L F
.838 .667 .67 r
.60435 .66136 m .60593 .6646 L .60719 .66136 L F
.613 .916 .979 r
.51688 .7436 m .51835 .74261 L .51567 .7451 L F
.921 .814 .724 r
.67779 .61043 m .67662 .61296 L .67814 .61369 L F
.937 .582 .317 r
.67722 .61523 m .67814 .61369 L .67662 .61296 L F
.67722 .61523 m .67875 .61594 L .67814 .61369 L F
.848 .504 .402 r
.7058 .70126 m .70671 .6993 L .70533 .69925 L F
.7058 .70126 m .70866 .70225 L .70671 .6993 L F
.54 .427 .674 r
.36605 .76184 m .36837 .76385 L .36811 .76145 L F
.36605 .76184 m .36638 .76426 L .36837 .76385 L F
.621 .875 .989 r
.35085 .80951 m .35158 .80794 L .34985 .8093 L F
.35085 .80951 m .354 .80856 L .35158 .80794 L F
.745 .781 .285 r
.36305 .68362 m .36404 .68023 L .3622 .68081 L F
.36305 .68362 m .3633 .68239 L .36404 .68023 L F
.884 .88 .825 r
.3628 .68587 m .3633 .68239 L .36305 .68362 L F
.654 .416 .546 r
.60905 .68615 m .60473 .6884 L .6049 .68656 L F
.809 .673 .714 r
.6557 .63999 m .65729 .64078 L .65598 .63763 L F
.846 .724 .728 r
.65408 .64271 m .65729 .64078 L .6557 .63999 L F
.65408 .64271 m .65665 .64262 L .65729 .64078 L F
.712 .785 .909 r
.37411 .80446 m .37532 .80629 L .378 .80492 L F
.401 .168 .442 r
.35116 .79322 m .35248 .79556 L .35214 .7936 L F
.35116 .79322 m .35025 .79651 L .35248 .79556 L F
.798 .691 .747 r
.58603 .68901 m .58292 .68891 L .5849 .68596 L F
.631 .631 .832 r
.58554 .69137 m .58292 .68891 L .58603 .68901 L F
.657 .487 .642 r
.58603 .68901 m .586 .69176 L .58554 .69137 L F
.694 .42 .504 r
.58952 .69355 m .58608 .69361 L .5856 .6916 L F
.58593 .69158 m .5856 .6916 L .58554 .69137 L F
.722 .541 .644 r
.58929 .69146 m .586 .69176 L .586 .69158 L F
.694 .42 .504 r
.58952 .69355 m .586 .69176 L .58929 .69146 L F
.58952 .69355 m .58554 .69137 L .586 .69176 L F
.58952 .69355 m .5856 .6916 L .58593 .69158 L F
.722 .541 .644 r
.58922 .6914 m .586 .69158 L .58603 .68901 L F
.58929 .69146 m .586 .69158 L .58922 .6914 L F
.345 0 0 r
.42929 .74098 m .42758 .74226 L .42537 .74248 L F
.587 .205 .284 r
.4305 .74063 m .42758 .74226 L .42929 .74098 L F
.831 .67 .127 r
.66795 .60235 m .668 .60121 L .66745 .60004 L F
.927 .797 .329 r
.66745 .60004 m .66754 .59651 L .66754 .59902 L F
.935 .611 .161 r
.66706 .60085 m .66745 .60004 L .66754 .59902 L F
.705 .853 .953 r
.70564 .63728 m .70692 .63842 L .70887 .6372 L F
.565 .402 .619 r
.3589 .78067 m .36114 .78037 L .36094 .77782 L F
.56 .345 .544 r
.35864 .78287 m .36114 .78037 L .3589 .78067 L F
.7 .611 .754 r
.5793 .686 m .57601 .68345 L .57932 .68366 L F
.67 .513 .663 r
.58177 .68559 m .5793 .686 L .57932 .68366 L F
.307 0 .182 r
.4045 .75057 m .4041 .75085 L .40236 .75065 L F
.554 .341 .545 r
.40009 .75103 m .40145 .75229 L .39758 .75358 L F
.40145 .75229 m .40213 .75292 L .39962 .75329 L F
.40145 .75229 m .39962 .75329 L .39758 .75358 L F
.4005 .75101 m .40213 .75292 L .40009 .75103 L F
.723 .341 .325 r
.40141 .75267 m .40213 .75292 L .40032 .75079 L F
.307 0 .182 r
.4041 .75085 m .40357 .75244 L .40141 .75267 L F
.4045 .75057 m .40446 .75065 L .4041 .75085 L F
.40446 .75065 m .40357 .75244 L .4041 .75085 L F
.4041 .75085 m .40141 .75267 L .40222 .75093 L F
.4041 .75085 m .40222 .75093 L .40236 .75065 L F
.554 .341 .545 r
.40032 .75079 m .4005 .75101 L .40009 .75103 L F
.723 .341 .325 r
.40141 .75267 m .40032 .75079 L .40236 .75065 L F
.846 .954 .884 r
.64826 .65355 m .64474 .65545 L .64473 .65612 L F
.64826 .65355 m .64734 .65306 L .64474 .65545 L F
.674 .976 .833 r
.64826 .65355 m .64928 .65223 L .64734 .65306 L F
.64826 .65355 m .65082 .65176 L .64928 .65223 L F
.684 .382 .457 r
.63272 .63486 m .62938 .63683 L .63048 .63482 L F
.795 .559 .581 r
.51408 .73222 m .51029 .73397 L .51075 .73236 L F
.51408 .73222 m .51359 .73467 L .51029 .73397 L F
.552 .535 .79 r
.516 .73157 m .51408 .73222 L .51263 .72886 L F
.082 0 0 r
.71007 .62041 m .71108 .61933 L .7134 .6186 L F
0 0 0 r
.7134 .6186 m .71108 .61933 L .70978 .62 L F
.426 .793 .995 r
.69344 .71862 m .69502 .71767 L .69241 .71815 L F
.69344 .71862 m .69604 .71835 L .69502 .71767 L F
.69502 .71767 m .69344 .71862 L .69241 .71815 L F
.69502 .71767 m .69604 .71835 L .69344 .71862 L F
.717 .963 .942 r
.38966 .7982 m .39054 .79848 L .39333 .79705 L F
.38966 .7982 m .39333 .79705 L .39155 .79788 L F
0 0 0 r
.39368 .79722 m .39333 .79705 L .3955 .79674 L F
.39368 .79722 m .39155 .79788 L .39333 .79705 L F
.947 .882 .736 r
.60906 .65043 m .61086 .64863 L .60989 .64795 L F
.60906 .65043 m .60929 .65172 L .61086 .64863 L F
.845 .931 .885 r
.61265 .64543 m .60989 .64795 L .61086 .64863 L F
.807 .326 0 r
.50874 .77702 m .51166 .78037 L .50983 .77799 L F
0 0 0 r
.44444 .78187 m .44599 .78077 L .44798 .78007 L F
.524 .175 .318 r
.51765 .77902 m .52097 .77728 L .5183 .77789 L F
.706 .565 .693 r
.6612 .62411 m .66418 .62637 L .66477 .6245 L F
.6612 .62411 m .6625 .62741 L .66418 .62637 L F
.427 .212 .483 r
.37819 .74022 m .37785 .74245 L .38003 .73967 L F
.283 0 .047 r
.38418 .80121 m .38544 .7994 L .38747 .79885 L F
.958 .63 .236 r
.67147 .60241 m .67092 .60384 L .67099 .60074 L F
.67147 .60241 m .67197 .60489 L .67092 .60384 L F
.422 .621 .934 r
.38332 .66902 m .38249 .67046 L .38142 .66894 L F
.496 .716 .969 r
.38332 .66902 m .38483 .67024 L .38249 .67046 L F
.738 .335 .287 r
.50574 .78304 m .50415 .78344 L .50238 .78241 L F
.78 .357 .244 r
.50574 .78304 m .50495 .78471 L .50415 .78344 L F
.50574 .78304 m .50771 .78533 L .50495 .78471 L F
.662 .636 .813 r
.39183 .76618 m .38948 .7668 L .3897 .76644 L F
.65 .562 .742 r
.39279 .7696 m .38948 .7668 L .39183 .76618 L F
.459 .084 .24 r
.60865 .63145 m .61169 .62929 L .60944 .62969 L F
.497 .502 .791 r
.38049 .66595 m .37936 .66868 L .37791 .66458 L F
.479 .481 .781 r
.38049 .66595 m .38142 .66894 L .37936 .66868 L F
.753 .889 .94 r
.71076 .62459 m .70979 .62682 L .70902 .62631 L F
.71076 .62459 m .71238 .62521 L .70979 .62682 L F
.377 .838 .777 r
.40865 .79209 m .41162 .79101 L .41081 .79159 L F
.057 0 0 r
.41381 .79053 m .41287 .79105 L .41162 .79101 L F
.061 0 0 r
.41287 .79105 m .41081 .79159 L .41162 .79101 L F
.617 .546 .752 r
.35515 .67507 m .35692 .68011 L .35888 .67858 L F
.602 .94 .758 r
.35692 .68011 m .35613 .68057 L .35888 .67858 L F
.758 .706 .803 r
.35888 .67858 m .35613 .68057 L .35956 .68089 L F
.62 .587 .795 r
.35613 .68057 m .35963 .68318 L .35956 .68089 L F
.658 .508 .669 r
.35956 .68089 m .3622 .68081 L .36179 .67815 L F
.44 .111 .31 r
.35178 .71744 m .35044 .71617 L .35253 .71571 L F
.35178 .71744 m .34973 .71784 L .35044 .71617 L F
0 .017 .553 r
.71817 .73744 m .72027 .73993 L .71852 .73752 L F
.476 .034 .118 r
.47573 .77488 m .47427 .77658 L .47241 .77572 L F
.499 .052 .12 r
.47771 .77516 m .47427 .77658 L .47573 .77488 L F
.152 0 0 r
.33624 .72764 m .33576 .72653 L .33769 .7256 L F
.33624 .72764 m .3344 .72837 L .33576 .72653 L F
.602 .895 .601 r
.68357 .63546 m .68154 .63751 L .68199 .63679 L F
0 .208 .68 r
.68154 .63751 m .68336 .6385 L .68199 .63679 L F
.68154 .63751 m .68429 .63947 L .68336 .6385 L F
.645 .106 0 r
.73005 .73208 m .72937 .73251 L .72729 .7313 L F
.692 .676 .83 r
.73123 .73747 m .72814 .73663 L .7295 .73293 L F
.541 .57 .833 r
.73274 .73706 m .73123 .73747 L .72988 .73304 L F
.744 .354 .314 r
.72885 .73248 m .73245 .73403 L .72981 .73248 L F
.72946 .73243 m .72981 .73248 L .72969 .73241 L F
.72885 .73248 m .72945 .73248 L .72946 .73243 L F
.371 .839 .829 r
.72878 .7325 m .72587 .73361 L .72877 .7324 L F
.701 .67 .817 r
.7288 .73264 m .72587 .73361 L .72885 .73248 L F
.975 .672 .306 r
.72878 .7325 m .7288 .73264 L .72885 .73248 L F
.7288 .73264 m .7288 .73269 L .72885 .73248 L F
.7288 .73269 m .72881 .73272 L .72881 .73269 L F
.7288 .73269 m .72881 .73269 L .72885 .73248 L F
.701 .67 .817 r
.72946 .73243 m .72878 .73269 L .72885 .73248 L F
.871 .985 .835 r
.72938 .73248 m .72933 .73252 L .72937 .73251 L F
.744 .354 .314 r
.72945 .73248 m .72981 .73248 L .72946 .73243 L F
.701 .67 .817 r
.72969 .73241 m .72933 .73252 L .72946 .73243 L F
.371 .839 .829 r
.72937 .73251 m .72587 .73361 L .72926 .73249 L F
.701 .67 .817 r
.72933 .73252 m .72878 .73269 L .72946 .73243 L F
.371 .839 .829 r
.72895 .73243 m .72878 .7325 L .72877 .7324 L F
.72937 .73251 m .72685 .73202 L .72913 .73237 L F
.871 .985 .835 r
.72969 .73165 m .72798 .7327 L .72933 .73252 L F
.72969 .73165 m .72933 .73252 L .72938 .73248 L F
.975 .672 .306 r
.72878 .7325 m .72885 .73248 L .72587 .73361 L F
.371 .839 .829 r
.72926 .73249 m .72587 .73361 L .72895 .73243 L F
.701 .67 .817 r
.72878 .73269 m .72587 .73361 L .7288 .73264 L F
.975 .672 .306 r
.72798 .7327 m .72878 .7325 L .72838 .73265 L F
.72798 .7327 m .72838 .73265 L .72587 .73361 L F
.371 .839 .829 r
.72877 .7324 m .72587 .73361 L .72685 .73202 L F
.909 .631 .134 r
.72757 .73257 m .72762 .73274 L .72798 .7327 L F
.371 .839 .829 r
.7288 .73269 m .72798 .7327 L .72587 .73361 L F
.701 .67 .817 r
.72878 .73269 m .72814 .73663 L .72587 .73361 L F
.975 .672 .306 r
.7288 .73272 m .72881 .73274 L .72881 .73272 L F
.744 .354 .314 r
.72946 .73243 m .72981 .73248 L .72946 .73243 L F
.541 .57 .833 r
.73274 .73706 m .72988 .73304 L .73022 .73322 L F
.692 .676 .83 r
.73123 .73747 m .7295 .73293 L .72988 .73304 L F
.964 .871 .697 r
.73292 .73649 m .73309 .73907 L .73196 .7381 L F
.73173 .73718 m .73196 .7381 L .73123 .73747 L F
.541 .57 .833 r
.73274 .73706 m .73105 .73449 L .73245 .73403 L F
0 0 .309 r
.73245 .73403 m .73292 .73649 L .73274 .73706 L F
.73245 .73403 m .73292 .73649 L .73274 .73706 L F
.964 .871 .697 r
.73292 .73649 m .73123 .73747 L .73274 .73706 L F
.73292 .73649 m .73196 .7381 L .73173 .73718 L F
.541 .57 .833 r
.73105 .73449 m .73022 .73322 L .73079 .73343 L F
.73105 .73449 m .73079 .73343 L .73245 .73403 L F
.744 .354 .314 r
.72952 .73297 m .7307 .73339 L .73066 .73326 L F
.73066 .73326 m .73072 .73349 L .73245 .73403 L F
.541 .57 .833 r
.73022 .73322 m .72969 .73241 L .73245 .73403 L F
.744 .354 .314 r
.7295 .73293 m .72952 .73297 L .73066 .73326 L F
.72952 .73297 m .73127 .73556 L .7307 .73339 L F
.72912 .73282 m .72912 .73283 L .7295 .73293 L F
.72912 .73283 m .73127 .73556 L .7295 .73293 L F
.744 .354 .315 r
.72885 .73248 m .72881 .73274 L .72912 .73282 L F
.701 .67 .817 r
.72969 .73241 m .7295 .73293 L .72878 .73269 L F
.7295 .73293 m .72923 .73367 L .72881 .73274 L F
.72923 .73367 m .72814 .73663 L .72878 .73273 L F
.72881 .73274 m .72878 .73273 L .72878 .73269 L F
.72923 .73367 m .72878 .73273 L .72881 .73274 L F
.744 .354 .315 r
.72881 .73274 m .72881 .73274 L .72912 .73282 L F
.72881 .73274 m .72835 .73533 L .72912 .73283 L F
.72881 .73274 m .72912 .73283 L .72912 .73282 L F
.72912 .73283 m .72835 .73533 L .73127 .73556 L F
.72912 .73282 m .72912 .73283 L .72912 .73283 L F
.72912 .73283 m .72835 .73533 L .72912 .73283 L F
.701 .67 .817 r
.72912 .73283 m .72881 .73274 L .72881 .73274 L F
.7295 .73293 m .72881 .73274 L .72912 .73283 L F
.7295 .73293 m .72881 .73274 L .72878 .73269 L F
.975 .672 .306 r
.72798 .7327 m .72835 .73533 L .72881 .73274 L F
.72798 .7327 m .72881 .73274 L .7288 .73272 L F
.909 .631 .134 r
.72762 .73274 m .72835 .73533 L .72798 .7327 L F
.975 .672 .306 r
.72798 .7327 m .72881 .73272 L .72878 .7325 L F
.371 .839 .829 r
.72937 .73251 m .72798 .7327 L .7288 .73269 L F
.871 .985 .835 r
.73027 .73011 m .73009 .73031 L .72969 .73165 L F
.371 .839 .829 r
.72913 .73237 m .72685 .73202 L .72729 .7313 L F
.871 .985 .835 r
.73009 .73031 m .72798 .7327 L .72969 .73165 L F
.541 .57 .833 r
.73022 .73322 m .72988 .73304 L .72969 .73241 L F
.744 .354 .314 r
.73072 .73349 m .73127 .73556 L .73224 .73431 L F
.73072 .73349 m .73224 .73431 L .73245 .73403 L F
.72885 .73248 m .72912 .73282 L .73066 .73326 L F
.692 .676 .83 r
.72988 .73304 m .7295 .73293 L .72969 .73241 L F
.269 .361 .774 r
.73005 .73208 m .73245 .73403 L .7317 .73109 L F
.73005 .73208 m .7317 .73109 L .72937 .73251 L F
.554 .265 .431 r
.41533 .74531 m .4124 .74757 L .41314 .7456 L F
.685 .626 .784 r
.36233 .80829 m .36327 .80442 L .36119 .80568 L F
.36233 .80829 m .36458 .80748 L .36327 .80442 L F
.58 .456 .676 r
.3628 .77266 m .36307 .77506 L .36493 .77229 L F
.621 .853 .987 r
.71869 .60236 m .71504 .59983 L .71749 .59914 L F
.71869 .60236 m .71507 .60218 L .71504 .59983 L F
.71507 .60218 m .71869 .60236 L .7177 .60436 L F
.53 .554 .824 r
.7196 .59891 m .71869 .60236 L .71749 .59914 L F
.7196 .59891 m .72081 .60201 L .71869 .60236 L F
.379 .026 .235 r
.71869 .60236 m .72025 .60377 L .7177 .60436 L F
.71869 .60236 m .72081 .60201 L .72025 .60377 L F
.676 .55 .704 r
.49171 .87439 m .49341 .8719 L .49148 .87396 L F
.62 .587 .795 r
.35613 .68057 m .35751 .68406 L .35963 .68318 L F
.521 .337 .572 r
.35963 .68318 m .35943 .6856 L .35751 .68406 L F
.254 0 .236 r
.60662 .63195 m .60819 .63313 L .60865 .63145 L F
.60662 .63195 m .60631 .63406 L .60819 .63313 L F
.596 .823 .986 r
.65082 .65176 m .65182 .64999 L .64928 .65223 L F
.529 .388 .634 r
.65246 .64869 m .65302 .65103 L .65082 .65176 L F
.596 .823 .986 r
.65082 .65176 m .65302 .65103 L .65182 .64999 L F
.555 .763 .975 r
.36038 .67701 m .36179 .67815 L .36269 .67683 L F
.244 .337 .761 r
.36179 .67815 m .36404 .68023 L .36269 .67683 L F
.467 .373 .666 r
.3622 .68081 m .36404 .68023 L .36179 .67815 L F
.434 0 0 r
.4343 .74054 m .433 .74134 L .4305 .74063 L F
.838 .84 .847 r
.65485 .62114 m .65829 .62002 L .6569 .6183 L F
.74 .757 .866 r
.6569 .6183 m .65829 .62002 L .66009 .61864 L F
.024 0 0 r
.47055 .73502 m .4696 .73488 L .47167 .73423 L F
.47055 .73502 m .4682 .73564 L .4696 .73488 L F
.331 0 .119 r
.29674 .66691 m .29864 .66665 L .29992 .66479 L F
.316 0 .133 r
.29864 .66665 m .30179 .66425 L .29992 .66479 L F
.694 .743 .889 r
.48718 .72477 m .4838 .72421 L .48589 .72323 L F
.657 .727 .901 r
.48918 .724 m .48718 .72477 L .48589 .72323 L F
.443 .185 .426 r
.36418 .70234 m .36371 .70458 L .36172 .70499 L F
.473 .212 .437 r
.36575 .70415 m .36418 .70234 L .36608 .70185 L F
.36575 .70415 m .36371 .70458 L .36418 .70234 L F
.385 .729 .99 r
.40829 .76925 m .40753 .77014 L .40581 .76918 L F
.40829 .76925 m .40753 .77014 L .40581 .76918 L F
.63 .09 0 r
.72431 .71001 m .72719 .71086 L .72562 .70995 L F
.533 .331 .551 r
.37365 .74555 m .37559 .74751 L .37575 .74517 L F
.467 .327 .606 r
.37376 .74794 m .37559 .74751 L .37365 .74555 L F
.619 .947 .94 r
.70302 .6014 m .70824 .59956 L .70619 .60022 L F
.679 .747 .903 r
.69374 .58307 m .69497 .58395 L .69165 .58346 L F
.779 .746 .823 r
.6973 .58137 m .69497 .58395 L .69374 .58307 L F
0 0 0 r
.4178 .78972 m .41975 .78916 L .41774 .78963 L F
.259 .764 .739 r
.41774 .78963 m .41975 .78916 L .42172 .78855 L F
.41774 .78963 m .42172 .78855 L .41987 .7893 L F
.107 0 0 r
.41987 .7893 m .41771 .78957 L .41774 .78963 L F
.41771 .78957 m .4168 .78969 L .41774 .78963 L F
0 0 0 r
.41588 .79026 m .4178 .78972 L .41774 .78963 L F
.246 .382 .803 r
.38694 .80653 m .38959 .8092 L .38926 .80695 L F
.109 .617 .896 r
.70511 .73085 m .70814 .73161 L .70471 .73213 L F
0 0 .456 r
.7053 .73372 m .70511 .73085 L .70471 .73213 L F
.545 .182 .302 r
.51774 .79126 m .52083 .78976 L .52021 .79139 L F
.331 .078 .371 r
.52083 .78976 m .52275 .78834 L .52242 .79072 L F
.349 0 .22 r
.52021 .79139 m .52083 .78976 L .52242 .79072 L F
.696 .643 .793 r
.49251 .87961 m .49467 .8774 L .49252 .87858 L F
.314 0 .056 r
.34014 .70808 m .34073 .70944 L .34234 .70783 L F
.34014 .70808 m .33874 .70989 L .34073 .70944 L F
.84 .73 .743 r
.69925 .57843 m .69608 .57997 L .69839 .57688 L F
.69925 .57843 m .6973 .58137 L .69608 .57997 L F
.786 .781 .848 r
.70147 .57613 m .69925 .57843 L .69839 .57688 L F
.761 .455 .466 r
.49783 .77478 m .49991 .77729 L .50116 .77496 L F
.67 .346 .416 r
.50116 .77496 m .49991 .77729 L .5033 .77695 L F
.692 .205 .089 r
.69791 .72682 m .69821 .72704 L .6971 .72787 L F
.69821 .72704 m .70053 .72874 L .6971 .72787 L F
.655 .387 .502 r
.69625 .72855 m .69642 .72838 L .6971 .72787 L F
.692 .205 .089 r
.69791 .72682 m .6971 .72787 L .69924 .72555 L F
.655 .387 .502 r
.69642 .72838 m .69924 .72555 L .6971 .72787 L F
.676 .55 .704 r
.49171 .87439 m .49502 .875 L .49341 .8719 L F
.613 .453 .641 r
.49252 .87858 m .49502 .875 L .49171 .87439 L F
.154 .648 .915 r
.35087 .6512 m .35019 .65169 L .34876 .65115 L F
.35087 .6512 m .35255 .65192 L .35019 .65169 L F
.273 0 .25 r
.5293 .78462 m .53074 .78159 L .53183 .78231 L F
.643 .765 .937 r
.69399 .59436 m .69736 .59506 L .69626 .5936 L F
.628 .741 .929 r
.69626 .5936 m .69736 .59506 L .6996 .59445 L F
.608 .593 .81 r
.4949 .73741 m .49604 .74035 L .49824 .7399 L F
.589 .57 .8 r
.49604 .74035 m .49934 .74298 L .49824 .7399 L F
.107 .654 .826 r
.43501 .72404 m .43847 .72422 L .43632 .7241 L F
.64 .341 .447 r
.61324 .68478 m .61247 .68787 L .61027 .68593 L F
.649 .376 .492 r
.61608 .68536 m .61247 .68787 L .61324 .68478 L F
.436 .551 .874 r
.29192 .61066 m .29162 .6133 L .2898 .61116 L F
.29192 .61066 m .29307 .61294 L .29162 .6133 L F
.538 .436 .686 r
.29307 .61294 m .2916 .61609 L .29162 .6133 L F
.663 .784 .939 r
.47729 .73388 m .48053 .73434 L .4793 .73347 L F
.695 .866 .963 r
.4793 .73347 m .48053 .73434 L .48299 .73295 L F
0 0 0 r
.42261 .77611 m .4241 .77525 L .42471 .77518 L F
.42261 .77611 m .42169 .7773 L .4241 .77525 L F
.666 .6 .771 r
.52259 .73464 m .52056 .737 L .52057 .73543 L F
.597 .8 .977 r
.68923 .58058 m .68906 .58357 L .68733 .58093 L F
.384 .207 .514 r
.39934 .75546 m .39758 .75358 L .40213 .75292 L F
.39934 .75546 m .39726 .75668 L .39758 .75358 L F
.168 0 .05 r
.61942 .66431 m .6216 .66371 L .62222 .66211 L F
0 0 0 r
.62222 .66211 m .62345 .66089 L .624 .65908 L F
.62234 .66273 m .62222 .66211 L .6216 .66371 L F
.62234 .66273 m .62345 .66089 L .62222 .66211 L F
.757 .762 .856 r
.70044 .58384 m .70163 .58026 L .69969 .5831 L F
.985 .728 .346 r
.69969 .5831 m .70053 .58609 L .70044 .58384 L F
0 .343 .813 r
.70385 .5865 m .70044 .58384 L .70053 .58609 L F
.922 .865 .766 r
.72987 .71857 m .72722 .72057 L .72866 .71752 L F
.72987 .71857 m .72813 .72118 L .72722 .72057 L F
.602 .479 .685 r
.69166 .5949 m .69399 .59436 L .6935 .59198 L F
.282 .722 .964 r
.33801 .64968 m .33916 .64942 L .34168 .65041 L F
.482 .695 .962 r
.34214 .64869 m .34168 .65041 L .33916 .64942 L F
.34214 .64869 m .34366 .65022 L .34168 .65041 L F
.99 .872 .528 r
.67238 .60815 m .67126 .60954 L .67196 .60746 L F
.518 .274 .485 r
.53476 .77715 m .53461 .7804 L .53226 .78056 L F
.355 .183 .505 r
.53476 .77715 m .53692 .77458 L .53714 .77698 L F
.454 .233 .487 r
.53714 .77698 m .53461 .7804 L .53476 .77715 L F
.712 .599 .728 r
.33568 .80693 m .33702 .80793 L .33944 .80722 L F
.587 .58 .812 r
.35724 .78631 m .35917 .78487 L .35656 .78506 L F
.35724 .78631 m .35942 .78603 L .35917 .78487 L F
.877 .702 .661 r
.69719 .71017 m .69558 .71267 L .69437 .71117 L F
.712 .599 .728 r
.33568 .80693 m .33944 .80722 L .33782 .80435 L F
.484 .57 .866 r
.33782 .80435 m .33944 .80722 L .34075 .8069 L F
.526 .035 .034 r
.44512 .77114 m .44772 .77157 L .44908 .77042 L F
.363 0 0 r
.44772 .77157 m .45099 .77086 L .44908 .77042 L F
.187 0 0 r
.686 .63498 m .68357 .63546 L .68199 .63679 L F
.745 .581 .672 r
.63812 .63484 m .64168 .6351 L .64124 .63731 L F
.663 .126 0 r
.33599 .84504 m .33658 .84516 L .33638 .84502 L F
.718 .332 0 r
.67066 .6242 m .67115 .62565 L .67022 .62356 L F
.67066 .6242 m .67215 .62749 L .67115 .62565 L F
.234 0 .25 r
.63126 .66941 m .62888 .67193 L .62919 .67012 L F
.776 .641 .711 r
.69811 .71068 m .69719 .71017 L .69901 .70953 L F
.69811 .71068 m .69779 .71317 L .69719 .71017 L F
.877 .702 .661 r
.69719 .71017 m .69779 .71317 L .69558 .71267 L F
.549 0 0 r
.69779 .71317 m .697 .71324 L .69558 .71267 L F
.463 .176 .391 r
.69811 .71068 m .697 .71324 L .69779 .71317 L F
.69811 .71068 m .69944 .71407 L .697 .71324 L F
.413 0 .123 r
.70191 .7097 m .69811 .71068 L .69901 .70953 L F
.70191 .7097 m .70134 .71162 L .69811 .71068 L F
.395 .143 .41 r
.70134 .71162 m .69944 .71407 L .69811 .71068 L F
.713 .673 .81 r
.49282 .72517 m .48918 .724 L .49137 .72364 L F
.651 .76 .929 r
.4948 .72428 m .49282 .72517 L .49137 .72364 L F
.147 .672 .875 r
.72628 .71635 m .72556 .71608 L .72329 .71604 L F
.386 0 0 r
.72866 .71752 m .72556 .71608 L .72628 .71635 L F
.06 .607 .838 r
.33466 .64914 m .33801 .64968 L .33605 .64993 L F
.597 .744 .947 r
.51029 .73397 m .50942 .73545 L .50889 .73455 L F
.51029 .73397 m .51156 .73497 L .50942 .73545 L F
.483 .341 .611 r
.36094 .77782 m .36287 .77983 L .36325 .77745 L F
.36094 .77782 m .36114 .78037 L .36287 .77983 L F
.359 .082 .349 r
.61737 .6405 m .6189 .6419 L .61658 .64247 L F
.61737 .6405 m .61935 .63962 L .6189 .6419 L F
0 .194 .725 r
.73117 .715 m .73308 .71783 L .7321 .71583 L F
.51 .285 .51 r
.38377 .68128 m .38416 .68547 L .38188 .68602 L F
.538 .282 .475 r
.38681 .68021 m .38377 .68128 L .38525 .6807 L F
.38681 .68021 m .38606 .68195 L .38377 .68128 L F
.43 .229 .504 r
.38611 .68473 m .38377 .68128 L .38606 .68195 L F
.38611 .68473 m .38416 .68547 L .38377 .68128 L F
0 0 0 r
.3273 .71515 m .32671 .71551 L .32855 .71451 L F
.747 .398 0 r
.71183 .73687 m .71145 .73624 L .71054 .73381 L F
.73 .233 0 r
.71469 .74014 m .71375 .73946 L .71183 .73687 L F
.585 .132 0 r
.71183 .73687 m .7128 .73822 L .71145 .73624 L F
.71183 .73687 m .71375 .73946 L .7128 .73822 L F
.501 .612 .894 r
.6738 .59194 m .67131 .59018 L .67296 .58873 L F
0 0 .487 r
.67296 .58873 m .67388 .591 L .6738 .59194 L F
0 0 .319 r
.67385 .59124 m .6738 .59194 L .67388 .591 L F
.67385 .59124 m .67453 .59403 L .6738 .59194 L F
.662 .636 .813 r
.39183 .76618 m .3897 .76644 L .392 .7653 L F
0 0 0 r
.64072 .59425 m .64257 .59363 L .64357 .59227 L F
.012 0 0 r
.64357 .59227 m .64441 .59276 L .64507 .59088 L F
.64357 .59227 m .64257 .59363 L .64441 .59276 L F
.529 .4 .648 r
.53845 .7695 m .53664 .77231 L .53618 .7705 L F
.53845 .7695 m .53878 .7722 L .53664 .77231 L F
0 0 .403 r
.53775 .77383 m .53664 .77231 L .53878 .7722 L F
.53775 .77383 m .53692 .77458 L .53664 .77231 L F
.784 .681 .75 r
.66458 .61534 m .66825 .61388 L .66714 .61318 L F
.66458 .61534 m .66604 .61673 L .66825 .61388 L F
.569 .338 .526 r
.64451 .61074 m .64683 .61245 L .64467 .61194 L F
.645 .966 .827 r
.32098 .73527 m .31885 .73605 L .31815 .73712 L F
.283 .769 .686 r
.32083 .73527 m .32098 .73527 L .32268 .73458 L F
.32083 .73527 m .31885 .73605 L .32098 .73527 L F
.616 .733 .93 r
.48299 .73295 m .4863 .73426 L .48494 .73239 L F
.475 .569 .87 r
.4863 .73426 m .48696 .73157 L .48494 .73239 L F
.4863 .73426 m .48823 .73422 L .48696 .73157 L F
.437 .083 .264 r
.53618 .7705 m .5335 .77264 L .53547 .77196 L F
.133 0 0 r
.53695 .77126 m .53618 .7705 L .53547 .77196 L F
.53695 .77126 m .53845 .7695 L .53618 .7705 L F
.953 .852 .704 r
.73331 .72584 m .73357 .72863 L .73445 .72665 L F
.779 .818 .883 r
.3362 .80558 m .33568 .80693 L .33782 .80435 L F
.497 .268 .497 r
.61468 .66732 m .61684 .66688 L .61687 .66475 L F
.411 .092 .311 r
.61684 .66688 m .61942 .66431 L .61687 .66475 L F
.377 0 .03 r
.45909 .77718 m .45766 .77881 L .45556 .77893 L F
.468 .044 .15 r
.46122 .77704 m .45766 .77881 L .45909 .77718 L F
.534 .812 .997 r
.31327 .71747 m .31137 .71792 L .31004 .7172 L F
.164 .558 .931 r
.68692 .58751 m .68861 .58733 L .68569 .58683 L F
.68692 .58751 m .68962 .58837 L .68861 .58733 L F
.47 .249 .495 r
.37541 .69154 m .37541 .69414 L .3734 .69455 L F
.459 .24 .494 r
.37742 .69344 m .37541 .69154 L .37764 .69079 L F
.37742 .69344 m .37541 .69414 L .37541 .69154 L F
.652 .569 .749 r
.39574 .75875 m .39256 .75604 L .39491 .75532 L F
.552 .444 .685 r
.39749 .75815 m .39491 .75532 L .39726 .75668 L F
.39749 .75815 m .39574 .75875 L .39491 .75532 L F
.318 0 0 r
.45363 .77854 m .4523 .77974 L .45014 .7799 L F
.206 0 0 r
.45438 .77934 m .45363 .77854 L .45556 .77893 L F
.45438 .77934 m .4523 .77974 L .45363 .77854 L F
.994 .772 .493 r
.73411 .71838 m .73421 .72387 L .73359 .72101 L F
.494 .518 .81 r
.35942 .78603 m .36044 .78887 L .36201 .78792 L F
.423 .39 .718 r
.36044 .78887 m .36263 .79068 L .36201 .78792 L F
.36044 .78887 m .36104 .79128 L .36263 .79068 L F
.385 .087 .33 r
.63995 .59592 m .64257 .59363 L .64072 .59425 L F
.619 .947 .94 r
.70302 .6014 m .70619 .60022 L .7043 .59923 L F
.131 0 0 r
.45099 .77086 m .45313 .77071 L .45473 .77013 L F
.103 0 0 r
.45313 .77071 m .45682 .76967 L .45473 .77013 L F
.744 .636 .741 r
.57678 .68616 m .57391 .68605 L .57601 .68345 L F
.719 .512 .609 r
.57678 .68616 m .57369 .6884 L .57391 .68605 L F
.57678 .68616 m .577 .68874 L .57369 .6884 L F
.7 .611 .754 r
.5793 .686 m .57678 .68616 L .57601 .68345 L F
.686 .487 .612 r
.5793 .686 m .577 .68874 L .57678 .68616 L F
.76 .742 .837 r
.67688 .63217 m .68023 .63246 L .6791 .63132 L F
.772 .832 .899 r
.6791 .63132 m .68023 .63246 L .68281 .63079 L F
.452 .193 .43 r
.63156 .6053 m .63404 .60494 L .63409 .60234 L F
.403 .162 .431 r
.63404 .60494 m .63594 .60174 L .63409 .60234 L F
.682 .492 .623 r
.58516 .6836 m .5849 .68596 L .58177 .68559 L F
.323 .168 .51 r
.29116 .62037 m .28962 .61913 L .29129 .61806 L F
.29116 .62037 m .2893 .62162 L .28962 .61913 L F
.477 .768 .995 r
.35981 .65284 m .35914 .65406 L .35777 .65329 L F
.35981 .65284 m .36115 .65379 L .35914 .65406 L F
.611 .363 .518 r
.59701 .68885 m .59689 .69094 L .59466 .69095 L F
.589 .345 .515 r
.59701 .68885 m .59922 .69074 L .59689 .69094 L F
.649 .324 .408 r
.59926 .6891 m .59922 .69074 L .59701 .68885 L F
0 0 0 r
.32493 .65075 m .32521 .6516 L .327 .65099 L F
.32493 .65075 m .32347 .65285 L .32521 .6516 L F
.624 .65908 m .62557 .65818 L .62655 .65677 L F
.807 .995 .764 r
.62557 .65818 m .62832 .65571 L .62655 .65677 L F
.454 .093 .26 r
.40764 .74815 m .40662 .75035 L .4045 .75057 L F
.774 .523 .556 r
.41011 .74804 m .40662 .75035 L .40764 .74815 L F
.671 .608 .776 r
.49824 .7399 m .49934 .74298 L .50174 .74257 L F
.576 .414 .625 r
.4998 .74516 m .50174 .74257 L .49934 .74298 L F
.607 .537 .75 r
.39509 .76918 m .39279 .7696 L .39183 .76618 L F
.46 0 0 r
.47911 .76772 m .48066 .76849 L .48175 .7678 L F
0 .116 .661 r
.48287 .76829 m .4836 .76945 L .48175 .7678 L F
.48287 .76829 m .48175 .7678 L .48066 .76849 L F
.666 .741 .906 r
.36515 .65496 m .36115 .65379 L .36328 .65352 L F
.529 .749 .976 r
.36541 .6531 m .36515 .65496 L .36328 .65352 L F
.36541 .6531 m .36721 .6545 L .36515 .65496 L F
.235 .743 .884 r
.43847 .72422 m .44061 .72401 L .44182 .7242 L F
.04 .606 .78 r
.44061 .72401 m .44387 .72423 L .44182 .7242 L F
.44 .141 .36 r
.3583 .79365 m .36031 .79333 L .36104 .79128 L F
.484 .183 .379 r
.36104 .79128 m .36274 .79263 L .36263 .79068 L F
.36104 .79128 m .36031 .79333 L .36274 .79263 L F
.554 .398 .625 r
.36638 .76426 m .36871 .76635 L .36837 .76385 L F
.36638 .76426 m .36646 .76682 L .36871 .76635 L F
.668 .398 .503 r
.58929 .69146 m .59157 .69361 L .58952 .69355 L F
.649 .402 .531 r
.59148 .69143 m .59157 .69361 L .58929 .69146 L F
.569 .939 .856 r
.7196 .62096 m .72099 .61969 L .72156 .62001 L F
.7196 .62096 m .7189 .62094 L .72099 .61969 L F
.845 .768 .777 r
.33636 .8455 m .33658 .84516 L .33599 .84504 L F
.529 .337 .565 r
.36961 .75343 m .37169 .7531 L .3718 .7508 L F
.51 .369 .626 r
.36961 .75343 m .37163 .75534 L .37169 .7531 L F
.36961 .75343 m .36983 .75584 L .37163 .75534 L F
.281 0 .144 r
.52275 .78834 m .52568 .78613 L .52494 .78752 L F
.247 0 .191 r
.52494 .78752 m .52568 .78613 L .52745 .78535 L F
.35 .094 .378 r
.36165 .70729 m .35934 .70992 L .35961 .70772 L F
.176 0 0 r
.34084 .6758 m .33685 .67667 L .33867 .67611 L F
.995 .754 .429 r
.67506 .58374 m .67504 .58605 L .67413 .58528 L F
.527 .806 .997 r
.6759 .58256 m .67735 .58331 L .67506 .58374 L F
0 0 0 r
.6759 .58256 m .67506 .58374 L .67413 .58528 L F
.527 .806 .997 r
.6759 .58256 m .67735 .58331 L .67506 .58374 L F
.84 .592 .564 r
.67452 .59588 m .67741 .59452 L .67453 .59403 L F
.67452 .59588 m .67783 .59686 L .67741 .59452 L F
.92 .817 .728 r
.65081 .61542 m .64819 .61796 L .6502 .61531 L F
.65081 .61542 m .64976 .61891 L .64819 .61796 L F
0 0 .012 r
.62345 .66089 m .62557 .65818 L .624 .65908 L F
.575 .45 .673 r
.36307 .77506 m .36519 .77475 L .36493 .77229 L F
.512 .344 .59 r
.36325 .77745 m .36519 .77475 L .36307 .77506 L F
.288 .591 .946 r
.28677 .60893 m .28455 .60836 L .28438 .60794 L F
.28677 .60893 m .28713 .60916 L .28455 .60836 L F
.578 .191 .272 r
.32083 .73527 m .31808 .73683 L .31885 .73605 L F
.629 .961 .888 r
.31885 .73605 m .31461 .73806 L .31815 .73712 L F
.578 .191 .272 r
.31808 .73683 m .31602 .738 L .31731 .73711 L F
.31808 .73683 m .31731 .73711 L .31885 .73605 L F
.309 .797 .759 r
.31815 .73712 m .31497 .73797 L .31385 .73841 L F
.31497 .73797 m .31461 .73806 L .31421 .73824 L F
.31497 .73797 m .31421 .73824 L .31385 .73841 L F
.955 .749 .585 r
.64976 .61891 m .64935 .6211 L .64819 .61796 L F
.741 .567 .658 r
.57933 .68848 m .577 .68874 L .5793 .686 L F
.682 .527 .669 r
.58177 .68559 m .57933 .68848 L .5793 .686 L F
.769 .547 .597 r
.3291 .64802 m .33246 .65075 L .33277 .64845 L F
.399 .506 .851 r
.28877 .60918 m .28788 .61119 L .28713 .60916 L F
.492 .616 .902 r
.28877 .60918 m .2898 .61116 L .28788 .61119 L F
.341 .119 .424 r
.62939 .60777 m .63167 .60723 L .63156 .6053 L F
.027 0 .368 r
.62939 .60777 m .63083 .60823 L .63167 .60723 L F
.62939 .60777 m .62964 .60975 L .63083 .60823 L F
.541 .607 .869 r
.37678 .6613 m .37481 .66162 L .37331 .65893 L F
.113 0 0 r
.42371 .78794 m .42726 .78605 L .42567 .78734 L F
.251 0 0 r
.42726 .78605 m .42781 .78688 L .42567 .78734 L F
.42726 .78605 m .42942 .78587 L .42781 .78688 L F
.79 .355 .216 r
.42471 .77518 m .42791 .77723 L .4255 .77673 L F
.279 .212 .6 r
.70064 .69859 m .70234 .70121 L .7023 .69887 L F
.359 .24 .579 r
.70064 .69859 m .69997 .70335 L .70234 .70121 L F
.287 0 .28 r
.62051 .6833 m .61811 .68578 L .61836 .68366 L F
.777 .864 .913 r
.68113 .62065 m .67777 .62373 L .67868 .62379 L F
.679 .694 .857 r
.71424 .59734 m .71504 .59983 L .71171 .59919 L F
.78 .544 .58 r
.71504 .59983 m .71187 .60177 L .71171 .59919 L F
.71504 .59983 m .71507 .60218 L .71187 .60177 L F
.646 .637 .827 r
.71629 .59623 m .71504 .59983 L .71424 .59734 L F
.71629 .59623 m .71749 .59914 L .71504 .59983 L F
0 0 0 r
.33282 .67728 m .32899 .67894 L .33073 .67718 L F
.376 0 0 r
.47321 .76916 m .47538 .76914 L .47688 .76817 L F
.266 0 0 r
.47688 .76817 m .47836 .76843 L .47911 .76772 L F
.47688 .76817 m .47538 .76914 L .47836 .76843 L F
.761 .66 .75 r
.69352 .63255 m .69488 .63532 L .6969 .63205 L F
.444 .261 .538 r
.6969 .63205 m .69488 .63532 L .69683 .63444 L F
.577 .575 .815 r
.69683 .63444 m .69488 .63532 L .69352 .63255 L F
0 0 0 r
.62887 .65389 m .63004 .65269 L .63112 .65137 L F
.62899 .65423 m .62887 .65389 L .62832 .65571 L F
.62899 .65423 m .63004 .65269 L .62887 .65389 L F
0 .454 .727 r
.67987 .60086 m .67817 .60053 L .67806 .59902 L F
.968 .684 .439 r
.67862 .60016 m .67881 .60056 L .67987 .60086 L F
0 .454 .727 r
.67987 .60086 m .68119 .60125 L .67817 .60053 L F
.968 .684 .439 r
.67881 .60056 m .68004 .60313 L .67987 .60086 L F
0 .454 .727 r
.67987 .60086 m .68133 .60128 L .68119 .60125 L F
.447 .822 .992 r
.72082 .62597 m .72297 .62564 L .72213 .6251 L F
.652 .569 .749 r
.39574 .75875 m .39395 .75907 L .39256 .75604 L F
.59 .414 .611 r
.39557 .76115 m .39395 .75907 L .39574 .75875 L F
.39557 .76115 m .39371 .7618 L .39395 .75907 L F
.514 .337 .579 r
.36371 .70458 m .36165 .70729 L .36172 .70499 L F
.853 .761 .76 r
.65246 .64869 m .65211 .64543 L .6516 .64795 L F
.968 .644 .312 r
.65182 .64999 m .65246 .64869 L .6516 .64795 L F
.65182 .64999 m .65302 .65103 L .65246 .64869 L F
.729 .698 .821 r
.5058 .72557 m .50699 .72669 L .50361 .72625 L F
.741 .699 .811 r
.50887 .72449 m .50699 .72669 L .5058 .72557 L F
.717 .659 .791 r
.50924 .72579 m .50699 .72669 L .50887 .72449 L F
.661 .202 .152 r
.49004 .77762 m .48887 .77813 L .48671 .77729 L F
.337 0 0 r
.49004 .77762 m .49096 .77819 L .48887 .77813 L F
.49004 .77762 m .49196 .77821 L .49096 .77819 L F
.63 .378 .518 r
.393 .73415 m .39541 .73415 L .39572 .73203 L F
.568 .338 .527 r
.39541 .73415 m .39772 .73169 L .39572 .73203 L F
.606 .365 .526 r
.58554 .69137 m .58608 .69361 L .58378 .69366 L F
.87 .739 .716 r
.63711 .63161 m .63881 .63264 L .63812 .63484 L F
.947 .878 .734 r
.60739 .65227 m .6067 .65649 L .60846 .65318 L F
.887 .858 .806 r
.60846 .65318 m .60906 .65043 L .60739 .65227 L F
.60846 .65318 m .60929 .65172 L .60906 .65043 L F
.51 .322 .562 r
.3718 .7508 m .37367 .75263 L .37377 .75039 L F
.3718 .7508 m .37169 .7531 L .37367 .75263 L F
.613 .453 .641 r
.49252 .87858 m .49467 .8774 L .49502 .875 L F
.844 .638 .624 r
.65321 .63119 m .65482 .63225 L .65337 .62919 L F
.829 .66 .673 r
.65321 .63119 m .65469 .63454 L .65482 .63225 L F
.504 .506 .791 r
.28512 .60463 m .28438 .60794 L .28372 .6052 L F
.28512 .60463 m .28677 .60893 L .28438 .60794 L F
.17 .014 .413 r
.34558 .80721 m .34677 .80458 L .3435 .80465 L F
.34558 .80721 m .34657 .80743 L .34677 .80458 L F
.723 .804 .915 r
.64171 .62472 m .64375 .62356 L .64476 .62495 L F
.682 .788 .93 r
.64375 .62356 m .64709 .62395 L .64476 .62495 L F
.548 .413 .649 r
.36788 .75909 m .37001 .75883 L .36983 .75584 L F
.575 .428 .644 r
.36788 .75909 m .37025 .76108 L .37001 .75883 L F
.36788 .75909 m .36811 .76145 L .37025 .76108 L F
0 0 .382 r
.68592 .62799 m .68501 .62932 L .68488 .62681 L F
.68592 .62799 m .68488 .62681 L .68347 .62602 L F
.67 .689 .859 r
.68725 .64156 m .6883 .64329 L .6899 .64219 L F
.348 .703 .984 r
.69254 .63142 m .69119 .63224 L .69015 .63152 L F
.69254 .63142 m .69352 .63255 L .69119 .63224 L F
.745 .581 .672 r
.63812 .63484 m .64124 .63731 L .63827 .63701 L F
.814 .652 .682 r
.63827 .63701 m .64124 .63731 L .63991 .64036 L F
.47 .085 .227 r
.41072 .72851 m .41289 .72836 L .41416 .72627 L F
.439 0 .1 r
.41289 .72836 m .41643 .72663 L .41416 .72627 L F
.651 .51 .678 r
.63259 .62355 m .63046 .62634 L .63087 .62422 L F
.434 .225 .494 r
.61468 .66732 m .61651 .66873 L .61684 .66688 L F
.61468 .66732 m .61453 .66949 L .61651 .66873 L F
.764 .751 .841 r
.51835 .74261 m .52159 .74281 L .52008 .74167 L F
.673 .747 .906 r
.52008 .74167 m .52159 .74281 L .52316 .74046 L F
.203 .641 .949 r
.70322 .59857 m .70514 .59883 L .7043 .59923 L F
0 0 0 r
.70514 .59883 m .70302 .6014 L .7043 .59923 L F
.279 .764 .918 r
.39796 .77204 m .3996 .77179 L .40177 .77212 L F
0 .459 .701 r
.3996 .77179 m .40373 .77262 L .40177 .77212 L F
.576 .414 .625 r
.4998 .74516 m .50174 .7448 L .50174 .74257 L F
.627 .613 .817 r
.4998 .74516 m .50306 .74628 L .50174 .7448 L F
.714 .728 .862 r
.70191 .7097 m .70516 .70933 L .70568 .70977 L F
.345 0 0 r
.70516 .70933 m .70794 .70972 L .70568 .70977 L F
.852 .603 .561 r
.60379 .66928 m .6067 .67234 L .60669 .66988 L F
.668 .482 .625 r
.60669 .66988 m .60953 .67187 L .60914 .66971 L F
.60669 .66988 m .6067 .67234 L .60953 .67187 L F
.661 .585 .758 r
.52259 .73464 m .52057 .73543 L .51917 .73207 L F
.144 0 .201 r
.51075 .73236 m .51029 .73397 L .50889 .73455 L F
.783 .881 .918 r
.67296 .58873 m .67016 .58911 L .67199 .58768 L F
0 .033 .602 r
.67199 .58768 m .67388 .591 L .67296 .58873 L F
.67203 .58775 m .67367 .58973 L .67388 .591 L F
.67199 .58768 m .67202 .58771 L .67203 .58775 L F
.67202 .58771 m .67367 .58973 L .67203 .58775 L F
.783 .881 .918 r
.6724 .5888 m .67131 .59018 L .67016 .58911 L F
.67296 .58873 m .67251 .58912 L .6724 .5888 L F
.67251 .58912 m .67131 .59018 L .6724 .5888 L F
.558 .162 .248 r
.44206 .74037 m .44087 .74167 L .43964 .74147 L F
.329 0 .077 r
.44407 .74069 m .44206 .74037 L .44551 .7396 L F
.44407 .74069 m .44087 .74167 L .44206 .74037 L F
.158 .257 .717 r
.69602 .62883 m .6969 .63205 L .69806 .63081 L F
.985 .735 .469 r
.6969 .63205 m .69611 .63282 L .69806 .63081 L F
.6969 .63205 m .69683 .63444 L .69611 .63282 L F
.713 .865 .451 r
.63438 .61912 m .63368 .61997 L .6326 .62209 L F
.782 .291 .048 r
.63525 .6204 m .63368 .61997 L .63438 .61912 L F
.507 .361 .616 r
.38855 .67945 m .38691 .67831 L .38885 .67749 L F
.38855 .67945 m .38681 .68021 L .38691 .67831 L F
.411 .092 .311 r
.61684 .66688 m .61901 .66642 L .61942 .66431 L F
.183 0 .087 r
.6203 .66534 m .61942 .66431 L .61901 .66642 L F
.6203 .66534 m .6216 .66371 L .61942 .66431 L F
.738 .743 .856 r
.63498 .64673 m .63644 .64493 L .63436 .64603 L F
.953 .852 .704 r
.73331 .72584 m .73214 .72872 L .73357 .72863 L F
.997 .845 .566 r
.73214 .72872 m .73251 .73169 L .73357 .72863 L F
.676 .828 .956 r
.57645 .70173 m .5773 .70224 L .57441 .70174 L F
.707 .512 .622 r
.57663 .70398 m .57441 .70174 L .5773 .70224 L F
.477 .768 .995 r
.57877 .70155 m .5773 .70224 L .57645 .70173 L F
.55 .345 .555 r
.57877 .70155 m .57663 .70398 L .5773 .70224 L F
.405 .163 .43 r
.35734 .71044 m .35697 .71282 L .35507 .71306 L F
.237 .023 .372 r
.35844 .71188 m .35734 .71044 L .35934 .70992 L F
.35844 .71188 m .35697 .71282 L .35734 .71044 L F
.484 .569 .866 r
.68319 .60123 m .68064 .60251 L .68133 .60128 L F
.115 0 .156 r
.68053 .60403 m .68064 .60251 L .68319 .60123 L F
.356 .819 .733 r
.40111 .79449 m .39815 .79552 L .3973 .79599 L F
.331 0 0 r
.40283 .7935 m .39815 .79552 L .40111 .79449 L F
.203 0 .206 r
.34775 .71836 m .34698 .72068 L .3453 .7209 L F
.098 0 .16 r
.34842 .71969 m .34775 .71836 L .34973 .71784 L F
.34842 .71969 m .34698 .72068 L .34775 .71836 L F
.465 0 0 r
.48589 .77124 m .48759 .77177 L .48899 .77169 L F
.491 0 0 r
.48759 .77177 m .4909 .77231 L .48899 .77169 L F
.418 .222 .506 r
.3161 .68085 m .31488 .68141 L .31454 .68142 L F
.637 .518 .702 r
.64601 .61438 m .64493 .61817 L .64303 .61752 L F
.696 .583 .726 r
.64241 .61367 m .64467 .61194 L .64303 .61752 L F
.64241 .61367 m .64303 .61752 L .64305 .61475 L F
.345 0 0 r
.64303 .61752 m .64245 .61801 L .64305 .61475 L F
.64303 .61752 m .64493 .61817 L .64245 .61801 L F
.532 .307 .518 r
.33752 .80211 m .3401 .80181 L .34032 .79878 L F
.688 .439 .541 r
.34032 .79878 m .3401 .80181 L .34219 .80138 L F
.631 .597 .797 r
.39796 .77204 m .39615 .77402 L .39585 .77243 L F
.719 .265 .171 r
.71054 .73381 m .71277 .73498 L .71356 .73445 L F
.025 0 0 r
.71277 .73498 m .71572 .73504 L .71356 .73445 L F
.37 .4 .761 r
.28331 .60389 m .28468 .60459 L .28372 .6052 L F
.504 .506 .791 r
.28512 .60463 m .28372 .6052 L .28468 .60459 L F
0 .568 .713 r
.44387 .72423 m .446 .72427 L .44724 .72431 L F
.105 .646 .845 r
.446 .72427 m .44935 .72457 L .44724 .72431 L F
.224 0 0 r
.42537 .74248 m .42181 .74423 L .42327 .74274 L F
.53 .087 .141 r
.47241 .77572 m .471 .77727 L .46886 .77708 L F
.477 .027 .103 r
.47427 .77658 m .471 .77727 L .47241 .77572 L F
.62 .592 .8 r
.5104 .74544 m .51158 .74828 L .51384 .74785 L F
.596 .463 .67 r
.35656 .78506 m .35864 .78287 L .35603 .78311 L F
.35656 .78506 m .35917 .78487 L .35864 .78287 L F
.335 .631 .96 r
.71469 .74014 m .71616 .73934 L .71375 .73946 L F
.71469 .74014 m .71722 .74052 L .71616 .73934 L F
.613 .432 .613 r
.72027 .73993 m .72049 .74266 L .71813 .7418 L F
.068 .521 .898 r
.71813 .7418 m .71934 .7417 L .71722 .74052 L F
.71813 .7418 m .72049 .74266 L .71934 .7417 L F
.562 .035 0 r
.49544 .78015 m .49885 .78043 L .49828 .78135 L F
.67 .142 0 r
.50108 .78226 m .49828 .78135 L .49885 .78043 L F
.485 .678 .951 r
.68463 .6413 m .68561 .63967 L .68429 .63947 L F
.68463 .6413 m .68725 .64156 L .68561 .63967 L F
.741 .313 .235 r
.70794 .70972 m .71103 .71031 L .71024 .71181 L F
.975 .676 .376 r
.71103 .71031 m .71135 .71262 L .71024 .71181 L F
.641 .508 .686 r
.51477 .72615 m .51263 .72886 L .51261 .72676 L F
.51477 .72615 m .516 .72954 L .51263 .72886 L F
.552 .535 .79 r
.516 .73157 m .51263 .72886 L .516 .72954 L F
.489 .219 .432 r
.30449 .68869 m .30195 .68875 L .30349 .68863 L F
.30449 .68869 m .30187 .69109 L .30195 .68875 L F
.621 .608 .816 r
.51092 .72396 m .50924 .72579 L .50887 .72449 L F
.51092 .72396 m .51261 .72676 L .50924 .72579 L F
.811 .848 .877 r
.7243 .61602 m .72529 .6129 L .72626 .61391 L F
.327 .526 .897 r
.72731 .61246 m .72626 .61391 L .72529 .6129 L F
.72731 .61246 m .72953 .6151 L .72626 .61391 L F
.912 .746 .662 r
.65206 .62585 m .65121 .62908 L .65337 .62919 L F
.856 .649 .622 r
.65033 .63099 m .65337 .62919 L .65121 .62908 L F
.65033 .63099 m .65321 .63119 L .65337 .62919 L F
.25 0 0 r
.44745 .7397 m .44407 .74069 L .44551 .7396 L F
.922 .976 .745 r
.63037 .64348 m .6315 .64338 L .63 .64559 L F
.403 .644 .955 r
.63298 .64207 m .6315 .64338 L .63037 .64348 L F
.63298 .64207 m .6347 .64398 L .6315 .64338 L F
.954 .642 .218 r
.72378 .6179 m .72278 .61535 L .7243 .61602 L F
.811 .848 .877 r
.7243 .61602 m .72278 .61535 L .72529 .6129 L F
.779 .746 .823 r
.6973 .58137 m .69374 .58307 L .69608 .57997 L F
.752 .743 .844 r
.3936 .76393 m .39183 .76618 L .392 .7653 L F
.61 .529 .738 r
.3936 .76393 m .39425 .76724 L .39183 .76618 L F
.607 .537 .75 r
.39509 .76918 m .39183 .76618 L .39425 .76724 L F
.774 .523 .556 r
.41011 .74804 m .40965 .75075 L .40662 .75035 L F
.673 .426 .539 r
.4121 .74966 m .41011 .74804 L .4124 .74757 L F
.4121 .74966 m .40965 .75075 L .41011 .74804 L F
.7 .612 .755 r
.6261 .62954 m .62873 .62773 L .62882 .62973 L F
.682 .527 .669 r
.58177 .68559 m .58292 .68891 L .57933 .68848 L F
.68 .526 .67 r
.5849 .68596 m .58292 .68891 L .58177 .68559 L F
.587 .205 .284 r
.4305 .74063 m .42955 .74221 L .42758 .74226 L F
.488 .099 .228 r
.433 .74134 m .42955 .74221 L .4305 .74063 L F
.27 0 .247 r
.35599 .71442 m .35507 .71306 L .35697 .71282 L F
.35599 .71442 m .35428 .71504 L .35507 .71306 L F
.514 .218 .402 r
.59466 .69095 m .59157 .69361 L .59148 .69143 L F
.5 .166 .333 r
.60953 .67187 m .61236 .66997 L .60914 .66971 L F
.60953 .67187 m .61175 .67158 L .61236 .66997 L F
.342 0 .212 r
.61175 .67158 m .61453 .66949 L .61236 .66997 L F
0 0 .268 r
.72328 .73659 m .72349 .73323 L .72489 .73427 L F
.573 .786 .979 r
.72587 .73361 m .72489 .73427 L .72349 .73323 L F
.841 .546 .49 r
.51055 .78593 m .50795 .78673 L .50771 .78533 L F
.51055 .78593 m .51099 .78809 L .50795 .78673 L F
.56 .503 .749 r
.6935 .59198 m .69512 .58877 L .69301 .58974 L F
.6935 .59198 m .69575 .5917 L .69512 .58877 L F
.61 .484 .684 r
.6935 .59198 m .69626 .5936 L .69575 .5917 L F
.6935 .59198 m .69399 .59436 L .69626 .5936 L F
.366 0 .17 r
.30819 .66088 m .31145 .65847 L .30956 .65926 L F
.52 .589 .864 r
.35515 .67507 m .35588 .67212 L .35348 .67277 L F
.35515 .67507 m .35699 .67471 L .35588 .67212 L F
.617 .546 .752 r
.35515 .67507 m .35888 .67858 L .35699 .67471 L F
.429 .318 .626 r
.63046 .62634 m .62882 .62973 L .62873 .62773 L F
.117 0 0 r
.62882 .62973 m .62955 .62988 L .6273 .63012 L F
.684 .382 .457 r
.63272 .63486 m .63258 .63644 L .62938 .63683 L F
.694 .391 .458 r
.63272 .63486 m .63489 .63693 L .63258 .63644 L F
.549 .372 .593 r
.63488 .63206 m .63481 .63436 L .63272 .63486 L F
.561 .408 .632 r
.63481 .63436 m .63489 .63693 L .63272 .63486 L F
.592 .586 .815 r
.63488 .63206 m .63812 .63484 L .63481 .63436 L F
.63488 .63206 m .63711 .63161 L .63812 .63484 L F
.728 .479 .551 r
.63812 .63484 m .63489 .63693 L .63481 .63436 L F
.63812 .63484 m .63827 .63701 L .63489 .63693 L F
.526 .092 .157 r
.70472 .71108 m .70134 .71162 L .70191 .7097 L F
.545 .491 .746 r
.69901 .70953 m .70213 .71028 L .7018 .7091 L F
.69927 .70904 m .7018 .7091 L .70091 .70591 L F
.69901 .70953 m .7018 .7091 L .69927 .70904 L F
.283 .716 .967 r
.70191 .7097 m .70568 .70977 L .70524 .70917 L F
.70191 .7097 m .70524 .70917 L .70352 .70913 L F
.70495 .70917 m .70524 .70917 L .70486 .70866 L F
.941 .959 .668 r
.70486 .70866 m .70568 .70977 L .70472 .71108 L F
.283 .716 .967 r
.70352 .70913 m .70495 .70917 L .70486 .70866 L F
.526 .092 .157 r
.70472 .71108 m .70191 .7097 L .70486 .70866 L F
.612 .25 .331 r
.70472 .71108 m .70437 .71199 L .70337 .7113 L F
.70437 .71199 m .70384 .7134 L .7035 .71189 L F
.70384 .7134 m .70351 .71195 L .7035 .71189 L F
.70437 .71199 m .7035 .71189 L .70337 .7113 L F
.953 .952 .706 r
.70384 .71342 m .70478 .7105 L .70351 .71195 L F
.70384 .71342 m .70351 .71195 L .70343 .71205 L F
.612 .25 .331 r
.70384 .7134 m .70383 .71341 L .70351 .71195 L F
.605 .604 .824 r
.70134 .71162 m .70343 .71205 L .7035 .71189 L F
.70134 .71162 m .7035 .71189 L .70486 .70866 L F
0 0 .351 r
.70486 .70866 m .7035 .71189 L .70478 .7105 L F
.7035 .71189 m .70343 .71205 L .70351 .71195 L F
.7035 .71189 m .70351 .71195 L .70478 .7105 L F
.612 .25 .331 r
.70472 .71108 m .70384 .71342 L .70383 .71341 L F
.632 .224 .251 r
.70343 .71205 m .70384 .71342 L .70234 .71234 L F
.7022 .7118 m .70234 .71234 L .70134 .71162 L F
.70343 .71205 m .70234 .71234 L .7022 .7118 L F
.129 0 .218 r
.70384 .71342 m .70151 .71601 L .70209 .71445 L F
.612 .25 .331 r
.70337 .7113 m .70383 .71341 L .70134 .71162 L F
.231 .031 .39 r
.70134 .71162 m .70342 .71276 L .70384 .71342 L F
.396 .333 .669 r
.70384 .71342 m .70209 .71445 L .70134 .71162 L F
0 0 .326 r
.70377 .7133 m .70151 .71601 L .70384 .71342 L F
.70342 .71276 m .70263 .71411 L .70377 .7133 L F
.70263 .71411 m .70151 .71601 L .70377 .7133 L F
.569 .428 .649 r
.70384 .71342 m .70373 .71599 L .70151 .71601 L F
0 0 .326 r
.70273 .71393 m .70281 .71552 L .70151 .71601 L F
.462 .822 .995 r
.69944 .71407 m .69588 .71402 L .697 .71324 L F
.69944 .71407 m .69768 .71357 L .69588 .71402 L F
.784 .54 .568 r
.70151 .71601 m .69768 .71357 L .69944 .71407 L F
.682 .393 .478 r
.70209 .71445 m .70151 .71601 L .69944 .71407 L F
.784 .54 .568 r
.70151 .71601 m .69815 .71594 L .69768 .71357 L F
.39 .817 .966 r
.70151 .71601 m .70048 .71558 L .69815 .71594 L F
.268 .742 .938 r
.70151 .71601 m .70281 .71552 L .70048 .71558 L F
.543 .216 .365 r
.70089 .718 m .70281 .71552 L .70056 .71558 L F
.70049 .71563 m .70056 .71558 L .70048 .71558 L F
.70089 .718 m .70056 .71558 L .70049 .71563 L F
0 0 .326 r
.70342 .71276 m .70296 .71484 L .70273 .71393 L F
.70296 .71484 m .70281 .71552 L .70273 .71393 L F
0 0 .351 r
.70486 .70866 m .70478 .7105 L .70486 .70865 L F
.509 .339 .586 r
.70486 .70866 m .70489 .70806 L .70457 .70574 L F
0 0 .351 r
.70486 .70866 m .70486 .70865 L .70489 .70806 L F
.644 .598 .788 r
.63241 .62608 m .6315 .62961 L .63168 .62825 L F
.63241 .62608 m .63248 .6288 L .6315 .62961 L F
.907 .637 .137 r
.7333 .71706 m .73411 .71838 L .73308 .71783 L F
.7333 .71706 m .73361 .71938 L .73411 .71838 L F
.994 .772 .493 r
.73411 .71838 m .73321 .72322 L .73421 .72387 L F
0 0 0 r
.7336 .72164 m .73321 .72322 L .73331 .72271 L F
.73372 .72089 m .73331 .72271 L .73411 .71838 L F
.7336 .72164 m .73331 .72271 L .73372 .72089 L F
.13 .162 .627 r
.73426 .71604 m .73457 .71709 L .73361 .71938 L F
.73457 .71709 m .73491 .71822 L .73417 .71888 L F
.73457 .71709 m .73417 .71888 L .73361 .71938 L F
0 0 0 r
.7336 .72164 m .73411 .71838 L .73361 .71938 L F
.759 .728 .824 r
.6569 .6183 m .66009 .61864 L .65921 .61595 L F
.428 .045 .208 r
.65002 .58863 m .65236 .58825 L .65303 .58635 L F
.285 0 .152 r
.65303 .58635 m .65441 .58753 L .65529 .586 L F
.65303 .58635 m .65236 .58825 L .65441 .58753 L F
.521 .779 .991 r
.36996 .65832 m .37331 .65893 L .3713 .65932 L F
.68 .418 .519 r
.60257 .68823 m .59922 .69074 L .59926 .6891 L F
.894 .857 .799 r
.70542 .58253 m .70734 .5802 L .70719 .57897 L F
.454 0 0 r
.45291 .72523 m .45488 .72587 L .45614 .72571 L F
.322 0 0 r
.45614 .72571 m .45488 .72587 L .45828 .72609 L F
.826 .592 .584 r
.37908 .8235 m .37684 .8212 L .37573 .82312 L F
.228 0 .015 r
.34609 .72186 m .3453 .7209 L .34698 .72068 L F
.34609 .72186 m .34407 .72258 L .3453 .7209 L F
.432 .182 .433 r
.62548 .61771 m .62575 .61591 L .62343 .61846 L F
.382 .181 .479 r
.62548 .61771 m .62713 .61536 L .62575 .61591 L F
.769 .647 .727 r
.57476 .67797 m .57311 .68016 L .57143 .67759 L F
.756 .654 .748 r
.62963 .64786 m .63112 .65137 L .63004 .64922 L F
.62963 .64786 m .63305 .64862 L .63112 .65137 L F
.997 .788 .496 r
.63112 .65137 m .63004 .65269 L .63004 .64922 L F
0 0 0 r
.69746 .6257 m .6979 .62525 L .69607 .62672 L F
.06 0 .456 r
.69746 .6257 m .69607 .62672 L .69691 .62869 L F
.043 0 .456 r
.69607 .62672 m .69602 .62883 L .69691 .62869 L F
0 .017 .553 r
.71817 .73744 m .71984 .73926 L .72027 .73993 L F
.759 .541 .602 r
.72392 .74277 m .72049 .74266 L .72027 .73993 L F
.134 0 0 r
.72392 .74277 m .72232 .74283 L .72049 .74266 L F
.959 .933 .721 r
.72161 .74243 m .72232 .74283 L .72288 .74189 L F
0 0 0 r
.72288 .74189 m .7221 .74244 L .72297 .74188 L F
.72288 .74189 m .72297 .74188 L .72427 .74106 L F
.759 .541 .602 r
.72392 .74277 m .7228 .7419 L .72288 .74189 L F
.7228 .7419 m .72027 .73993 L .72288 .74189 L F
.235 0 0 r
.31385 .73841 m .31128 .73849 L .31276 .73854 L F
.742 .685 .796 r
.50033 .7237 m .49813 .72625 L .49691 .72333 L F
.681 .587 .745 r
.50037 .7258 m .49813 .72625 L .50033 .7237 L F
.786 .781 .848 r
.70147 .57613 m .69839 .57688 L .70035 .5748 L F
.808 .614 .639 r
.65269 .63722 m .6557 .63999 L .65598 .63763 L F
.65269 .63722 m .65258 .63965 L .6557 .63999 L F
.871 .731 .705 r
.65256 .64199 m .6557 .63999 L .65258 .63965 L F
.65256 .64199 m .65408 .64271 L .6557 .63999 L F
.718 .476 .559 r
.34219 .80138 m .34482 .8023 L .34567 .79931 L F
.531 .29 .496 r
.34482 .8023 m .34788 .79918 L .34567 .79931 L F
.829 .66 .673 r
.65321 .63119 m .65154 .63414 L .65469 .63454 L F
.823 .695 .723 r
.65154 .63414 m .65269 .63722 L .65469 .63454 L F
.762 .601 .678 r
.65269 .63722 m .65598 .63763 L .65469 .63454 L F
.772 .832 .899 r
.6791 .63132 m .68281 .63079 L .68141 .63035 L F
.602 .181 .215 r
.68501 .62932 m .68141 .63035 L .68281 .63079 L F
.671 .608 .776 r
.49824 .7399 m .50174 .74257 L .50036 .73962 L F
.65 .094 0 r
.50409 .74202 m .50036 .73962 L .50174 .74257 L F
.726 .622 .742 r
.50174 .7448 m .50409 .74202 L .50174 .74257 L F
.459 .019 .115 r
.46424 .7686 m .46644 .76861 L .46775 .76692 L F
.769 .383 .323 r
.46775 .76692 m .46644 .76861 L .46773 .76817 L F
.666 .881 .978 r
.71462 .62432 m .71238 .62521 L .71076 .62459 L F
.804 .727 .779 r
.57391 .68605 m .57112 .68585 L .57211 .68515 L F
.801 .629 .669 r
.57369 .6884 m .57112 .68585 L .57391 .68605 L F
.801 .729 .785 r
.57601 .68345 m .57391 .68605 L .57211 .68515 L F
.173 .703 .849 r
.46598 .73611 m .46487 .73595 L .46277 .73608 L F
.186 0 0 r
.46487 .73595 m .46395 .73611 L .46277 .73608 L F
.037 .601 .79 r
.46405 .73628 m .46277 .73608 L .46161 .73606 L F
.186 0 0 r
.46395 .73611 m .46166 .73651 L .46277 .73608 L F
.037 .601 .79 r
.46161 .73606 m .46277 .73608 L .46049 .73596 L F
.173 .703 .849 r
.46598 .73611 m .46277 .73608 L .46405 .73628 L F
.643 .111 0 r
.42445 .77543 m .42471 .77518 L .4241 .77525 L F
.79 .355 .216 r
.42471 .77518 m .42693 .77738 L .42791 .77723 L F
.643 .111 0 r
.42445 .77543 m .42531 .7761 L .42471 .77518 L F
.42531 .7761 m .42693 .77738 L .4258 .77626 L F
.42531 .7761 m .4258 .77626 L .42471 .77518 L F
.44 .686 .969 r
.42622 .77607 m .42693 .77738 L .42445 .77543 L F
.599 .04 0 r
.42445 .77543 m .42422 .77589 L .42622 .77607 L F
0 .399 .767 r
.42626 .77581 m .42622 .77607 L .4248 .77594 L F
.42459 .77588 m .4248 .77594 L .42422 .77589 L F
.42626 .77581 m .4248 .77594 L .42459 .77588 L F
.418 .864 .809 r
.4339 .77599 m .43794 .77462 L .43589 .77518 L F
.66 .6 .776 r
.3676 .79895 m .36886 .80223 L .37089 .80129 L F
.327 .035 .307 r
.37464 .69561 m .3734 .69455 L .37541 .69414 L F
.37464 .69561 m .37283 .69627 L .3734 .69455 L F
.747 .479 .525 r
.71044 .59951 m .71171 .59919 L .71187 .60177 L F
.739 .926 .953 r
.71424 .59734 m .71171 .59919 L .71052 .59847 L F
.946 .903 .75 r
.67143 .61144 m .67137 .61073 L .67179 .61028 L F
.724 .377 .391 r
.66855 .60988 m .66886 .60998 L .67201 .60969 L F
.66855 .60988 m .67201 .60969 L .67201 .60969 L F
.946 .903 .75 r
.67137 .61073 m .67126 .60954 L .67171 .61017 L F
.67137 .61073 m .67171 .61017 L .67179 .61028 L F
.724 .377 .391 r
.67201 .60969 m .67201 .60969 L .67204 .60969 L F
.463 .803 .999 r
.3211 .71571 m .32318 .71536 L .32476 .71618 L F
.671 .876 .975 r
.32476 .71618 m .32521 .71448 L .32671 .71551 L F
.32476 .71618 m .32318 .71536 L .32521 .71448 L F
.446 .077 .243 r
.40061 .73105 m .40274 .73076 L .40336 .72942 L F
.476 .107 .258 r
.40274 .73076 m .40492 .73059 L .40336 .72942 L F
.487 .101 .234 r
.40336 .72942 m .40492 .73059 L .40558 .72933 L F
.056 0 .369 r
.7003 .70443 m .69969 .70775 L .70091 .70591 L F
.322 .243 .609 r
.7003 .70443 m .70234 .70121 L .69997 .70335 L F
.7003 .70443 m .70269 .70399 L .70234 .70121 L F
0 .289 .692 r
.28325 .60371 m .28331 .60389 L .2818 .60351 L F
.28325 .60371 m .28468 .60459 L .28331 .60389 L F
.304 0 .068 r
.31881 .65499 m .3216 .65352 L .31964 .65414 L F
.432 .088 .28 r
.62454 .63612 m .62457 .6373 L .6219 .63772 L F
.814 .583 .588 r
.57601 .68345 m .57318 .68336 L .57311 .68016 L F
.801 .729 .785 r
.57601 .68345 m .57211 .68515 L .57318 .68336 L F
.564 .432 .659 r
.39125 .67478 m .3917 .6771 L .39025 .67596 L F
.39125 .67478 m .39025 .67596 L .38843 .67454 L F
.509 .436 .71 r
.38843 .67454 m .3917 .6771 L .39071 .67581 L F
.42 .242 .532 r
.39071 .67581 m .38855 .67945 L .38883 .67765 L F
.3893 .67708 m .38883 .67765 L .38885 .67749 L F
.39071 .67581 m .38883 .67765 L .3893 .67708 L F
.564 .432 .659 r
.39068 .67181 m .39125 .67478 L .38843 .67454 L F
.509 .436 .71 r
.38843 .67454 m .39071 .67581 L .38885 .67749 L F
0 0 .067 r
.67035 .61845 m .6703 .61773 L .67011 .61536 L F
.98 .716 .321 r
.67035 .61845 m .66983 .61897 L .6703 .61773 L F
.67035 .61845 m .6706 .6208 L .66983 .61897 L F
.109 0 0 r
.45891 .76927 m .46207 .76844 L .45981 .7688 L F
.68 .418 .519 r
.60257 .68823 m .60168 .69103 L .59922 .69074 L F
.599 .335 .489 r
.60492 .69016 m .60257 .68823 L .60473 .6884 L F
.60492 .69016 m .60168 .69103 L .60257 .68823 L F
.507 .363 .62 r
.347 .70221 m .34882 .70191 L .34871 .69912 L F
.388 .197 .496 r
.347 .70221 m .34847 .70392 L .34882 .70191 L F
.347 .70221 m .34682 .70466 L .34847 .70392 L F
.594 .809 .982 r
.3211 .71571 m .31912 .71631 L .31765 .71527 L F
.525 .901 .725 r
.34457 .67416 m .34381 .67493 L .346 .67487 L F
.34457 .67416 m .343 .67529 L .34381 .67493 L F
.987 .805 .574 r
.72813 .72118 m .72694 .72297 L .72722 .72057 L F
.72813 .72118 m .72792 .72368 L .72694 .72297 L F
.653 .414 .545 r
.6102 .68794 m .60905 .68615 L .61027 .68593 L F
.592 .354 .524 r
.61027 .68593 m .61247 .68787 L .6102 .68794 L F
.712 .785 .909 r
.37411 .80446 m .378 .80492 L .37633 .80397 L F
.771 .523 .56 r
.38212 .80182 m .38025 .80284 L .38056 .8016 L F
.711 .931 .606 r
.37856 .80376 m .37939 .80312 L .37972 .8025 L F
.771 .523 .56 r
.38025 .80284 m .37856 .80376 L .37972 .8025 L F
.711 .931 .606 r
.37972 .8025 m .37939 .80312 L .38056 .8016 L F
.771 .523 .56 r
.38025 .80284 m .37972 .8025 L .38056 .8016 L F
.711 .931 .606 r
.37856 .80376 m .378 .80492 L .37939 .80312 L F
.771 .523 .56 r
.38212 .80182 m .38183 .80418 L .37856 .80376 L F
.895 .789 .737 r
.38149 .80462 m .38311 .80693 L .3808 .8057 L F
.163 .458 .885 r
.38438 .80666 m .38311 .80693 L .38224 .80569 L F
.38248 .80541 m .38224 .80569 L .38168 .80489 L F
.38438 .80666 m .38224 .80569 L .38248 .80541 L F
.256 .076 .434 r
.38386 .80367 m .38246 .80411 L .38212 .80182 L F
.163 .458 .885 r
.38419 .80536 m .38296 .80443 L .38391 .80357 L F
.3822 .80512 m .3825 .80418 L .38258 .80414 L F
.38296 .80443 m .38258 .80414 L .38391 .80357 L F
.3822 .80512 m .38258 .80414 L .38296 .80443 L F
.256 .076 .434 r
.38253 .8041 m .38246 .80411 L .38253 .80409 L F
.38246 .80411 m .38183 .80418 L .38195 .80318 L F
.296 .486 .876 r
.38161 .8037 m .38228 .80413 L .38253 .8041 L F
0 0 0 r
.38391 .80357 m .38343 .80421 L .38421 .80323 L F
.38343 .80421 m .38327 .80442 L .38361 .80398 L F
.38343 .80421 m .38361 .80398 L .38421 .80323 L F
.256 .076 .434 r
.38246 .80411 m .38195 .80318 L .38212 .80182 L F
.296 .486 .876 r
.38045 .80116 m .38141 .80326 L .38373 .80384 L F
.256 .076 .434 r
.3841 .80393 m .38361 .80398 L .38386 .80367 L F
.296 .486 .876 r
.38383 .80372 m .38373 .80384 L .3841 .80393 L F
.38045 .80116 m .38373 .80384 L .38383 .80372 L F
.124 0 0 r
.38269 .80451 m .38391 .80357 L .3825 .80418 L F
.256 .076 .434 r
.38361 .80398 m .38253 .8041 L .38386 .80367 L F
.38253 .8041 m .38253 .80409 L .38386 .80367 L F
.211 .061 .449 r
.38517 .8034 m .38391 .80357 L .38418 .80121 L F
.212 .674 .944 r
.38517 .8034 m .38391 .80357 L .38432 .8031 L F
.38472 .80314 m .38432 .8031 L .38451 .80288 L F
.948 .939 .607 r
.38451 .80288 m .38441 .80406 L .38468 .8031 L F
.283 0 .047 r
.38418 .80121 m .38747 .79885 L .38548 .80124 L F
.211 .061 .449 r
.38517 .8034 m .38418 .80121 L .38548 .80124 L F
.948 .939 .607 r
.38451 .80288 m .38468 .8031 L .38548 .80036 L F
.212 .674 .944 r
.38485 .80315 m .38472 .80314 L .38451 .80288 L F
.946 .91 .751 r
.38468 .8031 m .38517 .8034 L .38548 .80036 L F
.212 .674 .944 r
.38517 .8034 m .38432 .8031 L .38475 .80314 L F
.253 .313 .732 r
.38517 .8034 m .38601 .80572 L .38391 .80357 L F
.946 .91 .751 r
.38441 .80406 m .38517 .8034 L .38468 .8031 L F
.212 .674 .944 r
.38517 .8034 m .38475 .80314 L .38485 .80315 L F
.469 .355 .641 r
.38601 .80572 m .38438 .80666 L .38391 .80357 L F
.256 .076 .434 r
.3841 .80393 m .38386 .80367 L .38391 .80357 L F
.38386 .80367 m .38212 .80182 L .38391 .80357 L F
0 0 0 r
.38375 .80381 m .38293 .80486 L .38382 .80375 L F
.296 .486 .876 r
.38281 .80295 m .3841 .80393 L .38388 .80306 L F
0 0 .065 r
.3841 .80393 m .38391 .80357 L .38451 .80288 L F
0 0 0 r
.38421 .80323 m .38387 .80367 L .38451 .80288 L F
.483 .29 .542 r
.38418 .80121 m .38391 .80357 L .38212 .80182 L F
0 0 0 r
.38312 .79732 m .38276 .79786 L .38415 .79586 L F
.296 .486 .876 r
.37889 .79998 m .38281 .80295 L .38243 .79767 L F
.38204 .79765 m .38243 .79767 L .3824 .79738 L F
.37889 .79998 m .38243 .79767 L .38204 .79765 L F
.718 .679 .811 r
.38335 .79956 m .38502 .79776 L .38312 .79732 L F
.332 0 0 r
.38502 .79776 m .38487 .79782 L .38312 .79732 L F
.111 .215 .693 r
.38265 .79802 m .384 .80351 L .38451 .80288 L F
.38259 .7981 m .384 .80351 L .38265 .79802 L F
.296 .486 .876 r
.38281 .80295 m .38388 .80306 L .3824 .79738 L F
.843 .596 .565 r
.3824 .79738 m .38335 .79956 L .38312 .79732 L F
.111 .215 .693 r
.38255 .79772 m .38451 .80288 L .38335 .79956 L F
.3824 .79738 m .38253 .79771 L .38255 .79772 L F
.38253 .79771 m .38451 .80288 L .38255 .79772 L F
.332 0 0 r
.38487 .79782 m .38358 .79837 L .38287 .7977 L F
.38358 .79837 m .38197 .79905 L .38276 .79786 L F
.38358 .79837 m .38276 .79786 L .38287 .7977 L F
.38487 .79782 m .38287 .7977 L .38312 .79732 L F
0 0 0 r
.38276 .79786 m .38197 .79905 L .38352 .79678 L F
.38276 .79786 m .38352 .79678 L .38415 .79586 L F
.111 .215 .693 r
.3824 .79738 m .38259 .7981 L .38265 .79802 L F
.384 .80351 m .3841 .80393 L .38451 .80288 L F
0 0 0 r
.38387 .80367 m .38375 .80381 L .38451 .80288 L F
.38393 .8036 m .38393 .80361 L .38433 .80311 L F
.38384 .8037 m .38393 .80361 L .38393 .8036 L F
.38384 .8037 m .38382 .80375 L .38393 .80361 L F
.38375 .80381 m .38382 .80375 L .38384 .8037 L F
.38375 .80381 m .38433 .80311 L .38451 .80288 L F
.296 .486 .876 r
.38205 .80374 m .38253 .8041 L .38361 .80398 L F
.38369 .80389 m .38361 .80398 L .3841 .80393 L F
.38205 .80374 m .38361 .80398 L .38369 .80389 L F
.38161 .8037 m .38253 .8041 L .38205 .80374 L F
.38141 .80326 m .38161 .8037 L .38205 .80374 L F
0 0 0 r
.38327 .80442 m .38293 .80486 L .38375 .80381 L F
.38361 .80398 m .38375 .80381 L .38421 .80323 L F
.38327 .80442 m .38375 .80381 L .38361 .80398 L F
.296 .486 .876 r
.38141 .80326 m .38205 .80374 L .38369 .80389 L F
.38373 .80384 m .38369 .80389 L .3841 .80393 L F
.38141 .80326 m .38369 .80389 L .38373 .80384 L F
.163 .458 .885 r
.38438 .80666 m .3822 .80512 L .38296 .80443 L F
.38438 .80666 m .38296 .80443 L .38419 .80536 L F
.3822 .80512 m .38149 .80462 L .3825 .80418 L F
.38438 .80666 m .38168 .80489 L .38187 .80489 L F
.854 .901 .867 r
.38331 .8044 m .38244 .80551 L .38441 .80406 L F
0 0 0 r
.38293 .80486 m .38244 .80551 L .38324 .80449 L F
.124 0 0 r
.38141 .80549 m .38293 .80486 L .38221 .80488 L F
.854 .901 .867 r
.38217 .80477 m .38244 .80551 L .38331 .8044 L F
0 0 0 r
.38324 .80449 m .38244 .80551 L .38325 .80449 L F
.788 .676 .74 r
.38244 .80551 m .38601 .80572 L .38441 .80406 L F
.871 .655 .608 r
.38441 .80406 m .38601 .80572 L .38517 .8034 L F
.291 0 0 r
.38441 .80406 m .38454 .80461 L .38309 .80471 L F
0 0 0 r
.38293 .80486 m .38325 .80449 L .38331 .80441 L F
.38293 .80486 m .38331 .80441 L .38337 .80433 L F
.124 0 0 r
.38221 .80488 m .38293 .80486 L .38391 .80357 L F
.291 0 0 r
.38331 .8044 m .38309 .80471 L .38217 .80477 L F
.38441 .80406 m .38309 .80471 L .38331 .8044 L F
0 0 0 r
.38337 .80433 m .38331 .80441 L .3835 .80416 L F
.38557 .80446 m .38454 .80461 L .38441 .80406 L F
.139 0 0 r
.38333 .80444 m .38441 .80406 L .38557 .80446 L F
0 0 0 r
.38326 .80446 m .3835 .80416 L .38355 .80409 L F
.38293 .80486 m .38329 .80443 L .38326 .80446 L F
.38329 .80443 m .3835 .80416 L .38326 .80446 L F
.285 .777 .725 r
.38292 .80444 m .38217 .80477 L .38331 .8044 L F
.38341 .80431 m .38331 .8044 L .38441 .80406 L F
.38292 .80444 m .38331 .8044 L .38341 .80431 L F
.139 0 0 r
.38292 .80444 m .38341 .80431 L .38333 .80444 L F
.38341 .80431 m .38441 .80406 L .38333 .80444 L F
0 0 0 r
.38355 .80409 m .3835 .80416 L .38451 .80288 L F
.124 0 0 r
.38141 .80549 m .38244 .80551 L .38293 .80486 L F
.163 .458 .885 r
.38187 .80489 m .38168 .80489 L .38149 .80462 L F
.124 0 0 r
.38141 .80549 m .38269 .80451 L .38149 .80462 L F
.38269 .80451 m .3825 .80418 L .38149 .80462 L F
.296 .486 .876 r
.38161 .8037 m .38183 .80418 L .38228 .80413 L F
.37889 .79998 m .38013 .80175 L .38045 .80116 L F
.38013 .80175 m .38183 .80418 L .38045 .80116 L F
.467 .772 .997 r
.37633 .80397 m .378 .80492 L .37856 .80376 L F
0 0 0 r
.45828 .72609 m .46039 .72581 L .4616 .72552 L F
.281 0 0 r
.4616 .72552 m .46039 .72581 L .46377 .72573 L F
.704 .534 .656 r
.57933 .68848 m .57711 .69102 L .577 .68874 L F
.57933 .68848 m .58153 .6915 L .57711 .69102 L F
.757 .542 .606 r
.58237 .69061 m .57933 .68848 L .58292 .68891 L F
.58237 .69061 m .58153 .6915 L .57933 .68848 L F
.522 .357 .598 r
.37376 .74794 m .37581 .74996 L .37559 .74751 L F
.37376 .74794 m .37377 .75039 L .37581 .74996 L F
.768 .89 .932 r
.354 .80856 m .35437 .80668 L .35158 .80794 L F
.354 .80856 m .3559 .80734 L .35437 .80668 L F
.778 .488 .496 r
.51989 .77928 m .52337 .77767 L .52097 .77728 L F
.51989 .77928 m .52299 .77974 L .52337 .77767 L F
.4 .14 .401 r
.52337 .77767 m .52479 .77912 L .52578 .77717 L F
.52337 .77767 m .52299 .77974 L .52479 .77912 L F
.814 .721 .762 r
.3435 .80465 m .34677 .80458 L .34482 .8023 L F
.275 .523 .908 r
.34677 .80458 m .34803 .80429 L .34482 .8023 L F
.626 .518 .711 r
.34657 .80743 m .34803 .80429 L .34677 .80458 L F
.719 .647 .776 r
.50174 .7448 m .50306 .74628 L .50498 .74516 L F
.419 .253 .547 r
.39716 .76052 m .39574 .75875 L .39749 .75815 L F
.39716 .76052 m .39557 .76115 L .39574 .75875 L F
.44 .234 .503 r
.64241 .61367 m .64305 .61475 L .6401 .61736 L F
.77 .698 .783 r
.63525 .6204 m .63581 .6239 L .63259 .62355 L F
.782 .648 .714 r
.63259 .62355 m .63581 .6239 L .63444 .627 L F
.763 .693 .785 r
.63525 .6204 m .63875 .62117 L .63581 .6239 L F
.684 .29 .294 r
.35599 .79358 m .35693 .79522 L .3583 .79365 L F
.599 .271 .385 r
.35693 .79522 m .36031 .79333 L .3583 .79365 L F
.525 .282 .488 r
.35086 .69872 m .35325 .69597 L .35076 .69648 L F
.435 .161 .398 r
.61879 .62391 m .62098 .62326 L .62116 .62104 L F
.356 .082 .353 r
.62098 .62326 m .62308 .62045 L .62116 .62104 L F
.766 .923 .556 r
.64183 .6577 m .6417 .65748 L .64139 .65792 L F
.458 .847 .635 r
.64053 .65872 m .64236 .65744 L .64183 .6577 L F
0 0 0 r
.64053 .65872 m .64183 .6577 L .63952 .66045 L F
.766 .923 .556 r
.64183 .6577 m .64139 .65792 L .64062 .65901 L F
.458 .847 .635 r
.64236 .65744 m .64338 .65673 L .64183 .6577 L F
.736 .99 .874 r
.64474 .65545 m .64423 .65516 L .64338 .65673 L F
.739 .973 .719 r
.64338 .65673 m .64423 .65516 L .64183 .6577 L F
.654 .416 .546 r
.60905 .68615 m .60686 .68847 L .60473 .6884 L F
.653 .414 .545 r
.6102 .68794 m .60686 .68847 L .60905 .68615 L F
.086 0 0 r
.46377 .72573 m .46591 .7256 L .46703 .7253 L F
.337 .812 .752 r
.46703 .7253 m .46797 .72479 L .46915 .72483 L F
.46703 .7253 m .46591 .7256 L .46797 .72479 L F
.639 .918 .979 r
.4838 .72421 m .48468 .72288 L .48589 .72323 L F
.4838 .72421 m .48271 .7238 L .48468 .72288 L F
.444 0 .094 r
.41643 .72663 m .41823 .72739 L .41952 .72577 L F
.556 .148 .224 r
.41823 .72739 m .42173 .72578 L .41952 .72577 L F
.074 .636 .755 r
.42693 .77738 m .43021 .77728 L .42791 .77723 L F
.135 0 0 r
.32949 .73097 m .32929 .7315 L .32786 .73147 L F
.099 0 0 r
.32836 .7322 m .32786 .73147 L .32929 .7315 L F
.32836 .7322 m .32642 .73302 L .32786 .73147 L F
0 0 0 r
.30671 .71753 m .31004 .7172 L .30803 .71735 L F
.554 .265 .431 r
.41533 .74531 m .41451 .74753 L .4124 .74757 L F
.601 .342 .497 r
.4176 .74496 m .41451 .74753 L .41533 .74531 L F
.545 .872 .993 r
.47834 .72498 m .47883 .72371 L .4805 .72428 L F
.47834 .72498 m .47695 .72447 L .47883 .72371 L F
.257 0 0 r
.41587 .77982 m .41796 .7794 L .41958 .77776 L F
.146 0 0 r
.41958 .77776 m .41992 .7788 L .42169 .7773 L F
.41958 .77776 m .41796 .7794 L .41992 .7788 L F
0 .068 .556 r
.72728 .74003 m .72492 .73788 L .72672 .73927 L F
0 .31 .759 r
.73123 .61682 m .72941 .61612 L .72953 .6151 L F
0 0 0 r
.73123 .61682 m .73242 .61553 L .7315 .61663 L F
.73123 .61682 m .73021 .61821 L .73103 .6191 L F
.73123 .61682 m .7315 .61663 L .73021 .61821 L F
0 .31 .759 r
.73123 .61682 m .73226 .61778 L .73094 .61701 L F
.73123 .61682 m .73094 .61701 L .72941 .61612 L F
.415 .145 .393 r
.38504 .73475 m .38675 .73586 L .38693 .73451 L F
.38504 .73475 m .38445 .73671 L .38675 .73586 L F
.352 .096 .379 r
.62308 .62045 m .62548 .61771 L .62343 .61846 L F
.591 .539 .765 r
.40817 .77997 m .40609 .78051 L .40519 .7773 L F
.737 .439 .476 r
.51405 .78858 m .51106 .79028 L .51099 .78809 L F
.51405 .78858 m .51461 .79039 L .51106 .79028 L F
.621 .514 .711 r
.36432 .76937 m .36718 .77194 L .36631 .769 L F
.36432 .76937 m .36493 .77229 L .36718 .77194 L F
.945 .872 .734 r
.72288 .74189 m .72232 .74283 L .72392 .74277 L F
.634 .738 .923 r
.48804 .72258 m .48918 .724 L .48589 .72323 L F
.579 .669 .9 r
.49015 .7221 m .48918 .724 L .48804 .72258 L F
.49015 .7221 m .49137 .72364 L .48918 .724 L F
.805 .619 .651 r
.58237 .69061 m .58098 .69399 L .58153 .6915 L F
.762 .568 .635 r
.58378 .69366 m .58098 .69399 L .58237 .69061 L F
.572 .784 .979 r
.69928 .62332 m .7002 .62478 L .6979 .62525 L F
.692 .938 .964 r
.4048 .79285 m .40419 .79334 L .40865 .79209 L F
.4048 .79285 m .40865 .79209 L .40691 .79246 L F
.096 0 0 r
.41081 .79159 m .40691 .79246 L .40865 .79209 L F
.352 0 0 r
.42395 .72582 m .42615 .72559 L .42742 .72423 L F
.202 0 0 r
.42615 .72559 m .42948 .72412 L .42742 .72423 L F
.538 .436 .686 r
.29307 .61294 m .29363 .61559 L .2916 .61609 L F
.292 .017 .313 r
.29363 .61559 m .29129 .61806 L .2916 .61609 L F
.765 .646 .73 r
.57143 .67759 m .57311 .68016 L .56956 .67997 L F
.773 .549 .595 r
.57311 .68016 m .56953 .68279 L .56956 .67997 L F
.57311 .68016 m .57318 .68336 L .56953 .68279 L F
.616 .706 .909 r
.70568 .62524 m .7034 .62663 L .70334 .62619 L F
.70568 .62524 m .70654 .62686 L .7034 .62663 L F
.233 0 .23 r
.63802 .66146 m .63779 .66341 L .63603 .66426 L F
0 0 0 r
.64053 .65872 m .63952 .66045 L .63802 .66146 L F
0 0 .148 r
.63952 .66045 m .63779 .66341 L .63802 .66146 L F
.674 .638 .806 r
.70111 .62816 m .70206 .6279 L .70334 .62619 L F
.128 0 0 r
.63263 .60575 m .63156 .6053 L .63167 .60723 L F
.63263 .60575 m .63404 .60494 L .63156 .6053 L F
.675 .634 .801 r
.37031 .65611 m .36799 .65666 L .36721 .6545 L F
.199 .35 .792 r
.36996 .65832 m .36799 .65666 L .37031 .65611 L F
.141 0 0 r
.32021 .68138 m .31974 .68037 L .32103 .68143 L F
.32021 .68138 m .31808 .68259 L .31974 .68037 L F
.59 .115 .096 r
.32214 .68091 m .32103 .68143 L .31974 .68037 L F
.126 0 0 r
.72003 .71582 m .71673 .71618 L .71791 .71631 L F
.258 0 0 r
.44019 .78249 m .43935 .78328 L .4372 .78372 L F
.318 0 0 r
.44093 .78354 m .44019 .78249 L .44228 .78217 L F
.44093 .78354 m .43935 .78328 L .44019 .78249 L F
.508 .56 .844 r
.68372 .58655 m .68569 .58683 L .68602 .58506 L F
.549 .565 .823 r
.37857 .66123 m .37791 .66458 L .37678 .6613 L F
.37857 .66123 m .37983 .66427 L .37791 .66458 L F
.497 .502 .791 r
.38049 .66595 m .37791 .66458 L .37983 .66427 L F
.41 .128 .371 r
.37984 .68636 m .37939 .68806 L .37749 .68844 L F
.358 .034 .272 r
.38188 .68602 m .37939 .68806 L .37984 .68636 L F
0 .15 .66 r
.54013 .77057 m .54092 .77164 L .53845 .7695 L F
.536 .405 .649 r
.54092 .77164 m .53878 .7722 L .53845 .7695 L F
0 .15 .66 r
.54013 .77057 m .53845 .7695 L .53695 .77126 L F
.82 .72 .755 r
.60218 .66634 m .60486 .6669 L .60593 .6646 L F
.838 .65 .648 r
.60218 .66634 m .60379 .66928 L .60486 .6669 L F
.471 .827 .996 r
.72329 .71604 m .7223 .7154 L .72003 .71582 L F
.356 .724 .987 r
.72329 .71604 m .72427 .71516 L .7223 .7154 L F
.72329 .71604 m .72556 .71608 L .72427 .71516 L F
.642 .661 .852 r
.34657 .80743 m .34795 .81017 L .34985 .8093 L F
.739 .652 .764 r
.51477 .72615 m .51092 .72396 L .51336 .72357 L F
.51477 .72615 m .51261 .72676 L .51092 .72396 L F
.71 .74 .875 r
.51675 .72401 m .51477 .72615 L .51336 .72357 L F
.599 .557 .778 r
.51675 .72401 m .51793 .72741 L .51477 .72615 L F
.688 .533 .671 r
.51799 .72885 m .51477 .72615 L .51793 .72741 L F
.51799 .72885 m .516 .72954 L .51477 .72615 L F
.178 .367 .814 r
.40565 .77391 m .40482 .77494 L .40373 .77262 L F
.14 .31 .775 r
.40565 .77391 m .40697 .77695 L .40482 .77494 L F
.473 .375 .663 r
.40697 .77695 m .40519 .7773 L .40482 .77494 L F
.333 0 .155 r
.52275 .78834 m .52371 .78957 L .52242 .79072 L F
.52275 .78834 m .52494 .78752 L .52371 .78957 L F
.331 .062 .347 r
.61169 .62929 m .61366 .62843 L .61397 .62674 L F
.501 .208 .4 r
.61366 .62843 m .61594 .6281 L .61397 .62674 L F
.488 .215 .426 r
.61594 .6281 m .6162 .62627 L .61397 .62674 L F
.732 .373 0 r
.73063 .71398 m .73044 .71316 L .72864 .71212 L F
0 .291 .779 r
.73027 .71341 m .73063 .71398 L .72971 .71316 L F
.732 .373 0 r
.73063 .71398 m .73097 .7145 L .73044 .71316 L F
0 .291 .779 r
.73151 .71397 m .73063 .71398 L .73027 .71341 L F
.732 .373 0 r
.73063 .71398 m .73117 .715 L .73097 .7145 L F
.564 .73 .953 r
.69559 .64111 m .69728 .6392 L .69398 .64042 L F
.69559 .64111 m .69842 .6407 L .69728 .6392 L F
.827 .663 .68 r
.60401 .66368 m .60593 .6646 L .60435 .66136 L F
.82 .72 .755 r
.60218 .66634 m .60593 .6646 L .60401 .66368 L F
.261 0 0 r
.43624 .74049 m .43515 .74126 L .433 .74134 L F
.451 0 0 r
.43624 .74049 m .43881 .74113 L .43515 .74126 L F
.603 .034 0 r
.50415 .78344 m .50108 .78226 L .50238 .78241 L F
.54 .29 .485 r
.38003 .73967 m .38221 .73942 L .38269 .7373 L F
.385 .149 .429 r
.38269 .7373 m .38221 .73942 L .38445 .73671 L F
.3 .006 .286 r
.37283 .69627 m .37037 .69869 L .37107 .69698 L F
.549 .442 .684 r
.37204 .80482 m .37312 .80207 L .37089 .80129 L F
.37204 .80482 m .37411 .80446 L .37312 .80207 L F
.272 .74 .945 r
.34748 .65068 m .34685 .65124 L .34541 .65021 L F
.34748 .65068 m .34876 .65115 L .34685 .65124 L F
.395 .136 .399 r
.38855 .67945 m .38606 .68195 L .38681 .68021 L F
.57 .893 .987 r
.41152 .77958 m .40817 .77997 L .41041 .77925 L F
.186 .697 .898 r
.41041 .77925 m .41361 .77958 L .41152 .77958 L F
.342 .816 .757 r
.33227 .71291 m .33328 .71235 L .33429 .71246 L F
.33227 .71291 m .33014 .7135 L .33328 .71235 L F
.519 .215 .39 r
.30358 .66351 m .30647 .66156 L .3043 .66209 L F
.577 .452 .673 r
.36493 .77229 m .36731 .7744 L .36718 .77194 L F
.36493 .77229 m .36519 .77475 L .36731 .7744 L F
.697 .575 .715 r
.50288 .72313 m .50037 .7258 L .50033 .7237 L F
.50288 .72313 m .50361 .72625 L .50037 .7258 L F
.796 .762 .822 r
.69608 .57997 m .69374 .58307 L .69286 .57989 L F
.142 0 .16 r
.44512 .77114 m .44352 .77221 L .44555 .77136 L F
.558 .272 .438 r
.4421 .77368 m .44555 .77136 L .44352 .77221 L F
.332 .791 .944 r
.47729 .73388 m .47595 .73353 L .47382 .73381 L F
.211 .731 .861 r
.4793 .73347 m .47595 .73353 L .47729 .73388 L F
.514 .218 .402 r
.59466 .69095 m .59371 .69318 L .59157 .69361 L F
.669 .419 .533 r
.59689 .69094 m .59371 .69318 L .59466 .69095 L F
.579 .256 .386 r
.31488 .68141 m .31246 .68475 L .31046 .68491 L F
.418 .222 .506 r
.3161 .68085 m .31636 .68407 L .31488 .68141 L F
.711 .665 .803 r
.31636 .68407 m .31246 .68475 L .31488 .68141 L F
.512 .344 .59 r
.36325 .77745 m .36514 .77716 L .36519 .77475 L F
.599 .372 .543 r
.36325 .77745 m .36513 .77947 L .36514 .77716 L F
.36325 .77745 m .36287 .77983 L .36513 .77947 L F
.053 0 .332 r
.64002 .61801 m .63969 .62087 L .63875 .62117 L F
.158 .221 .679 r
.63969 .62087 m .64047 .62324 L .63875 .62117 L F
.695 .679 .831 r
.51917 .73207 m .516 .73157 L .51786 .7315 L F
.614 .876 .991 r
.52156 .73155 m .51917 .73207 L .52014 .73078 L F
.602 .86 .992 r
.51917 .73207 m .51786 .7315 L .52014 .73078 L F
.661 .585 .758 r
.52259 .73464 m .51917 .73207 L .52156 .73155 L F
.7 .285 .255 r
.5033 .77695 m .5051 .77771 L .50671 .77721 L F
.633 .286 .365 r
.5051 .77771 m .50874 .77702 L .50671 .77721 L F
.88 .679 .627 r
.72671 .72864 m .72568 .72866 L .72597 .7266 L F
.879 .675 .623 r
.72671 .72864 m .72729 .7313 L .72568 .72866 L F
.737 .213 0 r
.35963 .68318 m .3628 .68587 L .35943 .6856 L F
.504 .322 .568 r
.35943 .6856 m .36141 .68523 L .35963 .68318 L F
.737 .213 0 r
.35963 .68318 m .36141 .68523 L .3628 .68587 L F
.581 .798 .982 r
.68704 .63014 m .68828 .63124 L .6861 .63084 L F
.35 .565 .918 r
.68886 .62996 m .68828 .63124 L .68704 .63014 L F
.487 .308 .564 r
.69019 .62908 m .69015 .63152 L .68828 .63124 L F
.35 .565 .918 r
.68886 .62996 m .69015 .63152 L .68828 .63124 L F
.876 .858 .82 r
.70034 .63941 m .70156 .64039 L .7033 .6377 L F
.726 .622 .742 r
.50174 .7448 m .50498 .74516 L .50409 .74202 L F
.662 .584 .757 r
.50409 .74202 m .50498 .74516 L .50695 .74292 L F
.096 0 .093 r
.36063 .68859 m .35814 .69116 L .35986 .69023 L F
.117 0 .199 r
.3628 .68587 m .36063 .68859 L .36217 .68771 L F
.479 .244 .479 r
.35986 .69023 m .36217 .68771 L .36063 .68859 L F
.56 .345 .544 r
.35864 .78287 m .3608 .78264 L .36114 .78037 L F
.585 .366 .551 r
.36114 .78037 m .36256 .7824 L .36287 .77983 L F
.36114 .78037 m .3608 .78264 L .36256 .7824 L F
.613 .464 .655 r
.36631 .769 m .36871 .76635 L .36646 .76682 L F
.922 .976 .745 r
.63037 .64348 m .63 .64559 L .62917 .64527 L F
.996 .835 .565 r
.62917 .64527 m .63 .64559 L .62963 .64786 L F
.47 .781 .998 r
.47352 .7243 m .47273 .72538 L .47157 .72447 L F
.47352 .7243 m .47467 .72516 L .47273 .72538 L F
.681 .577 .732 r
.52421 .73259 m .52259 .73464 L .52156 .73155 L F
.714 .626 .758 r
.52421 .73259 m .5252 .7339 L .52259 .73464 L F
.613 .139 .105 r
.71552 .70696 m .71791 .70824 L .71889 .70708 L F
.697 .181 0 r
.7201 .70907 m .71889 .70708 L .71791 .70824 L F
.7201 .70907 m .7214 .70899 L .71889 .70708 L F
.628 .741 .929 r
.69626 .5936 m .6996 .59445 L .69854 .59334 L F
.601 .805 .978 r
.6996 .59445 m .70183 .59378 L .69854 .59334 L F
.416 .248 .544 r
.37939 .68806 m .37764 .69079 L .37749 .68844 L F
.499 .052 .12 r
.47771 .77516 m .47652 .77668 L .47427 .77658 L F
.551 .119 .174 r
.4797 .77554 m .47652 .77668 L .47771 .77516 L F
.748 .526 .594 r
.68237 .6229 m .67902 .62294 L .68113 .62065 L F
.13 .315 .783 r
.67902 .62294 m .68052 .62213 L .68049 .62212 L F
0 0 0 r
.68113 .62065 m .67902 .62294 L .678 .62351 L F
.13 .315 .783 r
.67902 .62294 m .68049 .62212 L .67819 .62124 L F
0 0 0 r
.678 .62351 m .67902 .62294 L .67777 .62373 L F
.714 .339 .337 r
.6767 .62553 m .68 .62606 L .67777 .62373 L F
0 0 0 r
.67902 .62294 m .6767 .62553 L .67777 .62373 L F
.113 0 0 r
.34213 .72318 m .33952 .725 L .34036 .72395 L F
.56 .422 .65 r
.36983 .75584 m .37209 .75844 L .37163 .75534 L F
.36983 .75584 m .37001 .75883 L .37209 .75844 L F
.565 .881 .992 r
.67984 .60923 m .68264 .60905 L .68233 .60744 L F
.726 .819 .923 r
.68233 .60744 m .68264 .60905 L .68559 .60786 L F
.608 .593 .81 r
.4949 .73741 m .49824 .7399 L .49712 .73678 L F
.564 .571 .819 r
.49824 .7399 m .49918 .73652 L .49712 .73678 L F
.49824 .7399 m .50036 .73962 L .49918 .73652 L F
.705 .853 .953 r
.70564 .63728 m .70887 .6372 L .70806 .63664 L F
.995 .855 .586 r
.70848 .63424 m .70887 .6372 L .71104 .63453 L F
.70848 .63424 m .70806 .63664 L .70887 .6372 L F
.572 .258 .397 r
.64467 .61194 m .64683 .61245 L .64601 .61438 L F
.921 .874 .774 r
.5733 .67466 m .57029 .67681 L .57205 .67365 L F
.5733 .67466 m .57143 .67759 L .57029 .67681 L F
.917 .85 .762 r
.57392 .67295 m .5733 .67466 L .57205 .67365 L F
.339 .21 .555 r
.62763 .61296 m .62969 .61205 L .62964 .60975 L F
.432 .273 .565 r
.62713 .61536 m .62969 .61205 L .62763 .61296 L F
.994 .841 .58 r
.38757 .66581 m .38819 .66709 L .38901 .66431 L F
.38901 .66431 m .38819 .66709 L .38757 .66581 L F
0 0 0 r
.44444 .78187 m .44798 .78007 L .44655 .78164 L F
.343 0 0 r
.44798 .78007 m .44869 .78132 L .44655 .78164 L F
.44798 .78007 m .45014 .7799 L .44869 .78132 L F
.258 0 0 r
.38548 .80124 m .38747 .79885 L .38966 .7982 L F
.536 .392 .633 r
.36837 .76385 m .37025 .76108 L .36811 .76145 L F
.331 0 .215 r
.6219 .63772 m .62136 .63917 L .61935 .63962 L F
.149 0 0 r
.6219 .63772 m .62327 .63812 L .62136 .63917 L F
.6219 .63772 m .62457 .6373 L .62327 .63812 L F
.604 .458 .656 r
.33752 .80211 m .33996 .80396 L .3401 .80181 L F
.33752 .80211 m .33782 .80435 L .33996 .80396 L F
.697 .53 .657 r
.38959 .8092 m .39204 .80716 L .38926 .80695 L F
.445 .835 .984 r
.47382 .73381 m .47257 .73336 L .47167 .73423 L F
.512 .864 .615 r
.47257 .73336 m .47055 .73502 L .47167 .73423 L F
.386 0 0 r
.72866 .71752 m .72738 .71705 L .72556 .71608 L F
.839 .897 .478 r
.72866 .71752 m .72739 .71925 L .72738 .71705 L F
.72866 .71752 m .72722 .72057 L .72739 .71925 L F
.745 .25 .054 r
.49405 .7797 m .49096 .77819 L .49196 .77821 L F
.997 .795 .514 r
.66766 .60458 m .66795 .60235 L .66706 .60085 L F
.907 .58 .414 r
.70736 .7037 m .70866 .70225 L .7058 .70126 L F
.70736 .7037 m .70885 .70423 L .70866 .70225 L F
.459 .084 .24 r
.60865 .63145 m .61076 .63116 L .61169 .62929 L F
.562 .29 .462 r
.61076 .63116 m .61366 .62843 L .61169 .62929 L F
.851 .698 .691 r
.70848 .63424 m .71104 .63453 L .70957 .63417 L F
.064 .363 .833 r
.71104 .63453 m .71128 .63443 L .70957 .63417 L F
.71104 .63453 m .71063 .6335 L .71128 .63443 L F
.741 .699 .811 r
.50887 .72449 m .5058 .72557 L .50795 .72301 L F
.62 .673 .879 r
.51092 .72396 m .50887 .72449 L .50795 .72301 L F
.691 .977 .801 r
.51591 .78075 m .51598 .78011 L .51765 .77902 L F
.51591 .78075 m .51396 .78162 L .51598 .78011 L F
.474 .545 .849 r
.52697 .73368 m .5252 .7339 L .52421 .73259 L F
.35 .292 .651 r
.52722 .73634 m .5252 .7339 L .52697 .73368 L F
.52722 .73634 m .52559 .73783 L .5252 .7339 L F
.456 .813 .997 r
.35943 .6856 m .36141 .68523 L .3628 .68587 L F
.884 .88 .825 r
.3628 .68587 m .36141 .68523 L .3633 .68239 L F
.818 .669 .697 r
.72729 .7313 m .72452 .73194 L .72568 .72866 L F
.573 .786 .979 r
.72587 .73361 m .72452 .73194 L .72729 .7313 L F
.334 .542 .906 r
.35644 .65209 m .35574 .65347 L .35491 .65193 L F
.487 .729 .979 r
.35644 .65209 m .35777 .65329 L .35574 .65347 L F
.489 .219 .432 r
.30449 .68869 m .30393 .69061 L .30187 .69109 L F
.453 .186 .417 r
.30602 .69013 m .30449 .68869 L .30629 .68809 L F
.30602 .69013 m .30393 .69061 L .30449 .68869 L F
.592 .465 .676 r
.6401 .61736 m .64245 .61801 L .64002 .61801 L F
.6401 .61736 m .64305 .61475 L .64245 .61801 L F
.351 0 0 r
.42948 .72412 m .43144 .72459 L .43288 .72406 L F
.704 .58 .713 r
.5058 .72557 m .50361 .72625 L .50288 .72313 L F
.649 .617 .804 r
.49368 .73438 m .4949 .73741 L .49712 .73678 L F
.563 .31 .49 r
.64245 .61801 m .63969 .62087 L .64002 .61801 L F
0 0 .014 r
.70302 .6014 m .70308 .6014 L .70322 .59857 L F
0 0 0 r
.70514 .59883 m .70308 .6014 L .70302 .6014 L F
.652 .849 .976 r
.69215 .58872 m .69301 .58974 L .69512 .58877 L F
.84 .745 .759 r
.51278 .74542 m .51567 .7451 L .515 .74447 L F
.51278 .74542 m .51384 .74785 L .51567 .7451 L F
.824 .979 .887 r
.515 .74447 m .51567 .7451 L .51835 .74261 L F
.622 .469 .654 r
.37575 .74517 m .3781 .74497 L .37785 .74245 L F
.588 .376 .561 r
.37575 .74517 m .37789 .74723 L .3781 .74497 L F
.37575 .74517 m .37559 .74751 L .37789 .74723 L F
.744 .236 0 r
.71572 .73504 m .71715 .73703 L .71817 .73744 L F
.76 .251 0 r
.71812 .73857 m .71817 .73744 L .71715 .73703 L F
.71812 .73857 m .71984 .73926 L .71831 .73758 L F
.386 .442 .796 r
.71722 .74052 m .71934 .7417 L .71812 .73857 L F
.707 .231 0 r
.71926 .73965 m .71984 .73926 L .71812 .73857 L F
.72093 .74125 m .72013 .73978 L .71926 .73965 L F
.72013 .73978 m .71984 .73926 L .71926 .73965 L F
.72093 .74125 m .71926 .73965 L .71934 .7417 L F
.71926 .73965 m .71812 .73857 L .71911 .74111 L F
.71926 .73965 m .71911 .74111 L .71934 .7417 L F
.391 .426 .777 r
.71945 .73766 m .71903 .73962 L .71801 .73946 L F
.71964 .73742 m .71938 .73835 L .71945 .73766 L F
.71938 .73835 m .71903 .73962 L .71945 .73766 L F
.71801 .73946 m .7189 .74008 L .71746 .74015 L F
.71903 .73962 m .7189 .74008 L .71801 .73946 L F
.71964 .73742 m .71793 .73956 L .71812 .73857 L F
.71793 .73956 m .71746 .74015 L .71812 .73857 L F
.76 .251 0 r
.71812 .73857 m .71831 .73758 L .71817 .73744 L F
.809 .999 .839 r
.5751 .6719 m .57392 .67295 L .57464 .67134 L F
.825 1 .822 r
.5751 .6719 m .57702 .66884 L .57807 .66952 L F
.5751 .6719 m .57464 .67134 L .57702 .66884 L F
.297 .785 .896 r
.35156 .67312 m .35227 .67262 L .34991 .67297 L F
.35156 .67312 m .35348 .67277 L .35227 .67262 L F
.825 .713 .742 r
.6032 .65824 m .6067 .65649 L .60572 .65576 L F
.6032 .65824 m .60487 .65914 L .6067 .65649 L F
.947 .878 .734 r
.60739 .65227 m .60572 .65576 L .6067 .65649 L F
.919 .763 .672 r
.69859 .58419 m .70053 .58609 L .69969 .5831 L F
.761 .509 .552 r
.69715 .587 m .70053 .58609 L .69859 .58419 L F
.69715 .587 m .70289 .58999 L .70053 .58609 L F
.49 .456 .747 r
.35169 .69416 m .35325 .69461 L .35246 .69291 L F
.395 0 .104 r
.35325 .69597 m .35169 .69416 L .35325 .69461 L F
.782 .648 .714 r
.63259 .62355 m .63444 .627 L .63241 .62608 L F
.779 .705 .782 r
.63444 .627 m .63248 .6288 L .63241 .62608 L F
.621 .528 .728 r
.39796 .77204 m .39585 .77243 L .39509 .76918 L F
.551 .646 .897 r
.67328 .63019 m .67358 .63057 L .67256 .62837 L F
.524 .646 .911 r
.67358 .63057 m .67473 .62816 L .67256 .62837 L F
.67358 .63057 m .67569 .63056 L .67473 .62816 L F
.644 .107 0 r
.51774 .79126 m .51666 .792 L .51461 .79039 L F
.469 0 0 r
.52021 .79139 m .51666 .792 L .51774 .79126 L F
.846 .816 .332 r
.668 .59448 m .66799 .59532 L .66851 .59344 L F
0 .055 .62 r
.668 .59448 m .66814 .59483 L .66799 .59532 L F
.733 .891 .499 r
.66799 .59532 m .66773 .5962 L .66903 .59403 L F
.98 .706 .43 r
.66903 .59403 m .66913 .59625 L .66799 .59532 L F
.733 .891 .499 r
.66799 .59532 m .66903 .59403 L .66851 .59344 L F
.98 .706 .43 r
.66903 .59403 m .66799 .59532 L .66851 .59344 L F
0 .22 .741 r
.66799 .59532 m .67002 .59734 L .66834 .59439 L F
0 .055 .62 r
.66814 .59483 m .66889 .59665 L .66799 .59532 L F
.733 .891 .499 r
.66799 .59532 m .66754 .59651 L .66773 .5962 L F
0 0 .413 r
.66889 .59665 m .66754 .59651 L .66799 .59532 L F
.66889 .59665 m .66754 .59902 L .66754 .59651 L F
.279 .006 .308 r
.2893 .62162 m .28911 .62314 L .28738 .6238 L F
.408 .2 .483 r
.29116 .62037 m .28911 .62314 L .2893 .62162 L F
.668 .281 .304 r
.32899 .67894 m .32597 .6789 L .32741 .67853 L F
.411 0 .136 r
.53226 .78056 m .53385 .78136 L .53183 .78231 L F
.53226 .78056 m .53461 .7804 L .53385 .78136 L F
.231 0 .043 r
.33817 .72695 m .33769 .7256 L .33952 .725 L F
.33817 .72695 m .33624 .72764 L .33769 .7256 L F
.704 .58 .713 r
.5058 .72557 m .50288 .72313 L .50637 .72441 L F
.836 .902 .885 r
.50795 .72301 m .5058 .72557 L .50637 .72441 L F
.278 0 .244 r
.35428 .71504 m .35178 .71744 L .35253 .71571 L F
.773 .916 .935 r
.66332 .61441 m .66458 .61534 L .66714 .61318 L F
.393 .506 .854 r
.35942 .78603 m .36051 .78486 L .35917 .78487 L F
.35942 .78603 m .36201 .78792 L .36051 .78486 L F
.684 .764 .912 r
.51359 .73467 m .51156 .73497 L .51029 .73397 L F
.717 .213 .034 r
.67676 .59746 m .67783 .59686 L .67452 .59588 L F
.971 .666 .379 r
.67806 .59902 m .67783 .59686 L .67676 .59746 L F
.673 .608 .775 r
.35699 .67471 m .35888 .67858 L .36038 .67701 L F
.768 .399 .356 r
.49467 .7741 m .49669 .77638 L .49783 .77478 L F
.801 .443 .379 r
.49669 .77638 m .49991 .77729 L .49783 .77478 L F
.734 .673 .791 r
.50288 .72313 m .50033 .7237 L .50309 .72182 L F
.634 .539 .729 r
.50474 .72045 m .50288 .72313 L .50309 .72182 L F
.50474 .72045 m .50637 .72441 L .50288 .72313 L F
0 0 0 r
.41487 .7905 m .41526 .79034 L .41588 .79026 L F
.383 .843 .786 r
.4168 .78969 m .41487 .7905 L .41588 .79026 L F
.247 0 0 r
.4168 .78969 m .41442 .79069 L .41487 .7905 L F
.41442 .79069 m .41314 .79124 L .41487 .7905 L F
0 0 0 r
.41487 .7905 m .41381 .79053 L .41526 .79034 L F
.41487 .7905 m .41287 .79105 L .41381 .79053 L F
0 0 .268 r
.72328 .73659 m .72375 .73702 L .72349 .73323 L F
.467 0 0 r
.72328 .73659 m .72492 .73788 L .72375 .73702 L F
.079 0 0 r
.73028 .7412 m .73064 .7415 L .72813 .74196 L F
0 0 0 r
.73216 .73848 m .73028 .7412 L .73309 .73907 L F
.73216 .73848 m .73064 .7415 L .73028 .7412 L F
.633 .676 .873 r
.70163 .58026 m .70542 .58253 L .70374 .57972 L F
.806 .732 .782 r
.70374 .57972 m .70542 .58253 L .70719 .57897 L F
.645 .817 .966 r
.35864 .78287 m .35603 .78311 L .35511 .78255 L F
.35864 .78287 m .35603 .78311 L .35511 .78255 L F
.312 .114 .443 r
.35917 .78487 m .3608 .78264 L .35864 .78287 L F
.731 .571 .674 r
.57711 .69102 m .57369 .6884 L .577 .68874 L F
.997 .845 .566 r
.73214 .72872 m .7317 .73109 L .73251 .73169 L F
.997 .767 .435 r
.7317 .73109 m .73245 .73403 L .73251 .73169 L F
.984 .78 .549 r
.62546 .63318 m .62603 .6343 L .62681 .63307 L F
.907 .972 .802 r
.62681 .63307 m .6273 .63012 L .62546 .63318 L F
.651 .76 .929 r
.4948 .72428 m .49137 .72364 L .49352 .72311 L F
.684 .806 .94 r
.49691 .72333 m .4948 .72428 L .49352 .72311 L F
.935 .945 .607 r
.72597 .7266 m .72694 .72297 L .72792 .72368 L F
.354 .161 .474 r
.28911 .62314 m .28711 .62601 L .28738 .6238 L F
.174 0 0 r
.42371 .78794 m .41987 .7893 L .42172 .78855 L F
.529 .355 .589 r
.39557 .76115 m .3936 .76393 L .39371 .7618 L F
0 0 0 r
.7134 .6186 m .70978 .62 L .71192 .61619 L F
.082 0 0 r
.71007 .62041 m .7134 .6186 L .7121 .61934 L F
.364 .527 .885 r
.71461 .61713 m .7134 .6186 L .71192 .61619 L F
.63 .935 .695 r
.7121 .61934 m .7134 .6186 L .71461 .61713 L F
.939 .79 .669 r
.51984 .7331 m .52177 .73386 L .52014 .73078 L F
.252 0 0 r
.51803 .73571 m .52177 .73386 L .51984 .7331 L F
.51803 .73571 m .5209 .73511 L .52177 .73386 L F
.614 .876 .991 r
.52156 .73155 m .51799 .72885 L .52061 .7289 L F
.52156 .73155 m .52014 .73078 L .51799 .72885 L F
.615 .621 .834 r
.52251 .72858 m .52156 .73155 L .52061 .7289 L F
.52251 .72858 m .52398 .73096 L .52156 .73155 L F
.681 .577 .732 r
.52421 .73259 m .52156 .73155 L .52398 .73096 L F
.491 .539 .833 r
.5257 .73071 m .52421 .73259 L .52398 .73096 L F
.5257 .73071 m .52697 .73368 L .52421 .73259 L F
.662 .708 .882 r
.52014 .73078 m .52177 .73386 L .52559 .73152 L F
.019 0 0 r
.52177 .73386 m .5224 .73467 L .52559 .73152 L F
.549 .572 .83 r
.52903 .73335 m .52697 .73368 L .5257 .73071 L F
.824 .706 .734 r
.5224 .73467 m .52546 .73506 L .52701 .73223 L F
.5224 .73467 m .52701 .73223 L .52559 .73152 L F
.556 .616 .868 r
.52369 .73182 m .52417 .73455 L .5224 .73467 L F
.694 .272 .239 r
.52417 .73455 m .52319 .73452 L .5224 .73467 L F
.019 0 0 r
.52177 .73386 m .52101 .73495 L .5224 .73467 L F
.96 .714 .521 r
.5224 .73467 m .52103 .73445 L .52113 .73199 L F
.556 .616 .868 r
.52369 .73182 m .5227 .73402 L .52113 .73199 L F
.5227 .73402 m .5224 .73467 L .52191 .73364 L F
.5227 .73402 m .52191 .73364 L .52113 .73199 L F
.694 .272 .239 r
.52319 .73452 m .52103 .73445 L .5224 .73467 L F
.019 0 0 r
.52101 .73495 m .5209 .73511 L .5224 .73467 L F
.707 .742 .878 r
.52167 .73841 m .5224 .73467 L .5209 .73511 L F
.52167 .73841 m .52367 .73622 L .5224 .73467 L F
.801 .762 .817 r
.5224 .73467 m .52367 .73622 L .52546 .73506 L F
.694 .272 .239 r
.52378 .73454 m .5232 .73633 L .52103 .73445 L F
.52417 .73455 m .5241 .73469 L .52378 .73454 L F
.5241 .73469 m .5232 .73633 L .52378 .73454 L F
.307 .767 .949 r
.71828 .59855 m .71749 .59914 L .71629 .59623 L F
.71828 .59855 m .7196 .59891 L .71749 .59914 L F
.466 .637 .93 r
.69476 .63056 m .69352 .63255 L .69254 .63142 L F
.69476 .63056 m .69611 .63282 L .69352 .63255 L F
.577 .575 .815 r
.69683 .63444 m .69352 .63255 L .69611 .63282 L F
.427 .416 .744 r
.39589 .76564 m .39509 .76918 L .39425 .76724 L F
.39589 .76564 m .39673 .76904 L .39509 .76918 L F
.621 .528 .728 r
.39796 .77204 m .39509 .76918 L .39673 .76904 L F
.437 .054 .213 r
.34073 .70944 m .34422 .70708 L .34234 .70783 L F
.543 .38 .609 r
.34882 .70191 m .35086 .69872 L .34871 .69912 L F
.856 .699 .687 r
.65033 .63099 m .65154 .63414 L .65321 .63119 L F
.917 .85 .762 r
.57392 .67295 m .57205 .67365 L .57464 .67134 L F
.524 .175 .318 r
.51765 .77902 m .51989 .77928 L .52097 .77728 L F
.935 .945 .607 r
.72597 .7266 m .72551 .72668 L .72694 .72297 L F
.996 .845 .5 r
.72568 .72866 m .72551 .72668 L .72597 .7266 L F
.804 1 .831 r
.72378 .6179 m .72156 .62001 L .72099 .61969 L F
.484 .825 .54 r
.3559 .80734 m .35546 .80767 L .35437 .80668 L F
.3559 .80734 m .35792 .80553 L .35546 .80767 L F
.898 .934 .829 r
.58264 .66191 m .58069 .66442 L .57995 .66349 L F
.947 .904 .747 r
.57964 .66656 m .57995 .66349 L .58069 .66442 L F
.481 .631 .919 r
.70789 .62528 m .70654 .62686 L .70568 .62524 L F
.589 .801 .981 r
.70789 .62528 m .70902 .62631 L .70654 .62686 L F
.819 .746 .783 r
.63991 .64036 m .63786 .64327 L .63605 .64199 L F
.826 .743 .772 r
.63786 .64327 m .63644 .64493 L .63605 .64199 L F
.898 .934 .829 r
.58264 .66191 m .57995 .66349 L .58039 .66268 L F
.878 .94 .854 r
.58494 .65933 m .58264 .66191 L .58269 .6599 L F
.888 .946 .842 r
.58269 .6599 m .58264 .66191 L .58039 .66268 L F
.344 0 .193 r
.35814 .69116 m .35927 .69239 L .35986 .69023 L F
.35814 .69116 m .35731 .69286 L .35927 .69239 L F
.379 .156 .445 r
.38989 .73431 m .39159 .73514 L .393 .73415 L F
.27 0 0 r
.393 .73415 m .39563 .7341 L .39541 .73415 L F
.393 .73415 m .39159 .73514 L .39563 .7341 L F
.901 .587 .094 r
.66903 .59403 m .66851 .59344 L .66799 .59088 L F
.041 0 0 r
.32521 .6516 m .32899 .65054 L .327 .65099 L F
.52 .338 .573 r
.327 .65099 m .32899 .65054 L .3291 .64802 L F
.776 .569 .618 r
.70374 .57972 m .70719 .57771 L .70454 .57666 L F
.70374 .57972 m .70719 .57897 L .70719 .57771 L F
.158 .257 .717 r
.69602 .62883 m .69806 .63081 L .69691 .62869 L F
.485 .284 .532 r
.37785 .74245 m .37978 .74216 L .38003 .73967 L F
.535 .416 .664 r
.3781 .74497 m .37978 .74216 L .37785 .74245 L F
.107 .654 .826 r
.43501 .72404 m .43725 .72403 L .43847 .72422 L F
.386 0 0 r
.43725 .72403 m .44061 .72401 L .43847 .72422 L F
.407 .537 .875 r
.70889 .61714 m .70978 .62 L .70737 .61849 L F
.705 .265 .203 r
.70737 .61849 m .71007 .62041 L .70671 .61987 L F
0 0 0 r
.70889 .61714 m .70737 .61849 L .70671 .61987 L F
.852 .603 .561 r
.60379 .66928 m .60391 .67199 L .6067 .67234 L F
.832 .706 .724 r
.60323 .67385 m .6067 .67234 L .60391 .67199 L F
.60323 .67385 m .60429 .6745 L .6067 .67234 L F
.684 .447 .558 r
.60429 .6745 m .60682 .67453 L .6067 .67234 L F
.593 .34 .503 r
.60682 .67453 m .60953 .67187 L .6067 .67234 L F
0 .194 .725 r
.73117 .715 m .7333 .71706 L .73308 .71783 L F
.63 .09 0 r
.72431 .71001 m .72683 .71162 L .72719 .71086 L F
.71 .185 0 r
.72683 .71162 m .72864 .71212 L .72719 .71086 L F
.51 .343 .591 r
.67699 .61618 m .67771 .61611 L .67732 .61576 L F
0 0 0 r
.67725 .6159 m .67699 .61618 L .67732 .61576 L F
.638 .082 0 r
.67732 .61577 m .67875 .61594 L .67724 .61524 L F
.67732 .61577 m .67733 .61577 L .67732 .61577 L F
.51 .343 .591 r
.67732 .61576 m .6774 .61577 L .67905 .61348 L F
.638 .082 0 r
.67733 .61577 m .67875 .61594 L .67732 .61577 L F
.67733 .61577 m .67875 .61594 L .67732 .61577 L F
.686 .577 .728 r
.67905 .61348 m .68097 .61677 L .67738 .61579 L F
.51 .343 .591 r
.6774 .61577 m .67922 .61596 L .67908 .61385 L F
.6774 .61577 m .67908 .61385 L .67876 .61388 L F
.765 .76 .848 r
.67922 .61596 m .68097 .61677 L .67905 .61348 L F
.189 0 0 r
.6804 .61371 m .68151 .61399 L .67832 .6144 L F
.68136 .61339 m .68141 .6136 L .6804 .61371 L F
.68141 .6136 m .68151 .61399 L .6804 .61371 L F
.51 .343 .591 r
.67876 .61388 m .67908 .61385 L .67905 .61348 L F
.686 .577 .728 r
.67905 .61348 m .67738 .61579 L .67732 .61577 L F
.638 .082 0 r
.67732 .61577 m .67733 .61577 L .67732 .61577 L F
.686 .577 .728 r
.67905 .61348 m .67732 .61577 L .67699 .61618 L F
0 0 0 r
.67732 .6158 m .67732 .61576 L .67905 .61348 L F
.67725 .6159 m .67732 .61576 L .67732 .6158 L F
.638 .082 0 r
.6773 .61566 m .67724 .61524 L .67722 .61523 L F
.67732 .61577 m .67724 .61524 L .6773 .61566 L F
.51 .343 .591 r
.67771 .61611 m .67922 .61596 L .67732 .61576 L F
.081 0 .209 r
.67732 .61576 m .67758 .61458 L .67905 .61348 L F
.67699 .61618 m .67721 .61559 L .67732 .61576 L F
0 0 0 r
.67732 .61577 m .67722 .61523 L .67758 .61458 L F
.081 0 .209 r
.67721 .61559 m .67758 .61458 L .67732 .61576 L F
.839 .847 .851 r
.69286 .57989 m .69201 .58289 L .68923 .58058 L F
.336 .469 .846 r
.67504 .58605 m .67637 .58462 L .67413 .58528 L F
.67504 .58605 m .67704 .5869 L .67637 .58462 L F
.819 .654 .678 r
.63827 .63701 m .63991 .64036 L .63796 .63916 L F
.819 .746 .783 r
.63991 .64036 m .63605 .64199 L .63796 .63916 L F
.415 .138 .382 r
.29616 .66898 m .29864 .66665 L .29674 .66691 L F
.731 .571 .674 r
.57711 .69102 m .57508 .69133 L .57369 .6884 L F
.632 .472 .647 r
.57718 .69331 m .57508 .69133 L .57711 .69102 L F
.743 .556 .641 r
.58153 .6915 m .57718 .69331 L .57711 .69102 L F
.06 .607 .838 r
.33466 .64914 m .33669 .64931 L .33801 .64968 L F
.271 0 0 r
.33669 .64931 m .33916 .64942 L .33801 .64968 L F
0 0 .318 r
.6704 .5974 m .67093 .59944 L .67094 .59853 L F
0 0 .047 r
.67094 .59853 m .67093 .59944 L .67099 .60074 L F
.994 .747 .429 r
.67197 .60489 m .67092 .60649 L .67092 .60384 L F
.67197 .60489 m .67196 .60746 L .67092 .60649 L F
.466 .239 .484 r
.36838 .69919 m .36803 .70143 L .36608 .70185 L F
.464 .237 .483 r
.37005 .70088 m .36838 .69919 L .37037 .69869 L F
.37005 .70088 m .36803 .70143 L .36838 .69919 L F
.307 .205 .572 r
.53845 .77659 m .53692 .77458 L .53755 .77402 L F
.53845 .77659 m .53755 .77402 L .538 .77479 L F
.53845 .77659 m .53714 .77698 L .53692 .77458 L F
.538 .77479 m .53755 .77402 L .53775 .77383 L F
.841 .707 .716 r
.53727 .77356 m .53845 .77659 L .53775 .77383 L F
.755 .514 .568 r
.54092 .77164 m .53775 .77383 L .53878 .7722 L F
.54092 .77164 m .5407 .77392 L .53775 .77383 L F
.728 .755 .874 r
.53775 .77383 m .5407 .77392 L .53727 .77356 L F
.769 .676 .76 r
.5407 .77392 m .53845 .77659 L .53727 .77356 L F
.775 .423 .389 r
.53615 .77782 m .53814 .77503 L .53385 .77527 L F
.53814 .77503 m .53817 .77499 L .53812 .77499 L F
.53814 .77503 m .53812 .77499 L .53385 .77527 L F
.708 .597 .73 r
.51799 .72885 m .516 .73157 L .516 .72954 L F
.481 .296 .552 r
.51799 .72885 m .51786 .7315 L .516 .73157 L F
.51799 .72885 m .51786 .7315 L .516 .73157 L F
.801 .629 .669 r
.57369 .6884 m .5705 .68804 L .57112 .68585 L F
.8 .641 .685 r
.57369 .6884 m .57214 .69101 L .5705 .68804 L F
.755 .581 .66 r
.57369 .6884 m .57508 .69133 L .57214 .69101 L F
.439 0 .1 r
.41289 .72836 m .41504 .72831 L .41643 .72663 L F
.443 .002 .103 r
.41643 .72663 m .41504 .72831 L .41823 .72739 L F
.427 .201 .466 r
.36327 .80442 m .36544 .80174 L .36516 .80373 L F
.617 .856 .492 r
.36611 .80072 m .36544 .80174 L .3676 .79895 L F
0 0 .318 r
.6704 .5974 m .67094 .59853 L .66913 .59625 L F
.316 0 .133 r
.29864 .66665 m .30053 .66619 L .30179 .66425 L F
.336 0 .145 r
.30179 .66425 m .30262 .66564 L .30358 .66351 L F
.30179 .66425 m .30053 .66619 L .30262 .66564 L F
.749 .666 .769 r
.4991 .72073 m .50033 .7237 L .49691 .72333 L F
.727 .655 .779 r
.50309 .72182 m .50033 .7237 L .4991 .72073 L F
.732 .97 .714 r
.72297 .62564 m .72478 .62329 L .72213 .6251 L F
.72366 .62474 m .72518 .62335 L .72478 .62329 L F
.72387 .6247 m .72518 .62335 L .72366 .62474 L F
.055 0 0 r
.72213 .6251 m .72478 .62329 L .72422 .62453 L F
.201 .725 .719 r
.72138 .62524 m .72213 .6251 L .72307 .62484 L F
.72278 .62489 m .72307 .62484 L .72422 .62453 L F
.72138 .62524 m .72307 .62484 L .72278 .62489 L F
.732 .97 .714 r
.72297 .62564 m .72387 .6247 L .72366 .62474 L F
0 0 0 r
.72518 .62335 m .72695 .62174 L .72671 .62197 L F
.72695 .62174 m .72763 .62113 L .72671 .62197 L F
.53 0 0 r
.72671 .62197 m .72711 .6226 L .72654 .62213 L F
0 0 0 r
.72518 .62335 m .72671 .62197 L .72478 .62329 L F
.72422 .62453 m .72478 .62329 L .72671 .62197 L F
.72422 .62453 m .72671 .62197 L .72575 .62147 L F
.53 0 0 r
.72671 .62197 m .72654 .62213 L .72575 .62147 L F
.876 .858 .82 r
.70034 .63941 m .7033 .6377 L .70251 .63683 L F
.604 .715 .923 r
.7033 .6377 m .70465 .63588 L .70251 .63683 L F
.7033 .6377 m .70564 .63728 L .70465 .63588 L F
.954 .642 .218 r
.72378 .6179 m .72297 .61745 L .72278 .61535 L F
.804 1 .831 r
.72378 .6179 m .72099 .61969 L .72297 .61745 L F
.568 .338 .527 r
.39541 .73415 m .39763 .73388 L .39772 .73169 L F
.501 .207 .399 r
.39763 .73388 m .40061 .73105 L .39772 .73169 L F
.686 .225 .152 r
.48671 .77729 m .48546 .77843 L .48341 .77678 L F
.42 0 0 r
.48887 .77813 m .48546 .77843 L .48671 .77729 L F
.994 .746 .41 r
.65448 .61451 m .65541 .61294 L .65381 .6125 L F
.65448 .61451 m .65554 .61537 L .65541 .61294 L F
.586 .568 .8 r
.65541 .61294 m .65684 .60918 L .65381 .6125 L F
.65541 .61294 m .65839 .61266 L .65684 .60918 L F
.462 .253 .508 r
.65554 .61537 m .65839 .61266 L .65541 .61294 L F
.453 .42 .732 r
.39589 .76564 m .39425 .76724 L .3936 .76393 L F
.163 0 0 r
.45503 .73616 m .4543 .73717 L .45119 .73857 L F
.168 0 0 r
.45748 .73565 m .45593 .73656 L .45503 .73616 L F
.122 0 0 r
.45593 .73656 m .4543 .73717 L .45503 .73616 L F
.859 .725 .713 r
.64819 .61796 m .64935 .6211 L .64755 .62018 L F
.821 .757 .793 r
.64755 .62018 m .64935 .6211 L .64709 .62395 L F
.64755 .62018 m .64709 .62395 L .64568 .62247 L F
.751 .718 .822 r
.64568 .62247 m .64709 .62395 L .64375 .62356 L F
.109 .617 .896 r
.70511 .73085 m .70691 .73098 L .70814 .73161 L F
.758 .254 0 r
.70691 .73098 m .70822 .73198 L .70814 .73161 L F
.769 .547 .597 r
.3291 .64802 m .32899 .65054 L .33246 .65075 L F
.311 0 .082 r
.36119 .80568 m .36327 .80442 L .36199 .80634 L F
.19 0 .014 r
.36199 .80634 m .36327 .80442 L .36516 .80373 L F
.67 .689 .859 r
.68725 .64156 m .6899 .64219 L .68908 .64125 L F
.654 .847 .974 r
.6899 .64219 m .69144 .64044 L .68908 .64125 L F
.6899 .64219 m .69263 .64117 L .69144 .64044 L F
.66 .6 .776 r
.3676 .79895 m .37089 .80129 L .36981 .79835 L F
.593 .565 .792 r
.37089 .80129 m .37216 .79796 L .36981 .79835 L F
.37089 .80129 m .37387 .80085 L .37216 .79796 L F
.592 .639 .866 r
.37089 .80129 m .37312 .80207 L .37387 .80085 L F
.58 .4 .601 r
.36519 .77475 m .36741 .77681 L .36731 .7744 L F
.36519 .77475 m .36514 .77716 L .36741 .77681 L F
.8 .802 .853 r
.70163 .72556 m .70127 .72658 L .69924 .72555 L F
.656 .439 .578 r
.58378 .69366 m .58054 .6958 L .58098 .69399 L F
.58378 .69366 m .58415 .69633 L .58054 .6958 L F
.63 .42 .58 r
.58606 .69594 m .58378 .69366 L .58608 .69361 L F
.58606 .69594 m .58415 .69633 L .58378 .69366 L F
.484 .57 .866 r
.33782 .80435 m .34075 .8069 L .33996 .80396 L F
.678 .626 .79 r
.33996 .80396 m .34075 .8069 L .3435 .80465 L F
.713 .469 .556 r
.68221 .61835 m .68176 .62105 L .68113 .62065 L F
.077 0 .341 r
.68359 .61923 m .68221 .61835 L .68161 .61723 L F
.25 0 0 r
.44745 .7397 m .44652 .74057 L .44407 .74069 L F
.258 0 0 r
.44967 .73963 m .44652 .74057 L .44745 .7397 L F
.534 .812 .997 r
.31327 .71747 m .31004 .7172 L .31189 .71671 L F
.707 .808 .928 r
.31474 .71615 m .31327 .71747 L .31189 .71671 L F
.49 .258 .489 r
.37978 .74216 m .38221 .73942 L .38003 .73967 L F
.695 .866 .963 r
.4793 .73347 m .48299 .73295 L .48128 .73264 L F
.5 .862 .988 r
.48128 .73264 m .48299 .73295 L .48494 .73239 L F
.906 .972 .804 r
.587 .65649 m .58494 .65933 L .58514 .65728 L F
.866 .95 .865 r
.58494 .65933 m .58269 .6599 L .58514 .65728 L F
.675 .634 .801 r
.37031 .65611 m .36721 .6545 L .3688 .65469 L F
.307 .684 .977 r
.37084 .65518 m .37031 .65611 L .3688 .65469 L F
.37084 .65518 m .37156 .65565 L .37031 .65611 L F
.717 .703 .836 r
.37156 .65565 m .36996 .65832 L .37031 .65611 L F
.776 .551 .593 r
.35248 .79556 m .35599 .79358 L .35214 .7936 L F
.35248 .79556 m .35477 .7964 L .35599 .79358 L F
.475 .22 .447 r
.35599 .79358 m .35477 .7964 L .35693 .79522 L F
.462 .002 .072 r
.47836 .76843 m .48066 .76849 L .47911 .76772 L F
.103 0 0 r
.4532 .77069 m .45523 .77043 L .45682 .76967 L F
.221 0 0 r
.45523 .77043 m .45891 .76927 L .45682 .76967 L F
.45523 .77043 m .45724 .77026 L .45891 .76927 L F
.076 .04 .509 r
.45523 .77043 m .45625 .76762 L .45721 .77017 L F
.45523 .77043 m .45721 .77017 L .45724 .77026 L F
.103 0 0 r
.45313 .77071 m .45523 .77043 L .4532 .77069 L F
0 0 0 r
.33282 .67728 m .33185 .67774 L .32899 .67894 L F
.328 .785 .648 r
.33367 .67683 m .33282 .67728 L .33502 .6776 L F
.33367 .67683 m .33185 .67774 L .33282 .67728 L F
.591 .539 .765 r
.40817 .77997 m .40519 .7773 L .40697 .77695 L F
.468 .205 .431 r
.62136 .63917 m .6189 .6419 L .61935 .63962 L F
.253 0 .038 r
.64507 .59088 m .64688 .59088 L .64788 .58936 L F
.254 0 .038 r
.64788 .58936 m .64932 .58973 L .65002 .58863 L F
.64788 .58936 m .64688 .59088 L .64932 .58973 L F
.514 .294 .518 r
.36803 .70143 m .36575 .70415 L .36608 .70185 L F
.649 .376 .492 r
.61608 .68536 m .61505 .68812 L .61247 .68787 L F
.422 .056 .237 r
.61811 .68578 m .61505 .68812 L .61608 .68536 L F
.602 .181 .215 r
.68501 .62932 m .68336 .63079 L .68141 .63035 L F
.827 .495 .427 r
.68568 .63104 m .68336 .63079 L .68501 .62932 L F
.271 .477 .876 r
.68592 .62799 m .68704 .63014 L .68501 .62932 L F
.875 .924 .854 r
.71575 .62926 m .71785 .62699 L .71679 .62614 L F
.603 .842 .989 r
.71785 .62699 m .71897 .62536 L .71679 .62614 L F
.71785 .62699 m .72005 .62623 L .71897 .62536 L F
.966 .937 .672 r
.67609 .61216 m .67779 .61043 L .6767 .60946 L F
.67609 .61216 m .67662 .61296 L .67779 .61043 L F
.75 .862 .931 r
.6767 .60946 m .67779 .61043 L .67984 .60923 L F
.974 .691 .426 r
.68053 .60403 m .68086 .60624 L .68173 .60516 L F
.628 .169 .142 r
.68086 .60624 m .68439 .60643 L .68173 .60516 L F
.04 .606 .78 r
.44061 .72401 m .44264 .72405 L .44387 .72423 L F
.264 0 0 r
.44264 .72405 m .446 .72427 L .44387 .72423 L F
.176 0 0 r
.34084 .6758 m .339 .67652 L .33685 .67667 L F
0 0 0 r
.34085 .67586 m .34084 .6758 L .343 .67529 L F
.34085 .67586 m .339 .67652 L .34084 .6758 L F
.959 .932 .72 r
.71575 .62926 m .71414 .63022 L .7146 .63113 L F
.875 .924 .854 r
.71575 .62926 m .71679 .62614 L .71522 .62867 L F
.924 .974 .751 r
.71522 .62867 m .71414 .63022 L .71575 .62926 L F
.743 .556 .641 r
.58153 .6915 m .58098 .69399 L .57718 .69331 L F
.692 .773 .913 r
.38689 .66901 m .38483 .67024 L .38332 .66902 L F
.474 .538 .842 r
.50925 .74234 m .5104 .74544 L .51165 .74361 L F
.521 .603 .876 r
.5104 .74544 m .51278 .74542 L .51165 .74361 L F
.62 .592 .8 r
.5104 .74544 m .51384 .74785 L .51278 .74542 L F
.666 .881 .978 r
.71462 .62432 m .71076 .62459 L .71371 .62367 L F
.736 .938 .952 r
.7163 .6231 m .71462 .62432 L .71371 .62367 L F
.895 .97 .823 r
.58916 .65373 m .587 .65649 L .58718 .6545 L F
.903 .973 .806 r
.587 .65649 m .58514 .65728 L .58718 .6545 L F
.675 .663 .831 r
.67569 .63056 m .67688 .63217 L .6791 .63132 L F
.815 .691 .728 r
.65155 .63679 m .65269 .63722 L .65154 .63414 L F
.841 .642 .634 r
.64963 .63901 m .65269 .63722 L .65155 .63679 L F
.64963 .63901 m .65258 .63965 L .65269 .63722 L F
.785 .522 .538 r
.38675 .73586 m .38989 .73431 L .38693 .73451 L F
.38675 .73586 m .38956 .73645 L .38989 .73431 L F
.379 .156 .445 r
.38989 .73431 m .38956 .73645 L .39159 .73514 L F
.726 .819 .923 r
.68233 .60744 m .68559 .60786 L .68439 .60643 L F
.602 .073 0 r
.48759 .77177 m .48992 .77316 L .4909 .77231 L F
.704 .2 .036 r
.48992 .77316 m .49302 .77409 L .4909 .77231 L F
.705 .228 .114 r
.4909 .77231 m .49302 .77409 L .49467 .7741 L F
.879 .991 .804 r
.59119 .65129 m .58916 .65373 L .58948 .6519 L F
.786 .999 .827 r
.59119 .65129 m .58948 .6519 L .59208 .64951 L F
0 0 0 r
.59208 .64951 m .59091 .65092 L .59114 .65066 L F
.71 .881 .488 r
.593 .64838 m .59119 .65129 L .59208 .64951 L F
0 0 0 r
.59208 .64951 m .59114 .65066 L .59325 .64832 L F
.71 .881 .488 r
.59321 .64805 m .593 .64838 L .59208 .64951 L F
.712 .295 .253 r
.71187 .60177 m .71507 .60218 L .71422 .60367 L F
.812 .42 .309 r
.71422 .60367 m .71507 .60218 L .71564 .60422 L F
.621 .853 .987 r
.71507 .60218 m .7177 .60436 L .71564 .60422 L F
.759 .694 .152 r
.6706 .6208 m .67031 .62216 L .66983 .61897 L F
.6706 .6208 m .67022 .62356 L .67031 .62216 L F
.246 .737 .918 r
.32899 .65054 m .33123 .6504 L .3313 .65068 L F
.033 0 0 r
.32719 .65128 m .33123 .6504 L .32899 .65054 L F
.545 .149 .242 r
.32948 .65095 m .33115 .65011 L .33123 .6504 L F
.33115 .65011 m .33307 .64914 L .33123 .6504 L F
.246 .737 .918 r
.3313 .65068 m .33123 .6504 L .33246 .65075 L F
.748 .973 .926 r
.33466 .64914 m .33246 .65075 L .33307 .64914 L F
.72 .949 .953 r
.33246 .65075 m .33123 .6504 L .33307 .64914 L F
.946 .903 .75 r
.67143 .61144 m .6696 .61213 L .67126 .60954 L F
.972 .877 .68 r
.67143 .61144 m .66924 .61445 L .6696 .61213 L F
.67143 .61144 m .67011 .61536 L .66924 .61445 L F
.716 .445 .514 r
.70234 .70121 m .70533 .69925 L .7023 .69887 L F
.70234 .70121 m .7058 .70126 L .70533 .69925 L F
.562 .409 .631 r
.37163 .75534 m .37367 .75263 L .37169 .7531 L F
.015 0 0 r
.42781 .78688 m .42942 .78587 L .43142 .78531 L F
0 .206 .703 r
.52683 .73846 m .52559 .73783 L .52722 .73634 L F
.52683 .73846 m .52765 .73938 L .52559 .73783 L F
.35 .094 .378 r
.36165 .70729 m .3611 .70979 L .35934 .70992 L F
.514 .337 .579 r
.36371 .70458 m .36364 .70689 L .36165 .70729 L F
.406 .143 .399 r
.36312 .70915 m .36165 .70729 L .36364 .70689 L F
.36312 .70915 m .3611 .70979 L .36165 .70729 L F
.4 0 .139 r
.40492 .73059 m .40856 .72825 L .40558 .72933 L F
.40492 .73059 m .4071 .73028 L .40856 .72825 L F
.513 .094 .183 r
.4071 .73028 m .41072 .72851 L .40856 .72825 L F
0 .068 .556 r
.72728 .74003 m .72656 .73933 L .72492 .73788 L F
.59 .656 .883 r
.72813 .74196 m .73064 .7415 L .7279 .74073 L F
0 0 .474 r
.72785 .74047 m .72813 .74196 L .72789 .7405 L F
.72728 .74003 m .72813 .74196 L .72785 .74047 L F
.59 .656 .883 r
.72813 .74196 m .7279 .74073 L .72757 .74064 L F
.651 .696 .879 r
.72842 .73756 m .72766 .7403 L .73016 .73871 L F
.72766 .7403 m .72757 .74064 L .72782 .74045 L F
.72766 .7403 m .72782 .74045 L .73016 .73871 L F
0 0 .474 r
.72664 .73941 m .72766 .7403 L .72656 .73933 L F
.392 .425 .776 r
.72789 .7405 m .72766 .7403 L .72842 .73756 L F
0 0 .474 r
.72766 .7403 m .72789 .7405 L .72761 .74025 L F
.72766 .7403 m .72761 .74025 L .72656 .73933 L F
.392 .425 .776 r
.72789 .7405 m .72757 .74064 L .72766 .7403 L F
0 0 .474 r
.72728 .74003 m .72789 .7405 L .72664 .73941 L F
.77 .993 .781 r
.59567 .64556 m .59321 .64805 L .59392 .64653 L F
.716 .883 .489 r
.59321 .64805 m .59208 .64951 L .59392 .64653 L F
.418 .62 .936 r
.34449 .64873 m .34366 .65022 L .34214 .64869 L F
.34449 .64873 m .34541 .65021 L .34366 .65022 L F
.311 .708 .978 r
.67707 .58235 m .67735 .58331 L .6763 .58277 L F
.707 .943 .958 r
.6821 .58083 m .67707 .58235 L .6797 .58315 L F
.317 .495 .875 r
.67954 .58217 m .67707 .58235 L .67793 .58105 L F
.67954 .58217 m .6797 .58315 L .67859 .58281 L F
.67828 .58226 m .67859 .58281 L .67707 .58235 L F
.67954 .58217 m .67859 .58281 L .67828 .58226 L F
.192 .121 .542 r
.67784 .58188 m .67637 .58462 L .67768 .58333 L F
.67748 .58209 m .67637 .58462 L .67784 .58188 L F
.344 .393 .768 r
.67707 .58235 m .6759 .58256 L .67793 .58105 L F
.311 .708 .978 r
.67701 .58236 m .6763 .58277 L .6759 .58256 L F
.67707 .58235 m .6763 .58277 L .67701 .58236 L F
.192 .121 .542 r
.67793 .58105 m .6759 .58256 L .67637 .58462 L F
.965 .738 .544 r
.67739 .5807 m .67768 .58333 L .67654 .58014 L F
.67793 .58105 m .67788 .58156 L .67739 .5807 L F
.192 .121 .542 r
.67793 .58105 m .67748 .58209 L .67784 .58188 L F
.965 .738 .544 r
.67788 .58156 m .67768 .58333 L .67739 .5807 L F
.536 .392 .633 r
.36837 .76385 m .37039 .76352 L .37025 .76108 L F
.486 .366 .641 r
.36837 .76385 m .37042 .76585 L .37039 .76352 L F
.36837 .76385 m .36871 .76635 L .37042 .76585 L F
.626 .833 .98 r
.3676 .79895 m .36981 .79835 L .36806 .79732 L F
.825 .941 .578 r
.36806 .79732 m .36611 .80072 L .3676 .79895 L F
.603 .034 0 r
.50415 .78344 m .50403 .78418 L .50108 .78226 L F
.752 .246 0 r
.50495 .78471 m .50403 .78418 L .50415 .78344 L F
.304 .251 .632 r
.39921 .75721 m .39726 .75668 L .39934 .75546 L F
.39921 .75721 m .39749 .75815 L .39726 .75668 L F
.479 .782 .998 r
.36179 .65265 m .36115 .65379 L .35981 .65284 L F
.36179 .65265 m .36328 .65352 L .36115 .65379 L F
.896 .594 .468 r
.48483 .77021 m .48759 .77177 L .48589 .77124 L F
.676 .941 .964 r
.48589 .72323 m .48667 .72182 L .48804 .72258 L F
.48589 .72323 m .48468 .72288 L .48667 .72182 L F
.232 0 .126 r
.64507 .59088 m .64631 .59205 L .64688 .59088 L F
.64507 .59088 m .64441 .59276 L .64631 .59205 L F
.552 .748 .968 r
.72253 .60041 m .72081 .60201 L .7196 .59891 L F
.72253 .60041 m .72296 .60157 L .72081 .60201 L F
.411 .076 .284 r
.72081 .60201 m .72263 .60339 L .72025 .60377 L F
.72081 .60201 m .72296 .60157 L .72263 .60339 L F
.501 .207 .399 r
.39763 .73388 m .39981 .73361 L .40061 .73105 L F
.448 .157 .378 r
.40061 .73105 m .40184 .73318 L .40274 .73076 L F
.40061 .73105 m .39981 .73361 L .40184 .73318 L F
.429 .426 .754 r
.37387 .80085 m .37312 .80207 L .37518 .80079 L F
0 .081 .619 r
.37312 .80207 m .37485 .80373 L .37518 .80079 L F
.37312 .80207 m .37411 .80446 L .37485 .80373 L F
0 .364 .747 r
.49544 .78015 m .49828 .78135 L .49752 .78085 L F
.49544 .78015 m .49752 .78085 L .49405 .7797 L F
.885 .681 .161 r
.6743 .59552 m .67453 .59403 L .67385 .59124 L F
.6743 .59552 m .67452 .59588 L .67453 .59403 L F
.3 0 .203 r
.36028 .71129 m .35934 .70992 L .3611 .70979 L F
.36028 .71129 m .35844 .71188 L .35934 .70992 L F
.665 .374 .469 r
.60473 .6884 m .60699 .69048 L .60492 .69016 L F
.647 .38 .5 r
.60686 .68847 m .60699 .69048 L .60473 .6884 L F
.593 .34 .503 r
.60682 .67453 m .60921 .67425 L .60953 .67187 L F
.531 .275 .473 r
.60921 .67425 m .61175 .67158 L .60953 .67187 L F
.491 .032 .09 r
.69554 .71036 m .69807 .71128 L .69901 .70953 L F
.545 .491 .746 r
.69901 .70953 m .70091 .70591 L .69969 .70775 L F
.767 .485 .506 r
.69807 .71128 m .70213 .71028 L .69901 .70953 L F
.278 .734 .955 r
.35285 .65126 m .35255 .65192 L .35087 .6512 L F
.35285 .65126 m .35491 .65193 L .35255 .65192 L F
.192 0 0 r
.5335 .77264 m .53277 .77353 L .53547 .77196 L F
.506 .034 .067 r
.3028 .69249 m .30187 .69109 L .30393 .69061 L F
.3028 .69249 m .3005 .69273 L .30187 .69109 L F
.489 .49 .785 r
.38233 .66572 m .38142 .66894 L .38049 .66595 L F
.38233 .66572 m .38332 .66902 L .38142 .66894 L F
.735 .562 .659 r
.57508 .69133 m .57156 .69342 L .57214 .69101 L F
.57508 .69133 m .57486 .69375 L .57156 .69342 L F
.632 .472 .647 r
.57718 .69331 m .57486 .69375 L .57508 .69133 L F
.65 .094 0 r
.50409 .74202 m .50255 .74149 L .50036 .73962 L F
.776 .941 .934 r
.50448 .74021 m .50409 .74202 L .50599 .7414 L F
.50448 .74021 m .50255 .74149 L .50409 .74202 L F
.662 .584 .757 r
.50409 .74202 m .50695 .74292 L .50599 .7414 L F
.807 .995 .764 r
.62557 .65818 m .62652 .6568 L .62832 .65571 L F
.79 .993 .762 r
.62832 .65571 m .62652 .6568 L .62899 .65423 L F
.865 .986 .84 r
.58916 .65373 m .58718 .6545 L .58948 .6519 L F
.985 .747 .492 r
.51799 .72885 m .51786 .7315 L .51677 .73045 L F
.678 .583 .742 r
.51991 .72633 m .51799 .72885 L .51793 .72741 L F
.701 .285 .254 r
.51799 .72885 m .52014 .73078 L .51677 .73045 L F
.643 .533 .714 r
.51991 .72633 m .52061 .7289 L .51799 .72885 L F
.792 .842 .889 r
.69761 .57474 m .69839 .57688 L .69719 .57529 L F
.876 .844 .81 r
.69839 .57688 m .69534 .57841 L .69719 .57529 L F
.69839 .57688 m .69608 .57997 L .69534 .57841 L F
.824 .856 .871 r
.70035 .5748 m .69839 .57688 L .69761 .57474 L F
.151 0 0 r
.43397 .7847 m .43356 .78509 L .43142 .78531 L F
.158 0 0 r
.4372 .78372 m .43356 .78509 L .43397 .7847 L F
.468 .044 .15 r
.46122 .77704 m .45986 .77885 L .45766 .77881 L F
.533 .073 .107 r
.46122 .77704 m .46203 .77883 L .45986 .77885 L F
.46122 .77704 m .46328 .77743 L .46203 .77883 L F
.525 .282 .488 r
.35086 .69872 m .35283 .69846 L .35325 .69597 L F
.535 .462 .721 r
.35325 .69597 m .3549 .69325 L .35325 .69461 L F
.35325 .69597 m .3555 .69567 L .3549 .69325 L F
.588 .388 .578 r
.35283 .69846 m .3555 .69567 L .35325 .69597 L F
.025 0 0 r
.71277 .73498 m .71519 .73504 L .71572 .73504 L F
0 .057 .616 r
.71703 .73552 m .71715 .73703 L .71572 .73504 L F
.71703 .73552 m .71572 .73504 L .71519 .73504 L F
.768 .597 .666 r
.57645 .70173 m .5729 .69879 L .57493 .69832 L F
.57645 .70173 m .57441 .70174 L .5729 .69879 L F
.743 .652 .759 r
.57809 .69895 m .57645 .70173 L .57493 .69832 L F
.477 .768 .995 r
.57877 .70155 m .57645 .70173 L .57809 .69895 L F
.401 .772 .993 r
.35792 .80553 m .36119 .80568 L .35985 .80501 L F
.069 0 0 r
.35546 .80767 m .35856 .80579 L .35878 .80589 L F
.35856 .80579 m .35985 .80501 L .35878 .80589 L F
.645 .133 .013 r
.35878 .80589 m .36199 .80634 L .36007 .80708 L F
0 .071 .597 r
.35886 .80592 m .35878 .80589 L .35889 .80599 L F
.069 0 0 r
.35856 .80579 m .35804 .80549 L .35985 .80501 L F
.658 .472 .622 r
.35878 .80589 m .36068 .80369 L .35692 .80272 L F
.726 .947 .642 r
.35868 .80548 m .36068 .80369 L .35878 .80589 L F
0 .071 .597 r
.35868 .80548 m .35878 .80589 L .35886 .80592 L F
.35936 .80626 m .35889 .80599 L .36007 .80708 L F
.68 .193 .086 r
.35985 .80501 m .36199 .80634 L .35878 .80589 L F
0 .071 .597 r
.35868 .80548 m .35889 .80599 L .35936 .80626 L F
.069 0 0 r
.35546 .80767 m .35792 .80553 L .35804 .80549 L F
.35546 .80767 m .35804 .80549 L .35856 .80579 L F
.183 0 0 r
.32449 .73369 m .32083 .73527 L .32268 .73458 L F
.131 .5 .907 r
.38822 .66984 m .39164 .67177 L .39068 .67181 L F
.367 .298 .646 r
.3924 .67395 m .39068 .67181 L .39164 .67177 L F
.3924 .67395 m .3917 .6771 L .39068 .67181 L F
.834 .705 .721 r
.6032 .65824 m .60435 .66136 L .60487 .65914 L F
.894 .887 .817 r
.57029 .67681 m .57143 .67759 L .56956 .67997 L F
.251 0 0 r
.28677 .60893 m .28877 .60918 L .28713 .60916 L F
.652 .132 0 r
.70885 .70423 m .71134 .70592 L .71195 .70497 L F
.678 .162 .002 r
.71134 .70592 m .71443 .70679 L .71195 .70497 L F
.482 .175 .369 r
.31145 .65847 m .31352 .65818 L .31402 .6568 L F
.36 .06 .314 r
.31402 .6568 m .31541 .65746 L .31586 .65635 L F
.31402 .6568 m .31352 .65818 L .31541 .65746 L F
.187 0 0 r
.686 .63498 m .68199 .63679 L .68498 .63428 L F
.247 0 .191 r
.52494 .78752 m .52745 .78535 L .52669 .78757 L F
.205 0 .042 r
.52745 .78535 m .52812 .78652 L .52669 .78757 L F
.52745 .78535 m .5293 .78462 L .52812 .78652 L F
.6 .803 .977 r
.51327 .71164 m .51446 .71265 L .51114 .71225 L F
.675 .228 .181 r
.51446 .71265 m .51311 .71412 L .51114 .71225 L F
.562 .752 .967 r
.5155 .71104 m .51446 .71265 L .51327 .71164 L F
.5155 .71104 m .51661 .71224 L .51446 .71265 L F
.654 .882 .524 r
.5155 .71104 m .51446 .71265 L .51661 .71224 L F
.5155 .71104 m .51311 .71412 L .51446 .71265 L F
.529 .355 .589 r
.39557 .76115 m .39555 .76358 L .3936 .76393 L F
.453 .42 .732 r
.39589 .76564 m .3936 .76393 L .39555 .76358 L F
.8 .308 0 r
.70842 .73214 m .70935 .73337 L .71054 .73381 L F
.54 .359 .584 r
.71157 .73342 m .7105 .73488 L .70935 .73337 L F
.7105 .73488 m .70991 .7357 L .70935 .73337 L F
.8 .308 0 r
.70822 .73198 m .70935 .73337 L .70842 .73214 L F
.905 .619 .491 r
.62808 .64741 m .62963 .64786 L .62834 .64943 L F
.996 .835 .565 r
.62917 .64527 m .62963 .64786 L .62808 .64741 L F
.763 .403 .373 r
.62963 .64786 m .63004 .64922 L .62834 .64943 L F
.815 .697 .734 r
.60114 .66091 m .60435 .66136 L .6032 .65824 L F
.817 .654 .68 r
.60103 .66332 m .60435 .66136 L .60114 .66091 L F
.60103 .66332 m .60401 .66368 L .60435 .66136 L F
.727 .655 .779 r
.50309 .72182 m .4991 .72073 L .50121 .7197 L F
.722 .662 .79 r
.50474 .72045 m .50309 .72182 L .50121 .7197 L F
0 0 0 r
.32416 .68007 m .32103 .68143 L .32214 .68091 L F
.934 .898 .768 r
.57807 .66952 m .57871 .66581 L .57964 .66656 L F
.947 .904 .747 r
.57964 .66656 m .57871 .66581 L .57995 .66349 L F
.498 .684 .95 r
.68561 .63967 m .68725 .64156 L .68908 .64125 L F
.312 .114 .443 r
.35917 .78487 m .36051 .78486 L .3608 .78264 L F
.331 0 0 r
.40283 .7935 m .40011 .79537 L .39815 .79552 L F
0 0 0 r
.40398 .79344 m .40283 .7935 L .4048 .79285 L F
.54 .419 .664 r
.39861 .79795 m .40093 .7981 L .4008 .7951 L F
0 0 0 r
.40398 .79344 m .40021 .79532 L .40283 .7935 L F
.40021 .79532 m .40011 .79537 L .40015 .79534 L F
.724 .979 .916 r
.40079 .79487 m .40011 .79537 L .40398 .79344 L F
.54 .419 .664 r
.40057 .79519 m .4008 .7951 L .40079 .79487 L F
.39861 .79795 m .4008 .7951 L .40057 .79519 L F
0 0 0 r
.40021 .79532 m .40015 .79534 L .40283 .7935 L F
.717 .773 .897 r
.64047 .62324 m .64375 .62356 L .64171 .62472 L F
.549 .648 .9 r
.29192 .61066 m .2898 .61116 L .28877 .60918 L F
.681 .877 .495 r
.59767 .64263 m .59567 .64556 L .59648 .6441 L F
0 0 0 r
.59969 .63984 m .59767 .64263 L .59874 .64141 L F
.59874 .64141 m .59767 .64263 L .59648 .6441 L F
.573 .445 .668 r
.37001 .75883 m .37238 .76072 L .37209 .75844 L F
.37001 .75883 m .37025 .76108 L .37238 .76072 L F
.983 .72 .444 r
.36068 .80369 m .36268 .80478 L .3608 .80088 L F
0 .096 .653 r
.3608 .80088 m .36268 .80478 L .3626 .8028 L F
.621 .891 .988 r
.3626 .8028 m .36268 .80478 L .36068 .80369 L F
.669 .419 .533 r
.59689 .69094 m .59718 .69322 L .59371 .69318 L F
.683 .485 .613 r
.59922 .69074 m .59718 .69322 L .59689 .69094 L F
.522 .341 .577 r
.37367 .75263 m .37581 .74996 L .37377 .75039 L F
.936 .734 .605 r
.36094 .81203 m .36242 .81298 L .3615 .8096 L F
.636 .572 .766 r
.36434 .8122 m .36242 .81298 L .3615 .8096 L F
.676 .822 .953 r
.36094 .81203 m .36242 .81298 L .36434 .8122 L F
.541 .607 .869 r
.37678 .6613 m .37331 .65893 L .37524 .65848 L F
.447 .55 .867 r
.37781 .65941 m .37678 .6613 L .37524 .65848 L F
.448 .551 .868 r
.37781 .65941 m .37857 .66123 L .37678 .6613 L F
.824 .979 .887 r
.515 .74447 m .51835 .74261 L .51709 .74173 L F
.748 .697 .802 r
.51835 .74261 m .51904 .739 L .51709 .74173 L F
.51835 .74261 m .52008 .74167 L .51904 .739 L F
.074 .636 .755 r
.42693 .77738 m .42914 .77727 L .43021 .77728 L F
.276 .772 .89 r
.42914 .77727 m .43243 .77707 L .43021 .77728 L F
.769 .807 .883 r
.69534 .57841 m .69608 .57997 L .69286 .57989 L F
.102 .617 .889 r
.72049 .74266 m .72161 .74243 L .71934 .7417 L F
.72049 .74266 m .72232 .74283 L .72161 .74243 L F
.613 .592 .806 r
.28703 .60437 m .28677 .60893 L .28512 .60463 L F
.28703 .60437 m .28898 .60907 L .28677 .60893 L F
.251 0 0 r
.28677 .60893 m .28898 .60907 L .28877 .60918 L F
0 0 .16 r
.59969 .63984 m .60109 .6392 L .60157 .63692 L F
0 0 0 r
.60044 .64043 m .59969 .63984 L .59874 .64141 L F
.60044 .64043 m .60109 .6392 L .59969 .63984 L F
.641 .966 .885 r
.34762 .6737 m .34668 .67378 L .346 .67487 L F
.491 .818 1 r
.346 .67487 m .34668 .67378 L .34457 .67416 L F
.678 .679 .843 r
.48696 .73157 m .48823 .73422 L .49046 .73346 L F
.639 .689 .881 r
.48823 .73422 m .49188 .73463 L .49046 .73346 L F
.833 .769 .79 r
.65211 .64543 m .65408 .64271 L .65256 .64199 L F
.536 .88 .987 r
.4805 .72428 m .48148 .72309 L .48271 .7238 L F
.4805 .72428 m .47883 .72371 L .48148 .72309 L F
.91 .668 .56 r
.6553 .61711 m .6569 .6183 L .65554 .61537 L F
.89 .871 .812 r
.65379 .6202 m .6569 .6183 L .6553 .61711 L F
.65379 .6202 m .65485 .62114 L .6569 .6183 L F
.681 .591 .748 r
.65554 .61537 m .6569 .6183 L .65921 .61595 L F
.287 0 .28 r
.62051 .6833 m .61996 .68483 L .61811 .68578 L F
0 0 .039 r
.62177 .68214 m .61996 .68483 L .62051 .6833 L F
.625 .631 .836 r
.51904 .739 m .52008 .74167 L .52262 .7402 L F
.673 .747 .906 r
.52008 .74167 m .52316 .74046 L .52262 .7402 L F
.218 0 .09 r
.52371 .78957 m .52494 .78752 L .52669 .78757 L F
.132 0 0 r
.33689 .71044 m .3356 .71159 L .33874 .70989 L F
.224 0 0 r
.42537 .74248 m .42399 .74381 L .42181 .74423 L F
.704 .375 .418 r
.42758 .74226 m .42399 .74381 L .42537 .74248 L F
.601 .342 .497 r
.4176 .74496 m .41719 .7473 L .41451 .74753 L F
.236 .025 .377 r
.41873 .74658 m .4176 .74496 L .41977 .74468 L F
.41873 .74658 m .41719 .7473 L .4176 .74496 L F
.833 .769 .79 r
.65211 .64543 m .65256 .64199 L .65063 .64456 L F
.905 .761 .69 r
.6516 .64795 m .65211 .64543 L .65063 .64456 L F
.651 .51 .678 r
.63259 .62355 m .63241 .62608 L .63046 .62634 L F
.644 .598 .788 r
.63241 .62608 m .63168 .62825 L .63046 .62634 L F
.492 0 0 r
.46328 .77743 m .4667 .77725 L .46538 .77815 L F
.261 0 0 r
.4667 .77725 m .4675 .77803 L .46538 .77815 L F
.4667 .77725 m .46886 .77708 L .4675 .77803 L F
.258 .56 .934 r
.3664 .65293 m .36721 .6545 L .36541 .6531 L F
.3664 .65293 m .3688 .65469 L .36721 .6545 L F
.458 .198 .431 r
.61651 .66873 m .61901 .66642 L .61684 .66688 L F
.403 .162 .431 r
.63404 .60494 m .6361 .60409 L .63594 .60174 L F
.339 .237 .591 r
.63594 .60174 m .63761 .59844 L .6361 .59962 L F
.63594 .60174 m .63791 .60096 L .63761 .59844 L F
.202 0 .28 r
.63728 .60279 m .63594 .60174 L .6361 .60409 L F
.63728 .60279 m .63791 .60096 L .63594 .60174 L F
.581 .798 .982 r
.68704 .63014 m .6861 .63084 L .68568 .63104 L F
0 0 .429 r
.6861 .63084 m .68656 .63326 L .687 .63325 L F
.6861 .63084 m .687 .63325 L .68568 .63104 L F
.596 .516 .734 r
.36631 .769 m .36718 .77194 L .36935 .77159 L F
.59 .442 .649 r
.36731 .7744 m .36935 .77159 L .36718 .77194 L F
.159 0 0 r
.46049 .73596 m .45938 .73592 L .45748 .73565 L F
.051 0 0 r
.46277 .73608 m .45938 .73592 L .46049 .73596 L F
.569 .607 .851 r
.29373 .60986 m .29307 .61294 L .29192 .61066 L F
.29373 .60986 m .29498 .61239 L .29307 .61294 L F
.517 .394 .651 r
.29498 .61239 m .29527 .61479 L .29307 .61294 L F
.477 .395 .684 r
.29527 .61479 m .29363 .61559 L .29307 .61294 L F
.158 0 0 r
.4372 .78372 m .43569 .78471 L .43356 .78509 L F
.306 0 0 r
.43935 .78328 m .43569 .78471 L .4372 .78372 L F
.965 .94 .668 r
.60838 .6491 m .60906 .65043 L .60989 .64795 L F
.92 .933 .8 r
.60639 .6517 m .60906 .65043 L .60838 .6491 L F
.60639 .6517 m .60739 .65227 L .60906 .65043 L F
.688 .607 .76 r
.51991 .72633 m .51793 .72741 L .51675 .72401 L F
.233 0 .273 r
.41451 .74753 m .4121 .74966 L .4124 .74757 L F
.471 .302 .57 r
.36557 .70619 m .36371 .70458 L .36575 .70415 L F
.36557 .70619 m .36364 .70689 L .36371 .70458 L F
.74 .635 .743 r
.57321 .71036 m .5733 .71214 L .5717 .71197 L F
.693 .447 .547 r
.57304 .71464 m .5717 .71197 L .5733 .71214 L F
.72 .619 .744 r
.57505 .70971 m .5733 .71214 L .57321 .71036 L F
.572 .418 .633 r
.57505 .70971 m .57504 .71196 L .5733 .71214 L F
.663 .395 .504 r
.57546 .71451 m .5733 .71214 L .57504 .71196 L F
.57546 .71451 m .57304 .71464 L .5733 .71214 L F
.5 .242 .455 r
.6162 .62627 m .61844 .6258 L .61879 .62391 L F
.507 .272 .493 r
.61844 .6258 m .62098 .62326 L .61879 .62391 L F
.721 .603 .724 r
.69575 .5917 m .69626 .5936 L .69865 .59123 L F
.514 .291 .514 r
.69626 .5936 m .69854 .59334 L .69865 .59123 L F
.257 0 .056 r
.35039 .7191 m .34973 .71784 L .35178 .71744 L F
.35039 .7191 m .34842 .71969 L .34973 .71784 L F
.448 .05 .192 r
.4121 .74966 m .41236 .75052 L .40965 .75075 L F
.233 0 .273 r
.41451 .74753 m .41407 .74928 L .4121 .74966 L F
.224 0 .244 r
.41407 .74928 m .41236 .75052 L .4121 .74966 L F
.964 .871 .697 r
.73292 .73649 m .73216 .73848 L .73309 .73907 L F
.92 .675 .182 r
.68962 .58837 m .68936 .59024 L .68861 .58733 L F
.68962 .58837 m .68982 .59089 L .68936 .59024 L F
.46 .74 .989 r
.68962 .58837 m .69098 .58715 L .68861 .58733 L F
.4 .634 .949 r
.68962 .58837 m .69215 .58872 L .69098 .58715 L F
.92 .675 .182 r
.68962 .58837 m .68936 .59024 L .68861 .58733 L F
.68962 .58837 m .68982 .59089 L .68936 .59024 L F
.732 .404 .426 r
.70794 .70972 m .70472 .71108 L .70568 .70977 L F
.70794 .70972 m .70697 .71197 L .70472 .71108 L F
.693 .36 .409 r
.71024 .71181 m .70697 .71197 L .70794 .70972 L F
.932 .563 .286 r
.64943 .61346 m .64893 .61339 L .64683 .61245 L F
.64943 .61346 m .6502 .61531 L .64893 .61339 L F
.724 .626 .749 r
.69575 .5917 m .69865 .59123 L .69715 .587 L F
.767 .666 .751 r
.69854 .59334 m .70074 .59061 L .69865 .59123 L F
.46 .31 .59 r
.39716 .76052 m .39555 .76358 L .39557 .76115 L F
.455 .499 .815 r
.68526 .58388 m .68275 .58367 L .6821 .58083 L F
.68515 .58354 m .6821 .58083 L .684 .57966 L F
.68526 .58388 m .68492 .58355 L .68515 .58354 L F
.68492 .58355 m .6821 .58083 L .68515 .58354 L F
.578 .507 .739 r
.68733 .58093 m .68526 .58388 L .684 .57966 L F
.292 .53 .909 r
.68234 .58371 m .68566 .58353 L .6816 .58377 L F
.68275 .58367 m .68387 .58362 L .68234 .58371 L F
.68387 .58362 m .68566 .58353 L .68234 .58371 L F
0 0 .456 r
.70523 .73268 m .70557 .73218 L .70511 .73085 L F
0 0 .476 r
.70511 .73085 m .70598 .73335 L .70625 .7315 L F
.70511 .73085 m .70625 .7315 L .70267 .73071 L F
.069 .626 .807 r
.70267 .73071 m .70691 .73098 L .70511 .73085 L F
.70344 .73076 m .70584 .73079 L .70691 .73098 L F
.70267 .73071 m .70406 .73075 L .70344 .73076 L F
.70406 .73075 m .70584 .73079 L .70344 .73076 L F
.553 0 0 r
.70698 .73147 m .70561 .73072 L .70625 .7315 L F
.546 .476 .728 r
.70454 .72747 m .70584 .73079 L .70267 .73071 L F
.553 0 0 r
.70561 .73072 m .70401 .72984 L .7052 .73073 L F
.70561 .73072 m .7052 .73073 L .70625 .7315 L F
.334 .646 .967 r
.70267 .73071 m .70607 .73146 L .70401 .72984 L F
.70607 .73146 m .70625 .7315 L .70611 .7314 L F
.70607 .73146 m .70611 .7314 L .70401 .72984 L F
0 0 .456 r
.7053 .73372 m .70598 .73335 L .70557 .73218 L F
.7053 .73372 m .70557 .73218 L .70523 .73268 L F
.219 .716 .915 r
.70941 .73381 m .70598 .73335 L .7053 .73372 L F
.757 .526 .582 r
.56956 .67997 m .56608 .68244 L .56762 .67955 L F
.56956 .67997 m .56953 .68279 L .56608 .68244 L F
.894 .887 .817 r
.57029 .67681 m .56956 .67997 L .56762 .67955 L F
.942 .861 .731 r
.73229 .72497 m .73421 .72387 L .73321 .72322 L F
.73229 .72497 m .73331 .72584 L .73421 .72387 L F
.461 .842 .616 r
.60157 .63692 m .60295 .63582 L .60426 .63496 L F
.348 .035 .286 r
.60157 .63692 m .60312 .63841 L .60295 .63582 L F
.60157 .63692 m .60109 .6392 L .60312 .63841 L F
.613 .464 .655 r
.36631 .769 m .36879 .76943 L .36871 .76635 L F
.596 .516 .734 r
.36631 .769 m .36935 .77159 L .36879 .76943 L F
.748 .988 .778 r
.59648 .6441 m .59567 .64556 L .59392 .64653 L F
.673 .608 .775 r
.35699 .67471 m .36038 .67701 L .35945 .67396 L F
.62 .616 .826 r
.36038 .67701 m .36133 .6736 L .35945 .67396 L F
.36038 .67701 m .36269 .67683 L .36133 .6736 L F
.028 0 0 r
.33094 .73065 m .32949 .73097 L .33262 .72915 L F
.132 0 0 r
.33292 .73006 m .33262 .72915 L .3344 .72837 L F
.33292 .73006 m .33094 .73065 L .33262 .72915 L F
.329 .777 .958 r
.45488 .72587 m .45699 .72567 L .45828 .72609 L F
.465 .847 .984 r
.45828 .72609 m .45907 .72519 L .46039 .72581 L F
.45828 .72609 m .45699 .72567 L .45907 .72519 L F
.926 .972 .751 r
.65315 .62205 m .65485 .62114 L .65379 .6202 L F
.65315 .62205 m .65311 .62396 L .65485 .62114 L F
.366 0 .17 r
.30819 .66088 m .31021 .66047 L .31145 .65847 L F
.325 0 .102 r
.31021 .66047 m .31352 .65818 L .31145 .65847 L F
.389 .188 .482 r
.39926 .75987 m .39749 .75815 L .39921 .75721 L F
.39926 .75987 m .39716 .76052 L .39749 .75815 L F
.619 .072 0 r
.71475 .71505 m .71327 .71503 L .7117 .71407 L F
.527 .891 .974 r
.39563 .7341 m .39763 .73388 L .39541 .73415 L F
.196 0 0 r
.44087 .74167 m .43881 .74113 L .43964 .74147 L F
.649 .617 .804 r
.49368 .73438 m .49712 .73678 L .49589 .73375 L F
.505 .592 .875 r
.49712 .73678 m .4981 .73506 L .49589 .73375 L F
.49712 .73678 m .49918 .73652 L .4981 .73506 L F
.096 0 0 r
.40976 .79183 m .40892 .79225 L .40691 .79246 L F
.435 .843 .661 r
.40989 .79153 m .40827 .79258 L .40892 .79225 L F
.036 0 0 r
.40892 .79225 m .40825 .79259 L .40594 .79297 L F
.435 .843 .661 r
.40827 .79258 m .40825 .79259 L .40892 .79225 L F
.096 0 0 r
.41081 .79159 m .40892 .79225 L .40976 .79183 L F
.256 .751 .68 r
.41099 .79149 m .41081 .79159 L .41287 .79105 L F
.41099 .79149 m .40892 .79225 L .41081 .79159 L F
.604 .651 .869 r
.50695 .74292 m .50925 .74234 L .50599 .7414 L F
.364 0 .178 r
.72763 .62113 m .7296 .62225 L .72671 .62197 L F
.72763 .62113 m .72991 .6205 L .7296 .62225 L F
.535 .416 .664 r
.3781 .74497 m .38011 .74458 L .37978 .74216 L F
.463 .258 .515 r
.3781 .74497 m .37979 .74676 L .38011 .74458 L F
.3781 .74497 m .37789 .74723 L .37979 .74676 L F
.594 .809 .982 r
.3211 .71571 m .31765 .71527 L .3197 .71458 L F
.015 .563 .83 r
.3197 .71458 m .32318 .71536 L .3211 .71571 L F
.619 .407 .572 r
.30884 .68537 m .30851 .68801 L .30629 .68809 L F
.6 .479 .686 r
.31046 .68491 m .30851 .68801 L .30884 .68537 L F
.376 .122 .397 r
.34788 .79918 m .34958 .79873 L .35025 .79651 L F
.572 .378 .58 r
.34958 .79873 m .35248 .79556 L .35025 .79651 L F
.556 .148 .224 r
.41823 .72739 m .42041 .72762 L .42173 .72578 L F
.5 .086 .185 r
.42041 .72762 m .42395 .72582 L .42173 .72578 L F
.358 .822 .915 r
.46693 .7355 m .46598 .73611 L .4682 .73564 L F
.46693 .7355 m .46487 .73595 L .46598 .73611 L F
.686 .676 .835 r
.52765 .73938 m .52953 .7424 L .52742 .74195 L F
.52765 .73938 m .52742 .74195 L .52647 .74143 L F
.408 0 0 r
.52953 .7424 m .52647 .74143 L .52742 .74195 L F
.52953 .7424 m .52854 .74231 L .52647 .74143 L F
.192 .416 .85 r
.52765 .73938 m .53005 .74104 L .52953 .7424 L F
.739 .989 .884 r
.52953 .7424 m .53005 .74104 L .52854 .74231 L F
.342 0 .212 r
.61175 .67158 m .61411 .67132 L .61453 .66949 L F
.115 0 .141 r
.61453 .66949 m .61563 .67046 L .61651 .66873 L F
.61453 .66949 m .61411 .67132 L .61563 .67046 L F
.655 .152 .039 r
.65742 .58559 m .65981 .58721 L .66065 .58627 L F
.688 .192 .062 r
.65981 .58721 m .66288 .58809 L .66065 .58627 L F
.741 .643 .752 r
.58054 .6958 m .57858 .69661 L .58098 .69399 L F
.685 .541 .684 r
.58054 .6958 m .57809 .69895 L .57858 .69661 L F
.58054 .6958 m .58148 .69896 L .57809 .69895 L F
.556 .381 .599 r
.58415 .69633 m .58148 .69896 L .58054 .6958 L F
.782 .673 .743 r
.57211 .68515 m .56953 .68279 L .57318 .68336 L F
.57211 .68515 m .57112 .68585 L .56953 .68279 L F
.481 .507 .808 r
.39877 .76882 m .39796 .77204 L .39673 .76904 L F
.481 .504 .805 r
.39796 .77204 m .39982 .7719 L .3996 .77179 L F
0 .459 .701 r
.3996 .77179 m .4003 .77193 L .40373 .77262 L F
.4003 .77193 m .40289 .77245 L .40299 .77247 L F
.4003 .77193 m .40299 .77247 L .40373 .77262 L F
.574 .546 .785 r
.40153 .77009 m .40289 .77245 L .3996 .77179 L F
.40153 .77009 m .3996 .77179 L .39982 .7719 L F
.6 .58 .803 r
.40153 .77009 m .39988 .77184 L .39877 .76882 L F
.39988 .77184 m .39982 .7719 L .3998 .77183 L F
.39988 .77184 m .3998 .77183 L .39877 .76882 L F
.481 .507 .808 r
.39877 .76882 m .39982 .7719 L .39796 .77204 L F
.418 .864 .809 r
.4339 .77599 m .43674 .7749 L .43794 .77462 L F
.003 0 0 r
.43794 .77462 m .43847 .7748 L .44003 .77419 L F
.43794 .77462 m .43674 .7749 L .43847 .7748 L F
.642 .661 .852 r
.34657 .80743 m .34985 .8093 L .34839 .80685 L F
.611 .637 .852 r
.34839 .80685 m .34985 .8093 L .35158 .80794 L F
.739 .578 .674 r
.63489 .63693 m .63827 .63701 L .63796 .63916 L F
.702 .482 .586 r
.58952 .69355 m .58606 .69594 L .58608 .69361 L F
.58952 .69355 m .58971 .69614 L .58606 .69594 L F
.654 .445 .588 r
.59159 .69588 m .58952 .69355 L .59157 .69361 L F
.59159 .69588 m .58971 .69614 L .58952 .69355 L F
.205 0 0 r
.60426 .63496 m .60517 .63547 L .60631 .63406 L F
.60426 .63496 m .60295 .63582 L .60517 .63547 L F
.109 0 0 r
.45891 .76927 m .46097 .76895 L .46207 .76844 L F
.402 0 0 r
.46207 .76844 m .46097 .76895 L .46424 .7686 L F
.698 .584 .724 r
.63525 .6204 m .63259 .62355 L .6326 .62209 L F
.717 .703 .836 r
.37156 .65565 m .37331 .65893 L .36996 .65832 L F
.602 .65 .87 r
.37456 .6565 m .37331 .65893 L .37156 .65565 L F
.557 .594 .846 r
.37456 .6565 m .37524 .65848 L .37331 .65893 L F
.672 .828 .959 r
.32855 .71451 m .32671 .71551 L .32521 .71448 L F
.87 .428 .122 r
.51106 .79028 m .50795 .78673 L .51099 .78809 L F
.641 .376 .503 r
.6102 .68794 m .60699 .69048 L .60686 .68847 L F
.421 .225 .506 r
.31808 .68259 m .31636 .68407 L .3161 .68085 L F
.661 .726 .897 r
.71128 .63443 m .70908 .63124 L .70957 .63417 L F
.782 .728 .803 r
.71128 .63443 m .71063 .6335 L .7146 .63113 L F
.661 .726 .897 r
.71128 .63443 m .71141 .63044 L .70908 .63124 L F
.762 .809 .891 r
.71325 .62929 m .71128 .63443 L .71414 .63022 L F
.71325 .62929 m .71141 .63044 L .71128 .63443 L F
.782 .728 .803 r
.71128 .63443 m .7146 .63113 L .71414 .63022 L F
.803 .739 .793 r
.56935 .69614 m .56617 .69583 L .56837 .69312 L F
.82 .661 .685 r
.56935 .69614 m .56774 .699 L .56617 .69583 L F
.776 .601 .662 r
.57061 .69914 m .56774 .699 L .56935 .69614 L F
.78 .727 .804 r
.57156 .69342 m .56935 .69614 L .56837 .69312 L F
.679 .57 .725 r
.57156 .69342 m .57276 .69654 L .56935 .69614 L F
.701 .567 .701 r
.5729 .69879 m .56935 .69614 L .57276 .69654 L F
.5729 .69879 m .57061 .69914 L .56935 .69614 L F
.967 .869 .688 r
.72568 .72866 m .72331 .73082 L .72502 .72811 L F
.72568 .72866 m .72452 .73194 L .72331 .73082 L F
.996 .845 .5 r
.72568 .72866 m .72502 .72811 L .72551 .72668 L F
.676 .639 .805 r
.49188 .73463 m .49368 .73438 L .49046 .73346 L F
.483 0 0 r
.71707 .70815 m .71552 .70696 L .71443 .70679 L F
.71707 .70815 m .71791 .70824 L .71552 .70696 L F
.6 .584 .807 r
.41041 .77925 m .40817 .77997 L .40697 .77695 L F
.724 .626 .749 r
.69575 .5917 m .69715 .587 L .69512 .58877 L F
.633 .286 .365 r
.5051 .77771 m .50721 .7794 L .50874 .77702 L F
.728 .4 .424 r
.50721 .7794 m .51063 .77988 L .50874 .77702 L F
.807 .326 0 r
.50874 .77702 m .51063 .77988 L .51166 .78037 L F
.944 .954 .744 r
.65139 .6251 m .65311 .62396 L .65315 .62205 L F
.65139 .6251 m .65206 .62585 L .65311 .62396 L F
.818 .998 .846 r
.64734 .65306 m .64423 .65516 L .64474 .65545 L F
.422 .056 .237 r
.61811 .68578 m .61765 .68764 L .61505 .68812 L F
.048 0 .116 r
.61908 .68666 m .61811 .68578 L .61996 .68483 L F
.61908 .68666 m .61765 .68764 L .61811 .68578 L F
.753 .628 .722 r
.57858 .69661 m .57809 .69895 L .57493 .69832 L F
.651 .455 .605 r
.58148 .69896 m .57877 .70155 L .57809 .69895 L F
.072 .534 .899 r
.68336 .6385 m .68429 .63947 L .68561 .63967 L F
.304 0 .068 r
.31881 .65499 m .32059 .65455 L .3216 .65352 L F
.16 0 0 r
.32059 .65455 m .32347 .65285 L .3216 .65352 L F
.75 .862 .931 r
.6767 .60946 m .67984 .60923 L .67915 .60726 L F
.729 .803 .91 r
.67915 .60726 m .67984 .60923 L .68233 .60744 L F
.531 .29 .496 r
.34482 .8023 m .34786 .80172 L .34788 .79918 L F
.621 .362 .504 r
.34788 .79918 m .34786 .80172 L .34969 .80097 L F
.465 .36 .65 r
.34788 .79918 m .34969 .80097 L .34958 .79873 L F
.34788 .79918 m .34969 .80097 L .34958 .79873 L F
.06 .625 .745 r
.46039 .72581 m .46256 .72572 L .46377 .72573 L F
.344 .806 .932 r
.46256 .72572 m .46591 .7256 L .46377 .72573 L F
.801 .34 .143 r
.697 .71324 m .69391 .7119 L .69558 .71267 L F
.841 .805 .815 r
.71192 .61619 m .70978 .62 L .70889 .61714 L F
.775 .429 0 r
.69924 .72555 m .70053 .72874 L .70163 .72556 L F
.318 .804 .872 r
.46915 .72483 m .47019 .72429 L .47157 .72447 L F
.46915 .72483 m .46797 .72479 L .47019 .72429 L F
.812 .689 .728 r
.60103 .66332 m .60218 .66634 L .60401 .66368 L F
.961 .626 .287 r
.51063 .77988 m .51202 .78228 L .51166 .78037 L F
.416 .248 .544 r
.37939 .68806 m .37932 .69038 L .37764 .69079 L F
.373 .192 .502 r
.37905 .69264 m .37764 .69079 L .37932 .69038 L F
.37905 .69264 m .37742 .69344 L .37764 .69079 L F
.573 .786 .979 r
.72587 .73361 m .72349 .73323 L .72452 .73194 L F
.934 .898 .768 r
.57807 .66952 m .57702 .66884 L .57871 .66581 L F
.805 .422 .33 r
.50771 .78533 m .5065 .78691 L .50495 .78471 L F
.867 .513 .378 r
.50795 .78673 m .5065 .78691 L .50771 .78533 L F
.631 .815 .971 r
.70232 .62387 m .7002 .62478 L .69928 .62332 L F
.656 .612 .793 r
.70334 .62619 m .7002 .62478 L .70232 .62387 L F
0 0 0 r
.30671 .71753 m .30809 .71492 L .31004 .7172 L F
.636 .733 .918 r
.31189 .71671 m .31004 .7172 L .30809 .71492 L F
0 0 .471 r
.67758 .61458 m .67722 .61523 L .67662 .61296 L F
.67758 .61458 m .67662 .61296 L .67609 .61216 L F
.694 .668 .821 r
.36051 .78486 m .36201 .78792 L .36367 .78517 L F
.588 .53 .757 r
.36367 .78517 m .36201 .78792 L .36424 .78753 L F
.581 .489 .715 r
.36263 .79068 m .36424 .78753 L .36201 .78792 L F
.936 .685 .533 r
.3808 .8057 m .38311 .80693 L .38181 .80723 L F
0 0 0 r
.38181 .80723 m .38311 .80693 L .38438 .80666 L F
.89 .754 .706 r
.6516 .64795 m .65063 .64456 L .65052 .64659 L F
.8 .496 .476 r
.64909 .64975 m .6516 .64795 L .65052 .64659 L F
.64909 .64975 m .65182 .64999 L .6516 .64795 L F
.691 .7 .853 r
.50311 .71784 m .50474 .72045 L .50121 .7197 L F
.588 .655 .883 r
.50679 .71995 m .50474 .72045 L .50311 .71784 L F
.69 .567 .711 r
.50795 .72301 m .50474 .72045 L .50679 .71995 L F
.50795 .72301 m .50637 .72441 L .50474 .72045 L F
.664 .661 .837 r
.70456 .62268 m .70334 .62619 L .70232 .62387 L F
.70456 .62268 m .70568 .62524 L .70334 .62619 L F
.698 .584 .724 r
.63525 .6204 m .6326 .62209 L .63368 .61997 L F
.576 .126 .147 r
.46996 .76941 m .47187 .77067 L .47321 .76916 L F
.537 .11 .178 r
.47187 .77067 m .47538 .76914 L .47321 .76916 L F
.843 .651 .643 r
.60218 .66634 m .60209 .6692 L .60379 .66928 L F
.83 .558 .527 r
.60209 .6692 m .60211 .67072 L .60379 .66928 L F
.857 .607 .559 r
.60211 .67072 m .60391 .67199 L .60379 .66928 L F
.438 .07 .241 r
.40662 .75035 m .40357 .75244 L .4045 .75057 L F
.723 .62 .743 r
.57718 .69331 m .57858 .69661 L .57493 .69614 L F
.753 .628 .722 r
.57858 .69661 m .57493 .69832 L .57493 .69614 L F
.728 .623 .74 r
.58098 .69399 m .57858 .69661 L .57718 .69331 L F
.419 .089 .297 r
.52773 .77491 m .52937 .77584 L .53051 .77403 L F
.401 0 .153 r
.52937 .77584 m .53277 .77353 L .53051 .77403 L F
.395 .136 .399 r
.38855 .67945 m .38827 .68232 L .38606 .68195 L F
.217 .021 .386 r
.38744 .68393 m .38606 .68195 L .38827 .68232 L F
.38744 .68393 m .38611 .68473 L .38606 .68195 L F
.534 0 0 r
.7214 .70899 m .7238 .71033 L .72431 .71001 L F
0 .177 .597 r
.72581 .71097 m .72683 .71162 L .72431 .71001 L F
.72581 .71097 m .72431 .71001 L .7238 .71033 L F
.258 0 0 r
.38548 .80124 m .38966 .7982 L .38884 .79876 L F
.409 .81 .983 r
.39155 .79788 m .39035 .79739 L .38966 .7982 L F
.553 .884 .622 r
.39035 .79739 m .38884 .79876 L .38966 .7982 L F
.584 .793 .979 r
.7104 .61166 m .70883 .61304 L .70771 .61173 L F
.7104 .61166 m .71132 .61253 L .70883 .61304 L F
.287 .263 .657 r
.70883 .61304 m .7104 .61166 L .70771 .61173 L F
.53 .279 .479 r
.71132 .61253 m .71093 .6151 L .70883 .61304 L F
.287 .263 .657 r
.70883 .61304 m .71093 .6151 L .7104 .61166 L F
.744 .561 .646 r
.57061 .69914 m .5672 .70121 L .56774 .699 L F
.57061 .69914 m .57066 .70157 L .5672 .70121 L F
.691 .518 .648 r
.5729 .69879 m .57066 .70157 L .57061 .69914 L F
.756 .62 .709 r
.5717 .71197 m .56786 .71191 L .56968 .7097 L F
.749 .528 .594 r
.5717 .71197 m .56941 .71468 L .56786 .71191 L F
.74 .635 .743 r
.57321 .71036 m .5717 .71197 L .56968 .7097 L F
.693 .447 .547 r
.57304 .71464 m .56941 .71468 L .5717 .71197 L F
.644 .661 .852 r
.51025 .72245 m .51092 .72396 L .50795 .72301 L F
.615 .645 .857 r
.51196 .72214 m .51092 .72396 L .51025 .72245 L F
.586 .609 .842 r
.51196 .72214 m .51336 .72357 L .51092 .72396 L F
.311 0 .082 r
.36119 .80568 m .36199 .80634 L .35985 .80501 L F
0 0 .049 r
.66706 .60085 m .66754 .59902 L .66889 .59665 L F
.126 0 0 r
.72003 .71582 m .71901 .71613 L .71673 .71618 L F
.038 0 0 r
.7223 .7154 m .71901 .71613 L .72003 .71582 L F
.702 .581 .717 r
.57493 .69614 m .57156 .69342 L .57486 .69375 L F
.639 .499 .676 r
.57718 .69331 m .57493 .69614 L .57486 .69375 L F
.42 0 0 r
.48887 .77813 m .4875 .77881 L .48546 .77843 L F
.546 .086 .113 r
.49096 .77819 m .4875 .77881 L .48887 .77813 L F
.61 .681 .892 r
.49352 .72311 m .49137 .72364 L .49015 .7221 L F
.226 .64 .957 r
.66775 .60911 m .66855 .60988 L .66768 .60684 L F
.66775 .60911 m .66886 .60998 L .66855 .60988 L F
.727 .646 .768 r
.57505 .70971 m .57212 .70725 L .57464 .70779 L F
.57505 .70971 m .57321 .71036 L .57212 .70725 L F
.609 .536 .747 r
.5772 .70766 m .57505 .70971 L .57464 .70779 L F
.706 .705 .846 r
.577 .70874 m .57505 .70971 L .5772 .70766 L F
.606 .445 .637 r
.577 .70874 m .57504 .71196 L .57505 .70971 L F
.543 .38 .609 r
.34882 .70191 m .35102 .70169 L .35086 .69872 L F
.392 .149 .422 r
.34882 .70191 m .35028 .70332 L .35102 .70169 L F
.34882 .70191 m .34847 .70392 L .35028 .70332 L F
.356 .631 .958 r
.68569 .58683 m .68765 .58607 L .68602 .58506 L F
.68569 .58683 m .68861 .58733 L .68765 .58607 L F
.129 .592 .922 r
.28512 .60463 m .28468 .60459 L .28325 .60371 L F
.42 .242 .532 r
.39071 .67581 m .39004 .67904 L .38855 .67945 L F
.38 .124 .396 r
.39012 .68164 m .38855 .67945 L .39004 .67904 L F
.39012 .68164 m .38827 .68232 L .38855 .67945 L F
.721 .643 .77 r
.57212 .70725 m .57321 .71036 L .56968 .7097 L F
.939 .964 .691 r
.66779 .60981 m .66886 .60998 L .66775 .60911 L F
.66779 .60981 m .66714 .61318 L .66886 .60998 L F
.556 .402 .628 r
.37039 .76352 m .37238 .76072 L .37025 .76108 L F
.994 .872 .592 r
.65072 .62734 m .65206 .62585 L .65139 .6251 L F
.65072 .62734 m .65121 .62908 L .65206 .62585 L F
.715 .465 0 r
.66799 .59088 m .66851 .59344 L .66818 .59204 L F
.91 .768 .691 r
.64898 .63612 m .65155 .63679 L .65154 .63414 L F
.909 .77 .695 r
.64963 .63901 m .65155 .63679 L .64898 .63612 L F
0 0 0 r
.62413 .67932 m .62177 .68214 L .62286 .68055 L F
.997 .795 .514 r
.66766 .60458 m .66706 .60085 L .66992 .6027 L F
.142 .044 .474 r
.66768 .60684 m .66766 .60458 L .66992 .6027 L F
0 0 .183 r
.66781 .60625 m .66766 .60458 L .66992 .6027 L F
.834 .603 .589 r
.64956 .64137 m .65258 .63965 L .64963 .63901 L F
.64956 .64137 m .65256 .64199 L .65258 .63965 L F
.677 .445 .563 r
.59392 .69569 m .59157 .69361 L .59371 .69318 L F
.59392 .69569 m .59159 .69588 L .59157 .69361 L F
.738 .586 .686 r
.5729 .69879 m .57441 .70174 L .57066 .70157 L F
.703 .592 .728 r
.57493 .69614 m .5729 .69879 L .57276 .69654 L F
.633 .493 .673 r
.57493 .69832 m .5729 .69879 L .57493 .69614 L F
.748 .739 .844 r
.49691 .72333 m .49352 .72311 L .49552 .72208 L F
.792 .739 .804 r
.4991 .72073 m .49691 .72333 L .49552 .72208 L F
.581 .489 .715 r
.36263 .79068 m .36485 .79041 L .36424 .78753 L F
.601 .427 .618 r
.36274 .79263 m .36485 .79041 L .36263 .79068 L F
.971 .701 .283 r
.67011 .61536 m .66961 .61703 L .66924 .61445 L F
.67011 .61536 m .6703 .61773 L .66961 .61703 L F
.746 .66 .765 r
.56953 .68279 m .57112 .68585 L .56738 .68525 L F
.785 .581 .624 r
.5705 .68804 m .56738 .68525 L .57112 .68585 L F
.857 .658 .632 r
.69118 .71605 m .69241 .71815 L .68982 .71697 L F
.869 .611 .546 r
.68982 .71697 m .69241 .71815 L .69235 .7188 L F
.68982 .71697 m .69235 .7188 L .69137 .71982 L F
.69137 .71982 m .69235 .7188 L .6921 .72118 L F
.68982 .71697 m .6921 .72118 L .69213 .71799 L F
.966 .836 .665 r
.69213 .71799 m .6908 .72042 L .68906 .72123 L F
.6908 .72042 m .68999 .72191 L .68963 .72165 L F
.6908 .72042 m .68963 .72165 L .68906 .72123 L F
.583 .613 .848 r
.69349 .71499 m .69241 .71815 L .69118 .71605 L F
.69349 .71499 m .69502 .71767 L .69241 .71815 L F
0 0 0 r
.69241 .71815 m .69498 .71769 L .6921 .72118 L F
.69241 .71815 m .69502 .71767 L .69498 .71769 L F
.311 .38 .772 r
.36269 .67683 m .36404 .68023 L .36455 .67872 L F
.513 .387 .646 r
.3633 .68239 m .36455 .67872 L .36404 .68023 L F
.754 .745 .844 r
.35079 .80418 m .35412 .80422 L .3535 .80187 L F
.678 .267 .259 r
.35079 .80418 m .35334 .80621 L .35412 .80422 L F
.383 .496 .85 r
.3535 .80187 m .35412 .80422 L .35633 .80477 L F
.109 0 .152 r
.35437 .80668 m .35412 .80422 L .35334 .80621 L F
.35437 .80668 m .35633 .80477 L .35412 .80422 L F
.602 .839 .989 r
.47695 .72447 m .47467 .72516 L .47352 .7243 L F
.686 .681 .84 r
.35588 .67212 m .35699 .67471 L .35945 .67396 L F
.518 .255 .455 r
.61594 .6281 m .61844 .6258 L .6162 .62627 L F
.54 .357 .582 r
.70322 .59857 m .70308 .6014 L .70514 .59883 L F
.424 .076 .268 r
.37671 .69516 m .37541 .69414 L .37742 .69344 L F
.37671 .69516 m .37464 .69561 L .37541 .69414 L F
.805 .792 .841 r
.63605 .64199 m .6347 .64398 L .63298 .64207 L F
.818 .998 .846 r
.64734 .65306 m .64662 .65284 L .64423 .65516 L F
.655 .888 .982 r
.64734 .65306 m .64928 .65223 L .64818 .65156 L F
.745 .99 .885 r
.64734 .65306 m .64818 .65156 L .64662 .65284 L F
.801 .34 .143 r
.697 .71324 m .69588 .71402 L .69391 .7119 L F
.658 .319 .387 r
.62938 .63683 m .63258 .63644 L .6317 .63861 L F
.771 .498 .522 r
.63489 .63693 m .6317 .63861 L .63258 .63644 L F
.675 .663 .831 r
.67569 .63056 m .6791 .63132 L .67788 .62888 L F
.622 .654 .861 r
.67788 .62888 m .6791 .63132 L .68141 .63035 L F
.105 .646 .845 r
.446 .72427 m .4482 .72429 L .44935 .72457 L F
.461 0 0 r
.4482 .72429 m .4516 .72484 L .44935 .72457 L F
.292 .017 .313 r
.29363 .61559 m .29293 .61744 L .29129 .61806 L F
.521 .337 .572 r
.2932 .61985 m .29129 .61806 L .29293 .61744 L F
.2932 .61985 m .29116 .62037 L .29129 .61806 L F
.824 .856 .871 r
.70035 .5748 m .69761 .57474 L .69978 .5747 L F
.339 .591 .938 r
.70211 .57379 m .70035 .5748 L .69978 .5747 L F
.70216 .5738 m .70035 .5748 L .70211 .57379 L F
.70238 .57368 m .70428 .57675 L .70035 .5748 L F
.415 .663 .963 r
.70092 .57251 m .70238 .57368 L .69978 .5747 L F
.88 .815 .781 r
.70043 .57466 m .70107 .57548 L .70167 .57561 L F
.70043 .57466 m .70167 .57561 L .70029 .57477 L F
.927 .788 .687 r
.70029 .57477 m .70167 .57561 L .70117 .57351 L F
.70068 .57337 m .70117 .57351 L .70092 .57251 L F
.70029 .57477 m .70117 .57351 L .70068 .57337 L F
.339 .591 .938 r
.70238 .57368 m .70216 .5738 L .70211 .57379 L F
.352 .096 .379 r
.62308 .62045 m .62537 .61997 L .62548 .61771 L F
.382 .181 .479 r
.62548 .61771 m .62759 .61766 L .62713 .61536 L F
.317 0 .142 r
.62668 .61887 m .62548 .61771 L .62537 .61997 L F
.62668 .61887 m .62759 .61766 L .62548 .61771 L F
.186 0 0 r
.49991 .77729 m .502 .77726 L .5033 .77695 L F
.562 .013 0 r
.502 .77726 m .5051 .77771 L .5033 .77695 L F
.999 .788 .479 r
.65448 .61451 m .6553 .61711 L .65554 .61537 L F
.462 .253 .508 r
.65554 .61537 m .65754 .61536 L .65839 .61266 L F
.681 .591 .748 r
.65554 .61537 m .65701 .6156 L .6571 .61536 L F
.794 .596 .633 r
.65839 .61266 m .65754 .61536 L .65448 .61451 L F
.65706 .61542 m .65448 .61451 L .65674 .61608 L F
.23 .384 .811 r
.65745 .61556 m .65448 .61451 L .65754 .61536 L F
.794 .596 .633 r
.65839 .61266 m .65448 .61451 L .65706 .61542 L F
.674 .797 .337 r
.65717 .61519 m .65706 .61542 L .65723 .61503 L F
.65706 .61542 m .65674 .61608 L .65697 .61558 L F
.65706 .61542 m .65697 .61558 L .65723 .61503 L F
.23 .384 .811 r
.65707 .61639 m .65669 .61611 L .65745 .61556 L F
.65697 .61558 m .65448 .61451 L .65706 .61542 L F
.767 .696 .784 r
.65697 .61558 m .65674 .61608 L .65664 .6155 L F
.23 .384 .811 r
.65694 .61564 m .65664 .6155 L .65697 .61558 L F
.65664 .6155 m .65448 .61451 L .65697 .61558 L F
.165 .316 .772 r
.65684 .60918 m .65839 .61266 L .65908 .61107 L F
.767 .696 .784 r
.65908 .61107 m .65697 .61558 L .65579 .61065 L F
.65697 .61558 m .65664 .6155 L .65579 .61065 L F
.607 .587 .805 r
.65579 .61065 m .65664 .6155 L .65448 .61451 L F
.65664 .6155 m .65674 .61608 L .65448 .61451 L F
.23 .384 .811 r
.65669 .61611 m .65448 .61451 L .65694 .61564 L F
.65669 .61611 m .65706 .61542 L .65745 .61556 L F
.674 .797 .337 r
.65839 .61266 m .65717 .61519 L .65908 .61107 L F
.65717 .61519 m .65723 .61503 L .65908 .61107 L F
.681 .591 .748 r
.6571 .61536 m .65921 .61595 L .65754 .61536 L F
.65701 .6156 m .65921 .61595 L .6571 .61536 L F
.828 .835 .853 r
.70848 .63424 m .70957 .63417 L .70908 .63124 L F
.609 .516 .724 r
.35246 .69291 m .35325 .69461 L .3549 .69325 L F
.488 .224 .44 r
.40141 .75267 m .39934 .75546 L .40213 .75292 L F
.40141 .75267 m .40141 .75532 L .39934 .75546 L F
.384 .146 .425 r
.40324 .75461 m .40141 .75267 L .40357 .75244 L F
.40324 .75461 m .40141 .75532 L .40141 .75267 L F
.641 .376 .503 r
.6102 .68794 m .60953 .69066 L .60699 .69048 L F
.579 .316 .483 r
.61253 .6896 m .6102 .68794 L .61247 .68787 L F
.61253 .6896 m .60953 .69066 L .6102 .68794 L F
.768 .632 .71 r
.57214 .69101 m .56854 .69086 L .5705 .68804 L F
.8 .607 .64 r
.57156 .69342 m .56854 .69086 L .57214 .69101 L F
.696 .501 .621 r
.57441 .70174 m .57083 .70401 L .57066 .70157 L F
.57441 .70174 m .57412 .70436 L .57083 .70401 L F
.707 .512 .622 r
.57663 .70398 m .57412 .70436 L .57441 .70174 L F
.739 .926 .953 r
.71424 .59734 m .71052 .59847 L .71301 .59569 L F
.718 .72 .851 r
.71301 .59569 m .71629 .59623 L .71424 .59734 L F
.202 0 0 r
.42615 .72559 m .42816 .72521 L .42948 .72412 L F
.417 0 0 r
.42948 .72412 m .42816 .72521 L .43144 .72459 L F
.047 0 .112 r
.52578 .77717 m .52479 .77912 L .52705 .77647 L F
.947 .842 .706 r
.73098 .72806 m .73331 .72584 L .73229 .72497 L F
.73098 .72806 m .73214 .72872 L .73331 .72584 L F
.358 .034 .272 r
.38188 .68602 m .38128 .68756 L .37939 .68806 L F
.545 .267 .445 r
.38416 .68547 m .38128 .68756 L .38188 .68602 L F
.478 .032 .111 r
.51765 .77902 m .51598 .78011 L .51989 .77928 L F
.624 .874 .989 r
.3356 .71159 m .33429 .71246 L .33495 .71102 L F
.737 .984 .905 r
.33429 .71246 m .33328 .71235 L .33495 .71102 L F
.688 .607 .76 r
.51991 .72633 m .51675 .72401 L .51898 .72321 L F
.567 .541 .785 r
.52204 .72584 m .51991 .72633 L .51898 .72321 L F
.555 .478 .723 r
.52204 .72584 m .52251 .72858 L .51991 .72633 L F
.554 .478 .724 r
.51991 .72633 m .52251 .72858 L .52061 .7289 L F
0 0 0 r
.61265 .64543 m .61134 .64693 L .60989 .64795 L F
.60989 .64795 m .61134 .64693 L .60838 .6491 L F
.519 .215 .39 r
.30358 .66351 m .30573 .6633 L .30647 .66156 L F
.417 .113 .34 r
.30647 .66156 m .30769 .66282 L .30819 .66088 L F
.30647 .66156 m .30573 .6633 L .30769 .66282 L F
.113 0 0 r
.34213 .72318 m .34083 .72515 L .33952 .725 L F
.34083 .72515 m .33817 .72695 L .33952 .725 L F
.638 .604 .799 r
.51025 .72245 m .50795 .72301 L .50679 .71995 L F
.592 .076 0 r
.41041 .77925 m .41226 .77995 L .41361 .77958 L F
.144 0 0 r
.41226 .77995 m .41587 .77982 L .41361 .77958 L F
.458 .512 .826 r
.38126 .66251 m .37983 .66427 L .37857 .66123 L F
.423 .46 .795 r
.38126 .66251 m .38233 .66572 L .37983 .66427 L F
.478 .451 .75 r
.37983 .66427 m .38233 .66572 L .38049 .66595 L F
.599 .271 .385 r
.35693 .79522 m .35887 .79632 L .36031 .79333 L F
.38 .048 .271 r
.36031 .79333 m .36176 .79517 L .36274 .79263 L F
.36031 .79333 m .35887 .79632 L .36176 .79517 L F
.27 0 .302 r
.29527 .61479 m .29293 .61744 L .29363 .61559 L F
.114 0 0 r
.44444 .78187 m .44093 .78354 L .44228 .78217 L F
0 .325 .811 r
.40474 .77253 m .40373 .77262 L .40289 .77245 L F
.40474 .77253 m .40565 .77391 L .40373 .77262 L F
.72 .537 .642 r
.36051 .78486 m .36256 .7824 L .3608 .78264 L F
.921 .618 .454 r
.73127 .73556 m .73292 .73649 L .73245 .73403 L F
.356 .082 .353 r
.62098 .62326 m .6229 .62258 L .62308 .62045 L F
.195 0 0 r
.62429 .62107 m .62308 .62045 L .6229 .62258 L F
.62429 .62107 m .62537 .61997 L .62308 .62045 L F
.211 .731 .861 r
.4793 .73347 m .4781 .73331 L .47595 .73353 L F
.378 .835 .916 r
.48021 .7328 m .4793 .73347 L .48128 .73264 L F
.48021 .7328 m .4781 .73331 L .4793 .73347 L F
.499 .373 .64 r
.36871 .76635 m .37058 .76817 L .37042 .76585 L F
.36871 .76635 m .36879 .76943 L .37058 .76817 L F
.261 0 .259 r
.34682 .70466 m .34606 .70641 L .34847 .70392 L F
.767 .666 .751 r
.69854 .59334 m .70183 .59378 L .70074 .59061 L F
.75 .657 .758 r
.70074 .59061 m .70183 .59378 L .70433 .59149 L F
.432 .856 .948 r
.37485 .80373 m .37411 .80446 L .37633 .80397 L F
.229 .669 .955 r
.34965 .65043 m .34876 .65115 L .34748 .65068 L F
.34965 .65043 m .35087 .6512 L .34876 .65115 L F
.384 .767 .99 r
.42717 .77637 m .42693 .77738 L .42622 .77607 L F
.42717 .77637 m .42914 .77727 L .42693 .77738 L F
.737 .611 .717 r
.3401 .80181 m .33996 .80396 L .34219 .80138 L F
.704 .561 .689 r
.33996 .80396 m .3435 .80465 L .34219 .80138 L F
.687 .552 .696 r
.34219 .80138 m .3435 .80465 L .34482 .8023 L F
.563 .31 .49 r
.64245 .61801 m .64331 .6196 L .63969 .62087 L F
.509 .426 .697 r
.64245 .61801 m .64455 .61971 L .64331 .6196 L F
.64245 .61801 m .64493 .61817 L .64455 .61971 L F
.739 .578 .674 r
.63489 .63693 m .63796 .63916 L .63498 .63891 L F
.812 .688 .728 r
.63796 .63916 m .63605 .64199 L .63498 .63891 L F
.645 .665 .854 r
.49046 .73346 m .49368 .73438 L .49271 .73275 L F
.648 .666 .853 r
.49271 .73275 m .49368 .73438 L .49589 .73375 L F
.466 .827 .995 r
.47595 .73353 m .47257 .73336 L .47382 .73381 L F
.781 .34 .202 r
.49302 .77409 m .49669 .77638 L .49467 .7741 L F
.419 .089 .297 r
.52773 .77491 m .52705 .77647 L .52937 .77584 L F
.883 .782 .744 r
.50395 .73257 m .50477 .73402 L .50346 .73155 L F
.631 .318 .423 r
.50149 .73601 m .50477 .73402 L .50395 .73257 L F
.50149 .73601 m .50435 .73631 L .50477 .73402 L F
.434 .481 .809 r
.50477 .73402 m .50564 .73104 L .50346 .73155 L F
.50477 .73402 m .50682 .73381 L .50564 .73104 L F
.619 .426 .6 r
.50435 .73631 m .50682 .73381 L .50477 .73402 L F
.884 .873 .821 r
.71145 .73624 m .71157 .73342 L .71277 .73498 L F
.377 .571 .914 r
.7136 .73302 m .71277 .73498 L .71157 .73342 L F
.7136 .73302 m .71519 .73504 L .71277 .73498 L F
.2 .702 .909 r
.67987 .60086 m .68319 .60123 L .68133 .60128 L F
.754 .684 .783 r
.56517 .70402 m .56629 .70701 L .56287 .70672 L F
.796 .612 .652 r
.56629 .70701 m .56299 .70909 L .56287 .70672 L F
.56629 .70701 m .56614 .70948 L .56299 .70909 L F
.72 .666 .796 r
.56864 .70444 m .56629 .70701 L .56517 .70402 L F
.701 .635 .78 r
.56858 .70632 m .56629 .70701 L .56864 .70444 L F
.726 .586 .698 r
.56858 .70632 m .56614 .70948 L .56629 .70701 L F
.324 0 0 r
.44555 .77136 m .44772 .77157 L .44512 .77114 L F
.562 .409 .631 r
.37163 .75534 m .37384 .75504 L .37367 .75263 L F
.567 .444 .671 r
.37209 .75844 m .37384 .75504 L .37163 .75534 L F
.635 .074 0 r
.72738 .71705 m .72427 .71516 L .72556 .71608 L F
.469 0 0 r
.52021 .79139 m .51866 .79224 L .51666 .792 L F
.365 0 0 r
.52242 .79072 m .51866 .79224 L .52021 .79139 L F
.329 0 0 r
.45014 .7799 m .45085 .78103 L .44869 .78132 L F
.45014 .7799 m .4523 .77974 L .45085 .78103 L F
.651 .455 .605 r
.58148 .69896 m .58168 .70178 L .57877 .70155 L F
.556 .381 .599 r
.58415 .69633 m .5839 .69861 L .58148 .69896 L F
.574 .397 .603 r
.58393 .70114 m .58148 .69896 L .5839 .69861 L F
.58393 .70114 m .58168 .70178 L .58148 .69896 L F
.579 .756 .962 r
.36981 .79835 m .36996 .79629 L .36806 .79732 L F
.36981 .79835 m .37216 .79796 L .36996 .79629 L F
.503 .349 .605 r
.35086 .69872 m .35296 .7011 L .35283 .69846 L F
.35086 .69872 m .35102 .70169 L .35296 .7011 L F
.296 0 0 r
.43144 .72459 m .43363 .72467 L .43501 .72404 L F
.237 0 0 r
.43363 .72467 m .43725 .72403 L .43501 .72404 L F
.615 .462 .651 r
.36513 .77947 m .36741 .77681 L .36514 .77716 L F
0 0 0 r
.626 .67662 m .62508 .67771 L .62703 .6749 L F
0 0 .058 r
.626 .67662 m .62413 .67932 L .62508 .67771 L F
.454 .233 .487 r
.53714 .77698 m .53662 .77974 L .53461 .7804 L F
.35 .142 .45 r
.53827 .77882 m .53714 .77698 L .53845 .77659 L F
.53827 .77882 m .53662 .77974 L .53714 .77698 L F
.141 0 0 r
.33307 .64914 m .33669 .64931 L .33466 .64914 L F
.08 .27 .756 r
.73339 .71597 m .73117 .715 L .73063 .71398 L F
.73339 .71597 m .7333 .71706 L .73117 .715 L F
.702 .581 .717 r
.57493 .69614 m .57276 .69654 L .57156 .69342 L F
.386 .442 .796 r
.71722 .74052 m .71812 .73857 L .71616 .73934 L F
.763 .657 .746 r
.57412 .70436 m .57464 .70779 L .57212 .70725 L F
.607 .485 .687 r
.57663 .70398 m .57464 .70779 L .57412 .70436 L F
.57663 .70398 m .5772 .70766 L .57464 .70779 L F
.694 .746 .892 r
.67473 .62816 m .67569 .63056 L .67788 .62888 L F
.589 .102 .067 r
.51461 .79039 m .51306 .79089 L .51106 .79028 L F
.592 .069 0 r
.51666 .792 m .51306 .79089 L .51461 .79039 L F
0 0 .444 r
.67022 .62356 m .67115 .62565 L .67031 .62216 L F
.652 .849 .976 r
.69215 .58872 m .69512 .58877 L .69409 .58754 L F
.82 .892 .894 r
.69512 .58877 m .69613 .58609 L .69409 .58754 L F
.69512 .58877 m .69715 .587 L .69613 .58609 L F
.598 .59 .815 r
.49918 .73652 m .50036 .73962 L .50239 .73904 L F
.535 .369 .603 r
.50036 .73962 m .50255 .74149 L .50239 .73904 L F
.551 .119 .174 r
.4797 .77554 m .47878 .7769 L .47652 .77668 L F
.565 .134 .182 r
.48201 .7765 m .47878 .7769 L .4797 .77554 L F
.389 0 0 r
.48341 .77678 m .48201 .7765 L .4797 .77554 L F
.475 .8 1 r
.40662 .75035 m .40965 .75075 L .40841 .74998 L F
.119 0 0 r
.41236 .75052 m .40841 .74998 L .40965 .75075 L F
.258 0 0 r
.44967 .73963 m .44838 .74046 L .44652 .74057 L F
0 0 0 r
.45073 .73902 m .44967 .73963 L .45119 .73857 L F
.45073 .73902 m .44838 .74046 L .44967 .73963 L F
.089 0 0 r
.63603 .66426 m .63779 .66341 L .63509 .66548 L F
.929 .97 .748 r
.69859 .58419 m .69969 .5831 L .69819 .58368 L F
.907 .982 .773 r
.69978 .58111 m .69969 .5831 L .70163 .58026 L F
.91 .982 .762 r
.69819 .58368 m .69969 .5831 L .69978 .58111 L F
.685 .552 .698 r
.36256 .7824 m .36513 .77947 L .36287 .77983 L F
.49 .365 .637 r
.37559 .74751 m .37765 .7495 L .37789 .74723 L F
.37559 .74751 m .37581 .74996 L .37765 .7495 L F
.811 .861 .886 r
.71076 .62459 m .70902 .62631 L .70789 .62528 L F
0 0 0 r
.4241 .77525 m .42169 .7773 L .42298 .77633 L F
.42169 .7773 m .41992 .7788 L .42298 .77633 L F
.678 .679 .843 r
.48696 .73157 m .49046 .73346 L .48913 .73079 L F
.65 .734 .91 r
.49046 .73346 m .49125 .73071 L .48913 .73079 L F
.49046 .73346 m .49271 .73275 L .49125 .73071 L F
.508 0 0 r
.72492 .73788 m .72557 .73856 L .72375 .73702 L F
.72518 .73812 m .72656 .73933 L .72557 .73856 L F
.521 0 0 r
.72656 .73933 m .72778 .7404 L .72557 .73856 L F
.72778 .7404 m .72789 .7405 L .72773 .74037 L F
.72778 .7404 m .72773 .74037 L .72557 .73856 L F
.698 .534 .662 r
.72784 .74045 m .73216 .73848 L .73038 .73868 L F
.72757 .74064 m .72789 .74048 L .72784 .74045 L F
.72789 .74048 m .73216 .73848 L .72784 .74045 L F
.392 .425 .776 r
.72773 .74037 m .72842 .73756 L .72557 .73856 L F
.72789 .7405 m .72793 .74024 L .72773 .74037 L F
.72793 .74024 m .72842 .73756 L .72773 .74037 L F
.698 .534 .662 r
.72911 .73949 m .73038 .73868 L .73016 .73871 L F
.72757 .74064 m .73038 .73868 L .72911 .73949 L F
0 0 0 r
.72713 .73687 m .72557 .73856 L .72842 .73756 L F
.72713 .73687 m .72592 .73897 L .72557 .73856 L F
.72592 .73897 m .72537 .73992 L .72557 .73856 L F
.508 0 0 r
.72492 .73788 m .72518 .73812 L .72557 .73856 L F
.642 .731 .914 r
.70465 .63588 m .70564 .63728 L .70806 .63664 L F
.416 .302 .616 r
.3924 .67395 m .39071 .67581 L .3917 .6771 L F
.3924 .67395 m .39287 .67649 L .39071 .67581 L F
.371 .163 .462 r
.39287 .67649 m .39004 .67904 L .39071 .67581 L F
.432 .273 .565 r
.62713 .61536 m .62978 .61463 L .62969 .61205 L F
.217 .078 .468 r
.62713 .61536 m .62892 .61623 L .62978 .61463 L F
.62713 .61536 m .62759 .61766 L .62892 .61623 L F
.171 0 .019 r
.34266 .72439 m .34213 .72318 L .34407 .72258 L F
.34266 .72439 m .34083 .72515 L .34213 .72318 L F
.363 0 0 r
.44772 .77157 m .44995 .77158 L .45099 .77086 L F
.29 0 0 r
.45099 .77086 m .44995 .77158 L .45313 .77071 L F
.652 .134 0 r
.70053 .72874 m .69944 .72941 L .6971 .72787 L F
.775 .429 0 r
.69924 .72555 m .70019 .72829 L .70053 .72874 L F
.892 .969 .653 r
.70053 .72874 m .69944 .72941 L .70019 .72829 L F
.891 .497 .055 r
.7117 .71407 m .71124 .71437 L .71024 .71181 L F
.028 0 0 r
.33094 .73065 m .32929 .7315 L .32949 .73097 L F
.771 .498 .522 r
.63489 .63693 m .63498 .63891 L .6317 .63861 L F
.451 .006 .098 r
.6141 .64619 m .61265 .64543 L .61411 .64465 L F
.6141 .64619 m .61134 .64693 L .61265 .64543 L F
.636 .572 .766 r
.36434 .8122 m .3615 .8096 L .36094 .81203 L F
.907 .982 .773 r
.69978 .58111 m .70163 .58026 L .70046 .57884 L F
.647 .64 .829 r
.70163 .58026 m .70292 .57667 L .70046 .57884 L F
.70163 .58026 m .70374 .57972 L .70292 .57667 L F
.281 0 0 r
.45766 .77881 m .45438 .77934 L .45556 .77893 L F
.447 .698 .973 r
.5257 .73071 m .52398 .73096 L .52253 .72977 L F
.778 .375 .29 r
.48546 .77843 m .48201 .7765 L .48341 .77678 L F
.74 .802 .901 r
.69842 .6407 m .70034 .63941 L .69728 .6392 L F
.736 .938 .952 r
.7163 .6231 m .71371 .62367 L .71554 .62241 L F
.819 .969 .898 r
.71846 .62008 m .7163 .6231 L .71554 .62241 L F
.71846 .62008 m .7189 .62094 L .7163 .6231 L F
.281 0 .206 r
.31586 .65635 m .31722 .65677 L .31881 .65499 L F
.215 0 0 r
.31881 .65499 m .31983 .65557 L .32059 .65455 L F
.31881 .65499 m .31722 .65677 L .31983 .65557 L F
.452 .198 .437 r
.37283 .69627 m .37236 .6983 L .37037 .69869 L F
.48 .224 .447 r
.37434 .69788 m .37283 .69627 L .37464 .69561 L F
.37434 .69788 m .37236 .6983 L .37283 .69627 L F
.565 .762 .971 r
.35981 .65284 m .35777 .65329 L .35644 .65209 L F
.383 .843 .786 r
.4168 .78969 m .41588 .79026 L .41774 .78963 L F
.792 .739 .804 r
.4991 .72073 m .49552 .72208 L .49783 .71981 L F
.755 .846 .919 r
.50121 .7197 m .4991 .72073 L .49783 .71981 L F
.762 .707 .8 r
.64194 .62231 m .64375 .62356 L .64047 .62324 L F
.748 .71 .816 r
.64568 .62247 m .64375 .62356 L .64194 .62231 L F
.765 .747 .836 r
.72252 .61239 m .72278 .61535 L .72052 .61394 L F
.735 .541 0 r
.72278 .61535 m .72284 .61654 L .72052 .61394 L F
.72278 .61535 m .72297 .61745 L .72284 .61654 L F
.768 .749 .836 r
.72529 .6129 m .72278 .61535 L .72252 .61239 L F
.8 .607 .64 r
.57156 .69342 m .56837 .69312 L .56854 .69086 L F
0 0 0 r
.35844 .71188 m .35599 .71442 L .35697 .71282 L F
.59 .442 .649 r
.36731 .7744 m .36963 .77414 L .36935 .77159 L F
.555 .375 .593 r
.36741 .77681 m .36963 .77414 L .36731 .7744 L F
.783 .819 .881 r
.65754 .61536 m .65921 .61595 L .6613 .61424 L F
.871 .985 .835 r
.73027 .73011 m .72937 .73251 L .7317 .73109 L F
0 0 .149 r
.62815 .67365 m .62703 .6749 L .62888 .67193 L F
0 0 0 r
.626 .67662 m .62703 .6749 L .62815 .67365 L F
.447 .497 .817 r
.28932 .60543 m .28898 .60907 L .28703 .60437 L F
.943 .892 .493 r
.28877 .60918 m .28898 .60907 L .28932 .60543 L F
.174 0 0 r
.42371 .78794 m .42163 .78904 L .41987 .7893 L F
0 0 0 r
.42288 .78872 m .42371 .78794 L .42567 .78734 L F
.42288 .78872 m .42163 .78904 L .42371 .78794 L F
.972 .923 .612 r
.72694 .72297 m .72739 .71925 L .72722 .72057 L F
.638 .888 .986 r
.33685 .67667 m .33367 .67683 L .33502 .6776 L F
.49 .258 .489 r
.37978 .74216 m .38203 .74176 L .38221 .73942 L F
.449 .229 .486 r
.38221 .73942 m .38407 .73901 L .38445 .73671 L F
.636 .38 .515 r
.38221 .73942 m .38203 .74176 L .38436 .74146 L F
.501 .385 .653 r
.38221 .73942 m .38436 .74146 L .38407 .73901 L F
.38221 .73942 m .38436 .74146 L .38407 .73901 L F
.694 .19 0 r
.66799 .59532 m .66913 .59625 L .67094 .59853 L F
.437 .054 .213 r
.34073 .70944 m .34299 .70922 L .34422 .70708 L F
.267 0 .119 r
.34422 .70708 m .34491 .70855 L .34606 .70641 L F
.34422 .70708 m .34299 .70922 L .34491 .70855 L F
.512 .304 .534 r
.38407 .73901 m .38675 .73586 L .38445 .73671 L F
.709 .55 .671 r
.60323 .67385 m .60442 .67668 L .60429 .6745 L F
.702 .474 .575 r
.60442 .67668 m .60685 .67696 L .60429 .6745 L F
.689 .476 .593 r
.60429 .6745 m .60685 .67696 L .60682 .67453 L F
.722 .42 .466 r
.64683 .61245 m .64893 .61339 L .64601 .61438 L F
.513 .094 .183 r
.4071 .73028 m .40937 .73029 L .41072 .72851 L F
.507 .109 .219 r
.40937 .73029 m .41289 .72836 L .41072 .72851 L F
.235 .339 .767 r
.68534 .62528 m .68592 .62799 L .68347 .62602 L F
.898 .713 .644 r
.65018 .63298 m .65154 .63414 L .65033 .63099 L F
.91 .768 .691 r
.64898 .63612 m .65154 .63414 L .65018 .63298 L F
.144 0 .162 r
.63126 .66941 m .63031 .67083 L .62888 .67193 L F
.061 0 .062 r
.63295 .66834 m .63031 .67083 L .63126 .66941 L F
.041 0 0 r
.32521 .6516 m .32719 .65128 L .32899 .65054 L F
.721 .236 .092 r
.71187 .60177 m .71158 .60329 L .71063 .6013 L F
.71187 .60177 m .71422 .60367 L .71158 .60329 L F
.586 .334 .502 r
.30629 .68809 m .30818 .69 L .30602 .69013 L F
.601 .333 .482 r
.30851 .68801 m .30818 .69 L .30629 .68809 L F
.582 .684 .911 r
.69263 .64117 m .69404 .63908 L .69144 .64044 L F
.69263 .64117 m .69398 .64042 L .69404 .63908 L F
0 0 .06 r
.63031 .67083 m .62815 .67365 L .62888 .67193 L F
.531 .275 .473 r
.60921 .67425 m .61179 .67394 L .61175 .67158 L F
.368 .13 .416 r
.61179 .67394 m .61411 .67132 L .61175 .67158 L F
.354 .161 .474 r
.28911 .62314 m .28885 .62543 L .28711 .62601 L F
.463 .348 .637 r
.28813 .62738 m .28711 .62601 L .28885 .62543 L F
.28813 .62738 m .28641 .62798 L .28711 .62601 L F
.504 .275 .5 r
.51114 .71225 m .51311 .71412 L .51327 .71164 L F
.683 .485 .613 r
.59922 .69074 m .59926 .69316 L .59718 .69322 L F
.653 .437 .578 r
.60168 .69103 m .59926 .69316 L .59922 .69074 L F
.196 0 0 r
.44087 .74167 m .44053 .74159 L .43881 .74113 L F
.289 .785 .766 r
.44407 .74069 m .4427 .74099 L .44087 .74167 L F
.314 .805 .827 r
.4427 .74099 m .44053 .74159 L .44087 .74167 L F
0 0 0 r
.46773 .76817 m .46644 .76861 L .46857 .76818 L F
.46943 .76713 m .46899 .76783 L .46857 .76818 L F
0 .429 .848 r
.46857 .76818 m .46996 .76941 L .46823 .76845 L F
.978 .767 .551 r
.46857 .76818 m .46842 .77075 L .46996 .76941 L F
.999 .797 .481 r
.46857 .76818 m .4675 .77019 L .46842 .77075 L F
0 0 0 r
.46899 .76783 m .4675 .77019 L .46857 .76818 L F
0 .429 .848 r
.46857 .76818 m .46823 .76845 L .46773 .76817 L F
.726 .586 .698 r
.56858 .70632 m .56968 .7097 L .56614 .70948 L F
.67 .547 .706 r
.57083 .70401 m .56858 .70632 L .56864 .70444 L F
.57083 .70401 m .57212 .70725 L .56858 .70632 L F
.667 .553 .716 r
.57212 .70725 m .56968 .7097 L .56858 .70632 L F
.894 .977 .683 r
.6272 .63358 m .62955 .62988 L .62885 .63168 L F
.896 .594 .468 r
.48483 .77021 m .48615 .7717 L .48759 .77177 L F
.882 .55 .416 r
.48615 .7717 m .48632 .77347 L .48759 .77177 L F
.603 .183 .218 r
.48759 .77177 m .48632 .77347 L .48992 .77316 L F
.971 .666 .379 r
.67806 .59902 m .67676 .59746 L .6789 .59764 L F
.138 .264 .732 r
.67987 .60086 m .67806 .59902 L .6789 .59764 L F
.599 .547 .767 r
.34482 .8023 m .34803 .80429 L .34786 .80172 L F
0 0 0 r
.63379 .66684 m .63509 .66548 L .63295 .66834 L F
.71 .74 .875 r
.51675 .72401 m .51336 .72357 L .51553 .7228 L F
.704 .777 .909 r
.51898 .72321 m .51675 .72401 L .51553 .7228 L F
.575 .844 .995 r
.49015 .7221 m .48804 .72258 L .48667 .72182 L F
0 0 .44 r
.67367 .58973 m .67385 .59124 L .67388 .591 L F
.447 .274 .552 r
.38113 .68985 m .37939 .68806 L .38128 .68756 L F
.38113 .68985 m .37932 .69038 L .37939 .68806 L F
.727 .576 .685 r
.56968 .7097 m .56786 .71191 L .56614 .70948 L F
.985 .86 .631 r
.67196 .60746 m .67039 .60865 L .67092 .60649 L F
.67196 .60746 m .67126 .60954 L .67039 .60865 L F
.422 .857 .932 r
.35227 .67262 m .35348 .67277 L .35588 .67212 L F
.742 .656 .765 r
.59898 .66593 m .60218 .66634 L .60103 .66332 L F
.772 .59 .653 r
.59931 .66879 m .60218 .66634 L .59898 .66593 L F
.59931 .66879 m .60209 .6692 L .60218 .66634 L F
.76 .685 .78 r
.64455 .61971 m .64755 .62018 L .64568 .62247 L F
.748 .71 .816 r
.64568 .62247 m .64194 .62231 L .64455 .61971 L F
.493 .251 .477 r
.37206 .70044 m .37037 .69869 L .37236 .6983 L F
.37206 .70044 m .37005 .70088 L .37037 .69869 L F
.906 .915 .815 r
.72349 .73323 m .72331 .73082 L .72452 .73194 L F
.442 0 0 r
.45938 .73592 m .45593 .73656 L .45748 .73565 L F
.773 .916 .935 r
.66332 .61441 m .66714 .61318 L .66535 .61311 L F
.879 .923 .85 r
.66535 .61311 m .66714 .61318 L .66779 .60981 L F
.197 .455 .878 r
.3973 .79599 m .39815 .79552 L .398 .79498 L F
.956 .697 .248 r
.72349 .73323 m .72314 .73538 L .72227 .73259 L F
.72349 .73323 m .72375 .73702 L .72314 .73538 L F
.906 .915 .815 r
.72349 .73323 m .72227 .73259 L .72331 .73082 L F
.692 .773 .913 r
.38689 .66901 m .38332 .66902 L .38544 .6689 L F
.109 .44 .877 r
.38747 .66841 m .38689 .66901 L .38544 .6689 L F
.38747 .66841 m .38824 .66978 L .38689 .66901 L F
.064 .426 .869 r
.38824 .66978 m .38822 .66984 L .38689 .66901 L F
.018 0 0 r
.45724 .77026 m .46097 .76895 L .45891 .76927 L F
.857 .658 .632 r
.69118 .71605 m .68982 .71697 L .69195 .71441 L F
.376 .216 .533 r
.69349 .71499 m .69118 .71605 L .69195 .71441 L F
.585 .376 .563 r
.60685 .67696 m .60921 .67425 L .60682 .67453 L F
.5 .862 .988 r
.48128 .73264 m .48494 .73239 L .48372 .73157 L F
.67 .821 .956 r
.48494 .73239 m .48581 .73066 L .48372 .73157 L F
.48494 .73239 m .48696 .73157 L .48581 .73066 L F
.885 .874 .821 r
.6502 .61531 m .64701 .61718 L .64893 .61339 L F
.6502 .61531 m .64819 .61796 L .64701 .61718 L F
.211 0 .006 r
.53461 .7804 m .53662 .77974 L .53385 .78136 L F
.784 .899 .924 r
.69978 .5747 m .69685 .57407 L .69922 .57244 L F
.69978 .5747 m .69761 .57474 L .69685 .57407 L F
.415 .663 .963 r
.70092 .57251 m .69978 .5747 L .69922 .57244 L F
.386 0 0 r
.43725 .72403 m .43915 .7245 L .44061 .72401 L F
.365 0 0 r
.43915 .7245 m .44264 .72405 L .44061 .72401 L F
.606 .445 .637 r
.577 .70874 m .58035 .71258 L .57504 .71196 L F
.543 .547 .808 r
.5772 .70766 m .57989 .70854 L .577 .70874 L F
.585 .442 .653 r
.58105 .70981 m .577 .70874 L .57989 .70854 L F
.58105 .70981 m .58035 .71258 L .577 .70874 L F
.745 .39 .38 r
.68568 .63104 m .68372 .63287 L .68336 .63079 L F
.68568 .63104 m .687 .63325 L .68372 .63287 L F
.562 .013 0 r
.502 .77726 m .50415 .77848 L .5051 .77771 L F
.681 .156 0 r
.50415 .77848 m .50721 .7794 L .5051 .77771 L F
.755 .846 .919 r
.50121 .7197 m .49783 .71981 L .50031 .71812 L F
.746 .81 .903 r
.50311 .71784 m .50121 .7197 L .50031 .71812 L F
.535 .273 .465 r
.30602 .69013 m .3028 .69249 L .30393 .69061 L F
.73 .322 .277 r
.51989 .77928 m .52179 .78136 L .52299 .77974 L F
.501 .135 .276 r
.52179 .78136 m .52479 .77912 L .52299 .77974 L F
.264 0 0 r
.44264 .72405 m .44468 .72441 L .446 .72427 L F
.056 0 0 r
.44468 .72441 m .4482 .72429 L .446 .72427 L F
.193 0 0 r
.64932 .58973 m .65236 .58825 L .65002 .58863 L F
.507 .241 .446 r
.63272 .61029 m .63129 .60906 L .63104 .61133 L F
.301 .219 .595 r
.62969 .61205 m .63104 .61133 L .63083 .60823 L F
.62968 .61164 m .63083 .60823 L .62964 .60975 L F
.62994 .61123 m .63083 .60823 L .62968 .61164 L F
.675 .503 .645 r
.63083 .60823 m .63104 .61133 L .63038 .60827 L F
.507 .241 .446 r
.63129 .60906 m .63038 .60827 L .63074 .60994 L F
.63129 .60906 m .63074 .60994 L .63104 .61133 L F
.301 .219 .595 r
.62969 .61205 m .62994 .61123 L .62968 .61164 L F
.705 .207 .054 r
.49669 .77638 m .4988 .77746 L .49991 .77729 L F
.403 0 0 r
.4988 .77746 m .502 .77726 L .49991 .77729 L F
.776 .633 .702 r
.64819 .61796 m .64455 .61971 L .64701 .61718 L F
.64819 .61796 m .64755 .62018 L .64455 .61971 L F
.266 0 .122 r
.42059 .74606 m .41977 .74468 L .42181 .74423 L F
.42059 .74606 m .41873 .74658 L .41977 .74468 L F
.413 .066 .265 r
.40184 .73318 m .40492 .73059 L .40274 .73076 L F
.453 .094 .265 r
.69391 .7119 m .69578 .71186 L .69554 .71036 L F
.491 .119 .26 r
.69554 .71036 m .69578 .71186 L .69807 .71128 L F
.714 .209 0 r
.7082 .73242 m .70822 .73198 L .70691 .73098 L F
.7082 .73242 m .70935 .73337 L .70822 .73198 L F
.742 .596 .693 r
.57066 .70157 m .56864 .70444 L .5672 .70121 L F
.731 .579 .685 r
.57083 .70401 m .56864 .70444 L .57066 .70157 L F
.902 .944 .585 r
.60588 .65399 m .60739 .65227 L .60639 .6517 L F
.60588 .65399 m .60572 .65576 L .60725 .65255 L F
.862 .983 .849 r
.60588 .65399 m .60375 .65628 L .60572 .65576 L F
0 0 0 r
.60771 .65328 m .60485 .65507 L .60588 .65399 L F
.18 0 0 r
.60588 .65399 m .60327 .65561 L .60375 .65628 L F
0 0 0 r
.60485 .65507 m .60411 .65552 L .60588 .65399 L F
.902 .944 .585 r
.60588 .65399 m .60725 .65255 L .60739 .65227 L F
.235 0 0 r
.31385 .73841 m .31328 .73865 L .31128 .73849 L F
.428 .867 .788 r
.31461 .73806 m .31328 .73865 L .31385 .73841 L F
.562 .29 .462 r
.61076 .63116 m .6137 .63011 L .61366 .62843 L F
.531 .273 .47 r
.6137 .63011 m .61594 .6281 L .61366 .62843 L F
.626 .518 .711 r
.34657 .80743 m .34839 .80685 L .34803 .80429 L F
.51 .561 .844 r
.36269 .67683 m .36316 .67344 L .36133 .6736 L F
.36269 .67683 m .36495 .67662 L .36316 .67344 L F
.311 .38 .772 r
.36269 .67683 m .36455 .67872 L .36495 .67662 L F
.865 .986 .711 r
.62327 .63812 m .62457 .6373 L .62505 .63528 L F
.686 .681 .84 r
.35588 .67212 m .35945 .67396 L .35793 .6711 L F
.528 .571 .842 r
.35945 .67396 m .35994 .67069 L .35793 .6711 L F
.35945 .67396 m .36133 .6736 L .35994 .67069 L F
.612 .432 .613 r
.58035 .71258 m .57791 .71354 L .57831 .71234 L F
.58035 .71258 m .57754 .71441 L .57546 .71451 L F
.514 .324 .561 r
.58105 .70981 m .57754 .71441 L .58035 .71258 L F
.58105 .70981 m .58025 .71403 L .57764 .7144 L F
.5777 .71421 m .57764 .7144 L .57754 .71441 L F
.58105 .70981 m .57764 .7144 L .5777 .71421 L F
.612 .432 .613 r
.57831 .71234 m .57546 .71451 L .57504 .71196 L F
.57791 .71354 m .57546 .71451 L .57831 .71234 L F
.785 .581 .624 r
.5705 .68804 m .5672 .68776 L .56738 .68525 L F
.783 .653 .719 r
.5705 .68804 m .56854 .69086 L .5672 .68776 L F
.486 .896 .789 r
.72005 .62623 m .72138 .62524 L .71897 .62536 L F
.72148 .62545 m .72213 .6251 L .72138 .62524 L F
.201 .725 .719 r
.72138 .62524 m .72422 .62453 L .72365 .62658 L F
0 .29 .746 r
.72138 .62524 m .7227 .62566 L .72126 .62497 L F
.72138 .62524 m .72126 .62497 L .71999 .62437 L F
.486 .896 .789 r
.72005 .62623 m .72148 .62545 L .72138 .62524 L F
.692 .922 .97 r
.72099 .61969 m .7189 .62094 L .71846 .62008 L F
.701 .237 .148 r
.62938 .63683 m .6284 .63814 L .62872 .63586 L F
.62938 .63683 m .6317 .63861 L .6284 .63814 L F
.573 .788 .981 r
.71546 .59513 m .71629 .59623 L .71301 .59569 L F
0 0 .513 r
.71776 .59778 m .71629 .59623 L .71546 .59513 L F
.71776 .59778 m .71828 .59855 L .71629 .59623 L F
.129 .592 .922 r
.28512 .60463 m .28325 .60371 L .28375 .60369 L F
.428 .781 .997 r
.28585 .60369 m .28512 .60463 L .28375 .60369 L F
.28585 .60369 m .28703 .60437 L .28512 .60463 L F
.446 .178 .413 r
.35428 .71504 m .35372 .717 L .35178 .71744 L F
.458 .234 .485 r
.35599 .71442 m .35372 .717 L .35428 .71504 L F
.015 0 0 r
.42781 .78688 m .43142 .78531 L .42991 .78655 L F
.27 0 0 r
.43142 .78531 m .43205 .78626 L .42991 .78655 L F
.43142 .78531 m .43356 .78509 L .43205 .78626 L F
.707 .808 .928 r
.31474 .71615 m .31189 .71671 L .31408 .71504 L F
.714 .806 .922 r
.31765 .71527 m .31474 .71615 L .31408 .71504 L F
.907 .842 .769 r
.69195 .71441 m .68875 .71601 L .69012 .71428 L F
.69195 .71441 m .68982 .71697 L .68875 .71601 L F
.36 0 0 r
.69012 .71428 m .69349 .71499 L .69195 .71441 L F
.538 .419 .665 r
.37978 .74216 m .38212 .74415 L .38203 .74176 L F
.37978 .74216 m .38011 .74458 L .38212 .74415 L F
.243 .599 .951 r
.35513 .65089 m .35491 .65193 L .35285 .65126 L F
.35513 .65089 m .35644 .65209 L .35491 .65193 L F
.736 .771 .881 r
.69806 .63081 m .69611 .63282 L .69476 .63056 L F
.524 .649 .914 r
.69254 .63142 m .69015 .63152 L .68886 .62996 L F
.19 0 .014 r
.36199 .80634 m .36516 .80373 L .36409 .80397 L F
0 0 .092 r
.36516 .80373 m .36599 .8032 L .36739 .80373 L F
.36516 .80373 m .36611 .80072 L .36599 .8032 L F
.287 .738 .958 r
.36516 .80373 m .36599 .8032 L .36409 .80397 L F
.36516 .80373 m .36739 .80373 L .36599 .8032 L F
.522 .341 .577 r
.37367 .75263 m .37572 .75228 L .37581 .74996 L F
.559 .42 .648 r
.37384 .75504 m .37572 .75228 L .37367 .75263 L F
.512 .05 .092 r
.46203 .77883 m .46328 .77743 L .46538 .77815 L F
.889 .889 .824 r
.69613 .58609 m .69715 .587 L .69859 .58419 L F
.909 .587 .424 r
.70736 .7037 m .70793 .70603 L .70885 .70423 L F
.643 .251 .286 r
.70793 .70603 m .71134 .70592 L .70885 .70423 L F
.593 .759 .958 r
.7128 .73822 m .71375 .73946 L .71527 .73774 L F
.531 .658 .917 r
.71375 .73946 m .71616 .73934 L .71527 .73774 L F
.579 .118 .124 r
.46996 .76941 m .46842 .77075 L .47187 .77067 L F
.574 .327 .505 r
.61658 .64247 m .61654 .64436 L .61411 .64465 L F
.445 .182 .42 r
.6189 .6419 m .61654 .64436 L .61658 .64247 L F
.861 .777 .767 r
.59983 .66018 m .6032 .65824 L .6022 .65764 L F
.59983 .66018 m .60114 .66091 L .6032 .65824 L F
.755 .936 .945 r
.60375 .65628 m .6032 .65824 L .60572 .65576 L F
.60375 .65628 m .6022 .65764 L .6032 .65824 L F
.5 0 0 r
.72971 .71316 m .72864 .71212 L .72683 .71162 L F
.003 .48 .867 r
.72862 .71229 m .7288 .71235 L .72971 .71316 L F
.5 0 0 r
.72971 .71316 m .73062 .71397 L .72864 .71212 L F
.003 .48 .867 r
.7288 .71235 m .73044 .71292 L .72971 .71316 L F
.5 0 0 r
.72971 .71316 m .73063 .71398 L .73062 .71397 L F
.515 .362 .612 r
.52934 .73533 m .52697 .73368 L .52903 .73335 L F
.52829 .73459 m .52722 .73634 L .52697 .73368 L F
.656 .763 .929 r
.52546 .73506 m .529 .73336 L .52723 .73263 L F
.529 .73336 m .52903 .73335 L .52901 .73334 L F
.529 .73336 m .52901 .73334 L .52723 .73263 L F
.515 .362 .612 r
.52934 .73533 m .52729 .73631 L .52829 .73459 L F
.52729 .73631 m .52722 .73634 L .52829 .73459 L F
.276 .772 .89 r
.42914 .77727 m .43178 .77689 L .43243 .77707 L F
.505 .886 .699 r
.43243 .77707 m .43336 .77621 L .4339 .77599 L F
.49 .897 .922 r
.43243 .77707 m .43178 .77689 L .43336 .77621 L F
.447 .078 .244 r
.41719 .7473 m .41407 .74928 L .41451 .74753 L F
.55 .345 .555 r
.57877 .70155 m .57887 .70376 L .57663 .70398 L F
.719 .475 .556 r
.58164 .70378 m .57877 .70155 L .58168 .70178 L F
.58164 .70378 m .57887 .70376 L .57877 .70155 L F
.424 .833 .974 r
.36404 .65276 m .36328 .65352 L .36179 .65265 L F
.36404 .65276 m .36541 .6531 L .36328 .65352 L F
0 0 0 r
.63263 .60575 m .6361 .60409 L .63404 .60494 L F
.636 .733 .918 r
.31189 .71671 m .30809 .71492 L .31073 .71452 L F
.686 .743 .894 r
.31408 .71504 m .31189 .71671 L .31073 .71452 L F
.846 .854 .848 r
.62955 .62988 m .6308 .62997 L .63168 .62825 L F
.121 0 .25 r
.36451 .70816 m .36364 .70689 L .36557 .70619 L F
.36451 .70816 m .36312 .70915 L .36364 .70689 L F
.556 .402 .628 r
.37039 .76352 m .3725 .76317 L .37238 .76072 L F
.55 .384 .609 r
.37039 .76352 m .37247 .76548 L .3725 .76317 L F
.37039 .76352 m .37042 .76585 L .37247 .76548 L F
.527 .891 .974 r
.39563 .7341 m .3957 .73356 L .39763 .73388 L F
.407 0 0 r
.39754 .73388 m .39763 .73388 L .3957 .73356 L F
.076 0 0 r
.39563 .7341 m .39314 .73577 L .39504 .73519 L F
.39563 .7341 m .39504 .73519 L .3957 .73356 L F
.504 .138 .279 r
.3957 .73356 m .39504 .73519 L .39822 .73434 L F
.407 0 0 r
.39754 .73388 m .39852 .7345 L .39763 .73388 L F
.39758 .7339 m .39852 .7345 L .39754 .73388 L F
.233 0 0 r
.39763 .73388 m .39852 .7345 L .39981 .73361 L F
.407 0 0 r
.39754 .73388 m .39758 .7339 L .39754 .73388 L F
.272 0 0 r
.39852 .7345 m .40184 .73318 L .39981 .73361 L F
.39852 .7345 m .40059 .73426 L .40184 .73318 L F
.444 0 0 r
.39754 .73388 m .40059 .73426 L .39852 .7345 L F
.504 .138 .279 r
.39781 .73406 m .39822 .73434 L .39857 .73424 L F
.3957 .73356 m .39822 .73434 L .39781 .73406 L F
.761 .656 .746 r
.56169 .70135 m .55866 .69881 L .56049 .69811 L F
.56169 .70135 m .55826 .70115 L .55866 .69881 L F
.781 .572 .617 r
.56169 .70135 m .55832 .70339 L .55826 .70115 L F
.56169 .70135 m .56015 .70383 L .55832 .70339 L F
.796 .592 .626 r
.56177 .70363 m .56015 .70383 L .56169 .70135 L F
.748 .664 .769 r
.56392 .69843 m .56169 .70135 L .56049 .69811 L F
.674 .557 .714 r
.56392 .69843 m .56538 .70171 L .56169 .70135 L F
.7 .545 .673 r
.56538 .70171 m .56177 .70363 L .56169 .70135 L F
.743 .71 .821 r
.50816 .73908 m .51137 .73929 L .51069 .73689 L F
.677 .588 .749 r
.50816 .73908 m .51147 .74171 L .51137 .73929 L F
.639 .648 .843 r
.51069 .73689 m .51137 .73929 L .51364 .739 L F
.621 .454 .634 r
.51137 .73929 m .51147 .74171 L .51364 .739 L F
.809 .946 .913 r
.55948 .68752 m .5609 .68523 L .56173 .68795 L F
.729 .506 .588 r
.56173 .68795 m .5614 .69026 L .55948 .68752 L F
.757 .768 .862 r
.56422 .68528 m .56173 .68795 L .5609 .68523 L F
.63 .552 .748 r
.56374 .68719 m .56173 .68795 L .56422 .68528 L F
.767 .542 .592 r
.56482 .6902 m .56173 .68795 L .56374 .68719 L F
.56482 .6902 m .5614 .69026 L .56173 .68795 L F
.555 .484 .73 r
.36935 .77159 m .37058 .76817 L .36879 .76943 L F
.36935 .77159 m .37136 .77123 L .37058 .76817 L F
.513 .386 .645 r
.36935 .77159 m .37152 .77365 L .37136 .77123 L F
.36935 .77159 m .36963 .77414 L .37152 .77365 L F
.704 .375 .418 r
.42758 .74226 m .42793 .74463 L .42399 .74381 L F
.679 .358 .423 r
.4293 .74419 m .42793 .74463 L .42758 .74226 L F
.644 .36 .473 r
.42955 .74221 m .4293 .74419 L .42758 .74226 L F
.514 .294 .518 r
.36803 .70143 m .36764 .70377 L .36575 .70415 L F
.401 .167 .441 r
.37005 .70088 m .36764 .70377 L .36803 .70143 L F
.145 .459 .887 r
.72143 .59885 m .7196 .59891 L .71828 .59855 L F
.72143 .59885 m .72253 .60041 L .7196 .59891 L F
.653 .437 .578 r
.60168 .69103 m .6017 .693 L .59926 .69316 L F
.628 .417 .577 r
.60541 .69262 m .60168 .69103 L .60492 .69016 L F
.60541 .69262 m .6017 .693 L .60168 .69103 L F
.494 .594 .883 r
.62772 .63563 m .6272 .63358 L .62603 .6343 L F
.281 0 .206 r
.31586 .65635 m .31541 .65746 L .31722 .65677 L F
.306 0 0 r
.43935 .78328 m .43782 .78454 L .43569 .78471 L F
.234 0 0 r
.44093 .78354 m .43782 .78454 L .43935 .78328 L F
.609 .428 .611 r
.58613 .69828 m .58415 .69633 L .58606 .69594 L F
.58613 .69828 m .5839 .69861 L .58415 .69633 L F
.884 .873 .821 r
.71145 .73624 m .70991 .7357 L .71157 .73342 L F
0 0 .491 r
.71145 .73624 m .71225 .73711 L .70991 .7357 L F
.71145 .73624 m .7128 .73822 L .71225 .73711 L F
.183 0 0 r
.32449 .73369 m .3228 .7349 L .32083 .73527 L F
.081 0 0 r
.32473 .73437 m .32449 .73369 L .32642 .73302 L F
.32473 .73437 m .3228 .7349 L .32449 .73369 L F
.279 0 .091 r
.30262 .66564 m .30573 .6633 L .30358 .66351 L F
.46 .31 .59 r
.39716 .76052 m .39737 .76394 L .39555 .76358 L F
.441 .371 .683 r
.39737 .76394 m .39776 .76548 L .39555 .76358 L F
.487 .372 .648 r
.39555 .76358 m .39776 .76548 L .39589 .76564 L F
.824 .694 .72 r
.63498 .63891 m .63605 .64199 L .63298 .64207 L F
.796 .61 .65 r
.56614 .70948 m .56454 .71158 L .56299 .70909 L F
.779 .585 .637 r
.56614 .70948 m .56786 .71191 L .56454 .71158 L F
.587 .947 .866 r
.3428 .67463 m .343 .67529 L .34457 .67416 L F
.3428 .67463 m .34085 .67586 L .343 .67529 L F
.497 .722 .972 r
.5155 .71104 m .51661 .71224 L .51777 .7109 L F
.5155 .71104 m .51661 .71224 L .51777 .7109 L F
.16 0 0 r
.65441 .58753 m .65651 .58687 L .65742 .58559 L F
.657 .189 .13 r
.65651 .58687 m .65981 .58721 L .65742 .58559 L F
.841 .805 .815 r
.71192 .61619 m .70889 .61714 L .71093 .6151 L F
.029 .496 .88 r
.71346 .61621 m .71192 .61619 L .71093 .6151 L F
0 0 0 r
.71423 .61608 m .71346 .61621 L .71489 .61562 L F
.029 .496 .88 r
.71346 .61621 m .71461 .61713 L .71247 .61638 L F
.834 .882 .878 r
.7121 .61934 m .71346 .61621 L .71116 .61815 L F
.7121 .61934 m .71461 .61713 L .71346 .61621 L F
0 0 0 r
.71248 .61729 m .71346 .61621 L .71423 .61608 L F
.029 .496 .88 r
.71346 .61621 m .71247 .61638 L .71192 .61619 L F
.567 .444 .671 r
.37209 .75844 m .3741 .75814 L .37384 .75504 L F
.594 .466 .676 r
.37209 .75844 m .37461 .7604 L .3741 .75814 L F
.37209 .75844 m .37238 .76072 L .37461 .7604 L F
.748 .526 .594 r
.68237 .6229 m .68113 .62065 L .68176 .62105 L F
.274 0 .25 r
.5293 .78462 m .53183 .78231 L .53103 .78485 L F
.265 0 .075 r
.52812 .78652 m .5293 .78462 L .53103 .78485 L F
.779 .563 .607 r
.56482 .6902 m .56154 .69243 L .5614 .69026 L F
.56482 .6902 m .56474 .69288 L .56154 .69243 L F
.674 .605 .77 r
.5672 .68776 m .56482 .6902 L .56374 .68719 L F
.673 .603 .768 r
.5672 .68776 m .56854 .69086 L .56482 .6902 L F
.717 .533 .64 r
.56854 .69086 m .56474 .69288 L .56482 .6902 L F
.925 .747 .641 r
.73027 .73011 m .73214 .72872 L .73098 .72806 L F
.73027 .73011 m .7317 .73109 L .73214 .72872 L F
.424 .485 .819 r
.37216 .79796 m .37387 .80085 L .37518 .80079 L F
.693 .558 .698 r
.57412 .70436 m .57212 .70725 L .57083 .70401 L F
.5 .086 .185 r
.42041 .72762 m .42263 .72763 L .42395 .72582 L F
.444 .034 .166 r
.42263 .72763 m .42615 .72559 L .42395 .72582 L F
.72 .537 .642 r
.36051 .78486 m .36367 .78517 L .36256 .7824 L F
.685 .552 .698 r
.36256 .7824 m .36588 .7824 L .36513 .77947 L F
.691 .523 .655 r
.36256 .7824 m .36619 .78487 L .36588 .7824 L F
.36256 .7824 m .36367 .78517 L .36619 .78487 L F
.8 .809 .859 r
.50448 .74021 m .50599 .7414 L .50816 .73908 L F
.675 .587 .749 r
.50599 .7414 m .50925 .74234 L .50816 .73908 L F
.415 .138 .382 r
.29616 .66898 m .29806 .66854 L .29864 .66665 L F
.396 .121 .374 r
.29864 .66665 m .29994 .66796 L .30053 .66619 L F
.29864 .66665 m .29806 .66854 L .29994 .66796 L F
.628 .813 .971 r
.52014 .73078 m .51786 .7315 L .51677 .73045 L F
.557 .275 .443 r
.60819 .63313 m .61076 .63116 L .60865 .63145 L F
.306 0 .264 r
.53103 .78485 m .53183 .78231 L .53385 .78136 L F
0 .454 .759 r
.4516 .72484 m .45359 .72538 L .45488 .72587 L F
.215 .716 .908 r
.45359 .72538 m .45699 .72567 L .45488 .72587 L F
.647 .87 .501 r
.63167 .60723 m .63083 .60823 L .63263 .60575 L F
.799 .602 .635 r
.64601 .61438 m .64893 .61339 L .64701 .61718 L F
.798 .998 .848 r
.72122 .58913 m .7206 .59078 L .72008 .59046 L F
.72122 .58913 m .7206 .59078 L .72008 .59046 L F
.549 .508 .763 r
.72506 .60228 m .72296 .60157 L .72253 .60041 L F
.72506 .60228 m .72263 .60339 L .72296 .60157 L F
.809 .946 .913 r
.55948 .68752 m .55839 .68738 L .5609 .68523 L F
.803 .512 .496 r
.55948 .68752 m .55817 .68974 L .55839 .68738 L F
.55948 .68752 m .5614 .69026 L .55817 .68974 L F
.506 .413 .684 r
.57933 .70605 m .57663 .70398 L .57887 .70376 L F
.57933 .70605 m .5772 .70766 L .57663 .70398 L F
.698 .299 .288 r
.70935 .73337 m .70598 .73335 L .70941 .73381 L F
.355 0 .187 r
.53277 .77353 m .53521 .77268 L .53547 .77196 L F
.575 .426 .641 r
.53521 .77268 m .53695 .77126 L .53547 .77196 L F
.359 .542 .898 r
.72731 .61246 m .73044 .61359 L .72953 .6151 L F
.12 .225 .699 r
.73044 .61359 m .73123 .61682 L .72953 .6151 L F
.763 .461 .474 r
.56786 .71191 m .56627 .71404 L .56454 .71158 L F
.822 .545 .519 r
.56786 .71191 m .56941 .71468 L .56627 .71404 L F
.67 .142 0 r
.50108 .78226 m .49958 .78225 L .49828 .78135 L F
.523 0 0 r
.50108 .78226 m .50234 .78348 L .49958 .78225 L F
.50108 .78226 m .50403 .78418 L .50234 .78348 L F
.509 .575 .857 r
.70789 .62528 m .70568 .62524 L .70456 .62268 L F
.676 .977 .876 r
.67016 .58911 m .6712 .58781 L .67199 .58768 L F
.67016 .58911 m .66788 .58981 L .6712 .58781 L F
.828 .835 .853 r
.70848 .63424 m .70908 .63124 L .70683 .63343 L F
.869 .706 .679 r
.70683 .63343 m .70806 .63664 L .70848 .63424 L F
.572 .422 .639 r
.70234 .70121 m .70456 .7034 L .7058 .70126 L F
.754 .467 .498 r
.70456 .7034 m .70736 .7037 L .7058 .70126 L F
.811 .861 .886 r
.71076 .62459 m .70789 .62528 L .71002 .62263 L F
.659 .798 .949 r
.71241 .62238 m .71076 .62459 L .71002 .62263 L F
.71241 .62238 m .71371 .62367 L .71076 .62459 L F
.328 0 0 r
.46097 .76895 m .46318 .76906 L .46424 .7686 L F
.032 0 0 r
.46318 .76906 m .46644 .76861 L .46424 .7686 L F
.421 0 0 r
.46886 .77708 m .46968 .7782 L .4675 .77803 L F
.46886 .77708 m .471 .77727 L .46968 .7782 L F
.512 .857 .994 r
.37856 .80376 m .37485 .80373 L .37633 .80397 L F
.363 .715 .987 r
.54103 .77081 m .54092 .77164 L .54013 .77057 L F
0 0 0 r
.54103 .77081 m .5407 .77392 L .54092 .77164 L F
.42298 .77633 m .42445 .77543 L .4241 .77525 L F
.793 .932 .924 r
.70564 .57475 m .70292 .57667 L .70454 .57666 L F
.909 .784 .711 r
.70292 .57667 m .70374 .57972 L .70454 .57666 L F
.714 .806 .922 r
.31765 .71527 m .31408 .71504 L .31614 .71441 L F
.065 0 0 r
.31614 .71441 m .3197 .71458 L .31765 .71527 L F
.553 .185 .296 r
.47538 .76914 m .47743 .77033 L .47836 .76843 L F
.579 .233 .346 r
.47743 .77033 m .48066 .76849 L .47836 .76843 L F
.713 .621 .754 r
.56617 .69583 m .56774 .699 L .56392 .69843 L F
.717 .576 .695 r
.5672 .70121 m .56392 .69843 L .56774 .699 L F
.494 0 0 r
.46277 .73608 m .46166 .73651 L .45938 .73592 L F
.763 .695 .786 r
.72796 .6091 m .72423 .60921 L .72633 .60667 L F
.519 .323 .555 r
.72796 .6091 m .72529 .6129 L .72423 .60921 L F
.72796 .6091 m .72731 .61246 L .72529 .6129 L F
0 .205 .732 r
.72633 .60667 m .72817 .60839 L .72796 .6091 L F
0 0 .271 r
.72872 .6108 m .72796 .6091 L .72817 .60839 L F
.72872 .6108 m .72731 .61246 L .72796 .6091 L F
.38 0 .123 r
.35372 .717 m .35039 .7191 L .35178 .71744 L F
.647 .493 .66 r
.59725 .69526 m .59371 .69318 L .59718 .69322 L F
.59725 .69526 m .59392 .69569 L .59371 .69318 L F
.95 .607 .325 r
.69952 .61654 m .70103 .61804 L .70067 .61919 L F
.622 .741 .932 r
.70335 .61721 m .70103 .61804 L .69952 .61654 L F
.673 .254 .242 r
.70103 .61804 m .70314 .61956 L .70067 .61919 L F
.522 .364 .608 r
.70335 .61721 m .70314 .61956 L .70103 .61804 L F
.674 .672 .84 r
.51165 .74361 m .51278 .74542 L .515 .74447 L F
.598 .671 .891 r
.52316 .74046 m .52482 .73946 L .52262 .7402 L F
.52316 .74046 m .52647 .74143 L .52482 .73946 L F
.784 .677 .745 r
.56738 .68525 m .56422 .68528 L .56608 .68244 L F
.698 .504 .622 r
.56738 .68525 m .56374 .68719 L .56422 .68528 L F
.56738 .68525 m .5672 .68776 L .56374 .68719 L F
.747 .661 .766 r
.56953 .68279 m .56738 .68525 L .56608 .68244 L F
.783 .819 .881 r
.65754 .61536 m .6613 .61424 L .65989 .61576 L F
.176 0 0 r
.66195 .61501 m .65989 .61576 L .6613 .61424 L F
.566 .071 .039 r
.43881 .74113 m .43709 .74178 L .43515 .74126 L F
.543 .061 .061 r
.44053 .74159 m .43709 .74178 L .43881 .74113 L F
.704 .777 .909 r
.51898 .72321 m .51553 .7228 L .51792 .7222 L F
.655 .777 .938 r
.5212 .7225 m .51898 .72321 L .51792 .7222 L F
.567 .541 .785 r
.52204 .72584 m .51898 .72321 L .5212 .7225 L F
.776 .782 .857 r
.64928 .65223 m .64909 .64975 L .64818 .65156 L F
.64928 .65223 m .65182 .64999 L .64909 .64975 L F
.479 .244 .479 r
.35986 .69023 m .36163 .69 L .36217 .68771 L F
.571 .525 .765 r
.36217 .68771 m .36345 .68477 L .36141 .68523 L F
.36217 .68771 m .36408 .68736 L .36345 .68477 L F
.559 .318 .508 r
.36217 .68771 m .36385 .68963 L .36408 .68736 L F
.36217 .68771 m .36163 .69 L .36385 .68963 L F
.664 .437 .566 r
.38675 .73586 m .38901 .73849 L .38956 .73645 L F
0 0 0 r
.38956 .73645 m .39083 .73592 L .39159 .73514 L F
.149 0 .193 r
.38956 .73645 m .39042 .73778 L .39083 .73592 L F
.38956 .73645 m .38901 .73849 L .39042 .73778 L F
.408 .2 .483 r
.29116 .62037 m .29087 .62262 L .28911 .62314 L F
.291 .109 .452 r
.29029 .62462 m .28911 .62314 L .29087 .62262 L F
.29029 .62462 m .28885 .62543 L .28911 .62314 L F
.615 .462 .651 r
.36513 .77947 m .36769 .77975 L .36741 .77681 L F
.563 .476 .714 r
.36513 .77947 m .36789 .782 L .36769 .77975 L F
.36513 .77947 m .36588 .7824 L .36789 .782 L F
.708 .87 .958 r
.67704 .5869 m .67864 .58443 L .67637 .58462 L F
.67704 .5869 m .68003 .5855 L .67864 .58443 L F
.518 .338 .576 r
.37581 .74996 m .37772 .75185 L .37765 .7495 L F
.37581 .74996 m .37572 .75228 L .37772 .75185 L F
.754 .373 0 r
.67215 .62749 m .67256 .62837 L .67115 .62565 L F
.325 0 .102 r
.31021 .66047 m .31218 .66004 L .31352 .65818 L F
.395 .029 .22 r
.31218 .66004 m .31541 .65746 L .31352 .65818 L F
.577 .849 .506 r
.73226 .61778 m .73103 .6191 L .72991 .6205 L F
0 0 0 r
.72991 .6205 m .73103 .6191 L .7296 .62225 L F
.284 .449 .849 r
.41031 .77738 m .41081 .779 L .40735 .77657 L F
.025 .231 .735 r
.40729 .77624 m .40718 .77649 L .40714 .77544 L F
.40718 .77649 m .40697 .77695 L .40668 .77627 L F
.40714 .77544 m .40718 .77649 L .40565 .77391 L F
.194 .467 .886 r
.40689 .77625 m .40724 .77652 L .40732 .7764 L F
0 .294 .771 r
.40735 .77657 m .40724 .77652 L .40689 .77625 L F
.025 .231 .735 r
.40718 .77649 m .40668 .77627 L .40565 .77391 L F
0 .294 .771 r
.40724 .77652 m .40718 .77649 L .40689 .77625 L F
.6 .584 .807 r
.40718 .77649 m .40697 .77695 L .40689 .77625 L F
.194 .467 .886 r
.40689 .77625 m .40697 .77695 L .40724 .77652 L F
.284 .449 .849 r
.40732 .77639 m .40732 .7764 L .40689 .77625 L F
.6 .584 .807 r
.41041 .77925 m .40697 .77695 L .40718 .77649 L F
.025 .231 .735 r
.40761 .77593 m .40697 .77695 L .40703 .77682 L F
.40761 .77593 m .40703 .77682 L .40749 .7758 L F
.284 .449 .849 r
.41031 .77738 m .40732 .77639 L .40761 .77593 L F
.40732 .77639 m .40689 .77625 L .40761 .77593 L F
.194 .467 .886 r
.40689 .77625 m .40732 .7764 L .40761 .77593 L F
.284 .449 .849 r
.40732 .7764 m .40735 .77657 L .40689 .77625 L F
.41031 .77738 m .40735 .77657 L .40732 .77639 L F
.025 .231 .735 r
.40749 .7758 m .40729 .77624 L .40714 .77544 L F
0 .294 .771 r
.41081 .779 m .41041 .77925 L .40718 .77649 L F
.41081 .779 m .40718 .77649 L .40735 .77657 L F
.595 .324 .476 r
.61247 .68787 m .61468 .68962 L .61253 .6896 L F
.634 .303 .394 r
.61505 .68812 m .61468 .68962 L .61247 .68787 L F
.968 .905 .547 r
.68936 .59024 m .68872 .59213 L .68982 .59089 L F
.68936 .59024 m .68872 .59213 L .68982 .59089 L F
.733 .914 .956 r
.48271 .7238 m .48339 .72199 L .48468 .72288 L F
.48271 .7238 m .48148 .72309 L .48339 .72199 L F
.58 .449 .666 r
.68461 .62247 m .68176 .62105 L .68359 .61923 L F
.68461 .62247 m .68237 .6229 L .68176 .62105 L F
0 0 0 r
.52708 .7407 m .52765 .73938 L .52647 .74143 L F
.848 .844 .839 r
.52647 .74143 m .52683 .73846 L .52482 .73946 L F
.52647 .74143 m .52765 .73938 L .52683 .73846 L F
.36 .487 .852 r
.52647 .74143 m .52854 .74231 L .52708 .7407 L F
.513 .48 .757 r
.39776 .76548 m .39673 .76904 L .39589 .76564 L F
.39776 .76548 m .39877 .76882 L .39673 .76904 L F
.491 .164 .339 r
.433 .74134 m .4293 .74419 L .42955 .74221 L F
.089 0 0 r
.40594 .79297 m .4048 .79285 L .40691 .79246 L F
.40594 .79297 m .40398 .79344 L .4048 .79285 L F
.638 .604 .799 r
.51025 .72245 m .50679 .71995 L .50902 .71921 L F
.628 .577 .778 r
.51219 .72024 m .51025 .72245 L .50902 .71921 L F
.615 .645 .857 r
.51196 .72214 m .51025 .72245 L .51219 .72024 L F
.414 .494 .833 r
.69814 .61776 m .6989 .62041 L .69828 .61884 L F
.963 .658 .247 r
.69828 .61884 m .6989 .62041 L .69833 .62132 L F
.95 .607 .325 r
.69952 .61654 m .6989 .62041 L .69814 .61776 L F
.69952 .61654 m .70067 .61919 L .6989 .62041 L F
.799 .624 .665 r
.70067 .61919 m .69833 .62132 L .6989 .62041 L F
0 .213 .676 r
.67593 .59667 m .67452 .59588 L .6743 .59552 L F
.67593 .59667 m .67676 .59746 L .67452 .59588 L F
.839 .408 .21 r
.71984 .73926 m .72197 .74226 L .72288 .74189 L F
.959 .933 .721 r
.72202 .74226 m .72288 .74189 L .72197 .74226 L F
.839 .408 .21 r
.72197 .74226 m .7221 .74244 L .72288 .74189 L F
.959 .933 .721 r
.72197 .74226 m .72288 .74189 L .72193 .74227 L F
.72193 .74227 m .72288 .74189 L .72427 .74106 L F
.72161 .74243 m .72202 .74226 L .72193 .74227 L F
.728 .851 .939 r
.72093 .74125 m .72161 .74243 L .72193 .74227 L F
.707 .231 0 r
.72093 .74125 m .72191 .74224 L .71984 .73926 L F
.72193 .74227 m .72197 .74226 L .71984 .73926 L F
.728 .851 .939 r
.72093 .74125 m .72193 .74227 L .72427 .74106 L F
.707 .231 0 r
.72093 .74125 m .72193 .74227 L .72191 .74224 L F
.72193 .74227 m .7221 .74244 L .72197 .74226 L F
.388 .143 .416 r
.36764 .70377 m .36557 .70619 L .36575 .70415 L F
.972 .903 .689 r
.65072 .62734 m .65033 .63099 L .65121 .62908 L F
.537 .11 .178 r
.47187 .77067 m .47411 .77089 L .47538 .76914 L F
.57 .147 .199 r
.47538 .76914 m .47411 .77089 L .47743 .77033 L F
.845 .933 .555 r
.62505 .63528 m .62603 .6343 L .62546 .63318 L F
.401 0 .153 r
.52937 .77584 m .53155 .7756 L .53277 .77353 L F
.43 .055 .224 r
.53155 .7756 m .53521 .77268 L .53277 .77353 L F
.823 .62 .628 r
.35248 .79556 m .35299 .79673 L .35477 .7964 L F
.758 .588 .666 r
.35299 .79673 m .35569 .79846 L .35477 .7964 L F
.518 .472 .745 r
.35477 .7964 m .35583 .79623 L .35693 .79522 L F
.35477 .7964 m .35569 .79846 L .35583 .79623 L F
.504 .579 .864 r
.67256 .62837 m .67364 .62541 L .67115 .62565 L F
.67256 .62837 m .67473 .62816 L .67364 .62541 L F
.834 .74 .761 r
.72694 .72297 m .72551 .72668 L .7234 .72511 L F
.961 .729 .541 r
.72551 .72668 m .72356 .72736 L .7234 .72511 L F
.72551 .72668 m .72502 .72811 L .72356 .72736 L F
.59 .656 .883 r
.72813 .74196 m .72757 .74064 L .72789 .7405 L F
.196 .69 .919 r
.45907 .72519 m .46256 .72572 L .46039 .72581 L F
.422 .156 .402 r
.29584 .67017 m .29806 .66854 L .29616 .66898 L F
.574 .276 .425 r
.60517 .63547 m .60819 .63313 L .60631 .63406 L F
.648 .666 .853 r
.49271 .73275 m .49589 .73375 L .49474 .73131 L F
.476 .501 .805 r
.49589 .73375 m .49678 .73052 L .49474 .73131 L F
.49589 .73375 m .49818 .73368 L .49678 .73052 L F
.478 .489 .791 r
.49589 .73375 m .4981 .73506 L .49818 .73368 L F
.496 .342 .602 r
.3555 .69567 m .35731 .69286 L .3549 .69325 L F
.245 .511 .906 r
.34604 .64903 m .34541 .65021 L .34449 .64873 L F
.303 .585 .941 r
.34604 .64903 m .34748 .65068 L .34541 .65021 L F
.468 .205 .431 r
.62136 .63917 m .62273 .6399 L .6189 .6419 L F
.377 .303 .646 r
.62327 .63812 m .62273 .6399 L .62136 .63917 L F
.993 .778 .51 r
.73123 .61682 m .73103 .6191 L .73226 .61778 L F
.202 0 0 r
.47019 .72429 m .47352 .7243 L .47157 .72447 L F
.553 .577 .833 r
.38412 .66591 m .38332 .66902 L .38233 .66572 L F
.38412 .66591 m .38544 .6689 L .38332 .66902 L F
.232 0 0 r
.32416 .68007 m .32021 .68138 L .32103 .68143 L F
.32416 .68007 m .32215 .6812 L .32021 .68138 L F
.294 0 .032 r
.32597 .6789 m .32215 .6812 L .32416 .68007 L F
.517 .848 .997 r
.32855 .71451 m .32521 .71448 L .32721 .71397 L F
.621 .884 .989 r
.32855 .71451 m .32919 .71313 L .33014 .7135 L F
.32855 .71451 m .32721 .71397 L .32919 .71313 L F
.815 .711 .75 r
.65063 .64456 m .65256 .64199 L .64956 .64137 L F
.638 .944 .955 r
.46895 .73452 m .4682 .73564 L .47055 .73502 L F
.46895 .73452 m .46693 .7355 L .4682 .73564 L F
.638 .221 .235 r
.43847 .7748 m .4421 .77368 L .44003 .77419 L F
.677 .588 .749 r
.50816 .73908 m .50925 .74234 L .51147 .74171 L F
.474 .538 .842 r
.50925 .74234 m .51165 .74361 L .51147 .74171 L F
.547 .93 .878 r
.34874 .67269 m .34762 .6737 L .34991 .67297 L F
.34874 .67269 m .34668 .67378 L .34762 .6737 L F
.56 .604 .854 r
.29584 .60937 m .29498 .61239 L .29373 .60986 L F
.29584 .60937 m .29653 .61171 L .29498 .61239 L F
.351 .274 .628 r
.29662 .61383 m .29498 .61239 L .29653 .61171 L F
.29662 .61383 m .29527 .61479 L .29498 .61239 L F
.739 .594 .695 r
.5672 .70121 m .56864 .70444 L .56517 .70402 L F
.791 .716 .781 r
.69728 .6392 m .70034 .63941 L .69897 .6385 L F
.789 .717 .783 r
.69897 .6385 m .70034 .63941 L .70251 .63683 L F
.847 .657 .645 r
.63004 .64922 m .63004 .65269 L .62834 .64943 L F
.601 .427 .618 r
.36274 .79263 m .36495 .79278 L .36485 .79041 L F
.728 .439 .49 r
.36176 .79517 m .36495 .79278 L .36274 .79263 L F
.588 .835 .466 r
.62234 .66273 m .6216 .66371 L .6203 .66534 L F
.806 .675 .719 r
.72423 .60921 m .72529 .6129 L .72252 .61239 L F
.121 0 0 r
.41487 .7905 m .41099 .79149 L .41287 .79105 L F
.717 .533 .64 r
.56854 .69086 m .56837 .69312 L .56474 .69288 L F
0 0 .047 r
.67094 .59853 m .67099 .60074 L .67034 .60056 L F
.997 .787 .499 r
.67099 .60074 m .66992 .6027 L .67034 .60056 L F
.67099 .60074 m .67092 .60384 L .66992 .6027 L F
.666 .535 .696 r
.71757 .60605 m .71564 .60422 L .7177 .60436 L F
.698 .545 .676 r
.72025 .60377 m .71757 .60605 L .7177 .60436 L F
.507 .272 .493 r
.61844 .6258 m .62072 .62533 L .62098 .62326 L F
.197 .015 .393 r
.62098 .62326 m .62221 .62436 L .6229 .62258 L F
.62098 .62326 m .62072 .62533 L .62221 .62436 L F
.721 .518 .615 r
.58971 .69614 m .58613 .69828 L .58606 .69594 L F
.717 .625 .754 r
.34803 .80429 m .35079 .80418 L .34969 .80097 L F
.208 .213 .644 r
.34803 .80429 m .34959 .80564 L .35079 .80418 L F
.686 .608 .763 r
.34969 .80097 m .35079 .80418 L .3535 .80187 L F
.675 .271 .272 r
.34959 .80564 m .35334 .80621 L .35079 .80418 L F
.588 .388 .578 r
.35283 .69846 m .35542 .6985 L .3555 .69567 L F
.496 .342 .602 r
.3555 .69567 m .35723 .69538 L .35731 .69286 L F
.466 .289 .556 r
.3555 .69567 m .35721 .69774 L .35723 .69538 L F
.3555 .69567 m .35542 .6985 L .35721 .69774 L F
.6 .479 .686 r
.31046 .68491 m .31119 .68763 L .30851 .68801 L F
.558 .301 .482 r
.31119 .68763 m .30818 .69 L .30851 .68801 L F
.085 0 .443 r
.70509 .5746 m .70566 .57466 L .70657 .57318 L F
.727 .802 .911 r
.70558 .57456 m .70238 .57368 L .70416 .57287 L F
.70566 .57466 m .70555 .57462 L .70558 .57456 L F
.70555 .57462 m .70238 .57368 L .70558 .57456 L F
.67 .738 .902 r
.70657 .57318 m .70566 .57466 L .70558 .57456 L F
0 0 .259 r
.70604 .57369 m .70558 .57456 L .70509 .5746 L F
.70657 .57318 m .7055 .57471 L .70604 .57369 L F
.67 .738 .902 r
.70657 .57318 m .70558 .57456 L .70416 .57287 L F
0 0 .259 r
.70558 .57456 m .7055 .57471 L .70548 .5747 L F
.70558 .57456 m .70548 .5747 L .70509 .5746 L F
.70657 .57318 m .70564 .57475 L .7055 .57471 L F
.498 .277 .509 r
.2932 .61985 m .29087 .62262 L .29116 .62037 L F
.837 .912 .509 r
.65419 .61853 m .65379 .6202 L .6553 .61711 L F
.23 .384 .811 r
.65707 .61639 m .6553 .61711 L .65448 .61451 L F
0 0 0 r
.65419 .61853 m .6553 .61711 L .65707 .61639 L F
.423 .137 .373 r
.35927 .69239 m .36163 .69 L .35986 .69023 L F
.811 .456 .384 r
.68982 .71697 m .69213 .71799 L .68918 .71905 L F
.966 .836 .665 r
.69213 .71799 m .68906 .72123 L .68918 .71905 L F
.857 .654 .628 r
.6921 .72118 m .68999 .72191 L .69213 .71799 L F
0 0 0 r
.30671 .71753 m .30683 .71738 L .30809 .71492 L F
.618 .955 .81 r
.30652 .7176 m .30683 .71738 L .30671 .71753 L F
.834 .638 .638 r
.56287 .70672 m .56015 .70383 L .56177 .70363 L F
.56287 .70672 m .56 .7063 L .56015 .70383 L F
.805 .617 .647 r
.56299 .70909 m .56 .7063 L .56287 .70672 L F
.693 .587 .732 r
.56517 .70402 m .56287 .70672 L .56177 .70363 L F
.579 .524 .758 r
.36367 .78517 m .36424 .78753 L .3663 .78685 L F
.637 .526 .711 r
.36424 .78753 m .36714 .79019 L .3663 .78685 L F
.36424 .78753 m .36485 .79041 L .36714 .79019 L F
.066 .591 .871 r
.28101 .60302 m .2818 .60351 L .28029 .60307 L F
.28101 .60302 m .28325 .60371 L .2818 .60351 L F
.717 .576 .695 r
.5672 .70121 m .56538 .70171 L .56392 .69843 L F
.711 .555 .674 r
.5672 .70121 m .56517 .70402 L .56538 .70171 L F
.519 .39 .645 r
.36619 .78487 m .36789 .782 L .36588 .7824 L F
.599 .799 .976 r
.71336 .61177 m .71132 .61253 L .7104 .61166 L F
.419 .184 .448 r
.71336 .61177 m .71093 .6151 L .71132 .61253 L F
.961 .93 .717 r
.6703 .61773 m .66983 .61897 L .66872 .61835 L F
.966 .643 .275 r
.66983 .61897 m .6693 .62062 L .66872 .61835 L F
.66983 .61897 m .67031 .62216 L .6693 .62062 L F
0 0 0 r
.33467 .72921 m .3344 .72837 L .33624 .72764 L F
.33467 .72921 m .33292 .73006 L .3344 .72837 L F
.722 .546 .651 r
.59931 .66879 m .60211 .67072 L .60209 .6692 L F
.721 .518 .615 r
.58971 .69614 m .59016 .69862 L .58613 .69828 L F
.687 .495 .623 r
.5915 .6983 m .58971 .69614 L .59159 .69588 L F
.5915 .6983 m .59016 .69862 L .58971 .69614 L F
.61 .681 .892 r
.49352 .72311 m .49015 .7221 L .49213 .72095 L F
.744 .725 .834 r
.49552 .72208 m .49352 .72311 L .49213 .72095 L F
.73 .709 .831 r
.56296 .69576 m .56392 .69843 L .56049 .69811 L F
.782 .736 .81 r
.56617 .69583 m .56392 .69843 L .56296 .69576 L F
.774 .576 .631 r
.35299 .79673 m .35573 .80043 L .35569 .79846 L F
.211 .203 .631 r
.35569 .79846 m .35727 .80055 L .35583 .79623 L F
.356 .245 .587 r
.35573 .80043 m .35727 .80055 L .35569 .79846 L F
.68 .449 .565 r
.60699 .69048 m .60541 .69262 L .60492 .69016 L F
.124 0 0 r
.31128 .73849 m .31328 .73865 L .31021 .73853 L F
.736 .683 .799 r
.59576 .6653 m .59898 .66593 L .59775 .66282 L F
.761 .623 .707 r
.59576 .6653 m .59673 .66877 L .59898 .66593 L F
.685 .512 .646 r
.59673 .66877 m .59931 .66879 L .59898 .66593 L F
.77 .699 .785 r
.59775 .66282 m .59898 .66593 L .60103 .66332 L F
.532 .384 .626 r
.37238 .76072 m .3745 .76275 L .37461 .7604 L F
.37238 .76072 m .3725 .76317 L .3745 .76275 L F
.785 .675 .743 r
.60211 .67072 m .60002 .67373 L .60323 .67385 L F
.787 .657 .719 r
.60002 .67373 m .60127 .6769 L .60323 .67385 L F
.709 .55 .671 r
.60323 .67385 m .60127 .6769 L .60442 .67668 L F
.778 .672 .746 r
.60211 .67072 m .60323 .67385 L .60391 .67199 L F
.498 .684 .95 r
.68561 .63967 m .68908 .64125 L .68823 .63943 L F
.645 .751 .926 r
.68908 .64125 m .69055 .63859 L .68823 .63943 L F
.68908 .64125 m .69144 .64044 L .69055 .63859 L F
.775 .615 .682 r
.51576 .7363 m .51904 .739 L .51803 .73571 L F
.51576 .7363 m .51791 .73966 L .51904 .739 L F
.787 .645 .704 r
.51791 .73966 m .51709 .74173 L .51904 .739 L F
.645 .611 .801 r
.51904 .739 m .5209 .73511 L .51803 .73571 L F
.51904 .739 m .52167 .73841 L .5209 .73511 L F
.625 .631 .836 r
.51904 .739 m .52262 .7402 L .52167 .73841 L F
0 0 .049 r
.66706 .60085 m .66889 .59665 L .66858 .59954 L F
.23 .363 .791 r
.66992 .6027 m .66706 .60085 L .66858 .59954 L F
.495 .267 .497 r
.38011 .74458 m .38182 .74637 L .38212 .74415 L F
.38011 .74458 m .37979 .74676 L .38182 .74637 L F
.87 .428 .122 r
.51106 .79028 m .50979 .78979 L .50795 .78673 L F
.732 .249 .094 r
.51306 .79089 m .50979 .78979 L .51106 .79028 L F
.547 .368 .59 r
.37765 .7495 m .37979 .74676 L .37789 .74723 L F
.879 .908 .844 r
.62909 .64321 m .63037 .64348 L .62917 .64527 L F
.968 .935 .674 r
.62778 .64634 m .62917 .64527 L .62808 .64741 L F
.62778 .64634 m .62909 .64321 L .62917 .64527 L F
.86 .729 .717 r
.56762 .67955 m .5645 .68129 L .56653 .67855 L F
.56762 .67955 m .56608 .68244 L .5645 .68129 L F
.821 .927 .904 r
.56653 .67855 m .57029 .67681 L .56762 .67955 L F
.255 .543 .925 r
.39087 .67063 m .38822 .66984 L .38824 .66978 L F
.39087 .67063 m .39164 .67177 L .38822 .66984 L F
.551 .871 .588 r
.61701 .66827 m .61758 .66757 L .61901 .66642 L F
.151 .063 .493 r
.6175 .66923 m .61815 .66689 L .61758 .66757 L F
.817 .802 .837 r
.61888 .66386 m .62017 .66517 L .61758 .66757 L F
.151 .063 .493 r
.61815 .66689 m .6183 .66638 L .61758 .66757 L F
.551 .871 .588 r
.61651 .66873 m .61758 .66757 L .61701 .66827 L F
.591 .937 .764 r
.61901 .66642 m .62017 .66517 L .6203 .66534 L F
.55 .87 .588 r
.61758 .66757 m .62017 .66517 L .61901 .66642 L F
.385 .087 .33 r
.63995 .59592 m .64206 .59526 L .64257 .59363 L F
.284 0 .287 r
.64257 .59363 m .64206 .59526 L .64441 .59276 L F
0 .462 .839 r
.41081 .779 m .41226 .77995 L .41041 .77925 L F
.438 .07 .241 r
.40662 .75035 m .40564 .75225 L .40357 .75244 L F
0 0 .009 r
.40724 .75124 m .40662 .75035 L .40841 .74998 L F
.40724 .75124 m .40564 .75225 L .40662 .75035 L F
.517 .016 0 r
.66765 .60612 m .66781 .60625 L .66649 .60494 L F
.142 .044 .474 r
.66768 .60684 m .66794 .60636 L .66781 .60625 L F
.054 0 .457 r
.66926 .60774 m .66768 .60684 L .66781 .60625 L F
.517 .016 0 r
.66926 .60774 m .66781 .60625 L .66765 .60612 L F
.142 .044 .474 r
.66794 .60636 m .66992 .6027 L .66781 .60625 L F
.054 0 .457 r
.66926 .60774 m .66775 .60911 L .66768 .60684 L F
.789 .717 .783 r
.69897 .6385 m .70251 .63683 L .70147 .63587 L F
.699 .854 .957 r
.70147 .63587 m .70251 .63683 L .70465 .63588 L F
.664 .559 .726 r
.63969 .62087 m .64194 .62231 L .64047 .62324 L F
.63969 .62087 m .64331 .6196 L .64194 .62231 L F
0 .26 .679 r
.72237 .70941 m .7214 .70899 L .7201 .70907 L F
.72237 .70941 m .7238 .71033 L .7214 .70899 L F
.631 .514 .702 r
.39926 .75987 m .39737 .76394 L .39716 .76052 L F
.729 .803 .91 r
.67915 .60726 m .68233 .60744 L .68086 .60624 L F
.739 .706 .82 r
.68086 .60624 m .68233 .60744 L .68439 .60643 L F
.344 .806 .932 r
.46256 .72572 m .46467 .72536 L .46591 .7256 L F
0 0 0 r
.46467 .72536 m .46797 .72479 L .46591 .7256 L F
.607 .596 .813 r
.68775 .6272 m .68704 .63014 L .68592 .62799 L F
.68775 .6272 m .68886 .62996 L .68704 .63014 L F
.602 .839 .989 r
.47695 .72447 m .47352 .7243 L .47515 .72278 L F
.577 .795 .982 r
.47883 .72371 m .47695 .72447 L .47515 .72278 L F
0 0 0 r
.4543 .73717 m .45265 .73823 L .45119 .73857 L F
.45265 .73823 m .45073 .73902 L .45119 .73857 L F
.753 .687 .787 r
.37856 .80376 m .38183 .80418 L .37889 .79998 L F
.599 .41 .598 r
.36495 .79278 m .36714 .79019 L .36485 .79041 L F
.212 0 0 r
.33495 .71102 m .33874 .70989 L .3356 .71159 L F
.33495 .71102 m .33694 .71088 L .33874 .70989 L F
.475 .011 .072 r
.33694 .71088 m .34073 .70944 L .33874 .70989 L F
.588 .655 .883 r
.50679 .71995 m .50311 .71784 L .50565 .71752 L F
.776 .741 .821 r
.50884 .71748 m .50679 .71995 L .50565 .71752 L F
.659 .558 .729 r
.50902 .71921 m .50679 .71995 L .50884 .71748 L F
0 0 0 r
.684 .57966 m .6821 .58083 L .6797 .58315 L F
.015 .563 .83 r
.3197 .71458 m .3214 .71483 L .32318 .71536 L F
.071 .633 .711 r
.3214 .71483 m .32521 .71448 L .32318 .71536 L F
.742 .656 .765 r
.34786 .80172 m .34803 .80429 L .34969 .80097 L F
.208 .213 .644 r
.34803 .80429 m .34839 .80685 L .34959 .80564 L F
.491 .164 .339 r
.433 .74134 m .43177 .74386 L .4293 .74419 L F
.525 .2 .36 r
.43515 .74126 m .43177 .74386 L .433 .74134 L F
.555 .375 .593 r
.36741 .77681 m .36951 .77657 L .36963 .77414 L F
.547 .411 .648 r
.36741 .77681 m .36983 .77924 L .36951 .77657 L F
.36741 .77681 m .36769 .77975 L .36983 .77924 L F
.511 0 0 r
.51063 .77988 m .51396 .78162 L .51202 .78228 L F
.63 .312 .413 r
.61411 .64465 m .61636 .64644 L .6141 .64619 L F
.576 .335 .514 r
.61654 .64436 m .61636 .64644 L .61411 .64465 L F
.7 .545 .673 r
.56538 .70171 m .56517 .70402 L .56177 .70363 L F
.549 .648 .9 r
.29192 .61066 m .28877 .60918 L .29038 .60935 L F
.63 .763 .942 r
.29373 .60986 m .29192 .61066 L .29038 .60935 L F
0 0 .039 r
.62177 .68214 m .62134 .68396 L .61996 .68483 L F
0 0 0 r
.62134 .68396 m .61908 .68666 L .61996 .68483 L F
.961 .93 .717 r
.6703 .61773 m .66872 .61835 L .66961 .61703 L F
.585 .376 .563 r
.60685 .67696 m .60931 .67666 L .60921 .67425 L F
.509 .291 .519 r
.60931 .67666 m .61179 .67394 L .60921 .67425 L F
.998 .806 .458 r
.62834 .64943 m .62778 .64634 L .62808 .64741 L F
.904 .766 .699 r
.65052 .64659 m .64919 .64371 L .64801 .64634 L F
.65052 .64659 m .65063 .64456 L .64919 .64371 L F
.939 .778 .655 r
.64774 .64893 m .65052 .64659 L .64801 .64634 L F
.64774 .64893 m .64909 .64975 L .65052 .64659 L F
.666 .785 .937 r
.49271 .73275 m .49343 .73028 L .49125 .73071 L F
.49271 .73275 m .49474 .73131 L .49343 .73028 L F
.45 .6 .908 r
.34839 .80685 m .35108 .80736 L .34959 .80564 L F
.611 .637 .852 r
.34839 .80685 m .35158 .80794 L .35108 .80736 L F
.64 .412 .558 r
.59926 .69316 m .59725 .69526 L .59718 .69322 L F
.499 .848 .994 r
.69588 .72289 m .69282 .72296 L .69541 .72228 L F
.491 .049 .124 r
.69588 .72289 m .69263 .7243 L .69282 .72296 L F
.69588 .72289 m .69471 .72455 L .69263 .7243 L F
.981 .882 .523 r
.69541 .72228 m .69471 .72455 L .69588 .72289 L F
.144 0 0 r
.41226 .77995 m .41453 .78003 L .41587 .77982 L F
.246 .761 .794 r
.41453 .78003 m .41796 .7794 L .41587 .77982 L F
.417 .659 .96 r
.37611 .65729 m .37524 .65848 L .37456 .6565 L F
.37611 .65729 m .37692 .65817 L .37524 .65848 L F
.447 .55 .867 r
.37781 .65941 m .37524 .65848 L .37692 .65817 L F
.904 .914 .817 r
.57029 .67681 m .5713 .67327 L .57205 .67365 L F
.853 .995 .827 r
.57205 .67365 m .57364 .67067 L .57464 .67134 L F
.57205 .67365 m .5713 .67327 L .57364 .67067 L F
.718 .392 0 r
.65448 .61451 m .65381 .6125 L .6533 .61128 L F
.865 .952 .866 r
.6533 .61128 m .65381 .6125 L .65684 .60918 L F
.518 .255 .455 r
.61594 .6281 m .61816 .62771 L .61844 .6258 L F
.285 .059 .385 r
.61844 .6258 m .62 .62669 L .62072 .62533 L F
.61844 .6258 m .61816 .62771 L .62 .62669 L F
.575 .844 .995 r
.49015 .7221 m .48667 .72182 L .48893 .72056 L F
.652 .794 .95 r
.49213 .72095 m .49015 .7221 L .48893 .72056 L F
.316 .019 .292 r
.40141 .75532 m .39921 .75721 L .39934 .75546 L F
.732 .646 .764 r
.70465 .63588 m .70806 .63664 L .70683 .63343 L F
.752 .695 .796 r
.58489 .7031 m .58164 .70378 L .58393 .70114 L F
.7 .5 .614 r
.58397 .70527 m .58164 .70378 L .58489 .7031 L F
.618 .632 .842 r
.58639 .70231 m .58489 .7031 L .58393 .70114 L F
.496 .285 .523 r
.58639 .70231 m .58397 .70527 L .58489 .7031 L F
.834 .74 .761 r
.72694 .72297 m .7234 .72511 L .72635 .72263 L F
.972 .923 .612 r
.72694 .72297 m .72635 .72263 L .72739 .71925 L F
0 0 0 r
.61651 .66873 m .61563 .67046 L .61758 .66757 L F
.376 .793 .977 r
.3923 .79713 m .39155 .79788 L .39368 .79722 L F
.3923 .79713 m .39035 .79739 L .39155 .79788 L F
0 0 .06 r
.63031 .67083 m .62988 .6728 L .62815 .67365 L F
.061 0 .062 r
.63295 .66834 m .63227 .67031 L .63031 .67083 L F
.07 0 .09 r
.63227 .67031 m .62988 .6728 L .63031 .67083 L F
.839 .847 .851 r
.69286 .57989 m .68923 .58058 L .69179 .57889 L F
.774 .835 .899 r
.69465 .57636 m .69286 .57989 L .69179 .57889 L F
.69465 .57636 m .69534 .57841 L .69286 .57989 L F
.767 .485 .506 r
.69807 .71128 m .70134 .71162 L .70213 .71028 L F
.355 .367 .734 r
.70091 .70591 m .70213 .71028 L .70486 .70866 L F
.605 .604 .824 r
.70134 .71162 m .70486 .70866 L .70213 .71028 L F
.569 .526 .768 r
.57933 .70605 m .57989 .70854 L .5772 .70766 L F
.477 .302 .564 r
.35283 .69846 m .35476 .70058 L .35542 .6985 L F
.35283 .69846 m .35296 .7011 L .35476 .70058 L F
.832 .374 0 r
.50795 .78673 m .50871 .789 L .5065 .78691 L F
.50795 .78673 m .50979 .78979 L .50871 .789 L F
.481 .035 .111 r
.47311 .77806 m .471 .77727 L .47427 .77658 L F
.537 .107 .171 r
.47652 .77668 m .47311 .77806 L .47427 .77658 L F
.744 .725 .834 r
.49552 .72208 m .49213 .72095 L .49457 .71993 L F
.778 .807 .876 r
.49783 .71981 m .49552 .72208 L .49457 .71993 L F
.537 .338 .558 r
.67637 .58462 m .6759 .58256 L .67413 .58528 L F
.344 0 .068 r
.44431 .77368 m .44772 .77157 L .44555 .77136 L F
.44431 .77368 m .44643 .77333 L .44772 .77157 L F
.353 0 .011 r
.44643 .77333 m .44995 .77158 L .44772 .77157 L F
.114 0 0 r
.44444 .78187 m .44337 .7826 L .44093 .78354 L F
.418 0 0 r
.44526 .78328 m .44444 .78187 L .44655 .78164 L F
.44526 .78328 m .44337 .7826 L .44444 .78187 L F
.038 0 0 r
.7223 .7154 m .72114 .71588 L .71901 .71613 L F
.354 0 0 r
.72427 .71516 m .72114 .71588 L .7223 .7154 L F
.394 .684 .976 r
.36996 .79629 m .37216 .79796 L .37387 .79783 L F
.424 .485 .819 r
.37216 .79796 m .37518 .80079 L .37387 .79783 L F
.16 0 0 r
.32059 .65455 m .32196 .65478 L .32347 .65285 L F
.175 0 0 r
.32347 .65285 m .32396 .65399 L .32521 .6516 L F
.32347 .65285 m .32196 .65478 L .32396 .65399 L F
.324 .809 .792 r
.48223 .73213 m .48128 .73264 L .48372 .73157 L F
.48223 .73213 m .48021 .7328 L .48128 .73264 L F
.95 .941 .74 r
.67126 .60954 m .6696 .61213 L .66939 .61078 L F
.964 .887 .704 r
.67039 .60865 m .67126 .60954 L .66939 .61078 L F
.572 .422 .639 r
.70234 .70121 m .70269 .70399 L .70456 .7034 L F
.533 .375 .612 r
.36141 .68523 m .36345 .68477 L .3633 .68239 L F
.656 .624 .805 r
.51553 .7228 m .51336 .72357 L .51196 .72214 L F
0 0 0 r
.34842 .71969 m .34609 .72186 L .34698 .72068 L F
.989 .805 .565 r
.64899 .63187 m .65033 .63099 L .64949 .63024 L F
.64899 .63187 m .65018 .63298 L .65033 .63099 L F
.972 .903 .689 r
.65072 .62734 m .64949 .63024 L .65033 .63099 L F
.235 0 0 r
.69944 .72941 m .69625 .72855 L .6971 .72787 L F
.271 0 0 r
.33669 .64931 m .33869 .64959 L .33916 .64942 L F
.463 .87 .712 r
.33916 .64942 m .34114 .6481 L .34214 .64869 L F
.33916 .64942 m .33869 .64959 L .34114 .6481 L F
0 0 .058 r
.62413 .67932 m .62356 .68125 L .62177 .68214 L F
.626 .67662 m .62562 .67843 L .62413 .67932 L F
0 0 .016 r
.62562 .67843 m .62356 .68125 L .62413 .67932 L F
.9 .733 .666 r
.59983 .66018 m .60103 .66332 L .60114 .66091 L F
.765 .672 .76 r
.70671 .61987 m .71007 .62041 L .70889 .61714 L F
.62 .593 .802 r
.70889 .61714 m .71007 .62041 L .7121 .61934 L F
.546 .476 .728 r
.70454 .72747 m .70267 .73071 L .70174 .73027 L F
.304 .798 .844 r
.70323 .72968 m .70151 .7301 L .70174 .73027 L F
0 .376 .719 r
.7019 .73039 m .70174 .73027 L .70043 .72978 L F
.7017 .73032 m .70043 .72978 L .69944 .72941 L F
.70267 .73071 m .70174 .73027 L .69944 .72941 L F
.611 .365 .519 r
.70019 .72829 m .70174 .73027 L .69944 .72941 L F
.655 .387 .502 r
.69625 .72855 m .6996 .72982 L .69957 .72947 L F
.235 0 0 r
.69944 .72941 m .69912 .72934 L .69625 .72855 L F
.655 .387 .502 r
.69625 .72855 m .69957 .72947 L .69924 .72555 L F
.235 0 0 r
.69912 .72934 m .69866 .72925 L .69625 .72855 L F
.067 .519 .898 r
.69716 .72817 m .69883 .7293 L .69625 .72855 L F
.69883 .7293 m .6996 .72982 L .69625 .72855 L F
.235 0 0 r
.69866 .72925 m .69858 .72923 L .69625 .72855 L F
.39 .195 .492 r
.69924 .72555 m .70196 .72768 L .70019 .72829 L F
.70159 .7274 m .70119 .72701 L .70196 .72768 L F
.69924 .72555 m .70119 .72701 L .70159 .7274 L F
.459 .334 .621 r
.70196 .72768 m .70174 .73027 L .70019 .72829 L F
.39 .195 .492 r
.69924 .72555 m .69958 .72954 L .70119 .72701 L F
.467 0 0 r
.70174 .73027 m .70011 .72974 L .69944 .72941 L F
.39 .195 .492 r
.69958 .72954 m .69974 .72958 L .6996 .72952 L F
.467 0 0 r
.70011 .72974 m .69924 .72937 L .69944 .72941 L F
.862 .782 .771 r
.69978 .7295 m .69974 .72958 L .69802 .72875 L F
.39 .195 .492 r
.69958 .72954 m .6996 .72982 L .69974 .72958 L F
.862 .782 .771 r
.69974 .72958 m .6996 .72982 L .69888 .72933 L F
.467 0 0 r
.69974 .72958 m .69858 .72923 L .69924 .72937 L F
.69883 .72932 m .69858 .72923 L .69974 .72958 L F
.862 .782 .771 r
.69974 .72958 m .69888 .72933 L .69802 .72875 L F
.467 0 0 r
.70011 .72974 m .69883 .72932 L .69974 .72958 L F
.39 .195 .492 r
.6996 .72952 m .69974 .72958 L .70119 .72701 L F
.862 .782 .771 r
.70119 .72701 m .69716 .72817 L .69915 .72509 L F
.70119 .72701 m .69915 .72509 L .69951 .72454 L F
.467 0 0 r
.70174 .73027 m .70088 .73025 L .69858 .72923 L F
.304 .798 .844 r
.70151 .7301 m .70088 .73025 L .70174 .73027 L F
0 .376 .719 r
.70267 .73071 m .70174 .73027 L .7019 .73039 L F
.70267 .73071 m .70043 .72978 L .7017 .73032 L F
.862 .782 .771 r
.70119 .72701 m .69978 .7295 L .69716 .72817 L F
.69978 .7295 m .69802 .72875 L .69716 .72817 L F
.631 .815 .971 r
.70232 .62387 m .69928 .62332 L .70126 .62222 L F
.693 .763 .906 r
.70456 .62268 m .70232 .62387 L .70126 .62222 L F
.228 0 .259 r
.63761 .59844 m .63965 .59726 L .63995 .59592 L F
.401 .231 .533 r
.63925 .59978 m .63761 .59844 L .63791 .60096 L F
.63925 .59978 m .63965 .59726 L .63761 .59844 L F
.917 .669 .174 r
.68004 .60313 m .68053 .60403 L .67987 .60086 L F
.757 .687 .784 r
.67987 .60086 m .68053 .60403 L .68319 .60123 L F
.917 .669 .174 r
.68004 .60313 m .68053 .60403 L .67987 .60086 L F
.358 .035 .274 r
.35102 .70169 m .35216 .7028 L .35296 .7011 L F
.35102 .70169 m .35028 .70332 L .35216 .7028 L F
.396 .809 .977 r
.42983 .77633 m .42914 .77727 L .42717 .77637 L F
.42983 .77633 m .43178 .77689 L .42914 .77727 L F
.702 .523 .643 r
.59359 .69718 m .59159 .69588 L .59392 .69569 L F
.59359 .69718 m .5915 .6983 L .59159 .69588 L F
.989 .74 .366 r
.71052 .59847 m .7106 .6006 L .70977 .59981 L F
.764 .837 .378 r
.71052 .59847 m .70977 .59981 L .71054 .59804 L F
.982 .877 .65 r
.71054 .59804 m .70977 .59981 L .70893 .59911 L F
0 0 .433 r
.70977 .59981 m .71132 .59859 L .70903 .59909 L F
.70977 .59981 m .70903 .59909 L .70893 .59911 L F
.989 .74 .366 r
.7106 .6006 m .71063 .6013 L .70977 .59981 L F
.764 .861 .425 r
.71052 .59847 m .71198 .59493 L .71301 .59569 L F
.71052 .59847 m .71054 .59804 L .71066 .59812 L F
.982 .877 .65 r
.71054 .59804 m .70893 .59911 L .71132 .59859 L F
.71054 .59804 m .71132 .59859 L .71036 .59791 L F
.71054 .59804 m .71036 .59791 L .70883 .59684 L F
.764 .861 .425 r
.71066 .59812 m .71054 .59804 L .71198 .59493 L F
.943 .892 .493 r
.28877 .60918 m .28932 .60543 L .29038 .60935 L F
.346 .523 .888 r
.37945 .65988 m .37857 .66123 L .37781 .65941 L F
.37945 .65988 m .38126 .66251 L .37857 .66123 L F
.342 .538 .901 r
.38976 .66867 m .38824 .66978 L .38747 .66841 L F
.38976 .66867 m .39087 .67063 L .38824 .66978 L F
.717 .784 .905 r
.69098 .58715 m .69215 .58872 L .69409 .58754 L F
.545 .267 .445 r
.38416 .68547 m .38355 .68734 L .38128 .68756 L F
.41 .138 .387 r
.38548 .68679 m .38416 .68547 L .38611 .68473 L F
.38548 .68679 m .38355 .68734 L .38416 .68547 L F
.62 .605 .813 r
.52262 .7402 m .52482 .73946 L .52167 .73841 L F
0 .074 .635 r
.67264 .58745 m .67199 .58768 L .6712 .58781 L F
.67264 .58745 m .67367 .58973 L .67199 .58768 L F
.833 .761 .783 r
.56471 .72529 m .56528 .72173 L .56649 .7229 L F
.716 .549 .662 r
.56649 .7229 m .56722 .72584 L .56471 .72529 L F
.607 .759 .952 r
.56877 .72266 m .56649 .7229 L .56528 .72173 L F
.49 .406 .688 r
.56879 .72492 m .56649 .7229 L .56877 .72266 L F
.56879 .72492 m .56722 .72584 L .56649 .7229 L F
.64 .412 .558 r
.59926 .69316 m .5993 .69535 L .59725 .69526 L F
.678 .463 .587 r
.6017 .693 m .5993 .69535 L .59926 .69316 L F
.833 .926 .54 r
.62228 .6623 m .62345 .66089 L .62234 .66273 L F
.612 .855 .492 r
.62439 .65954 m .62557 .65818 L .62345 .66089 L F
.606 .845 .474 r
.62439 .65954 m .62345 .66089 L .62228 .6623 L F
.161 0 0 r
.32059 .65455 m .31983 .65557 L .32196 .65478 L F
.236 0 .258 r
.37905 .69264 m .37671 .69516 L .37742 .69344 L F
.547 .369 .592 r
.36963 .77414 m .37173 .77606 L .37152 .77365 L F
.36963 .77414 m .36951 .77657 L .37173 .77606 L F
.685 .825 .95 r
.48581 .73066 m .48696 .73157 L .48913 .73079 L F
.588 .506 .729 r
.52435 .7255 m .52251 .72858 L .52204 .72584 L F
.432 .096 .294 r
.52493 .72852 m .52253 .72977 L .52251 .72858 L F
.604 .353 .51 r
.52251 .72858 m .52469 .7289 L .52493 .72852 L F
.432 .096 .294 r
.52415 .72893 m .52519 .72948 L .52253 .72977 L F
.619 .529 .731 r
.52656 .72512 m .52475 .72878 L .52435 .7255 L F
.52475 .72878 m .52469 .7289 L .52468 .7288 L F
.432 .096 .294 r
.52493 .72852 m .52498 .72871 L .52415 .72893 L F
.619 .529 .731 r
.52475 .72878 m .52468 .7288 L .52435 .7255 L F
.432 .096 .294 r
.52498 .72871 m .52498 .72873 L .52468 .7288 L F
.52498 .72871 m .52468 .7288 L .52415 .72893 L F
.588 .506 .729 r
.52468 .7288 m .52469 .7289 L .52442 .72886 L F
.432 .096 .294 r
.52498 .72873 m .52519 .72948 L .52415 .72893 L F
.588 .506 .729 r
.52435 .7255 m .52468 .7288 L .52251 .72858 L F
.52468 .7288 m .52442 .72886 L .52251 .72858 L F
.559 .42 .648 r
.37384 .75504 m .37581 .75471 L .37572 .75228 L F
.493 .36 .627 r
.3741 .75814 m .37581 .75471 L .37384 .75504 L F
.767 .675 .761 r
.59801 .67442 m .59611 .67667 L .59885 .67686 L F
.737 .394 .399 r
.59611 .67667 m .59803 .67873 L .59885 .67686 L F
.682 .606 .764 r
.59885 .67686 m .60002 .67373 L .59801 .67442 L F
.59885 .67686 m .60127 .6769 L .60002 .67373 L F
.685 .363 .424 r
.59803 .67873 m .60127 .6769 L .59885 .67686 L F
.598 .59 .815 r
.49918 .73652 m .50239 .73904 L .50149 .73601 L F
.513 .402 .665 r
.50239 .73904 m .50435 .73631 L .50149 .73601 L F
.50239 .73904 m .50488 .73891 L .50435 .73631 L F
.596 .415 .607 r
.50239 .73904 m .50448 .74021 L .50488 .73891 L F
.50239 .73904 m .50255 .74149 L .50448 .74021 L F
.371 .163 .462 r
.39287 .67649 m .39252 .67881 L .39004 .67904 L F
.352 .109 .399 r
.39186 .68084 m .39004 .67904 L .39252 .67881 L F
.39186 .68084 m .39012 .68164 L .39004 .67904 L F
.594 .453 .659 r
.58393 .70114 m .58164 .70378 L .58168 .70178 L F
.426 .17 .42 r
.64196 .59695 m .63995 .59592 L .63965 .59726 L F
.64196 .59695 m .64206 .59526 L .63995 .59592 L F
.639 .648 .843 r
.51069 .73689 m .51364 .739 L .51365 .737 L F
.653 .498 .661 r
.51147 .74171 m .51422 .74177 L .51364 .739 L F
.675 .565 .723 r
.51365 .737 m .51364 .739 L .51576 .7363 L F
.694 .593 .738 r
.51364 .739 m .51791 .73966 L .51576 .7363 L F
.725 .572 .682 r
.51422 .74177 m .51791 .73966 L .51364 .739 L F
.579 .352 .536 r
.59725 .69526 m .59359 .69718 L .59392 .69569 L F
.718 .94 .957 r
.35158 .80794 m .35334 .80621 L .35108 .80736 L F
.35158 .80794 m .35437 .80668 L .35334 .80621 L F
.004 0 .084 r
.62356 .68125 m .62134 .68396 L .62177 .68214 L F
.914 .752 .667 r
.65063 .64456 m .64956 .64137 L .64919 .64371 L F
.914 .764 .68 r
.73127 .73556 m .73216 .73848 L .73292 .73649 L F
.351 0 0 r
.33085 .67875 m .32899 .67894 L .33185 .67774 L F
0 0 0 r
.33085 .67875 m .33185 .67774 L .33367 .67683 L F
.38 .119 .388 r
.30819 .66088 m .30951 .66215 L .31021 .66047 L F
.30819 .66088 m .30769 .66282 L .30951 .66215 L F
.572 .378 .58 r
.34958 .79873 m .35194 .79851 L .35248 .79556 L F
.823 .62 .628 r
.35248 .79556 m .35194 .79851 L .35299 .79673 L F
.466 .827 .995 r
.47595 .73353 m .47469 .73296 L .47257 .73336 L F
.386 .788 .985 r
.47595 .73353 m .4781 .73331 L .47469 .73296 L F
.217 0 0 r
.45085 .78103 m .4523 .77974 L .45438 .77934 L F
.721 .611 .734 r
.51165 .74361 m .51422 .74177 L .51147 .74171 L F
.485 0 0 r
.67715 .62627 m .68 .62606 L .6767 .62553 L F
.67715 .62627 m .67926 .62708 L .68 .62606 L F
.493 .518 .812 r
.68017 .62876 m .68281 .62944 L .68174 .62646 L F
.689 .196 .07 r
.68174 .62646 m .68133 .62803 L .68123 .62672 L F
.198 0 0 r
.68 .62606 m .68174 .62646 L .6822 .62622 L F
.689 .196 .07 r
.68174 .62646 m .68123 .62672 L .68113 .62555 L F
.198 0 0 r
.6822 .62622 m .68174 .62646 L .68248 .62624 L F
.68 .62606 m .67926 .62708 L .68174 .62646 L F
.109 0 .152 r
.35437 .80668 m .35546 .80767 L .35633 .80477 L F
.736 .648 .762 r
.64331 .6196 m .64455 .61971 L .64194 .62231 L F
.447 .078 .244 r
.41719 .7473 m .41621 .74904 L .41407 .74928 L F
.451 .183 .415 r
.41873 .74658 m .41621 .74904 L .41719 .7473 L F
.709 .684 .823 r
.3064 .71737 m .30683 .71738 L .30652 .7176 L F
.622 .654 .861 r
.67788 .62888 m .68141 .63035 L .68017 .62876 L F
.393 .649 .96 r
.68141 .63035 m .68281 .62944 L .68017 .62876 L F
.68174 .63043 m .68336 .63079 L .68281 .62944 L F
.769 .484 .503 r
.68336 .63079 m .68372 .63287 L .68044 .63249 L F
.68336 .63079 m .68044 .63249 L .68192 .63205 L F
.982 .904 .646 r
.68336 .63079 m .68192 .63205 L .68281 .62944 L F
.377 .185 .488 r
.68233 .63126 m .68393 .62841 L .68281 .62944 L F
.68393 .62841 m .68406 .62817 L .68281 .62944 L F
.393 .649 .96 r
.68141 .63035 m .68174 .63043 L .68281 .62944 L F
.563 .804 .989 r
.7144 .59415 m .71301 .59569 L .71198 .59493 L F
.7144 .59415 m .71546 .59513 L .71301 .59569 L F
0 .525 .765 r
.34114 .6481 m .34449 .64873 L .34214 .64869 L F
.687 .607 .76 r
.34969 .80097 m .35194 .79851 L .34958 .79873 L F
0 0 .041 r
.67658 .611 m .67609 .61216 L .6767 .60946 L F
0 0 0 r
.67838 .60624 m .6767 .60946 L .67915 .60726 L F
.67838 .60624 m .67748 .60889 L .6767 .60946 L F
.128 0 .187 r
.67796 .61042 m .6767 .60946 L .67748 .60889 L F
.67796 .61042 m .67658 .611 L .6767 .60946 L F
.579 .524 .758 r
.36367 .78517 m .3663 .78685 L .36619 .78487 L F
.111 .664 .734 r
.44652 .74057 m .4427 .74099 L .44407 .74069 L F
.776 .684 .762 r
.59775 .66282 m .60103 .66332 L .59983 .66018 L F
.744 .632 .735 r
.35194 .79851 m .35573 .80043 L .35299 .79673 L F
.584 .529 .76 r
.52332 .72219 m .52204 .72584 L .5212 .7225 L F
.52332 .72219 m .52435 .7255 L .52204 .72584 L F
.81 .761 .807 r
.50015 .73295 m .50395 .73257 L .50346 .73155 L F
.814 .712 .752 r
.50015 .73295 m .50149 .73601 L .50395 .73257 L F
.507 .109 .219 r
.40937 .73029 m .4116 .73023 L .41289 .72836 L F
.425 .007 .14 r
.4116 .73023 m .41504 .72831 L .41289 .72836 L F
.683 .66 .821 r
.4981 .73506 m .49918 .73652 L .50149 .73601 L F
.612 .439 .624 r
.58613 .69828 m .58393 .70114 L .5839 .69861 L F
0 .521 .824 r
.67732 .61577 m .68097 .61677 L .68161 .61723 L F
.721 .309 .267 r
.68031 .61891 m .68359 .61923 L .68161 .61723 L F
.836 .981 .876 r
.62586 .65644 m .62652 .6568 L .62557 .65818 L F
.872 .935 .56 r
.62586 .65644 m .62557 .65818 L .62439 .65954 L F
0 0 0 r
.626 .67662 m .62815 .67365 L .62761 .67559 L F
0 0 .043 r
.62815 .67365 m .62988 .6728 L .62761 .67559 L F
.68 .449 .565 r
.60699 .69048 m .60704 .69272 L .60541 .69262 L F
.619 .4 .563 r
.60933 .6924 m .60699 .69048 L .60953 .69066 L F
.60933 .6924 m .60704 .69272 L .60699 .69048 L F
.66 .261 .277 r
.68237 .6229 m .68242 .6256 L .68162 .62498 L F
.68186 .62291 m .68162 .62498 L .67902 .62294 L F
.68237 .6229 m .68162 .62498 L .68186 .62291 L F
.68242 .6256 m .68238 .6256 L .67902 .62294 L F
.13 .315 .783 r
.67902 .62294 m .68238 .6256 L .68052 .62213 L F
.932 .684 .204 r
.68156 .62558 m .68107 .62334 L .68249 .62561 L F
.68174 .62646 m .68156 .62558 L .68249 .62561 L F
.66 .261 .277 r
.68242 .6256 m .68242 .62563 L .68238 .6256 L F
.13 .315 .783 r
.68238 .6256 m .68242 .62563 L .68229 .62539 L F
.68238 .6256 m .68229 .62539 L .68052 .62213 L F
.932 .684 .204 r
.68249 .62561 m .68246 .62556 L .68389 .624 L F
.169 0 .247 r
.68389 .624 m .68242 .62563 L .68242 .6256 L F
.68389 .624 m .68242 .6256 L .68237 .6229 L F
.705 .621 .76 r
.68052 .62213 m .68229 .62539 L .68389 .624 L F
.932 .684 .204 r
.68246 .62556 m .68233 .62536 L .68389 .624 L F
.705 .621 .76 r
.68229 .62539 m .68242 .62563 L .68389 .624 L F
.932 .684 .204 r
.68233 .62536 m .68214 .62506 L .68389 .624 L F
.68214 .62506 m .68107 .62334 L .68143 .62343 L F
.68214 .62506 m .68143 .62343 L .68389 .624 L F
.68156 .62558 m .68113 .62555 L .68107 .62334 L F
.68174 .62646 m .6815 .62609 L .68156 .62558 L F
.6815 .62609 m .68113 .62555 L .68156 .62558 L F
.169 0 .247 r
.68389 .624 m .68237 .6229 L .68461 .62247 L F
.241 0 0 r
.44995 .77158 m .45218 .77136 L .45313 .77071 L F
.048 0 0 r
.45313 .77071 m .45419 .77083 L .45523 .77043 L F
.45313 .77071 m .45218 .77136 L .45419 .77083 L F
.527 .237 .418 r
.61765 .68764 m .61468 .68962 L .61505 .68812 L F
.8 .809 .859 r
.50448 .74021 m .50816 .73908 L .50687 .73777 L F
.768 .767 .852 r
.50687 .73777 m .50816 .73908 L .51069 .73689 L F
.356 0 0 r
.39083 .73592 m .39563 .7341 L .39159 .73514 L F
.39083 .73592 m .39314 .73577 L .39563 .7341 L F
.889 .889 .824 r
.69613 .58609 m .69859 .58419 L .69819 .58368 L F
.125 .042 .483 r
.62969 .61205 m .63091 .61297 L .63104 .61133 L F
.511 .313 .548 r
.6309 .61184 m .63272 .61029 L .63104 .61133 L F
.993 .756 .395 r
.63091 .61297 m .63048 .6133 L .63104 .61133 L F
.511 .313 .548 r
.63048 .6133 m .63182 .6115 L .6309 .61184 L F
.63182 .6115 m .63272 .61029 L .6309 .61184 L F
.125 .042 .483 r
.6299 .61221 m .62978 .61463 L .63091 .61297 L F
.62969 .61205 m .6297 .61229 L .6299 .61221 L F
.6297 .61229 m .62978 .61463 L .6299 .61221 L F
.798 .667 .719 r
.50901 .7357 m .51271 .7358 L .51234 .7342 L F
.796 .681 .738 r
.50901 .7357 m .51069 .73689 L .51271 .7358 L F
.618 .553 .76 r
.51271 .7358 m .51365 .737 L .51234 .7342 L F
.639 .648 .843 r
.51069 .73689 m .51365 .737 L .51271 .7358 L F
.313 .467 .854 r
.69598 .71635 m .69502 .71767 L .69349 .71499 L F
.631 .893 .571 r
.69498 .71769 m .69502 .71767 L .69598 .71635 L F
.725 .572 .682 r
.51422 .74177 m .51709 .74173 L .51791 .73966 L F
.607 .487 .691 r
.37058 .76817 m .37247 .76548 L .37042 .76585 L F
.818 .86 .879 r
.68498 .63428 m .68199 .63679 L .682 .63521 L F
.091 .228 .713 r
.68199 .63679 m .68336 .6385 L .682 .63521 L F
.753 .498 .547 r
.60154 .67887 m .60442 .67668 L .60127 .6769 L F
.60154 .67887 m .60375 .67904 L .60442 .67668 L F
.602 .345 .499 r
.60442 .67668 m .60665 .67872 L .60685 .67696 L F
.60442 .67668 m .60375 .67904 L .60665 .67872 L F
.565 .762 .971 r
.35981 .65284 m .35644 .65209 L .35849 .65172 L F
.448 .767 .997 r
.36047 .65173 m .35981 .65284 L .35849 .65172 L F
.36047 .65173 m .36179 .65265 L .35981 .65284 L F
.519 .39 .645 r
.36619 .78487 m .36813 .78448 L .36789 .782 L F
.345 .146 .461 r
.3663 .78685 m .36813 .78448 L .36619 .78487 L F
.715 .664 .798 r
.30809 .71492 m .30683 .71738 L .3064 .71737 L F
.662 .708 .882 r
.52014 .73078 m .52559 .73152 L .52253 .72977 L F
.383 .375 .727 r
.52559 .73152 m .5257 .73071 L .52253 .72977 L F
.52559 .73152 m .52701 .73223 L .5257 .73071 L F
.616 .823 .98 r
.34829 .87367 m .34656 .87439 L .34483 .87341 L F
.34829 .87367 m .34656 .87439 L .34483 .87341 L F
.514 .283 .502 r
.5155 .71104 m .51311 .71412 L .51327 .71164 L F
.892 .884 .818 r
.69719 .57529 m .69534 .57841 L .69465 .57636 L F
.365 0 0 r
.52242 .79072 m .52089 .79209 L .51866 .79224 L F
0 0 0 r
.52257 .79114 m .52242 .79072 L .52371 .78957 L F
.52257 .79114 m .52089 .79209 L .52242 .79072 L F
.68 .583 .74 r
.51234 .7342 m .51365 .737 L .51576 .7363 L F
.759 .655 .748 r
.70671 .61987 m .70767 .62292 L .70456 .62268 L F
.509 .575 .857 r
.70789 .62528 m .70456 .62268 L .70767 .62292 L F
.603 .606 .828 r
.70929 .61953 m .70767 .62292 L .70671 .61987 L F
.70929 .61953 m .71002 .62263 L .70767 .62292 L F
.583 .421 .627 r
.71002 .62263 m .70789 .62528 L .70767 .62292 L F
.277 .038 .36 r
.70091 .70591 m .70244 .70582 L .70269 .70399 L F
.355 .367 .734 r
.70091 .70591 m .70486 .70866 L .70244 .70582 L F
.835 .955 .612 r
.58039 .66268 m .57995 .66349 L .58013 .6624 L F
.908 .981 .779 r
.57871 .66581 m .58013 .6624 L .57995 .66349 L F
.236 .55 .93 r
.3664 .65293 m .36941 .65377 L .3688 .65469 L F
.256 .577 .942 r
.36941 .65377 m .37084 .65518 L .3688 .65469 L F
.854 .397 .068 r
.5065 .78691 m .50403 .78418 L .50495 .78471 L F
.148 0 0 r
.34451 .72369 m .34407 .72258 L .34609 .72186 L F
.34451 .72369 m .34266 .72439 L .34407 .72258 L F
.426 .222 .498 r
.38113 .68985 m .37905 .69264 L .37932 .69038 L F
.715 .664 .798 r
.30809 .71492 m .3064 .71737 L .30518 .71501 L F
.795 .628 .675 r
.56617 .69583 m .56296 .69576 L .56474 .69288 L F
.714 .597 .724 r
.56837 .69312 m .56617 .69583 L .56474 .69288 L F
0 0 0 r
.66851 .59344 m .66799 .59532 L .66834 .59439 L F
.558 .272 .438 r
.4421 .77368 m .44431 .77368 L .44555 .77136 L F
0 0 .063 r
.62761 .67559 m .62562 .67843 L .626 .67662 L F
.108 .399 .853 r
.48287 .76829 m .48483 .77021 L .4836 .76945 L F
.313 0 .202 r
.36312 .70915 m .36028 .71129 L .3611 .70979 L F
.463 .008 .086 r
.51598 .78011 m .51911 .7807 L .51989 .77928 L F
.597 .044 0 r
.51911 .7807 m .52179 .78136 L .51989 .77928 L F
.769 .658 .741 r
.55826 .70115 m .55732 .69779 L .55866 .69881 L F
.55826 .70115 m .55475 .70075 L .55732 .69779 L F
.55826 .70115 m .55667 .70125 L .55475 .70075 L F
.759 .559 .626 r
.55826 .70115 m .55629 .70357 L .55667 .70125 L F
.715 .495 .59 r
.55832 .70339 m .55629 .70357 L .55826 .70115 L F
.578 .442 .659 r
.35723 .69538 m .35927 .69239 L .35731 .69286 L F
.281 0 0 r
.45766 .77881 m .45654 .77932 L .45438 .77934 L F
.301 0 0 r
.45986 .77885 m .45654 .77932 L .45766 .77881 L F
.169 0 0 r
.42781 .78688 m .42288 .78872 L .42567 .78734 L F
.685 .363 .424 r
.59803 .67873 m .60019 .67902 L .60127 .6769 L F
.692 .371 .428 r
.60127 .6769 m .60019 .67902 L .60154 .67887 L F
.709 .737 .873 r
.63156 .64097 m .63037 .64348 L .62909 .64321 L F
.63156 .64097 m .63298 .64207 L .63037 .64348 L F
.06 0 .456 r
.69746 .6257 m .69691 .62869 L .69669 .62748 L F
.129 0 0 r
.69615 .6292 m .69254 .63142 L .69125 .62776 L F
.785 .571 .611 r
.69691 .62869 m .69806 .63081 L .69777 .63079 L F
.129 0 0 r
.6962 .62961 m .69585 .62978 L .69601 .62947 L F
.6962 .62961 m .69476 .63056 L .69254 .63142 L F
.785 .571 .611 r
.6962 .62961 m .69777 .63079 L .69476 .63056 L F
.69609 .6294 m .69777 .63079 L .69601 .62947 L F
.69691 .62869 m .69756 .63027 L .69609 .6294 L F
.69756 .63027 m .69777 .63079 L .69609 .6294 L F
.689 .633 .787 r
.69377 .62538 m .69629 .62878 L .69534 .62896 L F
.69629 .62878 m .69615 .6292 L .69534 .62896 L F
.129 0 0 r
.69585 .62978 m .69254 .63142 L .69615 .6292 L F
.785 .571 .611 r
.6967 .6275 m .69669 .62751 L .69669 .62748 L F
.69678 .62798 m .69638 .6285 L .6967 .6275 L F
.69691 .62869 m .69601 .62947 L .69678 .62798 L F
.688 .632 .788 r
.69669 .62748 m .69671 .62936 L .69629 .62878 L F
.69669 .62748 m .69629 .62878 L .69377 .62538 L F
.785 .571 .611 r
.69669 .62751 m .69476 .63056 L .69669 .62748 L F
.69638 .6285 m .69476 .63056 L .6967 .6275 L F
.689 .633 .787 r
.69629 .62878 m .69671 .62936 L .69615 .6292 L F
.69205 .62701 m .69534 .62896 L .69125 .62776 L F
.69377 .62538 m .69534 .62896 L .69205 .62701 L F
.129 0 0 r
.69671 .62936 m .69476 .63056 L .6962 .62961 L F
.785 .571 .611 r
.69601 .62947 m .6962 .62961 L .69476 .63056 L F
.129 0 0 r
.69671 .62936 m .6962 .62961 L .69615 .6292 L F
.6962 .62961 m .69601 .62947 L .69615 .6292 L F
.785 .571 .611 r
.69601 .62947 m .69476 .63056 L .69678 .62798 L F
.353 .076 .348 r
.34847 .70392 m .34606 .70641 L .34789 .70574 L F
.371 .094 .356 r
.34847 .70392 m .34973 .70514 L .35028 .70332 L F
.34847 .70392 m .34789 .70574 L .34973 .70514 L F
.638 .29 .366 r
.60665 .67872 m .60911 .67872 L .60685 .67696 L F
.57 .327 .508 r
.60685 .67696 m .60911 .67872 L .60931 .67666 L F
.289 0 0 r
.31885 .73605 m .31395 .73815 L .31461 .73806 L F
.31885 .73605 m .31602 .738 L .31402 .73814 L F
.31885 .73605 m .31402 .73814 L .31399 .73813 L F
.31399 .73813 m .31402 .73814 L .31395 .73815 L F
.457 .122 .309 r
.31395 .73815 m .31631 .73778 L .31402 .73736 L F
.31395 .73815 m .31602 .738 L .31631 .73778 L F
.682 .371 .442 r
.31631 .73778 m .31577 .73952 L .31402 .73736 L F
.054 .208 .706 r
.31402 .73736 m .31489 .73844 L .31478 .73646 L F
.31489 .73844 m .31577 .73952 L .31548 .73864 L F
.31489 .73844 m .31548 .73864 L .31478 .73646 L F
.698 .299 .288 r
.70935 .73337 m .70843 .73519 L .70598 .73335 L F
.479 .644 .93 r
.71066 .732 m .70935 .73337 L .7082 .73242 L F
.71066 .732 m .71157 .73342 L .70935 .73337 L F
.921 .594 .404 r
.70991 .7357 m .70843 .73519 L .70935 .73337 L F
.74 .611 .714 r
.59323 .66846 m .59673 .66877 L .59576 .6653 L F
.75 .576 .659 r
.59323 .66846 m .59664 .6713 L .59673 .66877 L F
.681 .522 .664 r
.59664 .6713 m .59931 .66879 L .59673 .66877 L F
.408 .818 .977 r
.71131 .58994 m .7118 .59045 L .70856 .59037 L F
.71131 .58994 m .7118 .59045 L .70856 .59037 L F
.513 .387 .646 r
.3633 .68239 m .36509 .68194 L .36455 .67872 L F
.534 .375 .612 r
.3633 .68239 m .36548 .68423 L .36509 .68194 L F
.3633 .68239 m .36345 .68477 L .36548 .68423 L F
.38 .13 .405 r
.29527 .61479 m .29459 .61693 L .29293 .61744 L F
.37 .176 .483 r
.29662 .61383 m .29459 .61693 L .29527 .61479 L F
.568 .467 .699 r
.35583 .79623 m .35887 .79632 L .35693 .79522 L F
.651 .389 .509 r
.52708 .7407 m .53005 .74104 L .52765 .73938 L F
.119 0 0 r
.41236 .75052 m .41081 .75033 L .40841 .74998 L F
.281 0 0 r
.41407 .74928 m .41081 .75033 L .41236 .75052 L F
.413 .066 .265 r
.40184 .73318 m .40385 .73283 L .40492 .73059 L F
.48 .138 .309 r
.40385 .73283 m .4071 .73028 L .40492 .73059 L F
.146 0 0 r
.35227 .67262 m .34874 .67269 L .34991 .67297 L F
.749 .611 .705 r
.71662 .60801 m .71357 .60936 L .71534 .60677 L F
.615 .324 .452 r
.71662 .60801 m .71515 .61078 L .71357 .60936 L F
.666 .585 .755 r
.71757 .60605 m .71662 .60801 L .71534 .60677 L F
.71757 .60605 m .71842 .60863 L .71662 .60801 L F
.448 .047 .186 r
.71842 .60863 m .71515 .61078 L .71662 .60801 L F
.732 .856 .939 r
.336 .67573 m .33367 .67683 L .33685 .67667 L F
.429 .775 .997 r
.33685 .67667 m .33752 .67571 L .336 .67573 L F
.33685 .67667 m .339 .67652 L .33752 .67571 L F
.315 0 0 r
.45593 .73656 m .45265 .73823 L .4543 .73717 L F
.461 0 0 r
.4482 .72429 m .45019 .72496 L .4516 .72484 L F
.22 .71 .924 r
.45019 .72496 m .45359 .72538 L .4516 .72484 L F
.237 0 0 r
.43363 .72467 m .43573 .72464 L .43725 .72403 L F
.407 0 0 r
.43725 .72403 m .43573 .72464 L .43915 .7245 L F
.193 0 0 r
.64932 .58973 m .65142 .58952 L .65236 .58825 L F
0 0 0 r
.65236 .58825 m .65328 .58851 L .65441 .58753 L F
.65236 .58825 m .65142 .58952 L .65328 .58851 L F
.721 .611 .734 r
.51165 .74361 m .515 .74447 L .51422 .74177 L F
.726 .614 .733 r
.51422 .74177 m .515 .74447 L .51709 .74173 L F
0 .194 .724 r
.68566 .58353 m .68602 .58506 L .68636 .58399 L F
.007 .316 .805 r
.68602 .58506 m .68765 .58607 L .68636 .58399 L F
.699 .504 .621 r
.57302 .717 m .56941 .71468 L .57304 .71464 L F
.73 .555 .655 r
.57546 .71451 m .57302 .717 L .57304 .71464 L F
.453 .303 .586 r
.29459 .61693 m .29475 .61922 L .29293 .61744 L F
.388 .297 .63 r
.29293 .61744 m .29475 .61922 L .2932 .61985 L F
.974 .844 .653 r
.64898 .63612 m .65018 .63298 L .64899 .63187 L F
.648 .767 .936 r
.39426 .67115 m .39164 .67177 L .39087 .67063 L F
.543 .409 .648 r
.39426 .67115 m .3924 .67395 L .39164 .67177 L F
0 0 0 r
.63295 .66834 m .63509 .66548 L .63436 .66747 L F
.63436 .66747 m .63227 .67031 L .63295 .66834 L F
.852 .907 .872 r
.69839 .57882 m .70046 .57884 L .70107 .57548 L F
.905 .641 .528 r
.69978 .58111 m .70046 .57884 L .69839 .57882 L F
.779 .842 .899 r
.70107 .57548 m .70046 .57884 L .70292 .57667 L F
.744 .632 .735 r
.35194 .79851 m .3535 .80187 L .35573 .80043 L F
.383 .496 .85 r
.3535 .80187 m .35633 .80477 L .35573 .80043 L F
.434 .366 .681 r
.35573 .80043 m .35692 .80272 L .35727 .80055 L F
.35573 .80043 m .35633 .80477 L .35692 .80272 L F
.694 .746 .892 r
.67473 .62816 m .67788 .62888 L .67715 .62627 L F
.533 .66 .918 r
.67788 .62888 m .67926 .62708 L .67715 .62627 L F
.67788 .62888 m .68017 .62876 L .67926 .62708 L F
.681 .159 0 r
.48992 .77316 m .49185 .7743 L .49302 .77409 L F
.702 .178 0 r
.49385 .77567 m .49302 .77409 L .49185 .7743 L F
.49385 .77567 m .49509 .77636 L .49302 .77409 L F
.781 .34 .202 r
.49302 .77409 m .49509 .77636 L .49669 .77638 L F
.578 .578 .817 r
.36817 .80037 m .36739 .80373 L .36599 .8032 L F
.36817 .80037 m .36951 .80346 L .36739 .80373 L F
.354 .798 .957 r
.36739 .80373 m .36816 .80307 L .36599 .8032 L F
.36739 .80373 m .36951 .80346 L .36816 .80307 L F
.745 .25 .054 r
.49405 .7797 m .49242 .77946 L .49096 .77819 L F
.786 .322 .136 r
.49405 .7797 m .49309 .7806 L .49242 .77946 L F
.528 0 0 r
.49752 .78085 m .49309 .7806 L .49405 .7797 L F
.644 .561 .747 r
.5111 .7169 m .50902 .71921 L .50884 .71748 L F
.5111 .7169 m .51219 .72024 L .50902 .71921 L F
.461 0 0 r
.46968 .7782 m .471 .77727 L .47311 .77806 L F
.59 .369 .549 r
.59359 .69718 m .59172 .70076 L .5915 .6983 L F
.59359 .69718 m .59429 .70059 L .59172 .70076 L F
.579 .352 .536 r
.59725 .69526 m .59681 .69792 L .59359 .69718 L F
.529 .33 .555 r
.59619 .70002 m .59359 .69718 L .59681 .69792 L F
.59619 .70002 m .59429 .70059 L .59359 .69718 L F
.422 .857 .932 r
.35227 .67262 m .35588 .67212 L .35408 .67231 L F
.382 .843 .8 r
.35793 .6711 m .35408 .67231 L .35588 .67212 L F
.841 .72 .73 r
.63498 .63891 m .63156 .64097 L .6317 .63861 L F
.63498 .63891 m .63298 .64207 L .63156 .64097 L F
.018 0 0 r
.45724 .77026 m .45939 .76979 L .46097 .76895 L F
.148 0 0 r
.45939 .76979 m .46318 .76906 L .46097 .76895 L F
.86 .66 .63 r
.62834 .64943 m .63004 .65269 L .62815 .65184 L F
.899 .714 .644 r
.62899 .65423 m .62815 .65184 L .63004 .65269 L F
.66 .576 .75 r
.64493 .61817 m .64701 .61718 L .64455 .61971 L F
.141 0 0 r
.33307 .64914 m .33508 .64931 L .33669 .64931 L F
.21 0 0 r
.33669 .64931 m .33508 .64931 L .33869 .64959 L F
.666 .606 .778 r
.51441 .71965 m .51196 .72214 L .51219 .72024 L F
.51441 .71965 m .51553 .7228 L .51196 .72214 L F
.814 .681 .717 r
.56941 .71468 m .56751 .71707 L .56627 .71404 L F
.695 .503 .623 r
.56941 .71468 m .57112 .71771 L .56751 .71707 L F
.699 .504 .621 r
.57302 .717 m .57112 .71771 L .56941 .71468 L F
.736 .529 .612 r
.58164 .70378 m .57933 .70605 L .57887 .70376 L F
.58164 .70378 m .58169 .70609 L .57933 .70605 L F
.7 .5 .614 r
.58397 .70527 m .58169 .70609 L .58164 .70378 L F
.825 .796 .824 r
.69814 .61776 m .69828 .61884 L .69654 .61935 L F
.701 .377 .425 r
.69654 .61935 m .69828 .61884 L .69833 .62132 L F
.665 .626 .8 r
.52367 .73622 m .52722 .73634 L .52546 .73506 L F
.52367 .73622 m .52683 .73846 L .52722 .73634 L F
.656 .763 .929 r
.52546 .73506 m .52722 .73634 L .52934 .73533 L F
.5 .332 .585 r
.52722 .73634 m .52828 .73757 L .52934 .73533 L F
.72 .585 .704 r
.52934 .73533 m .52944 .73857 L .52784 .7385 L F
.339 0 0 r
.52683 .73846 m .52944 .73857 L .52933 .73879 L F
.5 .332 .585 r
.52828 .73757 m .52933 .73879 L .52934 .73533 L F
.72 .585 .704 r
.52934 .73533 m .52784 .7385 L .52683 .73846 L F
.591 .405 .598 r
.52683 .73846 m .52934 .73533 L .52722 .73634 L F
.72 .585 .704 r
.52934 .73533 m .52683 .73846 L .52722 .73634 L F
.445 .182 .42 r
.6189 .6419 m .61859 .64383 L .61654 .64436 L F
.59 .372 .553 r
.62273 .6399 m .61859 .64383 L .6189 .6419 L F
.865 .952 .866 r
.6533 .61128 m .65684 .60918 L .6558 .60828 L F
.698 .255 .197 r
.65684 .60918 m .65579 .61065 L .6558 .60828 L F
.65684 .60918 m .65908 .61107 L .65579 .61065 L F
.678 .463 .587 r
.6017 .693 m .60189 .69561 L .5993 .69535 L F
.578 .388 .587 r
.60393 .69505 m .6017 .693 L .60541 .69262 L F
.60393 .69505 m .60189 .69561 L .6017 .693 L F
.557 .275 .443 r
.60819 .63313 m .61063 .63295 L .61076 .63116 L F
.583 .314 .474 r
.61063 .63295 m .6137 .63011 L .61076 .63116 L F
.821 .927 .904 r
.56653 .67855 m .56924 .67615 L .57029 .67681 L F
.904 .914 .817 r
.57029 .67681 m .56924 .67615 L .5713 .67327 L F
.399 .351 .689 r
.3125 .68701 m .31046 .68491 L .31246 .68475 L F
.3125 .68701 m .31119 .68763 L .31046 .68491 L F
.708 .792 .916 r
.69404 .63908 m .69398 .64042 L .69728 .6392 L F
.531 .273 .47 r
.6137 .63011 m .6158 .62976 L .61594 .6281 L F
.448 .163 .388 r
.6158 .62976 m .61816 .62771 L .61594 .6281 L F
.279 0 .091 r
.30262 .66564 m .30448 .66515 L .30573 .6633 L F
.321 0 .12 r
.30448 .66515 m .30769 .66282 L .30573 .6633 L F
.772 .29 .09 r
.71327 .71503 m .71247 .71598 L .71124 .71437 L F
.312 .794 .905 r
.71668 .71575 m .71247 .71598 L .71327 .71503 L F
.811 .456 .384 r
.68982 .71697 m .68918 .71905 L .68875 .71601 L F
.655 .777 .938 r
.5212 .7225 m .51792 .7222 L .52052 .72212 L F
.555 .647 .895 r
.52305 .72171 m .5212 .7225 L .52052 .72212 L F
.52305 .72171 m .52332 .72219 L .5212 .7225 L F
.283 0 .147 r
.34606 .70641 m .3468 .70791 L .34789 .70574 L F
.34606 .70641 m .34491 .70855 L .3468 .70791 L F
.131 0 0 r
.47257 .73336 m .46895 .73452 L .47055 .73502 L F
.403 0 0 r
.4988 .77746 m .50071 .77816 L .502 .77726 L F
.573 .051 0 r
.50071 .77816 m .50415 .77848 L .502 .77726 L F
.512 .304 .534 r
.38407 .73901 m .38644 .73871 L .38675 .73586 L F
.664 .437 .566 r
.38675 .73586 m .38644 .73871 L .38901 .73849 L F
.73 .555 .655 r
.57546 .71451 m .57532 .71715 L .57302 .717 L F
.527 .338 .568 r
.57754 .71441 m .57532 .71715 L .57546 .71451 L F
.543 .409 .648 r
.39426 .67115 m .39468 .67375 L .3924 .67395 L F
.314 .233 .603 r
.39413 .6758 m .3924 .67395 L .39468 .67375 L F
.39413 .6758 m .39287 .67649 L .3924 .67395 L F
.796 .849 .89 r
.72054 .61846 m .72099 .61969 L .71846 .62008 L F
.98 .69 .326 r
.7224 .61874 m .72297 .61745 L .72099 .61969 L F
.7224 .61874 m .72099 .61969 L .72054 .61846 L F
.687 .607 .76 r
.34969 .80097 m .3535 .80187 L .35194 .79851 L F
.666 .296 .334 r
.71024 .71181 m .70914 .71271 L .70697 .71197 L F
.807 .508 .483 r
.71024 .71181 m .71124 .71437 L .70914 .71271 L F
0 0 0 r
.33094 .73065 m .32836 .7322 L .32929 .7315 L F
.568 .467 .699 r
.35583 .79623 m .35931 .79775 L .35887 .79632 L F
.603 .432 .622 r
.35583 .79623 m .35727 .80055 L .35931 .79775 L F
.914 .764 .68 r
.73127 .73556 m .73016 .73871 L .73216 .73848 L F
.698 .534 .662 r
.72757 .74064 m .73064 .7415 L .73216 .73848 L F
.798 .667 .719 r
.50901 .7357 m .51234 .7342 L .51114 .73285 L F
.528 .67 .928 r
.51234 .7342 m .51312 .73172 L .51114 .73285 L F
.51234 .7342 m .51407 .73398 L .51312 .73172 L F
.68 .583 .74 r
.51234 .7342 m .51576 .7363 L .51407 .73398 L F
.54 .427 .674 r
.38407 .73901 m .38649 .74118 L .38644 .73871 L F
.559 .427 .658 r
.38436 .74146 m .38649 .74118 L .38407 .73901 L F
.9 .882 .807 r
.71481 .62599 m .71522 .62867 L .71679 .62614 L F
.925 .892 .779 r
.71325 .62929 m .71522 .62867 L .71481 .62599 L F
.71325 .62929 m .71414 .63022 L .71522 .62867 L F
.448 .047 .186 r
.71842 .60863 m .7185 .61014 L .71515 .61078 L F
.7185 .61014 m .71807 .61076 L .71515 .61078 L F
.391 .721 .989 r
.71515 .61078 m .71807 .61076 L .71712 .60999 L F
.978 .766 .549 r
.71875 .60979 m .71763 .61141 L .71712 .60999 L F
.391 .721 .989 r
.71807 .61076 m .71854 .61076 L .71712 .60999 L F
.978 .766 .549 r
.71811 .6108 m .71816 .61293 L .71763 .61141 L F
.71895 .60976 m .71859 .61119 L .71811 .6108 L F
.71859 .61119 m .71816 .61293 L .71811 .6108 L F
.71895 .60976 m .71763 .61141 L .71875 .60979 L F
.448 .047 .186 r
.7185 .61014 m .71854 .61076 L .71807 .61076 L F
.538 .378 .611 r
.72045 .60633 m .71842 .60863 L .71757 .60605 L F
.72045 .60633 m .72104 .60867 L .71842 .60863 L F
.72 .534 .638 r
.72104 .60867 m .72126 .61121 L .71895 .60976 L F
.864 .937 .867 r
.72126 .61121 m .71816 .61293 L .71895 .60976 L F
.72 .534 .638 r
.72104 .60867 m .71895 .60976 L .71854 .61076 L F
.893 .503 .278 r
.71854 .61076 m .71895 .60976 L .71875 .60979 L F
.71854 .61076 m .71875 .60979 L .71712 .60999 L F
.72 .534 .638 r
.719 .60864 m .71854 .61076 L .71842 .60863 L F
.72104 .60867 m .71854 .61076 L .719 .60864 L F
.544 0 0 r
.67819 .58412 m .67912 .58473 L .67658 .58474 L F
.67912 .58473 m .68042 .58559 L .67791 .58503 L F
.67912 .58473 m .67791 .58503 L .67658 .58474 L F
.798 .999 .843 r
.6809 .58366 m .68056 .58437 L .6816 .58377 L F
.68056 .58437 m .68003 .5855 L .6812 .58422 L F
.68056 .58437 m .6812 .58422 L .6816 .58377 L F
.667 .859 .973 r
.67864 .58443 m .68003 .5855 L .6809 .58366 L F
.235 0 0 r
.43356 .78509 m .43419 .78601 L .43205 .78626 L F
.43356 .78509 m .43569 .78471 L .43419 .78601 L F
0 0 0 r
.63509 .66548 m .63779 .66341 L .63645 .66464 L F
0 0 .078 r
.63921 .66241 m .63779 .66341 L .63952 .66045 L F
0 0 0 r
.63645 .66464 m .63779 .66341 L .63921 .66241 L F
.988 .741 .465 r
.67092 .60384 m .66984 .60562 L .66992 .6027 L F
.67092 .60384 m .67092 .60649 L .66984 .60562 L F
.969 .823 .645 r
.71564 .60422 m .71436 .60579 L .71422 .60367 L F
.71564 .60422 m .71534 .60677 L .71436 .60579 L F
.666 .535 .696 r
.71757 .60605 m .71534 .60677 L .71564 .60422 L F
0 0 0 r
.63509 .66548 m .63645 .66464 L .63436 .66747 L F
.699 .854 .957 r
.70147 .63587 m .70465 .63588 L .70357 .63487 L F
.853 .882 .859 r
.70357 .63487 m .70465 .63588 L .70683 .63343 L F
.033 0 0 r
.32719 .65128 m .32948 .65095 L .33123 .6504 L F
.257 0 .054 r
.42253 .74553 m .42181 .74423 L .42399 .74381 L F
.42253 .74553 m .42059 .74606 L .42181 .74423 L F
.778 .604 .664 r
.56474 .69288 m .56296 .69576 L .56154 .69243 L F
.776 .741 .821 r
.50884 .71748 m .50565 .71752 L .50761 .71647 L F
.63 .798 .963 r
.5111 .7169 m .50884 .71748 L .50761 .71647 L F
.065 0 0 r
.31614 .71441 m .3182 .71453 L .3197 .71458 L F
.133 0 0 r
.3182 .71453 m .3214 .71483 L .3197 .71458 L F
.369 .113 .388 r
.37671 .69516 m .37434 .69788 L .37464 .69561 L F
.599 .41 .598 r
.36495 .79278 m .36712 .79259 L .36714 .79019 L F
.452 .478 .795 r
.36714 .79019 m .36782 .78695 L .3663 .78685 L F
.36714 .79019 m .36892 .78978 L .36782 .78695 L F
.549 .437 .678 r
.36712 .79259 m .36892 .78978 L .36714 .79019 L F
.739 .216 0 r
.49958 .78225 m .49752 .78085 L .49828 .78135 L F
.81 .968 .658 r
.58039 .66268 m .58214 .65955 L .58269 .6599 L F
.56 .892 .641 r
.58013 .6624 m .57849 .66357 L .57905 .66309 L F
.58013 .6624 m .57905 .66309 L .58128 .6612 L F
.81 .968 .658 r
.58078 .66198 m .58013 .6624 L .58214 .65955 L F
.58039 .66268 m .58013 .6624 L .58078 .66198 L F
.493 .36 .627 r
.3741 .75814 m .376 .75778 L .37581 .75471 L F
.446 .353 .656 r
.37461 .7604 m .376 .75778 L .3741 .75814 L F
.991 .881 .562 r
.6526 .62157 m .65315 .62205 L .65379 .6202 L F
.852 .939 .568 r
.6526 .62157 m .65379 .6202 L .65419 .61853 L F
.562 .513 .758 r
.69541 .72228 m .6921 .72118 L .69498 .71769 L F
.631 .893 .571 r
.69498 .71769 m .69598 .71635 L .69669 .71886 L F
.003 0 .486 r
.69642 .72115 m .69498 .71769 L .69669 .71886 L F
.69642 .72115 m .69541 .72228 L .69498 .71769 L F
.909 .77 .695 r
.64963 .63901 m .64898 .63612 L .64835 .63832 L F
.947 .716 .557 r
.64956 .64137 m .64963 .63901 L .64835 .63832 L F
.501 .135 .276 r
.52179 .78136 m .52407 .78122 L .52479 .77912 L F
.194 0 .25 r
.52479 .77912 m .52669 .77868 L .52705 .77647 L F
.321 0 .207 r
.52479 .77912 m .52606 .7806 L .52669 .77868 L F
.52479 .77912 m .52407 .78122 L .52606 .7806 L F
.681 .522 .664 r
.59664 .6713 m .60009 .6715 L .59931 .66879 L F
.722 .546 .651 r
.59931 .66879 m .60009 .6715 L .60211 .67072 L F
.809 .64 .673 r
.5614 .69026 m .55949 .69268 L .55817 .68974 L F
.713 .499 .597 r
.56154 .69243 m .55949 .69268 L .5614 .69026 L F
.422 .48 .814 r
.38251 .66261 m .38233 .66572 L .38126 .66251 L F
.38251 .66261 m .38412 .66591 L .38233 .66572 L F
.492 .711 .968 r
.68861 .58733 m .68944 .58599 L .68765 .58607 L F
.68861 .58733 m .69098 .58715 L .68944 .58599 L F
.53 .358 .592 r
.68861 .58733 m .68936 .59024 L .69098 .58715 L F
.466 0 0 r
.68336 .6385 m .68561 .63967 L .68473 .63932 L F
.454 .77 .997 r
.68561 .63967 m .68751 .63866 L .68473 .63932 L F
.68561 .63967 m .68823 .63943 L .68751 .63866 L F
.572 .423 .641 r
.37247 .76548 m .3745 .76275 L .3725 .76317 L F
.996 .861 .541 r
.52014 .73078 m .51892 .7324 L .51984 .7331 L F
.799 .989 .886 r
.52119 .72854 m .52014 .73078 L .52253 .72977 L F
.52119 .72854 m .51961 .73025 L .52014 .73078 L F
.978 .897 .55 r
.51961 .73025 m .51892 .7324 L .52014 .73078 L F
.745 .69 .799 r
.56049 .69811 m .55732 .69779 L .55945 .69512 L F
.56049 .69811 m .55866 .69881 L .55732 .69779 L F
.719 .689 .82 r
.56296 .69576 m .56049 .69811 L .55945 .69512 L F
.745 .822 .912 r
.71554 .62241 m .71371 .62367 L .71241 .62238 L F
.688 .632 .788 r
.69669 .62748 m .69621 .62422 L .69746 .6257 L F
.759 .732 .827 r
.69928 .62332 m .69746 .6257 L .69621 .62422 L F
.732 .595 .703 r
.56454 .71158 m .5608 .71173 L .56299 .70909 L F
.585 .415 .617 r
.56311 .71367 m .5608 .71173 L .56454 .71158 L F
.748 .46 .494 r
.56454 .71158 m .56627 .71404 L .56311 .71367 L F
.857 .654 .628 r
.6921 .72118 m .69282 .72296 L .68999 .72191 L F
.867 .491 .331 r
.69263 .7243 m .68999 .72191 L .69282 .72296 L F
.562 .513 .758 r
.69541 .72228 m .69282 .72296 L .6921 .72118 L F
.722 .431 .484 r
.56722 .72584 m .56653 .72755 L .56471 .72529 L F
.554 .252 .41 r
.56884 .72696 m .56722 .72584 L .56879 .72492 L F
.56884 .72696 m .56653 .72755 L .56722 .72584 L F
.818 .86 .879 r
.68498 .63428 m .682 .63521 L .68372 .63287 L F
.698 .775 .911 r
.687 .63325 m .68498 .63428 L .68372 .63287 L F
.896 .807 .752 r
.72423 .60921 m .72126 .61121 L .72291 .60821 L F
.72423 .60921 m .72252 .61239 L .72126 .61121 L F
.839 .833 .841 r
.72633 .60667 m .72423 .60921 L .72291 .60821 L F
.683 .66 .821 r
.4981 .73506 m .50149 .73601 L .50015 .73295 L F
.638 .244 .281 r
.56471 .72529 m .56379 .72712 L .56099 .72527 L F
.506 0 0 r
.56099 .72527 m .56298 .72556 L .56471 .72529 L F
.833 .761 .783 r
.56471 .72529 m .56298 .72556 L .56528 .72173 L F
.79 .42 .356 r
.56471 .72529 m .56653 .72755 L .56379 .72712 L F
0 .495 .737 r
.65754 .61536 m .65989 .61576 L .65918 .61557 L F
.65754 .61536 m .65918 .61557 L .65707 .61639 L F
.746 .81 .903 r
.50311 .71784 m .50031 .71812 L .5023 .71712 L F
.588 .703 .922 r
.5042 .71605 m .50311 .71784 L .5023 .71712 L F
.5042 .71605 m .50565 .71752 L .50311 .71784 L F
.676 .654 .821 r
.51407 .73398 m .51576 .7363 L .51803 .73571 L F
.391 .031 .229 r
.53385 .78136 m .53662 .77974 L .53587 .78085 L F
.093 0 .035 r
.53587 .78085 m .53662 .77974 L .53827 .77882 L F
.493 .298 .544 r
.3831 .68936 m .38128 .68756 L .38355 .68734 L F
.3831 .68936 m .38113 .68985 L .38128 .68756 L F
.855 .772 .77 r
.71534 .60677 m .71215 .60849 L .71436 .60579 L F
.71534 .60677 m .71357 .60936 L .71215 .60849 L F
.711 .665 .803 r
.31636 .68407 m .31609 .68508 L .31246 .68475 L F
.372 0 .067 r
.31609 .68508 m .3125 .68701 L .31246 .68475 L F
.31609 .68508 m .31462 .68674 L .3125 .68701 L F
.525 .473 .741 r
.31775 .68426 m .31609 .68508 L .31636 .68407 L F
.283 0 .008 r
.31654 .68627 m .31609 .68508 L .31775 .68426 L F
.31654 .68627 m .31462 .68674 L .31609 .68508 L F
.893 .894 .822 r
.59203 .66751 m .59576 .6653 L .59428 .6643 L F
.59203 .66751 m .59323 .66846 L .59576 .6653 L F
.846 .884 .867 r
.59428 .6643 m .59576 .6653 L .59775 .66282 L F
.792 .688 .75 r
.56608 .68244 m .56236 .68408 L .5645 .68129 L F
.56608 .68244 m .56422 .68528 L .56236 .68408 L F
.458 .221 .466 r
.37434 .69788 m .37206 .70044 L .37236 .6983 L F
.535 .273 .465 r
.30602 .69013 m .30574 .69243 L .3028 .69249 L F
.564 .298 .471 r
.30771 .69207 m .30602 .69013 L .30818 .69 L F
.30771 .69207 m .30574 .69243 L .30602 .69013 L F
.818 .748 .786 r
.67364 .62541 m .6767 .62553 L .67619 .62466 L F
.67364 .62541 m .67715 .62627 L .6767 .62553 L F
.67364 .62541 m .67473 .62816 L .67715 .62627 L F
.892 .925 .537 r
.67619 .62466 m .67336 .62417 L .67364 .62541 L F
.876 .602 .078 r
.6758 .62207 m .67619 .62466 L .67654 .62491 L F
.763 .695 .787 r
.6758 .62207 m .6767 .62553 L .67902 .62294 L F
0 0 .462 r
.67713 .62311 m .67619 .62466 L .6758 .62207 L F
.892 .925 .537 r
.67619 .62466 m .67631 .62334 L .67336 .62417 L F
.67619 .62466 m .67506 .62625 L .67585 .62441 L F
.67619 .62466 m .67585 .62441 L .67631 .62334 L F
.876 .602 .078 r
.67654 .62491 m .67619 .62466 L .6767 .62553 L F
.711 .86 .953 r
.48667 .72182 m .48468 .72288 L .48339 .72199 L F
.071 0 0 r
.34668 .67378 m .3428 .67463 L .34457 .67416 L F
.436 .283 .575 r
.36789 .782 m .36983 .77924 L .36769 .77975 L F
.444 .034 .166 r
.42263 .72763 m .42488 .72741 L .42615 .72559 L F
.458 .076 .225 r
.42488 .72741 m .42816 .72521 L .42615 .72559 L F
.075 0 0 r
.32756 .73312 m .32642 .73302 L .32836 .7322 L F
.32756 .73312 m .32473 .73437 L .32642 .73302 L F
.718 .654 .785 r
.69125 .62776 m .68886 .62996 L .68775 .6272 L F
.524 .649 .914 r
.69254 .63142 m .68886 .62996 L .69125 .62776 L F
0 0 0 r
.36595 .65319 m .36541 .6531 L .36404 .65276 L F
.36595 .65319 m .3664 .65293 L .36541 .6531 L F
.9 .882 .807 r
.71481 .62599 m .71679 .62614 L .71591 .62553 L F
.626 .876 .988 r
.71679 .62614 m .71804 .62463 L .71591 .62553 L F
.71679 .62614 m .71897 .62536 L .71804 .62463 L F
.567 .44 .667 r
.37581 .75471 m .37772 .75185 L .37572 .75228 L F
.707 .231 0 r
.72093 .74125 m .71934 .7417 L .7189 .74008 L F
.239 .555 .932 r
.71934 .7417 m .72093 .74125 L .7189 .74008 L F
.71934 .7417 m .72161 .74243 L .72093 .74125 L F
.873 .929 .857 r
.57464 .67134 m .57591 .66808 L .57702 .66884 L F
.57464 .67134 m .57364 .67067 L .57591 .66808 L F
.801 .674 .724 r
.6273 .63012 m .62955 .62988 L .6272 .63358 L F
.579 .233 .346 r
.47743 .77033 m .47956 .77067 L .48066 .76849 L F
.669 .383 .479 r
.47956 .77067 m .48287 .76829 L .48066 .76849 L F
.387 .058 .281 r
.52669 .77868 m .52937 .77584 L .52705 .77647 L F
.414 0 0 r
.45938 .73592 m .45863 .73683 L .45593 .73656 L F
.292 0 0 r
.45938 .73592 m .46111 .73664 L .45863 .73683 L F
.45938 .73592 m .46166 .73651 L .46111 .73664 L F
.594 .021 0 r
.4975 .77764 m .49669 .77638 L .49509 .77636 L F
.4975 .77764 m .4988 .77746 L .49669 .77638 L F
.889 .9 .83 r
.57702 .66884 m .57807 .66533 L .57871 .66581 L F
.908 .981 .779 r
.57871 .66581 m .57807 .66533 L .58013 .6624 L F
.517 .471 .744 r
.3646 .67846 m .36718 .67855 L .36495 .67662 L F
.3659 .67863 m .36718 .67855 L .3646 .67846 L F
.36455 .67872 m .36658 .67893 L .36718 .67855 L F
.5 .48 .767 r
.36658 .67893 m .36691 .67825 L .36718 .67855 L F
.36691 .67825 m .36819 .67558 L .36718 .67855 L F
0 .298 .794 r
.36701 .67836 m .36718 .67855 L .36711 .67845 L F
.36495 .67662 m .36718 .67855 L .36701 .67836 L F
.36498 .67638 m .36711 .67845 L .36509 .67544 L F
.36495 .67662 m .36711 .67845 L .36498 .67638 L F
.5 .48 .767 r
.36691 .67825 m .36719 .67825 L .36819 .67558 L F
.689 .692 .847 r
.36711 .67845 m .36718 .67855 L .36819 .67558 L F
.5 .48 .767 r
.36727 .67861 m .36902 .67823 L .36691 .67825 L F
.689 .692 .847 r
.36509 .67544 m .36711 .67845 L .36819 .67558 L F
.5 .48 .767 r
.36719 .67825 m .36902 .67823 L .36819 .67558 L F
.36668 .67873 m .36727 .67861 L .36691 .67825 L F
.36658 .67893 m .36708 .67879 L .36668 .67873 L F
.36708 .67879 m .36902 .67823 L .36668 .67873 L F
.517 .471 .744 r
.36455 .67872 m .3659 .67863 L .3646 .67846 L F
.458 .317 .601 r
.36509 .68194 m .36658 .67893 L .36455 .67872 L F
.634 .091 0 r
.71502 .70733 m .71443 .70679 L .71134 .70592 L F
.609 .131 .094 r
.71707 .70815 m .71443 .70679 L .71502 .70733 L F
.453 .198 .436 r
.35844 .71188 m .35795 .71399 L .35599 .71442 L F
.459 .225 .471 r
.36028 .71129 m .35795 .71399 L .35844 .71188 L F
.607 .759 .952 r
.56877 .72266 m .56528 .72173 L .56767 .7193 L F
.733 .655 .772 r
.57086 .71974 m .56877 .72266 L .56767 .7193 L F
.641 .526 .707 r
.57086 .71974 m .57118 .72251 L .56877 .72266 L F
.628 .411 .569 r
.57118 .72251 m .56879 .72492 L .56877 .72266 L F
.525 .415 .672 r
.69391 .7119 m .69588 .71402 L .69578 .71186 L F
.804 .824 .866 r
.69728 .6392 m .69897 .6385 L .69851 .63581 L F
.774 .806 .878 r
.69851 .63581 m .69897 .6385 L .70147 .63587 L F
.693 .953 .953 r
.6646 .61269 m .66332 .61441 L .66535 .61311 L F
.651 .45 .599 r
.5915 .6983 m .58944 .7008 L .59016 .69862 L F
.5915 .6983 m .59172 .70076 L .58944 .7008 L F
.559 .479 .721 r
.52742 .72815 m .5257 .73071 L .52493 .72852 L F
.053 .365 .835 r
.5257 .73071 m .52619 .73001 L .52519 .72948 L F
.559 .479 .721 r
.52742 .72815 m .52782 .73032 L .5257 .73071 L F
.549 .572 .83 r
.52903 .73335 m .5257 .73071 L .52782 .73032 L F
.372 .227 .552 r
.52701 .73223 m .52619 .73001 L .5257 .73071 L F
.884 .82 .78 r
.51741 .73396 m .51984 .7331 L .51892 .7324 L F
.51741 .73396 m .51803 .73571 L .51984 .7331 L F
.66 .836 .968 r
.48795 .72985 m .48581 .73066 L .48913 .73079 L F
.536 .791 .991 r
.48795 .72985 m .48913 .73079 L .49011 .72947 L F
.463 .689 .964 r
.48913 .73079 m .49125 .73071 L .49011 .72947 L F
.794 .701 .762 r
.35931 .79775 m .35801 .80006 L .3608 .80088 L F
.983 .72 .444 r
.36068 .80369 m .3608 .80088 L .35801 .80006 L F
.552 .58 .836 r
.3608 .80088 m .36146 .79734 L .35931 .79775 L F
.3608 .80088 m .36319 .8012 L .36146 .79734 L F
0 .096 .653 r
.3608 .80088 m .3626 .8028 L .36319 .8012 L F
.43 .055 .224 r
.53155 .7756 m .53385 .77527 L .53521 .77268 L F
.575 .426 .641 r
.53521 .77268 m .53727 .77356 L .53695 .77126 L F
.843 .671 .669 r
.53385 .77527 m .53727 .77356 L .53521 .77268 L F
.597 .509 .726 r
.37136 .77123 m .37301 .76861 L .37058 .76817 L F
.37136 .77123 m .3736 .77093 L .37301 .76861 L F
.509 .33 .573 r
.37152 .77365 m .3736 .77093 L .37136 .77123 L F
.833 .999 .817 r
.58269 .6599 m .58454 .65699 L .58514 .65728 L F
.58269 .6599 m .58214 .65955 L .58454 .65699 L F
.624 .602 .808 r
.52167 .73841 m .52482 .73946 L .52367 .73622 L F
.032 0 0 r
.46318 .76906 m .46531 .76904 L .46644 .76861 L F
.364 .813 .681 r
.46644 .76861 m .46838 .76755 L .46857 .76818 L F
.46644 .76861 m .46531 .76904 L .46838 .76755 L F
.7 .515 .635 r
.59016 .69862 m .58581 .70058 L .58613 .69828 L F
.59016 .69862 m .58944 .7008 L .58581 .70058 L F
.276 .51 .899 r
.28769 .60319 m .28703 .60437 L .28585 .60369 L F
.28769 .60319 m .28932 .60543 L .28703 .60437 L F
.418 .541 .873 r
.3808 .8057 m .38181 .80723 L .38141 .80549 L F
.126 .311 .78 r
.38141 .80549 m .38181 .80723 L .38244 .80566 L F
0 0 0 r
.38181 .80723 m .38438 .80666 L .38244 .80566 L F
.805 .617 .647 r
.56299 .70909 m .55966 .70867 L .56 .7063 L F
.794 .693 .753 r
.56299 .70909 m .5608 .71173 L .55966 .70867 L F
.071 .633 .711 r
.3214 .71483 m .32268 .7147 L .32521 .71448 L F
.506 .852 .994 r
.32521 .71448 m .32583 .71344 L .32721 .71397 L F
.594 .937 .943 r
.32521 .71448 m .32268 .7147 L .32583 .71344 L F
.06 0 0 r
.2951 .67079 m .29806 .66854 L .29584 .67017 L F
.607 .487 .691 r
.37058 .76817 m .37301 .76861 L .37247 .76548 L F
.419 0 0 r
.52519 .72948 m .52119 .72854 L .52253 .72977 L F
.801 .674 .724 r
.6273 .63012 m .6272 .63358 L .62726 .63273 L F
.355 .201 .529 r
.62546 .63318 m .6273 .63012 L .62726 .63273 L F
.281 .011 .313 r
.62546 .63318 m .62726 .63273 L .62505 .63528 L F
.757 .768 .862 r
.56422 .68528 m .5609 .68523 L .56236 .68408 L F
.728 .439 .49 r
.36176 .79517 m .36352 .79534 L .36495 .79278 L F
.763 .576 .643 r
.36352 .79534 m .36712 .79259 L .36495 .79278 L F
.75 .576 .659 r
.59323 .66846 m .59462 .6714 L .59664 .6713 L F
.75 .575 .658 r
.59462 .6714 m .59471 .67385 L .59664 .6713 L F
.758 .586 .664 r
.59471 .67385 m .59801 .67442 L .59664 .6713 L F
.696 .559 .695 r
.59664 .6713 m .60002 .67373 L .60009 .6715 L F
.59664 .6713 m .59801 .67442 L .60002 .67373 L F
.801 .599 .629 r
.55667 .70125 m .55462 .70304 L .55475 .70075 L F
.55667 .70125 m .55629 .70357 L .55462 .70304 L F
.565 .924 .949 r
.43523 .77531 m .43481 .77542 L .4341 .77545 L F
.43481 .77542 m .43223 .77605 L .4341 .77545 L F
.566 .871 .995 r
.43152 .7753 m .4341 .77545 L .43223 .77605 L F
.064 0 0 r
.43299 .7755 m .4341 .77545 L .43152 .7753 L F
.43459 .77572 m .4341 .77545 L .43299 .7755 L F
.195 .721 .846 r
.4341 .77545 m .43469 .77543 L .43523 .77531 L F
.43469 .77543 m .43735 .77537 L .43523 .77531 L F
.327 .789 .663 r
.43625 .77509 m .43523 .77531 L .43674 .7749 L F
.4339 .77599 m .43523 .77531 L .43625 .77509 L F
.458 0 .027 r
.43523 .77531 m .43847 .7748 L .43674 .7749 L F
.698 .545 .676 r
.72025 .60377 m .72045 .60633 L .71757 .60605 L F
.579 .467 .69 r
.72263 .60339 m .72045 .60633 L .72025 .60377 L F
.588 .231 .331 r
.35633 .80477 m .35878 .80589 L .35692 .80272 L F
.35633 .80477 m .35546 .80767 L .35878 .80589 L F
.272 .32 .729 r
.36408 .68736 m .36542 .68656 L .36345 .68477 L F
.39 .294 .625 r
.36385 .68963 m .36542 .68656 L .36408 .68736 L F
.687 .617 .772 r
.51792 .7222 m .51553 .7228 L .51441 .71965 L F
.074 0 0 r
.51375 .78176 m .51598 .78011 L .51396 .78162 L F
.51375 .78176 m .51573 .78126 L .51598 .78011 L F
.122 0 0 r
.51598 .78011 m .51722 .78062 L .51911 .7807 L F
.51598 .78011 m .51573 .78126 L .51722 .78062 L F
.382 .843 .8 r
.35793 .6711 m .35679 .67131 L .35408 .67231 L F
.378 .841 .798 r
.35847 .67063 m .35793 .6711 L .35994 .67069 L F
.35847 .67063 m .35679 .67131 L .35793 .6711 L F
.819 .902 .899 r
.69719 .57529 m .69685 .57407 L .69761 .57474 L F
.69719 .57529 m .69619 .57464 L .69685 .57407 L F
.892 .884 .818 r
.69719 .57529 m .69465 .57636 L .69619 .57464 L F
.388 .143 .416 r
.36764 .70377 m .36728 .70615 L .36557 .70619 L F
.401 .167 .441 r
.37005 .70088 m .36982 .70347 L .36764 .70377 L F
.506 .244 .451 r
.36946 .70565 m .36764 .70377 L .36982 .70347 L F
.36946 .70565 m .36728 .70615 L .36764 .70377 L F
.849 .878 .861 r
.72052 .61394 m .72126 .61121 L .72252 .61239 L F
.72052 .61394 m .71861 .61416 L .72126 .61121 L F
.762 .394 .357 r
.72052 .61394 m .71951 .61632 L .71861 .61416 L F
.72052 .61394 m .72284 .61654 L .71951 .61632 L F
.798 .507 .497 r
.71527 .73774 m .71715 .73703 L .71703 .73552 L F
.71527 .73774 m .71812 .73857 L .71715 .73703 L F
.402 .168 .442 r
.37155 .70267 m .37005 .70088 L .37206 .70044 L F
.37155 .70267 m .36982 .70347 L .37005 .70088 L F
.84 .878 .44 r
.64062 .65901 m .64127 .65623 L .64009 .6595 L F
.595 .856 .509 r
.63952 .66045 m .6412 .65846 L .64062 .65901 L F
0 0 .019 r
.63952 .66045 m .64062 .65901 L .63921 .66241 L F
.84 .878 .44 r
.64062 .65901 m .64009 .6595 L .6397 .66057 L F
.595 .856 .509 r
.6412 .65846 m .64183 .6577 L .64062 .65901 L F
.924 .959 .785 r
.64423 .65516 m .6417 .65748 L .64183 .6577 L F
.732 .249 .094 r
.51306 .79089 m .51195 .79178 L .50979 .78979 L F
.593 .073 0 r
.51306 .79089 m .51529 .79216 L .51195 .79178 L F
.592 .069 0 r
.51666 .792 m .51529 .79216 L .51306 .79089 L F
.682 .735 .891 r
.71527 .73774 m .71616 .73934 L .71812 .73857 L F
.215 .716 .908 r
.45359 .72538 m .45569 .72532 L .45699 .72567 L F
.041 0 0 r
.45569 .72532 m .45907 .72519 L .45699 .72567 L F
.637 .518 .702 r
.64601 .61438 m .64701 .61718 L .64493 .61817 L F
0 0 0 r
.684 .57966 m .6797 .58315 L .6833 .57894 L F
.602 .874 .992 r
.6863 .57896 m .684 .57966 L .6833 .57894 L F
.578 .507 .739 r
.68733 .58093 m .684 .57966 L .6863 .57896 L F
.674 .525 .675 r
.38203 .74176 m .38212 .74415 L .38436 .74146 L F
.487 .572 .867 r
.36133 .6736 m .36171 .67081 L .35994 .67069 L F
.36133 .6736 m .36316 .67344 L .36171 .67081 L F
.543 .285 .475 r
.29994 .66796 m .30262 .66564 L .30053 .66619 L F
.748 .622 .719 r
.60009 .6715 m .60002 .67373 L .60211 .67072 L F
.801 .891 .472 r
.7336 .72164 m .73229 .72497 L .73321 .72322 L F
.512 .857 .994 r
.37856 .80376 m .37747 .80323 L .37485 .80373 L F
.779 .335 .194 r
.37575 .80338 m .37747 .80323 L .37518 .80079 L F
.433 .871 .898 r
.3766 .80316 m .37747 .80323 L .37575 .80338 L F
.37783 .80284 m .37747 .80323 L .3766 .80316 L F
.753 .687 .787 r
.37856 .80376 m .37834 .80331 L .37747 .80323 L F
.37834 .80331 m .37654 .79964 L .37747 .80323 L F
.37856 .80376 m .37889 .79998 L .37654 .79964 L F
.857 .715 .705 r
.52723 .73263 m .52903 .73335 L .52782 .73032 L F
.656 .763 .929 r
.52546 .73506 m .52934 .73533 L .52903 .73335 L F
.446 .353 .656 r
.37461 .7604 m .37631 .76 L .376 .75778 L F
.574 .45 .673 r
.3745 .76275 m .37631 .76 L .37461 .7604 L F
.399 .612 .936 r
.40646 .7726 m .40565 .77391 L .40474 .77253 L F
.142 .267 .734 r
.40646 .7726 m .40761 .77593 L .40565 .77391 L F
.881 .776 .741 r
.68004 .60313 m .67838 .60624 L .68086 .60624 L F
.824 .884 .887 r
.67838 .60624 m .67915 .60726 L .68086 .60624 L F
.142 0 0 r
.64631 .59205 m .64932 .58973 L .64688 .59088 L F
.474 .249 .492 r
.61654 .64436 m .61859 .64383 L .61636 .64644 L F
.306 0 .264 r
.53103 .78485 m .53385 .78136 L .5333 .78431 L F
.471 .19 .405 r
.53385 .78136 m .53542 .78389 L .5333 .78431 L F
.53385 .78136 m .53587 .78085 L .53542 .78389 L F
.68 .835 .958 r
.37401 .65512 m .37156 .65565 L .37084 .65518 L F
.602 .65 .87 r
.37456 .6565 m .37156 .65565 L .37401 .65512 L F
.668 .281 .304 r
.32899 .67894 m .32797 .67948 L .32597 .6789 L F
.351 0 0 r
.33085 .67875 m .32797 .67948 L .32899 .67894 L F
.483 .063 .167 r
.41504 .72831 m .41683 .72924 L .41823 .72739 L F
.557 .145 .217 r
.41683 .72924 m .42041 .72762 L .41823 .72739 L F
.629 .401 .553 r
.61253 .6896 m .60933 .6924 L .60953 .69066 L F
.758 .599 .68 r
.70537 .6122 m .7023 .61394 L .70369 .61201 L F
.553 0 0 r
.70582 .61246 m .70537 .6122 L .70369 .61201 L F
.758 .599 .68 r
.70537 .6122 m .70564 .61444 L .7023 .61394 L F
.061 .084 .571 r
.7073 .61239 m .70601 .61226 L .70771 .61173 L F
.12 0 0 r
.70738 .61202 m .70771 .61173 L .70689 .6119 L F
.061 .084 .571 r
.70601 .61226 m .70537 .6122 L .70689 .6119 L F
.12 0 0 r
.70614 .61213 m .70689 .6119 L .70537 .6122 L F
.061 .084 .571 r
.70601 .61226 m .70689 .6119 L .70771 .61173 L F
.12 0 0 r
.70738 .61202 m .70689 .6119 L .70614 .61213 L F
.553 0 0 r
.70582 .61246 m .70537 .6122 L .70369 .61201 L F
.504 .735 .977 r
.70623 .61036 m .70587 .61222 L .70346 .61225 L F
.12 0 0 r
.70639 .6123 m .70537 .6122 L .70582 .61246 L F
.504 .735 .977 r
.70584 .61233 m .70582 .61246 L .70559 .61244 L F
.061 .084 .571 r
.70683 .61315 m .70537 .6122 L .7073 .61239 L F
.504 .735 .977 r
.70587 .61222 m .70584 .61233 L .70553 .61232 L F
.061 .084 .571 r
.70552 .6123 m .70564 .61444 L .70537 .6122 L F
.66 .112 0 r
.70346 .61225 m .70566 .61244 L .70369 .61201 L F
.70566 .61244 m .70582 .61246 L .70563 .61242 L F
.70566 .61244 m .70563 .61242 L .70369 .61201 L F
.061 .084 .571 r
.70683 .61315 m .70656 .61344 L .70552 .6123 L F
.70656 .61344 m .70564 .61444 L .70552 .6123 L F
.66 .112 0 r
.70346 .61225 m .70582 .61246 L .70369 .61201 L F
.504 .735 .977 r
.70587 .61222 m .70553 .61232 L .70346 .61225 L F
.70584 .61233 m .70559 .61244 L .70346 .61225 L F
.12 0 0 r
.70738 .61202 m .70537 .6122 L .70639 .6123 L F
.562 .301 .478 r
.5993 .69535 m .59681 .69792 L .59725 .69526 L F
.186 0 0 r
.46487 .73595 m .46392 .73638 L .46166 .73651 L F
.056 0 0 r
.46693 .7355 m .46392 .73638 L .46487 .73595 L F
.386 .024 .223 r
.36657 .70774 m .36557 .70619 L .36728 .70615 L F
.36657 .70774 m .36451 .70816 L .36557 .70619 L F
.778 .589 .643 r
.56015 .70383 m .56 .7063 L .55832 .70339 L F
0 0 .517 r
.4851 .77043 m .48615 .7717 L .48483 .77021 L F
.798 .482 .453 r
.48327 .77245 m .48615 .7717 L .4851 .77043 L F
.48327 .77245 m .48632 .77347 L .48615 .7717 L F
.368 .703 .985 r
.41299 .77882 m .41226 .77995 L .41081 .779 L F
.41299 .77882 m .41453 .78003 L .41226 .77995 L F
.659 .44 .576 r
.70244 .70582 m .70456 .7034 L .70269 .70399 L F
0 0 0 r
.53996 .7758 m .53845 .77659 L .5407 .77392 L F
.132 .003 .424 r
.53976 .77781 m .53845 .77659 L .53996 .7758 L F
.53976 .77781 m .53827 .77882 L .53845 .77659 L F
.875 .74 .709 r
.59006 .67039 m .59323 .66846 L .59203 .66751 L F
.59006 .67039 m .59151 .67096 L .59323 .66846 L F
.774 .585 .643 r
.59151 .67096 m .59462 .6714 L .59323 .66846 L F
.385 0 0 r
.71707 .70815 m .7201 .70907 L .71791 .70824 L F
.506 .034 .067 r
.3028 .69249 m .30055 .69275 L .3005 .69273 L F
.545 .258 .431 r
.3028 .69249 m .30036 .69508 L .30055 .69275 L F
.3028 .69249 m .30262 .69499 L .30036 .69508 L F
.363 .113 .394 r
.3044 .69418 m .3028 .69249 L .30574 .69243 L F
.3044 .69418 m .30262 .69499 L .3028 .69249 L F
0 0 0 r
.63466 .6051 m .6361 .60409 L .63263 .60575 L F
.603 .296 .423 r
.63466 .6051 m .63728 .60279 L .6361 .60409 L F
.036 0 0 r
.40892 .79225 m .40594 .79297 L .40691 .79246 L F
.672 .153 0 r
.70698 .73147 m .70691 .73098 L .70584 .73079 L F
.70698 .73147 m .7082 .73242 L .70691 .73098 L F
.854 .95 .595 r
.52493 .72852 m .52656 .72512 L .52742 .72815 L F
.52493 .72852 m .52469 .7289 L .52656 .72512 L F
.913 .837 .38 r
.54043 .77339 m .5407 .77392 L .54103 .77081 L F
.911 .826 .363 r
.53996 .7758 m .5407 .77392 L .54043 .77339 L F
.395 .029 .22 r
.31218 .66004 m .31432 .65962 L .31541 .65746 L F
.232 0 .135 r
.31541 .65746 m .3161 .65892 L .31722 .65677 L F
.31541 .65746 m .31432 .65962 L .3161 .65892 L F
.764 .731 .822 r
.69321 .58488 m .69098 .58715 L .69409 .58754 L F
.719 .706 .837 r
.69321 .58488 m .69409 .58754 L .69613 .58609 L F
.583 .314 .474 r
.61063 .63295 m .61303 .6328 L .6137 .63011 L F
.526 .26 .454 r
.61538 .63237 m .6137 .63011 L .61303 .6328 L F
.61538 .63237 m .6158 .62976 L .6137 .63011 L F
.584 .592 .826 r
.56206 .72184 m .56099 .72527 L .55995 .72432 L F
.56206 .72184 m .56298 .72556 L .56099 .72527 L F
.454 0 0 r
.56099 .72527 m .56252 .72644 L .55995 .72432 L F
.56099 .72527 m .56379 .72712 L .56252 .72644 L F
.954 .853 .431 r
.6696 .61213 m .66896 .61349 L .66939 .61078 L F
.6696 .61213 m .66924 .61445 L .66896 .61349 L F
.891 .918 .524 r
.73115 .72649 m .73229 .72497 L .73211 .72482 L F
.73115 .72649 m .73098 .72806 L .73229 .72497 L F
.801 .891 .472 r
.7336 .72164 m .73211 .72482 L .73229 .72497 L F
.725 .637 .76 r
.52052 .72212 m .517 .71892 L .51894 .71834 L F
.52052 .72212 m .51792 .7222 L .517 .71892 L F
.591 .627 .856 r
.52102 .71798 m .52052 .72212 L .51894 .71834 L F
.52102 .71798 m .52305 .72171 L .52052 .72212 L F
.537 .107 .171 r
.47652 .77668 m .47519 .77841 L .47311 .77806 L F
.575 .149 .196 r
.47839 .77793 m .47519 .77841 L .47652 .77668 L F
.567 .161 .231 r
.47652 .77668 m .47878 .7769 L .47839 .77793 L F
.768 .767 .852 r
.50687 .73777 m .51069 .73689 L .50901 .7357 L F
.672 .521 .671 r
.58581 .70058 m .58393 .70114 L .58613 .69828 L F
.564 .39 .605 r
.37518 .80079 m .37747 .80323 L .37654 .79964 L F
0 0 0 r
.37723 .79914 m .37518 .80079 L .37654 .79964 L F
.67 .607 .776 r
.37387 .79783 m .37518 .80079 L .37723 .79914 L F
.779 .335 .194 r
.37575 .80338 m .37518 .80079 L .37485 .80373 L F
.38 0 .123 r
.35372 .717 m .35247 .71878 L .35039 .7191 L F
.458 .234 .485 r
.35599 .71442 m .35569 .71655 L .35372 .717 L F
.318 0 .086 r
.35447 .71831 m .35372 .717 L .35569 .71655 L F
.35447 .71831 m .35247 .71878 L .35372 .717 L F
.875 .781 .755 r
.70533 .63264 m .70683 .63343 L .70612 .63062 L F
.853 .882 .859 r
.70357 .63487 m .70683 .63343 L .70533 .63264 L F
.731 .701 .823 r
.70612 .63062 m .70683 .63343 L .70908 .63124 L F
.491 .052 .132 r
.667 .61072 m .66779 .60981 L .66775 .60911 L F
0 0 0 r
.667 .61072 m .66775 .60911 L .66926 .60774 L F
.738 .676 .79 r
.53105 .73307 m .53239 .73604 L .52934 .73533 L F
.287 0 .252 r
.53041 .73784 m .53127 .73708 L .52934 .73533 L F
.335 .279 .645 r
.53153 .73732 m .53127 .73708 L .53239 .73604 L F
.53127 .73708 m .52934 .73533 L .53139 .7358 L F
.53127 .73708 m .53139 .7358 L .53239 .73604 L F
.287 0 .252 r
.53127 .73708 m .5312 .73781 L .53231 .73616 L F
.53041 .73784 m .5312 .73781 L .53127 .73708 L F
.335 .279 .645 r
.5312 .73781 m .53052 .73811 L .53041 .73784 L F
.53052 .73811 m .52944 .73857 L .52934 .73533 L F
0 0 0 r
.52933 .73879 m .52944 .73857 L .5312 .73781 L F
.287 0 .252 r
.52933 .73879 m .5312 .73781 L .53041 .73784 L F
.335 .279 .645 r
.5312 .73781 m .53041 .73784 L .52934 .73533 L F
.287 0 .252 r
.52933 .73879 m .53041 .73784 L .52934 .73533 L F
.53127 .73708 m .53231 .73616 L .52934 .73533 L F
.335 .279 .645 r
.5312 .73781 m .52934 .73533 L .53153 .73732 L F
.209 .37 .807 r
.53105 .73307 m .53338 .73494 L .53239 .73604 L F
.523 .327 .557 r
.53338 .73494 m .5312 .73781 L .53239 .73604 L F
.709 .692 .832 r
.49818 .73368 m .4981 .73506 L .50015 .73295 L F
.758 .644 .736 r
.5925 .6762 m .59611 .67667 L .59471 .67385 L F
.743 .504 .568 r
.5925 .6762 m .59699 .67846 L .59611 .67667 L F
.745 .639 .743 r
.59471 .67385 m .59611 .67667 L .59801 .67442 L F
.606 .407 .587 r
.59699 .67846 m .59803 .67873 L .59611 .67667 L F
.558 .301 .482 r
.31119 .68763 m .31058 .68971 L .30818 .69 L F
.161 0 .305 r
.31199 .68883 m .31119 .68763 L .3125 .68701 L F
.31199 .68883 m .31058 .68971 L .31119 .68763 L F
.338 .764 .974 r
.71673 .71618 m .71864 .71564 L .71668 .71575 L F
.71673 .71618 m .71901 .71613 L .71864 .71564 L F
.697 .777 .913 r
.69055 .63859 m .69144 .64044 L .69404 .63908 L F
.901 .729 .659 r
.71357 .60936 m .71336 .61177 L .71215 .60849 L F
.464 .34 .626 r
.71515 .61078 m .71336 .61177 L .71357 .60936 L F
.742 .395 .394 r
.70697 .71197 m .70384 .71342 L .70472 .71108 L F
.468 .242 .488 r
.35769 .71585 m .35599 .71442 L .35795 .71399 L F
.35769 .71585 m .35569 .71655 L .35599 .71442 L F
.68 .835 .958 r
.37401 .65512 m .37084 .65518 L .37286 .65414 L F
.593 .783 .971 r
.37626 .65471 m .37401 .65512 L .37286 .65414 L F
0 .203 .73 r
.3753 .65545 m .37401 .65512 L .37626 .65471 L F
.3753 .65545 m .37611 .65729 L .37401 .65512 L F
.296 .33 .727 r
.37401 .65512 m .37611 .65729 L .37456 .6565 L F
.718 .711 .843 r
.31283 .71243 m .31408 .71504 L .31073 .71452 L F
.655 .68 .862 r
.31614 .71441 m .31408 .71504 L .31283 .71243 L F
.847 .998 .811 r
.58514 .65728 m .58683 .65446 L .58718 .6545 L F
.58514 .65728 m .58454 .65699 L .58683 .65446 L F
.889 .9 .83 r
.57702 .66884 m .57591 .66808 L .57807 .66533 L F
0 0 0 r
.46467 .72536 m .46683 .72505 L .46797 .72479 L F
.164 0 0 r
.46683 .72505 m .47019 .72429 L .46797 .72479 L F
.839 .754 .768 r
.69669 .62748 m .69476 .63056 L .69671 .62936 L F
.202 0 0 r
.47019 .72429 m .4723 .72448 L .47352 .7243 L F
.457 .127 .318 r
.4723 .72448 m .47515 .72278 L .47352 .7243 L F
.618 .632 .842 r
.58639 .70231 m .58393 .70114 L .58581 .70058 L F
.496 .285 .523 r
.58639 .70231 m .58614 .7052 L .58397 .70527 L F
.602 .391 .568 r
.58944 .7008 m .58639 .70231 L .58581 .70058 L F
.58944 .7008 m .58943 .70285 L .58639 .70231 L F
.598 .369 .54 r
.58943 .70285 m .58614 .7052 L .58639 .70231 L F
.327 .789 .663 r
.4339 .77599 m .43336 .77621 L .43523 .77531 L F
.924 .959 .785 r
.64423 .65516 m .64353 .65451 L .6417 .65748 L F
.835 .86 .864 r
.64423 .65516 m .64541 .6517 L .64353 .65451 L F
.64423 .65516 m .64662 .65284 L .64541 .6517 L F
.331 .74 .98 r
.28375 .60369 m .28325 .60371 L .28101 .60302 L F
.825 .679 .702 r
.72389 .60486 m .72633 .60667 L .72346 .60608 L F
.839 .833 .841 r
.72633 .60667 m .72291 .60821 L .72346 .60608 L F
.273 .584 .944 r
.72389 .60486 m .72691 .60605 L .72633 .60667 L F
.805 .405 0 r
.72691 .60605 m .72817 .60839 L .72633 .60667 L F
.41 .53 .867 r
.72872 .6108 m .73044 .61359 L .72731 .61246 L F
.256 .671 .965 r
.6789 .59764 m .67676 .59746 L .67593 .59667 L F
.763 .695 .787 r
.6758 .62207 m .67902 .62294 L .67819 .62124 L F
.622 .741 .932 r
.70335 .61721 m .69952 .61654 L .7023 .61394 L F
.748 .643 .744 r
.7023 .61394 m .70564 .61444 L .70335 .61721 L F
.668 .522 .677 r
.70564 .61444 m .70553 .61656 L .70335 .61721 L F
.742 .606 .706 r
.70553 .61656 m .70314 .61956 L .70335 .61721 L F
.475 .011 .072 r
.33694 .71088 m .3392 .71098 L .34073 .70944 L F
.227 0 0 r
.34073 .70944 m .34121 .71053 L .34196 .70987 L F
.34073 .70944 m .3392 .71098 L .34121 .71053 L F
.278 0 0 r
.34073 .70944 m .34196 .70987 L .34299 .70922 L F
.86 .721 .708 r
.55966 .70867 m .5608 .71173 L .55904 .71126 L F
.755 .639 .732 r
.56073 .71413 m .55904 .71126 L .5608 .71173 L F
.585 .415 .617 r
.56311 .71367 m .56073 .71413 L .5608 .71173 L F
.98 .69 .326 r
.7224 .61874 m .72335 .61965 L .72297 .61745 L F
.72297 .61745 m .7224 .61874 L .72284 .61654 L F
.72297 .61745 m .72335 .61965 L .7224 .61874 L F
.81 .761 .807 r
.50015 .73295 m .50346 .73155 L .50235 .73024 L F
.623 .746 .935 r
.50346 .73155 m .5045 .72985 L .50235 .73024 L F
.50346 .73155 m .50564 .73104 L .5045 .72985 L F
.778 .807 .876 r
.49783 .71981 m .49457 .71993 L .49642 .71882 L F
.778 .83 .893 r
.50031 .71812 m .49783 .71981 L .49642 .71882 L F
.248 0 .285 r
.29248 .62182 m .29087 .62262 L .2932 .61985 L F
.261 0 .291 r
.29416 .62093 m .2932 .61985 L .29475 .61922 L F
.29416 .62093 m .29248 .62182 L .2932 .61985 L F
.196 .69 .919 r
.45907 .72519 m .46123 .72524 L .46256 .72572 L F
.261 .752 .915 r
.46123 .72524 m .46467 .72536 L .46256 .72572 L F
.525 .2 .36 r
.43515 .74126 m .43396 .74372 L .43177 .74386 L F
.576 .233 .351 r
.43709 .74178 m .43396 .74372 L .43515 .74126 L F
.998 .806 .458 r
.62834 .64943 m .62751 .64862 L .62778 .64634 L F
.936 .945 .77 r
.62583 .65127 m .62834 .64943 L .62815 .65184 L F
.62583 .65127 m .62751 .64862 L .62834 .64943 L F
.436 .283 .575 r
.36789 .782 m .36978 .78159 L .36983 .77924 L F
.521 .392 .645 r
.36789 .782 m .3701 .78407 L .36978 .78159 L F
.36789 .782 m .36813 .78448 L .3701 .78407 L F
.249 .76 .85 r
.35153 .6512 m .35362 .65085 L .35422 .65086 L F
.35364 .65101 m .35422 .65086 L .35513 .65089 L F
.35153 .6512 m .35422 .65086 L .35364 .65101 L F
.487 0 0 r
.34965 .65043 m .35277 .65124 L .35087 .6512 L F
.35277 .65124 m .35285 .65126 L .35271 .65126 L F
.35277 .65124 m .35271 .65126 L .35087 .6512 L F
.18 0 .262 r
.29029 .62462 m .28813 .62738 L .28885 .62543 L F
.577 .591 .83 r
.38747 .66841 m .38544 .6689 L .38412 .66591 L F
.562 .353 .555 r
.58397 .70527 m .58214 .70828 L .58169 .70609 L F
.58397 .70527 m .58446 .70826 L .58214 .70828 L F
.559 .351 .555 r
.58735 .7075 m .58397 .70527 L .58614 .7052 L F
.58735 .7075 m .58446 .70826 L .58397 .70527 L F
.638 .221 .235 r
.43847 .7748 m .4407 .7754 L .4421 .77368 L F
.419 0 .063 r
.4407 .7754 m .44431 .77368 L .4421 .77368 L F
.529 .763 .983 r
.35724 .65058 m .35644 .65209 L .35513 .65089 L F
.35724 .65058 m .35849 .65172 L .35644 .65209 L F
.406 .624 .941 r
.70791 .61465 m .70564 .61444 L .70683 .61315 L F
.671 .67 .841 r
.70791 .61465 m .70553 .61656 L .70564 .61444 L F
.653 .567 .745 r
.51441 .71965 m .51219 .72024 L .5111 .7169 L F
.336 .13 .444 r
.63728 .60279 m .63925 .59978 L .63791 .60096 L F
.345 .146 .461 r
.3663 .78685 m .36782 .78695 L .36813 .78448 L F
.739 .485 .545 r
.70457 .70574 m .70736 .7037 L .70456 .7034 L F
.70457 .70574 m .70793 .70603 L .70736 .7037 L F
.535 .22 .382 r
.72192 .73164 m .72331 .73082 L .72227 .73259 L F
.72192 .73164 m .72402 .73194 L .72425 .73033 L F
.988 .722 .365 r
.72425 .73033 m .72402 .73194 L .72395 .73173 L F
.088 0 .174 r
.72331 .73082 m .72425 .73033 L .72459 .7288 L F
.535 .22 .382 r
.72192 .73164 m .72425 .73033 L .72331 .73082 L F
.988 .722 .365 r
.72425 .73033 m .72395 .73173 L .72303 .7289 L F
.088 0 .174 r
.72459 .7288 m .72425 .73033 L .72502 .72811 L F
.962 .71 .51 r
.72502 .72811 m .72425 .73033 L .72356 .72736 L F
.72502 .72811 m .72425 .73033 L .72356 .72736 L F
.604 .442 .635 r
.36951 .77657 m .37206 .77887 L .37173 .77606 L F
.36951 .77657 m .36983 .77924 L .37206 .77887 L F
.694 .162 0 r
.66896 .61349 m .66922 .61457 L .66759 .6125 L F
.606 .757 .95 r
.66922 .61457 m .66978 .61404 L .66771 .61232 L F
.66978 .61404 m .67085 .61301 L .66913 .61263 L F
.968 .814 .636 r
.66939 .61078 m .66896 .61349 L .66759 .6125 L F
.606 .757 .95 r
.66978 .61404 m .66913 .61263 L .66771 .61232 L F
0 0 .375 r
.66924 .61445 m .67058 .61578 L .66896 .61349 L F
.67058 .61578 m .67067 .61587 L .67053 .61568 L F
.67058 .61578 m .67053 .61568 L .66896 .61349 L F
.66924 .61445 m .66961 .61703 L .67067 .61587 L F
.719 .962 .695 r
.58718 .6545 m .58918 .65197 L .58948 .6519 L F
.58718 .6545 m .58683 .65446 L .58918 .65197 L F
.525 .473 .741 r
.31775 .68426 m .31636 .68407 L .31808 .68259 L F
.121 0 0 r
.41487 .7905 m .41314 .79124 L .41099 .79149 L F
.769 .638 .717 r
.70314 .61956 m .70456 .62268 L .70126 .62222 L F
.739 .626 .733 r
.70671 .61987 m .70456 .62268 L .70314 .61956 L F
.341 0 0 r
.4975 .77764 m .50071 .77816 L .4988 .77746 L F
.463 .348 .637 r
.28813 .62738 m .28696 .62779 L .28641 .62798 L F
.282 .168 .541 r
.28696 .62779 m .28651 .6304 L .28641 .62798 L F
.423 .137 .373 r
.35927 .69239 m .36117 .69196 L .36163 .69 L F
.546 .249 .415 r
.36163 .69 m .36363 .69164 L .36385 .68963 L F
.36163 .69 m .36117 .69196 L .36363 .69164 L F
.742 .606 .706 r
.70553 .61656 m .70671 .61987 L .70314 .61956 L F
.711 .59 .718 r
.70889 .61714 m .70671 .61987 L .70553 .61656 L F
.489 .288 .533 r
.70929 .61953 m .70671 .61987 L .70889 .61714 L F
.487 .273 .513 r
.38436 .74146 m .38212 .74415 L .38412 .74371 L F
.47 .258 .509 r
.38436 .74146 m .38607 .74324 L .38649 .74118 L F
.38436 .74146 m .38412 .74371 L .38607 .74324 L F
0 .166 .704 r
.36495 .67662 m .36509 .67544 L .36316 .67344 L F
0 .291 .779 r
.73151 .71397 m .73339 .71597 L .73063 .71398 L F
.635 .074 0 r
.72738 .71705 m .72637 .71674 L .72427 .71516 L F
.972 .659 .32 r
.72739 .71925 m .72637 .71674 L .72738 .71705 L F
.546 .086 .113 r
.49096 .77819 m .48975 .77906 L .4875 .77881 L F
.735 .337 .297 r
.49096 .77819 m .49242 .77946 L .48975 .77906 L F
.899 .714 .644 r
.62899 .65423 m .62704 .6547 L .62815 .65184 L F
.873 .978 .843 r
.62899 .65423 m .62586 .65644 L .62704 .6547 L F
.62899 .65423 m .62652 .6568 L .62586 .65644 L F
.511 0 0 r
.51063 .77988 m .51375 .78176 L .51396 .78162 L F
.535 .851 .552 r
.51375 .78176 m .51269 .78274 L .51396 .78162 L F
.51375 .78176 m .51269 .78274 L .51396 .78162 L F
.579 .467 .69 r
.72263 .60339 m .72346 .60608 L .72045 .60633 L F
.643 .443 .597 r
.72291 .60821 m .72045 .60633 L .72346 .60608 L F
.72291 .60821 m .72104 .60867 L .72045 .60633 L F
.646 .456 .612 r
.57532 .71715 m .57336 .71948 L .57302 .717 L F
.57532 .71715 m .57647 .7197 L .57336 .71948 L F
.527 .338 .568 r
.57754 .71441 m .57819 .71671 L .57532 .71715 L F
.72 .488 .574 r
.57872 .71936 m .57532 .71715 L .57819 .71671 L F
.57872 .71936 m .57647 .7197 L .57532 .71715 L F
.176 0 0 r
.33656 .72869 m .33624 .72764 L .33817 .72695 L F
.33656 .72869 m .33467 .72921 L .33624 .72764 L F
.578 .442 .659 r
.35723 .69538 m .35944 .69522 L .35927 .69239 L F
.484 .294 .547 r
.35723 .69538 m .35911 .69725 L .35944 .69522 L F
.35723 .69538 m .35721 .69774 L .35911 .69725 L F
.547 .368 .59 r
.37765 .7495 m .37976 .74913 L .37979 .74676 L F
.561 .403 .624 r
.37772 .75185 m .37976 .74913 L .37765 .7495 L F
.481 .013 .067 r
.42816 .72521 m .43047 .72539 L .43144 .72459 L F
.334 0 0 r
.43047 .72539 m .43363 .72467 L .43144 .72459 L F
.687 .617 .772 r
.51792 .7222 m .51441 .71965 L .517 .71892 L F
.215 .126 .533 r
.29798 .60837 m .29653 .61171 L .29584 .60937 L F
.29798 .60837 m .29807 .6106 L .29653 .61171 L F
.415 .336 .66 r
.29807 .6106 m .29662 .61383 L .29653 .61171 L F
.676 .654 .821 r
.51407 .73398 m .51803 .73571 L .51741 .73396 L F
.195 0 .26 r
.38149 .80462 m .3808 .8057 L .38141 .80549 L F
.365 0 0 r
.43915 .7245 m .44127 .72467 L .44264 .72405 L F
.436 0 0 r
.44264 .72405 m .44127 .72467 L .44468 .72441 L F
.533 0 0 r
.65981 .58721 m .66293 .58886 L .66288 .58809 L F
.14 0 0 r
.66288 .58809 m .6644 .58841 L .66544 .58929 L F
0 .324 .755 r
.72862 .71229 m .72683 .71162 L .72581 .71097 L F
.72862 .71229 m .72971 .71316 L .72683 .71162 L F
.708 .792 .916 r
.69404 .63908 m .69728 .6392 L .69591 .63799 L F
.804 .824 .866 r
.69728 .6392 m .69851 .63581 L .69591 .63799 L F
.251 .324 .745 r
.67658 .611 m .67758 .61458 L .67609 .61216 L F
.483 .261 .501 r
.38212 .74415 m .38182 .74637 L .38412 .74371 L F
.725 .639 .762 r
.50564 .73104 m .50917 .73298 L .508 .7302 L F
.50564 .73104 m .50682 .73381 L .50917 .73298 L F
.715 .502 .599 r
.50682 .73381 m .50901 .7357 L .50917 .73298 L F
.516 .374 .626 r
.50917 .73298 m .51116 .73042 L .508 .7302 L F
.50917 .73298 m .51114 .73285 L .51116 .73042 L F
.798 .667 .719 r
.50901 .7357 m .51114 .73285 L .50917 .73298 L F
.619 .426 .6 r
.50435 .73631 m .5069 .7361 L .50682 .73381 L F
.715 .502 .599 r
.50682 .73381 m .5069 .7361 L .50901 .7357 L F
.739 .637 .746 r
.58169 .70609 m .57989 .70854 L .57933 .70605 L F
.637 .494 .671 r
.58214 .70828 m .57989 .70854 L .58169 .70609 L F
.59 .459 .67 r
.58214 .70828 m .58105 .70981 L .57989 .70854 L F
.665 .626 .8 r
.52367 .73622 m .52482 .73946 L .52683 .73846 L F
.63 .763 .942 r
.29373 .60986 m .29038 .60935 L .29249 .60911 L F
.516 .8 .997 r
.29462 .60869 m .29373 .60986 L .29249 .60911 L F
.29462 .60869 m .29584 .60937 L .29373 .60986 L F
.246 .761 .794 r
.41453 .78003 m .41601 .77963 L .41796 .7794 L F
.265 .773 .803 r
.41796 .7794 m .41881 .77901 L .41992 .7788 L F
.41796 .7794 m .41601 .77963 L .41881 .77901 L F
.297 0 0 r
.50728 .78039 m .51063 .77988 L .50721 .7794 L F
.50728 .78039 m .50983 .78051 L .51063 .77988 L F
.692 .187 .036 r
.50983 .78051 m .51375 .78176 L .51063 .77988 L F
.342 .807 .709 r
.48448 .73112 m .48372 .73157 L .48581 .73066 L F
.48448 .73112 m .48223 .73213 L .48372 .73157 L F
.543 .061 .061 r
.44053 .74159 m .43924 .7429 L .43709 .74178 L F
.494 .08 .184 r
.4427 .74099 m .43924 .7429 L .44053 .74159 L F
.06 0 0 r
.2951 .67079 m .29665 .6703 L .29806 .66854 L F
.254 0 .017 r
.29806 .66854 m .29865 .66972 L .29994 .66796 L F
.29806 .66854 m .29665 .6703 L .29865 .66972 L F
.783 .6 .654 r
.59132 .67357 m .59462 .6714 L .59151 .67096 L F
.59132 .67357 m .59471 .67385 L .59462 .6714 L F
.585 .874 .994 r
.35625 .81109 m .35752 .81169 L .35421 .8119 L F
.35625 .81109 m .35752 .81169 L .35421 .8119 L F
.524 .26 .457 r
.35542 .6985 m .35699 .70012 L .35721 .69774 L F
.35542 .6985 m .35476 .70058 L .35699 .70012 L F
.142 0 0 r
.64631 .59205 m .64794 .59153 L .64932 .58973 L F
.232 0 .003 r
.64932 .58973 m .64794 .59153 L .65142 .58952 L F
.671 .67 .841 r
.70791 .61465 m .70889 .61714 L .70553 .61656 L F
0 0 0 r
.70683 .61315 m .70771 .61173 L .7093 .61044 L F
.7093 .61044 m .70771 .61173 L .70738 .61202 L F
.748 .71 .816 r
.71093 .6151 m .70889 .61714 L .70791 .61465 L F
.631 .166 .131 r
.70889 .61714 m .71126 .61941 L .70929 .61953 L F
.62 .593 .802 r
.70889 .61714 m .71045 .61821 L .71116 .61815 L F
.71045 .61821 m .7121 .61934 L .71116 .61815 L F
.136 0 .15 r
.71219 .61806 m .71116 .61815 L .71346 .61621 L F
.71126 .61941 m .71116 .61815 L .71219 .61806 L F
.631 .166 .131 r
.70889 .61714 m .71116 .61815 L .71126 .61941 L F
.605 .204 .257 r
.48201 .7765 m .47839 .77793 L .47878 .7769 L F
.48201 .7765 m .48072 .77837 L .47839 .77793 L F
.755 .385 .353 r
.48201 .7765 m .48408 .77898 L .48072 .77837 L F
.778 .375 .29 r
.48546 .77843 m .48408 .77898 L .48201 .7765 L F
.53 .134 .235 r
.3005 .69273 m .30055 .69275 L .30048 .69276 L F
0 .399 .767 r
.42626 .77581 m .42717 .77637 L .42622 .77607 L F
.567 .44 .667 r
.37581 .75471 m .37804 .75461 L .37772 .75185 L F
.5 .365 .628 r
.37581 .75471 m .37791 .75659 L .37804 .75461 L F
.37581 .75471 m .376 .75778 L .37791 .75659 L F
.906 .711 .629 r
.56627 .71404 m .56751 .71707 L .56618 .71565 L F
.754 .559 .632 r
.56751 .71707 m .56425 .71906 L .56618 .71565 L F
.56751 .71707 m .56767 .7193 L .56425 .71906 L F
.741 .631 .738 r
.57112 .71771 m .56767 .7193 L .56751 .71707 L F
.603 .933 .724 r
.38548 .80124 m .38884 .79876 L .38689 .79984 L F
.639 .948 .735 r
.38689 .79984 m .39035 .79739 L .38922 .79791 L F
.096 0 0 r
.38938 .79787 m .39167 .79729 L .39126 .79741 L F
.639 .948 .735 r
.38988 .79772 m .39003 .79768 L .39035 .79739 L F
.096 0 0 r
.38922 .79791 m .39035 .79739 L .3923 .79713 L F
.683 .945 .671 r
.39059 .79747 m .39043 .79766 L .39126 .79741 L F
0 0 .131 r
.38972 .79854 m .38922 .79791 L .39126 .79741 L F
.683 .945 .671 r
.39043 .79766 m .38972 .79854 L .39126 .79741 L F
.096 0 0 r
.39167 .79729 m .3923 .79713 L .39126 .79741 L F
.38922 .79791 m .38942 .79785 L .38938 .79787 L F
.38942 .79785 m .3923 .79713 L .38938 .79787 L F
.639 .948 .735 r
.38893 .79844 m .38884 .79876 L .39003 .79768 L F
.38689 .79984 m .39003 .79768 L .38988 .79772 L F
.743 .532 .61 r
.3901 .7974 m .38972 .79854 L .39044 .79756 L F
0 0 .131 r
.38925 .79795 m .38923 .79798 L .38922 .79791 L F
.38972 .79854 m .38923 .79798 L .38925 .79795 L F
.667 .216 .17 r
.38922 .79791 m .38502 .79776 L .38689 .79984 L F
.639 .948 .735 r
.38689 .79984 m .38864 .79887 L .38893 .79844 L F
.38864 .79887 m .38884 .79876 L .38893 .79844 L F
.667 .216 .17 r
.38922 .79791 m .38926 .79845 L .38502 .79776 L F
0 0 .131 r
.38972 .79854 m .38943 .80057 L .38936 .79963 L F
.667 .216 .17 r
.38931 .79907 m .38943 .80057 L .38889 .80022 L F
.614 .768 .953 r
.38902 .80001 m .3891 .79986 L .38972 .79854 L F
.743 .532 .61 r
.38906 .79993 m .38907 .79993 L .38972 .79854 L F
0 0 0 r
.38883 .80041 m .38972 .79854 L .38888 .80031 L F
.38884 .80038 m .38972 .79854 L .38881 .80045 L F
.667 .216 .17 r
.38926 .79845 m .38931 .79907 L .38887 .80021 L F
.38931 .79907 m .38889 .80022 L .38887 .80021 L F
.38926 .79845 m .38887 .80021 L .38502 .79776 L F
0 0 .131 r
.38972 .79854 m .38936 .79963 L .38923 .79798 L F
.743 .532 .61 r
.38666 .79575 m .38906 .79993 L .38972 .79854 L F
.428 .409 .736 r
.38887 .80021 m .38943 .80057 L .38907 .79993 L F
.614 .768 .953 r
.38884 .80038 m .38919 .79975 L .38902 .80001 L F
.428 .409 .736 r
.38502 .79776 m .38887 .80021 L .38666 .79575 L F
.38887 .80021 m .38907 .79993 L .38666 .79575 L F
.614 .768 .953 r
.38869 .80068 m .38882 .80044 L .38884 .80038 L F
0 0 0 r
.38869 .80068 m .38884 .80038 L .38879 .80049 L F
.743 .532 .61 r
.38666 .79575 m .38972 .79854 L .3901 .7974 L F
.614 .768 .953 r
.38869 .80068 m .38654 .80031 L .39022 .79771 L F
.3891 .79986 m .39027 .79785 L .38972 .79854 L F
.39027 .79785 m .39044 .79756 L .38972 .79854 L F
.591 .855 .51 r
.39054 .7975 m .38972 .79854 L .39059 .79747 L F
.614 .768 .953 r
.39029 .79782 m .39022 .79771 L .39044 .79756 L F
.591 .855 .51 r
.38997 .7982 m .38972 .79854 L .39029 .79782 L F
.743 .532 .61 r
.38907 .79993 m .38943 .80057 L .38972 .79854 L F
.614 .768 .953 r
.38919 .79975 m .39044 .79756 L .38902 .80001 L F
.38882 .80044 m .39044 .79756 L .38884 .80038 L F
.38869 .80068 m .38997 .7982 L .39029 .79782 L F
.38997 .7982 m .39022 .79771 L .39029 .79782 L F
.591 .855 .51 r
.39041 .79759 m .38997 .7982 L .39054 .7975 L F
.38997 .7982 m .39029 .79782 L .39054 .7975 L F
0 0 0 r
.38881 .80045 m .38883 .80041 L .38879 .80049 L F
.38883 .80041 m .38888 .80031 L .38879 .80049 L F
.38879 .80049 m .38972 .79854 L .39041 .79759 L F
.849 .572 .519 r
.33988 .87863 m .34091 .87881 L .34062 .87644 L F
.874 .614 .088 r
.34062 .87644 m .34091 .87881 L .34108 .87909 L F
.742 .395 .394 r
.70697 .71197 m .70737 .71414 L .70384 .71342 L F
.669 .345 .416 r
.70914 .71271 m .70737 .71414 L .70697 .71197 L F
.353 0 .011 r
.44643 .77333 m .4486 .77311 L .44995 .77158 L F
.269 0 0 r
.44995 .77158 m .4507 .77269 L .45218 .77136 L F
.44995 .77158 m .4486 .77311 L .4507 .77269 L F
.261 .021 .349 r
.29181 .62391 m .29087 .62262 L .29248 .62182 L F
.29181 .62391 m .29029 .62462 L .29087 .62262 L F
.744 .667 .775 r
.3932 .66828 m .39426 .67115 L .39087 .67063 L F
.621 .6 .808 r
.39659 .66761 m .39426 .67115 L .3932 .66828 L F
.385 .295 .63 r
.39659 .66761 m .39617 .67285 L .39426 .67115 L F
.379 .295 .634 r
.39617 .67285 m .39468 .67375 L .39426 .67115 L F
.574 .276 .425 r
.60517 .63547 m .60753 .63546 L .60819 .63313 L F
.544 .247 .414 r
.60819 .63313 m .61049 .63451 L .61063 .63295 L F
.60819 .63313 m .60753 .63546 L .61049 .63451 L F
.855 .571 .508 r
.71158 .60329 m .71422 .60367 L .71436 .60579 L F
.316 .019 .292 r
.40141 .75532 m .40074 .75705 L .39921 .75721 L F
.574 .496 .73 r
.40074 .75705 m .39926 .75987 L .39921 .75721 L F
.131 0 0 r
.47257 .73336 m .47133 .73416 L .46895 .73452 L F
.366 0 0 r
.47469 .73296 m .47133 .73416 L .47257 .73336 L F
.912 .699 .602 r
.55839 .68738 m .55657 .68869 L .55763 .68695 L F
.55839 .68738 m .55817 .68974 L .55657 .68869 L F
.865 .979 .852 r
.55839 .68738 m .55878 .68563 L .5609 .68523 L F
.55839 .68738 m .55763 .68695 L .55878 .68563 L F
.637 .43 .585 r
.30048 .69276 m .30055 .69275 L .30036 .69508 L F
.127 0 0 r
.41081 .75033 m .40724 .75124 L .40841 .74998 L F
.414 .179 .446 r
.4051 .75398 m .40357 .75244 L .40564 .75225 L F
.4051 .75398 m .40324 .75461 L .40357 .75244 L F
.029 .519 .878 r
.368 .65287 m .36941 .65377 L .3664 .65293 L F
.368 .65287 m .3664 .65293 L .36595 .65319 L F
.774 .854 .911 r
.64662 .65284 m .64818 .65156 L .64541 .6517 L F
.629 .401 .553 r
.61253 .6896 m .61291 .69228 L .60933 .6924 L F
.608 .386 .554 r
.61453 .69178 m .61253 .6896 L .61468 .68962 L F
.61453 .69178 m .61291 .69228 L .61253 .6896 L F
.703 .173 0 r
.72375 .73702 m .72336 .73782 L .72314 .73538 L F
.72375 .73702 m .72557 .73856 L .72336 .73782 L F
.715 .664 .798 r
.30809 .71492 m .30518 .71501 L .30723 .71425 L F
.621 .81 .972 r
.31073 .71452 m .30809 .71492 L .30723 .71425 L F
.359 .824 .909 r
.39465 .79661 m .39368 .79722 L .39664 .79661 L F
.39465 .79661 m .3923 .79713 L .39368 .79722 L F
.789 .308 0 r
.66781 .59607 m .66799 .59532 L .668 .59448 L F
.66781 .59607 m .66889 .59665 L .66799 .59532 L F
.694 .19 0 r
.66799 .59532 m .67062 .59819 L .67002 .59734 L F
.946 .918 .754 r
.66932 .59635 m .67002 .59734 L .66858 .59954 L F
.66932 .59633 m .67002 .59734 L .66932 .59635 L F
.694 .19 0 r
.67062 .59819 m .67094 .59853 L .67002 .59734 L F
.867 .421 .092 r
.71063 .6013 m .71025 .6024 L .70977 .59981 L F
.71063 .6013 m .71158 .60329 L .71025 .6024 L F
.467 .053 .17 r
.44869 .78132 m .44526 .78328 L .44655 .78164 L F
0 0 0 r
.62072 .62533 m .62 .62669 L .62221 .62436 L F
.591 .55 .777 r
.37654 .79964 m .37889 .79998 L .37723 .79914 L F
.522 .339 .575 r
.36345 .68477 m .36542 .68656 L .36548 .68423 L F
.334 .646 .967 r
.70267 .73071 m .70401 .72984 L .70174 .73027 L F
.661 .526 .688 r
.58025 .71403 m .57819 .71671 L .57754 .71441 L F
.509 .291 .519 r
.60931 .67666 m .61152 .67615 L .61179 .67394 L F
.368 .13 .416 r
.61179 .67394 m .61362 .67326 L .61411 .67132 L F
.506 .328 .574 r
.61152 .67615 m .61362 .67326 L .61179 .67394 L F
.639 .573 .764 r
.52854 .74231 m .53005 .74104 L .52708 .7407 L F
.325 0 0 r
.33069 .71172 m .33151 .71211 L .33153 .71239 L F
.719 .913 .961 r
.33328 .71235 m .33156 .71268 L .33153 .71239 L F
.33328 .71235 m .33014 .7135 L .32919 .71313 L F
.612 .217 .271 r
.33153 .71239 m .33495 .71102 L .33328 .71235 L F
.33153 .71239 m .33343 .71303 L .33495 .71102 L F
.325 0 0 r
.33151 .71211 m .33343 .71303 L .33153 .71239 L F
.719 .913 .961 r
.33156 .71268 m .32919 .71313 L .33153 .71239 L F
.825 .796 .824 r
.69814 .61776 m .69504 .6174 L .69665 .6161 L F
.69814 .61776 m .69654 .61935 L .69504 .6174 L F
.76 .707 .802 r
.69952 .61654 m .69814 .61776 L .69665 .6161 L F
.724 .642 .766 r
.69039 .62447 m .69125 .62776 L .68775 .6272 L F
.679 .615 .777 r
.69377 .62538 m .69125 .62776 L .69039 .62447 L F
.726 .575 .685 r
.7104 .61166 m .71093 .6151 L .71336 .61177 L F
0 0 0 r
.71515 .61078 m .71526 .61096 L .71336 .61177 L F
.304 .398 .794 r
.71336 .61177 m .71526 .61096 L .71215 .60849 L F
.719 .649 .778 r
.71215 .60849 m .71336 .61177 L .7104 .61166 L F
.533 .362 .595 r
.37976 .74913 m .38182 .74637 L .37979 .74676 L F
0 0 0 r
.62429 .62107 m .62668 .61887 L .62537 .61997 L F
.53727 .77356 m .54013 .77057 L .53695 .77126 L F
.588 .771 .967 r
.71225 .73711 m .7128 .73822 L .71527 .73774 L F
.607 .538 .751 r
.40086 .76835 m .39877 .76882 L .39776 .76548 L F
.6 .58 .803 r
.40153 .77009 m .39877 .76882 L .40086 .76835 L F
.504 .735 .977 r
.70623 .61036 m .70738 .61202 L .70582 .61246 L F
.769 .674 .758 r
.69504 .6174 m .69654 .61935 L .69437 .61904 L F
.72 .513 .61 r
.69541 .62121 m .69437 .61904 L .69654 .61935 L F
.701 .377 .425 r
.69654 .61935 m .69833 .62132 L .69541 .62121 L F
.741 .631 .738 r
.57112 .71771 m .57086 .71974 L .56767 .7193 L F
.744 .635 .738 r
.57302 .717 m .57086 .71974 L .57112 .71771 L F
.683 .544 .69 r
.57336 .71948 m .57086 .71974 L .57302 .717 L F
.68 .554 .705 r
.57415 .72227 m .57086 .71974 L .57336 .71948 L F
.57415 .72227 m .57118 .72251 L .57086 .71974 L F
.627 .843 .983 r
.31109 .73808 m .31328 .73865 L .31185 .73785 L F
.492 .816 1 r
.31021 .73853 m .31328 .73865 L .31109 .73808 L F
.31021 .73853 m .31328 .73865 L .31109 .73808 L F
0 .11 .633 r
.31328 .73865 m .31402 .73736 L .31185 .73785 L F
.31328 .73865 m .31395 .73815 L .31402 .73736 L F
.428 .867 .788 r
.31461 .73806 m .31395 .73815 L .31328 .73865 L F
.019 .236 .741 r
.6272 .63358 m .62872 .63586 L .62726 .63273 L F
.425 .007 .14 r
.4116 .73023 m .41388 .72998 L .41504 .72831 L F
.482 .066 .174 r
.41504 .72831 m .41388 .72998 L .41683 .72924 L F
.735 .967 .697 r
.68248 .62624 m .68389 .624 L .68534 .62528 L F
.68248 .62624 m .68174 .62646 L .68389 .624 L F
.439 .659 .954 r
.34965 .65043 m .34748 .65068 L .34604 .64903 L F
.54 .321 .531 r
.60911 .67872 m .61152 .67615 L .60931 .67666 L F
.649 .612 .799 r
.68552 .62004 m .68461 .62247 L .68359 .61923 L F
.108 0 0 r
.68359 .61923 m .68453 .61974 L .68454 .61963 L F
.68359 .61923 m .68454 .61963 L .68454 .61963 L F
.638 .608 .803 r
.69028 .61766 m .68561 .61982 L .68454 .61963 L F
.649 .612 .799 r
.68561 .61982 m .68473 .61956 L .68454 .61963 L F
.68473 .61956 m .68359 .61923 L .68454 .61963 L F
.68561 .61982 m .68552 .62004 L .68454 .61963 L F
0 0 0 r
.68473 .61956 m .68454 .61963 L .68454 .61963 L F
.649 .612 .799 r
.68473 .61956 m .68454 .61963 L .68359 .61923 L F
.68561 .61982 m .68454 .61963 L .68473 .61956 L F
0 0 0 r
.68865 .61825 m .68473 .61956 L .68453 .61974 L F
.68473 .61956 m .68454 .61963 L .68453 .61974 L F
.69028 .61766 m .68454 .61963 L .68865 .61825 L F
.759 .312 .188 r
.68665 .624 m .68389 .624 L .68461 .62247 L F
.665 .63 .805 r
.68561 .61982 m .68734 .62212 L .68461 .62247 L F
.778 .615 .677 r
.68734 .62212 m .68665 .624 L .68461 .62247 L F
.111 .302 .776 r
.73339 .71597 m .73426 .71604 L .7333 .71706 L F
.13 .162 .627 r
.73426 .71604 m .73361 .71938 L .7333 .71706 L F
.745 .822 .912 r
.71554 .62241 m .71241 .62238 L .71434 .62142 L F
.783 .794 .862 r
.71683 .61888 m .71554 .62241 L .71434 .62142 L F
.71683 .61888 m .71846 .62008 L .71554 .62241 L F
.257 .464 .87 r
.37692 .65817 m .37945 .65988 L .37781 .65941 L F
0 0 .517 r
.4851 .77043 m .48483 .77021 L .48287 .76829 L F
.631 .514 .702 r
.39926 .75987 m .40047 .7653 L .39737 .76394 L F
.477 .812 .999 r
.40047 .7653 m .39776 .76548 L .39737 .76394 L F
.354 0 0 r
.72427 .71516 m .72394 .71592 L .72114 .71588 L F
.696 .163 0 r
.72427 .71516 m .72637 .71674 L .72394 .71592 L F
0 0 0 r
.42298 .77633 m .42422 .77589 L .42445 .77543 L F
.59208 .64951 m .58948 .6519 L .59091 .65092 L F
.433 .85 .69 r
.58948 .6519 m .58918 .65197 L .59091 .65092 L F
.479 0 0 r
.48546 .77843 m .4875 .77881 L .48408 .77898 L F
0 0 0 r
.62892 .61623 m .62759 .61766 L .62668 .61887 L F
.331 .74 .98 r
.28375 .60369 m .28101 .60302 L .28228 .60284 L F
.386 .719 .988 r
.28425 .60262 m .28375 .60369 L .28228 .60284 L F
.28425 .60262 m .28585 .60369 L .28375 .60369 L F
.628 .395 .545 r
.60722 .69476 m .60541 .69262 L .60704 .69272 L F
.60722 .69476 m .60393 .69505 L .60541 .69262 L F
.687 .514 .648 r
.70134 .71162 m .70209 .71445 L .69944 .71407 L F
.688 .253 .21 r
.69807 .71128 m .70243 .71431 L .70134 .71162 L F
.231 .031 .39 r
.70134 .71162 m .70243 .71431 L .70342 .71276 L F
.14 .357 .816 r
.66828 .59354 m .66515 .592 L .66446 .59152 L F
.66828 .59354 m .668 .59448 L .66515 .592 L F
.403 .467 .812 r
.71161 .62098 m .71002 .62263 L .70929 .61953 L F
.541 .69 .936 r
.71161 .62098 m .71241 .62238 L .71002 .62263 L F
.217 0 0 r
.45085 .78103 m .45438 .77934 L .45298 .78066 L F
.357 0 0 r
.45438 .77934 m .45514 .78042 L .45298 .78066 L F
.45438 .77934 m .45654 .77932 L .45514 .78042 L F
.628 .411 .569 r
.57118 .72251 m .57149 .72482 L .56879 .72492 L F
.648 .419 .557 r
.57415 .72227 m .57149 .72482 L .57118 .72251 L F
.587 .339 .509 r
.59172 .70076 m .58943 .70285 L .58944 .7008 L F
.757 .976 .712 r
.36199 .80634 m .36409 .80397 L .36237 .80519 L F
.74 .99 .805 r
.36007 .80708 m .36199 .80634 L .36237 .80519 L F
.53 .779 .989 r
.71062 .58859 m .71131 .58994 L .70856 .59037 L F
.983 .906 .635 r
.71131 .58994 m .71062 .58859 L .70856 .59037 L F
.281 0 0 r
.41407 .74928 m .41242 .7505 L .41081 .75033 L F
.266 0 0 r
.41621 .74904 m .41242 .7505 L .41407 .74928 L F
.749 .892 .944 r
.62353 .62043 m .62429 .62107 L .6229 .62258 L F
.249 .161 .555 r
.62221 .62436 m .62353 .62043 L .6229 .62258 L F
.414 .156 .411 r
.34765 .72145 m .34609 .72186 L .34842 .71969 L F
.211 0 0 r
.34655 .72307 m .34609 .72186 L .34765 .72145 L F
.34655 .72307 m .34451 .72369 L .34609 .72186 L F
.865 .854 .398 r
.65057 .62671 m .65072 .62734 L .65139 .6251 L F
.778 .84 .38 r
.6526 .62157 m .65139 .6251 L .65315 .62205 L F
.6526 .62157 m .65141 .62464 L .65139 .6251 L F
.778 .835 .372 r
.65141 .62464 m .65057 .62671 L .65139 .6251 L F
.703 .528 .648 r
.50435 .73631 m .50687 .73777 L .5069 .7361 L F
.50435 .73631 m .50488 .73891 L .50687 .73777 L F
.515 .287 .507 r
.64206 .59526 m .64424 .59481 L .64441 .59276 L F
.437 .223 .489 r
.64441 .59276 m .64624 .59436 L .64631 .59205 L F
.64441 .59276 m .64424 .59481 L .64624 .59436 L F
.76 .673 .766 r
.55611 .69495 m .55732 .69779 L .55377 .69742 L F
.762 .664 .754 r
.55732 .69779 m .55475 .70075 L .55377 .69742 L F
.707 .649 .789 r
.55945 .69512 m .55732 .69779 L .55611 .69495 L F
.138 .264 .732 r
.67987 .60086 m .6789 .59764 L .67862 .60016 L F
.294 0 .032 r
.32597 .6789 m .32422 .68078 L .32215 .6812 L F
.655 .263 .291 r
.32797 .67948 m .32422 .68078 L .32597 .6789 L F
.806 .972 .669 r
.62017 .66517 m .62234 .66273 L .6203 .66534 L F
.729 .575 .681 r
.55832 .70339 m .55632 .70605 L .55629 .70357 L F
.885 .894 .474 r
.55832 .70339 m .55727 .70485 L .55809 .70295 L F
.729 .575 .681 r
.55832 .70339 m .56 .7063 L .55632 .70605 L F
.759 .992 .788 r
.55876 .70185 m .55809 .70295 L .55832 .70339 L F
0 0 .499 r
.55462 .70304 m .55208 .70013 L .55475 .70075 L F
.172 .684 .897 r
.55809 .70295 m .55831 .70278 L .5542 .7025 L F
.756 .877 .458 r
.55836 .70323 m .55831 .70278 L .55876 .70185 L F
0 0 0 r
.55876 .70185 m .55831 .70278 L .55809 .70295 L F
.756 .877 .458 r
.55831 .70278 m .5583 .70277 L .55876 .70185 L F
0 0 0 r
.55876 .70185 m .55848 .70265 L .55831 .70278 L F
0 0 .335 r
.5583 .70277 m .55868 .70212 L .55876 .70185 L F
.172 .684 .897 r
.55831 .70278 m .5584 .70265 L .5583 .70277 L F
.756 .877 .458 r
.55832 .70339 m .55727 .70485 L .5583 .70277 L F
0 0 .335 r
.55727 .70485 m .55842 .70263 L .5583 .70277 L F
.55841 .70264 m .55868 .70212 L .5583 .70277 L F
.748 .842 .922 r
.55842 .70261 m .55868 .70212 L .55556 .70062 L F
0 0 0 r
.55876 .70185 m .55868 .70212 L .55848 .70265 L F
.748 .842 .922 r
.55848 .70265 m .55868 .70212 L .55842 .70261 L F
0 0 .335 r
.55842 .70263 m .55868 .70212 L .55841 .70264 L F
.172 .684 .897 r
.55831 .70278 m .55848 .70265 L .5584 .70265 L F
.5583 .70277 m .5584 .70265 L .55829 .70265 L F
.55831 .70278 m .55829 .70265 L .5542 .7025 L F
.756 .877 .458 r
.55832 .70339 m .5583 .70277 L .55836 .70323 L F
.44 .208 .465 r
.48287 .76829 m .48487 .76795 L .48517 .76564 L F
.48287 .76829 m .48487 .76795 L .48517 .76564 L F
.532 .287 .49 r
.48487 .76795 m .48706 .7677 L .48517 .76564 L F
.441 .279 .564 r
.48517 .76564 m .48706 .7677 L .48692 .76511 L F
.554 .364 .578 r
.48487 .76795 m .48692 .76511 L .48517 .76564 L F
.48692 .76511 m .48487 .76795 L .48517 .76564 L F
.056 0 0 r
.44468 .72441 m .44679 .7244 L .4482 .72429 L F
.459 0 0 r
.44679 .7244 m .45019 .72496 L .4482 .72429 L F
.86 .715 .701 r
.55475 .70075 m .55208 .70013 L .55377 .69742 L F
.846 .884 .867 r
.59428 .6643 m .59775 .66282 L .5966 .66204 L F
.886 .895 .832 r
.5966 .66204 m .59775 .66282 L .59983 .66018 L F
.22 0 0 r
.3655 .7967 m .3678 .7969 L .3678 .79672 L F
.714 .381 0 r
.3678 .79672 m .36806 .79732 L .3678 .79664 L F
.635 .629 .827 r
.36739 .79557 m .36806 .79732 L .36996 .79629 L F
.855 .774 .771 r
.36489 .79869 m .36806 .79732 L .3678 .79672 L F
.36489 .79869 m .36611 .80072 L .36806 .79732 L F
.537 .361 .59 r
.36806 .79732 m .36817 .80037 L .36611 .80072 L F
.921 .701 .209 r
.3678 .79672 m .36817 .80037 L .36806 .79732 L F
.96 .762 .593 r
.36679 .79973 m .36817 .80037 L .3678 .79672 L F
.281 .035 .352 r
.36896 .797 m .36679 .79973 L .3678 .79672 L F
.22 0 0 r
.3678 .7969 m .36896 .797 L .3678 .79672 L F
.714 .381 0 r
.3678 .79672 m .3678 .79664 L .36739 .79557 L F
.562 .301 .478 r
.5993 .69535 m .59912 .69791 L .59681 .69792 L F
.664 .387 .491 r
.60151 .6975 m .59912 .69791 L .5993 .69535 L F
.669 .386 .484 r
.60189 .69561 m .60151 .6975 L .5993 .69535 L F
.449 .754 .994 r
.51641 .70991 m .51777 .7109 L .5155 .71104 L F
.348 0 .074 r
.51669 .712 m .5142 .7128 L .5155 .71104 L F
0 0 0 r
.51641 .70991 m .5142 .7128 L .5155 .71104 L F
.348 0 .074 r
.51669 .712 m .5155 .71104 L .51777 .7109 L F
0 0 0 r
.5142 .7128 m .51311 .71412 L .5155 .71104 L F
.572 .423 .641 r
.37247 .76548 m .37479 .76518 L .3745 .76275 L F
.535 .416 .664 r
.37301 .76861 m .37479 .76518 L .37247 .76548 L F
0 0 0 r
.52669 .78757 m .52499 .78877 L .52371 .78957 L F
.52499 .78877 m .52257 .79114 L .52371 .78957 L F
.63 .798 .963 r
.5111 .7169 m .50761 .71647 L .51014 .71443 L F
.537 .393 .632 r
.51311 .71412 m .5111 .7169 L .51014 .71443 L F
.51311 .71412 m .51321 .71657 L .5111 .7169 L F
.653 .567 .745 r
.51441 .71965 m .5111 .7169 L .51321 .71657 L F
.9 .986 .745 r
.34108 .87909 m .34091 .87881 L .34047 .87945 L F
.353 .029 .269 r
.35296 .7011 m .35216 .7028 L .35476 .70058 L F
.424 .108 .324 r
.31021 .66047 m .30951 .66215 L .31218 .66004 L F
.156 0 0 r
.4781 .73331 m .47679 .73325 L .47469 .73296 L F
.672 .3 .333 r
.48021 .7328 m .47679 .73325 L .4781 .73331 L F
.628 .607 .81 r
.5253 .72209 m .52435 .7255 L .52332 .72219 L F
.5253 .72209 m .52656 .72512 L .52435 .7255 L F
.92 .792 .702 r
.67094 .59853 m .66858 .59954 L .67002 .59734 L F
.67094 .59853 m .67034 .60056 L .66858 .59954 L F
.55 .481 .731 r
.63038 .60827 m .63263 .60575 L .63083 .60823 L F
.63038 .60827 m .63243 .60557 L .63263 .60575 L F
.63038 .60827 m .63315 .60809 L .63243 .60557 L F
.507 .241 .446 r
.63272 .61029 m .63315 .60809 L .63038 .60827 L F
.318 .021 .293 r
.40324 .75461 m .40074 .75705 L .40141 .75532 L F
.886 .895 .832 r
.5966 .66204 m .59983 .66018 L .59878 .65936 L F
.856 .914 .871 r
.59878 .65936 m .59983 .66018 L .6022 .65764 L F
.669 .383 .479 r
.47956 .77067 m .48279 .77081 L .48287 .76829 L F
.637 .357 .477 r
.48287 .76829 m .4851 .77043 L .48487 .76795 L F
.48287 .76829 m .48279 .77081 L .4851 .77043 L F
0 0 .517 r
.4851 .77043 m .48287 .76829 L .48487 .76795 L F
.315 0 0 r
.45593 .73656 m .45483 .73794 L .45265 .73823 L F
.158 0 0 r
.45863 .73683 m .45483 .73794 L .45593 .73656 L F
.492 .222 .432 r
.30977 .69152 m .30818 .69 L .31058 .68971 L F
.30977 .69152 m .30771 .69207 L .30818 .69 L F
.59 .459 .67 r
.58214 .70828 m .58128 .71103 L .58105 .70981 L F
.498 .326 .578 r
.58446 .70826 m .58128 .71103 L .58214 .70828 L F
.58446 .70826 m .58446 .71085 L .58128 .71103 L F
.533 .341 .566 r
.58446 .71085 m .58231 .71345 L .58128 .71103 L F
.538 .347 .569 r
.58231 .71345 m .58105 .70981 L .58128 .71103 L F
.58231 .71345 m .58025 .71403 L .58105 .70981 L F
0 0 0 r
.59208 .64951 m .59325 .64832 L .59392 .64653 L F
.455 .699 .972 r
.67768 .58333 m .67637 .58462 L .67864 .58443 L F
.778 .83 .893 r
.50031 .71812 m .49642 .71882 L .499 .71697 L F
.675 .834 .96 r
.5023 .71712 m .50031 .71812 L .499 .71697 L F
.265 0 .137 r
.60312 .63841 m .60109 .6392 L .60044 .64043 L F
.779 .842 .899 r
.70107 .57548 m .70292 .57667 L .70167 .57561 L F
.786 .829 .886 r
.70167 .57561 m .70292 .57667 L .70564 .57475 L F
.187 .708 .873 r
.42895 .74581 m .42793 .74463 L .4293 .74419 L F
.442 .131 .341 r
.43129 .7451 m .4293 .74419 L .43177 .74386 L F
.43129 .7451 m .42895 .74581 L .4293 .74419 L F
.76 .707 .802 r
.69952 .61654 m .69665 .6161 L .69891 .61364 L F
.768 .712 .799 r
.7023 .61394 m .69952 .61654 L .69891 .61364 L F
0 0 .44 r
.67367 .58973 m .67438 .59199 L .67385 .59124 L F
0 .033 .545 r
.67497 .59387 m .67385 .59124 L .67438 .59199 L F
.67497 .59387 m .6743 .59552 L .67385 .59124 L F
.509 .33 .573 r
.37152 .77365 m .37349 .77329 L .3736 .77093 L F
.54 .401 .641 r
.37173 .77606 m .37349 .77329 L .37152 .77365 L F
.711 .86 .953 r
.48667 .72182 m .48339 .72199 L .48535 .72096 L F
.71 .856 .951 r
.48893 .72056 m .48667 .72182 L .48535 .72096 L F
.806 .972 .669 r
.62017 .66517 m .62228 .6623 L .62234 .66273 L F
.791 .75 .815 r
.50488 .73891 m .50448 .74021 L .50687 .73777 L F
.03 0 .033 r
.32521 .6516 m .32621 .65171 L .32719 .65128 L F
.32521 .6516 m .32567 .65274 L .32621 .65171 L F
.32521 .6516 m .32396 .65399 L .32567 .65274 L F
.062 .536 .895 r
.71629 .73487 m .71519 .73504 L .7136 .73302 L F
.71629 .73487 m .71703 .73552 L .71519 .73504 L F
.759 .732 .827 r
.69928 .62332 m .69621 .62422 L .69833 .62132 L F
.719 .728 .857 r
.69833 .62132 m .70126 .62222 L .69928 .62332 L F
.745 .69 .798 r
.71527 .73774 m .71812 .73857 L .71703 .73552 L F
.751 .316 .218 r
.71812 .73857 m .71746 .74015 L .71527 .73774 L F
.281 .403 .809 r
.71703 .73552 m .71964 .73742 L .71812 .73857 L F
.234 .325 .753 r
.67593 .59667 m .6743 .59552 L .67497 .59387 L F
.916 .712 .613 r
.64818 .64059 m .64956 .64137 L .64835 .63832 L F
.903 .74 .67 r
.64919 .64371 m .64956 .64137 L .64818 .64059 L F
0 0 0 r
.59392 .64653 m .59538 .64557 L .59648 .6441 L F
.59392 .64653 m .59325 .64832 L .59538 .64557 L F
.809 .598 .617 r
.6284 .63814 m .6317 .63861 L .63156 .64097 L F
0 0 0 r
.62978 .61463 m .62892 .61623 L .63091 .61297 L F
.484 .766 .993 r
.71635 .59408 m .71546 .59513 L .7144 .59415 L F
.144 .253 .719 r
.71635 .59408 m .71776 .59778 L .71546 .59513 L F
0 .525 .765 r
.34114 .6481 m .34282 .64834 L .34449 .64873 L F
0 .469 .719 r
.34282 .64834 m .34604 .64903 L .34449 .64873 L F
.702 .485 .591 r
.60933 .6924 m .60722 .69476 L .60704 .69272 L F
.528 .88 .984 r
.30371 .71452 m .30723 .71425 L .30518 .71501 L F
.209 0 .174 r
.35039 .7191 m .34765 .72145 L .34842 .71969 L F
.364 .159 .463 r
.61362 .67326 m .61563 .67046 L .61411 .67132 L F
.671 .681 .851 r
.34959 .80564 m .35108 .80736 L .35334 .80621 L F
.569 .554 .798 r
.40369 .76987 m .40289 .77245 L .40153 .77009 L F
.40369 .76987 m .40474 .77253 L .40289 .77245 L F
.843 .671 .669 r
.53385 .77527 m .53817 .77499 L .53727 .77356 L F
.116 .341 .808 r
.53727 .77356 m .53817 .77499 L .53996 .7758 L F
.464 .058 .185 r
.53996 .7758 m .53817 .77499 L .53615 .77782 L F
.577 .795 .982 r
.47883 .72371 m .47515 .72278 L .47752 .72228 L F
.653 .79 .948 r
.48148 .72309 m .47883 .72371 L .47752 .72228 L F
.25 0 0 r
.34085 .67586 m .33752 .67571 L .339 .67652 L F
.48 .138 .309 r
.40385 .73283 m .40606 .73252 L .4071 .73028 L F
.463 .121 .301 r
.4071 .73028 m .40823 .73211 L .40937 .73029 L F
.4071 .73028 m .40606 .73252 L .40823 .73211 L F
.652 .794 .95 r
.49213 .72095 m .48893 .72056 L .49104 .71978 L F
.675 .809 .947 r
.49457 .71993 m .49213 .72095 L .49104 .71978 L F
.735 .74 .855 r
.36319 .8012 m .36611 .80072 L .36489 .79869 L F
.785 .558 .593 r
.3626 .8028 m .36611 .80072 L .36319 .8012 L F
.3626 .8028 m .36599 .8032 L .36611 .80072 L F
.532 .344 .572 r
.36817 .80037 m .36599 .8032 L .36611 .80072 L F
.476 .618 .911 r
.72004 .59673 m .71828 .59855 L .71776 .59778 L F
.72004 .59673 m .72143 .59885 L .71828 .59855 L F
.755 .569 .644 r
.56 .7063 m .55638 .70816 L .55632 .70605 L F
.56 .7063 m .55966 .70867 L .55638 .70816 L F
.076 .04 .509 r
.45523 .77043 m .45664 .77006 L .45625 .76762 L F
0 0 0 r
.45523 .77043 m .45419 .77083 L .45664 .77006 L F
.52812 .78652 m .52499 .78877 L .52669 .78757 L F
.648 .536 .713 r
.57647 .7197 m .57415 .72227 L .57336 .71948 L F
.627 .545 .743 r
.35692 .80272 m .35801 .80006 L .35727 .80055 L F
.35692 .80272 m .36068 .80369 L .35801 .80006 L F
.757 .595 .677 r
.56154 .69243 m .55945 .69512 L .55949 .69268 L F
.56154 .69243 m .56296 .69576 L .55945 .69512 L F
.404 .705 .984 r
.36242 .65146 m .36179 .65265 L .36047 .65173 L F
.36242 .65146 m .36404 .65276 L .36179 .65265 L F
.333 .44 .821 r
.3815 .65977 m .38126 .66251 L .37945 .65988 L F
.3815 .65977 m .38251 .66261 L .38126 .66251 L F
.169 0 0 r
.42781 .78688 m .42686 .78753 L .42288 .78872 L F
.193 0 0 r
.42991 .78655 m .42686 .78753 L .42781 .78688 L F
.325 .779 .952 r
.6816 .58377 m .68316 .58317 L .6809 .58366 L F
.6816 .58377 m .68566 .58353 L .68316 .58317 L F
.477 0 .005 r
.45869 .77999 m .45654 .77932 L .45986 .77885 L F
.391 0 0 r
.45986 .77885 m .46063 .78011 L .45869 .77999 L F
.45986 .77885 m .46203 .77883 L .46063 .78011 L F
.512 .05 .092 r
.46203 .77883 m .46538 .77815 L .46423 .77891 L F
.3 0 0 r
.4675 .77803 m .46423 .77891 L .46538 .77815 L F
.372 .604 .938 r
.72344 .59916 m .72253 .60041 L .72143 .59885 L F
.202 .363 .802 r
.72344 .59916 m .72506 .60228 L .72253 .60041 L F
.73 .655 .776 r
.71064 .57601 m .71172 .57917 L .70969 .57831 L F
.312 0 0 r
.70969 .57831 m .71172 .57917 L .71073 .57879 L F
.367 .435 .799 r
.71339 .57732 m .71172 .57917 L .71064 .57601 L F
.68 .964 .935 r
.71073 .57879 m .71172 .57917 L .71339 .57732 L F
.508 .269 .488 r
.64436 .59664 m .64206 .59526 L .64196 .59695 L F
.64436 .59664 m .64424 .59481 L .64206 .59526 L F
.763 .576 .643 r
.36352 .79534 m .36739 .79557 L .36712 .79259 L F
.549 .437 .678 r
.36712 .79259 m .36916 .79223 L .36892 .78978 L F
.592 .448 .655 r
.36712 .79259 m .36929 .79517 L .36916 .79223 L F
.36712 .79259 m .36739 .79557 L .36929 .79517 L F
.943 .664 .203 r
.7234 .72511 m .72356 .72736 L .72273 .72418 L F
.806 .947 .915 r
.72635 .72263 m .7234 .72511 L .72273 .72418 L F
.545 .149 .242 r
.32948 .65095 m .33159 .65121 L .33307 .64914 L F
.27 0 .069 r
.33307 .64914 m .33358 .65061 L .33508 .64931 L F
.33307 .64914 m .33159 .65121 L .33358 .65061 L F
.719 .706 .837 r
.69321 .58488 m .69613 .58609 L .69539 .5843 L F
.819 .82 .85 r
.69539 .5843 m .69613 .58609 L .69819 .58368 L F
.278 .165 .54 r
.28791 .62955 m .28696 .62779 L .28813 .62738 L F
.28791 .62955 m .28733 .62996 L .28696 .62779 L F
.282 .168 .541 r
.28696 .62779 m .28733 .62996 L .28651 .6304 L F
.17 0 .307 r
.38744 .68393 m .38548 .68679 L .38611 .68473 L F
.571 .882 .992 r
.43336 .77621 m .43178 .77689 L .42983 .77633 L F
.146 0 0 r
.35227 .67262 m .35074 .67278 L .34874 .67269 L F
0 0 0 r
.35408 .67231 m .35074 .67278 L .35227 .67262 L F
.295 0 .228 r
.39012 .68164 m .38744 .68393 L .38827 .68232 L F
0 0 0 r
.36237 .80519 m .36409 .80397 L .36599 .8032 L F
.448 .163 .388 r
.6158 .62976 m .61805 .62974 L .61816 .62771 L F
.569 .929 .939 r
.61816 .62771 m .61944 .62658 L .62 .62669 L F
.332 .074 .364 r
.61816 .62771 m .61986 .62894 L .61944 .62658 L F
.61816 .62771 m .61805 .62974 L .61986 .62894 L F
.731 .681 .802 r
.55341 .70388 m .55405 .70637 L .55126 .70594 L F
.822 .579 .572 r
.55415 .70878 m .55126 .70594 L .55405 .70637 L F
.686 .653 .812 r
.55632 .70605 m .55405 .70637 L .55341 .70388 L F
.675 .534 .685 r
.55632 .70605 m .55415 .70878 L .55405 .70637 L F
.968 .715 .499 r
.36816 .80307 m .36951 .80346 L .36817 .80037 L F
.436 .778 .997 r
.71897 .62536 m .71999 .62437 L .71804 .62463 L F
.71897 .62536 m .72138 .62524 L .71999 .62437 L F
.733 .623 .736 r
.40383 .65436 m .40166 .6571 L .40174 .6548 L F
.40383 .65436 m .40421 .65736 L .40166 .6571 L F
.389 .226 .536 r
.40378 .65651 m .40174 .6548 L .40383 .65436 L F
.40378 .65651 m .40166 .6571 L .40174 .6548 L F
.527 .237 .418 r
.61765 .68764 m .61695 .6894 L .61468 .68962 L F
.103 0 .2 r
.61908 .68666 m .61695 .6894 L .61765 .68764 L F
.202 .022 .399 r
.39384 .678 m .39287 .67649 L .39413 .6758 L F
.39384 .678 m .39252 .67881 L .39287 .67649 L F
.498 0 0 r
.69012 .71428 m .69366 .71557 L .69349 .71499 L F
.564 0 0 r
.69366 .71557 m .69598 .71635 L .69349 .71499 L F
.946 .952 .739 r
.73115 .72649 m .73027 .73011 L .73098 .72806 L F
.686 .653 .812 r
.55632 .70605 m .55462 .70304 L .55629 .70357 L F
.165 0 0 r
.33094 .73065 m .32961 .73255 L .32836 .7322 L F
.182 0 0 r
.32961 .73255 m .32756 .73312 L .32836 .7322 L F
.724 .979 .916 r
.40079 .79487 m .40398 .79344 L .40245 .79439 L F
0 0 0 r
.40405 .79368 m .40398 .79344 L .40594 .79297 L F
.40405 .79368 m .40245 .79439 L .40398 .79344 L F
.421 .175 .433 r
.38504 .68877 m .38355 .68734 L .38548 .68679 L F
.38504 .68877 m .3831 .68936 L .38355 .68734 L F
.578 .191 .272 r
.32083 .73527 m .31892 .73731 L .31621 .73789 L F
.31892 .73731 m .31789 .73841 L .31661 .73801 L F
.31892 .73731 m .31661 .73801 L .31621 .73789 L F
.671 .359 .438 r
.31846 .73943 m .31577 .73952 L .31619 .73814 L F
.31846 .73943 m .31619 .73814 L .31661 .73801 L F
.578 .191 .272 r
.31621 .73789 m .31785 .73846 L .31602 .738 L F
.671 .359 .438 r
.31846 .73943 m .31661 .73801 L .31856 .73861 L F
.578 .191 .272 r
.31789 .73841 m .31785 .73846 L .31621 .73789 L F
.671 .359 .438 r
.31661 .73801 m .31637 .73809 L .31631 .73778 L F
.31637 .73809 m .31624 .738 L .31631 .73778 L F
.051 0 0 r
.3218 .73546 m .31795 .73838 L .32083 .73527 L F
.31795 .73838 m .31789 .73841 L .32083 .73527 L F
.671 .359 .438 r
.31819 .73798 m .31631 .73778 L .31873 .73708 L F
.051 0 0 r
.31795 .73838 m .31785 .73846 L .31789 .73841 L F
.867 .853 .826 r
.31873 .73708 m .31785 .73846 L .31795 .73838 L F
.31873 .73708 m .31795 .73838 L .3218 .73546 L F
.671 .359 .438 r
.31862 .73803 m .31819 .73798 L .31873 .73708 L F
.31856 .73861 m .31794 .73838 L .31862 .73803 L F
.31794 .73838 m .31631 .73778 L .31862 .73803 L F
.31661 .73801 m .31631 .73778 L .31856 .73861 L F
.564 .424 .649 r
.31617 .73795 m .31785 .73846 L .31873 .73708 L F
.31602 .738 m .31637 .73809 L .31617 .73795 L F
.31637 .73809 m .31785 .73846 L .31617 .73795 L F
.671 .359 .438 r
.31637 .73809 m .31619 .73814 L .31624 .738 L F
.092 0 0 r
.3228 .7349 m .3218 .73546 L .32083 .73527 L F
0 0 .002 r
.59648 .6441 m .59787 .64341 L .59874 .64141 L F
.092 0 0 r
.59648 .6441 m .59734 .64477 L .59787 .64341 L F
.59648 .6441 m .59538 .64557 L .59734 .64477 L F
.296 .316 .712 r
.70625 .7315 m .70598 .73335 L .70698 .73147 L F
.369 .405 .768 r
.70598 .73335 m .70843 .73519 L .70698 .73147 L F
.276 0 .166 r
.59874 .64141 m .59994 .64265 L .60044 .64043 L F
.59874 .64141 m .59787 .64341 L .59994 .64265 L F
.817 .737 .776 r
.56528 .72173 m .56298 .72556 L .56206 .72184 L F
.448 .212 .462 r
.37905 .69264 m .37865 .69471 L .37671 .69516 L F
.426 .221 .497 r
.3809 .69204 m .37905 .69264 L .38113 .68985 L F
.452 .215 .463 r
.38063 .69421 m .37905 .69264 L .3809 .69204 L F
.38063 .69421 m .37865 .69471 L .37905 .69264 L F
.594 .255 .365 r
.33085 .67875 m .33006 .68109 L .32797 .67948 L F
0 0 0 r
.33085 .67875 m .33367 .67683 L .33283 .67819 L F
.105 0 .16 r
.33168 .6799 m .33085 .67875 L .33283 .67819 L F
.33168 .6799 m .33006 .68109 L .33085 .67875 L F
.477 .812 .999 r
.40047 .7653 m .39981 .76512 L .39776 .76548 L F
.607 .538 .751 r
.40086 .76835 m .39776 .76548 L .39981 .76512 L F
.693 .635 .787 r
.51648 .71752 m .51441 .71965 L .51321 .71657 L F
.695 .638 .789 r
.517 .71892 m .51441 .71965 L .51648 .71752 L F
.727 .578 .688 r
.70067 .61919 m .70314 .61956 L .70126 .62222 L F
.478 .259 .502 r
.36813 .78448 m .36782 .78695 L .3701 .78407 L F
.59 .372 .553 r
.62273 .6399 m .62118 .64374 L .61859 .64383 L F
.377 .303 .646 r
.62327 .63812 m .62319 .64243 L .62273 .6399 L F
0 0 0 r
.62319 .64243 m .62118 .64374 L .62273 .6399 L F
.775 .674 .752 r
.59132 .67357 m .5925 .6762 L .59471 .67385 L F
.506 .305 .542 r
.68936 .59024 m .68656 .59273 L .68872 .59213 L F
.369 .113 .388 r
.37671 .69516 m .37622 .69733 L .37434 .69788 L F
.458 .203 .438 r
.37865 .69471 m .37622 .69733 L .37671 .69516 L F
.493 .456 .744 r
.67031 .62216 m .67115 .62565 L .67336 .62417 L F
.548 .568 .827 r
.67115 .62565 m .67364 .62541 L .67336 .62417 L F
.607 .587 .805 r
.65579 .61065 m .65448 .61451 L .6533 .61128 L F
.081 .637 .803 r
.40148 .80052 m .40262 .80068 L .39919 .80052 L F
.39919 .80052 m .40262 .80068 L .40148 .80052 L F
.558 .921 .947 r
.40148 .80052 m .40262 .80068 L .40336 .79969 L F
.40148 .80052 m .40262 .80068 L .40336 .79969 L F
.458 .317 .601 r
.36509 .68194 m .36676 .68193 L .36658 .67893 L F
.506 .397 .665 r
.36548 .68423 m .36676 .68193 L .36509 .68194 L F
.795 .709 .769 r
.5592 .71484 m .55858 .71689 L .5554 .7164 L F
.859 .634 .596 r
.55858 .71689 m .55569 .71859 L .5554 .7164 L F
.55858 .71689 m .55847 .71957 L .55569 .71859 L F
.768 .679 .764 r
.56073 .71413 m .55858 .71689 L .5592 .71484 L F
.571 .399 .609 r
.56099 .71627 m .55858 .71689 L .56073 .71413 L F
.733 .524 .609 r
.56199 .71944 m .55858 .71689 L .56099 .71627 L F
.56199 .71944 m .55847 .71957 L .55858 .71689 L F
.148 0 0 r
.45939 .76979 m .46155 .76967 L .46318 .76906 L F
.382 0 .025 r
.4637 .76961 m .466 .76937 L .46665 .76887 L F
.357 0 0 r
.4616 .76965 m .46531 .76904 L .46318 .76906 L F
.46238 .76953 m .46531 .76904 L .4616 .76965 L F
.46155 .76967 m .4637 .76961 L .46531 .76904 L F
.382 0 .025 r
.4637 .76961 m .46838 .76755 L .46531 .76904 L F
.46469 .76917 m .46665 .76887 L .46838 .76755 L F
.4637 .76961 m .46665 .76887 L .46469 .76917 L F
.357 0 0 r
.46155 .76967 m .46238 .76953 L .4616 .76965 L F
.799 .419 .336 r
.50415 .77848 m .50728 .78039 L .50721 .7794 L F
.952 .776 .321 r
.72273 .62119 m .72335 .61965 L .7224 .61874 L F
.72273 .62119 m .72331 .6244 L .72335 .61965 L F
.72335 .61965 m .72273 .62119 L .7224 .61874 L F
.72335 .61965 m .72331 .6244 L .72273 .62119 L F
.581 .219 .319 r
.61312 .64827 m .61134 .64693 L .6141 .64619 L F
.651 .31 .381 r
.61636 .64644 m .61312 .64827 L .6141 .64619 L F
.688 .632 .788 r
.69669 .62748 m .69377 .62538 L .69621 .62422 L F
.602 .874 .992 r
.6863 .57896 m .6833 .57894 L .68525 .57756 L F
.62 .705 .906 r
.68773 .57681 m .6863 .57896 L .68525 .57756 L F
.68773 .57681 m .68851 .57839 L .6863 .57896 L F
.687 .588 .739 r
.68851 .57839 m .68733 .58093 L .6863 .57896 L F
.394 .684 .976 r
.36996 .79629 m .37387 .79783 L .3727 .79655 L F
.399 .663 .966 r
.3727 .79655 m .37387 .79783 L .37448 .79665 L F
.395 .658 .964 r
.37448 .79665 m .37387 .79783 L .37593 .79786 L F
.67 .607 .776 r
.37387 .79783 m .37723 .79914 L .37593 .79786 L F
.648 .419 .557 r
.57415 .72227 m .5742 .72503 L .57149 .72482 L F
.648 .536 .713 r
.57647 .7197 m .57643 .72216 L .57415 .72227 L F
.643 .414 .557 r
.57644 .72441 m .5742 .72503 L .57415 .72227 L F
.632 .416 .571 r
.57643 .72216 m .57644 .72441 L .57415 .72227 L F
.267 0 0 r
.43569 .78471 m .43627 .78562 L .43419 .78601 L F
.43569 .78471 m .43782 .78454 L .43627 .78562 L F
.949 .722 .562 r
.66858 .59954 m .67034 .60056 L .66992 .6027 L F
0 0 0 r
.31021 .73853 m .31109 .73808 L .30975 .73915 L F
.991 .77 .503 r
.42634 .75474 m .42518 .75676 L .42528 .75418 L F
.485 .816 1 r
.42581 .75365 m .42634 .75474 L .42528 .75418 L F
.426 .75403 m .42844 .75436 L .42634 .75474 L F
.4267 .75389 m .42844 .75436 L .426 .75403 L F
.657 .196 .146 r
.42844 .75436 m .42528 .75418 L .42634 .75474 L F
.428 .527 .856 r
.42528 .75418 m .42672 .75522 L .42642 .75471 L F
.657 .196 .146 r
.42586 .75422 m .42619 .7546 L .42528 .75418 L F
.428 .527 .856 r
.42528 .75418 m .42642 .75471 L .42581 .75365 L F
.418 0 0 r
.42528 .75418 m .42673 .75523 L .42672 .75522 L F
.657 .196 .146 r
.42619 .7546 m .42673 .75523 L .42528 .75418 L F
.42844 .75436 m .42742 .75488 L .42586 .75422 L F
.42742 .75488 m .42699 .75481 L .42586 .75422 L F
.485 .816 1 r
.42581 .75365 m .4267 .75389 L .426 .75403 L F
.58 .647 .881 r
.42913 .75156 m .42844 .75436 L .42581 .75365 L F
.544 .437 .682 r
.42642 .75471 m .42913 .75156 L .42581 .75365 L F
.42672 .75522 m .42699 .75481 L .42642 .75471 L F
.42699 .75481 m .42913 .75156 L .42642 .75471 L F
.657 .196 .146 r
.42742 .75488 m .42727 .75495 L .42699 .75481 L F
.42727 .75495 m .42673 .75523 L .42586 .75422 L F
.58 .647 .881 r
.42913 .75156 m .43055 .75398 L .42844 .75436 L F
.539 .363 .592 r
.43055 .75398 m .43056 .75645 L .42844 .75436 L F
.218 .312 .747 r
.42844 .75436 m .43056 .75645 L .43043 .75463 L F
.544 .437 .682 r
.42719 .75491 m .43014 .75449 L .42973 .75329 L F
.218 .312 .747 r
.42844 .75436 m .43043 .75463 L .42954 .75477 L F
.544 .437 .682 r
.42672 .75522 m .42747 .75506 L .42727 .75495 L F
.218 .312 .747 r
.42838 .75486 m .42954 .75477 L .42673 .75523 L F
.647 .772 .939 r
.42673 .75523 m .43014 .75449 L .42838 .75486 L F
.42673 .75523 m .42838 .75486 L .42672 .75522 L F
.218 .312 .747 r
.42844 .75436 m .42954 .75477 L .42727 .75495 L F
.544 .437 .682 r
.42747 .75506 m .43014 .75449 L .42719 .75491 L F
.218 .312 .747 r
.42727 .75495 m .42838 .75486 L .42673 .75523 L F
.544 .437 .682 r
.4271 .75497 m .42727 .75495 L .42719 .75491 L F
.42672 .75522 m .42727 .75495 L .4271 .75497 L F
.42772 .75369 m .42973 .75329 L .42913 .75156 L F
.42672 .75522 m .42973 .75329 L .42772 .75369 L F
.739 .216 0 r
.49958 .78225 m .49818 .78168 L .49752 .78085 L F
.484 0 0 r
.49958 .78225 m .499 .78272 L .49818 .78168 L F
.49958 .78225 m .50234 .78348 L .499 .78272 L F
.558 .427 .658 r
.35927 .69239 m .36174 .69474 L .36117 .69196 L F
.35927 .69239 m .35944 .69522 L .36174 .69474 L F
.193 0 0 r
.44316 .78326 m .44093 .78354 L .44337 .7826 L F
.419 0 .027 r
.44316 .78326 m .44337 .7826 L .44526 .78328 L F
.382 .67 .972 r
.33461 .85165 m .33545 .85171 L .33499 .852 L F
.394 .819 .644 r
.33458 .85223 m .33545 .85171 L .33499 .852 L F
.671 .786 .935 r
.49343 .73028 m .49474 .73131 L .49678 .73052 L F
.591 .405 .598 r
.52683 .73846 m .52933 .73879 L .52934 .73533 L F
.59 .464 .677 r
.52934 .73533 m .53231 .73616 L .53105 .73307 L F
.111 .664 .734 r
.44652 .74057 m .44481 .74073 L .4427 .74099 L F
.003 0 0 r
.44838 .74046 m .44481 .74073 L .44652 .74057 L F
.724 .617 .738 r
.68775 .6272 m .68592 .62799 L .68806 .62519 L F
.724 .642 .766 r
.69039 .62447 m .68775 .6272 L .68806 .62519 L F
.621 .81 .972 r
.31073 .71452 m .30723 .71425 L .30928 .71369 L F
.785 .852 .901 r
.31283 .71243 m .31073 .71452 L .30928 .71369 L F
.655 .68 .862 r
.31614 .71441 m .31283 .71243 L .31491 .71117 L F
.333 .412 .793 r
.31717 .71267 m .31614 .71441 L .31491 .71117 L F
.509 .64 .913 r
.31717 .71267 m .3182 .71453 L .31614 .71441 L F
.925 .751 .647 r
.62815 .65184 m .62557 .65362 L .62583 .65127 L F
.62815 .65184 m .62704 .6547 L .62557 .65362 L F
.556 .735 .959 r
.51407 .73398 m .51541 .73204 L .51312 .73172 L F
.51407 .73398 m .51741 .73396 L .51541 .73204 L F
.526 .464 .729 r
.37301 .76861 m .3736 .77093 L .37549 .77049 L F
.556 .368 .582 r
.3736 .77093 m .37559 .77292 L .37549 .77049 L F
.3736 .77093 m .37349 .77329 L .37559 .77292 L F
.659 .44 .576 r
.70244 .70582 m .70457 .70574 L .70456 .7034 L F
.63 .399 .549 r
.60393 .69505 m .60151 .6975 L .60189 .69561 L F
.901 .823 .76 r
.64818 .65156 m .64909 .64975 L .64774 .64893 L F
.968 .819 .642 r
.67092 .60649 m .66926 .60774 L .66984 .60562 L F
.67092 .60649 m .67039 .60865 L .66926 .60774 L F
.608 .543 .756 r
.37723 .79914 m .37935 .79804 L .37593 .79786 L F
.37723 .79914 m .37889 .79998 L .37935 .79804 L F
.557 .145 .217 r
.41683 .72924 m .41907 .72943 L .42041 .72762 L F
.522 .114 .208 r
.41907 .72943 m .42263 .72763 L .42041 .72762 L F
.749 .657 .759 r
.5069 .7361 m .50687 .73777 L .50901 .7357 L F
.689 .806 .937 r
.7023 .61394 m .69891 .61364 L .70141 .61256 L F
.66 .112 0 r
.70346 .61225 m .7023 .61394 L .70141 .61256 L F
.70346 .61225 m .70369 .61201 L .7023 .61394 L F
.535 .416 .664 r
.37301 .76861 m .37501 .76818 L .37479 .76518 L F
.526 .464 .729 r
.37301 .76861 m .37549 .77049 L .37501 .76818 L F
.493 .518 .812 r
.68017 .62876 m .68174 .62646 L .67926 .62708 L F
.71 .737 .872 r
.50761 .71647 m .50565 .71752 L .5042 .71605 L F
.799 .734 .792 r
.68806 .62519 m .68592 .62799 L .68534 .62528 L F
.563 .514 .759 r
.29141 .60515 m .29038 .60935 L .28932 .60543 L F
.29141 .60515 m .29249 .60911 L .29038 .60935 L F
0 .218 .635 r
.70991 .7357 m .71095 .73627 L .70843 .73519 L F
.70991 .7357 m .71225 .73711 L .71095 .73627 L F
.547 .084 .106 r
.48632 .77347 m .48857 .77451 L .48992 .77316 L F
.438 0 0 r
.48857 .77451 m .49185 .7743 L .48992 .77316 L F
.866 .87 .839 r
.5609 .68523 m .56086 .68329 L .56236 .68408 L F
.858 .846 .83 r
.5645 .68129 m .56236 .68408 L .56086 .68329 L F
.774 .675 .754 r
.62726 .63273 m .62872 .63586 L .62505 .63528 L F
.789 .553 .581 r
.62505 .63528 m .62872 .63586 L .6284 .63814 L F
.01 0 .13 r
.60838 .6491 m .608 .65095 L .60639 .6517 L F
.174 .006 .399 r
.608 .65095 m .60588 .65399 L .60639 .6517 L F
.321 0 .12 r
.30448 .66515 m .30639 .6647 L .30769 .66282 L F
.464 .128 .311 r
.30639 .6647 m .30951 .66215 L .30769 .66282 L F
.049 0 0 r
.65441 .58753 m .65532 .58751 L .65651 .58687 L F
.65441 .58753 m .65328 .58851 L .65532 .58751 L F
.717 .602 .728 r
.55817 .68974 m .55949 .69268 L .55608 .69233 L F
.718 .543 .652 r
.55949 .69268 m .55611 .69495 L .55608 .69233 L F
.55949 .69268 m .55945 .69512 L .55611 .69495 L F
.691 .615 .766 r
.49678 .73052 m .49818 .73368 L .50015 .73295 L F
.974 .844 .653 r
.64898 .63612 m .64899 .63187 L .64734 .63517 L F
.9 .744 .679 r
.64835 .63832 m .64898 .63612 L .64734 .63517 L F
.329 .081 .379 r
.63925 .59978 m .64196 .59695 L .63965 .59726 L F
.803 .55 .555 r
.56528 .72173 m .56199 .71944 L .56425 .71906 L F
.56528 .72173 m .56206 .72184 L .56199 .71944 L F
.748 .651 .753 r
.56767 .7193 m .56528 .72173 L .56425 .71906 L F
.55 .518 .773 r
.40295 .76793 m .40153 .77009 L .40086 .76835 L F
.40295 .76793 m .40369 .76987 L .40153 .77009 L F
.372 .227 .552 r
.52701 .73223 m .52668 .7316 L .52619 .73001 L F
.52701 .73223 m .52782 .73032 L .52668 .7316 L F
.52701 .73223 m .52723 .73263 L .52782 .73032 L F
.462 .263 .523 r
.52701 .73223 m .52546 .73506 L .52723 .73263 L F
.748 .71 .816 r
.71093 .6151 m .70791 .61465 L .71013 .61398 L F
.396 .488 .836 r
.7123 .61343 m .71093 .6151 L .71013 .61398 L F
.7123 .61343 m .71346 .61621 L .71093 .6151 L F
.755 .639 .732 r
.56073 .71413 m .55764 .71169 L .55904 .71126 L F
.56073 .71413 m .5592 .71484 L .55764 .71169 L F
.599 .418 .609 r
.56381 .71514 m .56073 .71413 L .56311 .71367 L F
.56381 .71514 m .56099 .71627 L .56073 .71413 L F
.345 .006 .238 r
.36312 .70915 m .36216 .71084 L .36028 .71129 L F
.436 .195 .449 r
.36451 .70816 m .36216 .71084 L .36312 .70915 L F
.37 0 0 r
.33508 .64931 m .33679 .64996 L .33869 .64959 L F
.694 .964 .939 r
.34114 .6481 m .33869 .64959 L .33953 .64802 L F
.725 .989 .869 r
.33869 .64959 m .33679 .64996 L .33953 .64802 L F
.587 .339 .509 r
.59172 .70076 m .59163 .70284 L .58943 .70285 L F
.56 .317 .505 r
.59391 .70248 m .59172 .70076 L .59429 .70059 L F
.59391 .70248 m .59163 .70284 L .59172 .70076 L F
.575 .627 .867 r
.71357 .73141 m .71157 .73342 L .71066 .732 L F
.71357 .73141 m .7136 .73302 L .71157 .73342 L F
.845 .695 .696 r
.72314 .73538 m .72192 .73164 L .72227 .73259 L F
.234 0 0 r
.44093 .78354 m .43988 .7843 L .43782 .78454 L F
.193 0 0 r
.44316 .78326 m .43988 .7843 L .44093 .78354 L F
.731 .701 .823 r
.70612 .63062 m .70908 .63124 L .70803 .62967 L F
.656 .682 .862 r
.70908 .63124 m .71141 .63044 L .70803 .62967 L F
.856 .914 .871 r
.59878 .65936 m .6022 .65764 L .6013 .65711 L F
.779 .956 .928 r
.60327 .65561 m .6022 .65764 L .60375 .65628 L F
.60327 .65561 m .6013 .65711 L .6022 .65764 L F
.572 .441 .664 r
.39815 .79552 m .40079 .79487 L .398 .79498 L F
.39815 .79552 m .40011 .79537 L .40079 .79487 L F
.514 .296 .521 r
.38294 .69163 m .38113 .68985 L .3831 .68936 L F
.38294 .69163 m .3809 .69204 L .38113 .68985 L F
.372 0 0 r
.51866 .79224 m .51529 .79216 L .51666 .792 L F
.458 .076 .225 r
.42488 .72741 m .42716 .72716 L .42816 .72521 L F
.339 0 .027 r
.42716 .72716 m .43047 .72539 L .42816 .72521 L F
.667 .641 .815 r
.36146 .79734 m .36319 .8012 L .36489 .79869 L F
.634 .091 0 r
.71502 .70733 m .71134 .70592 L .71379 .70874 L F
.602 .255 .354 r
.71379 .70874 m .71377 .71013 L .71502 .70733 L F
.617 .328 .456 r
.71693 .71013 m .71502 .70733 L .71377 .71013 L F
.71693 .71013 m .71707 .70815 L .71502 .70733 L F
.799 .624 .665 r
.70067 .61919 m .70126 .62222 L .69833 .62132 L F
.822 .579 .572 r
.55415 .70878 m .55098 .70839 L .55126 .70594 L F
.749 .507 .566 r
.55415 .70878 m .5507 .71075 L .55098 .70839 L F
.55415 .70878 m .55411 .71104 L .5507 .71075 L F
.558 .374 .588 r
.55638 .70816 m .55415 .70878 L .55632 .70605 L F
.73 .594 .704 r
.55638 .70816 m .55411 .71104 L .55415 .70878 L F
.139 0 .273 r
.28651 .6304 m .28733 .62996 L .28607 .632 L F
.165 0 .055 r
.336 .67573 m .33283 .67819 L .33367 .67683 L F
.956 .864 .707 r
.64846 .62936 m .65072 .62734 L .65057 .62671 L F
.64846 .62936 m .64949 .63024 L .65072 .62734 L F
.458 .221 .466 r
.37434 .69788 m .37395 .70004 L .37206 .70044 L F
.397 .169 .448 r
.37622 .69733 m .37395 .70004 L .37434 .69788 L F
.361 .075 .336 r
.34973 .70514 m .35216 .7028 L .35028 .70332 L F
.789 .68 .743 r
.59132 .67357 m .5894 .67619 L .5925 .6762 L F
.699 .469 .572 r
.58911 .67859 m .5925 .6762 L .5894 .67619 L F
.58911 .67859 m .59265 .67866 L .5925 .6762 L F
.743 .504 .568 r
.5925 .6762 m .59265 .67866 L .59699 .67846 L F
.833 .967 .645 r
.72953 .72957 m .72798 .7327 L .73027 .73011 L F
.72953 .72957 m .72757 .73257 L .72798 .7327 L F
.5 .552 .84 r
.52398 .71908 m .52332 .72219 L .52305 .72171 L F
.52398 .71908 m .5253 .72209 L .52332 .72219 L F
.37 .176 .483 r
.29662 .61383 m .29639 .61655 L .29459 .61693 L F
.486 .368 .644 r
.29639 .61655 m .29475 .61922 L .29459 .61693 L F
.172 .28 .735 r
.682 .63521 m .68336 .6385 L .68396 .63719 L F
.345 .492 .862 r
.68336 .6385 m .68473 .63932 L .68396 .63719 L F
.593 .783 .971 r
.37626 .65471 m .37286 .65414 L .37552 .65384 L F
1 .808 .483 r
.37552 .65384 m .3753 .65545 L .37626 .65471 L F
.574 .45 .673 r
.3745 .76275 m .37665 .76247 L .37631 .76 L F
.467 .294 .562 r
.37479 .76518 m .37665 .76247 L .3745 .76275 L F
.903 .74 .67 r
.64919 .64371 m .64818 .64059 L .64632 .64334 L F
.844 .673 .67 r
.64614 .64574 m .64919 .64371 L .64632 .64334 L F
.64614 .64574 m .64801 .64634 L .64919 .64371 L F
.22 .71 .924 r
.45019 .72496 m .45226 .72494 L .45359 .72538 L F
.033 .604 .724 r
.4545 .72532 m .45359 .72538 L .45226 .72494 L F
.4545 .72532 m .45569 .72532 L .45359 .72538 L F
.887 .972 .832 r
.6646 .61269 m .66535 .61311 L .66779 .60981 L F
.68 .133 0 r
.42399 .74381 m .42469 .74519 L .42253 .74553 L F
.42399 .74381 m .42611 .74573 L .42469 .74519 L F
.693 .326 .348 r
.42793 .74463 m .42611 .74573 L .42399 .74381 L F
.786 .829 .886 r
.70167 .57561 m .70564 .57475 L .70416 .57287 L F
.704 .701 .845 r
.70416 .57287 m .70564 .57475 L .70657 .57318 L F
.071 0 0 r
.34668 .67378 m .34484 .6744 L .3428 .67463 L F
.233 .736 .674 r
.34745 .67351 m .34668 .67378 L .34874 .67269 L F
.34745 .67351 m .34484 .6744 L .34668 .67378 L F
.12 0 0 r
.3314 .73176 m .33094 .73065 L .33292 .73006 L F
.3314 .73176 m .32961 .73255 L .33094 .73065 L F
.78 .794 .864 r
.72054 .61846 m .71846 .62008 L .71683 .61888 L F
.76 .665 .757 r
.69541 .62121 m .69621 .62422 L .69231 .62393 L F
.762 .654 .742 r
.69621 .62422 m .69377 .62538 L .69231 .62393 L F
.67 .611 .78 r
.69833 .62132 m .69621 .62422 L .69541 .62121 L F
.822 .648 .667 r
.72842 .73756 m .73127 .73556 L .72835 .73533 L F
.72842 .73756 m .73016 .73871 L .73127 .73556 L F
.105 0 0 r
.46166 .73651 m .4624 .73682 L .46111 .73664 L F
.46166 .73651 m .46392 .73638 L .4624 .73682 L F
.686 .653 .812 r
.55632 .70605 m .55341 .70388 L .55462 .70304 L F
.961 .704 .499 r
.55638 .70816 m .55496 .70798 L .55632 .70605 L F
.219 0 0 r
.48795 .72985 m .48448 .73112 L .48581 .73066 L F
.778 .615 .677 r
.68734 .62212 m .68806 .62519 L .68665 .624 L F
.622 .616 .824 r
.68922 .62125 m .68734 .62212 L .68561 .61982 L F
.681 .554 .705 r
.69039 .62447 m .68734 .62212 L .68922 .62125 L F
.69039 .62447 m .68806 .62519 L .68734 .62212 L F
.7 .774 .909 r
.37286 .65414 m .37084 .65518 L .36941 .65377 L F
.387 .058 .281 r
.52669 .77868 m .52845 .77829 L .52937 .77584 L F
.605 .322 .462 r
.52845 .77829 m .53155 .7756 L .52937 .77584 L F
.107 0 0 r
.41987 .7893 m .41896 .78954 L .4168 .78969 L F
0 0 0 r
.42163 .78904 m .41896 .78954 L .41987 .7893 L F
.217 0 0 r
.40184 .73318 m .40059 .73426 L .40385 .73283 L F
.557 .337 .536 r
.61538 .63237 m .61805 .62974 L .6158 .62976 L F
.729 .416 .45 r
.70831 .70792 m .71134 .70592 L .70793 .70603 L F
.70831 .70792 m .71013 .70788 L .71134 .70592 L F
.759 .455 .469 r
.71013 .70788 m .71379 .70874 L .71134 .70592 L F
.655 .263 .291 r
.32797 .67948 m .32798 .68099 L .32422 .68078 L F
.62 .235 .292 r
.32798 .68092 m .33006 .68109 L .32798 .68099 L F
.32868 .68003 m .33006 .68109 L .32798 .68092 L F
.597 .275 .394 r
.32772 .68112 m .32798 .68099 L .33006 .68109 L F
.322 0 .09 r
.33168 .6799 m .32772 .68112 L .33006 .68109 L F
.33168 .6799 m .33021 .68186 L .32781 .68115 L F
.597 .275 .394 r
.32772 .68112 m .32613 .68327 L .32798 .68099 L F
.284 .06 .387 r
.33021 .68186 m .32865 .683 L .32773 .68114 L F
.32773 .68112 m .32773 .68114 L .32772 .68112 L F
.33021 .68186 m .32773 .68114 L .32773 .68112 L F
.62 .303 .411 r
.32773 .68116 m .32613 .68327 L .32506 .68303 L F
.32798 .68099 m .32774 .68129 L .32773 .68116 L F
.32774 .68129 m .32613 .68327 L .32773 .68116 L F
.322 0 .09 r
.32774 .68112 m .32773 .68112 L .32772 .68112 L F
.62 .303 .411 r
.3278 .68107 m .32506 .68303 L .32408 .68281 L F
.32798 .68099 m .32506 .68303 L .3278 .68107 L F
.322 0 .09 r
.32786 .68108 m .32781 .68115 L .32773 .68112 L F
.32786 .68108 m .32773 .68112 L .32774 .68112 L F
.33168 .6799 m .32781 .68115 L .32786 .68108 L F
.62 .235 .292 r
.32797 .67948 m .32868 .68003 L .32798 .68092 L F
.353 0 0 r
.72114 .71588 m .71864 .71564 L .71901 .71613 L F
.199 .09 .497 r
.31906 .68344 m .31808 .68259 L .32021 .68138 L F
.31906 .68344 m .31775 .68426 L .31808 .68259 L F
.755 .693 .792 r
.55377 .69742 m .55251 .69427 L .55389 .6952 L F
.865 .841 .819 r
.55608 .69233 m .55389 .6952 L .55251 .69427 L F
.637 .483 .657 r
.55611 .69495 m .55389 .6952 L .55608 .69233 L F
.76 .673 .766 r
.55611 .69495 m .55377 .69742 L .55389 .6952 L F
.817 .775 .813 r
.64818 .65156 m .64774 .64893 L .64541 .6517 L F
.719 .914 .961 r
.32721 .71397 m .32862 .71207 L .32919 .71313 L F
.32721 .71397 m .32583 .71344 L .32862 .71207 L F
.65 .846 .975 r
.38244 .80566 m .38438 .80666 L .38601 .80572 L F
.574 .496 .73 r
.40074 .75705 m .40121 .75954 L .39926 .75987 L F
.52 .441 .707 r
.40295 .76374 m .40273 .76351 L .40282 .76343 L F
.40295 .76374 m .40047 .7653 L .4002 .76412 L F
.40273 .76351 m .4002 .76412 L .39926 .75987 L F
.40295 .76374 m .4002 .76412 L .40273 .76351 L F
.48 .31 .573 r
.40281 .76349 m .40386 .76457 L .40198 .7647 L F
.603 .467 .669 r
.40387 .76195 m .40295 .76374 L .40121 .75954 L F
.512 .822 1 r
.40198 .7647 m .40047 .7653 L .40295 .76374 L F
.48 .31 .573 r
.40387 .76195 m .40198 .7647 L .40295 .76374 L F
.40289 .76338 m .40295 .76346 L .40281 .76349 L F
.40295 .76346 m .40386 .76457 L .40281 .76349 L F
.40387 .76195 m .40387 .76261 L .40289 .76338 L F
.40387 .76261 m .40386 .76457 L .40289 .76338 L F
.52 .441 .707 r
.40282 .76343 m .39926 .75987 L .40121 .75954 L F
.40273 .76351 m .39926 .75987 L .40282 .76343 L F
.561 .403 .624 r
.37772 .75185 m .37991 .75149 L .37976 .74913 L F
.554 .431 .666 r
.37772 .75185 m .38023 .75416 L .37991 .75149 L F
.37772 .75185 m .37804 .75461 L .38023 .75416 L F
.093 0 .035 r
.53587 .78085 m .53827 .77882 L .53783 .78133 L F
.416 .144 .39 r
.53542 .78389 m .53587 .78085 L .53783 .78133 L F
.621 .434 .608 r
.36983 .77924 m .37207 .78126 L .37206 .77887 L F
.36983 .77924 m .36978 .78159 L .37207 .78126 L F
.638 .153 .086 r
.65651 .58687 m .65894 .5886 L .65981 .58721 L F
.51 0 0 r
.66087 .58818 m .65981 .58721 L .65894 .5886 L F
.66087 .58818 m .66293 .58886 L .65981 .58721 L F
.727 .766 .884 r
.72122 .58913 m .72008 .59046 L .7187 .58887 L F
.7187 .58887 m .72008 .59046 L .72122 .58913 L F
.503 .848 .995 r
.46857 .76818 m .46838 .76755 L .46943 .76713 L F
.75 .621 .715 r
.57872 .71936 m .57643 .72216 L .57647 .7197 L F
.67 .502 .649 r
.57872 .71936 m .57966 .72256 L .57643 .72216 L F
.647 .602 .79 r
.58086 .71692 m .57872 .71936 L .57819 .71671 L F
.602 .535 .751 r
.58086 .71692 m .58154 .7203 L .57872 .71936 L F
.653 .493 .654 r
.58189 .7219 m .57872 .71936 L .58154 .7203 L F
.58189 .7219 m .57966 .72256 L .57872 .71936 L F
.699 .741 .884 r
.69066 .57747 m .69179 .57889 L .68851 .57839 L F
.761 .628 .713 r
.68851 .57839 m .69179 .57889 L .68923 .58058 L F
.749 .756 .858 r
.69465 .57636 m .69179 .57889 L .69066 .57747 L F
.73 .513 .597 r
.60154 .67887 m .60372 .68116 L .60375 .67904 L F
.634 .421 .576 r
.60372 .68116 m .60665 .67872 L .60375 .67904 L F
.576 .233 .351 r
.43709 .74178 m .43748 .74376 L .43396 .74372 L F
.503 .186 .363 r
.43924 .7429 m .43748 .74376 L .43709 .74178 L F
.683 .766 .914 r
.5045 .72985 m .50564 .73104 L .508 .7302 L F
.865 .841 .819 r
.55608 .69233 m .55251 .69427 L .55535 .69207 L F
.979 .916 .613 r
.55608 .69233 m .55657 .68869 L .55817 .68974 L F
.55608 .69233 m .55535 .69207 L .55657 .68869 L F
.946 .952 .739 r
.73115 .72649 m .72953 .72957 L .73027 .73011 L F
.359 .001 .213 r
.34789 .70574 m .34878 .7074 L .34973 .70514 L F
.34789 .70574 m .3468 .70791 L .34878 .7074 L F
.315 .476 .861 r
.37787 .65728 m .37692 .65817 L .37611 .65729 L F
.37787 .65728 m .37945 .65988 L .37692 .65817 L F
.866 .87 .839 r
.5609 .68523 m .55878 .68563 L .56086 .68329 L F
.196 0 .33 r
.39617 .67285 m .39413 .6758 L .39468 .67375 L F
.755 .629 .721 r
.508 .7302 m .51116 .73042 L .51011 .72745 L F
.646 .606 .795 r
.51116 .73042 m .51222 .72703 L .51011 .72745 L F
.51116 .73042 m .51359 .73025 L .51222 .72703 L F
.428 .303 .607 r
.51116 .73042 m .51312 .73172 L .51359 .73025 L F
.51116 .73042 m .51114 .73285 L .51312 .73172 L F
.674 .523 .673 r
.57149 .72482 m .56884 .72696 L .56879 .72492 L F
.799 .734 .792 r
.68806 .62519 m .68534 .62528 L .68665 .624 L F
.071 0 .204 r
.67732 .61577 m .67758 .61458 L .67699 .61618 L F
.48 .481 .781 r
.67905 .61348 m .67758 .61458 L .67658 .611 L F
.492 .606 .894 r
.67031 .62216 m .67185 .62039 L .6693 .62062 L F
.67031 .62216 m .67245 .6218 L .67185 .62039 L F
.493 .456 .744 r
.67031 .62216 m .67336 .62417 L .67245 .6218 L F
.922 .838 .744 r
.70914 .71271 m .7068 .71636 L .70737 .71414 L F
.729 .539 .635 r
.70914 .71271 m .71021 .71647 L .7068 .71636 L F
.576 .449 .67 r
.71247 .71598 m .70914 .71271 L .71124 .71437 L F
.71247 .71598 m .71021 .71647 L .70914 .71271 L F
.39 .294 .625 r
.36385 .68963 m .3657 .68892 L .36542 .68656 L F
.372 .157 .452 r
.36363 .69164 m .3657 .68892 L .36385 .68963 L F
.385 .095 .344 r
.37395 .70004 m .37155 .70267 L .37206 .70044 L F
.797 .769 .827 r
.3932 .66828 m .39087 .67063 L .38976 .66867 L F
.774 .806 .878 r
.69851 .63581 m .70147 .63587 L .70049 .63438 L F
.686 .722 .877 r
.70049 .63438 m .70147 .63587 L .70357 .63487 L F
.646 .559 .743 r
.52959 .72796 m .52782 .73032 L .52742 .72815 L F
.52959 .72796 m .53065 .73026 L .52782 .73032 L F
.366 .726 .988 r
.52723 .73263 m .52668 .7316 L .52782 .73032 L F
.699 .598 .74 r
.53065 .73026 m .52723 .73263 L .52782 .73032 L F
0 0 0 r
.53727 .77356 m .53826 .77253 L .54013 .77057 L F
.116 .341 .808 r
.53727 .77356 m .53996 .7758 L .53826 .77253 L F
.854 .397 .068 r
.5065 .78691 m .50528 .78638 L .50403 .78418 L F
.8 .327 .099 r
.50871 .789 m .50528 .78638 L .5065 .78691 L F
.572 .569 .812 r
.51894 .71834 m .517 .71892 L .51648 .71752 L F
.041 0 0 r
.45569 .72532 m .4579 .72529 L .45907 .72519 L F
.151 0 0 r
.4579 .72529 m .46123 .72524 L .45907 .72519 L F
.906 .744 .67 r
.69437 .61904 m .69314 .61621 L .69504 .6174 L F
.69437 .61904 m .69198 .61868 L .69314 .61621 L F
.899 .778 .718 r
.69437 .61904 m .69251 .62193 L .69198 .61868 L F
.72 .513 .61 r
.69541 .62121 m .69251 .62193 L .69437 .61904 L F
.459 .087 .245 r
.31894 .68584 m .31775 .68426 L .31906 .68344 L F
.31894 .68584 m .31654 .68627 L .31775 .68426 L F
.742 .282 .158 r
.71929 .71025 m .7201 .70907 L .71707 .70815 L F
.452 0 0 r
.72237 .70941 m .7201 .70907 L .71929 .71025 L F
.431 .869 .905 r
.41099 .79149 m .40989 .79153 L .40892 .79225 L F
.488 .247 .474 r
.61695 .6894 m .61453 .69178 L .61468 .68962 L F
.618 .563 .77 r
.52877 .72475 m .52742 .72815 L .52656 .72512 L F
.52877 .72475 m .52959 .72796 L .52742 .72815 L F
.133 0 0 r
.3182 .71453 m .31999 .71475 L .3214 .71483 L F
.522 .904 .949 r
.3214 .71483 m .32241 .71381 L .32268 .7147 L F
.3214 .71483 m .31999 .71475 L .32241 .71381 L F
.961 .7 .494 r
.682 .63521 m .68044 .63249 L .68372 .63287 L F
.682 .63521 m .6805 .63485 L .68044 .63249 L F
0 .118 .661 r
.682 .63521 m .68278 .63537 L .6805 .63485 L F
.682 .63521 m .68396 .63719 L .68278 .63537 L F
.187 .708 .873 r
.42895 .74581 m .42611 .74573 L .42793 .74463 L F
.543 .285 .475 r
.29994 .66796 m .30214 .66771 L .30262 .66564 L F
.278 .048 .374 r
.30262 .66564 m .30375 .66685 L .30448 .66515 L F
.30262 .66564 m .30214 .66771 L .30375 .66685 L F
.388 .026 .225 r
.32215 .6812 m .31906 .68344 L .32021 .68138 L F
.858 .846 .83 r
.5645 .68129 m .56086 .68329 L .56323 .68039 L F
.875 .862 .824 r
.56653 .67855 m .5645 .68129 L .56323 .68039 L F
.427 .21 .48 r
.69588 .71402 m .69807 .71128 L .69578 .71186 L F
.537 .393 .632 r
.51311 .71412 m .51014 .71443 L .51182 .71286 L F
.507 .668 .936 r
.5142 .7128 m .51311 .71412 L .51182 .71286 L F
.555 .52 .771 r
.5142 .7128 m .51321 .71657 L .51311 .71412 L F
.732 .847 .935 r
.72093 .74125 m .7221 .74244 L .72427 .74106 L F
.033 0 .25 r
.53783 .78133 m .53827 .77882 L .53976 .77781 L F
.732 .63 .745 r
.55764 .71169 m .5592 .71484 L .55716 .71369 L F
.795 .709 .769 r
.5592 .71484 m .5554 .7164 L .55716 .71369 L F
.056 0 0 r
.46693 .7355 m .46491 .73626 L .46392 .73638 L F
0 0 0 r
.46803 .73533 m .46693 .7355 L .46895 .73452 L F
.46803 .73533 m .46491 .73626 L .46693 .7355 L F
.976 .674 .359 r
.59006 .67039 m .59132 .67357 L .59151 .67096 L F
.839 .421 .244 r
.51195 .79178 m .50871 .789 L .50979 .78979 L F
.702 .485 .591 r
.60933 .6924 m .60933 .69504 L .60722 .69476 L F
.653 .445 .59 r
.61208 .69386 m .60933 .6924 L .61291 .69228 L F
.61208 .69386 m .60933 .69504 L .60933 .6924 L F
.208 0 .103 r
.60838 .6491 m .61134 .64693 L .60956 .64886 L F
.244 0 .205 r
.60978 .65024 m .60838 .6491 L .60956 .64886 L F
.60978 .65024 m .608 .65095 L .60838 .6491 L F
.984 .712 .422 r
.69599 .72789 m .69625 .72855 L .69492 .72717 L F
.067 .519 .898 r
.69716 .72817 m .69706 .72821 L .69471 .72455 L F
.69706 .72821 m .69625 .72855 L .69581 .7274 L F
.69706 .72821 m .69581 .7274 L .69471 .72455 L F
.984 .712 .422 r
.69471 .72455 m .69599 .72789 L .69492 .72717 L F
0 .483 .853 r
.69625 .72855 m .69762 .72853 L .69492 .72717 L F
.428 0 0 r
.69492 .72717 m .69731 .72837 L .69635 .72814 L F
.69731 .72837 m .69762 .72853 L .69749 .72849 L F
.69731 .72837 m .69749 .72849 L .69635 .72814 L F
.69492 .72717 m .69635 .72814 L .69393 .72651 L F
.69492 .72717 m .69393 .72651 L .69392 .72651 L F
0 .483 .853 r
.69625 .72855 m .69858 .72923 L .69762 .72853 L F
.504 .386 .653 r
.37631 .76 m .37791 .75659 L .376 .75778 L F
.205 .287 .727 r
.73044 .61359 m .73242 .61553 L .73123 .61682 L F
0 0 0 r
.71064 .57601 m .70969 .57831 L .71033 .57706 L F
.017 .154 .665 r
.71033 .57706 m .70969 .57831 L .71073 .57879 L F
.487 0 0 r
.34965 .65043 m .35153 .6512 L .35285 .65126 L F
.249 .76 .85 r
.35153 .6512 m .35513 .65089 L .35285 .65126 L F
.916 .741 .649 r
.398 .79498 m .39861 .79795 L .39773 .79796 L F
.96 .681 .462 r
.39861 .79795 m .39778 .79987 L .39773 .79796 L F
.39861 .79795 m .39919 .80052 L .39778 .79987 L F
.54 .419 .664 r
.39861 .79795 m .40079 .79487 L .398 .79498 L F
.539 .436 .686 r
.40093 .7981 m .40148 .80052 L .39861 .79795 L F
.081 .637 .803 r
.40148 .80052 m .39919 .80052 L .39861 .79795 L F
.691 .615 .766 r
.49678 .73052 m .50015 .73295 L .49908 .72978 L F
.752 .658 .757 r
.49908 .72978 m .50015 .73295 L .50235 .73024 L F
.077 .534 .902 r
.72491 .71016 m .7238 .71033 L .72237 .70941 L F
.72491 .71016 m .72581 .71097 L .7238 .71033 L F
.529 .419 .672 r
.38644 .73871 m .38847 .74064 L .38901 .73849 L F
.38644 .73871 m .38649 .74118 L .38847 .74064 L F
.697 .777 .913 r
.69055 .63859 m .69404 .63908 L .6927 .63758 L F
.76 .755 .848 r
.69404 .63908 m .69591 .63799 L .6927 .63758 L F
.419 0 .063 r
.4407 .7754 m .44294 .77526 L .44431 .77368 L F
.3 0 0 r
.44294 .77526 m .44643 .77333 L .44431 .77368 L F
.805 .622 .653 r
.56627 .71404 m .56381 .71514 L .56311 .71367 L F
.56627 .71404 m .56618 .71565 L .56381 .71514 L F
0 0 0 r
.42298 .77633 m .41992 .7788 L .42162 .77759 L F
.007 0 0 r
.42284 .77745 m .42298 .77633 L .42162 .77759 L F
.42284 .77745 m .42422 .77589 L .42298 .77633 L F
.743 .537 .615 r
.59265 .67866 m .59449 .68114 L .59699 .67846 L F
.677 .446 .564 r
.59449 .68114 m .59803 .67873 L .59699 .67846 L F
.549 .238 .393 r
.60956 .64886 m .61134 .64693 L .61312 .64827 L F
.867 .491 .331 r
.69263 .7243 m .69189 .72509 L .68999 .72191 L F
.984 .712 .423 r
.69471 .72455 m .69189 .72509 L .69263 .7243 L F
.783 .767 .839 r
.68944 .58599 m .69098 .58715 L .69321 .58488 L F
.602 .24 .327 r
.46843 .77253 m .47187 .77067 L .46842 .77075 L F
.46843 .77253 m .47071 .77291 L .47187 .77067 L F
.442 .029 .16 r
.47071 .77291 m .47411 .77089 L .47187 .77067 L F
.549 .508 .763 r
.72506 .60228 m .72389 .60486 L .72263 .60339 L F
.7 .537 .664 r
.72389 .60486 m .72346 .60608 L .72263 .60339 L F
.536 .648 .906 r
.29141 .60515 m .28932 .60543 L .28769 .60319 L F
.643 .791 .953 r
.68823 .63943 m .68951 .63753 L .68751 .63866 L F
.68823 .63943 m .69055 .63859 L .68951 .63753 L F
.459 .225 .471 r
.36028 .71129 m .3599 .71356 L .35795 .71399 L F
.456 .222 .469 r
.36185 .71302 m .36028 .71129 L .36216 .71084 L F
.36185 .71302 m .3599 .71356 L .36028 .71129 L F
.361 0 .093 r
.33343 .71303 m .33694 .71088 L .33495 .71102 L F
.365 .247 .583 r
.36658 .67893 m .36862 .68023 L .36902 .67823 L F
.36658 .67893 m .36676 .68193 L .36862 .68023 L F
.875 .862 .824 r
.56653 .67855 m .56323 .68039 L .56558 .67775 L F
.805 .852 .884 r
.56794 .67518 m .56653 .67855 L .56558 .67775 L F
.56794 .67518 m .56924 .67615 L .56653 .67855 L F
.415 .336 .66 r
.29807 .6106 m .29834 .6131 L .29662 .61383 L F
.433 .228 .501 r
.2984 .61577 m .29662 .61383 L .29834 .6131 L F
.2984 .61577 m .29639 .61655 L .29662 .61383 L F
.819 .82 .85 r
.69539 .5843 m .69819 .58368 L .69744 .5829 L F
.907 .917 .814 r
.69744 .5829 m .69819 .58368 L .69978 .58111 L F
.356 .784 .971 r
.36171 .67081 m .35847 .67063 L .35994 .67069 L F
.807 .844 .878 r
.55341 .70388 m .55126 .70594 L .54958 .70531 L F
.951 .713 .542 r
.55126 .70594 m .54972 .7077 L .54958 .70531 L F
.55126 .70594 m .55098 .70839 L .54972 .7077 L F
.451 .183 .415 r
.41873 .74658 m .41819 .74855 L .41621 .74904 L F
.387 .124 .389 r
.42059 .74606 m .41819 .74855 L .41873 .74658 L F
.53 0 0 r
.72671 .62197 m .72761 .62256 L .72711 .6226 L F
.595 .201 .266 r
.72671 .62197 m .7296 .62225 L .72761 .62256 L F
.334 0 0 r
.43047 .72539 m .43202 .72588 L .43363 .72467 L F
.386 0 0 r
.43202 .72588 m .43573 .72464 L .43363 .72467 L F
.53 .334 .56 r
.60312 .63841 m .60517 .63547 L .60295 .63582 L F
.983 .703 .339 r
.53689 .74648 m .53616 .7464 L .53589 .74342 L F
0 0 .517 r
.53589 .74342 m .53689 .74538 L .53689 .74648 L F
.876 .994 .773 r
.53689 .74648 m .53689 .74538 L .53616 .7464 L F
.486 .264 .503 r
.61859 .64383 m .61849 .64591 L .61636 .64644 L F
.512 .286 .508 r
.61859 .64383 m .62094 .64535 L .61849 .64591 L F
.558 .254 .408 r
.62118 .64374 m .62094 .64535 L .61859 .64383 L F
.788 .537 .558 r
.56199 .71944 m .55872 .72138 L .55847 .71957 L F
.56199 .71944 m .56206 .72184 L .55872 .72138 L F
.676 .59 .752 r
.56425 .71906 m .56199 .71944 L .56099 .71627 L F
.164 0 0 r
.46683 .72505 m .46885 .72485 L .47019 .72429 L F
.176 0 0 r
.47019 .72429 m .471 .72486 L .4723 .72448 L F
.47019 .72429 m .46885 .72485 L .471 .72486 L F
.584 .744 .952 r
.49011 .72947 m .49125 .73071 L .49343 .73028 L F
.705 .64 .782 r
.37935 .79804 m .37889 .79998 L .38142 .7973 L F
.197 0 .278 r
.38142 .7973 m .37889 .79998 L .3824 .79738 L F
.564 .785 .982 r
.71066 .732 m .7082 .73242 L .70698 .73147 L F
.54 .401 .641 r
.37173 .77606 m .37359 .77573 L .37349 .77329 L F
.638 .492 .668 r
.37173 .77606 m .37435 .77858 L .37359 .77573 L F
.37173 .77606 m .37206 .77887 L .37435 .77858 L F
.76 .724 .82 r
.69665 .6161 m .69504 .6174 L .69314 .61621 L F
.653 .79 .948 r
.48148 .72309 m .47752 .72228 L .47998 .7218 L F
.73 .789 .899 r
.48339 .72199 m .48148 .72309 L .47998 .7218 L F
.771 .692 .776 r
.5742 .72503 m .57512 .72757 L .57245 .7272 L F
.785 .517 .531 r
.57512 .72757 m .57435 .72946 L .57245 .7272 L F
.616 .549 .756 r
.57644 .72441 m .57512 .72757 L .5742 .72503 L F
.57644 .72441 m .57757 .72733 L .57512 .72757 L F
.734 .573 .674 r
.57757 .72733 m .57435 .72946 L .57512 .72757 L F
.756 .607 .692 r
.55904 .71126 m .55638 .70816 L .55966 .70867 L F
.577 .269 .41 r
.61049 .63451 m .6128 .63456 L .61063 .63295 L F
.57 .273 .425 r
.61063 .63295 m .6128 .63456 L .61303 .6328 L F
0 0 .499 r
.55462 .70304 m .5542 .7025 L .55208 .70013 L F
.854 .781 .779 r
.55462 .70304 m .55167 .70293 L .5542 .7025 L F
.55462 .70304 m .55341 .70388 L .55167 .70293 L F
.866 .517 .388 r
.50528 .78638 m .50234 .78348 L .50403 .78418 L F
.845 .609 .582 r
.56653 .72986 m .56379 .72712 L .56653 .72755 L F
.69 .533 .669 r
.56884 .72696 m .56653 .72986 L .56653 .72755 L F
.984 .721 .441 r
.67477 .62187 m .6758 .62207 L .67482 .61881 L F
.61 .553 .766 r
.67482 .61881 m .6758 .62207 L .67819 .62124 L F
0 0 .462 r
.67713 .62311 m .6758 .62207 L .67477 .62187 L F
.577 .472 .698 r
.35887 .79632 m .36146 .79734 L .36176 .79517 L F
.35887 .79632 m .35931 .79775 L .36146 .79734 L F
.021 0 0 r
.29418 .67244 m .29665 .6703 L .2951 .67079 L F
.836 .705 .718 r
.69012 .71428 m .68747 .71389 L .68927 .71096 L F
.896 .754 .697 r
.68875 .71601 m .68747 .71389 L .69012 .71428 L F
.273 .338 .748 r
.69157 .71299 m .69012 .71428 L .68927 .71096 L F
.392 .542 .886 r
.69157 .71299 m .69366 .71557 L .69012 .71428 L F
.665 .597 .768 r
.69251 .62193 m .69039 .62447 L .68922 .62125 L F
.633 .548 .741 r
.69251 .62193 m .69231 .62393 L .69039 .62447 L F
.679 .615 .777 r
.69377 .62538 m .69039 .62447 L .69231 .62393 L F
0 .567 .751 r
.33395 .85158 m .33545 .85171 L .33461 .85165 L F
.261 .752 .915 r
.46123 .72524 m .46336 .72507 L .46467 .72536 L F
.074 .635 .767 r
.46336 .72507 m .46683 .72505 L .46467 .72536 L F
.576 .538 .776 r
.40295 .76793 m .40086 .76835 L .39981 .76512 L F
.247 0 0 r
.4168 .78969 m .41494 .79098 L .41314 .79124 L F
0 0 0 r
.41896 .78954 m .41494 .79098 L .4168 .78969 L F
.574 .618 .859 r
.52398 .71908 m .52305 .72171 L .52102 .71798 L F
.531 .296 .503 r
.35911 .69725 m .36174 .69474 L .35944 .69522 L F
.537 .797 .993 r
.49908 .72978 m .50235 .73024 L .50111 .72932 L F
.576 .705 .93 r
.50235 .73024 m .50343 .72849 L .50111 .72932 L F
.50235 .73024 m .5045 .72985 L .50343 .72849 L F
.78 .794 .864 r
.72054 .61846 m .71683 .61888 L .71843 .61784 L F
.472 .257 .506 r
.72284 .61654 m .72054 .61846 L .71843 .61784 L F
.72284 .61654 m .7224 .61874 L .72054 .61846 L F
.366 .726 .988 r
.52723 .73263 m .52881 .73164 L .52668 .7316 L F
.699 .598 .74 r
.53065 .73026 m .53105 .73307 L .52723 .73263 L F
.703 .874 .477 r
.52932 .73044 m .52924 .73058 L .52881 .73164 L F
.364 .721 .988 r
.52723 .73263 m .52841 .73265 L .52881 .73164 L F
.241 .71 .944 r
.53105 .73307 m .5306 .73268 L .52723 .73263 L F
.141 0 0 r
.52881 .73164 m .52572 .73385 L .52668 .7316 L F
.52881 .73164 m .52759 .73328 L .52572 .73385 L F
.703 .874 .477 r
.52924 .73058 m .52759 .73328 L .52881 .73164 L F
.364 .721 .988 r
.52841 .73265 m .5306 .73268 L .52881 .73164 L F
.576 .578 .819 r
.52877 .72475 m .52656 .72512 L .5253 .72209 L F
.878 .869 .825 r
.66649 .60494 m .66781 .60625 L .66992 .6027 L F
.709 .8 .921 r
.6927 .63758 m .69591 .63799 L .69473 .63657 L F
.754 .813 .899 r
.69473 .63657 m .69591 .63799 L .69851 .63581 L F
.764 .644 .729 r
.57966 .72256 m .57644 .72441 L .57643 .72216 L F
.826 .412 .259 r
.39664 .79661 m .39773 .79796 L .39465 .79661 L F
.916 .741 .649 r
.398 .79498 m .39773 .79796 L .39664 .79661 L F
.152 0 .006 r
.34083 .72515 m .33953 .72712 L .33817 .72695 L F
.13 0 0 r
.34133 .72628 m .34083 .72515 L .34266 .72439 L F
.34133 .72628 m .33953 .72712 L .34083 .72515 L F
.534 .707 .951 r
.28098 .60136 m .28029 .60307 L .27885 .60152 L F
.28098 .60136 m .28101 .60302 L .28029 .60307 L F
.346 0 0 r
.36372 .79624 m .36739 .79557 L .36352 .79534 L F
.36372 .79624 m .3678 .79672 L .36739 .79557 L F
.635 .629 .827 r
.36739 .79557 m .36996 .79629 L .36929 .79517 L F
.427 .21 .48 r
.69588 .71402 m .69768 .71357 L .69807 .71128 L F
.533 .362 .595 r
.37976 .74913 m .38183 .74876 L .38182 .74637 L F
.485 .318 .578 r
.37991 .75149 m .38183 .74876 L .37976 .74913 L F
.438 .162 .396 r
.39083 .73592 m .39241 .73734 L .39314 .73577 L F
.39083 .73592 m .39042 .73778 L .39241 .73734 L F
.023 0 .261 r
.69616 .72284 m .69541 .72228 L .69642 .72115 L F
.69616 .72284 m .69471 .72455 L .69541 .72228 L F
.151 0 0 r
.33953 .72712 m .33656 .72869 L .33817 .72695 L F
.658 .487 .642 r
.72291 .60821 m .72126 .61121 L .72104 .60867 L F
.708 .303 .279 r
.49242 .77946 m .48981 .78042 L .48975 .77906 L F
.49242 .77946 m .49309 .7806 L .48981 .78042 L F
.399 .244 .552 r
.62505 .63528 m .62513 .63779 L .62327 .63812 L F
.93 .958 .772 r
.62513 .63779 m .62319 .64243 L .62327 .63812 L F
.651 .31 .381 r
.61636 .64644 m .6161 .64817 L .61312 .64827 L F
.554 .288 .467 r
.61849 .64591 m .6161 .64817 L .61636 .64644 L F
.165 0 .055 r
.336 .67573 m .33456 .67805 L .33283 .67819 L F
0 0 0 r
.33589 .67705 m .336 .67573 L .33752 .67571 L F
.33589 .67705 m .33456 .67805 L .336 .67573 L F
.08 0 0 r
.31722 .65677 m .31904 .6562 L .31983 .65557 L F
.236 0 .129 r
.31722 .65677 m .31791 .65823 L .31904 .6562 L F
.31722 .65677 m .3161 .65892 L .31791 .65823 L F
.687 .588 .739 r
.68851 .57839 m .68923 .58058 L .68733 .58093 L F
0 0 0 r
.34299 .70922 m .34196 .70987 L .34491 .70855 L F
.577 .591 .83 r
.38747 .66841 m .38412 .66591 L .38623 .66543 L F
.438 .498 .824 r
.38839 .66646 m .38747 .66841 L .38623 .66543 L F
.492 .563 .856 r
.38839 .66646 m .38976 .66867 L .38747 .66841 L F
.417 0 0 r
.47411 .77089 m .47627 .77101 L .47743 .77033 L F
.547 .081 .099 r
.47627 .77101 m .47956 .77067 L .47743 .77033 L F
0 0 0 r
.62319 .64243 m .62299 .64281 L .62118 .64374 L F
.93 .958 .772 r
.62513 .63779 m .62437 .6399 L .62319 .64243 L F
.789 .572 .608 r
.62437 .6399 m .62299 .64281 L .62319 .64243 L F
.426 .195 .458 r
.38901 .73849 m .39033 .74014 L .39042 .73778 L F
.38901 .73849 m .38847 .74064 L .39033 .74014 L F
.893 .792 .741 r
.68665 .624 m .68534 .62528 L .68389 .624 L F
.529 .307 .522 r
.38607 .74324 m .38847 .74064 L .38649 .74118 L F
.112 .073 .53 r
.53213 .72951 m .53105 .73307 L .53065 .73026 L F
.53213 .72951 m .53269 .73156 L .53105 .73307 L F
.599 .928 .963 r
.53105 .73307 m .53269 .73156 L .5306 .73268 L F
.473 .402 .696 r
.53105 .73307 m .53231 .73616 L .53338 .73494 L F
.797 .769 .827 r
.3932 .66828 m .38976 .66867 L .39206 .66834 L F
.46 .851 .646 r
.3932 .66828 m .39406 .66757 L .39473 .66714 L F
.45 .882 .875 r
.3932 .66828 m .39206 .66834 L .39406 .66757 L F
.621 .6 .808 r
.39659 .66761 m .3932 .66828 L .39473 .66714 L F
.512 .822 1 r
.40198 .7647 m .39981 .76512 L .40047 .7653 L F
.465 .139 .328 r
.30262 .69499 m .29969 .69713 L .30036 .69508 L F
.9 .744 .679 r
.64835 .63832 m .64734 .63517 L .64725 .63749 L F
.982 .781 .558 r
.64818 .64059 m .64835 .63832 L .64725 .63749 L F
.47 .242 .485 r
.3595 .71529 m .35795 .71399 L .3599 .71356 L F
.3595 .71529 m .35769 .71585 L .35795 .71399 L F
.882 .925 .538 r
.67039 .60865 m .66926 .61009 L .66926 .60774 L F
.67039 .60865 m .66939 .61078 L .66926 .61009 L F
.775 .706 .168 r
.38548 .80036 m .38548 .80124 L .38689 .79984 L F
.38548 .80036 m .38517 .8034 L .38548 .80124 L F
0 0 0 r
.63466 .6051 m .63263 .60575 L .63243 .60557 L F
.509 .116 .232 r
.40937 .73029 m .40823 .73211 L .41112 .7315 L F
.51 .115 .228 r
.40937 .73029 m .41112 .7315 L .4116 .73023 L F
.596 .573 .798 r
.38623 .66543 m .38412 .66591 L .38251 .66261 L F
.317 .653 .971 r
.35724 .65058 m .35908 .65074 L .35849 .65172 L F
.362 .708 .986 r
.35908 .65074 m .36047 .65173 L .35849 .65172 L F
.997 .773 .456 r
.66858 .59954 m .66889 .59665 L .66781 .59607 L F
.249 .762 .818 r
.37575 .80338 m .37747 .80323 L .37485 .80373 L F
.798 .707 .764 r
.62624 .64317 m .62823 .64054 L .62909 .64321 L F
.802 .669 .716 r
.62624 .64317 m .62909 .64321 L .62778 .64634 L F
.769 .692 .777 r
.62823 .64054 m .63156 .64097 L .62909 .64321 L F
.809 .598 .617 r
.6284 .63814 m .63156 .64097 L .62823 .64054 L F
.794 .701 .762 r
.35931 .79775 m .35727 .80055 L .35801 .80006 L F
.35 0 0 r
.43573 .72464 m .43782 .72493 L .43915 .7245 L F
.43915 .7245 m .43984 .7254 L .44127 .72467 L F
.43915 .7245 m .43782 .72493 L .43984 .7254 L F
.972 .659 .32 r
.72739 .71925 m .72662 .71884 L .72637 .71674 L F
.899 .791 .732 r
.72739 .71925 m .72491 .72145 L .72662 .71884 L F
.72739 .71925 m .72635 .72263 L .72491 .72145 L F
.635 .075 0 r
.70012 .71322 m .69807 .71128 L .69768 .71357 L F
.592 .412 .607 r
.70048 .71558 m .70281 .71552 L .70297 .71478 L F
.635 .075 0 r
.6989 .71207 m .70243 .71431 L .69807 .71128 L F
.70191 .71407 m .70243 .71431 L .6989 .71207 L F
.592 .412 .607 r
.702 .71413 m .70297 .71478 L .70342 .71276 L F
.70048 .71558 m .70297 .71478 L .702 .71413 L F
.635 .075 0 r
.70012 .71322 m .70191 .71407 L .6989 .71207 L F
.494 .08 .184 r
.4427 .74099 m .44139 .74277 L .43924 .7429 L F
.617 .287 .389 r
.44481 .74073 m .44139 .74277 L .4427 .74099 L F
.126 .311 .78 r
.38141 .80549 m .38244 .80566 L .38244 .80551 L F
.755 .693 .792 r
.55377 .69742 m .5506 .69744 L .55251 .69427 L F
.758 .569 .642 r
.55377 .69742 m .55208 .70013 L .5506 .69744 L F
.896 .754 .697 r
.68875 .71601 m .687 .71629 L .68747 .71389 L F
.982 .695 .368 r
.68875 .71601 m .6882 .7182 L .687 .71629 L F
.68875 .71601 m .68918 .71905 L .6882 .7182 L F
.665 .121 0 r
.40501 .65977 m .40166 .6571 L .40421 .65736 L F
.172 .205 .654 r
.40383 .65436 m .40507 .65703 L .40421 .65736 L F
0 .098 .619 r
.40576 .65853 m .40421 .65736 L .40507 .65703 L F
.40576 .65853 m .40501 .65977 L .40421 .65736 L F
.723 .72 .847 r
.50672 .71423 m .50761 .71647 L .5042 .71605 L F
.757 .737 .834 r
.51014 .71443 m .50761 .71647 L .50672 .71423 L F
.424 .694 .976 r
.41514 .77857 m .41453 .78003 L .41299 .77882 L F
.41514 .77857 m .41601 .77963 L .41453 .78003 L F
.112 0 0 r
.35614 .71751 m .35569 .71655 L .35769 .71585 L F
.35614 .71751 m .35447 .71831 L .35569 .71655 L F
.575 .628 .867 r
.36316 .67344 m .36359 .67068 L .36171 .67081 L F
.36316 .67344 m .36512 .67297 L .36359 .67068 L F
.506 .325 .569 r
.36316 .67344 m .36509 .67544 L .36512 .67297 L F
.525 0 0 r
.51866 .79224 m .51682 .79318 L .51529 .79216 L F
0 0 0 r
.52089 .79209 m .51682 .79318 L .51866 .79224 L F
0 0 .292 r
.73435 .72001 m .73361 .71938 L .73491 .71822 L F
.73435 .72001 m .7336 .72164 L .73361 .71938 L F
.913 .837 .38 r
.54043 .77339 m .54103 .77081 L .54013 .77057 L F
.312 .794 .905 r
.71668 .71575 m .71517 .71552 L .71247 .71598 L F
.513 0 0 r
.71864 .71564 m .71517 .71552 L .71668 .71575 L F
.863 .81 .797 r
.50654 .72931 m .51011 .72745 L .50898 .72709 L F
.50654 .72931 m .508 .7302 L .51011 .72745 L F
.517 .809 .999 r
.51011 .72745 m .51222 .72703 L .51103 .72618 L F
.606 .923 .972 r
.50898 .72709 m .51011 .72745 L .51103 .72618 L F
.623 .375 .521 r
.59936 .69956 m .59681 .69792 L .59912 .69791 L F
.59936 .69956 m .59619 .70002 L .59681 .69792 L F
.434 .124 .339 r
.31171 .69098 m .31058 .68971 L .31199 .68883 L F
.31171 .69098 m .30977 .69152 L .31058 .68971 L F
.806 .947 .915 r
.72635 .72263 m .72273 .72418 L .72491 .72145 L F
.144 0 .172 r
.66916 .61893 m .66961 .61703 L .66872 .61835 L F
0 0 0 r
.67067 .61587 m .66961 .61703 L .66916 .61893 L F
.616 .297 .407 r
.70489 .70806 m .70793 .70603 L .70457 .70574 L F
.70489 .70806 m .70831 .70792 L .70793 .70603 L F
.756 .607 .692 r
.55904 .71126 m .55764 .71169 L .55638 .70816 L F
.588 .771 .967 r
.71225 .73711 m .71527 .73774 L .71434 .73702 L F
.87 .943 .862 r
.71527 .73774 m .71629 .73487 L .71703 .73552 L F
.71527 .73774 m .71434 .73702 L .71629 .73487 L F
.71527 .73774 m .71629 .73487 L .71703 .73552 L F
.71527 .73774 m .71434 .73702 L .71629 .73487 L F
0 0 .489 r
.71527 .73774 m .71655 .73911 L .71434 .73702 L F
.71527 .73774 m .71746 .74015 L .71655 .73911 L F
.366 0 0 r
.47469 .73296 m .47333 .73418 L .47133 .73416 L F
.111 0 0 r
.47679 .73325 m .47333 .73418 L .47469 .73296 L F
.467 .053 .17 r
.44869 .78132 m .44737 .78316 L .44526 .78328 L F
.156 0 0 r
.44916 .78253 m .44869 .78132 L .45085 .78103 L F
.44916 .78253 m .44737 .78316 L .44869 .78132 L F
.88 .553 .428 r
.7115 .60904 m .71215 .60849 L .71115 .60865 L F
.959 .724 .54 r
.71146 .60875 m .71215 .60849 L .7115 .60904 L F
.892 .681 .61 r
.71103 .60548 m .71146 .60875 L .70852 .60757 L F
.88 .553 .428 r
.7115 .60904 m .71115 .60865 L .7093 .61044 L F
.724 .438 .493 r
.71138 .60957 m .71495 .61281 L .7123 .61343 L F
.578 .507 .739 r
.71125 .60904 m .7093 .61044 L .71115 .60865 L F
.802 .781 .833 r
.71125 .60904 m .71106 .60931 L .7093 .61044 L F
.578 .507 .739 r
.7123 .61343 m .7093 .61044 L .71125 .60904 L F
.802 .781 .833 r
.71131 .60895 m .71125 .60904 L .7093 .61044 L F
.70852 .60757 m .71131 .60895 L .7093 .61044 L F
.71131 .60895 m .7115 .60904 L .71106 .60931 L F
.724 .438 .493 r
.71115 .60865 m .7113 .60881 L .71131 .60895 L F
.71125 .60904 m .71131 .60895 L .71138 .60957 L F
.71115 .60865 m .71131 .60895 L .71125 .60904 L F
.7113 .60881 m .71495 .61281 L .71138 .60957 L F
.892 .681 .61 r
.71146 .60875 m .7115 .60904 L .71131 .60895 L F
.71129 .60875 m .71131 .60895 L .71093 .60876 L F
.724 .438 .493 r
.7113 .60881 m .71526 .61096 L .71495 .61281 L F
.71115 .60865 m .71134 .60875 L .7113 .60881 L F
.892 .681 .61 r
.71146 .60875 m .71131 .60895 L .7113 .60881 L F
.71146 .60875 m .7113 .60881 L .71134 .60875 L F
.724 .438 .493 r
.71134 .60875 m .71526 .61096 L .7113 .60881 L F
.892 .681 .61 r
.71134 .60875 m .7113 .60881 L .71129 .60875 L F
.71146 .60875 m .71093 .60876 L .70852 .60757 L F
.728 .261 .139 r
.71146 .60875 m .71526 .61096 L .71139 .60878 L F
.71215 .60849 m .71247 .60874 L .71146 .60875 L F
.71247 .60874 m .71526 .61096 L .71146 .60875 L F
.71215 .60849 m .71139 .60878 L .71115 .60865 L F
.959 .724 .54 r
.71103 .60548 m .71215 .60849 L .71146 .60875 L F
.748 .651 .754 r
.71436 .60579 m .71215 .60849 L .71103 .60548 L F
0 .147 .684 r
.72506 .60228 m .72691 .60605 L .72389 .60486 L F
.507 .305 .54 r
.35721 .69774 m .35912 .69963 L .35911 .69725 L F
.35721 .69774 m .35699 .70012 L .35912 .69963 L F
.577 .409 .617 r
.37791 .75659 m .38023 .75416 L .37804 .75461 L F
.769 .547 .597 r
.5997 .68 m .60154 .67887 L .60019 .67902 L F
.5997 .68 m .60141 .68143 L .60154 .67887 L F
.73 .513 .597 r
.60154 .67887 m .60141 .68143 L .60372 .68116 L F
.506 .397 .665 r
.36548 .68423 m .36714 .68379 L .36676 .68193 L F
.478 .306 .569 r
.36542 .68656 m .36714 .68379 L .36548 .68423 L F
.462 .494 .806 r
.4053 .76962 m .40474 .77253 L .40369 .76987 L F
.4053 .76962 m .40646 .7726 L .40474 .77253 L F
.299 .792 .774 r
.41992 .7788 m .42087 .77835 L .42162 .77759 L F
.41992 .7788 m .41881 .77901 L .42087 .77835 L F
.789 .68 .744 r
.56618 .71565 m .56425 .71906 L .56381 .71514 L F
.544 0 0 r
.56381 .71514 m .56531 .71606 L .56618 .71565 L F
.147 0 0 r
.45218 .77136 m .45277 .77212 L .45419 .77083 L F
.45218 .77136 m .4507 .77269 L .45277 .77212 L F
.598 .369 .54 r
.58943 .70285 m .58989 .70563 L .58614 .7052 L F
.638 .396 .535 r
.59167 .70518 m .58943 .70285 L .59163 .70284 L F
.59167 .70518 m .58989 .70563 L .58943 .70285 L F
.76 .724 .819 r
.69665 .6161 m .69314 .61621 L .69574 .61335 L F
.773 .731 .814 r
.69891 .61364 m .69665 .6161 L .69574 .61335 L F
.707 .208 .053 r
.48327 .77245 m .48535 .77435 L .48632 .77347 L F
.689 .279 .263 r
.48535 .77435 m .48857 .77451 L .48632 .77347 L F
.473 .248 .492 r
.38182 .74637 m .3838 .74595 L .38412 .74371 L F
.529 .325 .547 r
.3838 .74595 m .38607 .74324 L .38412 .74371 L F
.772 .611 .679 r
.55716 .71369 m .55411 .71104 L .55764 .71169 L F
.55716 .71369 m .55405 .7135 L .55411 .71104 L F
.772 .616 .686 r
.55716 .71369 m .5554 .7164 L .55405 .7135 L F
0 0 0 r
.66788 .58981 m .67026 .58872 L .6712 .58781 L F
.6712 .58781 m .67268 .5872 L .67264 .58745 L F
.6712 .58781 m .67235 .58691 L .67268 .5872 L F
.6712 .58781 m .67026 .58872 L .67235 .58691 L F
.742 .26 .098 r
.49385 .77567 m .4975 .77764 L .49509 .77636 L F
.564 .613 .86 r
.36996 .79629 m .37147 .79512 L .36929 .79517 L F
.36996 .79629 m .3727 .79655 L .37147 .79512 L F
.504 .138 .279 r
.3957 .73356 m .39857 .73424 L .39754 .73388 L F
.71 .856 .951 r
.48893 .72056 m .48535 .72096 L .48772 .71965 L F
.637 .833 .976 r
.49104 .71978 m .48893 .72056 L .48772 .71965 L F
.905 .641 .528 r
.69978 .58111 m .69906 .57992 L .69906 .58044 L F
0 0 .025 r
.70102 .5793 m .70062 .57979 L .69906 .58044 L F
.828 .852 .865 r
.69692 .57793 m .69839 .57882 L .70107 .57548 L F
.69692 .57793 m .70107 .57548 L .70043 .57466 L F
0 0 0 r
.69906 .58044 m .69943 .58035 L .70102 .5793 L F
.744 .987 .777 r
.70043 .57466 m .69764 .57663 L .69692 .57793 L F
.568 .576 .822 r
.70102 .5793 m .69943 .58035 L .69764 .57663 L F
.408 .805 .578 r
.69971 .57517 m .69764 .57663 L .70043 .57466 L F
.568 .576 .822 r
.70065 .57815 m .69764 .57663 L .69971 .57517 L F
.70102 .5793 m .70053 .57891 L .70065 .57815 L F
.70053 .57891 m .69764 .57663 L .70065 .57815 L F
.205 .317 .757 r
.70223 .57792 m .70102 .5793 L .70086 .57879 L F
.70081 .57637 m .70086 .57879 L .69971 .57517 L F
.70223 .57792 m .70086 .57879 L .70081 .57637 L F
.788 .75 .819 r
.70416 .57287 m .70238 .57368 L .70092 .57251 L F
.8 .724 .781 r
.70092 .57251 m .70167 .57561 L .70416 .57287 L F
.678 .722 .883 r
.70168 .57433 m .70115 .57554 L .70079 .57554 L F
.367 .365 .725 r
.70115 .57554 m .70223 .57792 L .69971 .57517 L F
.70115 .57554 m .69971 .57517 L .69883 .57548 L F
.678 .722 .883 r
.70077 .5747 m .70079 .57554 L .69883 .57548 L F
.70168 .57433 m .70079 .57554 L .70077 .5747 L F
.187 .186 .625 r
.70223 .57792 m .70044 .57957 L .70102 .5793 L F
.70223 .57792 m .70037 .5796 L .70044 .57957 L F
.70223 .57792 m .70245 .57887 L .70043 .57958 L F
.70043 .57955 m .70043 .57958 L .70037 .5796 L F
.70223 .57792 m .70043 .57958 L .70043 .57955 L F
.70245 .57887 m .70285 .58052 L .70074 .57974 L F
.70245 .57887 m .70074 .57974 L .70037 .5796 L F
0 0 .025 r
.70062 .57979 m .69905 .58177 L .69906 .58059 L F
.70062 .57979 m .69906 .58059 L .69906 .58044 L F
.907 .917 .814 r
.69744 .5829 m .69978 .58111 L .69906 .58044 L F
0 0 .025 r
.69905 .58177 m .69883 .58205 L .69906 .58044 L F
.905 .641 .528 r
.69906 .57992 m .69839 .57882 L .69906 .58044 L F
.169 0 .357 r
.69109 .60295 m .69061 .60519 L .68954 .60556 L F
.683 .159 0 r
.692 .60766 m .68958 .60559 L .69061 .60519 L F
.69179 .60772 m .68954 .60556 L .692 .60766 L F
.69234 .60825 m .6912 .60756 L .68954 .60556 L F
.569 .608 .853 r
.69333 .6074 m .69234 .60825 L .69061 .60519 L F
.772 .671 .752 r
.69335 .60243 m .69424 .60555 L .69061 .60519 L F
.569 .608 .853 r
.69333 .6074 m .69061 .60519 L .69424 .60555 L F
.569 .549 .793 r
.6912 .60756 m .6922 .60459 L .69061 .60519 L F
.6922 .60459 m .69243 .6039 L .69061 .60519 L F
.683 .159 0 r
.68958 .60559 m .68954 .60556 L .69061 .60519 L F
.69234 .60825 m .69179 .60772 L .692 .60766 L F
.277 .778 .862 r
.69274 .60745 m .69365 .6071 L .6912 .60756 L F
.69333 .6074 m .69352 .60722 L .69274 .60745 L F
.69352 .60722 m .69365 .6071 L .69274 .60745 L F
.261 .216 .617 r
.68954 .60556 m .6912 .60756 L .69061 .60519 L F
.169 0 .357 r
.69109 .60295 m .69061 .60519 L .68954 .60556 L F
.63 .399 .549 r
.60393 .69505 m .60406 .69751 L .60151 .6975 L F
.635 .403 .549 r
.60707 .69699 m .60393 .69505 L .60722 .69476 L F
.60707 .69699 m .60406 .69751 L .60393 .69505 L F
.601 .153 .159 r
.4875 .77881 m .48634 .78035 L .48408 .77898 L F
.643 .202 .186 r
.48981 .78042 m .48634 .78035 L .4875 .77881 L F
.611 .258 .348 r
.48975 .77906 m .48981 .78042 L .4875 .77881 L F
.722 .776 .895 r
.33458 .85223 m .33545 .85171 L .33395 .85158 L F
.035 0 0 r
.45869 .77999 m .45514 .78042 L .45654 .77932 L F
.976 .838 .641 r
.64899 .63187 m .64949 .63024 L .64846 .62936 L F
.864 .937 .867 r
.72126 .61121 m .71861 .61416 L .71816 .61293 L F
0 0 .294 r
.71816 .61293 m .71861 .61416 L .71951 .61632 L F
.256 .671 .965 r
.6771 .59705 m .67593 .59667 L .67726 .5983 L F
0 .217 .738 r
.6765 .59598 m .67726 .5983 L .67593 .59667 L F
.852 .577 .04 r
.67747 .59984 m .67726 .5983 L .6765 .59598 L F
.67747 .59984 m .67726 .5983 L .67747 .59984 L F
.256 .671 .965 r
.6789 .59764 m .6771 .59705 L .67726 .5983 L F
.976 .766 .557 r
.67747 .59984 m .6789 .59764 L .67726 .5983 L F
.67747 .59984 m .67862 .60016 L .6789 .59764 L F
.693 .635 .787 r
.51648 .71752 m .51321 .71657 L .51539 .71638 L F
.614 .754 .944 r
.51854 .71687 m .51648 .71752 L .51539 .71638 L F
.572 .569 .812 r
.51894 .71834 m .51648 .71752 L .51854 .71687 L F
.628 .207 .225 r
.44838 .74046 m .44694 .74225 L .44481 .74073 L F
0 0 0 r
.45073 .73902 m .44921 .7404 L .44838 .74046 L F
0 0 .001 r
.44838 .74046 m .44841 .74196 L .44694 .74225 L F
.44838 .74046 m .44921 .7404 L .44841 .74196 L F
.185 0 0 r
.44127 .72467 m .44339 .72471 L .44468 .72441 L F
.194 0 0 r
.44468 .72441 m .44547 .7249 L .44679 .7244 L F
.44468 .72441 m .44339 .72471 L .44547 .7249 L F
0 0 0 r
.68179 .62206 m .6825 .62058 L .6817 .62221 L F
.108 0 0 r
.68359 .61923 m .6825 .62058 L .68453 .61974 L F
.652 .883 .982 r
.68453 .61974 m .6825 .62058 L .68362 .61895 L F
0 0 0 r
.68362 .61895 m .6825 .62058 L .68179 .62206 L F
.695 .252 .196 r
.68315 .61919 m .6825 .62058 L .68359 .61923 L F
.68031 .61891 m .6825 .62058 L .68315 .61919 L F
.617 .207 0 r
.68999 .72191 m .69083 .72336 L .68906 .72123 L F
.68999 .72191 m .69189 .72509 L .69083 .72336 L F
.641 .587 .778 r
.36782 .78695 m .36892 .78978 L .37121 .78947 L F
.63 .497 .681 r
.36892 .78978 m .36916 .79223 L .37121 .78947 L F
.504 .386 .653 r
.37631 .76 m .37831 .75978 L .37791 .75659 L F
.513 .448 .721 r
.37631 .76 m .37882 .76212 L .37831 .75978 L F
.571 .448 .673 r
.37631 .76 m .37665 .76247 L .37882 .76212 L F
.53 .334 .56 r
.60312 .63841 m .60537 .63792 L .60517 .63547 L F
.518 .325 .559 r
.60517 .63547 m .60754 .63736 L .60753 .63546 L F
.60517 .63547 m .60537 .63792 L .60754 .63736 L F
.129 0 .22 r
.40724 .75124 m .4051 .75398 L .40564 .75225 L F
.266 0 0 r
.41621 .74904 m .41446 .75033 L .41242 .7505 L F
.387 0 .027 r
.41819 .74855 m .41446 .75033 L .41621 .74904 L F
.671 .786 .935 r
.49343 .73028 m .49678 .73052 L .49565 .72979 L F
.671 .858 .971 r
.49565 .72979 m .49678 .73052 L .49908 .72978 L F
.237 0 0 r
.29865 .66972 m .30214 .66771 L .29994 .66796 L F
.676 .59 .752 r
.56425 .71906 m .56099 .71627 L .56381 .71514 L F
.51 .357 .61 r
.38182 .74637 m .38387 .74837 L .3838 .74595 L F
.528 .358 .594 r
.38182 .74637 m .38183 .74876 L .38387 .74837 L F
.892 .648 .561 r
.53826 .77253 m .54043 .77339 L .54013 .77057 L F
.764 .644 .729 r
.57966 .72256 m .57984 .7247 L .57644 .72441 L F
.766 .626 .705 r
.57984 .7247 m .57757 .72733 L .57644 .72441 L F
.702 .527 .649 r
.57984 .7247 m .58002 .72731 L .57757 .72733 L F
.591 .513 .736 r
.58207 .72426 m .57984 .7247 L .57966 .72256 L F
.602 .467 .67 r
.58207 .72426 m .58002 .72731 L .57984 .7247 L F
.603 .296 .423 r
.63466 .6051 m .63743 .60483 L .63728 .60279 L F
.336 .13 .444 r
.63728 .60279 m .63942 .60224 L .63925 .59978 L F
.35 .165 .484 r
.63928 .6042 m .63728 .60279 L .63743 .60483 L F
.63928 .6042 m .63942 .60224 L .63728 .60279 L F
.675 .809 .947 r
.49457 .71993 m .49104 .71978 L .49324 .71888 L F
.759 .819 .899 r
.49642 .71882 m .49457 .71993 L .49324 .71888 L F
.832 .752 .775 r
.34047 .87945 m .34091 .87881 L .33988 .87863 L F
.526 .658 .919 r
.68765 .58607 m .68874 .58382 L .68636 .58399 L F
.68765 .58607 m .68944 .58599 L .68874 .58382 L F
.675 .834 .96 r
.5023 .71712 m .499 .71697 L .50089 .71584 L F
.724 .792 .906 r
.5042 .71605 m .5023 .71712 L .50089 .71584 L F
.467 .294 .562 r
.37479 .76518 m .37657 .76478 L .37665 .76247 L F
.494 .385 .659 r
.37479 .76518 m .37684 .76732 L .37657 .76478 L F
.37479 .76518 m .37501 .76818 L .37684 .76732 L F
.528 .88 .984 r
.30371 .71452 m .3058 .71391 L .30723 .71425 L F
.372 .823 .936 r
.3058 .71391 m .30928 .71369 L .30723 .71425 L F
.876 .787 .759 r
.71198 .59493 m .70883 .59684 L .7124 .59427 L F
.71198 .59493 m .71054 .59804 L .70883 .59684 L F
.636 .796 .959 r
.7144 .59415 m .71198 .59493 L .7124 .59427 L F
.028 0 0 r
.53103 .78485 m .52971 .7863 L .52812 .78652 L F
.453 0 .052 r
.53249 .78564 m .52971 .7863 L .53103 .78485 L F
.416 .046 .226 r
.5333 .78431 m .53249 .78564 L .53103 .78485 L F
.209 0 .174 r
.35039 .7191 m .34937 .72149 L .34765 .72145 L F
.178 0 0 r
.34937 .72149 m .34655 .72307 L .34765 .72145 L F
.887 .972 .832 r
.6646 .61269 m .66779 .60981 L .667 .61072 L F
.66 .243 .243 r
.36237 .80519 m .36068 .80369 L .35868 .80548 L F
.591 .271 .395 r
.30771 .69207 m .3044 .69418 L .30574 .69243 L F
.54 .321 .531 r
.60911 .67872 m .61142 .67833 L .61152 .67615 L F
.506 .328 .574 r
.61152 .67615 m .61363 .67566 L .61362 .67326 L F
.46 .207 .443 r
.61327 .67768 m .61152 .67615 L .61142 .67833 L F
.61327 .67768 m .61363 .67566 L .61152 .67615 L F
0 0 .007 r
.6797 .60483 m .67838 .60624 L .68004 .60313 L F
0 0 .418 r
.67964 .60205 m .68004 .60313 L .67862 .60016 L F
.927 .719 .233 r
.6797 .60483 m .68004 .60313 L .67964 .60205 L F
.595 .676 .897 r
.68473 .63932 m .68611 .63689 L .68396 .63719 L F
.68473 .63932 m .68751 .63866 L .68611 .63689 L F
.292 .79 .823 r
.33358 .65061 m .33679 .64996 L .33508 .64931 L F
.855 .571 .508 r
.71158 .60329 m .71436 .60579 L .71103 .60548 L F
.672 .3 .333 r
.48021 .7328 m .47884 .73479 L .47679 .73325 L F
.712 .349 .359 r
.48251 .73476 m .48021 .7328 L .48223 .73213 L F
.48251 .73476 m .47884 .73479 L .48021 .7328 L F
.326 0 .087 r
.31904 .6562 m .32196 .65478 L .31983 .65557 L F
.775 .658 .734 r
.70244 .63239 m .70533 .63264 L .70612 .63062 L F
.774 .661 .738 r
.70244 .63239 m .70357 .63487 L .70533 .63264 L F
.405 .47 .814 r
.51222 .72703 m .51359 .73025 L .51486 .7297 L F
.608 .438 .626 r
.51312 .73172 m .51486 .7297 L .51359 .73025 L F
.488 .197 .396 r
.31462 .68674 m .31199 .68883 L .3125 .68701 L F
.394 0 .146 r
.45265 .73823 m .44921 .7404 L .45073 .73902 L F
.492 .187 .376 r
.33456 .67805 m .33168 .6799 L .33283 .67819 L F
.347 .113 .41 r
.29029 .62462 m .28976 .62678 L .28813 .62738 L F
.393 .205 .503 r
.28946 .62892 m .28813 .62738 L .28976 .62678 L F
.28946 .62892 m .28791 .62955 L .28813 .62738 L F
.127 0 0 r
.41081 .75033 m .40925 .75099 L .40724 .75124 L F
.237 0 0 r
.41242 .7505 m .40925 .75099 L .41081 .75033 L F
.775 .658 .734 r
.70244 .63239 m .70612 .63062 L .70474 .62929 L F
.738 .757 .868 r
.70474 .62929 m .70612 .63062 L .70803 .62967 L F
.419 0 0 r
.52519 .72948 m .52494 .72978 L .52119 .72854 L F
.864 .578 .049 r
.52476 .72909 m .52519 .72948 L .52619 .73001 L F
.52476 .72909 m .52494 .72978 L .52519 .72948 L F
.69 .533 .669 r
.56884 .72696 m .56956 .73048 L .56653 .72986 L F
.674 .523 .673 r
.57149 .72482 m .57245 .7272 L .56884 .72696 L F
.566 .451 .682 r
.57132 .72873 m .56884 .72696 L .57245 .7272 L F
.57132 .72873 m .56956 .73048 L .56884 .72696 L F
.536 .188 .325 r
.43396 .74372 m .43129 .7451 L .43177 .74386 L F
.19 .697 .903 r
.39919 .80052 m .40025 .80014 L .39778 .79987 L F
.39919 .80052 m .40148 .80052 L .40025 .80014 L F
.677 .446 .564 r
.59449 .68114 m .59796 .6811 L .59803 .67873 L F
.675 .445 .564 r
.59803 .67873 m .5997 .68 L .60019 .67902 L F
.59803 .67873 m .59796 .6811 L .5997 .68 L F
.391 .426 .777 r
.71964 .73742 m .72093 .74125 L .7189 .74008 L F
0 .371 .832 r
.7189 .74008 m .71975 .73989 L .71746 .74015 L F
.7189 .74008 m .72093 .74125 L .71975 .73989 L F
.509 .339 .586 r
.70486 .70866 m .70457 .70574 L .70244 .70582 L F
.28 0 .167 r
.31218 .66004 m .30951 .66215 L .31141 .66144 L F
.338 0 .2 r
.31218 .66004 m .31338 .66078 L .31432 .65962 L F
.31218 .66004 m .31141 .66144 L .31338 .66078 L F
.715 .93 .961 r
.29667 .60791 m .29584 .60937 L .29462 .60869 L F
.29667 .60791 m .29798 .60837 L .29584 .60937 L F
.597 .044 0 r
.51911 .7807 m .52047 .78143 L .52179 .78136 L F
.494 0 0 r
.52047 .78143 m .52407 .78122 L .52179 .78136 L F
.596 .804 .979 r
.5045 .72985 m .508 .7302 L .50654 .72931 L F
0 .29 .746 r
.72138 .62524 m .72365 .62658 L .7227 .62566 L F
.25 0 0 r
.34085 .67586 m .33994 .67602 L .33752 .67571 L F
.514 .907 .775 r
.3428 .67463 m .34158 .67513 L .34085 .67586 L F
.508 .91 .822 r
.34158 .67513 m .33994 .67602 L .34085 .67586 L F
0 0 0 r
.36237 .80519 m .36599 .8032 L .3626 .8028 L F
.36765 .8019 m .36638 .8027 L .36817 .80037 L F
.948 .623 .378 r
.36765 .8019 m .36817 .80037 L .36679 .79973 L F
.306 .398 .793 r
.36768 .79874 m .36863 .80129 L .36765 .8019 L F
.991 .752 .381 r
.36765 .8019 m .36816 .80307 L .36817 .80037 L F
.306 .398 .793 r
.36863 .80129 m .36895 .80214 L .36765 .8019 L F
0 0 0 r
.36765 .8019 m .36599 .8032 L .36638 .8027 L F
.523 .659 .922 r
.36599 .8032 m .36816 .80307 L .36765 .8019 L F
.634 .421 .576 r
.60372 .68116 m .60661 .68107 L .60665 .67872 L F
.661 .427 .554 r
.60661 .68107 m .60911 .67872 L .60665 .67872 L F
.48 .893 .916 r
.65918 .61557 m .65989 .61576 L .66195 .61501 L F
0 0 0 r
.52812 .78652 m .52637 .78831 L .52499 .78877 L F
.026 0 0 r
.52971 .7863 m .52637 .78831 L .52812 .78652 L F
.343 .127 .435 r
.29181 .62391 m .28976 .62678 L .29029 .62462 L F
0 0 0 r
.71064 .57601 m .71033 .57706 L .70973 .57502 L F
.323 0 0 r
.71215 .57678 m .71064 .57601 L .70973 .57502 L F
.71215 .57678 m .71339 .57732 L .71064 .57601 L F
.329 .081 .379 r
.63925 .59978 m .6415 .59926 L .64196 .59695 L F
.533 .359 .592 r
.63942 .60224 m .6415 .59926 L .63925 .59978 L F
.522 .114 .208 r
.41907 .72943 m .42128 .7295 L .42263 .72763 L F
.504 .095 .197 r
.42263 .72763 m .42128 .7295 L .42436 .72872 L F
.483 .117 .268 r
.42263 .72763 m .42436 .72872 L .42488 .72741 L F
.638 .608 .803 r
.69028 .61766 m .68922 .62125 L .68561 .61982 L F
.651 .512 .681 r
.5742 .72503 m .57245 .7272 L .57149 .72482 L F
.633 .467 .639 r
.58989 .70563 m .58735 .7075 L .58614 .7052 L F
.438 0 0 r
.48857 .77451 m .49058 .77491 L .49185 .7743 L F
.626 .095 0 r
.49058 .77491 m .49385 .77567 L .49185 .7743 L F
.367 0 0 r
.46203 .77883 m .46283 .77988 L .46063 .78011 L F
.46203 .77883 m .46423 .77891 L .46283 .77988 L F
.457 .758 .994 r
.51641 .70991 m .51895 .70979 L .51777 .7109 L F
.641 .568 .756 r
.51895 .70979 m .51669 .712 L .51777 .7109 L F
.802 .669 .716 r
.62624 .64317 m .62778 .64634 L .6264 .64549 L F
.965 .744 .554 r
.62778 .64634 m .62751 .64862 L .6264 .64549 L F
.265 .771 .775 r
.31114 .71258 m .31192 .71222 L .31362 .71179 L F
0 0 0 r
.31192 .71222 m .31298 .71206 L .31362 .71179 L F
.45 .877 .917 r
.31283 .71243 m .31362 .71179 L .31449 .71143 L F
0 0 0 r
.31298 .71206 m .31553 .71168 L .31362 .71179 L F
.45 .877 .917 r
.31449 .71143 m .31362 .71179 L .31491 .71117 L F
.43 0 0 r
.31553 .71168 m .31491 .71117 L .31362 .71179 L F
.31553 .71168 m .31717 .71267 L .31491 .71117 L F
.151 0 0 r
.34114 .6481 m .33953 .64802 L .34282 .64834 L F
.361 0 0 r
.32621 .65171 m .32948 .65095 L .32719 .65128 L F
.476 .81 .999 r
.36941 .65377 m .37144 .6534 L .37286 .65414 L F
.485 .785 .998 r
.37356 .6529 m .37286 .65414 L .37144 .6534 L F
.37356 .6529 m .37552 .65384 L .37286 .65414 L F
.459 .462 .775 r
.53213 .72951 m .53065 .73026 L .52959 .72796 L F
.728 .694 .818 r
.30975 .73915 m .31109 .73808 L .30908 .73797 L F
.665 .121 0 r
.40501 .65977 m .40354 .65903 L .40166 .6571 L F
.411 .286 .598 r
.40166 .6571 m .40354 .65903 L .40378 .65651 L F
.783 .767 .839 r
.68944 .58599 m .69321 .58488 L .69212 .58377 L F
.628 .784 .956 r
.69212 .58377 m .69321 .58488 L .69539 .5843 L F
.593 .407 .598 r
.37207 .78126 m .37435 .77858 L .37206 .77887 L F
0 0 .319 r
.66788 .58981 m .66818 .59204 L .66837 .59109 L F
.204 0 .28 r
.66788 .58981 m .66837 .59109 L .67026 .58872 L F
.555 .52 .771 r
.5142 .7128 m .51539 .71638 L .51321 .71657 L F
.979 .686 .319 r
.4675 .77019 m .46843 .77253 L .46842 .77075 L F
.359 .037 .276 r
.35476 .70058 m .35216 .7028 L .35432 .7022 L F
.625 .28 .366 r
.35432 .7022 m .35663 .70232 L .35476 .70058 L F
.539 .297 .497 r
.35476 .70058 m .35663 .70232 L .35699 .70012 L F
.689 .648 .804 r
.70803 .62967 m .71141 .63044 L .71029 .62731 L F
.715 .663 .797 r
.71029 .62731 m .71141 .63044 L .71325 .62929 L F
.791 .438 .387 r
.55847 .71957 m .55579 .72065 L .55569 .71859 L F
.55847 .71957 m .55872 .72138 L .55579 .72065 L F
.278 0 .151 r
.60249 .6397 m .60312 .63841 L .60044 .64043 L F
.377 0 .178 r
.60488 .63906 m .60312 .63841 L .60249 .6397 L F
.60488 .63906 m .60537 .63792 L .60312 .63841 L F
.732 .788 .898 r
.51541 .73204 m .51741 .73396 L .51892 .7324 L F
0 0 0 r
.42163 .78904 m .42107 .78922 L .41896 .78954 L F
.42315 .78875 m .42163 .78904 L .42288 .78872 L F
.42315 .78875 m .42107 .78922 L .42163 .78904 L F
.636 .739 .923 r
.70683 .61315 m .71013 .61398 L .70791 .61465 L F
.56 .793 .986 r
.28769 .60319 m .28585 .60369 L .28425 .60262 L F
.787 .812 .872 r
.69619 .57464 m .69534 .57292 L .69685 .57407 L F
.69619 .57464 m .69293 .57524 L .69534 .57292 L F
.795 .684 .742 r
.69619 .57464 m .69465 .57636 L .69293 .57524 L F
.312 .06 .362 r
.29416 .62093 m .29181 .62391 L .29248 .62182 L F
.219 0 0 r
.48795 .72985 m .48608 .73101 L .48587 .73061 L F
0 0 0 r
.489 .72954 m .48608 .73101 L .48795 .72985 L F
0 0 .026 r
.48731 .72978 m .48608 .73101 L .489 .72954 L F
.578 .48 .707 r
.48608 .73101 m .48739 .73415 L .48461 .73404 L F
.423 .396 .725 r
.48876 .73362 m .48739 .73415 L .48608 .73101 L F
.783 .539 .568 r
.48611 .73177 m .48876 .73362 L .48608 .73101 L F
0 0 .026 r
.48731 .72978 m .48631 .73144 L .48608 .73101 L F
.48631 .73144 m .48611 .73177 L .48608 .73101 L F
.219 0 0 r
.48587 .73061 m .48608 .73101 L .48448 .73112 L F
0 0 0 r
.489 .72954 m .48795 .72985 L .49011 .72947 L F
.73 .594 .704 r
.55638 .70816 m .55764 .71169 L .55411 .71104 L F
.691 .7 .853 r
.68969 .5749 m .68851 .57839 L .68773 .57681 L F
.68969 .5749 m .69066 .57747 L .68851 .57839 L F
.157 0 0 r
.47133 .73416 m .46803 .73533 L .46895 .73452 L F
.722 .78 .899 r
.71161 .62098 m .71434 .62142 L .71241 .62238 L F
.534 .707 .951 r
.28098 .60136 m .28228 .60284 L .28101 .60302 L F
0 0 0 r
.71712 .60999 m .71526 .61096 L .71515 .61078 L F
.538 .344 .565 r
.6533 .61128 m .6558 .60828 L .65579 .61065 L F
.984 .713 .427 r
.56179 .71032 m .56188 .7133 L .56311 .71367 L F
.686 .782 .306 r
.56311 .71367 m .56439 .71056 L .56179 .71032 L F
.56311 .71367 m .56328 .71317 L .56439 .71056 L F
.843 .39 0 r
.56401 .71501 m .56311 .71367 L .56188 .7133 L F
.56401 .71501 m .56328 .71317 L .56311 .71367 L F
.76 .665 .757 r
.69541 .62121 m .69231 .62393 L .69251 .62193 L F
.622 .492 .683 r
.37359 .77573 m .37559 .77292 L .37349 .77329 L F
.434 .215 .481 r
.64624 .59436 m .64424 .59481 L .64436 .59664 L F
.875 .842 .81 r
.5713 .67327 m .56794 .67518 L .57024 .67259 L F
.5713 .67327 m .56924 .67615 L .56794 .67518 L F
.887 .916 .838 r
.5713 .67327 m .57243 .66984 L .57364 .67067 L F
.5713 .67327 m .57024 .67259 L .57243 .66984 L F
.27 .532 .915 r
.36463 .65141 m .36404 .65276 L .36242 .65146 L F
.36463 .65141 m .36595 .65319 L .36404 .65276 L F
.661 .427 .554 r
.60661 .68107 m .60904 .68093 L .60911 .67872 L F
.513 .289 .512 r
.60904 .68093 m .61142 .67833 L .60911 .67872 L F
.277 .778 .862 r
.69333 .6074 m .6912 .60756 L .69234 .60825 L F
.811 .714 .758 r
.58794 .67539 m .59132 .67357 L .59036 .67291 L F
.58794 .67539 m .5894 .67619 L .59132 .67357 L F
.976 .674 .359 r
.59006 .67039 m .59036 .67291 L .59116 .67318 L F
0 0 .17 r
.59032 .67093 m .59036 .67291 L .59006 .67039 L F
.923 .949 .792 r
.59032 .67093 m .58924 .67254 L .59036 .67291 L F
.58924 .67254 m .58859 .67352 L .59036 .67291 L F
.976 .674 .359 r
.59116 .67318 m .59036 .67291 L .59132 .67357 L F
0 .046 .597 r
.34631 .90793 m .34663 .9083 L .34669 .90849 L F
.787 .999 .827 r
.34669 .90849 m .34663 .9083 L .34628 .90864 L F
.193 0 0 r
.42991 .78655 m .42887 .78721 L .42686 .78753 L F
.246 0 0 r
.43205 .78626 m .42887 .78721 L .42991 .78655 L F
.221 .7 .934 r
.44878 .72444 m .45019 .72496 L .44679 .7244 L F
.041 .61 .75 r
.45119 .72488 m .45019 .72496 L .44878 .72444 L F
.45119 .72488 m .45226 .72494 L .45019 .72496 L F
.807 .844 .878 r
.55341 .70388 m .54958 .70531 L .55167 .70293 L F
.585 .363 .546 r
.59619 .70002 m .59391 .70248 L .59429 .70059 L F
.623 .395 .551 r
.67245 .6218 m .67482 .61881 L .67355 .6181 L F
.67245 .6218 m .67477 .62187 L .67482 .61881 L F
.871 .93 .86 r
.67355 .6181 m .67482 .61881 L .67699 .61618 L F
.647 .525 .701 r
.67482 .61881 m .67721 .61853 L .67699 .61618 L F
.61 .553 .766 r
.67482 .61881 m .67819 .62124 L .67721 .61853 L F
.756 .503 .55 r
.45625 .76762 m .45939 .76979 L .45724 .77026 L F
.514 .2 .373 r
.36946 .70565 m .36657 .70774 L .36728 .70615 L F
.725 .795 .908 r
.48339 .72199 m .47998 .7218 L .48217 .7207 L F
.712 .792 .914 r
.48535 .72096 m .48339 .72199 L .48217 .7207 L F
.528 0 0 r
.49752 .78085 m .4952 .78116 L .49309 .7806 L F
.71 .273 .209 r
.49752 .78085 m .49818 .78168 L .4952 .78116 L F
.686 .722 .877 r
.70049 .63438 m .70357 .63487 L .70244 .63239 L F
.12 .047 .492 r
.42509 .75169 m .42528 .75418 L .42581 .75365 L F
.836 .512 .439 r
.40378 .65651 m .40507 .65703 L .40383 .65436 L F
.553 .853 .998 r
.40576 .65853 m .40354 .65903 L .40501 .65977 L F
.566 .419 .64 r
.3701 .78407 m .37207 .78126 L .36978 .78159 L F
.747 .85 .927 r
.7093 .61044 m .70738 .61202 L .70623 .61036 L F
.283 0 .21 r
.35125 .72075 m .35039 .7191 L .35247 .71878 L F
.35125 .72075 m .34937 .72149 L .35039 .7191 L F
.591 .513 .736 r
.58207 .72426 m .57966 .72256 L .58189 .7219 L F
.448 0 .055 r
.46657 .77954 m .46423 .77891 L .4675 .77803 L F
.405 0 0 r
.46968 .7782 m .46657 .77954 L .4675 .77803 L F
.002 0 0 r
.32415 .73482 m .3228 .7349 L .32473 .73437 L F
.32415 .73482 m .3218 .73546 L .3228 .7349 L F
.632 .499 .683 r
.37121 .78947 m .36916 .79223 L .37128 .79202 L F
.574 .43 .648 r
.36929 .79517 m .37128 .79202 L .36916 .79223 L F
.903 .928 .823 r
.55638 .70816 m .55727 .70485 L .55727 .70745 L F
.55638 .70816 m .55496 .70798 L .55727 .70485 L F
.396 .84 .935 r
.55638 .70816 m .55496 .70798 L .55727 .70745 L F
.584 .541 .772 r
.5319 .72741 m .52959 .72796 L .52877 .72475 L F
.459 .462 .775 r
.53213 .72951 m .52959 .72796 L .5319 .72741 L F
.366 .617 .948 r
.31875 .71301 m .3182 .71453 L .31717 .71267 L F
.31875 .71301 m .31999 .71475 L .3182 .71453 L F
.983 .906 .635 r
.71131 .58994 m .70994 .5909 L .71062 .58859 L F
.71062 .58859 m .70994 .5909 L .71131 .58994 L F
.391 0 0 r
.40825 .79259 m .40405 .79368 L .40594 .79297 L F
.486 .368 .644 r
.29639 .61655 m .29648 .61902 L .29475 .61922 L F
.319 .01 .274 r
.29648 .61902 m .29416 .62093 L .29475 .61922 L F
.661 .526 .688 r
.58025 .71403 m .58086 .71692 L .57819 .71671 L F
.713 .722 .856 r
.37593 .79786 m .37935 .79804 L .37798 .79687 L F
.723 .785 .901 r
.37935 .79804 m .38042 .79592 L .37798 .79687 L F
.37935 .79804 m .38142 .7973 L .38042 .79592 L F
.364 .159 .463 r
.61362 .67326 m .61538 .67269 L .61563 .67046 L F
.517 .383 .638 r
.61363 .67566 m .61538 .67269 L .61362 .67326 L F
.745 .814 .906 r
.69922 .57244 m .69685 .57407 L .69534 .57292 L F
.571 .882 .992 r
.43336 .77621 m .42983 .77633 L .43223 .77605 L F
.565 .924 .949 r
.43523 .77531 m .43336 .77621 L .43223 .77605 L F
.48 .481 .781 r
.67905 .61348 m .67658 .611 L .67796 .61042 L F
.472 .257 .506 r
.72284 .61654 m .71843 .61784 L .71951 .61632 L F
.785 .852 .901 r
.31283 .71243 m .30928 .71369 L .31114 .71258 L F
.45 .877 .917 r
.31283 .71243 m .31114 .71258 L .31362 .71179 L F
.813 .967 .903 r
.62353 .62043 m .62668 .61887 L .62429 .62107 L F
.62353 .62043 m .62599 .61835 L .62668 .61887 L F
.947 .943 .746 r
.62668 .61887 m .62723 .61557 L .62892 .61623 L F
.62723 .61557 m .62729 .61548 L .62892 .61623 L F
.437 .297 .592 r
.62599 .61835 m .62723 .61557 L .62701 .61594 L F
.947 .943 .746 r
.62723 .61557 m .62599 .61835 L .62725 .61546 L F
.62668 .61887 m .62599 .61835 L .62723 .61557 L F
0 0 0 r
.62729 .61548 m .63091 .61297 L .62892 .61623 L F
.437 .297 .592 r
.62701 .61594 m .62737 .61535 L .62762 .61449 L F
0 0 0 r
.62733 .61541 m .63091 .61297 L .62729 .61548 L F
.62733 .61541 m .63048 .6133 L .63091 .61297 L F
.62725 .61546 m .62733 .61541 L .62729 .61548 L F
.62725 .61546 m .62736 .61539 L .62733 .61541 L F
.68 .451 .568 r
.62846 .61468 m .63051 .61745 L .63008 .61504 L F
0 0 0 r
.62766 .61519 m .63048 .6133 L .62763 .61521 L F
.56 .229 .365 r
.62762 .61449 m .63048 .6133 L .62766 .61519 L F
0 0 0 r
.62736 .61539 m .62766 .61519 L .62733 .61541 L F
.62766 .61519 m .62763 .61521 L .62733 .61541 L F
.56 .229 .365 r
.62762 .61449 m .62766 .61519 L .62736 .61539 L F
.68 .451 .568 r
.62762 .61449 m .62806 .61494 L .62846 .61468 L F
.62806 .61494 m .63051 .61745 L .62846 .61468 L F
.437 .297 .592 r
.62599 .61835 m .62744 .61534 L .62729 .61548 L F
.62744 .61534 m .6277 .61481 L .62733 .61541 L F
.62744 .61534 m .62733 .61541 L .62729 .61548 L F
.62737 .61535 m .6277 .61481 L .62762 .61449 L F
.56 .229 .365 r
.62762 .61449 m .62736 .61539 L .62725 .61546 L F
.437 .297 .592 r
.6272 .61565 m .62729 .61548 L .62723 .61557 L F
.62599 .61835 m .62729 .61548 L .6272 .61565 L F
.62599 .61835 m .62832 .61752 L .6277 .61481 L F
.947 .943 .746 r
.62723 .61557 m .62725 .61546 L .62729 .61548 L F
.576 .538 .776 r
.40295 .76793 m .39981 .76512 L .40198 .7647 L F
0 .194 .717 r
.69692 .57793 m .69906 .58044 L .69839 .57882 L F
.85 .65 .632 r
.64774 .64893 m .64801 .64634 L .64614 .64574 L F
.476 .224 .452 r
.40324 .75461 m .40274 .75681 L .40074 .75705 L F
.483 .257 .494 r
.4051 .75398 m .40274 .75681 L .40324 .75461 L F
.346 0 0 r
.36372 .79624 m .3655 .7967 L .3678 .79672 L F
.855 .774 .771 r
.36489 .79869 m .3678 .79672 L .36679 .79973 L F
.845 .552 .494 r
.72637 .71674 m .72412 .71852 L .72394 .71592 L F
.72637 .71674 m .72662 .71884 L .72412 .71852 L F
.805 .405 0 r
.72691 .60605 m .72757 .60774 L .72817 .60839 L F
.906 .577 .096 r
.72757 .60774 m .72872 .6108 L .72817 .60839 L F
.585 .686 .911 r
.29879 .60639 m .3 .60791 L .29798 .60837 L F
.804 .936 .917 r
.29879 .60639 m .29798 .60837 L .29667 .60791 L F
.531 .367 .603 r
.3 .60791 m .29807 .6106 L .29798 .60837 L F
.621 .831 .981 r
.4224 .7005 m .41979 .70005 L .42083 .69947 L F
.42083 .69947 m .41979 .70005 L .4224 .7005 L F
.582 .818 .989 r
.42425 .69981 m .4224 .7005 L .42083 .69947 L F
.42425 .69981 m .4224 .7005 L .42083 .69947 L F
.568 .511 .752 r
.58348 .71863 m .58154 .7203 L .58086 .71692 L F
.518 .425 .689 r
.58348 .71863 m .58189 .7219 L .58154 .7203 L F
.323 .742 .976 r
.42845 .77558 m .42717 .77637 L .42626 .77581 L F
.42845 .77558 m .42983 .77633 L .42717 .77637 L F
.727 .766 .884 r
.72122 .58913 m .7187 .58887 L .72109 .58853 L F
.7187 .58887 m .72122 .58913 L .72109 .58853 L F
.21 0 0 r
.43782 .78454 m .4384 .7853 L .43627 .78562 L F
.43782 .78454 m .43988 .7843 L .4384 .7853 L F
.364 .458 .823 r
.67406 .58867 m .67367 .58973 L .67264 .58745 L F
0 0 .469 r
.67406 .58867 m .67438 .59199 L .67367 .58973 L F
.508 0 0 r
.68566 .58353 m .68636 .58399 L .68316 .58317 L F
.763 .814 .893 r
.49642 .71882 m .49324 .71888 L .49499 .71768 L F
.755 .814 .899 r
.499 .71697 m .49642 .71882 L .49499 .71768 L F
.757 .737 .834 r
.51014 .71443 m .50672 .71423 L .50863 .71312 L F
.799 .796 .849 r
.51182 .71286 m .51014 .71443 L .50863 .71312 L F
.738 .757 .868 r
.70474 .62929 m .70803 .62967 L .7069 .62831 L F
.773 .803 .877 r
.7069 .62831 m .70803 .62967 L .71029 .62731 L F
.492 .314 .568 r
.64624 .59436 m .64794 .59153 L .64631 .59205 L F
.554 .364 .578 r
.48487 .76795 m .48706 .7677 L .48692 .76511 L F
.48692 .76511 m .48706 .7677 L .48487 .76795 L F
.533 .308 .518 r
.48945 .7649 m .48706 .7677 L .48692 .76511 L F
.48706 .7677 m .48945 .7649 L .48692 .76511 L F
0 0 0 r
.35408 .67231 m .35287 .67249 L .35268 .67251 L F
.446 .88 .841 r
.35484 .67163 m .35287 .67249 L .35408 .67231 L F
.4 0 .04 r
.35484 .67163 m .35309 .67247 L .35287 .67249 L F
.35309 .67247 m .35134 .67332 L .35287 .67249 L F
0 0 0 r
.35268 .67251 m .35287 .67249 L .35074 .67278 L F
.446 .88 .841 r
.35484 .67163 m .35408 .67231 L .35679 .67131 L F
.772 .671 .752 r
.69335 .60243 m .69061 .60519 L .69109 .60295 L F
.059 0 .306 r
.69109 .60295 m .69243 .6039 L .69335 .60243 L F
.69109 .60295 m .69061 .60519 L .69243 .6039 L F
.845 .609 .582 r
.56653 .72986 m .56367 .72954 L .56379 .72712 L F
.877 .726 .692 r
.56653 .72986 m .56338 .73193 L .56367 .72954 L F
.56653 .72986 m .56469 .73282 L .56338 .73193 L F
.778 .582 .635 r
.56653 .72986 m .56771 .73327 L .56469 .73282 L F
.708 .546 .667 r
.56992 .73255 m .56653 .72986 L .56956 .73048 L F
.56992 .73255 m .56771 .73327 L .56653 .72986 L F
.608 .221 .284 r
.65532 .58751 m .65894 .5886 L .65651 .58687 L F
.94 .901 .759 r
.7296 .62225 m .73021 .61821 L .72936 .62019 L F
.7296 .62225 m .73103 .6191 L .73021 .61821 L F
.722 .826 .93 r
.72761 .62256 m .7296 .62225 L .72936 .62019 L F
.845 .695 .696 r
.72314 .73538 m .72005 .73504 L .72192 .73164 L F
.576 .446 .666 r
.72005 .73504 m .72286 .73718 L .71964 .73742 L F
.743 .298 .194 r
.72314 .73538 m .72286 .73718 L .72033 .73526 L F
.72314 .73538 m .72033 .73526 L .72038 .73507 L F
.57 .636 .877 r
.71964 .73742 m .72286 .73718 L .72057 .73488 L F
.71964 .73742 m .72018 .73595 L .7199 .73693 L F
.72018 .73595 m .72057 .73488 L .72008 .73636 L F
.72018 .73595 m .72008 .73636 L .7199 .73693 L F
.743 .298 .194 r
.72038 .73507 m .72033 .73526 L .72005 .73504 L F
.939 .656 .191 r
.72314 .73538 m .72336 .73782 L .72286 .73718 L F
.861 .681 .656 r
.69314 .61621 m .69113 .61737 L .69052 .6156 L F
.69113 .61737 m .69018 .61792 L .69045 .61607 L F
.69113 .61737 m .69045 .61607 L .69052 .6156 L F
.66 .631 .809 r
.69175 .61854 m .68922 .62125 L .69028 .61766 L F
.69198 .61868 m .69187 .61878 L .69175 .61854 L F
.69187 .61878 m .68922 .62125 L .69175 .61854 L F
.653 .617 .801 r
.69198 .61868 m .69251 .62193 L .68922 .62125 L F
.511 .266 .479 r
.61453 .69178 m .61208 .69386 L .61291 .69228 L F
.761 .752 .844 r
.69891 .61364 m .69574 .61335 L .69783 .61117 L F
.679 .712 .873 r
.70141 .61256 m .69891 .61364 L .69783 .61117 L F
.436 .252 .532 r
.37139 .705 m .36982 .70347 L .37155 .70267 L F
.37139 .705 m .36946 .70565 L .36982 .70347 L F
.57 .389 .597 r
.37657 .76478 m .37882 .76212 L .37665 .76247 L F
.968 .814 .636 r
.66939 .61078 m .66759 .6125 L .66926 .61009 L F
.733 .619 .732 r
.70454 .72747 m .70119 .72701 L .70229 .72587 L F
.70454 .72747 m .70196 .72768 L .70119 .72701 L F
.546 .476 .728 r
.70454 .72747 m .70174 .73027 L .70196 .72768 L F
.552 .727 .955 r
.70626 .72672 m .70454 .72747 L .70229 .72587 L F
.146 .237 .702 r
.70637 .72907 m .70454 .72747 L .70626 .72672 L F
.70637 .72907 m .70584 .73079 L .70454 .72747 L F
.339 0 .027 r
.42716 .72716 m .42922 .72683 L .43047 .72539 L F
.335 0 .024 r
.43047 .72539 m .42922 .72683 L .43202 .72588 L F
.825 .858 .871 r
.71481 .62599 m .71591 .62553 L .71481 .62445 L F
.663 .874 .978 r
.71591 .62553 m .71705 .62382 L .71481 .62445 L F
.71591 .62553 m .71804 .62463 L .71705 .62382 L F
.734 .484 .551 r
.70991 .71854 m .7068 .71636 L .71021 .71647 L F
.444 .198 .446 r
.71247 .71598 m .70991 .71854 L .71021 .71647 L F
.732 .847 .935 r
.72093 .74125 m .72427 .74106 L .72307 .7405 L F
.728 .851 .939 r
.72093 .74125 m .72427 .74106 L .72307 .7405 L F
.18 0 .33 r
.72713 .73687 m .72716 .73927 L .72537 .73992 L F
0 0 0 r
.72557 .73856 m .72537 .73992 L .7245 .74062 L F
.983 .799 .579 r
.72427 .74106 m .72336 .73782 L .72557 .73856 L F
.72427 .74106 m .72307 .7405 L .72336 .73782 L F
.98 .825 .423 r
.72336 .73782 m .72307 .7405 L .72296 .73794 L F
.753 .235 0 r
.72537 .73992 m .72296 .73794 L .72307 .7405 L F
.72537 .73992 m .72423 .73957 L .72296 .73794 L F
.581 .252 .376 r
.72603 .73939 m .72423 .73957 L .72537 .73992 L F
.72664 .73946 m .72603 .73939 L .72537 .73992 L F
.72716 .73927 m .72618 .73937 L .72664 .73946 L F
.72618 .73937 m .72603 .73939 L .72664 .73946 L F
.72716 .73927 m .72679 .74078 L .72423 .73957 L F
.823 .366 .139 r
.72679 .74078 m .72329 .7369 L .72423 .73957 L F
.72679 .74078 m .72555 .74064 L .7246 .73907 L F
.72538 .73922 m .7246 .73907 L .72329 .7369 L F
.72679 .74078 m .7246 .73907 L .72538 .73922 L F
0 0 0 r
.7245 .74062 m .72537 .73992 L .72427 .74106 L F
.529 .866 .993 r
.72537 .73992 m .72307 .7405 L .72427 .74106 L F
.906 .564 .385 r
.65658 .59201 m .65679 .5937 L .65776 .59214 L F
.864 .913 .863 r
.65894 .5886 m .65776 .59214 L .65926 .59127 L F
.65894 .5886 m .65658 .59201 L .65776 .59214 L F
.523 .267 .469 r
.65679 .5937 m .65926 .59127 L .65776 .59214 L F
.586 .534 .764 r
.40274 .75681 m .40121 .75954 L .40074 .75705 L F
.40274 .75681 m .40304 .76003 L .40121 .75954 L F
.603 .467 .669 r
.40387 .76195 m .40121 .75954 L .40304 .76003 L F
.989 .738 .45 r
.55995 .72432 m .55872 .72138 L .56206 .72184 L F
.55995 .72432 m .55883 .72364 L .55872 .72138 L F
.555 0 0 r
.55995 .72432 m .56121 .72567 L .55883 .72364 L F
.55995 .72432 m .56252 .72644 L .56121 .72567 L F
.982 .781 .558 r
.64818 .64059 m .64725 .63749 L .64695 .63966 L F
.911 .867 .782 r
.64632 .64334 m .64818 .64059 L .64695 .63966 L F
.104 .348 .816 r
.72872 .6108 m .73159 .6129 L .73044 .61359 L F
.058 .248 .742 r
.73159 .6129 m .73242 .61553 L .73044 .61359 L F
.371 .466 .828 r
.71126 .61941 m .71161 .62098 L .70929 .61953 L F
.949 .722 .562 r
.66858 .59954 m .66992 .6027 L .66943 .60175 L F
.23 .363 .791 r
.66992 .6027 m .66858 .59954 L .66955 .602 L F
.878 .869 .825 r
.66649 .60494 m .66992 .6027 L .66945 .60209 L F
.846 .468 0 r
.66858 .59954 m .66875 .60065 L .66679 .5993 L F
.828 .821 .842 r
.66649 .60494 m .66945 .60209 L .66912 .60154 L F
.66846 .60081 m .66912 .60154 L .66855 .60062 L F
.66649 .60494 m .66912 .60154 L .66846 .60081 L F
.846 .468 0 r
.66875 .60065 m .66825 .60058 L .66679 .5993 L F
.828 .821 .842 r
.66649 .60494 m .66843 .60043 L .66548 .60419 L F
.702 .18 0 r
.66691 .60599 m .66649 .60494 L .66548 .60419 L F
0 0 0 r
.66771 .60155 m .66548 .60419 L .66828 .60062 L F
.828 .821 .842 r
.66649 .60494 m .66855 .60062 L .66835 .6006 L F
.722 .604 .725 r
.6688 .60324 m .6662 .60356 L .66737 .6025 L F
0 0 0 r
.66613 .60363 m .6657 .60403 L .66771 .60155 L F
.6657 .60403 m .66571 .60392 L .66771 .60155 L F
.722 .604 .725 r
.66705 .60279 m .66703 .6027 L .66737 .6025 L F
.6662 .60356 m .66701 .60271 L .66705 .60279 L F
.66701 .60271 m .66703 .6027 L .66705 .60279 L F
0 .118 .628 r
.66825 .60058 m .66835 .60067 L .66755 .59981 L F
.846 .468 0 r
.66875 .60065 m .66881 .60108 L .66825 .60058 L F
0 .118 .628 r
.66835 .60067 m .66881 .60108 L .66816 .60043 L F
.66835 .60067 m .66816 .60043 L .66755 .59981 L F
.772 .269 0 r
.66469 .59834 m .66702 .60022 L .66437 .59694 L F
.66702 .60022 m .66763 .6007 L .66723 .60025 L F
.66702 .60022 m .66723 .60025 L .66437 .59694 L F
0 0 0 r
.66686 .60237 m .66829 .6006 L .66793 .60035 L F
.66745 .60028 m .66793 .60035 L .66751 .60006 L F
.66686 .60237 m .66793 .60035 L .66745 .60028 L F
.66829 .6006 m .66843 .60043 L .66805 .60028 L F
0 .118 .628 r
.66679 .5993 m .66825 .60058 L .66779 .60007 L F
.49 0 0 r
.66805 .60028 m .66843 .60043 L .66679 .5993 L F
0 .118 .628 r
.66679 .5993 m .66779 .60007 L .66755 .59981 L F
.49 0 0 r
.66751 .60006 m .66805 .60028 L .66679 .5993 L F
0 0 0 r
.66829 .6006 m .66805 .60028 L .66751 .60006 L F
.66657 .60343 m .66596 .60385 L .66673 .60284 L F
.66701 .6027 m .66695 .60256 L .66771 .60155 L F
.722 .604 .725 r
.6662 .60356 m .66532 .60366 L .667 .60271 L F
0 0 0 r
.66831 .60062 m .66828 .60062 L .66843 .60043 L F
.66701 .60271 m .66828 .60062 L .66831 .60062 L F
.66657 .60343 m .66699 .60273 L .66701 .60271 L F
.66699 .60273 m .66828 .60062 L .66701 .60271 L F
.989 .888 .567 r
.66653 .60222 m .66686 .60237 L .66667 .60191 L F
0 0 0 r
.66532 .60366 m .6666 .60229 L .66694 .60264 L F
.989 .888 .567 r
.66603 .60333 m .66678 .60247 L .66653 .60222 L F
.66678 .60247 m .66686 .60237 L .66653 .60222 L F
0 0 0 r
.66701 .60271 m .66843 .60043 L .66686 .60237 L F
.66701 .60271 m .66701 .60271 L .66701 .60271 L F
.66701 .60271 m .66843 .60043 L .66701 .60271 L F
.66694 .60264 m .66727 .60158 L .66735 .60237 L F
.66694 .60264 m .66694 .60263 L .66694 .60264 L F
.66694 .60263 m .66727 .60158 L .66694 .60264 L F
.6666 .60229 m .66727 .60158 L .66694 .60264 L F
.66703 .6027 m .66735 .60237 L .66737 .6025 L F
.66532 .60366 m .66694 .60264 L .667 .60271 L F
.989 .888 .567 r
.66603 .60333 m .66657 .60343 L .66682 .60252 L F
.66678 .60247 m .66682 .60252 L .66686 .60237 L F
.66603 .60333 m .66682 .60252 L .66678 .60247 L F
0 0 0 r
.667 .60271 m .66735 .60237 L .66703 .6027 L F
.66694 .60264 m .66735 .60237 L .667 .60271 L F
.722 .604 .725 r
.66701 .60272 m .667 .60271 L .66703 .6027 L F
.6662 .60356 m .667 .60271 L .66701 .60272 L F
.779 .547 .585 r
.66191 .60161 m .66696 .60081 L .66469 .59834 L F
.66696 .60081 m .66763 .6007 L .66703 .60023 L F
.66696 .60081 m .66703 .60023 L .66469 .59834 L F
.989 .888 .567 r
.66689 .60144 m .66686 .60237 L .66751 .60006 L F
.66667 .60191 m .6668 .60221 L .66689 .60144 L F
.6668 .60221 m .66686 .60237 L .66689 .60144 L F
0 0 0 r
.66657 .60343 m .66701 .60271 L .66686 .60237 L F
.66596 .60385 m .66582 .60395 L .66613 .60363 L F
.66582 .60395 m .6657 .60403 L .66613 .60363 L F
.6657 .60403 m .66548 .60419 L .66571 .60392 L F
0 0 .563 r
.66532 .60366 m .66691 .60599 L .66548 .60419 L F
.752 .611 .702 r
.6651 .60872 m .66691 .60599 L .66569 .6042 L F
.584 .392 .588 r
.66691 .60599 m .66734 .60848 L .6651 .60872 L F
0 0 .188 r
.66691 .60599 m .66729 .6073 L .66569 .60434 L F
.752 .611 .702 r
.66527 .60476 m .66569 .6042 L .66532 .60366 L F
0 0 .563 r
.66532 .60366 m .66548 .60419 L .66598 .60384 L F
.722 .604 .725 r
.6688 .60324 m .66801 .60439 L .66532 .60366 L F
0 0 .563 r
.66532 .60366 m .66598 .60384 L .66657 .60343 L F
.517 .016 0 r
.66926 .60774 m .66811 .60658 L .66828 .60696 L F
.66811 .60658 m .66649 .60494 L .6677 .60631 L F
.66811 .60658 m .6677 .60631 L .66828 .60696 L F
.702 .18 0 r
.66691 .60599 m .66828 .60696 L .66649 .60494 L F
.938 .773 .651 r
.66882 .60475 m .66707 .60588 L .6688 .60324 L F
.66707 .60588 m .66691 .60599 L .66701 .60584 L F
.66707 .60588 m .66701 .60584 L .6688 .60324 L F
.722 .604 .725 r
.66801 .60439 m .66691 .60599 L .66532 .60366 L F
0 0 .188 r
.66569 .6042 m .66569 .60434 L .66532 .60366 L F
.66691 .60599 m .66569 .60434 L .66569 .6042 L F
.752 .611 .702 r
.6651 .60872 m .66569 .6042 L .66527 .60476 L F
0 .118 .628 r
.66755 .59981 m .66836 .60063 L .66807 .60016 L F
.66836 .60063 m .66881 .60108 L .66845 .60064 L F
.66836 .60063 m .66845 .60064 L .66807 .60016 L F
.828 .821 .842 r
.66835 .6006 m .66855 .60062 L .66843 .60043 L F
.989 .764 .507 r
.66992 .6027 m .66938 .60199 L .66943 .60175 L F
.828 .821 .842 r
.66945 .60209 m .66955 .602 L .66942 .60182 L F
.66945 .60209 m .66942 .60182 L .66843 .60043 L F
.989 .764 .507 r
.66945 .60209 m .66882 .60475 L .66938 .60199 L F
.66992 .6027 m .6696 .60331 L .66945 .60209 L F
.6696 .60331 m .66882 .60475 L .66945 .60209 L F
.878 .869 .825 r
.66945 .60209 m .66992 .6027 L .66955 .602 L F
.989 .764 .507 r
.66992 .6027 m .66984 .60562 L .66882 .60475 L F
.767 .655 .739 r
.3701 .78407 m .36782 .78695 L .36679 .78374 L F
.596 .41 .601 r
.3701 .78407 m .36782 .78695 L .37008 .78644 L F
.749 .645 .746 r
.36679 .78374 m .36782 .78695 L .36454 .7868 L F
.246 0 0 r
.3698 .7865 m .36611 .78684 L .36782 .78695 L F
.37008 .78644 m .3697 .78648 L .3698 .7865 L F
.3697 .78648 m .36611 .78684 L .3698 .7865 L F
.748 .233 0 r
.36735 .78535 m .36858 .78618 L .36679 .78374 L F
.36858 .78618 m .36942 .78674 L .36902 .78629 L F
.36858 .78618 m .36902 .78629 L .36679 .78374 L F
.641 .587 .778 r
.36782 .78695 m .37121 .78947 L .37008 .78644 L F
.246 0 0 r
.37008 .78644 m .36822 .78692 L .36611 .78684 L F
.556 .379 .596 r
.3701 .78407 m .37008 .78644 L .37222 .78375 L F
.993 .765 .396 r
.3701 .78407 m .36951 .78639 L .37008 .78644 L F
.609 .955 .863 r
.36953 .78639 m .36856 .78678 L .37008 .78644 L F
.36856 .78678 m .36822 .78692 L .36842 .78687 L F
.36856 .78678 m .36842 .78687 L .37008 .78644 L F
.741 .394 .395 r
.36679 .78374 m .36921 .7865 L .3701 .78407 L F
.36921 .7865 m .36951 .78639 L .3701 .78407 L F
.609 .955 .863 r
.37073 .78546 m .36836 .78684 L .37033 .78607 L F
.741 .394 .395 r
.36921 .7865 m .36942 .78674 L .36951 .78639 L F
.732 .796 .903 r
.37073 .78546 m .36942 .78674 L .36904 .78649 L F
.37073 .78546 m .36904 .78649 L .36735 .78535 L F
.993 .765 .396 r
.36951 .78639 m .36942 .78674 L .37008 .78644 L F
.609 .955 .863 r
.37033 .78607 m .36953 .78639 L .37008 .78644 L F
.36836 .78684 m .36822 .78692 L .37033 .78607 L F
.566 .419 .64 r
.3701 .78407 m .37222 .78375 L .37207 .78126 L F
.336 .134 .451 r
.28791 .62955 m .28607 .632 L .28733 .62996 L F
.471 .292 .556 r
.38737 .68621 m .38548 .68679 L .38744 .68393 L F
.475 .241 .478 r
.38737 .68621 m .38504 .68877 L .38548 .68679 L F
.181 0 0 r
.35074 .67278 m .34745 .67351 L .34874 .67269 L F
.789 .553 .581 r
.62505 .63528 m .6284 .63814 L .62513 .63779 L F
.796 .616 .658 r
.62513 .63779 m .6284 .63814 L .62823 .64054 L F
.86 .881 .852 r
.57591 .66808 m .57364 .67067 L .57243 .66984 L F
.609 .436 .622 r
.58735 .7075 m .58446 .71085 L .58446 .70826 L F
.321 .408 .795 r
.71856 .73435 m .71703 .73552 L .71629 .73487 L F
.71856 .73435 m .71964 .73742 L .71703 .73552 L F
.381 .076 .319 r
.38938 .68341 m .38744 .68393 L .39012 .68164 L F
.496 .19 .376 r
.39163 .68302 m .39012 .68164 L .39186 .68084 L F
.39163 .68302 m .38938 .68341 L .39012 .68164 L F
.573 .579 .821 r
.29282 .60526 m .29249 .60911 L .29141 .60515 L F
.29282 .60526 m .29462 .60869 L .29249 .60911 L F
.671 .858 .971 r
.49565 .72979 m .49908 .72978 L .49756 .72856 L F
.558 .758 .971 r
.49756 .72856 m .49908 .72978 L .50111 .72932 L F
.839 .69 .697 r
.58794 .67539 m .58911 .67859 L .5894 .67619 L F
.499 .407 .682 r
.36117 .69196 m .36349 .69415 L .36363 .69164 L F
.36117 .69196 m .36174 .69474 L .36349 .69415 L F
.612 .368 .522 r
.6128 .63456 m .61538 .63237 L .61303 .6328 L F
0 .02 .567 r
.71417 .73073 m .7136 .73302 L .71357 .73141 L F
.237 .412 .834 r
.71417 .73073 m .71629 .73487 L .7136 .73302 L F
.58 .473 .696 r
.58281 .7163 m .58025 .71403 L .58231 .71345 L F
.58281 .7163 m .58086 .71692 L .58025 .71403 L F
.47 .389 .682 r
.37549 .77049 m .37684 .76732 L .37501 .76818 L F
.134 0 .282 r
.39384 .678 m .39186 .68084 L .39252 .67881 L F
.485 .318 .578 r
.37991 .75149 m .3818 .7511 L .38183 .74876 L F
.503 .384 .65 r
.37991 .75149 m .38206 .75348 L .3818 .7511 L F
.37991 .75149 m .38023 .75416 L .38206 .75348 L F
.574 .43 .648 r
.36929 .79517 m .37147 .79512 L .37128 .79202 L F
.429 .866 .913 r
.35513 .65089 m .35565 .65021 L .35724 .65058 L F
.35513 .65089 m .35362 .65085 L .35565 .65021 L F
.749 .756 .858 r
.69465 .57636 m .69066 .57747 L .69293 .57524 L F
.976 .838 .641 r
.64899 .63187 m .64846 .62936 L .64802 .63099 L F
.949 .897 .741 r
.64734 .63517 m .64899 .63187 L .64802 .63099 L F
.614 .779 .96 r
.33153 .71239 m .32919 .71313 L .32862 .71207 L F
.458 .203 .438 r
.37865 .69471 m .37816 .69692 L .37622 .69733 L F
.399 .135 .394 r
.38063 .69421 m .37816 .69692 L .37865 .69471 L F
.881 .865 .819 r
.51952 .72758 m .51961 .73025 L .52119 .72854 L F
.51952 .72758 m .51792 .72948 L .51961 .73025 L F
.946 .787 .653 r
.51792 .72948 m .51892 .7324 L .51961 .73025 L F
.647 .482 .647 r
.48487 .76795 m .4872 .76936 L .48706 .7677 L F
.48487 .76795 m .4851 .77043 L .4872 .76936 L F
.4872 .76936 m .48487 .76795 L .48706 .7677 L F
.4872 .76936 m .4851 .77043 L .48487 .76795 L F
.646 .792 .952 r
.30908 .73797 m .31109 .73808 L .31185 .73785 L F
.91 .924 .812 r
.68226 .57838 m .6833 .57894 L .6797 .58315 L F
.763 .977 .918 r
.68422 .57718 m .68525 .57756 L .6833 .57894 L F
.721 .929 .959 r
.68422 .57718 m .6833 .57894 L .68226 .57838 L F
.715 .663 .797 r
.71029 .62731 m .71325 .62929 L .71247 .62656 L F
.793 .702 .765 r
.71247 .62656 m .71325 .62929 L .71481 .62599 L F
.408 .635 .948 r
.38042 .79592 m .38142 .7973 L .38312 .79732 L F
.843 .596 .565 r
.3824 .79738 m .38312 .79732 L .38142 .7973 L F
.795 .575 .603 r
.55405 .7135 m .5507 .71075 L .55411 .71104 L F
.442 .029 .16 r
.47071 .77291 m .47289 .77276 L .47411 .77089 L F
.473 .061 .178 r
.47411 .77089 m .47601 .77178 L .47627 .77101 L F
.47411 .77089 m .47289 .77276 L .47601 .77178 L F
0 0 .425 r
.66872 .61835 m .6693 .62062 L .66916 .61893 L F
0 0 0 r
.46392 .73638 m .46491 .73626 L .4624 .73682 L F
.488 .247 .474 r
.61695 .6894 m .61648 .69135 L .61453 .69178 L F
.526 .339 .571 r
.61908 .68666 m .61913 .68896 L .61695 .6894 L F
.131 0 .093 r
.61913 .68896 m .61648 .69135 L .61695 .6894 L F
.648 .354 .459 r
.71693 .71013 m .71929 .71025 L .71707 .70815 L F
.85 .527 .439 r
.39465 .79661 m .39773 .79796 L .39778 .79987 L F
.433 .871 .898 r
.37783 .80284 m .37747 .80323 L .37575 .80338 L F
.468 .276 .536 r
.38487 .69107 m .3831 .68936 L .38504 .68877 L F
.38487 .69107 m .38294 .69163 L .3831 .68936 L F
.789 .572 .608 r
.62437 .6399 m .62624 .64317 L .62299 .64281 L F
.796 .616 .658 r
.62513 .63779 m .62823 .64054 L .62437 .6399 L F
.688 .542 .682 r
.62437 .6399 m .62823 .64054 L .62624 .64317 L F
.799 .419 .336 r
.50415 .77848 m .50607 .78116 L .50728 .78039 L F
.417 0 0 r
.50607 .78116 m .50983 .78051 L .50728 .78039 L F
.833 .881 .878 r
.54863 .6971 m .54992 .69449 L .5506 .69744 L F
.806 .582 .598 r
.5506 .69744 m .54881 .69954 L .54863 .6971 L F
.5506 .69744 m .55208 .70013 L .54881 .69954 L F
.842 .821 .828 r
.55251 .69427 m .5506 .69744 L .54992 .69449 L F
.05 0 0 r
.33317 .73098 m .33292 .73006 L .33467 .72921 L F
.33317 .73098 m .3314 .73176 L .33292 .73006 L F
.67 .122 0 r
.3753 .65545 m .37787 .65728 L .37611 .65729 L F
.562 .035 0 r
.4545 .72532 m .4579 .72529 L .45569 .72532 L F
.227 .175 .587 r
.40231 .79676 m .40079 .79487 L .40245 .79439 L F
.40231 .79676 m .40093 .7981 L .40079 .79487 L F
.734 .573 .674 r
.57757 .72733 m .5777 .72992 L .57435 .72946 L F
.553 .337 .541 r
.58002 .72731 m .5777 .72992 L .57757 .72733 L F
.461 0 0 r
.46968 .7782 m .47311 .77806 L .47169 .77867 L F
.485 0 0 r
.47311 .77806 m .47519 .77841 L .47169 .77867 L F
0 .12 .667 r
.3144 .76212 m .31455 .76228 L .31457 .76239 L F
.859 .996 .77 r
.31457 .76239 m .31455 .76228 L .31438 .7625 L F
.634 .565 .76 r
.63315 .60809 m .63466 .6051 L .63243 .60557 L F
.481 .264 .507 r
.38254 .6937 m .3809 .69204 L .38294 .69163 L F
.38254 .6937 m .38063 .69421 L .3809 .69204 L F
.656 .478 .632 r
.60141 .68385 m .60372 .68116 L .60141 .68143 L F
.60141 .68385 m .60394 .68347 L .60372 .68116 L F
.618 .431 .607 r
.60394 .68347 m .60661 .68107 L .60372 .68116 L F
.776 .769 .847 r
.68927 .71096 m .68643 .71065 L .68854 .7088 L F
.879 .772 .74 r
.68927 .71096 m .68621 .71289 L .68643 .71065 L F
.68927 .71096 m .68747 .71389 L .68621 .71289 L F
.382 .387 .74 r
.69029 .7077 m .68927 .71096 L .68854 .7088 L F
.69029 .7077 m .69193 .71184 L .68927 .71096 L F
.413 .356 .685 r
.69193 .71184 m .69157 .71299 L .68927 .71096 L F
.464 .128 .311 r
.30639 .6647 m .30862 .66435 L .30951 .66215 L F
.331 .003 .249 r
.30951 .66215 m .31045 .66374 L .31141 .66144 L F
.30951 .66215 m .30862 .66435 L .31045 .66374 L F
.747 .52 .587 r
.57245 .7272 m .57435 .72946 L .57132 .72873 L F
.518 .425 .689 r
.58348 .71863 m .58406 .72224 L .58189 .7219 L F
.525 .399 .652 r
.58406 .72224 m .58207 .72426 L .58189 .7219 L F
.482 .491 .79 r
.40923 .7757 m .40761 .77593 L .40646 .7726 L F
.481 .474 .773 r
.40923 .7757 m .41031 .77738 L .40761 .77593 L F
.732 .528 .615 r
.58914 .68082 m .59265 .67866 L .58911 .67859 L F
.58914 .68082 m .59256 .68114 L .59265 .67866 L F
.743 .537 .615 r
.59265 .67866 m .59256 .68114 L .59449 .68114 L F
.851 .695 .688 r
.58794 .67539 m .58598 .67817 L .58911 .67859 L F
.725 .642 .765 r
.58598 .67817 m .58914 .68082 L .58911 .67859 L F
.634 .565 .76 r
.63315 .60809 m .63494 .60744 L .63466 .6051 L F
.464 .193 .417 r
.63272 .61029 m .63494 .60744 L .63315 .60809 L F
.47 .389 .682 r
.37549 .77049 m .37731 .77017 L .37684 .76732 L F
.613 .526 .733 r
.37559 .77292 m .37731 .77017 L .37549 .77049 L F
.361 0 0 r
.40022 .73442 m .40385 .73283 L .40059 .73426 L F
.40022 .73442 m .40254 .73417 L .40385 .73283 L F
.132 0 0 r
.40385 .73283 m .40446 .73329 L .40606 .73252 L F
0 0 0 r
.40385 .73283 m .40461 .73326 L .40446 .73329 L F
.40385 .73283 m .40254 .73417 L .40461 .73326 L F
.754 .394 0 r
.53589 .74342 m .53531 .74238 L .53463 .74053 L F
.866 .951 .865 r
.53234 .74561 m .53589 .74342 L .53616 .7464 L F
.53234 .74561 m .53531 .74238 L .53589 .74342 L F
.47 .144 .331 r
.53769 .74022 m .53589 .74342 L .53463 .74053 L F
.53769 .74022 m .53531 .74238 L .53589 .74342 L F
.831 .452 .335 r
.53498 .74564 m .53589 .74342 L .53531 .74238 L F
.53498 .74564 m .53689 .74538 L .53589 .74342 L F
.658 .27 0 r
.53531 .74238 m .53689 .74538 L .53589 .74342 L F
.638 .161 .104 r
.50071 .77816 m .50323 .77965 L .50415 .77848 L F
.824 .346 .014 r
.5046 .78051 m .50415 .77848 L .50323 .77965 L F
.5046 .78051 m .50607 .78116 L .50415 .77848 L F
0 0 .038 r
.67885 .60656 m .67838 .60624 L .6797 .60483 L F
.67885 .60656 m .67748 .60889 L .67838 .60624 L F
.553 .337 .541 r
.58002 .72731 m .58003 .72983 L .5777 .72992 L F
.602 .467 .67 r
.58207 .72426 m .58234 .72727 L .58002 .72731 L F
.458 .196 .427 r
.58234 .72727 m .58003 .72983 L .58002 .72731 L F
.03 0 .182 r
.61758 .66757 m .61563 .67046 L .6175 .66923 L F
.27 .083 .432 r
.61563 .67046 m .61736 .67162 L .6175 .66923 L F
.61563 .67046 m .61538 .67269 L .61736 .67162 L F
.51 .556 .839 r
.38421 .66083 m .38251 .66261 L .3815 .65977 L F
.517 .567 .846 r
.38421 .66083 m .38419 .6628 L .38251 .66261 L F
.596 .573 .798 r
.38623 .66543 m .38251 .66261 L .38419 .6628 L F
.451 .46 .777 r
.40295 .76793 m .4053 .76962 L .40369 .76987 L F
.336 .134 .451 r
.28791 .62955 m .28597 .63246 L .28607 .632 L F
.18 0 0 r
.60588 .65399 m .60411 .65552 L .60327 .65561 L F
.174 .006 .399 r
.608 .65095 m .60771 .65328 L .60588 .65399 L F
.813 .631 .656 r
.55405 .7135 m .5554 .7164 L .55257 .71595 L F
.803 .5 .475 r
.5554 .7164 m .55382 .7185 L .55257 .71595 L F
.837 .548 .501 r
.55569 .71859 m .55382 .7185 L .5554 .7164 L F
.523 .327 .557 r
.5312 .73781 m .53338 .73494 L .53231 .73616 L F
.864 .987 .715 r
.58013 .6624 m .57807 .66533 L .57849 .66357 L F
0 0 0 r
.58214 .65955 m .58013 .6624 L .58128 .6612 L F
.002 .578 .737 r
.36782 .78695 m .36611 .78684 L .36454 .7868 L F
.622 .398 .557 r
.60722 .69476 m .60931 .69685 L .60707 .69699 L F
.691 .388 .458 r
.60933 .69504 m .60931 .69685 L .60722 .69476 L F
.591 .271 .395 r
.30771 .69207 m .3068 .69439 L .3044 .69418 L F
.326 .013 .273 r
.30866 .6936 m .30771 .69207 L .30977 .69152 L F
.30866 .6936 m .3068 .69439 L .30771 .69207 L F
.012 0 .41 r
.69563 .60214 m .69424 .60555 L .69335 .60243 L F
.69563 .60214 m .69591 .60458 L .69424 .60555 L F
.69591 .60458 m .69583 .60482 L .69424 .60555 L F
.452 .846 .641 r
.69537 .60592 m .69424 .60555 L .69583 .60482 L F
.579 .319 .487 r
.69808 .6039 m .69591 .60458 L .69563 .60214 L F
.692 .647 .8 r
.69622 .60366 m .69591 .60458 L .69808 .6039 L F
.69591 .60458 m .69548 .60584 L .69808 .6039 L F
.579 .319 .487 r
.69808 .6039 m .69593 .60477 L .69591 .60458 L F
.452 .846 .641 r
.69537 .60592 m .69583 .60482 L .69593 .60477 L F
.692 .647 .8 r
.69545 .60574 m .69537 .60592 L .69548 .60584 L F
.69475 .60347 m .69537 .60592 L .69545 .60574 L F
.69475 .60347 m .69548 .60584 L .69622 .60366 L F
.012 0 .41 r
.69591 .60458 m .69593 .60477 L .69583 .60482 L F
.452 .846 .641 r
.69537 .60592 m .69333 .6074 L .69424 .60555 L F
.388 .026 .225 r
.32215 .6812 m .32081 .68315 L .31906 .68344 L F
.606 .267 .37 r
.32408 .68281 m .32215 .6812 L .32422 .68078 L F
.32408 .68281 m .32081 .68315 L .32215 .6812 L F
.927 .938 .788 r
.62704 .6547 m .62502 .65588 L .62557 .65362 L F
.62704 .6547 m .62586 .65644 L .62502 .65588 L F
.487 .57 .865 r
.38048 .65782 m .37945 .65988 L .37787 .65728 L F
.514 .603 .88 r
.38048 .65782 m .3815 .65977 L .37945 .65988 L F
.352 .724 .986 r
.71225 .73711 m .71324 .73623 L .71095 .73627 L F
.71225 .73711 m .71434 .73702 L .71324 .73623 L F
.124 .25 .724 r
.73453 .71503 m .73339 .71597 L .73151 .71397 L F
.73453 .71503 m .73426 .71604 L .73339 .71597 L F
.547 .198 .327 r
.41112 .7315 m .41388 .72998 L .4116 .73023 L F
.735 .781 .889 r
.5042 .71605 m .50089 .71584 L .50336 .71427 L F
.748 .787 .885 r
.50672 .71423 m .5042 .71605 L .50336 .71427 L F
.776 .84 .901 r
.51182 .71286 m .50863 .71312 L .51123 .71127 L F
.528 .629 .895 r
.51328 .71068 m .51182 .71286 L .51123 .71127 L F
.51328 .71068 m .5142 .7128 L .51182 .71286 L F
.605 .322 .462 r
.52845 .77829 m .53091 .77832 L .53155 .7756 L F
.591 .309 .457 r
.53155 .7756 m .53375 .77736 L .53385 .77527 L F
.53155 .7756 m .53091 .77832 L .53375 .77736 L F
.657 .596 .775 r
.37008 .78644 m .37121 .78947 L .37352 .78912 L F
.63 .49 .672 r
.37128 .79202 m .37352 .78912 L .37121 .78947 L F
.361 .075 .336 r
.34973 .70514 m .35137 .70518 L .35216 .7028 L F
.459 .188 .414 r
.35137 .70518 m .35432 .7022 L .35216 .7028 L F
.985 .763 .518 r
.72835 .73533 m .72713 .73687 L .72842 .73756 L F
.952 .683 .231 r
.72777 .73467 m .72835 .73533 L .72757 .73257 L F
.988 .889 .567 r
.72777 .73467 m .72713 .73687 L .72835 .73533 L F
.472 .205 .428 r
.64196 .59695 m .64359 .59881 L .64436 .59664 L F
.64196 .59695 m .6415 .59926 L .64359 .59881 L F
.738 .596 .698 r
.36176 .79517 m .36146 .79734 L .36352 .79534 L F
.369 .074 .328 r
.36352 .79534 m .36146 .79734 L .36372 .79624 L F
.36352 .79534 m .36146 .79734 L .36372 .79624 L F
.251 0 .307 r
.62079 .68567 m .61908 .68666 L .62134 .68396 L F
0 0 .208 r
.62079 .68567 m .61913 .68896 L .61908 .68666 L F
.898 .971 .817 r
.57807 .66533 m .57619 .66592 L .57715 .66486 L F
.57807 .66533 m .57591 .66808 L .57619 .66592 L F
.801 .97 .909 r
.57807 .66533 m .57715 .66486 L .57849 .66357 L F
.511 .266 .479 r
.61453 .69178 m .61425 .69396 L .61208 .69386 L F
.417 .158 .411 r
.61648 .69135 m .61425 .69396 L .61453 .69178 L F
.685 .801 .937 r
.67864 .58443 m .6809 .58366 L .67768 .58333 L F
.627 .512 .704 r
.57223 .73199 m .56956 .73048 L .57132 .72873 L F
.57223 .73199 m .56992 .73255 L .56956 .73048 L F
.712 .345 .352 r
.34607 .90826 m .34663 .9083 L .34631 .90793 L F
.695 .378 .434 r
.62381 .64503 m .62118 .64374 L .62299 .64281 L F
.62381 .64503 m .62094 .64535 L .62118 .64374 L F
.387 .072 .305 r
.60044 .64043 m .60203 .64201 L .60249 .6397 L F
.60044 .64043 m .59994 .64265 L .60203 .64201 L F
.421 .336 .655 r
.36714 .68379 m .36862 .68023 L .36676 .68193 L F
.86 .881 .852 r
.57591 .66808 m .57243 .66984 L .57485 .66753 L F
.849 .94 .882 r
.57591 .66808 m .57485 .66753 L .57619 .66592 L F
.643 .913 .614 r
.58214 .65955 m .58306 .65824 L .58454 .65699 L F
0 0 0 r
.58214 .65955 m .58128 .6612 L .58306 .65824 L F
.904 .786 .721 r
.71158 .60329 m .71103 .60548 L .71025 .6024 L F
.349 .463 .835 r
.70637 .72907 m .70698 .73147 L .70584 .73079 L F
.732 .794 .901 r
.38244 .80566 m .38601 .80572 L .38244 .80551 L F
.921 .973 .768 r
.6417 .65748 m .64353 .65451 L .64143 .65591 L F
.772 .794 .302 r
.64143 .65591 m .64062 .65901 L .6417 .65748 L F
.429 .111 .323 r
.61208 .69386 m .60931 .69685 L .60933 .69504 L F
.61208 .69386 m .61156 .69636 L .60931 .69685 L F
.676 .423 .531 r
.61425 .69396 m .61156 .69636 L .61208 .69386 L F
.902 .785 .722 r
.71103 .60548 m .71001 .60567 L .71025 .6024 L F
.892 .681 .61 r
.71103 .60548 m .70852 .60757 L .71001 .60567 L F
.457 .127 .318 r
.4723 .72448 m .47444 .72416 L .47515 .72278 L F
.407 .027 .202 r
.47444 .72416 m .47752 .72228 L .47515 .72278 L F
.889 .793 .748 r
.66249 .59078 m .66544 .58929 L .6644 .58841 L F
.66249 .59078 m .66446 .59152 L .66544 .58929 L F
.732 .302 .228 r
.71381 .62328 m .71434 .62142 L .71161 .62098 L F
0 .145 .677 r
.71589 .62019 m .7174 .62112 L .71644 .61996 L F
0 0 0 r
.71683 .61888 m .71528 .62045 L .71589 .62019 L F
.494 .888 .726 r
.71853 .61758 m .71843 .61784 L .71683 .61888 L F
0 0 0 r
.71853 .61758 m .71683 .61888 L .71589 .62019 L F
.76 .683 .777 r
.71502 .61695 m .71853 .61758 L .71589 .62019 L F
0 .145 .677 r
.71589 .62019 m .71644 .61996 L .71548 .61881 L F
0 0 0 r
.71528 .62045 m .71434 .62142 L .71589 .62019 L F
.71589 .62019 m .71434 .62142 L .71381 .62328 L F
.739 .821 .915 r
.69055 .63859 m .6927 .63758 L .68951 .63753 L F
.02 0 0 r
.35847 .67063 m .35484 .67163 L .35679 .67131 L F
.722 .826 .93 r
.72761 .62256 m .72936 .62019 L .72711 .6226 L F
.282 0 .106 r
.61944 .62658 m .62221 .62436 L .62 .62669 L F
.61944 .62658 m .62187 .62601 L .62221 .62436 L F
.249 .161 .555 r
.62221 .62436 m .62389 .62337 L .62353 .62043 L F
.669 .472 .609 r
.62187 .62601 m .62389 .62337 L .62221 .62436 L F
.585 .518 .746 r
.52071 .7163 m .51894 .71834 L .51854 .71687 L F
.52071 .7163 m .52102 .71798 L .51894 .71834 L F
.394 .163 .441 r
.62356 .68125 m .62298 .68321 L .62134 .68396 L F
.268 0 .28 r
.62298 .68321 m .62079 .68567 L .62134 .68396 L F
.722 .841 .938 r
.67725 .6159 m .67396 .61579 L .67699 .61618 L F
.871 .93 .86 r
.67355 .6181 m .67699 .61618 L .67396 .61579 L F
.656 .619 .801 r
.67721 .61853 m .67922 .61596 L .67699 .61618 L F
.577 .047 0 r
.51529 .79216 m .51438 .79312 L .51195 .79178 L F
.524 0 0 r
.51529 .79216 m .51624 .79337 L .51438 .79312 L F
.51529 .79216 m .51682 .79318 L .51624 .79337 L F
.435 .263 .548 r
.38915 .68564 m .38744 .68393 L .38938 .68341 L F
.38915 .68564 m .38737 .68621 L .38744 .68393 L F
0 0 .127 r
.594 .6643 m .59203 .66751 L .59428 .6643 L F
.678 .932 .637 r
.59611 .66195 m .59428 .6643 L .5966 .66204 L F
.59611 .66195 m .594 .6643 L .59428 .6643 L F
.807 .63 .662 r
.7068 .71636 m .70384 .71342 L .70737 .71414 L F
.7068 .71636 m .70373 .71599 L .70384 .71342 L F
.859 .576 .506 r
.7068 .71636 m .70446 .71806 L .70373 .71599 L F
.7068 .71636 m .70711 .71881 L .70446 .71806 L F
.734 .484 .551 r
.70991 .71854 m .70711 .71881 L .7068 .71636 L F
.584 .744 .952 r
.49011 .72947 m .49343 .73028 L .49224 .72909 L F
.591 .763 .961 r
.49224 .72909 m .49343 .73028 L .49565 .72979 L F
0 .284 .653 r
.7274 .71169 m .72581 .71097 L .72491 .71016 L F
.7274 .71169 m .72862 .71229 L .72581 .71097 L F
.593 .407 .598 r
.37207 .78126 m .37433 .781 L .37435 .77858 L F
.521 .401 .656 r
.37435 .77858 m .37608 .77605 L .37359 .77573 L F
.37435 .77858 m .37634 .77819 L .37608 .77605 L F
.564 .383 .595 r
.37435 .77858 m .37648 .78064 L .37634 .77819 L F
.37435 .77858 m .37433 .781 L .37648 .78064 L F
.3 0 0 r
.44294 .77526 m .44507 .77489 L .44643 .77333 L F
.111 0 0 r
.44643 .77333 m .44695 .77422 L .4486 .77311 L F
.44643 .77333 m .44507 .77489 L .44695 .77422 L F
.667 .641 .815 r
.36146 .79734 m .36489 .79869 L .36333 .79944 L F
.631 .151 .094 r
.36489 .79869 m .36679 .79973 L .36333 .79944 L F
0 0 0 r
.66781 .59607 m .668 .59448 L .66828 .59354 L F
.564 .785 .982 r
.71066 .732 m .70698 .73147 L .70985 .73077 L F
.61 .779 .962 r
.71357 .73141 m .71066 .732 L .70985 .73077 L F
.577 .409 .617 r
.37791 .75659 m .38026 .75679 L .38023 .75416 L F
.558 .426 .656 r
.37791 .75659 m .38037 .75931 L .38026 .75679 L F
.37791 .75659 m .37831 .75978 L .38037 .75931 L F
.751 .256 .052 r
.31403 .76214 m .31455 .76228 L .3144 .76212 L F
.744 .809 .904 r
.69712 .6346 m .70049 .63438 L .69985 .63243 L F
.778 .703 .781 r
.69712 .6346 m .69851 .63581 L .70049 .63438 L F
.84 .856 .856 r
.69985 .63243 m .70049 .63438 L .70244 .63239 L F
.419 .215 .495 r
.62528 .68052 m .62356 .68125 L .62562 .67843 L F
.149 0 .213 r
.62528 .68052 m .62298 .68321 L .62356 .68125 L F
.694 .162 0 r
.66896 .61349 m .67067 .61587 L .66922 .61457 L F
.733 .316 .257 r
.34282 .64834 m .34455 .65027 L .34604 .64903 L F
.699 .939 .64 r
.34604 .64903 m .3468 .6477 L .34812 .64853 L F
.34604 .64903 m .34455 .65027 L .3468 .6477 L F
.439 .659 .954 r
.34965 .65043 m .34604 .64903 L .34812 .64853 L F
.636 .427 .582 r
.59424 .70493 m .59163 .70284 L .59391 .70248 L F
.59424 .70493 m .59167 .70518 L .59163 .70284 L F
.795 .57 .596 r
.56992 .73255 m .56666 .73448 L .56771 .73327 L F
.56992 .73255 m .57004 .73546 L .56666 .73448 L F
.609 .425 .607 r
.57225 .73474 m .56992 .73255 L .57223 .73199 L F
.57225 .73474 m .57004 .73546 L .56992 .73255 L F
.385 .095 .344 r
.37395 .70004 m .37339 .7022 L .37155 .70267 L F
.397 .169 .448 r
.37622 .69733 m .37599 .6999 L .37395 .70004 L F
.378 .089 .341 r
.37527 .70165 m .37395 .70004 L .37599 .6999 L F
.37527 .70165 m .37339 .7022 L .37395 .70004 L F
.622 .492 .683 r
.37359 .77573 m .37608 .77605 L .37559 .77292 L F
.325 .376 .761 r
.72273 .72418 m .72356 .72736 L .72524 .7262 L F
.979 .693 .317 r
.72356 .72736 m .72383 .72851 L .72303 .7289 L F
.72383 .72851 m .72425 .73033 L .72303 .7289 L F
.648 .934 .671 r
.72303 .7289 m .72166 .72986 L .72228 .72926 L F
.72303 .7289 m .72228 .72926 L .7241 .72748 L F
.979 .693 .317 r
.72356 .72736 m .72303 .7289 L .72524 .7262 L F
.817 .802 .837 r
.61888 .66386 m .61758 .66757 L .6183 .66638 L F
.386 0 0 r
.43202 .72588 m .43433 .72583 L .43573 .72464 L F
.481 0 .016 r
.43433 .72583 m .43782 .72493 L .43573 .72464 L F
.736 .331 0 r
.66834 .59439 m .67002 .59734 L .66932 .59633 L F
.187 .708 .873 r
.42895 .74581 m .42811 .74563 L .42611 .74573 L F
.518 .9 .954 r
.43026 .74486 m .42895 .74581 L .43129 .7451 L F
.43026 .74486 m .42811 .74563 L .42895 .74581 L F
.594 .333 .49 r
.60151 .6975 m .59936 .69956 L .59912 .69791 L F
.60151 .6975 m .60154 .69951 L .59936 .69956 L F
.619 .351 .49 r
.60406 .69751 m .60154 .69951 L .60151 .6975 L F
.499 0 0 r
.48072 .77837 m .48408 .77898 L .48332 .77964 L F
.717 .23 .086 r
.48634 .78035 m .48332 .77964 L .48408 .77898 L F
.795 .575 .603 r
.55405 .7135 m .55058 .71331 L .5507 .71075 L F
.912 .524 .258 r
.55257 .71595 m .55058 .71331 L .55405 .7135 L F
.781 .352 .231 r
.69366 .71557 m .69542 .71773 L .69598 .71635 L F
.517 .365 .613 r
.69598 .71635 m .69815 .71594 L .69768 .71357 L F
.457 .371 .671 r
.69834 .71829 m .69669 .71886 L .69598 .71635 L F
.706 .265 .2 r
.69542 .71773 m .69834 .71829 L .69598 .71635 L F
.517 .365 .613 r
.69598 .71635 m .69815 .71594 L .69768 .71357 L F
.518 .368 .616 r
.69598 .71635 m .69834 .71829 L .69815 .71594 L F
.568 .511 .752 r
.58348 .71863 m .58086 .71692 L .58281 .7163 L F
.418 .413 .746 r
.67721 .61853 m .67819 .62124 L .68052 .62213 L F
.646 .792 .952 r
.30908 .73797 m .31185 .73785 L .30892 .73751 L F
.441 .11 .308 r
.31185 .73785 m .3083 .73848 L .30892 .73751 L F
.31185 .73785 m .30891 .74031 L .3083 .73848 L F
.31185 .73785 m .31088 .7402 L .30891 .74031 L F
.469 .825 .996 r
.31402 .73736 m .31241 .73684 L .31185 .73785 L F
.343 .018 .261 r
.31306 .73956 m .31185 .73785 L .31241 .73684 L F
.31306 .73956 m .31088 .7402 L .31185 .73785 L F
.766 .738 .828 r
.69293 .57524 m .69066 .57747 L .68969 .5749 L F
.656 .619 .801 r
.67721 .61853 m .68031 .61891 L .67922 .61596 L F
.418 .413 .746 r
.67721 .61853 m .67936 .62022 L .68031 .61891 L F
.67721 .61853 m .68052 .62213 L .67936 .62022 L F
.48 .59 .886 r
.41199 .7774 m .41081 .779 L .41031 .77738 L F
.519 .646 .913 r
.41299 .77882 m .41081 .779 L .41199 .7774 L F
.547 .081 .099 r
.47627 .77101 m .47825 .77204 L .47956 .77067 L F
.275 0 0 r
.47956 .77067 m .48061 .77161 L .48174 .77215 L F
.47956 .77067 m .47825 .77204 L .48061 .77161 L F
.631 .261 .323 r
.47956 .77067 m .48174 .77215 L .48279 .77081 L F
0 0 0 r
.41896 .78954 m .41732 .79027 L .41494 .79098 L F
.41984 .78977 m .41896 .78954 L .42107 .78922 L F
.41984 .78977 m .41732 .79027 L .41896 .78954 L F
.31 0 .259 r
.30448 .66515 m .30568 .66611 L .30639 .6647 L F
.30448 .66515 m .30375 .66685 L .30568 .66611 L F
.856 .908 .868 r
.48174 .77215 m .48327 .77245 L .4851 .77043 L F
.757 .28 .11 r
.48174 .77215 m .48535 .77435 L .48327 .77245 L F
.643 .745 .923 r
.70229 .72587 m .70119 .72701 L .69951 .72454 L F
.769 .939 .594 r
.59203 .66751 m .59039 .66926 L .59006 .67039 L F
0 0 .17 r
.59032 .67093 m .59006 .67039 L .59039 .66926 L F
.074 .635 .767 r
.46336 .72507 m .46534 .72497 L .46683 .72505 L F
.116 .668 .758 r
.46751 .72487 m .46683 .72505 L .46534 .72497 L F
.46751 .72487 m .46885 .72485 L .46683 .72505 L F
.825 .858 .871 r
.71481 .62599 m .71481 .62445 L .71247 .62656 L F
.151 0 0 r
.4579 .72529 m .45986 .72546 L .46123 .72524 L F
.265 0 0 r
.45986 .72546 m .46336 .72507 L .46123 .72524 L F
.158 0 0 r
.45863 .73683 m .45699 .73763 L .45483 .73794 L F
.087 0 0 r
.45871 .73728 m .45863 .73683 L .46111 .73664 L F
.45871 .73728 m .45699 .73763 L .45863 .73683 L F
0 0 .202 r
.66818 .59204 m .66834 .59439 L .66837 .59109 L F
0 .423 .85 r
.73044 .71292 m .73151 .71397 L .72971 .71316 L F
.498 .528 .818 r
.52605 .71884 m .5253 .72209 L .52398 .71908 L F
.52605 .71884 m .52728 .72185 L .5253 .72209 L F
.576 .578 .819 r
.52877 .72475 m .5253 .72209 L .52728 .72185 L F
.485 .194 .396 r
.34878 .7074 m .35137 .70518 L .34973 .70514 L F
.953 .92 .738 r
.62502 .65588 m .62586 .65644 L .62439 .65954 L F
0 0 .127 r
.594 .6643 m .59334 .66636 L .59203 .66751 L F
0 0 0 r
.59334 .66636 m .59039 .66926 L .59203 .66751 L F
.465 .139 .328 r
.30262 .69499 m .3013 .69687 L .29969 .69713 L F
.559 .322 .512 r
.3044 .69418 m .3013 .69687 L .30262 .69499 L F
.727 .809 .916 r
.37593 .79786 m .37641 .79564 L .37448 .79665 L F
.37593 .79786 m .37798 .79687 L .37641 .79564 L F
.401 .21 .503 r
.39617 .67285 m .39591 .67525 L .39413 .6758 L F
.574 .41 .621 r
.39591 .67525 m .39384 .678 L .39413 .6758 L F
.827 .792 .818 r
.69263 .61311 m .69314 .61621 L .69052 .6156 L F
.66 .631 .809 r
.69198 .61868 m .69028 .61766 L .69018 .61792 L F
.861 .681 .656 r
.69314 .61621 m .69198 .61868 L .69018 .61792 L F
.781 .763 .836 r
.69574 .61335 m .69314 .61621 L .69263 .61311 L F
.163 .553 .929 r
.30908 .73797 m .30892 .73751 L .30836 .73736 L F
.567 .5 .739 r
.31369 .74641 m .31404 .74879 L .31164 .74827 L F
.31369 .74641 m .31424 .74881 L .31404 .74879 L F
.631 .089 0 r
.31424 .74881 m .31164 .74827 L .31404 .74879 L F
.276 .378 .787 r
.68174 .62646 m .68281 .62944 L .68406 .62817 L F
.377 .185 .488 r
.68233 .63126 m .68281 .62944 L .68192 .63205 L F
.497 .514 .804 r
.35038 .64812 m .34965 .65043 L .34812 .64853 L F
.35038 .64812 m .35153 .6512 L .34965 .65043 L F
0 .147 .684 r
.72506 .60228 m .72679 .6043 L .72691 .60605 L F
0 0 .398 r
.72679 .6043 m .72757 .60774 L .72691 .60605 L F
.602 .446 .642 r
.37207 .78126 m .37222 .78375 L .37433 .781 L F
.781 .976 .913 r
.58454 .65699 m .58494 .65523 L .58683 .65446 L F
.58454 .65699 m .58398 .65634 L .58494 .65523 L F
.966 .936 .645 r
.58454 .65699 m .58306 .65824 L .58398 .65634 L F
.678 .309 .34 r
.66411 .59442 m .66446 .59152 L .66249 .59078 L F
.66411 .59442 m .66828 .59354 L .66446 .59152 L F
.984 .712 .423 r
.69471 .72455 m .69392 .72651 L .69189 .72509 L F
.69471 .72455 m .69492 .72717 L .69392 .72651 L F
.398 .33 .664 r
.69616 .72284 m .69716 .72817 L .69471 .72455 L F
.46 .501 .814 r
.38658 .66182 m .38623 .66543 L .38419 .6628 L F
.38658 .66182 m .38803 .66539 L .38623 .66543 L F
.461 .492 .804 r
.38803 .66539 m .38839 .66646 L .38623 .66543 L F
.616 .722 .922 r
.50343 .72849 m .5045 .72985 L .50654 .72931 L F
.86 .81 .799 r
.64353 .65451 m .6441 .65056 L .64252 .6536 L F
.64353 .65451 m .64541 .6517 L .6441 .65056 L F
.96 .867 .701 r
.64143 .65591 m .64353 .65451 L .64252 .6536 L F
.41 .582 .911 r
.72344 .59916 m .72143 .59885 L .72004 .59673 L F
.575 .531 .769 r
.40501 .76748 m .40295 .76793 L .40198 .7647 L F
.558 .452 .69 r
.40501 .76748 m .4053 .76962 L .40295 .76793 L F
.557 .892 .984 r
.68633 .57621 m .68525 .57756 L .68422 .57718 L F
.68633 .57621 m .68773 .57681 L .68525 .57756 L F
.896 .907 .824 r
.61965 .66332 m .62017 .66517 L .61888 .66386 L F
.61965 .66332 m .62228 .6623 L .62017 .66517 L F
.63 .49 .672 r
.37128 .79202 m .37422 .79224 L .37352 .78912 L F
.569 .384 .591 r
.37147 .79512 m .37422 .79224 L .37128 .79202 L F
.521 .233 .418 r
.60754 .63736 m .61049 .63451 L .60753 .63546 L F
.436 .195 .449 r
.36451 .70816 m .36415 .71037 L .36216 .71084 L F
.496 .247 .467 r
.36615 .70989 m .36451 .70816 L .36657 .70774 L F
.36615 .70989 m .36415 .71037 L .36451 .70816 L F
.541 .896 .976 r
.68192 .63205 m .68044 .63249 L .68233 .63126 L F
.195 .093 .503 r
.68044 .63249 m .68201 .63336 L .68233 .63126 L F
.68044 .63249 m .6805 .63485 L .68201 .63336 L F
.425 0 .079 r
.44316 .78326 m .44206 .78418 L .43988 .7843 L F
.367 0 .032 r
.4443 .78443 m .44316 .78326 L .44526 .78328 L F
.4443 .78443 m .44206 .78418 L .44316 .78326 L F
0 .217 .738 r
.6765 .59598 m .67593 .59667 L .67497 .59387 L F
.61 .452 .644 r
.57661 .73161 m .57435 .72946 L .5777 .72992 L F
0 0 0 r
.57852 .7306 m .5777 .72992 L .58003 .72983 L F
.57852 .7306 m .57661 .73161 L .5777 .72992 L F
.801 .592 .619 r
.55208 .70013 m .54854 .70239 L .54881 .69954 L F
.55208 .70013 m .55167 .70293 L .54854 .70239 L F
0 0 .226 r
.55254 .70179 m .55208 .70013 L .5542 .7025 L F
.55254 .70179 m .55185 .70174 L .55208 .70013 L F
.413 .732 .991 r
.5542 .7025 m .55556 .70062 L .55254 .70179 L F
.953 .622 .216 r
.5516 .70065 m .55254 .70179 L .5516 .69917 L F
.396 .324 .659 r
.55254 .70179 m .55408 .69789 L .5516 .69917 L F
.55254 .70179 m .55556 .70062 L .55408 .69789 L F
0 .274 .742 r
.5533 .70185 m .55254 .70179 L .5516 .70065 L F
.55388 .70226 m .55254 .70179 L .5533 .70185 L F
0 0 .226 r
.55254 .70179 m .55167 .70293 L .55185 .70174 L F
.806 .911 .513 r
.65259 .62106 m .65419 .61853 L .65396 .61811 L F
.65259 .62106 m .6526 .62157 L .65419 .61853 L F
.792 .962 .919 r
.65419 .61853 m .6557 .6158 L .65396 .61811 L F
.65419 .61853 m .65707 .61639 L .6557 .6158 L F
.79 .725 .792 r
.64541 .6517 m .64613 .64783 L .6441 .65056 L F
.64541 .6517 m .64774 .64893 L .64613 .64783 L F
.745 .379 .36 r
.56771 .73327 m .56666 .73448 L .56469 .73282 L F
.944 .747 .608 r
.64614 .64574 m .64632 .64334 L .64505 .64226 L F
.911 .867 .782 r
.64632 .64334 m .64695 .63966 L .64505 .64226 L F
.478 .306 .569 r
.36542 .68656 m .3674 .68607 L .36714 .68379 L F
.488 .335 .599 r
.36542 .68656 m .36739 .68847 L .3674 .68607 L F
.442 .332 .634 r
.3657 .68892 m .36739 .68847 L .36542 .68656 L F
.764 .596 .669 r
.59796 .6811 m .60141 .68385 L .5997 .68 L F
.59796 .6811 m .59789 .68357 L .60141 .68385 L F
.776 .548 .589 r
.59813 .68577 m .60141 .68385 L .59789 .68357 L F
.59813 .68577 m .60141 .68626 L .60141 .68385 L F
.69 .57 .715 r
.5997 .68 m .60141 .68385 L .60141 .68143 L F
.692 .478 .593 r
.60141 .68385 m .6044 .68591 L .60394 .68347 L F
.60141 .68385 m .60141 .68626 L .6044 .68591 L F
.682 .478 .604 r
.71013 .70788 m .71377 .71013 L .71379 .70874 L F
.533 .359 .591 r
.3818 .7511 m .38387 .74837 L .38183 .74876 L F
.405 .176 .45 r
.37772 .69915 m .37622 .69733 L .37816 .69692 L F
.37772 .69915 m .37599 .6999 L .37622 .69733 L F
.692 .187 .036 r
.50983 .78051 m .51119 .78142 L .51375 .78176 L F
.897 .526 .325 r
.51119 .78142 m .51269 .78274 L .51375 .78176 L F
.51119 .78142 m .51173 .78298 L .51269 .78274 L F
.765 .638 .721 r
.51173 .78298 m .51375 .78176 L .51269 .78274 L F
.51173 .78298 m .51573 .78126 L .51375 .78176 L F
.883 .699 .648 r
.53826 .77253 m .53996 .7758 L .54043 .77339 L F
.169 0 0 r
.45298 .78066 m .44916 .78253 L .45085 .78103 L F
0 0 0 r
.73304 .72346 m .73211 .72482 L .7336 .72164 L F
.73435 .72001 m .73304 .72346 L .7336 .72164 L F
.637 .833 .976 r
.49104 .71978 m .48772 .71965 L .48985 .71895 L F
.672 .855 .969 r
.49324 .71888 m .49104 .71978 L .48985 .71895 L F
.836 .792 .81 r
.31438 .7625 m .31455 .76228 L .31403 .76214 L F
.344 .131 .44 r
.62761 .67559 m .62702 .67753 L .62562 .67843 L F
.047 0 .229 r
.62702 .67753 m .62528 .68052 L .62562 .67843 L F
.531 .296 .503 r
.35911 .69725 m .36128 .69705 L .36174 .69474 L F
.495 .262 .491 r
.36174 .69474 m .36325 .69658 L .36349 .69415 L F
.36174 .69474 m .36128 .69705 L .36325 .69658 L F
.754 .813 .899 r
.69473 .63657 m .69851 .63581 L .69712 .6346 L F
.326 0 .087 r
.31904 .6562 m .32072 .65641 L .32196 .65478 L F
.269 0 .051 r
.32196 .65478 m .32271 .65587 L .32396 .65399 L F
.32196 .65478 m .32072 .65641 L .32271 .65587 L F
.528 .828 .502 r
.58683 .65446 m .58787 .65332 L .58918 .65197 L F
.597 .943 .782 r
.58683 .65446 m .58494 .65523 L .58787 .65332 L F
0 0 0 r
.58918 .65197 m .58979 .65236 L .59091 .65092 L F
.58918 .65197 m .58787 .65332 L .58979 .65236 L F
.712 .792 .914 r
.48535 .72096 m .48217 .7207 L .48404 .71987 L F
.713 .837 .941 r
.48772 .71965 m .48535 .72096 L .48404 .71987 L F
.361 0 .093 r
.33343 .71303 m .33557 .7127 L .33694 .71088 L F
.605 .831 .445 r
.33694 .71088 m .33727 .71025 L .3392 .71098 L F
.33694 .71088 m .33557 .7127 L .33727 .71025 L F
.782 .28 0 r
.67842 .6011 m .67862 .60016 L .67747 .59984 L F
.856 .412 .007 r
.67842 .6011 m .67964 .60205 L .67862 .60016 L F
.048 0 0 r
.471 .72486 m .47444 .72416 L .4723 .72448 L F
.876 .994 .775 r
.62253 .66059 m .62439 .65954 L .62228 .6623 L F
.827 .979 .884 r
.62253 .66059 m .62228 .6623 L .61965 .66332 L F
.922 .79 .698 r
.70079 .63113 m .70244 .63239 L .70155 .62908 L F
.84 .856 .856 r
.69985 .63243 m .70244 .63239 L .70079 .63113 L F
.776 .719 .799 r
.70155 .62908 m .70244 .63239 L .70474 .62929 L F
0 0 0 r
.52089 .79209 m .52019 .79232 L .51682 .79318 L F
.524 .919 .85 r
.52257 .79114 m .52192 .79115 L .52089 .79209 L F
.52 .902 .737 r
.52192 .79115 m .52019 .79232 L .52089 .79209 L F
.336 .134 .451 r
.28791 .62955 m .28755 .63196 L .28597 .63246 L F
.439 .323 .624 r
.28755 .63196 m .28599 .63327 L .28597 .63246 L F
0 0 .107 r
.68918 .71905 m .68906 .72123 L .68939 .72083 L F
.68918 .71905 m .68939 .72083 L .6882 .7182 L F
.648 .648 .836 r
.531 .7241 m .52877 .72475 L .52728 .72185 L F
.584 .541 .772 r
.5319 .72741 m .52877 .72475 L .531 .7241 L F
.631 .089 0 r
.31424 .74881 m .31223 .74899 L .31164 .74827 L F
.038 .16 .664 r
.31358 .74569 m .31424 .74881 L .31369 .74641 L F
.31358 .74569 m .31511 .74779 L .31424 .74881 L F
.53 .214 .375 r
.31511 .74779 m .31223 .74899 L .31424 .74881 L F
.617 .287 .389 r
.44481 .74073 m .44388 .74299 L .44139 .74277 L F
.586 .255 .375 r
.44694 .74225 m .44388 .74299 L .44481 .74073 L F
0 0 .433 r
.70977 .59981 m .71088 .60079 L .71132 .59859 L F
.70977 .59981 m .71025 .6024 L .71088 .60079 L F
.66 .855 .461 r
.73304 .72346 m .73115 .72649 L .73211 .72482 L F
.372 .002 .2 r
.53542 .78389 m .53249 .78564 L .5333 .78431 L F
.949 .897 .741 r
.64734 .63517 m .64802 .63099 L .64641 .63432 L F
.981 .724 .325 r
.64641 .63432 m .64725 .63749 L .64734 .63517 L F
.102 0 0 r
.34311 .72546 m .34266 .72439 L .34451 .72369 L F
.34311 .72546 m .34133 .72628 L .34266 .72439 L F
.751 .694 .797 r
.34628 .90864 m .34663 .9083 L .34607 .90826 L F
.536 .648 .906 r
.29141 .60515 m .28769 .60319 L .28954 .60286 L F
.262 .519 .908 r
.29282 .60526 m .29141 .60515 L .28954 .60286 L F
.309 .8 .864 r
.39323 .79663 m .3923 .79713 L .39465 .79661 L F
.33 .807 .744 r
.39126 .79741 m .3923 .79713 L .39323 .79663 L F
.237 0 0 r
.29865 .66972 m .30052 .66932 L .30214 .66771 L F
.445 .091 .269 r
.30052 .66932 m .30375 .66685 L .30214 .66771 L F
.935 .777 .661 r
.55098 .70839 m .5507 .71075 L .54972 .7077 L F
.305 0 0 r
.34121 .71053 m .34491 .70855 L .34196 .70987 L F
.34121 .71053 m .34333 .71015 L .34491 .70855 L F
.262 0 0 r
.34491 .70855 m .34542 .70972 L .3468 .70791 L F
.34491 .70855 m .34333 .71015 L .34542 .70972 L F
.393 .637 .953 r
.2828 .60143 m .28228 .60284 L .28098 .60136 L F
.482 .736 .983 r
.28425 .60262 m .28228 .60284 L .2828 .60143 L F
.513 .33 .57 r
.36146 .79734 m .36333 .79944 L .36372 .79624 L F
.551 .108 .151 r
.47839 .77793 m .47738 .77872 L .47519 .77841 L F
.479 .021 .088 r
.47942 .77957 m .47839 .77793 L .48072 .77837 L F
.47942 .77957 m .47738 .77872 L .47839 .77793 L F
.438 .17 .408 r
.52669 .77868 m .52606 .7806 L .52845 .77829 L F
.794 .67 .727 r
.57391 .70231 m .57709 .70278 L .57595 .6996 L F
.779 .534 .564 r
.57392 .7047 m .57709 .70278 L .57391 .70231 L F
.57392 .7047 m .57716 .70511 L .57709 .70278 L F
.511 .445 .719 r
.57709 .70278 m .57903 .69932 L .57595 .6996 L F
.57709 .70278 m .57921 .70229 L .57903 .69932 L F
.555 .357 .567 r
.57709 .70278 m .57959 .70465 L .57921 .70229 L F
.57709 .70278 m .57716 .70511 L .57959 .70465 L F
.454 .15 .36 r
.39241 .73734 m .39504 .73519 L .39314 .73577 L F
.223 0 0 r
.35922 .71601 m .35769 .71585 L .3595 .71529 L F
.35922 .71601 m .35614 .71751 L .35769 .71585 L F
.48 .893 .916 r
.65918 .61557 m .66195 .61501 L .66103 .6145 L F
.825 .934 .902 r
.66103 .6145 m .66195 .61501 L .6646 .61269 L F
.698 .412 .485 r
.61312 .64827 m .60978 .65024 L .60956 .64886 L F
.494 0 0 r
.43984 .7254 m .44339 .72471 L .44127 .72467 L F
.549 .628 .883 r
.66916 .61893 m .6693 .62062 L .67185 .62039 L F
.953 .92 .738 r
.62502 .65588 m .62439 .65954 L .62388 .65897 L F
.906 .983 .767 r
.62388 .65897 m .62439 .65954 L .62253 .66059 L F
.136 0 .15 r
.71242 .61773 m .71346 .61621 L .71248 .61729 L F
.387 .809 .972 r
.71248 .61729 m .7138 .61657 L .71255 .61682 L F
.71248 .61729 m .71255 .61682 L .71162 .617 L F
.136 0 .15 r
.71126 .61941 m .71242 .61773 L .71248 .61729 L F
.318 .438 .826 r
.71489 .61562 m .71346 .61621 L .7123 .61343 L F
.494 .556 .848 r
.3727 .79655 m .37404 .79535 L .37147 .79512 L F
.3727 .79655 m .37448 .79665 L .37404 .79535 L F
.756 .671 .767 r
.69212 .58377 m .69539 .5843 L .69415 .58097 L F
.696 .64 .789 r
.69415 .58097 m .69539 .5843 L .69744 .5829 L F
.727 .838 .933 r
.67326 .61481 m .67396 .61579 L .67725 .6159 L F
.67326 .61481 m .67725 .6159 L .67526 .61609 L F
.961 .92 .721 r
.67586 .61281 m .67725 .6159 L .67832 .6144 L F
.67586 .61281 m .67526 .61609 L .67725 .6159 L F
0 0 0 r
.67725 .6159 m .67905 .61348 L .67832 .6144 L F
.765 .76 .848 r
.67922 .61596 m .68238 .61615 L .68097 .61677 L F
.79 .689 .752 r
.67922 .61596 m .68031 .61891 L .68238 .61615 L F
.658 .433 .566 r
.62624 .64317 m .62381 .64503 L .62299 .64281 L F
.62624 .64317 m .6264 .64549 L .62381 .64503 L F
.562 .451 .685 r
.40336 .79969 m .40093 .7981 L .40231 .79676 L F
.40336 .79969 m .40148 .80052 L .40093 .7981 L F
.912 .88 .791 r
.55763 .68695 m .55657 .68869 L .55536 .68776 L F
.885 .919 .842 r
.55763 .68695 m .55862 .68354 L .55878 .68563 L F
.55763 .68695 m .55657 .68621 L .55862 .68354 L F
.901 .915 .822 r
.55763 .68695 m .55536 .68776 L .55657 .68621 L F
0 0 0 r
.72422 .62453 m .72575 .62147 L .7254 .62331 L F
0 0 .192 r
.7254 .62331 m .72365 .62658 L .72422 .62453 L F
0 0 0 r
.42516 .78817 m .42288 .78872 L .42686 .78753 L F
.18 0 0 r
.42887 .78721 m .42516 .78817 L .42686 .78753 L F
.294 .035 .34 r
.36415 .71037 m .36185 .71302 L .36216 .71084 L F
.353 0 0 r
.72114 .71588 m .72027 .71595 L .71864 .71564 L F
.102 0 0 r
.72394 .71592 m .72027 .71595 L .72114 .71588 L F
.771 .808 .882 r
.68874 .58382 m .68944 .58599 L .69212 .58377 L F
.304 .798 .844 r
.70323 .72968 m .70174 .73027 L .70401 .72984 L F
.137 0 0 r
.7124 .59427 m .70883 .59684 L .71089 .59609 L F
.7124 .59427 m .71089 .59609 L .71054 .59257 L F
.967 .877 .694 r
.7112 .59171 m .7124 .59427 L .71054 .59257 L F
.104 .113 .583 r
.71054 .59257 m .71181 .59467 L .71177 .59406 L F
.71054 .59257 m .71089 .59609 L .7118 .59519 L F
.71181 .59467 m .7118 .59519 L .712 .59499 L F
.71054 .59257 m .7118 .59519 L .71181 .59467 L F
.861 .749 .738 r
.70941 .59394 m .71181 .59427 L .70892 .59565 L F
.556 .35 .556 r
.71148 .59286 m .712 .59499 L .71195 .59429 L F
.861 .749 .738 r
.71181 .59427 m .71189 .59428 L .71181 .59432 L F
.71181 .59427 m .71181 .59432 L .70892 .59565 L F
.71189 .59428 m .71195 .59429 L .71189 .59431 L F
.71189 .59428 m .71189 .59431 L .70892 .59565 L F
.104 .113 .583 r
.71181 .59467 m .712 .59499 L .71186 .59443 L F
.71181 .59467 m .71186 .59443 L .71177 .59406 L F
.71104 .59272 m .71177 .59406 L .71148 .59286 L F
.71054 .59257 m .71177 .59406 L .71104 .59272 L F
.788 .362 .237 r
.70911 .59263 m .71188 .59425 L .70941 .59394 L F
.71188 .59425 m .71195 .59429 L .71189 .59428 L F
.71188 .59425 m .71189 .59428 L .70941 .59394 L F
.753 .365 .318 r
.70949 .59183 m .71148 .59286 L .70911 .59263 L F
.70994 .5909 m .71061 .59175 L .70949 .59183 L F
.71061 .59175 m .71148 .59286 L .70949 .59183 L F
.967 .877 .694 r
.71191 .59078 m .71203 .59165 L .7112 .59171 L F
.71203 .59165 m .7124 .59427 L .7112 .59171 L F
.71191 .59078 m .71168 .59361 L .7124 .59427 L F
.636 .796 .959 r
.7144 .59415 m .7124 .59427 L .71168 .59361 L F
.601 .051 0 r
.51722 .78062 m .52047 .78143 L .51911 .7807 L F
.554 .288 .467 r
.61849 .64591 m .61827 .64825 L .6161 .64817 L F
.583 .356 .538 r
.62094 .64535 m .61827 .64825 L .61849 .64591 L F
.536 .188 .325 r
.43396 .74372 m .43377 .7451 L .43129 .7451 L F
.702 .473 .574 r
.43748 .74376 m .43377 .7451 L .43396 .74372 L F
.594 .841 .991 r
.51103 .72618 m .51222 .72703 L .51446 .72662 L F
.405 .47 .814 r
.51222 .72703 m .51486 .7297 L .51446 .72662 L F
.759 .799 .885 r
.68951 .63753 m .6927 .63758 L .69149 .63633 L F
.68 .665 .829 r
.6927 .63758 m .69375 .63412 L .69149 .63633 L F
.6927 .63758 m .69473 .63657 L .69375 .63412 L F
.529 .307 .522 r
.38607 .74324 m .38818 .74288 L .38847 .74064 L F
.442 .232 .498 r
.38847 .74064 m .38818 .74288 L .39033 .74014 L F
.394 0 .146 r
.45265 .73823 m .45127 .74023 L .44921 .7404 L F
.422 .017 .163 r
.45453 .7388 m .45265 .73823 L .45483 .73794 L F
.45453 .7388 m .45127 .74023 L .45265 .73823 L F
.856 .908 .868 r
.48174 .77215 m .4851 .77043 L .48279 .77081 L F
.669 .624 .795 r
.58439 .724 m .58207 .72426 L .58406 .72224 L F
.681 .527 .669 r
.58518 .72696 m .58207 .72426 L .58439 .724 L F
.58518 .72696 m .58234 .72727 L .58207 .72426 L F
.498 .648 .924 r
.36512 .67297 m .36606 .67134 L .36359 .67068 L F
.36512 .67297 m .36791 .67283 L .36606 .67134 L F
.539 .351 .574 r
.36512 .67297 m .36719 .67489 L .36791 .67283 L F
.36512 .67297 m .36509 .67544 L .36719 .67489 L F
.676 .276 .282 r
.67823 .62624 m .67619 .62466 L .67713 .62311 L F
.67823 .62624 m .67506 .62625 L .67619 .62466 L F
.249 .358 .779 r
.67713 .62311 m .67823 .62624 L .67619 .62466 L F
.614 .754 .944 r
.51854 .71687 m .51539 .71638 L .51751 .71556 L F
.633 .713 .905 r
.52071 .7163 m .51854 .71687 L .51751 .71556 L F
.163 .275 .733 r
.70843 .73519 m .70968 .73421 L .70698 .73147 L F
.276 .485 .881 r
.70843 .73519 m .71095 .73627 L .70968 .73421 L F
.785 .65 .714 r
.58142 .68362 m .57936 .68646 L .58246 .68668 L F
.733 .577 .68 r
.57958 .68843 m .58246 .68668 L .57936 .68646 L F
.57958 .68843 m .58272 .68906 L .58246 .68668 L F
.679 .594 .754 r
.58142 .68362 m .58246 .68668 L .58508 .68633 L F
.59 .415 .614 r
.58272 .68906 m .58508 .68633 L .58246 .68668 L F
0 0 0 r
.42162 .77759 m .42087 .77835 L .42284 .77745 L F
.607 .564 .781 r
.71571 .59099 m .7144 .59415 L .71168 .59361 L F
.71571 .59099 m .71635 .59408 L .7144 .59415 L F
.348 0 .009 r
.42626 .77581 m .42422 .77589 L .42284 .77745 L F
.452 0 0 r
.72237 .70941 m .71929 .71025 L .72173 .71047 L F
.55 .092 .118 r
.72173 .71047 m .72491 .71016 L .72237 .70941 L F
.825 .992 .741 r
.59764 .65982 m .5966 .66204 L .59878 .65936 L F
.82 .986 .715 r
.59764 .65982 m .59611 .66195 L .5966 .66204 L F
.202 0 .268 r
.62988 .6728 m .62962 .67511 L .62761 .67559 L F
.168 0 .164 r
.62761 .67559 m .6288 .67665 L .62702 .67753 L F
.62761 .67559 m .62962 .67511 L .6288 .67665 L F
.854 .698 .688 r
.55657 .68869 m .55342 .69078 L .55536 .68776 L F
.55657 .68869 m .55535 .69207 L .55342 .69078 L F
.494 0 0 r
.52047 .78143 m .52278 .78225 L .52407 .78122 L F
.411 0 .073 r
.52278 .78225 m .52606 .7806 L .52407 .78122 L F
.882 .656 .592 r
.64613 .64783 m .64774 .64893 L .64614 .64574 L F
.537 .318 .529 r
.35663 .70232 m .35912 .69963 L .35699 .70012 L F
.614 .729 .927 r
.31358 .74569 m .31369 .74641 L .31208 .74585 L F
.567 .5 .739 r
.31369 .74641 m .31164 .74827 L .31208 .74585 L F
.059 0 .079 r
.63227 .67031 m .63176 .67209 L .62988 .6728 L F
.14 0 .279 r
.62988 .6728 m .63116 .67399 L .62962 .67511 L F
.62988 .6728 m .63176 .67209 L .63116 .67399 L F
.189 .721 .812 r
.41314 .79124 m .40989 .79153 L .41099 .79149 L F
.295 .01 .299 r
.42006 .74794 m .41819 .74855 L .42059 .74606 L F
.5 .193 .378 r
.42209 .74747 m .42059 .74606 L .42253 .74553 L F
.42209 .74747 m .42006 .74794 L .42059 .74606 L F
.583 .414 .618 r
.38023 .75416 m .38225 .7564 L .38206 .75348 L F
.38023 .75416 m .38026 .75679 L .38225 .7564 L F
.864 .788 .774 r
.36719 .67489 m .37082 .6729 L .36975 .67151 L F
.36719 .67489 m .36819 .67558 L .37082 .6729 L F
.695 .491 .606 r
.37082 .6729 m .36819 .67558 L .37088 .67536 L F
.108 .46 .888 r
.37082 .6729 m .37108 .67188 L .36975 .67151 L F
.276 .345 .753 r
.37088 .67536 m .37108 .67188 L .37082 .6729 L F
.421 .336 .655 r
.36714 .68379 m .36908 .68403 L .36862 .68023 L F
.636 .555 .747 r
.3674 .68607 m .36908 .68403 L .36714 .68379 L F
.372 .823 .936 r
.3058 .71391 m .30795 .71347 L .30928 .71369 L F
.592 .949 .871 r
.30928 .71369 m .30992 .71277 L .31114 .71258 L F
.527 .898 .965 r
.30928 .71369 m .30795 .71347 L .30992 .71277 L F
.511 .477 .755 r
.40545 .75846 m .40304 .76003 L .40274 .75681 L F
.507 .409 .678 r
.40571 .76145 m .40304 .76003 L .40545 .75846 L F
.40571 .76145 m .40387 .76195 L .40304 .76003 L F
0 0 0 r
.36185 .71302 m .3595 .71529 L .3599 .71356 L F
.736 .808 .334 r
.65186 .62315 m .65141 .62464 L .6526 .62157 L F
.801 .828 .354 r
.65259 .62106 m .65186 .62315 L .6526 .62157 L F
0 0 .379 r
.3972 .66752 m .39659 .66761 L .39473 .66714 L F
.641 .517 .697 r
.39843 .67255 m .39617 .67285 L .39659 .66761 L F
.39843 .67255 m .39659 .66761 L .39691 .66972 L F
0 0 .379 r
.3972 .66752 m .39691 .66972 L .39659 .66761 L F
.541 .208 .352 r
.42436 .72872 m .42716 .72716 L .42488 .72741 L F
.962 .722 .528 r
.56379 .72712 m .56242 .72864 L .56252 .72644 L F
.56379 .72712 m .56367 .72954 L .56242 .72864 L F
.488 .803 1 r
.37008 .6526 m .36941 .65377 L .368 .65287 L F
.37008 .6526 m .37144 .6534 L .36941 .65377 L F
.67 .526 .68 r
.59256 .68114 m .59489 .68297 L .59449 .68114 L F
.735 .571 .67 r
.59489 .68297 m .59796 .6811 L .59449 .68114 L F
.458 0 .027 r
.43523 .77531 m .43735 .77537 L .43847 .7748 L F
.637 .216 .228 r
.43847 .7748 m .43735 .77537 L .4407 .7754 L F
.488 .197 .396 r
.31462 .68674 m .31412 .68847 L .31199 .68883 L F
.535 .241 .414 r
.31462 .68674 m .31627 .68827 L .31412 .68847 L F
.498 .245 .462 r
.31654 .68627 m .31627 .68827 L .31462 .68674 L F
.585 .363 .546 r
.59619 .70002 m .59623 .70228 L .59391 .70248 L F
.611 .384 .547 r
.59981 .70141 m .59619 .70002 L .59936 .69956 L F
.59981 .70141 m .59623 .70228 L .59619 .70002 L F
.672 .231 .195 r
.45277 .77212 m .45615 .77238 L .45419 .77083 L F
.514 .325 .563 r
.45419 .77083 m .45615 .77238 L .45664 .77006 L F
.45419 .77083 m .45615 .77238 L .45664 .77006 L F
0 0 0 r
.70683 .61315 m .7093 .61044 L .71013 .61398 L F
.578 .507 .739 r
.7123 .61343 m .71013 .61398 L .7093 .61044 L F
.739 .825 .918 r
.69922 .57244 m .69534 .57292 L .69739 .57171 L F
.416 .688 .975 r
.70025 .57141 m .69922 .57244 L .69739 .57171 L F
.70025 .57141 m .70092 .57251 L .69922 .57244 L F
0 0 .114 r
.63436 .66747 m .63394 .66951 L .63227 .67031 L F
0 0 0 r
.63227 .67031 m .63295 .67088 L .63176 .67209 L F
.63227 .67031 m .63394 .66951 L .63295 .67088 L F
.567 .712 .939 r
.71576 .58678 m .7187 .58887 L .71894 .58811 L F
.788 .598 .644 r
.71576 .58678 m .71894 .58811 L .71846 .58805 L F
.512 .756 .984 r
.71846 .58805 m .7187 .58887 L .71576 .58678 L F
.777 .678 .754 r
.71894 .58811 m .71879 .58824 L .71846 .58805 L F
.512 .756 .984 r
.71879 .58821 m .71879 .58824 L .71846 .58805 L F
.71879 .58824 m .7187 .58887 L .71846 .58805 L F
.777 .678 .754 r
.71846 .58805 m .71571 .59099 L .71415 .58754 L F
.71879 .58824 m .71571 .59099 L .71846 .58805 L F
.788 .598 .644 r
.71576 .58678 m .71846 .58805 L .71415 .58754 L F
.512 .756 .984 r
.71893 .58722 m .71879 .58821 L .71576 .58678 L F
.706 .454 .541 r
.7187 .58887 m .71879 .58824 L .71894 .58811 L F
.512 .756 .984 r
.7206 .58744 m .7187 .58887 L .71893 .58722 L F
.706 .454 .541 r
.7187 .58887 m .71571 .59099 L .71879 .58824 L F
.7187 .58887 m .71888 .59177 L .71571 .59099 L F
.512 .756 .984 r
.7206 .58744 m .72109 .58853 L .7187 .58887 L F
.528 .319 .541 r
.72093 .59089 m .71888 .59177 L .7187 .58887 L F
.727 .766 .884 r
.7187 .58887 m .72109 .58853 L .72093 .59089 L F
.913 .771 .69 r
.5507 .71075 m .54902 .71009 L .54972 .7077 L F
.91 .68 .576 r
.5507 .71075 m .54832 .71216 L .54902 .71009 L F
.5507 .71075 m .55058 .71331 L .54832 .71216 L F
.348 .142 .453 r
.3 .60791 m .29957 .61043 L .29807 .6106 L F
.57 .526 .767 r
.29957 .61043 m .29834 .6131 L .29807 .6106 L F
.438 .265 .549 r
.35911 .69725 m .36086 .69907 L .36128 .69705 L F
.35911 .69725 m .35912 .69963 L .36086 .69907 L F
.756 .503 .55 r
.45625 .76762 m .45664 .77006 L .45939 .76979 L F
.471 .742 .988 r
.67268 .5872 m .67406 .58867 L .67264 .58745 L F
.166 0 0 r
.31791 .65823 m .32072 .65641 L .31904 .6562 L F
.795 .845 .387 r
.65109 .62472 m .65141 .62464 L .65186 .62315 L F
.65109 .62472 m .65057 .62671 L .65141 .62464 L F
.274 0 0 r
.33752 .67571 m .33831 .67629 L .33589 .67705 L F
.33752 .67571 m .33994 .67602 L .33831 .67629 L F
.479 .762 .993 r
.36119 .65046 m .36047 .65173 L .35908 .65074 L F
.36119 .65046 m .36242 .65146 L .36047 .65173 L F
.462 0 0 r
.46657 .77954 m .46283 .77988 L .46423 .77891 L F
.586 .523 .751 r
.69815 .71594 m .70012 .71322 L .69768 .71357 L F
.657 .596 .775 r
.37008 .78644 m .37352 .78912 L .37213 .78601 L F
.681 .642 .804 r
.37213 .78601 m .37352 .78912 L .37514 .78641 L F
.628 .573 .773 r
.37514 .78641 m .37352 .78912 L .37594 .78869 L F
.621 .484 .673 r
.37352 .78912 m .37615 .7918 L .37594 .78869 L F
.37352 .78912 m .37422 .79224 L .37615 .7918 L F
.324 0 .25 r
.48448 .73112 m .48377 .7327 L .48223 .73213 L F
.569 .426 .647 r
.48461 .73404 m .48223 .73213 L .48377 .7327 L F
.48461 .73404 m .48251 .73476 L .48223 .73213 L F
.438 0 0 r
.44547 .7249 m .44878 .72444 L .44679 .7244 L F
.358 0 .153 r
.64794 .59153 m .6504 .59116 L .65142 .58952 L F
.613 .234 .301 r
.65142 .58952 m .6504 .59116 L .65329 .59089 L F
.441 .312 .608 r
.65142 .58952 m .65329 .59089 L .65328 .58851 L F
.65142 .58952 m .65329 .59089 L .65328 .58851 L F
.486 .222 .439 r
.39843 .67255 m .39591 .67525 L .39617 .67285 L F
.694 .256 .206 r
.67936 .62022 m .6825 .62058 L .68031 .61891 L F
0 0 .469 r
.67406 .58867 m .6767 .59168 L .67438 .59199 L F
.551 .248 .407 r
.6767 .59168 m .6762 .59353 L .67438 .59199 L F
.249 .268 .685 r
.6762 .59353 m .67497 .59387 L .67438 .59199 L F
.551 .248 .407 r
.6767 .59168 m .6762 .59353 L .67438 .59199 L F
.641 .598 .79 r
.68043 .6098 m .67905 .61348 L .67796 .61042 L F
.68043 .6098 m .68136 .61339 L .67905 .61348 L F
.189 0 0 r
.68136 .61339 m .67832 .6144 L .67905 .61348 L F
.387 0 .027 r
.41819 .74855 m .41699 .7501 L .41446 .75033 L F
.589 .268 .394 r
.42006 .74794 m .41699 .7501 L .41819 .74855 L F
.533 .308 .518 r
.48945 .7649 m .48923 .76746 L .48706 .7677 L F
.48706 .7677 m .48923 .76746 L .48945 .7649 L F
.514 .291 .514 r
.49153 .76699 m .48923 .76746 L .48945 .7649 L F
.49153 .76699 m .48923 .76746 L .48945 .7649 L F
.439 .323 .624 r
.28755 .63196 m .28686 .63457 L .28599 .63327 L F
.394 .285 .611 r
.28599 .63327 m .28686 .63457 L .28608 .6349 L F
.407 .027 .202 r
.47444 .72416 m .47658 .72381 L .47752 .72228 L F
.026 0 0 r
.47752 .72228 m .47829 .72253 L .47998 .7218 L F
.47752 .72228 m .47658 .72381 L .47829 .72253 L F
.361 0 0 r
.32621 .65171 m .32768 .65225 L .32948 .65095 L F
.133 0 0 r
.32948 .65095 m .32976 .65174 L .33159 .65121 L F
.32948 .65095 m .32768 .65225 L .32976 .65174 L F
.755 .814 .899 r
.499 .71697 m .49499 .71768 L .49768 .71603 L F
.742 .854 .932 r
.50089 .71584 m .499 .71697 L .49768 .71603 L F
.879 .726 .687 r
.6264 .64549 m .62751 .64862 L .62582 .64753 L F
.847 .751 .758 r
.62582 .64753 m .62751 .64862 L .62583 .65127 L F
.62 .622 .832 r
.38839 .66646 m .39206 .66834 L .38976 .66867 L F
.393 .188 .479 r
.28946 .62892 m .28755 .63196 L .28791 .62955 L F
.825 .992 .741 r
.59764 .65982 m .59878 .65936 L .59841 .65927 L F
.679 .963 .745 r
.59996 .65771 m .59878 .65936 L .6013 .65711 L F
.68 .965 .75 r
.59996 .65771 m .59841 .65927 L .59878 .65936 L F
.111 0 0 r
.47679 .73325 m .4756 .73387 L .47333 .73418 L F
.694 .191 .04 r
.47679 .73325 m .47884 .73479 L .4756 .73387 L F
.714 .88 .958 r
.32583 .71344 m .32268 .7147 L .32241 .71381 L F
.053 .615 .793 r
.34913 .88637 m .35259 .88661 L .35138 .88644 L F
.35138 .88644 m .35259 .88661 L .34913 .88637 L F
.24 .365 .79 r
.67858 .57902 m .67793 .58105 L .67654 .58014 L F
.67858 .57902 m .67954 .58217 L .67793 .58105 L F
.613 .526 .733 r
.37559 .77292 m .37799 .77268 L .37731 .77017 L F
.559 .448 .684 r
.37559 .77292 m .37812 .77553 L .37799 .77268 L F
.37559 .77292 m .37608 .77605 L .37812 .77553 L F
.544 0 0 r
.67819 .58412 m .67658 .58474 L .67768 .58333 L F
.692 .797 .93 r
.67768 .58333 m .6809 .58366 L .67819 .58412 L F
.405 .041 .229 r
.6809 .58366 m .68381 .58416 L .67819 .58412 L F
.6809 .58366 m .68316 .58317 L .68381 .58416 L F
.91 .924 .812 r
.68226 .57838 m .6797 .58315 L .67954 .58217 L F
.523 .573 .847 r
.67819 .58412 m .68381 .58416 L .68324 .58351 L F
.239 .679 .957 r
.68316 .58317 m .68636 .58399 L .68593 .58341 L F
.432 .656 .954 r
.68316 .58317 m .68593 .58341 L .68485 .58265 L F
.235 0 .329 r
.68381 .58416 m .68316 .58317 L .68485 .58265 L F
.75 .625 .722 r
.68144 .58146 m .68381 .58416 L .68485 .58265 L F
.416 .04 .215 r
.68351 .58349 m .68455 .58408 L .68232 .58423 L F
.68485 .58265 m .68469 .5834 L .68351 .58349 L F
.68469 .5834 m .68455 .58408 L .68351 .58349 L F
.523 .573 .847 r
.67851 .58386 m .68324 .58351 L .68144 .58146 L F
.67819 .58412 m .68324 .58351 L .67851 .58386 L F
.417 .157 .41 r
.68232 .58423 m .67819 .58412 L .68144 .58146 L F
.68232 .58423 m .68042 .58559 L .67819 .58412 L F
.572 .396 .604 r
.42285 .75678 m .42518 .75676 L .42528 .75418 L F
.42528 .75418 m .42518 .75676 L .42285 .75678 L F
.731 .593 .701 r
.57435 .72946 m .57223 .73199 L .57132 .72873 L F
.655 .481 .636 r
.57435 .72946 m .57499 .73211 L .57223 .73199 L F
.61 .452 .644 r
.57661 .73161 m .57499 .73211 L .57435 .72946 L F
.872 .855 .822 r
.36679 .78374 m .36454 .7868 L .36314 .78587 L F
.372 .222 .545 r
.36454 .7868 m .36701 .78489 L .36314 .78587 L F
.36454 .7868 m .36611 .78684 L .36701 .78489 L F
.949 .729 .571 r
.36141 .80344 m .36237 .80519 L .3626 .8028 L F
.613 .819 .979 r
.30426 .71288 m .30371 .71452 L .30234 .71291 L F
.30426 .71288 m .3058 .71391 L .30371 .71452 L F
.464 .193 .417 r
.63272 .61029 m .63499 .60983 L .63494 .60744 L F
.646 .434 .582 r
.63729 .60763 m .63466 .6051 L .63494 .60744 L F
0 0 0 r
.63499 .60983 m .63729 .60763 L .63494 .60744 L F
.529 .325 .547 r
.3838 .74595 m .3859 .74562 L .38607 .74324 L F
.54 .333 .549 r
.38607 .74324 m .38803 .74523 L .38818 .74288 L F
.38607 .74324 m .3859 .74562 L .38803 .74523 L F
.875 .894 .843 r
.56086 .68329 m .55862 .68354 L .56083 .68096 L F
.874 .896 .845 r
.56086 .68329 m .55878 .68563 L .55862 .68354 L F
.868 .89 .848 r
.56323 .68039 m .56086 .68329 L .56083 .68096 L F
.252 .09 .458 r
.2984 .61577 m .29648 .61902 L .29639 .61655 L F
.514 .2 .373 r
.36946 .70565 m .36877 .70745 L .36657 .70774 L F
.405 .095 .323 r
.37072 .70698 m .36946 .70565 L .37139 .705 L F
.37072 .70698 m .36877 .70745 L .36946 .70565 L F
0 0 0 r
.32561 .73369 m .32473 .73437 L .32756 .73312 L F
.08 0 0 r
.32961 .73255 m .32561 .73369 L .32756 .73312 L F
.462 .785 .999 r
.71705 .62382 m .71804 .62463 L .71999 .62437 L F
.491 .85 .992 r
.36241 .66987 m .36042 .67037 L .36171 .67081 L F
0 0 0 r
.36241 .66987 m .36173 .67008 L .36042 .67037 L F
.356 .784 .971 r
.36171 .67081 m .36042 .67037 L .35907 .67066 L F
0 0 0 r
.36173 .67008 m .35896 .6709 L .36042 .67037 L F
.356 .784 .971 r
.35907 .67066 m .36042 .67037 L .35847 .67063 L F
.491 .85 .992 r
.36241 .66987 m .36171 .67081 L .36359 .67068 L F
.611 .117 .055 r
.49309 .7806 m .49162 .78104 L .48981 .78042 L F
.582 .088 .048 r
.4952 .78116 m .49162 .78104 L .49309 .7806 L F
.618 .431 .607 r
.60394 .68347 m .60659 .68346 L .60661 .68107 L F
.576 .338 .518 r
.60659 .68346 m .60904 .68093 L .60661 .68107 L F
.557 .337 .536 r
.61538 .63237 m .61769 .63194 L .61805 .62974 L F
.576 .353 .541 r
.61805 .62974 m .62009 .63088 L .61986 .62894 L F
.61805 .62974 m .61769 .63194 L .62009 .63088 L F
.889 .874 .816 r
.72192 .73164 m .71927 .73283 L .72078 .73092 L F
.861 .718 .703 r
.72192 .73164 m .71856 .73435 L .71927 .73283 L F
.72192 .73164 m .72005 .73504 L .71856 .73435 L F
.493 .523 .817 r
.72303 .7289 m .72192 .73164 L .72078 .73092 L F
.72303 .7289 m .72402 .73194 L .72192 .73164 L F
.824 .62 .627 r
.52668 .7316 m .52476 .72909 L .52619 .73001 L F
0 0 0 r
.63462 .66712 m .63645 .66464 L .63524 .66628 L F
.63645 .66464 m .63765 .66323 L .63524 .66628 L F
.894 .935 .835 r
.63524 .66628 m .63765 .66323 L .63665 .6627 L F
0 0 .073 r
.63599 .66504 m .63589 .6654 L .63524 .66628 L F
.63589 .6654 m .63523 .66806 L .63524 .66628 L F
0 0 0 r
.63436 .66747 m .63462 .66712 L .63524 .66628 L F
.086 0 .352 r
.63524 .66628 m .63394 .66951 L .63436 .66747 L F
.595 .432 .631 r
.6044 .68591 m .60659 .68346 L .60394 .68347 L F
.673 .804 .945 r
.37798 .79687 m .37889 .79453 L .37641 .79564 L F
.37798 .79687 m .38042 .79592 L .37889 .79453 L F
.679 .712 .873 r
.70141 .61256 m .69783 .61117 L .70016 .61047 L F
.552 .617 .871 r
.70254 .60993 m .70141 .61256 L .70016 .61047 L F
.70254 .60993 m .70346 .61225 L .70141 .61256 L F
.385 .219 .53 r
.57958 .68843 m .58147 .69028 L .58272 .68906 L F
.4 .765 .994 r
.58147 .69028 m .58484 .69106 L .58272 .68906 L F
.59 .415 .614 r
.58272 .68906 m .58493 .68875 L .58508 .68633 L F
.578 .371 .564 r
.58272 .68906 m .58484 .69106 L .58493 .68875 L F
.331 0 .203 r
.31338 .66078 m .3161 .65892 L .31432 .65962 L F
.816 .608 .621 r
.65329 .59089 m .65532 .58751 L .65328 .58851 L F
.65329 .59089 m .65658 .59201 L .65532 .58751 L F
.566 .462 .695 r
.65532 .58751 m .65658 .59201 L .65894 .5886 L F
.529 .482 .748 r
.67245 .6218 m .67336 .62417 L .67631 .62334 L F
.223 .745 .802 r
.49224 .72909 m .489 .72954 L .49011 .72947 L F
.547 .386 .615 r
.3838 .74595 m .38387 .74837 L .3859 .74562 L F
.372 .157 .452 r
.36363 .69164 m .36528 .6912 L .3657 .68892 L F
.508 .333 .579 r
.36363 .69164 m .36542 .69363 L .36528 .6912 L F
.36363 .69164 m .36349 .69415 L .36542 .69363 L F
.779 .723 .8 r
.51541 .73204 m .51892 .7324 L .51792 .72948 L F
.623 .395 .551 r
.67245 .6218 m .67355 .6181 L .67185 .62039 L F
.452 .846 .641 r
.69537 .60592 m .69365 .6071 L .69333 .6074 L F
.521 .233 .418 r
.60754 .63736 m .60976 .63698 L .61049 .63451 L F
.594 .309 .453 r
.60976 .63698 m .6128 .63456 L .61049 .63451 L F
.571 .903 .98 r
.6557 .6158 m .65707 .61639 L .65918 .61557 L F
.513 .289 .512 r
.60904 .68093 m .61123 .68049 L .61142 .67833 L F
.397 .193 .483 r
.61142 .67833 m .61123 .68049 L .61327 .67768 L F
.637 .95 .745 r
.63645 .66464 m .63921 .66241 L .63765 .66323 L F
.933 .857 .423 r
.68747 .71389 m .68686 .71508 L .68621 .71289 L F
.68747 .71389 m .687 .71629 L .68686 .71508 L F
.633 .934 .688 r
.37008 .78644 m .36942 .78674 L .37073 .78546 L F
.539 .356 .581 r
.37222 .78375 m .37008 .78644 L .37213 .78601 L F
.872 .855 .822 r
.36679 .78374 m .36314 .78587 L .36701 .78489 L F
.748 .233 0 r
.36735 .78535 m .36679 .78374 L .36701 .78489 L F
.56 .793 .986 r
.28769 .60319 m .28425 .60262 L .28634 .60241 L F
.438 .782 .998 r
.28954 .60286 m .28769 .60319 L .28634 .60241 L F
.853 .776 .775 r
.55251 .69427 m .54992 .69449 L .55174 .69153 L F
.747 .719 .826 r
.55535 .69207 m .55251 .69427 L .55174 .69153 L F
.034 0 0 r
.35289 .71984 m .35247 .71878 L .35447 .71831 L F
.35289 .71984 m .35125 .72075 L .35247 .71878 L F
0 0 0 r
.32561 .73369 m .32415 .73482 L .32473 .73437 L F
.625 .59 .794 r
.40869 .77213 m .40646 .7726 L .4053 .76962 L F
.482 .491 .79 r
.40923 .7757 m .40646 .7726 L .40869 .77213 L F
.559 .006 0 r
.49818 .78168 m .4975 .78238 L .4952 .78116 L F
.767 .266 .014 r
.499 .78272 m .4975 .78238 L .49818 .78168 L F
.517 .383 .638 r
.61363 .67566 m .6157 .67509 L .61538 .67269 L F
.442 .192 .438 r
.61327 .67768 m .6157 .67509 L .61363 .67566 L F
.572 .505 .741 r
.48706 .7677 m .4872 .76936 L .48923 .76746 L F
.48706 .7677 m .4872 .76936 L .48923 .76746 L F
.348 0 .165 r
.60754 .63736 m .60537 .63792 L .60488 .63906 L F
.757 .752 .848 r
.69293 .57524 m .68969 .5749 L .69192 .57302 L F
.761 .754 .846 r
.69534 .57292 m .69293 .57524 L .69192 .57302 L F
.63 .899 .587 r
.53463 .74053 m .53585 .73893 L .53667 .73816 L F
.67 .671 .842 r
.53667 .73816 m .53769 .74022 L .53463 .74053 L F
.528 .495 .763 r
.53531 .74238 m .53585 .73893 L .53463 .74053 L F
.591 .287 .422 r
.7254 .62331 m .72575 .62147 L .72711 .6226 L F
.246 0 0 r
.43205 .78626 m .43107 .78696 L .42887 .78721 L F
.016 0 0 r
.43232 .78694 m .43205 .78626 L .43419 .78601 L F
.43232 .78694 m .43107 .78696 L .43205 .78626 L F
.306 .427 .82 r
.72639 .60118 m .72506 .60228 L .72344 .59916 L F
.204 .245 .683 r
.72639 .60118 m .72679 .6043 L .72506 .60228 L F
.747 .85 .927 r
.7093 .61044 m .70623 .61036 L .70852 .60757 L F
.735 .571 .67 r
.59489 .68297 m .59789 .68357 L .59796 .6811 L F
.315 .753 .967 r
.42611 .74573 m .42811 .74563 L .42469 .74519 L F
.57 .389 .597 r
.37657 .76478 m .37878 .76446 L .37882 .76212 L F
.544 .421 .663 r
.37657 .76478 m .37887 .76687 L .37878 .76446 L F
.37657 .76478 m .37684 .76732 L .37887 .76687 L F
.914 .807 .728 r
.58493 .6774 m .58794 .67539 L .58729 .67516 L F
.58493 .6774 m .58598 .67817 L .58794 .67539 L F
.811 .998 .851 r
.58859 .67352 m .58794 .67539 L .59036 .67291 L F
.822 1 .799 r
.58859 .67352 m .58729 .67516 L .58794 .67539 L F
.98 .708 .439 r
.56055 .70922 m .56188 .7133 L .56179 .71032 L F
.794 .859 .898 r
.56055 .70922 m .56179 .71032 L .56374 .70826 L F
.687 .653 .81 r
.56179 .71032 m .56439 .71056 L .56374 .70826 L F
.484 .298 .552 r
.39033 .74014 m .39241 .73734 L .39042 .73778 L F
.542 .562 .825 r
.56439 .71056 m .56551 .70785 L .56374 .70826 L F
.56439 .71056 m .56687 .71055 L .56551 .70785 L F
.668 .448 .577 r
.56439 .71056 m .56748 .71289 L .56687 .71055 L F
.56439 .71056 m .56328 .71317 L .56748 .71289 L F
.978 .85 .645 r
.66984 .60562 m .66828 .60696 L .66882 .60475 L F
.66984 .60562 m .66926 .60774 L .66828 .60696 L F
.145 0 0 r
.34484 .6744 m .34158 .67513 L .3428 .67463 L F
.575 .531 .769 r
.40501 .76748 m .40198 .7647 L .40386 .76457 L F
.242 .469 .878 r
.36765 .8019 m .36816 .80307 L .36895 .80214 L F
.679 .594 .754 r
.58142 .68362 m .58508 .68633 L .58435 .68403 L F
0 0 .296 r
.58508 .68633 m .58583 .68278 L .58435 .68403 L F
.58508 .68633 m .58586 .6851 L .58583 .68278 L F
.424 .721 .987 r
.58508 .68633 m .58715 .68602 L .58586 .6851 L F
.601 .425 .616 r
.58508 .68633 m .58717 .68795 L .58715 .68602 L F
.58508 .68633 m .58493 .68875 L .58717 .68795 L F
0 .237 .742 r
.65579 .61065 m .65824 .61263 L .65757 .61147 L F
.65579 .61065 m .65757 .61147 L .65473 .61232 L F
.604 .915 .978 r
.40025 .80014 m .40148 .80052 L .40336 .79969 L F
.553 0 0 r
.70698 .73147 m .70599 .73126 L .70401 .72984 L F
.62 .654 .862 r
.70985 .73077 m .70698 .73147 L .70637 .72907 L F
0 .216 .733 r
.70698 .73147 m .70968 .73421 L .7092 .73274 L F
.70698 .73147 m .7092 .73274 L .70599 .73126 L F
.62 .654 .862 r
.70985 .73077 m .70698 .73147 L .70637 .72907 L F
0 0 0 r
.42516 .78817 m .42315 .78875 L .42288 .78872 L F
.833 .881 .878 r
.54863 .6971 m .54751 .6967 L .54992 .69449 L F
.944 .692 .525 r
.54881 .69954 m .54751 .6967 L .54863 .6971 L F
.619 .351 .49 r
.60406 .69751 m .60377 .69947 L .60154 .69951 L F
.666 .394 .499 r
.60695 .69908 m .60406 .69751 L .60707 .69699 L F
.60695 .69908 m .60377 .69947 L .60406 .69751 L F
.542 .919 .773 r
.47998 .7218 m .48096 .72086 L .48217 .7207 L F
.47998 .7218 m .47829 .72253 L .48096 .72086 L F
.915 .783 .7 r
.54958 .70531 m .5481 .70487 L .54854 .70239 L F
.945 .668 .482 r
.54958 .70531 m .54825 .70695 L .5481 .70487 L F
.54958 .70531 m .54972 .7077 L .54825 .70695 L F
.767 .721 .81 r
.55167 .70293 m .54958 .70531 L .54854 .70239 L F
.558 .098 .117 r
.70991 .71854 m .71013 .71995 L .70711 .71881 L F
.444 .198 .446 r
.71247 .71598 m .71242 .71786 L .70991 .71854 L F
.643 .355 .467 r
.71242 .71786 m .71013 .71995 L .70991 .71854 L F
.628 .564 .763 r
.51751 .71556 m .51539 .71638 L .5142 .7128 L F
.533 .341 .566 r
.58446 .71085 m .58409 .71331 L .58231 .71345 L F
.565 .467 .702 r
.58409 .71331 m .58281 .7163 L .58231 .71345 L F
.855 .818 .812 r
.58029 .68255 m .58365 .68089 L .58243 .67998 L F
.58029 .68255 m .58142 .68362 L .58365 .68089 L F
.708 .571 .698 r
.58142 .68362 m .58435 .68403 L .58365 .68089 L F
.622 .64 .848 r
.58365 .68089 m .58493 .6774 L .58243 .67998 L F
.58365 .68089 m .58583 .68087 L .58493 .6774 L F
.344 .328 .697 r
.58365 .68089 m .58583 .68278 L .58583 .68087 L F
.58365 .68089 m .58435 .68403 L .58583 .68278 L F
.529 .454 .716 r
.58633 .72155 m .58439 .724 L .58406 .72224 L F
.58633 .72155 m .58578 .72596 L .58439 .724 L F
.58 .493 .721 r
.58578 .72596 m .58518 .72696 L .58439 .724 L F
.496 0 0 r
.39857 .73424 m .40022 .73442 L .39754 .73388 L F
.444 0 0 r
.39754 .73388 m .40022 .73442 L .40059 .73426 L F
.748 .787 .885 r
.50672 .71423 m .50336 .71427 L .50539 .7132 L F
.728 .839 .933 r
.50863 .71312 m .50672 .71423 L .50539 .7132 L F
.541 .467 .722 r
.37831 .75978 m .38078 .76168 L .38037 .75931 L F
.37831 .75978 m .37882 .76212 L .38078 .76168 L F
.944 .747 .608 r
.64614 .64574 m .64505 .64226 L .64471 .645 L F
.946 .713 .554 r
.64613 .64783 m .64614 .64574 L .64471 .645 L F
.57 .526 .767 r
.29957 .61043 m .30054 .61285 L .29834 .6131 L F
.417 .202 .478 r
.30054 .61285 m .2984 .61577 L .29834 .6131 L F
0 .014 .572 r
.37356 .6529 m .3753 .65545 L .37552 .65384 L F
.728 .573 .681 r
.58907 .68335 m .59256 .68114 L .58914 .68082 L F
.58907 .68335 m .59255 .68356 L .59256 .68114 L F
.67 .526 .68 r
.59256 .68114 m .59255 .68356 L .59489 .68297 L F
.457 .265 .531 r
.69844 .72063 m .69669 .71886 L .69834 .71829 L F
.69844 .72063 m .69642 .72115 L .69669 .71886 L F
.589 .367 .547 r
.71517 .71552 m .71242 .71786 L .71247 .71598 L F
.444 .622 .927 r
.30084 .60638 m .3 .60791 L .29879 .60639 L F
.503 .435 .714 r
.30084 .60638 m .29957 .61043 L .3 .60791 L F
.492 .33 .589 r
.42528 .75418 m .42518 .75676 L .42673 .75523 L F
.42528 .75418 m .42518 .75676 L .42673 .75523 L F
.505 .337 .587 r
.37878 .76446 m .38078 .76168 L .37882 .76212 L F
.663 .529 .691 r
.37222 .78375 m .37472 .78384 L .37433 .781 L F
.708 .536 .653 r
.37213 .78601 m .37472 .78384 L .37222 .78375 L F
.773 .803 .877 r
.7069 .62831 m .71029 .62731 L .70927 .62622 L F
.733 .79 .898 r
.71029 .62731 m .71247 .62656 L .70927 .62622 L F
0 .217 .738 r
.6765 .59598 m .67497 .59387 L .6762 .59353 L F
.612 .368 .522 r
.6128 .63456 m .6152 .63445 L .61538 .63237 L F
.585 .363 .546 r
.6152 .63445 m .61769 .63194 L .61538 .63237 L F
.205 .43 .858 r
.43134 .75291 m .43055 .75398 L .42913 .75156 L F
.523 .351 .589 r
.43261 .75602 m .43056 .75645 L .43055 .75633 L F
.43261 .75602 m .43055 .75633 L .43055 .75398 L F
.398 .788 .989 r
.43489 .75576 m .43455 .75572 L .43261 .75602 L F
.668 .126 0 r
.43128 .75532 m .43199 .75541 L .43055 .75398 L F
.398 .788 .989 r
.43455 .75572 m .43128 .75532 L .43261 .75602 L F
.668 .126 0 r
.43128 .75532 m .43055 .75398 L .43134 .75291 L F
.706 .509 .62 r
.57551 .7347 m .57223 .73199 L .57499 .73211 L F
.57551 .7347 m .57225 .73474 L .57223 .73199 L F
.997 .773 .456 r
.66858 .59954 m .66781 .59607 L .66679 .5993 L F
.896 .517 .064 r
.66843 .60043 m .66858 .59954 L .66679 .5993 L F
.66843 .60043 m .66955 .602 L .66858 .59954 L F
.946 .918 .754 r
.66932 .59633 m .66858 .59954 L .66679 .5993 L F
.846 .468 0 r
.66858 .59954 m .66943 .60175 L .66881 .60108 L F
.825 .934 .902 r
.66103 .6145 m .6646 .61269 L .66385 .61286 L F
0 0 0 r
.6646 .61269 m .66605 .61161 L .66385 .61286 L F
.903 .511 .264 r
.667 .61072 m .66759 .6125 L .66605 .61161 L F
0 .437 .856 r
.66605 .61161 m .66709 .61154 L .66638 .61144 L F
.66605 .61161 m .66638 .61144 L .66481 .6112 L F
0 0 0 r
.6646 .61269 m .66569 .6118 L .66605 .61161 L F
.66569 .6118 m .667 .61072 L .66605 .61161 L F
.879 .67 .616 r
.55425 .70329 m .55809 .70295 L .5542 .7025 L F
.561 .856 .997 r
.55254 .70179 m .55167 .70293 L .5542 .7025 L F
0 .342 .82 r
.55254 .70179 m .55425 .70329 L .5542 .7025 L F
0 .274 .742 r
.55388 .70226 m .55497 .70333 L .5533 .70227 L F
.55285 .7019 m .5533 .70227 L .55254 .70179 L F
.55388 .70226 m .5533 .70227 L .55285 .7019 L F
.879 .67 .616 r
.55449 .70327 m .55727 .70485 L .55809 .70295 L F
.55425 .70329 m .55496 .70366 L .55449 .70327 L F
.55496 .70366 m .55727 .70485 L .55449 .70327 L F
.755 .762 .858 r
.70341 .628 m .70155 .62908 L .70474 .62929 L F
.703 .753 .891 r
.70341 .628 m .70474 .62929 L .7069 .62831 L F
.576 .338 .518 r
.60659 .68346 m .60887 .68312 L .60904 .68093 L F
.522 .299 .516 r
.60887 .68312 m .61123 .68049 L .60904 .68093 L F
.592 .521 .743 r
.53415 .727 m .5319 .72741 L .531 .7241 L F
.603 .487 .693 r
.53415 .727 m .53213 .72951 L .5319 .72741 L F
.594 .841 .991 r
.51103 .72618 m .51446 .72662 L .51317 .72607 L F
.391 .812 .971 r
.51446 .72662 m .5168 .72615 L .51317 .72607 L F
.614 .545 .753 r
.51486 .7297 m .5168 .72615 L .51446 .72662 L F
0 0 .527 r
.687 .71629 m .68826 .71759 L .68686 .71508 L F
.687 .71629 m .6882 .7182 L .68826 .71759 L F
.405 0 0 r
.46968 .7782 m .4686 .7796 L .46657 .77954 L F
.498 0 0 r
.47169 .77867 m .4686 .7796 L .46968 .7782 L F
.396 0 .034 r
.69335 .60243 m .69475 .60347 L .69563 .60214 L F
.69335 .60243 m .69243 .6039 L .69475 .60347 L F
.847 .751 .758 r
.62582 .64753 m .62583 .65127 L .62484 .65056 L F
.969 .762 .57 r
.62583 .65127 m .62436 .65282 L .62484 .65056 L F
.62583 .65127 m .62557 .65362 L .62436 .65282 L F
0 .194 .717 r
.69692 .57793 m .69943 .58035 L .69906 .58044 L F
.661 .2 .147 r
.69906 .58044 m .69838 .58048 L .69747 .58286 L F
.69838 .58048 m .69637 .5806 L .69681 .58151 L F
.69838 .58048 m .69681 .58151 L .69747 .58286 L F
.69747 .58286 m .69637 .5806 L .69744 .5829 L F
.696 .64 .789 r
.69415 .58097 m .69566 .58185 L .69637 .5806 L F
.69566 .58185 m .69744 .5829 L .6968 .58151 L F
.682 .699 .86 r
.69637 .5806 m .69681 .58151 L .69677 .58152 L F
.696 .64 .789 r
.69566 .58185 m .69677 .58152 L .69637 .5806 L F
.682 .699 .86 r
.69637 .5806 m .69677 .58152 L .69431 .5825 L F
.696 .64 .789 r
.69677 .58152 m .6968 .58151 L .69637 .5806 L F
.51 .151 .293 r
.69754 .5813 m .69339 .58448 L .69388 .58343 L F
.69796 .58105 m .69769 .58125 L .69754 .5813 L F
.69769 .58125 m .69339 .58448 L .69754 .5813 L F
.69681 .58151 m .69388 .58343 L .69431 .5825 L F
.69796 .58105 m .69388 .58343 L .69681 .58151 L F
.682 .699 .86 r
.69637 .5806 m .69796 .58105 L .69681 .58151 L F
.51 .151 .293 r
.69796 .58105 m .696 .58432 L .69339 .58448 L F
.078 0 .038 r
.69781 .58325 m .69796 .58105 L .69883 .58205 L F
.69785 .58265 m .696 .58432 L .69796 .58105 L F
.69781 .58325 m .69773 .58329 L .69785 .58265 L F
.69773 .58329 m .696 .58432 L .69785 .58265 L F
.661 .2 .147 r
.69906 .58044 m .69883 .58205 L .69804 .58158 L F
.639 .109 0 r
.69637 .5806 m .6981 .58121 L .69796 .58105 L F
.69637 .5806 m .69883 .58205 L .6981 .58121 L F
.661 .2 .147 r
.69823 .58049 m .69804 .58158 L .69637 .5806 L F
.69906 .58044 m .69804 .58158 L .69823 .58049 L F
.262 .749 .921 r
.27932 .60101 m .27885 .60152 L .27735 .6008 L F
.27932 .60101 m .28098 .60136 L .27885 .60152 L F
.237 0 0 r
.43988 .7843 m .44055 .78499 L .4384 .7853 L F
.43988 .7843 m .44206 .78418 L .44055 .78499 L F
.305 .138 .482 r
.37286 .70421 m .37155 .70267 L .37339 .7022 L F
.37286 .70421 m .37139 .705 L .37155 .70267 L F
.553 .196 .317 r
.4133 .73148 m .41683 .72924 L .41388 .72998 L F
.4133 .73148 m .41559 .73146 L .41683 .72924 L F
.554 .185 .295 r
.41559 .73146 m .41907 .72943 L .41683 .72924 L F
.609 .436 .622 r
.58735 .7075 m .58804 .71086 L .58446 .71085 L F
.644 .478 .643 r
.58804 .71086 m .58409 .71331 L .58446 .71085 L F
.458 .196 .427 r
.58234 .72727 m .58214 .72937 L .58003 .72983 L F
.768 .464 .471 r
.5854 .7294 m .58234 .72727 L .58518 .72696 L F
.5854 .7294 m .58214 .72937 L .58234 .72727 L F
.686 .708 .864 r
.68611 .63689 m .68751 .63866 L .68951 .63753 L F
0 0 .442 r
.38557 .80446 m .38441 .80406 L .38451 .80288 L F
.509 0 0 r
.45119 .72488 m .4545 .72532 L .45226 .72494 L F
.72 .503 .596 r
.70846 .70995 m .71013 .70788 L .70831 .70792 L F
.70846 .70995 m .71068 .71072 L .71013 .70788 L F
.682 .478 .604 r
.71013 .70788 m .71068 .71072 L .71377 .71013 L F
.54 .807 .995 r
.31358 .74569 m .31208 .74585 L .31221 .74517 L F
0 0 0 r
.31208 .74585 m .31193 .74744 L .31221 .74517 L F
.31208 .74585 m .31164 .74827 L .31193 .74744 L F
.498 .31 .556 r
.36528 .6912 m .36739 .68847 L .3657 .68892 L F
.513 0 0 r
.71864 .71564 m .71684 .71575 L .71517 .71552 L F
.429 0 0 r
.71864 .71564 m .72027 .71595 L .71684 .71575 L F
.691 .467 .578 r
.70489 .70806 m .70846 .70995 L .70831 .70792 L F
.70489 .70806 m .70478 .7105 L .70846 .70995 L F
.346 0 .2 r
.31049 .69314 m .30977 .69152 L .31171 .69098 L F
.31049 .69314 m .30866 .6936 L .30977 .69152 L F
.708 .264 .194 r
.4975 .77764 m .49965 .77971 L .50071 .77816 L F
.639 .182 .153 r
.50071 .77816 m .49965 .77971 L .50323 .77965 L F
.547 .593 .852 r
.38658 .66182 m .38419 .6628 L .38421 .66083 L F
.633 .467 .639 r
.58989 .70563 m .58965 .70794 L .58735 .7075 L F
.673 .477 .613 r
.58952 .71023 m .58735 .7075 L .58965 .70794 L F
.58952 .71023 m .58804 .71086 L .58735 .7075 L F
.889 .85 .798 r
.466 .76937 m .46943 .76713 L .46838 .76755 L F
.343 .127 .435 r
.29181 .62391 m .29175 .62626 L .28976 .62678 L F
.187 0 .322 r
.29175 .62626 m .28946 .62892 L .28976 .62678 L F
.553 .233 .38 r
.45615 .77238 m .45939 .76979 L .45664 .77006 L F
.45615 .77238 m .45838 .77247 L .45939 .76979 L F
.556 .236 .382 r
.45939 .76979 m .46159 .77087 L .46155 .76967 L F
.45939 .76979 m .45838 .77247 L .46159 .77087 L F
.866 .517 .388 r
.50528 .78638 m .50369 .78645 L .50234 .78348 L F
.735 .224 0 r
.50528 .78638 m .50599 .78798 L .50369 .78645 L F
.50528 .78638 m .50721 .78877 L .50599 .78798 L F
.8 .327 .099 r
.50871 .789 m .50721 .78877 L .50528 .78638 L F
.868 .89 .848 r
.56323 .68039 m .56083 .68096 L .56211 .67963 L F
.861 .913 .866 r
.56558 .67775 m .56323 .68039 L .56211 .67963 L F
.907 .868 .788 r
.57839 .68572 m .58142 .68362 L .58029 .68255 L F
.57839 .68572 m .57936 .68646 L .58142 .68362 L F
.978 .811 .609 r
.57936 .68646 m .57781 .69003 L .57958 .68843 L F
.57781 .69003 m .57782 .69007 L .57958 .68843 L F
.902 .617 .494 r
.57777 .69012 m .57975 .69128 L .57958 .68843 L F
.79 .539 .557 r
.57718 .68868 m .57936 .68646 L .57839 .68572 L F
.57718 .68868 m .57777 .69012 L .57936 .68646 L F
.908 .926 .544 r
.57728 .68722 m .57718 .68868 L .57839 .68572 L F
.928 .755 .647 r
.57728 .68722 m .57815 .69023 L .57768 .68949 L F
.57725 .68767 m .57768 .68949 L .57718 .68868 L F
.57728 .68722 m .57768 .68949 L .57725 .68767 L F
.978 .811 .609 r
.57781 .69003 m .57777 .69012 L .57782 .69007 L F
.385 .219 .53 r
.57958 .68843 m .57975 .69128 L .58147 .69028 L F
.312 .06 .362 r
.29416 .62093 m .29373 .62341 L .29181 .62391 L F
.319 .01 .274 r
.29648 .61902 m .29607 .62024 L .29416 .62093 L F
.307 .056 .36 r
.29541 .62269 m .29416 .62093 L .29607 .62024 L F
.29541 .62269 m .29373 .62341 L .29416 .62093 L F
.631 .231 .267 r
.40446 .73329 m .40823 .73211 L .40606 .73252 L F
.569 .384 .591 r
.37147 .79512 m .37404 .79535 L .37422 .79224 L F
.754 .769 .865 r
.70927 .62622 m .71247 .62656 L .71171 .62426 L F
.764 .774 .861 r
.71171 .62426 m .71247 .62656 L .71481 .62445 L F
.796 .866 .425 r
.63921 .66241 m .64062 .65901 L .6397 .66057 L F
.86 .995 .764 r
.63765 .66323 m .63921 .66241 L .6397 .66057 L F
.391 0 0 r
.40825 .79259 m .4064 .79362 L .40405 .79368 L F
.133 0 0 r
.40851 .79324 m .40825 .79259 L .40989 .79153 L F
.40851 .79324 m .4064 .79362 L .40825 .79259 L F
.562 .035 0 r
.4545 .72532 m .45651 .72603 L .4579 .72529 L F
.257 0 0 r
.4579 .72529 m .45651 .72603 L .45986 .72546 L F
0 .279 .781 r
.69189 .72509 m .69329 .72528 L .69083 .72336 L F
.69189 .72509 m .69392 .72651 L .69329 .72528 L F
.322 0 .006 r
.60327 .65561 m .59996 .65771 L .6013 .65711 L F
.181 0 0 r
.35074 .67278 m .34906 .67365 L .34745 .67351 L F
.137 0 0 r
.35287 .67249 m .34906 .67365 L .35074 .67278 L F
.557 .375 .591 r
.3013 .69687 m .29961 .69949 L .29969 .69713 L F
.714 .88 .958 r
.32583 .71344 m .32241 .71381 L .32446 .71303 L F
.696 .94 .962 r
.32862 .71207 m .32583 .71344 L .32637 .71197 L F
.679 .924 .972 r
.32583 .71344 m .32446 .71303 L .32637 .71197 L F
.546 .096 .134 r
.47601 .77178 m .47825 .77204 L .47627 .77101 L F
.635 .76 .938 r
.32241 .71381 m .31999 .71475 L .31875 .71301 L F
.978 .677 .344 r
.72149 .7212 m .72273 .72418 L .72176 .72346 L F
.758 .662 .755 r
.72491 .72145 m .72273 .72418 L .72149 .7212 L F
.074 .629 .812 r
.72149 .7212 m .72463 .72129 L .72491 .72145 L F
.49 .467 .758 r
.72273 .72418 m .72463 .72129 L .72176 .72346 L F
.72273 .72418 m .72503 .72374 L .72463 .72129 L F
.474 .383 .672 r
.72273 .72418 m .72524 .7262 L .72503 .72374 L F
.464 .058 .185 r
.53996 .7758 m .53615 .77782 L .53976 .77781 L F
.272 .766 .901 r
.53976 .77781 m .54184 .77753 L .53996 .7758 L F
.518 .361 .608 r
.53996 .7758 m .54184 .77753 L .53976 .77781 L F
.795 .732 .794 r
.69574 .61335 m .69263 .61311 L .6948 .61071 L F
.734 .701 .82 r
.69783 .61117 m .69574 .61335 L .6948 .61071 L F
.594 .454 .66 r
.37608 .77605 m .37853 .77789 L .37812 .77553 L F
.37608 .77605 m .37634 .77819 L .37853 .77789 L F
.616 .54 .746 r
.72004 .59673 m .71776 .59778 L .71635 .59408 L F
.246 0 .301 r
.28608 .6349 m .28686 .63457 L .28583 .63574 L F
.461 .237 .487 r
.31412 .68847 m .31171 .69098 L .31199 .68883 L F
.46 .25 .507 r
.32081 .68315 m .31894 .68584 L .31906 .68344 L F
.953 .952 .706 r
.70384 .71342 m .70342 .71276 L .70478 .7105 L F
.203 .273 .714 r
.70373 .71599 m .70342 .71276 L .70384 .71342 L F
.457 .05 .177 r
.33908 .6504 m .34282 .64834 L .33953 .64802 L F
.33908 .6504 m .34113 .65037 L .34282 .64834 L F
.695 .33 .35 r
.34282 .64834 m .34113 .65037 L .34455 .65027 L F
.484 .289 .539 r
.59623 .70228 m .59424 .70493 L .59391 .70248 L F
.523 .327 .557 r
.5312 .73781 m .53334 .7373 L .53338 .73494 L F
.53338 .73494 m .53334 .7373 L .5312 .73781 L F
.598 .516 .733 r
.53338 .73494 m .53269 .73156 L .53557 .73219 L F
.822 .686 .713 r
.5343 .7292 m .53557 .73219 L .53436 .73192 L F
.53418 .72936 m .53436 .73192 L .53269 .73156 L F
.5343 .7292 m .53436 .73192 L .53418 .72936 L F
.579 .41 .617 r
.53557 .73219 m .53571 .73463 L .53338 .73494 L F
.598 .516 .733 r
.53438 .73219 m .53571 .73463 L .53481 .731 L F
.53338 .73494 m .53455 .73478 L .53438 .73219 L F
.53455 .73478 m .53571 .73463 L .53438 .73219 L F
.53338 .73494 m .53481 .731 L .53269 .73156 L F
.659 .492 .647 r
.53571 .73463 m .53334 .7373 L .53338 .73494 L F
.53334 .7373 m .53571 .73463 L .53338 .73494 L F
.723 .453 .517 r
.62381 .64503 m .62263 .64739 L .62094 .64535 L F
.654 .483 .64 r
.62381 .64503 m .62582 .64753 L .62263 .64739 L F
.62381 .64503 m .6264 .64549 L .62582 .64753 L F
.846 .384 .066 r
.50871 .789 m .50903 .79112 L .50721 .78877 L F
.50871 .789 m .51044 .7917 L .50903 .79112 L F
.839 .421 .244 r
.51195 .79178 m .51044 .7917 L .50871 .789 L F
.617 .145 .111 r
.4624 .73682 m .46491 .73626 L .46437 .73812 L F
.162 0 0 r
.46689 .73646 m .46491 .73626 L .46803 .73533 L F
.175 0 0 r
.46437 .73812 m .46491 .73626 L .46689 .73646 L F
.547 .198 .327 r
.41112 .7315 m .4133 .73148 L .41388 .72998 L F
.345 0 .155 r
.32621 .65171 m .32567 .65274 L .32768 .65225 L F
.021 0 0 r
.29418 .67244 m .29575 .67173 L .29665 .6703 L F
.66 .408 .528 r
.29575 .67173 m .29865 .66972 L .29665 .6703 L F
.483 .257 .494 r
.4051 .75398 m .40473 .75646 L .40274 .75681 L F
.317 .08 .389 r
.40689 .75326 m .4051 .75398 L .40724 .75124 L F
.508 .332 .577 r
.40689 .75326 m .40473 .75646 L .4051 .75398 L F
.555 .292 .473 r
.60154 .69951 m .59981 .70141 L .59936 .69956 L F
.863 .591 .059 r
.72491 .72145 m .72412 .71852 L .72662 .71884 L F
.582 .818 .989 r
.42425 .69981 m .42083 .69947 L .42303 .69906 L F
.42425 .69981 m .42083 .69947 L .42303 .69906 L F
.567 .616 .861 r
.68396 .63719 m .68538 .63413 L .68278 .63537 L F
.68396 .63719 m .68611 .63689 L .68538 .63413 L F
.772 .692 .776 r
.4651 .77108 m .46843 .77253 L .4675 .77019 L F
.815 .401 .263 r
.4651 .77108 m .46724 .77294 L .46843 .77253 L F
.015 .589 .715 r
.46724 .77294 m .47071 .77291 L .46843 .77253 L F
.252 .09 .458 r
.2984 .61577 m .29768 .61854 L .29648 .61902 L F
.176 0 .233 r
.29768 .61854 m .29607 .62024 L .29648 .61902 L F
.597 .487 .7 r
.37472 .78384 m .37648 .78064 L .37433 .781 L F
.564 .111 .134 r
.47169 .77867 m .47519 .77841 L .47389 .77989 L F
.619 .201 .228 r
.47738 .77872 m .47389 .77989 L .47519 .77841 L F
0 .485 .829 r
.52119 .72854 m .52208 .72858 L .51952 .72758 L F
.824 .62 .627 r
.52668 .7316 m .52369 .73182 L .52456 .72961 L F
.52544 .72997 m .52456 .72961 L .52476 .72909 L F
.52668 .7316 m .52456 .72961 L .52544 .72997 L F
0 .485 .829 r
.52119 .72854 m .52484 .72975 L .52267 .72883 L F
.945 .783 .65 r
.52422 .72943 m .52369 .73182 L .52243 .73056 L F
.82 .675 .703 r
.52208 .72858 m .52494 .72978 L .52476 .72909 L F
.945 .783 .65 r
.52476 .72909 m .52456 .72961 L .52422 .72943 L F
.52456 .72961 m .52369 .73182 L .52422 .72943 L F
0 .485 .829 r
.52484 .72975 m .52494 .72978 L .52474 .7297 L F
.52484 .72975 m .52474 .7297 L .52267 .72883 L F
.52207 .72858 m .52267 .72883 L .52208 .72858 L F
.52119 .72854 m .52267 .72883 L .52207 .72858 L F
.651 .729 .906 r
.29545 .60623 m .29462 .60869 L .29282 .60526 L F
.29545 .60623 m .29667 .60791 L .29462 .60869 L F
.304 .041 .339 r
.38487 .69107 m .38254 .6937 L .38294 .69163 L F
.599 .449 .649 r
.40378 .65651 m .40576 .65853 L .40507 .65703 L F
.62 .303 .411 r
.32798 .68099 m .32408 .68281 L .32422 .68078 L F
.863 .591 .059 r
.72491 .72145 m .72463 .72129 L .72412 .71852 L F
.434 .215 .481 r
.64624 .59436 m .64436 .59664 L .64637 .59661 L F
.628 .381 .526 r
.64359 .59881 m .64637 .59661 L .64436 .59664 L F
.558 .758 .971 r
.49756 .72856 m .50111 .72932 L .49981 .72655 L F
.68 .662 .825 r
.49981 .72655 m .50111 .72932 L .50343 .72849 L F
.509 .6 .88 r
.68636 .58399 m .68763 .58227 L .68593 .58341 L F
.68636 .58399 m .68874 .58382 L .68763 .58227 L F
.788 .617 .669 r
.70876 .60422 m .70595 .60553 L .70908 .60239 L F
.70847 .60584 m .70778 .60576 L .70876 .60422 L F
.70778 .60576 m .70595 .60553 L .70876 .60422 L F
.70847 .60584 m .70876 .60422 L .70822 .60471 L F
.70876 .60422 m .70908 .60239 L .70822 .60471 L F
.766 .913 .531 r
.71078 .60106 m .70822 .60471 L .71088 .60079 L F
.71025 .6024 m .70905 .60377 L .71078 .60106 L F
.70905 .60377 m .70822 .60471 L .71078 .60106 L F
.991 .865 .519 r
.71001 .60567 m .70822 .60471 L .71025 .6024 L F
.946 .958 .678 r
.71001 .60567 m .70847 .60584 L .70822 .60471 L F
.71001 .60567 m .70852 .60757 L .70847 .60584 L F
.772 .794 .302 r
.64143 .65591 m .64127 .65623 L .64062 .65901 L F
.77 .71 .796 r
.69375 .63412 m .69473 .63657 L .69712 .6346 L F
.667 .814 .953 r
.41881 .77901 m .41601 .77963 L .41514 .77857 L F
.434 .438 .764 r
.36902 .67823 m .37047 .67757 L .36819 .67558 L F
.597 .498 .713 r
.36862 .68023 m .37047 .67757 L .36902 .67823 L F
.646 .434 .582 r
.63729 .60763 m .63743 .60483 L .63466 .6051 L F
.299 .094 .425 r
.29326 .62545 m .29181 .62391 L .29373 .62341 L F
.29326 .62545 m .29175 .62626 L .29181 .62391 L F
.813 .956 .908 r
.68969 .5749 m .68773 .57681 L .68633 .57621 L F
.565 .467 .702 r
.58409 .71331 m .58536 .71587 L .58281 .7163 L F
.53 .441 .699 r
.58536 .71587 m .58348 .71863 L .58281 .7163 L F
.693 .522 .651 r
.58907 .68335 m .59252 .68577 L .59255 .68356 L F
.727 .559 .663 r
.59252 .68577 m .59489 .68297 L .59255 .68356 L F
.738 .614 .72 r
.57849 .73549 m .57892 .73808 L .57587 .73481 L F
.676 .35 .414 r
.57892 .73808 m .57513 .73975 L .57587 .73481 L F
.57892 .73808 m .57919 .73984 L .57513 .73975 L F
.579 .504 .735 r
.58041 .73529 m .57892 .73808 L .57849 .73549 L F
.62 .554 .759 r
.58177 .73734 m .57892 .73808 L .58041 .73529 L F
.75 .588 .676 r
.58177 .73734 m .57919 .73984 L .57892 .73808 L F
.606 .559 .775 r
.72307 .7405 m .72093 .74125 L .71964 .73742 L F
.636 .774 .947 r
.71975 .73989 m .72093 .74125 L .72307 .7405 L F
.553 0 0 r
.51195 .79178 m .51292 .7931 L .51044 .7917 L F
.51195 .79178 m .51438 .79312 L .51292 .7931 L F
.614 .779 .96 r
.33153 .71239 m .32862 .71207 L .33069 .71172 L F
0 .139 .672 r
.69157 .71299 m .69384 .71513 L .69366 .71557 L F
0 .038 .6 r
.69384 .71513 m .69542 .71773 L .69366 .71557 L F
.157 0 0 r
.47133 .73416 m .47011 .73494 L .46803 .73533 L F
.331 0 0 r
.47333 .73418 m .47011 .73494 L .47133 .73416 L F
.648 .648 .836 r
.531 .7241 m .52728 .72185 L .52979 .72202 L F
.499 .577 .865 r
.53172 .72159 m .531 .7241 L .52979 .72202 L F
.53172 .72159 m .53301 .72407 L .531 .7241 L F
.592 .521 .743 r
.53415 .727 m .531 .7241 L .53301 .72407 L F
.672 .855 .969 r
.49324 .71888 m .48985 .71895 L .49203 .71824 L F
.795 .911 .92 r
.49324 .71888 m .49383 .71681 L .49499 .71768 L F
.49324 .71888 m .49203 .71824 L .49383 .71681 L F
.655 .522 .689 r
.59489 .68297 m .59813 .68577 L .59789 .68357 L F
.638 .822 .971 r
.5306 .73268 m .53269 .73156 L .52881 .73164 L F
.374 .436 .797 r
.73031 .60926 m .72872 .6108 L .72757 .60774 L F
.174 .363 .811 r
.73016 .61092 m .72872 .6108 L .73031 .60926 L F
.73016 .61092 m .73159 .6129 L .72872 .6108 L F
.633 .585 .782 r
.52295 .71598 m .52102 .71798 L .52071 .7163 L F
.52295 .71598 m .52398 .71908 L .52102 .71798 L F
.53 .441 .699 r
.58536 .71587 m .58539 .71821 L .58348 .71863 L F
.597 .481 .691 r
.58633 .72155 m .58348 .71863 L .58539 .71821 L F
.58633 .72155 m .58406 .72224 L .58348 .71863 L F
.535 .354 .582 r
.66926 .61009 m .667 .61072 L .66926 .60774 L F
0 .076 .635 r
.68906 .72123 m .69083 .72336 L .68939 .72083 L F
.476 0 0 r
.56469 .73282 m .56565 .73367 L .56338 .73193 L F
0 0 .452 r
.56561 .73593 m .56529 .7334 L .56565 .73367 L F
.476 0 0 r
.56469 .73282 m .56607 .73398 L .56565 .73367 L F
.028 .313 .801 r
.56338 .73193 m .56565 .73367 L .56384 .73104 L F
0 0 .452 r
.56529 .7334 m .56523 .73295 L .56565 .73367 L F
.476 0 0 r
.56607 .73398 m .56666 .73448 L .56565 .73367 L F
.486 .222 .439 r
.39843 .67255 m .398 .67484 L .39591 .67525 L F
.604 .649 .868 r
.39914 .66941 m .39843 .67255 L .39691 .66972 L F
.39914 .66941 m .40076 .672 L .39843 .67255 L F
.524 .257 .451 r
.40022 .67438 m .398 .67484 L .39843 .67255 L F
.503 .257 .473 r
.40076 .672 m .40022 .67438 L .39843 .67255 L F
.571 .586 .83 r
.68245 .60965 m .68136 .61339 L .68043 .6098 L F
.619 .402 .566 r
.68136 .61339 m .68372 .61374 L .68418 .61264 L F
.003 0 .208 r
.68418 .61264 m .68372 .61374 L .68413 .61315 L F
.515 .177 .332 r
.68413 .61315 m .68413 .61332 L .68411 .61332 L F
.68418 .61264 m .68414 .61315 L .68413 .61315 L F
.68414 .61315 m .68413 .61332 L .68413 .61315 L F
.003 0 .208 r
.68418 .61264 m .68581 .61073 L .68682 .61283 L F
.784 .549 .581 r
.68682 .61283 m .68403 .61448 L .68414 .61315 L F
.68676 .61282 m .68414 .61315 L .68418 .61264 L F
.68682 .61283 m .68414 .61315 L .68676 .61282 L F
.003 0 .208 r
.68418 .61264 m .68413 .61314 L .68581 .61073 L F
.68413 .61314 m .68413 .61315 L .68581 .61073 L F
.515 .177 .332 r
.68418 .61264 m .68411 .61332 L .68136 .61339 L F
.72 .676 .807 r
.68581 .61073 m .68413 .61315 L .68245 .60965 L F
.68413 .61315 m .68413 .61315 L .68413 .61315 L F
.68413 .61315 m .68413 .61315 L .68245 .60965 L F
.68413 .61315 m .68372 .61374 L .68359 .61333 L F
.68413 .61315 m .68359 .61333 L .68245 .60965 L F
.571 .586 .83 r
.68359 .61333 m .68372 .61374 L .68136 .61339 L F
.515 .177 .332 r
.68413 .61332 m .68403 .61448 L .68136 .61339 L F
.571 .586 .83 r
.68245 .60965 m .68359 .61333 L .68136 .61339 L F
.21 .683 .938 r
.68403 .61448 m .68151 .61399 L .68136 .61339 L F
.546 .29 .478 r
.40925 .75099 m .40689 .75326 L .40724 .75124 L F
.475 .241 .478 r
.38737 .68621 m .38702 .68833 L .38504 .68877 L F
.432 .217 .485 r
.38915 .68564 m .38702 .68833 L .38737 .68621 L F
.131 0 .093 r
.61913 .68896 m .61857 .69075 L .61648 .69135 L F
0 0 .208 r
.62079 .68567 m .62055 .68797 L .61913 .68896 L F
0 0 0 r
.62055 .68797 m .61857 .69075 L .61913 .68896 L F
.417 .158 .411 r
.61648 .69135 m .61676 .69352 L .61425 .69396 L F
.152 0 .322 r
.61857 .69075 m .61676 .69352 L .61648 .69135 L F
.525 .411 .666 r
.40635 .80031 m .40694 .8028 L .40888 .80221 L F
.40635 .80031 m .40694 .8028 L .40888 .80221 L F
.58 .493 .721 r
.58578 .72596 m .58727 .72666 L .58518 .72696 L F
.608 .497 .702 r
.58727 .72666 m .5854 .7294 L .58518 .72696 L F
.986 .73 .451 r
.54048 .76984 m .53941 .76935 L .54044 .76742 L F
.399 .746 .993 r
.54134 .76647 m .54306 .7675 L .54044 .76742 L F
.606 .408 .587 r
.54306 .7675 m .54048 .76984 L .54044 .76742 L F
0 0 0 r
.54044 .76742 m .53941 .76935 L .54134 .76647 L F
.741 .332 .276 r
.50234 .78348 m .50063 .78385 L .499 .78272 L F
.717 .188 0 r
.50369 .78645 m .50063 .78385 L .50234 .78348 L F
.916 .971 .785 r
.57349 .70147 m .57595 .6996 L .57407 .69883 L F
.57349 .70147 m .57391 .70231 L .57595 .6996 L F
.601 .237 .323 r
.57836 .69691 m .57407 .69883 L .57595 .6996 L F
.605 .452 .647 r
.57595 .6996 m .57903 .69932 L .57836 .69691 L F
.567 .382 .59 r
.37422 .79224 m .3762 .79459 L .37615 .7918 L F
.37422 .79224 m .37404 .79535 L .3762 .79459 L F
.471 .742 .988 r
.67268 .5872 m .67453 .5873 L .67406 .58867 L F
0 0 0 r
.6767 .59168 m .67824 .58815 L .67901 .58869 L F
.578 .498 .728 r
.67901 .58869 m .67907 .59131 L .6767 .59168 L F
0 0 0 r
.67761 .59131 m .6767 .59168 L .67907 .59131 L F
.67744 .59131 m .67739 .59133 L .67761 .59131 L F
.67739 .59133 m .6767 .59168 L .67761 .59131 L F
.6767 .59168 m .677 .59201 L .67785 .58939 L F
.6767 .59168 m .67785 .58939 L .67818 .58831 L F
0 .147 .674 r
.67453 .5873 m .677 .59201 L .67406 .58867 L F
0 0 .469 r
.67406 .58867 m .677 .59201 L .6767 .59168 L F
.938 .888 .756 r
.67478 .59416 m .67717 .59159 L .67464 .59191 L F
0 0 0 r
.67744 .59131 m .6762 .59353 L .6767 .59168 L F
.938 .888 .756 r
.67717 .59159 m .67744 .59131 L .67725 .59135 L F
.741 .534 .613 r
.67721 .59135 m .677 .59201 L .67669 .59141 L F
.938 .888 .756 r
.67717 .59159 m .67725 .59135 L .67464 .59191 L F
0 0 0 r
.67818 .58831 m .67785 .58939 L .67824 .58815 L F
.741 .534 .613 r
.67824 .58815 m .67721 .59135 L .67453 .5873 L F
.67721 .59135 m .67669 .59141 L .67453 .5873 L F
.608 .438 .626 r
.51312 .73172 m .51541 .73204 L .51486 .7297 L F
0 .436 .73 r
.30836 .73736 m .30696 .73689 L .3069 .73676 L F
.30836 .73736 m .30892 .73751 L .30696 .73689 L F
.748 .658 .762 r
.69415 .58097 m .69212 .58377 L .69431 .5825 L F
.59 .153 .178 r
.69431 .5825 m .69135 .58371 L .69212 .58377 L F
.69431 .5825 m .69339 .58448 L .69135 .58371 L F
.682 .699 .86 r
.69637 .5806 m .69431 .5825 L .69415 .58097 L F
.591 .763 .961 r
.49224 .72909 m .49565 .72979 L .49436 .72886 L F
.758 .857 .924 r
.49436 .72886 m .49565 .72979 L .49756 .72856 L F
.528 .37 .611 r
.40571 .76145 m .40386 .76457 L .40387 .76195 L F
.48 .138 .309 r
.32772 .68112 m .32865 .683 L .32613 .68327 L F
.888 .986 .806 r
.73112 .72638 m .72953 .72957 L .73115 .72649 L F
.66 .855 .461 r
.73304 .72346 m .73112 .72638 L .73115 .72649 L F
.678 .507 .647 r
.59183 .70766 m .58989 .70563 L .59167 .70518 L F
.59183 .70766 m .58965 .70794 L .58989 .70563 L F
.742 .854 .932 r
.50089 .71584 m .49768 .71603 L .49951 .71475 L F
.745 .822 .912 r
.50336 .71427 m .50089 .71584 L .49951 .71475 L F
.522 .364 .608 r
.39388 .68038 m .39186 .68084 L .39384 .678 L F
.564 .371 .578 r
.39388 .68038 m .39163 .68302 L .39186 .68084 L F
.082 0 .076 r
.29408 .67263 m .29575 .67173 L .29418 .67244 L F
.492 .314 .568 r
.64624 .59436 m .64825 .59413 L .64794 .59153 L F
.488 .308 .563 r
.64637 .59661 m .64825 .59413 L .64624 .59436 L F
.406 .819 .975 r
.4305 .77538 m .42983 .77633 L .42845 .77558 L F
.4305 .77538 m .43223 .77605 L .42983 .77633 L F
.725 .642 .765 r
.58598 .67817 m .58583 .68087 L .58914 .68082 L F
.915 .585 .405 r
.58583 .68087 m .58709 .68325 L .58914 .68082 L F
.759 .604 .685 r
.58709 .68325 m .58907 .68335 L .58914 .68082 L F
.61 .779 .962 r
.71357 .73141 m .70985 .73077 L .71235 .73025 L F
0 0 .081 r
.71424 .7286 m .71357 .73141 L .71235 .73025 L F
.71424 .7286 m .71417 .73073 L .71357 .73141 L F
.134 0 .392 r
.53733 .72932 m .53557 .73219 L .5343 .7292 L F
.53733 .72932 m .53694 .73211 L .53557 .73219 L F
.153 .304 .765 r
.53694 .73211 m .53773 .73414 L .53557 .73219 L F
.504 .353 .609 r
.53773 .73414 m .53571 .73463 L .53557 .73219 L F
.042 .596 .824 r
.35565 .65021 m .35908 .65074 L .35724 .65058 L F
.127 .671 .827 r
.48332 .77964 m .47942 .77957 L .48072 .77837 L F
.457 .147 .349 r
.31045 .66374 m .31338 .66078 L .31141 .66144 L F
.745 .75 .856 r
.69375 .63412 m .69712 .6346 L .69618 .63188 L F
.714 .733 .866 r
.69618 .63188 m .69712 .6346 L .69985 .63243 L F
.579 .343 .523 r
.60931 .69685 m .60695 .69908 L .60707 .69699 L F
0 .342 .716 r
.69858 .72923 m .69949 .72951 L .69762 .72853 L F
.69858 .72923 m .70088 .73025 L .69949 .72951 L F
.676 .441 .558 r
.53375 .77736 m .53615 .77782 L .53385 .77527 L F
.257 .73 .94 r
.43129 .7451 m .43238 .74468 L .43026 .74486 L F
.43129 .7451 m .43377 .7451 L .43238 .74468 L F
.543 .748 .971 r
.35226 .64969 m .35153 .6512 L .35038 .64812 L F
.35226 .64969 m .35362 .65085 L .35153 .6512 L F
0 0 .483 r
.71172 .61992 m .71161 .62098 L .71126 .61941 L F
0 .182 .715 r
.71381 .62328 m .71161 .62098 L .71172 .61992 L F
.661 .337 .414 r
.61312 .64827 m .6161 .64817 L .61536 .6502 L F
.763 .59 .662 r
.61827 .64825 m .61536 .6502 L .6161 .64817 L F
.47 .144 .331 r
.53769 .74022 m .5367 .74233 L .53531 .74238 L F
.609 .543 .755 r
.53888 .73724 m .53769 .74022 L .53667 .73816 L F
.53888 .73724 m .54 .74016 L .53769 .74022 L F
.678 .364 .436 r
.53981 .74151 m .53769 .74022 L .54 .74016 L F
.53981 .74151 m .5367 .74233 L .53769 .74022 L F
.684 .783 .926 r
.4407 .7754 m .43735 .77537 L .43986 .77478 L F
.709 .498 .601 r
.43986 .77478 m .44294 .77526 L .4407 .7754 L F
.661 .601 .777 r
.71888 .59177 m .71635 .59408 L .71571 .59099 L F
.644 .57 .757 r
.71888 .59177 m .71961 .59463 L .71635 .59408 L F
.616 .54 .746 r
.72004 .59673 m .71635 .59408 L .71961 .59463 L F
.626 .481 .665 r
.68043 .6098 m .67748 .60889 L .67885 .60656 L F
.68043 .6098 m .67796 .61042 L .67748 .60889 L F
.984 .706 .349 r
.48251 .73476 m .48177 .73555 L .47884 .73479 L F
.48251 .73476 m .48223 .73596 L .48177 .73555 L F
.669 .436 .559 r
.48461 .73404 m .48223 .73596 L .48251 .73476 L F
.011 0 0 r
.471 .72486 m .46885 .72485 L .46751 .72487 L F
.614 .545 .753 r
.51486 .7297 m .51792 .72948 L .5168 .72615 L F
.602 .435 .627 r
.51486 .7297 m .51541 .73204 L .51792 .72948 L F
.579 .425 .636 r
.64825 .59413 m .6504 .59116 L .64794 .59153 L F
0 0 0 r
.72872 .73118 m .72757 .73257 L .72953 .72957 L F
.888 .986 .806 r
.73112 .72638 m .72913 .72888 L .72953 .72957 L F
.966 .838 .421 r
.72913 .72888 m .72872 .73118 L .72953 .72957 L F
.616 .722 .922 r
.50343 .72849 m .50654 .72931 L .50521 .7281 L F
.789 .777 .842 r
.50521 .7281 m .50654 .72931 L .50898 .72709 L F
.71 .429 .499 r
.52881 .73164 m .53269 .73156 L .53213 .72951 L F
.267 .661 .968 r
.53269 .73156 m .5311 .73072 L .53213 .72951 L F
.822 .686 .713 r
.5343 .7292 m .53269 .73156 L .53213 .72951 L F
.728 .313 .261 r
.53304 .7309 m .53188 .73076 L .5311 .73072 L F
.71 .429 .499 r
.53032 .73067 m .53213 .72951 L .5311 .73072 L F
.728 .313 .261 r
.53188 .73076 m .52932 .73044 L .5311 .73072 L F
.71 .429 .499 r
.52881 .73164 m .53032 .73067 L .5311 .73072 L F
.603 .487 .693 r
.53415 .727 m .5343 .7292 L .53213 .72951 L F
.399 .135 .394 r
.38063 .69421 m .38027 .69669 L .37816 .69692 L F
.326 .074 .371 r
.38192 .69592 m .38063 .69421 L .38254 .6937 L F
.38192 .69592 m .38027 .69669 L .38063 .69421 L F
.574 .462 .687 r
.37684 .76732 m .37945 .76975 L .37887 .76687 L F
.37684 .76732 m .37731 .77017 L .37945 .76975 L F
.416 .144 .39 r
.53542 .78389 m .53783 .78133 L .53742 .78338 L F
.033 0 .25 r
.53783 .78133 m .53976 .77781 L .53952 .77937 L F
.467 .197 .42 r
.53959 .78286 m .53783 .78133 L .53952 .77937 L F
.53959 .78286 m .53742 .78338 L .53783 .78133 L F
.533 .359 .591 r
.3818 .7511 m .38383 .75073 L .38387 .74837 L F
.524 .386 .634 r
.38206 .75348 m .38383 .75073 L .3818 .7511 L F
.268 0 .28 r
.62298 .68321 m .62295 .68537 L .62079 .68567 L F
.149 0 .213 r
.62528 .68052 m .62508 .68256 L .62298 .68321 L F
.167 0 .262 r
.62508 .68256 m .62295 .68537 L .62298 .68321 L F
.689 .196 .07 r
.68174 .62646 m .68406 .62817 L .68133 .62803 L F
.628 .846 .462 r
.71951 .61632 m .71843 .61784 L .71853 .61758 L F
.02 0 0 r
.35847 .67063 m .3569 .67127 L .35484 .67163 L F
0 0 0 r
.36042 .67037 m .3569 .67127 L .35847 .67063 L F
.981 .724 .325 r
.64641 .63432 m .64655 .63692 L .64725 .63749 L F
.971 .927 .675 r
.64725 .63749 m .64585 .63858 L .64695 .63966 L F
.64725 .63749 m .64655 .63692 L .64585 .63858 L F
.771 .808 .882 r
.68874 .58382 m .69212 .58377 L .69135 .58371 L F
.713 .837 .941 r
.48772 .71965 m .48404 .71987 L .48625 .71892 L F
.603 .857 .992 r
.48985 .71895 m .48772 .71965 L .48625 .71892 L F
0 0 0 r
.33517 .72979 m .33467 .72921 L .33656 .72869 L F
.33517 .72979 m .33317 .73098 L .33467 .72921 L F
.883 .548 .409 r
.33778 .71044 m .34121 .71053 L .3392 .71098 L F
.33799 .7103 m .34121 .71053 L .33778 .71044 L F
.33727 .71025 m .33799 .7103 L .33778 .71044 L F
.33727 .71025 m .33954 .7118 L .34121 .71053 L F
.423 0 .054 r
.33954 .7118 m .34333 .71015 L .34121 .71053 L F
.33954 .7118 m .34179 .71177 L .34333 .71015 L F
.199 .467 .886 r
.33829 .7101 m .34049 .71153 L .33954 .7118 L F
.3381 .70985 m .33838 .71004 L .33829 .7101 L F
.33838 .71004 m .34049 .71153 L .33829 .7101 L F
.564 .366 .571 r
.59424 .70493 m .59183 .70766 L .59167 .70518 L F
.535 .354 .582 r
.66926 .61009 m .66926 .60774 L .66828 .60696 L F
.992 .745 .447 r
.66926 .60774 m .66926 .61009 L .66828 .60696 L F
.54 .471 .726 r
.40473 .75646 m .40545 .75846 L .40274 .75681 L F
.783 .42 .369 r
.57004 .73546 m .56864 .73702 L .56666 .73448 L F
.657 .253 .267 r
.57166 .73659 m .56864 .73702 L .57004 .73546 L F
.946 .756 .614 r
.57225 .73474 m .57166 .73659 L .57004 .73546 L F
.67 .122 0 r
.3753 .65545 m .37684 .65688 L .37787 .65728 L F
.061 .574 .88 r
.37888 .65707 m .37787 .65728 L .37684 .65688 L F
.37888 .65707 m .38048 .65782 L .37787 .65728 L F
.902 .92 .53 r
.72872 .73118 m .72777 .73467 L .72757 .73257 L F
.705 .423 .494 r
.6014 .68798 m .6044 .68591 L .60141 .68626 L F
.6014 .68798 m .60365 .68843 L .6044 .68591 L F
.595 .432 .631 r
.6044 .68591 m .60672 .68585 L .60659 .68346 L F
.652 .369 .477 r
.6044 .68591 m .60671 .68812 L .60672 .68585 L F
.6044 .68591 m .60365 .68843 L .60671 .68812 L F
.593 .833 .99 r
.35041 .64797 m .34812 .64853 L .3468 .6477 L F
.497 .514 .804 r
.35038 .64812 m .34812 .64853 L .35041 .64797 L F
.912 .524 .258 r
.55257 .71595 m .55117 .71532 L .55058 .71331 L F
.882 .514 .342 r
.55257 .71595 m .55116 .7169 L .55117 .71532 L F
.55257 .71595 m .55382 .7185 L .55116 .7169 L F
.485 .805 1 r
.3513 .8077 m .35485 .8081 L .35336 .80735 L F
.313 0 .235 r
.59787 .64341 m .59734 .64477 L .59994 .64265 L F
.45 .242 .505 r
.38702 .68833 m .38487 .69107 L .38504 .68877 L F
.698 .412 .485 r
.61312 .64827 m .61326 .65007 L .60978 .65024 L F
.621 .353 .491 r
.61312 .64827 m .61536 .6502 L .61326 .65007 L F
.708 .536 .653 r
.37213 .78601 m .37514 .78641 L .37472 .78384 L F
.597 .487 .7 r
.37472 .78384 m .37718 .78363 L .37648 .78064 L F
.658 .501 .661 r
.37472 .78384 m .37756 .78604 L .37718 .78363 L F
.37472 .78384 m .37514 .78641 L .37756 .78604 L F
0 0 .294 r
.71816 .61293 m .71951 .61632 L .71869 .61524 L F
.628 .846 .462 r
.71951 .61632 m .71853 .61758 L .71869 .61524 L F
.747 .719 .826 r
.55535 .69207 m .55174 .69153 L .55342 .69078 L F
.133 0 0 r
.4507 .77269 m .4486 .77311 L .44695 .77422 L F
.408 .635 .948 r
.38042 .79592 m .38312 .79732 L .38192 .79443 L F
.229 .41 .835 r
.38192 .79443 m .38312 .79732 L .38415 .79586 L F
.734 .62 .732 r
.57661 .73161 m .57849 .73549 L .57551 .7347 L F
.738 .614 .72 r
.57849 .73549 m .57587 .73481 L .57551 .7347 L F
.436 .473 .799 r
.58001 .73396 m .57849 .73549 L .57661 .73161 L F
.579 .504 .735 r
.58041 .73529 m .57849 .73549 L .58001 .73396 L F
.541 .837 .999 r
.54125 .75043 m .53919 .75099 L .54243 .75116 L F
.54243 .75116 m .53919 .75099 L .54125 .75043 L F
.417 0 0 r
.50607 .78116 m .50837 .78177 L .50983 .78051 L F
.84 .468 0 r
.5111 .78216 m .50983 .78051 L .50837 .78177 L F
.5111 .78216 m .51119 .78142 L .50983 .78051 L F
.481 .18 .379 r
.31088 .7402 m .30813 .74234 L .30891 .74031 L F
.819 .902 .899 r
.68854 .7088 m .68643 .71065 L .68566 .70965 L F
.961 .8 .362 r
.68643 .71065 m .68585 .71186 L .68566 .70965 L F
.68643 .71065 m .68621 .71289 L .68585 .71186 L F
.743 .911 .95 r
.71073 .57879 m .71215 .57678 L .71033 .57706 L F
.71073 .57879 m .71339 .57732 L .71215 .57678 L F
.55 .408 .64 r
.38026 .75679 m .38247 .75891 L .38225 .7564 L F
.38026 .75679 m .38037 .75931 L .38247 .75891 L F
.473 .519 .825 r
.6805 .63485 m .68278 .63537 L .68201 .63336 L F
.709 .647 .786 r
.51975 .71419 m .52071 .7163 L .51751 .71556 L F
.6 .614 .837 r
.52201 .71368 m .52071 .7163 L .51975 .71419 L F
.52201 .71368 m .52295 .71598 L .52071 .7163 L F
.861 .913 .866 r
.56558 .67775 m .56211 .67963 L .5648 .67739 L F
.884 .967 .84 r
.5648 .67739 m .56794 .67518 L .56558 .67775 L F
.047 0 .229 r
.62702 .67753 m .62701 .67966 L .62528 .68052 L F
.027 0 .225 r
.6288 .67665 m .62701 .67966 L .62702 .67753 L F
.606 .292 .411 r
.59861 .68808 m .60141 .68626 L .59813 .68577 L F
.59861 .68808 m .6014 .68798 L .60141 .68626 L F
.689 .346 .389 r
.31193 .74744 m .31358 .74569 L .31221 .74517 L F
.31193 .74744 m .31511 .74779 L .31358 .74569 L F
.829 .354 0 r
.55579 .72065 m .55382 .7185 L .55569 .71859 L F
.253 0 .08 r
.32396 .65399 m .32463 .65526 L .32567 .65274 L F
.32396 .65399 m .32271 .65587 L .32463 .65526 L F
.265 .771 .775 r
.31114 .71258 m .30992 .71277 L .31192 .71222 L F
.276 0 0 r
.42315 .78875 m .41984 .78977 L .42107 .78922 L F
.548 .894 .98 r
.62049 .6207 m .62273 .61993 L .62353 .62043 L F
.925 .644 .489 r
.62353 .62043 m .62221 .62208 L .62049 .6207 L F
.62353 .62043 m .62389 .62337 L .62221 .62208 L F
.408 0 .059 r
.62273 .61993 m .62599 .61835 L .62353 .62043 L F
.083 .521 .904 r
.3174 .71198 m .31717 .71267 L .31553 .71168 L F
.3174 .71198 m .31875 .71301 L .31717 .71267 L F
.265 0 0 r
.45986 .72546 m .46202 .72556 L .46336 .72507 L F
.26 0 0 r
.46202 .72556 m .46534 .72497 L .46336 .72507 L F
.765 .453 .458 r
.65341 .59325 m .65658 .59201 L .65329 .59089 L F
.65341 .59325 m .65679 .5937 L .65658 .59201 L F
.531 .202 .355 r
.30568 .66611 m .30862 .66435 L .30639 .6647 L F
.431 .12 .335 r
.60203 .64201 m .60488 .63906 L .60249 .6397 L F
.322 .792 .691 r
.48217 .7207 m .48302 .72025 L .48404 .71987 L F
.298 .793 .793 r
.48217 .7207 m .48096 .72086 L .48302 .72025 L F
.983 .699 .345 r
.6739 .62106 m .67477 .62187 L .67355 .6181 L F
.58 .55 .785 r
.67812 .62036 m .67477 .62187 L .67355 .6181 L F
.498 .372 .639 r
.67477 .62187 m .67631 .62334 L .67713 .62311 L F
.627 .861 .987 r
.67812 .62036 m .67477 .62187 L .6739 .62106 L F
.214 .103 .504 r
.6157 .67509 m .61736 .67162 L .61538 .67269 L F
.296 .715 .973 r
.53616 .7464 m .53498 .74564 L .53234 .74561 L F
.888 .914 .837 r
.53616 .7464 m .53689 .74538 L .53498 .74564 L F
.826 .783 .811 r
.51641 .70991 m .5142 .7128 L .51328 .71068 L F
.628 .564 .763 r
.51751 .71556 m .5142 .7128 L .51669 .712 L F
.542 .724 .958 r
.38227 .65811 m .3815 .65977 L .38048 .65782 L F
.38227 .65811 m .38336 .65923 L .3815 .65977 L F
.51 .556 .839 r
.38421 .66083 m .3815 .65977 L .38336 .65923 L F
.562 .456 .691 r
.37594 .78869 m .37756 .78604 L .37514 .78641 L F
.37594 .78869 m .37776 .78846 L .37756 .78604 L F
.476 .378 .665 r
.37594 .78869 m .37813 .79104 L .37776 .78846 L F
.37594 .78869 m .37615 .7918 L .37813 .79104 L F
.756 .55 .618 r
.58715 .68602 m .58907 .68335 L .58709 .68325 L F
.58715 .68602 m .59033 .68633 L .58907 .68335 L F
.693 .522 .651 r
.58907 .68335 m .59033 .68633 L .59252 .68577 L F
.727 .559 .663 r
.59252 .68577 m .59602 .68601 L .59489 .68297 L F
.655 .522 .689 r
.59489 .68297 m .59602 .68601 L .59813 .68577 L F
.584 .502 .728 r
.4115 .77522 m .40923 .7757 L .40869 .77213 L F
.514 .428 .696 r
.4115 .77522 m .41031 .77738 L .40923 .7757 L F
.737 .494 .561 r
.72394 .71592 m .7206 .71802 L .72027 .71595 L F
.72394 .71592 m .72412 .71852 L .7206 .71802 L F
.576 .465 .69 r
.29476 .67483 m .29408 .67263 L .29386 .6749 L F
.29476 .67483 m .29575 .67173 L .29408 .67263 L F
.571 .571 .814 r
.4059 .7643 m .40501 .76748 L .40386 .76457 L F
.4059 .7643 m .40711 .76721 L .40501 .76748 L F
.561 .455 .69 r
.40711 .76721 m .4053 .76962 L .40501 .76748 L F
.792 .722 .787 r
.5854 .7294 m .58311 .73199 L .58214 .72937 L F
.622 .688 .891 r
.58311 .73199 m .58459 .72918 L .58214 .72937 L F
.623 .459 .639 r
.5854 .7294 m .5861 .73172 L .58311 .73199 L F
.622 .688 .891 r
.58311 .73199 m .5861 .73172 L .58459 .72918 L F
.026 0 .182 r
.62528 .68052 m .62701 .67966 L .62508 .68256 L F
.213 0 0 r
.44663 .78398 m .44526 .78328 L .44737 .78316 L F
.44663 .78398 m .4443 .78443 L .44526 .78328 L F
.473 .329 .605 r
.54184 .77753 m .53952 .77937 L .53976 .77781 L F
.54184 .77753 m .54228 .7805 L .53952 .77937 L F
.306 .117 .452 r
.54127 .78182 m .53952 .77937 L .54228 .7805 L F
.54127 .78182 m .53959 .78286 L .53952 .77937 L F
.742 .316 .238 r
.51722 .78062 m .51944 .78277 L .52047 .78143 L F
.51 .046 .087 r
.52047 .78143 m .51944 .78277 L .52278 .78225 L F
.203 .273 .714 r
.70373 .71599 m .70507 .71497 L .70342 .71276 L F
.883 .488 .277 r
.70373 .71599 m .70446 .71806 L .70249 .71712 L F
.504 .868 .985 r
.70281 .71552 m .70507 .71497 L .70373 .71599 L F
.674 .536 .689 r
.36333 .79944 m .3655 .7967 L .36372 .79624 L F
.916 .805 .722 r
.58493 .6774 m .58583 .68087 L .58598 .67817 L F
.915 .585 .405 r
.58583 .68087 m .58583 .68278 L .58709 .68325 L F
.626 .502 .691 r
.57661 .73161 m .57551 .7347 L .57499 .73211 L F
.542 .722 .957 r
.3669 .6515 m .36595 .65319 L .36463 .65141 L F
.3669 .6515 m .368 .65287 L .36595 .65319 L F
.63 .62 .821 r
.39089 .66601 m .39206 .66834 L .38839 .66646 L F
.633 .621 .82 r
.39406 .66757 m .39206 .66834 L .39089 .66601 L F
.591 .439 .643 r
.37634 .77819 m .37648 .78064 L .37853 .77789 L F
.68 .43 .537 r
.36819 .67558 m .37047 .67757 L .37088 .67536 L F
.276 .345 .753 r
.37088 .67536 m .37215 .6745 L .37108 .67188 L F
.241 .275 .697 r
.37088 .67536 m .37269 .67715 L .37215 .6745 L F
.545 .304 .501 r
.37088 .67536 m .37047 .67757 L .37269 .67715 L F
.37088 .67536 m .37047 .67757 L .37269 .67715 L F
.48 .386 .671 r
.70883 .59684 m .71132 .59859 L .71089 .59609 L F
0 0 0 r
.36185 .71302 m .36085 .71489 L .3595 .71529 L F
.36085 .71489 m .35922 .71601 L .3595 .71529 L F
.189 .721 .812 r
.41314 .79124 m .41201 .79125 L .40989 .79153 L F
.082 .642 .72 r
.41494 .79098 m .41201 .79125 L .41314 .79124 L F
.497 .292 .532 r
.39127 .68507 m .38938 .68341 L .39163 .68302 L F
.39127 .68507 m .38915 .68564 L .38938 .68341 L F
.61 .375 .536 r
.31894 .68584 m .31627 .68827 L .31654 .68627 L F
.874 .509 .353 r
.55883 .72364 m .55579 .72065 L .55872 .72138 L F
.169 0 0 r
.45298 .78066 m .45135 .78214 L .44916 .78253 L F
.282 0 0 r
.45372 .78166 m .45298 .78066 L .45514 .78042 L F
.45372 .78166 m .45135 .78214 L .45298 .78066 L F
.898 .942 .83 r
.64763 .62866 m .65057 .62671 L .64991 .62639 L F
.64763 .62866 m .64846 .62936 L .65057 .62671 L F
.878 .992 .796 r
.65109 .62472 m .64991 .62639 L .65057 .62671 L F
.789 .654 .1 r
.66837 .59109 m .66834 .59439 L .66828 .59311 L F
0 0 .342 r
.66834 .59439 m .66893 .59546 L .66828 .59311 L F
.66834 .59439 m .66932 .59633 L .66893 .59546 L F
.608 .497 .702 r
.58727 .72666 m .588 .72939 L .5854 .7294 L F
.277 .032 .351 r
.588 .72939 m .5861 .73172 L .5854 .7294 L F
.689 .692 .847 r
.36509 .67544 m .36819 .67558 L .36719 .67489 L F
0 0 0 r
.58058 .72967 m .58003 .72983 L .58214 .72937 L F
.58058 .72967 m .57852 .7306 L .58003 .72983 L F
.614 .474 .668 r
.3859 .74562 m .38387 .74837 L .38621 .74804 L F
.607 .419 .602 r
.38387 .74837 m .38618 .75047 L .38621 .74804 L F
.38387 .74837 m .38383 .75073 L .38618 .75047 L F
.667 .814 .953 r
.41881 .77901 m .41514 .77857 L .41738 .77816 L F
.582 .856 .995 r
.42087 .77835 m .41881 .77901 L .41738 .77816 L F
.048 0 0 r
.471 .72486 m .47287 .72466 L .47444 .72416 L F
.315 .804 .806 r
.47287 .72466 m .47658 .72381 L .47444 .72416 L F
.559 .322 .512 r
.3044 .69418 m .30503 .69739 L .3013 .69687 L F
.502 .285 .516 r
.3062 .69618 m .3044 .69418 L .3068 .69439 L F
.3062 .69618 m .30503 .69739 L .3044 .69418 L F
.275 .003 .307 r
.62295 .68537 m .62055 .68797 L .62079 .68567 L F
.996 .849 .576 r
.64802 .63099 m .64846 .62936 L .64763 .62866 L F
.839 .472 .359 r
.70711 .71881 m .70615 .72032 L .70446 .71806 L F
.564 .139 .193 r
.71013 .71995 m .70615 .72032 L .70711 .71881 L F
.552 .727 .955 r
.70626 .72672 m .70229 .72587 L .70664 .72627 L F
.118 .046 .492 r
.70773 .72773 m .70626 .72672 L .70703 .72574 L F
0 0 0 r
.70664 .72627 m .70703 .72574 L .70626 .72672 L F
.118 .046 .492 r
.70773 .72773 m .70637 .72907 L .70626 .72672 L F
.519 .432 .697 r
.37799 .77268 m .37945 .76975 L .37731 .77017 L F
.37799 .77268 m .37994 .77243 L .37945 .76975 L F
.347 .189 .52 r
.37812 .77553 m .37994 .77243 L .37799 .77268 L F
.429 .141 .372 r
.36877 .70745 m .36615 .70989 L .36657 .70774 L F
.468 .191 .409 r
.53615 .77782 m .53777 .77888 L .53976 .77781 L F
.272 .766 .901 r
.53976 .77781 m .54043 .7773 L .54184 .77753 L F
.415 .833 .661 r
.53777 .77888 m .54043 .7773 L .53976 .77781 L F
.702 .473 .574 r
.43748 .74376 m .43572 .74566 L .43377 .7451 L F
.622 .36 .501 r
.43917 .74488 m .43748 .74376 L .43924 .7429 L F
.43917 .74488 m .43572 .74566 L .43748 .74376 L F
.18 0 0 r
.42887 .78721 m .42734 .78797 L .42516 .78817 L F
0 0 0 r
.42939 .78749 m .42887 .78721 L .43107 .78696 L F
.42939 .78749 m .42734 .78797 L .42887 .78721 L F
.703 .753 .891 r
.70341 .628 m .7069 .62831 L .70602 .62587 L F
.746 .735 .842 r
.70602 .62587 m .7069 .62831 L .70927 .62622 L F
.629 .594 .796 r
.39089 .66601 m .38839 .66646 L .38803 .66539 L F
.481 0 .016 r
.43433 .72583 m .43652 .726 L .43782 .72493 L F
.407 0 0 r
.43782 .72493 m .43652 .726 L .43984 .7254 L F
.623 .394 .548 r
.44139 .74277 m .43917 .74488 L .43924 .7429 L F
0 0 0 r
.59091 .65092 m .59226 .64995 L .59325 .64832 L F
.59091 .65092 m .58979 .65236 L .59226 .64995 L F
.544 .92 .932 r
.39323 .79663 m .39465 .79661 L .39531 .79578 L F
.243 .539 .924 r
.39465 .79661 m .39665 .79728 L .39531 .79578 L F
.544 .92 .932 r
.39323 .79663 m .39465 .79661 L .39531 .79578 L F
.85 .527 .439 r
.39465 .79661 m .39778 .79987 L .39665 .79728 L F
.601 .237 .323 r
.57836 .69691 m .57753 .69902 L .57407 .69883 L F
.413 .231 .523 r
.57593 .69574 m .57728 .69648 L .57803 .69614 L F
.153 0 .171 r
.57903 .69932 m .58121 .69689 L .57836 .69691 L F
.641 .381 .51 r
.58121 .69689 m .58079 .69731 L .57836 .69691 L F
.594 .593 .82 r
.57836 .69691 m .58079 .69731 L .57941 .69328 L F
.153 0 .171 r
.58114 .69697 m .58065 .69866 L .58121 .69689 L F
.57903 .69932 m .58065 .69866 L .58114 .69697 L F
.606 .242 .325 r
.58065 .69866 m .57753 .69902 L .57836 .69691 L F
.007 0 .413 r
.57921 .70229 m .58065 .69866 L .57903 .69932 L F
.769 .555 .609 r
.58059 .69867 m .57717 .70073 L .57753 .69902 L F
.58065 .69866 m .58059 .6987 L .58059 .69867 L F
.58059 .6987 m .57717 .70073 L .58059 .69867 L F
.606 .242 .325 r
.58059 .6986 m .57836 .69691 L .57803 .69614 L F
.58065 .69866 m .5806 .69862 L .58059 .6986 L F
.5806 .69862 m .57836 .69691 L .58059 .6986 L F
.007 0 .413 r
.57921 .70229 m .58055 .70118 L .58065 .69866 L F
.769 .555 .609 r
.58065 .69866 m .58055 .70118 L .57717 .70073 L F
.976 .765 .345 r
.58008 .69803 m .57999 .70052 L .58026 .70084 L F
.58038 .70005 m .58026 .70084 L .58055 .70118 L F
.58008 .69803 m .58026 .70084 L .58038 .70005 L F
.58008 .69803 m .58034 .69976 L .58065 .69866 L F
.58034 .69976 m .58055 .70118 L .58065 .69866 L F
.606 .242 .325 r
.58065 .69866 m .58037 .69839 L .58008 .69803 L F
.58037 .69839 m .57803 .69614 L .58008 .69803 L F
.549 .811 .994 r
.57988 .69668 m .58008 .69803 L .57875 .69687 L F
.996 .763 .441 r
.57965 .69749 m .58008 .69803 L .57988 .69668 L F
.413 .231 .523 r
.57728 .69648 m .58008 .69803 L .57803 .69614 L F
.57633 .69596 m .57875 .69688 L .58008 .69803 L F
.874 .742 .714 r
.57709 .6988 m .57934 .6971 L .57646 .6976 L F
.57934 .6971 m .57988 .69668 L .57892 .69694 L F
.413 .231 .523 r
.57616 .69587 m .57875 .69687 L .57875 .69688 L F
.57616 .69587 m .57875 .69688 L .57633 .69596 L F
.57593 .69574 m .57875 .69687 L .57616 .69587 L F
.57593 .69574 m .57631 .69792 L .57875 .69687 L F
.477 .892 .913 r
.57631 .69792 m .57646 .6976 L .57875 .69687 L F
.874 .742 .714 r
.57934 .6971 m .57892 .69694 L .57646 .6976 L F
.448 .07 .229 r
.57875 .69687 m .57646 .6976 L .57892 .69694 L F
.57875 .69687 m .57892 .69694 L .57988 .69668 L F
.996 .763 .441 r
.57906 .69947 m .58008 .69803 L .57965 .69749 L F
.594 .593 .82 r
.57836 .69691 m .57867 .69584 L .57803 .69614 L F
.57867 .69584 m .57941 .69328 L .57803 .69614 L F
.541 .208 .352 r
.42436 .72872 m .42657 .72868 L .42716 .72716 L F
.505 .189 .365 r
.42657 .72868 m .42922 .72683 L .42716 .72716 L F
.55 .366 .585 r
.60672 .68585 m .60887 .68312 L .60659 .68346 L F
.469 .876 .95 r
.61944 .62658 m .62082 .62559 L .62187 .62601 L F
.61944 .62658 m .61853 .62633 L .62082 .62559 L F
.959 .775 .611 r
.62187 .62601 m .61853 .62633 L .61944 .62658 L F
.491 .383 .659 r
.61986 .62894 m .62187 .62601 L .61944 .62658 L F
.868 .896 .852 r
.32862 .71207 m .32858 .70949 L .33069 .71172 L F
.32862 .71207 m .32637 .71197 L .32858 .70949 L F
.454 .15 .36 r
.39241 .73734 m .39455 .73699 L .39504 .73519 L F
.557 .246 .397 r
.39504 .73519 m .39674 .73656 L .39857 .73424 L F
.39504 .73519 m .39455 .73699 L .39674 .73656 L F
.459 .188 .414 r
.35137 .70518 m .35357 .70473 L .35432 .7022 L F
.397 .131 .389 r
.35432 .7022 m .35534 .70416 L .35663 .70232 L F
.35432 .7022 m .35357 .70473 L .35534 .70416 L F
.98 .825 .423 r
.72336 .73782 m .72296 .73794 L .72286 .73718 L F
.693 .525 .654 r
.58484 .69106 m .58717 .68795 L .58493 .68875 L F
.494 0 0 r
.43984 .7254 m .44203 .72571 L .44339 .72471 L F
.364 0 0 r
.44203 .72571 m .44547 .7249 L .44339 .72471 L F
.412 .149 .403 r
.37969 .69854 m .37816 .69692 L .38027 .69669 L F
.37969 .69854 m .37772 .69915 L .37816 .69692 L F
.728 .839 .933 r
.50863 .71312 m .50539 .7132 L .50729 .71181 L F
.76 .782 .871 r
.51123 .71127 m .50863 .71312 L .50729 .71181 L F
.504 .432 .708 r
.58869 .72313 m .58578 .72596 L .58633 .72155 L F
.221 .145 .554 r
.58869 .72313 m .58727 .72666 L .58578 .72596 L F
.532 .804 .996 r
.30643 .71252 m .3058 .71391 L .30426 .71288 L F
.30643 .71252 m .30795 .71347 L .3058 .71391 L F
.035 0 0 r
.45869 .77999 m .4573 .78026 L .45514 .78042 L F
.213 0 0 r
.46063 .78011 m .4573 .78026 L .45869 .77999 L F
.541 .376 .607 r
.63729 .60763 m .63928 .6042 L .63743 .60483 L F
.329 .719 .982 r
.34913 .88637 m .35138 .88644 L .34979 .88559 L F
.34979 .88559 m .35138 .88644 L .34913 .88637 L F
.34913 .88637 m .35138 .88644 L .34979 .88559 L F
.903 .549 .36 r
.55058 .71331 m .54947 .71481 L .54832 .71216 L F
.874 .502 .336 r
.55117 .71532 m .54947 .71481 L .55058 .71331 L F
.734 .885 .95 r
.49768 .71603 m .49499 .71768 L .49383 .71681 L F
.322 0 .006 r
.60327 .65561 m .60214 .65726 L .59996 .65771 L F
.438 .017 .141 r
.60411 .65552 m .60214 .65726 L .60327 .65561 L F
.531 .524 .792 r
.52574 .71703 m .52398 .71908 L .52295 .71598 L F
.551 .552 .809 r
.52574 .71703 m .52605 .71884 L .52398 .71908 L F
.761 .754 .846 r
.69534 .57292 m .69213 .57302 L .6942 .57267 L F
.131 0 0 r
.6942 .57267 m .69739 .57171 L .69534 .57292 L F
.508 .056 .112 r
.69328 .5734 m .69658 .57226 L .6942 .57267 L F
.69658 .57226 m .69675 .57221 L .6942 .57267 L F
.761 .754 .846 r
.69213 .57302 m .69192 .57302 L .6942 .57267 L F
.356 .065 .326 r
.52845 .77829 m .52606 .7806 L .52824 .77977 L F
.624 .291 .387 r
.52824 .77977 m .53054 .7801 L .52845 .77829 L F
.599 .301 .435 r
.52845 .77829 m .53054 .7801 L .53091 .77832 L F
.884 .967 .84 r
.5648 .67739 m .56707 .67471 L .56794 .67518 L F
.856 .971 .867 r
.56794 .67518 m .56949 .67225 L .57024 .67259 L F
.56794 .67518 m .56707 .67471 L .56949 .67225 L F
.721 .484 .567 r
.57392 .7047 m .57747 .70666 L .57716 .70511 L F
.685 .356 .411 r
.57747 .70666 m .57951 .70721 L .57716 .70511 L F
.564 .386 .598 r
.57716 .70511 m .57951 .70721 L .57959 .70465 L F
.299 .139 .488 r
.40405 .79368 m .40231 .79676 L .40245 .79439 L F
.66 .243 .243 r
.36237 .80519 m .35868 .80548 L .36141 .80344 L F
0 0 0 r
.36007 .80708 m .36237 .80519 L .36095 .80657 L F
.202 .405 .838 r
.36363 .80455 m .36237 .80519 L .36141 .80344 L F
0 0 0 r
.36095 .80657 m .36237 .80519 L .36363 .80455 L F
.959 .723 .538 r
.36095 .80657 m .36237 .80519 L .36141 .80344 L F
.514 .428 .696 r
.4115 .77522 m .41199 .7774 L .41031 .77738 L F
.946 .713 .554 r
.64613 .64783 m .64471 .645 L .64465 .64673 L F
.878 .817 .785 r
.6441 .65056 m .64613 .64783 L .64465 .64673 L F
.594 .309 .453 r
.60976 .63698 m .61303 .6365 L .6128 .63456 L F
.681 .431 .537 r
.61303 .6365 m .6152 .63445 L .6128 .63456 L F
.586 .523 .751 r
.69815 .71594 m .70048 .71558 L .70012 .71322 L F
0 0 0 r
.59325 .64832 m .59464 .64738 L .59538 .64557 L F
.59325 .64832 m .59375 .64873 L .59464 .64738 L F
.59325 .64832 m .59226 .64995 L .59375 .64873 L F
0 0 .159 r
.70025 .57141 m .70029 .57477 L .70092 .57251 L F
.685 .808 .941 r
.37889 .79453 m .38042 .79592 L .38192 .79443 L F
.548 .638 .891 r
.414 .77696 m .41299 .77882 L .41199 .7774 L F
.414 .77696 m .41514 .77857 L .41299 .77882 L F
.216 0 0 r
.3468 .70791 m .34733 .70914 L .34878 .7074 L F
.3468 .70791 m .34542 .70972 L .34733 .70914 L F
.662 .38 .483 r
.41148 .75295 m .40925 .75099 L .41242 .7505 L F
.587 .322 .482 r
.41446 .75033 m .41148 .75295 L .41242 .7505 L F
.862 .551 .46 r
.69033 .61689 m .68709 .61489 L .69052 .6156 L F
.69018 .61792 m .68945 .61721 L .69033 .61689 L F
.68945 .61721 m .68709 .61489 L .69033 .61689 L F
0 0 0 r
.69028 .61766 m .68453 .61974 L .68585 .61857 L F
.69028 .61766 m .69009 .6177 L .68936 .61725 L F
.69009 .6177 m .68585 .61857 L .68914 .61733 L F
.69009 .6177 m .68914 .61733 L .68936 .61725 L F
.81 .926 .912 r
.68771 .61681 m .68453 .61974 L .68362 .61895 L F
.9 .523 .307 r
.68847 .61697 m .68788 .61684 L .68634 .61623 L F
.81 .926 .912 r
.688 .61666 m .6878 .61683 L .68771 .61681 L F
.6878 .61683 m .68453 .61974 L .68771 .61681 L F
.9 .523 .307 r
.68709 .61489 m .68847 .61697 L .68634 .61623 L F
.68847 .61697 m .68857 .61712 L .68788 .61684 L F
0 0 0 r
.68936 .61725 m .68585 .61857 L .68759 .61702 L F
.9 .523 .307 r
.68857 .61712 m .68655 .61635 L .68634 .61623 L F
.81 .926 .912 r
.688 .61666 m .68771 .61681 L .68634 .61623 L F
.68771 .61681 m .68362 .61895 L .68634 .61623 L F
.9 .523 .307 r
.68731 .61664 m .68899 .61775 L .68655 .61635 L F
0 0 0 r
.68921 .61719 m .68759 .61702 L .688 .61666 L F
.9 .523 .307 r
.68857 .61712 m .68862 .61719 L .68731 .61664 L F
.68862 .61719 m .68899 .61775 L .68731 .61664 L F
.862 .551 .46 r
.69018 .61792 m .68899 .61775 L .68857 .61712 L F
.68945 .61721 m .68857 .61712 L .68709 .61489 L F
0 0 0 r
.68936 .61725 m .68759 .61702 L .68921 .61719 L F
.876 .719 .684 r
.68921 .61719 m .69018 .61792 L .69028 .61766 L F
.862 .551 .46 r
.69018 .61792 m .68857 .61712 L .68921 .61719 L F
.876 .719 .684 r
.688 .61666 m .69018 .61792 L .68921 .61719 L F
.862 .551 .46 r
.69018 .61792 m .68921 .61719 L .68945 .61721 L F
.625 .59 .794 r
.40869 .77213 m .4053 .76962 L .4085 .77033 L F
.681 .589 .746 r
.41084 .76963 m .40869 .77213 L .4085 .77033 L F
.653 .548 .723 r
.41084 .76963 m .41108 .7728 L .40869 .77213 L F
.584 .502 .728 r
.4115 .77522 m .40869 .77213 L .41108 .7728 L F
0 0 .047 r
.67974 .60373 m .6797 .60483 L .67964 .60205 L F
.67974 .60373 m .67964 .60205 L .67842 .6011 L F
.56 .853 .997 r
.37105 .79656 m .37448 .79665 L .37337 .79592 L F
.37105 .79656 m .37448 .79665 L .37337 .79592 L F
.641 .648 .841 r
.37404 .79535 m .37448 .79665 L .37641 .79564 L F
.861 .787 .777 r
.30696 .73689 m .30892 .73751 L .3083 .73848 L F
.667 .601 .772 r
.40711 .76721 m .4085 .77033 L .4053 .76962 L F
.643 .745 .923 r
.70229 .72587 m .69951 .72454 L .70187 .72415 L F
.533 .614 .879 r
.70423 .72328 m .70229 .72587 L .70187 .72415 L F
.70423 .72328 m .70664 .72627 L .70229 .72587 L F
0 .033 .595 r
.56338 .73193 m .56242 .72864 L .56367 .72954 L F
0 .014 .572 r
.37356 .6529 m .37543 .65512 L .3753 .65545 L F
0 .12 .645 r
.37543 .65512 m .37684 .65688 L .3753 .65545 L F
.442 .068 .232 r
.45699 .73763 m .45453 .7388 L .45483 .73794 L F
.789 .777 .842 r
.50521 .7281 m .50898 .72709 L .50778 .72624 L F
.659 .868 .978 r
.50778 .72624 m .50898 .72709 L .51103 .72618 L F
.676 .423 .531 r
.61425 .69396 m .61431 .69671 L .61156 .69636 L F
.47 .274 .531 r
.61676 .69352 m .61431 .69671 L .61425 .69396 L F
.869 .734 .712 r
.54854 .70239 m .5458 .70393 L .54797 .70082 L F
.87 .683 .647 r
.54797 .70082 m .54443 .70086 L .54551 .6962 L F
.942 .835 .709 r
.54797 .70082 m .54458 .70319 L .54443 .70086 L F
.54797 .70082 m .5458 .70393 L .54458 .70319 L F
.964 .636 .268 r
.54717 .69925 m .54854 .70239 L .54797 .70082 L F
.907 .698 .609 r
.54881 .69954 m .54854 .70239 L .54717 .69925 L F
.54881 .69954 m .54717 .69925 L .5482 .69984 L F
.944 .692 .525 r
.54881 .69954 m .5482 .69984 L .54751 .6967 L F
.574 .41 .621 r
.39591 .67525 m .39601 .67762 L .39384 .678 L F
.568 .398 .611 r
.39601 .67762 m .39388 .68038 L .39384 .678 L F
0 0 0 r
.33159 .65121 m .3318 .6513 L .33358 .65061 L F
.33159 .65121 m .32976 .65174 L .3318 .6513 L F
.582 .088 .048 r
.4952 .78116 m .49388 .78229 L .49162 .78104 L F
.582 .089 .048 r
.4975 .78238 m .49388 .78229 L .4952 .78116 L F
.589 .175 .225 r
.39406 .66757 m .3972 .66752 L .39473 .66714 L F
.074 0 .034 r
.59538 .64557 m .59634 .64639 L .59734 .64477 L F
.59538 .64557 m .59464 .64738 L .59634 .64639 L F
.422 .373 .698 r
.70973 .57502 m .71033 .57706 L .71215 .57678 L F
.161 .605 .935 r
.71434 .73702 m .71553 .73663 L .71324 .73623 L F
.052 .273 .766 r
.71434 .73702 m .71655 .73911 L .71553 .73663 L F
.287 0 .029 r
.34507 .725 m .34451 .72369 L .34655 .72307 L F
.34507 .725 m .34311 .72546 L .34451 .72369 L F
.826 .783 .811 r
.51641 .70991 m .51328 .71068 L .51514 .70942 L F
.459 .809 .998 r
.51514 .70942 m .51895 .70979 L .51641 .70991 L F
.331 .089 .388 r
.71495 .61281 m .71526 .61096 L .71712 .60999 L F
.71495 .61281 m .71526 .61096 L .71712 .60999 L F
.58 .943 .851 r
.5234 .79016 m .52257 .79114 L .52499 .78877 L F
.5234 .79016 m .52192 .79115 L .52257 .79114 L F
.867 .853 .826 r
.31873 .73708 m .3218 .73546 L .31946 .73624 L F
.274 .742 .944 r
.32346 .73672 m .31946 .73624 L .3218 .73546 L F
.493 .238 .456 r
.32415 .73482 m .32346 .73672 L .3218 .73546 L F
.204 .37 .808 r
.39665 .79728 m .39778 .79987 L .39862 .79864 L F
.406 .65 .957 r
.39778 .79987 m .40025 .80014 L .39862 .79864 L F
.243 .306 .729 r
.57349 .70147 m .57392 .7047 L .57391 .70231 L F
.444 .778 .998 r
.28479 .60156 m .28425 .60262 L .2828 .60143 L F
.28479 .60156 m .28634 .60241 L .28425 .60262 L F
.501 .278 .508 r
.60989 .65268 m .608 .65095 L .60978 .65024 L F
.60989 .65268 m .60771 .65328 L .608 .65095 L F
.473 .827 .996 r
.31478 .73646 m .31241 .73684 L .31402 .73736 L F
.568 .393 .604 r
.36325 .69658 m .36542 .69363 L .36349 .69415 L F
.73 .454 .51 r
.7206 .71802 m .71684 .71575 L .72027 .71595 L F
.188 .547 .93 r
.73367 .71384 m .73151 .71397 L .73044 .71292 L F
.73367 .71384 m .73453 .71503 L .73151 .71397 L F
.861 .787 .777 r
.30696 .73689 m .3083 .73848 L .30688 .73724 L F
.671 .562 .723 r
.51975 .71419 m .51751 .71556 L .51669 .712 L F
.41 .582 .911 r
.72344 .59916 m .72004 .59673 L .72247 .596 L F
.5 .487 .774 r
.72559 .5989 m .72344 .59916 L .72247 .596 L F
.306 .427 .82 r
.72639 .60118 m .72344 .59916 L .72559 .5989 L F
.803 .718 .77 r
.71712 .60999 m .71816 .61293 L .71495 .61281 L F
.677 .442 .558 r
.71816 .61293 m .71489 .61562 L .71495 .61281 L F
.71816 .61293 m .71869 .61524 L .71489 .61562 L F
.599 .449 .649 r
.40378 .65651 m .40354 .65903 L .40576 .65853 L F
.68 .662 .825 r
.49981 .72655 m .50343 .72849 L .50213 .72623 L F
.585 .673 .9 r
.50213 .72623 m .50343 .72849 L .50521 .7281 L F
0 0 0 r
.53542 .78389 m .53393 .78531 L .53249 .78564 L F
.434 .008 .129 r
.53742 .78338 m .53393 .78531 L .53542 .78389 L F
.909 .624 .492 r
.36679 .79973 m .36556 .80238 L .36333 .79944 L F
.36679 .79973 m .36765 .8019 L .36556 .80238 L F
0 0 0 r
.36768 .79874 m .36679 .79973 L .36896 .797 L F
.306 .398 .793 r
.36768 .79874 m .36765 .8019 L .36679 .79973 L F
.554 .185 .295 r
.41559 .73146 m .41798 .7314 L .41907 .72943 L F
.511 .139 .271 r
.41907 .72943 m .42093 .73058 L .42128 .7295 L F
.41907 .72943 m .41798 .7314 L .42093 .73058 L F
.498 0 0 r
.47169 .77867 m .47042 .77985 L .4686 .7796 L F
.567 .074 .044 r
.47389 .77989 m .47042 .77985 L .47169 .77867 L F
.679 .511 .651 r
.59183 .70766 m .58952 .71023 L .58965 .70794 L F
.318 .438 .826 r
.71489 .61562 m .7123 .61343 L .71495 .61281 L F
.751 .381 .352 r
.57587 .73481 m .57434 .73648 L .57551 .7347 L F
.98 .799 .588 r
.57587 .73481 m .57513 .73975 L .57434 .73648 L F
.583 .356 .538 r
.62094 .64535 m .62092 .64775 L .61827 .64825 L F
.701 .452 .544 r
.62094 .64535 m .62263 .64739 L .62092 .64775 L F
.895 .9 .823 r
.7227 .62566 m .72365 .62658 L .7254 .62331 L F
.733 .653 .77 r
.67654 .58014 m .67768 .58333 L .67411 .58317 L F
.358 0 .039 r
.67768 .58333 m .6744 .5851 L .67411 .58317 L F
.67768 .58333 m .67748 .58358 L .6744 .5851 L F
.67748 .58358 m .67582 .58486 L .6744 .5851 L F
.517 .318 .55 r
.67658 .58474 m .67453 .5873 L .6744 .5851 L F
.948 .917 .748 r
.67453 .5873 m .67527 .58353 L .6744 .5851 L F
.67486 .58561 m .67357 .5866 L .67527 .58353 L F
.67453 .5873 m .67357 .5866 L .67486 .58561 L F
.67357 .5866 m .67357 .5866 L .67486 .58561 L F
.358 0 .039 r
.67748 .58358 m .67658 .58474 L .67582 .58486 L F
.758 .857 .924 r
.49436 .72886 m .49756 .72856 L .49675 .7268 L F
.784 .835 .891 r
.49675 .7268 m .49756 .72856 L .49981 .72655 L F
.157 0 .121 r
.52637 .78831 m .52656 .7887 L .52499 .78877 L F
.096 0 0 r
.52656 .7887 m .5234 .79016 L .52499 .78877 L F
.526 .29 .5 r
.36086 .69907 m .36325 .69658 L .36128 .69705 L F
.17 .58 .936 r
.36359 .67068 m .36474 .67022 L .36241 .66987 L F
.36359 .67068 m .36606 .67134 L .36474 .67022 L F
.537 .318 .529 r
.35663 .70232 m .3588 .70198 L .35912 .69963 L F
.465 .256 .51 r
.35912 .69963 m .36073 .70142 L .36086 .69907 L F
.35912 .69963 m .3588 .70198 L .36073 .70142 L F
0 0 .038 r
.52668 .7316 m .52417 .73455 L .52369 .73182 L F
.52668 .7316 m .52572 .73385 L .52417 .73455 L F
.528 .286 .492 r
.52572 .73385 m .5232 .73633 L .52417 .73455 L F
.237 .383 .808 r
.69764 .57663 m .69943 .58035 L .69692 .57793 L F
.531 .327 .549 r
.38803 .74523 m .3903 .74252 L .38818 .74288 L F
.544 .362 .585 r
.38818 .74288 m .3903 .74252 L .39033 .74014 L F
.396 .173 .455 r
.28769 .63421 m .28583 .63574 L .28686 .63457 L F
.28769 .63421 m .28558 .63699 L .28583 .63574 L F
.636 .555 .747 r
.3674 .68607 m .36975 .68584 L .36908 .68403 L F
.513 .355 .604 r
.3674 .68607 m .36739 .68847 L .3694 .68799 L F
.597 .352 .517 r
.3674 .68607 m .3694 .68799 L .36975 .68584 L F
.511 .313 .548 r
.63048 .6133 m .63286 .61254 L .63272 .61029 L F
.509 .312 .548 r
.63286 .61254 m .63499 .60983 L .63272 .61029 L F
.678 .331 .38 r
.71377 .71013 m .71614 .71206 L .71693 .71013 L F
.559 .177 .274 r
.71614 .71206 m .71929 .71025 L .71693 .71013 L F
.19 0 .021 r
.57551 .7347 m .5721 .73699 L .57225 .73474 L F
.57551 .7347 m .57434 .73648 L .5721 .73699 L F
0 .36 .778 r
.70599 .73126 m .70323 .72968 L .70401 .72984 L F
.168 0 .019 r
.48608 .73101 m .48377 .7327 L .48448 .73112 L F
.195 .721 .846 r
.4341 .77545 m .43577 .7753 L .43735 .77537 L F
.279 0 0 r
.43577 .7753 m .43986 .77478 L .43735 .77537 L F
.639 .508 .687 r
.3762 .79459 m .37813 .79104 L .37615 .7918 L F
.535 .823 .999 r
.37008 .6526 m .37356 .6529 L .37144 .6534 L F
.957 .799 .644 r
.62557 .65362 m .62502 .65588 L .62436 .65282 L F
.558 .109 .141 r
.34158 .67513 m .33831 .67629 L .33994 .67602 L F
.209 0 0 r
.34745 .67351 m .34694 .6741 L .34484 .6744 L F
.216 0 0 r
.34906 .67365 m .34694 .6741 L .34745 .67351 L F
.764 .774 .861 r
.71171 .62426 m .71481 .62445 L .71381 .62328 L F
.624 .646 .852 r
.71481 .62445 m .71631 .62165 L .71381 .62328 L F
.71481 .62445 m .71705 .62382 L .71631 .62165 L F
.689 .279 .263 r
.48535 .77435 m .48679 .77523 L .48857 .77451 L F
.537 .06 .069 r
.48857 .77451 m .48679 .77523 L .49058 .77491 L F
.505 .337 .587 r
.37878 .76446 m .38083 .76404 L .38078 .76168 L F
.547 .397 .629 r
.37878 .76446 m .38082 .76649 L .38083 .76404 L F
.37878 .76446 m .37887 .76687 L .38082 .76649 L F
.71 .682 .821 r
.68611 .63689 m .68951 .63753 L .68852 .63458 L F
.727 .691 .816 r
.68852 .63458 m .68951 .63753 L .69149 .63633 L F
.294 .035 .34 r
.36415 .71037 m .36356 .71279 L .36185 .71302 L F
.317 0 .17 r
.36277 .71431 m .36185 .71302 L .36356 .71279 L F
.36277 .71431 m .36085 .71489 L .36185 .71302 L F
.533 .359 .592 r
.63942 .60224 m .64162 .60164 L .6415 .59926 L F
.578 .389 .59 r
.63928 .6042 m .64162 .60164 L .63942 .60224 L F
.555 .292 .473 r
.60154 .69951 m .6014 .70144 L .59981 .70141 L F
.614 .342 .481 r
.60154 .69951 m .60387 .70142 L .6014 .70144 L F
.616 .341 .477 r
.60377 .69947 m .60387 .70142 L .60154 .69951 L F
.579 .343 .523 r
.60931 .69685 m .60916 .69896 L .60695 .69908 L F
.526 .313 .533 r
.61156 .69636 m .60916 .69896 L .60931 .69685 L F
0 0 0 r
.36768 .79874 m .36896 .797 L .3655 .7967 L F
.819 .902 .899 r
.68854 .7088 m .68566 .70965 L .68725 .70786 L F
.733 .864 .943 r
.69029 .7077 m .68854 .7088 L .68725 .70786 L F
.564 .366 .571 r
.59424 .70493 m .5942 .70735 L .59183 .70766 L F
.484 .289 .539 r
.59623 .70228 m .59628 .70445 L .59424 .70493 L F
.531 .34 .566 r
.59641 .70683 m .59424 .70493 L .59628 .70445 L F
.59641 .70683 m .5942 .70735 L .59424 .70493 L F
.86 .719 .705 r
.72005 .73504 m .71964 .73742 L .71856 .73435 L F
.17 .652 .927 r
.71975 .73989 m .71655 .73911 L .71746 .74015 L F
.524 .386 .634 r
.38206 .75348 m .384 .75313 L .38383 .75073 L F
.498 .379 .648 r
.38225 .7564 m .384 .75313 L .38206 .75348 L F
.635 .186 .167 r
.48981 .78042 m .48829 .78164 L .48634 .78035 L F
.461 0 0 r
.49162 .78104 m .48829 .78164 L .48981 .78042 L F
0 0 .335 r
.55727 .70485 m .55865 .70441 L .55867 .7024 L F
.55845 .70256 m .55867 .7024 L .55868 .70212 L F
.55727 .70485 m .55867 .7024 L .55845 .70256 L F
.413 .732 .991 r
.5542 .7025 m .55833 .70265 L .55556 .70062 L F
.55833 .70265 m .55848 .70265 L .5584 .7026 L F
.55833 .70265 m .5584 .7026 L .55556 .70062 L F
.411 0 .073 r
.52278 .78225 m .52493 .78212 L .52606 .7806 L F
.524 .184 .333 r
.52493 .78212 m .52824 .77977 L .52606 .7806 L F
.734 .701 .82 r
.69783 .61117 m .6948 .61071 L .69691 .6097 L F
.672 .722 .887 r
.70016 .61047 m .69783 .61117 L .69691 .6097 L F
.571 .868 .561 r
.70066 .5741 m .69971 .57517 L .70029 .57477 L F
.408 .805 .578 r
.69971 .57517 m .70043 .57466 L .70029 .57477 L F
.56 .229 .365 r
.62762 .61449 m .63008 .61504 L .63048 .6133 L F
.107 0 0 r
.63156 .61382 m .63048 .6133 L .63008 .61504 L F
.63156 .61382 m .63286 .61254 L .63048 .6133 L F
.435 .691 .972 r
.52243 .73056 m .52369 .73182 L .52113 .73199 L F
0 0 .234 r
.52243 .73056 m .52103 .73445 L .52113 .73199 L F
.946 .756 .614 r
.57225 .73474 m .5721 .73699 L .57166 .73659 L F
.438 0 0 r
.44547 .7249 m .44754 .72521 L .44878 .72444 L F
.318 0 0 r
.44754 .72521 m .45119 .72488 L .44878 .72444 L F
.641 .568 .756 r
.51895 .70979 m .51975 .71419 L .51669 .712 L F
.718 .679 .811 r
.38335 .79956 m .38689 .79984 L .38502 .79776 L F
.728 .59 .701 r
.38335 .79956 m .38548 .80036 L .38689 .79984 L F
.888 .984 .812 r
.57024 .67259 m .57163 .66953 L .57243 .66984 L F
.57024 .67259 m .56949 .67225 L .57163 .66953 L F
.408 0 .059 r
.62273 .61993 m .62498 .61979 L .62599 .61835 L F
.437 .297 .592 r
.62599 .61835 m .62762 .61449 L .62725 .61546 L F
.74 .558 .648 r
.62498 .61979 m .62832 .61752 L .62599 .61835 L F
0 0 .529 r
.31164 .74827 m .31223 .74899 L .31193 .74744 L F
.562 .451 .685 r
.40336 .79969 m .40231 .79676 L .40182 .79835 L F
.604 .915 .978 r
.40025 .80014 m .40336 .79969 L .40182 .79835 L F
.989 .725 .405 r
.65822 .61487 m .65918 .61557 L .65824 .61263 L F
.571 .903 .98 r
.6557 .6158 m .65918 .61557 L .65822 .61487 L F
.683 .621 .78 r
.65824 .61263 m .65918 .61557 L .66103 .6145 L F
.555 .402 .628 r
.398 .67484 m .39601 .67762 L .39591 .67525 L F
.557 .375 .591 r
.3013 .69687 m .30184 .69941 L .29961 .69949 L F
.567 .382 .59 r
.30401 .69896 m .3013 .69687 L .30503 .69739 L F
.30401 .69896 m .30184 .69941 L .3013 .69687 L F
.585 .363 .546 r
.6152 .63445 m .6178 .63416 L .61769 .63194 L F
.087 0 .161 r
.6178 .63416 m .62009 .63088 L .61769 .63194 L F
.794 .859 .898 r
.56055 .70922 m .56374 .70826 L .56288 .70706 L F
.537 .709 .951 r
.56288 .70706 m .56374 .70826 L .56551 .70785 L F
.474 .514 .818 r
.52879 .72023 m .52728 .72185 L .52605 .71884 L F
.555 .643 .892 r
.52879 .72023 m .52979 .72202 L .52728 .72185 L F
.462 .785 .999 r
.71705 .62382 m .71999 .62437 L .71909 .62354 L F
.28 .473 .87 r
.71999 .62437 m .72163 .62423 L .71909 .62354 L F
.71999 .62437 m .7227 .62566 L .72163 .62423 L F
.946 .708 .547 r
.58586 .6851 m .58709 .68325 L .58583 .68278 L F
.58586 .6851 m .58715 .68602 L .58709 .68325 L F
.737 .507 .58 r
.59252 .68577 m .59591 .68837 L .59602 .68601 L F
.638 .44 .598 r
.59602 .68601 m .59591 .68837 L .59813 .68577 L F
.08 0 0 r
.32961 .73255 m .32762 .73338 L .32561 .73369 L F
0 0 0 r
.32955 .7327 m .32961 .73255 L .3314 .73176 L F
.32955 .7327 m .32762 .73338 L .32961 .73255 L F
.484 .298 .552 r
.39033 .74014 m .39233 .73971 L .39241 .73734 L F
.496 .333 .59 r
.39033 .74014 m .3923 .74212 L .39233 .73971 L F
.509 .334 .579 r
.3903 .74252 m .3923 .74212 L .39033 .74014 L F
.487 .664 .941 r
.36318 .64976 m .36242 .65146 L .36119 .65046 L F
.36318 .64976 m .36463 .65141 L .36242 .65146 L F
.439 .323 .624 r
.28755 .63196 m .28769 .63421 L .28686 .63457 L F
.167 0 0 r
.35481 .71932 m .35447 .71831 L .35614 .71751 L F
.35481 .71932 m .35289 .71984 L .35447 .71831 L F
.558 .559 .81 r
.38947 .66298 m .38803 .66539 L .38658 .66182 L F
.629 .594 .796 r
.39089 .66601 m .38803 .66539 L .38947 .66298 L F
.956 .746 .579 r
.71628 .73399 m .71602 .73403 L .7171 .73336 L F
.71438 .73546 m .71553 .73663 L .71602 .73403 L F
.71438 .73546 m .71602 .73403 L .71628 .73399 L F
0 0 .498 r
.71602 .73403 m .71629 .73487 L .71587 .73406 L F
.71602 .73403 m .71587 .73406 L .71417 .73073 L F
.545 .832 .998 r
.71602 .73403 m .71856 .73435 L .71629 .73487 L F
.54 .421 .667 r
.3859 .74562 m .38815 .7476 L .38803 .74523 L F
.3859 .74562 m .38621 .74804 L .38815 .7476 L F
.455 .182 .409 r
.42469 .74519 m .42209 .74747 L .42253 .74553 L F
.607 .053 0 r
.58604 .74368 m .58894 .74561 L .58537 .7455 L F
.58604 .74368 m .5881 .74529 L .58894 .74561 L F
.502 .338 .59 r
.5881 .74529 m .58537 .7455 L .58894 .74561 L F
.71 .252 .162 r
.49058 .77491 m .4928 .77688 L .49385 .77567 L F
.738 .288 .183 r
.4928 .77688 m .49596 .77762 L .49385 .77567 L F
.742 .26 .098 r
.49385 .77567 m .49596 .77762 L .4975 .77764 L F
0 .067 .602 r
.43043 .75463 m .43056 .75645 L .43128 .75532 L F
.494 .823 1 r
.43128 .75532 m .43056 .75645 L .43261 .75602 L F
.597 .393 .576 r
.59183 .70766 m .59189 .71007 L .58952 .71023 L F
.52 .309 .534 r
.5942 .70735 m .59189 .71007 L .59183 .70766 L F
.349 .083 .362 r
.36532 .71212 m .36415 .71037 L .36615 .70989 L F
.36532 .71212 m .36356 .71279 L .36415 .71037 L F
.474 .289 .549 r
.37682 .81027 m .37455 .81295 L .37467 .8105 L F
.37682 .81027 m .37455 .81295 L .37467 .8105 L F
.769 .573 .633 r
.39674 .73656 m .40022 .73442 L .39857 .73424 L F
.549 .628 .883 r
.66916 .61893 m .67185 .62039 L .66964 .61797 L F
.787 .736 .806 r
.66964 .61797 m .67185 .62039 L .67355 .6181 L F
0 .062 .586 r
.73453 .71503 m .73491 .71822 L .73426 .71604 L F
.616 .545 .752 r
.72093 .59089 m .71961 .59463 L .71888 .59177 L F
.72093 .59089 m .72201 .59431 L .71961 .59463 L F
.701 .635 .78 r
.72201 .59431 m .72004 .59673 L .71961 .59463 L F
.03 0 .45 r
.72108 .73873 m .71964 .73742 L .7199 .73693 L F
.606 .559 .775 r
.72307 .7405 m .71964 .73742 L .71975 .73989 L F
.03 0 .45 r
.72108 .73873 m .71975 .73989 L .71964 .73742 L F
.086 0 0 r
.43485 .78646 m .43419 .78601 L .43627 .78562 L F
.43485 .78646 m .43232 .78694 L .43419 .78601 L F
.223 .745 .802 r
.49224 .72909 m .49119 .72913 L .489 .72954 L F
.204 .731 .823 r
.49436 .72886 m .49119 .72913 L .49224 .72909 L F
.686 .61 .766 r
.41084 .76963 m .4085 .77033 L .40711 .76721 L F
.705 .621 .76 r
.68052 .62213 m .68389 .624 L .68107 .62334 L F
.477 .194 .405 r
.59981 .70141 m .59628 .70445 L .59623 .70228 L F
.686 .688 .846 r
.6644 .58841 m .66293 .58886 L .66087 .58818 L F
.644 .478 .643 r
.58804 .71086 m .58729 .71331 L .58409 .71331 L F
.693 .523 .653 r
.58787 .71551 m .58409 .71331 L .58729 .71331 L F
.58787 .71551 m .58536 .71587 L .58409 .71331 L F
.398 .183 .466 r
.40643 .73342 m .40676 .73627 L .40855 .73545 L F
.345 0 0 r
.40643 .73342 m .40744 .73356 L .40552 .73339 L F
.40643 .73342 m .40552 .73339 L .40446 .73329 L F
.631 .231 .267 r
.40446 .73329 m .40511 .73335 L .40516 .73333 L F
.40446 .73329 m .40516 .73333 L .40823 .73211 L F
.345 0 0 r
.40572 .73336 m .40446 .73329 L .40461 .73326 L F
.40643 .73342 m .40446 .73329 L .40572 .73336 L F
.631 .231 .267 r
.40511 .73335 m .40572 .73336 L .40823 .73211 L F
.40572 .73336 m .40754 .73338 L .40771 .73307 L F
.40572 .73336 m .40771 .73307 L .40823 .73211 L F
.518 .265 .471 r
.40461 .73335 m .40552 .73339 L .40461 .73326 L F
.40552 .73339 m .40643 .73342 L .40572 .73336 L F
.40552 .73339 m .40572 .73336 L .40461 .73326 L F
.40447 .73652 m .40643 .73342 L .40461 .73335 L F
.508 .818 1 r
.40461 .73326 m .40572 .73336 L .4036 .73249 L F
.40572 .73336 m .40643 .73342 L .40627 .73337 L F
.40572 .73336 m .40627 .73337 L .4036 .73249 L F
.631 .231 .267 r
.40511 .73335 m .40744 .73356 L .40754 .73338 L F
.686 .376 .444 r
.40744 .73356 m .41112 .7315 L .40823 .73211 L F
.28 0 0 r
.44055 .78499 m .44206 .78418 L .4443 .78443 L F
.461 .237 .487 r
.31412 .68847 m .31401 .69057 L .31171 .69098 L F
.512 .143 .277 r
.31567 .6914 m .31171 .69098 L .31401 .69057 L F
.31567 .6914 m .31049 .69314 L .31171 .69098 L F
.445 .091 .269 r
.30052 .66932 m .3027 .66895 L .30375 .66685 L F
.369 .016 .229 r
.30375 .66685 m .30467 .66844 L .30568 .66611 L F
.30375 .66685 m .3027 .66895 L .30467 .66844 L F
.974 .677 .293 r
.72149 .7212 m .72176 .72346 L .72064 .72047 L F
.574 .436 .655 r
.72412 .71852 m .72149 .7212 L .72064 .72047 L F
.72412 .71852 m .72463 .72129 L .72149 .7212 L F
.785 .999 .828 r
.57485 .66753 m .57243 .66984 L .5731 .6682 L F
.758 .984 .906 r
.57243 .66984 m .57163 .66953 L .5731 .6682 L F
.433 .039 .189 r
.35534 .70416 m .3588 .70198 L .35663 .70232 L F
.597 .498 .713 r
.36862 .68023 m .37092 .67996 L .37047 .67757 L F
.511 .402 .667 r
.36862 .68023 m .37095 .68263 L .37092 .67996 L F
.36862 .68023 m .36908 .68403 L .37095 .68263 L F
.993 .761 .478 r
.64505 .64226 m .64384 .64391 L .64471 .645 L F
.64505 .64226 m .64399 .64152 L .64384 .64391 L F
.869 .846 .819 r
.64505 .64226 m .64585 .63858 L .64399 .64152 L F
.64505 .64226 m .64695 .63966 L .64585 .63858 L F
0 .334 .807 r
.57914 .73279 m .57661 .73161 L .57852 .7306 L F
.57914 .73279 m .58001 .73396 L .57661 .73161 L F
0 0 .198 r
.67435 .61741 m .67355 .6181 L .67389 .61618 L F
.67435 .61741 m .67389 .61618 L .67396 .61579 L F
.67435 .61741 m .67396 .61579 L .67326 .61481 L F
.859 .461 .285 r
.67435 .61741 m .67326 .61481 L .67144 .61428 L F
.67435 .61741 m .67144 .61428 L .67369 .61568 L F
.666 .339 0 r
.67369 .61568 m .67447 .61773 L .67435 .61741 L F
.58 .55 .785 r
.67812 .62036 m .67355 .6181 L .67618 .61962 L F
.983 .699 .379 r
.67355 .6181 m .6739 .62106 L .67278 .61942 L F
.428 0 0 r
.675 .61912 m .67355 .6181 L .67278 .61942 L F
.675 .61912 m .67618 .61962 L .67355 .6181 L F
.542 .399 .636 r
.675 .61912 m .67278 .61942 L .67435 .61741 L F
.666 .339 0 r
.67447 .61773 m .675 .61912 L .67435 .61741 L F
.588 .524 .751 r
.69844 .72063 m .69616 .72284 L .69642 .72115 L F
.69844 .72063 m .69951 .72454 L .69616 .72284 L F
.639 .494 .67 r
.69951 .72454 m .69716 .72817 L .69616 .72284 L F
.566 .871 .995 r
.43152 .7753 m .43223 .77605 L .4305 .77538 L F
.619 .201 .228 r
.47738 .77872 m .47605 .78038 L .47389 .77989 L F
.477 .042 .133 r
.47942 .77957 m .47605 .78038 L .47738 .77872 L F
.393 .188 .479 r
.28946 .62892 m .28922 .63128 L .28755 .63196 L F
.187 0 .322 r
.29175 .62626 m .29122 .62806 L .28946 .62892 L F
.388 .184 .477 r
.2913 .63044 m .28946 .62892 L .29122 .62806 L F
.2913 .63044 m .28922 .63128 L .28946 .62892 L F
.545 .377 .605 r
.64162 .60164 m .64359 .59881 L .6415 .59926 L F
.545 .438 .684 r
.38078 .76168 m .38247 .75891 L .38037 .75931 L F
.859 .984 .85 r
.67067 .61587 m .66916 .61893 L .66949 .6169 L F
.355 .536 .895 r
.66949 .6169 m .66916 .61893 L .66964 .61797 L F
.843 .39 0 r
.56401 .71501 m .56531 .71606 L .56328 .71317 L F
.685 .545 .689 r
.56328 .71317 m .56531 .71606 L .56748 .71289 L F
.564 .424 .649 r
.31602 .738 m .31873 .73708 L .31631 .73778 L F
.015 .589 .715 r
.46724 .77294 m .46942 .77291 L .47071 .77291 L F
.111 .664 .777 r
.47131 .77272 m .47071 .77291 L .46942 .77291 L F
.47131 .77272 m .47289 .77276 L .47071 .77291 L F
.734 .478 .541 r
.70522 .71239 m .70846 .70995 L .70478 .7105 L F
.70522 .71239 m .70726 .71253 L .70846 .70995 L F
.671 .406 .511 r
.70846 .70995 m .70726 .71253 L .71053 .71242 L F
.731 .403 .426 r
.70846 .70995 m .71053 .71242 L .71068 .71072 L F
.534 .557 .824 r
.72189 .58773 m .72109 .58853 L .7206 .58744 L F
.72189 .58773 m .72093 .59089 L .72109 .58853 L F
.348 0 .165 r
.60754 .63736 m .60488 .63906 L .60712 .63881 L F
.631 .284 .365 r
.60712 .63881 m .60967 .63907 L .60754 .63736 L F
.554 .319 .514 r
.60967 .63907 m .60976 .63698 L .60754 .63736 L F
.607 .607 .825 r
.53509 .72423 m .53415 .727 L .53301 .72407 L F
.53509 .72423 m .53641 .72672 L .53415 .727 L F
.599 .483 .693 r
.53641 .72672 m .5343 .7292 L .53415 .727 L F
.597 .443 .644 r
.30184 .69941 m .29963 .70191 L .29961 .69949 L F
.348 0 .009 r
.42626 .77581 m .42423 .77678 L .42472 .77663 L F
.191 .722 .813 r
.42536 .77643 m .42472 .77663 L .4237 .77683 L F
.128 0 0 r
.42845 .77558 m .42626 .77581 L .42472 .77663 L F
.191 .722 .813 r
.42571 .77635 m .42472 .77663 L .42536 .77643 L F
.348 0 .009 r
.42423 .77678 m .42284 .77745 L .42472 .77663 L F
.691 .249 .195 r
.5046 .78051 m .50837 .78177 L .50607 .78116 L F
.843 .888 .46 r
.72936 .62019 m .73021 .61821 L .72927 .61962 L F
.335 .096 .394 r
.73021 .61821 m .73242 .61553 L .73255 .6168 L F
0 0 0 r
.72927 .61962 m .73021 .61821 L .73255 .6168 L F
.745 .822 .912 r
.50336 .71427 m .49951 .71475 L .50192 .71326 L F
.702 .841 .95 r
.50539 .7132 m .50336 .71427 L .50192 .71326 L F
.564 .026 0 r
.42811 .74563 m .42724 .74577 L .42469 .74519 L F
.375 0 .041 r
.43026 .74486 m .42724 .74577 L .42811 .74563 L F
.719 .6 .723 r
.58717 .68795 m .59034 .68853 L .59033 .68633 L F
.731 .545 .64 r
.58717 .68795 m .58829 .6913 L .59034 .68853 L F
.714 .521 .628 r
.59034 .68853 m .58829 .6913 L .5907 .69106 L F
.713 .595 .723 r
.59033 .68633 m .59034 .68853 L .59252 .68577 L F
.618 .71 .911 r
.5907 .69106 m .59435 .69063 L .59043 .68915 L F
.633 .43 .59 r
.59435 .69063 m .59434 .69059 L .59282 .6906 L F
.59464 .69166 m .59602 .69058 L .59434 .69059 L F
.618 .71 .911 r
.59435 .69063 m .5944 .69063 L .59434 .6906 L F
.59435 .69063 m .59282 .6906 L .59486 .69057 L F
.5907 .69106 m .59282 .6906 L .59435 .69063 L F
.633 .43 .59 r
.59464 .69166 m .59435 .69063 L .59282 .6906 L F
.59288 .69304 m .59464 .69166 L .59282 .6906 L F
.618 .71 .911 r
.59435 .69063 m .59434 .6906 L .59043 .68915 L F
.654 .418 .55 r
.59434 .69059 m .59437 .69059 L .59348 .69013 L F
.59437 .69059 m .59602 .69058 L .59351 .69014 L F
.59437 .69059 m .59351 .69014 L .59348 .69013 L F
.59348 .69013 m .59602 .69058 L .59591 .68837 L F
.59348 .69013 m .59591 .68837 L .59486 .69057 L F
.615 .457 .644 r
.59038 .68848 m .59486 .69057 L .59252 .68577 L F
.59034 .68853 m .59134 .68898 L .59038 .68848 L F
.59134 .68898 m .59486 .69057 L .59038 .68848 L F
.618 .71 .911 r
.5944 .69063 m .59486 .69057 L .59348 .69013 L F
.5944 .69063 m .59348 .69013 L .59043 .68915 L F
.654 .418 .55 r
.59282 .6906 m .59434 .69059 L .59348 .69013 L F
.59282 .6906 m .59348 .69013 L .59486 .69057 L F
.618 .71 .911 r
.59043 .68915 m .59486 .69057 L .59034 .68853 L F
.874 .807 .323 r
.66943 .60175 m .6688 .60324 L .66881 .60108 L F
.66943 .60175 m .66882 .60475 L .6688 .60324 L F
.745 .724 .832 r
.70623 .61036 m .70346 .61225 L .70254 .60993 L F
.499 .06 .136 r
.34484 .6744 m .34321 .67615 L .34158 .67513 L F
.275 0 0 r
.34559 .67552 m .34484 .6744 L .34694 .6741 L F
.34559 .67552 m .34321 .67615 L .34484 .6744 L F
.889 .747 .699 r
.68855 .57632 m .69028 .57426 L .68909 .57494 L F
.636 .958 .788 r
.68969 .5749 m .68909 .57494 L .69098 .57343 L F
.889 .747 .699 r
.69028 .57426 m .69098 .57343 L .68909 .57494 L F
.813 .956 .908 r
.68969 .5749 m .688 .57556 L .68909 .57494 L F
.688 .57556 m .68633 .57621 L .68909 .57494 L F
.622 .939 .722 r
.68969 .5749 m .69098 .57343 L .69192 .57302 L F
0 0 .159 r
.70025 .57141 m .70066 .5741 L .70029 .57477 L F
.745 .3 .194 r
.49596 .77762 m .49965 .77971 L .4975 .77764 L F
.354 .397 .767 r
.72927 .60612 m .72757 .60774 L .72679 .6043 L F
.378 .436 .794 r
.72927 .60612 m .73031 .60926 L .72757 .60774 L F
.701 .635 .78 r
.72201 .59431 m .72247 .596 L .72004 .59673 L F
.276 .403 .811 r
.57921 .70229 m .58177 .70422 L .58055 .70118 L F
.545 .408 .646 r
.57959 .70465 m .58177 .70422 L .57921 .70229 L F
.562 .935 .836 r
.61963 .66293 m .61965 .66332 L .61888 .66386 L F
.209 .146 .563 r
.6183 .66638 m .61963 .66293 L .61888 .66386 L F
0 0 0 r
.36007 .80708 m .36095 .80657 L .35868 .80548 L F
.903 .816 .752 r
.64252 .6536 m .6441 .65056 L .64303 .6493 L F
.878 .817 .785 r
.6441 .65056 m .64465 .64673 L .64303 .6493 L F
.78 .772 .845 r
.29545 .60623 m .29879 .60639 L .29667 .60791 L F
.29545 .60623 m .29879 .60639 L .29667 .60791 L F
.433 .871 .898 r
.37783 .80284 m .37575 .80338 L .37799 .80094 L F
0 0 .468 r
.37799 .80094 m .37823 .80245 L .37783 .80284 L F
.433 .871 .898 r
.37783 .80284 m .37575 .80338 L .37823 .80245 L F
.388 .255 .576 r
.28922 .63128 m .28769 .63421 L .28755 .63196 L F
.901 .979 .8 r
.58275 .69387 m .58121 .69689 L .58298 .69613 L F
.58275 .69387 m .58079 .69731 L .58121 .69689 L F
.724 .489 .57 r
.58065 .69866 m .58298 .69613 L .58121 .69689 L F
.219 0 0 r
.53249 .78564 m .53199 .78612 L .52971 .7863 L F
0 0 0 r
.53393 .78531 m .53199 .78612 L .53249 .78564 L F
.66781 .59607 m .66828 .59354 L .66514 .59622 L F
.797 .654 .705 r
.66556 .59741 m .66781 .59607 L .66514 .59622 L F
.66556 .59741 m .66679 .5993 L .66781 .59607 L F
0 .522 .846 r
.36765 .8019 m .36779 .80148 L .36556 .80238 L F
.36765 .8019 m .36895 .80214 L .36779 .80148 L F
.659 .492 .647 r
.53571 .73463 m .53644 .73782 L .53334 .7373 L F
.53334 .7373 m .53644 .73782 L .53571 .73463 L F
0 0 .535 r
.53571 .73463 m .53629 .73368 L .53481 .731 L F
.335 .281 .647 r
.5375 .73669 m .53571 .73463 L .53773 .73414 L F
.53571 .73463 m .5375 .73669 L .53629 .73368 L F
.53571 .73463 m .53644 .73782 L .5375 .73669 L F
.5375 .73669 m .53644 .73782 L .53571 .73463 L F
.681 .136 0 r
.499 .78272 m .49973 .78431 L .4975 .78238 L F
.499 .78272 m .50063 .78385 L .49973 .78431 L F
0 0 .245 r
.54832 .71216 m .54859 .70922 L .54902 .71009 L F
.54832 .71216 m .54865 .71144 L .54859 .70922 L F
0 0 .369 r
.54859 .70922 m .54865 .71144 L .54955 .71033 L F
.54859 .70922 m .54955 .71033 L .54797 .709 L F
.54859 .70922 m .54797 .709 L .5473 .70844 L F
.966 .903 .541 r
.54921 .70944 m .54859 .70922 L .54972 .7077 L F
.54902 .71009 m .54859 .70922 L .54921 .70944 L F
.942 .638 .435 r
.54972 .7077 m .54859 .70922 L .54825 .70695 L F
.54972 .7077 m .54859 .70922 L .54825 .70695 L F
.331 0 .203 r
.31338 .66078 m .31508 .66088 L .3161 .65892 L F
.372 .016 .225 r
.3161 .65892 m .31715 .66038 L .31791 .65823 L F
.3161 .65892 m .31508 .66088 L .31715 .66038 L F
.643 .47 .634 r
.46159 .77087 m .4637 .76961 L .46155 .76967 L F
.546 .363 .585 r
.55727 .70485 m .55496 .70798 L .55727 .70745 L F
.77 .675 .758 r
.71415 .58754 m .71571 .59099 L .71191 .59078 L F
.763 .702 .794 r
.71571 .59099 m .71168 .59361 L .71191 .59078 L F
.319 .29 .669 r
.41268 .77178 m .41108 .7728 L .41084 .76963 L F
.473 .378 .667 r
.41315 .77477 m .41108 .7728 L .41268 .77178 L F
.41315 .77477 m .4115 .77522 L .41108 .7728 L F
.886 .723 .673 r
.69999 .62801 m .70155 .62908 L .70045 .62595 L F
.878 .731 .696 r
.70079 .63113 m .70155 .62908 L .69999 .62801 L F
.716 .643 .775 r
.70045 .62595 m .70155 .62908 L .70341 .628 L F
.569 .549 .793 r
.6912 .60756 m .69365 .6071 L .69243 .6039 L F
.417 .202 .478 r
.30054 .61285 m .30016 .61528 L .2984 .61577 L F
.512 .494 .773 r
.29957 .61043 m .30247 .61222 L .30054 .61285 L F
.41 .201 .482 r
.30247 .61222 m .30016 .61528 L .30054 .61285 L F
.889 .85 .798 r
.466 .76937 m .4675 .77019 L .46943 .76713 L F
.595 .444 .646 r
.37853 .77789 m .37648 .78064 L .37875 .78033 L F
.521 .438 .703 r
.37648 .78064 m .37907 .78312 L .37875 .78033 L F
.37648 .78064 m .37718 .78363 L .37907 .78312 L F
0 0 0 r
.53333 .74458 m .53531 .74238 L .53234 .74561 L F
.5 .591 .877 r
.53234 .74561 m .53498 .74564 L .53333 .74458 L F
.202 .044 .431 r
.2995 .61707 m .2984 .61577 L .30016 .61528 L F
.2995 .61707 m .29768 .61854 L .2984 .61577 L F
.728 .59 .701 r
.38335 .79956 m .38451 .80288 L .38548 .80036 L F
.226 0 0 r
.41201 .79125 m .40851 .79324 L .40989 .79153 L F
.522 .299 .516 r
.60887 .68312 m .61102 .68271 L .61123 .68049 L F
.436 .24 .515 r
.61123 .68049 m .61311 .67984 L .61327 .67768 L F
.275 .04 .365 r
.61102 .68271 m .61311 .67984 L .61123 .68049 L F
.566 .364 .567 r
.39241 .73734 m .39452 .73936 L .39455 .73699 L F
.39241 .73734 m .39233 .73971 L .39452 .73936 L F
.766 .586 .654 r
.62582 .64753 m .62484 .65056 L .62263 .64739 L F
.398 .183 .466 r
.40643 .73342 m .40855 .73545 L .41001 .7339 L F
.111 0 0 r
.40643 .73342 m .41001 .7339 L .40744 .73356 L F
.686 .376 .444 r
.40744 .73356 m .41001 .7339 L .41112 .7315 L F
.583 .272 .407 r
.41001 .7339 m .4133 .73148 L .41112 .7315 L F
.546 .363 .585 r
.55727 .70485 m .55722 .70541 L .55425 .70329 L F
.55727 .70485 m .55727 .70745 L .55722 .70541 L F
.205 .68 .936 r
.55939 .70482 m .55865 .70441 L .55727 .70485 L F
.692 .644 .798 r
.55727 .70745 m .55939 .70482 L .55727 .70485 L F
.658 .57 .744 r
.53641 .72672 m .53733 .72932 L .5343 .7292 L F
.848 .998 .784 r
.466 .76937 m .4651 .77108 L .4675 .77019 L F
.348 .335 .703 r
.35041 .64797 m .35226 .64969 L .35038 .64812 L F
.62 .654 .862 r
.70786 .7298 m .70637 .72907 L .70759 .729 L F
.577 .488 .717 r
.70599 .73126 m .70748 .72866 L .70537 .73069 L F
.375 .447 .808 r
.70773 .72773 m .70799 .72898 L .70637 .72907 L F
.577 .488 .717 r
.70748 .72866 m .70766 .72834 L .70745 .72856 L F
.70748 .72866 m .70745 .72856 L .70537 .73069 L F
.62 .654 .862 r
.70985 .73077 m .70786 .7298 L .70799 .72898 L F
.70786 .7298 m .70759 .729 L .70799 .72898 L F
0 .536 .837 r
.70799 .72898 m .71235 .73025 L .70985 .73077 L F
0 .155 .674 r
.54028 .73922 m .54 .74016 L .53888 .73724 L F
0 0 .035 r
.54028 .73922 m .53981 .74151 L .54 .74016 L F
.636 .319 .418 r
.71068 .71072 m .71444 .71138 L .71377 .71013 L F
.71068 .71072 m .71053 .71242 L .71444 .71138 L F
.279 0 0 r
.43577 .7753 m .43961 .77545 L .43986 .77478 L F
.324 0 0 r
.44016 .77537 m .43986 .77478 L .43961 .77545 L F
.44016 .77537 m .44243 .77533 L .43986 .77478 L F
.709 .498 .601 r
.43986 .77478 m .44243 .77533 L .44294 .77526 L F
.28 .309 .713 r
.52078 .71148 m .51975 .71419 L .51895 .70979 L F
.574 .64 .878 r
.52078 .71148 m .52201 .71368 L .51975 .71419 L F
.563 .52 .765 r
.73372 .61178 m .73242 .61553 L .73159 .6129 L F
.73372 .61178 m .73441 .61498 L .73242 .61553 L F
.219 0 0 r
.73242 .61553 m .73354 .61628 L .73255 .6168 L F
.73242 .61553 m .73441 .61498 L .73354 .61628 L F
.63 .359 .49 r
.71444 .71138 m .71614 .71206 L .71377 .71013 L F
.491 .383 .659 r
.61986 .62894 m .62182 .62843 L .62187 .62601 L F
.323 .185 .534 r
.62009 .63088 m .62182 .62843 L .61986 .62894 L F
.559 .177 .274 r
.71614 .71206 m .71842 .71232 L .71929 .71025 L F
.571 .189 .279 r
.71929 .71025 m .71842 .71232 L .72164 .71136 L F
.574 .171 .241 r
.72164 .71136 m .72173 .71047 L .71929 .71025 L F
.737 .507 .58 r
.59252 .68577 m .59486 .69057 L .59591 .68837 L F
.943 .646 .446 r
.65473 .61232 m .65488 .61446 L .65576 .61243 L F
.744 .38 .363 r
.65488 .61446 m .65822 .61487 L .65576 .61243 L F
.646 .41 .546 r
.65822 .61487 m .65824 .61263 L .65576 .61243 L F
.561 .318 .506 r
.31627 .68827 m .31401 .69057 L .31412 .68847 L F
.256 0 .261 r
.61327 .67768 m .61503 .67692 L .6157 .67509 L F
.214 .103 .504 r
.6157 .67509 m .61748 .67438 L .61736 .67162 L F
.088 0 .182 r
.61503 .67692 m .61748 .67438 L .6157 .67509 L F
.657 .242 .246 r
.69475 .60347 m .69808 .6039 L .69563 .60214 L F
.727 .691 .816 r
.68852 .63458 m .69149 .63633 L .69048 .6337 L F
.759 .699 .795 r
.69048 .6337 m .69149 .63633 L .69375 .63412 L F
.618 .741 .934 r
.37428 .80172 m .37575 .80338 L .37242 .80246 L F
.37428 .80172 m .37575 .80338 L .37242 .80246 L F
.816 .792 .83 r
.37799 .80094 m .37575 .80338 L .37428 .80172 L F
.653 .753 .924 r
.37428 .80172 m .37575 .80338 L .37823 .80245 L F
.719 .6 .723 r
.58717 .68795 m .59033 .68633 L .58715 .68602 L F
.347 .189 .52 r
.37812 .77553 m .37973 .77498 L .37994 .77243 L F
.43 .374 .695 r
.37853 .77789 m .37973 .77498 L .37812 .77553 L F
.256 .353 .771 r
.68686 .71508 m .68585 .71186 L .68621 .71289 L F
.477 .233 .465 r
.70342 .71276 m .70522 .71239 L .70478 .7105 L F
.812 .732 .776 r
.68226 .57838 m .67954 .58217 L .67858 .57902 L F
.68226 .57838 m .67858 .57902 L .68002 .57891 L F
.582 .944 .843 r
.68422 .57718 m .68226 .57838 L .68002 .57891 L F
.498 .379 .648 r
.38225 .7564 m .38417 .75633 L .384 .75313 L F
.551 .386 .61 r
.38225 .7564 m .38451 .75852 L .38417 .75633 L F
.38225 .7564 m .38247 .75891 L .38451 .75852 L F
.248 0 0 r
.46803 .73533 m .46882 .73614 L .46689 .73646 L F
.46803 .73533 m .47011 .73494 L .46882 .73614 L F
.749 .62 .716 r
.5168 .72615 m .51792 .72948 L .51952 .72758 L F
.5168 .72615 m .51952 .72758 L .51874 .72815 L F
.53 0 0 r
.51952 .72758 m .52208 .72858 L .51874 .72815 L F
.545 .438 .684 r
.38078 .76168 m .3828 .76132 L .38247 .75891 L F
.403 .202 .491 r
.38083 .76404 m .3828 .76132 L .38078 .76168 L F
.546 .29 .478 r
.40925 .75099 m .40929 .75314 L .40689 .75326 L F
.662 .38 .483 r
.41148 .75295 m .40929 .75314 L .40925 .75099 L F
.913 .927 .808 r
.54134 .76647 m .54048 .76984 L .54306 .7675 L F
.852 .851 .841 r
.54134 .76647 m .54306 .7675 L .54262 .76509 L F
.54262 .76509 m .54306 .7675 L .54134 .76647 L F
.081 .628 .837 r
.2828 .60143 m .28098 .60136 L .27932 .60101 L F
.137 0 0 r
.35287 .67249 m .35134 .67332 L .34906 .67365 L F
.76 .782 .871 r
.51123 .71127 m .50729 .71181 L .50973 .71046 L F
.59 .83 .99 r
.51328 .71068 m .51123 .71127 L .50973 .71046 L F
.623 .394 .548 r
.44139 .74277 m .44129 .74501 L .43917 .74488 L F
.499 .2 .389 r
.44388 .74299 m .44129 .74501 L .44139 .74277 L F
.672 .814 .951 r
.35041 .64797 m .3468 .6477 L .34861 .64682 L F
.477 .755 .991 r
.35091 .64666 m .35041 .64797 L .34868 .64687 L F
.066 .272 .762 r
.35091 .64666 m .35226 .64969 L .35041 .64797 L F
.644 .63 .821 r
.35445 .64875 m .35226 .64969 L .35091 .64666 L F
.35445 .64875 m .35091 .64666 L .35328 .64625 L F
.477 .755 .991 r
.35091 .64666 m .34868 .64687 L .34861 .64682 L F
.626 .845 .46 r
.34903 .6493 m .35091 .64666 L .34861 .64682 L F
.34976 .64828 m .34945 .64856 L .35091 .64666 L F
.34903 .6493 m .34945 .64856 L .34976 .64828 L F
.517 .355 .599 r
.3468 .6477 m .34903 .6493 L .34861 .64682 L F
.561 .838 .496 r
.34506 .64969 m .34528 .64938 L .3468 .6477 L F
.34455 .65027 m .34528 .64938 L .34506 .64969 L F
.407 .859 .868 r
.34528 .64938 m .3451 .6489 L .34555 .64899 L F
.659 .261 .281 r
.3468 .6477 m .34528 .64938 L .34903 .6493 L F
0 0 0 r
.34528 .64938 m .34747 .64934 L .34903 .6493 L F
.407 .859 .868 r
.34528 .64938 m .34555 .64899 L .34747 .64934 L F
.636 .907 .983 r
.34747 .64934 m .34752 .64816 L .34945 .64856 L F
.535 0 0 r
.34752 .64816 m .34924 .64877 L .34945 .64856 L F
.34924 .64877 m .35129 .64949 L .34945 .64856 L F
.494 .102 .226 r
.34945 .64856 m .35291 .64648 L .35091 .64666 L F
.35291 .64648 m .35328 .64625 L .35091 .64666 L F
.606 .559 .775 r
.72307 .7405 m .71975 .73989 L .72296 .73794 L F
.636 .774 .947 r
.71975 .73989 m .72307 .7405 L .72296 .73794 L F
.693 .525 .654 r
.58484 .69106 m .58829 .6913 L .58717 .68795 L F
.522 .911 .928 r
.53481 .731 m .53304 .7309 L .53269 .73156 L F
.813 .346 .111 r
.53481 .731 m .53466 .7331 L .53304 .7309 L F
.53481 .731 m .53629 .73368 L .53466 .7331 L F
.192 0 .282 r
.37286 .70421 m .37072 .70698 L .37139 .705 L F
.66 .408 .528 r
.29575 .67173 m .29826 .67184 L .29865 .66972 L F
.466 .231 .473 r
.29865 .66972 m .29826 .67184 L .30052 .66932 L F
.485 .194 .396 r
.34878 .7074 m .3509 .70704 L .35137 .70518 L F
.436 .15 .378 r
.35137 .70518 m .3529 .70654 L .35357 .70473 L F
.35137 .70518 m .3509 .70704 L .3529 .70654 L F
.669 .436 .559 r
.48461 .73404 m .48445 .73698 L .48223 .73596 L F
.819 .778 .814 r
.48608 .73101 m .48461 .73404 L .48377 .7327 L F
.675 .441 .56 r
.48658 .7363 m .48461 .73404 L .48739 .73415 L F
.48658 .7363 m .48445 .73698 L .48461 .73404 L F
.034 0 0 r
.44294 .77526 m .4432 .7755 L .44507 .77489 L F
.44294 .77526 m .44243 .77533 L .4432 .7755 L F
.764 .706 .798 r
.68143 .5886 m .67901 .58869 L .68063 .58614 L F
.567 .489 .727 r
.68129 .59061 m .67901 .58869 L .68143 .5886 L F
.519 .436 .702 r
.68274 .58549 m .68143 .5886 L .68063 .58614 L F
.68274 .58549 m .68375 .58794 L .68143 .5886 L F
.428 .193 .453 r
.68375 .58794 m .68129 .59061 L .68143 .5886 L F
.46 .25 .507 r
.32081 .68315 m .32079 .68546 L .31894 .68584 L F
.513 .198 .37 r
.32408 .68281 m .32079 .68546 L .32081 .68315 L F
.131 0 0 r
.6942 .57267 m .69675 .57221 L .69739 .57171 L F
.377 0 0 r
.69675 .57221 m .70025 .57141 L .69739 .57171 L F
.591 .423 .622 r
.58945 .71259 m .58804 .71086 L .58952 .71023 L F
.504 .26 .478 r
.59189 .71007 m .58945 .71259 L .58952 .71023 L F
0 0 0 r
.67654 .58014 m .67411 .58317 L .67598 .58169 L F
0 0 .41 r
.67411 .58317 m .67527 .58353 L .67598 .58169 L F
0 0 0 r
.67527 .58353 m .67401 .5852 L .67634 .58259 L F
.67527 .58353 m .67634 .58259 L .67674 .58215 L F
0 0 .41 r
.67411 .58317 m .67429 .58438 L .67527 .58353 L F
.67429 .58438 m .6744 .5851 L .67527 .58353 L F
.321 0 0 r
.29707 .6066 m .29879 .60639 L .29545 .60623 L F
.046 0 0 r
.29909 .60652 m .29879 .60639 L .29707 .6066 L F
.29909 .60652 m .30084 .60638 L .29879 .60639 L F
.451 .122 .315 r
.44921 .7404 m .45127 .74023 L .44841 .74196 L F
.262 .519 .908 r
.29282 .60526 m .28954 .60286 L .29214 .60337 L F
.428 .515 .845 r
.29384 .60335 m .29282 .60526 L .29214 .60337 L F
.439 .529 .852 r
.29384 .60335 m .29545 .60623 L .29282 .60526 L F
.221 .145 .554 r
.58869 .72313 m .58892 .72567 L .58727 .72666 L F
.339 0 .154 r
.58727 .72666 m .58928 .72726 L .58892 .72567 L F
.059 .372 .839 r
.58928 .72726 m .59021 .72893 L .58727 .72666 L F
.565 .47 .706 r
.58727 .72666 m .59021 .72893 L .588 .72939 L F
.339 0 .154 r
.58727 .72666 m .58672 .72809 L .58928 .72726 L F
.059 .372 .839 r
.58928 .72726 m .58727 .72666 L .58672 .72809 L F
.715 .571 .692 r
.66087 .58818 m .66249 .59078 L .6644 .58841 L F
.784 .549 .581 r
.68682 .61283 m .68709 .61489 L .68403 .61448 L F
.662 .648 .825 r
.68919 .61254 m .68682 .61283 L .68581 .61073 L F
.639 .447 .606 r
.68919 .61254 m .68709 .61489 L .68682 .61283 L F
.325 0 0 r
.33069 .71172 m .33274 .71273 L .33343 .71303 L F
.93 .962 .661 r
.33274 .71273 m .33182 .71451 L .33343 .71303 L F
.751 .949 .63 r
.33343 .71303 m .33364 .7123 L .33557 .7127 L F
.33343 .71303 m .33182 .71451 L .33364 .7123 L F
.68 .451 .568 r
.62762 .61449 m .62832 .61752 L .63051 .61745 L F
.292 .79 .823 r
.33358 .65061 m .33562 .65008 L .33679 .64996 L F
.401 .856 .868 r
.33679 .64996 m .33802 .64927 L .33953 .64802 L F
.33679 .64996 m .33562 .65008 L .33802 .64927 L F
.996 .849 .576 r
.64802 .63099 m .64763 .62866 L .6471 .63025 L F
.928 .864 .756 r
.64641 .63432 m .64802 .63099 L .6471 .63025 L F
.811 .568 .571 r
.5721 .73699 m .57061 .73902 L .57166 .73659 L F
.5721 .73699 m .5734 .73969 L .57061 .73902 L F
.648 .629 .817 r
.57434 .73648 m .5734 .73969 L .5721 .73699 L F
.094 0 0 r
.4432 .7755 m .44243 .77533 L .44016 .77537 L F
.422 0 0 r
.4624 .73682 m .45871 .73728 L .46111 .73664 L F
.656 .354 .449 r
.53334 .7373 m .53585 .73893 L .53644 .73782 L F
.53334 .7373 m .53585 .73893 L .53644 .73782 L F
.84 .468 0 r
.5111 .78216 m .51173 .78298 L .51119 .78142 L F
.136 0 0 r
.33953 .72712 m .33794 .72877 L .33656 .72869 L F
.142 0 0 r
.33988 .72813 m .33953 .72712 L .34133 .72628 L F
.33988 .72813 m .33794 .72877 L .33953 .72712 L F
.712 .442 .515 r
.71684 .71575 m .71726 .71803 L .71517 .71552 L F
.73 .454 .51 r
.7206 .71802 m .71726 .71803 L .71684 .71575 L F
.75 .588 .676 r
.58177 .73734 m .58254 .74122 L .57919 .73984 L F
.228 .376 .805 r
.58041 .73529 m .58268 .73692 L .58177 .73734 L F
.479 .407 .698 r
.58441 .73979 m .58177 .73734 L .58268 .73692 L F
.58441 .73979 m .58254 .74122 L .58177 .73734 L F
.438 .782 .998 r
.28954 .60286 m .28634 .60241 L .28826 .60204 L F
.303 .659 .972 r
.2904 .60206 m .28954 .60286 L .28826 .60204 L F
.2904 .60206 m .29214 .60337 L .28954 .60286 L F
.681 .431 .537 r
.61303 .6365 m .61512 .63658 L .6152 .63445 L F
.586 .355 .533 r
.61512 .63658 m .6178 .63416 L .6152 .63445 L F
.727 .775 .891 r
.58604 .74368 m .58537 .7455 L .58232 .74491 L F
.807 .649 .686 r
.58537 .7455 m .58324 .74763 L .58232 .74491 L F
.702 .478 .581 r
.58537 .7455 m .58567 .74777 L .58324 .74763 L F
.502 .338 .59 r
.5881 .74529 m .58567 .74777 L .58537 .7455 L F
.686 .61 .766 r
.41084 .76963 m .40711 .76721 L .40946 .76669 L F
.341 .272 .632 r
.41208 .76635 m .41084 .76963 L .40946 .76669 L F
.41208 .76635 m .41216 .7695 L .41084 .76963 L F
.344 .297 .661 r
.41216 .7695 m .41268 .77178 L .41084 .76963 L F
.19 .357 .801 r
.56687 .71055 m .56815 .71008 L .56551 .70785 L F
.481 .429 .722 r
.56687 .71055 m .56911 .7123 L .56815 .71008 L F
.56687 .71055 m .56748 .71289 L .56911 .7123 L F
.457 .147 .349 r
.31045 .66374 m .31253 .66338 L .31338 .66078 L F
.469 .201 .424 r
.31253 .66338 m .31508 .66088 L .31338 .66078 L F
.591 .423 .622 r
.58945 .71259 m .58729 .71331 L .58804 .71086 L F
0 0 .483 r
.71172 .61992 m .71126 .61941 L .71248 .61729 L F
.769 .573 .633 r
.39674 .73656 m .40014 .7372 L .40022 .73442 L F
.493 .802 .999 r
.40022 .73442 m .40254 .73417 L .40093 .73333 L F
.40093 .73333 m .40254 .73417 L .40022 .73442 L F
.52 .328 .56 r
.40014 .7372 m .40254 .73417 L .40022 .73442 L F
.55 .366 .585 r
.60672 .68585 m .60893 .68546 L .60887 .68312 L F
.564 .371 .578 r
.60671 .68812 m .60893 .68546 L .60672 .68585 L F
.688 .42 .511 r
.60695 .69908 m .60387 .70142 L .60377 .69947 L F
.60695 .69908 m .60633 .7019 L .60387 .70142 L F
.566 .303 .477 r
.60973 .69965 m .60695 .69908 L .60916 .69896 L F
.60973 .69965 m .60633 .7019 L .60695 .69908 L F
.555 .822 .996 r
.53788 .75011 m .53919 .75099 L .54125 .75043 L F
.53788 .75011 m .53919 .75099 L .54125 .75043 L F
.481 .405 .694 r
.37756 .78604 m .37907 .78312 L .37718 .78363 L F
.37756 .78604 m .37935 .78581 L .37907 .78312 L F
.647 .606 .793 r
.37776 .78846 m .37935 .78581 L .37756 .78604 L F
.874 .509 .353 r
.55883 .72364 m .55722 .72327 L .55579 .72065 L F
.897 .594 .465 r
.55883 .72364 m .55751 .72549 L .55722 .72327 L F
.04 0 0 r
.56121 .72567 m .55751 .72549 L .55883 .72364 L F
.626 .589 .792 r
.7242 .59366 m .72247 .596 L .72201 .59431 L F
.591 .539 .766 r
.7242 .59366 m .72469 .59559 L .72247 .596 L F
.5 .487 .774 r
.72559 .5989 m .72247 .596 L .72469 .59559 L F
.913 .927 .808 r
.54134 .76647 m .53941 .76935 L .54048 .76984 L F
.342 .282 .644 r
.69301 .70933 m .69157 .71299 L .69193 .71184 L F
.69301 .70933 m .69349 .71227 L .69157 .71299 L F
.362 .335 .694 r
.69349 .71227 m .69384 .71513 L .69157 .71299 L F
.499 .038 .09 r
.72164 .71136 m .72491 .71016 L .72173 .71047 L F
.72164 .71136 m .72392 .71155 L .72491 .71016 L F
0 .229 .664 r
.72645 .71098 m .7274 .71169 L .72491 .71016 L F
.72645 .71098 m .72491 .71016 L .72392 .71155 L F
.712 .545 .661 r
.59813 .68577 m .59591 .68837 L .59861 .68808 L F
.375 .089 .345 r
.37717 .70108 m .37599 .6999 L .37772 .69915 L F
.37717 .70108 m .37527 .70165 L .37599 .6999 L F
.262 .767 .865 r
.33598 .6505 m .33643 .65047 L .33802 .64927 L F
.981 .815 .603 r
.33802 .64927 m .33908 .6504 L .3395 .64816 L F
.262 .767 .865 r
.33643 .65047 m .33981 .65026 L .33802 .64927 L F
.981 .815 .603 r
.33802 .64927 m .3395 .64816 L .33953 .64802 L F
.589 .367 .547 r
.71517 .71552 m .71528 .71769 L .71242 .71786 L F
.686 .442 .547 r
.71517 .71552 m .71726 .71803 L .71528 .71769 L F
.793 .678 .737 r
.58254 .74122 m .58266 .74288 L .57893 .74211 L F
.731 .59 .698 r
.58232 .74491 m .57893 .74211 L .58266 .74288 L F
.539 .484 .743 r
.58473 .74222 m .58266 .74288 L .58254 .74122 L F
.727 .775 .891 r
.58604 .74368 m .58266 .74288 L .58473 .74222 L F
.58604 .74368 m .58402 .74435 L .58349 .74375 L F
.58403 .74321 m .58349 .74375 L .58275 .74291 L F
.58604 .74368 m .58349 .74375 L .58403 .74321 L F
.58275 .74291 m .58232 .74491 L .58266 .74288 L F
.58402 .74435 m .58232 .74491 L .58275 .74291 L F
.731 .59 .698 r
.58232 .74491 m .58114 .74628 L .57893 .74211 L F
.893 .974 .821 r
.58354 .74177 m .58135 .74588 L .58232 .74491 L F
.58135 .74588 m .58114 .74628 L .58232 .74491 L F
.038 .224 .726 r
.58419 .74372 m .58567 .74777 L .5881 .74529 L F
.58419 .74372 m .58653 .74659 L .58629 .74693 L F
.5847 .74512 m .58629 .74693 L .58567 .74777 L F
.58419 .74372 m .58629 .74693 L .5847 .74512 L F
.603 .857 .992 r
.48985 .71895 m .48625 .71892 L .48854 .71844 L F
.595 .886 .991 r
.48985 .71895 m .4908 .71764 L .49203 .71824 L F
.48985 .71895 m .48854 .71844 L .4908 .71764 L F
.704 .656 .8 r
.57941 .69328 m .58079 .69731 L .58275 .69387 L F
.574 .829 .463 r
.67026 .58872 m .66837 .59109 L .66933 .58983 L F
0 0 .232 r
.66837 .59109 m .66902 .59193 L .66933 .58983 L F
.66837 .59109 m .66828 .59311 L .66902 .59193 L F
.087 0 .161 r
.6178 .63416 m .61923 .63332 L .62009 .63088 L F
.323 .185 .534 r
.62009 .63088 m .62196 .63084 L .62182 .62843 L F
.286 0 .253 r
.62009 .63088 m .61923 .63332 L .62196 .63084 L F
.364 .728 .988 r
.68164 .60913 m .68043 .6098 L .67885 .60656 L F
.68164 .60913 m .68245 .60965 L .68043 .6098 L F
.705 .396 .451 r
.43572 .74566 m .43563 .74745 L .43377 .7451 L F
0 .13 .677 r
.43377 .7451 m .43563 .74745 L .43581 .7468 L F
.43377 .7451 m .43581 .7468 L .43238 .74468 L F
0 .139 .585 r
.58177 .73625 m .58041 .73529 L .58001 .73396 L F
.858 .47 0 r
.581 .73537 m .58125 .73585 L .58177 .73625 L F
0 .139 .585 r
.58177 .73625 m .58226 .73662 L .58041 .73529 L F
.858 .47 0 r
.58125 .73585 m .58256 .73843 L .58177 .73625 L F
0 .139 .585 r
.58177 .73625 m .58268 .73692 L .58226 .73662 L F
.716 .643 .775 r
.70045 .62595 m .70341 .628 L .70258 .62545 L F
.683 .636 .796 r
.70258 .62545 m .70341 .628 L .70602 .62587 L F
0 .033 .595 r
.56338 .73193 m .56384 .73104 L .56242 .72864 L F
.528 .37 .611 r
.40571 .76145 m .4059 .7643 L .40386 .76457 L F
.549 .377 .601 r
.38621 .74804 m .38836 .75003 L .38815 .7476 L F
.38621 .74804 m .38618 .75047 L .38836 .75003 L F
0 .408 .756 r
.7274 .71169 m .73044 .71292 L .72862 .71229 L F
.42 .426 .761 r
.5861 .73172 m .58672 .72809 L .58459 .72918 L F
.277 .032 .351 r
.588 .72939 m .5876 .73127 L .5861 .73172 L F
.42 .426 .761 r
.5861 .73172 m .5876 .73127 L .58672 .72809 L F
.787 .736 .806 r
.66964 .61797 m .67355 .6181 L .67278 .61942 L F
0 0 0 r
.67278 .61942 m .67355 .6181 L .67435 .61741 L F
.407 .149 .407 r
.37527 .70165 m .37286 .70421 L .37339 .7022 L F
.757 .714 .811 r
.70602 .62587 m .70927 .62622 L .70827 .62354 L F
.723 .696 .824 r
.70827 .62354 m .70927 .62622 L .71171 .62426 L F
.397 .528 .872 r
.3023 .71285 m .30241 .71287 L .30234 .71291 L F
.613 .819 .979 r
.30426 .71288 m .30234 .71291 L .30241 .71287 L F
.523 .267 .469 r
.65679 .5937 m .65918 .5932 L .65926 .59127 L F
.702 .599 .739 r
.65894 .5886 m .65926 .59127 L .66249 .59078 L F
.451 .211 .457 r
.65926 .59127 m .66119 .59267 L .66249 .59078 L F
.65926 .59127 m .65918 .5932 L .66119 .59267 L F
.73 .72 .841 r
.68538 .63413 m .68611 .63689 L .68852 .63458 L F
.758 .625 .713 r
.68919 .61254 m .69052 .6156 L .68709 .61489 L F
.719 .608 .732 r
.69263 .61311 m .69052 .6156 L .68919 .61254 L F
.878 .662 .607 r
.54751 .6967 m .54551 .6962 L .54569 .69597 L F
.54751 .6967 m .54717 .69925 L .54551 .6962 L F
.806 .8 .846 r
.54992 .69449 m .54751 .6967 L .54569 .69597 L F
.866 .651 .609 r
.54751 .6967 m .5482 .69984 L .54717 .69925 L F
.818 .76 .797 r
.66514 .59622 m .66828 .59354 L .66411 .59442 L F
.542 .233 .393 r
.53054 .7801 m .53375 .77736 L .53091 .77832 L F
.403 0 .049 r
.44916 .78253 m .44663 .78398 L .44737 .78316 L F
.155 0 .313 r
.61311 .67984 m .61503 .67692 L .61327 .67768 L F
.683 .621 .78 r
.65824 .61263 m .66103 .6145 L .6604 .61206 L F
.706 .702 .844 r
.6604 .61206 m .66103 .6145 L .66385 .61286 L F
.563 .387 .601 r
.56748 .71289 m .56531 .71606 L .56773 .71554 L F
.427 .288 .588 r
.56748 .71289 m .56773 .71554 L .56911 .7123 L F
.364 .42 .786 r
.40125 .66888 m .40076 .672 L .39914 .66941 L F
.40125 .66888 m .40211 .67164 L .40076 .672 L F
.238 .021 .369 r
.40211 .67164 m .40022 .67438 L .40076 .672 L F
.702 .599 .739 r
.65894 .5886 m .66249 .59078 L .66087 .58818 L F
.747 .683 .789 r
.36606 .67134 m .36791 .67283 L .36975 .67151 L F
.648 .485 .649 r
.36791 .67283 m .36719 .67489 L .36975 .67151 L F
.498 .31 .556 r
.36528 .6912 m .36728 .6908 L .36739 .68847 L F
.563 .441 .672 r
.36542 .69363 m .36728 .6908 L .36528 .6912 L F
0 .138 .661 r
.68052 .62213 m .6825 .62058 L .67936 .62022 L F
.68052 .62213 m .6817 .62221 L .6825 .62058 L F
.68052 .62213 m .68107 .62334 L .6817 .62221 L F
.545 .165 .271 r
.42128 .7295 m .42316 .73077 L .42436 .72872 L F
.59 .242 .347 r
.42316 .73077 m .42657 .72868 L .42436 .72872 L F
.509 .318 .556 r
.60893 .68546 m .61102 .68271 L .60887 .68312 L F
.633 .96 .811 r
.57485 .66753 m .57596 .66629 L .57619 .66592 L F
.57485 .66753 m .5731 .6682 L .57596 .66629 L F
.635 .76 .938 r
.32241 .71381 m .31875 .71301 L .32084 .71242 L F
.655 .769 .933 r
.32446 .71303 m .32241 .71381 L .32084 .71242 L F
.902 .92 .53 r
.72872 .73118 m .72748 .73374 L .72777 .73467 L F
0 .008 .544 r
.72748 .73374 m .72713 .73687 L .72777 .73467 L F
.129 .239 .711 r
.56283 .71193 m .56188 .7133 L .56055 .70922 L F
.191 .327 .773 r
.56283 .71193 m .56401 .71501 L .56188 .7133 L F
.503 .435 .714 r
.30084 .60638 m .30146 .61013 L .29957 .61043 L F
.511 .494 .774 r
.30146 .61013 m .30247 .61222 L .29957 .61043 L F
.813 .407 .281 r
.56666 .73448 m .56561 .73593 L .56565 .73367 L F
.56666 .73448 m .56864 .73702 L .56561 .73593 L F
.758 .271 .077 r
.48218 .77394 m .48174 .77215 L .48061 .77161 L F
.48218 .77394 m .48383 .77439 L .48174 .77215 L F
.757 .28 .11 r
.48174 .77215 m .48383 .77439 L .48535 .77435 L F
.509 .545 .828 r
.30289 .70971 m .3023 .71285 L .30093 .71053 L F
.30289 .70971 m .30241 .71287 L .3023 .71285 L F
.766 .871 .925 r
.72687 .71988 m .72463 .72129 L .72689 .72108 L F
.683 .604 .761 r
.72463 .72129 m .72745 .72347 L .72689 .72108 L F
.412 .581 .909 r
.72687 .71988 m .72689 .72108 L .72854 .71992 L F
.632 .423 .581 r
.72845 .72223 m .72653 .72487 L .72853 .72453 L F
.29 .321 .722 r
.72853 .72453 m .72847 .72414 L .72845 .72223 L F
0 .024 .54 r
.72689 .72108 m .72845 .72223 L .72842 .72001 L F
.72689 .72108 m .72745 .72347 L .72845 .72223 L F
0 0 0 r
.72745 .72347 m .72653 .72487 L .72845 .72223 L F
.29 .321 .722 r
.72847 .72414 m .72805 .72131 L .72845 .72223 L F
0 .024 .54 r
.72842 .72001 m .72845 .72223 L .72854 .71992 L F
.016 .58 .796 r
.56401 .71501 m .56773 .71554 L .56531 .71606 L F
.628 .381 .526 r
.64359 .59881 m .64698 .59855 L .64637 .59661 L F
.488 .308 .563 r
.64637 .59661 m .64849 .59616 L .64825 .59413 L F
.651 .505 .672 r
.64698 .59855 m .64849 .59616 L .64637 .59661 L F
0 0 0 r
.67026 .58872 m .67063 .58871 L .67235 .58691 L F
.67026 .58872 m .66933 .58983 L .67063 .58871 L F
.61 .375 .536 r
.31894 .68584 m .31876 .68805 L .31627 .68827 L F
.362 .13 .421 r
.32079 .68546 m .31876 .68805 L .31894 .68584 L F
.538 .578 .842 r
.52489 .71568 m .52295 .71598 L .52201 .71368 L F
.531 .524 .792 r
.52574 .71703 m .52295 .71598 L .52489 .71568 L F
.43 .374 .695 r
.37853 .77789 m .38026 .77757 L .37973 .77498 L F
.434 .394 .715 r
.37853 .77789 m .3808 .77999 L .38026 .77757 L F
.539 .402 .643 r
.37875 .78033 m .3808 .77999 L .37853 .77789 L F
.764 .824 .899 r
.53888 .73724 m .53667 .73816 L .53644 .73782 L F
.958 .738 .562 r
.53773 .73414 m .5375 .73669 L .53888 .73724 L F
.83 .565 .538 r
.5375 .73669 m .54028 .73922 L .53888 .73724 L F
.492 .187 .376 r
.33456 .67805 m .33362 .67969 L .33168 .6799 L F
0 0 .059 r
.33589 .67705 m .33362 .67969 L .33456 .67805 L F
.641 .648 .841 r
.37404 .79535 m .37641 .79564 L .3762 .79459 L F
.763 .59 .662 r
.61827 .64825 m .61854 .65043 L .61536 .6502 L F
.586 .436 .645 r
.62092 .64775 m .61854 .65043 L .61827 .64825 L F
.591 .287 .422 r
.7254 .62331 m .72711 .6226 L .72721 .62255 L F
0 0 0 r
.72721 .62255 m .72711 .6226 L .72936 .62019 L F
.633 .621 .82 r
.39406 .66757 m .39089 .66601 L .39303 .66537 L F
.303 .475 .864 r
.39447 .66554 m .39406 .66757 L .39303 .66537 L F
.519 .697 .95 r
.39447 .66554 m .39623 .66733 L .39406 .66757 L F
.302 .771 .938 r
.39623 .66733 m .3972 .66752 L .39406 .66757 L F
.082 .642 .72 r
.41494 .79098 m .41425 .79103 L .41201 .79125 L F
.471 .893 .832 r
.4161 .79006 m .41494 .79098 L .41732 .79027 L F
.4161 .79006 m .41425 .79103 L .41494 .79098 L F
.513 .198 .37 r
.32408 .68281 m .32281 .68522 L .32079 .68546 L F
.548 .235 .39 r
.32536 .6844 m .32408 .68281 L .32613 .68327 L F
.32536 .6844 m .32281 .68522 L .32408 .68281 L F
0 .118 .628 r
.66679 .5993 m .66807 .60016 L .66828 .59789 L F
.989 .799 .411 r
.66786 .59856 m .66828 .59789 L .66807 .60016 L F
0 0 0 r
.66828 .59789 m .66908 .59661 L .66721 .59881 L F
.989 .799 .411 r
.66767 .59699 m .66828 .59789 L .66786 .59856 L F
0 0 0 r
.66828 .59789 m .66932 .59633 L .66908 .59661 L F
.66717 .59894 m .66721 .59881 L .66679 .5993 L F
.66828 .59789 m .66721 .59881 L .66717 .59894 L F
.732 .213 0 r
.66698 .59953 m .66556 .59741 L .66437 .59694 L F
.49 0 0 r
.66751 .60006 m .66679 .5993 L .66556 .59741 L F
.732 .213 0 r
.66751 .60006 m .66702 .59939 L .66698 .59953 L F
.66702 .59939 m .66556 .59741 L .66698 .59953 L F
.948 .894 .5 r
.66893 .59546 m .66932 .59633 L .66828 .59789 L F
.542 .233 .393 r
.53054 .7801 m .53277 .78001 L .53375 .77736 L F
.684 .379 .452 r
.53375 .77736 m .5358 .7794 L .53615 .77782 L F
.53375 .77736 m .53277 .78001 L .5358 .7794 L F
.816 .792 .83 r
.37799 .80094 m .37428 .80172 L .37638 .80141 L F
.932 .623 .434 r
.37638 .80141 m .37823 .80245 L .37799 .80094 L F
.367 0 0 r
.48302 .72025 m .48625 .71892 L .48404 .71987 L F
.526 .651 .913 r
.71095 .73627 m .71161 .73415 L .70968 .73421 L F
.71095 .73627 m .71324 .73623 L .71161 .73415 L F
.538 .31 .517 r
.51468 .78314 m .51722 .78062 L .51573 .78126 L F
.51468 .78314 m .51738 .78321 L .51722 .78062 L F
.619 .37 .52 r
.51722 .78062 m .51738 .78321 L .51944 .78277 L F
.612 .773 .957 r
.35565 .65021 m .35362 .65085 L .35226 .64969 L F
.53 0 0 r
.47884 .73479 m .47729 .73467 L .4756 .73387 L F
.262 .595 .95 r
.47884 .73479 m .48028 .73383 L .47729 .73467 L F
.47884 .73479 m .48177 .73555 L .48028 .73383 L F
.966 .701 .48 r
.69688 .71801 m .69834 .71829 L .69542 .71773 L F
.69688 .71801 m .69844 .72063 L .69834 .71829 L F
.357 .805 .951 r
.6774 .62588 m .67506 .62625 L .67823 .62624 L F
.257 .364 .781 r
.67954 .62492 m .67823 .62624 L .67713 .62311 L F
.594 .925 .964 r
.67954 .62492 m .6774 .62588 L .67823 .62624 L F
.988 .803 .565 r
.62436 .65282 m .62502 .65588 L .624 .65511 L F
.959 .868 .705 r
.624 .65511 m .62502 .65588 L .62388 .65897 L F
.589 .268 .394 r
.42006 .74794 m .4191 .75021 L .41699 .7501 L F
.511 .189 .357 r
.42123 .74984 m .42006 .74794 L .42209 .74747 L F
.42123 .74984 m .4191 .75021 L .42006 .74794 L F
.176 0 .233 r
.29768 .61854 m .29757 .62001 L .29607 .62024 L F
.184 0 .267 r
.29757 .62001 m .29541 .62269 L .29607 .62024 L F
.647 .606 .793 r
.37776 .78846 m .38037 .78817 L .37935 .78581 L F
.535 .378 .615 r
.37776 .78846 m .37977 .79031 L .38037 .78817 L F
.37776 .78846 m .37813 .79104 L .37977 .79031 L F
.561 .381 .595 r
.384 .75313 m .38618 .75047 L .38383 .75073 L F
.564 .637 .882 r
.39118 .66281 m .39089 .66601 L .38947 .66298 L F
.39118 .66281 m .39303 .66537 L .39089 .66601 L F
.647 .772 .939 r
.42673 .75523 m .43043 .75463 L .43014 .75449 L F
.496 .193 .381 r
.30826 .69571 m .3062 .69618 L .3068 .69439 L F
.43 .201 .463 r
.30866 .6936 m .30826 .69571 L .3068 .69439 L F
.509 .545 .828 r
.30289 .70971 m .30426 .71288 L .30241 .71287 L F
.393 .432 .782 r
.67921 .59771 m .67747 .59984 L .6765 .59598 L F
.258 .24 .647 r
.67842 .6011 m .67747 .59984 L .67921 .59771 L F
.783 .655 .722 r
.53585 .73893 m .53981 .74151 L .53765 .73899 L F
.53585 .73893 m .5367 .74233 L .53981 .74151 L F
.792 .805 .863 r
.53765 .73899 m .53981 .74151 L .54028 .73922 L F
.436 .369 .683 r
.36975 .68584 m .37095 .68263 L .36908 .68403 L F
.36975 .68584 m .37139 .68528 L .37095 .68263 L F
.338 .126 .437 r
.36975 .68584 m .3694 .68799 L .37139 .68528 L F
.304 .041 .339 r
.38487 .69107 m .3843 .69364 L .38254 .6937 L F
.239 0 .254 r
.38357 .69516 m .38254 .6937 L .3843 .69364 L F
.38357 .69516 m .38192 .69592 L .38254 .6937 L F
.564 .371 .578 r
.39388 .68038 m .39381 .6827 L .39163 .68302 L F
.568 .398 .611 r
.39601 .67762 m .39611 .68007 L .39388 .68038 L F
.457 .284 .557 r
.39569 .68209 m .39388 .68038 L .39611 .68007 L F
.39569 .68209 m .39381 .6827 L .39388 .68038 L F
.429 .141 .372 r
.36877 .70745 m .36822 .70952 L .36615 .70989 L F
.486 .193 .393 r
.37013 .70901 m .36877 .70745 L .37072 .70698 L F
.37013 .70901 m .36822 .70952 L .36877 .70745 L F
.844 .528 .452 r
.66119 .59267 m .66411 .59442 L .66249 .59078 L F
.331 0 0 r
.47333 .73418 m .47229 .73488 L .47011 .73494 L F
.311 0 0 r
.4756 .73387 m .47229 .73488 L .47333 .73418 L F
.625 .518 .712 r
.5877 .71734 m .58539 .71821 L .58536 .71587 L F
.621 .525 .724 r
.58847 .72074 m .58539 .71821 L .5877 .71734 L F
.58847 .72074 m .58633 .72155 L .58539 .71821 L F
0 0 .41 r
.68826 .71759 m .6882 .7182 L .68939 .72083 L F
.45 .242 .505 r
.38702 .68833 m .38673 .69059 L .38487 .69107 L F
.416 .137 .38 r
.38624 .69304 m .38487 .69107 L .38673 .69059 L F
.38624 .69304 m .3843 .69364 L .38487 .69107 L F
.755 .708 .808 r
.69048 .6337 m .69375 .63412 L .69284 .63112 L F
.712 .684 .821 r
.69284 .63112 m .69375 .63412 L .69618 .63188 L F
.607 .413 .594 r
.573 .71273 m .57095 .71551 L .57377 .71277 L F
0 0 0 r
.573 .71273 m .57217 .71439 L .57095 .71551 L F
.54 .313 .519 r
.57377 .71277 m .57534 .71257 L .573 .71273 L F
.581 .376 .568 r
.57095 .71551 m .57297 .71748 L .57377 .71277 L F
.54 .313 .519 r
.57377 .71277 m .57515 .71473 L .57534 .71257 L F
.5 .303 .543 r
.57377 .71277 m .57297 .71748 L .57515 .71473 L F
.723 .232 .075 r
.57515 .71473 m .573 .71273 L .57534 .71257 L F
.57515 .71473 m .57217 .71439 L .573 .71273 L F
.613 .5 .701 r
.37887 .76687 m .3817 .76939 L .38082 .76649 L F
.37887 .76687 m .37945 .76975 L .3817 .76939 L F
.578 .411 .62 r
.58847 .72074 m .58869 .72313 L .58633 .72155 L F
.851 .772 .774 r
.55174 .69153 m .54829 .69336 L .55027 .6904 L F
.55174 .69153 m .54992 .69449 L .54829 .69336 L F
.736 .799 .902 r
.55342 .69078 m .55174 .69153 L .55027 .6904 L F
.747 .683 .789 r
.36606 .67134 m .36975 .67151 L .3683 .67067 L F
0 .46 .837 r
.36975 .67151 m .37008 .67118 L .3683 .67067 L F
.36975 .67151 m .37108 .67188 L .37008 .67118 L F
.689 .671 .827 r
.69138 .61198 m .69263 .61311 L .68919 .61254 L F
.761 .672 .764 r
.6948 .61071 m .69263 .61311 L .69138 .61198 L F
.123 0 0 r
.33794 .72877 m .33517 .72979 L .33656 .72869 L F
.528 .495 .763 r
.53531 .74238 m .5367 .74233 L .53585 .73893 L F
.75 .533 .601 r
.53498 .74564 m .53531 .74238 L .53333 .74458 L F
.704 .698 .841 r
.69916 .60882 m .70016 .61047 L .69691 .6097 L F
.612 .653 .866 r
.70161 .60841 m .70016 .61047 L .69916 .60882 L F
.70161 .60841 m .70254 .60993 L .70016 .61047 L F
.903 .816 .752 r
.64252 .6536 m .64303 .6493 L .64154 .65283 L F
.964 .875 .699 r
.64143 .65591 m .64252 .6536 L .64154 .65283 L F
.745 .724 .832 r
.70623 .61036 m .70254 .60993 L .70471 .609 L F
.813 .798 .837 r
.70852 .60757 m .70623 .61036 L .70471 .609 L F
.475 .234 .468 r
.39323 .68455 m .39163 .68302 L .39381 .6827 L F
.39323 .68455 m .39127 .68507 L .39163 .68302 L F
.994 .764 .476 r
.56252 .72644 m .56143 .72818 L .56121 .72567 L F
.56252 .72644 m .56242 .72864 L .56143 .72818 L F
.928 .864 .756 r
.64641 .63432 m .6471 .63025 L .64588 .63351 L F
.132 .227 .697 r
.64588 .63351 m .64655 .63692 L .64641 .63432 L F
.765 .638 .721 r
.51173 .78298 m .51468 .78314 L .51573 .78126 L F
.586 .577 .81 r
.38614 .6604 m .38421 .66083 L .38336 .65923 L F
.547 .593 .852 r
.38658 .66182 m .38421 .66083 L .38614 .6604 L F
.302 0 .095 r
.34844 .72254 m .34655 .72307 L .34937 .72149 L F
.115 0 0 r
.35125 .72075 m .34844 .72254 L .34937 .72149 L F
.501 .238 .447 r
.59021 .72893 m .5876 .73127 L .588 .72939 L F
.531 .202 .355 r
.30568 .66611 m .30787 .66596 L .30862 .66435 L F
.458 .169 .385 r
.30787 .66596 m .31045 .66374 L .30862 .66435 L F
.604 .55 .767 r
.71094 .58634 m .71062 .58859 L .7087 .58541 L F
.038 .256 .755 r
.7087 .58541 m .71062 .58859 L .7091 .5856 L F
.73 .585 .693 r
.71062 .58859 m .70644 .59089 L .7091 .5856 L F
.71062 .58859 m .70994 .5909 L .70644 .59089 L F
.463 .419 .724 r
.71094 .58634 m .71191 .59078 L .71062 .58859 L F
.639 .49 .664 r
.71062 .58859 m .71191 .59078 L .70994 .5909 L F
.146 .14 .592 r
.69816 .70472 m .69964 .70344 L .70053 .70436 L F
.71 .47 .56 r
.70053 .70436 m .6975 .70669 L .69816 .70472 L F
0 0 .036 r
.69816 .70472 m .6975 .70669 L .69867 .70441 L F
.146 .14 .592 r
.69816 .70472 m .69867 .70441 L .69964 .70344 L F
0 0 0 r
.57619 .66592 m .57596 .66629 L .57715 .66486 L F
.57715 .66486 m .57756 .66508 L .57849 .66357 L F
.57715 .66486 m .57596 .66629 L .57756 .66508 L F
.945 .783 .65 r
.52476 .72909 m .52243 .73056 L .52208 .72858 L F
.133 0 0 r
.4507 .77269 m .44695 .77422 L .44892 .77318 L F
0 0 0 r
.45277 .77212 m .4507 .77269 L .44892 .77318 L F
.567 .489 .727 r
.68129 .59061 m .67907 .59131 L .67901 .58869 L F
.777 .989 .893 r
.68011 .58965 m .67907 .59131 L .68129 .59061 L F
.692 .468 .579 r
.67824 .58815 m .67894 .59038 L .68011 .58965 L F
.777 .989 .893 r
.68011 .58965 m .67747 .59131 L .67907 .59131 L F
.692 .468 .579 r
.67894 .59038 m .67904 .5907 L .68011 .58965 L F
.741 .534 .613 r
.67824 .58815 m .67453 .5873 L .67686 .587 L F
.753 .617 .709 r
.67543 .58982 m .67854 .59058 L .67686 .587 L F
.777 .989 .893 r
.68011 .58965 m .67758 .59122 L .67747 .59131 L F
.67758 .59122 m .67744 .59131 L .67745 .59131 L F
.67758 .59122 m .67745 .59131 L .67747 .59131 L F
.709 .495 .596 r
.67904 .5907 m .67744 .59131 L .68011 .58965 L F
.753 .617 .709 r
.67854 .59058 m .67904 .5907 L .67885 .59038 L F
.67854 .59058 m .67885 .59038 L .67686 .587 L F
.625 .518 .712 r
.5877 .71734 m .58536 .71587 L .58787 .71551 L F
.714 .733 .866 r
.69618 .63188 m .69985 .63243 L .69838 .631 L F
.83 .772 .797 r
.69838 .631 m .69985 .63243 L .70079 .63113 L F
.733 .864 .943 r
.69029 .7077 m .68725 .70786 L .68942 .70708 L F
.215 .449 .87 r
.69192 .7073 m .69029 .7077 L .68942 .70708 L F
.69192 .7073 m .69301 .70933 L .69029 .7077 L F
.494 .452 .739 r
.69301 .70933 m .69193 .71184 L .69029 .7077 L F
.498 .309 .556 r
.36739 .68847 m .36728 .6908 L .3694 .68799 L F
.643 .355 .467 r
.71242 .71786 m .71201 .7205 L .71013 .71995 L F
.51 .237 .436 r
.71444 .71983 m .71242 .71786 L .71528 .71769 L F
.71444 .71983 m .71201 .7205 L .71242 .71786 L F
.276 0 0 r
.42315 .78875 m .42157 .78966 L .41984 .78977 L F
0 0 0 r
.42351 .78912 m .42315 .78875 L .42516 .78817 L F
.42351 .78912 m .42157 .78966 L .42315 .78875 L F
.784 .835 .891 r
.49675 .7268 m .49981 .72655 L .4987 .72562 L F
.553 .789 .987 r
.4987 .72562 m .49981 .72655 L .50068 .72524 L F
.541 .772 .983 r
.49981 .72655 m .50213 .72623 L .50068 .72524 L F
.516 .187 .348 r
.43917 .74488 m .43563 .74745 L .43572 .74566 L F
.461 0 0 r
.49162 .78104 m .49055 .78202 L .48829 .78164 L F
.578 .062 0 r
.49162 .78104 m .49388 .78229 L .49055 .78202 L F
.848 .998 .784 r
.466 .76937 m .46381 .77203 L .4651 .77108 L F
.67 .13 0 r
.46589 .77227 m .4651 .77108 L .46381 .77203 L F
.658 .358 .452 r
.46466 .77275 m .46563 .77253 L .46589 .77227 L F
.67 .13 0 r
.46589 .77227 m .46724 .77294 L .46616 .772 L F
.241 .718 .937 r
.46738 .77211 m .46724 .77294 L .46589 .77227 L F
.658 .358 .452 r
.46563 .77253 m .46738 .77211 L .46589 .77227 L F
.67 .13 0 r
.46589 .77227 m .46616 .772 L .4651 .77108 L F
.761 .672 .764 r
.6948 .61071 m .69138 .61198 L .69365 .60962 L F
.716 .84 .941 r
.69691 .6097 m .6948 .61071 L .69365 .60962 L F
.835 .895 .475 r
.67885 .60656 m .6797 .60483 L .67974 .60373 L F
.559 .843 .508 r
.59611 .66195 m .59488 .66324 L .594 .6643 L F
0 0 0 r
.594 .66486 m .594 .6643 L .59488 .66324 L F
.594 .66486 m .59334 .66636 L .594 .6643 L F
0 0 .036 r
.73491 .71822 m .73464 .72022 L .73435 .72001 L F
0 .062 .586 r
.73453 .71503 m .73566 .71684 L .73491 .71822 L F
0 0 .002 r
.73566 .71684 m .73464 .72022 L .73491 .71822 L F
.551 .452 .695 r
.414 .77696 m .4115 .77522 L .41315 .77477 L F
.414 .77696 m .41199 .7774 L .4115 .77522 L F
.477 .194 .405 r
.59981 .70141 m .59847 .70404 L .59628 .70445 L F
.612 .341 .482 r
.60083 .70382 m .59981 .70141 L .6014 .70144 L F
.60083 .70382 m .59847 .70404 L .59981 .70141 L F
.536 .508 .772 r
.40694 .75831 m .40571 .76145 L .40545 .75846 L F
.40694 .75831 m .40794 .76177 L .40571 .76145 L F
.563 .397 .614 r
.40794 .76177 m .4059 .7643 L .40571 .76145 L F
.788 .598 .644 r
.71576 .58678 m .71415 .58754 L .71682 .58474 L F
.564 .633 .878 r
.71819 .58491 m .71576 .58678 L .71682 .58474 L F
.71819 .58491 m .7206 .58744 L .71576 .58678 L F
.505 .189 .365 r
.42657 .72868 m .42876 .72845 L .42922 .72683 L F
.418 .055 .239 r
.42876 .72845 m .43202 .72588 L .42922 .72683 L F
.432 .217 .485 r
.38915 .68564 m .38888 .68781 L .38702 .68833 L F
.386 .167 .455 r
.38888 .68781 m .38673 .69059 L .38702 .68833 L F
.431 .12 .335 r
.60203 .64201 m .60418 .64148 L .60488 .63906 L F
.574 .288 .444 r
.60418 .64148 m .60712 .63881 L .60488 .63906 L F
0 0 0 r
.72721 .62255 m .72936 .62019 L .72927 .61962 L F
.906 .603 .46 r
.68107 .62334 m .67954 .62492 L .6817 .62221 L F
.68107 .62334 m .68113 .62555 L .67954 .62492 L F
.751 .994 .846 r
.36141 .80344 m .35868 .80548 L .35966 .80393 L F
0 .263 .641 r
.36173 .80358 m .36141 .80344 L .35966 .80393 L F
.36173 .80358 m .36363 .80455 L .36141 .80344 L F
.508 .657 .927 r
.36611 .78684 m .36735 .78535 L .36701 .78489 L F
.36611 .78684 m .36822 .78692 L .36735 .78535 L F
.273 .443 .847 r
.53396 .72281 m .53301 .72407 L .53172 .72159 L F
.421 .654 .956 r
.53396 .72281 m .53509 .72423 L .53301 .72407 L F
.878 .731 .696 r
.70079 .63113 m .69999 .62801 L .69838 .631 L F
.558 .109 .141 r
.34158 .67513 m .3401 .6767 L .33831 .67629 L F
.506 .05 .103 r
.34321 .67615 m .3401 .6767 L .34158 .67513 L F
.261 .753 .912 r
.38217 .80477 m .38454 .80461 L .38292 .80444 L F
.488 .448 .739 r
.58963 .71494 m .58787 .71551 L .58729 .71331 L F
.567 .455 .686 r
.58963 .71494 m .5877 .71734 L .58787 .71551 L F
.793 .678 .737 r
.58254 .74122 m .57893 .74211 L .57919 .73984 L F
.539 .484 .743 r
.58473 .74222 m .58254 .74122 L .58441 .73979 L F
.869 .734 .712 r
.54854 .70239 m .5481 .70487 L .5458 .70393 L F
.516 .42 .685 r
.42913 .75156 m .43014 .75449 L .43134 .75291 L F
.943 .907 .757 r
.57757 .68482 m .58029 .68255 L .57956 .68143 L F
.57757 .68482 m .57839 .68572 L .58029 .68255 L F
.469 .033 .128 r
.58243 .67998 m .57956 .68143 L .58029 .68255 L F
.582 .856 .995 r
.42087 .77835 m .41738 .77816 L .41941 .77732 L F
.65 .84 .973 r
.42284 .77745 m .42087 .77835 L .41941 .77732 L F
.656 .617 .799 r
.40946 .76669 m .40711 .76721 L .4059 .7643 L F
.806 .8 .846 r
.54992 .69449 m .54569 .69597 L .54829 .69336 L F
.243 .306 .729 r
.57349 .70147 m .57522 .70359 L .57392 .7047 L F
.721 .484 .567 r
.57392 .7047 m .57395 .70697 L .57747 .70666 L F
.137 .032 .461 r
.57523 .70563 m .57392 .7047 L .57522 .70359 L F
.57523 .70563 m .57395 .70697 L .57392 .7047 L F
.893 .987 .791 r
.72078 .73092 m .71927 .73283 L .71978 .73089 L F
.577 .942 .889 r
.72078 .73092 m .72166 .72986 L .72303 .7289 L F
.72078 .73092 m .71978 .73089 L .72166 .72986 L F
.895 .9 .823 r
.7227 .62566 m .7254 .62331 L .72538 .62369 L F
0 0 0 r
.72721 .62255 m .72538 .62369 L .7254 .62331 L F
.557 .152 .229 r
.42093 .73058 m .42316 .73077 L .42128 .7295 L F
.87 .683 .647 r
.54797 .70082 m .54551 .6962 L .54717 .69925 L F
.508 .332 .577 r
.40689 .75326 m .40717 .75613 L .40473 .75646 L F
.385 .27 .598 r
.40717 .75613 m .40545 .75846 L .40473 .75646 L F
.555 .402 .628 r
.398 .67484 m .39813 .6772 L .39601 .67762 L F
.449 .306 .594 r
.39787 .67942 m .39601 .67762 L .39813 .6772 L F
.39787 .67942 m .39611 .68007 L .39601 .67762 L F
.397 0 0 r
.70323 .72968 m .69949 .72951 L .70088 .73025 L F
.45 .09 .261 r
.29296 .67681 m .29476 .67483 L .29386 .6749 L F
.896 .597 .471 r
.54825 .70695 m .5458 .70393 L .5481 .70487 L F
.748 .814 .904 r
.51033 .72501 m .50778 .72624 L .51103 .72618 L F
.554 .591 .846 r
.51103 .72618 m .51177 .72275 L .51033 .72501 L F
.51103 .72618 m .51317 .72607 L .51177 .72275 L F
.396 .173 .455 r
.28769 .63421 m .2873 .63639 L .28558 .63699 L F
.387 .191 .488 r
.2873 .63639 m .28536 .63925 L .28558 .63699 L F
.734 .885 .95 r
.49768 .71603 m .49383 .71681 L .49658 .71545 L F
.789 .93 .927 r
.49768 .71603 m .4983 .71411 L .49951 .71475 L F
.49768 .71603 m .49658 .71545 L .4983 .71411 L F
.829 .354 0 r
.55579 .72065 m .55478 .72021 L .55382 .7185 L F
.918 .555 .327 r
.55722 .72327 m .55478 .72021 L .55579 .72065 L F
.388 .255 .576 r
.28922 .63128 m .28933 .63345 L .28769 .63421 L F
.375 .176 .477 r
.28933 .63345 m .2873 .63639 L .28769 .63421 L F
.434 0 .032 r
.4573 .78026 m .45372 .78166 L .45514 .78042 L F
.765 .35 .262 r
.51173 .78298 m .51518 .78499 L .51468 .78314 L F
.633 .49 .67 r
.51518 .78499 m .51738 .78321 L .51468 .78314 L F
.608 .79 .969 r
.35786 .64959 m .35908 .65074 L .35565 .65021 L F
.35786 .64959 m .35908 .65074 L .35565 .65021 L F
.46 .782 .998 r
.35973 .64963 m .35908 .65074 L .35786 .64959 L F
.35973 .64963 m .36119 .65046 L .35908 .65074 L F
.366 .038 .271 r
.32567 .65274 m .32663 .65467 L .32768 .65225 L F
.32567 .65274 m .32463 .65526 L .32663 .65467 L F
.418 .055 .239 r
.42876 .72845 m .43088 .72808 L .43202 .72588 L F
.468 .084 .227 r
.43088 .72808 m .43433 .72583 L .43202 .72588 L F
.311 0 0 r
.69098 .57343 m .6942 .57267 L .69192 .57302 L F
.409 .165 .43 r
.39127 .68507 m .38888 .68781 L .38915 .68564 L F
.683 .945 .671 r
.39059 .79747 m .39126 .79741 L .39323 .79663 L F
.264 0 .054 r
.33222 .6813 m .33168 .6799 L .33362 .67969 L F
.33222 .6813 m .33021 .68186 L .33168 .6799 L F
0 0 .537 r
.66759 .6125 m .66771 .61232 L .66605 .61161 L F
.66759 .6125 m .66922 .61457 L .66771 .61232 L F
.438 .017 .141 r
.60411 .65552 m .60435 .65711 L .60214 .65726 L F
.217 0 .08 r
.60771 .65328 m .6065 .65509 L .60411 .65552 L F
.524 .244 .432 r
.6065 .65509 m .60435 .65711 L .60411 .65552 L F
.633 .621 .821 r
.3762 .79459 m .37641 .79564 L .37889 .79453 L F
.876 .719 .684 r
.688 .61666 m .68899 .61775 L .69018 .61792 L F
.427 .434 .764 r
.53879 .72842 m .53733 .72932 L .53641 .72672 L F
.287 .107 .454 r
.53897 .73045 m .53733 .72932 L .53879 .72842 L F
.53897 .73045 m .53694 .73211 L .53733 .72932 L F
0 .366 .766 r
.57815 .69023 m .57975 .69128 L .57777 .69012 L F
.832 .707 .727 r
.57815 .69023 m .57941 .69328 L .57975 .69128 L F
.322 .109 .426 r
.57975 .69128 m .57941 .69328 L .58147 .69028 L F
.315 .804 .806 r
.47287 .72466 m .47562 .72391 L .47658 .72381 L F
.416 .865 .836 r
.47658 .72381 m .47769 .72308 L .47829 .72253 L F
.47658 .72381 m .47562 .72391 L .47769 .72308 L F
.579 .425 .636 r
.64825 .59413 m .65131 .59377 L .6504 .59116 L F
.721 .622 .746 r
.64849 .59616 m .65131 .59377 L .64825 .59413 L F
.528 .438 .697 r
.37945 .76975 m .38179 .77191 L .3817 .76939 L F
.37945 .76975 m .37994 .77243 L .38179 .77191 L F
0 .488 .813 r
.3669 .6515 m .37008 .6526 L .368 .65287 L F
.416 0 0 r
.7087 .58541 m .7091 .5856 L .70774 .58651 L F
.585 .919 .969 r
.70999 .58416 m .71093 .58451 L .7087 .58541 L F
0 0 0 r
.7087 .58541 m .70774 .58651 L .70999 .58416 L F
.604 .55 .767 r
.71094 .58634 m .7087 .58541 L .71093 .58451 L F
.488 .448 .739 r
.58963 .71494 m .58729 .71331 L .58945 .71259 L F
.674 .536 .689 r
.36333 .79944 m .36691 .79957 L .3655 .7967 L F
.661 .405 .522 r
.36333 .79944 m .36556 .80238 L .36691 .79957 L F
.677 .41 .511 r
.59591 .68837 m .59817 .69053 L .59861 .68808 L F
.635 .371 .501 r
.59861 .68808 m .60048 .69034 L .6014 .68798 L F
.59861 .68808 m .59817 .69053 L .60048 .69034 L F
.734 .409 .43 r
.61536 .6502 m .61854 .65043 L .61713 .65233 L F
.586 .436 .645 r
.62092 .64775 m .62092 .65013 L .61854 .65043 L F
.759 .577 .651 r
.62092 .65013 m .61713 .65233 L .61854 .65043 L F
.301 0 0 r
.47289 .77276 m .4748 .77296 L .47601 .77178 L F
.567 .114 .136 r
.4748 .77296 m .47825 .77204 L .47601 .77178 L F
0 0 0 r
.36042 .67037 m .35896 .6709 L .3569 .67127 L F
.458 0 0 r
.45277 .77212 m .45499 .77268 L .45615 .77238 L F
.445 0 0 r
.45499 .77268 m .45838 .77247 L .45615 .77238 L F
.625 .955 .792 r
.55042 .69756 m .5482 .69984 L .55152 .69716 L F
.593 .557 .783 r
.55152 .69716 m .5482 .69984 L .5516 .69917 L F
.46 .139 .334 r
.5516 .69917 m .5516 .70065 L .5482 .69984 L F
.349 .432 .806 r
.55042 .69756 m .5516 .70065 L .5482 .69984 L F
.174 0 .114 r
.52843 .78772 m .52637 .78831 L .52971 .7863 L F
.117 0 0 r
.5305 .78701 m .52971 .7863 L .53199 .78612 L F
.5305 .78701 m .52843 .78772 L .52971 .7863 L F
.85 .783 .786 r
.57647 .71811 m .57521 .72068 L .57709 .7207 L F
.766 .358 .279 r
.57521 .72068 m .57641 .72254 L .57709 .7207 L F
.036 0 .37 r
.57709 .7207 m .57856 .7178 L .57647 .71811 L F
.57709 .7207 m .57859 .71973 L .57856 .7178 L F
.76 .648 .738 r
.57641 .72254 m .57859 .71973 L .57709 .7207 L F
.848 .464 .32 r
.55478 .72021 m .55116 .7169 L .55382 .7185 L F
.396 0 .151 r
.70994 .5909 m .70685 .59301 L .70644 .59089 L F
.70994 .5909 m .70911 .59263 L .70685 .59301 L F
.967 .877 .694 r
.71191 .59078 m .71054 .59257 L .71148 .59286 L F
.71191 .59078 m .71148 .59286 L .70994 .5909 L F
.516 .347 .59 r
.57959 .70465 m .5818 .70654 L .58177 .70422 L F
.57959 .70465 m .57951 .70721 L .5818 .70654 L F
.736 .799 .902 r
.55342 .69078 m .55027 .6904 L .55241 .68918 L F
.884 .854 .808 r
.55536 .68776 m .55342 .69078 L .55241 .68918 L F
.662 .648 .825 r
.68919 .61254 m .68581 .61073 L .68829 .60997 L F
.69 .687 .842 r
.69138 .61198 m .68919 .61254 L .68829 .60997 L F
.345 0 0 r
.68151 .61399 m .67586 .61281 L .67832 .6144 L F
.564 .811 .991 r
.65757 .61147 m .65824 .61263 L .6604 .61206 L F
.734 .401 .417 r
.5168 .72615 m .51502 .72831 L .51317 .72607 L F
.659 .304 .359 r
.51874 .72815 m .51502 .72831 L .5168 .72615 L F
.585 .673 .9 r
.50213 .72623 m .50521 .7281 L .50469 .72543 L F
.664 .628 .803 r
.50469 .72543 m .50521 .7281 L .50778 .72624 L F
.54 .374 .604 r
.62221 .62208 m .62273 .61993 L .62049 .6207 L F
.663 .136 0 r
.48383 .77439 m .48679 .77523 L .48535 .77435 L F
.891 .943 .839 r
.55862 .68354 m .55657 .68621 L .55638 .68447 L F
.925 .971 .758 r
.55536 .68776 m .55638 .68447 L .55657 .68621 L F
.23 .588 .947 r
.38096 .65689 m .38048 .65782 L .37888 .65707 L F
.38096 .65689 m .38227 .65811 L .38048 .65782 L F
.4 .765 .994 r
.58147 .69028 m .5837 .69017 L .58484 .69106 L F
.925 .883 .774 r
.58178 .69327 m .58484 .69106 L .5837 .69017 L F
.58178 .69327 m .58275 .69387 L .58484 .69106 L F
.738 .556 .647 r
.58484 .69106 m .58275 .69387 L .58501 .69327 L F
.721 .58 .696 r
.58501 .69327 m .58829 .6913 L .58484 .69106 L F
.117 0 .025 r
.59734 .64477 m .59902 .64449 L .59994 .64265 L F
.354 0 .172 r
.59902 .64449 m .60203 .64201 L .59994 .64265 L F
.294 0 0 r
.52019 .79232 m .51624 .79337 L .51682 .79318 L F
.52019 .79232 m .51855 .79325 L .51624 .79337 L F
.415 .83 .646 r
.51998 .79235 m .52019 .79232 L .52192 .79115 L F
.51998 .79235 m .51855 .79325 L .52019 .79232 L F
.724 .489 .57 r
.58065 .69866 m .58265 .69888 L .58298 .69613 L F
.585 .446 .658 r
.58298 .69613 m .58501 .69327 L .58275 .69387 L F
.58298 .69613 m .58604 .69615 L .58501 .69327 L F
.64 .413 .558 r
.58298 .69613 m .58613 .69845 L .58604 .69615 L F
.58298 .69613 m .58265 .69888 L .58613 .69845 L F
.179 .303 .754 r
.39781 .66832 m .39691 .66972 L .39623 .66733 L F
.521 .763 .985 r
.39781 .66832 m .39914 .66941 L .39691 .66972 L F
.717 .23 .086 r
.48634 .78035 m .48478 .78041 L .48332 .77964 L F
.565 0 0 r
.48829 .78164 m .48478 .78041 L .48634 .78035 L F
.722 .631 .756 r
.70342 .71276 m .70243 .71431 L .70012 .71322 L F
0 0 .127 r
.58306 .65824 m .58494 .65523 L .58398 .65634 L F
.13 0 0 r
.43232 .78694 m .42939 .78749 L .43107 .78696 L F
0 0 0 r
.67858 .57902 m .67654 .58014 L .67797 .57938 L F
.67654 .58014 m .67598 .58169 L .67797 .57938 L F
.669 .472 .609 r
.62187 .62601 m .62443 .62599 L .62389 .62337 L F
.651 .536 .71 r
.62504 .62172 m .62221 .62208 L .62389 .62337 L F
.056 .029 .506 r
.62443 .62599 m .62504 .62172 L .62389 .62337 L F
.563 .103 .118 r
.48679 .77523 m .48945 .77628 L .49058 .77491 L F
.702 .266 .212 r
.48945 .77628 m .4928 .77688 L .49058 .77491 L F
.621 .834 .982 r
.30992 .71277 m .30795 .71347 L .30643 .71252 L F
.997 .858 .567 r
.64471 .645 m .64348 .64494 L .64465 .64673 L F
.64471 .645 m .64384 .64391 L .64348 .64494 L F
0 0 0 r
.56064 .70105 m .55868 .70212 L .55876 .70185 L F
.386 0 0 r
.55868 .70212 m .56064 .70105 L .55876 .70185 L F
.592 .412 .607 r
.70048 .71558 m .70342 .71276 L .70012 .71322 L F
.385 .27 .598 r
.40717 .75613 m .40694 .75831 L .40545 .75846 L F
.649 .52 .693 r
.58829 .6913 m .5907 .69327 L .5907 .69106 L F
.599 .43 .624 r
.5907 .69327 m .59282 .6906 L .5907 .69106 L F
.442 .068 .232 r
.45699 .73763 m .45666 .73854 L .45453 .7388 L F
.503 .125 .256 r
.45699 .73763 m .45878 .73872 L .45666 .73854 L F
.473 .156 .347 r
.45871 .73728 m .45878 .73872 L .45699 .73763 L F
.041 0 .201 r
.2995 .61707 m .29757 .62001 L .29768 .61854 L F
.464 .441 .748 r
.71856 .73435 m .71978 .73089 L .71927 .73283 L F
.3 .349 .745 r
.3655 .7967 m .36691 .79957 L .36768 .79874 L F
.691 .473 .586 r
.65131 .59377 m .65329 .59089 L .6504 .59116 L F
.65131 .59377 m .65341 .59325 L .65329 .59089 L F
.267 .661 .968 r
.53269 .73156 m .53304 .7309 L .5311 .73072 L F
.576 .465 .69 r
.29476 .67483 m .2961 .67462 L .29575 .67173 L F
.45 .09 .261 r
.29296 .67681 m .2961 .67462 L .29476 .67483 L F
.614 .409 .581 r
.40916 .75548 m .40689 .75326 L .40929 .75314 L F
.40916 .75548 m .40717 .75613 L .40689 .75326 L F
.528 .763 .983 r
.71705 .62382 m .7182 .6224 L .71631 .62165 L F
.71705 .62382 m .71909 .62354 L .7182 .6224 L F
.401 .837 .947 r
.35917 .91288 m .35714 .91333 L .35783 .91265 L F
.35783 .91265 m .35714 .91333 L .35917 .91288 L F
.1 0 0 r
.34697 .72407 m .34655 .72307 L .34844 .72254 L F
.34697 .72407 m .34507 .725 L .34655 .72307 L F
.512 .163 .313 r
.44694 .74225 m .44345 .74472 L .44388 .74299 L F
.44694 .74225 m .4457 .74455 L .44345 .74472 L F
.582 .285 .43 r
.44841 .74196 m .4457 .74455 L .44694 .74225 L F
.484 .871 .972 r
.37105 .79656 m .37172 .79565 L .37337 .79592 L F
.37105 .79656 m .37172 .79565 L .37337 .79592 L F
.616 .545 .752 r
.7242 .59366 m .72201 .59431 L .72093 .59089 L F
.686 .478 .599 r
.61347 .65193 m .60978 .65024 L .61326 .65007 L F
.633 .39 .531 r
.61536 .6502 m .61347 .65193 L .61326 .65007 L F
.651 .415 .55 r
.59602 .69058 m .59817 .69053 L .59591 .68837 L F
.481 .18 .379 r
.31088 .7402 m .31018 .74212 L .30813 .74234 L F
.423 .125 .352 r
.31216 .7416 m .31088 .7402 L .31306 .73956 L F
.31216 .7416 m .31018 .74212 L .31088 .7402 L F
.216 0 0 r
.46063 .78011 m .45935 .78036 L .4573 .78026 L F
.331 0 0 r
.4617 .78088 m .46063 .78011 L .46283 .77988 L F
.4617 .78088 m .45935 .78036 L .46063 .78011 L F
0 0 0 r
.33358 .65061 m .33394 .65063 L .33562 .65008 L F
.33358 .65061 m .3318 .6513 L .33394 .65063 L F
.923 .861 .761 r
.65112 .62001 m .65396 .61811 L .6524 .61698 L F
.65112 .62001 m .65259 .62106 L .65396 .61811 L F
.78 .793 .864 r
.6524 .61698 m .65396 .61811 L .6557 .6158 L F
.201 0 .306 r
.32561 .73369 m .32346 .73672 L .32415 .73482 L F
.597 .443 .644 r
.30184 .69941 m .30191 .70174 L .29963 .70191 L F
.597 .448 .649 r
.29963 .70191 m .30191 .70174 L .29981 .70419 L F
.516 .187 .348 r
.43917 .74488 m .43813 .74712 L .43563 .74745 L F
.286 0 .229 r
.43991 .74656 m .43917 .74488 L .44129 .74501 L F
.43991 .74656 m .43813 .74712 L .43917 .74488 L F
.226 0 0 r
.34878 .7074 m .34929 .70858 L .3509 .70704 L F
.34878 .7074 m .34733 .70914 L .34929 .70858 L F
.884 .854 .808 r
.55536 .68776 m .55241 .68918 L .55465 .68731 L F
.925 .971 .758 r
.55536 .68776 m .55465 .68731 L .55638 .68447 L F
.818 .76 .797 r
.66514 .59622 m .66411 .59442 L .66406 .59552 L F
.966 .641 .309 r
.66437 .59694 m .66514 .59622 L .66406 .59552 L F
.66437 .59694 m .66556 .59741 L .66514 .59622 L F
.959 .868 .705 r
.624 .65511 m .62388 .65897 L .62304 .65827 L F
.928 .937 .787 r
.62304 .65827 m .62388 .65897 L .62253 .66059 L F
.602 .64 .861 r
.68874 .58382 m .69135 .58371 L .68763 .58227 L F
.574 .436 .655 r
.72412 .71852 m .72064 .72047 L .7206 .71802 L F
.938 .773 .651 r
.66882 .60475 m .66828 .60696 L .66691 .60599 L F
.545 .797 .991 r
.53047 .72057 m .52979 .72202 L .52879 .72023 L F
.53047 .72057 m .53172 .72159 L .52979 .72202 L F
.442 .231 .496 r
.57534 .71257 m .57847 .71273 L .57777 .71208 L F
.57534 .71257 m .57643 .71482 L .57847 .71273 L F
.845 .665 .659 r
.57643 .71482 m .57849 .71528 L .57847 .71273 L F
.992 .788 .53 r
.57847 .71273 m .57979 .71177 L .57777 .71208 L F
.57847 .71273 m .57849 .71528 L .57704 .71417 L F
.57847 .71273 m .57704 .71417 L .57979 .71177 L F
.526 .29 .5 r
.36086 .69907 m .36299 .69872 L .36325 .69658 L F
.568 .393 .604 r
.36325 .69658 m .36552 .69628 L .36542 .69363 L F
.513 .264 .474 r
.36299 .69872 m .36552 .69628 L .36325 .69658 L F
.872 .462 .243 r
.57061 .73902 m .56864 .73702 L .57166 .73659 L F
.742 .816 .91 r
.39885 .79643 m .40231 .79676 L .40083 .79561 L F
.819 .614 .625 r
.40182 .79835 m .40231 .79676 L .39885 .79643 L F
.844 .814 .82 r
.40083 .79561 m .40231 .79676 L .40405 .79368 L F
.294 .758 .947 r
.58214 .72937 m .58278 .72865 L .58058 .72967 L F
.58214 .72937 m .58459 .72918 L .58278 .72865 L F
.874 .884 .839 r
.68063 .58614 m .67901 .58869 L .67824 .58815 L F
.468 .191 .409 r
.53615 .77782 m .5358 .7794 L .53777 .77888 L F
.747 .228 0 r
.50063 .78385 m .50231 .78577 L .49973 .78431 L F
.717 .188 0 r
.50369 .78645 m .50231 .78577 L .50063 .78385 L F
.777 .634 .703 r
.64949 .61201 m .65462 .61303 L .65143 .60943 L F
.784 .505 .514 r
.65151 .61422 m .65462 .61303 L .64949 .61201 L F
.411 .538 .875 r
.65143 .60943 m .65462 .61303 L .65473 .61232 L F
.7 .451 .543 r
.65151 .61422 m .65473 .61232 L .65462 .61303 L F
.702 .841 .95 r
.50539 .7132 m .50192 .71326 L .50416 .71244 L F
.796 .893 .913 r
.50729 .71181 m .50539 .7132 L .50416 .71244 L F
.499 .2 .389 r
.44388 .74299 m .44345 .74472 L .44129 .74501 L F
.531 .327 .549 r
.38803 .74523 m .39015 .74486 L .3903 .74252 L F
.497 .299 .541 r
.3903 .74252 m .39015 .74486 L .3923 .74212 L F
.3903 .74252 m .39015 .74486 L .3923 .74212 L F
.648 .161 .082 r
.6558 .59483 m .65679 .5937 L .65341 .59325 L F
.637 .148 .075 r
.6589 .5952 m .65679 .5937 L .6558 .59483 L F
.527 .277 .48 r
.6589 .5952 m .65918 .5932 L .65679 .5937 L F
0 .226 .696 r
.50369 .78645 m .50504 .78707 L .50231 .78577 L F
.50369 .78645 m .50599 .78798 L .50504 .78707 L F
.08 .28 .766 r
.57217 .71439 m .57297 .71748 L .57095 .71551 L F
.532 .375 .614 r
.57095 .71551 m .57086 .71811 L .57297 .71748 L F
.417 .521 .856 r
.52733 .71741 m .52605 .71884 L .52574 .71703 L F
.52733 .71741 m .52879 .72023 L .52605 .71884 L F
.834 .951 .894 r
.6201 .66146 m .61965 .66332 L .61963 .66293 L F
.6201 .66146 m .62253 .66059 L .61965 .66332 L F
.939 .781 .658 r
.65045 .62208 m .65259 .62106 L .65112 .62001 L F
.65045 .62208 m .65186 .62315 L .65259 .62106 L F
.8 .467 .425 r
.5734 .73969 m .57214 .74162 L .57061 .73902 L F
.648 .629 .817 r
.57434 .73648 m .57513 .73975 L .5734 .73969 L F
.772 .495 .517 r
.57513 .73975 m .57214 .74162 L .5734 .73969 L F
.629 .612 .814 r
.68201 .63336 m .68278 .63537 L .68538 .63413 L F
.493 .799 .999 r
.28826 .60204 m .28634 .60241 L .28479 .60156 L F
.668 .453 .584 r
.60967 .63907 m .61303 .6365 L .60976 .63698 L F
.561 .449 .683 r
.37092 .67996 m .37269 .67715 L .37047 .67757 L F
.563 .441 .672 r
.36542 .69363 m .36765 .6933 L .36728 .6908 L F
.509 .348 .597 r
.36542 .69363 m .36756 .69577 L .36765 .6933 L F
.36542 .69363 m .36552 .69628 L .36756 .69577 L F
.151 .063 .493 r
.6175 .66923 m .61845 .66885 L .6183 .66638 L F
.438 .356 .666 r
.61736 .67162 m .61845 .66885 L .6175 .66923 L F
.525 .347 .582 r
.67631 .62334 m .6774 .62588 L .67713 .62311 L F
.67631 .62334 m .67506 .62625 L .6774 .62588 L F
0 0 0 r
.63499 .60983 m .63637 .60884 L .63729 .60763 L F
.541 .376 .607 r
.63729 .60763 m .63976 .60701 L .63928 .6042 L F
.322 0 .098 r
.63835 .60869 m .63729 .60763 L .63637 .60884 L F
.63835 .60869 m .63976 .60701 L .63729 .60763 L F
.459 .809 .998 r
.51514 .70942 m .51736 .70908 L .51895 .70979 L F
0 .199 .728 r
.51964 .70943 m .51895 .70979 L .51736 .70908 L F
.51964 .70943 m .52078 .71148 L .51895 .70979 L F
.323 .796 .918 r
.54184 .77753 m .54043 .7773 L .544 .77715 L F
0 0 .451 r
.54283 .77905 m .54184 .77753 L .544 .77715 L F
.54283 .77905 m .54228 .7805 L .54184 .77753 L F
.735 .558 .652 r
.62263 .64739 m .62092 .65013 L .62092 .64775 L F
.755 .584 .664 r
.62263 .64739 m .62484 .65056 L .62092 .65013 L F
.525 .338 .57 r
.37994 .77243 m .38168 .77441 L .38179 .77191 L F
.37994 .77243 m .37973 .77498 L .38168 .77441 L F
.166 0 0 r
.31791 .65823 m .31979 .65755 L .32072 .65641 L F
.269 0 .038 r
.32072 .65641 m .32171 .65703 L .32271 .65587 L F
.32072 .65641 m .31979 .65755 L .32171 .65703 L F
.647 .626 .815 r
.53863 .72599 m .53641 .72672 L .53509 .72423 L F
.581 .413 .618 r
.53863 .72599 m .53879 .72842 L .53641 .72672 L F
.346 .026 .273 r
.36725 .7115 m .36615 .70989 L .36822 .70952 L F
.36725 .7115 m .36532 .71212 L .36615 .70989 L F
.587 .655 .884 r
.414 .77696 m .41738 .77816 L .41514 .77857 L F
.583 .272 .407 r
.41001 .7339 m .41241 .73397 L .4133 .73148 L F
.54 .229 .389 r
.4133 .73148 m .41513 .73299 L .41559 .73146 L F
.4133 .73148 m .41241 .73397 L .41513 .73299 L F
.515 .813 .999 r
.36895 .80214 m .37242 .80246 L .37087 .80159 L F
.36895 .80214 m .37242 .80246 L .37087 .80159 L F
.607 .847 .989 r
.37428 .80172 m .37242 .80246 L .37087 .80159 L F
.37428 .80172 m .37242 .80246 L .37087 .80159 L F
.587 .454 .667 r
.38815 .7476 m .39015 .74486 L .38803 .74523 L F
.587 .322 .482 r
.41446 .75033 m .41475 .75311 L .41148 .75295 L F
.494 .226 .436 r
.41699 .7501 m .41475 .75311 L .41446 .75033 L F
.143 0 0 r
.59734 .64477 m .59843 .64562 L .59902 .64449 L F
.59734 .64477 m .59634 .64639 L .59843 .64562 L F
.494 .312 .563 r
.40765 .65806 m .4077 .66035 L .40576 .65853 L F
.40765 .65806 m .4077 .66035 L .40576 .65853 L F
.512 .768 .989 r
.38443 .65807 m .38336 .65923 L .38227 .65811 L F
.38443 .65807 m .38555 .65883 L .38336 .65923 L F
.586 .577 .81 r
.38614 .6604 m .38336 .65923 L .38555 .65883 L F
0 0 0 r
.53644 .73782 m .53585 .73893 L .5375 .73669 L F
.064 0 0 r
.43459 .77572 m .43577 .7753 L .4341 .77545 L F
.785 .356 .231 r
.55727 .70745 m .56055 .70922 L .56085 .70793 L F
.55727 .70745 m .55949 .71011 L .56055 .70922 L F
.693 .595 .742 r
.56085 .70793 m .56055 .70922 L .56288 .70706 L F
.566 .086 0 r
.56158 .71052 m .56055 .70922 L .55949 .71011 L F
.56158 .71052 m .56283 .71193 L .56055 .70922 L F
0 0 0 r
.59641 .66205 m .59611 .66195 L .59764 .65982 L F
.59641 .66205 m .59488 .66324 L .59611 .66195 L F
.561 .449 .683 r
.37092 .67996 m .37294 .67952 L .37269 .67715 L F
.615 .47 .661 r
.37095 .68263 m .37294 .67952 L .37092 .67996 L F
.721 .58 .696 r
.58501 .69327 m .58825 .6937 L .58829 .6913 L F
.649 .52 .693 r
.58829 .6913 m .58825 .6937 L .5907 .69327 L F
.578 .389 .59 r
.63928 .6042 m .64169 .60413 L .64162 .60164 L F
.314 .087 .401 r
.63976 .60701 m .64169 .60413 L .63928 .6042 L F
.455 .182 .409 r
.42469 .74519 m .4241 .7472 L .42209 .74747 L F
.422 0 .093 r
.42724 .74577 m .4241 .7472 L .42469 .74519 L F
.185 0 0 r
.37008 .6526 m .37221 .65289 L .37356 .6529 L F
0 .085 .644 r
.37433 .65305 m .37356 .6529 L .37221 .65289 L F
.37433 .65305 m .37543 .65512 L .37356 .6529 L F
.488 .362 .635 r
.39665 .79728 m .39885 .79643 L .39531 .79578 L F
.39665 .79728 m .39862 .79864 L .39885 .79643 L F
.559 0 0 r
.33802 .64927 m .34113 .65037 L .33908 .6504 L F
.509 0 0 r
.45119 .72488 m .4531 .72554 L .4545 .72532 L F
.521 0 0 r
.4531 .72554 m .45651 .72603 L .4545 .72532 L F
.582 .944 .843 r
.68422 .57718 m .68002 .57891 L .68213 .57888 L F
.008 0 0 r
.68633 .57621 m .68422 .57718 L .68213 .57888 L F
.52 .309 .534 r
.5942 .70735 m .59404 .70963 L .59189 .71007 L F
.606 .425 .61 r
.59641 .70683 m .59404 .70963 L .5942 .70735 L F
.699 .474 .579 r
.71602 .73403 m .7172 .73631 L .71856 .73435 L F
.464 .441 .748 r
.71856 .73435 m .72057 .73488 L .71978 .73089 L F
.774 .688 .769 r
.7172 .73631 m .72057 .73488 L .71856 .73435 L F
.332 0 0 r
.38394 .79822 m .38453 .79869 L .38197 .79905 L F
.566 .349 .545 r
.38453 .79869 m .38401 .801 L .38197 .79905 L F
.68 .792 .934 r
.38654 .80031 m .38401 .801 L .38453 .79869 L F
0 .129 .612 r
.38565 .79958 m .38453 .79869 L .38315 .79808 L F
.38623 .79993 m .38654 .80031 L .38453 .79869 L F
.38623 .79993 m .38453 .79869 L .38565 .79958 L F
.332 0 0 r
.38502 .79776 m .38453 .79869 L .38394 .79822 L F
.428 .409 .736 r
.38502 .79776 m .38415 .79586 L .38453 .79869 L F
.38502 .79776 m .38666 .79575 L .38415 .79586 L F
.755 .558 .629 r
.62092 .65013 m .62484 .65056 L .62436 .65282 L F
.545 .377 .605 r
.64162 .60164 m .64408 .60109 L .64359 .59881 L F
.529 .346 .577 r
.64169 .60413 m .64408 .60109 L .64162 .60164 L F
.519 .387 .641 r
.37875 .78033 m .38075 .78256 L .3808 .77999 L F
.37875 .78033 m .37907 .78312 L .38075 .78256 L F
.528 .382 .626 r
.70342 .71276 m .70507 .71497 L .70522 .71239 L F
0 0 .234 r
.52243 .73056 m .52201 .73333 L .52103 .73445 L F
.136 .302 .768 r
.52103 .73445 m .5232 .73633 L .52201 .73333 L F
0 0 0 r
.71248 .61729 m .71489 .61562 L .71502 .61695 L F
.785 .576 .618 r
.71869 .61524 m .71502 .61695 L .71489 .61562 L F
.462 .269 .532 r
.40022 .67438 m .39813 .6772 L .398 .67484 L F
.553 .561 .817 r
.3884 .66013 m .38658 .66182 L .38614 .6604 L F
.3884 .66013 m .38947 .66298 L .38658 .66182 L F
.434 .008 .129 r
.53742 .78338 m .53629 .78513 L .53393 .78531 L F
.24 0 .023 r
.5383 .78454 m .53742 .78338 L .53959 .78286 L F
.5383 .78454 m .53629 .78513 L .53742 .78338 L F
.375 0 .041 r
.43026 .74486 m .42867 .74669 L .42724 .74577 L F
.335 0 .004 r
.43238 .74468 m .42867 .74669 L .43026 .74486 L F
.882 .92 .846 r
.56083 .68096 m .55862 .68354 L .55873 .68138 L F
.899 .931 .828 r
.55873 .68138 m .55862 .68354 L .55638 .68447 L F
.466 .082 .225 r
.45319 .74114 m .45127 .74023 L .45453 .7388 L F
.545 .195 .325 r
.45666 .73854 m .45319 .74114 L .45453 .7388 L F
.683 .604 .761 r
.72463 .72129 m .72503 .72374 L .72745 .72347 L F
.026 0 0 r
.72395 .72574 m .72745 .72347 L .72503 .72374 L F
0 .008 .544 r
.72748 .73374 m .7283 .73615 L .72713 .73687 L F
.377 .102 .364 r
.72925 .73839 m .72713 .73687 L .7283 .73615 L F
.72925 .73839 m .72716 .73927 L .72713 .73687 L F
.333 0 .081 r
.59841 .65927 m .59723 .66093 L .59764 .65982 L F
0 0 0 r
.59883 .65963 m .59841 .65927 L .59996 .65771 L F
.59883 .65963 m .59723 .66093 L .59841 .65927 L F
.331 .562 .921 r
.48223 .73596 m .48323 .73538 L .48177 .73555 L F
.48223 .73596 m .48445 .73698 L .48323 .73538 L F
.783 .746 .819 r
.70574 .58775 m .70644 .59089 L .70343 .59014 L F
.699 .429 .512 r
.70644 .59089 m .70323 .59307 L .70343 .59014 L F
.70644 .59089 m .70685 .59301 L .70323 .59307 L F
.856 .788 .784 r
.7091 .5856 m .70644 .59089 L .70574 .58775 L F
.757 .554 .622 r
.57919 .73984 m .57551 .74197 L .57513 .73975 L F
.57919 .73984 m .57893 .74211 L .57551 .74197 L F
.433 .039 .189 r
.35534 .70416 m .3576 .70384 L .3588 .70198 L F
.353 0 .177 r
.3576 .70384 m .36073 .70142 L .3588 .70198 L F
.045 .573 .862 r
.47356 .77246 m .47289 .77276 L .47131 .77272 L F
.47356 .77246 m .4748 .77296 L .47289 .77276 L F
.785 .576 .618 r
.71869 .61524 m .71853 .61758 L .71502 .61695 L F
.698 .507 .625 r
.58501 .69327 m .58824 .69596 L .58825 .6937 L F
.66 .444 .58 r
.58825 .6937 m .59105 .69521 L .5907 .69327 L F
.58825 .6937 m .58824 .69596 L .59105 .69521 L F
.168 0 .019 r
.48608 .73101 m .48611 .73177 L .48377 .7327 L F
.819 .778 .814 r
.48608 .73101 m .48377 .7327 L .48611 .73177 L F
.704 .909 .967 r
.49951 .71475 m .50016 .713 L .50192 .71326 L F
.49951 .71475 m .4983 .71411 L .50016 .713 L F
.181 0 0 r
.35922 .71601 m .35779 .71758 L .35614 .71751 L F
.175 0 0 r
.3567 .71874 m .35614 .71751 L .35779 .71758 L F
.3567 .71874 m .35481 .71932 L .35614 .71751 L F
.561 .318 .506 r
.31627 .68827 m .31579 .69048 L .31401 .69057 L F
.37 .036 .262 r
.31876 .68805 m .31579 .69048 L .31627 .68827 L F
.939 .576 .187 r
.69911 .62333 m .69953 .62536 L .70045 .62595 L F
.782 .762 .835 r
.69953 .62536 m .69999 .62801 L .70045 .62595 L F
.687 .612 .766 r
.69911 .62333 m .70045 .62595 L .70281 .62341 L F
.698 .629 .776 r
.70281 .62341 m .70045 .62595 L .70258 .62545 L F
.69 .687 .842 r
.69138 .61198 m .68829 .60997 L .69034 .60888 L F
.69 .689 .844 r
.69365 .60962 m .69138 .61198 L .69034 .60888 L F
.327 .812 .811 r
.48961 .7291 m .489 .72954 L .49119 .72913 L F
.48961 .7291 m .48731 .72978 L .489 .72954 L F
.461 .313 .592 r
.39674 .73656 m .39882 .73872 L .40014 .7372 L F
.096 0 0 r
.40014 .7372 m .40082 .73803 L .40232 .73686 L F
.40014 .7372 m .39882 .73872 L .40082 .73803 L F
.52 .328 .56 r
.40014 .7372 m .40232 .73686 L .40254 .73417 L F
.561 .381 .595 r
.384 .75313 m .3861 .75285 L .38618 .75047 L F
.52 .396 .651 r
.384 .75313 m .3862 .75516 L .3861 .75285 L F
.384 .75313 m .38417 .75633 L .3862 .75516 L F
.858 .943 .874 r
.56211 .67963 m .56083 .68096 L .55873 .68138 L F
.813 .798 .837 r
.70852 .60757 m .70471 .609 L .70737 .60757 L F
.893 .961 .832 r
.70852 .60757 m .70737 .60757 L .70847 .60584 L F
.388 .503 .854 r
.35868 .80548 m .36095 .80657 L .35966 .80393 L F
.504 .26 .478 r
.59189 .71007 m .59166 .7122 L .58945 .71259 L F
.52 .283 .496 r
.59404 .70963 m .59166 .7122 L .59189 .71007 L F
.144 0 0 r
.4384 .7853 m .43485 .78646 L .43627 .78562 L F
.256 .353 .771 r
.68686 .71508 m .68796 .71416 L .68585 .71186 L F
.137 .145 .604 r
.68686 .71508 m .68826 .71759 L .68796 .71416 L F
.17 .652 .927 r
.71975 .73989 m .71882 .73935 L .71655 .73911 L F
.534 .866 .994 r
.72108 .73873 m .71882 .73935 L .71975 .73989 L F
.241 .718 .937 r
.46738 .77211 m .46942 .77291 L .46724 .77294 L F
.601 .512 .725 r
.70069 .72013 m .69951 .72454 L .69844 .72063 L F
.70069 .72013 m .70187 .72415 L .69951 .72454 L F
.723 .696 .824 r
.70827 .62354 m .71171 .62426 L .7105 .62274 L F
.697 .748 .891 r
.7105 .62274 m .71171 .62426 L .71381 .62328 L F
.088 0 .176 r
.63286 .61254 m .63455 .61155 L .63499 .60983 L F
.708 .492 .593 r
.63156 .61382 m .63455 .61155 L .63286 .61254 L F
.513 .137 .264 r
.60979 .65446 m .60771 .65328 L .60989 .65268 L F
.60979 .65446 m .6065 .65509 L .60771 .65328 L F
.696 .25 .19 r
.68709 .61489 m .68634 .61623 L .68403 .61448 L F
.587 .619 .85 r
.38037 .78817 m .38144 .78569 L .37935 .78581 L F
.38037 .78817 m .38277 .78818 L .38144 .78569 L F
.664 .477 .622 r
.37977 .79031 m .38277 .78818 L .38037 .78817 L F
.526 .313 .533 r
.61156 .69636 m .61165 .69858 L .60916 .69896 L F
.617 .382 .538 r
.61156 .69636 m .61394 .69847 L .61165 .69858 L F
.668 .367 .454 r
.61431 .69671 m .61394 .69847 L .61156 .69636 L F
.254 .284 .7 r
.72836 .60285 m .72679 .6043 L .72639 .60118 L F
.321 .395 .782 r
.72836 .60285 m .72927 .60612 L .72679 .6043 L F
.398 .788 .989 r
.43128 .75532 m .43489 .75576 L .43261 .75602 L F
.422 0 .093 r
.42724 .74577 m .42651 .747 L .4241 .7472 L F
.366 0 .065 r
.42724 .74577 m .42867 .74669 L .42651 .747 L F
.326 .104 .416 r
.29326 .62545 m .29122 .62806 L .29175 .62626 L F
.313 .489 .872 r
.69083 .72336 m .69209 .72222 L .68939 .72083 L F
.236 .358 .785 r
.69083 .72336 m .69329 .72528 L .69209 .72222 L F
.79 .292 0 r
.50903 .79112 m .51044 .7917 L .50998 .79256 L F
.576 .015 0 r
.50998 .79256 m .51044 .7917 L .51292 .7931 L F
.983 .716 .332 r
.67575 .59506 m .67648 .59575 L .6762 .59353 L F
0 0 0 r
.67575 .59506 m .6762 .59353 L .67744 .59131 L F
.938 .888 .756 r
.67478 .59416 m .67575 .59506 L .67744 .59131 L F
.518 0 0 r
.67497 .59433 m .67575 .59506 L .67478 .59416 L F
.983 .716 .332 r
.67575 .59506 m .6765 .59598 L .67648 .59575 L F
.032 .377 .842 r
.67822 .59621 m .6765 .59598 L .67575 .59506 L F
.67822 .59621 m .67921 .59771 L .6765 .59598 L F
.518 0 0 r
.67718 .59623 m .67822 .59621 L .67782 .59602 L F
.67718 .59623 m .67782 .59602 L .67575 .59506 L F
.989 .731 .369 r
.67655 .59643 m .67718 .59623 L .67615 .59495 L F
.67714 .59864 m .67718 .59623 L .67655 .59643 L F
.518 0 0 r
.67718 .59623 m .67575 .59506 L .67497 .59433 L F
.955 .786 .634 r
.58479 .68377 m .58254 .68707 L .58334 .68519 L F
.97 .851 .667 r
.58479 .68377 m .58334 .68519 L .58357 .68398 L F
.876 .698 .658 r
.58085 .68632 m .58357 .68398 L .58158 .68382 L F
.58085 .68632 m .58281 .68477 L .58357 .68398 L F
.918 .791 .705 r
.58357 .68398 m .58334 .68519 L .58281 .68477 L F
.876 .698 .658 r
.58281 .68477 m .58348 .68424 L .58357 .68398 L F
.918 .791 .705 r
.58357 .68398 m .58281 .68477 L .58158 .68382 L F
.883 .678 .621 r
.58281 .68477 m .58085 .68632 L .58158 .68382 L F
.58334 .68519 m .58085 .68632 L .58281 .68477 L F
.58334 .68519 m .58254 .68707 L .58085 .68632 L F
.876 .698 .658 r
.58085 .68632 m .58254 .68707 L .58348 .68424 L F
.972 .833 .647 r
.58357 .68398 m .58254 .68707 L .58479 .68377 L F
.555 .438 .674 r
.3828 .76132 m .38451 .75852 L .38247 .75891 L F
.98 .702 .422 r
.63499 .60983 m .63455 .61155 L .63375 .6089 L F
.351 .473 .844 r
.636 .60817 m .63637 .60884 L .63499 .60983 L F
.642 .854 .981 r
.63375 .6089 m .636 .60817 L .63499 .60983 L F
.641 .553 .74 r
.63455 .61155 m .636 .60817 L .63499 .60983 L F
.73 .221 0 r
.50903 .79112 m .50599 .78798 L .50721 .78877 L F
.156 .635 .925 r
.27728 .60023 m .27735 .6008 L .27583 .6004 L F
.262 .749 .921 r
.27932 .60101 m .27735 .6008 L .27919 .60101 L F
.156 .635 .925 r
.27728 .60023 m .27919 .60101 L .27735 .6008 L F
.748 .757 .86 r
.43014 .75449 m .43043 .75463 L .43134 .75291 L F
.154 .044 .466 r
.43043 .75463 m .43128 .75532 L .43134 .75291 L F
.469 .033 .128 r
.58243 .67998 m .58111 .68174 L .57956 .68143 L F
.773 .993 .78 r
.58298 .67869 m .58243 .67998 L .58493 .6774 L F
.73 .888 .494 r
.58298 .67869 m .58111 .68174 L .58243 .67998 L F
.706 .581 .713 r
.57643 .71482 m .57856 .7178 L .57849 .71528 L F
.57689 .71546 m .57647 .71811 L .57856 .7178 L F
.57643 .71482 m .57644 .71536 L .57689 .71546 L F
.57644 .71536 m .57647 .71811 L .57689 .71546 L F
.438 .271 .556 r
.57849 .71528 m .57856 .7178 L .58072 .71701 L F
.637 .153 .088 r
.57813 .71573 m .58072 .71701 L .57803 .71674 L F
.57945 .71602 m .58072 .71701 L .57813 .71573 L F
.395 .176 .46 r
.57856 .7178 m .57859 .71973 L .58072 .71701 L F
.718 .604 .729 r
.58072 .71701 m .57859 .71973 L .57736 .71718 L F
.58072 .71701 m .57736 .71718 L .57738 .71668 L F
.023 0 .029 r
.57802 .71678 m .57851 .7179 L .57927 .71603 L F
.57736 .71718 m .57796 .71755 L .57802 .71678 L F
.57796 .71755 m .57851 .7179 L .57802 .71678 L F
.637 .153 .088 r
.57811 .71576 m .57803 .71674 L .57738 .71668 L F
.57813 .71573 m .57803 .71674 L .57811 .71576 L F
.57849 .71528 m .57945 .71602 L .57813 .71573 L F
.57849 .71528 m .57738 .71668 L .57704 .71417 L F
.403 .202 .491 r
.38083 .76404 m .38255 .76361 L .3828 .76132 L F
.584 .503 .729 r
.38082 .76649 m .38255 .76361 L .38083 .76404 L F
.259 .458 .865 r
.69688 .71801 m .69542 .71773 L .69384 .71513 L F
.692 .644 .798 r
.55727 .70745 m .56085 .70793 L .55939 .70482 L F
.711 .653 .791 r
.55939 .70482 m .56085 .70793 L .56288 .70706 L F
.548 .341 .552 r
.61165 .69858 m .60973 .69965 L .60916 .69896 L F
.716 .84 .941 r
.69691 .6097 m .69365 .60962 L .69591 .60883 L F
.696 .877 .966 r
.69916 .60882 m .69691 .6097 L .69591 .60883 L F
.821 .785 .819 r
.69799 .61927 m .69708 .62028 L .69927 .62053 L F
.85 .668 .656 r
.69627 .62249 m .69927 .62053 L .69708 .62028 L F
.69627 .62249 m .69911 .62333 L .69927 .62053 L F
.518 .556 .834 r
.69927 .62053 m .70084 .61858 L .69799 .61927 L F
.69927 .62053 m .70152 .62029 L .70084 .61858 L F
.685 .624 .781 r
.69911 .62333 m .70152 .62029 L .69927 .62053 L F
.729 .659 .781 r
.72064 .72047 m .72176 .72346 L .72463 .72129 L F
.603 .353 .512 r
.4241 .7472 m .42123 .74984 L .42209 .74747 L F
.682 .714 .873 r
.41023 .76177 m .41206 .76399 L .40831 .76332 L F
.738 .623 .731 r
.41206 .76399 m .40946 .76669 L .40831 .76332 L F
.638 .466 .634 r
.41208 .76635 m .40946 .76669 L .41206 .76399 L F
.643 .549 .733 r
.41134 .75718 m .41314 .7629 L .4105 .76189 L F
.537 .466 .724 r
.4136 .75717 m .41319 .7629 L .41134 .75718 L F
.41319 .7629 m .41319 .76303 L .41314 .7629 L F
.41319 .7629 m .41314 .7629 L .41134 .75718 L F
.4136 .75717 m .41524 .76273 L .41516 .76274 L F
.4136 .75717 m .41491 .76185 L .41319 .7629 L F
.41491 .76185 m .41516 .76274 L .41401 .76284 L F
.41491 .76185 m .41401 .76284 L .41319 .7629 L F
.69 .709 .862 r
.41578 .76325 m .41344 .76364 L .41336 .76355 L F
.4148 .76302 m .41401 .76284 L .41554 .76307 L F
.41401 .76284 m .41247 .76248 L .41424 .76282 L F
.41401 .76284 m .41424 .76282 L .41554 .76307 L F
.537 .466 .724 r
.41319 .7629 m .41516 .76274 L .41319 .76303 L F
.643 .549 .733 r
.41314 .7629 m .41319 .76303 L .41282 .76288 L F
.478 .768 .995 r
.41319 .76303 m .41352 .76285 L .41247 .76248 L F
.69 .709 .862 r
.41401 .76284 m .41388 .76298 L .41247 .76248 L F
.41511 .76275 m .41247 .76248 L .41452 .76231 L F
.478 .768 .995 r
.41352 .76285 m .41452 .76231 L .41247 .76248 L F
.69 .709 .862 r
.41388 .76298 m .41336 .76355 L .41247 .76248 L F
.41578 .76325 m .41336 .76355 L .41401 .76284 L F
.41537 .76294 m .41448 .7628 L .41511 .76275 L F
.41448 .7628 m .41247 .76248 L .41511 .76275 L F
.41554 .76307 m .41482 .76293 L .41537 .76294 L F
.41482 .76293 m .41247 .76248 L .41537 .76294 L F
.41578 .76325 m .4148 .76302 L .41554 .76307 L F
.643 .549 .733 r
.41314 .7629 m .41282 .76288 L .4105 .76189 L F
.41024 .76173 m .4105 .76189 L .41023 .76177 L F
.41134 .75718 m .4105 .76189 L .41024 .76173 L F
.316 .547 .915 r
.41233 .76297 m .41344 .76364 L .41206 .76399 L F
.41247 .76248 m .41342 .76362 L .41233 .76297 L F
.41342 .76362 m .41344 .76364 L .41233 .76297 L F
.127 .542 .92 r
.41023 .76177 m .41319 .76303 L .41247 .76248 L F
.316 .547 .915 r
.41247 .76248 m .41206 .76399 L .41023 .76177 L F
.355 .287 .641 r
.41344 .76364 m .41208 .76635 L .41206 .76399 L F
0 0 0 r
.33175 .73188 m .3314 .73176 L .33317 .73098 L F
.33175 .73188 m .32955 .7327 L .3314 .73176 L F
.534 .557 .824 r
.72189 .58773 m .72313 .59062 L .72093 .59089 L F
.616 .545 .752 r
.7242 .59366 m .72093 .59089 L .72313 .59062 L F
.046 0 0 r
.35956 .71682 m .35922 .71601 L .36085 .71489 L F
.35956 .71682 m .35779 .71758 L .35922 .71601 L F
.537 .709 .951 r
.56288 .70706 m .56551 .70785 L .56505 .7067 L F
.188 .356 .801 r
.56551 .70785 m .5677 .70836 L .56505 .7067 L F
.56551 .70785 m .56815 .71008 L .5677 .70836 L F
.266 0 0 r
.34113 .65037 m .34279 .65071 L .34455 .65027 L F
.58 .943 .842 r
.34455 .65027 m .34279 .65071 L .34528 .64938 L F
.372 .265 .601 r
.64359 .59881 m .64578 .6004 L .64698 .59855 L F
.64359 .59881 m .64408 .60109 L .64578 .6004 L F
.472 .284 .544 r
.36556 .80238 m .36768 .79874 L .36691 .79957 L F
.63 .848 .983 r
.40461 .73326 m .40254 .73417 L .40093 .73333 L F
.40461 .73326 m .40254 .73417 L .40093 .73333 L F
.56 .362 .569 r
.40254 .73417 m .40447 .73652 L .40461 .73326 L F
.40254 .73417 m .40232 .73686 L .40447 .73652 L F
.494 .138 .292 r
.45838 .77247 m .46077 .77239 L .46159 .77087 L F
.643 .47 .634 r
.46159 .77087 m .46381 .77203 L .4637 .76961 L F
.125 .674 .739 r
.46077 .77239 m .46381 .77203 L .46159 .77087 L F
0 0 0 r
.57849 .66357 m .58004 .66267 L .58128 .6612 L F
.58128 .6612 m .58248 .65993 L .58306 .65824 L F
.58128 .6612 m .58004 .66267 L .58248 .65993 L F
.51 .3 .53 r
.36073 .70142 m .36299 .69872 L .36086 .69907 L F
.528 .355 .591 r
.59847 .70404 m .59641 .70683 L .59628 .70445 L F
.462 0 0 r
.46657 .77954 m .46494 .78012 L .46283 .77988 L F
.325 0 0 r
.4686 .7796 m .46494 .78012 L .46657 .77954 L F
.639 .508 .687 r
.3762 .79459 m .37889 .79453 L .37813 .79104 L F
.791 .762 .827 r
.39862 .79864 m .40025 .80014 L .40182 .79835 L F
.584 .434 .644 r
.30401 .69896 m .30191 .70174 L .30184 .69941 L F
.561 .389 .605 r
.3861 .75285 m .38836 .75003 L .38618 .75047 L F
.772 .495 .517 r
.57513 .73975 m .57551 .74197 L .57214 .74162 L F
.204 .731 .823 r
.49436 .72886 m .49321 .72883 L .49119 .72913 L F
0 0 0 r
.49675 .7268 m .49566 .72814 L .49436 .72886 L F
.394 .85 .891 r
.49566 .72814 m .49321 .72883 L .49436 .72886 L F
.796 .893 .913 r
.50729 .71181 m .50416 .71244 L .50601 .71112 L F
.709 .903 .965 r
.50973 .71046 m .50729 .71181 L .50601 .71112 L F
.706 .702 .844 r
.6604 .61206 m .66385 .61286 L .6629 .6114 L F
.686 .767 .912 r
.6629 .6114 m .66385 .61286 L .66605 .61161 L F
.59 .83 .99 r
.51328 .71068 m .50973 .71046 L .5118 .71 L F
.096 0 0 r
.5118 .71 m .51514 .70942 L .51328 .71068 L F
.962 .704 .5 r
.71089 .59609 m .71132 .59859 L .71007 .59724 L F
0 0 0 r
.71089 .59609 m .71007 .59724 L .712 .59499 L F
.962 .704 .5 r
.71089 .59609 m .71132 .59859 L .71007 .59724 L F
.701 .577 .713 r
.71415 .58754 m .71191 .59078 L .71094 .58634 L F
.586 .355 .533 r
.61512 .63658 m .61757 .63636 L .6178 .63416 L F
.137 0 .395 r
.6178 .63416 m .61881 .63508 L .61923 .63332 L F
.6178 .63416 m .61757 .63636 L .61881 .63508 L F
.643 .224 .235 r
.7206 .71802 m .72037 .71936 L .71726 .71803 L F
.916 .708 .211 r
.72062 .71928 m .72064 .72047 L .72037 .71936 L F
.277 .479 .876 r
.72037 .71936 m .72064 .72047 L .72176 .71951 L F
.127 0 0 r
.72176 .71951 m .72006 .71945 L .72037 .71936 L F
.72006 .71945 m .71882 .71942 L .72037 .71936 L F
.916 .708 .211 r
.7206 .71802 m .72062 .71928 L .72037 .71936 L F
0 0 0 r
.57849 .66357 m .57756 .66508 L .58004 .66267 L F
.195 0 0 r
.45678 .72598 m .45871 .72592 L .45986 .72546 L F
.112 0 0 r
.4574 .72564 m .46054 .72586 L .45871 .72592 L F
.164 0 0 r
.45871 .72592 m .46081 .72588 L .46202 .72556 L F
.112 0 0 r
.46054 .72586 m .46081 .72588 L .45871 .72592 L F
.195 0 0 r
.45651 .72603 m .45871 .72592 L .45678 .72598 L F
.164 0 0 r
.45871 .72592 m .46202 .72556 L .45986 .72546 L F
.357 .584 .929 r
.3775 .65529 m .37684 .65688 L .37543 .65512 L F
.3775 .65529 m .37888 .65707 L .37684 .65688 L F
.671 .534 .688 r
.29575 .67173 m .2961 .67462 L .29826 .67184 L F
.719 .344 .339 r
.49965 .77971 m .50146 .78042 L .50323 .77965 L F
.588 .114 .095 r
.50146 .78042 m .5046 .78051 L .50323 .77965 L F
0 .009 .559 r
.55722 .70541 m .55806 .70642 L .55727 .70745 L F
0 .03 .587 r
.55842 .70833 m .55727 .70745 L .55806 .70642 L F
.55842 .70833 m .55949 .71011 L .55727 .70745 L F
.585 .787 .976 r
.70191 .58921 m .70131 .59085 L .70011 .58973 L F
.70191 .58921 m .70343 .59014 L .70131 .59085 L F
.915 .544 .306 r
.70131 .59085 m .70032 .59215 L .70011 .58973 L F
.70131 .59085 m .70167 .59276 L .70032 .59215 L F
.442 .218 .477 r
.70343 .59014 m .70167 .59276 L .70131 .59085 L F
.698 .507 .625 r
.58501 .69327 m .58604 .69615 L .58824 .69596 L F
.567 .455 .686 r
.58963 .71494 m .59009 .71697 L .5877 .71734 L F
.546 .471 .723 r
.59039 .72021 m .5877 .71734 L .59009 .71697 L F
.59039 .72021 m .58847 .72074 L .5877 .71734 L F
.226 0 0 r
.41201 .79125 m .40995 .79316 L .40851 .79324 L F
0 0 0 r
.41207 .79207 m .4133 .79112 L .41425 .79103 L F
.41352 .79166 m .41207 .79207 L .41425 .79103 L F
.41351 .79107 m .41207 .79207 L .41352 .79166 L F
.41351 .79107 m .41181 .79227 L .41207 .79207 L F
.41181 .79227 m .41174 .79232 L .41207 .79207 L F
.41207 .79207 m .41201 .79125 L .4133 .79112 L F
.41207 .79207 m .40995 .79316 L .41201 .79125 L F
.656 .617 .799 r
.40946 .76669 m .4059 .7643 L .40831 .76332 L F
.686 .478 .599 r
.61347 .65193 m .60989 .65268 L .60978 .65024 L F
.921 .54 .264 r
.64053 .65577 m .64127 .65623 L .64143 .65591 L F
.964 .875 .699 r
.64143 .65591 m .64154 .65283 L .64053 .65577 L F
.15 .693 .75 r
.38819 .83719 m .38925 .83696 L .38682 .83701 L F
.38819 .83719 m .39027 .83687 L .38925 .83696 L F
.38819 .83719 m .38925 .83696 L .38682 .83701 L F
.38819 .83719 m .39027 .83687 L .38925 .83696 L F
.431 0 .108 r
.4624 .73682 m .45878 .73872 L .45871 .73728 L F
.4624 .73682 m .46095 .73855 L .45878 .73872 L F
.613 .079 0 r
.4624 .73682 m .46307 .73833 L .46095 .73855 L F
.4624 .73682 m .46437 .73812 L .46307 .73833 L F
.307 .078 .394 r
.29483 .62476 m .29373 .62341 L .29541 .62269 L F
.29483 .62476 m .29326 .62545 L .29373 .62341 L F
.709 .457 .541 r
.6014 .68798 m .60048 .69034 L .60366 .69039 L F
.706 .457 .545 r
.6014 .68798 m .60366 .69039 L .60365 .68843 L F
.805 .803 .849 r
.68184 .6083 m .68273 .60971 L .68164 .60913 L F
.68266 .60488 m .68273 .60943 L .68184 .6083 L F
.68273 .60943 m .68273 .60971 L .68184 .6083 L F
.72 .676 .807 r
.68581 .61073 m .68305 .60984 L .68477 .6092 L F
.68305 .60984 m .68245 .60965 L .68284 .60957 L F
.68305 .60984 m .68284 .60957 L .68477 .6092 L F
.636 .755 .934 r
.68707 .60855 m .68581 .61073 L .68477 .6092 L F
.68707 .60855 m .68829 .60997 L .68581 .61073 L F
.248 .062 .42 r
.59039 .72021 m .58869 .72313 L .58847 .72074 L F
.209 .703 .92 r
.3683 .67067 m .36474 .67022 L .36606 .67134 L F
.858 .943 .874 r
.56211 .67963 m .55873 .68138 L .5613 .67914 L F
.825 .98 .885 r
.56211 .67963 m .56382 .67677 L .5648 .67739 L F
.56211 .67963 m .5613 .67914 L .56382 .67677 L F
.591 .848 .493 r
.72524 .7262 m .7241 .72748 L .72395 .72574 L F
.72524 .7262 m .72303 .7289 L .7241 .72748 L F
0 0 .513 r
.72286 .73718 m .72296 .73794 L .72329 .7369 L F
0 .118 .646 r
.72296 .73794 m .72423 .73957 L .72329 .7369 L F
.8 1 .823 r
.72329 .7369 m .72108 .73873 L .72296 .73794 L F
.494 .292 .534 r
.3923 .74212 m .39452 .73936 L .39233 .73971 L F
.653 .753 .924 r
.37428 .80172 m .37823 .80245 L .37638 .80141 L F
.696 .598 .742 r
.70258 .62545 m .70493 .62243 L .70281 .62341 L F
.70258 .62545 m .70602 .62587 L .70493 .62243 L F
.512 .866 .989 r
.57395 .70697 m .57549 .70602 L .57747 .70666 L F
.849 .489 .37 r
.57549 .70602 m .57951 .70721 L .57747 .70666 L F
.375 0 .17 r
.32787 .68361 m .32613 .68327 L .32865 .683 L F
.32787 .68361 m .32536 .6844 L .32613 .68327 L F
.4 0 .04 r
.35484 .67163 m .35335 .67324 L .35134 .67332 L F
.512 .112 .22 r
.3569 .67127 m .35335 .67324 L .35484 .67163 L F
.461 .681 .96 r
.3647 .64984 m .36463 .65141 L .36318 .64976 L F
.3647 .64984 m .3669 .6515 L .36463 .65141 L F
.59 .242 .347 r
.42316 .73077 m .42555 .73089 L .42657 .72868 L F
.434 .068 .244 r
.42555 .73089 m .42876 .72845 L .42657 .72868 L F
.667 .749 .256 r
.73368 .72177 m .73435 .72001 L .73464 .72022 L F
.73368 .72177 m .73304 .72346 L .73433 .72007 L F
.017 0 .273 r
.73397 .72171 m .73337 .72257 L .73368 .72177 L F
.792 .936 .575 r
.73368 .72177 m .73178 .72482 L .73304 .72346 L F
.017 0 .273 r
.73337 .72257 m .73178 .72482 L .73368 .72177 L F
.667 .749 .256 r
.73368 .72177 m .73433 .72007 L .73435 .72001 L F
.533 .131 .225 r
.71053 .71242 m .71287 .71331 L .71444 .71138 L F
.322 0 0 r
.71287 .71331 m .71614 .71206 L .71444 .71138 L F
.655 .769 .933 r
.32446 .71303 m .32084 .71242 L .32288 .71223 L F
.246 .757 .856 r
.32288 .71223 m .32637 .71197 L .32446 .71303 L F
.999 .819 .528 r
.57757 .68482 m .57728 .68722 L .57839 .68572 L F
.675 .605 .769 r
.71366 .58461 m .71094 .58634 L .71093 .58451 L F
.71366 .58461 m .71415 .58754 L .71094 .58634 L F
.026 0 0 r
.72395 .72574 m .72653 .72487 L .72745 .72347 L F
.703 .874 .477 r
.52932 .73044 m .52881 .73164 L .5311 .73072 L F
.697 .982 .833 r
.49383 .71681 m .49203 .71824 L .4929 .71689 L F
.601 .88 .992 r
.49203 .71824 m .4908 .71764 L .4929 .71689 L F
.424 0 .082 r
.47011 .73494 m .47118 .73631 L .46882 .73614 L F
.47011 .73494 m .47229 .73488 L .47118 .73631 L F
.622 .796 .966 r
.32084 .71242 m .31875 .71301 L .3174 .71198 L F
.321 .669 .975 r
.29384 .60335 m .29214 .60337 L .2904 .60206 L F
.524 .184 .333 r
.52493 .78212 m .52716 .78217 L .52824 .77977 L F
.366 .028 .254 r
.52824 .77977 m .52926 .7815 L .53054 .7801 L F
.52824 .77977 m .52716 .78217 L .52926 .7815 L F
0 .071 .613 r
.55116 .7169 m .54947 .71481 L .55117 .71532 L F
.737 .85 .933 r
.68274 .58549 m .68042 .58559 L .68232 .58423 L F
.68274 .58549 m .68063 .58614 L .68042 .58559 L F
.495 .651 .928 r
.68455 .58408 m .68274 .58549 L .68232 .58423 L F
.084 .09 .567 r
.68455 .58408 m .68375 .58794 L .68274 .58549 L F
.831 .66 .67 r
.58232 .74491 m .58324 .74763 L .58208 .74709 L F
.829 .582 .565 r
.5835 .74919 m .58208 .74709 L .58324 .74763 L F
.686 .465 .58 r
.58324 .74763 m .58565 .75013 L .5835 .74919 L F
.7 .463 .562 r
.58567 .74777 m .58565 .75013 L .58324 .74763 L F
.717 .484 .571 r
.70446 .71806 m .70419 .72029 L .70249 .71712 L F
.70446 .71806 m .70615 .72032 L .70419 .72029 L F
.588 .427 .631 r
.4637 .76961 m .46381 .77203 L .466 .76937 L F
.416 .056 .244 r
.30467 .66844 m .30787 .66596 L .30568 .66611 L F
.719 .635 .763 r
.71682 .58474 m .71415 .58754 L .71366 .58461 L F
.687 .592 .744 r
.70493 .62243 m .70602 .62587 L .70827 .62354 L F
.653 .529 .7 r
.30191 .70174 m .29986 .70443 L .29981 .70419 L F
.30191 .70174 m .30216 .70432 L .29986 .70443 L F
.637 .421 .573 r
.29986 .70443 m .30184 .70602 L .29983 .70682 L F
.29986 .70443 m .30216 .70432 L .30184 .70602 L F
.756 .713 .812 r
.3808 .7935 m .38429 .79383 L .38298 .79108 L F
.728 .758 .876 r
.3808 .7935 m .38192 .79443 L .38429 .79383 L F
.62 .333 .461 r
.38192 .79443 m .38415 .79586 L .38429 .79383 L F
.581 .628 .863 r
.38298 .79108 m .38429 .79383 L .38639 .79347 L F
.687 .493 .619 r
.38415 .79586 m .38639 .79347 L .38429 .79383 L F
.86 .583 .518 r
.68406 .62817 m .68237 .62958 L .68133 .62803 L F
.377 .185 .488 r
.68233 .63126 m .68416 .63072 L .68406 .62817 L F
.835 .539 .489 r
.68237 .62958 m .68416 .63072 L .68406 .62817 L F
.458 .671 .955 r
.68406 .62817 m .6862 .62805 L .68485 .62675 L F
.728 .962 .688 r
.68485 .62675 m .68237 .62958 L .68406 .62817 L F
.483 .263 .503 r
.68406 .62817 m .68416 .63072 L .6862 .62805 L F
.076 .28 .766 r
.58653 .74659 m .58789 .74951 L .58567 .74777 L F
.485 .291 .541 r
.58789 .74951 m .58565 .75013 L .58567 .74777 L F
.685 .808 .941 r
.37889 .79453 m .38192 .79443 L .3808 .7935 L F
.733 .686 .805 r
.68482 .59421 m .68517 .59607 L .68233 .59586 L F
.379 .434 .792 r
.68506 .59473 m .68517 .59607 L .68492 .59473 L F
.724 .705 .832 r
.68233 .59586 m .68517 .59607 L .68506 .59473 L F
.313 0 .074 r
.68233 .59586 m .68506 .59473 L .68372 .59696 L F
.724 .705 .832 r
.68506 .59473 m .68517 .59607 L .68544 .59457 L F
.313 0 .074 r
.68506 .59473 m .68544 .59457 L .68532 .59474 L F
.68506 .59473 m .68532 .59474 L .68372 .59696 L F
.379 .434 .792 r
.68502 .59428 m .68506 .59473 L .68482 .59421 L F
.68506 .59473 m .68492 .59473 L .68482 .59421 L F
.313 .307 .692 r
.68544 .59457 m .68517 .59607 L .68687 .59491 L F
.379 .434 .792 r
.68687 .59491 m .68517 .59607 L .68505 .59471 L F
.382 0 .116 r
.68372 .59696 m .68532 .59474 L .68687 .59491 L F
.68532 .59474 m .68544 .59457 L .68687 .59491 L F
.379 .434 .792 r
.68687 .59491 m .68505 .59471 L .68502 .59428 L F
.983 .723 .453 r
.56606 .70086 m .56723 .70395 L .56732 .70176 L F
.488 .797 .999 r
.56732 .70176 m .56832 .70049 L .56606 .70086 L F
.56732 .70176 m .56979 .70144 L .56832 .70049 L F
.516 .283 .501 r
.56723 .70395 m .56979 .70144 L .56732 .70176 L F
.477 0 0 r
.69392 .72651 m .69524 .7276 L .69329 .72528 L F
.69392 .72651 m .69635 .72814 L .69524 .7276 L F
.601 .551 .771 r
.72704 .59333 m .72469 .59559 L .7242 .59366 L F
.72704 .59333 m .72713 .5962 L .72469 .59559 L F
.648 .554 .735 r
.72713 .5962 m .72559 .5989 L .72469 .59559 L F
0 0 0 r
.4432 .7755 m .44695 .77422 L .44507 .77489 L F
.545 .32 .524 r
.73372 .61178 m .7361 .61384 L .73441 .61498 L F
0 0 0 r
.73354 .61628 m .73441 .61498 L .7361 .61384 L F
.416 .027 .191 r
.30813 .74234 m .31018 .74212 L .30807 .74243 L F
0 0 .334 r
.31925 .73752 m .31873 .73708 L .31946 .73624 L F
.31925 .73752 m .31846 .73943 L .31873 .73708 L F
0 0 .45 r
.66902 .59193 m .66828 .59311 L .66893 .59546 L F
.765 .35 .262 r
.51173 .78298 m .51367 .78522 L .51518 .78499 L F
.893 .502 .279 r
.5111 .78216 m .51367 .78522 L .51173 .78298 L F
.564 .371 .578 r
.60671 .68812 m .6089 .68778 L .60893 .68546 L F
.509 .318 .556 r
.60893 .68546 m .61091 .68497 L .61102 .68271 L F
.494 .315 .567 r
.60893 .68546 m .61062 .68727 L .61091 .68497 L F
.60893 .68546 m .6089 .68778 L .61062 .68727 L F
.589 .326 .486 r
.60387 .70142 m .60083 .70382 L .6014 .70144 L F
.808 .448 .375 r
.3069 .73676 m .30696 .73689 L .30681 .73686 L F
.958 .721 .536 r
.3069 .73676 m .30553 .73455 L .30602 .73405 L F
.3069 .73676 m .30681 .73686 L .30553 .73455 L F
.759 .66 .753 r
.68538 .63413 m .68852 .63458 L .68744 .6313 L F
.723 .641 .766 r
.68744 .6313 m .68852 .63458 L .69048 .6337 L F
0 .322 .675 r
.69949 .72951 m .69635 .72814 L .69762 .72853 L F
.699 .451 .546 r
.60365 .68843 m .60681 .69027 L .60671 .68812 L F
.60365 .68843 m .60366 .69039 L .60681 .69027 L F
.711 .653 .791 r
.55939 .70482 m .56288 .70706 L .56176 .70399 L F
.806 .329 .08 r
.56505 .7067 m .56176 .70399 L .56288 .70706 L F
.634 .451 .618 r
.39455 .73699 m .39452 .73936 L .39674 .73656 L F
.589 .448 .658 r
.59166 .7122 m .58963 .71494 L .58945 .71259 L F
.555 .438 .674 r
.3828 .76132 m .38489 .76095 L .38451 .75852 L F
.493 .269 .502 r
.38255 .76361 m .38489 .76095 L .3828 .76132 L F
.439 .351 .66 r
.68233 .63126 m .68387 .63273 L .68416 .63072 L F
.493 .355 .622 r
.68201 .63336 m .68387 .63273 L .68233 .63126 L F
.549 0 0 r
.39165 .84191 m .3949 .84256 L .39394 .84275 L F
.39394 .84275 m .3949 .84256 L .39165 .84191 L F
.576 .94 .826 r
.39563 .84165 m .3949 .84256 L .39394 .84275 L F
.39394 .84275 m .3949 .84256 L .39563 .84165 L F
.369 .055 .295 r
.31791 .65823 m .31904 .65983 L .31979 .65755 L F
.31791 .65823 m .31715 .66038 L .31904 .65983 L F
.432 .236 .513 r
.33364 .7123 m .33727 .71025 L .33557 .7127 L F
.44 .294 .586 r
.2913 .63044 m .28933 .63345 L .28922 .63128 L F
.864 .895 .855 r
.53897 .73045 m .53773 .73414 L .53694 .73211 L F
.53897 .73045 m .53629 .73368 L .53773 .73414 L F
.955 .734 .565 r
.53629 .73368 m .5375 .73669 L .53773 .73414 L F
.758 .401 .378 r
.56242 .72864 m .56094 .73046 L .56143 .72818 L F
0 0 .468 r
.56384 .73104 m .56507 .73283 L .56523 .73295 L F
.56507 .73283 m .56565 .73367 L .56523 .73295 L F
0 0 .452 r
.56561 .73593 m .56631 .73575 L .56523 .73295 L F
.56631 .73575 m .56632 .73575 L .5663 .73571 L F
.56631 .73575 m .5663 .73571 L .56523 .73295 L F
.866 .439 .01 r
.56523 .73295 m .56626 .73559 L .56533 .73469 L F
.56523 .73295 m .56533 .73469 L .56548 .73315 L F
.56548 .73315 m .56533 .73469 L .56552 .73318 L F
.56523 .73295 m .56552 .73318 L .5657 .7318 L F
.215 .441 .863 r
.56523 .73295 m .56491 .73255 L .56384 .73104 L F
.56491 .73255 m .563 .73019 L .56384 .73104 L F
.758 .401 .378 r
.56227 .72882 m .56384 .73104 L .56094 .73046 L F
.56242 .72864 m .56384 .73104 L .56227 .72882 L F
.466 .774 .997 r
.56094 .73046 m .56384 .73104 L .563 .73019 L F
.215 .441 .863 r
.56523 .73295 m .5657 .7318 L .563 .73019 L F
.976 .746 .524 r
.5656 .73192 m .56533 .73469 L .56425 .73357 L F
.56565 .73219 m .56533 .73469 L .5656 .73192 L F
.61 .806 .975 r
.56429 .73369 m .56533 .73469 L .56711 .7341 L F
.976 .746 .524 r
.56425 .73357 m .56533 .73469 L .56416 .73367 L F
.61 .806 .975 r
.56416 .73367 m .56533 .73469 L .56429 .73369 L F
.866 .439 .01 r
.56626 .73559 m .5663 .73571 L .56533 .73469 L F
.5663 .73571 m .56632 .73575 L .56533 .73469 L F
.976 .746 .524 r
.5657 .7318 m .56565 .73219 L .5656 .73192 L F
.633 .39 .531 r
.61536 .6502 m .61547 .65243 L .61347 .65193 L F
.661 .41 .531 r
.61536 .6502 m .61713 .65233 L .61547 .65243 L F
.856 .788 .784 r
.7091 .5856 m .70574 .58775 L .70774 .58651 L F
.744 .704 .814 r
.68593 .58341 m .68763 .58227 L .68485 .58265 L F
.631 .502 .688 r
.37813 .79104 m .3808 .7935 L .37977 .79031 L F
.37813 .79104 m .37889 .79453 L .3808 .7935 L F
.26 0 0 r
.46202 .72556 m .4642 .7255 L .46534 .72497 L F
.205 0 0 r
.4642 .7255 m .46751 .72487 L .46534 .72497 L F
.648 .554 .735 r
.72713 .5962 m .72811 .59832 L .72559 .5989 L F
.585 .35 .526 r
.72559 .5989 m .72811 .59832 L .72737 .60098 L F
.252 .278 .695 r
.72737 .60098 m .72639 .60118 L .72559 .5989 L F
.585 .35 .526 r
.72559 .5989 m .72811 .59832 L .72737 .60098 L F
.046 0 .091 r
.62962 .67511 m .63116 .67399 L .6288 .67665 L F
0 0 0 r
.68566 .70965 m .68613 .70644 L .68725 .70786 L F
.68566 .70965 m .68577 .7091 L .68613 .70644 L F
0 0 .38 r
.68566 .70965 m .68641 .71078 L .68577 .7091 L F
.68566 .70965 m .68585 .71186 L .68641 .71078 L F
.228 0 .25 r
.29826 .67184 m .29985 .67132 L .30052 .66932 L F
.492 .18 .366 r
.30052 .66932 m .29985 .67132 L .30206 .67077 L F
.486 .181 .374 r
.30052 .66932 m .30206 .67077 L .3027 .66895 L F
.016 .58 .796 r
.56401 .71501 m .5665 .71525 L .56773 .71554 L F
0 0 0 r
.5678 .71536 m .5685 .7144 L .56911 .7123 L F
0 .275 .777 r
.5691 .71356 m .5685 .7144 L .56806 .71222 L F
.661 .571 .743 r
.5685 .7144 m .57217 .71439 L .57018 .71149 L F
.616 .295 .403 r
.5685 .7144 m .57067 .716 L .57217 .71439 L F
0 .275 .777 r
.57007 .71482 m .5685 .7144 L .5691 .71356 L F
0 0 0 r
.56773 .71554 m .5685 .7144 L .5678 .71536 L F
.586 .924 .962 r
.56773 .71554 m .5665 .71525 L .5685 .7144 L F
0 0 0 r
.47829 .72253 m .47963 .72223 L .48096 .72086 L F
.47829 .72253 m .47769 .72308 L .47963 .72223 L F
.275 .04 .365 r
.61102 .68271 m .61318 .68185 L .61311 .67984 L F
.317 .151 .491 r
.61091 .68497 m .61318 .68185 L .61102 .68271 L F
.723 .641 .766 r
.68744 .6313 m .69048 .6337 L .68974 .6307 L F
.692 .604 .753 r
.68974 .6307 m .69048 .6337 L .69284 .63112 L F
.584 .403 .602 r
.60681 .69027 m .6089 .68778 L .60671 .68812 L F
.571 .179 .26 r
.67235 .58691 m .67453 .5873 L .67268 .5872 L F
0 0 0 r
.67235 .58691 m .67357 .5866 L .67345 .58711 L F
.67235 .58691 m .67063 .58871 L .67357 .5866 L F
.542 .171 .287 r
.67084 .58841 m .67357 .5866 L .67063 .58871 L F
.67084 .58841 m .67255 .58928 L .67357 .5866 L F
.705 .767 .274 r
.67357 .5866 m .67255 .58928 L .67369 .58608 L F
.67357 .5866 m .67369 .58608 L .67401 .5852 L F
0 0 0 r
.67345 .58711 m .67357 .5866 L .67453 .5873 L F
.174 0 .114 r
.52843 .78772 m .52656 .7887 L .52637 .78831 L F
.874 .884 .839 r
.68063 .58614 m .67824 .58815 L .68042 .58559 L F
.567 .114 .136 r
.4748 .77296 m .47701 .77353 L .47825 .77204 L F
.731 .453 .507 r
.47701 .77353 m .48061 .77161 L .47825 .77204 L F
.954 .643 .401 r
.66691 .60599 m .66828 .60696 L .66734 .60848 L F
.66691 .60599 m .66828 .60696 L .66734 .60848 L F
.741 .639 .747 r
.69284 .63112 m .69618 .63188 L .69498 .6284 L F
.653 .591 .773 r
.69498 .6284 m .69618 .63188 L .69838 .631 L F
.45 .09 .261 r
.29296 .67681 m .29515 .67659 L .2961 .67462 L F
.497 .301 .545 r
.29826 .67184 m .2961 .67462 L .29807 .67413 L F
.327 0 .199 r
.2961 .67462 m .29676 .67614 L .29807 .67413 L F
.2961 .67462 m .29515 .67659 L .29676 .67614 L F
.497 .301 .545 r
.29826 .67184 m .2961 .67462 L .29807 .67413 L F
.47 .274 .531 r
.61676 .69352 m .61661 .69605 L .61431 .69671 L F
.392 .099 .343 r
.61431 .69671 m .61564 .69772 L .61394 .69847 L F
.61431 .69671 m .61661 .69605 L .61564 .69772 L F
.214 0 .039 r
.58787 .65332 m .58494 .65523 L .58716 .65434 L F
.226 0 .106 r
.58716 .65434 m .58979 .65236 L .58787 .65332 L F
.311 0 0 r
.69098 .57343 m .69328 .5734 L .6942 .57267 L F
.367 0 0 r
.48302 .72025 m .4853 .72009 L .48625 .71892 L F
.153 0 0 r
.48625 .71892 m .48736 .71942 L .48854 .71844 L F
.48625 .71892 m .4853 .72009 L .48736 .71942 L F
.508 .267 .485 r
.37969 .69854 m .37717 .70108 L .37772 .69915 L F
.38 .107 .368 r
.39569 .68209 m .39323 .68455 L .39381 .6827 L F
.361 .558 .91 r
.72057 .73488 m .72286 .73718 L .72367 .73631 L F
0 0 .513 r
.72286 .73718 m .72329 .7369 L .72367 .73631 L F
.834 .647 .649 r
.30681 .73686 m .30696 .73689 L .30688 .73724 L F
.959 .775 .611 r
.62187 .62601 m .62082 .62559 L .61853 .62633 L F
.62187 .62601 m .62182 .62843 L .62082 .62559 L F
.62082 .62559 m .62182 .62843 L .62187 .62601 L F
.638 .336 .442 r
.62334 .6274 m .62443 .62599 L .62187 .62601 L F
.447 .347 .649 r
.62182 .62843 m .62334 .6274 L .62187 .62601 L F
.098 0 0 r
.34172 .72732 m .34133 .72628 L .34311 .72546 L F
.34172 .72732 m .33988 .72813 L .34133 .72628 L F
0 0 .127 r
.58306 .65824 m .5845 .65736 L .58494 .65523 L F
0 0 0 r
.58306 .65824 m .58248 .65993 L .5845 .65736 L F
.525 .358 .596 r
.67713 .62311 m .6774 .62588 L .67954 .62492 L F
.649 .788 .948 r
.69996 .71824 m .69844 .72063 L .69688 .71801 L F
.69996 .71824 m .70069 .72013 L .69844 .72063 L F
0 .161 .678 r
.73367 .71384 m .73483 .71479 L .73453 .71503 L F
0 0 .49 r
.73483 .71479 m .73566 .71684 L .73453 .71503 L F
.891 .972 .827 r
.58634 .67427 m .58493 .6774 L .58729 .67516 L F
.842 .929 .888 r
.58634 .67427 m .58729 .67516 L .58859 .67352 L F
.472 .048 .152 r
.44345 .74472 m .43991 .74656 L .44129 .74501 L F
.406 .167 .436 r
.39758 .68137 m .39611 .68007 L .39787 .67942 L F
.39758 .68137 m .39569 .68209 L .39611 .68007 L F
.528 .776 .988 r
.30807 .74243 m .31018 .74212 L .30759 .74208 L F
.556 .474 .717 r
.3817 .76939 m .38313 .76682 L .38082 .76649 L F
.3817 .76939 m .38375 .76902 L .38313 .76682 L F
.585 .428 .635 r
.3817 .76939 m .38405 .77159 L .38375 .76902 L F
.3817 .76939 m .38179 .77191 L .38405 .77159 L F
.782 .762 .835 r
.69953 .62536 m .69718 .62785 L .69999 .62801 L F
.808 .664 .704 r
.69718 .62785 m .69838 .631 L .69999 .62801 L F
.668 .453 .584 r
.60967 .63907 m .61245 .63891 L .61303 .6365 L F
.678 .415 .518 r
.61491 .63862 m .61303 .6365 L .61245 .63891 L F
.61491 .63862 m .61512 .63658 L .61303 .6365 L F
.587 .454 .667 r
.38815 .7476 m .3905 .74737 L .39015 .74486 L F
.493 .302 .55 r
.38836 .75003 m .3905 .74737 L .38815 .7476 L F
.849 .936 .882 r
.62175 .65998 m .62253 .66059 L .6201 .66146 L F
.928 .937 .787 r
.62304 .65827 m .62253 .66059 L .62175 .65998 L F
.561 .633 .88 r
.52397 .71306 m .52201 .71368 L .52078 .71148 L F
.538 .578 .842 r
.52489 .71568 m .52201 .71368 L .52397 .71306 L F
.11 .655 .831 r
.38292 .80444 m .38454 .80461 L .38557 .80446 L F
.209 .146 .563 r
.6183 .66638 m .6201 .66527 L .61963 .66293 L F
0 0 .282 r
.6183 .66638 m .61893 .66771 L .6201 .66527 L F
.6183 .66638 m .61845 .66885 L .61893 .66771 L F
.726 .776 .892 r
.67278 .61942 m .6739 .62106 L .67618 .61962 L F
.627 .861 .987 r
.67812 .62036 m .6739 .62106 L .67618 .61962 L F
.669 .746 .908 r
.35445 .64875 m .35565 .65021 L .35226 .64969 L F
.619 .728 .924 r
.35786 .64959 m .35565 .65021 L .35445 .64875 L F
.155 0 .313 r
.61311 .67984 m .61493 .67905 L .61503 .67692 L F
.168 0 .346 r
.61311 .67984 m .61448 .6811 L .61493 .67905 L F
.61311 .67984 m .61318 .68185 L .61448 .6811 L F
.141 0 0 r
.34333 .71015 m .34375 .71114 L .34542 .70972 L F
.34333 .71015 m .34179 .71177 L .34375 .71114 L F
.724 .633 .757 r
.69243 .6039 m .69365 .6071 L .69537 .60592 L F
.582 .394 .592 r
.69591 .60883 m .69365 .60962 L .69365 .6071 L F
.208 .382 .817 r
.6949 .60642 m .69591 .60883 L .69365 .6071 L F
.6949 .60642 m .69365 .6071 L .69254 .60785 L F
.468 .084 .227 r
.43088 .72808 m .43307 .72789 L .43433 .72583 L F
.546 .159 .259 r
.43307 .72789 m .43652 .726 L .43433 .72583 L F
.584 .503 .729 r
.38082 .76649 m .38313 .76682 L .38255 .76361 L F
.442 .231 .496 r
.57704 .71417 m .57534 .71257 L .57777 .71208 L F
.57534 .71257 m .57704 .71417 L .57643 .71482 L F
.57704 .71417 m .57515 .71473 L .57534 .71257 L F
.57534 .71257 m .57515 .71473 L .57704 .71417 L F
.41 .201 .482 r
.30247 .61222 m .30202 .61468 L .30016 .61528 L F
.336 .047 .317 r
.30202 .61468 m .2995 .61707 L .30016 .61528 L F
0 0 .165 r
.63176 .67209 m .63295 .67088 L .63116 .67399 L F
.777 .642 .712 r
.41148 .75295 m .41257 .75583 L .40916 .75548 L F
.65 .441 .587 r
.41134 .75718 m .40916 .75548 L .41257 .75583 L F
.057 0 .259 r
.41475 .75311 m .41257 .75583 L .41148 .75295 L F
.41475 .75311 m .41387 .7551 L .41257 .75583 L F
.599 .402 .586 r
.41387 .7551 m .41134 .75718 L .41257 .75583 L F
.819 .614 .625 r
.40182 .79835 m .39885 .79643 L .39862 .79864 L F
.577 .488 .717 r
.70599 .73126 m .7092 .73274 L .70766 .72834 L F
.441 .57 .888 r
.7092 .73274 m .70968 .73421 L .71126 .73283 L F
0 .536 .837 r
.70799 .72898 m .70872 .72914 L .70968 .72947 L F
.536 .562 .828 r
.71005 .72752 m .70799 .72898 L .70773 .72773 L F
.71005 .72752 m .7105 .72956 L .70799 .72898 L F
.845 .389 .112 r
.71126 .73283 m .70766 .72834 L .7092 .73274 L F
.669 .117 0 r
.71031 .73296 m .70726 .73106 L .7076 .72876 L F
.70797 .72889 m .7076 .72876 L .70766 .72834 L F
.71031 .73296 m .7076 .72876 L .70797 .72889 L F
0 .536 .837 r
.70968 .72947 m .7105 .72956 L .71235 .73025 L F
.70872 .72914 m .7105 .72956 L .70968 .72947 L F
.574 .843 .996 r
.71235 .73025 m .71316 .72922 L .71424 .7286 L F
.71235 .73025 m .7105 .72956 L .71316 .72922 L F
.729 .659 .781 r
.72064 .72047 m .72463 .72129 L .72298 .71998 L F
.753 .791 .884 r
.72298 .71998 m .72463 .72129 L .72687 .71988 L F
.328 .079 .375 r
.38192 .69592 m .37969 .69854 L .38027 .69669 L F
.637 .877 .526 r
.72988 .72771 m .72913 .72888 L .73112 .72638 L F
.759 .926 .567 r
.73178 .72482 m .73112 .72638 L .73304 .72346 L F
.759 .926 .565 r
.73178 .72482 m .72988 .72771 L .73112 .72638 L F
.549 .518 .773 r
.38732 .65817 m .38614 .6604 L .38555 .65883 L F
.38732 .65817 m .3884 .66013 L .38614 .6604 L F
.799 .74 .216 r
.7288 .72941 m .72913 .72888 L .72988 .72771 L F
.7288 .72941 m .72872 .73118 L .72913 .72888 L F
.857 .805 .798 r
.50068 .72524 m .50425 .72332 L .50325 .72301 L F
.50068 .72524 m .50213 .72623 L .50425 .72332 L F
.685 .54 .683 r
.50213 .72623 m .50469 .72543 L .50425 .72332 L F
.479 .877 .96 r
.50535 .72225 m .50425 .72332 L .50665 .72315 L F
.50535 .72225 m .50325 .72301 L .50425 .72332 L F
.691 .591 .739 r
.50469 .72543 m .50665 .72315 L .50425 .72332 L F
.844 .814 .82 r
.40083 .79561 m .40405 .79368 L .40283 .79461 L F
0 0 0 r
.40502 .79293 m .40405 .79368 L .4064 .79362 L F
.40502 .79293 m .40283 .79461 L .40405 .79368 L F
.584 .859 .995 r
.6783 .61951 m .67936 .62022 L .67812 .62036 L F
.6783 .61951 m .67936 .62022 L .67812 .62036 L F
.599 .865 .993 r
.68042 .61888 m .67936 .62022 L .6783 .61951 L F
.392 .101 .346 r
.35357 .70473 m .35486 .70596 L .35534 .70416 L F
.35357 .70473 m .3529 .70654 L .35486 .70596 L F
.386 .244 .563 r
.48876 .73362 m .48658 .7363 L .48739 .73415 L F
.958 .721 .536 r
.30688 .73724 m .30537 .7374 L .30681 .73686 L F
.267 0 0 r
.34906 .67365 m .34559 .67552 L .34694 .6741 L F
.696 .877 .966 r
.69916 .60882 m .69591 .60883 L .69825 .60691 L F
.602 .74 .942 r
.70161 .60841 m .69916 .60882 L .69825 .60691 L F
.328 .162 .498 r
.29826 .67184 m .29807 .67413 L .29985 .67132 L F
.29826 .67184 m .29807 .67413 L .29985 .67132 L F
0 0 0 r
.59641 .66205 m .59764 .65982 L .59723 .66093 L F
.441 .726 .986 r
.6783 .61951 m .67812 .62036 L .67618 .61962 L F
.6783 .61951 m .67812 .62036 L .67618 .61962 L F
.914 .853 .768 r
.64465 .64673 m .64192 .6483 L .64303 .6493 L F
.64465 .64673 m .64348 .64494 L .64192 .6483 L F
.462 .228 .473 r
.31049 .69314 m .30826 .69571 L .30866 .6936 L F
.53 .214 .375 r
.31223 .74899 m .31511 .74779 L .31193 .74744 L F
.31223 .74899 m .3146 .74903 L .31511 .74779 L F
.31511 .74779 m .3146 .74903 L .31223 .74899 L F
.702 .591 .729 r
.40831 .76332 m .4059 .7643 L .40794 .76177 L F
.673 .679 .848 r
.70471 .609 m .70254 .60993 L .70161 .60841 L F
.998 .782 .466 r
.58957 .67032 m .59039 .66926 L .59072 .66861 L F
.58957 .67032 m .59032 .67093 L .59039 .66926 L F
.676 .933 .64 r
.59191 .6672 m .59039 .66926 L .59334 .66636 L F
.59191 .6672 m .59072 .66861 L .59039 .66926 L F
.329 0 .161 r
.44841 .74196 m .45127 .74023 L .45149 .74117 L F
.478 .041 .129 r
.45149 .74117 m .45127 .74023 L .45319 .74114 L F
.599 .43 .624 r
.5907 .69327 m .59288 .69304 L .59282 .6906 L F
.565 .392 .607 r
.59105 .69521 m .59288 .69304 L .5907 .69327 L F
.958 .721 .536 r
.30688 .73724 m .30634 .73905 L .30537 .7374 L F
.646 .333 .428 r
.31511 .74779 m .31677 .74983 L .3146 .74903 L F
.31511 .74779 m .31677 .74983 L .3146 .74903 L F
.995 .84 .487 r
.58208 .74709 m .58121 .74707 L .58232 .74491 L F
.893 .974 .821 r
.58354 .74177 m .58232 .74491 L .58419 .74372 L F
.463 .153 .354 r
.58121 .74707 m .58419 .74372 L .58232 .74491 L F
.835 .895 .475 r
.67885 .60656 m .67974 .60373 L .68066 .60532 L F
.389 .428 .78 r
.68066 .60532 m .68164 .60913 L .67885 .60656 L F
.397 0 0 r
.31846 .73943 m .31825 .73977 L .31577 .73952 L F
.716 .823 .368 r
.31925 .73752 m .31825 .73977 L .31846 .73943 L F
.239 .51 .907 r
.67085 .61301 m .67144 .61428 L .6737 .61471 L F
.67362 .61455 m .6737 .61471 L .67404 .61478 L F
.67085 .61301 m .6737 .61471 L .67362 .61455 L F
.67085 .61301 m .67404 .61478 L .67496 .61242 L F
.946 .89 .743 r
.67257 .61284 m .67284 .6128 L .67305 .6145 L F
.67284 .6128 m .67496 .61242 L .67342 .61409 L F
.67284 .6128 m .67342 .61409 L .67305 .6145 L F
0 .297 .751 r
.67326 .61481 m .67391 .61478 L .67144 .61428 L F
.404 0 0 r
.67254 .61505 m .67369 .61568 L .67144 .61428 L F
.946 .89 .743 r
.67255 .61434 m .67305 .6145 L .67254 .61505 L F
.67257 .61284 m .67305 .6145 L .67255 .61434 L F
0 .297 .751 r
.67391 .61478 m .67404 .61478 L .6737 .61471 L F
.67391 .61478 m .6737 .61471 L .67144 .61428 L F
.627 .617 .821 r
.67577 .61392 m .6774 .61649 L .67592 .61617 L F
0 .297 .751 r
.67326 .61481 m .67526 .61609 L .67422 .61497 L F
.684 .635 .794 r
.6774 .61649 m .675 .61912 L .67396 .61638 L F
.67411 .61577 m .67396 .61638 L .67369 .61568 L F
.965 .924 .708 r
.6745 .61428 m .67526 .61609 L .67586 .61281 L F
.684 .635 .794 r
.6774 .61649 m .67396 .61638 L .67411 .61577 L F
.965 .924 .708 r
.67429 .6145 m .67439 .61468 L .6745 .61428 L F
.67439 .61468 m .67526 .61609 L .6745 .61428 L F
.67404 .61478 m .67422 .61497 L .67429 .6145 L F
.67422 .61497 m .67526 .61609 L .67429 .6145 L F
.627 .617 .821 r
.67439 .61509 m .67592 .61617 L .67411 .61577 L F
.67418 .61527 m .67411 .61577 L .67369 .61568 L F
.67439 .61509 m .67411 .61577 L .67418 .61527 L F
.67577 .61392 m .67592 .61617 L .67439 .61509 L F
0 .297 .751 r
.67394 .61478 m .67422 .61497 L .67404 .61478 L F
.67326 .61481 m .67422 .61497 L .67394 .61478 L F
0 0 0 r
.72927 .61962 m .73255 .6168 L .73208 .61751 L F
.73354 .61628 m .73208 .61751 L .73255 .6168 L F
.149 0 0 r
.71726 .71803 m .71444 .71983 L .71528 .71769 L F
.377 0 0 r
.69675 .57221 m .69904 .57257 L .70025 .57141 L F
.763 .327 .216 r
.69904 .57257 m .70066 .5741 L .70025 .57141 L F
.311 0 0 r
.4756 .73387 m .47435 .73509 L .47229 .73488 L F
.068 0 0 r
.47729 .73467 m .47435 .73509 L .4756 .73387 L F
.891 .972 .827 r
.58634 .67427 m .58426 .67691 L .58493 .6774 L F
.922 .963 .785 r
.58426 .67691 m .58298 .67869 L .58493 .6774 L F
.992 .845 .594 r
.31579 .69048 m .31567 .6914 L .31401 .69057 L F
.611 .306 .427 r
.48658 .7363 m .48655 .73872 L .48445 .73698 L F
.386 .244 .563 r
.48876 .73362 m .48882 .73604 L .48658 .7363 L F
.35 .104 .394 r
.48882 .73604 m .48655 .73872 L .48658 .7363 L F
.747 .708 .816 r
.71017 .58182 m .71093 .58451 L .70999 .58416 L F
.71017 .58182 m .713 .58232 L .71093 .58451 L F
.664 .57 .739 r
.713 .58232 m .71366 .58461 L .71093 .58451 L F
.463 .302 .577 r
.31478 .73646 m .31306 .73956 L .31241 .73684 L F
.236 0 .141 r
.61491 .63862 m .61757 .63636 L .61512 .63658 L F
.677 .159 0 r
.48597 .77613 m .48679 .77523 L .48383 .77439 L F
.331 0 0 r
.48805 .7759 m .48679 .77523 L .48597 .77613 L F
.48805 .7759 m .48945 .77628 L .48679 .77523 L F
.591 .813 .984 r
.69474 .70285 m .69867 .70441 L .69559 .70415 L F
.714 .594 .721 r
.69379 .70129 m .69559 .70415 L .6916 .70404 L F
.446 .131 .336 r
.69379 .70129 m .69334 .70325 L .69462 .70266 L F
.69379 .70129 m .69462 .70266 L .69495 .70252 L F
.591 .813 .984 r
.69454 .70253 m .69455 .70254 L .69379 .70129 L F
.69455 .70254 m .69559 .70415 L .69379 .70129 L F
.533 .424 .675 r
.69487 .7028 m .69495 .70252 L .69462 .70266 L F
.69472 .70282 m .69462 .70266 L .69413 .70289 L F
.591 .813 .984 r
.69461 .70263 m .69474 .70285 L .69454 .70253 L F
.69472 .70282 m .69474 .70285 L .69461 .70263 L F
.709 .287 .243 r
.69485 .70281 m .69964 .70344 L .69867 .70441 L F
.69485 .70281 m .69964 .70344 L .69485 .70281 L F
.69508 .70279 m .69964 .70344 L .69484 .70281 L F
.69497 .70278 m .69816 .70368 L .69964 .70344 L F
.533 .424 .675 r
.69487 .7028 m .69496 .70277 L .69487 .7028 L F
.69496 .70277 m .69496 .70277 L .69487 .7028 L F
.69487 .7028 m .69462 .70266 L .69472 .70281 L F
.709 .287 .243 r
.69467 .70273 m .69508 .70279 L .69484 .70281 L F
.533 .424 .675 r
.69487 .7028 m .69503 .70275 L .69495 .70252 L F
.709 .287 .243 r
.69506 .70284 m .69816 .70368 L .69497 .70278 L F
.738 .536 .619 r
.69495 .70252 m .69816 .70368 L .69506 .70284 L F
.533 .424 .675 r
.69503 .70275 m .69505 .70274 L .69495 .70252 L F
.709 .287 .243 r
.69467 .70273 m .69506 .70284 L .69497 .70278 L F
.533 .424 .675 r
.69496 .70277 m .69505 .70274 L .69496 .70277 L F
.69505 .70275 m .69505 .70274 L .69487 .7028 L F
.738 .536 .619 r
.69495 .70252 m .69506 .70284 L .69467 .70273 L F
.591 .813 .984 r
.69474 .70285 m .69559 .70415 L .69454 .70253 L F
.69477 .70284 m .69867 .70441 L .69474 .70285 L F
.69484 .70281 m .69867 .70441 L .69472 .70282 L F
.665 .316 .373 r
.69559 .70415 m .69397 .70596 L .6916 .70404 L F
.533 .424 .675 r
.69397 .70596 m .69505 .70275 L .69487 .7028 L F
.709 .287 .243 r
.69484 .70281 m .69485 .70281 L .69485 .70281 L F
.533 .424 .675 r
.69484 .70281 m .69472 .70281 L .69472 .70282 L F
.69487 .7028 m .69472 .70281 L .69484 .70281 L F
.591 .813 .984 r
.69467 .70273 m .69472 .70282 L .69461 .70263 L F
.814 .587 .595 r
.69867 .70441 m .6975 .70669 L .69397 .70596 L F
.533 .424 .675 r
.69397 .70596 m .69654 .70587 L .69627 .70531 L F
.814 .587 .595 r
.69867 .70441 m .69397 .70596 L .69559 .70415 L F
.533 .424 .675 r
.69492 .70314 m .69627 .70531 L .69505 .70274 L F
.69397 .70596 m .69627 .70531 L .69492 .70314 L F
.591 .813 .984 r
.69472 .70282 m .69477 .70284 L .69474 .70285 L F
.533 .424 .675 r
.69397 .70596 m .69487 .7028 L .69334 .70325 L F
.69487 .7028 m .69413 .70289 L .69334 .70325 L F
.591 .813 .984 r
.69467 .70273 m .69484 .70281 L .69472 .70282 L F
.132 .227 .697 r
.64588 .63351 m .64743 .63538 L .64655 .63692 L F
.679 .925 .971 r
.64655 .63692 m .64743 .63538 L .64562 .63633 L F
.941 .927 .763 r
.64655 .63692 m .64474 .63772 L .64585 .63858 L F
.64655 .63692 m .64562 .63633 L .64474 .63772 L F
.604 .448 .643 r
.3694 .68799 m .36728 .6908 L .36957 .69045 L F
.46 .286 .558 r
.36765 .6933 m .36957 .69045 L .36728 .6908 L F
.661 .585 .758 r
.69627 .62249 m .69953 .62536 L .69911 .62333 L F
.685 .624 .781 r
.69911 .62333 m .70281 .62341 L .70152 .62029 L F
.724 .633 .757 r
.69243 .6039 m .69537 .60592 L .69475 .60347 L F
.734 .743 .859 r
.69808 .6039 m .69537 .60592 L .69593 .60477 L F
.011 0 0 r
.471 .72486 m .46751 .72487 L .46971 .72509 L F
.329 0 0 r
.46971 .72509 m .47287 .72466 L .471 .72486 L F
.67 .753 .913 r
.70848 .59786 m .71132 .59859 L .71007 .59724 L F
.70848 .59786 m .71132 .59859 L .71007 .59724 L F
.95 .735 .577 r
.71132 .59859 m .71088 .60079 L .71007 .59724 L F
.71132 .59859 m .71088 .60079 L .71007 .59724 L F
.849 .489 .37 r
.57549 .70602 m .57953 .70883 L .57951 .70721 L F
.678 .488 .622 r
.57953 .70883 m .5818 .70654 L .57951 .70721 L F
.71 .47 .56 r
.70053 .70436 m .69761 .7076 L .6975 .70669 L F
.196 0 .119 r
.70048 .7058 m .69761 .7076 L .70053 .70436 L F
.70048 .7058 m .70053 .70436 L .69964 .70344 L F
0 0 0 r
.31192 .71222 m .31396 .71192 L .31553 .71168 L F
.293 0 0 r
.31553 .71168 m .31396 .71192 L .3174 .71198 L F
.179 .688 .9 r
.28133 .60103 m .2828 .60143 L .27932 .60101 L F
.262 .681 .966 r
.28328 .6007 m .2828 .60143 L .28133 .60103 L F
.28328 .6007 m .28479 .60156 L .2828 .60143 L F
.748 .777 .876 r
.36735 .78535 m .36822 .78692 L .37073 .78546 L F
.513 .391 .65 r
.38451 .75852 m .3862 .75516 L .38417 .75633 L F
0 0 .206 r
.57421 .70032 m .57349 .70147 L .57407 .69883 L F
.57421 .70032 m .57407 .69883 L .5716 .69854 L F
.472 0 0 r
.57407 .69883 m .57336 .6992 L .5716 .69854 L F
.805 .964 .646 r
.57593 .69574 m .57407 .69883 L .57631 .69792 L F
.57593 .69574 m .57336 .6992 L .57407 .69883 L F
.659 .25 .258 r
.57407 .69883 m .57717 .70073 L .57421 .70032 L F
.626 .319 .43 r
.57753 .69902 m .57717 .70073 L .57407 .69883 L F
.659 .25 .258 r
.57407 .69883 m .57421 .70032 L .57631 .69792 L F
.772 .981 .723 r
.594 .66486 m .59191 .6672 L .59334 .66636 L F
.277 0 0 r
.68485 .58265 m .68763 .58227 L .68647 .58292 L F
.76 .856 .922 r
.68847 .57852 m .69117 .57838 L .68951 .5774 L F
.343 .709 .984 r
.69117 .57838 m .69352 .57765 L .68951 .5774 L F
.53 .528 .797 r
.68951 .5774 m .69352 .57765 L .69245 .57462 L F
.218 .132 .539 r
.6902 .57716 m .69009 .57774 L .68847 .57852 L F
.817 .988 .724 r
.68771 .58164 m .68763 .58227 L .68983 .57945 L F
.693 .581 .725 r
.68763 .58227 m .69135 .58371 L .68983 .57945 L F
.817 .988 .724 r
.68647 .58292 m .68983 .57945 L .68847 .57852 L F
.76 .856 .922 r
.68847 .57852 m .68983 .57945 L .69117 .57838 L F
.218 .132 .539 r
.69009 .57774 m .68946 .58098 L .68892 .57965 L F
.69009 .57774 m .68892 .57965 L .68847 .57852 L F
.817 .988 .724 r
.68647 .58292 m .68717 .58253 L .68771 .58164 L F
.68717 .58253 m .68763 .58227 L .68771 .58164 L F
.901 .708 .632 r
.68634 .61623 m .68899 .61775 L .688 .61666 L F
0 0 .069 r
.62196 .63084 m .62334 .6274 L .62182 .62843 L F
0 0 0 r
.45277 .77212 m .44892 .77318 L .45177 .77213 L F
0 .507 .817 r
.45316 .77192 m .45277 .77212 L .45177 .77213 L F
.45316 .77192 m .45499 .77268 L .45277 .77212 L F
.301 .606 .952 r
.71324 .73623 m .71438 .73546 L .71161 .73415 L F
.71324 .73623 m .71553 .73663 L .71438 .73546 L F
.306 .412 .806 r
.52489 .71568 m .52733 .71741 L .52574 .71703 L F
0 0 0 r
.5234 .79016 m .52305 .79042 L .52192 .79115 L F
.386 .804 .609 r
.52305 .79042 m .51998 .79235 L .52192 .79115 L F
.823 .669 .693 r
.7093 .61945 m .71248 .61729 L .71162 .617 L F
.7093 .61945 m .71172 .61992 L .71248 .61729 L F
.387 .809 .972 r
.71248 .61729 m .71502 .61695 L .7138 .61657 L F
.629 .612 .814 r
.68201 .63336 m .68538 .63413 L .68387 .63273 L F
.152 0 .322 r
.61857 .69075 m .61798 .69282 L .61676 .69352 L F
.226 .076 .459 r
.61798 .69282 m .61661 .69605 L .61676 .69352 L F
.704 .656 .8 r
.57941 .69328 m .58275 .69387 L .58178 .69327 L F
.116 .183 .657 r
.7064 .72244 m .70664 .72627 L .70423 .72328 L F
.7064 .72244 m .70703 .72574 L .70664 .72627 L F
.372 .105 .373 r
.37527 .70165 m .37478 .70366 L .37286 .70421 L F
.494 .215 .419 r
.37688 .70326 m .37527 .70165 L .37717 .70108 L F
.37688 .70326 m .37478 .70366 L .37527 .70165 L F
.58 .237 .353 r
.41513 .73299 m .41741 .73308 L .41559 .73146 L F
.575 .238 .361 r
.41559 .73146 m .41741 .73308 L .41798 .7314 L F
.631 .471 .647 r
.71381 .62328 m .71631 .62165 L .71589 .62019 L F
.71381 .62328 m .71631 .62165 L .71589 .62019 L F
.76 .683 .777 r
.71502 .61695 m .71589 .62019 L .71548 .61881 L F
0 .145 .677 r
.71589 .62019 m .7182 .6224 L .7174 .62112 L F
.447 .361 .665 r
.71589 .62019 m .71631 .62165 L .7182 .6224 L F
.438 .356 .666 r
.61736 .67162 m .61913 .6711 L .61845 .66885 L F
.317 .151 .492 r
.61748 .67438 m .61913 .6711 L .61736 .67162 L F
0 .366 .766 r
.57815 .69023 m .57777 .69012 L .57718 .68868 L F
.462 .269 .532 r
.40022 .67438 m .40006 .67667 L .39813 .6772 L F
.475 .265 .514 r
.39983 .67889 m .39813 .6772 L .40006 .67667 L F
.39983 .67889 m .39787 .67942 L .39813 .6772 L F
.254 0 .307 r
.3351 .6789 m .33362 .67969 L .33589 .67705 L F
.448 .081 .247 r
.3351 .6789 m .33222 .6813 L .33362 .67969 L F
.397 .454 .802 r
.33063 .70909 m .33069 .71172 L .32858 .70949 L F
.33063 .70909 m .33274 .71273 L .33069 .71172 L F
.834 .749 .77 r
.65045 .62208 m .65109 .62472 L .65186 .62315 L F
.721 .622 .746 r
.64849 .59616 m .65143 .59584 L .65131 .59377 L F
.684 .433 .537 r
.65117 .59802 m .65143 .59584 L .64849 .59616 L F
.736 .633 .745 r
.65131 .59377 m .65143 .59584 L .65341 .59325 L F
0 0 .025 r
.65341 .59325 m .65143 .59584 L .65269 .59499 L F
.086 0 .357 r
.65269 .59499 m .65143 .59584 L .65117 .59802 L F
.347 .119 .419 r
.37246 .70635 m .37072 .70698 L .37286 .70421 L F
.212 0 .267 r
.37246 .70635 m .37013 .70901 L .37072 .70698 L F
.548 .548 .806 r
.726 .59173 m .7242 .59366 L .72313 .59062 L F
.594 .621 .849 r
.726 .59173 m .72704 .59333 L .7242 .59366 L F
.759 .577 .651 r
.62092 .65013 m .62092 .65281 L .61713 .65233 L F
.755 .558 .629 r
.62092 .65013 m .62436 .65282 L .62092 .65281 L F
.381 .468 .825 r
.52467 .71398 m .52489 .71568 L .52397 .71306 L F
.237 .402 .825 r
.52627 .71495 m .52489 .71568 L .52467 .71398 L F
.52627 .71495 m .52733 .71741 L .52489 .71568 L F
0 .47 .82 r
.72935 .71231 m .73044 .71292 L .7274 .71169 L F
0 .424 .719 r
.73213 .71333 m .73044 .71292 L .72935 .71231 L F
.73213 .71333 m .73367 .71384 L .73044 .71292 L F
.809 .765 .811 r
.31695 .73823 m .31825 .73977 L .31925 .73752 L F
.096 0 0 r
.31925 .73752 m .3184 .7381 L .31695 .73823 L F
.206 .708 .907 r
.3184 .7381 m .31812 .73807 L .31695 .73823 L F
.3 .382 .78 r
.31478 .73646 m .31542 .73845 L .31695 .73823 L F
.463 .302 .577 r
.31478 .73646 m .31449 .73993 L .31306 .73956 L F
.972 .662 .352 r
.31292 .73659 m .31449 .73993 L .31478 .73646 L F
.343 0 0 r
.31695 .73823 m .31292 .73659 L .31478 .73646 L F
.206 .708 .907 r
.31812 .73807 m .31547 .73775 L .31695 .73823 L F
.3 .382 .78 r
.31542 .73845 m .31577 .73952 L .31695 .73823 L F
.473 .652 .938 r
.31577 .73952 m .31825 .73977 L .31695 .73823 L F
.501 .238 .447 r
.59021 .72893 m .58981 .73088 L .5876 .73127 L F
.59 .721 .934 r
.59223 .72825 m .59021 .72893 L .58928 .72726 L F
.575 .373 .57 r
.59223 .72825 m .58981 .73088 L .59021 .72893 L F
.285 .285 .684 r
.30279 .60842 m .30247 .61222 L .30146 .61013 L F
.30279 .60842 m .30346 .61146 L .30247 .61222 L F
.299 .104 .44 r
.30351 .61371 m .30247 .61222 L .30346 .61146 L F
.30351 .61371 m .30202 .61468 L .30247 .61222 L F
.37 .036 .262 r
.31876 .68805 m .31781 .68998 L .31579 .69048 L F
.415 .08 .286 r
.31989 .6895 m .31876 .68805 L .32042 .68752 L F
.31989 .6895 m .31781 .68998 L .31876 .68805 L F
.362 .13 .421 r
.32079 .68546 m .32042 .68752 L .31876 .68805 L F
.572 .574 .816 r
.30492 .70922 m .30426 .71288 L .30289 .70971 L F
.30492 .70922 m .30643 .71252 L .30426 .71288 L F
.05 .612 .795 r
.43668 .77514 m .43577 .7753 L .43459 .77572 L F
.43668 .77514 m .43961 .77545 L .43577 .7753 L F
.682 .714 .873 r
.41023 .76177 m .40831 .76332 L .40794 .76177 L F
.65 .84 .973 r
.42284 .77745 m .41941 .77732 L .42149 .77699 L F
.574 .887 .99 r
.42472 .77663 m .42284 .77745 L .42149 .77699 L F
.647 .626 .815 r
.53863 .72599 m .53509 .72423 L .5375 .72349 L F
.598 .619 .844 r
.53953 .72294 m .53863 .72599 L .5375 .72349 L F
.53953 .72294 m .54084 .72557 L .53863 .72599 L F
.47 .284 .546 r
.54084 .72557 m .53879 .72842 L .53863 .72599 L F
.584 .434 .644 r
.30401 .69896 m .30401 .70121 L .30191 .70174 L F
.616 .51 .71 r
.30401 .70121 m .30216 .70432 L .30191 .70174 L F
.67 .373 .46 r
.70249 .71712 m .70281 .71552 L .70089 .718 L F
.70249 .71712 m .70281 .71552 L .70089 .718 L F
.476 .164 .357 r
.705 .71663 m .70281 .71552 L .70249 .71712 L F
.705 .71663 m .70507 .71497 L .70281 .71552 L F
.533 .541 .809 r
.37087 .80159 m .36895 .80214 L .36768 .79874 L F
.479 .841 .993 r
.36779 .80148 m .36895 .80214 L .37087 .80159 L F
.99 .8 .554 r
.58354 .74177 m .58473 .74222 L .58441 .73979 L F
.99 .797 .55 r
.58354 .74177 m .58419 .74372 L .58473 .74222 L F
.791 .454 .416 r
.58419 .74372 m .58604 .74368 L .58473 .74222 L F
.449 .382 .689 r
.37907 .78312 m .38083 .78409 L .38075 .78256 L F
.37907 .78312 m .37935 .78581 L .38083 .78409 L F
.681 .785 .929 r
.39369 .79414 m .39323 .79663 L .39531 .79578 L F
.883 .961 .845 r
.39059 .79747 m .39323 .79663 L .39369 .79414 L F
0 .013 .574 r
.54832 .71216 m .54947 .71481 L .54865 .71144 L F
.527 .264 .46 r
.32281 .68522 m .32042 .68752 L .32079 .68546 L F
.375 .493 .851 r
.29707 .6066 m .29545 .60623 L .29384 .60335 L F
.811 .608 .628 r
.62436 .65282 m .62112 .65471 L .62092 .65281 L F
.62436 .65282 m .624 .65511 L .62112 .65471 L F
.434 0 .032 r
.4573 .78026 m .45594 .78168 L .45372 .78166 L F
.438 0 .014 r
.4573 .78026 m .4581 .78168 L .45594 .78168 L F
.4573 .78026 m .45935 .78036 L .4581 .78168 L F
.067 .302 .787 r
.39647 .66577 m .39623 .66733 L .39447 .66554 L F
.39647 .66577 m .39781 .66832 L .39623 .66733 L F
.445 0 0 r
.45499 .77268 m .45686 .77336 L .45838 .77247 L F
.288 0 0 r
.45686 .77336 m .46077 .77239 L .45838 .77247 L F
.958 .86 .7 r
.64154 .65283 m .64303 .6493 L .64192 .6483 L F
.85 .891 .867 r
.57996 .7435 m .58354 .74177 L .58208 .74069 L F
.74 .61 .713 r
.58159 .74217 m .58024 .74363 L .57996 .7435 L F
0 0 .447 r
.57957 .74331 m .58114 .74628 L .57996 .7435 L F
.85 .891 .867 r
.57996 .7435 m .58114 .74628 L .58354 .74177 L F
.74 .61 .713 r
.58024 .74363 m .57884 .74515 L .57996 .7435 L F
0 0 .447 r
.57893 .74211 m .57957 .74331 L .57996 .7435 L F
.07 .197 .69 r
.69069 .58044 m .69129 .58353 L .6912 .58101 L F
.68983 .57945 m .69026 .58068 L .69069 .58044 L F
.69026 .58068 m .69129 .58353 L .69069 .58044 L F
.55 .501 .754 r
.69117 .57838 m .69257 .57951 L .69448 .57853 L F
.35 .803 .669 r
.69448 .57853 m .69257 .57951 L .69117 .58017 L F
.07 .197 .69 r
.68983 .57945 m .6912 .58101 L .69257 .57951 L F
.35 .803 .669 r
.69151 .57998 m .69117 .58017 L .68946 .58098 L F
.69448 .57853 m .69117 .58017 L .69151 .57998 L F
.922 .893 .783 r
.68946 .58098 m .69117 .58017 L .6912 .58101 L F
.69117 .58017 m .69257 .57951 L .6912 .58101 L F
.07 .197 .69 r
.69129 .58353 m .69135 .58371 L .6912 .58101 L F
.877 .853 .816 r
.69135 .58371 m .68979 .58367 L .6912 .58101 L F
.594 .188 .243 r
.69339 .58448 m .69089 .58463 L .69135 .58371 L F
.85 .491 .371 r
.69135 .58371 m .69089 .58463 L .68979 .58367 L F
.458 .169 .385 r
.30787 .66596 m .30987 .66553 L .31045 .66374 L F
.333 .053 .33 r
.31045 .66374 m .31169 .66477 L .31253 .66338 L F
.31045 .66374 m .30987 .66553 L .31169 .66477 L F
.621 .834 .982 r
.30992 .71277 m .30643 .71252 L .3085 .71142 L F
.597 .757 .955 r
.31192 .71222 m .30992 .71277 L .3085 .71142 L F
.183 0 .155 r
.32768 .65225 m .32833 .65379 L .32976 .65174 L F
.32768 .65225 m .32663 .65467 L .32833 .65379 L F
.585 .546 .777 r
.30063 .70964 m .30289 .70971 L .30093 .71053 L F
0 .36 .778 r
.70599 .73126 m .70537 .73069 L .70323 .72968 L F
.411 .538 .875 r
.65143 .60943 m .65473 .61232 L .65425 .60884 L F
.7 .451 .543 r
.65151 .61422 m .65488 .61446 L .65473 .61232 L F
.582 .512 .741 r
.65425 .60884 m .65473 .61232 L .65757 .61147 L F
.692 .579 .724 r
.73372 .61178 m .73159 .6129 L .73016 .61092 L F
.387 .191 .488 r
.2873 .63639 m .28702 .63861 L .28536 .63925 L F
.388 .18 .472 r
.28702 .63861 m .28503 .64144 L .28536 .63925 L F
.574 .288 .444 r
.60418 .64148 m .60651 .64137 L .60712 .63881 L F
.654 .365 .468 r
.60712 .63881 m .60961 .64087 L .60967 .63907 L F
.60712 .63881 m .60651 .64137 L .60961 .64087 L F
0 .182 .715 r
.71381 .62328 m .71172 .61992 L .7105 .62274 L F
.6 .131 0 r
.581 .73537 m .58001 .73396 L .57914 .73279 L F
.674 .518 .666 r
.58258 .73412 m .58103 .73553 L .581 .73537 L F
.893 .676 .602 r
.57929 .73716 m .58256 .73843 L .581 .73537 L F
.674 .518 .666 r
.58103 .73553 m .57967 .73678 L .581 .73537 L F
.6 .131 0 r
.581 .73537 m .58177 .73625 L .58097 .73521 L F
.581 .73537 m .58097 .73521 L .58001 .73396 L F
.897 .772 .716 r
.64473 .63039 m .64763 .62866 L .64605 .62748 L F
.64473 .63039 m .6471 .63025 L .64763 .62866 L F
.809 .778 .824 r
.64605 .62748 m .64763 .62866 L .64991 .62639 L F
.128 0 0 r
.42845 .77558 m .42472 .77663 L .42692 .77634 L F
.255 0 0 r
.42915 .7763 m .42845 .77558 L .42692 .77634 L F
.42915 .7763 m .4305 .77538 L .42845 .77558 L F
.081 .641 .77 r
.68045 .57889 m .67858 .57902 L .67797 .57938 L F
.68045 .57889 m .68002 .57891 L .67858 .57902 L F
.822 .368 0 r
.57502 .72548 m .57619 .72565 L .57364 .72414 L F
.57587 .7263 m .57619 .72565 L .57502 .72548 L F
.388 .845 .896 r
.57689 .72576 m .57619 .72565 L .57752 .72558 L F
.57541 .72617 m .57619 .72565 L .57689 .72576 L F
.57541 .72617 m .57619 .72565 L .57752 .72558 L F
.403 0 .049 r
.44916 .78253 m .44804 .78392 L .44663 .78398 L F
.348 0 .076 r
.45135 .78214 m .44804 .78392 L .44916 .78253 L F
.74 .65 .761 r
.70152 .62029 m .70493 .62243 L .70387 .61966 L F
.70152 .62029 m .70281 .62341 L .70493 .62243 L F
.703 .694 .839 r
.70387 .61966 m .70493 .62243 L .70715 .62022 L F
.66 .619 .797 r
.70493 .62243 m .70827 .62354 L .70715 .62022 L F
.691 .591 .739 r
.50469 .72543 m .50778 .72624 L .50665 .72315 L F
.516 .478 .752 r
.37935 .78581 m .38144 .78569 L .38083 .78409 L F
.518 .146 .274 r
.68375 .58794 m .68011 .58965 L .68129 .59061 L F
.379 .374 .728 r
.37215 .6745 m .37269 .67715 L .37351 .6748 L F
.374 .369 .725 r
.37269 .67715 m .37431 .67688 L .37351 .6748 L F
.567 .546 .79 r
.37294 .67952 m .37431 .67688 L .37269 .67715 L F
.245 0 .175 r
.33831 .67629 m .3351 .6789 L .33589 .67705 L F
.429 0 0 r
.42734 .78797 m .42351 .78912 L .42516 .78817 L F
.056 .029 .506 r
.62443 .62599 m .62539 .62443 L .62504 .62172 L F
.389 .237 .551 r
.62334 .6274 m .62539 .62443 L .62443 .62599 L F
.582 .285 .43 r
.44841 .74196 m .44836 .74465 L .4457 .74455 L F
.315 .081 .39 r
.44995 .74364 m .44841 .74196 L .45149 .74117 L F
.44995 .74364 m .44836 .74465 L .44841 .74196 L F
0 .191 .716 r
.51317 .72607 m .51349 .72456 L .51177 .72275 L F
.583 .102 0 r
.51317 .72607 m .51347 .72656 L .51349 .72456 L F
.51317 .72607 m .51502 .72831 L .51347 .72656 L F
.196 .116 .533 r
.57523 .70563 m .57549 .70602 L .57395 .70697 L F
.222 0 0 r
.51438 .79312 m .51624 .79337 L .51292 .7931 L F
.607 .37 .533 r
.70507 .71497 m .70726 .71253 L .70522 .71239 L F
.70507 .71497 m .70764 .71492 L .70726 .71253 L F
.474 .138 .316 r
.70764 .71492 m .71053 .71242 L .70726 .71253 L F
.529 .499 .767 r
.71655 .73911 m .7172 .73631 L .71553 .73663 L F
.71655 .73911 m .71882 .73935 L .7172 .73631 L F
.104 .322 .795 r
.56911 .7123 m .57018 .71149 L .56815 .71008 L F
.661 .571 .743 r
.5685 .7144 m .57018 .71149 L .56911 .7123 L F
0 0 0 r
.63488 .66836 m .63295 .67088 L .63394 .66951 L F
.086 0 .352 r
.63524 .66628 m .63488 .66836 L .63394 .66951 L F
.254 .284 .7 r
.72836 .60285 m .72639 .60118 L .72737 .60098 L F
.52 .917 .837 r
.49383 .71681 m .49477 .71586 L .49658 .71545 L F
.49383 .71681 m .4929 .71689 L .49477 .71586 L F
.704 .755 .892 r
.6481 .609 m .65143 .60943 L .6508 .60649 L F
.77 .623 .697 r
.6481 .609 m .64949 .61201 L .65143 .60943 L F
.686 .743 .895 r
.6508 .60649 m .65143 .60943 L .65425 .60884 L F
.613 .47 .663 r
.37139 .68528 m .3694 .68799 L .3717 .68767 L F
.495 .303 .549 r
.36957 .69045 m .3717 .68767 L .3694 .68799 L F
.258 .24 .647 r
.67842 .6011 m .67921 .59771 L .67869 .60022 L F
0 0 .474 r
.67938 .60219 m .67842 .6011 L .67869 .60022 L F
.67938 .60219 m .67974 .60373 L .67842 .6011 L F
.355 .287 .641 r
.41344 .76364 m .41357 .76599 L .41208 .76635 L F
.369 .294 .64 r
.41384 .76815 m .41208 .76635 L .41357 .76599 L F
.41384 .76815 m .41216 .7695 L .41208 .76635 L F
.648 .643 .831 r
.73257 .60881 m .73016 .61092 L .73031 .60926 L F
.73257 .60881 m .73372 .61178 L .73016 .61092 L F
0 0 0 r
.36241 .66987 m .36104 .67038 L .35896 .6709 L F
.291 0 0 r
.36474 .67022 m .36104 .67038 L .36241 .66987 L F
.885 .956 .844 r
.56477 .67547 m .5648 .67739 L .56382 .67677 L F
.56477 .67547 m .56707 .67471 L .5648 .67739 L F
.651 .505 .672 r
.64698 .59855 m .64906 .59849 L .64849 .59616 L F
.55 .153 .241 r
.64829 .60021 m .64698 .59855 L .64578 .6004 L F
.64829 .60021 m .64906 .59849 L .64698 .59855 L F
.386 .167 .455 r
.38888 .68781 m .38887 .69024 L .38673 .69059 L F
.429 .156 .396 r
.38823 .69247 m .38673 .69059 L .38887 .69024 L F
.38823 .69247 m .38624 .69304 L .38673 .69059 L F
.573 .406 .616 r
.62221 .62208 m .62498 .61979 L .62273 .61993 L F
.452 .399 .708 r
.30279 .60842 m .30084 .60638 L .30259 .6061 L F
.19 .717 .719 r
.30332 .60587 m .30264 .60608 L .3009 .60686 L F
.30264 .60608 m .30259 .6061 L .30252 .60613 L F
.30264 .60608 m .30252 .60613 L .3009 .60686 L F
.452 .399 .708 r
.30279 .60842 m .30146 .61013 L .30091 .60677 L F
.30113 .60668 m .30091 .60677 L .30084 .60638 L F
.30279 .60842 m .30091 .60677 L .30113 .60668 L F
.637 .188 .169 r
.57893 .74211 m .57788 .74382 L .57551 .74197 L F
0 0 .447 r
.57893 .74211 m .57996 .7435 L .57788 .74382 L F
.791 .454 .416 r
.58419 .74372 m .5881 .74529 L .58604 .74368 L F
.316 .002 .263 r
.58494 .65523 m .58648 .65654 L .58716 .65434 L F
.58494 .65523 m .5845 .65736 L .58648 .65654 L F
.616 .51 .71 r
.30401 .70121 m .30466 .70374 L .30216 .70432 L F
.658 .501 .66 r
.30466 .70374 m .30184 .70602 L .30216 .70432 L F
.57 .683 .917 r
.48323 .73538 m .48445 .73698 L .48532 .73552 L F
.297 .33 .727 r
.48445 .73698 m .48655 .73872 L .48532 .73552 L F
.365 .122 .407 r
.37478 .70366 m .37246 .70635 L .37286 .70421 L F
.438 0 0 r
.51944 .78277 m .52208 .78297 L .52278 .78225 L F
.164 .698 .839 r
.52278 .78225 m .52383 .78199 L .52493 .78212 L F
0 0 0 r
.52278 .78225 m .52208 .78297 L .52383 .78199 L F
.684 .433 .537 r
.65117 .59802 m .64849 .59616 L .64906 .59849 L F
.397 0 0 r
.70323 .72968 m .70216 .73016 L .69949 .72951 L F
.542 0 0 r
.70323 .72968 m .70537 .73069 L .70216 .73016 L F
.62 .269 .354 r
.72884 .59336 m .72969 .59258 L .72914 .59471 L F
.613 .557 .768 r
.73123 .58958 m .72969 .59258 L .72884 .59336 L F
.73123 .58958 m .73221 .5928 L .72969 .59258 L F
.624 .404 .562 r
.72969 .59258 m .73247 .59499 L .72914 .59471 L F
.72969 .59258 m .73221 .5928 L .73247 .59499 L F
.167 .705 .774 r
.30259 .6061 m .30084 .60638 L .29909 .60652 L F
.594 .797 .977 r
.71609 .58365 m .71682 .58474 L .71366 .58461 L F
.238 .573 .941 r
.71819 .58491 m .71682 .58474 L .71609 .58365 L F
.614 .423 .601 r
.39452 .73936 m .39705 .73956 L .39674 .73656 L F
.461 .313 .592 r
.39674 .73656 m .39705 .73956 L .39882 .73872 L F
.115 0 0 r
.35125 .72075 m .34975 .72266 L .34844 .72254 L F
.113 0 0 r
.34975 .72266 m .34697 .72407 L .34844 .72254 L F
.219 0 .003 r
.35173 .72201 m .35125 .72075 L .35289 .71984 L F
.35173 .72201 m .34975 .72266 L .35125 .72075 L F
.785 .876 .914 r
.68338 .59312 m .68233 .59586 L .68234 .59527 L F
.68338 .59312 m .68482 .59421 L .68233 .59586 L F
.313 0 .074 r
.68233 .59586 m .6813 .59694 L .68234 .59527 L F
.68233 .59586 m .68372 .59696 L .6813 .59694 L F
.615 .47 .661 r
.37095 .68263 m .37326 .68235 L .37294 .67952 L F
.45 .287 .567 r
.37139 .68528 m .37326 .68235 L .37095 .68263 L F
.149 0 0 r
.71726 .71803 m .71643 .71931 L .71444 .71983 L F
.101 0 0 r
.72037 .71936 m .71643 .71931 L .71726 .71803 L F
.379 .658 .967 r
.71909 .62354 m .72075 .62256 L .7182 .6224 L F
.71909 .62354 m .72163 .62423 L .72075 .62256 L F
.454 .626 .926 r
.30602 .73405 m .307 .73356 L .30559 .7335 L F
0 0 0 r
.30553 .73455 m .307 .73356 L .30602 .73405 L F
.657 .136 0 r
.4928 .77688 m .49518 .77846 L .49596 .77762 L F
.626 .092 0 r
.49705 .77914 m .49596 .77762 L .49518 .77846 L F
.49705 .77914 m .49818 .77984 L .49596 .77762 L F
.745 .3 .194 r
.49596 .77762 m .49818 .77984 L .49965 .77971 L F
.56 .767 .975 r
.6321 .61454 m .63008 .61504 L .63051 .61745 L F
.6321 .61454 m .63156 .61382 L .63008 .61504 L F
.575 .538 .776 r
.40906 .75799 m .40794 .76177 L .40694 .75831 L F
.40906 .75799 m .41023 .76177 L .40794 .76177 L F
0 0 .067 r
.63524 .66628 m .63523 .66806 L .63488 .66836 L F
.894 .935 .835 r
.63524 .66628 m .63665 .6627 L .63599 .66504 L F
.612 .268 .362 r
.6558 .59483 m .65341 .59325 L .65269 .59499 L F
.633 .49 .67 r
.51518 .78499 m .51749 .78559 L .51738 .78321 L F
0 .551 .739 r
.51367 .78522 m .51749 .78559 L .51518 .78499 L F
.643 .586 .775 r
.70827 .62354 m .7093 .61945 L .70715 .62022 L F
.70827 .62354 m .7105 .62274 L .7093 .61945 L F
.693 .592 .739 r
.50665 .72315 m .50778 .72624 L .51033 .72501 L F
.701 .632 .776 r
.69164 .62789 m .69283 .62884 L .69167 .62602 L F
.703 .556 .685 r
.68974 .6307 m .69283 .62884 L .69164 .62789 L F
.68974 .6307 m .69284 .63112 L .69283 .62884 L F
.679 .621 .783 r
.69167 .62602 m .69283 .62884 L .69498 .6284 L F
.661 .522 .684 r
.69283 .62884 m .69284 .63112 L .69498 .6284 L F
.518 .146 .274 r
.68375 .58794 m .68308 .59082 L .68011 .58965 L F
.084 .09 .567 r
.68455 .58408 m .68492 .58682 L .68375 .58794 L F
0 0 .093 r
.68467 .58859 m .68375 .58794 L .68492 .58682 L F
.68467 .58859 m .68308 .59082 L .68375 .58794 L F
.813 .954 .909 r
.7227 .62566 m .72428 .62314 L .72163 .62423 L F
.7227 .62566 m .72538 .62369 L .72428 .62314 L F
.852 .743 .742 r
.57648 .69329 m .57803 .69614 L .57941 .69328 L F
.57648 .69329 m .57593 .69574 L .57803 .69614 L F
.672 .929 .971 r
.72428 .62314 m .72538 .62369 L .72721 .62255 L F
.513 .264 .474 r
.36299 .69872 m .36512 .69839 L .36552 .69628 L F
.478 .233 .463 r
.36552 .69628 m .36716 .69794 L .36756 .69577 L F
.36552 .69628 m .36512 .69839 L .36716 .69794 L F
.74 .558 .648 r
.62498 .61979 m .62833 .61977 L .62832 .61752 L F
.691 .519 .649 r
.62832 .61752 m .62833 .61977 L .63051 .61745 L F
.61 .747 .943 r
.5375 .72349 m .53509 .72423 L .53396 .72281 L F
.537 .112 .182 r
.43652 .726 m .43841 .72715 L .43984 .7254 L F
.459 0 .06 r
.43841 .72715 m .44203 .72571 L .43984 .7254 L F
.088 0 .182 r
.61503 .67692 m .61678 .6761 L .61748 .67438 L F
.148 0 .311 r
.61503 .67692 m .61493 .67905 L .61678 .6761 L F
.457 .865 .958 r
.35984 .9121 m .35917 .91288 L .35783 .91265 L F
.35783 .91265 m .35917 .91288 L .35984 .9121 L F
.945 .882 .741 r
.64585 .63858 m .64321 .64096 L .64399 .64152 L F
.64585 .63858 m .64474 .63772 L .64321 .64096 L F
.409 .165 .43 r
.39127 .68507 m .39108 .68759 L .38888 .68781 L F
.351 .119 .416 r
.39265 .68691 m .39127 .68507 L .39323 .68455 L F
.39265 .68691 m .39108 .68759 L .39127 .68507 L F
.106 .655 .816 r
.35973 .64963 m .36318 .64976 L .36119 .65046 L F
.78 .793 .864 r
.6524 .61698 m .6557 .6158 L .65488 .61446 L F
.734 .743 .859 r
.6557 .6158 m .65822 .61487 L .65488 .61446 L F
.473 .629 .921 r
.70968 .73421 m .71161 .73415 L .71126 .73283 L F
.211 .295 .732 r
.57421 .70032 m .57522 .70359 L .57349 .70147 L F
.917 .952 .801 r
.54569 .69597 m .54493 .69532 L .54699 .69242 L F
.908 .968 .804 r
.54569 .69597 m .54498 .69534 L .54493 .69532 L F
.54569 .69597 m .54551 .6962 L .54498 .69534 L F
.917 .952 .801 r
.54569 .69597 m .54699 .69242 L .54829 .69336 L F
.318 0 0 r
.44754 .72521 m .44969 .72534 L .45119 .72488 L F
.556 .034 0 r
.45119 .72488 m .44969 .72534 L .4531 .72554 L F
.474 .138 .316 r
.70764 .71492 m .71014 .71464 L .71053 .71242 L F
.198 0 0 r
.71014 .71464 m .71287 .71331 L .71053 .71242 L F
.452 .213 .459 r
.66119 .59267 m .65918 .5932 L .6589 .5952 L F
.858 .509 .391 r
.52208 .72858 m .52065 .72983 L .51874 .72815 L F
.52208 .72858 m .52243 .73056 L .52065 .72983 L F
.918 .555 .327 r
.55722 .72327 m .55498 .7226 L .55478 .72021 L F
.952 .637 .397 r
.55722 .72327 m .55617 .72498 L .55498 .7226 L F
.55722 .72327 m .55751 .72549 L .55617 .72498 L F
.533 .373 .609 r
.40226 .67395 m .40022 .67438 L .40211 .67164 L F
.487 .278 .521 r
.40226 .67395 m .40006 .67667 L .40022 .67438 L F
.457 .528 .842 r
.38976 .6598 m .38947 .66298 L .3884 .66013 L F
.38976 .6598 m .39118 .66281 L .38947 .66298 L F
.514 .123 .238 r
.34929 .70858 m .3529 .70654 L .3509 .70704 L F
0 .488 .813 r
.3669 .6515 m .36866 .65195 L .37008 .6526 L F
.21 .646 .951 r
.3707 .65199 m .37008 .6526 L .36866 .65195 L F
.3707 .65199 m .37221 .65289 L .37008 .6526 L F
.904 .788 .723 r
.54443 .70086 m .54498 .69534 L .54551 .6962 L F
.809 .778 .824 r
.64605 .62748 m .64991 .62639 L .64842 .62501 L F
.823 .808 .837 r
.64842 .62501 m .64991 .62639 L .65109 .62472 L F
.768 .532 .576 r
.58208 .74709 m .57905 .74773 L .58121 .74707 L F
.58208 .74709 m .58063 .74929 L .57905 .74773 L F
.58208 .74709 m .58215 .75034 L .58063 .74929 L F
.829 .582 .565 r
.5835 .74919 m .58215 .75034 L .58208 .74709 L F
.592 .491 .709 r
.30184 .70602 m .30063 .70964 L .29983 .70682 L F
.30184 .70602 m .30289 .70971 L .30063 .70964 L F
.474 .53 .835 r
.66964 .61797 m .67141 .61577 L .66949 .6169 L F
.66964 .61797 m .67278 .61942 L .67141 .61577 L F
.58 .787 .977 r
.40125 .66888 m .39914 .66941 L .39781 .66832 L F
0 .275 .691 r
.53279 .72202 m .53172 .72159 L .53047 .72057 L F
.53279 .72202 m .53396 .72281 L .53172 .72159 L F
.697 .206 .076 r
.65757 .61147 m .6604 .61206 L .65918 .6127 L F
.335 .817 .851 r
.6604 .61206 m .66204 .61135 L .65918 .6127 L F
.6604 .61206 m .6629 .6114 L .66204 .61135 L F
.096 0 0 r
.5118 .71 m .51397 .70979 L .51514 .70942 L F
.135 0 0 r
.51397 .70979 m .51736 .70908 L .51514 .70942 L F
.665 .88 .978 r
.68836 .70632 m .68725 .70786 L .68613 .70644 L F
.68836 .70632 m .68942 .70708 L .68725 .70786 L F
.471 .417 .715 r
.58177 .70422 m .58278 .70071 L .58055 .70118 L F
.58177 .70422 m .5837 .70366 L .58278 .70071 L F
.436 .307 .606 r
.58177 .70422 m .58389 .70615 L .5837 .70366 L F
.477 .307 .571 r
.58177 .70422 m .5818 .70654 L .58389 .70615 L F
.303 0 0 r
.33394 .65063 m .33802 .64927 L .33562 .65008 L F
.896 .597 .471 r
.54825 .70695 m .54668 .7068 L .5458 .70393 L F
.845 .449 .296 r
.54825 .70695 m .5473 .70844 L .54668 .7068 L F
.964 .655 .389 r
.54825 .70695 m .54859 .70922 L .5473 .70844 L F
.364 0 0 r
.44203 .72571 m .44415 .72567 L .44547 .7249 L F
.514 .038 .063 r
.44547 .7249 m .44415 .72567 L .44754 .72521 L F
.446 .274 .553 r
.53585 .73893 m .53765 .73899 L .5375 .73669 L F
.32 .448 .834 r
.3931 .66269 m .39303 .66537 L .39118 .66281 L F
.3931 .66269 m .39447 .66554 L .39303 .66537 L F
.898 .758 .699 r
.64588 .63351 m .6471 .63025 L .64473 .63039 L F
.821 1 .827 r
.56949 .67225 m .56707 .67471 L .56766 .67302 L F
.803 .99 .881 r
.56766 .67302 m .56707 .67471 L .56477 .67547 L F
.57 .469 .701 r
.38026 .77757 m .38168 .77441 L .37973 .77498 L F
.498 .467 .753 r
.41515 .77359 m .41315 .77477 L .41268 .77178 L F
.599 .571 .794 r
.41515 .77359 m .414 .77696 L .41315 .77477 L F
.899 .883 .808 r
.6397 .66057 m .63665 .6627 L .63765 .66323 L F
.832 .707 .727 r
.57815 .69023 m .57648 .69329 L .57941 .69328 L F
.156 .318 .776 r
.57941 .69328 m .57815 .69023 L .58147 .69028 L F
.57941 .69328 m .58038 .69215 L .57815 .69023 L F
.414 .706 .983 r
.57941 .69328 m .58178 .69327 L .58038 .69215 L F
.395 0 .109 r
.47963 .72223 m .48302 .72025 L .48096 .72086 L F
.777 .642 .712 r
.41148 .75295 m .40916 .75548 L .40929 .75314 L F
.69 .666 .821 r
.73257 .60881 m .73594 .60951 L .73372 .61178 L F
.571 .474 .705 r
.73594 .60951 m .73658 .61158 L .73372 .61178 L F
.545 .32 .524 r
.73372 .61178 m .73658 .61158 L .7361 .61384 L F
0 0 .081 r
.71424 .7286 m .71421 .73095 L .71417 .73073 L F
.08 .132 .616 r
.71644 .73097 m .71602 .73403 L .71443 .73119 L F
.71644 .73097 m .71443 .73119 L .71417 .73073 L F
.237 0 0 r
.7188 .73017 m .71768 .73084 L .71644 .73097 L F
.08 .132 .616 r
.71644 .73097 m .7171 .73336 L .71602 .73403 L F
.244 .24 .655 r
.7181 .7312 m .7171 .73336 L .71644 .73097 L F
.251 0 0 r
.71644 .73097 m .71568 .73203 L .7181 .7312 L F
.237 0 0 r
.71768 .73084 m .71568 .73203 L .71644 .73097 L F
.08 .132 .616 r
.71644 .73097 m .71417 .73073 L .71421 .73095 L F
.354 0 .172 r
.59902 .64449 m .60094 .64393 L .60203 .64201 L F
.454 .074 .227 r
.60203 .64201 m .60398 .64291 L .60418 .64148 L F
.60203 .64201 m .60094 .64393 L .60398 .64291 L F
.514 .566 .846 r
.71585 .72908 m .71421 .73095 L .71424 .7286 L F
.71585 .72908 m .71424 .7286 L .71316 .72922 L F
.274 .742 .944 r
.32346 .73672 m .32289 .73603 L .31946 .73624 L F
.906 .963 .642 r
.32452 .73368 m .32346 .73672 L .32561 .73369 L F
.32452 .73368 m .32289 .73603 L .32346 .73672 L F
.508 .818 1 r
.40461 .73326 m .40643 .73342 L .4036 .73249 L F
.518 .265 .471 r
.40447 .73652 m .40676 .73627 L .40643 .73342 L F
.598 .5 .714 r
.68983 .57945 m .69257 .57951 L .69117 .57838 L F
.753 .68 .78 r
.68981 .62876 m .68744 .6313 L .68974 .6307 L F
.703 .556 .685 r
.68974 .6307 m .69164 .62789 L .68981 .62876 L F
.641 .444 .601 r
.62833 .61977 m .63071 .62026 L .63051 .61745 L F
.593 .514 .735 r
.63051 .61745 m .63286 .61699 L .6321 .61454 L F
.499 .309 .554 r
.63071 .62026 m .63286 .61699 L .63051 .61745 L F
.272 0 0 r
.53054 .7801 m .53153 .78107 L .53277 .78001 L F
.53054 .7801 m .52926 .7815 L .53153 .78107 L F
.383 .165 .455 r
.39049 .68957 m .38888 .68781 L .39108 .68759 L F
.39049 .68957 m .38887 .69024 L .38888 .68781 L F
.375 .176 .477 r
.28933 .63345 m .28907 .63574 L .2873 .63639 L F
.426 .24 .524 r
.28907 .63574 m .28702 .63861 L .2873 .63639 L F
.872 .462 .243 r
.57061 .73902 m .56929 .73876 L .56864 .73702 L F
.866 .524 .401 r
.57214 .74162 m .56929 .73876 L .57061 .73902 L F
.646 .381 .504 r
.60973 .69965 m .60611 .70348 L .60633 .7019 L F
.60973 .69965 m .60841 .70327 L .60611 .70348 L F
.548 .341 .552 r
.61165 .69858 m .61182 .70036 L .60973 .69965 L F
.619 .353 .493 r
.61137 .70275 m .60973 .69965 L .61182 .70036 L F
.61137 .70275 m .60841 .70327 L .60973 .69965 L F
.277 0 .221 r
.36532 .71212 m .36277 .71431 L .36356 .71279 L F
.599 .571 .794 r
.41515 .77359 m .41616 .77639 L .414 .77696 L F
.609 .647 .863 r
.41616 .77639 m .41738 .77816 L .414 .77696 L F
.494 .226 .436 r
.41699 .7501 m .41677 .75277 L .41475 .75311 L F
.589 .305 .453 r
.41956 .75236 m .41699 .7501 L .4191 .75021 L F
.41956 .75236 m .41677 .75277 L .41699 .7501 L F
.589 .326 .486 r
.60387 .70142 m .60377 .70365 L .60083 .70382 L F
.609 .342 .488 r
.60387 .70142 m .60611 .70348 L .60377 .70365 L F
.674 .32 .367 r
.60633 .7019 m .60611 .70348 L .60387 .70142 L F
.417 0 0 r
.46283 .77988 m .46377 .78098 L .4617 .78088 L F
.46283 .77988 m .46494 .78012 L .46377 .78098 L F
.125 .674 .739 r
.46077 .77239 m .46302 .77208 L .46381 .77203 L F
.282 0 0 r
.46466 .77275 m .46381 .77203 L .46302 .77208 L F
.46466 .77275 m .46589 .77227 L .46381 .77203 L F
.578 .459 .681 r
.68273 .60971 m .68245 .60965 L .68164 .60913 L F
.68273 .60971 m .68477 .6092 L .68245 .60965 L F
.463 .886 .909 r
.32625 .73297 m .32561 .73369 L .32762 .73338 L F
.32625 .73297 m .32452 .73368 L .32561 .73369 L F
.664 .477 .622 r
.37977 .79031 m .38298 .79108 L .38277 .78818 L F
.645 .68 .869 r
.38277 .78818 m .38365 .78529 L .38144 .78569 L F
.38277 .78818 m .38518 .78805 L .38365 .78529 L F
.643 .461 .622 r
.38277 .78818 m .38523 .79031 L .38518 .78805 L F
.38277 .78818 m .38298 .79108 L .38523 .79031 L F
.416 .04 .215 r
.68485 .58265 m .68232 .58423 L .68144 .58146 L F
.347 0 .197 r
.68647 .58292 m .68455 .58408 L .68485 .58265 L F
.878 .895 .84 r
.70089 .718 m .70069 .72013 L .69996 .71824 L F
.668 .604 .775 r
.70249 .71712 m .70069 .72013 L .70089 .718 L F
.70249 .71712 m .70419 .72029 L .70069 .72013 L F
.596 .509 .726 r
.70423 .72328 m .70069 .72013 L .70419 .72029 L F
.70423 .72328 m .70187 .72415 L .70069 .72013 L F
.567 .546 .79 r
.37294 .67952 m .37526 .67916 L .37431 .67688 L F
.533 .41 .658 r
.37294 .67952 m .37526 .68185 L .37526 .67916 L F
.37294 .67952 m .37326 .68235 L .37526 .68185 L F
.753 .791 .884 r
.72298 .71998 m .72687 .71988 L .72532 .71956 L F
.081 .629 .832 r
.72687 .71988 m .72854 .71992 L .72532 .71956 L F
.527 .471 .737 r
.41384 .76815 m .41268 .77178 L .41216 .7695 L F
.314 .087 .401 r
.63976 .60701 m .64149 .60603 L .64169 .60413 L F
.529 .346 .577 r
.64169 .60413 m .64414 .60368 L .64408 .60109 L F
.379 .139 .42 r
.64169 .60413 m .64357 .60502 L .64414 .60368 L F
.64169 .60413 m .64149 .60603 L .64357 .60502 L F
.636 .482 .657 r
.39015 .74486 m .39254 .74465 L .3923 .74212 L F
.52 .406 .664 r
.39015 .74486 m .39242 .74688 L .39254 .74465 L F
.39015 .74486 m .3905 .74737 L .39242 .74688 L F
.436 0 .097 r
.53393 .78531 m .5305 .78701 L .53199 .78612 L F
.594 .797 .977 r
.71609 .58365 m .71366 .58461 L .713 .58232 L F
0 0 0 r
.49725 .72702 m .49675 .7268 L .4987 .72562 L F
.49725 .72702 m .49566 .72814 L .49675 .7268 L F
.46 .286 .558 r
.36765 .6933 m .36953 .6928 L .36957 .69045 L F
.454 .279 .553 r
.36765 .6933 m .36941 .69518 L .36953 .6928 L F
.36765 .6933 m .36756 .69577 L .36941 .69518 L F
.21 .683 .938 r
.68403 .61448 m .68276 .61394 L .68151 .61399 L F
.695 .254 .2 r
.68403 .61448 m .68311 .61596 L .68276 .61394 L F
.68403 .61448 m .68634 .61623 L .68311 .61596 L F
.561 .389 .605 r
.3861 .75285 m .38848 .75254 L .38836 .75003 L F
.546 .372 .596 r
.3862 .75516 m .38848 .75254 L .3861 .75285 L F
.629 .914 .98 r
.50192 .71326 m .50306 .71186 L .50416 .71244 L F
.50192 .71326 m .50016 .713 L .50306 .71186 L F
.578 .511 .743 r
.5876 .73127 m .58928 .72726 L .58672 .72809 L F
.5876 .73127 m .58981 .73088 L .58928 .72726 L F
.671 .541 .698 r
.43666 .74949 m .43368 .75055 L .43563 .74745 L F
.428 .05 .218 r
.43573 .75043 m .43368 .75055 L .43666 .74949 L F
.52 .352 .594 r
.43563 .74745 m .43368 .75055 L .43573 .75043 L F
.497 .476 .764 r
.37108 .67188 m .37215 .6745 L .37383 .67376 L F
.379 .374 .728 r
.37215 .6745 m .37351 .6748 L .37383 .67376 L F
.59 .102 .064 r
.4975 .78238 m .49587 .78287 L .49388 .78229 L F
.514 0 0 r
.49973 .78431 m .49587 .78287 L .4975 .78238 L F
.608 .325 .461 r
.71013 .71995 m .7064 .72244 L .70615 .72032 L F
.71013 .71995 m .70873 .72268 L .7064 .72244 L F
.604 .32 .459 r
.71276 .72221 m .71013 .71995 L .71201 .7205 L F
.71276 .72221 m .70873 .72268 L .71013 .71995 L F
.248 .062 .42 r
.59039 .72021 m .59008 .72273 L .58869 .72313 L F
.315 .249 .622 r
.59008 .72273 m .59067 .72509 L .58869 .72313 L F
.37 .255 .59 r
.59067 .72509 m .58892 .72567 L .58869 .72313 L F
.67 .715 .882 r
.41827 .77584 m .41738 .77816 L .41616 .77639 L F
.41827 .77584 m .41941 .77732 L .41738 .77816 L F
.875 .819 .79 r
.57349 .71882 m .57521 .72068 L .57647 .71811 L F
.764 .358 .283 r
.57374 .72193 m .57521 .72068 L .57349 .71882 L F
.57374 .72193 m .57641 .72254 L .57521 .72068 L F
.626 .272 .349 r
.5835 .74919 m .58245 .75169 L .58215 .75034 L F
.794 .515 .515 r
.58565 .75013 m .58245 .75169 L .5835 .74919 L F
.594 .43 .628 r
.30609 .69852 m .30503 .69739 L .3062 .69618 L F
.30609 .69852 m .30401 .69896 L .30503 .69739 L F
.699 .474 .579 r
.71602 .73403 m .71553 .73663 L .7172 .73631 L F
.029 .201 .707 r
.72889 .59714 m .72811 .59832 L .72713 .5962 L F
0 0 0 r
.72737 .60098 m .72811 .59832 L .72889 .59714 L F
0 .531 .746 r
.4531 .72554 m .45527 .7258 L .45651 .72603 L F
.227 .733 .894 r
.45527 .7258 m .45871 .72592 L .45651 .72603 L F
.83 .565 .538 r
.5375 .73669 m .53765 .73899 L .54028 .73922 L F
.821 .676 .703 r
.7105 .62274 m .71172 .61992 L .7093 .61945 L F
.899 .883 .808 r
.6397 .66057 m .63874 .65969 L .63665 .6627 L F
.955 .829 .68 r
.64053 .65577 m .64039 .65181 L .64001 .65409 L F
0 0 .268 r
.64053 .65577 m .64001 .65409 L .64008 .65431 L F
0 0 .043 r
.64127 .65623 m .64086 .65679 L .64096 .6571 L F
.64096 .6571 m .63874 .65969 L .6397 .66057 L F
.64086 .65679 m .63874 .65969 L .64096 .6571 L F
.64127 .65623 m .64105 .65723 L .63874 .65969 L F
.921 .54 .264 r
.64053 .65577 m .64105 .65723 L .64127 .65623 L F
0 0 .268 r
.64061 .65599 m .64008 .65431 L .64105 .65723 L F
.64053 .65577 m .64008 .65431 L .64061 .65599 L F
.78 .275 0 r
.4064 .79362 m .40573 .79423 L .40502 .79293 L F
.4064 .79362 m .40832 .79609 L .40573 .79423 L F
.961 .725 .536 r
.40851 .79324 m .40832 .79609 L .4064 .79362 L F
.599 .447 .646 r
.30609 .69852 m .30401 .70121 L .30401 .69896 L F
.448 .845 .977 r
.33811 .65016 m .33824 .65016 L .33981 .65026 L F
.559 0 0 r
.33802 .64927 m .33981 .65026 L .34103 .65033 L F
.448 .845 .977 r
.33824 .65016 m .34177 .65011 L .33981 .65026 L F
.559 0 0 r
.34103 .65033 m .33981 .65026 L .34113 .65037 L F
0 .5 .854 r
.34177 .65011 m .34113 .65037 L .33981 .65026 L F
.34177 .65011 m .34279 .65071 L .34113 .65037 L F
.211 .48 .892 r
.72124 .58637 m .7206 .58744 L .71819 .58491 L F
.206 .474 .889 r
.72124 .58637 m .72189 .58773 L .7206 .58744 L F
.53 .284 .488 r
.41016 .65693 m .4077 .66035 L .40765 .65806 L F
.41016 .65693 m .40988 .65997 L .4077 .66035 L F
.59 .501 .722 r
.4077 .66035 m .40988 .65997 L .40931 .65785 L F
.151 0 0 r
.40856 .65765 m .40955 .65778 L .41016 .65693 L F
.40765 .65806 m .40921 .65783 L .40856 .65765 L F
.40921 .65783 m .40955 .65778 L .40856 .65765 L F
.314 .104 .427 r
.412 .65709 m .40988 .65997 L .41016 .65693 L F
0 .088 .611 r
.40991 .65801 m .40988 .65997 L .41064 .65872 L F
.151 0 0 r
.40955 .65778 m .40973 .65775 L .40975 .65771 L F
.409 .442 .784 r
.40916 .65727 m .40973 .65775 L .40765 .65806 L F
0 .088 .611 r
.40916 .65727 m .40931 .65785 L .40991 .65801 L F
.40931 .65785 m .40988 .65997 L .40991 .65801 L F
.59 .501 .722 r
.4088 .65802 m .40931 .65785 L .40916 .65727 L F
.4077 .66035 m .40931 .65785 L .4088 .65802 L F
.151 0 0 r
.40955 .65778 m .40975 .65771 L .41016 .65693 L F
.258 0 0 r
.41016 .65693 m .40973 .65775 L .412 .65709 L F
.606 .425 .61 r
.59641 .70683 m .5966 .70932 L .59404 .70963 L F
.528 .355 .591 r
.59847 .70404 m .59858 .70642 L .59641 .70683 L F
.527 .366 .605 r
.59876 .7086 m .59641 .70683 L .59858 .70642 L F
.59876 .7086 m .5966 .70932 L .59641 .70683 L F
.45 .287 .567 r
.37139 .68528 m .37322 .68484 L .37326 .68235 L F
.488 .412 .697 r
.37139 .68528 m .37372 .68723 L .37322 .68484 L F
.532 .412 .661 r
.3717 .68767 m .37372 .68723 L .37139 .68528 L F
.545 .195 .325 r
.45666 .73854 m .45539 .7411 L .45319 .74114 L F
.579 .254 .383 r
.45878 .73872 m .45539 .7411 L .45666 .73854 L F
.387 .161 .445 r
.70037 .5796 m .69883 .58205 L .70102 .5793 L F
0 0 0 r
.70039 .58142 m .69883 .58205 L .70037 .5796 L F
.362 .011 .229 r
.70285 .58052 m .70039 .58142 L .70037 .5796 L F
.493 .799 .999 r
.28826 .60204 m .28479 .60156 L .28691 .60136 L F
.305 .712 .976 r
.28909 .60129 m .28826 .60204 L .28691 .60136 L F
.28909 .60129 m .2904 .60206 L .28826 .60204 L F
.891 .47 .174 r
.56864 .73702 m .5679 .73808 L .56561 .73593 L F
.56864 .73702 m .56929 .73876 L .5679 .73808 L F
.494 .292 .534 r
.3923 .74212 m .39427 .74179 L .39452 .73936 L F
.557 .44 .675 r
.39254 .74465 m .39427 .74179 L .3923 .74212 L F
.633 .43 .59 r
.59288 .69304 m .59591 .69283 L .59602 .69058 L F
.587 .351 .525 r
.59591 .69283 m .59817 .69053 L .59602 .69058 L F
.478 .276 .527 r
.30826 .69571 m .30609 .69852 L .3062 .69618 L F
.702 .524 .645 r
.58604 .69615 m .58613 .69845 L .58824 .69596 L F
.688 .505 .633 r
.58613 .69845 m .58846 .69856 L .58824 .69596 L F
.618 .452 .635 r
.58824 .69596 m .59086 .69823 L .59105 .69521 L F
.58824 .69596 m .58846 .69856 L .59086 .69823 L F
.448 .427 .743 r
.72914 .59471 m .72713 .5962 L .72704 .59333 L F
.029 .201 .707 r
.72889 .59714 m .72713 .5962 L .72914 .59471 L F
.633 .338 .453 r
.61347 .65193 m .6121 .65453 L .60989 .65268 L F
.749 .542 .614 r
.61547 .65243 m .6121 .65453 L .61347 .65193 L F
.215 0 .01 r
.32271 .65587 m .32171 .65703 L .32463 .65526 L F
.61 .722 .925 r
.30759 .74208 m .30886 .74064 L .30666 .74102 L F
.30759 .74208 m .31018 .74212 L .30886 .74064 L F
.759 .68 .774 r
.68848 .62748 m .69164 .62789 L .69167 .62602 L F
.771 .64 .717 r
.68848 .62748 m .68981 .62876 L .69164 .62789 L F
.643 .843 .977 r
.58147 .69028 m .57815 .69023 L .58028 .68945 L F
.567 .566 .812 r
.58254 .68707 m .58147 .69028 L .58028 .68945 L F
.58254 .68707 m .5837 .69017 L .58147 .69028 L F
.876 .828 .797 r
.55027 .6904 m .54699 .69242 L .54985 .6903 L F
.55027 .6904 m .54829 .69336 L .54699 .69242 L F
.764 .981 .727 r
.55027 .6904 m .55135 .68853 L .55241 .68918 L F
.55027 .6904 m .54985 .6903 L .55135 .68853 L F
.653 .591 .773 r
.69498 .6284 m .69838 .631 L .69718 .62785 L F
.891 .855 .8 r
.58822 .67157 m .59032 .67093 L .58957 .67032 L F
.58822 .67157 m .58859 .67352 L .59032 .67093 L F
.589 .448 .658 r
.59166 .7122 m .59196 .71462 L .58963 .71494 L F
.488 .33 .593 r
.59196 .71462 m .59009 .71697 L .58963 .71494 L F
.253 .021 .355 r
.62001 .68997 m .61857 .69075 L .62055 .68797 L F
.319 .091 .403 r
.61973 .69176 m .61857 .69075 L .62001 .68997 L F
.61973 .69176 m .61798 .69282 L .61857 .69075 L F
.709 .903 .965 r
.50973 .71046 m .50601 .71112 L .50858 .70988 L F
.629 .894 .987 r
.50973 .71046 m .51058 .709 L .5118 .71 L F
.50973 .71046 m .50858 .70988 L .51058 .709 L F
.803 .934 .567 r
.54283 .77905 m .54127 .78182 L .54228 .7805 L F
.961 .725 .536 r
.40851 .79324 m .40978 .7962 L .40832 .79609 L F
.949 .656 .448 r
.41092 .79328 m .40995 .79316 L .41174 .79232 L F
.188 .341 .787 r
.41064 .79507 m .40978 .7962 L .40873 .79374 L F
.41064 .79507 m .40873 .79374 L .40902 .79368 L F
.383 .377 .728 r
.40995 .79316 m .41064 .79507 L .40851 .79324 L F
.188 .341 .787 r
.40902 .79368 m .40873 .79374 L .40851 .79324 L F
.578 .377 .572 r
.40851 .79324 m .41064 .79507 L .40832 .79609 L F
.949 .656 .448 r
.40918 .79532 m .41064 .79507 L .40995 .79316 L F
.40918 .79532 m .40982 .79351 L .41092 .79328 L F
.40982 .79351 m .40995 .79316 L .41092 .79328 L F
.616 .939 .953 r
.41064 .79507 m .40978 .7962 L .40832 .79609 L F
.513 .391 .65 r
.38451 .75852 m .38648 .75821 L .3862 .75516 L F
.531 .421 .673 r
.38451 .75852 m .38687 .7605 L .38648 .75821 L F
.38451 .75852 m .38489 .76095 L .38687 .7605 L F
.59 .501 .722 r
.4077 .66035 m .40916 .65727 L .40765 .65806 L F
.658 .687 .866 r
.68595 .60562 m .68273 .60971 L .68266 .60488 L F
.63 .637 .838 r
.68595 .60562 m .68477 .6092 L .68273 .60971 L F
.593 .416 .611 r
.38179 .77191 m .38374 .77411 L .38405 .77159 L F
.38179 .77191 m .38168 .77441 L .38374 .77411 L F
.322 0 0 r
.71287 .71331 m .71506 .71325 L .71614 .71206 L F
.056 0 0 r
.71506 .71325 m .71842 .71232 L .71614 .71206 L F
.398 .788 .989 r
.43489 .75576 m .43335 .7551 L .43128 .75532 L F
.43128 .75532 m .43335 .7551 L .43489 .75576 L F
.445 0 0 r
.43335 .7551 m .43563 .75563 L .43489 .75576 L F
.644 .173 .12 r
.43563 .75563 m .43335 .7551 L .43489 .75576 L F
.398 .788 .989 r
.43489 .75576 m .43335 .7551 L .43128 .75532 L F
.721 .935 .61 r
.57163 .66953 m .56949 .67225 L .57022 .67085 L F
.738 .992 .826 r
.57022 .67085 m .56949 .67225 L .56766 .67302 L F
.572 .56 .802 r
.73257 .60881 m .73031 .60926 L .72927 .60612 L F
.693 .592 .739 r
.50665 .72315 m .51033 .72501 L .50956 .72342 L F
.653 .625 .809 r
.50956 .72342 m .51033 .72501 L .51177 .72275 L F
.512 .553 .835 r
.48177 .73555 m .48203 .73257 L .48028 .73383 L F
.48177 .73555 m .48323 .73538 L .48203 .73257 L F
.622 .796 .966 r
.32084 .71242 m .3174 .71198 L .31945 .7116 L F
.432 .771 .997 r
.31945 .7116 m .32288 .71223 L .32084 .71242 L F
.129 .307 .775 r
.68585 .71186 m .68796 .71416 L .68641 .71078 L F
.57 .469 .701 r
.38026 .77757 m .38231 .77716 L .38168 .77441 L F
.533 .461 .721 r
.38026 .77757 m .38271 .77956 L .38231 .77716 L F
.38026 .77757 m .3808 .77999 L .38271 .77956 L F
.361 .038 .276 r
.39427 .74179 m .39705 .73956 L .39452 .73936 L F
0 0 0 r
.63835 .60869 m .64149 .60603 L .63976 .60701 L F
.686 .743 .895 r
.6508 .60649 m .65425 .60884 L .6526 .60578 L F
.754 .704 .805 r
.6526 .60578 m .65425 .60884 L .65592 .60614 L F
.442 .305 .598 r
.65425 .60884 m .65634 .60843 L .65592 .60614 L F
.582 .512 .741 r
.65425 .60884 m .65757 .61147 L .65634 .60843 L F
.773 .681 .762 r
.68387 .63273 m .68538 .63413 L .68744 .6313 L F
.227 .405 .831 r
.5297 .71899 m .52879 .72023 L .52733 .71741 L F
.281 .484 .878 r
.5297 .71899 m .53047 .72057 L .52879 .72023 L F
.776 .503 .522 r
.68459 .57723 m .68593 .57692 L .68586 .57671 L F
.68593 .57692 m .68855 .57632 L .68586 .57671 L F
.008 0 0 r
.68633 .57621 m .68581 .57654 L .68586 .57671 L F
.68581 .57654 m .68213 .57888 L .68586 .57671 L F
.28 0 .055 r
.68855 .57632 m .68909 .57494 L .68633 .57621 L F
.201 0 0 r
.68855 .57632 m .68633 .57621 L .68586 .57671 L F
.565 .392 .607 r
.59105 .69521 m .59351 .69536 L .59288 .69304 L F
.593 .403 .594 r
.59086 .69823 m .59351 .69536 L .59105 .69521 L F
.666 .467 .606 r
.58065 .69866 m .58278 .70071 L .58265 .69888 L F
.639 .401 .541 r
.58278 .70071 m .58613 .69845 L .58265 .69888 L F
.774 .688 .769 r
.7172 .73631 m .7199 .73693 L .72057 .73488 L F
.599 .531 .75 r
.7172 .73631 m .72108 .73873 L .7199 .73693 L F
.875 .596 .512 r
.68113 .62555 m .67956 .62723 L .67954 .62492 L F
.68113 .62555 m .68133 .62803 L .67956 .62723 L F
.416 .056 .244 r
.30467 .66844 m .30675 .6681 L .30787 .66596 L F
.338 0 .176 r
.30675 .6681 m .30987 .66553 L .30787 .66596 L F
.556 .372 .587 r
.67824 .58815 m .67948 .58843 L .68042 .58559 L F
.507 .49 .773 r
.67824 .58815 m .68011 .58965 L .67948 .58843 L F
.012 .308 .8 r
.33045 .84747 m .33069 .84764 L .33064 .84776 L F
.632 .963 .878 r
.33064 .84776 m .33069 .84764 L .33044 .8478 L F
.282 0 .006 r
.54044 .78406 m .53959 .78286 L .54127 .78182 L F
.54044 .78406 m .5383 .78454 L .53959 .78286 L F
.344 .469 .843 r
.37108 .67188 m .37213 .67044 L .37008 .67118 L F
.37108 .67188 m .37383 .67376 L .37213 .67044 L F
.612 .499 .701 r
.38075 .78256 m .38271 .77956 L .3808 .77999 L F
.146 .69 .756 r
.49119 .72913 m .49189 .72892 L .48961 .7291 L F
.49119 .72913 m .49321 .72883 L .49189 .72892 L F
.403 .694 .979 r
.50665 .72315 m .50734 .72179 L .50535 .72225 L F
.655 .561 .737 r
.50956 .72342 m .50986 .72385 L .50665 .72315 L F
.403 .694 .979 r
.50665 .72315 m .50986 .72385 L .50734 .72179 L F
0 .463 .854 r
.68687 .59491 m .68482 .59421 L .68338 .59312 L F
.144 0 0 r
.4384 .7853 m .43708 .78615 L .43485 .78646 L F
.329 0 0 r
.44055 .78499 m .43708 .78615 L .4384 .7853 L F
.52 .283 .496 r
.59404 .70963 m .59397 .71177 L .59166 .7122 L F
.628 .371 .509 r
.59634 .71154 m .59397 .71177 L .59404 .70963 L F
.595 .381 .561 r
.5966 .70932 m .59634 .71154 L .59404 .70963 L F
.553 .126 .186 r
.53277 .78001 m .53465 .78114 L .5358 .7794 L F
.114 0 0 r
.53465 .78114 m .53777 .77888 L .5358 .7794 L F
.679 .621 .783 r
.69167 .62602 m .69498 .6284 L .69394 .62529 L F
.665 .619 .793 r
.69394 .62529 m .69498 .6284 L .69718 .62785 L F
.527 .339 .569 r
.40916 .75548 m .40694 .75831 L .40717 .75613 L F
.418 .692 .976 r
.33637 .8747 m .33688 .87471 L .33654 .87486 L F
0 0 0 r
.33636 .87496 m .33688 .87471 L .33654 .87486 L F
.51 .3 .53 r
.36073 .70142 m .36279 .701 L .36299 .69872 L F
.404 .211 .503 r
.36299 .69872 m .36459 .7002 L .36512 .69839 L F
.36299 .69872 m .36279 .701 L .36459 .7002 L F
.246 .757 .856 r
.32288 .71223 m .32509 .7119 L .32637 .71197 L F
.672 .925 .62 r
.32858 .70949 m .32637 .71197 L .32703 .71085 L F
.631 .951 .94 r
.32637 .71197 m .32509 .7119 L .32703 .71085 L F
.501 0 0 r
.41293 .80254 m .41297 .80227 L .41091 .80168 L F
.65 .473 .631 r
.41091 .80168 m .41297 .80227 L .41434 .80117 L F
.556 .212 .341 r
.41091 .80168 m .41434 .80117 L .41293 .80254 L F
.482 .843 .992 r
.72064 .72047 m .72298 .71998 L .72176 .71951 L F
.534 .531 .798 r
.40387 .67038 m .40211 .67164 L .40125 .66888 L F
.452 .336 .63 r
.40387 .67038 m .40226 .67395 L .40211 .67164 L F
.56 0 0 r
.54043 .7773 m .54283 .77905 L .544 .77715 L F
.637 .336 .444 r
.60989 .65268 m .6121 .65453 L .60979 .65446 L F
.845 .489 .379 r
.66406 .59552 m .66411 .59442 L .66119 .59267 L F
.368 .222 .548 r
.64408 .60109 m .64585 .60266 L .64578 .6004 L F
.64408 .60109 m .64414 .60368 L .64585 .60266 L F
.733 .836 .386 r
.43563 .74745 m .4357 .74699 L .43581 .7468 L F
.514 .39 .65 r
.43813 .74712 m .43666 .74949 L .43563 .74745 L F
0 0 .263 r
.43563 .74745 m .43627 .74897 L .4357 .74699 L F
.514 .39 .65 r
.43813 .74712 m .43757 .74903 L .43666 .74949 L F
.383 .044 .261 r
.43757 .74903 m .43573 .75043 L .43666 .74949 L F
.43757 .74903 m .4381 .74975 L .43573 .75043 L F
.214 .007 .369 r
.43991 .74656 m .43757 .74903 L .43813 .74712 L F
.43991 .74656 m .4381 .74975 L .43757 .74903 L F
.873 .809 .783 r
.43627 .74897 m .4381 .74975 L .43991 .74656 L F
.55 .2 .327 r
.43815 .74787 m .43666 .74877 L .43627 .74897 L F
0 0 .263 r
.43569 .74925 m .43573 .75043 L .43627 .74897 L F
.55 .2 .327 r
.43666 .74877 m .43499 .74979 L .43627 .74897 L F
0 0 .263 r
.43563 .74745 m .43569 .74925 L .43627 .74897 L F
.651 .536 .71 r
.62504 .62172 m .62498 .61979 L .62221 .62208 L F
0 .342 .82 r
.55254 .70179 m .55497 .70333 L .55425 .70329 L F
.645 .534 .714 r
.37977 .79031 m .3808 .7935 L .38298 .79108 L F
.243 .468 .877 r
.69192 .7073 m .69406 .7083 L .69301 .70933 L F
.465 .368 .661 r
.69301 .70933 m .69517 .7119 L .69349 .71227 L F
.753 .39 .367 r
.69169 .71122 m .69517 .7119 L .69301 .70933 L F
.69169 .71122 m .69301 .70933 L .69406 .7083 L F
.667 .516 .671 r
.51738 .78321 m .51749 .78559 L .51944 .78277 L F
.997 .795 .444 r
.64829 .60021 m .64905 .60105 L .64906 .59849 L F
.546 .392 .623 r
.64905 .60105 m .65117 .59802 L .64906 .59849 L F
.127 .671 .827 r
.48332 .77964 m .48159 .77953 L .47942 .77957 L F
.728 .26 .138 r
.48332 .77964 m .48478 .78041 L .48159 .77953 L F
.91 .547 .334 r
.55868 .70212 m .55744 .70327 L .55556 .70062 L F
.479 .243 .478 r
.55868 .70212 m .55865 .70441 L .56052 .70327 L F
.386 0 0 r
.55868 .70212 m .56176 .70399 L .56064 .70105 L F
.55868 .70212 m .56052 .70327 L .56176 .70399 L F
.584 .089 .044 r
.55868 .70212 m .56052 .70327 L .56064 .70105 L F
.55868 .70212 m .55744 .70327 L .56052 .70327 L F
.267 0 .3 r
.62222 .68708 m .62055 .68797 L .62295 .68537 L F
.371 .141 .43 r
.62222 .68708 m .62001 .68997 L .62055 .68797 L F
.873 .846 .815 r
.58822 .67157 m .58634 .67427 L .58859 .67352 L F
.819 .805 .838 r
.71116 .57824 m .70976 .5816 L .71017 .58182 L F
.583 .795 .98 r
.70976 .5816 m .70992 .58163 L .71017 .58182 L F
.819 .805 .838 r
.70896 .58089 m .71017 .58182 L .70885 .58102 L F
.71116 .57824 m .71019 .58172 L .70983 .58156 L F
.531 .827 .999 r
.71339 .58013 m .71483 .58085 L .70986 .58158 L F
.70983 .58157 m .70986 .58158 L .70976 .5816 L F
.71339 .58013 m .70986 .58158 L .70983 .58157 L F
.819 .805 .838 r
.71019 .58172 m .71017 .58182 L .70986 .58159 L F
.71019 .58172 m .70986 .58159 L .70983 .58156 L F
.531 .827 .999 r
.70983 .58157 m .70976 .5816 L .71116 .57824 L F
.819 .805 .838 r
.71116 .57824 m .70983 .58156 L .70896 .58089 L F
.531 .827 .999 r
.71339 .58013 m .70983 .58157 L .71116 .57824 L F
.58 .795 .981 r
.70992 .58163 m .71483 .58085 L .713 .58232 L F
.70976 .5816 m .70986 .58158 L .70992 .58163 L F
.70986 .58158 m .71483 .58085 L .70992 .58163 L F
.819 .805 .838 r
.71017 .58182 m .71017 .58182 L .70992 .58163 L F
.71017 .58182 m .70992 .58163 L .70896 .58089 L F
.583 .795 .98 r
.70992 .58163 m .713 .58232 L .71017 .58182 L F
.449 .527 .845 r
.71483 .58085 m .71609 .58365 L .713 .58232 L F
.335 0 .004 r
.43238 .74468 m .4309 .74634 L .42867 .74669 L F
.691 .275 .252 r
.43238 .74468 m .43581 .7468 L .4309 .74634 L F
.714 .423 .482 r
.62092 .65281 m .61752 .65461 L .61713 .65233 L F
.62092 .65281 m .62112 .65471 L .61752 .65461 L F
.326 .104 .416 r
.29326 .62545 m .29279 .62755 L .29122 .62806 L F
.396 .264 .581 r
.29279 .62755 m .2913 .63044 L .29122 .62806 L F
.651 .373 .485 r
.60961 .64087 m .61245 .63891 L .60967 .63907 L F
.44 .294 .586 r
.2913 .63044 m .29139 .63301 L .28933 .63345 L F
.409 .203 .487 r
.29139 .63301 m .28907 .63574 L .28933 .63345 L F
.072 .271 .759 r
.58436 .73883 m .58441 .73979 L .58268 .73692 L F
.99 .8 .554 r
.58354 .74177 m .58441 .73979 L .58436 .73883 L F
.493 .302 .55 r
.38836 .75003 m .39031 .7497 L .3905 .74737 L F
.478 .325 .595 r
.38836 .75003 m .39028 .75202 L .39031 .7497 L F
.38836 .75003 m .38848 .75254 L .39028 .75202 L F
.768 .647 .728 r
.68416 .63072 m .68744 .6313 L .6862 .62805 L F
.773 .681 .762 r
.68387 .63273 m .68744 .6313 L .68416 .63072 L F
.72 .623 .749 r
.6862 .62805 m .68744 .6313 L .68981 .62876 L F
0 0 0 r
.57163 .66953 m .57179 .66978 L .5731 .6682 L F
.57163 .66953 m .57022 .67085 L .57179 .66978 L F
.434 .068 .244 r
.42555 .73089 m .42773 .73051 L .42876 .72845 L F
.463 .112 .284 r
.42773 .73051 m .43088 .72808 L .42876 .72845 L F
.199 0 .029 r
.36143 .71613 m .36085 .71489 L .36277 .71431 L F
.36143 .71613 m .35956 .71682 L .36085 .71489 L F
.991 .882 .606 r
.64399 .64152 m .64269 .6432 L .64384 .64391 L F
.64399 .64152 m .64321 .64096 L .64269 .6432 L F
.353 0 .177 r
.3576 .70384 m .35959 .70351 L .36073 .70142 L F
.279 0 .137 r
.36073 .70142 m .36149 .70286 L .36279 .701 L F
.36073 .70142 m .35959 .70351 L .36149 .70286 L F
.299 .758 .951 r
.6629 .6114 m .66605 .61161 L .66481 .6112 L F
.6629 .6114 m .66605 .61161 L .66481 .6112 L F
0 .437 .856 r
.66605 .61161 m .66771 .61232 L .66709 .61154 L F
.988 .746 .361 r
.66807 .60016 m .66881 .60108 L .6688 .60324 L F
.264 0 .105 r
.601 .65881 m .59996 .65771 L .60214 .65726 L F
.601 .65881 m .59883 .65963 L .59996 .65771 L F
.362 0 0 r
.46081 .72588 m .4642 .7255 L .46202 .72556 L F
.711 .781 .907 r
.69034 .60888 m .68829 .60997 L .68707 .60855 L F
.726 .776 .892 r
.67278 .61942 m .67618 .61962 L .675 .61912 L F
.48 .69 .96 r
.67691 .61827 m .67618 .61962 L .675 .61912 L F
.67691 .61827 m .6783 .61951 L .67618 .61962 L F
.67691 .61827 m .67618 .61962 L .675 .61912 L F
.67691 .61827 m .6783 .61951 L .67618 .61962 L F
.666 .467 .606 r
.58065 .69866 m .58055 .70118 L .58278 .70071 L F
.62 .391 .549 r
.67902 .58578 m .67658 .58474 L .68042 .58559 L F
.876 .51 .349 r
.58177 .73625 m .58436 .73883 L .58268 .73692 L F
.668 .499 .648 r
.7064 .72244 m .70419 .72029 L .70615 .72032 L F
.734 .939 .953 r
.56052 .70327 m .55939 .70482 L .56176 .70399 L F
.56052 .70327 m .55865 .70441 L .55939 .70482 L F
.546 .159 .259 r
.43307 .72789 m .43542 .72794 L .43652 .726 L F
.523 .135 .247 r
.43652 .726 m .43542 .72794 L .43841 .72715 L F
.069 .621 .823 r
.30559 .7335 m .307 .73356 L .30444 .73328 L F
.673 .679 .848 r
.70471 .609 m .70161 .60841 L .70382 .60648 L F
.705 .718 .859 r
.70737 .60757 m .70471 .609 L .70382 .60648 L F
.663 .816 .956 r
.38732 .65817 m .38555 .65883 L .38443 .65807 L F
.188 0 0 r
.32858 .70949 m .32903 .71036 L .33063 .70909 L F
.32858 .70949 m .32703 .71085 L .32903 .71036 L F
.834 .749 .77 r
.65045 .62208 m .64842 .62501 L .65109 .62472 L F
.875 .819 .79 r
.57349 .71882 m .57647 .71811 L .57538 .7176 L F
0 .001 .505 r
.57738 .71668 m .57647 .71811 L .57643 .71482 L F
.683 .923 .972 r
.57538 .7176 m .57647 .71811 L .57738 .71668 L F
.524 .713 .958 r
.57736 .71718 m .57647 .71811 L .57738 .71668 L F
.334 .406 .788 r
.57736 .71718 m .57859 .71973 L .57647 .71811 L F
.535 .191 .331 r
.41741 .73308 m .42093 .73058 L .41798 .7314 L F
0 .377 .835 r
.55497 .70333 m .55722 .70541 L .55425 .70329 L F
.648 .265 .305 r
.40082 .73803 m .40447 .73652 L .40232 .73686 L F
.574 .542 .78 r
.55152 .69716 m .5516 .69917 L .55408 .69789 L F
.137 0 0 r
.49912 .72642 m .4987 .72562 L .50068 .72524 L F
.49912 .72642 m .49725 .72702 L .4987 .72562 L F
0 0 0 r
.33517 .72979 m .33435 .73072 L .33317 .73098 L F
.268 0 .004 r
.33435 .73072 m .33175 .73188 L .33317 .73098 L F
.588 .114 .095 r
.50146 .78042 m .50374 .78171 L .5046 .78051 L F
.692 .234 .158 r
.50374 .78171 m .50708 .78223 L .5046 .78051 L F
.691 .249 .195 r
.5046 .78051 m .50708 .78223 L .50837 .78177 L F
.09 0 .194 r
.6243 .68434 m .62295 .68537 L .62508 .68256 L F
.229 0 .321 r
.6243 .68434 m .62222 .68708 L .62295 .68537 L F
.261 0 .182 r
.36911 .71067 m .36822 .70952 L .37013 .70901 L F
.36911 .71067 m .36725 .7115 L .36822 .70952 L F
.538 .295 .494 r
.31449 .73993 m .31216 .7416 L .31306 .73956 L F
.646 .447 .599 r
.60097 .70598 m .59847 .70404 L .60083 .70382 L F
.60097 .70598 m .59858 .70642 L .59847 .70404 L F
.28 0 0 r
.44055 .78499 m .4443 .78443 L .44271 .78504 L F
0 0 0 r
.44481 .78438 m .4443 .78443 L .44663 .78398 L F
.44481 .78438 m .44271 .78504 L .4443 .78443 L F
.416 .717 .986 r
.38301 .65696 m .38227 .65811 L .38096 .65689 L F
.38301 .65696 m .38443 .65807 L .38227 .65811 L F
.864 .876 .844 r
.38415 .79586 m .38197 .79905 L .38061 .79828 L F
.523 .004 0 r
.38243 .79954 m .38401 .801 L .38307 .8002 L F
.38197 .79905 m .38257 .79962 L .38243 .79954 L F
.38257 .79962 m .38401 .801 L .38243 .79954 L F
.38197 .79905 m .38243 .79954 L .38061 .79828 L F
.38243 .79954 m .38307 .8002 L .38219 .79951 L F
.38243 .79954 m .38219 .79951 L .38061 .79828 L F
.527 .363 .602 r
.38061 .79828 m .38307 .8002 L .38315 .79808 L F
.59 .016 0 r
.38254 .7983 m .38315 .79808 L .38208 .79931 L F
.38203 .79928 m .38208 .79931 L .38192 .79949 L F
.38254 .7983 m .38208 .79931 L .38203 .79928 L F
.38176 .79947 m .38192 .79949 L .38122 .80029 L F
.38254 .7983 m .38192 .79949 L .38176 .79947 L F
.505 0 0 r
.47389 .77989 m .47322 .78092 L .47042 .77985 L F
.489 0 0 r
.47389 .77989 m .47478 .78109 L .47322 .78092 L F
.47389 .77989 m .47605 .78038 L .47478 .78109 L F
.57 .94 .874 r
.391 .83595 m .39027 .83687 L .38925 .83696 L F
.391 .83595 m .39027 .83687 L .38925 .83696 L F
.864 .906 .495 r
.72768 .73267 m .72748 .73374 L .72872 .73118 L F
.89 .907 .5 r
.7288 .72941 m .72768 .73267 L .72872 .73118 L F
.569 .343 .533 r
.59351 .69536 m .59591 .69283 L .59288 .69304 L F
.56 .271 .434 r
.62504 .62172 m .62833 .61977 L .62498 .61979 L F
.62504 .62172 m .6277 .62204 L .62833 .61977 L F
.597 .151 .164 r
.62999 .62161 m .62833 .61977 L .6277 .62204 L F
.62999 .62161 m .63071 .62026 L .62833 .61977 L F
.723 .629 .753 r
.57984 .72758 m .58316 .72861 L .5822 .7251 L F
.58316 .72861 m .58358 .72841 L .5822 .7251 L F
.743 .926 .951 r
.58278 .72865 m .58297 .7287 L .58316 .72861 L F
.58297 .7287 m .58459 .72918 L .58321 .72859 L F
.621 .663 .87 r
.58316 .72861 m .58278 .72865 L .58374 .72878 L F
.57984 .72758 m .58278 .72865 L .58316 .72861 L F
.743 .926 .951 r
.58278 .72865 m .58316 .72861 L .58321 .72859 L F
.686 .612 .767 r
.5822 .7251 m .58358 .72842 L .58531 .72747 L F
.743 .926 .951 r
.58358 .72842 m .58672 .72809 L .58548 .72755 L F
.58329 .72858 m .58672 .72809 L .58358 .72842 L F
.58321 .72859 m .58548 .72755 L .58531 .72747 L F
.58321 .72859 m .58459 .72918 L .58672 .72809 L F
.686 .612 .767 r
.58358 .72842 m .58374 .72878 L .58531 .72747 L F
.743 .926 .951 r
.58321 .72859 m .58329 .72858 L .58358 .72842 L F
.58278 .72865 m .58321 .72859 L .58531 .72747 L F
.723 .629 .753 r
.58316 .72861 m .58374 .72878 L .58358 .72841 L F
.81 .638 .669 r
.64612 .61111 m .64949 .61201 L .6481 .609 L F
.81 .482 .433 r
.64612 .61111 m .64847 .61436 L .64949 .61201 L F
.784 .505 .514 r
.65151 .61422 m .64949 .61201 L .64979 .61361 L F
.311 0 .205 r
.64949 .61201 m .65055 .61329 L .64979 .61361 L F
.64949 .61201 m .64847 .61436 L .65055 .61329 L F
.655 .268 .3 r
.33033 .84763 m .33069 .84764 L .33045 .84747 L F
.112 0 0 r
.71842 .71232 m .7208 .7119 L .72164 .71136 L F
.301 .793 .872 r
.7208 .7119 m .72392 .71155 L .72164 .71136 L F
.787 .828 .884 r
.36095 .80657 m .36173 .80358 L .35966 .80393 L F
.36095 .80657 m .36363 .80455 L .36173 .80358 L F
.508 .056 .112 r
.69328 .5734 m .69536 .57349 L .69675 .57221 L F
.4 0 .029 r
.69675 .57221 m .69536 .57349 L .69904 .57257 L F
.568 .31 .485 r
.60393 .69299 m .60681 .69027 L .60366 .69039 L F
.60393 .69299 m .60631 .69266 L .60681 .69027 L F
.584 .403 .602 r
.60681 .69027 m .60898 .69003 L .6089 .68778 L F
.544 .288 .478 r
.60681 .69027 m .60844 .69208 L .60898 .69003 L F
.60681 .69027 m .60631 .69266 L .60844 .69208 L F
.547 .113 .169 r
.4686 .7796 m .46695 .78119 L .46494 .78012 L F
.388 0 0 r
.47042 .77985 m .46695 .78119 L .4686 .7796 L F
.936 .937 .587 r
.56366 .69465 m .56353 .69599 L .56506 .69308 L F
.842 .631 .616 r
.56506 .69308 m .56353 .69599 L .56521 .69623 L F
.887 .943 .58 r
.56663 .69063 m .56621 .69154 L .56644 .69226 L F
0 0 0 r
.56644 .69226 m .56506 .69308 L .56664 .69287 L F
.722 .536 .639 r
.56506 .69308 m .56849 .69519 L .56708 .69281 L F
.56506 .69308 m .56521 .69623 L .56849 .69519 L F
0 0 0 r
.56644 .69226 m .56366 .69465 L .56506 .69308 L F
.56373 .69459 m .56524 .6937 L .56366 .69465 L F
.56644 .69226 m .56524 .6937 L .56373 .69459 L F
.887 .943 .58 r
.56621 .69154 m .56524 .6937 L .56644 .69226 L F
.901 .95 .6 r
.56538 .69183 m .56524 .6937 L .56663 .69063 L F
.366 .592 .932 r
.56538 .69183 m .56642 .693 L .56524 .6937 L F
.56642 .693 m .56685 .69348 L .56524 .6937 L F
0 0 0 r
.56644 .69226 m .56664 .69287 L .56708 .69281 L F
.992 .845 .594 r
.31579 .69048 m .31544 .69165 L .31567 .6914 L F
.431 .194 .452 r
.31781 .68998 m .31544 .69165 L .31579 .69048 L F
.46 .307 .586 r
.6089 .68778 m .61041 .68935 L .61062 .68727 L F
.6089 .68778 m .60898 .69003 L .61041 .68935 L F
0 0 .346 r
.56176 .70399 m .56251 .70092 L .56064 .70105 L F
.56176 .70399 m .56272 .70286 L .56251 .70092 L F
.805 .343 .135 r
.56176 .70399 m .56353 .70628 L .5611 .7053 L F
.806 .329 .08 r
.56505 .7067 m .56353 .70628 L .56176 .70399 L F
.805 .343 .135 r
.56176 .70399 m .5611 .7053 L .56272 .70286 L F
.978 .72 .474 r
.56064 .70105 m .56052 .70327 L .56176 .70399 L F
0 .001 .505 r
.57738 .71668 m .57643 .71482 L .57704 .71417 L F
.271 .737 .946 r
.47131 .77272 m .46942 .77291 L .46738 .77211 L F
.267 0 0 r
.34906 .67365 m .34755 .67521 L .34559 .67552 L F
.353 0 .016 r
.35134 .67332 m .34755 .67521 L .34906 .67365 L F
.512 .112 .22 r
.3569 .67127 m .35554 .67329 L .35335 .67324 L F
.299 0 .093 r
.35757 .67275 m .3569 .67127 L .35896 .6709 L F
.35757 .67275 m .35554 .67329 L .3569 .67127 L F
.343 0 .033 r
.47229 .73488 m .47435 .73509 L .47118 .73631 L F
0 0 0 r
.48854 .71844 m .48924 .71855 L .4908 .71764 L F
.48854 .71844 m .48736 .71942 L .48924 .71855 L F
.495 .303 .549 r
.36957 .69045 m .37158 .69004 L .3717 .68767 L F
.371 .16 .458 r
.36953 .6928 m .37158 .69004 L .36957 .69045 L F
.535 .191 .331 r
.41741 .73308 m .4197 .73296 L .42093 .73058 L F
.528 .161 .288 r
.4197 .73296 m .42316 .73077 L .42093 .73058 L F
.63 .848 .983 r
.40461 .73326 m .40093 .73333 L .4036 .73249 L F
.40461 .73326 m .40093 .73333 L .4036 .73249 L F
.149 0 .23 r
.6916 .70404 m .69334 .70325 L .69379 .70129 L F
.381 .369 .721 r
.6916 .70404 m .69397 .70596 L .69334 .70325 L F
.912 .719 .629 r
.6507 .6164 m .6524 .61698 L .65151 .61422 L F
.902 .754 .688 r
.65112 .62001 m .6524 .61698 L .6507 .6164 L F
.699 .616 .76 r
.65151 .61422 m .6524 .61698 L .65488 .61446 L F
0 .071 .613 r
.55116 .7169 m .55164 .71703 L .54947 .71481 L F
.848 .464 .32 r
.55478 .72021 m .55302 .71978 L .55116 .7169 L F
0 0 .545 r
.55116 .7169 m .55302 .71978 L .55164 .71703 L F
0 0 0 r
.41352 .79166 m .41425 .79103 L .4161 .79006 L F
.469 .201 .424 r
.31253 .66338 m .3146 .66295 L .31508 .66088 L F
.386 .127 .394 r
.31508 .66088 m .31642 .6623 L .31715 .66038 L F
.31508 .66088 m .3146 .66295 L .31642 .6623 L F
.389 0 0 r
.3363 .87476 m .33688 .87471 L .33637 .8747 L F
.603 .799 .975 r
.72075 .62256 m .72163 .62423 L .72428 .62314 L F
.67 .173 .058 r
.68836 .70632 m .69192 .7073 L .68942 .70708 L F
.587 .351 .525 r
.59591 .69283 m .59817 .69266 L .59817 .69053 L F
.709 .449 .529 r
.59817 .69053 m .60169 .69261 L .60048 .69034 L F
.59817 .69053 m .59817 .69266 L .60169 .69261 L F
0 .478 .831 r
.72828 .71166 m .7274 .71169 L .72645 .71098 L F
.72828 .71166 m .72935 .71231 L .7274 .71169 L F
.455 0 0 r
.43129 .77613 m .43152 .7753 L .4305 .77538 L F
.333 0 0 r
.43459 .77572 m .43152 .7753 L .43129 .77613 L F
.581 .628 .863 r
.38298 .79108 m .38639 .79347 L .38523 .79031 L F
.687 .493 .619 r
.38415 .79586 m .38666 .79575 L .38639 .79347 L F
.565 .543 .788 r
.38639 .79347 m .38713 .78996 L .38523 .79031 L F
.38639 .79347 m .38845 .79312 L .38713 .78996 L F
.265 .189 .58 r
.38639 .79347 m .38786 .79547 L .38845 .79312 L F
.38639 .79347 m .38666 .79575 L .38786 .79547 L F
.356 .312 .671 r
.59225 .71923 m .59039 .72021 L .59009 .71697 L F
.432 .214 .481 r
.59246 .72179 m .59039 .72021 L .59225 .71923 L F
.59246 .72179 m .59008 .72273 L .59039 .72021 L F
.488 .33 .593 r
.59196 .71462 m .59215 .71695 L .59009 .71697 L F
.356 .312 .671 r
.59225 .71923 m .59009 .71697 L .59215 .71695 L F
.527 .339 .569 r
.40916 .75548 m .40906 .75799 L .40694 .75831 L F
.601 .302 .435 r
.31567 .6914 m .31243 .69497 L .31049 .69314 L F
.522 .214 .386 r
.31544 .69165 m .31243 .69497 L .31567 .6914 L F
.568 .933 .79 r
.69883 .57548 m .69764 .57663 L .69971 .57517 L F
.69883 .57548 m .69764 .57663 L .69971 .57517 L F
0 0 0 r
.70039 .58142 m .69781 .58325 L .69883 .58205 L F
.668 .499 .648 r
.7064 .72244 m .70423 .72328 L .70419 .72029 L F
.071 0 .222 r
.62508 .68256 m .62701 .67966 L .62649 .68143 L F
.098 0 .222 r
.62649 .68143 m .6243 .68434 L .62508 .68256 L F
.514 .243 .442 r
.30206 .67077 m .30467 .66844 L .3027 .66895 L F
.681 .785 .929 r
.39369 .79414 m .39531 .79578 L .39395 .79304 L F
.596 .621 .847 r
.39395 .79304 m .39531 .79578 L .39741 .79527 L F
.596 .707 .921 r
.39531 .79578 m .39885 .79643 L .39741 .79527 L F
.686 .14 0 r
.38749 .78777 m .38365 .78529 L .38518 .78805 L F
.536 .347 .571 r
.38523 .79031 m .38749 .78777 L .38518 .78805 L F
.236 0 .141 r
.61491 .63862 m .61684 .63778 L .61757 .63636 L F
0 0 0 r
.61757 .63636 m .61859 .63499 L .61881 .63508 L F
.61757 .63636 m .61797 .63565 L .61859 .63499 L F
.61757 .63636 m .61684 .63778 L .61797 .63565 L F
.092 .537 .908 r
.36732 .65092 m .3669 .6515 L .3647 .64984 L F
.36732 .65092 m .36866 .65195 L .3669 .6515 L F
.586 .343 .516 r
.61394 .69847 m .61182 .70036 L .61165 .69858 L F
.345 0 0 r
.68151 .61399 m .68082 .61409 L .67586 .61281 L F
.879 .637 .568 r
.6781 .61065 m .68101 .61346 L .67877 .61114 L F
.345 0 0 r
.68082 .61409 m .68065 .61406 L .67586 .61281 L F
.68065 .61406 m .68037 .61401 L .67997 .61391 L F
.68065 .61406 m .67997 .61391 L .67586 .61281 L F
.843 .53 .458 r
.68065 .61406 m .68311 .61596 L .67949 .61593 L F
.68101 .61346 m .68079 .61409 L .68065 .61406 L F
.215 .683 .942 r
.68079 .61409 m .68101 .61346 L .68071 .6141 L F
.68151 .61399 m .68101 .61346 L .68079 .61409 L F
.843 .53 .458 r
.68101 .61346 m .68172 .6143 L .68079 .61409 L F
.68172 .6143 m .68311 .61596 L .68065 .61406 L F
.566 .584 .83 r
.67586 .61281 m .68037 .61401 L .6781 .61065 L F
.856 .705 .693 r
.67949 .61226 m .68065 .61406 L .68037 .61401 L F
.67917 .61381 m .68065 .61406 L .67949 .61593 L F
.345 0 0 r
.68082 .61409 m .68071 .6141 L .68037 .61401 L F
.566 .584 .83 r
.68037 .61401 m .68071 .6141 L .67983 .61294 L F
.68037 .61401 m .67983 .61294 L .6781 .61065 L F
.879 .637 .568 r
.67902 .61187 m .67983 .61294 L .67904 .61155 L F
.856 .705 .693 r
.67877 .61114 m .67949 .61226 L .67917 .61381 L F
.67949 .61226 m .68037 .61401 L .67917 .61381 L F
.67877 .61114 m .67898 .61256 L .67869 .6132 L F
.67898 .61256 m .67949 .61593 L .67891 .61393 L F
.67898 .61256 m .67891 .61393 L .67869 .6132 L F
.879 .637 .568 r
.67904 .61155 m .67983 .61294 L .68101 .61346 L F
.6781 .61065 m .67902 .61187 L .67904 .61155 L F
.856 .705 .693 r
.67996 .613 m .68101 .61346 L .68065 .61406 L F
.879 .637 .568 r
.67983 .61294 m .68071 .6141 L .68101 .61346 L F
.856 .705 .693 r
.67877 .61114 m .68101 .61346 L .67996 .613 L F
.215 .683 .942 r
.68151 .61399 m .68276 .61394 L .68101 .61346 L F
.428 .141 .374 r
.33021 .68186 m .32787 .68361 L .32865 .683 L F
.32 .713 .98 r
.27783 .60015 m .27919 .60101 L .27728 .60023 L F
.27783 .60015 m .27932 .60101 L .27919 .60101 L F
.789 .488 .48 r
.41144 .73424 m .41513 .73299 L .41241 .73397 L F
.41225 .73395 m .41513 .73299 L .41144 .73424 L F
.41225 .73395 m .41408 .73538 L .41513 .73299 L F
.222 0 0 r
.41147 .73423 m .41123 .73453 L .41176 .7343 L F
.41123 .73453 m .41098 .73485 L .41145 .73452 L F
.41123 .73453 m .41145 .73452 L .41176 .7343 L F
.789 .488 .48 r
.41145 .73452 m .41408 .73538 L .41225 .73395 L F
.382 0 0 r
.41254 .73447 m .41408 .73538 L .41145 .73452 L F
.222 0 0 r
.41176 .7343 m .41098 .73485 L .41254 .73447 L F
.382 0 0 r
.41254 .73447 m .41145 .73452 L .41098 .73437 L F
.208 0 0 r
.41001 .7339 m .41098 .73437 L .41241 .73397 L F
.789 .488 .48 r
.41098 .73437 m .41225 .73395 L .41144 .73424 L F
.222 0 0 r
.41001 .7339 m .4088 .73519 L .41147 .73423 L F
.41001 .7339 m .41176 .7343 L .41098 .73437 L F
.789 .488 .48 r
.41098 .73437 m .41145 .73452 L .41176 .7343 L F
.222 0 0 r
.41176 .7343 m .41254 .73447 L .41098 .73437 L F
.789 .488 .48 r
.41098 .73437 m .41176 .7343 L .41225 .73395 L F
.222 0 0 r
.41147 .73423 m .40855 .73545 L .41098 .73485 L F
.4088 .73519 m .40855 .73545 L .41147 .73423 L F
.796 .69 .747 r
.73459 .59243 m .73566 .59559 L .73247 .59499 L F
.747 .763 .866 r
.73566 .59559 m .73484 .59454 L .73247 .59499 L F
.43 .476 .806 r
.73459 .59243 m .73713 .5939 L .73566 .59559 L F
.577 .702 .927 r
.73566 .59559 m .73713 .5939 L .73484 .59454 L F
.446 .868 .94 r
.51824 .78443 m .51707 .78424 L .51863 .78378 L F
.608 .825 .428 r
.51944 .78277 m .51781 .78511 L .51824 .78443 L F
.112 0 0 r
.51824 .78443 m .52208 .78297 L .51944 .78277 L F
.446 .868 .94 r
.51824 .78443 m .51863 .78378 L .51925 .7836 L F
.608 .825 .428 r
.51781 .78511 m .51749 .78559 L .51824 .78443 L F
.517 .318 .55 r
.67658 .58474 m .67686 .587 L .67453 .5873 L F
.317 .151 .491 r
.61091 .68497 m .6131 .68418 L .61318 .68185 L F
.272 .095 .449 r
.61062 .68727 m .6131 .68418 L .61091 .68497 L F
.527 .471 .737 r
.41384 .76815 m .41463 .77144 L .41268 .77178 L F
.498 .467 .753 r
.41515 .77359 m .41268 .77178 L .41463 .77144 L F
.62 .391 .549 r
.67902 .58578 m .67686 .587 L .67658 .58474 L F
.53 .354 .587 r
.39031 .7497 m .39242 .74688 L .3905 .74737 L F
.602 .74 .942 r
.70161 .60841 m .69825 .60691 L .70043 .60594 L F
.68 .735 .892 r
.70382 .60648 m .70161 .60841 L .70043 .60594 L F
.472 .048 .152 r
.44345 .74472 m .44208 .74658 L .43991 .74656 L F
.556 .139 .205 r
.44528 .74602 m .44208 .74658 L .44345 .74472 L F
.516 .172 .324 r
.4457 .74455 m .44528 .74602 L .44345 .74472 L F
.446 .131 .336 r
.69379 .70129 m .69495 .70252 L .69467 .70273 L F
.652 .122 0 r
.48478 .78041 m .48399 .78128 L .48159 .77953 L F
.589 .048 0 r
.48478 .78041 m .48713 .78174 L .48399 .78128 L F
.565 0 0 r
.48829 .78164 m .48713 .78174 L .48478 .78041 L F
.516 .283 .501 r
.56723 .70395 m .56943 .70354 L .56979 .70144 L F
.973 .744 .532 r
.56979 .70144 m .56943 .70354 L .56832 .70049 L F
.808 .65 .687 r
.62112 .65471 m .624 .65511 L .62304 .65827 L F
.651 .373 .485 r
.60961 .64087 m .61206 .64115 L .61245 .63891 L F
.554 .261 .424 r
.61206 .64115 m .61491 .63862 L .61245 .63891 L F
.556 .35 .556 r
.71148 .59286 m .71195 .59429 L .70911 .59263 L F
.707 .708 .849 r
.33044 .8478 m .33069 .84764 L .33033 .84763 L F
.586 .146 .171 r
.70323 .59307 m .70685 .59301 L .70578 .59454 L F
.476 .155 .342 r
.70685 .59301 m .70941 .59394 L .70578 .59454 L F
.70685 .59301 m .70911 .59263 L .70941 .59394 L F
.529 .557 .828 r
.56525 .71194 m .56401 .71501 L .56283 .71193 L F
.56525 .71194 m .5665 .71525 L .56401 .71501 L F
.209 .703 .92 r
.3683 .67067 m .36671 .67019 L .36474 .67022 L F
0 .4 .689 r
.3683 .67067 m .37008 .67118 L .36671 .67019 L F
.603 .353 .512 r
.4241 .7472 m .42354 .7497 L .42123 .74984 L F
.578 .33 .504 r
.42637 .7492 m .4241 .7472 L .42651 .747 L F
.42637 .7492 m .42354 .7497 L .4241 .7472 L F
0 0 .337 r
.56121 .72567 m .56139 .72781 L .56198 .727 L F
.56139 .72781 m .56143 .72818 L .56198 .727 L F
.088 .312 .791 r
.56198 .727 m .56286 .72604 L .56266 .72606 L F
0 0 .337 r
.56099 .72566 m .56198 .727 L .55976 .7256 L F
.56121 .72567 m .56198 .727 L .56099 .72566 L F
.071 .353 .825 r
.55976 .7256 m .56198 .727 L .56046 .72564 L F
.04 0 0 r
.56121 .72567 m .55976 .7256 L .55915 .72557 L F
.635 .094 0 r
.55985 .7251 m .56198 .727 L .56076 .72627 L F
.088 .312 .791 r
.56198 .727 m .56266 .72606 L .56076 .72627 L F
.071 .353 .825 r
.55976 .7256 m .56046 .72564 L .55985 .7251 L F
.04 0 0 r
.55915 .72557 m .55976 .7256 L .55751 .72549 L F
.205 0 0 r
.4642 .7255 m .46634 .72537 L .46751 .72487 L F
.384 0 0 r
.46751 .72487 m .46634 .72537 L .46971 .72509 L F
.893 .546 .062 r
.5458 .70393 m .54576 .70548 L .54458 .70319 L F
.5458 .70393 m .54668 .7068 L .54576 .70548 L F
.588 .714 .93 r
.30886 .74064 m .31018 .74212 L .31216 .7416 L F
.526 .462 .727 r
.38255 .76361 m .38313 .76682 L .38504 .76573 L F
.557 .491 .737 r
.38375 .76902 m .38504 .76573 L .38313 .76682 L F
.47 .284 .546 r
.54084 .72557 m .54094 .7281 L .53879 .72842 L F
.463 .259 .516 r
.54094 .7281 m .53897 .73045 L .53879 .72842 L F
.54094 .7281 m .53897 .73045 L .53879 .72842 L F
.891 .981 .814 r
.70848 .59786 m .70892 .59565 L .71007 .59724 L F
.70848 .59786 m .70794 .59726 L .70892 .59565 L F
.768 .361 .28 r
.71007 .59724 m .70794 .59726 L .70848 .59786 L F
.711 .665 .802 r
.69254 .60785 m .69365 .60962 L .69034 .60888 L F
.719 .511 .609 r
.60048 .69034 m .60169 .69261 L .60366 .69039 L F
.743 .548 .63 r
.60169 .69261 m .60393 .69299 L .60366 .69039 L F
.713 .318 .298 r
.51624 .79337 m .51487 .79508 L .51292 .7931 L F
.098 0 0 r
.51774 .79343 m .51624 .79337 L .51855 .79325 L F
.51774 .79343 m .51487 .79508 L .51624 .79337 L F
.619 .728 .924 r
.35786 .64959 m .35445 .64875 L .3567 .64842 L F
.27 .7 .966 r
.35825 .64887 m .35786 .64959 L .3567 .64842 L F
.35825 .64887 m .35973 .64963 L .35786 .64959 L F
.493 .269 .502 r
.38255 .76361 m .3846 .76324 L .38489 .76095 L F
.572 .338 .522 r
.38489 .76095 m .38685 .76287 L .38687 .7605 L F
.38489 .76095 m .3846 .76324 L .38685 .76287 L F
.624 .548 .748 r
.33636 .87496 m .33688 .87471 L .3363 .87476 L F
.732 .877 .948 r
.39885 .79643 m .3995 .79479 L .39741 .79527 L F
.39885 .79643 m .40083 .79561 L .3995 .79479 L F
.731 .453 .507 r
.47701 .77353 m .4805 .77378 L .48061 .77161 L F
.72 .443 .506 r
.4805 .77378 m .48218 .77394 L .48061 .77161 L F
.467 .443 .748 r
.71978 .73089 m .72057 .73488 L .72264 .73277 L F
.528 .539 .811 r
.72057 .73488 m .72367 .73631 L .72264 .73277 L F
.852 .851 .841 r
.54134 .76647 m .54262 .76509 L .54363 .76646 L F
.54262 .76509 m .54134 .76647 L .54363 .76646 L F
.779 .471 .466 r
.57515 .74354 m .57214 .74162 L .57551 .74197 L F
.536 .261 .445 r
.57551 .74197 m .57788 .74382 L .57515 .74354 L F
.575 .885 .991 r
.58531 .72747 m .58672 .72809 L .58928 .72726 L F
.65 .441 .587 r
.41134 .75718 m .40906 .75799 L .40916 .75548 L F
.527 0 0 r
.5677 .70836 m .56353 .70628 L .56505 .7067 L F
.656 .524 .691 r
.30609 .69852 m .30664 .70092 L .30401 .70121 L F
.582 .489 .714 r
.30636 .70296 m .30401 .70121 L .30664 .70092 L F
.30636 .70296 m .30466 .70374 L .30401 .70121 L F
.381 .211 .521 r
.3717 .68767 m .37324 .68941 L .37372 .68723 L F
.3717 .68767 m .37158 .69004 L .37324 .68941 L F
.388 .713 .987 r
.27983 .59993 m .27932 .60101 L .27783 .60015 L F
.27983 .59993 m .28133 .60103 L .27932 .60101 L F
.527 .264 .46 r
.32281 .68522 m .32255 .6872 L .32042 .68752 L F
.545 .258 .431 r
.32536 .6844 m .32255 .6872 L .32281 .68522 L F
0 0 .282 r
.55478 .72021 m .55498 .7226 L .55533 .7214 L F
.55478 .72021 m .55533 .7214 L .55302 .71978 L F
.316 .095 .412 r
.29483 .62476 m .29279 .62755 L .29326 .62545 L F
.72 .623 .749 r
.6862 .62805 m .68981 .62876 L .68848 .62748 L F
.457 .293 .569 r
.37326 .68235 m .3752 .6834 L .37526 .68185 L F
.37326 .68235 m .37322 .68484 L .3752 .6834 L F
0 .551 .739 r
.51367 .78522 m .51635 .78544 L .51749 .78559 L F
.624 .95 .937 r
.51749 .78559 m .51635 .78544 L .51824 .78443 L F
.658 .501 .66 r
.30466 .70374 m .30489 .70654 L .30184 .70602 L F
.566 .475 .711 r
.30492 .70922 m .30184 .70602 L .30489 .70654 L F
.30492 .70922 m .30289 .70971 L .30184 .70602 L F
.403 0 0 r
.50129 .78069 m .49965 .77971 L .49818 .77984 L F
.50129 .78069 m .50146 .78042 L .49965 .77971 L F
.343 .709 .984 r
.69117 .57838 m .69448 .57853 L .69352 .57765 L F
.239 .041 .397 r
.6288 .67665 m .62855 .67888 L .62701 .67966 L F
.195 0 .291 r
.62855 .67888 m .62649 .68143 L .62701 .67966 L F
.531 .387 .63 r
.59397 .71177 m .59196 .71462 L .59166 .7122 L F
.807 .757 .806 r
.69497 .61927 m .69708 .62028 L .69799 .61927 L F
.868 .693 .663 r
.69497 .61927 m .69627 .62249 L .69708 .62028 L F
.743 .597 .695 r
.70343 .59014 m .70323 .59307 L .70167 .59276 L F
.703 .961 .944 r
.70191 .58921 m .70574 .58775 L .70343 .59014 L F
0 .322 .675 r
.69949 .72951 m .69895 .72924 L .69635 .72814 L F
.162 .635 .929 r
.70216 .73016 m .69895 .72924 L .69949 .72951 L F
.552 .224 .366 r
.70723 .71638 m .70507 .71497 L .705 .71663 L F
.561 .215 .34 r
.70723 .71638 m .70764 .71492 L .70507 .71497 L F
.794 .515 .515 r
.58565 .75013 m .58568 .75227 L .58245 .75169 L F
.717 .59 .712 r
.58789 .74951 m .58568 .75227 L .58565 .75013 L F
0 0 0 r
.4432 .7755 m .44678 .77432 L .44695 .77422 L F
.44695 .77422 m .44812 .7736 L .44892 .77318 L F
.44695 .77422 m .44678 .77432 L .44812 .7736 L F
.156 .682 .873 r
.33951 .86898 m .34078 .86936 L .33723 .86906 L F
.718 .335 .323 r
.33723 .86906 m .34078 .86936 L .33917 .87119 L F
.53 .904 .958 r
.34134 .86845 m .34078 .86936 L .33951 .86898 L F
.627 .869 .515 r
.33917 .87119 m .34078 .86936 L .34134 .86845 L F
.958 .86 .7 r
.64154 .65283 m .64192 .6483 L .64039 .65181 L F
.955 .829 .68 r
.64053 .65577 m .64154 .65283 L .64039 .65181 L F
0 0 0 r
.52464 .78932 m .5234 .79016 L .52656 .7887 L F
.215 0 0 r
.52843 .78772 m .52464 .78932 L .52656 .7887 L F
.822 .624 .635 r
.33364 .7123 m .33063 .70909 L .33304 .71097 L F
.33364 .7123 m .33274 .71273 L .33063 .70909 L F
.862 .753 .741 r
.33364 .7123 m .33182 .71451 L .33274 .71273 L F
.361 .447 .815 r
.33452 .71022 m .33364 .7123 L .33304 .71097 L F
.432 .236 .513 r
.33364 .7123 m .3358 .71265 L .33727 .71025 L F
.361 .447 .815 r
.33452 .71022 m .3358 .71265 L .33364 .7123 L F
.88 .738 .701 r
.69784 .59422 m .69889 .59562 L .69673 .59584 L F
.795 .431 .367 r
.69673 .59584 m .69889 .59562 L .69818 .59746 L F
.609 .588 .804 r
.70032 .59215 m .69889 .59562 L .69784 .59422 L F
.70032 .59215 m .70123 .5951 L .69889 .59562 L F
.758 .54 .601 r
.70123 .5951 m .69818 .59746 L .69889 .59562 L F
.617 .575 .784 r
.73385 .58922 m .73221 .5928 L .73123 .58958 L F
.73385 .58922 m .73459 .59243 L .73221 .5928 L F
.576 .369 .563 r
.73221 .5928 m .73459 .59243 L .73247 .59499 L F
.068 0 0 r
.47729 .73467 m .47651 .73497 L .47646 .73478 L F
.49 .892 .756 r
.47727 .73427 m .47651 .73497 L .47872 .73372 L F
0 0 0 r
.47656 .73517 m .47651 .73497 L .47727 .73427 L F
.47525 .73682 m .47651 .73497 L .47656 .73517 L F
.068 0 0 r
.47646 .73478 m .47651 .73497 L .47435 .73509 L F
.413 .838 .681 r
.47872 .73372 m .47729 .73467 L .48028 .73383 L F
.47872 .73372 m .47651 .73497 L .47729 .73467 L F
.999 .835 .516 r
.64808 .60261 m .64905 .60105 L .64829 .60021 L F
.35 0 .126 r
.65027 .60217 m .64905 .60105 L .64808 .60261 L F
.65027 .60217 m .65155 .60052 L .64905 .60105 L F
.546 .392 .623 r
.64905 .60105 m .65155 .60052 L .65117 .59802 L F
.557 .44 .675 r
.39254 .74465 m .39476 .7443 L .39427 .74179 L F
.495 .28 .516 r
.39242 .74688 m .39476 .7443 L .39254 .74465 L F
.579 .577 .814 r
.7248 .58888 m .72313 .59062 L .72189 .58773 L F
.7248 .58888 m .72593 .59008 L .72313 .59062 L F
.574 .532 .77 r
.72593 .59008 m .726 .59173 L .72313 .59062 L F
.516 .338 .578 r
.6774 .62588 m .67956 .62723 L .67954 .62492 L F
.6774 .62588 m .67956 .62723 L .67954 .62492 L F
.807 .757 .806 r
.69497 .61927 m .69799 .61927 L .69721 .61658 L F
.654 .65 .834 r
.69799 .61927 m .69958 .61575 L .69721 .61658 L F
.69799 .61927 m .70084 .61858 L .69958 .61575 L F
.586 .582 .815 r
.56832 .70049 m .56723 .70395 L .56606 .70086 L F
.56832 .70049 m .56943 .70354 L .56723 .70395 L F
.453 .087 .253 r
.29676 .67614 m .30026 .67384 L .29807 .67413 L F
.583 .471 .692 r
.29807 .67413 m .30026 .67384 L .29985 .67132 L F
0 0 .207 r
.69377 .71379 m .69384 .71513 L .69365 .71356 L F
0 .515 .735 r
.69409 .71438 m .69377 .71379 L .69245 .71515 L F
.507 .646 .919 r
.69661 .71491 m .69384 .71513 L .69377 .71379 L F
0 .515 .735 r
.6951 .71391 m .69562 .71404 L .69377 .71379 L F
.6951 .71391 m .69377 .71379 L .69409 .71438 L F
0 0 .207 r
.69377 .71379 m .69365 .71356 L .69349 .71227 L F
.259 .458 .865 r
.69688 .71801 m .69384 .71513 L .69661 .71491 L F
.557 .491 .737 r
.38375 .76902 m .38578 .76866 L .38504 .76573 L F
.555 .434 .67 r
.38375 .76902 m .38616 .77103 L .38578 .76866 L F
.38375 .76902 m .38405 .77159 L .38616 .77103 L F
.897 .812 .756 r
.64515 .61075 m .6481 .609 L .64743 .60873 L F
.64515 .61075 m .64612 .61111 L .6481 .609 L F
.749 .861 .931 r
.6476 .60678 m .6481 .609 L .6508 .60649 L F
.982 .903 .581 r
.64743 .60873 m .6481 .609 L .6476 .60678 L F
.047 0 0 r
.59464 .64738 m .59375 .64873 L .59634 .64639 L F
.542 .426 .67 r
.57777 .71208 m .57549 .70602 L .57671 .71136 L F
.57777 .71208 m .57953 .70883 L .57549 .70602 L F
.57777 .71208 m .57979 .71177 L .57953 .70883 L F
.991 .79 .409 r
.57671 .71136 m .57704 .71417 L .57777 .71208 L F
.518 .365 .613 r
.7241 .72748 m .72653 .72487 L .72395 .72574 L F
.459 0 .06 r
.43841 .72715 m .44065 .72718 L .44203 .72571 L F
.543 .123 .194 r
.44065 .72718 m .44415 .72567 L .44203 .72571 L F
.431 0 .056 r
.47942 .77957 m .47842 .781 L .47605 .78038 L F
.545 .125 .195 r
.48159 .77953 m .47842 .781 L .47942 .77957 L F
.745 .67 .777 r
.68857 .62538 m .69167 .62602 L .69095 .62303 L F
.759 .68 .774 r
.68848 .62748 m .69167 .62602 L .68857 .62538 L F
.671 .623 .793 r
.69095 .62303 m .69167 .62602 L .69394 .62529 L F
.526 .462 .727 r
.38255 .76361 m .38504 .76573 L .3846 .76324 L F
.859 .984 .85 r
.67067 .61587 m .66949 .6169 L .66922 .61457 L F
.606 .757 .95 r
.66922 .61457 m .67144 .61428 L .67085 .61301 L F
.621 .462 .645 r
.66922 .61457 m .66949 .6169 L .67144 .61428 L F
0 0 0 r
.34542 .70972 m .34557 .71009 L .34733 .70914 L F
.34542 .70972 m .34375 .71114 L .34557 .71009 L F
.4 .092 .323 r
.31904 .65983 m .32171 .65703 L .31979 .65755 L F
.639 .401 .541 r
.58278 .70071 m .58617 .70096 L .58613 .69845 L F
.68 .433 .541 r
.58613 .69845 m .58617 .70096 L .58833 .70068 L F
.68 .433 .542 r
.58613 .69845 m .58833 .70068 L .58846 .69856 L F
.329 0 0 r
.46971 .72509 m .47195 .72517 L .47287 .72466 L F
0 0 0 r
.47403 .72458 m .47287 .72466 L .47195 .72517 L F
.47403 .72458 m .47562 .72391 L .47287 .72466 L F
.502 .511 .799 r
.68826 .71759 m .68939 .72083 L .69128 .719 L F
.477 .471 .772 r
.68939 .72083 m .69209 .72222 L .69128 .719 L F
.351 0 .125 r
.56461 .69811 m .56849 .69519 L .56521 .69623 L F
.56461 .69811 m .56713 .69762 L .56849 .69519 L F
.585 .502 .727 r
.56849 .69519 m .56999 .69322 L .56708 .69281 L F
.56849 .69519 m .57069 .69584 L .56999 .69322 L F
.393 0 .147 r
.56849 .69519 m .56929 .69694 L .57069 .69584 L F
.56849 .69519 m .56751 .69694 L .56929 .69694 L F
.458 .415 .722 r
.5716 .69854 m .57287 .6951 L .57069 .69584 L F
.5716 .69854 m .57336 .6992 L .57287 .6951 L F
.042 .206 .708 r
.57069 .69584 m .57248 .69757 L .5716 .69854 L F
.681 .207 .121 r
.56929 .69694 m .57248 .69757 L .57069 .69584 L F
.243 .695 .954 r
.56819 .69632 m .57101 .69695 L .56929 .69694 L F
.57101 .69695 m .57141 .69704 L .56929 .69694 L F
.393 0 .147 r
.56751 .69694 m .56713 .69762 L .56929 .69694 L F
.593 .466 .676 r
.30636 .70296 m .30489 .70654 L .30466 .70374 L F
.656 .861 .978 r
.3995 .79479 m .40083 .79561 L .40283 .79461 L F
.226 0 .106 r
.58716 .65434 m .58897 .65422 L .58979 .65236 L F
0 0 0 r
.58979 .65236 m .59115 .65164 L .59226 .64995 L F
.309 0 .143 r
.58979 .65236 m .59109 .65362 L .59115 .65164 L F
.58979 .65236 m .58897 .65422 L .59109 .65362 L F
.661 .344 .424 r
.42108 .75216 m .41956 .75236 L .4191 .75021 L F
.576 .354 .542 r
.42123 .74984 m .42108 .75216 L .4191 .75021 L F
.448 .175 .406 r
.59115 .65164 m .59375 .64873 L .59226 .64995 L F
0 0 .443 r
.61845 .66885 m .61929 .66975 L .61893 .66771 L F
.61845 .66885 m .61913 .6711 L .61929 .66975 L F
.898 .758 .699 r
.64588 .63351 m .64473 .63039 L .64445 .63288 L F
.518 .328 .563 r
.64562 .63633 m .64588 .63351 L .64445 .63288 L F
.64562 .63633 m .64743 .63538 L .64588 .63351 L F
.747 .666 .771 r
.72781 .58954 m .72884 .59336 L .726 .59173 L F
.73 .673 .794 r
.726 .59173 m .72884 .59336 L .72704 .59333 L F
.672 .303 .338 r
.72704 .59333 m .72884 .59336 L .72914 .59471 L F
.72704 .59333 m .72884 .59336 L .72914 .59471 L F
.756 .671 .768 r
.73123 .58958 m .72884 .59336 L .72781 .58954 L F
.51 0 0 r
.50837 .78177 m .50708 .78223 L .5111 .78216 L F
0 0 .163 r
.4039 .66605 m .40483 .66534 L .40548 .66313 L F
.056 0 .236 r
.4039 .66605 m .40325 .66777 L .40456 .66679 L F
.609 .882 .991 r
.40325 .66777 m .40483 .66534 L .4039 .66605 L F
0 0 .163 r
.40548 .66313 m .40483 .66534 L .4039 .66605 L F
.056 0 .236 r
.4039 .66605 m .40456 .66679 L .40483 .66534 L F
.665 .619 .793 r
.69394 .62529 m .69718 .62785 L .6974 .6262 L F
.641 .523 .705 r
.6974 .6262 m .69718 .62785 L .69953 .62536 L F
.164 0 .248 r
.29757 .62001 m .29682 .62193 L .29541 .62269 L F
.451 .263 .534 r
.29682 .62193 m .29483 .62476 L .29541 .62269 L F
.665 .121 0 r
.48597 .77613 m .48383 .77439 L .48218 .77394 L F
.473 .204 .425 r
.2925 .67897 m .29515 .67659 L .29296 .67681 L F
.282 0 0 r
.48829 .78164 m .49055 .78202 L .48713 .78174 L F
.47 .239 .481 r
.31029 .69516 m .30826 .69571 L .31049 .69314 L F
.553 .309 .499 r
.31049 .69314 m .31243 .69497 L .31029 .69516 L F
.525 .517 .789 r
.51159 .72251 m .50956 .72342 L .51177 .72275 L F
.51159 .72251 m .50986 .72385 L .50956 .72342 L F
.066 0 0 r
.34346 .72648 m .34311 .72546 L .34507 .725 L F
.34346 .72648 m .34172 .72732 L .34311 .72546 L F
.851 .822 .82 r
.57515 .71473 m .57297 .71748 L .57217 .71439 L F
.655 .792 .948 r
.50734 .72179 m .50986 .72385 L .51159 .72251 L F
.548 .268 .443 r
.35486 .70596 m .3576 .70384 L .35534 .70416 L F
.656 .678 .859 r
.70152 .62029 m .70282 .61713 L .70084 .61858 L F
.70152 .62029 m .70387 .61966 L .70282 .61713 L F
.329 .008 .26 r
.71088 .60079 m .70822 .60471 L .70908 .60239 L F
.71088 .60079 m .70908 .60239 L .71034 .60144 L F
0 .096 .616 r
.71007 .59724 m .71088 .60079 L .71165 .59923 L F
.689 .86 .454 r
.71088 .60079 m .71034 .60144 L .71165 .59923 L F
.706 .983 .888 r
.49658 .71545 m .49743 .71409 L .4983 .71411 L F
.49658 .71545 m .49477 .71586 L .49743 .71409 L F
.796 .662 .715 r
.57287 .6951 m .57336 .6992 L .57593 .69574 L F
.189 .441 .869 r
.57248 .69757 m .57421 .70032 L .5716 .69854 L F
.737 .395 .401 r
.70167 .59276 m .70323 .59307 L .70362 .5948 L F
.586 .146 .171 r
.70323 .59307 m .70578 .59454 L .70362 .5948 L F
.472 .284 .544 r
.36556 .80238 m .36779 .80148 L .36768 .79874 L F
.533 .541 .809 r
.37087 .80159 m .36768 .79874 L .36779 .80148 L F
.611 .796 .97 r
.54221 .72379 m .54084 .72557 L .53953 .72294 L F
.54221 .72379 m .5434 .72507 L .54084 .72557 L F
.693 .455 .559 r
.54373 .72733 m .54084 .72557 L .5434 .72507 L F
.54373 .72733 m .54094 .7281 L .54084 .72557 L F
.43 0 .008 r
.4581 .78168 m .45935 .78036 L .4617 .78088 L F
.612 .499 .701 r
.38075 .78256 m .38318 .78249 L .38271 .77956 L F
.627 .468 .648 r
.38083 .78409 m .38318 .78249 L .38075 .78256 L F
.508 .267 .485 r
.37969 .69854 m .37924 .70069 L .37717 .70108 L F
.26 0 .313 r
.38128 .69787 m .37969 .69854 L .38192 .69592 L F
.422 .225 .506 r
.38128 .69787 m .37924 .70069 L .37969 .69854 L F
.545 .258 .431 r
.32536 .6844 m .32492 .68699 L .32255 .6872 L F
.34 .025 .277 r
.32787 .68361 m .32492 .68699 L .32536 .6844 L F
.298 0 0 r
.4541 .7726 m .45499 .77268 L .45316 .77192 L F
.424 0 0 r
.45686 .77336 m .4566 .7736 L .45777 .77454 L F
.816 .377 .197 r
.45623 .77324 m .45777 .77454 L .4566 .7736 L F
.298 0 0 r
.45609 .77314 m .45686 .77336 L .45585 .77299 L F
.683 .17 .011 r
.4541 .7726 m .4566 .7736 L .45686 .77336 L F
.92 .952 .797 r
.45333 .77047 m .45316 .77192 L .45293 .77055 L F
.4547 .7702 m .45394 .77104 L .45333 .77047 L F
.45394 .77104 m .45316 .77192 L .45333 .77047 L F
.45394 .77104 m .4541 .7726 L .45316 .77192 L F
.4547 .7702 m .45439 .77145 L .45394 .77104 L F
.45439 .77145 m .4541 .7726 L .45394 .77104 L F
.446 .505 .826 r
.45293 .77055 m .45177 .77213 L .44945 .77242 L F
.45293 .77055 m .45316 .77192 L .45177 .77213 L F
.159 0 0 r
.44945 .77242 m .45094 .76972 L .45293 .77055 L F
.712 .498 .598 r
.45094 .76972 m .45447 .76759 L .45293 .77055 L F
.398 .267 .583 r
.45447 .76759 m .4547 .7702 L .45293 .77055 L F
.711 .54 .656 r
.45094 .76972 m .45289 .77251 L .45429 .77015 L F
.526 .67 .928 r
.45382 .77085 m .45383 .77092 L .45289 .77251 L F
.45383 .77092 m .4541 .7726 L .45289 .77251 L F
.816 .377 .197 r
.45399 .77102 m .45658 .77346 L .45529 .77227 L F
.45382 .77085 m .45556 .7725 L .45399 .77102 L F
.45556 .7725 m .45658 .77346 L .45399 .77102 L F
.711 .54 .656 r
.45429 .77015 m .45385 .77088 L .4547 .7702 L F
.45385 .77088 m .45289 .77251 L .45403 .77105 L F
.45385 .77088 m .45403 .77105 L .4547 .7702 L F
.92 .952 .797 r
.45403 .77105 m .45289 .77251 L .45439 .77145 L F
.816 .377 .197 r
.454 .77102 m .45668 .77353 L .45658 .77346 L F
.45399 .77101 m .45668 .77353 L .454 .77102 L F
.45382 .77085 m .45637 .77333 L .45537 .77239 L F
.298 0 0 r
.4541 .7726 m .45609 .77314 L .45499 .77268 L F
.45609 .77314 m .45585 .77299 L .45499 .77268 L F
.526 .67 .928 r
.45382 .77085 m .45407 .7711 L .4541 .7726 L F
.92 .952 .797 r
.45439 .77145 m .45408 .77167 L .4541 .7726 L F
.526 .67 .928 r
.45407 .7711 m .4566 .7736 L .4541 .7726 L F
.92 .952 .797 r
.45408 .77167 m .45396 .77175 L .4541 .7726 L F
.816 .377 .197 r
.45382 .77085 m .45399 .77101 L .454 .77102 L F
.45529 .77227 m .45658 .77346 L .45637 .77333 L F
.45537 .77239 m .45637 .77333 L .45623 .77324 L F
.45668 .77353 m .45777 .77454 L .45623 .77324 L F
.45382 .77085 m .45643 .77447 L .45777 .77454 L F
0 .144 .674 r
.45529 .77127 m .45643 .77447 L .45394 .77102 L F
.45394 .77088 m .45394 .77102 L .45382 .77085 L F
.92 .952 .797 r
.4547 .7702 m .45403 .77105 L .45439 .77145 L F
0 .144 .674 r
.45529 .77127 m .45394 .77102 L .45394 .77088 L F
.92 .952 .797 r
.45396 .77175 m .45289 .77251 L .45399 .77259 L F
.45396 .77175 m .45399 .77259 L .4541 .7726 L F
.953 .605 .285 r
.57753 .73023 m .57914 .73279 L .57852 .7306 L F
.873 .956 .858 r
.57984 .72758 m .57852 .7306 L .58058 .72967 L F
.57984 .72758 m .57753 .73023 L .57852 .7306 L F
.364 .036 .269 r
.38553 .69464 m .3843 .69364 L .38624 .69304 L F
.38553 .69464 m .38357 .69516 L .3843 .69364 L F
.279 .772 .713 r
.41549 .80165 m .41439 .80204 L .41434 .80117 L F
.388 .086 .326 r
.41434 .80117 m .41297 .80227 L .41439 .80192 L F
.279 .772 .713 r
.41439 .80204 m .41293 .80254 L .41439 .80192 L F
.115 0 0 r
.41535 .80169 m .41439 .80192 L .41293 .80254 L F
.41439 .80192 m .41297 .80227 L .41293 .80254 L F
.279 .772 .713 r
.41439 .80192 m .41293 .80254 L .41434 .80117 L F
.388 .086 .326 r
.41434 .80117 m .41439 .80192 L .41535 .80169 L F
.41434 .80117 m .41535 .80169 L .41549 .80165 L F
.728 .623 .741 r
.69394 .62529 m .6974 .6262 L .69627 .62249 L F
.661 .585 .758 r
.69627 .62249 m .6974 .6262 L .69953 .62536 L F
.732 .759 .874 r
.30444 .73328 m .307 .73356 L .30553 .73455 L F
.718 .339 .329 r
.71201 .7205 m .71446 .72274 L .71276 .72221 L F
.573 .386 .59 r
.71444 .71983 m .71446 .72274 L .71201 .7205 L F
.464 0 0 r
.70537 .73069 m .70439 .73071 L .70216 .73016 L F
.414 .015 .17 r
.70766 .72834 m .70439 .73071 L .70537 .73069 L F
.70766 .72834 m .70726 .73106 L .70439 .73071 L F
.845 .389 .112 r
.71126 .73283 m .71031 .73296 L .70766 .72834 L F
.614 .427 .605 r
.60377 .70365 m .60097 .70598 L .60083 .70382 L F
.429 0 0 r
.42734 .78797 m .42558 .78914 L .42351 .78912 L F
.089 0 0 r
.42939 .78749 m .42558 .78914 L .42734 .78797 L F
.478 .276 .527 r
.30826 .69571 m .30793 .69815 L .30609 .69852 L F
.516 .402 .663 r
.30793 .69815 m .30831 .70035 L .30609 .69852 L F
.471 .403 .699 r
.30831 .70035 m .30664 .70092 L .30609 .69852 L F
.597 .757 .955 r
.31192 .71222 m .3085 .71142 L .31044 .71134 L F
.548 .686 .93 r
.31249 .71037 m .31192 .71222 L .31044 .71134 L F
.31249 .71037 m .31396 .71192 L .31192 .71222 L F
.292 .024 .324 r
.6288 .67665 m .63116 .67399 L .63084 .676 L F
0 0 0 r
.63295 .67088 m .632 .67333 L .63116 .67399 L F
0 0 .506 r
.63116 .67399 m .63246 .67518 L .63084 .676 L F
.63116 .67399 m .632 .67333 L .63246 .67518 L F
.923 .748 .647 r
.57641 .72254 m .57619 .72565 L .57752 .72558 L F
.697 .2 .06 r
.57619 .72565 m .57654 .727 L .57752 .72558 L F
.406 .116 .357 r
.57752 .72558 m .58067 .72314 L .57641 .72254 L F
.57752 .72558 m .57952 .7253 L .58067 .72314 L F
.851 .607 .569 r
.57654 .727 m .57952 .7253 L .57752 .72558 L F
.531 .872 .99 r
.57283 .71406 m .57217 .71439 L .57515 .71473 L F
.57515 .71473 m .57217 .71439 L .57283 .71406 L F
.63 .695 .891 r
.55865 .70441 m .55722 .70541 L .55497 .70333 L F
.481 .718 .975 r
.55744 .70327 m .55865 .70441 L .55497 .70333 L F
0 .008 .56 r
.55744 .70327 m .55806 .70642 L .55722 .70541 L F
.391 .385 .732 r
.70911 .72448 m .70703 .72574 L .7064 .72244 L F
.539 .542 .806 r
.70911 .72448 m .70773 .72773 L .70703 .72574 L F
0 0 .207 r
.69377 .71379 m .69349 .71227 L .69517 .7119 L F
.57 .728 .949 r
.42038 .77562 m .41941 .77732 L .41827 .77584 L F
.42038 .77562 m .42149 .77699 L .41941 .77732 L F
.501 .296 .534 r
.62539 .62443 m .6277 .62204 L .62504 .62172 L F
.446 .22 .475 r
.38357 .69516 m .38128 .69787 L .38192 .69592 L F
.38 .107 .368 r
.39569 .68209 m .39514 .68461 L .39323 .68455 L F
.385 .111 .37 r
.39707 .68386 m .39569 .68209 L .39758 .68137 L F
.39707 .68386 m .39514 .68461 L .39569 .68209 L F
.019 0 .134 r
.63084 .676 m .62855 .67888 L .6288 .67665 L F
.415 0 0 r
.50245 .78117 m .50146 .78042 L .50129 .78069 L F
.50245 .78117 m .50374 .78171 L .50146 .78042 L F
.056 .618 .786 r
.52493 .78212 m .52383 .78199 L .52716 .78217 L F
.546 .372 .596 r
.3862 .75516 m .38841 .7549 L .38848 .75254 L F
.522 .381 .63 r
.38648 .75821 m .38841 .7549 L .3862 .75516 L F
.657 .454 .597 r
.58833 .70068 m .59086 .69823 L .58846 .69856 L F
0 0 0 r
.52464 .78932 m .52305 .79042 L .5234 .79016 L F
.499 .834 .545 r
.61923 .63332 m .62062 .63201 L .62196 .63084 L F
0 0 .069 r
.62196 .63084 m .62298 .62959 L .62334 .6274 L F
.524 .283 .491 r
.62062 .63201 m .62298 .62959 L .62196 .63084 L F
.601 .952 .879 r
.66204 .61135 m .6629 .6114 L .66383 .61023 L F
.424 .737 .992 r
.66383 .61023 m .6629 .6114 L .66481 .6112 L F
.749 .542 .614 r
.61547 .65243 m .61543 .65459 L .6121 .65453 L F
.677 .482 .614 r
.61713 .65233 m .61543 .65459 L .61547 .65243 L F
.38 .01 .206 r
.31253 .66338 m .31169 .66477 L .3146 .66295 L F
.528 .286 .492 r
.52572 .73385 m .5254 .73593 L .5232 .73633 L F
.385 .163 .449 r
.52759 .73328 m .5254 .73593 L .52572 .73385 L F
.5 .017 .04 r
.44415 .72567 m .44621 .72654 L .44754 .72521 L F
.568 .131 .169 r
.44621 .72654 m .44969 .72534 L .44754 .72521 L F
.068 .091 .576 r
.71502 .61695 m .71548 .61881 L .71672 .61791 L F
.71502 .61695 m .71672 .61791 L .7138 .61657 L F
.106 .655 .816 r
.35973 .64963 m .36192 .6496 L .36318 .64976 L F
.324 .771 .959 r
.36192 .6496 m .3647 .64984 L .36318 .64976 L F
.432 .194 .451 r
.39983 .67889 m .39758 .68137 L .39787 .67942 L F
0 0 0 r
.47769 .72308 m .47562 .72391 L .47403 .72458 L F
.468 .259 .512 r
.31029 .69516 m .30793 .69815 L .30826 .69571 L F
.258 .042 .384 r
.29902 .6191 m .29757 .62001 L .2995 .61707 L F
.426 .205 .474 r
.29902 .6191 m .29682 .62193 L .29757 .62001 L F
.861 .928 .87 r
.55241 .68918 m .55351 .68632 L .55465 .68731 L F
.55241 .68918 m .55135 .68853 L .55351 .68632 L F
.794 .767 .828 r
.68485 .62675 m .6862 .62805 L .68857 .62538 L F
.708 .618 .755 r
.68857 .62538 m .6862 .62805 L .68848 .62748 L F
.358 0 0 r
.46695 .78119 m .46377 .78098 L .46494 .78012 L F
.245 0 .175 r
.33831 .67629 m .33674 .67893 L .3351 .6789 L F
.565 .236 .371 r
.33964 .67781 m .33831 .67629 L .3401 .6767 L F
.33964 .67781 m .33674 .67893 L .33831 .67629 L F
.561 .633 .88 r
.52397 .71306 m .52078 .71148 L .5228 .7117 L F
.21 .476 .89 r
.5228 .7117 m .52467 .71398 L .52397 .71306 L F
.5228 .7117 m .52535 .71294 L .52467 .71398 L F
.102 .326 .799 r
.52535 .71294 m .52627 .71495 L .52467 .71398 L F
.669 .624 .795 r
.3085 .71142 m .30643 .71252 L .30492 .70922 L F
.321 .669 .975 r
.29384 .60335 m .2904 .60206 L .29241 .60174 L F
.355 .607 .944 r
.29433 .602 m .29384 .60335 L .29241 .60174 L F
.291 .535 .913 r
.29553 .60369 m .29384 .60335 L .29433 .602 L F
.375 .493 .851 r
.29707 .6066 m .29384 .60335 L .29553 .60369 L F
.567 .062 .015 r
.53277 .78001 m .53153 .78107 L .53465 .78114 L F
.818 .933 .907 r
.50416 .71244 m .50472 .71038 L .50601 .71112 L F
.50416 .71244 m .50306 .71186 L .50472 .71038 L F
.368 .427 .791 r
.38732 .65817 m .38976 .6598 L .3884 .66013 L F
.522 .214 .386 r
.31544 .69165 m .31456 .69471 L .31243 .69497 L F
.431 .194 .452 r
.31781 .68998 m .31723 .69203 L .31544 .69165 L F
.627 .389 .537 r
.31723 .69203 m .31456 .69471 L .31544 .69165 L F
.571 .524 .763 r
.38401 .801 m .38557 .80446 L .38292 .80444 L F
.38401 .801 m .38292 .80444 L .38388 .80336 L F
.11 .655 .831 r
.38292 .80444 m .38557 .80446 L .38388 .80336 L F
.224 .296 .728 r
.54947 .71481 m .54991 .7117 L .54865 .71144 L F
.54947 .71481 m .5507 .71523 L .54991 .7117 L F
.249 .273 .691 r
.54947 .71481 m .55164 .71703 L .5507 .71523 L F
.643 .549 .733 r
.41134 .75718 m .41023 .76177 L .40906 .75799 L F
.178 0 .02 r
.32976 .65174 m .33025 .65301 L .3318 .6513 L F
.32976 .65174 m .32833 .65379 L .33025 .65301 L F
.899 .816 .342 r
.61881 .63508 m .61859 .63499 L .61923 .63332 L F
0 0 0 r
.61923 .63332 m .61859 .63499 L .62062 .63201 L F
.508 .526 .81 r
.69895 .7166 m .69688 .71801 L .69661 .71491 L F
.522 .554 .83 r
.69895 .7166 m .69996 .71824 L .69688 .71801 L F
0 0 0 r
.63443 .66894 m .6339 .66989 L .63295 .67088 L F
.97 .743 .311 r
.6339 .66989 m .63335 .66922 L .63334 .67087 L F
.6339 .66989 m .63334 .67154 L .632 .67333 L F
.6339 .66989 m .63334 .67087 L .63334 .67154 L F
0 0 0 r
.63488 .66836 m .6339 .66989 L .63443 .66894 L F
.63488 .66836 m .63523 .66806 L .6339 .66989 L F
.479 .262 .506 r
.68011 .58965 m .68316 .58822 L .67948 .58843 L F
.68011 .58965 m .68308 .59082 L .68316 .58822 L F
.678 .488 .622 r
.57953 .70883 m .58192 .70914 L .5818 .70654 L F
.576 .408 .618 r
.5818 .70654 m .58442 .70853 L .58389 .70615 L F
.5818 .70654 m .58192 .70914 L .58442 .70853 L F
.473 .507 .813 r
.52165 .70854 m .52078 .71148 L .51964 .70943 L F
.52165 .70854 m .5228 .7117 L .52078 .71148 L F
.543 .418 .66 r
.38231 .77716 m .38374 .77411 L .38168 .77441 L F
.288 0 0 r
.45686 .77336 m .45908 .77329 L .46077 .77239 L F
.306 0 0 r
.46077 .77239 m .46244 .77281 L .46302 .77208 L F
.46077 .77239 m .45908 .77329 L .46244 .77281 L F
.514 .566 .846 r
.71585 .72908 m .71644 .73097 L .71421 .73095 L F
.422 .782 .996 r
.28537 .60059 m .28479 .60156 L .28328 .6007 L F
.28537 .60059 m .28691 .60136 L .28479 .60156 L F
.604 .588 .808 r
.67948 .58843 m .68198 .58587 L .67902 .58578 L F
.67948 .58843 m .68316 .58822 L .68198 .58587 L F
.725 .339 .319 r
.65592 .60614 m .6546 .60782 L .6526 .60578 L F
.915 .62 .47 r
.65592 .60614 m .65634 .60843 L .6546 .60782 L F
.463 .153 .354 r
.58121 .74707 m .58344 .7466 L .58419 .74372 L F
.725 .404 .436 r
.58419 .74372 m .58344 .7466 L .58653 .74659 L F
.757 .686 .784 r
.52243 .73056 m .52473 .73095 L .52473 .72908 L F
.741 .551 .637 r
.52243 .73056 m .52404 .73258 L .52473 .73095 L F
.589 .518 .743 r
.52473 .73095 m .52639 .72765 L .52473 .72908 L F
.52473 .73095 m .52731 .73068 L .52639 .72765 L F
.671 .525 .678 r
.52404 .73258 m .52731 .73068 L .52473 .73095 L F
.76 .648 .738 r
.57641 .72254 m .58067 .72314 L .57859 .71973 L F
.553 .569 .824 r
.57859 .71973 m .58067 .72314 L .58191 .72244 L F
.576 .367 .561 r
.57952 .7253 m .58191 .72244 L .58067 .72314 L F
.448 .081 .247 r
.3351 .6789 m .33431 .68102 L .33222 .6813 L F
.288 0 .181 r
.33622 .68046 m .3351 .6789 L .33674 .67893 L F
.33622 .68046 m .33431 .68102 L .3351 .6789 L F
.315 .083 .395 r
.4077 .66035 m .40747 .66247 L .40548 .66313 L F
.604 .452 .648 r
.40747 .66247 m .40483 .66534 L .40548 .66313 L F
.315 .083 .395 r
.4077 .66035 m .40747 .66247 L .40548 .66313 L F
.604 .452 .648 r
.40747 .66247 m .40483 .66534 L .40548 .66313 L F
.594 .411 .604 r
.70167 .59276 m .70123 .5951 L .70032 .59215 L F
.70167 .59276 m .70362 .5948 L .70123 .5951 L F
.389 .237 .551 r
.62334 .6274 m .6255 .62715 L .62539 .62443 L F
.373 .173 .475 r
.62532 .62933 m .62334 .6274 L .62298 .62959 L F
.62532 .62933 m .6255 .62715 L .62334 .6274 L F
.381 .284 .619 r
.59067 .72509 m .58928 .72726 L .58892 .72567 L F
.332 .049 .326 r
.39445 .68624 m .39323 .68455 L .39514 .68461 L F
.39445 .68624 m .39265 .68691 L .39323 .68455 L F
.703 .961 .944 r
.70191 .58921 m .70509 .58734 L .70574 .58775 L F
.739 .971 .93 r
.70574 .58775 m .70687 .58602 L .70774 .58651 L F
.70574 .58775 m .70509 .58734 L .70687 .58602 L F
.226 .076 .459 r
.61798 .69282 m .6178 .69491 L .61661 .69605 L F
0 0 0 r
.61661 .69605 m .6178 .69491 L .61564 .69772 L F
.663 .816 .956 r
.38732 .65817 m .38443 .65807 L .38648 .65739 L F
.347 .426 .801 r
.38855 .65669 m .38732 .65817 L .38648 .65739 L F
.38855 .65669 m .38976 .6598 L .38732 .65817 L F
.719 .671 .802 r
.70387 .61966 m .70715 .62022 L .70603 .61869 L F
.701 .666 .812 r
.70603 .61869 m .70715 .62022 L .7093 .61945 L F
.248 0 .207 r
.58716 .65434 m .58648 .65654 L .58897 .65422 L F
.185 0 .162 r
.30126 .6161 m .2995 .61707 L .30202 .61468 L F
.481 .253 .491 r
.30351 .61371 m .30126 .6161 L .30202 .61468 L F
.624 .411 .573 r
.61713 .65233 m .61752 .65461 L .61543 .65459 L F
.604 .105 .041 r
.49388 .78229 m .49268 .78279 L .49055 .78202 L F
.481 0 0 r
.49587 .78287 m .49268 .78279 L .49388 .78229 L F
.736 .756 .868 r
.68919 .60762 m .69034 .60888 L .68707 .60855 L F
.733 .755 .87 r
.69254 .60785 m .69034 .60888 L .68919 .60762 L F
.329 0 0 r
.47842 .781 m .47478 .78109 L .47605 .78038 L F
.912 .719 .629 r
.6507 .6164 m .65151 .61422 L .64979 .61361 L F
.395 0 .109 r
.47963 .72223 m .48189 .72198 L .48302 .72025 L F
.112 0 0 r
.48302 .72025 m .48377 .72112 L .4853 .72009 L F
.48302 .72025 m .48189 .72198 L .48377 .72112 L F
.457 .834 .989 r
.3174 .71198 m .31396 .71192 L .31603 .71148 L F
.437 .825 .987 r
.3174 .71198 m .31603 .71148 L .31945 .7116 L F
.217 .578 .942 r
.57956 .68143 m .57939 .68083 L .57648 .67998 L F
.846 .762 .77 r
.57939 .68083 m .57847 .68092 L .57648 .67998 L F
.57847 .68092 m .57632 .68112 L .57648 .67998 L F
.848 .75 .754 r
.57585 .68402 m .57956 .68143 L .57932 .68131 L F
.57585 .68402 m .57932 .68131 L .57879 .68157 L F
.954 .713 .534 r
.57901 .68117 m .57902 .68197 L .57871 .68143 L F
.57939 .68083 m .57924 .68128 L .57901 .68117 L F
0 .284 .646 r
.57901 .68117 m .57932 .68131 L .57938 .68134 L F
.954 .713 .534 r
.57924 .68128 m .57902 .68197 L .57901 .68117 L F
0 .284 .646 r
.57847 .68092 m .57901 .68117 L .57938 .68134 L F
.57901 .68117 m .57925 .68128 L .57932 .68131 L F
.848 .75 .754 r
.57879 .68157 m .57932 .68131 L .57918 .68124 L F
.709 .676 .816 r
.57461 .68099 m .57585 .68402 L .57879 .68157 L F
.848 .75 .754 r
.57585 .68402 m .57757 .68482 L .57956 .68143 L F
.954 .713 .534 r
.57828 .68182 m .57851 .68356 L .57723 .68275 L F
.57871 .68143 m .5787 .68161 L .57828 .68182 L F
.5787 .68161 m .57851 .68356 L .57828 .68182 L F
.57902 .68197 m .57851 .68356 L .57871 .68143 L F
.709 .676 .816 r
.57873 .68145 m .57879 .68157 L .57891 .68147 L F
.57461 .68099 m .57879 .68157 L .57873 .68145 L F
.57461 .68099 m .57891 .68147 L .5774 .68115 L F
0 .284 .646 r
.57771 .68056 m .57938 .68134 L .57956 .68143 L F
.57648 .67998 m .57852 .68094 L .57771 .68056 L F
.57852 .68094 m .57938 .68134 L .57771 .68056 L F
.805 .522 .509 r
.58158 .68382 m .57924 .68128 L .57997 .68162 L F
.217 .578 .942 r
.57956 .68143 m .58111 .68174 L .57939 .68083 L F
.805 .522 .509 r
.58158 .68382 m .57939 .68083 L .58111 .68174 L F
.855 .679 .663 r
.58085 .68632 m .57851 .68356 L .58158 .68382 L F
0 0 .283 r
.58127 .68294 m .58085 .68632 L .58158 .68382 L F
.58127 .68294 m .58139 .68527 L .58112 .6858 L F
.58104 .6848 m .58112 .6858 L .58085 .68632 L F
.58127 .68294 m .58112 .6858 L .58104 .6848 L F
.805 .522 .509 r
.58091 .68308 m .57851 .68356 L .57924 .68128 L F
.58158 .68382 m .58096 .68376 L .58091 .68308 L F
.58096 .68376 m .57851 .68356 L .58091 .68308 L F
.57997 .68162 m .57924 .68128 L .57939 .68083 L F
.954 .713 .534 r
.57901 .68117 m .579 .68118 L .57847 .68092 L F
.579 .68118 m .57723 .68275 L .5783 .68116 L F
.579 .68118 m .5783 .68116 L .57847 .68092 L F
.709 .676 .816 r
.57461 .68099 m .5774 .68115 L .57632 .68112 L F
.5774 .68115 m .57891 .68147 L .57918 .68124 L F
.954 .713 .534 r
.57847 .68092 m .5782 .68132 L .577 .68106 L F
.709 .676 .816 r
.5774 .68115 m .57918 .68124 L .57632 .68112 L F
.954 .713 .534 r
.577 .68106 m .57723 .68275 L .57632 .68112 L F
.5782 .68132 m .57723 .68275 L .577 .68106 L F
.57939 .68083 m .57901 .68117 L .57847 .68092 L F
0 .284 .646 r
.57648 .67998 m .57918 .68124 L .57925 .68128 L F
.57648 .67998 m .57925 .68128 L .57847 .68092 L F
.525 .686 .94 r
.37987 .65535 m .37888 .65707 L .3775 .65529 L F
.37987 .65535 m .38096 .65689 L .37888 .65707 L F
.554 .261 .424 r
.61206 .64115 m .61467 .64098 L .61491 .63862 L F
.382 .122 .39 r
.61467 .64098 m .61684 .63778 L .61491 .63862 L F
.518 0 0 r
.55408 .69789 m .55042 .69756 L .55152 .69716 L F
.58 .787 .977 r
.40125 .66888 m .39781 .66832 L .39993 .66763 L F
.73 .8 .908 r
.40325 .66777 m .40125 .66888 L .39993 .66763 L F
.534 .531 .798 r
.40387 .67038 m .40125 .66888 L .40325 .66777 L F
.607 .391 .563 r
.59869 .71118 m .5966 .70932 L .59876 .7086 L F
.59869 .71118 m .59634 .71154 L .5966 .70932 L F
.503 .274 .5 r
.37887 .70281 m .37717 .70108 L .37924 .70069 L F
.37887 .70281 m .37688 .70326 L .37717 .70108 L F
.757 .683 .78 r
.70499 .60228 m .70207 .60244 L .70052 .60068 L F
.775 .749 .83 r
.7049 .6025 m .70264 .60509 L .70207 .60244 L F
.178 0 0 r
.7049 .6025 m .70207 .60244 L .70575 .60255 L F
.634 .63 .829 r
.7049 .6025 m .70608 .59888 L .70736 .60141 L F
.684 .917 .973 r
.70908 .60239 m .7049 .6025 L .70611 .60196 L F
.86 .753 .743 r
.70908 .60239 m .70595 .60553 L .7049 .6025 L F
.634 .63 .829 r
.7049 .6025 m .70575 .60255 L .70608 .59888 L F
.757 .683 .78 r
.70575 .60255 m .7042 .60251 L .70499 .60228 L F
.7042 .60251 m .70207 .60244 L .70499 .60228 L F
.684 .917 .973 r
.7076 .60154 m .70611 .60196 L .70736 .60141 L F
.70908 .60239 m .70611 .60196 L .7076 .60154 L F
.097 0 0 r
.70736 .60141 m .71034 .60144 L .70908 .60239 L F
.59 .721 .934 r
.59223 .72825 m .58928 .72726 L .59067 .72509 L F
.575 .373 .57 r
.59223 .72825 m .59223 .73057 L .58981 .73088 L F
.493 .582 .872 r
.59379 .72754 m .59223 .72825 L .59067 .72509 L F
.332 .182 .523 r
.59379 .72754 m .59223 .73057 L .59223 .72825 L F
.487 .278 .521 r
.40226 .67395 m .40211 .67609 L .40006 .67667 L F
.452 .336 .63 r
.40387 .67038 m .40419 .6734 L .40226 .67395 L F
.498 .287 .524 r
.40412 .6756 m .40226 .67395 L .40419 .6734 L F
.40412 .6756 m .40211 .67609 L .40226 .67395 L F
.426 .236 .517 r
.40179 .67825 m .40006 .67667 L .40211 .67609 L F
.40179 .67825 m .39983 .67889 L .40006 .67667 L F
.499 .309 .554 r
.63071 .62026 m .63297 .61944 L .63286 .61699 L F
.712 .53 .641 r
.63452 .61636 m .6321 .61454 L .63286 .61699 L F
0 0 0 r
.63297 .61944 m .63452 .61636 L .63286 .61699 L F
.929 .689 .555 r
.35502 .6458 m .35445 .64875 L .35328 .64625 L F
.35484 .64674 m .3567 .64842 L .35445 .64875 L F
.649 .284 .337 r
.35333 .64631 m .35156 .6484 L .35489 .64816 L F
.35328 .64625 m .35325 .64629 L .35333 .64631 L F
.35325 .64629 m .35156 .6484 L .35333 .64631 L F
.929 .689 .555 r
.35502 .6458 m .35579 .64701 L .35484 .64674 L F
.35579 .64701 m .3567 .64842 L .35484 .64674 L F
.533 0 0 r
.44969 .72534 m .45185 .72637 L .4531 .72554 L F
.512 .005 0 r
.45185 .72637 m .45527 .7258 L .4531 .72554 L F
.569 .343 .533 r
.59351 .69536 m .59578 .69518 L .59591 .69283 L F
.614 .394 .559 r
.59578 .69518 m .59817 .69266 L .59591 .69283 L F
.388 .18 .472 r
.28702 .63861 m .28677 .64083 L .28503 .64144 L F
.341 .108 .409 r
.28677 .64083 m .28462 .6436 L .28503 .64144 L F
.603 .584 .804 r
.41722 .77307 m .41616 .77639 L .41515 .77359 L F
.41722 .77307 m .41827 .77584 L .41616 .77639 L F
.436 0 .097 r
.53393 .78531 m .53271 .78697 L .5305 .78701 L F
.452 .02 .127 r
.53629 .78513 m .53271 .78697 L .53393 .78531 L F
.086 0 .357 r
.65269 .59499 m .65117 .59802 L .6514 .59767 L F
.976 .686 .403 r
.65117 .59802 m .65155 .60052 L .65032 .59951 L F
0 0 0 r
.6514 .59767 m .65117 .59802 L .65032 .59951 L F
.303 0 0 r
.33394 .65063 m .33598 .6505 L .33802 .64927 L F
.317 .151 .492 r
.61748 .67438 m .61897 .6734 L .61913 .6711 L F
.129 0 .205 r
.61748 .67438 m .61678 .6761 L .61897 .6734 L F
.584 .485 .708 r
.30831 .70035 m .30636 .70296 L .30664 .70092 L F
.218 .431 .854 r
.30634 .73905 m .307 .73822 L .30537 .7374 L F
.622 .68 .884 r
.30666 .74102 m .307 .73822 L .30634 .73905 L F
.402 .187 .469 r
.30126 .6161 m .29902 .6191 L .2995 .61707 L F
.586 .343 .516 r
.61394 .69847 m .61344 .70046 L .61182 .70036 L F
.391 .15 .425 r
.61564 .69772 m .61344 .70046 L .61394 .69847 L F
.637 .511 .693 r
.38374 .77411 m .38616 .77103 L .38405 .77159 L F
.712 .53 .641 r
.63452 .61636 m .63156 .61382 L .6321 .61454 L F
.361 .038 .276 r
.39427 .74179 m .39619 .74143 L .39705 .73956 L F
.447 .122 .321 r
.39705 .73956 m .39829 .74104 L .39882 .73872 L F
.39705 .73956 m .39619 .74143 L .39829 .74104 L F
.783 .539 .568 r
.48611 .73177 m .48544 .73334 L .48876 .73362 L F
.696 .485 .599 r
.48532 .73552 m .48876 .73362 L .48544 .73334 L F
.48532 .73552 m .48882 .73604 L .48876 .73362 L F
.947 .735 .583 r
.71017 .58182 m .70999 .58416 L .70885 .58102 L F
.99 .764 .382 r
.6975 .70669 m .69654 .70587 L .69397 .70596 L F
.6975 .70669 m .69732 .70868 L .69654 .70587 L F
.752 .472 .507 r
.69761 .7076 m .69732 .70868 L .6975 .70669 L F
.808 .65 .687 r
.62112 .65471 m .62304 .65827 L .62113 .65703 L F
.852 .771 .772 r
.62113 .65703 m .62304 .65827 L .62175 .65998 L F
.514 .123 .238 r
.34929 .70858 m .35153 .7086 L .3529 .70654 L F
.446 .093 .271 r
.35153 .7086 m .35486 .70596 L .3529 .70654 L F
.63 .637 .838 r
.68595 .60562 m .68707 .60855 L .68477 .6092 L F
.175 0 0 r
.46437 .73812 m .46689 .73646 L .46651 .73847 L F
.566 .325 .51 r
.46882 .73614 m .46651 .73847 L .46689 .73646 L F
.928 .755 .647 r
.57728 .68722 m .57505 .69106 L .57552 .69063 L F
.57736 .68751 m .57552 .69063 L .57769 .68866 L F
.57728 .68722 m .57552 .69063 L .57736 .68751 L F
.867 .99 .732 r
.57552 .69063 m .57479 .69215 L .57505 .69106 L F
.734 .869 .451 r
.57552 .69063 m .5753 .69101 L .57479 .69215 L F
.851 .734 .735 r
.57479 .69215 m .57815 .69023 L .57531 .69099 L F
.57479 .69215 m .57531 .69099 L .57505 .69106 L F
.699 .591 .732 r
.57213 .69264 m .57287 .6951 L .57479 .69215 L F
.667 .459 .594 r
.57179 .69236 m .57213 .69264 L .57479 .69215 L F
.57479 .69215 m .57213 .69264 L .57179 .69236 L F
.509 .065 .13 r
.57479 .69215 m .57462 .6924 L .57179 .69236 L F
.477 .473 .774 r
.57206 .69017 m .57213 .69244 L .57179 .69236 L F
.57213 .69244 m .57213 .69264 L .57179 .69236 L F
.509 .065 .13 r
.57213 .69244 m .57369 .69378 L .57189 .69244 L F
.57462 .6924 m .57428 .69291 L .57213 .69244 L F
.57428 .69291 m .57369 .69378 L .57213 .69244 L F
.57462 .6924 m .57189 .69244 L .57179 .69236 L F
.59 .655 .882 r
.56928 .69194 m .57134 .69245 L .57206 .69017 L F
.57134 .69245 m .57213 .69264 L .57213 .69244 L F
.176 .225 .675 r
.57179 .69236 m .57166 .69206 L .57206 .69017 L F
.59 .655 .882 r
.57134 .69245 m .57144 .69245 L .57206 .69017 L F
.57144 .69245 m .57157 .69244 L .57166 .69206 L F
.57144 .69245 m .57166 .69206 L .57206 .69017 L F
.71 .795 .917 r
.5679 .69101 m .56928 .69194 L .57206 .69017 L F
.5679 .69101 m .57206 .69017 L .57057 .68962 L F
.176 .225 .675 r
.57166 .69206 m .57057 .68962 L .57206 .69017 L F
.57166 .69206 m .5723 .68821 L .57057 .68962 L F
.57179 .69236 m .57187 .69166 L .57166 .69206 L F
.57187 .69166 m .5723 .68821 L .57166 .69206 L F
.59 .655 .882 r
.57185 .69115 m .57213 .69244 L .57206 .69017 L F
.176 .225 .675 r
.57187 .69166 m .5734 .69127 L .5723 .68821 L F
.57179 .69236 m .5719 .69229 L .57187 .69166 L F
.59 .655 .882 r
.57191 .69244 m .57213 .69244 L .57185 .69115 L F
.176 .225 .675 r
.5719 .69229 m .5734 .69127 L .57187 .69166 L F
.59 .655 .882 r
.57157 .69244 m .57191 .69244 L .57185 .69115 L F
.734 .869 .451 r
.5753 .69101 m .57369 .69378 L .57479 .69215 L F
.867 .99 .732 r
.57651 .68859 m .57552 .69063 L .57505 .69106 L F
.734 .869 .451 r
.57394 .69332 m .57369 .69378 L .57552 .69063 L F
.928 .755 .647 r
.57769 .68866 m .57505 .69106 L .57815 .69023 L F
.734 .869 .451 r
.57651 .68859 m .57394 .69332 L .57552 .69063 L F
.851 .734 .735 r
.57479 .69215 m .57648 .69329 L .57815 .69023 L F
.571 .906 .977 r
.57815 .69023 m .57921 .68905 L .58028 .68945 L F
.191 .325 .771 r
.57815 .69023 m .58038 .69215 L .57921 .68905 L F
.212 0 .267 r
.37246 .70635 m .37183 .70869 L .37013 .70901 L F
.13 0 0 r
.37183 .70869 m .36911 .71067 L .37013 .70901 L F
.388 0 0 r
.47042 .77985 m .4692 .78114 L .46695 .78119 L F
.339 0 0 r
.47322 .78092 m .4692 .78114 L .47042 .77985 L F
0 .487 .838 r
.48987 .77604 m .49136 .77685 L .48945 .77628 L F
.699 .167 0 r
.49021 .77703 m .49136 .77685 L .48987 .77604 L F
.49037 .7775 m .49136 .77685 L .49021 .77703 L F
.367 0 0 r
.49136 .77685 m .4928 .77688 L .49205 .77675 L F
.49136 .77685 m .49205 .77675 L .48945 .77628 L F
.716 .235 .101 r
.49136 .77685 m .49518 .77846 L .4928 .77688 L F
.633 .073 0 r
.49973 .78431 m .50231 .78577 L .50103 .78532 L F
.652 .11 0 r
.50504 .78707 m .50103 .78532 L .50231 .78577 L F
.135 0 0 r
.51397 .70979 m .51638 .70953 L .51736 .70908 L F
0 0 0 r
.51736 .70908 m .51843 .70883 L .51964 .70943 L F
.51736 .70908 m .51638 .70953 L .51843 .70883 L F
.864 .876 .844 r
.38415 .79586 m .38061 .79828 L .38305 .79524 L F
.983 .741 .491 r
.38315 .79808 m .38415 .79586 L .38305 .79524 L F
.38315 .79808 m .38453 .79869 L .38415 .79586 L F
.531 .387 .63 r
.59397 .71177 m .59406 .71421 L .59196 .71462 L F
.41 .219 .508 r
.59406 .71421 m .59215 .71695 L .59196 .71462 L F
.672 .929 .971 r
.72428 .62314 m .72721 .62255 L .72623 .62217 L F
.47 .277 .536 r
.7293 .6215 m .72721 .62255 L .72927 .61962 L F
.629 .929 .971 r
.72623 .62217 m .72721 .62255 L .7293 .6215 L F
.566 .234 .365 r
.60398 .64291 m .6063 .64298 L .60418 .64148 L F
.558 .239 .385 r
.60418 .64148 m .6063 .64298 L .60651 .64137 L F
.516 .248 .447 r
.51726 .72961 m .51502 .72831 L .51874 .72815 L F
.757 .51 .558 r
.51913 .72919 m .51969 .73168 L .51623 .73131 L F
.652 .1 0 r
.51929 .72863 m .52065 .72983 L .51957 .72941 L F
.51927 .7291 m .51957 .72941 L .51926 .72929 L F
.51929 .72863 m .51957 .72941 L .51927 .7291 L F
.853 .66 .641 r
.52065 .72983 m .52201 .73333 L .52243 .73056 L F
.806 .88 .899 r
.52243 .73056 m .5233 .72831 L .52065 .72983 L F
.853 .66 .641 r
.52243 .73056 m .52201 .73333 L .52065 .72983 L F
.501 .901 .78 r
.52065 .72983 m .52189 .72877 L .51957 .72941 L F
.42 .207 .482 r
.5206 .73048 m .51996 .72982 L .52015 .72845 L F
.757 .51 .558 r
.52015 .72845 m .52004 .72928 L .51913 .72919 L F
.501 .901 .78 r
.51957 .72941 m .52004 .72928 L .51926 .72929 L F
.757 .51 .558 r
.52004 .72928 m .51996 .72982 L .51926 .72929 L F
.52004 .72928 m .51926 .72929 L .51913 .72919 L F
.51996 .72982 m .51969 .73168 L .51913 .72919 L F
.652 .1 0 r
.51917 .72922 m .51926 .72929 L .51917 .72926 L F
.757 .51 .558 r
.51913 .72919 m .51623 .73131 L .51898 .72892 L F
.652 .1 0 r
.51898 .72892 m .51917 .72926 L .51878 .72911 L F
.501 .901 .78 r
.51926 .72929 m .52189 .72877 L .51878 .72911 L F
.42 .207 .482 r
.52189 .72877 m .52032 .7292 L .52015 .72845 L F
.501 .901 .78 r
.52004 .72928 m .52189 .72877 L .51926 .72929 L F
.42 .207 .482 r
.52189 .72877 m .5206 .73048 L .52032 .7292 L F
.5206 .73048 m .51969 .73168 L .51996 .72982 L F
.652 .1 0 r
.51929 .72863 m .51926 .72929 L .51917 .72922 L F
.51929 .72863 m .51917 .72926 L .51898 .72892 L F
.757 .51 .558 r
.51898 .72892 m .51623 .73131 L .51726 .72961 L F
.52015 .72845 m .51913 .72919 L .51898 .72892 L F
0 0 0 r
.51898 .72892 m .51878 .72911 L .52015 .72845 L F
.51726 .72961 m .51878 .72911 L .51898 .72892 L F
.652 .1 0 r
.51874 .72815 m .51929 .72863 L .51878 .72911 L F
.51874 .72815 m .51878 .72911 L .51726 .72961 L F
.095 0 0 r
.63179 .62073 m .63071 .62026 L .62999 .62161 L F
.63179 .62073 m .63297 .61944 L .63071 .62026 L F
.362 0 .016 r
.60435 .65711 m .601 .65881 L .60214 .65726 L F
.539 .542 .806 r
.70911 .72448 m .71005 .72752 L .70773 .72773 L F
.538 .721 .958 r
.73049 .60444 m .72927 .60612 L .72836 .60285 L F
.73049 .60444 m .73144 .60568 L .72927 .60612 L F
.439 .535 .858 r
.73691 .60801 m .73594 .60951 L .73513 .60781 L F
.254 0 0 r
.73513 .60781 m .73449 .60793 L .73691 .60801 L F
.687 .67 .827 r
.73513 .60781 m .73594 .60951 L .73257 .60881 L F
.572 .56 .802 r
.73219 .60776 m .72927 .60612 L .73144 .60568 L F
.73119 .60769 m .72927 .60612 L .73219 .60776 L F
.744 .42 0 r
.73144 .60568 m .73211 .60802 L .73257 .60881 L F
.572 .56 .802 r
.73257 .60881 m .73119 .60769 L .73219 .60776 L F
.833 .861 .41 r
.73228 .60846 m .732 .60775 L .73165 .60827 L F
.744 .42 0 r
.73211 .60802 m .73221 .60838 L .73228 .60846 L F
.73211 .60802 m .73228 .60846 L .73257 .60881 L F
.833 .861 .41 r
.73175 .61035 m .73228 .60846 L .73165 .60827 L F
.73228 .60846 m .73282 .60652 L .73211 .60802 L F
.061 0 .392 r
.73282 .60652 m .73221 .60838 L .73211 .60802 L F
.73282 .60652 m .73211 .60802 L .73144 .60568 L F
.833 .861 .41 r
.73211 .60802 m .73282 .60652 L .732 .60775 L F
.437 .876 .842 r
.73257 .60881 m .73221 .60838 L .73513 .60781 L F
.73257 .60881 m .73221 .60838 L .73257 .60881 L F
.833 .861 .41 r
.73228 .60846 m .73221 .60838 L .73282 .60652 L F
.833 .861 .409 r
.73257 .60881 m .73221 .60838 L .73175 .61035 L F
.627 .71 .906 r
.73175 .61035 m .73221 .60838 L .73257 .60881 L F
.833 .861 .41 r
.73175 .61035 m .73221 .60838 L .73228 .60846 L F
.254 0 0 r
.73449 .60793 m .73221 .60838 L .73621 .60806 L F
.73449 .60793 m .73621 .60806 L .73691 .60801 L F
.574 .887 .99 r
.42472 .77663 m .42149 .77699 L .4237 .77683 L F
.191 .722 .813 r
.42571 .77635 m .42692 .77634 L .42472 .77663 L F
.654 .958 .936 r
.59224 .74889 m .59045 .74991 L .59349 .74879 L F
0 0 .508 r
.59213 .7492 m .59045 .74991 L .59224 .74889 L F
.59114 .75198 m .59045 .74991 L .59213 .7492 L F
.74 .987 .783 r
.59503 .7479 m .59452 .74697 L .59535 .74772 L F
.648 .957 .936 r
.59493 .74779 m .59349 .74879 L .59535 .74772 L F
.59493 .74779 m .59443 .74799 L .59349 .74879 L F
.74 .987 .783 r
.59349 .74879 m .59389 .74807 L .59443 .74799 L F
.648 .957 .936 r
.59362 .74832 m .59224 .74889 L .59349 .74879 L F
.674 .53 .681 r
.5933 .74861 m .59213 .7492 L .59224 .74889 L F
.74 .987 .783 r
.59349 .74879 m .59302 .74886 L .59362 .74832 L F
.59389 .74807 m .5938 .74767 L .59452 .74697 L F
.59349 .74879 m .59362 .74832 L .59389 .74807 L F
.59362 .74832 m .5938 .74767 L .59389 .74807 L F
.648 .957 .936 r
.59443 .74799 m .59362 .74832 L .59349 .74879 L F
.74 .987 .783 r
.59349 .74879 m .59443 .74799 L .59503 .7479 L F
.674 .53 .681 r
.59443 .74799 m .59445 .74831 L .5933 .74861 L F
.59362 .74832 m .5933 .74861 L .59224 .74889 L F
.59443 .74799 m .5933 .74861 L .59362 .74832 L F
.59445 .74831 m .59302 .74886 L .5933 .74861 L F
.59302 .74886 m .59213 .7492 L .5933 .74861 L F
.74 .987 .783 r
.59362 .74832 m .59248 .74894 L .5938 .74767 L F
.59302 .74886 m .59248 .74894 L .59362 .74832 L F
.674 .53 .681 r
.59493 .74779 m .59479 .74794 L .59443 .74799 L F
.74 .987 .783 r
.59389 .74807 m .59452 .74697 L .59503 .7479 L F
.674 .53 .681 r
.59479 .74794 m .59445 .74831 L .59443 .74799 L F
.393 .848 .785 r
.59045 .74991 m .59289 .74888 L .59349 .74879 L F
.674 .53 .681 r
.59445 .74831 m .59114 .75198 L .59213 .7492 L F
.393 .848 .785 r
.59213 .7492 m .59248 .74894 L .59289 .74888 L F
.59045 .74991 m .59119 .74955 L .59213 .7492 L F
.59119 .74955 m .59248 .74894 L .59213 .7492 L F
.541 .886 .985 r
.37841 .81933 m .37774 .82038 L .38018 .81974 L F
.37841 .81933 m .37774 .82038 L .38018 .81974 L F
.396 .264 .581 r
.29279 .62755 m .29286 .6299 L .2913 .63044 L F
.382 .246 .568 r
.29286 .6299 m .29139 .63301 L .2913 .63044 L F
.705 .718 .859 r
.70737 .60757 m .70382 .60648 L .70595 .60553 L F
.76 .721 .816 r
.70847 .60584 m .70737 .60757 L .70595 .60553 L F
.878 .895 .84 r
.70089 .718 m .70231 .71863 L .70249 .71712 L F
.45 .154 .371 r
.70431 .71954 m .70249 .71712 L .70231 .71863 L F
.70431 .71954 m .705 .71663 L .70249 .71712 L F
.768 .361 .28 r
.71007 .59724 m .70922 .59928 L .70794 .59726 L F
.815 .842 .87 r
.712 .59499 m .71007 .59724 L .70892 .59565 L F
.653 .232 .233 r
.71165 .59923 m .70922 .59928 L .71007 .59724 L F
.467 .443 .748 r
.71978 .73089 m .72264 .73277 L .72166 .72986 L F
.197 .726 .818 r
.32955 .7327 m .32625 .73297 L .32762 .73338 L F
.463 .23 .474 r
.36756 .69577 m .36915 .69744 L .36941 .69518 L F
.36756 .69577 m .36716 .69794 L .36915 .69744 L F
.056 0 0 r
.71506 .71325 m .71735 .7129 L .71842 .71232 L F
0 0 0 r
.71735 .7129 m .7208 .7119 L .71842 .71232 L F
.986 .711 .404 r
.69339 .58448 m .6908 .58562 L .69089 .58463 L F
.69339 .58448 m .69243 .58528 L .6908 .58562 L F
.69339 .58448 m .69345 .58665 L .69243 .58528 L F
.58 .366 .554 r
.696 .58432 m .69345 .58665 L .69339 .58448 L F
.599 .531 .75 r
.7172 .73631 m .71882 .73935 L .72108 .73873 L F
.61 .747 .943 r
.5375 .72349 m .53396 .72281 L .53644 .72324 L F
.368 0 0 r
.53644 .72324 m .53953 .72294 L .5375 .72349 L F
0 0 0 r
.5731 .6682 m .57452 .66736 L .57596 .66629 L F
.521 .865 .606 r
.57596 .66629 m .57699 .66527 L .57756 .66508 L F
.57596 .66629 m .57452 .66736 L .57699 .66527 L F
.889 .965 .836 r
.48631 .72959 m .48611 .73177 L .48731 .72978 L F
.943 .754 .619 r
.48434 .73092 m .48611 .73177 L .48631 .72959 L F
.48434 .73092 m .48544 .73334 L .48611 .73177 L F
.683 .867 .968 r
.73821 .60875 m .73594 .60951 L .73691 .60801 L F
.659 .525 .69 r
.73821 .60875 m .73658 .61158 L .73594 .60951 L F
.553 .632 .884 r
.29818 .60434 m .29707 .6066 L .29553 .60369 L F
.29818 .60434 m .29909 .60652 L .29707 .6066 L F
.426 .24 .524 r
.28907 .63574 m .28891 .63801 L .28702 .63861 L F
.336 .111 .417 r
.28891 .63801 m .28677 .64083 L .28702 .63861 L F
.471 .191 .405 r
.32174 .68912 m .32042 .68752 L .32255 .6872 L F
.32174 .68912 m .31989 .6895 L .32042 .68752 L F
0 0 .025 r
.66017 .59457 m .66119 .59267 L .6589 .5952 L F
.655 .322 .396 r
.6619 .59413 m .66119 .59267 L .66017 .59457 L F
.845 .489 .379 r
.66406 .59552 m .66119 .59267 L .6619 .59413 L F
.33 .693 .981 r
.37301 .65201 m .37221 .65289 L .3707 .65199 L F
.37301 .65201 m .37433 .65305 L .37221 .65289 L F
.55 .756 .973 r
.51265 .70835 m .5118 .71 L .51058 .709 L F
.51265 .70835 m .51397 .70979 L .5118 .71 L F
.606 .634 .853 r
.58981 .73088 m .59074 .72801 L .58928 .72726 L F
.58981 .73088 m .59223 .73057 L .59074 .72801 L F
.809 .662 .7 r
.5904 .73273 m .59223 .73057 L .58981 .73088 L F
.805 .655 .696 r
.59223 .73057 m .5904 .73273 L .58981 .73088 L F
.114 0 0 r
.53465 .78114 m .53671 .78053 L .53777 .77888 L F
0 0 0 r
.53777 .77888 m .5396 .77837 L .54043 .7773 L F
.53777 .77888 m .53671 .78053 L .5396 .77837 L F
.805 .803 .849 r
.68266 .60488 m .68164 .60913 L .68066 .60532 L F
0 0 0 r
.72927 .61962 m .73208 .61751 L .73146 .6185 L F
.209 .039 .419 r
.72927 .61962 m .72968 .62194 L .7293 .6215 L F
.72927 .61962 m .73146 .6185 L .72968 .62194 L F
.515 .363 .613 r
.38841 .7549 m .39028 .75202 L .38848 .75254 L F
.277 0 .146 r
.35364 .72134 m .35289 .71984 L .35481 .71932 L F
.35364 .72134 m .35173 .72201 L .35289 .71984 L F
.828 .518 .466 r
.56353 .69599 m .56461 .69811 L .56521 .69623 L F
.745 .715 .823 r
.73003 .58694 m .73123 .58958 L .72781 .58954 L F
.59 .632 .861 r
.73227 .58658 m .73123 .58958 L .73003 .58694 L F
.73227 .58658 m .73385 .58922 L .73123 .58958 L F
.528 .161 .288 r
.4197 .73296 m .42195 .73288 L .42316 .73077 L F
.508 .112 .225 r
.42195 .73288 m .42555 .73089 L .42316 .73077 L F
.708 .492 .593 r
.63156 .61382 m .6346 .61393 L .63455 .61155 L F
.641 .553 .74 r
.63455 .61155 m .63697 .61128 L .636 .60817 L F
.61 .391 .559 r
.63689 .61323 m .63455 .61155 L .6346 .61393 L F
.63689 .61323 m .63697 .61128 L .63455 .61155 L F
0 0 0 r
.5731 .6682 m .57179 .66978 L .57452 .66736 L F
.543 .418 .66 r
.38231 .77716 m .38461 .77704 L .38374 .77411 L F
.545 .444 .69 r
.38231 .77716 m .38271 .77956 L .38461 .77704 L F
.462 .772 .997 r
.43128 .75532 m .43335 .7551 L .43208 .75421 L F
.43128 .75532 m .43335 .7551 L .43208 .75421 L F
.671 .623 .793 r
.69095 .62303 m .69394 .62529 L .69275 .62203 L F
.717 .605 .731 r
.69275 .62203 m .69394 .62529 L .69627 .62249 L F
.743 .532 .61 r
.38666 .79575 m .39044 .79756 L .38786 .79547 L F
0 .139 .675 r
.65634 .60843 m .65757 .61147 L .65838 .61091 L F
.013 .313 .803 r
.65757 .61147 m .65918 .6127 L .65838 .61091 L F
.317 .718 .979 r
.55751 .72549 m .55798 .72492 L .55617 .72498 L F
.55751 .72549 m .55976 .7256 L .55798 .72492 L F
.72 .695 .825 r
.69825 .60691 m .69591 .60883 L .6949 .60642 L F
.587 .496 .719 r
.5232 .73633 m .52404 .73258 L .52201 .73333 L F
.5232 .73633 m .5254 .73593 L .52404 .73258 L F
.663 .2 .143 r
.58055 .70118 m .57846 .70249 L .57717 .70073 L F
.953 .951 .708 r
.57999 .70052 m .57846 .70249 L .58055 .70118 L F
.593 .466 .676 r
.30636 .70296 m .30698 .70617 L .30489 .70654 L F
.541 .369 .597 r
.30698 .70617 m .30492 .70922 L .30489 .70654 L F
.69 .651 .806 r
.48203 .73257 m .48323 .73538 L .48544 .73334 L F
.57 .683 .917 r
.48323 .73538 m .48532 .73552 L .48544 .73334 L F
.995 .796 .429 r
.56815 .71008 m .56751 .71094 L .5677 .70836 L F
.636 .158 .103 r
.56815 .71008 m .57018 .71149 L .56751 .71094 L F
.227 .733 .894 r
.45527 .7258 m .4574 .72564 L .45871 .72592 L F
.743 .493 .552 r
.60169 .69261 m .60387 .69522 L .60393 .69299 L F
.609 .395 .566 r
.60387 .69522 m .60631 .69266 L .60393 .69299 L F
.43 .542 .869 r
.37631 .65322 m .37543 .65512 L .37433 .65305 L F
.456 .573 .884 r
.37631 .65322 m .3775 .65529 L .37543 .65512 L F
.555 .282 .456 r
.40896 .66214 m .4077 .66035 L .40988 .65997 L F
.40896 .66214 m .40747 .66247 L .4077 .66035 L F
.40896 .66214 m .4077 .66035 L .40988 .65997 L F
.40896 .66214 m .40747 .66247 L .4077 .66035 L F
.622 .68 .884 r
.30666 .74102 m .3072 .73824 L .307 .73822 L F
.30666 .74102 m .30886 .74064 L .3072 .73824 L F
.536 .347 .571 r
.38523 .79031 m .38713 .78996 L .38749 .78777 L F
.578 .513 .745 r
.38144 .78569 m .38365 .78529 L .38083 .78409 L F
.318 .065 .364 r
.60844 .69208 m .61041 .68935 L .60898 .69003 L F
.525 .877 .986 r
.6826 .57805 m .68213 .57888 L .68002 .57891 L F
.455 .867 .718 r
.68459 .57723 m .68213 .57888 L .6826 .57805 L F
.416 .155 .408 r
.68128 .5792 m .6826 .57805 L .68045 .57889 L F
.68245 .57966 m .68256 .57844 L .68128 .5792 L F
.68256 .57844 m .6826 .57805 L .68128 .5792 L F
.455 .867 .718 r
.68436 .57738 m .68586 .57671 L .68213 .57888 L F
.68459 .57723 m .68469 .57719 L .68436 .57738 L F
.68469 .57719 m .68586 .57671 L .68436 .57738 L F
.755 .671 .769 r
.56003 .6988 m .56064 .70105 L .56269 .69819 L F
.596 .451 .654 r
.56064 .70105 m .56251 .70092 L .56269 .69819 L F
.502 .77 .991 r
.56266 .69989 m .56064 .70105 L .55954 .69958 L F
.56266 .69989 m .56251 .70092 L .56064 .70105 L F
.507 .262 .477 r
.56052 .70327 m .56251 .70092 L .56064 .70105 L F
.391 .385 .732 r
.70911 .72448 m .7064 .72244 L .70873 .72268 L F
.681 .594 .751 r
.68845 .58327 m .69089 .58463 L .68979 .58367 L F
.761 .292 .132 r
.69089 .58463 m .6908 .58562 L .68845 .58327 L F
.718 .988 .858 r
.4983 .71411 m .49909 .71265 L .50016 .713 L F
.4983 .71411 m .49743 .71409 L .49909 .71265 L F
.896 .861 .798 r
.55638 .68447 m .55465 .68731 L .55351 .68632 L F
0 0 .514 r
.50599 .78798 m .50713 .78916 L .50504 .78707 L F
.73 .221 0 r
.50903 .79112 m .50783 .79029 L .50599 .78798 L F
0 0 .514 r
.50599 .78798 m .50783 .79029 L .50713 .78916 L F
0 0 .188 r
.66691 .60599 m .66734 .60848 L .66729 .6073 L F
.876 .809 .781 r
.58038 .69215 m .5837 .69017 L .58284 .68968 L F
.58038 .69215 m .58178 .69327 L .5837 .69017 L F
.979 .687 .325 r
.58254 .68707 m .58284 .68968 L .5837 .69017 L F
.167 .705 .774 r
.30259 .6061 m .29909 .60652 L .3009 .60686 L F
.19 .717 .719 r
.30332 .60587 m .30482 .60557 L .30259 .6061 L F
.598 .496 .71 r
.30482 .60557 m .30279 .60842 L .30259 .6061 L F
.226 .504 .905 r
.71161 .73415 m .71324 .73392 L .71126 .73283 L F
.71161 .73415 m .71438 .73546 L .71324 .73392 L F
.44 .233 .501 r
.41563 .75402 m .41475 .75311 L .41677 .75277 L F
.41563 .75402 m .41387 .7551 L .41475 .75311 L F
0 0 .45 r
.66902 .59193 m .66893 .59546 L .66816 .594 L F
.987 .898 .61 r
.66893 .59546 m .66767 .59699 L .66816 .594 L F
.66893 .59546 m .66828 .59789 L .66767 .59699 L F
.338 0 .176 r
.30675 .6681 m .30878 .6676 L .30987 .66553 L F
0 0 0 r
.30987 .66553 m .3103 .66652 L .31169 .66477 L F
.30987 .66553 m .30878 .6676 L .3103 .66652 L F
.78 .756 .831 r
.68845 .58327 m .68455 .58408 L .68647 .58292 L F
.541 .423 .667 r
.68681 .58605 m .68455 .58408 L .68845 .58327 L F
.471 .686 .96 r
.68893 .58209 m .68845 .58327 L .68647 .58292 L F
.68893 .58209 m .68979 .58367 L .68845 .58327 L F
.671 .366 .449 r
.6908 .58562 m .68681 .58605 L .68845 .58327 L F
.627 .468 .648 r
.38083 .78409 m .38365 .78529 L .38318 .78249 L F
.263 .023 .349 r
.67144 .61428 m .66949 .6169 L .67141 .61577 L F
.194 .038 .429 r
.68613 .70644 m .68759 .70706 L .68836 .70632 L F
.68613 .70644 m .68577 .7091 L .68759 .70706 L F
.433 0 0 r
.34321 .67615 m .34258 .6768 L .3401 .6767 L F
.028 0 0 r
.34559 .67552 m .34453 .6761 L .34321 .67615 L F
.053 0 0 r
.34453 .6761 m .34258 .6768 L .34321 .67615 L F
.365 .122 .407 r
.37478 .70366 m .37442 .70617 L .37246 .70635 L F
.31 .025 .307 r
.37361 .70793 m .37246 .70635 L .37442 .70617 L F
.37361 .70793 m .37183 .70869 L .37246 .70635 L F
.648 .265 .305 r
.40082 .73803 m .40333 .73857 L .40447 .73652 L F
.274 0 .106 r
.40447 .73652 m .40559 .73767 L .40676 .73627 L F
.40447 .73652 m .40333 .73857 L .40559 .73767 L F
0 0 0 r
.73146 .6185 m .73208 .61751 L .73354 .61628 L F
.896 .861 .798 r
.55638 .68447 m .55351 .68632 L .55583 .68392 L F
.924 .974 .749 r
.55638 .68447 m .55767 .68081 L .55873 .68138 L F
.55638 .68447 m .55583 .68392 L .55767 .68081 L F
.832 .577 .553 r
.6487 .61519 m .6507 .6164 L .64979 .61361 L F
.739 .648 .759 r
.64744 .61952 m .65025 .61623 L .65013 .61615 L F
.832 .577 .553 r
.65042 .61635 m .6507 .6164 L .65027 .61615 L F
.65013 .61615 m .65027 .61615 L .6487 .61519 L F
.65042 .61635 m .65027 .61615 L .65013 .61615 L F
.828 .797 .823 r
.64602 .61849 m .64744 .61952 L .65013 .61615 L F
.65004 .61615 m .65013 .61615 L .65021 .61605 L F
.64602 .61849 m .65013 .61615 L .65004 .61615 L F
.902 .754 .688 r
.65025 .61623 m .6507 .6164 L .65021 .61605 L F
.65112 .62001 m .6507 .6164 L .65025 .61623 L F
.828 .797 .823 r
.64602 .61849 m .65004 .61615 L .64822 .61588 L F
.832 .577 .553 r
.64822 .61588 m .65005 .61615 L .64846 .61553 L F
.828 .797 .823 r
.65004 .61615 m .65021 .61605 L .64822 .61588 L F
.832 .577 .553 r
.64822 .61588 m .65025 .61623 L .65005 .61615 L F
.64822 .61588 m .65042 .61635 L .65025 .61623 L F
.64846 .61553 m .65025 .61623 L .6487 .61519 L F
.739 .648 .759 r
.64744 .61952 m .65112 .62001 L .65025 .61623 L F
.65013 .61615 m .65025 .61623 L .65021 .61605 L F
.832 .577 .553 r
.64822 .61588 m .64979 .61361 L .65055 .61329 L F
.238 .573 .941 r
.71819 .58491 m .71609 .58365 L .71772 .58396 L F
.306 .484 .871 r
.72082 .58477 m .71819 .58491 L .71772 .58396 L F
.72082 .58477 m .72124 .58637 L .71819 .58491 L F
.463 0 0 r
.65791 .59574 m .6589 .5952 L .6558 .59483 L F
0 0 0 r
.66017 .59457 m .6589 .5952 L .65791 .59574 L F
.598 .496 .71 r
.30482 .60557 m .30496 .60807 L .30279 .60842 L F
.492 .428 .712 r
.30511 .60926 m .30279 .60842 L .30496 .60807 L F
.30511 .60926 m .30346 .61146 L .30279 .60842 L F
.905 .777 .709 r
.64467 .62628 m .64605 .62748 L .64514 .62456 L F
.91 .774 .699 r
.64473 .63039 m .64605 .62748 L .64467 .62628 L F
.755 .706 .806 r
.64514 .62456 m .64605 .62748 L .64842 .62501 L F
.564 .895 .643 r
.50185 .72397 m .50068 .72524 L .50248 .72368 L F
.558 .884 .617 r
.50185 .72397 m .49912 .72642 L .50068 .72524 L F
.249 .173 .571 r
.50101 .72399 m .49912 .72642 L .50185 .72397 L F
.762 .605 .683 r
.50424 .72536 m .50143 .72417 L .50185 .72397 L F
.50143 .72417 m .50101 .72399 L .50185 .72397 L F
.564 .895 .643 r
.50185 .72397 m .50248 .72368 L .50325 .72301 L F
.329 0 0 r
.44055 .78499 m .43886 .78609 L .43708 .78615 L F
0 0 0 r
.44271 .78504 m .43886 .78609 L .44055 .78499 L F
.454 .171 .393 r
.36512 .69839 m .36662 .69973 L .36716 .69794 L F
.36512 .69839 m .36459 .7002 L .36662 .69973 L F
0 0 0 r
.33606 .72989 m .33517 .72979 L .33794 .72877 L F
.33606 .72989 m .33435 .73072 L .33517 .72979 L F
.486 0 0 r
.72532 .71956 m .72176 .71951 L .72298 .71998 L F
.562 .584 .833 r
.67141 .61577 m .67278 .61942 L .675 .61912 L F
.701 .666 .812 r
.70603 .61869 m .7093 .61945 L .70862 .61694 L F
.787 .755 .823 r
.70862 .61694 m .7093 .61945 L .71162 .617 L F
.51 .514 .796 r
.37526 .67916 m .37694 .67874 L .37431 .67688 L F
.429 .317 .625 r
.37526 .67916 m .37695 .68116 L .37694 .67874 L F
.37526 .67916 m .37526 .68185 L .37695 .68116 L F
.404 0 0 r
.67254 .61505 m .67144 .61428 L .67141 .61577 L F
.707 .536 .655 r
.60097 .70598 m .59876 .7086 L .59858 .70642 L F
.733 .755 .87 r
.69254 .60785 m .68919 .60762 L .69178 .60584 L F
.685 .766 .912 r
.6949 .60642 m .69254 .60785 L .69178 .60584 L F
0 0 .086 r
.61973 .69176 m .6178 .69491 L .61798 .69282 L F
.892 .879 .815 r
.6912 .58101 m .68979 .58367 L .68893 .58209 L F
.325 .013 .273 r
.36449 .71361 m .36277 .71431 L .36532 .71212 L F
.257 0 .179 r
.36725 .7115 m .36449 .71361 L .36532 .71212 L F
.301 .793 .872 r
.72149 .71182 m .7231 .71143 L .72392 .71155 L F
.401 .853 .894 r
.7231 .71143 m .72527 .71078 L .72392 .71155 L F
.451 0 .067 r
.72201 .71225 m .72469 .71105 L .7231 .71143 L F
.72469 .71105 m .72527 .71078 L .7231 .71143 L F
.301 .793 .872 r
.7208 .7119 m .7231 .71143 L .72149 .71182 L F
.401 .842 .937 r
.72392 .71155 m .72527 .71078 L .72645 .71098 L F
.192 .328 .774 r
.69329 .72528 m .69446 .72429 L .69209 .72222 L F
.562 .083 0 r
.69329 .72528 m .69524 .7276 L .69442 .72669 L F
.69329 .72528 m .69442 .72669 L .69446 .72429 L F
.889 .747 .699 r
.68855 .57632 m .68951 .5774 L .69098 .57343 L F
.166 0 .368 r
.69098 .57343 m .69245 .57462 L .69328 .5734 L F
.69098 .57343 m .68951 .5774 L .69245 .57462 L F
.678 .749 .904 r
.32158 .71078 m .32288 .71223 L .31945 .7116 L F
.571 .699 .929 r
.32368 .71032 m .32288 .71223 L .32158 .71078 L F
.32368 .71032 m .32509 .7119 L .32288 .71223 L F
.846 .902 .875 r
.62054 .65935 m .62175 .65998 L .6201 .66146 L F
.803 .814 .33 r
.61963 .66293 m .62054 .65935 L .6201 .66146 L F
.658 .972 .877 r
.55767 .68081 m .5613 .67914 L .55873 .68138 L F
0 0 0 r
.63295 .67088 m .6339 .66989 L .632 .67333 L F
.015 0 0 r
.33807 .72933 m .33794 .72877 L .33988 .72813 L F
.33807 .72933 m .33606 .72989 L .33794 .72877 L F
.362 .12 .406 r
.37604 .70557 m .37478 .70366 L .37688 .70326 L F
.37604 .70557 m .37442 .70617 L .37478 .70366 L F
.988 .746 .361 r
.66807 .60016 m .6688 .60324 L .66737 .6025 L F
.852 .771 .772 r
.62113 .65703 m .62175 .65998 L .62054 .65935 L F
.611 .473 .669 r
.5837 .70366 m .58617 .70096 L .58278 .70071 L F
.092 0 0 r
.32463 .65526 m .32171 .65703 L .32367 .65623 L F
.355 0 .137 r
.32367 .65623 m .32663 .65467 L .32463 .65526 L F
.289 0 0 r
.49535 .72801 m .49602 .72843 L .49407 .72868 L F
.07 0 0 r
.49566 .72814 m .49236 .72883 L .49321 .72883 L F
.49236 .72883 m .49189 .72892 L .49204 .72891 L F
.49566 .72814 m .49407 .72868 L .49189 .72892 L F
.289 0 0 r
.49725 .72702 m .49407 .72868 L .49566 .72814 L F
.49725 .72702 m .49671 .72764 L .49535 .72801 L F
.49671 .72764 m .49602 .72843 L .49535 .72801 L F
.07 0 0 r
.49236 .72883 m .49204 .72891 L .49321 .72883 L F
.455 0 0 r
.43129 .77613 m .4305 .77538 L .42915 .7763 L F
.762 .264 0 r
.50903 .79112 m .50998 .79256 L .50783 .79029 L F
.476 .369 .653 r
.39427 .74179 m .39642 .7437 L .39619 .74143 L F
.451 .368 .671 r
.39427 .74179 m .39476 .7443 L .39642 .7437 L F
.941 .738 .6 r
.64348 .64494 m .64384 .64391 L .64269 .6432 L F
.571 .829 .994 r
.43573 .75043 m .4381 .74975 L .43627 .74897 L F
.685 .172 .011 r
.5396 .77837 m .54254 .77898 L .54043 .7773 L F
.56 0 0 r
.54043 .7773 m .54254 .77898 L .54283 .77905 L F
.463 .112 .284 r
.42773 .73051 m .42991 .73021 L .43088 .72808 L F
.495 .143 .299 r
.43088 .72808 m .43273 .72928 L .43307 .72789 L F
.43088 .72808 m .42991 .73021 L .43273 .72928 L F
.101 0 .118 r
.64414 .60368 m .64357 .60502 L .64585 .60266 L F
.904 .788 .723 r
.54443 .70086 m .54285 .70029 L .54498 .69534 L F
.955 .679 .472 r
.54443 .70086 m .54317 .70229 L .54285 .70029 L F
.54443 .70086 m .54458 .70319 L .54317 .70229 L F
.886 .688 .63 r
.57585 .68402 m .57728 .68722 L .57757 .68482 L F
.579 .254 .383 r
.45878 .73872 m .45796 .74127 L .45539 .7411 L F
.256 0 .251 r
.45975 .74032 m .45878 .73872 L .46095 .73855 L F
.45975 .74032 m .45796 .74127 L .45878 .73872 L F
.511 .907 .925 r
.34903 .6493 m .34747 .64934 L .34945 .64856 L F
.711 .626 .76 r
.69275 .62203 m .69627 .62249 L .69497 .61927 L F
.291 0 0 r
.36474 .67022 m .36313 .67056 L .36104 .67038 L F
.119 0 0 r
.36671 .67019 m .36313 .67056 L .36474 .67022 L F
.893 .502 .279 r
.5111 .78216 m .51218 .78489 L .51367 .78522 L F
.189 .686 .916 r
.51218 .78489 m .51635 .78544 L .51367 .78522 L F
.775 .663 .109 r
.61913 .6711 m .61895 .67171 L .61929 .66975 L F
.61913 .6711 m .61897 .6734 L .61895 .67171 L F
.993 .866 .531 r
.31946 .73624 m .3184 .7381 L .31925 .73752 L F
.458 .094 .259 r
.32289 .73603 m .3184 .7381 L .31946 .73624 L F
.788 .667 .73 r
.58063 .74929 m .57703 .74899 L .57905 .74773 L F
.762 .427 .42 r
.58063 .74929 m .57895 .75124 L .57703 .74899 L F
.726 .338 .315 r
.58215 .75034 m .57895 .75124 L .58063 .74929 L F
.362 0 0 r
.46081 .72588 m .46281 .72633 L .4642 .7255 L F
.178 0 0 r
.46281 .72633 m .46634 .72537 L .4642 .7255 L F
0 0 0 r
.73821 .60875 m .73739 .61021 L .73658 .61158 L F
.704 .969 .737 r
.73658 .61158 m .73486 .61268 L .7361 .61384 L F
.73658 .61158 m .73739 .61021 L .73486 .61268 L F
.778 .703 .78 r
.57287 .6951 m .57593 .69574 L .57479 .69215 L F
.847 .737 .742 r
.57479 .69215 m .57593 .69574 L .57648 .69329 L F
.794 .767 .828 r
.68485 .62675 m .68857 .62538 L .68716 .62424 L F
.782 .741 .814 r
.68716 .62424 m .68857 .62538 L .69095 .62303 L F
.369 .32 .672 r
.29985 .67132 m .30162 .67296 L .30206 .67077 L F
.29985 .67132 m .30026 .67384 L .30162 .67296 L F
.451 .046 .18 r
.44836 .74465 m .44528 .74602 L .4457 .74455 L F
.419 .018 .17 r
.70964 .71576 m .70764 .71492 L .70723 .71638 L F
.70964 .71576 m .71014 .71464 L .70764 .71492 L F
.765 .621 .7 r
.64722 .62175 m .65112 .62001 L .64744 .61952 L F
.64722 .62175 m .65045 .62208 L .65112 .62001 L F
.783 .601 .654 r
.67543 .58982 m .67744 .59131 L .67904 .5907 L F
.008 .448 .867 r
.69635 .72814 m .69832 .7285 L .69524 .7276 L F
.69635 .72814 m .69895 .72924 L .69832 .7285 L F
0 .151 .694 r
.51177 .72275 m .51372 .72428 L .51159 .72251 L F
.51177 .72275 m .51349 .72456 L .51372 .72428 L F
.334 .781 .957 r
.27522 .60023 m .27728 .60023 L .27583 .6004 L F
.701 .883 .965 r
.50858 .70988 m .50601 .71112 L .50472 .71038 L F
0 0 0 r
.4908 .71764 m .49195 .71697 L .4929 .71689 L F
.4908 .71764 m .48924 .71855 L .49195 .71697 L F
.459 .339 .629 r
.30511 .60926 m .30351 .61371 L .30346 .61146 L F
.237 0 .015 r
.36335 .71561 m .36277 .71431 L .36449 .71361 L F
.36335 .71561 m .36143 .71613 L .36277 .71431 L F
.619 .418 .588 r
.72483 .73456 m .72264 .73277 L .72367 .73631 L F
.733 .367 .358 r
.72264 .73277 m .72482 .73468 L .72108 .73456 L F
.356 .378 .746 r
.72659 .7346 m .72564 .7354 L .72483 .73456 L F
.545 .411 .649 r
.72482 .73472 m .72659 .7346 L .72483 .73456 L F
.72478 .73571 m .72504 .73529 L .72482 .73472 L F
.72472 .73724 m .72498 .73567 L .72478 .73571 L F
.72498 .73567 m .72504 .73529 L .72478 .73571 L F
0 0 .358 r
.72329 .7369 m .72472 .73724 L .72478 .73571 L F
.72417 .73564 m .72478 .73571 L .72482 .73472 L F
.72329 .7369 m .72478 .73571 L .72417 .73564 L F
.545 .411 .649 r
.72472 .73724 m .72754 .73735 L .72682 .73526 L F
.72596 .73549 m .72682 .73526 L .72659 .7346 L F
.72472 .73724 m .72682 .73526 L .72596 .73549 L F
.042 0 0 r
.72676 .73576 m .72632 .73588 L .72542 .73564 L F
.657 .579 .755 r
.72472 .73724 m .72504 .73529 L .72564 .7354 L F
.72472 .73724 m .72564 .7354 L .72532 .73561 L F
.042 0 0 r
.72593 .73549 m .72532 .73561 L .72564 .7354 L F
.733 .367 .358 r
.72482 .73468 m .72564 .7354 L .72504 .73529 L F
.72482 .73468 m .72504 .73529 L .72482 .73472 L F
.545 .411 .649 r
.72541 .73626 m .72659 .7346 L .72482 .73472 L F
.042 0 0 r
.72546 .73562 m .72542 .73564 L .72532 .73561 L F
.72676 .73576 m .72542 .73564 L .72546 .73562 L F
0 0 .358 r
.72329 .7369 m .72482 .73473 L .72481 .7346 L F
.72482 .73473 m .72482 .73472 L .72482 .73468 L F
.72482 .73473 m .72482 .73468 L .72481 .7346 L F
.619 .418 .588 r
.72483 .73456 m .72564 .7354 L .72482 .73468 L F
0 0 .358 r
.72481 .7346 m .72482 .73472 L .72483 .73456 L F
.619 .418 .588 r
.72483 .73456 m .72482 .73468 L .72264 .73277 L F
0 0 0 r
.72367 .73631 m .72329 .7369 L .72483 .73456 L F
.657 .579 .755 r
.72498 .73567 m .72108 .73456 L .72504 .73529 L F
.72472 .73724 m .72345 .7363 L .72498 .73567 L F
.72345 .7363 m .72108 .73456 L .72498 .73567 L F
.545 .411 .649 r
.72472 .73724 m .72524 .73581 L .72504 .73529 L F
.657 .579 .755 r
.72472 .73724 m .72532 .73561 L .72379 .7366 L F
.545 .411 .649 r
.72472 .73724 m .72541 .73626 L .72524 .73581 L F
.042 0 0 r
.72632 .73588 m .72379 .7366 L .72511 .73575 L F
.72632 .73588 m .72511 .73575 L .72532 .73561 L F
.72676 .73576 m .72532 .73561 L .72593 .73549 L F
.733 .367 .358 r
.72482 .73472 m .72504 .73529 L .72491 .73527 L F
.72482 .73468 m .72491 .73527 L .72108 .73456 L F
0 .053 .597 r
.72329 .7369 m .72555 .74064 L .72472 .73724 L F
.524 .244 .432 r
.6065 .65509 m .60657 .65692 L .60435 .65711 L F
.678 .431 .54 r
.60979 .65446 m .60657 .65692 L .6065 .65509 L F
.641 .409 .551 r
.42397 .75167 m .42123 .74984 L .42354 .7497 L F
.42397 .75167 m .42108 .75216 L .42123 .74984 L F
.803 .814 .33 r
.61963 .66293 m .61967 .66223 L .62054 .65935 L F
.992 .823 .572 r
.6201 .66527 m .61967 .66223 L .61963 .66293 L F
.726 .338 .315 r
.58215 .75034 m .58245 .75169 L .57895 .75124 L F
.348 0 .076 r
.45135 .78214 m .45019 .78349 L .44804 .78392 L F
.332 0 .065 r
.45223 .78319 m .45135 .78214 L .45372 .78166 L F
.45223 .78319 m .45019 .78349 L .45135 .78214 L F
.308 0 .086 r
.36279 .701 m .36356 .70234 L .36459 .7002 L F
.36279 .701 m .36149 .70286 L .36356 .70234 L F
.561 .913 .712 r
.67063 .58871 m .66933 .58983 L .67084 .58841 L F
.014 0 .326 r
.66933 .58983 m .67042 .59109 L .67084 .58841 L F
.66933 .58983 m .66902 .59193 L .67042 .59109 L F
.955 .666 .451 r
.38584 .78713 m .38445 .78679 L .38446 .78663 L F
.686 .14 0 r
.38698 .78744 m .38584 .78713 L .38365 .78529 L F
.38735 .78768 m .38584 .78713 L .38698 .78744 L F
.955 .666 .451 r
.38584 .78713 m .38525 .78447 L .38365 .78529 L F
.38584 .78713 m .38446 .78663 L .38448 .7848 L F
.38584 .78713 m .38448 .7848 L .38525 .78447 L F
.247 .713 .946 r
.38794 .78734 m .38473 .78683 L .38584 .78713 L F
.38473 .78683 m .38445 .78679 L .38584 .78713 L F
.686 .14 0 r
.38749 .78777 m .38584 .78713 L .38735 .78768 L F
.108 .62 .893 r
.38749 .78777 m .38851 .7876 L .38584 .78713 L F
.627 .663 .865 r
.38713 .78996 m .38851 .7876 L .38749 .78777 L F
.006 0 0 r
.33063 .70909 m .33113 .7095 L .33304 .71097 L F
.33063 .70909 m .32903 .71036 L .33113 .7095 L F
.488 .385 .664 r
.57953 .70883 m .57979 .71177 L .58204 .71101 L F
.665 .355 .439 r
.57953 .70883 m .58204 .71101 L .58192 .70914 L F
.488 .385 .664 r
.57953 .70883 m .57979 .71177 L .58204 .71101 L F
.272 .095 .449 r
.61062 .68727 m .61281 .68641 L .6131 .68418 L F
.184 .004 .388 r
.61041 .68935 m .61281 .68641 L .61062 .68727 L F
.371 .16 .458 r
.36953 .6928 m .37123 .69225 L .37158 .69004 L F
.465 .286 .553 r
.36953 .6928 m .37128 .69466 L .37123 .69225 L F
.36953 .6928 m .36941 .69518 L .37128 .69466 L F
.651 .591 .774 r
.38461 .77704 m .38271 .77956 L .38527 .77937 L F
.533 .377 .615 r
.38318 .78249 m .38527 .77937 L .38271 .77956 L F
0 .521 .843 r
.47586 .77295 m .4748 .77296 L .47356 .77246 L F
.47586 .77295 m .47701 .77353 L .4748 .77296 L F
.689 .334 .37 r
.50708 .78223 m .5092 .78429 L .5111 .78216 L F
.779 .458 .445 r
.5092 .78429 m .51218 .78489 L .5111 .78216 L F
.523 .326 .555 r
.41578 .76325 m .41357 .76599 L .41344 .76364 L F
.698 .607 .751 r
.57717 .70073 m .57522 .70359 L .57421 .70032 L F
0 0 0 r
.57717 .70073 m .57612 .70263 L .57522 .70359 L F
0 .171 .694 r
.57612 .70263 m .57714 .70536 L .57522 .70359 L F
.298 .211 .586 r
.57522 .70359 m .57714 .70536 L .57523 .70563 L F
.354 0 0 r
.46437 .73812 m .46651 .73847 L .46307 .73833 L F
.353 0 .016 r
.35134 .67332 m .34979 .67501 L .34755 .67521 L F
.652 .298 .36 r
.35335 .67324 m .34979 .67501 L .35134 .67332 L F
.73 .717 .838 r
.70282 .61713 m .70387 .61966 L .70603 .61869 L F
.595 .619 .846 r
.69958 .61575 m .70084 .61858 L .70282 .61713 L F
.505 .561 .846 r
.39148 .65929 m .39118 .66281 L .38976 .6598 L F
.39148 .65929 m .3931 .66269 L .39118 .66281 L F
.543 .152 .249 r
.53629 .73368 m .53313 .73548 L .53466 .7331 L F
.53629 .73368 m .53522 .73566 L .53313 .73548 L F
.445 .245 .514 r
.53886 .73241 m .53629 .73368 L .53897 .73045 L F
.458 .065 .206 r
.5376 .73529 m .53629 .73368 L .53886 .73241 L F
.5376 .73529 m .53522 .73566 L .53629 .73368 L F
.947 .691 .516 r
.66306 .59569 m .66406 .59552 L .6619 .59413 L F
.66306 .59569 m .66437 .59694 L .66406 .59552 L F
.593 .403 .594 r
.59086 .69823 m .59395 .69792 L .59351 .69536 L F
.592 .403 .594 r
.59351 .69536 m .59593 .69751 L .59578 .69518 L F
.59351 .69536 m .59395 .69792 L .59593 .69751 L F
.522 .381 .63 r
.38648 .75821 m .38853 .75793 L .38841 .7549 L F
.557 .447 .684 r
.38648 .75821 m .38895 .76012 L .38853 .75793 L F
.38648 .75821 m .38687 .7605 L .38895 .76012 L F
0 0 0 r
.72737 .60098 m .72889 .59714 L .7295 .59927 L F
.474 .391 .682 r
.73108 .60401 m .72836 .60285 L .72737 .60098 L F
.663 .679 .855 r
.73113 .60395 m .73312 .60366 L .73096 .6043 L F
.474 .391 .682 r
.73118 .6041 m .73105 .60404 L .73108 .60401 L F
.73105 .60404 m .72836 .60285 L .73108 .60401 L F
.663 .679 .855 r
.73233 .6015 m .73111 .604 L .73122 .60371 L F
.73233 .6015 m .73254 .60237 L .73113 .60395 L F
.442 .411 .729 r
.73233 .6015 m .73118 .6041 L .73111 .60391 L F
.73233 .6015 m .73111 .60391 L .7295 .59927 L F
.663 .679 .855 r
.73233 .6015 m .73122 .60371 L .73161 .60265 L F
.73111 .604 m .73096 .6043 L .73107 .60403 L F
.73111 .604 m .73107 .60403 L .73161 .60265 L F
.502 .368 .63 r
.73105 .60404 m .73049 .60444 L .72836 .60285 L F
.474 .391 .682 r
.73111 .60391 m .72737 .60098 L .7295 .59927 L F
.73108 .60401 m .72737 .60098 L .73111 .60391 L F
.663 .679 .855 r
.73161 .60265 m .73096 .6043 L .73049 .60444 L F
.502 .368 .63 r
.73118 .6041 m .73049 .60444 L .73105 .60404 L F
.474 .391 .682 r
.73118 .6041 m .73108 .60401 L .73111 .60391 L F
.663 .679 .855 r
.73233 .6015 m .73049 .60444 L .73118 .6041 L F
.41 .41 .749 r
.73125 .59895 m .73233 .6015 L .7295 .59927 L F
.982 .832 .618 r
.73233 .6015 m .73175 .60337 L .732 .60019 L F
.217 .296 .731 r
.73205 .59952 m .73233 .6015 L .73125 .59895 L F
.982 .832 .618 r
.73233 .6015 m .732 .60019 L .73205 .59952 L F
.663 .679 .855 r
.73233 .6015 m .73262 .60229 L .73254 .60237 L F
.73262 .60229 m .73312 .60366 L .73113 .60395 L F
.867 .599 .531 r
.70011 .58973 m .70032 .59215 L .69842 .59146 L F
.551 .883 .989 r
.7015 .58848 m .70191 .58921 L .70011 .58973 L F
0 0 0 r
.70011 .58973 m .69842 .59146 L .7015 .58848 L F
.952 .752 .293 r
.72854 .71992 m .72805 .72131 L .72532 .71956 L F
.72854 .71992 m .72845 .72223 L .72805 .72131 L F
.478 .768 .995 r
.41319 .76303 m .41524 .76273 L .41452 .76231 L F
.388 .544 .889 r
.56064 .70834 m .55949 .71011 L .55842 .70833 L F
.56064 .70834 m .56158 .71052 L .55949 .71011 L F
.478 .11 .262 r
.41408 .73538 m .41741 .73308 L .41513 .73299 L F
.728 .313 .261 r
.53304 .7309 m .53185 .73243 L .52932 .73044 L F
.803 .413 .316 r
.53304 .7309 m .53466 .7331 L .53185 .73243 L F
.581 .343 .521 r
.42852 .74894 m .42651 .747 L .42867 .74669 L F
.42852 .74894 m .42637 .7492 L .42651 .747 L F
.704 .463 .557 r
.59817 .69266 m .60058 .695 L .60169 .69261 L F
.739 .493 .558 r
.60058 .695 m .60387 .69522 L .60169 .69261 L F
.815 .842 .87 r
.712 .59499 m .70892 .59565 L .71195 .59429 L F
.822 .506 .455 r
.51292 .7931 m .51155 .79531 L .50998 .79256 L F
.684 .33 .369 r
.51292 .7931 m .51487 .79508 L .51155 .79531 L F
.503 .573 .859 r
.52896 .7157 m .52733 .71741 L .52627 .71495 L F
.401 .414 .758 r
.52896 .7157 m .5297 .71899 L .52733 .71741 L F
.714 .394 .434 r
.51502 .72831 m .51186 .72983 L .51347 .72656 L F
.51502 .72831 m .51518 .72999 L .51186 .72983 L F
.516 .248 .447 r
.51726 .72961 m .51518 .72999 L .51502 .72831 L F
.229 .365 .794 r
.68133 .62803 m .68243 .62717 L .67956 .62723 L F
.68133 .62803 m .68237 .62958 L .68243 .62717 L F
.498 .241 .455 r
.61344 .70046 m .61137 .70275 L .61182 .70036 L F
.177 .264 .716 r
.73583 .59121 m .73459 .59243 L .73385 .58922 L F
.307 .476 .863 r
.73583 .59121 m .73713 .5939 L .73459 .59243 L F
0 0 0 r
.66603 .60333 m .66532 .60366 L .66657 .60343 L F
.66603 .60333 m .66491 .60432 L .66532 .60366 L F
.928 .789 .687 r
.66208 .6075 m .66351 .60835 L .66532 .60366 L F
.66208 .6075 m .66532 .60366 L .66491 .60432 L F
.752 .611 .702 r
.6651 .60872 m .66532 .60366 L .66351 .60835 L F
0 0 .443 r
.66532 .60366 m .66729 .6073 L .66701 .60617 L F
.66532 .60366 m .66701 .60617 L .66491 .60432 L F
.989 .888 .567 r
.66676 .60213 m .66751 .60006 L .66763 .6007 L F
.66603 .60333 m .66636 .60261 L .66676 .60213 L F
.66636 .60261 m .66751 .60006 L .66676 .60213 L F
.779 .547 .585 r
.66191 .60161 m .66583 .60325 L .66763 .6007 L F
.66583 .60325 m .66603 .60333 L .66676 .60213 L F
.66583 .60325 m .66676 .60213 L .66763 .6007 L F
0 0 0 r
.66679 .6021 m .66675 .60213 L .66727 .60158 L F
.66532 .60366 m .66491 .60432 L .66679 .6021 L F
.753 .644 .74 r
.66156 .60391 m .66573 .60337 L .66191 .60161 L F
.66573 .60337 m .66603 .60333 L .66583 .60325 L F
.66573 .60337 m .66583 .60325 L .66191 .60161 L F
.66573 .60337 m .66491 .60432 L .66603 .60333 L F
0 0 0 r
.66491 .60432 m .66491 .60432 L .66679 .6021 L F
.753 .644 .74 r
.66156 .60391 m .66491 .60432 L .66573 .60337 L F
0 0 0 r
.66552 .60361 m .66491 .60432 L .66544 .60371 L F
.66675 .60213 m .66491 .60432 L .66552 .60361 L F
.66583 .60325 m .66544 .60371 L .66572 .60338 L F
.66675 .60213 m .66544 .60371 L .66583 .60325 L F
.66675 .60213 m .66572 .60338 L .66727 .60158 L F
.73247 .59499 m .73484 .59454 L .73396 .59495 L F
.21 0 0 r
.73484 .59454 m .73617 .59562 L .73396 .59495 L F
.73484 .59454 m .73713 .5939 L .73617 .59562 L F
.584 .485 .708 r
.30831 .70035 m .30865 .70354 L .30636 .70296 L F
.529 .386 .631 r
.30865 .70354 m .30698 .70617 L .30636 .70296 L F
.948 .613 .352 r
.73691 .60801 m .73739 .61021 L .73821 .60875 L F
.101 0 0 r
.72037 .71936 m .71882 .71942 L .71643 .71931 L F
.455 .273 .544 r
.36664 .80929 m .36446 .81245 L .3664 .81189 L F
.36664 .80929 m .36446 .81245 L .3664 .81189 L F
.34 .025 .277 r
.32787 .68361 m .32678 .68646 L .32492 .68699 L F
.428 .141 .374 r
.33021 .68186 m .32977 .68366 L .32787 .68361 L F
.233 0 .226 r
.32846 .68559 m .32787 .68361 L .32977 .68366 L F
.32846 .68559 m .32678 .68646 L .32787 .68361 L F
.558 .508 .756 r
.37351 .6748 m .37553 .67318 L .37383 .67376 L F
.37351 .6748 m .37635 .67635 L .37553 .67318 L F
.598 .507 .723 r
.37431 .67688 m .37635 .67635 L .37351 .6748 L F
.238 0 .015 r
.35955 .67217 m .35896 .6709 L .36104 .67038 L F
.35955 .67217 m .35757 .67275 L .35896 .6709 L F
0 .443 .782 r
.54381 .72498 m .5434 .72507 L .54221 .72379 L F
.54381 .72498 m .54477 .72548 L .5434 .72507 L F
.498 .451 .736 r
.54477 .72548 m .54373 .72733 L .5434 .72507 L F
.437 .377 .693 r
.68796 .71416 m .68826 .71759 L .69029 .71585 L F
.514 .507 .786 r
.68826 .71759 m .69128 .719 L .69029 .71585 L F
.371 .141 .43 r
.62222 .68708 m .62128 .68956 L .62001 .68997 L F
.229 0 .321 r
.6243 .68434 m .62437 .68655 L .62222 .68708 L F
.123 0 .224 r
.62437 .68655 m .62128 .68956 L .62222 .68708 L F
.465 .808 .999 r
.29089 .601 m .2904 .60206 L .28909 .60129 L F
.29089 .601 m .29241 .60174 L .2904 .60206 L F
.876 .51 .349 r
.58177 .73625 m .58256 .73843 L .58436 .73883 L F
.917 .766 .679 r
.58208 .74069 m .58436 .73883 L .58256 .73843 L F
.58208 .74069 m .58354 .74177 L .58436 .73883 L F
.912 .957 .807 r
.70774 .58651 m .70889 .58323 L .70999 .58416 L F
.70774 .58651 m .70687 .58602 L .70889 .58323 L F
.509 .518 .8 r
.56398 .70862 m .56283 .71193 L .56158 .71052 L F
.56398 .70862 m .56525 .71194 L .56283 .71193 L F
.53 .354 .587 r
.39031 .7497 m .39238 .74931 L .39242 .74688 L F
.537 .357 .584 r
.39031 .7497 m .39234 .75163 L .39238 .74931 L F
.39031 .7497 m .39028 .75202 L .39234 .75163 L F
.657 .454 .597 r
.58833 .70068 m .59101 .70066 L .59086 .69823 L F
.574 .391 .595 r
.59086 .69823 m .59365 .70018 L .59395 .69792 L F
.59086 .69823 m .59101 .70066 L .59365 .70018 L F
.271 .755 .655 r
.39534 .79469 m .39569 .79455 L .39796 .79361 L F
.692 .179 .01 r
.39395 .79304 m .39569 .79455 L .39474 .79493 L F
.271 .755 .655 r
.39474 .79493 m .39569 .79455 L .39534 .79469 L F
.596 .621 .847 r
.39395 .79304 m .39606 .7944 L .39569 .79455 L F
.39606 .7944 m .39741 .79527 L .39569 .79455 L F
.504 .83 .999 r
.39569 .79455 m .39741 .79527 L .3995 .79479 L F
.683 .662 .823 r
.71316 .72922 m .7105 .72956 L .71005 .72752 L F
.755 .723 .822 r
.68311 .61596 m .68362 .61895 L .68042 .61888 L F
.77 .65 .73 r
.68362 .61895 m .6817 .62221 L .68042 .61888 L F
.773 .734 .817 r
.68634 .61623 m .68362 .61895 L .68311 .61596 L F
.752 .472 .507 r
.69761 .7076 m .70068 .70898 L .69732 .70868 L F
.368 .625 .952 r
.70098 .70789 m .69761 .7076 L .70048 .7058 L F
.70098 .70789 m .70068 .70898 L .69761 .7076 L F
.631 .934 .691 r
.64015 .60695 m .64149 .60603 L .63835 .60869 L F
.684 .466 .584 r
.64015 .60695 m .64357 .60502 L .64149 .60603 L F
.866 .524 .401 r
.57214 .74162 m .57052 .74158 L .56929 .73876 L F
.766 .308 .16 r
.57214 .74162 m .57143 .74298 L .57052 .74158 L F
.823 .383 .192 r
.57214 .74162 m .57453 .74399 L .57143 .74298 L F
.779 .471 .466 r
.57515 .74354 m .57453 .74399 L .57214 .74162 L F
.68 .792 .934 r
.38654 .80031 m .38742 .80126 L .38401 .801 L F
.757 .481 .514 r
.38401 .801 m .38742 .80126 L .38676 .80349 L F
.614 .768 .953 r
.38869 .80068 m .38742 .80126 L .38654 .80031 L F
.331 .067 .354 r
.38676 .80349 m .38742 .80126 L .38869 .80068 L F
.327 .215 .57 r
.37372 .68723 m .3752 .6834 L .37322 .68484 L F
.409 .203 .487 r
.29139 .63301 m .29102 .63518 L .28907 .63574 L F
.422 .237 .523 r
.29102 .63518 m .28891 .63801 L .28907 .63574 L F
.099 0 .22 r
.62128 .68956 m .61973 .69176 L .62001 .68997 L F
.797 .717 .776 r
.68951 .62165 m .69275 .62203 L .69168 .6189 L F
.781 .751 .826 r
.68951 .62165 m .69095 .62303 L .69275 .62203 L F
.756 .696 .795 r
.69168 .6189 m .69275 .62203 L .69497 .61927 L F
.522 .57 .845 r
.37213 .67044 m .37383 .67376 L .37553 .67318 L F
.145 .24 .704 r
.71672 .61791 m .71548 .61881 L .7174 .62112 L F
.669 .624 .795 r
.3085 .71142 m .30492 .70922 L .30703 .70876 L F
.511 .522 .803 r
.3091 .7082 m .3085 .71142 L .30703 .70876 L F
.3091 .7082 m .31044 .71134 L .3085 .71142 L F
.565 .937 .842 r
.51951 .79223 m .51855 .79325 L .51998 .79235 L F
.567 .932 .79 r
.51951 .79223 m .51774 .79343 L .51855 .79325 L F
.752 .796 .888 r
.56115 .69664 m .56003 .6988 L .56269 .69819 L F
.479 .383 .669 r
.56269 .69819 m .56366 .69465 L .56115 .69664 L F
.56269 .69819 m .56353 .69599 L .56366 .69465 L F
.56269 .69819 m .56461 .69811 L .56353 .69599 L F
.728 .565 .67 r
.56269 .69819 m .56606 .70086 L .56461 .69811 L F
.56269 .69819 m .56251 .70092 L .56606 .70086 L F
.336 .697 .982 r
.33951 .86898 m .33723 .86906 L .33786 .8682 L F
0 .204 .72 r
.33723 .86906 m .33917 .87119 L .33786 .8682 L F
0 .187 .716 r
.56561 .73593 m .5679 .73808 L .56632 .73575 L F
.806 .88 .899 r
.52243 .73056 m .52473 .72908 L .5233 .72831 L F
.782 .881 .918 r
.5233 .72831 m .52473 .72908 L .52639 .72765 L F
.524 .847 .998 r
.40325 .66777 m .39993 .66763 L .40211 .66707 L F
.609 .882 .991 r
.40325 .66777 m .40456 .66679 L .40483 .66534 L F
.40325 .66777 m .40211 .66707 L .40456 .66679 L F
.619 .581 .789 r
.40456 .66679 m .40387 .67038 L .40325 .66777 L F
.694 .704 .855 r
.56708 .69281 m .56999 .69322 L .56928 .69194 L F
.59 .655 .882 r
.56928 .69194 m .56999 .69322 L .57213 .69264 L F
.594 .507 .726 r
.56999 .69322 m .57287 .6951 L .57213 .69264 L F
.56999 .69322 m .57069 .69584 L .57287 .6951 L F
.046 0 .109 r
.59641 .66205 m .594 .66486 L .59488 .66324 L F
.545 .125 .195 r
.48159 .77953 m .48028 .78131 L .47842 .781 L F
.64 .233 .256 r
.48399 .78128 m .48028 .78131 L .48159 .77953 L F
.762 .64 .726 r
.64722 .62175 m .64842 .62501 L .65045 .62208 L F
.514 .243 .442 r
.30206 .67077 m .30416 .67043 L .30467 .66844 L F
.294 .045 .355 r
.30467 .66844 m .30583 .66963 L .30675 .6681 L F
.30467 .66844 m .30416 .67043 L .30583 .66963 L F
.518 .515 .793 r
.68796 .71416 m .6886 .71051 L .68641 .71078 L F
.68796 .71416 m .68987 .71381 L .6886 .71051 L F
.437 .377 .693 r
.68796 .71416 m .69029 .71585 L .68987 .71381 L F
.221 0 0 r
.46634 .72537 m .46863 .72542 L .46971 .72509 L F
.208 .733 .831 r
.46863 .72542 m .47195 .72517 L .46971 .72509 L F
.848 .898 .872 r
.68243 .62717 m .68237 .62958 L .68485 .62675 L F
.801 .412 0 r
.54668 .7068 m .5473 .70844 L .54576 .70548 L F
.795 .688 .746 r
.58626 .72179 m .589 .72463 L .58868 .7212 L F
.58626 .72179 m .58801 .72496 L .589 .72463 L F
0 0 .034 r
.58801 .72496 m .58827 .72577 L .589 .72463 L F
0 0 .49 r
.58868 .7212 m .589 .72463 L .58957 .72238 L F
.58892 .7214 m .58957 .72238 L .58966 .72201 L F
.58868 .7212 m .58957 .72238 L .58892 .7214 L F
.761 .832 .371 r
.58901 .72459 m .58827 .72577 L .58946 .72256 L F
.58957 .72238 m .58948 .72253 L .58966 .72201 L F
.468 .454 .76 r
.58966 .72201 m .59034 .72304 L .58948 .72253 L F
.105 0 0 r
.58868 .7212 m .58516 .72119 L .58626 .72179 L F
.468 .454 .76 r
.58966 .72201 m .58948 .72253 L .58735 .72128 L F
.761 .832 .371 r
.58948 .72253 m .58946 .72256 L .58966 .72201 L F
.58901 .72459 m .58946 .72256 L .58957 .72238 L F
.669 .656 .828 r
.584 .72409 m .58801 .72496 L .58626 .72179 L F
.665 .155 .02 r
.58735 .72128 m .58948 .72253 L .58632 .7221 L F
.58948 .72253 m .5898 .72272 L .58973 .72271 L F
.58948 .72253 m .58973 .72271 L .58946 .72256 L F
0 0 .1 r
.58946 .72256 m .59034 .72304 L .58966 .72201 L F
.761 .832 .371 r
.589 .72463 m .58899 .72465 L .58901 .72459 L F
.58899 .72465 m .58827 .72577 L .58901 .72459 L F
.635 .452 .617 r
.59307 .72466 m .59067 .72509 L .59008 .72273 L F
0 0 .1 r
.58827 .72577 m .59034 .72304 L .58946 .72256 L F
.665 .155 .02 r
.58946 .72256 m .58973 .72271 L .5894 .72265 L F
.58948 .72253 m .5894 .72265 L .58632 .7221 L F
.5898 .72272 m .59034 .72304 L .58995 .72295 L F
.5898 .72272 m .58995 .72295 L .58632 .7221 L F
.575 .885 .991 r
.58531 .72747 m .58798 .72733 L .58801 .72496 L F
.58798 .72733 m .58928 .72726 L .58852 .72589 L F
.58798 .72733 m .58852 .72589 L .58801 .72496 L F
.457 0 0 r
.59074 .72801 m .58742 .72758 L .58928 .72726 L F
.505 .509 .794 r
.38713 .78996 m .38845 .79312 L .38996 .79242 L F
.358 .138 .438 r
.38786 .79547 m .38996 .79242 L .38845 .79312 L F
.741 .551 .637 r
.52243 .73056 m .52201 .73333 L .52404 .73258 L F
.658 .365 .463 r
.61543 .65459 m .61212 .65686 L .6121 .65453 L F
.61543 .65459 m .61397 .65694 L .61212 .65686 L F
.656 .362 .462 r
.61543 .65459 m .61773 .65669 L .61397 .65694 L F
.617 .372 .523 r
.61752 .65461 m .61773 .65669 L .61543 .65459 L F
.219 .625 .954 r
.66771 .61232 m .66964 .61195 L .66709 .61154 L F
.66771 .61232 m .67085 .61301 L .66964 .61195 L F
.991 .806 .556 r
.66383 .61023 m .6651 .60872 L .66351 .60835 L F
.66383 .61023 m .66481 .6112 L .6651 .60872 L F
.366 0 0 r
.66607 .60987 m .6651 .60872 L .66481 .6112 L F
.66607 .60987 m .66734 .60848 L .6651 .60872 L F
.648 .748 .923 r
.68042 .61888 m .6783 .61951 L .67691 .61827 L F
.859 .408 .036 r
.67691 .61827 m .6783 .61951 L .67918 .62137 L F
.858 .688 .67 r
.68042 .61888 m .67918 .62137 L .6783 .61951 L F
.755 .654 .75 r
.69844 .71173 m .69517 .7119 L .69732 .70868 L F
.8 .476 .44 r
.69875 .71417 m .69517 .7119 L .69844 .71173 L F
.756 .655 .749 r
.70068 .70898 m .69844 .71173 L .69732 .70868 L F
.581 .402 .604 r
.70083 .71134 m .69844 .71173 L .70068 .70898 L F
.528 .364 .602 r
.70083 .71134 m .69875 .71417 L .69844 .71173 L F
.194 0 0 r
.41984 .78977 m .4161 .79006 L .41732 .79027 L F
.59 .731 .941 r
.6813 .59694 m .67921 .59771 L .67822 .59621 L F
.412 .185 .457 r
.67869 .60022 m .67921 .59771 L .6813 .59694 L F
.533 .377 .615 r
.38318 .78249 m .38554 .78231 L .38527 .77937 L F
.532 .404 .65 r
.38318 .78249 m .38525 .78447 L .38554 .78231 L F
.38318 .78249 m .38365 .78529 L .38525 .78447 L F
.481 .212 .428 r
.31642 .6623 m .31904 .65983 L .31715 .66038 L F
.451 .162 .382 r
.33173 .68316 m .33021 .68186 L .33222 .6813 L F
.33173 .68316 m .32977 .68366 L .33021 .68186 L F
.707 .536 .655 r
.60097 .70598 m .60149 .70857 L .59876 .7086 L F
.614 .427 .605 r
.60377 .70365 m .60389 .7061 L .60097 .70598 L F
.587 .434 .641 r
.60389 .7061 m .60149 .70857 L .60097 .70598 L F
.547 .371 .595 r
.33727 .71025 m .3381 .70985 L .33954 .7118 L F
.296 0 0 r
.33853 .71251 m .34179 .71177 L .33954 .7118 L F
.33 0 .189 r
.34049 .71153 m .33882 .71264 L .33954 .7118 L F
.213 0 0 r
.33954 .7118 m .33882 .71264 L .33853 .71251 L F
.201 .579 .941 r
.53486 .72206 m .53396 .72281 L .53279 .72202 L F
.53486 .72206 m .53644 .72324 L .53396 .72281 L F
.453 .087 .253 r
.29676 .67614 m .29907 .67591 L .30026 .67384 L F
.305 0 .168 r
.30026 .67384 m .30122 .67474 L .30162 .67296 L F
.30026 .67384 m .29907 .67591 L .30122 .67474 L F
.795 .937 .578 r
.69762 .594 m .69784 .59422 L .69673 .59584 L F
.64 .954 .76 r
.70032 .59215 m .69784 .59422 L .69768 .59406 L F
.70032 .59215 m .69768 .59406 L .69794 .59378 L F
.70032 .59215 m .69762 .594 L .69886 .59333 L F
.70032 .59215 m .69886 .59333 L .69842 .59146 L F
.096 0 .445 r
.70049 .58975 m .69842 .59146 L .69876 .59292 L F
.6993 .59235 m .69876 .59292 L .69886 .59333 L F
.70049 .58975 m .69876 .59292 L .6993 .59235 L F
.64 .954 .76 r
.69794 .59378 m .69768 .59406 L .69762 .594 L F
.758 .54 .601 r
.70123 .5951 m .70138 .59743 L .69818 .59746 L F
.595 .415 .608 r
.70362 .5948 m .70138 .59743 L .70123 .5951 L F
.611 .473 .669 r
.5837 .70366 m .5861 .70332 L .58617 .70096 L F
.601 .431 .623 r
.5837 .70366 m .58389 .70615 L .5861 .70332 L F
.59 .921 .699 r
.44892 .77318 m .44945 .77242 L .45177 .77213 L F
.44892 .77318 m .44812 .7736 L .44945 .77242 L F
.75 .671 .774 r
.72781 .58954 m .726 .59173 L .72593 .59008 L F
0 .361 .723 r
.72828 .71166 m .73213 .71333 L .72935 .71231 L F
.535 .356 .585 r
.71712 .72212 m .71444 .71983 L .71643 .71931 L F
.71712 .72212 m .71446 .72274 L .71444 .71983 L F
.927 .851 .747 r
.70098 .70789 m .70301 .71092 L .70068 .70898 L F
.52 .356 .599 r
.70068 .70898 m .70301 .71092 L .70083 .71134 L F
.086 .307 .787 r
.70098 .70789 m .70301 .71092 L .70068 .70898 L F
.588 .714 .93 r
.30886 .74064 m .31216 .7416 L .31132 .74046 L F
.538 .295 .494 r
.31449 .73993 m .31445 .7414 L .31216 .7416 L F
.683 .173 .021 r
.31445 .7414 m .31132 .74046 L .31216 .7416 L F
.658 .972 .877 r
.55767 .68081 m .56072 .67895 L .5613 .67914 L F
.808 .995 .866 r
.56382 .67677 m .5613 .67914 L .5619 .67738 L F
.825 .999 .795 r
.5613 .67914 m .56072 .67895 L .5619 .67738 L F
.489 .612 .901 r
.72384 .58616 m .72189 .58773 L .72124 .58637 L F
.72384 .58616 m .7248 .58888 L .72189 .58773 L F
.523 .326 .555 r
.41578 .76325 m .41566 .76564 L .41357 .76599 L F
.601 .501 .712 r
.41566 .76564 m .41384 .76815 L .41357 .76599 L F
.48 .529 .83 r
.39525 .66266 m .39447 .66554 L .3931 .66269 L F
.39525 .66266 m .39647 .66577 L .39447 .66554 L F
0 0 .245 r
.56143 .72818 m .56219 .72915 L .56198 .727 L F
.56143 .72818 m .56094 .73046 L .56219 .72915 L F
.772 .269 0 r
.66469 .59834 m .66437 .59694 L .66306 .59569 L F
.732 .213 0 r
.66751 .60006 m .66437 .59694 L .66763 .6007 L F
.892 .953 .836 r
.58412 .67509 m .58426 .67691 L .58634 .67427 L F
.872 .922 .529 r
.58412 .67509 m .58298 .67869 L .58426 .67691 L F
.249 .084 .452 r
.56251 .70092 m .56376 .7015 L .56606 .70086 L F
.561 0 0 r
.56832 .70049 m .56461 .69811 L .56606 .70086 L F
.379 .84 .79 r
.56606 .70086 m .56735 .70013 L .56832 .70049 L F
.56606 .70086 m .56376 .7015 L .56735 .70013 L F
.623 .057 0 r
.73213 .71333 m .73483 .71479 L .73367 .71384 L F
0 0 0 r
.73464 .72022 m .73397 .72171 L .73368 .72177 L F
0 0 .329 r
.73566 .71684 m .736 .71928 L .73464 .72022 L F
0 0 0 r
.736 .71928 m .73397 .72171 L .73464 .72022 L F
.749 .742 .845 r
.33338 .84206 m .33466 .84463 L .33131 .84503 L F
.06 0 0 r
.33181 .84497 m .33466 .84463 L .33323 .84489 L F
.754 .379 .343 r
.33338 .84206 m .33531 .84381 L .33466 .84463 L F
.503 .433 .71 r
.33338 .84206 m .33386 .84456 L .33531 .84381 L F
.78 .619 .681 r
.32989 .84389 m .33338 .84206 L .33131 .84503 L F
.32989 .84389 m .33325 .84475 L .33338 .84206 L F
.523 .918 .898 r
.33323 .84489 m .33466 .84463 L .33502 .84418 L F
.33389 .84455 m .33502 .84418 L .33531 .84381 L F
.33323 .84489 m .33502 .84418 L .33389 .84455 L F
.33235 .84505 m .33323 .84489 L .33386 .84456 L F
.774 .634 .706 r
.33235 .84505 m .33392 .84493 L .33325 .84475 L F
.06 0 0 r
.33181 .84497 m .33323 .84489 L .33235 .84505 L F
.774 .634 .706 r
.33235 .84505 m .33325 .84475 L .32989 .84389 L F
.78 .619 .681 r
.33325 .84475 m .33392 .84493 L .33386 .84456 L F
.33325 .84475 m .33386 .84456 L .33338 .84206 L F
.523 .918 .898 r
.33244 .84501 m .33386 .84456 L .33531 .84381 L F
.33235 .84505 m .33386 .84456 L .33244 .84501 L F
.503 .433 .71 r
.33386 .84456 m .33391 .84485 L .33531 .84381 L F
.33391 .84485 m .33392 .84493 L .33403 .84484 L F
.33391 .84485 m .33403 .84484 L .33531 .84381 L F
.06 0 0 r
.33131 .84503 m .33181 .84497 L .33235 .84505 L F
.895 .965 .828 r
.6817 .62221 m .67954 .62492 L .67932 .6238 L F
.015 0 .434 r
.67954 .62492 m .68052 .62555 L .67932 .6238 L F
.67954 .62492 m .67956 .62723 L .68052 .62555 L F
.625 .803 .968 r
.38648 .65739 m .38443 .65807 L .38301 .65696 L F
.536 .225 .387 r
.45319 .74114 m .44995 .74364 L .45149 .74117 L F
.637 .511 .693 r
.38374 .77411 m .38676 .77424 L .38616 .77103 L F
.653 .483 .642 r
.38374 .77411 m .3869 .77646 L .38676 .77424 L F
.38374 .77411 m .38461 .77704 L .3869 .77646 L F
.35 .142 .451 r
.37158 .69004 m .37123 .69225 L .37324 .68941 L F
0 0 .375 r
.41688 .7636 m .41578 .76325 L .41452 .76231 L F
.41688 .7636 m .41566 .76564 L .41578 .76325 L F
.079 .3 .783 r
.7366 .71578 m .73566 .71684 L .73483 .71479 L F
.136 0 .352 r
.73719 .71793 m .73566 .71684 L .7366 .71578 L F
.73719 .71793 m .736 .71928 L .73566 .71684 L F
.782 .741 .814 r
.68716 .62424 m .69095 .62303 L .68951 .62165 L F
.554 .225 .366 r
.59843 .64562 m .60094 .64393 L .59902 .64449 L F
.098 0 .222 r
.62649 .68143 m .62614 .68361 L .6243 .68434 L F
.051 0 .288 r
.62541 .68537 m .6243 .68434 L .62614 .68361 L F
.62541 .68537 m .62437 .68655 L .6243 .68434 L F
.548 .268 .443 r
.35486 .70596 m .35712 .70578 L .3576 .70384 L F
.254 .006 .331 r
.3576 .70384 m .35876 .70496 L .35959 .70351 L F
.3576 .70384 m .35712 .70578 L .35876 .70496 L F
0 0 .017 r
.67797 .57938 m .67598 .58169 L .67767 .58045 L F
0 0 0 r
.67527 .58353 m .67767 .58045 L .67598 .58169 L F
.73 .717 .838 r
.70282 .61713 m .70603 .61869 L .70506 .61616 L F
.69 .721 .873 r
.70506 .61616 m .70603 .61869 L .70862 .61694 L F
.826 .752 .782 r
.33542 .83982 m .33689 .84198 L .33338 .84206 L F
.754 .379 .343 r
.33338 .84206 m .33689 .84198 L .33531 .84381 L F
.568 .662 .901 r
.33893 .84161 m .33689 .84198 L .33542 .83982 L F
.308 0 .026 r
.33531 .84381 m .33689 .84198 L .33893 .84161 L F
.599 .402 .586 r
.41387 .7551 m .4136 .75717 L .41134 .75718 L F
.658 .486 .64 r
.59634 .71154 m .59406 .71421 L .59397 .71177 L F
.703 .541 .665 r
.60611 .70348 m .60389 .7061 L .60377 .70365 L F
.543 .123 .194 r
.44065 .72718 m .44299 .72738 L .44415 .72567 L F
.501 .078 .169 r
.44415 .72567 m .44299 .72738 L .44621 .72654 L F
.536 .311 .521 r
.31989 .6895 m .31723 .69203 L .31781 .68998 L F
.783 .601 .654 r
.67543 .58982 m .67464 .59191 L .67744 .59131 L F
.787 .755 .823 r
.70862 .61694 m .71162 .617 L .71067 .61603 L F
.546 .803 .993 r
.71162 .617 m .7138 .61657 L .71067 .61603 L F
.858 .688 .67 r
.68042 .61888 m .6817 .62221 L .67918 .62137 L F
.895 .965 .828 r
.6817 .62221 m .67932 .6238 L .67918 .62137 L F
.972 .662 .352 r
.31292 .73659 m .31326 .73922 L .31449 .73993 L F
.981 .701 .408 r
.31326 .73922 m .31445 .7414 L .31449 .73993 L F
.621 .663 .87 r
.57984 .72758 m .58058 .72967 L .58278 .72865 L F
.62 .437 .613 r
.54373 .72733 m .54105 .73008 L .54094 .7281 L F
.54373 .72733 m .54438 .72983 L .54105 .73008 L F
.498 .451 .736 r
.54477 .72548 m .54487 .7279 L .54373 .72733 L F
.636 .472 .644 r
.54487 .7279 m .54438 .72983 L .54373 .72733 L F
.874 .466 .019 r
.56929 .73876 m .56929 .74022 L .5679 .73808 L F
.56929 .73876 m .57052 .74158 L .56929 .74022 L F
.644 .326 .419 r
.6063 .64298 m .60961 .64087 L .60651 .64137 L F
.6063 .64298 m .60889 .64319 L .60961 .64087 L F
.578 .261 .395 r
.60961 .64087 m .61175 .64246 L .61206 .64115 L F
.60961 .64087 m .60889 .64319 L .61175 .64246 L F
.555 .82 .995 r
.33452 .71022 m .33304 .71097 L .33113 .7095 L F
.82 .521 .483 r
.69816 .70368 m .69812 .70522 L .69964 .70344 L F
.852 .57 .511 r
.69812 .70522 m .70048 .7058 L .69964 .70344 L F
.918 .978 .744 r
.59072 .66861 m .58891 .66981 L .58957 .67032 L F
.814 .988 .88 r
.59108 .66699 m .59072 .66861 L .59191 .6672 L F
.855 .994 .752 r
.59108 .66699 m .58891 .66981 L .59072 .66861 L F
0 0 0 r
.59883 .65963 m .59641 .66205 L .59723 .66093 L F
.759 .519 .57 r
.62112 .65471 m .61773 .65669 L .61752 .65461 L F
.62112 .65471 m .62113 .65703 L .61773 .65669 L F
.495 .28 .516 r
.39242 .74688 m .39442 .74645 L .39476 .7443 L F
.536 .359 .588 r
.39242 .74688 m .39446 .74891 L .39442 .74645 L F
.39242 .74688 m .39238 .74931 L .39446 .74891 L F
.112 0 0 r
.51824 .78443 m .52041 .78398 L .52208 .78297 L F
.306 .799 .844 r
.52128 .78265 m .52198 .78253 L .52207 .78263 L F
.548 .899 .68 r
.52227 .78286 m .52207 .78263 L .52383 .78199 L F
.052 .615 .783 r
.52383 .78199 m .52594 .78203 L .52716 .78217 L F
.265 .773 .817 r
.52207 .78263 m .52594 .78203 L .52383 .78199 L F
.306 .799 .844 r
.52198 .78253 m .52488 .78202 L .52207 .78263 L F
.548 .899 .68 r
.52208 .78297 m .52207 .78263 L .52227 .78286 L F
.52208 .78297 m .52041 .78398 L .52207 .78263 L F
.439 .031 .166 r
.68006 .5798 m .67797 .57938 L .67767 .58045 L F
.446 .076 .241 r
.68006 .5798 m .68045 .57889 L .67797 .57938 L F
.236 .088 .467 r
.61318 .68185 m .6131 .68418 L .61448 .6811 L F
.67 .535 .692 r
.41563 .75402 m .4136 .75717 L .41387 .7551 L F
.4 .092 .323 r
.31904 .65983 m .32101 .65938 L .32171 .65703 L F
.347 .044 .302 r
.32171 .65703 m .32287 .65879 L .32367 .65623 L F
.32171 .65703 m .32101 .65938 L .32287 .65879 L F
.687 .372 .437 r
.58192 .70914 m .58328 .7104 L .58442 .70853 L F
.58192 .70914 m .58204 .71101 L .58328 .7104 L F
.287 .225 .611 r
.54254 .77898 m .54127 .78182 L .54283 .77905 L F
.54254 .77898 m .54293 .78199 L .54127 .78182 L F
0 0 0 r
.54166 .78185 m .54127 .78182 L .54293 .78199 L F
.54059 .78377 m .54054 .78377 L .54127 .78182 L F
.54166 .78185 m .54059 .78377 L .54127 .78182 L F
.54059 .78377 m .54044 .78406 L .54054 .78377 L F
.742 .864 .937 r
.54035 .78269 m .54044 .78406 L .54166 .78185 L F
0 0 .355 r
.54085 .78337 m .54098 .78381 L .54035 .78269 L F
.54098 .78381 m .54147 .78557 L .54078 .78379 L F
.54098 .78381 m .54078 .78379 L .54035 .78269 L F
0 .139 .683 r
.71674 .58314 m .716 .58344 L .71483 .58085 L F
.779 .277 0 r
.71411 .58129 m .71674 .58314 L .71483 .58085 L F
.079 .595 .882 r
.71753 .58282 m .71674 .58314 L .71577 .58248 L F
.71838 .58298 m .71674 .58314 L .71753 .58282 L F
0 .139 .683 r
.71674 .58314 m .71609 .58365 L .716 .58344 L F
.137 .583 .926 r
.71674 .58314 m .71772 .58396 L .71609 .58365 L F
.272 .694 .968 r
.38018 .81974 m .38056 .81894 L .37841 .81933 L F
.38018 .81974 m .3819 .81971 L .38056 .81894 L F
.38056 .81894 m .38018 .81974 L .37841 .81933 L F
.38056 .81894 m .3819 .81971 L .38018 .81974 L F
.481 0 0 r
.49587 .78287 m .4949 .78366 L .49268 .78279 L F
.563 .021 0 r
.49587 .78287 m .4982 .7841 L .4949 .78366 L F
.514 0 0 r
.49973 .78431 m .4982 .7841 L .49587 .78287 L F
.567 .387 .597 r
.38687 .7605 m .38901 .76253 L .38895 .76012 L F
.38687 .7605 m .38685 .76287 L .38901 .76253 L F
.455 .29 .567 r
.3752 .6834 m .37695 .68116 L .37526 .68185 L F
0 0 0 r
.67836 .58639 m .67686 .587 L .67902 .58578 L F
.059 .62 .794 r
.68198 .58587 m .68033 .58567 L .67902 .58578 L F
.512 .225 .415 r
.68033 .58567 m .67836 .58639 L .67902 .58578 L F
.689 .553 .695 r
.48532 .73552 m .48655 .73872 L .48882 .73604 L F
.598 .507 .723 r
.37431 .67688 m .37694 .67874 L .37635 .67635 L F
.479 .785 .998 r
.28173 .59979 m .28133 .60103 L .27983 .59993 L F
.28173 .59979 m .28328 .6007 L .28133 .60103 L F
.635 .175 0 r
.64719 .61273 m .64612 .61111 L .64515 .61075 L F
.64719 .61273 m .64778 .61341 L .64612 .61111 L F
.486 .819 .999 r
.64659 .61206 m .64719 .61273 L .64944 .61233 L F
.58 .049 0 r
.6462 .61202 m .64719 .61273 L .64515 .61075 L F
.486 .819 .999 r
.6462 .61202 m .64719 .61273 L .64659 .61206 L F
.635 .175 0 r
.64719 .61273 m .64847 .61436 L .64778 .61341 L F
.327 .215 .57 r
.37372 .68723 m .37518 .6866 L .3752 .6834 L F
.404 .215 .508 r
.37324 .68941 m .37518 .6866 L .37372 .68723 L F
.813 .53 .508 r
.57515 .74354 m .57441 .74639 L .57453 .74399 L F
.722 .553 .661 r
.57788 .74382 m .57441 .74639 L .57515 .74354 L F
.578 .539 .775 r
.41655 .7712 m .41515 .77359 L .41463 .77144 L F
.41655 .7712 m .41722 .77307 L .41515 .77359 L F
0 .1 .653 r
.57753 .73023 m .57952 .73248 L .57914 .73279 L F
0 .026 .598 r
.57952 .73248 m .581 .73537 L .57914 .73279 L F
.003 0 0 r
.34697 .72407 m .3463 .7249 L .34507 .725 L F
0 0 0 r
.3463 .7249 m .34346 .72648 L .34507 .725 L F
.627 .636 .84 r
.39993 .66763 m .39781 .66832 L .39647 .66577 L F
.093 .643 .823 r
.44016 .77537 m .43961 .77545 L .43668 .77514 L F
.622 .614 .822 r
.636 .60817 m .63835 .60869 L .63637 .60884 L F
.593 .372 .549 r
.72925 .73839 m .72679 .74078 L .72716 .73927 L F
.786 .609 .661 r
.50535 .72225 m .50185 .72397 L .50325 .72301 L F
.983 .723 .454 r
.70885 .58102 m .70999 .58416 L .70889 .58323 L F
.614 .394 .559 r
.59578 .69518 m .59829 .69505 L .59817 .69266 L F
.704 .463 .557 r
.59817 .69266 m .59829 .69505 L .60058 .695 L F
.776 .647 .719 r
.64514 .62456 m .64842 .62501 L .64722 .62175 L F
.537 .379 .614 r
.39442 .74645 m .39642 .7437 L .39476 .7443 L F
0 .487 .838 r
.48987 .77604 m .48945 .77628 L .48805 .7759 L F
.675 .51 .654 r
.38996 .79242 m .39306 .79402 L .39268 .79 L F
.965 .723 .52 r
.39307 .7941 m .39369 .79414 L .39395 .79304 L F
.3925 .79478 m .3931 .79446 L .39307 .7941 L F
.3931 .79446 m .39369 .79414 L .39307 .7941 L F
.631 .859 .488 r
.3925 .79478 m .39059 .79747 L .39369 .79414 L F
.737 .363 .344 r
.3925 .79478 m .39406 .79454 L .39319 .79409 L F
.692 .179 .01 r
.39307 .7941 m .39314 .79414 L .3925 .79478 L F
.737 .363 .344 r
.3925 .79478 m .39319 .79409 L .38996 .79242 L F
.692 .179 .01 r
.39314 .79414 m .39357 .79436 L .3925 .79478 L F
.39395 .79304 m .39432 .79394 L .3939 .794 L F
.39352 .79356 m .3939 .794 L .39307 .7941 L F
.39395 .79304 m .3939 .794 L .39352 .79356 L F
0 0 .54 r
.39268 .79 m .3939 .794 L .39389 .79087 L F
.3939 .794 m .39406 .79454 L .39404 .79417 L F
.3939 .794 m .39404 .79417 L .39389 .79087 L F
.675 .51 .654 r
.39306 .79402 m .39319 .79409 L .39268 .79 L F
.39319 .79409 m .39406 .79454 L .3939 .794 L F
.39319 .79409 m .3939 .794 L .39268 .79 L F
.841 .831 .837 r
.39389 .79087 m .39404 .79417 L .3925 .79478 L F
.39404 .79417 m .39406 .79454 L .3925 .79478 L F
.692 .179 .01 r
.39357 .79436 m .39474 .79493 L .3925 .79478 L F
.39432 .79394 m .39474 .79493 L .39307 .7941 L F
.398 0 .089 r
.34258 .6768 m .33964 .67781 L .3401 .6767 L F
.453 .67 .956 r
.42235 .77559 m .42149 .77699 L .42038 .77562 L F
.502 .734 .977 r
.42235 .77559 m .4237 .77683 L .42149 .77699 L F
.505 .412 .683 r
.41608 .76787 m .41463 .77144 L .41384 .76815 L F
.41608 .76787 m .41655 .7712 L .41463 .77144 L F
.499 .408 .684 r
.38578 .76866 m .38722 .76549 L .38504 .76573 L F
.38578 .76866 m .38769 .76831 L .38722 .76549 L F
.552 .467 .712 r
.38616 .77103 m .38769 .76831 L .38578 .76866 L F
.32 .228 .593 r
.57714 .70536 m .57549 .70602 L .57523 .70563 L F
.723 .62 .743 r
.54105 .73008 m .53897 .73045 L .54094 .7281 L F
.665 .401 .512 r
.54105 .73008 m .54077 .73278 L .53897 .73045 L F
.757 .484 .52 r
.54424 .733 m .54105 .73008 L .54438 .72983 L F
.54424 .733 m .54077 .73278 L .54105 .73008 L F
.615 .556 .765 r
.63933 .61108 m .636 .60817 L .63697 .61128 L F
.613 .369 .524 r
.63917 .6131 m .63697 .61128 L .63689 .61323 L F
.63917 .6131 m .63933 .61108 L .63697 .61128 L F
.465 0 0 r
.72914 .59471 m .73247 .59499 L .73174 .59514 L F
0 0 0 r
.73247 .59499 m .73396 .59495 L .73174 .59514 L F
.909 .941 .815 r
.5864 .67186 m .58634 .67427 L .58822 .67157 L F
.904 .938 .822 r
.5864 .67186 m .58412 .67509 L .58634 .67427 L F
.858 .47 0 r
.581 .73537 m .58256 .73843 L .58177 .73625 L F
.442 .158 .385 r
.57704 .71417 m .57925 .71379 L .57979 .71177 L F
.476 .189 .398 r
.57979 .71177 m .5818 .71302 L .58204 .71101 L F
.57979 .71177 m .57925 .71379 L .5818 .71302 L F
.494 .311 .561 r
.29483 .62476 m .29473 .62705 L .29279 .62755 L F
.488 .294 .544 r
.29473 .62705 m .29453 .62934 L .29279 .62755 L F
.43 .29 .588 r
.29279 .62755 m .29453 .62934 L .29286 .6299 L F
.656 .861 .978 r
.3995 .79479 m .40283 .79461 L .40115 .79448 L F
.562 .901 .978 r
.4039 .79363 m .40283 .79461 L .40502 .79293 L F
.4039 .79363 m .40115 .79448 L .40283 .79461 L F
.657 .968 .807 r
.70066 .5741 m .69971 .57517 L .69883 .57548 L F
.683 .662 .823 r
.71316 .72922 m .71005 .72752 L .71231 .72711 L F
.769 .286 .088 r
.71231 .72711 m .71585 .72908 L .71316 .72922 L F
.892 .879 .815 r
.6912 .58101 m .68893 .58209 L .68946 .58098 L F
.279 .772 .713 r
.41549 .80165 m .41535 .80169 L .41293 .80254 L F
.248 .752 .706 r
.41549 .80165 m .41535 .80169 L .41746 .801 L F
.41746 .801 m .41535 .80169 L .41549 .80165 L F
.949 .957 .7 r
.67527 .58806 m .67543 .58982 L .67686 .587 L F
0 0 0 r
.67836 .58639 m .67527 .58806 L .67686 .587 L F
.638 .62 .816 r
.5685 .7144 m .5665 .71525 L .56525 .71194 L F
.843 .53 .458 r
.68101 .61346 m .68276 .61394 L .68311 .61596 L F
.678 .431 .54 r
.60979 .65446 m .60967 .65697 L .60657 .65692 L F
.693 .467 .576 r
.6121 .65453 m .60967 .65697 L .60979 .65446 L F
.878 .895 .84 r
.70089 .718 m .69996 .71824 L .70231 .71863 L F
.508 .112 .225 r
.42195 .73288 m .42431 .73289 L .42555 .73089 L F
.445 .047 .189 r
.42555 .73089 m .42431 .73289 L .42721 .73188 L F
.431 .063 .237 r
.42555 .73089 m .42721 .73188 L .42773 .73051 L F
.807 .684 .728 r
.6476 .60678 m .6508 .60649 L .6526 .60578 L F
0 .159 .698 r
.6526 .60578 m .6546 .60782 L .65433 .60676 L F
.6526 .60578 m .65433 .60676 L .65183 .60602 L F
.54 .527 .789 r
.65183 .60602 m .65433 .60676 L .65402 .60566 L F
.807 .684 .728 r
.64911 .60648 m .6526 .60578 L .65183 .60602 L F
.54 .527 .789 r
.65183 .60602 m .65402 .60566 L .65344 .60359 L F
.807 .684 .728 r
.6476 .60678 m .64911 .60648 L .65183 .60602 L F
.844 .709 .714 r
.64562 .63633 m .64445 .63288 L .6441 .63523 L F
.835 .715 .732 r
.64474 .63772 m .64562 .63633 L .6441 .63523 L F
.358 0 0 r
.49055 .78202 m .48917 .78218 L .48713 .78174 L F
.364 0 0 r
.49055 .78202 m .49149 .78271 L .48917 .78218 L F
.49055 .78202 m .49268 .78279 L .49149 .78271 L F
0 0 .523 r
.72824 .73515 m .72748 .73374 L .72768 .73267 L F
.72824 .73515 m .7283 .73615 L .72748 .73374 L F
.124 .639 .891 r
.35825 .64887 m .36192 .6496 L .35973 .64963 L F
.619 .581 .789 r
.40456 .66679 m .40679 .67043 L .40387 .67038 L F
.592 .438 .641 r
.40642 .67293 m .40387 .67038 L .40679 .67043 L F
.40642 .67293 m .40419 .6734 L .40387 .67038 L F
.733 .214 0 r
.58041 .7202 m .57736 .71718 L .57859 .71973 L F
.553 .569 .824 r
.5789 .71981 m .58191 .72244 L .58041 .7202 L F
.733 .214 0 r
.58041 .7202 m .58004 .72064 L .57736 .71718 L F
0 0 .573 r
.57772 .7174 m .58004 .72064 L .57851 .7179 L F
.57736 .71718 m .57804 .71805 L .57772 .7174 L F
.57804 .71805 m .58004 .72064 L .57772 .7174 L F
.553 .569 .824 r
.57859 .71973 m .57904 .7201 L .5789 .71981 L F
.57904 .7201 m .58191 .72244 L .5789 .71981 L F
.321 0 0 r
.45594 .78168 m .45223 .78319 L .45372 .78166 L F
0 0 0 r
.47769 .72308 m .47403 .72458 L .47613 .72392 L F
.447 .005 .103 r
.47613 .72392 m .47963 .72223 L .47769 .72308 L F
.362 .107 .386 r
.65263 .59795 m .65269 .59499 L .6514 .59767 L F
.381 .121 .39 r
.65493 .59538 m .65269 .59499 L .65263 .59795 L F
.293 0 0 r
.65493 .59538 m .6558 .59483 L .65269 .59499 L F
.057 0 0 r
.3318 .6513 m .33281 .6514 L .33394 .65063 L F
.238 0 0 r
.3318 .6513 m .33228 .6525 L .33281 .6514 L F
.3318 .6513 m .33025 .65301 L .33228 .6525 L F
.352 0 0 r
.44804 .78392 m .44481 .78438 L .44663 .78398 L F
.425 .668 .963 r
.7182 .6224 m .71967 .62115 L .7174 .62112 L F
.7182 .6224 m .72075 .62256 L .71967 .62115 L F
.749 .602 .695 r
.57939 .68083 m .58298 .67869 L .58271 .6783 L F
.57939 .68083 m .58111 .68174 L .58298 .67869 L F
.872 .922 .529 r
.58412 .67509 m .58271 .6783 L .58298 .67869 L F
.717 .59 .712 r
.58789 .74951 m .58897 .75228 L .58568 .75227 L F
.754 .456 .48 r
.58897 .75424 m .58568 .75227 L .58897 .75228 L F
.694 .576 .718 r
.59045 .74991 m .58897 .75228 L .58789 .74951 L F
.59045 .74991 m .59119 .75228 L .58897 .75228 L F
.669 .462 .595 r
.59119 .75228 m .58897 .75424 L .58897 .75228 L F
.347 .117 .417 r
.39 .69164 m .38887 .69024 L .39049 .68957 L F
.39 .69164 m .38823 .69247 L .38887 .69024 L F
.585 .47 .688 r
.38504 .76573 m .38685 .76287 L .3846 .76324 L F
.671 .525 .678 r
.52404 .73258 m .52759 .73328 L .52731 .73068 L F
.668 .538 .697 r
.52404 .73258 m .5254 .73593 L .52759 .73328 L F
.492 .047 .119 r
.34557 .71009 m .34929 .70858 L .34733 .70914 L F
.473 .204 .425 r
.2925 .67897 m .29456 .67851 L .29515 .67659 L F
.438 .171 .41 r
.29515 .67659 m .29649 .67803 L .29676 .67614 L F
.29515 .67659 m .29456 .67851 L .29649 .67803 L F
.467 .248 .497 r
.49643 .73553 m .49443 .73606 L .49676 .73298 L F
.49643 .73553 m .49443 .73606 L .49676 .73298 L F
.965 .724 .523 r
.49519 .73242 m .49643 .73553 L .49676 .73298 L F
.337 .773 .967 r
.49676 .73298 m .49519 .73242 L .49872 .73273 L F
.458 .24 .495 r
.49872 .73273 m .49643 .73553 L .49676 .73298 L F
.129 .571 .923 r
.32989 .84389 m .32992 .84455 L .32918 .84386 L F
.32989 .84389 m .33131 .84503 L .32992 .84455 L F
.32989 .84389 m .32992 .84455 L .32918 .84386 L F
.32989 .84389 m .33131 .84503 L .32992 .84455 L F
0 0 0 r
.68777 .58021 m .68721 .58129 L .68847 .57852 L F
.774 .75 .831 r
.68855 .57632 m .68847 .57852 L .68951 .5774 L F
.378 .408 .765 r
.6902 .57716 m .68847 .57852 L .68855 .57632 L F
.751 .559 .635 r
.68893 .57863 m .68777 .58021 L .68975 .5789 L F
.836 .72 .737 r
.68974 .57752 m .68893 .57863 L .68958 .57765 L F
.476 .369 .654 r
.68855 .57632 m .68934 .57801 L .6902 .57716 L F
.68934 .57801 m .68975 .5789 L .6902 .57716 L F
.836 .72 .737 r
.68958 .57765 m .68929 .57806 L .68847 .57852 L F
.68929 .57806 m .68777 .58021 L .68822 .57911 L F
.68929 .57806 m .68822 .57911 L .68847 .57852 L F
.68893 .57863 m .68777 .58021 L .68958 .57765 L F
.776 .503 .522 r
.68459 .57723 m .68893 .57863 L .68855 .57632 L F
.68893 .57863 m .68975 .5789 L .68934 .57801 L F
.68893 .57863 m .68934 .57801 L .68855 .57632 L F
.751 .559 .635 r
.68459 .57723 m .68777 .58021 L .68893 .57863 L F
.836 .72 .737 r
.6902 .57716 m .68777 .58021 L .68974 .57752 L F
.751 .559 .635 r
.68459 .57723 m .68463 .58003 L .68777 .58021 L F
.623 .954 .92 r
.68777 .58021 m .68684 .58016 L .68821 .57938 L F
.574 .922 .727 r
.68975 .5789 m .68973 .57889 L .6902 .57716 L F
.836 .72 .737 r
.6902 .57716 m .68946 .58098 L .6892 .58086 L F
.6902 .57716 m .68973 .57889 L .68777 .58021 L F
.574 .922 .727 r
.68973 .57889 m .68777 .58021 L .68933 .57874 L F
.68975 .5789 m .68777 .58021 L .68973 .57889 L F
.836 .72 .737 r
.68973 .57889 m .6892 .58086 L .68777 .58021 L F
.574 .922 .727 r
.68973 .57889 m .68933 .57874 L .6902 .57716 L F
.623 .954 .92 r
.68777 .58021 m .68821 .57938 L .68933 .57874 L F
0 0 0 r
.68777 .58021 m .68647 .58292 L .68721 .58129 L F
.539 .231 .395 r
.32329 .73592 m .32289 .73603 L .32452 .73368 L F
.062 0 .031 r
.32625 .73297 m .32329 .73592 L .32452 .73368 L F
.628 .396 .547 r
.53897 .73045 m .54077 .73278 L .53886 .73241 L F
.215 0 0 r
.52843 .78772 m .52699 .78893 L .52464 .78932 L F
.125 0 0 r
.529 .78849 m .52843 .78772 L .5305 .78701 L F
.529 .78849 m .52699 .78893 L .52843 .78772 L F
.566 .325 .51 r
.46882 .73614 m .46885 .73834 L .46651 .73847 L F
.354 .163 .477 r
.47039 .73754 m .46882 .73614 L .47118 .73631 L F
.47039 .73754 m .46885 .73834 L .46882 .73614 L F
.735 .599 .706 r
.72781 .58954 m .7248 .58888 L .72693 .58616 L F
.72781 .58954 m .72593 .59008 L .7248 .58888 L F
.686 .619 .775 r
.73003 .58694 m .72781 .58954 L .72693 .58616 L F
.965 .924 .708 r
.67404 .61478 m .67586 .61281 L .67577 .61392 L F
.566 .584 .83 r
.67586 .61281 m .6781 .61065 L .67577 .61392 L F
.588 .828 .45 r
.65272 .5989 m .65155 .60052 L .65027 .60217 L F
.208 .412 .842 r
.54865 .71144 m .54991 .7117 L .54955 .71033 L F
.374 .047 .275 r
.38823 .69247 m .38553 .69464 L .38624 .69304 L F
.921 .538 .261 r
.3725 .80211 m .37142 .80283 L .37174 .80045 L F
.3725 .80211 m .37317 .80405 L .37142 .80283 L F
.141 .437 .874 r
.37488 .80313 m .3725 .80211 L .37174 .80045 L F
.472 .312 .581 r
.37488 .80313 m .37317 .80405 L .3725 .80211 L F
.808 .985 .888 r
.58891 .66981 m .58822 .67157 L .58957 .67032 L F
.58891 .66981 m .5864 .67186 L .58822 .67157 L F
.585 .47 .688 r
.38504 .76573 m .38722 .76549 L .38685 .76287 L F
.951 .95 .722 r
.54493 .69532 m .5458 .69172 L .54699 .69242 L F
.651 .96 .929 r
.5458 .69172 m .54985 .6903 L .54699 .69242 L F
.292 0 0 r
.52594 .78203 m .52926 .7815 L .52716 .78217 L F
.809 .662 .7 r
.5904 .73273 m .59259 .7335 L .59223 .73057 L F
.759 .51 .556 r
.5905 .73506 m .59259 .7335 L .5904 .73273 L F
.794 .573 .601 r
.5926 .73367 m .59304 .73578 L .5905 .73506 L F
.579 .596 .834 r
.59262 .7336 m .59461 .73346 L .5926 .73367 L F
0 0 0 r
.59257 .73362 m .59507 .73262 L .59259 .7335 L F
.59449 .73306 m .59507 .73262 L .59257 .73362 L F
.579 .596 .834 r
.59501 .73292 m .59461 .73346 L .59454 .73323 L F
.59501 .73292 m .59454 .73323 L .59477 .73298 L F
.59449 .73306 m .59461 .73346 L .59262 .7336 L F
.765 .359 .282 r
.59304 .73578 m .59212 .73582 L .59195 .73547 L F
.59287 .73617 m .59234 .73733 L .59221 .73656 L F
.59287 .73617 m .59188 .73676 L .59237 .73593 L F
.59304 .73578 m .59287 .73617 L .59212 .73582 L F
.6 .467 .672 r
.59461 .73346 m .59304 .73578 L .5926 .73367 L F
.59461 .73346 m .59529 .73549 L .59304 .73578 L F
.773 .526 .561 r
.59529 .73549 m .59234 .73733 L .59304 .73578 L F
.103 0 .396 r
.59234 .73733 m .59398 .73448 L .59216 .73628 L F
.59234 .73733 m .59216 .73628 L .59199 .73645 L F
.783 .28 0 r
.5905 .73506 m .59234 .73733 L .59199 .73645 L F
.765 .359 .282 r
.59221 .73656 m .59234 .73733 L .59188 .73676 L F
0 0 0 r
.59199 .73645 m .59216 .73628 L .59225 .73613 L F
.59199 .73645 m .59226 .73612 L .59212 .73582 L F
.759 .51 .556 r
.5905 .73506 m .59199 .73645 L .59212 .73582 L F
.765 .359 .282 r
.59237 .73593 m .59188 .73676 L .5905 .73506 L F
0 0 0 r
.59225 .73613 m .59398 .73448 L .59499 .73275 L F
.59216 .73628 m .59398 .73448 L .59225 .73613 L F
.59477 .73298 m .59499 .73275 L .59507 .73262 L F
.59199 .73645 m .59499 .73275 L .59477 .73298 L F
.579 .596 .834 r
.59477 .73298 m .59454 .73323 L .59449 .73306 L F
.59607 .73261 m .59486 .73331 L .59501 .73292 L F
.59486 .73331 m .59461 .73346 L .59501 .73292 L F
0 0 .169 r
.59507 .73262 m .59595 .72961 L .59342 .72935 L F
.579 .596 .834 r
.59717 .73197 m .59607 .73261 L .59537 .73175 L F
0 0 .169 r
.59507 .73262 m .59517 .73249 L .59595 .72961 L F
.579 .596 .834 r
.59561 .73088 m .59537 .73175 L .59342 .72935 L F
.59717 .73197 m .59537 .73175 L .59561 .73088 L F
0 0 .169 r
.59517 .73249 m .59561 .73088 L .59595 .72961 L F
.579 .596 .834 r
.59717 .73197 m .59561 .73088 L .59595 .72961 L F
0 0 .169 r
.59561 .73088 m .59594 .72965 L .59595 .72961 L F
.579 .596 .834 r
.59561 .73088 m .59342 .72935 L .59595 .72961 L F
0 0 0 r
.59507 .73262 m .59509 .73269 L .59517 .73249 L F
.59472 .733 m .59507 .73262 L .59449 .73306 L F
.57 .49 .726 r
.59507 .73262 m .59259 .7335 L .59223 .73057 L F
.59507 .73262 m .59223 .73057 L .59342 .72935 L F
.579 .596 .834 r
.59607 .73261 m .59449 .73306 L .59342 .72935 L F
0 0 .169 r
.59517 .73249 m .59586 .73156 L .59594 .72965 L F
.426 .327 .64 r
.59717 .73197 m .59529 .73549 L .59461 .73346 L F
0 0 0 r
.59517 .73249 m .59544 .73371 L .59586 .73156 L F
.59509 .73269 m .59544 .73371 L .59517 .73249 L F
.59472 .733 m .59472 .733 L .59449 .73306 L F
.579 .596 .834 r
.59342 .72935 m .59449 .73306 L .59262 .7336 L F
0 0 0 r
.59212 .73582 m .59472 .733 L .59257 .73362 L F
.59226 .73612 m .59507 .73262 L .59212 .73582 L F
.765 .359 .282 r
.59195 .73547 m .59212 .73582 L .5905 .73506 L F
.759 .51 .556 r
.5905 .73506 m .59212 .73582 L .59259 .7335 L F
0 .084 .642 r
.67938 .60219 m .68066 .60532 L .67974 .60373 L F
.503 .061 .133 r
.41822 .78997 m .41352 .79166 L .4161 .79006 L F
.194 0 0 r
.41984 .78977 m .41822 .78997 L .4161 .79006 L F
.849 .977 .87 r
.5679 .69101 m .56708 .69281 L .56928 .69194 L F
.5679 .69101 m .56644 .69226 L .56708 .69281 L F
.568 .131 .169 r
.44621 .72654 m .44836 .72695 L .44969 .72534 L F
.546 .106 .155 r
.44969 .72534 m .44836 .72695 L .45185 .72637 L F
.541 .369 .597 r
.30698 .70617 m .30703 .70876 L .30492 .70922 L F
.13 0 0 r
.43232 .78694 m .43154 .78724 L .42939 .78749 L F
0 0 0 r
.43357 .78665 m .43232 .78694 L .43485 .78646 L F
.43357 .78665 m .43154 .78724 L .43232 .78694 L F
.67 .173 .058 r
.68836 .70632 m .69077 .70796 L .69192 .7073 L F
.588 .068 0 r
.69077 .70796 m .69406 .7083 L .69192 .7073 L F
.345 .072 .349 r
.55408 .69789 m .5516 .70065 L .55042 .69756 L F
.55408 .69789 m .55375 .70037 L .5516 .70065 L F
.599 .285 .409 r
.55598 .69983 m .55408 .69789 L .55598 .69749 L F
.255 .259 .671 r
.55408 .69789 m .55556 .70062 L .55598 .69983 L F
.599 .285 .409 r
.55598 .69983 m .55375 .70037 L .55408 .69789 L F
.255 .259 .671 r
.55408 .69789 m .55598 .69983 L .55598 .69749 L F
.317 .082 .391 r
.39214 .68888 m .39108 .68759 L .39265 .68691 L F
.39214 .68888 m .39049 .68957 L .39108 .68759 L F
0 0 0 r
.63874 .65969 m .63784 .66149 L .63665 .6627 L F
.774 .989 .754 r
.64105 .65723 m .63947 .65816 L .63874 .65969 L F
.645 .78 .319 r
.63874 .65969 m .63947 .65816 L .63784 .66149 L F
.244 0 .276 r
.72166 .72986 m .72359 .72993 L .7241 .72748 L F
.918 .975 .772 r
.72264 .73277 m .72359 .72993 L .72166 .72986 L F
.742 .663 .772 r
.58036 .68925 m .58038 .69215 L .58284 .68968 L F
.57921 .68905 m .57959 .69006 L .58036 .68925 L F
.57959 .69006 m .58038 .69215 L .58036 .68925 L F
.511 .881 .977 r
.58028 .68945 m .58077 .68881 L .58254 .68707 L F
.58077 .68881 m .58095 .68858 L .58138 .68817 L F
.58077 .68881 m .58138 .68817 L .58254 .68707 L F
.58028 .68945 m .57921 .68905 L .58095 .68858 L F
.442 .743 .992 r
.55598 .69749 m .56003 .6988 L .55832 .69725 L F
.957 .835 .681 r
.55832 .69725 m .56003 .6988 L .55598 .69749 L F
.55832 .69725 m .55954 .69958 L .56003 .6988 L F
.809 .874 .894 r
.55832 .69725 m .56003 .6988 L .56115 .69664 L F
.904 .786 .72 r
.64192 .6483 m .64096 .64596 L .64013 .64822 L F
.904 .788 .722 r
.64039 .65181 m .64192 .6483 L .64013 .64822 L F
.86 .773 .765 r
.64192 .6483 m .64348 .64494 L .64096 .64596 L F
.601 .501 .712 r
.41566 .76564 m .41608 .76787 L .41384 .76815 L F
.72 .695 .825 r
.69825 .60691 m .6949 .60642 L .69721 .60555 L F
.685 .776 .92 r
.70043 .60594 m .69825 .60691 L .69721 .60555 L F
.067 0 0 r
.35956 .71682 m .3567 .71874 L .35779 .71758 L F
.631 .182 .167 r
.48129 .77574 m .48218 .77394 L .4805 .77378 L F
.64 .192 .171 r
.48465 .77579 m .48218 .77394 L .48129 .77574 L F
.645 .253 .286 r
.48344 .77576 m .48374 .77572 L .48465 .77579 L F
.665 .121 0 r
.48548 .77584 m .48218 .77394 L .48465 .77579 L F
.645 .253 .286 r
.48374 .77572 m .48681 .77525 L .48465 .77579 L F
.665 .121 0 r
.48597 .77613 m .48548 .77584 L .48465 .77579 L F
.089 0 0 r
.42939 .78749 m .42721 .78881 L .42558 .78914 L F
.383 .84 .77 r
.43154 .78724 m .42721 .78881 L .42939 .78749 L F
.635 .452 .617 r
.59307 .72466 m .59008 .72273 L .59246 .72179 L F
.507 .262 .477 r
.56052 .70327 m .56272 .70286 L .56251 .70092 L F
.484 .753 .989 r
.56386 .69927 m .56251 .70092 L .56266 .69989 L F
0 0 .036 r
.56376 .7015 m .56251 .70092 L .56272 .70286 L F
.56376 .7015 m .56386 .69927 L .56251 .70092 L F
.249 .084 .452 r
.56251 .70092 m .56272 .70286 L .56376 .7015 L F
.234 .385 .811 r
.58653 .74659 m .58891 .7484 L .58789 .74951 L F
.27 0 0 r
.59044 .75 m .59045 .74991 L .58789 .74951 L F
.398 .642 .955 r
.58891 .7484 m .59044 .75 L .58789 .74951 L F
.572 .695 .925 r
.31603 .71148 m .31396 .71192 L .31249 .71037 L F
.867 .697 .668 r
.57364 .72414 m .57641 .72254 L .57374 .72193 L F
.57364 .72414 m .57619 .72565 L .57641 .72254 L F
.286 .429 .831 r
.53146 .71918 m .53047 .72057 L .5297 .71899 L F
.53146 .71918 m .53279 .72202 L .53047 .72057 L F
.669 .462 .595 r
.59119 .75228 m .59127 .75473 L .58897 .75424 L F
0 0 .508 r
.59114 .75198 m .59119 .75228 L .59045 .74991 L F
.607 .443 .634 r
.59114 .75198 m .59127 .75473 L .59119 .75228 L F
.762 .297 .145 r
.65634 .60843 m .655 .60936 L .6546 .60782 L F
.65634 .60843 m .65838 .61091 L .655 .60936 L F
.676 .229 .181 r
.57248 .69757 m .57631 .69792 L .57421 .70032 L F
.805 .655 .696 r
.59223 .73057 m .5926 .73367 L .5904 .73273 L F
.794 .573 .601 r
.5926 .73367 m .5905 .73506 L .5904 .73273 L F
.579 .596 .834 r
.59342 .72935 m .5926 .73367 L .59223 .73057 L F
.515 .363 .613 r
.38841 .7549 m .39036 .75448 L .39028 .75202 L F
.551 .416 .65 r
.38853 .75793 m .39036 .75448 L .38841 .7549 L F
.501 .296 .534 r
.62539 .62443 m .628 .62393 L .6277 .62204 L F
.518 .335 .572 r
.62539 .62443 m .62767 .62647 L .628 .62393 L F
.62539 .62443 m .6255 .62715 L .62767 .62647 L F
.941 .738 .6 r
.64348 .64494 m .64269 .6432 L .64096 .64596 L F
.356 .708 .985 r
.36932 .65099 m .36866 .65195 L .36732 .65092 L F
.36932 .65099 m .3707 .65199 L .36866 .65195 L F
.574 .472 .701 r
.38527 .77937 m .3869 .77646 L .38461 .77704 L F
.38527 .77937 m .3875 .77914 L .3869 .77646 L F
.472 .331 .608 r
.38527 .77937 m .38716 .78149 L .3875 .77914 L F
.38527 .77937 m .38554 .78231 L .38716 .78149 L F
.368 0 0 r
.53671 .72321 m .53857 .72349 L .53953 .72294 L F
.282 0 0 r
.53857 .72349 m .54221 .72379 L .53953 .72294 L F
.53968 .72358 m .54064 .72386 L .54221 .72379 L F
.53857 .72349 m .54064 .72386 L .53968 .72358 L F
.077 .403 .858 r
.54131 .72328 m .54227 .72432 L .54064 .72386 L F
.518 0 0 r
.54064 .72386 m .54307 .72518 L .54381 .72498 L F
.077 .403 .858 r
.54227 .72432 m .54307 .72518 L .54064 .72386 L F
.45 .601 .909 r
.53856 .72161 m .54058 .72379 L .53857 .72349 L F
.54058 .72379 m .54064 .72386 L .53857 .72349 L F
.368 0 0 r
.53644 .72324 m .53857 .72349 L .53671 .72321 L F
.609 .395 .566 r
.60387 .69522 m .60636 .69505 L .60631 .69266 L F
.515 .293 .516 r
.60636 .69505 m .60844 .69208 L .60631 .69266 L F
.004 0 0 r
.48961 .7291 m .48631 .72959 L .48731 .72978 L F
.895 .718 .655 r
.64574 .62044 m .64744 .61952 L .64602 .61849 L F
.64574 .62044 m .64722 .62175 L .64744 .61952 L F
.515 .758 .984 r
.51478 .70815 m .51397 .70979 L .51265 .70835 L F
.51478 .70815 m .51638 .70953 L .51397 .70979 L F
.723 .687 .815 r
.68919 .60762 m .68707 .60855 L .68595 .60562 L F
.576 .367 .561 r
.57952 .7253 m .5822 .7251 L .58191 .72244 L F
.617 .193 .215 r
.57846 .70249 m .57612 .70263 L .57717 .70073 L F
.063 .338 .815 r
.58191 .72244 m .58327 .72219 L .58041 .7202 L F
.636 .411 .559 r
.58191 .72244 m .584 .72409 L .58327 .72219 L F
.58191 .72244 m .5822 .7251 L .584 .72409 L F
.226 .319 .751 r
.307 .73822 m .30442 .73569 L .30537 .7374 L F
.719 .432 .491 r
.58568 .75227 m .58236 .75428 L .58245 .75169 L F
.58568 .75227 m .58606 .75445 L .58236 .75428 L F
.754 .456 .48 r
.58897 .75424 m .58606 .75445 L .58568 .75227 L F
.472 .515 .82 r
.55302 .71978 m .55373 .71637 L .55164 .71703 L F
.55302 .71978 m .55485 .71936 L .55373 .71637 L F
.452 .405 .716 r
.55302 .71978 m .55533 .7214 L .55485 .71936 L F
.41 .219 .508 r
.59406 .71421 m .59403 .71645 L .59215 .71695 L F
.478 .342 .618 r
.59403 .71645 m .59225 .71923 L .59215 .71695 L F
.499 .658 .931 r
.30886 .74064 m .30952 .73822 L .3072 .73824 L F
.30886 .74064 m .31132 .74046 L .30952 .73822 L F
.622 .614 .822 r
.636 .60817 m .63848 .60767 L .63835 .60869 L F
.631 .934 .691 r
.64015 .60695 m .63835 .60869 L .63848 .60767 L F
.615 .556 .765 r
.63933 .61108 m .63848 .60767 L .636 .60817 L F
.468 .259 .512 r
.31029 .69516 m .31005 .69811 L .30793 .69815 L F
.503 .393 .662 r
.31013 .69999 m .30793 .69815 L .31005 .69811 L F
.31013 .69999 m .30831 .70035 L .30793 .69815 L F
.228 0 .027 r
.31169 .66477 m .31326 .66468 L .3146 .66295 L F
.386 .017 .21 r
.31326 .66468 m .31642 .6623 L .3146 .66295 L F
.524 .537 .812 r
.42038 .77562 m .41827 .77584 L .41722 .77307 L F
.391 .15 .425 r
.61564 .69772 m .61474 .70033 L .61344 .70046 L F
.045 0 .16 r
.6178 .69491 m .61756 .69687 L .61564 .69772 L F
.147 0 .399 r
.61564 .69772 m .61725 .69912 L .61474 .70033 L F
.61564 .69772 m .61756 .69687 L .61725 .69912 L F
.63 .091 0 r
.37008 .67118 m .36856 .67151 L .36671 .67019 L F
.443 0 0 r
.37213 .67044 m .36856 .67151 L .37008 .67118 L F
.382 .246 .568 r
.29286 .6299 m .29293 .63229 L .29139 .63301 L F
.412 .233 .526 r
.29293 .63229 m .29102 .63518 L .29139 .63301 L F
.451 .263 .534 r
.29682 .62193 m .29667 .6243 L .29483 .62476 L F
.499 .332 .586 r
.29667 .6243 m .29473 .62705 L .29483 .62476 L F
.38 .085 .334 r
.59375 .64873 m .59574 .64853 L .59634 .64639 L F
.462 .203 .435 r
.59574 .64853 m .59843 .64562 L .59634 .64639 L F
.506 .799 .998 r
.49764 .74575 m .49678 .74712 L .49533 .74629 L F
.49764 .74575 m .49918 .74671 L .49678 .74712 L F
.49764 .74575 m .49678 .74712 L .49533 .74629 L F
.49764 .74575 m .49918 .74671 L .49678 .74712 L F
.835 .468 0 r
.57666 .6862 m .57728 .68722 L .57585 .68402 L F
.849 .631 .607 r
.57437 .68878 m .57728 .68722 L .57666 .6862 L F
.823 .69 .717 r
.5723 .68821 m .57437 .68878 L .57666 .6862 L F
.693 .524 .654 r
.5723 .68821 m .57247 .68823 L .57437 .68878 L F
.849 .631 .607 r
.57437 .68878 m .57609 .68927 L .57728 .68722 L F
.693 .524 .654 r
.57247 .68823 m .57651 .68859 L .57437 .68878 L F
.849 .631 .607 r
.57437 .68878 m .57505 .69106 L .57609 .68927 L F
0 0 0 r
.59044 .75 m .59248 .74894 L .59045 .74991 L F
0 .463 .854 r
.68687 .59491 m .68338 .59312 L .68563 .59284 L F
.382 0 .116 r
.68372 .59696 m .68687 .59491 L .68601 .59669 L F
.616 .561 .77 r
.68368 .59304 m .68563 .59284 L .68338 .59312 L F
.597 .704 .918 r
.68338 .59312 m .68563 .59284 L .68368 .59304 L F
.616 .561 .77 r
.68368 .59304 m .68608 .59324 L .68563 .59284 L F
.68608 .59324 m .68657 .59328 L .68563 .59284 L F
.585 .633 .865 r
.68523 .59262 m .68586 .59293 L .68368 .59304 L F
.68586 .59293 m .68657 .59328 L .68608 .59324 L F
.26 .47 .874 r
.68586 .59293 m .68608 .59324 L .68563 .59284 L F
.585 .633 .865 r
.68586 .59293 m .68608 .59324 L .68368 .59304 L F
.26 .47 .874 r
.68816 .59385 m .68743 .59445 L .68608 .59324 L F
0 .406 .798 r
.68563 .59284 m .68657 .59328 L .68816 .59385 L F
0 .405 .797 r
.68816 .59385 m .68657 .59328 L .68586 .59293 L F
.26 .47 .874 r
.68816 .59385 m .68586 .59293 L .68586 .59293 L F
0 .405 .797 r
.68816 .59385 m .68586 .59293 L .68523 .59262 L F
.26 .47 .874 r
.68816 .59385 m .68608 .59324 L .68586 .59293 L F
.68743 .59445 m .68687 .59491 L .68563 .59284 L F
0 0 0 r
.68601 .59669 m .68687 .59491 L .68816 .59385 L F
.529 .386 .631 r
.30865 .70354 m .30892 .70587 L .30698 .70617 L F
.612 .468 .661 r
.30892 .70587 m .30703 .70876 L .30698 .70617 L F
.346 .506 .873 r
.49919 .77844 m .49818 .77984 L .49705 .77914 L F
.49919 .77844 m .50129 .78069 L .49818 .77984 L F
.195 0 .291 r
.62855 .67888 m .62839 .68092 L .62649 .68143 L F
.18 0 .249 r
.62839 .68092 m .62614 .68361 L .62649 .68143 L F
.835 .815 .331 r
.63665 .6627 m .63597 .66432 L .63599 .66504 L F
0 0 0 r
.63665 .6627 m .63784 .66149 L .63597 .66432 L F
.597 .401 .587 r
.59637 .71392 m .59406 .71421 L .59634 .71154 L F
.604 .401 .58 r
.59869 .71118 m .59637 .71392 L .59634 .71154 L F
.452 .02 .127 r
.53629 .78513 m .535 .78691 L .53271 .78697 L F
.44 .056 .213 r
.5383 .78454 m .535 .78691 L .53629 .78513 L F
.253 0 .047 r
.71276 .72221 m .70911 .72448 L .70873 .72268 L F
.316 .031 .312 r
.42637 .7492 m .42397 .75167 L .42354 .7497 L F
0 0 0 r
.73146 .6185 m .73354 .61628 L .73304 .61567 L F
.875 .787 .76 r
.7361 .61384 m .73304 .61567 L .73354 .61628 L F
.543 .322 .529 r
.31224 .69755 m .31029 .69516 L .31243 .69497 L F
.31224 .69755 m .31005 .69811 L .31029 .69516 L F
.982 .887 .653 r
.67385 .59065 m .67543 .58982 L .67527 .58806 L F
.67385 .59065 m .67464 .59191 L .67543 .58982 L F
.422 .225 .506 r
.38128 .69787 m .38107 .70016 L .37924 .70069 L F
.412 .192 .466 r
.38107 .70016 m .37887 .70281 L .37924 .70069 L F
.324 .771 .959 r
.36192 .6496 m .36393 .64941 L .3647 .64984 L F
.1 .481 .897 r
.36603 .64957 m .3647 .64984 L .36393 .64941 L F
.36603 .64957 m .36732 .65092 L .3647 .64984 L F
.368 .729 .989 r
.28757 .6004 m .28691 .60136 L .28537 .60059 L F
.28757 .6004 m .28909 .60129 L .28691 .60136 L F
.432 .194 .451 r
.39983 .67889 m .39944 .68085 L .39758 .68137 L F
.409 .181 .454 r
.40179 .67825 m .39944 .68085 L .39983 .67889 L F
.607 .419 .6 r
.64578 .6004 m .64585 .60266 L .64829 .60021 L F
.446 .103 .29 r
.32492 .68699 m .32174 .68912 L .32255 .6872 L F
.951 .95 .722 r
.54493 .69532 m .54421 .69483 L .5458 .69172 L F
.964 .927 .708 r
.54498 .69534 m .54421 .69483 L .54493 .69532 L F
.451 .188 .424 r
.39944 .68085 m .39707 .68386 L .39758 .68137 L F
.712 .558 .678 r
.58617 .70096 m .5861 .70332 L .58833 .70068 L F
.638 .452 .615 r
.5861 .70332 m .58847 .70325 L .58833 .70068 L F
.585 .362 .543 r
.58847 .70325 m .59101 .70066 L .58833 .70068 L F
0 0 0 r
.4853 .72009 m .48543 .72007 L .48736 .71942 L F
.4853 .72009 m .48377 .72112 L .48543 .72007 L F
.856 .846 .833 r
.57703 .74899 m .5777 .74654 L .57905 .74773 L F
.687 .224 .148 r
.5777 .74654 m .58121 .74707 L .57905 .74773 L F
.76 .686 .781 r
.69168 .6189 m .69497 .61927 L .69395 .61616 L F
.768 .691 .777 r
.69395 .61616 m .69497 .61927 L .69721 .61658 L F
.658 .237 .232 r
.47701 .77353 m .47905 .77527 L .4805 .77378 L F
.631 .182 .167 r
.48129 .77574 m .4805 .77378 L .47905 .77527 L F
.616 .559 .768 r
.52731 .73068 m .52853 .72747 L .52639 .72765 L F
.52731 .73068 m .52932 .73044 L .52853 .72747 L F
.606 .478 .679 r
.52731 .73068 m .52759 .73328 L .52932 .73044 L F
.065 0 0 r
.42783 .77645 m .42692 .77634 L .42571 .77635 L F
.42783 .77645 m .42915 .7763 L .42692 .77634 L F
0 0 0 r
.59379 .72754 m .59312 .72944 L .59223 .73057 L F
.197 .406 .841 r
.59223 .73057 m .59312 .72944 L .59074 .72801 L F
.264 0 .243 r
.30162 .67296 m .30416 .67043 L .30206 .67077 L F
.362 0 .016 r
.60435 .65711 m .60329 .65859 L .601 .65881 L F
.623 .255 .324 r
.60657 .65692 m .60329 .65859 L .60435 .65711 L F
.73 .783 .895 r
.31945 .7116 m .31603 .71148 L .31797 .71032 L F
.679 .774 .922 r
.32158 .71078 m .31945 .7116 L .31797 .71032 L F
.575 .336 .517 r
.60149 .70857 m .59869 .71118 L .59876 .7086 L F
.60149 .70857 m .60148 .71073 L .59869 .71118 L F
.587 .434 .641 r
.60389 .7061 m .60384 .70837 L .60149 .70857 L F
.546 .313 .514 r
.60373 .71022 m .60149 .70857 L .60384 .70837 L F
.60373 .71022 m .60148 .71073 L .60149 .70857 L F
.198 0 0 r
.71014 .71464 m .7122 .71404 L .71287 .71331 L F
.367 0 .003 r
.7122 .71404 m .71506 .71325 L .71287 .71331 L F
.481 0 0 r
.65791 .59574 m .6558 .59483 L .65493 .59538 L F
.859 .617 .572 r
.5755 .71587 m .57704 .71417 L .57647 .71383 L F
.5755 .71587 m .57738 .71668 L .57704 .71417 L F
.991 .79 .409 r
.57671 .71136 m .57647 .71383 L .57704 .71417 L F
.503 .365 .626 r
.57704 .71417 m .57927 .71603 L .57925 .71379 L F
.57704 .71417 m .57738 .71668 L .57927 .71603 L F
.835 .715 .732 r
.64474 .63772 m .6441 .63523 L .64341 .63737 L F
.941 .874 .743 r
.64321 .64096 m .64474 .63772 L .64341 .63737 L F
.828 .66 .674 r
.65021 .61605 m .6507 .6164 L .64822 .61588 L F
.645 .439 .59 r
.412 .65709 m .40973 .65775 L .40916 .65727 L F
0 .088 .611 r
.40916 .65727 m .41064 .65872 L .412 .65709 L F
.023 0 .029 r
.57736 .71718 m .57927 .71603 L .57738 .71668 L F
.735 .929 .954 r
.70302 .58694 m .70191 .58921 L .7015 .58848 L F
.70302 .58694 m .70509 .58734 L .70191 .58921 L F
.506 .821 1 r
.55084 .7356 m .55004 .73598 L .54775 .7356 L F
.773 .533 .571 r
.55004 .73598 m .54761 .73805 L .54775 .7356 L F
.55004 .73598 m .55098 .73837 L .54761 .73805 L F
.501 .849 .994 r
.55225 .73495 m .55004 .73598 L .55084 .7356 L F
.048 0 .45 r
.55225 .73495 m .55098 .73837 L .55004 .73598 L F
.324 .486 .866 r
.2996 .60442 m .29909 .60652 L .29818 .60434 L F
.325 .487 .866 r
.3009 .60686 m .29909 .60652 L .2996 .60442 L F
.793 .881 .91 r
.34528 .64938 m .34177 .65011 L .34382 .64946 L F
.34528 .64938 m .34279 .65071 L .34177 .65011 L F
.407 .859 .868 r
.34528 .64938 m .34382 .64946 L .3451 .6489 L F
.808 .995 .866 r
.56382 .67677 m .5619 .67738 L .56285 .67608 L F
.873 .986 .831 r
.56422 .67487 m .56382 .67677 L .56285 .67608 L F
.56422 .67487 m .56477 .67547 L .56382 .67677 L F
.678 .665 .831 r
.48203 .73257 m .48544 .73334 L .48434 .73092 L F
.68 .735 .892 r
.70382 .60648 m .70043 .60594 L .70264 .60509 L F
.724 .733 .858 r
.70595 .60553 m .70382 .60648 L .70264 .60509 L F
.673 .953 .951 r
.50016 .713 m .50177 .71124 L .50306 .71186 L F
.50016 .713 m .49909 .71265 L .50177 .71124 L F
.27 .429 .836 r
.40573 .79423 m .4039 .79363 L .40502 .79293 L F
.8 .476 .44 r
.69875 .71417 m .69562 .71404 L .69517 .7119 L F
.77 .836 .903 r
.69875 .71417 m .69661 .71491 L .69562 .71404 L F
.508 .526 .81 r
.69895 .7166 m .69661 .71491 L .69875 .71417 L F
.528 .364 .602 r
.70083 .71134 m .70114 .71374 L .69875 .71417 L F
.498 .324 .576 r
.70114 .71374 m .69895 .7166 L .69875 .71417 L F
.835 .821 .836 r
.69243 .58528 m .69345 .58665 L .696 .58432 L F
.69243 .58528 m .696 .58432 L .69481 .58464 L F
.502 .061 .134 r
.69781 .58325 m .69481 .58464 L .696 .58432 L F
.552 .467 .712 r
.38616 .77103 m .38823 .77072 L .38769 .76831 L F
.613 .495 .694 r
.38616 .77103 m .38888 .77379 L .38823 .77072 L F
.38616 .77103 m .38676 .77424 L .38888 .77379 L F
.433 .368 .684 r
.30704 .60754 m .30496 .60807 L .30482 .60557 L F
.406 .248 .551 r
.30704 .60754 m .30511 .60926 L .30496 .60807 L F
.497 .315 .564 r
.29247 .68135 m .29456 .67851 L .2925 .67897 L F
0 0 0 r
.34642 .67548 m .34559 .67552 L .34755 .67521 L F
.34642 .67548 m .34453 .6761 L .34559 .67552 L F
.91 .774 .699 r
.64473 .63039 m .64467 .62628 L .64291 .62957 L F
.877 .675 .626 r
.64445 .63288 m .64473 .63039 L .64291 .62957 L F
.712 .53 .641 r
.63452 .61636 m .6346 .61393 L .63156 .61382 L F
.5 .199 .387 r
.6364 .61553 m .6346 .61393 L .63452 .61636 L F
.6364 .61553 m .63689 .61323 L .6346 .61393 L F
.272 .746 .937 r
.34423 .82792 m .3477 .82819 L .34649 .82779 L F
.34423 .82792 m .3477 .82819 L .34649 .82779 L F
.449 .627 .929 r
.38179 .6553 m .38096 .65689 L .37987 .65535 L F
.38179 .6553 m .38301 .65696 L .38096 .65689 L F
.271 .737 .946 r
.47131 .77272 m .46848 .77228 L .47031 .77149 L F
.593 .643 .869 r
.47238 .77044 m .47131 .77272 L .47 .77111 L F
.29 0 .114 r
.46902 .77238 m .47133 .77231 L .47227 .77064 L F
.47134 .77104 m .47227 .77064 L .47238 .77044 L F
.46902 .77238 m .47227 .77064 L .47134 .77104 L F
.271 .737 .946 r
.47031 .77149 m .46738 .77211 L .47 .77111 L F
.46848 .77228 m .46738 .77211 L .47031 .77149 L F
.593 .643 .869 r
.47238 .77044 m .47356 .77246 L .47131 .77272 L F
.757 .481 .514 r
.38401 .801 m .38676 .80349 L .38557 .80446 L F
.659 .761 .925 r
.38388 .80336 m .38557 .80446 L .38676 .80349 L F
0 0 0 r
.61493 .67905 m .61612 .67785 L .61678 .6761 L F
0 0 .087 r
.61553 .67986 m .61493 .67905 L .61448 .6811 L F
.61553 .67986 m .61612 .67785 L .61493 .67905 L F
.498 .241 .455 r
.61344 .70046 m .61311 .7025 L .61137 .70275 L F
.313 .058 .358 r
.61474 .70033 m .61311 .7025 L .61344 .70046 L F
.478 .11 .262 r
.41408 .73538 m .41632 .73515 L .41741 .73308 L F
.428 .06 .236 r
.41741 .73308 m .4185 .73475 L .4197 .73296 L F
.41741 .73308 m .41632 .73515 L .4185 .73475 L F
.496 .284 .52 r
.41073 .65974 m .40896 .66214 L .40988 .65997 L F
.513 .468 .744 r
.41064 .65872 m .40896 .66214 L .40988 .65997 L F
.314 .104 .427 r
.412 .65709 m .41073 .65974 L .40988 .65997 L F
.224 0 0 r
.44238 .77588 m .44678 .77432 L .4432 .7755 L F
.44238 .77588 m .44457 .77561 L .44678 .77432 L F
.601 .931 .722 r
.44678 .77432 m .44741 .77339 L .44812 .7736 L F
.44678 .77432 m .44457 .77561 L .44741 .77339 L F
.627 .663 .865 r
.38713 .78996 m .39031 .79025 L .38851 .7876 L F
.505 .509 .794 r
.38713 .78996 m .38996 .79242 L .39031 .79025 L F
.516 .29 .509 r
.40412 .6756 m .40179 .67825 L .40211 .67609 L F
.274 .778 .851 r
.42035 .78956 m .41984 .78977 L .42157 .78966 L F
.42035 .78956 m .41822 .78997 L .41984 .78977 L F
0 .131 .647 r
.30535 .60564 m .30482 .60557 L .30332 .60587 L F
.30535 .60564 m .30704 .60754 L .30482 .60557 L F
0 .201 .697 r
.72968 .62194 m .73128 .62299 L .72905 .62216 L F
0 .446 .861 r
.73074 .62266 m .72905 .62216 L .73128 .62299 L F
.629 .929 .971 r
.72787 .62181 m .7293 .6215 L .72905 .62216 L F
0 .201 .697 r
.72968 .62194 m .72905 .62216 L .7293 .6215 L F
0 .446 .861 r
.72786 .62094 m .72905 .62216 L .73074 .62266 L F
.629 .929 .971 r
.72623 .62217 m .72787 .62181 L .72905 .62216 L F
.614 .713 .916 r
.68893 .58209 m .68647 .58292 L .68777 .58021 L F
.599 .068 0 r
.50374 .78171 m .50834 .78384 L .50708 .78223 L F
.626 .097 0 r
.50708 .78223 m .50834 .78384 L .50793 .78351 L F
.50708 .78223 m .50793 .78351 L .5092 .78429 L F
.382 .122 .39 r
.61467 .64098 m .61667 .64017 L .61684 .63778 L F
0 0 .151 r
.61684 .63778 m .61746 .63889 L .61797 .63565 L F
.61684 .63778 m .61667 .64017 L .61746 .63889 L F
.703 .541 .665 r
.60611 .70348 m .60621 .70598 L .60389 .7061 L F
.607 .42 .603 r
.60841 .70327 m .60621 .70598 L .60611 .70348 L F
.723 .687 .815 r
.68919 .60762 m .68595 .60562 L .68824 .60486 L F
.694 .731 .878 r
.69047 .60425 m .68919 .60762 L .68824 .60486 L F
.69047 .60425 m .69178 .60584 L .68919 .60762 L F
.964 .927 .708 r
.54498 .69534 m .54336 .69641 L .54421 .69483 L F
.969 .907 .698 r
.54498 .69534 m .54215 .69938 L .54336 .69641 L F
.54498 .69534 m .54285 .70029 L .54215 .69938 L F
.482 .109 .255 r
.61175 .64246 m .61387 .64233 L .61206 .64115 L F
.491 .101 .229 r
.61387 .64233 m .61467 .64098 L .61206 .64115 L F
.693 .467 .576 r
.6121 .65453 m .61212 .65686 L .60967 .65697 L F
.481 .763 .993 r
.56094 .73046 m .563 .73019 L .56219 .72915 L F
.701 .883 .965 r
.50858 .70988 m .50472 .71038 L .50717 .70888 L F
.651 .841 .973 r
.51058 .709 m .50858 .70988 L .50717 .70888 L F
.197 .726 .818 r
.32955 .7327 m .32843 .73268 L .32625 .73297 L F
.39 .847 .891 r
.33034 .73209 m .32955 .7327 L .33175 .73188 L F
.33034 .73209 m .32843 .73268 L .32955 .7327 L F
.759 .651 .742 r
.69169 .71122 m .69377 .71379 L .69517 .7119 L F
0 0 0 r
.69517 .7119 m .69566 .71127 L .69732 .70868 L F
.897 .561 .075 r
.69517 .7119 m .69682 .7126 L .69566 .71127 L F
.69517 .7119 m .69562 .71404 L .6951 .71391 L F
.69517 .7119 m .6951 .71391 L .69682 .7126 L F
.353 .745 .986 r
.69169 .71122 m .69566 .71127 L .69517 .7119 L F
.42 .378 .706 r
.55375 .70037 m .55388 .70226 L .5516 .70065 L F
.819 .804 .838 r
.72693 .58616 m .7248 .58888 L .72384 .58616 L F
.267 0 0 r
.46307 .73833 m .45975 .74032 L .46095 .73855 L F
.318 .065 .364 r
.60844 .69208 m .61076 .69147 L .61041 .68935 L F
.184 .004 .388 r
.61041 .68935 m .61243 .68859 L .61281 .68641 L F
.172 0 .358 r
.61041 .68935 m .61076 .69147 L .61243 .68859 L F
.437 0 0 r
.69455 .57443 m .69328 .5734 L .69245 .57462 L F
.69455 .57443 m .69606 .57425 L .69328 .5734 L F
.54 .125 .203 r
.69606 .57425 m .69536 .57349 L .69328 .5734 L F
.774 .989 .754 r
.64105 .65723 m .64056 .65714 L .63947 .65816 L F
.217 .33 .765 r
.64001 .65409 m .64223 .65598 L .64105 .65723 L F
.602 .951 .825 r
.64105 .65723 m .64223 .65598 L .64056 .65714 L F
.874 .839 .807 r
.68243 .62717 m .68485 .62675 L .6844 .62426 L F
.828 .813 .836 r
.6844 .62426 m .68485 .62675 L .68716 .62424 L F
.774 .634 .706 r
.33235 .84505 m .32989 .84389 L .33131 .84503 L F
.753 .65 .747 r
.69169 .71122 m .68987 .71381 L .69377 .71379 L F
.102 0 0 r
.69029 .71585 m .69377 .71379 L .68987 .71381 L F
.69029 .71585 m .69245 .71515 L .69377 .71379 L F
.507 .646 .919 r
.69661 .71491 m .69377 .71379 L .69562 .71404 L F
.607 .443 .634 r
.59114 .75198 m .59367 .75481 L .59127 .75473 L F
.674 .53 .681 r
.59493 .74779 m .59646 .75181 L .59114 .75198 L F
.521 .256 .453 r
.59646 .75181 m .59367 .75481 L .59114 .75198 L F
.231 0 .303 r
.628 .62393 m .62999 .62161 L .6277 .62204 L F
.426 .205 .474 r
.29902 .6191 m .2987 .62149 L .29682 .62193 L F
.402 .187 .469 r
.30126 .6161 m .30076 .61858 L .29902 .6191 L F
.468 .264 .52 r
.30076 .61858 m .2987 .62149 L .29902 .6191 L F
.541 .423 .667 r
.68681 .58605 m .68492 .58682 L .68455 .58408 L F
0 0 .148 r
.68479 .58542 m .68492 .58682 L .68455 .58408 L F
.536 .225 .387 r
.45319 .74114 m .45225 .74358 L .44995 .74364 L F
.488 .148 .317 r
.45539 .7411 m .45225 .74358 L .45319 .74114 L F
.112 0 0 r
.4574 .72564 m .45953 .72586 L .46081 .72588 L F
.428 0 0 r
.45953 .72586 m .46281 .72633 L .46081 .72588 L F
.891 .613 .508 r
.58085 .68632 m .58095 .68858 L .58254 .68707 L F
.58085 .68632 m .58095 .68858 L .58254 .68707 L F
.894 .617 .511 r
.58095 .68858 m .58284 .68968 L .58254 .68707 L F
.448 .175 .406 r
.59115 .65164 m .5935 .65124 L .59375 .64873 L F
.416 .149 .398 r
.59375 .64873 m .59561 .65058 L .59574 .64853 L F
.59375 .64873 m .5935 .65124 L .59561 .65058 L F
.071 .353 .825 r
.55976 .7256 m .55985 .7251 L .55798 .72492 L F
.782 .881 .918 r
.5233 .72831 m .52639 .72765 L .52521 .72733 L F
.232 .735 .9 r
.52853 .72747 m .52521 .72733 L .52639 .72765 L F
.37 .398 .759 r
.69128 .719 m .69209 .72222 L .69369 .72231 L F
.378 .36 .712 r
.69209 .72222 m .69446 .72429 L .69369 .72231 L F
.603 .799 .975 r
.72075 .62256 m .72428 .62314 L .7231 .62179 L F
.677 .816 .949 r
.7231 .62179 m .72428 .62314 L .72623 .62217 L F
.406 .615 .935 r
.66481 .6112 m .66709 .61154 L .66607 .60987 L F
.494 .102 .226 r
.34945 .64856 m .35156 .6484 L .35328 .64625 L F
.649 .284 .337 r
.35328 .64625 m .35489 .64816 L .35502 .6458 L F
.471 .29 .553 r
.2987 .62149 m .29667 .6243 L .29682 .62193 L F
.277 0 .11 r
.35556 .72073 m .35481 .71932 L .3567 .71874 L F
.35556 .72073 m .35364 .72134 L .35481 .71932 L F
.446 .22 .475 r
.38357 .69516 m .38322 .69739 L .38128 .69787 L F
.469 .246 .492 r
.38553 .69464 m .38322 .69739 L .38357 .69516 L F
.262 .767 .865 r
.33598 .6505 m .33811 .65016 L .33981 .65026 L F
0 0 .086 r
.61973 .69176 m .61923 .69394 L .6178 .69491 L F
0 0 .117 r
.6178 .69491 m .61923 .69394 L .61756 .69687 L F
.421 .805 .99 r
.27631 .59956 m .27728 .60023 L .27522 .60023 L F
.27631 .59956 m .27783 .60015 L .27728 .60023 L F
.569 .211 .322 r
.43273 .72928 m .43492 .72938 L .43307 .72789 L F
.566 .213 .329 r
.43307 .72789 m .43492 .72938 L .43542 .72794 L F
.421 .805 .99 r
.27631 .59956 m .27522 .60023 L .27431 .59986 L F
0 0 0 r
.57756 .66508 m .57886 .66413 L .58004 .66267 L F
.458 .867 .711 r
.57756 .66508 m .57699 .66527 L .57886 .66413 L F
.618 .392 .552 r
.41956 .75236 m .41563 .75402 L .41677 .75277 L F
.536 .576 .842 r
.68266 .60488 m .68066 .60532 L .67938 .60219 L F
.636 .428 .584 r
.59637 .71392 m .59403 .71645 L .59406 .71421 L F
.512 .005 0 r
.45185 .72637 m .4539 .72677 L .45527 .7258 L F
.197 0 0 r
.4539 .72677 m .4574 .72564 L .45527 .7258 L F
.996 .763 .441 r
.57906 .69947 m .57999 .70052 L .58008 .69803 L F
.596 .547 .771 r
.69582 .59751 m .69762 .594 L .69673 .59584 L F
.795 .431 .367 r
.69673 .59584 m .69818 .59746 L .69582 .59751 L F
.596 .547 .771 r
.69582 .59751 m .69818 .59746 L .69762 .594 L F
.76 .711 .806 r
.69395 .61616 m .69721 .61658 L .69615 .61373 L F
.681 .67 .832 r
.69615 .61373 m .69721 .61658 L .69958 .61575 L F
0 0 0 r
.63297 .61944 m .63393 .61776 L .63452 .61636 L F
.692 .898 .537 r
.63179 .62073 m .63393 .61776 L .63297 .61944 L F
.768 .487 0 r
.58127 .68294 m .58111 .68174 L .57939 .68083 L F
.58127 .68294 m .58158 .68382 L .58111 .68174 L F
.822 .368 0 r
.57587 .7263 m .57654 .727 L .57619 .72565 L F
.505 .284 .512 r
.39829 .74104 m .40082 .73803 L .39882 .73872 L F
.407 .093 .318 r
.37805 .70508 m .37688 .70326 L .37887 .70281 L F
.37805 .70508 m .37604 .70557 L .37688 .70326 L F
.446 .093 .271 r
.35153 .7086 m .3538 .70827 L .35486 .70596 L F
.305 0 .201 r
.35486 .70596 m .35563 .70767 L .35712 .70578 L F
.35486 .70596 m .3538 .70827 L .35563 .70767 L F
.457 .252 .513 r
.38322 .69739 m .38107 .70016 L .38128 .69787 L F
.481 .253 .491 r
.30351 .61371 m .30325 .61574 L .30126 .6161 L F
.459 .339 .629 r
.30511 .60926 m .3054 .61313 L .30351 .61371 L F
.506 .321 .564 r
.3054 .61313 m .30325 .61574 L .30351 .61371 L F
.414 .748 .994 r
.55608 .70229 m .55497 .70333 L .55388 .70226 L F
.55608 .70229 m .55744 .70327 L .55497 .70333 L F
0 0 0 r
.44271 .78504 m .44098 .78569 L .43886 .78609 L F
.022 0 0 r
.44355 .7853 m .44271 .78504 L .44481 .78438 L F
.44355 .7853 m .44098 .78569 L .44271 .78504 L F
.703 .634 .777 r
.68198 .58587 m .68316 .58822 L .68492 .58682 L F
.413 .209 .492 r
.68316 .58822 m .68467 .58859 L .68492 .58682 L F
.68316 .58822 m .68308 .59082 L .68467 .58859 L F
.525 .877 .986 r
.6826 .57805 m .68002 .57891 L .68045 .57889 L F
.538 .769 .983 r
.59667 .74616 m .5978 .74722 L .59535 .74772 L F
.572 .588 .831 r
.5978 .74722 m .59493 .74779 L .59535 .74772 L F
.5978 .74722 m .59863 .74923 L .59493 .74779 L F
.593 .43 .63 r
.59863 .74923 m .59646 .75181 L .59493 .74779 L F
.654 .654 .838 r
.7188 .73017 m .71644 .73097 L .71585 .72908 L F
.343 0 0 r
.31695 .73823 m .31547 .73775 L .31292 .73659 L F
.791 .908 .511 r
.67527 .58353 m .67357 .5866 L .67401 .5852 L F
0 0 0 r
.67527 .58353 m .67674 .58215 L .67767 .58045 L F
.378 .127 .402 r
.30325 .61574 m .30076 .61858 L .30126 .6161 L F
.326 .631 .961 r
.37495 .65186 m .37433 .65305 L .37301 .65201 L F
.37495 .65186 m .37631 .65322 L .37433 .65305 L F
.446 .87 .75 r
.4929 .71689 m .49396 .7161 L .49477 .71586 L F
.447 .881 .846 r
.4929 .71689 m .49195 .71697 L .49396 .7161 L F
.848 .762 .768 r
.64368 .62367 m .64722 .62175 L .64574 .62044 L F
.64368 .62367 m .64514 .62456 L .64722 .62175 L F
.695 .286 .267 r
.43581 .7468 m .4329 .74822 L .4309 .74634 L F
.782 .441 .41 r
.4357 .74699 m .4329 .74822 L .43581 .7468 L F
0 0 0 r
.58248 .65993 m .58004 .66267 L .58125 .66195 L F
.58004 .66267 m .57886 .66413 L .58125 .66195 L F
.362 .677 .977 r
.43414 .75408 m .43335 .7551 L .43208 .75421 L F
.644 .173 .12 r
.43563 .75563 m .43587 .75652 L .43335 .7551 L F
.445 0 0 r
.43335 .7551 m .43571 .75569 L .43563 .75563 L F
.362 .677 .977 r
.43414 .75408 m .43571 .75569 L .43335 .7551 L F
.187 .428 .86 r
.43335 .7551 m .43414 .75408 L .43208 .75421 L F
.43335 .7551 m .43587 .75652 L .43414 .75408 L F
.455 0 .039 r
.48203 .73257 m .47872 .73372 L .48028 .73383 L F
.48203 .73257 m .48066 .73414 L .47872 .73372 L F
0 0 0 r
.48434 .73092 m .48286 .73264 L .48203 .73257 L F
.482 .143 .316 r
.48286 .73264 m .48066 .73414 L .48203 .73257 L F
0 0 0 r
.71735 .7129 m .71966 .71232 L .7208 .7119 L F
.303 0 0 r
.71966 .71232 m .7231 .71143 L .7208 .7119 L F
.286 .348 .752 r
.73555 .58826 m .73385 .58922 L .73227 .58658 L F
.73555 .58826 m .73492 .58913 L .73385 .58922 L F
.283 .287 .687 r
.73492 .58913 m .73583 .59121 L .73385 .58922 L F
.598 .532 .752 r
.63933 .61108 m .64015 .60695 L .63848 .60767 L F
.63933 .61108 m .64181 .61103 L .64015 .60695 L F
.443 0 .069 r
.64119 .61228 m .63933 .61108 L .63917 .6131 L F
.64119 .61228 m .64181 .61103 L .63933 .61108 L F
.648 .748 .923 r
.68042 .61888 m .67691 .61827 L .67949 .61593 L F
.739 .694 .808 r
.68311 .61596 m .68042 .61888 L .67949 .61593 L F
.451 .046 .18 r
.44836 .74465 m .44767 .74575 L .44528 .74602 L F
.622 .394 .55 r
.44995 .74364 m .44767 .74575 L .44836 .74465 L F
.827 .392 .204 r
.56353 .70628 m .56275 .70754 L .5611 .7053 L F
.64 .158 .094 r
.56353 .70628 m .56611 .70788 L .56275 .70754 L F
.527 0 0 r
.5677 .70836 m .56611 .70788 L .56353 .70628 L F
.476 .551 .853 r
.69654 .70587 m .69732 .70868 L .69854 .70725 L F
.673 .368 .449 r
.69732 .70868 m .69939 .71105 L .69854 .70725 L F
.69732 .70868 m .69566 .71127 L .69939 .71105 L F
.518 .322 .554 r
.38305 .79524 m .38061 .79828 L .38315 .79808 L F
.851 .607 .569 r
.57654 .727 m .57984 .72758 L .57952 .7253 L F
.587 .421 .624 r
.57952 .7253 m .57984 .72758 L .5822 .7251 L F
.691 .486 .604 r
.59578 .69518 m .5982 .69743 L .59829 .69505 L F
.59578 .69518 m .59593 .69751 L .5982 .69743 L F
.35 .803 .669 r
.69448 .57853 m .68946 .58098 L .69352 .57765 L F
.996 .764 .45 r
.38307 .8002 m .38401 .801 L .38388 .80336 L F
.651 .96 .929 r
.5458 .69172 m .54572 .69166 L .54985 .6903 L F
.847 .933 .883 r
.55135 .68853 m .54985 .6903 L .55018 .68801 L F
.816 .908 .903 r
.54985 .6903 m .54572 .69166 L .55018 .68801 L F
.419 .473 .81 r
.52432 .70983 m .5228 .7117 L .52165 .70854 L F
.415 .468 .806 r
.52432 .70983 m .52535 .71294 L .5228 .7117 L F
.32 .228 .593 r
.57714 .70536 m .57726 .70765 L .57549 .70602 L F
.902 .88 .803 r
.57726 .70765 m .57671 .71136 L .57549 .70602 L F
.476 .184 .391 r
.51159 .72251 m .50855 .72487 L .50734 .72179 L F
.51159 .72251 m .51071 .72448 L .50855 .72487 L F
.606 .038 0 r
.51159 .72251 m .51166 .72335 L .51071 .72448 L F
.51159 .72251 m .51372 .72428 L .51166 .72335 L F
.019 0 .134 r
.63084 .676 m .63022 .67788 L .62855 .67888 L F
.087 0 .261 r
.62855 .67888 m .63022 .67788 L .62839 .68092 L F
.341 .108 .409 r
.28677 .64083 m .28651 .6431 L .28462 .6436 L F
.178 0 .26 r
.28651 .6431 m .2842 .64575 L .28462 .6436 L F
.607 .42 .603 r
.60841 .70327 m .60873 .7059 L .60621 .70598 L F
.515 .271 .483 r
.61137 .70275 m .60873 .7059 L .60841 .70327 L F
.779 .41 0 r
.43587 .75652 m .43663 .75793 L .43563 .75563 L F
.684 .739 .893 r
.32703 .71085 m .32509 .7119 L .32368 .71032 L F
.384 0 0 r
.72914 .59471 m .73066 .59556 L .72889 .59714 L F
.72914 .59471 m .73174 .59514 L .73066 .59556 L F
.276 0 0 r
.72527 .71078 m .72828 .71166 L .72645 .71098 L F
.518 .365 .613 r
.7241 .72748 m .72637 .72709 L .72653 .72487 L F
.528 .245 .428 r
.72359 .72993 m .72637 .72709 L .7241 .72748 L F
.745 .225 0 r
.40573 .79423 m .40832 .79609 L .40706 .79551 L F
.48 .898 .849 r
.40832 .79609 m .40918 .79532 L .40706 .79551 L F
.40832 .79609 m .41064 .79507 L .40918 .79532 L F
.481 .058 .159 r
.46244 .77281 m .46466 .77275 L .46302 .77208 L F
0 0 0 r
.57538 .7176 m .57413 .71873 L .57349 .71882 L F
.963 .94 .648 r
.5755 .71587 m .57538 .7176 L .57738 .71668 L F
.5755 .71587 m .57413 .71873 L .57538 .7176 L F
0 0 0 r
.58248 .65993 m .58362 .65934 L .5845 .65736 L F
.44 .178 .419 r
.58125 .66195 m .58362 .65934 L .58248 .65993 L F
.622 .459 .64 r
.58389 .70615 m .58634 .70582 L .5861 .70332 L F
.594 .357 .526 r
.58389 .70615 m .58608 .70799 L .58634 .70582 L F
.434 .371 .688 r
.58442 .70853 m .58608 .70799 L .58389 .70615 L F
.486 0 0 r
.72532 .71956 m .72477 .72027 L .72176 .71951 L F
.001 .532 .846 r
.72805 .72131 m .72477 .72027 L .72532 .71956 L F
0 0 0 r
.61678 .6761 m .61799 .67495 L .61897 .6734 L F
.61678 .6761 m .61612 .67785 L .61799 .67495 L F
.9 .612 .489 r
.57453 .74399 m .57172 .74507 L .57143 .74298 L F
.57453 .74399 m .57441 .74639 L .57172 .74507 L F
.415 .307 .622 r
.5861 .70332 m .58634 .70582 L .5881 .70506 L F
.596 .283 .409 r
.5861 .70332 m .5881 .70506 L .58847 .70325 L F
.415 .307 .622 r
.5861 .70332 m .58634 .70582 L .5881 .70506 L F
.636 .472 .644 r
.54487 .7279 m .54616 .73017 L .54438 .72983 L F
.476 .434 .732 r
.54477 .72548 m .54588 .72668 L .54487 .7279 L F
.502 .546 .834 r
.54796 .7287 m .54487 .7279 L .54588 .72668 L F
.54796 .7287 m .54616 .73017 L .54487 .7279 L F
.084 0 .245 r
.43571 .75569 m .43587 .75652 L .43563 .75563 L F
.654 .103 0 r
.50103 .78532 m .4982 .7841 L .49973 .78431 L F
.427 .148 .384 r
.36716 .69794 m .36662 .69973 L .36915 .69744 L F
.548 .389 .618 r
.39036 .75448 m .39234 .75163 L .39028 .75202 L F
.553 .321 .518 r
.46729 .7401 m .46636 .74178 L .46475 .74014 L F
.582 .084 .037 r
.46307 .73833 m .46651 .73847 L .46613 .74009 L F
.553 .321 .518 r
.46729 .7401 m .46475 .74014 L .4671 .74006 L F
.451 .026 .14 r
.46613 .74009 m .46729 .7401 L .46612 .7401 L F
.46651 .73847 m .46729 .7401 L .46613 .74009 L F
.261 0 0 r
.46402 .73939 m .46307 .73833 L .46612 .7401 L F
.553 .321 .518 r
.4671 .74006 m .46613 .74009 L .46402 .73939 L F
.46613 .74009 m .46475 .74014 L .4647 .74008 L F
.46613 .74009 m .4647 .74008 L .46402 .73939 L F
.582 .084 .037 r
.46611 .74009 m .46613 .74009 L .46612 .7401 L F
.46307 .73833 m .46613 .74009 L .46611 .74009 L F
.451 .026 .14 r
.46651 .73847 m .46885 .73834 L .46729 .7401 L F
.88 .86 .41 r
.66807 .60016 m .66737 .6025 L .66727 .60158 L F
.989 .799 .411 r
.66767 .59699 m .66807 .60016 L .6676 .59928 L F
.977 .821 .412 r
.6676 .59928 m .66807 .60016 L .66727 .60158 L F
.331 .067 .354 r
.38676 .80349 m .38869 .80068 L .38806 .80267 L F
0 0 0 r
.38869 .80068 m .39041 .79759 L .38879 .80042 L F
.38806 .80267 m .38869 .80068 L .38879 .80042 L F
.40676 .73627 m .40703 .73703 L .40855 .73545 L F
.40676 .73627 m .40559 .73767 L .40703 .73703 L F
0 0 .367 r
.54458 .70319 m .54576 .70548 L .54538 .70458 L F
.54458 .70319 m .54538 .70458 L .54317 .70229 L F
.605 .464 .663 r
.38676 .77424 m .3869 .77646 L .38888 .77379 L F
.178 0 0 r
.46281 .72633 m .46492 .72613 L .46634 .72537 L F
.106 0 0 r
.46492 .72613 m .46863 .72542 L .46634 .72537 L F
.893 .946 .588 r
.66729 .6073 m .66734 .60848 L .66607 .60987 L F
.447 .24 .505 r
.36941 .69518 m .36915 .69744 L .37128 .69466 L F
.672 .21 .146 r
.68759 .70706 m .69077 .70796 L .68836 .70632 L F
.526 .525 .797 r
.56117 .69692 m .55954 .69958 L .55832 .69725 L F
.56117 .69692 m .56266 .69989 L .55954 .69958 L F
.841 .997 .772 r
.70105 .59696 m .70138 .59743 L .70362 .5948 L F
.092 0 0 r
.70362 .5948 m .70505 .59505 L .70276 .59514 L F
.491 .672 .945 r
.70334 .59429 m .70276 .59514 L .70505 .59505 L F
.70114 .59331 m .70276 .59514 L .70334 .59429 L F
.841 .997 .772 r
.70105 .59696 m .70215 .59604 L .70276 .59514 L F
.70215 .59604 m .70362 .5948 L .70276 .59514 L F
.092 0 0 r
.70362 .5948 m .70578 .59454 L .70505 .59505 L F
.709 .458 .543 r
.60091 .69695 m .60387 .69522 L .60058 .695 L F
.60091 .69695 m .60384 .6974 L .60387 .69522 L F
.582 .342 .517 r
.60384 .6974 m .60636 .69505 L .60387 .69522 L F
.652 .298 .36 r
.35335 .67324 m .35203 .67545 L .34979 .67501 L F
.351 0 .082 r
.35554 .67329 m .35203 .67545 L .35335 .67324 L F
.827 .815 .839 r
.68626 .62303 m .6844 .62426 L .68716 .62424 L F
.815 .813 .849 r
.68626 .62303 m .68716 .62424 L .68951 .62165 L F
.336 .111 .417 r
.28891 .63801 m .28853 .64043 L .28677 .64083 L F
.28 0 .256 r
.28677 .64083 m .28768 .64221 L .28651 .6431 L F
.28677 .64083 m .28853 .64043 L .28768 .64221 L F
.274 0 .151 r
.5845 .65736 m .58566 .65862 L .58648 .65654 L F
.5845 .65736 m .58362 .65934 L .58566 .65862 L F
.829 .823 .843 r
.72923 .72764 m .7288 .72941 L .72988 .72771 L F
.219 0 .289 r
.73341 .72383 m .73269 .72611 L .73118 .72657 L F
.62 .231 .286 r
.73269 .72611 m .73181 .72612 L .73118 .72657 L F
0 0 0 r
.73178 .72482 m .73118 .72657 L .73014 .72733 L F
.73341 .72383 m .73118 .72657 L .73178 .72482 L F
.62 .231 .286 r
.73181 .72612 m .72994 .72613 L .73118 .72657 L F
0 0 0 r
.73014 .72733 m .73118 .72657 L .72988 .72771 L F
.551 .932 .864 r
.73118 .72657 m .72923 .72764 L .72988 .72771 L F
.463 .588 .893 r
.29628 .6017 m .29553 .60369 L .29433 .602 L F
.29628 .6017 m .29818 .60434 L .29553 .60369 L F
.394 .819 .966 r
.69818 .59746 m .70138 .59743 L .70105 .59696 L F
.746 .699 .807 r
.7049 .6025 m .70595 .60553 L .70264 .60509 L F
.257 0 .179 r
.36725 .7115 m .3663 .71371 L .36449 .71361 L F
.315 0 .147 r
.3663 .71371 m .36335 .71561 L .36449 .71361 L F
.59 .547 .775 r
.68641 .71078 m .68759 .70706 L .68577 .7091 L F
.911 .892 .475 r
.61897 .6734 m .61799 .67495 L .61895 .67171 L F
.903 .76 .693 r
.64269 .6432 m .64321 .64096 L .64184 .63972 L F
.941 .874 .743 r
.64321 .64096 m .64341 .63737 L .64184 .63972 L F
.492 .41 .691 r
.31013 .69999 m .30865 .70354 L .30831 .70035 L F
.632 .569 .766 r
.5611 .7053 m .55744 .70327 L .56052 .70327 L F
.526 .313 .533 r
.56272 .70286 m .5611 .7053 L .56052 .70327 L F
.473 .864 .973 r
.4227 .78893 m .42157 .78966 L .42351 .78912 L F
.4227 .78893 m .42035 .78956 L .42157 .78966 L F
.482 .254 .49 r
.4309 .74634 m .42852 .74894 L .42867 .74669 L F
.538 .769 .983 r
.59667 .74616 m .59535 .74772 L .59452 .74697 L F
.492 .41 .691 r
.31013 .69999 m .31061 .70347 L .30865 .70354 L F
.546 .431 .673 r
.31061 .70347 m .30892 .70587 L .30865 .70354 L F
.279 0 0 r
.34172 .72732 m .33807 .72933 L .33988 .72813 L F
.619 .709 .909 r
.73312 .60366 m .73144 .60568 L .73049 .60444 L F
.73312 .60366 m .73245 .60489 L .73144 .60568 L F
.061 0 .392 r
.73282 .60652 m .73144 .60568 L .73245 .60489 L F
.952 .73 .565 r
.5677 .70836 m .56751 .71094 L .56611 .70788 L F
.554 .225 .366 r
.59843 .64562 m .60081 .64545 L .60094 .64393 L F
.519 .19 .35 r
.60081 .64545 m .60398 .64291 L .60094 .64393 L F
.765 .493 .522 r
.58897 .75424 m .58789 .75703 L .58606 .75445 L F
.673 .39 .485 r
.59108 .75669 m .58897 .75424 L .59127 .75473 L F
.59108 .75669 m .58789 .75703 L .58897 .75424 L F
.568 .863 .996 r
.51964 .70943 m .52052 .7082 L .52165 .70854 L F
.51964 .70943 m .51843 .70883 L .52052 .7082 L F
.67 .535 .692 r
.41563 .75402 m .41638 .75736 L .4136 .75717 L F
.427 .397 .723 r
.4157 .75968 m .4136 .75717 L .41638 .75736 L F
.4157 .75968 m .41524 .76273 L .4136 .75717 L F
.929 .689 .555 r
.35502 .6458 m .35489 .64816 L .3567 .64842 L F
0 .446 .693 r
.35489 .64816 m .35825 .64887 L .3567 .64842 L F
.585 .362 .543 r
.58847 .70325 m .59106 .70322 L .59101 .70066 L F
.536 .324 .539 r
.59101 .70066 m .5931 .70266 L .59365 .70018 L F
.59101 .70066 m .59106 .70322 L .5931 .70266 L F
.679 .396 .486 r
.3103 .66652 m .31326 .66468 L .31169 .66477 L F
.58 .397 .599 r
.3358 .71265 m .336 .71428 L .33387 .71411 L F
.3358 .71265 m .336 .71428 L .33387 .71411 L F
.875 .787 .76 r
.7361 .61384 m .73486 .61268 L .73304 .61567 L F
.927 .851 .747 r
.70098 .70789 m .70083 .71134 L .70301 .71092 L F
.70098 .70789 m .69939 .71105 L .70083 .71134 L F
.907 .939 .818 r
.70027 .71283 m .70083 .71134 L .69939 .71105 L F
.521 .359 .602 r
.70301 .71092 m .70114 .71374 L .70083 .71134 L F
.907 .939 .818 r
.70027 .71283 m .70301 .71092 L .70083 .71134 L F
.478 .06 .167 r
.52305 .79042 m .51951 .79223 L .51998 .79235 L F
.562 .584 .833 r
.67141 .61577 m .675 .61912 L .67387 .61852 L F
.684 .635 .794 r
.6774 .61649 m .67691 .61827 L .675 .61912 L F
.276 0 .078 r
.675 .61912 m .67691 .61827 L .67734 .61973 L F
.675 .61912 m .67734 .61973 L .67387 .61852 L F
.56 .243 .389 r
.70657 .71919 m .705 .71663 L .70431 .71954 L F
.70657 .71919 m .70723 .71638 L .705 .71663 L F
.554 .596 .85 r
.71104 .7242 m .71005 .72752 L .70911 .72448 L F
.71104 .7242 m .71231 .72711 L .71005 .72752 L F
.355 0 .137 r
.32367 .65623 m .3253 .65657 L .32663 .65467 L F
.373 .032 .253 r
.3253 .65657 m .32833 .65379 L .32663 .65467 L F
.878 .913 .511 r
.66902 .59193 m .66816 .594 L .66801 .59325 L F
0 0 0 r
.67042 .59109 m .66902 .59193 L .66801 .59325 L F
.604 .452 .648 r
.40747 .66247 m .40746 .66504 L .40483 .66534 L F
.679 .528 .674 r
.40456 .66679 m .40746 .66504 L .40483 .66534 L F
.604 .452 .648 r
.40747 .66247 m .40746 .66504 L .40483 .66534 L F
.679 .528 .674 r
.40456 .66679 m .40746 .66504 L .40483 .66534 L F
.685 .766 .912 r
.6949 .60642 m .69178 .60584 L .69369 .60468 L F
.643 .704 .891 r
.69721 .60555 m .6949 .60642 L .69369 .60468 L F
.586 .935 .764 r
.58058 .67938 m .57939 .68083 L .58271 .6783 L F
.987 .834 .605 r
.58058 .67938 m .58127 .68294 L .57939 .68083 L F
.352 0 0 r
.44804 .78392 m .44705 .78449 L .44481 .78438 L F
.101 0 0 r
.45019 .78349 m .44705 .78449 L .44804 .78392 L F
.017 0 .273 r
.73397 .72171 m .73341 .72383 L .73178 .72482 L F
.259 0 .18 r
.36804 .71299 m .36725 .7115 L .36911 .71067 L F
.36804 .71299 m .3663 .71371 L .36725 .7115 L F
.976 .919 .666 r
.6201 .66527 m .61844 .6668 L .61909 .66443 L F
.6201 .66527 m .61893 .66771 L .61844 .6668 L F
.992 .823 .572 r
.6201 .66527 m .61909 .66443 L .61967 .66223 L F
.547 .921 .775 r
.56422 .67487 m .56766 .67302 L .56477 .67547 L F
.516 .332 .57 r
.68338 .59312 m .68234 .59527 L .68368 .59304 L F
.597 .704 .919 r
.68256 .59165 m .68338 .59312 L .68368 .59304 L F
.719 .795 .911 r
.65838 .61091 m .65918 .6127 L .66204 .61135 L F
.802 .362 0 r
.57191 .71928 m .57374 .72193 L .57349 .71882 L F
0 0 0 r
.57413 .71873 m .57191 .71928 L .57349 .71882 L F
.768 .467 .478 r
.69854 .70725 m .70048 .7058 L .69812 .70522 L F
.69854 .70725 m .70098 .70789 L .70048 .7058 L F
.724 .523 .618 r
.47586 .77295 m .47905 .77527 L .47701 .77353 L F
.159 .7 .776 r
.43485 .78646 m .43576 .78624 L .43357 .78665 L F
.43485 .78646 m .43708 .78615 L .43576 .78624 L F
.873 .809 .783 r
.43627 .74897 m .43991 .74656 L .43867 .74704 L F
.291 0 0 r
.43991 .74656 m .44098 .74737 L .43867 .74704 L F
.43991 .74656 m .44208 .74658 L .44098 .74737 L F
.12 .612 .909 r
.29433 .602 m .29241 .60174 L .29089 .601 L F
.344 .782 .965 r
.27841 .59947 m .27783 .60015 L .27631 .59956 L F
.27841 .59947 m .27983 .59993 L .27783 .60015 L F
.099 0 .22 r
.62128 .68956 m .62147 .69116 L .61973 .69176 L F
.078 0 .162 r
.62147 .69116 m .61923 .69394 L .61973 .69176 L F
.587 .36 .539 r
.60621 .70598 m .60384 .70837 L .60389 .7061 L F
.904 .788 .722 r
.64039 .65181 m .64013 .64822 L .63879 .65099 L F
.918 .73 .633 r
.64001 .65409 m .64039 .65181 L .63879 .65099 L F
.587 .36 .539 r
.60621 .70598 m .60618 .70818 L .60384 .70837 L F
.522 .308 .531 r
.6084 .70775 m .60621 .70598 L .60873 .7059 L F
.6084 .70775 m .60618 .70818 L .60621 .70598 L F
.147 .169 .626 r
.57179 .69236 m .57369 .69378 L .5734 .69127 L F
.123 0 .224 r
.62437 .68655 m .62359 .68839 L .62128 .68956 L F
.121 0 .221 r
.62359 .68839 m .62147 .69116 L .62128 .68956 L F
.486 .461 .755 r
.37553 .67318 m .37635 .67635 L .37756 .67455 L F
.589 .501 .723 r
.37635 .67635 m .37916 .67826 L .37756 .67455 L F
.37635 .67635 m .37694 .67874 L .37916 .67826 L F
.535 .601 .866 r
.67956 .62723 m .68243 .62717 L .68052 .62555 L F
.553 .428 .665 r
.38722 .76549 m .38901 .76253 L .38685 .76287 L F
.625 .803 .968 r
.38648 .65739 m .38301 .65696 L .3851 .65626 L F
.626 .8 .966 r
.38855 .65669 m .38648 .65739 L .3851 .65626 L F
.413 .782 .994 r
.4313 .6998 m .43478 .70033 L .43262 .7005 L F
.43478 .70033 m .4313 .6998 L .43262 .7005 L F
.353 .223 .561 r
.29437 .63168 m .29286 .6299 L .29453 .62934 L F
.29437 .63168 m .29293 .63229 L .29286 .6299 L F
.094 0 0 r
.4432 .7755 m .44016 .77537 L .44238 .77588 L F
.004 0 0 r
.48961 .7291 m .48844 .72937 L .48631 .72959 L F
.034 0 0 r
.49189 .72892 m .48844 .72937 L .48961 .7291 L F
.454 .17 .392 r
.71199 .71569 m .71014 .71464 L .70964 .71576 L F
.71199 .71569 m .7122 .71404 L .71014 .71464 L F
.416 .155 .408 r
.68245 .57966 m .68045 .57889 L .68006 .5798 L F
.503 .061 .133 r
.41822 .78997 m .41526 .79205 L .41352 .79166 L F
.024 0 0 r
.41935 .79002 m .41822 .78997 L .42035 .78956 L F
.41935 .79002 m .41526 .79205 L .41822 .78997 L F
.422 .237 .523 r
.29102 .63518 m .29086 .63744 L .28891 .63801 L F
.344 .102 .396 r
.29086 .63744 m .28853 .64043 L .28891 .63801 L F
.58 .375 .568 r
.59365 .70018 m .59593 .69751 L .59395 .69792 L F
.618 .392 .552 r
.41956 .75236 m .41874 .75451 L .41563 .75402 L F
.443 .273 .555 r
.41874 .75451 m .41638 .75736 L .41563 .75402 L F
.454 .252 .516 r
.41321 .6579 m .412 .65709 L .41418 .65705 L F
.253 0 .003 r
.412 .65709 m .41271 .65814 L .41418 .65705 L F
.454 .252 .516 r
.41321 .6579 m .41073 .65974 L .412 .65709 L F
.253 0 .003 r
.412 .65709 m .41064 .65872 L .41271 .65814 L F
.523 .353 .592 r
.37695 .68116 m .37916 .67826 L .37694 .67874 L F
.515 .293 .516 r
.60636 .69505 m .60887 .69455 L .60844 .69208 L F
.39 .22 .527 r
.60887 .69455 m .61076 .69147 L .60844 .69208 L F
.856 .846 .833 r
.57703 .74899 m .57556 .74942 L .5777 .74654 L F
.689 .182 0 r
.57703 .74899 m .57805 .75053 L .57556 .74942 L F
.57703 .74899 m .57895 .75124 L .57805 .75053 L F
.604 .401 .58 r
.59869 .71118 m .59872 .71372 L .59637 .71392 L F
.564 .37 .576 r
.6012 .71314 m .59869 .71118 L .60148 .71073 L F
.6012 .71314 m .59872 .71372 L .59869 .71118 L F
.546 .374 .599 r
.39234 .75163 m .39446 .74891 L .39238 .74931 L F
.162 .635 .929 r
.70216 .73016 m .70114 .72954 L .69895 .72924 L F
.274 0 0 r
.70216 .73016 m .70341 .73072 L .70114 .72954 L F
.70216 .73016 m .70439 .73071 L .70341 .73072 L F
.208 .733 .831 r
.46929 .72537 m .47081 .72511 L .47195 .72517 L F
.461 0 .041 r
.46928 .72577 m .47222 .72487 L .47081 .72511 L F
.316 .804 .871 r
.47195 .72517 m .47081 .72511 L .47302 .72462 L F
.461 0 .041 r
.47222 .72487 m .47302 .72462 L .47081 .72511 L F
.208 .733 .831 r
.46863 .72542 m .47081 .72511 L .46929 .72537 L F
.316 .804 .871 r
.47195 .72517 m .47302 .72462 L .47403 .72458 L F
.501 .901 .78 r
.52065 .72983 m .5233 .72831 L .52189 .72877 L F
.535 .62 .883 r
.37834 .65304 m .3775 .65529 L .37631 .65322 L F
.37834 .65304 m .37987 .65535 L .3775 .65529 L F
.809 .61 .632 r
.69606 .57425 m .69904 .57257 L .69536 .57349 L F
.69606 .57425 m .69883 .57548 L .69904 .57257 L F
.657 .968 .807 r
.70066 .5741 m .69883 .57548 L .69904 .57257 L F
.577 .406 .614 r
.69883 .57548 m .70168 .57433 L .69904 .57257 L F
.497 .294 .535 r
.40642 .67293 m .40412 .6756 L .40419 .6734 L F
.69 .687 .842 r
.38851 .7876 m .39031 .79025 L .39268 .79 L F
.675 .51 .654 r
.38996 .79242 m .39268 .79 L .39031 .79025 L F
.54 .553 .816 r
.70135 .7161 m .69996 .71824 L .69895 .7166 L F
.70135 .7161 m .70231 .71863 L .69996 .71824 L F
.632 .407 .558 r
.42083 .7542 m .41956 .75236 L .42108 .75216 L F
.498 .251 .471 r
.42296 .75366 m .42108 .75216 L .42397 .75167 L F
.42296 .75366 m .42083 .7542 L .42108 .75216 L F
0 0 0 r
.59443 .66531 m .59304 .66585 L .59314 .66578 L F
.425 .846 .689 r
.59314 .66578 m .59235 .66612 L .59108 .66699 L F
0 0 0 r
.59304 .66585 m .59235 .66612 L .59314 .66578 L F
.658 .96 .936 r
.59314 .66578 m .59191 .6672 L .59325 .6657 L F
.59314 .66578 m .59325 .6657 L .594 .66486 L F
.59314 .66578 m .59108 .66699 L .59191 .6672 L F
.752 .745 .846 r
.58374 .72878 m .58278 .72865 L .58531 .72747 L F
.455 .29 .567 r
.3752 .6834 m .37712 .68333 L .37695 .68116 L F
.404 .276 .591 r
.3752 .6834 m .37706 .68575 L .37712 .68333 L F
.3752 .6834 m .37518 .6866 L .37706 .68575 L F
.261 0 .004 r
.36158 .67166 m .36104 .67038 L .36313 .67056 L F
.36158 .67166 m .35955 .67217 L .36104 .67038 L F
.733 .818 .917 r
.30818 .73202 m .30657 .73291 L .30961 .73303 L F
.737 .498 .567 r
.30605 .73503 m .30961 .73303 L .30657 .73291 L F
.30605 .73503 m .31169 .73689 L .30961 .73303 L F
.349 .386 .759 r
.30961 .73303 m .31081 .73135 L .30818 .73202 L F
.30961 .73303 m .31118 .73282 L .31081 .73135 L F
0 0 .436 r
.30961 .73303 m .31148 .73638 L .31118 .73282 L F
.30961 .73303 m .31169 .73689 L .31148 .73638 L F
.59 .547 .775 r
.68641 .71078 m .6886 .71051 L .68759 .70706 L F
.542 .165 .276 r
.31177 .73621 m .31337 .73711 L .31239 .73585 L F
.31148 .73638 m .31189 .73654 L .31177 .73621 L F
.31189 .73654 m .31337 .73711 L .31177 .73621 L F
.974 .665 .331 r
.31217 .73737 m .31326 .73922 L .31292 .73659 L F
.31159 .73799 m .31266 .73878 L .31217 .73737 L F
.31266 .73878 m .31326 .73922 L .31217 .73737 L F
.037 0 0 r
.31337 .73711 m .31292 .73659 L .31547 .73775 L F
.31337 .73711 m .31159 .73799 L .31292 .73659 L F
.115 .271 .747 r
.3905 .65855 m .38976 .6598 L .38855 .65669 L F
.493 .768 .992 r
.3905 .65855 m .39148 .65929 L .38976 .6598 L F
.884 .991 .783 r
.70892 .59565 m .70794 .59726 L .70727 .59654 L F
.806 .32 0 r
.70794 .59726 m .70775 .59823 L .70727 .59654 L F
.70794 .59726 m .70922 .59928 L .70775 .59823 L F
.638 .62 .816 r
.5685 .7144 m .56525 .71194 L .56751 .71094 L F
.606 .704 .913 r
.56751 .71094 m .57018 .71149 L .56968 .71036 L F
.563 .833 .996 r
.5686 .70941 m .56751 .71094 L .56968 .71036 L F
.719 .703 .169 r
.5686 .70941 m .56806 .71222 L .56751 .71094 L F
.5686 .70941 m .56827 .71098 L .56806 .71222 L F
.56827 .71098 m .56787 .71289 L .56806 .71222 L F
0 0 .515 r
.56806 .71222 m .5685 .7144 L .56799 .71262 L F
.56806 .71222 m .56799 .71262 L .56751 .71094 L F
0 .275 .777 r
.57007 .71482 m .57067 .716 L .5685 .7144 L F
.756 .574 0 r
.67464 .59297 m .67464 .59191 L .67385 .59065 L F
.67464 .59297 m .67478 .59416 L .67464 .59191 L F
.493 .582 .872 r
.59379 .72754 m .59067 .72509 L .59307 .72466 L F
.421 .435 .768 r
.59307 .72466 m .59602 .72688 L .59379 .72754 L F
.633 .442 .607 r
.59602 .72688 m .59312 .72944 L .59379 .72754 L F
.504 .83 .999 r
.39569 .79455 m .3995 .79479 L .39796 .79361 L F
.524 .788 .993 r
.39796 .79361 m .3995 .79479 L .40115 .79448 L F
.922 .664 .529 r
.70885 .58102 m .70744 .5824 L .70857 .58076 L F
.70885 .58102 m .70889 .58323 L .70744 .5824 L F
.757 .953 .939 r
.70922 .57902 m .71041 .57931 L .70857 .58076 L F
0 .375 .81 r
.71051 .57935 m .71041 .57931 L .70922 .57902 L F
.717 .237 .106 r
.71041 .57931 m .71339 .58013 L .71116 .57824 L F
.547 0 0 r
.71041 .57931 m .71325 .58076 L .71339 .58013 L F
0 .375 .81 r
.71222 .57977 m .71325 .58076 L .71041 .57931 L F
.71222 .57977 m .71041 .57931 L .71051 .57935 L F
0 0 0 r
.71116 .57824 m .7103 .57928 L .71041 .57931 L F
.7103 .57928 m .70885 .58102 L .71041 .57931 L F
.652 .967 .816 r
.71041 .57931 m .70885 .58102 L .70857 .58076 L F
.296 0 0 r
.33853 .71251 m .34006 .71294 L .34179 .71177 L F
.554 .859 .997 r
.34179 .71177 m .34049 .71153 L .34375 .71114 L F
.627 .636 .84 r
.39993 .66763 m .39647 .66577 L .39847 .66553 L F
.599 .674 .893 r
.40211 .66707 m .39993 .66763 L .39847 .66553 L F
.229 .389 .816 r
.30408 .73364 m .30443 .73205 L .30379 .73296 L F
.30408 .73364 m .30472 .73203 L .30443 .73205 L F
.30408 .73364 m .30605 .73503 L .30472 .73203 L F
.47 .395 .69 r
.30442 .73569 m .30605 .73503 L .30408 .73364 L F
.695 .772 .911 r
.71067 .61603 m .7138 .61657 L .71294 .61504 L F
.544 .695 .938 r
.71294 .61504 m .7138 .61657 L .71521 .61476 L F
.391 .472 .824 r
.7138 .61657 m .71672 .61791 L .71521 .61476 L F
.347 0 .194 r
.30675 .6681 m .30583 .66963 L .30878 .6676 L F
.864 .443 .002 r
.43414 .75408 m .43587 .75652 L .43571 .75569 L F
.947 .761 .618 r
.57461 .68099 m .57376 .68337 L .57585 .68402 L F
.835 .706 .722 r
.57376 .68337 m .57666 .6862 L .57585 .68402 L F
.519 .19 .35 r
.60081 .64545 m .60313 .64525 L .60398 .64291 L F
.579 .254 .383 r
.60313 .64525 m .6063 .64298 L .60398 .64291 L F
.438 .421 .742 r
.40728 .66835 m .40679 .67043 L .40456 .66679 L F
.40728 .66835 m .408 .67 L .40679 .67043 L F
.491 .354 .622 r
.408 .67 m .40642 .67293 L .40679 .67043 L F
.703 .634 .777 r
.68198 .58587 m .68492 .58682 L .68479 .58542 L F
.222 .404 .831 r
.68479 .58542 m .68492 .58682 L .68563 .58512 L F
.515 .255 .459 r
.68695 .5881 m .68492 .58682 L .68681 .58605 L F
.68492 .58682 m .68695 .5881 L .68563 .58512 L F
.68492 .58682 m .68467 .58859 L .68592 .58832 L F
.68492 .58682 m .68592 .58832 L .68627 .58767 L F
.588 .268 .394 r
.6908 .58562 m .68695 .5881 L .68691 .58759 L F
.68898 .58581 m .68691 .58759 L .68681 .58605 L F
.6908 .58562 m .68691 .58759 L .68898 .58581 L F
0 .174 .704 r
.68695 .5881 m .68768 .58757 L .68563 .58512 L F
.81 .506 .476 r
.68726 .5874 m .68524 .5892 L .68568 .58866 L F
.68524 .5892 m .68516 .58926 L .68521 .58921 L F
.68524 .5892 m .68521 .58921 L .68568 .58866 L F
.515 .255 .459 r
.68658 .58787 m .68568 .58838 L .68492 .58682 L F
.68568 .58838 m .68467 .58859 L .68482 .58755 L F
.68568 .58838 m .68482 .58755 L .68492 .58682 L F
.812 .61 .629 r
.68479 .58542 m .68582 .58851 L .68035 .58738 L F
.68582 .58851 m .68581 .58851 L .68035 .58738 L F
.564 .001 0 r
.68582 .58851 m .68473 .58965 L .68259 .58855 L F
.68207 .58774 m .68259 .58855 L .68035 .58738 L F
.68582 .58851 m .68259 .58855 L .68207 .58774 L F
.307 .431 .824 r
.68035 .58738 m .68473 .58965 L .68297 .58822 L F
.956 .687 .24 r
.68473 .58965 m .68398 .58771 L .68297 .58822 L F
.621 .562 .766 r
.68398 .58771 m .68317 .58944 L .68297 .58822 L F
.68317 .58944 m .68242 .59107 L .68283 .58891 L F
.68317 .58944 m .68283 .58891 L .68297 .58822 L F
.299 .339 .736 r
.68563 .58512 m .68582 .58851 L .68479 .58542 L F
.68582 .58851 m .68582 .58851 L .68479 .58542 L F
.515 .255 .459 r
.68609 .58829 m .68568 .58838 L .68658 .58787 L F
.68627 .58767 m .68592 .58832 L .68695 .5881 L F
.299 .339 .736 r
.68563 .58512 m .68726 .5874 L .68582 .58851 L F
.204 .363 .802 r
.68612 .58758 m .6847 .58871 L .68398 .58771 L F
0 .181 .685 r
.6847 .58871 m .68527 .58918 L .68398 .58771 L F
.78 .686 .76 r
.68695 .5881 m .68667 .59319 L .68471 .591 L F
.43 .384 .706 r
.68957 .59048 m .68667 .59319 L .68695 .5881 L F
0 0 0 r
.68695 .5881 m .68471 .591 L .68602 .58984 L F
.588 .268 .394 r
.6908 .58562 m .68934 .58799 L .68695 .5881 L F
.43 .384 .706 r
.68957 .59048 m .68695 .5881 L .68934 .58799 L F
.631 .625 .826 r
.68602 .58984 m .68768 .58757 L .68695 .5881 L F
.621 .636 .844 r
.68735 .59122 m .68957 .59048 L .68602 .58984 L F
.631 .625 .826 r
.68602 .58984 m .68957 .59048 L .68768 .58757 L F
.81 .506 .476 r
.68516 .58926 m .68494 .58943 L .68568 .58866 L F
.68609 .58831 m .68568 .58866 L .68582 .58852 L F
.515 .255 .459 r
.68695 .5881 m .68609 .58829 L .68658 .58787 L F
.81 .506 .476 r
.68726 .5874 m .68568 .58866 L .68609 .58831 L F
.68582 .58851 m .68582 .58852 L .68582 .58851 L F
.68726 .5874 m .68582 .58852 L .68582 .58851 L F
.299 .339 .736 r
.68582 .58851 m .68582 .58851 L .68582 .58851 L F
.812 .61 .629 r
.68582 .58851 m .68582 .58851 L .68581 .58851 L F
.81 .506 .476 r
.68516 .58926 m .68473 .58965 L .68494 .58943 L F
.68726 .5874 m .6847 .58871 L .68473 .58965 L F
.684 .347 .398 r
.68768 .58757 m .68693 .59055 L .6847 .58871 L F
.204 .363 .802 r
.68588 .58873 m .68693 .59055 L .68527 .58918 L F
0 .181 .685 r
.68527 .58918 m .68693 .59055 L .68571 .58937 L F
.68543 .58911 m .68571 .58937 L .68544 .58911 L F
.68527 .58918 m .68571 .58937 L .68543 .58911 L F
.54 .628 .888 r
.68471 .591 m .68667 .59319 L .68735 .59122 L F
.549 .616 .872 r
.68471 .591 m .68735 .59122 L .68602 .58984 L F
.709 .576 .703 r
.68509 .5906 m .68667 .59026 L .68499 .59233 L F
.68667 .59026 m .68689 .59021 L .68677 .59035 L F
.68667 .59026 m .68677 .59035 L .68499 .59233 L F
.021 .294 .789 r
.68768 .58757 m .68957 .59048 L .6896 .58892 L F
.684 .347 .398 r
.68768 .58757 m .6847 .58871 L .68726 .5874 L F
0 .262 .767 r
.68768 .58757 m .6896 .58892 L .68864 .58752 L F
.68768 .58757 m .68864 .58752 L .68693 .59055 L F
.837 .788 .805 r
.68612 .58758 m .68693 .59055 L .68864 .58752 L F
.709 .576 .703 r
.68689 .59021 m .68716 .59015 L .68697 .59034 L F
.68689 .59021 m .68697 .59034 L .68499 .59233 L F
.204 .363 .802 r
.68603 .58862 m .68653 .58969 L .68588 .58873 L F
.68653 .58969 m .68693 .59055 L .68588 .58873 L F
.68634 .58839 m .68678 .58999 L .68603 .58862 L F
.68678 .58999 m .68693 .59055 L .68603 .58862 L F
.631 .729 .918 r
.68735 .59122 m .68667 .59319 L .68957 .59048 L F
.546 .457 .705 r
.68821 .59145 m .68767 .5916 L .68716 .59015 L F
.68767 .5916 m .68499 .59233 L .68697 .59034 L F
.68767 .5916 m .68697 .59034 L .68716 .59015 L F
.204 .363 .802 r
.68612 .58758 m .68634 .58839 L .6847 .58871 L F
0 .181 .685 r
.68527 .58918 m .68544 .58911 L .68398 .58771 L F
.204 .363 .802 r
.68634 .58839 m .68527 .58918 L .6847 .58871 L F
.515 .271 .483 r
.61137 .70275 m .61104 .70544 L .60873 .7059 L F
.461 .21 .446 r
.61311 .7025 m .61104 .70544 L .61137 .70275 L F
.552 .446 .688 r
.58328 .7104 m .58608 .70799 L .58442 .70853 L F
.683 .173 .021 r
.31445 .7414 m .31131 .74134 L .31132 .74046 L F
.098 .347 .817 r
.31478 .74007 m .31445 .7414 L .31326 .73922 L F
.671 .934 .968 r
.31478 .74007 m .31131 .74134 L .31445 .7414 L F
.586 .552 .783 r
.54991 .7117 m .5507 .71523 L .55326 .71349 L F
.528 .406 .658 r
.5507 .71523 m .55373 .71637 L .55326 .71349 L F
.5507 .71523 m .55164 .71703 L .55373 .71637 L F
.253 0 .047 r
.71276 .72221 m .71104 .7242 L .70911 .72448 L F
.394 0 .147 r
.71334 .72365 m .71276 .72221 L .71446 .72274 L F
.71334 .72365 m .71104 .7242 L .71276 .72221 L F
.551 .416 .65 r
.38853 .75793 m .39064 .75767 L .39036 .75448 L F
.589 .486 .705 r
.38853 .75793 m .39114 .75977 L .39064 .75767 L F
.38853 .75793 m .38895 .76012 L .39114 .75977 L F
.903 .76 .693 r
.64269 .6432 m .64184 .63972 L .6403 .64296 L F
.891 .789 .741 r
.64096 .64596 m .64269 .6432 L .6403 .64296 L F
.914 .978 .713 r
.68368 .59304 m .6813 .59694 L .68028 .5959 L F
.68368 .59304 m .68234 .59527 L .6813 .59694 L F
.482 .102 .242 r
.68372 .59696 m .68601 .59669 L .68606 .59806 L F
.096 .356 .824 r
.68265 .59505 m .68372 .59696 L .68606 .59806 L F
.674 .129 0 r
.68343 .59618 m .68265 .59505 L .6851 .59749 L F
.914 .978 .713 r
.68215 .59433 m .68028 .5959 L .68265 .59505 L F
.577 .65 .886 r
.6813 .59694 m .68265 .59505 L .68028 .5959 L F
.6813 .59694 m .68372 .59696 L .68265 .59505 L F
.46 .886 .893 r
.6818 .59491 m .68265 .59505 L .68028 .5959 L F
.6818 .59491 m .68265 .59505 L .68028 .5959 L F
.674 .129 0 r
.6818 .59491 m .68265 .59505 L .68343 .59618 L F
.914 .978 .713 r
.68368 .59304 m .68215 .59433 L .68265 .59505 L F
.585 .633 .865 r
.68523 .59262 m .68368 .59304 L .68265 .59505 L F
.377 0 .081 r
.47118 .73631 m .47435 .73509 L .47389 .73694 L F
.415 0 .129 r
.47435 .73509 m .47525 .73682 L .47389 .73694 L F
.47435 .73509 m .47651 .73497 L .47525 .73682 L F
.855 .541 .456 r
.66038 .59595 m .6619 .59413 L .66017 .59457 L F
.66038 .59595 m .66306 .59569 L .6619 .59413 L F
.685 .776 .92 r
.70043 .60594 m .69721 .60555 L .69943 .60442 L F
.691 .718 .87 r
.70264 .60509 m .70043 .60594 L .69943 .60442 L F
.534 .386 .626 r
.54616 .73017 m .54424 .733 L .54438 .72983 L F
.874 .74 .712 r
.64207 .62658 m .64514 .62456 L .64368 .62367 L F
.64207 .62658 m .64467 .62628 L .64514 .62456 L F
.217 .438 .861 r
.71126 .73283 m .71262 .73198 L .71031 .73296 L F
.71126 .73283 m .71324 .73392 L .71262 .73198 L F
.495 .367 .635 r
.4157 .75968 m .41452 .76231 L .41524 .76273 L F
.426 0 0 r
.36671 .67019 m .36522 .67079 L .36313 .67056 L F
.526 0 0 r
.36671 .67019 m .36755 .67112 L .36522 .67079 L F
.36671 .67019 m .36856 .67151 L .36755 .67112 L F
0 0 0 r
.59503 .66372 m .594 .66486 L .59641 .66205 L F
.528 .821 .484 r
.59503 .66372 m .59314 .66578 L .594 .66486 L F
.536 .311 .521 r
.31989 .6895 m .31964 .69224 L .31723 .69203 L F
.545 .319 .523 r
.32192 .69164 m .31989 .6895 L .32174 .68912 L F
.32192 .69164 m .31964 .69224 L .31989 .6895 L F
.772 .677 .758 r
.50734 .72179 m .50855 .72487 L .50523 .7245 L F
.457 .048 .175 r
.50855 .72487 m .50514 .72689 L .50523 .7245 L F
.50855 .72487 m .50752 .72666 L .50514 .72689 L F
.254 0 .069 r
.50947 .7261 m .50855 .72487 L .51071 .72448 L F
.76 .664 .756 r
.51166 .72335 m .51297 .72658 L .50947 .7261 L F
.753 .684 .785 r
.51297 .72658 m .51056 .72897 L .50947 .7261 L F
0 0 .482 r
.50947 .7261 m .51059 .72712 L .512 .72613 L F
.482 .825 .998 r
.512 .72613 m .5098 .72623 L .50947 .7261 L F
.254 0 .069 r
.50947 .7261 m .50752 .72666 L .50815 .72556 L F
.781 .697 .772 r
.50947 .7261 m .50729 .72885 L .50752 .72666 L F
.50947 .7261 m .51056 .72897 L .50729 .72885 L F
.482 .825 .998 r
.50761 .72634 m .50734 .72635 L .50947 .7261 L F
.765 .772 .858 r
.50947 .7261 m .50734 .72635 L .50621 .72607 L F
.653 .812 .96 r
.50621 .72607 m .50734 .72635 L .50736 .72626 L F
.254 0 .069 r
.50947 .7261 m .50815 .72556 L .50855 .72487 L F
.76 .664 .756 r
.51166 .72335 m .50947 .7261 L .51071 .72448 L F
.563 .652 .895 r
.50743 .72627 m .51143 .72543 L .50968 .72414 L F
.50734 .72635 m .50747 .72632 L .50743 .72627 L F
.536 .349 .574 r
.50773 .72632 m .50947 .7261 L .50725 .72608 L F
.563 .652 .895 r
.50747 .72632 m .51143 .72543 L .50743 .72627 L F
.536 .349 .574 r
.50741 .72626 m .50725 .72608 L .50651 .72607 L F
.50773 .72632 m .50725 .72608 L .50741 .72626 L F
.50736 .72626 m .50651 .72607 L .50621 .72607 L F
.50773 .72632 m .50651 .72607 L .50736 .72626 L F
.563 .652 .895 r
.50736 .72626 m .50968 .72414 L .50774 .72433 L F
.50734 .72635 m .50743 .72627 L .50736 .72626 L F
.50743 .72627 m .50968 .72414 L .50736 .72626 L F
.653 .812 .96 r
.50621 .72607 m .50736 .72626 L .50774 .72433 L F
.536 .349 .574 r
.50637 .7265 m .50773 .72632 L .50621 .72607 L F
.575 .345 .53 r
.50752 .72666 m .50729 .72885 L .50514 .72689 L F
.536 .349 .574 r
.50916 .7265 m .50947 .7261 L .50761 .72634 L F
.482 .825 .998 r
.5098 .72623 m .50761 .72634 L .50947 .7261 L F
.738 .576 0 r
.51056 .72897 m .51051 .72899 L .50729 .72885 L F
.536 .349 .574 r
.50729 .72885 m .51051 .72899 L .50959 .72642 L F
.50916 .7265 m .50959 .72642 L .50947 .7261 L F
.50729 .72885 m .50959 .72642 L .50916 .7265 L F
0 0 .482 r
.50965 .72626 m .51051 .72899 L .51055 .72803 L F
.5104 .72768 m .51055 .72803 L .51055 .72797 L F
.50965 .72626 m .51055 .72803 L .5104 .72768 L F
.50959 .72642 m .51051 .72899 L .50965 .72626 L F
.536 .349 .574 r
.50729 .72885 m .50916 .7265 L .50637 .7265 L F
.217 .49 .898 r
.50514 .72689 m .50424 .72536 L .50523 .7245 L F
.50514 .72689 m .50621 .72607 L .50424 .72536 L F
.108 .289 .765 r
.50514 .72689 m .50729 .72885 L .50621 .72607 L F
.768 .392 .342 r
.51059 .7281 m .5072 .72909 L .50515 .72654 L F
.659 .777 .936 r
.51141 .72809 m .51051 .72899 L .51145 .72814 L F
.77 .611 .682 r
.5105 .72775 m .5107 .72799 L .51055 .72797 L F
.659 .777 .936 r
.51059 .72712 m .51055 .72797 L .51141 .72809 L F
.51055 .72797 m .51051 .72899 L .51141 .72809 L F
.77 .611 .682 r
.51055 .72797 m .51085 .72818 L .51059 .7281 L F
.5107 .72799 m .51085 .72818 L .51055 .72797 L F
.768 .392 .342 r
.51085 .72818 m .51064 .72823 L .51059 .7281 L F
.51064 .72823 m .5072 .72909 L .51059 .7281 L F
.482 .825 .998 r
.50967 .72623 m .50985 .72579 L .50747 .72632 L F
.50761 .72634 m .50747 .72632 L .50734 .72635 L F
.512 .72613 m .50747 .72632 L .50761 .72634 L F
.536 .349 .574 r
.50916 .7265 m .50761 .72634 L .50637 .7265 L F
.128 0 .011 r
.50515 .72654 m .50424 .72536 L .50621 .72607 L F
.77 .611 .682 r
.50774 .72433 m .50515 .72654 L .50621 .72607 L F
.50774 .72433 m .5105 .72775 L .50515 .72654 L F
.5105 .72775 m .51059 .7281 L .50515 .72654 L F
.217 .417 .844 r
.51059 .72712 m .51085 .72818 L .5105 .72775 L F
0 0 .482 r
.5103 .72686 m .5105 .72775 L .51059 .72712 L F
.50965 .72626 m .51055 .72797 L .5103 .72686 L F
.50947 .7261 m .50959 .72642 L .50965 .72626 L F
.92 .866 .769 r
.51347 .72656 m .51056 .72897 L .51297 .72658 L F
.51347 .72656 m .51186 .72983 L .51056 .72897 L F
.722 .798 .911 r
.51059 .72712 m .51145 .72814 L .51409 .72746 L F
.623 .274 .357 r
.51293 .7278 m .51228 .72811 L .51059 .72712 L F
.217 .417 .844 r
.51059 .72712 m .5105 .72775 L .50948 .72648 L F
0 0 .482 r
.5105 .72775 m .51055 .72797 L .51059 .72712 L F
.626 .178 .166 r
.51518 .72999 m .514 .73135 L .51186 .72983 L F
.706 .725 .865 r
.51051 .72899 m .51305 .73029 L .51145 .72814 L F
.522 .534 .809 r
.51305 .73029 m .51409 .72746 L .51145 .72814 L F
.639 .292 .366 r
.51059 .72712 m .5072 .72909 L .51085 .72818 L F
.623 .274 .357 r
.51228 .72811 m .50924 .72955 L .51059 .72712 L F
.217 .417 .844 r
.51059 .72712 m .50948 .72648 L .50774 .72433 L F
.482 .825 .998 r
.51086 .72618 m .51143 .72543 L .50985 .72579 L F
.51086 .72618 m .50985 .72579 L .50967 .72623 L F
.512 .72613 m .51188 .72598 L .51086 .72618 L F
.51188 .72598 m .51143 .72543 L .51086 .72618 L F
.346 0 .214 r
.36459 .7002 m .36548 .70184 L .36662 .69973 L F
.36459 .7002 m .36356 .70234 L .36548 .70184 L F
.897 .964 .64 r
.71438 .73546 m .71568 .73203 L .71324 .73392 L F
.71438 .73546 m .7142 .7355 L .71568 .73203 L F
.956 .746 .579 r
.71438 .73546 m .7171 .73336 L .7142 .7355 L F
.315 .184 .538 r
.63645 .61779 m .63452 .61636 L .63393 .61776 L F
.63645 .61779 m .6364 .61553 L .63452 .61636 L F
.384 .394 .747 r
.41688 .7636 m .41793 .76754 L .41566 .76564 L F
.455 .399 .707 r
.41566 .76564 m .41793 .76754 L .41608 .76787 L F
.642 .665 .857 r
.72986 .58553 m .73003 .58694 L .72693 .58616 L F
.486 .546 .843 r
.72986 .58553 m .7316 .58499 L .73003 .58694 L F
.589 .7 .92 r
.7316 .58499 m .73227 .58658 L .73003 .58694 L F
.669 .178 .074 r
.48399 .78128 m .48713 .78174 L .48559 .78201 L F
.175 0 0 r
.48713 .78174 m .48828 .78204 L .48559 .78201 L F
.48713 .78174 m .48917 .78218 L .48828 .78204 L F
.547 .371 .595 r
.33727 .71025 m .3358 .71265 L .3381 .70985 L F
.821 .799 .831 r
.72693 .58616 m .72384 .58616 L .72575 .58365 L F
.639 .716 .903 r
.72986 .58553 m .72693 .58616 L .72575 .58365 L F
.498 .172 .345 r
.6364 .61553 m .63917 .6131 L .63689 .61323 L F
.687 .224 .148 r
.5777 .74654 m .58 .74823 L .58121 .74707 L F
0 0 0 r
.58121 .74707 m .58233 .74648 L .58344 .7466 L F
.58121 .74707 m .58 .74823 L .58233 .74648 L F
.338 .815 .89 r
.71446 .72357 m .71334 .72365 L .71446 .72274 L F
.266 0 0 r
.71712 .72212 m .71446 .72357 L .71446 .72274 L F
.692 .35 .392 r
.54424 .733 m .54111 .73454 L .54077 .73278 L F
.54424 .733 m .54322 .73543 L .54111 .73454 L F
.534 .386 .626 r
.54616 .73017 m .54671 .73255 L .54424 .733 L F
.665 .32 .38 r
.54673 .73517 m .54424 .733 L .54671 .73255 L F
.54673 .73517 m .54322 .73543 L .54424 .733 L F
.003 0 0 r
.73066 .59556 m .73174 .59514 L .73396 .59495 L F
.209 0 0 r
.4949 .78366 m .49149 .78271 L .49268 .78279 L F
.51 .552 .835 r
.39349 .65925 m .3931 .66269 L .39148 .65929 L F
.39349 .65925 m .39525 .66266 L .3931 .66269 L F
.961 .678 .452 r
.57621 .72949 m .57643 .73195 L .57753 .73023 L F
.852 .872 .854 r
.57621 .72949 m .57753 .73023 L .57984 .72758 L F
.741 .344 .3 r
.57643 .73195 m .57952 .73248 L .57753 .73023 L F
0 0 0 r
.41207 .79207 m .41174 .79232 L .40995 .79316 L F
.69 .687 .842 r
.38851 .7876 m .39268 .79 L .3914 .78696 L F
.484 .523 .822 r
.3914 .78696 m .39268 .79 L .39439 .78941 L F
0 0 .54 r
.39268 .79 m .39389 .79087 L .39439 .78941 L F
.679 .774 .922 r
.32158 .71078 m .31797 .71032 L .32024 .70864 L F
.588 .698 .919 r
.32368 .71032 m .32158 .71078 L .32024 .70864 L F
0 0 .039 r
.66816 .594 m .66767 .59699 L .66819 .59565 L F
.66816 .594 m .66819 .59565 L .66801 .59325 L F
.568 .662 .901 r
.33893 .84161 m .33542 .83982 L .33706 .83942 L F
.308 0 .026 r
.33531 .84381 m .33893 .84161 L .33655 .84183 L F
.155 .437 .872 r
.33952 .84065 m .33893 .84161 L .33706 .83942 L F
.572 .932 .935 r
.33655 .84183 m .33893 .84161 L .33952 .84065 L F
.316 .359 .748 r
.52932 .73044 m .53064 .72895 L .52853 .72747 L F
.354 .417 .788 r
.52932 .73044 m .53185 .73243 L .53064 .72895 L F
.561 0 0 r
.56832 .70049 m .56735 .70013 L .56461 .69811 L F
.609 .469 .666 r
.38888 .77379 m .3869 .77646 L .3892 .77616 L F
.492 .418 .701 r
.3869 .77646 m .38927 .77854 L .3892 .77616 L F
.3869 .77646 m .3875 .77914 L .38927 .77854 L F
.478 .06 .167 r
.52305 .79042 m .52019 .7925 L .51951 .79223 L F
.627 .962 .86 r
.52395 .78925 m .52305 .79042 L .52464 .78932 L F
.625 .935 .702 r
.52395 .78925 m .52019 .7925 L .52305 .79042 L F
.321 0 0 r
.45594 .78168 m .45448 .78301 L .45223 .78319 L F
.367 0 0 r
.45594 .78168 m .45676 .78281 L .45448 .78301 L F
.45594 .78168 m .4581 .78168 L .45676 .78281 L F
.096 0 .169 r
.63084 .676 m .63246 .67518 L .63022 .67788 L F
.616 .327 .455 r
.42721 .73188 m .42991 .73021 L .42773 .73051 L F
.481 .212 .428 r
.31642 .6623 m .3185 .6619 L .31904 .65983 L F
.337 .082 .372 r
.31904 .65983 m .32027 .66114 L .32101 .65938 L F
.31904 .65983 m .3185 .6619 L .32027 .66114 L F
.476 .187 .395 r
.33431 .68102 m .33173 .68316 L .33222 .6813 L F
.749 .651 .753 r
.5822 .7251 m .58553 .72532 L .584 .72409 L F
.686 .612 .767 r
.5822 .7251 m .58531 .72747 L .58553 .72532 L F
.669 .656 .828 r
.584 .72409 m .58553 .72532 L .58801 .72496 L F
.654 .504 .667 r
.58553 .72532 m .58531 .72747 L .58801 .72496 L F
.478 .342 .618 r
.59403 .71645 m .59415 .71882 L .59225 .71923 L F
.533 .394 .638 r
.59449 .72134 m .59225 .71923 L .59415 .71882 L F
.59449 .72134 m .59246 .72179 L .59225 .71923 L F
.632 .407 .558 r
.42083 .7542 m .41874 .75451 L .41956 .75236 L F
.47 .743 .988 r
.52717 .71379 m .52627 .71495 L .52535 .71294 L F
.52717 .71379 m .52825 .71473 L .52627 .71495 L F
.503 .573 .859 r
.52896 .7157 m .52627 .71495 L .52825 .71473 L F
.604 .482 .687 r
.41879 .77071 m .41608 .76787 L .41793 .76754 L F
.41879 .77071 m .41655 .7712 L .41608 .76787 L F
.161 0 0 r
.3483 .7243 m .34697 .72407 L .34975 .72266 L F
.108 0 0 r
.35011 .72363 m .34975 .72266 L .35173 .72201 L F
.35011 .72363 m .3483 .7243 L .34975 .72266 L F
.547 .921 .775 r
.56422 .67487 m .56715 .67306 L .56766 .67302 L F
.5 .848 .583 r
.57022 .67085 m .56766 .67302 L .56886 .67191 L F
.543 .92 .776 r
.56766 .67302 m .56715 .67306 L .56886 .67191 L F
.316 .031 .312 r
.42637 .7492 m .42543 .75169 L .42397 .75167 L F
.585 .293 .438 r
.42821 .751 m .42637 .7492 L .42852 .74894 L F
.42821 .751 m .42543 .75169 L .42637 .7492 L F
.627 .389 .537 r
.31723 .69203 m .3166 .69463 L .31456 .69471 L F
.627 .388 .537 r
.31962 .69435 m .31723 .69203 L .31964 .69224 L F
.31962 .69435 m .3166 .69463 L .31723 .69203 L F
.782 .441 .41 r
.4357 .74699 m .43627 .74897 L .4329 .74822 L F
.67 .407 .514 r
.5818 .71302 m .58328 .7104 L .58204 .71101 L F
.5818 .71302 m .58418 .71339 L .58328 .7104 L F
.552 .446 .688 r
.58328 .7104 m .58676 .71084 L .58608 .70799 L F
.505 .312 .553 r
.58328 .7104 m .5863 .71282 L .58676 .71084 L F
.58328 .7104 m .58418 .71339 L .5863 .71282 L F
.161 0 0 r
.3483 .7243 m .3463 .7249 L .34697 .72407 L F
.71 .986 .857 r
.39044 .79756 m .38654 .80031 L .38623 .79993 L F
.447 .005 .103 r
.47613 .72392 m .47835 .72391 L .47963 .72223 L F
.234 0 0 r
.47835 .72391 m .48189 .72198 L .47963 .72223 L F
.624 .264 .339 r
.33452 .71022 m .3381 .70985 L .3358 .71265 L F
.678 .468 .594 r
.3358 .71265 m .336 .71428 L .33853 .71251 L F
.3358 .71265 m .33836 .71252 L .33882 .71264 L F
.273 0 .263 r
.33853 .71251 m .3383 .71391 L .34006 .71294 L F
.678 .468 .594 r
.33836 .71252 m .33853 .71251 L .33882 .71264 L F
.227 0 0 r
.33882 .71264 m .34006 .71294 L .33985 .71292 L F
.449 .118 .311 r
.336 .71428 m .3383 .71391 L .33853 .71251 L F
.227 0 0 r
.33882 .71264 m .33985 .71292 L .33655 .71256 L F
0 0 .353 r
.33655 .71256 m .3358 .71265 L .33882 .71264 L F
.33655 .71256 m .336 .71428 L .3358 .71265 L F
.682 .491 .622 r
.69495 .70252 m .69812 .70522 L .69816 .70368 L F
.71 .986 .857 r
.38854 .79863 m .38623 .79993 L .38738 .79944 L F
.908 .689 .594 r
.38315 .79808 m .38307 .8002 L .38122 .80029 L F
.59 .016 0 r
.38254 .7983 m .38623 .79993 L .38315 .79808 L F
.417 .713 .985 r
.38738 .79944 m .38623 .79993 L .38254 .7983 L F
.572 .589 .831 r
.3856 .79913 m .38664 .79996 L .38738 .79944 L F
.956 .796 .643 r
.38806 .80267 m .38879 .80042 L .38738 .79944 L F
.38806 .80267 m .38738 .79944 L .38878 .80168 L F
.572 .589 .831 r
.38664 .79996 m .38878 .80168 L .38738 .79944 L F
.71 .986 .857 r
.39044 .79756 m .38854 .79863 L .38738 .79944 L F
.696 .372 0 r
.39044 .79756 m .38952 .79513 L .38786 .79547 L F
.39044 .79756 m .39041 .79759 L .38952 .79513 L F
.899 .851 .787 r
.38738 .79944 m .39041 .79759 L .39044 .79756 L F
.45 0 0 r
.64352 .61193 m .64515 .61075 L .64181 .61103 L F
.36 0 0 r
.64181 .61103 m .64515 .61075 L .64357 .61113 L F
.765 .696 .786 r
.64515 .61075 m .64394 .60785 L .64357 .61113 L F
.64515 .61075 m .64743 .60873 L .64394 .60785 L F
.58 .049 0 r
.6462 .61202 m .64515 .61075 L .64352 .61193 L F
.817 .654 .681 r
.62113 .65703 m .61776 .65901 L .61773 .65669 L F
.62113 .65703 m .62054 .65935 L .61776 .65901 L F
.576 .416 .628 r
.38901 .76253 m .39114 .75977 L .38895 .76012 L F
0 0 0 r
.59883 .65963 m .59776 .66117 L .59641 .66205 L F
.59776 .66117 m .59503 .66372 L .59641 .66205 L F
.519 .146 .272 r
.43492 .72938 m .43841 .72715 L .43542 .72794 L F
.43492 .72938 m .4372 .7293 L .43841 .72715 L F
.468 .072 .204 r
.4372 .7293 m .44065 .72718 L .43841 .72715 L F
.681 .67 .832 r
.69615 .61373 m .69958 .61575 L .69842 .61285 L F
.585 .61 .844 r
.69958 .61575 m .70066 .61246 L .69842 .61285 L F
.69958 .61575 m .70179 .61527 L .70066 .61246 L F
.595 .619 .846 r
.69958 .61575 m .70282 .61713 L .70179 .61527 L F
.654 .654 .838 r
.7188 .73017 m .71585 .72908 L .71801 .72894 L F
.84 .955 .888 r
.7181 .7312 m .71592 .7336 L .7171 .73336 L F
.726 .69 .816 r
.71568 .73203 m .7142 .7355 L .7181 .7312 L F
.237 0 0 r
.7188 .73017 m .71808 .73146 L .71568 .73203 L F
.577 .584 .824 r
.71568 .73203 m .71703 .73171 L .7171 .73045 L F
.71568 .73203 m .7171 .73045 L .7165 .73033 L F
.995 .763 .416 r
.71519 .72961 m .71568 .73203 L .71574 .7309 L F
.71519 .72961 m .71574 .7309 L .71585 .72908 L F
.769 .286 .088 r
.71231 .72711 m .71519 .72961 L .71585 .72908 L F
.528 .65 .912 r
.71449 .72798 m .71519 .72961 L .71353 .72763 L F
0 0 0 r
.71585 .72908 m .71719 .72893 L .71801 .72894 L F
.71585 .72908 m .71519 .72961 L .71719 .72893 L F
.528 .65 .912 r
.71719 .72893 m .71519 .72961 L .71449 .72798 L F
.773 .816 .886 r
.71262 .73198 m .71324 .73392 L .71568 .73203 L F
.817 .7 .735 r
.71519 .72961 m .71262 .73198 L .71568 .73203 L F
.577 .584 .824 r
.71568 .73203 m .71719 .72893 L .71519 .72961 L F
.639 .401 .542 r
.71478 .72998 m .71626 .73227 L .71262 .73198 L F
.71519 .72961 m .71539 .73011 L .71478 .72998 L F
.71539 .73011 m .71626 .73227 L .71478 .72998 L F
.577 .584 .824 r
.7165 .73033 m .7171 .73045 L .71719 .72893 L F
.71703 .73171 m .71808 .73146 L .71774 .73049 L F
.71703 .73171 m .71774 .73049 L .71719 .72893 L F
.84 .955 .888 r
.71592 .7336 m .7142 .7355 L .71527 .73471 L F
.71592 .7336 m .71527 .73471 L .7171 .73336 L F
.681 .53 .674 r
.64585 .60266 m .64808 .60261 L .64829 .60021 L F
.772 .465 .467 r
.66055 .6099 m .66351 .60835 L .66208 .6075 L F
.66055 .6099 m .66383 .61023 L .66351 .60835 L F
.541 .408 .649 r
.39642 .7437 m .39829 .74104 L .39619 .74143 L F
.52 .431 .695 r
.41879 .77071 m .41722 .77307 L .41655 .7712 L F
.41879 .77071 m .41927 .773 L .41722 .77307 L F
.524 .537 .812 r
.42038 .77562 m .41722 .77307 L .41927 .773 L F
.398 0 .089 r
.34258 .6768 m .34144 .67781 L .33964 .67781 L F
.244 0 .018 r
.34453 .6761 m .34144 .67781 L .34258 .6768 L F
.902 .88 .803 r
.57726 .70765 m .57507 .71097 L .57671 .71136 L F
.951 .712 .541 r
.57507 .71097 m .57647 .71383 L .57671 .71136 L F
.678 .612 .774 r
.31249 .71037 m .31044 .71134 L .3091 .7082 L F
.553 .428 .665 r
.38722 .76549 m .38948 .76511 L .38901 .76253 L F
.555 .448 .687 r
.38722 .76549 m .38978 .7679 L .38948 .76511 L F
.38722 .76549 m .38769 .76831 L .38978 .7679 L F
.684 .466 .584 r
.64015 .60695 m .64394 .60785 L .64357 .60502 L F
.582 .394 .592 r
.64357 .60502 m .64596 .6051 L .64585 .60266 L F
.64357 .60502 m .64394 .60785 L .64596 .6051 L F
.631 .859 .488 r
.3925 .79478 m .39041 .79759 L .39059 .79747 L F
.226 .319 .751 r
.307 .73822 m .30605 .73503 L .30442 .73569 L F
.537 .379 .614 r
.39442 .74645 m .39651 .74608 L .39642 .7437 L F
.546 .378 .604 r
.39442 .74645 m .39658 .7485 L .39651 .74608 L F
.39442 .74645 m .39446 .74891 L .39658 .7485 L F
.812 .678 .716 r
.6441 .63523 m .64328 .63158 L .64099 .63452 L F
.6441 .63523 m .64445 .63288 L .64328 .63158 L F
.857 .617 .575 r
.64341 .63737 m .6441 .63523 L .64099 .63452 L F
.189 .686 .916 r
.51218 .78489 m .51496 .78493 L .51635 .78544 L F
.592 .898 .987 r
.51635 .78544 m .51707 .78424 L .51824 .78443 L F
.51635 .78544 m .51496 .78493 L .51707 .78424 L F
.874 .764 .738 r
.64291 .62957 m .64467 .62628 L .64207 .62658 L F
0 .297 .76 r
.54381 .72498 m .54588 .72668 L .54477 .72548 L F
.521 .256 .453 r
.59646 .75181 m .59593 .75459 L .59367 .75481 L F
.593 .43 .63 r
.59863 .74923 m .59869 .75142 L .59646 .75181 L F
.471 .186 .399 r
.59869 .75142 m .59593 .75459 L .59646 .75181 L F
.229 .34 .77 r
.67141 .61577 m .67387 .61852 L .67254 .61505 L F
.858 .67 .648 r
.64328 .63158 m .64445 .63288 L .64291 .62957 L F
.108 0 0 r
.70726 .73106 m .70341 .73072 L .70439 .73071 L F
.415 .443 .781 r
.69029 .71585 m .69128 .719 L .69301 .71899 L F
.37 .398 .759 r
.69128 .719 m .69369 .72231 L .69301 .71899 L F
.443 .273 .555 r
.41874 .75451 m .4183 .75693 L .41638 .75736 L F
.539 .365 .594 r
.4183 .75693 m .4157 .75968 L .41638 .75736 L F
.632 .569 .766 r
.5611 .7053 m .55806 .70642 L .55744 .70327 L F
.52 .35 .591 r
.5611 .7053 m .55842 .70833 L .55806 .70642 L F
.406 .248 .551 r
.30704 .60754 m .30677 .60925 L .30511 .60926 L F
.561 .462 .699 r
.30677 .60925 m .3054 .61313 L .30511 .60926 L F
.577 .765 .968 r
.42571 .77635 m .4237 .77683 L .42235 .77559 L F
.257 0 .265 r
.32367 .65623 m .32455 .65802 L .3253 .65657 L F
.32367 .65623 m .32287 .65879 L .32455 .65802 L F
.918 .975 .772 r
.72264 .73277 m .72112 .73329 L .72359 .72993 L F
.733 .367 .358 r
.72264 .73277 m .72108 .73456 L .72112 .73329 L F
.471 .208 .433 r
.29676 .67614 m .29851 .6776 L .29907 .67591 L F
.29676 .67614 m .29649 .67803 L .29851 .6776 L F
.443 0 0 r
.37213 .67044 m .37057 .67172 L .36856 .67151 L F
.522 .57 .845 r
.37213 .67044 m .37553 .67318 L .37434 .66976 L F
.046 0 0 r
.37261 .67098 m .37213 .67044 L .37434 .66976 L F
.37261 .67098 m .37057 .67172 L .37213 .67044 L F
.124 .639 .891 r
.35825 .64887 m .36026 .64904 L .36192 .6496 L F
.383 .776 .988 r
.36263 .64874 m .36192 .6496 L .36026 .64904 L F
.36263 .64874 m .36393 .64941 L .36192 .6496 L F
.113 .344 .811 r
.7382 .59297 m .73713 .5939 L .73583 .59121 L F
.68 .232 .179 r
.73617 .59562 m .73713 .5939 L .73949 .596 L F
.063 .254 .747 r
.73949 .596 m .73713 .5939 L .7382 .59297 L F
.69 .721 .873 r
.70506 .61616 m .70862 .61694 L .70739 .61526 L F
.671 .712 .879 r
.70862 .61694 m .71067 .61603 L .70739 .61526 L F
.352 .632 .958 r
.30379 .73296 m .30443 .73205 L .30284 .73201 L F
.30284 .73201 m .30443 .73205 L .30268 .73185 L F
.186 .64 .941 r
.30268 .73185 m .30443 .73205 L .30322 .73128 L F
.614 .206 .247 r
.30267 .73372 m .30443 .73205 L .30322 .73128 L F
.30267 .73372 m .30316 .73377 L .30472 .73203 L F
.30419 .73228 m .30468 .73206 L .30443 .73205 L F
.30303 .73339 m .30429 .73238 L .30419 .73228 L F
.30429 .73238 m .30468 .73206 L .30419 .73228 L F
.30304 .73341 m .30468 .73206 L .30303 .73339 L F
.557 .381 .597 r
.30322 .73128 m .30316 .73377 L .30435 .73244 L F
.614 .206 .247 r
.30468 .73206 m .30472 .73203 L .30443 .73205 L F
.38 .759 .99 r
.30443 .73205 m .30472 .73203 L .30322 .73128 L F
.30443 .73205 m .30472 .73203 L .30322 .73128 L F
.557 .381 .597 r
.30322 .73128 m .30435 .73244 L .30472 .73203 L F
0 .001 .505 r
.3041 .73215 m .30533 .73341 L .30322 .73128 L F
.897 .741 .681 r
.30472 .73203 m .30605 .73503 L .30657 .73291 L F
0 .001 .505 r
.30533 .73341 m .30544 .73353 L .30523 .73332 L F
.30533 .73341 m .30523 .73332 L .30322 .73128 L F
.557 .381 .597 r
.30322 .73128 m .30544 .73353 L .30316 .73377 L F
0 .001 .505 r
.3041 .73215 m .30322 .73128 L .30316 .73357 L F
.30322 .73366 m .30316 .73357 L .30316 .73377 L F
.3041 .73215 m .30316 .73357 L .30322 .73366 L F
.614 .206 .247 r
.30267 .73372 m .30304 .73341 L .30303 .73339 L F
.461 .276 .542 r
.37123 .69225 m .37311 .69183 L .37324 .68941 L F
.495 .382 .654 r
.37123 .69225 m .37343 .69431 L .37311 .69183 L F
.552 .383 .606 r
.37128 .69466 m .37343 .69431 L .37123 .69225 L F
.802 .362 0 r
.57191 .71928 m .57288 .72117 L .57374 .72193 L F
.967 .755 .317 r
.57304 .72218 m .57374 .72193 L .57288 .72117 L F
.57304 .72218 m .57364 .72414 L .57374 .72193 L F
.682 .491 .622 r
.69495 .70252 m .69654 .70587 L .69812 .70522 L F
.664 .457 .595 r
.64585 .60266 m .64817 .60412 L .64808 .60261 L F
.64585 .60266 m .64596 .6051 L .64817 .60412 L F
.676 .229 .181 r
.57248 .69757 m .57488 .69922 L .57631 .69792 L F
.403 .027 .208 r
.57488 .69922 m .57646 .6976 L .57631 .69792 L F
.665 .52 .678 r
.59829 .69505 m .60091 .69695 L .60058 .695 L F
.573 .409 .621 r
.40896 .66214 m .40746 .66504 L .40747 .66247 L F
.40896 .66214 m .40746 .66504 L .40747 .66247 L F
.781 .669 .74 r
.64394 .60785 m .64743 .60873 L .64596 .6051 L F
.588 .571 .802 r
.64596 .6051 m .64743 .60873 L .6476 .60678 L F
.347 0 .117 r
.601 .65881 m .59776 .66117 L .59883 .65963 L F
.706 .658 .799 r
.67949 .61593 m .67691 .61827 L .6774 .61649 L F
0 0 .438 r
.67789 .62046 m .67734 .61973 L .67691 .61827 L F
0 0 .518 r
.67734 .61973 m .67762 .61947 L .67665 .61883 L F
.67734 .61973 m .67665 .61883 L .6749 .61766 L F
0 0 .438 r
.67794 .62058 m .67734 .61973 L .67789 .62046 L F
.859 .408 .036 r
.67691 .61827 m .67918 .62137 L .67794 .62058 L F
.889 .738 .688 r
.68812 .62059 m .68951 .62165 L .68846 .6185 L F
.815 .813 .849 r
.68626 .62303 m .68951 .62165 L .68812 .62059 L F
.78 .689 .764 r
.68846 .6185 m .68951 .62165 L .69168 .6189 L F
.299 0 .206 r
.42543 .75169 m .42296 .75366 L .42397 .75167 L F
.454 .098 .271 r
.5881 .70506 m .59106 .70322 L .58847 .70325 L F
.418 .416 .751 r
.55498 .7226 m .55617 .72498 L .55533 .7214 L F
.395 .755 .993 r
.28379 .5997 m .28328 .6007 L .28173 .59979 L F
.28379 .5997 m .28537 .60059 L .28328 .6007 L F
.358 .138 .438 r
.38786 .79547 m .38952 .79513 L .38996 .79242 L F
.737 .363 .344 r
.3925 .79478 m .38996 .79242 L .38952 .79513 L F
.786 .666 .73 r
.68846 .6185 m .69168 .6189 L .69054 .61557 L F
.728 .636 .755 r
.69054 .61557 m .69168 .6189 L .69395 .61616 L F
.685 .804 .938 r
.35777 .90544 m .35868 .90664 L .35519 .90643 L F
.613 .127 .074 r
.35519 .90643 m .35868 .90664 L .35692 .90734 L F
.179 .518 .917 r
.35933 .90587 m .35868 .90664 L .35777 .90544 L F
.542 .922 .793 r
.35692 .90734 m .35868 .90664 L .35933 .90587 L F
.757 .929 .944 r
.70687 .58602 m .70509 .58734 L .70302 .58694 L F
.547 .315 .515 r
.31429 .69686 m .31224 .69755 L .31243 .69497 L F
.558 .315 .503 r
.31456 .69471 m .31429 .69686 L .31243 .69497 L F
.523 .372 .619 r
.54995 .74025 m .54761 .73805 L .55098 .73837 L F
.048 0 .45 r
.55225 .73495 m .55204 .7382 L .55098 .73837 L F
0 0 0 r
.55207 .7384 m .55098 .73837 L .55204 .7382 L F
.55207 .7384 m .54995 .74025 L .55098 .73837 L F
.558 .293 .47 r
.59127 .75473 m .59337 .75647 L .59108 .75669 L F
.582 .285 .43 r
.59367 .75481 m .59337 .75647 L .59127 .75473 L F
0 0 .188 r
.6131 .68418 m .61439 .68305 L .61448 .6811 L F
0 0 .329 r
.61281 .68641 m .61439 .68305 L .6131 .68418 L F
.646 .367 .483 r
.54111 .73454 m .53886 .73241 L .54077 .73278 L F
.54111 .73454 m .5376 .73529 L .53886 .73241 L F
.747 .64 .743 r
.6886 .71051 m .68987 .71381 L .69169 .71122 L F
.424 0 0 r
.45686 .77336 m .45777 .77454 L .45908 .77329 L F
.598 .572 .796 r
.37553 .67318 m .37647 .66935 L .37434 .66976 L F
.37553 .67318 m .37775 .67281 L .37647 .66935 L F
.486 .461 .755 r
.37553 .67318 m .37756 .67455 L .37775 .67281 L F
.538 .544 .808 r
.3972 .66198 m .39647 .66577 L .39525 .66266 L F
.3972 .66198 m .39847 .66553 L .39647 .66577 L F
.556 .153 .233 r
.4197 .73296 m .4185 .73475 L .42133 .73436 L F
.529 .163 .29 r
.4197 .73296 m .42133 .73436 L .42195 .73288 L F
.612 .468 .661 r
.30892 .70587 m .3091 .7082 L .30703 .70876 L F
.32 .795 .918 r
.68479 .58542 m .68033 .58567 L .68198 .58587 L F
.322 .161 .502 r
.38525 .78447 m .38716 .78149 L .38554 .78231 L F
.08 .263 .751 r
.53313 .73548 m .53185 .73243 L .53466 .7331 L F
.781 .374 .279 r
.66469 .59834 m .66306 .59569 L .66038 .59595 L F
.686 .625 .782 r
.67404 .61478 m .67577 .61392 L .67545 .61135 L F
.67504 .61142 m .67545 .61135 L .67534 .61041 L F
.617 .842 .985 r
.67085 .61301 m .67496 .61242 L .67109 .61208 L F
.67 .61226 m .67109 .61208 L .66964 .61195 L F
.499 0 0 r
.67109 .61208 m .67496 .61242 L .67391 .61261 L F
.915 .958 .629 r
.67383 .61202 m .67496 .61242 L .67534 .61041 L F
.67383 .61203 m .67496 .61242 L .67383 .61202 L F
.67381 .61221 m .67496 .61242 L .67382 .61203 L F
.446 .881 .85 r
.67257 .61284 m .67496 .61242 L .67386 .61221 L F
.686 .625 .782 r
.67413 .61454 m .67534 .61041 L .67496 .61242 L F
.67414 .61442 m .67534 .61041 L .67413 .61454 L F
.67404 .61478 m .67414 .61442 L .67413 .61454 L F
.67404 .61478 m .67439 .61391 L .67427 .61399 L F
.67439 .61391 m .67486 .61279 L .67427 .61399 L F
.67427 .61399 m .67486 .61279 L .67464 .61275 L F
.757 .846 .917 r
.67244 .61271 m .67516 .61344 L .67254 .61505 L F
.499 0 0 r
.67109 .61208 m .67391 .61261 L .67257 .61284 L F
.396 .622 .943 r
.67112 .6114 m .67257 .61284 L .67329 .61241 L F
.757 .846 .917 r
.67318 .61212 m .6735 .61234 L .67329 .61241 L F
.639 .825 .972 r
.67381 .61221 m .6735 .61234 L .67318 .61212 L F
.396 .622 .943 r
.67313 .61201 m .67318 .61212 L .67317 .61203 L F
.392 .622 .944 r
.67112 .6114 m .67317 .61203 L .67293 .61111 L F
.639 .825 .972 r
.67317 .61193 m .67317 .61203 L .67316 .61193 L F
.67381 .61221 m .67318 .61212 L .67317 .61193 L F
.67383 .61183 m .67381 .61221 L .67239 .6116 L F
.392 .622 .944 r
.67317 .61203 m .67368 .61218 L .67313 .61139 L F
.814 .715 .756 r
.67534 .61041 m .67577 .61392 L .6781 .61065 L F
.997 .816 .538 r
.67534 .61041 m .67577 .61392 L .67516 .61344 L F
.547 .835 .499 r
.67389 .61195 m .67534 .61041 L .67605 .6096 L F
.67368 .61218 m .67382 .61203 L .67389 .61195 L F
.67382 .61203 m .67534 .61041 L .67389 .61195 L F
.686 .625 .782 r
.67464 .61275 m .67545 .61135 L .67504 .61142 L F
.67486 .61279 m .67545 .61135 L .67464 .61275 L F
.639 .825 .972 r
.67777 .61245 m .67379 .61253 L .67382 .61203 L F
.67398 .61185 m .67382 .61203 L .67383 .61183 L F
.915 .958 .629 r
.67382 .61203 m .67383 .61203 L .67383 .61202 L F
.639 .825 .972 r
.67777 .61245 m .67382 .61203 L .67398 .61185 L F
.67383 .61183 m .67384 .61149 L .67438 .61145 L F
.67405 .61179 m .67438 .61145 L .67669 .61128 L F
.67383 .61183 m .67438 .61145 L .67405 .61179 L F
0 0 0 r
.67368 .61218 m .67385 .61199 L .67438 .61145 L F
.646 .813 .963 r
.67552 .61029 m .67669 .61128 L .67438 .61145 L F
0 0 0 r
.67496 .61086 m .67438 .61145 L .67552 .61029 L F
.67368 .61218 m .67438 .61145 L .67496 .61086 L F
.67385 .61199 m .67605 .6096 L .67552 .61029 L F
.646 .813 .963 r
.67552 .61029 m .67438 .61145 L .67315 .61154 L F
.392 .622 .944 r
.67317 .61203 m .67313 .61142 L .67293 .61111 L F
.646 .813 .963 r
.67311 .6113 m .67315 .61154 L .67239 .6116 L F
0 0 0 r
.67312 .61138 m .67552 .61029 L .67293 .61111 L F
.646 .813 .963 r
.67552 .61029 m .67315 .61154 L .67312 .61138 L F
.639 .825 .972 r
.67383 .61183 m .67255 .61163 L .67384 .61149 L F
.67255 .61163 m .67239 .6116 L .6727 .61158 L F
.67255 .61163 m .6727 .61158 L .67384 .61149 L F
0 0 0 r
.67316 .61143 m .67552 .61029 L .67312 .61138 L F
.67368 .61218 m .67496 .61086 L .67316 .61143 L F
.67496 .61086 m .67552 .61029 L .67316 .61143 L F
.646 .813 .963 r
.67552 .61029 m .67312 .61138 L .67311 .6113 L F
.392 .622 .944 r
.67313 .61142 m .67313 .61139 L .67312 .61138 L F
.67313 .61142 m .67312 .61138 L .67293 .61111 L F
.639 .825 .972 r
.67316 .61193 m .67318 .61212 L .67239 .6116 L F
.67317 .61203 m .67318 .61212 L .67316 .61193 L F
.396 .622 .943 r
.67317 .61203 m .67329 .61241 L .67368 .61218 L F
.67318 .61212 m .67329 .61241 L .67317 .61203 L F
.67112 .6114 m .67329 .61241 L .67313 .61201 L F
.757 .846 .917 r
.67239 .6116 m .67318 .61212 L .67244 .61271 L F
.67318 .61212 m .67329 .61241 L .67244 .61271 L F
.446 .881 .85 r
.67257 .61284 m .67386 .61221 L .67366 .61228 L F
.67257 .61284 m .67381 .61221 L .67319 .61247 L F
.757 .846 .917 r
.6735 .61234 m .67516 .61344 L .67244 .61271 L F
.446 .881 .85 r
.67366 .61228 m .67386 .61221 L .67381 .61221 L F
.67319 .61247 m .67381 .61221 L .67368 .61218 L F
.639 .825 .972 r
.67381 .61221 m .67379 .61253 L .6735 .61234 L F
.67777 .61245 m .6744 .61192 L .67669 .61128 L F
.6744 .61192 m .67383 .61183 L .67443 .61171 L F
.6744 .61192 m .67443 .61171 L .67669 .61128 L F
.915 .958 .629 r
.67368 .61218 m .67381 .61221 L .67382 .61203 L F
.639 .825 .972 r
.67777 .61245 m .67516 .61344 L .67379 .61253 L F
.748 .931 .949 r
.67577 .61392 m .67369 .61568 L .67254 .61505 L F
.67577 .61392 m .67254 .61505 L .67516 .61344 L F
.2 .192 .624 r
.67254 .61505 m .67472 .61576 L .67355 .61367 L F
.67245 .61307 m .67355 .61367 L .67239 .6116 L F
.67254 .61505 m .67355 .61367 L .67245 .61307 L F
.499 0 0 r
.67137 .61248 m .67109 .61208 L .67257 .61284 L F
.66964 .61195 m .67056 .61203 L .67137 .61248 L F
.617 .842 .985 r
.67085 .61301 m .67109 .61208 L .67 .61226 L F
.499 0 0 r
.67056 .61203 m .67109 .61208 L .67137 .61248 L F
.779 .277 0 r
.71411 .58129 m .71483 .58085 L .71339 .58013 L F
.446 .103 .29 r
.32492 .68699 m .32426 .68903 L .32174 .68912 L F
.4 .061 .271 r
.32607 .68812 m .32492 .68699 L .32678 .68646 L F
.32607 .68812 m .32426 .68903 L .32492 .68699 L F
.731 .92 .956 r
.50306 .71186 m .50371 .71014 L .50472 .71038 L F
.50306 .71186 m .50177 .71124 L .50371 .71014 L F
.37 .41 .773 r
.72824 .73515 m .72925 .73839 L .7283 .73615 L F
.593 .372 .549 r
.72925 .73839 m .72937 .74097 L .72679 .74078 L F
.533 .524 .791 r
.73048 .73473 m .72925 .73839 L .72824 .73515 L F
.73048 .73473 m .73132 .73786 L .72925 .73839 L F
.459 .27 .536 r
.73132 .73786 m .72937 .74097 L .72925 .73839 L F
.492 .047 .119 r
.34557 .71009 m .34781 .7102 L .34929 .70858 L F
.25 0 0 r
.34781 .7102 m .35153 .7086 L .34929 .70858 L F
.744 .932 .95 r
.55135 .68853 m .55314 .68639 L .55351 .68632 L F
.55135 .68853 m .55018 .68801 L .55314 .68639 L F
.383 .84 .77 r
.43154 .78724 m .42757 .78852 L .42721 .78881 L F
.014 0 0 r
.43108 .78781 m .43154 .78724 L .43357 .78665 L F
.43108 .78781 m .42757 .78852 L .43154 .78724 L F
.488 .148 .317 r
.45539 .7411 m .45439 .74351 L .45225 .74358 L F
.292 0 .225 r
.45619 .74278 m .45539 .7411 L .45796 .74127 L F
.45619 .74278 m .45439 .74351 L .45539 .7411 L F
.497 .315 .564 r
.29247 .68135 m .29442 .68083 L .29456 .67851 L F
.548 .391 .62 r
.29243 .68374 m .29442 .68083 L .29247 .68135 L F
.499 .332 .586 r
.29667 .6243 m .29663 .62649 L .29473 .62705 L F
.405 .195 .478 r
.29663 .62649 m .29453 .62934 L .29473 .62705 L F
.806 .749 .23 r
.63599 .66504 m .63557 .66642 L .63523 .66806 L F
.63599 .66504 m .63597 .66432 L .63557 .66642 L F
.716 .235 .101 r
.49136 .77685 m .4935 .77862 L .49518 .77846 L F
.494 0 0 r
.4935 .77862 m .49705 .77914 L .49518 .77846 L F
0 .326 .724 r
.73506 .71474 m .73483 .71479 L .73213 .71333 L F
0 .253 .697 r
.7366 .71578 m .73483 .71479 L .73506 .71474 L F
.59 .731 .941 r
.6813 .59694 m .67822 .59621 L .68028 .5959 L F
.412 .185 .457 r
.67869 .60022 m .6813 .59694 L .68028 .5959 L F
.296 .08 .407 r
.59115 .65164 m .59277 .65256 L .5935 .65124 L F
.59115 .65164 m .59109 .65362 L .59277 .65256 L F
.73 .745 .864 r
.56398 .70862 m .56158 .71052 L .56064 .70834 L F
.494 .23 .443 r
.39707 .68386 m .39445 .68624 L .39514 .68461 L F
.869 .431 .145 r
.50998 .79256 m .50892 .79221 L .50783 .79029 L F
.867 .507 .365 r
.50998 .79256 m .50893 .79363 L .50892 .79221 L F
.50998 .79256 m .51155 .79531 L .50893 .79363 L F
.292 0 0 r
.52594 .78203 m .52839 .782 L .52926 .7815 L F
.206 0 0 r
.52839 .782 m .53153 .78107 L .52926 .7815 L F
.276 0 0 r
.53271 .78697 m .529 .78849 L .5305 .78701 L F
.636 .428 .584 r
.59637 .71392 m .59643 .71628 L .59403 .71645 L F
.615 .417 .591 r
.59872 .71372 m .59643 .71628 L .59637 .71392 L F
.13 .678 .791 r
.42996 .7761 m .42915 .7763 L .42783 .77645 L F
.42996 .7761 m .43129 .77613 L .42915 .7763 L F
.264 0 .243 r
.30162 .67296 m .3033 .67262 L .30416 .67043 L F
.391 .074 .304 r
.30416 .67043 m .30529 .67194 L .30583 .66963 L F
.30416 .67043 m .3033 .67262 L .30529 .67194 L F
.447 .013 .12 r
.51726 .72961 m .514 .73135 L .51518 .72999 L F
.296 0 .168 r
.35959 .70351 m .35876 .70496 L .36149 .70286 L F
.555 .398 .624 r
.38716 .78149 m .38927 .77854 L .3875 .77914 L F
.412 .185 .457 r
.67869 .60022 m .68028 .5959 L .68009 .59843 L F
.702 .38 0 r
.67906 .60143 m .67938 .60219 L .67882 .60058 L F
.67906 .60143 m .67882 .60058 L .67869 .60022 L F
.536 .576 .842 r
.68266 .60488 m .68045 .60307 L .68079 .60307 L F
.68045 .60307 m .67938 .60219 L .68079 .60307 L F
.671 .779 .931 r
.6839 .60213 m .68266 .60488 L .68079 .60307 L F
.006 0 0 r
.68199 .60305 m .68079 .60307 L .68103 .60351 L F
.6839 .60213 m .68079 .60307 L .68199 .60305 L F
.488 0 0 r
.68103 .60351 m .68079 .60307 L .67938 .60219 L F
.68057 .60303 m .67938 .60219 L .67906 .60143 L F
.68103 .60351 m .68082 .60335 L .68057 .60303 L F
.68082 .60335 m .67938 .60219 L .68057 .60303 L F
.654 .554 .73 r
.68292 .60135 m .67955 .60173 L .68006 .60021 L F
.488 0 0 r
.68103 .60351 m .67906 .60143 L .67842 .60378 L F
0 0 .092 r
.67921 .60194 m .67906 .60143 L .67987 .60045 L F
.6793 .60175 m .67987 .60045 L .68006 .60021 L F
.67921 .60194 m .67987 .60045 L .6793 .60175 L F
.654 .554 .73 r
.68292 .60135 m .68103 .60351 L .67918 .60203 L F
0 0 .092 r
.67842 .60378 m .67906 .60143 L .67921 .60196 L F
.655 .554 .729 r
.67918 .60203 m .68103 .60351 L .67842 .60378 L F
0 0 .092 r
.67842 .60378 m .67921 .60196 L .67923 .60202 L F
.655 .554 .729 r
.6789 .6018 m .67918 .60203 L .67842 .60378 L F
.654 .554 .73 r
.6793 .60175 m .67918 .60203 L .6789 .6018 L F
.68292 .60135 m .67918 .60203 L .6793 .60175 L F
.67955 .60173 m .67924 .60133 L .68006 .60021 L F
0 0 .092 r
.67923 .60202 m .67921 .60194 L .68006 .60021 L F
.654 .554 .73 r
.67941 .60154 m .6789 .6018 L .67924 .60133 L F
.67955 .60173 m .6793 .60175 L .67941 .60154 L F
.6793 .60175 m .6789 .6018 L .67941 .60154 L F
.702 .38 0 r
.67906 .60143 m .67869 .60022 L .68009 .59843 L F
.665 .52 .678 r
.59829 .69505 m .5982 .69743 L .60091 .69695 L F
.726 .676 .801 r
.6886 .71051 m .69169 .71122 L .69077 .70796 L F
.761 .696 .79 r
.69077 .70796 m .69169 .71122 L .69406 .7083 L F
.591 .017 0 r
.58041 .7202 m .58327 .72219 L .58004 .72064 L F
.466 .808 .999 r
.48681 .77525 m .48597 .77613 L .48465 .77579 L F
.48681 .77525 m .48805 .7759 L .48597 .77613 L F
.575 .321 .494 r
.60618 .70818 m .60373 .71022 L .60384 .70837 L F
.418 .103 .322 r
.38756 .69417 m .38553 .69464 L .38823 .69247 L F
.373 .061 .301 r
.38952 .69363 m .38823 .69247 L .39 .69164 L F
.38952 .69363 m .38756 .69417 L .38823 .69247 L F
.236 .59 .948 r
.71985 .58366 m .71772 .58396 L .71674 .58314 L F
.71985 .58366 m .72082 .58477 L .71772 .58396 L F
.471 .299 .565 r
.58608 .70799 m .5881 .70506 L .58634 .70582 L F
.929 .566 .149 r
.54576 .70548 m .5473 .70844 L .54641 .70764 L F
.002 .286 .785 r
.5473 .70844 m .54915 .70878 L .54641 .70764 L F
.54831 .70929 m .54955 .71033 L .54915 .70878 L F
.824 .606 .607 r
.5513 .71029 m .54915 .70878 L .54955 .71033 L F
.411 .567 .898 r
.54991 .7117 m .5513 .71029 L .54955 .71033 L F
.824 .606 .607 r
.5513 .71029 m .54858 .71186 L .54915 .70878 L F
0 0 .177 r
.54915 .70878 m .54858 .71186 L .54982 .70838 L F
.54915 .70878 m .54982 .70838 L .55005 .70775 L F
.002 .286 .785 r
.5473 .70844 m .54831 .70929 L .54915 .70878 L F
.498 .324 .576 r
.70114 .71374 m .70135 .7161 L .69895 .7166 L F
.701 .479 0 r
.54285 .70029 m .5431 .70188 L .54215 .69938 L F
.54285 .70029 m .54317 .70229 L .5431 .70188 L F
.43 0 .008 r
.4581 .78168 m .4617 .78088 L .46036 .78182 L F
.463 .015 .099 r
.46377 .78098 m .46036 .78182 L .4617 .78088 L F
.266 0 0 r
.58344 .7466 m .58542 .74689 L .58653 .74659 L F
.162 .37 .821 r
.5886 .74738 m .58891 .7484 L .58653 .74659 L F
.5886 .74738 m .58653 .74659 L .58542 .74689 L F
.579 .388 .587 r
.58531 .72747 m .58742 .72758 L .58801 .72496 L F
.58531 .72747 m .58742 .72758 L .58801 .72496 L F
.556 .739 .961 r
.56593 .6966 m .56713 .69762 L .56461 .69811 L F
.715 .252 .152 r
.56461 .69811 m .56735 .70013 L .56386 .69927 L F
.56461 .69811 m .56386 .69927 L .56593 .6966 L F
.169 0 0 r
.43343 .77609 m .43459 .77572 L .43129 .77613 L F
.313 0 0 r
.43343 .77609 m .43668 .77514 L .43459 .77572 L F
.685 .668 .827 r
.70179 .61527 m .70282 .61713 L .70506 .61616 L F
.624 .264 .339 r
.33452 .71022 m .33747 .71261 L .3381 .70985 L F
.182 0 .203 r
.3381 .70985 m .33861 .70971 L .34049 .71153 L F
.3381 .70985 m .33747 .71261 L .33861 .70971 L F
.354 0 0 r
.33394 .65063 m .33281 .6514 L .33598 .6505 L F
.317 .083 .391 r
.39214 .68888 m .39 .69164 L .39049 .68957 L F
.628 .619 .822 r
.5978 .74722 m .60071 .74885 L .59863 .74923 L F
.523 .336 .569 r
.60071 .74885 m .59869 .75142 L .59863 .74923 L F
.428 .125 .347 r
.70964 .71576 m .70723 .71638 L .70657 .71919 L F
.377 0 .081 r
.47118 .73631 m .47389 .73694 L .47039 .73754 L F
.412 .233 .526 r
.29293 .63229 m .2927 .63464 L .29102 .63518 L F
.304 .104 .435 r
.2927 .63464 m .29086 .63744 L .29102 .63518 L F
.468 .755 .992 r
.325 .8242 m .32691 .82531 L .32544 .8252 L F
.731 .404 0 r
.32544 .8252 m .32619 .82746 L .325 .8242 L F
.66 .412 .534 r
.32691 .82531 m .32619 .82746 L .32544 .8252 L F
.359 .601 .939 r
.47408 .77096 m .47356 .77246 L .47238 .77044 L F
.47408 .77096 m .47586 .77295 L .47356 .77246 L F
.663 .752 .917 r
.58891 .7484 m .59248 .74894 L .59044 .75 L F
.206 0 0 r
.44528 .74602 m .44423 .74645 L .44208 .74658 L F
.439 .813 .993 r
.44528 .74602 m .44767 .74575 L .44636 .74526 L F
.445 .867 .738 r
.44636 .74526 m .44423 .74645 L .44528 .74602 L F
.454 .111 .293 r
.33833 .68 m .33674 .67893 L .33964 .67781 L F
.334 0 .15 r
.34041 .67942 m .33964 .67781 L .34144 .67781 L F
.34041 .67942 m .33833 .68 L .33964 .67781 L F
.815 .536 .515 r
.58236 .75428 m .57895 .75124 L .58245 .75169 L F
.936 .962 .75 r
.6339 .66989 m .63523 .66806 L .63335 .66922 L F
.858 .996 .771 r
.63335 .66922 m .63523 .66806 L .63557 .66642 L F
.496 .284 .52 r
.41073 .65974 m .41185 .66206 L .40896 .66214 L F
.716 .648 .781 r
.41626 .65634 m .41752 .65946 L .41321 .6579 L F
.662 .473 .619 r
.4162 .65951 m .41321 .6579 L .41752 .65946 L F
.4162 .65951 m .41401 .6614 L .41321 .6579 L F
.775 .673 .75 r
.41271 .65814 m .41512 .65908 L .41486 .65784 L F
.41512 .65908 m .4162 .65951 L .41578 .65898 L F
.41512 .65908 m .41578 .65898 L .41486 .65784 L F
.606 .331 .473 r
.41353 .65932 m .41073 .65974 L .41321 .6579 L F
.41401 .6614 m .41075 .65975 L .41353 .65932 L F
.41075 .65975 m .41073 .65974 L .41353 .65932 L F
.41401 .6614 m .41185 .66206 L .41073 .65974 L F
.983 .739 .486 r
.54775 .7356 m .54951 .7326 L .55084 .7356 L F
.448 .52 .84 r
.55225 .73495 m .55084 .7356 L .54951 .7326 L F
.668 .653 .826 r
.31458 .70835 m .31603 .71148 L .31249 .71037 L F
.693 .666 .818 r
.31797 .71032 m .31603 .71148 L .31458 .70835 L F
.425 .324 .637 r
.71821 .72083 m .71643 .71931 L .71882 .71942 L F
.71821 .72083 m .71712 .72212 L .71643 .71931 L F
.444 .669 .958 r
.72016 .72894 m .7188 .73017 L .71801 .72894 L F
.358 0 0 r
.72004 .73086 m .7188 .73017 L .72016 .72894 L F
.72004 .73086 m .71808 .73146 L .7188 .73017 L F
.583 .786 .976 r
.51843 .70883 m .51638 .70953 L .51478 .70815 L F
.306 .283 .669 r
.6514 .59767 m .65272 .5989 L .65263 .59795 L F
.539 .29 .487 r
.65032 .59951 m .65272 .5989 L .6514 .59767 L F
.699 .167 0 r
.49037 .7775 m .4935 .77862 L .49136 .77685 L F
.554 .366 .581 r
.64817 .60412 m .65027 .60217 L .64808 .60261 L F
.852 .872 .854 r
.57621 .72949 m .57984 .72758 L .57654 .727 L F
.701 .625 .768 r
.56751 .71094 m .56525 .71194 L .56398 .70862 L F
.667 .93 .64 r
.57022 .67085 m .57118 .66944 L .57179 .66978 L F
.57022 .67085 m .56886 .67191 L .57118 .66944 L F
.623 .255 .324 r
.60657 .65692 m .60527 .65904 L .60329 .65859 L F
.737 .39 .393 r
.60657 .65692 m .60862 .65908 L .60527 .65904 L F
.673 .405 .508 r
.60967 .65697 m .60862 .65908 L .60657 .65692 L F
.757 .986 .758 r
.55583 .68392 m .55351 .68632 L .5543 .68472 L F
.735 .937 .607 r
.55351 .68632 m .55314 .68639 L .5543 .68472 L F
.75 .557 .635 r
.5982 .69743 m .598 .70031 L .60152 .69923 L F
.651 .329 .414 r
.598 .70031 m .59833 .702 L .60152 .69923 L F
.964 .687 .259 r
.60152 .69923 m .60091 .69695 L .5982 .69743 L F
.652 .336 .425 r
.59833 .702 m .60147 .69984 L .60152 .69923 L F
.964 .687 .259 r
.60152 .69923 m .60147 .69984 L .60091 .69695 L F
.44 .371 .683 r
.38888 .77379 m .39018 .77035 L .38823 .77072 L F
.38888 .77379 m .39063 .77349 L .39018 .77035 L F
.446 .404 .718 r
.38888 .77379 m .39117 .77573 L .39063 .77349 L F
.52 .406 .663 r
.38888 .77379 m .3892 .77616 L .39117 .77573 L F
.255 .753 .686 r
.48736 .71942 m .48855 .71897 L .48924 .71855 L F
.48736 .71942 m .48543 .72007 L .48855 .71897 L F
.66 .805 .953 r
.37142 .80283 m .37317 .80405 L .37488 .80313 L F
.062 0 .031 r
.32625 .73297 m .32535 .73552 L .32329 .73592 L F
.382 0 .146 r
.32719 .73443 m .32625 .73297 L .32843 .73268 L F
.32719 .73443 m .32535 .73552 L .32625 .73297 L F
.548 .389 .618 r
.39036 .75448 m .39258 .75412 L .39234 .75163 L F
.542 .409 .649 r
.39036 .75448 m .39278 .75725 L .39258 .75412 L F
.39036 .75448 m .39064 .75767 L .39278 .75725 L F
.404 .215 .508 r
.37324 .68941 m .37508 .68886 L .37518 .6866 L F
.482 .32 .584 r
.37311 .69183 m .37508 .68886 L .37324 .68941 L F
0 0 0 r
.61387 .64233 m .61667 .64017 L .61467 .64098 L F
.293 0 .128 r
.35956 .71682 m .35823 .71896 L .3567 .71874 L F
.397 .012 .188 r
.36112 .71759 m .35956 .71682 L .36143 .71613 L F
.36112 .71759 m .35823 .71896 L .35956 .71682 L F
.582 .342 .517 r
.60384 .6974 m .60625 .69719 L .60636 .69505 L F
.518 .289 .507 r
.60636 .69505 m .60869 .69668 L .60887 .69455 L F
.60636 .69505 m .60625 .69719 L .60869 .69668 L F
.322 .161 .502 r
.38525 .78447 m .387 .78444 L .38716 .78149 L F
.117 0 0 r
.38448 .7848 m .387 .78444 L .38525 .78447 L F
.677 .816 .949 r
.7231 .62179 m .72623 .62217 L .72515 .62096 L F
.443 .756 .995 r
.72623 .62217 m .72786 .62094 L .72515 .62096 L F
.72623 .62217 m .72905 .62216 L .72786 .62094 L F
.031 0 0 r
.57143 .74298 m .56929 .74022 L .57052 .74158 L F
.546 .431 .673 r
.31061 .70347 m .31109 .70583 L .30892 .70587 L F
.545 .417 .656 r
.31109 .70583 m .3091 .7082 L .30892 .70587 L F
.365 .114 .394 r
.39445 .68624 m .39214 .68888 L .39265 .68691 L F
0 0 0 r
.66017 .59457 m .65791 .59574 L .66038 .59595 L F
.878 .719 .682 r
.64571 .61492 m .64847 .61436 L .64719 .61273 L F
.64571 .61492 m .64822 .61588 L .64847 .61436 L F
.704 .749 .887 r
.65055 .61329 m .64847 .61436 L .64719 .61273 L F
.65055 .61329 m .64847 .61436 L .64719 .61273 L F
.832 .577 .553 r
.64822 .61588 m .65055 .61329 L .64847 .61436 L F
.303 0 .049 r
.35712 .70578 m .35772 .70718 L .35876 .70496 L F
.35712 .70578 m .35563 .70767 L .35772 .70718 L F
.525 .43 .689 r
.38823 .77072 m .38978 .7679 L .38769 .76831 L F
.651 .841 .973 r
.51058 .709 m .50717 .70888 L .50936 .70813 L F
.604 .833 .987 r
.51265 .70835 m .51058 .709 L .50936 .70813 L F
.281 0 0 r
.72176 .71951 m .72098 .71977 L .71882 .71942 L F
.126 .574 .922 r
.72176 .71951 m .72477 .72027 L .72384 .71948 L F
.72176 .71951 m .72384 .71948 L .72098 .71977 L F
.983 .739 .486 r
.54775 .7356 m .54671 .73255 L .54951 .7326 L F
.54775 .7356 m .54673 .73517 L .54671 .73255 L F
.985 .775 .541 r
.54775 .7356 m .54761 .73805 L .54673 .73517 L F
.218 0 .082 r
.33059 .6846 m .32977 .68366 L .33173 .68316 L F
.33059 .6846 m .32846 .68559 L .32977 .68366 L F
.593 .404 .595 r
.62532 .62933 m .62767 .62647 L .6255 .62715 L F
.716 .648 .781 r
.41626 .65634 m .41321 .6579 L .41418 .65705 L F
.312 0 0 r
.41271 .65814 m .41626 .65634 L .41418 .65705 L F
.358 0 0 r
.46695 .78119 m .46568 .78135 L .46377 .78098 L F
.072 0 0 r
.4692 .78114 m .46568 .78135 L .46695 .78119 L F
.979 .723 .474 r
.63881 .65331 m .64001 .65409 L .63879 .65099 L F
.702 .267 .213 r
.63898 .65568 m .64001 .65409 L .63881 .65331 L F
.63898 .65568 m .64223 .65598 L .64001 .65409 L F
.574 .576 .817 r
.69818 .59746 m .69886 .59333 L .69762 .594 L F
.69818 .59746 m .70105 .59696 L .69886 .59333 L F
.659 .761 .925 r
.38388 .80336 m .38676 .80349 L .38657 .8039 L F
0 0 0 r
.38806 .80267 m .38657 .8039 L .38676 .80349 L F
.564 .401 .619 r
.29442 .68083 m .29649 .67803 L .29456 .67851 L F
.656 .597 .777 r
.55617 .72498 m .55747 .72121 L .55533 .7214 L F
.55617 .72498 m .55798 .72492 L .55747 .72121 L F
.692 .245 .187 r
.55519 .72633 m .55864 .72681 L .55617 .72498 L F
.442 0 0 r
.55739 .72593 m .55617 .72498 L .55519 .72633 L F
.55739 .72593 m .55864 .72681 L .55617 .72498 L F
.684 .739 .893 r
.32703 .71085 m .32368 .71032 L .3257 .70954 L F
.589 .741 .948 r
.32903 .71036 m .32703 .71085 L .3257 .70954 L F
.415 .719 .987 r
.37145 .65081 m .3707 .65199 L .36932 .65099 L F
.37145 .65081 m .37301 .65201 L .3707 .65199 L F
.654 .103 0 r
.50103 .78532 m .50039 .78584 L .4982 .7841 L F
.633 .076 0 r
.50103 .78532 m .50336 .78689 L .50039 .78584 L F
.652 .11 0 r
.50504 .78707 m .50336 .78689 L .50103 .78532 L F
.374 0 0 r
.50499 .7825 m .50374 .78171 L .50245 .78117 L F
.694 .225 .133 r
.50708 .78482 m .51017 .78526 L .50852 .78397 L F
.374 0 0 r
.50454 .78222 m .50834 .78384 L .50374 .78171 L F
.50712 .78335 m .50834 .78384 L .50454 .78222 L F
.68 .765 .915 r
.50793 .78351 m .50834 .78384 L .50499 .7825 L F
.694 .225 .133 r
.50783 .78367 m .50852 .78397 L .50793 .78351 L F
.50708 .78482 m .50852 .78397 L .50783 .78367 L F
.374 0 0 r
.50499 .7825 m .50712 .78335 L .50454 .78222 L F
.44 .056 .213 r
.5383 .78454 m .53725 .78658 L .535 .78691 L F
.484 .134 .297 r
.54044 .78406 m .53725 .78658 L .5383 .78454 L F
.58 .375 .568 r
.59365 .70018 m .59586 .69992 L .59593 .69751 L F
.748 .555 .635 r
.59586 .69992 m .5982 .69743 L .59593 .69751 L F
0 0 0 r
.59507 .73262 m .59398 .73448 L .59544 .73371 L F
0 0 .034 r
.58801 .72496 m .58742 .72758 L .58827 .72577 L F
.783 .416 .363 r
.50713 .78916 m .50336 .78689 L .50504 .78707 L F
.719 .795 .911 r
.65838 .61091 m .66204 .61135 L .66055 .6099 L F
.691 .804 .935 r
.66055 .6099 m .66204 .61135 L .66383 .61023 L F
.386 .017 .21 r
.31326 .66468 m .3154 .66432 L .31642 .6623 L F
.231 0 .131 r
.31642 .6623 m .31717 .66364 L .3185 .6619 L F
.31642 .6623 m .3154 .66432 L .31717 .66364 L F
.516 .641 .911 r
.72253 .5846 m .72124 .58637 L .72082 .58477 L F
.539 .673 .925 r
.72253 .5846 m .72384 .58616 L .72124 .58637 L F
.502 .546 .834 r
.54796 .7287 m .54832 .73011 L .54616 .73017 L F
.508 .369 .627 r
.54832 .73011 m .54671 .73255 L .54616 .73017 L F
.523 .353 .592 r
.37695 .68116 m .3793 .68086 L .37916 .67826 L F
.381 .157 .444 r
.37712 .68333 m .3793 .68086 L .37695 .68116 L F
.814 .662 .694 r
.62054 .65935 m .61715 .66147 L .61776 .65901 L F
.62054 .65935 m .61967 .66223 L .61715 .66147 L F
.541 .408 .649 r
.39642 .7437 m .39848 .74331 L .39829 .74104 L F
.529 .371 .611 r
.39651 .74608 m .39848 .74331 L .39642 .7437 L F
.401 0 0 r
.53153 .78107 m .53379 .7815 L .53465 .78114 L F
.035 0 0 r
.53465 .78114 m .5359 .78111 L .53671 .78053 L F
.01 0 0 r
.53379 .7815 m .5359 .78111 L .53465 .78114 L F
.632 .455 .625 r
.72637 .72709 m .72853 .72453 L .72653 .72487 L F
.173 .25 .703 r
.53094 .71767 m .5297 .71899 L .52896 .7157 L F
.359 .543 .899 r
.53094 .71767 m .53146 .71918 L .5297 .71899 L F
.309 .004 .275 r
.37545 .70711 m .37442 .70617 L .37604 .70557 L F
.37545 .70711 m .37361 .70793 L .37442 .70617 L F
.267 0 0 r
.46307 .73833 m .46214 .74028 L .45975 .74032 L F
.261 0 0 r
.46402 .73939 m .46214 .74028 L .46307 .73833 L F
.268 0 .004 r
.33435 .73072 m .33331 .73169 L .33175 .73188 L F
0 0 0 r
.33606 .72989 m .33331 .73169 L .33435 .73072 L F
.712 .668 .805 r
.69054 .61557 m .69395 .61616 L .69294 .61326 L F
.746 .686 .794 r
.69294 .61326 m .69395 .61616 L .69615 .61373 L F
.705 .705 .847 r
.70207 .60244 m .70264 .60509 L .69943 .60442 L F
.516 .29 .509 r
.40412 .6756 m .40376 .67787 L .40179 .67825 L F
.497 .294 .535 r
.40642 .67293 m .40616 .67501 L .40412 .6756 L F
.418 .178 .442 r
.40616 .67501 m .40376 .67787 L .40412 .6756 L F
.293 .065 .387 r
.30162 .67296 m .30273 .67475 L .3033 .67262 L F
.30162 .67296 m .30122 .67474 L .30273 .67475 L F
.404 0 0 r
.33331 .73169 m .33034 .73209 L .33175 .73188 L F
.748 .555 .635 r
.59586 .69992 m .598 .70031 L .5982 .69743 L F
.869 .43 .141 r
.50783 .79029 m .50737 .79145 L .50713 .78916 L F
.50783 .79029 m .50892 .79221 L .50737 .79145 L F
.881 .879 .829 r
.33434 .8398 m .33542 .83982 L .33338 .84206 L F
.184 0 0 r
.33649 .8397 m .33542 .83982 L .33434 .8398 L F
.33649 .8397 m .33706 .83942 L .33542 .83982 L F
.908 .705 .615 r
.57929 .73716 m .58208 .74069 L .58256 .73843 L F
.525 .43 .689 r
.38823 .77072 m .39018 .77035 L .38978 .7679 L F
.647 .376 .494 r
.61251 .65843 m .60967 .65697 L .61212 .65686 L F
.691 .369 .427 r
.61212 .65686 m .6141 .65888 L .61251 .65843 L F
.661 .375 .476 r
.61397 .65694 m .6141 .65888 L .61212 .65686 L F
.461 .495 .808 r
.57018 .71149 m .57217 .71439 L .57283 .71406 L F
.41 .044 .229 r
.57217 .71439 m .57303 .71556 L .57283 .71406 L F
.57217 .71439 m .57067 .716 L .57303 .71556 L F
.51 .902 .762 r
.49477 .71586 m .4957 .715 L .49743 .71409 L F
.49477 .71586 m .49396 .7161 L .4957 .715 L F
.469 .39 .685 r
.59449 .72134 m .59307 .72466 L .59246 .72179 L F
.59449 .72134 m .5948 .72445 L .59307 .72466 L F
.475 .435 .734 r
.5948 .72445 m .59602 .72688 L .59307 .72466 L F
.779 .839 .898 r
.58327 .72219 m .584 .72409 L .58626 .72179 L F
.63 .772 .949 r
.71967 .62115 m .72075 .62256 L .7231 .62179 L F
.884 .991 .783 r
.70892 .59565 m .70578 .59454 L .70941 .59394 L F
.70892 .59565 m .70727 .59654 L .70578 .59454 L F
.451 .188 .424 r
.39944 .68085 m .39909 .68343 L .39707 .68386 L F
.409 .181 .454 r
.40179 .67825 m .40142 .68079 L .39944 .68085 L F
.408 .153 .412 r
.40097 .68276 m .39944 .68085 L .40142 .68079 L F
.40097 .68276 m .39909 .68343 L .39944 .68085 L F
.647 .376 .494 r
.61251 .65843 m .60862 .65908 L .60967 .65697 L F
.412 .192 .466 r
.38107 .70016 m .38073 .7023 L .37887 .70281 L F
.397 .072 .293 r
.38009 .70459 m .37887 .70281 L .38073 .7023 L F
.38009 .70459 m .37805 .70508 L .37887 .70281 L F
.573 .409 .621 r
.40896 .66214 m .40976 .66474 L .40746 .66504 L F
.40896 .66214 m .40976 .66474 L .40746 .66504 L F
.513 .468 .744 r
.41064 .65872 m .41185 .66206 L .40896 .66214 L F
.624 .438 .61 r
.40896 .66214 m .41238 .66284 L .41185 .66206 L F
.40896 .66214 m .40976 .66474 L .41238 .66284 L F
.41238 .66284 m .40896 .66214 L .41185 .66206 L F
.41238 .66284 m .40976 .66474 L .40896 .66214 L F
.555 .82 .995 r
.33452 .71022 m .33113 .7095 L .33352 .70902 L F
0 .262 .768 r
.33514 .70899 m .33452 .71022 L .33352 .70902 L F
.33514 .70899 m .33747 .71261 L .33452 .71022 L F
.589 .474 .691 r
.64181 .61103 m .64394 .60785 L .64015 .60695 L F
.64181 .61103 m .64357 .61113 L .64394 .60785 L F
.436 0 .066 r
.64352 .61193 m .64181 .61103 L .64119 .61228 L F
.765 .667 .754 r
.49519 .73242 m .49643 .73553 L .49872 .73273 L F
.678 .612 .774 r
.31249 .71037 m .3091 .7082 L .31217 .70866 L F
.57 .489 .725 r
.31458 .70835 m .31249 .71037 L .31217 .70866 L F
.728 .91 .958 r
.73691 .60801 m .73221 .60838 L .73619 .60711 L F
.722 .472 .548 r
.73423 .61004 m .73691 .60801 L .73221 .60838 L F
.73423 .61004 m .73739 .61021 L .73691 .60801 L F
.576 .611 .851 r
.73857 .60704 m .73619 .60711 L .73691 .60801 L F
.434 .76 .996 r
.73691 .60801 m .73857 .60704 L .73619 .60711 L F
.094 .558 .909 r
.32786 .82526 m .32691 .82531 L .325 .8242 L F
.682 .435 .542 r
.32773 .82664 m .32691 .82531 L .32786 .82526 L F
.32773 .82664 m .32619 .82746 L .32691 .82531 L F
.411 0 0 r
.40211 .66707 m .40408 .66732 L .40456 .66679 L F
.679 .528 .674 r
.40456 .66679 m .40728 .66835 L .40746 .66504 L F
.361 .722 .987 r
.40408 .66732 m .40728 .66835 L .40456 .66679 L F
.679 .528 .674 r
.40456 .66679 m .40728 .66835 L .40746 .66504 L F
0 0 .127 r
.30755 .7431 m .30637 .74602 L .30513 .74331 L F
.30755 .7431 m .30666 .74627 L .30637 .74602 L F
.376 .334 .684 r
.30637 .74602 m .30666 .74627 L .30643 .74637 L F
.232 .735 .9 r
.52853 .72747 m .52722 .7272 L .52521 .72733 L F
.755 .296 .159 r
.53064 .72895 m .52722 .7272 L .52853 .72747 L F
.52 .35 .591 r
.5611 .7053 m .56064 .70834 L .55842 .70833 L F
.659 .157 .042 r
.5092 .78429 m .51138 .78588 L .51218 .78489 L F
.036 0 0 r
.51218 .78489 m .5136 .7851 L .51496 .78493 L F
.51218 .78489 m .51138 .78588 L .5136 .7851 L F
.786 .609 .661 r
.50535 .72225 m .50523 .7245 L .50185 .72397 L F
.639 .483 .655 r
.50734 .72179 m .50523 .7245 L .50535 .72225 L F
.351 0 .082 r
.35554 .67329 m .35425 .67512 L .35203 .67545 L F
.024 0 0 r
.35599 .67418 m .35554 .67329 L .35757 .67275 L F
.35599 .67418 m .35425 .67512 L .35554 .67329 L F
0 .076 .636 r
.67932 .6238 m .67794 .62058 L .67918 .62137 L F
.093 .643 .823 r
.44016 .77537 m .43668 .77514 L .43889 .77448 L F
.121 .589 .918 r
.44115 .77509 m .44016 .77537 L .43889 .77448 L F
.44115 .77509 m .44238 .77588 L .44016 .77537 L F
.606 .842 .468 r
.57895 .7018 m .57999 .70052 L .57906 .69947 L F
.57895 .7018 m .57846 .70249 L .57999 .70052 L F
0 .49 .828 r
.70114 .72954 m .69832 .7285 L .69895 .72924 L F
.461 .09 .247 r
.48595 .73189 m .48434 .73092 L .48631 .72959 L F
.48595 .73189 m .48286 .73264 L .48434 .73092 L F
.186 .719 .797 r
.67718 .59623 m .68028 .5959 L .67822 .59621 L F
.122 0 0 r
.69243 .58528 m .68934 .58799 L .6908 .58562 L F
.223 0 .347 r
.30643 .74637 m .30666 .74627 L .30632 .74686 L F
.706 .652 .794 r
.31109 .70583 m .31217 .70866 L .3091 .7082 L F
.576 .563 .802 r
.31334 .70536 m .31217 .70866 L .31109 .70583 L F
.31334 .70536 m .31458 .70835 L .31217 .70866 L F
.471 .29 .553 r
.2987 .62149 m .29853 .62377 L .29667 .6243 L F
.454 .296 .577 r
.29821 .62549 m .29667 .6243 L .29853 .62377 L F
.29821 .62549 m .29663 .62649 L .29667 .6243 L F
.834 .779 .8 r
.64571 .61492 m .64602 .61849 L .64822 .61588 L F
.412 .412 .749 r
.72779 .72836 m .72768 .73267 L .7288 .72941 L F
.72779 .72836 m .72959 .73265 L .72768 .73267 L F
.411 .422 .761 r
.72959 .73265 m .73048 .73473 L .72768 .73267 L F
.5 .419 .696 r
.72768 .73267 m .73048 .73473 L .72824 .73515 L F
0 0 0 r
.46729 .7401 m .46885 .73834 L .47039 .73754 L F
.457 0 0 r
.59074 .72801 m .58954 .72845 L .58742 .72758 L F
0 .338 .806 r
.59074 .72801 m .59312 .72944 L .59191 .72814 L F
.59074 .72801 m .59191 .72814 L .58954 .72845 L F
.617 .692 .897 r
.70337 .57529 m .70115 .57554 L .70168 .57433 L F
.70337 .57529 m .70223 .57792 L .70115 .57554 L F
.226 .319 .751 r
.307 .73822 m .3072 .73824 L .30605 .73503 L F
.118 0 0 r
.72679 .74078 m .72749 .74098 L .72555 .74064 L F
.72679 .74078 m .72937 .74097 L .72749 .74098 L F
.285 0 0 r
.52052 .7082 m .52408 .70778 L .52165 .70854 L F
.419 .473 .81 r
.52432 .70983 m .52165 .70854 L .52408 .70778 L F
.523 .676 .934 r
.57018 .71149 m .57169 .71016 L .56968 .71036 L F
.57018 .71149 m .57274 .71159 L .57169 .71016 L F
.461 .495 .808 r
.57018 .71149 m .57283 .71406 L .57274 .71159 L F
.959 .783 .338 r
.51347 .72656 m .51297 .72658 L .51349 .72456 L F
0 0 0 r
.51349 .72456 m .51297 .72658 L .51372 .72428 L F
.313 .058 .358 r
.61474 .70033 m .61529 .70209 L .61311 .7025 L F
.296 .141 .494 r
.61474 .70033 m .61716 .7013 L .61529 .70209 L F
.61474 .70033 m .61725 .69912 L .61716 .7013 L F
.701 .625 .768 r
.56751 .71094 m .56398 .70862 L .56611 .70788 L F
.773 .526 .561 r
.59529 .73549 m .59526 .73796 L .59234 .73733 L F
.426 .327 .64 r
.59717 .73197 m .59731 .73527 L .59529 .73549 L F
.566 .435 .661 r
.59731 .73527 m .59526 .73796 L .59529 .73549 L F
.722 .553 .661 r
.57788 .74382 m .5777 .74654 L .57441 .74639 L F
0 0 .401 r
.57884 .74515 m .57788 .74382 L .57996 .7435 L F
.57884 .74515 m .5777 .74654 L .57788 .74382 L F
.887 .976 .828 r
.50472 .71038 m .50593 .70743 L .50717 .70888 L F
.50472 .71038 m .50371 .71014 L .50593 .70743 L F
.454 .111 .293 r
.33833 .68 m .33622 .68046 L .33674 .67893 L F
.323 .451 .835 r
.563 .73019 m .56414 .72882 L .56219 .72915 L F
.563 .73019 m .5657 .7318 L .56414 .72882 L F
0 0 .104 r
.61448 .6811 m .6148 .68231 L .61553 .67986 L F
.61448 .6811 m .61439 .68305 L .6148 .68231 L F
.186 .719 .78 r
.34979 .67501 m .34642 .67548 L .34755 .67521 L F
.313 0 0 r
.44481 .78438 m .44549 .78527 L .44355 .7853 L F
.44481 .78438 m .44705 .78449 L .44549 .78527 L F
.515 .536 .816 r
.42235 .77559 m .42038 .77562 L .41927 .773 L F
.222 .353 .786 r
.41848 .65786 m .41752 .65946 L .41626 .65634 L F
.696 .961 .944 r
.41848 .65786 m .4162 .65951 L .41752 .65946 L F
.482 .254 .49 r
.4309 .74634 m .43064 .74853 L .42852 .74894 L F
.567 .327 .511 r
.4309 .74634 m .4329 .74822 L .43064 .74853 L F
.216 0 .175 r
.58897 .65422 m .58648 .65654 L .58825 .65559 L F
.208 0 .075 r
.58825 .65559 m .59109 .65362 L .58897 .65422 L F
.491 .354 .622 r
.408 .67 m .40812 .67242 L .40642 .67293 L F
.441 .242 .513 r
.40812 .67242 m .40616 .67501 L .40642 .67293 L F
.742 .663 .772 r
.57921 .68905 m .58284 .68968 L .58095 .68858 L F
.553 .301 .488 r
.61104 .70544 m .6084 .70775 L .60873 .7059 L F
.08 .263 .751 r
.53313 .73548 m .53397 .73442 L .53185 .73243 L F
.386 .709 .986 r
.53313 .73548 m .53522 .73566 L .53397 .73442 L F
.97 .652 .299 r
.61893 .66771 m .61843 .66902 L .61844 .6668 L F
.61893 .66771 m .61929 .66975 L .61843 .66902 L F
0 .342 .701 r
.69814 .57511 m .69883 .57548 L .69606 .57425 L F
.435 .874 .837 r
.69998 .57473 m .70168 .57433 L .69883 .57548 L F
.433 .854 .954 r
.69998 .57473 m .69883 .57548 L .69814 .57511 L F
.665 .682 .856 r
.68482 .60413 m .68595 .60562 L .68266 .60488 L F
.684 .703 .861 r
.68735 .60232 m .68595 .60562 L .68482 .60413 L F
.68735 .60232 m .68824 .60486 L .68595 .60562 L F
.622 .394 .55 r
.44995 .74364 m .44996 .7463 L .44767 .74575 L F
.401 .221 .519 r
.45162 .74517 m .44995 .74364 L .45225 .74358 L F
.45162 .74517 m .44996 .7463 L .44995 .74364 L F
.367 0 .003 r
.7122 .71404 m .71461 .71379 L .71506 .71325 L F
.314 0 0 r
.71506 .71325 m .71461 .71379 L .71735 .7129 L F
.729 .74 .861 r
.69369 .60468 m .69178 .60584 L .69047 .60425 L F
.996 .764 .45 r
.38307 .8002 m .38388 .80336 L .38324 .80232 L F
.242 .643 .961 r
.38388 .80336 m .38541 .80254 L .38324 .80232 L F
.38541 .80254 m .38533 .80249 L .38324 .80232 L F
.38388 .80336 m .38657 .8039 L .38553 .80258 L F
.572 .589 .831 r
.38803 .80108 m .38789 .80289 L .38878 .80168 L F
.3856 .79913 m .38725 .80185 L .38803 .80108 L F
.38725 .80185 m .38789 .80289 L .38803 .80108 L F
.738 .929 .953 r
.38651 .80257 m .38657 .8039 L .38806 .80267 L F
.38599 .80254 m .38615 .80293 L .38651 .80257 L F
.38615 .80293 m .38657 .8039 L .38651 .80257 L F
.38574 .80252 m .38581 .80264 L .38599 .80254 L F
.38581 .80264 m .38657 .8039 L .38599 .80254 L F
.705 .643 .785 r
.38323 .8014 m .38628 .80238 L .3856 .79913 L F
.38628 .80238 m .38789 .80289 L .38725 .80185 L F
.38628 .80238 m .38725 .80185 L .3856 .79913 L F
.738 .929 .953 r
.38553 .80258 m .38657 .8039 L .38574 .80252 L F
.76 .527 .58 r
.38586 .80278 m .38574 .80252 L .3855 .80259 L F
.3855 .80259 m .38628 .80238 L .38338 .80144 L F
.738 .929 .953 r
.38547 .80251 m .38553 .80258 L .38574 .80252 L F
.38574 .80252 m .38806 .80267 L .38664 .8045 L F
.76 .527 .58 r
.38664 .8045 m .38735 .80359 L .38533 .80251 L F
.195 .557 .934 r
.38323 .8014 m .38324 .80232 L .38533 .80249 L F
.76 .527 .58 r
.38735 .80359 m .38533 .80249 L .38323 .8014 L F
.38533 .80249 m .38338 .80144 L .38323 .8014 L F
.195 .557 .934 r
.38323 .8014 m .38533 .80249 L .38547 .80251 L F
.738 .929 .953 r
.38547 .80251 m .38574 .80252 L .38664 .8045 L F
.76 .527 .58 r
.38735 .80359 m .38628 .80238 L .38574 .80252 L F
.38735 .80359 m .38574 .80252 L .38586 .80278 L F
.575 .819 .44 r
.38664 .8045 m .38806 .80267 L .38842 .80218 L F
.38664 .8045 m .38842 .80218 L .38878 .80168 L F
.76 .527 .58 r
.38735 .80359 m .38789 .80289 L .38788 .80289 L F
.38735 .80358 m .38788 .80289 L .38628 .80238 L F
.38735 .80359 m .38788 .80289 L .38735 .80358 L F
.242 .643 .961 r
.38541 .80254 m .38553 .80258 L .38547 .80251 L F
.38388 .80336 m .38553 .80258 L .38541 .80254 L F
.76 .527 .58 r
.38392 .80203 m .38533 .80251 L .38323 .8014 L F
.38664 .8045 m .38533 .80251 L .38392 .80203 L F
.242 .643 .961 r
.38541 .80254 m .38547 .80251 L .38533 .80249 L F
.814 .446 .359 r
.5396 .77837 m .54154 .78053 L .54254 .77898 L F
.686 .424 .52 r
.54254 .77898 m .54546 .78036 L .54293 .78199 L F
.584 .073 0 r
.54381 .78049 m .54254 .77898 L .54154 .78053 L F
.373 0 0 r
.54449 .78099 m .54166 .78185 L .54293 .78199 L F
.686 .424 .52 r
.54254 .77898 m .54438 .7809 L .54546 .78036 L F
.373 0 0 r
.54546 .78036 m .54438 .7809 L .54449 .78099 L F
.686 .424 .52 r
.54438 .7809 m .54515 .78171 L .54546 .78036 L F
.373 0 0 r
.54546 .78036 m .54427 .78082 L .54438 .7809 L F
.54427 .78082 m .54166 .78185 L .54449 .78099 L F
.54427 .78082 m .54419 .78155 L .54166 .78185 L F
.584 .073 0 r
.54428 .78083 m .54515 .78171 L .54438 .7809 L F
.373 0 0 r
.54546 .78036 m .54456 .7812 L .54427 .78082 L F
.958 .624 .328 r
.5445 .78112 m .54419 .78155 L .54515 .78171 L F
.373 0 0 r
.5445 .78112 m .54419 .78155 L .54427 .78082 L F
.958 .624 .328 r
.54381 .78049 m .54419 .78155 L .5445 .78112 L F
.373 0 0 r
.54456 .7812 m .54419 .78155 L .5445 .78112 L F
.584 .073 0 r
.54381 .78049 m .5445 .78112 L .54428 .78083 L F
.5445 .78112 m .54515 .78171 L .54428 .78083 L F
.54379 .78046 m .54438 .7809 L .54254 .77898 L F
.54381 .78049 m .54438 .7809 L .54379 .78046 L F
.891 .771 .723 r
.64291 .62957 m .64207 .62658 L .64162 .62872 L F
.93 .713 .588 r
.64328 .63158 m .64291 .62957 L .64162 .62872 L F
.904 .785 .72 r
.64013 .64822 m .64096 .64596 L .63967 .64505 L F
.891 .789 .741 r
.64096 .64596 m .6403 .64296 L .63967 .64505 L F
.525 .59 .862 r
.73534 .60366 m .73245 .60489 L .73312 .60366 L F
.243 0 .261 r
.73282 .60652 m .73245 .60489 L .73534 .60366 L F
.097 0 0 r
.70736 .60141 m .70947 .60152 L .71034 .60144 L F
.766 .716 .805 r
.71165 .59923 m .71034 .60144 L .70922 .59928 L F
.979 .681 .353 r
.71034 .60144 m .70947 .60152 L .70922 .59928 L F
.705 .885 .498 r
.69916 .58078 m .69781 .58325 L .70039 .58142 L F
.296 .4 .8 r
.70039 .58142 m .70157 .57937 L .69916 .58078 L F
.362 .011 .229 r
.70285 .58052 m .70277 .58178 L .70039 .58142 L F
.296 .4 .8 r
.70039 .58142 m .70277 .58178 L .70157 .57937 L F
.326 0 .215 r
.37108 .70991 m .36911 .71067 L .37183 .70869 L F
.323 0 .213 r
.37293 .70926 m .37183 .70869 L .37361 .70793 L F
.37293 .70926 m .37108 .70991 L .37183 .70869 L F
.546 .374 .599 r
.39234 .75163 m .39444 .75139 L .39446 .74891 L F
.497 .352 .614 r
.39234 .75163 m .39441 .75347 L .39444 .75139 L F
.39234 .75163 m .39258 .75412 L .39441 .75347 L F
.101 0 0 r
.45019 .78349 m .44911 .78411 L .44705 .78449 L F
.129 0 0 r
.45223 .78319 m .44911 .78411 L .45019 .78349 L F
.815 .766 .807 r
.64321 .61789 m .64602 .61849 L .64571 .61492 L F
.886 .681 .62 r
.64321 .61789 m .64574 .62044 L .64602 .61849 L F
.417 .579 .905 r
.69524 .7276 m .69671 .72622 L .69442 .72669 L F
.69524 .7276 m .69832 .7285 L .69671 .72622 L F
.457 .252 .513 r
.38322 .69739 m .38299 .69968 L .38107 .70016 L F
.46 .233 .482 r
.38273 .70176 m .38107 .70016 L .38299 .69968 L F
.38273 .70176 m .38073 .7023 L .38107 .70016 L F
.907 .939 .818 r
.70027 .71283 m .70114 .71374 L .70301 .71092 L F
.983 .7 .342 r
.70037 .71535 m .70114 .71374 L .70027 .71283 L F
.70037 .71535 m .70135 .7161 L .70114 .71374 L F
.738 .513 .587 r
.61773 .65669 m .6141 .65888 L .61397 .65694 L F
.655 .829 .409 r
.55767 .68081 m .55583 .68392 L .55657 .68252 L F
.733 .98 .756 r
.55583 .68392 m .5543 .68472 L .55657 .68252 L F
.772 .265 0 r
.70578 .59454 m .70727 .59654 L .70505 .59505 L F
.303 0 0 r
.71966 .71232 m .72201 .71225 L .7231 .71143 L F
.447 .3 .588 r
.29437 .63168 m .2927 .63464 L .29293 .63229 L F
.231 0 .303 r
.628 .62393 m .62947 .62349 L .62999 .62161 L F
.36 .314 .67 r
.62976 .62591 m .628 .62393 L .62767 .62647 L F
.62976 .62591 m .62947 .62349 L .628 .62393 L F
.402 .367 .705 r
.73066 .59556 m .7295 .59927 L .72889 .59714 L F
.7 .785 .917 r
.33786 .8682 m .34134 .86845 L .33951 .86898 L F
0 .297 .76 r
.54381 .72498 m .54614 .72634 L .54588 .72668 L F
0 .123 .657 r
.54614 .72634 m .54796 .7287 L .54588 .72668 L F
.471 .269 .524 r
.37518 .6866 m .377 .68822 L .37706 .68575 L F
.37518 .6866 m .37508 .68886 L .377 .68822 L F
.835 .706 .722 r
.57378 .68339 m .573 .686 L .57666 .6862 L F
.823 .69 .717 r
.5723 .68821 m .57666 .6862 L .573 .686 L F
.613 .38 .539 r
.57363 .68538 m .57243 .68793 L .573 .686 L F
.57243 .68793 m .5723 .68821 L .573 .686 L F
.835 .706 .722 r
.57376 .68337 m .573 .686 L .57378 .68339 L F
.492 0 0 r
.51487 .79508 m .51333 .79584 L .51155 .79531 L F
0 0 0 r
.51638 .79466 m .51487 .79508 L .51774 .79343 L F
.51638 .79466 m .51333 .79584 L .51487 .79508 L F
.435 .481 .808 r
.55556 .70062 m .55744 .70327 L .55598 .69983 L F
.93 .713 .588 r
.64328 .63158 m .64162 .62872 L .64009 .63174 L F
.881 .758 .722 r
.64099 .63452 m .64328 .63158 L .64009 .63174 L F
.53 .306 .519 r
.60373 .71022 m .6012 .71314 L .60148 .71073 L F
.809 .874 .894 r
.55832 .69725 m .56115 .69664 L .56117 .69692 L F
0 0 0 r
.56366 .69465 m .56117 .69692 L .56115 .69664 L F
.539 .756 .977 r
.33655 .71256 m .3383 .71391 L .336 .71428 L F
.855 .679 .663 r
.58085 .68632 m .57813 .68593 L .57851 .68356 L F
.825 .944 .585 r
.57884 .68909 m .57778 .69067 L .57921 .68905 L F
.58 .843 .489 r
.57967 .68845 m .57778 .69067 L .57921 .68905 L F
0 .063 .559 r
.58018 .68786 m .57813 .68593 L .58088 .68704 L F
.58095 .68858 m .58048 .6881 L .57813 .68593 L F
.58095 .68858 m .58018 .68786 L .58088 .68704 L F
.58048 .6881 m .58018 .68779 L .57999 .68761 L F
.58048 .6881 m .57999 .68761 L .57813 .68593 L F
.58088 .68704 m .57813 .68593 L .58085 .68632 L F
.903 .771 .705 r
.5788 .68644 m .58139 .68527 L .57949 .68465 L F
.184 .318 .767 r
.57999 .68761 m .57921 .68905 L .57813 .68593 L F
.58018 .68779 m .58005 .68795 L .57999 .68761 L F
.58005 .68795 m .57921 .68905 L .57999 .68761 L F
.652 .1 0 r
.57813 .68593 m .58005 .68767 L .57861 .68693 L F
.58005 .68767 m .58018 .68779 L .57861 .68693 L F
.919 .61 .133 r
.57921 .68905 m .57884 .68909 L .57813 .68593 L F
.992 .855 .502 r
.57851 .68356 m .57813 .68593 L .57757 .68513 L F
0 0 .3 r
.57813 .68593 m .57856 .68639 L .57757 .68513 L F
.57813 .68593 m .57884 .68909 L .57856 .68639 L F
.652 .1 0 r
.57813 .68593 m .57857 .68685 L .57757 .68513 L F
.837 .654 .654 r
.57884 .68909 m .57839 .68658 L .57862 .68692 L F
.652 .1 0 r
.57857 .68685 m .57861 .68693 L .5785 .68674 L F
.57857 .68685 m .5785 .68674 L .57757 .68513 L F
.867 .99 .732 r
.57651 .68859 m .57505 .69106 L .57437 .68878 L F
.746 .618 .716 r
.5734 .69127 m .57369 .69378 L .57651 .68859 L F
.837 .654 .654 r
.57884 .68909 m .57529 .69002 L .57839 .68658 L F
.57862 .68692 m .57857 .68685 L .57861 .68687 L F
.652 .1 0 r
.57857 .68685 m .58018 .68779 L .57861 .68693 L F
.57813 .68593 m .57985 .68749 L .57857 .68685 L F
.57985 .68749 m .58018 .68779 L .57857 .68685 L F
.837 .654 .654 r
.57861 .68687 m .57839 .68658 L .57856 .68639 L F
.652 .1 0 r
.57813 .68593 m .57861 .68693 L .57757 .68513 L F
.837 .654 .654 r
.57857 .68685 m .57839 .68658 L .57861 .68687 L F
.634 .395 .538 r
.57856 .68639 m .57363 .68538 L .57757 .68513 L F
.5784 .68636 m .57383 .68725 L .57363 .68538 L F
.57856 .68639 m .57839 .68642 L .5784 .68636 L F
.57839 .68642 m .57383 .68725 L .5784 .68636 L F
.693 .524 .654 r
.5723 .68821 m .5734 .69127 L .57651 .68859 L F
.681 .566 .719 r
.57856 .68639 m .57529 .69002 L .57383 .68725 L F
.984 .805 .585 r
.57708 .68883 m .57828 .68734 L .57723 .68636 L F
.57828 .68734 m .57861 .68693 L .57834 .68682 L F
.57828 .68734 m .57834 .68682 L .57723 .68636 L F
.88 .838 .8 r
.57729 .68626 m .57861 .68693 L .57855 .68404 L F
.57723 .68636 m .57861 .68693 L .57729 .68626 L F
.903 .771 .705 r
.57861 .68693 m .57904 .68668 L .5788 .68644 L F
.57904 .68668 m .58139 .68527 L .5788 .68644 L F
.58 .843 .489 r
.58018 .68779 m .57858 .68972 L .57967 .68845 L F
.57858 .68972 m .57778 .69067 L .57967 .68845 L F
.972 .923 .681 r
.58139 .68527 m .58095 .68858 L .58085 .68632 L F
.51 .247 .452 r
.43025 .75059 m .42852 .74894 L .43064 .74853 L F
.43025 .75059 m .42821 .751 L .42852 .74894 L F
.532 .708 .952 r
.56172 .72436 m .55985 .7251 L .56089 .72439 L F
.588 .556 .786 r
.55825 .72447 m .56089 .72439 L .56031 .72099 L F
.56089 .72439 m .56172 .72436 L .56144 .7237 L F
.56089 .72439 m .56144 .7237 L .56031 .72099 L F
.257 .359 .777 r
.56031 .72099 m .56172 .72436 L .56219 .72349 L F
.532 .708 .952 r
.56172 .72436 m .56089 .72439 L .56219 .72349 L F
.588 .556 .786 r
.55798 .72492 m .56172 .72436 L .55825 .72447 L F
.534 .779 .988 r
.5608 .7245 m .55985 .7251 L .56172 .72436 L F
.55798 .72492 m .55985 .7251 L .5608 .7245 L F
.635 .094 0 r
.56089 .72439 m .56089 .72444 L .56219 .72349 L F
.56089 .72444 m .56076 .72627 L .5621 .72368 L F
.56089 .72444 m .5621 .72368 L .56219 .72349 L F
.55985 .7251 m .56008 .7254 L .56089 .72439 L F
.56008 .7254 m .56076 .72627 L .56089 .72439 L F
.457 .321 .608 r
.57925 .71379 m .58161 .71508 L .5818 .71302 L F
.57925 .71379 m .57927 .71603 L .58161 .71508 L F
.634 .714 .905 r
.3851 .65626 m .38301 .65696 L .38179 .6553 L F
.463 .774 .997 r
.29089 .601 m .28909 .60129 L .28757 .6004 L F
.576 .416 .628 r
.38901 .76253 m .39134 .76229 L .39114 .75977 L F
.533 .415 .664 r
.38901 .76253 m .39127 .76453 L .39134 .76229 L F
.38901 .76253 m .38948 .76511 L .39127 .76453 L F
.469 .246 .492 r
.38553 .69464 m .38521 .69693 L .38322 .69739 L F
.45 .23 .486 r
.38714 .69639 m .38553 .69464 L .38756 .69417 L F
.38714 .69639 m .38521 .69693 L .38553 .69464 L F
.749 .771 .871 r
.68946 .58098 m .68893 .58209 L .68777 .58021 L F
.495 .367 .635 r
.4157 .75968 m .41641 .76239 L .41452 .76231 L F
0 0 .375 r
.41688 .7636 m .41452 .76231 L .41641 .76239 L F
.974 .695 .437 r
.55598 .69983 m .55744 .70327 L .55608 .70229 L F
.462 .203 .435 r
.59574 .64853 m .598 .64831 L .59843 .64562 L F
.465 .205 .435 r
.59843 .64562 m .60027 .64771 L .60081 .64545 L F
.59843 .64562 m .598 .64831 L .60027 .64771 L F
.502 .061 .134 r
.69781 .58325 m .69701 .58479 L .69481 .58464 L F
.705 .885 .498 r
.69916 .58078 m .69788 .5829 L .69781 .58325 L F
.713 .815 .354 r
.69788 .5829 m .69701 .58479 L .69781 .58325 L F
.378 .127 .402 r
.30325 .61574 m .303 .61798 L .30076 .61858 L F
.506 .321 .564 r
.3054 .61313 m .30551 .61538 L .30325 .61574 L F
.428 .168 .415 r
.3046 .61745 m .30325 .61574 L .30551 .61538 L F
.3046 .61745 m .303 .61798 L .30325 .61574 L F
.648 .453 .605 r
.5931 .70266 m .59586 .69992 L .59365 .70018 L F
.978 .686 .385 r
.57441 .74639 m .57556 .74942 L .57434 .7484 L F
.718 .62 .747 r
.5777 .74654 m .57556 .74942 L .57441 .74639 L F
.692 .153 0 r
.57805 .75053 m .57434 .7484 L .57556 .74942 L F
.977 .708 .452 r
.51186 .72983 m .51066 .73154 L .51056 .72897 L F
.096 0 0 r
.51305 .73029 m .51186 .72983 L .514 .73135 L F
.51305 .73029 m .51066 .73154 L .51186 .72983 L F
.452 .802 .998 r
.27481 .59883 m .27431 .59986 L .2728 .59907 L F
.27481 .59883 m .27631 .59956 L .27431 .59986 L F
.197 0 0 r
.4539 .72677 m .45605 .7265 L .4574 .72564 L F
.239 0 0 r
.45605 .7265 m .45953 .72586 L .4574 .72564 L F
.435 .866 .76 r
.52189 .72877 m .5233 .72831 L .52521 .72733 L F
.106 0 0 r
.46492 .72613 m .46711 .72595 L .46863 .72542 L F
.161 0 0 r
.46711 .72595 m .47081 .72511 L .46863 .72542 L F
.636 .907 .983 r
.34747 .64934 m .3451 .6489 L .34752 .64816 L F
.738 .513 .587 r
.61773 .65669 m .61776 .65901 L .6141 .65888 L F
.588 .556 .786 r
.55798 .72492 m .56031 .72099 L .55747 .72121 L F
.579 .254 .383 r
.60313 .64525 m .60546 .64524 L .6063 .64298 L F
.649 .326 .412 r
.6063 .64298 m .60546 .64524 L .60861 .64488 L F
.645 .329 .423 r
.60861 .64488 m .60889 .64319 L .6063 .64298 L F
.684 .673 .833 r
.69603 .60387 m .69721 .60555 L .69369 .60468 L F
.718 .684 .816 r
.69943 .60442 m .69721 .60555 L .69603 .60387 L F
.463 .211 .446 r
.40376 .67787 m .40142 .68079 L .40179 .67825 L F
.376 .777 .985 r
.38716 .65607 m .38855 .65669 L .3851 .65626 L F
.238 .672 .959 r
.38855 .65669 m .38952 .6563 L .39078 .65714 L F
.589 .179 .232 r
.38716 .65607 m .38952 .6563 L .38855 .65669 L F
.115 .271 .747 r
.3905 .65855 m .38855 .65669 L .39078 .65714 L F
.682 .4 .489 r
.45908 .77329 m .46123 .77338 L .46244 .77281 L F
.507 .115 .232 r
.46123 .77338 m .46466 .77275 L .46244 .77281 L F
.744 .501 .564 r
.58581 .75654 m .58236 .75428 L .58606 .75445 L F
.706 .485 .587 r
.58606 .75445 m .58789 .75703 L .58581 .75654 L F
.503 .433 .71 r
.33338 .84206 m .33531 .84381 L .33434 .8398 L F
.771 .938 .937 r
.55814 .67919 m .55767 .68081 L .55618 .67957 L F
.134 .547 .922 r
.55618 .67957 m .55767 .68081 L .55606 .6794 L F
.969 .719 .29 r
.55606 .6794 m .55565 .67962 L .55618 .67957 L F
.966 .691 .265 r
.55606 .6794 m .55609 .67958 L .55565 .67962 L F
.225 0 0 r
.55565 .67962 m .55609 .67958 L .55607 .67958 L F
.966 .691 .265 r
.55609 .67958 m .55657 .68252 L .55565 .67962 L F
.225 0 0 r
.55565 .67962 m .5563 .67955 L .55609 .67958 L F
.55565 .67962 m .55814 .67919 L .5563 .67955 L F
.55607 .67958 m .5563 .67955 L .55618 .67957 L F
.655 .829 .409 r
.55767 .68081 m .55657 .68252 L .55609 .67958 L F
.55624 .67956 m .55609 .67958 L .55606 .6794 L F
.55767 .68081 m .55609 .67958 L .55624 .67956 L F
.771 .938 .937 r
.55814 .67919 m .56072 .67895 L .55767 .68081 L F
.455 .285 .56 r
.38927 .77854 m .39117 .77573 L .3892 .77616 L F
.886 .681 .62 r
.64321 .61789 m .64309 .62083 L .64574 .62044 L F
.891 .824 .775 r
.64309 .62083 m .64368 .62367 L .64574 .62044 L F
.734 .747 .863 r
.30952 .73822 m .31132 .74046 L .31326 .73922 L F
.65 .969 .876 r
.31132 .74046 m .31128 .73974 L .31326 .73922 L F
.724 .581 .004 r
.31132 .74046 m .31131 .74134 L .31128 .73974 L F
0 0 0 r
.44945 .77242 m .44812 .7736 L .44937 .7726 L F
.522 .911 .929 r
.44812 .7736 m .44741 .77339 L .44937 .7726 L F
.524 .788 .993 r
.39796 .79361 m .40115 .79448 L .40036 .79277 L F
.673 .778 .929 r
.40036 .79277 m .40115 .79448 L .4039 .79363 L F
.591 .429 .631 r
.59644 .71843 m .59403 .71645 L .59643 .71628 L F
.59644 .71843 m .59415 .71882 L .59403 .71645 L F
.499 .284 .518 r
.63861 .61546 m .64119 .61228 L .63917 .6131 L F
.498 .172 .345 r
.6364 .61553 m .63861 .61546 L .63917 .6131 L F
.604 .938 .742 r
.49743 .71409 m .49836 .71298 L .49909 .71265 L F
.49743 .71409 m .4957 .715 L .49836 .71298 L F
.426 0 0 r
.44423 .74645 m .44098 .74737 L .44208 .74658 L F
.246 0 .115 r
.67767 .58045 m .67922 .5809 L .68006 .5798 L F
.67767 .58045 m .67674 .58215 L .67922 .5809 L F
.415 .443 .781 r
.69029 .71585 m .69301 .71899 L .69245 .71515 L F
.446 .23 .491 r
.38521 .69693 m .38299 .69968 L .38322 .69739 L F
.527 .228 .403 r
.71435 .71544 m .7122 .71404 L .71199 .71569 L F
.71435 .71544 m .71461 .71379 L .7122 .71404 L F
.571 .534 .775 r
.37916 .67826 m .38017 .67569 L .37756 .67455 L F
.37916 .67826 m .38133 .67806 L .38017 .67569 L F
.408 .265 .574 r
.37916 .67826 m .38086 .68014 L .38133 .67806 L F
.37916 .67826 m .3793 .68086 L .38086 .68014 L F
0 0 0 r
.68363 .59427 m .68523 .59262 L .68265 .59505 L F
.438 0 0 r
.68772 .59389 m .68523 .59262 L .68363 .59427 L F
0 .405 .797 r
.68816 .59385 m .68523 .59262 L .68772 .59389 L F
.632 .455 .625 r
.72637 .72709 m .72923 .72764 L .72853 .72453 L F
.29 .321 .722 r
.72853 .72453 m .73026 .72353 L .72805 .72131 L F
0 0 .523 r
.72853 .72453 m .72994 .72613 L .73026 .72353 L F
.72853 .72453 m .72923 .72764 L .72994 .72613 L F
.209 0 0 r
.49841 .72769 m .49725 .72702 L .49912 .72642 L F
.49841 .72769 m .49602 .72843 L .49725 .72702 L F
.518 0 0 r
.54064 .72386 m .54381 .72498 L .54221 .72379 L F
.709 .685 .825 r
.67869 .6132 m .6774 .61649 L .67577 .61392 L F
.67869 .6132 m .67949 .61593 L .6774 .61649 L F
.178 .652 .932 r
.38584 .78713 m .38851 .7876 L .38794 .78734 L F
.329 0 0 r
.47842 .781 m .47688 .7813 L .47478 .78109 L F
.4 0 0 r
.47842 .781 m .48028 .78131 L .47688 .7813 L F
.379 .598 .932 r
.66607 .60987 m .66709 .61154 L .66964 .61195 L F
.411 .567 .898 r
.54991 .7117 m .55326 .71349 L .5513 .71029 L F
.468 .264 .52 r
.30076 .61858 m .30028 .62121 L .2987 .62149 L F
.481 .276 .524 r
.30332 .61812 m .30076 .61858 L .303 .61798 L F
.30332 .61812 m .30028 .62121 L .30076 .61858 L F
.461 .536 .848 r
.53415 .72029 m .53279 .72202 L .53146 .71918 L F
.456 .528 .843 r
.53486 .72206 m .53279 .72202 L .53415 .72029 L F
0 .194 .722 r
.5679 .73808 m .56815 .73747 L .56632 .73575 L F
0 0 .566 r
.5679 .73808 m .56929 .74022 L .56815 .73747 L F
.401 .848 .921 r
.4227 .78893 m .42118 .78889 L .42035 .78956 L F
.446 .859 .698 r
.42118 .78889 m .41935 .79002 L .42035 .78956 L F
.418 .136 .375 r
.36915 .69744 m .36662 .69973 L .36843 .6992 L F
.339 .11 .412 r
.37128 .69466 m .36915 .69744 L .37087 .69665 L F
.227 0 .251 r
.36843 .6992 m .37087 .69665 L .36915 .69744 L F
.276 0 0 r
.72527 .71078 m .72779 .71163 L .72828 .71166 L F
0 .438 .84 r
.73013 .71198 m .73108 .71279 L .72828 .71166 L F
.73013 .71198 m .72828 .71166 L .72779 .71163 L F
0 .361 .723 r
.72828 .71166 m .73108 .71279 L .73213 .71333 L F
0 .201 .697 r
.72968 .62194 m .7319 .62382 L .73128 .62299 L F
.289 .125 .478 r
.73146 .6185 m .73136 .62073 L .72968 .62194 L F
0 .201 .697 r
.73128 .62299 m .72968 .62194 L .73136 .62073 L F
.73128 .62299 m .7319 .62382 L .72968 .62194 L F
.249 0 0 r
.32426 .73812 m .32273 .73823 L .32039 .73787 L F
.588 .931 .739 r
.32255 .7381 m .32039 .73787 L .32273 .73823 L F
.458 .094 .259 r
.32289 .73603 m .32039 .73787 L .31918 .73774 L F
.761 .55 .612 r
.32426 .73812 m .32039 .73787 L .32289 .73603 L F
.588 .931 .739 r
.32097 .73695 m .32039 .73787 L .32255 .7381 L F
.458 .094 .259 r
.31918 .73774 m .32039 .73787 L .3184 .7381 L F
.761 .55 .612 r
.32426 .73812 m .32289 .73603 L .32329 .73592 L F
.524 .283 .491 r
.62062 .63201 m .62289 .63166 L .62298 .62959 L F
.533 .273 .467 r
.62289 .63166 m .62532 .62933 L .62298 .62959 L F
.188 0 .083 r
.35751 .71997 m .3567 .71874 L .35823 .71896 L F
.35751 .71997 m .35556 .72073 L .3567 .71874 L F
0 .076 .636 r
.67932 .6238 m .6798 .62307 L .67794 .62058 L F
0 .107 .66 r
.67932 .6238 m .68052 .62555 L .6798 .62307 L F
.488 .511 .807 r
.30779 .73938 m .30917 .74258 L .30755 .7431 L F
.748 .646 .749 r
.31128 .73974 m .30917 .74258 L .30779 .73938 L F
.779 .992 .769 r
.30959 .74129 m .30834 .74259 L .30917 .74258 L F
.363 .153 .455 r
.30917 .74258 m .30726 .74557 L .30755 .7431 L F
0 0 .127 r
.30755 .7431 m .30738 .74458 L .3068 .74579 L F
.615 .64 .852 r
.30503 .74314 m .30755 .7431 L .30513 .74331 L F
.432 .781 .997 r
.30653 .74229 m .30755 .7431 L .30503 .74314 L F
.488 .511 .807 r
.30779 .73938 m .30755 .7431 L .30653 .74229 L F
.769 .658 .74 r
.30653 .74229 m .30726 .74557 L .30917 .74258 L F
.30653 .74229 m .30917 .74258 L .30713 .74384 L F
.779 .992 .769 r
.30834 .74259 m .30713 .74384 L .30799 .74331 L F
.30834 .74259 m .30799 .74331 L .30917 .74258 L F
0 0 .127 r
.3068 .74579 m .30726 .74557 L .30666 .74627 L F
.30738 .74458 m .30726 .74557 L .3068 .74579 L F
.434 .858 .947 r
.30666 .74627 m .30485 .74617 L .30632 .74686 L F
.30666 .74627 m .30726 .74557 L .30485 .74617 L F
.678 .601 .762 r
.68759 .70706 m .6886 .71051 L .69077 .70796 L F
.766 .673 .761 r
.33786 .8682 m .33917 .87119 L .34134 .86845 L F
.461 .21 .446 r
.61311 .7025 m .61332 .70493 L .61104 .70544 L F
.326 .094 .401 r
.61311 .7025 m .61483 .70411 L .61332 .70493 L F
.61311 .7025 m .61529 .70209 L .61483 .70411 L F
.379 0 0 r
.73375 .71428 m .73213 .71333 L .73108 .71279 L F
.73375 .71428 m .73506 .71474 L .73213 .71333 L F
0 0 0 r
.36522 .67079 m .36158 .67166 L .36313 .67056 L F
.704 .849 .952 r
.33531 .84381 m .33392 .84493 L .33235 .84505 L F
.468 .222 .458 r
.60147 .69984 m .60384 .6974 L .60091 .69695 L F
.643 .697 .885 r
.70179 .61527 m .70506 .61616 L .70411 .61457 L F
.692 .719 .87 r
.70411 .61457 m .70506 .61616 L .70739 .61526 L F
.603 .301 .43 r
.40703 .73703 m .41254 .73447 L .40855 .73545 L F
0 0 0 r
.56366 .69465 m .56257 .69625 L .56117 .69692 L F
.524 .301 .517 r
.56524 .6937 m .56257 .69625 L .56366 .69465 L F
.097 0 0 r
.43886 .78609 m .43576 .78624 L .43708 .78615 L F
.393 .042 .246 r
.37015 .7125 m .36911 .71067 L .37108 .70991 L F
.37015 .7125 m .36804 .71299 L .36911 .71067 L F
.138 0 .11 r
.58648 .65654 m .58747 .65755 L .58825 .65559 L F
.58648 .65654 m .58566 .65862 L .58747 .65755 L F
.413 .782 .994 r
.4313 .6998 m .4334 .69959 L .43478 .70033 L F
.43478 .70033 m .4334 .69959 L .4313 .6998 L F
.454 .801 .998 r
.43478 .70033 m .43706 .70001 L .4334 .69959 L F
.43478 .70033 m .43706 .70001 L .4334 .69959 L F
.279 0 0 r
.34172 .72732 m .34014 .72894 L .33807 .72933 L F
.057 0 0 r
.34202 .72816 m .34172 .72732 L .34346 .72648 L F
.34202 .72816 m .34014 .72894 L .34172 .72732 L F
.679 .605 .766 r
.31224 .69755 m .31013 .69999 L .31005 .69811 L F
.671 .779 .931 r
.6839 .60213 m .68482 .60413 L .68266 .60488 L F
.471 .186 .399 r
.59869 .75142 m .59828 .75411 L .59593 .75459 L F
.523 .336 .569 r
.60071 .74885 m .60078 .75086 L .59869 .75142 L F
.412 .136 .382 r
.60033 .75337 m .59869 .75142 L .60078 .75086 L F
.60033 .75337 m .59828 .75411 L .59869 .75142 L F
.829 .823 .843 r
.72923 .72764 m .72779 .72836 L .7288 .72941 L F
.909 .933 .815 r
.70889 .58323 m .70603 .58524 L .70744 .5824 L F
.70889 .58323 m .70687 .58602 L .70603 .58524 L F
.505 .284 .512 r
.39829 .74104 m .40041 .74067 L .40082 .73803 L F
.532 .307 .519 r
.40082 .73803 m .40041 .74067 L .40277 .74011 L F
.657 .302 .359 r
.40082 .73803 m .40277 .74011 L .40333 .73857 L F
.311 .509 .889 r
.2996 .60442 m .29818 .60434 L .29628 .6017 L F
.693 .666 .818 r
.31797 .71032 m .31458 .70835 L .31677 .7076 L F
.661 .643 .821 r
.32024 .70864 m .31797 .71032 L .31677 .7076 L F
.475 .294 .554 r
.30004 .62296 m .2987 .62149 L .30028 .62121 L F
.30004 .62296 m .29853 .62377 L .2987 .62149 L F
.446 .868 .94 r
.51824 .78443 m .51925 .7836 L .52041 .78398 L F
.986 .77 .372 r
.66767 .59699 m .66691 .59803 L .66819 .59565 L F
.66767 .59699 m .6676 .59928 L .66691 .59803 L F
.544 .524 .784 r
.55485 .71936 m .55583 .71594 L .55373 .71637 L F
.55485 .71936 m .55678 .71911 L .55583 .71594 L F
.608 .553 .767 r
.55533 .7214 m .55678 .71911 L .55485 .71936 L F
.639 .716 .903 r
.72986 .58553 m .72575 .58365 L .72761 .5831 L F
.489 .783 .997 r
.73072 .58403 m .72986 .58553 L .72761 .5831 L F
.73072 .58403 m .7316 .58499 L .72986 .58553 L F
.289 .75 .949 r
.28173 .59979 m .27983 .59993 L .27841 .59947 L F
.828 .606 .602 r
.61967 .66223 m .61909 .66443 L .61715 .66147 L F
.36 0 .067 r
.3072 .73824 m .31169 .73689 L .30605 .73503 L F
.3072 .73824 m .30952 .73822 L .31169 .73689 L F
.875 .813 .784 r
.68723 .6174 m .69054 .61557 L .68946 .6142 L F
.68723 .6174 m .68846 .6185 L .69054 .61557 L F
.783 .814 .877 r
.68946 .6142 m .69054 .61557 L .69294 .61326 L F
.56 .393 .611 r
.39444 .75139 m .39658 .7485 L .39446 .74891 L F
0 0 .326 r
.32535 .73552 m .32426 .73812 L .32329 .73592 L F
.598 .742 .945 r
.70739 .61526 m .71067 .61603 L .70957 .6147 L F
.696 .78 .916 r
.70957 .6147 m .71067 .61603 L .71294 .61504 L F
.536 .329 .547 r
.32367 .69098 m .32174 .68912 L .32426 .68903 L F
.32367 .69098 m .32192 .69164 L .32174 .68912 L F
.237 .754 .826 r
.52595 .78888 m .52464 .78932 L .52699 .78893 L F
.52595 .78888 m .52395 .78925 L .52464 .78932 L F
.468 .222 .458 r
.60147 .69984 m .6037 .6994 L .60384 .6974 L F
.59 .323 .48 r
.6037 .6994 m .60608 .69925 L .60384 .6974 L F
.578 .327 .499 r
.60384 .6974 m .60608 .69925 L .60625 .69719 L F
0 .164 .67 r
.67615 .59495 m .67478 .59416 L .67464 .59297 L F
.67615 .59495 m .67718 .59623 L .67478 .59416 L F
.468 .072 .204 r
.4372 .7293 m .43944 .72911 L .44065 .72718 L F
.541 .149 .247 r
.44065 .72718 m .44266 .72838 L .44299 .72738 L F
.44065 .72718 m .43944 .72911 L .44266 .72838 L F
.311 .765 .954 r
.42558 .78914 m .4227 .78893 L .42351 .78912 L F
.757 .929 .944 r
.70687 .58602 m .70302 .58694 L .70603 .58524 L F
.027 0 0 r
.47302 .72462 m .47613 .72392 L .47403 .72458 L F
.339 0 0 r
.47322 .78092 m .47129 .7813 L .4692 .78114 L F
.391 0 0 r
.47478 .78109 m .47129 .7813 L .47322 .78092 L F
.33 0 .189 r
.34049 .71153 m .34006 .71294 L .33882 .71264 L F
.623 .724 .919 r
.34072 .70798 m .34049 .71153 L .33861 .70971 L F
.235 0 0 r
.34049 .71153 m .34333 .71129 L .34375 .71114 L F
.623 .724 .919 r
.34072 .70798 m .34333 .71129 L .34049 .71153 L F
.402 .165 .436 r
.37128 .69466 m .37273 .69583 L .37343 .69431 L F
.37128 .69466 m .37087 .69665 L .37273 .69583 L F
0 0 .416 r
.6546 .60782 m .65564 .60824 L .65433 .60676 L F
.6546 .60782 m .655 .60936 L .65564 .60824 L F
.181 .266 .717 r
.71672 .61791 m .7174 .62112 L .71869 .61997 L F
.418 .679 .97 r
.71869 .61997 m .7174 .62112 L .71967 .62115 L F
.523 .805 .997 r
.61749 .6341 m .61859 .63499 L .6152 .63452 L F
.61749 .6341 m .61859 .63499 L .6152 .63452 L F
.439 .253 .53 r
.61859 .63499 m .62083 .63402 L .62062 .63201 L F
.53 .274 .471 r
.61797 .63565 m .62083 .63402 L .61859 .63499 L F
.577 .59 .829 r
.54729 .73847 m .5462 .73781 L .54761 .73805 L F
.585 .419 .623 r
.54761 .73805 m .54784 .74086 L .54544 .74088 L F
.523 .372 .619 r
.54995 .74025 m .54784 .74086 L .54761 .73805 L F
.697 .155 0 r
.54937 .73967 m .54508 .73713 L .5462 .73781 L F
.972 .804 .616 r
.54673 .73517 m .5462 .73781 L .54498 .73707 L F
.697 .155 0 r
.54508 .73713 m .54498 .73707 L .5462 .73781 L F
.577 .59 .829 r
.54544 .74088 m .5462 .73781 L .54729 .73847 L F
.54544 .74088 m .54784 .74086 L .5462 .73781 L F
.676 .549 .703 r
.31013 .69999 m .31242 .69982 L .31212 .69917 L F
.592 .51 .731 r
.31212 .69917 m .31429 .69686 L .31529 .69855 L F
.31212 .69917 m .31242 .69982 L .31284 .69915 L F
.542 .374 .603 r
.31302 .69908 m .31284 .69915 L .31266 .69916 L F
.31284 .69903 m .31266 .69916 L .31212 .69917 L F
.592 .51 .731 r
.31212 .69917 m .31284 .69915 L .31429 .69686 L F
.646 .58 .767 r
.31429 .69686 m .31284 .69915 L .31224 .69755 L F
.31284 .69915 m .31242 .69982 L .31239 .69936 L F
.31284 .69915 m .31239 .69936 L .31224 .69755 L F
.542 .374 .603 r
.31529 .69855 m .31479 .69912 L .31284 .69915 L F
.31529 .69855 m .31284 .69915 L .31302 .69908 L F
.31529 .69855 m .31266 .69916 L .31284 .69903 L F
.31479 .69912 m .31264 .70153 L .31212 .69917 L F
.612 .496 .697 r
.31219 .6995 m .31013 .69999 L .31212 .69917 L F
.679 .605 .766 r
.31219 .6995 m .31242 .69982 L .3117 .69987 L F
.31239 .69936 m .3117 .69987 L .31013 .69999 L F
.612 .496 .697 r
.31264 .70153 m .31013 .69999 L .31219 .6995 L F
.679 .605 .766 r
.31239 .69936 m .3124 .69946 L .31219 .6995 L F
.3124 .69946 m .31242 .69982 L .31219 .6995 L F
.31224 .69755 m .31239 .69936 L .31013 .69999 L F
.612 .496 .697 r
.31264 .70153 m .31061 .70347 L .31013 .69999 L F
.66 .172 .08 r
.50523 .7245 m .50424 .72536 L .50185 .72397 L F
.964 .657 .251 r
.70142 .7174 m .70231 .71863 L .70135 .7161 L F
.298 0 0 r
.70278 .71885 m .70231 .71863 L .70142 .7174 L F
.70278 .71885 m .70431 .71954 L .70231 .71863 L F
.904 .785 .72 r
.64013 .64822 m .63967 .64505 L .63896 .64738 L F
.942 .864 .734 r
.63879 .65099 m .64013 .64822 L .63896 .64738 L F
.362 .509 .87 r
.7336 .58514 m .73227 .58658 L .7316 .58499 L F
.7336 .58514 m .73555 .58826 L .73227 .58658 L F
.456 .058 .195 r
.42133 .73436 m .42431 .73289 L .42195 .73288 L F
.608 .553 .767 r
.55533 .7214 m .55747 .72121 L .55678 .71911 L F
.178 0 .26 r
.28651 .6431 m .28573 .64505 L .2842 .64575 L F
.097 0 .099 r
.2842 .64575 m .28573 .64505 L .28355 .64708 L F
.165 .701 .731 r
.37647 .66935 m .37498 .66958 L .37434 .66976 L F
0 0 0 r
.37498 .66958 m .37261 .67098 L .37434 .66976 L F
.572 .391 .598 r
.41954 .75594 m .41874 .75451 L .42083 .7542 L F
.41954 .75594 m .4183 .75693 L .41874 .75451 L F
.615 .417 .591 r
.59872 .71372 m .59878 .71613 L .59643 .71628 L F
.585 .394 .589 r
.6008 .7153 m .59872 .71372 L .6012 .71314 L F
.6008 .7153 m .59878 .71613 L .59872 .71372 L F
.922 .66 .522 r
.33861 .70971 m .33514 .70899 L .33712 .70846 L F
.33861 .70971 m .33747 .71261 L .33514 .70899 L F
.572 .894 .987 r
.33861 .70971 m .3389 .70784 L .34072 .70798 L F
.33861 .70971 m .33712 .70846 L .3389 .70784 L F
.633 .381 .518 r
.31633 .69645 m .31456 .69471 L .3166 .69463 L F
.31633 .69645 m .31429 .69686 L .31456 .69471 L F
.841 .985 .866 r
.56663 .69063 m .56644 .69226 L .5679 .69101 L F
.728 .975 .924 r
.56937 .68882 m .5679 .69101 L .57057 .68962 L F
.56937 .68882 m .56663 .69063 L .5679 .69101 L F
.528 .245 .428 r
.72359 .72993 m .72582 .72963 L .72637 .72709 L F
.63 .339 .458 r
.72637 .72709 m .72779 .72836 L .72923 .72764 L F
.72637 .72709 m .72582 .72963 L .72779 .72836 L F
.298 .033 .332 r
.62947 .62349 m .63179 .62073 L .62999 .62161 L F
.476 .187 .395 r
.33431 .68102 m .3339 .68269 L .33173 .68316 L F
.446 .16 .384 r
.33547 .68226 m .33431 .68102 L .33622 .68046 L F
.33547 .68226 m .3339 .68269 L .33431 .68102 L F
.552 .479 .726 r
.39114 .75977 m .39278 .75725 L .39064 .75767 L F
.39114 .75977 m .39317 .7594 L .39278 .75725 L F
.485 .348 .619 r
.39114 .75977 m .39317 .76177 L .39317 .7594 L F
.39114 .75977 m .39134 .76229 L .39317 .76177 L F
.733 .709 .829 r
.69294 .61326 m .69615 .61373 L .69495 .61238 L F
.706 .704 .845 r
.69495 .61238 m .69615 .61373 L .69842 .61285 L F
.471 .669 .95 r
.38034 .65354 m .37987 .65535 L .37834 .65304 L F
.38034 .65354 m .38179 .6553 L .37987 .65535 L F
.492 .423 .707 r
.70049 .58975 m .70327 .59158 L .70291 .58929 L F
.241 0 0 r
.70049 .58975 m .70222 .59038 L .7005 .58999 L F
0 0 0 r
.70047 .58947 m .69842 .59146 L .70049 .58975 L F
.241 0 0 r
.70049 .58975 m .7005 .58999 L .69969 .5898 L F
0 0 0 r
.7015 .58848 m .70047 .58947 L .70049 .58975 L F
.21 .289 .727 r
.57981 .73972 m .57976 .73866 L .57809 .73807 L F
.57981 .73972 m .57929 .73716 L .57976 .73866 L F
.908 .705 .615 r
.57929 .73716 m .57976 .73866 L .57976 .73866 L F
.57929 .73716 m .57976 .73866 L .58208 .74069 L F
.21 .289 .727 r
.57976 .73866 m .57929 .73716 L .57967 .73678 L F
.57976 .73866 m .57967 .73678 L .57873 .73755 L F
.57976 .73866 m .57873 .73755 L .57809 .73807 L F
.908 .705 .615 r
.57976 .73866 m .58044 .74087 L .58168 .74073 L F
.57976 .73866 m .58168 .74073 L .58208 .74069 L F
0 0 0 r
.58159 .74217 m .57996 .7435 L .58208 .74069 L F
.58159 .74217 m .58208 .74069 L .58044 .74087 L F
.448 .845 .977 r
.33811 .65016 m .34026 .64967 L .34177 .65011 L F
.343 0 0 r
.34026 .64967 m .34382 .64946 L .34177 .65011 L F
.628 .619 .822 r
.5978 .74722 m .60012 .74655 L .60071 .74885 L F
.507 .462 .741 r
.60224 .74571 m .60071 .74885 L .60012 .74655 L F
.60224 .74571 m .60334 .74787 L .60071 .74885 L F
.387 .208 .514 r
.60334 .74787 m .60078 .75086 L .60071 .74885 L F
.087 0 0 r
.3914 .78696 m .38794 .78734 L .38851 .7876 L F
.3914 .78696 m .39026 .78724 L .38794 .78734 L F
.484 .523 .822 r
.3914 .78696 m .39439 .78941 L .3935 .7866 L F
.105 0 0 r
.3935 .7866 m .39026 .78724 L .3914 .78696 L F
.599 .674 .893 r
.40211 .66707 m .39847 .66553 L .40097 .66573 L F
.392 .627 .947 r
.40289 .66577 m .40211 .66707 L .40097 .66573 L F
.40289 .66577 m .40408 .66732 L .40211 .66707 L F
.616 .327 .455 r
.42721 .73188 m .42945 .73209 L .42991 .73021 L F
.5 .187 .367 r
.42945 .73209 m .43273 .72928 L .42991 .73021 L F
.372 .12 .397 r
.68459 .57723 m .6826 .57805 L .68245 .57966 L F
.382 0 0 r
.41254 .73447 m .41287 .73467 L .41408 .73538 L F
.982 .752 .515 r
.41287 .73467 m .41281 .73711 L .41408 .73538 L F
.05 0 0 r
.41281 .73711 m .41632 .73515 L .41408 .73538 L F
.435 0 0 r
.4581 .78168 m .45891 .78298 L .45676 .78281 L F
.4581 .78168 m .46036 .78182 L .45891 .78298 L F
.361 .722 .987 r
.40408 .66732 m .4064 .66735 L .40728 .66835 L F
.329 .531 .899 r
.40846 .66673 m .40728 .66835 L .4064 .66735 L F
.40846 .66673 m .40975 .66896 L .40728 .66835 L F
.455 .43 .742 r
.40728 .66835 m .40975 .66896 L .408 .67 L F
.753 .675 .775 r
.57648 .67998 m .57632 .68112 L .57918 .68124 L F
.331 0 0 r
.67922 .5809 m .68245 .57966 L .68006 .5798 L F
.373 .032 .253 r
.3253 .65657 m .32738 .65609 L .32833 .65379 L F
.267 0 .203 r
.32833 .65379 m .32915 .65536 L .33025 .65301 L F
.32833 .65379 m .32738 .65609 L .32915 .65536 L F
.763 .995 .859 r
.34375 .71114 m .34535 .70905 L .34557 .71009 L F
.34375 .71114 m .34333 .71129 L .34535 .70905 L F
0 0 0 r
.51802 .79331 m .51774 .79343 L .51951 .79223 L F
.51802 .79331 m .51638 .79466 L .51774 .79343 L F
.588 .571 .802 r
.64596 .6051 m .6476 .60678 L .64817 .60412 L F
.554 .366 .581 r
.64817 .60412 m .65078 .60412 L .65027 .60217 L F
.643 .574 .762 r
.6476 .60678 m .65078 .60412 L .64817 .60412 L F
.561 .462 .699 r
.30677 .60925 m .30741 .61294 L .3054 .61313 L F
.631 .466 .642 r
.30741 .61294 m .30551 .61538 L .3054 .61313 L F
.44 .123 .33 r
.59593 .75459 m .59337 .75647 L .59367 .75481 L F
.384 .532 .881 r
.58443 .74494 m .58344 .7466 L .58233 .74648 L F
.58443 .74494 m .58542 .74689 L .58344 .7466 L F
.634 .874 .986 r
.39078 .65714 m .38952 .6563 L .39288 .65588 L F
.43 .73 .989 r
.39514 .65868 m .39349 .65925 L .39146 .65771 L F
.157 0 .2 r
.39198 .65642 m .39096 .65788 L .39078 .65714 L F
.39096 .65788 m .39089 .65799 L .39088 .65791 L F
.39096 .65788 m .39088 .65791 L .39078 .65714 L F
.39089 .65799 m .3905 .65855 L .39058 .65814 L F
.39089 .65799 m .39058 .65814 L .39078 .65714 L F
.517 .644 .913 r
.39089 .65799 m .39349 .65925 L .39148 .65929 L F
.747 .644 .747 r
.39116 .65609 m .39074 .65765 L .39288 .65588 L F
.517 .644 .913 r
.39074 .65765 m .39108 .65789 L .39089 .65799 L F
.39074 .65765 m .39089 .65799 L .3905 .65855 L F
.747 .644 .747 r
.39074 .65765 m .3905 .65855 L .39108 .65789 L F
.517 .644 .913 r
.39146 .65771 m .39349 .65925 L .39089 .65799 L F
.157 0 .2 r
.39288 .65588 m .3905 .65855 L .39198 .65642 L F
.747 .644 .747 r
.39074 .65765 m .39108 .65789 L .39288 .65588 L F
.38952 .6563 m .3905 .65855 L .39116 .6561 L F
.38952 .6563 m .39116 .6561 L .39116 .65609 L F
.589 .179 .232 r
.38716 .65607 m .38816 .65646 L .38952 .6563 L F
.38816 .65646 m .39013 .65725 L .38952 .6563 L F
.517 .644 .913 r
.39041 .65692 m .39146 .65771 L .39108 .65789 L F
.39041 .65692 m .39108 .65789 L .39074 .65765 L F
.43 .73 .989 r
.39202 .65752 m .39146 .65771 L .39041 .65692 L F
.39514 .65868 m .39146 .65771 L .39202 .65752 L F
.517 .644 .913 r
.39041 .65692 m .39074 .65765 L .3905 .65855 L F
.39089 .65799 m .39148 .65929 L .3905 .65855 L F
.446 .799 .997 r
.48905 .77495 m .48805 .7759 L .48681 .77525 L F
.357 .656 .969 r
.48905 .77495 m .48987 .77604 L .48805 .7759 L F
.617 .692 .897 r
.70337 .57529 m .70422 .57727 L .70223 .57792 L F
.412 .336 .661 r
.70223 .57792 m .70355 .57923 L .70285 .58052 L F
.70355 .57923 m .70449 .58015 L .70312 .58046 L F
.70355 .57923 m .70312 .58046 L .70285 .58052 L F
.731 .29 .203 r
.70157 .57937 m .70337 .57985 L .70223 .57792 L F
.70337 .57985 m .70449 .58015 L .70355 .57923 L F
.70337 .57985 m .70355 .57923 L .70223 .57792 L F
.268 0 .215 r
.70449 .58015 m .70277 .58178 L .70285 .58052 L F
.764 .636 .72 r
.70337 .57985 m .70277 .58178 L .70449 .58015 L F
.70157 .57937 m .70273 .5817 L .70337 .57985 L F
.70273 .5817 m .70277 .58178 L .70337 .57985 L F
0 0 0 r
.7033 .58015 m .70372 .57882 L .70434 .57706 L F
.70372 .57882 m .70397 .57804 L .70418 .57749 L F
.70372 .57882 m .70418 .57749 L .70434 .57706 L F
.70397 .57804 m .70422 .57727 L .70428 .57717 L F
.70397 .57804 m .70428 .57717 L .70434 .57706 L F
.731 .29 .203 r
.70157 .57937 m .70223 .57792 L .70422 .57727 L F
.5 .895 .945 r
.57179 .66978 m .57311 .66869 L .57452 .66736 L F
.57179 .66978 m .57118 .66944 L .57311 .66869 L F
.46 .67 .954 r
.53838 .72285 m .53644 .72324 L .53486 .72206 L F
.53838 .72285 m .53857 .72349 L .53644 .72324 L F
.548 .391 .62 r
.29243 .68374 m .29456 .68345 L .29442 .68083 L F
.555 .329 .526 r
.29202 .68593 m .29456 .68345 L .29243 .68374 L F
.643 .574 .762 r
.6476 .60678 m .65183 .60602 L .65078 .60412 L F
.704 .749 .887 r
.65055 .61329 m .64719 .61273 L .64944 .61233 L F
.65055 .61329 m .64719 .61273 L .64944 .61233 L F
.491 .82 1 r
.65055 .61329 m .65191 .61213 L .64944 .61233 L F
.65055 .61329 m .65286 .61287 L .65191 .61213 L F
.65055 .61329 m .65191 .61213 L .64944 .61233 L F
.65055 .61329 m .65286 .61287 L .65191 .61213 L F
0 .446 .693 r
.35632 .64847 m .35692 .64859 L .35825 .64887 L F
0 0 0 r
.35548 .64925 m .3577 .64876 L .35692 .64859 L F
.264 .728 .948 r
.35692 .64859 m .35897 .64848 L .36026 .64904 L F
0 0 0 r
.3577 .64876 m .35897 .64848 L .35692 .64859 L F
0 .446 .693 r
.35489 .64816 m .35692 .64859 L .35632 .64847 L F
.264 .728 .948 r
.35692 .64859 m .36026 .64904 L .35825 .64887 L F
.575 .321 .494 r
.60618 .70818 m .60621 .71001 L .60373 .71022 L F
.628 .363 .497 r
.60618 .70818 m .60846 .71024 L .60621 .71001 L F
.543 .374 .602 r
.6084 .70775 m .60846 .71024 L .60618 .70818 L F
.6084 .70775 m .60846 .71024 L .60618 .70818 L F
.502 .176 .347 r
.36548 .70184 m .36843 .6992 L .36662 .69973 L F
.83 .907 .892 r
.5619 .67738 m .56072 .67895 L .55814 .67919 L F
.734 .827 .923 r
.30472 .73203 m .30657 .73291 L .30818 .73202 L F
.652 .336 .425 r
.59833 .702 m .60084 .70232 L .60147 .69984 L F
.521 .212 .384 r
.60147 .69984 m .60361 .70146 L .6037 .6994 L F
.60147 .69984 m .60084 .70232 L .60361 .70146 L F
.588 .698 .919 r
.32368 .71032 m .32024 .70864 L .32221 .70767 L F
.634 .652 .85 r
.3257 .70954 m .32368 .71032 L .32221 .70767 L F
.804 .737 .79 r
.6828 .62301 m .68626 .62303 L .68514 .62034 L F
.6828 .62301 m .6844 .62426 L .68626 .62303 L F
.799 .751 .809 r
.68514 .62034 m .68626 .62303 L .68812 .62059 L F
.951 .777 .631 r
.54761 .73805 m .5462 .73781 L .54673 .73517 L F
.481 .717 .974 r
.37699 .65172 m .37631 .65322 L .37495 .65186 L F
.37699 .65172 m .37834 .65304 L .37631 .65322 L F
.266 .378 .791 r
.57884 .74515 m .58 .74823 L .5777 .74654 L F
.25 0 0 r
.34782 .7102 m .34989 .70992 L .35153 .7086 L F
.287 0 0 r
.34989 .70992 m .3538 .70827 L .35153 .7086 L F
.34989 .70992 m .352 .70966 L .3538 .70827 L F
.287 .734 .961 r
.34838 .70906 m .35189 .70964 L .34989 .70992 L F
.35189 .70964 m .352 .70966 L .34989 .70992 L F
.25 0 0 r
.34781 .7102 m .34989 .70992 L .34782 .7102 L F
.811 .459 0 r
.71163 .72586 m .71231 .72711 L .71104 .7242 L F
0 .239 .748 r
.71353 .72763 m .71231 .72711 L .71163 .72586 L F
.71353 .72763 m .71519 .72961 L .71231 .72711 L F
.621 .81 .973 r
.59896 .74553 m .5978 .74722 L .59667 .74616 L F
.59896 .74553 m .60012 .74655 L .5978 .74722 L F
.654 .252 .271 r
.49189 .72892 m .49048 .73109 L .48844 .72937 L F
.462 .062 .194 r
.49407 .72868 m .49048 .73109 L .49189 .72892 L F
.318 .618 .956 r
.36603 .64957 m .36797 .64983 L .36732 .65092 L F
.371 .685 .979 r
.36797 .64983 m .36932 .65099 L .36732 .65092 L F
.718 .684 .816 r
.69943 .60442 m .69603 .60387 L .69842 .60192 L F
.714 .725 .859 r
.70207 .60244 m .69943 .60442 L .69842 .60192 L F
.552 .332 .535 r
.35692 .90734 m .35777 .90544 L .35519 .90643 L F
.666 .764 .923 r
.30143 .60425 m .3009 .60686 L .2996 .60442 L F
.30143 .60425 m .30332 .60587 L .3009 .60686 L F
.539 .365 .594 r
.4183 .75693 m .41731 .75957 L .4157 .75968 L F
.52 .373 .621 r
.41731 .75957 m .41641 .76239 L .4157 .75968 L F
.2 0 .029 r
.30583 .66963 m .30757 .66919 L .30878 .6676 L F
.417 .018 .171 r
.30878 .6676 m .30973 .6688 L .3103 .66652 L F
.30878 .6676 m .30757 .66919 L .30973 .6688 L F
.726 .29 .215 r
.3184 .7381 m .31639 .73927 L .31547 .73775 L F
.182 0 0 r
.31858 .73883 m .3184 .7381 L .32039 .73787 L F
.31858 .73883 m .31639 .73927 L .3184 .7381 L F
.688 .775 .918 r
.69265 .60328 m .69369 .60468 L .69047 .60425 L F
.693 .777 .916 r
.69603 .60387 m .69369 .60468 L .69265 .60328 L F
.587 .443 .652 r
.39829 .74104 m .40072 .74295 L .40041 .74067 L F
.39829 .74104 m .39848 .74331 L .40072 .74295 L F
0 0 0 r
.57967 .73678 m .57929 .73716 L .581 .73537 L F
.366 .468 .832 r
.58258 .73412 m .581 .73537 L .57952 .73248 L F
.046 .305 .793 r
.52825 .71473 m .52991 .71598 L .52896 .7157 L F
.173 .25 .703 r
.53094 .71767 m .52896 .7157 L .52991 .71598 L F
.234 0 0 r
.47835 .72391 m .48049 .72343 L .48189 .72198 L F
.055 0 0 r
.48189 .72198 m .48243 .72267 L .48377 .72112 L F
.48189 .72198 m .48049 .72343 L .48243 .72267 L F
.605 .22 .286 r
.33649 .8397 m .33952 .84065 L .33706 .83942 L F
.447 .013 .12 r
.51726 .72961 m .51623 .73131 L .514 .73135 L F
.927 .784 .684 r
.64184 .63972 m .64087 .63691 L .64041 .63873 L F
.92 .792 .702 r
.6403 .64296 m .64184 .63972 L .64041 .63873 L F
.796 .734 .794 r
.64184 .63972 m .64341 .63737 L .64087 .63691 L F
.377 0 .123 r
.35364 .72134 m .35011 .72363 L .35173 .72201 L F
.73 .745 .864 r
.56398 .70862 m .56064 .70834 L .56275 .70754 L F
.664 .799 .947 r
.56611 .70788 m .56398 .70862 L .56275 .70754 L F
.499 .507 .796 r
.37775 .67281 m .37841 .66915 L .37647 .66935 L F
.37775 .67281 m .37955 .67235 L .37841 .66915 L F
.589 .529 .756 r
.37756 .67455 m .37955 .67235 L .37775 .67281 L F
0 .089 .623 r
.73552 .5891 m .73492 .58913 L .73555 .58826 L F
.73552 .5891 m .73583 .59121 L .73492 .58913 L F
.647 .191 .156 r
.49149 .78271 m .48828 .78204 L .48917 .78218 L F
.122 0 0 r
.69243 .58528 m .69136 .58734 L .68934 .58799 L F
.218 .737 .73 r
.69481 .58464 m .69381 .58485 L .69243 .58528 L F
0 0 0 r
.69381 .58485 m .69136 .58734 L .69243 .58528 L F
.81 .706 .751 r
.73184 .61248 m .73486 .61268 L .73423 .61004 L F
.812 .691 .73 r
.73304 .61567 m .73486 .61268 L .73184 .61248 L F
.721 .653 .781 r
.73486 .61268 m .73739 .61021 L .73423 .61004 L F
.071 .625 .816 r
.45447 .76759 m .45716 .76771 L .45789 .7679 L F
.583 .402 .603 r
.45716 .76771 m .45447 .76759 L .45789 .7679 L F
.855 .995 .826 r
.45789 .7679 m .45716 .76771 L .45796 .76646 L F
.45789 .7679 m .45716 .76771 L .45796 .76646 L F
.27 .429 .836 r
.40573 .79423 m .40605 .79315 L .4039 .79363 L F
.40573 .79423 m .40706 .79551 L .40605 .79315 L F
0 0 0 r
.72098 .71977 m .71821 .72083 L .71882 .71942 L F
.12 .612 .909 r
.29433 .602 m .29089 .601 L .29281 .60117 L F
.446 .787 .998 r
.29628 .6017 m .29433 .602 L .29281 .60117 L F
.703 .454 .543 r
.45975 .74032 m .45619 .74278 L .45796 .74127 L F
.815 .415 .292 r
.57283 .71406 m .5755 .71587 L .57647 .71383 L F
.57283 .71406 m .57303 .71556 L .5755 .71587 L F
.987 .738 .464 r
.57303 .71556 m .57413 .71873 L .5755 .71587 L F
.577 .765 .968 r
.42571 .77635 m .42235 .77559 L .42443 .77534 L F
.375 .711 .987 r
.42645 .77535 m .42571 .77635 L .42443 .77534 L F
.42645 .77535 m .42783 .77645 L .42571 .77635 L F
.454 .098 .271 r
.5881 .70506 m .59044 .70481 L .59106 .70322 L F
.602 .244 .334 r
.59106 .70322 m .5926 .70445 L .5931 .70266 L F
.59106 .70322 m .59044 .70481 L .5926 .70445 L F
.624 .165 .141 r
.45777 .77454 m .46123 .77338 L .45908 .77329 L F
.583 .453 .669 r
.31264 .70153 m .31109 .70583 L .31061 .70347 L F
.405 .289 .607 r
.41006 .67153 m .408 .67 L .40975 .66896 L F
.41006 .67153 m .40812 .67242 L .408 .67 L F
.624 .332 .454 r
.60861 .64488 m .61175 .64246 L .60889 .64319 L F
.46 .456 .767 r
.41971 .76733 m .41879 .77071 L .41793 .76754 L F
.41971 .76733 m .42059 .7706 L .41879 .77071 L F
.42059 .7706 m .42138 .77249 L .41879 .77071 L F
.543 .447 .696 r
.41879 .77071 m .42138 .77249 L .41927 .773 L F
.658 .358 .452 r
.46466 .77275 m .46693 .77315 L .46738 .77211 L F
.655 .355 .451 r
.46738 .77211 m .46902 .77238 L .47 .77111 L F
.46738 .77211 m .46693 .77315 L .46902 .77238 L F
.562 .388 .604 r
.56275 .70754 m .56064 .70834 L .5611 .7053 L F
.639 .677 .87 r
.69047 .60425 m .68824 .60486 L .68735 .60232 L F
.561 .408 .63 r
.62303 .63412 m .62062 .63201 L .62083 .63402 L F
.62303 .63412 m .62289 .63166 L .62062 .63201 L F
.29 .737 .961 r
.44767 .74575 m .44842 .7452 L .44636 .74526 L F
.217 .623 .953 r
.44767 .74575 m .44996 .7463 L .44842 .7452 L F
.567 .284 .446 r
.48827 .73149 m .48631 .72959 L .48844 .72937 L F
.48827 .73149 m .48595 .73189 L .48631 .72959 L F
.681 .733 .89 r
.34311 .84194 m .34431 .84393 L .34112 .843 L F
.617 .067 0 r
.34112 .843 m .34431 .84393 L .34312 .84411 L F
.572 .576 .818 r
.34507 .8406 m .34431 .84393 L .34311 .84194 L F
.34507 .8406 m .34637 .84361 L .34431 .84393 L F
.354 .804 .949 r
.34431 .84393 m .34506 .84329 L .34312 .84411 L F
.34431 .84393 m .34637 .84361 L .34506 .84329 L F
.883 .821 .781 r
.64138 .62362 m .64368 .62367 L .64309 .62083 L F
.895 .774 .72 r
.64207 .62658 m .64368 .62367 L .64138 .62362 L F
.529 .371 .611 r
.39651 .74608 m .39856 .74569 L .39848 .74331 L F
.561 .412 .637 r
.39658 .7485 m .39856 .74569 L .39651 .74608 L F
.637 .64 .836 r
.70066 .61246 m .70179 .61527 L .70411 .61457 L F
.885 .468 .206 r
.57895 .75124 m .57869 .75304 L .57805 .75053 L F
.57895 .75124 m .58133 .75449 L .57869 .75304 L F
.815 .536 .515 r
.58236 .75428 m .58133 .75449 L .57895 .75124 L F
.476 .551 .853 r
.69654 .70587 m .69854 .70725 L .69812 .70522 L F
0 0 .326 r
.32535 .73552 m .32503 .73748 L .32426 .73812 L F
.43 .871 .882 r
.32503 .73748 m .32273 .73823 L .32426 .73812 L F
.776 .274 0 r
.32426 .73812 m .32605 .74052 L .32367 .73817 L F
.624 .165 .141 r
.45777 .77454 m .45986 .77515 L .46123 .77338 L F
.547 .078 .093 r
.46123 .77338 m .45986 .77515 L .46324 .77484 L F
.507 .115 .232 r
.46123 .77338 m .46324 .77484 L .46466 .77275 L F
.861 .569 .492 r
.58252 .75656 m .58133 .75449 L .58236 .75428 L F
.744 .501 .564 r
.58581 .75654 m .58252 .75656 L .58236 .75428 L F
.265 .773 .817 r
.52207 .78263 m .52488 .78202 L .52594 .78203 L F
.177 0 0 r
.52488 .78202 m .52839 .782 L .52594 .78203 L F
.244 0 .018 r
.34453 .6761 m .34369 .67723 L .34144 .67781 L F
.341 0 .076 r
.34598 .67664 m .34453 .6761 L .34642 .67548 L F
.34598 .67664 m .34369 .67723 L .34453 .6761 L F
.754 .604 .692 r
.69854 .70725 m .69939 .71105 L .70098 .70789 L F
.545 .055 .044 r
.48399 .78128 m .48341 .78243 L .48028 .78131 L F
.366 0 0 r
.48559 .78201 m .48341 .78243 L .48399 .78128 L F
.405 .195 .478 r
.29663 .62649 m .29615 .62876 L .29453 .62934 L F
.414 .233 .524 r
.29615 .62876 m .29437 .63168 L .29453 .62934 L F
.32 .086 .394 r
.59574 .64853 m .59744 .64955 L .598 .64831 L F
.59574 .64853 m .59561 .65058 L .59744 .64955 L F
.189 .313 .761 r
.52432 .70983 m .52642 .71183 L .52535 .71294 L F
.261 .429 .84 r
.52642 .71183 m .52717 .71379 L .52535 .71294 L F
.5 .187 .367 r
.42945 .73209 m .43165 .73182 L .43273 .72928 L F
.447 .084 .254 r
.43165 .73182 m .43492 .72938 L .43273 .72928 L F
0 0 .243 r
.72385 .61264 m .724 .61309 L .72287 .60988 L F
.662 .973 .859 r
.72249 .61331 m .724 .61309 L .72385 .61264 L F
0 0 .243 r
.72385 .61264 m .724 .61309 L .72287 .60988 L F
.662 .973 .859 r
.72385 .61264 m .724 .61309 L .72249 .61331 L F
0 .179 .666 r
.52909 .71512 m .52825 .71473 L .52717 .71379 L F
0 .262 .755 r
.52837 .71407 m .52909 .71512 L .52828 .71456 L F
.52837 .71407 m .52828 .71456 L .52717 .71379 L F
.759 .303 0 r
.52847 .71357 m .52837 .71407 L .5284 .71319 L F
0 0 .409 r
.52837 .71407 m .52863 .71455 L .52909 .71512 L F
.759 .303 0 r
.52887 .71559 m .52837 .71407 L .52847 .71357 L F
0 0 .409 r
.52863 .71455 m .52987 .71686 L .52909 .71512 L F
0 .179 .666 r
.52909 .71512 m .52991 .71598 L .52958 .71573 L F
.52909 .71512 m .52958 .71573 L .52825 .71473 L F
.214 .688 .938 r
.56929 .69694 m .57141 .69704 L .57248 .69757 L F
0 .164 .608 r
.57305 .69792 m .57248 .69757 L .57141 .69704 L F
.57305 .69792 m .57488 .69922 L .57248 .69757 L F
.708 .611 .746 r
.57274 .71159 m .57283 .71406 L .57647 .71383 L F
.489 .466 .758 r
.69301 .71899 m .69369 .72231 L .69601 .72088 L F
.285 .305 .706 r
.69369 .72231 m .6957 .72294 L .69601 .72088 L F
.69369 .72231 m .69446 .72429 L .6957 .72294 L F
.974 .685 .41 r
.58954 .72845 m .58827 .72577 L .58742 .72758 L F
.708 .611 .746 r
.57274 .71159 m .57647 .71383 L .57507 .71097 L F
.819 .669 .696 r
.68514 .62034 m .68846 .6185 L .68723 .6174 L F
.68514 .62034 m .68812 .62059 L .68846 .6185 L F
.861 .513 .004 r
.54576 .70548 m .54577 .70671 L .54538 .70458 L F
.54576 .70548 m .54641 .70764 L .54577 .70671 L F
.575 .461 .686 r
.38948 .76511 m .39189 .76751 L .39127 .76453 L F
.38948 .76511 m .38978 .7679 L .39189 .76751 L F
.341 0 .172 r
.33281 .6514 m .3343 .65194 L .33598 .6505 L F
0 0 0 r
.33598 .6505 m .33691 .65044 L .33811 .65016 L F
.33598 .6505 m .3343 .65194 L .33691 .65044 L F
.55 .16 .255 r
.44299 .72738 m .44474 .72865 L .44621 .72654 L F
.147 0 0 r
.44474 .72865 m .44836 .72695 L .44621 .72654 L F
.419 .125 .357 r
.29907 .67591 m .30048 .67714 L .30122 .67474 L F
.29907 .67591 m .29851 .6776 L .30048 .67714 L F
.347 0 .117 r
.601 .65881 m .59998 .66069 L .59776 .66117 L F
.632 .305 .4 r
.60329 .65859 m .59998 .66069 L .601 .65881 L F
.905 .497 .197 r
.57434 .7484 m .57172 .74507 L .57441 .74639 L F
.583 .361 .545 r
.59878 .71613 m .59644 .71843 L .59643 .71628 L F
.431 .145 .376 r
.42296 .75366 m .41954 .75594 L .42083 .7542 L F
.739 .229 0 r
.56869 .71387 m .56806 .71222 L .56787 .71289 L F
.56869 .71387 m .57007 .71482 L .56806 .71222 L F
.555 .398 .624 r
.38716 .78149 m .38959 .78114 L .38927 .77854 L F
.692 .467 .577 r
.38716 .78149 m .38997 .78366 L .38959 .78114 L F
.38716 .78149 m .387 .78444 L .38997 .78366 L F
.734 .747 .863 r
.31064 .7381 m .31326 .73922 L .31159 .73799 L F
.30983 .7383 m .31326 .73922 L .31064 .7381 L F
.56 .03 0 r
.31128 .73974 m .31478 .74007 L .31326 .73922 L F
.332 .347 .726 r
.3117 .73783 m .31285 .73984 L .31128 .73974 L F
.542 .165 .276 r
.31148 .73638 m .31159 .73799 L .31337 .73711 L F
.332 .347 .726 r
.31197 .73656 m .31228 .73768 L .3117 .73783 L F
.31228 .73768 m .31285 .73984 L .3117 .73783 L F
.734 .747 .863 r
.30952 .73822 m .30983 .7383 L .31064 .7381 L F
0 0 .329 r
.61281 .68641 m .61416 .68527 L .61439 .68305 L F
0 0 .088 r
.61243 .68859 m .61416 .68527 L .61281 .68641 L F
.62 .434 .609 r
.59586 .69992 m .59833 .702 L .598 .70031 L F
0 .167 .701 r
.57398 .72371 m .57364 .72414 L .57304 .72218 L F
.57398 .72371 m .57587 .7263 L .57364 .72414 L F
.313 0 0 r
.43343 .77609 m .43583 .77593 L .43668 .77514 L F
0 0 0 r
.43769 .77501 m .43889 .77448 L .43668 .77514 L F
.43668 .77514 m .43583 .77593 L .43769 .77501 L F
.624 .332 .454 r
.60861 .64488 m .61111 .64486 L .61175 .64246 L F
.588 .321 .479 r
.61111 .64486 m .61387 .64233 L .61175 .64246 L F
.37 .059 .302 r
.32101 .65938 m .32208 .66062 L .32287 .65879 L F
.32101 .65938 m .32027 .66114 L .32208 .66062 L F
.578 .042 0 r
.4982 .7841 m .49739 .78493 L .4949 .78366 L F
.622 .057 0 r
.4982 .7841 m .49909 .78544 L .49739 .78493 L F
.4982 .7841 m .50017 .78566 L .49909 .78544 L F
.684 .142 0 r
.49909 .78544 m .49568 .78374 L .49739 .78493 L F
.49909 .78544 m .49767 .78522 L .49568 .78374 L F
.238 .539 .924 r
.49909 .78544 m .50088 .78498 L .49794 .7852 L F
.49909 .78544 m .49794 .7852 L .49767 .78522 L F
.622 .057 0 r
.50017 .78566 m .50039 .78584 L .49909 .78544 L F
.589 .529 .756 r
.37756 .67455 m .38017 .67569 L .37955 .67235 L F
0 0 0 r
.5458 .69172 m .54434 .69457 L .54478 .69374 L F
.1 .312 .788 r
.54527 .6928 m .54478 .69374 L .54348 .69297 L F
.48 .083 .208 r
.5458 .69172 m .54478 .69374 L .54723 .69336 L F
.1 .312 .788 r
.54566 .69276 m .54478 .69374 L .54527 .6928 L F
0 0 0 r
.54434 .69457 m .54421 .69483 L .54478 .69374 L F
.379 .819 .952 r
.5458 .69172 m .54757 .69111 L .54572 .69166 L F
.48 .083 .208 r
.5458 .69172 m .54723 .69336 L .54757 .69111 L F
.276 0 0 r
.53271 .78697 m .53141 .78821 L .529 .78849 L F
.524 .065 .105 r
.535 .78691 m .53141 .78821 L .53271 .78697 L F
.161 .689 .866 r
.43216 .77583 m .43129 .77613 L .42996 .7761 L F
.43216 .77583 m .43343 .77609 L .43129 .77613 L F
.51 .222 .412 r
.57851 .7179 m .58161 .71508 L .57927 .71603 L F
.809 .971 .903 r
.71821 .72083 m .71446 .72357 L .71712 .72212 L F
.588 .828 .45 r
.65272 .5989 m .65027 .60217 L .65362 .60194 L F
.363 .002 .212 r
.65078 .60412 m .65362 .60194 L .65027 .60217 L F
.206 0 0 r
.52839 .782 m .5304 .78173 L .53153 .78107 L F
.512 .016 .016 r
.5304 .78173 m .53379 .7815 L .53153 .78107 L F
.367 .635 .957 r
.36487 .64815 m .36393 .64941 L .36263 .64874 L F
.36487 .64815 m .36603 .64957 L .36393 .64941 L F
.572 .531 .771 r
.72108 .73456 m .72009 .73796 L .71906 .73758 L F
.72108 .73456 m .72236 .73787 L .72009 .73796 L F
.657 .579 .755 r
.72472 .73724 m .72445 .73731 L .72108 .73456 L F
.72445 .73731 m .72236 .73787 L .72224 .73756 L F
.72445 .73731 m .72224 .73756 L .72108 .73456 L F
.403 .761 .994 r
.71976 .73784 m .72271 .73673 L .71906 .73758 L F
.72009 .73796 m .72053 .73775 L .71976 .73784 L F
.72053 .73775 m .72271 .73673 L .71976 .73784 L F
.72009 .73796 m .72236 .73787 L .72271 .73673 L F
.922 .976 .735 r
.73142 .61676 m .73146 .6185 L .73304 .61567 L F
.95 .69 .508 r
.72981 .61981 m .73146 .6185 L .73142 .61676 L F
.72981 .61981 m .73136 .62073 L .73146 .6185 L F
.757 .683 .78 r
.70575 .60255 m .70052 .60068 L .70288 .59852 L F
.738 .722 .837 r
.70608 .59888 m .70575 .60255 L .70288 .59852 L F
.714 .558 0 r
.73184 .61248 m .73175 .61035 L .73165 .60827 L F
.627 .71 .906 r
.73175 .61035 m .73423 .61004 L .73221 .60838 L F
.81 .706 .751 r
.73184 .61248 m .73423 .61004 L .73175 .61035 L F
.451 0 .08 r
.46229 .78252 m .46036 .78182 L .46377 .78098 L F
.493 0 0 r
.46377 .78098 m .46439 .78233 L .46229 .78252 L F
.46377 .78098 m .46568 .78135 L .46439 .78233 L F
0 0 0 r
.43576 .78624 m .43108 .78781 L .43357 .78665 L F
.555 .221 .357 r
.32792 .82832 m .32619 .82746 L .32773 .82664 L F
.391 .473 .824 r
.32786 .82526 m .33046 .82702 L .32773 .82664 L F
.452 .149 .361 r
.32773 .82664 m .33046 .82702 L .32792 .82832 L F
.141 .437 .874 r
.37488 .80313 m .37174 .80045 L .37142 .80283 L F
.311 .765 .954 r
.42558 .78914 m .42464 .78878 L .4227 .78893 L F
.193 .714 .869 r
.42721 .78881 m .42464 .78878 L .42558 .78914 L F
.379 0 0 r
.47872 .73372 m .48066 .73414 L .47727 .73427 L F
.446 .76 .995 r
.28614 .59938 m .28537 .60059 L .28379 .5997 L F
.28614 .59938 m .28757 .6004 L .28537 .60059 L F
.184 0 0 r
.32905 .73383 m .32843 .73268 L .33034 .73209 L F
.32905 .73383 m .32719 .73443 L .32843 .73268 L F
.353 .149 .458 r
.2974 .6284 m .29663 .62649 L .29821 .62549 L F
.2974 .6284 m .29615 .62876 L .29663 .62649 L F
.673 .882 .511 r
.5938 .74004 m .59331 .74074 L .59362 .74003 L F
.657 .548 .72 r
.59526 .73796 m .59581 .74076 L .59331 .74074 L F
.633 .356 .481 r
.59581 .74076 m .59558 .74264 L .59331 .74074 L F
.551 0 0 r
.59331 .74074 m .59417 .74175 L .59362 .74003 L F
.769 .432 0 r
.59362 .74003 m .59417 .74175 L .59349 .74002 L F
.59362 .74003 m .59349 .74002 L .59306 .73892 L F
.673 .882 .511 r
.59526 .73796 m .5938 .74004 L .59362 .74003 L F
.885 .957 .844 r
.59347 .74372 m .59174 .74431 L .59417 .74175 L F
.505 .065 .137 r
.59329 .74304 m .59422 .74188 L .59417 .74175 L F
.59422 .74188 m .59485 .74109 L .59417 .74175 L F
.551 0 0 r
.59331 .74074 m .59402 .74134 L .59417 .74175 L F
.59402 .74134 m .59558 .74264 L .59417 .74175 L F
.442 .643 .943 r
.30733 .60576 m .30704 .60754 L .30535 .60564 L F
.315 .515 .892 r
.30838 .60715 m .30704 .60754 L .30733 .60576 L F
.51 .482 .762 r
.30838 .60715 m .30677 .60925 L .30704 .60754 L F
.604 .833 .987 r
.51265 .70835 m .50936 .70813 L .51149 .70742 L F
.493 .722 .974 r
.51366 .70696 m .51265 .70835 L .51149 .70742 L F
.51366 .70696 m .51478 .70815 L .51265 .70835 L F
.576 .329 .505 r
.57723 .68275 m .57461 .68099 L .57632 .68112 L F
.57723 .68275 m .57376 .68337 L .57461 .68099 L F
.564 .401 .619 r
.29442 .68083 m .29655 .68048 L .29649 .67803 L F
.504 .357 .615 r
.29442 .68083 m .29637 .6829 L .29655 .68048 L F
.29442 .68083 m .29456 .68345 L .29637 .6829 L F
.686 .599 .754 r
.54832 .73011 m .54951 .7326 L .54671 .73255 L F
.731 .614 .728 r
.68052 .62555 m .68243 .62717 L .6844 .62426 L F
.402 .367 .705 r
.73066 .59556 m .73125 .59895 L .7295 .59927 L F
.706 .704 .845 r
.69495 .61238 m .69842 .61285 L .69742 .6106 L F
.571 .638 .878 r
.69842 .61285 m .69937 .60976 L .69742 .6106 L F
.69842 .61285 m .70066 .61246 L .69937 .60976 L F
.494 .23 .443 r
.39707 .68386 m .39656 .68583 L .39445 .68624 L F
.367 .115 .394 r
.39843 .68515 m .39707 .68386 L .39909 .68343 L F
.39843 .68515 m .39656 .68583 L .39707 .68386 L F
.408 .078 .291 r
.36149 .70286 m .35876 .70496 L .36086 .70446 L F
.497 .164 .332 r
.36086 .70446 m .363 .7042 L .36149 .70286 L F
.452 .171 .396 r
.36149 .70286 m .363 .7042 L .36356 .70234 L F
.344 .102 .396 r
.29086 .63744 m .29023 .63973 L .28853 .64043 L F
.304 .104 .435 r
.2927 .63464 m .29238 .6368 L .29086 .63744 L F
.349 .107 .399 r
.29193 .63893 m .29086 .63744 L .29238 .6368 L F
.29193 .63893 m .29023 .63973 L .29086 .63744 L F
.714 .606 .735 r
.55598 .69983 m .55388 .70226 L .55375 .70037 L F
.512 .318 .555 r
.55598 .69983 m .55608 .70229 L .55388 .70226 L F
.59 .593 .824 r
.3972 .66198 m .39525 .66266 L .39349 .65925 L F
.731 .83 .926 r
.67534 .61041 m .6781 .61065 L .67851 .60966 L F
.816 .93 .908 r
.67851 .60966 m .6781 .61065 L .67854 .60897 L F
.479 0 0 r
.6781 .61065 m .67877 .61114 L .67865 .61117 L F
.6781 .61065 m .67865 .61117 L .67854 .60897 L F
.749 .63 .729 r
.59109 .74584 m .59248 .74894 L .58891 .7484 L F
.695 .606 .753 r
.59452 .74697 m .59248 .74894 L .59109 .74584 L F
.349 0 .085 r
.3339 .68269 m .33059 .6846 L .33173 .68316 L F
0 0 0 r
.57452 .66736 m .57573 .66647 L .57699 .66527 L F
.57452 .66736 m .57311 .66869 L .57573 .66647 L F
.324 0 0 r
.4692 .78114 m .46794 .78154 L .46568 .78135 L F
.278 0 0 r
.46942 .78191 m .4692 .78114 L .47129 .7813 L F
.46942 .78191 m .46794 .78154 L .4692 .78114 L F
.383 .447 .803 r
.56257 .69625 m .56266 .69989 L .56117 .69692 L F
.56257 .69625 m .56386 .69927 L .56266 .69989 L F
.515 .536 .816 r
.42235 .77559 m .41927 .773 L .42138 .77249 L F
.233 0 0 r
.44836 .72695 m .45049 .72689 L .45185 .72637 L F
.388 0 0 r
.45049 .72689 m .4539 .72677 L .45185 .72637 L F
.66 .427 .557 r
.40277 .74011 m .40559 .73767 L .40333 .73857 L F
.672 .463 .594 r
.31962 .69435 m .31633 .69645 L .3166 .69463 L F
.731 .614 .728 r
.68052 .62555 m .6844 .62426 L .6828 .62301 L F
.014 0 .166 r
.28768 .64221 m .28573 .64505 L .28651 .6431 L F
0 .065 .598 r
.54317 .70229 m .54538 .70458 L .5431 .70188 L F
.556 .554 .807 r
.39998 .66303 m .39847 .66553 L .3972 .66198 L F
.557 .555 .808 r
.39998 .66303 m .40097 .66573 L .39847 .66553 L F
.358 .035 .274 r
.30952 .73822 m .31148 .73638 L .31169 .73689 L F
.285 0 0 r
.52052 .7082 m .52273 .70823 L .52408 .70778 L F
.978 .69 .399 r
.52305 .70863 m .52408 .70778 L .52273 .70823 L F
.52305 .70863 m .52432 .70983 L .52408 .70778 L F
.973 .716 .486 r
.63881 .65331 m .63879 .65099 L .63756 .65019 L F
.942 .864 .734 r
.63879 .65099 m .63896 .64738 L .63756 .65019 L F
.344 .032 .283 r
.60081 .64545 m .6021 .64699 L .60313 .64525 L F
.60081 .64545 m .60027 .64771 L .6021 .64699 L F
.577 .44 .658 r
.59644 .71843 m .59449 .72134 L .59415 .71882 L F
.709 .595 .726 r
.69352 .57765 m .68946 .58098 L .6902 .57716 L F
.857 .617 .575 r
.64341 .63737 m .64099 .63452 L .64087 .63691 L F
.692 .719 .87 r
.70411 .61457 m .70739 .61526 L .70661 .61377 L F
.6 .735 .939 r
.70661 .61377 m .70739 .61526 L .70957 .6147 L F
.506 0 0 r
.51017 .78526 m .5092 .78429 L .50793 .78351 L F
.582 .172 .23 r
.509 .78647 m .51056 .78575 L .51017 .78526 L F
.506 0 0 r
.51017 .78526 m .51138 .78588 L .50966 .78463 L F
.569 .861 .996 r
.5136 .7851 m .51138 .78588 L .51017 .78526 L F
.5136 .7851 m .51017 .78526 L .51292 .78465 L F
.582 .172 .23 r
.51056 .78575 m .51292 .78465 L .51017 .78526 L F
.506 0 0 r
.51017 .78526 m .50966 .78463 L .5092 .78429 L F
.992 .805 .428 r
.7319 .62382 m .73105 .62527 L .73128 .62299 L F
.7319 .62382 m .73105 .62527 L .73128 .62299 L F
.589 .741 .948 r
.32903 .71036 m .3257 .70954 L .32727 .70832 L F
.667 .73 .897 r
.33113 .7095 m .32903 .71036 L .32727 .70832 L F
.186 .64 .941 r
.30268 .73185 m .3036 .72882 L .30183 .72957 L F
.30268 .73185 m .30322 .73128 L .3036 .72882 L F
.812 .337 .079 r
.51155 .79531 m .51005 .79499 L .50893 .79363 L F
0 .395 .691 r
.51155 .79531 m .51253 .79557 L .51005 .79499 L F
.51155 .79531 m .51333 .79584 L .51253 .79557 L F
.977 .909 .672 r
.58313 .67436 m .58271 .6783 L .58412 .67509 L F
.896 .91 .826 r
.58313 .67436 m .58412 .67509 L .5864 .67186 L F
0 0 0 r
.48924 .71855 m .49061 .71809 L .49195 .71697 L F
.48924 .71855 m .48855 .71897 L .49061 .71809 L F
.267 0 .249 r
.28853 .64043 m .29023 .63973 L .28768 .64221 L F
.482 .32 .584 r
.37311 .69183 m .37499 .69139 L .37508 .68886 L F
.496 .382 .654 r
.37311 .69183 m .37527 .69369 L .37499 .69139 L F
.37311 .69183 m .37343 .69431 L .37527 .69369 L F
.381 .157 .444 r
.37712 .68333 m .3788 .68293 L .3793 .68086 L F
.486 .339 .606 r
.37706 .68575 m .3788 .68293 L .37712 .68333 L F
.655 .749 .919 r
.50936 .70813 m .50717 .70888 L .50593 .70743 L F
.823 .83 .357 r
.63334 .67154 m .63246 .67518 L .632 .67333 L F
.29 0 .114 r
.46902 .77238 m .47238 .77044 L .47 .77111 L F
.005 0 0 r
.47238 .77044 m .47321 .77118 L .47408 .77096 L F
.47238 .77044 m .47133 .77231 L .47321 .77118 L F
.363 .002 .212 r
.65078 .60412 m .65344 .60359 L .65362 .60194 L F
.616 .599 .811 r
.65362 .60194 m .65476 .5986 L .65272 .5989 L F
.65362 .60194 m .65596 .60171 L .65476 .5986 L F
0 0 .133 r
.65362 .60194 m .65473 .60224 L .65596 .60171 L F
.65362 .60194 m .65344 .60359 L .65473 .60224 L F
.588 .438 .645 r
.39258 .75412 m .39489 .75677 L .39441 .75347 L F
.39258 .75412 m .39278 .75725 L .39489 .75677 L F
.734 .827 .923 r
.30472 .73203 m .30818 .73202 L .30662 .72882 L F
.651 .782 .944 r
.30662 .72882 m .30818 .73202 L .31081 .73135 L F
.564 .471 .708 r
.33434 .8398 m .33655 .84183 L .33649 .8397 L F
.596 .372 .547 r
.33655 .84183 m .33952 .84065 L .33649 .8397 L F
.673 .778 .929 r
.40036 .79277 m .4039 .79363 L .40213 .79183 L F
.546 .714 .95 r
.40213 .79183 m .4039 .79363 L .40605 .79315 L F
.946 .956 .664 r
.54336 .69641 m .54271 .69618 L .54421 .69483 L F
.703 .935 .623 r
.54421 .69483 m .54271 .69618 L .54478 .69374 L F
.558 .392 .612 r
.32192 .69164 m .31962 .69435 L .31964 .69224 L F
.571 .441 .665 r
.38978 .7679 m .39221 .76992 L .39189 .76751 L F
.544 .443 .69 r
.38978 .7679 m .39018 .77035 L .39221 .76992 L F
0 0 .036 r
.56376 .7015 m .56386 .69927 L .56735 .70013 L F
.56376 .7015 m .56382 .70172 L .56386 .69927 L F
.56376 .7015 m .56382 .70172 L .56386 .69927 L F
.284 .384 .79 r
.53522 .73566 m .53661 .73426 L .53397 .73442 L F
.489 .126 .276 r
.5376 .73529 m .53742 .7365 L .53522 .73566 L F
.284 .384 .79 r
.53522 .73566 m .53742 .7365 L .53661 .73426 L F
.593 .404 .595 r
.62532 .62933 m .6276 .62886 L .62767 .62647 L F
.587 .427 .632 r
.6276 .62886 m .62976 .62591 L .62767 .62647 L F
.471 .299 .565 r
.58608 .70799 m .58833 .70769 L .5881 .70506 L F
.494 .41 .69 r
.58608 .70799 m .58847 .71008 L .58833 .70769 L F
.496 .41 .688 r
.58608 .70799 m .58676 .71084 L .58847 .71008 L F
.495 .085 .193 r
.46902 .77238 m .46693 .77315 L .46961 .77281 L F
.357 .146 .45 r
.46961 .77281 m .47133 .77231 L .46902 .77238 L F
.812 .61 .629 r
.68479 .58542 m .68035 .58738 L .68033 .58567 L F
.217 0 .004 r
.3185 .6619 m .31908 .66305 L .32027 .66114 L F
.3185 .6619 m .31717 .66364 L .31908 .66305 L F
.391 .093 .335 r
.32797 .68742 m .32678 .68646 L .32846 .68559 L F
.32797 .68742 m .32607 .68812 L .32678 .68646 L F
.53 .306 .519 r
.60373 .71022 m .6034 .71292 L .6012 .71314 L F
.525 .273 .475 r
.60621 .71001 m .6034 .71292 L .60373 .71022 L F
.361 0 .151 r
.34369 .67723 m .34041 .67942 L .34144 .67781 L F
.648 .453 .605 r
.5931 .70266 m .59655 .70369 L .59586 .69992 L F
.62 .434 .609 r
.59586 .69992 m .59655 .70369 L .59833 .702 L F
.786 .445 .409 r
.50424 .72536 m .50265 .72779 L .50236 .72766 L F
.249 .173 .571 r
.50096 .72405 m .5009 .72646 L .49912 .72642 L F
.501 .72416 m .5009 .72646 L .50096 .72405 L F
0 0 0 r
.49948 .72636 m .49912 .72642 L .5009 .72646 L F
.762 .605 .683 r
.50424 .72536 m .5009 .72646 L .50101 .72399 L F
.786 .445 .409 r
.50109 .72639 m .49948 .72636 L .5009 .72646 L F
.50424 .72536 m .50106 .72603 L .50109 .72639 L F
.50106 .72603 m .49948 .72636 L .50109 .72639 L F
.756 .335 .249 r
.50104 .72563 m .49812 .7242 L .49927 .7251 L F
.50226 .726 m .50103 .72547 L .50104 .72563 L F
.50103 .72547 m .49812 .7242 L .50104 .72563 L F
.786 .445 .409 r
.50168 .7259 m .50236 .72766 L .49948 .72636 L F
.50424 .72536 m .50236 .72766 L .50168 .7259 L F
.249 .173 .571 r
.50101 .72399 m .501 .72416 L .50096 .72405 L F
0 0 0 r
.49948 .72636 m .49841 .72769 L .49912 .72642 L F
.71 .799 .92 r
.68735 .60232 m .68482 .60413 L .6839 .60213 L F
.435 .866 .76 r
.52189 .72877 m .52521 .72733 L .52406 .72898 L F
.564 .213 .333 r
.52722 .7272 m .52406 .72898 L .52521 .72733 L F
.484 .134 .297 r
.54044 .78406 m .5397 .78631 L .53725 .78658 L F
.28 0 .216 r
.54147 .78557 m .54044 .78406 L .54035 .78269 L F
.54147 .78557 m .5397 .78631 L .54044 .78406 L F
.448 .479 .798 r
.55088 .7318 m .54951 .7326 L .54832 .73011 L F
.448 .52 .84 r
.55225 .73495 m .54951 .7326 L .55088 .7318 L F
.683 .746 .899 r
.34535 .70905 m .34333 .71129 L .34072 .70798 L F
.991 .781 .522 r
.54515 .78171 m .54419 .78155 L .54546 .78036 L F
.434 .535 .861 r
.40605 .79315 m .40706 .79551 L .40831 .79364 L F
.539 .678 .929 r
.40706 .79551 m .40918 .79532 L .40831 .79364 L F
.524 0 0 r
.69703 .57552 m .69606 .57425 L .69455 .57443 L F
.69703 .57552 m .69814 .57511 L .69606 .57425 L F
.489 .225 .44 r
.36335 .71561 m .36112 .71759 L .36143 .71613 L F
.922 .976 .735 r
.73142 .61676 m .73304 .61567 L .73252 .61463 L F
.812 .691 .73 r
.73304 .61567 m .73184 .61248 L .73252 .61463 L F
0 0 .076 r
.62541 .68537 m .62359 .68839 L .62437 .68655 L F
.428 .125 .347 r
.70964 .71576 m .70657 .71919 L .7093 .71883 L F
.531 .157 .276 r
.7113 .71789 m .70964 .71576 L .7093 .71883 L F
.7113 .71789 m .71199 .71569 L .70964 .71576 L F
.63 .772 .949 r
.71967 .62115 m .7231 .62179 L .72183 .62064 L F
.136 0 0 r
.7231 .62179 m .72515 .62096 L .72438 .62219 L F
.7231 .62179 m .72438 .62219 L .72183 .62064 L F
.088 .312 .791 r
.56198 .727 m .56414 .72882 L .56286 .72604 L F
.571 .364 .561 r
.56198 .727 m .56219 .72915 L .56414 .72882 L F
.721 .35 .347 r
.4935 .77862 m .49548 .78102 L .49705 .77914 L F
.606 .207 .261 r
.49705 .77914 m .49921 .78032 L .49919 .77844 L F
.49705 .77914 m .49548 .78102 L .49921 .78032 L F
.546 .023 0 r
.70337 .57529 m .70168 .57433 L .69998 .57473 L F
.515 .148 .281 r
.34945 .64856 m .35129 .64949 L .35156 .6484 L F
.64 .14 0 r
.72679 .7207 m .72757 .72194 L .72648 .72034 L F
.194 .58 .941 r
.72477 .72027 m .72679 .7207 L .72612 .7198 L F
.64 .14 0 r
.72679 .7207 m .72648 .72034 L .72612 .7198 L F
.001 .532 .846 r
.72702 .72098 m .72679 .7207 L .72477 .72027 L F
.72805 .72131 m .72679 .7207 L .72702 .72098 L F
.74 .219 0 r
.72805 .72131 m .72852 .72274 L .72679 .7207 L F
.72805 .72131 m .73026 .72353 L .72852 .72274 L F
.994 .762 .472 r
.67877 .61114 m .67777 .61245 L .67865 .61117 L F
.67877 .61114 m .67869 .6132 L .67777 .61245 L F
.415 0 .033 r
.46324 .77484 m .46693 .77315 L .46466 .77275 L F
.544 .349 .567 r
.69446 .72429 m .69671 .72622 L .6957 .72294 L F
.69446 .72429 m .69442 .72669 L .69671 .72622 L F
.109 .523 .911 r
.55326 .71349 m .55325 .71243 L .5513 .71029 L F
.55326 .71349 m .55409 .71326 L .55325 .71243 L F
.596 .474 .684 r
.55326 .71349 m .55583 .71594 L .55409 .71326 L F
.55326 .71349 m .55373 .71637 L .55583 .71594 L F
.538 .381 .616 r
.29649 .67803 m .29858 .67996 L .29851 .6776 L F
.29649 .67803 m .29655 .68048 L .29858 .67996 L F
.568 .396 .608 r
.39856 .74569 m .40072 .74295 L .39848 .74331 L F
.696 .78 .916 r
.70957 .6147 m .71294 .61504 L .71176 .61394 L F
.509 .752 .983 r
.71176 .61394 m .71294 .61504 L .71521 .61476 L F
.418 .178 .442 r
.40616 .67501 m .40582 .67778 L .40376 .67787 L F
.441 .242 .513 r
.40812 .67242 m .40789 .67468 L .40616 .67501 L F
.488 .238 .461 r
.40797 .67645 m .40616 .67501 L .40789 .67468 L F
.40797 .67645 m .40582 .67778 L .40616 .67501 L F
.583 .453 .669 r
.31264 .70153 m .31334 .70536 L .31109 .70583 L F
.734 .467 .524 r
.68009 .59843 m .68028 .5959 L .67718 .59623 L F
.27 0 0 r
.69745 .59047 m .69775 .59047 L .70039 .58924 L F
.657 .271 .302 r
.69462 .59147 m .69532 .5912 L .69682 .59074 L F
.69532 .5912 m .70039 .58924 L .69737 .59051 L F
.69532 .5912 m .69737 .59051 L .69682 .59074 L F
.69462 .59147 m .69511 .59052 L .70039 .58924 L F
.27 0 0 r
.69511 .59052 m .69745 .59047 L .70039 .58924 L F
.54 .502 .762 r
.69794 .58594 m .69776 .59038 L .69609 .58617 L F
.69776 .59038 m .69775 .59047 L .69772 .59039 L F
.546 .544 .803 r
.69768 .5904 m .69775 .59047 L .69745 .59047 L F
.462 0 0 r
.69969 .5898 m .70039 .58924 L .69775 .59047 L F
.70039 .58924 m .6998 .58972 L .69776 .59038 L F
.69769 .5904 m .69776 .59038 L .69767 .59041 L F
.70039 .58924 m .69776 .59038 L .69769 .5904 L F
.54 .502 .762 r
.69776 .59038 m .69969 .5898 L .69775 .59047 L F
.462 0 0 r
.6998 .58972 m .69969 .5898 L .69767 .59041 L F
.657 .271 .302 r
.69745 .59047 m .70039 .58924 L .69768 .5904 L F
.54 .502 .762 r
.69794 .58594 m .69969 .5898 L .69776 .59038 L F
.546 .544 .803 r
.69772 .59039 m .69772 .59039 L .69768 .5904 L F
.69772 .59039 m .69775 .59047 L .69768 .5904 L F
.462 0 0 r
.69767 .59041 m .69838 .59019 L .69715 .59063 L F
.69838 .59019 m .69969 .5898 L .69959 .58984 L F
.69838 .59019 m .69959 .58984 L .69715 .59063 L F
.54 .502 .762 r
.69776 .59038 m .69776 .59038 L .69772 .59039 L F
.69776 .59038 m .69772 .59039 L .69772 .59039 L F
.69776 .59038 m .69772 .59039 L .69609 .58617 L F
.546 .544 .803 r
.69609 .58617 m .69772 .59039 L .69511 .59052 L F
.69772 .59039 m .69745 .59047 L .69511 .59052 L F
0 0 0 r
.69715 .59063 m .69969 .5898 L .69853 .59034 L F
.69715 .59063 m .69853 .59034 L .69848 .59034 L F
.657 .271 .302 r
.69701 .59066 m .69745 .59047 L .69715 .59063 L F
.69745 .59047 m .69768 .5904 L .69715 .59063 L F
0 0 0 r
.69715 .59063 m .69848 .59034 L .69629 .59039 L F
.657 .271 .302 r
.69682 .59074 m .69701 .59066 L .69715 .59063 L F
.462 0 0 r
.69969 .5898 m .70049 .58975 L .70039 .58924 L F
.70039 .58924 m .70049 .58975 L .69969 .5898 L F
.97 .685 .431 r
.38448 .7848 m .38445 .78679 L .38312 .7857 L F
0 0 0 r
.38448 .7848 m .38527 .78459 L .387 .78444 L F
.38448 .7848 m .38312 .7857 L .38527 .78459 L F
.972 .754 .548 r
.61929 .66975 m .61811 .67138 L .61843 .66902 L F
.61929 .66975 m .61895 .67171 L .61811 .67138 L F
0 .46 .726 r
.57507 .71097 m .57169 .71016 L .57274 .71159 L F
.721 .684 .814 r
.5976 .73776 m .59883 .74057 L .59581 .74076 L F
.64 .282 .349 r
.59581 .74076 m .59883 .74057 L .5979 .74241 L F
.226 .218 .64 r
.59984 .7372 m .59883 .74057 L .5976 .73776 L F
.59984 .7372 m .60015 .7394 L .59883 .74057 L F
.698 .576 .715 r
.60015 .7394 m .5979 .74241 L .59883 .74057 L F
.59 .437 .643 r
.54757 .69111 m .55018 .68801 L .54572 .69166 L F
.455 .285 .56 r
.38927 .77854 m .39109 .77815 L .39117 .77573 L F
.337 .242 .598 r
.38927 .77854 m .39095 .7805 L .39109 .77815 L F
.38927 .77854 m .38959 .78114 L .39095 .7805 L F
.432 .781 .997 r
.30653 .74229 m .30503 .74314 L .30466 .74309 L F
.097 0 0 r
.43886 .78609 m .43791 .78624 L .43576 .78624 L F
.196 0 0 r
.44098 .78569 m .43791 .78624 L .43886 .78609 L F
.462 .286 .555 r
.42017 .75799 m .4183 .75693 L .41954 .75594 L F
.42017 .75799 m .41731 .75957 L .4183 .75693 L F
.379 .157 .445 r
.3918 .69103 m .39 .69164 L .39214 .68888 L F
.482 .26 .5 r
.3918 .69103 m .38952 .69363 L .39 .69164 L F
.312 0 0 r
.41271 .65814 m .41486 .65784 L .41626 .65634 L F
.255 0 0 r
.41626 .65634 m .41697 .6574 L .41848 .65786 L F
.41626 .65634 m .41486 .65784 L .41697 .6574 L F
.269 .765 .896 r
.44331 .77541 m .44238 .77588 L .44115 .77509 L F
.44331 .77541 m .44457 .77561 L .44238 .77588 L F
0 0 0 r
.73132 .73786 m .7306 .7397 L .72937 .74097 L F
.601 .943 .934 r
.72937 .74097 m .7306 .7397 L .72749 .74098 L F
.281 0 .281 r
.30273 .67475 m .30122 .67474 L .30048 .67714 L F
.39 .22 .527 r
.60887 .69455 m .6107 .69382 L .61076 .69147 L F
.251 .035 .378 r
.60869 .69668 m .6107 .69382 L .60887 .69455 L F
.633 .642 .842 r
.39439 .78941 m .39526 .78635 L .3935 .7866 L F
.39439 .78941 m .3968 .78928 L .39526 .78635 L F
.79 .579 .615 r
.39389 .79087 m .3968 .78928 L .39439 .78941 L F
.523 .317 .542 r
.30529 .67194 m .30757 .66919 L .30583 .66963 L F
0 0 .481 r
.73177 .73609 m .7312 .7373 L .731 .73661 L F
.73177 .73609 m .731 .73661 L .73048 .73473 L F
0 0 .281 r
.73307 .73295 m .73323 .73519 L .73177 .73609 L F
.393 .827 .677 r
.73323 .73519 m .73247 .73561 L .73177 .73609 L F
0 0 .211 r
.73048 .73473 m .7312 .7373 L .73126 .73762 L F
.393 .827 .677 r
.73247 .73561 m .72996 .73698 L .73177 .73609 L F
.982 .823 .61 r
.73112 .73689 m .7312 .7373 L .73177 .73609 L F
.72953 .73886 m .7312 .7373 L .73112 .73689 L F
0 0 .211 r
.73126 .73762 m .7312 .7373 L .73132 .73786 L F
.857 .816 .334 r
.7312 .7373 m .7306 .7397 L .73132 .73786 L F
0 0 0 r
.61387 .64233 m .61542 .64168 L .61667 .64017 L F
.61387 .64233 m .61542 .64168 L .61667 .64017 L F
.21 .122 .531 r
.61529 .63913 m .61542 .64168 L .61387 .64233 L F
.62 .433 .607 r
.61529 .63913 m .61542 .64168 L .61586 .64108 L F
.61529 .63913 m .61663 .64004 L .61581 .64089 L F
.61529 .63913 m .61712 .63937 L .61746 .63889 L F
.644 .864 .49 r
.61737 .63904 m .61663 .64004 L .61746 .63889 L F
.61663 .64004 m .61712 .63937 L .61746 .63889 L F
.61667 .64017 m .61597 .64095 L .61737 .63904 L F
.62 .433 .607 r
.61663 .64004 m .61754 .63942 L .61781 .64085 L F
.61529 .63913 m .61712 .63937 L .61663 .64004 L F
.644 .864 .49 r
.61597 .64095 m .61663 .64004 L .61737 .63904 L F
.62 .433 .607 r
.61712 .63937 m .61754 .63942 L .61663 .64004 L F
.644 .864 .49 r
.61597 .64095 m .61586 .64108 L .61663 .64004 L F
.62 .433 .607 r
.61663 .64004 m .61542 .64166 L .61487 .64185 L F
.644 .864 .49 r
.61663 .64004 m .61586 .64108 L .61712 .63937 L F
.62 .433 .607 r
.61529 .63913 m .61746 .63889 L .6174 .63868 L F
.811 .704 .747 r
.61746 .63889 m .61712 .63937 L .6174 .63868 L F
.62 .433 .607 r
.61529 .63913 m .61744 .63891 L .61712 .63937 L F
.61529 .63913 m .61586 .64108 L .61712 .63937 L F
.811 .704 .747 r
.61712 .63937 m .61542 .64168 L .6174 .63868 L F
.62 .433 .607 r
.6173 .63893 m .6174 .63868 L .61744 .63891 L F
.61529 .63913 m .6174 .63868 L .6173 .63893 L F
.61712 .63937 m .61744 .63891 L .61754 .63942 L F
.61529 .63913 m .61581 .64089 L .61487 .64185 L F
.644 .864 .49 r
.61667 .64017 m .61542 .64168 L .61586 .64108 L F
.62 .433 .607 r
.61663 .64004 m .61781 .64085 L .61542 .64166 L F
.877 .81 .78 r
.63947 .65816 m .64056 .65714 L .63898 .65568 L F
.712 .803 .921 r
.64056 .65714 m .64223 .65598 L .63898 .65568 L F
.693 .777 .916 r
.69603 .60387 m .69265 .60328 L .69546 .602 L F
.739 .826 .919 r
.69842 .60192 m .69603 .60387 L .69546 .602 L F
.533 .912 .757 r
.45439 .74351 m .45162 .74517 L .45225 .74358 L F
.699 .625 .771 r
.69245 .57462 m .69352 .57765 L .6902 .57716 L F
.517 .018 .011 r
.47478 .78109 m .47343 .78171 L .47129 .7813 L F
.32 0 0 r
.47478 .78109 m .47578 .78184 L .47343 .78171 L F
.47478 .78109 m .47688 .7813 L .47578 .78184 L F
.451 0 .067 r
.72201 .71225 m .72444 .71221 L .72527 .71078 L F
.254 0 0 r
.72444 .71221 m .72779 .71163 L .72527 .71078 L F
.653 .326 .407 r
.59108 .75669 m .58808 .75854 L .58789 .75703 L F
.59108 .75669 m .59026 .75908 L .58808 .75854 L F
.509 .178 .342 r
.59337 .75647 m .59026 .75908 L .59108 .75669 L F
.634 .714 .905 r
.3851 .65626 m .38179 .6553 L .38383 .65502 L F
.405 .775 .993 r
.38583 .65533 m .3851 .65626 L .38383 .65502 L F
.38583 .65533 m .38716 .65607 L .3851 .65626 L F
.697 .779 .915 r
.56929 .69694 m .56713 .69762 L .56593 .6966 L F
.48 .69 .96 r
.37339 .65031 m .37301 .65201 L .37145 .65081 L F
.37339 .65031 m .37495 .65186 L .37301 .65201 L F
.977 .909 .672 r
.58313 .67436 m .58191 .67763 L .58271 .6783 L F
.931 .946 .778 r
.58191 .67763 m .58058 .67938 L .58271 .6783 L F
.644 .612 .802 r
.57942 .705 m .57714 .70536 L .57612 .70263 L F
.621 .459 .642 r
.57942 .705 m .57726 .70765 L .57714 .70536 L F
.789 .956 .63 r
.5619 .67738 m .56143 .67753 L .56285 .67608 L F
0 0 0 r
.56285 .67608 m .56304 .67619 L .56422 .67487 L F
.56285 .67608 m .56143 .67753 L .56304 .67619 L F
.49195 .71697 m .49227 .71692 L .49396 .7161 L F
.49195 .71697 m .49061 .71809 L .49227 .71692 L F
.564 .471 .708 r
.33434 .8398 m .33531 .84381 L .33655 .84183 L F
.583 .786 .976 r
.51843 .70883 m .51478 .70815 L .51696 .70783 L F
.604 .819 .982 r
.52052 .7082 m .51843 .70883 L .51696 .70783 L F
0 0 0 r
.43815 .74787 m .43627 .74897 L .43867 .74704 L F
.374 0 .021 r
.44098 .74737 m .43815 .74787 L .43867 .74704 L F
.968 .753 .56 r
.47433 .7744 m .47565 .77572 L .47586 .77295 L F
0 .023 .543 r
.47564 .77253 m .47586 .77295 L .47408 .77096 L F
.729 .94 .621 r
.47433 .7744 m .47586 .77295 L .47564 .77253 L F
.724 .523 .618 r
.47586 .77295 m .47565 .77572 L .47905 .77527 L F
.428 0 0 r
.45953 .72586 m .46157 .72645 L .46281 .72633 L F
0 0 0 r
.46281 .72633 m .46157 .72645 L .46492 .72613 L F
.801 .832 .875 r
.6798 .62307 m .68052 .62555 L .6828 .62301 L F
.449 .129 .33 r
.53284 .72851 m .53245 .72981 L .53064 .72895 L F
.199 .313 .756 r
.53064 .72895 m .53185 .73243 L .53241 .72979 L F
.449 .129 .33 r
.53245 .72981 m .53216 .73078 L .53064 .72895 L F
.199 .313 .756 r
.53064 .72895 m .53241 .72979 L .53249 .72941 L F
.659 .33 .405 r
.53504 .72961 m .5335 .73023 L .53284 .72851 L F
.5335 .73023 m .53302 .73012 L .53284 .72851 L F
.53305 .73041 m .53245 .72982 L .53284 .72851 L F
.629 .601 .803 r
.53267 .73004 m .53476 .72987 L .53249 .72941 L F
.53397 .73442 m .53465 .7305 L .5335 .73023 L F
.53397 .73442 m .5335 .73023 L .53279 .73044 L F
.426 .02 .164 r
.53476 .72987 m .5335 .73023 L .53504 .72961 L F
.629 .601 .803 r
.53465 .7305 m .53476 .72987 L .53267 .73004 L F
.175 .288 .741 r
.53185 .73243 m .53397 .73442 L .53267 .73004 L F
.53185 .73243 m .53267 .73004 L .53241 .72978 L F
.426 .02 .164 r
.53476 .72987 m .53216 .73078 L .5335 .73023 L F
.629 .601 .803 r
.53279 .73044 m .5335 .73023 L .53267 .73004 L F
.659 .33 .405 r
.5335 .73023 m .53305 .73041 L .53302 .73012 L F
.53305 .73041 m .53216 .73078 L .53245 .72982 L F
.175 .288 .741 r
.53241 .72978 m .53267 .73004 L .53249 .72941 L F
.779 .839 .898 r
.58327 .72219 m .58626 .72179 L .58516 .72119 L F
.644 .17 .112 r
.69566 .71127 m .70027 .71283 L .69939 .71105 L F
.415 .756 .995 r
.56968 .71036 m .57169 .71016 L .5686 .70941 L F
.158 0 0 r
.35801 .67364 m .35757 .67275 L .35955 .67217 L F
.35801 .67364 m .35599 .67418 L .35757 .67275 L F
.717 .402 .445 r
.58581 .75654 m .5846 .75888 L .58252 .75656 L F
.681 .361 .426 r
.58808 .75854 m .58581 .75654 L .58789 .75703 L F
.58808 .75854 m .5846 .75888 L .58581 .75654 L F
.455 .446 .759 r
.41872 .76393 m .41793 .76754 L .41688 .7636 L F
.41872 .76393 m .41971 .76733 L .41793 .76754 L F
.403 .027 .208 r
.57488 .69922 m .57709 .6988 L .57646 .6976 L F
.04 0 0 r
.67042 .59109 m .67385 .59065 L .673 .59087 L F
.673 .59087 m .67385 .59065 L .67042 .59109 L F
.401 .319 .649 r
.67084 .58841 m .673 .59087 L .67255 .58928 L F
.04 0 0 r
.67042 .59109 m .673 .59087 L .67084 .58841 L F
.896 .91 .826 r
.58313 .67436 m .5864 .67186 L .58551 .67161 L F
.635 .947 .95 r
.58743 .67058 m .5864 .67186 L .58891 .66981 L F
.58743 .67058 m .58551 .67161 L .5864 .67186 L F
.447 .3 .588 r
.29437 .63168 m .29446 .63405 L .2927 .63464 L F
.396 .182 .467 r
.29446 .63405 m .29238 .6368 L .2927 .63464 L F
.606 .859 .991 r
.67777 .61245 m .67577 .61392 L .67516 .61344 L F
.67777 .61245 m .67869 .6132 L .67577 .61392 L F
.669 .165 .04 r
.43627 .74897 m .43499 .74979 L .4329 .74822 L F
.533 .273 .467 r
.62289 .63166 m .6252 .63124 L .62532 .62933 L F
.612 .338 .479 r
.62532 .62933 m .62763 .631 L .6276 .62886 L F
.62532 .62933 m .6252 .63124 L .62763 .631 L F
.372 .441 .802 r
.27711 .61556 m .2784 .61467 L .27646 .61391 L F
.558 .503 .749 r
.27719 .61798 m .2784 .61467 L .27711 .61556 L F
.636 .378 .511 r
.58161 .71508 m .58388 .71521 L .5818 .71302 L F
.666 .375 .469 r
.5818 .71302 m .58388 .71521 L .58418 .71339 L F
.794 .743 .805 r
.70922 .59928 m .70736 .60141 L .70608 .59888 L F
.366 .115 .395 r
.39445 .68624 m .39398 .68831 L .39214 .68888 L F
.46 .198 .429 r
.39602 .68783 m .39445 .68624 L .39656 .68583 L F
.39602 .68783 m .39398 .68831 L .39445 .68624 L F
.202 0 0 r
.33606 .72989 m .33261 .73222 L .33331 .73169 L F
.33606 .72989 m .33465 .7316 L .33261 .73222 L F
0 0 0 r
.33639 .73067 m .33606 .72989 L .33807 .72933 L F
.33639 .73067 m .33465 .7316 L .33606 .72989 L F
.679 .396 .486 r
.3103 .66652 m .31279 .66672 L .31326 .66468 L F
.418 .154 .404 r
.31326 .66468 m .31472 .66612 L .3154 .66432 L F
.31326 .66468 m .31279 .66672 L .31472 .66612 L F
.568 .849 .997 r
.60412 .74277 m .60221 .74325 L .60313 .74198 L F
.635 .462 .631 r
.60173 .74344 m .59896 .74553 L .5979 .74241 L F
.96 .699 .495 r
.60221 .74325 m .60107 .74409 L .60173 .74344 L F
.60296 .74221 m .60182 .74335 L .60296 .7422 L F
.60182 .74335 m .60182 .74334 L .60296 .7422 L F
.60221 .74325 m .60173 .74344 L .60296 .74221 L F
.60296 .7422 m .60107 .7441 L .60313 .74198 L F
.622 .538 .739 r
.60313 .74198 m .60187 .74347 L .60182 .74335 L F
.60313 .74198 m .60182 .74335 L .60015 .7394 L F
.698 .576 .715 r
.60182 .74335 m .60173 .74344 L .5979 .74241 L F
.96 .699 .495 r
.60182 .74335 m .60173 .74344 L .60182 .74334 L F
.698 .576 .715 r
.60015 .7394 m .60182 .74335 L .5979 .74241 L F
.60182 .74335 m .60187 .74347 L .60173 .74344 L F
.635 .462 .631 r
.60187 .74347 m .60126 .74391 L .60173 .74344 L F
.60126 .74391 m .59896 .74553 L .60173 .74344 L F
.96 .699 .495 r
.60107 .74409 m .60107 .7441 L .60296 .7422 L F
.60221 .74325 m .60224 .74571 L .60107 .7441 L F
.596 .395 .579 r
.6045 .74507 m .60221 .74325 L .60412 .74277 L F
.6045 .74507 m .60224 .74571 L .60221 .74325 L F
.366 0 0 r
.51878 .72911 m .52189 .72877 L .52015 .72845 L F
.594 .467 .677 r
.6902 .57716 m .69264 .57612 L .69245 .57462 L F
.094 0 0 r
.6902 .57716 m .69146 .57785 L .69264 .57612 L F
.6902 .57716 m .68933 .57874 L .69146 .57785 L F
.171 0 0 r
.44705 .78449 m .44765 .78522 L .44549 .78527 L F
.44705 .78449 m .44911 .78411 L .44765 .78522 L F
.586 .28 .417 r
.71735 .7129 m .71435 .71544 L .71666 .71508 L F
.71735 .7129 m .71461 .71379 L .71435 .71544 L F
.282 0 .045 r
.71735 .7129 m .71893 .71305 L .71966 .71232 L F
.309 .032 .32 r
.71888 .71444 m .71735 .7129 L .71666 .71508 L F
.71888 .71444 m .71893 .71305 L .71735 .7129 L F
.553 .301 .488 r
.61104 .70544 m .61078 .70742 L .6084 .70775 L F
.431 .179 .429 r
.61332 .70493 m .61078 .70742 L .61104 .70544 L F
0 0 .085 r
.38307 .8002 m .38324 .80232 L .38323 .8014 L F
.38307 .8002 m .38323 .8014 L .38122 .80029 L F
.366 0 0 r
.48559 .78201 m .48458 .78266 L .48341 .78243 L F
.637 .219 .234 r
.48828 .78204 m .48458 .78266 L .48559 .78201 L F
.574 .357 .549 r
.60608 .69925 m .60869 .69668 L .60625 .69719 L F
.571 .451 .677 r
.39127 .76453 m .39317 .76177 L .39134 .76229 L F
.617 .954 .913 r
.49909 .71265 m .50001 .71153 L .50177 .71124 L F
.616 .932 .705 r
.49909 .71265 m .49836 .71298 L .50001 .71153 L F
.309 0 .178 r
.5935 .65124 m .59277 .65256 L .59561 .65058 L F
.783 .814 .877 r
.68946 .6142 m .69294 .61326 L .69174 .61201 L F
.743 .768 .873 r
.69174 .61201 m .69294 .61326 L .69495 .61238 L F
.729 .761 .878 r
.41401 .6614 m .41238 .66284 L .41185 .66206 L F
.41185 .66206 m .41238 .66284 L .41401 .6614 L F
.667 .337 0 r
.67254 .61505 m .67387 .61852 L .67332 .6171 L F
.237 .533 .921 r
.67387 .61852 m .6749 .61766 L .67332 .6171 L F
.67387 .61852 m .67734 .61973 L .6749 .61766 L F
.416 .111 .337 r
.37805 .70508 m .37545 .70711 L .37604 .70557 L F
.743 .593 .689 r
.61776 .65901 m .61616 .66115 L .6141 .65888 L F
.735 .581 .683 r
.61776 .65901 m .61715 .66147 L .61616 .66115 L F
.562 .15 .217 r
.44266 .72838 m .44474 .72865 L .44299 .72738 L F
.4 0 0 r
.47688 .7813 m .48028 .78131 L .47976 .78212 L F
.557 .018 0 r
.48341 .78243 m .47976 .78212 L .48028 .78131 L F
.463 .211 .446 r
.40376 .67787 m .40354 .68024 L .40142 .68079 L F
.279 .003 .303 r
.40582 .67778 m .40354 .68024 L .40376 .67787 L F
.571 .57 .812 r
.55747 .72121 m .55911 .71771 L .55678 .71911 L F
.55747 .72121 m .56031 .72099 L .55911 .71771 L F
.481 0 0 r
.65791 .59574 m .65493 .59538 L .65712 .59538 L F
.102 .636 .863 r
.65851 .5956 m .65791 .59574 L .65712 .59538 L F
.65851 .5956 m .66038 .59595 L .65791 .59574 L F
.505 .31 .55 r
.39398 .68831 m .3918 .69103 L .39214 .68888 L F
.56 .393 .611 r
.39444 .75139 m .39672 .75108 L .39658 .7485 L F
.523 .32 .546 r
.39441 .75347 m .39672 .75108 L .39444 .75139 L F
.527 .426 .683 r
.39063 .77349 m .39221 .76992 L .39018 .77035 L F
.472 0 0 r
.49921 .78032 m .50129 .78069 L .49919 .77844 L F
.49921 .78032 m .50245 .78117 L .50129 .78069 L F
0 0 .494 r
.325 .8242 m .32619 .82746 L .32648 .82689 L F
0 .377 .83 r
.32648 .82689 m .32619 .82746 L .32792 .82832 L F
.652 .882 .525 r
.58986 .66832 m .58891 .66981 L .59108 .66699 L F
.709 .974 .754 r
.58986 .66832 m .58743 .67058 L .58891 .66981 L F
0 0 .078 r
.62763 .6823 m .62614 .68361 L .62839 .68092 L F
.104 0 .225 r
.62763 .6823 m .62541 .68537 L .62614 .68361 L F
.694 .625 .775 r
.31677 .7076 m .31458 .70835 L .31334 .70536 L F
.341 0 .172 r
.33281 .6514 m .33228 .6525 L .3343 .65194 L F
.968 .653 .275 r
.70142 .7174 m .70135 .7161 L .70037 .71535 L F
.993 .823 .452 r
.6676 .59928 m .66666 .60069 L .66691 .59803 L F
.6676 .59928 m .66727 .60158 L .66666 .60069 L F
0 0 0 r
.736 .71928 m .73511 .7207 L .73397 .72171 L F
0 0 .23 r
.73511 .7207 m .73341 .72383 L .73397 .72171 L F
.512 .441 .713 r
.65263 .59795 m .65476 .5986 L .65493 .59538 L F
.21 .698 .927 r
.65712 .59538 m .65493 .59538 L .65598 .59492 L F
0 0 .306 r
.65598 .59492 m .65493 .59538 L .65476 .5986 L F
0 .49 .828 r
.70114 .72954 m .70003 .72893 L .69832 .7285 L F
.729 .241 .083 r
.70341 .73072 m .70003 .72893 L .70114 .72954 L F
.429 .231 .509 r
.41006 .67398 m .40812 .67242 L .41006 .67153 L F
.41006 .67398 m .40789 .67468 L .40812 .67242 L F
.577 .44 .658 r
.59644 .71843 m .59689 .72116 L .59449 .72134 L F
.444 .371 .681 r
.59657 .72364 m .59449 .72134 L .59689 .72116 L F
.59657 .72364 m .5948 .72445 L .59449 .72134 L F
.151 0 0 r
.57699 .66527 m .57785 .66585 L .57886 .66413 L F
.57699 .66527 m .57573 .66647 L .57785 .66585 L F
.51 .482 .762 r
.30838 .60715 m .30882 .60911 L .30677 .60925 L F
.539 .458 .713 r
.30882 .60911 m .30741 .61294 L .30677 .60925 L F
.741 .295 0 r
.50893 .79363 m .50737 .79145 L .50892 .79221 L F
0 0 0 r
.36522 .67079 m .36368 .67126 L .36158 .67166 L F
.112 .664 .781 r
.36755 .67112 m .36368 .67126 L .36522 .67079 L F
.483 .474 .771 r
.69301 .71899 m .69449 .71575 L .69245 .71515 L F
.69301 .71899 m .69553 .7193 L .69449 .71575 L F
.486 .466 .76 r
.69301 .71899 m .69601 .72088 L .69553 .7193 L F
.794 .752 .815 r
.72575 .58365 m .72384 .58616 L .72253 .5846 L F
.437 .262 .544 r
.29982 .62449 m .29853 .62377 L .30004 .62296 L F
.29982 .62449 m .29821 .62549 L .29853 .62377 L F
.721 .684 .814 r
.5976 .73776 m .59581 .74076 L .59526 .73796 L F
.64 .282 .349 r
.59581 .74076 m .5979 .74241 L .59558 .74264 L F
.127 0 0 r
.34539 .72579 m .34346 .72648 L .3463 .7249 L F
.281 0 .045 r
.3483 .7243 m .34539 .72579 L .3463 .7249 L F
.442 0 0 r
.45891 .78298 m .46036 .78182 L .46229 .78252 L F
.646 .622 .811 r
.70257 .5848 m .70302 .58694 L .7015 .58848 L F
.70257 .5848 m .7015 .58848 L .70269 .58699 L F
0 0 0 r
.7015 .58848 m .70049 .58975 L .70269 .58699 L F
.527 .088 .15 r
.35129 .64949 m .35489 .64816 L .35156 .6484 L F
.35129 .64949 m .35345 .64983 L .35489 .64816 L F
.211 0 0 r
.35489 .64816 m .35548 .64925 L .35692 .64859 L F
.35489 .64816 m .35353 .64973 L .35548 .64925 L F
.33 .788 .946 r
.35404 .64872 m .35728 .64879 L .35548 .64925 L F
0 0 0 r
.35548 .64925 m .35754 .6488 L .35897 .64848 L F
.33 .788 .946 r
.35728 .64879 m .35754 .6488 L .35548 .64925 L F
.211 0 0 r
.35353 .64973 m .35345 .64983 L .35548 .64925 L F
.541 .371 .6 r
.3788 .68293 m .38086 .68014 L .3793 .68086 L F
.542 .374 .603 r
.31529 .69855 m .31459 .70125 L .31264 .70153 L F
.635 .516 .701 r
.31459 .70125 m .31334 .70536 L .31264 .70153 L F
.635 .655 .853 r
.59347 .74372 m .59452 .74697 L .59109 .74584 L F
.625 .649 .854 r
.59667 .74616 m .59452 .74697 L .59347 .74372 L F
.313 0 .248 r
.372 .71186 m .37108 .70991 L .37293 .70926 L F
.372 .71186 m .37015 .7125 L .37108 .70991 L F
.404 0 0 r
.33331 .73169 m .33261 .73222 L .33034 .73209 L F
.431 .145 .376 r
.42296 .75366 m .42231 .75601 L .41954 .75594 L F
.476 .282 .537 r
.42231 .75601 m .42017 .75799 L .41954 .75594 L F
0 0 0 r
.68601 .59669 m .68816 .59385 L .68916 .5948 L F
.611 .395 .564 r
.68601 .59669 m .68868 .59847 L .68606 .59806 L F
.68601 .59669 m .68916 .5948 L .68868 .59847 L F
.848 .753 .757 r
.65959 .60675 m .66208 .6075 L .66156 .60391 L F
.859 .732 .722 r
.65959 .60675 m .66055 .6099 L .66208 .6075 L F
.741 .682 .793 r
.66156 .60391 m .66208 .6075 L .66491 .60432 L F
.439 .673 .962 r
.655 .60936 m .65838 .61091 L .65735 .60963 L F
.699 .793 .923 r
.65735 .60963 m .65838 .61091 L .66055 .6099 L F
.186 .719 .78 r
.34979 .67501 m .34819 .67517 L .34642 .67548 L F
.272 0 0 r
.35203 .67545 m .34819 .67517 L .34979 .67501 L F
.421 .743 .993 r
.27676 .59839 m .27631 .59956 L .27481 .59883 L F
.27676 .59839 m .27841 .59947 L .27631 .59956 L F
.483 .259 .498 r
.35933 .90587 m .35777 .90544 L .35692 .90734 L F
0 .273 .773 r
.73758 .59184 m .73583 .59121 L .73552 .5891 L F
.73758 .59184 m .7382 .59297 L .73583 .59121 L F
.647 .333 .425 r
.4237 .73415 m .42721 .73188 L .42431 .73289 L F
.4237 .73415 m .42606 .73438 L .42721 .73188 L F
.563 .224 .352 r
.42606 .73438 m .42945 .73209 L .42721 .73188 L F
.694 .565 .704 r
.38952 .79513 m .39041 .79759 L .3925 .79478 L F
.83 .907 .892 r
.56175 .67746 m .55814 .67919 L .56143 .67753 L F
0 0 0 r
.55814 .67919 m .55985 .67851 L .56143 .67753 L F
.553 .9 .674 r
.56143 .67753 m .55985 .67851 L .56099 .67762 L F
.56143 .67753 m .56099 .67762 L .56234 .67658 L F
.83 .907 .892 r
.5619 .67738 m .56175 .67746 L .56143 .67753 L F
0 0 0 r
.59235 .66612 m .58986 .66832 L .59108 .66699 L F
.139 .221 .688 r
.57587 .7263 m .57621 .72949 L .57654 .727 L F
.57587 .7263 m .57748 .72844 L .57621 .72949 L F
0 0 .154 r
.57748 .72844 m .57643 .73195 L .57621 .72949 L F
.673 .882 .511 r
.59526 .73796 m .59362 .74003 L .59234 .73733 L F
.566 .435 .661 r
.59731 .73527 m .5976 .73776 L .59526 .73796 L F
.047 0 0 r
.45188 .77208 m .45382 .77085 L .45289 .77251 L F
.45188 .77208 m .45337 .77202 L .45371 .77112 L F
.4527 .77156 m .45371 .77112 L .45382 .77085 L F
.45188 .77208 m .45371 .77112 L .4527 .77156 L F
.159 0 0 r
.44945 .77242 m .45066 .77246 L .45094 .76972 L F
.45066 .77246 m .45289 .77251 L .45234 .77172 L F
.45066 .77246 m .45234 .77172 L .45094 .76972 L F
.44945 .77242 m .44937 .7726 L .45289 .77251 L F
0 0 .354 r
.71672 .61791 m .71759 .61432 L .71521 .61476 L F
.71672 .61791 m .71768 .61687 L .71759 .61432 L F
.626 .096 0 r
.71672 .61791 m .71869 .61997 L .71762 .61923 L F
.71672 .61791 m .71762 .61923 L .71768 .61687 L F
.428 .188 .445 r
.38952 .69363 m .38714 .69639 L .38756 .69417 L F
0 0 0 r
.46729 .7401 m .47039 .73754 L .46955 .73949 L F
.369 0 .146 r
.47039 .73754 m .47162 .73901 L .46955 .73949 L F
.47039 .73754 m .47389 .73694 L .47162 .73901 L F
.491 .484 .777 r
.31081 .73135 m .31118 .73282 L .31262 .73118 L F
.329 .266 .634 r
.31148 .73638 m .31262 .73118 L .31118 .73282 L F
.687 .914 .972 r
.72994 .72613 m .72923 .72764 L .73118 .72657 L F
.743 .768 .873 r
.69174 .61201 m .69495 .61238 L .69354 .61136 L F
.706 .801 .924 r
.69354 .61136 m .69495 .61238 L .69742 .6106 L F
.208 0 .075 r
.58825 .65559 m .59012 .65573 L .59109 .65362 L F
.342 .011 .25 r
.59012 .65573 m .59277 .65256 L .59109 .65362 L F
.426 0 0 r
.44423 .74645 m .44281 .74752 L .44098 .74737 L F
.4 0 .13 r
.44636 .74526 m .44281 .74752 L .44423 .74645 L F
.517 .506 .783 r
.38017 .67569 m .38133 .67806 L .38308 .67738 L F
.591 .424 .623 r
.38086 .68014 m .38308 .67738 L .38133 .67806 L F
.644 .17 .112 r
.69566 .71127 m .69682 .7126 L .70027 .71283 L F
.081 0 0 r
.73693 .71994 m .736 .71928 L .73719 .71793 L F
.73693 .71994 m .73511 .7207 L .736 .71928 L F
.522 .511 .785 r
.69042 .59307 m .68916 .5948 L .68816 .59385 L F
.69042 .59307 m .69153 .59588 L .68916 .5948 L F
.685 .493 .621 r
.69153 .59588 m .68868 .59847 L .68916 .5948 L F
.662 .794 .945 r
.34006 .71294 m .3383 .71391 L .33655 .71256 L F
.497 .299 .542 r
.6034 .71292 m .6008 .7153 L .6012 .71314 L F
0 0 .107 r
.63022 .67788 m .62992 .67985 L .62839 .68092 L F
0 0 .095 r
.62992 .67985 m .62763 .6823 L .62839 .68092 L F
.794 .743 .805 r
.70922 .59928 m .70608 .59888 L .70775 .59823 L F
.552 .574 .83 r
.4231 .77235 m .42235 .77559 L .42138 .77249 L F
.4231 .77235 m .42443 .77534 L .42235 .77559 L F
.463 .774 .997 r
.29089 .601 m .28757 .6004 L .28984 .59993 L F
.163 .647 .924 r
.29129 .60049 m .29089 .601 L .28984 .59993 L F
.29129 .60049 m .29281 .60117 L .29089 .601 L F
.456 .058 .195 r
.42133 .73436 m .4237 .73415 L .42431 .73289 L F
.862 .838 .82 r
.59109 .74584 m .5886 .74738 L .58992 .74496 L F
.59109 .74584 m .58891 .7484 L .5886 .74738 L F
.254 .752 .688 r
.58992 .74496 m .59347 .74372 L .59109 .74584 L F
.648 .429 .572 r
.5881 .70506 m .59065 .70724 L .59044 .70481 L F
.5881 .70506 m .58833 .70769 L .59065 .70724 L F
.435 .282 .573 r
.37508 .68886 m .37709 .69045 L .377 .68822 L F
.37508 .68886 m .37499 .69139 L .37709 .69045 L F
.195 .379 .819 r
.51951 .79223 m .52019 .7925 L .52042 .79116 L F
.583 .9 .638 r
.52042 .79116 m .51802 .79331 L .51951 .79223 L F
.442 .7 .975 r
.48214 .77444 m .48344 .77576 L .48129 .77574 L F
.66 .13 0 r
.48216 .77574 m .48344 .77576 L .48214 .77444 L F
0 .575 .713 r
.48129 .77574 m .48344 .77576 L .4844 .77578 L F
.66 .13 0 r
.48217 .77629 m .48344 .77576 L .48216 .77574 L F
0 .575 .713 r
.4844 .77578 m .48344 .77576 L .48465 .77579 L F
.899 .851 .787 r
.38738 .79944 m .38879 .80042 L .39041 .79759 L F
.371 .023 .239 r
.35876 .70496 m .35971 .70667 L .36086 .70446 L F
.35876 .70496 m .35772 .70718 L .35971 .70667 L F
.05 0 0 r
.41281 .73711 m .41491 .73655 L .41632 .73515 L F
.705 .236 .135 r
.41632 .73515 m .41491 .73655 L .41822 .73696 L F
.534 .303 .511 r
.41632 .73515 m .41822 .73696 L .4185 .73475 L F
.45 .601 .909 r
.53856 .72161 m .53857 .72349 L .53838 .72285 L F
.972 .923 .681 r
.58139 .68527 m .58018 .68779 L .58095 .68858 L F
.361 .447 .814 r
.54956 .72889 m .54832 .73011 L .54796 .7287 L F
.379 .476 .833 r
.54956 .72889 m .55088 .7318 L .54832 .73011 L F
0 0 0 r
.67512 .58862 m .67503 .58877 L .67527 .58806 L F
.67503 .58877 m .67385 .59065 L .6747 .5891 L F
.67503 .58877 m .6747 .5891 L .67527 .58806 L F
.092 .164 .647 r
.67449 .58683 m .67506 .58874 L .67609 .58662 L F
.67506 .58874 m .67517 .58863 L .67623 .58632 L F
.745 .573 .661 r
.67401 .5852 m .67255 .58928 L .67501 .58883 L F
.67506 .58874 m .67501 .58883 L .67508 .58882 L F
.67401 .5852 m .67501 .58883 L .67506 .58874 L F
.948 .607 .204 r
.67508 .58882 m .674 .58902 L .67539 .58734 L F
0 0 0 r
.67546 .58724 m .67549 .58723 L .67551 .58722 L F
.67546 .58724 m .67555 .58718 L .67623 .58632 L F
.948 .607 .204 r
.67609 .58662 m .67555 .58718 L .67623 .58632 L F
0 0 0 r
.67555 .58718 m .67828 .58537 L .67623 .58632 L F
.948 .607 .204 r
.67555 .58718 m .67539 .58734 L .67623 .58632 L F
.092 .164 .647 r
.67506 .58874 m .67508 .58882 L .67513 .58871 L F
.568 .274 .429 r
.67578 .58885 m .6751 .5887 L .67527 .58806 L F
.092 .164 .647 r
.6751 .5887 m .67513 .58871 L .67517 .58863 L F
.67506 .58874 m .67513 .58871 L .6751 .5887 L F
.568 .274 .429 r
.67703 .58778 m .67578 .58885 L .67527 .58806 L F
.67578 .58885 m .67485 .58965 L .6751 .5887 L F
.948 .607 .204 r
.67508 .58882 m .67539 .58734 L .67549 .58723 L F
.67508 .58882 m .67549 .58723 L .67604 .58673 L F
0 0 0 r
.67499 .58857 m .6774 .58693 L .67549 .58723 L F
.67544 .58728 m .67549 .58723 L .67546 .58724 L F
.67499 .58857 m .67549 .58723 L .67544 .58728 L F
.948 .607 .204 r
.67604 .58673 m .67549 .58723 L .67609 .58662 L F
0 0 0 r
.67551 .58722 m .6774 .58693 L .67769 .58642 L F
.67549 .58723 m .6774 .58693 L .67551 .58722 L F
.67646 .58657 m .67769 .58642 L .67828 .58537 L F
.67546 .58724 m .67769 .58642 L .67646 .58657 L F
.092 .164 .647 r
.67401 .5852 m .67449 .58683 L .67623 .58632 L F
.67449 .58683 m .67609 .58662 L .67623 .58632 L F
.533 .401 .647 r
.67501 .58883 m .67485 .58965 L .67508 .58882 L F
0 0 0 r
.67485 .58965 m .67428 .59022 L .67501 .58883 L F
.67428 .59022 m .67385 .59065 L .67512 .58862 L F
.533 .401 .647 r
.67255 .58928 m .67485 .58965 L .67501 .58883 L F
0 0 0 r
.67485 .58965 m .67501 .58883 L .67505 .58874 L F
.948 .607 .204 r
.67504 .58883 m .67485 .58965 L .674 .58902 L F
.67508 .58882 m .67485 .58965 L .67504 .58883 L F
0 0 0 r
.67485 .58965 m .67505 .58874 L .67512 .58862 L F
.156 0 0 r
.67836 .58639 m .67703 .58778 L .67527 .58806 L F
.553 .764 .976 r
.57303 .71556 m .57067 .716 L .57007 .71482 L F
.387 .208 .514 r
.60334 .74787 m .60323 .75103 L .60078 .75086 L F
.394 .111 .361 r
.60323 .75103 m .60033 .75337 L .60078 .75086 L F
.994 .752 .4 r
.58133 .75449 m .58007 .75534 L .57869 .75304 L F
.58133 .75449 m .58106 .75669 L .58007 .75534 L F
.861 .569 .492 r
.58252 .75656 m .58106 .75669 L .58133 .75449 L F
.512 .441 .713 r
.65263 .59795 m .65272 .5989 L .65476 .5986 L F
.383 0 0 r
.45223 .78319 m .45132 .78401 L .44911 .78411 L F
.323 0 0 r
.45448 .78301 m .45132 .78401 L .45223 .78319 L F
.561 .412 .637 r
.39658 .7485 m .39872 .7482 L .39856 .74569 L F
.505 .351 .605 r
.39658 .7485 m .39869 .75055 L .39872 .7482 L F
.39658 .7485 m .39672 .75108 L .39869 .75055 L F
.583 .361 .545 r
.59878 .71613 m .59877 .7182 L .59644 .71843 L F
.543 .329 .54 r
.60124 .71773 m .59878 .71613 L .6008 .7153 L F
.60124 .71773 m .59877 .7182 L .59878 .71613 L F
.938 .904 .763 r
.64571 .61492 m .64719 .61273 L .6462 .61202 L F
.486 .819 .999 r
.6462 .61202 m .64719 .61273 L .64944 .61233 L F
.352 .06 .321 r
.38198 .70388 m .38073 .7023 L .38273 .70176 L F
.38198 .70388 m .38009 .70459 L .38073 .7023 L F
.683 .621 .78 r
.69886 .59333 m .70105 .59696 L .70276 .59514 L F
.361 .33 .689 r
.59657 .72364 m .59602 .72688 L .5948 .72445 L F
.828 .559 .531 r
.60862 .65908 m .60576 .66049 L .60527 .65904 L F
.60862 .65908 m .60882 .6613 L .60576 .66049 L F
.693 .477 .59 r
.61251 .65843 m .60882 .6613 L .60862 .65908 L F
.647 .968 .851 r
.71801 .72894 m .71893 .72775 L .72016 .72894 L F
.71801 .72894 m .71719 .72893 L .71893 .72775 L F
.549 .14 .218 r
.68035 .58738 m .67703 .58778 L .67836 .58639 L F
.512 .225 .415 r
.68033 .58567 m .68035 .58738 L .67836 .58639 L F
.337 .046 .315 r
.37545 .70711 m .37293 .70926 L .37361 .70793 L F
.834 .607 .595 r
.61715 .66147 m .61909 .66443 L .61672 .66368 L F
.888 .659 .586 r
.61844 .6668 m .61672 .66368 L .61909 .66443 L F
.558 .369 .581 r
.5863 .71282 m .58847 .71008 L .58676 .71084 L F
.583 .593 .828 r
.5462 .73781 m .54784 .74086 L .54995 .74025 L F
0 0 .438 r
.67794 .62058 m .67804 .62065 L .67734 .61973 L F
.689 .198 0 r
.67794 .62058 m .6798 .62307 L .67856 .62181 L F
.67794 .62058 m .67856 .62181 L .67804 .62065 L F
.447 .084 .254 r
.43165 .73182 m .43381 .73147 L .43492 .72938 L F
.527 .166 .297 r
.43381 .73147 m .4372 .7293 L .43492 .72938 L F
.066 0 0 r
.50185 .72397 m .50101 .72399 L .49837 .72387 L F
.249 .173 .571 r
.50101 .72399 m .50185 .72397 L .49837 .72387 L F
.687 .98 .863 r
.52207 .78263 m .52041 .78398 L .52128 .78265 L F
.632 .925 .974 r
.52041 .78398 m .51925 .7836 L .52128 .78265 L F
.21 0 .109 r
.58825 .65559 m .58747 .65755 L .59012 .65573 L F
.346 .037 .29 r
.37273 .69583 m .37527 .69369 L .37343 .69431 L F
.893 .868 .426 r
.54215 .69938 m .54271 .69618 L .54336 .69641 L F
0 0 0 r
.56422 .67487 m .56574 .67421 L .56715 .67306 L F
.56422 .67487 m .56304 .67619 L .56574 .67421 L F
.4329 .74822 m .43025 .75059 L .43064 .74853 L F
.672 .463 .594 r
.31962 .69435 m .31979 .69654 L .31633 .69645 L F
.558 .392 .612 r
.32192 .69164 m .32167 .69416 L .31962 .69435 L F
.624 .468 .65 r
.32167 .69416 m .31979 .69654 L .31962 .69435 L F
.325 .101 .412 r
.30332 .61812 m .30004 .62296 L .30028 .62121 L F
.38 .535 .885 r
.41352 .79166 m .41529 .79087 L .41351 .79107 L F
.41352 .79166 m .41526 .79205 L .41529 .79087 L F
.693 .477 .59 r
.61251 .65843 m .61269 .66126 L .60882 .6613 L F
.685 .471 .591 r
.6141 .65888 m .61269 .66126 L .61251 .65843 L F
.433 .37 .687 r
.27768 .61898 m .2791 .61779 L .27719 .61798 L F
.27768 .61898 m .27962 .62012 L .2791 .61779 L F
.431 .37 .689 r
.27799 .62081 m .27962 .62012 L .27768 .61898 L F
.634 .652 .85 r
.3257 .70954 m .32221 .70767 L .32424 .70735 L F
.632 .693 .889 r
.32727 .70832 m .3257 .70954 L .32424 .70735 L F
.446 .23 .491 r
.38521 .69693 m .38483 .69924 L .38299 .69968 L F
.359 .122 .412 r
.38483 .69924 m .38273 .70176 L .38299 .69968 L F
.517 .571 .849 r
.30183 .72957 m .3036 .72882 L .30136 .72864 L F
.527 .426 .683 r
.39063 .77349 m .39263 .77309 L .39221 .76992 L F
.148 .013 .428 r
.39117 .77573 m .39263 .77309 L .39063 .77349 L F
.138 .683 .804 r
.42464 .78878 m .42118 .78889 L .4227 .78893 L F
.841 .831 .837 r
.39389 .79087 m .3925 .79478 L .39474 .79493 L F
.857 .736 .728 r
.64162 .62872 m .64055 .6254 L .63878 .62831 L F
.64162 .62872 m .64207 .62658 L .64055 .6254 L F
.87 .699 .667 r
.63855 .63055 m .64162 .62872 L .63878 .62831 L F
.63855 .63055 m .64009 .63174 L .64162 .62872 L F
.714 .658 .793 r
.5926 .70445 m .59655 .70369 L .5931 .70266 L F
0 .488 .732 r
.37057 .67172 m .36755 .67112 L .36856 .67151 L F
.712 .498 .598 r
.45094 .76972 m .4547 .7702 L .45447 .76759 L F
.298 .721 .972 r
.45513 .76687 m .45716 .76771 L .45447 .76759 L F
.583 .402 .603 r
.45447 .76759 m .45716 .76771 L .45513 .76687 L F
.45447 .76759 m .4547 .7702 L .45716 .76771 L F
.45716 .76771 m .4547 .7702 L .45447 .76759 L F
.712 .498 .598 r
.45094 .76972 m .4547 .7702 L .45447 .76759 L F
.639 .677 .87 r
.69047 .60425 m .68735 .60232 L .68943 .6012 L F
.658 .631 .811 r
.69265 .60328 m .69047 .60425 L .68943 .6012 L F
.52 .373 .621 r
.41731 .75957 m .41832 .76209 L .41641 .76239 L F
.533 .397 .641 r
.42017 .75799 m .41832 .76209 L .41731 .75957 L F
.426 .123 .346 r
.42575 .75289 m .42296 .75366 L .42543 .75169 L F
.544 .192 .321 r
.42543 .75169 m .42729 .75303 L .42575 .75289 L F
.538 .196 .337 r
.42821 .751 m .42729 .75303 L .42543 .75169 L F
.661 .643 .821 r
.32024 .70864 m .31677 .7076 L .3188 .70704 L F
.703 .693 .838 r
.32221 .70767 m .32024 .70864 L .3188 .70704 L F
0 0 0 r
.63246 .67518 m .63171 .67695 L .63022 .67788 L F
0 0 .106 r
.63022 .67788 m .63171 .67695 L .62992 .67985 L F
.992 .855 .502 r
.57851 .68356 m .57757 .68513 L .57723 .68275 L F
.343 0 0 r
.34026 .64967 m .34232 .64993 L .34382 .64946 L F
0 0 0 r
.34382 .64946 m .34436 .64942 L .3451 .6489 L F
.34382 .64946 m .34232 .64993 L .34436 .64942 L F
.416 .797 .991 r
.56593 .6966 m .56819 .69632 L .56929 .69694 L F
.243 .695 .954 r
.56819 .69632 m .57141 .69704 L .56929 .69694 L F
.669 .826 .959 r
.59896 .74553 m .60224 .74571 L .60012 .74655 L F
.393 .469 .819 r
.55273 .73188 m .55225 .73495 L .55088 .7318 L F
.55273 .73188 m .55387 .73476 L .55225 .73495 L F
.624 .462 .642 r
.55376 .73657 m .55225 .73495 L .55387 .73476 L F
.55376 .73657 m .55204 .7382 L .55225 .73495 L F
.834 .607 .595 r
.61715 .66147 m .61672 .66368 L .61616 .66115 L F
.027 0 0 r
.47302 .72462 m .47509 .72429 L .47613 .72392 L F
.428 0 0 r
.47509 .72429 m .47835 .72391 L .47613 .72392 L F
.146 .676 .866 r
.73175 .60337 m .73534 .60366 L .73312 .60366 L F
.148 .013 .428 r
.39117 .77573 m .39222 .77527 L .39263 .77309 L F
.274 .317 .725 r
.39117 .77573 m .39324 .77784 L .39222 .77527 L F
.547 .359 .578 r
.39109 .77815 m .39324 .77784 L .39117 .77573 L F
.863 .659 .625 r
.64087 .63691 m .64099 .63452 L .63972 .63391 L F
.881 .758 .722 r
.64099 .63452 m .64009 .63174 L .63972 .63391 L F
.112 .549 .916 r
.44001 .77414 m .43889 .77448 L .43769 .77501 L F
.44001 .77414 m .44115 .77509 L .43889 .77448 L F
.386 .153 .434 r
.38714 .69639 m .38483 .69924 L .38521 .69693 L F
.731 .29 .203 r
.70157 .57937 m .70422 .57727 L .7033 .58015 L F
0 0 .498 r
.70434 .57706 m .70422 .57727 L .70337 .57529 L F
.501 .68 .946 r
.722 .58318 m .72082 .58477 L .71985 .58366 L F
.722 .58318 m .72253 .5846 L .72082 .58477 L F
0 0 0 r
.37841 .66915 m .37498 .66958 L .37647 .66935 L F
.904 .807 .741 r
.57226 .71906 m .57413 .71873 L .57304 .71801 L F
.57226 .71906 m .57288 .72117 L .57413 .71873 L F
.987 .738 .464 r
.57303 .71556 m .57304 .71801 L .57413 .71873 L F
.122 0 0 r
.34418 .72727 m .34346 .72648 L .34539 .72579 L F
.34418 .72727 m .34202 .72816 L .34346 .72648 L F
.588 .931 .739 r
.32097 .73695 m .31858 .73883 L .32039 .73787 L F
.376 .481 .839 r
.59646 .7306 m .59865 .73177 L .59717 .73197 L F
.59672 .73023 m .59865 .73177 L .59646 .7306 L F
.741 .454 .495 r
.59586 .73156 m .59624 .73159 L .59595 .72961 L F
.59624 .73159 m .59865 .73177 L .59672 .73023 L F
.376 .481 .839 r
.59595 .72961 m .59672 .73023 L .59646 .7306 L F
.741 .454 .495 r
.59624 .73159 m .59672 .73023 L .59595 .72961 L F
0 0 0 r
.59581 .73281 m .59641 .73256 L .59713 .72965 L F
.59544 .73371 m .59553 .7336 L .59581 .73281 L F
.59553 .7336 m .59641 .73256 L .59581 .73281 L F
.59702 .72981 m .59713 .72965 L .5972 .72935 L F
.59544 .73371 m .59713 .72965 L .59702 .72981 L F
.59 .527 .752 r
.59865 .73177 m .59731 .73527 L .59717 .73197 L F
.895 .774 .72 r
.64207 .62658 m .64138 .62362 L .64055 .6254 L F
.529 0 0 r
.54307 .72518 m .54614 .72634 L .54381 .72498 L F
.694 .625 .775 r
.31677 .7076 m .31334 .70536 L .3154 .70451 L F
.609 .597 .814 r
.3188 .70704 m .31677 .7076 L .3154 .70451 L F
.564 .013 0 r
.57643 .73195 m .57832 .73274 L .57952 .73248 L F
.335 .598 .943 r
.58087 .73148 m .57952 .73248 L .57832 .73274 L F
.58087 .73148 m .58139 .73262 L .57952 .73248 L F
.366 .468 .832 r
.58258 .73412 m .57952 .73248 L .58139 .73262 L F
.243 .545 .927 r
.53258 .71848 m .53146 .71918 L .53094 .71767 L F
.53258 .71848 m .53415 .72029 L .53146 .71918 L F
.509 .502 .784 r
.55583 .71594 m .55678 .71911 L .55911 .71771 L F
.631 .466 .642 r
.30741 .61294 m .30757 .61516 L .30551 .61538 L F
.539 .458 .713 r
.30882 .60911 m .30911 .61237 L .30741 .61294 L F
.412 .263 .567 r
.30911 .61237 m .30757 .61516 L .30741 .61294 L F
.415 0 .033 r
.46324 .77484 m .46549 .77477 L .46693 .77315 L F
.266 0 0 r
.46693 .77315 m .46762 .77435 L .46961 .77281 L F
.46693 .77315 m .46549 .77477 L .46762 .77435 L F
.637 .64 .836 r
.70066 .61246 m .70411 .61457 L .70299 .61185 L F
.631 .691 .888 r
.70411 .61457 m .70525 .61161 L .70299 .61185 L F
.70411 .61457 m .70661 .61377 L .70525 .61161 L F
.823 .83 .357 r
.63334 .67154 m .63253 .67413 L .63246 .67518 L F
.817 .818 .336 r
.63253 .67413 m .63171 .67695 L .63246 .67518 L F
.105 0 0 r
.3935 .7866 m .39222 .78708 L .39026 .78724 L F
.893 .989 .77 r
.39276 .78635 m .3935 .7866 L .39526 .78635 L F
.39276 .78635 m .39222 .78708 L .3935 .7866 L F
.161 0 0 r
.46711 .72595 m .46928 .72577 L .47081 .72511 L F
.512 .747 .98 r
.30382 .60445 m .30332 .60587 L .30143 .60425 L F
.30382 .60445 m .30535 .60564 L .30332 .60587 L F
.042 0 0 r
.72676 .73576 m .72564 .7354 L .72659 .7346 L F
.79 .315 0 r
.71325 .58076 m .71411 .58129 L .71339 .58013 L F
.031 0 0 r
.57143 .74298 m .56768 .74291 L .56929 .74022 L F
.57143 .74298 m .56955 .74296 L .56768 .74291 L F
0 .043 .547 r
.57172 .74507 m .56955 .74296 L .57143 .74298 L F
.557 .418 .648 r
.34112 .843 m .34312 .84411 L .34311 .84194 L F
.644 .612 .802 r
.57942 .705 m .57612 .70263 L .57846 .70249 L F
0 .028 .59 r
.57907 .70295 m .57846 .70249 L .57895 .7018 L F
.57907 .70295 m .57942 .705 L .57846 .70249 L F
.637 .856 .983 r
.57895 .7018 m .57612 .70263 L .57846 .70249 L F
.514 .238 .434 r
.58418 .71339 m .58613 .71478 L .5863 .71282 L F
.58418 .71339 m .58388 .71521 L .58613 .71478 L F
.693 .832 .95 r
.44842 .7452 m .44996 .7463 L .45162 .74517 L F
.502 .176 .347 r
.36548 .70184 m .36774 .70162 L .36843 .6992 L F
.227 0 .251 r
.36843 .6992 m .37027 .69888 L .37087 .69665 L F
.377 .063 .301 r
.36843 .6992 m .36973 .70105 L .37027 .69888 L F
.36843 .6992 m .36774 .70162 L .36973 .70105 L F
.779 .592 .647 r
.6141 .65888 m .61616 .66115 L .61269 .66126 L F
.769 .534 .578 r
.61269 .66126 m .61616 .66115 L .6138 .66358 L F
.77 .535 .579 r
.61616 .66115 m .61672 .66368 L .6138 .66358 L F
.877 .81 .78 r
.63947 .65816 m .63898 .65568 L .63844 .65785 L F
.952 .918 .741 r
.63784 .66149 m .63947 .65816 L .63844 .65785 L F
.345 0 .197 r
.30757 .61516 m .3046 .61745 L .30551 .61538 L F
.476 .45 .75 r
.37955 .67235 m .38017 .67569 L .38207 .67418 L F
.517 .506 .783 r
.38017 .67569 m .38308 .67738 L .38207 .67418 L F
.511 .372 .628 r
.27781 .62309 m .27962 .62012 L .27799 .62081 L F
.585 .224 .324 r
.54111 .73454 m .53742 .7365 L .5376 .73529 L F
.54111 .73454 m .53977 .73684 L .53742 .7365 L F
.08 0 .034 r
.542 .73562 m .54111 .73454 L .54322 .73543 L F
.54019 .73661 m .53977 .73684 L .54072 .73522 L F
.542 .73562 m .54019 .73661 L .54038 .7362 L F
.542 .73562 m .54038 .7362 L .54111 .73454 L F
.447 .503 .824 r
.542 .73562 m .54281 .73543 L .54261 .73541 L F
.08 0 .034 r
.54019 .73661 m .54072 .73522 L .54111 .73454 L F
.447 .503 .824 r
.542 .73562 m .54261 .73541 L .54026 .73516 L F
.61 .781 .963 r
.54026 .73516 m .53983 .73665 L .542 .73562 L F
.53983 .73665 m .53977 .73684 L .54019 .73661 L F
.53983 .73665 m .54019 .73661 L .542 .73562 L F
.498 .088 .193 r
.54017 .73667 m .53624 .73845 L .53715 .73695 L F
.483 .648 .931 r
.54026 .73516 m .5404 .73669 L .53977 .73684 L F
.498 .088 .193 r
.5404 .73669 m .53742 .7365 L .53977 .73684 L F
.53982 .73665 m .53715 .73695 L .53742 .7365 L F
.54017 .73667 m .53715 .73695 L .53982 .73665 L F
.5404 .73669 m .54012 .73681 L .54017 .73667 L F
.54012 .73681 m .53624 .73845 L .54017 .73667 L F
.247 .713 .946 r
.38794 .78734 m .38659 .78679 L .38445 .78679 L F
.361 .761 .985 r
.38794 .78734 m .38865 .78652 L .38659 .78679 L F
.38794 .78734 m .39026 .78724 L .38865 .78652 L F
.452 .863 .957 r
.51526 .73495 m .51631 .73411 L .5141 .73468 L F
.51526 .73495 m .51631 .73411 L .5141 .73468 L F
0 0 .046 r
.61076 .69147 m .61205 .69049 L .61243 .68859 L F
.705 .802 .334 r
.6107 .69382 m .61205 .69049 L .61076 .69147 L F
.53 .415 .668 r
.41832 .76209 m .41872 .76393 L .41641 .76239 L F
.444 .43 .748 r
.41641 .76239 m .41872 .76393 L .41688 .7636 L F
.321 0 0 r
.47565 .77572 m .47805 .77577 L .47905 .77527 L F
0 0 0 r
.47905 .77527 m .48002 .77528 L .48129 .77574 L F
.47905 .77527 m .47805 .77577 L .48002 .77528 L F
.44 .123 .33 r
.59593 .75459 m .59554 .75605 L .59337 .75647 L F
.445 .127 .332 r
.59828 .75411 m .59554 .75605 L .59593 .75459 L F
.58 .48 .705 r
.39317 .7594 m .39489 .75677 L .39278 .75725 L F
.39317 .7594 m .39537 .75906 L .39489 .75677 L F
.54 .355 .58 r
.39317 .76177 m .39537 .75906 L .39317 .7594 L F
.307 .463 .852 r
.27646 .61391 m .2764 .61167 L .27593 .6125 L F
.27646 .61391 m .27683 .61179 L .2764 .61167 L F
.27646 .61391 m .2784 .61467 L .27683 .61179 L F
.194 .58 .941 r
.72477 .72027 m .72612 .7198 L .72384 .71948 L F
.147 0 0 r
.44474 .72865 m .44691 .72815 L .44836 .72695 L F
.374 0 0 r
.44691 .72815 m .45049 .72689 L .44836 .72695 L F
.555 .329 .526 r
.29202 .68593 m .29419 .68568 L .29456 .68345 L F
.486 .267 .506 r
.29456 .68345 m .2962 .68516 L .29637 .6829 L F
.29456 .68345 m .29419 .68568 L .2962 .68516 L F
.856 .722 .713 r
.63967 .64505 m .63864 .642 L .63679 .64465 L F
.862 .672 .643 r
.63896 .64738 m .63967 .64505 L .63679 .64465 L F
.823 .707 .736 r
.63967 .64505 m .6403 .64296 L .63864 .642 L F
.669 .117 0 r
.71031 .73296 m .70913 .73262 L .70726 .73106 L F
.337 0 0 r
.71262 .73198 m .70913 .73262 L .71031 .73296 L F
.289 .75 .949 r
.28173 .59979 m .27841 .59947 L .28021 .59903 L F
.347 .743 .984 r
.28379 .5997 m .28173 .59979 L .28021 .59903 L F
.572 .389 .595 r
.61078 .70742 m .60846 .71024 L .6084 .70775 L F
.846 .472 .343 r
.49037 .7775 m .49231 .78014 L .4935 .77862 L F
.782 .283 .007 r
.49367 .78024 m .4935 .77862 L .49231 .78014 L F
.49367 .78024 m .49548 .78102 L .4935 .77862 L F
.992 .755 .472 r
.61797 .63565 m .61746 .63889 L .6174 .63868 L F
.53 .274 .471 r
.61797 .63565 m .61979 .63671 L .62083 .63402 L F
.629 .403 .555 r
.6174 .63868 m .61979 .63671 L .61797 .63565 L F
.714 .725 .859 r
.70207 .60244 m .69842 .60192 L .70052 .60068 L F
.548 .376 .6 r
.63835 .61711 m .6364 .61553 L .63645 .61779 L F
.63835 .61711 m .63861 .61546 L .6364 .61553 L F
.92 .792 .702 r
.6403 .64296 m .64041 .63873 L .63864 .642 L F
.654 .585 .765 r
.30438 .74538 m .30653 .74229 L .30466 .74309 L F
.155 .697 .758 r
.529 .78849 m .52595 .78888 L .52699 .78893 L F
.54 .527 .789 r
.65183 .60602 m .65344 .60359 L .65078 .60412 L F
.402 .394 .736 r
.69832 .7285 m .69953 .72576 L .69671 .72622 L F
.69832 .7285 m .70003 .72893 L .69953 .72576 L F
.77 .629 .704 r
.72359 .72993 m .72016 .72894 L .7225 .72916 L F
.72359 .72993 m .72004 .73086 L .72016 .72894 L F
.72359 .72993 m .72112 .73329 L .72004 .73086 L F
.505 .809 1 r
.72488 .72854 m .72359 .72993 L .7225 .72916 L F
.72488 .72854 m .72582 .72963 L .72359 .72993 L F
.517 .692 .947 r
.38383 .65502 m .38179 .6553 L .38034 .65354 L F
.349 0 .04 r
.352 .70966 m .35563 .70767 L .3538 .70827 L F
.358 .035 .274 r
.30952 .73822 m .31159 .73799 L .31148 .73638 L F
.329 .266 .634 r
.31148 .73638 m .31239 .73585 L .31262 .73118 L F
0 0 0 r
.56715 .67306 m .56757 .67325 L .56886 .67191 L F
.56715 .67306 m .56574 .67421 L .56757 .67325 L F
.57 .936 .808 r
.673 .59087 m .67385 .59065 L .67485 .58965 L F
.67485 .58965 m .67385 .59065 L .673 .59087 L F
.173 .204 .653 r
.6755 .59254 m .67385 .59065 L .67485 .58965 L F
.6755 .59254 m .67464 .59297 L .67385 .59065 L F
.219 0 .248 r
.37087 .69665 m .3718 .69818 L .37273 .69583 L F
.37087 .69665 m .37027 .69888 L .3718 .69818 L F
.651 .782 .944 r
.30662 .72882 m .31081 .73135 L .30906 .72876 L F
.443 .688 .969 r
.31081 .73135 m .31065 .72957 L .30906 .72876 L F
.31081 .73135 m .31262 .73118 L .31065 .72957 L F
0 0 .041 r
.57726 .70765 m .57635 .71005 L .57507 .71097 L F
.649 .32 .402 r
.57946 .70953 m .57635 .71005 L .57726 .70765 L F
.635 .479 .654 r
.57942 .705 m .5801 .70777 L .57726 .70765 L F
.616 .334 .466 r
.5801 .70777 m .57946 .70953 L .57726 .70765 L F
.905 .719 .64 r
.51372 .72428 m .51297 .72658 L .51166 .72335 L F
.35 0 .215 r
.32915 .65536 m .33228 .6525 L .33025 .65301 L F
.461 .28 .547 r
.6951 .71391 m .69245 .71515 L .69449 .71575 L F
.815 .643 .669 r
.70744 .5824 m .70713 .57979 L .70857 .58076 L F
.757 .953 .939 r
.70922 .57902 m .70857 .58076 L .70713 .57979 L F
0 0 0 r
.71858 .721 m .71446 .72357 L .71821 .72083 L F
.72098 .71977 m .72017 .7202 L .71821 .72083 L F
.72017 .7202 m .71858 .721 L .71821 .72083 L F
.177 0 0 r
.52488 .78202 m .52701 .78218 L .52839 .782 L F
.027 0 0 r
.52701 .78218 m .5304 .78173 L .52839 .782 L F
.51 .778 .993 r
.42996 .7761 m .42783 .77645 L .42645 .77535 L F
.57 .719 .943 r
.40494 .66541 m .40408 .66732 L .40289 .66577 L F
.498 .635 .914 r
.40494 .66541 m .4064 .66735 L .40408 .66732 L F
.538 .094 .143 r
.53671 .78053 m .53806 .77796 L .5396 .77837 L F
.53671 .78053 m .53943 .78096 L .53806 .77796 L F
.53671 .78053 m .5359 .78111 L .53943 .78096 L F
.815 .643 .669 r
.70744 .5824 m .70449 .58015 L .70713 .57979 L F
.70744 .5824 m .70648 .58292 L .70449 .58015 L F
.823 .665 .686 r
.70744 .5824 m .70603 .58524 L .70648 .58292 L F
.271 .755 .655 r
.39474 .79493 m .39796 .79361 L .39702 .794 L F
.002 0 0 r
.39879 .79372 m .40036 .79277 L .39796 .79361 L F
.39879 .79372 m .39796 .79361 L .39707 .79187 L F
.414 .233 .524 r
.29615 .62876 m .29598 .63109 L .29437 .63168 L F
.313 .154 .499 r
.29598 .63109 m .29446 .63405 L .29437 .63168 L F
.588 .321 .479 r
.61111 .64486 m .61384 .64465 L .61387 .64233 L F
.21 .122 .531 r
.61529 .63913 m .61387 .64233 L .61487 .64185 L F
.542 .284 .474 r
.61387 .64233 m .61593 .64395 L .61487 .64185 L F
.61387 .64233 m .61384 .64465 L .61593 .64395 L F
.79 .579 .615 r
.39389 .79087 m .39707 .79187 L .3968 .78928 L F
.475 .557 .86 r
.3968 .78928 m .39712 .78611 L .39526 .78635 L F
.3968 .78928 m .3984 .78887 L .39712 .78611 L F
.461 .338 .626 r
.39707 .79187 m .39929 .79149 L .3968 .78928 L F
.669 .117 0 r
.3968 .78928 m .39929 .79149 L .39752 .79067 L F
.3968 .78928 m .39752 .79067 L .3984 .78887 L F
0 0 0 r
.33691 .65044 m .34026 .64967 L .33811 .65016 L F
.627 .068 0 r
.50336 .78689 m .50307 .78759 L .50039 .78584 L F
.778 .272 0 r
.50336 .78689 m .50441 .78929 L .50307 .78759 L F
.50336 .78689 m .50616 .78993 L .50441 .78929 L F
.783 .416 .363 r
.50713 .78916 m .50616 .78993 L .50336 .78689 L F
.462 .062 .194 r
.49407 .72868 m .49272 .73094 L .49048 .73109 L F
.547 .151 .242 r
.49516 .73076 m .49407 .72868 L .49602 .72843 L F
.49516 .73076 m .49272 .73094 L .49407 .72868 L F
.667 .73 .897 r
.33113 .7095 m .32727 .70832 L .32959 .70799 L F
.57 .745 .96 r
.33352 .70902 m .33113 .7095 L .32959 .70799 L F
.915 .973 .783 r
.63597 .66432 m .63784 .66149 L .63614 .66206 L F
.886 .858 .408 r
.63597 .66432 m .63508 .66603 L .63557 .66642 L F
.63597 .66432 m .63614 .66206 L .63508 .66603 L F
.36 .553 .907 r
.34651 .7089 m .34557 .71009 L .34535 .70905 L F
.466 .706 .973 r
.34651 .7089 m .34781 .7102 L .34557 .71009 L F
.582 .424 .632 r
.62303 .63412 m .6252 .63124 L .62289 .63166 L F
.306 0 0 r
.46568 .78135 m .46668 .78214 L .46439 .78233 L F
.46568 .78135 m .46794 .78154 L .46668 .78214 L F
.997 .816 .464 r
.72221 .60898 m .72287 .60988 L .72274 .60704 L F
.773 .507 .533 r
.71973 .61186 m .72287 .60988 L .72221 .60898 L F
.71973 .61186 m .72255 .6124 L .72274 .60996 L F
.096 0 0 r
.72038 .61388 m .72385 .61264 L .71973 .61186 L F
.72038 .61388 m .72249 .61331 L .72385 .61264 L F
.72038 .61388 m .72223 .61366 L .72249 .61331 L F
.912 .739 .244 r
.72249 .61324 m .72223 .61366 L .7223 .61123 L F
.72249 .61331 m .72248 .61333 L .72249 .61324 L F
.72248 .61333 m .72223 .61366 L .72249 .61324 L F
.773 .507 .533 r
.72274 .60996 m .72385 .61264 L .72287 .60988 L F
.72255 .6124 m .72385 .61264 L .72274 .60996 L F
.997 .816 .464 r
.72274 .60704 m .72287 .60988 L .72221 .60898 L F
.937 .564 .238 r
.72287 .60988 m .7223 .61123 L .72221 .60898 L F
.72287 .60988 m .72385 .61264 L .7223 .61123 L F
.435 .148 .377 r
.42407 .7556 m .42296 .75366 L .42575 .75289 L F
.42407 .7556 m .42231 .75601 L .42296 .75366 L F
.53 .407 .657 r
.59897 .72043 m .59644 .71843 L .59877 .7182 L F
.59897 .72043 m .59689 .72116 L .59644 .71843 L F
.794 .752 .815 r
.72575 .58365 m .72253 .5846 L .72482 .58184 L F
.643 .736 .916 r
.72719 .58152 m .72575 .58365 L .72482 .58184 L F
.72719 .58152 m .72761 .5831 L .72575 .58365 L F
.507 .185 .355 r
.43025 .75059 m .42729 .75303 L .42821 .751 L F
.835 .397 .19 r
.48904 .77694 m .48987 .77604 L .48905 .77495 L F
.48904 .77694 m .49037 .7775 L .48987 .77604 L F
0 .065 .578 r
.52468 .70996 m .52432 .70983 L .52305 .70863 L F
.52468 .70996 m .52642 .71183 L .52432 .70983 L F
0 .143 .683 r
.58108 .70587 m .57942 .705 L .57907 .70295 L F
.58108 .70587 m .58117 .70703 L .57942 .705 L F
.317 .274 .651 r
.58117 .70703 m .5801 .70777 L .57942 .705 L F
.968 .717 .501 r
.34506 .84329 m .34637 .84361 L .34507 .8406 L F
.499 .881 .969 r
.34737 .85422 m .34875 .85449 L .3494 .85359 L F
.34737 .85422 m .34875 .85449 L .3494 .85359 L F
.775 .673 .75 r
.41271 .65814 m .41401 .6614 L .4162 .65951 L F
.695 .807 .935 r
.41486 .65784 m .4162 .65951 L .41848 .65786 L F
.437 .819 .99 r
.35897 .64848 m .36263 .64874 L .36026 .64904 L F
.209 0 0 r
.49397 .7834 m .4935 .78328 L .49149 .78271 L F
.296 .53 .908 r
.4935 .78328 m .49444 .78217 L .4928 .7831 L F
.615 .146 .117 r
.49149 .78271 m .4935 .78328 L .49019 .78322 L F
.296 .53 .908 r
.4935 .78328 m .4928 .7831 L .49252 .78326 L F
.209 0 0 r
.4949 .78366 m .4935 .78328 L .49397 .7834 L F
0 .324 .751 r
.4949 .78366 m .49568 .78374 L .4935 .78328 L F
.4949 .78366 m .49739 .78493 L .49568 .78374 L F
.072 .601 .868 r
.65598 .59492 m .65851 .5956 L .65712 .59538 L F
.573 .371 .569 r
.65495 .59848 m .65851 .5956 L .65598 .59492 L F
.65488 .59872 m .65498 .59864 L .65495 .59848 L F
.65498 .59864 m .65851 .5956 L .65495 .59848 L F
.276 .388 .797 r
.65499 .59872 m .65596 .60171 L .65743 .59998 L F
.65476 .5986 m .65514 .59958 L .65499 .59872 L F
.65514 .59958 m .65596 .60171 L .65499 .59872 L F
.638 .952 .753 r
.65596 .60171 m .65473 .60224 L .65743 .59998 L F
0 0 0 r
.48377 .72112 m .48509 .72065 L .48543 .72007 L F
.48377 .72112 m .48243 .72267 L .48509 .72065 L F
.377 0 .123 r
.35364 .72134 m .3523 .72333 L .35011 .72363 L F
.059 0 0 r
.35409 .72234 m .35364 .72134 L .35556 .72073 L F
.35409 .72234 m .3523 .72333 L .35364 .72134 L F
.893 .868 .426 r
.54215 .69938 m .54192 .69859 L .54219 .69917 L F
0 0 .279 r
.54215 .69938 m .54273 .70072 L .54192 .69859 L F
.687 .353 0 r
.54192 .69859 m .54273 .70072 L .54175 .69822 L F
.54192 .69859 m .54175 .69822 L .54151 .69762 L F
.893 .868 .426 r
.54219 .69917 m .54192 .69859 L .54271 .69618 L F
0 .168 .706 r
.54464 .70366 m .54273 .70072 L .5431 .70188 L F
.649 .11 0 r
.54273 .70072 m .54349 .702 L .54303 .70136 L F
0 0 .279 r
.54243 .70011 m .5431 .70188 L .54273 .70072 L F
.649 .11 0 r
.54273 .70072 m .54303 .70136 L .54192 .69979 L F
0 0 .279 r
.54215 .69938 m .54243 .70011 L .54273 .70072 L F
.489 .345 .612 r
.40072 .74295 m .40277 .74011 L .40041 .74067 L F
.59 .437 .643 r
.54757 .69111 m .55029 .6874 L .55018 .68801 L F
.683 .967 .931 r
.55314 .68639 m .55018 .68801 L .55029 .6874 L F
.571 .451 .677 r
.39127 .76453 m .39354 .76438 L .39317 .76177 L F
.502 .391 .66 r
.39189 .76751 m .39354 .76438 L .39127 .76453 L F
0 .574 .736 r
.71504 .58281 m .71626 .58288 L .71577 .58248 L F
.433 0 0 r
.71577 .58248 m .71674 .58314 L .71544 .58223 L F
0 .574 .736 r
.71626 .58288 m .71838 .58298 L .71577 .58248 L F
.433 0 0 r
.71577 .58248 m .71544 .58223 L .71411 .58129 L F
.079 .595 .882 r
.71838 .58298 m .71985 .58366 L .71674 .58314 L F
.972 .804 .616 r
.54673 .73517 m .54498 .73707 L .54322 .73543 L F
0 .46 .726 r
.57507 .71097 m .57372 .71062 L .57169 .71016 L F
.454 .058 .198 r
.57635 .71005 m .57372 .71062 L .57507 .71097 L F
.524 .065 .105 r
.535 .78691 m .53369 .78836 L .53141 .78821 L F
.62 .256 .33 r
.53725 .78658 m .53369 .78836 L .535 .78691 L F
.655 .749 .919 r
.50936 .70813 m .50593 .70743 L .5081 .70698 L F
.634 .795 .96 r
.51149 .70742 m .50936 .70813 L .5081 .70698 L F
.733 .595 .702 r
.53806 .77796 m .54154 .78053 L .5396 .77837 L F
.388 0 0 r
.45049 .72689 m .45243 .7275 L .4539 .72677 L F
.469 0 0 r
.45243 .7275 m .45605 .7265 L .4539 .72677 L F
0 0 .524 r
.72472 .73724 m .72555 .74064 L .72552 .73901 L F
.294 .457 .852 r
.72552 .73901 m .72555 .74064 L .72749 .74098 L F
.506 .465 .745 r
.73178 .73099 m .72959 .73265 L .72779 .72836 L F
.479 .116 .272 r
.72582 .72963 m .72914 .72949 L .72779 .72836 L F
.337 .465 .842 r
.73025 .72763 m .73178 .73099 L .72779 .72836 L F
.73025 .72763 m .72779 .72836 L .72914 .72949 L F
.551 .373 .593 r
.29637 .6829 m .29858 .67996 L .29655 .68048 L F
.272 0 0 r
.35203 .67545 m .35033 .67561 L .34819 .67517 L F
0 0 0 r
.35425 .67512 m .35033 .67561 L .35203 .67545 L F
.18 0 .126 r
.3253 .65657 m .32631 .65709 L .32738 .65609 L F
.3253 .65657 m .32455 .65802 L .32631 .65709 L F
.44 .178 .419 r
.58125 .66195 m .58335 .66107 L .58362 .65934 L F
.406 .149 .409 r
.58362 .65934 m .58335 .66107 L .58566 .65862 L F
.353 .651 .967 r
.37699 .65172 m .37902 .6519 L .37834 .65304 L F
.257 .527 .914 r
.37902 .6519 m .38034 .65354 L .37834 .65304 L F
.614 .214 .261 r
.60313 .64525 m .6021 .64699 L .60537 .64681 L F
.578 .253 .382 r
.60313 .64525 m .60537 .64681 L .60546 .64524 L F
.597 .257 .364 r
.387 .78444 m .38865 .78652 L .38997 .78366 L F
.634 .619 .818 r
.38997 .78366 m .39095 .7805 L .38959 .78114 L F
.38997 .78366 m .3925 .78376 L .39095 .7805 L F
.64 .397 .534 r
.38997 .78366 m .39276 .78635 L .3925 .78376 L F
.114 0 .119 r
.38997 .78366 m .39109 .78411 L .39276 .78635 L F
.38997 .78366 m .38865 .78652 L .39109 .78411 L F
.779 .375 .285 r
.58252 .75656 m .58159 .75807 L .58106 .75669 L F
.78 .375 .286 r
.58252 .75656 m .5846 .75888 L .58159 .75807 L F
.488 .331 .594 r
.32328 .69366 m .32192 .69164 L .32367 .69098 L F
.32328 .69366 m .32167 .69416 L .32192 .69164 L F
.621 .488 .678 r
.31633 .69645 m .31529 .69855 L .31429 .69686 L F
.411 .057 .25 r
.34814 .67589 m .34642 .67548 L .34819 .67517 L F
.34814 .67589 m .34598 .67664 L .34642 .67548 L F
0 .391 .786 r
.54641 .70764 m .54585 .70709 L .54577 .70671 L F
.54641 .70764 m .54915 .70878 L .54585 .70709 L F
.301 .093 .421 r
.29971 .62739 m .29821 .62549 L .29982 .62449 L F
.29971 .62739 m .2974 .6284 L .29821 .62549 L F
.952 .918 .741 r
.63784 .66149 m .63844 .65785 L .637 .6593 L F
.966 .905 .708 r
.63784 .66149 m .637 .6593 L .63614 .66206 L F
.536 .302 .508 r
.49048 .73109 m .48827 .73149 L .48844 .72937 L F
.568 .396 .608 r
.39856 .74569 m .4008 .74536 L .40072 .74295 L F
.524 .357 .597 r
.39872 .7482 m .4008 .74536 L .39856 .74569 L F
.416 0 .119 r
.71349 .71713 m .71199 .71569 L .7113 .71789 L F
.71349 .71713 m .71435 .71544 L .71199 .71569 L F
.528 .318 .539 r
.62947 .62349 m .63179 .62301 L .63179 .62073 L F
.483 .301 .557 r
.63393 .62028 m .63393 .61776 L .63179 .62073 L F
.475 .276 .53 r
.63179 .62301 m .63393 .62028 L .63179 .62073 L F
.63179 .62301 m .63393 .62028 L .63179 .62073 L F
.633 .442 .607 r
.59602 .72688 m .59496 .72948 L .59312 .72944 L F
.361 .33 .689 r
.59657 .72364 m .59751 .72658 L .59602 .72688 L F
.685 .634 .792 r
.59751 .72658 m .59817 .72956 L .59496 .72948 L F
.485 .793 .999 r
.59496 .72948 m .59676 .72937 L .59593 .72809 L F
.59676 .72937 m .5972 .72935 L .59593 .72809 L F
.833 .591 .574 r
.59817 .72956 m .5972 .72935 L .59496 .72948 L F
.505 .269 .49 r
.59544 .73371 m .5972 .72935 L .59586 .73156 L F
.579 .084 0 r
.59669 .72884 m .59755 .72993 L .59593 .72809 L F
0 0 0 r
.5972 .72935 m .59641 .73256 L .59755 .72993 L F
.885 .62 .533 r
.59755 .72993 m .59541 .72729 L .59593 .72809 L F
.59541 .72729 m .59525 .7271 L .59593 .72809 L F
.579 .084 0 r
.5972 .72935 m .59744 .72975 L .59669 .72884 L F
.59744 .72975 m .59755 .72993 L .59669 .72884 L F
.685 .634 .792 r
.59751 .72658 m .59612 .72816 L .59602 .72688 L F
.59612 .72816 m .59496 .72948 L .5957 .72765 L F
.59612 .72816 m .5957 .72765 L .59602 .72688 L F
.867 .711 .686 r
.57809 .73807 m .57768 .74029 L .57981 .73972 L F
.21 .289 .727 r
.57981 .73972 m .58044 .74087 L .57929 .73716 L F
.659 .112 0 r
.57768 .74029 m .58044 .74087 L .57981 .73972 L F
.621 .488 .678 r
.31633 .69645 m .31734 .69834 L .31529 .69855 L F
.619 .453 .635 r
.31734 .69834 m .31459 .70125 L .31529 .69855 L F
.66 .427 .557 r
.40277 .74011 m .40523 .74007 L .40559 .73767 L F
.361 .164 .473 r
.40559 .73767 m .40686 .73935 L .40703 .73703 L F
.40559 .73767 m .40523 .74007 L .40686 .73935 L F
.551 .326 .527 r
.30273 .67475 m .30529 .67194 L .3033 .67262 L F
.633 .464 .636 r
.68245 .57966 m .68463 .58003 L .68459 .57723 L F
.703 .454 .543 r
.45975 .74032 m .45938 .74239 L .45619 .74278 L F
.332 .12 .434 r
.46066 .74155 m .45975 .74032 L .46214 .74028 L F
.46066 .74155 m .45938 .74239 L .45975 .74032 L F
.571 .865 .996 r
.32965 .74043 m .32605 .74052 L .32817 .73973 L F
.32965 .74043 m .32605 .74052 L .32817 .73973 L F
.482 .143 .316 r
.48286 .73264 m .48272 .73403 L .48066 .73414 L F
.363 .049 .292 r
.48473 .73335 m .48286 .73264 L .48595 .73189 L F
.48473 .73335 m .48272 .73403 L .48286 .73264 L F
.338 .815 .89 r
.71446 .72357 m .71517 .72322 L .71334 .72365 L F
0 0 0 r
.71858 .721 m .71517 .72322 L .71446 .72357 L F
.898 .73 .665 r
.72411 .60388 m .72517 .6072 L .72357 .60586 L F
.632 .305 .4 r
.60329 .65859 m .6018 .661 L .59998 .66069 L F
.643 .318 .406 r
.60576 .66049 m .6018 .661 L .60329 .65859 L F
.633 .325 .432 r
.60527 .65904 m .60576 .66049 L .60329 .65859 L F
.105 0 0 r
.58868 .7212 m .58735 .72128 L .58516 .72119 L F
.468 .454 .76 r
.58966 .72201 m .58735 .72128 L .58868 .7212 L F
.094 .307 .785 r
.56414 .72882 m .5657 .7318 L .56631 .73039 L F
.976 .746 .524 r
.5657 .7318 m .56711 .7341 L .56631 .73039 L F
.5657 .7318 m .56416 .73367 L .56711 .7341 L F
.413 .172 .437 r
.28355 .64708 m .28526 .64693 L .28332 .64766 L F
.28355 .64708 m .28573 .64505 L .28526 .64693 L F
.165 0 .345 r
.61923 .69394 m .61876 .6963 L .61756 .69687 L F
.363 .215 .543 r
.61876 .6963 m .61725 .69912 L .61756 .69687 L F
.249 .717 .945 r
.29481 .60116 m .29628 .6017 L .29281 .60117 L F
.26 .723 .948 r
.29807 .6016 m .29628 .6017 L .29481 .60116 L F
.311 .509 .889 r
.2996 .60442 m .29628 .6017 L .29807 .6016 L F
0 0 0 r
.68363 .59427 m .68265 .59505 L .6818 .59491 L F
.096 .356 .824 r
.68265 .59505 m .68606 .59806 L .6851 .59749 L F
.851 .915 .876 r
.57076 .68741 m .57057 .68962 L .5723 .68821 L F
.57076 .68741 m .56937 .68882 L .57057 .68962 L F
.524 .557 .832 r
.30136 .72864 m .30262 .72628 L .3003 .72639 L F
.30136 .72864 m .3036 .72882 L .30262 .72628 L F
.558 .503 .749 r
.27719 .61798 m .2791 .61779 L .2784 .61467 L F
.315 0 .147 r
.3663 .71371 m .36532 .71512 L .36335 .71561 L F
.197 0 .072 r
.36804 .71299 m .36532 .71512 L .3663 .71371 L F
.525 .273 .475 r
.60621 .71001 m .60555 .71273 L .6034 .71292 L F
.592 .317 .469 r
.60846 .71024 m .60555 .71273 L .60621 .71001 L F
.306 0 .236 r
.33833 .68 m .33547 .68226 L .33622 .68046 L F
.574 .76 .966 r
.71869 .61997 m .71967 .62115 L .72183 .62064 L F
.734 .467 .524 r
.68009 .59843 m .67718 .59623 L .67714 .59864 L F
.587 .427 .632 r
.6276 .62886 m .63014 .62845 L .62976 .62591 L F
.633 .446 .612 r
.62763 .631 m .63014 .62845 L .6276 .62886 L F
.467 .658 .944 r
.72515 .62096 m .72786 .62094 L .7268 .6195 L F
.72515 .62096 m .7268 .6195 L .72438 .62219 L F
.454 .198 .435 r
.403 .68228 m .40142 .68079 L .40354 .68024 L F
.403 .68228 m .40097 .68276 L .40142 .68079 L F
.577 .414 .624 r
.2921 .68837 m .29419 .68568 L .29202 .68593 L F
.476 .123 .287 r
.69518 .57477 m .69245 .57462 L .69264 .57612 L F
.69518 .57477 m .69455 .57443 L .69245 .57462 L F
.463 .737 .987 r
.37 .64968 m .36932 .65099 L .36797 .64983 L F
.37 .64968 m .37145 .65081 L .36932 .65099 L F
.874 .742 .714 r
.57709 .6988 m .57906 .69947 L .57988 .69668 L F
.973 .716 .486 r
.63881 .65331 m .63756 .65019 L .6376 .65263 L F
.819 .55 .531 r
.6358 .65497 m .63881 .65331 L .6376 .65263 L F
.6358 .65497 m .63898 .65568 L .63881 .65331 L F
.204 0 0 r
.47129 .7813 m .47191 .78158 L .46942 .78191 L F
.47129 .7813 m .47343 .78171 L .47191 .78158 L F
.545 .891 .982 r
.72271 .73673 m .72236 .73787 L .72472 .73724 L F
.331 0 0 r
.67922 .5809 m .68172 .58071 L .68245 .57966 L F
.56 .075 .06 r
.68172 .58071 m .68463 .58003 L .68245 .57966 L F
.329 .77 .964 r
.4345 .77538 m .43343 .77609 L .43216 .77583 L F
.4345 .77538 m .43583 .77593 L .43343 .77609 L F
.652 .904 .981 r
.67534 .61041 m .67851 .60966 L .67605 .6096 L F
.756 .889 .938 r
.67605 .6096 m .67851 .60966 L .67854 .60897 L F
.349 0 .085 r
.3339 .68269 m .3326 .68432 L .33059 .6846 L F
.362 0 .124 r
.33547 .68226 m .3326 .68432 L .3339 .68269 L F
.542 .073 .091 r
.5136 .7851 m .51707 .78424 L .51496 .78493 L F
.88 .917 .847 r
.64209 .61764 m .64321 .61789 L .64571 .61492 L F
.96 .75 .575 r
.64209 .61764 m .64309 .62083 L .64321 .61789 L F
.452 .138 .343 r
.60361 .70146 m .60608 .69925 L .6037 .6994 L F
.777 .299 .097 r
.31547 .73775 m .3158 .739 L .31337 .73711 L F
.31547 .73775 m .31639 .73927 L .3158 .739 L F
.666 .207 .154 r
.70278 .71885 m .70657 .71919 L .70431 .71954 L F
0 0 .494 r
.325 .8242 m .3264 .82526 L .32786 .82526 L F
.325 .8242 m .32648 .82689 L .3264 .82526 L F
.486 .339 .606 r
.37706 .68575 m .37893 .68531 L .3788 .68293 L F
.477 .329 .601 r
.377 .68822 m .37893 .68531 L .37706 .68575 L F
.712 .976 .919 r
.50177 .71124 m .50269 .70981 L .50371 .71014 L F
.50177 .71124 m .50001 .71153 L .50269 .70981 L F
.396 .225 .529 r
.2974 .6284 m .29598 .63109 L .29615 .62876 L F
.602 .332 .48 r
.61979 .63671 m .62303 .63412 L .62083 .63402 L F
.497 .299 .542 r
.6034 .71292 m .60347 .7153 L .6008 .7153 L F
.481 .268 .513 r
.60347 .7153 m .60124 .71773 L .6008 .7153 L F
.747 .312 .217 r
.49921 .78032 m .50128 .78257 L .50245 .78117 L F
.583 .112 .103 r
.50245 .78117 m .50128 .78257 L .50499 .7825 L F
0 0 .088 r
.61243 .68859 m .61356 .68739 L .61416 .68527 L F
0 0 .012 r
.61243 .68859 m .61205 .69049 L .61356 .68739 L F
.512 .016 .016 r
.5304 .78173 m .53249 .78264 L .53379 .7815 L F
.54 .049 .037 r
.53379 .7815 m .53582 .78265 L .5359 .78111 L F
.53379 .7815 m .53249 .78264 L .53582 .78265 L F
0 0 0 r
.43576 .78624 m .4325 .78744 L .43108 .78781 L F
.324 0 0 r
.43635 .78673 m .43576 .78624 L .43791 .78624 L F
.43635 .78673 m .4325 .78744 L .43576 .78624 L F
.854 .923 .875 r
.60663 .74012 m .60412 .74277 L .60313 .74198 L F
.554 .382 .602 r
.60663 .74012 m .60705 .7426 L .60412 .74277 L F
.431 .214 .482 r
.60705 .7426 m .6045 .74507 L .60412 .74277 L F
.699 .572 .708 r
.41064 .65872 m .41401 .6614 L .41271 .65814 L F
.41064 .65872 m .41185 .66206 L .41401 .6614 L F
.893 .987 .735 r
.61799 .67495 m .61612 .67785 L .61596 .67667 L F
.748 .696 .154 r
.61553 .67986 m .61596 .67667 L .61612 .67785 L F
.461 .664 .95 r
.655 .60936 m .65735 .60963 L .65564 .60824 L F
.515 .805 .998 r
.55519 .72633 m .55864 .72681 L .55739 .72593 L F
.062 .286 .775 r
.56632 .73575 m .56711 .7341 L .56533 .73469 L F
.56632 .73575 m .56785 .7361 L .56711 .7341 L F
.56632 .73575 m .56815 .73747 L .56785 .7361 L F
.325 .101 .412 r
.30332 .61812 m .30218 .62238 L .30004 .62296 L F
.375 .199 .51 r
.3046 .61745 m .30332 .61812 L .303 .61798 L F
.3046 .61745 m .30461 .61982 L .30332 .61812 L F
.434 .193 .448 r
.30461 .61982 m .30218 .62238 L .30332 .61812 L F
.599 .657 .878 r
.53629 .72005 m .53486 .72206 L .53415 .72029 L F
.53629 .72005 m .53838 .72285 L .53486 .72206 L F
0 .004 .581 r
.57282 .72101 m .57288 .72117 L .57226 .71906 L F
.57282 .72101 m .57304 .72218 L .57288 .72117 L F
.421 .143 .383 r
.36356 .70234 m .363 .7042 L .36548 .70184 L F
.684 .714 .872 r
.32116 .7061 m .32221 .70767 L .3188 .70704 L F
.549 .671 .918 r
.32299 .70582 m .32221 .70767 L .32116 .7061 L F
.32299 .70582 m .32424 .70735 L .32221 .70767 L F
.502 .391 .66 r
.39189 .76751 m .39379 .76713 L .39354 .76438 L F
.525 .419 .677 r
.39221 .76992 m .39379 .76713 L .39189 .76751 L F
.619 .413 .58 r
.31979 .69654 m .31734 .69834 L .31633 .69645 L F
.239 0 0 r
.45605 .7265 m .45822 .72642 L .45953 .72586 L F
.532 .012 0 r
.45953 .72586 m .45822 .72642 L .46157 .72645 L F
.692 .696 .849 r
.56894 .70511 m .57086 .70546 L .56954 .70233 L F
.724 .362 .363 r
.56894 .70511 m .57024 .70666 L .57086 .70546 L F
.827 .757 .786 r
.56954 .70233 m .57086 .70546 L .57264 .70195 L F
.538 .4 .642 r
.57086 .70546 m .57303 .70506 L .57264 .70195 L F
.288 0 .074 r
.57024 .70666 m .57303 .70506 L .57086 .70546 L F
.489 .345 .612 r
.40072 .74295 m .40264 .74252 L .40277 .74011 L F
.472 .316 .587 r
.4008 .74536 m .40264 .74252 L .40072 .74295 L F
.578 .489 .718 r
.63214 .6257 m .62947 .62349 L .62976 .62591 L F
.63214 .6257 m .63179 .62301 L .62947 .62349 L F
.331 .376 .757 r
.73114 .73414 m .73048 .73473 L .72959 .73265 L F
0 0 .481 r
.73177 .73609 m .73048 .73473 L .73114 .73414 L F
.28 .491 .884 r
.27593 .6125 m .2764 .61167 L .27509 .61122 L F
.103 0 .396 r
.59234 .73733 m .59387 .73677 L .59398 .73448 L F
.986 .89 .559 r
.59362 .74003 m .59387 .73677 L .59268 .73803 L F
.59362 .74003 m .59306 .73892 L .59387 .73677 L F
.507 .352 .605 r
.59306 .73892 m .59452 .73609 L .59387 .73677 L F
.59452 .73609 m .59455 .73603 L .59387 .73677 L F
.986 .89 .559 r
.59268 .73803 m .59387 .73677 L .59234 .73733 L F
.59 .593 .824 r
.3972 .66198 m .39349 .65925 L .39511 .65875 L F
.559 .637 .885 r
.39853 .66003 m .3972 .66198 L .39511 .65875 L F
.573 .657 .894 r
.39904 .66154 m .3972 .66198 L .39853 .66003 L F
.556 .554 .807 r
.39998 .66303 m .3972 .66198 L .39904 .66154 L F
.987 .834 .605 r
.58058 .67938 m .58 .6824 L .58127 .68294 L F
.944 .748 .607 r
.58 .6824 m .58139 .68527 L .58127 .68294 L F
.95 .697 .52 r
.73128 .62299 m .73136 .62073 L .72981 .61981 L F
.6 .735 .939 r
.70661 .61377 m .70957 .6147 L .7083 .61351 L F
.645 .803 .959 r
.70957 .6147 m .71105 .61269 L .7083 .61351 L F
.70957 .6147 m .71176 .61394 L .71105 .61269 L F
.509 .178 .342 r
.59337 .75647 m .59265 .75892 L .59026 .75908 L F
.437 .113 .317 r
.59554 .75605 m .59265 .75892 L .59337 .75647 L F
.331 .376 .757 r
.73114 .73414 m .72959 .73265 L .73178 .73099 L F
.751 .803 .894 r
.69378 .59766 m .69493 .59896 L .69216 .59862 L F
.773 .391 .332 r
.69216 .59862 m .69493 .59896 L .69423 .59995 L F
.063 .444 .878 r
.69647 .59954 m .69493 .59896 L .69378 .59766 L F
.316 .395 .785 r
.69647 .59954 m .69727 .60052 L .69493 .59896 L F
.66 .251 .258 r
.69493 .59896 m .69727 .60052 L .69423 .59995 L F
.714 .558 0 r
.73184 .61248 m .73165 .60827 L .73347 .61145 L F
.914 .566 .366 r
.73086 .61373 m .73252 .61463 L .73184 .61248 L F
.73086 .61373 m .73184 .61248 L .73347 .61145 L F
.648 .226 .229 r
.50589 .79081 m .50616 .78993 L .50713 .78916 L F
.943 .647 .449 r
.50713 .78916 m .50737 .79145 L .50589 .79081 L F
.479 .561 .861 r
.30143 .60425 m .2996 .60442 L .29807 .6016 L F
0 0 .025 r
.66729 .6073 m .66753 .60794 L .66701 .60617 L F
.66729 .6073 m .66607 .60987 L .66753 .60794 L F
.379 .598 .932 r
.66607 .60987 m .66964 .61195 L .66812 .60969 L F
.311 .502 .883 r
.66812 .60969 m .66964 .61195 L .67112 .6114 L F
.333 .591 .939 r
.66964 .61195 m .67257 .61284 L .67112 .6114 L F
.096 0 0 r
.68463 .58003 m .68604 .58045 L .68684 .58016 L F
.329 0 0 r
.68604 .58045 m .68661 .58015 L .68684 .58016 L F
.68661 .58015 m .68933 .57874 L .68684 .58016 L F
.044 0 0 r
.68699 .58016 m .68684 .58016 L .68777 .58021 L F
.68463 .58003 m .68684 .58016 L .68699 .58016 L F
.598 .669 .889 r
.59312 .72944 m .59389 .72712 L .59191 .72814 L F
.59312 .72944 m .59496 .72948 L .59389 .72712 L F
.55 .378 .6 r
.71334 .72365 m .71163 .72586 L .71104 .7242 L F
0 0 0 r
.57886 .66413 m .58031 .66354 L .58125 .66195 L F
.299 0 .069 r
.57886 .66413 m .58005 .6653 L .58031 .66354 L F
.57886 .66413 m .57785 .66585 L .58005 .6653 L F
0 0 0 r
.33261 .73222 m .32905 .73383 L .33034 .73209 L F
.719 .519 .619 r
.35583 .83672 m .3529 .83538 L .35508 .835 L F
.35583 .83672 m .35291 .83832 L .3529 .83538 L F
.37 0 .136 r
.35513 .83802 m .35291 .83832 L .35583 .83672 L F
.521 .36 .603 r
.3529 .83538 m .35513 .83802 L .35508 .835 L F
.3529 .83538 m .35291 .83832 L .35513 .83802 L F
.171 .65 .928 r
.73258 .5846 m .7316 .58499 L .73072 .58403 L F
.73258 .5846 m .7336 .58514 L .7316 .58499 L F
.563 .224 .352 r
.42606 .73438 m .4283 .73444 L .42945 .73209 L F
.499 .158 .319 r
.42945 .73209 m .43133 .7333 L .43165 .73182 L F
.42945 .73209 m .4283 .73444 L .43133 .7333 L F
.026 0 0 r
.46961 .77281 m .46965 .77367 L .47133 .77231 L F
.46961 .77281 m .46762 .77435 L .46965 .77367 L F
.59 .527 .752 r
.59865 .73177 m .59918 .73525 L .59731 .73527 L F
.579 .439 .654 r
.59918 .73525 m .5976 .73776 L .59731 .73527 L F
.193 .714 .869 r
.42721 .78881 m .42672 .78865 L .42464 .78878 L F
.286 .777 .9 r
.42721 .78881 m .42757 .78852 L .42886 .78833 L F
.42721 .78881 m .42886 .78833 L .42672 .78865 L F
.888 .659 .586 r
.61844 .6668 m .61644 .66632 L .61672 .66368 L F
.874 .655 .603 r
.61843 .66902 m .61644 .66632 L .61844 .6668 L F
.2 .192 .624 r
.67254 .61505 m .67332 .6171 L .67472 .61576 L F
0 0 0 r
.66727 .60158 m .66491 .60432 L .66642 .6029 L F
.265 .322 .735 r
.66491 .60432 m .66701 .60617 L .66642 .6029 L F
.43 .73 .989 r
.39514 .65868 m .39511 .65875 L .39349 .65925 L F
.77 .688 .772 r
.65959 .60675 m .65735 .60963 L .66055 .6099 L F
.635 .516 .701 r
.31459 .70125 m .3154 .70451 L .31334 .70536 L F
.606 .341 .489 r
.52758 .72793 m .52398 .73127 L .52406 .72898 L F
.52826 .72773 m .52781 .7281 L .52758 .72793 L F
.52781 .7281 m .52398 .73127 L .52758 .72793 L F
.755 .296 .159 r
.53064 .72895 m .52979 .72957 L .52722 .7272 L F
.52979 .72957 m .52974 .72961 L .52938 .72926 L F
.52979 .72957 m .52938 .72926 L .52722 .7272 L F
.969 .683 .433 r
.53064 .72895 m .52956 .73082 L .52974 .72961 L F
.632 .296 .384 r
.53216 .73078 m .52956 .73082 L .53064 .72895 L F
.199 .313 .756 r
.53064 .72895 m .53249 .72941 L .53284 .72851 L F
.231 0 .302 r
.62147 .69116 m .62137 .69336 L .61923 .69394 L F
.24 .027 .376 r
.62089 .69529 m .61923 .69394 L .62137 .69336 L F
.62089 .69529 m .61876 .6963 L .61923 .69394 L F
.722 .624 .748 r
.57264 .70195 m .57612 .70263 L .57488 .69922 L F
0 0 0 r
.57303 .70506 m .57612 .70263 L .57264 .70195 L F
.57303 .70506 m .57493 .70409 L .57612 .70263 L F
.654 .588 .768 r
.57488 .69922 m .57612 .70263 L .57895 .7018 L F
.527 .097 .168 r
.57612 .70263 m .57907 .70295 L .57895 .7018 L F
.57612 .70263 m .57493 .70409 L .57907 .70295 L F
0 .369 .835 r
.32831 .82488 m .32786 .82526 L .3264 .82526 L F
.32831 .82488 m .33046 .82702 L .32786 .82526 L F
.516 .814 .999 r
.28803 .59915 m .28757 .6004 L .28614 .59938 L F
.28803 .59915 m .28984 .59993 L .28757 .6004 L F
.88 .917 .847 r
.64209 .61764 m .64571 .61492 L .64409 .61456 L F
.938 .904 .763 r
.64571 .61492 m .6462 .61202 L .64409 .61456 L F
.268 0 0 r
.47648 .77645 m .47565 .77572 L .47433 .7744 L F
.47648 .77645 m .47805 .77577 L .47565 .77572 L F
.623 .666 .87 r
.69937 .60976 m .70066 .61246 L .70299 .61185 L F
.741 .295 0 r
.50893 .79363 m .50885 .79403 L .50737 .79145 L F
.692 .189 0 r
.50893 .79363 m .51005 .79499 L .50885 .79403 L F
.395 .37 .713 r
.52722 .7272 m .52974 .72961 L .52826 .72773 L F
.564 .213 .333 r
.52722 .7272 m .52826 .72773 L .52406 .72898 L F
.387 0 0 r
.47578 .78184 m .47688 .7813 L .47976 .78212 L F
.714 .658 .793 r
.5926 .70445 m .59606 .70506 L .59655 .70369 L F
.637 .342 .454 r
.5931 .70703 m .59606 .70506 L .5926 .70445 L F
.5931 .70703 m .59619 .70726 L .59606 .70506 L F
.514 .439 .71 r
.59655 .70369 m .59606 .70506 L .59822 .7042 L F
.56 .361 .568 r
.59619 .70726 m .59822 .7042 L .59606 .70506 L F
.482 .529 .829 r
.40164 .66288 m .40097 .66573 L .39998 .66303 L F
.40164 .66288 m .40289 .66577 L .40097 .66573 L F
0 .181 .716 r
.73537 .58692 m .73555 .58826 L .7336 .58514 L F
0 0 .552 r
.73537 .58692 m .73552 .5891 L .73555 .58826 L F
.258 0 .265 r
.32287 .65879 m .32208 .66062 L .32455 .65802 L F
.614 .463 .653 r
.63014 .62845 m .63214 .6257 L .62976 .62591 L F
.801 .832 .875 r
.6798 .62307 m .6828 .62301 L .68172 .62207 L F
.866 .902 .856 r
.68172 .62207 m .6828 .62301 L .68514 .62034 L F
.496 .319 .571 r
.32527 .69035 m .32426 .68903 L .32607 .68812 L F
.32527 .69035 m .32367 .69098 L .32426 .68903 L F
.614 .405 .575 r
.63393 .62028 m .63622 .61957 L .63393 .61776 L F
.639 .396 .535 r
.63622 .61957 m .63645 .61779 L .63393 .61776 L F
.546 .752 .972 r
.51581 .70662 m .51478 .70815 L .51366 .70696 L F
.51581 .70662 m .51696 .70783 L .51478 .70815 L F
.808 .862 .888 r
.68833 .61301 m .68946 .6142 L .68897 .61227 L F
.89 .852 .799 r
.68622 .6162 m .68946 .6142 L .68833 .61301 L F
.68622 .6162 m .68723 .6174 L .68946 .6142 L F
.825 .87 .879 r
.68897 .61227 m .68946 .6142 L .69174 .61201 L F
.357 .056 .309 r
.40097 .68276 m .39843 .68515 L .39909 .68343 L F
0 0 0 r
.69518 .57477 m .69264 .57612 L .69146 .57785 L F
.683 .621 .78 r
.69886 .59333 m .70276 .59514 L .70114 .59331 L F
0 0 .023 r
.67401 .5852 m .67614 .58392 L .67674 .58215 L F
.092 .164 .647 r
.67401 .5852 m .67623 .58632 L .67614 .58392 L F
.375 .2 .511 r
.30218 .62238 m .29982 .62449 L .30004 .62296 L F
.345 0 .197 r
.30757 .61516 m .30672 .61705 L .3046 .61745 L F
.412 .263 .567 r
.30911 .61237 m .30921 .61462 L .30757 .61516 L F
.136 0 .058 r
.30921 .61462 m .30672 .61705 L .30757 .61516 L F
.532 .641 .902 r
.66753 .60794 m .66607 .60987 L .66812 .60969 L F
.604 .819 .982 r
.52052 .7082 m .51696 .70783 L .51916 .70767 L F
.232 0 0 r
.51916 .70767 m .52273 .70823 L .52052 .7082 L F
.614 .576 .787 r
.37841 .66915 m .37955 .67235 L .38175 .6719 L F
.476 .45 .75 r
.37955 .67235 m .38207 .67418 L .38175 .6719 L F
.208 .178 .603 r
.7166 .73107 m .71519 .72961 L .71719 .72893 L F
.7166 .73107 m .71626 .73227 L .71519 .72961 L F
.75 .964 .676 r
.40994 .79376 m .40918 .79532 L .41174 .79232 L F
.688 .976 .908 r
.412 .79132 m .41174 .79232 L .41351 .79107 L F
.77 .969 .681 r
.412 .79132 m .40994 .79376 L .41174 .79232 L F
0 0 0 r
.66968 .59233 m .67042 .59109 L .66801 .59325 L F
.081 .642 .732 r
.67132 .59097 m .67042 .59109 L .66968 .59233 L F
.67132 .59097 m .673 .59087 L .67042 .59109 L F
.596 .434 .633 r
.56768 .74291 m .56955 .74296 L .56929 .74022 L F
0 .162 .697 r
.56929 .74022 m .57002 .73957 L .56815 .73747 L F
.151 .107 .55 r
.56929 .74022 m .57131 .74144 L .57002 .73957 L F
.56929 .74022 m .56955 .74296 L .57131 .74144 L F
.444 .388 .701 r
.42268 .76923 m .42138 .77249 L .42059 .7706 L F
.42268 .76923 m .4231 .77235 L .42138 .77249 L F
.359 .135 .432 r
.6232 .69018 m .62147 .69116 L .62359 .68839 L F
.113 0 .274 r
.62268 .69238 m .62147 .69116 L .6232 .69018 L F
.62268 .69238 m .62137 .69336 L .62147 .69116 L F
.967 .881 .696 r
.61895 .67171 m .61703 .6742 L .61811 .67138 L F
.61895 .67171 m .61799 .67495 L .61703 .6742 L F
.727 .252 .119 r
.38527 .78459 m .38865 .78652 L .387 .78444 L F
.523 .32 .546 r
.39441 .75347 m .39648 .75317 L .39672 .75108 L F
.535 .433 .685 r
.39441 .75347 m .3969 .75633 L .39648 .75317 L F
.39441 .75347 m .39489 .75677 L .3969 .75633 L F
.683 .967 .931 r
.55314 .68639 m .55029 .6874 L .55105 .68678 L F
.754 .982 .91 r
.55314 .68639 m .55391 .68474 L .5543 .68472 L F
.55314 .68639 m .55105 .68678 L .55391 .68474 L F
.863 .659 .625 r
.64087 .63691 m .63972 .63391 L .63966 .6363 L F
.848 .694 .691 r
.64041 .63873 m .64087 .63691 L .63966 .6363 L F
.245 .564 .937 r
.5487 .72769 m .54796 .7287 L .54614 .72634 L F
.5487 .72769 m .54956 .72889 L .54796 .7287 L F
0 0 .225 r
.57376 .68337 m .57363 .68538 L .573 .686 L F
.649 .344 .442 r
.57757 .68513 m .57376 .68337 L .57723 .68275 L F
.57757 .68513 m .57363 .68538 L .57376 .68337 L F
.893 .987 .735 r
.61799 .67495 m .61596 .67667 L .61703 .6742 L F
.892 .681 .61 r
.57709 .6988 m .57895 .7018 L .57906 .69947 L F
0 .253 .697 r
.7366 .71578 m .73506 .71474 L .73661 .71547 L F
0 0 .302 r
.73661 .71547 m .73719 .71793 L .7366 .71578 L F
.49 .883 .715 r
.49396 .7161 m .49518 .7151 L .4957 .715 L F
.49396 .7161 m .49227 .71692 L .49518 .7151 L F
.196 0 0 r
.44098 .78569 m .4401 .7861 L .43791 .78624 L F
.281 0 0 r
.44355 .7853 m .4401 .7861 L .44098 .78569 L F
.19 0 0 r
.46157 .72645 m .46384 .72646 L .46492 .72613 L F
.114 .664 .704 r
.46384 .72646 m .46711 .72595 L .46492 .72613 L F
.377 .579 .92 r
.40831 .79364 m .40918 .79532 L .40994 .79376 L F
.40831 .79364 m .40918 .79532 L .40994 .79376 L F
.659 .112 0 r
.57768 .74029 m .58159 .74217 L .58044 .74087 L F
.95 .788 .646 r
.57076 .68741 m .5723 .68821 L .57133 .68523 L F
.613 .38 .539 r
.57363 .68538 m .57133 .68523 L .5723 .68821 L F
.691 .381 .446 r
.55376 .73657 m .55207 .7384 L .55204 .7382 L F
.991 .813 .434 r
.66666 .60069 m .66727 .60158 L .66642 .6029 L F
.62 .675 .88 r
.58683 .74449 m .58542 .74689 L .58443 .74494 L F
.58683 .74449 m .5886 .74738 L .58542 .74689 L F
.42 .686 .973 r
.49837 .72387 m .50101 .72399 L .49964 .72274 L F
.49837 .72387 m .50101 .72399 L .49964 .72274 L F
.832 .502 .431 r
.65921 .59754 m .66038 .59595 L .65851 .5956 L F
.712 .341 .345 r
.65921 .59754 m .66268 .598 L .66038 .59595 L F
.781 .374 .279 r
.66469 .59834 m .66038 .59595 L .66268 .598 L F
.381 .412 .769 r
.73857 .60704 m .73886 .60585 L .73754 .60318 L F
.464 .498 .808 r
.73886 .60585 m .73778 .60416 L .73857 .60704 L F
.73886 .60585 m .73778 .60416 L .73857 .60704 L F
.576 .611 .851 r
.73619 .60711 m .73886 .60585 L .73857 .60704 L F
.73857 .60704 m .73886 .60585 L .73619 .60711 L F
.794 .73 .793 r
.69136 .58734 m .68957 .59048 L .68934 .58799 L F
.727 .641 .763 r
.72101 .60341 m .72274 .60704 L .72411 .60388 L F
.997 .816 .464 r
.72274 .60704 m .72221 .60898 L .72357 .60586 L F
.981 .859 .644 r
.72284 .60753 m .7224 .60509 L .72357 .60586 L F
.729 .434 .48 r
.71883 .60858 m .72274 .60704 L .72219 .60633 L F
.779 .402 0 r
.72101 .60341 m .72196 .60583 L .72274 .60704 L F
.72196 .60583 m .72202 .60597 L .72215 .60618 L F
.72196 .60583 m .72215 .60618 L .72274 .60704 L F
.769 .841 .907 r
.71848 .60632 m .71883 .60858 L .72132 .60681 L F
0 0 .525 r
.71848 .60632 m .71909 .60785 L .71883 .60858 L F
.729 .434 .48 r
.71883 .60858 m .72219 .60633 L .72203 .6063 L F
.71883 .60858 m .72221 .60898 L .72274 .60704 L F
.736 .606 .713 r
.71883 .60858 m .71973 .61186 L .72221 .60898 L F
.847 .658 .647 r
.72075 .61043 m .71999 .61034 L .71933 .60725 L F
0 0 .525 r
.71909 .60785 m .71911 .60789 L .71914 .60799 L F
.71911 .60789 m .71914 .60798 L .71914 .60799 L F
.71909 .60785 m .71914 .60799 L .71883 .60858 L F
.727 .601 .716 r
.71643 .61135 m .71973 .61186 L .71883 .60858 L F
.847 .812 .816 r
.71584 .60872 m .71883 .60858 L .71914 .60798 L F
.748 .569 .652 r
.71438 .60752 m .7191 .60797 L .71848 .60632 L F
.847 .658 .647 r
.71911 .60789 m .71897 .60799 L .71907 .60778 L F
.71914 .60798 m .7191 .60798 L .71911 .60789 L F
.7191 .60798 m .71897 .60799 L .71911 .60789 L F
.71999 .61034 m .71907 .60778 L .71933 .60725 L F
0 0 .525 r
.71911 .60789 m .71914 .60798 L .71914 .60798 L F
.748 .569 .652 r
.7191 .60797 m .71914 .60798 L .71911 .60789 L F
.7191 .60797 m .71911 .60789 L .71848 .60632 L F
.847 .812 .816 r
.71912 .60798 m .71914 .60798 L .71914 .60798 L F
.71584 .60872 m .71914 .60798 L .71912 .60798 L F
.847 .658 .647 r
.71999 .61034 m .71795 .61008 L .71897 .60799 L F
.71999 .61034 m .71897 .60799 L .71914 .60798 L F
.847 .812 .816 r
.71584 .60872 m .71643 .61135 L .71883 .60858 L F
.653 .771 .935 r
.71438 .60752 m .71584 .60872 L .7191 .60799 L F
.71907 .60797 m .7191 .60799 L .71914 .60798 L F
.71438 .60752 m .7191 .60799 L .71907 .60797 L F
.877 .699 .658 r
.71735 .60697 m .71795 .61008 L .71674 .60689 L F
.71887 .60719 m .71869 .60775 L .71735 .60697 L F
.71869 .60775 m .71795 .61008 L .71735 .60697 L F
.71933 .60725 m .71907 .60778 L .71887 .60719 L F
.71907 .60778 m .71795 .61008 L .71887 .60719 L F
.748 .569 .652 r
.71438 .60752 m .71848 .60632 L .71655 .60458 L F
.87 .596 .519 r
.71933 .60725 m .71674 .60689 L .71665 .60585 L F
.7182 .60617 m .71665 .60585 L .71655 .60458 L F
.71933 .60725 m .71665 .60585 L .7182 .60617 L F
.769 .841 .907 r
.72036 .60661 m .72132 .60681 L .72138 .60677 L F
.71848 .60632 m .72132 .60681 L .72036 .60661 L F
.72093 .60626 m .72138 .60677 L .72212 .60624 L F
.71848 .60632 m .72138 .60677 L .72093 .60626 L F
.833 .642 .645 r
.72153 .60507 m .72065 .60594 L .72015 .60503 L F
.72087 .60617 m .72125 .60816 L .71933 .60725 L F
.482 .774 .996 r
.72243 .6031 m .72411 .60388 L .72327 .60292 L F
.72101 .60341 m .72388 .60385 L .72243 .6031 L F
.72388 .60385 m .72411 .60388 L .72243 .6031 L F
.518 .576 .854 r
.72101 .60341 m .72327 .60292 L .72142 .60138 L F
.917 .76 .671 r
.72128 .60316 m .72212 .60624 L .72101 .60341 L F
.72134 .6031 m .7221 .60615 L .72128 .60316 L F
.92 .704 .593 r
.7224 .60509 m .72186 .60507 L .72126 .60278 L F
.917 .76 .671 r
.72142 .60302 m .72192 .60532 L .72134 .6031 L F
.72192 .60532 m .7221 .60615 L .72134 .6031 L F
.518 .576 .854 r
.72101 .60341 m .72142 .60138 L .72003 .59997 L F
0 0 .529 r
.72005 .60003 m .72087 .60181 L .72065 .60215 L F
.78 .531 .56 r
.72086 .60182 m .72015 .60503 L .7181 .60397 L F
.72142 .60138 m .72109 .60234 L .72086 .60182 L F
0 0 .529 r
.72065 .60215 m .72101 .60215 L .72101 .60341 L F
.72087 .60181 m .72102 .60215 L .72065 .60215 L F
.78 .531 .56 r
.72109 .60234 m .72015 .60503 L .72086 .60182 L F
0 0 .529 r
.72101 .60215 m .72102 .60215 L .72102 .60219 L F
.72101 .60215 m .72102 .60219 L .72101 .60341 L F
.72007 .60006 m .72102 .60215 L .72005 .60003 L F
.768 .496 .522 r
.71687 .60223 m .71969 .60272 L .72003 .59997 L F
.78 .531 .56 r
.72086 .60182 m .71954 .60283 L .72087 .60181 L F
.774 .543 .585 r
.7181 .60397 m .71969 .60272 L .71687 .60223 L F
.78 .531 .56 r
.71954 .60283 m .71838 .60373 L .71969 .60272 L F
.71954 .60283 m .71969 .60272 L .72087 .60181 L F
.72086 .60182 m .7181 .60397 L .71838 .60373 L F
.92 .704 .593 r
.72119 .60263 m .72015 .60503 L .72107 .6024 L F
0 0 .529 r
.72102 .60215 m .72134 .6031 L .72101 .60341 L F
.92 .704 .593 r
.72124 .60281 m .72015 .60503 L .72119 .60263 L F
.72186 .60507 m .72015 .60503 L .72126 .60278 L F
.774 .543 .585 r
.7181 .60397 m .72142 .60302 L .71969 .60272 L F
.92 .704 .593 r
.72126 .60278 m .72124 .60281 L .72119 .60263 L F
.7224 .60509 m .72107 .6024 L .72179 .60277 L F
0 0 .529 r
.72102 .60215 m .72142 .60302 L .72134 .6031 L F
.768 .496 .522 r
.71969 .60272 m .72142 .60302 L .72087 .60181 L F
0 0 .529 r
.72003 .59997 m .72007 .60006 L .72005 .60003 L F
.768 .496 .522 r
.71969 .60272 m .72087 .60181 L .72003 .59997 L F
.78 .531 .56 r
.72087 .60181 m .71838 .60373 L .72116 .60135 L F
.72116 .60135 m .7181 .60397 L .72106 .60134 L F
.72142 .60138 m .72086 .60182 L .72116 .60135 L F
.768 .496 .522 r
.71687 .60223 m .72003 .59997 L .71891 .59912 L F
.589 .069 0 r
.72045 .60051 m .72106 .60134 L .71891 .59912 L F
.72142 .60138 m .72116 .60135 L .72045 .60051 L F
.72116 .60135 m .72106 .60134 L .72045 .60051 L F
.92 .704 .593 r
.72179 .60277 m .72107 .6024 L .72142 .60138 L F
.833 .642 .645 r
.72186 .60507 m .72179 .60552 L .72153 .60507 L F
.7224 .60509 m .72191 .60544 L .72186 .60507 L F
.72191 .60544 m .72179 .60552 L .72186 .60507 L F
.917 .76 .671 r
.7221 .60615 m .72212 .60624 L .72191 .60547 L F
.72191 .60544 m .72191 .60547 L .72128 .60316 L F
.7221 .60615 m .72191 .60547 L .72191 .60544 L F
.833 .642 .645 r
.72191 .60544 m .72198 .60621 L .72087 .60617 L F
.7224 .60509 m .72206 .606 L .72191 .60544 L F
.72206 .606 m .72198 .60621 L .72191 .60544 L F
.72198 .60621 m .72125 .60816 L .72087 .60617 L F
.769 .841 .907 r
.71848 .60632 m .72093 .60626 L .72087 .60617 L F
.71877 .6061 m .72087 .60617 L .72015 .60503 L F
.71848 .60632 m .72087 .60617 L .71877 .6061 L F
.833 .642 .645 r
.72179 .60552 m .72087 .60617 L .72153 .60507 L F
.72087 .60617 m .7207 .60589 L .72153 .60507 L F
.769 .841 .907 r
.72093 .60626 m .72212 .60624 L .72015 .60503 L F
.833 .642 .645 r
.72087 .60617 m .71933 .60725 L .7207 .60589 L F
.72065 .60594 m .71933 .60725 L .72006 .60528 L F
.72065 .60594 m .72006 .60528 L .72015 .60503 L F
.981 .859 .644 r
.72234 .60636 m .72219 .60633 L .7224 .60509 L F
.72219 .60633 m .72195 .60629 L .72204 .60606 L F
.779 .402 0 r
.72202 .60597 m .72208 .60614 L .72223 .60638 L F
.72208 .60614 m .72219 .60633 L .72223 .60638 L F
.981 .859 .644 r
.72219 .60633 m .72204 .60606 L .7224 .60509 L F
.779 .402 0 r
.72208 .60614 m .72212 .60624 L .72219 .60633 L F
.729 .434 .48 r
.72203 .6063 m .72219 .60633 L .72212 .60624 L F
.981 .859 .644 r
.72221 .60898 m .72125 .60816 L .72195 .60629 L F
.779 .402 0 r
.72202 .60597 m .72223 .60638 L .72274 .60704 L F
.981 .859 .644 r
.72221 .60898 m .72195 .60629 L .72234 .60636 L F
.72221 .60898 m .72233 .60657 L .72284 .60753 L F
.72233 .60657 m .7224 .60509 L .72284 .60753 L F
.54 .399 .639 r
.29858 .67996 m .30048 .67714 L .29851 .6776 L F
.264 0 .01 r
.68938 .59461 m .68816 .59385 L .68772 .59389 L F
.68938 .59461 m .69042 .59307 L .68816 .59385 L F
0 0 0 r
.59443 .66531 m .59314 .66578 L .59503 .66372 L F
.863 .819 .804 r
.66191 .60161 m .66469 .59834 L .66268 .598 L F
.443 .255 .53 r
.28748 .64442 m .28573 .64505 L .28768 .64221 L F
.398 .159 .431 r
.28526 .64693 m .28573 .64505 L .28748 .64442 L F
0 0 .415 r
.66801 .59325 m .66919 .59413 L .66968 .59233 L F
.66801 .59325 m .66819 .59565 L .66919 .59413 L F
.764 .637 .72 r
.70449 .58015 m .70648 .58292 L .70277 .58178 L F
.756 .597 .68 r
.70648 .58292 m .70257 .5848 L .70277 .58178 L F
.70648 .58292 m .70603 .58524 L .70257 .5848 L F
.581 .919 .703 r
.44741 .77339 m .44457 .77561 L .44539 .77464 L F
.533 .906 .956 r
.44539 .77464 m .44457 .77561 L .44331 .77541 L F
.558 .52 .77 r
.42268 .76923 m .42059 .7706 L .41971 .76733 L F
.692 .696 .849 r
.56894 .70511 m .56954 .70233 L .56754 .70436 L F
.768 .571 .631 r
.56754 .70436 m .57024 .70666 L .56894 .70511 L F
.241 0 0 r
.69701 .58479 m .69381 .58485 L .69481 .58464 L F
.541 .346 .567 r
.50418 .73768 m .50653 .73967 L .50661 .73707 L F
.50418 .73768 m .50653 .73967 L .50661 .73707 L F
.823 .973 .893 r
.52042 .79116 m .52019 .7925 L .52395 .78925 L F
.273 .062 .4 r
.62541 .68537 m .62576 .68787 L .62359 .68839 L F
.104 0 .225 r
.62763 .6823 m .62729 .68474 L .62541 .68537 L F
.147 0 .386 r
.62698 .6868 m .62541 .68537 L .62729 .68474 L F
.62698 .6868 m .62576 .68787 L .62541 .68537 L F
0 0 0 r
.72248 .71965 m .72098 .71977 L .72384 .71948 L F
.72248 .71965 m .72017 .7202 L .72098 .71977 L F
.313 0 .158 r
.58031 .66354 m .58335 .66107 L .58125 .66195 L F
.465 .183 .401 r
.39812 .68732 m .39656 .68583 L .39843 .68515 L F
.39812 .68732 m .39602 .68783 L .39656 .68583 L F
.3 0 0 r
.45132 .78401 m .44765 .78522 L .44911 .78411 L F
.165 0 .269 r
.62576 .68787 m .6232 .69018 L .62359 .68839 L F
.375 .291 .632 r
.37499 .69139 m .37675 .69279 L .37709 .69045 L F
.37499 .69139 m .37527 .69369 L .37675 .69279 L F
.658 .631 .811 r
.69265 .60328 m .68943 .6012 L .6918 .60061 L F
.64 .632 .826 r
.69546 .602 m .69265 .60328 L .6918 .60061 L F
.447 .204 .452 r
.33059 .6846 m .32797 .68742 L .32846 .68559 L F
.254 .452 .861 r
.55583 .71594 m .55687 .71492 L .55409 .71326 L F
.288 .507 .894 r
.55583 .71594 m .55911 .71771 L .55687 .71492 L F
.722 .37 .381 r
.30952 .73822 m .31128 .73974 L .30779 .73938 L F
.797 .748 .808 r
.31023 .73759 m .30952 .73822 L .30779 .73938 L F
.31023 .73759 m .31159 .73799 L .30952 .73822 L F
0 0 0 r
.4329 .74822 m .43163 .75006 L .43025 .75059 L F
.644 .252 .287 r
.43499 .74979 m .43163 .75006 L .4329 .74822 L F
.849 .992 .735 r
.69831 .58122 m .69788 .5829 L .69916 .58078 L F
.815 .885 .457 r
.69831 .58122 m .69701 .58479 L .69788 .5829 L F
.664 .111 0 r
.54322 .73543 m .54498 .73707 L .542 .73562 L F
.527 .166 .297 r
.43381 .73147 m .43618 .73137 L .4372 .7293 L F
.471 .1 .253 r
.43618 .73137 m .43944 .72911 L .4372 .7293 L F
.598 .615 .84 r
.35559 .83503 m .35583 .83672 L .35508 .835 L F
.997 .83 .48 r
.35559 .83503 m .35513 .83802 L .35583 .83672 L F
.361 0 .206 r
.60027 .64771 m .598 .64831 L .59744 .64955 L F
.465 .769 .996 r
.27328 .59784 m .2728 .59907 L .2713 .59815 L F
.27328 .59784 m .27481 .59883 L .2728 .59907 L F
0 0 0 r
.33848 .72958 m .33807 .72933 L .34014 .72894 L F
.33848 .72958 m .33639 .73067 L .33807 .72933 L F
.763 .731 .823 r
.60107 .7441 m .60224 .74571 L .59896 .74553 L F
.454 .32 .608 r
.6045 .74507 m .60334 .74787 L .60224 .74571 L F
.675 .36 .433 r
.60537 .64681 m .60861 .64488 L .60546 .64524 L F
.60537 .64681 m .60821 .64724 L .60861 .64488 L F
.702 .385 .438 r
.60821 .64724 m .61103 .64708 L .60861 .64488 L F
.642 .405 .544 r
.60861 .64488 m .61103 .64708 L .61111 .64486 L F
.489 .225 .44 r
.36335 .71561 m .36295 .71725 L .36112 .71759 L F
.201 0 .171 r
.36532 .71512 m .36295 .71725 L .36335 .71561 L F
.773 .877 .923 r
.30322 .73128 m .30472 .73203 L .30662 .72882 L F
.734 .679 .797 r
.70603 .58524 m .70302 .58694 L .70257 .5848 L F
.509 .752 .983 r
.71176 .61394 m .71521 .61476 L .71453 .61244 L F
.617 .606 .817 r
.71521 .61476 m .71643 .61135 L .71453 .61244 L F
.71521 .61476 m .71759 .61432 L .71643 .61135 L F
.533 .912 .757 r
.45387 .74382 m .45202 .74469 L .45162 .74517 L F
.452 0 0 r
.45202 .74469 m .45275 .74488 L .45181 .74479 L F
.45202 .74469 m .45059 .74467 L .45162 .74517 L F
.45202 .74469 m .45181 .74479 L .45059 .74467 L F
.533 .912 .757 r
.45439 .74351 m .45202 .74469 L .45387 .74382 L F
0 0 0 r
.45619 .74278 m .45202 .74469 L .45439 .74351 L F
.825 .734 .764 r
.63972 .63391 m .63855 .63055 L .63646 .63339 L F
.843 .64 .628 r
.63966 .6363 m .63972 .63391 L .63646 .63339 L F
.812 .728 .771 r
.63972 .63391 m .64009 .63174 L .63855 .63055 L F
.544 .368 .592 r
.39648 .75317 m .39869 .75055 L .39672 .75108 L F
.849 .588 .543 r
.72108 .73456 m .72004 .73086 L .72112 .73329 L F
.282 0 .264 r
.28768 .64221 m .29023 .63973 L .28931 .64162 L F
.267 0 .255 r
.28931 .64162 m .29023 .63973 L .29193 .63893 L F
.692 .153 0 r
.57805 .75053 m .57663 .75033 L .57434 .7484 L F
.88 .446 .085 r
.57869 .75304 m .57663 .75033 L .57805 .75053 L F
.095 0 0 r
.36022 .67285 m .35955 .67217 L .36158 .67166 L F
.36022 .67285 m .35801 .67364 L .35955 .67217 L F
.277 .498 .89 r
.3879 .65475 m .38716 .65607 L .38583 .65533 L F
.3879 .65475 m .39013 .65725 L .38716 .65607 L F
.691 .381 .446 r
.55376 .73657 m .55416 .73932 L .55207 .7384 L F
.531 .562 .832 r
.55596 .73494 m .55376 .73657 L .55387 .73476 L F
.55596 .73494 m .55689 .73724 L .55376 .73657 L F
.724 .508 .597 r
.55689 .73724 m .55416 .73932 L .55376 .73657 L F
0 .384 .844 r
.7321 .71259 m .73108 .71279 L .73013 .71198 L F
.7321 .71259 m .73375 .71428 L .73108 .71279 L F
.866 .902 .856 r
.68172 .62207 m .68514 .62034 L .68425 .61961 L F
.911 .942 .813 r
.68425 .61961 m .68514 .62034 L .68723 .6174 L F
.473 .143 .325 r
.41822 .73696 m .42133 .73436 L .4185 .73475 L F
.41822 .73696 m .42041 .73666 L .42133 .73436 L F
.389 .062 .286 r
.42133 .73436 m .42243 .73615 L .4237 .73415 L F
.42133 .73436 m .42041 .73666 L .42243 .73615 L F
0 0 .23 r
.73511 .7207 m .73476 .7227 L .73341 .72383 L F
.197 0 .278 r
.73484 .72505 m .73341 .72383 L .73476 .7227 L F
.73484 .72505 m .73269 .72611 L .73341 .72383 L F
.849 .588 .543 r
.72108 .73456 m .71808 .73146 L .72004 .73086 L F
.72108 .73456 m .71827 .73425 L .71808 .73146 L F
.845 .743 .751 r
.72108 .73456 m .71906 .73758 L .71827 .73425 L F
0 .038 .572 r
.3905 .65855 m .39127 .65735 L .39041 .65692 L F
.33 .589 .939 r
.39013 .65725 m .39127 .65735 L .3905 .65855 L F
.911 .942 .813 r
.68425 .61961 m .68723 .6174 L .68622 .6162 L F
.619 .453 .635 r
.31734 .69834 m .31775 .70254 L .31459 .70125 L F
.637 .518 .701 r
.31764 .70405 m .31459 .70125 L .31775 .70254 L F
.31764 .70405 m .3154 .70451 L .31459 .70125 L F
.442 .7 .975 r
.48214 .77444 m .48129 .77574 L .48002 .77528 L F
.603 .301 .43 r
.40703 .73703 m .40954 .73719 L .41254 .73447 L F
.754 .525 .585 r
.41254 .73447 m .41281 .73711 L .41287 .73467 L F
.41254 .73447 m .40954 .73719 L .41281 .73711 L F
.108 0 0 r
.70726 .73106 m .70583 .73097 L .70341 .73072 L F
.721 .201 0 r
.70726 .73106 m .70913 .73262 L .70583 .73097 L F
.177 .216 .664 r
.67615 .59495 m .67464 .59297 L .6755 .59254 L F
0 0 0 r
.39879 .79372 m .40036 .79277 L .40213 .79183 L F
.415 .563 .893 r
.36643 .64727 m .36603 .64957 L .36487 .64815 L F
.36643 .64727 m .36797 .64983 L .36603 .64957 L F
.603 .707 .917 r
.5383 .71994 m .53838 .72285 L .53629 .72005 L F
.5383 .71994 m .53856 .72161 L .53838 .72285 L F
.096 0 .445 r
.70049 .58975 m .69886 .59333 L .7011 .59196 L F
.507 .503 .787 r
.7011 .59196 m .69886 .59333 L .70114 .59331 L F
.697 .268 .225 r
.73617 .59562 m .73949 .596 L .73858 .5975 L F
0 0 .437 r
.73941 .5954 m .73949 .596 L .7382 .59297 L F
.85 .878 .44 r
.73858 .5975 m .73949 .596 L .73941 .5954 L F
.515 .301 .527 r
.32797 .68742 m .32527 .69035 L .32607 .68812 L F
.905 .497 .197 r
.57434 .7484 m .57306 .74782 L .57172 .74507 L F
.631 .073 0 r
.57663 .75033 m .57306 .74782 L .57434 .7484 L F
.789 .882 .914 r
.41529 .79087 m .41935 .79002 L .41681 .79007 L F
.41529 .79087 m .41526 .79205 L .41935 .79002 L F
0 0 0 r
.42118 .78889 m .41681 .79007 L .41935 .79002 L F
0 .262 .755 r
.52837 .71407 m .52717 .71379 L .52642 .71183 L F
.416 .5 .837 r
.39095 .7805 m .3925 .78376 L .39405 .78321 L F
.295 .151 .508 r
.3925 .78376 m .39276 .78635 L .39405 .78321 L F
.805 .426 .337 r
.58327 .72219 m .58204 .72327 L .58004 .72064 L F
.093 0 0 r
.58412 .7226 m .58327 .72219 L .58516 .72119 L F
.58412 .7226 m .58204 .72327 L .58327 .72219 L F
0 0 0 r
.44741 .77339 m .44697 .77375 L .44937 .7726 L F
.44741 .77339 m .44539 .77464 L .44697 .77375 L F
.854 .923 .875 r
.60663 .74012 m .60313 .74198 L .60554 .73999 L F
.12 .346 .811 r
.60554 .73999 m .60705 .7426 L .60663 .74012 L F
.574 .357 .549 r
.60608 .69925 m .60861 .699 L .60869 .69668 L F
.251 .035 .378 r
.60869 .69668 m .61015 .69594 L .6107 .69382 L F
.313 .149 .492 r
.60869 .69668 m .60861 .699 L .61015 .69594 L F
.294 0 .117 r
.32027 .66114 m .32102 .66251 L .32208 .66062 L F
.32027 .66114 m .31908 .66305 L .32102 .66251 L F
.619 .413 .58 r
.31979 .69654 m .31978 .69928 L .31734 .69834 L F
.624 .468 .65 r
.32167 .69416 m .32197 .69639 L .31979 .69654 L F
.586 .372 .558 r
.32197 .69639 m .31978 .69928 L .31979 .69654 L F
.59 .449 .657 r
.59897 .72043 m .59657 .72364 L .59689 .72116 L F
.625 .649 .854 r
.59667 .74616 m .59347 .74372 L .59558 .74264 L F
.605 .525 .738 r
.5979 .74241 m .59667 .74616 L .59558 .74264 L F
.5979 .74241 m .59896 .74553 L .59667 .74616 L F
.738 .576 0 r
.51056 .72897 m .51066 .73154 L .51051 .72899 L F
.337 .046 .315 r
.37545 .70711 m .37468 .70975 L .37293 .70926 L F
.352 .015 .245 r
.37397 .71128 m .37293 .70926 L .37468 .70975 L F
.37397 .71128 m .372 .71186 L .37293 .70926 L F
.827 .757 .786 r
.56954 .70233 m .57264 .70195 L .57157 .7013 L F
.973 .876 .678 r
.57305 .69792 m .57264 .70195 L .57488 .69922 L F
.57305 .69792 m .57157 .7013 L .57264 .70195 L F
.4 0 .13 r
.44636 .74526 m .44497 .74725 L .44281 .74752 L F
.445 .036 .169 r
.44842 .7452 m .44497 .74725 L .44636 .74526 L F
0 0 .095 r
.62992 .67985 m .6291 .68166 L .62763 .6823 L F
0 0 .182 r
.6291 .68166 m .62729 .68474 L .62763 .6823 L F
.546 .714 .95 r
.40213 .79183 m .40605 .79315 L .40423 .79171 L F
.351 .579 .927 r
.40605 .79315 m .40611 .79124 L .40423 .79171 L F
.40605 .79315 m .40831 .79364 L .40611 .79124 L F
.366 0 0 r
.73375 .71428 m .73661 .71547 L .73506 .71474 L F
.42 .117 .342 r
.37805 .70508 m .37733 .70667 L .37545 .70711 L F
.404 .101 .334 r
.37968 .7061 m .37805 .70508 L .38009 .70459 L F
.37968 .7061 m .37733 .70667 L .37805 .70508 L F
.626 .661 .864 r
.30485 .74617 m .30726 .74557 L .30438 .74538 L F
.968 .653 .275 r
.70142 .7174 m .70037 .71535 L .69974 .71813 L F
.76 .318 .202 r
.70209 .71961 m .70142 .7174 L .69974 .71813 L F
.70209 .71961 m .70278 .71885 L .70142 .7174 L F
.481 .7 .965 r
.3754 .65027 m .37495 .65186 L .37339 .65031 L F
.3754 .65027 m .37699 .65172 L .37495 .65186 L F
.525 .419 .677 r
.39221 .76992 m .39421 .76956 L .39379 .76713 L F
.517 .419 .683 r
.39221 .76992 m .39474 .77185 L .39421 .76956 L F
.39221 .76992 m .39263 .77309 L .39474 .77185 L F
.522 .535 .81 r
.38445 .78679 m .38527 .78459 L .38312 .7857 L F
.38445 .78679 m .38659 .78679 L .38527 .78459 L F
.528 .915 .926 r
.51253 .79557 m .51333 .79584 L .51638 .79466 L F
.848 .694 .691 r
.64041 .63873 m .63966 .6363 L .6378 .63899 L F
.867 .777 .76 r
.63864 .642 m .64041 .63873 L .6378 .63899 L F
.602 .332 .48 r
.61979 .63671 m .62303 .63605 L .62303 .63412 L F
.611 .463 .655 r
.6254 .63381 m .6252 .63124 L .62303 .63412 L F
.642 .411 .553 r
.62303 .63605 m .6254 .63381 L .62303 .63412 L F
.645 .253 .286 r
.48344 .77576 m .48548 .77726 L .48681 .77525 L F
.654 .263 .292 r
.48681 .77525 m .48904 .77694 L .48905 .77495 L F
.48681 .77525 m .48548 .77726 L .48904 .77694 L F
.392 .096 .339 r
.28526 .64693 m .28264 .64968 L .28332 .64766 L F
.296 0 0 r
.69929 .57578 m .69814 .57511 L .69703 .57552 L F
.69929 .57578 m .69998 .57473 L .69814 .57511 L F
.867 .968 .858 r
.50371 .71014 m .50509 .70728 L .50593 .70743 L F
.50371 .71014 m .50269 .70981 L .50509 .70728 L F
.779 .332 0 r
.52909 .71512 m .53094 .71767 L .52991 .71598 L F
.771 .656 .736 r
.56593 .6966 m .56386 .69927 L .56257 .69625 L F
.426 .797 .994 r
.56484 .69594 m .56819 .69632 L .56593 .6966 L F
.546 .39 .621 r
.41006 .67398 m .40797 .67645 L .40789 .67468 L F
.099 0 .205 r
.29446 .63405 m .29374 .63571 L .29238 .6368 L F
.348 .161 .479 r
.29374 .63571 m .29193 .63893 L .29238 .6368 L F
.739 .826 .919 r
.69842 .60192 m .69546 .602 L .69727 .60052 L F
.773 .784 .862 r
.70052 .60068 m .69842 .60192 L .69727 .60052 L F
.685 .493 .621 r
.69153 .59588 m .69216 .59862 L .68868 .59847 L F
.448 .468 .787 r
.69042 .59307 m .69491 .59663 L .69153 .59588 L F
.691 .97 .927 r
.69491 .59663 m .69216 .59862 L .69153 .59588 L F
.4 .219 .517 r
.28748 .64442 m .28768 .64221 L .28931 .64162 L F
.545 .891 .982 r
.72271 .73673 m .72472 .73724 L .72379 .7366 L F
0 0 .524 r
.72472 .73724 m .72552 .73901 L .72754 .73735 L F
.644 .573 .76 r
.39389 .79087 m .39702 .794 L .39707 .79187 L F
.508 0 0 r
.39389 .79087 m .39595 .79188 L .39707 .79187 L F
.39707 .79187 m .39595 .79188 L .39389 .79087 L F
.69 .979 .893 r
.39707 .79187 m .39595 .79188 L .39752 .79067 L F
.39707 .79187 m .39595 .79188 L .39752 .79067 L F
.002 0 0 r
.39879 .79372 m .39707 .79187 L .39929 .79149 L F
.71 .799 .92 r
.68735 .60232 m .6839 .60213 L .6863 .60119 L F
.759 .829 .906 r
.6863 .60119 m .68943 .6012 L .68735 .60232 L F
.541 .371 .6 r
.3788 .68293 m .38091 .68255 L .38086 .68014 L F
.483 .306 .564 r
.37893 .68531 m .38091 .68255 L .3788 .68293 L F
.184 .569 .937 r
.72987 .58298 m .72761 .5831 L .72719 .58152 L F
.72987 .58298 m .73072 .58403 L .72761 .5831 L F
.336 .178 .514 r
.73275 .60953 m .73165 .60827 L .73282 .60652 L F
.918 .541 .123 r
.73346 .60799 m .73275 .60953 L .73375 .60722 L F
.73249 .6106 m .73275 .60953 L .73346 .60799 L F
.041 .12 .62 r
.73347 .61145 m .73258 .60989 L .73275 .60953 L F
.73258 .60989 m .73165 .60827 L .73275 .60953 L F
.531 .398 .644 r
.34311 .84194 m .34506 .84329 L .34507 .8406 L F
.34311 .84194 m .34312 .84411 L .34506 .84329 L F
.717 .558 .672 r
.59044 .70481 m .59065 .70724 L .5926 .70445 L F
.641 .457 .618 r
.59065 .70724 m .5931 .70703 L .5926 .70445 L F
.023 0 .176 r
.58117 .70703 m .57946 .70953 L .5801 .70777 L F
.616 .457 .643 r
.31978 .69928 m .31775 .70254 L .31734 .69834 L F
.587 .62 .852 r
.41041 .66568 m .40975 .66896 L .40846 .66673 L F
.41041 .66568 m .41169 .66858 L .40975 .66896 L F
.548 .406 .64 r
.41169 .66858 m .41006 .67153 L .40975 .66896 L F
0 0 .154 r
.57748 .72844 m .57716 .73107 L .57643 .73195 L F
.194 .519 .917 r
.57716 .73107 m .57832 .73274 L .57643 .73195 L F
.471 .344 .625 r
.32328 .69366 m .32197 .69639 L .32167 .69416 L F
.524 .357 .597 r
.39872 .7482 m .40081 .74787 L .4008 .74536 L F
.475 .295 .557 r
.39872 .7482 m .40058 .7501 L .40081 .74787 L F
.39872 .7482 m .39869 .75055 L .40058 .7501 L F
.609 .597 .814 r
.3188 .70704 m .3154 .70451 L .31764 .70405 L F
.656 .598 .778 r
.32116 .7061 m .3188 .70704 L .31764 .70405 L F
.281 0 .045 r
.3483 .7243 m .34704 .72608 L .34539 .72579 L F
.019 0 0 r
.34874 .72518 m .3483 .7243 L .35011 .72363 L F
.34874 .72518 m .34704 .72608 L .3483 .7243 L F
.507 .11 .222 r
.71966 .71232 m .71893 .71305 L .72201 .71225 L F
.717 .715 .847 r
.58992 .74496 m .5886 .74738 L .58683 .74449 L F
.576 .403 .611 r
.32527 .69035 m .32328 .69366 L .32367 .69098 L F
0 0 .552 r
.73537 .58692 m .73628 .58881 L .73552 .5891 L F
0 .061 .625 r
.73628 .58881 m .73758 .59184 L .73552 .5891 L F
.691 .601 .75 r
.70775 .59823 m .70505 .59505 L .70727 .59654 L F
.052 0 .173 r
.3154 .66432 m .31615 .66515 L .31717 .66364 L F
.3154 .66432 m .31472 .66612 L .31615 .66515 L F
.514 .439 .71 r
.59655 .70369 m .59822 .7042 L .59833 .702 L F
.554 .342 .547 r
.59822 .7042 m .60063 .70383 L .59833 .702 L F
.644 .304 .38 r
.59833 .702 m .60063 .70383 L .60084 .70232 L F
.502 .407 .68 r
.39537 .75906 m .3969 .75633 L .39489 .75677 L F
0 .137 .662 r
.73661 .71547 m .73815 .71753 L .73719 .71793 L F
.573 .432 .652 r
.73815 .71753 m .73693 .71994 L .73719 .71793 L F
.542 .341 .557 r
.39109 .77815 m .39095 .7805 L .39324 .77784 L F
.212 .422 .849 r
.59496 .72948 m .59593 .72809 L .59389 .72712 L F
.54 .355 .58 r
.39317 .76177 m .39531 .76141 L .39537 .75906 L F
.531 .422 .675 r
.39317 .76177 m .39557 .76394 L .39531 .76141 L F
.39317 .76177 m .39354 .76438 L .39557 .76394 L F
.579 .439 .654 r
.59918 .73525 m .59984 .7372 L .5976 .73776 L F
.32 0 .19 r
.59277 .65256 m .59511 .65308 L .59561 .65058 L F
.194 0 .156 r
.59561 .65058 m .59683 .65173 L .59744 .64955 L F
.59561 .65058 m .59511 .65308 L .59683 .65173 L F
.583 .593 .828 r
.5462 .73781 m .54995 .74025 L .54937 .73967 L F
.862 .672 .643 r
.63896 .64738 m .63679 .64465 L .63662 .64704 L F
.842 .728 .738 r
.63756 .65019 m .63896 .64738 L .63662 .64704 L F
.707 .645 .785 r
.58233 .74648 m .58 .74823 L .57884 .74515 L F
0 0 .129 r
.56933 .70961 m .56905 .71141 L .56787 .71289 L F
.177 0 0 r
.57169 .71016 m .57052 .70989 L .56879 .70946 L F
.56876 .70945 m .56879 .70946 L .5686 .70941 L F
.57169 .71016 m .56879 .70946 L .56876 .70945 L F
0 0 .129 r
.56959 .70904 m .5686 .70941 L .57052 .70989 L F
.56959 .70904 m .56945 .70964 L .56933 .70961 L F
.56945 .70964 m .56905 .71141 L .56933 .70961 L F
.159 .596 .935 r
.57169 .71016 m .57264 .7097 L .57052 .70989 L F
.57169 .71016 m .57372 .71062 L .57264 .7097 L F
.372 .8 .969 r
.42548 .78902 m .42249 .78885 L .42326 .78883 L F
0 0 0 r
.42394 .78881 m .42326 .78883 L .42118 .78889 L F
.42213 .78883 m .42118 .78889 L .42326 .78883 L F
.372 .8 .969 r
.42249 .78885 m .42213 .78883 L .42326 .78883 L F
0 0 0 r
.42464 .78878 m .42326 .78883 L .42394 .78881 L F
.114 0 0 r
.42464 .78878 m .42548 .78902 L .42326 .78883 L F
.42464 .78878 m .42672 .78865 L .42548 .78902 L F
.745 .722 .83 r
.31128 .73974 m .31131 .74134 L .31478 .74007 L F
0 .554 .74 r
.31128 .73974 m .31285 .73984 L .31478 .74007 L F
.361 0 .151 r
.34369 .67723 m .34233 .67915 L .34041 .67942 L F
.346 0 .141 r
.34456 .67865 m .34369 .67723 L .34598 .67664 L F
.34456 .67865 m .34233 .67915 L .34369 .67723 L F
.081 .41 .861 r
.53856 .72161 m .54131 .72328 L .54064 .72386 L F
.592 .317 .469 r
.60846 .71024 m .60903 .71242 L .60555 .71273 L F
0 .135 .593 r
.61183 .7128 m .60846 .71024 L .61079 .7098 L F
.6109 .7121 m .61135 .7124 L .60846 .71024 L F
.61183 .7128 m .61135 .7124 L .6109 .7121 L F
.893 .989 .76 r
.61335 .70958 m .61183 .7128 L .61079 .7098 L F
.61335 .70958 m .61135 .7124 L .61183 .7128 L F
.517 .323 .556 r
.61172 .71204 m .61149 .71249 L .61135 .7124 L F
.97 .903 .548 r
.61183 .7128 m .61068 .71409 L .61135 .7124 L F
.61183 .7128 m .61068 .71409 L .61135 .7124 L F
.517 .323 .556 r
.61149 .71249 m .61068 .71409 L .61135 .7124 L F
.635 .343 .458 r
.60846 .71024 m .61135 .7124 L .60903 .71242 L F
.572 .389 .595 r
.61078 .70742 m .61079 .7098 L .60846 .71024 L F
.527 .315 .535 r
.60555 .71273 m .60347 .7153 L .6034 .71292 L F
.681 .289 .298 r
.47727 .73427 m .48066 .73414 L .47935 .73626 L F
.422 .003 .137 r
.48066 .73414 m .48155 .73589 L .47935 .73626 L F
.48066 .73414 m .48272 .73403 L .48155 .73589 L F
.339 0 .049 r
.35935 .71963 m .35823 .71896 L .36112 .71759 L F
.36 0 .115 r
.36247 .7182 m .36112 .71759 L .36295 .71725 L F
.36247 .7182 m .35935 .71963 L .36112 .71759 L F
.825 .87 .879 r
.68897 .61227 m .69174 .61201 L .69042 .61104 L F
.695 .842 .953 r
.69042 .61104 m .69174 .61201 L .69354 .61136 L F
.674 .853 .968 r
.69958 .5995 m .70052 .60068 L .69727 .60052 L F
.786 .892 .92 r
.70288 .59852 m .70052 .60068 L .69958 .5995 L F
.401 .058 .264 r
.67614 .58392 m .67922 .5809 L .67674 .58215 L F
.53 .789 .992 r
.28021 .59903 m .27841 .59947 L .27676 .59839 L F
.578 .753 .96 r
.5081 .70698 m .50593 .70743 L .50724 .70569 L F
.723 .985 .895 r
.50593 .70743 m .50509 .70728 L .50724 .70569 L F
.454 .32 .608 r
.6045 .74507 m .60498 .74808 L .60334 .74787 L F
.276 .122 .483 r
.60444 .74992 m .60334 .74787 L .60498 .74808 L F
.60444 .74992 m .60323 .75103 L .60334 .74787 L F
.431 .179 .429 r
.61332 .70493 m .6128 .70689 L .61078 .70742 L F
.549 .399 .63 r
.6128 .70689 m .61079 .7098 L .61078 .70742 L F
.387 .005 .187 r
.35971 .70667 m .363 .7042 L .36086 .70446 L F
.745 .224 0 r
.71325 .58076 m .71577 .58248 L .71411 .58129 L F
.477 .329 .601 r
.377 .68822 m .37892 .68793 L .37893 .68531 L F
.42 .235 .522 r
.377 .68822 m .37878 .6897 L .37892 .68793 L F
.377 .68822 m .37709 .69045 L .37878 .6897 L F
.542 .073 .091 r
.5136 .7851 m .51583 .7855 L .51707 .78424 L F
0 0 0 r
.51707 .78424 m .51776 .78428 L .51925 .7836 L F
.51707 .78424 m .51583 .7855 L .51776 .78428 L F
.842 .506 0 r
.63364 .66952 m .63345 .66849 L .63311 .66797 L F
.63288 .66772 m .63311 .66797 L .63275 .66742 L F
0 0 .189 r
.63335 .66922 m .63345 .66849 L .63364 .66952 L F
.842 .506 0 r
.63364 .66952 m .63311 .66797 L .63288 .66772 L F
.808 .961 .635 r
.63508 .66603 m .63369 .6686 L .63557 .66642 L F
.63369 .6686 m .63335 .66922 L .63377 .66869 L F
.63369 .6686 m .63377 .66869 L .63557 .66642 L F
.63508 .66603 m .63345 .66849 L .63335 .66922 L F
0 0 .189 r
.63335 .66922 m .63364 .66952 L .63334 .67154 L F
.823 .596 .594 r
.61672 .66368 m .61417 .66579 L .6138 .66358 L F
.61672 .66368 m .61644 .66632 L .61417 .66579 L F
.25 .017 .351 r
.61483 .70411 m .6128 .70689 L .61332 .70493 L F
.55 .378 .6 r
.71334 .72365 m .71388 .72723 L .71163 .72586 L F
.349 .425 .798 r
.71388 .72723 m .71353 .72763 L .71163 .72586 L F
.52 .679 .938 r
.72704 .72762 m .72582 .72963 L .72488 .72854 L F
.72704 .72762 m .72914 .72949 L .72582 .72963 L F
.003 0 0 r
.73066 .59556 m .73396 .59495 L .73291 .59529 L F
.596 .094 .03 r
.73396 .59495 m .73617 .59562 L .73291 .59529 L F
.56 .075 .06 r
.68172 .58071 m .68392 .58136 L .68463 .58003 L F
.096 0 0 r
.68463 .58003 m .68392 .58136 L .68604 .58045 L F
.51 .222 .412 r
.57851 .7179 m .58067 .71757 L .58161 .71508 L F
.643 .357 .47 r
.58161 .71508 m .58299 .71747 L .58388 .71521 L F
.58161 .71508 m .58067 .71757 L .58299 .71747 L F
.313 .154 .499 r
.29598 .63109 m .29571 .63314 L .29446 .63405 L F
.36 .135 .431 r
.29571 .63314 m .29374 .63571 L .29446 .63405 L F
.739 .513 .586 r
.69659 .71489 m .70027 .71283 L .69682 .7126 L F
.69659 .71489 m .70037 .71535 L .70027 .71283 L F
.428 0 0 r
.47509 .72429 m .47678 .72492 L .47835 .72391 L F
0 0 0 r
.47835 .72391 m .47883 .72423 L .48049 .72343 L F
.47835 .72391 m .47678 .72492 L .47883 .72423 L F
.567 .378 .585 r
.60134 .72005 m .59877 .7182 L .60124 .71773 L F
.60134 .72005 m .59897 .72043 L .59877 .7182 L F
.644 .573 .76 r
.39389 .79087 m .39474 .79493 L .39702 .794 L F
.666 .207 .154 r
.70278 .71885 m .70571 .72036 L .70657 .71919 L F
.349 0 0 r
.70657 .71919 m .70571 .72036 L .70842 .71953 L F
.362 0 .069 r
.70842 .71953 m .7093 .71883 L .70657 .71919 L F
.258 0 0 r
.48827 .73149 m .48473 .73335 L .48595 .73189 L F
0 0 0 r
.59776 .66117 m .59689 .66295 L .59503 .66372 L F
.59689 .66295 m .59443 .66531 L .59503 .66372 L F
.482 .26 .5 r
.3918 .69103 m .39155 .6932 L .38952 .69363 L F
.505 .31 .55 r
.39398 .68831 m .39383 .69059 L .3918 .69103 L F
.498 .278 .51 r
.39383 .69059 m .39155 .6932 L .3918 .69103 L F
.412 .264 .569 r
.41281 .73711 m .41491 .73655 L .41287 .73467 L F
.827 .513 .458 r
.60894 .66326 m .60576 .66049 L .60882 .6613 L F
.717 .432 .493 r
.61258 .66311 m .60882 .6613 L .61269 .66126 L F
.61258 .66311 m .60894 .66326 L .60882 .6613 L F
.521 .536 .812 r
.42517 .772 m .42443 .77534 L .4231 .77235 L F
.42517 .772 m .42645 .77535 L .42443 .77534 L F
.276 .082 .427 r
.3103 .66652 m .31129 .66801 L .31279 .66672 L F
.3103 .66652 m .30973 .6688 L .31129 .66801 L F
.577 .414 .624 r
.2921 .68837 m .29411 .68787 L .29419 .68568 L F
.537 .381 .617 r
.2923 .69089 m .29411 .68787 L .2921 .68837 L F
.461 0 .041 r
.46928 .72577 m .47147 .72591 L .47302 .72462 L F
.311 0 0 r
.47302 .72462 m .47466 .72489 L .47509 .72429 L F
.47302 .72462 m .47147 .72591 L .47466 .72489 L F
.71 .552 .672 r
.63622 .61957 m .63835 .61711 L .63645 .61779 L F
.438 .137 .355 r
.37664 .70933 m .37545 .70711 L .37733 .70667 L F
.37664 .70933 m .37468 .70975 L .37545 .70711 L F
.856 .977 .673 r
.5677 .68132 m .56698 .68271 L .56862 .68055 L F
.56747 .6815 m .56735 .6818 L .5677 .68132 L F
.56735 .6818 m .56698 .68271 L .5677 .68132 L F
.666 .432 .556 r
.56698 .68271 m .56954 .68271 L .56862 .68055 L F
.721 .54 .645 r
.56698 .68271 m .56584 .68558 L .56764 .68537 L F
.734 .548 .641 r
.56698 .68271 m .57018 .68426 L .56954 .68271 L F
.56698 .68271 m .57133 .68523 L .57018 .68426 L F
.56698 .68271 m .56764 .68537 L .57133 .68523 L F
.566 .123 .157 r
.56815 .68637 m .57133 .68523 L .56764 .68537 L F
.583 .178 .241 r
.56584 .68558 m .56713 .68603 L .56764 .68537 L F
.56713 .68603 m .56815 .68637 L .56792 .68593 L F
.56713 .68603 m .56792 .68593 L .56764 .68537 L F
.852 .696 .689 r
.56695 .68233 m .56698 .68271 L .56701 .68228 L F
.503 .262 .481 r
.56696 .68235 m .56695 .68233 L .56696 .68234 L F
.56696 .68235 m .56695 .68236 L .56695 .68233 L F
.852 .696 .689 r
.56467 .68399 m .56542 .68357 L .56695 .68233 L F
.56467 .68399 m .56584 .68558 L .56698 .68271 L F
.121 .672 .761 r
.56575 .6866 m .56815 .68637 L .56584 .68558 L F
.092 0 .376 r
.56695 .68233 m .56683 .68643 L .56575 .6866 L F
.852 .696 .689 r
.56542 .68357 m .56639 .68304 L .56695 .68233 L F
.56639 .68304 m .56698 .68271 L .56695 .68233 L F
.56639 .68304 m .56695 .68233 L .56695 .68233 L F
.092 0 .376 r
.56695 .68233 m .56695 .68233 L .56467 .68399 L F
.788 .994 .875 r
.56695 .68233 m .56467 .68399 L .56704 .68186 L F
.852 .696 .689 r
.56467 .68399 m .56701 .68228 L .56704 .68186 L F
.669 .66 .832 r
.56239 .68489 m .56584 .68558 L .56467 .68399 L F
.663 .482 .629 r
.56239 .68489 m .56575 .6866 L .56584 .68558 L F
.092 0 .376 r
.56695 .68233 m .56587 .68618 L .56467 .68399 L F
.56587 .68618 m .56575 .6866 L .56559 .68621 L F
.56587 .68618 m .56559 .68621 L .56467 .68399 L F
.503 .262 .481 r
.56905 .68585 m .56683 .68643 L .56695 .68236 L F
.56905 .68585 m .56695 .68236 L .56696 .68235 L F
.56905 .68585 m .56696 .68235 L .56844 .68405 L F
.56696 .68235 m .56696 .68234 L .56844 .68405 L F
.856 .977 .673 r
.56704 .68186 m .56701 .68226 L .56747 .6815 L F
.56701 .68226 m .56698 .68271 L .56747 .6815 L F
.865 .511 .378 r
.56862 .68055 m .56954 .68271 L .56704 .68186 L F
.433 .319 .624 r
.57014 .67975 m .56954 .68271 L .56862 .68055 L F
.57014 .67975 m .56954 .68271 L .56862 .68055 L F
0 0 .168 r
.61439 .68305 m .61416 .68527 L .6148 .68231 L F
.863 .819 .804 r
.66191 .60161 m .66268 .598 L .6608 .60091 L F
.95 .805 .666 r
.6608 .60091 m .66156 .60391 L .66191 .60161 L F
.452 .138 .343 r
.60361 .70146 m .6056 .70105 L .60608 .69925 L F
.464 .565 .873 r
.6056 .70105 m .60718 .70099 L .60608 .69925 L F
.494 .135 .285 r
.60608 .69925 m .60718 .70099 L .60861 .699 L F
.323 0 0 r
.45448 .78301 m .4536 .7838 L .45132 .78401 L F
.257 0 0 r
.45504 .78409 m .45448 .78301 L .45676 .78281 L F
.45504 .78409 m .4536 .7838 L .45448 .78301 L F
.747 .333 .266 r
.57007 .71482 m .57191 .71704 L .57303 .71556 L F
.985 .735 .47 r
.57191 .71704 m .57304 .71801 L .57303 .71556 L F
.316 .288 .668 r
.31059 .61106 m .30911 .61237 L .30882 .60911 L F
.356 .269 .618 r
.31059 .61106 m .30921 .61462 L .30911 .61237 L F
.794 .73 .793 r
.69136 .58734 m .69264 .5904 L .68957 .59048 L F
.618 .758 .945 r
.69042 .59307 m .68957 .59048 L .69264 .5904 L F
.616 .427 .603 r
.69264 .5904 m .69319 .59268 L .69042 .59307 L F
.57 .612 .855 r
.6939 .58709 m .69264 .5904 L .69136 .58734 L F
.6939 .58709 m .69511 .59052 L .69264 .5904 L F
.39 .284 .612 r
.69462 .59147 m .69264 .5904 L .69511 .59052 L F
.69462 .59147 m .69319 .59268 L .69264 .5904 L F
.437 .738 .991 r
.514 .73135 m .51554 .73034 L .51305 .73029 L F
.514 .73135 m .51623 .73131 L .51554 .73034 L F
.402 .59 .919 r
.56031 .72099 m .55993 .71765 L .55911 .71771 L F
.56031 .72099 m .56124 .71932 L .55993 .71765 L F
.56031 .72099 m .56141 .72046 L .56124 .71932 L F
.257 .359 .777 r
.56031 .72099 m .56219 .72349 L .56141 .72046 L F
.863 .88 .848 r
.72482 .58184 m .72253 .5846 L .722 .58318 L F
.315 0 .118 r
.59885 .66247 m .59776 .66117 L .59998 .66069 L F
.59885 .66247 m .59689 .66295 L .59776 .66117 L F
.694 .752 .896 r
.54937 .73967 m .54995 .74025 L .55207 .7384 L F
.027 0 0 r
.52701 .78218 m .5291 .78202 L .5304 .78173 L F
0 .384 .819 r
.53161 .78176 m .5304 .78173 L .5291 .78202 L F
.53161 .78176 m .53249 .78264 L .5304 .78173 L F
.381 .677 .975 r
.30591 .60442 m .30535 .60564 L .30382 .60445 L F
.30591 .60442 m .30733 .60576 L .30535 .60564 L F
.774 .675 .754 r
.63978 .62029 m .64309 .62083 L .64209 .61764 L F
.778 .66 .732 r
.64138 .62362 m .64309 .62083 L .63978 .62029 L F
.823 .973 .893 r
.52042 .79116 m .52395 .78925 L .52201 .79059 L F
.196 0 0 r
.52636 .78882 m .52395 .78925 L .52595 .78888 L F
.52636 .78882 m .52201 .79059 L .52395 .78925 L F
.502 .407 .68 r
.39537 .75906 m .39725 .7586 L .3969 .75633 L F
.516 .357 .604 r
.39531 .76141 m .39725 .7586 L .39537 .75906 L F
.339 0 .049 r
.35935 .71963 m .35751 .71997 L .35823 .71896 L F
.428 .188 .445 r
.38952 .69363 m .38914 .69614 L .38714 .69639 L F
.467 .221 .457 r
.39155 .6932 m .38914 .69614 L .38952 .69363 L F
.511 .372 .628 r
.27781 .62309 m .27983 .62256 L .27962 .62012 L F
.368 .188 .501 r
.27786 .62551 m .27983 .62256 L .27781 .62309 L F
.182 0 0 r
.37138 .67054 m .36845 .67123 L .3693 .67143 L F
0 .488 .732 r
.37024 .67166 m .3693 .67143 L .36755 .67112 L F
.241 0 0 r
.36755 .67112 m .3693 .67143 L .36573 .67112 L F
.182 0 0 r
.36845 .67123 m .36788 .67136 L .3693 .67143 L F
0 .488 .732 r
.37057 .67172 m .3693 .67143 L .37024 .67166 L F
.6 .92 .973 r
.37138 .67054 m .37057 .67172 L .37261 .67098 L F
.37138 .67054 m .3693 .67143 L .37057 .67172 L F
.883 .784 .747 r
.63864 .642 m .6378 .63899 L .63691 .64125 L F
.888 .777 .733 r
.63679 .64465 m .63864 .642 L .63691 .64125 L F
.608 .432 .619 r
.6254 .63381 m .62763 .631 L .6252 .63124 L F
.359 .122 .412 r
.38483 .69924 m .38459 .70154 L .38273 .70176 L F
.371 .055 .292 r
.38392 .70334 m .38273 .70176 L .38459 .70154 L F
.38392 .70334 m .38198 .70388 L .38273 .70176 L F
.469 .794 .999 r
.34838 .70906 m .34781 .7102 L .34651 .7089 L F
.34838 .70906 m .34989 .70992 L .34781 .7102 L F
.769 .534 .578 r
.61269 .66126 m .6138 .66358 L .61258 .66311 L F
.507 .185 .355 r
.43025 .75059 m .42946 .75285 L .42729 .75303 L F
.599 .275 .392 r
.43176 .7526 m .43025 .75059 L .43163 .75006 L F
.43176 .7526 m .42946 .75285 L .43025 .75059 L F
.006 0 .042 r
.56886 .67191 m .57044 .67142 L .57118 .66944 L F
0 0 0 r
.56886 .67191 m .56757 .67325 L .57044 .67142 L F
.833 .591 .574 r
.59817 .72956 m .59865 .73177 L .5972 .72935 L F
.567 .555 .8 r
.60021 .72798 m .59817 .72956 L .59751 .72658 L F
.52 .423 .685 r
.60021 .72798 m .59865 .73177 L .59817 .72956 L F
.499 .284 .518 r
.63861 .61546 m .64069 .61452 L .64119 .61228 L F
.436 0 .066 r
.64352 .61193 m .64119 .61228 L .6428 .61148 L F
.718 .64 .77 r
.64069 .61452 m .6428 .61148 L .64119 .61228 L F
.537 .646 .904 r
.70525 .61161 m .70661 .61377 L .7083 .61351 L F
.591 .424 .623 r
.38086 .68014 m .38309 .67984 L .38308 .67738 L F
.563 .375 .584 r
.38091 .68255 m .38309 .67984 L .38086 .68014 L F
.654 .588 .768 r
.57488 .69922 m .57895 .7018 L .57709 .6988 L F
0 0 .168 r
.68006 .60021 m .67928 .6008 L .68009 .59843 L F
.68006 .60021 m .68009 .59843 L .67714 .59864 L F
.328 .714 .982 r
.68061 .5998 m .68006 .60021 L .67863 .59946 L F
.68175 .6 m .68006 .60021 L .68061 .5998 L F
0 0 .168 r
.68006 .60021 m .67906 .60143 L .67928 .6008 L F
.505 .854 .993 r
.45162 .74517 m .45059 .74467 L .44842 .7452 L F
.683 .556 .705 r
.58833 .70769 m .58847 .71008 L .59065 .70724 L F
.432 .465 .794 r
.55267 .72912 m .55088 .7318 L .54956 .72889 L F
.55267 .72912 m .55273 .73188 L .55088 .7318 L F
.793 .852 .895 r
.45796 .76646 m .45716 .76771 L .45513 .76687 L F
.391 0 0 r
.45513 .76687 m .45796 .76646 L .45716 .76771 L F
.815 .667 .699 r
.68868 .59847 m .68943 .6012 L .6863 .60119 L F
.683 .591 .746 r
.69216 .59862 m .68943 .6012 L .68868 .59847 L F
.607 .467 .665 r
.69216 .59862 m .6918 .60061 L .68943 .6012 L F
.318 .505 .883 r
.57692 .72561 m .57587 .7263 L .57398 .72371 L F
.189 .24 .685 r
.57692 .72561 m .57748 .72844 L .57587 .7263 L F
.142 0 .206 r
.61716 .7013 m .61483 .70411 L .61529 .70209 L F
.306 0 .236 r
.33833 .68 m .33723 .68238 L .33547 .68226 L F
.502 .199 .384 r
.34041 .67942 m .33723 .68238 L .33833 .68 L F
.428 .214 .484 r
.39602 .68783 m .39383 .69059 L .39398 .68831 L F
.284 0 0 r
.34704 .72608 m .34418 .72727 L .34539 .72579 L F
.705 .802 .334 r
.6107 .69382 m .61115 .69249 L .61205 .69049 L F
.068 .052 .529 r
.61015 .69594 m .61115 .69249 L .6107 .69382 L F
.362 0 .124 r
.33547 .68226 m .33469 .68399 L .3326 .68432 L F
.487 .156 .331 r
.33723 .68238 m .33469 .68399 L .33547 .68226 L F
.558 .369 .581 r
.5863 .71282 m .58853 .71249 L .58847 .71008 L F
.621 .47 .656 r
.58847 .71008 m .5911 .70989 L .59065 .70724 L F
.6 .402 .585 r
.58847 .71008 m .59074 .71215 L .5911 .70989 L F
.58847 .71008 m .58853 .71249 L .59074 .71215 L F
.905 .789 .723 r
.66019 .60273 m .66156 .60391 L .6608 .60091 L F
.894 .837 .781 r
.65838 .60582 m .66156 .60391 L .66019 .60273 L F
.65838 .60582 m .65959 .60675 L .66156 .60391 L F
.519 .356 .6 r
.7157 .72613 m .71334 .72365 L .71517 .72322 L F
.7157 .72613 m .71388 .72723 L .71334 .72365 L F
.614 .8 .971 r
.51013 .70639 m .51149 .70742 L .5081 .70698 L F
.562 .782 .981 r
.51366 .70696 m .51149 .70742 L .51013 .70639 L F
.467 .453 .759 r
.31052 .60879 m .30882 .60911 L .30838 .60715 L F
.316 .288 .668 r
.31059 .61106 m .30882 .60911 L .31052 .60879 L F
.658 .474 .624 r
.39263 .77309 m .39531 .775 L .39474 .77185 L F
.39263 .77309 m .39222 .77527 L .39531 .775 L F
.733 .595 .702 r
.53806 .77796 m .53943 .78096 L .54154 .78053 L F
.731 .583 .69 r
.53943 .78096 m .54035 .78269 L .54154 .78053 L F
.742 .864 .937 r
.54035 .78269 m .54166 .78185 L .54154 .78053 L F
.648 .501 .67 r
.54166 .78185 m .54381 .78049 L .54154 .78053 L F
.349 .726 .986 r
.29333 .60027 m .29281 .60117 L .29129 .60049 L F
.29333 .60027 m .29481 .60116 L .29281 .60117 L F
.62 .256 .33 r
.53725 .78658 m .53608 .7887 L .53369 .78836 L F
.52 .148 .275 r
.5391 .78791 m .53608 .7887 L .53725 .78658 L F
.497 .163 .332 r
.5397 .78631 m .5391 .78791 L .53725 .78658 L F
.204 0 .225 r
.59558 .74326 m .59806 .74062 L .59511 .74106 L F
.5949 .74124 m .59511 .74106 L .59485 .74109 L F
.59558 .74326 m .59511 .74106 L .5949 .74124 L F
.885 .957 .844 r
.59347 .74372 m .59408 .74201 L .59558 .74264 L F
.59408 .74201 m .59417 .74175 L .59428 .74182 L F
.59408 .74201 m .59428 .74182 L .59558 .74264 L F
.225 0 0 r
.55565 .67962 m .55844 .67954 L .55814 .67919 L F
0 0 0 r
.55814 .67919 m .55844 .67954 L .55985 .67851 L F
.533 .556 .825 r
.3003 .72639 m .30262 .72628 L .30002 .72575 L F
.346 .037 .29 r
.37273 .69583 m .37448 .69595 L .37527 .69369 L F
.406 .091 .316 r
.37527 .69369 m .37653 .6954 L .37675 .69279 L F
.37527 .69369 m .37448 .69595 L .37653 .6954 L F
.523 .317 .542 r
.30529 .67194 m .30754 .67141 L .30757 .66919 L F
.466 .224 .462 r
.30754 .67141 m .30973 .6688 L .30757 .66919 L F
.592 .333 .493 r
.61344 .64683 m .61111 .64486 L .61103 .64708 L F
.61344 .64683 m .61384 .64465 L .61111 .64486 L F
0 .144 .674 r
.45529 .77127 m .45382 .77085 L .45337 .77202 L F
.342 .011 .25 r
.59012 .65573 m .59221 .65479 L .59277 .65256 L F
.303 0 .236 r
.59277 .65256 m .59422 .65392 L .59511 .65308 L F
.59277 .65256 m .59221 .65479 L .59422 .65392 L F
.633 .738 .924 r
.57231 .69499 m .57141 .69704 L .574 .6963 L F
.901 .796 .735 r
.57231 .69499 m .57305 .69792 L .57141 .69704 L F
.57252 .69583 m .57053 .6983 L .57305 .69792 L F
.57231 .69499 m .57207 .69543 L .57252 .69583 L F
.6 .771 .962 r
.57094 .69444 m .57141 .69704 L .56819 .69632 L F
.57101 .6945 m .57141 .69704 L .57094 .69444 L F
.746 .871 .938 r
.57231 .69499 m .57141 .69704 L .571 .6944 L F
.901 .796 .735 r
.57207 .69543 m .57053 .6983 L .57252 .69583 L F
.6 .771 .962 r
.571 .6944 m .57101 .6945 L .57094 .69444 L F
.437 .392 .71 r
.73333 .59778 m .73125 .59895 L .73066 .59556 L F
.217 .296 .731 r
.73205 .59952 m .73125 .59895 L .73333 .59778 L F
.531 .294 .501 r
.5863 .71282 m .58856 .71431 L .58853 .71249 L F
.5863 .71282 m .58613 .71478 L .58856 .71431 L F
.374 0 0 r
.44691 .72815 m .44914 .72807 L .45049 .72689 L F
.58 .178 .246 r
.44914 .72807 m .45243 .7275 L .45049 .72689 L F
.505 .133 .268 r
.31129 .66801 m .31472 .66612 L .31279 .66672 L F
.551 .373 .593 r
.29637 .6829 m .29854 .68259 L .29858 .67996 L F
.501 .275 .504 r
.2962 .68516 m .29854 .68259 L .29637 .6829 L F
.386 .153 .434 r
.38714 .69639 m .38692 .69875 L .38483 .69924 L F
.378 .138 .418 r
.38641 .70084 m .38483 .69924 L .38692 .69875 L F
.38641 .70084 m .38459 .70154 L .38483 .69924 L F
.764 .646 .732 r
.73282 .60652 m .73534 .60366 L .73175 .60337 L F
.366 .075 .331 r
.40264 .74252 m .40523 .74007 L .40277 .74011 L F
.35 0 .215 r
.32915 .65536 m .33115 .65481 L .33228 .6525 L F
.341 0 .21 r
.33228 .6525 m .33312 .65423 L .3343 .65194 L F
.33228 .6525 m .33115 .65481 L .33312 .65423 L F
.471 .095 .244 r
.34819 .67517 m .35033 .67561 L .34814 .67589 L F
.566 .509 .75 r
.42084 .76345 m .41971 .76733 L .41872 .76393 L F
.42084 .76345 m .42183 .76696 L .41971 .76733 L F
.558 .52 .77 r
.42268 .76923 m .41971 .76733 L .42183 .76696 L F
.533 .397 .641 r
.42017 .75799 m .42065 .76245 L .41832 .76209 L F
.565 .438 .667 r
.42084 .76345 m .41832 .76209 L .42065 .76245 L F
.42084 .76345 m .41872 .76393 L .41832 .76209 L F
.632 .693 .889 r
.32727 .70832 m .32424 .70735 L .32637 .70677 L F
.572 .755 .965 r
.32829 .70675 m .32727 .70832 L .32637 .70677 L F
.32829 .70675 m .32959 .70799 L .32727 .70832 L F
.445 .208 .46 r
.38914 .69614 m .38692 .69875 L .38714 .69639 L F
.653 .302 .366 r
.53582 .78265 m .53798 .78306 L .5359 .78111 L F
.707 .263 .196 r
.5359 .78111 m .54035 .78269 L .53943 .78096 L F
.5359 .78111 m .53798 .78306 L .54035 .78269 L F
.068 .198 .692 r
.65344 .60359 m .65433 .60676 L .65518 .60542 L F
.101 .245 .726 r
.65433 .60676 m .65564 .60824 L .65518 .60542 L F
.286 0 0 r
.53258 .71848 m .53629 .72005 L .53415 .72029 L F
.437 .392 .71 r
.73333 .59778 m .73066 .59556 L .73291 .59529 L F
.773 .661 .739 r
.64055 .6254 m .64138 .62362 L .63947 .62217 L F
.758 .653 .745 r
.6373 .62513 m .64055 .6254 L .63947 .62217 L F
.764 .603 .678 r
.63878 .62831 m .64055 .6254 L .6373 .62513 L F
.989 .861 .617 r
.72411 .60388 m .72357 .60586 L .72327 .60292 L F
0 .188 .71 r
.68563 .58512 m .68768 .58757 L .68726 .5874 L F
.374 0 0 r
.39222 .78708 m .38865 .78652 L .39026 .78724 L F
.923 .762 .664 r
.63756 .65019 m .63662 .64704 L .63622 .64992 L F
.927 .708 .587 r
.6376 .65263 m .63756 .65019 L .63622 .64992 L F
.591 .559 .788 r
.38207 .67418 m .38308 .67738 L .38528 .67696 L F
.59 .44 .646 r
.38309 .67984 m .38528 .67696 L .38308 .67738 L F
.472 .316 .587 r
.4008 .74536 m .40267 .74492 L .40264 .74252 L F
.525 .358 .597 r
.4008 .74536 m .4028 .74743 L .40267 .74492 L F
.4008 .74536 m .40081 .74787 L .4028 .74743 L F
0 0 .489 r
.5431 .70188 m .54538 .70458 L .54464 .70366 L F
.057 .17 .668 r
.54577 .70671 m .54464 .70366 L .54538 .70458 L F
.538 .489 .75 r
.60165 .73352 m .59918 .73525 L .59865 .73177 L F
.568 .433 .656 r
.60207 .73676 m .59918 .73525 L .60165 .73352 L F
.60207 .73676 m .59984 .7372 L .59918 .73525 L F
.584 .449 .664 r
.29411 .68787 m .2962 .68516 L .29419 .68568 L F
.778 .66 .732 r
.64138 .62362 m .63978 .62029 L .63947 .62217 L F
.156 0 .104 r
.57118 .66944 m .57224 .67042 L .57311 .66869 L F
.57118 .66944 m .57044 .67142 L .57224 .67042 L F
.989 .753 .37 r
.71906 .73758 m .71836 .73725 L .71827 .73425 L F
.541 .913 .949 r
.72047 .73637 m .71906 .73758 L .72271 .73673 L F
.72047 .73637 m .71836 .73725 L .71906 .73758 L F
.706 .801 .924 r
.69354 .61136 m .69742 .6106 L .69639 .60924 L F
.643 .76 .934 r
.69639 .60924 m .69742 .6106 L .69937 .60976 L F
.375 .2 .511 r
.30218 .62238 m .30202 .62482 L .29982 .62449 L F
.379 .134 .412 r
.29982 .62449 m .30153 .62685 L .29971 .62739 L F
.29982 .62449 m .30202 .62482 L .30153 .62685 L F
.466 .699 .969 r
.7215 .72768 m .72016 .72894 L .71893 .72775 L F
.43 .637 .942 r
.7215 .72768 m .7225 .72916 L .72016 .72894 L F
.445 .127 .332 r
.59828 .75411 m .59771 .75563 L .59554 .75605 L F
.368 .055 .297 r
.60033 .75337 m .59771 .75563 L .59828 .75411 L F
.81 .615 .64 r
.46612 .7401 m .46729 .7401 L .46402 .73939 L F
.553 .321 .518 r
.46729 .7401 m .46729 .7422 L .46636 .74178 L F
.529 .329 .553 r
.46955 .73949 m .46729 .7422 L .46729 .7401 L F
.264 0 0 r
.71556 .71622 m .71435 .71544 L .71349 .71713 L F
.71556 .71622 m .71666 .71508 L .71435 .71544 L F
.551 .326 .527 r
.30273 .67475 m .30495 .67442 L .30529 .67194 L F
.553 .345 .552 r
.30495 .67442 m .30754 .67141 L .30529 .67194 L F
0 .414 .769 r
.27509 .61122 m .27503 .60878 L .27365 .60939 L F
.27509 .61122 m .27683 .61179 L .27503 .60878 L F
.27509 .61122 m .2764 .61167 L .27683 .61179 L F
.888 .951 .601 r
.70277 .58178 m .7033 .58015 L .70449 .58015 L F
.367 .811 .952 r
.70596 .5794 m .70449 .58015 L .7033 .58015 L F
.70596 .5794 m .70713 .57979 L .70449 .58015 L F
.683 .576 .729 r
.63835 .61711 m .64069 .61452 L .63861 .61546 L F
.431 .214 .482 r
.60705 .7426 m .60646 .74472 L .6045 .74507 L F
.333 .236 .593 r
.6065 .74698 m .6045 .74507 L .60646 .74472 L F
.6065 .74698 m .60498 .74808 L .6045 .74507 L F
0 0 .306 r
.65598 .59492 m .65476 .5986 L .65488 .59872 L F
.383 0 0 r
.65743 .59998 m .65488 .59872 L .65476 .5986 L F
.367 .571 .917 r
.71372 .73186 m .71508 .73166 L .71247 .731 L F
.916 .6 .43 r
.71808 .73146 m .71747 .73264 L .7166 .73107 L F
.71747 .73264 m .71685 .73239 L .7166 .73107 L F
.248 .572 .94 r
.71705 .73344 m .71626 .73227 L .7166 .73107 L F
.367 .571 .917 r
.71508 .73166 m .71749 .73131 L .71364 .73107 L F
.71508 .73166 m .71364 .73107 L .71247 .731 L F
.916 .6 .43 r
.71747 .73264 m .71705 .73344 L .71685 .73239 L F
.926 .755 .65 r
.71808 .73146 m .7166 .73107 L .71719 .72893 L F
.962 .682 .457 r
.71808 .73146 m .71827 .73425 L .71705 .73344 L F
.874 .655 .603 r
.61843 .66902 m .61618 .66857 L .61644 .66632 L F
.919 .668 .541 r
.61811 .67138 m .61618 .66857 L .61843 .66902 L F
.767 .646 .728 r
.70505 .59505 m .70608 .59888 L .70288 .59852 L F
.691 .601 .75 r
.70775 .59823 m .70608 .59888 L .70505 .59505 L F
.484 .398 .683 r
.31262 .73118 m .31239 .73585 L .31483 .73419 L F
.291 .363 .765 r
.31239 .73585 m .31471 .73605 L .31483 .73419 L F
.31239 .73585 m .31337 .73711 L .31471 .73605 L F
.508 .228 .424 r
.3718 .69818 m .37448 .69595 L .37273 .69583 L F
0 .554 .725 r
.47191 .78158 m .47343 .78171 L .47578 .78184 L F
.54 .399 .639 r
.29858 .67996 m .30066 .67953 L .30048 .67714 L F
.53 .358 .592 r
.29854 .68259 m .30066 .67953 L .29858 .67996 L F
.654 .585 .765 r
.30438 .74538 m .30726 .74557 L .30653 .74229 L F
.673 .817 .953 r
.71105 .61269 m .71176 .61394 L .71453 .61244 L F
.275 0 0 r
.46668 .78214 m .46794 .78154 L .46942 .78191 L F
.633 .446 .612 r
.62763 .631 m .63078 .63118 L .63014 .62845 L F
.614 .463 .653 r
.63014 .62845 m .63315 .62837 L .63214 .6257 L F
.616 .478 .672 r
.63302 .6307 m .63014 .62845 L .63078 .63118 L F
.63302 .6307 m .63315 .62837 L .63014 .62845 L F
.51 .397 .661 r
.39354 .76438 m .39572 .76666 L .39557 .76394 L F
.39354 .76438 m .39379 .76713 L .39572 .76666 L F
0 0 0 r
.33691 .65044 m .33885 .65008 L .34026 .64967 L F
.534 .047 .044 r
.33885 .65008 m .34232 .64993 L .34026 .64967 L F
.695 .842 .953 r
.69042 .61104 m .69354 .61136 L .69319 .60878 L F
.705 .769 .901 r
.69319 .60878 m .69354 .61136 L .69639 .60924 L F
0 .043 .547 r
.57172 .74507 m .57151 .74479 L .56955 .74296 L F
.676 .293 0 r
.57172 .74507 m .57306 .74782 L .57151 .74479 L F
.507 0 0 r
.69703 .57552 m .69455 .57443 L .69518 .57477 L F
.51 .778 .993 r
.42996 .7761 m .42645 .77535 L .42874 .77451 L F
.535 .698 .944 r
.43216 .77583 m .42996 .7761 L .42874 .77451 L F
.432 .49 .819 r
.39904 .66154 m .40164 .66288 L .39998 .66303 L F
.345 0 0 r
.37841 .66915 m .37622 .66997 L .37498 .66958 L F
0 .48 .843 r
.37841 .66915 m .37999 .66959 L .38007 .66933 L F
.614 .576 .787 r
.37841 .66915 m .38175 .6719 L .37999 .66959 L F
0 .48 .843 r
.37841 .66915 m .38007 .66933 L .37622 .66997 L F
.349 0 .04 r
.352 .70966 m .3541 .70937 L .35563 .70767 L F
.371 0 .095 r
.3541 .70937 m .35772 .70718 L .35563 .70767 L F
.843 .64 .628 r
.63966 .6363 m .63646 .63339 L .63622 .63573 L F
.819 .629 .645 r
.6378 .63899 m .63966 .6363 L .63622 .63573 L F
.117 0 0 r
.48543 .72007 m .48706 .7201 L .48855 .71897 L F
.48543 .72007 m .48509 .72065 L .48706 .7201 L F
.469 0 0 r
.45243 .7275 m .4547 .72771 L .45605 .7265 L F
.617 .214 .256 r
.4547 .72771 m .45822 .72642 L .45605 .7265 L F
.618 .758 .945 r
.69042 .59307 m .69203 .59117 L .68957 .59048 L F
.69042 .59307 m .69319 .59268 L .69203 .59117 L F
.625 .463 .642 r
.69319 .59268 m .69491 .59663 L .69042 .59307 L F
.76 .362 .299 r
.68938 .59461 m .69491 .59663 L .69042 .59307 L F
.625 .463 .642 r
.69319 .59268 m .69491 .59663 L .69042 .59307 L F
.591 .241 .345 r
.43944 .72911 m .44133 .73074 L .44266 .72838 L F
.519 .139 .26 r
.44133 .73074 m .44474 .72865 L .44266 .72838 L F
.625 .459 .637 r
.5911 .70989 m .5931 .70703 L .59065 .70724 L F
.2 0 0 r
.35605 .72179 m .35556 .72073 L .35751 .71997 L F
.35605 .72179 m .35409 .72234 L .35556 .72073 L F
.863 .88 .848 r
.72482 .58184 m .722 .58318 L .72389 .58089 L F
.458 .802 .998 r
.72574 .58089 m .72482 .58184 L .72389 .58089 L F
.72574 .58089 m .72719 .58152 L .72482 .58184 L F
.401 0 0 r
.52166 .70822 m .52305 .70863 L .52273 .70823 L F
.189 .427 .859 r
.52261 .70743 m .52306 .70858 L .52166 .70822 L F
.401 0 0 r
.52166 .70822 m .52322 .70898 L .52305 .70863 L F
.189 .427 .859 r
.52306 .70858 m .52322 .70898 L .52166 .70822 L F
.232 0 0 r
.52005 .70781 m .52166 .70822 L .52273 .70823 L F
.51916 .70767 m .52166 .70822 L .52005 .70781 L F
.245 .262 .681 r
.56955 .74296 m .57151 .74479 L .57131 .74144 L F
.565 .938 .868 r
.32792 .82832 m .32932 .82714 L .32648 .82689 L F
.32792 .82832 m .33046 .82702 L .32932 .82714 L F
0 0 0 r
.48855 .71897 m .4891 .71938 L .49061 .71809 L F
.48855 .71897 m .48706 .7201 L .4891 .71938 L F
.437 .819 .99 r
.35919 .64849 m .36092 .6481 L .36263 .64874 L F
.214 0 0 r
.35968 .64871 m .36267 .6477 L .36092 .6481 L F
.51 .849 .996 r
.36139 .64811 m .36314 .64755 L .36487 .64815 L F
.36092 .6481 m .36314 .64755 L .36139 .64811 L F
.36092 .6481 m .36487 .64815 L .36263 .64874 L F
.811 .901 .905 r
.36487 .64815 m .36314 .64755 L .36528 .64588 L F
0 0 0 r
.36314 .64755 m .36186 .64839 L .36473 .64704 L F
.36314 .64755 m .36473 .64704 L .36517 .64683 L F
.214 0 0 r
.36267 .6477 m .36314 .64755 L .36092 .6481 L F
.437 .819 .99 r
.35897 .64848 m .36092 .6481 L .35919 .64849 L F
.455 .402 .709 r
.2791 .61779 m .2803 .61433 L .2784 .61467 L F
.2791 .61779 m .28102 .61705 L .2803 .61433 L F
.172 .191 .639 r
.2791 .61779 m .28061 .61902 L .28102 .61705 L F
.2791 .61779 m .27962 .62012 L .28061 .61902 L F
0 .004 .581 r
.57282 .72101 m .57398 .72371 L .57304 .72218 L F
.912 .654 .535 r
.67854 .60897 m .67669 .61128 L .67605 .6096 L F
.67854 .60897 m .67865 .61117 L .67669 .61128 L F
.604 .121 .08 r
.69929 .57578 m .70237 .57581 L .69998 .57473 L F
.546 .023 0 r
.70337 .57529 m .69998 .57473 L .70237 .57581 L F
.4 .41 .755 r
.69553 .7193 m .69601 .72088 L .69769 .72071 L F
.588 .53 .757 r
.6957 .72294 m .69769 .72071 L .69601 .72088 L F
.91 .791 .718 r
.58027 .67666 m .58313 .67436 L .58214 .67374 L F
.58027 .67666 m .58191 .67763 L .58313 .67436 L F
.867 .936 .865 r
.58456 .67111 m .58313 .67436 L .58551 .67161 L F
.58456 .67111 m .58214 .67374 L .58313 .67436 L F
0 0 0 r
.4401 .7861 m .43635 .78673 L .43791 .78624 L F
.826 .704 .73 r
.60063 .70383 m .60361 .70146 L .60084 .70232 L F
.637 .219 .234 r
.48828 .78204 m .4868 .78323 L .48458 .78266 L F
.642 .225 .239 r
.48828 .78204 m .49019 .78322 L .4868 .78323 L F
.647 .191 .156 r
.49149 .78271 m .49019 .78322 L .48828 .78204 L F
.55 .2 .327 r
.43815 .74787 m .43716 .74992 L .43499 .74979 L F
.441 .063 .224 r
.44098 .74737 m .43716 .74992 L .43815 .74787 L F
.606 .642 .86 r
.56286 .72604 m .56414 .72882 L .56657 .72838 L F
.094 .307 .785 r
.56414 .72882 m .56631 .73039 L .56657 .72838 L F
.256 0 0 r
.58632 .7221 m .58516 .72119 L .58735 .72128 L F
.58632 .7221 m .58412 .7226 L .58516 .72119 L F
.347 .743 .984 r
.28379 .5997 m .28021 .59903 L .28211 .59886 L F
.472 .79 .999 r
.28453 .59855 m .28379 .5997 L .28211 .59886 L F
.28453 .59855 m .28614 .59938 L .28379 .5997 L F
.371 .764 .987 r
.6428 .61148 m .6462 .61202 L .64352 .61193 L F
.148 0 0 r
.3451 .6489 m .34789 .64851 L .34752 .64816 L F
.3451 .6489 m .34436 .64942 L .34789 .64851 L F
.363 .215 .543 r
.61876 .6963 m .61882 .69851 L .61725 .69912 L F
.214 .031 .403 r
.61882 .69851 m .61716 .7013 L .61725 .69912 L F
.552 .115 .163 r
.49548 .78102 m .49787 .78222 L .49921 .78032 L F
.731 .323 .275 r
.49921 .78032 m .49787 .78222 L .50128 .78257 L F
.453 0 0 r
.30262 .72628 m .29861 .72398 L .30002 .72575 L F
.837 .654 .654 r
.57884 .68909 m .57778 .69067 L .57529 .69002 L F
.57 .745 .96 r
.33352 .70902 m .32959 .70799 L .33181 .70804 L F
.342 .687 .98 r
.33388 .70805 m .33352 .70902 L .33181 .70804 L F
.33388 .70805 m .33514 .70899 L .33352 .70902 L F
.54 .079 .107 r
.58808 .75854 m .58663 .75923 L .5846 .75888 L F
.483 0 0 r
.59026 .75908 m .58663 .75923 L .58808 .75854 L F
0 0 0 r
.41529 .79087 m .412 .79132 L .41351 .79107 L F
.337 0 0 r
.71262 .73198 m .7109 .73278 L .70913 .73262 L F
0 0 0 r
.71372 .73186 m .71262 .73198 L .71626 .73227 L F
.71372 .73186 m .7109 .73278 L .71262 .73198 L F
.735 .807 .908 r
.39929 .79149 m .40213 .79183 L .4011 .79073 L F
0 0 0 r
.39879 .79372 m .40213 .79183 L .39929 .79149 L F
.555 .743 .964 r
.4011 .79073 m .40213 .79183 L .40283 .79058 L F
.495 .667 .94 r
.40283 .79058 m .40213 .79183 L .40423 .79171 L F
0 0 0 r
.33261 .73222 m .33041 .73346 L .32905 .73383 L F
.127 0 0 r
.33269 .733 m .33261 .73222 L .33465 .7316 L F
.33269 .733 m .33041 .73346 L .33261 .73222 L F
.792 .723 .787 r
.65564 .60824 m .65735 .60963 L .65959 .60675 L F
.468 .589 .891 r
.38175 .6719 m .38318 .67044 L .37999 .66959 L F
.38175 .6719 m .38348 .67144 L .38318 .67044 L F
.545 .471 .723 r
.38207 .67418 m .38348 .67144 L .38175 .6719 L F
0 0 .355 r
.54085 .78337 m .54035 .78269 L .53798 .78306 L F
.517 .692 .947 r
.38383 .65502 m .38034 .65354 L .38238 .653 L F
.446 .535 .854 r
.38436 .65246 m .38383 .65502 L .38238 .653 L F
.38436 .65246 m .38583 .65533 L .38383 .65502 L F
.716 .682 .816 r
.45289 .77251 m .44937 .7726 L .45188 .77208 L F
.586 .372 .558 r
.32197 .69639 m .32173 .69867 L .31978 .69928 L F
.471 .344 .625 r
.32328 .69366 m .32434 .69618 L .32197 .69639 L F
.489 .289 .535 r
.32378 .69836 m .32197 .69639 L .32434 .69618 L F
.32378 .69836 m .32173 .69867 L .32197 .69639 L F
.613 .427 .607 r
.51785 .73339 m .51623 .73131 L .51969 .73168 L F
.769 .476 .49 r
.51969 .73168 m .51967 .73397 L .51785 .73339 L F
.689 .557 .7 r
.52189 .72877 m .52255 .73172 L .51969 .73168 L F
.724 .482 .56 r
.52255 .73172 m .51967 .73397 L .51969 .73168 L F
.396 .225 .529 r
.2974 .6284 m .29732 .62976 L .29598 .63109 L F
.284 .073 .406 r
.29598 .63109 m .29754 .63239 L .29571 .63314 L F
.29598 .63109 m .29732 .62976 L .29754 .63239 L F
.533 .401 .647 r
.67255 .58928 m .673 .59087 L .67485 .58965 L F
.602 .266 .373 r
.43133 .7333 m .43354 .73353 L .43165 .73182 L F
.531 .282 .482 r
.43165 .73182 m .43354 .73353 L .43381 .73147 L F
.655 .709 .887 r
.72871 .60232 m .72957 .60389 L .73175 .60337 L F
.698 .195 .039 r
.72871 .60232 m .73175 .60337 L .72957 .60389 L F
0 .054 .591 r
.47517 .77185 m .47564 .77253 L .47408 .77096 L F
.47517 .77185 m .47408 .77096 L .47321 .77118 L F
.683 .746 .899 r
.34535 .70905 m .34072 .70798 L .34299 .70723 L F
.357 .575 .923 r
.34474 .70694 m .34535 .70905 L .34299 .70723 L F
.34474 .70694 m .34651 .7089 L .34535 .70905 L F
.74 .61 .713 r
.58159 .74217 m .58233 .74648 L .57884 .74515 L F
.663 .558 .726 r
.58443 .74494 m .58233 .74648 L .58159 .74217 L F
.635 .912 .981 r
.43769 .77501 m .43583 .77593 L .4345 .77538 L F
.645 .505 .678 r
.63214 .6257 m .63417 .62259 L .63179 .62301 L F
.63214 .6257 m .63556 .62587 L .63417 .62259 L F
.644 .527 .706 r
.6352 .62801 m .63214 .6257 L .63315 .62837 L F
.6352 .62801 m .63556 .62587 L .63214 .6257 L F
.574 .76 .966 r
.71869 .61997 m .72183 .62064 L .72106 .62033 L F
0 .356 .82 r
.72183 .62064 m .72312 .62082 L .72106 .62033 L F
.72183 .62064 m .72438 .62219 L .72312 .62082 L F
.667 .833 .963 r
.32097 .73695 m .32273 .73823 L .32503 .73748 L F
.317 .089 .402 r
.30672 .61705 m .30461 .61982 L .3046 .61745 L F
.582 .673 .902 r
.40494 .66541 m .40846 .66673 L .4064 .66735 L F
.398 .069 .288 r
.36742 .71453 m .36532 .71512 L .36804 .71299 L F
.442 .112 .309 r
.3694 .71406 m .36804 .71299 L .37015 .7125 L F
.3694 .71406 m .36742 .71453 L .36804 .71299 L F
.128 0 .011 r
.50515 .72654 m .50265 .72779 L .50424 .72536 L F
.745 .428 0 r
.73239 .60549 m .73282 .60652 L .73175 .60337 L F
.942 .738 .267 r
.73275 .60953 m .73282 .60652 L .73239 .60549 L F
.605 .526 .739 r
.49815 .72769 m .4997 .73101 L .49781 .73081 L F
.905 .979 .79 r
.49927 .7251 m .49698 .72804 L .49841 .72769 L F
.605 .526 .739 r
.49828 .72644 m .49863 .72755 L .49815 .72769 L F
.49863 .72755 m .4997 .73101 L .49815 .72769 L F
.253 .759 .729 r
.49841 .72769 m .49725 .72797 L .49602 .72843 L F
.49725 .72797 m .49698 .72804 L .4968 .72811 L F
.49725 .72797 m .4968 .72811 L .49602 .72843 L F
.639 .591 .785 r
.49698 .72804 m .49516 .73076 L .49602 .72843 L F
.623 .666 .87 r
.69937 .60976 m .70299 .61185 L .7013 .60949 L F
.529 .686 .938 r
.70299 .61185 m .7042 .61019 L .7013 .60949 L F
.70299 .61185 m .70525 .61161 L .7042 .61019 L F
.134 .563 .924 r
.51005 .79499 m .51141 .79466 L .50885 .79403 L F
.51005 .79499 m .51253 .79557 L .51141 .79466 L F
0 .446 .861 r
.72786 .62094 m .73128 .62299 L .72981 .61981 L F
0 0 .478 r
.58004 .72064 m .58067 .71757 L .57851 .7179 L F
.58004 .72064 m .58092 .7201 L .58067 .71757 L F
.772 .279 0 r
.58004 .72064 m .58204 .72327 L .58056 .72214 L F
.58004 .72064 m .58056 .72214 L .58092 .7201 L F
.719 .96 .688 r
.5543 .68472 m .55595 .68251 L .55657 .68252 L F
.5543 .68472 m .55391 .68474 L .55595 .68251 L F
.815 .667 .699 r
.68868 .59847 m .6863 .60119 L .68606 .59806 L F
0 0 0 r
.35425 .67512 m .35228 .67544 L .35033 .67561 L F
.083 0 0 r
.35599 .67418 m .35228 .67544 L .35425 .67512 L F
0 .269 .737 r
.50039 .78584 m .5013 .78606 L .49909 .78544 L F
.50039 .78584 m .50307 .78759 L .5013 .78606 L F
.711 .688 .825 r
.30733 .60576 m .31066 .60652 L .30838 .60715 L F
.467 .453 .759 r
.31052 .60879 m .30838 .60715 L .31066 .60652 L F
.606 .341 .489 r
.52826 .72773 m .52825 .72888 L .52398 .73127 L F
.732 .419 .451 r
.52974 .72961 m .52825 .72888 L .52826 .72773 L F
.384 .211 .519 r
.52406 .72898 m .52255 .73172 L .52189 .72877 L F
.974 .685 .41 r
.58954 .72845 m .5884 .72858 L .58827 .72577 L F
.496 .906 .851 r
.5897 .72813 m .5884 .72858 L .58954 .72845 L F
.792 .833 .883 r
.59191 .72814 m .5897 .72813 L .58954 .72845 L F
.155 .697 .758 r
.529 .78849 m .52808 .78856 L .52595 .78888 L F
.106 .66 .732 r
.53141 .78821 m .52808 .78856 L .529 .78849 L F
.912 .739 .244 r
.72249 .61331 m .7223 .61123 L .72385 .61264 L F
.719 .413 .459 r
.45938 .74239 m .45652 .74453 L .45619 .74278 L F
.45938 .74239 m .45904 .74489 L .45652 .74453 L F
.392 .128 .389 r
.46101 .74415 m .45938 .74239 L .46066 .74155 L F
.46101 .74415 m .45904 .74489 L .45938 .74239 L F
.624 .426 .593 r
.35508 .835 m .35513 .83802 L .35559 .83503 L F
.59 .449 .657 r
.59897 .72043 m .59927 .72439 L .59657 .72364 L F
.612 .48 .677 r
.59973 .72584 m .59657 .72364 L .59927 .72439 L F
.59973 .72584 m .59751 .72658 L .59657 .72364 L F
.366 .075 .331 r
.40264 .74252 m .40457 .74201 L .40523 .74007 L F
.536 .317 .53 r
.40457 .74201 m .40686 .73935 L .40523 .74007 L F
.279 .003 .303 r
.40582 .67778 m .40524 .6795 L .40354 .68024 L F
.41 .154 .412 r
.40493 .68169 m .40354 .68024 L .40524 .6795 L F
.40493 .68169 m .403 .68228 L .40354 .68024 L F
.351 .497 .864 r
.40011 .66018 m .39904 .66154 L .39853 .66003 L F
.40011 .66018 m .40164 .66288 L .39904 .66154 L F
.315 .278 .657 r
.72881 .73735 m .72974 .73735 L .72946 .7371 L F
.72974 .73735 m .7298 .73707 L .72659 .7346 L F
.72754 .73735 m .72881 .73735 L .72659 .7346 L F
0 .205 .701 r
.72731 .73705 m .72962 .73729 L .72754 .73735 L F
0 0 0 r
.73177 .73609 m .72983 .73697 L .72973 .73759 L F
.72999 .73829 m .72973 .73759 L .72953 .73886 L F
.73177 .73609 m .72973 .73759 L .72999 .73829 L F
.315 .278 .657 r
.72881 .73735 m .72946 .7371 L .72659 .7346 L F
0 .205 .701 r
.72731 .73705 m .72676 .73576 L .72953 .73705 L F
.315 .278 .657 r
.72974 .73735 m .73016 .73735 L .72975 .7373 L F
.72978 .73717 m .73016 .73735 L .7298 .73707 L F
0 0 0 r
.7298 .73707 m .72945 .73721 L .72974 .73735 L F
.72983 .73697 m .72941 .73873 L .72953 .73886 L F
0 .205 .701 r
.72962 .73729 m .72953 .73705 L .73016 .73735 L F
.72915 .73724 m .72955 .7371 L .72962 .73729 L F
0 0 0 r
.72963 .73706 m .72838 .73763 L .7298 .73707 L F
.72955 .7371 m .72996 .73698 L .72838 .73763 L F
.72983 .73697 m .72963 .73706 L .7298 .73707 L F
.72983 .73697 m .72988 .73697 L .72955 .7371 L F
.72988 .73697 m .72996 .73698 L .72955 .7371 L F
0 .205 .701 r
.72731 .73705 m .72953 .73705 L .72955 .7371 L F
.72731 .73705 m .72955 .7371 L .72915 .73724 L F
.72962 .73729 m .73016 .73735 L .72974 .73735 L F
.72962 .73729 m .72974 .73735 L .72754 .73735 L F
0 0 0 r
.72974 .73735 m .72838 .73763 L .72941 .73873 L F
.72945 .73721 m .72838 .73763 L .72974 .73735 L F
.634 .101 0 r
.72659 .7346 m .7298 .73707 L .72676 .73576 L F
.7298 .73707 m .73016 .73735 L .72953 .73705 L F
.7298 .73707 m .72953 .73705 L .72676 .73576 L F
0 0 0 r
.73177 .73609 m .73048 .73672 L .72983 .73697 L F
.73048 .73672 m .72996 .73698 L .72983 .73697 L F
.495 .352 .616 r
.56076 .72627 m .56286 .72604 L .56219 .72349 L F
.108 0 .009 r
.58299 .71747 m .58613 .71478 L .58388 .71521 L F
.332 .051 .328 r
.40706 .67889 m .40582 .67778 L .40797 .67645 L F
.40706 .67889 m .40524 .6795 L .40582 .67778 L F
.037 0 0 r
.45822 .72642 m .46029 .72646 L .46157 .72645 L F
.507 0 0 r
.46029 .72646 m .46384 .72646 L .46157 .72645 L F
.608 .432 .619 r
.6254 .63381 m .62773 .6335 L .62763 .631 L F
.633 .508 .692 r
.63079 .63335 m .62763 .631 L .62773 .6335 L F
.63079 .63335 m .63078 .63118 L .62763 .631 L F
.699 .578 .716 r
.63417 .62259 m .63393 .62028 L .63179 .62301 L F
.252 .597 .951 r
.39331 .65696 m .39514 .65868 L .39041 .65692 L F
.39331 .65696 m .39041 .65692 L .39127 .65735 L F
.944 .748 .607 r
.58 .6824 m .57949 .68465 L .58139 .68527 L F
.903 .771 .705 r
.57861 .68693 m .58018 .68779 L .58139 .68527 L F
.664 .587 .759 r
.69449 .71575 m .69553 .7193 L .69894 .71758 L F
.4 .41 .755 r
.69553 .7193 m .69769 .72071 L .69894 .71758 L F
.711 .739 .873 r
.30156 .72779 m .3036 .72882 L .30034 .72883 L F
.256 0 0 r
.3036 .72882 m .29978 .72977 L .30034 .72883 L F
.3036 .72882 m .30213 .72951 L .29978 .72977 L F
.796 .705 .764 r
.30262 .72628 m .3036 .72882 L .30156 .72779 L F
.051 .599 .836 r
.30497 .72992 m .30213 .72951 L .3036 .72882 L F
.089 0 .105 r
.58566 .65862 m .58335 .66107 L .58506 .65985 L F
.161 0 .145 r
.58506 .65985 m .58747 .65755 L .58566 .65862 L F
.693 .981 .827 r
.49836 .71298 m .4957 .715 L .49653 .71366 L F
.691 .959 .714 r
.4957 .715 m .49518 .7151 L .49653 .71366 L F
.68 .765 .915 r
.50793 .78351 m .50499 .7825 L .50645 .78299 L F
.694 .225 .133 r
.50708 .78482 m .50793 .78351 L .50645 .78299 L F
.429 .545 .872 r
.31262 .73118 m .31281 .72845 L .31065 .72957 L F
.31262 .73118 m .31431 .73116 L .31281 .72845 L F
.484 .398 .683 r
.31262 .73118 m .31483 .73419 L .31431 .73116 L F
.343 .421 .797 r
.67472 .61576 m .67332 .6171 L .6749 .61766 L F
.122 .616 .909 r
.44185 .77471 m .44115 .77509 L .44001 .77414 L F
.44185 .77471 m .44331 .77541 L .44115 .77509 L F
.881 .459 .049 r
.52987 .71686 m .53094 .71767 L .52909 .71512 L F
.502 0 0 r
.52987 .71686 m .53258 .71848 L .53094 .71767 L F
.548 .406 .64 r
.41169 .66858 m .412 .67124 L .41006 .67153 L F
.508 .324 .567 r
.412 .67124 m .41006 .67398 L .41006 .67153 L F
.049 0 0 r
.32738 .65609 m .32631 .65709 L .32915 .65536 L F
.617 .474 .665 r
.57967 .73678 m .57768 .74029 L .57809 .73807 L F
.474 0 0 r
.53249 .72941 m .53504 .72961 L .53284 .72851 L F
.383 0 0 r
.65743 .59998 m .65611 .59948 L .65488 .59872 L F
.573 .371 .569 r
.65488 .59872 m .65921 .59754 L .65851 .5956 L F
.383 0 0 r
.65488 .59872 m .65743 .59998 L .65921 .59754 L F
.65488 .59872 m .65611 .59948 L .65743 .59998 L F
.537 .381 .617 r
.2923 .69089 m .29449 .69069 L .29411 .68787 L F
.546 .377 .604 r
.29226 .69328 m .29449 .69069 L .2923 .69089 L F
.744 .921 .562 r
.38254 .7983 m .38122 .80029 L .38194 .79869 L F
.245 .416 .834 r
.38122 .80029 m .38323 .8014 L .38194 .79869 L F
.8 .398 0 r
.58106 .75669 m .58159 .75807 L .58007 .75534 L F
.888 .951 .601 r
.70277 .58178 m .70228 .58206 L .7033 .58015 L F
.949 .791 .651 r
.70277 .58178 m .70049 .58335 L .70228 .58206 L F
.70277 .58178 m .70257 .5848 L .70049 .58335 L F
.459 .771 .997 r
.51792 .70673 m .51696 .70783 L .51581 .70662 L F
.51792 .70673 m .51916 .70767 L .51696 .70783 L F
.471 .1 .253 r
.43618 .73137 m .43843 .73108 L .43944 .72911 L F
.602 .236 .321 r
.43944 .72911 m .43843 .73108 L .44133 .73074 L F
.7 .64 .786 r
.31955 .70148 m .31764 .70405 L .31775 .70254 L F
.651 .57 .75 r
.31955 .70148 m .32047 .7055 L .31764 .70405 L F
.656 .598 .778 r
.32116 .7061 m .31764 .70405 L .32047 .7055 L F
.258 0 0 r
.48827 .73149 m .48676 .73308 L .48473 .73335 L F
.463 .037 .146 r
.49048 .73109 m .48676 .73308 L .48827 .73149 L F
.476 .282 .537 r
.42231 .75601 m .42215 .75804 L .42017 .75799 L F
.567 .448 .677 r
.42215 .75804 m .42065 .76245 L .42017 .75799 L F
.623 .701 .901 r
.32637 .70677 m .32424 .70735 L .32299 .70582 L F
.31 .155 .503 r
.2995 .62968 m .2974 .6284 L .29971 .62739 L F
.2995 .62968 m .29732 .62976 L .2974 .6284 L F
.283 0 .245 r
.36548 .70184 m .363 .7042 L .36486 .70337 L F
.268 0 .062 r
.36486 .70337 m .36774 .70162 L .36548 .70184 L F
.229 .17 .58 r
.73178 .73099 m .73235 .73397 L .73114 .73414 L F
.188 0 .351 r
.73235 .73397 m .73177 .73609 L .73114 .73414 L F
.608 .149 .137 r
.69701 .58479 m .69609 .58617 L .69381 .58485 L F
.815 .885 .457 r
.69831 .58122 m .69702 .58419 L .69701 .58479 L F
.424 0 .038 r
.69794 .58594 m .69701 .58479 L .69702 .58419 L F
.69794 .58594 m .69609 .58617 L .69701 .58479 L F
.386 .727 .99 r
.70049 .58335 m .70257 .5848 L .69957 .58364 L F
.832 .593 .578 r
.70269 .58699 m .69957 .58364 L .70257 .5848 L F
.53 .53 .8 r
.32181 .70313 m .32116 .7061 L .32047 .7055 L F
.32181 .70313 m .32299 .70582 L .32116 .7061 L F
.784 .689 .76 r
.39405 .78321 m .39276 .78635 L .39526 .78635 L F
.476 .413 .707 r
.39526 .78635 m .39651 .78287 L .39405 .78321 L F
.39526 .78635 m .39712 .78611 L .39651 .78287 L F
.437 .113 .317 r
.59554 .75605 m .59487 .75847 L .59265 .75892 L F
.397 .064 .279 r
.59771 .75563 m .59487 .75847 L .59554 .75605 L F
.64 .14 0 r
.72679 .7207 m .72852 .72274 L .72757 .72194 L F
.884 .761 .72 r
.73142 .61676 m .73252 .61463 L .73086 .61373 L F
.59 .437 .643 r
.54757 .69111 m .55029 .69256 L .55029 .6874 L F
.695 .608 .755 r
.54723 .69336 m .55029 .69256 L .54757 .69111 L F
.642 .411 .553 r
.62303 .63605 m .62537 .63602 L .6254 .63381 L F
.598 .38 .556 r
.62537 .63602 m .62773 .6335 L .6254 .63381 L F
.792 .723 .787 r
.65564 .60824 m .65959 .60675 L .65838 .60582 L F
.66 .546 .714 r
.63417 .62259 m .63622 .61957 L .63393 .62028 L F
.63417 .62259 m .63758 .62313 L .63622 .61957 L F
.657 .557 .73 r
.6373 .62513 m .63417 .62259 L .63556 .62587 L F
.6373 .62513 m .63758 .62313 L .63417 .62259 L F
.559 .824 .995 r
.37208 .64946 m .37145 .65081 L .37 .64968 L F
.37208 .64946 m .37339 .65031 L .37145 .65081 L F
.695 .936 .964 r
.58609 .67037 m .58551 .67161 L .58743 .67058 L F
.58609 .67037 m .58456 .67111 L .58551 .67161 L F
.816 .639 .662 r
.63844 .65785 m .63898 .65568 L .6358 .65497 L F
.535 0 0 r
.34789 .64851 m .3499 .64943 L .34752 .64816 L F
.34752 .64816 m .3499 .64943 L .35129 .64949 L F
.724 .482 .56 r
.52255 .73172 m .52236 .73412 L .51967 .73397 L F
.384 .211 .519 r
.52406 .72898 m .52398 .73127 L .52255 .73172 L F
.341 .159 .482 r
.52396 .73339 m .52255 .73172 L .52398 .73127 L F
.469 .167 .37 r
.52426 .73307 m .52614 .733 L .52396 .73339 L F
.52825 .72888 m .52651 .73228 L .52426 .73307 L F
.52651 .73228 m .52614 .733 L .52426 .73307 L F
.52825 .72888 m .52396 .73339 L .52398 .73127 L F
.732 .419 .451 r
.52974 .72961 m .52956 .73082 L .52825 .72888 L F
.512 .14 .271 r
.52956 .73082 m .52614 .733 L .52825 .72888 L F
.52956 .73082 m .52849 .73248 L .52614 .733 L F
.652 .298 .359 r
.52956 .73082 m .53178 .73277 L .52849 .73248 L F
.779 .721 .798 r
.52714 .72949 m .52961 .73119 L .52943 .72884 L F
.635 .307 .399 r
.53176 .73106 m .53178 .73277 L .52956 .73082 L F
.779 .721 .798 r
.52961 .73119 m .53064 .7319 L .53027 .73096 L F
.52961 .73119 m .53027 .73096 L .52943 .72884 L F
.771 .715 .8 r
.52614 .733 m .52532 .73291 L .52396 .73339 L F
.52532 .73291 m .52303 .73267 L .52396 .73339 L F
.341 .159 .482 r
.52396 .73339 m .52236 .73412 L .52237 .73395 L F
.52396 .73339 m .52237 .73395 L .52255 .73172 L F
.288 0 .074 r
.57024 .70666 m .57239 .70604 L .57303 .70506 L F
.066 0 0 r
.57303 .70506 m .57239 .70604 L .57493 .70409 L F
.769 .316 0 r
.50737 .79145 m .50791 .79307 L .50589 .79081 L F
.50737 .79145 m .50885 .79403 L .50791 .79307 L F
.576 .303 .466 r
.42739 .75462 m .42575 .75289 L .42729 .75303 L F
.42739 .75462 m .42407 .7556 L .42575 .75289 L F
.254 0 0 r
.72444 .71221 m .72678 .71214 L .72779 .71163 L F
.428 0 0 r
.72779 .71163 m .72678 .71214 L .73013 .71198 L F
.313 0 .158 r
.58031 .66354 m .58263 .663 L .58335 .66107 L F
.03 0 .044 r
.58335 .66107 m .58424 .66185 L .58506 .65985 L F
.58335 .66107 m .58263 .663 L .58424 .66185 L F
.872 .559 .456 r
.70237 .57581 m .70434 .57706 L .70337 .57529 L F
0 0 0 r
.66764 .5975 m .66819 .59565 L .66691 .59803 L F
.66919 .59413 m .66819 .59565 L .66764 .5975 L F
.65 .557 .736 r
.6957 .72294 m .69671 .72622 L .69953 .72576 L F
.708 .655 .795 r
.71643 .61135 m .71759 .61432 L .71973 .61186 L F
.636 .543 .732 r
.71759 .61432 m .72038 .61388 L .71973 .61186 L F
.397 .23 .535 r
.71759 .61432 m .71946 .61535 L .72038 .61388 L F
.71759 .61432 m .71768 .61687 L .71946 .61535 L F
.483 .306 .564 r
.37893 .68531 m .3809 .68488 L .38091 .68255 L F
.511 .363 .616 r
.37892 .68793 m .3809 .68488 L .37893 .68531 L F
.172 0 0 r
.45188 .77208 m .44937 .7726 L .44697 .77375 L F
.211 .344 .781 r
.55565 .67962 m .55657 .68252 L .55769 .68129 L F
.607 .953 .825 r
.55657 .68252 m .55595 .68251 L .55769 .68129 L F
.697 .155 0 r
.54937 .73967 m .5481 .74007 L .54498 .73707 L F
.849 .968 .645 r
.54925 .73811 m .54937 .73967 L .55078 .73763 L F
.56 .029 0 r
.54498 .73707 m .5481 .74007 L .5459 .73824 L F
.694 .752 .896 r
.54937 .73967 m .55207 .7384 L .55078 .73763 L F
.329 .57 .927 r
.55207 .7384 m .5526 .73734 L .55078 .73763 L F
.55207 .7384 m .55416 .73932 L .5526 .73734 L F
0 .259 .762 r
.55416 .73932 m .55436 .73873 L .5526 .73734 L F
0 0 0 r
.55196 .73747 m .55078 .73763 L .5526 .73734 L F
.658 .966 .79 r
.55048 .73925 m .55235 .7374 L .55177 .73767 L F
0 .26 .764 r
.5526 .73734 m .55306 .73746 L .55196 .73747 L F
.5526 .73734 m .55358 .73811 L .55388 .73769 L F
.55358 .73811 m .55436 .73873 L .55388 .73769 L F
.557 .867 .57 r
.55523 .73623 m .55418 .73725 L .55388 .73769 L F
.658 .966 .79 r
.54947 .74025 m .55296 .73756 L .55225 .7375 L F
.55177 .73767 m .55235 .7374 L .55195 .73747 L F
.371 .138 .425 r
.55195 .73747 m .55138 .73871 L .55001 .73984 L F
.55195 .73747 m .54943 .74054 L .55105 .73855 L F
.55105 .73855 m .54939 .74055 L .55167 .73753 L F
.658 .966 .79 r
.54947 .74025 m .55048 .73925 L .55105 .73855 L F
.5512 .73831 m .55105 .73855 L .55177 .73767 L F
.54947 .74025 m .55105 .73855 L .5512 .73831 L F
.371 .138 .425 r
.55167 .73753 m .54939 .74055 L .54925 .73811 L F
.658 .966 .79 r
.54947 .74025 m .55195 .73747 L .54967 .73801 L F
.371 .138 .425 r
.55195 .73747 m .55105 .73855 L .55167 .73753 L F
0 0 .153 r
.55231 .73907 m .55067 .74025 L .55138 .73871 L F
.55207 .73798 m .55161 .73822 L .55195 .73747 L F
.725 .551 .655 r
.55007 .73901 m .55248 .73776 L .55262 .73769 L F
0 0 .153 r
.55208 .73802 m .55195 .73747 L .55289 .73757 L F
.725 .551 .655 r
.55218 .73792 m .55262 .73769 L .55283 .73758 L F
.55007 .73901 m .55262 .73769 L .55218 .73792 L F
0 0 .153 r
.55208 .73802 m .55138 .73871 L .55161 .73822 L F
.55208 .73802 m .55161 .73822 L .55207 .73798 L F
.658 .966 .79 r
.55144 .73865 m .55208 .73802 L .55251 .73778 L F
.54999 .73985 m .55251 .73778 L .55308 .73747 L F
0 0 .153 r
.55231 .73907 m .55138 .73871 L .55208 .73802 L F
.658 .966 .79 r
.54947 .74025 m .55 .73917 L .55208 .73802 L F
.54947 .74025 m .55208 .73802 L .55144 .73865 L F
.54947 .74025 m .55251 .73778 L .54999 .73985 L F
.371 .138 .425 r
.55001 .73984 m .55067 .74025 L .54943 .74054 L F
.55138 .73871 m .55067 .74025 L .55001 .73984 L F
0 0 .153 r
.55231 .73907 m .55208 .73802 L .55388 .73769 L F
.55208 .73802 m .55289 .73757 L .55388 .73769 L F
.658 .966 .79 r
.55308 .73747 m .55007 .73901 L .55314 .73742 L F
.55 .73917 m .55007 .73901 L .55308 .73747 L F
.557 .867 .57 r
.55418 .73725 m .55231 .73907 L .55388 .73769 L F
0 .26 .764 r
.55306 .73746 m .55369 .73763 L .55288 .73756 L F
.55306 .73746 m .55288 .73756 L .55196 .73747 L F
0 .081 .637 r
.55314 .73742 m .5538 .73707 L .55242 .73447 L F
.725 .551 .655 r
.55283 .73758 m .5538 .73707 L .55314 .73742 L F
.658 .966 .79 r
.55296 .73756 m .55314 .73742 L .55225 .7375 L F
.725 .551 .655 r
.55248 .73776 m .5538 .73707 L .55283 .73758 L F
.658 .966 .79 r
.55225 .7375 m .55314 .73742 L .55235 .7374 L F
0 .26 .764 r
.55196 .73747 m .55388 .73769 L .55195 .73747 L F
.55369 .73763 m .55388 .73769 L .55196 .73747 L F
.371 .138 .425 r
.55105 .73855 m .54943 .74054 L .54939 .74055 L F
0 0 0 r
.55195 .73747 m .54925 .73811 L .55078 .73763 L F
.55167 .73753 m .54925 .73811 L .55195 .73747 L F
.658 .966 .79 r
.54967 .73801 m .55195 .73747 L .54969 .73785 L F
0 0 0 r
.55195 .73747 m .55167 .73753 L .55195 .73747 L F
.55195 .73747 m .55195 .73747 L .55196 .73747 L F
.55195 .73747 m .55078 .73763 L .55196 .73747 L F
.658 .966 .79 r
.54969 .73785 m .55235 .7374 L .54973 .73734 L F
.54891 .73829 m .54973 .73734 L .54863 .73732 L F
.849 .968 .645 r
.54925 .73811 m .54914 .73829 L .54925 .73815 L F
.658 .966 .79 r
.54947 .74025 m .54973 .73734 L .54891 .73829 L F
.811 .759 .805 r
.54891 .73829 m .5481 .74007 L .54914 .73829 L F
.5459 .73824 m .54767 .73971 L .54891 .73829 L F
.54767 .73971 m .5481 .74007 L .54891 .73829 L F
.816 .581 .583 r
.5459 .73824 m .54843 .73828 L .54863 .73732 L F
.54827 .739 m .54897 .7385 L .54863 .73732 L F
.849 .968 .645 r
.54925 .73815 m .5481 .74007 L .54937 .73967 L F
.54914 .73829 m .5481 .74007 L .54925 .73815 L F
.553 .658 .906 r
.54939 .74055 m .5459 .73824 L .54932 .73934 L F
.816 .581 .583 r
.54817 .73951 m .54851 .73908 L .54827 .739 L F
.54851 .73908 m .54897 .7385 L .54827 .739 L F
.811 .759 .805 r
.5459 .73824 m .54914 .73829 L .54925 .73811 L F
.816 .581 .583 r
.5459 .73824 m .54817 .73951 L .54843 .73828 L F
.54817 .73951 m .54947 .74025 L .54897 .7385 L F
.553 .658 .906 r
.54932 .73934 m .5459 .73824 L .54925 .73811 L F
.281 0 .281 r
.30273 .67475 m .30048 .67714 L .30226 .67672 L F
.518 .233 .421 r
.30447 .67628 m .30273 .67475 L .30226 .67672 L F
.30447 .67628 m .30495 .67442 L .30273 .67475 L F
0 0 .511 r
.58308 .73073 m .58139 .73262 L .58087 .73148 L F
.58308 .73073 m .58258 .73412 L .58139 .73262 L F
.206 .242 .679 r
.28061 .61902 m .27962 .62012 L .28133 .62191 L F
.381 .275 .608 r
.27962 .62012 m .27983 .62256 L .28133 .62191 L F
.114 .664 .704 r
.46384 .72646 m .46594 .72613 L .46711 .72595 L F
.093 0 0 r
.46594 .72613 m .46928 .72577 L .46711 .72595 L F
.3 0 0 r
.45132 .78401 m .44986 .78508 L .44765 .78522 L F
.168 0 0 r
.45199 .78471 m .45132 .78401 L .4536 .7838 L F
.45199 .78471 m .44986 .78508 L .45132 .78401 L F
.508 .758 .986 r
.30926 .60535 m .31066 .60652 L .30733 .60576 L F
.309 .657 .971 r
.3111 .60549 m .31066 .60652 L .30926 .60535 L F
.432 .458 .787 r
.3111 .60549 m .31052 .60879 L .31066 .60652 L F
.89 .68 .613 r
.73026 .72353 m .72856 .72591 L .72852 .72274 L F
.73026 .72353 m .72994 .72613 L .72856 .72591 L F
.659 .112 0 r
.57768 .74029 m .57976 .74193 L .58159 .74217 L F
.922 .847 .751 r
.58159 .74217 m .58396 .74037 L .58342 .74162 L F
.58159 .74217 m .58162 .7392 L .58396 .74037 L F
.58159 .74217 m .57976 .74193 L .58162 .7392 L F
.663 .558 .726 r
.58443 .74494 m .58159 .74217 L .58342 .74162 L F
.311 .756 .962 r
.3499 .64943 m .35345 .64983 L .35129 .64949 L F
.924 .871 .442 r
.6148 .68231 m .61456 .68174 L .61553 .67986 L F
.748 .696 .154 r
.61553 .67986 m .61552 .67958 L .61596 .67667 L F
.758 .836 .379 r
.61553 .67986 m .61456 .68174 L .61552 .67958 L F
.447 .204 .452 r
.33059 .6846 m .32995 .68749 L .32797 .68742 L F
.507 .265 .482 r
.3326 .68432 m .32995 .68749 L .33059 .6846 L F
.544 .368 .592 r
.39648 .75317 m .3986 .7529 L .39869 .75055 L F
.528 .419 .674 r
.39648 .75317 m .39888 .75578 L .3986 .7529 L F
.39648 .75317 m .3969 .75633 L .39888 .75578 L F
.414 .52 .857 r
.39712 .78611 m .3984 .78887 L .3998 .78786 L F
.735 .814 .913 r
.39752 .79067 m .3998 .78786 L .3984 .78887 L F
.543 .596 .856 r
.27683 .61179 m .2784 .61467 L .2803 .61433 L F
0 .347 .691 r
.29129 .60049 m .28984 .59993 L .28803 .59915 L F
.172 0 0 r
.45188 .77208 m .44697 .77375 L .44962 .77382 L F
.151 0 0 r
.45188 .77208 m .45171 .77335 L .45337 .77202 L F
.45188 .77208 m .44962 .77382 L .45171 .77335 L F
.683 .576 .729 r
.63835 .61711 m .64209 .61764 L .64069 .61452 L F
.69 .542 .681 r
.63978 .62029 m .64209 .61764 L .63835 .61711 L F
.71 .552 .672 r
.63622 .61957 m .63978 .62029 L .63835 .61711 L F
.254 .752 .688 r
.59117 .74452 m .59174 .74431 L .59347 .74372 L F
0 0 .077 r
.59174 .74431 m .59125 .74643 L .59276 .74392 L F
.59174 .74431 m .59276 .74392 L .59329 .74304 L F
.254 .752 .688 r
.58992 .74496 m .59174 .74431 L .59117 .74452 L F
.484 .219 .437 r
.40097 .68276 m .40049 .68477 L .39843 .68515 L F
.419 .161 .413 r
.4025 .68417 m .40097 .68276 L .403 .68228 L F
.4025 .68417 m .40049 .68477 L .40097 .68276 L F
.24 .173 .578 r
.73454 .59682 m .73291 .59529 L .73617 .59562 L F
.703 .242 .154 r
.73617 .59562 m .73858 .5975 L .73454 .59682 L F
.417 .029 .192 r
.34814 .67589 m .34456 .67865 L .34598 .67664 L F
.528 .915 .926 r
.51253 .79557 m .51638 .79466 L .51429 .79525 L F
.025 0 0 r
.51802 .79331 m .51429 .79525 L .51638 .79466 L F
.591 .179 .23 r
.47648 .77645 m .48002 .77528 L .47805 .77577 L F
.796 .975 .907 r
.30744 .72813 m .30662 .72882 L .30906 .72876 L F
.5 .839 .998 r
.30954 .72768 m .30744 .72813 L .30906 .72876 L F
.107 .38 .84 r
.30906 .72876 m .31065 .72957 L .30954 .72768 L F
.5 .839 .998 r
.30954 .72768 m .30744 .72813 L .30906 .72876 L F
.58 .269 .407 r
.47389 .73694 m .47379 .73946 L .47162 .73901 L F
.47389 .73694 m .47525 .73682 L .47379 .73946 L F
.695 .807 .935 r
.41486 .65784 m .41848 .65786 L .41697 .6574 L F
.784 .963 .652 r
.30959 .74129 m .30917 .74258 L .31128 .73974 L F
.346 .218 .56 r
.39421 .76956 m .39572 .76666 L .39379 .76713 L F
.547 .14 .222 r
.42243 .73615 m .42606 .73438 L .4237 .73415 L F
.359 .506 .869 r
.66812 .60969 m .66973 .60825 L .66753 .60794 L F
.66812 .60969 m .67112 .6114 L .66973 .60825 L F
.635 .462 .631 r
.60187 .74347 m .60107 .7441 L .59896 .74553 L F
.725 .989 .838 r
.55215 .70894 m .54858 .71186 L .5513 .71029 L F
0 .05 .593 r
.5513 .71029 m .55261 .71139 L .55215 .70894 L F
.5513 .71029 m .55325 .71243 L .55261 .71139 L F
.579 .24 .359 r
.72201 .71225 m .71888 .71444 L .72121 .71401 L F
.72201 .71225 m .71893 .71305 L .71888 .71444 L F
.403 0 .084 r
.72121 .71401 m .72444 .71221 L .72201 .71225 L F
.485 .335 .602 r
.40267 .74492 m .40457 .74201 L .40264 .74252 L F
.165 0 .269 r
.62576 .68787 m .6251 .68978 L .6232 .69018 L F
.136 0 .165 r
.6251 .68978 m .62268 .69238 L .6232 .69018 L F
.603 .45 .647 r
.6951 .71391 m .69659 .71489 L .69682 .7126 L F
.62 .442 .619 r
.69449 .71575 m .69659 .71489 L .6951 .71391 L F
.542 .472 .727 r
.39222 .77527 m .39522 .77739 L .39531 .775 L F
.39222 .77527 m .39324 .77784 L .39522 .77739 L F
.067 .14 .632 r
.69953 .72576 m .70003 .72893 L .70111 .72758 L F
.729 .241 .083 r
.70341 .73072 m .70238 .73112 L .70003 .72893 L F
.172 .298 .752 r
.70003 .72893 m .70238 .73112 L .70111 .72758 L F
.999 .826 .49 r
.61529 .63913 m .61487 .64185 L .61423 .6406 L F
.61423 .6406 m .61487 .64185 L .61529 .63913 L F
.89 .815 .767 r
.72327 .60292 m .72357 .60586 L .7224 .60509 L F
.164 .269 .727 r
.67814 .59678 m .67714 .59864 L .67615 .59495 L F
.349 0 0 r
.67863 .59946 m .68006 .60021 L .67889 .59958 L F
.67863 .59946 m .67889 .59958 L .67714 .59864 L F
.67863 .59946 m .67714 .59864 L .67814 .59678 L F
.863 .868 .841 r
.67844 .59938 m .67863 .59946 L .67867 .5993 L F
.67521 .60043 m .67863 .59946 L .67844 .59938 L F
.826 .992 .741 r
.57241 .71816 m .57226 .71906 L .57304 .71801 L F
0 0 .38 r
.57241 .71816 m .57282 .72101 L .57226 .71906 L F
.691 .97 .927 r
.69491 .59663 m .69378 .59766 L .69216 .59862 L F
.773 .391 .332 r
.69216 .59862 m .69423 .59995 L .6918 .60061 L F
.476 .52 .824 r
.55554 .73327 m .55387 .73476 L .55273 .73188 L F
.496 .556 .846 r
.55554 .73327 m .55596 .73494 L .55387 .73476 L F
.52 .423 .685 r
.60021 .72798 m .60072 .73169 L .59865 .73177 L F
.538 .489 .75 r
.60165 .73352 m .59865 .73177 L .60072 .73169 L F
.571 .169 .24 r
.57493 .70409 m .57715 .70548 L .57907 .70295 L F
.753 .389 .366 r
.57907 .70295 m .57715 .70548 L .58108 .70587 L F
.26 .723 .948 r
.29807 .6016 m .29481 .60116 L .29682 .60094 L F
.342 .706 .984 r
.29878 .60079 m .29807 .6016 L .29682 .60094 L F
.29878 .60079 m .29976 .60147 L .29807 .6016 L F
.479 .561 .861 r
.30143 .60425 m .29807 .6016 L .29976 .60147 L F
.524 .301 .517 r
.56524 .6937 m .56484 .69594 L .56257 .69625 L F
.317 .118 .445 r
.56685 .69348 m .56484 .69594 L .56524 .6937 L F
.502 .857 .991 r
.33095 .826 m .33046 .82702 L .32831 .82488 L F
.33095 .826 m .33235 .82647 L .33046 .82702 L F
.33095 .826 m .33046 .82702 L .32932 .82714 L F
.33095 .826 m .33235 .82647 L .33046 .82702 L F
.927 .708 .587 r
.6376 .65263 m .63622 .64992 L .63586 .65313 L F
.937 .869 .745 r
.6358 .65497 m .6376 .65263 L .63586 .65313 L F
.826 .704 .73 r
.60063 .70383 m .60355 .70225 L .60361 .70146 L F
.574 .22 .331 r
.60063 .70383 m .60262 .70503 L .60355 .70225 L F
.405 .176 .45 r
.60355 .70225 m .6056 .70105 L .60361 .70146 L F
.60355 .70225 m .60544 .70381 L .6056 .70105 L F
.502 .151 .304 r
.60355 .70225 m .60262 .70503 L .60544 .70381 L F
.368 .188 .501 r
.27786 .62551 m .27957 .62489 L .27983 .62256 L F
.345 .137 .448 r
.27922 .62705 m .27786 .62551 L .27724 .62754 L F
.27922 .62705 m .27957 .62489 L .27786 .62551 L F
.515 .301 .527 r
.32797 .68742 m .32914 .6904 L .32527 .69035 L F
.552 .32 .517 r
.33027 .68998 m .32797 .68742 L .32995 .68749 L F
.33027 .68998 m .32914 .6904 L .32797 .68742 L F
.576 .403 .611 r
.32527 .69035 m .32588 .69529 L .32328 .69366 L F
.496 .332 .588 r
.33012 .69235 m .32803 .69512 L .32911 .69459 L F
.3295 .69317 m .32902 .69437 L .32803 .69512 L F
.538 .377 .61 r
.32899 .69445 m .32588 .69529 L .32527 .69035 L F
.32911 .69459 m .32892 .69463 L .32899 .69445 L F
.496 .332 .588 r
.32915 .69427 m .3284 .69492 L .32803 .69512 L F
.568 .476 .711 r
.32888 .69466 m .32803 .69512 L .32596 .69552 L F
.32911 .69459 m .32803 .69512 L .32888 .69466 L F
.496 .332 .588 r
.3284 .69492 m .3282 .69509 L .32803 .69512 L F
.33007 .69359 m .32911 .69435 L .32915 .69427 L F
.32911 .69435 m .3282 .69509 L .32915 .69427 L F
.56 .405 .627 r
.33012 .69235 m .32911 .69459 L .32911 .69435 L F
.496 .332 .588 r
.33012 .69235 m .32902 .69437 L .3295 .69317 L F
.56 .405 .627 r
.33012 .69235 m .32911 .69435 L .32914 .6904 L F
.538 .377 .61 r
.32892 .69463 m .32588 .69529 L .32899 .69445 L F
.496 .332 .588 r
.33012 .69235 m .33007 .69359 L .32902 .69437 L F
.538 .377 .61 r
.32911 .69459 m .32899 .69445 L .32911 .69435 L F
.496 .332 .588 r
.33007 .69359 m .33002 .6948 L .3282 .69509 L F
.538 .377 .61 r
.32911 .69435 m .32527 .69035 L .32914 .6904 L F
.32899 .69445 m .32527 .69035 L .32911 .69435 L F
.392 .096 .339 r
.28526 .64693 m .28458 .64955 L .28264 .64968 L F
.398 .159 .431 r
.28526 .64693 m .28748 .64442 L .28705 .64624 L F
.255 0 .242 r
.28705 .64624 m .28458 .64955 L .28526 .64693 L F
.584 .449 .664 r
.29411 .68787 m .29647 .688 L .2962 .68516 L F
.547 .366 .588 r
.29449 .69069 m .29647 .688 L .29411 .68787 L F
.076 0 0 r
.34202 .72816 m .33848 .72958 L .34014 .72894 L F
.481 .89 .77 r
.49836 .71298 m .49946 .7121 L .50001 .71153 L F
.49836 .71298 m .49653 .71366 L .49946 .7121 L F
0 .045 .608 r
.57075 .71501 m .57007 .71482 L .56869 .71387 L F
.57075 .71501 m .57191 .71704 L .57007 .71482 L F
.63 .89 .564 r
.67708 .60518 m .67614 .60645 L .67842 .60378 L F
.661 .569 .741 r
.67614 .60645 m .67833 .60665 L .67842 .60378 L F
.312 .274 .655 r
.67896 .60636 m .67833 .60665 L .67842 .60378 L F
.524 .711 .957 r
.67614 .60645 m .67896 .60636 L .67708 .60518 L F
.47 .75 .99 r
.67896 .60636 m .67833 .60665 L .67614 .60645 L F
.75 .481 .525 r
.6138 .66358 m .61417 .66579 L .61258 .66311 L F
.625 .459 .637 r
.5911 .70989 m .59396 .70965 L .5931 .70703 L F
.738 .52 .599 r
.5931 .70703 m .59615 .70965 L .59619 .70726 L F
.5931 .70703 m .59396 .70965 L .59615 .70965 L F
0 .16 .697 r
.73758 .59184 m .73941 .5954 L .7382 .59297 L F
.617 .474 .665 r
.57967 .73678 m .57949 .74119 L .57768 .74029 L F
.676 .192 .095 r
.57949 .74119 m .57976 .74193 L .57768 .74029 L F
.891 .809 .761 r
.58027 .67666 m .58058 .67938 L .58191 .67763 L F
.358 .486 .852 r
.31337 .73711 m .31393 .73754 L .31471 .73605 L F
.31393 .73754 m .31492 .7366 L .31471 .73605 L F
.376 .499 .855 r
.31471 .73605 m .3158 .739 L .31686 .73804 L F
.123 0 0 r
.31471 .73605 m .31769 .73391 L .31483 .73419 L F
.31471 .73605 m .31549 .73583 L .31769 .73391 L F
.31549 .73583 m .31634 .73557 L .31701 .73475 L F
.31549 .73583 m .31701 .73475 L .31769 .73391 L F
.376 .499 .855 r
.31471 .73605 m .31686 .73804 L .31634 .73557 L F
.839 .739 .753 r
.31259 .73516 m .3154 .73613 L .31197 .73656 L F
.3154 .73613 m .31539 .73614 L .31197 .73656 L F
.797 .748 .808 r
.31023 .73759 m .31128 .73974 L .31159 .73799 L F
.332 .347 .726 r
.31197 .73656 m .31128 .73974 L .31023 .73759 L F
.686 .701 .859 r
.31197 .73656 m .31023 .73759 L .30881 .73651 L F
.358 .486 .852 r
.31393 .73754 m .3158 .739 L .31492 .7366 L F
.623 .537 .737 r
.31542 .73614 m .31285 .73984 L .31197 .73656 L F
.684 .704 .862 r
.31045 .73408 m .31197 .73656 L .30881 .73651 L F
.266 .482 .881 r
.31259 .73516 m .31197 .73656 L .31045 .73408 L F
.839 .739 .753 r
.31259 .73516 m .31062 .73833 L .31436 .73662 L F
.3154 .73613 m .31542 .73614 L .31539 .73614 L F
.31517 .73605 m .31436 .73662 L .31542 .73614 L F
.31259 .73516 m .31436 .73662 L .31517 .73605 L F
.675 .315 .356 r
.61258 .66311 m .61124 .66521 L .60894 .66326 L F
.815 .493 .444 r
.61258 .66311 m .61417 .66579 L .61124 .66521 L F
.982 .823 .61 r
.72953 .73886 m .7306 .7397 L .7312 .7373 L F
.588 .53 .757 r
.6957 .72294 m .69829 .72255 L .69769 .72071 L F
.65 .557 .736 r
.6957 .72294 m .69953 .72576 L .69829 .72255 L F
.513 .314 .548 r
.40686 .73935 m .40917 .73891 L .40703 .73703 L F
.602 .297 .425 r
.40703 .73703 m .40917 .73891 L .40954 .73719 L F
.112 .664 .781 r
.36755 .67112 m .36573 .67112 L .36368 .67126 L F
.629 .601 .803 r
.53397 .73442 m .53661 .73426 L .53476 .72987 L F
.59 .32 .475 r
.53397 .73442 m .53603 .7363 L .53661 .73426 L F
.501 .37 .634 r
.30048 .67714 m .3025 .67906 L .30226 .67672 L F
.30048 .67714 m .30066 .67953 L .3025 .67906 L F
.694 .385 .448 r
.40954 .73719 m .4123 .73854 L .41281 .73711 L F
.634 .467 .639 r
.4123 .73854 m .41491 .73655 L .41281 .73711 L F
0 0 0 r
.42118 .78889 m .41832 .78967 L .41681 .79007 L F
.42213 .78883 m .41832 .78967 L .42118 .78889 L F
.387 .005 .187 r
.35971 .70667 m .36184 .70629 L .363 .7042 L F
.17 0 .071 r
.363 .7042 m .36365 .70546 L .36486 .70337 L F
.363 .7042 m .36184 .70629 L .36365 .70546 L F
.608 .515 .723 r
.60207 .73676 m .60015 .7394 L .59984 .7372 L F
.056 .618 .783 r
.71838 .58298 m .722 .58318 L .71985 .58366 L F
.274 .35 .76 r
.56219 .72349 m .56376 .72249 L .56141 .72046 L F
.581 .405 .608 r
.56219 .72349 m .56507 .72552 L .56376 .72249 L F
.56219 .72349 m .56286 .72604 L .56507 .72552 L F
.401 .058 .264 r
.67614 .58392 m .67829 .58342 L .67922 .5809 L F
.554 .233 .378 r
.67829 .58342 m .68172 .58071 L .67922 .5809 L F
.755 .573 .65 r
.31285 .73984 m .30959 .74129 L .31128 .73974 L F
.447 .853 .675 r
.70047 .57984 m .69916 .58078 L .70157 .57937 L F
.70047 .57984 m .69831 .58122 L .69916 .58078 L F
.965 .742 .552 r
.53742 .7365 m .53603 .7363 L .53661 .73426 L F
.507 .343 .593 r
.53624 .73845 m .53603 .7363 L .53742 .7365 L F
.816 .337 0 r
.46402 .73939 m .46636 .74178 L .46474 .74142 L F
.493 .899 .923 r
.46474 .74142 m .46636 .74178 L .46835 .74082 L F
.582 .598 .834 r
.46729 .7422 m .46835 .74082 L .46636 .74178 L F
.4 .219 .517 r
.28748 .64442 m .28931 .64162 L .28889 .6438 L F
.293 .078 .406 r
.28875 .64644 m .28748 .64442 L .28889 .6438 L F
.28875 .64644 m .28705 .64624 L .28748 .64442 L F
.549 .399 .63 r
.6128 .70689 m .61335 .70958 L .61079 .7098 L F
.12 .346 .811 r
.60554 .73999 m .6077 .74151 L .60705 .7426 L F
.42 .402 .733 r
.6077 .74151 m .60646 .74472 L .60705 .7426 L F
.776 .715 .795 r
.41361 .6658 m .41169 .66858 L .41041 .66568 L F
.61 .483 .683 r
.41483 .6666 m .41169 .66858 L .41361 .6658 L F
.569 .421 .641 r
.41416 .67073 m .41169 .66858 L .41483 .6666 L F
.41416 .67073 m .412 .67124 L .41169 .66858 L F
.435 0 .023 r
.47466 .72489 m .47678 .72492 L .47509 .72429 L F
.469 0 .025 r
.45652 .74453 m .45202 .74469 L .45619 .74278 L F
.648 .501 .67 r
.54166 .78185 m .54419 .78155 L .54381 .78049 L F
.529 .792 .993 r
.27524 .59742 m .27481 .59883 L .27328 .59784 L F
.27524 .59742 m .27676 .59839 L .27481 .59883 L F
.1 0 .112 r
.32455 .65802 m .32208 .66062 L .32361 .65958 L F
.281 0 .253 r
.32361 .65958 m .32631 .65709 L .32455 .65802 L F
0 0 .129 r
.56959 .70904 m .56787 .71289 L .5686 .70941 L F
.526 .487 .756 r
.32181 .70313 m .32047 .7055 L .31955 .70148 L F
.818 .867 .884 r
.60313 .74198 m .60107 .7441 L .60187 .74347 L F
.395 0 0 r
.38194 .79869 m .3856 .79913 L .38254 .7983 L F
.417 .713 .985 r
.38738 .79944 m .38254 .7983 L .3856 .79913 L F
.563 .164 .243 r
.36368 .67126 m .36022 .67285 L .36158 .67166 L F
.491 .672 .945 r
.70114 .59331 m .70505 .59505 L .70437 .59394 L F
0 0 0 r
.70505 .59505 m .70288 .59852 L .70434 .59709 L F
.324 .597 .944 r
.70437 .59394 m .70505 .59505 L .70627 .59423 L F
0 0 0 r
.70627 .59423 m .70505 .59505 L .70434 .59709 L F
.583 .618 .852 r
.40356 .66269 m .40289 .66577 L .40164 .66288 L F
.40356 .66269 m .40494 .66541 L .40289 .66577 L F
.201 0 .171 r
.36532 .71512 m .36435 .71747 L .36295 .71725 L F
.202 0 .049 r
.36435 .71747 m .36247 .7182 L .36295 .71725 L F
.64 .632 .826 r
.69546 .602 m .6918 .60061 L .69423 .59995 L F
.025 0 0 r
.37498 .66958 m .37138 .67054 L .37261 .67098 L F
.919 .668 .541 r
.61811 .67138 m .61621 .67105 L .61618 .66857 L F
.95 .827 .687 r
.61811 .67138 m .61581 .67338 L .61621 .67105 L F
.61811 .67138 m .61703 .6742 L .61581 .67338 L F
.361 0 .206 r
.60027 .64771 m .59744 .64955 L .59966 .64898 L F
.489 .191 .387 r
.59966 .64898 m .6021 .64699 L .60027 .64771 L F
.458 .564 .875 r
.30241 .60245 m .30143 .60425 L .29976 .60147 L F
.528 .653 .914 r
.30241 .60245 m .30382 .60445 L .30143 .60425 L F
.606 .568 .785 r
.58683 .74449 m .58443 .74494 L .58342 .74162 L F
.908 .768 .278 r
.66691 .59803 m .66631 .59947 L .66764 .5975 L F
.66691 .59803 m .66666 .60069 L .66631 .59947 L F
.725 .587 .701 r
.6352 .62801 m .63878 .62831 L .6373 .62513 L F
.727 .557 .66 r
.63855 .63055 m .63878 .62831 L .6352 .62801 L F
.629 .403 .555 r
.6174 .63868 m .61991 .63865 L .61979 .63671 L F
.656 .446 .587 r
.61991 .63865 m .62303 .63605 L .61979 .63671 L F
0 0 .518 r
.67734 .61973 m .67804 .62065 L .67762 .61947 L F
.006 0 0 r
.6839 .60213 m .68103 .60351 L .68292 .60135 L F
.678 .872 .972 r
.68527 .6004 m .6839 .60213 L .68292 .60135 L F
.68527 .6004 m .6863 .60119 L .6839 .60213 L F
.563 .375 .584 r
.38091 .68255 m .38309 .6823 L .38309 .67984 L F
.59 .44 .646 r
.38309 .67984 m .38568 .67966 L .38528 .67696 L F
.462 .226 .47 r
.38309 .6823 m .38568 .67966 L .38309 .67984 L F
.677 .588 .748 r
.69727 .60052 m .69546 .602 L .69423 .59995 L F
.683 .523 .662 r
.59074 .71215 m .59396 .70965 L .5911 .70989 L F
.793 .852 .895 r
.45796 .76646 m .45513 .76687 L .45771 .76439 L F
.391 0 0 r
.45513 .76687 m .45759 .76698 L .45796 .76646 L F
.728 .7 .824 r
.45771 .76439 m .45513 .76687 L .45791 .7649 L F
.45771 .76439 m .45791 .7649 L .45817 .76471 L F
.15 .336 .795 r
.45778 .76496 m .4584 .76615 L .45796 .76646 L F
.45771 .76439 m .45797 .76505 L .45778 .76496 L F
.45797 .76505 m .4584 .76615 L .45778 .76496 L F
.36 .238 .576 r
.45817 .76471 m .45807 .7651 L .45917 .76561 L F
.15 .336 .795 r
.45791 .7649 m .45873 .76592 L .4584 .76615 L F
0 0 0 r
.45917 .76561 m .45759 .76698 L .45796 .76646 L F
.36 .238 .576 r
.45807 .7651 m .45759 .76698 L .45917 .76561 L F
.638 .512 .693 r
.45513 .76687 m .45759 .76698 L .45807 .7651 L F
.45791 .7649 m .45807 .7651 L .45817 .76471 L F
.45513 .76687 m .45807 .7651 L .45791 .7649 L F
.15 .336 .795 r
.45771 .76439 m .45917 .76561 L .45873 .76592 L F
.45771 .76439 m .45873 .76592 L .45791 .7649 L F
.901 .751 .686 r
.57053 .6983 m .57157 .7013 L .57305 .69792 L F
.674 .518 .666 r
.58258 .73412 m .58505 .73833 L .57967 .73678 L F
0 0 .511 r
.58308 .73073 m .58357 .73328 L .58258 .73412 L F
.074 .224 .716 r
.58357 .73328 m .58437 .736 L .58258 .73412 L F
.029 .211 .716 r
.58437 .736 m .58363 .7359 L .58258 .73412 L F
.968 .773 .587 r
.58357 .73328 m .58304 .73569 L .58437 .736 L F
.58357 .73328 m .58304 .73569 L .58437 .736 L F
.558 .006 0 r
.58304 .73569 m .58508 .73609 L .58437 .736 L F
.58508 .73609 m .58625 .73631 L .58437 .736 L F
.029 .211 .716 r
.58437 .736 m .58505 .73833 L .58363 .7359 L F
.711 .739 .873 r
.30156 .72779 m .30034 .72883 L .29991 .72758 L F
.94 .588 .318 r
.50441 .78929 m .50616 .78993 L .50589 .79081 L F
.718 .64 .77 r
.64069 .61452 m .64409 .61456 L .6428 .61148 L F
.722 .594 .712 r
.64069 .61452 m .64209 .61764 L .64409 .61456 L F
.759 .659 .751 r
.64409 .61456 m .6462 .61202 L .6428 .61148 L F
.28 .103 .454 r
.59398 .73448 m .59387 .73677 L .59544 .73371 L F
.546 .39 .621 r
.41006 .67398 m .40993 .67622 L .40797 .67645 L F
.451 .125 .32 r
.40993 .67622 m .40706 .67889 L .40797 .67645 L F
.76 .638 .726 r
.6352 .62801 m .6373 .62513 L .63556 .62587 L F
.754 .647 .742 r
.6373 .62513 m .63947 .62217 L .63758 .62313 L F
.551 .897 .666 r
.56143 .67753 m .56234 .67658 L .56304 .67619 L F
.596 .949 .893 r
.55029 .6874 m .55016 .6867 L .55105 .68678 L F
0 0 .424 r
.55029 .6874 m .55182 .69009 L .55016 .6867 L F
.309 .213 .58 r
.55029 .6874 m .55029 .69256 L .55182 .69009 L F
.66 .13 0 r
.48217 .77629 m .48548 .77726 L .48344 .77576 L F
.591 .404 .597 r
.32596 .69552 m .32328 .69366 L .32588 .69529 L F
.32596 .69552 m .32434 .69618 L .32328 .69366 L F
.49 .326 .585 r
.3986 .7529 m .40058 .7501 L .39869 .75055 L F
.66 .793 .946 r
.58087 .73148 m .57832 .73274 L .57716 .73107 L F
.03 .204 .71 r
.56815 .73747 m .56993 .73823 L .56785 .7361 L F
.56815 .73747 m .57002 .73957 L .56993 .73823 L F
.433 .203 .463 r
.3809 .68488 m .38309 .6823 L .38091 .68255 L F
.622 .452 .63 r
.47727 .73427 m .47725 .73694 L .47525 .73682 L F
.47727 .73427 m .47725 .73694 L .47525 .73682 L F
.46 .321 .604 r
.47935 .73626 m .47725 .73694 L .47727 .73427 L F
.47935 .73626 m .47725 .73694 L .47727 .73427 L F
.778 .371 .28 r
.5846 .75888 m .58348 .76042 L .58159 .75807 L F
.574 .134 .167 r
.58663 .75923 m .58348 .76042 L .5846 .75888 L F
.545 .29 .481 r
.61593 .64395 m .61384 .64465 L .61344 .64683 L F
.849 .864 .852 r
.32465 .73434 m .32535 .73552 L .32719 .73443 L F
.32465 .73434 m .32719 .73443 L .3258 .73487 L F
.863 .812 .798 r
.32719 .73443 m .32594 .73496 L .32576 .73488 L F
.881 .803 .768 r
.3231 .73615 m .32503 .73748 L .32535 .73552 L F
.404 .647 .956 r
.32145 .73373 m .32535 .73552 L .32515 .73518 L F
.881 .803 .768 r
.3231 .73615 m .32535 .73552 L .32145 .73373 L F
.863 .812 .798 r
.32528 .73523 m .32503 .73748 L .3231 .73615 L F
.32719 .73443 m .326 .73611 L .32528 .73523 L F
.326 .73611 m .32503 .73748 L .32528 .73523 L F
.321 .089 .397 r
.32667 .73662 m .32503 .73748 L .32719 .73443 L F
.863 .812 .798 r
.32683 .73596 m .3231 .73615 L .32667 .73662 L F
.32719 .73443 m .32528 .73523 L .32683 .73596 L F
.32528 .73523 m .3231 .73615 L .32683 .73596 L F
.404 .647 .956 r
.32337 .73435 m .32515 .73518 L .32496 .73486 L F
.32145 .73373 m .32515 .73518 L .32337 .73435 L F
.3245 .73431 m .32496 .73486 L .32465 .73434 L F
.32145 .73373 m .32496 .73486 L .3245 .73431 L F
.863 .812 .798 r
.32719 .73443 m .32667 .73662 L .32594 .73496 L F
.414 .171 .435 r
.3288 .73549 m .32667 .73662 L .32712 .73472 L F
.3288 .73549 m .32712 .73472 L .32719 .73443 L F
.309 0 0 r
.33059 .73622 m .32986 .73598 L .3288 .73549 L F
.32986 .73598 m .3275 .73518 L .3288 .73549 L F
.699 .162 0 r
.3275 .73518 m .32366 .73291 L .32588 .73491 L F
.32601 .73497 m .32588 .73491 L .32594 .73496 L F
.3275 .73518 m .32588 .73491 L .32601 .73497 L F
.849 .864 .852 r
.32482 .73442 m .3258 .73487 L .32576 .73488 L F
.32465 .73434 m .3258 .73487 L .32482 .73442 L F
.414 .171 .435 r
.3288 .73549 m .32719 .73443 L .32905 .73383 L F
.701 .586 .724 r
.63947 .62217 m .63622 .61957 L .63758 .62313 L F
.63947 .62217 m .63978 .62029 L .63622 .61957 L F
.675 .957 .946 r
.7157 .72613 m .71353 .72763 L .71388 .72723 L F
.528 .65 .912 r
.71719 .72893 m .71353 .72763 L .7157 .72613 L F
.568 .274 .429 r
.67703 .58778 m .67714 .58909 L .67485 .58965 L F
.583 .241 .355 r
.68035 .58738 m .67714 .58909 L .67703 .58778 L F
.706 .725 .865 r
.51051 .72899 m .51066 .73154 L .51305 .73029 L F
.003 .39 .847 r
.55409 .71326 m .5561 .71381 L .55325 .71243 L F
.55409 .71326 m .55687 .71492 L .5561 .71381 L F
.882 .974 .836 r
.39095 .7805 m .39192 .7779 L .39324 .77784 L F
.279 .782 .829 r
.39324 .77784 m .39364 .77751 L .39522 .77739 L F
.39324 .77784 m .39192 .7779 L .39364 .77751 L F
.479 .178 .377 r
.32102 .66251 m .32361 .65958 L .32208 .66062 L F
.901 .95 .6 r
.56538 .69183 m .56663 .69063 L .56574 .68991 L F
.766 .929 .94 r
.56574 .68991 m .56663 .69063 L .56937 .68882 L F
.677 .967 .926 r
.67485 .58965 m .673 .59087 L .67132 .59097 L F
.603 .535 .751 r
.67485 .58965 m .6755 .59254 L .673 .59087 L F
.608 .515 .723 r
.60207 .73676 m .60246 .73899 L .60015 .7394 L F
.622 .538 .739 r
.60313 .74198 m .60015 .7394 L .60246 .73899 L F
.292 0 .215 r
.36625 .71666 m .36532 .71512 L .36742 .71453 L F
.36625 .71666 m .36435 .71747 L .36532 .71512 L F
.267 0 .255 r
.28931 .64162 m .29193 .63893 L .29162 .64047 L F
.348 .161 .479 r
.29374 .63571 m .29326 .6383 L .29193 .63893 L F
.33 .125 .444 r
.29193 .63893 m .29284 .64001 L .29162 .64047 L F
.29193 .63893 m .29326 .6383 L .29284 .64001 L F
.599 .459 .663 r
.58162 .7392 m .57949 .74119 L .57967 .73678 L F
.719 .573 .69 r
.58505 .73833 m .58162 .7392 L .57967 .73678 L F
.543 .476 .73 r
.70157 .57937 m .7033 .58015 L .70237 .57581 L F
.70157 .57937 m .70237 .57581 L .70186 .57902 L F
.454 .865 .709 r
.70186 .57902 m .70047 .57984 L .70157 .57937 L F
.608 .418 .598 r
.70157 .57937 m .70228 .58206 L .7033 .58015 L F
0 .175 .658 r
.73258 .5846 m .73537 .58692 L .7336 .58514 L F
.466 .224 .462 r
.30754 .67141 m .3094 .67088 L .30973 .6688 L F
.479 .306 .568 r
.3094 .67088 m .31129 .66801 L .30973 .6688 L F
.136 0 .058 r
.30921 .61462 m .3083 .61639 L .30672 .61705 L F
.356 .269 .618 r
.31059 .61106 m .31077 .61407 L .30921 .61462 L F
.228 0 .157 r
.31077 .61407 m .3083 .61639 L .30921 .61462 L F
.583 .241 .355 r
.68035 .58738 m .68002 .58908 L .67714 .58909 L F
.307 .431 .824 r
.68035 .58738 m .68297 .58822 L .68002 .58908 L F
.712 .537 0 r
.68606 .59806 m .68604 .59795 L .6851 .59749 L F
.68606 .59806 m .6863 .60119 L .68604 .59795 L F
.306 .799 .844 r
.52128 .78265 m .52352 .78209 L .52488 .78202 L F
.454 0 0 r
.52352 .78209 m .52701 .78218 L .52488 .78202 L F
.223 .069 .451 r
.62089 .69529 m .61882 .69851 L .61876 .6963 L F
0 .017 .582 r
.491 .77795 m .49037 .7775 L .48904 .77694 L F
.491 .77795 m .49231 .78014 L .49037 .7775 L F
.516 .357 .604 r
.39531 .76141 m .39731 .76101 L .39725 .7586 L F
.539 .414 .658 r
.39557 .76394 m .39731 .76101 L .39531 .76141 L F
.545 .471 .723 r
.38207 .67418 m .38384 .67386 L .38348 .67144 L F
.591 .559 .788 r
.38207 .67418 m .38528 .67696 L .38384 .67386 L F
.567 .424 .647 r
.60134 .72005 m .59927 .72439 L .59897 .72043 L F
.546 .544 .803 r
.69609 .58617 m .69511 .59052 L .6939 .58709 L F
.792 .833 .883 r
.59191 .72814 m .59127 .72621 L .5897 .72813 L F
.672 .667 .836 r
.59191 .72814 m .59334 .72495 L .59127 .72621 L F
.59191 .72814 m .59389 .72712 L .59334 .72495 L F
.882 .974 .836 r
.39095 .7805 m .38962 .78088 L .39192 .7779 L F
.245 .751 .708 r
.39074 .78049 m .38962 .78088 L .39095 .7805 L F
.575 .847 .996 r
.39405 .78321 m .39487 .78231 L .39209 .78138 L F
.39487 .78231 m .39518 .78197 L .39397 .78174 L F
.39402 .78202 m .39366 .78168 L .39209 .78138 L F
.787 .579 .62 r
.38821 .77917 m .39192 .7779 L .38962 .78088 L F
.575 .847 .996 r
.39487 .78231 m .39397 .78174 L .39366 .78168 L F
.39487 .78231 m .39366 .78168 L .39402 .78202 L F
.416 .5 .837 r
.39095 .7805 m .39405 .78321 L .39209 .78138 L F
.554 .129 .188 r
.39518 .78197 m .39177 .78253 L .39209 .78138 L F
.787 .579 .62 r
.38821 .77917 m .39346 .78182 L .39325 .78128 L F
.3893 .77879 m .39325 .78128 L .39192 .7779 L F
.38821 .77917 m .39325 .78128 L .3893 .77879 L F
.918 .625 .473 r
.39166 .77977 m .39346 .78182 L .39166 .77981 L F
.39192 .7779 m .39325 .78128 L .39166 .77977 L F
.39325 .78128 m .39346 .78182 L .39166 .77977 L F
.818 .629 .647 r
.39074 .78049 m .3914 .78082 L .38821 .77917 L F
.3914 .78082 m .39346 .78182 L .39081 .78048 L F
.951 .602 .296 r
.39101 .78067 m .39077 .78049 L .39095 .7805 L F
.818 .629 .647 r
.3914 .78082 m .39081 .78048 L .38821 .77917 L F
.951 .602 .296 r
.39209 .78138 m .39177 .78253 L .39074 .78049 L F
.39209 .78138 m .39101 .78067 L .39095 .7805 L F
.39101 .78067 m .39074 .78049 L .39077 .78049 L F
.818 .629 .647 r
.39074 .78049 m .39177 .78253 L .39346 .78182 L F
.569 .47 .702 r
.39177 .78253 m .39166 .77981 L .39346 .78182 L F
.421 0 0 r
.39518 .78197 m .39351 .78297 L .39177 .78253 L F
.588 .925 .716 r
.39589 .78118 m .39511 .78176 L .39518 .78197 L F
.39451 .78226 m .39351 .78297 L .39403 .78266 L F
.39511 .78178 m .39403 .78266 L .39518 .78197 L F
.624 .463 .644 r
.39166 .77981 m .39462 .78217 L .39589 .78118 L F
.588 .925 .716 r
.39511 .78176 m .39462 .78217 L .39511 .78178 L F
.39462 .78217 m .39403 .78266 L .39511 .78178 L F
.624 .463 .644 r
.39462 .78217 m .3947 .78224 L .39589 .78118 L F
.451 .078 .239 r
.39451 .78226 m .39351 .78297 L .3947 .78224 L F
.39177 .78253 m .39351 .78297 L .39451 .78226 L F
.588 .925 .716 r
.39511 .78176 m .39351 .78297 L .39451 .78226 L F
.569 .47 .702 r
.39171 .78099 m .39459 .78219 L .39166 .77981 L F
.39459 .78219 m .3947 .78224 L .39462 .78217 L F
.39459 .78219 m .39462 .78217 L .39166 .77981 L F
.39171 .78118 m .39259 .78149 L .39171 .78099 L F
.39259 .78149 m .3947 .78224 L .39171 .78099 L F
.39177 .78253 m .39335 .78237 L .39171 .78118 L F
.39335 .78237 m .3947 .78224 L .39171 .78118 L F
0 0 .135 r
.60861 .699 m .60999 .69792 L .61015 .69594 L F
.584 .836 .471 r
.60788 .70058 m .60861 .699 L .60718 .70099 L F
.60788 .70058 m .60999 .69792 L .60861 .699 L F
.175 0 0 r
.50724 .70569 m .51013 .70639 L .5081 .70698 L F
.441 .063 .224 r
.44098 .74737 m .43935 .74964 L .43716 .74992 L F
.348 0 .163 r
.44141 .74917 m .44098 .74737 L .44281 .74752 L F
.44141 .74917 m .43935 .74964 L .44098 .74737 L F
.596 .699 .915 r
.38238 .653 m .38034 .65354 L .37902 .6519 L F
.616 .457 .643 r
.31978 .69928 m .31955 .70148 L .31775 .70254 L F
.508 .362 .618 r
.32166 .70134 m .31978 .69928 L .32173 .69867 L F
.32166 .70134 m .31955 .70148 L .31978 .69928 L F
.316 .567 .928 r
.71869 .61997 m .72013 .61902 L .71762 .61923 L F
.71869 .61997 m .72106 .62033 L .72013 .61902 L F
.24 0 0 r
.72612 .7198 m .72248 .71965 L .72384 .71948 L F
.748 .715 .821 r
.56685 .69348 m .56819 .69632 L .56484 .69594 L F
.534 .606 .871 r
.571 .6944 m .56819 .69632 L .56685 .69348 L F
.149 0 0 r
.51776 .78428 m .52128 .78265 L .51925 .7836 L F
.025 0 0 r
.37498 .66958 m .37343 .67022 L .37138 .67054 L F
0 0 0 r
.37622 .66997 m .37343 .67022 L .37498 .66958 L F
.768 .996 .859 r
.65473 .60224 m .65344 .60359 L .65409 .60197 L F
.042 .191 .694 r
.65344 .60359 m .65518 .60542 L .65409 .60197 L F
.755 .781 .874 r
.72786 .62094 m .72981 .61981 L .7268 .6195 L F
.512 .259 .468 r
.38198 .70388 m .37968 .7061 L .38009 .70459 L F
.483 0 0 r
.59026 .75908 m .58913 .76016 L .58663 .75923 L F
.585 .15 .181 r
.59265 .75892 m .58913 .76016 L .59026 .75908 L F
.445 .036 .169 r
.44842 .7452 m .44712 .74699 L .44497 .74725 L F
.718 .473 .554 r
.45059 .74467 m .44712 .74699 L .44842 .7452 L F
.638 .35 .464 r
.47725 .73694 m .47379 .73946 L .47525 .73682 L F
.063 .444 .878 r
.69647 .59954 m .69378 .59766 L .6961 .5963 L F
.411 .428 .768 r
.69834 .59722 m .69647 .59954 L .6961 .5963 L F
.596 .485 .698 r
.69958 .5995 m .69647 .59954 L .69834 .59722 L F
.69958 .5995 m .69727 .60052 L .69647 .59954 L F
.768 .571 .631 r
.56754 .70436 m .56715 .70672 L .57024 .70666 L F
.688 .306 .319 r
.56715 .70672 m .56959 .70904 L .57024 .70666 L F
.482 .11 .256 r
.57024 .70666 m .5716 .708 L .57239 .70604 L F
.57024 .70666 m .56959 .70904 L .5716 .708 L F
.527 .315 .535 r
.60555 .71273 m .60519 .7149 L .60347 .7153 L F
.64 .418 .565 r
.6084 .71425 m .60555 .71273 L .60903 .71242 L F
.6084 .71425 m .60519 .7149 L .60555 .71273 L F
.56 .361 .568 r
.59619 .70726 m .59804 .70688 L .59822 .7042 L F
.436 .201 .458 r
.59804 .70688 m .60063 .70383 L .59822 .7042 L F
.072 0 0 r
.42886 .78833 m .42548 .78902 L .42672 .78865 L F
.078 .238 .727 r
.57191 .71704 m .57241 .71816 L .57304 .71801 L F
.557 .018 0 r
.48341 .78243 m .48119 .78254 L .47976 .78212 L F
.32 0 0 r
.48341 .78243 m .48458 .78266 L .48119 .78254 L F
.381 .635 .954 r
.69203 .59117 m .69319 .59268 L .69398 .59121 L F
.686 .975 .908 r
.69398 .59121 m .69319 .59268 L .69462 .59147 L F
.444 .372 .681 r
.69462 .59147 m .69491 .59663 L .69319 .59268 L F
.686 .975 .908 r
.69398 .59121 m .69319 .59268 L .69462 .59147 L F
.444 .372 .681 r
.69462 .59147 m .69491 .59663 L .69319 .59268 L F
.821 .645 .665 r
.63662 .64704 m .63679 .64465 L .63555 .64406 L F
.888 .777 .733 r
.63679 .64465 m .63691 .64125 L .63555 .64406 L F
.549 0 0 r
.73563 .71534 m .73661 .71547 L .73375 .71428 L F
.687 .193 0 r
.73747 .717 m .73661 .71547 L .73563 .71534 L F
.73747 .717 m .73815 .71753 L .73661 .71547 L F
.224 0 .03 r
.48155 .73589 m .48272 .73403 L .48473 .73335 L F
.655 .709 .887 r
.72871 .60232 m .73175 .60337 L .73084 .60044 L F
.698 .195 .039 r
.72871 .60232 m .73135 .60464 L .73175 .60337 L F
.947 .799 .663 r
.73084 .60044 m .73176 .6033 L .73205 .59952 L F
.217 .296 .731 r
.73205 .59952 m .73333 .59778 L .73306 .59927 L F
.947 .799 .663 r
.73084 .60044 m .73205 .59952 L .73306 .59927 L F
.676 .674 .841 r
.72994 .59768 m .73084 .60044 L .73306 .59927 L F
.72974 .59758 m .73084 .60044 L .72994 .59768 L F
.947 .799 .663 r
.73084 .60044 m .73175 .60337 L .73176 .6033 L F
.922 .538 .144 r
.73175 .60337 m .73135 .60464 L .73239 .60549 L F
.486 .258 .493 r
.40015 .68684 m .39843 .68515 L .40049 .68477 L F
.40015 .68684 m .39812 .68732 L .39843 .68515 L F
.667 .833 .963 r
.32097 .73695 m .32503 .73748 L .3231 .73615 L F
.62 .802 .969 r
.3231 .73615 m .32503 .73748 L .32667 .73662 L F
.667 .888 .529 r
.63334 .67154 m .63169 .67347 L .63253 .67413 L F
.63334 .67154 m .63333 .67133 L .63169 .67347 L F
.733 .697 .159 r
.63364 .66952 m .63333 .67133 L .63334 .67154 L F
.367 0 0 r
.70583 .73097 m .70238 .73112 L .70341 .73072 L F
0 0 0 r
.35041 .72428 m .35011 .72363 L .3523 .72333 L F
.35041 .72428 m .34874 .72518 L .35011 .72363 L F
.693 .926 .968 r
.6961 .5963 m .69378 .59766 L .69491 .59663 L F
.677 .506 .647 r
.69894 .71758 m .70037 .71535 L .69659 .71489 L F
.69894 .71758 m .69974 .71813 L .70037 .71535 L F
.666 .784 .937 r
.49964 .72274 m .50101 .72399 L .50327 .72255 L F
.49964 .72274 m .50101 .72399 L .50327 .72255 L F
.369 .644 .962 r
.3778 .65053 m .37699 .65172 L .3754 .65027 L F
.3778 .65053 m .37902 .6519 L .37699 .65172 L F
.481 .268 .513 r
.60347 .7153 m .60326 .71733 L .60124 .71773 L F
.532 .374 .612 r
.60326 .71733 m .60134 .72005 L .60124 .71773 L F
.36 .135 .431 r
.29571 .63314 m .29532 .63448 L .29374 .63571 L F
.385 .171 .462 r
.29374 .63571 m .2955 .63763 L .29326 .6383 L F
.29374 .63571 m .29532 .63448 L .2955 .63763 L F
.786 .892 .92 r
.70288 .59852 m .69958 .5995 L .70172 .59903 L F
.601 .939 .754 r
.70434 .59709 m .70288 .59852 L .70172 .59903 L F
.826 .659 .675 r
.7033 .58015 m .70434 .57706 L .70237 .57581 L F
.306 0 0 r
.57372 .71062 m .57444 .71104 L .57264 .7097 L F
.57372 .71062 m .57588 .71134 L .57444 .71104 L F
.454 .058 .198 r
.57635 .71005 m .57588 .71134 L .57372 .71062 L F
.055 0 0 r
.47883 .72423 m .48243 .72267 L .48049 .72343 L F
.838 .382 0 r
.67552 .61029 m .67605 .6096 L .67669 .61128 L F
.775 .387 .321 r
.41491 .73655 m .4168 .73857 L .41822 .73696 L F
.65 .878 .518 r
.41822 .73696 m .41897 .73574 L .42041 .73666 L F
.41822 .73696 m .4168 .73857 L .41897 .73574 L F
0 0 0 r
.52808 .78856 m .52636 .78882 L .52595 .78888 L F
.351 0 .13 r
.46965 .77367 m .47321 .77118 L .47133 .77231 L F
.533 .333 .555 r
.40058 .7501 m .4028 .74743 L .40081 .74787 L F
.504 .253 .468 r
.71858 .721 m .71611 .72404 L .71517 .72322 L F
.56 .422 .649 r
.71611 .72404 m .7157 .72613 L .71517 .72322 L F
.346 .218 .56 r
.39421 .76956 m .39594 .76922 L .39572 .76666 L F
.373 .326 .676 r
.39421 .76956 m .39619 .77154 L .39594 .76922 L F
.387 .328 .669 r
.39474 .77185 m .39619 .77154 L .39421 .76956 L F
.567 .555 .8 r
.60021 .72798 m .59751 .72658 L .59973 .72584 L F
.856 .638 .606 r
.61644 .66632 m .61421 .66809 L .61417 .66579 L F
.61644 .66632 m .61618 .66857 L .61421 .66809 L F
.482 .797 .999 r
.70798 .73224 m .71011 .73215 L .70927 .732 L F
.70798 .73224 m .70927 .732 L .70795 .73227 L F
.70798 .73224 m .70795 .73227 L .70755 .73236 L F
.461 0 0 r
.70583 .73097 m .70811 .73211 L .70798 .73224 L F
.70811 .73211 m .70913 .73262 L .70798 .73224 L F
.211 .64 .952 r
.70913 .73262 m .71011 .73215 L .70798 .73224 L F
.70913 .73262 m .7109 .73278 L .71011 .73215 L F
.53 .789 .992 r
.28021 .59903 m .27676 .59839 L .27874 .59806 L F
.393 .735 .991 r
.28211 .59886 m .28021 .59903 L .27874 .59806 L F
0 0 0 r
.49256 .78326 m .49252 .78326 L .49444 .78217 L F
.49101 .78417 m .49252 .78326 L .49256 .78326 L F
0 .569 .71 r
.49019 .78322 m .49248 .78326 L .49252 .78326 L F
.49248 .78326 m .4935 .78328 L .49252 .78326 L F
.296 .53 .908 r
.4935 .78328 m .49568 .78374 L .49444 .78217 L F
0 .166 .611 r
.52468 .70996 m .52755 .71199 L .52642 .71183 L F
0 .262 .755 r
.52837 .71407 m .52642 .71183 L .52755 .71199 L F
.982 .882 .526 r
.57076 .68741 m .5702 .68679 L .57133 .68523 L F
.566 .123 .157 r
.56815 .68637 m .5702 .68679 L .57133 .68523 L F
.991 .755 .479 r
.57133 .68523 m .5702 .68679 L .57018 .68426 L F
.982 .882 .526 r
.57076 .68741 m .5702 .68679 L .57133 .68523 L F
.613 .38 .539 r
.57363 .68538 m .57076 .68741 L .57133 .68523 L F
.724 .508 .597 r
.55689 .73724 m .55745 .73946 L .55416 .73932 L F
.532 .562 .832 r
.55923 .7363 m .55689 .73724 L .55596 .73494 L F
.361 .233 .569 r
.55923 .7363 m .55745 .73946 L .55689 .73724 L F
.519 .139 .26 r
.44133 .73074 m .44364 .73068 L .44474 .72865 L F
.471 .119 .286 r
.44364 .73068 m .44691 .72815 L .44474 .72865 L F
.451 .167 .39 r
.37968 .7061 m .37664 .70933 L .37733 .70667 L F
.664 .587 .759 r
.69449 .71575 m .69894 .71758 L .69659 .71489 L F
.547 .14 .222 r
.42243 .73615 m .4247 .73623 L .42606 .73438 L F
.544 .136 .219 r
.42606 .73438 m .4247 .73623 L .42782 .73569 L F
.534 .143 .247 r
.42606 .73438 m .42782 .73569 L .4283 .73444 L F
.467 .674 .954 r
.33041 .70648 m .32959 .70799 L .32829 .70675 L F
.33041 .70648 m .33181 .70804 L .32959 .70799 L F
.367 0 0 r
.45676 .78281 m .45747 .78383 L .45504 .78409 L F
.45676 .78281 m .45891 .78298 L .45747 .78383 L F
.912 .669 .557 r
.51623 .73131 m .51444 .7334 L .51554 .73034 L F
.51623 .73131 m .51631 .73411 L .51444 .7334 L F
.613 .427 .607 r
.51785 .73339 m .51631 .73411 L .51623 .73131 L F
.854 .963 .874 r
.56702 .70358 m .56754 .70436 L .56954 .70233 L F
.856 .774 .269 r
.56712 .70556 m .56754 .70436 L .56702 .70358 L F
.489 0 0 r
.56659 .70516 m .5668 .70534 L .56712 .70556 L F
.856 .774 .269 r
.56712 .70556 m .56715 .70672 L .56732 .7057 L F
.068 .261 .752 r
.56946 .70764 m .56715 .70672 L .56712 .70556 L F
.489 0 0 r
.5668 .70534 m .56946 .70764 L .56712 .70556 L F
.856 .774 .269 r
.56712 .70556 m .56732 .7057 L .56754 .70436 L F
.884 .761 .72 r
.73142 .61676 m .73086 .61373 L .7302 .61538 L F
.893 .819 .768 r
.72919 .61712 m .73142 .61676 L .7302 .61538 L F
.72919 .61712 m .72981 .61981 L .73142 .61676 L F
.453 .334 .627 r
.39725 .7586 m .39888 .75578 L .3969 .75633 L F
.553 .468 .713 r
.42517 .772 m .4231 .77235 L .42268 .76923 L F
0 0 .389 r
.3264 .82526 m .32752 .82542 L .32831 .82488 L F
.3264 .82526 m .32648 .82689 L .32752 .82542 L F
.099 .332 .804 r
.55911 .71771 m .55969 .71649 L .55687 .71492 L F
.55911 .71771 m .55993 .71765 L .55969 .71649 L F
.816 .639 .662 r
.63844 .65785 m .6358 .65497 L .63584 .65741 L F
.847 .645 .63 r
.637 .6593 m .63844 .65785 L .63584 .65741 L F
.992 .749 .457 r
.71888 .59712 m .72003 .59997 L .7196 .59813 L F
.71888 .59712 m .72003 .59997 L .7196 .59813 L F
.442 0 0 r
.45891 .78298 m .46229 .78252 L .46105 .78269 L F
0 0 0 r
.46439 .78233 m .46105 .78269 L .46229 .78252 L F
.552 .548 .804 r
.38659 .78679 m .38865 .78652 L .38527 .78459 L F
.663 .194 .128 r
.70209 .71961 m .70571 .72036 L .70278 .71885 L F
.718 .566 .682 r
.63302 .6307 m .6352 .62801 L .63315 .62837 L F
.672 .5 .644 r
.63302 .6307 m .63545 .63036 L .6352 .62801 L F
.727 .557 .66 r
.63855 .63055 m .6352 .62801 L .63545 .63036 L F
.452 .368 .671 r
.424 .76651 m .42268 .76923 L .42183 .76696 L F
.424 .76651 m .42438 .76876 L .42268 .76923 L F
.553 .468 .713 r
.42517 .772 m .42268 .76923 L .42438 .76876 L F
.18 0 .103 r
.57573 .66647 m .57311 .66869 L .5751 .66757 L F
.203 0 .031 r
.5751 .66757 m .57785 .66585 L .57573 .66647 L F
.616 .212 .255 r
.60262 .66243 m .59885 .66247 L .59998 .66069 L F
.611 .219 .275 r
.6018 .661 m .60262 .66243 L .59998 .66069 L F
0 .246 .679 r
.54011 .7224 m .53856 .72161 L .5383 .71994 L F
.54011 .7224 m .54131 .72328 L .53856 .72161 L F
.299 .082 .408 r
.29754 .63239 m .29732 .62976 L .2995 .62968 L F
.319 .097 .412 r
.29744 .6347 m .29571 .63314 L .29754 .63239 L F
.29744 .6347 m .29532 .63448 L .29571 .63314 L F
.729 .836 .388 r
.29948 .72841 m .30156 .72779 L .29991 .72758 L F
.579 .831 .993 r
.5141 .73468 m .51631 .73411 L .51444 .7334 L F
.896 .543 .369 r
.51631 .73411 m .51444 .7334 L .5141 .73468 L F
.498 .278 .51 r
.39383 .69059 m .39359 .69277 L .39155 .6932 L F
.428 .214 .484 r
.39602 .68783 m .39569 .69008 L .39383 .69059 L F
.494 .299 .545 r
.39569 .69008 m .39359 .69277 L .39383 .69059 L F
0 0 0 r
.69518 .57477 m .69146 .57785 L .6938 .57754 L F
.659 .348 .434 r
.6938 .57754 m .69703 .57552 L .69518 .57477 L F
0 0 0 r
.31717 .66364 m .31761 .66413 L .31908 .66305 L F
.554 .361 .574 r
.31645 .66518 m .31536 .66742 L .31775 .66685 L F
.31599 .66459 m .31569 .66596 L .31645 .66518 L F
.31569 .66596 m .31536 .66742 L .31645 .66518 L F
0 0 0 r
.31717 .66364 m .31615 .66515 L .31722 .6644 L F
.31755 .66407 m .31722 .6644 L .31761 .66413 L F
.31717 .66364 m .31722 .6644 L .31755 .66407 L F
.432 .572 .894 r
.36879 .64803 m .36797 .64983 L .36643 .64727 L F
.505 .66 .93 r
.36879 .64803 m .37 .64968 L .36797 .64983 L F
.518 .472 .745 r
.39474 .77185 m .39531 .775 L .39721 .77464 L F
.475 .297 .559 r
.39531 .775 m .39522 .77739 L .39721 .77464 L F
0 0 .373 r
.6148 .68231 m .61416 .68527 L .61529 .6838 L F
0 0 .316 r
.61356 .68739 m .61529 .6838 L .61416 .68527 L F
.537 .646 .904 r
.70525 .61161 m .7083 .61351 L .70762 .61095 L F
.643 .724 .907 r
.7083 .61351 m .70992 .61069 L .70762 .61095 L F
.7083 .61351 m .71105 .61269 L .70992 .61069 L F
.502 .199 .384 r
.34041 .67942 m .33937 .68211 L .33723 .68238 L F
.534 .231 .399 r
.34197 .68093 m .34041 .67942 L .34233 .67915 L F
.34197 .68093 m .33937 .68211 L .34041 .67942 L F
.659 .391 .503 r
.58853 .71249 m .59166 .71389 L .59074 .71215 L F
.58853 .71249 m .58856 .71431 L .59166 .71389 L F
.492 .295 .541 r
.42426 .75755 m .42231 .75601 L .42407 .7556 L F
.42426 .75755 m .42215 .75804 L .42231 .75601 L F
.782 .991 .887 r
.72754 .73735 m .72552 .73901 L .72731 .73705 L F
.432 .334 .644 r
.72552 .73901 m .72743 .73994 L .72731 .73705 L F
.294 .457 .852 r
.72552 .73901 m .72749 .74098 L .72743 .73994 L F
.295 0 .243 r
.54147 .78557 m .5391 .78791 L .5397 .78631 L F
.44 0 .08 r
.57946 .70953 m .57588 .71134 L .57635 .71005 L F
.57946 .70953 m .57826 .71118 L .57588 .71134 L F
.578 .423 .635 r
.58117 .70703 m .58191 .70958 L .57946 .70953 L F
.32 0 0 r
.58191 .70958 m .57826 .71118 L .57946 .70953 L F
.578 .423 .635 r
.58117 .70703 m .58191 .70958 L .57946 .70953 L F
.128 0 0 r
.33691 .65044 m .3343 .65194 L .33643 .65112 L F
.471 .079 .214 r
.33643 .65112 m .33885 .65008 L .33691 .65044 L F
.61 .456 .648 r
.29162 .64047 m .28889 .6438 L .28931 .64162 L F
.931 .948 .779 r
.54271 .69618 m .54348 .69297 L .54478 .69374 L F
.493 0 0 r
.54478 .69374 m .54806 .69603 L .54723 .69336 L F
.54478 .69374 m .54687 .69532 L .54806 .69603 L F
.1 .312 .788 r
.54566 .69276 m .54687 .69532 L .54478 .69374 L F
.562 .782 .981 r
.51366 .70696 m .51013 .70639 L .51259 .70547 L F
.564 .685 .921 r
.51518 .70511 m .51366 .70696 L .51259 .70547 L F
.51518 .70511 m .51581 .70662 L .51366 .70696 L F
.728 .222 0 r
.57811 .69294 m .57529 .69002 L .57778 .69067 L F
.83 .821 .341 r
.57861 .68693 m .57778 .69067 L .58018 .68779 L F
.57861 .68693 m .57781 .68945 L .57778 .69067 L F
.992 .874 .607 r
.57781 .68945 m .57811 .69294 L .57778 .69067 L F
.196 0 0 r
.68957 .59048 m .69068 .59081 L .6896 .58892 L F
.68957 .59048 m .69203 .59117 L .69068 .59081 L F
.539 .909 .955 r
.70825 .57878 m .70713 .57979 L .70596 .5794 L F
.70825 .57878 m .70922 .57902 L .70713 .57979 L F
.256 0 0 r
.54307 .72518 m .54508 .72594 L .54614 .72634 L F
0 .295 .708 r
.54756 .72691 m .5487 .72769 L .54705 .72682 L F
.54756 .72691 m .54705 .72682 L .54614 .72634 L F
0 0 .535 r
.54784 .72655 m .54806 .72699 L .54756 .72691 L F
.793 .335 .153 r
.54756 .72691 m .55036 .7285 L .5487 .72769 L F
.161 .655 .916 r
.55036 .7285 m .54956 .72889 L .5487 .72769 L F
.793 .335 .153 r
.54764 .72696 m .54912 .72923 L .55036 .7285 L F
.54756 .72691 m .54912 .72923 L .54764 .72696 L F
.161 .655 .916 r
.55036 .7285 m .55267 .72912 L .54956 .72889 L F
.326 .375 .759 r
.55403 .73032 m .55273 .73188 L .55267 .72947 L F
.55403 .73032 m .55267 .72947 L .55267 .72912 L F
.43 .527 .856 r
.55403 .73032 m .55554 .73327 L .55273 .73188 L F
.473 .727 .981 r
.55654 .73182 m .55554 .73327 L .55403 .73032 L F
.622 .064 0 r
.55264 .73011 m .55615 .73165 L .55403 .73032 L F
.55615 .73165 m .55654 .73182 L .55403 .73032 L F
.642 .084 0 r
.55036 .7285 m .55403 .73032 L .55267 .72912 L F
.5529 .72976 m .55264 .73011 L .55403 .73032 L F
.55036 .7285 m .55264 .73011 L .5529 .72976 L F
0 0 0 r
.55264 .73011 m .55123 .73202 L .55212 .73082 L F
.55264 .73011 m .55212 .73082 L .55316 .72943 L F
.686 .183 .042 r
.54912 .72923 m .55264 .73011 L .55036 .7285 L F
.54 .101 .155 r
.54953 .73145 m .55264 .73011 L .54912 .72923 L F
.465 .4 .7 r
.55086 .72788 m .5499 .73044 L .54912 .72923 L F
.5499 .73044 m .54953 .73145 L .54912 .72923 L F
0 0 .535 r
.54806 .72699 m .54912 .72923 L .54756 .72691 L F
0 .295 .708 r
.54756 .72691 m .54614 .72634 L .54508 .72594 L F
.727 .771 .887 r
.67856 .62181 m .6798 .62307 L .68172 .62207 L F
.982 .893 .551 r
.54271 .69618 m .54192 .69859 L .54151 .69762 L F
.931 .948 .779 r
.54271 .69618 m .54203 .69538 L .54348 .69297 L F
.997 .858 .538 r
.54271 .69618 m .54151 .69762 L .54203 .69538 L F
.501 .275 .504 r
.2962 .68516 m .29822 .68479 L .29854 .68259 L F
.53 .358 .592 r
.29854 .68259 m .3006 .68218 L .30066 .67953 L F
.502 .276 .503 r
.29822 .68479 m .3006 .68218 L .29854 .68259 L F
.281 0 0 r
.44355 .7853 m .44226 .78589 L .4401 .7861 L F
.411 0 0 r
.44549 .78527 m .44226 .78589 L .44355 .7853 L F
.898 .887 .813 r
.67865 .61117 m .67777 .61245 L .67669 .61128 L F
.549 .337 .545 r
.60519 .7149 m .60326 .71733 L .60347 .7153 L F
.515 0 0 r
.52322 .70898 m .52468 .70996 L .52305 .70863 L F
.439 .375 .689 r
.38528 .67696 m .38646 .67434 L .38384 .67386 L F
.38528 .67696 m .38694 .67646 L .38646 .67434 L F
.432 .329 .637 r
.38528 .67696 m .38724 .67884 L .38694 .67646 L F
.38528 .67696 m .38568 .67966 L .38724 .67884 L F
.413 .082 .292 r
.33312 .65423 m .33643 .65112 L .3343 .65194 L F
.113 .641 .872 r
.58683 .74449 m .58871 .74458 L .58992 .74496 L F
.58683 .74449 m .58871 .74458 L .58992 .74496 L F
.658 .287 .331 r
.58871 .74458 m .59174 .74431 L .58992 .74496 L F
.514 .744 .978 r
.30926 .60535 m .30733 .60576 L .30591 .60442 L F
.917 .635 .494 r
.72221 .60898 m .72075 .61043 L .72125 .60816 L F
.72221 .60898 m .7223 .61123 L .72075 .61043 L F
.648 .609 .797 r
.42874 .77451 m .42645 .77535 L .42517 .772 L F
.467 .221 .457 r
.39155 .6932 m .39122 .6958 L .38914 .69614 L F
.403 .167 .439 r
.39303 .6952 m .39155 .6932 L .39359 .69277 L F
.39303 .6952 m .39122 .6958 L .39155 .6932 L F
.449 .429 .745 r
.69953 .72576 m .70037 .72215 L .69829 .72255 L F
.69953 .72576 m .7012 .72539 L .70037 .72215 L F
.067 .14 .632 r
.69953 .72576 m .70111 .72758 L .7012 .72539 L F
.816 .441 .345 r
.57018 .68426 m .56704 .68186 L .56954 .68271 L F
.643 .76 .934 r
.69639 .60924 m .69937 .60976 L .69875 .60841 L F
.577 .63 .868 r
.69937 .60976 m .70103 .60789 L .69875 .60841 L F
.69937 .60976 m .7013 .60949 L .70103 .60789 L F
.702 .664 .809 r
.71893 .72775 m .71719 .72893 L .7157 .72613 L F
.411 .205 .488 r
.61483 .70411 m .61454 .70639 L .6128 .70689 L F
.448 .3 .587 r
.6128 .70689 m .61406 .70784 L .61335 .70958 L F
.6128 .70689 m .61454 .70639 L .61406 .70784 L F
.401 .148 .412 r
.39812 .68732 m .39569 .69008 L .39602 .68783 L F
.498 .34 .597 r
.37709 .69045 m .37859 .69222 L .37878 .6897 L F
.37709 .69045 m .37675 .69279 L .37859 .69222 L F
.28 0 0 r
.55592 .69322 m .55246 .6952 L .55388 .69568 L F
.55592 .69322 m .55438 .69493 L .55246 .6952 L F
.764 .615 .694 r
.55388 .69568 m .55624 .696 L .55592 .69322 L F
.606 .486 .689 r
.55592 .69322 m .55846 .69293 L .5579 .69055 L F
0 0 0 r
.5579 .69055 m .55706 .6925 L .55592 .69322 L F
.464 .314 .592 r
.55624 .696 m .55846 .69293 L .55592 .69322 L F
0 0 0 r
.55706 .6925 m .55438 .69493 L .55592 .69322 L F
.278 0 .207 r
.59744 .64955 m .59875 .65087 L .59966 .64898 L F
.59744 .64955 m .59683 .65173 L .59875 .65087 L F
.248 .572 .94 r
.71705 .73344 m .71372 .73186 L .71626 .73227 L F
.774 .755 .836 r
.7268 .6195 m .72981 .61981 L .72919 .61712 L F
.745 .224 0 r
.71325 .58076 m .71504 .58281 L .71577 .58248 L F
.34 .61 .949 r
.40831 .79364 m .40873 .79242 L .40611 .79124 L F
.40831 .79364 m .40994 .79376 L .40873 .79242 L F
.598 .38 .556 r
.62537 .63602 m .62766 .63573 L .62773 .6335 L F
.67 .435 .556 r
.62766 .63573 m .63079 .63335 L .62773 .6335 L F
.417 .029 .192 r
.34814 .67589 m .3466 .67831 L .34456 .67865 L F
.341 0 .096 r
.35033 .67561 m .3466 .67831 L .34814 .67589 L F
.741 .604 .705 r
.63646 .63339 m .63855 .63055 L .63545 .63036 L F
.126 0 0 r
.71888 .71444 m .71666 .71508 L .71556 .71622 L F
.745 .409 .414 r
.55388 .69568 m .55599 .69824 L .55624 .696 L F
.464 .314 .592 r
.55624 .696 m .55855 .69585 L .55846 .69293 L F
.299 .032 .331 r
.55624 .696 m .55785 .69725 L .55855 .69585 L F
.55624 .696 m .55599 .69824 L .55785 .69725 L F
.441 .25 .524 r
.27983 .62256 m .28141 .6243 L .28133 .62191 L F
.27983 .62256 m .27957 .62489 L .28141 .6243 L F
.24 .173 .578 r
.73454 .59682 m .73333 .59778 L .73291 .59529 L F
.131 .672 .834 r
.41041 .66568 m .41251 .66562 L .41361 .6658 L F
.395 .843 .925 r
.41361 .6658 m .41487 .66502 L .41596 .66573 L F
.41361 .6658 m .41251 .66562 L .41487 .66502 L F
.291 .072 .4 r
.41596 .66573 m .41483 .6666 L .41361 .6658 L F
.697 .605 .75 r
.54723 .69336 m .54806 .69603 L .55002 .69384 L F
.515 .829 1 r
.54806 .69603 m .54687 .69532 L .54908 .69485 L F
.572 .42 .636 r
.54806 .69603 m .55041 .69599 L .55002 .69384 L F
.452 .736 .988 r
.54908 .69485 m .55041 .69599 L .54806 .69603 L F
.656 .736 .908 r
.3158 .739 m .31639 .73927 L .31858 .73883 L F
.556 .598 .851 r
.70114 .59331 m .70327 .59158 L .7011 .59196 L F
.70114 .59331 m .70437 .59394 L .70327 .59158 L F
.057 .17 .668 r
.54577 .70671 m .54625 .70534 L .54464 .70366 L F
0 0 .177 r
.54915 .70878 m .55005 .70775 L .54618 .70714 L F
.54611 .70723 m .54618 .70714 L .54585 .70709 L F
.54915 .70878 m .54618 .70714 L .54611 .70723 L F
.48 .546 .847 r
.54618 .70714 m .55005 .70775 L .54618 .70682 L F
.057 .17 .668 r
.54618 .70687 m .54625 .70707 L .54625 .7069 L F
.54577 .70671 m .54618 .70702 L .54618 .70687 L F
.54618 .70702 m .54625 .70707 L .54618 .70687 L F
.48 .546 .847 r
.54618 .70682 m .55005 .70775 L .54823 .70513 L F
.54585 .70709 m .54618 .70714 L .54618 .70702 L F
.367 .126 .41 r
.54585 .70709 m .54662 .70735 L .54618 .70702 L F
.54585 .70709 m .54618 .70702 L .54577 .70671 L F
.48 .546 .847 r
.54585 .70709 m .54618 .70702 L .54618 .70682 L F
.54585 .70709 m .54618 .70682 L .54662 .70735 L F
.54618 .70682 m .54823 .70513 L .54662 .70735 L F
.057 .17 .668 r
.54587 .70644 m .54625 .7069 L .54625 .70534 L F
.54577 .70671 m .54625 .7069 L .54587 .70644 L F
.54625 .70707 m .54662 .70735 L .54651 .70675 L F
.54625 .70707 m .54651 .70675 L .54625 .70534 L F
.593 .525 .748 r
.424 .76651 m .42183 .76696 L .42084 .76345 L F
.068 .052 .529 r
.61015 .69594 m .61145 .69478 L .61115 .69249 L F
0 0 .129 r
.61015 .69594 m .60999 .69792 L .61145 .69478 L F
.656 .446 .587 r
.61991 .63865 m .62311 .63854 L .62303 .63605 L F
.652 .476 .632 r
.6254 .63828 m .62303 .63605 L .62311 .63854 L F
.6254 .63828 m .62537 .63602 L .62303 .63605 L F
.043 .056 .546 r
.47517 .77185 m .47433 .7744 L .47564 .77253 L F
.47517 .77185 m .47564 .77412 L .47433 .7744 L F
.085 .251 .738 r
.47564 .77412 m .47648 .77645 L .47433 .7744 L F
.924 .828 .732 r
.57957 .67913 m .58058 .67938 L .58027 .67666 L F
.991 .796 .546 r
.57957 .67913 m .58 .6824 L .58058 .67938 L F
.892 .52 .326 r
.49367 .78024 m .49444 .78217 L .49548 .78102 L F
.531 0 0 r
.4966 .78231 m .49548 .78102 L .49444 .78217 L F
.4966 .78231 m .49787 .78222 L .49548 .78102 L F
.371 0 .095 r
.3541 .70937 m .35639 .70907 L .35772 .70718 L F
.062 0 0 r
.35772 .70718 m .35817 .70817 L .35971 .70667 L F
.35772 .70718 m .35639 .70907 L .35817 .70817 L F
.553 .345 .552 r
.30495 .67442 m .30723 .67415 L .30754 .67141 L F
.497 .296 .538 r
.30723 .67415 m .3094 .67088 L .30754 .67141 L F
.978 .702 .436 r
.35277 .85629 m .35408 .85924 L .35289 .85866 L F
.35277 .85629 m .35408 .85924 L .35289 .85866 L F
.946 .597 .314 r
.73167 .62822 m .72962 .62513 L .73105 .62527 L F
.209 .332 .771 r
.73383 .62626 m .73331 .62723 L .73105 .62527 L F
.475 .364 .648 r
.73331 .62723 m .73167 .62822 L .73105 .62527 L F
.209 .332 .771 r
.73383 .62626 m .73105 .62527 L .72962 .62513 L F
.546 .421 .661 r
.2962 .68516 m .29852 .68727 L .29822 .68479 L F
.2962 .68516 m .29647 .688 L .29852 .68727 L F
.294 .313 .71 r
.73246 .72757 m .73178 .73099 L .73025 .72763 L F
.73246 .72757 m .73289 .73056 L .73178 .73099 L F
.175 .134 .569 r
.73307 .73295 m .73178 .73099 L .73289 .73056 L F
.73307 .73295 m .73235 .73397 L .73178 .73099 L F
.54 .266 .448 r
.43354 .73353 m .43618 .73137 L .43381 .73147 L F
.637 .415 .565 r
.59392 .71206 m .59615 .70965 L .59396 .70965 L F
.59392 .71206 m .59626 .71195 L .59615 .70965 L F
.585 .477 .697 r
.59615 .70965 m .59804 .70688 L .59619 .70726 L F
.59615 .70965 m .59882 .7092 L .59804 .70688 L F
.539 .331 .547 r
.59626 .71195 m .59882 .7092 L .59615 .70965 L F
.193 0 0 r
.45986 .77515 m .46208 .77516 L .46324 .77484 L F
.1 0 0 r
.46208 .77516 m .46549 .77477 L .46324 .77484 L F
.774 .51 .535 r
.58827 .72577 m .5884 .72858 L .5897 .72813 L F
0 0 .1 r
.58827 .72577 m .58967 .72491 L .59034 .72304 L F
.752 .761 .86 r
.5897 .72813 m .58967 .72491 L .58827 .72577 L F
0 0 0 r
.52636 .78882 m .52379 .79019 L .52201 .79059 L F
.52571 .78948 m .52636 .78882 L .52687 .78877 L F
.52571 .78948 m .52379 .79019 L .52636 .78882 L F
.52808 .78856 m .52687 .78877 L .52636 .78882 L F
.421 .124 .353 r
.60033 .75337 m .5998 .75511 L .59771 .75563 L F
.331 .024 .285 r
.60235 .75273 m .5998 .75511 L .60033 .75337 L F
.394 .111 .361 r
.60323 .75103 m .60235 .75273 L .60033 .75337 L F
.505 .133 .268 r
.31129 .66801 m .3138 .66801 L .31472 .66612 L F
.217 0 .124 r
.31472 .66612 m .31599 .66459 L .31615 .66515 L F
.31472 .66612 m .31536 .66742 L .31599 .66459 L F
.31472 .66612 m .3138 .66801 L .31536 .66742 L F
.69 .554 .695 r
.63079 .63335 m .63302 .6307 L .63078 .63118 L F
.474 .751 .99 r
.29531 .5998 m .29481 .60116 L .29333 .60027 L F
.29531 .5998 m .29682 .60094 L .29481 .60116 L F
.511 .308 .54 r
.61781 .64085 m .61991 .63865 L .6174 .63868 L F
0 0 0 r
.4401 .7861 m .43898 .7865 L .43635 .78673 L F
.115 0 0 r
.44226 .78589 m .43898 .7865 L .4401 .7861 L F
.854 .963 .874 r
.56702 .70358 m .56954 .70233 L .56814 .70084 L F
.698 .749 .891 r
.56814 .70084 m .56954 .70233 L .57157 .7013 L F
.584 .346 .522 r
.42946 .75285 m .42739 .75462 L .42729 .75303 L F
.617 .214 .256 r
.4547 .72771 m .45718 .72799 L .45822 .72642 L F
.423 .006 .141 r
.45822 .72642 m .46006 .7271 L .46029 .72646 L F
.45822 .72642 m .45718 .72799 L .46006 .7271 L F
.89 .626 .111 r
.58108 .70587 m .58191 .70958 L .58117 .70703 L F
.54 .304 .507 r
.69381 .58485 m .6939 .58709 L .69136 .58734 L F
.528 .296 .506 r
.69609 .58617 m .6939 .58709 L .69381 .58485 L F
.613 .38 .539 r
.57363 .68538 m .57383 .68725 L .57076 .68741 L F
.606 .642 .86 r
.56286 .72604 m .56657 .72838 L .56507 .72552 L F
.259 .345 .762 r
.56657 .72838 m .568 .72704 L .56507 .72552 L F
.56657 .72838 m .5679 .72859 L .568 .72704 L F
.325 .11 .426 r
.56657 .72838 m .56631 .73039 L .5679 .72859 L F
.187 .431 .863 r
.39287 .78492 m .39276 .78635 L .39109 .78411 L F
.848 .97 .875 r
.39287 .78492 m .39222 .78708 L .39276 .78635 L F
.453 .334 .627 r
.39725 .7586 m .39901 .75829 L .39888 .75578 L F
.464 .383 .68 r
.39725 .7586 m .39945 .76065 L .39901 .75829 L F
.554 .387 .609 r
.39725 .7586 m .39731 .76101 L .39945 .76065 L F
.821 .645 .665 r
.63662 .64704 m .63555 .64406 L .63529 .64636 L F
.855 .694 .682 r
.63622 .64992 m .63662 .64704 L .63529 .64636 L F
.054 0 .054 r
.46231 .74124 m .46066 .74155 L .46214 .74028 L F
.325 .117 .436 r
.4626 .7436 m .46066 .74155 L .46231 .74124 L F
.4626 .7436 m .46101 .74415 L .46066 .74155 L F
0 0 0 r
.57311 .66869 m .57387 .66936 L .5751 .66757 L F
.57311 .66869 m .57224 .67042 L .57387 .66936 L F
.013 0 0 r
.70842 .71953 m .7113 .71789 L .7093 .71883 L F
.312 0 .167 r
.71946 .61535 m .72223 .61366 L .72038 .61388 L F
.511 .363 .616 r
.37892 .68793 m .38112 .68748 L .3809 .68488 L F
.473 .25 .494 r
.37878 .6897 m .38112 .68748 L .37892 .68793 L F
.544 .544 .805 r
.57601 .72313 m .57398 .72371 L .57282 .72101 L F
.318 .505 .883 r
.57692 .72561 m .57398 .72371 L .57601 .72313 L F
0 0 0 r
.49061 .71809 m .49158 .71737 L .49227 .71692 L F
.49061 .71809 m .4891 .71938 L .49158 .71737 L F
.523 .287 .499 r
.69769 .72071 m .69974 .71813 L .69894 .71758 L F
.546 .377 .604 r
.29226 .69328 m .29456 .69345 L .29449 .69069 L F
.624 .507 .699 r
.29234 .69574 m .29456 .69345 L .29226 .69328 L F
.526 .487 .756 r
.32181 .70313 m .31955 .70148 L .32166 .70134 L F
.544 .369 .595 r
.30066 .67953 m .30272 .68174 L .3025 .67906 L F
.30066 .67953 m .3006 .68218 L .30272 .68174 L F
.727 .892 .955 r
.72749 .74098 m .72953 .73886 L .72743 .73994 L F
.72749 .74098 m .7306 .7397 L .72953 .73886 L F
.227 0 0 r
.60764 .6489 m .61103 .64708 L .60821 .64724 L F
.60764 .6489 m .61064 .64786 L .61103 .64708 L F
.307 0 0 r
.61064 .64786 m .61344 .64683 L .61103 .64708 L F
.142 0 .206 r
.61716 .7013 m .61693 .70319 L .61483 .70411 L F
.341 .184 .518 r
.61693 .70319 m .61454 .70639 L .61483 .70411 L F
.637 .228 .252 r
.60408 .66241 m .6018 .661 L .60576 .66049 L F
.792 .497 .49 r
.60576 .66049 m .60675 .66315 L .60408 .66241 L F
.827 .513 .458 r
.60894 .66326 m .60675 .66315 L .60576 .66049 L F
.214 .031 .403 r
.61882 .69851 m .61911 .70083 L .61716 .7013 L F
0 0 .052 r
.61911 .70083 m .61693 .70319 L .61716 .7013 L F
.561 .234 .371 r
.58512 .71668 m .58642 .71748 L .58597 .71709 L F
.108 0 .009 r
.58435 .7163 m .58512 .71668 L .58613 .71478 L F
.068 0 0 r
.58613 .71478 m .58512 .71668 L .58735 .71486 L F
.835 .913 .889 r
.58735 .71486 m .58512 .71668 L .58435 .71568 L F
.561 .234 .371 r
.58512 .71668 m .58597 .71709 L .58435 .71568 L F
.108 0 .009 r
.58299 .71747 m .58512 .71668 L .58435 .7163 L F
.068 0 0 r
.58613 .71478 m .58735 .71486 L .58856 .71431 L F
.458 .304 .583 r
.30653 .74229 m .30826 .74267 L .30779 .73938 L F
.475 .159 .349 r
.30653 .74229 m .30713 .74384 L .30826 .74267 L F
.163 0 0 r
.42886 .78833 m .42757 .78852 L .43108 .78781 L F
.374 0 0 r
.39222 .78708 m .39062 .78712 L .38865 .78652 L F
.577 .388 .589 r
.38865 .78652 m .39156 .78643 L .39109 .78411 L F
.472 .336 .614 r
.39109 .78411 m .39192 .78608 L .39287 .78492 L F
.848 .97 .875 r
.39276 .78527 m .39156 .78643 L .39266 .78561 L F
.472 .336 .614 r
.39192 .78608 m .39206 .78641 L .39287 .78492 L F
.848 .97 .875 r
.39266 .78561 m .39156 .78652 L .39222 .78708 L F
.39156 .78652 m .39084 .78711 L .39108 .78711 L F
.39156 .78652 m .39108 .78711 L .39222 .78708 L F
.39156 .78643 m .39084 .78711 L .39266 .78561 L F
.539 .233 .398 r
.39156 .78643 m .39062 .78712 L .39206 .78641 L F
.38865 .78652 m .39062 .78712 L .39156 .78643 L F
.577 .388 .589 r
.39156 .78643 m .39206 .78641 L .39192 .78608 L F
.39156 .78643 m .39192 .78608 L .39109 .78411 L F
.848 .97 .875 r
.39287 .78492 m .39062 .78712 L .39084 .78711 L F
.39287 .78492 m .39084 .78711 L .39276 .78527 L F
.537 .642 .901 r
.3945 .65708 m .39853 .66003 L .39511 .65875 L F
.3945 .65708 m .39511 .65875 L .39514 .65868 L F
.662 .878 .979 r
.73331 .62723 m .73444 .62795 L .73167 .62822 L F
.534 .047 .044 r
.33885 .65008 m .34072 .6511 L .34232 .64993 L F
.363 0 .001 r
.34072 .6511 m .34436 .64942 L .34232 .64993 L F
.111 0 .263 r
.6065 .74698 m .60444 .74992 L .60498 .74808 L F
.508 .324 .567 r
.412 .67124 m .41191 .6738 L .41006 .67398 L F
.369 .175 .481 r
.41191 .6738 m .40993 .67622 L .41006 .67398 L F
.74 .411 .426 r
.60894 .66326 m .60601 .66472 L .60675 .66315 L F
.60894 .66326 m .60782 .66541 L .60601 .66472 L F
.664 .323 .386 r
.61124 .66521 m .60782 .66541 L .60894 .66326 L F
.287 .059 .383 r
.37027 .69888 m .37135 .7002 L .3718 .69818 L F
.37027 .69888 m .36973 .70105 L .37135 .7002 L F
.742 .611 .712 r
.65921 .59754 m .6608 .60091 L .66268 .598 L F
.545 .29 .481 r
.61593 .64395 m .61344 .64683 L .61559 .64629 L F
.583 .441 .654 r
.61593 .64395 m .61781 .64085 L .61487 .64185 L F
.61593 .64395 m .61819 .6434 L .61781 .64085 L F
.443 .103 .292 r
.61768 .6455 m .61593 .64395 L .61559 .64629 L F
.61768 .6455 m .61819 .6434 L .61593 .64395 L F
.67 .435 .556 r
.62766 .63573 m .63094 .63556 L .63079 .63335 L F
.661 .512 .671 r
.63311 .63313 m .63302 .6307 L .63079 .63335 L F
.732 .546 .64 r
.63094 .63556 m .63311 .63313 L .63079 .63335 L F
.364 0 0 r
.53219 .71848 m .53384 .71919 L .53491 .71948 L F
.625 .938 .959 r
.53491 .71948 m .53384 .71919 L .53402 .71911 L F
.286 0 0 r
.53258 .71848 m .53491 .71948 L .53581 .71984 L F
.625 .938 .959 r
.53491 .71948 m .53402 .71911 L .53612 .71814 L F
.286 0 0 r
.53581 .71984 m .53491 .71948 L .53629 .72005 L F
.339 .735 .983 r
.53711 .7192 m .53629 .72005 L .53491 .71948 L F
.53711 .7192 m .5383 .71994 L .53629 .72005 L F
.363 0 0 r
.45643 .77447 m .45986 .77515 L .45777 .77454 L F
.611 .447 .635 r
.32378 .69836 m .32166 .70134 L .32173 .69867 L F
.091 0 0 r
.58986 .66832 m .58609 .67037 L .58743 .67058 L F
.354 .125 .421 r
.73693 .71994 m .73476 .7227 L .73511 .7207 L F
.905 .979 .79 r
.49927 .7251 m .49841 .72769 L .49948 .72636 L F
0 0 0 r
.30779 .73938 m .30881 .73651 L .31023 .73759 L F
.30779 .73938 m .30825 .73854 L .30881 .73651 L F
.439 .291 .582 r
.30779 .73938 m .30959 .74129 L .30825 .73854 L F
.30779 .73938 m .30826 .74267 L .30959 .74129 L F
.623 .701 .901 r
.32637 .70677 m .32299 .70582 L .32465 .70477 L F
.457 .632 .93 r
.32705 .70521 m .32637 .70677 L .32465 .70477 L F
.32705 .70521 m .32829 .70675 L .32637 .70677 L F
.725 .595 .711 r
.63311 .63313 m .63545 .63036 L .63302 .6307 L F
.635 .912 .981 r
.43769 .77501 m .4345 .77538 L .43631 .77421 L F
.551 .908 .965 r
.44001 .77414 m .43769 .77501 L .43843 .77399 L F
.441 .778 .998 r
.43843 .77399 m .43769 .77501 L .43631 .77421 L F
.43843 .77399 m .43769 .77501 L .43631 .77421 L F
0 0 0 r
.50001 .71153 m .50125 .71104 L .50269 .70981 L F
.50001 .71153 m .49946 .7121 L .50125 .71104 L F
.684 .584 .738 r
.60554 .73999 m .60313 .74198 L .60246 .73899 L F
.238 0 .272 r
.58162 .7392 m .57976 .74193 L .57949 .74119 L F
.412 0 0 r
.72987 .58298 m .72719 .58152 L .72574 .58089 L F
.539 .414 .658 r
.39557 .76394 m .39759 .76357 L .39731 .76101 L F
.506 .371 .631 r
.39572 .76666 m .39759 .76357 L .39557 .76394 L F
.463 .037 .146 r
.49048 .73109 m .48934 .7328 L .48676 .73308 L F
.139 0 0 r
.49273 .73347 m .49048 .73109 L .49272 .73094 L F
.49273 .73347 m .48934 .7328 L .49048 .73109 L F
.62 .231 .286 r
.73269 .72611 m .73246 .72757 L .72994 .72613 L F
.143 0 .178 r
.73484 .72505 m .73246 .72757 L .73269 .72611 L F
.726 .543 .643 r
.73025 .72763 m .72856 .72591 L .72994 .72613 L F
.584 .297 .447 r
.72994 .72613 m .73246 .72757 L .73025 .72763 L F
0 0 0 r
.71902 .72189 m .71858 .721 L .72017 .7202 L F
.71902 .72189 m .71611 .72404 L .71858 .721 L F
.88 .446 .085 r
.57869 .75304 m .57779 .75263 L .57663 .75033 L F
.904 .517 .277 r
.58007 .75534 m .57779 .75263 L .57869 .75304 L F
.054 0 .054 r
.46231 .74124 m .46214 .74028 L .46402 .73939 L F
.816 .337 0 r
.46402 .73939 m .46474 .74142 L .46231 .74124 L F
.535 .698 .944 r
.43216 .77583 m .42874 .77451 L .43079 .77428 L F
.559 .716 .946 r
.4345 .77538 m .43216 .77583 L .43079 .77428 L F
.907 .875 .444 r
.63169 .67528 m .63253 .67413 L .63169 .67347 L F
.63169 .67528 m .63171 .67695 L .63253 .67413 L F
.958 .852 .695 r
.68604 .59795 m .6863 .60119 L .68527 .6004 L F
.518 .472 .745 r
.39474 .77185 m .39721 .77464 L .39619 .77154 L F
.549 .434 .675 r
.67714 .58909 m .6755 .59254 L .67485 .58965 L F
.67714 .58909 m .6778 .59217 L .6755 .59254 L F
.5 .428 .707 r
.67815 .59451 m .6755 .59254 L .6778 .59217 L F
.67815 .59451 m .67615 .59495 L .6755 .59254 L F
.807 .811 .854 r
.68321 .61638 m .68622 .6162 L .68576 .61388 L F
.828 .711 .735 r
.68425 .61961 m .68622 .6162 L .68321 .61638 L F
.886 .853 .805 r
.68576 .61388 m .68622 .6162 L .68833 .61301 L F
.363 .827 .757 r
.28356 .65089 m .28264 .64968 L .28458 .64955 L F
.28356 .65089 m .28187 .65165 L .28264 .64968 L F
.755 .745 .844 r
.65518 .60542 m .65564 .60824 L .65838 .60582 L F
.862 .923 .867 r
.68789 .61169 m .68833 .61301 L .68897 .61227 L F
.68789 .61169 m .68576 .61388 L .68833 .61301 L F
.556 .368 .581 r
.41416 .67073 m .41191 .6738 L .412 .67124 L F
0 0 .092 r
.67842 .60378 m .68006 .60021 L .6789 .6018 L F
.872 .641 .587 r
.67842 .60378 m .67896 .60636 L .67708 .60518 L F
.648 .5 .668 r
.67842 .60378 m .67896 .60636 L .68103 .60351 L F
.67842 .60378 m .67896 .60636 L .68103 .60351 L F
.453 0 0 r
.30262 .72628 m .30108 .72555 L .29861 .72398 L F
.629 .896 .986 r
.30407 .72544 m .30108 .72555 L .30262 .72628 L F
.285 .055 .378 r
.30262 .72628 m .30156 .72779 L .30407 .72544 L F
.277 .583 .943 r
.52094 .70713 m .51916 .70767 L .51792 .70673 L F
.52094 .70713 m .52166 .70822 L .51916 .70767 L F
.268 0 .062 r
.36486 .70337 m .36641 .70358 L .36774 .70162 L F
.253 0 .054 r
.36774 .70162 m .36833 .70296 L .36973 .70105 L F
.36774 .70162 m .36641 .70358 L .36833 .70296 L F
.239 0 0 r
.35754 .6488 m .36092 .6481 L .35897 .64848 L F
.792 .689 .75 r
.63211 .64357 m .63555 .64406 L .6344 .64073 L F
.805 .604 .63 r
.63529 .64636 m .63555 .64406 L .63211 .64357 L F
.776 .681 .758 r
.63555 .64406 m .63691 .64125 L .6344 .64073 L F
.729 .836 .388 r
.29948 .72841 m .30004 .72696 L .30156 .72779 L F
.796 .92 .921 r
.30004 .72696 m .30156 .72779 L .30407 .72544 L F
.509 .211 .396 r
.30661 .67592 m .30495 .67442 L .30447 .67628 L F
.30661 .67592 m .30723 .67415 L .30495 .67442 L F
.146 .231 .695 r
.66642 .6029 m .66701 .60617 L .66862 .605 L F
.366 .538 .892 r
.66753 .60794 m .66862 .605 L .66701 .60617 L F
.766 .929 .94 r
.56574 .68991 m .56937 .68882 L .568 .68955 L F
.85 .996 .761 r
.56937 .68882 m .5702 .68679 L .57076 .68741 L F
.56937 .68882 m .568 .68955 L .5702 .68679 L F
.535 .549 .816 r
.53476 .72987 m .53661 .73426 L .5383 .73343 L F
.487 .28 .524 r
.53603 .7363 m .5383 .73343 L .53661 .73426 L F
0 0 .094 r
.60444 .74992 m .60235 .75273 L .60323 .75103 L F
.485 .335 .602 r
.40267 .74492 m .40464 .74457 L .40457 .74201 L F
.575 .464 .69 r
.4028 .74743 m .40464 .74457 L .40267 .74492 L F
.529 .329 .553 r
.46955 .73949 m .46943 .74182 L .46729 .7422 L F
.823 .581 .572 r
.46835 .74082 m .46943 .74182 L .46955 .73949 L F
.46835 .74082 m .46955 .73949 L .47162 .73901 L F
.582 .598 .834 r
.46729 .7422 m .46943 .74182 L .46835 .74082 L F
0 .519 .791 r
.37208 .64946 m .3754 .65027 L .37339 .65031 L F
.209 0 0 r
.33488 .73255 m .33465 .7316 L .33639 .73067 L F
.33488 .73255 m .33269 .733 L .33465 .7316 L F
.656 .736 .908 r
.3158 .739 m .31858 .73883 L .31686 .73804 L F
.394 .103 .348 r
.372 .71186 m .3694 .71406 L .37015 .7125 L F
.443 0 0 r
.53141 .78821 m .53021 .78874 L .52808 .78856 L F
.382 0 0 r
.53304 .78917 m .53141 .78821 L .53369 .78836 L F
.53304 .78917 m .53021 .78874 L .53141 .78821 L F
.979 .736 .499 r
.71827 .73425 m .71715 .73581 L .71705 .73344 L F
.71827 .73425 m .71836 .73725 L .71715 .73581 L F
.086 .531 .906 r
.73152 .58365 m .73072 .58403 L .72987 .58298 L F
.73152 .58365 m .73258 .5846 L .73072 .58403 L F
.694 .385 .448 r
.40954 .73719 m .40917 .73891 L .4123 .73854 L F
.725 .595 .711 r
.63311 .63313 m .63646 .63339 L .63545 .63036 L F
.727 .569 .676 r
.63622 .63573 m .63646 .63339 L .63311 .63313 L F
.403 0 .084 r
.72121 .71401 m .72354 .71379 L .72444 .71221 L F
.194 0 0 r
.72549 .71271 m .72444 .71221 L .72354 .71379 L F
.54 .923 .91 r
.72524 .71305 m .72549 .71271 L .72519 .7131 L F
.194 0 0 r
.72549 .71271 m .72678 .71214 L .72589 .71217 L F
.224 .727 .902 r
.72797 .71172 m .72678 .71214 L .72549 .71271 L F
.54 .923 .91 r
.72691 .71153 m .72797 .71172 L .72549 .71271 L F
.72691 .71153 m .72549 .71271 L .72524 .71305 L F
.194 0 0 r
.72549 .71271 m .72589 .71217 L .72444 .71221 L F
.477 .777 .997 r
.28665 .59821 m .28614 .59938 L .28453 .59855 L F
.28665 .59821 m .28803 .59915 L .28614 .59938 L F
.61 .731 .932 r
.72488 .72854 m .7225 .72916 L .7215 .72768 L F
.811 .901 .905 r
.36487 .64815 m .36528 .64588 L .36643 .64727 L F
.523 .287 .499 r
.69769 .72071 m .7003 .72025 L .69974 .71813 L F
.647 .361 .472 r
.69974 .71813 m .7003 .72025 L .70209 .71961 L F
.592 .514 .735 r
.42302 .76305 m .42084 .76345 L .42065 .76245 L F
.593 .525 .748 r
.424 .76651 m .42084 .76345 L .42302 .76305 L F
.507 0 0 r
.46029 .72646 m .46234 .72732 L .46384 .72646 L F
.401 0 0 r
.46234 .72732 m .46594 .72613 L .46384 .72646 L F
.892 .809 .76 r
.3945 .65708 m .39514 .65868 L .39331 .65696 L F
0 0 .373 r
.6148 .68231 m .61529 .6838 L .61456 .68174 L F
.522 .534 .809 r
.51305 .73029 m .51554 .73034 L .51409 .72746 L F
.203 0 0 r
.41529 .79087 m .41432 .79127 L .412 .79132 L F
.036 0 0 r
.41681 .79007 m .41659 .79078 L .41529 .79087 L F
0 0 0 r
.41529 .79087 m .41659 .79078 L .41432 .79127 L F
.7 .39 .448 r
.60205 .64867 m .60537 .64681 L .6021 .64699 L F
.60205 .64867 m .60421 .649 L .60537 .64681 L F
.683 .37 .439 r
.60537 .64681 m .60421 .649 L .60764 .6489 L F
.677 .372 .45 r
.60537 .64681 m .60764 .6489 L .60821 .64724 L F
.083 0 0 r
.35599 .67418 m .3543 .67511 L .35228 .67544 L F
.293 0 0 r
.35801 .67364 m .3543 .67511 L .35599 .67418 L F
.97 .851 .668 r
.61596 .67667 m .61581 .67338 L .61703 .6742 L F
.638 .35 .464 r
.47725 .73694 m .47717 .73909 L .47379 .73946 L F
.461 .324 .607 r
.47935 .73626 m .47945 .73858 L .47725 .73694 L F
.568 .292 .457 r
.47725 .73694 m .47945 .73858 L .47717 .73909 L F
.802 .634 .673 r
.65743 .59998 m .6608 .60091 L .65921 .59754 L F
.878 .755 .723 r
.65758 .60285 m .6608 .60091 L .65743 .59998 L F
.65758 .60285 m .66019 .60273 L .6608 .60091 L F
.402 0 0 r
.34436 .64942 m .34657 .64947 L .34789 .64851 L F
.1 0 0 r
.34789 .64851 m .34862 .64888 L .3499 .64943 L F
.34789 .64851 m .34657 .64947 L .34862 .64888 L F
.737 .759 .871 r
.68126 .61982 m .67856 .62181 L .68172 .62207 L F
.807 .802 .847 r
.68126 .61982 m .68172 .62207 L .68425 .61961 L F
.432 .458 .787 r
.3111 .60549 m .31216 .60837 L .31052 .60879 L F
.414 .384 .716 r
.31216 .60837 m .31274 .6108 L .31052 .60879 L F
.539 .391 .628 r
.31052 .60879 m .31274 .6108 L .31059 .61106 L F
.566 .388 .599 r
.70049 .58975 m .70291 .58929 L .70269 .58699 L F
.864 .996 .78 r
.70269 .58699 m .70049 .58975 L .69969 .5898 L F
.241 0 0 r
.70049 .58975 m .70291 .58929 L .70222 .59038 L F
.566 .388 .599 r
.70049 .58975 m .70291 .58929 L .70269 .58699 L F
.492 .423 .707 r
.70049 .58975 m .7011 .59196 L .70327 .59158 L F
.834 .999 .798 r
.70244 .58745 m .70049 .58975 L .69969 .5898 L F
.637 .228 .252 r
.60408 .66241 m .60262 .66243 L .6018 .661 L F
.889 .719 .666 r
.39752 .79067 m .39879 .79372 L .39929 .79149 L F
.735 .814 .913 r
.39752 .79067 m .39929 .79149 L .4011 .79073 L F
.889 .719 .666 r
.39929 .79149 m .39879 .79372 L .39752 .79067 L F
.671 .474 .61 r
.30322 .73128 m .30316 .73377 L .30267 .73372 L F
.773 .877 .923 r
.30322 .73128 m .30662 .72882 L .30497 .72992 L F
.52 .73 .97 r
.27185 .59651 m .2713 .59815 L .27053 .59749 L F
.27185 .59651 m .27328 .59784 L .2713 .59815 L F
.531 .679 .932 r
.40283 .79058 m .40423 .79171 L .40611 .79124 L F
.703 .726 .868 r
.73025 .72763 m .72914 .72949 L .72704 .72762 L F
.567 .448 .677 r
.42215 .75804 m .42283 .76234 L .42065 .76245 L F
.592 .514 .735 r
.42302 .76305 m .42065 .76245 L .42283 .76234 L F
.683 .523 .662 r
.59074 .71215 m .59392 .71206 L .59396 .70965 L F
.474 0 0 r
.53249 .72941 m .53476 .72987 L .53504 .72961 L F
.344 0 0 r
.53476 .72987 m .53721 .7301 L .53504 .72961 L F
.53476 .72987 m .53721 .7301 L .53504 .72961 L F
.765 .705 .795 r
.58563 .73938 m .58342 .74162 L .58396 .74037 L F
.508 .305 .54 r
.58563 .73938 m .58557 .74157 L .58342 .74162 L F
.606 .568 .785 r
.58683 .74449 m .58342 .74162 L .58557 .74157 L F
.091 0 0 r
.58986 .66832 m .58864 .66968 L .58609 .67037 L F
0 0 0 r
.59235 .66612 m .5914 .66763 L .58986 .66832 L F
.5914 .66763 m .58864 .66968 L .58986 .66832 L F
.038 .607 .71 r
.72678 .71214 m .72908 .71203 L .73013 .71198 L F
0 .465 .816 r
.73133 .71209 m .73013 .71198 L .72908 .71203 L F
.73133 .71209 m .7321 .71259 L .73013 .71198 L F
.575 .847 .996 r
.39405 .78321 m .39651 .78287 L .39518 .78197 L F
0 .043 .612 r
.57151 .74479 m .57306 .74782 L .57273 .74662 L F
.012 .279 .778 r
.57306 .74782 m .57498 .74838 L .57273 .74662 L F
.631 .073 0 r
.57663 .75033 m .57538 .7498 L .57306 .74782 L F
.012 .279 .778 r
.57306 .74782 m .57538 .7498 L .57498 .74838 L F
.972 .66 .302 r
.72752 .60007 m .72771 .60235 L .72871 .60232 L F
.707 .696 .838 r
.72752 .60007 m .72871 .60232 L .73084 .60044 L F
.215 .298 .735 r
.73037 .60135 m .72871 .60232 L .72771 .60235 L F
.73037 .60135 m .73135 .60464 L .72871 .60232 L F
.397 .064 .279 r
.59771 .75563 m .59704 .75789 L .59487 .75847 L F
.331 0 .224 r
.5998 .75511 m .59704 .75789 L .59771 .75563 L F
.372 .405 .766 r
.56631 .73039 m .56711 .7341 L .56909 .73305 L F
.307 .28 .665 r
.56711 .7341 m .56835 .73351 L .56909 .73305 L F
.56711 .7341 m .56785 .7361 L .56835 .73351 L F
.665 .913 .977 r
.34072 .70798 m .34158 .70659 L .34299 .70723 L F
.34072 .70798 m .3389 .70784 L .34158 .70659 L F
.855 .694 .682 r
.63622 .64992 m .63529 .64636 L .63328 .64909 L F
.82 .603 .608 r
.63586 .65313 m .63622 .64992 L .63328 .64909 L F
.599 .801 .977 r
.33712 .70846 m .33514 .70899 L .33388 .70805 L F
0 .399 .847 r
.59389 .72712 m .59572 .72496 L .59334 .72495 L F
.59389 .72712 m .59525 .7271 L .59572 .72496 L F
.59389 .72712 m .59593 .72809 L .59525 .7271 L F
.617 .663 .872 r
.40692 .6649 m .40846 .66673 L .40494 .66541 L F
.687 .684 .841 r
.41041 .66568 m .40846 .66673 L .40692 .6649 L F
.434 .193 .448 r
.30461 .61982 m .30415 .62187 L .30218 .62238 L F
.417 .215 .495 r
.30415 .62187 m .30202 .62482 L .30218 .62238 L F
.172 .708 .745 r
.43635 .78673 m .43287 .78727 L .4325 .78744 L F
.43635 .78673 m .43491 .78688 L .43287 .78727 L F
.22 .74 .843 r
.43898 .7865 m .43491 .78688 L .43635 .78673 L F
.567 .424 .647 r
.60134 .72005 m .60193 .72415 L .59927 .72439 L F
.549 .478 .728 r
.6018 .72535 m .59927 .72439 L .60193 .72415 L F
.6018 .72535 m .59973 .72584 L .59927 .72439 L F
.596 .836 .461 r
.38878 .80168 m .38789 .80289 L .38664 .8045 L F
.411 .417 .756 r
.40111 .65827 m .39853 .66003 L .3945 .65708 L F
.489 .634 .918 r
.4031 .65815 m .40304 .65827 L .39893 .65661 L F
.40304 .65827 m .40216 .65983 L .40139 .65906 L F
.411 .417 .756 r
.40111 .65827 m .40045 .65952 L .39853 .66003 L F
.342 .678 .978 r
.39488 .65685 m .40111 .65827 L .3945 .65708 L F
.545 .654 .907 r
.39893 .65661 m .39919 .6574 L .40111 .65827 L F
.342 .678 .978 r
.39541 .65653 m .39939 .65749 L .39488 .65685 L F
.3962 .65606 m .39919 .6574 L .39541 .65653 L F
.39919 .6574 m .39939 .65749 L .39541 .65653 L F
.39948 .6575 m .40111 .65827 L .39488 .65685 L F
.411 .417 .756 r
.40045 .65952 m .39926 .6601 L .39853 .66003 L F
.545 .654 .907 r
.39919 .6574 m .40011 .66018 L .40111 .65827 L F
.39919 .6574 m .40216 .65983 L .40011 .66018 L F
.69 .733 .883 r
.39893 .65661 m .40111 .65827 L .39933 .65743 L F
.545 .654 .907 r
.39893 .65661 m .39933 .65743 L .39919 .6574 L F
.69 .733 .883 r
.39893 .65661 m .39933 .65743 L .39628 .65601 L F
.545 .654 .907 r
.39893 .65661 m .39989 .65756 L .39933 .65743 L F
.39989 .65756 m .40216 .65983 L .39919 .6574 L F
.342 .678 .978 r
.39628 .65601 m .39948 .6575 L .39939 .65749 L F
.39628 .65601 m .39939 .65749 L .3962 .65606 L F
.489 .634 .918 r
.40304 .65827 m .40139 .65906 L .39989 .65756 L F
.40206 .65787 m .39989 .65756 L .39893 .65661 L F
.40304 .65827 m .39989 .65756 L .40206 .65787 L F
.411 .417 .756 r
.40045 .65952 m .40011 .66018 L .39926 .6601 L F
.767 .767 .852 r
.71584 .60872 m .71321 .61101 L .71643 .61135 L F
.779 .747 .824 r
.71321 .61101 m .71453 .61244 L .71643 .61135 L F
.774 .613 .681 r
.6343 .63847 m .6378 .63899 L .63622 .63573 L F
.768 .643 .723 r
.63691 .64125 m .6378 .63899 L .6343 .63847 L F
.634 .734 .92 r
.7042 .61019 m .70525 .61161 L .70762 .61095 L F
.851 .427 .223 r
.57076 .68741 m .57038 .68918 L .5702 .68679 L F
.586 .556 .788 r
.57156 .69207 m .56915 .69281 L .568 .68955 L F
.57156 .69207 m .568 .68955 L .57038 .68918 L F
0 0 0 r
.568 .68955 m .56842 .69023 L .57038 .68918 L F
.648 .402 .532 r
.56842 .69023 m .56875 .69 L .57038 .68918 L F
.851 .427 .223 r
.57076 .68741 m .57148 .68863 L .57038 .68918 L F
.752 .423 .427 r
.57529 .69002 m .57229 .68999 L .57076 .68741 L F
.552 .369 .587 r
.568 .68955 m .57038 .68918 L .5702 .68679 L F
.752 .423 .427 r
.57529 .69002 m .57076 .68741 L .57383 .68725 L F
0 0 .482 r
.57038 .68918 m .57125 .68559 L .5702 .68679 L F
.57038 .68918 m .5715 .68806 L .57125 .68559 L F
.648 .402 .532 r
.56875 .69 m .5715 .68806 L .57038 .68918 L F
.851 .427 .223 r
.57148 .68863 m .57229 .68999 L .57038 .68918 L F
.373 .357 .713 r
.59973 .72584 m .60215 .7277 L .60021 .72798 L F
.184 .178 .617 r
.60207 .73016 m .60021 .72798 L .60215 .7277 L F
.60207 .73016 m .60072 .73169 L .60021 .72798 L F
.702 .664 .809 r
.71893 .72775 m .7157 .72613 L .71801 .72567 L F
.505 .649 .923 r
.72013 .72571 m .71893 .72775 L .71801 .72567 L F
.72013 .72571 m .7215 .72768 L .71893 .72775 L F
.864 .996 .78 r
.70269 .58699 m .69969 .5898 L .70244 .58745 L F
.832 .593 .578 r
.70269 .58699 m .70244 .58745 L .69957 .58364 L F
.695 .608 .755 r
.54723 .69336 m .55002 .69384 L .55029 .69256 L F
.138 0 0 r
.32631 .65709 m .3278 .65692 L .32915 .65536 L F
.308 0 .041 r
.32915 .65536 m .3299 .65644 L .33115 .65481 L F
.32915 .65536 m .3278 .65692 L .3299 .65644 L F
.49 .326 .585 r
.3986 .7529 m .40056 .75243 L .40058 .7501 L F
.536 .419 .667 r
.39888 .75578 m .40056 .75243 L .3986 .7529 L F
.093 0 0 r
.46594 .72613 m .46805 .72603 L .46928 .72577 L F
.49 0 0 r
.46805 .72603 m .47147 .72591 L .46928 .72577 L F
.656 .436 .573 r
.43499 .74979 m .43176 .7526 L .43163 .75006 L F
.43499 .74979 m .43456 .75274 L .43176 .7526 L F
.537 .328 .545 r
.43692 .7523 m .43499 .74979 L .43716 .74992 L F
.43692 .7523 m .43456 .75274 L .43499 .74979 L F
.763 .62 .702 r
.43503 .76597 m .43387 .76318 L .43516 .76382 L F
.27 .692 .967 r
.43387 .76318 m .43599 .76327 L .43516 .76382 L F
.55 .535 .791 r
.43599 .76327 m .43503 .76597 L .43516 .76382 L F
.317 .089 .402 r
.30672 .61705 m .30628 .61912 L .30461 .61982 L F
.281 .048 .371 r
.30628 .61912 m .30415 .62187 L .30461 .61982 L F
.23 .159 .566 r
.55029 .69256 m .55124 .69092 L .55182 .69009 L F
.55029 .69256 m .55002 .69384 L .55124 .69092 L F
.845 .932 .554 r
.55002 .69384 m .54908 .69485 L .55124 .69092 L F
.534 .394 .637 r
.55002 .69384 m .55041 .69599 L .55246 .6952 L F
.645 .167 .103 r
.55002 .69384 m .55246 .6952 L .54908 .69485 L F
0 0 .215 r
.66666 .60069 m .66734 .60175 L .66631 .59947 L F
.66666 .60069 m .66642 .6029 L .66734 .60175 L F
.311 .756 .962 r
.3499 .64943 m .35201 .64929 L .35345 .64983 L F
.528 .863 .994 r
.35345 .64983 m .35404 .64872 L .35548 .64925 L F
.35345 .64983 m .35201 .64929 L .35404 .64872 L F
.511 .308 .54 r
.61781 .64085 m .61964 .64054 L .61991 .63865 L F
.583 .461 .679 r
.61819 .6434 m .61964 .64054 L .61781 .64085 L F
.375 0 0 r
.45504 .78409 m .45199 .78471 L .4536 .7838 L F
0 0 0 r
.56304 .67619 m .56464 .67598 L .56574 .67421 L F
.56304 .67619 m .56234 .67658 L .56464 .67598 L F
.655 .503 .665 r
.6254 .63828 m .62766 .63573 L .62537 .63602 L F
.701 .512 .63 r
.55992 .68717 m .56242 .68718 L .56239 .68489 L F
.55992 .68717 m .56242 .68718 L .56239 .68489 L F
.663 .482 .629 r
.56575 .6866 m .56239 .68489 L .56467 .68399 L F
.56575 .6866 m .56242 .68718 L .56239 .68489 L F
.56239 .68489 m .56242 .68718 L .56575 .6866 L F
.259 .469 .873 r
.56141 .72046 m .5625 .71946 L .56124 .71932 L F
.178 .331 .781 r
.56141 .72046 m .56376 .72249 L .5625 .71946 L F
.465 .302 .575 r
.67814 .59678 m .67615 .59495 L .67815 .59451 L F
.025 0 0 r
.51802 .79331 m .51749 .7939 L .51429 .79525 L F
0 0 0 r
.52042 .79116 m .51908 .79266 L .51802 .79331 L F
.51908 .79266 m .51749 .7939 L .51802 .79331 L F
.511 .346 .593 r
.6018 .72535 m .60215 .7277 L .59973 .72584 L F
.161 0 .145 r
.58506 .65985 m .58686 .65961 L .58747 .65755 L F
.146 0 .081 r
.58424 .66185 m .58686 .65961 L .58506 .65985 L F
.768 .643 .723 r
.63691 .64125 m .6343 .63847 L .6344 .64073 L F
.462 .236 .484 r
.37653 .6954 m .37859 .69222 L .37675 .69279 L F
.547 .366 .588 r
.29449 .69069 m .29637 .69047 L .29647 .688 L F
.586 .424 .629 r
.29456 .69345 m .29637 .69047 L .29449 .69069 L F
.445 .208 .46 r
.38914 .69614 m .38885 .69828 L .38692 .69875 L F
.314 .099 .419 r
.39045 .69746 m .38914 .69614 L .39122 .6958 L F
.39045 .69746 m .38885 .69828 L .38914 .69614 L F
.598 .617 .841 r
.3879 .65475 m .38583 .65533 L .38436 .65246 L F
.574 .134 .167 r
.58663 .75923 m .58583 .76062 L .58348 .76042 L F
.501 .059 .13 r
.58663 .75923 m .58913 .76016 L .58583 .76062 L F
.674 .129 0 r
.6818 .59491 m .6851 .59749 L .68363 .59427 L F
.576 .555 .794 r
.32465 .70477 m .32299 .70582 L .32181 .70313 L F
.061 0 0 r
.58747 .65755 m .58935 .65695 L .59012 .65573 L F
.237 0 .173 r
.58747 .65755 m .58875 .65877 L .58935 .65695 L F
.58747 .65755 m .58686 .65961 L .58875 .65877 L F
.948 .894 .741 r
.63033 .67826 m .63082 .67472 L .6303 .6776 L F
.973 .797 .374 r
.6303 .6776 m .63031 .67769 L .63033 .67826 L F
.824 .958 .621 r
.63037 .67912 m .63171 .67695 L .63033 .67826 L F
.973 .797 .374 r
.63031 .67769 m .63055 .68063 L .63033 .67826 L F
.824 .958 .621 r
.62992 .67985 m .63037 .67912 L .63033 .67826 L F
.096 .044 .502 r
.63033 .67826 m .6291 .68166 L .62992 .67985 L F
.42 .402 .733 r
.6077 .74151 m .60818 .74436 L .60646 .74472 L F
.493 .281 .52 r
.60856 .74627 m .60646 .74472 L .60818 .74436 L F
.60856 .74627 m .6065 .74698 L .60646 .74472 L F
.876 .778 .751 r
.65758 .60285 m .65838 .60582 L .66019 .60273 L F
.291 .072 .4 r
.41596 .66573 m .41626 .6671 L .41483 .6666 L F
.637 .594 .789 r
.41626 .6671 m .41416 .67073 L .41483 .6666 L F
.585 .657 .887 r
.60513 .73828 m .60246 .73899 L .60207 .73676 L F
.60513 .73828 m .60554 .73999 L .60246 .73899 L F
.175 .283 .737 r
.56905 .71141 m .56869 .71387 L .56787 .71289 L F
.468 .623 .918 r
.30591 .60442 m .30382 .60445 L .30241 .60245 L F
.732 .546 .64 r
.63094 .63556 m .63322 .6355 L .63311 .63313 L F
.727 .569 .676 r
.63622 .63573 m .63311 .63313 L .63322 .6355 L F
.089 0 0 r
.44185 .77471 m .44539 .77464 L .44331 .77541 L F
.704 .915 .572 r
.46348 .75669 m .46208 .75874 L .4628 .75727 L F
.521 .484 .755 r
.46348 .75669 m .46446 .75833 L .46208 .75874 L F
.441 .186 .43 r
.46208 .75874 m .46446 .75833 L .4628 .75727 L F
.46208 .75874 m .46183 .76066 L .46446 .75833 L F
.46446 .75833 m .46183 .76066 L .46208 .75874 L F
.638 .42 .571 r
.59166 .71389 m .59392 .71206 L .59074 .71215 L F
.626 .142 0 r
.57779 .75263 m .57538 .7498 L .57663 .75033 L F
.673 .817 .953 r
.71105 .61269 m .71453 .61244 L .71321 .61101 L F
.822 .988 .875 r
.68897 .61227 m .69042 .61104 L .68979 .61044 L F
.769 .979 .913 r
.68979 .61044 m .69042 .61104 L .69319 .60878 L F
.756 .852 .922 r
.31686 .73804 m .31858 .73883 L .32097 .73695 L F
.508 .604 .884 r
.27365 .60939 m .27503 .60878 L .27311 .6085 L F
.319 .124 .452 r
.2955 .63763 m .29532 .63448 L .29744 .6347 L F
.355 0 .033 r
.44497 .74725 m .44141 .74917 L .44281 .74752 L F
.094 0 0 r
.52115 .79174 m .52042 .79116 L .52201 .79059 L F
.52115 .79174 m .51908 .79266 L .52042 .79116 L F
0 .19 .716 r
.55438 .69493 m .55388 .69568 L .55246 .6952 L F
.55438 .69493 m .55599 .69824 L .55388 .69568 L F
.677 .299 .323 r
.50128 .78257 m .50373 .78465 L .50499 .7825 L F
.759 .44 .445 r
.50373 .78465 m .50645 .78299 L .50499 .7825 L F
.511 .336 .581 r
.29637 .69047 m .29852 .68727 L .29647 .688 L F
.562 .841 .997 r
.31962 .73382 m .31964 .73374 L .31769 .73391 L F
.31979 .73381 m .31964 .73374 L .31962 .73382 L F
.759 .767 .26 r
.32052 .72991 m .31988 .73222 L .31964 .73374 L F
.833 .63 .628 r
.32015 .73591 m .32145 .73373 L .31769 .73391 L F
.841 .375 .061 r
.31964 .73374 m .31637 .73074 L .31769 .73391 L F
.31964 .73374 m .31921 .73478 L .31769 .73281 L F
.31921 .73478 m .31911 .73503 L .31903 .7349 L F
.31921 .73478 m .31903 .7349 L .31769 .73281 L F
.768 .39 .338 r
.31769 .73391 m .31634 .73557 L .32015 .73591 L F
.386 .806 .973 r
.31812 .73573 m .31858 .73527 L .32015 .73591 L F
.31634 .73557 m .31858 .73527 L .31812 .73573 L F
.841 .375 .061 r
.31964 .73374 m .31769 .73281 L .31637 .73074 L F
.759 .767 .26 r
.31988 .73222 m .31911 .73503 L .31964 .73374 L F
.396 .305 .634 r
.31637 .73074 m .31911 .73503 L .31845 .73092 L F
.69 .509 .637 r
.31845 .73092 m .31911 .73503 L .32052 .72991 L F
.43 .489 .819 r
.31993 .73409 m .31858 .73527 L .31687 .73201 L F
.958 .75 .58 r
.31876 .73509 m .31858 .73527 L .31895 .73494 L F
.805 .744 .796 r
.31634 .73557 m .31686 .73804 L .32015 .73591 L F
.386 .806 .973 r
.31634 .73557 m .31858 .73527 L .32015 .73591 L F
.756 .852 .922 r
.31686 .73804 m .32097 .73695 L .32015 .73591 L F
.711 .178 0 r
.31634 .73557 m .31802 .73747 L .31656 .73675 L F
.528 .29 .498 r
.31858 .73527 m .31802 .73747 L .31634 .73557 L F
.958 .75 .58 r
.31656 .73675 m .31858 .73527 L .31876 .73509 L F
.31844 .73527 m .31895 .73494 L .31993 .73409 L F
.31656 .73675 m .31895 .73494 L .31844 .73527 L F
.562 .841 .997 r
.32145 .73373 m .31964 .73374 L .31979 .73381 L F
.833 .63 .628 r
.32015 .73591 m .32097 .73695 L .32145 .73373 L F
.268 .651 .967 r
.32145 .73373 m .32424 .73363 L .31964 .73374 L F
.32145 .73373 m .32465 .73434 L .32424 .73363 L F
.611 .42 .599 r
.32145 .73373 m .32097 .73695 L .3231 .73615 L F
.654 .804 .36 r
.7033 .58015 m .70228 .58206 L .70322 .58021 L F
.487 .822 .527 r
.7033 .58015 m .70478 .57876 L .70596 .5794 L F
.7033 .58015 m .70322 .58021 L .70478 .57876 L F
.719 .573 .69 r
.58505 .73833 m .58396 .74037 L .58162 .7392 L F
.7 .55 .68 r
.58563 .73938 m .58505 .73833 L .58437 .736 L F
.58563 .73938 m .58396 .74037 L .58505 .73833 L F
.507 .265 .482 r
.3326 .68432 m .33215 .68742 L .32995 .68749 L F
.481 .243 .475 r
.33433 .68653 m .3326 .68432 L .33469 .68399 L F
.33433 .68653 m .33215 .68742 L .3326 .68432 L F
.254 .667 .965 r
.38318 .67044 m .38007 .66933 L .37999 .66959 L F
.068 .261 .752 r
.56946 .70764 m .56959 .70904 L .56715 .70672 L F
.464 .565 .873 r
.6056 .70105 m .60788 .70058 L .60718 .70099 L F
.525 .34 .572 r
.60544 .70381 m .60788 .70058 L .6056 .70105 L F
.981 .913 .616 r
.512 .72613 m .51059 .72712 L .51143 .72543 L F
.512 .72613 m .51059 .72712 L .51143 .72543 L F
.056 .618 .783 r
.71838 .58298 m .72067 .58302 L .722 .58318 L F
.581 .932 .942 r
.722 .58318 m .72416 .58191 L .72389 .58089 L F
.722 .58318 m .72067 .58302 L .72416 .58191 L F
.403 .126 .374 r
.58031 .66354 m .58005 .6653 L .58263 .663 L F
.255 0 .242 r
.28705 .64624 m .28634 .6487 L .28458 .64955 L F
.123 0 .189 r
.28779 .64778 m .28705 .64624 L .28875 .64644 L F
.28779 .64778 m .28634 .6487 L .28705 .64624 L F
.705 .769 .901 r
.69319 .60878 m .69639 .60924 L .69528 .6079 L F
.717 .757 .884 r
.69528 .6079 m .69639 .60924 L .69875 .60841 L F
.382 .538 .887 r
.38959 .65491 m .39013 .65725 L .3879 .65475 L F
.38959 .65491 m .39127 .65735 L .39013 .65725 L F
.459 .443 .754 r
.60316 .73325 m .60207 .73676 L .60165 .73352 L F
.60316 .73325 m .60429 .73692 L .60207 .73676 L F
.434 .513 .84 r
.60429 .73692 m .60513 .73828 L .60207 .73676 L F
0 0 0 r
.50907 .70614 m .50763 .70668 L .50908 .70616 L F
.50907 .70614 m .51024 .70574 L .51125 .70558 L F
.50907 .70614 m .50908 .70616 L .51024 .70574 L F
.175 0 0 r
.50906 .70613 m .50907 .70614 L .51013 .70639 L F
.50724 .70569 m .50907 .70614 L .50906 .70613 L F
.435 .875 .852 r
.51013 .70639 m .51125 .70558 L .51259 .70547 L F
.416 .852 .936 r
.51013 .70639 m .50907 .70614 L .51125 .70558 L F
.735 .814 .913 r
.39752 .79067 m .4011 .79073 L .3998 .78786 L F
.605 .591 .811 r
.4011 .79073 m .40189 .78789 L .3998 .78786 L F
.4011 .79073 m .40283 .79058 L .40189 .78789 L F
.076 0 0 r
.34202 .72816 m .34033 .72919 L .33848 .72958 L F
0 0 0 r
.34418 .72727 m .34298 .72796 L .34202 .72816 L F
.34298 .72796 m .34033 .72919 L .34202 .72816 L F
.595 .366 .539 r
.52236 .73412 m .51961 .73667 L .51967 .73397 L F
.52236 .73412 m .52219 .73634 L .51961 .73667 L F
.34 .155 .479 r
.52396 .73339 m .52219 .73634 L .52236 .73412 L F
.325 .638 .964 r
.34701 .7078 m .34651 .7089 L .34474 .70694 L F
.34701 .7078 m .34838 .70906 L .34651 .7089 L F
.752 .582 .666 r
.6343 .63847 m .63622 .63573 L .63322 .6355 L F
.822 .988 .875 r
.68897 .61227 m .68979 .61044 L .68789 .61169 L F
.997 .771 .443 r
.72852 .72274 m .72739 .7241 L .72757 .72194 L F
.72852 .72274 m .72856 .72591 L .72739 .7241 L F
.171 0 0 r
.35801 .72098 m .35751 .71997 L .35935 .71963 L F
.35801 .72098 m .35605 .72179 L .35751 .71997 L F
.603 .043 0 r
.51292 .78465 m .51583 .7855 L .5136 .7851 L F
.536 .317 .53 r
.40457 .74201 m .40671 .74174 L .40686 .73935 L F
.534 .329 .549 r
.40671 .74174 m .40917 .73891 L .40686 .73935 L F
.494 .413 .693 r
.5579 .69055 m .55846 .69293 L .56028 .69238 L F
.702 .324 .331 r
.56028 .69238 m .55706 .6925 L .5579 .69055 L F
.284 .553 .926 r
.7321 .71259 m .73512 .71364 L .73375 .71428 L F
.256 .474 .878 r
.73512 .71364 m .73563 .71534 L .73375 .71428 L F
.942 .738 .267 r
.73275 .60953 m .73239 .60549 L .73375 .60722 L F
.918 .541 .123 r
.73249 .6106 m .73347 .61145 L .73275 .60953 L F
.677 .967 .926 r
.67485 .58965 m .67132 .59097 L .674 .58902 L F
0 0 0 r
.59324 .66652 m .59235 .66612 L .59443 .66531 L F
.59324 .66652 m .5914 .66763 L .59235 .66612 L F
.786 .286 0 r
.58557 .74157 m .58871 .74458 L .58683 .74449 L F
.149 0 0 r
.51776 .78428 m .51983 .78385 L .52128 .78265 L F
.253 0 0 r
.51983 .78385 m .52352 .78209 L .52128 .78265 L F
.499 .257 .478 r
.40493 .68169 m .4025 .68417 L .403 .68228 L F
.576 .324 .497 r
.61135 .7124 m .6084 .71425 L .60903 .71242 L F
.477 .223 .45 r
.58092 .7201 m .58299 .71747 L .58067 .71757 L F
.543 .596 .856 r
.27683 .61179 m .2803 .61433 L .2787 .61158 L F
.418 .538 .871 r
.2787 .61158 m .2803 .61433 L .28178 .61402 L F
.405 .427 .77 r
.2803 .61433 m .28267 .61594 L .28178 .61402 L F
.484 .421 .71 r
.28102 .61705 m .28267 .61594 L .2803 .61433 L F
.684 .285 .285 r
.70583 .73097 m .70487 .73284 L .70238 .73112 L F
.601 .194 .243 r
.70755 .73236 m .70583 .73097 L .70798 .73224 L F
.70755 .73236 m .70487 .73284 L .70583 .73097 L F
.615 .634 .846 r
.40692 .6649 m .40494 .66541 L .40356 .66269 L F
.433 .203 .463 r
.3809 .68488 m .38279 .68441 L .38309 .6823 L F
.462 .226 .47 r
.38309 .6823 m .38508 .68182 L .38568 .67966 L F
.465 .229 .472 r
.38309 .6823 m .38478 .68394 L .38508 .68182 L F
.38309 .6823 m .38279 .68441 L .38478 .68394 L F
.582 .253 .378 r
.42782 .73569 m .43133 .7333 L .4283 .73444 L F
.511 .569 .85 r
.40216 .65983 m .40164 .66288 L .40011 .66018 L F
.40216 .65983 m .40356 .66269 L .40164 .66288 L F
.452 .252 .517 r
.40706 .67889 m .40493 .68169 L .40524 .6795 L F
.668 .297 .332 r
.55745 .73946 m .55641 .74122 L .55416 .73932 L F
.361 .233 .569 r
.55923 .7363 m .55944 .73874 L .55745 .73946 L F
.851 .527 .439 r
.55811 .74146 m .55745 .73946 L .55944 .73874 L F
.55811 .74146 m .55641 .74122 L .55745 .73946 L F
.489 .191 .387 r
.59966 .64898 m .60205 .64867 L .6021 .64699 L F
.825 .776 .806 r
.71768 .61687 m .71504 .61655 L .71678 .61519 L F
.78 .545 .579 r
.71768 .61687 m .71442 .61879 L .71504 .61655 L F
.71768 .61687 m .71762 .61923 L .71442 .61879 L F
.685 .722 .877 r
.71946 .61535 m .71768 .61687 L .71678 .61519 L F
.548 .029 0 r
.48119 .78254 m .48458 .78266 L .48309 .78351 L F
.67 .214 .161 r
.48647 .7842 m .48309 .78351 L .48458 .78266 L F
.615 .154 .135 r
.48458 .78266 m .4868 .78323 L .48647 .7842 L F
.915 .71 .611 r
.55929 .74208 m .55811 .74146 L .55986 .74143 L F
.55929 .74208 m .55792 .74459 L .55811 .74146 L F
.496 .29 .529 r
.55929 .74208 m .55906 .74296 L .55893 .74274 L F
.55858 .74475 m .55959 .74463 L .55792 .74721 L F
.55906 .74296 m .55956 .74454 L .55858 .74475 L F
.55956 .74454 m .55959 .74463 L .55858 .74475 L F
.55893 .74274 m .55792 .74721 L .55792 .74459 L F
.55906 .74296 m .55792 .74721 L .55893 .74274 L F
.746 .557 .639 r
.55811 .74146 m .55792 .74459 L .55963 .74453 L F
.55991 .74377 m .55974 .74424 L .56048 .7445 L F
.55974 .74424 m .55963 .74453 L .55968 .74453 L F
.55974 .74424 m .55968 .74453 L .56048 .7445 L F
.391 .223 .53 r
.56004 .74442 m .55979 .74449 L .55974 .74424 L F
.496 .29 .529 r
.55958 .74345 m .56025 .7467 L .55906 .74296 L F
0 0 0 r
.55792 .74459 m .55929 .7439 L .55995 .7444 L F
.55792 .74459 m .56022 .74437 L .56009 .74441 L F
.55792 .74459 m .56027 .74439 L .55963 .74453 L F
.563 .458 .692 r
.55792 .74459 m .55792 .74721 L .55575 .74774 L F
.606 .935 .955 r
.55575 .74774 m .5563 .74634 L .55792 .74459 L F
0 0 0 r
.55792 .74459 m .5563 .74634 L .55929 .7439 L F
.18 0 0 r
.5551 .7458 m .55929 .7439 L .5563 .74634 L F
.5551 .7458 m .55677 .74585 L .55929 .7439 L F
.683 .162 0 r
.55896 .74529 m .55669 .74587 L .5567 .74594 L F
.18 0 0 r
.55677 .74585 m .55694 .74586 L .55702 .74579 L F
.55677 .74585 m .55702 .74579 L .55929 .7439 L F
.496 .29 .529 r
.55959 .74463 m .55869 .74704 L .55792 .74721 L F
.683 .162 0 r
.55939 .74547 m .55896 .74529 L .5567 .74594 L F
.958 .948 .676 r
.55929 .7439 m .55702 .74579 L .55831 .74318 L F
.233 .382 .808 r
.55629 .74416 m .55677 .74585 L .5551 .7458 L F
.683 .162 0 r
.55677 .74585 m .55629 .74416 L .55669 .74587 L F
.55702 .74579 m .55629 .74416 L .55677 .74585 L F
.233 .382 .808 r
.55629 .74416 m .55694 .74586 L .55677 .74585 L F
.958 .948 .676 r
.55702 .74579 m .55694 .74586 L .55704 .74565 L F
.55702 .74579 m .55704 .74565 L .55831 .74318 L F
.746 .557 .639 r
.55811 .74146 m .55963 .74453 L .55991 .74377 L F
.496 .29 .529 r
.55929 .74208 m .55958 .74345 L .55906 .74296 L F
.746 .557 .639 r
.55819 .74145 m .55999 .74384 L .55863 .7414 L F
.55999 .74384 m .56022 .74407 L .56016 .74396 L F
.391 .223 .53 r
.55985 .74369 m .55958 .74345 L .55929 .74208 L F
.746 .557 .639 r
.55995 .74378 m .56016 .74396 L .55863 .7414 L F
.55999 .74384 m .56016 .74396 L .55995 .74378 L F
.391 .223 .53 r
.55999 .74298 m .55985 .74369 L .55929 .74208 L F
.55985 .74369 m .55974 .74424 L .55958 .74345 L F
.746 .557 .639 r
.55843 .74188 m .55985 .74369 L .55819 .74145 L F
.55985 .74369 m .56048 .7445 L .55992 .74375 L F
.55985 .74369 m .55992 .74375 L .55819 .74145 L F
0 0 0 r
.56009 .74441 m .56022 .74437 L .56027 .74439 L F
.55968 .74453 m .56027 .74439 L .56048 .7445 L F
.55963 .74453 m .55979 .74449 L .55968 .74453 L F
.55979 .74449 m .56027 .74439 L .55968 .74453 L F
.746 .557 .639 r
.55999 .74384 m .56048 .7445 L .56022 .74407 L F
.452 .339 .634 r
.56228 .74108 m .55929 .74208 L .55986 .74143 L F
.56228 .74108 m .56273 .74411 L .55929 .74208 L F
.391 .223 .53 r
.56218 .74578 m .56047 .74358 L .56273 .74411 L F
.56047 .74358 m .55929 .74208 L .56083 .74299 L F
.56047 .74358 m .56083 .74299 L .56273 .74411 L F
.851 .527 .439 r
.55811 .74146 m .55944 .73874 L .55986 .74143 L F
.336 .521 .89 r
.55863 .7414 m .56016 .74396 L .55958 .74093 L F
.56016 .74396 m .56048 .7445 L .56035 .74397 L F
.391 .223 .53 r
.56078 .74399 m .55985 .74369 L .55999 .74298 L F
.56016 .74396 m .55985 .74369 L .56078 .74399 L F
.336 .521 .89 r
.56016 .74396 m .56035 .74397 L .55958 .74093 L F
.391 .223 .53 r
.56205 .74562 m .56016 .74396 L .56078 .74399 L F
.985 .891 .64 r
.56031 .74383 m .55929 .7439 L .55958 .74093 L F
.56035 .74397 m .56023 .74396 L .56031 .74383 L F
.391 .223 .53 r
.56031 .7441 m .55974 .74424 L .55985 .74369 L F
.985 .891 .64 r
.56023 .74396 m .55929 .7439 L .56031 .74383 L F
.56048 .7445 m .56022 .74437 L .56035 .74397 L F
.391 .223 .53 r
.56026 .74427 m .55974 .74424 L .56031 .7441 L F
.985 .891 .64 r
.56022 .74437 m .55929 .7439 L .56035 .74397 L F
.391 .223 .53 r
.56051 .74429 m .56026 .74427 L .56031 .7441 L F
.56218 .74578 m .56004 .74442 L .56051 .74429 L F
.56004 .74442 m .55974 .74424 L .56051 .74429 L F
.56218 .74578 m .55985 .74369 L .56205 .74562 L F
.885 .757 .716 r
.55915 .74155 m .55704 .74565 L .55629 .74416 L F
.55704 .74565 m .55694 .74586 L .55629 .74416 L F
.683 .162 0 r
.55896 .74529 m .5572 .74455 L .55704 .74565 L F
.5571 .74577 m .55704 .74565 L .55702 .74579 L F
.55896 .74529 m .55704 .74565 L .5571 .74577 L F
.5572 .74455 m .55629 .74416 L .55702 .74579 L F
.958 .948 .676 r
.55929 .7439 m .55831 .74318 L .55915 .74155 L F
0 0 0 r
.55995 .7444 m .55929 .7439 L .56022 .74437 L F
.391 .223 .53 r
.56218 .74578 m .56025 .7467 L .55979 .74449 L F
.56218 .74578 m .55979 .74449 L .56004 .74442 L F
.496 .29 .529 r
.55959 .74463 m .56025 .7467 L .55869 .74704 L F
.746 .557 .639 r
.55811 .74146 m .55843 .74188 L .55819 .74145 L F
.443 .313 .608 r
.3809 .68488 m .38284 .68678 L .38279 .68441 L F
.3809 .68488 m .38112 .68748 L .38284 .68678 L F
.865 .621 .567 r
.61618 .66857 m .61427 .67038 L .61421 .66809 L F
.61618 .66857 m .61621 .67105 L .61427 .67038 L F
.625 .233 .281 r
.29861 .72398 m .30108 .72555 L .29775 .72512 L F
.563 .164 .243 r
.36368 .67126 m .36233 .67325 L .36022 .67285 L F
.208 0 0 r
.36573 .67112 m .36233 .67325 L .36368 .67126 L F
.542 .371 .599 r
.38508 .68182 m .38724 .67884 L .38568 .67966 L F
.992 .749 .457 r
.71888 .59712 m .71891 .59912 L .72003 .59997 L F
.71888 .59712 m .71891 .59912 L .72003 .59997 L F
.589 .069 0 r
.72142 .60138 m .71891 .59912 L .72003 .59997 L F
.486 .633 .919 r
.59485 .74109 m .59306 .73892 L .59417 .74175 L F
.59485 .74109 m .59537 .73881 L .59306 .73892 L F
.505 .065 .137 r
.59329 .74304 m .59558 .74326 L .59485 .74109 L F
.299 .286 .677 r
.59485 .74109 m .59739 .73813 L .59537 .73881 L F
.59485 .74109 m .59806 .74062 L .59739 .73813 L F
.327 .468 .849 r
.60661 .73846 m .60554 .73999 L .60513 .73828 L F
.252 .363 .783 r
.60661 .73846 m .6077 .74151 L .60554 .73999 L F
0 .328 .811 r
.54131 .72328 m .54386 .7249 L .54307 .72518 L F
.024 .481 .878 r
.54386 .7249 m .54508 .72594 L .54307 .72518 L F
.614 .342 .481 r
.55565 .67962 m .55769 .68129 L .55844 .67954 L F
.732 .615 .728 r
.65409 .60197 m .65743 .59998 L .65473 .60224 L F
.181 0 .286 r
.3083 .61639 m .30628 .61912 L .30672 .61705 L F
.667 .521 .677 r
.62316 .64104 m .61991 .63865 L .61964 .64054 L F
.62316 .64104 m .62311 .63854 L .61991 .63865 L F
.398 0 0 r
.44549 .78527 m .44445 .78593 L .44226 .78589 L F
.197 0 0 r
.44633 .78597 m .44549 .78527 L .44765 .78522 L F
.44633 .78597 m .44445 .78593 L .44549 .78527 L F
.552 .601 .857 r
.58625 .73631 m .58563 .73938 L .58437 .736 L F
.58625 .73631 m .58756 .73882 L .58563 .73938 L F
.454 .262 .529 r
.58756 .73882 m .58557 .74157 L .58563 .73938 L F
.452 0 0 r
.4868 .78323 m .49019 .78322 L .48887 .78407 L F
.32 0 0 r
.49019 .78322 m .49101 .78417 L .48887 .78407 L F
.49019 .78322 m .49252 .78326 L .49101 .78417 L F
.347 .108 .403 r
.38807 .70014 m .38692 .69875 L .38885 .69828 L F
.38807 .70014 m .38641 .70084 L .38692 .69875 L F
.532 .374 .612 r
.60326 .71733 m .60351 .71969 L .60134 .72005 L F
.547 .411 .647 r
.60429 .72305 m .60134 .72005 L .60351 .71969 L F
.60429 .72305 m .60193 .72415 L .60134 .72005 L F
.223 .069 .451 r
.62089 .69529 m .62072 .69757 L .61882 .69851 L F
.187 .014 .4 r
.62032 .69954 m .61882 .69851 L .62072 .69757 L F
.62032 .69954 m .61911 .70083 L .61882 .69851 L F
.451 .125 .32 r
.40993 .67622 m .40919 .67849 L .40706 .67889 L F
.369 .175 .481 r
.41191 .6738 m .41179 .67616 L .40993 .67622 L F
.333 .017 .272 r
.41179 .67616 m .40919 .67849 L .40993 .67622 L F
.846 .436 .261 r
.54498 .73707 m .54416 .73822 L .542 .73562 L F
.56 .029 0 r
.54498 .73707 m .5459 .73824 L .54416 .73822 L F
.393 0 0 r
.48548 .77726 m .48756 .77749 L .48904 .77694 L F
.596 .056 0 r
.48981 .77847 m .48904 .77694 L .48756 .77749 L F
.48981 .77847 m .491 .77795 L .48904 .77694 L F
.61 .456 .648 r
.29162 .64047 m .29177 .64366 L .28889 .6438 L F
.513 .131 .253 r
.28889 .6438 m .29062 .64571 L .28875 .64644 L F
.28889 .6438 m .29177 .64366 L .29062 .64571 L F
.454 0 0 r
.52352 .78209 m .52586 .78258 L .52701 .78218 L F
.286 .787 .83 r
.52586 .78258 m .5291 .78202 L .52701 .78218 L F
.812 .56 .557 r
.69928 .57762 m .70237 .57581 L .69929 .57578 L F
.69928 .57762 m .70186 .57902 L .70237 .57581 L F
.559 .489 .733 r
.69829 .72255 m .7003 .72025 L .69769 .72071 L F
.69829 .72255 m .70037 .72215 L .7003 .72025 L F
.262 0 .167 r
.57239 .70604 m .57412 .70591 L .57493 .70409 L F
.556 .192 .306 r
.57493 .70409 m .57412 .70591 L .576 .70564 L F
.52 .254 .452 r
.576 .70548 m .57574 .70584 L .57283 .70479 L F
.482 .256 .494 r
.5716 .708 m .57387 .7085 L .57412 .70591 L F
.622 .376 .523 r
.576 .70564 m .57693 .70667 L .57715 .70548 L F
.57412 .70591 m .57547 .70628 L .576 .70564 L F
.57547 .70628 m .57693 .70667 L .576 .70564 L F
.57412 .70591 m .57387 .7085 L .57693 .70667 L F
.52 .254 .452 r
.57574 .70584 m .57527 .70651 L .57358 .70748 L F
.57527 .70651 m .57387 .7085 L .5738 .70825 L F
.57527 .70651 m .5738 .70825 L .57358 .70748 L F
.482 .256 .494 r
.5716 .708 m .57412 .70591 L .57239 .70604 L F
.52 .254 .452 r
.57574 .70584 m .57358 .70748 L .57283 .70479 L F
.556 .192 .306 r
.57664 .70516 m .576 .70564 L .57715 .70548 L F
.57493 .70409 m .576 .70564 L .57664 .70516 L F
.937 .869 .745 r
.6358 .65497 m .63586 .65313 L .6345 .65443 L F
.918 .69 .578 r
.6345 .65443 m .63584 .65741 L .6358 .65497 L F
.991 .796 .546 r
.57957 .67913 m .57902 .68171 L .58 .6824 L F
.984 .812 .59 r
.57902 .68171 m .57949 .68465 L .58 .6824 L F
.14 .65 .899 r
.3989 .78277 m .39518 .78197 L .39651 .78287 L F
.455 .399 .705 r
.39651 .78287 m .39866 .78499 L .3989 .78277 L F
.39651 .78287 m .39712 .78611 L .39866 .78499 L F
.506 .371 .631 r
.39572 .76666 m .39775 .76651 L .39759 .76357 L F
.631 .427 .588 r
.39572 .76666 m .39819 .76879 L .39775 .76651 L F
.39572 .76666 m .39594 .76922 L .39819 .76879 L F
.327 .04 .316 r
.38641 .70084 m .38392 .70334 L .38459 .70154 L F
.589 .135 .141 r
.53249 .78264 m .53482 .78379 L .53582 .78265 L F
.462 0 0 r
.53482 .78379 m .53798 .78306 L .53582 .78265 L F
.161 0 .015 r
.56574 .67421 m .5667 .67512 L .56757 .67325 L F
.56574 .67421 m .56464 .67598 L .5667 .67512 L F
0 .16 .697 r
.73758 .59184 m .73939 .59388 L .73941 .5954 L F
0 0 .082 r
.74 .59605 m .73941 .5954 L .73939 .59388 L F
.74 .59605 m .73858 .5975 L .73941 .5954 L F
.591 .179 .23 r
.47648 .77645 m .47879 .77689 L .48002 .77528 L F
.57 .156 .217 r
.48002 .77528 m .48217 .77629 L .48214 .77444 L F
.48002 .77528 m .47879 .77689 L .48217 .77629 L F
.009 .55 .84 r
.70825 .57878 m .71222 .57977 L .70922 .57902 L F
.535 .569 .836 r
.57052 .70989 m .5716 .708 L .56959 .70904 L F
.57052 .70989 m .57264 .7097 L .5716 .708 L F
.389 .457 .809 r
.32965 .82284 m .32831 .82488 L .32752 .82542 L F
.32965 .82284 m .33095 .826 L .32831 .82488 L F
.009 0 .408 r
.57872 .72516 m .57748 .72844 L .57692 .72561 L F
.57872 .72516 m .57879 .7274 L .57748 .72844 L F
.561 .507 .752 r
.57879 .7274 m .57716 .73107 L .57748 .72844 L F
.938 .754 .627 r
.68287 .61851 m .68425 .61961 L .68321 .61638 L F
.807 .802 .847 r
.68126 .61982 m .68425 .61961 L .68287 .61851 L F
.514 .568 .848 r
.55746 .73299 m .55596 .73494 L .55554 .73327 L F
.55746 .73299 m .55923 .7363 L .55596 .73494 L F
.583 .627 .861 r
.31281 .72845 m .31431 .73116 L .31637 .73074 L F
.717 .572 .691 r
.31431 .73116 m .31769 .73391 L .31637 .73074 L F
.31431 .73116 m .31483 .73419 L .31769 .73391 L F
.467 .55 .858 r
.27503 .60878 m .27683 .61179 L .27805 .61012 L F
.517 .621 .894 r
.27805 .61012 m .27683 .61179 L .2787 .61158 L F
.281 0 .253 r
.32361 .65958 m .32551 .65947 L .32631 .65709 L F
.428 .173 .423 r
.32551 .65947 m .3278 .65692 L .32631 .65709 L F
.648 .609 .797 r
.42874 .77451 m .42517 .772 L .42723 .77155 L F
.546 .571 .831 r
.42945 .77121 m .42874 .77451 L .42723 .77155 L F
.42945 .77121 m .43079 .77428 L .42874 .77451 L F
.006 0 .034 r
.50509 .70728 m .50269 .70981 L .50435 .70835 L F
0 0 0 r
.50269 .70981 m .50372 .70924 L .50435 .70835 L F
.50269 .70981 m .50125 .71104 L .50372 .70924 L F
.549 .337 .545 r
.60519 .7149 m .60543 .71706 L .60326 .71733 L F
.568 .305 .478 r
.6084 .71425 m .60543 .71706 L .60519 .7149 L F
.459 .811 .997 r
.27719 .59741 m .27676 .59839 L .27524 .59742 L F
.27719 .59741 m .27874 .59806 L .27676 .59839 L F
.638 .573 .765 r
.38384 .67386 m .38558 .67117 L .38348 .67144 L F
.38384 .67386 m .38646 .67434 L .38558 .67117 L F
.275 .389 .798 r
.6749 .61766 m .67579 .61587 L .67472 .61576 L F
.6749 .61766 m .67762 .61947 L .67579 .61587 L F
.931 .953 .627 r
.63033 .67826 m .63171 .67695 L .63169 .67528 L F
.265 .326 .739 r
.30096 .73545 m .30186 .73621 L .30131 .7366 L F
0 0 .116 r
.30131 .7366 m .30186 .73621 L .3008 .73812 L F
.471 .079 .214 r
.33643 .65112 m .33853 .65102 L .33885 .65008 L F
.514 .12 .23 r
.33853 .65102 m .34072 .6511 L .33885 .65008 L F
.436 .201 .458 r
.59804 .70688 m .60014 .70648 L .60063 .70383 L F
.52 .276 .485 r
.60063 .70383 m .60014 .70648 L .60262 .70503 L F
.718 .473 .554 r
.45059 .74467 m .45061 .74832 L .44712 .74699 L F
.558 .327 .522 r
.45275 .74488 m .45061 .74832 L .45059 .74467 L F
.273 0 .142 r
.36815 .716 m .36742 .71453 L .3694 .71406 L F
.36815 .716 m .36625 .71666 L .36742 .71453 L F
.438 0 0 r
.68772 .59389 m .68363 .59427 L .68658 .59289 L F
.338 0 0 r
.68805 .59416 m .68772 .59389 L .68658 .59289 L F
.68805 .59416 m .68938 .59461 L .68772 .59389 L F
.582 .253 .378 r
.42782 .73569 m .43015 .73577 L .43133 .7333 L F
.605 .278 .39 r
.43015 .73577 m .43354 .73353 L .43133 .7333 L F
.745 .681 .789 r
.56814 .70084 m .57157 .7013 L .57053 .6983 L F
.214 0 0 r
.45891 .78298 m .45963 .78376 L .45747 .78383 L F
.45891 .78298 m .46105 .78269 L .45963 .78376 L F
.401 .533 .875 r
.66973 .60825 m .67112 .6114 L .67293 .61111 L F
.596 .699 .915 r
.38238 .653 m .37902 .6519 L .38098 .65188 L F
.593 .776 .967 r
.38436 .65246 m .38238 .653 L .38098 .65188 L F
0 .103 .649 r
.56704 .68186 m .56844 .68405 L .56695 .68233 L F
.479 .178 .377 r
.32102 .66251 m .32315 .66217 L .32361 .65958 L F
.416 .125 .359 r
.32361 .65958 m .32514 .66165 L .32551 .65947 L F
.32361 .65958 m .32315 .66217 L .32514 .66165 L F
.585 .15 .181 r
.59265 .75892 m .59154 .7605 L .58913 .76016 L F
.302 0 .019 r
.59487 .75847 m .59154 .7605 L .59265 .75892 L F
.272 0 .118 r
.36486 .70337 m .3656 .70486 L .36641 .70358 L F
.36486 .70337 m .36365 .70546 L .3656 .70486 L F
.869 .454 .233 r
.71222 .57977 m .71504 .58281 L .71325 .58076 L F
.638 .42 .571 r
.59166 .71389 m .59384 .71424 L .59392 .71206 L F
.591 .351 .522 r
.59384 .71424 m .59626 .71195 L .59392 .71206 L F
.379 .509 .863 r
.57392 .71924 m .57282 .72101 L .57241 .71816 L F
.57392 .71924 m .5755 .72196 L .57282 .72101 L F
.544 .544 .805 r
.57601 .72313 m .57282 .72101 L .5755 .72196 L F
.363 0 0 r
.45643 .77447 m .45828 .77504 L .45986 .77515 L F
.26 0 0 r
.45828 .77504 m .46208 .77516 L .45986 .77515 L F
.554 .233 .378 r
.67829 .58342 m .6808 .58322 L .68172 .58071 L F
.521 .162 .298 r
.6808 .58322 m .68392 .58136 L .68172 .58071 L F
.504 .675 .942 r
.32648 .82689 m .32932 .82714 L .32752 .82542 L F
.822 .594 .594 r
.69957 .58364 m .70244 .58745 L .69794 .58594 L F
.814 .628 .65 r
.70244 .58745 m .69969 .5898 L .69794 .58594 L F
.729 .836 .388 r
.29948 .72841 m .29974 .7276 L .29995 .72719 L F
.894 .484 .215 r
.30213 .72951 m .29948 .72841 L .29978 .72977 L F
.30213 .72951 m .29974 .7276 L .29948 .72841 L F
.704 .39 .442 r
.29974 .7276 m .30032 .72922 L .29883 .72935 L F
.29974 .7276 m .29883 .72935 L .29684 .72954 L F
.729 .836 .388 r
.29995 .72719 m .29974 .7276 L .30004 .72696 L F
.45 .588 .898 r
.49342 .77857 m .49231 .78014 L .491 .77795 L F
.49342 .77857 m .49367 .78024 L .49231 .78014 L F
.37 .415 .777 r
.60072 .73169 m .60316 .73325 L .60165 .73352 L F
.624 .507 .699 r
.29234 .69574 m .2947 .69551 L .29456 .69345 L F
.626 .525 .719 r
.29264 .69712 m .2947 .69551 L .29234 .69574 L F
.572 .44 .663 r
.29281 .69839 m .2947 .69551 L .29264 .69712 L F
.072 0 0 r
.42886 .78833 m .42786 .78895 L .42548 .78902 L F
0 0 0 r
.4309 .78786 m .42786 .78895 L .42886 .78833 L F
.163 0 0 r
.42886 .78833 m .43108 .78781 L .4309 .78786 L F
.522 .524 .798 r
.39712 .78611 m .3998 .78786 L .39866 .78499 L F
.837 .586 .559 r
.61417 .66579 m .61141 .66752 L .61124 .66521 L F
.61417 .66579 m .61421 .66809 L .61141 .66752 L F
.867 .473 .002 r
.58159 .75807 m .58107 .75786 L .58007 .75534 L F
.793 .361 .222 r
.58159 .75807 m .58048 .75945 L .58107 .75786 L F
.58159 .75807 m .58348 .76042 L .58048 .75945 L F
.896 .543 .369 r
.51631 .73411 m .51501 .73549 L .51444 .7334 L F
.788 .376 .269 r
.51631 .73411 m .51815 .73643 L .51501 .73549 L F
.911 .621 .482 r
.51785 .73339 m .51815 .73643 L .51631 .73411 L F
.344 .415 .792 r
.60207 .73016 m .60316 .73325 L .60072 .73169 L F
.383 0 .104 r
.58204 .72327 m .57872 .72516 L .58056 .72214 L F
.363 .192 .511 r
.58039 .72666 m .57872 .72516 L .58096 .72493 L F
.998 .797 .507 r
.58096 .72493 m .58039 .72666 L .58024 .72601 L F
.58096 .72493 m .58024 .72601 L .57995 .72469 L F
.383 0 .104 r
.58204 .72327 m .58096 .72493 L .57872 .72516 L F
.58204 .72327 m .58096 .72493 L .58204 .72327 L F
.369 0 .159 r
.58412 .7226 m .58096 .72493 L .58204 .72327 L F
.26 0 .075 r
.58935 .65695 m .59221 .65479 L .59012 .65573 L F
.544 .807 .994 r
.42243 .73615 m .42041 .73666 L .41897 .73574 L F
.458 .886 .888 r
.55105 .68678 m .55217 .6859 L .55391 .68474 L F
.55105 .68678 m .55016 .6867 L .55217 .6859 L F
.748 .592 .682 r
.51967 .73397 m .51961 .73667 L .51785 .73339 L F
.473 .324 .597 r
.28061 .61902 m .28267 .61594 L .28102 .61705 L F
.511 .84 .998 r
.41772 .73273 m .41559 .73322 L .41695 .73384 L F
.41772 .73273 m .41559 .73322 L .41695 .73384 L F
.341 0 .096 r
.35033 .67561 m .34873 .67789 L .3466 .67831 L F
.497 .123 .261 r
.35228 .67544 m .34873 .67789 L .35033 .67561 L F
.186 0 0 r
.53021 .78874 m .52687 .78877 L .52808 .78856 L F
.477 .223 .45 r
.58092 .7201 m .58324 .71974 L .58299 .71747 L F
.307 .107 .437 r
.58299 .71747 m .58324 .71974 L .58512 .71668 L F
.563 .446 .677 r
.42502 .76159 m .42215 .75804 L .42426 .75755 L F
.42502 .76159 m .42283 .76234 L .42215 .75804 L F
.855 .775 .772 r
.63614 .66206 m .63569 .65987 L .63381 .66257 L F
.852 .718 .715 r
.63508 .66603 m .63614 .66206 L .63381 .66257 L F
.879 .788 .757 r
.63614 .66206 m .637 .6593 L .63569 .65987 L F
.409 .547 .883 r
.38318 .67044 m .38348 .67144 L .38456 .67017 L F
.54 .748 .972 r
.38348 .67144 m .38558 .67117 L .38456 .67017 L F
0 0 0 r
.50435 .70835 m .50724 .70569 L .50509 .70728 L F
.127 .489 .902 r
.32465 .73434 m .32576 .73488 L .32366 .73291 L F
.32465 .73434 m .32366 .73291 L .32424 .73363 L F
.759 .767 .26 r
.32052 .72991 m .31964 .73374 L .32424 .73363 L F
.264 0 0 r
.46439 .78233 m .46318 .78275 L .46105 .78269 L F
.445 0 0 r
.46541 .78349 m .46439 .78233 L .46668 .78214 L F
.46541 .78349 m .46318 .78275 L .46439 .78233 L F
.435 .202 .46 r
.40207 .68632 m .40049 .68477 L .4025 .68417 L F
.40207 .68632 m .40015 .68684 L .40049 .68477 L F
.912 .964 .802 r
.63275 .66742 m .63345 .66849 L .63508 .66603 L F
.502 0 0 r
.52987 .71686 m .53219 .71848 L .53258 .71848 L F
.364 0 0 r
.53219 .71848 m .53491 .71948 L .53258 .71848 L F
.618 .803 .97 r
.69528 .6079 m .69875 .60841 L .69723 .60733 L F
.559 .783 .983 r
.69723 .60733 m .69875 .60841 L .70103 .60789 L F
.136 0 .309 r
.62268 .69238 m .62089 .69529 L .62137 .69336 L F
.345 .139 .451 r
.29284 .64001 m .29326 .6383 L .2955 .63763 L F
.44 0 0 r
.55301 .74634 m .55575 .74774 L .5532 .74744 L F
.545 .072 .084 r
.55575 .74774 m .55502 .74852 L .5532 .74744 L F
.858 .426 .189 r
.55502 .74852 m .55301 .74634 L .5532 .74744 L F
.126 0 0 r
.3693 .67143 m .36788 .67136 L .36573 .67112 L F
.968 .711 .492 r
.72923 .61425 m .73086 .61373 L .72962 .61252 L F
.978 .891 .668 r
.7302 .61538 m .73086 .61373 L .72923 .61425 L F
.824 .922 .901 r
.73086 .61373 m .73249 .6106 L .72962 .61252 L F
.73086 .61373 m .73347 .61145 L .73249 .6106 L F
.601 .426 .617 r
.40457 .74201 m .4069 .74415 L .40671 .74174 L F
.40457 .74201 m .40464 .74457 L .4069 .74415 L F
0 .213 .725 r
.39586 .77727 m .39522 .77739 L .39364 .77751 L F
.576 .221 .329 r
.39522 .77739 m .3982 .7796 L .39768 .77747 L F
0 .213 .725 r
.39586 .77727 m .3982 .7796 L .39522 .77739 L F
.627 .493 .679 r
.39522 .77739 m .39768 .77747 L .39721 .77464 L F
.92 .704 .593 r
.7224 .60509 m .72142 .60138 L .72327 .60292 L F
.693 .926 .968 r
.6961 .5963 m .69491 .59663 L .69518 .59672 L F
.515 0 0 r
.69834 .59722 m .6961 .5963 L .69518 .59672 L F
.172 .057 .472 r
.59882 .7092 m .60014 .70648 L .59804 .70688 L F
.54 .266 .448 r
.43354 .73353 m .43578 .73331 L .43618 .73137 L F
.545 .272 .453 r
.43578 .73331 m .43843 .73108 L .43618 .73137 L F
.283 .41 .814 r
.68363 .59427 m .6851 .59749 L .68661 .5965 L F
.27 .384 .795 r
.68661 .5965 m .6851 .59749 L .68604 .59795 L F
0 0 0 r
.48243 .72267 m .48382 .72229 L .48509 .72065 L F
.084 0 0 r
.48509 .72065 m .48571 .72149 L .48706 .7201 L F
.48509 .72065 m .48382 .72229 L .48571 .72149 L F
.818 .801 .835 r
.72312 .62082 m .72438 .62219 L .7268 .6195 L F
.553 .424 .659 r
.39731 .76101 m .39968 .76307 L .39945 .76065 L F
.39731 .76101 m .39759 .76357 L .39968 .76307 L F
.533 .333 .555 r
.40058 .7501 m .40274 .74971 L .4028 .74743 L F
.575 .464 .69 r
.4028 .74743 m .40505 .7472 L .40464 .74457 L F
.462 .228 .473 r
.40274 .74971 m .40505 .7472 L .4028 .74743 L F
0 0 0 r
.69957 .58364 m .70068 .5833 L .70049 .58335 L F
.822 .594 .594 r
.69957 .58364 m .69794 .58594 L .70068 .5833 L F
0 .206 .726 r
.55416 .73932 m .55574 .74005 L .55436 .73873 L F
.55416 .73932 m .55641 .74122 L .55574 .74005 L F
.946 .597 .314 r
.73167 .62822 m .73029 .62774 L .72962 .62513 L F
.553 .46 .703 r
.73331 .62723 m .73435 .62928 L .73186 .62828 L F
.73435 .62928 m .73465 .62987 L .73196 .62834 L F
.73435 .62928 m .73196 .62834 L .73186 .62828 L F
0 .354 .797 r
.73167 .62822 m .73465 .62987 L .73196 .62834 L F
.553 .46 .703 r
.73186 .62828 m .73465 .62987 L .73176 .62835 L F
.647 .378 .497 r
.73379 .63201 m .73465 .62987 L .73176 .62835 L F
.545 .371 .596 r
.73211 .62839 m .73379 .63201 L .73176 .62835 L F
.73591 .62895 m .73538 .62971 L .73211 .62839 L F
0 .354 .797 r
.73196 .62834 m .73465 .62987 L .73467 .62972 L F
.545 .371 .596 r
.73538 .62971 m .73519 .62999 L .73467 .62972 L F
.73477 .62946 m .73467 .62972 L .73211 .62839 L F
.73538 .62971 m .73467 .62972 L .73477 .62946 L F
.732 .799 .32 r
.73467 .62972 m .73465 .62987 L .73379 .63201 L F
0 .354 .797 r
.73196 .62834 m .73467 .62972 L .73199 .62835 L F
.545 .371 .596 r
.73519 .62999 m .73379 .63201 L .73211 .62841 L F
.73519 .62999 m .73211 .62841 L .73211 .62839 L F
.732 .799 .32 r
.73469 .62947 m .73467 .62972 L .73379 .63201 L F
0 .354 .797 r
.73199 .62835 m .73467 .62972 L .73469 .62947 L F
.7319 .62831 m .73469 .62947 L .73155 .62818 L F
.73196 .62834 m .73199 .62835 L .7319 .62831 L F
.73199 .62835 m .73469 .62947 L .7319 .62831 L F
.73155 .62818 m .73469 .62947 L .73029 .62774 L F
.73167 .62822 m .73196 .62834 L .73155 .62818 L F
.471 .119 .286 r
.44364 .73068 m .44582 .73039 L .44691 .72815 L F
.542 .2 .338 r
.44582 .73039 m .44914 .72807 L .44691 .72815 L F
.698 .187 .015 r
.29943 .73568 m .30186 .73621 L .30096 .73545 L F
.538 .329 .545 r
.30316 .73377 m .30096 .73545 L .30267 .73372 L F
.30316 .73377 m .30186 .73621 L .30096 .73545 L F
.209 .432 .858 r
.35075 .70769 m .35123 .70846 L .3498 .70899 L F
.606 .106 .04 r
.3498 .70899 m .3541 .70937 L .352 .70966 L F
.3498 .70899 m .3524 .71033 L .3541 .70937 L F
.209 .432 .858 r
.35123 .70846 m .3524 .71033 L .3498 .70899 L F
.287 .734 .961 r
.34923 .7092 m .3498 .70899 L .352 .70966 L F
.34838 .70906 m .3498 .70899 L .34923 .7092 L F
.507 .348 .599 r
.55846 .69293 m .5608 .69513 L .56028 .69238 L F
.55846 .69293 m .55855 .69585 L .5608 .69513 L F
.851 .935 .558 r
.61205 .69049 m .61223 .68903 L .61356 .68739 L F
0 0 .267 r
.61115 .69249 m .61223 .68903 L .61205 .69049 L F
.534 .323 .539 r
.42584 .75711 m .42407 .7556 L .42739 .75462 L F
.42584 .75711 m .42426 .75755 L .42407 .7556 L F
.733 .765 .878 r
.70992 .61069 m .71105 .61269 L .71321 .61101 L F
0 0 0 r
.61335 .70958 m .61172 .71204 L .61135 .7124 L F
0 0 .056 r
.614 .71052 m .61335 .70958 L .61406 .70784 L F
.614 .71052 m .61172 .71204 L .61335 .70958 L F
.567 .388 .598 r
.40058 .7501 m .40277 .7521 L .40274 .74971 L F
.40058 .7501 m .40056 .75243 L .40277 .7521 L F
.492 0 0 r
.53369 .78836 m .53472 .78934 L .53304 .78917 L F
.53369 .78836 m .53574 .78965 L .53472 .78934 L F
.605 .205 .26 r
.53369 .78836 m .53608 .7887 L .53574 .78965 L F
0 0 0 r
.43287 .78727 m .43108 .78781 L .4325 .78744 L F
.43287 .78727 m .4309 .78786 L .43108 .78781 L F
.70049 .58335 m .70322 .58021 L .70228 .58206 L F
.055 0 0 r
.47883 .72423 m .48093 .7237 L .48243 .72267 L F
0 0 0 r
.48243 .72267 m .48093 .7237 L .48382 .72229 L F
.224 0 .03 r
.48155 .73589 m .48473 .73335 L .48385 .73576 L F
.419 .127 .36 r
.48473 .73335 m .48613 .73535 L .48385 .73576 L F
.48473 .73335 m .48676 .73308 L .48613 .73535 L F
.529 .604 .872 r
.7013 .60949 m .703 .60754 L .70103 .60789 L F
.7013 .60949 m .7042 .61019 L .703 .60754 L F
.512 .259 .468 r
.38198 .70388 m .38157 .7059 L .37968 .7061 L F
.471 .222 .455 r
.38342 .70534 m .38198 .70388 L .38392 .70334 L F
.38342 .70534 m .38157 .7059 L .38198 .70388 L F
.576 .324 .497 r
.61135 .7124 m .61068 .71409 L .6084 .71425 L F
.546 .433 .675 r
.68018 .59129 m .67714 .58909 L .68002 .58908 L F
.68018 .59129 m .6778 .59217 L .67714 .58909 L F
.341 .173 .502 r
.31274 .6108 m .31077 .61407 L .31059 .61106 L F
.97 .851 .668 r
.61596 .67667 m .61497 .67612 L .61581 .67338 L F
.977 .856 .464 r
.61596 .67667 m .61505 .67808 L .61497 .67612 L F
.61596 .67667 m .61552 .67958 L .61505 .67808 L F
0 .347 .691 r
.29129 .60049 m .28803 .59915 L .29004 .59879 L F
.406 .612 .934 r
.29188 .59891 m .29129 .60049 L .29004 .59879 L F
.505 .724 .971 r
.29188 .59891 m .29333 .60027 L .29129 .60049 L F
.733 .695 .814 r
.38194 .79869 m .38323 .8014 L .3856 .79913 L F
.76 .527 .58 r
.38664 .8045 m .38323 .8014 L .38547 .80251 L F
.355 0 .019 r
.35409 .72234 m .35041 .72428 L .3523 .72333 L F
.402 0 .055 r
.47147 .72591 m .47389 .72575 L .47466 .72489 L F
.116 0 0 r
.47389 .72575 m .47678 .72492 L .47466 .72489 L F
.469 0 .025 r
.45652 .74453 m .45275 .74488 L .45202 .74469 L F
.752 .761 .86 r
.5897 .72813 m .59127 .72621 L .58967 .72491 L F
.092 .057 .521 r
.29297 .64285 m .29162 .64047 L .29284 .64001 L F
.29297 .64285 m .29177 .64366 L .29162 .64047 L F
.784 .699 .77 r
.5193 .72755 m .52331 .72949 L .52171 .72478 L F
.897 .499 .252 r
.52181 .72953 m .52331 .72949 L .5193 .72755 L F
.52181 .72953 m .52276 .7303 L .52331 .72949 L F
.24 .269 .69 r
.52331 .72949 m .52394 .72441 L .52171 .72478 L F
.52417 .72897 m .52542 .72821 L .5252 .72765 L F
.364 .342 .701 r
.52394 .72441 m .52542 .72821 L .52618 .72627 L F
0 0 0 r
.52569 .72704 m .52514 .72856 L .52432 .72913 L F
.52618 .72627 m .52604 .72658 L .52569 .72704 L F
.52604 .72658 m .52514 .72856 L .52569 .72704 L F
.24 .269 .69 r
.52331 .72949 m .52417 .72897 L .52394 .72441 L F
.52417 .72897 m .5252 .72765 L .52394 .72441 L F
.498 .392 .665 r
.52276 .7303 m .52542 .72821 L .52331 .72949 L F
.805 .604 .63 r
.63529 .64636 m .63211 .64357 L .63366 .64682 L F
.839 .723 .736 r
.63366 .64682 m .63328 .64909 L .63529 .64636 L F
.238 .539 .924 r
.49909 .78544 m .5013 .78606 L .50088 .78498 L F
.576 .661 .895 r
.70172 .59903 m .69958 .5995 L .69834 .59722 L F
.413 .837 .677 r
.7099 .71858 m .7113 .71789 L .70842 .71953 L F
0 0 0 r
.71349 .71713 m .7113 .71789 L .7099 .71858 L F
.572 .44 .663 r
.29281 .69839 m .29491 .69805 L .2947 .69551 L F
.593 .391 .577 r
.29251 .70066 m .29491 .69805 L .29281 .69839 L F
.366 .538 .892 r
.66753 .60794 m .66875 .60703 L .66862 .605 L F
.66753 .60794 m .66973 .60825 L .66875 .60703 L F
.728 .222 0 r
.57811 .69294 m .57728 .6925 L .57529 .69002 L F
.992 .874 .607 r
.57781 .68945 m .57728 .6925 L .57811 .69294 L F
.532 .346 .574 r
.3494 .85359 m .35138 .85594 L .35147 .85328 L F
.963 .721 .523 r
.35147 .85328 m .35138 .85594 L .3494 .85359 L F
.536 .447 .702 r
.42656 .76826 m .42517 .772 L .42438 .76876 L F
.42656 .76826 m .42723 .77155 L .42517 .772 L F
.556 .365 .577 r
.32596 .69552 m .32378 .69836 L .32434 .69618 L F
.655 .563 .739 r
.42644 .76619 m .424 .76651 L .42302 .76305 L F
.618 .483 .676 r
.42656 .76826 m .424 .76651 L .42644 .76619 L F
.42656 .76826 m .42438 .76876 L .424 .76651 L F
.319 0 0 r
.70571 .72036 m .7085 .72008 L .70842 .71953 L F
0 0 0 r
.70842 .71953 m .7085 .72008 L .7099 .71858 L F
.32 0 0 r
.58191 .70958 m .58056 .71088 L .57826 .71118 L F
.89 .626 .111 r
.58108 .70587 m .58144 .70877 L .58191 .70958 L F
.968 .927 .609 r
.58144 .70877 m .58056 .71088 L .58191 .70958 L F
.769 .722 .809 r
.65518 .60542 m .65838 .60582 L .65758 .60285 L F
.137 .648 .898 r
.59236 .74262 m .59363 .74287 L .59329 .74304 L F
.59363 .74287 m .59558 .74326 L .59329 .74304 L F
0 0 0 r
.59417 .74175 m .59265 .74335 L .59329 .74304 L F
.59265 .74335 m .59174 .74431 L .59329 .74304 L F
.034 0 .266 r
.73454 .59682 m .73306 .59927 L .73333 .59778 L F
.1 0 0 r
.46208 .77516 m .4639 .77519 L .46549 .77477 L F
.005 0 0 r
.4639 .77519 m .46762 .77435 L .46549 .77477 L F
.66 .793 .946 r
.58087 .73148 m .57716 .73107 L .5794 .73069 L F
.666 .224 .193 r
.5794 .73069 m .58308 .73073 L .58087 .73148 L F
.528 .634 .899 r
.33243 .70576 m .33181 .70804 L .33041 .70648 L F
.33243 .70576 m .33388 .70805 L .33181 .70804 L F
.401 .148 .412 r
.39812 .68732 m .3977 .68961 L .39569 .69008 L F
.45 .186 .42 r
.40015 .68684 m .3977 .68961 L .39812 .68732 L F
.502 .276 .503 r
.29822 .68479 m .30024 .68438 L .3006 .68218 L F
.525 .296 .51 r
.3006 .68218 m .3023 .68398 L .30272 .68174 L F
.3006 .68218 m .30024 .68438 L .3023 .68398 L F
.55 .3 .49 r
.54147 .78557 m .54121 .7876 L .5391 .78791 L F
.805 .79 .839 r
.54367 .78293 m .54147 .78557 L .54085 .78337 L F
.02 0 0 r
.54296 .78652 m .54121 .7876 L .54147 .78557 L F
.596 .462 .669 r
.54367 .78293 m .54376 .78572 L .54147 .78557 L F
.51 .074 .148 r
.54376 .78572 m .54296 .78652 L .54147 .78557 L F
.536 .419 .667 r
.39888 .75578 m .40088 .75572 L .40056 .75243 L F
.582 .433 .645 r
.39888 .75578 m .40132 .75786 L .40088 .75572 L F
.39888 .75578 m .39901 .75829 L .40132 .75786 L F
.346 .578 .928 r
.30126 .60084 m .29976 .60147 L .29878 .60079 L F
.30126 .60084 m .30241 .60245 L .29976 .60147 L F
0 0 .064 r
.59387 .73677 m .59455 .73603 L .59544 .73371 L F
.575 .405 .614 r
.60569 .71887 m .60326 .71733 L .60543 .71706 L F
.60569 .71887 m .60351 .71969 L .60326 .71733 L F
.431 0 0 r
.33217 .73646 m .33059 .73622 L .3288 .73549 L F
.3288 .73549 m .33059 .73622 L .33217 .73646 L F
.298 .237 .618 r
.33041 .73346 m .33059 .73622 L .32905 .73383 L F
.579 .331 .504 r
.32905 .73383 m .33059 .73622 L .3288 .73549 L F
.56 .422 .649 r
.71611 .72404 m .71801 .72567 L .7157 .72613 L F
.429 .417 .744 r
.71977 .72367 m .71611 .72404 L .71902 .72189 L F
.71977 .72367 m .71801 .72567 L .71611 .72404 L F
.254 .476 .88 r
.51518 .70511 m .51674 .70551 L .51581 .70662 L F
.39 .678 .974 r
.51674 .70551 m .51792 .70673 L .51581 .70662 L F
.203 0 .031 r
.5751 .66757 m .57692 .66764 L .57785 .66585 L F
.06 0 0 r
.57785 .66585 m .57871 .66662 L .58005 .6653 L F
.57785 .66585 m .57692 .66764 L .57871 .66662 L F
.661 .704 .879 r
.32594 .73496 m .32667 .73662 L .3288 .73549 L F
.691 .441 .54 r
.72416 .58191 m .72574 .58089 L .72389 .58089 L F
.584 .346 .522 r
.42946 .75285 m .42944 .75501 L .42739 .75462 L F
.681 .449 .564 r
.43176 .7526 m .42944 .75501 L .42946 .75285 L F
0 .168 .706 r
.54464 .70366 m .5447 .70271 L .54273 .70072 L F
0 .192 .723 r
.54464 .70366 m .54625 .70534 L .5447 .70271 L F
.583 .461 .679 r
.61819 .6434 m .62096 .64326 L .61964 .64054 L F
.549 .285 .467 r
.61997 .64547 m .61819 .6434 L .61768 .6455 L F
.61997 .64547 m .62096 .64326 L .61819 .6434 L F
.911 .621 .482 r
.51785 .73339 m .51961 .73667 L .51815 .73643 L F
.744 .517 .585 r
.53603 .7363 m .5404 .73669 L .53847 .73598 L F
.53603 .7363 m .53624 .73845 L .5404 .73669 L F
.746 .485 .537 r
.5396 .74081 m .53624 .73845 L .5404 .73669 L F
.5396 .74081 m .53567 .74129 L .53624 .73845 L F
.803 .988 .73 r
.53567 .74129 m .5404 .73669 L .53624 .73845 L F
.283 .063 .393 r
.53485 .74041 m .53567 .74129 L .53411 .74147 L F
.53624 .73845 m .53585 .74037 L .53485 .74041 L F
.53585 .74037 m .53567 .74129 L .53485 .74041 L F
.53411 .74147 m .53567 .74129 L .53613 .73898 L F
.53603 .73875 m .53613 .73898 L .53624 .73845 L F
.53411 .74147 m .53613 .73898 L .53603 .73875 L F
.645 .39 .518 r
.5396 .74081 m .53629 .74345 L .53567 .74129 L F
.5396 .74081 m .53895 .74337 L .53629 .74345 L F
.489 .241 .464 r
.54164 .74275 m .53895 .74337 L .5396 .74081 L F
.473 .498 .803 r
.53672 .74033 m .53949 .74197 L .53838 .73911 L F
.53524 .74143 m .53732 .74169 L .53672 .74033 L F
.53732 .74169 m .53949 .74197 L .53672 .74033 L F
.283 .063 .393 r
.53624 .73845 m .53567 .74129 L .53411 .74147 L F
.803 .988 .73 r
.53567 .74129 m .53524 .74143 L .5404 .73669 L F
.211 0 .019 r
.5404 .73669 m .53642 .74035 L .53838 .73911 L F
.53642 .74035 m .53524 .74143 L .53672 .74033 L F
.53642 .74035 m .53672 .74033 L .53838 .73911 L F
.79 .878 .911 r
.54026 .73516 m .53847 .73598 L .5404 .73669 L F
.615 .669 .878 r
.53838 .73911 m .5396 .74081 L .5404 .73669 L F
.497 .296 .538 r
.30723 .67415 m .30929 .67372 L .3094 .67088 L F
.479 .306 .568 r
.3094 .67088 m .31143 .67058 L .31129 .66801 L F
.432 .244 .524 r
.3094 .67088 m .31112 .67297 L .31143 .67058 L F
.3094 .67088 m .30929 .67372 L .31112 .67297 L F
.524 .511 .784 r
.57601 .72313 m .57872 .72516 L .57692 .72561 L F
.521 .589 .864 r
.27311 .6085 m .275 .6075 L .27223 .6074 L F
.27311 .6085 m .27503 .60878 L .275 .6075 L F
.963 .721 .523 r
.35147 .85328 m .35277 .85629 L .35138 .85594 L F
.958 .683 .472 r
.35138 .85594 m .35277 .85629 L .35289 .85866 L F
.003 .213 .725 r
.35343 .8554 m .35277 .85629 L .35147 .85328 L F
0 0 .309 r
.35289 .85866 m .35277 .85629 L .35343 .8554 L F
.847 .645 .63 r
.637 .6593 m .63584 .65741 L .63569 .65987 L F
.625 .542 .74 r
.32372 .70051 m .32181 .70313 L .32166 .70134 L F
.32372 .70051 m .32465 .70477 L .32181 .70313 L F
.911 .62 .48 r
.51815 .73643 m .51961 .73667 L .5186 .73829 L F
.796 .89 .473 r
.51961 .73667 m .51812 .73959 L .5186 .73829 L F
.737 .545 .634 r
.51961 .73667 m .52016 .7396 L .51812 .73959 L F
.467 .364 .654 r
.52176 .73851 m .51961 .73667 L .52219 .73634 L F
.52176 .73851 m .52016 .7396 L .51961 .73667 L F
.912 .964 .802 r
.63275 .66742 m .63508 .66603 L .63353 .66495 L F
.852 .718 .715 r
.63508 .66603 m .63381 .66257 L .63353 .66495 L F
0 .35 .78 r
.53366 .78286 m .53249 .78264 L .53161 .78176 L F
.53366 .78286 m .53482 .78379 L .53249 .78264 L F
.478 .766 .994 r
.51141 .79466 m .51253 .79557 L .51429 .79525 L F
.687 .684 .841 r
.41041 .66568 m .40692 .6649 L .41088 .66488 L F
0 0 0 r
.41088 .66488 m .41085 .66499 L .41041 .66568 L F
.325 .746 .976 r
.41085 .66499 m .41251 .66562 L .41041 .66568 L F
.568 .305 .478 r
.6084 .71425 m .60796 .71691 L .60543 .71706 L F
.533 .274 .468 r
.61068 .71617 m .6084 .71425 L .61068 .71409 L F
.61068 .71617 m .60796 .71691 L .6084 .71425 L F
.42 .202 .474 r
.28141 .6243 m .27957 .62489 L .27922 .62705 L F
.115 0 0 r
.44226 .78589 m .44018 .78641 L .43898 .7865 L F
.17 .708 .772 r
.44445 .78593 m .44018 .78641 L .44226 .78589 L F
.555 .407 .635 r
.3025 .67906 m .30447 .67628 L .30226 .67672 L F
.493 .895 .935 r
.69462 .59147 m .69629 .59039 L .69398 .59121 L F
.69462 .59147 m .69715 .59063 L .69629 .59039 L F
.7 .404 .471 r
.31761 .66413 m .32102 .66251 L .31908 .66305 L F
.682 .517 .656 r
.62316 .64104 m .6254 .63828 L .62311 .63854 L F
.62316 .64104 m .62641 .64111 L .6254 .63828 L F
.655 .503 .665 r
.6254 .63828 m .6288 .63858 L .62766 .63573 L F
.65 .543 .719 r
.62875 .64087 m .6254 .63828 L .62641 .64111 L F
.62875 .64087 m .6288 .63858 L .6254 .63828 L F
.508 .228 .424 r
.3718 .69818 m .37396 .69789 L .37448 .69595 L F
.488 .228 .446 r
.37396 .69789 m .37653 .6954 L .37448 .69595 L F
.724 .568 .678 r
.63096 .63811 m .63322 .6355 L .63094 .63556 L F
.63096 .63811 m .6343 .63847 L .63322 .6355 L F
.494 .299 .545 r
.39569 .69008 m .3956 .69234 L .39359 .69277 L F
.421 .146 .387 r
.39502 .69463 m .39359 .69277 L .3956 .69234 L F
.39502 .69463 m .39303 .6952 L .39359 .69277 L F
.153 .526 .919 r
.55992 .68717 m .56062 .68695 L .55927 .68644 L F
.833 .474 .376 r
.55992 .68717 m .56092 .68998 L .56341 .69016 L F
0 0 .516 r
.56125 .68884 m .56092 .68998 L .55992 .68717 L F
.833 .474 .376 r
.55992 .68717 m .56341 .69016 L .56242 .68718 L F
.968 .713 .495 r
.55795 .68547 m .55781 .68841 L .55927 .68644 L F
0 .461 .843 r
.55927 .68644 m .55777 .68542 L .55795 .68547 L F
.55927 .68644 m .56062 .68695 L .5582 .68565 L F
.763 .25 0 r
.55933 .68756 m .55927 .68644 L .55781 .68841 L F
.622 .398 .556 r
.55933 .68756 m .55781 .68841 L .55794 .68555 L F
.55802 .68558 m .55794 .68555 L .55795 .68547 L F
0 .461 .843 r
.558 .68557 m .55802 .68558 L .55799 .68557 L F
.622 .398 .556 r
.55933 .68756 m .55794 .68555 L .55802 .68558 L F
0 .461 .843 r
.55799 .68557 m .5582 .68565 L .55777 .68542 L F
.622 .398 .556 r
.55802 .68558 m .55795 .68547 L .55839 .68565 L F
.489 .716 .971 r
.5582 .68565 m .56062 .68695 L .56116 .68641 L F
.55857 .68565 m .56116 .68641 L .56189 .68569 L F
.5582 .68565 m .56116 .68641 L .55857 .68565 L F
0 .395 .683 r
.55777 .68542 m .56099 .68636 L .55857 .68565 L F
.55777 .68542 m .55857 .68565 L .55795 .68547 L F
.622 .398 .556 r
.5582 .68565 m .55839 .68565 L .56068 .68658 L F
.55802 .68558 m .55839 .68565 L .5582 .68565 L F
.489 .716 .971 r
.55777 .68542 m .5582 .68565 L .56229 .6853 L F
.5582 .68565 m .56189 .68569 L .56229 .6853 L F
0 .461 .843 r
.55802 .68558 m .5582 .68565 L .55799 .68557 L F
.55927 .68644 m .5582 .68565 L .558 .68557 L F
.622 .398 .556 r
.56068 .68658 m .55795 .68547 L .56099 .68636 L F
0 0 .516 r
.56002 .68735 m .55992 .68717 L .55927 .68644 L F
.763 .25 0 r
.55933 .68756 m .56125 .68884 L .55927 .68644 L F
.622 .398 .556 r
.55933 .68756 m .55802 .68558 L .56068 .68658 L F
.584 .93 .742 r
.56062 .68695 m .55993 .68728 L .56229 .6853 L F
.55993 .68728 m .55933 .68756 L .55982 .68719 L F
.55993 .68728 m .55982 .68719 L .56229 .6853 L F
0 0 .516 r
.56125 .68884 m .56015 .68745 L .56002 .68735 L F
.56015 .68745 m .55992 .68717 L .56002 .68735 L F
.212 .723 .889 r
.56242 .68718 m .56062 .68695 L .55992 .68717 L F
.759 .44 .445 r
.50373 .78465 m .50708 .78482 L .50645 .78299 L F
0 0 .18 r
.62698 .6868 m .6251 .68978 L .62576 .68787 L F
.66 .706 .881 r
.30954 .72768 m .31065 .72957 L .31281 .72845 L F
.484 .815 1 r
.34376 .70618 m .34299 .70723 L .34158 .70659 L F
.34376 .70618 m .34474 .70694 L .34299 .70723 L F
.307 0 0 r
.61064 .64786 m .6122 .64817 L .61344 .64683 L F
.398 0 0 r
.61344 .64683 m .61396 .64785 L .61559 .64629 L F
.61344 .64683 m .6122 .64817 L .61396 .64785 L F
.329 0 0 r
.68604 .58045 m .68825 .58007 L .68933 .57874 L F
.393 0 .024 r
.68933 .57874 m .6913 .57923 L .69146 .57785 L F
.68933 .57874 m .68825 .58007 L .6913 .57923 L F
.428 .524 .854 r
.70327 .59158 m .70437 .59394 L .70627 .59423 L F
.221 .63 .955 r
.69172 .59497 m .69491 .59663 L .68938 .59461 L F
0 .289 .673 r
.69518 .59672 m .69491 .59663 L .69172 .59497 L F
.478 .262 .506 r
.27696 .62956 m .27922 .62705 L .27724 .62754 L F
.319 0 .027 r
.72248 .71965 m .71902 .72189 L .72017 .7202 L F
.357 .328 .689 r
.56785 .7361 m .56993 .73823 L .56835 .73351 L F
.194 0 0 r
.5751 .66757 m .57387 .66936 L .57692 .66764 L F
.852 .458 .297 r
.56242 .68718 m .56125 .68884 L .56062 .68695 L F
.65 .536 .711 r
.56242 .68718 m .56574 .68991 L .56575 .6866 L F
.56346 .68804 m .56341 .69016 L .56574 .68991 L F
.56242 .68718 m .56283 .68841 L .56346 .68804 L F
.56283 .68841 m .56341 .69016 L .56346 .68804 L F
0 0 0 r
.56556 .68791 m .56385 .68868 L .56558 .68678 L F
.56573 .68669 m .56558 .68678 L .56575 .6866 L F
.56556 .68791 m .56558 .68678 L .56573 .68669 L F
.469 .019 .099 r
.56575 .6866 m .56125 .68884 L .56242 .68718 L F
.459 .224 .468 r
.34394 .68022 m .34233 .67915 L .34456 .67865 L F
.34394 .68022 m .34197 .68093 L .34233 .67915 L F
.387 0 0 r
.47578 .78184 m .47976 .78212 L .47783 .78198 L F
.484 0 0 r
.47976 .78212 m .48119 .78254 L .47783 .78198 L F
.503 .741 .98 r
.37068 .64824 m .37 .64968 L .36879 .64803 L F
.37068 .64824 m .37208 .64946 L .37 .64968 L F
.73 .227 0 r
.50307 .78759 m .50293 .78819 L .5013 .78606 L F
.50307 .78759 m .50441 .78929 L .50293 .78819 L F
.629 .811 .97 r
.55246 .6952 m .55041 .69599 L .54908 .69485 L F
.123 0 0 r
.41869 .79002 m .41681 .79007 L .41832 .78967 L F
.41869 .79002 m .41659 .79078 L .41681 .79007 L F
.146 0 0 r
.36247 .7182 m .36088 .71967 L .35935 .71963 L F
.098 0 0 r
.36286 .71902 m .36247 .7182 L .36435 .71747 L F
.36286 .71902 m .36088 .71967 L .36247 .7182 L F
.657 .844 .438 r
.58107 .67524 m .58027 .67666 L .58214 .67374 L F
.614 .89 .578 r
.58456 .67111 m .58318 .67234 L .58214 .67374 L F
0 0 0 r
.58318 .67234 m .58107 .67524 L .58214 .67374 L F
.734 .584 .688 r
.6288 .63858 m .63094 .63556 L .62766 .63573 L F
.181 .529 .922 r
.3778 .65053 m .37959 .65106 L .37902 .6519 L F
.332 .721 .983 r
.37959 .65106 m .38098 .65188 L .37902 .6519 L F
.849 .793 .796 r
.40873 .79242 m .40994 .79376 L .412 .79132 L F
.40873 .79242 m .412 .79132 L .41047 .79222 L F
.648 .947 .718 r
.41269 .79018 m .412 .79132 L .41432 .79127 L F
.41269 .79018 m .41047 .79222 L .412 .79132 L F
.276 0 0 r
.44058 .77448 m .44001 .77414 L .43843 .77399 L F
.44058 .77448 m .44185 .77471 L .44001 .77414 L F
.496 .906 .864 r
.51259 .70547 m .51356 .70448 L .51518 .70511 L F
.51259 .70547 m .51125 .70558 L .51356 .70448 L F
0 0 .316 r
.61356 .68739 m .61501 .68631 L .61529 .6838 L F
0 0 0 r
.61356 .68739 m .61223 .68903 L .61501 .68631 L F
.462 0 0 r
.53482 .78379 m .53689 .78414 L .53798 .78306 L F
.623 .212 .243 r
.53689 .78414 m .54085 .78337 L .53798 .78306 L F
.94 .588 .318 r
.50441 .78929 m .50589 .79081 L .50486 .78992 L F
0 .115 .666 r
.50589 .79081 m .50719 .79159 L .50486 .78992 L F
.50589 .79081 m .50791 .79307 L .50719 .79159 L F
.638 .333 .439 r
.58856 .71431 m .59082 .71652 L .59166 .71389 L F
.721 .467 .541 r
.59082 .71652 m .59384 .71424 L .59166 .71389 L F
.548 .424 .662 r
.29822 .68479 m .30049 .68675 L .30024 .68438 L F
.29822 .68479 m .29852 .68727 L .30049 .68675 L F
.745 .771 .874 r
.72276 .73519 m .72047 .73637 L .72379 .7366 L F
.781 .518 .539 r
.72047 .73637 m .72271 .73673 L .72379 .7366 L F
.621 .726 .921 r
.72276 .73519 m .72379 .7366 L .72676 .73576 L F
.428 .1 .305 r
.37664 .70933 m .37397 .71128 L .37468 .70975 L F
.73 .21 0 r
.58922 .7159 m .58856 .71431 L .58735 .71486 L F
.58922 .7159 m .59082 .71652 L .58856 .71431 L F
.91 .694 .598 r
.7223 .61123 m .72223 .61366 L .72075 .61043 L F
.309 .472 .859 r
.55325 .71243 m .55457 .71119 L .55261 .71139 L F
.55325 .71243 m .5561 .71381 L .55457 .71119 L F
.653 .454 .602 r
.49516 .73076 m .49273 .73347 L .49272 .73094 L F
.126 0 0 r
.71888 .71444 m .71556 .71622 L .71807 .71625 L F
.347 0 .072 r
.72023 .71569 m .71888 .71444 L .71807 .71625 L F
.72023 .71569 m .72121 .71401 L .71888 .71444 L F
.597 .276 .396 r
.59875 .65087 m .60205 .64867 L .59966 .64898 L F
.024 0 0 r
.35971 .70667 m .36008 .70739 L .36184 .70629 L F
.35971 .70667 m .35817 .70817 L .36008 .70739 L F
.473 .25 .494 r
.37878 .6897 m .38075 .6894 L .38112 .68748 L F
.461 .309 .587 r
.37859 .69222 m .38075 .6894 L .37878 .6897 L F
.591 .403 .596 r
.33211 .68951 m .32995 .68749 L .33215 .68742 L F
.33211 .68951 m .33027 .68998 L .32995 .68749 L F
.363 0 .001 r
.34072 .6511 m .34285 .65092 L .34436 .64942 L F
.37 0 0 r
.34285 .65092 m .34657 .64947 L .34436 .64942 L F
.642 .762 .936 r
.71715 .73581 m .71836 .73725 L .72047 .73637 L F
.556 .368 .581 r
.41416 .67073 m .41408 .6737 L .41191 .6738 L F
.637 .594 .789 r
.41626 .6671 m .41618 .67025 L .41416 .67073 L F
.485 .274 .517 r
.41618 .67025 m .41408 .6737 L .41416 .67073 L F
.436 .385 .703 r
.39721 .77464 m .39847 .7712 L .39619 .77154 L F
.39721 .77464 m .399 .77433 L .39847 .7712 L F
.566 .451 .681 r
.39721 .77464 m .39978 .77685 L .399 .77433 L F
.39721 .77464 m .39768 .77747 L .39978 .77685 L F
.917 .76 .671 r
.72142 .60302 m .72015 .60503 L .72212 .60624 L F
.72142 .60302 m .72015 .60503 L .72212 .60624 L F
.504 .373 .636 r
.73331 .62723 m .73591 .62895 L .73176 .62835 L F
.487 .156 .331 r
.33723 .68238 m .33671 .68392 L .33469 .68399 L F
.453 .11 .293 r
.33937 .68211 m .33671 .68392 L .33723 .68238 L F
.413 .082 .292 r
.33312 .65423 m .33518 .65377 L .33643 .65112 L F
.324 0 .153 r
.33518 .65377 m .33853 .65102 L .33643 .65112 L F
.539 .331 .547 r
.59626 .71195 m .5986 .71153 L .59882 .7092 L F
.172 .057 .472 r
.59882 .7092 m .5999 .70871 L .60014 .70648 L F
.249 .233 .645 r
.59882 .7092 m .60063 .71096 L .5999 .70871 L F
.442 .249 .522 r
.59882 .7092 m .5986 .71153 L .60063 .71096 L F
.818 .801 .835 r
.72312 .62082 m .7268 .6195 L .72561 .61858 L F
.818 .858 .877 r
.72561 .61858 m .7268 .6195 L .72919 .61712 L F
.411 .218 .506 r
.3977 .68961 m .3956 .69234 L .39569 .69008 L F
.677 .633 .797 r
.40189 .78789 m .40283 .79058 L .40518 .78793 L F
.644 .58 .768 r
.40283 .79058 m .40611 .79124 L .40518 .78793 L F
.158 .047 .467 r
.59455 .73603 m .59641 .73256 L .59544 .73371 L F
.393 .735 .991 r
.28211 .59886 m .27874 .59806 L .2807 .59793 L F
.488 .805 1 r
.28273 .59767 m .28211 .59886 L .2807 .59793 L F
.28273 .59767 m .28453 .59855 L .28211 .59886 L F
.647 .141 .03 r
.50708 .78482 m .509 .78647 L .51017 .78526 L F
.591 .351 .522 r
.59384 .71424 m .59619 .71416 L .59626 .71195 L F
.561 .344 .543 r
.59619 .71416 m .5986 .71153 L .59626 .71195 L F
.539 .729 .962 r
.30316 .73377 m .30544 .73353 L .3041 .73215 L F
.637 .858 .983 r
.5712 .69373 m .57231 .69499 L .571 .6944 L F
.534 .606 .871 r
.571 .6944 m .56685 .69348 L .56915 .69281 L F
.637 .858 .983 r
.5712 .69373 m .571 .6944 L .56915 .69281 L F
.928 .843 .74 r
.56934 .69738 m .57231 .69499 L .5712 .69373 L F
.56934 .69738 m .57053 .6983 L .57231 .69499 L F
.692 .38 .442 r
.40917 .73891 m .41118 .74101 L .4123 .73854 L F
.634 .467 .639 r
.4123 .73854 m .41456 .73874 L .41491 .73655 L F
.558 .212 .339 r
.41118 .74101 m .41456 .73874 L .4123 .73854 L F
.452 0 0 r
.4868 .78323 m .48887 .78407 L .48647 .7842 L F
.468 .727 .982 r
.29736 .5995 m .29682 .60094 L .29531 .5998 L F
.29736 .5995 m .29878 .60079 L .29682 .60094 L F
.697 .398 .467 r
.57529 .69002 m .57156 .69207 L .57229 .68999 L F
.57529 .69002 m .57567 .69251 L .57156 .69207 L F
.698 .4 .466 r
.57529 .69002 m .57728 .6925 L .57567 .69251 L F
.682 .887 .973 r
.71011 .73215 m .7109 .73278 L .71372 .73186 L F
.735 .219 0 r
.73226 .60595 m .73239 .60549 L .73135 .60464 L F
.73226 .60595 m .73375 .60722 L .73239 .60549 L F
.565 .541 .787 r
.38646 .67434 m .38758 .671 L .38558 .67117 L F
.38646 .67434 m .38816 .67394 L .38758 .671 L F
.498 .392 .664 r
.38694 .67646 m .38816 .67394 L .38646 .67434 L F
.038 .209 .712 r
.66642 .6029 m .66862 .605 L .66734 .60175 L F
.483 0 0 r
.72612 .7198 m .72482 .72015 L .72248 .71965 L F
.633 .072 0 r
.72757 .72194 m .72482 .72015 L .72612 .7198 L F
.71 .669 .808 r
.56092 .68998 m .56336 .69201 L .56341 .69016 L F
.616 .383 .541 r
.56336 .69201 m .56574 .68991 L .56341 .69016 L F
.598 .566 .789 r
.42525 .76261 m .42302 .76305 L .42283 .76234 L F
.655 .563 .739 r
.42644 .76619 m .42302 .76305 L .42525 .76261 L F
.162 .206 .661 r
.33269 .733 m .33217 .73646 L .33059 .73622 L F
.33269 .733 m .33345 .73609 L .33217 .73646 L F
.483 .03 .1 r
.33345 .73609 m .33059 .73622 L .33217 .73646 L F
.451 .167 .39 r
.37968 .7061 m .37871 .70894 L .37664 .70933 L F
.479 .194 .402 r
.38105 .70848 m .37968 .7061 L .38157 .7059 L F
.38105 .70848 m .37871 .70894 L .37968 .7061 L F
0 0 .281 r
.73307 .73295 m .73177 .73609 L .73235 .73397 L F
0 0 0 r
.49227 .71692 m .49364 .71663 L .49518 .7151 L F
.49227 .71692 m .49158 .71737 L .49364 .71663 L F
.519 .65 .916 r
.41692 .66392 m .41596 .66573 L .41487 .66502 L F
.46 .173 .389 r
.4194 .66527 m .41626 .6671 L .41596 .66573 L F
.4194 .66527 m .41596 .66573 L .41938 .66533 L F
.519 .65 .916 r
.41897 .66509 m .41938 .66533 L .41802 .66549 L F
.832 .83 .356 r
.4194 .66527 m .41956 .66457 L .41946 .66484 L F
.4194 .66527 m .41938 .66533 L .4195 .66482 L F
.41951 .66481 m .4195 .66482 L .41956 .66457 L F
.4194 .66527 m .4195 .66482 L .41951 .66481 L F
0 .538 .822 r
.41692 .66392 m .41956 .66457 L .4195 .66482 L F
.41897 .66509 m .4195 .66482 L .41938 .66533 L F
0 0 0 r
.41946 .66484 m .41945 .66485 L .41946 .66484 L F
0 .538 .822 r
.41692 .66392 m .4195 .66482 L .41897 .66509 L F
0 0 0 r
.41951 .66487 m .41925 .66498 L .41945 .66485 L F
.454 .354 .652 r
.42215 .6667 m .42223 .66893 L .41946 .66484 L F
0 0 0 r
.41951 .66487 m .41945 .66485 L .41946 .66484 L F
.41938 .665 m .41668 .6667 L .41925 .66498 L F
.439 .301 .596 r
.4194 .66527 m .41855 .66995 L .41618 .67025 L F
.483 .356 .632 r
.41946 .66484 m .41855 .66995 L .4194 .66527 L F
.41946 .66484 m .42028 .66927 L .41855 .66995 L F
0 0 0 r
.41976 .66507 m .41911 .66541 L .41938 .665 L F
.41911 .66541 m .41668 .6667 L .41938 .665 L F
.504 .371 .632 r
.41946 .66484 m .42223 .66893 L .42028 .66927 L F
0 0 0 r
.41976 .66507 m .41925 .66498 L .41951 .66487 L F
.519 .65 .916 r
.41692 .66392 m .41897 .66509 L .41596 .66573 L F
.41897 .66509 m .41802 .66549 L .41596 .66573 L F
.969 .827 .649 r
.61552 .67958 m .61357 .68092 L .61505 .67808 L F
.61552 .67958 m .61456 .68174 L .61357 .68092 L F
.41 .085 .3 r
.30848 .67538 m .30723 .67415 L .30661 .67592 L F
.30848 .67538 m .30929 .67372 L .30723 .67415 L F
.681 .449 .564 r
.43176 .7526 m .43151 .75505 L .42944 .75501 L F
.714 .479 .567 r
.43491 .75506 m .43176 .7526 L .43456 .75274 L F
.43491 .75506 m .43151 .75505 L .43176 .7526 L F
.109 0 .208 r
.55844 .67954 m .55769 .68129 L .55985 .67851 L F
.524 .067 .11 r
.46006 .7271 m .46234 .72732 L .46029 .72646 L F
0 0 0 r
.55391 .68474 m .55515 .68388 L .55595 .68251 L F
.55391 .68474 m .55435 .68472 L .55515 .68388 L F
.55391 .68474 m .55217 .6859 L .55435 .68472 L F
.58 .178 .246 r
.44914 .72807 m .45154 .72816 L .45243 .7275 L F
.542 .129 .208 r
.45243 .7275 m .45154 .72816 L .4547 .72771 L F
.978 .891 .668 r
.7302 .61538 m .72923 .61425 L .73031 .61528 L F
0 0 0 r
.72919 .61712 m .7302 .61538 L .73031 .61528 L F
0 0 .394 r
.67804 .62065 m .67856 .62181 L .67762 .61947 L F
.727 .734 .856 r
.67762 .61947 m .67856 .62181 L .68126 .61982 L F
.502 .767 .991 r
.28872 .59772 m .28803 .59915 L .28665 .59821 L F
.28872 .59772 m .29004 .59879 L .28803 .59915 L F
.599 .801 .977 r
.33712 .70846 m .33388 .70805 L .33596 .70749 L F
.637 .815 .968 r
.3389 .70784 m .33712 .70846 L .33596 .70749 L F
.751 .372 .335 r
.49787 .78222 m .50088 .78498 L .50128 .78257 L F
.676 .299 .324 r
.50128 .78257 m .50088 .78498 L .50373 .78465 L F
.514 .744 .978 r
.30926 .60535 m .30591 .60442 L .3077 .60464 L F
.174 .652 .93 r
.3111 .60549 m .30926 .60535 L .3077 .60464 L F
.404 .134 .386 r
.41408 .6737 m .41179 .67616 L .41191 .6738 L F
.684 .415 .509 r
.50327 .72255 m .50226 .72371 L .49964 .72274 L F
.655 .329 .408 r
.49964 .72274 m .50196 .72348 L .50327 .72255 L F
.841 .982 .693 r
.50435 .72031 m .50241 .72346 L .50327 .72255 L F
.50241 .72346 m .50226 .72371 L .50327 .72255 L F
.4 0 .003 r
.50196 .72348 m .5025 .72336 L .50327 .72255 L F
.5025 .72336 m .505 .72281 L .50327 .72255 L F
.50114 .72407 m .50243 .72365 L .50196 .72348 L F
.50211 .72354 m .505 .72281 L .50196 .72348 L F
.787 .777 .843 r
.50056 .72174 m .50211 .72354 L .50435 .72031 L F
.50211 .72354 m .50226 .72371 L .50241 .72346 L F
.50211 .72354 m .50241 .72346 L .50435 .72031 L F
.4 0 .003 r
.50243 .72365 m .50468 .72291 L .50211 .72354 L F
.50468 .72291 m .505 .72281 L .50211 .72354 L F
.367 .612 .944 r
.49964 .72274 m .50226 .72371 L .50211 .72354 L F
.50196 .72348 m .50211 .72354 L .5021 .72353 L F
.49964 .72274 m .50211 .72354 L .50196 .72348 L F
.49964 .72274 m .5021 .72353 L .50083 .72206 L F
.655 .329 .408 r
.49964 .72274 m .50114 .72407 L .50196 .72348 L F
.4 0 .003 r
.50114 .72407 m .50362 .72429 L .505 .72281 L F
.462 .499 .811 r
.50197 .72217 m .50362 .72429 L .50114 .72407 L F
.5024 .72121 m .50281 .72225 L .50197 .72217 L F
.50281 .72225 m .50362 .72429 L .50197 .72217 L F
.367 .612 .944 r
.50031 .72201 m .50083 .72206 L .50056 .72174 L F
.49964 .72274 m .50083 .72206 L .50031 .72201 L F
.841 .982 .693 r
.50435 .72031 m .50327 .72255 L .505 .72281 L F
.331 .024 .285 r
.60235 .75273 m .60181 .75518 L .5998 .75511 L F
.412 .202 .482 r
.60444 .74992 m .60425 .75204 L .60235 .75273 L F
.317 .013 .281 r
.60425 .75204 m .60181 .75518 L .60235 .75273 L F
.447 .282 .563 r
.31129 .66801 m .31319 .6701 L .3138 .66801 L F
.31129 .66801 m .31143 .67058 L .31319 .6701 L F
.654 .554 .73 r
.68292 .60135 m .68043 .60036 L .68175 .6 L F
0 0 0 r
.68277 .59972 m .68175 .6 L .68011 .60059 L F
.68 .823 .952 r
.68411 .59928 m .68292 .60135 L .68175 .6 L F
0 0 0 r
.68411 .59928 m .68175 .6 L .68277 .59972 L F
.654 .554 .73 r
.68043 .60036 m .68006 .60021 L .68175 .6 L F
0 .554 .725 r
.47191 .78158 m .47578 .78184 L .47436 .7818 L F
.08 0 0 r
.47578 .78184 m .47783 .78198 L .47436 .7818 L F
.667 .902 .979 r
.57834 .67783 m .57957 .67913 L .58027 .67666 L F
.57834 .67783 m .57805 .67867 L .57957 .67913 L F
.95 .734 .576 r
.57788 .68079 m .57957 .67913 L .57805 .67867 L F
.57788 .68079 m .57902 .68171 L .57957 .67913 L F
.894 .484 .215 r
.30213 .72951 m .30032 .72922 L .29974 .7276 L F
0 .512 .705 r
.30383 .7296 m .30032 .72922 L .30213 .72951 L F
.051 .599 .836 r
.30497 .72992 m .30383 .7296 L .30213 .72951 L F
.658 .287 .331 r
.58871 .74458 m .59125 .74643 L .59174 .74431 L F
.722 .589 .706 r
.6344 .64073 m .6343 .63847 L .63096 .63811 L F
.516 .695 .95 r
.26983 .59673 m .27185 .59651 L .27053 .59749 L F
.722 .589 .706 r
.6344 .64073 m .63096 .63811 L .63229 .64134 L F
.777 .663 .738 r
.63211 .64357 m .6344 .64073 L .63229 .64134 L F
.568 .476 .711 r
.32911 .69459 m .32596 .69552 L .32588 .69529 L F
.555 .407 .635 r
.3025 .67906 m .30473 .67869 L .30447 .67628 L F
.528 .386 .631 r
.3025 .67906 m .30465 .68113 L .30473 .67869 L F
.3025 .67906 m .30272 .68174 L .30465 .68113 L F
.46 .278 .546 r
.67614 .58392 m .67828 .58537 L .67829 .58342 L F
.67614 .58392 m .67623 .58632 L .67828 .58537 L F
.224 .727 .902 r
.72797 .71172 m .72908 .71203 L .72678 .71214 L F
.507 .343 .593 r
.53624 .73845 m .53411 .7391 L .53603 .7363 L F
.283 .063 .393 r
.53624 .73845 m .53411 .74147 L .53411 .7391 L F
.507 .343 .593 r
.53624 .73845 m .53411 .7391 L .53603 .7363 L F
.283 .063 .393 r
.53411 .74147 m .53624 .73845 L .53411 .7391 L F
.341 .184 .518 r
.61693 .70319 m .61677 .70569 L .61454 .70639 L F
.247 .046 .399 r
.61677 .70569 m .61406 .70784 L .61454 .70639 L F
.734 .584 .688 r
.6288 .63858 m .63096 .63811 L .63094 .63556 L F
.68 .823 .952 r
.68411 .59928 m .68527 .6004 L .68292 .60135 L F
.124 .575 .921 r
.50885 .79403 m .50974 .79347 L .50791 .79307 L F
.50885 .79403 m .51141 .79466 L .50974 .79347 L F
.547 .384 .611 r
.69831 .58122 m .69863 .585 L .69702 .58419 L F
0 0 .342 r
.69928 .57762 m .69831 .58122 L .70047 .57984 L F
.69928 .57762 m .69935 .58005 L .69844 .58072 L F
.71 .657 .796 r
.69928 .57762 m .70047 .57984 L .70186 .57902 L F
.758 .494 .534 r
.69608 .57955 m .69935 .58005 L .69928 .57762 L F
.749 .442 .463 r
.69608 .57955 m .69612 .58144 L .69935 .58005 L F
.433 .865 .757 r
.69935 .58005 m .69612 .58144 L .70031 .57934 L F
.69935 .58005 m .70031 .57934 L .70103 .57898 L F
0 0 .342 r
.69844 .58072 m .69935 .58005 L .69831 .58122 L F
0 0 0 r
.70049 .58335 m .703 .5826 L .70322 .58021 L F
.522 .365 .609 r
.70068 .5833 m .69831 .58122 L .69935 .58005 L F
.70068 .5833 m .69863 .585 L .69831 .58122 L F
.796 .975 .907 r
.30744 .72813 m .30497 .72992 L .30662 .72882 L F
.709 .692 .832 r
.72752 .60007 m .73084 .60044 L .72974 .59758 L F
.646 .424 .568 r
.42944 .75501 m .42584 .75711 L .42739 .75462 L F
.634 .734 .92 r
.7042 .61019 m .70762 .61095 L .70663 .60976 L F
.37 .78 .981 r
.70762 .61095 m .7091 .61043 L .70663 .60976 L F
.70762 .61095 m .70992 .61069 L .7091 .61043 L F
.746 .709 .817 r
.55005 .70775 m .54858 .71186 L .55215 .70894 L F
.563 .414 .637 r
.39759 .76357 m .3999 .76606 L .39968 .76307 L F
.39759 .76357 m .39775 .76651 L .3999 .76606 L F
0 .175 .658 r
.73258 .5846 m .73464 .58614 L .73537 .58692 L F
.802 .385 0 r
.73464 .58614 m .73628 .58881 L .73537 .58692 L F
.974 .675 .295 r
.70291 .58929 m .70327 .59158 L .70222 .59038 L F
.281 .466 .864 r
.55687 .71492 m .55783 .71357 L .5561 .71381 L F
.55687 .71492 m .55969 .71649 L .55783 .71357 L F
.156 0 0 r
.58609 .67037 m .58318 .67234 L .58456 .67111 L F
.904 .688 .6 r
.63442 .65673 m .63584 .65741 L .6345 .65443 L F
.909 .613 .471 r
.63461 .65907 m .63584 .65741 L .63442 .65673 L F
.987 .785 .547 r
.63569 .65987 m .63584 .65741 L .63461 .65907 L F
.775 .719 .8 r
.30228 .73715 m .30427 .73909 L .30117 .73869 L F
.475 0 0 r
.30117 .73869 m .30427 .73909 L .30294 .73926 L F
.715 .322 .304 r
.30228 .73715 m .30809 .73803 L .30427 .73909 L F
.30809 .73803 m .30807 .73809 L .30427 .73909 L F
.42 0 0 r
.30361 .73804 m .30228 .73715 L .30294 .73926 L F
.968 .658 .271 r
.30252 .73748 m .30361 .73804 L .30258 .73767 L F
.42 0 0 r
.30361 .73804 m .30408 .73829 L .30401 .73824 L F
.30361 .73804 m .30401 .73824 L .30228 .73715 L F
.30476 .73871 m .30483 .73874 L .30228 .73715 L F
.317 .806 .815 r
.30499 .7388 m .30516 .73886 L .30807 .73809 L F
.715 .322 .304 r
.30809 .73803 m .30822 .73805 L .30807 .73809 L F
.317 .806 .815 r
.30806 .73809 m .30807 .73809 L .30822 .73805 L F
.30294 .73926 m .30807 .73809 L .30806 .73809 L F
.30294 .73926 m .30427 .73909 L .30516 .73886 L F
.30294 .73926 m .30516 .73886 L .30499 .7388 L F
.30294 .73926 m .30347 .73914 L .30405 .7391 L F
.30347 .73914 m .30822 .73805 L .30487 .73889 L F
.30347 .73914 m .30487 .73889 L .30405 .7391 L F
.715 .322 .304 r
.30228 .73715 m .30501 .73885 L .30822 .73805 L F
.30501 .73885 m .30518 .73896 L .30822 .73805 L F
.317 .806 .815 r
.30405 .7391 m .30822 .73805 L .30418 .73908 L F
0 0 0 r
.30822 .73805 m .30709 .73839 L .30715 .73839 L F
.30709 .73839 m .30518 .73896 L .30715 .73839 L F
.30822 .73805 m .30715 .73839 L .30881 .73651 L F
.30822 .73805 m .30881 .73651 L .30825 .73854 L F
.658 .103 0 r
.30822 .73805 m .30825 .73854 L .30715 .73839 L F
.452 .748 .992 r
.30825 .73854 m .30898 .73733 L .30715 .73839 L F
0 0 0 r
.30719 .73839 m .30715 .73839 L .30898 .73733 L F
.30534 .73949 m .30715 .73839 L .30719 .73839 L F
.42 0 0 r
.30361 .73804 m .30476 .73871 L .30408 .73829 L F
.30476 .73871 m .30518 .73896 L .30483 .73874 L F
.514 .743 .978 r
.30634 .73863 m .30502 .73886 L .30361 .73804 L F
.658 .103 0 r
.30501 .73887 m .30715 .73839 L .30418 .73908 L F
.30822 .73805 m .30715 .73839 L .30501 .73887 L F
.514 .743 .978 r
.30715 .73839 m .30634 .73863 L .30621 .7386 L F
.30715 .73839 m .30621 .7386 L .30361 .73804 L F
.30634 .73863 m .30518 .73896 L .30502 .73886 L F
.968 .658 .271 r
.30173 .73459 m .30361 .73804 L .30252 .73748 L F
.141 .397 .846 r
.30431 .73659 m .30361 .73804 L .30173 .73459 L F
.643 .959 .927 r
.30259 .73753 m .30361 .73804 L .30431 .73659 L F
.30243 .73762 m .30361 .73804 L .30259 .73753 L F
.30213 .73778 m .30361 .73804 L .30243 .73762 L F
.968 .658 .271 r
.30258 .73767 m .30361 .73804 L .30258 .73768 L F
.874 .939 .569 r
.3088 .73457 m .30881 .73603 L .30746 .73796 L F
.30735 .73794 m .30746 .73796 L .30715 .73839 L F
.3088 .73457 m .30746 .73796 L .30735 .73794 L F
.30881 .73603 m .30881 .73651 L .30852 .73684 L F
.30881 .73603 m .30852 .73684 L .30715 .73839 L F
.581 .336 .51 r
.43922 .75198 m .43716 .74992 L .43935 .74964 L F
.43922 .75198 m .43692 .7523 L .43716 .74992 L F
.728 .469 .536 r
.45904 .74489 m .45841 .74712 L .45652 .74453 L F
.49 .235 .453 r
.46083 .74652 m .45904 .74489 L .46101 .74415 L F
.46083 .74652 m .45841 .74712 L .45904 .74489 L F
.148 0 0 r
.36088 .71967 m .35801 .72098 L .35935 .71963 L F
0 0 .409 r
.52837 .71407 m .52989 .71666 L .52984 .7168 L F
.759 .303 0 r
.52887 .71559 m .52989 .71666 L .52837 .71407 L F
.444 0 0 r
.52994 .71653 m .52989 .71666 L .52887 .71559 L F
.53127 .71771 m .52989 .71666 L .52994 .71653 L F
0 0 .409 r
.52984 .7168 m .52989 .71666 L .52987 .71686 L F
0 .193 .66 r
.52989 .71666 m .53219 .71848 L .52987 .71686 L F
.556 .365 .577 r
.32596 .69552 m .32587 .69789 L .32378 .69836 L F
.534 .346 .573 r
.32803 .69512 m .32587 .69789 L .32596 .69552 L F
.247 .046 .399 r
.61677 .70569 m .61644 .70781 L .61406 .70784 L F
.231 0 .262 r
.61406 .70784 m .61644 .70781 L .614 .71052 L F
.883 .821 .782 r
.72856 .72591 m .72587 .72639 L .72739 .7241 L F
.72856 .72591 m .72704 .72762 L .72587 .72639 L F
.726 .543 .643 r
.73025 .72763 m .72704 .72762 L .72856 .72591 L F
.687 .468 .585 r
.62096 .64326 m .62316 .64104 L .61964 .64054 L F
.62096 .64326 m .62322 .64334 L .62316 .64104 L F
.72 .538 .644 r
.62322 .64334 m .62641 .64111 L .62316 .64104 L F
0 .205 .701 r
.72731 .73705 m .72838 .73763 L .72676 .73576 L F
.72731 .73705 m .72953 .73886 L .72838 .73763 L F
.609 .473 .671 r
.72731 .73705 m .72743 .73994 L .72953 .73886 L F
.61 .731 .932 r
.72488 .72854 m .7215 .72768 L .72372 .7274 L F
.708 .81 .929 r
.72704 .72762 m .72488 .72854 L .72372 .7274 L F
.466 .721 .98 r
.35057 .64805 m .3499 .64943 L .34862 .64888 L F
.35057 .64805 m .35201 .64929 L .3499 .64943 L F
.401 0 0 r
.46234 .72732 m .46459 .72726 L .46594 .72613 L F
.38 0 0 r
.46594 .72613 m .46778 .72667 L .46805 .72603 L F
.46594 .72613 m .46459 .72726 L .46778 .72667 L F
.275 0 0 r
.46668 .78214 m .46942 .78191 L .4688 .78245 L F
.439 0 .031 r
.47191 .78158 m .4688 .78245 L .46942 .78191 L F
.672 .719 .884 r
.56915 .69281 m .56685 .69348 L .56538 .69183 L F
.089 0 0 r
.44185 .77471 m .44426 .77476 L .44539 .77464 L F
.54 .152 .255 r
.44426 .77476 m .44697 .77375 L .44539 .77464 L F
.336 0 .014 r
.73858 .5975 m .73544 .5993 L .73454 .59682 L F
.73858 .5975 m .73774 .59896 L .73544 .5993 L F
.668 .22 .177 r
.74104 .59923 m .73858 .5975 L .74 .59605 L F
.74104 .59923 m .73774 .59896 L .73858 .5975 L F
.728 .368 .369 r
.70516 .7216 m .70571 .72036 L .70209 .71961 L F
.043 0 0 r
.70516 .7216 m .7085 .72008 L .70571 .72036 L F
.632 .296 .384 r
.53216 .73078 m .53176 .73106 L .52956 .73082 L F
.495 .904 .822 r
.33848 .72958 m .33718 .72992 L .33639 .73067 L F
0 0 0 r
.33718 .72992 m .33488 .73255 L .33639 .73067 L F
.14 .65 .899 r
.3989 .78277 m .39736 .7822 L .39518 .78197 L F
.576 .512 .746 r
.40023 .77967 m .3989 .78277 L .40142 .78226 L F
.513 .861 .992 r
.39942 .78159 m .3989 .78277 L .40023 .77967 L F
.39942 .78159 m .39736 .7822 L .3989 .78277 L F
.653 .521 .691 r
.39866 .78499 m .40142 .78226 L .3989 .78277 L F
.734 .976 .733 r
.58107 .67524 m .57834 .67783 L .58027 .67666 L F
.586 .424 .629 r
.29456 .69345 m .29656 .6929 L .29637 .69047 L F
.511 .336 .581 r
.29637 .69047 m .29847 .69021 L .29852 .68727 L F
.537 .387 .625 r
.29637 .69047 m .29848 .69239 L .29847 .69021 L F
.29637 .69047 m .29656 .6929 L .29848 .69239 L F
.131 0 .317 r
.6291 .68166 m .62916 .68396 L .62729 .68474 L F
.166 0 .386 r
.62916 .68396 m .62698 .6868 L .62729 .68474 L F
.411 .228 .52 r
.6065 .74698 m .60627 .74938 L .60444 .74992 L F
.498 .316 .565 r
.60627 .74938 m .60425 .75204 L .60444 .74992 L F
.622 .505 .699 r
.29456 .69345 m .29699 .69515 L .29656 .6929 L F
.29456 .69345 m .2947 .69551 L .29699 .69515 L F
.175 .283 .737 r
.56905 .71141 m .56972 .7128 L .56869 .71387 L F
.271 .439 .845 r
.56972 .7128 m .57075 .71501 L .56869 .71387 L F
.18 .318 .769 r
.50056 .72174 m .50114 .72407 L .49964 .72274 L F
.579 .416 .625 r
.41456 .73874 m .4168 .73857 L .41491 .73655 L F
.293 0 0 r
.35801 .67364 m .35622 .6749 L .3543 .67511 L F
0 0 0 r
.35848 .67411 m .35801 .67364 L .36022 .67285 L F
.35848 .67411 m .35622 .6749 L .35801 .67364 L F
.199 0 .231 r
.67132 .59097 m .66968 .59233 L .67141 .59229 L F
.213 0 .355 r
.67141 .59229 m .66968 .59233 L .66919 .59413 L F
.49 0 0 r
.46805 .72603 m .47008 .72688 L .47147 .72591 L F
.542 .086 .119 r
.47008 .72688 m .47389 .72575 L .47147 .72591 L F
.778 .558 .601 r
.56522 .73012 m .5679 .72859 L .56631 .73039 L F
.091 .634 .844 r
.56522 .73012 m .56856 .73053 L .56631 .73039 L F
.372 .405 .766 r
.56631 .73039 m .56909 .73305 L .56856 .73053 L F
.605 .278 .39 r
.43015 .73577 m .43257 .73596 L .43354 .73353 L F
.514 .186 .349 r
.43354 .73353 m .43544 .7348 L .43578 .73331 L F
.43354 .73353 m .43257 .73596 L .43544 .7348 L F
0 .12 .57 r
.73366 .5854 m .73258 .5846 L .73152 .58365 L F
.73366 .5854 m .73464 .58614 L .73258 .5846 L F
.598 .566 .789 r
.42525 .76261 m .42283 .76234 L .42502 .76159 L F
.239 0 0 r
.35754 .6488 m .35968 .64871 L .36092 .6481 L F
.469 .019 .099 r
.56575 .6866 m .56385 .68868 L .56125 .68884 L F
.6 .586 .809 r
.56574 .68991 m .56683 .68643 L .56575 .6866 L F
.118 .08 .536 r
.56575 .6866 m .56574 .68991 L .56683 .68643 L F
0 0 0 r
.56556 .68791 m .56575 .6866 L .56683 .68643 L F
.121 .672 .761 r
.56575 .6866 m .56683 .68643 L .56815 .68637 L F
.796 .92 .921 r
.30004 .72696 m .30407 .72544 L .30108 .72555 L F
.335 .439 .819 r
.56376 .72249 m .56507 .72552 L .56647 .72422 L F
.359 .48 .846 r
.56507 .72552 m .568 .72704 L .56647 .72422 L F
.351 0 .13 r
.46965 .77367 m .47175 .77327 L .47321 .77118 L F
.389 0 .153 r
.47321 .77118 m .47455 .77268 L .47517 .77185 L F
.47321 .77118 m .47175 .77327 L .47455 .77268 L F
.109 0 0 r
.49518 .7151 m .49567 .71589 L .49653 .71366 L F
.49518 .7151 m .49364 .71663 L .49567 .71589 L F
.615 .634 .846 r
.40692 .6649 m .40356 .66269 L .40553 .66261 L F
.557 .686 .926 r
.40772 .66271 m .40692 .6649 L .40553 .66261 L F
.40772 .66271 m .41088 .66488 L .40692 .6649 L F
.463 .274 .538 r
.38075 .6894 m .38284 .68678 L .38112 .68748 L F
.284 0 0 r
.34704 .72608 m .346 .72695 L .34418 .72727 L F
0 0 0 r
.34874 .72518 m .346 .72695 L .34704 .72608 L F
.362 0 .12 r
.36973 .70105 m .37049 .70253 L .37135 .7002 L F
.36973 .70105 m .36833 .70296 L .37049 .70253 L F
.59 .817 .425 r
.505 .72281 m .50509 .72 L .50435 .72031 L F
.505 .72281 m .50706 .71992 L .50509 .72 L F
.505 .72281 m .50584 .72158 L .50706 .71992 L F
.615 .867 .519 r
.505 .72281 m .50362 .72429 L .50584 .72158 L F
0 .519 .791 r
.37208 .64946 m .37433 .64987 L .3754 .65027 L F
.289 0 0 r
.37433 .64987 m .3778 .65053 L .3754 .65027 L F
.659 .348 .434 r
.6938 .57754 m .6962 .5778 L .69703 .57552 L F
.694 .385 .448 r
.6962 .5778 m .69928 .57762 L .69703 .57552 L F
.678 .39 .478 r
.69703 .57552 m .69928 .57762 L .69929 .57578 L F
.814 1 .803 r
.5563 .74634 m .55547 .74776 L .55688 .74736 L F
0 0 0 r
.55688 .74736 m .55502 .74852 L .55575 .74774 L F
.814 1 .803 r
.55547 .74776 m .55502 .74852 L .55589 .74798 L F
.55547 .74776 m .55589 .74798 L .55688 .74736 L F
.44 0 0 r
.55301 .74634 m .55359 .74679 L .55575 .74774 L F
.858 .426 .189 r
.55502 .74852 m .55424 .74873 L .55301 .74634 L F
0 0 .554 r
.55301 .74634 m .55424 .74873 L .55407 .74712 L F
.55301 .74634 m .55407 .74712 L .55403 .74676 L F
.44 0 0 r
.55359 .74679 m .55391 .74704 L .554 .74707 L F
.55368 .74683 m .554 .74707 L .55455 .74728 L F
.55359 .74679 m .554 .74707 L .55368 .74683 L F
.55359 .74679 m .55455 .74728 L .55575 .74774 L F
.606 .935 .955 r
.55575 .74774 m .55391 .74704 L .5563 .74634 L F
0 0 0 r
.55688 .74736 m .55575 .74774 L .55792 .74721 L F
.50435 .70835 m .50567 .70799 L .50724 .70569 L F
.014 0 0 r
.50724 .70569 m .50763 .70668 L .50907 .70614 L F
.50724 .70569 m .50567 .70799 L .50763 .70668 L F
.793 .439 0 r
.737 .59086 m .73758 .59184 L .73628 .58881 L F
.065 .218 .713 r
.73938 .59232 m .73758 .59184 L .737 .59086 L F
.73938 .59232 m .73939 .59388 L .73758 .59184 L F
.603 .043 0 r
.51292 .78465 m .51471 .78565 L .51583 .7855 L F
.97 .912 .695 r
.51471 .78565 m .51394 .78649 L .51583 .7855 L F
.458 .864 .697 r
.51583 .7855 m .51672 .78478 L .51776 .78428 L F
.457 .861 .685 r
.51583 .7855 m .51394 .78649 L .51672 .78478 L F
.228 0 .157 r
.31077 .61407 m .31006 .61566 L .3083 .61639 L F
.341 .173 .502 r
.31274 .6108 m .31264 .61306 L .31077 .61407 L F
.435 .176 .421 r
.31264 .61306 m .31006 .61566 L .31077 .61407 L F
.823 .581 .572 r
.46835 .74082 m .47162 .73901 L .47248 .74107 L F
0 0 .36 r
.47243 .74037 m .47162 .73901 L .47396 .74067 L F
.47243 .74037 m .47248 .74107 L .47162 .73901 L F
.638 .236 .266 r
.47379 .73946 m .47396 .74067 L .47162 .73901 L F
.682 .887 .973 r
.71011 .73215 m .71372 .73186 L .71247 .731 L F
.255 .449 .858 r
.71812 .73239 m .7181 .7333 L .71705 .73344 L F
.248 .572 .94 r
.71705 .73344 m .7181 .7333 L .71755 .73311 L F
.71705 .73344 m .71755 .73311 L .71372 .73186 L F
.556 .709 .942 r
.71706 .73369 m .71751 .73314 L .71705 .73344 L F
.71751 .73314 m .71812 .73239 L .71705 .73344 L F
.367 .571 .917 r
.71755 .73311 m .7181 .7333 L .71791 .73268 L F
.556 .709 .942 r
.71715 .73581 m .71809 .73247 L .71706 .73369 L F
.71809 .73247 m .71812 .73239 L .71706 .73369 L F
.367 .571 .917 r
.71372 .73186 m .71755 .73311 L .71749 .73131 L F
.71755 .73311 m .71791 .73268 L .71749 .73131 L F
.611 .447 .635 r
.32378 .69836 m .32372 .70051 L .32166 .70134 L F
.572 .415 .629 r
.32587 .69789 m .32372 .70051 L .32378 .69836 L F
.004 .37 .837 r
.57785 .72366 m .57601 .72313 L .5755 .72196 L F
.57785 .72366 m .57872 .72516 L .57601 .72313 L F
.461 .362 .656 r
.68014 .59356 m .6778 .59217 L .68018 .59129 L F
.68014 .59356 m .67815 .59451 L .6778 .59217 L F
.564 .54 .786 r
.42729 .76227 m .42644 .76619 L .42525 .76261 L F
.42729 .76227 m .42851 .7658 L .42644 .76619 L F
.617 .506 .705 r
.42851 .7658 m .42656 .76826 L .42644 .76619 L F
.558 .398 .621 r
.29491 .69805 m .29699 .69515 L .2947 .69551 L F
.653 .454 .602 r
.49516 .73076 m .49501 .73327 L .49273 .73347 L F
.639 .591 .785 r
.49698 .72804 m .49781 .73081 L .49516 .73076 L F
.693 .489 .606 r
.49825 .73322 m .49516 .73076 L .49781 .73081 L F
.49825 .73322 m .49501 .73327 L .49516 .73076 L F
.191 0 0 r
.44765 .78522 m .44845 .78579 L .44633 .78597 L F
.44765 .78522 m .44986 .78508 L .44845 .78579 L F
.17 0 .257 r
.73675 .72133 m .73476 .7227 L .73693 .71994 L F
0 0 .2 r
.73675 .72133 m .73484 .72505 L .73476 .7227 L F
.284 .583 .943 r
.38821 .77917 m .38962 .78088 L .39074 .78049 L F
.488 .093 .216 r
.53574 .78965 m .53608 .7887 L .5391 .78791 L F
.769 .979 .913 r
.68979 .61044 m .69319 .60878 L .69207 .60773 L F
.721 .823 .928 r
.69207 .60773 m .69319 .60878 L .69528 .6079 L F
.549 .624 .879 r
.32912 .7048 m .32829 .70675 L .32705 .70521 L F
.32912 .7048 m .33041 .70648 L .32829 .70675 L F
0 0 0 r
.50435 .70835 m .50372 .70924 L .50567 .70799 L F
.387 .108 .363 r
.59644 .66444 m .59443 .66531 L .59689 .66295 L F
0 0 0 r
.59885 .66247 m .59644 .66444 L .59689 .66295 L F
.391 0 0 r
.47783 .78198 m .48119 .78254 L .47975 .78252 L F
.476 0 0 r
.48119 .78254 m .48219 .78353 L .47975 .78252 L F
.48119 .78254 m .48309 .78351 L .48219 .78353 L F
.971 .929 .671 r
.56641 .70201 m .56814 .70084 L .56475 .69976 L F
.764 .301 .149 r
.56814 .70084 m .56631 .70045 L .56475 .69976 L F
.971 .929 .671 r
.56641 .70201 m .56702 .70358 L .56814 .70084 L F
.784 .811 .874 r
.56934 .69738 m .56814 .70084 L .57053 .6983 L F
.56934 .69738 m .56631 .70045 L .56814 .70084 L F
.741 .618 .722 r
.62875 .64087 m .63096 .63811 L .6288 .63858 L F
.694 .549 .685 r
.62875 .64087 m .63229 .64134 L .63096 .63811 L F
0 .166 .611 r
.52468 .70996 m .5267 .71135 L .52755 .71199 L F
.92 .534 .14 r
.5267 .71135 m .52837 .71407 L .52755 .71199 L F
.755 .573 .65 r
.31285 .73984 m .3133 .74217 L .30959 .74129 L F
.543 .431 .677 r
.31542 .73614 m .3133 .74217 L .31285 .73984 L F
.544 .041 .009 r
.46835 .74082 m .46685 .74261 L .46474 .74142 L F
.589 .208 .288 r
.47248 .74107 m .46919 .74288 L .46685 .74261 L F
.47248 .74107 m .46945 .7419 L .46835 .74082 L F
.442 .074 .244 r
.47243 .74037 m .46919 .74288 L .47248 .74107 L F
.47045 .74191 m .47145 .74246 L .46919 .74288 L F
.47243 .74037 m .47171 .74192 L .47045 .74191 L F
.47171 .74192 m .47145 .74246 L .47045 .74191 L F
.589 .208 .288 r
.46945 .7419 m .46685 .74261 L .46746 .74188 L F
.46945 .7419 m .46746 .74188 L .46835 .74082 L F
.498 .392 .664 r
.38694 .67646 m .38872 .67599 L .38816 .67394 L F
.495 .382 .654 r
.38694 .67646 m .38913 .6784 L .38872 .67599 L F
.498 .382 .652 r
.38724 .67884 m .38913 .6784 L .38694 .67646 L F
.473 .324 .597 r
.28061 .61902 m .28263 .61857 L .28267 .61594 L F
.311 .315 .702 r
.28061 .61902 m .28249 .6204 L .28263 .61857 L F
.28061 .61902 m .28133 .62191 L .28249 .6204 L F
.659 .759 .924 r
.39475 .81708 m .39235 .81802 L .39473 .81726 L F
.39475 .81708 m .39235 .81802 L .39473 .81726 L F
.527 .898 .965 r
.39309 .81706 m .39235 .81802 L .39473 .81726 L F
.39473 .81726 m .39235 .81802 L .39309 .81706 L F
.39473 .81726 m .39235 .81802 L .39309 .81706 L F
.172 0 0 r
.30744 .72813 m .30383 .7296 L .30497 .72992 L F
.097 .142 .619 r
.57151 .74479 m .5728 .74366 L .57131 .74144 L F
.147 .252 .716 r
.57273 .74662 m .5728 .74366 L .57151 .74479 L F
.548 .383 .61 r
.69863 .585 m .69794 .58594 L .69702 .58419 L F
.484 .241 .47 r
.58092 .7201 m .58056 .72214 L .58324 .71974 L F
.559 .716 .946 r
.4345 .77538 m .43079 .77428 L .43289 .77386 L F
.714 .725 .859 r
.43631 .77421 m .4345 .77538 L .43289 .77386 L F
.517 .323 .556 r
.61172 .71204 m .61241 .71387 L .61068 .71409 L F
.334 .284 .653 r
.614 .71052 m .61241 .71387 L .61172 .71204 L F
.172 0 0 r
.30744 .72813 m .30568 .72928 L .30383 .7296 L F
.013 0 0 r
.3082 .72824 m .30744 .72813 L .30954 .72768 L F
.3082 .72824 m .30568 .72928 L .30744 .72813 L F
.564 .15 .216 r
.45652 .74453 m .45519 .74621 L .45275 .74488 L F
.814 .466 .397 r
.45652 .74453 m .45841 .74712 L .45519 .74621 L F
.379 .263 .594 r
.7012 .72539 m .70283 .72199 L .70037 .72215 L F
.7012 .72539 m .70283 .72492 L .70283 .72199 L F
.502 .359 .62 r
.70111 .72758 m .70283 .72492 L .7012 .72539 L F
.543 0 0 r
.36528 .64588 m .36879 .64803 L .36643 .64727 L F
.598 .617 .841 r
.3879 .65475 m .38436 .65246 L .38647 .65221 L F
.459 .562 .872 r
.38907 .6529 m .3879 .65475 L .38647 .65221 L F
.434 .528 .855 r
.38959 .65491 m .3879 .65475 L .38907 .6529 L F
.394 .103 .348 r
.372 .71186 m .37111 .71385 L .3694 .71406 L F
.421 .135 .371 r
.37397 .71128 m .37111 .71385 L .372 .71186 L F
.078 .238 .727 r
.57191 .71704 m .57392 .71924 L .57241 .71816 L F
.501 .506 .794 r
.54625 .70534 m .54662 .70735 L .54823 .70513 L F
.355 0 .033 r
.44497 .74725 m .44361 .74887 L .44141 .74917 L F
.694 .283 .262 r
.44497 .74725 m .44705 .74916 L .44361 .74887 L F
.568 .33 .515 r
.44712 .74699 m .44705 .74916 L .44497 .74725 L F
0 0 0 r
.55595 .68251 m .55636 .68266 L .55769 .68129 L F
.55595 .68251 m .55515 .68388 L .55636 .68266 L F
.426 .227 .505 r
.2995 .62968 m .29971 .62739 L .30153 .62685 L F
.546 .781 .986 r
.27378 .59632 m .27328 .59784 L .27185 .59651 L F
.27378 .59632 m .27524 .59742 L .27328 .59784 L F
.264 .163 .548 r
.28133 .62191 m .28277 .62361 L .28249 .6204 L F
.28133 .62191 m .28141 .6243 L .28277 .62361 L F
.892 .809 .76 r
.3945 .65708 m .39331 .65696 L .39522 .6566 L F
.342 .678 .978 r
.39628 .65601 m .3945 .65708 L .39522 .6566 L F
.417 .215 .495 r
.30415 .62187 m .30386 .62421 L .30202 .62482 L F
.353 .078 .35 r
.30202 .62482 m .3031 .6261 L .30153 .62685 L F
.30202 .62482 m .30386 .62421 L .3031 .6261 L F
.56 .695 .931 r
.39231 .65548 m .39127 .65735 L .38959 .65491 L F
.39231 .65548 m .39331 .65696 L .39127 .65735 L F
.591 .47 .683 r
.39901 .75829 m .39945 .76065 L .40132 .75786 L F
.883 .805 .768 r
.3982 .7796 m .39978 .77685 L .39768 .77747 L F
.684 .137 0 r
.52322 .70898 m .5267 .71135 L .52468 .70996 L F
.488 .093 .216 r
.53574 .78965 m .5391 .78791 L .53789 .78935 L F
0 0 0 r
.54121 .7876 m .53789 .78935 L .5391 .78791 L F
.275 0 .065 r
.33115 .65481 m .33243 .65519 L .33312 .65423 L F
.33115 .65481 m .3299 .65644 L .33243 .65519 L F
.346 .109 .404 r
.3718 .69818 m .37309 .69947 L .37396 .69789 L F
.3718 .69818 m .37135 .7002 L .37309 .69947 L F
.738 .629 .738 r
.62894 .64337 m .63211 .64357 L .63229 .64134 L F
.741 .541 .623 r
.63027 .64626 m .63211 .64357 L .62894 .64337 L F
.776 .59 .647 r
.63027 .64626 m .63366 .64682 L .63211 .64357 L F
.559 0 0 r
.48217 .77629 m .48417 .77724 L .48548 .77726 L F
.481 .013 .065 r
.48641 .77883 m .48548 .77726 L .48417 .77724 L F
.48641 .77883 m .48756 .77749 L .48548 .77726 L F
0 .239 .698 r
.54268 .7239 m .54131 .72328 L .54011 .7224 L F
.54268 .7239 m .54386 .7249 L .54131 .72328 L F
.732 .615 .728 r
.65409 .60197 m .65611 .59948 L .65743 .59998 L F
.927 .678 .543 r
.65611 .59948 m .65758 .60285 L .65743 .59998 L F
.791 .566 .596 r
.60675 .66315 m .60601 .66472 L .60408 .66241 L F
.798 .759 .817 r
.58967 .72491 m .59334 .72495 L .59199 .72456 L F
.58967 .72491 m .59127 .72621 L .59334 .72495 L F
.509 .532 .816 r
.59334 .72495 m .59189 .72207 L .59199 .72456 L F
.59334 .72495 m .5943 .72162 L .59189 .72207 L F
.59334 .72495 m .59572 .72496 L .5943 .72162 L F
.805 .79 .839 r
.54367 .78293 m .54085 .78337 L .54235 .78195 L F
.485 .375 .654 r
.54583 .78471 m .54376 .78572 L .54367 .78293 L F
.784 .288 .02 r
.54235 .78195 m .54583 .78471 L .54367 .78293 L F
.426 .02 .164 r
.53476 .72987 m .53176 .73106 L .53216 .73078 L F
.619 .155 0 r
.53916 .72127 m .5383 .71994 L .53711 .7192 L F
.53916 .72127 m .54011 .7224 L .5383 .71994 L F
.564 .246 .387 r
.53476 .72987 m .53178 .73277 L .53176 .73106 L F
.53476 .72987 m .53395 .73267 L .53178 .73277 L F
.535 .549 .816 r
.53476 .72987 m .5383 .73343 L .53721 .7301 L F
.461 .112 .287 r
.53721 .7301 m .53395 .73267 L .53476 .72987 L F
.558 .327 .522 r
.45275 .74488 m .45285 .7479 L .45061 .74832 L F
.482 .27 .514 r
.45519 .74621 m .45285 .7479 L .45275 .74488 L F
.281 0 .072 r
.37027 .71538 m .3694 .71406 L .37111 .71385 L F
.37027 .71538 m .36815 .716 L .3694 .71406 L F
.531 .353 .584 r
.29852 .68727 m .30034 .68951 L .30049 .68675 L F
.29852 .68727 m .29847 .69021 L .30034 .68951 L F
.462 .236 .484 r
.37653 .6954 m .3785 .69499 L .37859 .69222 L F
.461 .309 .587 r
.37859 .69222 m .38087 .69203 L .38075 .6894 L F
.469 .241 .486 r
.37859 .69222 m .38053 .69441 L .38087 .69203 L F
.37859 .69222 m .3785 .69499 L .38053 .69441 L F
.82 .603 .608 r
.63586 .65313 m .63328 .64909 L .63352 .65146 L F
.77 .63 .706 r
.6345 .65443 m .63586 .65313 L .63352 .65146 L F
.331 0 .224 r
.5998 .75511 m .5991 .75719 L .59704 .75789 L F
.288 0 .041 r
.5998 .75511 m .60076 .75624 L .5991 .75719 L F
.5998 .75511 m .60181 .75518 L .60076 .75624 L F
.37 .007 .212 r
.73928 .71957 m .73675 .72133 L .73693 .71994 L F
.573 .432 .652 r
.73815 .71753 m .73928 .71957 L .73693 .71994 L F
.101 .641 .851 r
.69068 .59081 m .69203 .59117 L .69398 .59121 L F
.208 0 0 r
.36573 .67112 m .3644 .67268 L .36233 .67325 L F
.333 0 0 r
.36573 .67112 m .36635 .67195 L .3644 .67268 L F
.36573 .67112 m .36788 .67136 L .36635 .67195 L F
.574 .026 0 r
.73614 .7161 m .73563 .71534 L .73512 .71364 L F
.73614 .7161 m .73747 .717 L .73563 .71534 L F
.984 .812 .59 r
.57902 .68171 m .57855 .68404 L .57949 .68465 L F
.947 .881 .736 r
.57855 .68404 m .57861 .68693 L .57949 .68465 L F
.904 .517 .277 r
.58007 .75534 m .57865 .75485 L .57779 .75263 L F
.927 .584 .365 r
.58007 .75534 m .57909 .75693 L .57865 .75485 L F
.898 .535 .343 r
.58007 .75534 m .58107 .75786 L .57909 .75693 L F
0 0 0 r
.29062 .64571 m .29177 .64366 L .29297 .64285 L F
.984 .805 .585 r
.57708 .68883 m .57781 .68945 L .57861 .68693 L F
.345 .139 .451 r
.29284 .64001 m .2955 .63763 L .2953 .64022 L F
.399 .158 .429 r
.29297 .64285 m .29284 .64001 L .2953 .64022 L F
.589 .37 .551 r
.68002 .58908 m .68242 .59107 L .68018 .59129 L F
.68002 .58908 m .68297 .58822 L .68242 .59107 L F
.635 .583 .779 r
.3998 .78786 m .40175 .78527 L .39866 .78499 L F
.3998 .78786 m .40189 .78789 L .40175 .78527 L F
.798 .683 .737 r
.63 .64859 m .63328 .64909 L .63366 .64682 L F
.789 .61 .658 r
.63 .64859 m .63352 .65146 L .63328 .64909 L F
.57 .014 0 r
.45817 .76471 m .45917 .76561 L .45771 .76439 L F
.705 .527 .645 r
.62641 .64111 m .62658 .64341 L .62875 .64087 L F
.728 .562 .665 r
.62875 .64087 m .62658 .64341 L .62894 .64337 L F
.738 .629 .738 r
.62894 .64337 m .63229 .64134 L .62875 .64087 L F
.041 0 0 r
.34499 .72746 m .34418 .72727 L .346 .72695 L F
.34499 .72746 m .34298 .72796 L .34418 .72727 L F
.858 .669 .646 r
.61621 .67105 m .61581 .67338 L .61427 .67038 L F
0 0 0 r
.50868 .71932 m .50509 .72 L .50706 .71992 L F
.50706 .71992 m .50711 .72075 L .50868 .71932 L F
.50706 .71992 m .50584 .72158 L .50711 .72075 L F
.37622 .66997 m .37553 .67006 L .37343 .67022 L F
.274 .775 .756 r
.37757 .66943 m .37622 .66997 L .38007 .66933 L F
.37757 .66943 m .37553 .67006 L .37622 .66997 L F
.52 .413 .672 r
.32622 .7001 m .32465 .70477 L .32372 .70051 L F
.32622 .7001 m .32705 .7045 L .32465 .70477 L F
.53 .547 .817 r
.32705 .7045 m .32705 .70521 L .32465 .70477 L F
.074 0 0 r
.59566 .66565 m .59443 .66531 L .59644 .66444 L F
.59566 .66565 m .59324 .66652 L .59443 .66531 L F
.156 0 0 r
.58609 .67037 m .58523 .67185 L .58318 .67234 L F
.294 0 0 r
.58766 .67143 m .58609 .67037 L .58864 .66968 L F
.58766 .67143 m .58523 .67185 L .58609 .67037 L F
.26 0 .075 r
.58935 .65695 m .59135 .65644 L .59221 .65479 L F
.273 0 .081 r
.59221 .65479 m .59334 .6559 L .59422 .65392 L F
.59221 .65479 m .59135 .65644 L .59334 .6559 L F
.538 .395 .634 r
.40505 .7472 m .4069 .74415 L .40464 .74457 L F
.496 .14 .292 r
.43802 .73309 m .44133 .73074 L .43843 .73108 L F
.43802 .73309 m .44031 .73289 L .44133 .73074 L F
.479 .122 .283 r
.44133 .73074 m .44237 .73253 L .44364 .73068 L F
.44133 .73074 m .44031 .73289 L .44237 .73253 L F
.374 .422 .783 r
.57278 .71425 m .57191 .71704 L .57075 .71501 L F
.57278 .71425 m .57322 .71704 L .57191 .71704 L F
.381 .322 .666 r
.57322 .71704 m .57392 .71924 L .57191 .71704 L F
.254 .667 .965 r
.38318 .67044 m .38231 .66933 L .38007 .66933 L F
.81 .352 .143 r
.38456 .67017 m .38231 .66933 L .38318 .67044 L F
.473 .727 .981 r
.55654 .73182 m .55746 .73299 L .55554 .73327 L F
.487 .28 .524 r
.53603 .7363 m .53847 .73598 L .5383 .73343 L F
0 0 .399 r
.5383 .73343 m .53949 .73011 L .53721 .7301 L F
.5383 .73343 m .5395 .73243 L .53949 .73011 L F
.654 .405 .53 r
.5383 .73343 m .54026 .73516 L .5395 .73243 L F
.5383 .73343 m .53847 .73598 L .54026 .73516 L F
.053 .291 .781 r
.55993 .71765 m .56124 .71932 L .55969 .71649 L F
.026 .587 .803 r
.71762 .61923 m .71726 .61905 L .71442 .61879 L F
.677 .971 .788 r
.71895 .61763 m .71762 .61923 L .72013 .61902 L F
.71895 .61763 m .71726 .61905 L .71762 .61923 L F
.186 0 0 r
.53021 .78874 m .53098 .78919 L .52687 .78877 L F
.09 0 0 r
.53132 .78909 m .53021 .78874 L .53304 .78917 L F
.53132 .78909 m .53098 .78919 L .53021 .78874 L F
.467 .793 .999 r
.39407 .8068 m .39243 .80747 L .39289 .80617 L F
.39434 .80714 m .39243 .80747 L .39417 .80676 L F
.191 .723 .79 r
.39434 .80714 m .39553 .80708 L .39243 .80747 L F
.177 0 0 r
.39243 .80747 m .39553 .80708 L .3935 .8076 L F
.823 .869 .88 r
.39289 .80617 m .3935 .8076 L .39423 .80689 L F
.39289 .80617 m .39423 .80689 L .39558 .80557 L F
.467 .793 .999 r
.39417 .80676 m .39407 .8068 L .39289 .80617 L F
.832 .978 .883 r
.39434 .80714 m .39553 .80708 L .39423 .80689 L F
.467 .793 .999 r
.39481 .80707 m .39434 .80714 L .39417 .80676 L F
.832 .978 .883 r
.39423 .80689 m .39553 .80708 L .39558 .80557 L F
.39394 .80717 m .39434 .80714 L .39423 .80689 L F
.3935 .8076 m .39553 .80708 L .39394 .80717 L F
.191 .723 .79 r
.39481 .80707 m .39553 .80708 L .39434 .80714 L F
.896 .987 .744 r
.39558 .80557 m .39553 .80708 L .39481 .80707 L F
.556 .437 .672 r
.60429 .72305 m .6018 .72535 L .60193 .72415 L F
.60429 .72305 m .60404 .72531 L .6018 .72535 L F
.55 .373 .594 r
.60404 .72531 m .60215 .7277 L .6018 .72535 L F
.72 .538 .644 r
.62322 .64334 m .62658 .64341 L .62641 .64111 L F
.096 .044 .502 r
.63033 .67826 m .63055 .68063 L .6291 .68166 L F
0 0 .239 r
.62985 .6827 m .6291 .68166 L .63055 .68063 L F
.62985 .6827 m .62916 .68396 L .6291 .68166 L F
.461 .597 .901 r
.49551 .77872 m .49367 .78024 L .49342 .77857 L F
.564 .544 .791 r
.49551 .77872 m .49444 .78217 L .49367 .78024 L F
0 0 0 r
.30826 .74267 m .30713 .74384 L .30959 .74129 L F
.549 .295 .483 r
.33635 .68587 m .33469 .68399 L .33671 .68392 L F
.33635 .68587 m .33433 .68653 L .33469 .68399 L F
.763 .62 .702 r
.43503 .76597 m .43201 .76602 L .43387 .76318 L F
.713 .473 .561 r
.43503 .76597 m .43169 .76842 L .43201 .76602 L F
.43503 .76597 m .43388 .76846 L .43169 .76842 L F
.55 .535 .791 r
.43599 .76327 m .43682 .76587 L .43503 .76597 L F
.632 .427 .586 r
.43682 .76587 m .43388 .76846 L .43503 .76597 L F
.833 1 .804 r
.31045 .73408 m .30881 .73651 L .3088 .73457 L F
.545 .272 .453 r
.43578 .73331 m .43802 .73309 L .43843 .73108 L F
.372 .8 .969 r
.42548 .78902 m .42371 .78856 L .42213 .78883 L F
.387 0 0 r
.42786 .78895 m .42371 .78856 L .42548 .78902 L F
.532 .345 .573 r
.55746 .73299 m .55915 .73521 L .55923 .7363 L F
.261 .353 .769 r
.55915 .73521 m .55944 .73874 L .55923 .7363 L F
.538 .421 .667 r
.40056 .75243 m .40282 .75456 L .40277 .7521 L F
.40056 .75243 m .40088 .75572 L .40282 .75456 L F
.554 .566 .821 r
.72106 .62033 m .72224 .61805 L .72013 .61902 L F
.72106 .62033 m .72312 .62082 L .72224 .61805 L F
.681 .136 0 r
.49568 .78374 m .49471 .78385 L .49444 .78217 L F
.49568 .78374 m .49767 .78522 L .49471 .78385 L F
.281 .048 .371 r
.30628 .61912 m .3057 .62119 L .30415 .62187 L F
.304 .112 .447 r
.3057 .62119 m .30386 .62421 L .30415 .62187 L F
.616 .383 .541 r
.56336 .69201 m .56538 .69183 L .56574 .68991 L F
.6 .586 .809 r
.56574 .68991 m .568 .68955 L .56683 .68643 L F
.367 .073 .328 r
.56538 .69183 m .568 .68955 L .56574 .68991 L F
.746 .645 .749 r
.568 .68955 m .56538 .69183 L .56574 .68991 L F
.182 0 0 r
.37138 .67054 m .37033 .6711 L .36788 .67136 L F
0 0 0 r
.37343 .67022 m .37033 .6711 L .37138 .67054 L F
.729 .769 .885 r
.70992 .61069 m .71321 .61101 L .71222 .6091 L F
.776 .789 .863 r
.71222 .6091 m .71321 .61101 L .71584 .60872 L F
.968 .663 .267 r
.72688 .60147 m .72752 .60007 L .72683 .59902 L F
.96 .626 .255 r
.72558 .59823 m .72598 .60091 L .72688 .60147 L F
.7 .935 .964 r
.72688 .60147 m .72598 .60091 L .72608 .60085 L F
.96 .626 .255 r
.72558 .59823 m .72688 .60147 L .72683 .59902 L F
.968 .663 .267 r
.72688 .60147 m .72769 .60209 L .72752 .60007 L F
.512 .097 .191 r
.72974 .59758 m .72683 .59902 L .72752 .60007 L F
.546 .384 .613 r
.72683 .59902 m .72688 .60147 L .72908 .59935 L F
.7 .935 .964 r
.72688 .60147 m .72608 .60085 L .72829 .59962 L F
.968 .663 .267 r
.72688 .60147 m .72771 .60235 L .72769 .60209 L F
.286 .787 .83 r
.52586 .78258 m .52801 .78205 L .5291 .78202 L F
.518 .916 .889 r
.5291 .78202 m .53044 .78094 L .53161 .78176 L F
.5291 .78202 m .52801 .78205 L .53044 .78094 L F
0 0 0 r
.56757 .67325 m .5691 .67271 L .57044 .67142 L F
.57044 .67142 m .57091 .67165 L .57224 .67042 L F
.57044 .67142 m .5691 .67271 L .57091 .67165 L F
0 .022 .591 r
.45683 .77365 m .45643 .77447 L .45529 .77127 L F
.172 .55 .929 r
.45683 .77365 m .45828 .77504 L .45643 .77447 L F
.746 .557 .639 r
.55811 .74146 m .55863 .7414 L .55641 .74122 L F
.714 .427 .489 r
.51812 .73959 m .52016 .7396 L .51821 .7404 L F
.621 .958 .894 r
.51821 .7404 m .52016 .7396 L .52176 .73851 L F
.593 .776 .967 r
.38436 .65246 m .38098 .65188 L .38314 .65196 L F
.396 .796 .985 r
.38526 .65172 m .38436 .65246 L .38314 .65196 L F
.38526 .65172 m .38647 .65221 L .38436 .65246 L F
.384 .283 .615 r
.30447 .67628 m .30626 .67821 L .30661 .67592 L F
.30447 .67628 m .30473 .67869 L .30626 .67821 L F
.539 .397 .636 r
.43692 .7523 m .43491 .75506 L .43456 .75274 L F
.816 .441 .345 r
.57018 .68426 m .56844 .68405 L .56704 .68186 L F
.399 .421 .767 r
.40518 .78793 m .40611 .79124 L .4075 .78988 L F
.469 .534 .842 r
.40611 .79124 m .40873 .79242 L .4075 .78988 L F
.188 .232 .676 r
.73347 .72984 m .73289 .73056 L .73246 .72757 L F
.144 .106 .553 r
.73347 .72984 m .73307 .73295 L .73289 .73056 L F
.615 .452 .638 r
.70037 .72215 m .70209 .71961 L .7003 .72025 L F
.70037 .72215 m .70283 .72199 L .70209 .71961 L F
.728 .368 .369 r
.70516 .7216 m .70209 .71961 L .70283 .72199 L F
.514 .589 .868 r
.70238 .73112 m .70411 .72938 L .70111 .72758 L F
.70238 .73112 m .70411 .73089 L .70411 .72938 L F
.503 .406 .678 r
.70238 .73112 m .70487 .73284 L .70411 .73089 L F
.685 .722 .877 r
.71946 .61535 m .71678 .61519 L .71959 .61337 L F
.785 .805 .868 r
.71959 .61337 m .72223 .61366 L .71946 .61535 L F
.583 .627 .861 r
.31281 .72845 m .31637 .73074 L .31493 .72775 L F
.368 .427 .791 r
.31637 .73074 m .31701 .72771 L .31493 .72775 L F
.31637 .73074 m .31845 .73092 L .31701 .72771 L F
.749 .904 .519 r
.52266 .73504 m .52219 .73634 L .52396 .73339 L F
0 .181 .702 r
.52266 .73504 m .52396 .73831 L .52219 .73634 L F
.553 .317 .512 r
.52219 .73634 m .52396 .73831 L .52176 .73851 L F
.818 .858 .877 r
.72561 .61858 m .72919 .61712 L .72807 .61657 L F
0 0 0 r
.72919 .61712 m .73031 .61528 L .72807 .61657 L F
.101 .209 .691 r
.73993 .71881 m .73815 .71753 L .73747 .717 L F
.73993 .71881 m .73928 .71957 L .73815 .71753 L F
.334 .751 .978 r
.2807 .59793 m .27874 .59806 L .27719 .59741 L F
.295 .073 .396 r
.58756 .73882 m .58751 .74134 L .58557 .74157 L F
.786 .286 0 r
.58557 .74157 m .58763 .74423 L .58871 .74458 L F
.344 .305 .671 r
.58751 .74134 m .58763 .74423 L .58557 .74157 L F
.9 .488 .194 r
.68946 .59541 m .68938 .59461 L .68805 .59416 L F
.221 .63 .955 r
.69172 .59497 m .68938 .59461 L .68946 .59541 L F
.836 .725 .742 r
.3008 .73812 m .30186 .73621 L .29943 .73568 L F
.721 .467 .541 r
.59082 .71652 m .59425 .71705 L .59384 .71424 L F
.669 .43 .551 r
.59384 .71424 m .59629 .71658 L .59619 .71416 L F
.59384 .71424 m .59425 .71705 L .59629 .71658 L F
.822 .632 .647 r
.67995 .61849 m .68321 .61638 L .68263 .61593 L F
.67995 .61849 m .68287 .61851 L .68321 .61638 L F
.825 .992 .863 r
.68263 .61593 m .68321 .61638 L .68576 .61388 L F
.497 .684 .95 r
.38558 .67117 m .38664 .6698 L .38456 .67017 L F
.38558 .67117 m .38758 .671 L .38664 .6698 L F
.616 .362 .51 r
.45979 .76351 m .45917 .76561 L .45771 .76439 L F
.45979 .76351 m .45917 .76561 L .45771 .76439 L F
.542 .2 .338 r
.44582 .73039 m .44808 .73031 L .44914 .72807 L F
.54 .198 .337 r
.44914 .72807 m .44808 .73031 L .45111 .72945 L F
.574 .166 .23 r
.44914 .72807 m .45111 .72945 L .45154 .72816 L F
.661 .541 .708 r
.39594 .76922 m .39619 .77154 L .39819 .76879 L F
.542 .371 .599 r
.38508 .68182 m .38729 .68144 L .38724 .67884 L F
.483 .246 .479 r
.38508 .68182 m .38684 .68348 L .38729 .68144 L F
.38508 .68182 m .38478 .68394 L .38684 .68348 L F
.32 .003 .262 r
.39303 .6952 m .39045 .69746 L .39122 .6958 L F
.55 .768 .979 r
.31761 .66413 m .31615 .66515 L .31599 .66459 L F
.798 .683 .737 r
.63 .64859 m .63366 .64682 L .63027 .64626 L F
.253 0 0 r
.51983 .78385 m .52227 .78342 L .52352 .78209 L F
.52 .03 .033 r
.52227 .78342 m .52586 .78258 L .52352 .78209 L F
.056 .262 .756 r
.29634 .71714 m .29648 .71687 L .29603 .71645 L F
0 0 0 r
.2959 .71853 m .29648 .71687 L .29634 .71714 L F
.67 .164 .033 r
.59034 .72304 m .58877 .72335 L .58632 .7221 L F
.946 .72 .565 r
.59034 .72304 m .58967 .72491 L .58877 .72335 L F
.633 .836 .978 r
.59035 .72132 m .59034 .72304 L .59189 .72207 L F
.855 .98 .86 r
.59035 .72132 m .58877 .72335 L .59034 .72304 L F
.183 0 .262 r
.59034 .72304 m .58967 .72491 L .59189 .72207 L F
.113 .28 .756 r
.57002 .73957 m .57131 .74144 L .56993 .73823 L F
.116 0 0 r
.47389 .72575 m .47589 .72543 L .47678 .72492 L F
.403 0 0 r
.47678 .72492 m .47757 .72609 L .47883 .72423 L F
.47678 .72492 m .47589 .72543 L .47757 .72609 L F
.837 .677 .684 r
.72075 .61043 m .72223 .61366 L .71959 .61337 L F
.485 .274 .517 r
.41618 .67025 m .41639 .67318 L .41408 .6737 L F
.439 .301 .596 r
.4194 .66527 m .41618 .67025 L .41626 .6671 L F
.451 .249 .514 r
.41814 .67252 m .41618 .67025 L .41855 .66995 L F
.41814 .67252 m .41639 .67318 L .41618 .67025 L F
.57 .419 .638 r
.39619 .77154 m .39847 .7712 L .39819 .76879 L F
.989 .735 .443 r
.56591 .70411 m .56702 .70358 L .56641 .70201 L F
.56591 .70411 m .56712 .70556 L .56702 .70358 L F
.191 .343 .788 r
.51409 .72746 m .51554 .73034 L .51641 .72983 L F
.228 .091 .477 r
.51444 .7334 m .51641 .72983 L .51554 .73034 L F
.69 .733 .884 r
.32752 .82542 m .32932 .82714 L .33095 .826 L F
.014 .496 .872 r
.73412 .71282 m .7321 .71259 L .73133 .71209 L F
.73412 .71282 m .73512 .71364 L .7321 .71259 L F
.27 .384 .795 r
.68661 .5965 m .68604 .59795 L .68411 .59928 L F
.941 .827 .704 r
.68604 .59795 m .68527 .6004 L .68411 .59928 L F
.038 0 0 r
.52379 .79019 m .52115 .79174 L .52201 .79059 L F
.534 .329 .549 r
.40671 .74174 m .4089 .7414 L .40917 .73891 L F
.6 .388 .564 r
.40917 .73891 m .4089 .7414 L .41118 .74101 L F
0 0 0 r
.56757 .67325 m .5667 .67512 L .5691 .67271 L F
.807 .603 .625 r
.61427 .67038 m .61141 .66752 L .61421 .66809 L F
.572 .634 .874 r
.56049 .73845 m .55986 .74143 L .55944 .73874 L F
.56049 .73845 m .56228 .74108 L .55986 .74143 L F
.336 0 0 r
.46105 .78269 m .46185 .78365 L .45963 .78376 L F
.46105 .78269 m .46318 .78275 L .46185 .78365 L F
.499 .257 .478 r
.40493 .68169 m .40461 .68378 L .4025 .68417 L F
.452 .252 .517 r
.40706 .67889 m .40685 .68118 L .40493 .68169 L F
.546 .347 .562 r
.40685 .68118 m .40461 .68378 L .40493 .68169 L F
.558 .212 .339 r
.41118 .74101 m .41346 .74095 L .41456 .73874 L F
.552 .224 .367 r
.41346 .74095 m .4168 .73857 L .41456 .73874 L F
.596 .445 .647 r
.60611 .72186 m .60351 .71969 L .60569 .71887 L F
.60611 .72186 m .60429 .72305 L .60351 .71969 L F
.279 0 .262 r
.61241 .71387 m .61068 .71617 L .61068 .71409 L F
.382 .158 .445 r
.60856 .74627 m .60627 .74938 L .6065 .74698 L F
.619 .852 .987 r
.72889 .62522 m .72935 .62586 L .7284 .62529 L F
.891 .553 .063 r
.72962 .62513 m .73006 .62685 L .72935 .62586 L F
.227 .601 .95 r
.73228 .62479 m .73383 .62626 L .72962 .62513 L F
.73228 .62479 m .72962 .62513 L .72935 .62586 L F
.619 .852 .987 r
.73228 .62479 m .72935 .62586 L .72889 .62522 L F
.891 .553 .063 r
.73006 .62685 m .73029 .62774 L .72935 .62586 L F
.221 .728 .894 r
.69528 .6079 m .6951 .60777 L .69207 .60773 L F
.859 .987 .714 r
.6964 .6051 m .69528 .6079 L .69723 .60733 L F
.6964 .6051 m .6951 .60777 L .69528 .6079 L F
.947 .628 .197 r
.54151 .69762 m .54273 .70072 L .54192 .69979 L F
.649 .11 0 r
.54273 .70072 m .5447 .70271 L .54349 .702 L F
.708 .279 .228 r
.57715 .70548 m .57974 .70747 L .58108 .70587 L F
.95 .65 .434 r
.57974 .70747 m .58144 .70877 L .58108 .70587 L F
.574 .786 .979 r
.7042 .61019 m .70562 .60833 L .703 .60754 L F
.7042 .61019 m .70663 .60976 L .70562 .60833 L F
.666 .224 .193 r
.5794 .73069 m .58285 .73261 L .58308 .73073 L F
.94 .636 .181 r
.58308 .73073 m .58285 .73261 L .58357 .73328 L F
.457 .142 .343 r
.55785 .69725 m .5608 .69513 L .55855 .69585 L F
.585 .463 .68 r
.39945 .76065 m .40166 .76034 L .40132 .75786 L F
.55 .414 .649 r
.39945 .76065 m .40175 .76263 L .40166 .76034 L F
.39945 .76065 m .39968 .76307 L .40175 .76263 L F
.574 .435 .654 r
.40671 .74174 m .40908 .74378 L .4089 .7414 L F
.40671 .74174 m .4069 .74415 L .40908 .74378 L F
.21 .491 .899 r
.54588 .72499 m .54508 .72594 L .54386 .7249 L F
.54588 .72499 m .54756 .72691 L .54508 .72594 L F
.66 .715 .889 r
.30959 .74129 m .3133 .74217 L .31062 .73833 L F
.845 .768 .776 r
.31062 .73833 m .3133 .74217 L .31542 .73614 L F
0 0 0 r
.4309 .78786 m .42835 .78886 L .42786 .78895 L F
.215 .729 .691 r
.43169 .78761 m .4315 .78768 L .43287 .78727 L F
.112 0 0 r
.43491 .78688 m .43341 .78766 L .43169 .78761 L F
.006 .577 .773 r
.43169 .78761 m .43341 .78766 L .43196 .7875 L F
.43169 .78761 m .43196 .7875 L .43169 .78747 L F
.215 .729 .691 r
.43169 .78761 m .4309 .78786 L .4315 .78768 L F
0 0 0 r
.43169 .78761 m .42835 .78886 L .4309 .78786 L F
.895 .988 .754 r
.67174 .61158 m .67271 .6112 L .67142 .61302 L F
.67271 .6112 m .67293 .61111 L .67267 .61145 L F
.685 .402 .488 r
.67239 .6116 m .67377 .61447 L .67142 .61302 L F
.204 .347 .787 r
.67259 .61185 m .67472 .61576 L .67579 .61587 L F
.67257 .61193 m .67472 .61576 L .67259 .61185 L F
.861 .459 .272 r
.67252 .61188 m .67579 .61587 L .67377 .61447 L F
.204 .347 .787 r
.67239 .6116 m .67257 .61193 L .67259 .61185 L F
.861 .459 .272 r
.67239 .6116 m .67259 .61185 L .67252 .61188 L F
.67259 .61185 m .67579 .61587 L .67252 .61188 L F
.646 .813 .963 r
.67552 .61029 m .67239 .6116 L .67293 .61111 L F
0 0 0 r
.67293 .61111 m .67269 .61133 L .67267 .61145 L F
.67269 .61133 m .67239 .6116 L .67267 .61145 L F
.67267 .61145 m .67239 .6116 L .67142 .61302 L F
.895 .988 .754 r
.67271 .6112 m .67267 .61145 L .67222 .61201 L F
.6721 .61206 m .67222 .61201 L .67142 .61302 L F
.67271 .6112 m .67222 .61201 L .6721 .61206 L F
.302 0 .019 r
.59487 .75847 m .59385 .75999 L .59154 .7605 L F
.155 0 0 r
.59704 .75789 m .59385 .75999 L .59487 .75847 L F
.717 .804 .919 r
.72704 .72762 m .72372 .7274 L .72587 .72639 L F
.519 .749 .979 r
.72281 .72628 m .7215 .72768 L .72013 .72571 L F
.72281 .72628 m .72372 .7274 L .7215 .72768 L F
.593 .391 .577 r
.29251 .70066 m .29479 .70033 L .29491 .69805 L F
.558 .398 .621 r
.29491 .69805 m .29705 .6977 L .29699 .69515 L F
.538 .342 .563 r
.29479 .70033 m .29705 .6977 L .29491 .69805 L F
.527 .791 .993 r
.51617 .74094 m .51763 .74191 L .51399 .74133 L F
.054 0 .433 r
.51821 .7404 m .51763 .74191 L .51812 .73959 L F
.51821 .7404 m .51763 .74191 L .51812 .73959 L F
.26 0 0 r
.45828 .77504 m .46058 .77543 L .46208 .77516 L F
.16 0 0 r
.46058 .77543 m .4639 .77519 L .46208 .77516 L F
.042 0 0 r
.3524 .71033 m .35639 .70907 L .3541 .70937 L F
.439 0 .031 r
.47191 .78158 m .47107 .78245 L .4688 .78245 L F
.452 0 .04 r
.47436 .7818 m .47107 .78245 L .47191 .78158 L F
.462 .228 .473 r
.40274 .74971 m .40472 .74927 L .40505 .7472 L F
.538 .395 .634 r
.40505 .7472 m .40713 .74682 L .4069 .74415 L F
.466 .219 .455 r
.40472 .74927 m .40713 .74682 L .40505 .7472 L F
.691 .441 .54 r
.72416 .58191 m .72631 .5831 L .72574 .58089 L F
.412 0 0 r
.72987 .58298 m .72574 .58089 L .72631 .5831 L F
.224 0 .263 r
.39045 .69746 m .38807 .70014 L .38885 .69828 L F
.339 0 0 r
.56683 .68643 m .5702 .68679 L .56815 .68637 L F
.354 .446 .817 r
.275 .6075 m .27503 .60878 L .27611 .6071 L F
.435 .555 .877 r
.27503 .60878 m .27805 .61012 L .27611 .6071 L F
.304 .485 .872 r
.34557 .70536 m .34474 .70694 L .34376 .70618 L F
.34557 .70536 m .34701 .7078 L .34474 .70694 L F
.587 .421 .624 r
.48155 .73589 m .47945 .73858 L .47935 .73626 L F
.616 .609 .821 r
.43289 .77386 m .43079 .77428 L .42945 .77121 L F
0 .16 .625 r
.59062 .74594 m .59125 .74643 L .59115 .74636 L F
.902 .493 .104 r
.58781 .74278 m .5888 .7439 L .58771 .74366 L F
.5888 .7439 m .59062 .74594 L .58782 .74375 L F
.5888 .7439 m .58782 .74375 L .58771 .74366 L F
.58781 .74278 m .58846 .74413 L .59062 .74594 L F
0 .16 .625 r
.59062 .74594 m .59088 .74616 L .59081 .74611 L F
.59062 .74594 m .59081 .74611 L .58871 .74458 L F
.59062 .74594 m .58871 .74458 L .58763 .74423 L F
.902 .493 .104 r
.58771 .74366 m .59062 .74594 L .58763 .74423 L F
.58846 .74413 m .58883 .74489 L .58914 .7447 L F
.43 .028 .173 r
.58883 .74489 m .58918 .74467 L .59062 .74594 L F
.58918 .74467 m .59236 .74262 L .59062 .74594 L F
.58883 .74489 m .59122 .7445 L .59135 .74429 L F
.59008 .74409 m .59135 .74429 L .59236 .74262 L F
.58883 .74489 m .59135 .74429 L .59008 .74409 L F
0 .16 .625 r
.59062 .74594 m .59115 .74636 L .59088 .74616 L F
0 0 0 r
.71349 .71713 m .7099 .71858 L .7126 .71674 L F
.56 .924 .943 r
.71556 .71622 m .71349 .71713 L .7148 .71595 L F
.551 .903 .972 r
.7148 .71595 m .71349 .71713 L .7126 .71674 L F
.827 .715 .741 r
.43387 .76318 m .4306 .76538 L .43258 .76293 L F
.43387 .76318 m .43201 .76602 L .4306 .76538 L F
.542 0 0 r
.43258 .76293 m .43599 .76327 L .43387 .76318 L F
0 0 0 r
.54583 .78471 m .54296 .78652 L .54376 .78572 L F
.519 .577 .854 r
.40417 .65976 m .40356 .66269 L .40216 .65983 L F
.40417 .65976 m .40553 .66261 L .40356 .66269 L F
.492 .47 .761 r
.63352 .65146 m .63582 .65434 L .6345 .65443 L F
.333 0 .041 r
.6345 .65443 m .63128 .65628 L .63442 .65673 L F
.6345 .65443 m .63582 .65434 L .63128 .65628 L F
.912 .89 .796 r
.63381 .66257 m .63569 .65987 L .63461 .65907 L F
.369 0 .159 r
.58412 .7226 m .58326 .72453 L .58096 .72493 L F
0 0 0 r
.58431 .72232 m .58412 .7226 L .58632 .7221 L F
.58431 .72232 m .58326 .72453 L .58412 .7226 L F
.468 .623 .918 r
.30591 .60442 m .30241 .60245 L .30422 .60241 L F
.366 .581 .925 r
.3077 .60464 m .30591 .60442 L .30422 .60241 L F
.044 0 .444 r
.67966 .59527 m .67815 .59451 L .68014 .59356 L F
.67966 .59527 m .67814 .59678 L .67815 .59451 L F
.778 .558 .601 r
.56522 .73012 m .56856 .73053 L .5679 .72859 L F
.076 .158 .648 r
.56856 .73053 m .568 .72704 L .5679 .72859 L F
.56 .405 .627 r
.33012 .69235 m .32914 .6904 L .33027 .68998 L F
.536 .361 .592 r
.38279 .68441 m .38484 .68637 L .38478 .68394 L F
.38279 .68441 m .38284 .68678 L .38484 .68637 L F
.813 .637 .663 r
.47717 .73909 m .47396 .74067 L .47379 .73946 L F
.488 .614 .903 r
.2787 .61158 m .27957 .60972 L .27805 .61012 L F
.2787 .61158 m .28105 .61167 L .27957 .60972 L F
.418 .538 .871 r
.2787 .61158 m .28178 .61402 L .28105 .61167 L F
.294 .409 .809 r
.56124 .71932 m .56125 .71638 L .55969 .71649 L F
.56124 .71932 m .5625 .71946 L .56125 .71638 L F
.561 .507 .752 r
.57879 .7274 m .5794 .73069 L .57716 .73107 L F
.553 .391 .616 r
.40274 .74971 m .4049 .75167 L .40472 .74927 L F
.40274 .74971 m .40277 .7521 L .4049 .75167 L F
.521 .162 .298 r
.6808 .58322 m .68503 .58328 L .68392 .58136 L F
.411 .123 .363 r
.68392 .58136 m .68595 .58262 L .68604 .58045 L F
.68392 .58136 m .68503 .58328 L .68595 .58262 L F
.383 .065 .297 r
.28634 .6487 m .28356 .65089 L .28458 .64955 L F
.181 0 .286 r
.3083 .61639 m .30771 .61829 L .30628 .61912 L F
.213 0 .339 r
.30771 .61829 m .3057 .62119 L .30628 .61912 L F
.81 .738 .784 r
.71678 .61519 m .71329 .61551 L .71557 .61285 L F
.71678 .61519 m .71504 .61655 L .71329 .61551 L F
.686 .72 .876 r
.71959 .61337 m .71678 .61519 L .71557 .61285 L F
.68 .843 .961 r
.68658 .59289 m .68363 .59427 L .68499 .59233 L F
.68 .136 0 r
.68363 .59427 m .68661 .5965 L .6847 .59575 L F
.68363 .59427 m .6847 .59575 L .68499 .59233 L F
.677 .772 .923 r
.42144 .73534 m .42243 .73615 L .41897 .73574 L F
.491 .714 .97 r
.4236 .73491 m .42243 .73615 L .42144 .73534 L F
.611 .336 .477 r
.42243 .73615 m .42448 .73812 L .4247 .73623 L F
.233 .304 .732 r
.4236 .73491 m .42448 .73812 L .42243 .73615 L F
.746 .645 .749 r
.568 .68955 m .56915 .69281 L .56538 .69183 L F
.489 .272 .511 r
.57156 .69207 m .5712 .69373 L .56915 .69281 L F
.617 .506 .705 r
.42851 .7658 m .42939 .76884 L .42656 .76826 L F
.596 .471 .681 r
.42939 .76884 m .42723 .77155 L .42656 .76826 L F
.92 .531 .233 r
.4628 .75727 m .46446 .75833 L .46348 .75669 L F
.469 .634 .926 r
.34943 .70742 m .34838 .70906 L .34701 .7078 L F
.34943 .70742 m .3498 .70899 L .34838 .70906 L F
0 .135 .682 r
.58625 .73631 m .58785 .73812 L .58756 .73882 L F
0 0 .293 r
.58847 .74012 m .58756 .73882 L .58785 .73812 L F
.58847 .74012 m .58751 .74134 L .58756 .73882 L F
.663 .542 .706 r
.32622 .7001 m .32372 .70051 L .32587 .69789 L F
.458 .207 .445 r
.38593 .70278 m .38392 .70334 L .38641 .70084 L F
.461 .248 .503 r
.38807 .70014 m .38593 .70278 L .38641 .70084 L F
.748 .544 .619 r
.62665 .64578 m .62894 .64337 L .62658 .64341 L F
.62665 .64578 m .63027 .64626 L .62894 .64337 L F
0 .574 .736 r
.71504 .58281 m .71739 .58291 L .71838 .58298 L F
.028 .599 .753 r
.71739 .58291 m .72067 .58302 L .71838 .58298 L F
.502 0 0 r
.57264 .7097 m .57387 .7085 L .5716 .708 L F
.57264 .7097 m .57276 .70999 L .57387 .7085 L F
.57264 .7097 m .57444 .71104 L .57276 .70999 L F
.821 .455 .363 r
.57018 .68426 m .56905 .68585 L .56844 .68405 L F
.548 .756 .973 r
.57018 .68426 m .57239 .68403 L .57137 .68288 L F
.532 .331 .554 r
.60796 .71691 m .60569 .71887 L .60543 .71706 L F
.476 .32 .589 r
.38724 .67884 m .38912 .68079 L .38913 .6784 L F
.38724 .67884 m .38729 .68144 L .38912 .68079 L F
.683 .894 .532 r
.55124 .69092 m .55019 .69203 L .55182 .69009 L F
.889 .767 .721 r
.55124 .69092 m .54908 .69485 L .54775 .69336 L F
.633 .575 .771 r
.55019 .69203 m .55309 .69172 L .55274 .69073 L F
.923 .694 .574 r
.55182 .69009 m .55038 .68988 L .55016 .6867 L F
.55182 .69009 m .55038 .68988 L .55016 .6867 L F
.633 .575 .771 r
.55019 .69203 m .55274 .69073 L .55224 .6893 L F
.889 .767 .721 r
.55124 .69092 m .54824 .69302 L .55019 .69203 L F
.54824 .69302 m .54775 .69336 L .55019 .69203 L F
.189 .427 .859 r
.52261 .70743 m .52166 .70822 L .52094 .70713 L F
.768 .4 0 r
.57779 .75263 m .57803 .75382 L .5772 .75214 L F
0 .011 .58 r
.5772 .75214 m .57803 .75382 L .57773 .75284 L F
.5772 .75214 m .57773 .75284 L .57709 .75079 L F
.626 .142 0 r
.57598 .7505 m .5772 .75214 L .57538 .7498 L F
.57779 .75263 m .5772 .75214 L .57598 .7505 L F
.768 .4 0 r
.57779 .75263 m .57865 .75485 L .57803 .75382 L F
.384 .336 .681 r
.60605 .73595 m .60513 .73828 L .60429 .73692 L F
.60605 .73595 m .60661 .73846 L .60513 .73828 L F
0 0 .374 r
.51812 .73959 m .51821 .7404 L .5186 .73829 L F
.746 .709 .817 r
.55005 .70775 m .55215 .70894 L .55157 .70809 L F
.909 .605 .115 r
.55215 .70894 m .55261 .71139 L .55157 .70809 L F
.355 0 .019 r
.35409 .72234 m .35255 .72399 L .35041 .72428 L F
.218 0 0 r
.35455 .72347 m .35409 .72234 L .35605 .72179 L F
.35455 .72347 m .35255 .72399 L .35409 .72234 L F
.593 .618 .846 r
.54908 .69485 m .54687 .69532 L .54566 .69276 L F
.499 .724 .973 r
.27223 .6074 m .27316 .60626 L .27074 .60618 L F
.27223 .6074 m .275 .6075 L .27316 .60626 L F
.455 .221 .469 r
.40919 .67849 m .40685 .68118 L .40706 .67889 L F
.918 .625 .473 r
.39192 .7779 m .39166 .77981 L .39364 .77751 L F
.637 .815 .968 r
.3389 .70784 m .33596 .70749 L .33814 .70652 L F
.69 .852 .96 r
.34158 .70659 m .3389 .70784 L .33814 .70652 L F
.556 .33 .527 r
.30272 .68174 m .30462 .6835 L .30465 .68113 L F
.30272 .68174 m .3023 .68398 L .30462 .6835 L F
.847 .658 .647 r
.72075 .61043 m .71933 .60725 L .72125 .60816 L F
.559 .783 .983 r
.69723 .60733 m .70103 .60789 L .70138 .6072 L F
.418 .793 .993 r
.70103 .60789 m .70372 .60704 L .70138 .6072 L F
.70103 .60789 m .703 .60754 L .70372 .60704 L F
0 0 0 r
.48706 .7201 m .48757 .7206 L .4891 .71938 L F
.48706 .7201 m .48571 .72149 L .48757 .7206 L F
.529 .343 .573 r
.35147 .85328 m .35138 .85594 L .35343 .8554 L F
.617 .677 .884 r
.33596 .70749 m .33388 .70805 L .33243 .70576 L F
.499 .424 .703 r
.39775 .76651 m .40004 .76831 L .3999 .76606 L F
.39775 .76651 m .39819 .76879 L .40004 .76831 L F
.038 .257 .755 r
.29603 .71645 m .29726 .71375 L .2949 .71399 L F
.29603 .71645 m .297 .71605 L .29726 .71375 L F
.29603 .71645 m .29648 .71687 L .297 .71605 L F
.368 .462 .825 r
.29365 .70556 m .29508 .70297 L .29304 .70335 L F
.29365 .70556 m .29538 .70573 L .29508 .70297 L F
.29365 .70556 m .29452 .70588 L .29538 .70573 L F
.458 .406 .711 r
.29377 .70614 m .29452 .70588 L .29365 .70556 L F
.661 .704 .879 r
.32594 .73496 m .3288 .73549 L .3275 .73518 L F
.139 0 0 r
.49273 .73347 m .49211 .73335 L .48934 .7328 L F
.778 .318 .152 r
.49273 .73347 m .49193 .73479 L .49211 .73335 L F
.49273 .73347 m .49502 .7358 L .49193 .73479 L F
.639 .401 .541 r
.49501 .73327 m .49502 .7358 L .49273 .73347 L F
0 0 .234 r
.73416 .62595 m .73331 .62723 L .73383 .62626 L F
0 .281 .761 r
.73526 .62805 m .73331 .62723 L .73416 .62595 L F
.73526 .62805 m .73591 .62895 L .73331 .62723 L F
.576 .466 .692 r
.42716 .76058 m .42426 .75755 L .42584 .75711 L F
.42716 .76058 m .42502 .76159 L .42426 .75755 L F
.996 .818 .547 r
.52303 .73267 m .52266 .73504 L .52396 .73339 L F
.503 .252 .466 r
.52396 .73339 m .52614 .733 L .52406 .73566 L F
.274 .077 .422 r
.62228 .69456 m .62089 .69529 L .62268 .69238 L F
.079 0 .308 r
.62228 .69456 m .62072 .69757 L .62089 .69529 L F
.363 .827 .757 r
.28356 .65089 m .28235 .65142 L .28187 .65165 L F
.04 0 0 r
.28187 .65165 m .28235 .65142 L .28169 .65193 L F
.916 .9 .795 r
.54348 .69297 m .54203 .69538 L .54098 .69445 L F
.997 .848 .56 r
.54203 .69538 m .54071 .6968 L .54098 .69445 L F
.54203 .69538 m .54151 .69762 L .54071 .6968 L F
.604 .535 .75 r
.29388 .70862 m .29452 .70588 L .29377 .70614 L F
.919 .932 .802 r
.63169 .67347 m .63333 .67133 L .63103 .67239 L F
.934 .826 .714 r
.63103 .67239 m .63333 .67133 L .63364 .66952 L F
.583 .573 .808 r
.31328 .60517 m .31216 .60837 L .3111 .60549 L F
.31328 .60517 m .31409 .60779 L .31216 .60837 L F
.483 .394 .679 r
.31409 .60779 m .31274 .6108 L .31216 .60837 L F
.594 .279 .405 r
.37658 .8124 m .37913 .81257 L .37823 .81404 L F
.37658 .8124 m .37913 .81257 L .37823 .81404 L F
.442 .205 .457 r
.31006 .61566 m .30771 .61829 L .3083 .61639 L F
.605 .526 .739 r
.49828 .72644 m .49781 .73081 L .49698 .72804 L F
.614 .481 .676 r
.4997 .73101 m .49825 .73322 L .49781 .73081 L F
.36 0 0 r
.46282 .77544 m .46513 .77551 L .46594 .77487 L F
.736 .945 .63 r
.46594 .77487 m .46513 .77551 L .46537 .77515 L F
.46594 .77487 m .46537 .77515 L .46603 .77417 L F
.005 0 0 r
.4665 .7746 m .46594 .77487 L .46762 .77435 L F
.4639 .77519 m .46594 .77487 L .4665 .7746 L F
0 0 0 r
.46762 .77435 m .46876 .774 L .46965 .77367 L F
.46762 .77435 m .46594 .77487 L .46876 .774 L F
.482 .654 .936 r
.30323 .60082 m .30241 .60245 L .30126 .60084 L F
.444 .608 .917 r
.30422 .60241 m .30241 .60245 L .30323 .60082 L F
.916 .9 .795 r
.54348 .69297 m .54098 .69445 L .54277 .69273 L F
.477 .758 .992 r
.54468 .6917 m .54348 .69297 L .54277 .69273 L F
.54468 .6917 m .54566 .69276 L .54348 .69297 L F
.11 0 0 r
.48981 .77847 m .49342 .77857 L .491 .77795 L F
.482 .234 .461 r
.40461 .68378 m .40207 .68632 L .4025 .68417 L F
.774 .543 .585 r
.7181 .60397 m .72015 .60503 L .72142 .60302 L F
.567 .75 .963 r
.29531 .5998 m .29333 .60027 L .29188 .59891 L F
.72 .637 .765 r
.65409 .60197 m .65518 .60542 L .65758 .60285 L F
.483 .394 .679 r
.31409 .60779 m .31455 .61018 L .31274 .6108 L F
.353 .182 .506 r
.31417 .61227 m .31274 .6108 L .31455 .61018 L F
.31417 .61227 m .31264 .61306 L .31274 .6108 L F
.727 .703 .827 r
.43482 .77121 m .43631 .77421 L .43289 .77386 L F
.562 .548 .796 r
.43736 .77074 m .43631 .77421 L .43482 .77121 L F
.43736 .77074 m .43843 .77399 L .43631 .77421 L F
.524 .427 .687 r
.29699 .69515 m .29848 .69239 L .29656 .6929 L F
.813 .637 .663 r
.47717 .73909 m .4772 .74148 L .47396 .74067 L F
.641 .498 .672 r
.47945 .73858 m .4772 .74148 L .47717 .73909 L F
0 0 0 r
.67294 .59025 m .67132 .59097 L .67141 .59229 L F
.434 .283 .576 r
.67294 .59025 m .67463 .59053 L .67378 .59007 L F
0 0 0 r
.67294 .59025 m .674 .58902 L .67205 .59044 L F
.67541 .58732 m .674 .58902 L .67546 .58724 L F
.582 .839 .479 r
.67546 .58724 m .674 .58902 L .67294 .59025 L F
.67546 .58724 m .67294 .59025 L .67417 .58924 L F
.67546 .58724 m .67449 .58875 L .67499 .58857 L F
.492 .188 .378 r
.67549 .5884 m .67499 .58857 L .67431 .58818 L F
.67708 .58869 m .6774 .58693 L .67499 .58857 L F
.67708 .58869 m .67499 .58857 L .67549 .5884 L F
.582 .839 .479 r
.67449 .58875 m .67417 .58924 L .67499 .58857 L F
0 0 0 r
.67623 .58632 m .67541 .58732 L .67546 .58724 L F
.71 .816 .931 r
.67499 .58857 m .67294 .59025 L .67182 .58899 L F
.434 .283 .576 r
.67294 .59025 m .67378 .59007 L .67182 .58899 L F
0 0 0 r
.67294 .59025 m .67205 .59044 L .67132 .59097 L F
.759 .464 .486 r
.60421 .649 m .60766 .65129 L .60764 .6489 L F
.662 .468 .612 r
.60766 .65129 m .61064 .64786 L .60764 .6489 L F
.419 .777 .996 r
.27032 .59572 m .26983 .59673 L .26831 .59594 L F
.27032 .59572 m .27185 .59651 L .26983 .59673 L F
.73 .657 .777 r
.40175 .78527 m .40189 .78789 L .40405 .78481 L F
.683 .591 .746 r
.40189 .78789 m .40518 .78793 L .40405 .78481 L F
.45 .186 .42 r
.40015 .68684 m .39976 .68924 L .3977 .68961 L F
.415 .156 .41 r
.40166 .68868 m .40015 .68684 L .40207 .68632 L F
.40166 .68868 m .39976 .68924 L .40015 .68684 L F
.692 .976 .908 r
.31239 .72631 m .31194 .7266 L .31164 .72755 L F
.31194 .7266 m .30984 .72797 L .31164 .72755 L F
.66 .706 .881 r
.30954 .72768 m .31146 .72813 L .31164 .72755 L F
.31146 .72813 m .31281 .72845 L .31164 .72755 L F
.634 .83 .976 r
.31164 .72755 m .31281 .72845 L .31493 .72775 L F
.17 .708 .772 r
.44445 .78593 m .44277 .78602 L .44018 .78641 L F
.174 .706 .838 r
.44633 .78597 m .44277 .78602 L .44445 .78593 L F
.576 .661 .895 r
.70172 .59903 m .69834 .59722 L .70081 .59666 L F
.752 .719 .822 r
.70081 .59666 m .70434 .59709 L .70172 .59903 L F
.41 .186 .459 r
.385 .70476 m .38392 .70334 L .38593 .70278 L F
.385 .70476 m .38342 .70534 L .38392 .70334 L F
.676 .674 .841 r
.72974 .59758 m .73306 .59927 L .73204 .59656 L F
.73 .67 .791 r
.73204 .59656 m .73306 .59927 L .73454 .59682 L F
0 0 .309 r
.35289 .85866 m .35343 .8554 L .35138 .85594 L F
.533 .405 .651 r
.29304 .70335 m .29479 .70033 L .29251 .70066 L F
.324 0 .153 r
.33518 .65377 m .33718 .65324 L .33853 .65102 L F
.309 0 .144 r
.33853 .65102 m .33918 .65266 L .34072 .6511 L F
.33853 .65102 m .33718 .65324 L .33918 .65266 L F
.453 .11 .293 r
.33937 .68211 m .33882 .6836 L .33671 .68392 L F
.395 .056 .268 r
.34087 .68308 m .33937 .68211 L .34197 .68093 L F
.34087 .68308 m .33882 .6836 L .33937 .68211 L F
0 0 0 r
.58005 .6653 m .58125 .6643 L .58263 .663 L F
.58263 .663 m .5831 .66331 L .58424 .66185 L F
.58263 .663 m .58125 .6643 L .5831 .66331 L F
.727 .734 .856 r
.67762 .61947 m .68126 .61982 L .67995 .61849 L F
.794 .798 .856 r
.67995 .61849 m .68126 .61982 L .68287 .61851 L F
.61 .233 .303 r
.45111 .72945 m .4547 .72771 L .45154 .72816 L F
.45111 .72945 m .4534 .72977 L .4547 .72771 L F
.417 0 .045 r
.4534 .72977 m .45718 .72799 L .4547 .72771 L F
.43 .087 .282 r
.34394 .68022 m .34087 .68308 L .34197 .68093 L F
.348 .354 .724 r
.56835 .73351 m .57022 .73264 L .56909 .73305 L F
.56835 .73351 m .57125 .73483 L .57022 .73264 L F
.52 .499 .774 r
.56993 .73823 m .57125 .73483 L .56835 .73351 L F
.381 .137 .414 r
.2787 .62917 m .27696 .62956 L .27692 .62975 L F
.2787 .62917 m .27922 .62705 L .27696 .62956 L F
.324 .177 .521 r
.39847 .7712 m .40004 .76831 L .39819 .76879 L F
.234 0 0 r
.41352 .66529 m .41576 .66504 L .41649 .66434 L F
.32 0 0 r
.41085 .66499 m .41308 .665 L .41163 .66529 L F
.41308 .665 m .41487 .66502 L .41163 .66529 L F
.41085 .66499 m .41351 .66529 L .41487 .66502 L F
.234 0 0 r
.41351 .66529 m .41692 .66392 L .41487 .66502 L F
.4153 .66457 m .41649 .66434 L .41692 .66392 L F
.41351 .66529 m .41649 .66434 L .4153 .66457 L F
0 .538 .822 r
.41692 .66392 m .41963 .66444 L .41956 .66457 L F
.204 0 0 r
.41576 .66504 m .41963 .66444 L .41692 .66392 L F
.41576 .66504 m .41769 .66503 L .41963 .66444 L F
.514 .555 .835 r
.41635 .66206 m .4176 .66484 L .41576 .66504 L F
.4176 .66484 m .41769 .66503 L .41576 .66504 L F
.234 0 0 r
.41351 .66529 m .41576 .66504 L .41352 .66529 L F
.32 0 0 r
.41163 .66529 m .41487 .66502 L .41251 .66562 L F
.524 .427 .687 r
.29699 .69515 m .2989 .69469 L .29848 .69239 L F
.546 .407 .643 r
.29705 .6977 m .2989 .69469 L .29699 .69515 L F
0 0 0 r
.58005 .6653 m .57871 .66662 L .58125 .6643 L F
.70049 .58335 m .70068 .5833 L .703 .5826 L F
.772 .522 .557 r
.61124 .66521 m .60791 .66704 L .60782 .66541 L F
.61124 .66521 m .61141 .66752 L .60791 .66704 L F
.319 0 .027 r
.72248 .71965 m .7216 .72173 L .71902 .72189 L F
.277 0 .012 r
.72443 .72079 m .72248 .71965 L .72482 .72015 L F
.72443 .72079 m .7216 .72173 L .72248 .71965 L F
.488 .228 .446 r
.37396 .69789 m .3761 .6975 L .37653 .6954 L F
.354 .11 .399 r
.37653 .6954 m .37791 .69672 L .3785 .69499 L F
.37653 .6954 m .3761 .6975 L .37791 .69672 L F
.724 .505 .592 r
.62325 .6456 m .62658 .64341 L .62322 .64334 L F
.62325 .6456 m .62665 .64578 L .62658 .64341 L F
.532 .518 .785 r
.38758 .671 m .38816 .67394 L .39041 .67263 L F
.419 .343 .664 r
.38816 .67394 m .39048 .67474 L .39041 .67263 L F
.38816 .67394 m .38872 .67599 L .39048 .67474 L F
.789 .61 .658 r
.63 .64859 m .62978 .65108 L .63352 .65146 L F
.765 .524 .569 r
.62976 .65334 m .63352 .65146 L .62978 .65108 L F
.62976 .65334 m .63582 .65434 L .63352 .65146 L F
.565 .454 .686 r
.40088 .75572 m .40344 .75748 L .40282 .75456 L F
.40088 .75572 m .40132 .75786 L .40344 .75748 L F
.181 .296 .747 r
.28178 .61402 m .28267 .61594 L .28365 .61588 L F
.503 .438 .716 r
.28263 .61857 m .28365 .61588 L .28267 .61594 L F
.5 .8 .999 r
.285 .59724 m .28453 .59855 L .28273 .59767 L F
.285 .59724 m .28665 .59821 L .28453 .59855 L F
.507 .352 .605 r
.59306 .73892 m .59537 .73881 L .59455 .73603 L F
.238 .588 .947 r
.37325 .64882 m .37208 .64946 L .37068 .64824 L F
.37325 .64882 m .37433 .64987 L .37208 .64946 L F
.596 .471 .681 r
.42939 .76884 m .42945 .77121 L .42723 .77155 L F
.551 .416 .65 r
.30049 .68675 m .3023 .68398 L .30024 .68438 L F
.493 .603 .891 r
.5447 .70271 m .54625 .70534 L .54823 .70513 L F
.825 .992 .863 r
.68263 .61593 m .68576 .61388 L .68421 .61274 L F
.811 .777 .821 r
.68421 .61274 m .68576 .61388 L .68789 .61169 L F
.981 .695 .328 r
.70222 .59038 m .70327 .59158 L .70334 .59408 L F
.428 .524 .854 r
.70327 .59158 m .70627 .59423 L .70334 .59408 L F
.7 .404 .471 r
.31761 .66413 m .32033 .66438 L .32102 .66251 L F
.478 .178 .377 r
.32102 .66251 m .32033 .66438 L .32315 .66217 L F
.566 .588 .835 r
.28105 .61167 m .28178 .61402 L .2832 .61156 L F
.181 .296 .747 r
.28178 .61402 m .28365 .61588 L .2832 .61156 L F
.552 .382 .605 r
.33187 .69195 m .33027 .68998 L .33211 .68951 L F
.33187 .69195 m .33012 .69235 L .33027 .68998 L F
.552 .471 .717 r
.42716 .76058 m .42525 .76261 L .42502 .76159 L F
.42716 .76058 m .42729 .76227 L .42525 .76261 L F
.304 0 0 r
.72175 .71501 m .72121 .71401 L .72023 .71569 L F
.72175 .71501 m .72354 .71379 L .72121 .71401 L F
.428 .1 .305 r
.37664 .70933 m .37602 .71088 L .37397 .71128 L F
.367 .043 .277 r
.37809 .71026 m .37664 .70933 L .37871 .70894 L F
.37809 .71026 m .37602 .71088 L .37664 .70933 L F
.521 .869 .989 r
.55905 .69187 m .55706 .6925 L .56028 .69238 L F
.71 .669 .808 r
.56092 .68998 m .56028 .69238 L .56336 .69201 L F
.221 0 0 r
.56049 .69183 m .55829 .69348 L .55905 .69187 L F
.046 .041 .527 r
.56125 .68884 m .56161 .6918 L .56028 .69238 L F
.56072 .6908 m .56028 .69238 L .56076 .69058 L F
.302 .754 .957 r
.56028 .69238 m .56161 .6918 L .55905 .69187 L F
.221 0 0 r
.56161 .6918 m .56036 .69243 L .56049 .69183 L F
.56036 .69243 m .55829 .69348 L .56049 .69183 L F
.046 .041 .527 r
.56125 .68884 m .56072 .6908 L .56092 .68998 L F
.56072 .6908 m .56076 .69058 L .56092 .68998 L F
.434 .321 .626 r
.56028 .69238 m .56264 .69385 L .56336 .69201 L F
.56028 .69238 m .5608 .69513 L .56264 .69385 L F
.267 .007 .321 r
.38273 .70757 m .38157 .7059 L .38342 .70534 L F
.38273 .70757 m .38105 .70848 L .38157 .7059 L F
.712 .483 .576 r
.61997 .64547 m .62322 .64334 L .62096 .64326 L F
.912 .89 .796 r
.63381 .66257 m .63461 .65907 L .63253 .6618 L F
.966 .779 .6 r
.63231 .66399 m .63381 .66257 L .63253 .6618 L F
.63231 .66399 m .63353 .66495 L .63381 .66257 L F
.533 .405 .651 r
.29304 .70335 m .29508 .70297 L .29479 .70033 L F
.643 .415 .558 r
.43458 .75708 m .43151 .75505 L .43491 .75506 L F
.539 .397 .636 r
.43692 .7523 m .43703 .75469 L .43491 .75506 L F
.577 .272 .416 r
.43682 .75681 m .43491 .75506 L .43703 .75469 L F
.43682 .75681 m .43458 .75708 L .43491 .75506 L F
.899 .674 .59 r
.61427 .67038 m .61581 .67338 L .61405 .6726 L F
.945 .814 .683 r
.61581 .67338 m .61373 .67535 L .61405 .6726 L F
.61581 .67338 m .61497 .67612 L .61373 .67535 L F
.653 .521 .691 r
.39866 .78499 m .40175 .78527 L .40142 .78226 L F
.642 .762 .936 r
.71715 .73581 m .72047 .73637 L .71946 .7355 L F
.751 .873 .935 r
.71946 .7355 m .72047 .73637 L .72276 .73519 L F
.676 .363 .437 r
.56264 .69385 m .56538 .69183 L .56336 .69201 L F
.536 .052 .054 r
.46668 .78214 m .46742 .78375 L .46541 .78349 L F
.46668 .78214 m .4688 .78245 L .46742 .78375 L F
.513 .542 .823 r
.71977 .72367 m .72013 .72571 L .71801 .72567 L F
.476 .442 .741 r
.61042 .74336 m .60818 .74436 L .6077 .74151 L F
.354 .233 .574 r
.61042 .74336 m .60856 .74627 L .60818 .74436 L F
.921 .67 .542 r
.55182 .69009 m .55019 .69203 L .55038 .68988 L F
.318 0 0 r
.34033 .72919 m .33718 .72992 L .33848 .72958 L F
.842 .506 0 r
.63364 .66952 m .63275 .66742 L .63289 .66936 L F
.934 .826 .714 r
.63103 .67239 m .63364 .66952 L .63289 .66936 L F
.184 0 .263 r
.28141 .6243 m .27922 .62705 L .28078 .62629 L F
.23 .004 .351 r
.28078 .62629 m .27922 .62705 L .2787 .62917 L F
.497 .123 .261 r
.35228 .67544 m .35098 .67776 L .34873 .67789 L F
.154 0 .073 r
.35273 .67695 m .35228 .67544 L .3543 .67511 L F
.35273 .67695 m .35098 .67776 L .35228 .67544 L F
.853 .708 .701 r
.71504 .61655 m .71442 .61879 L .71329 .61551 L F
.052 0 0 r
.3647 .71828 m .36435 .71747 L .36625 .71666 L F
.3647 .71828 m .36286 .71902 L .36435 .71747 L F
.411 .218 .506 r
.3977 .68961 m .39757 .69208 L .3956 .69234 L F
.365 .087 .352 r
.39692 .69394 m .3956 .69234 L .39757 .69208 L F
.39692 .69394 m .39502 .69463 L .3956 .69234 L F
.924 .967 .67 r
.66625 .59845 m .66764 .5975 L .66631 .59947 L F
.482 .851 .613 r
.66909 .59632 m .66764 .5975 L .66625 .59845 L F
0 0 0 r
.66919 .59413 m .66764 .5975 L .66909 .59632 L F
.662 .468 .612 r
.60766 .65129 m .61048 .65104 L .61064 .64786 L F
.218 .345 .779 r
.61314 .65102 m .61064 .64786 L .61048 .65104 L F
.61314 .65102 m .6122 .64817 L .61064 .64786 L F
0 0 .267 r
.61115 .69249 m .61216 .6911 L .61223 .68903 L F
.614 .872 .532 r
.61144 .69189 m .61115 .69249 L .61145 .69478 L F
.61144 .69189 m .61216 .6911 L .61115 .69249 L F
.753 .749 .849 r
.32576 .73488 m .32594 .73496 L .32366 .73291 L F
.478 .766 .994 r
.51141 .79466 m .51429 .79525 L .51382 .79467 L F
.091 0 0 r
.51749 .7939 m .51382 .79467 L .51429 .79525 L F
.048 0 0 r
.36184 .70629 m .36222 .70684 L .36365 .70546 L F
.36184 .70629 m .36008 .70739 L .36222 .70684 L F
.671 .779 .93 r
.30558 .73178 m .30544 .73353 L .3041 .73215 L F
.3041 .73215 m .30544 .73353 L .30558 .73178 L F
.349 .679 .978 r
.51883 .70574 m .51792 .70673 L .51674 .70551 L F
.51883 .70574 m .52094 .70713 L .51792 .70673 L F
.741 .53 .608 r
.57592 .71392 m .57444 .71104 L .57588 .71134 L F
.591 .371 .55 r
.57803 .71298 m .57588 .71134 L .57826 .71118 L F
.57803 .71298 m .57592 .71392 L .57588 .71134 L F
.561 .344 .543 r
.59619 .71416 m .59848 .71379 L .5986 .71153 L F
.44 .245 .518 r
.5986 .71153 m .59848 .71379 L .60063 .71096 L F
.653 .416 .548 r
.61396 .64785 m .61768 .6455 L .61559 .64629 L F
.447 .564 .88 r
.39473 .81726 m .39654 .81733 L .39475 .81708 L F
.39475 .81708 m .39654 .81733 L .39473 .81726 L F
.026 .594 .775 r
.39309 .81706 m .39654 .81733 L .39473 .81726 L F
.39309 .81706 m .39654 .81733 L .39473 .81726 L F
.337 .003 .241 r
.3466 .67831 m .34394 .68022 L .34456 .67865 L F
.153 .44 .875 r
.39289 .80617 m .39243 .80747 L .3935 .8076 L F
.781 .567 .61 r
.60408 .66241 m .60292 .66434 L .60262 .66243 L F
.60408 .66241 m .60601 .66472 L .60292 .66434 L F
.54 .262 .443 r
.6913 .57923 m .6938 .57754 L .69146 .57785 L F
0 .153 .693 r
.55553 .69663 m .55599 .69824 L .55438 .69493 L F
.623 .718 .914 r
.55785 .69725 m .55599 .69824 L .55553 .69663 L F
.55785 .69725 m .55599 .69824 L .55553 .69663 L F
.886 .694 .637 r
.57229 .68999 m .57156 .69207 L .57038 .68918 L F
.254 .219 .624 r
.27694 .62989 m .2787 .62917 L .27692 .62975 L F
.785 .512 .524 r
.45055 .74937 m .44712 .74699 L .45061 .74832 L F
.45055 .74937 m .44705 .74916 L .44712 .74699 L F
.751 .608 .699 r
.30004 .72696 m .29775 .72512 L .30108 .72555 L F
.30004 .72696 m .29757 .72747 L .29775 .72512 L F
.335 .34 .716 r
.53567 .74129 m .53629 .74345 L .53411 .74147 L F
.53567 .74129 m .53629 .74345 L .53411 .74147 L F
.254 .219 .624 r
.27694 .62989 m .2785 .63143 L .2787 .62917 L F
.27694 .62989 m .27805 .63179 L .2785 .63143 L F
.441 .294 .585 r
.27695 .63215 m .27805 .63179 L .27694 .62989 L F
0 0 0 r
.73484 .72505 m .73408 .72679 L .73246 .72757 L F
0 0 .433 r
.73408 .72679 m .73347 .72984 L .73246 .72757 L F
.147 .252 .716 r
.57273 .74662 m .57366 .74701 L .5728 .74366 L F
.021 .307 .798 r
.57273 .74662 m .57498 .74838 L .57366 .74701 L F
.628 .472 .651 r
.32803 .69512 m .32815 .69745 L .32587 .69789 L F
.587 .489 .71 r
.32847 .69964 m .32587 .69789 L .32815 .69745 L F
.32847 .69964 m .32622 .7001 L .32587 .69789 L F
.811 .777 .821 r
.68421 .61274 m .68789 .61169 L .68662 .61027 L F
.741 .799 .899 r
.68662 .61027 m .68789 .61169 L .68979 .61044 L F
.043 0 0 r
.49653 .71366 m .49832 .71339 L .49946 .7121 L F
.125 0 .101 r
.49653 .71366 m .49744 .71479 L .49832 .71339 L F
.49653 .71366 m .49567 .71589 L .49744 .71479 L F
.669 .814 .953 r
.70705 .57733 m .70596 .5794 L .70478 .57876 L F
.70705 .57733 m .70825 .57878 L .70596 .5794 L F
0 0 .245 r
.57131 .74144 m .57192 .73794 L .56993 .73823 L F
.57131 .74144 m .57193 .74036 L .57192 .73794 L F
0 .063 .609 r
.57131 .74144 m .5728 .74366 L .57193 .74036 L F
.5 .013 .032 r
.46778 .72667 m .47008 .72688 L .46805 .72603 L F
.578 .827 .992 r
.41432 .79127 m .41483 .78962 L .41269 .79018 L F
.41432 .79127 m .41659 .79078 L .41483 .78962 L F
0 .145 .647 r
.57585 .72171 m .57687 .72255 L .57785 .72366 L F
.57687 .72255 m .5782 .72365 L .57785 .72366 L F
.821 .6 .604 r
.57785 .72366 m .58056 .72214 L .57891 .72486 L F
.57785 .72366 m .57891 .72486 L .57872 .72516 L F
.363 .192 .511 r
.58039 .72666 m .57879 .7274 L .57872 .72516 L F
0 .126 .675 r
.5267 .71135 m .5284 .71319 L .52837 .71407 L F
.56 .256 .41 r
.43544 .7348 m .43802 .73309 L .43578 .73331 L F
.565 .415 .636 r
.4069 .74415 m .40932 .74627 L .40908 .74378 L F
.4069 .74415 m .40713 .74682 L .40932 .74627 L F
.447 .503 .824 r
.542 .73562 m .545 .73663 L .54281 .73543 L F
.513 .453 .727 r
.542 .73562 m .54416 .73822 L .545 .73663 L F
.256 0 .282 r
.62455 .69142 m .62268 .69238 L .6251 .68978 L F
.02 0 .159 r
.62455 .69142 m .62228 .69456 L .62268 .69238 L F
.37 0 0 r
.34285 .65092 m .34506 .65082 L .34657 .64947 L F
.172 0 0 r
.34657 .64947 m .34712 .65029 L .34862 .64888 L F
.34657 .64947 m .34506 .65082 L .34712 .65029 L F
.404 .134 .386 r
.41408 .6737 m .41375 .67554 L .41179 .67616 L F
.408 .122 .363 r
.41639 .67318 m .41375 .67554 L .41408 .6737 L F
.412 0 0 r
.72987 .58298 m .72631 .5831 L .72874 .58221 L F
0 .443 .847 r
.73056 .5828 m .72987 .58298 L .72874 .58221 L F
.73056 .5828 m .73152 .58365 L .72987 .58298 L F
.5 .298 .537 r
.44141 .74917 m .43922 .75198 L .43935 .74964 L F
.44141 .74917 m .43922 .75198 L .43935 .74964 L F
.589 .524 .75 r
.60605 .73595 m .60429 .73692 L .60316 .73325 L F
.103 0 .224 r
.28277 .62361 m .28141 .6243 L .28078 .62629 L F
0 0 0 r
.54121 .7876 m .54 .78854 L .53789 .78935 L F
.02 0 0 r
.54296 .78652 m .54282 .78726 L .54121 .7876 L F
0 0 0 r
.54121 .7876 m .54282 .78726 L .54 .78854 L F
.597 .276 .396 r
.59875 .65087 m .60101 .65127 L .60205 .64867 L F
.728 .416 .451 r
.60101 .65127 m .6043 .65102 L .60205 .64867 L F
.705 .421 .491 r
.60205 .64867 m .6043 .65102 L .60421 .649 L F
.158 .047 .467 r
.59455 .73603 m .59638 .73503 L .59641 .73256 L F
.584 .546 .778 r
.59537 .73881 m .59638 .73503 L .59455 .73603 L F
.567 .263 .413 r
.48676 .73308 m .48825 .73527 L .48613 .73535 L F
.48676 .73308 m .48934 .7328 L .48825 .73527 L F
.646 .424 .568 r
.42944 .75501 m .42946 .75765 L .42584 .75711 L F
.672 .446 .569 r
.43147 .75746 m .42946 .75765 L .42944 .75501 L F
.681 .446 .56 r
.43151 .75505 m .43147 .75746 L .42944 .75501 L F
.627 .774 .951 r
.4306 .76538 m .43201 .76602 L .42851 .7658 L F
.667 .536 .695 r
.43169 .76842 m .42851 .7658 L .43201 .76602 L F
.772 .644 .72 r
.49587 .72476 m .49927 .7251 L .49812 .7242 L F
.49587 .72476 m .49698 .72804 L .49927 .7251 L F
.574 .669 .903 r
.49948 .72636 m .50226 .726 L .49927 .7251 L F
.712 .483 .576 r
.61997 .64547 m .62325 .6456 L .62322 .64334 L F
.419 .267 .566 r
.60014 .70648 m .6019 .70731 L .60262 .70503 L F
.60014 .70648 m .5999 .70871 L .6019 .70731 L F
.557 .438 .672 r
.32889 .7034 m .32622 .7001 L .32847 .69964 L F
.32889 .7034 m .32705 .7045 L .32622 .7001 L F
.666 .422 .542 r
.49815 .73492 m .49501 .73327 L .49825 .73322 L F
.49815 .73492 m .49502 .7358 L .49501 .73327 L F
.644 .259 .301 r
.45055 .74937 m .4471 .75108 L .44705 .74916 L F
.45055 .74937 m .44933 .75167 L .4471 .75108 L F
.656 .594 .774 r
.45282 .74875 m .45055 .74937 L .45061 .74832 L F
.288 0 .118 r
.45135 .75105 m .45055 .74937 L .45225 .7507 L F
.45135 .75105 m .44933 .75167 L .45055 .74937 L F
.464 .113 .285 r
.45282 .74875 m .45225 .7507 L .45055 .74937 L F
.776 .789 .863 r
.71222 .6091 m .71584 .60872 L .71438 .60752 L F
.396 .423 .771 r
.40405 .78481 m .40518 .78793 L .40665 .7868 L F
.394 .42 .769 r
.40518 .78793 m .4075 .78988 L .40665 .7868 L F
.759 .464 .486 r
.60421 .649 m .6043 .65102 L .60766 .65129 L F
.653 .106 0 r
.61456 .68174 m .61525 .68306 L .61357 .68092 L F
.456 .418 .728 r
.61529 .6838 m .61714 .68349 L .61456 .68174 L F
.653 .106 0 r
.61456 .68174 m .61714 .68349 L .61525 .68306 L F
.106 0 .271 r
.62698 .6868 m .62698 .68886 L .6251 .68978 L F
.229 .015 .367 r
.62698 .68886 m .62455 .69142 L .6251 .68978 L F
.454 .699 .972 r
.29939 .59922 m .29878 .60079 L .29736 .5995 L F
.29939 .59922 m .30126 .60084 L .29878 .60079 L F
.59 .443 .65 r
.39968 .76307 m .40212 .7656 L .40175 .76263 L F
.39968 .76307 m .3999 .76606 L .40212 .7656 L F
.006 .552 .833 r
.37959 .65106 m .38314 .65196 L .38098 .65188 L F
.973 .713 .478 r
.4772 .74148 m .47603 .74228 L .47396 .74067 L F
.4772 .74148 m .47711 .74374 L .47603 .74228 L F
.599 .44 .637 r
.47945 .73858 m .47971 .74156 L .4772 .74148 L F
.376 .196 .506 r
.47916 .74304 m .4772 .74148 L .47971 .74156 L F
.47916 .74304 m .47711 .74374 L .4772 .74148 L F
.632 .542 .735 r
.33002 .6948 m .32815 .69745 L .32803 .69512 L F
.551 .454 .697 r
.30465 .68113 m .30626 .67821 L .30473 .67869 L F
.964 .647 .254 r
.47455 .77268 m .47564 .77412 L .47517 .77185 L F
.685 .199 0 r
.50441 .78929 m .50394 .78908 L .50293 .78819 L F
.50441 .78929 m .50486 .78992 L .50394 .78908 L F
.279 0 .268 r
.28169 .65193 m .28227 .65298 L .28072 .65342 L F
.28169 .65193 m .28356 .65089 L .28227 .65298 L F
.28169 .65193 m .28235 .65142 L .28356 .65089 L F
.767 .679 .766 r
.43922 .75198 m .44053 .75512 L .43703 .75469 L F
.71 .291 .25 r
.44053 .75512 m .43903 .75665 L .43703 .75469 L F
.008 0 .4 r
.44161 .75201 m .44053 .75512 L .43922 .75198 L F
.44161 .75201 m .44169 .75434 L .44053 .75512 L F
0 0 0 r
.44169 .75434 m .43903 .75665 L .44053 .75512 L F
.386 0 .179 r
.42448 .73812 m .42782 .73569 L .4247 .73623 L F
.42448 .73812 m .42661 .73773 L .42782 .73569 L F
.005 0 0 r
.42782 .73569 m .42839 .73666 L .43015 .73577 L F
.42782 .73569 m .42661 .73773 L .42839 .73666 L F
.38 0 0 r
.69853 .59034 m .69969 .5898 L .70222 .59038 L F
0 0 0 r
.55769 .68129 m .55908 .68058 L .55985 .67851 L F
.55769 .68129 m .55636 .68266 L .55908 .68058 L F
.213 0 .355 r
.67141 .59229 m .66919 .59413 L .66988 .59402 L F
.309 .114 .446 r
.66988 .59402 m .66919 .59413 L .66909 .59632 L F
.722 .798 .911 r
.51059 .72712 m .51409 .72746 L .51321 .72626 L F
.191 .343 .788 r
.51409 .72746 m .51641 .72983 L .51607 .72729 L F
.455 .117 .302 r
.51641 .72983 m .5193 .72755 L .51607 .72729 L F
.781 .694 .767 r
.5182 .7245 m .5193 .72755 L .52171 .72478 L F
.787 .697 .764 r
.51607 .72729 m .5193 .72755 L .5182 .7245 L F
.757 .65 .742 r
.5182 .7245 m .51927 .72583 L .51607 .72729 L F
.689 .174 .005 r
.51607 .72729 m .51351 .72637 L .51409 .72746 L F
.51351 .72637 m .51321 .72626 L .51326 .72633 L F
.51607 .72729 m .51437 .72723 L .51321 .72626 L F
.622 .224 .268 r
.51927 .72583 m .51437 .72723 L .51607 .72729 L F
.51598 .72677 m .51689 .72865 L .51437 .72723 L F
.51927 .72583 m .51817 .72713 L .51598 .72677 L F
.51817 .72713 m .51689 .72865 L .51598 .72677 L F
.689 .174 .005 r
.51351 .72637 m .51326 .72633 L .51409 .72746 L F
.076 .158 .648 r
.56856 .73053 m .56962 .72941 L .568 .72704 L F
.088 .177 .663 r
.56856 .73053 m .57022 .73264 L .56962 .72941 L F
.294 .241 .627 r
.56909 .73305 m .57022 .73264 L .56856 .73053 L F
.995 .812 .448 r
.63169 .67347 m .63082 .67472 L .63169 .67528 L F
.63169 .67347 m .63103 .67239 L .63082 .67472 L F
.998 .792 .443 r
.72875 .61211 m .72923 .61425 L .72962 .61252 L F
.711 .972 .929 r
.72875 .61211 m .72962 .61252 L .73249 .6106 L F
.768 .465 .473 r
.60601 .66472 m .60447 .66702 L .60292 .66434 L F
.716 .399 .439 r
.60601 .66472 m .60791 .66704 L .60447 .66702 L F
.739 .396 .401 r
.60782 .66541 m .60791 .66704 L .60601 .66472 L F
.299 .082 .408 r
.29754 .63239 m .2995 .62968 L .29892 .63174 L F
.265 .125 .497 r
.29874 .63404 m .29754 .63239 L .29892 .63174 L F
.29874 .63404 m .29744 .6347 L .29754 .63239 L F
.66 .715 .889 r
.30959 .74129 m .31062 .73833 L .30825 .73854 L F
.365 .033 .262 r
.59511 .65308 m .59626 .65336 L .59683 .65173 L F
.59511 .65308 m .59422 .65392 L .59626 .65336 L F
.047 0 0 r
.44845 .78579 m .44986 .78508 L .45199 .78471 L F
.627 .366 .502 r
.49825 .73322 m .50042 .73528 L .49815 .73492 L F
.657 .538 .707 r
.4997 .73101 m .50111 .73342 L .49825 .73322 L F
.645 .362 .476 r
.50111 .73342 m .50042 .73528 L .49825 .73322 L F
.581 .326 .495 r
.67828 .58537 m .6808 .58322 L .67829 .58342 L F
.515 .755 .983 r
.53612 .71814 m .53711 .7192 L .53491 .71948 L F
.574 .669 .903 r
.49948 .72636 m .50265 .72779 L .50226 .726 L F
.635 .711 .902 r
.50226 .726 m .50265 .72779 L .50515 .72654 L F
.572 .053 0 r
.50373 .78465 m .50614 .78602 L .50708 .78482 L F
.677 .191 .088 r
.50614 .78602 m .509 .78647 L .50708 .78482 L F
.952 .748 .59 r
.47564 .77412 m .47518 .77671 L .47648 .77645 L F
.486 0 0 r
.47735 .77769 m .47648 .77645 L .47518 .77671 L F
.47735 .77769 m .47879 .77689 L .47648 .77645 L F
.187 .684 .916 r
.73085 .71162 m .72908 .71203 L .72797 .71172 L F
.73085 .71162 m .73133 .71209 L .72908 .71203 L F
.059 0 0 r
.55985 .67851 m .56184 .67753 L .56234 .67658 L F
.304 0 .044 r
.56184 .67753 m .56464 .67598 L .56234 .67658 L F
0 .213 .737 r
.73612 .58773 m .73628 .58881 L .73464 .58614 L F
.071 .102 .586 r
.73804 .58955 m .73628 .58881 L .73612 .58773 L F
.73804 .58955 m .737 .59086 L .73628 .58881 L F
.621 .726 .921 r
.72276 .73519 m .72676 .73576 L .72569 .73455 L F
.236 .556 .933 r
.72676 .73576 m .72738 .73496 L .72569 .73455 L F
.007 .216 .727 r
.72676 .73576 m .72838 .73763 L .72738 .73496 L F
.542 .163 .272 r
.44364 .73068 m .44237 .73253 L .44543 .73202 L F
.5 .186 .366 r
.44364 .73068 m .44543 .73202 L .44582 .73039 L F
.463 .274 .538 r
.38075 .6894 m .38265 .68907 L .38284 .68678 L F
.437 .29 .583 r
.38075 .6894 m .38262 .69143 L .38265 .68907 L F
.38075 .6894 m .38087 .69203 L .38262 .69143 L F
.352 .102 .389 r
.31536 .66742 m .3138 .66801 L .31319 .6701 L F
.582 .172 .23 r
.509 .78647 m .51126 .78656 L .51292 .78465 L F
.696 .311 .315 r
.51292 .78465 m .51394 .78649 L .51471 .78565 L F
.51292 .78465 m .51126 .78656 L .51394 .78649 L F
.753 .68 .78 r
.39206 .78641 m .39062 .78712 L .39287 .78492 L F
.012 0 0 r
.51776 .78428 m .51672 .78478 L .51983 .78385 L F
.279 0 .229 r
.31112 .67297 m .30929 .67372 L .30848 .67538 L F
.372 .172 .475 r
.31143 .67058 m .31279 .67223 L .31319 .6701 L F
.31143 .67058 m .31112 .67297 L .31279 .67223 L F
.734 .674 .791 r
.72224 .61805 m .72312 .62082 L .72561 .61858 L F
.489 0 0 r
.56659 .70516 m .56712 .70556 L .56591 .70411 L F
.571 .431 .652 r
.30117 .73869 m .30294 .73926 L .30228 .73715 L F
.496 0 0 r
.47783 .78198 m .47628 .78228 L .47436 .7818 L F
.52 0 0 r
.47783 .78198 m .4787 .78335 L .47628 .78228 L F
.47783 .78198 m .47975 .78252 L .4787 .78335 L F
.956 .687 .24 r
.68473 .58965 m .6847 .58871 L .68398 .58771 L F
.76 .703 .798 r
.70334 .59408 m .70434 .59709 L .70081 .59666 L F
.811 .729 .774 r
.70627 .59423 m .70434 .59709 L .70334 .59408 L F
.551 .432 .671 r
.40166 .76034 m .40344 .75748 L .40132 .75786 L F
.613 .206 .248 r
.60262 .66243 m .6015 .66403 L .59885 .66247 L F
.93 .637 .466 r
.60292 .66434 m .6015 .66403 L .60262 .66243 L F
.643 .415 .558 r
.43458 .75708 m .43147 .75746 L .43151 .75505 L F
0 .051 .558 r
.39846 .80334 m .39967 .80459 L .3989 .80387 L F
.39846 .80334 m .39967 .80459 L .3989 .80387 L F
.5 .096 .207 r
.72067 .58302 m .72299 .5831 L .72416 .58191 L F
.202 .723 .866 r
.72299 .5831 m .72631 .5831 L .72416 .58191 L F
.091 0 0 r
.51749 .7939 m .51498 .79463 L .51382 .79467 L F
.238 .745 .704 r
.51689 .794 m .51749 .7939 L .51908 .79266 L F
.51689 .794 m .51498 .79463 L .51749 .7939 L F
.542 .086 .119 r
.47008 .72688 m .47249 .72704 L .47389 .72575 L F
.306 0 0 r
.47389 .72575 m .47547 .72613 L .47589 .72543 L F
.47389 .72575 m .47249 .72704 L .47547 .72613 L F
0 0 .2 r
.73675 .72133 m .73628 .72401 L .73484 .72505 L F
0 0 0 r
.73628 .72401 m .73408 .72679 L .73484 .72505 L F
0 .09 .648 r
.57538 .7498 m .57574 .74909 L .57498 .74838 L F
0 .121 .663 r
.57538 .7498 m .57709 .75079 L .57574 .74909 L F
.57538 .7498 m .5772 .75214 L .57709 .75079 L F
.346 .441 .815 r
.5625 .71946 m .56376 .72249 L .56531 .72129 L F
.345 .439 .814 r
.56376 .72249 m .56647 .72422 L .56531 .72129 L F
.491 .373 .645 r
.33345 .68855 m .33215 .68742 L .33433 .68653 L F
.33345 .68855 m .33211 .68951 L .33215 .68742 L F
0 .441 .749 r
.51356 .70448 m .51674 .70551 L .51518 .70511 L F
0 0 .187 r
.29536 .71907 m .29648 .71687 L .2959 .71853 L F
.29536 .71907 m .297 .71605 L .29648 .71687 L F
.56 .832 .483 r
.49946 .7121 m .49927 .71224 L .50125 .71104 L F
.49946 .7121 m .49832 .71339 L .49927 .71224 L F
0 0 0 r
.31164 .72755 m .3082 .72824 L .30954 .72768 L F
.417 0 .045 r
.4534 .72977 m .45555 .7297 L .45718 .72799 L F
.478 .021 .088 r
.45718 .72799 m .45555 .7297 L .45885 .72907 L F
.45 .049 .186 r
.45718 .72799 m .45885 .72907 L .46006 .7271 L F
.038 0 0 r
.36233 .67325 m .35848 .67411 L .36022 .67285 L F
.936 .563 .193 r
.51501 .73549 m .51417 .73519 L .51444 .7334 L F
.228 .091 .477 r
.51444 .7334 m .51635 .73247 L .51641 .72983 L F
.003 .013 .515 r
.51444 .7334 m .51589 .73474 L .51635 .73247 L F
.51444 .7334 m .51501 .73549 L .51589 .73474 L F
.305 .665 .973 r
.29188 .59891 m .29004 .59879 L .28872 .59772 L F
0 .029 .596 r
.57392 .71924 m .57585 .72171 L .5755 .72196 L F
0 .233 .728 r
.57585 .72171 m .57785 .72366 L .5755 .72196 L F
.751 .873 .935 r
.71946 .7355 m .72276 .73519 L .72125 .73354 L F
.584 .757 .96 r
.72276 .73519 m .72404 .73313 L .72125 .73354 L F
.72276 .73519 m .72569 .73455 L .72404 .73313 L F
.732 .615 .728 r
.65409 .60197 m .65758 .60285 L .65611 .59948 L F
.845 .687 .686 r
.72075 .61043 m .71959 .61337 L .71795 .61008 L F
.47 .284 .547 r
.70068 .5833 m .69794 .58594 L .69863 .585 L F
.144 .106 .553 r
.73347 .72984 m .73469 .73193 L .73307 .73295 L F
.006 0 .285 r
.73469 .73193 m .73323 .73519 L .73307 .73295 L F
.41 0 .115 r
.45171 .77335 m .45529 .77127 L .45337 .77202 L F
.985 .706 .368 r
.71329 .61551 m .71442 .61879 L .71342 .61791 L F
.478 .64 .927 r
.71442 .61879 m .71573 .61729 L .71342 .61791 L F
.71442 .61879 m .71726 .61905 L .71573 .61729 L F
.396 .181 .466 r
.61529 .6838 m .61501 .68631 L .61714 .68349 L F
.214 0 0 r
.35968 .64871 m .36186 .64839 L .36314 .64755 L F
0 0 0 r
.36314 .64755 m .36517 .64683 L .36528 .64588 L F
.229 .144 .548 r
.70283 .72199 m .70447 .72407 L .70516 .7216 L F
.70283 .72199 m .70283 .72492 L .70447 .72407 L F
.196 .724 .748 r
.56025 .7467 m .55688 .74736 L .55792 .74721 L F
.924 .534 .181 r
.60704 .70622 m .60572 .70431 L .60449 .70452 L F
0 0 0 r
.60336 .70471 m .60449 .70452 L .60544 .70381 L F
.49 .251 .479 r
.60763 .70326 m .60731 .7051 L .60544 .70381 L F
.60544 .70381 m .60731 .7051 L .60763 .70326 L F
.60763 .70326 m .60544 .70381 L .60449 .70452 L F
.525 .34 .572 r
.60544 .70381 m .60763 .70326 L .60788 .70058 L F
.49 .251 .479 r
.60763 .70326 m .60449 .70452 L .60601 .70187 L F
.75 .895 .499 r
.60449 .70452 m .60494 .70319 L .60601 .70187 L F
.924 .534 .181 r
.60572 .70431 m .60494 .70319 L .60449 .70452 L F
0 0 0 r
.60262 .70503 m .60449 .70452 L .60336 .70471 L F
.582 .417 .623 r
.59619 .71416 m .59629 .71658 L .59848 .71379 L F
.883 .805 .768 r
.3982 .7796 m .40023 .77967 L .39978 .77685 L F
.573 .524 .762 r
.399 .77433 m .39978 .77685 L .40185 .77632 L F
.534 .453 .71 r
.39978 .77685 m .40218 .77923 L .40185 .77632 L F
.39978 .77685 m .40023 .77967 L .40218 .77923 L F
.516 0 0 r
.4993 .78362 m .49787 .78222 L .4966 .78231 L F
.381 0 0 r
.4997 .78409 m .4993 .78362 L .49747 .78326 L F
.516 0 0 r
.4993 .78362 m .50088 .78498 L .49903 .78328 L F
.27 .719 .959 r
.50074 .78436 m .50088 .78498 L .4993 .78362 L F
.381 0 0 r
.50044 .78437 m .4993 .78362 L .4997 .78409 L F
.516 0 0 r
.4993 .78362 m .49903 .78328 L .49787 .78222 L F
.34 .151 .472 r
.4626 .7436 m .46083 .74652 L .46101 .74415 L F
.361 0 .192 r
.37309 .69947 m .3761 .6975 L .37396 .69789 L F
.532 .331 .554 r
.60796 .71691 m .60784 .71812 L .60569 .71887 L F
.595 .457 .663 r
.60784 .71812 m .60611 .72186 L .60569 .71887 L F
.627 .395 .547 r
.63224 .6593 m .63442 .65673 L .63128 .65628 L F
.63224 .6593 m .63461 .65907 L .63442 .65673 L F
.157 0 .11 r
.55985 .67851 m .56091 .67949 L .56184 .67753 L F
.55985 .67851 m .55908 .68058 L .56091 .67949 L F
.679 .235 .189 r
.44058 .77448 m .44426 .77476 L .44185 .77471 L F
.166 0 .386 r
.62916 .68396 m .62884 .68608 L .62698 .6868 L F
0 0 .193 r
.62768 .68783 m .62698 .6868 L .62884 .68608 L F
.62768 .68783 m .62698 .68886 L .62698 .6868 L F
.376 .154 .444 r
.48126 .73834 m .47945 .73858 L .48155 .73589 L F
.427 .372 .694 r
.48126 .73834 m .48162 .74087 L .47945 .73858 L F
.529 .388 .633 r
.47945 .73858 m .48162 .74087 L .47971 .74156 L F
.721 .661 .79 r
.5186 .73829 m .51821 .7404 L .52176 .73851 L F
.153 .672 .887 r
.35264 .64804 m .35486 .64816 L .356 .64847 L F
.524 0 0 r
.35486 .64816 m .35499 .6482 L .356 .64847 L F
.33 .788 .946 r
.35404 .64872 m .356 .64847 L .35718 .64879 L F
.524 0 0 r
.35499 .6482 m .35805 .64909 L .356 .64847 L F
.33 .788 .946 r
.35718 .64879 m .356 .64847 L .35754 .6488 L F
.393 0 0 r
.356 .64847 m .35968 .64871 L .35754 .6488 L F
.589 .204 .282 r
.45885 .72907 m .46234 .72732 L .46006 .7271 L F
.726 .618 .737 r
.60452 .7271 m .60215 .7277 L .60404 .72531 L F
.744 .571 .66 r
.60452 .7271 m .60207 .73016 L .60215 .7277 L F
.60452 .7271 m .60471 .73106 L .60207 .73016 L F
.653 .663 .848 r
.60634 .72503 m .60452 .7271 L .60404 .72531 L F
.60634 .72503 m .6076 .72773 L .60452 .7271 L F
.468 .357 .644 r
.60735 .72966 m .60452 .7271 L .6076 .72773 L F
.60735 .72966 m .60471 .73106 L .60452 .7271 L F
.389 .736 .991 r
.30958 .60447 m .3111 .60549 L .3077 .60464 L F
.476 .757 .992 r
.31157 .60413 m .3111 .60549 L .30958 .60447 L F
.31157 .60413 m .31328 .60517 L .3111 .60549 L F
.366 .727 .989 r
.27552 .59642 m .27524 .59742 L .27378 .59632 L F
.27552 .59642 m .27719 .59741 L .27524 .59742 L F
.776 .541 .58 r
.51815 .73643 m .515 .73798 L .51501 .73549 L F
.51815 .73643 m .5186 .73829 L .515 .73798 L F
.1 0 0 r
.36394 .64803 m .36634 .64772 L .36715 .64725 L F
.409 .822 .63 r
.36715 .64725 m .36634 .64772 L .36686 .64738 L F
.36715 .64725 m .36686 .64738 L .36801 .64665 L F
.543 0 0 r
.36737 .64716 m .36715 .64725 L .36879 .64803 L F
.36528 .64588 m .36715 .64725 L .36737 .64716 L F
.423 .544 .874 r
.36912 .64573 m .36879 .64803 L .36715 .64725 L F
.36912 .64573 m .37068 .64824 L .36879 .64803 L F
.883 .805 .768 r
.3982 .7796 m .39929 .78035 L .40023 .77967 L F
.511 .146 .283 r
.39929 .78035 m .39942 .78159 L .40023 .77967 L F
.516 .384 .64 r
.40023 .77967 m .40236 .78197 L .40218 .77923 L F
.225 .316 .748 r
.40023 .77967 m .40142 .78226 L .40236 .78197 L F
.996 .834 .566 r
.57786 .6831 m .57902 .68171 L .57788 .68079 L F
.57786 .6831 m .57855 .68404 L .57902 .68171 L F
.6 .776 .964 r
.35404 .64872 m .35201 .64929 L .35057 .64805 L F
.427 .479 .811 r
.60953 .74006 m .6077 .74151 L .60661 .73846 L F
.408 .444 .786 r
.60953 .74006 m .61042 .74336 L .6077 .74151 L F
.551 .416 .65 r
.30049 .68675 m .30254 .68643 L .3023 .68398 L F
.503 .334 .584 r
.30049 .68675 m .30236 .68869 L .30254 .68643 L F
.30049 .68675 m .30034 .68951 L .30236 .68869 L F
.641 .585 .776 r
.4306 .76538 m .42851 .7658 L .42729 .76227 L F
.667 .536 .695 r
.43169 .76842 m .42939 .76884 L .42851 .7658 L F
.545 .083 .106 r
.48981 .77847 m .48756 .77749 L .48641 .77883 L F
.743 .669 .779 r
.66973 .60825 m .6723 .60756 L .67215 .6059 L F
.401 .533 .875 r
.66973 .60825 m .67293 .61111 L .6723 .60756 L F
.528 .412 .664 r
.6723 .60756 m .67408 .60471 L .67215 .6059 L F
.6723 .60756 m .6747 .60726 L .67408 .60471 L F
.612 .54 .75 r
.67293 .61111 m .6747 .60726 L .6723 .60756 L F
.633 .595 .793 r
.60569 .73283 m .60316 .73325 L .60207 .73016 L F
.589 .524 .75 r
.60605 .73595 m .60316 .73325 L .60569 .73283 L F
.153 .357 .812 r
.60634 .72503 m .60847 .72662 L .6076 .72773 L F
.091 0 .194 r
.60863 .72896 m .6076 .72773 L .60847 .72662 L F
.60863 .72896 m .60735 .72966 L .6076 .72773 L F
0 0 0 r
.59885 .66247 m .59781 .66371 L .59644 .66444 L F
.29 .752 .949 r
.6015 .66403 m .59781 .66371 L .59885 .66247 L F
.568 .42 .641 r
.40282 .75456 m .4049 .75167 L .40277 .7521 L F
.37 .007 .212 r
.73928 .71957 m .739 .72156 L .73675 .72133 L F
.312 .53 .904 r
.73851 .71796 m .73928 .71957 L .73993 .71881 L F
.96 .672 .241 r
.73851 .71796 m .739 .72156 L .73928 .71957 L F
.535 .924 .875 r
.42213 .78883 m .41869 .79002 L .41832 .78967 L F
.788 .626 .68 r
.6267 .64818 m .63027 .64626 L .62665 .64578 L F
.6267 .64818 m .63 .64859 L .63027 .64626 L F
.781 .308 .113 r
.5013 .78606 m .50015 .78654 L .50088 .78498 L F
.5013 .78606 m .50293 .78819 L .50015 .78654 L F
.499 .78 .995 r
.69754 .5964 m .69834 .59722 L .69518 .59672 L F
.589 .825 .989 r
.69754 .5964 m .70081 .59666 L .69834 .59722 L F
.63 .746 .931 r
.69723 .60733 m .6985 .60464 L .6964 .6051 L F
.69723 .60733 m .70138 .6072 L .6985 .60464 L F
.715 .567 .686 r
.40142 .78226 m .40405 .78481 L .40236 .78197 L F
.40142 .78226 m .40175 .78527 L .40405 .78481 L F
.755 .651 .746 r
.54526 .74135 m .54194 .74134 L .54416 .73822 L F
.559 .067 .043 r
.54526 .74135 m .54438 .74275 L .54194 .74134 L F
.569 .667 .904 r
.5459 .73824 m .54526 .74135 L .54416 .73822 L F
.5459 .73824 m .54759 .74116 L .54526 .74135 L F
.449 0 .054 r
.54759 .74116 m .54438 .74275 L .54526 .74135 L F
.401 0 0 r
.47879 .77689 m .48094 .777 L .48217 .77629 L F
.627 .15 .103 r
.48094 .777 m .48417 .77724 L .48217 .77629 L F
.69 .733 .884 r
.32752 .82542 m .33095 .826 L .3295 .82528 L F
.959 .718 .53 r
.3295 .82528 m .33095 .826 L .32965 .82284 L F
.317 .013 .281 r
.60425 .75204 m .60375 .7544 L .60181 .75518 L F
.498 .316 .565 r
.60627 .74938 m .60625 .7515 L .60425 .75204 L F
.259 0 .262 r
.60551 .75339 m .60425 .75204 L .60625 .7515 L F
.60551 .75339 m .60375 .7544 L .60425 .75204 L F
.832 .607 .597 r
.51143 .72543 m .51059 .72712 L .50968 .72414 L F
.499 .22 .422 r
.51321 .72626 m .51059 .72712 L .51143 .72543 L F
.41 0 .115 r
.45171 .77335 m .45386 .77316 L .45529 .77127 L F
.742 .363 .335 r
.45386 .77316 m .45683 .77365 L .45529 .77127 L F
.502 .359 .62 r
.70111 .72758 m .70298 .7274 L .70283 .72492 L F
.515 .468 .742 r
.70111 .72758 m .70411 .72938 L .70298 .7274 L F
0 0 .147 r
.60788 .70058 m .60826 .6992 L .60807 .7003 L F
.454 .28 .554 r
.60788 .70058 m .60601 .70187 L .60826 .6992 L F
.60788 .70058 m .60763 .70326 L .60601 .70187 L F
.60788 .70058 m .60954 .70235 L .60763 .70326 L F
.584 .836 .471 r
.60788 .70058 m .60807 .7003 L .60999 .69792 L F
.454 .28 .554 r
.60763 .70326 m .60954 .70235 L .60788 .70058 L F
.656 .594 .774 r
.45282 .74875 m .45061 .74832 L .45285 .7479 L F
.632 .427 .586 r
.43682 .76587 m .43714 .76847 L .43388 .76846 L F
.444 .468 .79 r
.43599 .76327 m .43894 .76509 L .43682 .76587 L F
.623 .421 .587 r
.43939 .76804 m .43682 .76587 L .43894 .76509 L F
.43939 .76804 m .43714 .76847 L .43682 .76587 L F
.812 .415 .298 r
.58048 .75945 m .58348 .76042 L .58246 .76193 L F
.713 .286 .234 r
.58348 .76042 m .58573 .76242 L .58246 .76193 L F
.643 .336 .436 r
.58583 .76062 m .58573 .76242 L .58348 .76042 L F
.367 .073 .328 r
.56538 .69183 m .56724 .69156 L .568 .68955 L F
.766 .674 .761 r
.56683 .68643 m .568 .68955 L .5702 .68679 L F
0 0 0 r
.568 .68955 m .56724 .69156 L .56842 .69023 L F
.59781 .66371 m .59566 .66565 L .59644 .66444 L F
.418 .049 .228 r
.33243 .65519 m .33518 .65377 L .33312 .65423 L F
.371 .066 .311 r
.41179 .67616 m .41115 .67796 L .40919 .67849 L F
.432 .122 .338 r
.41324 .67749 m .41179 .67616 L .41375 .67554 L F
.41324 .67749 m .41115 .67796 L .41179 .67616 L F
.519 .368 .616 r
.29848 .69239 m .30034 .68951 L .29847 .69021 L F
.421 .135 .371 r
.37397 .71128 m .37418 .7137 L .37111 .71385 L F
.514 .2 .373 r
.37528 .71253 m .37397 .71128 L .37602 .71088 L F
.37528 .71253 m .37418 .7137 L .37397 .71128 L F
.26 .633 .962 r
.56475 .69976 m .56631 .70045 L .56585 .69934 L F
.54 .256 .432 r
.5712 .69373 m .56778 .69683 L .56934 .69738 L F
.822 .978 .889 r
.56763 .69834 m .5665 .70025 L .56934 .69738 L F
.56585 .69934 m .56934 .69738 L .56778 .69683 L F
.54 .256 .432 r
.5712 .69373 m .57006 .69847 L .56778 .69683 L F
.57006 .69847 m .57006 .69849 L .57004 .69847 L F
.57006 .69847 m .57004 .69847 L .56778 .69683 L F
.322 .307 .687 r
.5683 .69721 m .57004 .69847 L .56957 .69508 L F
.57004 .69847 m .57006 .69849 L .57006 .69847 L F
.57004 .69847 m .57006 .69847 L .56957 .69508 L F
.41 .77 .995 r
.57016 .69843 m .5707 .69844 L .57022 .69847 L F
.619 .394 .554 r
.57156 .69207 m .57341 .69383 L .5712 .69373 L F
0 0 .203 r
.57244 .69343 m .5712 .69373 L .57341 .69383 L F
.57244 .69343 m .57007 .69847 L .5712 .69373 L F
.57007 .69847 m .57006 .69849 L .57006 .69847 L F
.57007 .69847 m .57006 .69847 L .5712 .69373 L F
.41 .77 .995 r
.57015 .69842 m .57232 .69819 L .57028 .69851 L F
.784 .639 .7 r
.56928 .69312 m .57006 .69849 L .57244 .69343 L F
.41 .77 .995 r
.56912 .69774 m .57093 .69799 L .57015 .69842 L F
.57093 .69799 m .57232 .69819 L .57015 .69842 L F
.56912 .69774 m .57044 .69833 L .57016 .69843 L F
.57044 .69833 m .5707 .69844 L .57016 .69843 L F
.56912 .69774 m .57232 .69819 L .5707 .69844 L F
.57022 .69847 m .5707 .69844 L .57028 .69851 L F
.322 .307 .687 r
.56778 .69683 m .5683 .69721 L .56928 .69312 L F
.5683 .69721 m .56957 .69508 L .56928 .69312 L F
.822 .978 .889 r
.56585 .69934 m .56631 .70045 L .5665 .70025 L F
.56585 .69934 m .5665 .70025 L .56763 .69834 L F
.626 .653 .857 r
.33243 .70576 m .33041 .70648 L .32912 .7048 L F
.456 .641 .936 r
.39437 .65543 m .39331 .65696 L .39231 .65548 L F
.525 .735 .97 r
.39437 .65543 m .39522 .6566 L .39331 .65696 L F
.631 .492 .674 r
.42931 .75994 m .42584 .75711 L .42946 .75765 L F
.42931 .75994 m .42716 .76058 L .42584 .75711 L F
.987 .754 .365 r
.51399 .74133 m .51327 .74309 L .5141 .74107 L F
.873 .68 .638 r
.51225 .74025 m .5141 .74107 L .51327 .74309 L F
0 .126 .676 r
.51327 .74309 m .51383 .74279 L .51251 .74258 L F
.922 .695 .577 r
.51225 .74025 m .51327 .74309 L .51149 .74243 L F
0 .126 .676 r
.51327 .74309 m .51251 .74258 L .51149 .74243 L F
.987 .754 .365 r
.51399 .74133 m .51398 .74356 L .51327 .74309 L F
.51398 .74356 m .51398 .7437 L .51327 .74309 L F
0 0 0 r
.51617 .74094 m .51398 .7437 L .51399 .74133 L F
.604 .535 .75 r
.29388 .70862 m .29538 .70573 L .29452 .70588 L F
.29388 .70862 m .29613 .70855 L .29538 .70573 L F
.644 .479 .645 r
.29384 .71102 m .29613 .70855 L .29388 .70862 L F
.398 0 .121 r
.34874 .72518 m .34499 .72746 L .346 .72695 L F
.34874 .72518 m .34711 .72719 L .34499 .72746 L F
.292 0 .051 r
.34941 .72658 m .34874 .72518 L .35041 .72428 L F
.34941 .72658 m .34711 .72719 L .34874 .72518 L F
.428 .231 .51 r
.39937 .69141 m .3977 .68961 L .39976 .68924 L F
.39937 .69141 m .39757 .69208 L .3977 .68961 L F
0 0 .052 r
.61911 .70083 m .61806 .70254 L .61693 .70319 L F
.236 .099 .482 r
.61693 .70319 m .61806 .70254 L .61677 .70569 L F
.676 .363 .437 r
.56264 .69385 m .56491 .69454 L .56538 .69183 L F
.524 .225 .402 r
.56538 .69183 m .56733 .69363 L .56724 .69156 L F
.56538 .69183 m .56491 .69454 L .56733 .69363 L F
.638 .936 .965 r
.37935 .66848 m .38007 .66933 L .38231 .66933 L F
.37935 .66848 m .37757 .66943 L .38007 .66933 L F
.261 .353 .769 r
.55915 .73521 m .56049 .73845 L .55944 .73874 L F
.465 .44 .746 r
.50189 .7294 m .4997 .73101 L .49828 .72644 L F
.479 .467 .766 r
.50189 .7294 m .50269 .73254 L .4997 .73101 L F
.483 .465 .762 r
.50269 .73254 m .50111 .73342 L .4997 .73101 L F
.543 .28 .467 r
.48385 .73576 m .48126 .73834 L .48155 .73589 L F
.623 .212 .243 r
.53689 .78414 m .53929 .78457 L .54085 .78337 L F
.371 0 .015 r
.54085 .78337 m .54165 .78421 L .54235 .78195 L F
.54085 .78337 m .53929 .78457 L .54165 .78421 L F
.616 .609 .821 r
.43289 .77386 m .42945 .77121 L .43162 .77083 L F
.706 .671 .813 r
.43482 .77121 m .43289 .77386 L .43162 .77083 L F
.426 .227 .505 r
.2995 .62968 m .30153 .62685 L .30094 .62894 L F
.235 .002 .342 r
.29892 .63174 m .2995 .62968 L .30094 .62894 L F
.042 0 .139 r
.41897 .73574 m .4168 .73857 L .41877 .73704 L F
.052 0 0 r
.41877 .73704 m .42144 .73534 L .41897 .73574 L F
.52 .03 .033 r
.52227 .78342 m .52445 .78378 L .52586 .78258 L F
.083 0 0 r
.52586 .78258 m .52658 .78315 L .52801 .78205 L F
.52586 .78258 m .52445 .78378 L .52658 .78315 L F
.439 .221 .485 r
.30848 .67538 m .30661 .67592 L .30626 .67821 L F
.641 .482 .652 r
.38872 .67599 m .39142 .67817 L .39048 .67474 L F
.38872 .67599 m .38913 .6784 L .39142 .67817 L F
.754 .882 .937 r
.7091 .61043 m .70992 .61069 L .71222 .6091 L F
.601 .423 .613 r
.68242 .59107 m .68014 .59356 L .68018 .59129 L F
.988 .804 .569 r
.58199 .73474 m .58357 .73328 L .58285 .73261 L F
.58199 .73474 m .58304 .73569 L .58357 .73328 L F
.542 0 0 r
.52171 .72478 m .51963 .72493 L .5182 .7245 L F
.738 .427 .455 r
.52394 .72441 m .51963 .72493 L .52171 .72478 L F
.043 0 0 r
.70516 .7216 m .70714 .72126 L .7085 .72008 L F
0 0 0 r
.7085 .72008 m .70899 .72022 L .7099 .71858 L F
.7085 .72008 m .70714 .72126 L .70899 .72022 L F
.55 .768 .979 r
.31761 .66413 m .31599 .66459 L .31735 .66445 L F
.554 .361 .574 r
.31599 .66459 m .31775 .66685 L .31735 .66445 L F
.009 .55 .84 r
.70825 .57878 m .71091 .57924 L .71222 .57977 L F
.723 .279 0 r
.71316 .58189 m .71222 .57977 L .71091 .57924 L F
.687 .325 .355 r
.70991 .58133 m .71316 .58189 L .71091 .57924 L F
.685 .923 .971 r
.71316 .58189 m .7123 .58148 L .71262 .58132 L F
.723 .279 0 r
.71316 .58189 m .71412 .5829 L .71222 .57977 L F
.869 .454 .233 r
.71222 .57977 m .71434 .58326 L .71504 .58281 L F
.685 .923 .971 r
.71316 .58189 m .71262 .58132 L .71445 .58036 L F
.723 .279 0 r
.71316 .58189 m .71434 .58326 L .71412 .5829 L F
.922 .698 .581 r
.61505 .67808 m .61373 .67535 L .61497 .67612 L F
.443 0 0 r
.70705 .57733 m .71091 .57924 L .70825 .57878 L F
.612 .54 .75 r
.67293 .61111 m .67552 .61029 L .6747 .60726 L F
.619 .84 .984 r
.67446 .60944 m .67293 .61111 L .67174 .61158 L F
.67446 .60944 m .67552 .61029 L .67293 .61111 L F
.494 .329 .586 r
.33345 .68855 m .33187 .69195 L .33211 .68951 L F
.534 .66 .917 r
.40405 .78481 m .40473 .78201 L .40236 .78197 L F
.40405 .78481 m .40616 .78445 L .40473 .78201 L F
.396 .423 .771 r
.40405 .78481 m .40665 .7868 L .40616 .78445 L F
.48 .771 .995 r
.5702 .68679 m .57125 .68559 L .56905 .68585 L F
.738 .263 .117 r
.45841 .74712 m .45705 .74804 L .45519 .74621 L F
.601 .084 0 r
.45841 .74712 m .45999 .74838 L .45705 .74804 L F
.462 .172 .385 r
.46083 .74652 m .45999 .74838 L .45841 .74712 L F
.65 .568 .749 r
.6019 .70731 m .60449 .70452 L .60262 .70503 L F
.782 .649 .715 r
.49598 .72654 m .49698 .72804 L .49587 .72476 L F
.704 .52 .636 r
.49598 .72654 m .49646 .72955 L .49698 .72804 L F
.167 0 .252 r
.49646 .72955 m .49828 .72644 L .49698 .72804 L F
.724 .619 .74 r
.49587 .72476 m .49698 .72804 L .49828 .72644 L F
.552 .224 .367 r
.41346 .74095 m .4157 .74098 L .4168 .73857 L F
.467 .138 .325 r
.4168 .73857 m .4183 .73992 L .41877 .73704 L F
.4168 .73857 m .4157 .74098 L .4183 .73992 L F
.619 .59 .799 r
.32889 .7034 m .32705 .70521 L .32705 .7045 L F
.32889 .7034 m .32912 .7048 L .32705 .70521 L F
0 0 .203 r
.67867 .5993 m .67863 .59946 L .67814 .59678 L F
.08 .03 .495 r
.67867 .5993 m .67814 .59678 L .67966 .59527 L F
.362 .084 .351 r
.59683 .65173 m .59626 .65336 L .59875 .65087 L F
.455 .117 .302 r
.51641 .72983 m .51918 .72939 L .5193 .72755 L F
.777 .393 .327 r
.51918 .72939 m .52181 .72953 L .5193 .72755 L F
.359 .06 .315 r
.39364 .77751 m .39519 .77751 L .39586 .77727 L F
.39364 .77751 m .39166 .77981 L .39519 .77751 L F
.878 .701 .658 r
.63074 .66673 m .63353 .66495 L .63231 .66399 L F
.63074 .66673 m .63275 .66742 L .63353 .66495 L F
.535 .924 .875 r
.42213 .78883 m .41942 .78914 L .41869 .79002 L F
.169 .706 .75 r
.42265 .7886 m .42213 .78883 L .42371 .78856 L F
.42265 .7886 m .41942 .78914 L .42213 .78883 L F
.537 .391 .63 r
.60611 .72186 m .60404 .72531 L .60429 .72305 L F
.515 .074 .138 r
.53098 .78919 m .52571 .78948 L .52687 .78877 L F
.476 .139 .315 r
.59334 .6559 m .59626 .65336 L .59422 .65392 L F
.462 .499 .811 r
.5024 .72121 m .50114 .72407 L .50056 .72174 L F
.263 .624 .96 r
.70663 .60976 m .70783 .60862 L .70562 .60833 L F
.70663 .60976 m .7091 .61043 L .70783 .60862 L F
.821 .6 .604 r
.57785 .72366 m .58096 .72493 L .58056 .72214 L F
0 0 0 r
.58056 .72214 m .58223 .72142 L .58324 .71974 L F
0 0 .047 r
.58096 .72493 m .58223 .72142 L .58056 .72214 L F
.551 .432 .671 r
.40166 .76034 m .40379 .75995 L .40344 .75748 L F
.559 .41 .636 r
.40175 .76263 m .40379 .75995 L .40166 .76034 L F
.461 .112 .287 r
.53721 .7301 m .53607 .73235 L .53395 .73267 L F
.713 .383 .419 r
.5395 .73243 m .53721 .7301 L .53949 .73011 L F
.5395 .73243 m .53607 .73235 L .53721 .7301 L F
.682 .745 .899 r
.73204 .59656 m .73454 .59682 L .73399 .59619 L F
.565 .719 .945 r
.73544 .5993 m .73399 .59619 L .73454 .59682 L F
.49 .261 .493 r
.33794 .68541 m .33671 .68392 L .33882 .6836 L F
.33794 .68541 m .33635 .68587 L .33671 .68392 L F
.546 .355 .573 r
.38265 .68907 m .38484 .68637 L .38284 .68678 L F
.324 .177 .521 r
.39847 .7712 m .39977 .77081 L .40004 .76831 L F
.354 .257 .604 r
.39847 .7712 m .4001 .77337 L .39977 .77081 L F
.187 .205 .647 r
.39847 .7712 m .399 .77433 L .4001 .77337 L F
.279 0 .262 r
.61241 .71387 m .61243 .71594 L .61068 .71617 L F
.334 .284 .653 r
.614 .71052 m .61467 .71331 L .61241 .71387 L F
.166 0 .247 r
.6139 .7149 m .61241 .71387 L .61467 .71331 L F
.6139 .7149 m .61243 .71594 L .61241 .71387 L F
0 0 0 r
.36788 .67136 m .36835 .67141 L .36635 .67195 L F
.458 .886 .828 r
.37023 .67051 m .36921 .6707 L .36835 .67141 L F
0 0 0 r
.36921 .6707 m .36849 .67147 L .36835 .67141 L F
.36849 .67147 m .36696 .67311 L .36835 .67141 L F
.36788 .67136 m .36816 .67133 L .36835 .67141 L F
.36816 .67133 m .37033 .6711 L .36835 .67141 L F
.743 .669 .779 r
.66973 .60825 m .67078 .60424 L .66875 .60703 L F
.66973 .60825 m .67215 .6059 L .67078 .60424 L F
.657 .794 .948 r
.70927 .732 m .71011 .73215 L .71247 .731 L F
.807 .603 .625 r
.61427 .67038 m .61122 .66993 L .61141 .66752 L F
.817 .582 .583 r
.61405 .6726 m .61122 .66993 L .61427 .67038 L F
.573 .307 .476 r
.36517 .64683 m .36715 .64725 L .36528 .64588 L F
.146 .674 .868 r
.7148 .71595 m .71807 .71625 L .71556 .71622 L F
.75 .532 .6 r
.70411 .73089 m .70755 .73236 L .7061 .72954 L F
.70411 .73089 m .70487 .73284 L .70755 .73236 L F
.67 .765 .921 r
.70755 .73236 m .70839 .72884 L .7061 .72954 L F
.70755 .73236 m .70927 .732 L .70839 .72884 L F
.553 .426 .661 r
.50974 .79347 m .51268 .7943 L .51109 .79234 L F
.824 .415 .27 r
.51109 .79234 m .51268 .7943 L .51108 .794 L F
.51109 .79234 m .51108 .79353 L .51158 .79119 L F
.51108 .79353 m .51108 .794 L .51117 .79347 L F
.51108 .79353 m .51117 .79347 L .51158 .79119 L F
.146 .673 .872 r
.51141 .79466 m .51268 .7943 L .51074 .79375 L F
.51043 .79396 m .51074 .79375 L .50974 .79347 L F
.51141 .79466 m .51074 .79375 L .51043 .79396 L F
.51141 .79466 m .51382 .79467 L .51268 .7943 L F
.428 .61 .924 r
.39061 .65332 m .38959 .65491 L .38907 .6529 L F
.39061 .65332 m .39231 .65548 L .38959 .65491 L F
.537 .391 .63 r
.60611 .72186 m .60634 .72503 L .60404 .72531 L F
0 0 0 r
.49101 .78417 m .49444 .78217 L .49471 .78385 L F
.564 .544 .791 r
.49551 .77872 m .4966 .78231 L .49444 .78217 L F
.575 .337 .518 r
.49444 .78217 m .4966 .78231 L .49471 .78385 L F
.615 .456 .643 r
.43922 .75198 m .43703 .75469 L .43692 .7523 L F
.176 .587 .939 r
.38632 .65136 m .38647 .65221 L .38526 .65172 L F
.38632 .65136 m .38907 .6529 L .38647 .65221 L F
.538 .342 .563 r
.29479 .70033 m .29694 .69997 L .29705 .6977 L F
.545 .413 .652 r
.29479 .70033 m .29717 .70248 L .29694 .69997 L F
.29479 .70033 m .29508 .70297 L .29717 .70248 L F
.987 .743 .473 r
.57137 .68288 m .57125 .68559 L .57239 .68403 L F
.441 .701 .976 r
.57137 .68288 m .57239 .68403 L .57353 .68281 L F
.592 .152 .172 r
.57239 .68403 m .57477 .68534 L .57353 .68281 L F
.57239 .68403 m .57125 .68559 L .57477 .68534 L F
.283 0 .275 r
.58935 .65695 m .5907 .65787 L .59135 .65644 L F
.58935 .65695 m .58875 .65877 L .5907 .65787 L F
.481 0 0 r
.46541 .78349 m .46185 .78365 L .46318 .78275 L F
.532 .547 .816 r
.40873 .79242 m .40957 .78972 L .4075 .78988 L F
.40873 .79242 m .41047 .79222 L .40957 .78972 L F
.504 .33 .578 r
.40873 .79242 m .40922 .79567 L .41047 .79222 L F
0 0 .269 r
.54192 .69979 m .54071 .6968 L .54151 .69762 L F
.701 .723 .867 r
.69207 .60773 m .6951 .60777 L .69314 .60428 L F
.671 .71 .877 r
.69314 .60428 m .6951 .60777 L .6964 .6051 L F
.428 .173 .423 r
.32551 .65947 m .32745 .65896 L .3278 .65692 L F
.381 .133 .408 r
.3278 .65692 m .32927 .65834 L .3299 .65644 L F
.3278 .65692 m .32745 .65896 L .32927 .65834 L F
0 0 .1 r
.58512 .71668 m .58324 .71974 L .58453 .71871 L F
.234 0 .072 r
.58324 .71974 m .58407 .72051 L .58453 .71871 L F
.58324 .71974 m .58223 .72142 L .58407 .72051 L F
.868 .43 .038 r
.53044 .78094 m .53062 .78192 L .53161 .78176 L F
.815 .396 .249 r
.53062 .78192 m .53366 .78286 L .53161 .78176 L F
.542 .359 .582 r
.43169 .76842 m .42945 .77121 L .42939 .76884 L F
.364 .51 .87 r
.399 .77433 m .40185 .77632 L .4001 .77337 L F
.863 .868 .841 r
.67521 .60043 m .67642 .60168 L .67863 .59946 L F
.552 .328 .529 r
.67642 .60168 m .67911 .60188 L .67863 .59946 L F
.224 .118 .516 r
.67863 .59946 m .68011 .60059 L .68175 .6 L F
.67863 .59946 m .67911 .60188 L .68011 .60059 L F
.382 .158 .445 r
.60856 .74627 m .60872 .74894 L .60627 .74938 L F
.354 .233 .574 r
.61042 .74336 m .6108 .74617 L .60856 .74627 L F
.056 0 .185 r
.6108 .74617 m .60872 .74894 L .60856 .74627 L F
.78 .545 0 r
.41048 .66313 m .41088 .66488 L .40772 .66271 L F
.41048 .66313 m .41085 .66499 L .41088 .66488 L F
.942 .961 .687 r
.61145 .69478 m .60999 .69792 L .60982 .69616 L F
.908 .964 .646 r
.60807 .7003 m .60982 .69616 L .60999 .69792 L F
.709 .315 .301 r
.50509 .72 m .5024 .72121 L .50435 .72031 L F
.50509 .72 m .50584 .72158 L .5024 .72121 L F
.442 .202 .453 r
.50711 .72075 m .50885 .71933 L .50886 .71933 L F
0 0 0 r
.51018 .71838 m .50711 .72075 L .50886 .71933 L F
.50951 .7188 m .50711 .72075 L .51018 .71838 L F
.51018 .71838 m .50886 .71933 L .50868 .71932 L F
.50868 .71932 m .50711 .72075 L .50951 .7188 L F
.442 .202 .453 r
.50711 .72075 m .50509 .72 L .50885 .71933 L F
.50711 .72075 m .50584 .72158 L .50509 .72 L F
0 0 0 r
.50868 .71932 m .50886 .71933 L .50509 .72 L F
.632 .542 .735 r
.33002 .6948 m .3306 .69718 L .32815 .69745 L F
.562 .429 .657 r
.33053 .699 m .32815 .69745 L .3306 .69718 L F
.33053 .699 m .32847 .69964 L .32815 .69745 L F
0 0 .554 r
.55301 .74634 m .55403 .74676 L .55327 .74601 L F
0 .018 .579 r
.55327 .74601 m .55391 .74704 L .55301 .74634 L F
.472 0 .008 r
.46742 .78375 m .4688 .78245 L .47067 .78324 L F
.472 .029 .115 r
.4688 .78245 m .47107 .78245 L .47067 .78324 L F
.463 .192 .417 r
.37049 .70253 m .37309 .69947 L .37135 .7002 L F
0 0 0 r
.37343 .67022 m .37242 .67055 L .37033 .6711 L F
.336 .806 .721 r
.37413 .6698 m .37343 .67022 L .37553 .67006 L F
.37413 .6698 m .37242 .67055 L .37343 .67022 L F
.167 0 .252 r
.49646 .72955 m .49806 .72918 L .49828 .72644 L F
.465 .44 .746 r
.50189 .7294 m .49828 .72644 L .50226 .726 L F
.139 0 .245 r
.49828 .72644 m .50005 .72641 L .50226 .726 L F
.49828 .72644 m .49806 .72918 L .50005 .72641 L F
.233 0 .177 r
.37823 .81404 m .37913 .81257 L .38084 .81185 L F
.38084 .81185 m .37913 .81257 L .37823 .81404 L F
.546 .407 .643 r
.29705 .6977 m .29912 .69732 L .2989 .69469 L F
.507 .316 .557 r
.29705 .6977 m .29886 .69955 L .29912 .69732 L F
.29705 .6977 m .29694 .69997 L .29886 .69955 L F
.922 .779 .686 r
.57444 .71104 m .57153 .71331 L .57276 .70999 L F
.57444 .71104 m .57278 .71425 L .57153 .71331 L F
.741 .53 .608 r
.57592 .71392 m .57278 .71425 L .57444 .71104 L F
.556 .709 .942 r
.71715 .73581 m .71907 .73398 L .71812 .73239 L F
.71715 .73581 m .71946 .7355 L .71907 .73398 L F
.305 .066 .377 r
.30094 .62894 m .30153 .62685 L .3031 .6261 L F
.665 .754 .917 r
.69083 .59321 m .68946 .59541 L .68805 .59416 L F
.69083 .59321 m .69172 .59497 L .68946 .59541 L F
.541 .283 .473 r
.38729 .68144 m .38908 .68313 L .38912 .68079 L F
.38729 .68144 m .38684 .68348 L .38908 .68313 L F
.603 .471 .674 r
.33269 .733 m .33059 .73622 L .33041 .73346 L F
.289 0 0 r
.37433 .64987 m .37621 .65037 L .3778 .65053 L F
.309 0 0 r
.37621 .65037 m .37959 .65106 L .3778 .65053 L F
.754 .322 .226 r
.45683 .77365 m .46058 .77543 L .45828 .77504 L F
.79 .709 .775 r
.68662 .61027 m .68979 .61044 L .68875 .6073 L F
.775 .701 .782 r
.68875 .6073 m .68979 .61044 L .69207 .60773 L F
.751 .608 .699 r
.30004 .72696 m .29974 .7276 L .29757 .72747 L F
.392 .599 .929 r
.275 .6075 m .27604 .60617 L .27316 .60626 L F
.275 .6075 m .27611 .6071 L .27604 .60617 L F
.754 .638 .733 r
.63128 .65628 m .63582 .65434 L .62976 .65334 L F
.551 .377 .599 r
.33208 .69432 m .33012 .69235 L .33187 .69195 L F
.33208 .69432 m .33002 .6948 L .33012 .69235 L F
.212 0 .335 r
.60872 .74894 m .60625 .7515 L .60627 .74938 L F
.515 .275 .488 r
.61068 .71617 m .60784 .71812 L .60796 .71691 L F
.87 .596 .519 r
.71933 .60725 m .71655 .60458 L .71848 .60632 L F
.676 .582 .742 r
.72015 .60503 m .71933 .60725 L .71848 .60632 L F
.304 .112 .447 r
.3057 .62119 m .30535 .62329 L .30386 .62421 L F
.186 0 .26 r
.30386 .62421 m .30535 .62329 L .3031 .6261 L F
.779 .721 .798 r
.52714 .72949 m .52849 .73248 L .53064 .7319 L F
.616 .456 .642 r
.52836 .73267 m .52994 .73565 L .52639 .73564 L F
.52849 .73248 m .52856 .73264 L .52836 .73267 L F
.52856 .73264 m .52994 .73565 L .52836 .73267 L F
.635 .465 .635 r
.53188 .73465 m .52935 .73303 L .53178 .73277 L F
.52935 .73303 m .52849 .73248 L .52986 .7326 L F
.52935 .73303 m .52986 .7326 L .53178 .73277 L F
.53188 .73465 m .52994 .73565 L .52888 .73334 L F
.52935 .73303 m .52888 .73334 L .52849 .73248 L F
.53188 .73465 m .52888 .73334 L .52935 .73303 L F
.807 .61 .636 r
.52947 .73415 m .53289 .73118 L .5314 .73165 L F
.53055 .73222 m .5314 .73165 L .53075 .73186 L F
.52947 .73415 m .5314 .73165 L .53055 .73222 L F
.53058 .732 m .53075 .73186 L .53064 .7319 L F
.52947 .73415 m .53075 .73186 L .53058 .732 L F
.373 0 .013 r
.52721 .73435 m .52947 .73415 L .5304 .73237 L F
.52988 .73244 m .5304 .73237 L .53064 .7319 L F
.52721 .73435 m .5304 .73237 L .52988 .73244 L F
.52721 .73435 m .53064 .7319 L .52849 .73248 L F
.31 .226 .597 r
.53064 .7319 m .53271 .72945 L .52943 .72884 L F
.53064 .7319 m .53289 .73118 L .53271 .72945 L F
.874 .815 .788 r
.71544 .60139 m .71891 .59912 L .71766 .59865 L F
.71544 .60139 m .71687 .60223 L .71891 .59912 L F
.793 .527 .535 r
.72106 .60134 m .71766 .59865 L .71891 .59912 L F
0 0 0 r
.57224 .67042 m .57359 .6699 L .57387 .66936 L F
.57224 .67042 m .57091 .67165 L .57359 .6699 L F
.512 .097 .191 r
.72974 .59758 m .72908 .59935 L .72683 .59902 L F
.192 0 .071 r
.73119 .59802 m .72974 .59758 L .73204 .59656 L F
.73119 .59802 m .72908 .59935 L .72974 .59758 L F
.799 .619 .658 r
.62663 .65059 m .63 .64859 L .6267 .64818 L F
.62663 .65059 m .62978 .65108 L .63 .64859 L F
.577 .625 .864 r
.57278 .71425 m .57075 .71501 L .56972 .7128 L F
.693 .729 .878 r
.72224 .61805 m .72561 .61858 L .72427 .61598 L F
.752 .755 .855 r
.72427 .61598 m .72561 .61858 L .72807 .61657 L F
.605 .616 .836 r
.2949 .71399 m .29726 .71375 L .29468 .71354 L F
.772 .293 .096 r
.49471 .78385 m .49767 .78522 L .4967 .7862 L F
.534 .289 .489 r
.49767 .78522 m .50015 .78654 L .4967 .7862 L F
.49767 .78522 m .50088 .78498 L .50015 .78654 L F
.776 .667 .743 r
.31371 .72458 m .31164 .72755 L .31493 .72775 L F
.198 .324 .767 r
.31371 .72458 m .31493 .72775 L .31576 .72634 L F
.442 .644 .943 r
.31493 .72775 m .31701 .72771 L .31576 .72634 L F
.54 .152 .255 r
.44426 .77476 m .44604 .77561 L .44697 .77375 L F
.275 0 0 r
.44604 .77561 m .44962 .77382 L .44697 .77375 L F
.526 .861 .995 r
.48945 .74912 m .49186 .74849 L .48948 .7467 L F
.578 .825 .992 r
.49186 .74849 m .48945 .74912 L .48948 .7467 L F
.243 0 0 r
.47883 .72423 m .48036 .72444 L .48093 .7237 L F
.474 .12 .284 r
.47757 .72609 m .48036 .72444 L .47883 .72423 L F
.161 0 0 r
.53789 .78935 m .53472 .78934 L .53574 .78965 L F
.862 .463 .283 r
.56062 .68695 m .56125 .68884 L .55933 .68756 L F
.25 .036 .38 r
.45519 .74621 m .45282 .74875 L .45285 .7479 L F
.45519 .74621 m .45461 .74838 L .45282 .74875 L F
.192 0 .184 r
.45461 .74838 m .45225 .7507 L .45282 .74875 L F
.052 0 0 r
.41877 .73704 m .41886 .73704 L .42144 .73534 L F
.41886 .73704 m .4201 .73668 L .42144 .73534 L F
.241 0 0 r
.42144 .73534 m .4197 .73708 L .42188 .73663 L F
.42144 .73534 m .42188 .73663 L .42069 .73503 L F
.392 .221 .527 r
.42069 .73503 m .42159 .73624 L .42268 .73518 L F
.42159 .73624 m .42188 .73663 L .4222 .73606 L F
.42159 .73624 m .4222 .73606 L .42268 .73518 L F
.052 0 0 r
.41886 .73704 m .4197 .73708 L .4201 .73668 L F
.143 0 0 r
.42069 .73503 m .4236 .73491 L .42144 .73534 L F
.627 .486 .67 r
.4089 .7414 m .40908 .74378 L .41118 .74101 L F
.007 0 0 r
.71504 .58281 m .71642 .58275 L .71739 .58291 L F
.71504 .58281 m .71434 .58326 L .71642 .58275 L F
.375 0 0 r
.45504 .78409 m .45425 .78471 L .45199 .78471 L F
.169 0 0 r
.45747 .78383 m .45425 .78471 L .45504 .78409 L F
.617 .677 .884 r
.33596 .70749 m .33243 .70576 L .33448 .70529 L F
.609 .686 .897 r
.33814 .70652 m .33596 .70749 L .33448 .70529 L F
.2 .257 .698 r
.52176 .73851 m .52246 .73734 L .52251 .73792 L F
.52246 .73734 m .52295 .73652 L .52251 .73792 L F
.599 .89 .99 r
.52229 .73551 m .52251 .73792 L .52266 .73504 L F
.018 .021 .516 r
.52304 .73955 m .52176 .73851 L .52396 .73831 L F
.52304 .73955 m .52295 .73652 L .52246 .73734 L F
.5224 .73903 m .52246 .73734 L .52176 .73851 L F
.599 .89 .99 r
.52244 .73788 m .52251 .73792 L .52246 .73734 L F
.018 .021 .516 r
.52304 .73955 m .52246 .73734 L .5224 .73903 L F
.599 .89 .99 r
.521 .73716 m .52244 .73788 L .52229 .73551 L F
.52244 .73788 m .52246 .73734 L .52229 .73551 L F
.484 .803 1 r
.5186 .73829 m .52176 .73851 L .52251 .73792 L F
.503 .438 .716 r
.28263 .61857 m .28451 .61792 L .28365 .61588 L F
.494 .345 .608 r
.28249 .6204 m .28451 .61792 L .28263 .61857 L F
.194 0 .261 r
.50269 .73254 m .50042 .73528 L .50111 .73342 L F
.648 .551 .731 r
.60063 .71096 m .6019 .70731 L .5999 .70871 L F
.434 .52 .847 r
.70411 .72938 m .70411 .73089 L .7061 .72954 L F
0 .048 .615 r
.58048 .75945 m .57909 .75693 L .58107 .75786 L F
.159 .573 .933 r
.55005 .70775 m .55083 .70721 L .54823 .70513 L F
.55005 .70775 m .55157 .70809 L .55083 .70721 L F
.371 0 .125 r
.37418 .7137 m .37027 .71538 L .37111 .71385 L F
.704 .39 .442 r
.29974 .7276 m .29684 .72954 L .29757 .72747 L F
.69 .852 .96 r
.34158 .70659 m .33814 .70652 L .34 .70575 L F
.54 .788 .99 r
.3423 .70509 m .34158 .70659 L .34 .70575 L F
.3423 .70509 m .34376 .70618 L .34158 .70659 L F
.209 .432 .858 r
.35075 .70769 m .3498 .70899 L .34943 .70742 L F
.593 .278 .405 r
.68604 .58045 m .68829 .58206 L .68825 .58007 L F
.68604 .58045 m .68595 .58262 L .68829 .58206 L F
.751 .89 .942 r
.54187 .73339 m .54281 .73543 L .54521 .73305 L F
.499 0 0 r
.54402 .73352 m .54315 .73357 L .54187 .73339 L F
.54315 .73357 m .54103 .73367 L .54187 .73339 L F
.513 .756 .984 r
.53968 .73309 m .54187 .73339 L .5395 .73243 L F
.54026 .73516 m .54187 .73339 L .53968 .73309 L F
.54026 .73516 m .54281 .73543 L .54187 .73339 L F
.204 0 .22 r
.70516 .7216 m .70447 .72407 L .70714 .72126 L F
.645 .586 .773 r
.67579 .61587 m .67762 .61947 L .67995 .61849 L F
.768 .373 .305 r
.6043 .65102 m .6077 .65316 L .60766 .65129 L F
.702 .46 .555 r
.6077 .65316 m .61048 .65104 L .60766 .65129 L F
.419 .68 .971 r
.55574 .74005 m .55641 .74122 L .55749 .74006 L F
.41 .667 .966 r
.55641 .74122 m .55863 .7414 L .55749 .74006 L F
.155 0 0 r
.59704 .75789 m .59588 .75937 L .59385 .75999 L F
.099 0 0 r
.59704 .75789 m .59771 .75861 L .59588 .75937 L F
.59704 .75789 m .5991 .75719 L .59771 .75861 L F
.225 .731 .895 r
.71739 .58291 m .71979 .58276 L .72067 .58302 L F
.349 .727 .986 r
.72222 .58226 m .72067 .58302 L .71979 .58276 L F
.72222 .58226 m .72299 .5831 L .72067 .58302 L F
.049 .243 .741 r
.56997 .70779 m .56959 .70904 L .56946 .70764 L F
.118 0 .351 r
.57089 .70953 m .56959 .70904 L .56997 .70779 L F
.57089 .70953 m .56905 .71141 L .56959 .70904 L F
.319 .124 .452 r
.2955 .63763 m .29744 .6347 L .29721 .63708 L F
.388 .209 .513 r
.29698 .63948 m .2955 .63763 L .29721 .63708 L F
.29698 .63948 m .2953 .64022 L .2955 .63763 L F
0 0 0 r
.62032 .69954 m .61806 .70254 L .61911 .70083 L F
.578 .825 .992 r
.49186 .74849 m .49287 .74939 L .48945 .74912 L F
.48945 .74912 m .49287 .74939 L .49186 .74849 L F
.942 .961 .687 r
.61145 .69478 m .60982 .69616 L .61093 .69458 L F
.959 .921 .572 r
.61093 .69458 m .61144 .69189 L .61145 .69478 L F
.819 .365 .152 r
.39041 .67263 m .38664 .6698 L .38758 .671 L F
.01 .192 .704 r
.55949 .73431 m .55746 .73299 L .55654 .73182 L F
.55949 .73431 m .55962 .73559 L .55746 .73299 L F
.532 .345 .573 r
.55746 .73299 m .55962 .73559 L .55915 .73521 L F
.548 .384 .61 r
.40004 .76831 m .40212 .7656 L .3999 .76606 L F
.561 .234 .371 r
.58512 .71668 m .58453 .71871 L .58757 .71809 L F
.58512 .71668 m .58757 .71809 L .58642 .71748 L F
.455 .221 .469 r
.40919 .67849 m .40887 .68069 L .40685 .68118 L F
.508 .297 .528 r
.41115 .67796 m .40887 .68069 L .40919 .67849 L F
.63 .372 .508 r
.49211 .73335 m .48825 .73527 L .48934 .7328 L F
.717 .838 .939 r
.72587 .72639 m .72372 .7274 L .72281 .72628 L F
.426 .704 .98 r
.39518 .78197 m .39736 .7822 L .39589 .78118 L F
.39518 .78197 m .39736 .7822 L .39589 .78118 L F
.334 .751 .978 r
.2807 .59793 m .27719 .59741 L .27953 .59721 L F
.374 .781 .982 r
.28131 .59708 m .2807 .59793 L .27953 .59721 L F
.28131 .59708 m .28273 .59767 L .2807 .59793 L F
.466 .219 .455 r
.40472 .74927 m .40673 .74889 L .40713 .74682 L F
.612 .351 .499 r
.40713 .74682 m .40917 .74848 L .40932 .74627 L F
.40713 .74682 m .40673 .74889 L .40917 .74848 L F
.633 .072 0 r
.72653 .72127 m .72664 .72175 L .72482 .72015 L F
.72757 .72194 m .72664 .72175 L .72653 .72127 L F
.982 .791 .384 r
.72757 .72194 m .72682 .7226 L .72664 .72175 L F
0 0 .153 r
.72664 .72175 m .72682 .7226 L .72671 .72203 L F
.72664 .72175 m .72671 .72203 L .72642 .72053 L F
0 .215 .738 r
.72482 .72015 m .72664 .72175 L .72642 .72053 L F
.72482 .72015 m .72642 .72053 L .72443 .72079 L F
.471 .594 .894 r
.27805 .61012 m .27777 .60715 L .27611 .6071 L F
.27805 .61012 m .27957 .60972 L .27777 .60715 L F
.968 .84 .663 r
.57614 .69155 m .57781 .68945 L .57708 .68883 L F
.57614 .69155 m .57728 .6925 L .57781 .68945 L F
.203 0 .07 r
.28779 .64778 m .28875 .64644 L .29062 .64571 L F
.835 .913 .889 r
.58735 .71486 m .58391 .7135 L .58652 .71314 L F
.58735 .71486 m .58435 .71568 L .58391 .7135 L F
0 .366 .824 r
.58848 .71484 m .58735 .71486 L .58652 .71314 L F
.58848 .71484 m .58922 .7159 L .58735 .71486 L F
.379 0 0 r
.58632 .7221 m .58695 .72254 L .58431 .72232 L F
.58632 .7221 m .58877 .72335 L .58695 .72254 L F
.811 .552 .547 r
.5201 .73218 m .52276 .7303 L .52181 .72953 L F
.5201 .73218 m .52303 .73267 L .52276 .7303 L F
.498 .392 .665 r
.52276 .7303 m .52494 .73019 L .52542 .72821 L F
.489 .319 .577 r
.52303 .73267 m .52494 .73019 L .52276 .7303 L F
0 0 0 r
.58056 .71088 m .57803 .71298 L .57826 .71118 L F
.329 .153 .485 r
.27683 .63448 m .27805 .63179 L .27695 .63215 L F
.786 .697 .766 r
.56249 .69909 m .56475 .69976 L .56377 .69861 L F
.822 .515 .471 r
.56249 .69909 m .56346 .70157 L .56475 .69976 L F
.214 .474 .887 r
.56475 .69976 m .56585 .69934 L .56377 .69861 L F
.136 .237 .705 r
.56585 .69934 m .56641 .70201 L .56475 .69976 L F
0 0 0 r
.56475 .69976 m .56346 .70157 L .56585 .69934 L F
.734 .53 .616 r
.43388 .76846 m .43162 .77083 L .43169 .76842 L F
.43388 .76846 m .43482 .77121 L .43162 .77083 L F
.666 .494 .642 r
.43736 .77074 m .43388 .76846 L .43714 .76847 L F
.43736 .77074 m .43482 .77121 L .43388 .76846 L F
.122 0 0 r
.35633 .72284 m .35605 .72179 L .35801 .72098 L F
.35633 .72284 m .35455 .72347 L .35605 .72179 L F
.542 .359 .582 r
.43169 .76842 m .43162 .77083 L .42945 .77121 L F
.503 0 0 r
.50486 .78992 m .50583 .79088 L .50394 .78908 L F
.50486 .78992 m .50719 .79159 L .50583 .79088 L F
.404 .542 .88 r
.55969 .71649 m .56117 .71521 L .55783 .71357 L F
.55969 .71649 m .56125 .71638 L .56117 .71521 L F
.714 .757 .886 r
.71895 .61763 m .72013 .61902 L .72224 .61805 L F
0 0 0 r
.43491 .78688 m .43169 .78761 L .43287 .78727 L F
.332 .018 .274 r
.39235 .69688 m .39045 .69746 L .39303 .6952 L F
.423 .104 .318 r
.39446 .6963 m .39303 .6952 L .39502 .69463 L F
.39446 .6963 m .39235 .69688 L .39303 .6952 L F
.617 .182 0 r
.56162 .74017 m .56228 .74108 L .56049 .73845 L F
0 .028 .597 r
.56261 .74067 m .56228 .74108 L .56162 .74017 L F
.56261 .74067 m .56405 .74331 L .56228 .74108 L F
.349 .266 .62 r
.56405 .74331 m .56273 .74411 L .56228 .74108 L F
0 0 0 r
.4891 .71938 m .49037 .71882 L .49158 .71737 L F
.074 0 0 r
.49158 .71737 m .49228 .71806 L .49364 .71663 L F
.49158 .71737 m .49037 .71882 L .49228 .71806 L F
0 0 .406 r
.67521 .60043 m .67408 .60471 L .67642 .60168 L F
.591 .392 .581 r
.67408 .60471 m .67678 .60454 L .67642 .60168 L F
.349 .222 .562 r
.67642 .60168 m .67789 .60331 L .67911 .60188 L F
.67642 .60168 m .67678 .60454 L .67789 .60331 L F
.382 0 .142 r
.58913 .76016 m .58573 .76242 L .58583 .76062 L F
.58913 .76016 m .58796 .76205 L .58573 .76242 L F
.448 0 .064 r
.59154 .7605 m .58796 .76205 L .58913 .76016 L F
.747 .994 .854 r
.57614 .69155 m .57567 .69251 L .57728 .6925 L F
.593 .618 .846 r
.54908 .69485 m .54566 .69276 L .54775 .69336 L F
.551 .454 .697 r
.30465 .68113 m .30677 .68073 L .30626 .67821 L F
.503 .32 .565 r
.30462 .6835 m .30677 .68073 L .30465 .68113 L F
0 .475 .702 r
.53546 .78389 m .53482 .78379 L .53366 .78286 L F
.53546 .78389 m .53689 .78414 L .53482 .78379 L F
.189 .328 .775 r
.71795 .60111 m .71687 .60223 L .71544 .60139 L F
.71795 .60111 m .7181 .60397 L .71687 .60223 L F
.759 .703 .799 r
.57456 .71521 m .57322 .71704 L .57278 .71425 L F
.229 .228 .65 r
.57535 .71781 m .57322 .71704 L .57456 .71521 L F
.57535 .71781 m .57392 .71924 L .57322 .71704 L F
.939 .841 .72 r
.73137 .60957 m .73375 .60722 L .73226 .60595 L F
.73137 .60957 m .73249 .6106 L .73375 .60722 L F
.399 0 .047 r
.33918 .65266 m .34285 .65092 L .34072 .6511 L F
.422 .59 .912 r
.70138 .6072 m .70244 .60531 L .6985 .60464 L F
.264 .477 .878 r
.70372 .60704 m .703 .60754 L .70399 .6064 L F
.422 .59 .912 r
.70138 .6072 m .70372 .60704 L .70244 .60531 L F
0 0 0 r
.4891 .71938 m .48757 .7206 L .49037 .71882 L F
.483 .627 .915 r
.5561 .71381 m .55866 .7119 L .55457 .71119 L F
.5561 .71381 m .55783 .71357 L .55866 .7119 L F
.519 .368 .616 r
.29848 .69239 m .30069 .69219 L .30034 .68951 L F
.593 .516 .737 r
.2989 .69469 m .30069 .69219 L .29848 .69239 L F
.042 0 0 r
.3524 .71033 m .35445 .70993 L .35639 .70907 L F
.534 .912 .757 r
.35639 .70907 m .35619 .70872 L .35817 .70817 L F
.35639 .70907 m .35445 .70993 L .35619 .70872 L F
.758 .494 .534 r
.69608 .57955 m .69928 .57762 L .6962 .5778 L F
.754 .74 .84 r
.68875 .6073 m .69207 .60773 L .69066 .60655 L F
.701 .723 .867 r
.69207 .60773 m .69314 .60428 L .69066 .60655 L F
.982 .791 .384 r
.72757 .72194 m .72739 .7241 L .72682 .7226 L F
.217 .417 .844 r
.51059 .72712 m .50774 .72433 L .50968 .72414 L F
.321 .419 .806 r
.5943 .72162 m .59572 .72496 L .5968 .72359 L F
.208 .01 .377 r
.59572 .72496 m .59654 .72636 L .5968 .72359 L F
.59572 .72496 m .59525 .7271 L .59654 .72636 L F
.656 .756 .923 r
.70839 .72884 m .70927 .732 L .71167 .72944 L F
.657 .794 .948 r
.70927 .732 m .71247 .731 L .71167 .72944 L F
.625 .557 .758 r
.29468 .71354 m .29667 .71113 L .29384 .71102 L F
.29468 .71354 m .29726 .71375 L .29667 .71113 L F
.674 .454 .579 r
.6896 .58892 m .68716 .59015 L .68864 .58752 L F
.6896 .58892 m .68821 .59145 L .68716 .59015 L F
.6896 .58892 m .69068 .59081 L .68821 .59145 L F
.565 .42 .643 r
.38484 .68637 m .38684 .68348 L .38478 .68394 L F
0 0 .433 r
.73408 .72679 m .73437 .72899 L .73347 .72984 L F
0 .02 .556 r
.73437 .72899 m .73469 .73193 L .73347 .72984 L F
.519 .533 .81 r
.31582 .6061 m .31409 .60779 L .31328 .60517 L F
.311 .249 .624 r
.31582 .6061 m .31455 .61018 L .31409 .60779 L F
.566 .209 .322 r
.54665 .68887 m .55016 .6867 L .55038 .68988 L F
.54665 .68887 m .54854 .68942 L .55016 .6867 L F
0 0 0 r
.55016 .6867 m .55141 .68605 L .55217 .6859 L F
.74 .294 .191 r
.55038 .68988 m .54934 .69084 L .54665 .68887 L F
.54934 .69084 m .54886 .69128 L .54843 .69082 L F
.54934 .69084 m .54843 .69082 L .54665 .68887 L F
.649 .728 .907 r
.54611 .69077 m .54636 .69226 L .54579 .69092 L F
.5478 .68996 m .54727 .69079 L .54611 .69077 L F
.54727 .69079 m .54636 .69226 L .54611 .69077 L F
0 0 0 r
.55016 .6867 m .54854 .68942 L .55141 .68605 L F
.584 .829 .991 r
.41483 .78962 m .41659 .79078 L .41869 .79002 L F
.771 .715 .8 r
.52614 .733 m .52494 .73019 L .52303 .73267 L F
.337 0 .049 r
.52266 .73504 m .52614 .733 L .52406 .73566 L F
.76 .594 .671 r
.52406 .73566 m .52614 .733 L .52639 .73564 L F
.337 0 .049 r
.52266 .73504 m .52527 .7349 L .52614 .733 L F
.764 .629 .71 r
.52639 .73564 m .52733 .73845 L .52396 .73831 L F
.624 .159 .129 r
.52733 .73845 m .52607 .74006 L .52396 .73831 L F
.696 .682 .833 r
.52614 .733 m .52714 .72949 L .52494 .73019 L F
.52614 .733 m .52849 .73248 L .52714 .72949 L F
.616 .456 .642 r
.52849 .73248 m .52639 .73564 L .52614 .733 L F
.39 0 .07 r
.52614 .733 m .52721 .73435 L .52849 .73248 L F
.52614 .733 m .52527 .7349 L .52721 .73435 L F
.062 0 .182 r
.52994 .73565 m .52733 .73845 L .52639 .73564 L F
.52994 .73565 m .52888 .73762 L .52733 .73845 L F
.717 .476 .56 r
.52888 .73762 m .52607 .74006 L .52733 .73845 L F
.412 .515 .853 r
.40657 .66075 m .40553 .66261 L .40417 .65976 L F
.499 .626 .907 r
.40657 .66075 m .40772 .66271 L .40553 .66261 L F
.731 .704 .826 r
.67078 .60424 m .67215 .6059 L .67408 .60471 L F
.241 .043 .398 r
.32551 .65947 m .32665 .66071 L .32745 .65896 L F
.32551 .65947 m .32514 .66165 L .32665 .66071 L F
.861 .81 .799 r
.576 .70548 m .57283 .70479 L .57536 .70175 L F
.489 .164 .341 r
.57387 .7085 m .5764 .7083 L .57693 .70667 L F
.52 .254 .452 r
.576 .70548 m .5764 .7083 L .57387 .7085 L F
0 .017 .58 r
.57536 .70175 m .57674 .70394 L .576 .70548 L F
0 0 .335 r
.57726 .70622 m .576 .70548 L .57674 .70394 L F
.57726 .70622 m .5764 .7083 L .576 .70548 L F
.722 .515 .61 r
.62331 .64801 m .62665 .64578 L .62325 .6456 L F
.62331 .64801 m .6267 .64818 L .62665 .64578 L F
.227 0 0 r
.46876 .774 m .47175 .77327 L .46965 .77367 L F
.304 0 0 r
.49598 .72654 m .49249 .7287 L .49361 .72974 L F
.49598 .72654 m .49469 .72841 L .49249 .7287 L F
.704 .52 .636 r
.49598 .72654 m .49361 .72974 L .49646 .72955 L F
.057 0 .179 r
.49812 .7242 m .49598 .72654 L .49587 .72476 L F
.49812 .7242 m .49689 .72702 L .49598 .72654 L F
.783 .578 .623 r
.49689 .72702 m .49469 .72841 L .49598 .72654 L F
.778 .536 .57 r
.69068 .59081 m .69398 .59121 L .69399 .5941 L F
.624 .849 .985 r
.69297 .59032 m .69398 .59121 L .69629 .59039 L F
.69297 .59032 m .69629 .59039 L .69529 .58972 L F
.594 .543 .767 r
.69529 .58972 m .69398 .59121 L .69297 .59032 L F
.69529 .58972 m .69399 .5941 L .69398 .59121 L F
.546 .457 .705 r
.68821 .59145 m .68658 .59289 L .68499 .59233 L F
.68821 .59145 m .68805 .59416 L .68658 .59289 L F
.457 .142 .343 r
.55785 .69725 m .5597 .6971 L .5608 .69513 L F
.074 0 .107 r
.5608 .69513 m .5597 .6971 L .56264 .69385 L F
.097 0 0 r
.42839 .73666 m .43193 .7369 L .43015 .73577 L F
.516 .047 .079 r
.43015 .73577 m .43193 .7369 L .43257 .73596 L F
.118 .185 .658 r
.58042 .72955 m .5794 .73069 L .57879 .7274 L F
.299 .464 .857 r
.58042 .72955 m .58285 .73261 L .5794 .73069 L F
.4 .049 .25 r
.3656 .70486 m .36833 .70296 L .36641 .70358 L F
.817 .826 .857 r
.39755 .77821 m .39929 .78035 L .3982 .7796 L F
.39755 .77821 m .3982 .7796 L .39586 .77727 L F
.584 .759 .962 r
.39589 .78118 m .39929 .78035 L .39755 .77821 L F
.39589 .78118 m .39942 .78159 L .39929 .78035 L F
.546 .347 .562 r
.40685 .68118 m .40674 .6835 L .40461 .68378 L F
.454 .272 .543 r
.4087 .68296 m .40685 .68118 L .40887 .68069 L F
.4087 .68296 m .40674 .6835 L .40685 .68118 L F
0 .289 .673 r
.69518 .59672 m .69172 .59497 L .69399 .5941 L F
.573 .597 .839 r
.69654 .59367 m .69518 .59672 L .69399 .5941 L F
.69654 .59367 m .69754 .5964 L .69518 .59672 L F
.542 .381 .612 r
.30254 .68643 m .30462 .6835 L .3023 .68398 L F
.195 0 .181 r
.38431 .70678 m .38342 .70534 L .385 .70476 L F
.38431 .70678 m .38273 .70757 L .38342 .70534 L F
.634 .429 .588 r
.54281 .73543 m .54611 .73532 L .54521 .73305 L F
.54281 .73543 m .545 .73663 L .54611 .73532 L F
.52 .499 .774 r
.56993 .73823 m .57192 .73794 L .57125 .73483 L F
.576 .463 .688 r
.4049 .75167 m .40673 .74889 L .40472 .74927 L F
.282 .366 .772 r
.55157 .70809 m .55261 .71139 L .55381 .70983 L F
.51 .695 .952 r
.55261 .71139 m .55457 .71119 L .55381 .70983 L F
.242 0 0 r
.73399 .59619 m .73119 .59802 L .73204 .59656 L F
.337 .003 .241 r
.3466 .67831 m .34555 .68064 L .34394 .68022 L F
.472 .147 .333 r
.34873 .67789 m .34555 .68064 L .3466 .67831 L F
.486 .631 .917 r
.4031 .65815 m .40417 .65976 L .40216 .65983 L F
.558 .006 0 r
.58304 .73569 m .58601 .73716 L .58625 .73631 L F
.759 .245 0 r
.58601 .73716 m .58785 .73812 L .58625 .73631 L F
.615 .669 .878 r
.53838 .73911 m .54194 .74134 L .5396 .74081 L F
.489 .241 .464 r
.54164 .74275 m .5396 .74081 L .54194 .74134 L F
.482 .234 .461 r
.40461 .68378 m .40414 .68596 L .40207 .68632 L F
.417 .131 .369 r
.40674 .6835 m .40414 .68596 L .40461 .68378 L F
.202 .723 .866 r
.72299 .5831 m .72554 .5829 L .72631 .5831 L F
.532 .917 .924 r
.72631 .5831 m .72757 .58202 L .72874 .58221 L F
.72631 .5831 m .72554 .5829 L .72757 .58202 L F
.567 .75 .963 r
.29531 .5998 m .29188 .59891 L .29389 .59863 L F
.506 .755 .985 r
.29589 .59834 m .29531 .5998 L .29389 .59863 L F
.29589 .59834 m .29736 .5995 L .29531 .5998 L F
.43 .087 .282 r
.34394 .68022 m .34293 .68274 L .34087 .68308 L F
.381 .041 .259 r
.34498 .68223 m .34394 .68022 L .34555 .68064 L F
.34498 .68223 m .34293 .68274 L .34394 .68022 L F
.581 .326 .495 r
.67828 .58537 m .68068 .58536 L .6808 .58322 L F
.588 .358 .534 r
.68068 .58536 m .68503 .58328 L .6808 .58322 L F
.914 .76 .676 r
.59035 .72132 m .59189 .72207 L .59089 .71896 L F
.556 .37 .585 r
.58967 .72491 m .59199 .72456 L .59189 .72207 L F
.62 .61 .819 r
.59089 .71896 m .59189 .72207 L .5943 .72162 L F
.69 .368 .425 r
.54165 .78421 m .54437 .78432 L .54235 .78195 L F
.784 .288 .02 r
.54235 .78195 m .54437 .78432 L .54583 .78471 L F
.388 .189 .486 r
.30771 .61829 m .30745 .62042 L .3057 .62119 L F
.288 .067 .394 r
.30745 .62042 m .30535 .62329 L .3057 .62119 L F
.386 .116 .376 r
.739 .72156 m .73628 .72401 L .73675 .72133 L F
.079 0 .308 r
.62228 .69456 m .62253 .69643 L .62072 .69757 L F
.242 .104 .484 r
.62253 .69643 m .62032 .69954 L .62072 .69757 L F
.435 .176 .421 r
.31264 .61306 m .31197 .61512 L .31006 .61566 L F
.259 .013 .338 r
.31417 .61227 m .31197 .61512 L .31264 .61306 L F
0 0 .531 r
.568 .72704 m .56807 .72645 L .56647 .72422 L F
0 0 .522 r
.568 .72704 m .56962 .72941 L .56807 .72645 L F
.641 .585 .776 r
.4306 .76538 m .42729 .76227 L .42943 .7616 L F
.624 .579 .784 r
.43258 .76293 m .4306 .76538 L .42943 .7616 L F
.56 .256 .41 r
.43544 .7348 m .43764 .73485 L .43802 .73309 L F
.531 .23 .402 r
.43764 .73485 m .43987 .73469 L .43802 .73309 L F
.531 .23 .401 r
.43802 .73309 m .43987 .73469 L .44031 .73289 L F
.692 .378 .439 r
.57567 .69251 m .57341 .69383 L .57156 .69207 L F
.81 .352 .143 r
.38456 .67017 m .38311 .66998 L .38231 .66933 L F
.923 .625 .461 r
.38456 .67017 m .38307 .67177 L .38311 .66998 L F
.501 .101 .213 r
.38664 .6698 m .38551 .67043 L .38456 .67017 L F
.38664 .6698 m .38536 .67178 L .38307 .67177 L F
.617 .711 .913 r
.38311 .66998 m .38636 .67024 L .38331 .66673 L F
.625 .184 0 r
.38664 .6698 m .38766 .67144 L .38536 .67178 L F
.617 .711 .913 r
.38636 .67024 m .38675 .67027 L .38665 .67017 L F
.38636 .67024 m .38665 .67017 L .38331 .66673 L F
.501 .101 .213 r
.38551 .67043 m .38307 .67177 L .38401 .67076 L F
.38551 .67043 m .38401 .67076 L .38456 .67017 L F
.383 .065 .297 r
.28634 .6487 m .2854 .65044 L .28356 .65089 L F
.071 0 .107 r
.28779 .64778 m .2854 .65044 L .28634 .6487 L F
.911 .895 .8 r
.576 .6852 m .57723 .68636 L .57855 .68404 L F
.993 .756 .465 r
.57594 .68787 m .57723 .68636 L .576 .6852 L F
.57594 .68787 m .57708 .68883 L .57723 .68636 L F
.568 .42 .641 r
.40282 .75456 m .4052 .75526 L .4049 .75167 L F
.548 .45 .696 r
.40282 .75456 m .40546 .75708 L .4052 .75526 L F
.40282 .75456 m .40344 .75748 L .40546 .75708 L F
.957 .657 .229 r
.43752 .772 m .43843 .77399 L .43736 .77074 L F
.18 .594 .941 r
.43913 .77337 m .43843 .77399 L .43752 .772 L F
.43913 .77337 m .44058 .77448 L .43843 .77399 L F
0 .512 .705 r
.30383 .7296 m .30232 .72944 L .30032 .72922 L F
.293 .781 .901 r
.30523 .72931 m .30383 .7296 L .30568 .72928 L F
.30523 .72931 m .30232 .72944 L .30383 .7296 L F
.814 1 .803 r
.5563 .74634 m .55424 .74873 L .55502 .74852 L F
.128 .552 .921 r
.54636 .69226 m .54566 .69276 L .54468 .6917 L F
.54636 .69226 m .54775 .69336 L .54566 .69276 L F
.461 .248 .503 r
.38807 .70014 m .38777 .7024 L .38593 .70278 L F
.375 .096 .356 r
.38777 .7024 m .385 .70476 L .38593 .70278 L F
.634 .364 .492 r
.57693 .70667 m .57974 .70747 L .57715 .70548 L F
.747 .994 .854 r
.57614 .69155 m .57341 .69383 L .57567 .69251 L F
.54 .262 .443 r
.6913 .57923 m .69388 .5792 L .6938 .57754 L F
.66 .354 .443 r
.69388 .5792 m .69608 .57955 L .6938 .57754 L F
.661 .354 .442 r
.6938 .57754 m .69608 .57955 L .6962 .5778 L F
.684 .137 0 r
.52322 .70898 m .52535 .71088 L .5267 .71135 L F
.537 .043 0 r
.52703 .71178 m .5267 .71135 L .52535 .71088 L F
.52703 .71178 m .5284 .71319 L .5267 .71135 L F
.397 .28 .601 r
.70283 .72492 m .70538 .72614 L .70447 .72407 L F
.70283 .72492 m .70298 .7274 L .70538 .72614 L F
.633 .595 .793 r
.60569 .73283 m .60207 .73016 L .60471 .73106 L F
.442 .442 .763 r
.60732 .73093 m .60471 .73106 L .60735 .72966 L F
.60732 .73093 m .60569 .73283 L .60471 .73106 L F
0 0 0 r
.72549 .71271 m .72354 .71379 L .72519 .7131 L F
.72519 .7131 m .72354 .71379 L .72175 .71501 L F
.344 .55 .909 r
.50719 .79159 m .50791 .79307 L .50889 .79186 L F
.268 .437 .844 r
.50889 .79186 m .50791 .79307 L .50974 .79347 L F
.524 .809 .998 r
.28872 .59772 m .28665 .59821 L .285 .59724 L F
.309 0 0 r
.33059 .73622 m .33015 .73622 L .3275 .73518 L F
.316 0 0 r
.33059 .73622 m .3305 .73634 L .33015 .73622 L F
.33059 .73622 m .33225 .73691 L .3305 .73634 L F
.483 .03 .1 r
.33345 .73609 m .33225 .73691 L .33059 .73622 L F
0 0 .229 r
.57834 .67783 m .57788 .68079 L .57805 .67867 L F
.642 .449 .606 r
.46474 .74142 m .4626 .7436 L .46231 .74124 L F
.46474 .74142 m .4626 .7436 L .46231 .74124 L F
.309 .114 .446 r
.66988 .59402 m .66909 .59632 L .67076 .59579 L F
.334 .173 .508 r
.67141 .59229 m .66988 .59402 L .67304 .59245 L F
.694 .599 .745 r
.67076 .59579 m .67304 .59245 L .66988 .59402 L F
0 0 .178 r
.30022 .73236 m .29943 .73568 L .29807 .73298 L F
.30022 .73236 m .30008 .73474 L .29943 .73568 L F
.565 .933 .92 r
.29943 .73568 m .30008 .73474 L .2979 .73575 L F
.879 .665 .609 r
.47293 .77376 m .47564 .77412 L .47455 .77268 L F
.47293 .77376 m .47518 .77671 L .47564 .77412 L F
0 0 0 r
.32033 .66438 m .3217 .66393 L .32315 .66217 L F
.187 0 0 r
.32315 .66217 m .32371 .66325 L .32514 .66165 L F
.32315 .66217 m .3217 .66393 L .32371 .66325 L F
.67 .214 .161 r
.48647 .7842 m .48536 .78458 L .48309 .78351 L F
.28 0 0 r
.48887 .78407 m .48536 .78458 L .48647 .7842 L F
0 0 .318 r
.73037 .60135 m .73148 .60443 L .73135 .60464 L F
0 0 .413 r
.73148 .60443 m .73226 .60595 L .73135 .60464 L F
.71 .559 .681 r
.59425 .71705 m .59407 .71927 L .59629 .71658 L F
.631 .447 .616 r
.59407 .71927 m .5964 .71908 L .59629 .71658 L F
.586 .422 .627 r
.59629 .71658 m .59875 .71626 L .59848 .71379 L F
.525 .366 .607 r
.59629 .71658 m .59868 .7186 L .59875 .71626 L F
.59629 .71658 m .5964 .71908 L .59868 .7186 L F
.441 .174 .411 r
.5186 .73829 m .51617 .74094 L .515 .73798 L F
.5186 .73829 m .51807 .74129 L .51617 .74094 L F
.347 .794 .955 r
.52251 .73792 m .52079 .73764 L .5186 .73829 L F
.599 .89 .99 r
.521 .73716 m .52049 .73759 L .52251 .73792 L F
.985 .788 .558 r
.52304 .73955 m .52157 .73923 L .52295 .73652 L F
.607 .229 .3 r
.52305 .73901 m .52298 .73737 L .52157 .73923 L F
.52298 .73737 m .52295 .73652 L .52248 .73743 L F
.52298 .73737 m .52248 .73743 L .52157 .73923 L F
.347 .794 .955 r
.52079 .73764 m .52049 .73759 L .52026 .7377 L F
.389 .228 .539 r
.51996 .73884 m .52084 .73742 L .52049 .73759 L F
.52084 .73742 m .521 .73716 L .52049 .73759 L F
.347 .794 .955 r
.52026 .7377 m .52049 .73759 L .52016 .73772 L F
.52079 .73764 m .52016 .73772 L .5186 .73829 L F
.074 0 .279 r
.51996 .73884 m .5186 .73829 L .52049 .73759 L F
.338 .105 .406 r
.51823 .73976 m .52024 .73783 L .51594 .73671 L F
.52024 .73783 m .52049 .73759 L .52042 .73758 L F
.52024 .73783 m .52042 .73758 L .51594 .73671 L F
.074 0 .279 r
.51996 .73884 m .51807 .74129 L .51816 .74079 L F
.51963 .73871 m .51816 .74079 L .5186 .73829 L F
.51996 .73884 m .51816 .74079 L .51963 .73871 L F
.507 .064 .131 r
.47067 .78324 m .47436 .7818 L .47312 .78327 L F
.47067 .78324 m .47107 .78245 L .47436 .7818 L F
.564 .09 .088 r
.47436 .7818 m .47514 .78363 L .47312 .78327 L F
.47436 .7818 m .47628 .78228 L .47514 .78363 L F
.595 .457 .663 r
.60784 .71812 m .6086 .7216 L .60611 .72186 L F
.532 .387 .629 r
.60821 .72439 m .60611 .72186 L .6086 .7216 L F
.60821 .72439 m .60634 .72503 L .60611 .72186 L F
.07 0 .001 r
.58613 .66072 m .58686 .65961 L .58424 .66185 L F
.308 0 .216 r
.58613 .66072 m .58875 .65877 L .58686 .65961 L F
.439 0 0 r
.73029 .62774 m .72959 .62791 L .72935 .62586 L F
.73029 .62774 m .73469 .62947 L .72959 .62791 L F
.43 .382 .703 r
.60808 .73454 m .60605 .73595 L .60569 .73283 L F
.524 .474 .743 r
.60808 .73454 m .60661 .73846 L .60605 .73595 L F
.382 .003 .189 r
.54583 .78471 m .54349 .78669 L .54296 .78652 L F
.54583 .78471 m .54492 .78681 L .54282 .78726 L F
.413 .296 .609 r
.54634 .78538 m .54584 .78588 L .54437 .78432 L F
.54584 .78588 m .54492 .78681 L .54479 .78624 L F
.54584 .78588 m .54479 .78624 L .54437 .78432 L F
.382 .003 .189 r
.54349 .78669 m .54282 .78726 L .54288 .7869 L F
.54349 .78669 m .54288 .7869 L .54296 .78652 L F
.319 0 0 r
.47953 .77776 m .47879 .77689 L .47735 .77769 L F
.47953 .77776 m .48094 .777 L .47879 .77689 L F
.729 .646 .766 r
.71795 .61008 m .71959 .61337 L .71557 .61285 L F
.415 .177 .442 r
.39045 .69746 m .39009 .69955 L .38807 .70014 L F
.41 .205 .487 r
.38939 .70221 m .38807 .70014 L .39009 .69955 L F
.38939 .70221 m .38777 .7024 L .38807 .70014 L F
.609 .039 0 r
.55219 .6919 m .55453 .69331 L .55581 .69344 L F
.239 .752 .859 r
.55453 .69331 m .55588 .69313 L .55581 .69344 L F
.579 .895 .626 r
.55581 .69344 m .55575 .69369 L .55706 .6925 L F
.486 .082 .2 r
.55905 .69187 m .55581 .69344 L .55706 .6925 L F
.55905 .69187 m .55829 .69348 L .55581 .69344 L F
0 0 .448 r
.55581 .69344 m .5572 .69296 L .55705 .69003 L F
.239 .752 .859 r
.55588 .69313 m .5572 .69296 L .55581 .69344 L F
.579 .895 .626 r
.55581 .69344 m .55438 .69493 L .55575 .69369 L F
0 0 .035 r
.58175 .70969 m .58056 .71088 L .58144 .70877 L F
.58175 .70969 m .58144 .70877 L .57974 .70747 L F
.467 .222 .458 r
.39183 .69892 m .39045 .69746 L .39235 .69688 L F
.39183 .69892 m .39009 .69955 L .39045 .69746 L F
.585 .428 .636 r
.40908 .74378 m .41146 .74351 L .41118 .74101 L F
.517 .376 .629 r
.40908 .74378 m .41125 .74574 L .41146 .74351 L F
.40908 .74378 m .40932 .74627 L .41125 .74574 L F
.432 .755 .995 r
.27232 .59536 m .27185 .59651 L .27032 .59572 L F
.27232 .59536 m .27378 .59632 L .27185 .59651 L F
.599 .396 .578 r
.38912 .68079 m .39142 .67817 L .38913 .6784 L F
.548 .114 .169 r
.53838 .73911 m .54416 .73822 L .54194 .74134 L F
.016 .59 .725 r
.54438 .74275 m .54164 .74275 L .54194 .74134 L F
.626 .734 .925 r
.69399 .5941 m .69172 .59497 L .69083 .59321 L F
.542 0 0 r
.43258 .76293 m .43627 .76398 L .43599 .76327 L F
.645 .092 0 r
.43627 .76398 m .43636 .7635 L .43599 .76327 L F
.738 .669 .117 r
.43635 .76281 m .43627 .76398 L .43425 .76265 L F
.43635 .76281 m .43617 .76448 L .43627 .76398 L F
.43617 .76448 m .43616 .76451 L .43627 .76398 L F
.645 .092 0 r
.43627 .76398 m .43894 .76509 L .43636 .7635 L F
.68 .877 .972 r
.73037 .60135 m .72771 .60235 L .72688 .60147 L F
.843 .474 .355 r
.60292 .66434 m .60172 .66586 L .6015 .66403 L F
.60292 .66434 m .60447 .66702 L .60172 .66586 L F
.825 .618 .624 r
.61141 .66752 m .60805 .66939 L .60791 .66704 L F
.61141 .66752 m .61122 .66993 L .60805 .66939 L F
.479 .741 .986 r
.28105 .61167 m .28143 .61041 L .27957 .60972 L F
.28105 .61167 m .2832 .61156 L .28143 .61041 L F
.702 .46 .555 r
.6077 .65316 m .61047 .65372 L .61048 .65104 L F
.486 .178 .369 r
.61047 .65372 m .61314 .65102 L .61048 .65104 L F
.662 .117 0 r
.67142 .61302 m .67377 .61447 L .67217 .6143 L F
.67142 .61302 m .67217 .6143 L .67174 .61158 L F
.389 .457 .809 r
.32965 .82284 m .32752 .82542 L .3295 .82528 L F
.654 .425 .56 r
.46989 .7491 m .46606 .74951 L .46812 .74856 L F
.46989 .7491 m .46711 .75146 L .46606 .74951 L F
.734 .52 .603 r
.4668 .74999 m .4672 .74974 L .46812 .74856 L F
.952 .674 .473 r
.46989 .7491 m .46812 .74856 L .46942 .7469 L F
.46942 .7469 m .46812 .74856 L .46935 .74656 L F
.076 .103 .586 r
.47059 .74824 m .46989 .7491 L .46935 .74656 L F
.632 .235 .273 r
.46935 .74656 m .46812 .74856 L .47059 .74824 L F
.538 .892 .978 r
.47059 .74824 m .46812 .74856 L .47018 .74784 L F
.734 .52 .603 r
.4672 .74974 m .47018 .74784 L .46812 .74856 L F
.602 .746 .946 r
.39846 .80334 m .39967 .80459 L .40223 .80397 L F
.39846 .80334 m .39967 .80459 L .40223 .80397 L F
.366 .581 .925 r
.3077 .60464 m .30422 .60241 L .30632 .60209 L F
.486 .582 .876 r
.30958 .60447 m .3077 .60464 L .30632 .60209 L F
.777 .545 .584 r
.59082 .71652 m .59407 .71927 L .59425 .71705 L F
.585 .449 .662 r
.33113 .70286 m .32847 .69964 L .33053 .699 L F
.33113 .70286 m .32889 .7034 L .32847 .69964 L F
.565 .719 .945 r
.73544 .5993 m .73733 .59749 L .73399 .59619 L F
.73544 .5993 m .73774 .59896 L .73733 .59749 L F
.647 .544 .723 r
.42931 .75994 m .42729 .76227 L .42716 .76058 L F
.602 .477 .683 r
.42943 .7616 m .42729 .76227 L .42931 .75994 L F
.112 0 0 r
.3647 .71828 m .36625 .71666 L .36815 .716 L F
.589 .204 .282 r
.45885 .72907 m .46106 .72938 L .46234 .72732 L F
.518 .128 .241 r
.46106 .72938 m .46459 .72726 L .46234 .72732 L F
.548 .114 .169 r
.53838 .73911 m .54357 .74043 L .54416 .73822 L F
.259 .061 .411 r
.54416 .73822 m .54611 .73532 L .545 .73663 L F
.54416 .73822 m .5459 .73824 L .54611 .73532 L F
.38 0 .123 r
.54416 .73822 m .54508 .7396 L .5459 .73824 L F
.54416 .73822 m .54357 .74043 L .54508 .7396 L F
0 0 .474 r
.66631 .59947 m .66734 .60175 L .66625 .59845 L F
.646 .388 .515 r
.48162 .74087 m .47916 .74304 L .47971 .74156 L F
.442 .205 .457 r
.31006 .61566 m .30961 .6177 L .30771 .61829 L F
.436 .193 .446 r
.31197 .61512 m .30961 .6177 L .31006 .61566 L F
.304 0 .044 r
.56184 .67753 m .56358 .67776 L .56464 .67598 L F
.088 0 0 r
.56464 .67598 m .56565 .67673 L .5667 .67512 L F
.56464 .67598 m .56358 .67776 L .56565 .67673 L F
.583 .279 .418 r
.44543 .73202 m .44808 .73031 L .44582 .73039 L F
.777 .94 .933 r
.70478 .57876 m .70322 .58021 L .70399 .57809 L F
.993 .762 .479 r
.70322 .58021 m .70209 .57974 L .70399 .57809 L F
.70322 .58021 m .703 .5826 L .70209 .57974 L F
.593 .516 .737 r
.2989 .69469 m .30109 .69433 L .30069 .69219 L F
.544 .406 .643 r
.2989 .69469 m .30116 .69683 L .30109 .69433 L F
.2989 .69469 m .29912 .69732 L .30116 .69683 L F
.787 .777 .843 r
.50056 .72174 m .50435 .72031 L .5024 .72121 L F
.072 .298 .782 r
.52501 .70921 m .52322 .70898 L .52261 .70743 L F
.52501 .70921 m .52535 .71088 L .52322 .70898 L F
.911 .897 .801 r
.57786 .6831 m .576 .6852 L .57855 .68404 L F
.375 .402 .761 r
.55581 .69344 m .55553 .69663 L .55438 .69493 L F
.737 .684 .8 r
.66862 .605 m .66875 .60703 L .67078 .60424 L F
.214 .434 .858 r
.31191 .73163 m .31293 .73259 L .31154 .733 L F
.57 .411 .627 r
.31304 .73281 m .31259 .73516 L .31045 .73408 L F
.776 .654 .728 r
.31558 .73251 m .31259 .73516 L .31304 .73281 L F
.408 0 0 r
.31154 .733 m .31558 .73251 L .31304 .73281 L F
.57 .411 .627 r
.31304 .73281 m .31145 .73359 L .31189 .73329 L F
.31304 .73281 m .3088 .73457 L .31154 .733 L F
.408 0 0 r
.3143 .73267 m .31417 .73375 L .31558 .73251 L F
.31154 .733 m .31337 .73353 L .3143 .73267 L F
.31337 .73353 m .31417 .73375 L .3143 .73267 L F
.214 .434 .858 r
.31271 .73273 m .31417 .73375 L .31209 .73316 L F
.31293 .73259 m .3135 .73312 L .31271 .73273 L F
.3135 .73312 m .31417 .73375 L .31271 .73273 L F
.776 .654 .728 r
.31558 .73251 m .31634 .73557 L .31259 .73516 L F
.483 .364 .642 r
.31323 .73398 m .31548 .73422 L .31543 .73408 L F
.998 .842 .515 r
.31558 .73251 m .31417 .73375 L .31427 .73103 L F
.651 .546 .722 r
.31427 .73103 m .31417 .73375 L .31191 .73163 L F
.483 .364 .642 r
.31353 .73314 m .31543 .73408 L .31427 .73103 L F
.31323 .73398 m .31543 .73408 L .31353 .73314 L F
.214 .434 .858 r
.31293 .73259 m .31209 .73316 L .31154 .733 L F
.932 .577 .328 r
.3117 .73327 m .313 .73387 L .31191 .73163 L F
.313 .73387 m .31323 .73398 L .31311 .73377 L F
.313 .73387 m .31311 .73377 L .31191 .73163 L F
.57 .411 .627 r
.31189 .73329 m .31045 .73408 L .3088 .73457 L F
.31145 .73359 m .31045 .73408 L .31189 .73329 L F
.526 0 0 r
.4787 .78335 m .47975 .78252 L .48219 .78353 L F
.782 .569 .611 r
.62651 .65299 m .62978 .65108 L .62663 .65059 L F
.62651 .65299 m .62976 .65334 L .62978 .65108 L F
.562 .331 .523 r
.43703 .75469 m .43903 .75665 L .43682 .75681 L F
.045 0 0 r
.58424 .66185 m .58504 .66251 L .58613 .66072 L F
.58424 .66185 m .5831 .66331 L .58504 .66251 L F
.425 .147 .386 r
.40414 .68596 m .40166 .68868 L .40207 .68632 L F
.74 .534 .615 r
.62015 .64743 m .62325 .6456 L .61997 .64547 L F
.62015 .64743 m .62331 .64801 L .62325 .6456 L F
.402 .384 .725 r
.60732 .73093 m .60808 .73454 L .60569 .73283 L F
.584 .455 .672 r
.29508 .70297 m .29761 .70527 L .29717 .70248 L F
.29508 .70297 m .29538 .70573 L .29761 .70527 L F
.764 .629 .71 r
.52639 .73564 m .52396 .73831 L .52406 .73566 L F
.11 0 0 r
.48981 .77847 m .49193 .77861 L .49342 .77857 L F
.119 0 0 r
.49193 .77861 m .49551 .77872 L .49342 .77857 L F
.242 0 0 r
.73399 .59619 m .73349 .59756 L .73119 .59802 L F
.188 .716 .847 r
.73733 .59749 m .73349 .59756 L .73399 .59619 L F
.38 .493 .849 r
.30361 .73804 m .30294 .73926 L .30418 .73908 L F
.486 .178 .369 r
.61047 .65372 m .61263 .65341 L .61314 .65102 L F
.311 .242 .616 r
.61314 .65102 m .61396 .64785 L .6122 .64817 L F
.61314 .65102 m .61395 .65033 L .61396 .64785 L F
.545 .312 .513 r
.61263 .65341 m .61395 .65033 L .61314 .65102 L F
0 .085 .626 r
.73614 .58726 m .73464 .58614 L .73366 .5854 L F
.73614 .58726 m .73612 .58773 L .73464 .58614 L F
.377 .206 .517 r
.29884 .63641 m .29744 .6347 L .29874 .63404 L F
.29884 .63641 m .29721 .63708 L .29744 .6347 L F
.518 .306 .531 r
.33635 .68587 m .33345 .68855 L .33433 .68653 L F
.488 .307 .561 r
.38053 .69441 m .38262 .69143 L .38087 .69203 L F
.452 .107 .289 r
.38105 .70848 m .37809 .71026 L .37871 .70894 L F
.169 0 0 r
.34862 .64888 m .34914 .64972 L .35057 .64805 L F
.34862 .64888 m .34712 .65029 L .34914 .64972 L F
0 0 .505 r
.57909 .75693 m .57803 .75382 L .57865 .75485 L F
.6 .592 .815 r
.703 .5826 m .70068 .5833 L .69935 .58005 L F
0 0 0 r
.59014 .66902 m .58864 .66968 L .5914 .66763 L F
.015 0 0 r
.5921 .66823 m .5914 .66763 L .59324 .66652 L F
.5921 .66823 m .59014 .66902 L .5914 .66763 L F
.8 .564 .58 r
.58757 .71809 m .59082 .71652 L .58922 .7159 L F
.58757 .71809 m .59089 .71896 L .59082 .71652 L F
.777 .545 .584 r
.59082 .71652 m .59089 .71896 L .59407 .71927 L F
.482 .277 .524 r
.30961 .6177 m .30745 .62042 L .30771 .61829 L F
.711 .972 .929 r
.72875 .61211 m .73249 .6106 L .73137 .60957 L F
.515 .275 .488 r
.61068 .71617 m .6106 .71802 L .60784 .71812 L F
.567 .438 .665 r
.60936 .72059 m .60784 .71812 L .6106 .71802 L F
.60936 .72059 m .6086 .7216 L .60784 .71812 L F
.992 .735 .407 r
.71227 .61241 m .71329 .61551 L .71232 .61508 L F
.985 .706 .368 r
.71329 .61551 m .71342 .61791 L .71232 .61508 L F
.757 .686 .782 r
.71557 .61285 m .71329 .61551 L .71227 .61241 L F
.559 .41 .636 r
.40175 .76263 m .40395 .7624 L .40379 .75995 L F
.509 .378 .638 r
.40212 .7656 m .40395 .7624 L .40175 .76263 L F
.534 .365 .598 r
.59848 .71379 m .60068 .71336 L .60063 .71096 L F
.521 .324 .553 r
.59848 .71379 m .60051 .71563 L .60068 .71336 L F
.452 .325 .617 r
.59848 .71379 m .59875 .71626 L .60051 .71563 L F
.292 .767 .655 r
.52115 .79174 m .52034 .79209 L .51908 .79266 L F
0 0 0 r
.52034 .79209 m .51689 .794 L .51908 .79266 L F
.512 .247 .45 r
.37791 .69672 m .38053 .69441 L .3785 .69499 L F
.097 .533 .909 r
.703 .60754 m .7046 .60739 L .70399 .6064 L F
.703 .60754 m .70562 .60833 L .7046 .60739 L F
.324 .279 .653 r
.67408 .60471 m .6747 .60726 L .67554 .60626 L F
.714 .276 .209 r
.67554 .60626 m .67312 .60613 L .67408 .60471 L F
0 0 0 r
.67408 .60471 m .67312 .60613 L .67415 .6048 L F
.569 .305 .477 r
.67408 .60471 m .67554 .60626 L .67678 .60454 L F
.256 .265 .678 r
.67408 .60471 m .67554 .60626 L .67548 .60467 L F
.67517 .60344 m .67548 .60467 L .67543 .60314 L F
.67408 .60471 m .67548 .60467 L .67517 .60344 L F
0 0 0 r
.67517 .60344 m .67511 .60355 L .67543 .60314 L F
.67408 .60471 m .6749 .60379 L .67517 .60344 L F
.6749 .60379 m .67511 .60355 L .67517 .60344 L F
0 0 .406 r
.67521 .60043 m .6749 .60379 L .67408 .60471 L F
.704 .553 .681 r
.67351 .60192 m .67453 .60426 L .67499 .60278 L F
0 0 .406 r
.6749 .60379 m .6748 .60488 L .67408 .60471 L F
.704 .553 .681 r
.67453 .60426 m .6748 .60488 L .6749 .60379 L F
.67453 .60426 m .6749 .60379 L .67499 .60278 L F
.67454 .60102 m .67499 .60278 L .67521 .60043 L F
.67351 .60192 m .67499 .60278 L .67454 .60102 L F
.152 0 0 r
.67408 .60471 m .67413 .60477 L .67078 .60424 L F
.6 .503 .716 r
.67078 .60424 m .67413 .60477 L .67351 .60192 L F
.152 0 0 r
.67408 .60471 m .6748 .60488 L .67413 .60477 L F
.6 .503 .716 r
.67413 .60477 m .6748 .60488 L .67453 .60426 L F
0 0 0 r
.67408 .60471 m .67413 .60477 L .675 .60367 L F
.6 .503 .716 r
.67413 .60477 m .67453 .60426 L .67351 .60192 L F
0 0 0 r
.675 .60367 m .67415 .6048 L .67511 .60355 L F
.67413 .60477 m .67415 .6048 L .675 .60367 L F
.814 .64 .667 r
.63077 .65905 m .63224 .6593 L .63128 .65628 L F
.812 .582 .589 r
.62955 .66124 m .63224 .6593 L .63077 .65905 L F
.62955 .66124 m .63253 .6618 L .63224 .6593 L F
.643 .459 .62 r
.63253 .6618 m .63461 .65907 L .63224 .6593 L F
.535 .657 .914 r
.30632 .60209 m .30422 .60241 L .30323 .60082 L F
.759 .703 .799 r
.57456 .71521 m .57278 .71425 L .57592 .71392 L F
.358 .037 .277 r
.57803 .71298 m .57456 .71521 L .57592 .71392 L F
.57803 .71298 m .57743 .7154 L .57456 .71521 L F
.374 .15 .44 r
.57743 .7154 m .57535 .71781 L .57456 .71521 L F
.773 .722 .804 r
.31814 .80484 m .32001 .80656 L .3169 .80655 L F
.234 .742 .887 r
.32001 .80656 m .31906 .80631 L .3169 .80655 L F
.327 .587 .938 r
.31998 .80546 m .32001 .80656 L .31814 .80484 L F
.872 .987 .83 r
.31998 .80546 m .31906 .80631 L .32001 .80656 L F
.311 .249 .624 r
.31582 .6061 m .31592 .60991 L .31455 .61018 L F
.41 .25 .551 r
.31592 .60991 m .31417 .61227 L .31455 .61018 L F
.02 0 .159 r
.62455 .69142 m .62404 .69364 L .62228 .69456 L F
.091 0 .309 r
.62404 .69364 m .62253 .69643 L .62228 .69456 L F
.317 0 .151 r
.28356 .65089 m .28425 .65251 L .28227 .65298 L F
.28356 .65089 m .2854 .65044 L .28425 .65251 L F
0 .112 .595 r
.73274 .58453 m .73152 .58365 L .73056 .5828 L F
.73274 .58453 m .73366 .5854 L .73152 .58365 L F
.718 .766 .891 r
.69949 .59534 m .70081 .59666 L .69754 .5964 L F
.798 .777 .834 r
.70334 .59408 m .70081 .59666 L .69949 .59534 L F
.576 .221 .33 r
.68825 .58007 m .69065 .5816 L .6913 .57923 L F
.591 .235 .334 r
.6913 .57923 m .69292 .58141 L .69388 .5792 L F
.6913 .57923 m .69065 .5816 L .69292 .58141 L F
.696 .56 .697 r
.44141 .74917 m .44161 .75201 L .43922 .75198 L F
.447 .37 .676 r
.4436 .75131 m .44141 .74917 L .44361 .74887 L F
.4436 .75131 m .44161 .75201 L .44141 .74917 L F
.746 .792 .89 r
.72106 .60134 m .7181 .60397 L .71795 .60111 L F
.948 .894 .741 r
.63033 .67826 m .63169 .67528 L .63082 .67472 L F
.318 0 0 r
.34033 .72919 m .33956 .72983 L .33718 .72992 L F
0 0 0 r
.34122 .72884 m .34033 .72919 L .34298 .72796 L F
.34122 .72884 m .33956 .72983 L .34033 .72919 L F
0 .116 .668 r
.73412 .71282 m .73614 .7161 L .73512 .71364 L F
.575 .215 .32 r
.36222 .70684 m .3656 .70486 L .36365 .70546 L F
.21 .355 .792 r
.73977 .59158 m .73939 .59388 L .73938 .59232 L F
.822 .497 0 r
.73946 .59502 m .73939 .59388 L .73977 .59158 L F
.73946 .59502 m .74 .59605 L .73939 .59388 L F
.107 .121 .591 r
.51963 .72493 m .51927 .72583 L .5182 .7245 L F
.51963 .72493 m .52059 .7261 L .51927 .72583 L F
.721 .348 .342 r
.52026 .72883 m .51927 .72583 L .52059 .7261 L F
.52026 .72883 m .51689 .72865 L .51927 .72583 L F
.047 0 0 r
.44845 .78579 m .45199 .78471 L .44975 .78579 L F
.268 0 0 r
.45425 .78471 m .44975 .78579 L .45199 .78471 L F
.428 0 0 r
.57785 .72366 m .57995 .72469 L .58096 .72493 L F
0 0 .047 r
.58096 .72493 m .58133 .7248 L .58223 .72142 L F
.45 .149 .362 r
.58096 .72493 m .58326 .72453 L .58133 .7248 L F
.58096 .72493 m .58039 .72666 L .58326 .72453 L F
.58326 .72453 m .58039 .72666 L .58096 .72493 L F
.998 .797 .507 r
.57995 .72469 m .58039 .72666 L .58096 .72493 L F
.57995 .72469 m .58039 .72666 L .58096 .72493 L F
.006 .552 .833 r
.37959 .65106 m .38193 .65149 L .38314 .65196 L F
.37 .794 .973 r
.38314 .65196 m .38393 .65114 L .38526 .65172 L F
.38314 .65196 m .38193 .65149 L .38393 .65114 L F
.537 .407 .651 r
.40344 .75748 m .40574 .75952 L .40546 .75708 L F
.516 .407 .669 r
.40344 .75748 m .40379 .75995 L .40574 .75952 L F
0 .541 .719 r
.74104 .59923 m .7407 .59919 L .73774 .59896 L F
.271 .366 .778 r
.74 .59605 m .74241 .59787 L .74104 .59923 L F
.583 .93 .746 r
.74104 .59923 m .7407 .59919 L .74241 .59787 L F
.275 0 0 r
.44604 .77561 m .44819 .77526 L .44962 .77382 L F
.509 .106 .213 r
.44819 .77526 m .45171 .77335 L .44962 .77382 L F
.488 .863 .643 r
.50125 .71104 m .50232 .7101 L .50372 .70924 L F
.491 .869 .66 r
.50125 .71104 m .49927 .71224 L .50232 .7101 L F
.577 .409 .618 r
.30034 .68951 m .30284 .69147 L .30236 .68869 L F
.30034 .68951 m .30069 .69219 L .30284 .69147 L F
.035 .231 .734 r
.5625 .71946 m .56333 .71856 L .56125 .71638 L F
.112 .402 .854 r
.5625 .71946 m .56528 .72042 L .56333 .71856 L F
.5625 .71946 m .56531 .72129 L .56528 .72042 L F
.644 .479 .645 r
.29384 .71102 m .29667 .71113 L .29613 .70855 L F
.644 .583 .772 r
.29613 .70855 m .29761 .70527 L .29538 .70573 L F
.29613 .70855 m .29857 .70835 L .29761 .70527 L F
.697 .513 .635 r
.29613 .70855 m .29931 .71084 L .29857 .70835 L F
.29613 .70855 m .29667 .71113 L .29931 .71084 L F
.601 .423 .613 r
.68242 .59107 m .68313 .59327 L .68014 .59356 L F
.536 .215 .37 r
.68014 .59356 m .68168 .59516 L .67966 .59527 L F
.68014 .59356 m .68313 .59327 L .68168 .59516 L F
.27 0 0 r
.36186 .64839 m .36394 .64803 L .36517 .64683 L F
.1 0 0 r
.36394 .64803 m .36715 .64725 L .36517 .64683 L F
.719 .484 .569 r
.61777 .64791 m .61997 .64547 L .61768 .6455 L F
.61777 .64791 m .62015 .64743 L .61997 .64547 L F
.553 .896 .663 r
.50372 .70924 m .50378 .70886 L .50567 .70799 L F
.50372 .70924 m .50232 .7101 L .50378 .70886 L F
.714 .757 .886 r
.71895 .61763 m .72224 .61805 L .7209 .61616 L F
.694 .73 .878 r
.7209 .61616 m .72224 .61805 L .72427 .61598 L F
.548 .384 .61 r
.40004 .76831 m .40232 .76794 L .40212 .7656 L F
.554 .381 .6 r
.39977 .77081 m .40232 .76794 L .40004 .76831 L F
0 .362 .743 r
.53249 .71842 m .53219 .71848 L .52989 .71666 L F
.53249 .71842 m .53384 .71919 L .53219 .71848 L F
.372 .139 .426 r
.41146 .74351 m .41346 .74095 L .41118 .74101 L F
.82 .66 .684 r
.62804 .65599 m .63128 .65628 L .62976 .65334 L F
.821 .647 .667 r
.63077 .65905 m .63128 .65628 L .62804 .65599 L F
.62 .61 .819 r
.59089 .71896 m .5943 .72162 L .59407 .71927 L F
.443 .333 .634 r
.5943 .72162 m .59613 .72127 L .59407 .71927 L F
.601 .332 .482 r
.59407 .71927 m .59613 .72127 L .5964 .71908 L F
.443 .333 .634 r
.5943 .72162 m .59613 .72127 L .59407 .71927 L F
.617 .589 .799 r
.33113 .70286 m .32912 .7048 L .32889 .7034 L F
.626 .653 .857 r
.33243 .70576 m .32912 .7048 L .33113 .70286 L F
.717 .838 .939 r
.72587 .72639 m .72281 .72628 L .72464 .7257 L F
.889 .917 .837 r
.72739 .7241 m .72587 .72639 L .72464 .7257 L F
.535 0 0 r
.48309 .78351 m .48536 .78458 L .48219 .78353 L F
.038 0 0 r
.36233 .67325 m .3607 .6738 L .35848 .67411 L F
.338 0 0 r
.3644 .67268 m .3607 .6738 L .36233 .67325 L F
0 .462 .799 r
.50311 .78513 m .50192 .78496 L .50074 .78436 L F
.402 0 0 r
.50591 .78605 m .50373 .78465 L .50192 .78496 L F
0 .462 .799 r
.50591 .78605 m .50192 .78496 L .50311 .78513 L F
.114 0 0 r
.50154 .7849 m .50192 .78496 L .50373 .78465 L F
.50088 .78498 m .50192 .78496 L .50154 .7849 L F
.402 0 0 r
.50591 .78605 m .50614 .78602 L .50373 .78465 L F
.423 .707 .982 r
.53612 .71814 m .53817 .71808 L .53711 .7192 L F
.982 .753 .514 r
.53817 .71808 m .53916 .72127 L .53711 .7192 L F
.303 .441 .835 r
.73804 .58955 m .73938 .59232 L .737 .59086 L F
.754 .882 .937 r
.7091 .61043 m .71222 .6091 L .71102 .60715 L F
.774 .781 .859 r
.71222 .6091 m .71438 .60752 L .71102 .60715 L F
.486 .584 .878 r
.72164 .72383 m .72013 .72571 L .71977 .72367 L F
.72164 .72383 m .72281 .72628 L .72013 .72571 L F
.67 .122 0 r
.53916 .72127 m .54268 .7239 L .54011 .7224 L F
.575 .505 .74 r
.33243 .69681 m .3306 .69718 L .33002 .6948 L F
.546 .364 .586 r
.33243 .69681 m .33053 .699 L .3306 .69718 L F
.543 .28 .467 r
.48385 .73576 m .48361 .73792 L .48126 .73834 L F
.593 .323 .477 r
.48385 .73576 m .48589 .73757 L .48361 .73792 L F
.561 .33 .521 r
.48613 .73535 m .48589 .73757 L .48385 .73576 L F
.653 .416 .548 r
.61396 .64785 m .61777 .64791 L .61768 .6455 L F
.621 .562 .766 r
.68398 .58771 m .68509 .5906 L .68242 .59107 L F
.707 .573 .703 r
.68509 .5906 m .68313 .59327 L .68242 .59107 L F
.885 .62 .533 r
.59755 .72993 m .59538 .72949 L .59525 .7271 L F
.982 .75 .509 r
.59641 .73256 m .59538 .72949 L .59755 .72993 L F
.691 .221 .13 r
.55696 .69701 m .55729 .69788 L .55785 .69725 L F
0 .473 .817 r
.55768 .69817 m .55704 .69787 L .55814 .69573 L F
.55704 .69787 m .55695 .69783 L .55702 .69771 L F
.55704 .69787 m .55702 .69771 L .55814 .69573 L F
.691 .221 .13 r
.55592 .69674 m .55702 .69765 L .55696 .69701 L F
.55702 .69765 m .55729 .69788 L .55696 .69701 L F
.55553 .69663 m .55689 .6976 L .55592 .69674 L F
.55689 .6976 m .55729 .69788 L .55592 .69674 L F
.214 .289 .726 r
.55814 .69573 m .55702 .69771 L .55581 .69344 L F
.55702 .69771 m .55695 .69783 L .55689 .6976 L F
.55702 .69771 m .55689 .6976 L .55581 .69344 L F
.375 .402 .761 r
.55581 .69344 m .55689 .6976 L .55553 .69663 L F
.55689 .6976 m .55695 .69783 L .55553 .69663 L F
.711 .178 0 r
.55553 .69663 m .55695 .69783 L .55697 .69824 L F
.691 .221 .13 r
.55553 .69663 m .55697 .69824 L .55729 .69788 L F
.966 .65 .363 r
.55912 .6989 m .55785 .69725 L .55697 .69824 L F
.55912 .6989 m .5597 .6971 L .55785 .69725 L F
.518 .664 .928 r
.47603 .74228 m .47711 .74374 L .47916 .74304 L F
.912 .668 .557 r
.63096 .66944 m .63275 .66742 L .63074 .66673 L F
.63096 .66944 m .63289 .66936 L .63275 .66742 L F
.624 .463 .644 r
.39166 .77981 m .39589 .78118 L .39519 .77751 L F
.526 0 0 r
.31634 .73557 m .31508 .73597 L .31259 .73516 L F
.582 .568 .803 r
.31687 .73201 m .31634 .73557 L .31558 .73251 L F
.31687 .73201 m .31858 .73527 L .31634 .73557 L F
.711 .178 0 r
.31634 .73557 m .31656 .73675 L .31508 .73597 L F
.726 .197 0 r
.67377 .61447 m .67579 .61587 L .67487 .61558 L F
.066 .471 .888 r
.67579 .61587 m .67766 .61617 L .67487 .61558 L F
.67579 .61587 m .67874 .61721 L .67766 .61617 L F
.645 .586 .773 r
.67579 .61587 m .67995 .61849 L .67874 .61721 L F
.494 .345 .608 r
.28249 .6204 m .2845 .62015 L .28451 .61792 L F
.504 .384 .649 r
.28249 .6204 m .28462 .62303 L .2845 .62015 L F
.28249 .6204 m .28277 .62361 L .28462 .62303 L F
.405 0 .048 r
.47757 .72609 m .47589 .72543 L .47547 .72613 L F
.402 .272 .588 r
.58039 .72666 m .58042 .72955 L .57879 .7274 L F
.6 .776 .964 r
.35404 .64872 m .35057 .64805 L .35264 .64804 L F
.153 .672 .887 r
.35264 .64804 m .356 .64847 L .35404 .64872 L F
.752 .755 .855 r
.72427 .61598 m .72807 .61657 L .72696 .6152 L F
.744 .799 .896 r
.72696 .6152 m .72807 .61657 L .73031 .61528 L F
.524 .474 .743 r
.60808 .73454 m .60863 .73831 L .60661 .73846 L F
.427 .479 .811 r
.60953 .74006 m .60661 .73846 L .60863 .73831 L F
.445 0 0 r
.73819 .71759 m .73747 .717 L .73614 .7161 L F
.73819 .71759 m .73993 .71881 L .73747 .717 L F
.557 .193 .307 r
.49815 .73492 m .4947 .73687 L .49502 .7358 L F
.49815 .73492 m .49695 .73732 L .4947 .73687 L F
.486 .121 .271 r
.49915 .73697 m .49815 .73492 L .50042 .73528 L F
.49915 .73697 m .49695 .73732 L .49815 .73492 L F
.251 0 0 r
.35622 .6749 m .35273 .67695 L .3543 .67511 L F
.376 .193 .502 r
.4436 .75131 m .44169 .75434 L .44161 .75201 L F
0 0 0 r
.34332 .72812 m .34298 .72796 L .34499 .72746 L F
.34332 .72812 m .34122 .72884 L .34298 .72796 L F
.627 .15 .103 r
.48094 .777 m .48295 .77836 L .48417 .77724 L F
.681 .217 .146 r
.48295 .77836 m .48641 .77883 L .48417 .77724 L F
.452 .748 .992 r
.30825 .73854 m .31062 .73833 L .30898 .73733 L F
.494 .329 .586 r
.33345 .68855 m .33466 .69268 L .33187 .69195 L F
.518 .306 .531 r
.33635 .68587 m .33638 .68976 L .33345 .68855 L F
.547 .36 .58 r
.3365 .69155 m .33345 .68855 L .33638 .68976 L F
.3365 .69155 m .33466 .69268 L .33345 .68855 L F
.861 .932 .87 r
.70783 .60862 m .7091 .61043 L .71005 .6088 L F
.70783 .60862 m .71005 .6088 L .71102 .60715 L F
.7 .512 .631 r
.70783 .60862 m .71016 .60835 L .70847 .61097 L F
.70783 .60862 m .70847 .61097 L .7095 .60947 L F
.70783 .60862 m .7095 .60947 L .70701 .60855 L F
.70783 .60862 m .70701 .60855 L .70674 .60845 L F
.466 .673 .954 r
.30119 .59898 m .30126 .60084 L .29939 .59922 L F
.30119 .59898 m .30323 .60082 L .30126 .60084 L F
.866 .773 .757 r
.68148 .61273 m .68421 .61274 L .68293 .61141 L F
.92 .848 .756 r
.68136 .61487 m .68421 .61274 L .68148 .61273 L F
.68136 .61487 m .68263 .61593 L .68421 .61274 L F
.792 .775 .837 r
.68293 .61141 m .68421 .61274 L .68662 .61027 L F
.593 .611 .839 r
.33448 .70529 m .33243 .70576 L .33113 .70286 L F
.468 .851 .982 r
.51918 .72939 m .52026 .72883 L .52181 .72953 L F
.842 .632 .618 r
.51918 .72939 m .5201 .73218 L .52181 .72953 L F
.23 .004 .351 r
.28078 .62629 m .2787 .62917 L .28039 .62852 L F
.316 .151 .492 r
.2787 .62917 m .2802 .63036 L .28039 .62852 L F
.2787 .62917 m .2785 .63143 L .2802 .63036 L F
.576 .463 .688 r
.4049 .75167 m .40709 .7515 L .40673 .74889 L F
.511 .378 .636 r
.4049 .75167 m .40726 .75382 L .40709 .7515 L F
.4049 .75167 m .4052 .75526 L .40726 .75382 L F
.691 .534 .668 r
.43147 .75746 m .42931 .75994 L .42946 .75765 L F
.461 .64 .934 r
.71749 .73131 m .7181 .7333 L .71812 .73239 L F
.393 0 0 r
.356 .64847 m .35805 .64909 L .35968 .64871 L F
.156 0 0 r
.35805 .64909 m .36186 .64839 L .35968 .64871 L F
.313 .572 .932 r
.52136 .70569 m .52094 .70713 L .51883 .70574 L F
.52136 .70569 m .52261 .70743 L .52094 .70713 L F
.568 .342 .533 r
.53607 .73374 m .53178 .73277 L .53395 .73267 L F
.53607 .73374 m .53188 .73465 L .53178 .73277 L F
0 0 0 r
.41976 .66507 m .41946 .66484 L .41956 .66457 L F
.41946 .66484 m .41668 .6667 L .41976 .66507 L F
.454 .354 .652 r
.42215 .6667 m .41946 .66484 L .41976 .66507 L F
0 0 .065 r
.41956 .66457 m .41976 .66507 L .41946 .66484 L F
.512 .271 .485 r
.60763 .70326 m .60955 .70469 L .60954 .70235 L F
.60763 .70326 m .60731 .7051 L .60955 .70469 L F
.60955 .70469 m .60763 .70326 L .60954 .70235 L F
.60955 .70469 m .60731 .7051 L .60763 .70326 L F
.765 .699 .789 r
.4001 .77337 m .40185 .77632 L .40373 .77353 L F
.573 .438 .659 r
.40185 .77632 m .40402 .77634 L .40373 .77353 L F
.235 .217 .633 r
.40185 .77632 m .40356 .77832 L .40402 .77634 L F
.40185 .77632 m .40218 .77923 L .40356 .77832 L F
.582 .657 .889 r
.34753 .70516 m .34701 .7078 L .34557 .70536 L F
.34753 .70516 m .34943 .70742 L .34701 .7078 L F
.448 0 .064 r
.59154 .7605 m .59021 .762 L .58796 .76205 L F
.482 .024 .087 r
.59279 .76138 m .59021 .762 L .59154 .7605 L F
.417 .064 .256 r
.59385 .75999 m .59279 .76138 L .59154 .7605 L F
.352 .102 .389 r
.31536 .66742 m .31319 .6701 L .31505 .6695 L F
.585 .37 .555 r
.31505 .6695 m .31775 .66685 L .31536 .66742 L F
.724 .511 .603 r
.4471 .75108 m .44361 .74887 L .44705 .74916 L F
.493 .603 .891 r
.5447 .70271 m .54823 .70513 L .54726 .70384 L F
0 .114 .592 r
.54823 .70513 m .54968 .70619 L .54726 .70384 L F
0 .282 .737 r
.55083 .70721 m .55081 .70682 L .54968 .70619 L F
.365 0 0 r
.54968 .70619 m .55081 .70682 L .54996 .70636 L F
.54968 .70619 m .54996 .70636 L .54837 .70551 L F
0 .114 .592 r
.54823 .70513 m .54902 .70577 L .54968 .70619 L F
.54902 .70577 m .55083 .70721 L .54968 .70619 L F
.679 .235 .189 r
.44058 .77448 m .44378 .77531 L .44426 .77476 L F
.545 .125 .195 r
.44378 .77531 m .44604 .77561 L .44426 .77476 L F
.449 0 .054 r
.54759 .74116 m .54645 .74273 L .54438 .74275 L F
.462 .33 .615 r
.54922 .7406 m .5488 .74119 L .54759 .74116 L F
.54946 .74122 m .54946 .74277 L .54759 .74116 L F
.553 .658 .906 r
.54922 .74044 m .54759 .74116 L .5459 .73824 L F
.54851 .74084 m .54759 .74116 L .54922 .74044 L F
.69 .249 .198 r
.54966 .74294 m .54645 .74273 L .54759 .74116 L F
0 0 0 r
.54645 .74273 m .54947 .74025 L .54508 .7396 L F
.54947 .74025 m .54947 .74025 L .54947 .74025 L F
.54947 .74025 m .54947 .74025 L .54508 .7396 L F
.54645 .74273 m .54777 .74213 L .54939 .74034 L F
.54929 .7404 m .54939 .74034 L .54947 .74025 L F
.553 .658 .906 r
.5493 .74049 m .54851 .74084 L .54922 .74044 L F
.54939 .74055 m .54922 .7406 L .5493 .74049 L F
.54922 .7406 m .54851 .74084 L .5493 .74049 L F
0 0 0 r
.54645 .74273 m .54864 .74095 L .54868 .7409 L F
.54864 .74095 m .54939 .74034 L .54868 .7409 L F
.54868 .7409 m .54939 .74034 L .54929 .7404 L F
.816 .581 .583 r
.5459 .73824 m .54508 .7396 L .54947 .74025 L F
.567 .382 .59 r
.54777 .74213 m .55007 .73901 L .54955 .74008 L F
.54939 .74034 m .54955 .74008 L .54948 .74024 L F
.54777 .74213 m .54955 .74008 L .54939 .74034 L F
.54947 .74025 m .54948 .74024 L .54947 .74025 L F
.54777 .74213 m .54948 .74024 L .54947 .74025 L F
.462 .33 .615 r
.54939 .74055 m .54946 .74122 L .5488 .74119 L F
.54939 .74055 m .5488 .74119 L .54922 .7406 L F
.54946 .74122 m .54966 .74294 L .54946 .74277 L F
0 0 0 r
.71142 .71772 m .7126 .71674 L .7099 .71858 L F
.71142 .71772 m .7099 .71858 L .70899 .72022 L F
.542 .381 .612 r
.30254 .68643 m .30471 .68646 L .30462 .6835 L F
.598 .431 .627 r
.30236 .68869 m .30471 .68646 L .30254 .68643 L F
.339 0 .037 r
.56905 .68585 m .56556 .68791 L .56683 .68643 L F
.557 .216 .346 r
.33298 .82552 m .33565 .82549 L .3346 .82708 L F
.33298 .82552 m .33565 .82549 L .3346 .82708 L F
.315 0 0 r
.56377 .69861 m .56284 .69963 L .56249 .69909 L F
.515 .048 .084 r
.56585 .69934 m .56284 .69963 L .56377 .69861 L F
.361 0 .192 r
.37309 .69947 m .37504 .69943 L .3761 .6975 L F
.289 0 .152 r
.3761 .6975 m .37702 .69881 L .37791 .69672 L F
.3761 .6975 m .37504 .69943 L .37702 .69881 L F
.817 .582 .583 r
.61405 .6726 m .61127 .6723 L .61122 .66993 L F
.865 .656 .619 r
.61405 .6726 m .61137 .67456 L .61127 .6723 L F
.61405 .6726 m .61373 .67535 L .61137 .67456 L F
0 0 0 r
.51617 .74094 m .51506 .74315 L .51398 .7437 L F
.48 .361 .64 r
.33488 .73255 m .33345 .73609 L .33269 .733 L F
.575 .505 .74 r
.33243 .69681 m .33002 .6948 L .33208 .69432 L F
.408 .122 .363 r
.41639 .67318 m .41574 .675 L .41375 .67554 L F
.429 .142 .373 r
.41778 .67448 m .41639 .67318 L .41814 .67252 L F
.41778 .67448 m .41574 .675 L .41639 .67318 L F
.511 .368 .623 r
.33466 .69268 m .33208 .69432 L .33187 .69195 L F
0 .302 .796 r
.32052 .72991 m .32424 .73363 L .32366 .73291 L F
.639 .292 .366 r
.51059 .72712 m .50924 .72955 L .5072 .72909 L F
.623 .274 .357 r
.51293 .7278 m .51059 .72712 L .51321 .72626 L F
.287 0 0 r
.51672 .78478 m .51897 .78456 L .51983 .78385 L F
.274 0 0 r
.51983 .78385 m .52122 .7843 L .52227 .78342 L F
.278 0 0 r
.51897 .78456 m .52122 .7843 L .51983 .78385 L F
.478 .242 .478 r
.43147 .75746 m .43133 .7596 L .42931 .75994 L F
.43147 .75746 m .43133 .7596 L .42931 .75994 L F
.611 .352 .501 r
.43371 .75921 m .43147 .75746 L .43458 .75708 L F
.43371 .75921 m .43133 .7596 L .43147 .75746 L F
0 0 0 r
.59014 .66902 m .58766 .67143 L .58864 .66968 L F
.236 .099 .483 r
.61806 .70254 m .61809 .70487 L .61677 .70569 L F
.392 .229 .538 r
.61809 .70487 m .61644 .70781 L .61677 .70569 L F
.35 .757 .982 r
.27774 .59651 m .27719 .59741 L .27552 .59642 L F
.27774 .59651 m .27953 .59721 L .27719 .59741 L F
.279 0 .229 r
.31112 .67297 m .30848 .67538 L .31041 .67494 L F
.642 .453 .612 r
.31041 .67494 m .31279 .67223 L .31112 .67297 L F
.577 .002 0 r
.47603 .74228 m .47243 .74037 L .47396 .74067 L F
0 0 .413 r
.73148 .60443 m .73222 .60565 L .73226 .60595 L F
.98 .801 .59 r
.73031 .60858 m .73226 .60595 L .73222 .60565 L F
.73031 .60858 m .73137 .60957 L .73226 .60595 L F
.833 .845 .856 r
.39558 .80557 m .39481 .80707 L .39289 .80617 L F
.584 .546 .778 r
.59537 .73881 m .59739 .73813 L .59638 .73503 L F
.26 .276 .688 r
.57535 .71781 m .57585 .72171 L .57392 .71924 L F
.648 .551 .731 r
.60063 .71096 m .6031 .71081 L .6019 .70731 L F
.551 .326 .527 r
.60068 .71336 m .6031 .71081 L .60063 .71096 L F
.541 .347 .567 r
.71674 .60689 m .71438 .60752 L .71655 .60458 L F
.814 .798 .837 r
.67874 .61721 m .67995 .61849 L .68263 .61593 L F
.292 0 .001 r
.48093 .7237 m .4825 .72402 L .48382 .72229 L F
.098 0 0 r
.48382 .72229 m .48448 .72317 L .48571 .72149 L F
.48382 .72229 m .4825 .72402 L .48448 .72317 L F
.644 .854 .468 r
.31239 .72631 m .31164 .72755 L .31371 .72458 L F
.122 0 0 r
.31444 .72548 m .31371 .72458 L .31576 .72634 L F
.31444 .72548 m .31239 .72631 L .31371 .72458 L F
.229 .015 .367 r
.62698 .68886 m .62642 .69102 L .62455 .69142 L F
.186 0 .22 r
.62642 .69102 m .62404 .69364 L .62455 .69142 L F
0 .198 .712 r
.54588 .72499 m .54784 .72655 L .54756 .72691 L F
0 0 0 r
.67828 .58537 m .67929 .58586 L .68068 .58536 L F
.67828 .58537 m .6774 .58693 L .67929 .58586 L F
.224 0 .346 r
.61243 .71594 m .6106 .71802 L .61068 .71617 L F
.985 .724 .449 r
.6747 .60726 m .67552 .61029 L .67446 .60944 L F
.838 .69 .699 r
.51617 .74094 m .51422 .73719 L .515 .73798 L F
.51617 .74094 m .5141 .74107 L .51422 .73719 L F
.712 .381 .417 r
.5183 .74313 m .51617 .74094 L .51807 .74129 L F
.5183 .74313 m .51506 .74315 L .51617 .74094 L F
.738 .723 .837 r
.71448 .61089 m .71557 .61285 L .71227 .61241 L F
.785 .74 .812 r
.71795 .61008 m .71557 .61285 L .71448 .61089 L F
.584 .759 .962 r
.39589 .78118 m .39736 .7822 L .39942 .78159 L F
.635 .21 .218 r
.31735 .66445 m .32033 .66438 L .31761 .66413 L F
.47 .395 .689 r
.31735 .66445 m .31955 .6664 L .32033 .66438 L F
.05 0 .128 r
.32106 .66554 m .32033 .66438 L .31955 .6664 L F
.32106 .66554 m .3217 .66393 L .32033 .66438 L F
.599 .396 .578 r
.38912 .68079 m .39139 .6806 L .39142 .67817 L F
.575 .562 .801 r
.39142 .67817 m .39251 .67439 L .39048 .67474 L F
.39142 .67817 m .39372 .67766 L .39251 .67439 L F
.528 .345 .576 r
.39139 .6806 m .39372 .67766 L .39142 .67817 L F
.418 .049 .228 r
.33243 .65519 m .33432 .65555 L .33518 .65377 L F
.287 0 .135 r
.33432 .65555 m .33718 .65324 L .33518 .65377 L F
0 0 .204 r
.41963 .66444 m .41976 .66507 L .41956 .66457 L F
.298 0 .254 r
.37809 .71026 m .37528 .71253 L .37602 .71088 L F
.598 .411 .6 r
.31279 .67223 m .31505 .6695 L .31319 .6701 L F
.711 .613 .746 r
.29667 .71113 m .29726 .71375 L .29931 .71084 L F
.362 .167 .475 r
.29931 .71084 m .29726 .71375 L .29891 .71314 L F
.223 .052 .426 r
.29726 .71375 m .29826 .71549 L .29891 .71314 L F
.29726 .71375 m .297 .71605 L .29826 .71549 L F
.371 .834 .903 r
.37033 .6711 m .37023 .67051 L .36835 .67141 L F
.37033 .6711 m .37242 .67055 L .37023 .67051 L F
.074 .049 .521 r
.40218 .77923 m .40352 .78065 L .40356 .77832 L F
.40218 .77923 m .40236 .78197 L .40352 .78065 L F
.737 .622 .731 r
.31701 .72771 m .32052 .72991 L .31932 .72664 L F
.31701 .72771 m .31845 .73092 L .32052 .72991 L F
.575 .557 .796 r
.31932 .72664 m .32052 .72991 L .32261 .7295 L F
0 .302 .796 r
.32052 .72991 m .32366 .73291 L .32261 .7295 L F
.212 0 .335 r
.60872 .74894 m .60813 .7511 L .60625 .7515 L F
.143 0 .104 r
.60813 .7511 m .60551 .75339 L .60625 .7515 L F
.551 .335 .54 r
.34087 .68308 m .33794 .68541 L .33882 .6836 L F
0 .348 .776 r
.58316 .73545 m .58304 .73569 L .58199 .73474 L F
.58316 .73545 m .58601 .73716 L .58304 .73569 L F
.512 .277 .495 r
.68829 .58206 m .69065 .5816 L .68825 .58007 L F
.082 .204 .693 r
.5728 .74366 m .57366 .74701 L .57438 .74546 L F
.963 .654 .25 r
.57574 .74909 m .57366 .74701 L .57498 .74838 L F
.57574 .74909 m .57438 .74546 L .57366 .74701 L F
.228 .601 .951 r
.73416 .62595 m .73383 .62626 L .73228 .62479 L F
.817 .538 .516 r
.4947 .73687 m .49193 .73479 L .49502 .7358 L F
0 0 .315 r
.49626 .78092 m .4966 .78231 L .49551 .77872 L F
.827 .392 .203 r
.49626 .78092 m .4993 .78362 L .4966 .78231 L F
.546 .355 .573 r
.38265 .68907 m .38479 .68877 L .38484 .68637 L F
.565 .42 .643 r
.38484 .68637 m .38706 .686 L .38684 .68348 L F
.508 .324 .566 r
.38484 .68637 m .38689 .6883 L .38706 .686 L F
.38484 .68637 m .38479 .68877 L .38689 .6883 L F
.017 .526 .867 r
.73293 .71212 m .73133 .71209 L .73085 .71162 L F
.73293 .71212 m .73412 .71282 L .73133 .71209 L F
.48 .361 .64 r
.33488 .73255 m .33539 .73558 L .33345 .73609 L F
.089 0 0 r
.33539 .73558 m .33225 .73691 L .33345 .73609 L F
.444 .225 .486 r
.38262 .69143 m .38479 .68877 L .38265 .68907 L F
.316 .017 .29 r
.46465 .74292 m .4626 .7436 L .46474 .74142 L F
.502 .161 .32 r
.46474 .74142 m .46685 .74261 L .46465 .74292 L F
.922 .698 .581 r
.61505 .67808 m .61334 .67783 L .61373 .67535 L F
.942 .897 .753 r
.61505 .67808 m .61271 .67994 L .61334 .67783 L F
.61505 .67808 m .61357 .68092 L .61271 .67994 L F
.575 .577 .817 r
.4075 .78988 m .40816 .78642 L .40665 .7868 L F
.4075 .78988 m .40957 .78972 L .40816 .78642 L F
.512 .203 .38 r
.32927 .65834 m .33243 .65519 L .3299 .65644 L F
.683 .377 .45 r
.43193 .7369 m .43544 .7348 L .43257 .73596 L F
.633 .575 .771 r
.55019 .69203 m .55224 .6893 L .55038 .68988 L F
.052 0 0 r
.5513 .69041 m .55038 .68988 L .55224 .6893 L F
.5513 .69041 m .54886 .69128 L .55038 .68988 L F
.442 0 0 r
.48887 .78407 m .48783 .78476 L .48536 .78458 L F
.406 0 0 r
.49014 .78534 m .48887 .78407 L .49101 .78417 L F
.49014 .78534 m .48783 .78476 L .48887 .78407 L F
.649 .512 .683 r
.43939 .76804 m .43736 .77074 L .43714 .76847 L F
.494 .759 .989 r
.27074 .60618 m .27323 .60514 L .26924 .60515 L F
.27074 .60618 m .27316 .60626 L .27323 .60514 L F
.509 .378 .638 r
.40212 .7656 m .40413 .76543 L .40395 .7624 L F
.63 .445 .613 r
.40212 .7656 m .40467 .76773 L .40413 .76543 L F
.40212 .7656 m .40232 .76794 L .40467 .76773 L F
.793 .67 .728 r
.72875 .61211 m .73031 .61528 L .72923 .61425 L F
.68 .877 .972 r
.73037 .60135 m .72688 .60147 L .72908 .59935 L F
.072 .391 .85 r
.72908 .59935 m .73064 .60025 L .73037 .60135 L F
0 0 .257 r
.73082 .60245 m .73037 .60135 L .73064 .60025 L F
.73082 .60245 m .73148 .60443 L .73037 .60135 L F
.161 0 0 r
.53711 .78935 m .53698 .7895 L .53472 .78934 L F
0 .041 .609 r
.53563 .78641 m .53698 .7895 L .53903 .78652 L F
.53674 .78895 m .53731 .78876 L .53698 .7895 L F
.53563 .78641 m .53731 .78876 L .53674 .78895 L F
.161 0 0 r
.53789 .78935 m .53698 .7895 L .53711 .78935 L F
.886 .991 .754 r
.53903 .78652 m .53698 .7895 L .53789 .78935 L F
0 .459 .837 r
.53792 .78855 m .53731 .78876 L .53644 .78797 L F
.886 .991 .754 r
.53903 .78652 m .53789 .78935 L .54 .78854 L F
0 .459 .837 r
.53904 .78898 m .53731 .78876 L .53792 .78855 L F
.568 .432 .656 r
.53731 .78876 m .53679 .78972 L .53698 .7895 L F
.586 .199 .275 r
.53698 .7895 m .53586 .79146 L .53341 .79123 L F
.568 .432 .656 r
.53679 .78972 m .53586 .79146 L .53698 .7895 L F
.305 .665 .973 r
.29188 .59891 m .28872 .59772 L .29042 .59785 L F
.489 .764 .992 r
.29389 .59863 m .29188 .59891 L .29042 .59785 L F
.861 .841 .375 r
.31064 .7241 m .30949 .72812 L .30984 .72797 L F
.54 .184 .312 r
.30833 .73062 m .30663 .72923 L .30984 .72797 L F
.861 .841 .375 r
.30949 .72812 m .30935 .72862 L .30984 .72797 L F
0 0 0 r
.3101 .72786 m .30984 .72797 L .3082 .72824 L F
.31164 .72755 m .30984 .72797 L .3101 .72786 L F
.568 .415 .633 r
.42028 .66927 m .41814 .67252 L .41855 .66995 L F
.373 0 0 r
.56025 .7467 m .5563 .74634 L .55688 .74736 L F
.55733 .74643 m .5591 .74697 L .55673 .74638 L F
.56025 .7467 m .5591 .74697 L .55733 .74643 L F
.568 .171 .249 r
.56098 .74744 m .56084 .74763 L .5591 .74697 L F
.243 .492 .894 r
.5591 .74697 m .56084 .74763 L .56073 .74747 L F
.568 .171 .249 r
.56218 .74578 m .5591 .74697 L .56025 .7467 L F
.56218 .74578 m .56098 .74744 L .5591 .74697 L F
.243 .492 .894 r
.5591 .74697 m .56073 .74747 L .55939 .74547 L F
.373 0 0 r
.55673 .74638 m .5591 .74697 L .5563 .74634 L F
.639 .847 .98 r
.71102 .60715 m .71438 .60752 L .71389 .60653 L F
.591 .819 .986 r
.71389 .60653 m .71438 .60752 L .71674 .60689 L F
.991 .846 .481 r
.71438 .60752 m .71346 .60877 L .71389 .60653 L F
.923 .573 .352 r
.71438 .60752 m .71497 .60997 L .71346 .60877 L F
.661 .25 .255 r
.60107 .65231 m .6043 .65102 L .60101 .65127 L F
.60107 .65231 m .60308 .6526 L .6043 .65102 L F
.761 .377 .326 r
.60308 .6526 m .60616 .65313 L .6043 .65102 L F
.768 .373 .305 r
.6043 .65102 m .60616 .65313 L .6077 .65316 L F
.799 .663 .714 r
.70222 .59038 m .70334 .59408 L .70024 .59361 L F
.798 .777 .834 r
.70334 .59408 m .69949 .59534 L .70024 .59361 L F
.67 .443 .567 r
.51641 .72983 m .5201 .73218 L .51918 .72939 L F
.51641 .72983 m .51635 .73247 L .5201 .73218 L F
.517 .383 .637 r
.29694 .69997 m .29903 .70192 L .29886 .69955 L F
.29694 .69997 m .29717 .70248 L .29903 .70192 L F
.631 .101 0 r
.42623 .78909 m .42265 .7886 L .42371 .78856 L F
.387 0 0 r
.42786 .78895 m .42623 .78909 L .42371 .78856 L F
.526 .861 .995 r
.48945 .74912 m .49037 .74798 L .49186 .74849 L F
.49186 .74849 m .49037 .74798 L .48945 .74912 L F
.482 .851 .613 r
.66909 .59632 m .66625 .59845 L .66953 .59753 L F
.119 0 .281 r
.66953 .59753 m .67076 .59579 L .66909 .59632 L F
.569 .361 .559 r
.33794 .68541 m .33638 .68976 L .33635 .68587 L F
.334 .049 .323 r
.59875 .65087 m .59626 .65336 L .59839 .65264 L F
.525 .215 .384 r
.59839 .65264 m .60107 .65231 L .59875 .65087 L F
.569 .158 .223 r
.59875 .65087 m .60107 .65231 L .60101 .65127 L F
.866 .713 .69 r
.52266 .73504 m .52406 .73566 L .52396 .73831 L F
.608 .175 .193 r
.52396 .73831 m .52607 .74006 L .52304 .73955 L F
.565 .179 .267 r
.46459 .72726 m .46653 .72872 L .46778 .72667 L F
.557 .162 .249 r
.46653 .72872 m .47008 .72688 L .46778 .72667 L F
.284 0 0 r
.51024 .70574 m .51356 .70448 L .51125 .70558 L F
.348 .701 .983 r
.54478 .72404 m .54386 .7249 L .54268 .7239 L F
.54478 .72404 m .54588 .72499 L .54386 .7249 L F
.609 .04 0 r
.54726 .70384 m .54349 .702 L .5447 .70271 L F
.916 .719 .622 r
.51501 .73549 m .515 .73798 L .51422 .73719 L F
.096 0 .188 r
.51422 .73719 m .5145 .73765 L .51501 .73549 L F
.991 .733 .402 r
.51501 .73549 m .5145 .73765 L .51417 .73519 L F
.123 0 .199 r
.51501 .73549 m .51594 .73671 L .51589 .73474 L F
.51501 .73549 m .5145 .73765 L .51594 .73671 L F
.343 .526 .891 r
.72569 .73455 m .72579 .73264 L .72404 .73313 L F
.72569 .73455 m .72738 .73496 L .72579 .73264 L F
.705 .689 .831 r
.54521 .73305 m .54611 .73532 L .54679 .73404 L F
.781 .496 .504 r
.54611 .73532 m .54863 .73732 L .54679 .73404 L F
.54611 .73532 m .5459 .73824 L .54863 .73732 L F
0 0 .133 r
.4626 .7436 m .46215 .74581 L .46083 .74652 L F
0 0 .006 r
.46215 .74581 m .45999 .74838 L .46083 .74652 L F
.41 .67 .967 r
.39628 .65601 m .39522 .6566 L .39437 .65543 L F
.091 0 .187 r
.56405 .74331 m .56218 .74578 L .56273 .74411 L F
.654 .425 .56 r
.46989 .7491 m .46959 .75155 L .46711 .75146 L F
.355 .255 .602 r
.47059 .74824 m .46959 .75155 L .46989 .7491 L F
.585 .49 .713 r
.69083 .59321 m .68805 .59416 L .68821 .59145 L F
.418 .142 .385 r
.41574 .675 m .41324 .67749 L .41375 .67554 L F
0 0 .187 r
.29536 .71907 m .29643 .71821 L .297 .71605 L F
.525 .92 .841 r
.29433 .71932 m .29643 .71821 L .29536 .71907 L F
.683 .377 .45 r
.43193 .7369 m .43437 .73742 L .43544 .7348 L F
.554 .24 .39 r
.43437 .73742 m .43764 .73485 L .43544 .7348 L F
.426 .154 .395 r
.49384 .73298 m .49646 .72955 L .49361 .72974 L F
.49384 .73298 m .49609 .73222 L .49646 .72955 L F
.187 0 .321 r
.49646 .72955 m .49609 .73222 L .49806 .72918 L F
.814 .798 .837 r
.67874 .61721 m .68263 .61593 L .68136 .61487 L F
.421 .863 .79 r
.52801 .78205 m .5279 .78197 L .53044 .78094 L F
.437 .017 .142 r
.52658 .78315 m .5279 .78197 L .52801 .78205 L F
0 0 .273 r
.27805 .63179 m .27807 .63362 L .2785 .63143 L F
.27805 .63179 m .27757 .63417 L .27807 .63362 L F
.329 .153 .485 r
.27683 .63448 m .27757 .63417 L .27805 .63179 L F
.514 .381 .637 r
.40395 .7624 m .40574 .75952 L .40379 .75995 L F
.8 .732 .789 r
.6847 .59575 m .68661 .5965 L .68411 .59928 L F
.372 .81 .959 r
.71642 .58275 m .71979 .58276 L .71739 .58291 L F
.925 .546 .147 r
.52278 .70034 m .52454 .70311 L .52324 .7019 L F
.52278 .70034 m .52454 .70311 L .52324 .7019 L F
.529 .774 .987 r
.52555 .70143 m .52454 .70311 L .52324 .7019 L F
.52555 .70143 m .52734 .70275 L .52454 .70311 L F
.193 .333 .778 r
.52454 .70311 m .52555 .70143 L .52324 .7019 L F
.522 .247 .44 r
.52734 .70275 m .52674 .7045 L .52454 .70311 L F
.193 .333 .778 r
.52454 .70311 m .52674 .7045 L .52555 .70143 L F
0 0 0 r
.58056 .71088 m .57944 .71227 L .57803 .71298 L F
.21 .328 .767 r
.58175 .70969 m .58192 .71186 L .58056 .71088 L F
.813 .405 .276 r
.58056 .71088 m .58235 .71331 L .57944 .71227 L F
.361 .328 .687 r
.58192 .71186 m .58235 .71331 L .58056 .71088 L F
.465 .438 .743 r
.70411 .72938 m .70538 .72614 L .70298 .7274 L F
0 0 0 r
.68411 .59928 m .68011 .60059 L .68297 .59796 L F
.8 .732 .789 r
.6847 .59575 m .68411 .59928 L .68297 .59796 L F
.635 .711 .902 r
.50226 .726 m .50515 .72654 L .50362 .72429 L F
.852 .671 .656 r
.50515 .72654 m .50375 .72666 L .50362 .72429 L F
.809 .359 .168 r
.50515 .72654 m .50364 .72753 L .50375 .72666 L F
.216 0 .352 r
.50352 .73129 m .5047 .73082 L .50526 .72901 L F
.809 .359 .168 r
.50515 .72654 m .5072 .72909 L .50502 .72813 L F
.715 .186 0 r
.5072 .72909 m .50647 .72953 L .50559 .72891 L F
.5072 .72909 m .50559 .72891 L .50545 .72878 L F
.5072 .72909 m .50545 .72878 L .50502 .72813 L F
.602 .363 .527 r
.50535 .7287 m .50756 .73067 L .5047 .73082 L F
.50535 .7287 m .50756 .73067 L .5047 .73082 L F
.715 .186 0 r
.50545 .72878 m .5054 .72877 L .50535 .7287 L F
.50545 .72878 m .50535 .7287 L .50502 .72813 L F
.665 .165 .049 r
.50924 .72955 m .50647 .72953 L .5072 .72909 L F
.50924 .72955 m .5079 .73065 L .50647 .72953 L F
.602 .363 .527 r
.50573 .72747 m .5079 .73065 L .50756 .73067 L F
.715 .186 0 r
.50545 .72878 m .50559 .72891 L .5054 .72877 L F
.216 0 .352 r
.50513 .72852 m .50535 .7287 L .50519 .72841 L F
.5049 .7289 m .5047 .73082 L .50352 .73129 L F
.50573 .72747 m .50533 .72879 L .5049 .7289 L F
.50533 .72879 m .5047 .73082 L .5049 .7289 L F
.715 .186 0 r
.50502 .72813 m .5054 .72877 L .50364 .72753 L F
.809 .359 .168 r
.50467 .72685 m .50502 .72813 L .50364 .72753 L F
.359 .503 .866 r
.50364 .72753 m .5054 .72877 L .50461 .72716 L F
.602 .363 .527 r
.50616 .72912 m .50559 .72891 L .50535 .7287 L F
.50689 .72949 m .50619 .72918 L .50616 .72912 L F
.50619 .72918 m .50559 .72891 L .50616 .72912 L F
.50573 .72747 m .50689 .72949 L .50535 .7287 L F
.359 .503 .866 r
.50559 .72891 m .50647 .72953 L .50619 .72918 L F
.508 0 0 r
.50647 .72953 m .5063 .72943 L .50619 .72918 L F
.50647 .72953 m .5079 .73065 L .5063 .72943 L F
.602 .363 .527 r
.50573 .72747 m .50728 .73018 L .50535 .7287 L F
.50728 .73018 m .50756 .73067 L .50547 .72881 L F
.50728 .73018 m .50547 .72881 L .50535 .7287 L F
.50689 .72949 m .50756 .73067 L .50559 .72891 L F
.508 0 0 r
.5063 .72943 m .5079 .73065 L .50583 .72916 L F
.359 .503 .866 r
.50559 .72891 m .50619 .72918 L .50461 .72716 L F
.508 0 0 r
.50619 .72918 m .50583 .72916 L .50461 .72716 L F
.5063 .72943 m .50583 .72916 L .50619 .72918 L F
.359 .503 .866 r
.5054 .72877 m .50559 .72891 L .5055 .72875 L F
.5054 .72877 m .5055 .72875 L .50461 .72716 L F
.602 .363 .527 r
.50573 .72747 m .5079 .73065 L .50756 .73067 L F
.216 0 .352 r
.50513 .72852 m .50526 .72901 L .50535 .7287 L F
.50519 .72841 m .50535 .7287 L .50573 .72747 L F
.50352 .73129 m .50526 .72901 L .50513 .72852 L F
.809 .359 .168 r
.50515 .72654 m .50502 .72813 L .50467 .72685 L F
0 0 .269 r
.54192 .69979 m .54171 .69927 L .54071 .6968 L F
0 0 .46 r
.54192 .69979 m .54349 .702 L .54171 .69927 L F
.743 .732 .841 r
.71573 .61729 m .71726 .61905 L .71895 .61763 L F
.738 .427 .455 r
.52394 .72441 m .52059 .7261 L .51963 .72493 L F
.52394 .72441 m .52253 .72683 L .52059 .7261 L F
.633 .302 .393 r
.52394 .72441 m .52618 .72627 L .52253 .72683 L F
.63 .575 .775 r
.43133 .7596 m .42943 .7616 L .42931 .75994 L F
.616 .695 .9 r
.72838 .73763 m .72965 .735 L .72738 .73496 L F
.72838 .73763 m .72996 .73698 L .72965 .735 L F
0 0 .111 r
.57944 .71227 m .57743 .7154 L .57803 .71298 L F
.832 .861 .411 r
.41047 .79222 m .40922 .79567 L .40952 .79454 L F
.427 .25 .537 r
.41079 .79536 m .40922 .79567 L .41047 .79222 L F
.692 .64 .793 r
.40957 .78972 m .41047 .79222 L .41269 .79018 L F
.671 .427 .542 r
.41079 .79536 m .41047 .79222 L .40952 .79454 L F
0 .181 .707 r
.55436 .73873 m .55574 .74005 L .55388 .73769 L F
.915 .803 .722 r
.49122 .73129 m .49361 .72974 L .49249 .7287 L F
.49122 .73129 m .49211 .73335 L .49361 .72974 L F
.6 .423 .613 r
.49361 .72974 m .49211 .73335 L .49384 .73298 L F
.103 0 .224 r
.28277 .62361 m .28078 .62629 L .28289 .62586 L F
.342 .064 .339 r
.28039 .62852 m .28289 .62586 L .28078 .62629 L F
.724 .542 .644 r
.62663 .65059 m .6267 .64818 L .62331 .64801 L F
0 0 .229 r
.57834 .67783 m .57853 .67982 L .57788 .68079 L F
.858 .85 .391 r
.57853 .67982 m .57786 .6831 L .57788 .68079 L F
.43 0 0 r
.56249 .69909 m .56284 .69963 L .56031 .69951 L F
0 0 .374 r
.56284 .69963 m .56346 .70157 L .56249 .69909 L F
.591 .417 .614 r
.29886 .69955 m .30116 .69683 L .29912 .69732 L F
.831 .889 .883 r
.58695 .72254 m .58877 .72335 L .59035 .72132 L F
.512 .203 .38 r
.32927 .65834 m .33152 .65807 L .33243 .65519 L F
.238 0 .265 r
.33243 .65519 m .33323 .65719 L .33432 .65555 L F
.33243 .65519 m .33152 .65807 L .33323 .65719 L F
0 0 .173 r
.58781 .74278 m .58763 .74423 L .58751 .74134 L F
.552 .37 .588 r
.40932 .74627 m .41147 .74808 L .41125 .74574 L F
.40932 .74627 m .40917 .74848 L .41147 .74808 L F
.503 .32 .565 r
.30462 .6835 m .30661 .68309 L .30677 .68073 L F
.553 .405 .633 r
.30471 .68646 m .30661 .68309 L .30462 .6835 L F
.194 0 .21 r
.27659 .63507 m .27757 .63417 L .27683 .63448 L F
.889 .917 .837 r
.72739 .7241 m .72464 .7257 L .72682 .7226 L F
.364 .82 .713 r
.31405 .60469 m .31328 .60517 L .31157 .60413 L F
.31405 .60469 m .31542 .60418 L .31328 .60517 L F
.519 .533 .81 r
.31582 .6061 m .31328 .60517 L .31542 .60418 L F
.476 .139 .315 r
.59334 .6559 m .59569 .65556 L .59626 .65336 L F
.465 .184 .403 r
.59569 .65556 m .59839 .65264 L .59626 .65336 L F
.501 .582 .868 r
.41242 .66292 m .41085 .66499 L .41048 .66313 L F
.519 .607 .881 r
.41242 .66292 m .41351 .66529 L .41085 .66499 L F
.51 .426 .697 r
.30626 .67821 m .30858 .6802 L .30828 .67775 L F
.30626 .67821 m .30677 .68073 L .30858 .6802 L F
.48 .272 .519 r
.30848 .67538 m .30626 .67821 L .30828 .67775 L F
.437 .236 .508 r
.31041 .67494 m .30848 .67538 L .30828 .67775 L F
.762 .699 .792 r
.3041 .73215 m .30022 .73236 L .30232 .72944 L F
.243 0 0 r
.3041 .73215 m .30008 .73474 L .30022 .73236 L F
.3041 .73215 m .30173 .73459 L .30008 .73474 L F
.453 .34 .635 r
.30523 .72931 m .3041 .73215 L .30232 .72944 L F
.383 0 .092 r
.30558 .73178 m .30589 .73225 L .3041 .73215 L F
.30558 .73178 m .30589 .73225 L .3041 .73215 L F
.453 .34 .635 r
.30523 .72931 m .30589 .73225 L .3041 .73215 L F
.245 0 0 r
.30397 .73388 m .3041 .73215 L .30589 .73225 L F
.30397 .73388 m .30173 .73459 L .3041 .73215 L F
.448 .217 .47 r
.40136 .69083 m .39976 .68924 L .40166 .68868 L F
.40136 .69083 m .39937 .69141 L .39976 .68924 L F
.427 .539 .867 r
.37491 .64769 m .37433 .64987 L .37325 .64882 L F
.37491 .64769 m .37621 .65037 L .37433 .64987 L F
.795 .86 .898 r
.71907 .73398 m .71946 .7355 L .72125 .73354 L F
.204 0 0 r
.36088 .71967 m .35931 .72133 L .35801 .72098 L F
.18 0 0 r
.36137 .72073 m .36088 .71967 L .36286 .71902 L F
.36137 .72073 m .35931 .72133 L .36088 .71967 L F
.674 .322 .369 r
.49471 .78385 m .49315 .7862 L .49101 .78417 L F
.686 .336 .377 r
.49471 .78385 m .4967 .7862 L .49315 .7862 L F
.277 .269 .67 r
.2832 .61156 m .28365 .61588 L .28507 .61422 L F
.118 .214 .689 r
.28365 .61588 m .28509 .61653 L .28507 .61422 L F
.28365 .61588 m .28451 .61792 L .28509 .61653 L F
.102 0 0 r
.60181 .75518 m .60375 .7544 L .60076 .75624 L F
.481 .293 .549 r
.30076 .6312 m .29892 .63174 L .30094 .62894 L F
.479 .289 .544 r
.29874 .63404 m .29892 .63174 L .30076 .6312 L F
.823 .587 .581 r
.61122 .66993 m .60807 .67167 L .60805 .66939 L F
.61122 .66993 m .61127 .6723 L .60807 .67167 L F
.084 0 0 r
.37757 .66943 m .37413 .6698 L .37553 .67006 L F
.477 .576 .875 r
.30287 .75423 m .3036 .75428 L .30302 .75449 L F
.123 0 .032 r
.30302 .75449 m .3036 .75428 L .30284 .75478 L F
.579 .573 .811 r
.42538 .73463 m .42448 .73812 L .4236 .73491 L F
.42538 .73463 m .42661 .73773 L .42448 .73812 L F
.598 .718 .928 r
.52948 .75799 m .53162 .7598 L .52871 .75998 L F
.605 .369 .533 r
.53162 .7598 m .53092 .7621 L .52871 .75998 L F
.827 .664 .68 r
.53092 .7621 m .52948 .75799 L .52871 .75998 L F
.307 .794 .745 r
.7141 .71609 m .7126 .71674 L .71142 .71772 L F
.7141 .71609 m .7148 .71595 L .7126 .71674 L F
.205 0 .269 r
.38766 .67144 m .38743 .67272 L .38803 .67203 L F
.625 .184 0 r
.38696 .6703 m .3893 .67383 L .38766 .67144 L F
.38692 .67023 m .3893 .67383 L .38686 .67016 L F
.819 .365 .152 r
.39041 .67263 m .3893 .67383 L .38692 .67023 L F
.39041 .67263 m .38692 .67023 L .38709 .67014 L F
.816 .597 .606 r
.38766 .67144 m .3893 .67383 L .38995 .6705 L F
.205 0 .269 r
.38766 .67144 m .38803 .67203 L .38938 .67047 L F
.625 .184 0 r
.38686 .67016 m .38696 .6703 L .38766 .67144 L F
.38664 .6698 m .38692 .67023 L .38686 .67016 L F
.615 .519 .723 r
.38663 .67039 m .38672 .67 L .38675 .67027 L F
.504 .67 .938 r
.38331 .66673 m .38675 .67027 L .38711 .6684 L F
.615 .519 .723 r
.38672 .67 m .38711 .6684 L .38678 .67007 L F
.38672 .67 m .38678 .67007 L .38675 .67027 L F
.509 .12 .238 r
.38307 .67177 m .38536 .67178 L .38675 .67027 L F
.615 .519 .723 r
.38536 .67178 m .38586 .67081 L .38663 .67039 L F
.509 .12 .238 r
.38307 .67177 m .38675 .67027 L .38311 .66998 L F
.615 .519 .723 r
.38586 .67081 m .38711 .6684 L .38663 .67039 L F
.819 .365 .152 r
.38709 .67014 m .38692 .67023 L .38664 .6698 L F
.98 .843 .449 r
.38995 .6705 m .39041 .67263 L .39249 .67222 L F
.38995 .6705 m .3893 .67383 L .39041 .67263 L F
.479 .322 .59 r
.39048 .67474 m .39249 .67222 L .39041 .67263 L F
.117 0 0 r
.57387 .66936 m .57569 .66914 L .57692 .66764 L F
.201 0 0 r
.57692 .66764 m .57783 .66852 L .57871 .66662 L F
.57692 .66764 m .57569 .66914 L .57783 .66852 L F
.404 .119 .364 r
.39891 .69335 m .39757 .69208 L .39937 .69141 L F
.39891 .69335 m .39692 .69394 L .39757 .69208 L F
.169 0 0 r
.45747 .78383 m .45628 .78441 L .45425 .78471 L F
.337 0 0 r
.45963 .78376 m .45628 .78441 L .45747 .78383 L F
0 .25 .763 r
.36994 .64704 m .37105 .64734 L .37068 .64824 L F
.462 0 0 r
.36962 .64699 m .37191 .64756 L .37105 .64734 L F
.391 0 0 r
.37105 .64734 m .37491 .64769 L .37325 .64882 L F
.462 0 0 r
.37191 .64756 m .37369 .648 L .37105 .64734 L F
0 .25 .763 r
.36912 .64573 m .37105 .64734 L .36994 .64704 L F
.232 .605 .952 r
.37105 .64734 m .37325 .64882 L .37068 .64824 L F
.642 .824 .97 r
.34557 .70536 m .34376 .70618 L .3423 .70509 L F
.585 .49 .713 r
.69083 .59321 m .68821 .59145 L .69068 .59081 L F
.778 .536 .57 r
.69068 .59081 m .69399 .5941 L .69083 .59321 L F
.336 .412 .792 r
.31564 .80317 m .31645 .80631 L .31506 .80566 L F
.31564 .80317 m .3169 .80655 L .31645 .80631 L F
.347 0 0 r
.31645 .80631 m .31555 .80586 L .31506 .80566 L F
.31645 .80631 m .3169 .80655 L .31555 .80586 L F
.45 0 0 r
.53472 .78934 m .53132 .78909 L .53304 .78917 L F
.735 .619 .729 r
.59329 .74304 m .59125 .74643 L .59062 .74594 L F
.548 .01 0 r
.71647 .71692 m .71807 .71625 L .7148 .71595 L F
.626 .235 .282 r
.71647 .71692 m .72023 .71569 L .71807 .71625 L F
.517 .095 .179 r
.5764 .7083 m .57974 .70747 L .57693 .70667 L F
.793 .67 .728 r
.72875 .61211 m .72696 .6152 L .73031 .61528 L F
.85 .993 .746 r
.43803 .76878 m .43736 .77074 L .43939 .76804 L F
.278 .309 .714 r
.43803 .76878 m .43752 .772 L .43736 .77074 L F
.321 .419 .806 r
.5943 .72162 m .5968 .72359 L .59613 .72127 L F
.539 .685 .933 r
.72434 .58113 m .72299 .5831 L .72222 .58226 L F
.72434 .58113 m .72554 .5829 L .72299 .5831 L F
.985 .724 .449 r
.6747 .60726 m .67446 .60944 L .67554 .60626 L F
.998 .842 .515 r
.31558 .73251 m .31427 .73103 L .31687 .73201 L F
.677 .87 .482 r
.61054 .69216 m .61171 .69066 L .60989 .69336 L F
.541 .857 .562 r
.61054 .69216 m .61127 .69148 L .61171 .69066 L F
.969 .739 .305 r
.61216 .6911 m .61171 .69066 L .61221 .68973 L F
.541 .857 .562 r
.61127 .69148 m .61312 .68976 L .61171 .69066 L F
.969 .739 .305 r
.61221 .68973 m .61171 .69066 L .61223 .68903 L F
.512 .83 .522 r
.61223 .68903 m .61339 .68786 L .61393 .68737 L F
.471 .28 .539 r
.61171 .69066 m .61312 .68976 L .61339 .68786 L F
0 0 .099 r
.61312 .68976 m .6131 .68813 L .61339 .68786 L F
.6131 .68813 m .61308 .68695 L .61339 .68786 L F
.512 .83 .522 r
.61393 .68737 m .61339 .68786 L .61501 .68631 L F
0 0 0 r
.61171 .69066 m .61339 .68786 L .61223 .68903 L F
.886 .99 .789 r
.61714 .68349 m .61501 .68631 L .61496 .68503 L F
.914 .968 .662 r
.61501 .68631 m .61339 .68786 L .61496 .68503 L F
.756 .335 .249 r
.50226 .726 m .50005 .72641 L .49812 .7242 L F
.412 .262 .566 r
.50213 .72716 m .50357 .72903 L .50189 .7294 L F
.50226 .726 m .5027 .72703 L .50213 .72716 L F
.5027 .72703 m .50357 .72903 L .50213 .72716 L F
.632 .366 .498 r
.50375 .72666 m .50357 .72903 L .50226 .726 L F
.831 .545 .505 r
.50078 .72805 m .50357 .72903 L .50375 .72666 L F
.50078 .72805 m .50321 .72692 L .50249 .72751 L F
.50321 .72692 m .50375 .72666 L .50346 .72686 L F
.50321 .72692 m .50346 .72686 L .50249 .72751 L F
.625 .126 .046 r
.50226 .726 m .50005 .72641 L .50375 .72666 L F
.57 .453 .681 r
.50362 .72429 m .50375 .72666 L .50226 .726 L F
.625 .126 .046 r
.50226 .726 m .50005 .72641 L .50375 .72666 L F
.425 .402 .729 r
.57089 .70953 m .56972 .7128 L .56905 .71141 L F
.16 0 0 r
.46058 .77543 m .46282 .77544 L .4639 .77519 L F
.36 0 0 r
.46282 .77544 m .46594 .77487 L .4639 .77519 L F
.475 .223 .453 r
.5964 .71908 m .59613 .72127 L .59868 .7186 L F
.792 .775 .837 r
.68293 .61141 m .68662 .61027 L .68544 .60915 L F
.864 .834 .816 r
.68544 .60915 m .68662 .61027 L .68875 .6073 L F
.821 .647 .667 r
.63077 .65905 m .62804 .65599 L .62777 .65835 L F
.835 .615 .605 r
.6277 .6607 m .63077 .65905 L .62777 .65835 L F
.6277 .6607 m .62955 .66124 L .63077 .65905 L F
.732 .799 .32 r
.73469 .62947 m .73379 .63201 L .73316 .63191 L F
.562 .413 .637 r
.73629 .63119 m .73654 .63362 L .73379 .63201 L F
0 .376 .834 r
.73379 .63201 m .73654 .63362 L .73591 .63249 L F
.73379 .63201 m .73591 .63249 L .73316 .63191 L F
.545 .371 .596 r
.73591 .62895 m .73629 .63119 L .73379 .63201 L F
.292 0 .001 r
.48093 .7237 m .48036 .72444 L .4825 .72402 L F
.044 0 0 r
.3082 .72824 m .30523 .72931 L .30568 .72928 L F
.3082 .72824 m .30663 .72923 L .30523 .72931 L F
.048 0 0 r
.30984 .72797 m .30663 .72923 L .3082 .72824 L F
.201 0 0 r
.35931 .72133 m .35633 .72284 L .35801 .72098 L F
0 .223 .727 r
.55157 .70809 m .55281 .70858 L .55083 .70721 L F
.55157 .70809 m .55381 .70983 L .55281 .70858 L F
.399 0 .047 r
.33918 .65266 m .34134 .65251 L .34285 .65092 L F
.384 0 .029 r
.34134 .65251 m .34506 .65082 L .34285 .65092 L F
0 0 0 r
.55515 .68388 m .55435 .68472 L .55636 .68266 L F
.535 .657 .914 r
.71247 .731 m .71401 .72906 L .71167 .72944 L F
.71247 .731 m .71749 .73131 L .71401 .72906 L F
.63 .575 .775 r
.43133 .7596 m .43258 .76293 L .42943 .7616 L F
.518 .128 .241 r
.46106 .72938 m .46321 .72964 L .46459 .72726 L F
.566 .178 .267 r
.46459 .72726 m .46321 .72964 L .46653 .72872 L F
0 0 0 r
.51545 .70502 m .51416 .70536 L .51587 .705 L F
.51545 .70502 m .51659 .70485 L .51777 .70548 L F
.51545 .70502 m .51587 .705 L .51659 .70485 L F
0 .441 .749 r
.51526 .70503 m .51545 .70502 L .51674 .70551 L F
.51356 .70448 m .51545 .70502 L .51526 .70503 L F
0 .471 .722 r
.51545 .70502 m .51883 .70574 L .51674 .70551 L F
.523 .293 .508 r
.38908 .68313 m .39139 .6806 L .38912 .68079 L F
.543 .244 .411 r
.43682 .75681 m .43371 .75921 L .43458 .75708 L F
.595 .554 .778 r
.29761 .70527 m .29857 .70835 L .30048 .70767 L F
0 0 .277 r
.29931 .71084 m .30048 .70767 L .29857 .70835 L F
.542 .065 .074 r
.47514 .78363 m .47628 .78228 L .4787 .78335 L F
.454 .615 .918 r
.40473 .78201 m .40616 .78445 L .40729 .78306 L F
.261 .331 .747 r
.40616 .78445 m .40816 .78642 L .40729 .78306 L F
.437 .366 .679 r
.40665 .7868 m .40816 .78642 L .40616 .78445 L F
.527 .375 .618 r
.60821 .72439 m .60847 .72662 L .60634 .72503 L F
.612 .346 .49 r
.43987 .73469 m .44237 .73253 L .44031 .73289 L F
.735 .619 .729 r
.59329 .74304 m .59062 .74594 L .59236 .74262 L F
.81 .334 .079 r
.61357 .68092 m .61326 .68209 L .61271 .67994 L F
.61357 .68092 m .61525 .68306 L .61326 .68209 L F
.236 0 .243 r
.46329 .74539 m .4626 .7436 L .46465 .74292 L F
.46329 .74539 m .46215 .74581 L .4626 .7436 L F
.783 .606 .661 r
.62651 .65299 m .62804 .65599 L .62976 .65334 L F
.534 .756 .978 r
.26891 .59448 m .26831 .59594 L .26683 .59459 L F
.419 .777 .996 r
.27032 .59572 m .26831 .59594 L .27007 .59576 L F
.534 .756 .978 r
.26891 .59448 m .27007 .59576 L .26831 .59594 L F
.269 .022 .343 r
.62032 .69954 m .62047 .70171 L .61806 .70254 L F
.242 .104 .484 r
.62253 .69643 m .62237 .69906 L .62032 .69954 L F
.096 0 .318 r
.62161 .70092 m .62032 .69954 L .62237 .69906 L F
.62161 .70092 m .62047 .70171 L .62032 .69954 L F
.056 0 .083 r
.351 .7254 m .35041 .72428 L .35255 .72399 L F
.351 .7254 m .34941 .72658 L .35041 .72428 L F
.766 .695 .783 r
.40234 .7704 m .4001 .77337 L .40373 .77353 L F
.557 .558 .811 r
.40373 .77353 m .40455 .7701 L .40234 .7704 L F
.40373 .77353 m .40577 .77316 L .40455 .7701 L F
.537 .414 .66 r
.40402 .77634 m .40577 .77316 L .40373 .77353 L F
.699 .162 0 r
.3275 .73518 m .3257 .73465 L .32366 .73291 L F
.493 .327 .584 r
.32775 .73669 m .3275 .73518 L .33015 .73622 L F
.32775 .73669 m .3257 .73465 L .3275 .73518 L F
.474 .608 .904 r
.39284 .65328 m .39231 .65548 L .39061 .65332 L F
.39284 .65328 m .39437 .65543 L .39231 .65548 L F
.583 .279 .418 r
.44543 .73202 m .44773 .73207 L .44808 .73031 L F
.543 .223 .376 r
.44773 .73207 m .45111 .72945 L .44808 .73031 L F
0 .048 .615 r
.58048 .75945 m .58092 .75929 L .57909 .75693 L F
0 .088 .645 r
.58048 .75945 m .58246 .76193 L .58092 .75929 L F
.858 .655 .628 r
.52014 .73468 m .52303 .73267 L .5201 .73218 L F
.52014 .73468 m .52266 .73504 L .52303 .73267 L F
.47 .292 .558 r
.52266 .73504 m .52527 .7349 L .52303 .73267 L F
.724 .629 .752 r
.66734 .60175 m .67078 .60424 L .66969 .60116 L F
.66734 .60175 m .66862 .605 L .67078 .60424 L F
.6 .503 .716 r
.67078 .60424 m .67351 .60192 L .66969 .60116 L F
.125 .559 .921 r
.38632 .65136 m .38934 .65217 L .38907 .6529 L F
.064 .488 .892 r
.38934 .65217 m .39061 .65332 L .38907 .6529 L F
.086 .627 .85 r
.30202 .75402 m .3036 .75428 L .30287 .75423 L F
.759 .808 .892 r
.68875 .6073 m .69066 .60655 L .69016 .60424 L F
.742 .798 .897 r
.69016 .60424 m .69066 .60655 L .69314 .60428 L F
0 0 0 r
.5222 .7913 m .52115 .79174 L .52379 .79019 L F
.5222 .7913 m .52034 .79209 L .52115 .79174 L F
.908 .85 .774 r
.63103 .67239 m .63289 .66936 L .63096 .66944 L F
.578 .339 .518 r
.45705 .74804 m .45461 .74838 L .45519 .74621 L F
.353 .753 .984 r
.69629 .59039 m .69853 .59034 L .69529 .58972 L F
.967 .657 .264 r
.7354 .63032 m .73591 .62895 L .73526 .62805 L F
.7354 .63032 m .73629 .63119 L .73591 .62895 L F
.708 .374 .409 r
.60791 .66704 m .60649 .66904 L .60447 .66702 L F
.852 .569 .51 r
.60791 .66704 m .60805 .66939 L .60649 .66904 L F
.318 0 .192 r
.56184 .67753 m .56091 .67949 L .56358 .67776 L F
.738 .558 .649 r
.62015 .64743 m .62111 .65049 L .62331 .64801 L F
.693 .491 .61 r
.62111 .65049 m .62345 .65041 L .62331 .64801 L F
.724 .542 .644 r
.62663 .65059 m .62331 .64801 L .62345 .65041 L F
0 0 0 r
.5991 .75719 m .60076 .75624 L .60059 .75669 L F
.5991 .75719 m .60059 .75669 L .59771 .75861 L F
.425 .402 .729 r
.57089 .70953 m .57153 .71331 L .56972 .7128 L F
.577 .625 .864 r
.57278 .71425 m .56972 .7128 L .57153 .71331 L F
0 0 0 r
.29062 .64571 m .29297 .64285 L .29232 .64489 L F
.399 .158 .429 r
.29297 .64285 m .2953 .64022 L .29466 .64212 L F
.308 .05 .35 r
.29232 .64489 m .29297 .64285 L .29466 .64212 L F
.344 .184 .515 r
.62047 .70171 m .61809 .70487 L .61806 .70254 L F
.895 .638 .541 r
.58391 .7135 m .58235 .71331 L .58192 .71186 L F
.851 .478 .344 r
.58391 .7135 m .5823 .71372 L .58235 .71331 L F
.507 .667 .934 r
.58425 .71219 m .58391 .7135 L .58192 .71186 L F
.612 .774 .958 r
.58652 .71314 m .58391 .7135 L .58425 .71219 L F
.823 .97 .895 r
.58425 .71219 m .5823 .71372 L .58391 .7135 L F
.228 .175 .587 r
.58391 .7135 m .58547 .71442 L .58425 .71219 L F
.58391 .7135 m .58435 .71568 L .58547 .71442 L F
.417 .131 .369 r
.40674 .6835 m .40627 .68579 L .40414 .68596 L F
.366 .087 .352 r
.40811 .68517 m .40674 .6835 L .4087 .68296 L F
.40811 .68517 m .40627 .68579 L .40674 .6835 L F
.4 .049 .25 r
.3656 .70486 m .36769 .70446 L .36833 .70296 L F
.53 .217 .382 r
.36769 .70446 m .37049 .70253 L .36833 .70296 L F
0 0 .173 r
.58781 .74278 m .58751 .74134 L .58847 .74012 L F
0 0 .338 r
.32261 .7295 m .32366 .73291 L .32344 .73156 L F
.942 .583 .292 r
.3257 .73465 m .32344 .73156 L .32366 .73291 L F
.305 .066 .377 r
.30094 .62894 m .3031 .6261 L .30255 .62825 L F
.407 .207 .493 r
.30094 .62894 m .30256 .63073 L .30076 .6312 L F
.30094 .62894 m .30255 .62825 L .30256 .63073 L F
.241 0 .31 r
.3031 .6261 m .30535 .62329 L .30488 .62511 L F
.298 .08 .405 r
.30255 .62825 m .3031 .6261 L .30488 .62511 L F
.746 .985 .765 r
.54277 .69273 m .54098 .69445 L .54138 .69344 L F
.425 .843 .678 r
.54277 .69273 m .543 .69245 L .54468 .6917 L F
.54277 .69273 m .54138 .69344 L .543 .69245 L F
.321 .802 .747 r
.35817 .70817 m .35903 .70771 L .36008 .70739 L F
.35817 .70817 m .35619 .70872 L .35903 .70771 L F
.886 .99 .789 r
.61714 .68349 m .61496 .68503 L .61525 .68306 L F
0 0 .277 r
.29931 .71084 m .30011 .71034 L .30048 .70767 L F
0 0 .139 r
.29891 .71314 m .30011 .71034 L .29931 .71084 L F
.296 .034 .335 r
.29466 .64212 m .2953 .64022 L .29698 .63948 L F
.415 .235 .527 r
.59875 .71626 m .59868 .7186 L .60051 .71563 L F
.807 .671 .714 r
.71674 .60689 m .71795 .61008 L .71497 .60997 L F
.785 .74 .812 r
.71795 .61008 m .71448 .61089 L .71497 .60997 L F
.864 .834 .816 r
.68544 .60915 m .68875 .6073 L .68741 .6063 L F
.759 .808 .892 r
.68875 .6073 m .69016 .60424 L .68741 .6063 L F
.424 .306 .614 r
.28277 .62361 m .28441 .62502 L .28462 .62303 L F
.28277 .62361 m .28289 .62586 L .28441 .62502 L F
.478 .308 .571 r
.60936 .72059 m .60821 .72439 L .6086 .7216 L F
.372 .139 .426 r
.41146 .74351 m .4132 .74299 L .41346 .74095 L F
.437 .118 .326 r
.4132 .74299 m .4157 .74098 L .41346 .74095 L F
.474 .889 .781 r
.55217 .6859 m .55331 .68501 L .55435 .68472 L F
.475 .89 .788 r
.55217 .6859 m .55141 .68605 L .55331 .68501 L F
.255 0 0 r
.49364 .71663 m .49451 .71761 L .49567 .71589 L F
.49364 .71663 m .49228 .71806 L .49451 .71761 L F
.465 .438 .743 r
.70411 .72938 m .7061 .72954 L .70538 .72614 L F
0 0 .15 r
.54071 .6968 m .54138 .69344 L .54098 .69445 L F
.564 .428 .654 r
.41125 .74574 m .4132 .74299 L .41146 .74351 L F
.497 .314 .563 r
.30677 .68073 m .30852 .6826 L .30858 .6802 L F
.30677 .68073 m .30661 .68309 L .30852 .6826 L F
.375 .096 .356 r
.38777 .7024 m .38718 .70498 L .385 .70476 L F
.378 .004 .196 r
.38653 .70626 m .385 .70476 L .38718 .70498 L F
.38653 .70626 m .38431 .70678 L .385 .70476 L F
.392 .099 .344 r
.39643 .69557 m .39502 .69463 L .39692 .69394 L F
.39643 .69557 m .39446 .6963 L .39502 .69463 L F
.684 .167 0 r
.55958 .74093 m .55749 .74006 L .55863 .7414 L F
.624 .804 .968 r
.40495 .79747 m .40592 .79859 L .40851 .79784 L F
.40495 .79747 m .40592 .79859 L .40851 .79784 L F
0 0 0 r
.58107 .67524 m .58016 .67695 L .57834 .67783 L F
.014 0 .154 r
.58318 .67234 m .58264 .67458 L .58107 .67524 L F
0 0 0 r
.58264 .67458 m .58016 .67695 L .58107 .67524 L F
.788 .697 .764 r
.56405 .74331 m .5654 .74623 L .56218 .74578 L F
.832 .591 .574 r
.5654 .74623 m .56232 .7477 L .56218 .74578 L F
.5654 .74623 m .56541 .74861 L .56232 .7477 L F
.325 .448 .831 r
.56405 .74331 m .56691 .74523 L .5654 .74623 L F
.066 0 .431 r
.56691 .74523 m .56541 .74861 L .5654 .74623 L F
.288 .067 .394 r
.30745 .62042 m .30696 .62251 L .30535 .62329 L F
.309 .107 .435 r
.30535 .62329 m .30691 .62481 L .30488 .62511 L F
.30535 .62329 m .30696 .62251 L .30691 .62481 L F
.917 .648 .515 r
.53546 .78389 m .53563 .78641 L .53689 .78414 L F
.699 .357 .394 r
.53563 .78641 m .53903 .78652 L .53689 .78414 L F
.658 .362 .458 r
.53689 .78414 m .53903 .78652 L .53929 .78457 L F
.613 .63 .844 r
.54863 .73732 m .54956 .7336 L .54679 .73404 L F
.54863 .73732 m .55314 .73742 L .54956 .7336 L F
.463 .192 .417 r
.37049 .70253 m .37261 .70215 L .37309 .69947 L F
.428 .162 .406 r
.37309 .69947 m .37457 .70152 L .37504 .69943 L F
.37309 .69947 m .37261 .70215 L .37457 .70152 L F
.494 .318 .571 r
.38706 .686 m .38908 .68313 L .38684 .68348 L F
.766 .606 .679 r
.53949 .74197 m .54357 .74043 L .53838 .73911 L F
.465 .294 .564 r
.59525 .7271 m .59691 .72886 L .59654 .72636 L F
.59525 .7271 m .59538 .72949 L .59691 .72886 L F
.556 .09 0 r
.73819 .71759 m .73851 .71796 L .73993 .71881 L F
0 0 .493 r
.74003 .71977 m .739 .72156 L .73851 .71796 L F
.556 .09 0 r
.73819 .71759 m .73944 .71913 L .73851 .71796 L F
0 0 .493 r
.74003 .71977 m .73851 .71796 L .73944 .71913 L F
.625 .338 .462 r
.39936 .65347 m .39628 .65601 L .39451 .65536 L F
.69 .733 .883 r
.39893 .65661 m .39628 .65601 L .39936 .65347 L F
.449 .637 .936 r
.40206 .65661 m .39893 .65661 L .39936 .65347 L F
.742 .22 0 r
.40043 .65582 m .39936 .65347 L .3971 .65481 L F
.11 .524 .912 r
.39769 .65418 m .39869 .65478 L .3971 .65481 L F
.39869 .65478 m .40043 .65582 L .3971 .65481 L F
.625 .338 .462 r
.39936 .65347 m .39587 .65483 L .3971 .65481 L F
.39587 .65483 m .39451 .65536 L .3971 .65481 L F
.742 .22 0 r
.40043 .65582 m .40206 .65661 L .39936 .65347 L F
.291 0 0 r
.73051 .58296 m .72874 .58221 L .72757 .58202 L F
.73051 .58296 m .73056 .5828 L .72874 .58221 L F
.334 .173 .508 r
.67141 .59229 m .67304 .59245 L .67294 .59025 L F
.472 .147 .333 r
.34873 .67789 m .34749 .6803 L .34555 .68064 L F
.537 .215 .37 r
.3503 .6791 m .34873 .67789 L .35098 .67776 L F
.3503 .6791 m .34749 .6803 L .34873 .67789 L F
.627 .358 .491 r
.50005 .72641 m .49689 .72702 L .49812 .7242 L F
.338 0 .216 r
.59135 .65644 m .5907 .65787 L .59334 .6559 L F
.421 .489 .824 r
.6108 .74019 m .61042 .74336 L .60953 .74006 L F
.6108 .74019 m .61168 .74279 L .61042 .74336 L F
.179 .111 .538 r
.61159 .74478 m .61042 .74336 L .61168 .74279 L F
.61159 .74478 m .6108 .74617 L .61042 .74336 L F
.543 .223 .376 r
.44773 .73207 m .44998 .73196 L .45111 .72945 L F
.533 .172 .3 r
.44998 .73196 m .4534 .72977 L .45111 .72945 L F
0 .121 .666 r
.56647 .72422 m .56706 .72335 L .56531 .72129 L F
0 .064 .62 r
.56647 .72422 m .56807 .72645 L .56706 .72335 L F
.83 .631 .633 r
.62955 .66124 m .63231 .66399 L .63253 .6618 L F
0 .064 .591 r
.44022 .76699 m .43939 .76804 L .43894 .76509 L F
.61 .935 .721 r
.44022 .76699 m .43803 .76878 L .43939 .76804 L F
.933 .565 .284 r
.47397 .77648 m .47518 .77671 L .47293 .77376 L F
.401 0 0 r
.47735 .77769 m .47518 .77671 L .47397 .77648 L F
.551 .326 .527 r
.60068 .71336 m .60301 .71304 L .6031 .71081 L F
.655 .555 .729 r
.6019 .70731 m .6031 .71081 L .60506 .70789 L F
.554 .423 .657 r
.6031 .71081 m .60531 .71055 L .60506 .70789 L F
.526 .306 .523 r
.6031 .71081 m .60301 .71304 L .60531 .71055 L F
.136 .666 .868 r
.51382 .79467 m .51498 .79463 L .51268 .7943 L F
.842 .72 .729 r
.46493 .75422 m .463 .75431 L .46387 .75147 L F
.802 .494 .468 r
.46493 .75422 m .46347 .75658 L .463 .75431 L F
.571 .582 .825 r
.46677 .75325 m .46493 .75422 L .46387 .75147 L F
.086 0 .036 r
.4662 .75427 m .46493 .75422 L .46677 .75325 L F
.4662 .75427 m .46347 .75658 L .46493 .75422 L F
.504 .635 .911 r
.40852 .66057 m .40772 .66271 L .40657 .66075 L F
.40852 .66057 m .41048 .66313 L .40772 .66271 L F
.546 .364 .586 r
.33243 .69681 m .33237 .69869 L .33053 .699 L F
.605 .471 .672 r
.33319 .70212 m .33053 .699 L .33237 .69869 L F
.33319 .70212 m .33113 .70286 L .33053 .699 L F
.879 .678 .155 r
.53607 .73235 m .53607 .73374 L .53395 .73267 L F
.981 .729 .477 r
.59641 .73256 m .59638 .73503 L .59529 .73197 L F
.982 .75 .509 r
.59641 .73256 m .59529 .73197 L .59538 .72949 L F
.227 0 0 r
.46876 .774 m .47098 .77383 L .47175 .77327 L F
.686 .249 .206 r
.47098 .77383 m .47455 .77268 L .47175 .77327 L F
.536 .476 .736 r
.30069 .69219 m .30109 .69433 L .30301 .69387 L F
.532 .376 .615 r
.30109 .69433 m .30308 .69639 L .30301 .69387 L F
.30109 .69433 m .30116 .69683 L .30308 .69639 L F
.665 .531 .691 r
.61395 .65033 m .61777 .64791 L .61396 .64785 L F
.203 0 .07 r
.28779 .64778 m .29062 .64571 L .28958 .64716 L F
.127 0 .043 r
.28958 .64716 m .29062 .64571 L .29232 .64489 L F
.554 .381 .6 r
.39977 .77081 m .40234 .7704 L .40232 .76794 L F
.561 .404 .626 r
.39977 .77081 m .4001 .77337 L .40234 .7704 L F
.536 .78 .988 r
.37829 .64997 m .37959 .65106 L .37621 .65037 L F
.336 .633 .961 r
.38033 .64989 m .37959 .65106 L .37829 .64997 L F
.38033 .64989 m .38193 .65149 L .37959 .65106 L F
.108 0 0 r
.57387 .66936 m .57359 .6699 L .57569 .66914 L F
0 0 .207 r
.62985 .6827 m .62884 .68608 L .62916 .68396 L F
.352 .327 .691 r
.56733 .69363 m .56842 .69023 L .56724 .69156 L F
.349 .501 .868 r
.53629 .74345 m .53524 .74143 L .53567 .74129 L F
.356 .604 .942 r
.55457 .71119 m .5554 .70997 L .55381 .70983 L F
.55457 .71119 m .55866 .7119 L .5554 .70997 L F
.984 .751 .506 r
.48126 .73834 m .48162 .74087 L .48025 .73986 L F
.609 .504 .709 r
.48361 .73792 m .48162 .74087 L .48126 .73834 L F
0 0 0 r
.70668 .57759 m .70705 .57733 L .70478 .57876 L F
.70673 .57755 m .70676 .57753 L .70668 .57759 L F
.70676 .57753 m .70705 .57733 L .70668 .57759 L F
.888 .596 .487 r
.70561 .57964 m .70786 .57797 L .70593 .57807 L F
0 0 0 r
.70673 .57755 m .70478 .57876 L .70399 .57809 L F
.888 .596 .487 r
.70533 .57845 m .70593 .57807 L .70525 .5781 L F
.70561 .57964 m .70593 .57807 L .70533 .57845 L F
.681 .925 .615 r
.33548 .73144 m .33488 .73255 L .33718 .72992 L F
.091 0 0 r
.33956 .72983 m .33548 .73144 L .33718 .72992 L F
.508 .297 .528 r
.41115 .67796 m .41093 .68026 L .40887 .68069 L F
.486 .279 .523 r
.41297 .67969 m .41115 .67796 L .41324 .67749 L F
.41297 .67969 m .41093 .68026 L .41115 .67796 L F
.345 .634 .961 r
.2832 .61156 m .28377 .61043 L .28143 .61041 L F
.2832 .61156 m .28513 .61179 L .28377 .61043 L F
.277 .269 .67 r
.2832 .61156 m .28507 .61422 L .28513 .61179 L F
.698 .691 .84 r
.69878 .59266 m .69754 .5964 L .69654 .59367 L F
.69878 .59266 m .69949 .59534 L .69754 .5964 L F
.609 .686 .897 r
.33814 .70652 m .33448 .70529 L .33653 .70522 L F
.665 .772 .929 r
.34 .70575 m .33814 .70652 L .33653 .70522 L F
0 0 0 r
.50269 .73254 m .50135 .73417 L .50042 .73528 L F
.755 .669 .767 r
.50135 .73417 m .49915 .73697 L .50042 .73528 L F
.481 .744 .986 r
.29939 .59922 m .29736 .5995 L .29589 .59834 L F
.681 .519 .66 r
.30032 .72922 m .29772 .73241 L .29684 .72954 L F
.30032 .72922 m .29911 .73239 L .29772 .73241 L F
.30032 .72922 m .30022 .73236 L .29911 .73239 L F
.56 .418 .645 r
.30232 .72944 m .30022 .73236 L .30032 .72922 L F
.153 .257 .719 r
.28451 .61792 m .28628 .61972 L .28509 .61653 L F
.451 .311 .599 r
.2845 .62015 m .28628 .61972 L .28451 .61792 L F
.59 .347 .516 r
.48613 .73535 m .48796 .73761 L .48589 .73757 L F
.48613 .73535 m .48825 .73527 L .48796 .73761 L F
.084 0 0 r
.28072 .65342 m .28227 .65298 L .27998 .65434 L F
.499 0 0 r
.67487 .61558 m .67217 .6143 L .67377 .61447 L F
.349 .501 .868 r
.53629 .74345 m .53803 .74303 L .53524 .74143 L F
.663 .122 0 r
.53629 .74345 m .53873 .74575 L .53688 .74458 L F
.652 .416 .55 r
.53895 .74337 m .53873 .74575 L .53629 .74345 L F
.663 .122 0 r
.53629 .74345 m .53688 .74458 L .53803 .74303 L F
.43 .738 .992 r
.27316 .60626 m .27358 .60462 L .27323 .60514 L F
.27316 .60626 m .27604 .60617 L .27358 .60462 L F
.65 .568 .749 r
.6019 .70731 m .60506 .70789 L .60449 .70452 L F
.646 .388 .515 r
.48162 .74087 m .48143 .74297 L .47916 .74304 L F
.669 .584 .751 r
.48361 .73792 m .48398 .74045 L .48162 .74087 L F
.603 .342 .495 r
.48162 .74087 m .48374 .74305 L .48143 .74297 L F
.48162 .74087 m .48398 .74045 L .48374 .74305 L F
.461 .833 .991 r
.28335 .5967 m .28273 .59767 L .28131 .59708 L F
.28335 .5967 m .285 .59724 L .28273 .59767 L F
.308 0 .255 r
.32745 .65896 m .32665 .66071 L .32927 .65834 L F
.365 .179 .491 r
.29698 .63948 m .29721 .63708 L .29884 .63641 L F
.613 .49 .688 r
.40673 .74889 m .40942 .75106 L .40917 .74848 L F
.40673 .74889 m .40709 .7515 L .40942 .75106 L F
.967 .839 .664 r
.57498 .69071 m .57708 .68883 L .57594 .68787 L F
.57498 .69071 m .57614 .69155 L .57708 .68883 L F
.74 .797 .898 r
.30202 .75402 m .3036 .75428 L .30284 .75478 L F
.626 .109 0 r
.47953 .77776 m .48295 .77836 L .48094 .777 L F
.384 0 .043 r
.34914 .64972 m .35264 .64804 L .35057 .64805 L F
.833 .845 .856 r
.39558 .80557 m .39289 .80617 L .39432 .80414 L F
.823 .869 .88 r
.39289 .80617 m .39558 .80557 L .39432 .80414 L F
.432 .59 .908 r
.40236 .78197 m .40473 .78201 L .40352 .78065 L F
.684 .684 .844 r
.29772 .73241 m .29911 .73239 L .29807 .73298 L F
0 0 .178 r
.30022 .73236 m .29807 .73298 L .29911 .73239 L F
.528 .065 .1 r
.437 .78658 m .43341 .78766 L .43491 .78688 L F
.22 .74 .843 r
.43898 .7865 m .437 .78658 L .43491 .78688 L F
.569 .532 .774 r
.56229 .6853 m .56099 .68636 L .55777 .68542 L F
.494 .281 .519 r
.41093 .68026 m .4087 .68296 L .40887 .68069 L F
.251 0 0 r
.35622 .6749 m .35491 .67648 L .35273 .67695 L F
.131 0 0 r
.35848 .67411 m .35761 .67489 L .35622 .6749 L F
.437 .063 .23 r
.35761 .67489 m .35491 .67648 L .35622 .6749 L F
.041 .251 .75 r
.33548 .73144 m .3369 .73452 L .33488 .73255 L F
.452 .342 .638 r
.3369 .73452 m .33539 .73558 L .33488 .73255 L F
.908 .964 .646 r
.60807 .7003 m .60826 .6992 L .60982 .69616 L F
.752 .716 .818 r
.71573 .61729 m .71895 .61763 L .71795 .61478 L F
.732 .751 .867 r
.71895 .61763 m .72042 .61402 L .71795 .61478 L F
.71895 .61763 m .7209 .61616 L .72042 .61402 L F
0 0 0 r
.67678 .60454 m .67554 .60626 L .67789 .60331 L F
.1 0 0 r
.32514 .66165 m .32551 .66262 L .32665 .66071 L F
.32514 .66165 m .32371 .66325 L .32551 .66262 L F
.042 .601 .807 r
.73774 .59896 m .73965 .59891 L .73733 .59749 L F
.73774 .59896 m .7407 .59919 L .73965 .59891 L F
.47 .395 .689 r
.31735 .66445 m .31775 .66685 L .31955 .6664 L F
.303 .772 .649 r
.31932 .72664 m .31783 .72732 L .31701 .72771 L F
.152 .484 .9 r
.31701 .72771 m .31783 .72732 L .31576 .72634 L F
.719 .639 .768 r
.31814 .80484 m .3169 .80655 L .31564 .80317 L F
.31814 .80484 m .31564 .80317 L .31776 .80426 L F
.519 .566 .843 r
.3169 .80655 m .31776 .80426 L .31555 .80586 L F
.3169 .80655 m .31906 .80631 L .31776 .80426 L F
.584 .829 .991 r
.41483 .78962 m .41869 .79002 L .41699 .7895 L F
0 .143 .673 r
.41869 .79002 m .41942 .78914 L .41921 .78878 L F
.605 .908 .983 r
.41921 .78878 m .41699 .7895 L .41869 .79002 L F
.834 .672 .682 r
.58893 .71974 m .59089 .71896 L .58757 .71809 L F
.58893 .71974 m .59035 .72132 L .59089 .71896 L F
.444 0 0 r
.53127 .71771 m .53249 .71842 L .52989 .71666 L F
.575 .297 .457 r
.39519 .77751 m .39755 .77821 L .39586 .77727 L F
.533 .422 .673 r
.39519 .77751 m .39589 .78118 L .39755 .77821 L F
0 .12 .639 r
.50352 .73129 m .50269 .73254 L .50189 .7294 L F
.525 .356 .595 r
.50352 .73129 m .50135 .73417 L .50269 .73254 L F
.545 .312 .513 r
.61263 .65341 m .61452 .65289 L .61395 .65033 L F
.665 .531 .691 r
.61395 .65033 m .6177 .65044 L .61777 .64791 L F
.707 .473 .567 r
.61452 .65289 m .6177 .65044 L .61395 .65033 L F
.725 .721 .846 r
.68612 .58758 m .68716 .59015 L .68509 .5906 L F
.842 .773 .785 r
.68612 .58758 m .68716 .59015 L .68864 .58752 L F
.68864 .58752 m .68716 .59015 L .68612 .58758 L F
.68864 .58752 m .68716 .59015 L .68612 .58758 L F
.463 .603 .905 r
.55866 .7119 m .55783 .71357 L .55943 .71213 L F
.423 .531 .863 r
.55783 .71357 m .56117 .71521 L .55943 .71213 L F
.524 .809 .998 r
.28872 .59772 m .285 .59724 L .28707 .59699 L F
.156 .643 .92 r
.29042 .59785 m .28872 .59772 L .28707 .59699 L F
.711 .543 .659 r
.6177 .65044 m .62015 .64743 L .61777 .64791 L F
.6177 .65044 m .62111 .65049 L .62015 .64743 L F
.536 .476 .736 r
.30069 .69219 m .30301 .69387 L .30284 .69147 L F
0 .121 .651 r
.73614 .58726 m .73804 .58955 L .73612 .58773 L F
.471 .209 .435 r
.38939 .70221 m .38718 .70498 L .38777 .7024 L F
.479 .322 .59 r
.39048 .67474 m .39251 .67439 L .39249 .67222 L F
.76 .691 .786 r
.57283 .70479 m .57387 .7085 L .56997 .70779 L F
.825 .637 .649 r
.57387 .7085 m .57089 .70953 L .56997 .70779 L F
.57387 .7085 m .57276 .70999 L .57089 .70953 L F
.478 .308 .571 r
.60936 .72059 m .60967 .72348 L .60821 .72439 L F
.357 .26 .606 r
.61181 .71799 m .60936 .72059 L .6106 .71802 L F
.61181 .71799 m .61219 .72037 L .60936 .72059 L F
.328 .188 .534 r
.61219 .72037 m .60967 .72348 L .60936 .72059 L F
.483 .49 .789 r
.40952 .79454 m .40922 .79567 L .41079 .79536 L F
.411 .202 .483 r
.41079 .79536 m .40851 .79784 L .40922 .79567 L F
.57 .521 .761 r
.33424 .69413 m .33243 .69681 L .33208 .69432 L F
.33424 .69413 m .33507 .69727 L .33243 .69681 L F
.656 .524 .692 r
.33507 .69727 m .33237 .69869 L .33243 .69681 L F
.154 0 0 r
.44018 .78641 m .437 .78658 L .43898 .7865 L F
.27 .719 .959 r
.50074 .78436 m .50192 .78496 L .50088 .78498 L F
.707 .573 .703 r
.68509 .5906 m .68499 .59233 L .68313 .59327 L F
.725 .721 .846 r
.68612 .58758 m .68509 .5906 L .68398 .58771 L F
.488 .488 .782 r
.4054 .65725 m .40417 .65976 L .4031 .65815 L F
.4054 .65725 m .40657 .66075 L .40417 .65976 L F
.24 0 .064 r
.51394 .78649 m .51579 .78652 L .51672 .78478 L F
.281 0 .084 r
.51672 .78478 m .51784 .78595 L .51897 .78456 L F
.51672 .78478 m .51579 .78652 L .51784 .78595 L F
.602 .746 .946 r
.39846 .80334 m .40223 .80397 L .40057 .80299 L F
.39846 .80334 m .40223 .80397 L .40057 .80299 L F
.724 .511 .603 r
.4471 .75108 m .4436 .75131 L .44361 .74887 L F
.757 .607 .69 r
.69853 .59034 m .70222 .59038 L .70024 .59361 L F
.238 .338 .764 r
.55962 .73559 m .56049 .73845 L .55915 .73521 L F
.167 .288 .744 r
.55962 .73559 m .56152 .73742 L .56049 .73845 L F
.226 .324 .755 r
.56152 .73742 m .56162 .74017 L .56049 .73845 L F
.594 .543 .767 r
.69529 .58972 m .69654 .59367 L .69399 .5941 L F
.828 .758 .786 r
.52253 .72683 m .52432 .72913 L .52026 .72883 L F
.698 .225 .125 r
.52432 .72913 m .52248 .73076 L .52026 .72883 L F
0 0 0 r
.52618 .72627 m .52432 .72913 L .52253 .72683 L F
.573 .305 .471 r
.52514 .72856 m .52248 .73076 L .52432 .72913 L F
.328 .663 .974 r
.27426 .59526 m .27378 .59632 L .27232 .59536 L F
.27426 .59526 m .27552 .59642 L .27378 .59632 L F
.436 .193 .446 r
.31197 .61512 m .3113 .6172 L .30961 .6177 L F
.352 .123 .42 r
.31376 .6142 m .31197 .61512 L .31417 .61227 L F
.384 .156 .44 r
.31376 .6142 m .3113 .6172 L .31197 .61512 L F
.674 .537 .69 r
.29717 .70248 m .30001 .70471 L .29903 .70192 L F
.29717 .70248 m .29761 .70527 L .30001 .70471 L F
.179 .161 .6 r
.31688 .60621 m .31582 .6061 L .31542 .60418 L F
.757 .282 .115 r
.31688 .60621 m .31542 .60418 L .31405 .60469 L F
.955 .775 .62 r
.67642 .59742 m .67867 .5993 L .67739 .59578 L F
.659 .945 .959 r
.67419 .60003 m .67867 .5993 L .67642 .59742 L F
.67419 .60003 m .67521 .60043 L .67867 .5993 L F
.757 .703 .801 r
.67739 .59578 m .67867 .5993 L .67966 .59527 L F
.955 .775 .62 r
.67642 .59742 m .67867 .5993 L .67739 .59578 L F
.795 .625 .671 r
.68499 .59233 m .68168 .59516 L .68313 .59327 L F
.68499 .59233 m .6847 .59575 L .68168 .59516 L F
.476 .36 .642 r
.40546 .75708 m .40726 .75382 L .4052 .75526 L F
.545 0 0 r
.48219 .78353 m .48536 .78458 L .48415 .78453 L F
.241 0 0 r
.48536 .78458 m .48664 .78517 L .48415 .78453 L F
.48536 .78458 m .48783 .78476 L .48664 .78517 L F
.483 0 0 r
.44127 .77517 m .44058 .77448 L .43913 .77337 L F
.44127 .77517 m .44264 .77601 L .44058 .77448 L F
.679 .235 .189 r
.44058 .77448 m .44264 .77601 L .44378 .77531 L F
.748 .562 .643 r
.62651 .65299 m .62663 .65059 L .62345 .65041 L F
0 .335 .818 r
.73946 .59502 m .74241 .59787 L .74 .59605 L F
.433 .865 .757 r
.69935 .58005 m .70103 .57898 L .70209 .57974 L F
.6 .592 .815 r
.703 .5826 m .69935 .58005 L .70209 .57974 L F
.342 .555 .913 r
.27604 .60617 m .27611 .6071 L .27677 .60566 L F
.37 .589 .929 r
.27611 .6071 m .27777 .60715 L .27677 .60566 L F
.371 .542 .894 r
.27777 .60715 m .27957 .60972 L .28043 .60821 L F
.316 .471 .856 r
.27957 .60972 m .28143 .61041 L .28043 .60821 L F
.752 .838 .917 r
.55019 .69203 m .54775 .69336 L .54636 .69226 L F
.287 .334 .736 r
.57192 .73794 m .57363 .73703 L .57125 .73483 L F
.036 0 .434 r
.57192 .73794 m .57332 .73915 L .57363 .73703 L F
.57192 .73794 m .57193 .74036 L .57332 .73915 L F
.514 .381 .637 r
.40395 .7624 m .40586 .762 L .40574 .75952 L F
.525 .391 .64 r
.40395 .7624 m .40615 .76496 L .40586 .762 L F
.40395 .7624 m .40413 .76543 L .40615 .76496 L F
.502 .524 .812 r
.72683 .59902 m .72792 .59582 L .72558 .59823 L F
.72683 .59902 m .72908 .59935 L .72792 .59582 L F
.823 .521 .478 r
.60616 .65313 m .60651 .65521 L .6077 .65316 L F
.684 .346 .397 r
.60651 .65521 m .60987 .65513 L .6077 .65316 L F
.689 .343 .385 r
.60987 .65513 m .61047 .65372 L .6077 .65316 L F
.461 .596 .9 r
.71902 .72189 m .7216 .72173 L .72061 .72061 L F
.364 .416 .782 r
.72061 .72061 m .72164 .72383 L .71902 .72189 L F
.414 .419 .755 r
.71902 .72189 m .72164 .72383 L .71977 .72367 L F
.622 .872 .526 r
.68011 .60059 m .67911 .60188 L .67789 .60331 L F
.112 0 0 r
.3647 .71828 m .36815 .716 L .36677 .7178 L F
.246 0 .007 r
.36677 .7178 m .36815 .716 L .37027 .71538 L F
.165 0 .021 r
.51437 .72723 m .51293 .7278 L .51321 .72626 L F
.827 .666 .682 r
.58642 .71748 m .58922 .7159 L .58848 .71484 L F
.58642 .71748 m .58757 .71809 L .58922 .7159 L F
.508 .264 .48 r
.53113 .73675 m .52994 .73565 L .53188 .73465 L F
.53113 .73675 m .52888 .73762 L .52994 .73565 L F
0 0 0 r
.3346 .82708 m .33565 .82549 L .33603 .82492 L F
.33603 .82492 m .33565 .82549 L .3346 .82708 L F
.52462 .79041 m .52379 .79019 L .52571 .78948 L F
.52462 .79041 m .5222 .7913 L .52379 .79019 L F
.216 0 .222 r
.27574 .63627 m .27757 .63417 L .27659 .63507 L F
.268 0 0 r
.45425 .78471 m .45404 .78571 L .44975 .78579 L F
0 0 0 r
.45493 .78511 m .45425 .78471 L .45628 .78441 L F
.45493 .78511 m .45404 .78571 L .45425 .78471 L F
.482 .277 .524 r
.30961 .6177 m .30943 .61979 L .30745 .62042 L F
.417 .169 .427 r
.30943 .61979 m .30696 .62251 L .30745 .62042 L F
.705 .689 .831 r
.54521 .73305 m .54679 .73404 L .54716 .73235 L F
.476 .418 .713 r
.54679 .73404 m .54953 .73145 L .54716 .73235 L F
.54679 .73404 m .54956 .7336 L .54953 .73145 L F
.63 .372 .508 r
.49211 .73335 m .49193 .73479 L .48825 .73527 L F
.644 .691 .879 r
.49384 .73298 m .49211 .73335 L .49122 .73129 L F
.452 .107 .289 r
.38105 .70848 m .38015 .70992 L .37809 .71026 L F
.118 0 .08 r
.38273 .70757 m .38015 .70992 L .38105 .70848 L F
.308 0 .216 r
.58613 .66072 m .58812 .66093 L .58875 .65877 L F
.236 0 .189 r
.58875 .65877 m .59 .66001 L .5907 .65787 L F
.58875 .65877 m .58812 .66093 L .59 .66001 L F
.421 0 0 r
.44264 .77601 m .44604 .77561 L .44378 .77531 L F
.476 .394 .685 r
.43371 .75921 m .43258 .76293 L .43133 .7596 L F
.43371 .75921 m .43425 .76265 L .43258 .76293 L F
.491 .629 .913 r
.43425 .76265 m .43627 .76398 L .43258 .76293 L F
.531 .331 .554 r
.57137 .68288 m .57125 .68559 L .56905 .68585 L F
.978 .731 .491 r
.57008 .68247 m .57125 .68559 L .57137 .68288 L F
.216 .714 .914 r
.57353 .68281 m .57008 .68247 L .57137 .68288 L F
.891 .838 .787 r
.63103 .67239 m .63096 .66944 L .62973 .67161 L F
.954 .749 .586 r
.63082 .67472 m .63103 .67239 L .62973 .67161 L F
.75 .76 .251 r
.30663 .72923 m .30589 .73225 L .30523 .72931 L F
.839 .61 .592 r
.61373 .67535 m .6112 .677 L .61137 .67456 L F
.61373 .67535 m .61334 .67783 L .6112 .677 L F
.235 0 .238 r
.58442 .67358 m .58318 .67234 L .58523 .67185 L F
.58442 .67358 m .58264 .67458 L .58318 .67234 L F
.425 .147 .386 r
.40414 .68596 m .40365 .68823 L .40166 .68868 L F
.44 .16 .391 r
.4057 .68774 m .40414 .68596 L .40627 .68579 L F
.4057 .68774 m .40365 .68823 L .40414 .68596 L F
.41 .25 .551 r
.31592 .60991 m .31518 .61276 L .31417 .61227 L F
.438 .194 .444 r
.31518 .61276 m .31376 .6142 L .31417 .61227 L F
.444 .236 .502 r
.3113 .6172 m .30943 .61979 L .30961 .6177 L F
.092 .19 .675 r
.57009 .70639 m .56946 .70764 L .56659 .70516 L F
.57009 .70639 m .56997 .70779 L .56946 .70764 L F
.174 .706 .838 r
.44633 .78597 m .44529 .78586 L .44277 .78602 L F
.093 0 0 r
.44845 .78579 m .44529 .78586 L .44633 .78597 L F
.363 .105 .384 r
.28779 .64778 m .28717 .64972 L .2854 .65044 L F
.297 .045 .353 r
.28886 .64975 m .28779 .64778 L .28958 .64716 L F
.28886 .64975 m .28717 .64972 L .28779 .64778 L F
.543 .244 .411 r
.43682 .75681 m .43599 .75913 L .43371 .75921 L F
.586 .287 .429 r
.43903 .75857 m .43682 .75681 L .43903 .75665 L F
.43903 .75857 m .43599 .75913 L .43682 .75681 L F
.422 .241 .528 r
.60068 .71336 m .602 .71447 L .60301 .71304 L F
.60068 .71336 m .60051 .71563 L .602 .71447 L F
.055 .62 .705 r
.53249 .71842 m .53612 .71814 L .53384 .71919 L F
.221 .117 .517 r
.56641 .70201 m .56659 .70516 L .56591 .70411 L F
.557 .162 .249 r
.46653 .72872 m .46882 .72884 L .47008 .72688 L F
.455 .009 .1 r
.46882 .72884 m .47249 .72704 L .47008 .72688 L F
.837 .788 .805 r
.68612 .58758 m .68864 .58752 L .68853 .58703 L F
.842 .773 .785 r
.68612 .58758 m .68864 .58752 L .68853 .58703 L F
.618 .164 .153 r
.5395 .73243 m .53814 .73371 L .53692 .73291 L F
.53716 .73238 m .53692 .73291 L .53607 .73235 L F
.5395 .73243 m .53692 .73291 L .53716 .73238 L F
.53814 .73371 m .53766 .73365 L .53607 .73235 L F
.879 .678 .155 r
.53607 .73235 m .53598 .73425 L .53607 .73374 L F
.528 .22 .389 r
.53796 .73388 m .53598 .73425 L .53607 .73235 L F
.568 .293 .458 r
.53594 .73585 m .533 .73721 L .53607 .73374 L F
.486 .189 .387 r
.53607 .73374 m .53113 .73675 L .53188 .73465 L F
.53607 .73374 m .533 .73721 L .53113 .73675 L F
.617 .479 .672 r
.53289 .73118 m .53345 .73481 L .53598 .73422 L F
.568 .293 .458 r
.53598 .73426 m .53607 .73374 L .53598 .73424 L F
.53594 .73585 m .53605 .73407 L .53598 .73427 L F
.617 .479 .672 r
.53599 .73404 m .53598 .73422 L .53613 .73418 L F
.53289 .73118 m .53598 .73422 L .53599 .73404 L F
.568 .293 .458 r
.53598 .73427 m .53598 .73426 L .53598 .73425 L F
.53598 .73426 m .53598 .73424 L .53598 .73425 L F
.617 .479 .672 r
.53289 .73118 m .53599 .73404 L .5349 .73142 L F
.568 .293 .458 r
.53605 .73407 m .53607 .73374 L .53599 .73421 L F
.617 .479 .672 r
.53599 .73404 m .53613 .73418 L .53598 .73383 L F
.53599 .73404 m .53598 .73383 L .5349 .73142 L F
.568 .293 .458 r
.53599 .73424 m .53599 .73421 L .53598 .73427 L F
.53605 .73407 m .53599 .73421 L .53599 .73424 L F
.58 .378 .572 r
.53796 .73388 m .53594 .73585 L .53598 .73427 L F
.53603 .73424 m .53598 .73427 L .53598 .73425 L F
.53796 .73388 m .53598 .73427 L .53603 .73424 L F
0 0 0 r
.53613 .73418 m .53595 .73437 L .53621 .73506 L F
.53595 .73437 m .5345 .73583 L .53563 .73532 L F
.53595 .73437 m .53563 .73532 L .53621 .73506 L F
.53666 .7335 m .53621 .73506 L .5373 .73268 L F
.53613 .73418 m .53617 .73462 L .53666 .7335 L F
.53617 .73462 m .53621 .73506 L .53666 .7335 L F
.689 .586 .735 r
.5349 .73142 m .53578 .73338 L .5373 .73268 L F
.53578 .73338 m .53613 .73418 L .53666 .7335 L F
.53578 .73338 m .53666 .7335 L .5373 .73268 L F
.618 .164 .153 r
.53814 .73371 m .53796 .73388 L .53766 .73365 L F
.063 0 0 r
.54187 .73339 m .53796 .73388 L .5395 .73243 L F
.663 .555 .723 r
.52542 .72821 m .52494 .73019 L .52714 .72949 L F
.062 0 0 r
.59566 .66565 m .59487 .66631 L .59324 .66652 L F
.412 .055 .245 r
.59487 .66631 m .5921 .66823 L .59324 .66652 L F
.286 0 .032 r
.58613 .66072 m .58504 .66251 L .58812 .66093 L F
.598 .431 .627 r
.30236 .68869 m .30486 .68887 L .30471 .68646 L F
.645 .522 .698 r
.30284 .69147 m .30486 .68887 L .30236 .68869 L F
.407 .842 .944 r
.3861 .65091 m .38526 .65172 L .38393 .65114 L F
.3861 .65091 m .38632 .65136 L .38526 .65172 L F
.512 .247 .45 r
.37791 .69672 m .38006 .69641 L .38053 .69441 L F
.488 .307 .561 r
.38053 .69441 m .38251 .69386 L .38262 .69143 L F
.47 .209 .435 r
.38053 .69441 m .38213 .69594 L .38251 .69386 L F
.38053 .69441 m .38006 .69641 L .38213 .69594 L F
.83 .631 .633 r
.62955 .66124 m .62946 .66371 L .63231 .66399 L F
.89 .795 .748 r
.62918 .66611 m .63231 .66399 L .62946 .66371 L F
.62918 .66611 m .63074 .66673 L .63231 .66399 L F
.56 .934 .894 r
.36529 .83283 m .36536 .83342 L .3644 .83342 L F
.3644 .83342 m .36536 .83342 L .36529 .83283 L F
.338 0 0 r
.3644 .67268 m .36274 .67377 L .3607 .6738 L F
.454 .022 .127 r
.36635 .67195 m .36274 .67377 L .3644 .67268 L F
.575 .401 .608 r
.42393 .7352 m .42188 .73663 L .42411 .73616 L F
.143 0 0 r
.42069 .73503 m .42231 .73516 L .4236 .73491 L F
.42231 .73516 m .42274 .73517 L .4236 .73491 L F
.816 .974 .674 r
.4236 .73491 m .42268 .73518 L .42368 .73386 L F
.575 .401 .608 r
.42368 .73386 m .42283 .73517 L .42393 .7352 L F
.42283 .73517 m .42188 .73663 L .42393 .7352 L F
.143 0 0 r
.42231 .73516 m .42268 .73518 L .42274 .73517 L F
.816 .974 .674 r
.4236 .73491 m .42368 .73386 L .42538 .73463 L F
.511 .368 .623 r
.33466 .69268 m .33424 .69413 L .33208 .69432 L F
.575 .557 .796 r
.31932 .72664 m .32261 .7295 L .32137 .72642 L F
.146 0 0 r
.32137 .72642 m .31783 .72732 L .31932 .72664 L F
.602 .13 .107 r
.51126 .78656 m .51278 .78805 L .51394 .78649 L F
.205 0 0 r
.51278 .78805 m .51579 .78652 L .51394 .78649 L F
.349 .138 .446 r
.2785 .63143 m .28002 .63279 L .2802 .63036 L F
.2785 .63143 m .27807 .63362 L .28002 .63279 L F
.585 .37 .555 r
.31505 .6695 m .31756 .66939 L .31775 .66685 L F
.371 .193 .505 r
.31775 .66685 m .31917 .66866 L .31955 .6664 L F
.31775 .66685 m .31756 .66939 L .31917 .66866 L F
.397 .536 .878 r
.56117 .71521 m .56125 .71638 L .56262 .71506 L F
.25 .295 .714 r
.56125 .71638 m .56333 .71856 L .56262 .71506 L F
0 0 0 r
.36715 .64725 m .36801 .64665 L .36912 .64573 L F
.469 .24 .483 r
.39446 .6963 m .39183 .69892 L .39235 .69688 L F
.527 .351 .585 r
.40709 .7515 m .40912 .75345 L .40942 .75106 L F
.40709 .7515 m .40726 .75382 L .40912 .75345 L F
.995 .872 .568 r
.63055 .68063 m .62925 .68209 L .62985 .6827 L F
.973 .797 .374 r
.6303 .6776 m .63003 .68003 L .63055 .68063 L F
.972 .917 .586 r
.63003 .68003 m .62925 .68209 L .63055 .68063 L F
.825 .744 .775 r
.71142 .61073 m .71227 .61241 L .7096 .61186 L F
.99 .732 .423 r
.71227 .61241 m .71135 .61384 L .7096 .61186 L F
.71227 .61241 m .71232 .61508 L .71135 .61384 L F
.733 .71 .829 r
.71448 .61089 m .71227 .61241 L .71142 .61073 L F
.593 .611 .839 r
.33448 .70529 m .33113 .70286 L .33319 .70212 L F
.516 .551 .831 r
.33503 .70198 m .33448 .70529 L .33319 .70212 L F
.33503 .70198 m .33653 .70522 L .33448 .70529 L F
.115 .663 .816 r
.73085 .71162 m .72797 .71172 L .72691 .71153 L F
.529 .731 .967 r
.37082 .83579 m .36877 .8361 L .36779 .83482 L F
.37082 .83579 m .36877 .8361 L .36779 .83482 L F
.862 .979 .855 r
.57498 .69071 m .57341 .69383 L .57614 .69155 L F
.57498 .69071 m .57244 .69343 L .57341 .69383 L F
.958 .75 .58 r
.31656 .73675 m .31802 .73747 L .31858 .73527 L F
.26 0 .191 r
.2854 .65044 m .28631 .65191 L .28425 .65251 L F
.2854 .65044 m .28717 .64972 L .28631 .65191 L F
.476 .36 .642 r
.40546 .75708 m .4073 .75675 L .40726 .75382 L F
.527 .423 .68 r
.40574 .75952 m .4073 .75675 L .40546 .75708 L F
.755 .66 .757 r
.50584 .72158 m .50362 .72429 L .5024 .72121 L F
.154 0 0 r
.44018 .78641 m .43947 .78657 L .437 .78658 L F
.031 0 0 r
.44277 .78602 m .43947 .78657 L .44018 .78641 L F
.509 .106 .213 r
.44819 .77526 m .45049 .77532 L .45171 .77335 L F
.294 0 .092 r
.45171 .77335 m .45254 .77476 L .45386 .77316 L F
.45171 .77335 m .45049 .77532 L .45254 .77476 L F
.596 .414 .605 r
.40232 .76794 m .40455 .7701 L .40467 .76773 L F
.40232 .76794 m .40234 .7704 L .40455 .7701 L F
0 0 0 r
.56264 .69385 m .5597 .6971 L .56133 .69611 L F
.653 .32 .396 r
.56264 .69385 m .56133 .69611 L .56536 .69598 L F
.671 .304 .341 r
.56264 .69385 m .56536 .69598 L .56491 .69454 L F
.654 .633 .816 r
.71232 .61508 m .71342 .61791 L .71573 .61729 L F
.504 .372 .635 r
.56348 .69076 m .56125 .68884 L .56385 .68868 L F
.56348 .69076 m .56161 .6918 L .56125 .68884 L F
.493 .724 .974 r
.67929 .58586 m .6774 .58693 L .67863 .5855 L F
.545 .46 .709 r
.67911 .58791 m .67914 .58841 L .67708 .58869 L F
.334 .806 .913 r
.67929 .58586 m .68118 .58585 L .68048 .58543 L F
.68118 .58585 m .68323 .58584 L .68048 .58543 L F
.68056 .58585 m .68184 .58563 L .68323 .58584 L F
.67929 .58586 m .68184 .58563 L .68056 .58585 L F
.502 .044 .097 r
.68323 .58584 m .6864 .58542 L .68307 .58516 L F
.68323 .58584 m .68524 .58633 L .6864 .58542 L F
.516 .153 .29 r
.68068 .58536 m .68323 .58584 L .68307 .58516 L F
.234 .567 .938 r
.68424 .58509 m .68323 .58584 L .68184 .58563 L F
.68424 .58509 m .68524 .58633 L .68323 .58584 L F
.493 .179 .362 r
.68396 .58695 m .68422 .58522 L .68184 .58563 L F
.68422 .58522 m .68424 .58509 L .68184 .58563 L F
.742 .741 .851 r
.67863 .5855 m .68184 .58563 L .67929 .58586 L F
.068 0 .041 r
.67911 .58791 m .68184 .58563 L .67895 .58551 L F
.67914 .58841 m .68156 .58592 L .67911 .58791 L F
.68156 .58592 m .68184 .58563 L .67911 .58791 L F
.67906 .58795 m .67895 .58551 L .67863 .5855 L F
.67914 .58841 m .67911 .58791 L .67906 .58795 L F
.67911 .58791 m .67895 .58551 L .67906 .58795 L F
.545 .46 .709 r
.6797 .58768 m .67914 .58841 L .67911 .58791 L F
.6797 .58768 m .67911 .58791 L .67963 .58773 L F
.67911 .58791 m .67708 .58869 L .67906 .58795 L F
.67911 .58791 m .67906 .58795 L .67963 .58773 L F
0 0 .106 r
.67906 .58795 m .67708 .58869 L .67914 .58841 L F
.545 .46 .709 r
.67963 .58773 m .67906 .58795 L .67629 .59039 L F
.67906 .58795 m .67708 .58869 L .67643 .59008 L F
.67906 .58795 m .67643 .59008 L .67629 .59039 L F
0 0 .106 r
.67863 .5855 m .67708 .58869 L .67906 .58795 L F
.482 .182 .38 r
.67813 .59021 m .6797 .58768 L .67629 .59039 L F
.68014 .59 m .6798 .58821 L .67813 .59021 L F
.6798 .58821 m .6797 .58768 L .67813 .59021 L F
.068 0 .041 r
.68137 .58632 m .6809 .58755 L .68161 .5861 L F
.623 .274 .358 r
.68014 .59 m .68084 .58978 L .67989 .58804 L F
.068 0 .041 r
.67914 .58841 m .67989 .58804 L .6803 .58733 L F
.623 .274 .358 r
.67989 .58804 m .67989 .58804 L .6797 .58768 L F
.068 0 .041 r
.6803 .58733 m .67997 .58801 L .68137 .58632 L F
.312 .157 .503 r
.67989 .58804 m .68084 .58978 L .6809 .58755 L F
.068 0 .041 r
.67989 .58804 m .67997 .58801 L .67997 .58801 L F
.67989 .58804 m .67997 .58801 L .6803 .58733 L F
.67989 .58804 m .67997 .58801 L .67989 .58804 L F
.312 .157 .503 r
.6797 .58768 m .67989 .58804 L .6809 .58755 L F
.6797 .58768 m .6809 .58755 L .67989 .58804 L F
.6797 .58768 m .67989 .58804 L .67914 .58841 L F
.623 .274 .358 r
.6798 .58821 m .67989 .58804 L .6797 .58768 L F
.68014 .59 m .67989 .58804 L .6798 .58821 L F
.068 0 .041 r
.67997 .58801 m .6809 .58755 L .68137 .58632 L F
.68146 .58602 m .68161 .5861 L .68184 .58563 L F
.67914 .58841 m .68161 .5861 L .68146 .58602 L F
.334 .806 .913 r
.68048 .58543 m .68323 .58584 L .68068 .58536 L F
.588 .358 .534 r
.68068 .58536 m .68307 .58516 L .68503 .58328 L F
0 .32 .717 r
.5782 .72365 m .57995 .72469 L .57785 .72366 L F
.872 .792 .768 r
.30898 .73733 m .31259 .73516 L .31113 .73454 L F
.30898 .73733 m .31062 .73833 L .31259 .73516 L F
.319 .583 .937 r
.31259 .73516 m .31323 .73398 L .31113 .73454 L F
.31259 .73516 m .31508 .73597 L .31323 .73398 L F
.537 .414 .66 r
.40402 .77634 m .40624 .77589 L .40577 .77316 L F
.324 .015 .278 r
.40356 .77832 m .40624 .77589 L .40402 .77634 L F
.474 .248 .49 r
.39183 .69892 m .38939 .70221 L .39009 .69955 L F
.339 0 .037 r
.56905 .68585 m .56793 .68753 L .56556 .68791 L F
.792 .564 .592 r
.57125 .68559 m .56793 .68753 L .56905 .68585 L F
.569 .361 .559 r
.33794 .68541 m .33863 .68967 L .33638 .68976 L F
.551 .335 .54 r
.34087 .68308 m .34187 .68629 L .33794 .68541 L F
.503 .317 .561 r
.34046 .68851 m .33794 .68541 L .34187 .68629 L F
.34046 .68851 m .33863 .68967 L .33794 .68541 L F
.156 0 0 r
.35805 .64909 m .36014 .64899 L .36186 .64839 L F
0 0 0 r
.36014 .64899 m .36394 .64803 L .36186 .64839 L F
.561 .931 .919 r
.43026 .78759 m .42835 .78886 L .43169 .78761 L F
.006 .577 .773 r
.43169 .78761 m .43169 .78747 L .43026 .78759 L F
.555 .507 .756 r
.4183 .73992 m .4197 .73708 L .41877 .73704 L F
.747 .71 .817 r
.46711 .75146 m .46387 .75147 L .46606 .74951 L F
.571 .582 .825 r
.46677 .75325 m .46387 .75147 L .46711 .75146 L F
.536 .226 .389 r
.46959 .75155 m .46677 .75325 L .46711 .75146 L F
.059 .573 .878 r
.50583 .79088 m .50719 .79159 L .50889 .79186 L F
.521 .33 .563 r
.71766 .59865 m .71795 .60111 L .71544 .60139 L F
.46 .871 .721 r
.50567 .70799 m .50671 .70718 L .50763 .70668 L F
.50567 .70799 m .50378 .70886 L .50671 .70718 L F
.27 .242 .643 r
.56776 .69919 m .56641 .70201 L .56585 .69934 L F
.56776 .69919 m .56831 .7015 L .56641 .70201 L F
0 0 .437 r
.56771 .70383 m .56641 .70201 L .56831 .7015 L F
.56771 .70383 m .56659 .70516 L .56641 .70201 L F
.3 0 .172 r
.59385 .75999 m .59588 .75937 L .59279 .76138 L F
.233 0 0 r
.34711 .72719 m .34332 .72812 L .34499 .72746 L F
.643 .183 .146 r
.49193 .77861 m .4944 .78022 L .49551 .77872 L F
.93 .584 .355 r
.49551 .77872 m .4944 .78022 L .49626 .78092 L F
.966 .65 .363 r
.55912 .6989 m .56031 .69951 L .5597 .6971 L F
.015 .067 .572 r
.5597 .6971 m .56131 .69834 L .56133 .69611 L F
.5597 .6971 m .56031 .69951 L .56131 .69834 L F
.595 .554 .778 r
.29761 .70527 m .30048 .70767 L .30001 .70471 L F
.531 .798 .995 r
.71642 .58275 m .71434 .58326 L .71316 .58189 L F
.669 .377 .468 r
.69292 .58141 m .69608 .57955 L .69388 .5792 L F
0 0 0 r
.5667 .67512 m .56815 .67432 L .5691 .67271 L F
.5667 .67512 m .56565 .67673 L .56815 .67432 L F
.34 .388 .766 r
.57193 .74036 m .5728 .74366 L .57443 .74233 L F
.003 .179 .694 r
.5728 .74366 m .57468 .74477 L .57443 .74233 L F
.5728 .74366 m .57438 .74546 L .57468 .74477 L F
.416 0 .085 r
.51293 .7278 m .51183 .7294 L .50924 .72955 L F
.165 0 .021 r
.51437 .72723 m .51381 .72873 L .51293 .7278 L F
.212 0 0 r
.51293 .7278 m .51381 .72873 L .51183 .7294 L F
.397 .026 .212 r
.60987 .65513 m .61263 .65341 L .61047 .65372 L F
0 0 .505 r
.57909 .75693 m .5794 .75641 L .57803 .75382 L F
.007 .169 .684 r
.57909 .75693 m .58083 .75796 L .5794 .75641 L F
.57909 .75693 m .58092 .75929 L .58083 .75796 L F
.216 0 .222 r
.27574 .63627 m .27807 .63362 L .27757 .63417 L F
.164 .236 .692 r
.56962 .72941 m .57022 .73264 L .57147 .73144 L F
.129 .23 .701 r
.57022 .73264 m .57224 .73357 L .57147 .73144 L F
.57022 .73264 m .57125 .73483 L .57224 .73357 L F
0 0 .322 r
.53977 .74476 m .53895 .74337 L .54164 .74275 L F
.53977 .74476 m .53873 .74575 L .53895 .74337 L F
.486 .582 .876 r
.30958 .60447 m .30632 .60209 L .30817 .60134 L F
.576 .65 .886 r
.31065 .60223 m .30958 .60447 L .30817 .60134 L F
.31065 .60223 m .31157 .60413 L .30958 .60447 L F
.662 .686 .862 r
.40957 .78972 m .41269 .79018 L .41129 .78898 L F
.615 .678 .886 r
.41129 .78898 m .41269 .79018 L .41483 .78962 L F
.68 .452 .569 r
.53903 .78652 m .54165 .78421 L .53929 .78457 L F
.508 0 0 r
.58246 .76193 m .58573 .76242 L .5853 .76325 L F
.369 0 .114 r
.58573 .76242 m .58689 .76392 L .5853 .76325 L F
.58573 .76242 m .58796 .76205 L .58689 .76392 L F
.564 .417 .64 r
.40942 .75106 m .41147 .74808 L .40917 .74848 L F
.734 .255 .109 r
.49101 .78417 m .49315 .7862 L .49014 .78534 L F
.278 .309 .714 r
.43803 .76878 m .43913 .77337 L .43752 .772 L F
.815 .396 .249 r
.53062 .78192 m .53232 .78346 L .53366 .78286 L F
.672 .18 .074 r
.53232 .78346 m .53546 .78389 L .53366 .78286 L F
.342 .064 .339 r
.28039 .62852 m .28225 .62808 L .28289 .62586 L F
.333 .056 .335 r
.28289 .62586 m .28421 .62737 L .28441 .62502 L F
.28289 .62586 m .28225 .62808 L .28421 .62737 L F
.213 0 0 r
.37431 .71443 m .37418 .7137 L .37528 .71253 L F
.298 0 .254 r
.37809 .71026 m .37725 .71276 L .37528 .71253 L F
.262 0 .083 r
.37615 .71375 m .37528 .71253 L .37725 .71276 L F
.37615 .71375 m .37431 .71443 L .37528 .71253 L F
.575 .215 .32 r
.36222 .70684 m .36448 .70707 L .3656 .70486 L F
.361 0 .209 r
.3656 .70486 m .36652 .70655 L .36769 .70446 L F
.3656 .70486 m .36448 .70707 L .36652 .70655 L F
.535 .657 .914 r
.30632 .60209 m .30323 .60082 L .3049 .60066 L F
.636 .742 .925 r
.30817 .60134 m .30632 .60209 L .3049 .60066 L F
.638 .252 .295 r
.48641 .77883 m .48852 .78053 L .48981 .77847 L F
.476 .066 .182 r
.48852 .78053 m .49193 .77861 L .48981 .77847 L F
.458 .431 .741 r
.48606 .73979 m .48398 .74045 L .48361 .73792 L F
.345 .129 .435 r
.48374 .74305 m .48398 .74045 L .48606 .73979 L F
.102 .543 .912 r
.31776 .80426 m .31998 .80546 L .31814 .80484 L F
0 0 0 r
.5691 .67271 m .56971 .67314 L .57091 .67165 L F
.5691 .67271 m .56815 .67432 L .56971 .67314 L F
.568 .415 .633 r
.42028 .66927 m .42046 .67232 L .41814 .67252 L F
.403 .086 .31 r
.42046 .67232 m .41778 .67448 L .41814 .67252 L F
.612 .346 .49 r
.43987 .73469 m .44221 .73465 L .44237 .73253 L F
.566 .267 .42 r
.44221 .73465 m .44543 .73202 L .44237 .73253 L F
.242 .386 .809 r
.35023 .70614 m .34943 .70742 L .34753 .70516 L F
.35023 .70614 m .35075 .70769 L .34943 .70742 L F
.354 .725 .987 r
.30342 .59974 m .30323 .60082 L .30119 .59898 L F
.30342 .59974 m .3049 .60066 L .30323 .60082 L F
.642 .613 .805 r
.40816 .78642 m .40957 .78972 L .41129 .78898 L F
.663 .555 .723 r
.52542 .72821 m .52714 .72949 L .52618 .72627 L F
.152 .264 .726 r
.59638 .73503 m .59739 .73813 L .59801 .73696 L F
.728 .442 0 r
.59739 .73813 m .59749 .73879 L .59801 .73696 L F
.59739 .73813 m .59806 .74062 L .59749 .73879 L F
.883 .788 .751 r
.31154 .733 m .3088 .73457 L .30779 .73421 L F
.31154 .733 m .30779 .73421 L .31008 .73438 L F
.932 .577 .328 r
.3117 .73327 m .31154 .733 L .31008 .73438 L F
.3117 .73327 m .31191 .73163 L .31154 .733 L F
.491 .754 .988 r
.58425 .71219 m .5884 .71277 L .58652 .71314 L F
0 .366 .824 r
.58848 .71484 m .58652 .71314 L .5884 .71277 L F
.444 .225 .486 r
.38262 .69143 m .38451 .69094 L .38479 .68877 L F
.524 .358 .599 r
.38251 .69386 m .38451 .69094 L .38262 .69143 L F
.819 .856 .875 r
.58431 .72232 m .58133 .7248 L .58326 .72453 L F
.585 .101 .072 r
.58133 .7248 m .58228 .7257 L .58326 .72453 L F
.819 .856 .875 r
.58431 .72232 m .58133 .7248 L .58326 .72453 L F
.554 .24 .39 r
.43437 .73742 m .43664 .73733 L .43764 .73485 L F
.549 .234 .388 r
.43764 .73485 m .43975 .73626 L .43987 .73469 L F
.43764 .73485 m .43664 .73733 L .43975 .73626 L F
.602 .668 .886 r
.72397 .72351 m .72281 .72628 L .72164 .72383 L F
.72397 .72351 m .72464 .7257 L .72281 .72628 L F
.791 .327 .137 r
.60447 .66702 m .60369 .66816 L .60172 .66586 L F
.77 .299 .123 r
.60447 .66702 m .60649 .66904 L .60369 .66816 L F
.384 .513 .864 r
.53212 .75786 m .53162 .7598 L .52948 .75799 L F
.53212 .75786 m .53299 .75947 L .53162 .7598 L F
.638 .527 .711 r
.53299 .75947 m .53092 .7621 L .53162 .7598 L F
.793 .527 .535 r
.72106 .60134 m .71795 .60111 L .71766 .59865 L F
.831 .889 .883 r
.58695 .72254 m .59035 .72132 L .58893 .71974 L F
.443 0 0 r
.70705 .57733 m .70957 .57871 L .71091 .57924 L F
.687 .325 .355 r
.70991 .58133 m .71091 .57924 L .70957 .57871 L F
.523 .293 .508 r
.38908 .68313 m .39122 .68277 L .39139 .6806 L F
.528 .345 .576 r
.39139 .6806 m .39386 .68026 L .39372 .67766 L F
.404 .139 .395 r
.39122 .68277 m .39386 .68026 L .39139 .6806 L F
.962 .63 .27 r
.57481 .69962 m .57405 .70072 L .57424 .69882 L F
.57481 .69962 m .57536 .70175 L .57405 .70072 L F
.57481 .69962 m .57405 .70072 L .57424 .69882 L F
.57481 .69962 m .57536 .70175 L .57405 .70072 L F
.473 .25 .494 r
.38479 .68877 m .38651 .69048 L .38689 .6883 L F
.38479 .68877 m .38451 .69094 L .38651 .69048 L F
.667 .558 .722 r
.66734 .60175 m .66953 .59753 L .66625 .59845 L F
.66734 .60175 m .66969 .60116 L .66953 .59753 L F
0 0 0 r
.50375 .72666 m .50364 .72753 L .50461 .72716 L F
.50375 .72666 m .50461 .72716 L .50249 .72751 L F
.494 .318 .571 r
.38706 .686 m .3891 .68556 L .38908 .68313 L F
.33 .153 .483 r
.38706 .686 m .38849 .68757 L .3891 .68556 L F
.38706 .686 m .38689 .6883 L .38849 .68757 L F
.192 0 .358 r
.58016 .67695 m .57853 .67982 L .57834 .67783 L F
.647 .631 .82 r
.30418 .73908 m .30715 .73839 L .30361 .73804 L F
.766 .254 0 r
.50293 .78819 m .50225 .78853 L .50015 .78654 L F
.50293 .78819 m .50394 .78908 L .50225 .78853 L F
.748 .787 .885 r
.72965 .735 m .72996 .73698 L .73323 .73519 L F
.9 .56 .393 r
.58695 .7395 m .58785 .73812 L .58601 .73716 L F
.58695 .7395 m .58847 .74012 L .58785 .73812 L F
.577 .002 0 r
.47603 .74228 m .47454 .74203 L .47243 .74037 L F
.649 .253 .28 r
.4782 .74103 m .47454 .74203 L .47603 .74228 L F
.518 .664 .928 r
.47603 .74228 m .47916 .74304 L .4782 .74103 L F
.492 .581 .873 r
.55574 .74005 m .55601 .73734 L .55388 .73769 L F
.55574 .74005 m .55749 .74006 L .55601 .73734 L F
.473 .703 .969 r
.68612 .58758 m .68398 .58771 L .68524 .58633 L F
.68612 .58758 m .68398 .58771 L .68524 .58633 L F
.732 .781 .892 r
.54 .78854 m .54121 .78641 L .53903 .78652 L F
.54 .78854 m .54282 .78726 L .54121 .78641 L F
.533 .172 .3 r
.44998 .73196 m .45238 .7319 L .4534 .72977 L F
.457 .096 .263 r
.4534 .72977 m .45523 .73073 L .45555 .7297 L F
.4534 .72977 m .45238 .7319 L .45523 .73073 L F
0 .473 .817 r
.55768 .69817 m .55697 .69824 L .55695 .69783 L F
.791 .794 .854 r
.55403 .74676 m .55424 .74873 L .5558 .74691 L F
.55403 .74676 m .5558 .74691 L .55551 .74649 L F
.779 .724 .801 r
.5563 .74634 m .55327 .74601 L .5551 .7458 L F
.5563 .74634 m .55391 .74704 L .55327 .74601 L F
.791 .794 .854 r
.55403 .74676 m .5563 .74634 L .5551 .7458 L F
.962 .633 .26 r
.55426 .74613 m .5553 .74766 L .55511 .74593 L F
.55504 .74582 m .55511 .74593 L .5551 .7458 L F
.55426 .74613 m .55511 .74593 L .55504 .74582 L F
.791 .794 .854 r
.55551 .74649 m .5558 .74691 L .5563 .74634 L F
.283 .489 .882 r
.38231 .66933 m .38247 .66874 L .37935 .66848 L F
.38231 .66933 m .38311 .66998 L .38247 .66874 L F
.316 .201 .56 r
.34275 .68505 m .34087 .68308 L .34293 .68274 L F
.34275 .68505 m .34187 .68629 L .34087 .68308 L F
.853 .778 .778 r
.70024 .59361 m .69949 .59534 L .69878 .59266 L F
.192 .334 .779 r
.32137 .72642 m .32261 .7295 L .32334 .72807 L F
0 0 .136 r
.32158 .73142 m .32261 .7295 L .32344 .73156 L F
.32158 .73142 m .32334 .72807 L .32261 .7295 L F
.553 .405 .633 r
.30471 .68646 m .3069 .68617 L .30661 .68309 L F
.567 .407 .625 r
.30471 .68646 m .30684 .68826 L .3069 .68617 L F
.30471 .68646 m .30486 .68887 L .30684 .68826 L F
.412 .392 .727 r
.61065 .73658 m .60863 .73831 L .60808 .73454 L F
.386 .349 .694 r
.61065 .73658 m .6108 .74019 L .60863 .73831 L F
.289 .337 .739 r
.60863 .73831 m .6108 .74019 L .60953 .74006 L F
.599 .89 .99 r
.521 .73716 m .52266 .73504 L .52014 .73468 L F
.479 .356 .634 r
.52497 .73709 m .52527 .7349 L .52266 .73504 L F
.61 .343 .487 r
.52295 .73652 m .52497 .73709 L .52266 .73504 L F
.525 0 0 r
.45386 .77316 m .45635 .77426 L .45683 .77365 L F
.738 .217 0 r
.45635 .77426 m .45924 .77588 L .45683 .77365 L F
.754 .322 .226 r
.45683 .77365 m .45924 .77588 L .46058 .77543 L F
.598 .411 .6 r
.31279 .67223 m .31515 .67197 L .31505 .6695 L F
.57 .308 .48 r
.31698 .6714 m .31505 .6695 L .31515 .67197 L F
.31698 .6714 m .31756 .66939 L .31505 .6695 L F
.558 .118 .16 r
.52227 .78342 m .52122 .7843 L .52445 .78378 L F
.457 0 .033 r
.45963 .78376 m .4585 .78453 L .45628 .78441 L F
.267 0 0 r
.4603 .78478 m .45963 .78376 L .46185 .78365 L F
.4603 .78478 m .4585 .78453 L .45963 .78376 L F
.637 .914 .62 r
.39451 .65536 m .39437 .65543 L .39533 .65412 L F
.41 .67 .967 r
.39628 .65601 m .39437 .65543 L .39451 .65536 L F
.261 .692 .964 r
.39533 .65412 m .3971 .65481 L .39451 .65536 L F
.461 .64 .934 r
.71749 .73131 m .71812 .73239 L .71813 .73125 L F
.416 .417 .752 r
.71812 .73239 m .72004 .731 L .71813 .73125 L F
.71812 .73239 m .72029 .73371 L .72004 .731 L F
.299 0 .043 r
.71907 .73398 m .72029 .73371 L .71812 .73239 L F
.6 .787 .97 r
.60506 .70789 m .60704 .70622 L .60449 .70452 L F
.60506 .70789 m .60749 .70745 L .60704 .70622 L F
.524 .355 .594 r
.60531 .71055 m .60749 .70745 L .60506 .70789 L F
.287 0 .135 r
.33432 .65555 m .33613 .65511 L .33718 .65324 L F
.301 0 .138 r
.33613 .65511 m .33918 .65266 L .33718 .65324 L F
.481 .092 .225 r
.5279 .78197 m .53062 .78192 L .53044 .78094 L F
.645 .092 0 r
.43627 .76398 m .4362 .76433 L .43894 .76509 L F
.4362 .76433 m .43654 .76459 L .43894 .76509 L F
.902 .599 .464 r
.43616 .76451 m .4375 .76642 L .43894 .76509 L F
.097 .198 .681 r
.4377 .76319 m .43756 .76538 L .43635 .76281 L F
.43756 .76538 m .4375 .76642 L .43704 .76498 L F
.43756 .76538 m .43704 .76498 L .43635 .76281 L F
.645 .092 0 r
.4362 .76433 m .43616 .76451 L .43654 .76459 L F
0 .064 .591 r
.44022 .76699 m .43894 .76509 L .44027 .7646 L F
.734 .511 .589 r
.4375 .76642 m .44027 .7646 L .43894 .76509 L F
.54 .101 .155 r
.54953 .73145 m .55123 .73202 L .55264 .73011 L F
.622 .064 0 r
.55264 .73011 m .55513 .73177 L .55654 .73182 L F
0 0 0 r
.55264 .73011 m .55316 .72943 L .55513 .73177 L F
.752 .838 .917 r
.55019 .69203 m .54636 .69226 L .54886 .69128 L F
.318 .512 .888 r
.5513 .69041 m .55019 .69203 L .54886 .69128 L F
0 0 0 r
.55019 .69203 m .55219 .6919 L .55309 .69172 L F
.318 .512 .888 r
.5513 .69041 m .55219 .6919 L .55019 .69203 L F
.43 .866 .917 r
.55654 .73182 m .55513 .73177 L .55731 .7311 L F
.071 .343 .818 r
.55731 .7311 m .55949 .73431 L .55654 .73182 L F
.43 .866 .917 r
.55654 .73182 m .55513 .73177 L .55731 .7311 L F
.953 .795 .346 r
.51422 .73719 m .5141 .74107 L .51362 .7397 L F
.84 .737 .75 r
.72545 .61396 m .72875 .61211 L .72816 .61132 L F
.72545 .61396 m .72696 .6152 L .72875 .61211 L F
.897 .966 .824 r
.73031 .60858 m .72875 .61211 L .73137 .60957 L F
.73031 .60858 m .72816 .61132 L .72875 .61211 L F
.967 .679 .43 r
.7284 .62529 m .72935 .62586 L .72831 .62755 L F
.941 .624 .409 r
.72831 .62755 m .72935 .62586 L .72959 .62791 L F
.45 0 0 r
.53472 .78934 m .53366 .78958 L .53132 .78909 L F
.944 .648 .447 r
.53472 .78934 m .53341 .79123 L .53366 .78958 L F
.586 .199 .275 r
.53698 .7895 m .53341 .79123 L .53472 .78934 L F
.812 .569 .572 r
.61137 .67456 m .60807 .67167 L .61127 .6723 L F
.269 .491 .887 r
.52366 .70628 m .52261 .70743 L .52136 .70569 L F
.52366 .70628 m .52391 .70738 L .52261 .70743 L F
.072 .298 .782 r
.52501 .70921 m .52261 .70743 L .52391 .70738 L F
.378 0 0 r
.45924 .77588 m .46282 .77544 L .46058 .77543 L F
.505 0 0 r
.71647 .71692 m .7148 .71595 L .7141 .71609 L F
.591 .417 .614 r
.29886 .69955 m .30114 .69935 L .30116 .69683 L F
.648 .507 .678 r
.29903 .70192 m .30114 .69935 L .29886 .69955 L F
.795 .86 .898 r
.71907 .73398 m .72125 .73354 L .72035 .73384 L F
.453 .874 .756 r
.72296 .73246 m .72125 .73354 L .72404 .73313 L F
.72296 .73246 m .72035 .73384 L .72125 .73354 L F
.671 .71 .877 r
.69314 .60428 m .6964 .6051 L .69547 .60349 L F
.606 .709 .917 r
.6964 .6051 m .69772 .60315 L .69547 .60349 L F
.6964 .6051 m .6985 .60464 L .69772 .60315 L F
.253 0 .004 r
.48571 .72149 m .48654 .72264 L .48757 .7206 L F
.48571 .72149 m .48448 .72317 L .48654 .72264 L F
.494 .388 .663 r
.28462 .62303 m .28628 .61972 L .2845 .62015 L F
.739 .537 .62 r
.61773 .6527 m .62111 .65049 L .6177 .65044 L F
.61773 .6527 m .62114 .65287 L .62111 .65049 L F
.682 .482 .609 r
.62114 .65287 m .62345 .65041 L .62111 .65049 L F
.736 .945 .63 r
.46594 .77487 m .46603 .77417 L .46876 .774 L F
.953 .795 .346 r
.51422 .73719 m .51362 .7397 L .5145 .73765 L F
.528 .331 .556 r
.67217 .6143 m .66983 .61722 L .67 .61449 L F
.67217 .6143 m .66983 .61722 L .67 .61449 L F
0 .12 .639 r
.50352 .73129 m .50189 .7294 L .50357 .72903 L F
.292 .555 .926 r
.54866 .68815 m .54665 .68887 L .54657 .6879 L F
.54866 .68815 m .54857 .68904 L .54665 .68887 L F
.54857 .68904 m .54844 .68939 L .54665 .68887 L F
.479 .323 .591 r
.54657 .6879 m .5478 .68996 L .54866 .68815 L F
.752 .914 .541 r
.5478 .68996 m .54821 .68871 L .54876 .68823 L F
.854 .998 .794 r
.55141 .68605 m .54854 .68942 L .54866 .68815 L F
.55141 .68605 m .54866 .68815 L .54966 .68693 L F
.752 .914 .541 r
.5478 .68996 m .54966 .68693 L .54866 .68815 L F
.5478 .68996 m .5491 .68762 L .54889 .68817 L F
0 .004 .539 r
.54665 .68887 m .54886 .69128 L .5478 .68996 L F
.644 .727 .908 r
.5513 .69041 m .54886 .69128 L .5478 .68996 L F
.5513 .69041 m .54886 .69128 L .5478 .68996 L F
.5513 .69041 m .5478 .68996 L .54997 .68898 L F
.5513 .69041 m .5478 .68996 L .54997 .68898 L F
0 0 .293 r
.5478 .68996 m .54881 .69093 L .54821 .68871 L F
.951 .6 .24 r
.54821 .68871 m .54881 .69093 L .54721 .68957 L F
.54821 .68871 m .54721 .68957 L .54717 .68954 L F
.752 .914 .541 r
.54876 .68823 m .54821 .68871 L .5491 .68762 L F
.54889 .68817 m .5491 .68762 L .54966 .68693 L F
.292 .555 .926 r
.54857 .68904 m .54854 .68942 L .54844 .68939 L F
0 .004 .539 r
.54665 .68887 m .5478 .68996 L .54657 .6879 L F
.635 .586 .782 r
.29903 .70192 m .30001 .70471 L .30165 .70213 L F
.588 .524 .75 r
.30001 .70471 m .3023 .70478 L .30165 .70213 L F
.38 .232 .552 r
.30048 .70767 m .3023 .70478 L .30001 .70471 L F
.522 .907 .941 r
.37023 .67051 m .37242 .67055 L .37413 .6698 L F
.617 .711 .913 r
.38311 .66998 m .38331 .66673 L .38247 .66874 L F
.837 .945 .892 r
.3947 .78224 m .39351 .78297 L .39589 .78118 L F
.652 .292 .349 r
.4471 .75108 m .44558 .75321 L .4436 .75131 L F
0 0 0 r
.44933 .75167 m .44558 .75321 L .4471 .75108 L F
.436 .228 .497 r
.2802 .63036 m .28225 .62808 L .28039 .62852 L F
.789 .65 .708 r
.6847 .59575 m .68297 .59796 L .68168 .59516 L F
.566 .267 .42 r
.44221 .73465 m .4446 .73458 L .44543 .73202 L F
.496 .163 .332 r
.4446 .73458 m .44773 .73207 L .44543 .73202 L F
.329 0 .16 r
.37702 .69881 m .38006 .69641 L .37791 .69672 L F
.129 0 .18 r
.3788 .71172 m .37809 .71026 L .38015 .70992 L F
.3788 .71172 m .37725 .71276 L .37809 .71026 L F
.899 .877 .806 r
.68148 .61273 m .68293 .61141 L .68159 .61045 L F
.805 .89 .905 r
.68159 .61045 m .68293 .61141 L .68544 .60915 L F
0 0 .15 r
.54071 .6968 m .54123 .69572 L .54138 .69344 L F
0 0 .338 r
.54071 .6968 m .54136 .698 L .54123 .69572 L F
.54071 .6968 m .54171 .69927 L .54136 .698 L F
.664 .626 .801 r
.52618 .72627 m .52714 .72949 L .52943 .72884 L F
.455 0 0 r
.70786 .57797 m .70705 .57733 L .70673 .57755 L F
.70786 .57797 m .70957 .57871 L .70705 .57733 L F
.525 .533 .806 r
.39372 .67766 m .39446 .67402 L .39251 .67439 L F
.39372 .67766 m .39563 .67726 L .39446 .67402 L F
.111 .034 .482 r
.39372 .67766 m .39492 .67926 L .39563 .67726 L F
.39372 .67766 m .39386 .68026 L .39492 .67926 L F
.394 .146 .415 r
.61644 .70781 m .61583 .71013 L .614 .71052 L F
.392 .229 .538 r
.61809 .70487 m .618 .70706 L .61644 .70781 L F
.463 .251 .505 r
.618 .70706 m .61583 .71013 L .61644 .70781 L F
.682 .482 .609 r
.62114 .65287 m .62342 .65254 L .62345 .65041 L F
.748 .562 .643 r
.62651 .65299 m .62345 .65041 L .62342 .65254 L F
.481 0 0 r
.46541 .78349 m .46401 .78404 L .46185 .78365 L F
.413 0 0 r
.46541 .78349 m .46742 .78375 L .46401 .78404 L F
.147 0 0 r
.35303 .72481 m .35255 .72399 L .35455 .72347 L F
.35303 .72481 m .351 .7254 L .35255 .72399 L F
.375 .249 .579 r
.55067 .74025 m .54966 .74294 L .54939 .74055 L F
.293 .788 .87 r
.42802 .78874 m .42786 .78895 L .42835 .78886 L F
.42802 .78874 m .42623 .78909 L .42786 .78895 L F
.651 .537 .712 r
.29643 .71821 m .29826 .71549 L .297 .71605 L F
.479 .289 .544 r
.29874 .63404 m .30076 .6312 L .30053 .63339 L F
.373 .247 .577 r
.30039 .63569 m .29874 .63404 L .30053 .63339 L F
.30039 .63569 m .29884 .63641 L .29874 .63404 L F
.489 .764 .992 r
.29389 .59863 m .29042 .59785 L .29241 .5977 L F
.469 .778 .998 r
.29589 .59834 m .29389 .59863 L .29241 .5977 L F
.552 .385 .609 r
.30116 .69683 m .30309 .69877 L .30308 .69639 L F
.30116 .69683 m .30114 .69935 L .30309 .69877 L F
.29 .752 .949 r
.6015 .66403 m .59905 .66371 L .59781 .66371 L F
.833 .446 .317 r
.60172 .66586 m .59905 .66371 L .6015 .66403 L F
.694 .73 .878 r
.7209 .61616 m .72427 .61598 L .72413 .61529 L F
.715 .746 .876 r
.72427 .61598 m .72545 .61396 L .72413 .61529 L F
.72427 .61598 m .72696 .6152 L .72545 .61396 L F
.707 .473 .567 r
.61452 .65289 m .61773 .6527 L .6177 .65044 L F
.416 .45 .788 r
.58435 .71568 m .58642 .71748 L .58547 .71442 L F
.239 .135 .528 r
.58133 .7248 m .58039 .72666 L .57995 .72469 L F
.58133 .7248 m .58228 .7257 L .58039 .72666 L F
0 0 .389 r
.58146 .72826 m .58039 .72666 L .58228 .7257 L F
.58146 .72826 m .58042 .72955 L .58039 .72666 L F
.284 0 0 r
.51024 .70574 m .51192 .70587 L .51356 .70448 L F
.221 0 0 r
.51356 .70448 m .51416 .70536 L .51545 .70502 L F
.005 0 0 r
.5131 .70521 m .51634 .70488 L .51416 .70536 L F
.51634 .70488 m .51659 .70485 L .51416 .70536 L F
.221 0 0 r
.51356 .70448 m .51193 .70586 L .51416 .70536 L F
.51193 .70586 m .51192 .70587 L .51416 .70536 L F
.858 .85 .391 r
.57853 .67982 m .57782 .68194 L .57786 .6831 L F
.809 .965 .647 r
.57782 .68194 m .576 .6852 L .57786 .6831 L F
.407 0 .096 r
.47249 .72704 m .4742 .72791 L .47547 .72613 L F
.579 .2 .289 r
.4742 .72791 m .47757 .72609 L .47547 .72613 L F
.224 0 .346 r
.61243 .71594 m .61181 .71799 L .6106 .71802 L F
.477 .193 .403 r
.44169 .75434 m .44114 .75635 L .43903 .75665 L F
.253 .053 .404 r
.44333 .75346 m .44169 .75434 L .4436 .75131 L F
.448 .245 .511 r
.44333 .75346 m .44114 .75635 L .44169 .75434 L F
.461 .344 .634 r
.61583 .71013 m .61617 .71232 L .614 .71052 L F
.427 .345 .662 r
.614 .71052 m .61617 .71232 L .61467 .71331 L F
.958 .948 .676 r
.55929 .7439 m .55915 .74155 L .55958 .74093 L F
.684 .977 .81 r
.55435 .68472 m .55661 .68254 L .55636 .68266 L F
.55435 .68472 m .55331 .68501 L .55661 .68254 L F
.757 .607 .69 r
.69853 .59034 m .70024 .59361 L .69878 .59266 L F
.38 .232 .552 r
.30048 .70767 m .3023 .70729 L .3023 .70478 L F
.281 .101 .45 r
.30048 .70767 m .30194 .70942 L .3023 .70729 L F
.30048 .70767 m .30011 .71034 L .30194 .70942 L F
.739 .762 .871 r
.34557 .70536 m .3423 .70509 L .34437 .70387 L F
.535 .651 .91 r
.34656 .70346 m .34557 .70536 L .34437 .70387 L F
.34656 .70346 m .34753 .70516 L .34557 .70536 L F
.523 .8 .996 r
.35311 .70906 m .3524 .71033 L .35075 .70769 L F
.35311 .70906 m .35445 .70993 L .3524 .71033 L F
.156 0 0 r
.49108 .73323 m .49223 .73306 L .49265 .73272 L F
.24 .743 .687 r
.49441 .73275 m .49384 .73298 L .49265 .73272 L F
.156 0 0 r
.49223 .73306 m .49441 .73275 L .49265 .73272 L F
.644 .691 .879 r
.49384 .73298 m .49299 .73243 L .49265 .73272 L F
.49299 .73243 m .49122 .73129 L .49265 .73272 L F
.24 .743 .687 r
.49441 .73275 m .49609 .73222 L .49384 .73298 L F
.783 .606 .661 r
.62464 .6556 m .62804 .65599 L .62651 .65299 L F
.783 .605 .659 r
.62777 .65835 m .62804 .65599 L .62464 .6556 L F
.645 .454 .611 r
.68307 .58516 m .68595 .58262 L .68503 .58328 L F
.673 .449 .573 r
.49193 .73479 m .48796 .73761 L .48825 .73527 L F
.642 .453 .612 r
.31041 .67494 m .3128 .6746 L .31279 .67223 L F
.509 .296 .525 r
.3128 .6746 m .31515 .67197 L .31279 .67223 L F
.531 .398 .645 r
.42223 .66893 m .42046 .67232 L .42028 .66927 L F
.462 .369 .664 r
.3178 .60829 m .31582 .6061 L .31688 .60621 L F
.3178 .60829 m .31592 .60991 L .31582 .6061 L F
.367 .822 .717 r
.37545 .66997 m .37634 .66968 L .37862 .6686 L F
.17 0 0 r
.37413 .6698 m .37634 .66968 L .37472 .67028 L F
.367 .822 .717 r
.37472 .67028 m .37634 .66968 L .37545 .66997 L F
.084 0 0 r
.37694 .66949 m .37634 .66968 L .37413 .6698 L F
.37757 .66943 m .37634 .66968 L .37694 .66949 L F
.465 .886 .789 r
.37935 .66848 m .37862 .6686 L .37757 .66943 L F
.464 .89 .833 r
.37862 .6686 m .37634 .66968 L .37757 .66943 L F
0 .15 .646 r
.5469 .72555 m .54588 .72499 L .54478 .72404 L F
.125 0 0 r
.54738 .72566 m .5469 .72555 L .54503 .72517 L F
.283 .536 .915 r
.55053 .72584 m .54784 .72655 L .5469 .72555 L F
.125 0 0 r
.54807 .72581 m .5469 .72555 L .54738 .72566 L F
0 .15 .646 r
.5469 .72555 m .54784 .72655 L .54645 .72544 L F
.5469 .72555 m .54645 .72544 L .54588 .72499 L F
.767 .583 .649 r
.62464 .6556 m .62651 .65299 L .62342 .65254 L F
.455 .009 .1 r
.46882 .72884 m .47109 .72883 L .47249 .72704 L F
.411 0 .073 r
.47249 .72704 m .47109 .72883 L .4742 .72791 L F
.733 .71 .829 r
.71448 .61089 m .71142 .61073 L .71346 .60877 L F
.777 .753 .831 r
.71497 .60997 m .71448 .61089 L .71346 .60877 L F
.592 .848 .993 r
.7209 .61616 m .72324 .6144 L .72042 .61402 L F
.7209 .61616 m .72413 .61529 L .72324 .6144 L F
.435 .284 .577 r
.60967 .72348 m .60847 .72662 L .60821 .72439 L F
.665 .772 .929 r
.34 .70575 m .33653 .70522 L .33876 .70478 L F
.607 .818 .981 r
.3423 .70509 m .34 .70575 L .33876 .70478 L F
.688 .142 0 r
.50225 .78853 m .50394 .78908 L .50583 .79088 L F
.531 .545 .815 r
.42839 .73666 m .42661 .73773 L .42538 .73463 L F
.343 .2 .539 r
.38908 .68313 m .3906 .68476 L .39122 .68277 L F
.38908 .68313 m .3891 .68556 L .3906 .68476 L F
.884 .62 .535 r
.62904 .66844 m .63074 .66673 L .62918 .66611 L F
.62904 .66844 m .63096 .66944 L .63074 .66673 L F
.536 .226 .389 r
.46959 .75155 m .46912 .75317 L .46677 .75325 L F
.355 .255 .602 r
.47059 .74824 m .47117 .75091 L .46959 .75155 L F
.196 0 .252 r
.47117 .75091 m .46912 .75317 L .46959 .75155 L F
.437 .118 .326 r
.4132 .74299 m .41525 .74266 L .4157 .74098 L F
.477 .155 .341 r
.4157 .74098 m .41748 .7422 L .4183 .73992 L F
.4157 .74098 m .41525 .74266 L .41748 .7422 L F
.658 .46 .605 r
.58407 .72051 m .58757 .71809 L .58453 .71871 L F
.372 .81 .959 r
.71642 .58275 m .71888 .58236 L .71979 .58276 L F
.531 .863 .994 r
.71888 .58236 m .72222 .58226 L .71979 .58276 L F
.917 .976 .703 r
.60982 .69616 m .6094 .69567 L .61093 .69458 L F
.93 .888 .768 r
.60989 .69336 m .61093 .69458 L .6094 .69567 L F
.60989 .69336 m .61144 .69189 L .61093 .69458 L F
.96 .657 .412 r
.52703 .71178 m .52887 .71559 L .5284 .71319 L F
.564 .428 .654 r
.41125 .74574 m .41342 .74547 L .4132 .74299 L F
.522 .378 .626 r
.41125 .74574 m .41331 .74763 L .41342 .74547 L F
.41125 .74574 m .41147 .74808 L .41331 .74763 L F
.677 .191 .088 r
.50614 .78602 m .50768 .78655 L .50743 .78622 L F
.68 .154 0 r
.50893 .78816 m .50768 .78655 L .5065 .78579 L F
.51014 .78935 m .50768 .78655 L .50893 .78816 L F
.677 .191 .088 r
.50743 .78622 m .50768 .78655 L .509 .78647 L F
.197 0 0 r
.509 .78647 m .50768 .78655 L .51126 .78656 L F
.418 .142 .385 r
.41574 .675 m .4153 .67699 L .41324 .67749 L F
.555 .315 .506 r
.41778 .67448 m .4153 .67699 L .41574 .675 L F
.669 .377 .468 r
.69292 .58141 m .69599 .58139 L .69608 .57955 L F
.666 .374 .468 r
.69599 .58139 m .69612 .58144 L .69608 .57955 L F
.056 0 .185 r
.6108 .74617 m .60999 .74803 L .60872 .74894 L F
.124 0 .293 r
.60999 .74803 m .60813 .7511 L .60872 .74894 L F
.432 .231 .505 r
.3021 .63313 m .30076 .6312 L .30256 .63073 L F
.3021 .63313 m .30053 .63339 L .30076 .6312 L F
.751 .89 .942 r
.54187 .73339 m .54521 .73305 L .54402 .73352 L F
.572 .161 .226 r
.54716 .73235 m .54402 .73352 L .54521 .73305 L F
.24 .393 .815 r
.74066 .5912 m .73977 .59158 L .73938 .59232 L F
.74066 .5912 m .73938 .59232 L .73804 .58955 L F
.648 .815 .963 r
.52894 .70174 m .52734 .70275 L .52555 .70143 L F
.563 .384 .597 r
.52894 .70174 m .52674 .7045 L .52734 .70275 L F
.391 0 0 r
.57125 .68559 m .57405 .68582 L .57477 .68534 L F
.997 .769 .431 r
.57503 .68683 m .576 .6852 L .57477 .68534 L F
.02 0 0 r
.576 .6852 m .5755 .6854 L .57477 .68534 L F
0 .138 .682 r
.57477 .68534 m .5755 .6854 L .57353 .68281 L F
.997 .769 .431 r
.57503 .68683 m .57477 .68534 L .57405 .68582 L F
.449 .637 .936 r
.40206 .65661 m .4031 .65815 L .39893 .65661 L F
.465 .22 .458 r
.35273 .67695 m .3503 .6791 L .35098 .67776 L F
.517 .095 .179 r
.5764 .7083 m .57857 .7095 L .57974 .70747 L F
.755 .361 .307 r
.57974 .70747 m .57857 .7095 L .58175 .70969 L F
0 0 .146 r
.37716 .64682 m .37621 .65037 L .37491 .64769 L F
.37716 .64682 m .37692 .6491 L .37628 .6501 L F
.798 .559 .576 r
.37369 .648 m .37716 .64682 L .37491 .64769 L F
.37369 .648 m .37692 .6491 L .37716 .64682 L F
.109 0 0 r
.37565 .64899 m .37724 .64859 L .37692 .6491 L F
.546 .333 .542 r
.37716 .64682 m .37692 .6491 L .37926 .64807 L F
.37716 .64682 m .37692 .6491 L .37926 .64807 L F
.109 0 0 r
.37724 .64859 m .37926 .64807 L .37692 .6491 L F
0 0 .146 r
.37628 .6501 m .37692 .6491 L .37621 .65037 L F
.512 .804 .998 r
.37692 .6491 m .37829 .64997 L .37621 .65037 L F
.763 .524 0 r
.67174 .61158 m .67217 .6143 L .67158 .61114 L F
.713 .987 .841 r
.67446 .60944 m .67174 .61158 L .67158 .61114 L F
.554 .405 .633 r
.30661 .68309 m .30878 .68547 L .30852 .6826 L F
.30661 .68309 m .3069 .68617 L .30878 .68547 L F
.477 .682 .956 r
.38995 .6705 m .39249 .67222 L .39391 .67154 L F
.479 .322 .59 r
.39249 .67222 m .39446 .67402 L .39391 .67154 L F
.39249 .67222 m .39251 .67439 L .39446 .67402 L F
.458 .431 .741 r
.48606 .73979 m .48361 .73792 L .48589 .73757 L F
.656 .524 .692 r
.33507 .69727 m .33532 .69918 L .33237 .69869 L F
.451 .255 .522 r
.33532 .69918 m .33319 .70212 L .33237 .69869 L F
.677 .453 .574 r
.51589 .73474 m .5201 .73218 L .51635 .73247 L F
.718 .231 .089 r
.73591 .63249 m .73629 .63119 L .7354 .63032 L F
.475 .35 .63 r
.73629 .63119 m .73846 .63311 L .73654 .63362 L F
.718 .231 .089 r
.73591 .63249 m .73846 .63311 L .73629 .63119 L F
.645 .454 .611 r
.68307 .58516 m .6864 .58542 L .68595 .58262 L F
.554 .391 .616 r
.68595 .58262 m .68845 .58454 L .68829 .58206 L F
.68595 .58262 m .6864 .58542 L .68845 .58454 L F
.236 .365 .792 r
.52648 .70933 m .52535 .71088 L .52501 .70921 L F
.52648 .70933 m .52703 .71178 L .52535 .71088 L F
.527 .423 .68 r
.40574 .75952 m .40774 .75912 L .4073 .75675 L F
.582 .465 .685 r
.40586 .762 m .40774 .75912 L .40574 .75952 L F
.384 0 .029 r
.34134 .65251 m .34353 .65236 L .34506 .65082 L F
.359 0 .069 r
.34353 .65236 m .34712 .65029 L .34506 .65082 L F
.53 .217 .382 r
.36769 .70446 m .36988 .70427 L .37049 .70253 L F
.261 0 .264 r
.37049 .70253 m .37179 .70332 L .37261 .70215 L F
.37049 .70253 m .36988 .70427 L .37179 .70332 L F
0 .116 .668 r
.73412 .71282 m .7362 .71524 L .73614 .7161 L F
0 .323 .81 r
.7362 .71524 m .73819 .71759 L .73614 .7161 L F
.416 .318 .635 r
.40467 .76773 m .40615 .76496 L .40413 .76543 L F
0 0 .102 r
.62768 .68783 m .62642 .69102 L .62698 .68886 L F
.534 .756 .978 r
.26891 .59448 m .27032 .59572 L .27007 .59576 L F
.034 0 0 r
.36321 .71988 m .36286 .71902 L .3647 .71828 L F
.36321 .71988 m .36137 .72073 L .36286 .71902 L F
0 .521 .767 r
.59236 .74262 m .59497 .74305 L .59542 .74323 L F
.482 0 0 r
.5933 .74412 m .59497 .74305 L .59236 .74262 L F
.917 .811 .727 r
.5933 .74412 m .59464 .74292 L .59497 .74305 L F
.59464 .74292 m .59596 .74173 L .59497 .74305 L F
0 .521 .767 r
.59542 .74323 m .59497 .74305 L .59558 .74326 L F
.833 1 .807 r
.59558 .74326 m .59596 .74173 L .59806 .74062 L F
.836 .999 .793 r
.59497 .74305 m .59596 .74173 L .59558 .74326 L F
.228 .601 .951 r
.73416 .62595 m .73228 .62479 L .73342 .62582 L F
.769 .348 0 r
.7344 .62695 m .73416 .62595 L .73342 .62582 L F
.7344 .62695 m .73526 .62805 L .73416 .62595 L F
.948 .926 .75 r
.59806 .74062 m .59596 .74173 L .59749 .73879 L F
.867 .71 .685 r
.56536 .69598 m .56778 .69683 L .56733 .69363 L F
.465 .619 .917 r
.5672 .69777 m .56585 .69934 L .5674 .69733 L F
.5672 .69777 m .5674 .69733 L .56778 .69683 L F
.631 .067 0 r
.56586 .69821 m .56709 .69803 L .5672 .69777 L F
.472 .623 .917 r
.56912 .69774 m .56776 .69919 L .5672 .69777 L F
.631 .067 0 r
.56709 .69803 m .56912 .69774 L .5672 .69777 L F
.465 .619 .917 r
.5672 .69777 m .56778 .69683 L .56536 .69598 L F
.322 .307 .687 r
.56778 .69683 m .56928 .69312 L .56733 .69363 L F
.114 0 .084 r
.57871 .66662 m .58044 .66618 L .58125 .6643 L F
.305 0 .122 r
.57871 .66662 m .57998 .6679 L .58044 .66618 L F
.57871 .66662 m .57783 .66852 L .57998 .6679 L F
.416 .318 .635 r
.40467 .76773 m .40626 .76744 L .40615 .76496 L F
.39 .221 .529 r
.40467 .76773 m .40455 .7701 L .40626 .76744 L F
.40467 .76773 m .40455 .7701 L .40626 .76744 L F
.626 .235 .282 r
.71647 .71692 m .71918 .71778 L .72023 .71569 L F
.495 .904 .899 r
.72175 .71501 m .72023 .71569 L .72168 .71467 L F
0 0 0 r
.72023 .71569 m .71918 .71778 L .72168 .71467 L F
.5 .647 .923 r
.41406 .66291 m .41351 .66529 L .41242 .66292 L F
.41406 .66291 m .41576 .66504 L .41351 .66529 L F
.169 .584 .937 r
.70562 .60833 m .70783 .60862 L .7046 .60739 L F
.184 .311 .76 r
.57125 .73483 m .57363 .73703 L .57224 .73357 L F
.719 .308 .267 r
.4967 .7862 m .50015 .78654 L .49887 .78822 L F
.694 .277 .25 r
.50015 .78654 m .50225 .78853 L .49887 .78822 L F
.645 .522 .698 r
.30284 .69147 m .30512 .6911 L .30486 .68887 L F
.641 .499 .674 r
.30284 .69147 m .30301 .69387 L .30512 .6911 L F
.306 .526 .903 r
.70244 .60531 m .70372 .60704 L .70399 .6064 L F
.617 .354 .496 r
.68829 .58206 m .69077 .58397 L .69065 .5816 L F
.68829 .58206 m .68845 .58454 L .69077 .58397 L F
.331 .229 .586 r
.60863 .72896 m .60732 .73093 L .60735 .72966 L F
.293 0 .167 r
.58125 .6643 m .58245 .66556 L .5831 .66331 L F
.58125 .6643 m .58044 .66618 L .58245 .66556 L F
.867 .71 .685 r
.56536 .69598 m .56733 .69363 L .56491 .69454 L F
.789 .524 .536 r
.69529 .58972 m .69853 .59034 L .69878 .59266 L F
.767 .668 .754 r
.67224 .60024 m .67521 .60043 L .67419 .60003 L F
.67224 .60024 m .67351 .60192 L .67521 .60043 L F
.498 .57 .859 r
.72738 .73496 m .72925 .73343 L .72579 .73264 L F
.72738 .73496 m .72965 .735 L .72925 .73343 L F
.631 .529 .721 r
.66953 .59753 m .66969 .60116 L .67224 .60024 L F
.662 .643 .82 r
.66969 .60116 m .67351 .60192 L .67224 .60024 L F
.817 .538 .516 r
.4947 .73687 m .49301 .73739 L .49193 .73479 L F
.805 .509 .488 r
.4947 .73687 m .49335 .73956 L .49301 .73739 L F
.754 .552 .623 r
.49695 .73732 m .49335 .73956 L .4947 .73687 L F
.392 .174 .459 r
.40313 .6902 m .40166 .68868 L .40365 .68823 L F
.40313 .6902 m .40136 .69083 L .40166 .68868 L F
.954 .749 .586 r
.63082 .67472 m .62973 .67161 L .62903 .67437 L F
.938 .772 .65 r
.6303 .6776 m .63082 .67472 L .62903 .67437 L F
.486 0 0 r
.56541 .74861 m .564 .74867 L .56232 .7477 L F
.549 .028 0 r
.5657 .74784 m .56188 .7477 L .56292 .74841 L F
0 .259 .766 r
.56232 .7477 m .56387 .74864 L .56398 .74914 L F
.549 .028 0 r
.56446 .74878 m .56387 .74864 L .56398 .74914 L F
0 .259 .766 r
.56387 .74864 m .56393 .74867 L .56398 .74914 L F
.549 .028 0 r
.56387 .74864 m .56292 .74841 L .56398 .74914 L F
.486 0 0 r
.564 .74867 m .56387 .74864 L .56232 .7477 L F
.549 .028 0 r
.5657 .74784 m .56292 .74841 L .56446 .74878 L F
.486 0 0 r
.564 .74867 m .56393 .74867 L .56387 .74864 L F
.066 0 .431 r
.56691 .74523 m .56686 .74769 L .56541 .74861 L F
.731 .49 .563 r
.56686 .74769 m .56393 .74867 L .56541 .74861 L F
.643 .503 .678 r
.30828 .67775 m .3106 .6774 L .31041 .67494 L F
.564 .452 .684 r
.30828 .67775 m .31063 .67975 L .3106 .6774 L F
.30828 .67775 m .30858 .6802 L .31063 .67975 L F
.758 .826 .905 r
.3305 .73634 m .33225 .73691 L .33539 .73558 L F
.499 0 0 r
.67487 .61558 m .67401 .61544 L .67217 .6143 L F
.43 .605 .92 r
.67487 .61558 m .67754 .61454 L .67401 .61544 L F
.67487 .61558 m .67766 .61617 L .67754 .61454 L F
.624 .804 .968 r
.40495 .79747 m .40851 .79784 L .40724 .79737 L F
.40495 .79747 m .40851 .79784 L .40724 .79737 L F
.851 .931 .879 r
.40724 .79737 m .40851 .79784 L .41079 .79536 L F
.684 .214 .128 r
.36801 .64665 m .37105 .64734 L .36912 .64573 L F
.743 .381 .366 r
.45999 .74838 m .45917 .7504 L .45705 .74804 L F
0 0 .006 r
.46215 .74581 m .46126 .74764 L .45999 .74838 L F
0 0 0 r
.46126 .74764 m .45917 .7504 L .45999 .74838 L F
.955 .853 .701 r
.67554 .60626 m .67339 .60851 L .67312 .60613 L F
.67554 .60626 m .67446 .60944 L .67339 .60851 L F
.765 .676 .764 r
.67789 .60331 m .67554 .60626 L .67543 .60314 L F
.785 .81 .873 r
.67766 .61617 m .67874 .61721 L .68136 .61487 L F
.472 0 .008 r
.46742 .78375 m .47067 .78324 L .46959 .78374 L F
.278 0 0 r
.47312 .78327 m .46959 .78374 L .47067 .78324 L F
.758 .826 .905 r
.3305 .73634 m .33539 .73558 L .33331 .7345 L F
.677 .843 .963 r
.33331 .7345 m .33539 .73558 L .3369 .73452 L F
.734 .658 .775 r
.56585 .69934 m .56346 .70157 L .56284 .69963 L F
.991 .735 .427 r
.56284 .69963 m .5625 .70138 L .56346 .70157 L F
.398 .193 .481 r
.54165 .78421 m .54363 .786 L .54437 .78432 L F
.558 .106 .135 r
.54437 .78432 m .54363 .786 L .54634 .78538 L F
.331 .11 .42 r
.56556 .68791 m .56348 .69076 L .56385 .68868 L F
.236 0 0 r
.46603 .77417 m .47098 .77383 L .46876 .774 L F
.625 .953 .929 r
.30258 .73768 m .30361 .73804 L .30213 .73778 L F
.963 .855 .445 r
.29891 .71314 m .29799 .71467 L .29985 .71244 L F
.29891 .71314 m .29826 .71549 L .29799 .71467 L F
.868 .994 .806 r
.29985 .71244 m .29799 .71467 L .29768 .71351 L F
.663 .208 .16 r
.29985 .71244 m .29768 .71351 L .29993 .71365 L F
.29985 .71244 m .29993 .71365 L .30124 .71373 L F
0 0 .139 r
.29976 .71115 m .29985 .71244 L .30011 .71034 L F
.29891 .71314 m .29985 .71244 L .29976 .71115 L F
.621 .448 .627 r
.58223 .72142 m .58431 .72232 L .58407 .72051 L F
.58223 .72142 m .58133 .7248 L .58431 .72232 L F
.754 .463 .49 r
.72238 .60013 m .72598 .60091 L .72558 .59823 L F
.716 .899 .961 r
.72829 .59962 m .72801 .59966 L .72719 .59876 L F
.72801 .59966 m .72505 .60009 L .72719 .59876 L F
.778 .74 .819 r
.7246 .59525 m .72226 .59772 L .72558 .59823 L F
.754 .463 .49 r
.72238 .60013 m .72558 .59823 L .72226 .59772 L F
.687 .691 .848 r
.7246 .59525 m .72558 .59823 L .72792 .59582 L F
.642 .845 .978 r
.72629 .59777 m .72719 .59876 L .72374 .59868 L F
.909 .613 .473 r
.72629 .59777 m .72631 .5978 L .72719 .59876 L F
.697 .967 .738 r
.72873 .59969 m .72688 .60147 L .72829 .59962 L F
.716 .899 .961 r
.72829 .59962 m .72598 .60091 L .72505 .60009 L F
.909 .613 .473 r
.72631 .5978 m .72886 .60068 L .72719 .59876 L F
.695 .178 0 r
.72787 .59955 m .72829 .59962 L .72719 .59876 L F
.72886 .60068 m .72829 .59962 L .72787 .59955 L F
.697 .967 .738 r
.72908 .59935 m .72873 .59969 L .72829 .59962 L F
.901 .758 .694 r
.73469 .62947 m .73144 .63047 L .72959 .62791 L F
.73469 .62947 m .73316 .63191 L .73144 .63047 L F
.708 .926 .964 r
.41976 .66507 m .41668 .6667 L .41769 .66503 L F
.41976 .66507 m .41668 .6667 L .41769 .66503 L F
.817 .673 .704 r
.57276 .70999 m .57153 .71331 L .57089 .70953 L F
.218 .535 .924 r
.54579 .69092 m .54468 .6917 L .543 .69245 L F
.54579 .69092 m .54636 .69226 L .54468 .6917 L F
0 .15 .687 r
.58042 .72955 m .58286 .73181 L .58285 .73261 L F
.377 .433 .793 r
.58286 .73181 m .58199 .73474 L .58285 .73261 L F
0 0 0 r
.60076 .75624 m .60375 .7544 L .60238 .75567 L F
.60238 .75567 m .60375 .7544 L .60551 .75339 L F
.426 .167 .416 r
.40136 .69083 m .39891 .69335 L .39937 .69141 L F
.513 .831 1 r
.54282 .78726 m .54363 .786 L .54121 .78641 L F
.54282 .78726 m .54492 .78681 L .54363 .786 L F
.437 .334 .64 r
.29671 .72947 m .29671 .72615 L .29537 .7273 L F
.29671 .72947 m .29814 .72707 L .29671 .72615 L F
.29671 .72947 m .29817 .72878 L .29814 .72707 L F
.221 .006 .36 r
.29637 .73174 m .29817 .72878 L .29671 .72947 L F
.384 .754 .992 r
.27983 .59628 m .27953 .59721 L .27774 .59651 L F
.27983 .59628 m .28131 .59708 L .27953 .59721 L F
.654 .633 .816 r
.71232 .61508 m .71573 .61729 L .71485 .61456 L F
.763 .735 .827 r
.71485 .61456 m .71573 .61729 L .71795 .61478 L F
0 0 0 r
.49927 .71224 m .49832 .71339 L .49932 .71229 L F
.116 0 .296 r
.49744 .71479 m .49932 .71229 L .49832 .71339 L F
.284 .767 .674 r
.45339 .75021 m .45225 .7507 L .45461 .74838 L F
.427 .014 .152 r
.45705 .74804 m .45339 .75021 L .45461 .74838 L F
.755 .64 .734 r
.55224 .6893 m .55568 .69125 L .5545 .68813 L F
.55224 .6893 m .55309 .69172 L .55568 .69125 L F
.839 .636 .628 r
.55219 .6919 m .55581 .69344 L .55568 .69125 L F
0 0 0 r
.55555 .69163 m .55453 .69331 L .55537 .69132 L F
.839 .636 .628 r
.55528 .69132 m .55568 .69125 L .55527 .69132 L F
0 0 0 r
.55549 .69131 m .55537 .69132 L .55546 .69111 L F
.55555 .69163 m .55537 .69132 L .55549 .69131 L F
.839 .636 .628 r
.55219 .6919 m .55528 .69132 L .55309 .69172 L F
.55528 .69132 m .55527 .69132 L .55309 .69172 L F
.291 .394 .796 r
.5545 .68813 m .55568 .69125 L .55705 .69003 L F
0 0 .448 r
.55581 .69344 m .55705 .69003 L .55568 .69125 L F
.055 .62 .705 r
.53249 .71842 m .53479 .71824 L .53612 .71814 L F
.552 .058 .038 r
.53479 .71824 m .53817 .71808 L .53612 .71814 L F
.453 .291 .57 r
.31817 .61099 m .31592 .60991 L .3178 .60829 L F
.31817 .61099 m .31518 .61276 L .31592 .60991 L F
.526 .337 .566 r
.31506 .80566 m .31555 .80586 L .31564 .80317 L F
.602 .398 .578 r
.31564 .80317 m .31555 .80586 L .31776 .80426 L F
.717 .476 .56 r
.52888 .73762 m .52845 .74001 L .52607 .74006 L F
.6 .367 .534 r
.53315 .73772 m .52888 .73762 L .53113 .73675 L F
.53315 .73772 m .52845 .74001 L .52888 .73762 L F
0 0 0 r
.49567 .71589 m .49588 .71651 L .49744 .71479 L F
.49567 .71589 m .49451 .71761 L .49588 .71651 L F
.415 .689 .976 r
.56528 .72042 m .56531 .72129 L .56623 .72009 L F
.066 .181 .675 r
.56531 .72129 m .56706 .72335 L .56623 .72009 L F
.47 .809 .999 r
.27078 .59463 m .27032 .59572 L .26891 .59448 L F
.27078 .59463 m .27232 .59536 L .27032 .59572 L F
.655 .739 .912 r
.72757 .58202 m .72554 .5829 L .72434 .58113 L F
.597 .581 .806 r
.40455 .7701 m .40577 .77316 L .40796 .7728 L F
.538 .307 .513 r
.40577 .77316 m .40757 .77511 L .40796 .7728 L F
.347 .282 .641 r
.40577 .77316 m .40624 .77589 L .40757 .77511 L F
.538 .307 .513 r
.40577 .77316 m .40757 .77511 L .40796 .7728 L F
.879 .876 .438 r
.463 .75431 m .46282 .75387 L .46387 .75147 L F
0 0 0 r
.46606 .74951 m .46387 .75147 L .46543 .75062 L F
.74 .62 .725 r
.46282 .75387 m .46543 .75062 L .46387 .75147 L F
.298 .08 .405 r
.30255 .62825 m .30488 .62511 L .3038 .62899 L F
.418 .215 .496 r
.30256 .63073 m .30255 .62825 L .3038 .62899 L F
.284 .767 .674 r
.45339 .75021 m .45135 .75105 L .45225 .7507 L F
.553 .426 .661 r
.50974 .79347 m .51109 .79234 L .50889 .79186 L F
0 0 0 r
.59613 .72127 m .59772 .72055 L .59868 .7186 L F
.26 .059 .406 r
.60051 .71563 m .59868 .7186 L .59987 .71795 L F
.117 0 .02 r
.59868 .7186 m .59952 .71961 L .59987 .71795 L F
.59868 .7186 m .59772 .72055 L .59952 .71961 L F
.437 .017 .142 r
.52658 .78315 m .52887 .78303 L .5279 .78197 L F
.766 .479 .499 r
.52887 .78303 m .53062 .78192 L .5279 .78197 L F
.396 .243 .553 r
.59538 .72949 m .59664 .73107 L .59691 .72886 L F
.59538 .72949 m .59529 .73197 L .59664 .73107 L F
0 .06 .566 r
.58175 .70969 m .58425 .71219 L .58192 .71186 L F
.625 .635 .84 r
.31791 .72863 m .31687 .73201 L .31427 .73103 L F
.43 .489 .819 r
.31993 .73409 m .31687 .73201 L .31973 .73213 L F
.617 .492 .688 r
.32074 .73278 m .31993 .73409 L .31976 .73245 L F
.31999 .73229 m .31976 .73245 L .31973 .73213 L F
.32074 .73278 m .31976 .73245 L .31999 .73229 L F
.573 .132 .163 r
.31687 .73201 m .31999 .73229 L .31973 .73213 L F
.461 .343 .632 r
.31973 .73213 m .32009 .7323 L .32158 .73142 L F
.625 .635 .84 r
.32006 .73225 m .32009 .7323 L .31999 .73229 L F
.573 .132 .163 r
.31999 .73229 m .32009 .7323 L .31973 .73213 L F
.591 .62 .849 r
.32158 .73142 m .32009 .7323 L .32006 .73225 L F
.617 .492 .688 r
.32158 .73142 m .32074 .73278 L .31998 .73229 L F
.32158 .73142 m .31998 .73229 L .31973 .73213 L F
.591 .62 .849 r
.32158 .73142 m .32006 .73225 L .31791 .72863 L F
.625 .635 .84 r
.31791 .72863 m .32006 .73225 L .31687 .73201 L F
.32006 .73225 m .31999 .73229 L .31687 .73201 L F
.686 .249 .206 r
.47098 .77383 m .47293 .77376 L .47455 .77268 L F
.47098 .77383 m .47304 .77584 L .47293 .77376 L F
.501 .128 .263 r
.47143 .77685 m .47271 .77608 L .47304 .77584 L F
.911 .526 .104 r
.47357 .77544 m .47304 .77584 L .47397 .77648 L F
.403 .583 .914 r
.4749 .77477 m .47397 .77648 L .47304 .77584 L F
.501 .128 .263 r
.47271 .77608 m .4749 .77477 L .47304 .77584 L F
.911 .526 .104 r
.47293 .77376 m .47304 .77584 L .47357 .77544 L F
.499 .594 .88 r
.41066 .66013 m .41048 .66313 L .40852 .66057 L F
.41066 .66013 m .41242 .66292 L .41048 .66313 L F
.226 .324 .755 r
.56152 .73742 m .56261 .74067 L .56162 .74017 L F
0 .219 .716 r
.7353 .5862 m .73366 .5854 L .73274 .58453 L F
.7353 .5862 m .73614 .58726 L .73366 .5854 L F
0 0 0 r
.36008 .70739 m .36087 .70724 L .36222 .70684 L F
.36008 .70739 m .35903 .70771 L .36087 .70724 L F
.922 .975 .758 r
.60989 .69336 m .61216 .6911 L .61144 .69189 L F
.60989 .69336 m .61171 .69066 L .61216 .6911 L F
.63 .717 .909 r
.52943 .72884 m .53271 .72945 L .53212 .72793 L F
.281 .485 .879 r
.53212 .72793 m .53271 .72945 L .53374 .7283 L F
.44 .489 .813 r
.53289 .73118 m .53374 .7283 L .53271 .72945 L F
.677 .453 .574 r
.51589 .73474 m .52014 .73468 L .5201 .73218 L F
.632 .821 .973 r
.67701 .60237 m .67789 .60331 L .67543 .60314 L F
.86 .878 .85 r
.68011 .60059 m .67789 .60331 L .67701 .60237 L F
.748 .787 .885 r
.72965 .735 m .73323 .73519 L .73205 .73505 L F
.53 .27 .466 r
.73617 .73262 m .73724 .73414 L .73436 .73445 L F
.164 0 0 r
.73724 .73414 m .73514 .73405 L .73436 .73445 L F
0 0 .178 r
.73469 .73193 m .73436 .73445 L .73332 .73498 L F
.414 .12 .354 r
.73617 .73262 m .73436 .73445 L .73469 .73193 L F
.164 0 0 r
.73514 .73405 m .73282 .73395 L .73436 .73445 L F
0 0 .178 r
.73332 .73498 m .73436 .73445 L .73323 .73519 L F
.425 .862 .92 r
.73436 .73445 m .73205 .73505 L .73323 .73519 L F
0 0 .463 r
.59529 .73197 m .59638 .73503 L .59626 .73412 L F
.902 .63 .515 r
.59801 .73696 m .59626 .73412 L .59638 .73503 L F
.3 .449 .843 r
.56008 .73378 m .55962 .73559 L .55949 .73431 L F
.97 .654 .291 r
.56008 .73378 m .56152 .73742 L .55962 .73559 L F
.339 .354 .73 r
.60884 .73129 m .60808 .73454 L .60732 .73093 L F
.60884 .73129 m .60966 .73502 L .60808 .73454 L F
.308 .382 .777 r
.60966 .73502 m .61065 .73658 L .60808 .73454 L F
.559 .31 .494 r
.4436 .75131 m .44558 .75321 L .44333 .75346 L F
.564 .417 .64 r
.40942 .75106 m .41173 .75078 L .41147 .74808 L F
.549 .334 .54 r
.40912 .75345 m .41173 .75078 L .40942 .75106 L F
.588 .926 .717 r
.55636 .68266 m .55741 .6815 L .55908 .68058 L F
0 0 0 r
.55636 .68266 m .55661 .68254 L .55741 .6815 L F
.92 .747 .651 r
.46347 .75658 m .46282 .75387 L .463 .75431 L F
.494 .388 .663 r
.28462 .62303 m .28669 .62229 L .28628 .61972 L F
.357 .163 .474 r
.28441 .62502 m .28669 .62229 L .28462 .62303 L F
.091 0 0 r
.33956 .72983 m .33718 .73121 L .33548 .73144 L F
0 0 0 r
.33921 .73013 m .33956 .72983 L .34122 .72884 L F
.33921 .73013 m .33718 .73121 L .33956 .72983 L F
.187 0 .201 r
.60531 .71055 m .60301 .71304 L .60473 .71204 L F
.091 0 0 r
.60473 .71204 m .60769 .71004 L .60531 .71055 L F
.524 .355 .594 r
.60531 .71055 m .60769 .71004 L .60749 .70745 L F
.119 0 .281 r
.66953 .59753 m .67059 .59751 L .67076 .59579 L F
.631 .529 .721 r
.66953 .59753 m .67224 .60024 L .67059 .59751 L F
.344 .184 .515 r
.62047 .70171 m .62053 .70415 L .61809 .70487 L F
.162 0 .334 r
.62053 .70415 m .618 .70706 L .61809 .70487 L F
0 0 0 r
.60076 .75624 m .60238 .75567 L .60059 .75669 L F
.861 .932 .87 r
.70783 .60862 m .71102 .60715 L .71016 .60835 L F
.639 .432 .586 r
.71389 .60653 m .71346 .60877 L .71102 .60715 L F
.719 .325 .302 r
.71102 .60715 m .71346 .60877 L .71016 .60835 L F
.511 .074 .145 r
.45555 .7297 m .45745 .73076 L .45885 .72907 L F
.429 0 .007 r
.45745 .73076 m .46106 .72938 L .45885 .72907 L F
.434 .532 .858 r
.5657 .7419 m .56405 .74331 L .56261 .74067 L F
.389 .452 .805 r
.5657 .7419 m .56691 .74523 L .56405 .74331 L F
.68 .452 .569 r
.53903 .78652 m .54121 .78641 L .54165 .78421 L F
.398 .193 .481 r
.54165 .78421 m .54121 .78641 L .54363 .786 L F
.668 .624 .796 r
.47916 .74304 m .48025 .73986 L .4782 .74103 L F
.47916 .74304 m .48143 .74297 L .48025 .73986 L F
.29 .756 .945 r
.28335 .5967 m .28707 .59699 L .285 .59724 L F
.587 .419 .621 r
.3106 .6774 m .3128 .6746 L .31041 .67494 L F
.179 .32 .771 r
.56031 .69951 m .5625 .70138 L .56131 .69834 L F
.56131 .69834 m .56031 .69951 L .55912 .6989 L F
.56131 .69834 m .5625 .70138 L .56031 .69951 L F
.701 .65 .796 r
.52058 .74052 m .52154 .74327 L .5183 .74313 L F
.786 .6 .649 r
.52154 .74327 m .51834 .74525 L .5183 .74313 L F
.52154 .74327 m .52188 .74567 L .51834 .74525 L F
.597 .497 .711 r
.52304 .73955 m .52154 .74327 L .52058 .74052 L F
.52304 .73955 m .52382 .74272 L .52154 .74327 L F
.44 .277 .564 r
.52382 .74272 m .52188 .74567 L .52154 .74327 L F
.918 .904 .502 r
.62895 .68393 m .62884 .68608 L .62985 .6827 L F
.926 .949 .613 r
.62895 .68393 m .62768 .68783 L .62884 .68608 L F
.479 .262 .506 r
.41507 .67918 m .41324 .67749 L .4153 .67699 L F
.41507 .67918 m .41297 .67969 L .41324 .67749 L F
0 .081 .637 r
.55314 .73742 m .55242 .73447 L .54956 .7336 L F
.889 .588 .471 r
.56232 .7477 m .56084 .74763 L .56218 .74578 L F
.716 .294 .243 r
.48295 .77836 m .48509 .78039 L .48641 .77883 L F
.661 .225 .202 r
.48509 .78039 m .48852 .78053 L .48641 .77883 L F
.354 .792 .623 r
.55908 .68058 m .56016 .67996 L .56091 .67949 L F
.55908 .68058 m .55741 .6815 L .56016 .67996 L F
.474 .12 .284 r
.47757 .72609 m .47974 .72588 L .48036 .72444 L F
.372 .022 .235 r
.48036 .72444 m .48182 .72537 L .4825 .72402 L F
.48036 .72444 m .47974 .72588 L .48182 .72537 L F
.603 .942 .764 r
.56229 .6853 m .55933 .68756 L .56099 .68636 L F
.221 0 0 r
.56161 .6918 m .56052 .69304 L .55829 .69348 L F
0 0 0 r
.56206 .69172 m .56161 .6918 L .56348 .69076 L F
.56206 .69172 m .56052 .69304 L .56161 .6918 L F
.69 .316 .332 r
.51126 .78656 m .50768 .78655 L .51014 .78935 L F
.436 .862 .733 r
.51014 .78935 m .51278 .78805 L .51126 .78656 L F
.642 .613 .805 r
.40816 .78642 m .41129 .78898 L .41128 .78696 L F
.596 .534 .756 r
.41128 .78696 m .41129 .78898 L .41353 .78677 L F
.615 .678 .886 r
.41129 .78898 m .41483 .78962 L .41353 .78677 L F
.682 .727 .884 r
.47454 .74203 m .47145 .74246 L .47243 .74037 L F
.048 0 .114 r
.58798 .72149 m .58695 .72254 L .58893 .71974 L F
.658 .46 .605 r
.58407 .72051 m .58798 .72149 L .58757 .71809 L F
.813 .571 .573 r
.58757 .71809 m .58798 .72149 L .58893 .71974 L F
.833 .633 .632 r
.6277 .6607 m .62946 .66371 L .62955 .66124 L F
.553 .378 .598 r
.30858 .6802 m .31073 .68214 L .31063 .67975 L F
.30858 .6802 m .30852 .6826 L .31073 .68214 L F
.432 .159 .397 r
.39851 .69496 m .39692 .69394 L .39891 .69335 L F
.39851 .69496 m .39643 .69557 L .39692 .69394 L F
.054 0 .143 r
.60601 .70187 m .60784 .70133 L .60826 .6992 L F
.243 0 .104 r
.60494 .70319 m .60784 .70133 L .60601 .70187 L F
.555 .507 .756 r
.4183 .73992 m .4205 .73994 L .4197 .73708 L F
.644 .321 .41 r
.4183 .73992 m .42041 .74159 L .4205 .73994 L F
.4183 .73992 m .41748 .7422 L .42041 .74159 L F
.782 .492 .496 r
.60319 .65474 m .60616 .65313 L .60308 .6526 L F
.60319 .65474 m .60651 .65521 L .60616 .65313 L F
.474 .248 .49 r
.39183 .69892 m .39192 .70235 L .38939 .70221 L F
.469 .24 .483 r
.39446 .6963 m .39302 .69923 L .39183 .69892 L F
.635 .372 .503 r
.39677 .70157 m .39183 .69892 L .39302 .69923 L F
.39677 .70157 m .39192 .70235 L .39183 .69892 L F
.316 .458 .844 r
.56807 .72645 m .56962 .72941 L .57092 .72816 L F
.185 .241 .688 r
.56962 .72941 m .57147 .73144 L .57092 .72816 L F
.878 .985 .71 r
.68544 .60915 m .68741 .6063 L .68696 .60588 L F
.702 .983 .88 r
.68696 .60588 m .68741 .6063 L .69016 .60424 L F
.371 0 .125 r
.37418 .7137 m .37228 .71506 L .37027 .71538 L F
.213 0 0 r
.37431 .71443 m .37228 .71506 L .37418 .7137 L F
.673 .449 .573 r
.49193 .73479 m .49178 .73711 L .48796 .73761 L F
.738 .505 .577 r
.49193 .73479 m .49301 .73739 L .49178 .73711 L F
.384 0 .043 r
.34914 .64972 m .35131 .64953 L .35264 .64804 L F
.418 0 .066 r
.35264 .64804 m .35467 .6485 L .35486 .64816 L F
.35264 .64804 m .35131 .64953 L .35467 .6485 L F
.742 .798 .897 r
.69016 .60424 m .69314 .60428 L .69215 .60302 L F
.685 .77 .915 r
.69314 .60428 m .69547 .60349 L .69215 .60302 L F
.772 .493 .512 r
.5183 .74313 m .51498 .74494 L .51506 .74315 L F
.5183 .74313 m .51834 .74525 L .51498 .74494 L F
.633 .545 .737 r
.52058 .74052 m .5183 .74313 L .51807 .74129 L F
.667 .491 .638 r
.44114 .75635 m .43903 .75857 L .43903 .75665 L F
.636 .167 .123 r
.4787 .78335 m .48219 .78353 L .48061 .78408 L F
.638 .133 .032 r
.48219 .78353 m .48287 .78535 L .48061 .78408 L F
.48219 .78353 m .48415 .78453 L .48287 .78535 L F
.494 .281 .519 r
.41093 .68026 m .41055 .68256 L .4087 .68296 L F
.347 .101 .392 r
.41297 .67969 m .41055 .68256 L .41093 .68026 L F
.511 0 0 r
.73051 .58296 m .73274 .58453 L .73056 .5828 L F
.902 .656 .556 r
.60805 .66939 m .60658 .67108 L .60649 .66904 L F
.60805 .66939 m .60807 .67167 L .60658 .67108 L F
.861 .674 .647 r
.68168 .59516 m .68297 .59796 L .6814 .59639 L F
.779 .69 .765 r
.6814 .59639 m .68297 .59796 L .68011 .60059 L F
.586 .044 0 r
.4196 .66481 m .41963 .66444 L .41769 .66503 L F
.56 .275 .44 r
.41976 .66507 m .4207 .66547 L .41963 .66444 L F
.586 .044 0 r
.4196 .66481 m .4207 .66547 L .41963 .66444 L F
0 0 0 r
.61159 .74478 m .60999 .74803 L .6108 .74617 L F
.253 0 0 r
.45628 .78441 m .45704 .78503 L .45493 .78511 L F
.45628 .78441 m .4585 .78453 L .45704 .78503 L F
0 0 0 r
.73628 .72401 m .73543 .7261 L .73408 .72679 L F
0 0 .322 r
.73543 .7261 m .73437 .72899 L .73408 .72679 L F
.434 .283 .576 r
.67294 .59025 m .67501 .59211 L .67463 .59053 L F
.67294 .59025 m .67304 .59245 L .67501 .59211 L F
.506 .321 .564 r
.30301 .69387 m .305 .69342 L .30512 .6911 L F
.608 .491 .694 r
.30308 .69639 m .305 .69342 L .30301 .69387 L F
.383 .047 .266 r
.59334 .6559 m .5907 .65787 L .59289 .6571 L F
.343 0 .136 r
.59289 .6571 m .59569 .65556 L .59334 .6559 L F
.421 0 0 r
.44264 .77601 m .44482 .77621 L .44604 .77561 L F
0 0 0 r
.44604 .77561 m .44689 .77551 L .44819 .77526 L F
.44604 .77561 m .44482 .77621 L .44689 .77551 L F
.21 0 .188 r
.73842 .72297 m .73628 .72401 L .739 .72156 L F
.428 .058 .232 r
.73739 .72553 m .73628 .72401 L .73842 .72297 L F
.73739 .72553 m .73543 .7261 L .73628 .72401 L F
.783 .605 .659 r
.62777 .65835 m .62464 .6556 L .62486 .65795 L F
.853 .625 .593 r
.6277 .6607 m .62777 .65835 L .62486 .65795 L F
.578 .592 .83 r
.44684 .75869 m .44591 .76215 L .44566 .76114 L F
.44684 .75869 m .44833 .76221 L .44591 .76215 L F
.725 .211 0 r
.44833 .76221 m .44566 .76114 L .44591 .76215 L F
.308 .05 .35 r
.29232 .64489 m .29466 .64212 L .29408 .64418 L F
.296 .034 .335 r
.29466 .64212 m .29698 .63948 L .29622 .64134 L F
.29 .055 .373 r
.29408 .64418 m .29466 .64212 L .29622 .64134 L F
.808 .671 .712 r
.31776 .80426 m .31906 .80631 L .31998 .80546 L F
.238 0 0 r
.29292 .72029 m .29643 .71821 L .29433 .71932 L F
.352 .327 .691 r
.56733 .69363 m .56928 .69312 L .56842 .69023 L F
.817 .451 .362 r
.51268 .7943 m .51498 .79463 L .51478 .79703 L F
.117 0 0 r
.51696 .79424 m .51498 .79463 L .51689 .794 L F
.216 0 0 r
.51696 .79424 m .52034 .79209 L .51879 .79349 L F
.348 .819 .761 r
.51831 .79366 m .51696 .79424 L .51879 .79349 L F
.51421 .79509 m .51696 .79424 L .51831 .79366 L F
.208 0 .277 r
.51478 .79703 m .51494 .79512 L .51696 .79424 L F
.51494 .79512 m .51498 .79463 L .51696 .79424 L F
.127 0 0 r
.51897 .78456 m .51985 .78528 L .52122 .7843 L F
.51897 .78456 m .51784 .78595 L .51985 .78528 L F
.473 .498 .803 r
.53524 .74143 m .53803 .74303 L .53949 .74197 L F
.284 .381 .786 r
.57193 .74036 m .57443 .74233 L .57332 .73915 L F
.875 .93 .856 r
.52305 .765 m .52099 .76775 L .52039 .76681 L F
.622 .509 .705 r
.52305 .765 m .52355 .76768 L .52099 .76775 L F
.576 .272 .416 r
.52355 .76768 m .52305 .76943 L .52099 .76775 L F
.682 .159 0 r
.52305 .76943 m .52039 .76681 L .52099 .76775 L F
.443 .371 .681 r
.43631 .76146 m .43371 .75921 L .43599 .75913 L F
.43631 .76146 m .43425 .76265 L .43371 .75921 L F
.091 0 0 r
.53212 .72793 m .52834 .72763 L .52943 .72884 L F
.018 0 0 r
.5296 .72769 m .52834 .72763 L .53031 .72782 L F
.5296 .72769 m .52929 .72785 L .52834 .72763 L F
.664 .626 .801 r
.5277 .72747 m .52943 .72884 L .52834 .72763 L F
.018 0 0 r
.52929 .72785 m .5256 .72981 L .52834 .72763 L F
.664 .626 .801 r
.52618 .72627 m .5277 .72747 L .52834 .72763 L F
0 .471 .722 r
.51545 .70502 m .51777 .70548 L .51883 .70574 L F
.296 0 0 r
.51777 .70548 m .52136 .70569 L .51883 .70574 L F
.485 .71 .969 r
.38393 .65114 m .38193 .65149 L .38033 .64989 L F
.75 .76 .251 r
.30663 .72923 m .30609 .73097 L .30589 .73225 L F
.8 .975 .682 r
.30609 .73097 m .30397 .73388 L .30589 .73225 L F
.691 .785 .923 r
.2979 .73575 m .29696 .73414 L .29643 .73493 L F
.2979 .73575 m .30008 .73474 L .29696 .73414 L F
.283 0 .288 r
.602 .71447 m .60473 .71204 L .60301 .71304 L F
.382 .095 .348 r
.41006 .68459 m .4087 .68296 L .41055 .68256 L F
.41006 .68459 m .40811 .68517 L .4087 .68296 L F
.465 .619 .917 r
.5672 .69777 m .56776 .69919 L .56585 .69934 L F
.268 0 0 r
.3055 .71845 m .30685 .7192 L .30791 .71834 L F
.501 .084 .18 r
.30611 .71875 m .30717 .71828 L .30685 .7192 L F
.929 .908 .78 r
.30829 .7146 m .30791 .71834 L .30918 .7174 L F
.30798 .71763 m .30576 .71825 L .30791 .71834 L F
.30576 .71825 m .30577 .71831 L .30791 .71834 L F
.835 .712 .728 r
.3046 .71656 m .30576 .71806 L .30589 .71789 L F
.30524 .71622 m .30589 .71789 L .30829 .7146 L F
.3046 .71656 m .30589 .71789 L .30524 .71622 L F
.929 .908 .78 r
.30829 .7146 m .30589 .71789 L .30798 .71763 L F
.30589 .71789 m .30558 .71831 L .30587 .71822 L F
.30589 .71789 m .30587 .71822 L .30798 .71763 L F
.501 .084 .18 r
.30717 .71828 m .30918 .7174 L .30807 .71825 L F
0 0 0 r
.30791 .71834 m .30689 .71916 L .30918 .7174 L F
.30689 .71916 m .30685 .7192 L .30693 .71913 L F
.30689 .71916 m .30693 .71913 L .30918 .7174 L F
.501 .084 .18 r
.30717 .71828 m .30807 .71825 L .30693 .71913 L F
.30688 .71911 m .30693 .71913 L .30685 .7192 L F
.30717 .71828 m .30693 .71913 L .30688 .71911 L F
.087 .645 .766 r
.30791 .71834 m .30627 .71832 L .3055 .71845 L F
.501 .084 .18 r
.30611 .71875 m .30792 .71918 L .30918 .7174 L F
.413 .481 .821 r
.30665 .71616 m .30767 .71859 L .30623 .71878 L F
.30767 .71859 m .30792 .71918 L .30713 .71899 L F
.30767 .71859 m .30713 .71899 L .30623 .71878 L F
.30615 .71856 m .30623 .71878 L .30611 .71875 L F
.30665 .71616 m .30623 .71878 L .30615 .71856 L F
.30573 .71634 m .30576 .71806 L .3046 .71656 L F
.30576 .71806 m .30576 .71825 L .3046 .71656 L F
.931 .718 .592 r
.3046 .71656 m .30576 .71825 L .30558 .71831 L F
.835 .712 .728 r
.3046 .71656 m .30558 .71831 L .30576 .71806 L F
.413 .481 .821 r
.30665 .71616 m .30611 .71875 L .30576 .71825 L F
.30665 .71616 m .30576 .71825 L .30573 .71634 L F
.929 .908 .78 r
.30576 .71825 m .30558 .71831 L .30577 .71831 L F
.087 .645 .766 r
.30627 .71832 m .30558 .71831 L .30556 .71834 L F
.30627 .71832 m .30556 .71834 L .3055 .71845 L F
.931 .718 .592 r
.30576 .71825 m .30611 .71875 L .30558 .71831 L F
0 .217 .633 r
.30611 .71875 m .3055 .71845 L .30558 .71831 L F
.30611 .71875 m .30685 .7192 L .3055 .71845 L F
.332 .011 .261 r
.28958 .64716 m .29232 .64489 L .29132 .64654 L F
.279 0 .226 r
.29132 .64654 m .29232 .64489 L .29408 .64418 L F
.528 .065 .1 r
.437 .78658 m .43588 .78778 L .43341 .78766 L F
.5 .04 .092 r
.43947 .78657 m .43588 .78778 L .437 .78658 L F
.365 .179 .491 r
.29698 .63948 m .29884 .63641 L .29843 .63859 L F
.164 0 .241 r
.29622 .64134 m .29698 .63948 L .29843 .63859 L F
0 0 0 r
.50763 .70668 m .50876 .70642 L .51024 .70574 L F
.50763 .70668 m .50671 .70718 L .50876 .70642 L F
.889 .878 .818 r
.57536 .70175 m .57156 .70411 L .57405 .70072 L F
.57536 .70175 m .57283 .70479 L .57156 .70411 L F
.897 .541 .36 r
.57405 .70072 m .57674 .70394 L .57536 .70175 L F
.451 .255 .522 r
.33532 .69918 m .33503 .70198 L .33319 .70212 L F
.317 0 0 r
.48664 .78517 m .48783 .78476 L .49014 .78534 L F
.577 .41 .619 r
.51089 .7467 m .51039 .74874 L .51056 .74575 L F
.685 .626 .783 r
.51284 .7454 m .51089 .7467 L .51056 .74575 L F
.51284 .7454 m .51394 .74845 L .51089 .7467 L F
.502 .337 .59 r
.51275 .74804 m .51089 .7467 L .51394 .74845 L F
.507 .351 .604 r
.51056 .74575 m .51275 .74804 L .51284 .7454 L F
.502 .337 .59 r
.51275 .74804 m .51039 .74874 L .51089 .7467 L F
.507 .351 .604 r
.51056 .74575 m .51039 .74874 L .51275 .74804 L F
.347 .541 .902 r
.39533 .65412 m .39437 .65543 L .39284 .65328 L F
.308 .091 .413 r
.59987 .71795 m .602 .71447 L .60051 .71563 L F
.58 .493 .721 r
.33636 .69338 m .33507 .69727 L .33424 .69413 L F
.33636 .69338 m .33689 .69744 L .33507 .69727 L F
.567 .45 .678 r
.33689 .69744 m .33532 .69918 L .33507 .69727 L F
.847 .881 .864 r
.57283 .70479 m .56997 .70779 L .57009 .70639 L F
.492 .36 .628 r
.30512 .6911 m .30684 .68826 L .30486 .68887 L F
.481 .162 .348 r
.34749 .6803 m .34498 .68223 L .34555 .68064 L F
.038 .195 .699 r
.57803 .75382 m .57885 .75287 L .57709 .75079 L F
0 .065 .593 r
.57803 .75382 m .5794 .75641 L .57885 .75287 L F
.789 .524 .536 r
.69529 .58972 m .69878 .59266 L .69654 .59367 L F
.331 .229 .586 r
.60863 .72896 m .60884 .73129 L .60732 .73093 L F
.744 .235 .004 r
.5823 .71372 m .57944 .71227 L .58235 .71331 L F
.836 .844 .852 r
.5968 .72359 m .59363 .72369 L .595 .72291 L F
.925 .695 .57 r
.59613 .72127 m .5968 .72359 L .595 .72291 L F
.292 .162 .526 r
.59654 .72636 m .59862 .72323 L .5968 .72359 L F
.59654 .72636 m .59865 .7256 L .59862 .72323 L F
.782 .659 .728 r
.59716 .72603 m .59363 .72369 L .5968 .72359 L F
.429 .41 .737 r
.5968 .72359 m .59862 .72323 L .59613 .72127 L F
.306 .173 .53 r
.59862 .72323 m .59716 .72603 L .5968 .72359 L F
.429 .41 .737 r
.5968 .72359 m .59862 .72323 L .59613 .72127 L F
.431 .679 .967 r
.28377 .61043 m .28513 .61179 L .28567 .61042 L F
.003 .165 .68 r
.28513 .61179 m .28681 .6138 L .28567 .61042 L F
.444 .286 .571 r
.28513 .61179 m .28507 .61422 L .28681 .6138 L F
.648 .507 .678 r
.29903 .70192 m .30165 .70213 L .30114 .69935 L F
.465 .184 .403 r
.59569 .65556 m .59785 .65504 L .59839 .65264 L F
.528 .236 .414 r
.59785 .65504 m .60107 .65231 L .59839 .65264 L F
.713 .987 .841 r
.67446 .60944 m .67158 .61114 L .67339 .60851 L F
.445 .277 .558 r
.4882 .73954 m .48589 .73757 L .48796 .73761 L F
.4882 .73954 m .48606 .73979 L .48589 .73757 L F
.553 .424 .659 r
.4073 .75675 m .40912 .75345 L .40726 .75382 L F
.199 0 .054 r
.46827 .75346 m .46677 .75325 L .46912 .75317 L F
.46827 .75346 m .4662 .75427 L .46677 .75325 L F
.444 .236 .502 r
.3113 .6172 m .31115 .61883 L .30943 .61979 L F
.384 .156 .44 r
.31376 .6142 m .31361 .6163 L .3113 .6172 L F
.353 .134 .435 r
.31361 .6163 m .31115 .61883 L .3113 .6172 L F
.246 0 .007 r
.36677 .7178 m .37027 .71538 L .36879 .7172 L F
.319 0 .011 r
.37027 .71538 m .3708 .71672 L .36879 .7172 L F
.37027 .71538 m .37228 .71506 L .3708 .71672 L F
.417 .169 .427 r
.30943 .61979 m .3085 .62168 L .30696 .62251 L F
.226 0 .308 r
.31048 .62139 m .30943 .61979 L .31115 .61883 L F
.31048 .62139 m .3085 .62168 L .30943 .61979 L F
.561 .931 .919 r
.43026 .78759 m .42802 .78874 L .42835 .78886 L F
.093 0 0 r
.44845 .78579 m .44721 .7859 L .44529 .78586 L F
.225 0 0 r
.44975 .78579 m .44721 .7859 L .44845 .78579 L F
.083 .582 .895 r
.5563 .74634 m .5567 .74594 L .5551 .7458 L F
.5563 .74634 m .5591 .74697 L .5567 .74594 L F
.427 .195 .458 r
.39614 .69832 m .39446 .6963 L .39643 .69557 L F
.39614 .69832 m .39302 .69923 L .39446 .6963 L F
0 0 0 r
.44933 .75167 m .44756 .75272 L .44558 .75321 L F
.343 0 0 r
.45135 .75105 m .44756 .75272 L .44933 .75167 L F
.851 .882 .862 r
.71142 .61073 m .70847 .61097 L .71016 .60835 L F
.71142 .61073 m .7096 .61186 L .70847 .61097 L F
.724 .731 .857 r
.71346 .60877 m .71142 .61073 L .71016 .60835 L F
.982 .753 .514 r
.53817 .71808 m .53801 .72072 L .53916 .72127 L F
0 .058 .561 r
.54038 .72229 m .53916 .72127 L .53801 .72072 L F
.67 .122 0 r
.53916 .72127 m .54146 .72341 L .54268 .7239 L F
0 .058 .561 r
.54038 .72229 m .54146 .72341 L .53916 .72127 L F
.481 .744 .986 r
.29939 .59922 m .29589 .59834 L .29799 .59825 L F
.509 .772 .991 r
.29989 .59794 m .29939 .59922 L .29799 .59825 L F
.29989 .59794 m .30119 .59898 L .29939 .59922 L F
.752 .318 0 r
.4966 .7822 m .49626 .78092 L .4944 .78022 L F
.4966 .7822 m .49747 .78326 L .49626 .78092 L F
.827 .392 .203 r
.49626 .78092 m .49747 .78326 L .4993 .78362 L F
.609 .04 0 r
.54726 .70384 m .54585 .70366 L .54349 .702 L F
.655 .109 0 r
.54726 .70384 m .54837 .70551 L .54585 .70366 L F
.54726 .70384 m .54968 .70619 L .54837 .70551 L F
.004 .201 .714 r
.73581 .71373 m .73412 .71282 L .73293 .71212 L F
.73581 .71373 m .7362 .71524 L .73412 .71282 L F
.202 .407 .84 r
.58246 .76193 m .58349 .76102 L .58092 .75929 L F
.201 .405 .838 r
.58246 .76193 m .5853 .76325 L .58349 .76102 L F
.899 .877 .806 r
.68148 .61273 m .68159 .61045 L .68064 .61212 L F
.937 .753 .629 r
.67996 .61381 m .68148 .61273 L .68064 .61212 L F
.67996 .61381 m .68136 .61487 L .68148 .61273 L F
.023 0 0 r
.45386 .77316 m .45439 .77382 L .45635 .77426 L F
.45386 .77316 m .45254 .77476 L .45439 .77382 L F
.566 .43 .654 r
.4132 .74299 m .41557 .74497 L .41525 .74266 L F
.4132 .74299 m .41342 .74547 L .41557 .74497 L F
0 0 0 r
.59613 .72127 m .595 .72291 L .59772 .72055 L F
.389 .39 .739 r
.73437 .72899 m .73666 .73099 L .73469 .73193 L F
.414 .12 .354 r
.73617 .73262 m .73469 .73193 L .73666 .73099 L F
.573 .135 .169 r
.74241 .59787 m .73965 .59891 L .7407 .59919 L F
.829 .359 .073 r
.31791 .72863 m .31444 .72548 L .31576 .72634 L F
.604 .38 .549 r
.31783 .72732 m .31791 .72863 L .31576 .72634 L F
.633 .545 .737 r
.52058 .74052 m .51807 .74129 L .51996 .73884 L F
.651 .62 .806 r
.51996 .73884 m .52058 .74052 L .51807 .74129 L F
0 0 .384 r
.51498 .74494 m .51394 .74845 L .51284 .7454 L F
.51498 .74494 m .51485 .7474 L .51394 .74845 L F
.569 .898 .983 r
.51485 .7474 m .51275 .74804 L .51394 .74845 L F
.918 .904 .502 r
.62895 .68393 m .62985 .6827 L .62925 .68209 L F
.824 .657 .677 r
.61334 .67783 m .61271 .67994 L .6112 .677 L F
.277 0 0 r
.59778 .66544 m .59566 .66565 L .59781 .66371 L F
.59778 .66544 m .59487 .66631 L .59566 .66565 L F
.233 0 0 r
.34711 .72719 m .34539 .72803 L .34332 .72812 L F
0 0 0 r
.34737 .72723 m .34711 .72719 L .34941 .72658 L F
.34737 .72723 m .34539 .72803 L .34711 .72719 L F
0 .171 .708 r
.60749 .70745 m .60754 .7065 L .60704 .70622 L F
0 0 .389 r
.60749 .70745 m .60856 .70867 L .60754 .7065 L F
.60749 .70745 m .60769 .71004 L .60856 .70867 L F
0 0 0 r
.32665 .66071 m .32789 .66027 L .32927 .65834 L F
.261 0 .052 r
.32927 .65834 m .32996 .65966 L .33152 .65807 L F
.32927 .65834 m .32789 .66027 L .32996 .65966 L F
.622 .556 .76 r
.74003 .71977 m .73842 .72297 L .739 .72156 L F
.497 .604 .89 r
.41483 .78962 m .41671 .78827 L .41353 .78677 L F
.41483 .78962 m .41699 .7895 L .41671 .78827 L F
.031 0 0 r
.44277 .78602 m .44166 .78631 L .43947 .78657 L F
.145 .689 .752 r
.44529 .78586 m .44166 .78631 L .44277 .78602 L F
.747 .525 .593 r
.61779 .655 m .62114 .65287 L .61773 .6527 L F
.61779 .655 m .62121 .65523 L .62114 .65287 L F
.752 .576 .658 r
.62121 .65523 m .62342 .65254 L .62114 .65287 L F
0 0 0 r
.70714 .72126 m .70447 .72407 L .70604 .72291 L F
.70714 .72126 m .70604 .72291 L .70586 .72179 L F
.70714 .72126 m .70885 .72065 L .70899 .72022 L F
.70714 .72126 m .70586 .72179 L .70885 .72065 L F
.043 .534 .883 r
.38797 .65133 m .38632 .65136 L .3861 .65091 L F
.38797 .65133 m .38934 .65217 L .38632 .65136 L F
.492 .36 .628 r
.30512 .6911 m .307 .69063 L .30684 .68826 L F
.55 .357 .573 r
.30512 .6911 m .30711 .693 L .307 .69063 L F
.30512 .6911 m .305 .69342 L .30711 .693 L F
.445 0 0 r
.52799 .7896 m .52462 .79041 L .52571 .78948 L F
.691 .361 .412 r
.53132 .78909 m .52836 .79083 L .52799 .7896 L F
.336 0 0 r
.53132 .78909 m .52799 .7896 L .53098 .78919 L F
.515 .074 .138 r
.53098 .78919 m .52799 .7896 L .52571 .78948 L F
.997 .769 .431 r
.57503 .68683 m .57594 .68787 L .576 .6852 L F
.809 .965 .647 r
.57782 .68194 m .5755 .6854 L .576 .6852 L F
.582 .465 .685 r
.40586 .762 m .40807 .76179 L .40774 .75912 L F
.519 .391 .646 r
.40586 .762 m .40825 .76445 L .40807 .76179 L F
.40586 .762 m .40615 .76496 L .40825 .76445 L F
.656 .732 .906 r
.30728 .59982 m .30817 .60134 L .3049 .60066 L F
.293 .525 .906 r
.30728 .59982 m .30889 .60009 L .30817 .60134 L F
.311 .549 .917 r
.30889 .60009 m .31065 .60223 L .30817 .60134 L F
.268 .378 .791 r
.70447 .72407 m .70719 .72601 L .70604 .72291 L F
.414 .382 .714 r
.70538 .72614 m .70719 .72601 L .70447 .72407 L F
.528 .212 .375 r
.46685 .74261 m .46329 .74539 L .46465 .74292 L F
.86 .878 .85 r
.68011 .60059 m .67701 .60237 L .6794 .59998 L F
.779 .69 .765 r
.6814 .59639 m .68011 .60059 L .6794 .59998 L F
.211 .296 .734 r
.57726 .70622 m .57857 .7095 L .5764 .7083 L F
.084 0 .14 r
.61467 .71331 m .61617 .71232 L .6139 .7149 L F
.91 .597 .112 r
.47018 .74784 m .47117 .75091 L .47059 .74824 L F
.419 .224 .507 r
.3038 .62899 m .30488 .62511 L .30691 .62481 L F
.526 0 0 r
.54146 .72341 m .54478 .72404 L .54268 .7239 L F
.651 .76 .281 r
.3088 .73457 m .30808 .73624 L .30779 .73421 L F
0 0 .568 r
.30826 .73542 m .30834 .73562 L .30808 .73624 L F
.651 .76 .281 r
.3088 .73457 m .30783 .73682 L .30808 .73624 L F
.892 .9 .827 r
.30808 .73624 m .31113 .73454 L .31008 .73438 L F
.30808 .73624 m .30898 .73733 L .31113 .73454 L F
0 0 0 r
.30534 .73949 m .30709 .73845 L .30754 .73913 L F
.30709 .73845 m .30898 .73733 L .30754 .73913 L F
.656 .111 0 r
.30811 .73998 m .30754 .73913 L .30926 .74089 L F
.827 .997 .771 r
.30808 .73624 m .30715 .73839 L .30534 .73949 L F
.744 .657 .764 r
.30808 .73624 m .30534 .73949 L .30431 .73659 L F
.514 .81 .999 r
.30534 .73949 m .30754 .73913 L .30586 .7382 L F
.656 .111 0 r
.30586 .7382 m .30754 .73913 L .30811 .73998 L F
.992 .839 .591 r
.30754 .73913 m .30898 .73733 L .30808 .73624 L F
0 0 .568 r
.30834 .73562 m .30948 .73849 L .30808 .73624 L F
.651 .76 .281 r
.30783 .73682 m .30715 .73839 L .30808 .73624 L F
.587 .419 .621 r
.3106 .6774 m .31294 .67707 L .3128 .6746 L F
.53 .336 .562 r
.31063 .67975 m .31294 .67707 L .3106 .6774 L F
.454 .022 .127 r
.36635 .67195 m .36494 .67374 L .36274 .67377 L F
.202 0 0 r
.36835 .67141 m .36494 .67374 L .36635 .67195 L F
.237 .358 .784 r
.48025 .73986 m .48143 .74297 L .48257 .74168 L F
.475 .725 .98 r
.48143 .74297 m .48374 .74305 L .48257 .74168 L F
.963 .654 .25 r
.57574 .74909 m .57499 .74844 L .57438 .74546 L F
.672 .185 0 r
.57574 .74909 m .57709 .75079 L .57499 .74844 L F
.636 .328 .432 r
.43975 .73626 m .4419 .73661 L .43987 .73469 L F
.609 .334 .475 r
.43987 .73469 m .4419 .73661 L .44221 .73465 L F
.699 .897 .968 r
.70209 .57974 m .70309 .5779 L .70399 .57809 L F
.70209 .57974 m .70103 .57898 L .70309 .5779 L F
.567 .45 .678 r
.33689 .69744 m .33735 .69879 L .33532 .69918 L F
.536 .329 .547 r
.33735 .69879 m .33503 .70198 L .33532 .69918 L F
.397 .026 .212 r
.60987 .65513 m .61223 .65463 L .61263 .65341 L F
.669 .398 .503 r
.61223 .65463 m .61452 .65289 L .61263 .65341 L F
.627 .187 .185 r
.51689 .72865 m .51381 .72873 L .51437 .72723 L F
.759 .34 .256 r
.31225 .72385 m .3112 .72446 L .3089 .72305 L F
.538 .55 .815 r
.3089 .72305 m .3112 .72446 L .31113 .72429 L F
.729 .27 .161 r
.3089 .72305 m .31076 .72408 L .31225 .72385 L F
.908 .663 .557 r
.31064 .7241 m .31239 .72631 L .31225 .72385 L F
.003 0 .376 r
.31225 .72385 m .31128 .72403 L .31112 .72405 L F
.014 0 .296 r
.31225 .72385 m .31293 .72038 L .31139 .72401 L F
.31225 .72385 m .31139 .72401 L .3112 .72446 L F
.806 .692 .739 r
.31031 .72218 m .31104 .72406 L .31293 .72038 L F
.31104 .72406 m .3112 .72446 L .31139 .72401 L F
.003 0 .376 r
.31225 .72385 m .31112 .72405 L .31076 .72408 L F
.806 .692 .739 r
.31104 .72406 m .31139 .72401 L .31293 .72038 L F
.003 0 .376 r
.31139 .72401 m .31311 .72381 L .31128 .72403 L F
.31225 .72385 m .3127 .72383 L .31139 .72401 L F
.3127 .72383 m .31311 .72381 L .31139 .72401 L F
.538 .55 .815 r
.31076 .72408 m .31113 .72429 L .31104 .72406 L F
.003 0 .376 r
.31076 .72408 m .31112 .72405 L .31064 .7241 L F
.538 .55 .815 r
.3089 .72305 m .31076 .72408 L .31031 .72218 L F
.31076 .72408 m .31104 .72406 L .31031 .72218 L F
.729 .27 .161 r
.3089 .72305 m .31064 .7241 L .31076 .72408 L F
.014 0 .296 r
.31225 .72385 m .31401 .7206 L .31293 .72038 L F
.31225 .72385 m .31303 .72397 L .31401 .7206 L F
.31303 .72397 m .31336 .72349 L .31401 .7206 L F
.706 .652 .793 r
.31401 .7206 m .3167 .72082 L .31516 .71758 L F
.037 0 .308 r
.31656 .72081 m .3159 .71992 L .3167 .72082 L F
.31401 .7206 m .3159 .71992 L .31656 .72081 L F
.706 .652 .793 r
.31401 .7206 m .31516 .71758 L .31293 .72038 L F
.87 .602 .075 r
.31558 .71901 m .3159 .71992 L .31459 .71846 L F
.31558 .71901 m .31574 .7197 L .3159 .71992 L F
.037 0 .308 r
.31401 .7206 m .31349 .7229 L .3159 .71992 L F
.31349 .7229 m .31325 .724 L .31477 .72166 L F
.31349 .7229 m .31477 .72166 L .3159 .71992 L F
.696 .731 .878 r
.3159 .71992 m .31379 .72286 L .31578 .71997 L F
.19 0 .016 r
.3159 .71992 m .31293 .72038 L .31459 .71846 L F
.3159 .71992 m .31045 .7226 L .31293 .72038 L F
.014 0 .296 r
.31303 .72397 m .31325 .724 L .31336 .72349 L F
.074 0 .344 r
.3159 .71992 m .31325 .724 L .31311 .72381 L F
.87 .602 .075 r
.31574 .7197 m .31668 .72363 L .3159 .71992 L F
.245 .533 .92 r
.3167 .72082 m .31709 .71954 L .31516 .71758 L F
.108 .265 .743 r
.3167 .72082 m .31867 .72279 L .31756 .72022 L F
0 .013 .522 r
.3159 .71992 m .31867 .72279 L .3167 .72082 L F
.939 .593 .175 r
.31756 .72022 m .31867 .72279 L .31709 .71954 L F
.888 .707 .651 r
.3159 .71992 m .31668 .72363 L .31867 .72279 L F
.933 .574 .158 r
.31737 .72144 m .31829 .72502 L .31867 .72279 L F
.3159 .71992 m .31718 .72266 L .31737 .72144 L F
.31718 .72266 m .31829 .72502 L .31737 .72144 L F
.28 .08 .42 r
.31867 .72279 m .31829 .72502 L .32033 .72179 L F
.933 .574 .158 r
.31718 .72266 m .31737 .72371 L .31829 .72502 L F
.536 .571 .838 r
.31709 .71954 m .31867 .72279 L .32033 .72179 L F
.377 .171 .469 r
.31889 .72388 m .31737 .72371 L .31803 .72043 L F
.31737 .72371 m .31668 .72363 L .31702 .72283 L F
.31737 .72371 m .31702 .72283 L .31803 .72043 L F
.933 .574 .158 r
.31737 .72371 m .31755 .72467 L .31782 .7248 L F
.31737 .72371 m .31782 .7248 L .31829 .72502 L F
.377 .171 .469 r
.31889 .72388 m .31698 .72399 L .31703 .72367 L F
.426 .46 .792 r
.31596 .72052 m .31668 .72363 L .31594 .72052 L F
.933 .574 .158 r
.3159 .71992 m .31658 .72188 L .31718 .72266 L F
.31658 .72188 m .31735 .72354 L .31718 .72266 L F
.377 .171 .469 r
.31742 .72396 m .31755 .72467 L .31698 .72399 L F
.31703 .72367 m .31698 .72399 L .31668 .72363 L F
0 .09 .608 r
.31668 .72363 m .31755 .72467 L .31658 .72188 L F
.31668 .72363 m .31658 .72188 L .3159 .71992 L F
.426 .46 .792 r
.31803 .72043 m .31702 .72283 L .31658 .72188 L F
.3165 .7205 m .31658 .72188 L .31596 .72052 L F
.31803 .72043 m .31658 .72188 L .3165 .7205 L F
.31702 .72283 m .31668 .72363 L .31596 .72052 L F
.933 .574 .158 r
.31658 .72188 m .31755 .72467 L .31735 .72354 L F
.377 .171 .469 r
.31889 .72388 m .31755 .72467 L .31742 .72396 L F
.426 .46 .792 r
.31678 .71971 m .31594 .72052 L .31558 .71901 L F
.245 .533 .92 r
.3167 .72082 m .31756 .72022 L .31709 .71954 L F
.426 .46 .792 r
.31803 .72043 m .31594 .72052 L .31678 .71971 L F
.696 .731 .878 r
.31578 .71997 m .31311 .72381 L .31045 .7226 L F
.31379 .72286 m .31311 .72381 L .31578 .71997 L F
.003 0 .376 r
.31225 .72385 m .31306 .72397 L .31311 .72381 L F
.589 .629 .86 r
.31064 .7241 m .31275 .72487 L .31311 .72381 L F
.31275 .72487 m .31444 .72548 L .31311 .72381 L F
.31064 .7241 m .31239 .72631 L .31444 .72548 L F
.633 .07 0 r
.31503 .72634 m .314 .7258 L .31311 .72381 L F
.591 .125 0 r
.31325 .724 m .31335 .72412 L .31311 .72381 L F
.31335 .72412 m .31444 .72548 L .31311 .72381 L F
0 0 .456 r
.31444 .72548 m .31524 .72645 L .31311 .72381 L F
.633 .07 0 r
.31524 .72645 m .31503 .72634 L .31311 .72381 L F
.003 0 .376 r
.31306 .72397 m .31319 .72399 L .31311 .72381 L F
.633 .07 0 r
.314 .7258 m .31124 .72435 L .31311 .72381 L F
.003 0 .376 r
.31319 .72399 m .31325 .724 L .31311 .72381 L F
.752 .576 .658 r
.62121 .65523 m .62464 .6556 L .62342 .65254 L F
.891 .858 .802 r
.39289 .80617 m .39432 .80414 L .39153 .8054 L F
.39289 .80617 m .39432 .80414 L .39153 .8054 L F
.354 .668 .974 r
.27604 .59515 m .27552 .59642 L .27426 .59526 L F
.27604 .59515 m .27774 .59651 L .27552 .59642 L F
.563 .841 .997 r
.72404 .73313 m .72528 .73191 L .72296 .73246 L F
.72404 .73313 m .72579 .73264 L .72528 .73191 L F
.214 .289 .726 r
.55814 .69573 m .55581 .69344 L .55829 .69348 L F
.496 .163 .332 r
.4446 .73458 m .44686 .73428 L .44773 .73207 L F
.528 .195 .347 r
.44773 .73207 m .4496 .73348 L .44998 .73196 L F
.44773 .73207 m .44686 .73428 L .4496 .73348 L F
.392 .126 .387 r
.30696 .62251 m .30851 .62417 L .30691 .62481 L F
.30696 .62251 m .3085 .62168 L .30851 .62417 L F
.282 .469 .866 r
.31228 .60266 m .31157 .60413 L .31065 .60223 L F
.383 .593 .928 r
.31228 .60266 m .31405 .60469 L .31157 .60413 L F
.347 0 0 r
.52122 .7843 m .52309 .78487 L .52445 .78378 L F
.564 .148 .212 r
.52309 .78487 m .52658 .78315 L .52445 .78378 L F
.434 .336 .645 r
.59654 .72636 m .59942 .72786 L .59865 .7256 L F
.59654 .72636 m .59691 .72886 L .59942 .72786 L F
.439 .78 .998 r
.26924 .60515 m .27028 .6039 L .26772 .60437 L F
.26924 .60515 m .27323 .60514 L .27028 .6039 L F
.438 .194 .444 r
.31518 .61276 m .31598 .6137 L .31376 .6142 L F
.401 .151 .415 r
.31598 .6137 m .31361 .6163 L .31376 .6142 L F
.822 .572 .562 r
.53248 .78564 m .53546 .78389 L .53232 .78346 L F
.53248 .78564 m .53563 .78641 L .53546 .78389 L F
.829 .797 .821 r
.40526 .65547 m .4031 .65815 L .40206 .65661 L F
.599 .443 .641 r
.4054 .65725 m .4031 .65815 L .40526 .65547 L F
.529 .731 .967 r
.37082 .83579 m .36779 .83482 L .36943 .83519 L F
.37082 .83579 m .36779 .83482 L .36943 .83519 L F
0 0 0 r
.28227 .65298 m .2791 .65495 L .27998 .65434 L F
.156 .643 .92 r
.29042 .59785 m .28707 .59699 L .28892 .59715 L F
.358 .76 .984 r
.28892 .59715 m .29241 .5977 L .29042 .59785 L F
.938 .772 .65 r
.6303 .6776 m .62903 .67437 L .62862 .67667 L F
.923 .688 .566 r
.62825 .67903 m .6303 .6776 L .62862 .67667 L F
.62825 .67903 m .63003 .68003 L .6303 .6776 L F
.544 .38 .61 r
.31817 .61099 m .31598 .6137 L .31518 .61276 L F
.805 .89 .905 r
.68159 .61045 m .68544 .60915 L .68421 .60813 L F
.878 .985 .71 r
.68544 .60915 m .68696 .60588 L .68421 .60813 L F
.694 .599 .745 r
.67076 .59579 m .67393 .59525 L .67304 .59245 L F
.558 .22 .351 r
.67059 .59751 m .67393 .59525 L .67076 .59579 L F
.794 .555 .576 r
.5145 .73765 m .51823 .73976 L .51594 .73671 L F
.5145 .73765 m .51362 .7397 L .51823 .73976 L F
.666 .216 .173 r
.51362 .7397 m .51617 .74168 L .51823 .73976 L F
.338 .105 .406 r
.51823 .73976 m .51996 .73884 L .52049 .73759 L F
.574 .2 .294 r
.51617 .74168 m .51996 .73884 L .51823 .73976 L F
.573 .757 .965 r
.71232 .61508 m .71366 .61337 L .71135 .61384 L F
.71232 .61508 m .71485 .61456 L .71366 .61337 L F
.216 0 .222 r
.27574 .63627 m .27737 .63571 L .27807 .63362 L F
.34 .024 .276 r
.27807 .63362 m .27925 .6351 L .28002 .63279 L F
.27807 .63362 m .27737 .63571 L .27925 .6351 L F
.965 .859 .454 r
.60872 .69813 m .60982 .69616 L .60826 .6992 L F
.60872 .69813 m .6094 .69567 L .60982 .69616 L F
.402 .116 .36 r
.29132 .64654 m .28886 .64975 L .28958 .64716 L F
.931 .661 .504 r
.61496 .68503 m .61326 .68209 L .61525 .68306 L F
.747 .534 .606 r
.54966 .74294 m .54771 .74298 L .54645 .74273 L F
.54966 .74294 m .54993 .7456 L .54771 .74298 L F
.375 .249 .579 r
.55067 .74025 m .55079 .74412 L .54966 .74294 L F
.513 .438 .709 r
.55079 .74412 m .54993 .7456 L .54966 .74294 L F
.67 .586 .753 r
.58431 .72232 m .58798 .72149 L .58407 .72051 L F
.574 .424 .64 r
.41147 .74808 m .41381 .7503 L .41331 .74763 L F
.41147 .74808 m .41173 .75078 L .41381 .7503 L F
0 0 0 r
.57359 .6699 m .57091 .67165 L .57286 .67063 L F
.316 0 .117 r
.57286 .67063 m .57569 .66914 L .57359 .6699 L F
.656 .513 .677 r
.30114 .69935 m .30403 .70166 L .30309 .69877 L F
.30114 .69935 m .30165 .70213 L .30403 .70166 L F
.625 .547 .746 r
.70538 .72614 m .7061 .72954 L .70839 .72884 L F
.571 .007 0 r
.52199 .74773 m .51834 .74525 L .52188 .74567 L F
.44 .277 .564 r
.52382 .74272 m .52397 .7451 L .52188 .74567 L F
.453 .301 .584 r
.52397 .7451 m .52199 .74773 L .52188 .74567 L F
.524 .358 .599 r
.38251 .69386 m .3846 .6934 L .38451 .69094 L F
.475 .233 .467 r
.38251 .69386 m .38414 .69543 L .3846 .6934 L F
.38251 .69386 m .38213 .69594 L .38414 .69543 L F
.841 .803 .815 r
.72682 .7226 m .72464 .7257 L .72399 .72358 L F
.72682 .7226 m .72399 .72358 L .72407 .72348 L F
.72682 .7226 m .72397 .72351 L .72633 .72309 L F
.187 .304 .752 r
.72682 .7226 m .72871 .72266 L .72642 .72053 L F
.111 0 0 r
.72871 .72266 m .72633 .72309 L .72682 .7226 L F
.552 .348 .558 r
.72871 .72266 m .72633 .72309 L .72641 .72086 L F
.72658 .72067 m .72641 .72086 L .72642 .72053 L F
.72871 .72266 m .72641 .72086 L .72658 .72067 L F
.841 .803 .815 r
.72407 .72348 m .72399 .72358 L .72397 .72351 L F
.51 .5 .781 r
.40747 .65732 m .40657 .66075 L .4054 .65725 L F
.40747 .65732 m .40852 .66057 L .40657 .66075 L F
.507 .797 .998 r
.73654 .63362 m .73846 .63311 L .73591 .63249 L F
.501 .095 .202 r
.45523 .73073 m .45745 .73076 L .45555 .7297 L F
.36 .148 .451 r
.6139 .7149 m .61181 .71799 L .61243 .71594 L F
.476 .066 .182 r
.48852 .78053 m .49085 .78034 L .49193 .77861 L F
.63 .232 .27 r
.49085 .78034 m .4944 .78022 L .49193 .77861 L F
.104 0 .004 r
.46606 .74951 m .4668 .74999 L .46812 .74856 L F
.46606 .74951 m .46543 .75062 L .4668 .74999 L F
.199 .106 .518 r
.60784 .70133 m .60872 .69813 L .60826 .6992 L F
.377 .433 .793 r
.58286 .73181 m .58383 .73372 L .58199 .73474 L F
.404 .498 .841 r
.58383 .73372 m .58316 .73545 L .58199 .73474 L F
.394 0 0 r
.58796 .76205 m .58908 .76328 L .58689 .76392 L F
.58796 .76205 m .59021 .762 L .58908 .76328 L F
.792 .564 .592 r
.57125 .68559 m .5715 .68806 L .56793 .68753 L F
.599 .429 .623 r
.57353 .68281 m .57125 .68559 L .57008 .68247 L F
.57353 .68281 m .57405 .68582 L .57125 .68559 L F
.599 .422 .614 r
.57125 .68559 m .5715 .68806 L .57405 .68582 L F
.57125 .68559 m .5715 .68806 L .57405 .68582 L F
0 0 0 r
.36014 .64899 m .3623 .64852 L .36394 .64803 L F
.198 0 0 r
.36394 .64803 m .36566 .64819 L .36634 .64772 L F
.36394 .64803 m .3623 .64852 L .36566 .64819 L F
.008 .319 .807 r
.31508 .73597 m .31501 .73476 L .31323 .73398 L F
.31508 .73597 m .31656 .73675 L .31501 .73476 L F
.299 .098 .431 r
.29843 .63859 m .29884 .63641 L .30039 .63569 L F
.405 .738 .992 r
.3915 .65232 m .39061 .65332 L .38934 .65217 L F
.3915 .65232 m .39284 .65328 L .39061 .65332 L F
.617 .358 .503 r
.59781 .66371 m .59997 .66573 L .59778 .66544 L F
.615 .358 .506 r
.59905 .66371 m .59997 .66573 L .59781 .66371 L F
.509 .296 .525 r
.3128 .6746 m .31486 .6742 L .31515 .67197 L F
.489 .278 .52 r
.31515 .67197 m .31684 .67377 L .31698 .6714 L F
.31515 .67197 m .31486 .6742 L .31684 .67377 L F
.435 .284 .577 r
.60967 .72348 m .611 .72558 L .60847 .72662 L F
.449 .316 .607 r
.60847 .72662 m .61015 .72888 L .60863 .72896 L F
.60847 .72662 m .611 .72558 L .61015 .72888 L F
.3 .057 .368 r
.31917 .66866 m .31756 .66939 L .31698 .6714 L F
.807 .61 .636 r
.52947 .73415 m .53345 .73481 L .53289 .73118 L F
.44 .489 .813 r
.53289 .73118 m .5349 .73142 L .53374 .7283 L F
.717 .694 .827 r
.52736 .74823 m .5286 .75095 L .52493 .75069 L F
.74 .584 .68 r
.5286 .75095 m .52642 .75381 L .52493 .75069 L F
.747 .594 .685 r
.5286 .75095 m .52917 .75403 L .52642 .75381 L F
.621 .605 .812 r
.52975 .74719 m .5286 .75095 L .52736 .74823 L F
.52975 .74719 m .53091 .75051 L .5286 .75095 L F
.558 .466 .706 r
.53092 .75356 m .5286 .75095 L .53091 .75051 L F
.53092 .75356 m .52917 .75403 L .5286 .75095 L F
.252 .27 .686 r
.57733 .71999 m .57585 .72171 L .57535 .71781 L F
.125 .319 .787 r
.57785 .72193 m .57585 .72171 L .57733 .71999 L F
.57785 .72193 m .5782 .72365 L .57585 .72171 L F
.301 0 0 r
.5782 .72365 m .58133 .7248 L .57995 .72469 L F
.478 .336 .609 r
.3128 .6746 m .31479 .67657 L .31486 .6742 L F
.3128 .6746 m .31294 .67707 L .31479 .67657 L F
.707 .647 .788 r
.72792 .59582 m .72908 .59935 L .73119 .59802 L F
.58 .012 0 r
.72829 .59962 m .73064 .60025 L .72908 .59935 L F
.34 .435 .813 r
.6108 .74019 m .61348 .74189 L .61168 .74279 L F
.053 0 .35 r
.61348 .74189 m .61159 .74478 L .61168 .74279 L F
.631 .101 0 r
.42623 .78909 m .4247 .78922 L .42265 .7886 L F
.483 .828 .998 r
.4268 .78812 m .42623 .78909 L .42802 .78874 L F
.598 .941 .937 r
.4268 .78812 m .4247 .78922 L .42623 .78909 L F
.328 .188 .534 r
.61219 .72037 m .61217 .72268 L .60967 .72348 L F
.444 .288 .573 r
.61284 .72494 m .60967 .72348 L .61217 .72268 L F
.61284 .72494 m .611 .72558 L .60967 .72348 L F
.398 .527 .871 r
.56117 .71521 m .561 .71258 L .55943 .71213 L F
.56117 .71521 m .56262 .71506 L .561 .71258 L F
.403 .086 .31 r
.42046 .67232 m .41984 .67399 L .41778 .67448 L F
.531 .398 .645 r
.42223 .66893 m .42251 .6717 L .42046 .67232 L F
.514 .24 .437 r
.42251 .6717 m .41984 .67399 L .42046 .67232 L F
.277 0 .198 r
.28631 .65191 m .28717 .64972 L .28886 .64975 L F
.574 .681 .913 r
.6985 .60464 m .70008 .60266 L .69772 .60315 L F
.6985 .60464 m .70244 .60531 L .70008 .60266 L F
.133 .264 .734 r
.58146 .72826 m .58286 .73181 L .58042 .72955 L F
.682 .615 .774 r
.40729 .78306 m .40816 .78642 L .41086 .78609 L F
.682 .63 .791 r
.40816 .78642 m .41128 .78696 L .41086 .78609 L F
.4 .121 .371 r
.3819 .70943 m .38015 .70992 L .38273 .70757 L F
.338 .08 .367 r
.38431 .70678 m .3819 .70943 L .38273 .70757 L F
.591 .62 .849 r
.32123 .73077 m .31834 .72831 L .31992 .72839 L F
.32158 .73142 m .3212 .73112 L .32123 .73077 L F
.786 .346 0 r
.31969 .7293 m .32158 .73142 L .32006 .72866 L F
.31969 .7293 m .32006 .72866 L .31943 .7275 L F
.591 .62 .849 r
.32123 .73077 m .31791 .72863 L .31834 .72831 L F
.3212 .73112 m .31791 .72863 L .32123 .73077 L F
0 0 0 r
.31798 .7303 m .31944 .72971 L .31969 .7293 L F
.31944 .72971 m .32005 .72946 L .31969 .7293 L F
.611 .448 .637 r
.32344 .73156 m .32204 .73406 L .32158 .73142 L F
0 0 .136 r
.32158 .73142 m .32166 .7317 L .32334 .72807 L F
.42 .769 .996 r
.32334 .72807 m .32527 .72839 L .32551 .72776 L F
.32527 .72839 m .32677 .72863 L .32551 .72776 L F
.473 .301 .567 r
.32334 .72807 m .32551 .72776 L .32677 .72863 L F
.32334 .72807 m .32166 .7317 L .32551 .72776 L F
.617 .492 .688 r
.32158 .73142 m .32204 .73406 L .31993 .73409 L F
.786 .346 0 r
.31969 .7293 m .32166 .7317 L .32158 .73142 L F
.786 .811 .873 r
.32551 .72776 m .32166 .7317 L .31969 .7293 L F
.32484 .72866 m .31969 .7293 L .324 .72969 L F
.942 .583 .292 r
.3257 .73465 m .32432 .73392 L .32344 .73156 L F
.611 .448 .637 r
.32344 .73156 m .32432 .73392 L .32204 .73406 L F
.749 .584 .671 r
.32241 .73005 m .32357 .73229 L .32534 .72938 L F
.786 .811 .873 r
.32409 .72967 m .324 .72969 L .32407 .72969 L F
.32484 .72866 m .324 .72969 L .32409 .72967 L F
.749 .584 .671 r
.32534 .72938 m .32357 .73229 L .3262 .72944 L F
.786 .811 .873 r
.32551 .72776 m .32257 .72854 L .32484 .72866 L F
.32257 .72854 m .31969 .7293 L .32484 .72866 L F
.883 .909 .841 r
.32386 .72496 m .32334 .72807 L .32551 .72776 L F
0 .258 .764 r
.32551 .72776 m .32588 .7268 L .32386 .72496 L F
.748 .555 .635 r
.32409 .72967 m .32586 .72683 L .32551 .72776 L F
.749 .584 .671 r
.32192 .7291 m .32409 .72967 L .32432 .72929 L F
.748 .555 .635 r
.32407 .72969 m .32428 .72935 L .32409 .72967 L F
.32428 .72935 m .32586 .72683 L .32409 .72967 L F
.749 .584 .671 r
.32192 .7291 m .324 .72969 L .32409 .72967 L F
.288 .685 .973 r
.32192 .7291 m .32407 .72969 L .324 .72969 L F
.32192 .7291 m .324 .72969 L .31969 .7293 L F
.749 .584 .671 r
.32192 .7291 m .32241 .73005 L .324 .72969 L F
.748 .555 .635 r
.32586 .72683 m .32588 .7268 L .32551 .72776 L F
.32428 .72935 m .3262 .72944 L .32588 .7268 L F
.749 .584 .671 r
.32428 .72935 m .32409 .72967 L .32525 .7294 L F
.748 .555 .635 r
.32407 .72969 m .3262 .72944 L .32428 .72935 L F
.749 .584 .671 r
.32432 .72929 m .32428 .72935 L .32534 .72938 L F
.32428 .72935 m .32525 .7294 L .32534 .72938 L F
.591 .62 .849 r
.31992 .72839 m .31834 .72831 L .31943 .7275 L F
.796 .471 .44 r
.32334 .72807 m .31943 .7275 L .32137 .72642 L F
.883 .909 .841 r
.32386 .72496 m .32156 .72735 L .32334 .72807 L F
.796 .471 .44 r
.32334 .72807 m .31969 .7293 L .31943 .7275 L F
.883 .909 .841 r
.32156 .72735 m .31969 .7293 L .32143 .72871 L F
.32156 .72735 m .32143 .72871 L .32334 .72807 L F
0 0 .406 r
.31943 .7275 m .31969 .7293 L .32005 .72777 L F
.31943 .7275 m .32005 .72777 L .32036 .72645 L F
.271 .132 .501 r
.31943 .7275 m .31783 .72732 L .31857 .72713 L F
.31943 .7275 m .31857 .72713 L .32137 .72642 L F
.861 .841 .375 r
.31064 .7241 m .30984 .72797 L .31239 .72631 L F
.739 .85 .411 r
.30935 .72862 m .30833 .73062 L .30984 .72797 L F
.591 .914 .976 r
.67739 .59578 m .67966 .59527 L .67807 .59525 L F
.815 .424 .313 r
.67807 .59525 m .67966 .59527 L .6789 .59706 L F
.756 .353 .287 r
.67966 .59527 m .6814 .59639 L .6789 .59706 L F
.861 .674 .647 r
.68168 .59516 m .6814 .59639 L .67966 .59527 L F
.738 .669 .117 r
.43635 .76281 m .43425 .76265 L .43631 .76146 L F
.299 0 .043 r
.71907 .73398 m .72035 .73384 L .72029 .73371 L F
0 .224 .746 r
.54349 .702 m .54365 .70113 L .54171 .69927 L F
.914 .559 .35 r
.54585 .70366 m .54365 .70113 L .54349 .702 L F
.917 .731 .636 r
.51327 .74309 m .51284 .7454 L .51149 .74243 L F
.436 .162 .399 r
.51284 .7454 m .51506 .74315 L .51498 .74494 L F
.634 .322 .425 r
.51327 .74309 m .51506 .74315 L .51498 .74494 L F
0 .126 .676 r
.51327 .74309 m .51498 .74494 L .51383 .74279 L F
.55 .396 .625 r
.57353 .68281 m .5755 .6854 L .57405 .68582 L F
.57353 .68281 m .5755 .6854 L .57405 .68582 L F
.434 .752 .994 r
.27604 .60617 m .27535 .60467 L .27358 .60462 L F
.27604 .60617 m .27677 .60566 L .27535 .60467 L F
.613 .771 .956 r
.70839 .72884 m .71167 .72944 L .71076 .72821 L F
.475 .701 .968 r
.71076 .72821 m .71167 .72944 L .713 .72813 L F
.529 .794 .994 r
.71167 .72944 m .71401 .72906 L .713 .72813 L F
.676 .214 .149 r
.42959 .7361 m .43114 .73694 L .43087 .73686 L F
.415 0 0 r
.43087 .73686 m .43292 .73791 L .43437 .73742 L F
.676 .214 .149 r
.43114 .73694 m .43292 .73791 L .43087 .73686 L F
.097 0 0 r
.43076 .73682 m .43087 .73686 L .43193 .7369 L F
.42839 .73666 m .43087 .73686 L .43076 .73682 L F
.337 0 0 r
.43087 .73686 m .43437 .73742 L .43193 .7369 L F
.596 .569 .794 r
.41128 .78696 m .41244 .78345 L .41086 .78609 L F
.41128 .78696 m .41353 .78677 L .41244 .78345 L F
.471 .209 .435 r
.38939 .70221 m .38934 .70452 L .38718 .70498 L F
.439 .184 .43 r
.39138 .70385 m .38939 .70221 L .39192 .70235 L F
.39138 .70385 m .38934 .70452 L .38939 .70221 L F
0 0 0 r
.49249 .7287 m .49142 .73113 L .49122 .73129 L F
.406 .049 .242 r
.49469 .72841 m .49142 .73113 L .49249 .7287 L F
.549 .499 .752 r
.30165 .70213 m .3023 .70478 L .30428 .70434 L F
.564 .377 .587 r
.3023 .70478 m .30446 .70687 L .30428 .70434 L F
.3023 .70478 m .3023 .70729 L .30446 .70687 L F
.462 .705 .973 r
.26766 .59319 m .26683 .59459 L .26537 .59296 L F
.26766 .59319 m .26891 .59448 L .26683 .59459 L F
.324 .015 .278 r
.40356 .77832 m .40499 .77862 L .40624 .77589 L F
.055 0 .128 r
.40624 .77589 m .40499 .77862 L .40757 .77511 L F
.295 0 .215 r
.5907 .65787 m .59207 .65923 L .59289 .6571 L F
.5907 .65787 m .59 .66001 L .59207 .65923 L F
.624 .718 .914 r
.50889 .79186 m .51109 .79234 L .51158 .79119 L F
.212 .255 .69 r
.58189 .72263 m .58218 .72529 L .58084 .72472 L F
.58218 .72529 m .5822 .72543 L .58084 .72472 L F
.301 0 0 r
.57915 .724 m .58084 .72472 L .58133 .7248 L F
.5782 .72365 m .58084 .72472 L .57915 .724 L F
.547 0 0 r
.58084 .72472 m .58228 .7257 L .58133 .7248 L F
.847 .881 .864 r
.57283 .70479 m .57009 .70639 L .57156 .70411 L F
.34 0 .178 r
.36769 .70446 m .36855 .70601 L .36988 .70427 L F
.36769 .70446 m .36652 .70655 L .36855 .70601 L F
.093 0 .048 r
.58658 .67248 m .58523 .67185 L .58766 .67143 L F
.58658 .67248 m .58442 .67358 L .58523 .67185 L F
.785 .81 .873 r
.67766 .61617 m .68136 .61487 L .67996 .61381 L F
.805 .779 .274 r
.32366 .73759 m .32432 .73392 L .3257 .73465 L F
.32366 .73759 m .32368 .7365 L .32432 .73392 L F
.547 .368 .59 r
.3257 .73465 m .3258 .73731 L .32366 .73759 L F
.918 .621 .467 r
.3258 .73731 m .32368 .7365 L .32366 .73759 L F
.887 .671 .604 r
.5862 .74144 m .58847 .74012 L .58695 .7395 L F
.5862 .74144 m .58781 .74278 L .58847 .74012 L F
.598 .608 .832 r
.33727 .70171 m .33653 .70522 L .33503 .70198 L F
.33727 .70171 m .33876 .70478 L .33653 .70522 L F
.493 .327 .584 r
.32775 .73669 m .3258 .73731 L .3257 .73465 L F
.684 .167 0 r
.55958 .74093 m .55915 .74155 L .55749 .74006 L F
.507 .144 .285 r
.3819 .70943 m .3788 .71172 L .38015 .70992 L F
0 0 0 r
.51024 .70574 m .51092 .70591 L .51192 .70587 L F
.51024 .70574 m .50876 .70642 L .51092 .70591 L F
.011 0 0 r
.57091 .67165 m .57163 .67229 L .57286 .67063 L F
.57091 .67165 m .56971 .67314 L .57163 .67229 L F
.628 .487 .67 r
.33636 .69338 m .33466 .69268 L .3365 .69155 L F
.33636 .69338 m .33424 .69413 L .33466 .69268 L F
.827 .664 .68 r
.53092 .7621 m .52781 .76176 L .52948 .75799 L F
.615 .305 .422 r
.53092 .7621 m .52758 .7642 L .52781 .76176 L F
.53092 .7621 m .53074 .76411 L .52758 .7642 L F
.58 .275 .416 r
.53092 .7621 m .53317 .76391 L .53074 .76411 L F
.638 .527 .711 r
.53299 .75947 m .53362 .76233 L .53092 .7621 L F
.609 .26 .353 r
.53362 .76233 m .53317 .76391 L .53092 .7621 L F
.408 0 0 r
.46185 .78365 m .46283 .78469 L .4603 .78478 L F
.46185 .78365 m .46401 .78404 L .46283 .78469 L F
.643 .961 .791 r
.38037 .66724 m .37935 .66848 L .38247 .66874 L F
.714 .841 .943 r
.38037 .66724 m .38247 .66874 L .38331 .66673 L F
.478 .587 .884 r
.67059 .59751 m .67224 .60024 L .67419 .60003 L F
.435 0 .015 r
.5926 .76285 m .59021 .762 L .59279 .76138 L F
.197 0 .048 r
.59588 .75937 m .59507 .76113 L .59279 .76138 L F
.206 0 .078 r
.59279 .76138 m .59356 .76289 L .5926 .76285 L F
.59279 .76138 m .59507 .76113 L .59356 .76289 L F
.643 .961 .791 r
.38037 .66724 m .37862 .6686 L .37935 .66848 L F
0 0 0 r
.32551 .66262 m .32789 .66027 L .32665 .66071 L F
.378 0 0 r
.45924 .77588 m .46133 .77638 L .46282 .77544 L F
0 0 0 r
.46282 .77544 m .4642 .77507 L .46513 .77551 L F
.46282 .77544 m .46133 .77638 L .4642 .77507 L F
.487 .216 .429 r
.34469 .68415 m .34293 .68274 L .34498 .68223 L F
.34469 .68415 m .34275 .68505 L .34293 .68274 L F
.531 .798 .995 r
.71642 .58275 m .71316 .58189 L .71536 .58096 L F
.535 .759 .979 r
.71748 .58089 m .71642 .58275 L .71536 .58096 L F
.71748 .58089 m .71888 .58236 L .71642 .58275 L F
.998 .793 .447 r
.7186 .57898 m .71748 .58089 L .71797 .57769 L F
.417 .637 .946 r
.71814 .57754 m .7186 .57898 L .71797 .57769 L F
.986 .838 .456 r
.71814 .57754 m .71748 .58089 L .7186 .57898 L F
.67 .484 .625 r
.52917 .75403 m .52634 .75683 L .52642 .75381 L F
.52917 .75403 m .52915 .7568 L .52634 .75683 L F
.543 .387 .62 r
.53092 .75356 m .52915 .7568 L .52917 .75403 L F
.52 .38 .631 r
.3069 .68617 m .30867 .68778 L .30878 .68547 L F
.3069 .68617 m .30684 .68826 L .30867 .68778 L F
.942 .685 .519 r
.53873 .74575 m .5383 .7478 L .53688 .74458 L F
.658 .575 .75 r
.53977 .74476 m .5383 .7478 L .53873 .74575 L F
.757 .747 .843 r
.71485 .61456 m .71795 .61478 L .71692 .61311 L F
.66 .717 .89 r
.71795 .61478 m .71928 .61184 L .71692 .61311 L F
.71795 .61478 m .72042 .61402 L .71928 .61184 L F
0 0 0 r
.48757 .7206 m .48895 .72015 L .49037 .71882 L F
.299 0 .041 r
.48895 .72015 m .49228 .71806 L .49037 .71882 L F
.558 .22 .351 r
.67059 .59751 m .67348 .59891 L .67393 .59525 L F
.65 .659 .845 r
.67393 .59525 m .67501 .59211 L .67304 .59245 L F
.67393 .59525 m .67739 .59578 L .67501 .59211 L F
.693 .396 .467 r
.67642 .59742 m .67739 .59578 L .67393 .59525 L F
0 0 .026 r
.67393 .59525 m .67436 .59524 L .67642 .59742 L F
.67393 .59525 m .67348 .59891 L .67436 .59524 L F
.89 .756 .707 r
.67419 .60003 m .67543 .60314 L .67371 .60193 L F
.929 .849 .743 r
.67312 .60613 m .67371 .60193 L .67543 .60314 L F
.591 .615 .844 r
.67701 .60237 m .67543 .60314 L .67419 .60003 L F
.329 0 .16 r
.37702 .69881 m .37898 .69834 L .38006 .69641 L F
.347 0 .163 r
.37898 .69834 m .38213 .69594 L .38006 .69641 L F
.386 .65 .962 r
.55381 .70983 m .55494 .7087 L .55281 .70858 L F
.35 .592 .936 r
.55381 .70983 m .5554 .70997 L .55494 .7087 L F
.829 .797 .821 r
.40526 .65547 m .40206 .65661 L .40398 .6562 L F
0 .159 .663 r
.40608 .65578 m .40747 .65732 L .40633 .65637 L F
.40608 .65578 m .40633 .65637 L .40526 .65547 L F
.522 .385 .635 r
.40526 .65547 m .40747 .65732 L .4054 .65725 L F
0 .159 .663 r
.40608 .65578 m .40526 .65547 L .40398 .6562 L F
0 0 0 r
.40458 .65574 m .40594 .65546 L .40608 .65578 L F
.40594 .65546 m .40812 .65502 L .40608 .65578 L F
.415 .468 .807 r
.55749 .74006 m .55886 .73738 L .55601 .73734 L F
.55749 .74006 m .55841 .74023 L .55886 .73738 L F
.814 .341 0 r
.55915 .74155 m .55841 .74023 L .55749 .74006 L F
.237 0 .096 r
.33432 .65555 m .33511 .65653 L .33613 .65511 L F
.33432 .65555 m .33323 .65719 L .33511 .65653 L F
.447 .046 .186 r
.3607 .6738 m .35761 .67489 L .35848 .67411 L F
.27 .544 .923 r
.27777 .60715 m .27851 .60615 L .27677 .60566 L F
.27777 .60715 m .28043 .60821 L .27851 .60615 L F
.036 0 0 r
.59588 .75937 m .59594 .7604 L .59507 .76113 L F
.59588 .75937 m .59771 .75861 L .59594 .7604 L F
.539 .619 .881 r
.71749 .73131 m .7163 .72848 L .71401 .72906 L F
.71749 .73131 m .71813 .73125 L .7163 .72848 L F
.3 .093 .423 r
.38689 .6883 m .38651 .69048 L .38849 .68757 L F
.509 .633 .908 r
.28143 .61041 m .28203 .60809 L .28043 .60821 L F
.28143 .61041 m .28377 .61043 L .28203 .60809 L F
.705 .631 .771 r
.58547 .71442 m .58642 .71748 L .58848 .71484 L F
0 0 .208 r
.62404 .69364 m .62343 .69587 L .62253 .69643 L F
.094 .014 .465 r
.62343 .69587 m .6234 .69779 L .62253 .69643 L F
.148 .029 .449 r
.6234 .69779 m .62237 .69906 L .62253 .69643 L F
.294 0 0 r
.46401 .78404 m .46742 .78375 L .46619 .78416 L F
.272 0 0 r
.46742 .78375 m .46815 .7846 L .46619 .78416 L F
.46742 .78375 m .46959 .78374 L .46815 .7846 L F
.553 .424 .659 r
.4073 .75675 m .40945 .75643 L .40912 .75345 L F
.588 .464 .679 r
.4073 .75675 m .40999 .75874 L .40945 .75643 L F
.4073 .75675 m .40774 .75912 L .40999 .75874 L F
.475 .238 .475 r
.37457 .70152 m .37702 .69881 L .37504 .69943 L F
.575 .401 .608 r
.42368 .73386 m .42411 .73616 L .42538 .73463 L F
.531 .545 .815 r
.42839 .73666 m .42538 .73463 L .42747 .73425 L F
.608 .274 .379 r
.42411 .73616 m .42747 .73425 L .42538 .73463 L F
.607 .818 .981 r
.3423 .70509 m .33876 .70478 L .34075 .70384 L F
.745 .785 .885 r
.34437 .70387 m .3423 .70509 L .34075 .70384 L F
.742 .459 .5 r
.62333 .65705 m .62464 .6556 L .62121 .65523 L F
.78 .514 .533 r
.62333 .65705 m .62486 .65795 L .62464 .6556 L F
.357 .163 .474 r
.28441 .62502 m .28634 .62483 L .28669 .62229 L F
.245 .021 .363 r
.28441 .62502 m .28565 .62664 L .28634 .62483 L F
.28441 .62502 m .28421 .62737 L .28565 .62664 L F
.62 .797 .967 r
.69215 .60302 m .69547 .60349 L .69446 .60235 L F
.522 .752 .98 r
.69446 .60235 m .69547 .60349 L .69772 .60315 L F
.608 .491 .694 r
.30308 .69639 m .30533 .69609 L .305 .69342 L F
.592 .428 .628 r
.30309 .69877 m .30533 .69609 L .30308 .69639 L F
.301 0 .138 r
.33613 .65511 m .33799 .65463 L .33918 .65266 L F
.37 0 .121 r
.33799 .65463 m .34134 .65251 L .33918 .65266 L F
.427 .014 .152 r
.45705 .74804 m .45553 .75002 L .45339 .75021 L F
.743 .381 .368 r
.45705 .74804 m .45917 .7504 L .45553 .75002 L F
0 .094 .628 r
.49142 .73113 m .49265 .73272 L .49122 .73129 L F
.826 .632 .639 r
.6275 .66334 m .62946 .66371 L .6277 .6607 L F
.877 .68 .632 r
.62746 .66539 m .62946 .66371 L .6275 .66334 L F
.62746 .66539 m .62918 .66611 L .62946 .66371 L F
.812 .569 .572 r
.61137 .67456 m .6081 .67418 L .60807 .67167 L F
.821 .625 .638 r
.61137 .67456 m .60808 .67652 L .6081 .67418 L F
.61137 .67456 m .6112 .677 L .60808 .67652 L F
0 .06 .566 r
.58175 .70969 m .58396 .71176 L .58425 .71219 L F
0 0 0 r
.58396 .71176 m .5823 .71372 L .58425 .71219 L F
.724 .535 .635 r
.58547 .71442 m .5884 .71277 L .58425 .71219 L F
.203 0 0 r
.53566 .73712 m .5354 .73723 L .533 .73721 L F
.565 .32 .503 r
.53315 .73772 m .52849 .74223 L .52845 .74001 L F
.53315 .73772 m .5308 .74202 L .52849 .74223 L F
.97 .926 .614 r
.533 .73721 m .53165 .73876 L .53315 .73772 L F
.317 .053 .345 r
.53275 .74133 m .5308 .74202 L .53315 .73772 L F
.53275 .74133 m .53315 .73772 L .53165 .73876 L F
.203 0 0 r
.5354 .73723 m .53165 .73876 L .533 .73721 L F
.97 .926 .614 r
.533 .73721 m .53315 .73772 L .53207 .7372 L F
.533 .73721 m .53207 .7372 L .53113 .73675 L F
.783 .578 .623 r
.49689 .72702 m .49806 .72918 L .49469 .72841 L F
.686 .545 .689 r
.50005 .72641 m .49806 .72918 L .49689 .72702 L F
.783 .578 .623 r
.49689 .72702 m .49806 .72918 L .49469 .72841 L F
.367 .238 .57 r
.38451 .69094 m .38614 .69266 L .38651 .69048 L F
.38451 .69094 m .3846 .6934 L .38614 .69266 L F
.607 .229 .3 r
.52305 .73901 m .52497 .73709 L .52295 .73652 L F
.482 0 0 r
.5933 .74412 m .59236 .74262 L .59122 .7445 L F
.016 .59 .725 r
.54234 .74275 m .54262 .74273 L .54164 .74275 L F
.708 .388 .432 r
.54454 .74466 m .54164 .74275 L .54262 .74273 L F
.54454 .74466 m .53977 .74476 L .54164 .74275 L F
.54454 .74466 m .53977 .74476 L .54164 .74275 L F
.016 .59 .725 r
.54438 .74275 m .54262 .74273 L .54234 .74275 L F
.761 .621 .705 r
.54645 .74273 m .54454 .74466 L .54262 .74273 L F
0 0 0 r
.54262 .74273 m .54209 .74435 L .54309 .74271 L F
.889 .813 .766 r
.54508 .7396 m .54262 .74273 L .54438 .74275 L F
.54508 .7396 m .54438 .74275 L .54645 .74273 L F
.761 .621 .705 r
.54645 .74273 m .54416 .74273 L .54534 .74293 L F
.54416 .74273 m .54262 .74273 L .54534 .74293 L F
.856 .697 .684 r
.54771 .74298 m .54651 .74562 L .54645 .74273 L F
.761 .621 .705 r
.54645 .74273 m .54651 .74562 L .54454 .74466 L F
.513 .197 .368 r
.54534 .74293 m .54777 .74213 L .54645 .74273 L F
.54534 .74293 m .54727 .74373 L .54777 .74213 L F
.325 .392 .777 r
.5463 .74093 m .54709 .74323 L .54534 .74293 L F
.54709 .74323 m .54727 .74373 L .54534 .74293 L F
0 0 0 r
.54262 .74273 m .54401 .7412 L .54534 .74293 L F
.54262 .74273 m .54309 .74271 L .54401 .7412 L F
.691 .361 .412 r
.53132 .78909 m .53009 .79165 L .52836 .79083 L F
.669 .336 .401 r
.53341 .79123 m .53132 .78909 L .53366 .78958 L F
.53341 .79123 m .53009 .79165 L .53132 .78909 L F
.088 0 0 r
.35515 .72407 m .35455 .72347 L .35633 .72284 L F
.35515 .72407 m .35303 .72481 L .35455 .72347 L F
.586 .946 .851 r
.72519 .7131 m .72175 .71501 L .72168 .71467 L F
.522 .907 .941 r
.37023 .67051 m .37413 .6698 L .37273 .66999 L F
.17 0 0 r
.37413 .6698 m .37472 .67028 L .37273 .66999 L F
.601 .451 .65 r
.33844 .6908 m .33638 .68976 L .33863 .68967 L F
.33844 .6908 m .3365 .69155 L .33638 .68976 L F
.454 .354 .652 r
.42215 .6667 m .41976 .66507 L .4207 .66547 L F
.579 .63 .866 r
.42346 .66624 m .42215 .6667 L .4207 .66547 L F
.42346 .66624 m .42223 .66893 L .42215 .6667 L F
.476 .262 .509 r
.32114 .66817 m .31955 .6664 L .31917 .66866 L F
.352 .245 .591 r
.32106 .66554 m .31955 .6664 L .32114 .66817 L F
.381 0 0 r
.50044 .78437 m .50074 .78436 L .4993 .78362 L F
.443 .627 .932 r
.56771 .70383 m .57009 .70639 L .56659 .70516 L F
.207 0 .297 r
.3891 .68556 m .38849 .68757 L .3906 .68476 L F
.059 .573 .878 r
.50583 .79088 m .50889 .79186 L .50759 .79166 L F
.62 .745 .936 r
.50889 .79186 m .51014 .78935 L .50759 .79166 L F
.50889 .79186 m .51158 .79119 L .51014 .78935 L F
.514 0 0 r
.41769 .66503 m .4207 .66547 L .41976 .66507 L F
.41769 .66503 m .4207 .66547 L .41976 .66507 L F
.618 .546 .751 r
.33603 .82492 m .33703 .82732 L .3346 .82708 L F
.33603 .82492 m .33703 .82732 L .3346 .82708 L F
.689 .854 .961 r
.35619 .70872 m .35445 .70993 L .35311 .70906 L F
.591 .257 .371 r
.52834 .72763 m .52514 .72856 L .52618 .72627 L F
.744 .235 .004 r
.5823 .71372 m .58188 .71459 L .57944 .71227 L F
0 0 0 r
.58396 .71176 m .58188 .71459 L .5823 .71372 L F
.404 .139 .395 r
.39122 .68277 m .39317 .68223 L .39386 .68026 L F
.395 .121 .375 r
.39122 .68277 m .3906 .68476 L .39317 .68223 L F
.67 .586 .753 r
.58431 .72232 m .58695 .72254 L .58798 .72149 L F
.744 .509 .575 r
.61429 .65493 m .61773 .6527 L .61452 .65289 L F
.61429 .65493 m .61779 .655 L .61773 .6527 L F
.579 .2 .289 r
.4742 .72791 m .47647 .72812 L .47757 .72609 L F
.432 .044 .201 r
.47647 .72812 m .47974 .72588 L .47757 .72609 L F
.881 .67 .613 r
.61271 .67994 m .61093 .67979 L .6112 .677 L F
.838 .48 .377 r
.61271 .67994 m .61145 .68163 L .61093 .67979 L F
.898 .573 .425 r
.61326 .68209 m .61145 .68163 L .61271 .67994 L F
.117 .441 .878 r
.40483 .77796 m .40356 .77832 L .40227 .77758 L F
.40483 .77796 m .40499 .77862 L .40356 .77832 L F
.40483 .77796 m .40356 .77832 L .40227 .77758 L F
.40483 .77796 m .40499 .77862 L .40356 .77832 L F
.699 .712 .858 r
.40352 .78065 m .40499 .77862 L .40356 .77832 L F
.605 .451 .646 r
.41331 .74763 m .41557 .74497 L .41342 .74547 L F
.557 .867 .57 r
.55523 .73623 m .55388 .73769 L .55601 .73734 L F
.365 .046 .284 r
.32371 .66325 m .3217 .66393 L .32106 .66554 L F
.833 .446 .317 r
.60172 .66586 m .59997 .66573 L .59905 .66371 L F
.604 .495 .703 r
.68612 .58758 m .68845 .58454 L .6864 .58542 L F
.68612 .58758 m .68853 .58703 L .68845 .58454 L F
.594 .813 .984 r
.68751 .58595 m .68612 .58758 L .68524 .58633 L F
.68751 .58595 m .68853 .58703 L .68612 .58758 L F
0 0 .316 r
.55145 .74156 m .55067 .74025 L .55231 .73907 L F
.55145 .74156 m .55079 .74412 L .55067 .74025 L F
0 .236 .71 r
.55083 .70721 m .55281 .70858 L .55081 .70682 L F
.5 .04 .092 r
.43947 .78657 m .43497 .78909 L .43588 .78778 L F
0 0 0 r
.44043 .78636 m .43947 .78657 L .44166 .78631 L F
.44043 .78636 m .43497 .78909 L .43947 .78657 L F
.576 .841 .995 r
.29548 .72303 m .29733 .72369 L .29814 .72352 L F
.783 .592 .641 r
.29441 .7259 m .29733 .72369 L .29548 .72303 L F
.29441 .7259 m .29671 .72615 L .29733 .72369 L F
.801 .659 .706 r
.29671 .72615 m .29814 .72352 L .29733 .72369 L F
.264 .039 .373 r
.54771 .74298 m .54631 .74756 L .54651 .74562 L F
.701 .462 .559 r
.55014 .74739 m .54771 .74298 L .54993 .7456 L F
.55014 .74739 m .54631 .74756 L .54771 .74298 L F
0 .473 .817 r
.55768 .69817 m .55912 .6989 L .55697 .69824 L F
.513 .64 .911 r
.34863 .70334 m .34753 .70516 L .34656 .70346 L F
.447 .553 .87 r
.34863 .70334 m .35023 .70614 L .34753 .70516 L F
.724 .535 .635 r
.58547 .71442 m .58848 .71484 L .5884 .71277 L F
.682 .615 .774 r
.40729 .78306 m .41086 .78609 L .40898 .78306 L F
.715 .719 .853 r
.40898 .78306 m .41086 .78609 L .41244 .78345 L F
.4 .136 .393 r
.39386 .68026 m .39508 .68171 L .39492 .67926 L F
.39386 .68026 m .39317 .68223 L .39508 .68171 L F
.625 .547 .746 r
.70538 .72614 m .70839 .72884 L .70719 .72601 L F
0 0 0 r
.28227 .65298 m .28056 .65449 L .2791 .65495 L F
.28246 .65361 m .28227 .65298 L .28425 .65251 L F
.28246 .65361 m .28056 .65449 L .28227 .65298 L F
.821 .611 .619 r
.5545 .68813 m .5513 .69041 L .55224 .6893 L F
.429 0 .007 r
.45745 .73076 m .45972 .73074 L .46106 .72938 L F
.5 .034 .08 r
.45972 .73074 m .46321 .72964 L .46106 .72938 L F
.586 .41 .61 r
.54912 .72923 m .54716 .73235 L .54953 .73145 L F
.54912 .72923 m .54716 .73235 L .54953 .73145 L F
.464 .525 .836 r
.55086 .72788 m .54912 .72923 L .54784 .72655 L F
.768 .359 .276 r
.60172 .66586 m .60076 .66753 L .59997 .66573 L F
.60172 .66586 m .60369 .66816 L .60076 .66753 L F
.549 .499 .752 r
.30165 .70213 m .30428 .70434 L .30403 .70166 L F
.675 .706 .872 r
.52289 .75105 m .51966 .75112 L .51988 .74944 L F
.52289 .75105 m .52047 .74975 L .52199 .74773 L F
.52047 .74975 m .51988 .74944 L .52084 .74866 L F
.52047 .74975 m .52084 .74866 L .52199 .74773 L F
.75 .58 .665 r
.52289 .75105 m .51955 .75322 L .51966 .75112 L F
0 0 .283 r
.52021 .7505 m .52025 .75149 L .52103 .74958 L F
.51966 .75112 m .51994 .75129 L .52021 .7505 L F
.51994 .75129 m .52025 .75149 L .52021 .7505 L F
.282 .336 .741 r
.51988 .74944 m .51966 .75112 L .52103 .74958 L F
0 0 .283 r
.51966 .75112 m .51955 .75322 L .52025 .75149 L F
.649 .18 0 r
.72959 .62791 m .7306 .62954 L .72831 .62755 L F
.72959 .62791 m .73144 .63047 L .7306 .62954 L F
.469 .778 .998 r
.29589 .59834 m .29241 .5977 L .29441 .59733 L F
.354 .75 .985 r
.2965 .5975 m .29589 .59834 L .29441 .59733 L F
.2965 .5975 m .29799 .59825 L .29589 .59834 L F
.756 .676 .773 r
.52304 .73955 m .52058 .74052 L .51996 .73884 L F
.172 0 0 r
.51996 .73884 m .52157 .73923 L .52304 .73955 L F
.652 .529 .701 r
.52304 .73955 m .52622 .74252 L .52382 .74272 L F
.52304 .73955 m .52607 .74006 L .52622 .74252 L F
.439 .56 .881 r
.67501 .59211 m .67739 .59578 L .67807 .59525 L F
.275 .663 .969 r
.52142 .76384 m .52305 .765 L .52133 .76447 L F
.875 .93 .856 r
.52305 .765 m .52039 .76681 L .52133 .76447 L F
.629 .827 .976 r
.5253 .76439 m .52305 .765 L .52142 .76384 L F
.569 .473 .706 r
.5257 .76726 m .52305 .765 L .5253 .76439 L F
.5257 .76726 m .52355 .76768 L .52305 .765 L F
.069 .555 .895 r
.5065 .78579 m .50614 .78602 L .50591 .78605 L F
.5065 .78579 m .50768 .78655 L .50614 .78602 L F
.99 .81 .568 r
.51079 .73999 m .51225 .74025 L .51149 .74243 L F
.446 .869 .937 r
.51362 .7397 m .51225 .74025 L .51079 .73999 L F
.497 .839 .997 r
.27487 .63819 m .27737 .63571 L .27574 .63627 L F
0 .061 .608 r
.7096 .61186 m .7106 .6126 L .70847 .61097 L F
.7096 .61186 m .71135 .61384 L .7106 .6126 L F
.359 0 .069 r
.34353 .65236 m .3457 .65206 L .34712 .65029 L F
.285 0 .022 r
.34712 .65029 m .34765 .65162 L .34914 .64972 L F
.34712 .65029 m .3457 .65206 L .34765 .65162 L F
.715 .685 .82 r
.40352 .78065 m .40473 .78201 L .40686 .78101 L F
.454 .615 .918 r
.40473 .78201 m .40729 .78306 L .40686 .78101 L F
.647 .539 .718 r
.40626 .76744 m .40455 .7701 L .4069 .76963 L F
.597 .581 .806 r
.40455 .7701 m .40796 .7728 L .4069 .76963 L F
.707 .647 .788 r
.72792 .59582 m .73119 .59802 L .73005 .59495 L F
.588 .599 .831 r
.73119 .59802 m .73233 .59457 L .73005 .59495 L F
.73119 .59802 m .73349 .59756 L .73233 .59457 L F
.501 .255 .472 r
.48654 .72264 m .48895 .72015 L .48757 .7206 L F
.532 0 0 r
.35467 .6485 m .35671 .64923 L .35486 .64816 L F
.524 0 0 r
.35486 .64816 m .35671 .64923 L .35805 .64909 L F
.826 .744 .223 r
.59626 .73412 m .59664 .73107 L .59529 .73197 L F
.774 .626 .696 r
.51594 .73671 m .52014 .73468 L .51589 .73474 L F
.842 .552 .497 r
.43292 .73791 m .43619 .73846 L .43437 .73742 L F
.478 .056 .16 r
.43437 .73742 m .43619 .73846 L .43664 .73733 L F
.768 .681 .766 r
.73082 .60245 m .73222 .60565 L .73148 .60443 L F
.436 .228 .497 r
.2802 .63036 m .28202 .63003 L .28225 .62808 L F
.398 .212 .509 r
.2802 .63036 m .28171 .63234 L .28202 .63003 L F
.2802 .63036 m .28002 .63279 L .28171 .63234 L F
.487 .308 .564 r
.3021 .63313 m .30039 .63569 L .30053 .63339 L F
.372 .11 .381 r
.40756 .68708 m .40627 .68579 L .40811 .68517 L F
.40756 .68708 m .4057 .68774 L .40627 .68579 L F
.488 .609 .899 r
.37926 .64807 m .37829 .64997 L .37692 .6491 L F
.37926 .64807 m .38033 .64989 L .37829 .64997 L F
.744 .914 .544 r
.49806 .72918 m .49609 .73222 L .49671 .73074 L F
.762 .996 .836 r
.49671 .73074 m .49609 .73222 L .49441 .73275 L F
.743 .449 0 r
.7344 .62695 m .7354 .63032 L .73526 .62805 L F
.238 0 0 r
.29292 .72029 m .29475 .71995 L .29643 .71821 L F
.841 .505 .418 r
.29475 .71995 m .29632 .72087 L .29643 .71821 L F
.651 .537 .712 r
.29643 .71821 m .29728 .71839 L .29826 .71549 L F
.817 .483 .422 r
.29643 .71821 m .29979 .72088 L .29728 .71839 L F
.29643 .71821 m .29632 .72087 L .29979 .72088 L F
.593 .896 .988 r
.30545 .59939 m .3049 .60066 L .30342 .59974 L F
.30545 .59939 m .30728 .59982 L .3049 .60066 L F
.821 .73 .764 r
.62973 .67161 m .63096 .66944 L .62904 .66844 L F
.225 0 0 r
.44975 .78579 m .44934 .78604 L .44721 .7859 L F
0 0 0 r
.45146 .78534 m .44975 .78579 L .45404 .78571 L F
.45146 .78534 m .44934 .78604 L .44975 .78579 L F
.821 .73 .764 r
.62973 .67161 m .62904 .66844 L .6283 .67084 L F
.935 .74 .615 r
.62756 .67359 m .62973 .67161 L .6283 .67084 L F
.62756 .67359 m .62903 .67437 L .62973 .67161 L F
.853 .926 .877 r
.72324 .6144 m .72413 .61529 L .72545 .61396 L F
.655 .739 .912 r
.72757 .58202 m .72434 .58113 L .72656 .58093 L F
0 .377 .68 r
.72912 .5825 m .72757 .58202 L .72656 .58093 L F
.72912 .5825 m .73051 .58296 L .72757 .58202 L F
.188 .716 .847 r
.73733 .59749 m .73787 .59727 L .73349 .59756 L F
.939 .587 .323 r
.73965 .59891 m .73786 .59662 L .73733 .59749 L F
0 .038 .598 r
.73786 .59662 m .73787 .59727 L .73733 .59749 L F
.555 .315 .506 r
.41778 .67448 m .41751 .67663 L .4153 .67699 L F
.515 .28 .496 r
.41965 .67619 m .41778 .67448 L .41984 .67399 L F
.41965 .67619 m .41751 .67663 L .41778 .67448 L F
.597 .547 .769 r
.4069 .76963 m .40796 .7728 L .41014 .77238 L F
.376 .101 .363 r
.40757 .77511 m .41014 .77238 L .40796 .7728 L F
.532 .405 .653 r
.30852 .6826 m .31071 .68467 L .31073 .68214 L F
.30852 .6826 m .30878 .68547 L .31071 .68467 L F
.509 .892 .715 r
.55141 .68605 m .55277 .68489 L .55331 .68501 L F
.55141 .68605 m .54966 .68693 L .55277 .68489 L F
.828 .758 .786 r
.52253 .72683 m .52026 .72883 L .52059 .7261 L F
.194 .459 .881 r
.73896 .58862 m .73804 .58955 L .73614 .58726 L F
.153 .394 .842 r
.73896 .58862 m .74066 .5912 L .73804 .58955 L F
.714 .602 .73 r
.52493 .75069 m .52199 .74773 L .52401 .74772 L F
.52493 .75069 m .52289 .75105 L .52199 .74773 L F
.729 .579 .687 r
.52493 .75069 m .5229 .75346 L .52289 .75105 L F
.52493 .75069 m .52642 .75381 L .5229 .75346 L F
.74 .737 .848 r
.52736 .74823 m .52493 .75069 L .52401 .74772 L F
.107 .022 .467 r
.52039 .76681 m .52142 .76384 L .52133 .76447 L F
.619 .852 .987 r
.73228 .62479 m .7284 .62529 L .73077 .62416 L F
.71 .174 0 r
.73077 .62416 m .73342 .62582 L .73228 .62479 L F
.821 .611 .619 r
.5545 .68813 m .55546 .69111 L .5513 .69041 L F
.451 .401 .712 r
.55705 .69003 m .55546 .69111 L .5545 .68813 L F
.766 .911 .938 r
.54363 .786 m .54492 .78681 L .54634 .78538 L F
.544 .256 .428 r
.4419 .73661 m .4446 .73458 L .44221 .73465 L F
.436 .122 .334 r
.34917 .68147 m .34749 .6803 L .3503 .6791 L F
.465 .22 .458 r
.35273 .67695 m .35241 .67878 L .3503 .6791 L F
.329 0 .193 r
.35126 .68079 m .3503 .6791 L .35241 .67878 L F
.35126 .68079 m .34917 .68147 L .3503 .6791 L F
.818 .737 .774 r
.40499 .77862 m .40913 .77827 L .40797 .77791 L F
.40499 .77862 m .40686 .78101 L .40913 .77827 L F
.656 .486 .641 r
.40686 .78101 m .40929 .78089 L .40913 .77827 L F
.348 .8 .949 r
.41096 .77789 m .40797 .77791 L .40913 .77827 L F
.636 .553 .744 r
.40929 .78089 m .41096 .77789 L .40913 .77827 L F
.159 0 .291 r
.59664 .73107 m .59942 .72786 L .59691 .72886 L F
.744 .914 .544 r
.49806 .72918 m .49671 .73074 L .49469 .72841 L F
.463 .251 .505 r
.618 .70706 m .61788 .70921 L .61583 .71013 L F
.162 0 .334 r
.62053 .70415 m .61997 .70626 L .618 .70706 L F
.082 0 .315 r
.61997 .70626 m .61788 .70921 L .618 .70706 L F
.75 .58 .665 r
.52289 .75105 m .5229 .75346 L .51955 .75322 L F
.668 .667 .84 r
.72061 .72061 m .7216 .72173 L .72443 .72079 L F
.558 .426 .657 r
.72443 .72079 m .72164 .72383 L .72061 .72061 L F
.72443 .72079 m .72397 .72351 L .72164 .72383 L F
.273 .693 .969 r
.44329 .77527 m .44264 .77601 L .44127 .77517 L F
.44329 .77527 m .44482 .77621 L .44264 .77601 L F
.777 .706 .784 r
.29696 .73414 m .30008 .73474 L .29882 .73252 L F
.855 .971 .656 r
.30181 .73364 m .30173 .73459 L .30245 .73263 L F
.258 .443 .852 r
.29882 .73252 m .30008 .73474 L .30161 .73444 L F
.29882 .73252 m .30161 .73444 L .30165 .73431 L F
.224 .715 .921 r
.30008 .73474 m .30173 .73459 L .30161 .73444 L F
.855 .971 .656 r
.30153 .73479 m .30173 .73459 L .30175 .73436 L F
.30165 .73431 m .30175 .73436 L .30181 .73364 L F
.30153 .73479 m .30175 .73436 L .30165 .73431 L F
.409 0 0 r
.29882 .73252 m .30165 .73431 L .29925 .73288 L F
.258 .443 .852 r
.30165 .73431 m .30161 .73444 L .3018 .7344 L F
.409 0 0 r
.30165 .73431 m .3018 .7344 L .3016 .73428 L F
.30165 .73431 m .3016 .73428 L .29925 .73288 L F
.224 .715 .921 r
.30161 .73444 m .30173 .73459 L .3018 .7344 L F
.415 .374 .705 r
.30173 .73459 m .30258 .73768 L .30008 .73474 L F
.855 .971 .656 r
.30042 .73582 m .30153 .73479 L .30161 .73444 L F
.30144 .73421 m .30161 .73444 L .30181 .73364 L F
.899 .754 .693 r
.29925 .73288 m .3016 .73428 L .30042 .73582 L F
.855 .971 .656 r
.30042 .73582 m .30161 .73444 L .30155 .73435 L F
.899 .754 .693 r
.3016 .73428 m .3018 .7344 L .30042 .73582 L F
.855 .971 .656 r
.30042 .73582 m .30155 .73435 L .30144 .73421 L F
.522 .246 .436 r
.5257 .76726 m .52305 .76943 L .52355 .76768 L F
.801 .659 .706 r
.29671 .72615 m .29814 .72707 L .29814 .72352 L F
.422 .349 .67 r
.29814 .72352 m .29814 .72707 L .29997 .72517 L F
.289 .185 .559 r
.29817 .72878 m .29997 .72517 L .29814 .72707 L F
0 0 0 r
.62642 .69102 m .62557 .69267 L .62404 .69364 L F
0 0 .135 r
.62464 .69471 m .62404 .69364 L .62557 .69267 L F
.62464 .69471 m .62343 .69587 L .62404 .69364 L F
.96 .657 .412 r
.52703 .71178 m .52771 .71544 L .52887 .71559 L F
0 .074 .568 r
.53011 .71657 m .52887 .71559 L .52771 .71544 L F
.53011 .71657 m .53127 .71771 L .52887 .71559 L F
.177 .524 .919 r
.58316 .73545 m .58632 .73633 L .58601 .73716 L F
.827 .538 .499 r
.58463 .73925 m .58601 .73716 L .58632 .73633 L F
0 0 .221 r
.58647 .73908 m .5862 .74144 L .58695 .7395 L F
.827 .538 .499 r
.58622 .73942 m .58695 .7395 L .58613 .73746 L F
0 0 .221 r
.58647 .73908 m .58647 .73909 L .58647 .73908 L F
.58647 .73909 m .5862 .74144 L .58647 .73908 L F
.562 .311 .493 r
.58592 .74045 m .58425 .74153 L .58463 .73925 L F
.58658 .74106 m .58559 .74126 L .58592 .74045 L F
.58559 .74126 m .58425 .74153 L .58592 .74045 L F
0 0 .221 r
.58647 .73908 m .58658 .74106 L .58631 .74133 L F
.58628 .74073 m .58631 .74133 L .5862 .74144 L F
.58647 .73908 m .58631 .74133 L .58628 .74073 L F
.827 .538 .499 r
.58463 .73925 m .58622 .73942 L .58601 .73716 L F
.58622 .73942 m .58613 .73746 L .58601 .73716 L F
.236 0 0 r
.46603 .77417 m .46966 .77434 L .47098 .77383 L F
.709 .187 0 r
.46966 .77434 m .47304 .77584 L .47098 .77383 L F
.513 .027 .04 r
.70309 .5779 m .70673 .57755 L .70399 .57809 L F
.401 0 0 r
.47735 .77769 m .47397 .77648 L .47614 .77679 L F
.485 .662 .94 r
.47868 .77675 m .47735 .77769 L .47614 .77679 L F
.47868 .77675 m .47953 .77776 L .47735 .77769 L F
.368 .461 .824 r
.58515 .73348 m .58316 .73545 L .58383 .73372 L F
.58515 .73348 m .58632 .73633 L .58316 .73545 L F
.551 .549 .805 r
.39446 .67402 m .39563 .67726 L .39756 .6767 L F
.378 .08 .327 r
.39563 .67726 m .39492 .67926 L .39756 .6767 L F
.734 .511 .589 r
.4375 .76642 m .44022 .76699 L .44027 .7646 L F
.704 .522 .639 r
.69077 .58397 m .69292 .58141 L .69065 .5816 L F
.988 .717 .371 r
.72776 .62605 m .7252 .62292 L .72446 .6217 L F
.72776 .62605 m .72737 .62652 L .7252 .62292 L F
0 .114 .662 r
.72446 .6217 m .72737 .62652 L .72719 .62512 L F
.787 .291 .014 r
.72446 .6217 m .72672 .62473 L .72388 .62131 L F
0 0 .469 r
.72396 .62141 m .72672 .62473 L .72524 .62289 L F
.72388 .62131 m .72415 .62164 L .72396 .62141 L F
.72415 .62164 m .72672 .62473 L .72396 .62141 L F
.988 .717 .371 r
.7284 .62529 m .72776 .62605 L .72446 .6217 L F
.7284 .62529 m .72831 .62755 L .72737 .62652 L F
.573 .66 .896 r
.73077 .62416 m .7284 .62529 L .72446 .6217 L F
.649 .246 .269 r
.4967 .7862 m .49546 .78785 L .49315 .7862 L F
.708 .319 .309 r
.4967 .7862 m .49887 .78822 L .49546 .78785 L F
.694 .512 .638 r
.52622 .74252 m .52397 .7451 L .52382 .74272 L F
0 0 .202 r
.30011 .71034 m .30082 .71155 L .30194 .70942 L F
.30011 .71034 m .29985 .71244 L .30082 .71155 L F
.621 .237 .295 r
.60655 .65679 m .60987 .65513 L .60651 .65521 L F
.60655 .65679 m .60899 .65708 L .60987 .65513 L F
.44 .111 .31 r
.61111 .65677 m .60987 .65513 L .60899 .65708 L F
.61111 .65677 m .61223 .65463 L .60987 .65513 L F
.727 .618 .736 r
.52412 .75618 m .52068 .75416 L .5229 .75346 L F
.52412 .75618 m .52088 .75698 L .52068 .75416 L F
.505 .237 .442 r
.52302 .75697 m .52088 .75698 L .52412 .75618 L F
.725 .611 .73 r
.52642 .75381 m .52412 .75618 L .5229 .75346 L F
.722 .407 .446 r
.52634 .75683 m .52629 .75856 L .52412 .75618 L F
0 .104 .65 r
.52412 .75618 m .5259 .75813 L .52538 .75732 L F
.5259 .75813 m .52629 .75856 L .52538 .75732 L F
.696 .563 .701 r
.52642 .75381 m .52634 .75683 L .52412 .75618 L F
.527 .669 .927 r
.52383 .75488 m .52538 .75732 L .52389 .75474 L F
0 .104 .65 r
.52412 .75618 m .52538 .75732 L .52302 .75697 L F
.527 .669 .927 r
.52302 .75697 m .52538 .75732 L .52383 .75488 L F
.381 .29 .627 r
.40615 .76496 m .40813 .76623 L .40825 .76445 L F
.40615 .76496 m .40626 .76744 L .40813 .76623 L F
.563 .384 .597 r
.52674 .7045 m .52894 .70174 L .52555 .70143 L F
.52674 .7045 m .52917 .70426 L .52894 .70174 L F
.52894 .70174 m .52917 .70426 L .52674 .7045 L F
.579 .63 .866 r
.42346 .66624 m .42436 .66858 L .42223 .66893 L F
.42 .316 .63 r
.42421 .67085 m .42223 .66893 L .42436 .66858 L F
.42421 .67085 m .42251 .6717 L .42223 .66893 L F
.065 0 0 r
.36514 .7191 m .3647 .71828 L .36677 .7178 L F
.36514 .7191 m .36321 .71988 L .3647 .71828 L F
.531 .863 .994 r
.71888 .58236 m .72115 .58174 L .72222 .58226 L F
.525 .861 .994 r
.72222 .58226 m .72349 .58117 L .72434 .58113 L F
.72222 .58226 m .72115 .58174 L .72349 .58117 L F
.853 .625 .593 r
.6277 .6607 m .62486 .65795 L .62463 .6603 L F
.794 .602 .642 r
.62481 .66292 m .6277 .6607 L .62463 .6603 L F
.62481 .66292 m .6275 .66334 L .6277 .6607 L F
.572 .161 .226 r
.54716 .73235 m .5462 .73394 L .54402 .73352 L F
.03 0 0 r
.54788 .7329 m .54716 .73235 L .54953 .73145 L F
.54788 .7329 m .5462 .73394 L .54716 .73235 L F
.917 .811 .726 r
.6814 .59639 m .6794 .59998 L .6789 .59706 L F
.669 .398 .503 r
.61223 .65463 m .61429 .65493 L .61452 .65289 L F
.962 .633 .26 r
.55426 .74613 m .5551 .7458 L .55327 .74601 L F
.217 .359 .793 r
.5551 .7458 m .5567 .74594 L .55629 .74416 L F
.898 .581 .439 r
.36529 .83283 m .36779 .83482 L .36595 .83527 L F
.235 .553 .932 r
.36943 .83519 m .36779 .83482 L .36529 .83283 L F
.374 0 0 r
.36595 .83527 m .36779 .83482 L .36943 .83519 L F
.824 .65 .667 r
.55403 .74676 m .55014 .74739 L .55136 .74593 L F
.719 .351 .353 r
.55403 .74676 m .55214 .74831 L .55014 .74739 L F
.604 .196 .242 r
.5553 .74766 m .55214 .74831 L .55403 .74676 L F
0 0 0 r
.60238 .75567 m .60551 .75339 L .60428 .7549 L F
.60813 .7511 m .60709 .75282 L .60551 .75339 L F
.60551 .75339 m .60709 .75282 L .60428 .7549 L F
.525 .502 .773 r
.28628 .61972 m .28772 .61587 L .28509 .61653 L F
.28628 .61972 m .28813 .61923 L .28772 .61587 L F
.448 .356 .659 r
.28628 .61972 m .28844 .62167 L .28813 .61923 L F
.28628 .61972 m .28669 .62229 L .28844 .62167 L F
0 0 .322 r
.73543 .7261 m .73547 .72792 L .73437 .72899 L F
.189 .35 .795 r
.73547 .72792 m .73666 .73099 L .73437 .72899 L F
0 0 .447 r
.62748 .68723 m .62642 .69102 L .62768 .68783 L F
.62748 .68723 m .62764 .6899 L .62642 .69102 L F
0 0 0 r
.62764 .6899 m .62557 .69267 L .62642 .69102 L F
.568 .663 .902 r
.71813 .73125 m .71844 .72864 L .7163 .72848 L F
.71813 .73125 m .72004 .731 L .71844 .72864 L F
.523 .451 .717 r
.33914 .69546 m .33689 .69744 L .33636 .69338 L F
.356 .244 .587 r
.33914 .69546 m .33735 .69879 L .33689 .69744 L F
.48 .351 .626 r
.30684 .68826 m .30891 .69035 L .30867 .68778 L F
.30684 .68826 m .307 .69063 L .30891 .69035 L F
.817 .483 .422 r
.29632 .72087 m .29811 .72336 L .29979 .72088 L F
.184 .429 .862 r
.29728 .71839 m .29979 .72088 L .30057 .71999 L F
0 0 0 r
.29979 .72088 m .29811 .72336 L .30057 .71999 L F
.902 .647 .542 r
.60807 .67167 m .6081 .67418 L .60658 .67108 L F
.649 .728 .907 r
.5478 .68996 m .54886 .69128 L .54636 .69226 L F
.308 .091 .413 r
.59987 .71795 m .60235 .71736 L .602 .71447 L F
.283 0 .288 r
.602 .71447 m .6044 .71435 L .60473 .71204 L F
.265 .063 .409 r
.602 .71447 m .60387 .71643 L .6044 .71435 L F
.602 .71447 m .60235 .71736 L .60387 .71643 L F
.3 .059 .371 r
.57743 .7154 m .57705 .71776 L .57535 .71781 L F
.326 .287 .661 r
.57705 .71776 m .57733 .71999 L .57535 .71781 L F
.498 .168 .339 r
.37179 .70332 m .37457 .70152 L .37261 .70215 L F
.927 .77 .667 r
.67217 .6143 m .67065 .61415 L .67158 .61114 L F
.528 .331 .556 r
.67217 .6143 m .67226 .61676 L .66983 .61722 L F
.67217 .6143 m .67226 .61676 L .66983 .61722 L F
.42 0 0 r
.67217 .6143 m .67271 .61473 L .67065 .61415 L F
.67217 .6143 m .67401 .61544 L .67271 .61473 L F
.538 .433 .683 r
.40774 .75912 m .41029 .7613 L .40999 .75874 L F
.40774 .75912 m .40807 .76179 L .41029 .7613 L F
.642 .747 .925 r
.38995 .6705 m .392 .67069 L .3915 .66774 L F
.477 .682 .956 r
.38995 .6705 m .39391 .67154 L .392 .67069 L F
.54 .673 .923 r
.3915 .66774 m .392 .67069 L .39449 .66905 L F
.599 .67 .89 r
.39391 .67154 m .39449 .66905 L .392 .67069 L F
.755 .669 .767 r
.50135 .73417 m .50257 .73726 L .49915 .73697 L F
.487 .329 .592 r
.5013 .73892 m .49915 .73697 L .50257 .73726 L F
.115 .096 .557 r
.50366 .73393 m .50257 .73726 L .50135 .73417 L F
.50366 .73393 m .50397 .73663 L .50257 .73726 L F
0 0 0 r
.50397 .73663 m .5013 .73892 L .50257 .73726 L F
.5 .651 .926 r
.70008 .60266 m .70244 .60531 L .70391 .60499 L F
.306 .526 .903 r
.70244 .60531 m .70399 .6064 L .70391 .60499 L F
.576 .841 .995 r
.29548 .72303 m .29814 .72352 L .29632 .72087 L F
.864 .782 .769 r
.30057 .71999 m .29707 .72185 L .29928 .71935 L F
.656 .605 .785 r
.29727 .72241 m .29548 .72303 L .29632 .72087 L F
0 0 .445 r
.29814 .72352 m .29813 .72346 L .29632 .72087 L F
.29813 .72346 m .29811 .72336 L .29757 .7226 L F
.29813 .72346 m .29757 .7226 L .29632 .72087 L F
.783 .592 .641 r
.29441 .7259 m .29548 .72303 L .29397 .72511 L F
.712 .968 .935 r
.29727 .72241 m .29397 .72511 L .29548 .72303 L F
.29727 .72241 m .29248 .72439 L .29397 .72511 L F
.212 .175 .597 r
.29475 .71995 m .29525 .72289 L .296 .72202 L F
.29525 .72289 m .29529 .72311 L .296 .72202 L F
.691 .149 0 r
.29534 .72278 m .29618 .72233 L .29453 .72294 L F
.29727 .72241 m .29618 .72233 L .29534 .72278 L F
.212 .175 .597 r
.296 .72202 m .29559 .72265 L .29618 .72233 L F
.29559 .72265 m .29529 .72311 L .29618 .72233 L F
.712 .968 .935 r
.29727 .72241 m .29627 .7226 L .29496 .72322 L F
.29477 .72345 m .29496 .72322 L .29248 .72439 L F
.29727 .72241 m .29496 .72322 L .29477 .72345 L F
.833 .6 .586 r
.29495 .72297 m .29525 .72289 L .29475 .71995 L F
.712 .968 .935 r
.29627 .7226 m .29418 .72319 L .29248 .72439 L F
.655 .102 0 r
.29453 .72294 m .29529 .72311 L .29495 .72297 L F
.29453 .72294 m .29495 .72297 L .29183 .72169 L F
.712 .968 .935 r
.29495 .72297 m .29453 .72294 L .29418 .72319 L F
.29627 .7226 m .29453 .72294 L .29495 .72297 L F
.833 .6 .586 r
.29183 .72169 m .29495 .72297 L .29475 .71995 L F
.29495 .72297 m .29529 .72311 L .29525 .72289 L F
0 .032 .599 r
.29632 .72087 m .29811 .72336 L .29727 .72241 L F
.691 .149 0 r
.29727 .72241 m .29811 .72336 L .29618 .72233 L F
.864 .428 .163 r
.29618 .72233 m .29811 .72336 L .29632 .72087 L F
.864 .782 .769 r
.29707 .72185 m .29618 .72233 L .29692 .72162 L F
.29707 .72185 m .29692 .72162 L .29928 .71935 L F
0 .066 .564 r
.29814 .72352 m .29997 .72517 L .29811 .72336 L F
.416 .292 .602 r
.29728 .71839 m .30088 .71817 L .29826 .71549 L F
.184 .429 .862 r
.29728 .71839 m .30057 .71999 L .30088 .71817 L F
.095 0 .077 r
.59014 .66902 m .58936 .67111 L .58766 .67143 L F
.179 0 .112 r
.59125 .67011 m .59014 .66902 L .5921 .66823 L F
.59125 .67011 m .58936 .67111 L .59014 .66902 L F
.677 .843 .963 r
.33331 .7345 m .3369 .73452 L .33553 .73415 L F
.059 .264 .757 r
.33548 .73144 m .33754 .73341 L .3369 .73452 L F
.565 .896 .983 r
.33754 .73341 m .33553 .73415 L .3369 .73452 L F
.355 .029 .267 r
.5831 .66331 m .58456 .6649 L .58504 .66251 L F
.5831 .66331 m .58245 .66556 L .58456 .6649 L F
.89 .873 .814 r
.7243 .61293 m .72545 .61396 L .72547 .61117 L F
.853 .926 .877 r
.72324 .6144 m .72545 .61396 L .7243 .61293 L F
.792 .801 .859 r
.72547 .61117 m .72545 .61396 L .72816 .61132 L F
.729 .291 .21 r
.52947 .73415 m .53146 .73604 L .53345 .73481 L F
.412 0 .011 r
.53146 .73604 m .53613 .73418 L .53345 .73481 L F
.859 .523 .414 r
.67056 .60488 m .67176 .60642 L .67312 .60613 L F
.929 .849 .743 r
.67312 .60613 m .67176 .60642 L .67188 .60613 L F
.834 .415 .242 r
.67056 .60488 m .6725 .60583 L .67165 .60606 L F
.303 .406 .803 r
.67185 .60409 m .67177 .60619 L .67056 .60488 L F
.67177 .60619 m .67176 .60642 L .67056 .60488 L F
.834 .415 .242 r
.67056 .60488 m .67165 .60606 L .67141 .60613 L F
.6725 .60583 m .67312 .60613 L .67188 .60613 L F
.6725 .60583 m .67188 .60613 L .67141 .60613 L F
.963 .94 .686 r
.67371 .60193 m .67188 .60613 L .67185 .60409 L F
.67188 .60613 m .67176 .60642 L .67177 .60619 L F
.67188 .60613 m .67177 .60619 L .67185 .60409 L F
.929 .849 .743 r
.67312 .60613 m .67188 .60613 L .67371 .60193 L F
.834 .415 .242 r
.67141 .60613 m .67312 .60613 L .67246 .60768 L F
.979 .683 .325 r
.67312 .60613 m .67339 .60851 L .67246 .60768 L F
0 .52 .821 r
.73316 .63191 m .73444 .63192 L .73144 .63047 L F
.73316 .63191 m .73591 .63249 L .73444 .63192 L F
.649 .253 .28 r
.4782 .74103 m .47673 .74228 L .47454 .74203 L F
.489 .053 .137 r
.48084 .74082 m .4782 .74103 L .48025 .73986 L F
.48084 .74082 m .47673 .74228 L .4782 .74103 L F
.481 .162 .348 r
.34749 .6803 m .34711 .68192 L .34498 .68223 L F
.436 .122 .334 r
.34917 .68147 m .34711 .68192 L .34749 .6803 L F
.239 .016 .36 r
.30851 .62417 m .3085 .62168 L .31048 .62139 L F
.31 .743 .969 r
.27286 .59466 m .27232 .59536 L .27078 .59463 L F
.27286 .59466 m .27426 .59526 L .27232 .59536 L F
.145 .689 .752 r
.44529 .78586 m .44378 .786 L .44166 .78631 L F
.11 0 0 r
.44721 .7859 m .44378 .786 L .44529 .78586 L F
.513 .781 .993 r
.28198 .59574 m .28131 .59708 L .27983 .59628 L F
.28198 .59574 m .28335 .5967 L .28131 .59708 L F
.903 .613 .485 r
.60649 .66904 m .60485 .67025 L .60369 .66816 L F
.60649 .66904 m .60658 .67108 L .60485 .67025 L F
.445 0 0 r
.52799 .7896 m .52666 .79074 L .52462 .79041 L F
.787 .344 .197 r
.52836 .79083 m .52666 .79074 L .52799 .7896 L F
.417 0 0 r
.51183 .7294 m .5079 .73065 L .50924 .72955 L F
.748 .43 .445 r
.52948 .75799 m .52634 .75683 L .52915 .7568 L F
.52948 .75799 m .52629 .75856 L .52634 .75683 L F
.727 .472 .54 r
.49178 .73711 m .4882 .73954 L .48796 .73761 L F
.964 .64 .339 r
.52781 .76176 m .52629 .75856 L .52948 .75799 L F
.605 .635 .854 r
.53147 .75656 m .52948 .75799 L .52915 .7568 L F
.53147 .75656 m .53212 .75786 L .52948 .75799 L F
.475 .383 .671 r
.28507 .61422 m .28772 .61587 L .28681 .6138 L F
.28507 .61422 m .28509 .61653 L .28772 .61587 L F
.453 .19 .424 r
.4057 .68774 m .40313 .6902 L .40365 .68823 L F
.528 .212 .375 r
.46685 .74261 m .46591 .74527 L .46329 .74539 L F
.314 0 .09 r
.46919 .74288 m .46591 .74527 L .46685 .74261 L F
.116 0 .296 r
.49744 .71479 m .49902 .7146 L .49932 .71229 L F
.032 0 0 r
.49744 .71479 m .49588 .71651 L .49902 .7146 L F
.115 .663 .816 r
.73085 .71162 m .72691 .71153 L .72934 .71098 L F
.339 .609 .948 r
.73194 .71065 m .73085 .71162 L .72934 .71098 L F
.73194 .71065 m .73293 .71212 L .73085 .71162 L F
.586 .946 .851 r
.72519 .7131 m .72168 .71467 L .72326 .7135 L F
.743 .991 .879 r
.72691 .71153 m .72519 .7131 L .72326 .7135 L F
.745 .785 .885 r
.34437 .70387 m .34075 .70384 L .34277 .70286 L F
.572 .722 .943 r
.34502 .70155 m .34437 .70387 L .34277 .70286 L F
.34502 .70155 m .34656 .70346 L .34437 .70387 L F
.504 .264 .484 r
.35491 .67648 m .35241 .67878 L .35273 .67695 L F
.549 .334 .54 r
.40912 .75345 m .41148 .75318 L .41173 .75078 L F
.491 .284 .526 r
.41173 .75078 m .41351 .75264 L .41381 .7503 L F
.41173 .75078 m .41148 .75318 L .41351 .75264 L F
.619 .495 .69 r
.33844 .6908 m .33636 .69338 L .3365 .69155 L F
.53 .336 .562 r
.31063 .67975 m .31281 .67939 L .31294 .67707 L F
.492 .314 .567 r
.31073 .68214 m .31281 .67939 L .31063 .67975 L F
.725 .211 0 r
.44833 .76221 m .44622 .76212 L .44566 .76114 L F
.58 .593 .83 r
.45019 .7614 m .4476 .76049 L .44854 .76007 L F
.729 .42 .457 r
.44684 .75869 m .44993 .7598 L .44988 .75902 L F
0 0 .365 r
.44988 .75902 m .44993 .7598 L .45013 .75914 L F
.44988 .75902 m .45121 .75562 L .45192 .75809 L F
.134 0 0 r
.45143 .75881 m .45034 .75896 L .45192 .75809 L F
.45034 .75896 m .44988 .75902 L .45081 .7586 L F
.45034 .75896 m .45081 .7586 L .45192 .75809 L F
0 0 .365 r
.44988 .75902 m .45013 .75914 L .45121 .75562 L F
.865 .794 .78 r
.45121 .75562 m .45014 .75912 L .44761 .75778 L F
.58 .593 .83 r
.45019 .7614 m .44684 .75869 L .44856 .76064 L F
.721 .389 .417 r
.44988 .75902 m .44941 .75959 L .44684 .75869 L F
.334 .643 .966 r
.44941 .75959 m .44937 .7596 L .44684 .75869 L F
.721 .389 .417 r
.44941 .75959 m .44856 .76064 L .44684 .75869 L F
.334 .643 .966 r
.44964 .75955 m .44941 .75959 L .44684 .75869 L F
.44761 .75778 m .44964 .75955 L .44684 .75869 L F
.44964 .75955 m .44993 .7598 L .44937 .7596 L F
.134 0 0 r
.45001 .75948 m .44856 .76064 L .44903 .76006 L F
.4504 .75925 m .45012 .75946 L .45001 .75948 L F
.45012 .75946 m .44856 .76064 L .45001 .75948 L F
.44957 .75961 m .44903 .76006 L .44931 .75972 L F
.865 .794 .78 r
.45013 .75914 m .44993 .7598 L .44964 .75955 L F
.134 0 0 r
.4504 .75925 m .44903 .76006 L .44957 .75961 L F
.45131 .75883 m .44931 .75972 L .44988 .75902 L F
.865 .794 .78 r
.45014 .75912 m .45013 .75914 L .44961 .75953 L F
.45013 .75914 m .44964 .75955 L .44961 .75953 L F
.45014 .75912 m .44961 .75953 L .44761 .75778 L F
.134 0 0 r
.45143 .75881 m .4506 .75934 L .4504 .75925 L F
.4506 .75934 m .44856 .76064 L .4504 .75925 L F
.45143 .75881 m .44931 .75972 L .45131 .75883 L F
.58 .593 .83 r
.45019 .7614 m .44833 .76221 L .4476 .76049 L F
.44854 .76007 m .4476 .76049 L .44684 .75869 L F
.784 .966 .92 r
.44856 .76064 m .44833 .76221 L .45019 .7614 L F
.44856 .76064 m .44622 .76212 L .44833 .76221 L F
.13 0 0 r
.4603 .78478 m .45704 .78503 L .4585 .78453 L F
.258 .295 .71 r
.44028 .77169 m .43913 .77337 L .43803 .76878 L F
.297 .347 .746 r
.44028 .77169 m .44127 .77517 L .43913 .77337 L F
.704 .454 .544 r
.49335 .73956 m .49178 .73711 L .49301 .73739 L F
.186 0 .343 r
.60944 .74991 m .60813 .7511 L .60999 .74803 L F
.059 0 0 r
.60886 .75189 m .60813 .7511 L .60944 .74991 L F
.60886 .75189 m .60709 .75282 L .60813 .7511 L F
.885 .509 .323 r
.50078 .72805 m .50352 .73129 L .50357 .72903 L F
.702 .983 .88 r
.68696 .60588 m .69016 .60424 L .68937 .60334 L F
.76 .862 .925 r
.69016 .60424 m .69105 .60198 L .68937 .60334 L F
.69016 .60424 m .69215 .60302 L .69105 .60198 L F
.754 .552 .623 r
.49695 .73732 m .49697 .73976 L .49335 .73956 L F
.606 .433 .621 r
.49915 .73697 m .49697 .73976 L .49695 .73732 L F
0 0 0 r
.58936 .67111 m .58658 .67248 L .58766 .67143 L F
.486 0 0 r
.47514 .78363 m .4787 .78335 L .47738 .78397 L F
.635 .164 .119 r
.4787 .78335 m .47937 .78531 L .47738 .78397 L F
.4787 .78335 m .48061 .78408 L .47937 .78531 L F
.544 .11 .166 r
.51985 .78528 m .52309 .78487 L .52122 .7843 L F
.297 .172 .537 r
.43764 .76082 m .43599 .75913 L .43903 .75857 L F
.43764 .76082 m .43631 .76146 L .43599 .75913 L F
.127 0 0 r
.48115 .77805 m .48295 .77836 L .47953 .77776 L F
.734 .245 .076 r
.48167 .77918 m .48295 .77836 L .48115 .77805 L F
.48167 .77918 m .48509 .78039 L .48295 .77836 L F
.403 .583 .914 r
.4749 .77477 m .47614 .77679 L .47397 .77648 L F
.106 0 .324 r
.61788 .70921 m .61617 .71232 L .61583 .71013 L F
.353 .134 .435 r
.31361 .6163 m .31318 .61921 L .31115 .61883 L F
.356 0 .182 r
.31115 .61883 m .31219 .62053 L .31048 .62139 L F
.31115 .61883 m .31318 .61921 L .31219 .62053 L F
.504 .269 .492 r
.40098 .69292 m .39891 .69335 L .40136 .69083 L F
.438 .211 .471 r
.40284 .69244 m .40136 .69083 L .40313 .6902 L F
.40284 .69244 m .40098 .69292 L .40136 .69083 L F
.617 .493 .689 r
.3388 .69304 m .33636 .69338 L .33844 .6908 L F
.523 .451 .717 r
.33914 .69546 m .33636 .69338 L .3388 .69304 L F
.774 .626 .696 r
.51594 .73671 m .52049 .73759 L .52014 .73468 L F
.262 .25 .656 r
.52014 .73468 m .52049 .73759 L .521 .73716 L F
.389 .228 .539 r
.51996 .73884 m .521 .73716 L .52049 .73759 L F
.974 .671 .3 r
.52088 .75698 m .51955 .75322 L .52068 .75416 L F
.52088 .75698 m .51972 .75633 L .51955 .75322 L F
.929 .634 .464 r
.52088 .75698 m .51895 .7576 L .51972 .75633 L F
.52088 .75698 m .5207 .75862 L .51895 .7576 L F
.505 .237 .442 r
.52302 .75697 m .5207 .75862 L .52088 .75698 L F
.343 0 .136 r
.59289 .6571 m .59524 .65661 L .59569 .65556 L F
.498 .16 .324 r
.59524 .65661 m .59785 .65504 L .59569 .65556 L F
.513 .493 .771 r
.72004 .731 m .72029 .73371 L .72208 .73056 L F
.23 0 .073 r
.72029 .73371 m .72296 .73246 L .72208 .73056 L F
.72029 .73371 m .72035 .73384 L .72296 .73246 L F
0 .228 .739 r
.57709 .75079 m .57716 .75008 L .57499 .74844 L F
0 .054 .615 r
.57709 .75079 m .57885 .75287 L .57716 .75008 L F
0 0 0 r
.56358 .67776 m .56091 .67949 L .56244 .67869 L F
.043 0 0 r
.56091 .67949 m .56246 .67945 L .56244 .67869 L F
.56091 .67949 m .56016 .67996 L .56246 .67945 L F
.816 .597 .606 r
.38766 .67144 m .38995 .6705 L .38977 .66828 L F
.642 .747 .925 r
.38995 .6705 m .3915 .66774 L .38977 .66828 L F
0 0 0 r
.36087 .70724 m .36448 .70707 L .36222 .70684 L F
.583 .375 .564 r
.51284 .7454 m .51485 .7474 L .51498 .74494 L F
.51284 .7454 m .51275 .74804 L .51485 .7474 L F
.595 .628 .854 r
.53521 .75906 m .53299 .75947 L .53212 .75786 L F
.607 .506 .714 r
.53591 .76166 m .53299 .75947 L .53521 .75906 L F
.53591 .76166 m .53362 .76233 L .53299 .75947 L F
.725 .963 .941 r
.42684 .66457 m .42455 .66627 L .42504 .66476 L F
.993 .776 .506 r
.42455 .66627 m .42346 .66624 L .42504 .66476 L F
.42455 .66627 m .42436 .66858 L .42346 .66624 L F
.543 .39 .623 r
.42684 .66457 m .42436 .66858 L .42455 .66627 L F
.4 .783 .991 r
.53347 .71756 m .53249 .71842 L .53127 .71771 L F
.53347 .71756 m .53479 .71824 L .53249 .71842 L F
.465 .541 .85 r
.35202 .70602 m .35075 .70769 L .35023 .70614 L F
.408 .46 .802 r
.35202 .70602 m .35311 .70906 L .35075 .70769 L F
.699 .712 .858 r
.40352 .78065 m .40686 .78101 L .40499 .77862 L F
.634 .38 .517 r
.40686 .78101 m .40898 .78306 L .40929 .78089 L F
.424 .373 .697 r
.40729 .78306 m .40898 .78306 L .40686 .78101 L F
.704 .713 .856 r
.40499 .77862 m .40686 .78101 L .40797 .77791 L F
.851 .681 .672 r
.31064 .7241 m .30935 .72862 L .31239 .72631 L F
.156 .508 .912 r
.30221 .5984 m .30119 .59898 L .29989 .59794 L F
.30221 .5984 m .30342 .59974 L .30119 .59898 L F
.221 .006 .36 r
.29637 .73174 m .29752 .73208 L .29817 .72878 L F
.774 .699 .78 r
.29606 .73403 m .29752 .73208 L .29637 .73174 L F
.092 0 0 r
.56244 .67869 m .56565 .67673 L .56358 .67776 L F
0 0 .311 r
.73977 .59158 m .7403 .59408 L .73946 .59502 L F
.056 0 .354 r
.74066 .5912 m .7403 .59408 L .73977 .59158 L F
.289 .185 .559 r
.29817 .72878 m .30061 .72776 L .29997 .72517 L F
0 0 .261 r
.29817 .72878 m .29918 .73061 L .30061 .72776 L F
.29817 .72878 m .29752 .73208 L .29918 .73061 L F
.704 .522 .639 r
.69077 .58397 m .69369 .5842 L .69292 .58141 L F
.588 .452 .663 r
.69292 .58141 m .69586 .58347 L .69599 .58139 L F
.69292 .58141 m .69369 .5842 L .69586 .58347 L F
.793 .965 .655 r
.56484 .68888 m .56348 .69076 L .56492 .68879 L F
.622 .261 .337 r
.56484 .68888 m .56206 .69172 L .56348 .69076 L F
.56484 .68888 m .56456 .69195 L .56209 .69172 L F
.56484 .68888 m .56209 .69172 L .56206 .69172 L F
.793 .965 .655 r
.56484 .68888 m .56492 .68879 L .56556 .68791 L F
.255 0 .082 r
.49932 .71229 m .50232 .7101 L .49927 .71224 L F
.49932 .71229 m .50116 .71204 L .50232 .7101 L F
0 0 0 r
.50232 .7101 m .50286 .71085 L .50378 .70886 L F
.50232 .7101 m .50116 .71204 L .50286 .71085 L F
.345 .129 .435 r
.48374 .74305 m .48606 .73979 L .48607 .74291 L F
.547 .203 .337 r
.48374 .74305 m .48607 .74291 L .48575 .74451 L F
0 .192 .693 r
.48257 .74168 m .48374 .74305 L .48575 .74451 L F
.727 .472 .54 r
.49178 .73711 m .49204 .73993 L .4882 .73954 L F
.704 .454 .544 r
.49335 .73956 m .49204 .73993 L .49178 .73711 L F
.214 0 .114 r
.4825 .72402 m .48182 .72537 L .48448 .72317 L F
.482 .553 .852 r
.70391 .60499 m .70399 .6064 L .70618 .60474 L F
.478 .471 .772 r
.7046 .60739 m .70618 .60474 L .70399 .6064 L F
.01 0 0 r
.35805 .64909 m .35671 .64923 L .36014 .64899 L F
.164 0 .064 r
.59952 .71961 m .60235 .71736 L .59987 .71795 L F
.49 .456 .746 r
.30309 .69877 m .30403 .70166 L .30585 .70124 L F
.564 .472 .708 r
.30428 .70434 m .30585 .70124 L .30403 .70166 L F
.782 .659 .728 r
.59716 .72603 m .59309 .72563 L .59363 .72369 L F
.53 0 0 r
.59716 .72603 m .59496 .72676 L .59309 .72563 L F
.306 .173 .53 r
.59862 .72323 m .59865 .7256 L .59716 .72603 L F
.245 .749 .699 r
.59865 .7256 m .59496 .72676 L .59716 .72603 L F
.074 .218 .709 r
.56328 .73935 m .56261 .74067 L .56152 .73742 L F
0 .474 .866 r
.56437 .74084 m .56261 .74067 L .56328 .73935 L F
.56437 .74084 m .5657 .7419 L .56261 .74067 L F
.728 .452 .51 r
.60107 .65231 m .60319 .65474 L .60308 .6526 L F
.559 .342 .542 r
.52845 .74001 m .52622 .74252 L .52607 .74006 L F
.52845 .74001 m .52849 .74223 L .52622 .74252 L F
.541 .201 .341 r
.4496 .73348 m .45185 .73343 L .44998 .73196 L F
.544 .2 .336 r
.44998 .73196 m .45185 .73343 L .45238 .7319 L F
.619 .633 .843 r
.70719 .72601 m .70839 .72884 L .71076 .72821 L F
.74 .721 .192 r
.74264 .59634 m .74249 .5972 L .74241 .59787 L F
0 0 .06 r
.74241 .59787 m .74255 .59727 L .74264 .59634 L F
.485 .569 .865 r
.74264 .59634 m .74255 .59727 L .74249 .59719 L F
.74264 .59634 m .74249 .59719 L .7403 .59408 L F
.74 .721 .192 r
.74264 .59634 m .74252 .59693 L .74249 .5972 L F
.573 .135 .169 r
.74241 .59787 m .742 .59946 L .73965 .59891 L F
.135 .381 .836 r
.7403 .59408 m .74249 .59719 L .73946 .59502 L F
.74249 .59719 m .74255 .59727 L .74248 .59722 L F
.74249 .59719 m .74248 .59722 L .73946 .59502 L F
.74 .721 .192 r
.74252 .59693 m .742 .59946 L .74236 .59805 L F
0 .335 .818 r
.73946 .59502 m .74248 .59722 L .74241 .59787 L F
.74 .721 .192 r
.74248 .59722 m .74236 .59805 L .74241 .59787 L F
.74252 .59693 m .74236 .59805 L .74248 .59722 L F
0 .335 .818 r
.74248 .59722 m .74255 .59727 L .74241 .59787 L F
.528 .236 .414 r
.59785 .65504 m .60001 .65475 L .60107 .65231 L F
.728 .452 .51 r
.60107 .65231 m .60001 .65475 L .60319 .65474 L F
0 0 0 r
.34332 .72812 m .34209 .7287 L .34122 .72884 L F
.34209 .7287 m .33921 .73013 L .34122 .72884 L F
.139 0 0 r
.44689 .77551 m .45049 .77532 L .44819 .77526 L F
.855 .806 .801 r
.33027 .73391 m .33015 .73622 L .3305 .73634 L F
.689 .667 .823 r
.33027 .73391 m .3305 .73634 L .33331 .7345 L F
.497 .346 .605 r
.40945 .75643 m .41148 .75318 L .40912 .75345 L F
.751 .728 .831 r
.29537 .7273 m .29671 .72615 L .29441 .7259 L F
.931 .661 .504 r
.61496 .68503 m .61335 .6847 L .61326 .68209 L F
.937 .966 .699 r
.61496 .68503 m .61308 .68695 L .61335 .6847 L F
.61496 .68503 m .61339 .68786 L .61308 .68695 L F
.45 .27 .544 r
.31294 .67707 m .31461 .67885 L .31479 .67657 L F
.31294 .67707 m .31281 .67939 L .31461 .67885 L F
.403 .658 .963 r
.72579 .73264 m .72753 .73171 L .72528 .73191 L F
.72579 .73264 m .72925 .73343 L .72753 .73171 L F
.917 .652 .521 r
.70882 .58075 m .70957 .57871 L .70786 .57797 L F
.70882 .58075 m .70991 .58133 L .70957 .57871 L F
.347 .101 .392 r
.41297 .67969 m .41259 .68221 L .41055 .68256 L F
.29 0 .272 r
.41185 .68385 m .41055 .68256 L .41259 .68221 L F
.41185 .68385 m .41006 .68459 L .41055 .68256 L F
.465 .497 .807 r
.39664 .70096 m .39302 .69923 L .39614 .69832 L F
.39664 .70096 m .39677 .70157 L .39302 .69923 L F
.437 0 0 r
.47146 .75364 m .46827 .75346 L .46912 .75317 L F
.638 .498 .675 r
.47117 .75091 m .47146 .75364 L .46912 .75317 L F
.405 .201 .487 r
.28225 .62808 m .28386 .62954 L .28421 .62737 L F
.28225 .62808 m .28202 .63003 L .28386 .62954 L F
.552 .058 .038 r
.53479 .71824 m .53727 .7191 L .53817 .71808 L F
.998 .78 .451 r
.53727 .7191 m .53801 .72072 L .53817 .71808 L F
0 0 0 r
.33152 .65807 m .3316 .65862 L .33323 .65719 L F
.33152 .65807 m .32996 .65966 L .3316 .65862 L F
.31 .093 .414 r
.69586 .58347 m .69612 .58144 L .69599 .58139 L F
.549 .503 .756 r
.4197 .73708 m .4205 .73994 L .42255 .73944 L F
.519 .346 .586 r
.42041 .74159 m .42255 .73944 L .4205 .73994 L F
.813 .897 .902 r
.67754 .61454 m .67766 .61617 L .67996 .61381 L F
.703 .455 .547 r
.61791 .65733 m .62121 .65523 L .61779 .655 L F
.61791 .65733 m .62126 .65753 L .62121 .65523 L F
.742 .459 .5 r
.62333 .65705 m .62121 .65523 L .62126 .65753 L F
.432 0 0 r
.58908 .76328 m .59021 .762 L .5926 .76285 L F
.766 .479 .499 r
.52887 .78303 m .53232 .78346 L .53062 .78192 L F
.8 .659 .707 r
.53591 .76166 m .53317 .76391 L .53362 .76233 L F
.216 0 0 r
.51696 .79424 m .51689 .794 L .52034 .79209 L F
0 0 0 r
.51879 .79349 m .52034 .79209 L .5222 .7913 L F
.475 0 .029 r
.47312 .78327 m .47159 .78388 L .46959 .78374 L F
.527 .017 0 r
.47312 .78327 m .47387 .78472 L .47159 .78388 L F
.47312 .78327 m .47514 .78363 L .47387 .78472 L F
.571 .007 0 r
.52199 .74773 m .5207 .74712 L .51834 .74525 L F
.282 .336 .741 r
.51988 .74944 m .52103 .74958 L .52199 .74773 L F
.453 .301 .584 r
.52397 .7451 m .52401 .74772 L .52199 .74773 L F
.273 0 .14 r
.52199 .74773 m .5231 .74895 L .52401 .74772 L F
.52199 .74773 m .52103 .74958 L .5231 .74895 L F
.21 .686 .936 r
.52199 .74773 m .52401 .74772 L .5207 .74712 L F
.391 0 0 r
.37105 .64734 m .37369 .648 L .37491 .64769 L F
0 0 .106 r
.67863 .5855 m .6774 .58693 L .67708 .58869 L F
.29 .756 .945 r
.28335 .5967 m .28539 .59655 L .28707 .59699 L F
.072 .613 .849 r
.28539 .59655 m .28892 .59715 L .28707 .59699 L F
.424 0 0 r
.48287 .78535 m .48415 .78453 L .48664 .78517 L F
.327 .496 .873 r
.56008 .73378 m .55949 .73431 L .55731 .7311 L F
.855 .806 .801 r
.33027 .73391 m .32775 .73669 L .33015 .73622 L F
.449 .187 .423 r
.41448 .68174 m .41297 .67969 L .41507 .67918 L F
.41448 .68174 m .41259 .68221 L .41297 .67969 L F
0 .259 .766 r
.56232 .7477 m .56398 .74914 L .56084 .74763 L F
.164 0 .367 r
.61159 .74478 m .61185 .74728 L .60999 .74803 L F
.18 0 .359 r
.61185 .74728 m .60944 .74991 L .60999 .74803 L F
.592 .428 .628 r
.30309 .69877 m .3057 .69885 L .30533 .69609 L F
.49 .456 .746 r
.30309 .69877 m .30585 .70124 L .3057 .69885 L F
.667 .491 .638 r
.44114 .75635 m .44116 .75908 L .43903 .75857 L F
.448 .245 .511 r
.44333 .75346 m .44311 .75597 L .44114 .75635 L F
.528 .38 .623 r
.44338 .75843 m .44114 .75635 L .44311 .75597 L F
.44338 .75843 m .44116 .75908 L .44114 .75635 L F
.568 .454 .684 r
.30533 .69609 m .30711 .693 L .305 .69342 L F
.19 0 0 r
.3708 .71672 m .37228 .71506 L .37431 .71443 L F
.704 .425 .499 r
.55546 .69111 m .55219 .6919 L .5513 .69041 L F
.55546 .69111 m .55453 .69331 L .55219 .6919 L F
0 0 0 r
.55555 .69163 m .55546 .69111 L .55705 .69003 L F
.454 .539 .854 r
.72925 .73343 m .72965 .735 L .73122 .73335 L F
.531 .665 .922 r
.72965 .735 m .73205 .73505 L .73122 .73335 L F
.31 .093 .414 r
.69586 .58347 m .69807 .5829 L .69612 .58144 L F
.526 .92 .848 r
.70103 .57898 m .69612 .58144 L .69961 .57905 L F
.22 .113 .512 r
.69612 .58144 m .69807 .5829 L .69961 .57905 L F
.958 .75 .58 r
.31888 .73493 m .31993 .73409 L .31892 .73479 L F
.607 .248 .335 r
.32204 .73406 m .31892 .73479 L .31993 .73409 L F
.32204 .73406 m .32138 .73535 L .31892 .73479 L F
.32138 .73535 m .32087 .73633 L .31912 .73495 L F
.32138 .73535 m .31912 .73495 L .31892 .73479 L F
.791 .58 .616 r
.32432 .73392 m .32223 .73538 L .32204 .73406 L F
.787 .548 .574 r
.32087 .73633 m .32368 .7365 L .32205 .73538 L F
.791 .58 .616 r
.32205 .73538 m .32087 .73633 L .32138 .73535 L F
.787 .548 .574 r
.32087 .73633 m .32205 .73538 L .32144 .73495 L F
.791 .58 .616 r
.32223 .73538 m .32087 .73633 L .32205 .73538 L F
.32223 .73538 m .32138 .73535 L .32204 .73406 L F
.32223 .73538 m .32368 .7365 L .32087 .73633 L F
.32432 .73392 m .32377 .73615 L .32232 .73532 L F
.519 .656 .921 r
.32151 .73486 m .32553 .73487 L .32357 .73229 L F
.32144 .73495 m .32167 .73495 L .32151 .73486 L F
.32167 .73495 m .32553 .73487 L .32151 .73486 L F
.791 .58 .616 r
.32232 .73532 m .32368 .7365 L .32223 .73538 L F
.32377 .73615 m .32368 .7365 L .32232 .73532 L F
.545 .617 .875 r
.32205 .73538 m .3222 .73536 L .32144 .73495 L F
.3222 .73536 m .32553 .73487 L .32167 .73495 L F
.3222 .73536 m .32167 .73495 L .32144 .73495 L F
.32223 .7355 m .32273 .7354 L .32205 .73538 L F
.32273 .7354 m .32553 .73487 L .32205 .73538 L F
.32368 .7365 m .32439 .73588 L .32223 .7355 L F
.32439 .73588 m .32553 .73487 L .32223 .7355 L F
0 .204 .722 r
.31892 .73479 m .32087 .73633 L .31908 .73428 L F
.31892 .73479 m .31908 .73428 L .31899 .73417 L F
.958 .75 .58 r
.31656 .73675 m .31888 .73493 L .31892 .73479 L F
.514 .353 .6 r
.40807 .76179 m .4103 .764 L .41029 .7613 L F
.40807 .76179 m .40825 .76445 L .4103 .764 L F
.464 .198 .426 r
.40087 .69438 m .39891 .69335 L .40098 .69292 L F
.40087 .69438 m .39851 .69496 L .39891 .69335 L F
.817 .609 .621 r
.6112 .677 m .60794 .67912 L .60808 .67652 L F
.6112 .677 m .61093 .67979 L .60794 .67912 L F
.649 .621 .808 r
.53323 .74863 m .53091 .75051 L .52975 .74719 L F
.536 .42 .668 r
.53323 .74863 m .53307 .75048 L .53091 .75051 L F
.394 .306 .637 r
.53307 .75266 m .53091 .75051 L .53307 .75048 L F
.53307 .75266 m .53092 .75356 L .53091 .75051 L F
.743 .652 .76 r
.5229 .75346 m .52068 .75416 L .51955 .75322 L F
.416 .162 .419 r
.39851 .69496 m .39614 .69832 L .39643 .69557 L F
.342 .253 .607 r
.36529 .83283 m .3644 .83342 L .36595 .83527 L F
.648 .402 .532 r
.56842 .69023 m .57126 .69053 L .5715 .68806 L F
.712 .274 .209 r
.5715 .68806 m .57017 .6894 L .56793 .68753 L F
.541 .309 .512 r
.5715 .68806 m .57126 .69053 L .57348 .68972 L F
.513 .438 .709 r
.55079 .74412 m .55136 .74593 L .54993 .7456 L F
.551 .269 .44 r
.55136 .74593 m .55014 .74739 L .54993 .7456 L F
.026 .209 .716 r
.29826 .71549 m .29928 .71487 L .29799 .71467 L F
.29826 .71549 m .30088 .71817 L .29928 .71487 L F
.4 .848 .916 r
.31008 .73438 m .31113 .73454 L .31323 .73398 L F
.141 .29 .756 r
.73805 .71502 m .73819 .71759 L .7362 .71524 L F
.73805 .71502 m .73944 .71913 L .73819 .71759 L F
.053 0 .35 r
.61348 .74189 m .61313 .74415 L .61159 .74478 L F
.228 .086 .471 r
.61313 .74415 m .61185 .74728 L .61159 .74478 L F
.796 .322 .104 r
.45635 .77426 m .45806 .77649 L .45924 .77588 L F
.459 0 0 r
.45806 .77649 m .46133 .77638 L .45924 .77588 L F
.903 .763 .698 r
.57348 .68972 m .57594 .68787 L .57503 .68683 L F
.57348 .68972 m .57498 .69071 L .57594 .68787 L F
.512 .09 .177 r
.46321 .72964 m .46529 .7304 L .46653 .72872 L F
.483 .041 .121 r
.46529 .7304 m .46882 .72884 L .46653 .72872 L F
.347 .737 .985 r
.42959 .7361 m .42839 .73666 L .42747 .73425 L F
.42959 .7361 m .43087 .73686 L .42839 .73666 L F
.536 .329 .547 r
.33735 .69879 m .33727 .70171 L .33503 .70198 L F
.356 .244 .587 r
.33914 .69546 m .33859 .69872 L .33735 .69879 L F
.537 .33 .547 r
.33938 .7011 m .33735 .69879 L .33859 .69872 L F
.33938 .7011 m .33727 .70171 L .33735 .69879 L F
.091 0 0 r
.60473 .71204 m .60673 .71164 L .60769 .71004 L F
0 0 0 r
.60769 .71004 m .60673 .71164 L .60856 .70867 L F
.13 0 .26 r
.56697 .68793 m .56556 .68791 L .56793 .68753 L F
.56697 .68793 m .56484 .68888 L .56556 .68791 L F
.468 .4 .697 r
.4882 .73954 m .48854 .74245 L .48606 .73979 L F
.551 .413 .646 r
.48606 .73979 m .48854 .74245 L .48607 .74291 L F
.882 .66 .597 r
.62904 .66844 m .62918 .66611 L .62746 .66539 L F
.307 .367 .762 r
.48025 .73986 m .48257 .74168 L .48084 .74082 L F
.377 .015 .217 r
.38934 .70452 m .38653 .70626 L .38718 .70498 L F
.966 .684 .445 r
.57602 .70915 m .57671 .71089 L .57798 .71192 L F
0 0 .25 r
.57798 .71192 m .57743 .7154 L .57909 .71282 L F
.57784 .71282 m .57808 .71434 L .57743 .7154 L F
.57798 .71192 m .57808 .71434 L .57784 .71282 L F
.723 .214 0 r
.57702 .71409 m .57821 .71518 L .57808 .71434 L F
.344 .37 .744 r
.57915 .71603 m .57864 .7174 L .57808 .71434 L F
.723 .214 0 r
.57821 .71518 m .57915 .71603 L .57808 .71434 L F
.966 .684 .445 r
.57671 .71089 m .57808 .71434 L .57798 .71192 L F
0 0 .25 r
.57798 .71192 m .57909 .71282 L .57944 .71227 L F
.48 .211 .427 r
.57864 .7174 m .57743 .7154 L .57808 .71434 L F
.57864 .7174 m .57705 .71776 L .57743 .7154 L F
.49 .503 .797 r
.40626 .76744 m .40899 .76909 L .40813 .76623 L F
.564 .489 .729 r
.40626 .76744 m .4069 .76963 L .40899 .76909 L F
.362 .734 .988 r
.27323 .60514 m .27199 .60382 L .27028 .6039 L F
.27323 .60514 m .27358 .60462 L .27199 .60382 L F
0 0 0 r
.54123 .69572 m .543 .69245 L .54138 .69344 L F
0 0 .397 r
.62117 .70303 m .62047 .70171 L .62161 .70092 L F
.62117 .70303 m .62053 .70415 L .62047 .70171 L F
.234 0 .239 r
.46329 .74539 m .46126 .74764 L .46215 .74581 L F
.514 .555 .835 r
.41635 .66206 m .41576 .66504 L .41406 .66291 L F
0 .139 .669 r
.56706 .72335 m .56807 .72645 L .5685 .72526 L F
.926 .57 .334 r
.57092 .72816 m .5685 .72526 L .56844 .72667 L F
.57092 .72816 m .56944 .72766 L .5685 .72526 L F
0 0 .505 r
.5685 .72526 m .56944 .72766 L .56854 .72451 L F
.5685 .72526 m .56854 .72451 L .56825 .72353 L F
.926 .57 .334 r
.56844 .72667 m .5685 .72526 L .56807 .72645 L F
.355 .783 .971 r
.57028 .69851 m .57232 .69819 L .57424 .69882 L F
.947 .657 .455 r
.57424 .69882 m .57232 .69819 L .57028 .69851 L F
.57424 .69882 m .57405 .70072 L .57232 .69819 L F
.509 .855 .994 r
.57424 .69882 m .57232 .69819 L .57477 .6977 L F
.947 .657 .455 r
.57232 .69819 m .57424 .69882 L .57477 .6977 L F
.57232 .69819 m .57405 .70072 L .57424 .69882 L F
0 0 .247 r
.57438 .74546 m .57471 .74647 L .57468 .74477 L F
.57438 .74546 m .57499 .74844 L .57471 .74647 L F
.399 .439 .786 r
.41285 .65952 m .41242 .66292 L .41066 .66013 L F
.41285 .65952 m .41406 .66291 L .41242 .66292 L F
.926 .949 .613 r
.62895 .68393 m .62748 .68723 L .62768 .68783 L F
.13 0 .26 r
.56697 .68793 m .56593 .68966 L .56484 .68888 L F
.142 0 .243 r
.56593 .68966 m .56456 .69195 L .56484 .68888 L F
.962 .633 .26 r
.55426 .74613 m .55327 .74601 L .55136 .74593 L F
.597 .547 .769 r
.4069 .76963 m .41014 .77238 L .40899 .76909 L F
.236 .464 .875 r
.71928 .61184 m .72042 .61402 L .72187 .61315 L F
.321 .651 .97 r
.72042 .61402 m .72324 .6144 L .72187 .61315 L F
.648 .89 .983 r
.4268 .78812 m .42802 .78874 L .43026 .78759 L F
.814 .341 0 r
.55915 .74155 m .5585 .74139 L .55841 .74023 L F
.296 .352 .751 r
.55886 .73738 m .55841 .74023 L .56063 .73878 L F
0 0 .004 r
.55841 .74023 m .5585 .74139 L .56063 .73878 L F
0 0 0 r
.36988 .70427 m .37044 .70485 L .37179 .70332 L F
.36988 .70427 m .36855 .70601 L .37044 .70485 L F
.519 .306 .531 r
.41709 .67872 m .4153 .67699 L .41751 .67663 L F
.41709 .67872 m .41507 .67918 L .4153 .67699 L F
.387 0 .141 r
.3607 .6738 m .35699 .67624 L .35761 .67489 L F
.3607 .6738 m .35915 .67586 L .35699 .67624 L F
.564 .196 .303 r
.36274 .67377 m .35915 .67586 L .3607 .6738 L F
.243 .492 .894 r
.5591 .74697 m .55939 .74547 L .5567 .74594 L F
.466 .887 .796 r
.34991 .72601 m .34941 .72658 L .351 .7254 L F
.34991 .72601 m .34737 .72723 L .34941 .72658 L F
.546 .543 .802 r
.54956 .7336 m .55123 .73202 L .54953 .73145 L F
.54956 .7336 m .55242 .73447 L .55123 .73202 L F
.454 .25 .512 r
.4451 .75544 m .44333 .75346 L .44558 .75321 L F
.4451 .75544 m .44311 .75597 L .44333 .75346 L F
.279 0 .226 r
.29132 .64654 m .29408 .64418 L .29324 .64563 L F
.297 .062 .379 r
.29552 .64327 m .29408 .64418 L .29622 .64134 L F
.34 .069 .348 r
.29552 .64327 m .29324 .64563 L .29408 .64418 L F
.258 .301 .716 r
.56262 .71506 m .56333 .71856 L .56465 .71708 L F
.379 .486 .843 r
.56528 .72042 m .56465 .71708 L .56333 .71856 L F
.343 0 0 r
.45135 .75105 m .44984 .75245 L .44756 .75272 L F
.752 .507 .561 r
.45339 .75021 m .44984 .75245 L .45135 .75105 L F
.543 .387 .62 r
.53092 .75356 m .53147 .75656 L .52915 .7568 L F
.231 0 0 r
.53212 .72793 m .53374 .7283 L .53031 .72782 L F
0 .509 .724 r
.53155 .72799 m .53077 .72787 L .53031 .72782 L F
.091 0 0 r
.53212 .72793 m .53031 .72782 L .52949 .72772 L F
0 .509 .724 r
.53077 .72787 m .5296 .72769 L .53031 .72782 L F
.091 0 0 r
.52949 .72772 m .53031 .72782 L .52834 .72763 L F
.74 .442 .476 r
.60319 .65474 m .60655 .65679 L .60651 .65521 L F
0 .118 .668 r
.52366 .70628 m .52501 .70921 L .52391 .70738 L F
.063 0 0 r
.54187 .73339 m .54103 .73367 L .53796 .73388 L F
.529 .507 .776 r
.31688 .60621 m .31974 .60787 L .3178 .60829 L F
.511 .38 .638 r
.31974 .60787 m .31817 .61099 L .3178 .60829 L F
.484 .414 .703 r
.41353 .78677 m .41489 .78305 L .41244 .78345 L F
.41353 .78677 m .41577 .7868 L .41489 .78305 L F
.467 .524 .833 r
.41353 .78677 m .41671 .78827 L .41577 .7868 L F
.681 .577 .732 r
.53688 .74458 m .53949 .74197 L .53803 .74303 L F
.432 .288 .584 r
.30878 .68547 m .31045 .68689 L .31071 .68467 L F
.30878 .68547 m .30867 .68778 L .31045 .68689 L F
.296 0 0 r
.51909 .70555 m .52 .70586 L .52136 .70569 L F
.38 0 0 r
.52 .70586 m .52366 .70628 L .52136 .70569 L F
.757 .422 .418 r
.52 .70586 m .52193 .7085 L .52366 .70628 L F
.099 .228 .71 r
.52096 .70494 m .52133 .70632 L .52 .70586 L F
.52133 .70632 m .52193 .7085 L .52 .70586 L F
.296 0 0 r
.51777 .70548 m .52 .70586 L .51909 .70555 L F
.743 .728 .837 r
.57156 .70411 m .57009 .70639 L .56771 .70383 L F
.558 .237 .382 r
.59207 .65923 m .59524 .65661 L .59289 .6571 L F
.568 .454 .684 r
.30533 .69609 m .30757 .69581 L .30711 .693 L F
.587 .424 .628 r
.30533 .69609 m .30779 .69842 L .30757 .69581 L F
.30533 .69609 m .3057 .69885 L .30779 .69842 L F
.725 .358 .354 r
.52026 .72883 m .51905 .73084 L .51689 .72865 L F
.657 .278 .315 r
.52026 .72883 m .52248 .73076 L .51905 .73084 L F
.558 .445 .681 r
.41525 .74266 m .41778 .7445 L .41748 .7422 L F
.41525 .74266 m .41557 .74497 L .41778 .7445 L F
.202 0 0 r
.36835 .67141 m .36696 .67311 L .36494 .67374 L F
.605 .451 .646 r
.41331 .74763 m .41559 .7477 L .41557 .74497 L F
.538 .424 .672 r
.41331 .74763 m .41585 .74974 L .41559 .7477 L F
.41331 .74763 m .41381 .7503 L .41585 .74974 L F
.738 .274 .15 r
.53248 .78564 m .53456 .78758 L .53563 .78641 L F
.687 .203 0 r
.53644 .78797 m .53563 .78641 L .53456 .78758 L F
.102 0 0 r
.53644 .78797 m .5351 .78888 L .53653 .78854 L F
.687 .203 0 r
.53644 .78797 m .53731 .78876 L .53636 .78743 L F
.102 0 0 r
.53644 .78797 m .53653 .78854 L .53749 .78832 L F
.687 .203 0 r
.53644 .78797 m .53636 .78743 L .53563 .78641 L F
.402 .116 .36 r
.29132 .64654 m .29091 .64912 L .28886 .64975 L F
.317 .046 .334 r
.29263 .6483 m .29132 .64654 L .29324 .64563 L F
.29263 .6483 m .29091 .64912 L .29132 .64654 L F
.535 .391 .632 r
.61015 .72888 m .60884 .73129 L .60863 .72896 L F
.765 .322 .199 r
.49315 .7862 m .49186 .78657 L .49014 .78534 L F
.665 .183 .096 r
.49315 .7862 m .49383 .78813 L .49186 .78657 L F
.49315 .7862 m .49546 .78785 L .49383 .78813 L F
.407 .205 .491 r
.28669 .62229 m .2881 .62407 L .28844 .62167 L F
.28669 .62229 m .28634 .62483 L .2881 .62407 L F
.018 .515 .871 r
.42178 .66526 m .4207 .66547 L .4196 .66481 L F
.42178 .66526 m .42346 .66624 L .4207 .66547 L F
.271 .132 .501 r
.31943 .7275 m .31791 .72863 L .31783 .72732 L F
.234 .314 .742 r
.47193 .74951 m .47117 .75091 L .47018 .74784 L F
.734 .52 .603 r
.4668 .74999 m .47097 .75123 L .47018 .74784 L F
.856 .656 .631 r
.47016 .75269 m .47146 .75364 L .47117 .75091 L F
.634 .8 .363 r
.47158 .75015 m .47021 .7526 L .47117 .75091 L F
.47021 .7526 m .47016 .75269 L .47018 .75266 L F
.47021 .7526 m .47018 .75266 L .47117 .75091 L F
.456 .35 .645 r
.47018 .74784 m .47104 .7511 L .47193 .74951 L F
.634 .8 .363 r
.47193 .74951 m .47103 .75112 L .47158 .75015 L F
.456 .35 .645 r
.47104 .7511 m .47108 .75127 L .47193 .74951 L F
.634 .8 .363 r
.47103 .75112 m .47016 .75269 L .47158 .75015 L F
.49 .389 .667 r
.47108 .75127 m .47016 .75269 L .47103 .75112 L F
.734 .52 .603 r
.47103 .75112 m .47108 .75127 L .47104 .7511 L F
.49 .389 .667 r
.47108 .75127 m .47103 .75112 L .47193 .74951 L F
.734 .52 .603 r
.47097 .75123 m .47108 .75127 L .47103 .75112 L F
.47097 .75123 m .47104 .7511 L .47018 .74784 L F
.616 .481 .675 r
.47117 .75091 m .4743 .75156 L .47338 .75061 L F
.47117 .75091 m .47146 .75364 L .4743 .75156 L F
.58 .457 .677 r
.47338 .75061 m .47146 .75364 L .47117 .75091 L F
.427 .035 .191 r
.51834 .74525 m .51485 .7474 L .51498 .74494 L F
.696 .362 .407 r
.5207 .74712 m .51901 .74947 L .51701 .74732 L F
.906 .535 .317 r
.51901 .74947 m .51792 .74809 L .51701 .74732 L F
.427 .035 .191 r
.51834 .74525 m .51701 .74732 L .51615 .7466 L F
.671 .302 .338 r
.5207 .74712 m .51701 .74732 L .51834 .74525 L F
.906 .535 .317 r
.51792 .74809 m .51657 .74637 L .51701 .74732 L F
.427 .035 .191 r
.51615 .7466 m .51701 .74732 L .51485 .7474 L F
.195 0 .262 r
.60473 .71204 m .6044 .71435 L .60673 .71164 L F
.902 .744 .676 r
.62825 .67903 m .62925 .68209 L .63003 .68003 L F
.629 .827 .976 r
.5253 .76439 m .52142 .76384 L .52448 .76273 L F
.773 .75 .832 r
.52781 .76176 m .5253 .76439 L .52448 .76273 L F
.651 .542 .718 r
.52781 .76176 m .52758 .7642 L .5253 .76439 L F
.58 .449 .666 r
.52789 .76686 m .5253 .76439 L .52758 .7642 L F
.52789 .76686 m .5257 .76726 L .5253 .76439 L F
.694 .512 .638 r
.52622 .74252 m .52654 .74493 L .52397 .7451 L F
.497 .324 .576 r
.52849 .74223 m .52654 .74493 L .52622 .74252 L F
.275 .395 .804 r
.43861 .76648 m .44022 .76699 L .4375 .76642 L F
.43861 .76648 m .43803 .76878 L .44022 .76699 L F
.43861 .76648 m .43961 .76903 L .43803 .76878 L F
.315 .314 .7 r
.43961 .76903 m .44028 .77169 L .43803 .76878 L F
.358 .124 .416 r
.29622 .64134 m .29843 .63859 L .29776 .6405 L F
.353 .115 .408 r
.29552 .64327 m .29622 .64134 L .29776 .6405 L F
.437 .063 .23 r
.35761 .67489 m .35699 .67624 L .35491 .67648 L F
.4 .519 .862 r
.58083 .75796 m .58092 .75929 L .58245 .75794 L F
.345 .423 .799 r
.58092 .75929 m .58349 .76102 L .58245 .75794 L F
.397 0 0 r
.46619 .78416 m .46283 .78469 L .46401 .78404 L F
.22 .011 .369 r
.3023 .70729 m .30366 .70834 L .30446 .70687 L F
.3023 .70729 m .30194 .70942 L .30366 .70834 L F
.852 .974 .869 r
.72204 .59668 m .72226 .59772 L .7246 .59525 L F
0 0 .444 r
.72374 .59868 m .72226 .59772 L .72204 .59668 L F
.72374 .59868 m .72238 .60013 L .72226 .59772 L F
.418 .215 .496 r
.30256 .63073 m .3038 .62899 L .3045 .62943 L F
.469 .3 .568 r
.30363 .63119 m .30256 .63073 L .3045 .62943 L F
.30363 .63119 m .3021 .63313 L .30256 .63073 L F
.693 .551 .689 r
.52721 .73435 m .52527 .7349 L .52497 .73709 L F
.623 .784 .959 r
.69215 .60302 m .69333 .60129 L .69105 .60198 L F
.69215 .60302 m .69446 .60235 L .69333 .60129 L F
.174 0 0 r
.44116 .75908 m .43764 .76082 L .43903 .75857 L F
.523 .518 .792 r
.31031 .72218 m .31064 .7241 L .3089 .72305 L F
.549 .503 .756 r
.4197 .73708 m .42255 .73944 L .42188 .73663 L F
.682 .727 .884 r
.47181 .74241 m .4772 .7424 L .47145 .74246 L F
.47454 .74203 m .47564 .74218 L .47181 .74241 L F
.47564 .74218 m .4772 .7424 L .47181 .74241 L F
.68 .375 .452 r
.4772 .7424 m .47127 .74438 L .47145 .74246 L F
.4772 .7424 m .47349 .7448 L .47127 .74438 L F
.49 .1 .227 r
.47654 .74394 m .47349 .7448 L .4772 .7424 L F
.607 .237 .314 r
.4773 .74208 m .47883 .74389 L .47673 .74228 L F
.48084 .74082 m .48012 .74191 L .4773 .74208 L F
.48012 .74191 m .47883 .74389 L .4773 .74208 L F
.553 .176 .281 r
.48144 .74366 m .48084 .74082 L .48257 .74168 L F
.48144 .74366 m .47883 .74389 L .48084 .74082 L F
.412 .208 .491 r
.55979 .69447 m .55829 .69348 L .56052 .69304 L F
.55979 .69447 m .55814 .69573 L .55829 .69348 L F
.404 .293 .614 r
.53363 .75453 m .53092 .75356 L .53307 .75266 L F
.53363 .75453 m .53147 .75656 L .53092 .75356 L F
.316 0 .117 r
.57286 .67063 m .57476 .67102 L .57569 .66914 L F
.257 0 .09 r
.57569 .66914 m .57689 .6703 L .57783 .66852 L F
.57569 .66914 m .57476 .67102 L .57689 .6703 L F
.778 .62 .684 r
.54357 .74043 m .54262 .74273 L .54508 .7396 L F
.564 .148 .212 r
.52309 .78487 m .52533 .78503 L .52658 .78315 L F
.32 0 .008 r
.52533 .78503 m .52887 .78303 L .52658 .78315 L F
.431 .126 .344 r
.5755 .6854 m .57503 .68683 L .57405 .68582 L F
.573 .241 .368 r
.56131 .69834 m .56536 .69598 L .56133 .69611 L F
.56131 .69834 m .56375 .6983 L .56536 .69598 L F
.685 .375 .444 r
.56536 .69598 m .56375 .6983 L .5672 .69777 L F
.263 .249 .655 r
.61065 .73658 m .61239 .7387 L .6108 .74019 L F
.378 .435 .794 r
.6108 .74019 m .61239 .7387 L .61348 .74189 L F
.92 .747 .651 r
.46347 .75658 m .4615 .75607 L .46282 .75387 L F
.834 .39 .173 r
.4615 .75607 m .46206 .75729 L .46347 .75658 L F
.92 .747 .651 r
.46282 .75387 m .46347 .75658 L .4662 .75427 L F
.46282 .75387 m .4615 .75607 L .46347 .75658 L F
.834 .39 .173 r
.4615 .75607 m .46206 .75729 L .46347 .75658 L F
.667 .642 .816 r
.34075 .70384 m .33876 .70478 L .33727 .70171 L F
.71 .816 .931 r
.67499 .58857 m .67182 .58899 L .67431 .58818 L F
.466 .292 .56 r
.31486 .6742 m .31666 .67605 L .31684 .67377 L F
.31486 .6742 m .31479 .67657 L .31666 .67605 L F
.755 .266 .072 r
.73288 .62687 m .73342 .62582 L .73077 .62416 L F
.73288 .62687 m .7344 .62695 L .73342 .62582 L F
.902 .63 .515 r
.59801 .73696 m .59611 .73674 L .59626 .73412 L F
.85 .71 .708 r
.59749 .73879 m .59611 .73674 L .59801 .73696 L F
.269 .047 .382 r
.3846 .6934 m .38414 .69543 L .38614 .69266 L F
.36 .148 .451 r
.6139 .7149 m .61365 .71753 L .61181 .71799 L F
.371 .251 .584 r
.61365 .71753 m .61219 .72037 L .61181 .71799 L F
.583 .819 .989 r
.713 .72813 m .71401 .72906 L .7163 .72848 L F
.636 .553 .744 r
.40929 .78089 m .41168 .78089 L .41096 .77789 L F
.756 .594 .676 r
.40898 .78306 m .41168 .78089 L .40929 .78089 L F
.316 .427 .816 r
.52648 .70933 m .52914 .7112 L .52703 .71178 L F
.173 .133 .568 r
.52927 .7133 m .52703 .71178 L .52914 .7112 L F
.52927 .7133 m .52771 .71544 L .52703 .71178 L F
.727 .491 .57 r
.54631 .74756 m .54454 .74466 L .54651 .74562 L F
.197 .597 .945 r
.55866 .7119 m .55846 .71117 L .5554 .70997 L F
.55866 .7119 m .55943 .71213 L .55846 .71117 L F
.299 .098 .431 r
.29843 .63859 m .30039 .63569 L .29996 .63759 L F
.593 .431 .631 r
.29996 .63759 m .29776 .6405 L .29843 .63859 L F
.507 .298 .53 r
.52497 .73709 m .52711 .73662 L .52721 .73435 L F
.52497 .73709 m .52711 .73662 L .52721 .73435 L F
.556 .338 .539 r
.52721 .73435 m .52711 .73662 L .52947 .73415 L F
.472 .245 .488 r
.57944 .71227 m .58175 .70969 L .57857 .7095 L F
.57944 .71227 m .582 .71195 L .58175 .70969 L F
.606 .34 .487 r
.582 .71195 m .58396 .71176 L .58175 .70969 L F
.009 0 .023 r
.70899 .72022 m .71071 .71959 L .71142 .71772 L F
0 0 0 r
.70899 .72022 m .70885 .72065 L .71071 .71959 L F
.853 .544 .464 r
.49037 .74798 m .48854 .74853 L .48932 .74705 L F
.49037 .74798 m .48936 .75019 L .48854 .74853 L F
.016 0 .057 r
.49176 .74787 m .49037 .74798 L .48932 .74705 L F
.49176 .74787 m .48936 .75019 L .49037 .74798 L F
.594 .436 .637 r
.307 .69063 m .30941 .69266 L .30891 .69035 L F
.307 .69063 m .30711 .693 L .30941 .69266 L F
.419 .224 .507 r
.3038 .62899 m .30691 .62481 L .3066 .62703 L F
.5 .347 .605 r
.3066 .62703 m .3045 .62943 L .3038 .62899 L F
.918 .621 .467 r
.3258 .73731 m .32406 .73867 L .32368 .7365 L F
.575 .891 .619 r
.32636 .73656 m .3258 .73731 L .32775 .73669 L F
.32636 .73656 m .32406 .73867 L .3258 .73731 L F
.78 .819 .884 r
.71366 .61337 m .71485 .61456 L .71692 .61311 L F
.156 0 0 r
.36634 .64772 m .36765 .64765 L .36801 .64665 L F
.36634 .64772 m .36566 .64819 L .36765 .64765 L F
.028 0 0 r
.57163 .67229 m .57476 .67102 L .57286 .67063 L F
.514 .24 .437 r
.42251 .6717 m .42204 .67363 L .41984 .67399 L F
.536 .352 .578 r
.42421 .67085 m .42204 .67363 L .42251 .6717 L F
0 0 0 r
.71142 .71772 m .71292 .71682 L .7141 .71609 L F
.71142 .71772 m .71071 .71959 L .71292 .71682 L F
.296 .548 .92 r
.39362 .65204 m .39284 .65328 L .3915 .65232 L F
.39362 .65204 m .39533 .65412 L .39284 .65328 L F
.164 .671 .904 r
.29093 .59722 m .29241 .5977 L .28892 .59715 L F
.431 .822 .986 r
.29298 .59682 m .29241 .5977 L .29093 .59722 L F
.29298 .59682 m .29441 .59733 L .29241 .5977 L F
.785 .546 .575 r
.62511 .66495 m .6275 .66334 L .62481 .66292 L F
.62511 .66495 m .62746 .66539 L .6275 .66334 L F
.526 0 0 r
.54146 .72341 m .54375 .72459 L .54419 .72436 L F
.653 .112 0 r
.54376 .72459 m .5469 .72555 L .54478 .72404 L F
.54375 .72459 m .54378 .7246 L .54376 .72459 L F
.54378 .7246 m .5469 .72555 L .54376 .72459 L F
.094 .544 .909 r
.54698 .725 m .54807 .72581 L .54517 .7252 L F
.754 .29 .146 r
.54375 .72459 m .54503 .72517 L .5469 .72555 L F
.094 .544 .909 r
.54509 .72516 m .54517 .7252 L .54503 .72517 L F
.54698 .725 m .54517 .7252 L .54509 .72516 L F
.608 .056 0 r
.54297 .7238 m .54503 .72517 L .54375 .72459 L F
.54297 .7238 m .5437 .72443 L .5446 .72493 L F
.54453 .72484 m .5446 .72493 L .54503 .72517 L F
.54297 .7238 m .5446 .72493 L .54453 .72484 L F
.526 0 0 r
.54382 .72386 m .54419 .72436 L .54478 .72404 L F
.54146 .72341 m .54419 .72436 L .54382 .72386 L F
.914 .793 .713 r
.57857 .7095 m .57798 .71192 L .57944 .71227 L F
.505 .375 .637 r
.57944 .71227 m .58188 .71459 L .582 .71195 L F
.411 .179 .45 r
.6139 .7149 m .61617 .71232 L .61539 .71396 L F
.455 .227 .477 r
.61568 .71695 m .6139 .7149 L .61539 .71396 L F
.61568 .71695 m .61365 .71753 L .6139 .7149 L F
.757 .282 .115 r
.31688 .60621 m .31405 .60469 L .31582 .60483 L F
.357 .514 .876 r
.31779 .6047 m .31688 .60621 L .31582 .60483 L F
.31779 .6047 m .31974 .60787 L .31688 .60621 L F
.691 .206 0 r
.51268 .7943 m .51349 .79566 L .51108 .794 L F
.51268 .7943 m .51478 .79703 L .51349 .79566 L F
.774 .69 .771 r
.57126 .69053 m .56928 .69312 L .57244 .69343 L F
.76 .684 .778 r
.57126 .69053 m .57244 .69343 L .57498 .69071 L F
.687 .691 .848 r
.7246 .59525 m .72792 .59582 L .72673 .59431 L F
.702 .682 .828 r
.72673 .59431 m .72792 .59582 L .73005 .59495 L F
.599 .67 .89 r
.39391 .67154 m .396 .67108 L .39449 .66905 L F
.545 .365 .588 r
.39391 .67154 m .39617 .67355 L .396 .67108 L F
.416 .363 .691 r
.39446 .67402 m .39617 .67355 L .39391 .67154 L F
.574 .2 .294 r
.51617 .74168 m .51939 .74063 L .51996 .73884 L F
.389 .228 .539 r
.51996 .73884 m .52157 .73923 L .521 .73716 L F
.517 .196 .362 r
.51939 .74063 m .52157 .73923 L .51996 .73884 L F
.389 .228 .539 r
.51996 .73884 m .52157 .73923 L .521 .73716 L F
.37 0 .121 r
.33799 .65463 m .34015 .65423 L .34134 .65251 L F
.299 0 .002 r
.34015 .65423 m .34353 .65236 L .34134 .65251 L F
.118 0 0 r
.35931 .72133 m .35788 .72284 L .35633 .72284 L F
.002 0 0 r
.35969 .72204 m .35931 .72133 L .36137 .72073 L F
.35969 .72204 m .35788 .72284 L .35931 .72133 L F
.588 .938 .935 r
.34659 .82899 m .346 .83 L .34472 .82992 L F
.34659 .82899 m .346 .83 L .34472 .82992 L F
0 0 0 r
.59778 .66544 m .59419 .66777 L .59487 .66631 L F
.59778 .66544 m .59719 .66602 L .59419 .66777 L F
.457 .863 .962 r
.59997 .66573 m .59719 .66602 L .59778 .66544 L F
.689 .563 .707 r
.68845 .58454 m .68853 .58703 L .69077 .58397 L F
.657 .518 .683 r
.68853 .58703 m .69164 .58707 L .69077 .58397 L F
.429 .717 .985 r
.68989 .58584 m .68853 .58703 L .68751 .58595 L F
.602 .252 .349 r
.69114 .58731 m .69164 .58707 L .68853 .58703 L F
.429 .717 .985 r
.68989 .58584 m .69114 .58731 L .68853 .58703 L F
.693 .339 .372 r
.4642 .77507 m .46603 .77417 L .46513 .77551 L F
.58 .258 .389 r
.52305 .73901 m .52711 .73662 L .52497 .73709 L F
0 0 .531 r
.56901 .70004 m .56776 .69919 L .56912 .69774 L F
.56901 .70004 m .56831 .7015 L .56776 .69919 L F
.591 .615 .844 r
.67701 .60237 m .67419 .60003 L .6765 .59971 L F
.78 .746 .822 r
.6794 .59998 m .67701 .60237 L .6765 .59971 L F
.583 .236 .347 r
.43619 .73846 m .43975 .73626 L .43664 .73733 L F
.598 .478 .686 r
.34056 .69026 m .33844 .6908 L .33863 .68967 L F
.438 .282 .571 r
.34056 .69026 m .3388 .69304 L .33844 .6908 L F
.465 .4 .7 r
.55086 .72788 m .55123 .73202 L .54953 .73145 L F
.009 0 0 r
.5504 .73162 m .54953 .73145 L .55123 .73202 L F
.5504 .73162 m .54788 .7329 L .54953 .73145 L F
.281 .602 .952 r
.52578 .70823 m .52501 .70921 L .52366 .70628 L F
.52578 .70823 m .52648 .70933 L .52501 .70921 L F
.505 0 0 r
.71647 .71692 m .7141 .71609 L .71613 .71641 L F
.503 .548 .835 r
.71876 .71506 m .71647 .71692 L .71613 .71641 L F
.71876 .71506 m .71918 .71778 L .71647 .71692 L F
.598 .478 .686 r
.34056 .69026 m .33863 .68967 L .34046 .68851 L F
.507 .144 .285 r
.3819 .70943 m .38105 .71168 L .3788 .71172 L F
.338 .08 .367 r
.38431 .70678 m .38282 .70975 L .3819 .70943 L F
.369 .015 .227 r
.38311 .71115 m .3819 .70943 L .38282 .70975 L F
.38311 .71115 m .38105 .71168 L .3819 .70943 L F
.268 .771 .87 r
.72349 .58117 m .72656 .58093 L .72434 .58113 L F
.485 .71 .969 r
.38393 .65114 m .38033 .64989 L .3824 .64944 L F
.539 .691 .938 r
.38437 .64914 m .38393 .65114 L .3824 .64944 L F
.38437 .64914 m .3861 .65091 L .38393 .65114 L F
0 0 .571 r
.5657 .7419 m .56714 .74412 L .56691 .74523 L F
0 0 .252 r
.56761 .74641 m .56691 .74523 L .56714 .74412 L F
.56761 .74641 m .56686 .74769 L .56691 .74523 L F
.623 .708 .907 r
.55731 .7311 m .55513 .73177 L .55316 .72943 L F
.564 .472 .708 r
.30428 .70434 m .30639 .70398 L .30585 .70124 L F
.562 .409 .631 r
.30428 .70434 m .30649 .70638 L .30639 .70398 L F
.30428 .70434 m .30446 .70687 L .30649 .70638 L F
.219 .496 .901 r
.31228 .60266 m .31065 .60223 L .30889 .60009 L F
.798 .906 .916 r
.35695 .83437 m .35855 .83503 L .35642 .83499 L F
.35642 .83499 m .35855 .83503 L .35695 .83437 L F
.258 .716 .953 r
.36036 .83497 m .35855 .83503 L .35695 .83437 L F
.35695 .83437 m .35855 .83503 L .36036 .83497 L F
.762 .969 .685 r
.7141 .71609 m .71439 .71485 L .71613 .71641 L F
.7141 .71609 m .71292 .71682 L .71439 .71485 L F
.768 .681 .766 r
.73082 .60245 m .7292 .60547 L .73222 .60565 L F
.772 .661 .741 r
.7292 .60547 m .73031 .60858 L .73222 .60565 L F
.792 .801 .859 r
.72547 .61117 m .72816 .61132 L .72668 .61027 L F
.839 .795 .81 r
.72668 .61027 m .72816 .61132 L .73031 .60858 L F
0 0 0 r
.58264 .67458 m .58181 .67617 L .58016 .67695 L F
.58272 .67509 m .58264 .67458 L .58442 .67358 L F
.58272 .67509 m .58181 .67617 L .58264 .67458 L F
.77 .906 .514 r
.57899 .67844 m .57853 .67982 L .58016 .67695 L F
0 0 0 r
.57899 .67844 m .57782 .68194 L .57853 .67982 L F
.347 0 .163 r
.37898 .69834 m .38103 .69788 L .38213 .69594 L F
.283 0 .128 r
.38213 .69594 m .38293 .69737 L .38414 .69543 L F
.38213 .69594 m .38103 .69788 L .38293 .69737 L F
.379 .486 .843 r
.56528 .72042 m .56623 .72009 L .56465 .71708 L F
.431 0 0 r
.46959 .78374 m .47036 .785 L .46815 .7846 L F
.46959 .78374 m .47159 .78388 L .47036 .785 L F
.261 .692 .964 r
.39533 .65412 m .39659 .65401 L .3971 .65481 L F
.11 .524 .912 r
.39769 .65418 m .3971 .65481 L .39659 .65401 L F
.722 .326 .299 r
.52887 .78303 m .53111 .78519 L .53232 .78346 L F
.947 .66 .463 r
.53111 .78519 m .53248 .78564 L .53232 .78346 L F
.412 .055 .245 r
.59487 .66631 m .59419 .66777 L .5921 .66823 L F
.362 .104 .382 r
.38572 .70879 m .38431 .70678 L .38653 .70626 L F
.38572 .70879 m .38282 .70975 L .38431 .70678 L F
.74 .62 .725 r
.46282 .75387 m .4662 .75427 L .46543 .75062 L F
.545 .49 .745 r
.46543 .75062 m .4662 .75427 L .46827 .75346 L F
0 0 .034 r
.6234 .69779 m .62161 .70092 L .62237 .69906 L F
.432 .044 .201 r
.47647 .72812 m .4787 .72782 L .47974 .72588 L F
.297 0 .131 r
.47974 .72588 m .48073 .72725 L .48182 .72537 L F
.47974 .72588 m .4787 .72782 L .48073 .72725 L F
.981 .691 .372 r
.7302 .6017 m .73064 .60025 L .72829 .59962 L F
.7302 .6017 m .73082 .60245 L .73064 .60025 L F
.585 .454 .668 r
.41559 .7477 m .41778 .7445 L .41557 .74497 L F
.299 0 .041 r
.48895 .72015 m .49105 .71977 L .49228 .71806 L F
.346 0 .08 r
.49105 .71977 m .49451 .71761 L .49228 .71806 L F
.283 .536 .915 r
.55017 .72593 m .55086 .72788 L .54784 .72655 L F
.55057 .72608 m .55086 .72788 L .55017 .72593 L F
.439 .693 .973 r
.55191 .72647 m .55086 .72788 L .55053 .72584 L F
.717 .188 0 r
.54904 .72585 m .55118 .72723 L .55021 .7265 L F
.439 .693 .973 r
.55191 .72647 m .55273 .72768 L .55086 .72788 L F
.631 .526 .717 r
.55316 .72943 m .55086 .72788 L .55273 .72768 L F
.717 .188 0 r
.55118 .72723 m .5526 .72814 L .55021 .7265 L F
.479 0 0 r
.54968 .72611 m .55021 .7265 L .55168 .72648 L F
.54807 .72581 m .55021 .7265 L .54968 .72611 L F
.55144 .72639 m .55168 .72648 L .55191 .72647 L F
.54807 .72581 m .55168 .72648 L .55144 .72639 L F
.283 .536 .915 r
.55053 .72584 m .55057 .72608 L .55017 .72593 L F
.106 0 .324 r
.61788 .70921 m .61796 .71131 L .61617 .71232 L F
.358 .232 .569 r
.61796 .71131 m .61539 .71396 L .61617 .71232 L F
.3 .057 .368 r
.31917 .66866 m .31698 .6714 L .31884 .67091 L F
.568 .421 .641 r
.31684 .67377 m .31884 .67091 L .31698 .6714 L F
.101 .473 .894 r
.50583 .79088 m .50637 .79021 L .50449 .78989 L F
.606 .079 0 r
.50637 .79021 m .50473 .78994 L .50449 .78989 L F
.50473 .78994 m .50332 .7897 L .50449 .78989 L F
.688 .142 0 r
.50225 .78853 m .50427 .78985 L .50449 .78989 L F
.50427 .78985 m .50583 .79088 L .50449 .78989 L F
.101 .473 .894 r
.50583 .79088 m .50759 .79166 L .50637 .79021 L F
.544 .256 .428 r
.4419 .73661 m .44416 .73645 L .4446 .73458 L F
.553 .278 .452 r
.44416 .73645 m .44686 .73428 L .4446 .73458 L F
.526 .275 .478 r
.34711 .68192 m .34469 .68415 L .34498 .68223 L F
.529 .476 .742 r
.611 .731 m .60966 .73502 L .60884 .73129 L F
.611 .731 m .61228 .73413 L .60966 .73502 L F
.5 .392 .663 r
.60966 .73502 m .61237 .73817 L .61065 .73658 L F
.60966 .73502 m .61228 .73413 L .61237 .73817 L F
.219 .391 .821 r
.41671 .78827 m .41699 .7895 L .41821 .78899 L F
.296 .789 .756 r
.41821 .78899 m .41699 .7895 L .41921 .78878 L F
0 .502 .75 r
.30545 .59939 m .30889 .60009 L .30728 .59982 L F
.484 .245 .477 r
.34193 .6881 m .34187 .68629 L .34275 .68505 L F
.34193 .6881 m .34046 .68851 L .34187 .68629 L F
.393 .598 .928 r
.31582 .60483 m .31405 .60469 L .31228 .60266 L F
.497 .346 .605 r
.40945 .75643 m .41157 .75596 L .41148 .75318 L F
.443 .346 .651 r
.40999 .75874 m .41157 .75596 L .40945 .75643 L F
.615 .519 .723 r
.38536 .67178 m .38766 .67144 L .38711 .6684 L F
.519 .199 .365 r
.38536 .67178 m .38743 .67272 L .38766 .67144 L F
.38536 .67178 m .38743 .67272 L .38766 .67144 L F
.581 .399 .6 r
.49915 .73697 m .49933 .7395 L .49697 .73976 L F
.487 .329 .592 r
.5013 .73892 m .49933 .7395 L .49915 .73697 L F
.566 0 0 r
.7046 .60739 m .70783 .60862 L .70674 .60845 L F
.478 .471 .772 r
.7046 .60739 m .70674 .60845 L .70618 .60474 L F
.578 .544 .78 r
.40968 .65686 m .40852 .66057 L .40747 .65732 L F
.40968 .65686 m .41066 .66013 L .40852 .66057 L F
.622 .556 .76 r
.74003 .71977 m .74077 .7231 L .73842 .72297 L F
.708 .451 .534 r
.74104 .72553 m .73842 .72297 L .74077 .7231 L F
.74104 .72553 m .73739 .72553 L .73842 .72297 L F
.682 .873 .485 r
.57994 .67676 m .58016 .67695 L .58181 .67617 L F
.742 .41 .419 r
.57658 .67902 m .57816 .67926 L .57898 .67727 L F
0 0 0 r
.57849 .67993 m .57843 .68052 L .57782 .68194 L F
.57899 .67844 m .57843 .68052 L .57849 .67993 L F
.58005 .67954 m .57836 .68114 L .57843 .68052 L F
.57797 .68259 m .57782 .68194 L .57843 .68052 L F
.995 .835 .569 r
.57843 .68052 m .57735 .6821 L .57797 .68259 L F
0 0 0 r
.57836 .68114 m .57735 .6821 L .57843 .68052 L F
.215 .173 .593 r
.57898 .67727 m .57843 .68052 L .57899 .67844 L F
.682 .873 .485 r
.57998 .6768 m .57899 .67844 L .58016 .67695 L F
.57973 .67713 m .57899 .67844 L .57998 .6768 L F
.731 .928 .956 r
.57898 .67727 m .57899 .67844 L .57994 .67676 L F
.215 .173 .593 r
.57898 .67727 m .58005 .67954 L .57843 .68052 L F
.742 .41 .419 r
.57816 .67926 m .58005 .67954 L .57923 .67781 L F
.57816 .67926 m .57923 .67781 L .57898 .67727 L F
.682 .873 .485 r
.57994 .67676 m .57973 .67713 L .57998 .6768 L F
.54 .184 .312 r
.30833 .73062 m .30609 .73097 L .30663 .72923 L F
.235 .576 .942 r
.26931 .59347 m .26891 .59448 L .26766 .59319 L F
.31 .662 .973 r
.26931 .59347 m .27078 .59463 L .26891 .59448 L F
.608 .274 .379 r
.42411 .73616 m .42635 .73613 L .42747 .73425 L F
.642 .313 .4 r
.42635 .73613 m .42959 .7361 L .42747 .73425 L F
0 0 .465 r
.51014 .78935 m .51158 .79119 L .51168 .79124 L F
0 0 0 r
.51168 .79124 m .51158 .79119 L .51108 .794 L F
.938 .726 .589 r
.72889 .60732 m .73031 .60858 L .7292 .60547 L F
.839 .795 .81 r
.72668 .61027 m .73031 .60858 L .72889 .60732 L F
.78 .564 .608 r
.61449 .65699 m .61779 .655 L .61429 .65493 L F
.61449 .65699 m .61791 .65733 L .61779 .655 L F
.688 .536 .675 r
.69077 .58397 m .69366 .58624 L .69369 .5842 L F
.69077 .58397 m .69164 .58707 L .69366 .58624 L F
.8 .659 .707 r
.53591 .76166 m .53648 .76433 L .53317 .76391 L F
.693 .44 .535 r
.53307 .76636 m .53074 .76411 L .53317 .76391 L F
.53307 .76636 m .53091 .76673 L .53074 .76411 L F
.533 0 0 r
.53636 .76431 m .53484 .76448 L .53317 .76391 L F
.878 .943 .854 r
.53412 .76322 m .53317 .76391 L .53505 .76455 L F
.53412 .76322 m .53307 .76636 L .53317 .76391 L F
.53366 .7646 m .53212 .76573 L .53307 .76636 L F
.53412 .76322 m .53296 .76468 L .53366 .7646 L F
.53296 .76468 m .53212 .76573 L .53366 .7646 L F
.533 0 0 r
.53648 .76433 m .53505 .76455 L .53484 .76448 L F
.53648 .76433 m .53484 .76448 L .53636 .76431 L F
.459 .364 .661 r
.53724 .75852 m .53801 .76104 L .53591 .76166 L F
0 0 .511 r
.53853 .75992 m .53801 .76104 L .53748 .75931 L F
.53853 .75992 m .53748 .75931 L .53724 .75852 L F
.416 .013 .164 r
.54062 .75924 m .5391 .76025 L .53853 .75992 L F
.931 .757 .644 r
.53736 .76098 m .53801 .76104 L .53853 .75992 L F
.416 .013 .164 r
.5391 .76025 m .53728 .76146 L .53853 .75992 L F
0 .08 .604 r
.53721 .76299 m .53591 .76166 L .53801 .76104 L F
.931 .757 .644 r
.536 .76221 m .53696 .76165 L .53736 .76098 L F
.53696 .76165 m .53801 .76104 L .53736 .76098 L F
0 .08 .604 r
.53721 .76299 m .53648 .76433 L .53619 .76296 L F
.53656 .76233 m .53619 .76296 L .53591 .76166 L F
.53721 .76299 m .53619 .76296 L .53656 .76233 L F
.695 .978 .905 r
.53721 .76299 m .53505 .76455 L .53648 .76433 L F
.848 .855 .848 r
.50753 .71982 m .50882 .72332 L .5092 .72168 L F
.50753 .71982 m .50628 .72259 L .50882 .72332 L F
.54 .856 .56 r
.5092 .72168 m .50829 .72247 L .50981 .72092 L F
.38 .79 .981 r
.50767 .72318 m .50628 .72259 L .5032 .72263 L F
.641 .162 .1 r
.50392 .72398 m .50882 .72332 L .5032 .72263 L F
.54 .856 .56 r
.50829 .72247 m .50718 .72345 L .50883 .72187 L F
.50829 .72247 m .50883 .72187 L .50981 .72092 L F
.38 .79 .981 r
.50882 .72332 m .50781 .72302 L .50767 .72318 L F
.50781 .72302 m .50628 .72259 L .50767 .72318 L F
.418 .2 .474 r
.50621 .72467 m .50757 .72629 L .50754 .72606 L F
.641 .162 .1 r
.50535 .72378 m .50621 .72467 L .50882 .72332 L F
.725 .982 .774 r
.50882 .72332 m .50621 .72467 L .50718 .72345 L F
.418 .2 .474 r
.50621 .72467 m .50754 .72606 L .50718 .72345 L F
.641 .162 .1 r
.50392 .72398 m .50621 .72467 L .50535 .72378 L F
.725 .982 .774 r
.50882 .72332 m .50718 .72345 L .5092 .72168 L F
.583 .236 .347 r
.43619 .73846 m .43838 .73858 L .43975 .73626 L F
.498 .097 .211 r
.43838 .73858 m .4419 .73661 L .43975 .73626 L F
.406 .049 .242 r
.49469 .72841 m .49327 .73095 L .49142 .73113 L F
.691 .356 .404 r
.49671 .73074 m .49327 .73095 L .49469 .72841 L F
.563 .357 .559 r
.72642 .72053 m .72397 .72351 L .72443 .72079 L F
.72642 .72053 m .72633 .72309 L .72397 .72351 L F
.314 0 .09 r
.46919 .74288 m .46782 .74481 L .46591 .74527 L F
.571 .174 .251 r
.47127 .74438 m .46782 .74481 L .46919 .74288 L F
.509 .217 .406 r
.47145 .74246 m .47127 .74438 L .46919 .74288 L F
.89 .478 .064 r
.58774 .74374 m .58781 .74278 L .5862 .74144 L F
.58774 .74374 m .58883 .74489 L .58781 .74278 L F
0 0 0 r
.59771 .75861 m .60059 .75669 L .59943 .75819 L F
.59943 .75819 m .60059 .75669 L .60238 .75567 L F
.755 .994 .867 r
.55661 .68254 m .55331 .68501 L .55423 .68331 L F
0 0 0 r
.55661 .68254 m .55635 .68274 L .55741 .6815 L F
.55661 .68254 m .55423 .68331 L .55635 .68274 L F
.113 0 0 r
.35788 .72284 m .35515 .72407 L .35633 .72284 L F
.87 .806 .785 r
.67914 .61098 m .68064 .61212 L .68159 .61045 L F
.91 .783 .708 r
.67914 .61098 m .67996 .61381 L .68064 .61212 L F
0 0 0 r
.59771 .75861 m .59943 .75819 L .59594 .7604 L F
.709 .385 .428 r
.49697 .73976 m .49369 .74159 L .49335 .73956 L F
.49697 .73976 m .49585 .74186 L .49369 .74159 L F
.624 .339 .464 r
.49933 .7395 m .49585 .74186 L .49697 .73976 L F
.412 0 .011 r
.53146 .73604 m .5345 .73583 L .53613 .73418 L F
.376 .101 .363 r
.40757 .77511 m .41001 .77466 L .41014 .77238 L F
.432 .496 .825 r
.41014 .77238 m .41052 .7693 L .40899 .76909 L F
.41014 .77238 m .41181 .77207 L .41052 .7693 L F
.719 .381 .405 r
.41014 .77238 m .41001 .77466 L .41214 .77453 L F
.413 .366 .696 r
.41014 .77238 m .41214 .77453 L .41181 .77207 L F
.41014 .77238 m .41214 .77453 L .41181 .77207 L F
.497 .264 .49 r
.51955 .75322 m .52165 .75526 L .52025 .75149 L F
.51955 .75322 m .51972 .75633 L .52165 .75526 L F
.47 .248 .493 r
.32114 .66817 m .31917 .66866 L .31884 .67091 L F
.207 .733 .823 r
.44166 .78631 m .44256 .78597 L .44043 .78636 L F
.44166 .78631 m .44378 .786 L .44256 .78597 L F
.87 .806 .785 r
.67914 .61098 m .68159 .61045 L .68071 .6095 L F
.831 .91 .892 r
.68159 .61045 m .68321 .60725 L .68071 .6095 L F
.68159 .61045 m .68421 .60813 L .68321 .60725 L F
.502 .082 .176 r
.51208 .78834 m .51579 .78652 L .51278 .78805 L F
.51208 .78834 m .5142 .78845 L .51579 .78652 L F
.42 0 .121 r
.51579 .78652 m .51705 .78761 L .51784 .78595 L F
.51579 .78652 m .5142 .78845 L .51705 .78761 L F
.401 .151 .415 r
.31598 .6137 m .31533 .61629 L .31361 .6163 L F
.544 .38 .61 r
.31817 .61099 m .31729 .61299 L .31598 .6137 L F
.399 .143 .406 r
.31729 .61299 m .31533 .61629 L .31598 .6137 L F
.449 0 0 r
.47514 .78363 m .476 .78486 L .47387 .78472 L F
.47514 .78363 m .47738 .78397 L .476 .78486 L F
.76 .684 .778 r
.57126 .69053 m .57498 .69071 L .57348 .68972 L F
.796 .693 .751 r
.47016 .75269 m .46827 .75346 L .47146 .75364 L F
.579 .417 .626 r
.4743 .75156 m .47367 .7537 L .47146 .75364 L F
.58 .457 .677 r
.47338 .75061 m .47367 .7537 L .47146 .75364 L F
.129 .066 .511 r
.69369 .5842 m .69493 .58483 L .69586 .58347 L F
.69369 .5842 m .69366 .58624 L .69493 .58483 L F
.074 .508 .899 r
.55943 .71213 m .56004 .71165 L .55846 .71117 L F
.084 .524 .904 r
.55943 .71213 m .561 .71258 L .56004 .71165 L F
.674 .215 0 r
.54365 .70113 m .54136 .698 L .54171 .69927 L F
0 .462 .799 r
.50591 .78605 m .50074 .78436 L .5035 .78513 L F
.222 0 0 r
.5035 .78513 m .50074 .78436 L .50044 .78437 L F
.592 .808 .982 r
.71977 .58058 m .71888 .58236 L .71748 .58089 L F
.71977 .58058 m .72115 .58174 L .71888 .58236 L F
.587 .108 .084 r
.47937 .78531 m .48061 .78408 L .48287 .78535 L F
.436 .014 .138 r
.34914 .64972 m .35064 .65039 L .35131 .64953 L F
.34914 .64972 m .34765 .65162 L .35064 .65039 L F
.452 .136 .338 r
.48607 .74291 m .48788 .74419 L .48575 .74451 L F
.48607 .74291 m .48854 .74245 L .48788 .74419 L F
.826 .744 .223 r
.59626 .73412 m .59628 .73367 L .59664 .73107 L F
0 0 .099 r
.59626 .73412 m .59651 .73543 L .59628 .73367 L F
.59626 .73412 m .59611 .73674 L .59651 .73543 L F
0 .455 .711 r
.36801 .64665 m .36962 .64699 L .37105 .64734 L F
.551 .549 .805 r
.39446 .67402 m .39756 .6767 L .39617 .67355 L F
.743 .449 0 r
.7344 .62695 m .73517 .62979 L .7354 .63032 L F
.935 .602 .379 r
.73444 .63192 m .7354 .63032 L .73517 .62979 L F
.73444 .63192 m .73591 .63249 L .7354 .63032 L F
.365 .046 .284 r
.32371 .66325 m .32106 .66554 L .32323 .66529 L F
.376 .128 .405 r
.32551 .66262 m .32371 .66325 L .32323 .66529 L F
.492 .314 .567 r
.31073 .68214 m .31265 .68177 L .31281 .67939 L F
.535 .398 .64 r
.31071 .68467 m .31265 .68177 L .31073 .68214 L F
.95 .894 .503 r
.67158 .61114 m .67065 .61415 L .67072 .61205 L F
.905 .962 .815 r
.67339 .60851 m .67158 .61114 L .67153 .60937 L F
.94 .901 .507 r
.67153 .60937 m .67158 .61114 L .67072 .61205 L F
.298 .091 .421 r
.38849 .68757 m .38651 .69048 L .38817 .68966 L F
.292 .091 .427 r
.38651 .69048 m .38795 .69188 L .38817 .68966 L F
.38651 .69048 m .38614 .69266 L .38795 .69188 L F
.824 .57 .555 r
.61326 .68209 m .61132 .68408 L .61145 .68163 L F
.61326 .68209 m .61335 .6847 L .61132 .68408 L F
.159 0 .291 r
.59664 .73107 m .59875 .73037 L .59942 .72786 L F
0 0 .114 r
.59628 .73367 m .59875 .73037 L .59664 .73107 L F
.438 .282 .571 r
.34056 .69026 m .34057 .69264 L .3388 .69304 L F
.368 .27 .611 r
.34048 .69485 m .3388 .69304 L .34057 .69264 L F
.34048 .69485 m .33914 .69546 L .3388 .69304 L F
.49 .6 .89 r
.28377 .61043 m .28371 .60767 L .28203 .60809 L F
.28377 .61043 m .28567 .61042 L .28371 .60767 L F
0 0 0 r
.2791 .65495 m .28056 .65449 L .27834 .6556 L F
.328 .766 .967 r
.40043 .65582 m .40398 .6562 L .40206 .65661 L F
.522 .752 .98 r
.69446 .60235 m .69772 .60315 L .69678 .60181 L F
.586 .684 .908 r
.69772 .60315 m .69864 .60153 L .69678 .60181 L F
.69772 .60315 m .70008 .60266 L .69864 .60153 L F
.72 .908 .961 r
.35619 .70872 m .35743 .70691 L .35903 .70771 L F
.526 .845 .999 r
.36087 .70724 m .35903 .70771 L .35743 .70691 L F
.439 .56 .881 r
.67501 .59211 m .67807 .59525 L .67714 .59378 L F
.902 .881 .803 r
.67714 .59378 m .67807 .59525 L .67642 .59742 L F
.52 .301 .522 r
.67642 .59742 m .67807 .59525 L .6789 .59706 L F
.76 .992 .789 r
.55331 .68501 m .55277 .68489 L .55423 .68331 L F
.441 .156 .382 r
.41778 .7445 m .42041 .74159 L .41748 .7422 L F
.41778 .7445 m .41976 .74411 L .42041 .74159 L F
.519 .346 .586 r
.42041 .74159 m .42243 .74138 L .42255 .73944 L F
.463 .172 .385 r
.41976 .74411 m .42243 .74138 L .42041 .74159 L F
.574 .843 .996 r
.44689 .77551 m .44482 .77621 L .44329 .77527 L F
.78 .819 .884 r
.71366 .61337 m .71692 .61311 L .71622 .61142 L F
.673 .817 .952 r
.71622 .61142 m .71692 .61311 L .71928 .61184 L F
.299 .088 .416 r
.31472 .6182 m .31361 .6163 L .31533 .61629 L F
.31472 .6182 m .31318 .61921 L .31361 .6163 L F
.475 .238 .475 r
.37457 .70152 m .37663 .70107 L .37702 .69881 L F
.449 .215 .466 r
.37702 .69881 m .37859 .70051 L .37898 .69834 L F
.37702 .69881 m .37663 .70107 L .37859 .70051 L F
.97 .654 .291 r
.56008 .73378 m .56072 .73737 L .56152 .73742 L F
.04 .207 .71 r
.56343 .73816 m .56328 .73935 L .56152 .73742 L F
.56343 .73816 m .56152 .73742 L .56072 .73737 L F
.338 0 .096 r
.58504 .66251 m .58699 .66259 L .58812 .66093 L F
.411 .065 .265 r
.58699 .66259 m .59 .66001 L .58812 .66093 L F
.443 .346 .651 r
.40999 .75874 m .4118 .75834 L .41157 .75596 L F
.473 .353 .636 r
.40999 .75874 m .41208 .76079 L .4118 .75834 L F
.40999 .75874 m .41029 .7613 L .41208 .76079 L F
.174 0 0 r
.44116 .75908 m .43963 .76043 L .43764 .76082 L F
0 0 0 r
.44245 .75835 m .44116 .75908 L .44338 .75843 L F
.44245 .75835 m .43963 .76043 L .44116 .75908 L F
.517 .698 .951 r
.72004 .731 m .72145 .72894 L .71844 .72864 L F
.72004 .731 m .72208 .73056 L .72145 .72894 L F
.784 .634 .695 r
.52654 .74493 m .52736 .74823 L .52401 .74772 L F
.68 .626 .789 r
.52854 .7444 m .52736 .74823 L .52654 .74493 L F
.52854 .7444 m .52975 .74719 L .52736 .74823 L F
.193 .519 .917 r
.5554 .70997 m .55619 .7091 L .55494 .7087 L F
.5554 .70997 m .55846 .71117 L .55619 .7091 L F
.474 .245 .485 r
.41351 .75264 m .41585 .74974 L .41381 .7503 L F
.466 .781 .998 r
.27828 .59536 m .27774 .59651 L .27604 .59515 L F
.27828 .59536 m .27983 .59628 L .27774 .59651 L F
.852 .974 .869 r
.72204 .59668 m .7246 .59525 L .72377 .59516 L F
.562 .932 .914 r
.72377 .59516 m .7246 .59525 L .72673 .59431 L F
.965 .716 .509 r
.49142 .73113 m .49108 .73323 L .49265 .73272 L F
.316 .464 .85 r
.67182 .58899 m .67313 .58757 L .67078 .58832 L F
.563 .867 .996 r
.67431 .58818 m .67182 .58899 L .67253 .58825 L F
.67431 .58818 m .67253 .58825 L .67313 .58757 L F
.316 .464 .85 r
.67182 .58899 m .67315 .58761 L .67313 .58757 L F
.563 .867 .996 r
.67253 .58825 m .67078 .58832 L .67313 .58757 L F
.316 .464 .85 r
.67253 .58825 m .67463 .59053 L .67315 .58761 L F
.67182 .58899 m .67187 .58901 L .67253 .58825 L F
.67187 .58901 m .67463 .59053 L .67253 .58825 L F
.563 .867 .996 r
.67253 .58825 m .67182 .58899 L .67078 .58832 L F
.412 .55 .885 r
.28043 .60821 m .28162 .60685 L .27851 .60615 L F
.28043 .60821 m .28203 .60809 L .28162 .60685 L F
.589 .606 .837 r
.53363 .75453 m .53212 .75786 L .53147 .75656 L F
.53363 .75453 m .53434 .75749 L .53212 .75786 L F
.595 .628 .854 r
.53521 .75906 m .53212 .75786 L .53434 .75749 L F
.719 .581 .7 r
.62463 .6603 m .62486 .65795 L .62333 .65705 L F
.108 0 0 r
.28425 .65251 m .28453 .65333 L .28246 .65361 L F
.28425 .65251 m .28631 .65191 L .28453 .65333 L F
.806 .692 .739 r
.31031 .72218 m .31293 .72038 L .31045 .7226 L F
0 0 0 r
.31459 .71846 m .31293 .72038 L .31516 .71758 L F
.583 .357 .538 r
.53074 .76411 m .52789 .76686 L .52758 .7642 L F
.289 0 .094 r
.33613 .65511 m .33715 .65596 L .33799 .65463 L F
.33613 .65511 m .33511 .65653 L .33715 .65596 L F
.615 .676 .885 r
.73349 .59756 m .73467 .59468 L .73233 .59457 L F
.73349 .59756 m .73787 .59727 L .73467 .59468 L F
.487 .308 .564 r
.3021 .63313 m .30189 .6349 L .30039 .63569 L F
.443 .227 .489 r
.30039 .63569 m .30141 .63678 L .29996 .63759 L F
.30039 .63569 m .30189 .6349 L .30141 .63678 L F
.689 .854 .961 r
.35619 .70872 m .35311 .70906 L .35488 .7083 L F
.72 .908 .961 r
.35619 .70872 m .35488 .7083 L .35743 .70691 L F
.362 .731 .988 r
.72505 .60009 m .72598 .60091 L .72238 .60013 L F
.544 .892 .981 r
.47018 .74784 m .47106 .74675 L .47239 .74717 L F
.234 .314 .742 r
.47193 .74951 m .47018 .74784 L .47239 .74717 L F
.456 .35 .645 r
.47018 .74784 m .47193 .74951 L .47106 .74675 L F
.525 .308 .528 r
.61237 .73817 m .61239 .7387 L .61065 .73658 L F
.553 .829 .997 r
.37092 .8705 m .36909 .8711 L .36743 .87024 L F
.37092 .8705 m .36909 .8711 L .36743 .87024 L F
0 0 0 r
.36087 .70724 m .36264 .70718 L .36448 .70707 L F
.069 0 0 r
.36264 .70718 m .36652 .70655 L .36448 .70707 L F
.527 .262 .456 r
.54454 .74466 m .54098 .7477 L .53977 .74476 L F
.54454 .74466 m .54308 .74746 L .54098 .7477 L F
.727 .491 .57 r
.54631 .74756 m .54308 .74746 L .54454 .74466 L F
.971 .655 .339 r
.56626 .73144 m .56537 .73137 L .56463 .72945 L F
.338 .601 .944 r
.56463 .72945 m .56736 .73042 L .56626 .73144 L F
.533 .921 .905 r
.56736 .73042 m .56537 .73137 L .56626 .73144 L F
.522 .246 .436 r
.5257 .76726 m .52529 .76922 L .52305 .76943 L F
.596 .355 .522 r
.52789 .76686 m .52529 .76922 L .5257 .76726 L F
0 .263 .704 r
.73051 .58296 m .73324 .5846 L .73274 .58453 L F
0 .262 .735 r
.73446 .58528 m .73274 .58453 L .73324 .5846 L F
.01 .429 .863 r
.73728 .58647 m .7353 .5862 L .73446 .58528 L F
0 .436 .849 r
.73538 .58548 m .73446 .58528 L .73391 .58537 L F
.73629 .58555 m .73728 .58647 L .73446 .58528 L F
.73629 .58555 m .73446 .58528 L .73538 .58548 L F
0 .262 .735 r
.73446 .58528 m .7353 .5862 L .73361 .5851 L F
.73446 .58528 m .73361 .5851 L .73274 .58453 L F
0 0 .422 r
.6094 .69567 m .61054 .69216 L .60989 .69336 L F
.778 .609 .67 r
.62127 .65996 m .62333 .65705 L .62126 .65753 L F
.62127 .65996 m .62463 .6603 L .62333 .65705 L F
.5 .034 .08 r
.45972 .73074 m .462 .73092 L .46321 .72964 L F
.507 .043 .085 r
.46321 .72964 m .462 .73092 L .46529 .7304 L F
.685 .702 .86 r
.72673 .59431 m .73005 .59495 L .7292 .59201 L F
.563 .508 .752 r
.73005 .59495 m .73128 .59131 L .7292 .59201 L F
.73005 .59495 m .73233 .59457 L .73128 .59131 L F
.19 .234 .678 r
.55278 .7439 m .55079 .74412 L .55145 .74156 L F
.55278 .7439 m .55136 .74593 L .55079 .74412 L F
.483 .041 .121 r
.46529 .7304 m .46747 .73054 L .46882 .72884 L F
.454 .009 .102 r
.46747 .73054 m .47109 .72883 L .46882 .72884 L F
.068 .333 .811 r
.56262 .71506 m .56324 .71421 L .561 .71258 L F
0 .228 .739 r
.56262 .71506 m .56465 .71708 L .56324 .71421 L F
.458 .575 .884 r
.35034 .7033 m .35023 .70614 L .34863 .70334 L F
.35034 .7033 m .35202 .70602 L .35023 .70614 L F
.525 .356 .595 r
.50352 .73129 m .50366 .73393 L .50135 .73417 L F
.473 .802 1 r
.29847 .59714 m .29799 .59825 L .2965 .5975 L F
.29847 .59714 m .29989 .59794 L .29799 .59825 L F
.796 .605 .644 r
.62126 .66233 m .62463 .6603 L .62127 .65996 L F
.62126 .66233 m .62481 .66292 L .62463 .6603 L F
.766 .606 .679 r
.53949 .74197 m .54262 .74273 L .54357 .74043 L F
.543 .39 .623 r
.42684 .66457 m .42639 .66838 L .42436 .66858 L F
.528 .32 .542 r
.42639 .66838 m .42421 .67085 L .42436 .66858 L F
.24 .559 .935 r
.36206 .85595 m .36305 .85716 L .36374 .85627 L F
.36206 .85595 m .36305 .85716 L .36374 .85627 L F
0 .153 .682 r
.57224 .73357 m .57363 .73703 L .57411 .73573 L F
0 0 .499 r
.57332 .73915 m .57411 .73573 L .57363 .73703 L F
.559 .242 .387 r
.45185 .73343 m .45523 .73073 L .45238 .7319 L F
.916 .737 .645 r
.62707 .6759 m .62903 .67437 L .62756 .67359 L F
.62707 .6759 m .62862 .67667 L .62903 .67437 L F
.107 .022 .467 r
.52039 .76681 m .52144 .7663 L .52142 .76384 L F
.682 .159 0 r
.52305 .76943 m .52204 .7689 L .52039 .76681 L F
.481 .735 .983 r
.52068 .76797 m .52246 .76922 L .5214 .76841 L F
.686 .146 0 r
.52039 .76681 m .5214 .76841 L .52068 .76797 L F
.481 .735 .983 r
.52068 .76797 m .5214 .76841 L .52087 .768 L F
.631 .933 .967 r
.52305 .76943 m .52155 .76957 L .52204 .7689 L F
.481 .735 .983 r
.52203 .76892 m .52155 .76957 L .52246 .76922 L F
.52068 .76797 m .52155 .76957 L .52203 .76892 L F
.631 .933 .967 r
.52204 .7689 m .52155 .76957 L .52154 .76864 L F
.686 .146 0 r
.5214 .76841 m .52154 .76864 L .52068 .76797 L F
.682 .159 0 r
.52204 .7689 m .52154 .76864 L .5214 .76841 L F
.52204 .7689 m .5214 .76841 L .52039 .76681 L F
.481 .735 .983 r
.52087 .768 m .52246 .76922 L .52397 .76863 L F
.686 .146 0 r
.52039 .76681 m .52068 .76797 L .52144 .7663 L F
.785 .734 .805 r
.6789 .59706 m .6794 .59998 L .6765 .59971 L F
.385 .109 .366 r
.28002 .63279 m .28112 .63452 L .28171 .63234 L F
.28002 .63279 m .27925 .6351 L .28112 .63452 L F
.199 .33 .773 r
.53374 .7283 m .5349 .73142 L .536 .73025 L F
.689 .586 .735 r
.5349 .73142 m .5373 .73268 L .536 .73025 L F
.784 .634 .695 r
.52654 .74493 m .52401 .74772 L .52397 .7451 L F
.342 .083 .369 r
.49932 .71229 m .49902 .7146 L .50116 .71204 L F
.774 .699 .78 r
.29606 .73403 m .29882 .73252 L .29752 .73208 L F
.29606 .73403 m .29696 .73414 L .29882 .73252 L F
.409 0 0 r
.29882 .73252 m .29918 .73061 L .29752 .73208 L F
.29882 .73252 m .29925 .73288 L .29918 .73061 L F
.284 0 .264 r
.3906 .68476 m .39257 .6842 L .39317 .68223 L F
.512 .188 .354 r
.39317 .68223 m .3946 .68383 L .39508 .68171 L F
.39317 .68223 m .39257 .6842 L .3946 .68383 L F
.24 0 0 r
.36879 .7172 m .36514 .7191 L .36677 .7178 L F
0 .22 .741 r
.5373 .73268 m .53858 .73276 L .536 .73025 L F
.447 .195 .439 r
.53621 .73506 m .53858 .73276 L .5373 .73268 L F
.558 .432 .665 r
.30891 .69035 m .31045 .68689 L .30867 .68778 L F
.051 .408 .86 r
.47868 .77675 m .47976 .777 L .47953 .77776 L F
.519 .088 .161 r
.48081 .7797 m .48115 .77805 L .47953 .77776 L F
.48081 .7797 m .47953 .77776 L .47976 .777 L F
.729 .427 .468 r
.61111 .65677 m .61449 .65699 L .61223 .65463 L F
.672 .437 .556 r
.61223 .65463 m .61449 .65699 L .61429 .65493 L F
.078 .515 .901 r
.27677 .60566 m .27699 .60494 L .27535 .60467 L F
.27677 .60566 m .27851 .60615 L .27699 .60494 L F
.459 .364 .661 r
.53724 .75852 m .53591 .76166 L .53521 .75906 L F
.5 .292 .529 r
.42173 .67568 m .41984 .67399 L .42204 .67363 L F
.42173 .67568 m .41965 .67619 L .41984 .67399 L F
.689 .225 .145 r
.55886 .73738 m .55523 .73623 L .55601 .73734 L F
.414 .214 .497 r
.30831 .62654 m .30691 .62481 L .30851 .62417 L F
.30831 .62654 m .3066 .62703 L .30691 .62481 L F
.068 .631 .748 r
.44647 .78592 m .44591 .7859 L .44378 .786 L F
.215 0 0 r
.44591 .7859 m .44643 .78625 L .44507 .78587 L F
.192 .719 .846 r
.44591 .7859 m .44468 .78576 L .44256 .78597 L F
.215 0 0 r
.44591 .7859 m .44507 .78587 L .44468 .78576 L F
.068 .631 .748 r
.44721 .7859 m .44591 .7859 L .44647 .78592 L F
.226 0 0 r
.44721 .7859 m .44812 .78628 L .44591 .7859 L F
.44721 .7859 m .44934 .78604 L .44812 .78628 L F
.545 .49 .745 r
.46543 .75062 m .46827 .75346 L .4668 .74999 L F
.81 .724 .77 r
.595 .72291 m .59182 .7227 L .59427 .72036 L F
.595 .72291 m .59363 .72369 L .59182 .7227 L F
.648 .514 .686 r
.59427 .72036 m .59772 .72055 L .595 .72291 L F
.782 .675 .746 r
.29643 .73493 m .29696 .73414 L .29606 .73403 L F
.21 .331 .769 r
.57443 .74233 m .57567 .74153 L .57332 .73915 L F
.513 .856 .994 r
.57468 .74477 m .57567 .74153 L .57443 .74233 L F
.694 .276 .249 r
.49887 .78822 m .50225 .78853 L .50068 .78983 L F
.564 0 0 r
.50225 .78853 m .50332 .7897 L .50068 .78983 L F
.50225 .78853 m .50449 .78989 L .50332 .7897 L F
.6 .563 .785 r
.43635 .76281 m .4375 .76642 L .43616 .76451 L F
.097 .198 .681 r
.4377 .76319 m .43861 .76648 L .4375 .76642 L F
.624 .674 .878 r
.72208 .73056 m .72296 .73246 L .72528 .73191 L F
.596 .103 .054 r
.55768 .69817 m .56131 .69834 L .55912 .6989 L F
.727 .351 .338 r
.53509 .7475 m .5383 .7478 L .5385 .75025 L F
.53509 .7475 m .53689 .74895 L .5351 .75005 L F
.53689 .74895 m .5385 .75025 L .53545 .75007 L F
.53689 .74895 m .53545 .75007 L .5351 .75005 L F
.658 .575 .75 r
.53977 .74476 m .54098 .7477 L .5383 .7478 L F
.569 .34 .529 r
.54098 .7477 m .5385 .75025 L .5383 .7478 L F
0 0 0 r
.53844 .74775 m .53647 .74962 L .53996 .74719 L F
.5383 .7478 m .53804 .74806 L .53844 .74775 L F
.53804 .74806 m .53647 .74962 L .53844 .74775 L F
.727 .351 .338 r
.53509 .7475 m .53647 .74962 L .5383 .7478 L F
.105 0 .38 r
.5383 .7478 m .53977 .74476 L .53688 .74458 L F
.5383 .7478 m .53996 .74719 L .53977 .74476 L F
.408 .661 .963 r
.33548 .73144 m .33718 .73121 L .33638 .73015 L F
.652 .93 .654 r
.33638 .73015 m .33391 .73269 L .33548 .73144 L F
.71 .304 .277 r
.33391 .73269 m .33754 .73341 L .33548 .73144 L F
.826 .632 .64 r
.60658 .67108 m .6081 .67418 L .60652 .67331 L F
.799 .597 .629 r
.6081 .67418 m .60497 .6759 L .60652 .67331 L F
.6081 .67418 m .60808 .67652 L .60497 .6759 L F
.111 .133 .603 r
.70882 .58075 m .70952 .58288 L .70991 .58133 L F
.156 .653 .913 r
.71256 .58179 m .7123 .58148 L .71316 .58189 L F
.70991 .58133 m .7123 .58148 L .71256 .58179 L F
.747 .994 .856 r
.7123 .58148 m .71092 .58178 L .71188 .58099 L F
.7123 .58148 m .71188 .58099 L .71357 .5796 L F
.56 .935 .845 r
.70952 .58288 m .7123 .58148 L .70991 .58133 L F
.498 .168 .339 r
.37179 .70332 m .37377 .70321 L .37457 .70152 L F
.403 .073 .289 r
.37457 .70152 m .37377 .70321 L .37663 .70107 L F
.497 .324 .576 r
.52849 .74223 m .52854 .7444 L .52654 .74493 L F
.559 .242 .387 r
.45185 .73343 m .45415 .73334 L .45523 .73073 L F
.559 .245 .392 r
.45415 .73334 m .45745 .73076 L .45523 .73073 L F
.882 .66 .597 r
.62904 .66844 m .62746 .66539 L .62595 .66803 L F
.81 .642 .674 r
.6283 .67084 m .62904 .66844 L .62595 .66803 L F
.398 .128 .384 r
.41006 .68459 m .40756 .68708 L .40811 .68517 L F
.478 .587 .884 r
.6728 .59906 m .67419 .60003 L .67317 .59931 L F
.988 .892 .62 r
.67419 .60003 m .67273 .60152 L .67317 .59931 L F
.147 .09 .53 r
.67273 .60152 m .67355 .59955 L .67317 .59931 L F
.67355 .59955 m .6742 .598 L .67317 .59931 L F
.478 .587 .884 r
.67059 .59751 m .6728 .59906 L .67317 .59931 L F
.988 .892 .62 r
.67419 .60003 m .67371 .60193 L .67273 .60152 L F
.659 .945 .959 r
.67419 .60003 m .67642 .59742 L .6765 .59971 L F
.533 .921 .819 r
.30999 .72663 m .30933 .72699 L .30946 .72747 L F
.691 .255 .208 r
.30833 .73062 m .30459 .73011 L .30609 .73097 L F
.30833 .73062 m .30708 .73105 L .30459 .73011 L F
.745 .674 .782 r
.30585 .72626 m .30708 .73105 L .30946 .72747 L F
.30585 .72626 m .30946 .72747 L .30652 .72849 L F
.533 .921 .819 r
.30933 .72699 m .30652 .72849 L .30946 .72747 L F
.792 .795 .301 r
.30946 .72747 m .30935 .72862 L .30956 .72787 L F
.30946 .72747 m .30956 .72787 L .31064 .7241 L F
.639 .739 .921 r
.31045 .7226 m .31064 .7241 L .31031 .72218 L F
.31045 .7226 m .31311 .72381 L .31064 .7241 L F
0 0 0 r
.31124 .72435 m .31064 .7241 L .31311 .72381 L F
.31124 .72435 m .30946 .72747 L .31064 .7241 L F
.773 .75 .832 r
.52672 .76208 m .52448 .76273 L .52707 .76159 L F
.287 0 0 r
.52448 .76273 m .52586 .76308 L .52707 .76159 L F
.489 .29 .536 r
.52586 .76308 m .52748 .76104 L .52707 .76159 L F
.964 .64 .339 r
.52781 .76176 m .52707 .76159 L .52629 .75856 L F
.278 .234 .628 r
.52629 .75856 m .52707 .76159 L .52809 .76027 L F
.489 .29 .536 r
.52748 .76104 m .52809 .76027 L .52707 .76159 L F
.773 .75 .832 r
.52781 .76176 m .52672 .76208 L .52707 .76159 L F
.331 .174 .512 r
.30408 .63459 m .3021 .63313 L .30363 .63119 L F
.30408 .63459 m .30189 .6349 L .3021 .63313 L F
.374 .452 .813 r
.74083 .71663 m .73944 .71913 L .73805 .71502 L F
.447 .486 .807 r
.74083 .71663 m .74003 .71977 L .73944 .71913 L F
.941 .61 .176 r
.56842 .69023 m .56928 .69312 L .56805 .68978 L F
.492 .724 .975 r
.56842 .69023 m .57017 .6894 L .56805 .68978 L F
.56842 .69023 m .57126 .69053 L .57017 .6894 L F
.292 .723 .969 r
.31098 .7307 m .31191 .73163 L .30833 .73062 L F
.31098 .7307 m .31191 .73163 L .30833 .73062 L F
.483 .364 .642 r
.31323 .73398 m .31427 .73103 L .31191 .73163 L F
.982 .754 .516 r
.6281 .68138 m .62925 .68209 L .62825 .67903 L F
.973 .763 .56 r
.62834 .68332 m .62925 .68209 L .6281 .68138 L F
.62834 .68332 m .62895 .68393 L .62925 .68209 L F
.919 .974 .769 r
.40757 .77511 m .40643 .77692 L .40797 .77791 L F
.40757 .77511 m .40499 .77862 L .40483 .77796 L F
.40757 .77511 m .40483 .77796 L .40643 .77692 L F
.802 .568 .584 r
.40757 .77511 m .40945 .77776 L .41001 .77466 L F
.40757 .77511 m .40797 .77791 L .40945 .77776 L F
.743 .991 .879 r
.72691 .71153 m .72326 .7135 L .72651 .71226 L F
.171 0 0 r
.72934 .71098 m .72691 .71153 L .72882 .71159 L F
.199 0 0 r
.72882 .71159 m .72691 .71153 L .72651 .71226 L F
.014 .425 .862 r
.73813 .58753 m .73614 .58726 L .7353 .5862 L F
.73813 .58753 m .73896 .58862 L .73614 .58726 L F
.139 0 0 r
.44689 .77551 m .44913 .77555 L .45049 .77532 L F
0 0 0 r
.45049 .77532 m .45117 .77538 L .45254 .77476 L F
.45049 .77532 m .44913 .77555 L .45117 .77538 L F
.289 .787 .859 r
.71135 .61384 m .71278 .61329 L .7106 .6126 L F
.71135 .61384 m .71366 .61337 L .71278 .61329 L F
.579 .739 .952 r
.33027 .73391 m .33331 .7345 L .33208 .7332 L F
.611 .752 .945 r
.33208 .7332 m .33331 .7345 L .33391 .73269 L F
.579 .717 .937 r
.33331 .7345 m .33553 .73415 L .33391 .73269 L F
.452 .678 .961 r
.73434 .71083 m .73293 .71212 L .73194 .71065 L F
.354 .506 .871 r
.73434 .71083 m .73581 .71373 L .73293 .71212 L F
.814 .909 .905 r
.68321 .60725 m .68421 .60813 L .68696 .60588 L F
.123 .658 .857 r
.43588 .78778 m .43169 .78747 L .43341 .78766 L F
.756 .594 .676 r
.40898 .78306 m .41244 .78345 L .41168 .78089 L F
.669 .574 .74 r
.41096 .77789 m .41168 .78089 L .4142 .78059 L F
.665 .542 .704 r
.41168 .78089 m .41244 .78345 L .4142 .78059 L F
.848 .757 .762 r
.67843 .61348 m .67996 .61381 L .67914 .61098 L F
.813 .897 .902 r
.67754 .61454 m .67996 .61381 L .67843 .61348 L F
.518 .625 .897 r
.34689 .70081 m .34656 .70346 L .34502 .70155 L F
.34689 .70081 m .34863 .70334 L .34656 .70346 L F
.082 0 .315 r
.61997 .70626 m .61941 .70842 L .61788 .70921 L F
.084 0 .319 r
.61941 .70842 m .61796 .71131 L .61788 .70921 L F
.219 .414 .841 r
.67172 .5965 m .67348 .59891 L .67059 .59751 L F
.205 .39 .825 r
.67059 .59751 m .67317 .59931 L .67172 .5965 L F
.617 .643 .854 r
.53724 .75852 m .53521 .75906 L .53434 .75749 L F
.811 .464 .4 r
.61093 .67979 m .60832 .68068 L .60794 .67912 L F
.61093 .67979 m .61145 .68163 L .60832 .68068 L F
.316 .666 .974 r
.41921 .78878 m .42011 .78791 L .41821 .78899 L F
.326 0 0 r
.42265 .7886 m .41921 .78878 L .41942 .78914 L F
.42265 .7886 m .42147 .78896 L .41921 .78878 L F
.316 .666 .974 r
.41921 .78878 m .42147 .78896 L .42011 .78791 L F
.553 .417 .65 r
.30757 .69581 m .30941 .69266 L .30711 .693 L F
0 .42 .801 r
.56084 .74763 m .56398 .74914 L .56188 .7477 L F
.731 .49 .563 r
.56686 .74769 m .56673 .74843 L .56393 .74867 L F
.56673 .74843 m .56648 .7499 L .56393 .74867 L F
.518 .613 .886 r
.56393 .74867 m .5657 .74784 L .56468 .74861 L F
.56393 .74867 m .56468 .74861 L .56398 .74914 L F
.905 .962 .815 r
.67339 .60851 m .67153 .60937 L .67246 .60768 L F
.619 .633 .843 r
.70719 .72601 m .71076 .72821 L .70999 .7263 L F
.391 .745 .992 r
.71076 .72821 m .71198 .72731 L .70999 .7263 L F
.71076 .72821 m .713 .72813 L .71198 .72731 L F
.465 .206 .437 r
.41965 .67619 m .41709 .67872 L .41751 .67663 L F
.378 .655 .966 r
.26572 .59148 m .26537 .59296 L .26389 .5915 L F
.26572 .59148 m .26766 .59319 L .26537 .59296 L F
.092 0 0 r
.56244 .67869 m .5645 .67838 L .56565 .67673 L F
.127 0 .037 r
.56244 .67869 m .56246 .67945 L .5645 .67838 L F
.685 .923 .971 r
.71316 .58189 m .71445 .58036 L .71536 .58096 L F
.498 .16 .324 r
.59524 .65661 m .59781 .65648 L .59785 .65504 L F
.641 .275 .334 r
.59781 .65648 m .59997 .65672 L .59785 .65504 L F
.557 .317 .508 r
.59785 .65504 m .59997 .65672 L .60001 .65475 L F
.296 .059 .375 r
.3906 .68476 m .38849 .68757 L .39014 .6869 L F
.439 .211 .469 r
.38849 .68757 m .39012 .68901 L .39014 .6869 L F
.38849 .68757 m .38817 .68966 L .39012 .68901 L F
.446 .869 .937 r
.51362 .7397 m .51079 .73999 L .5125 .73879 L F
.548 .353 .568 r
.51149 .74243 m .51362 .7397 L .5125 .73879 L F
.51149 .74243 m .51383 .74279 L .51362 .7397 L F
.502 .319 .564 r
.51383 .74279 m .51617 .74168 L .51362 .7397 L F
.604 .866 .992 r
.30808 .73624 m .306 .73576 L .30779 .73421 L F
.302 0 0 r
.30779 .7345 m .31008 .73438 L .30779 .73421 L F
.30779 .7345 m .31008 .73438 L .30779 .73421 L F
0 0 .222 r
.30779 .73421 m .30779 .7345 L .306 .73576 L F
.30779 .73421 m .30808 .73624 L .30826 .73542 L F
.30779 .73421 m .30826 .73542 L .30779 .7345 L F
0 0 0 r
.30779 .7345 m .30779 .73421 L .306 .73576 L F
.30779 .7345 m .30779 .73421 L .306 .73576 L F
.829 .359 .073 r
.31791 .72863 m .31624 .72819 L .31444 .72548 L F
.589 .58 .81 r
.31427 .73103 m .31624 .72819 L .31791 .72863 L F
.547 .36 .579 r
.31281 .67939 m .31477 .68125 L .31461 .67885 L F
.31281 .67939 m .31265 .68177 L .31477 .68125 L F
.902 .881 .803 r
.67714 .59378 m .67642 .59742 L .67436 .59524 L F
.785 .734 .805 r
.6789 .59706 m .6765 .59971 L .67642 .59742 L F
.667 .642 .816 r
.34075 .70384 m .33727 .70171 L .33938 .7011 L F
.665 .665 .84 r
.34277 .70286 m .34075 .70384 L .33938 .7011 L F
.239 .678 .957 r
.39017 .65158 m .38934 .65217 L .38797 .65133 L F
.39017 .65158 m .3915 .65232 L .38934 .65217 L F
.688 .706 .181 r
.56805 .70249 m .56831 .7015 L .56901 .70004 L F
.56805 .70249 m .56771 .70383 L .56831 .7015 L F
0 0 0 r
.57719 .68383 m .5755 .6854 L .57782 .68194 L F
0 0 .154 r
.57719 .68383 m .57503 .68683 L .5755 .6854 L F
0 0 0 r
.39756 .6767 m .39492 .67926 L .39687 .67821 L F
.577 .55 .788 r
.39756 .6767 m .3985 .67325 L .39617 .67355 L F
.39756 .6767 m .39967 .6763 L .3985 .67325 L F
.009 0 0 r
.39687 .67821 m .39967 .6763 L .39756 .6767 L F
.169 .523 .919 r
.53712 .71838 m .53479 .71824 L .53347 .71756 L F
.53712 .71838 m .53727 .7191 L .53479 .71824 L F
0 0 0 r
.69366 .58624 m .69164 .58707 L .69114 .58731 L F
.535 .391 .632 r
.61015 .72888 m .611 .731 L .60884 .73129 L F
0 0 0 r
.50378 .70886 m .50531 .70832 L .50671 .70718 L F
.50378 .70886 m .50286 .71085 L .50531 .70832 L F
.3788 .71172 m .37615 .71375 L .37725 .71276 L F
.466 .615 .913 r
.55278 .7439 m .55426 .74613 L .55136 .74593 L F
.446 .747 .992 r
.28394 .59554 m .28335 .5967 L .28198 .59574 L F
.28394 .59554 m .28539 .59655 L .28335 .5967 L F
.18 0 .359 r
.61185 .74728 m .61137 .74946 L .60944 .74991 L F
.102 0 .095 r
.61137 .74946 m .60886 .75189 L .60944 .74991 L F
.782 .445 .418 r
.70673 .57755 m .70525 .5781 L .70786 .57797 L F
.888 .596 .487 r
.70561 .57964 m .70882 .58075 L .70786 .57797 L F
0 0 0 r
.51879 .79349 m .5222 .7913 L .5206 .79252 L F
.52462 .79041 m .52342 .79119 L .5222 .7913 L F
.5222 .7913 m .52342 .79119 L .5206 .79252 L F
.5 .651 .926 r
.70008 .60266 m .70391 .60499 L .70255 .60203 L F
.484 .512 .81 r
.70391 .60499 m .70509 .60163 L .70255 .60203 L F
.70391 .60499 m .70618 .60474 L .70509 .60163 L F
.544 .779 .985 r
.38104 .64843 m .38033 .64989 L .37926 .64807 L F
.38104 .64843 m .3824 .64944 L .38033 .64989 L F
.446 .192 .434 r
.44756 .75272 m .4451 .75544 L .44558 .75321 L F
.504 .264 .484 r
.35491 .67648 m .35497 .67904 L .35241 .67878 L F
.57 .315 .49 r
.35667 .67838 m .35491 .67648 L .35699 .67624 L F
.35667 .67838 m .35497 .67904 L .35491 .67648 L F
.478 .218 .441 r
.3906 .68476 m .39238 .68637 L .39257 .6842 L F
.3906 .68476 m .39014 .6869 L .39238 .68637 L F
.924 .534 .181 r
.60704 .70622 m .60585 .70599 L .60494 .70319 L F
.965 .798 .365 r
.60681 .70639 m .60728 .70488 L .60655 .70577 L F
.711 .885 .961 r
.60754 .7065 m .60641 .70616 L .60704 .70622 L F
.60641 .70616 m .60585 .70599 L .60624 .70606 L F
.60641 .70616 m .60624 .70606 L .60704 .70622 L F
.60754 .7065 m .60655 .70577 L .60585 .70599 L F
.904 .494 .121 r
.60856 .70867 m .60743 .7079 L .60655 .70577 L F
.965 .798 .365 r
.60743 .7079 m .60737 .70672 L .60681 .70639 L F
.60737 .70672 m .60728 .70488 L .60681 .70639 L F
.417 0 0 r
.51183 .7294 m .51024 .73056 L .5079 .73065 L F
.123 0 0 r
.51118 .73025 m .51183 .7294 L .51381 .72873 L F
.51118 .73025 m .51024 .73056 L .51183 .7294 L F
.511 .303 .533 r
.40813 .76623 m .4103 .764 L .40825 .76445 L F
.511 .38 .638 r
.31974 .60787 m .31925 .61077 L .31817 .61099 L F
.392 .191 .484 r
.31925 .61077 m .31729 .61299 L .31817 .61099 L F
.99 .762 .495 r
.71797 .57769 m .71748 .58089 L .71676 .57687 L F
.529 .837 .999 r
.71797 .57769 m .71676 .57687 L .71814 .57754 L F
0 0 0 r
.69366 .58624 m .69114 .58731 L .69376 .58647 L F
.69366 .58624 m .69376 .58647 L .69493 .58483 L F
.904 .691 .605 r
.60652 .67331 m .60485 .67025 L .60658 .67108 L F
.457 .262 .526 r
.28171 .63234 m .28386 .62954 L .28202 .63003 L F
0 .33 .813 r
.53951 .7209 m .53801 .72072 L .53727 .7191 L F
.53951 .7209 m .54038 .72229 L .53801 .72072 L F
.439 .171 .409 r
.40517 .68962 m .40313 .6902 L .4057 .68774 L F
.435 .167 .408 r
.40714 .68899 m .4057 .68774 L .40756 .68708 L F
.40714 .68899 m .40517 .68962 L .4057 .68774 L F
.963 .94 .686 r
.67371 .60193 m .67185 .60409 L .67273 .60152 L F
.571 .403 .615 r
.41148 .75318 m .41365 .75559 L .41351 .75264 L F
.41148 .75318 m .41157 .75596 L .41365 .75559 L F
.273 0 0 r
.34539 .72803 m .34209 .7287 L .34332 .72812 L F
.722 .297 .239 r
.4247 .78922 m .42147 .78896 L .42265 .7886 L F
.709 .832 .941 r
.42348 .788 m .42147 .78896 L .4247 .78922 L F
.42348 .788 m .42147 .78896 L .4247 .78922 L F
.676 .821 .953 r
.42348 .788 m .4247 .78922 L .4268 .78812 L F
.4 .848 .916 r
.31008 .73438 m .31323 .73398 L .3117 .73327 L F
.432 .518 .846 r
.31323 .73398 m .31501 .73476 L .31548 .73422 L F
.885 .509 .323 r
.50109 .72842 m .5021 .73101 L .50352 .73129 L F
.50078 .72805 m .5021 .73101 L .50109 .72842 L F
.957 .697 .5 r
.50228 .73305 m .50352 .73129 L .5021 .73101 L F
.50228 .73305 m .50366 .73393 L .50352 .73129 L F
.50352 .73129 m .50366 .73393 L .50228 .73305 L F
.629 .436 .602 r
.50583 .73368 m .50352 .73129 L .5047 .73082 L F
.50583 .73368 m .50366 .73393 L .50352 .73129 L F
.957 .697 .5 r
.50352 .73129 m .50228 .73305 L .50457 .73117 L F
.592 .375 .555 r
.50457 .73117 m .50275 .73267 L .5021 .73101 L F
.50275 .73267 m .50228 .73305 L .5021 .73101 L F
.605 .403 .581 r
.50249 .72751 m .5021 .73101 L .50078 .72805 L F
.263 .767 .87 r
.35671 .64923 m .35881 .6489 L .36014 .64899 L F
.114 .666 .737 r
.35881 .6489 m .3623 .64852 L .36014 .64899 L F
.211 0 .275 r
.58044 .66618 m .58164 .66684 L .58245 .66556 L F
.58044 .66618 m .57998 .6679 L .58164 .66684 L F
.173 0 0 r
.35131 .64953 m .35328 .64925 L .35467 .6485 L F
.26 0 0 r
.35328 .64925 m .35671 .64923 L .35467 .6485 L F
.379 .678 .976 r
.72925 .73343 m .73085 .73235 L .72753 .73171 L F
.72925 .73343 m .73122 .73335 L .73085 .73235 L F
.431 .031 .178 r
.35497 .67904 m .35126 .68079 L .35241 .67878 L F
.666 .739 .905 r
.73122 .73335 m .73205 .73505 L .73436 .73445 L F
.369 .658 .969 r
.55281 .70858 m .55419 .70756 L .55081 .70682 L F
.55281 .70858 m .55494 .7087 L .55419 .70756 L F
.585 .454 .668 r
.41559 .7477 m .41795 .74737 L .41778 .7445 L F
.533 .342 .568 r
.41585 .74974 m .41795 .74737 L .41559 .7477 L F
.358 .232 .569 r
.61796 .71131 m .61818 .71367 L .61539 .71396 L F
.585 .469 .688 r
.61818 .71367 m .61568 .71695 L .61539 .71396 L F
.649 .52 .694 r
.4142 .78059 m .41244 .78345 L .41489 .78305 L F
.548 .353 .568 r
.51149 .74243 m .5125 .73879 L .51079 .73999 L F
.217 .264 .697 r
.28772 .61587 m .28813 .61923 L .28922 .61773 L F
.12 .13 .595 r
.28813 .61923 m .28954 .62123 L .28922 .61773 L F
.208 .158 .578 r
.28844 .62167 m .28954 .62123 L .28813 .61923 L F
.282 .326 .73 r
.57499 .74844 m .57647 .74671 L .57471 .74647 L F
.57499 .74844 m .57716 .75008 L .57647 .74671 L F
.23 .059 .431 r
.44566 .76114 m .44669 .76123 L .44684 .75869 L F
.231 .025 .38 r
.44566 .76114 m .44622 .76212 L .44669 .76123 L F
.616 .487 .683 r
.30585 .70124 m .30779 .69842 L .3057 .69885 L F
.564 .196 .303 r
.36274 .67377 m .36164 .67592 L .35915 .67586 L F
.205 0 .116 r
.36344 .67515 m .36274 .67377 L .36494 .67374 L F
.36344 .67515 m .36164 .67592 L .36274 .67377 L F
.551 .38 .603 r
.36595 .83527 m .36804 .8345 L .36529 .83283 L F
.235 .553 .932 r
.36943 .83519 m .36529 .83283 L .36804 .8345 L F
.271 .721 .958 r
.27604 .59515 m .27426 .59526 L .27286 .59466 L F
0 0 0 r
.56565 .67673 m .56679 .67574 L .56815 .67432 L F
.56815 .67432 m .56868 .67485 L .56971 .67314 L F
.56815 .67432 m .56679 .67574 L .56868 .67485 L F
.238 .27 .693 r
.67056 .60488 m .67246 .60768 L .67185 .60409 L F
.456 .177 .4 r
.4031 .69355 m .40098 .69292 L .40284 .69244 L F
.4031 .69355 m .40087 .69438 L .40098 .69292 L F
.563 .052 0 r
.48762 .78157 m .48852 .78053 L .48509 .78039 L F
.751 .25 .033 r
.48922 .78259 m .48852 .78053 L .48762 .78157 L F
.48922 .78259 m .49064 .78267 L .48852 .78053 L F
.589 .355 .529 r
.49064 .78267 m .49085 .78034 L .48852 .78053 L F
.101 .635 .863 r
.45439 .77382 m .45682 .774 L .45635 .77426 L F
.956 .722 .544 r
.45682 .774 m .45806 .77649 L .45635 .77426 L F
.19 0 0 r
.3708 .71672 m .37431 .71443 L .37263 .71589 L F
.177 0 0 r
.37615 .71375 m .37263 .71589 L .37431 .71443 L F
.528 .382 .626 r
.32106 .66554 m .32317 .66771 L .32323 .66529 L F
.32106 .66554 m .32114 .66817 L .32317 .66771 L F
0 0 0 r
.56565 .67673 m .5645 .67838 L .56679 .67574 L F
.541 .857 .562 r
.61054 .69216 m .61322 .68957 L .61312 .68976 L F
0 0 .099 r
.61312 .68976 m .61322 .68957 L .61308 .68695 L F
.481 .899 .859 r
.56706 .72335 m .56882 .72224 L .56623 .72009 L F
.56706 .72335 m .56816 .72276 L .56882 .72224 L F
0 .139 .669 r
.56706 .72335 m .56825 .72353 L .56816 .72276 L F
.56706 .72335 m .5685 .72526 L .56825 .72353 L F
.915 .865 .428 r
.58148 .72704 m .58228 .7257 L .58084 .72472 L F
.58148 .72704 m .58146 .72826 L .58228 .7257 L F
.399 .143 .406 r
.31729 .61299 m .31719 .61573 L .31533 .61629 L F
.392 .191 .484 r
.31925 .61077 m .31961 .613 L .31729 .61299 L F
.366 .118 .399 r
.31904 .61499 m .31729 .61299 L .31961 .613 L F
.31904 .61499 m .31719 .61573 L .31729 .61299 L F
.394 .105 .351 r
.73923 .73127 m .73617 .73262 L .73666 .73099 L F
.73923 .73127 m .73889 .73287 L .73617 .73262 L F
.401 .236 .54 r
.73889 .73287 m .73724 .73414 L .73617 .73262 L F
0 .335 .79 r
.54297 .7238 m .54146 .72341 L .54038 .72229 L F
.54297 .7238 m .54375 .72459 L .54146 .72341 L F
.9 .872 .8 r
.42268 .73518 m .42188 .73663 L .42368 .73386 L F
0 .058 .589 r
.57885 .75287 m .5794 .75641 L .5802 .75523 L F
.259 .675 .966 r
.58083 .75796 m .5802 .75523 L .5794 .75641 L F
.374 0 0 r
.36595 .83527 m .36943 .83519 L .36804 .8345 L F
.957 .697 .5 r
.50352 .73129 m .50457 .73117 L .5047 .73082 L F
0 0 .276 r
.32845 .73314 m .32775 .73669 L .33027 .73391 L F
.577 .863 .996 r
.3308 .73241 m .33027 .73391 L .33208 .7332 L F
.3308 .73241 m .32845 .73314 L .33027 .73391 L F
.203 0 0 r
.53566 .73712 m .533 .73721 L .53594 .73585 L F
.754 .492 .536 r
.4394 .73776 m .44206 .73966 L .44066 .73854 L F
.44206 .73966 m .4425 .73998 L .44066 .73854 L F
.498 .097 .211 r
.43975 .73781 m .44066 .73854 L .4419 .73661 L F
.43838 .73858 m .44066 .73854 L .43975 .73781 L F
.572 .212 .318 r
.44066 .73854 m .44416 .73645 L .4419 .73661 L F
.25 0 .061 r
.30446 .70687 m .3049 .70777 L .30649 .70638 L F
.30446 .70687 m .30366 .70834 L .3049 .70777 L F
.577 .703 .928 r
.40812 .65502 m .40747 .65732 L .40608 .65578 L F
.40812 .65502 m .40968 .65686 L .40747 .65732 L F
.5 .347 .605 r
.3066 .62703 m .30617 .62831 L .3045 .62943 L F
.413 .203 .483 r
.3045 .62943 m .30609 .63174 L .30363 .63119 L F
.3045 .62943 m .30617 .62831 L .30609 .63174 L F
.58 .378 .572 r
.53796 .73388 m .53825 .73633 L .53594 .73585 L F
.579 .403 .607 r
.54103 .73367 m .53825 .73633 L .53796 .73388 L F
.371 .251 .584 r
.61365 .71753 m .61378 .72025 L .61219 .72037 L F
.48 .357 .635 r
.61378 .72025 m .61217 .72268 L .61219 .72037 L F
.592 .948 .85 r
.70103 .57898 m .70159 .57822 L .70309 .5779 L F
.70103 .57898 m .69961 .57905 L .70159 .57822 L F
.457 .863 .962 r
.59997 .66573 m .59854 .66569 L .59719 .66602 L F
.882 .449 .102 r
.59997 .66573 m .59952 .66695 L .59854 .66569 L F
.59997 .66573 m .60076 .66753 L .59952 .66695 L F
.05 .37 .838 r
.42767 .66422 m .42684 .66457 L .42504 .66476 L F
.42767 .66422 m .42845 .66563 L .42684 .66457 L F
.502 .336 .589 r
.42845 .66563 m .42639 .66838 L .42684 .66457 L F
.279 .313 .718 r
.57092 .72816 m .57147 .73144 L .57302 .73025 L F
.299 .349 .746 r
.57147 .73144 m .57378 .73329 L .57302 .73025 L F
.376 .354 .707 r
.57224 .73357 m .57378 .73329 L .57147 .73144 L F
.502 .411 .685 r
.3424 .68973 m .34046 .68851 L .34193 .6881 L F
.3424 .68973 m .34056 .69026 L .34046 .68851 L F
.389 0 0 r
.3623 .64852 m .36441 .64878 L .36566 .64819 L F
.076 0 0 r
.36441 .64878 m .36765 .64765 L .36566 .64819 L F
.296 .784 .899 r
.26772 .60437 m .26813 .60386 L .26617 .60401 L F
.26772 .60437 m .27028 .6039 L .26813 .60386 L F
.307 .187 .549 r
.43764 .76082 m .43635 .76281 L .43631 .76146 L F
.351 .193 .522 r
.61284 .72494 m .61015 .72888 L .611 .72558 L F
.513 .027 .04 r
.70309 .5779 m .70525 .5781 L .70673 .57755 L F
.581 .798 .982 r
.69376 .58647 m .69114 .58731 L .68989 .58584 L F
.85 .71 .708 r
.59749 .73879 m .59538 .73897 L .59611 .73674 L F
.849 .75 .753 r
.59749 .73879 m .59596 .74173 L .59538 .73897 L F
0 0 0 r
.54123 .69572 m .5422 .69458 L .543 .69245 L F
.379 .817 .667 r
.543 .69245 m .5445 .69155 L .54579 .69092 L F
0 0 0 r
.543 .69245 m .5422 .69458 L .5445 .69155 L F
.72 .39 .421 r
.51689 .72865 m .51369 .7306 L .51381 .72873 L F
.51689 .72865 m .51733 .73086 L .51369 .7306 L F
.691 .371 .43 r
.51689 .72865 m .51905 .73084 L .51733 .73086 L F
0 0 .114 r
.59628 .73367 m .59785 .73273 L .59875 .73037 L F
0 0 .171 r
.59628 .73367 m .59651 .73543 L .59785 .73273 L F
.794 .449 .402 r
.53825 .73633 m .53566 .73712 L .53594 .73585 L F
.576 .385 .586 r
.53087 .74395 m .52849 .74223 L .5308 .74202 L F
.53087 .74395 m .52854 .7444 L .52849 .74223 L F
.535 .028 0 r
.40945 .77776 m .40797 .77791 L .41096 .77789 L F
.771 .762 .844 r
.41001 .77466 m .40945 .77776 L .41214 .77453 L F
.634 .723 .912 r
.40945 .77776 m .41338 .77754 L .41214 .77453 L F
.40945 .77776 m .41096 .77789 L .41338 .77754 L F
.482 .567 .865 r
.73794 .71352 m .7362 .71524 L .73581 .71373 L F
.505 .605 .887 r
.73794 .71352 m .73805 .71502 L .7362 .71524 L F
.75 .663 .765 r
.31501 .73476 m .31656 .73675 L .31892 .73479 L F
0 0 .166 r
.62464 .69471 m .6234 .69779 L .62343 .69587 L F
.604 .196 .242 r
.5553 .74766 m .55405 .74952 L .55214 .74831 L F
.252 .52 .911 r
.55426 .74613 m .55628 .74666 L .5553 .74766 L F
.662 .538 .703 r
.55628 .74666 m .55405 .74952 L .5553 .74766 L F
0 0 0 r
.36765 .64765 m .36962 .64699 L .36801 .64665 L F
.562 .932 .914 r
.72377 .59516 m .72673 .59431 L .7264 .59431 L F
.712 .986 .827 r
.72819 .59221 m .72673 .59431 L .72886 .59233 L F
.674 .933 .642 r
.7264 .59431 m .72673 .59431 L .72819 .59221 L F
.81 .989 .881 r
.72626 .59339 m .7264 .59431 L .72819 .59221 L F
.72344 .59512 m .72512 .59466 L .72626 .59339 L F
.72512 .59466 m .7264 .59431 L .72626 .59339 L F
.712 .986 .827 r
.72819 .59221 m .72886 .59233 L .7292 .59201 L F
.81 .989 .881 r
.72344 .59512 m .72819 .59221 L .72724 .59185 L F
.959 .947 .672 r
.72819 .59221 m .72888 .59095 L .72904 .58896 L F
.72819 .59221 m .72904 .58896 L .72724 .59185 L F
.001 .51 .86 r
.72819 .59221 m .72897 .5921 L .72724 .59185 L F
.72819 .59221 m .7305 .59304 L .72897 .5921 L F
.497 0 0 r
.72819 .59221 m .7305 .59304 L .72997 .5935 L F
.477 .364 .647 r
.72897 .5921 m .72759 .5919 L .72997 .5935 L F
.72759 .5919 m .72724 .59185 L .7275 .59201 L F
.497 0 0 r
.72819 .59221 m .72997 .5935 L .72769 .59212 L F
.72819 .59221 m .72769 .59212 L .72724 .59185 L F
.477 .364 .647 r
.72759 .5919 m .7275 .59201 L .72997 .5935 L F
0 0 0 r
.50671 .70718 m .50786 .7064 L .50876 .70642 L F
.50671 .70718 m .50531 .70832 L .50786 .7064 L F
.384 .085 .33 r
.58504 .66251 m .58662 .66423 L .58699 .66259 L F
.58504 .66251 m .58456 .6649 L .58662 .66423 L F
.802 .809 .857 r
.51895 .7576 m .52302 .75697 L .52165 .75526 L F
.51895 .7576 m .5207 .75862 L .52302 .75697 L F
.527 .669 .927 r
.52302 .75697 m .52389 .75474 L .52165 .75526 L F
.983 .703 .403 r
.59309 .72563 m .59182 .72493 L .59182 .7227 L F
.986 .723 .433 r
.59309 .72563 m .59195 .7273 L .59182 .72493 L F
.828 .711 .734 r
.59363 .72369 m .59309 .72563 L .59182 .7227 L F
0 0 0 r
.59496 .72676 m .59195 .7273 L .59309 .72563 L F
.3 .334 .729 r
.74242 .72177 m .74077 .7231 L .74003 .71977 L F
.374 .467 .827 r
.74242 .72177 m .74366 .72491 L .74077 .7231 L F
.589 .431 .635 r
.74366 .72491 m .74104 .72553 L .74077 .7231 L F
.34 .069 .348 r
.29552 .64327 m .2952 .64576 L .29324 .64563 L F
.353 .115 .408 r
.29552 .64327 m .29776 .6405 L .2976 .64319 L F
.402 .148 .41 r
.2976 .64319 m .2952 .64576 L .29552 .64327 L F
.416 .162 .419 r
.39851 .69496 m .39801 .69774 L .39614 .69832 L F
.458 .195 .427 r
.40087 .69438 m .39801 .69774 L .39851 .69496 L F
0 0 .368 r
.70586 .72179 m .7073 .7193 L .70885 .72065 L F
.70586 .72179 m .70723 .72176 L .7073 .7193 L F
.70586 .72179 m .70604 .72291 L .70723 .72176 L F
.743 .728 .837 r
.57156 .70411 m .56771 .70383 L .57023 .70508 L F
0 0 0 r
.57156 .70411 m .57202 .70396 L .57405 .70072 L F
.523 .504 .777 r
.57023 .70508 m .57202 .70396 L .57156 .70411 L F
.115 .323 .793 r
.56793 .68753 m .56909 .68683 L .56697 .68793 L F
0 0 0 r
.57025 .6859 m .56909 .68683 L .57152 .68571 L F
.57025 .6859 m .56991 .68618 L .56909 .68683 L F
.115 .323 .793 r
.56807 .68765 m .57017 .6894 L .56909 .68683 L F
0 0 0 r
.56991 .68618 m .5678 .68794 L .56909 .68683 L F
.115 .323 .793 r
.56793 .68753 m .56807 .68765 L .56909 .68683 L F
.531 .517 .785 r
.28567 .61042 m .28681 .6138 L .28862 .6131 L F
.42 .236 .523 r
.28681 .6138 m .28848 .61576 L .28862 .6131 L F
.055 .152 .649 r
.28772 .61587 m .28848 .61576 L .28681 .6138 L F
.812 .823 .345 r
.54136 .698 m .5422 .69458 L .54123 .69572 L F
.594 .505 .723 r
.42188 .73663 m .42466 .73831 L .42411 .73616 L F
.42188 .73663 m .42255 .73944 L .42466 .73831 L F
.669 .574 .74 r
.41096 .77789 m .4142 .78059 L .41338 .77754 L F
.443 .278 .561 r
.3424 .68973 m .34057 .69264 L .34056 .69026 L F
.342 .088 .376 r
.29324 .64563 m .29465 .6478 L .29263 .6483 L F
.29324 .64563 m .2952 .64576 L .29465 .6478 L F
.494 .316 .568 r
.42243 .74138 m .42466 .73831 L .42255 .73944 L F
.218 0 .224 r
.46267 .74696 m .46126 .74764 L .46329 .74539 L F
.451 .135 .338 r
.46537 .74591 m .46267 .74696 L .46329 .74539 L F
.443 .012 .124 r
.46329 .74539 m .46591 .74527 L .46537 .74591 L F
.401 .085 .311 r
.48182 .72537 m .4838 .72491 L .48448 .72317 L F
.316 0 .221 r
.4838 .72491 m .48654 .72264 L .48448 .72317 L F
.182 0 .028 r
.53977 .74476 m .54262 .74273 L .53949 .74197 L F
.53977 .74476 m .54209 .74435 L .54262 .74273 L F
.459 .252 .511 r
.40477 .6918 m .40313 .6902 L .40517 .68962 L F
.40477 .6918 m .40284 .69244 L .40313 .6902 L F
.187 .435 .865 r
.31524 .72645 m .31624 .72819 L .31702 .72738 L F
.471 0 0 r
.31524 .72645 m .31702 .72738 L .31558 .72683 L F
0 0 .456 r
.31463 .72577 m .31624 .72819 L .31524 .72645 L F
.471 0 0 r
.31524 .72645 m .31558 .72683 L .31269 .72574 L F
0 0 .456 r
.31444 .72548 m .31463 .72577 L .31524 .72645 L F
.75 .663 .765 r
.31501 .73476 m .31892 .73479 L .31756 .73308 L F
0 .204 .722 r
.31892 .73479 m .31899 .73417 L .31756 .73308 L F
.629 .708 .903 r
.69446 .60235 m .69581 .59943 L .69333 .60129 L F
.69446 .60235 m .69678 .60181 L .69581 .59943 L F
.351 .193 .522 r
.61284 .72494 m .6129 .72733 L .61015 .72888 L F
.511 .434 .706 r
.6129 .72733 m .611 .731 L .61015 .72888 L F
.463 0 0 r
.47036 .785 m .47159 .78388 L .47387 .78472 L F
.134 .652 .889 r
.28539 .59655 m .28735 .59667 L .28892 .59715 L F
.234 .693 .949 r
.28937 .59654 m .28892 .59715 L .28735 .59667 L F
.28937 .59654 m .29093 .59722 L .28892 .59715 L F
.2 .515 .915 r
.40899 .76909 m .41005 .76638 L .40813 .76623 L F
.40899 .76909 m .40965 .76802 L .41005 .76638 L F
.40899 .76909 m .41052 .7693 L .40965 .76802 L F
.705 .416 .484 r
.59997 .65672 m .60319 .65474 L .60001 .65475 L F
.59997 .65672 m .60347 .65675 L .60319 .65474 L F
.74 .442 .476 r
.60319 .65474 m .60347 .65675 L .60655 .65679 L F
.646 .395 .525 r
.44684 .75869 m .44669 .76123 L .44856 .76064 L F
.076 .255 .744 r
.44684 .75869 m .44856 .76064 L .44761 .75778 L F
.15 0 .073 r
.59302 .66918 m .5921 .66823 L .59419 .66777 L F
.59302 .66918 m .59125 .67011 L .5921 .66823 L F
.583 .357 .538 r
.53074 .76411 m .53091 .76673 L .52789 .76686 L F
.509 .36 .614 r
.47573 .75016 m .4743 .75156 L .47338 .75061 L F
.47573 .75016 m .47576 .75294 L .4743 .75156 L F
.553 .438 .676 r
.47576 .75294 m .47338 .75061 L .47573 .75016 L F
.523 .36 .602 r
.47576 .75294 m .47367 .7537 L .4743 .75156 L F
.553 .438 .676 r
.47576 .75294 m .47367 .7537 L .47338 .75061 L F
.466 .428 .732 r
.53087 .74395 m .52975 .74719 L .52854 .7444 L F
.53087 .74395 m .5316 .74743 L .52975 .74719 L F
.649 .621 .808 r
.53323 .74863 m .52975 .74719 L .5316 .74743 L F
.102 .071 .533 r
.51498 .74494 m .51617 .74168 L .51383 .74279 L F
.51498 .74494 m .51607 .74424 L .51617 .74168 L F
.528 .506 .775 r
.51485 .7474 m .51607 .74424 L .51498 .74494 L F
.487 .221 .437 r
.41664 .68125 m .41507 .67918 L .41709 .67872 L F
.41664 .68125 m .41448 .68174 L .41507 .67918 L F
.399 .85 .905 r
.52397 .76863 m .52305 .76943 L .52529 .76922 L F
.52397 .76863 m .52155 .76957 L .52305 .76943 L F
.621 .346 .48 r
.49335 .73956 m .48914 .74157 L .49204 .73993 L F
.49335 .73956 m .49369 .74159 L .48914 .74157 L F
.535 .398 .64 r
.31071 .68467 m .31297 .6849 L .31265 .68177 L F
.614 .46 .65 r
.31045 .68689 m .31297 .6849 L .31071 .68467 L F
.461 .688 .964 r
.72374 .59868 m .72505 .60009 L .72238 .60013 L F
.937 .681 .524 r
.45917 .7504 m .45745 .7502 L .45553 .75002 L F
.45917 .7504 m .45918 .75286 L .45745 .7502 L F
.16 0 .268 r
.46035 .74987 m .45917 .7504 L .46126 .74764 L F
.937 .681 .524 r
.45745 .7502 m .45917 .7504 L .46035 .74987 L F
.45745 .7502 m .45918 .75286 L .45917 .7504 L F
.593 .431 .631 r
.29996 .63759 m .30049 .64057 L .29776 .6405 L F
.537 .173 .297 r
.29776 .6405 m .29955 .64261 L .2976 .64319 L F
.29776 .6405 m .30049 .64057 L .29955 .64261 L F
.786 .558 .59 r
.6214 .66476 m .62481 .66292 L .62126 .66233 L F
.6214 .66476 m .62511 .66495 L .62481 .66292 L F
.123 0 0 r
.5316 .74743 m .53509 .7475 L .53323 .74863 L F
.55 .432 .672 r
.5351 .75005 m .53323 .74863 L .53509 .7475 L F
.5351 .75005 m .53307 .75048 L .53323 .74863 L F
.32 .044 .329 r
.39317 .70311 m .39192 .70235 L .39677 .70157 L F
.39317 .70311 m .39138 .70385 L .39192 .70235 L F
.377 .015 .217 r
.38934 .70452 m .38863 .70583 L .38653 .70626 L F
.43 .106 .313 r
.39138 .70385 m .38863 .70583 L .38934 .70452 L F
.738 .564 .656 r
.618 .65987 m .62126 .65753 L .61791 .65733 L F
.618 .65987 m .62127 .65996 L .62126 .65753 L F
.379 0 0 r
.31709 .71954 m .31459 .71846 L .31516 .71758 L F
.628 .832 .979 r
.71876 .71506 m .71613 .71641 L .71439 .71485 L F
.523 .531 .805 r
.55123 .73202 m .55242 .73447 L .55446 .73314 L F
.598 .484 .695 r
.55242 .73447 m .55523 .73623 L .55446 .73314 L F
.55242 .73447 m .5538 .73707 L .55523 .73623 L F
.772 .616 .686 r
.4668 .74999 m .47016 .75269 L .47108 .75127 L F
.4668 .74999 m .46827 .75346 L .47016 .75269 L F
.54 .377 .608 r
.31461 .67885 m .31666 .67605 L .31479 .67657 L F
.994 .831 .467 r
.72821 .60675 m .72889 .60732 L .7292 .60547 L F
.807 .923 .541 r
.73002 .6035 m .7292 .60547 L .73082 .60245 L F
.781 .895 .487 r
.73002 .6035 m .72821 .60675 L .7292 .60547 L F
.208 0 0 r
.35303 .72481 m .34991 .72601 L .351 .7254 L F
.553 .417 .65 r
.30757 .69581 m .30968 .6954 L .30941 .69266 L F
.552 .416 .65 r
.30757 .69581 m .30984 .69794 L .30968 .6954 L F
.30757 .69581 m .30779 .69842 L .30984 .69794 L F
.499 0 0 r
.54402 .73352 m .54267 .73381 L .54103 .73367 L F
.459 0 0 r
.5462 .73394 m .54267 .73381 L .54402 .73352 L F
.794 .586 .619 r
.61448 .65934 m .61791 .65733 L .61449 .65699 L F
.61448 .65934 m .61598 .65951 L .61791 .65733 L F
.783 .569 .61 r
.61598 .65951 m .618 .65987 L .61791 .65733 L F
0 0 .079 r
.60872 .69813 m .60924 .69751 L .6094 .69567 L F
0 0 .422 r
.6094 .69567 m .61062 .69453 L .61054 .69216 L F
0 0 0 r
.60938 .69603 m .6094 .69567 L .60924 .69751 L F
.60938 .69603 m .61062 .69453 L .6094 .69567 L F
.473 .811 .999 r
.7163 .72848 m .71531 .72777 L .713 .72813 L F
.7163 .72848 m .71531 .72777 L .713 .72813 L F
.165 .662 .915 r
.7163 .72848 m .71761 .72817 L .71531 .72777 L F
.7163 .72848 m .71844 .72864 L .71761 .72817 L F
.499 .546 .836 r
.4196 .66481 m .41769 .66503 L .41635 .66206 L F
.782 .606 .662 r
.62511 .66495 m .62595 .66803 L .62746 .66539 L F
.497 .839 .997 r
.27487 .63819 m .27671 .63765 L .27737 .63571 L F
.384 .1 .354 r
.27737 .63571 m .27856 .63711 L .27925 .6351 L F
.27737 .63571 m .27671 .63765 L .27856 .63711 L F
.752 .507 .561 r
.45339 .75021 m .45296 .75306 L .44984 .75245 L F
.452 .236 .494 r
.45491 .75238 m .45339 .75021 L .45553 .75002 L F
.45491 .75238 m .45296 .75306 L .45339 .75021 L F
.549 .75 .97 r
.68751 .58595 m .68524 .58633 L .68424 .58509 L F
.816 .597 .606 r
.38766 .67144 m .38977 .66828 L .38938 .67047 L F
.472 .42 .718 r
.38711 .6684 m .38766 .67144 L .38938 .67047 L F
.205 0 .269 r
.38766 .67144 m .38743 .67272 L .38938 .67047 L F
.466 .461 .768 r
.41338 .77754 m .4142 .78059 L .41581 .77985 L F
.424 .358 .679 r
.4142 .78059 m .41642 .78288 L .41581 .77985 L F
.375 .349 .701 r
.41489 .78305 m .41642 .78288 L .4142 .78059 L F
.372 .84 .853 r
.51192 .70587 m .5131 .70521 L .51416 .70536 L F
.51192 .70587 m .51092 .70591 L .5131 .70521 L F
.392 .186 .476 r
.30408 .63459 m .30363 .63119 L .30609 .63174 L F
.658 .802 .952 r
.67401 .61544 m .67602 .61305 L .67271 .61473 L F
.67401 .61544 m .67754 .61454 L .67602 .61305 L F
.527 .325 .55 r
.5351 .75005 m .53307 .75266 L .53307 .75048 L F
.595 .423 .619 r
.34469 .68415 m .34193 .6881 L .34275 .68505 L F
.893 .59 .086 r
.30918 .7174 m .30867 .71707 L .30829 .7146 L F
.929 .926 .554 r
.30918 .7174 m .30792 .71918 L .30867 .71707 L F
.241 .491 .894 r
.57939 .72275 m .5782 .72365 L .57785 .72193 L F
.57939 .72275 m .58084 .72472 L .5782 .72365 L F
0 0 0 r
.37273 .66999 m .36921 .6707 L .37023 .67051 L F
.567 .437 .663 r
.4103 .764 m .41208 .76079 L .41029 .7613 L F
0 .144 .66 r
.72831 .62755 m .72975 .62843 L .72737 .62652 L F
.72831 .62755 m .7306 .62954 L .72975 .62843 L F
.435 0 0 r
.49851 .78427 m .49747 .78326 L .4966 .7822 L F
.49851 .78427 m .50044 .78437 L .49747 .78326 L F
.383 .111 .372 r
.52711 .73662 m .52771 .73708 L .52947 .73415 L F
.597 .352 .516 r
.52947 .73415 m .52771 .73708 L .53146 .73604 L F
.405 .68 .973 r
.71671 .57989 m .71536 .58096 L .71445 .58036 L F
.71671 .57989 m .71748 .58089 L .71536 .58096 L F
.897 .541 .36 r
.57405 .70072 m .57553 .70387 L .57674 .70394 L F
.928 .544 .213 r
.57553 .70387 m .57726 .70622 L .57674 .70394 L F
.569 .34 .529 r
.54098 .7477 m .54085 .75011 L .5385 .75025 L F
.518 .285 .5 r
.54308 .74746 m .54085 .75011 L .54098 .7477 L F
.156 0 0 r
.29273 .72044 m .29475 .71995 L .29292 .72029 L F
.124 .649 .878 r
.47673 .74228 m .4772 .7424 L .47454 .74203 L F
.49 .1 .227 r
.47654 .74394 m .4772 .7424 L .47673 .74228 L F
.437 .596 .91 r
.39449 .66905 m .396 .67108 L .39737 .66989 L F
.652 .445 .591 r
.396 .67108 m .3985 .67325 L .39737 .66989 L F
.396 .67108 m .39617 .67355 L .3985 .67325 L F
.918 .732 .635 r
.62707 .6759 m .62825 .67903 L .62862 .67667 L F
.52 .569 .846 r
.70719 .72601 m .70902 .72424 L .70604 .72291 L F
.70719 .72601 m .70925 .72574 L .70902 .72424 L F
.51 .428 .699 r
.70719 .72601 m .70999 .7263 L .70925 .72574 L F
.581 .379 .573 r
.58909 .74591 m .58883 .74489 L .58774 .74374 L F
.58909 .74591 m .59122 .7445 L .58883 .74489 L F
.397 0 0 r
.46619 .78416 m .46481 .7849 L .46283 .78469 L F
.313 0 0 r
.46815 .7846 m .46481 .7849 L .46619 .78416 L F
.64 .902 .586 r
.3018 .7344 m .30173 .73459 L .30042 .73582 L F
.942 .679 .509 r
.30173 .73459 m .30258 .73768 L .30042 .73582 L F
.657 .77 .932 r
.30245 .73263 m .30173 .73459 L .30397 .73388 L F
.749 .354 .304 r
.30042 .73582 m .30431 .73659 L .30173 .73459 L F
.72 .609 .732 r
.56805 .68978 m .56928 .69312 L .57126 .69053 L F
.582 .567 .802 r
.35488 .7083 m .35311 .70906 L .35202 .70602 L F
.027 0 0 r
.33511 .65653 m .33323 .65719 L .3316 .65862 L F
.918 .785 .699 r
.59596 .74173 m .59425 .74208 L .59538 .73897 L F
.917 .811 .727 r
.5933 .74412 m .59425 .74208 L .59596 .74173 L F
.654 .634 .817 r
.47708 .77378 m .47614 .77679 L .4749 .77477 L F
.47708 .77378 m .47868 .77675 L .47614 .77679 L F
.814 .909 .905 r
.68321 .60725 m .68696 .60588 L .68581 .60495 L F
.843 .9 .878 r
.68581 .60495 m .68696 .60588 L .68937 .60334 L F
.255 .763 .863 r
.50461 .72716 m .50407 .72701 L .50249 .72751 L F
.051 0 .388 r
.50355 .72862 m .50249 .72751 L .50407 .72701 L F
.50355 .72862 m .5021 .73101 L .50249 .72751 L F
.504 .67 .938 r
.38331 .66673 m .38711 .6684 L .38561 .66636 L F
.676 .684 .85 r
.38711 .6684 m .38772 .6656 L .38561 .66636 L F
.38711 .6684 m .38977 .66828 L .38772 .6656 L F
.472 .42 .718 r
.38711 .6684 m .38938 .67047 L .38977 .66828 L F
.517 .585 .862 r
.52538 .75732 m .52629 .75856 L .52791 .75798 L F
.278 .234 .628 r
.52629 .75856 m .52809 .76027 L .52791 .75798 L F
.32 0 .008 r
.52533 .78503 m .52773 .78467 L .52887 .78303 L F
.734 .314 .25 r
.52773 .78467 m .53111 .78519 L .52887 .78303 L F
0 0 .073 r
.62117 .70303 m .61997 .70626 L .62053 .70415 L F
.681 .577 .732 r
.53688 .74458 m .53977 .74476 L .53949 .74197 L F
.327 .496 .873 r
.56008 .73378 m .55731 .7311 L .55911 .73145 L F
0 .232 .745 r
.55911 .73145 m .56107 .73344 L .56008 .73378 L F
.44 .301 .595 r
.56247 .73614 m .56008 .73378 L .56107 .73344 L F
.56247 .73614 m .56072 .73737 L .56008 .73378 L F
.961 .753 .578 r
.71676 .57687 m .71748 .58089 L .71814 .57754 L F
.616 .487 .683 r
.30585 .70124 m .30812 .70084 L .30779 .69842 L F
.559 .468 .708 r
.30585 .70124 m .30844 .70347 L .30812 .70084 L F
.30585 .70124 m .30639 .70398 L .30844 .70347 L F
.81 .642 .674 r
.6283 .67084 m .62595 .66803 L .62592 .67042 L F
.876 .678 .631 r
.62587 .67282 m .6283 .67084 L .62592 .67042 L F
.62587 .67282 m .62756 .67359 L .6283 .67084 L F
.553 .278 .452 r
.44416 .73645 m .44642 .73631 L .44686 .73428 L F
.549 .258 .425 r
.44642 .73631 m .4496 .73348 L .44686 .73428 L F
.124 .109 .568 r
.30173 .63961 m .29996 .63759 L .30141 .63678 L F
.30173 .63961 m .30049 .64057 L .29996 .63759 L F
.299 0 .002 r
.34015 .65423 m .34222 .65381 L .34353 .65236 L F
.33 0 .023 r
.34353 .65236 m .34454 .65337 L .3457 .65206 L F
.34353 .65236 m .34222 .65381 L .34454 .65337 L F
.534 .448 .704 r
.34048 .69485 m .33859 .69872 L .33914 .69546 L F
.246 .635 .961 r
.51884 .70496 m .51777 .70548 L .51659 .70485 L F
.51884 .70496 m .52 .70586 L .51777 .70548 L F
.589 .58 .81 r
.31427 .73103 m .31715 .73096 L .31624 .72819 L F
.627 .465 .643 r
.31548 .73422 m .31715 .73096 L .31427 .73103 L F
0 0 0 r
.57797 .68259 m .57719 .68383 L .57782 .68194 L F
.157 0 .015 r
.69586 .58347 m .69493 .58483 L .69807 .5829 L F
.499 .854 .992 r
.43073 .78654 m .43026 .78759 L .43169 .78747 L F
.298 .699 .976 r
.43169 .78747 m .43347 .78684 L .43073 .78654 L F
.43169 .78747 m .43478 .78748 L .43347 .78684 L F
.123 .658 .857 r
.43588 .78778 m .43478 .78748 L .43169 .78747 L F
.45 .54 .857 r
.67463 .59053 m .67501 .59211 L .67629 .59039 L F
0 .211 .708 r
.67501 .59211 m .67621 .59267 L .67629 .59039 L F
.67501 .59211 m .67714 .59378 L .67621 .59267 L F
.499 .854 .992 r
.43073 .78654 m .42947 .78667 L .43026 .78759 L F
.699 .753 .894 r
.42396 .78516 m .42784 .78712 L .42635 .78489 L F
.42784 .78712 m .42789 .78711 L .42635 .78489 L F
.42793 .78717 m .42804 .78707 L .42635 .78489 L F
.62 .769 .951 r
.42635 .78489 m .42823 .78732 L .42953 .78577 L F
.585 .848 .994 r
.42823 .78732 m .43073 .78654 L .42953 .78577 L F
.499 .854 .992 r
.42947 .78667 m .42729 .78689 L .42804 .78707 L F
.42947 .78667 m .42804 .78707 L .43026 .78759 L F
.699 .753 .894 r
.42784 .78712 m .42793 .78717 L .42789 .78711 L F
.648 .89 .983 r
.42682 .78812 m .43026 .78759 L .42816 .78709 L F
.42793 .78717 m .42816 .78709 L .42804 .78707 L F
.42682 .78812 m .42816 .78709 L .42793 .78717 L F
.699 .753 .894 r
.42396 .78516 m .42557 .78735 L .4274 .78733 L F
.42793 .78717 m .4274 .78733 L .42823 .78732 L F
.42396 .78516 m .4274 .78733 L .42793 .78717 L F
.42793 .78717 m .42823 .78732 L .42804 .78707 L F
.648 .89 .983 r
.42745 .78757 m .42804 .78707 L .42729 .78689 L F
.564 .82 .994 r
.4274 .78733 m .42729 .78689 L .42823 .78732 L F
.42557 .78735 m .42729 .78689 L .4274 .78733 L F
.648 .89 .983 r
.42682 .78812 m .42745 .78757 L .42729 .78689 L F
.4268 .78812 m .42682 .78812 L .42729 .78689 L F
.129 0 0 r
.57783 .66852 m .57882 .66938 L .57998 .6679 L F
.57783 .66852 m .57689 .6703 L .57882 .66938 L F
0 0 0 r
.43588 .78778 m .43665 .78746 L .43478 .78748 L F
.43588 .78778 m .43497 .78909 L .43665 .78746 L F
.283 .195 .576 r
.39492 .67926 m .39633 .68083 L .39687 .67821 L F
.39492 .67926 m .39508 .68171 L .39633 .68083 L F
.714 .462 .543 r
.49335 .78038 m .4944 .78022 L .49085 .78034 L F
.673 .354 .426 r
.49335 .78038 m .4966 .7822 L .4944 .78022 L F
.914 .559 .35 r
.54585 .70366 m .54441 .70332 L .54365 .70113 L F
.664 .114 0 r
.54837 .70551 m .54441 .70332 L .54585 .70366 L F
.246 0 0 r
.52142 .76384 m .52372 .76343 L .52448 .76273 L F
.287 0 0 r
.52448 .76273 m .52372 .76343 L .52586 .76308 L F
.623 .708 .907 r
.55731 .7311 m .55316 .72943 L .55675 .73004 L F
.211 .545 .929 r
.55675 .73004 m .55824 .73036 L .55731 .7311 L F
.234 .585 .946 r
.55824 .73036 m .55911 .73145 L .55731 .7311 L F
.353 .157 .469 r
.28421 .62737 m .28547 .62893 L .28565 .62664 L F
.28421 .62737 m .28386 .62954 L .28547 .62893 L F
.398 0 .053 r
.47109 .72883 m .47285 .72949 L .4742 .72791 L F
.403 0 0 r
.47285 .72949 m .47647 .72812 L .4742 .72791 L F
.797 .452 .403 r
.60076 .66753 m .60369 .66816 L .60228 .66999 L F
.834 .505 .432 r
.60369 .66816 m .60485 .67025 L .60228 .66999 L F
.885 .757 .716 r
.55915 .74155 m .55629 .74416 L .5585 .74139 L F
.568 .421 .641 r
.31684 .67377 m .31904 .67342 L .31884 .67091 L F
.53 .29 .496 r
.31864 .6756 m .31684 .67377 L .31666 .67605 L F
.31864 .6756 m .31904 .67342 L .31684 .67377 L F
0 0 0 r
.4451 .75544 m .44338 .75843 L .44311 .75597 L F
.867 .659 .619 r
.60808 .67652 m .60545 .67794 L .60497 .6759 L F
.60808 .67652 m .60794 .67912 L .60545 .67794 L F
0 0 .518 r
.56602 .74163 m .5657 .7419 L .56437 .74084 L F
.56602 .74163 m .56714 .74412 L .5657 .7419 L F
.317 0 0 r
.48664 .78517 m .49014 .78534 L .48849 .78589 L F
.766 .331 .219 r
.49014 .78534 m .49054 .78768 L .48849 .78589 L F
.49014 .78534 m .49186 .78657 L .49054 .78768 L F
.405 .432 .775 r
.70847 .61097 m .7106 .6126 L .7095 .60947 L F
.226 .667 .954 r
.29501 .59667 m .29441 .59733 L .29298 .59682 L F
.29501 .59667 m .2965 .5975 L .29441 .59733 L F
.578 .538 .774 r
.73778 .72722 m .73666 .73099 L .73547 .72792 L F
.73778 .72722 m .73923 .73127 L .73666 .73099 L F
.579 .393 .594 r
.46267 .74696 m .46035 .74987 L .46126 .74764 L F
0 .22 .74 r
.56084 .74763 m .56188 .7477 L .55939 .74547 L F
.395 .578 .913 r
.67065 .61415 m .67249 .61264 L .67072 .61205 L F
.67065 .61415 m .67271 .61473 L .67249 .61264 L F
.314 .108 .433 r
.30141 .63678 m .30189 .6349 L .30408 .63459 L F
.526 .275 .478 r
.34711 .68192 m .3467 .68387 L .34469 .68415 L F
.48 .234 .463 r
.34862 .68345 m .34711 .68192 L .34917 .68147 L F
.34862 .68345 m .3467 .68387 L .34711 .68192 L F
.981 .792 .576 r
.47106 .74675 m .47193 .74951 L .47239 .74717 L F
.624 .339 .464 r
.49933 .7395 m .49872 .74158 L .49585 .74186 L F
.462 .205 .438 r
.5013 .73892 m .49872 .74158 L .49933 .7395 L F
.904 .691 .605 r
.60652 .67331 m .60416 .67318 L .60485 .67025 L F
.9 .769 .707 r
.60652 .67331 m .60332 .67554 L .60416 .67318 L F
.60652 .67331 m .60497 .6759 L .60332 .67554 L F
.497 .589 .877 r
.32139 .60734 m .31974 .60787 L .31779 .6047 L F
.499 .368 .633 r
.32179 .60966 m .31974 .60787 L .32139 .60734 L F
.32179 .60966 m .31925 .61077 L .31974 .60787 L F
.259 .675 .966 r
.58083 .75796 m .58132 .75712 L .5802 .75523 L F
.58083 .75796 m .58245 .75794 L .58132 .75712 L F
.72 .609 .732 r
.56805 .68978 m .57126 .69053 L .57017 .6894 L F
.676 .8 .941 r
.57017 .6894 m .57126 .69053 L .57348 .68972 L F
.262 .27 .68 r
.56704 .74738 m .56648 .7499 L .56686 .74769 L F
.56708 .74803 m .56648 .7499 L .56704 .74738 L F
.518 .613 .886 r
.56393 .74867 m .56648 .7499 L .5657 .74784 L F
.262 .27 .68 r
.56761 .74641 m .56708 .74803 L .56704 .74738 L F
.56761 .74641 m .5657 .74784 L .56648 .7499 L F
.638 .14 .053 r
.5657 .74784 m .56712 .74846 L .56422 .74857 L F
.274 .28 .684 r
.5695 .74837 m .56797 .75011 L .56761 .74641 L F
.262 .27 .68 r
.56761 .74641 m .56797 .75011 L .56862 .74912 L F
.638 .14 .053 r
.56712 .74846 m .56862 .74912 L .56715 .74894 L F
.56712 .74846 m .56715 .74894 L .56422 .74857 L F
.277 0 .198 r
.28631 .65191 m .28886 .64975 L .28798 .65095 L F
.278 0 .109 r
.28886 .64975 m .29001 .65039 L .28798 .65095 L F
.28886 .64975 m .29091 .64912 L .29001 .65039 L F
.497 .839 .997 r
.27487 .63819 m .27573 .63796 L .27671 .63765 L F
.486 .312 .57 r
.27478 .64055 m .27573 .63796 L .27487 .63819 L F
.376 .624 .949 r
.29811 .72336 m .29997 .72517 L .30038 .72403 L F
.703 .576 .709 r
.29921 .73054 m .30167 .72751 L .30061 .72776 L F
.29918 .73061 m .29925 .73053 L .29921 .73054 L F
.29925 .73053 m .30167 .72751 L .29921 .73054 L F
.29918 .73061 m .30155 .73055 L .30167 .72751 L F
.732 .601 .71 r
.30167 .72751 m .30155 .73055 L .29819 .73039 L F
.213 0 .2 r
.29996 .72983 m .29819 .73039 L .29942 .73045 L F
.30042 .73004 m .29942 .73045 L .30155 .73055 L F
.29996 .72983 m .29942 .73045 L .30042 .73004 L F
.732 .601 .71 r
.30167 .72751 m .29819 .73039 L .2999 .72786 L F
.959 .716 .525 r
.30185 .72882 m .30243 .7281 L .2999 .72786 L F
.30243 .7281 m .3035 .72678 L .30169 .72732 L F
.30243 .7281 m .30169 .72732 L .2999 .72786 L F
.774 .553 .6 r
.30104 .72664 m .30038 .72403 L .29997 .72517 L F
.30167 .72751 m .30155 .72718 L .30104 .72664 L F
.30155 .72718 m .30038 .72403 L .30104 .72664 L F
.508 .085 .173 r
.2999 .72786 m .30185 .72882 L .30258 .72792 L F
.30181 .72728 m .30258 .72792 L .3035 .72678 L F
.215 .139 .55 r
.30061 .72776 m .30167 .72751 L .30104 .72664 L F
.30015 .7259 m .30104 .72664 L .29997 .72517 L F
.30061 .72776 m .30104 .72664 L .30015 .7259 L F
.774 .553 .6 r
.30167 .72751 m .2999 .72786 L .30038 .72403 L F
.508 .085 .173 r
.2999 .72786 m .30258 .72792 L .30181 .72728 L F
.516 .103 .195 r
.37044 .70485 m .37377 .70321 L .37179 .70332 L F
0 .153 .682 r
.57224 .73357 m .57411 .73573 L .57378 .73329 L F
.534 .448 .704 r
.34048 .69485 m .342 .69976 L .33859 .69872 L F
.564 .417 .64 r
.34149 .7005 m .33859 .69872 L .342 .69976 L F
.34149 .7005 m .33938 .7011 L .33859 .69872 L F
.478 .236 .469 r
.28565 .62664 m .2881 .62407 L .28634 .62483 L F
.731 .583 .69 r
.4882 .73954 m .49204 .73993 L .48914 .74157 L F
.569 .438 .663 r
.30649 .70638 m .30844 .70347 L .30639 .70398 L F
0 0 .276 r
.32845 .73314 m .32845 .73569 L .32775 .73669 L F
.55 .916 .952 r
.32845 .73569 m .32636 .73656 L .32775 .73669 L F
0 0 .294 r
.5256 .72981 m .52514 .72856 L .52834 .72763 L F
.236 0 .02 r
.46603 .77417 m .46471 .7756 L .46785 .77431 L F
.254 .309 .727 r
.46466 .77559 m .46583 .7769 L .46471 .7756 L F
.236 0 .02 r
.46471 .7756 m .46461 .77571 L .46485 .7756 L F
.46471 .7756 m .46485 .7756 L .46785 .77431 L F
.254 .309 .727 r
.46471 .7756 m .46583 .7769 L .46576 .77667 L F
.4642 .77507 m .46466 .77559 L .46471 .7756 L F
.693 .339 .372 r
.4642 .77507 m .46471 .7756 L .46603 .77417 L F
.254 .309 .727 r
.4642 .77507 m .46486 .77574 L .46482 .77311 L F
.687 .674 .831 r
.46482 .77311 m .46461 .77571 L .46485 .7756 L F
.46482 .77311 m .46485 .7756 L .46785 .77431 L F
.254 .309 .727 r
.46486 .77574 m .46576 .77667 L .46482 .77311 L F
.682 .381 .458 r
.46366 .77608 m .46583 .7769 L .4642 .77507 L F
.693 .339 .372 r
.4642 .77507 m .46461 .77571 L .46471 .7756 L F
.236 0 .02 r
.46603 .77417 m .46785 .77431 L .46966 .77434 L F
.58 .258 .389 r
.52305 .73901 m .52714 .73729 L .52711 .73662 L F
.508 .393 .658 r
.52714 .73729 m .52771 .73708 L .52711 .73662 L F
.695 .178 0 r
.72886 .60068 m .7302 .6017 L .72829 .59962 L F
.558 .237 .382 r
.59207 .65923 m .59445 .65916 L .59524 .65661 L F
.501 .18 .355 r
.59445 .65916 m .59781 .65648 L .59524 .65661 L F
.708 .226 .103 r
.53009 .79165 m .52666 .79074 L .52836 .79083 L F
.836 .782 .799 r
.72168 .71467 m .71876 .71506 L .72075 .71374 L F
.72168 .71467 m .71918 .71778 L .71876 .71506 L F
.691 .861 .963 r
.72326 .7135 m .72168 .71467 L .72075 .71374 L F
.638 .514 .696 r
.41489 .78305 m .41816 .78542 L .41642 .78288 L F
.41489 .78305 m .41577 .7868 L .41816 .78542 L F
.73 .294 .215 r
.53184 .78729 m .53248 .78564 L .53111 .78519 L F
.53184 .78729 m .53456 .78758 L .53248 .78564 L F
.75 .454 0 r
.73443 .62759 m .7344 .62695 L .73288 .62687 L F
.713 .217 0 r
.73174 .62593 m .73288 .62687 L .73077 .62416 L F
0 .368 .8 r
.73174 .62593 m .73424 .6272 L .73443 .62759 L F
.73424 .6272 m .73503 .6276 L .73443 .62759 L F
.75 .454 0 r
.73443 .62759 m .73517 .62979 L .73477 .62829 L F
.73443 .62759 m .73477 .62829 L .7344 .62695 L F
.427 .312 .62 r
.41671 .78827 m .41816 .78542 L .41577 .7868 L F
.41671 .78827 m .41821 .78899 L .41816 .78542 L F
.627 .119 .024 r
.47738 .78397 m .47937 .78531 L .476 .78486 L F
.046 .437 .872 r
.73144 .63047 m .73298 .63056 L .7306 .62954 L F
.73144 .63047 m .73444 .63192 L .73298 .63056 L F
.29 .072 .4 r
.38614 .69266 m .38414 .69543 L .3857 .69442 L F
.35 0 .129 r
.38414 .69543 m .38504 .69695 L .3857 .69442 L F
.38414 .69543 m .38293 .69737 L .38504 .69695 L F
.522 .649 .914 r
.38977 .66828 m .38952 .66569 L .38772 .6656 L F
.38977 .66828 m .3915 .66774 L .38952 .66569 L F
.031 0 0 r
.36164 .72139 m .36137 .72073 L .36321 .71988 L F
.36164 .72139 m .35969 .72204 L .36137 .72073 L F
.393 .072 .297 r
.38863 .70583 m .38572 .70879 L .38653 .70626 L F
.669 .308 .352 r
.52366 .70628 m .52193 .7085 L .52578 .70823 L F
.362 .546 .9 r
.38704 .64959 m .3861 .65091 L .38437 .64914 L F
.38704 .64959 m .38797 .65133 L .3861 .65091 L F
.469 .31 .583 r
.55705 .69003 m .5572 .69296 L .55917 .69164 L F
.646 .212 .204 r
.55917 .69164 m .55555 .69163 L .55705 .69003 L F
.211 0 0 r
.35064 .65039 m .35328 .64925 L .35131 .64953 L F
.422 0 0 r
.5327 .79232 m .53009 .79165 L .53341 .79123 L F
.694 .279 .254 r
.53586 .79146 m .5327 .79232 L .53341 .79123 L F
0 0 .212 r
.55894 .69673 m .55814 .69573 L .55979 .69447 L F
.55894 .69673 m .55768 .69817 L .55814 .69573 L F
.525 0 0 r
.37369 .648 m .37565 .64899 L .37692 .6491 L F
.778 .754 .832 r
.56156 .686 m .56606 .68703 L .56399 .68444 L F
.697 .193 .04 r
.56156 .686 m .56419 .68822 L .56606 .68703 L F
.966 .672 .419 r
.56606 .68703 m .56444 .68712 L .56399 .68444 L F
.931 .569 .311 r
.56606 .68703 m .56419 .68822 L .56444 .68712 L F
.526 .845 .999 r
.36087 .70724 m .35743 .70691 L .35918 .70611 L F
.221 .618 .953 r
.36146 .70634 m .36087 .70724 L .35918 .70611 L F
.36146 .70634 m .36264 .70718 L .36087 .70724 L F
0 0 0 r
.39517 .70254 m .39317 .70311 L .39677 .70157 L F
.39517 .70254 m .39677 .70157 L .39664 .70096 L F
.846 .534 .461 r
.57405 .70072 m .57202 .70396 L .57553 .70387 L F
0 .067 .631 r
.58658 .74106 m .58774 .74374 L .5862 .74144 L F
.33 .811 .883 r
.5862 .74144 m .58425 .74153 L .58658 .74106 L F
.666 .739 .905 r
.73122 .73335 m .73436 .73445 L .73282 .73395 L F
.648 .866 .981 r
.40483 .77796 m .40499 .77862 L .40797 .77791 L F
.807 .923 .541 r
.73002 .6035 m .73082 .60245 L .7302 .6017 L F
.614 .566 .777 r
.41285 .65952 m .41066 .66013 L .40968 .65686 L F
.744 .303 .205 r
.5035 .78513 m .5065 .78579 L .50591 .78605 L F
.623 .084 0 r
.50511 .78593 m .5065 .78579 L .5035 .78513 L F
.735 .21 0 r
.50732 .78759 m .5065 .78579 L .50511 .78593 L F
.50732 .78759 m .50846 .78791 L .5065 .78579 L F
.68 .154 0 r
.51014 .78935 m .5065 .78579 L .50846 .78791 L F
.367 .822 .717 r
.37472 .67028 m .37862 .6686 L .37672 .66967 L F
.522 .882 .659 r
.38037 .66724 m .3794 .66783 L .37862 .6686 L F
.518 .869 .623 r
.37862 .6686 m .3782 .6687 L .37672 .66967 L F
.37862 .6686 m .3794 .66783 L .3782 .6687 L F
.436 .862 .733 r
.51014 .78935 m .51208 .78834 L .51278 .78805 L F
.573 .66 .896 r
.73077 .62416 m .72446 .6217 L .72971 .62354 L F
.713 .217 0 r
.73174 .62593 m .73077 .62416 L .72971 .62354 L F
.346 0 .08 r
.49105 .71977 m .49332 .7194 L .49451 .71761 L F
0 0 0 r
.49451 .71761 m .49595 .71671 L .49588 .71651 L F
.093 0 0 r
.49451 .71761 m .49515 .71856 L .49595 .71671 L F
.49451 .71761 m .49332 .7194 L .49515 .71856 L F
.509 .395 .659 r
.41778 .7445 m .41999 .74672 L .41976 .74411 L F
.41778 .7445 m .41795 .74737 L .41999 .74672 L F
.6 .344 .501 r
.73778 .72722 m .73543 .7261 L .73739 .72553 L F
.73778 .72722 m .73547 .72792 L .73543 .7261 L F
.783 .738 .811 r
.45379 .75505 m .45121 .75562 L .45296 .75306 L F
.499 .043 .099 r
.45379 .75505 m .45286 .75643 L .45121 .75562 L F
.152 .352 .808 r
.45296 .75306 m .45498 .75462 L .45379 .75505 L F
0 0 0 r
.45498 .75462 m .45286 .75643 L .45379 .75505 L F
.714 .462 .543 r
.49335 .78038 m .49085 .78034 L .49064 .78267 L F
.597 .29 .42 r
.49064 .78267 m .49287 .78298 L .49335 .78038 L F
.685 .312 .333 r
.49496 .78434 m .49335 .78038 L .49287 .78298 L F
.49496 .78434 m .4966 .7822 L .49335 .78038 L F
.775 .827 .893 r
.50637 .79021 m .50759 .79166 L .51014 .78935 L F
.868 .728 .706 r
.31683 .74182 m .31545 .74222 L .31643 .73913 L F
.825 .574 .559 r
.31683 .74182 m .31469 .7448 L .31545 .74222 L F
.336 .35 .727 r
.31643 .73913 m .31882 .74145 L .31683 .74182 L F
.646 .485 .65 r
.31545 .74222 m .31655 .74266 L .31643 .73913 L F
.31655 .74266 m .31686 .74278 L .31682 .74244 L F
.31655 .74266 m .31682 .74244 L .31643 .73913 L F
.173 0 .101 r
.31785 .74163 m .31682 .74244 L .31683 .74182 L F
.491 .372 .645 r
.31682 .74244 m .31686 .74278 L .31882 .74145 L F
.173 0 .101 r
.31882 .74145 m .31582 .74323 L .31785 .74163 L F
.491 .372 .645 r
.31643 .73913 m .31682 .74244 L .31882 .74145 L F
.678 .416 .518 r
.31655 .74266 m .31469 .7448 L .31686 .74278 L F
.173 0 .101 r
.31667 .74252 m .31582 .74323 L .31614 .74278 L F
.31655 .74266 m .31582 .74323 L .31667 .74252 L F
.678 .416 .518 r
.31545 .74222 m .31469 .7448 L .31655 .74266 L F
.173 0 .101 r
.31682 .74244 m .31655 .74266 L .31667 .74252 L F
.31682 .74244 m .31614 .74278 L .31683 .74182 L F
0 0 0 r
.31686 .74278 m .31469 .7448 L .31882 .74145 L F
.173 0 .101 r
.31882 .74145 m .31469 .7448 L .31582 .74323 L F
0 0 .099 r
.56206 .69172 m .55979 .69447 L .56052 .69304 L F
.302 .09 .416 r
.53977 .74476 m .53996 .74719 L .54209 .74435 L F
.881 .758 .722 r
.30042 .73582 m .30258 .73768 L .30213 .73778 L F
.268 .771 .87 r
.72349 .58117 m .7256 .58082 L .72656 .58093 L F
.597 .03 0 r
.72741 .58211 m .72656 .58093 L .7256 .58082 L F
.72741 .58211 m .72912 .5825 L .72656 .58093 L F
.549 .258 .425 r
.44642 .73631 m .44873 .73615 L .4496 .73348 L F
.536 .233 .401 r
.44873 .73615 m .45185 .73343 L .4496 .73348 L F
.541 .724 .958 r
.30545 .59939 m .30342 .59974 L .30221 .5984 L F
.419 .047 .223 r
.48073 .72725 m .4838 .72491 L .48182 .72537 L F
.331 .757 .974 r
.71977 .58058 m .72349 .58117 L .72115 .58174 L F
.553 .765 .977 r
.55555 .69163 m .5572 .69296 L .55453 .69331 L F
.307 .187 .549 r
.43764 .76082 m .4377 .76319 L .43635 .76281 L F
.899 .921 .826 r
.51478 .79703 m .51696 .79424 L .51421 .79509 L F
.596 .355 .522 r
.52789 .76686 m .52777 .76914 L .52529 .76922 L F
.441 .14 .357 r
.53091 .76673 m .52777 .76914 L .52789 .76686 L F
.833 .6 .586 r
.29183 .72169 m .29273 .72044 L .29116 .72102 L F
.29183 .72169 m .29475 .71995 L .29273 .72044 L F
.528 .506 .775 r
.51485 .7474 m .51701 .74732 L .51607 .74424 L F
.192 .719 .846 r
.44591 .7859 m .44256 .78597 L .44378 .786 L F
0 0 0 r
.51168 .79124 m .51108 .794 L .51276 .79391 L F
.491 .441 .729 r
.51108 .794 m .51349 .79566 L .51276 .79391 L F
0 0 0 r
.58658 .67248 m .58581 .67303 L .58442 .67358 L F
.58581 .67303 m .58272 .67509 L .58442 .67358 L F
.404 .189 .471 r
.32179 .60966 m .31961 .613 L .31925 .61077 L F
.659 .206 .166 r
.49546 .78785 m .49887 .78822 L .49783 .7894 L F
.659 .172 .083 r
.50068 .78983 m .49783 .7894 L .49887 .78822 L F
0 0 0 r
.59943 .75819 m .60238 .75567 L .60104 .75716 L F
.056 0 0 r
.60238 .75567 m .604 .7555 L .60104 .75716 L F
.60238 .75567 m .60428 .7549 L .604 .7555 L F
.764 .556 .616 r
.61796 .66214 m .62127 .65996 L .618 .65987 L F
.61796 .66214 m .62126 .66233 L .62127 .65996 L F
.038 0 .075 r
.30194 .70942 m .30082 .71155 L .30366 .70834 L F
.787 .291 .014 r
.72446 .6217 m .72388 .62131 L .72671 .62074 L F
0 .114 .662 r
.72446 .6217 m .72719 .62512 L .72672 .62473 L F
.278 .595 .949 r
.72938 .62255 m .72446 .6217 L .72671 .62074 L F
.72938 .62255 m .72971 .62354 L .72446 .6217 L F
.947 .9 .512 r
.62834 .68332 m .62748 .68723 L .62895 .68393 L F
.714 .841 .943 r
.38037 .66724 m .38331 .66673 L .38267 .66648 L F
.389 .819 .962 r
.38561 .66636 m .38267 .66648 L .38331 .66673 L F
.718 .322 .296 r
.52401 .74772 m .5231 .74895 L .5207 .74712 L F
.326 .306 .683 r
.53529 .74538 m .53625 .74781 L .53388 .74757 L F
.469 0 0 r
.53388 .74757 m .53647 .74962 L .53509 .7475 L F
.689 .399 .478 r
.5385 .75025 m .53511 .75235 L .5351 .75005 L F
.469 0 0 r
.53388 .74757 m .53724 .75031 L .53702 .75011 L F
.53484 .74833 m .53702 .75011 L .53647 .74962 L F
.53388 .74757 m .53702 .75011 L .53484 .74833 L F
.689 .399 .478 r
.5385 .75025 m .53974 .7545 L .53511 .75235 L F
.457 .273 .543 r
.53834 .74846 m .53719 .75025 L .53829 .75079 L F
.53719 .75025 m .53639 .75149 L .53799 .7509 L F
.53719 .75025 m .53799 .7509 L .53829 .75079 L F
0 0 .073 r
.53931 .74764 m .53834 .74846 L .53996 .74719 L F
.53647 .74962 m .53834 .74846 L .53931 .74764 L F
.53647 .74962 m .53724 .75031 L .53834 .74846 L F
.734 .523 .606 r
.53834 .74846 m .53724 .75031 L .53529 .74538 L F
.711 .254 .165 r
.53739 .74926 m .53834 .74846 L .53687 .74784 L F
.53763 .7499 m .53834 .74846 L .53739 .74926 L F
.326 .306 .683 r
.53625 .74781 m .53724 .75031 L .53388 .74757 L F
.123 0 0 r
.53274 .74745 m .53388 .74757 L .53509 .7475 L F
.5316 .74743 m .53388 .74757 L .53274 .74745 L F
.454 .009 .102 r
.46747 .73054 m .46963 .73062 L .47109 .72883 L F
.397 0 .065 r
.47109 .72883 m .46963 .73062 L .47285 .72949 L F
.371 .806 .641 r
.5577 .68134 m .5588 .68067 L .56016 .67996 L F
0 0 0 r
.5588 .68067 m .55737 .68193 L .55985 .68004 L F
.392 .818 .646 r
.5588 .68067 m .5601 .67985 L .56073 .67953 L F
0 0 0 r
.5588 .68067 m .55985 .68004 L .5601 .67985 L F
.371 .806 .641 r
.55741 .6815 m .5588 .68067 L .5577 .68134 L F
0 0 0 r
.55741 .6815 m .55635 .68274 L .5588 .68067 L F
.72 .358 .362 r
.67629 .59039 m .67708 .58869 L .67431 .58818 L F
.284 .473 .868 r
.73896 .58862 m .74174 .58994 L .74066 .5912 L F
.556 .5 .748 r
.74174 .58994 m .7403 .59408 L .74066 .5912 L F
.053 0 .248 r
.6234 .69779 m .62329 .70006 L .62161 .70092 L F
0 0 .121 r
.62329 .70006 m .62117 .70303 L .62161 .70092 L F
.665 .665 .84 r
.34277 .70286 m .33938 .7011 L .34149 .7005 L F
.642 .681 .872 r
.34502 .70155 m .34277 .70286 L .34149 .7005 L F
.546 .833 .998 r
.28041 .59493 m .27983 .59628 L .27828 .59536 L F
.28041 .59493 m .28198 .59574 L .27983 .59628 L F
.447 .486 .807 r
.74083 .71663 m .74179 .71962 L .74003 .71977 L F
.3 .334 .729 r
.74242 .72177 m .74003 .71977 L .74179 .71962 L F
.712 .395 .438 r
.54919 .74859 m .54631 .74756 L .55014 .74739 L F
.341 0 0 r
.55214 .74831 m .54919 .74859 L .55014 .74739 L F
.138 .518 .915 r
.29799 .71467 m .29928 .71487 L .29768 .71351 L F
.513 .856 .994 r
.57468 .74477 m .57533 .74364 L .57567 .74153 L F
.57468 .74477 m .57315 .7442 L .57533 .74364 L F
0 .177 .698 r
.57468 .74477 m .57533 .74364 L .57315 .7442 L F
.57468 .74477 m .57647 .74671 L .57533 .74364 L F
.414 .281 .589 r
.57471 .74647 m .57647 .74671 L .57468 .74477 L F
.562 .651 .894 r
.53508 .75465 m .53434 .75749 L .53363 .75453 L F
.53508 .75465 m .53704 .75716 L .53434 .75749 L F
.617 .643 .854 r
.53724 .75852 m .53434 .75749 L .53704 .75716 L F
.382 .416 .772 r
.52927 .7133 m .53011 .71657 L .52771 .71544 L F
.47 .274 .532 r
.28844 .62167 m .29005 .62349 L .28954 .62123 L F
.28844 .62167 m .2881 .62407 L .29005 .62349 L F
.402 .184 .465 r
.41926 .78577 m .42011 .78791 L .4211 .78653 L F
.315 0 0 r
.41926 .78577 m .42148 .78661 L .41997 .78607 L F
.503 .506 .792 r
.4222 .78499 m .42148 .78661 L .41926 .78577 L F
.402 .184 .465 r
.41926 .78577 m .41997 .78607 L .4222 .78499 L F
.815 .388 .231 r
.41816 .78542 m .42011 .78791 L .41926 .78577 L F
.315 0 0 r
.41926 .78577 m .41997 .78607 L .41816 .78542 L F
.583 .618 .852 r
.41816 .78542 m .41997 .78607 L .41858 .78278 L F
.41997 .78607 m .42148 .78661 L .4208 .78571 L F
.41997 .78607 m .4208 .78571 L .41858 .78278 L F
.606 .626 .845 r
.41858 .78278 m .4208 .78571 L .4222 .78499 L F
.4208 .78571 m .42148 .78661 L .4222 .78499 L F
.402 .184 .465 r
.4208 .78571 m .4211 .78653 L .42209 .78514 L F
.41997 .78607 m .42004 .78609 L .4208 .78571 L F
.42004 .78609 m .4211 .78653 L .4208 .78571 L F
.41997 .78607 m .42209 .78514 L .4222 .78499 L F
.624 .674 .878 r
.72208 .73056 m .72528 .73191 L .72445 .73017 L F
.529 .655 .915 r
.72528 .73191 m .72669 .72998 L .72445 .73017 L F
.72528 .73191 m .72753 .73171 L .72669 .72998 L F
.559 .474 .715 r
.30941 .69266 m .31105 .68988 L .30891 .69035 L F
.30941 .69266 m .31153 .69224 L .31105 .68988 L F
.537 .405 .649 r
.30941 .69266 m .31173 .69491 L .31153 .69224 L F
.30941 .69266 m .30968 .6954 L .31173 .69491 L F
.899 .921 .826 r
.51478 .79703 m .51421 .79509 L .51349 .79566 L F
.228 .281 .711 r
.70618 .60474 m .70674 .60845 L .70813 .60667 L F
.402 .532 .873 r
.70674 .60845 m .7095 .60947 L .70813 .60667 L F
.559 .245 .392 r
.45415 .73334 m .45644 .73326 L .45745 .73076 L F
.472 .125 .296 r
.45644 .73326 m .45972 .73074 L .45745 .73076 L F
.507 .294 .526 r
.32089 .67046 m .32114 .66817 L .31884 .67091 L F
.495 .284 .522 r
.32317 .66771 m .32114 .66817 L .32089 .67046 L F
0 0 .405 r
.53964 .74936 m .5385 .75025 L .54085 .75011 L F
.5396 .74934 m .53958 .74936 L .53964 .74936 L F
.53958 .74936 m .5385 .75025 L .53964 .74936 L F
.53948 .74933 m .5385 .75025 L .5396 .74934 L F
.53948 .74933 m .53974 .7545 L .5385 .75025 L F
.53953 .74944 m .53974 .7545 L .53948 .74933 L F
.565 .413 .634 r
.54056 .75458 m .53974 .7545 L .53953 .7495 L F
.53 .334 .56 r
.53834 .74846 m .53928 .74931 L .54061 .74804 L F
.565 .413 .634 r
.53956 .7495 m .53953 .7495 L .53952 .7493 L F
.53956 .7495 m .53952 .7493 L .53953 .7493 L F
.518 .285 .5 r
.54308 .74746 m .54293 .74975 L .54085 .75011 L F
.938 .768 .644 r
.54253 .74982 m .54021 .74941 L .54085 .75011 L F
.54021 .74941 m .53953 .74929 L .53987 .7495 L F
.54021 .74941 m .53987 .7495 L .54085 .75011 L F
.54293 .74975 m .54206 .74963 L .54253 .74982 L F
.54206 .74963 m .53953 .74929 L .54253 .74982 L F
.654 .347 .44 r
.54631 .74756 m .54293 .74975 L .54308 .74746 L F
.54631 .74756 m .54694 .74975 L .54293 .74975 L F
.53 .334 .56 r
.53928 .74931 m .54055 .74928 L .54061 .74804 L F
.938 .768 .644 r
.53953 .74929 m .53952 .74929 L .53953 .74929 L F
.53953 .74929 m .53953 .74929 L .54085 .75011 L F
0 0 .405 r
.53952 .74929 m .53948 .74933 L .5396 .74934 L F
.938 .768 .644 r
.54293 .74975 m .54132 .75377 L .53953 .7493 L F
.53953 .74929 m .53953 .7493 L .53952 .74929 L F
.54293 .74975 m .53953 .7493 L .53953 .74929 L F
.53 .334 .56 r
.53953 .7493 m .5396 .7496 L .54055 .74928 L F
0 0 .405 r
.53952 .74929 m .53953 .74944 L .53948 .74933 L F
.53952 .74929 m .53952 .7493 L .53952 .74929 L F
.53952 .7493 m .53953 .74944 L .53952 .74929 L F
.53 .334 .56 r
.53943 .7493 m .5395 .74942 L .53953 .74931 L F
.53952 .7493 m .53953 .74931 L .53953 .7493 L F
.53943 .7493 m .53953 .74931 L .53952 .7493 L F
.5395 .74942 m .5396 .7496 L .53953 .7493 L F
0 0 .174 r
.5439 .75073 m .54293 .74975 L .54546 .75147 L F
.54381 .75064 m .54132 .75377 L .54293 .74975 L F
.5439 .75073 m .54225 .75268 L .54381 .75064 L F
.54225 .75268 m .54132 .75377 L .54381 .75064 L F
.672 .65 .821 r
.54294 .75419 m .54256 .75364 L .54132 .75377 L F
.609 .631 .847 r
.54498 .75339 m .54256 .75364 L .5439 .75073 L F
.54256 .75364 m .54132 .75377 L .54225 .75268 L F
.54256 .75364 m .54225 .75268 L .5439 .75073 L F
.672 .65 .821 r
.54256 .75364 m .53952 .74929 L .54132 .75377 L F
.54256 .75364 m .54083 .75454 L .54206 .75293 L F
.609 .631 .847 r
.54259 .75375 m .54294 .75419 L .54132 .75377 L F
.672 .65 .821 r
.54294 .75419 m .54259 .75375 L .54256 .75364 L F
.609 .631 .847 r
.54511 .7537 m .54294 .75419 L .54259 .75375 L F
.672 .65 .821 r
.54294 .75419 m .54274 .75423 L .54259 .75375 L F
.54274 .75423 m .54083 .75454 L .54256 .75364 L F
.609 .631 .847 r
.54511 .7537 m .54132 .75377 L .54498 .75339 L F
.672 .65 .821 r
.54127 .75179 m .54056 .75458 L .53955 .74945 L F
.53966 .74948 m .53955 .74945 L .53952 .74929 L F
.54127 .75179 m .53955 .74945 L .53966 .74948 L F
.565 .413 .634 r
.54056 .75458 m .53953 .7495 L .53956 .7495 L F
.711 .254 .165 r
.53763 .7499 m .53992 .75031 L .53932 .74937 L F
.53921 .74933 m .53932 .74937 L .53928 .74931 L F
.53763 .7499 m .53932 .74937 L .53921 .74933 L F
.53992 .75031 m .5405 .75041 L .5396 .7496 L F
.623 .096 0 r
.53763 .7499 m .53937 .75113 L .5405 .75041 L F
.413 0 .004 r
.53937 .75113 m .54088 .74935 L .5405 .75041 L F
.977 .735 .503 r
.54061 .74804 m .5405 .75041 L .54105 .74914 L F
.413 0 .004 r
.54088 .74935 m .541 .7492 L .54089 .74946 L F
.54088 .74935 m .54089 .74946 L .5405 .75041 L F
.672 .65 .821 r
.54206 .75293 m .54154 .7535 L .54127 .75179 L F
.54154 .7535 m .54056 .75458 L .54127 .75179 L F
.54083 .75454 m .54056 .75458 L .54206 .75293 L F
.599 .201 .259 r
.54694 .74975 m .54546 .75147 L .54293 .74975 L F
.194 0 .023 r
.5412 .74916 m .54126 .75124 L .54394 .74945 L F
.54105 .74914 m .54105 .7492 L .5412 .74916 L F
.54105 .7492 m .54126 .75124 L .5412 .74916 L F
.413 0 .004 r
.541 .7492 m .54105 .74914 L .54102 .74921 L F
.541 .7492 m .54102 .74921 L .5405 .75041 L F
.53 .334 .56 r
.53928 .74931 m .5393 .74933 L .53943 .7493 L F
.5393 .74933 m .5396 .7496 L .53943 .7493 L F
.413 0 .004 r
.54061 .74966 m .54083 .74954 L .54071 .74954 L F
.53 .334 .56 r
.5396 .7496 m .5405 .75041 L .54053 .74966 L F
.413 0 .004 r
.53937 .75113 m .54072 .74967 L .54061 .74966 L F
.54072 .74967 m .54083 .74954 L .54061 .74966 L F
.53 .334 .56 r
.5396 .7496 m .54053 .74966 L .54055 .74928 L F
.565 .413 .634 r
.53953 .7493 m .53952 .7493 L .53952 .74929 L F
.413 0 .004 r
.54071 .74954 m .54106 .74929 L .54092 .7493 L F
.54083 .74954 m .54106 .74929 L .54071 .74954 L F
.711 .254 .165 r
.53992 .75031 m .5396 .7496 L .53928 .74931 L F
.413 0 .004 r
.53937 .75113 m .54126 .75124 L .54106 .74929 L F
.54092 .7493 m .54106 .74929 L .54105 .74914 L F
.711 .254 .165 r
.53798 .74919 m .53928 .74931 L .53834 .74846 L F
.53763 .7499 m .53928 .74931 L .53798 .74919 L F
.598 .95 .837 r
.73959 .60665 m .73822 .608 L .74075 .6075 L F
.73959 .60665 m .73779 .60789 L .73822 .608 L F
.967 .808 .381 r
.74014 .60895 m .73822 .608 L .73779 .60789 L F
.74014 .60895 m .74075 .6075 L .73822 .608 L F
.558 .432 .665 r
.30891 .69035 m .31105 .68988 L .31045 .68689 L F
.631 .526 .717 r
.55316 .72943 m .55123 .73202 L .55086 .72788 L F
.317 0 0 r
.55446 .73314 m .5504 .73162 L .55123 .73202 L F
.867 .835 .812 r
.72187 .61315 m .72324 .6144 L .7243 .61293 L F
.218 0 .111 r
.51705 .78761 m .51985 .78528 L .51784 .78595 L F
.648 .514 .686 r
.59427 .72036 m .59689 .7224 L .59772 .72055 L F
.526 .248 .436 r
.59689 .7224 m .59952 .71961 L .59772 .72055 L F
.767 .33 .214 r
.48167 .77918 m .48115 .77805 L .48081 .7797 L F
.021 .26 .761 r
.56623 .72009 m .56681 .71909 L .56465 .71708 L F
.052 .303 .791 r
.56623 .72009 m .56882 .72224 L .56681 .71909 L F
.245 .749 .699 r
.59865 .7256 m .59774 .72584 L .59496 .72676 L F
.489 .439 .728 r
.59932 .72756 m .60125 .72736 L .59865 .7256 L F
.59942 .72786 m .60125 .72736 L .59932 .72756 L F
.293 .755 .948 r
.60327 .72715 m .60324 .72714 L .60125 .72736 L F
.389 0 0 r
.60125 .72736 m .59774 .72584 L .59865 .7256 L F
.293 .755 .948 r
.60324 .72714 m .5998 .72683 L .60125 .72736 L F
0 .453 .819 r
.47868 .77614 m .47868 .77675 L .47708 .77378 L F
.69 .51 .638 r
.47708 .77378 m .4749 .77477 L .47704 .77163 L F
0 .453 .819 r
.47882 .77635 m .47708 .77378 L .47846 .77364 L F
.738 .559 .651 r
.47613 .77624 m .47772 .77447 L .47577 .77346 L F
.47772 .77447 m .47846 .77364 L .4772 .77355 L F
.47772 .77447 m .4772 .77355 L .47577 .77346 L F
0 .453 .819 r
.47882 .77635 m .47881 .77637 L .47868 .77614 L F
.47881 .77637 m .47868 .77675 L .47868 .77614 L F
.47882 .77635 m .47976 .777 L .47868 .77675 L F
.3 .793 .772 r
.44812 .78628 m .44934 .78604 L .45146 .78534 L F
.655 .593 .773 r
.41635 .66206 m .41406 .66291 L .41285 .65952 L F
.772 .264 0 r
.53277 .73026 m .53031 .72782 L .53374 .7283 L F
.674 .321 .367 r
.536 .73025 m .53277 .73026 L .53374 .7283 L F
.511 .272 .489 r
.42419 .67321 m .42173 .67568 L .42204 .67363 L F
.536 .352 .578 r
.42421 .67085 m .42419 .67321 L .42204 .67363 L F
.596 .103 .054 r
.55768 .69817 m .56006 .69939 L .56131 .69834 L F
.568 .905 .977 r
.56006 .69939 m .5628 .69907 L .56131 .69834 L F
.512 .093 .182 r
.56131 .69834 m .5628 .69907 L .56375 .6983 L F
.273 .608 .955 r
.3009 .5971 m .29989 .59794 L .29847 .59714 L F
.3009 .5971 m .30221 .5984 L .29989 .59794 L F
0 .154 .679 r
.30431 .73659 m .30534 .73949 L .30586 .7382 L F
.355 0 .044 r
.56476 .69814 m .56586 .69821 L .5672 .69777 L F
.631 .067 0 r
.56586 .69821 m .56901 .70004 L .56912 .69774 L F
.249 .289 .708 r
.56704 .69608 m .5681 .69834 L .56586 .69821 L F
.814 .642 .669 r
.56733 .70106 m .56805 .70249 L .56901 .70004 L F
.56567 .70207 m .56772 .70243 L .56733 .70106 L F
.56772 .70243 m .56805 .70249 L .56733 .70106 L F
.56567 .70207 m .56733 .70106 L .56942 .70116 L F
.56733 .70106 m .56901 .70004 L .56942 .70116 L F
.631 .067 0 r
.56586 .69821 m .56672 .69893 L .56694 .69883 L F
.56885 .69994 m .56942 .70116 L .56901 .70004 L F
.249 .289 .708 r
.56755 .69857 m .56942 .70116 L .56672 .69893 L F
.56902 .7003 m .56942 .70116 L .56755 .69857 L F
.503 .819 1 r
.56861 .70135 m .56693 .70075 L .56567 .70207 L F
.56942 .70116 m .56693 .70075 L .56861 .70135 L F
.543 .672 .921 r
.5639 .69927 m .56693 .70075 L .5655 .69937 L F
.918 .655 .523 r
.5655 .69937 m .56693 .70075 L .5639 .69927 L F
.5655 .69937 m .56577 .70032 L .56693 .70075 L F
.325 0 0 r
.56799 .70399 m .56771 .70383 L .56805 .70249 L F
.864 .542 .441 r
.56567 .70207 m .56799 .70399 L .56805 .70249 L F
.56567 .70207 m .56608 .70414 L .56799 .70399 L F
0 0 .332 r
.56655 .703 m .56567 .70207 L .56693 .70075 L F
.918 .655 .523 r
.56577 .70032 m .56655 .703 L .56693 .70075 L F
.541 .443 .692 r
.56945 .69822 m .56942 .70116 L .56704 .69608 L F
.782 .752 .826 r
.57041 .7008 m .56942 .70116 L .56945 .69822 L F
.57041 .7008 m .56693 .70075 L .56942 .70116 L F
.734 .363 .349 r
.56943 .70079 m .56803 .70253 L .56693 .70075 L F
.57041 .7008 m .56982 .70124 L .56943 .70079 L F
.56982 .70124 m .56803 .70253 L .56943 .70079 L F
.249 .289 .708 r
.5681 .69834 m .56902 .7003 L .56755 .69857 L F
.56653 .69825 m .56672 .69893 L .56586 .69821 L F
.5681 .69834 m .56672 .69893 L .56653 .69825 L F
.355 0 .044 r
.56375 .6983 m .56586 .69821 L .56476 .69814 L F
.871 .824 .8 r
.72389 .6101 m .7243 .61293 L .72547 .61117 L F
.72389 .6101 m .72187 .61315 L .7243 .61293 L F
.418 .028 .19 r
.28798 .65095 m .28453 .65333 L .28631 .65191 L F
0 0 0 r
.59719 .66602 m .59582 .66726 L .59419 .66777 L F
.115 0 0 r
.5973 .66674 m .59719 .66602 L .59854 .66569 L F
.5973 .66674 m .59582 .66726 L .59719 .66602 L F
.595 .423 .619 r
.34469 .68415 m .34455 .68945 L .34193 .6881 L F
.341 .217 .562 r
.34616 .68693 m .34469 .68415 L .3467 .68387 L F
.34616 .68693 m .34455 .68945 L .34469 .68415 L F
.58 .255 .383 r
.47673 .74228 m .47883 .74389 L .47654 .74394 L F
.354 .5 .866 r
.53863 .75745 m .53724 .75852 L .53704 .75716 L F
0 0 .511 r
.53853 .75992 m .53724 .75852 L .53863 .75745 L F
.715 .189 0 r
.52578 .70823 m .52914 .7112 L .52648 .70933 L F
.517 .482 .757 r
.44234 .77137 m .44127 .77517 L .44028 .77169 L F
.44234 .77137 m .44329 .77527 L .44127 .77517 L F
.593 .551 .777 r
.41214 .77453 m .41338 .77754 L .41561 .77718 L F
.466 .461 .768 r
.41338 .77754 m .41581 .77985 L .41561 .77718 L F
.504 .408 .679 r
.30779 .69842 m .31004 .70039 L .30984 .69794 L F
.30779 .69842 m .30812 .70084 L .31004 .70039 L F
0 .211 .699 r
.561 .71258 m .56239 .71325 L .56004 .71165 L F
.561 .71258 m .56324 .71421 L .56239 .71325 L F
.749 .4 .391 r
.70535 .58216 m .70882 .58075 L .70561 .57964 L F
.56 .935 .845 r
.71073 .58227 m .71092 .58178 L .7123 .58148 L F
.70952 .58288 m .70988 .58259 L .71073 .58227 L F
.70988 .58259 m .71092 .58178 L .71073 .58227 L F
.749 .4 .391 r
.70535 .58216 m .70902 .58292 L .70882 .58075 L F
.111 .133 .603 r
.70961 .58284 m .71006 .58313 L .70952 .58288 L F
0 0 .136 r
.70952 .58288 m .71053 .58242 L .71092 .58178 L F
.111 .133 .603 r
.70947 .58275 m .70961 .58284 L .70952 .58288 L F
.749 .4 .391 r
.70902 .58292 m .70978 .58307 L .7098 .58262 L F
.111 .133 .603 r
.70882 .58075 m .71006 .58313 L .70947 .58275 L F
.749 .4 .391 r
.70978 .58307 m .71006 .58313 L .70985 .58273 L F
.293 0 .229 r
.71006 .58313 m .70932 .58441 L .70952 .58288 L F
0 0 .136 r
.70952 .58288 m .70957 .58375 L .70985 .58273 L F
.781 .509 .525 r
.70973 .58322 m .70932 .58441 L .71006 .58313 L F
0 0 .136 r
.70952 .58288 m .70932 .58441 L .70958 .58398 L F
.781 .509 .525 r
.70569 .58427 m .70932 .58441 L .70973 .58322 L F
0 0 .136 r
.70957 .58375 m .70958 .58398 L .70977 .58312 L F
.781 .509 .525 r
.70973 .58322 m .71006 .58313 L .70978 .58307 L F
0 0 .136 r
.70973 .58322 m .70977 .58312 L .70978 .58307 L F
.70957 .58375 m .70977 .58312 L .70973 .58322 L F
.70957 .58375 m .70978 .58307 L .70985 .58273 L F
.781 .509 .525 r
.70569 .58427 m .70973 .58322 L .70535 .58216 L F
.70973 .58322 m .70978 .58307 L .70535 .58216 L F
.749 .4 .391 r
.70978 .58307 m .70985 .58273 L .7098 .58262 L F
0 0 .136 r
.70985 .58273 m .70958 .58398 L .71053 .58242 L F
.749 .4 .391 r
.70902 .58292 m .7098 .58262 L .70882 .58075 L F
.683 .704 .863 r
.70008 .60266 m .70126 .59915 L .69864 .60153 L F
.70008 .60266 m .70255 .60203 L .70126 .59915 L F
.354 .715 .986 r
.27132 .59363 m .27078 .59463 L .26931 .59347 L F
.27132 .59363 m .27286 .59466 L .27078 .59463 L F
.509 .319 .558 r
.52144 .7663 m .52372 .76343 L .52142 .76384 L F
.234 .25 .673 r
.29985 .71244 m .30124 .71373 L .30082 .71155 L F
.29985 .71244 m .30124 .71373 L .30082 .71155 L F
.542 .677 .926 r
.52389 .75474 m .52538 .75732 L .52761 .75629 L F
.517 .585 .862 r
.52538 .75732 m .52791 .75798 L .52761 .75629 L F
0 0 .166 r
.62464 .69471 m .62448 .69668 L .6234 .69779 L F
0 0 .145 r
.62448 .69668 m .62329 .70006 L .6234 .69779 L F
0 .092 .629 r
.57092 .72816 m .57115 .72785 L .56944 .72766 L F
.57092 .72816 m .57302 .73025 L .57115 .72785 L F
.573 .305 .471 r
.52514 .72856 m .52504 .73076 L .52248 .73076 L F
.76 .951 .939 r
.52741 .72752 m .52699 .72782 L .5256 .72981 L F
0 0 .294 r
.5256 .72981 m .52504 .73061 L .52514 .72856 L F
.76 .951 .939 r
.52699 .72782 m .52456 .72954 L .5256 .72981 L F
0 0 .294 r
.5256 .72981 m .52504 .73076 L .52504 .73061 L F
.36 .167 .478 r
.3857 .69442 m .38795 .69188 L .38614 .69266 L F
0 0 .499 r
.57332 .73915 m .57434 .73819 L .57411 .73573 L F
.188 .324 .771 r
.57332 .73915 m .57567 .74153 L .57434 .73819 L F
.731 .583 .69 r
.4882 .73954 m .48914 .74157 L .48854 .74245 L F
.186 .228 .673 r
.39804 .70037 m .39664 .70096 L .39614 .69832 L F
.13 0 0 r
.39711 .70188 m .39664 .70096 L .39804 .70037 L F
.39711 .70188 m .39517 .70254 L .39664 .70096 L F
.498 .368 .634 r
.31884 .67091 m .32094 .67288 L .32089 .67046 L F
.31884 .67091 m .31904 .67342 L .32094 .67288 L F
.361 .445 .812 r
.58391 .7305 m .58383 .73372 L .58286 .73181 L F
.58391 .7305 m .58515 .73348 L .58383 .73372 L F
.939 .587 .323 r
.73965 .59891 m .73843 .59873 L .73786 .59662 L F
.219 0 0 r
.73965 .59891 m .742 .59946 L .73843 .59873 L F
.561 .417 .642 r
.31265 .68177 m .31503 .68422 L .31477 .68125 L F
.31265 .68177 m .31297 .6849 L .31503 .68422 L F
.272 0 .242 r
.3849 .71035 m .38282 .70975 L .38572 .70879 L F
.3849 .71035 m .38311 .71115 L .38282 .70975 L F
.474 .245 .485 r
.41351 .75264 m .41554 .75223 L .41585 .74974 L F
.533 .342 .568 r
.41585 .74974 m .41795 .7496 L .41795 .74737 L F
.598 .39 .57 r
.41554 .75223 m .41795 .7496 L .41585 .74974 L F
.355 .543 .9 r
.39467 .65165 m .39533 .65412 L .39362 .65204 L F
.39467 .65165 m .39659 .65401 L .39533 .65412 L F
.725 .551 .655 r
.55007 .73901 m .55231 .73907 L .5538 .73707 L F
.41 .152 .409 r
.5538 .73707 m .55231 .73907 L .55523 .73623 L F
.007 .414 .857 r
.5092 .72168 m .50981 .72092 L .50753 .71982 L F
0 .479 .859 r
.5853 .76325 m .5857 .76306 L .58349 .76102 L F
.5853 .76325 m .58689 .76392 L .5857 .76306 L F
.069 0 0 r
.36264 .70718 m .36453 .70704 L .36652 .70655 L F
.228 .742 .72 r
.36652 .70655 m .36648 .70647 L .36855 .70601 L F
.36652 .70655 m .36453 .70704 L .36648 .70647 L F
.393 .598 .928 r
.31582 .60483 m .31228 .60266 L .31428 .60284 L F
.494 .636 .917 r
.31779 .6047 m .31582 .60483 L .31428 .60284 L F
.481 .238 .468 r
.37898 .69834 m .38066 .70005 L .38103 .69788 L F
.37898 .69834 m .37859 .70051 L .38066 .70005 L F
.463 .172 .385 r
.41976 .74411 m .42173 .74375 L .42243 .74138 L F
.494 .316 .568 r
.42243 .74138 m .42442 .74117 L .42466 .73831 L F
.607 .374 .538 r
.42173 .74375 m .42442 .74117 L .42243 .74138 L F
.784 .545 .575 r
.48914 .74157 m .48788 .74419 L .48854 .74245 L F
.36 .106 .387 r
.42596 .67032 m .42421 .67085 L .42639 .66838 L F
.353 .04 .288 r
.42892 .66816 m .42596 .67032 L .42639 .66838 L F
.502 .336 .589 r
.42845 .66563 m .42892 .66816 L .42639 .66838 L F
.557 .753 .969 r
.28567 .61042 m .28619 .60866 L .28371 .60767 L F
.28567 .61042 m .28774 .61 L .28619 .60866 L F
.531 .517 .785 r
.28567 .61042 m .28862 .6131 L .28774 .61 L F
.798 .831 .877 r
.72389 .6101 m .72547 .61117 L .72668 .61027 L F
.843 .9 .878 r
.68581 .60495 m .68937 .60334 L .68815 .60196 L F
.789 .822 .878 r
.68815 .60196 m .68937 .60334 L .69105 .60198 L F
.648 .866 .981 r
.40483 .77796 m .40797 .77791 L .40643 .77692 L F
.683 .405 .494 r
.74104 .72553 m .73778 .72722 L .73739 .72553 L F
.74104 .72553 m .74095 .72755 L .73778 .72722 L F
.563 .321 .507 r
.74366 .72491 m .74095 .72755 L .74104 .72553 L F
.784 .545 .575 r
.48914 .74157 m .49131 .74451 L .48788 .74419 L F
.436 .241 .517 r
.49369 .74159 m .49131 .74451 L .48914 .74157 L F
.818 .617 .63 r
.61335 .6847 m .61308 .68695 L .61132 .68408 L F
.947 .9 .512 r
.62834 .68332 m .6272 .68643 L .62748 .68723 L F
.889 .667 .149 r
.6271 .68727 m .62748 .68723 L .6272 .68643 L F
.6271 .68727 m .62764 .6899 L .62748 .68723 L F
.574 .843 .996 r
.44689 .77551 m .44329 .77527 L .44569 .7749 L F
.375 .723 .989 r
.44772 .77445 m .44689 .77551 L .44569 .7749 L F
.44772 .77445 m .44913 .77555 L .44689 .77551 L F
0 0 0 r
.4451 .75544 m .44434 .75729 L .44338 .75843 L F
.58 .941 .904 r
.44434 .75729 m .44245 .75835 L .44338 .75843 L F
0 .264 .652 r
.34193 .6881 m .34455 .68945 L .34426 .6893 L F
.34193 .6881 m .34426 .6893 L .3424 .68973 L F
.588 .455 .666 r
.41157 .75596 m .41401 .75795 L .41365 .75559 L F
.41157 .75596 m .4118 .75834 L .41401 .75795 L F
.634 .733 .92 r
.33391 .73269 m .33553 .73415 L .33754 .73341 L F
.411 .065 .265 r
.58699 .66259 m .58931 .66209 L .59 .66001 L F
.427 .119 .338 r
.58931 .66209 m .59207 .65923 L .59 .66001 L F
.587 .787 .975 r
.72671 .62074 m .72388 .62131 L .72281 .62009 L F
0 0 .469 r
.72388 .62131 m .72524 .62289 L .72281 .62009 L F
.524 .684 .94 r
.53248 .71603 m .53127 .71771 L .53011 .71657 L F
.53248 .71603 m .53347 .71756 L .53127 .71771 L F
.477 .305 .568 r
.42615 .67265 m .42421 .67085 L .42596 .67032 L F
.42615 .67265 m .42419 .67321 L .42421 .67085 L F
.492 .828 .999 r
.47813 .74984 m .47573 .75016 L .47662 .74907 L F
.682 .498 .631 r
.47824 .75219 m .47573 .75016 L .47813 .74984 L F
.055 .005 .477 r
.47573 .75016 m .47654 .75044 L .47662 .74907 L F
.682 .498 .631 r
.47824 .75219 m .47576 .75294 L .47573 .75016 L F
.055 .005 .477 r
.47573 .75016 m .47576 .75294 L .47654 .75044 L F
.24 0 0 r
.36879 .7172 m .36717 .71871 L .36514 .7191 L F
.079 0 0 r
.36918 .71801 m .36879 .7172 L .3708 .71672 L F
.36918 .71801 m .36717 .71871 L .36879 .7172 L F
.644 .12 0 r
.7024 .57889 m .70309 .5779 L .70159 .57822 L F
.7024 .57889 m .70561 .57964 L .70309 .5779 L F
.61 .264 .359 r
.70309 .5779 m .70561 .57964 L .70525 .5781 L F
.235 .303 .73 r
.45286 .75643 m .45192 .75809 L .45121 .75562 L F
.66 .844 .436 r
.45286 .75643 m .45143 .75881 L .45192 .75809 L F
.394 .24 .552 r
.30822 .62889 m .3066 .62703 L .30831 .62654 L F
.30822 .62889 m .30617 .62831 L .3066 .62703 L F
.59 .626 .855 r
.58878 .74073 m .58909 .74591 L .58774 .74374 L F
.636 .701 .893 r
.58878 .74073 m .59254 .74158 L .58909 .74591 L F
.66 .68 .858 r
.58909 .74591 m .59254 .74158 L .59287 .7427 L F
.627 .448 .621 r
.58886 .74727 m .59161 .74743 L .59122 .7445 L F
.415 .261 .562 r
.59161 .74743 m .5933 .74412 L .59122 .7445 L F
.66 .68 .858 r
.59057 .74528 m .5933 .74412 L .59122 .7445 L F
.59057 .74528 m .59287 .7427 L .5933 .74412 L F
0 0 0 r
.59122 .7445 m .59097 .74483 L .59057 .74528 L F
.66 .68 .858 r
.58909 .74591 m .59057 .74528 L .59122 .7445 L F
.58909 .74591 m .59287 .7427 L .59057 .74528 L F
0 0 0 r
.59057 .74528 m .58996 .74618 L .58915 .74699 L F
.59097 .74483 m .58996 .74618 L .59057 .74528 L F
.59122 .7445 m .58915 .74699 L .58886 .74727 L F
.59 .626 .855 r
.58878 .74073 m .58909 .74591 L .58774 .74374 L F
.005 0 0 r
.32687 .66201 m .32789 .66027 L .32551 .66262 L F
.331 0 .186 r
.32996 .65966 m .32789 .66027 L .32687 .66201 L F
.549 .339 .547 r
.323 .8076 m .3228 .81022 L .32494 .80967 L F
.323 .8076 m .3228 .81022 L .32494 .80967 L F
.883 .758 .72 r
.57602 .70915 m .57857 .7095 L .57737 .70903 L F
.57602 .70915 m .57798 .71192 L .57857 .7095 L F
.9 .859 .791 r
.57938 .70592 m .57857 .7095 L .57726 .70622 L F
.57938 .70592 m .57737 .70903 L .57857 .7095 L F
.369 .108 .382 r
.59942 .72786 m .59875 .73037 L .60125 .72736 L F
.723 .388 .411 r
.54631 .74756 m .54932 .7503 L .54694 .74975 L F
.712 .395 .438 r
.54919 .74859 m .54932 .7503 L .54631 .74756 L F
.36 0 .127 r
.33715 .65596 m .34015 .65423 L .33799 .65463 L F
.696 .962 .943 r
.31548 .73422 m .31501 .73476 L .31756 .73308 L F
.379 .72 .988 r
.27358 .60462 m .27384 .60366 L .27199 .60382 L F
.27358 .60462 m .27535 .60467 L .27384 .60366 L F
.718 .387 .417 r
.51381 .72873 m .51369 .7306 L .51118 .73025 L F
.394 .82 .649 r
.56016 .67996 m .56073 .67953 L .56246 .67945 L F
.56016 .67996 m .5588 .68067 L .56073 .67953 L F
.673 .817 .952 r
.71622 .61142 m .71928 .61184 L .71808 .61046 L F
.286 .465 .862 r
.71928 .61184 m .71955 .61164 L .71808 .61046 L F
.71928 .61184 m .72187 .61315 L .71955 .61164 L F
.944 .736 .592 r
.62699 .678 m .62825 .67903 L .62707 .6759 L F
.92 .687 .57 r
.62679 .6805 m .62825 .67903 L .62699 .678 L F
.62679 .6805 m .6281 .68138 L .62825 .67903 L F
.465 .206 .437 r
.41965 .67619 m .41913 .67837 L .41709 .67872 L F
.451 .189 .424 r
.42173 .67568 m .41913 .67837 L .41965 .67619 L F
.789 .584 .624 r
.62283 .66768 m .62511 .66495 L .6214 .66476 L F
.815 .625 .646 r
.62283 .66768 m .62595 .66803 L .62511 .66495 L F
0 0 .27 r
.30531 .71192 m .30493 .71186 L .305 .71163 L F
.76 .734 .828 r
.30518 .71414 m .30809 .71457 L .30531 .71192 L F
.30809 .71457 m .30829 .7146 L .30636 .71286 L F
.30628 .71284 m .30636 .71286 L .305 .71163 L F
.30809 .71457 m .30636 .71286 L .30628 .71284 L F
.30451 .71404 m .30518 .71414 L .305 .71163 L F
0 0 .27 r
.30531 .71192 m .30518 .71413 L .30493 .71186 L F
.76 .734 .828 r
.30518 .71414 m .30531 .71192 L .305 .71163 L F
.336 .601 .945 r
.305 .71163 m .30829 .7146 L .30865 .71366 L F
.383 .416 .772 r
.30406 .71241 m .30553 .71195 L .30406 .7124 L F
.30392 .71266 m .30435 .71247 L .30406 .71241 L F
.30435 .71247 m .30553 .71195 L .30406 .71241 L F
.835 .712 .728 r
.3046 .71656 m .30482 .71644 L .30665 .71616 L F
.30482 .71644 m .30829 .7146 L .30665 .71616 L F
.855 .524 .425 r
.30829 .7146 m .30867 .71707 L .30831 .7169 L F
.30828 .71461 m .30831 .7169 L .30665 .71616 L F
.30829 .7146 m .30831 .7169 L .30828 .71461 L F
0 0 .229 r
.30832 .71785 m .30843 .71915 L .30893 .71587 L F
.30792 .71918 m .30834 .71915 L .30832 .71785 L F
.30834 .71915 m .30843 .71915 L .30832 .71785 L F
.462 .251 .506 r
.30829 .7146 m .30867 .71707 L .31048 .71449 L F
.534 .541 .809 r
.30665 .71616 m .30893 .71587 L .3089 .7158 L F
.755 .371 .328 r
.30518 .71414 m .30652 .71598 L .30829 .7146 L F
.30652 .71598 m .30665 .71616 L .30669 .71613 L F
.30652 .71598 m .30669 .71613 L .30829 .7146 L F
0 0 .27 r
.30553 .71195 m .30518 .71413 L .30531 .71192 L F
0 0 0 r
.30493 .71186 m .30451 .71404 L .305 .71163 L F
.383 .416 .772 r
.30392 .71266 m .30492 .71454 L .30553 .71195 L F
.545 .412 .65 r
.3046 .71656 m .30665 .71616 L .30595 .71546 L F
.30452 .71437 m .30595 .71546 L .30451 .71404 L F
.383 .416 .772 r
.30505 .71478 m .3053 .71524 L .30532 .71498 L F
.718 .496 .588 r
.30451 .71404 m .3053 .71524 L .30495 .71511 L F
.545 .412 .65 r
.3046 .71656 m .30531 .71598 L .30492 .71519 L F
.30459 .71626 m .30492 .71519 L .30452 .71437 L F
.3046 .71656 m .30492 .71519 L .30459 .71626 L F
.30531 .71598 m .3047 .71451 L .30452 .71437 L F
.52 .392 .647 r
.30264 .71699 m .30451 .71404 L .30124 .71373 L F
.30264 .71699 m .30451 .71658 L .30451 .71404 L F
.30451 .71658 m .3046 .71656 L .30459 .71626 L F
.30451 .71658 m .30459 .71626 L .30451 .71404 L F
.849 .399 .135 r
.30256 .71658 m .30644 .71618 L .3046 .71656 L F
.30644 .71618 m .30665 .71616 L .3046 .71656 L F
.52 .392 .647 r
.30451 .71658 m .3046 .71656 L .30451 .71658 L F
.718 .496 .588 r
.30451 .71404 m .30495 .71511 L .30124 .71373 L F
.686 .559 .705 r
.30124 .71373 m .30489 .71509 L .30392 .71266 L F
.30489 .71509 m .30495 .71511 L .30491 .71502 L F
.30489 .71509 m .30491 .71502 L .30392 .71266 L F
.30495 .71511 m .3053 .71524 L .30505 .71478 L F
.30495 .71511 m .30505 .71478 L .30392 .71266 L F
.545 .412 .65 r
.30531 .71598 m .30595 .71546 L .3047 .71451 L F
.383 .416 .772 r
.30492 .71454 m .30505 .71478 L .30532 .7149 L F
.30505 .71478 m .30532 .71498 L .30532 .7149 L F
0 0 .27 r
.30532 .7149 m .3053 .71524 L .30518 .71415 L F
.755 .371 .328 r
.30451 .71404 m .30531 .71483 L .30518 .71414 L F
.30531 .71483 m .30665 .71616 L .30518 .71414 L F
0 0 .27 r
.30553 .71195 m .30532 .7149 L .30518 .71413 L F
.30532 .7149 m .30518 .71415 L .30518 .71413 L F
.383 .416 .772 r
.30492 .71454 m .30532 .7149 L .30553 .71195 L F
.762 .952 .632 r
.30829 .7146 m .30665 .71616 L .30865 .71366 L F
0 .348 .759 r
.305 .71163 m .30865 .71366 L .30738 .71269 L F
.534 .541 .809 r
.30665 .71616 m .30738 .71269 L .30865 .71366 L F
.30665 .71616 m .3089 .7158 L .30738 .71269 L F
0 0 .27 r
.30553 .71195 m .30531 .71192 L .305 .71163 L F
.604 .423 .609 r
.32323 .66529 m .32563 .66509 L .32551 .66262 L F
.235 .142 .541 r
.32551 .66262 m .32694 .66447 L .32687 .66201 L F
.32551 .66262 m .32563 .66509 L .32694 .66447 L F
.28 .774 .892 r
.73087 .71048 m .72934 .71098 L .72882 .71159 L F
.73087 .71048 m .73194 .71065 L .72934 .71098 L F
.177 0 0 r
.37615 .71375 m .37555 .71458 L .37263 .71589 L F
.183 0 .113 r
.3788 .71172 m .3777 .71397 L .37615 .71375 L F
.179 0 0 r
.3777 .71397 m .37555 .71458 L .37615 .71375 L F
.171 .536 .924 r
.73786 .59662 m .73467 .59468 L .73787 .59727 L F
.621 .06 0 r
.48367 .78028 m .48509 .78039 L .48167 .77918 L F
.475 0 0 r
.48762 .78157 m .48509 .78039 L .48367 .78028 L F
.687 .906 .973 r
.4668 .74999 m .46377 .74987 L .46641 .74913 L F
.847 .708 .709 r
.46685 .75173 m .46377 .74987 L .4668 .74999 L F
.387 .715 .987 r
.46641 .74913 m .46767 .74878 L .4668 .74999 L F
0 0 .429 r
.46767 .74878 m .46685 .75173 L .4668 .74999 L F
.928 .544 .213 r
.57553 .70387 m .57594 .70551 L .57726 .70622 L F
.665 .198 .134 r
.57594 .70551 m .57938 .70592 L .57726 .70622 L F
.466 0 0 r
.52462 .79041 m .52666 .79074 L .52342 .79119 L F
.896 .939 .832 r
.30946 .72747 m .30833 .73062 L .30935 .72862 L F
.56 .303 .484 r
.30935 .72862 m .31098 .7307 L .30833 .73062 L F
.217 .264 .697 r
.28772 .61587 m .28922 .61773 L .28848 .61576 L F
.563 .459 .694 r
.57864 .7174 m .57733 .71999 L .57705 .71776 L F
.196 .272 .716 r
.73128 .59131 m .73233 .59457 L .73356 .59327 L F
.436 .651 .95 r
.73233 .59457 m .73467 .59468 L .73356 .59327 L F
.598 .475 .683 r
.58632 .73633 m .58647 .73908 L .58463 .73925 L F
.562 .311 .493 r
.58658 .74106 m .58463 .73925 L .58647 .73908 L F
.58658 .74106 m .58463 .73925 L .58647 .73908 L F
.58658 .74106 m .58425 .74153 L .58463 .73925 L F
.688 .299 .304 r
.60347 .65675 m .60566 .65876 L .60655 .65679 L F
.604 .19 .23 r
.60743 .65856 m .60655 .65679 L .60566 .65876 L F
.60743 .65856 m .60899 .65708 L .60655 .65679 L F
.71 .879 .96 r
.72389 .6101 m .72668 .61027 L .72592 .60933 L F
.897 .917 .827 r
.72592 .60933 m .72668 .61027 L .72889 .60732 L F
.409 .2 .482 r
.30609 .63174 m .30617 .62831 L .30822 .62889 L F
.976 .715 .469 r
.67313 .58757 m .67463 .59053 L .67431 .58818 L F
.446 .345 .647 r
.67431 .58818 m .67463 .59053 L .67629 .59039 L F
0 0 0 r
.71622 .61142 m .71556 .61252 L .71366 .61337 L F
.386 .845 .884 r
.71366 .61337 m .71556 .61252 L .71278 .61329 L F
.713 .744 .876 r
.30213 .73778 m .30431 .73659 L .30042 .73582 L F
.581 .336 .509 r
.41448 .68174 m .41185 .68385 L .41259 .68221 L F
.938 .863 .739 r
.67736 .61149 m .67843 .61348 L .67914 .61098 L F
.867 .837 .814 r
.67602 .61305 m .67843 .61348 L .67736 .61149 L F
.67602 .61305 m .67754 .61454 L .67843 .61348 L F
0 .167 .705 r
.57885 .75287 m .57912 .75204 L .57716 .75008 L F
0 0 .564 r
.57885 .75287 m .58028 .7541 L .57912 .75204 L F
.57885 .75287 m .5802 .75523 L .58028 .7541 L F
.54 .38 .613 r
.41795 .7496 m .41999 .74672 L .41795 .74737 L F
.28 .359 .767 r
.58391 .7305 m .58286 .73181 L .58146 .72826 L F
.91 .723 .637 r
.72888 .59095 m .7313 .58963 L .73002 .58972 L F
.72888 .59095 m .73128 .59131 L .7313 .58963 L F
0 0 .465 r
.7313 .58963 m .73128 .59126 L .73219 .59027 L F
.73128 .59126 m .73128 .59131 L .73219 .59027 L F
.428 0 0 r
.73262 .5898 m .73219 .59027 L .7327 .5898 L F
.73002 .58972 m .7313 .58963 L .73219 .59027 L F
.73002 .58972 m .73219 .59027 L .73262 .5898 L F
.47 .259 .51 r
.35873 .67774 m .35699 .67624 L .35915 .67586 L F
.35873 .67774 m .35667 .67838 L .35699 .67624 L F
.158 0 0 r
.28056 .65449 m .27688 .65616 L .27834 .6556 L F
.693 .514 .641 r
.60585 .70599 m .6069 .70242 L .60494 .70319 L F
.243 0 .104 r
.60494 .70319 m .6069 .70242 L .60784 .70133 L F
.328 .766 .967 r
.40043 .65582 m .40259 .65566 L .40398 .6562 L F
.042 0 0 r
.40259 .65566 m .40608 .65578 L .40398 .6562 L F
.678 .213 .141 r
.49186 .78657 m .49383 .78813 L .49054 .78768 L F
.569 .438 .663 r
.30649 .70638 m .30861 .70604 L .30844 .70347 L F
.422 .016 .162 r
.3049 .70777 m .30861 .70604 L .30649 .70638 L F
.569 .293 .458 r
.32506 .6671 m .32563 .66509 L .32323 .66529 L F
.455 .294 .573 r
.32323 .66529 m .32317 .66771 L .32506 .6671 L F
.377 .211 .526 r
.53275 .74133 m .53087 .74395 L .5308 .74202 L F
.572 .212 .318 r
.44066 .73854 m .44303 .73861 L .44416 .73645 L F
.482 .118 .271 r
.44416 .73645 m .44584 .7377 L .44642 .73631 L F
.44416 .73645 m .44303 .73861 L .44584 .7377 L F
.26 0 0 r
.35328 .64925 m .35498 .6496 L .35671 .64923 L F
0 0 0 r
.35498 .6496 m .35881 .6489 L .35671 .64923 L F
.511 .303 .533 r
.40813 .76623 m .41005 .76638 L .4103 .764 L F
.692 .338 .371 r
.45117 .77538 m .45439 .77382 L .45254 .77476 L F
.897 .917 .827 r
.72592 .60933 m .72889 .60732 L .72821 .60675 L F
.009 0 0 r
.39687 .67821 m .39795 .67797 L .39967 .6763 L F
.436 .467 .793 r
.3985 .67325 m .39967 .6763 L .40129 .67585 L F
.735 .332 .287 r
.39967 .6763 m .39795 .67797 L .40173 .67836 L F
.408 .356 .688 r
.39967 .6763 m .40173 .67836 L .40129 .67585 L F
.136 0 0 r
.37377 .70321 m .3754 .703 L .37663 .70107 L F
.149 0 .003 r
.37663 .70107 m .37718 .70227 L .37859 .70051 L F
.37663 .70107 m .3754 .703 L .37718 .70227 L F
.462 0 .053 r
.34539 .72803 m .34379 .7296 L .34209 .7287 L F
.488 .094 .219 r
.34737 .72723 m .34379 .7296 L .34539 .72803 L F
.004 .183 .697 r
.58349 .76102 m .58461 .7605 L .58245 .75794 L F
.036 .266 .763 r
.58349 .76102 m .5857 .76306 L .58461 .7605 L F
.375 .203 .516 r
.61568 .71695 m .61378 .72025 L .61365 .71753 L F
.442 .292 .581 r
.27573 .63796 m .27672 .64005 L .27671 .63765 L F
.486 .312 .57 r
.27478 .64055 m .27672 .64005 L .27573 .63796 L F
.031 0 0 r
.36528 .67448 m .36494 .67374 L .36696 .67311 L F
.36528 .67448 m .36344 .67515 L .36494 .67374 L F
.461 .273 .538 r
.42466 .73831 m .42635 .73613 L .42411 .73616 L F
.772 .432 .411 r
.48257 .74168 m .48395 .74406 L .48144 .74366 L F
0 .192 .693 r
.48257 .74168 m .48575 .74451 L .48395 .74406 L F
.501 .255 .472 r
.48654 .72264 m .48871 .72224 L .48895 .72015 L F
.466 .225 .463 r
.48895 .72015 m .48871 .72224 L .49105 .71977 L F
.219 .496 .901 r
.31228 .60266 m .30889 .60009 L .31078 .59996 L F
.436 .543 .867 r
.31313 .60066 m .31228 .60266 L .31078 .59996 L F
.464 .576 .882 r
.31313 .60066 m .31428 .60284 L .31228 .60266 L F
.186 .228 .673 r
.39804 .70037 m .39614 .69832 L .39801 .69774 L F
.48 .357 .635 r
.61378 .72025 m .61408 .7223 L .61217 .72268 L F
.474 .335 .612 r
.61408 .7223 m .61435 .72467 L .61217 .72268 L F
.373 .329 .681 r
.61217 .72268 m .61435 .72467 L .61284 .72494 L F
.643 .663 .854 r
.69678 .60181 m .69793 .59841 L .69581 .59943 L F
.69678 .60181 m .69864 .60153 L .69793 .59841 L F
.56 .772 .978 r
.30749 .59893 m .30889 .60009 L .30545 .59939 L F
.418 .723 .988 r
.30952 .59894 m .30889 .60009 L .30749 .59893 L F
.30952 .59894 m .31078 .59996 L .30889 .60009 L F
.795 .517 .516 r
.5445 .69155 m .5478 .68996 L .54579 .69092 L F
.5445 .69155 m .54773 .69212 L .5478 .68996 L F
0 0 .293 r
.5478 .68996 m .54773 .69212 L .54881 .69093 L F
.645 .493 .662 r
.582 .71195 m .58188 .71459 L .58396 .71176 L F
.563 .459 .694 r
.57864 .7174 m .57962 .71968 L .57733 .71999 L F
.548 .385 .612 r
.57962 .71968 m .57785 .72193 L .57733 .71999 L F
.471 .229 .465 r
.49327 .73095 m .49108 .73323 L .49142 .73113 L F
.814 .784 .825 r
.30245 .73263 m .30397 .73388 L .30609 .73097 L F
.665 .789 .94 r
.71071 .71959 m .70885 .72065 L .7073 .7193 L F
.622 .839 .983 r
.42557 .78735 m .42348 .788 L .4268 .78812 L F
.564 .82 .994 r
.42557 .78735 m .4268 .78812 L .42729 .78689 L F
.443 .278 .561 r
.3424 .68973 m .34236 .69228 L .34057 .69264 L F
.545 .368 .592 r
.34266 .69434 m .34057 .69264 L .34236 .69228 L F
.34266 .69434 m .34048 .69485 L .34057 .69264 L F
.532 .409 .658 r
.30812 .70084 m .31033 .70296 L .31004 .70039 L F
.30812 .70084 m .30844 .70347 L .31033 .70296 L F
.547 0 0 r
.73159 .58411 m .73051 .58296 L .72912 .5825 L F
.73159 .58411 m .73324 .5846 L .73051 .58296 L F
.783 .537 .565 r
.61598 .65951 m .61796 .66214 L .618 .65987 L F
.076 0 0 r
.36441 .64878 m .36652 .64833 L .36765 .64765 L F
0 0 0 r
.36765 .64765 m .3686 .64768 L .36962 .64699 L F
.36765 .64765 m .36652 .64833 L .3686 .64768 L F
.283 .372 .778 r
.61239 .7387 m .61495 .7408 L .61348 .74189 L F
.235 .131 .526 r
.61495 .7408 m .61313 .74415 L .61348 .74189 L F
0 0 .466 r
.50434 .73515 m .50397 .73663 L .50366 .73393 L F
.599 .176 .209 r
.50366 .73393 m .50226 .73545 L .50434 .73515 L F
.566 .119 .148 r
.50434 .73515 m .50226 .73545 L .50366 .73393 L F
.522 .147 .269 r
.50583 .73368 m .50434 .73515 L .50366 .73393 L F
0 0 0 r
.3814 .66728 m .38037 .66724 L .38267 .66648 L F
.3814 .66728 m .3794 .66783 L .38037 .66724 L F
.36 .185 .504 r
.3946 .68383 m .39633 .68083 L .39508 .68171 L F
.604 .866 .992 r
.30808 .73624 m .30431 .73659 L .306 .73576 L F
.992 .839 .591 r
.30754 .73913 m .30808 .73624 L .30948 .73849 L F
.904 .494 .121 r
.60856 .70867 m .60655 .70577 L .60754 .7065 L F
.199 .106 .518 r
.60784 .70133 m .60876 .70011 L .60872 .69813 L F
.63 .875 .525 r
.60784 .70133 m .6069 .70242 L .60876 .70011 L F
.532 .738 .97 r
.38312 .64788 m .3824 .64944 L .38104 .64843 L F
.38312 .64788 m .38437 .64914 L .3824 .64944 L F
.416 .733 .991 r
.28394 .59554 m .28593 .59543 L .28539 .59655 L F
.372 .682 .978 r
.28593 .59543 m .28735 .59667 L .28539 .59655 L F
.674 .215 0 r
.54365 .70113 m .54295 .70038 L .54136 .698 L F
.872 .5 .015 r
.54365 .70113 m .54441 .70332 L .54295 .70038 L F
.114 .666 .737 r
.35881 .6489 m .3609 .64864 L .3623 .64852 L F
.167 .695 .861 r
.3609 .64864 m .36441 .64878 L .3623 .64852 L F
.814 .594 .605 r
.62592 .67042 m .62595 .66803 L .62283 .66768 L F
.417 .519 .855 r
.34884 .70062 m .34863 .70334 L .34689 .70081 L F
.34884 .70062 m .35034 .7033 L .34863 .70334 L F
.315 .763 .959 r
.57348 .68972 m .57237 .68923 L .57017 .6894 L F
0 0 0 r
.57503 .68683 m .57458 .68865 L .57348 .68972 L F
.501 .864 .987 r
.57458 .68865 m .57237 .68923 L .57348 .68972 L F
.864 .428 .163 r
.29618 .72233 m .29632 .72087 L .29475 .71995 L F
.528 .397 .646 r
.41365 .75559 m .41554 .75223 L .41351 .75264 L F
.708 .226 .103 r
.53009 .79165 m .52879 .79263 L .52666 .79074 L F
.402 0 0 r
.5327 .79232 m .52879 .79263 L .53009 .79165 L F
.461 .273 .538 r
.42466 .73831 m .42658 .73814 L .42635 .73613 L F
.686 .578 .729 r
.42442 .74117 m .42658 .73814 L .42466 .73831 L F
.325 0 0 r
.56799 .70399 m .57023 .70508 L .56771 .70383 L F
.595 .354 .521 r
.4895 .77469 m .49164 .77684 L .49176 .77454 L F
.4895 .77469 m .49164 .77684 L .49176 .77454 L F
.398 .129 .385 r
.40956 .68646 m .40756 .68708 L .41006 .68459 L F
.482 .205 .417 r
.41171 .68597 m .41006 .68459 L .41185 .68385 L F
.41171 .68597 m .40956 .68646 L .41006 .68459 L F
.774 .541 .582 r
.5933 .74412 m .58996 .74618 L .59122 .7445 L F
.858 .464 .294 r
.60794 .67912 m .60693 .68054 L .60545 .67794 L F
.873 .487 .306 r
.60832 .68068 m .60693 .68054 L .60794 .67912 L F
.788 .731 .799 r
.38938 .67047 m .38833 .67305 L .38743 .67272 L F
.474 .374 .661 r
.38938 .67047 m .3935 .67454 L .38833 .67305 L F
0 .475 .794 r
.38833 .67305 m .38963 .67332 L .38743 .67272 L F
0 .483 .837 r
.38833 .67305 m .3935 .67454 L .38963 .67332 L F
.526 .785 .992 r
.72208 .73056 m .72358 .72909 L .72145 .72894 L F
.72208 .73056 m .72445 .73017 L .72358 .72909 L F
.963 .72 .523 r
.33902 .84552 m .34033 .84855 L .33886 .84804 L F
.33902 .84552 m .34033 .84855 L .33886 .84804 L F
.511 .434 .706 r
.6129 .72733 m .61313 .73091 L .611 .731 L F
.633 .532 .722 r
.61346 .73345 m .611 .731 L .61313 .73091 L F
.61346 .73345 m .61228 .73413 L .611 .731 L F
.403 0 0 r
.47285 .72949 m .47505 .72946 L .47647 .72812 L F
.254 0 0 r
.47505 .72946 m .4787 .72782 L .47647 .72812 L F
.781 .832 .892 r
.69006 .60075 m .68815 .60196 L .69105 .60198 L F
.669 .796 .942 r
.69006 .60075 m .69105 .60198 L .69333 .60129 L F
.614 .46 .65 r
.31045 .68689 m .31298 .68704 L .31297 .6849 L F
.619 .476 .665 r
.31105 .68988 m .31298 .68704 L .31045 .68689 L F
.933 .815 .706 r
.59611 .73674 m .59454 .73655 L .59651 .73543 L F
.59611 .73674 m .59538 .73897 L .59454 .73655 L F
.579 .501 .731 r
.52025 .75149 m .5231 .74895 L .52103 .74958 L F
.52025 .75149 m .52379 .75235 L .5231 .74895 L F
.582 .441 .654 r
.52025 .75149 m .52389 .75474 L .52379 .75235 L F
.52025 .75149 m .52165 .75526 L .52389 .75474 L F
.203 0 0 r
.45493 .78511 m .45146 .78534 L .45404 .78571 L F
.567 .437 .663 r
.4103 .764 m .41228 .7637 L .41208 .76079 L F
.623 .439 .613 r
.41005 .76638 m .41228 .7637 L .4103 .764 L F
.203 0 0 r
.45493 .78511 m .45363 .78539 L .45146 .78534 L F
.119 0 0 r
.45704 .78503 m .45363 .78539 L .45493 .78511 L F
.771 .903 .933 r
.7292 .59201 m .73128 .59131 L .72888 .59095 L F
.196 .272 .716 r
.73128 .59131 m .73356 .59327 L .73219 .59027 L F
.541 .763 .979 r
.713 .72813 m .71428 .72667 L .71198 .72731 L F
.713 .72813 m .71531 .72777 L .71428 .72667 L F
.341 0 0 r
.55214 .74831 m .55115 .74894 L .54919 .74859 L F
.616 .107 .018 r
.55214 .74831 m .55405 .74952 L .55115 .74894 L F
0 0 0 r
.59419 .66777 m .59582 .66726 L .59302 .66918 L F
.847 .708 .709 r
.46685 .75173 m .46321 .75231 L .46377 .74987 L F
.394 0 0 r
.46685 .75173 m .46453 .75334 L .46321 .75231 L F
0 0 .429 r
.46767 .74878 m .46798 .75185 L .46685 .75173 L F
.216 0 0 r
.46886 .7527 m .46685 .75173 L .46798 .75185 L F
.46886 .7527 m .46453 .75334 L .46685 .75173 L F
0 0 .045 r
.56816 .72276 m .56825 .72353 L .56882 .72224 L F
.552 .931 .885 r
.50876 .70642 m .50969 .70542 L .51092 .70591 L F
.50876 .70642 m .50786 .7064 L .50969 .70542 L F
.575 .83 .993 r
.5857 .76306 m .58689 .76392 L .58908 .76328 L F
.47 .624 .918 r
.73612 .71148 m .73581 .71373 L .73434 .71083 L F
.73612 .71148 m .73794 .71352 L .73581 .71373 L F
.486 .231 .452 r
.41913 .67837 m .41664 .68125 L .41709 .67872 L F
.463 .557 .866 r
.35227 .70315 m .35202 .70602 L .35034 .7033 L F
.35227 .70315 m .35383 .70588 L .35202 .70602 L F
.582 .567 .802 r
.35488 .7083 m .35202 .70602 L .35383 .70588 L F
.426 .192 .453 r
.38795 .69188 m .39012 .68901 L .38817 .68966 L F
.773 .849 .908 r
.42504 .66476 m .42346 .66624 L .42178 .66526 L F
.325 .392 .777 r
.5463 .74093 m .54534 .74293 L .54401 .7412 L F
.125 0 0 r
.54807 .72581 m .55053 .72584 L .5469 .72555 L F
.411 .686 .975 r
.30829 .7146 m .31048 .71449 L .30865 .71366 L F
.30829 .7146 m .31048 .71449 L .30865 .71366 L F
.812 .823 .345 r
.54136 .698 m .54126 .69741 L .5422 .69458 L F
0 .017 .591 r
.54136 .698 m .54257 .69887 L .54126 .69741 L F
.54136 .698 m .54295 .70038 L .54257 .69887 L F
.54 .377 .608 r
.31461 .67885 m .31672 .67843 L .31666 .67605 L F
.546 .404 .639 r
.31477 .68125 m .31672 .67843 L .31461 .67885 L F
.812 .45 .372 r
.46966 .77434 m .47143 .77685 L .47304 .77584 L F
.704 .77 .903 r
.30779 .7345 m .31008 .73438 L .3117 .73327 L F
.30779 .7345 m .31008 .73438 L .3117 .73327 L F
.483 0 0 r
.30826 .73542 m .31008 .73438 L .30779 .7345 L F
.198 0 0 r
.5462 .73394 m .54257 .73581 L .54267 .73381 L F
.54474 .73548 m .54463 .73566 L .54454 .73569 L F
.5462 .73394 m .54482 .73545 L .54474 .73548 L F
.54482 .73545 m .54463 .73566 L .54474 .73548 L F
.5462 .73394 m .54447 .73577 L .54464 .73474 L F
.295 0 0 r
.54711 .73493 m .5462 .73394 L .54788 .7329 L F
.54711 .73493 m .54443 .73588 L .5462 .73394 L F
.618 .662 .87 r
.5468 .73484 m .54849 .73217 L .54516 .73439 L F
.54711 .73493 m .54722 .73471 L .5468 .73484 L F
0 0 0 r
.5504 .73162 m .54959 .7322 L .54788 .7329 L F
.621 .441 .617 r
.54959 .7322 m .54711 .73493 L .54788 .7329 L F
.618 .662 .87 r
.54722 .73471 m .54849 .73217 L .5468 .73484 L F
.775 .632 .703 r
.54405 .73449 m .54672 .73487 L .54516 .73439 L F
.54672 .73487 m .54711 .73493 L .5468 .73484 L F
.54672 .73487 m .5468 .73484 L .54516 .73439 L F
.198 0 0 r
.54454 .73569 m .54453 .73576 L .54447 .73577 L F
.54463 .73566 m .54453 .73576 L .54454 .73569 L F
.54464 .73474 m .54447 .73577 L .54257 .73581 L F
.329 .416 .799 r
.54447 .73577 m .54509 .73762 L .54257 .73581 L F
.869 .559 .041 r
.54447 .73577 m .54456 .73692 L .54509 .73762 L F
.329 .416 .799 r
.54405 .73449 m .54447 .73577 L .54257 .73581 L F
.198 0 0 r
.54453 .73576 m .54443 .73588 L .54257 .73581 L F
.264 .306 .719 r
.54405 .73449 m .54443 .73588 L .54257 .73581 L F
.869 .559 .041 r
.54405 .73449 m .5444 .73617 L .54447 .73577 L F
.5444 .73617 m .54456 .73692 L .54447 .73577 L F
.327 0 .186 r
.37973 .71337 m .3788 .71172 L .38105 .71168 L F
.37973 .71337 m .3777 .71397 L .3788 .71172 L F
.776 .551 .595 r
.61095 .65899 m .61449 .65699 L .61111 .65677 L F
.61095 .65899 m .61448 .65934 L .61449 .65699 L F
.694 .279 .254 r
.53586 .79146 m .53453 .79317 L .5327 .79232 L F
.388 0 .057 r
.53809 .79127 m .53453 .79317 L .53586 .79146 L F
.568 .432 .656 r
.53731 .78876 m .53809 .79127 L .53586 .79146 L F
.109 0 0 r
.37565 .64899 m .37783 .64869 L .37926 .64807 L F
.181 .715 .808 r
.37783 .64869 m .38104 .64843 L .37926 .64807 L F
.517 .196 .362 r
.51939 .74063 m .52125 .74041 L .52157 .73923 L F
.113 0 0 r
.52125 .74041 m .52305 .73901 L .52157 .73923 L F
.869 .802 .781 r
.48932 .74705 m .48854 .74853 L .48577 .74859 L F
.704 .534 .656 r
.48867 .75166 m .48577 .74859 L .48854 .74853 L F
.416 .022 .181 r
.49066 .75104 m .48987 .7513 L .48936 .75019 L F
.49068 .75105 m .4904 .75114 L .49066 .75104 L F
.4904 .75114 m .48987 .7513 L .49066 .75104 L F
.48967 .75123 m .48867 .75166 L .48908 .75078 L F
.704 .534 .656 r
.48867 .75166 m .4905 .75179 L .48967 .75123 L F
.687 .647 .805 r
.48979 .75132 m .4905 .75179 L .48867 .75166 L F
.468 0 0 r
.48975 .7513 m .4905 .75179 L .48979 .75132 L F
.687 .647 .805 r
.4904 .75114 m .4905 .75179 L .48979 .75132 L F
.468 0 0 r
.48979 .75132 m .4905 .75179 L .48983 .75135 L F
.416 .022 .181 r
.48979 .75146 m .48867 .75166 L .48983 .75135 L F
.887 .548 .4 r
.48908 .75078 m .48867 .75166 L .48862 .75048 L F
.704 .534 .656 r
.48867 .75166 m .48967 .75123 L .48577 .74859 L F
.416 .022 .181 r
.49098 .75125 m .48936 .75019 L .49176 .74787 L F
.687 .647 .805 r
.49 .74858 m .4904 .75114 L .48984 .75131 L F
.416 .022 .181 r
.48983 .75135 m .48867 .75166 L .48967 .75123 L F
.468 0 0 r
.48744 .74972 m .4905 .75179 L .48836 .75037 L F
.48678 .7493 m .48836 .75037 L .48592 .74875 L F
.48744 .74972 m .48836 .75037 L .48678 .7493 L F
.416 .022 .181 r
.48993 .75143 m .48908 .75078 L .48936 .75019 L F
.687 .647 .805 r
.49 .74858 m .48984 .75131 L .48907 .75074 L F
.49 .74858 m .48903 .75083 L .48946 .75092 L F
.468 0 0 r
.48592 .74875 m .48975 .7513 L .48607 .74891 L F
.48975 .7513 m .48983 .75135 L .48607 .74891 L F
.48577 .74859 m .48744 .74972 L .48592 .74875 L F
.887 .548 .4 r
.48936 .75019 m .48908 .75078 L .48854 .74853 L F
.48908 .75078 m .48862 .75048 L .48854 .74853 L F
.726 .675 .799 r
.48607 .74891 m .48942 .75109 L .49 .74858 L F
.48942 .75109 m .48983 .75135 L .49 .74858 L F
.48983 .75135 m .4904 .75114 L .49 .74858 L F
.687 .647 .805 r
.49 .74858 m .48946 .75092 L .49098 .75125 L F
.48907 .75074 m .48984 .75131 L .48867 .75166 L F
.48903 .75083 m .48867 .75166 L .48979 .75146 L F
.856 .477 .328 r
.48607 .74891 m .48972 .75168 L .48979 .75146 L F
.48942 .75109 m .48979 .75146 L .48983 .75135 L F
.687 .647 .805 r
.48903 .75083 m .48979 .75146 L .48942 .75109 L F
.856 .477 .328 r
.48607 .74891 m .48979 .75146 L .48942 .75109 L F
.48983 .75135 m .48972 .75168 L .4905 .75179 L F
.416 .022 .181 r
.48993 .75143 m .48979 .75146 L .48983 .75135 L F
.687 .647 .805 r
.48942 .75109 m .48979 .75146 L .48993 .75143 L F
.726 .675 .799 r
.48983 .75135 m .4905 .75179 L .4904 .75114 L F
.416 .022 .181 r
.49098 .75125 m .48993 .75143 L .48987 .7513 L F
.49098 .75125 m .48987 .7513 L .49068 .75105 L F
.687 .647 .805 r
.48903 .75083 m .48993 .75143 L .49098 .75125 L F
.856 .477 .328 r
.48607 .74891 m .48699 .75127 L .48972 .75168 L F
.7 .416 .49 r
.52364 .74038 m .52714 .73729 L .52305 .73901 L F
.52364 .74038 m .5262 .74113 L .52714 .73729 L F
.508 .393 .658 r
.52714 .73729 m .5292 .73829 L .52771 .73708 L F
.482 .166 .354 r
.5262 .74113 m .5292 .73829 L .52714 .73729 L F
.694 .359 .406 r
.5231 .74895 m .51901 .74947 L .5207 .74712 L F
.493 .179 .362 r
.68396 .58695 m .68184 .58563 L .6809 .58755 L F
.533 .415 .665 r
.4118 .75834 m .4141 .76037 L .41401 .75795 L F
.4118 .75834 m .41208 .76079 L .4141 .76037 L F
.421 .781 .996 r
.52529 .76922 m .52618 .76821 L .52397 .76863 L F
.52529 .76922 m .52777 .76914 L .52618 .76821 L F
.457 .262 .526 r
.28171 .63234 m .28362 .63184 L .28386 .62954 L F
.323 .074 .372 r
.28171 .63234 m .28282 .6338 L .28362 .63184 L F
.28171 .63234 m .28112 .63452 L .28282 .6338 L F
.543 .462 .713 r
.41181 .77207 m .41214 .77453 L .41451 .77404 L F
.593 .551 .777 r
.41214 .77453 m .41561 .77718 L .41451 .77404 L F
.487 .531 .827 r
.44146 .76819 m .43961 .76903 L .43861 .76648 L F
.54 .464 .719 r
.44234 .77137 m .43961 .76903 L .44146 .76819 L F
.44234 .77137 m .44028 .77169 L .43961 .76903 L F
.854 .703 .693 r
.44984 .75245 m .45121 .75562 L .44975 .75526 L F
.865 .794 .78 r
.45121 .75562 m .44761 .75778 L .44975 .75526 L F
.724 .65 .775 r
.45296 .75306 m .45121 .75562 L .44984 .75245 L F
.555 .562 .816 r
.70255 .60203 m .70362 .59836 L .70126 .59915 L F
.70255 .60203 m .70509 .60163 L .70362 .59836 L F
0 0 .154 r
.57719 .68383 m .57657 .68574 L .57503 .68683 L F
0 0 .001 r
.57657 .68574 m .57458 .68865 L .57503 .68683 L F
.55 .712 .947 r
.28203 .60809 m .28303 .60634 L .28162 .60685 L F
.28203 .60809 m .28371 .60767 L .28303 .60634 L F
.554 .081 .086 r
.48287 .78535 m .48664 .78517 L .48573 .78665 L F
.658 .207 .169 r
.48664 .78517 m .48718 .78725 L .48573 .78665 L F
.48664 .78517 m .48849 .78589 L .48718 .78725 L F
.477 .658 .941 r
.41051 .65535 m .40968 .65686 L .40812 .65502 L F
.4 .562 .899 r
.41051 .65535 m .41143 .65682 L .40968 .65686 L F
.614 .566 .777 r
.41285 .65952 m .40968 .65686 L .41143 .65682 L F
.501 .535 .824 r
.41052 .7693 m .41181 .77207 L .41289 .77073 L F
.452 .465 .781 r
.41181 .77207 m .41451 .77404 L .41289 .77073 L F
0 0 .301 r
.61346 .73345 m .61237 .73817 L .61228 .73413 L F
0 0 .058 r
.59594 .7604 m .59639 .76038 L .59507 .76113 L F
0 0 0 r
.59507 .76113 m .59422 .76277 L .59356 .76289 L F
.59507 .76113 m .59419 .7631 L .59422 .76277 L F
.516 .297 .52 r
.59361 .76514 m .59582 .76465 L .59422 .76277 L F
.59361 .76514 m .59582 .76465 L .59422 .76277 L F
0 0 0 r
.59507 .76113 m .59639 .76038 L .59419 .7631 L F
.455 .218 .465 r
.40907 .68836 m .40756 .68708 L .40956 .68646 L F
.40907 .68836 m .40714 .68899 L .40756 .68708 L F
.232 .577 .943 r
.26931 .59347 m .26766 .59319 L .26572 .59148 L F
.247 0 .15 r
.45745 .7502 m .45491 .75238 L .45553 .75002 L F
.695 .816 .94 r
.43586 .65491 m .43521 .65701 L .43723 .65604 L F
.43586 .65491 m .43521 .65701 L .43723 .65604 L F
.208 0 0 r
.35303 .72481 m .35141 .7261 L .34991 .72601 L F
.107 0 0 r
.35515 .72407 m .35417 .725 L .35303 .72481 L F
.277 0 0 r
.35417 .725 m .35141 .7261 L .35303 .72481 L F
.762 .687 .779 r
.48788 .74419 m .48932 .74705 L .48566 .74697 L F
.869 .802 .781 r
.48932 .74705 m .48577 .74859 L .48566 .74697 L F
.887 .52 .046 r
.48858 .74629 m .48932 .74705 L .48788 .74419 L F
.78 .407 .349 r
.48858 .74629 m .49171 .74784 L .48932 .74705 L F
.016 0 .057 r
.49176 .74787 m .48932 .74705 L .49171 .74784 L F
.851 .94 .88 r
.67962 .6088 m .67914 .61098 L .68071 .6095 L F
.88 .964 .846 r
.67736 .61149 m .67914 .61098 L .67962 .6088 L F
.444 .781 .998 r
.39236 .65127 m .3915 .65232 L .39017 .65158 L F
.39236 .65127 m .39362 .65204 L .3915 .65232 L F
.013 .011 .507 r
.42969 .6661 m .42845 .66563 L .42767 .66422 L F
.42969 .6661 m .42892 .66816 L .42845 .66563 L F
.358 .057 .311 r
.31533 .61629 m .31649 .61747 L .31472 .6182 L F
.31533 .61629 m .31719 .61573 L .31649 .61747 L F
.524 .379 .626 r
.59182 .7227 m .59273 .72429 L .59427 .72036 L F
.367 0 .147 r
.59182 .72493 m .59273 .72429 L .59182 .7227 L F
.386 .66 .967 r
.27851 .60615 m .27899 .6047 L .27699 .60494 L F
.27851 .60615 m .28162 .60685 L .27899 .6047 L F
.239 .016 .36 r
.30851 .62417 m .31048 .62139 L .31 .62355 L F
.334 .177 .513 r
.30831 .62654 m .30851 .62417 L .31 .62355 L F
.274 0 .012 r
.46591 .74527 m .46782 .74481 L .46537 .74591 L F
.398 .162 .436 r
.40477 .6918 m .4031 .69355 L .40284 .69244 L F
.314 .108 .433 r
.30141 .63678 m .30408 .63459 L .30349 .63662 L F
.261 .073 .427 r
.30173 .63961 m .30141 .63678 L .30349 .63662 L F
.553 .425 .659 r
.30984 .69794 m .31173 .69491 L .30968 .6954 L F
.677 .474 .604 r
.55007 .73901 m .55145 .74156 L .55231 .73907 L F
.118 0 0 r
.56971 .67314 m .57141 .67293 L .57163 .67229 L F
.078 0 0 r
.57043 .67381 m .56971 .67314 L .56868 .67485 L F
.57043 .67381 m .57141 .67293 L .56971 .67314 L F
.705 .332 .34 r
.54856 .75154 m .54694 .74975 L .54932 .7503 L F
.841 .499 .406 r
.54919 .74859 m .54856 .75154 L .54932 .7503 L F
.661 .313 .373 r
.55114 .75149 m .54919 .74859 L .55115 .74894 L F
.55114 .75149 m .54856 .75154 L .54919 .74859 L F
.05 .417 .864 r
.52154 .76864 m .52155 .76957 L .52068 .76797 L F
.352 .602 .942 r
.58886 .74727 m .58996 .74618 L .59031 .74733 L F
0 .575 .748 r
.59031 .74733 m .59161 .74743 L .58886 .74727 L F
0 0 0 r
.29955 .64261 m .30049 .64057 L .30173 .63961 L F
.794 .449 .402 r
.53825 .73633 m .53709 .73815 L .53566 .73712 L F
.579 .403 .607 r
.54103 .73367 m .54039 .73606 L .53825 .73633 L F
.764 .538 .592 r
.54039 .73606 m .53709 .73815 L .53825 .73633 L F
.611 .125 .075 r
.59854 .66569 m .59952 .66695 L .5973 .66674 L F
.291 0 .14 r
.58245 .66556 m .58164 .66684 L .58456 .6649 L F
.587 .597 .83 r
.72058 .60788 m .72295 .60777 L .7237 .60722 L F
.771 .569 .625 r
.72239 .61009 m .72295 .60777 L .72058 .60788 L F
.587 .597 .83 r
.72058 .60788 m .7237 .60722 L .72101 .60847 L F
.72058 .60788 m .72101 .60847 L .72084 .60855 L F
.771 .569 .625 r
.72101 .60847 m .72058 .60788 L .72076 .60825 L F
.72239 .61009 m .72058 .60788 L .72184 .6096 L F
.655 .622 .805 r
.71933 .60413 m .72073 .60823 L .7237 .60722 L F
0 0 .373 r
.72076 .60825 m .72084 .60855 L .72106 .60888 L F
.72058 .60788 m .72084 .60855 L .72076 .60825 L F
.655 .622 .805 r
.72076 .60825 m .72084 .60855 L .72101 .60847 L F
.72073 .60823 m .72084 .60855 L .72076 .60825 L F
.72073 .60823 m .72101 .60847 L .7237 .60722 L F
.771 .569 .625 r
.72184 .6096 m .72101 .60847 L .72106 .60888 L F
.72101 .60847 m .72076 .60825 L .72106 .60888 L F
.656 .151 .036 r
.49546 .78785 m .49619 .7897 L .49383 .78813 L F
.49546 .78785 m .49783 .7894 L .49619 .7897 L F
.595 .811 .409 r
.47704 .77163 m .4749 .77477 L .47577 .77346 L F
.166 0 .29 r
.47924 .77137 m .47708 .77378 L .47704 .77163 L F
.754 .505 .556 r
.47577 .77346 m .47924 .77137 L .47704 .77163 L F
.462 .241 .491 r
.40614 .69013 m .40517 .68962 L .40714 .68899 L F
.40614 .69013 m .40477 .6918 L .40517 .68962 L F
.842 .552 .497 r
.43292 .73791 m .435 .739 L .43619 .73846 L F
.473 0 .01 r
.43619 .73846 m .435 .739 L .43838 .73858 L F
0 0 .02 r
.56192 .69135 m .55979 .69447 L .56206 .69172 L F
.56192 .69135 m .56074 .69406 L .55979 .69447 L F
0 0 0 r
.56074 .69406 m .55894 .69673 L .55979 .69447 L F
.36 .543 .898 r
.70604 .72291 m .70902 .72424 L .70723 .72176 L F
.527 .325 .55 r
.5351 .75005 m .53511 .75235 L .53307 .75266 L F
.459 0 0 r
.45806 .77649 m .46022 .77691 L .46133 .77638 L F
.124 0 0 r
.46133 .77638 m .46366 .77608 L .4642 .77507 L F
.46133 .77638 m .46022 .77691 L .46366 .77608 L F
0 0 .345 r
.46123 .75515 m .46206 .75729 L .4615 .75607 L F
.46123 .75515 m .46206 .75729 L .4615 .75607 L F
.43 .106 .313 r
.39138 .70385 m .39044 .70543 L .38863 .70583 L F
.251 0 .2 r
.39317 .70311 m .39044 .70543 L .39138 .70385 L F
0 0 .459 r
.55523 .73623 m .55564 .73578 L .55446 .73314 L F
.689 .225 .145 r
.55886 .73738 m .55872 .73868 L .55523 .73623 L F
.73 .644 .084 r
.55878 .73781 m .55872 .73868 L .55886 .73738 L F
.835 .847 .855 r
.56062 .73877 m .55827 .73866 L .55878 .73781 L F
.56063 .73878 m .55827 .73866 L .56062 .73877 L F
.55872 .73868 m .55856 .73977 L .55827 .73866 L F
.55856 .73977 m .55807 .73899 L .55827 .73866 L F
.55856 .73977 m .55719 .74043 L .55807 .73899 L F
.56063 .73878 m .5585 .74139 L .55809 .7411 L F
.55825 .73992 m .55809 .7411 L .55719 .74043 L F
.56063 .73878 m .55809 .7411 L .55825 .73992 L F
.763 .659 .747 r
.55854 .73871 m .55719 .74043 L .55814 .74014 L F
.55839 .73887 m .55814 .74014 L .55826 .73902 L F
.55854 .73871 m .5583 .73956 L .55839 .73887 L F
.5583 .73956 m .55814 .74014 L .55839 .73887 L F
.689 .225 .145 r
.55857 .73867 m .55785 .73864 L .55862 .73861 L F
.763 .659 .747 r
.55878 .73781 m .55827 .73866 L .55854 .73871 L F
.55827 .73866 m .55719 .74043 L .55854 .73871 L F
.689 .225 .145 r
.55862 .73861 m .55811 .73863 L .55523 .73623 L F
.55811 .73863 m .55785 .73864 L .55777 .73857 L F
.55811 .73863 m .55777 .73857 L .55523 .73623 L F
.55872 .73868 m .55857 .73867 L .55862 .73861 L F
.55872 .73868 m .55864 .73935 L .55785 .73864 L F
.229 .305 .735 r
.5583 .73905 m .55857 .73932 L .55857 .73928 L F
.689 .225 .145 r
.55864 .73935 m .55864 .73937 L .5583 .73905 L F
.55864 .73935 m .5583 .73905 L .55785 .73864 L F
.229 .305 .735 r
.55827 .73902 m .5583 .73905 L .55857 .7392 L F
.5583 .73905 m .55857 .73928 L .55857 .7392 L F
.811 .521 .499 r
.55701 .73666 m .55829 .73876 L .55878 .73781 L F
.55564 .73578 m .55878 .73781 L .55848 .73713 L F
.763 .659 .747 r
.55854 .73871 m .55826 .73902 L .55848 .73713 L F
.229 .305 .735 r
.55829 .73876 m .55857 .7392 L .55848 .73713 L F
.55827 .73902 m .55857 .7392 L .55829 .73876 L F
.811 .521 .499 r
.55564 .73578 m .55823 .73888 L .55829 .73876 L F
.55564 .73578 m .55829 .73876 L .55701 .73666 L F
.763 .659 .747 r
.55878 .73781 m .55854 .73871 L .55852 .73832 L F
.811 .521 .499 r
.55829 .73876 m .55864 .73933 L .55878 .73781 L F
.763 .659 .747 r
.55878 .73781 m .55852 .73832 L .55848 .73713 L F
.229 .305 .735 r
.55857 .7392 m .55878 .73742 L .55848 .73713 L F
.835 .847 .855 r
.55863 .73974 m .55856 .73977 L .55872 .73868 L F
.229 .305 .735 r
.5586 .73996 m .55864 .73933 L .55857 .7392 L F
.55864 .73933 m .55878 .73742 L .55857 .7392 L F
.811 .521 .499 r
.55823 .73888 m .55864 .73937 L .55864 .73933 L F
.55823 .73888 m .55864 .73933 L .55829 .73876 L F
0 .166 .703 r
.5578 .73857 m .55864 .73937 L .55729 .73775 L F
.55785 .73864 m .5583 .73905 L .5578 .73857 L F
.5583 .73905 m .55864 .73937 L .5578 .73857 L F
.229 .305 .735 r
.55814 .74014 m .5586 .73996 L .55857 .73932 L F
.55814 .74014 m .55857 .73932 L .55827 .73902 L F
.73 .644 .084 r
.55878 .73781 m .55864 .73933 L .55872 .73868 L F
.55864 .73933 m .55864 .73935 L .55872 .73868 L F
.835 .847 .855 r
.56063 .73878 m .55863 .73974 L .55872 .73868 L F
.229 .305 .735 r
.5586 .73996 m .56058 .73918 L .55878 .73742 L F
.73 .644 .084 r
.55864 .73933 m .55864 .73937 L .55864 .73935 L F
0 .166 .703 r
.55523 .73623 m .55785 .73864 L .55564 .73578 L F
.55785 .73864 m .55729 .73775 L .55564 .73578 L F
.875 .62 .55 r
.61132 .68408 m .60832 .68068 L .61145 .68163 L F
.951 .75 .596 r
.60485 .67025 m .60273 .67232 L .60228 .66999 L F
.60485 .67025 m .60416 .67318 L .60273 .67232 L F
.316 0 .221 r
.4838 .72491 m .48579 .72461 L .48654 .72264 L F
.363 0 .205 r
.48579 .72461 m .48871 .72224 L .48654 .72264 L F
.709 .825 .937 r
.42011 .78791 m .42147 .78896 L .42348 .788 L F
.821 .941 .905 r
.67962 .6088 m .68071 .6095 L .68321 .60725 L F
.692 .679 .833 r
.35743 .70691 m .35488 .7083 L .35383 .70588 L F
.556 .095 .114 r
.49298 .73468 m .49441 .73275 L .49108 .73323 L F
.755 .698 .797 r
.49671 .73074 m .49441 .73275 L .49327 .73095 L F
.038 .317 .803 r
.49327 .73095 m .49441 .73275 L .49544 .73238 L F
.604 .411 .594 r
.49327 .73095 m .49392 .73353 L .49108 .73323 L F
.49392 .73353 m .49395 .73362 L .49384 .73361 L F
.49392 .73353 m .49384 .73361 L .49108 .73323 L F
0 0 0 r
.49544 .73238 m .49395 .73362 L .49298 .73468 L F
.49544 .73238 m .49509 .73251 L .49298 .73468 L F
.435 .307 .606 r
.49544 .73238 m .49395 .73362 L .49392 .73353 L F
0 0 0 r
.49509 .73251 m .49441 .73275 L .49371 .73369 L F
.49509 .73251 m .49371 .73369 L .49392 .73353 L F
.435 .307 .606 r
.49544 .73238 m .49392 .73353 L .49327 .73095 L F
0 0 0 r
.49384 .73361 m .49371 .73369 L .49366 .73376 L F
.49386 .73358 m .49371 .73369 L .49384 .73361 L F
.544 .106 .159 r
.49108 .73323 m .49384 .73361 L .49298 .73468 L F
.49384 .73361 m .49395 .73362 L .49298 .73468 L F
0 0 0 r
.49392 .73353 m .49386 .73358 L .49384 .73361 L F
.49509 .73251 m .49366 .73376 L .49298 .73468 L F
.389 .084 .323 r
.27463 .64094 m .27672 .64005 L .27478 .64055 L F
.73 .644 .084 r
.55878 .73781 m .55886 .73738 L .56063 .73878 L F
.449 0 0 r
.48788 .74419 m .49131 .74451 L .48989 .74469 L F
.436 .241 .517 r
.49369 .74159 m .49347 .74411 L .49131 .74451 L F
.494 .049 .121 r
.49347 .74411 m .48989 .74469 L .49131 .74451 L F
0 0 0 r
.72349 .596 m .72279 .59602 L .72377 .59516 L F
.263 .764 .727 r
.72377 .59516 m .72344 .59512 L .72349 .596 L F
.602 .892 .989 r
.72409 .59598 m .72349 .596 L .72344 .59512 L F
.72508 .59725 m .72349 .596 L .72409 .59598 L F
0 0 0 r
.72349 .596 m .72204 .59668 L .72279 .59602 L F
.604 .106 0 r
.72275 .59773 m .72204 .59668 L .72349 .596 L F
.602 .892 .989 r
.72508 .59725 m .72275 .59773 L .72349 .596 L F
.538 .814 .997 r
.72275 .59773 m .72508 .59725 L .7241 .59636 L F
.604 .106 0 r
.72275 .59773 m .72374 .59868 L .72271 .59746 L F
.729 .793 .903 r
.72719 .59876 m .72505 .60009 L .72374 .59868 L F
.602 .892 .989 r
.72508 .59725 m .72374 .59868 L .72275 .59773 L F
.72508 .59725 m .72629 .59777 L .72374 .59868 L F
.636 .484 .659 r
.72275 .59773 m .72476 .59938 L .72508 .59725 L F
.72275 .59773 m .72283 .60011 L .72476 .59938 L F
.538 .814 .997 r
.72275 .59773 m .7241 .59636 L .7228 .59799 L F
.505 .437 .714 r
.72103 .59995 m .72283 .60011 L .72275 .59773 L F
.538 .814 .997 r
.72275 .59773 m .7228 .59799 L .72188 .59915 L F
.604 .106 0 r
.72275 .59773 m .72271 .59746 L .72204 .59668 L F
.655 .593 .773 r
.41635 .66206 m .41285 .65952 L .41505 .65906 L F
.512 .584 .864 r
.41676 .65907 m .41635 .66206 L .41505 .65906 L F
.41676 .65907 m .41832 .66186 L .41635 .66206 L F
.499 .546 .836 r
.4196 .66481 m .41635 .66206 L .41832 .66186 L F
.559 .342 .542 r
.42635 .73613 m .42857 .73752 L .42959 .7361 L F
.42635 .73613 m .42658 .73814 L .42857 .73752 L F
.549 .75 .97 r
.68751 .58595 m .68424 .58509 L .68638 .58698 L F
.284 0 0 r
.68989 .58584 m .68751 .58595 L .68638 .58698 L F
.563 .64 .885 r
.5547 .72795 m .55316 .72943 L .55273 .72768 L F
.5547 .72795 m .55675 .73004 L .55316 .72943 L F
.295 .668 .973 r
.71844 .72864 m .71974 .72789 L .71761 .72817 L F
.71844 .72864 m .72145 .72894 L .71974 .72789 L F
.722 .345 .334 r
.60743 .65856 m .61095 .65899 L .60899 .65708 L F
.618 .376 .528 r
.60899 .65708 m .61095 .65899 L .61111 .65677 L F
.583 .618 .852 r
.41816 .78542 m .41858 .78278 L .41642 .78288 L F
.517 .384 .638 r
.41816 .78542 m .41821 .78899 L .42011 .78791 L F
.446 .192 .434 r
.44756 .75272 m .44558 .75572 L .4451 .75544 L F
.705 .506 .617 r
.44975 .75526 m .44756 .75272 L .44984 .75245 L F
.44975 .75526 m .44558 .75572 L .44756 .75272 L F
.458 .195 .427 r
.40087 .69438 m .40006 .69742 L .39801 .69774 L F
.395 .117 .369 r
.4031 .69355 m .40006 .69742 L .40087 .69438 L F
.789 .575 .61 r
.61796 .66432 m .62126 .66233 L .61796 .66214 L F
.61796 .66432 m .6214 .66476 L .62126 .66233 L F
.407 .485 .828 r
.58515 .73348 m .58808 .73499 L .58632 .73633 L F
.355 .389 .758 r
.58808 .73499 m .58876 .73838 L .58632 .73633 L F
.499 .398 .671 r
.58632 .73633 m .58876 .73838 L .58647 .73908 L F
.434 .205 .465 r
.32094 .67288 m .31904 .67342 L .31864 .6756 L F
.433 .828 .983 r
.29149 .59635 m .29093 .59722 L .28937 .59654 L F
.29149 .59635 m .29298 .59682 L .29093 .59722 L F
.462 0 0 r
.36962 .64699 m .37203 .64792 L .37369 .648 L F
0 .278 .667 r
.37407 .64811 m .37369 .648 L .37203 .64792 L F
.37407 .64811 m .37565 .64899 L .37369 .648 L F
.545 .617 .875 r
.32368 .7365 m .32636 .73656 L .32553 .73487 L F
.574 .39 .594 r
.32368 .7365 m .32406 .73867 L .32636 .73656 L F
.13 0 0 r
.4603 .78478 m .45922 .78501 L .45704 .78503 L F
.429 0 0 r
.46283 .78469 m .45922 .78501 L .4603 .78478 L F
.867 .699 .672 r
.62707 .6759 m .62756 .67359 L .62587 .67282 L F
.355 0 .044 r
.56375 .6983 m .5628 .69907 L .56586 .69821 L F
.563 .849 .997 r
.33391 .73269 m .3308 .73241 L .33208 .7332 L F
.826 .777 .806 r
.59538 .73897 m .59299 .73865 L .59454 .73655 L F
.939 .817 .697 r
.59538 .73897 m .5929 .7403 L .59299 .73865 L F
.59538 .73897 m .59425 .74208 L .5929 .7403 L F
.536 .233 .401 r
.44873 .73615 m .45098 .73587 L .45185 .73343 L F
.546 .243 .405 r
.45185 .73343 m .45383 .73496 L .45415 .73334 L F
.45185 .73343 m .45098 .73587 L .45383 .73496 L F
.516 .103 .195 r
.37044 .70485 m .37263 .70495 L .37377 .70321 L F
.15 0 0 r
.37377 .70321 m .37447 .70419 L .3754 .703 L F
.37377 .70321 m .37263 .70495 L .37447 .70419 L F
.592 .639 .866 r
.41344 .65638 m .41285 .65952 L .41143 .65682 L F
.41344 .65638 m .41505 .65906 L .41285 .65952 L F
.055 .431 .871 r
.55494 .7087 m .55549 .70805 L .55419 .70756 L F
.55494 .7087 m .55619 .7091 L .55549 .70805 L F
.918 .654 .523 r
.48566 .74697 m .48395 .74406 L .48575 .74451 L F
.555 .39 .612 r
.48788 .74419 m .48566 .74697 L .48575 .74451 L F
.567 .382 .59 r
.54777 .74213 m .54995 .74186 L .55007 .73901 L F
.677 .474 .604 r
.55007 .73901 m .54995 .74186 L .55145 .74156 L F
.262 .45 .857 r
.74099 .71555 m .73805 .71502 L .73794 .71352 L F
.74099 .71555 m .74083 .71663 L .73805 .71502 L F
.349 0 .06 r
.30826 .73542 m .30779 .7345 L .306 .73576 L F
.546 .012 0 r
.58276 .72963 m .58146 .72826 L .58148 .72704 L F
.58276 .72963 m .58391 .7305 L .58146 .72826 L F
.463 .256 .513 r
.39012 .68901 m .39238 .68637 L .39014 .6869 L F
.28 0 0 r
.34454 .65337 m .34765 .65162 L .3457 .65206 L F
.415 .235 .526 r
.53511 .75235 m .53363 .75453 L .53307 .75266 L F
.505 .329 .576 r
.34426 .6893 m .34236 .69228 L .3424 .68973 L F
.398 .223 .524 r
.28362 .63184 m .28547 .62893 L .28386 .62954 L F
0 0 0 r
.31219 .62053 m .31318 .61921 L .31472 .6182 L F
.899 .535 .34 r
.60545 .67794 m .60332 .67554 L .60497 .6759 L F
.682 .596 .754 r
.74095 .72755 m .73923 .73127 L .73778 .72722 L F
.512 .4 .663 r
.74095 .72755 m .74145 .73088 L .73923 .73127 L F
.424 .131 .361 r
.74145 .73088 m .73889 .73287 L .73923 .73127 L F
.147 .003 .414 r
.62117 .70303 m .62168 .7055 L .61997 .70626 L F
0 0 .045 r
.62168 .7055 m .61941 .70842 L .61997 .70626 L F
.709 .808 .927 r
.33638 .73015 m .33718 .73121 L .33921 .73013 L F
.403 0 0 r
.51905 .73084 m .52248 .73076 L .5215 .73123 L F
.011 0 0 r
.52504 .73076 m .5215 .73123 L .52248 .73076 L F
.382 .102 .359 r
.27925 .6351 m .27856 .63711 L .28112 .63452 L F
.301 0 .261 r
.52998 .76872 m .53091 .76673 L .53307 .76636 L F
.52998 .76872 m .53307 .76636 L .53212 .76573 L F
.627 .465 .643 r
.31548 .73422 m .31756 .73308 L .31715 .73096 L F
.742 .668 .778 r
.31624 .72819 m .31715 .73096 L .31798 .7303 L F
.872 .653 .604 r
.31899 .73417 m .32144 .73495 L .32144 .73314 L F
.3206 .7334 m .32144 .73314 L .32144 .733 L F
.31899 .73417 m .32144 .73314 L .3206 .7334 L F
.432 .334 .644 r
.31715 .73096 m .31923 .73384 L .31798 .7303 L F
.31923 .73384 m .3194 .73408 L .3193 .73381 L F
.31923 .73384 m .3193 .73381 L .31798 .7303 L F
.006 0 0 r
.3194 .73408 m .31899 .73417 L .32144 .733 L F
.432 .334 .644 r
.31715 .73096 m .31756 .73308 L .3194 .73408 L F
.207 .038 .419 r
.61435 .72467 m .6129 .72733 L .61284 .72494 L F
.828 .618 .619 r
.61132 .68408 m .61308 .68695 L .60994 .68682 L F
.807 .565 .572 r
.61308 .68695 m .60956 .68903 L .60994 .68682 L F
.61308 .68695 m .61322 .68957 L .60956 .68903 L F
.498 .344 .602 r
.31666 .67605 m .31866 .67797 L .31864 .6756 L F
.31666 .67605 m .31672 .67843 L .31866 .67797 L F
.5 .493 .78 r
.28862 .6131 m .2895 .60987 L .28774 .61 L F
.28862 .6131 m .28989 .6128 L .2895 .60987 L F
.51 .309 .543 r
.28862 .6131 m .29048 .61515 L .28989 .6128 L F
.28862 .6131 m .28848 .61576 L .29048 .61515 L F
.664 .792 .943 r
.67249 .61264 m .67271 .61473 L .67602 .61305 L F
.747 .994 .856 r
.7123 .58148 m .71357 .5796 L .71445 .58036 L F
0 .459 .837 r
.53904 .78898 m .54026 .78987 L .53731 .78876 L F
.58 .439 .654 r
.54026 .78987 m .53809 .79127 L .53731 .78876 L F
.668 .679 .851 r
.69793 .59841 m .69864 .60153 L .70126 .59915 L F
.023 .496 .877 r
.55846 .71117 m .55893 .71077 L .55619 .7091 L F
.55846 .71117 m .56004 .71165 L .55893 .71077 L F
.548 .678 .924 r
.71808 .61046 m .71955 .61164 L .71989 .6084 L F
.67 .788 .937 r
.71989 .6084 m .71955 .61164 L .72239 .61009 L F
.607 .447 .639 r
.71955 .61164 m .72389 .6101 L .72239 .61009 L F
.71955 .61164 m .72187 .61315 L .72389 .6101 L F
.389 .819 .962 r
.38561 .66636 m .38479 .66612 L .38267 .66648 L F
.143 .685 .714 r
.38772 .6656 m .38479 .66612 L .38561 .66636 L F
.377 .106 .37 r
.35126 .68079 m .34862 .68345 L .34917 .68147 L F
.745 .883 .943 r
.53412 .76322 m .53505 .76455 L .53721 .76299 L F
.038 0 0 r
.57998 .6679 m .58077 .66851 L .58164 .66684 L F
.57998 .6679 m .57882 .66938 L .58077 .66851 L F
.472 .125 .296 r
.45644 .73326 m .45883 .73294 L .45972 .73074 L F
.466 .119 .293 r
.45972 .73074 m .46089 .73246 L .462 .73092 L F
.45972 .73074 m .45883 .73294 L .46089 .73246 L F
.519 .395 .651 r
.5079 .73065 m .50583 .73368 L .5047 .73082 L F
.5079 .73065 m .5081 .73315 L .50583 .73368 L F
.295 0 .081 r
.5081 .73315 m .50434 .73515 L .50583 .73368 L F
.931 .757 .644 r
.536 .76221 m .53721 .76299 L .53801 .76104 L F
.331 .757 .974 r
.71977 .58058 m .72247 .58052 L .72349 .58117 L F
0 0 0 r
.72496 .581 m .7256 .58082 L .72516 .58089 L F
.72496 .581 m .72516 .58089 L .72349 .58117 L F
.028 .552 .862 r
.72372 .58043 m .72496 .581 L .72489 .58099 L F
.72372 .58043 m .72489 .58099 L .72247 .58052 L F
.325 .615 .954 r
.7201 .57839 m .72357 .58034 L .71889 .57951 L F
0 .243 .643 r
.72239 .57965 m .72372 .58043 L .72357 .58034 L F
.883 .45 .12 r
.72239 .57965 m .72246 .57982 L .72372 .58043 L F
.091 .647 .79 r
.72357 .58034 m .71977 .58058 L .71889 .57951 L F
.72357 .58034 m .72247 .58052 L .71977 .58058 L F
.028 .552 .862 r
.72372 .58043 m .72247 .58052 L .72357 .58034 L F
.883 .45 .12 r
.72246 .57982 m .72312 .58144 L .72372 .58043 L F
0 .08 .625 r
.7248 .58109 m .72496 .581 L .72372 .58043 L F
0 0 0 r
.72509 .58114 m .72741 .58211 L .72496 .581 L F
.743 .476 .527 r
.72588 .5844 m .7288 .58269 L .72741 .58211 L F
0 0 0 r
.72706 .58324 m .72588 .5844 L .72665 .58324 L F
.72706 .58324 m .72665 .58324 L .72741 .58211 L F
.72706 .58324 m .72741 .58211 L .72509 .58114 L F
.507 0 0 r
.72741 .58325 m .72706 .58324 L .72635 .58204 L F
.743 .476 .527 r
.72588 .5844 m .72907 .58435 L .72912 .5825 L F
.563 .327 .516 r
.72907 .58435 m .73159 .58411 L .72912 .5825 L F
.265 0 0 r
.73083 .58495 m .72907 .58435 L .7281 .58455 L F
.73083 .58495 m .73159 .58411 L .72907 .58435 L F
.286 .611 .956 r
.73054 .58482 m .7281 .58455 L .72706 .58324 L F
.73083 .58495 m .7281 .58455 L .73054 .58482 L F
.215 0 0 r
.7281 .58455 m .72907 .58435 L .72663 .58439 L F
.7281 .58455 m .72663 .58439 L .72588 .5844 L F
.507 0 0 r
.72844 .58444 m .72969 .58459 L .72706 .58324 L F
.72844 .58444 m .72706 .58324 L .72741 .58325 L F
.743 .476 .527 r
.7288 .58269 m .72912 .5825 L .72741 .58211 L F
0 .08 .625 r
.72635 .58204 m .72706 .58324 L .72496 .581 L F
.72635 .58204 m .72496 .581 L .7248 .58109 L F
0 0 0 r
.72496 .581 m .72349 .58117 L .72247 .58052 L F
.86 .55 .461 r
.50461 .72716 m .50355 .72862 L .50407 .72701 L F
.50461 .72716 m .50583 .72916 L .50355 .72862 L F
.628 .533 .727 r
.50583 .72916 m .5079 .73065 L .5047 .73082 L F
0 0 0 r
.5047 .73082 m .50457 .73117 L .50583 .72916 L F
.027 0 0 r
.33511 .65653 m .3316 .65862 L .33384 .65842 L F
.276 0 .07 r
.33715 .65596 m .33511 .65653 L .33384 .65842 L F
.872 .653 .604 r
.31899 .73417 m .32087 .73633 L .32144 .73495 L F
.519 .656 .921 r
.32144 .73495 m .32357 .73229 L .32144 .733 L F
.621 .265 .346 r
.42857 .73752 m .43209 .73823 L .42959 .7361 L F
.676 .214 .149 r
.42959 .7361 m .43209 .73823 L .43292 .73791 L F
.271 .721 .958 r
.27604 .59515 m .27286 .59466 L .27492 .59457 L F
.303 .686 .976 r
.27689 .59443 m .27604 .59515 L .27492 .59457 L F
.27689 .59443 m .27828 .59536 L .27604 .59515 L F
.479 .154 .337 r
.54727 .74373 m .54995 .74186 L .54777 .74213 L F
.263 .764 .727 r
.72377 .59516 m .7264 .59431 L .72344 .59512 L F
.338 .113 .419 r
.31 .62355 m .31048 .62139 L .31219 .62053 L F
.91 .735 .653 r
.62679 .6805 m .62834 .68332 L .6281 .68138 L F
.62679 .6805 m .62541 .68338 L .62834 .68332 L F
.883 .688 .634 r
.62499 .68577 m .62834 .68332 L .62541 .68338 L F
.62499 .68577 m .6272 .68643 L .62834 .68332 L F
.527 .404 .655 r
.30861 .70604 m .31033 .70296 L .30844 .70347 L F
.501 .887 .708 r
.54966 .68693 m .55099 .68582 L .55277 .68489 L F
0 0 0 r
.54966 .68693 m .54821 .68871 L .55099 .68582 L F
.742 .668 .778 r
.31624 .72819 m .31798 .7303 L .31943 .7275 L F
0 0 0 r
.31798 .7303 m .31969 .7293 L .31943 .7275 L F
.659 .613 .792 r
.3194 .73408 m .32005 .72946 L .31798 .7303 L F
.867 .654 .612 r
.72717 .60363 m .7302 .6017 L .72886 .60068 L F
.72717 .60363 m .73002 .6035 L .7302 .6017 L F
.775 .827 .893 r
.50637 .79021 m .51014 .78935 L .50846 .78791 L F
.747 .698 .805 r
.50846 .78791 m .51208 .78834 L .51014 .78935 L F
.50846 .78791 m .51208 .78834 L .51014 .78935 L F
.596 .359 .527 r
.51168 .79124 m .51208 .78834 L .51014 .78935 L F
.404 .232 .532 r
.30431 .73659 m .30586 .7382 L .306 .73576 L F
0 0 0 r
.37273 .66999 m .37124 .67034 L .36921 .6707 L F
.435 0 0 r
.37472 .67028 m .37124 .67034 L .37273 .66999 L F
.511 .353 .603 r
.31298 .68704 m .31503 .68422 L .31297 .6849 L F
.107 0 0 r
.34209 .7287 m .34039 .73018 L .33921 .73013 L F
.462 0 .05 r
.34379 .7296 m .34039 .73018 L .34209 .7287 L F
.829 .452 .34 r
.60076 .66753 m .5995 .66914 L .59952 .66695 L F
.60076 .66753 m .60228 .66999 L .5995 .66914 L F
.864 .782 .769 r
.30057 .71999 m .29811 .72336 L .29618 .72233 L F
.828 .77 .798 r
.30088 .71817 m .30057 .71999 L .30264 .71699 L F
.501 .322 .57 r
.30057 .71999 m .30265 .71958 L .30264 .71699 L F
.431 .821 .987 r
.30057 .71999 m .29928 .71935 L .30265 .71958 L F
.694 .703 .854 r
.53146 .73604 m .52771 .73708 L .52828 .73504 L F
.624 .372 .516 r
.52771 .73708 m .53073 .73805 L .53146 .73604 L F
.52771 .73708 m .5292 .73829 L .53073 .73805 L F
.553 .376 .595 r
.38743 .67272 m .38963 .67332 L .38938 .67047 L F
.422 .794 .994 r
.47662 .74907 m .48036 .74957 L .47813 .74984 L F
.247 .055 .411 r
.48036 .74957 m .47824 .75219 L .47813 .74984 L F
.398 .721 .989 r
.51884 .70496 m .52096 .70494 L .52 .70586 L F
.814 .784 .825 r
.30245 .73263 m .30609 .73097 L .30459 .73011 L F
.784 .537 .564 r
.61442 .6617 m .61598 .65951 L .61448 .65934 L F
.61442 .6617 m .61796 .66214 L .61598 .65951 L F
.524 .263 .461 r
.54267 .73381 m .54039 .73606 L .54103 .73367 L F
.54267 .73381 m .54257 .73581 L .54039 .73606 L F
.453 .046 .177 r
.47824 .75219 m .4783 .75296 L .47576 .75294 L F
.247 .055 .411 r
.48036 .74957 m .48002 .75178 L .47824 .75219 L F
.176 0 .179 r
.48002 .75178 m .4783 .75296 L .47824 .75219 L F
.409 .858 .804 r
.72411 .71277 m .72651 .71226 L .72326 .7135 L F
.081 0 0 r
.72612 .71363 m .72651 .71226 L .72442 .71271 L F
.72612 .71363 m .72442 .71271 L .72437 .71288 L F
.546 .03 0 r
.72413 .71351 m .72612 .71363 L .72411 .71277 L F
0 0 0 r
.72559 .7112 m .72425 .71332 L .72462 .7125 L F
.72425 .71332 m .72413 .71351 L .72429 .71319 L F
.72425 .71332 m .72429 .71319 L .72462 .7125 L F
.081 0 0 r
.72437 .71288 m .72442 .71271 L .72411 .71277 L F
.72612 .71363 m .72882 .71159 L .72651 .71226 L F
.579 .393 .594 r
.46267 .74696 m .46377 .74987 L .46035 .74987 L F
.679 .445 .559 r
.46641 .74913 m .46267 .74696 L .46537 .74591 L F
.46641 .74913 m .46377 .74987 L .46267 .74696 L F
.999 .79 .457 r
.51082 .78955 m .51208 .78834 L .51168 .79124 L F
.319 0 0 r
.51293 .78913 m .51208 .78834 L .51082 .78955 L F
.51293 .78913 m .5142 .78845 L .51208 .78834 L F
.101 .459 .887 r
.53712 .71838 m .53813 .71852 L .53727 .7191 L F
.012 .289 .786 r
.53813 .71852 m .53951 .7209 L .53727 .7191 L F
0 0 .301 r
.61346 .73345 m .61315 .7359 L .61237 .73817 L F
.228 .294 .724 r
.61313 .73091 m .61494 .73272 L .61346 .73345 L F
.281 .192 .573 r
.61494 .73272 m .61315 .7359 L .61346 .73345 L F
.569 .626 .869 r
.3985 .67325 m .39904 .66973 L .39737 .66989 L F
.3985 .67325 m .40069 .67273 L .39904 .66973 L F
.436 .467 .793 r
.3985 .67325 m .40129 .67585 L .40069 .67273 L F
.538 .506 .768 r
.47576 .75294 m .4783 .75296 L .47654 .75044 L F
.824 .683 .708 r
.31816 .72604 m .31943 .7275 L .31829 .72502 L F
.742 .668 .778 r
.31624 .72819 m .31943 .7275 L .31816 .72604 L F
0 0 .406 r
.31943 .7275 m .32036 .72645 L .31829 .72502 L F
0 .325 .81 r
.73122 .73335 m .732 .73302 L .73085 .73235 L F
0 .405 .852 r
.73122 .73335 m .73282 .73395 L .732 .73302 L F
.158 0 0 r
.28056 .65449 m .27887 .65577 L .27688 .65616 L F
0 0 0 r
.28079 .65482 m .28056 .65449 L .28246 .65361 L F
.28079 .65482 m .27887 .65577 L .28056 .65449 L F
.628 .483 .667 r
.41208 .76079 m .41467 .7634 L .4141 .76037 L F
.41208 .76079 m .41228 .7637 L .41467 .7634 L F
0 0 .121 r
.62329 .70006 m .62268 .70205 L .62117 .70303 L F
.055 0 .403 r
.6227 .70438 m .62117 .70303 L .62268 .70205 L F
.6227 .70438 m .62168 .7055 L .62117 .70303 L F
0 0 .411 r
.60876 .70011 m .60924 .69751 L .60872 .69813 L F
.517 .326 .561 r
.58876 .73838 m .58658 .74106 L .58647 .73908 L F
.432 .341 .652 r
.61315 .7359 m .61239 .7387 L .61237 .73817 L F
.164 0 .064 r
.59952 .71961 m .60111 .71928 L .60235 .71736 L F
0 0 0 r
.60235 .71736 m .60111 .71928 L .60387 .71643 L F
.709 .933 .615 r
.50116 .71204 m .49902 .7146 L .49976 .71323 L F
.041 0 0 r
.50116 .71204 m .50176 .71259 L .50286 .71085 L F
.50116 .71204 m .49976 .71323 L .50176 .71259 L F
.373 .633 .955 r
.2643 .59004 m .26389 .5915 L .26307 .59074 L F
.2643 .59004 m .26572 .59148 L .26389 .5915 L F
.749 .739 .843 r
.55629 .74416 m .55426 .74613 L .55278 .7439 L F
.477 .3 .561 r
.55629 .74416 m .55628 .74666 L .55426 .74613 L F
.352 .348 .716 r
.53291 .74575 m .5316 .74743 L .53087 .74395 L F
.528 .598 .868 r
.53291 .74575 m .53388 .74757 L .5316 .74743 L F
.126 0 .014 r
.29001 .65039 m .29091 .64912 L .29263 .6483 L F
.875 .62 .55 r
.61132 .68408 m .60866 .68386 L .60832 .68068 L F
.888 .7 .643 r
.61132 .68408 m .60828 .68588 L .60866 .68386 L F
.61132 .68408 m .60994 .68682 L .60828 .68588 L F
.285 .419 .822 r
.55894 .69673 m .56006 .69939 L .55768 .69817 L F
.219 0 0 r
.3637 .72093 m .36321 .71988 L .36514 .7191 L F
.3637 .72093 m .36164 .72139 L .36321 .71988 L F
.551 .332 .535 r
.34862 .68345 m .34616 .68693 L .3467 .68387 L F
.581 .798 .982 r
.69376 .58647 m .68989 .58584 L .69223 .58512 L F
.82 .834 .859 r
.69493 .58483 m .69376 .58647 L .69223 .58512 L F
.455 .501 .817 r
.42027 .66186 m .4196 .66481 L .41832 .66186 L F
.42027 .66186 m .42178 .66526 L .4196 .66481 L F
.714 .573 .694 r
.44669 .76123 m .44622 .76212 L .44856 .76064 L F
.733 .692 .811 r
.44761 .75778 m .44856 .76064 L .45143 .75881 L F
.54 .673 .923 r
.3915 .66774 m .39449 .66905 L .39349 .66746 L F
.413 .601 .924 r
.39449 .66905 m .3953 .66746 L .39349 .66746 L F
.39449 .66905 m .39737 .66989 L .3953 .66746 L F
.967 .808 .381 r
.74014 .60895 m .74055 .60996 L .74075 .6075 L F
.265 0 .176 r
.74014 .60895 m .74075 .6075 L .73959 .60665 L F
.53 .595 .863 r
.74147 .60798 m .74055 .60996 L .74075 .6075 L F
.265 0 .176 r
.74014 .60895 m .74147 .60798 L .74075 .6075 L F
.7 .81 .933 r
.55917 .69164 m .5572 .69296 L .55555 .69163 L F
.592 .375 .555 r
.50457 .73117 m .5021 .73101 L .50355 .72862 L F
.628 .325 .438 r
.60001 .65899 m .60347 .65675 L .59997 .65672 L F
.60001 .65899 m .60233 .65898 L .60347 .65675 L F
.629 .326 .438 r
.60347 .65675 m .60233 .65898 L .60566 .65876 L F
0 0 .318 r
.50226 .73545 m .5013 .73892 L .50397 .73663 L F
.754 .832 .912 r
.50226 .73545 m .50397 .73663 L .50434 .73515 L F
.165 .237 .693 r
.58087 .71843 m .57864 .7174 L .57915 .71603 L F
.58087 .71843 m .57962 .71968 L .57864 .7174 L F
.771 .903 .933 r
.7292 .59201 m .72888 .59095 L .72819 .59221 L F
.544 .11 .166 r
.51985 .78528 m .52211 .78552 L .52309 .78487 L F
.552 .12 .174 r
.52309 .78487 m .52211 .78552 L .52533 .78503 L F
.937 .681 .524 r
.45745 .7502 m .46035 .74987 L .45989 .75157 L F
.794 .652 .706 r
.46377 .74987 m .45989 .75157 L .46035 .74987 L F
.772 .264 0 r
.53277 .73026 m .53031 .72782 L .53155 .72799 L F
.53277 .73026 m .53171 .7302 L .53031 .72782 L F
.53277 .73026 m .53171 .7302 L .53031 .72782 L F
.214 0 0 r
.58797 .67258 m .58658 .67248 L .58936 .67111 L F
.404 .019 .192 r
.59125 .67011 m .58797 .67258 L .58936 .67111 L F
.528 .397 .646 r
.41365 .75559 m .4157 .75531 L .41554 .75223 L F
.568 .463 .695 r
.41401 .75795 m .4157 .75531 L .41365 .75559 L F
.468 .277 .538 r
.30926 .74089 m .30754 .73913 L .30948 .73849 L F
.383 .464 .82 r
.70902 .72424 m .70925 .72574 L .71078 .72446 L F
.437 .514 .84 r
.70999 .7263 m .71078 .72446 L .70925 .72574 L F
.686 .455 .566 r
.49565 .74382 m .49369 .74159 L .49585 .74186 L F
.712 .502 .603 r
.49872 .74158 m .49565 .74382 L .49585 .74186 L F
.054 0 0 r
.60428 .7549 m .60709 .75282 L .60605 .75453 L F
.038 0 0 r
.60605 .75453 m .60709 .75282 L .60886 .75189 L F
.478 .236 .469 r
.28565 .62664 m .28767 .62618 L .2881 .62407 L F
.504 .286 .516 r
.28767 .62618 m .29005 .62349 L .2881 .62407 L F
.605 .746 .944 r
.5032 .72263 m .50452 .71997 L .50272 .72145 L F
.5032 .72263 m .50628 .72259 L .50473 .72029 L F
.829 .829 .848 r
.50563 .71992 m .50628 .72259 L .50753 .71982 L F
.50452 .71997 m .50493 .72058 L .50563 .71992 L F
.50493 .72058 m .50628 .72259 L .50563 .71992 L F
.605 .746 .944 r
.5032 .72263 m .50473 .72029 L .50428 .72047 L F
.813 .335 0 r
.50309 .72358 m .5032 .72263 L .50272 .72145 L F
.50309 .72358 m .50392 .72398 L .5032 .72263 L F
.441 .851 .677 r
.50654 .72146 m .50309 .72358 L .5029 .7225 L F
.50401 .72145 m .5029 .7225 L .50272 .72145 L F
.50654 .72146 m .5029 .7225 L .50401 .72145 L F
.575 .546 .785 r
.50292 .72128 m .50654 .72146 L .50272 .72145 L F
.605 .746 .944 r
.50428 .72047 m .50473 .72029 L .50452 .71997 L F
.575 .546 .785 r
.50452 .71997 m .50505 .72036 L .50292 .72128 L F
.50505 .72036 m .50654 .72146 L .50292 .72128 L F
.829 .829 .848 r
.50452 .71997 m .50753 .71982 L .50689 .71838 L F
.727 .543 .643 r
.50689 .71838 m .50654 .72146 L .50452 .71997 L F
.50689 .71838 m .50391 .72181 L .50654 .72146 L F
.326 .025 .292 r
.50689 .72059 m .50391 .72181 L .50524 .72028 L F
.50571 .72007 m .50524 .72028 L .5055 .71998 L F
.50689 .72059 m .50524 .72028 L .50571 .72007 L F
.50689 .71942 m .5055 .71998 L .50689 .71838 L F
.50689 .72059 m .5055 .71998 L .50689 .71942 L F
.462 .205 .438 r
.5013 .73892 m .50103 .74159 L .49872 .74158 L F
0 0 .318 r
.50226 .73545 m .50225 .73787 L .5013 .73892 L F
.065 .204 .698 r
.50225 .73787 m .50333 .74105 L .5013 .73892 L F
.651 .581 .763 r
.50225 .73787 m .50103 .74159 L .5013 .73892 L F
.669 .796 .942 r
.69006 .60075 m .69333 .60129 L .6925 .5989 L F
.703 .778 .91 r
.6925 .5989 m .69333 .60129 L .69581 .59943 L F
.535 .291 .492 r
.51607 .74424 m .51939 .74063 L .51617 .74168 L F
.51607 .74424 m .51867 .74417 L .51939 .74063 L F
.414 .182 .451 r
.51939 .74063 m .52051 .74326 L .52125 .74041 L F
.51939 .74063 m .51867 .74417 L .52051 .74326 L F
.817 .889 .895 r
.43665 .78746 m .44043 .78636 L .43857 .78684 L F
.43665 .78746 m .43497 .78909 L .44043 .78636 L F
0 0 0 r
.44075 .78638 m .44043 .78636 L .44256 .78597 L F
.44075 .78638 m .43857 .78684 L .44043 .78636 L F
.501 .18 .355 r
.59445 .65916 m .59669 .65887 L .59781 .65648 L F
.736 .436 .473 r
.59781 .65648 m .60001 .65899 L .59997 .65672 L F
.59781 .65648 m .59669 .65887 L .60001 .65899 L F
.506 .342 .592 r
.43963 .76043 m .4377 .76319 L .43764 .76082 L F
.222 0 0 r
.5035 .78513 m .50044 .78437 L .50177 .78495 L F
.615 .068 0 r
.50408 .78657 m .5035 .78513 L .50177 .78495 L F
.50408 .78657 m .50511 .78593 L .5035 .78513 L F
.268 0 .123 r
.27509 .64258 m .27463 .64094 L .27372 .64236 L F
.27509 .64258 m .27672 .64005 L .27463 .64094 L F
.568 .143 .195 r
.462 .73092 m .46395 .7322 L .46529 .7304 L F
.56 .156 .234 r
.46395 .7322 m .46747 .73054 L .46529 .7304 L F
.549 .609 .865 r
.52761 .75629 m .52791 .75798 L .52997 .75701 L F
.557 .428 .661 r
.52809 .76027 m .52997 .75701 L .52791 .75798 L F
.933 .622 .162 r
.70509 .60163 m .70618 .60474 L .7054 .60364 L F
0 .141 .684 r
.70618 .60474 m .70748 .60545 L .7054 .60364 L F
.70618 .60474 m .70813 .60667 L .70748 .60545 L F
.546 .404 .639 r
.31477 .68125 m .31692 .68082 L .31672 .67843 L F
.537 .395 .636 r
.31477 .68125 m .31681 .68368 L .31692 .68082 L F
.31477 .68125 m .31503 .68422 L .31681 .68368 L F
.381 0 0 r
.55081 .70682 m .55122 .70714 L .54837 .70551 L F
.276 0 0 r
.55419 .70756 m .55122 .70714 L .55081 .70682 L F
.393 .072 .297 r
.38863 .70583 m .38768 .70835 L .38572 .70879 L F
.401 .079 .301 r
.38968 .70785 m .38863 .70583 L .39044 .70543 L F
.38968 .70785 m .38768 .70835 L .38863 .70583 L F
.045 .213 .713 r
.56343 .73816 m .56437 .74084 L .56328 .73935 L F
.211 0 0 r
.35064 .65039 m .35192 .65073 L .35328 .64925 L F
.349 0 .006 r
.35328 .64925 m .35192 .65073 L .35498 .6496 L F
.691 .861 .963 r
.72326 .7135 m .72075 .71374 L .72292 .7133 L F
.409 .858 .804 r
.72411 .71277 m .72326 .7135 L .72292 .7133 L F
.129 .25 .721 r
.7095 .60947 m .7106 .6126 L .71164 .61126 L F
.337 .554 .914 r
.7106 .6126 m .71278 .61329 L .71164 .61126 L F
.992 .874 .604 r
.73444 .63192 m .73517 .62979 L .73443 .62759 L F
.441 .14 .357 r
.53091 .76673 m .52944 .76903 L .52777 .76914 L F
.301 0 .261 r
.52998 .76872 m .52944 .76903 L .53091 .76673 L F
.701 .179 0 r
.44558 .75572 m .44434 .75729 L .4451 .75544 L F
.543 .41 .648 r
.41999 .74672 m .42173 .74375 L .41976 .74411 L F
0 .546 .78 r
.28041 .59493 m .28394 .59554 L .28198 .59574 L F
.19 .311 .758 r
.41451 .77404 m .41561 .77718 L .41632 .77569 L F
.342 .499 .87 r
.41561 .77718 m .41722 .77698 L .41632 .77569 L F
.556 .548 .801 r
.41581 .77985 m .41722 .77698 L .41561 .77718 L F
.563 .321 .507 r
.74366 .72491 m .7433 .72732 L .74095 .72755 L F
.096 .334 .807 r
.7446 .72405 m .74366 .72491 L .74242 .72177 L F
.7446 .72405 m .74488 .72522 L .74366 .72491 L F
.26 .062 .411 r
.74488 .72522 m .7433 .72732 L .74366 .72491 L F
.897 .98 .805 r
.62569 .69088 m .62557 .69267 L .62764 .6899 L F
0 0 0 r
.62569 .69088 m .62464 .69471 L .62557 .69267 L F
.228 .086 .471 r
.61313 .74415 m .61307 .74639 L .61185 .74728 L F
.144 0 .343 r
.61307 .74639 m .61137 .74946 L .61185 .74728 L F
.541 .724 .958 r
.30545 .59939 m .30221 .5984 L .30405 .59828 L F
.509 .828 1 r
.30597 .59822 m .30545 .59939 L .30405 .59828 L F
.30597 .59822 m .30749 .59893 L .30545 .59939 L F
.763 .609 .687 r
.29928 .71487 m .30264 .71699 L .30124 .71373 L F
.29928 .71487 m .30088 .71817 L .30264 .71699 L F
.558 .603 .854 r
.30264 .71699 m .30558 .71831 L .3046 .71656 L F
.497 .319 .57 r
.30264 .71699 m .30265 .71958 L .3046 .71656 L F
.479 .767 .994 r
.27384 .60366 m .27535 .60467 L .27584 .60339 L F
.287 .551 .924 r
.27535 .60467 m .27699 .60494 L .27584 .60339 L F
.105 0 .259 r
.32694 .66447 m .32563 .66509 L .32506 .6671 L F
.79 .912 .923 r
.53164 .72628 m .5296 .72769 L .53155 .72799 L F
.446 .621 .926 r
.53164 .72628 m .53155 .72799 L .53373 .72635 L F
.548 .554 .812 r
.53277 .73026 m .53373 .72635 L .53155 .72799 L F
.465 .889 .891 r
.56246 .67945 m .56289 .67866 L .5645 .67838 L F
.56246 .67945 m .56073 .67953 L .56289 .67866 L F
.36 .167 .478 r
.3857 .69442 m .38765 .69459 L .38795 .69188 L F
.381 .068 .305 r
.3857 .69442 m .38703 .69638 L .38765 .69459 L F
.3857 .69442 m .38504 .69695 L .38703 .69638 L F
.52 .334 .569 r
.39257 .6842 m .39429 .68582 L .3946 .68383 L F
.39257 .6842 m .39238 .68637 L .39429 .68582 L F
.287 0 0 r
.34765 .65162 m .34924 .65193 L .35064 .65039 L F
.213 0 0 r
.35064 .65039 m .34924 .65193 L .35192 .65073 L F
.503 .803 .999 r
.29667 .59625 m .2965 .5975 L .29501 .59667 L F
.29667 .59625 m .29847 .59714 L .2965 .5975 L F
.619 .476 .665 r
.31105 .68988 m .31329 .68939 L .31298 .68704 L F
.474 .328 .602 r
.31153 .69224 m .31329 .68939 L .31105 .68988 L F
.215 0 0 r
.44591 .7859 m .44812 .78628 L .44643 .78625 L F
.509 .319 .558 r
.52144 .7663 m .52359 .76601 L .52372 .76343 L F
.469 .111 .275 r
.52068 .76797 m .52359 .76601 L .52144 .7663 L F
.414 .27 .574 r
.27671 .63765 m .27828 .6391 L .27856 .63711 L F
.27671 .63765 m .27672 .64005 L .27828 .6391 L F
.591 .53 .755 r
.56463 .72945 m .56537 .73137 L .56736 .73042 L F
.513 .379 .635 r
.45491 .75238 m .45498 .75462 L .45296 .75306 L F
.848 .978 .869 r
.67436 .59524 m .67621 .59267 L .67714 .59378 L F
.558 .379 .595 r
.38963 .67332 m .3935 .67454 L .38938 .67047 L F
0 0 0 r
.6044 .71435 m .60553 .71321 L .60673 .71164 L F
.779 .92 .543 r
.60387 .71643 m .60553 .71321 L .6044 .71435 L F
.553 .425 .659 r
.30984 .69794 m .31194 .69766 L .31173 .69491 L F
.639 .524 .707 r
.31004 .70039 m .31194 .69766 L .30984 .69794 L F
.511 .272 .489 r
.42419 .67321 m .42389 .67527 L .42173 .67568 L F
.518 .313 .54 r
.42615 .67265 m .42389 .67527 L .42419 .67321 L F
.572 .4 .61 r
.51972 .75633 m .51895 .7576 L .52165 .75526 L F
0 .148 .689 r
.56043 .73208 m .55911 .73145 L .55824 .73036 L F
.56043 .73208 m .56107 .73344 L .55911 .73145 L F
.922 .699 .583 r
.50535 .74638 m .50589 .74709 L .50493 .74691 L F
.901 .575 .419 r
.50589 .74709 m .50486 .74904 L .50493 .74691 L F
.651 .674 .859 r
.50819 .74658 m .50589 .74709 L .50535 .74638 L F
0 0 0 r
.50574 .74743 m .50589 .74709 L .50819 .74658 L F
.651 .674 .859 r
.50819 .74658 m .50535 .74638 L .50691 .7436 L F
.104 .303 .779 r
.50691 .7436 m .50899 .74541 L .50819 .74658 L F
.637 .426 .58 r
.50899 .74541 m .50574 .74743 L .50819 .74658 L F
.50899 .74541 m .50902 .74805 L .50574 .74743 L F
.001 .553 .823 r
.50574 .74743 m .50902 .74805 L .50582 .7473 L F
0 0 0 r
.50574 .74743 m .50559 .74766 L .50589 .74709 L F
.001 .553 .823 r
.50574 .74743 m .50582 .7473 L .50555 .74723 L F
0 0 0 r
.50574 .74743 m .50486 .74904 L .50559 .74766 L F
.609 .492 .695 r
.34371 .69802 m .34048 .69485 L .34266 .69434 L F
.34371 .69802 m .342 .69976 L .34048 .69485 L F
.419 .047 .223 r
.48073 .72725 m .48292 .72689 L .4838 .72491 L F
.328 0 .181 r
.4838 .72491 m .48505 .72631 L .48579 .72461 L F
.4838 .72491 m .48292 .72689 L .48505 .72631 L F
.171 .536 .924 r
.73786 .59662 m .73814 .59589 L .73467 .59468 L F
.947 .589 .261 r
.73786 .59662 m .73843 .59873 L .73728 .59789 L F
.671 .775 .3 r
.73786 .59662 m .73728 .59789 L .73814 .59589 L F
.947 .589 .261 r
.73786 .59662 m .73843 .59873 L .73728 .59789 L F
.278 .699 .969 r
.73331 .71013 m .73194 .71065 L .73087 .71048 L F
.73331 .71013 m .73434 .71083 L .73194 .71065 L F
.431 .031 .178 r
.35497 .67904 m .35338 .68062 L .35126 .68079 L F
.593 .267 .386 r
.35667 .67838 m .35338 .68062 L .35497 .67904 L F
.781 .638 .703 r
.67436 .59524 m .67348 .59891 L .67172 .5965 L F
.27 .431 .839 r
.67172 .5965 m .67317 .59931 L .6742 .598 L F
.105 .145 .62 r
.46482 .77311 m .46461 .77571 L .4642 .77507 L F
.285 .415 .818 r
.56324 .71421 m .56465 .71708 L .56596 .71585 L F
.225 .315 .747 r
.56465 .71708 m .56681 .71909 L .56596 .71585 L F
.474 .328 .602 r
.31153 .69224 m .3133 .69175 L .31329 .68939 L F
.489 .364 .637 r
.31153 .69224 m .31348 .6942 L .3133 .69175 L F
.31153 .69224 m .31173 .69491 L .31348 .6942 L F
.01 .429 .863 r
.73728 .58647 m .73813 .58753 L .7353 .5862 L F
.686 .455 .566 r
.49565 .74382 m .49347 .74411 L .49369 .74159 L F
.556 .548 .801 r
.41581 .77985 m .41831 .77962 L .41722 .77698 L F
.564 .46 .694 r
.41642 .78288 m .41831 .77962 L .41581 .77985 L F
.495 .284 .522 r
.32317 .66771 m .32089 .67046 L .32274 .66995 L F
.403 .174 .448 r
.32506 .6671 m .32317 .66771 L .32274 .66995 L F
.485 .569 .865 r
.74264 .59634 m .74236 .59345 L .74356 .59573 L F
.74264 .59634 m .7403 .59408 L .74236 .59345 L F
.045 0 .417 r
.74348 .59789 m .74264 .59634 L .74356 .59573 L F
.74348 .59789 m .742 .59946 L .74264 .59634 L F
0 0 0 r
.49588 .71651 m .49721 .7157 L .49902 .7146 L F
.725 .974 .737 r
.49902 .7146 m .49721 .7157 L .49976 .71323 L F
.647 .545 .724 r
.57202 .70396 m .57594 .70551 L .57553 .70387 L F
.097 0 0 r
.38479 .66612 m .3814 .66728 L .38267 .66648 L F
.377 .211 .526 r
.53154 .74301 m .53214 .74437 L .53087 .74395 L F
.813 .388 0 r
.53112 .74321 m .53247 .74512 L .53214 .74437 L F
.352 .348 .716 r
.53291 .74575 m .53087 .74395 L .53214 .74437 L F
.813 .388 0 r
.53247 .74512 m .53291 .74575 L .53214 .74437 L F
.377 .211 .526 r
.53275 .74133 m .53214 .74437 L .53154 .74301 L F
.166 0 .29 r
.47924 .77137 m .47846 .77364 L .47708 .77378 L F
.696 .254 .198 r
.48718 .78725 m .48849 .78589 L .49054 .78768 L F
.36 0 .127 r
.33715 .65596 m .33929 .65552 L .34015 .65423 L F
.399 .006 .173 r
.33929 .65552 m .34222 .65381 L .34015 .65423 L F
.897 .98 .805 r
.62569 .69088 m .62764 .6899 L .62676 .68941 L F
.997 .855 .559 r
.6271 .68727 m .62676 .68941 L .62764 .6899 L F
.113 0 0 r
.52125 .74041 m .52275 .74051 L .52305 .73901 L F
.811 .337 .09 r
.52275 .74051 m .52364 .74038 L .52305 .73901 L F
.164 0 0 r
.73724 .73414 m .73513 .73416 L .73282 .73395 L F
.451 .875 .929 r
.73846 .73326 m .73724 .73414 L .73889 .73287 L F
.73846 .73326 m .73513 .73416 L .73724 .73414 L F
.949 .754 .605 r
.7189 .60674 m .72084 .60855 L .71933 .60413 L F
.608 .101 0 r
.72106 .60888 m .72084 .60855 L .7189 .60674 L F
.936 .716 .581 r
.62591 .6749 m .62707 .6759 L .62587 .67282 L F
.854 .698 .688 r
.62591 .6749 m .62699 .678 L .62707 .6759 L F
.477 .325 .596 r
.32089 .67046 m .32094 .67288 L .32279 .67233 L F
.471 .325 .6 r
.32089 .67046 m .32279 .67233 L .32274 .66995 L F
.648 .957 .76 r
.55277 .68489 m .5535 .68385 L .55423 .68331 L F
.55277 .68489 m .55099 .68582 L .5535 .68385 L F
.375 .203 .516 r
.61568 .71695 m .6162 .71891 L .61378 .72025 L F
.437 .319 .621 r
.61378 .72025 m .61567 .72177 L .61408 .7223 L F
.61378 .72025 m .6162 .71891 L .61567 .72177 L F
.071 .634 .75 r
.27028 .6039 m .27027 .60384 L .26813 .60386 L F
.27028 .6039 m .27199 .60382 L .27027 .60384 L F
.526 .248 .436 r
.59689 .7224 m .59944 .72164 L .59952 .71961 L F
.37 .126 .408 r
.59952 .71961 m .60135 .72021 L .60156 .71879 L F
.313 .197 .557 r
.60156 .71879 m .60111 .71928 L .59952 .71961 L F
.37 .126 .408 r
.59952 .71961 m .59944 .72164 L .60135 .72021 L F
.532 .154 .268 r
.44584 .7377 m .44827 .73768 L .44642 .73631 L F
.515 .165 .311 r
.44642 .73631 m .44827 .73768 L .44873 .73615 L F
.557 .773 .979 r
.71889 .57951 m .71748 .58089 L .71671 .57989 L F
.71889 .57951 m .71977 .58058 L .71748 .58089 L F
0 .326 .712 r
.7414 .60024 m .73843 .59873 L .742 .59946 L F
.847 .778 .784 r
.74348 .59789 m .7414 .60024 L .742 .59946 L F
0 0 0 r
.49588 .71651 m .49595 .71671 L .49721 .7157 L F
.59 .626 .855 r
.58878 .74073 m .58774 .74374 L .58658 .74106 L F
.141 .332 .794 r
.74538 .61885 m .74686 .6197 L .74635 .62117 L F
0 .226 .738 r
.74538 .61885 m .74635 .62117 L .74632 .62003 L F
0 0 .109 r
.74635 .62117 m .74686 .6197 L .74646 .623 L F
0 0 .045 r
.74646 .623 m .74635 .62117 L .74632 .62003 L F
.74646 .623 m .74647 .62348 L .74635 .62117 L F
0 0 .109 r
.74635 .62117 m .74646 .623 L .74647 .62348 L F
.576 .089 .061 r
.47937 .78531 m .48287 .78535 L .48156 .78656 L F
.551 .06 .043 r
.48156 .78656 m .48287 .78535 L .48573 .78665 L F
.383 .559 .903 r
.38883 .64979 m .38797 .65133 L .38704 .64959 L F
.426 .614 .928 r
.38883 .64979 m .39017 .65158 L .38797 .65133 L F
.398 .5 .846 r
.51168 .79124 m .51276 .79391 L .5145 .79261 L F
.262 .31 .724 r
.51276 .79391 m .51421 .79509 L .5145 .79261 L F
.51276 .79391 m .51349 .79566 L .51421 .79509 L F
.505 .307 .545 r
.28565 .62664 m .28547 .62893 L .28767 .62618 L F
.455 .265 .532 r
.57962 .71968 m .57939 .72275 L .57785 .72193 L F
.559 .033 0 r
.36962 .64699 m .3686 .64768 L .37203 .64792 L F
.421 .802 .991 r
.55222 .78456 m .55128 .78546 L .55004 .78488 L F
.55222 .78456 m .55352 .78517 L .55128 .78546 L F
.55128 .78546 m .55222 .78456 L .55004 .78488 L F
.55128 .78546 m .55352 .78517 L .55222 .78456 L F
.814 .594 .605 r
.62592 .67042 m .62283 .66768 L .62257 .67007 L F
.778 .574 .624 r
.62587 .67282 m .62592 .67042 L .62257 .67007 L F
.2 .47 .887 r
.74106 .58849 m .73896 .58862 L .73813 .58753 L F
.74106 .58849 m .74174 .58994 L .73896 .58862 L F
.348 .819 .761 r
.51421 .79509 m .51879 .79349 L .51776 .79394 L F
.394 .831 .693 r
.51879 .79349 m .5206 .79252 L .5199 .79278 L F
.394 .831 .691 r
.51776 .79394 m .51879 .79349 L .5199 .79278 L F
.692 .338 .371 r
.45117 .77538 m .45334 .77635 L .45439 .77382 L F
.561 .36 .567 r
.45439 .77382 m .45682 .774 L .45688 .77148 L F
.767 .548 .6 r
.45334 .77635 m .45682 .774 L .45439 .77382 L F
.2 0 0 r
.37263 .71589 m .36918 .71801 L .3708 .71672 L F
0 0 .514 r
.67185 .60409 m .67246 .60768 L .67315 .60678 L F
.118 0 .286 r
.67246 .60768 m .67358 .60844 L .67315 .60678 L F
.67246 .60768 m .67153 .60937 L .67358 .60844 L F
.821 .941 .905 r
.67962 .6088 m .68321 .60725 L .68249 .60668 L F
.814 .975 .897 r
.68249 .60668 m .68321 .60725 L .68581 .60495 L F
.3 .793 .772 r
.44812 .78628 m .45146 .78534 L .44997 .7862 L F
.271 0 0 r
.45146 .78534 m .4523 .78609 L .44997 .7862 L F
.45146 .78534 m .45363 .78539 L .4523 .78609 L F
.289 .785 .76 r
.36855 .70601 m .36942 .70561 L .37044 .70485 L F
.36855 .70601 m .36648 .70647 L .36942 .70561 L F
.435 .083 .267 r
.36164 .67592 m .35873 .67774 L .35915 .67586 L F
.532 .465 .726 r
.56247 .73614 m .56343 .73816 L .56072 .73737 L F
.493 .713 .969 r
.40141 .65445 m .40043 .65582 L .39769 .65418 L F
.40141 .65445 m .40259 .65566 L .40043 .65582 L F
.433 .629 .936 r
.28774 .61 m .28838 .60831 L .28619 .60866 L F
.28774 .61 m .2895 .60987 L .28838 .60831 L F
.587 .787 .975 r
.72671 .62074 m .72281 .62009 L .72564 .61939 L F
0 .178 .688 r
.72564 .61939 m .72751 .62087 L .72671 .62074 L F
.63 .113 0 r
.72751 .62087 m .72938 .62255 L .72671 .62074 L F
.636 .137 .046 r
.39701 .8205 m .39955 .82128 L .39762 .8215 L F
.39701 .8205 m .39762 .8215 L .39762 .8215 L F
.536 0 0 r
.39701 .8205 m .39798 .82126 L .39753 .82136 L F
.39701 .8205 m .39753 .82136 L .39609 .82169 L F
.636 .137 .046 r
.39701 .8205 m .39762 .8215 L .39722 .82137 L F
.536 0 0 r
.39798 .82126 m .39762 .8215 L .39762 .8215 L F
.39753 .82136 m .39762 .8215 L .39609 .82169 L F
.39798 .82126 m .39762 .8215 L .39753 .82136 L F
.636 .137 .046 r
.39701 .8205 m .39722 .82137 L .39609 .82169 L F
.513 .631 .905 r
.39722 .82137 m .39609 .82169 L .39762 .8215 L F
.636 .137 .046 r
.39722 .82137 m .39726 .82154 L .39609 .82169 L F
.513 .631 .905 r
.3955 .82079 m .39609 .82169 L .39722 .82137 L F
.636 .137 .046 r
.39722 .82137 m .39762 .8215 L .39726 .82154 L F
.39762 .8215 m .39762 .8215 L .39762 .8215 L F
.39762 .8215 m .39762 .8215 L .39726 .82154 L F
.536 0 0 r
.39711 .82058 m .39955 .82128 L .39798 .82126 L F
.39705 .82052 m .39955 .82128 L .39711 .82058 L F
.835 .921 .891 r
.39798 .82126 m .39955 .82128 L .40019 .81976 L F
.39762 .8215 m .40019 .81976 L .40024 .81966 L F
.513 .631 .905 r
.3955 .82079 m .39762 .8215 L .39762 .8215 L F
.835 .921 .891 r
.39762 .8215 m .39955 .82128 L .39798 .82126 L F
.39726 .82154 m .39797 .82126 L .39772 .82125 L F
.536 0 0 r
.39798 .82126 m .39821 .82143 L .39762 .8215 L F
.513 .631 .905 r
.39765 .8213 m .39762 .8215 L .39821 .82143 L F
.39764 .8213 m .39762 .8215 L .39765 .8213 L F
.39723 .82137 m .39762 .8215 L .39764 .8213 L F
.835 .921 .891 r
.39726 .82154 m .39765 .8213 L .3978 .82135 L F
.39765 .8213 m .39772 .82125 L .39774 .82128 L F
.513 .631 .905 r
.39789 .82126 m .39765 .8213 L .39821 .82143 L F
.835 .921 .891 r
.39772 .82125 m .39795 .82124 L .39774 .82128 L F
.513 .631 .905 r
.39767 .82114 m .39765 .8213 L .39789 .82126 L F
.39765 .8213 m .39765 .8213 L .39789 .82126 L F
.835 .921 .891 r
.39772 .82125 m .39797 .82126 L .40024 .81966 L F
.39772 .82125 m .40024 .81966 L .39795 .82124 L F
.39774 .82128 m .39795 .82124 L .3978 .82135 L F
.39765 .8213 m .39774 .82128 L .3978 .82135 L F
.513 .631 .905 r
.3955 .82079 m .39723 .82137 L .39764 .8213 L F
.536 0 0 r
.39798 .82126 m .39955 .82128 L .39821 .82143 L F
.876 .974 .843 r
.40024 .81966 m .39955 .82128 L .39826 .82142 L F
.39827 .82138 m .39826 .82142 L .39821 .82143 L F
.40024 .81966 m .39826 .82142 L .39827 .82138 L F
.40024 .81966 m .39821 .82143 L .40035 .82041 L F
.835 .921 .891 r
.39805 .82125 m .40024 .81966 L .40035 .82041 L F
.3978 .82135 m .39793 .82125 L .39805 .82125 L F
.677 .818 .951 r
.39804 .82125 m .39862 .8193 L .3965 .81964 L F
.39821 .82143 m .39825 .8212 L .39804 .82125 L F
.835 .921 .891 r
.39804 .82125 m .39806 .82125 L .39805 .82125 L F
.39793 .82125 m .39806 .82125 L .39804 .82125 L F
.536 0 0 r
.39701 .8205 m .39705 .82052 L .39711 .82058 L F
.513 .631 .905 r
.39462 .81947 m .39789 .82126 L .3965 .81964 L F
.39789 .82126 m .39804 .82125 L .3965 .81964 L F
.39462 .81947 m .3955 .82079 L .39765 .8213 L F
.39462 .81947 m .39765 .8213 L .39767 .82114 L F
.668 .816 .954 r
.39726 .82154 m .39808 .82124 L .39849 .81952 L F
.39808 .82124 m .39829 .82116 L .39844 .81996 L F
.677 .818 .951 r
.39808 .82124 m .39862 .8193 L .39804 .82125 L F
.668 .816 .954 r
.39808 .82124 m .39844 .81996 L .39849 .81952 L F
.677 .818 .951 r
.39825 .8212 m .39862 .8193 L .39808 .82124 L F
.835 .921 .891 r
.39793 .82125 m .40024 .81966 L .39806 .82125 L F
.513 .631 .905 r
.39789 .82126 m .39821 .82143 L .39804 .82125 L F
.668 .816 .954 r
.39849 .81952 m .40035 .82041 L .39862 .8193 L F
.39829 .82116 m .40035 .82041 L .39849 .81952 L F
.835 .921 .891 r
.39762 .8215 m .39762 .8215 L .39762 .8215 L F
.39762 .8215 m .39955 .82128 L .39762 .8215 L F
.39726 .82154 m .39762 .8215 L .39797 .82126 L F
.773 .849 .908 r
.42504 .66476 m .42178 .66526 L .42392 .66463 L F
.375 .831 .923 r
.42504 .66476 m .42581 .66415 L .42767 .66422 L F
.382 .838 .913 r
.42504 .66476 m .42392 .66463 L .42581 .66415 L F
.432 .341 .652 r
.61315 .7359 m .61409 .73856 L .61239 .7387 L F
.436 .388 .706 r
.61409 .73856 m .61495 .7408 L .61239 .7387 L F
.896 .939 .832 r
.30946 .72747 m .30708 .73105 L .30833 .73062 L F
.598 .39 .57 r
.41554 .75223 m .41819 .75225 L .41795 .7496 L F
.54 .38 .613 r
.41795 .7496 m .4201 .74954 L .41999 .74672 L F
.611 .399 .57 r
.41795 .7496 m .42029 .75187 L .4201 .74954 L F
.41795 .7496 m .41819 .75225 L .42029 .75187 L F
.503 .286 .517 r
.52359 .76601 m .52586 .76308 L .52372 .76343 L F
.906 .535 .317 r
.51901 .74947 m .51646 .74847 L .51657 .74637 L F
0 0 0 r
.51657 .74637 m .51657 .74765 L .51662 .74758 L F
.799 .493 0 r
.51655 .74584 m .51701 .74732 L .51657 .74637 L F
0 0 0 r
.51657 .74637 m .51662 .74758 L .51812 .74538 L F
.799 .493 0 r
.51607 .74424 m .51655 .74584 L .51657 .74637 L F
.422 .016 .162 r
.3049 .70777 m .30769 .70749 L .30861 .70604 L F
.527 .404 .655 r
.30861 .70604 m .31066 .70578 L .31033 .70296 L F
.447 .068 .226 r
.30769 .70749 m .31066 .70578 L .30861 .70604 L F
.787 .69 .757 r
.4222 .78499 m .42011 .78791 L .42348 .788 L F
.634 .616 .815 r
.4222 .78499 m .42348 .788 L .42557 .78735 L F
.426 .194 .457 r
.38103 .69788 m .38066 .70005 L .38293 .69737 L F
.488 .094 .219 r
.34737 .72723 m .34601 .72948 L .34379 .7296 L F
.194 0 0 r
.34991 .72601 m .34876 .72744 L .34737 .72723 L F
.315 0 .123 r
.348 .729 m .34737 .72723 L .34876 .72744 L F
.348 .729 m .34601 .72948 L .34737 .72723 L F
.497 .589 .877 r
.32139 .60734 m .31779 .6047 L .31982 .60429 L F
.454 .536 .852 r
.32295 .60701 m .32139 .60734 L .31982 .60429 L F
.493 .434 .719 r
.32295 .60701 m .32179 .60966 L .32139 .60734 L F
.497 .21 .409 r
.51905 .73084 m .51671 .73292 L .51733 .73086 L F
.51905 .73084 m .51871 .73235 L .51671 .73292 L F
.403 0 0 r
.51905 .73084 m .5215 .73123 L .51871 .73235 L F
.529 .69 .942 r
.3915 .66774 m .39272 .66614 L .38952 .66569 L F
.3915 .66774 m .39349 .66746 L .39272 .66614 L F
.637 .8 .961 r
.43935 .65526 m .43723 .65604 L .43586 .65491 L F
.55 .405 .636 r
.43935 .65526 m .44025 .65786 L .43723 .65604 L F
0 .275 .721 r
.43723 .65604 m .4386 .65657 L .43586 .65491 L F
.43723 .65604 m .44025 .65786 L .4386 .65657 L F
.122 .446 .881 r
.53951 .7209 m .54124 .7216 L .54038 .72229 L F
.098 .403 .856 r
.54124 .7216 m .54297 .7238 L .54038 .72229 L F
.501 .128 .263 r
.47143 .77685 m .47383 .7766 L .4749 .77477 L F
.463 .088 .241 r
.4749 .77477 m .47613 .77624 L .47577 .77346 L F
.4749 .77477 m .47383 .7766 L .47613 .77624 L F
.642 .681 .872 r
.34502 .70155 m .34149 .7005 L .34366 .69987 L F
.651 .672 .857 r
.34689 .70081 m .34502 .70155 L .34366 .69987 L F
.511 .353 .603 r
.31298 .68704 m .31497 .68669 L .31503 .68422 L F
.553 .443 .683 r
.31329 .68939 m .31497 .68669 L .31298 .68704 L F
.142 .687 .752 r
.435 .739 m .43747 .73864 L .43771 .73866 L F
.423 0 0 r
.43209 .73823 m .435 .739 L .43292 .73791 L F
.43209 .73823 m .43277 .73854 L .435 .739 L F
.611 .14 .11 r
.43277 .73854 m .43747 .73864 L .435 .739 L F
.43277 .73854 m .43581 .73982 L .43747 .73864 L F
.655 .938 .675 r
.43747 .73864 m .43581 .73982 L .43705 .73861 L F
.43747 .73864 m .43705 .73861 L .43838 .73731 L F
.142 .687 .752 r
.43771 .73866 m .43747 .73864 L .43838 .73858 L F
.396 .764 .993 r
.4394 .73776 m .44066 .73854 L .43838 .73858 L F
.479 .898 .866 r
.43838 .73858 m .43747 .73864 L .4394 .73776 L F
.396 .764 .993 r
.4394 .73776 m .44066 .73854 L .43838 .73858 L F
.432 0 0 r
.58908 .76328 m .5926 .76285 L .59157 .76339 L F
0 0 0 r
.59356 .76289 m .59157 .76339 L .5926 .76285 L F
.361 .718 .987 r
.27492 .59457 m .27286 .59466 L .27132 .59363 L F
.44 .611 .92 r
.72753 .73171 m .72857 .73004 L .72669 .72998 L F
.72753 .73171 m .73085 .73235 L .72857 .73004 L F
.43 .636 .942 r
.53433 .71601 m .53347 .71756 L .53248 .71603 L F
.53433 .71601 m .53712 .71838 L .53347 .71756 L F
.218 0 .111 r
.51705 .78761 m .51882 .78742 L .51985 .78528 L F
.34 0 .171 r
.51985 .78528 m .52078 .78693 L .52211 .78552 L F
.51985 .78528 m .51882 .78742 L .52078 .78693 L F
.03 0 0 r
.60428 .7549 m .60605 .75453 L .604 .7555 L F
.303 .682 .976 r
.45117 .77538 m .44913 .77555 L .44772 .77445 L F
.451 .189 .424 r
.42173 .67568 m .42115 .67801 L .41913 .67837 L F
.504 .237 .443 r
.42349 .67755 m .42173 .67568 L .42389 .67527 L F
.42349 .67755 m .42115 .67801 L .42173 .67568 L F
.858 .718 .707 r
.50583 .72916 m .50457 .73117 L .50355 .72862 L F
.462 .801 .999 r
.52618 .76821 m .52777 .76914 L .52998 .76872 L F
.478 .274 .524 r
.52777 .76914 m .52944 .76903 L .52998 .76872 L F
.331 0 .186 r
.32996 .65966 m .32687 .66201 L .32894 .66122 L F
0 0 0 r
.3316 .65862 m .32996 .65966 L .32894 .66122 L F
.418 .028 .19 r
.28798 .65095 m .28669 .65304 L .28453 .65333 L F
.195 0 .063 r
.28857 .65225 m .28798 .65095 L .29001 .65039 L F
.28857 .65225 m .28669 .65304 L .28798 .65095 L F
0 .051 .612 r
.58245 .75794 m .58461 .7605 L .58367 .75887 L F
.58245 .75794 m .58367 .75887 L .58132 .75712 L F
.924 .955 .788 r
.60856 .70867 m .60673 .71164 L .60604 .71039 L F
.989 .872 .526 r
.60673 .71164 m .60553 .71321 L .60604 .71039 L F
.593 .267 .386 r
.35667 .67838 m .35587 .68087 L .35338 .68062 L F
.358 .046 .293 r
.35774 .68024 m .35667 .67838 L .35873 .67774 L F
.35774 .68024 m .35587 .68087 L .35667 .67838 L F
.601 .273 .386 r
.68638 .58698 m .68424 .58509 L .68396 .58695 L F
.581 .336 .509 r
.41448 .68174 m .41422 .68372 L .41185 .68385 L F
.494 .253 .478 r
.41664 .68125 m .41422 .68372 L .41448 .68174 L F
.447 .435 .753 r
.44475 .77285 m .44329 .77527 L .44234 .77137 L F
.596 .628 .853 r
.44475 .77285 m .44569 .7749 L .44329 .77527 L F
.712 .502 .603 r
.49872 .74158 m .49901 .74401 L .49565 .74382 L F
.64 .559 .748 r
.50103 .74159 m .49901 .74401 L .49872 .74158 L F
.552 .515 .768 r
.57017 .6894 m .57152 .68571 L .56909 .68683 L F
.57017 .6894 m .57237 .68923 L .57152 .68571 L F
.147 0 0 r
.51185 .70509 m .51529 .70506 L .5131 .70521 L F
.5145 .70507 m .5145 .70521 L .51529 .70506 L F
.51185 .70509 m .5145 .70521 L .5145 .70507 L F
.52 .145 .269 r
.51289 .70631 m .51451 .70536 L .5145 .70521 L F
.447 .876 .785 r
.51529 .70506 m .5145 .70521 L .51451 .70521 L F
.005 0 0 r
.5131 .70521 m .51529 .70506 L .51607 .70491 L F
.447 .876 .785 r
.51529 .70506 m .51451 .70521 L .51651 .70419 L F
.52 .145 .269 r
.51451 .70536 m .51651 .70419 L .5145 .70521 L F
.005 0 0 r
.51607 .70491 m .51529 .70506 L .51659 .70485 L F
.4 .855 .825 r
.51659 .70485 m .51751 .7042 L .51884 .70496 L F
.51659 .70485 m .51529 .70506 L .51751 .7042 L F
.936 .967 .723 r
.56697 .68793 m .56498 .68908 L .56593 .68966 L F
0 0 0 r
.5678 .68794 m .56697 .68793 L .56909 .68683 L F
.5678 .68794 m .56498 .68908 L .56697 .68793 L F
.443 .281 .566 r
.67153 .60937 m .67072 .61205 L .67249 .61264 L F
.671 .59 .756 r
.67249 .61264 m .67358 .60844 L .67153 .60937 L F
.272 0 0 r
.53704 .75716 m .53497 .75735 L .53863 .75745 L F
.282 .378 .785 r
.31756 .73308 m .31899 .73417 L .3194 .73408 L F
.623 .439 .613 r
.41005 .76638 m .41261 .76622 L .41228 .7637 L F
.635 .447 .612 r
.41228 .7637 m .41494 .76575 L .41467 .7634 L F
.41228 .7637 m .41261 .76622 L .41494 .76575 L F
.924 .822 .727 r
.5929 .7403 m .59425 .74208 L .5933 .74412 L F
.641 .961 .918 r
.45153 .75644 m .44977 .75772 L .45286 .75643 L F
.423 0 0 r
.45136 .75718 m .44977 .75772 L .45153 .75644 L F
.808 .847 .879 r
.44977 .75772 m .45143 .75881 L .45286 .75643 L F
.423 0 0 r
.45099 .75876 m .44977 .75772 L .45136 .75718 L F
.733 .692 .811 r
.44761 .75778 m .4487 .75807 L .44977 .75772 L F
.4487 .75807 m .45143 .75881 L .44977 .75772 L F
.693 .514 .641 r
.60585 .70599 m .60655 .70577 L .6069 .70242 L F
.108 0 .345 r
.60728 .70488 m .6069 .70242 L .60655 .70577 L F
.842 .754 .766 r
.60682 .70113 m .60717 .70403 L .60516 .70395 L F
.60717 .70403 m .60728 .70488 L .60676 .70466 L F
.60717 .70403 m .60676 .70466 L .60516 .70395 L F
.064 0 .163 r
.6069 .70242 m .60843 .70207 L .60876 .70011 L F
.60843 .70207 m .60858 .70204 L .6086 .70182 L F
.60843 .70207 m .6086 .70182 L .60876 .70011 L F
.108 0 .345 r
.60728 .70488 m .60858 .70204 L .6069 .70242 L F
.674 .79 .936 r
.40965 .76802 m .41052 .7693 L .41319 .76857 L F
.501 .535 .824 r
.41052 .7693 m .41289 .77073 L .41319 .76857 L F
.143 .685 .714 r
.38772 .6656 m .38731 .66564 L .38479 .66612 L F
.026 .598 .739 r
.38952 .66569 m .38731 .66564 L .38772 .6656 L F
0 0 0 r
.35498 .6496 m .35722 .64924 L .35881 .6489 L F
.485 0 0 r
.35722 .64924 m .3609 .64864 L .35881 .6489 L F
.534 .078 .117 r
.49144 .78441 m .49064 .78267 L .48922 .78259 L F
.49144 .78441 m .49287 .78298 L .49064 .78267 L F
.415 .261 .562 r
.59161 .74743 m .59338 .74655 L .5933 .74412 L F
.606 .85 .99 r
.59031 .74733 m .59338 .74655 L .59161 .74743 L F
.568 .463 .695 r
.41401 .75795 m .41616 .75759 L .4157 .75531 L F
.587 .44 .648 r
.4141 .76037 m .41616 .75759 L .41401 .75795 L F
.568 .039 0 r
.46923 .77488 m .46785 .77431 L .46821 .77455 L F
.85 .395 .107 r
.46926 .77489 m .47143 .77685 L .46966 .77434 L F
.336 .021 .275 r
.46821 .77455 m .4688 .77765 L .46964 .77676 L F
.85 .395 .107 r
.46926 .77489 m .46963 .7758 L .46926 .77489 L F
.46942 .77567 m .46963 .7758 L .46926 .77489 L F
.46963 .7758 m .47035 .77621 L .46926 .77489 L F
.47035 .77621 m .47143 .77685 L .47056 .77606 L F
.47035 .77621 m .47056 .77606 L .46926 .77489 L F
.336 .021 .275 r
.46925 .77489 m .46942 .77567 L .4709 .77543 L F
.501 .759 .988 r
.4722 .77593 m .47143 .77685 L .47035 .77621 L F
.47057 .77578 m .47035 .77621 L .46942 .77567 L F
.4722 .77593 m .47035 .77621 L .47057 .77578 L F
.336 .021 .275 r
.46821 .77455 m .46964 .77676 L .46926 .77489 L F
.85 .395 .107 r
.46926 .77489 m .46926 .77489 L .46923 .77488 L F
.46926 .77489 m .46966 .77434 L .46785 .77431 L F
.336 .021 .275 r
.46923 .77488 m .46926 .77489 L .46925 .77489 L F
.46821 .77455 m .46926 .77489 L .46923 .77488 L F
.85 .395 .107 r
.4689 .77537 m .46926 .77489 L .46785 .77431 L F
.46926 .77489 m .46923 .77488 L .46785 .77431 L F
.4689 .77537 m .46942 .77567 L .46926 .77489 L F
.568 .039 0 r
.4709 .77543 m .46923 .77482 L .46925 .77489 L F
.46925 .77489 m .46785 .77431 L .46923 .77488 L F
.46923 .77482 m .46785 .77431 L .46925 .77489 L F
.4709 .77543 m .4689 .77537 L .46785 .77431 L F
.465 .767 .996 r
.47117 .77451 m .4689 .77537 L .4709 .77543 L F
.715 .921 .579 r
.4709 .77543 m .4706 .77575 L .47112 .77469 L F
.336 .021 .275 r
.46942 .77567 m .47057 .77578 L .4709 .77543 L F
.715 .921 .579 r
.4706 .77575 m .47057 .77578 L .47075 .77543 L F
.4706 .77575 m .47075 .77543 L .47112 .77469 L F
.465 .767 .996 r
.47117 .77451 m .47257 .77548 L .47075 .77543 L F
.47117 .77451 m .47075 .77543 L .4689 .77537 L F
.501 .759 .988 r
.47257 .77548 m .4722 .77593 L .4689 .77537 L F
.4722 .77593 m .46942 .77567 L .4689 .77537 L F
.715 .921 .579 r
.47112 .77469 m .46964 .77676 L .47117 .77451 L F
.47057 .77578 m .46964 .77676 L .47112 .77469 L F
.336 .021 .275 r
.46942 .77567 m .46964 .77676 L .47057 .77578 L F
.715 .921 .579 r
.46964 .77676 m .4688 .77765 L .46924 .77707 L F
.46964 .77676 m .46924 .77707 L .47117 .77451 L F
.624 .802 .373 r
.71719 .60974 m .71622 .61142 L .71808 .61046 L F
.71719 .60974 m .71556 .61252 L .71622 .61142 L F
.002 0 .031 r
.36878 .67154 m .36696 .67311 L .36921 .6707 L F
.067 0 0 r
.3672 .67391 m .36696 .67311 L .36878 .67154 L F
.3672 .67391 m .36528 .67448 L .36696 .67311 L F
.494 .636 .917 r
.31779 .6047 m .31428 .60284 L .31672 .60295 L F
.569 .654 .894 r
.31982 .60429 m .31779 .6047 L .31672 .60295 L F
.956 .722 .544 r
.45682 .774 m .45669 .7766 L .45806 .77649 L F
.315 0 0 r
.45669 .7766 m .46022 .77691 L .45806 .77649 L F
.254 0 0 r
.47505 .72946 m .47727 .72914 L .4787 .72782 L F
.469 .049 .16 r
.47727 .72914 m .48073 .72725 L .4787 .72782 L F
.628 .832 .979 r
.71876 .71506 m .71439 .71485 L .71623 .71506 L F
.771 .956 .931 r
.72075 .71374 m .71876 .71506 L .71623 .71506 L F
.782 .54 .571 r
.61113 .66118 m .61448 .65934 L .61095 .65899 L F
.61113 .66118 m .61442 .6617 L .61448 .65934 L F
.317 0 0 r
.55446 .73314 m .55282 .73263 L .5504 .73162 L F
.695 .363 .411 r
.55446 .73314 m .55402 .73517 L .55282 .73263 L F
.55446 .73314 m .55564 .73578 L .55402 .73517 L F
.692 .679 .833 r
.35743 .70691 m .35383 .70588 L .35599 .70527 L F
.659 .719 .893 r
.35918 .70611 m .35743 .70691 L .35599 .70527 L F
.284 0 0 r
.45704 .78503 m .45581 .78546 L .45363 .78539 L F
.288 0 0 r
.45758 .78583 m .45704 .78503 L .45922 .78501 L F
.45758 .78583 m .45581 .78546 L .45704 .78503 L F
.235 .131 .526 r
.61495 .7408 m .61508 .74333 L .61313 .74415 L F
.17 0 .374 r
.61313 .74415 m .61465 .74554 L .61307 .74639 L F
.61313 .74415 m .61508 .74333 L .61465 .74554 L F
.918 .654 .523 r
.48566 .74697 m .48404 .74702 L .48395 .74406 L F
.891 .564 .423 r
.48566 .74697 m .48577 .74859 L .48404 .74702 L F
.311 0 .099 r
.37124 .67034 m .36878 .67154 L .36921 .6707 L F
.79 .581 .619 r
.61796 .66432 m .61941 .66708 L .6214 .66476 L F
.792 .586 .621 r
.61941 .66708 m .62283 .66768 L .6214 .66476 L F
.479 0 .015 r
.52342 .79119 m .52666 .79074 L .52603 .79216 L F
.707 .227 .106 r
.52666 .79074 m .52879 .79263 L .52603 .79216 L F
.028 0 0 r
.57163 .67229 m .57339 .67183 L .57476 .67102 L F
0 0 0 r
.57476 .67102 m .57339 .67183 L .57689 .6703 L F
.607 .374 .538 r
.42173 .74375 m .42401 .74373 L .42442 .74117 L F
.686 .578 .729 r
.42442 .74117 m .42742 .74155 L .42658 .73814 L F
.59 .359 .534 r
.42442 .74117 m .42701 .7432 L .42742 .74155 L F
.42442 .74117 m .42401 .74373 L .42701 .7432 L F
.32 .663 .974 r
.38521 .64821 m .38437 .64914 L .38312 .64788 L F
.38521 .64821 m .38704 .64959 L .38437 .64914 L F
.764 .538 .592 r
.54039 .73606 m .54053 .73849 L .53709 .73815 L F
.558 .381 .597 r
.54257 .73581 m .54053 .73849 L .54039 .73606 L F
.782 .537 .565 r
.61442 .6617 m .61796 .66432 L .61796 .66214 L F
.724 .591 .707 r
.51671 .73292 m .51369 .7306 L .51733 .73086 L F
.708 .693 .834 r
.53027 .73284 m .53146 .73604 L .52828 .73504 L F
.807 .609 .636 r
.53073 .73805 m .53165 .73876 L .5316 .73796 L F
.53097 .73739 m .5316 .73796 L .53146 .73604 L F
.53073 .73805 m .5316 .73796 L .53097 .73739 L F
.576 .007 0 r
.53146 .73604 m .53142 .73684 L .52828 .73504 L F
.014 .378 .842 r
.52835 .73498 m .53142 .73684 L .52903 .73442 L F
.52828 .73504 m .52863 .73524 L .52835 .73498 L F
.52863 .73524 m .53142 .73684 L .52835 .73498 L F
.626 .608 .813 r
.5328 .73225 m .53146 .73604 L .53027 .73284 L F
.5328 .73225 m .5345 .73583 L .53146 .73604 L F
.618 .466 .654 r
.53146 .73604 m .53566 .73712 L .5345 .73583 L F
.53322 .73649 m .53165 .73876 L .53566 .73712 L F
.53146 .73604 m .53155 .73735 L .53322 .73649 L F
.53155 .73735 m .53165 .73876 L .53322 .73649 L F
.623 .561 .764 r
.53566 .73712 m .53621 .73506 L .5345 .73583 L F
.587 .22 .313 r
.53621 .73506 m .5325 .73735 L .53449 .73584 L F
.53456 .7358 m .53449 .73584 L .5345 .73583 L F
.53621 .73506 m .53449 .73584 L .53456 .7358 L F
.525 .041 .049 r
.5345 .73583 m .53142 .73684 L .53146 .73604 L F
.873 .727 .697 r
.72717 .60363 m .72821 .60675 L .73002 .6035 L F
0 0 0 r
.48167 .77918 m .48081 .7797 L .48267 .77881 L F
.155 .482 .899 r
.48267 .77881 m .48367 .78028 L .48167 .77918 L F
0 0 0 r
.48167 .77918 m .48081 .7797 L .48267 .77881 L F
.924 .955 .788 r
.60856 .70867 m .60604 .71039 L .60743 .7079 L F
.718 .742 .871 r
.7101 .71733 m .71071 .71959 L .7073 .7193 L F
.845 .812 .817 r
.71292 .71682 m .71071 .71959 L .7101 .71733 L F
.554 .509 .76 r
.44066 .76606 m .43861 .76648 L .4377 .76319 L F
.556 .522 .773 r
.44066 .76606 m .44146 .76819 L .43861 .76648 L F
.134 .58 .925 r
.29811 .72336 m .29796 .72273 L .29618 .72233 L F
.29811 .72336 m .30038 .72403 L .29796 .72273 L F
.53 .595 .863 r
.74147 .60798 m .74374 .61065 L .74055 .60996 L F
.761 .653 .742 r
.74629 .60972 m .74485 .61024 L .74147 .60798 L F
.74485 .61024 m .74374 .61065 L .74291 .60967 L F
.74485 .61024 m .74291 .60967 L .74147 .60798 L F
.225 .339 .771 r
.74055 .60996 m .74132 .6092 L .74014 .60895 L F
.74132 .6092 m .74204 .60848 L .74033 .60891 L F
.74132 .6092 m .74033 .60891 L .74014 .60895 L F
.602 .202 .257 r
.74374 .61065 m .74312 .61166 L .74055 .60996 L F
.225 .339 .771 r
.74055 .60996 m .74312 .61166 L .74204 .60848 L F
.433 .13 .35 r
.58699 .66259 m .5888 .6637 L .58931 .66209 L F
.58699 .66259 m .58662 .66423 L .5888 .6637 L F
.683 .162 0 r
.55939 .74547 m .55863 .746 L .55629 .74416 L F
.738 .235 .032 r
.55939 .74547 m .56188 .7477 L .55863 .746 L F
.437 .514 .84 r
.70999 .7263 m .71198 .72731 L .71078 .72446 L F
.427 .119 .338 r
.58931 .66209 m .59159 .66156 L .59207 .65923 L F
.335 .041 .309 r
.59207 .65923 m .59345 .66079 L .59445 .65916 L F
.59207 .65923 m .59159 .66156 L .59345 .66079 L F
.704 .502 .612 r
.44975 .75526 m .44761 .75778 L .44558 .75572 L F
.847 .778 .784 r
.74348 .59789 m .74159 .6002 L .7414 .60024 L F
0 .326 .712 r
.7414 .60024 m .74159 .6002 L .73843 .59873 L F
.028 0 .383 r
.58088 .72067 m .57962 .71968 L .58087 .71843 L F
.58088 .72067 m .57939 .72275 L .57962 .71968 L F
.943 .745 .605 r
.47127 .74438 m .46953 .74629 L .46782 .74481 L F
.47127 .74438 m .47106 .74675 L .46953 .74629 L F
.565 .4 .617 r
.47298 .7452 m .47106 .74675 L .47127 .74438 L F
.638 .214 .222 r
.47349 .7448 m .47298 .7452 L .47127 .74438 L F
.212 .255 .69 r
.58189 .72263 m .58084 .72472 L .57939 .72275 L F
0 0 .319 r
.5822 .72543 m .58148 .72704 L .58084 .72472 L F
.556 .5 .748 r
.74174 .58994 m .74236 .59345 L .7403 .59408 L F
.415 .235 .526 r
.53511 .75235 m .53508 .75465 L .53363 .75453 L F
.047 0 0 r
.38153 .71254 m .38105 .71168 L .38311 .71115 L F
.38153 .71254 m .37973 .71337 L .38105 .71168 L F
.307 0 .043 r
.37718 .70227 m .38066 .70005 L .37859 .70051 L F
.561 .241 .384 r
.45383 .73496 m .45609 .73493 L .45415 .73334 L F
.558 .242 .389 r
.45415 .73334 m .45609 .73493 L .45644 .73326 L F
.339 .179 .513 r
.39955 .69941 m .39801 .69774 L .40006 .69742 L F
.39955 .69941 m .39804 .70037 L .39801 .69774 L F
.334 .177 .513 r
.30831 .62654 m .31 .62355 L .31024 .626 L F
.349 .184 .511 r
.30976 .62815 m .30831 .62654 L .31024 .626 L F
.30976 .62815 m .30822 .62889 L .30831 .62654 L F
.34 0 .107 r
.35141 .7261 m .34876 .72744 L .34991 .72601 L F
.712 .591 .719 r
.32018 .71993 m .31991 .7203 L .31709 .71954 L F
.185 .641 .94 r
.31709 .71954 m .31991 .7203 L .31985 .72026 L F
.536 .571 .838 r
.31709 .71954 m .32033 .72179 L .32021 .72035 L F
.31709 .71954 m .31985 .72026 L .32017 .71993 L F
.31985 .72026 m .31985 .72026 L .31995 .72016 L F
.31985 .72026 m .31995 .72016 L .32017 .71993 L F
.883 .873 .822 r
.3208 .71658 m .31995 .72016 L .32018 .71993 L F
.31995 .72016 m .31991 .7203 L .32018 .71993 L F
.888 .878 .819 r
.31731 .71877 m .31985 .72026 L .3208 .71658 L F
.31985 .72026 m .31991 .7203 L .31995 .72016 L F
.31985 .72026 m .31995 .72016 L .3208 .71658 L F
.536 .571 .838 r
.32017 .71993 m .32021 .72035 L .32018 .71993 L F
.31985 .72026 m .32021 .72035 L .32017 .71993 L F
.185 .641 .94 r
.31709 .71954 m .31985 .72026 L .31731 .71877 L F
.69 .309 .321 r
.33921 .73013 m .33798 .73194 L .33638 .73015 L F
.123 0 0 r
.34039 .73018 m .33798 .73194 L .33921 .73013 L F
.296 0 .006 r
.35788 .72284 m .35417 .725 L .35515 .72407 L F
.042 0 0 r
.40259 .65566 m .40458 .65574 L .40608 .65578 L F
.922 .699 .583 r
.50535 .74638 m .50493 .74691 L .50315 .74393 L F
.855 .851 .837 r
.50315 .74393 m .50244 .7441 L .50251 .74385 L F
.50315 .74393 m .50333 .74105 L .502 .7434 L F
.646 .632 .822 r
.50262 .74342 m .50251 .74385 L .502 .7434 L F
.875 .545 .421 r
.502 .7434 m .50251 .74385 L .50315 .74393 L F
.855 .851 .837 r
.50315 .74393 m .50256 .74385 L .50287 .74271 L F
.50315 .74393 m .50287 .74271 L .5033 .74149 L F
.65 .618 .804 r
.50564 .74052 m .50691 .7436 L .50262 .74342 L F
.50287 .74271 m .50262 .74342 L .502 .7434 L F
.50564 .74052 m .50262 .74342 L .50287 .74271 L F
.855 .851 .837 r
.5033 .74149 m .50287 .74271 L .50333 .74105 L F
.65 .618 .804 r
.50287 .74271 m .502 .7434 L .50333 .74105 L F
.855 .851 .837 r
.50256 .74385 m .50178 .74376 L .50333 .74105 L F
.65 .618 .804 r
.50564 .74052 m .50287 .74271 L .50333 .74105 L F
.71 .283 0 r
.50315 .74393 m .50319 .74437 L .5019 .74434 L F
.50315 .74393 m .5019 .74434 L .50145 .74433 L F
.875 .545 .421 r
.50251 .74385 m .50275 .74406 L .50315 .74393 L F
.50275 .74406 m .50376 .74496 L .50315 .74393 L F
.50376 .74496 m .50535 .74638 L .50315 .74393 L F
.646 .632 .822 r
.50691 .7436 m .50535 .74638 L .50376 .74496 L F
.50303 .74382 m .50376 .74496 L .50251 .74385 L F
.71 .283 0 r
.50315 .74393 m .50389 .74517 L .50376 .74496 L F
.646 .632 .822 r
.50691 .7436 m .50376 .74496 L .50303 .74382 L F
.71 .283 0 r
.50376 .74496 m .50493 .74691 L .50477 .74668 L F
.50389 .74517 m .50493 .74691 L .50376 .74496 L F
.50315 .74393 m .50477 .74668 L .50319 .74437 L F
.646 .632 .822 r
.50691 .7436 m .50251 .74385 L .50262 .74342 L F
.855 .851 .837 r
.50251 .74385 m .50145 .74433 L .50178 .74376 L F
.50244 .7441 m .50145 .74433 L .50251 .74385 L F
.68 .305 .329 r
.49851 .78427 m .4966 .7822 L .49496 .78434 L F
.367 0 .147 r
.59182 .72493 m .59398 .72462 L .59273 .72429 L F
.648 .514 .686 r
.59427 .72036 m .59273 .72429 L .59689 .7224 L F
.668 .425 .544 r
.59398 .72462 m .59689 .7224 L .59273 .72429 L F
.203 .029 .409 r
.61941 .70842 m .61919 .71069 L .61796 .71131 L F
.149 .045 .47 r
.61919 .71069 m .61818 .71367 L .61796 .71131 L F
.883 .873 .822 r
.3208 .71658 m .32018 .71993 L .32214 .71958 L F
.615 .479 .673 r
.32033 .72179 m .32214 .71958 L .32018 .71993 L F
.572 .631 .871 r
.70813 .60667 m .7095 .60947 L .71191 .60898 L F
.129 .25 .721 r
.7095 .60947 m .71164 .61126 L .71191 .60898 L F
.814 .899 .901 r
.69223 .58512 m .69369 .58395 L .69489 .58267 L F
.804 .861 .891 r
.69489 .58303 m .69493 .58483 L .69281 .58506 L F
.69489 .58303 m .69281 .58506 L .69318 .58461 L F
.69489 .58303 m .69267 .58507 L .69369 .58397 L F
.765 .832 .904 r
.69807 .5829 m .69493 .58483 L .6949 .58348 L F
.69556 .58272 m .6949 .58348 L .69489 .58267 L F
.69807 .5829 m .6949 .58348 L .69556 .58272 L F
.69807 .5829 m .69489 .58267 L .69652 .58152 L F
.822 .781 .814 r
.69961 .57905 m .69807 .5829 L .69652 .58152 L F
.626 .552 .752 r
.69557 .58307 m .69796 .5802 L .69682 .58125 L F
.69636 .58178 m .69682 .58125 L .69652 .58152 L F
.69557 .58307 m .69682 .58125 L .69636 .58178 L F
.155 0 .33 r
.69557 .58307 m .69372 .58394 L .69391 .5861 L F
.69372 .58394 m .69369 .58395 L .6937 .58397 L F
.69372 .58394 m .6937 .58397 L .69391 .5861 L F
.804 .861 .891 r
.69318 .58461 m .69281 .58506 L .69267 .58507 L F
.69369 .58397 m .69267 .58507 L .69223 .58512 L F
.096 0 .205 r
.69489 .58267 m .69369 .58395 L .69372 .58394 L F
.69489 .58267 m .69372 .58394 L .69557 .58307 L F
.374 .091 .349 r
.69391 .5861 m .6937 .58397 L .69223 .58512 L F
.6937 .58397 m .69369 .58395 L .69223 .58512 L F
.804 .861 .891 r
.69489 .58267 m .69489 .58303 L .69223 .58512 L F
.307 .436 .828 r
.54295 .70038 m .54441 .70332 L .54567 .70187 L F
.664 .114 0 r
.54837 .70551 m .54671 .70513 L .54441 .70332 L F
.249 .347 .769 r
.54441 .70332 m .54671 .70513 L .54567 .70187 L F
.419 .69 .975 r
.30405 .59828 m .30221 .5984 L .3009 .5971 L F
.585 .469 .688 r
.61818 .71367 m .61806 .716 L .61568 .71695 L F
.134 0 .232 r
.61806 .716 m .6162 .71891 L .61568 .71695 L F
.269 .77 .878 r
.50969 .70542 m .5131 .70521 L .51092 .70591 L F
.379 0 0 r
.31709 .71954 m .31558 .71901 L .31459 .71846 L F
.512 .383 .641 r
.34616 .68693 m .34426 .6893 L .34455 .68945 L F
.404 .189 .471 r
.32179 .60966 m .32131 .61244 L .31961 .613 L F
.493 .434 .719 r
.32295 .60701 m .32363 .60911 L .32179 .60966 L F
.51 .318 .555 r
.32363 .60911 m .32131 .61244 L .32179 .60966 L F
.454 .66 .95 r
.28162 .60685 m .28081 .60433 L .27899 .6047 L F
.28162 .60685 m .28303 .60634 L .28081 .60433 L F
.525 .068 .11 r
.40115 .80683 m .40438 .80615 L .4032 .80717 L F
.40115 .80683 m .40438 .80615 L .4032 .80717 L F
0 0 0 r
.4032 .80717 m .40438 .80615 L .40539 .80614 L F
.40539 .80614 m .40438 .80615 L .4032 .80717 L F
.845 .812 .817 r
.71292 .71682 m .7101 .71733 L .71186 .71601 L F
.825 .9 .893 r
.71439 .71485 m .71292 .71682 L .71186 .71601 L F
.526 .755 .98 r
.71428 .72667 m .71531 .72777 L .71674 .72643 L F
.436 .597 .912 r
.71531 .72777 m .71761 .72817 L .71674 .72643 L F
.03 .153 .66 r
.57302 .73025 m .57378 .73329 L .57455 .73221 L F
0 0 0 r
.57411 .73573 m .57455 .73221 L .57378 .73329 L F
.167 .695 .861 r
.3609 .64864 m .36289 .64855 L .36441 .64878 L F
.089 0 0 r
.36289 .64855 m .36652 .64833 L .36441 .64878 L F
.564 .46 .694 r
.41642 .78288 m .41858 .78278 L .41831 .77962 L F
.406 .746 .993 r
.28773 .59556 m .28735 .59667 L .28593 .59543 L F
.28773 .59556 m .28937 .59654 L .28735 .59667 L F
.773 .654 .73 r
.57594 .70551 m .57737 .70903 L .57938 .70592 L F
.665 .198 .134 r
.57594 .70551 m .57792 .7064 L .57938 .70592 L F
.493 .902 .811 r
.57938 .70592 m .57792 .7064 L .57838 .70616 L F
.773 .654 .73 r
.57594 .70551 m .57938 .70592 L .57838 .70616 L F
.693 .73 .879 r
.58128 .70465 m .57838 .70616 L .57716 .70402 L F
.57838 .70616 m .57792 .7064 L .57782 .70608 L F
.57838 .70616 m .57782 .70608 L .57716 .70402 L F
.773 .654 .73 r
.57782 .70608 m .57838 .70616 L .57822 .7062 L F
.57594 .70551 m .57838 .70616 L .57782 .70608 L F
.416 .55 .882 r
.57782 .70608 m .57792 .7064 L .57594 .70551 L F
.773 .654 .73 r
.57594 .70551 m .57822 .7062 L .57797 .70626 L F
.416 .55 .882 r
.57716 .70402 m .57782 .70608 L .57594 .70551 L F
.493 .902 .811 r
.57938 .70592 m .57838 .70616 L .58128 .70465 L F
.773 .654 .73 r
.57797 .70626 m .57938 .70592 L .57859 .70649 L F
.493 .902 .811 r
.57938 .70592 m .58128 .70465 L .58091 .70557 L F
.737 .218 0 r
.57938 .70592 m .58185 .70827 L .57859 .70649 L F
.428 .367 .687 r
.58091 .70557 m .58185 .70827 L .57938 .70592 L F
.492 .356 .624 r
.31692 .68082 m .31866 .67797 L .31672 .67843 L F
.388 0 .057 r
.53809 .79127 m .537 .79297 L .53453 .79317 L F
.547 .857 .556 r
.54026 .78987 m .537 .79297 L .53809 .79127 L F
.353 .04 .288 r
.42892 .66816 m .42826 .6698 L .42596 .67032 L F
.522 .396 .65 r
.42826 .6698 m .42615 .67265 L .42596 .67032 L F
.561 .017 0 r
.33391 .73269 m .33285 .73323 L .3308 .73241 L F
0 0 0 r
.33638 .73015 m .33468 .73263 L .33391 .73269 L F
.33468 .73263 m .33285 .73323 L .33391 .73269 L F
.626 .523 .717 r
.34366 .69987 m .34149 .7005 L .342 .69976 L F
.437 .479 .806 r
.74385 .71848 m .74179 .71962 L .74083 .71663 L F
.327 .261 .629 r
.74385 .71848 m .74242 .72177 L .74179 .71962 L F
.395 .117 .369 r
.4031 .69355 m .40198 .69692 L .40006 .69742 L F
.398 .162 .436 r
.40477 .6918 m .40458 .69444 L .4031 .69355 L F
.442 .167 .4 r
.40458 .69444 m .40198 .69692 L .4031 .69355 L F
.771 .569 .625 r
.72239 .61009 m .72389 .6101 L .72295 .60777 L F
.144 0 .223 r
.7237 .60722 m .72295 .60777 L .72517 .60657 L F
.724 .725 .851 r
.72389 .6101 m .72517 .60657 L .72295 .60777 L F
.58 .171 .23 r
.52533 .78503 m .52211 .78552 L .52419 .78691 L F
.578 .237 .355 r
.52419 .78691 m .52773 .78467 L .52533 .78503 L F
.401 .771 .993 r
.72445 .73017 m .72568 .72925 L .72358 .72909 L F
.72445 .73017 m .72669 .72998 L .72568 .72925 L F
.562 .271 .431 r
.46782 .74481 m .46866 .74734 L .46537 .74591 L F
.49 .232 .45 r
.46953 .74629 m .46866 .74734 L .46782 .74481 L F
.575 .83 .993 r
.5857 .76306 m .58908 .76328 L .58794 .76268 L F
.176 .354 .803 r
.58908 .76328 m .59041 .76254 L .58794 .76268 L F
.398 0 0 r
.59157 .76339 m .5911 .76397 L .58908 .76328 L F
.176 .354 .803 r
.58908 .76328 m .5911 .76397 L .59041 .76254 L F
0 .05 .59 r
.57716 .75008 m .57793 .74917 L .57647 .74671 L F
.251 .295 .714 r
.57716 .75008 m .57958 .7511 L .57793 .74917 L F
.57716 .75008 m .57912 .75204 L .57958 .7511 L F
.217 .544 .928 r
.55721 .72904 m .55675 .73004 L .5547 .72795 L F
.55721 .72904 m .55824 .73036 L .55675 .73004 L F
.543 .41 .648 r
.41999 .74672 m .42219 .7464 L .42173 .74375 L F
.54 .382 .615 r
.4201 .74954 m .42219 .7464 L .41999 .74672 L F
.128 .328 .794 r
.72737 .62652 m .72921 .62643 L .72719 .62512 L F
.72737 .62652 m .72975 .62843 L .72921 .62643 L F
.655 .102 0 r
.29453 .72294 m .29107 .72245 L .29248 .72439 L F
.781 .638 .703 r
.67436 .59524 m .67172 .5965 L .67398 .59483 L F
.848 .978 .869 r
.67436 .59524 m .67398 .59483 L .67621 .59267 L F
.185 .641 .94 r
.31709 .71954 m .31731 .71877 L .31558 .71901 L F
.656 .845 .441 r
.31829 .72502 m .31889 .72388 L .32033 .72179 L F
.623 .945 .947 r
.31829 .72502 m .31755 .72467 L .31889 .72388 L F
.214 0 0 r
.32036 .72645 m .31816 .72604 L .31829 .72502 L F
.3 .514 .896 r
.39467 .65165 m .39754 .65276 L .39659 .65401 L F
.385 .637 .955 r
.39754 .65276 m .39769 .65418 L .39659 .65401 L F
.531 .645 .907 r
.31503 .60058 m .31428 .60284 L .31313 .60066 L F
.31503 .60058 m .31672 .60295 L .31428 .60284 L F
.539 .419 .665 r
.74377 .73006 m .74095 .72755 L .7433 .72732 L F
.74377 .73006 m .74145 .73088 L .74095 .72755 L F
.162 .64 .927 r
.55355 .72729 m .55273 .72768 L .55191 .72647 L F
.55355 .72729 m .5547 .72795 L .55273 .72768 L F
.87 .943 .579 r
.31949 .72527 m .31904 .72657 L .31916 .72645 L F
.659 .171 .081 r
.31836 .72853 m .31702 .72738 L .31916 .72645 L F
.87 .943 .579 r
.31904 .72657 m .31836 .72853 L .31916 .72645 L F
.214 0 0 r
.31935 .72626 m .31916 .72645 L .31816 .72604 L F
.32036 .72645 m .31916 .72645 L .31935 .72626 L F
.031 0 0 r
.31916 .72645 m .31702 .72738 L .31816 .72604 L F
.674 .79 .936 r
.40965 .76802 m .41261 .76622 L .41005 .76638 L F
.791 .723 .192 r
.60887 .69966 m .60924 .69751 L .60876 .70011 L F
0 0 0 r
.60876 .70011 m .60858 .70204 L .60887 .69966 L F
.643 .89 .985 r
.71445 .58036 m .71575 .57868 L .71671 .57989 L F
.71445 .58036 m .71357 .5796 L .71575 .57868 L F
.584 .658 .888 r
.56498 .68908 m .56469 .69109 L .56593 .68966 L F
.56469 .69109 m .56456 .69195 L .56553 .69034 L F
.56469 .69109 m .56553 .69034 L .56593 .68966 L F
.56498 .68908 m .56676 .69149 L .56456 .69195 L F
.649 .249 .273 r
.56676 .69149 m .5655 .69315 L .56362 .69203 L F
.246 .709 .949 r
.56206 .69172 m .56456 .69195 L .56192 .69135 L F
.649 .249 .273 r
.56396 .69173 m .56362 .69203 L .56321 .69179 L F
.56676 .69149 m .56321 .69179 L .56456 .69195 L F
.56676 .69149 m .56362 .69203 L .56396 .69173 L F
.008 0 .022 r
.49105 .71977 m .48871 .72224 L .49026 .72124 L F
.191 0 0 r
.49026 .72124 m .49332 .7194 L .49105 .71977 L F
.575 .433 .651 r
.41554 .75223 m .41805 .75482 L .41819 .75225 L F
.41554 .75223 m .4157 .75531 L .41805 .75482 L F
.548 .678 .924 r
.71808 .61046 m .71989 .6084 L .71719 .60974 L F
.839 .764 .78 r
.60125 .72736 m .5965 .72792 L .59959 .7269 L F
.59997 .7269 m .59959 .7269 L .5998 .72683 L F
.60125 .72736 m .59959 .7269 L .59997 .7269 L F
.60125 .72736 m .59875 .73037 L .5965 .72792 L F
.389 0 0 r
.59997 .7269 m .5998 .72683 L .5994 .72664 L F
.59997 .7269 m .5994 .72664 L .59774 .72584 L F
.453 .877 .775 r
.59761 .72533 m .59496 .72676 L .59774 .72584 L F
.506 .53 .815 r
.59774 .72584 m .59862 .72363 L .59708 .72482 L F
.389 0 0 r
.60125 .72736 m .59997 .7269 L .59774 .72584 L F
.506 .53 .815 r
.59774 .72584 m .5998 .72683 L .59862 .72363 L F
.806 .432 .348 r
.59761 .72533 m .5998 .72683 L .5965 .72792 L F
.59891 .72692 m .59882 .729 L .60013 .7284 L F
.59827 .72614 m .59842 .72693 L .59891 .72692 L F
.59842 .72693 m .59882 .729 L .59891 .72692 L F
.59761 .72533 m .59781 .72593 L .59827 .72614 L F
.59781 .72593 m .59882 .729 L .59827 .72614 L F
.293 .755 .948 r
.60327 .72715 m .5998 .72683 L .60125 .72736 L F
.218 0 0 r
.26617 .60401 m .26813 .60386 L .26577 .60426 L F
.777 .73 .809 r
.60956 .68903 m .61054 .69216 L .60967 .69136 L F
.60956 .68903 m .61322 .68957 L .61054 .69216 L F
.987 .725 .432 r
.61054 .69216 m .60955 .6938 L .60967 .69136 L F
.61054 .69216 m .61062 .69453 L .60955 .6938 L F
.358 .568 .918 r
.31153 .59856 m .31078 .59996 L .30952 .59894 L F
.31153 .59856 m .31313 .60066 L .31078 .59996 L F
.251 .06 .414 r
.46866 .74734 m .46641 .74913 L .46537 .74591 L F
.296 0 .006 r
.35788 .72284 m .3564 .72454 L .35417 .725 L F
.142 0 0 r
.35825 .72391 m .35788 .72284 L .35969 .72204 L F
.35825 .72391 m .3564 .72454 L .35788 .72284 L F
.769 .465 .472 r
.52808 .78708 m .53111 .78519 L .52773 .78467 L F
.52808 .78708 m .53184 .78729 L .53111 .78519 L F
.664 .466 .607 r
.6441 .51968 m .64102 .51998 L .64303 .51894 L F
.6441 .51968 m .64188 .52213 L .64102 .51998 L F
.6441 .51968 m .64416 .52199 L .64188 .52213 L F
.648 .51 .682 r
.64687 .51923 m .6441 .51968 L .64629 .51684 L F
0 0 0 r
.6441 .51968 m .64529 .51854 L .64629 .51684 L F
.5 .831 .999 r
.64303 .51894 m .64529 .51854 L .6441 .51968 L F
.643 .45 .606 r
.64675 .52163 m .6441 .51968 L .64687 .51923 L F
.64675 .52163 m .64416 .52199 L .6441 .51968 L F
.094 .544 .909 r
.54698 .725 m .54503 .72517 L .5437 .72443 L F
.854 .698 .688 r
.62591 .6749 m .62406 .67774 L .62699 .678 L F
.881 .639 .568 r
.62406 .67774 m .62679 .6805 L .62699 .678 L F
.208 .523 .918 r
.28371 .60767 m .28452 .60677 L .28303 .60634 L F
.28371 .60767 m .28619 .60866 L .28452 .60677 L F
.772 .678 .759 r
.5551 .74107 m .55629 .74416 L .55278 .7439 L F
.767 .675 .762 r
.5585 .74139 m .55629 .74416 L .5551 .74107 L F
.526 .339 .57 r
.55863 .746 m .55628 .74666 L .55629 .74416 L F
.546 .489 .743 r
.42658 .73814 m .42742 .74155 L .4294 .74099 L F
.633 .398 .544 r
.42701 .7432 m .4294 .74099 L .42742 .74155 L F
.354 0 0 r
.37472 .67028 m .37305 .67088 L .37124 .67034 L F
.253 .749 .674 r
.37603 .66978 m .37472 .67028 L .37672 .66967 L F
.37603 .66978 m .37305 .67088 L .37472 .67028 L F
.703 .985 .848 r
.58009 .67647 m .57994 .67676 L .58133 .67593 L F
.737 .991 .865 r
.58133 .67593 m .57994 .67676 L .58064 .67654 L F
.298 0 .08 r
.58091 .67596 m .5811 .67778 L .57831 .67786 L F
.703 .985 .848 r
.57996 .67653 m .58272 .67509 L .58206 .67439 L F
.298 0 .08 r
.58225 .67498 m .58218 .67515 L .58091 .67596 L F
.703 .985 .848 r
.58168 .67564 m .58133 .67593 L .58272 .67509 L F
.57996 .67653 m .58133 .67593 L .58168 .67564 L F
.737 .991 .865 r
.58133 .67593 m .58064 .67654 L .58181 .67617 L F
.298 0 .08 r
.58218 .67515 m .5811 .67778 L .58091 .67596 L F
.703 .985 .848 r
.57996 .67653 m .57995 .67656 L .58009 .67647 L F
.57995 .67656 m .57994 .67676 L .58009 .67647 L F
.354 .145 .451 r
.58541 .67412 m .58449 .67623 L .58237 .67505 L F
.58241 .67501 m .58237 .67505 L .58235 .67503 L F
.58541 .67412 m .58237 .67505 L .58241 .67501 L F
.58248 .67491 m .58235 .67503 L .58225 .67498 L F
.244 0 0 r
.58581 .67303 m .58206 .67439 L .58272 .67509 L F
.354 .145 .451 r
.58541 .67412 m .58235 .67503 L .58248 .67491 L F
.737 .991 .865 r
.58272 .67509 m .58133 .67593 L .58181 .67617 L F
.751 .763 .863 r
.29768 .71351 m .29928 .71487 L .30124 .71373 L F
.449 .209 .458 r
.40907 .68836 m .40614 .69013 L .40714 .68899 L F
.426 .192 .453 r
.38795 .69188 m .38984 .69144 L .39012 .68901 L F
.463 .256 .513 r
.39012 .68901 m .39228 .68885 L .39238 .68637 L F
.481 .251 .488 r
.38984 .69144 m .39228 .68885 L .39012 .68901 L F
.56 .156 .234 r
.462 .73092 m .46089 .73246 L .46395 .7322 L F
.261 .545 .925 r
.73467 .59468 m .73734 .59446 L .73356 .59327 L F
.73467 .59468 m .73814 .59589 L .73734 .59446 L F
.247 0 .15 r
.45745 .7502 m .45682 .75182 L .45491 .75238 L F
.603 .225 .299 r
.45989 .75157 m .45682 .75182 L .45745 .7502 L F
.771 .956 .931 r
.72075 .71374 m .71623 .71506 L .71698 .71382 L F
0 0 0 r
.71698 .71382 m .72292 .7133 L .72075 .71374 L F
.701 .179 0 r
.44558 .75572 m .44633 .75693 L .44434 .75729 L F
.44558 .75572 m .44761 .75778 L .44633 .75693 L F
.639 .524 .707 r
.31004 .70039 m .31228 .70012 L .31194 .69766 L F
.581 .433 .645 r
.31033 .70296 m .31228 .70012 L .31004 .70039 L F
0 .368 .8 r
.73174 .62593 m .73443 .62759 L .73288 .62687 L F
.36 .185 .504 r
.3946 .68383 m .39647 .68339 L .39633 .68083 L F
.31 .091 .412 r
.39429 .68582 m .39647 .68339 L .3946 .68383 L F
0 .176 .705 r
.73155 .62447 m .72971 .62354 L .72938 .62255 L F
.73155 .62447 m .73174 .62593 L .72971 .62354 L F
.486 .231 .452 r
.41913 .67837 m .41868 .68086 L .41664 .68125 L F
.549 .322 .524 r
.42115 .67801 m .41868 .68086 L .41913 .67837 L F
.966 .684 .445 r
.57602 .70915 m .57702 .71409 L .57808 .71434 L F
.796 .461 .422 r
.53184 .78729 m .53355 .78991 L .53456 .78758 L F
.013 0 .058 r
.53456 .78758 m .5351 .78888 L .53644 .78797 L F
.53456 .78758 m .5337 .78956 L .5351 .78888 L F
.451 .866 .95 r
.5351 .78888 m .53424 .78867 L .5359 .78849 L F
.5351 .78888 m .5359 .78849 L .53749 .78832 L F
.013 0 .058 r
.5337 .78956 m .53355 .78991 L .5351 .78888 L F
.553 .443 .683 r
.31329 .68939 m .31534 .68897 L .31497 .68669 L F
.578 .411 .618 r
.31329 .68939 m .3155 .6914 L .31534 .68897 L F
.31329 .68939 m .3133 .69175 L .3155 .6914 L F
.163 .501 .909 r
.7306 .62954 m .73246 .62935 L .72975 .62843 L F
.7306 .62954 m .73298 .63056 L .73246 .62935 L F
.108 .053 .507 r
.52259 .74268 m .52125 .74041 L .52051 .74326 L F
.52259 .74268 m .52275 .74051 L .52125 .74041 L F
.023 0 .346 r
.67185 .60409 m .67237 .60402 L .67273 .60152 L F
.047 .054 .542 r
.67185 .60409 m .67315 .60678 L .67237 .60402 L F
.598 .497 .71 r
.31194 .69766 m .31348 .6942 L .31173 .69491 L F
.413 .174 .44 r
.4065 .69384 m .40477 .6918 L .40614 .69013 L F
.449 .209 .458 r
.40907 .68836 m .40884 .6913 L .40614 .69013 L F
.437 .194 .446 r
.40843 .6933 m .40614 .69013 L .40884 .6913 L F
.40843 .6933 m .4065 .69384 L .40614 .69013 L F
.494 .231 .444 r
.41422 .68372 m .41171 .68597 L .41185 .68385 L F
.207 .695 .926 r
.5445 .69155 m .54632 .69116 L .54773 .69212 L F
.62 .816 .976 r
.55719 .74043 m .5585 .74139 L .5551 .74107 L F
.844 .594 .561 r
.54881 .69093 m .54588 .69124 L .54717 .68954 L F
.54881 .69093 m .54632 .69116 L .54588 .69124 L F
.54632 .69116 m .54881 .69093 L .54773 .69212 L F
.659 .172 .083 r
.50068 .78983 m .49971 .79042 L .49783 .7894 L F
.19 0 0 r
.50068 .78983 m .50161 .79015 L .49971 .79042 L F
.50068 .78983 m .50332 .7897 L .50161 .79015 L F
.699 .552 .683 r
.30082 .71155 m .30392 .71266 L .30366 .70834 L F
0 0 .078 r
.30392 .71266 m .3049 .70777 L .30366 .70834 L F
.399 .275 .594 r
.61567 .72177 m .61435 .72467 L .61408 .7223 L F
.363 0 .205 r
.48579 .72461 m .48775 .72422 L .48871 .72224 L F
.393 .027 .22 r
.48871 .72224 m .49003 .72367 L .49026 .72124 L F
.48871 .72224 m .48775 .72422 L .49003 .72367 L F
.626 .523 .717 r
.34366 .69987 m .342 .69976 L .34371 .69802 L F
.814 .975 .897 r
.68249 .60668 m .68581 .60495 L .6846 .60384 L F
.859 .847 .831 r
.6846 .60384 m .68581 .60495 L .68815 .60196 L F
.604 .891 .99 r
.29618 .72233 m .29529 .72311 L .29453 .72294 L F
.789 .62 .671 r
.62257 .67007 m .62283 .66768 L .61941 .66708 L F
.652 .495 .658 r
.51024 .73056 m .5081 .73315 L .5079 .73065 L F
.51024 .73056 m .5081 .73315 L .5079 .73065 L F
.413 .174 .44 r
.4065 .69384 m .40458 .69444 L .40477 .6918 L F
.774 .541 .582 r
.5933 .74412 m .59338 .74655 L .58996 .74618 L F
.924 .822 .727 r
.5929 .7403 m .5933 .74412 L .59254 .74158 L F
.837 .778 .796 r
.32036 .72645 m .31969 .7293 L .32386 .72496 L F
.32036 .72645 m .32386 .72496 L .32219 .72568 L F
.586 .042 0 r
.32386 .72496 m .3242 .7256 L .32219 .72568 L F
.32386 .72496 m .32588 .7268 L .3242 .7256 L F
.479 .154 .337 r
.54727 .74373 m .54944 .7436 L .54995 .74186 L F
.773 .513 .543 r
.54944 .7436 m .55145 .74156 L .54995 .74186 L F
.811 .67 .707 r
.57391 .70753 m .57737 .70903 L .57594 .70551 L F
.858 .637 .601 r
.57391 .70753 m .57602 .70915 L .57737 .70903 L F
.377 .435 .794 r
.57594 .70551 m .57737 .70903 L .57859 .70649 L F
.298 .045 .352 r
.32073 .61416 m .31961 .613 L .32131 .61244 L F
.32073 .61416 m .31904 .61499 L .31961 .613 L F
.474 .514 .819 r
.58691 .73206 m .58515 .73348 L .58391 .7305 L F
.453 .477 .793 r
.58691 .73206 m .58808 .73499 L .58515 .73348 L F
.585 .848 .994 r
.42823 .78732 m .42729 .78689 L .43073 .78654 L F
.543 .572 .834 r
.50732 .78759 m .50637 .79021 L .50846 .78791 L F
.505 .329 .576 r
.34426 .6893 m .34453 .69185 L .34236 .69228 L F
.531 .419 .671 r
.34453 .69185 m .34465 .69391 L .34236 .69228 L F
.532 .419 .67 r
.34465 .69391 m .34266 .69434 L .34236 .69228 L F
.715 .189 0 r
.52578 .70823 m .5277 .71041 L .52914 .7112 L F
.471 .812 .999 r
.5277 .71041 m .53111 .71075 L .52914 .7112 L F
.471 .293 .558 r
.53111 .71075 m .52927 .7133 L .52914 .7112 L F
.496 0 0 r
.5504 .73162 m .55282 .73263 L .54959 .7322 L F
.38 0 .034 r
.47654 .74394 m .47298 .7452 L .47349 .7448 L F
.501 .345 .601 r
.31503 .68422 m .31707 .68631 L .31681 .68368 L F
.31503 .68422 m .31497 .68669 L .31707 .68631 L F
.799 .493 0 r
.51607 .74424 m .51812 .74538 L .51867 .74417 L F
.51607 .74424 m .51657 .74637 L .51812 .74538 L F
.011 0 0 r
.52504 .73076 m .52301 .73116 L .5215 .73123 L F
.819 .95 .905 r
.52456 .72954 m .52504 .73076 L .5256 .72981 L F
.899 .966 .82 r
.52456 .72954 m .52301 .73116 L .52504 .73076 L F
.656 .12 0 r
.50732 .78759 m .50511 .78593 L .50408 .78657 L F
0 0 .045 r
.62168 .7055 m .62089 .70735 L .61941 .70842 L F
.302 .212 .585 r
.62089 .70735 m .61919 .71069 L .61941 .70842 L F
.554 .235 .382 r
.43061 .66933 m .42892 .66816 L .42969 .6661 L F
.43061 .66933 m .42826 .6698 L .42892 .66816 L F
.773 .513 .543 r
.54944 .7436 m .55278 .7439 L .55145 .74156 L F
.281 .192 .573 r
.61494 .73272 m .61526 .7348 L .61315 .7359 L F
0 0 .405 r
.61526 .7348 m .61409 .73856 L .61315 .7359 L F
.28 0 0 r
.34454 .65337 m .34654 .65298 L .34765 .65162 L F
.291 0 0 r
.34765 .65162 m .34654 .65298 L .34924 .65193 L F
.796 .832 .879 r
.536 .76221 m .53412 .76322 L .53721 .76299 L F
.389 .805 .607 r
.59594 .7604 m .59943 .75819 L .59769 .75927 L F
.59769 .75927 m .59943 .75819 L .60104 .75716 L F
.383 .404 .758 r
.2895 .60987 m .28989 .6128 L .2917 .61148 L F
.578 .515 .748 r
.29048 .61515 m .2917 .61148 L .28989 .6128 L F
.402 .148 .41 r
.2976 .64319 m .29708 .64519 L .2952 .64576 L F
.314 .035 .319 r
.29955 .64261 m .29708 .64519 L .2976 .64319 L F
.635 .759 .938 r
.53974 .7545 m .53508 .75465 L .53511 .75235 L F
.419 0 0 r
.55122 .70714 m .54671 .70513 L .54837 .70551 L F
.284 .748 .947 r
.29501 .59667 m .29298 .59682 L .29149 .59635 L F
.419 .514 .849 r
.41539 .65615 m .41505 .65906 L .41344 .65638 L F
.41539 .65615 m .41676 .65907 L .41505 .65906 L F
.38 0 .034 r
.47654 .74394 m .47598 .74501 L .47298 .7452 L F
.862 .584 .516 r
.47883 .74389 m .47598 .74501 L .47654 .74394 L F
.391 .837 .931 r
.45988 .77018 m .4618 .77035 L .45935 .77093 L F
.58 .515 .746 r
.45935 .77093 m .46139 .77138 L .4618 .77035 L F
.614 .283 .386 r
.46139 .77138 m .46112 .77326 L .45935 .77093 L F
0 .046 .612 r
.45935 .77093 m .46112 .77326 L .45988 .77018 L F
.398 .223 .524 r
.28362 .63184 m .28531 .63124 L .28547 .62893 L F
.291 0 .287 r
.28362 .63184 m .28282 .6338 L .28531 .63124 L F
.513 .786 .994 r
.3938 .65078 m .39362 .65204 L .39236 .65127 L F
.3938 .65078 m .39467 .65165 L .39362 .65204 L F
.916 .528 .128 r
.47971 .7788 m .47976 .777 L .47882 .77635 L F
.47971 .7788 m .48081 .7797 L .47976 .777 L F
.568 .905 .977 r
.56006 .69939 m .56208 .69872 L .5628 .69907 L F
.82 .972 .896 r
.5628 .69907 m .56452 .69651 L .56586 .69821 L F
.5628 .69907 m .56208 .69872 L .56452 .69651 L F
.457 .463 .776 r
.28922 .61773 m .29081 .61737 L .28848 .61576 L F
.436 .373 .688 r
.28922 .61773 m .2915 .61925 L .29081 .61737 L F
.28922 .61773 m .28954 .62123 L .2915 .61925 L F
.447 .195 .437 r
.41171 .68597 m .40907 .68836 L .40956 .68646 L F
.286 0 0 r
.51622 .78873 m .5142 .78845 L .51293 .78913 L F
.377 0 .053 r
.51705 .78761 m .5142 .78845 L .51622 .78873 L F
.432 .447 .775 r
.44311 .76795 m .44234 .77137 L .44146 .76819 L F
.44311 .76795 m .44411 .77115 L .44234 .77137 L F
.447 .435 .753 r
.44475 .77285 m .44234 .77137 L .44411 .77115 L F
.466 .878 .943 r
.3308 .73241 m .32913 .73234 L .32845 .73314 L F
.936 .682 .529 r
.32676 .73308 m .32845 .73314 L .32913 .73234 L F
.32676 .73308 m .32845 .73569 L .32845 .73314 L F
.724 .591 .707 r
.51671 .73292 m .51352 .73305 L .51369 .7306 L F
.739 .521 .598 r
.51688 .73563 m .51352 .73305 L .51671 .73292 L F
0 0 0 r
.51871 .73235 m .51688 .73563 L .51671 .73292 L F
.147 .09 .53 r
.67273 .60152 m .67453 .60023 L .6742 .598 L F
.314 .135 .471 r
.67273 .60152 m .6748 .60287 L .67453 .60023 L F
.67273 .60152 m .67237 .60402 L .6748 .60287 L F
.661 .248 .25 r
.64629 .51684 m .64899 .51828 L .64856 .51631 L F
.535 .438 .692 r
.64629 .51684 m .64687 .51923 L .64899 .51828 L F
.661 .248 .25 r
.64629 .51684 m .64529 .51854 L .64899 .51828 L F
.535 .438 .692 r
.64629 .51684 m .64899 .51828 L .64856 .51631 L F
.307 .009 .285 r
.31649 .61747 m .31719 .61573 L .31904 .61499 L F
.588 .015 0 r
.72496 .581 m .72741 .58211 L .7256 .58082 L F
.422 .35 .671 r
.28954 .62123 m .2914 .6225 L .2915 .61925 L F
.414 .351 .678 r
.28954 .62123 m .29005 .62349 L .2914 .6225 L F
.817 .746 .785 r
.30155 .73055 m .29925 .73288 L .30245 .73263 L F
.819 .727 .762 r
.29925 .73288 m .30042 .73582 L .30245 .73263 L F
.789 .734 .802 r
.30155 .73055 m .30245 .73263 L .30459 .73011 L F
.585 .543 .773 r
.39633 .68083 m .39795 .67797 L .39687 .67821 L F
.606 .079 0 r
.50637 .79021 m .50507 .79053 L .50332 .7897 L F
.543 .572 .834 r
.50732 .78759 m .50847 .79002 L .50637 .79021 L F
.405 0 0 r
.508 .79133 m .50637 .79021 L .50847 .79002 L F
.508 .79133 m .50507 .79053 L .50637 .79021 L F
.512 .383 .641 r
.34616 .68693 m .3465 .69012 L .34426 .6893 L F
.599 .397 .579 r
.34679 .69135 m .34426 .6893 L .3465 .69012 L F
.34679 .69135 m .34453 .69185 L .34426 .6893 L F
.237 0 .077 r
.58164 .66684 m .58364 .66678 L .58456 .6649 L F
.229 0 .073 r
.58456 .6649 m .58562 .666 L .58662 .66423 L F
.58456 .6649 m .58364 .66678 L .58562 .666 L F
.522 .09 .162 r
.69961 .57905 m .7024 .57889 L .70159 .57822 L F
.506 .342 .592 r
.43963 .76043 m .4397 .76297 L .4377 .76319 L F
.554 .509 .76 r
.44066 .76606 m .4377 .76319 L .4397 .76297 L F
.157 .157 .607 r
.61441 .72946 m .61313 .73091 L .6129 .72733 L F
.253 .3 .718 r
.61441 .72946 m .61494 .73272 L .61313 .73091 L F
.125 .674 .783 r
.27199 .60382 m .27384 .60366 L .27027 .60384 L F
.546 .489 .743 r
.42658 .73814 m .4294 .74099 L .42857 .73752 L F
.214 0 0 r
.58797 .67258 m .58581 .67303 L .58658 .67248 L F
.167 0 0 r
.51622 .78873 m .51882 .78742 L .51705 .78761 L F
.379 .099 .358 r
.2952 .64576 m .2964 .64705 L .29465 .6478 L F
.2952 .64576 m .29708 .64519 L .2964 .64705 L F
.427 .227 .505 r
.39238 .68637 m .39402 .68831 L .39429 .68582 L F
.39238 .68637 m .39228 .68885 L .39402 .68831 L F
.533 .374 .611 r
.49344 .74649 m .49176 .74787 L .49171 .74784 L F
.49344 .74649 m .49397 .74893 L .49176 .74787 L F
.658 .437 .573 r
.49397 .74893 m .49098 .75125 L .49176 .74787 L F
.231 .353 .782 r
.57434 .73819 m .57567 .74153 L .57679 .73995 L F
.558 .519 .767 r
.57533 .74364 m .57679 .73995 L .57567 .74153 L F
.043 0 0 r
.5206 .79252 m .52208 .79248 L .5199 .79278 L F
.5206 .79252 m .52342 .79119 L .52208 .79248 L F
.919 .653 .518 r
.60832 .68068 m .60698 .68278 L .60693 .68054 L F
.60832 .68068 m .60866 .68386 L .60698 .68278 L F
.029 0 0 r
.27828 .6391 m .27672 .64005 L .27509 .64258 L F
.778 .574 .624 r
.62587 .67282 m .62257 .67007 L .62264 .67237 L F
.811 .614 .636 r
.62591 .6749 m .62587 .67282 L .62264 .67237 L F
.637 .805 .964 r
.58996 .74618 m .59338 .74655 L .59031 .74733 L F
.789 .684 .749 r
.29679 .73568 m .29823 .73859 L .29511 .73819 L F
.29699 .73539 m .29511 .73819 L .29678 .73551 L F
.493 .296 .542 r
.29678 .73551 m .29511 .73819 L .29688 .738 L F
.29668 .73547 m .29688 .738 L .29547 .7349 L F
.29678 .73551 m .29679 .73567 L .29668 .73547 L F
.29679 .73567 m .29688 .738 L .29668 .73547 L F
.789 .684 .749 r
.29699 .73539 m .29816 .73841 L .29679 .73568 L F
.29816 .73841 m .29823 .73859 L .29679 .73568 L F
.339 .77 .971 r
.29511 .73819 m .29823 .73859 L .29688 .738 L F
.978 .726 .486 r
.29688 .738 m .29823 .73859 L .29699 .73539 L F
.618 .528 .73 r
.5231 .74895 m .52379 .75235 L .52609 .75201 L F
.6 .436 .631 r
.52379 .75235 m .52389 .75474 L .52609 .75201 L F
.377 .106 .37 r
.35126 .68079 m .35052 .68304 L .34862 .68345 L F
.466 .171 .379 r
.35338 .68062 m .35052 .68304 L .35126 .68079 L F
.429 0 0 r
.46283 .78469 m .4614 .78521 L .45922 .78501 L F
.46 0 0 r
.46283 .78469 m .46481 .7849 L .4614 .78521 L F
.615 .479 .673 r
.32033 .72179 m .32279 .72206 L .32214 .71958 L F
.075 0 0 r
.32033 .72179 m .32168 .7219 L .32279 .72206 L F
.32033 .72179 m .31889 .72388 L .32168 .7219 L F
.299 .379 .778 r
.41289 .77073 m .41451 .77404 L .41565 .77292 L F
.266 .327 .74 r
.41451 .77404 m .41632 .77569 L .41565 .77292 L F
.992 .874 .604 r
.73444 .63192 m .73443 .62759 L .73298 .63056 L F
.686 .559 .705 r
.30124 .71373 m .30392 .71266 L .30082 .71155 L F
.674 .79 .936 r
.40965 .76802 m .41319 .76857 L .41261 .76622 L F
.516 .393 .651 r
.41319 .76857 m .41494 .76575 L .41261 .76622 L F
.41319 .76857 m .41518 .76826 L .41494 .76575 L F
.641 .574 .764 r
.41289 .77073 m .41518 .76826 L .41319 .76857 L F
.336 0 0 r
.476 .78486 m .47937 .78531 L .478 .78535 L F
.538 0 0 r
.478 .78535 m .47937 .78531 L .48156 .78656 L F
.428 .648 .95 r
.26241 .59 m .26364 .59003 L .26307 .59074 L F
.373 .633 .955 r
.2643 .59004 m .26307 .59074 L .26364 .59003 L F
.634 .664 .862 r
.32553 .73487 m .32636 .73656 L .32845 .73569 L F
.314 .545 .914 r
.70902 .72424 m .71004 .72305 L .70723 .72176 L F
.70902 .72424 m .71078 .72446 L .71004 .72305 L F
0 0 0 r
.55423 .68331 m .55562 .68306 L .55635 .68274 L F
.55423 .68331 m .5535 .68385 L .55562 .68306 L F
.911 .657 .54 r
.53102 .74076 m .53275 .74133 L .53165 .73876 L F
.987 .826 .598 r
.53112 .74321 m .53275 .74133 L .53102 .74076 L F
.53112 .74321 m .53214 .74437 L .53275 .74133 L F
.581 .433 .645 r
.31033 .70296 m .31234 .70281 L .31228 .70012 L F
.498 .343 .602 r
.31066 .70578 m .31234 .70281 L .31033 .70296 L F
.255 0 .205 r
.39317 .70311 m .39171 .70516 L .39044 .70543 L F
.419 .085 .291 r
.39179 .70737 m .39044 .70543 L .39171 .70516 L F
.39179 .70737 m .38968 .70785 L .39044 .70543 L F
.348 .438 .812 r
.56481 .73838 m .56437 .74084 L .56343 .73816 L F
.56481 .73838 m .56602 .74163 L .56437 .74084 L F
.609 .183 .209 r
.52193 .7085 m .52431 .70993 L .52578 .70823 L F
.73 .334 .299 r
.52431 .70993 m .5277 .71041 L .52578 .70823 L F
.475 .804 1 r
.37637 .64773 m .37565 .64899 L .37407 .64811 L F
.37637 .64773 m .37783 .64869 L .37565 .64899 L F
.391 .074 .304 r
.39447 .70418 m .39317 .70311 L .39517 .70254 L F
.39447 .70418 m .39171 .70516 L .39317 .70311 L F
.411 .176 .444 r
.32049 .67512 m .32094 .67288 L .31864 .6756 L F
.417 .181 .446 r
.32279 .67233 m .32094 .67288 L .32049 .67512 L F
.493 .321 .576 r
.59195 .7273 m .59398 .72462 L .59182 .72493 L F
.859 .847 .831 r
.6846 .60384 m .68815 .60196 L .68657 .60102 L F
.772 .792 .869 r
.68657 .60102 m .68815 .60196 L .69006 .60075 L F
.633 .642 .841 r
.35599 .70527 m .35383 .70588 L .35227 .70315 L F
.724 .725 .851 r
.72389 .6101 m .72592 .60933 L .72517 .60657 L F
.766 .676 .764 r
.46206 .75729 m .45881 .75786 L .46123 .75515 L F
.642 .287 .354 r
.46206 .75729 m .46092 .75957 L .45881 .75786 L F
0 .075 .633 r
.46123 .75515 m .46243 .75672 L .46206 .75729 L F
0 0 0 r
.46243 .75672 m .46092 .75957 L .46206 .75729 L F
.435 .083 .267 r
.36164 .67592 m .36083 .6773 L .35873 .67774 L F
.331 .01 .26 r
.36344 .67515 m .36083 .6773 L .36164 .67592 L F
.899 .535 .34 r
.60545 .67794 m .60391 .67749 L .60332 .67554 L F
.843 .466 .337 r
.60545 .67794 m .60518 .68028 L .60391 .67749 L F
.60545 .67794 m .60693 .68054 L .60518 .68028 L F
.457 .248 .507 r
.38795 .69188 m .3896 .69398 L .38984 .69144 L F
.38795 .69188 m .38765 .69459 L .3896 .69398 L F
.503 .34 .593 r
.31864 .6756 m .31866 .67797 L .32063 .67753 L F
.472 .338 .617 r
.31864 .6756 m .32063 .67753 L .32049 .67512 L F
.159 .206 .662 r
.40069 .67273 m .40129 .67585 L .40243 .67467 L F
.295 .423 .821 r
.40129 .67585 m .40379 .67773 L .40243 .67467 L F
.521 .435 .699 r
.40129 .67585 m .40173 .67836 L .40379 .67773 L F
.749 .626 .723 r
.54053 .73849 m .54177 .74135 L .53939 .74006 L F
.82 .47 .395 r
.54177 .74135 m .54061 .74248 L .53939 .74006 L F
.697 .602 .746 r
.54401 .7412 m .54177 .74135 L .54053 .73849 L F
.74 .893 .499 r
.54401 .7412 m .54061 .74248 L .54177 .74135 L F
.217 .684 .943 r
.43665 .78746 m .43347 .78684 L .43478 .78748 L F
.614 .573 .784 r
.53248 .71603 m .53011 .71657 L .52927 .7133 L F
.744 .619 .72 r
.49565 .74382 m .4968 .74672 L .49344 .74649 L F
.443 .315 .611 r
.4944 .74842 m .49344 .74649 L .4968 .74672 L F
.595 .437 .637 r
.49901 .74401 m .4968 .74672 L .49565 .74382 L F
.49901 .74401 m .49915 .74645 L .4968 .74672 L F
.079 0 0 r
.49841 .7467 m .4968 .74672 L .49915 .74645 L F
.49841 .7467 m .4944 .74842 L .4968 .74672 L F
.21 .728 .704 r
.73712 .60804 m .73779 .60789 L .73722 .60803 L F
.967 .808 .381 r
.74014 .60895 m .73779 .60789 L .73959 .60665 L F
0 .035 .605 r
.70362 .59836 m .70509 .60163 L .70506 .59998 L F
0 0 .17 r
.70506 .59998 m .70509 .60163 L .7054 .60364 L F
.842 .59 .558 r
.48395 .74406 m .48305 .74648 L .48144 .74366 L F
.48395 .74406 m .48404 .74702 L .48296 .7467 L F
.536 .401 .643 r
.48381 .74676 m .4871 .74603 L .48281 .74564 L F
.48404 .74702 m .48429 .74694 L .48381 .74676 L F
.48429 .74694 m .4871 .74603 L .48381 .74676 L F
.842 .59 .558 r
.48305 .74648 m .48296 .7467 L .48281 .7464 L F
.48305 .74648 m .48281 .7464 L .48144 .74366 L F
.068 0 0 r
.28288 .6542 m .28246 .65361 L .28453 .65333 L F
.28288 .6542 m .28079 .65482 L .28246 .65361 L F
.276 0 .07 r
.33715 .65596 m .33384 .65842 L .33606 .65819 L F
.472 .133 .311 r
.33606 .65819 m .33929 .65552 L .33715 .65596 L F
.911 .657 .54 r
.53102 .74076 m .53165 .73876 L .53073 .73805 L F
.924 .803 .708 r
.60273 .67232 m .60416 .67318 L .60332 .67554 L F
.536 .126 .21 r
.46022 .77691 m .46221 .77794 L .46366 .77608 L F
.587 .143 .162 r
.46221 .77794 m .46583 .7769 L .46366 .77608 L F
.294 .448 .845 r
.35119 .70186 m .35034 .7033 L .34884 .70062 L F
.479 .689 .96 r
.35119 .70186 m .35227 .70315 L .35034 .7033 L F
.453 .877 .775 r
.59761 .72533 m .59413 .72696 L .59496 .72676 L F
.632 .528 .718 r
.59515 .72868 m .59195 .7273 L .59413 .72696 L F
0 0 0 r
.5949 .72794 m .59761 .72533 L .59413 .72696 L F
.639 .628 .823 r
.59538 .72855 m .59515 .72868 L .59413 .72696 L F
0 0 0 r
.59549 .72858 m .59761 .72533 L .59449 .72832 L F
.639 .628 .823 r
.5965 .72792 m .59561 .72842 L .59608 .72775 L F
.675 .739 .898 r
.59538 .72855 m .59547 .7286 L .59515 .72868 L F
.59547 .7286 m .59875 .73037 L .59535 .72878 L F
.59547 .7286 m .59535 .72878 L .59515 .72868 L F
.5965 .72792 m .59761 .72913 L .59549 .72858 L F
.59561 .72842 m .59549 .72858 L .59538 .72855 L F
.5965 .72792 m .59549 .72858 L .59561 .72842 L F
.59761 .72913 m .59875 .73037 L .59547 .7286 L F
.59549 .72858 m .59547 .7286 L .59538 .72855 L F
.59761 .72913 m .59547 .7286 L .59549 .72858 L F
.639 .628 .823 r
.5965 .72792 m .59608 .72775 L .59761 .72533 L F
0 0 0 r
.59549 .72858 m .5961 .72772 L .59761 .72533 L F
.639 .628 .823 r
.59608 .72775 m .59413 .72696 L .59761 .72533 L F
0 0 0 r
.5961 .72772 m .59695 .72653 L .59761 .72533 L F
.59545 .72864 m .59561 .72842 L .59549 .72858 L F
.59561 .72842 m .59695 .72653 L .59549 .72858 L F
.839 .457 .325 r
.59875 .73037 m .59776 .73199 L .5953 .72888 L F
0 0 0 r
.59452 .72842 m .59549 .72858 L .59449 .72832 L F
.471 .267 .521 r
.59515 .72868 m .59457 .72948 L .59241 .72958 L F
.604 .561 .779 r
.59457 .72948 m .59483 .7296 L .59479 .72947 L F
.59241 .72958 m .59432 .7296 L .59457 .72948 L F
.59432 .7296 m .59483 .7296 L .59457 .72948 L F
.471 .267 .521 r
.59445 .72964 m .59485 .73217 L .59222 .73269 L F
.59459 .72968 m .59485 .73217 L .59445 .72964 L F
.761 .482 .51 r
.59445 .72964 m .59432 .7296 L .59241 .72958 L F
.471 .267 .521 r
.59457 .72948 m .59445 .72964 L .59241 .72958 L F
.59445 .72964 m .59222 .73269 L .59241 .72958 L F
.761 .482 .51 r
.59464 .7297 m .59445 .72964 L .59241 .72958 L F
.709 .523 .635 r
.59241 .72958 m .59222 .73269 L .58975 .73258 L F
.761 .482 .51 r
.59114 .73144 m .59464 .7297 L .59241 .72958 L F
.59464 .7297 m .59483 .7296 L .59432 .7296 L F
.471 .267 .521 r
.59457 .72948 m .59459 .72968 L .59445 .72964 L F
0 0 0 r
.59483 .7296 m .5953 .72888 L .59519 .72881 L F
.471 .267 .521 r
.59515 .72868 m .59513 .7289 L .59457 .72948 L F
.59513 .7289 m .59477 .72938 L .59457 .72948 L F
0 0 0 r
.59477 .72938 m .59519 .72881 L .59452 .72842 L F
.59483 .7296 m .59519 .72881 L .59477 .72938 L F
.471 .267 .521 r
.59513 .7289 m .5951 .72923 L .59477 .72938 L F
.761 .482 .51 r
.59464 .7297 m .59485 .73217 L .59483 .7296 L F
.471 .267 .521 r
.59462 .72946 m .59485 .73217 L .59457 .72948 L F
.761 .482 .51 r
.59114 .73144 m .59485 .73217 L .59464 .7297 L F
.471 .267 .521 r
.59482 .72966 m .59485 .73217 L .59466 .72992 L F
.761 .605 .036 r
.59483 .7296 m .59485 .73217 L .59482 .72965 L F
.471 .267 .521 r
.5951 .72923 m .59485 .73217 L .59482 .72966 L F
.761 .605 .036 r
.59482 .72965 m .59485 .73217 L .59469 .73065 L F
.721 .482 .564 r
.59776 .73199 m .59485 .73217 L .5951 .72918 L F
.59529 .72886 m .5951 .72918 L .59515 .72868 L F
0 0 0 r
.59483 .7296 m .59512 .72918 L .5953 .72888 L F
.721 .482 .564 r
.59776 .73199 m .59511 .72919 L .5953 .72888 L F
0 0 0 r
.59512 .72918 m .59523 .72902 L .5953 .72888 L F
.59512 .72918 m .5953 .72888 L .5953 .72888 L F
.721 .482 .564 r
.5953 .72888 m .5951 .72918 L .59529 .72886 L F
.59511 .72919 m .5951 .72918 L .5953 .72888 L F
.761 .605 .036 r
.5949 .72954 m .59469 .73065 L .5956 .72897 L F
.471 .267 .521 r
.5951 .72923 m .59466 .72992 L .59487 .72956 L F
0 0 0 r
.59483 .7296 m .59487 .72956 L .59508 .72924 L F
.471 .267 .521 r
.59508 .72923 m .59487 .72956 L .59507 .72924 L F
.5951 .72923 m .59487 .72956 L .59508 .72923 L F
.839 .457 .325 r
.59875 .73037 m .5953 .72888 L .59535 .72878 L F
0 0 0 r
.59508 .72924 m .5956 .72897 L .59682 .72677 L F
.59487 .72956 m .5956 .72897 L .59508 .72924 L F
.761 .605 .036 r
.59487 .72956 m .59487 .7296 L .5949 .72954 L F
.59487 .7296 m .59469 .73065 L .5949 .72954 L F
.59483 .7296 m .59482 .72965 L .59487 .72956 L F
.59482 .72965 m .59469 .73065 L .59487 .72956 L F
.471 .267 .521 r
.59507 .72924 m .59466 .72992 L .59462 .72946 L F
.632 .528 .718 r
.59515 .72868 m .59241 .72958 L .59195 .7273 L F
.604 .561 .779 r
.59241 .72958 m .59479 .72947 L .59413 .72696 L F
.839 .457 .325 r
.59535 .72878 m .5953 .72888 L .59515 .72868 L F
.5953 .72888 m .5953 .72887 L .59515 .72868 L F
0 0 0 r
.5953 .72888 m .59549 .72858 L .59452 .72842 L F
.839 .457 .325 r
.5953 .72888 m .5953 .72888 L .5953 .72887 L F
0 0 0 r
.5953 .72888 m .59622 .72759 L .59545 .72864 L F
.59523 .72902 m .59622 .72759 L .5953 .72888 L F
.59622 .72759 m .59695 .72653 L .59561 .72842 L F
.59622 .72759 m .59561 .72842 L .59545 .72864 L F
.59622 .72759 m .59682 .72677 L .59695 .72653 L F
.59483 .7296 m .59682 .72677 L .59622 .72759 L F
.639 .628 .823 r
.59608 .72775 m .59538 .72855 L .59413 .72696 L F
.59561 .72842 m .59538 .72855 L .59608 .72775 L F
0 0 0 r
.59449 .72832 m .5949 .72794 L .59413 .72696 L F
.903 .888 .465 r
.59875 .73037 m .59785 .73273 L .59776 .73199 L F
.232 .577 .943 r
.26931 .59347 m .26572 .59148 L .26806 .59175 L F
.374 .593 .93 r
.26987 .59192 m .26931 .59347 L .26806 .59175 L F
.401 .623 .943 r
.26987 .59192 m .27132 .59363 L .26931 .59347 L F
.207 .038 .419 r
.61435 .72467 m .6142 .72728 L .6129 .72733 L F
.157 .157 .607 r
.61441 .72946 m .6129 .72733 L .6142 .72728 L F
.476 .367 .651 r
.41467 .7634 m .41633 .76007 L .4141 .76037 L F
.41467 .7634 m .41682 .76286 L .41633 .76007 L F
.568 .466 .698 r
.41494 .76575 m .41682 .76286 L .41467 .7634 L F
.551 .332 .535 r
.34862 .68345 m .34854 .68693 L .34616 .68693 L F
.529 .314 .532 r
.35096 .68614 m .34862 .68345 L .35052 .68304 L F
.35096 .68614 m .34854 .68693 L .34862 .68345 L F
.284 0 0 r
.68989 .58584 m .68638 .58698 L .68878 .58617 L F
.217 .729 .685 r
.69223 .58512 m .68989 .58584 L .68878 .58617 L F
.435 .163 .401 r
.31219 .62053 m .31472 .6182 L .31412 .62013 L F
.33 .066 .354 r
.31412 .62013 m .31472 .6182 L .31649 .61747 L F
.487 .524 .821 r
.41898 .65856 m .41832 .66186 L .41676 .65907 L F
.41898 .65856 m .42027 .66186 L .41832 .66186 L F
.399 .811 .611 r
.56399 .68444 m .56204 .68567 L .56156 .686 L F
0 .246 .76 r
.56204 .68567 m .56419 .68822 L .56156 .686 L F
.523 .798 .996 r
.27898 .59401 m .27828 .59536 L .27689 .59443 L F
.27898 .59401 m .28041 .59493 L .27828 .59536 L F
.482 .166 .354 r
.5262 .74113 m .52845 .74082 L .5292 .73829 L F
.754 .435 .445 r
.5292 .73829 m .53102 .74076 L .53073 .73805 L F
.5292 .73829 m .52845 .74082 L .53102 .74076 L F
.704 .623 .765 r
.34565 .69733 m .34689 .70081 L .34366 .69987 L F
.557 .551 .804 r
.34759 .69715 m .34689 .70081 L .34565 .69733 L F
.34759 .69715 m .34884 .70062 L .34689 .70081 L F
.191 0 .015 r
.57163 .67229 m .57347 .67217 L .57339 .67183 L F
.57163 .67229 m .57141 .67293 L .57347 .67217 L F
0 .183 .713 r
.56602 .74163 m .56775 .74331 L .56714 .74412 L F
0 .009 .551 r
.56775 .74331 m .56761 .74641 L .56714 .74412 L F
.585 .543 .773 r
.39633 .68083 m .39901 .68079 L .39795 .67797 L F
.482 .275 .522 r
.39633 .68083 m .39849 .68291 L .39901 .68079 L F
.39633 .68083 m .39647 .68339 L .39849 .68291 L F
0 .286 .741 r
.56324 .71421 m .56508 .71499 L .56239 .71325 L F
.56324 .71421 m .56596 .71585 L .56508 .71499 L F
.138 0 .121 r
.28112 .63452 m .27856 .63711 L .28 .63634 L F
.257 0 .214 r
.28 .63634 m .28282 .6338 L .28112 .63452 L F
.873 .612 .541 r
.56399 .68444 m .56444 .68712 L .56204 .68567 L F
.731 .597 .707 r
.51369 .7306 m .51352 .73305 L .51118 .73025 L F
.63 .342 .462 r
.44827 .73768 m .45098 .73587 L .44873 .73615 L F
.634 .616 .815 r
.4222 .78499 m .42557 .78735 L .42396 .78516 L F
0 0 .078 r
.30392 .71266 m .30406 .7124 L .3049 .70777 L F
.427 .281 .578 r
.3049 .70777 m .30679 .70876 L .30769 .70749 L F
.3049 .70777 m .30406 .7124 L .30679 .70876 L F
0 0 0 r
.5231 .74895 m .51857 .75071 L .51901 .74947 L F
.5231 .74895 m .52024 .75035 L .51889 .75064 L F
.51904 .75052 m .51889 .75064 L .51857 .75071 L F
.5231 .74895 m .51889 .75064 L .51904 .75052 L F
.52055 .74887 m .51857 .75071 L .52024 .75035 L F
.5207 .74812 m .52015 .7488 L .52055 .74887 L F
.52015 .7488 m .51857 .75071 L .52055 .74887 L F
.5207 .74812 m .51853 .75099 L .51857 .75071 L F
.688 .91 .568 r
.519 .75034 m .51889 .75019 L .51858 .75087 L F
.5207 .74812 m .51889 .75019 L .519 .75034 L F
.5207 .74812 m .51858 .75087 L .51867 .75081 L F
.451 .524 .842 r
.5231 .74895 m .52492 .74888 L .52362 .74581 L F
.5231 .74895 m .52362 .74581 L .5239 .74785 L F
.654 .96 .766 r
.5239 .74785 m .52313 .74838 L .5231 .74895 L F
.52313 .74838 m .52024 .75035 L .52275 .74912 L F
.52313 .74838 m .52275 .74912 L .5231 .74895 L F
.814 .472 .409 r
.52029 .74582 m .5239 .74785 L .52362 .74581 L F
.195 0 0 r
.52393 .74682 m .52321 .74748 L .52394 .74648 L F
.618 .528 .73 r
.5231 .74895 m .52609 .75201 L .52492 .74888 L F
.814 .472 .409 r
.52029 .74582 m .5207 .74812 L .52236 .74798 L F
.52304 .74737 m .52236 .74798 L .5239 .74785 L F
.52029 .74582 m .52236 .74798 L .52304 .74737 L F
.876 .785 .757 r
.52265 .74796 m .52024 .75035 L .5239 .74785 L F
.195 0 0 r
.52387 .74945 m .52178 .75005 L .52315 .7476 L F
.52323 .74754 m .52315 .7476 L .52321 .74748 L F
.52387 .74945 m .52315 .7476 L .52323 .74754 L F
.876 .785 .757 r
.52236 .74798 m .52188 .74852 L .52265 .74796 L F
.52188 .74852 m .52024 .75035 L .52265 .74796 L F
.5207 .74812 m .52055 .74887 L .52236 .74798 L F
.52055 .74887 m .52024 .75035 L .52236 .74798 L F
.44 0 .077 r
.5229 .74772 m .52227 .74917 L .52124 .74899 L F
.52321 .74748 m .52315 .7476 L .5229 .74772 L F
.52315 .7476 m .52227 .74917 L .5229 .74772 L F
.52224 .74809 m .52124 .74899 L .5209 .74893 L F
.52321 .74748 m .52124 .74899 L .52224 .74809 L F
.195 0 0 r
.52387 .74945 m .52336 .74793 L .52393 .74682 L F
.52336 .74793 m .52321 .74748 L .52393 .74682 L F
.154 0 0 r
.52178 .75005 m .51946 .7504 L .51889 .75019 L F
0 .412 .808 r
.51946 .7504 m .51878 .75004 L .51889 .75019 L F
.267 0 0 r
.51857 .75071 m .51646 .74847 L .51901 .74947 L F
.51857 .75071 m .51589 .75118 L .51646 .74847 L F
.51857 .75071 m .51853 .75099 L .51589 .75118 L F
0 .218 .739 r
.51853 .75099 m .51889 .75019 L .51657 .74765 L F
0 0 0 r
.51657 .74637 m .51648 .74808 L .51657 .74765 L F
.51648 .74808 m .51646 .74847 L .51657 .74765 L F
.653 .438 .579 r
.51812 .74538 m .52029 .74582 L .52051 .74326 L F
.653 .36 .463 r
.51812 .74538 m .5207 .74812 L .52029 .74582 L F
.068 .249 .741 r
.51893 .74467 m .5207 .74812 L .51812 .74538 L F
0 0 0 r
.51812 .74538 m .51657 .74765 L .51893 .74467 L F
.037 0 .115 r
.51893 .74467 m .51657 .74765 L .51759 .74578 L F
.86 .412 .032 r
.51889 .75019 m .51664 .74727 L .51657 .74765 L F
.979 .917 .638 r
.51759 .74578 m .51657 .74765 L .51614 .74662 L F
.86 .412 .032 r
.51664 .74727 m .51614 .74662 L .51657 .74765 L F
.51889 .75019 m .51756 .74941 L .51614 .74662 L F
0 .412 .808 r
.51878 .75004 m .51756 .74941 L .51889 .75019 L F
.44 0 .077 r
.5209 .74893 m .52178 .75005 L .51889 .75019 L F
.52227 .74917 m .52178 .75005 L .5209 .74893 L F
.688 .91 .568 r
.51867 .75081 m .51858 .75087 L .51853 .75099 L F
.389 .805 .607 r
.59594 .7604 m .59769 .75927 L .59639 .76038 L F
.519 .307 .532 r
.535 .73174 m .53277 .73026 L .536 .73025 L F
.619 .087 0 r
.536 .73025 m .5369 .73155 L .535 .73174 L F
.536 .73025 m .53858 .73276 L .5369 .73155 L F
.886 .563 .431 r
.51118 .73025 m .51352 .73305 L .51095 .73136 L F
.841 .772 .785 r
.51352 .73305 m .50979 .73524 L .51095 .73136 L F
.51352 .73305 m .51149 .73354 L .50979 .73524 L F
.806 .579 .594 r
.51352 .73305 m .51343 .73571 L .51149 .73354 L F
.739 .521 .598 r
.51688 .73563 m .51343 .73571 L .51352 .73305 L F
.661 .414 .537 r
.47654 .75044 m .48036 .74957 L .47662 .74907 L F
.47654 .75044 m .48002 .75178 L .48036 .74957 L F
.417 .198 .471 r
.48222 .74901 m .48002 .75178 L .48036 .74957 L F
.48222 .74901 m .48002 .75178 L .48036 .74957 L F
.561 .101 .117 r
.47387 .78472 m .47269 .78548 L .47036 .785 L F
.406 0 0 r
.47387 .78472 m .47477 .78596 L .47269 .78548 L F
.47387 .78472 m .476 .78486 L .47477 .78596 L F
.56 .156 .234 r
.46395 .7322 m .46624 .73236 L .46747 .73054 L F
.488 .081 .195 r
.46624 .73236 m .46963 .73062 L .46747 .73054 L F
.768 .789 .871 r
.47147 .74583 m .47106 .74675 L .47298 .7452 L F
.635 .383 .519 r
.47202 .74814 m .47106 .74675 L .47147 .74583 L F
.47202 .74814 m .46953 .74629 L .47106 .74675 L F
.326 .306 .683 r
.53529 .74538 m .53388 .74757 L .53291 .74575 L F
0 0 0 r
.73087 .71048 m .72882 .71159 L .72612 .71363 L F
.598 .133 .121 r
.52419 .78691 m .52211 .78552 L .52078 .78693 L F
.503 .286 .517 r
.52359 .76601 m .52584 .76585 L .52586 .76308 L F
.489 .29 .536 r
.52586 .76308 m .5282 .76277 L .52809 .76027 L F
.585 .4 .597 r
.52584 .76585 m .5282 .76277 L .52586 .76308 L F
.641 .574 .764 r
.41289 .77073 m .41607 .77116 L .41518 .76826 L F
.299 .379 .778 r
.41289 .77073 m .41565 .77292 L .41607 .77116 L F
.697 .602 .746 r
.54401 .7412 m .54053 .73849 L .54304 .73914 L F
.74 .893 .499 r
.54401 .7412 m .54267 .74294 L .54061 .74248 L F
.54361 .74186 m .54209 .74435 L .54267 .74294 L F
.435 .169 .41 r
.54209 .74435 m .54333 .74502 L .54267 .74294 L F
.08 .255 .743 r
.54267 .74294 m .54333 .74502 L .54406 .74392 L F
.504 0 0 r
.54406 .74392 m .54179 .74396 L .54267 .74294 L F
.54179 .74396 m .54162 .74396 L .54267 .74294 L F
.74 .893 .499 r
.54401 .7412 m .54361 .74186 L .54267 .74294 L F
.599 .591 .815 r
.54509 .73762 m .54401 .7412 L .54304 .73914 L F
.54509 .73762 m .5463 .74093 L .54401 .7412 L F
.562 .451 .684 r
.28848 .61576 m .29081 .61737 L .29048 .61515 L F
.567 .425 .648 r
.42173 .74375 m .42437 .74564 L .42401 .74373 L F
.42173 .74375 m .42219 .7464 L .42437 .74564 L F
.212 .284 .721 r
.56825 .72353 m .56944 .72766 L .57076 .72633 L F
.339 .49 .863 r
.56944 .72766 m .57115 .72785 L .57076 .72633 L F
0 .286 .773 r
.56004 .71165 m .56169 .71221 L .55893 .71077 L F
.56004 .71165 m .56239 .71325 L .56169 .71221 L F
.587 .44 .648 r
.4141 .76037 m .41633 .76007 L .41616 .75759 L F
.887 .71 .196 r
.62464 .69471 m .62431 .69637 L .62448 .69668 L F
0 0 0 r
.62569 .69088 m .62487 .69416 L .62464 .69471 L F
.62487 .69416 m .62431 .69637 L .62464 .69471 L F
.181 .715 .808 r
.37783 .64869 m .37992 .64841 L .38104 .64843 L F
.421 .861 .916 r
.37992 .64841 m .38312 .64788 L .38104 .64843 L F
.789 .62 .671 r
.62257 .67007 m .61941 .66708 L .61953 .66953 L F
.796 .544 .558 r
.61939 .67196 m .62257 .67007 L .61953 .66953 L F
.61939 .67196 m .62264 .67237 L .62257 .67007 L F
.637 .524 .709 r
.34565 .69733 m .34266 .69434 L .34465 .69391 L F
.34565 .69733 m .34371 .69802 L .34266 .69434 L F
.901 .872 .799 r
.57244 .67937 m .57223 .68254 L .57381 .68043 L F
.272 .009 .32 r
.57223 .68254 m .57284 .68286 L .57381 .68043 L F
.405 0 0 r
.57559 .6804 m .57244 .67937 L .57381 .68043 L F
.418 .149 .396 r
.57381 .68043 m .57284 .68286 L .57559 .6804 L F
.338 .113 .419 r
.31 .62355 m .31219 .62053 L .31187 .62304 L F
.381 .274 .605 r
.31172 .62525 m .31 .62355 L .31187 .62304 L F
.31172 .62525 m .31024 .626 L .31 .62355 L F
.148 .456 .885 r
.73885 .71275 m .73794 .71352 L .73612 .71148 L F
.11 .389 .846 r
.73885 .71275 m .74099 .71555 L .73794 .71352 L F
.333 .743 .98 r
.29915 .59628 m .29847 .59714 L .29667 .59625 L F
.29915 .59628 m .3009 .5971 L .29847 .59714 L F
.96 .643 .379 r
.50493 .74691 m .50489 .74831 L .50339 .74806 L F
0 .201 .722 r
.50493 .74691 m .5048 .74584 L .50319 .74437 L F
.798 .868 .9 r
.50339 .74806 m .5048 .74584 L .50493 .74691 L F
.50339 .74806 m .50555 .74723 L .5048 .74584 L F
.716 .629 .758 r
.50187 .74501 m .50339 .74806 L .50033 .74625 L F
.783 .309 .107 r
.50339 .74806 m .502 .748 L .50033 .74625 L F
.611 .581 .795 r
.50555 .74723 m .50339 .74806 L .50187 .74501 L F
.591 .197 .263 r
.50555 .74723 m .50245 .7479 L .50339 .74806 L F
.50245 .7479 m .502 .748 L .50339 .74806 L F
.96 .643 .379 r
.50489 .74831 m .50486 .74904 L .50339 .74806 L F
.48 0 .028 r
.52208 .79248 m .52342 .79119 L .52603 .79216 L F
.275 .779 .806 r
.72267 .6199 m .72281 .62009 L .72198 .61947 L F
.72267 .6199 m .72564 .61939 L .72281 .62009 L F
0 0 .546 r
.72281 .62009 m .72435 .62159 L .72198 .61947 L F
.72281 .62009 m .72524 .62289 L .72435 .62159 L F
.974 .733 .509 r
.3035 .72678 m .30333 .72956 L .30459 .73011 L F
.789 .734 .802 r
.30155 .73055 m .30459 .73011 L .30333 .72956 L F
.603 .585 .806 r
.30459 .73011 m .30585 .72626 L .3035 .72678 L F
.30459 .73011 m .30708 .73105 L .30585 .72626 L F
.328 0 .061 r
.36717 .71871 m .3637 .72093 L .36514 .7191 L F
.148 0 0 r
.44468 .78576 m .44075 .78638 L .44256 .78597 L F
0 0 0 r
.59496 .72676 m .59413 .72696 L .59195 .7273 L F
.226 0 .029 r
.58077 .66851 m .58364 .66678 L .58164 .66684 L F
.438 .133 .349 r
.29001 .65039 m .29263 .6483 L .29195 .64993 L F
.393 .068 .292 r
.29263 .6483 m .29374 .64932 L .29195 .64993 L F
.29263 .6483 m .29465 .6478 L .29374 .64932 L F
.492 .356 .624 r
.31692 .68082 m .31885 .68036 L .31866 .67797 L F
.516 .374 .626 r
.31692 .68082 m .31901 .68298 L .31885 .68036 L F
.31692 .68082 m .31681 .68368 L .31901 .68298 L F
.772 .792 .869 r
.68657 .60102 m .69006 .60075 L .68908 .5996 L F
.735 .9 .953 r
.68908 .5996 m .69006 .60075 L .6925 .5989 L F
.268 .714 .96 r
.30801 .59825 m .30749 .59893 L .30597 .59822 L F
.30801 .59825 m .30952 .59894 L .30749 .59893 L F
.481 .324 .59 r
.32687 .66201 m .32885 .66368 L .32894 .66122 L F
.32687 .66201 m .32694 .66447 L .32885 .66368 L F
.784 .728 .801 r
.30265 .71958 m .29928 .71935 L .30166 .71733 L F
.816 .741 .781 r
.3046 .71656 m .30265 .71958 L .30166 .71733 L F
.311 0 .189 r
.39901 .68079 m .40173 .67836 L .39795 .67797 L F
.39901 .68079 m .40116 .67993 L .40173 .67836 L F
.668 .455 .586 r
.40116 .67993 m .40379 .67773 L .40173 .67836 L F
.587 .523 .751 r
.47654 .75044 m .4783 .75296 L .48002 .75178 L F
.207 .727 .861 r
.44997 .7862 m .44643 .78625 L .44812 .78628 L F
.754 .505 .556 r
.47577 .77346 m .47846 .77364 L .47924 .77137 L F
0 0 0 r
.59356 .76289 m .59422 .76277 L .59157 .76339 L F
.399 .006 .173 r
.33929 .65552 m .34143 .65518 L .34222 .65381 L F
.35 0 .147 r
.34222 .65381 m .34344 .65471 L .34454 .65337 L F
.34222 .65381 m .34143 .65518 L .34344 .65471 L F
.795 .766 .827 r
.72517 .60657 m .72592 .60933 L .72821 .60675 L F
.395 .584 .917 r
.39737 .66989 m .39818 .66843 L .3953 .66746 L F
.39737 .66989 m .39904 .66973 L .39818 .66843 L F
.724 .609 .728 r
.54257 .73581 m .54304 .73914 L .54053 .73849 L F
.461 .419 .725 r
.54509 .73762 m .54304 .73914 L .54257 .73581 L F
.535 .34 .563 r
.306 .73576 m .30586 .7382 L .30826 .73542 L F
.56 .178 .275 r
.44066 .73854 m .4425 .73998 L .44303 .73861 L F
.655 .622 .805 r
.71933 .60413 m .7237 .60722 L .72233 .60381 L F
.405 .45 .794 r
.72233 .60381 m .7237 .60722 L .72517 .60657 L F
.404 .019 .192 r
.59125 .67011 m .59031 .67219 L .58797 .67258 L F
.315 0 .152 r
.5924 .67153 m .59125 .67011 L .59302 .66918 L F
.5924 .67153 m .59031 .67219 L .59125 .67011 L F
.096 .406 .858 r
.57302 .73025 m .57353 .72935 L .57115 .72785 L F
0 .098 .647 r
.57302 .73025 m .57455 .73221 L .57353 .72935 L F
.474 .265 .515 r
.31219 .62053 m .31386 .62237 L .31187 .62304 L F
.31219 .62053 m .31412 .62013 L .31386 .62237 L F
.107 0 .239 r
.54209 .74435 m .53996 .74719 L .54149 .74597 L F
.417 .058 .247 r
.53834 .74846 m .54149 .74597 L .53996 .74719 L F
.574 .678 .91 r
.41274 .65484 m .41143 .65682 L .41051 .65535 L F
.41274 .65484 m .41344 .65638 L .41143 .65682 L F
0 0 .415 r
.52828 .73504 m .5286 .73064 L .53027 .73284 L F
.52828 .73504 m .52903 .73442 L .5286 .73064 L F
.598 .497 .71 r
.31194 .69766 m .31418 .69735 L .31348 .6942 L F
.598 .495 .708 r
.31194 .69766 m .31228 .70012 L .31418 .69735 L F
.8 .855 .403 r
.74646 .623 m .74564 .62494 L .74647 .62348 L F
.74647 .62348 m .74564 .62494 L .74646 .623 L F
.557 .428 .661 r
.52809 .76027 m .53043 .76008 L .52997 .75701 L F
.617 .433 .61 r
.5282 .76277 m .53043 .76008 L .52809 .76027 L F
0 0 0 r
.7073 .7193 m .70896 .71826 L .7101 .71733 L F
.043 0 .403 r
.7073 .7193 m .7088 .72051 L .70896 .71826 L F
.7073 .7193 m .70723 .72176 L .7088 .72051 L F
.635 .518 .704 r
.64899 .51828 m .64675 .52163 L .64687 .51923 L F
.454 .67 .956 r
.3994 .65243 m .39769 .65418 L .39754 .65276 L F
.3994 .65243 m .40141 .65445 L .39769 .65418 L F
.249 .289 .708 r
.56704 .69608 m .56586 .69821 L .56452 .69651 L F
.5 .296 .535 r
.67621 .59267 m .68014 .59 L .67629 .59039 L F
.705 .332 .34 r
.54856 .75154 m .54546 .75147 L .54694 .74975 L F
.038 0 0 r
.60605 .75453 m .60886 .75189 L .60735 .75334 L F
0 0 0 r
.61137 .74946 m .6103 .75117 L .60886 .75189 L F
.60886 .75189 m .6103 .75117 L .60735 .75334 L F
.563 .119 .154 r
.46697 .7862 m .46481 .7849 L .46815 .7846 L F
.558 .068 .048 r
.46815 .7846 m .46899 .78622 L .46697 .7862 L F
.46815 .7846 m .47036 .785 L .46899 .78622 L F
.507 0 0 r
.42819 .66478 m .42767 .66422 L .42581 .66415 L F
.443 .496 .819 r
.42715 .66197 m .42759 .66462 L .42581 .66415 L F
.42759 .66462 m .42761 .66473 L .42581 .66415 L F
.507 0 0 r
.42823 .66482 m .42819 .66478 L .42581 .66415 L F
.685 .672 .832 r
.43023 .66283 m .42791 .66451 L .42715 .66197 L F
.42791 .66451 m .42761 .66473 L .42751 .66416 L F
.42791 .66451 m .42751 .66416 L .42715 .66197 L F
.507 0 0 r
.42813 .66471 m .42969 .6661 L .42767 .66422 L F
.42823 .66482 m .42888 .66538 L .42813 .66471 L F
.42888 .66538 m .42969 .6661 L .42813 .66471 L F
.349 .103 .393 r
.51024 .73056 m .51007 .7328 L .5081 .73315 L F
.473 .202 .421 r
.51095 .73136 m .51007 .7328 L .51024 .73056 L F
.886 .563 .431 r
.51118 .73025 m .51095 .73136 L .51024 .73056 L F
.097 0 0 r
.38479 .66612 m .38354 .66686 L .3814 .66728 L F
.319 0 0 r
.38731 .66564 m .38354 .66686 L .38479 .66612 L F
.769 .682 .768 r
.30586 .7382 m .30948 .73849 L .30826 .73542 L F
.656 .111 0 r
.30586 .7382 m .30926 .74089 L .30948 .73849 L F
.542 .677 .926 r
.52389 .75474 m .52761 .75629 L .52626 .75411 L F
.614 .631 .845 r
.52626 .75411 m .52761 .75629 L .52933 .75549 L F
.549 .609 .865 r
.52761 .75629 m .52997 .75701 L .52933 .75549 L F
.409 .425 .766 r
.40069 .67273 m .40132 .66909 L .39904 .66973 L F
.40069 .67273 m .40227 .67208 L .40132 .66909 L F
.159 .206 .662 r
.40069 .67273 m .40243 .67467 L .40227 .67208 L F
.768 .685 .772 r
.64102 .51998 m .64188 .52213 L .63887 .52176 L F
.768 .607 .679 r
.64188 .52213 m .63842 .52425 L .63887 .52176 L F
.64188 .52213 m .64196 .5247 L .63842 .52425 L F
.674 .533 .685 r
.64416 .52199 m .64196 .5247 L .64188 .52213 L F
.644 .726 .908 r
.35835 .70454 m .35918 .70611 L .35599 .70527 L F
.336 .544 .908 r
.36 .70473 m .35918 .70611 L .35835 .70454 L F
.402 .63 .947 r
.36 .70473 m .36146 .70634 L .35918 .70611 L F
.653 .779 .941 r
.29796 .72273 m .30038 .72403 L .30139 .72272 L F
.535 .601 .867 r
.30038 .72403 m .30259 .72385 L .30139 .72272 L F
.731 .513 .596 r
.30038 .72403 m .3035 .72678 L .30259 .72385 L F
.30038 .72403 m .2999 .72786 L .3035 .72678 L F
.364 0 0 r
.56456 .69195 m .56321 .69179 L .56192 .69135 L F
.204 0 0 r
.45581 .78546 m .4523 .78609 L .45363 .78539 L F
.647 .315 .395 r
.33798 .73194 m .33468 .73263 L .33638 .73015 L F
0 0 0 r
.74145 .73088 m .74073 .73233 L .73889 .73287 L F
.74204 .73099 m .74145 .73088 L .74377 .73006 L F
.74204 .73099 m .74073 .73233 L .74145 .73088 L F
.105 .501 .905 r
.73542 .71049 m .73434 .71083 L .73331 .71013 L F
.73542 .71049 m .73612 .71148 L .73434 .71083 L F
.532 .406 .654 r
.41616 .75759 m .41805 .75482 L .4157 .75531 L F
.64 .559 .748 r
.50103 .74159 m .50145 .74433 L .49901 .74401 L F
.654 .482 .639 r
.50145 .74433 m .49915 .74645 L .49901 .74401 L F
.723 .214 0 r
.57702 .71409 m .57852 .71602 L .57915 .71603 L F
.771 .269 0 r
.57952 .71762 m .57915 .71603 L .57852 .71602 L F
.57952 .71762 m .58087 .71843 L .57915 .71603 L F
.504 .286 .516 r
.28767 .62618 m .28975 .62572 L .29005 .62349 L F
.238 .061 .427 r
.29005 .62349 m .28975 .62572 L .2914 .6225 L F
.639 .529 .714 r
.34565 .69733 m .34366 .69987 L .34371 .69802 L F
.164 0 .059 r
.50667 .73467 m .50434 .73515 L .5081 .73315 L F
.427 .381 .705 r
.51007 .7328 m .50979 .73524 L .5081 .73315 L F
.804 .413 .313 r
.50979 .73524 m .50667 .73467 L .5081 .73315 L F
.761 .653 .742 r
.74629 .60972 m .74147 .60798 L .7457 .60813 L F
.558 .181 .283 r
.74629 .60972 m .74312 .61166 L .74374 .61065 L F
.74629 .60972 m .74556 .61174 L .74312 .61166 L F
.637 .873 .986 r
.74759 .60802 m .74629 .60972 L .7457 .60813 L F
.74759 .60802 m .74894 .60892 L .74629 .60972 L F
.59 .213 .295 r
.74838 .61113 m .74556 .61174 L .74629 .60972 L F
.537 .259 .441 r
.74894 .60892 m .74838 .61113 L .74629 .60972 L F
0 .546 .78 r
.28041 .59493 m .28235 .59518 L .28394 .59554 L F
.225 .725 .908 r
.28394 .59554 m .28235 .59518 L .28593 .59543 L F
.644 .556 .741 r
.31228 .70012 m .31495 .70007 L .31418 .69735 L F
.605 .428 .615 r
.31234 .70281 m .31495 .70007 L .31228 .70012 L F
.832 .788 .81 r
.59454 .73655 m .59299 .73865 L .5919 .73844 L F
.786 .54 .564 r
.5929 .7403 m .5919 .73844 L .59299 .73865 L F
.251 .06 .414 r
.46866 .74734 m .46767 .74878 L .46641 .74913 L F
0 0 0 r
.28767 .62618 m .28547 .62893 L .28691 .62776 L F
.146 .019 .438 r
.28547 .62893 m .287 .62994 L .28691 .62776 L F
.28547 .62893 m .28531 .63124 L .287 .62994 L F
.173 .654 .927 r
.36146 .70634 m .36453 .70704 L .36264 .70718 L F
.518 .273 .482 r
.44245 .75835 m .44239 .76048 L .43963 .76043 L F
.55 .39 .617 r
.44239 .76048 m .4397 .76297 L .43963 .76043 L F
.22 0 0 r
.37555 .71458 m .37408 .71614 L .37263 .71589 L F
.2 0 0 r
.37614 .71563 m .37555 .71458 L .3777 .71397 L F
.37614 .71563 m .37408 .71614 L .37555 .71458 L F
.374 .557 .905 r
.39462 .81947 m .39609 .82169 L .39726 .82154 L F
0 0 .397 r
.57425 .73496 m .57544 .73677 L .57427 .73498 L F
0 0 0 r
.57421 .73492 m .57425 .73496 L .57455 .73221 L F
.984 .791 .389 r
.57455 .73221 m .57425 .73496 L .5738 .73425 L F
0 0 .397 r
.57425 .73496 m .57427 .73498 L .5738 .73425 L F
0 0 0 r
.57411 .73573 m .57425 .73496 L .57421 .73492 L F
0 .032 .601 r
.57411 .73573 m .57544 .73677 L .57425 .73496 L F
.57411 .73573 m .57576 .73776 L .57544 .73677 L F
.332 .248 .608 r
.57434 .73819 m .57576 .73776 L .57411 .73573 L F
0 0 .074 r
.45682 .75182 m .45498 .75462 L .45491 .75238 L F
.816 .741 .781 r
.3046 .71656 m .30166 .71733 L .30256 .71658 L F
.637 .8 .961 r
.43935 .65526 m .43586 .65491 L .438 .65418 L F
.721 .319 .286 r
.438 .65418 m .4417 .65524 L .43935 .65526 L F
.915 .959 .801 r
.4417 .65524 m .44025 .65786 L .43935 .65526 L F
.475 0 0 r
.48762 .78157 m .48466 .78061 L .486 .7814 L F
.48466 .78061 m .48367 .78028 L .486 .7814 L F
.659 .116 0 r
.486 .7814 m .48922 .78259 L .48762 .78157 L F
.761 .305 .166 r
.48812 .78364 m .48922 .78259 L .486 .7814 L F
.072 .251 .742 r
.48688 .78056 m .4876 .78235 L .486 .7814 L F
.4876 .78235 m .48812 .78364 L .486 .7814 L F
.063 .414 .863 r
.486 .7814 m .48367 .78028 L .48267 .77881 L F
.664 .185 .105 r
.49054 .78768 m .49383 .78813 L .49277 .78936 L F
.634 .15 .085 r
.49383 .78813 m .49619 .7897 L .49277 .78936 L F
0 0 0 r
.40458 .65574 m .4067 .65534 L .40812 .65502 L F
.336 0 0 r
.40812 .65502 m .4067 .65534 L .41051 .65535 L F
0 0 0 r
.73889 .73287 m .74073 .73233 L .73846 .73326 L F
.313 .489 .872 r
.73843 .59873 m .73962 .59753 L .73728 .59789 L F
.73843 .59873 m .74159 .6002 L .73962 .59753 L F
.485 .59 .884 r
.32214 .71958 m .32253 .71648 L .3208 .71658 L F
.32214 .71958 m .32381 .71907 L .32253 .71648 L F
0 0 0 r
.32279 .72206 m .32381 .71907 L .32214 .71958 L F
.668 .425 .544 r
.59398 .72462 m .59708 .72482 L .59689 .7224 L F
.312 .164 .513 r
.59689 .7224 m .59862 .72363 L .59944 .72164 L F
.59689 .7224 m .59708 .72482 L .59862 .72363 L F
.605 .161 .17 r
.49496 .78434 m .49287 .78298 L .49144 .78441 L F
.097 0 .306 r
.61307 .74639 m .61308 .74887 L .61137 .74946 L F
0 0 0 r
.61137 .74946 m .61193 .75019 L .6103 .75117 L F
.61137 .74946 m .61308 .74887 L .61193 .75019 L F
.549 .26 .43 r
.45609 .73493 m .45883 .73294 L .45644 .73326 L F
.506 0 0 r
.73159 .58411 m .73446 .58528 L .73324 .5846 L F
.843 .54 .003 r
.7098 .58665 m .71034 .58775 L .70932 .58441 L F
.7098 .58665 m .71034 .58775 L .70932 .58441 L F
.718 .289 0 r
.56681 .71909 m .56882 .72224 L .56796 .72112 L F
0 .081 .623 r
.56825 .72353 m .56796 .72112 L .56882 .72224 L F
.713 .491 .586 r
.59422 .76277 m .5911 .76397 L .59157 .76339 L F
.852 .598 .553 r
.62499 .68577 m .6271 .68727 L .6272 .68643 L F
.881 .639 .568 r
.62406 .67774 m .62406 .68011 L .62679 .6805 L F
.879 .691 .643 r
.62379 .68257 m .62679 .6805 L .62406 .68011 L F
.62379 .68257 m .62541 .68338 L .62679 .6805 L F
.508 .113 .228 r
.59345 .66079 m .59669 .65887 L .59445 .65916 L F
0 0 .319 r
.5822 .72543 m .58257 .72651 L .58148 .72704 L F
0 0 .524 r
.58254 .7278 m .58148 .72704 L .58257 .72651 L F
.58254 .7278 m .58276 .72963 L .58148 .72704 L F
.547 .857 .556 r
.54026 .78987 m .53838 .79158 L .537 .79297 L F
.238 .671 .959 r
.53904 .78898 m .54226 .78994 L .54026 .78987 L F
.989 .825 .589 r
.53904 .78898 m .54026 .78987 L .54226 .78994 L F
.53904 .78898 m .53838 .79158 L .54026 .78987 L F
.156 .149 .598 r
.57647 .74671 m .57737 .74322 L .57533 .74364 L F
.57647 .74671 m .57794 .74567 L .57737 .74322 L F
0 0 .525 r
.57647 .74671 m .57767 .74793 L .57794 .74567 L F
.57647 .74671 m .57793 .74917 L .57767 .74793 L F
.242 0 0 r
.26577 .60426 m .26642 .60501 L .26454 .60459 L F
.26577 .60426 m .26813 .60386 L .26642 .60501 L F
.463 .135 .324 r
.28691 .62776 m .28975 .62572 L .28767 .62618 L F
.744 .619 .72 r
.49565 .74382 m .49344 .74649 L .49347 .74411 L F
0 0 0 r
.50286 .71085 m .50422 .71005 L .50531 .70832 L F
.50286 .71085 m .50176 .71259 L .50422 .71005 L F
.222 .067 .448 r
.27856 .63711 m .27915 .63693 L .28 .63634 L F
.27856 .63711 m .27828 .6391 L .27915 .63693 L F
.376 .037 .258 r
.38768 .70835 m .3849 .71035 L .38572 .70879 L F
.341 .792 .951 r
.55568 .78465 m .55222 .78456 L .55352 .78517 L F
.55222 .78456 m .55568 .78465 L .55352 .78517 L F
.514 .846 .997 r
.55222 .78456 m .55352 .78517 L .55568 .78465 L F
.791 .723 .192 r
.60887 .69966 m .60938 .69603 L .60924 .69751 L F
.632 .8 .963 r
.71278 .61329 m .71402 .61119 L .71164 .61126 L F
.71278 .61329 m .71556 .61252 L .71402 .61119 L F
.812 .693 .734 r
.30867 .71707 m .30792 .71918 L .30665 .71616 L F
.327 .261 .629 r
.74385 .71848 m .74444 .72093 L .74242 .72177 L F
.352 .325 .689 r
.74444 .72093 m .7446 .72405 L .74242 .72177 L F
.858 .637 .601 r
.57391 .70753 m .57485 .70959 L .57602 .70915 L F
.979 .683 .331 r
.57589 .71295 m .57602 .70915 L .57485 .70959 L F
0 .189 .719 r
.57497 .7126 m .57589 .71295 L .57463 .71247 L F
.979 .683 .331 r
.57589 .71295 m .57702 .71409 L .57686 .71332 L F
0 .189 .719 r
.57726 .71351 m .57787 .71477 L .57589 .71295 L F
.57726 .71351 m .57589 .71295 L .57497 .7126 L F
.979 .683 .331 r
.57589 .71295 m .57686 .71332 L .57602 .70915 L F
0 0 0 r
.5645 .67838 m .56568 .67741 L .56679 .67574 L F
.56679 .67574 m .56748 .67632 L .56868 .67485 L F
.56679 .67574 m .56568 .67741 L .56748 .67632 L F
.525 .041 .049 r
.5345 .73583 m .5325 .73735 L .53142 .73684 L F
.553 .57 .826 r
.53621 .73506 m .5345 .73583 L .5328 .73225 L F
.392 .186 .476 r
.30408 .63459 m .30609 .63174 L .30543 .63372 L F
.163 0 .309 r
.30349 .63662 m .30408 .63459 L .30543 .63372 L F
.606 .626 .845 r
.41858 .78278 m .4222 .78499 L .42054 .78251 L F
.37 .446 .808 r
.4222 .78499 m .4227 .78176 L .42054 .78251 L F
.4222 .78499 m .42396 .78516 L .4227 .78176 L F
.811 .614 .636 r
.62591 .6749 m .62264 .67237 L .62264 .67475 L F
.819 .645 .667 r
.62264 .67475 m .62406 .67774 L .62591 .6749 L F
.442 .822 .582 r
.50531 .70832 m .50651 .70738 L .50786 .7064 L F
0 0 0 r
.50531 .70832 m .50422 .71005 L .50651 .70738 L F
.288 .685 .973 r
.32192 .7291 m .31969 .7293 L .32005 .72946 L F
.311 0 .099 r
.37124 .67034 m .37095 .67105 L .36878 .67154 L F
.256 0 .064 r
.36921 .67323 m .36878 .67154 L .37095 .67105 L F
.36921 .67323 m .3672 .67391 L .36878 .67154 L F
.974 .727 .501 r
.44761 .75778 m .44627 .75932 L .44633 .75693 L F
.311 0 0 r
.44836 .75904 m .44761 .75778 L .44977 .75772 L F
.44836 .75904 m .44627 .75932 L .44761 .75778 L F
.781 .68 .753 r
.30496 .71854 m .30792 .71918 L .30665 .71616 L F
.778 .411 .362 r
.30496 .71854 m .30698 .72276 L .30792 .71918 L F
.30698 .72276 m .30699 .72277 L .30792 .71918 L F
0 0 .004 r
.30792 .71918 m .30699 .72277 L .30843 .71915 L F
.605 .564 .782 r
.30571 .72195 m .30614 .72333 L .30744 .72305 L F
0 0 .004 r
.30699 .72277 m .30699 .72279 L .307 .72276 L F
.30699 .72277 m .307 .72276 L .30843 .71915 L F
.605 .564 .782 r
.30513 .7201 m .30571 .72195 L .30665 .72228 L F
.84 .397 0 r
.30513 .7201 m .30698 .72276 L .30496 .71854 L F
.842 .614 .593 r
.30843 .71915 m .307 .72276 L .30513 .7201 L F
.605 .564 .782 r
.30667 .72229 m .30744 .72305 L .3083 .72287 L F
.30571 .72195 m .30702 .72278 L .30667 .72229 L F
.30702 .72278 m .30744 .72305 L .30667 .72229 L F
.84 .397 0 r
.30513 .7201 m .30699 .72279 L .30698 .72276 L F
.605 .564 .782 r
.30513 .7201 m .30665 .72228 L .30718 .72247 L F
.778 .411 .362 r
.30698 .72276 m .30699 .72279 L .30699 .72277 L F
.842 .614 .593 r
.307 .72276 m .30699 .72279 L .30513 .7201 L F
.605 .564 .782 r
.30741 .72209 m .30718 .72247 L .3083 .72287 L F
.30513 .7201 m .30718 .72247 L .30741 .72209 L F
0 0 .229 r
.30792 .71918 m .30893 .71587 L .30665 .71616 L F
.494 .253 .478 r
.41664 .68125 m .41638 .68331 L .41422 .68372 L F
.413 .184 .455 r
.41828 .68262 m .41664 .68125 L .41868 .68086 L F
.41828 .68262 m .41638 .68331 L .41664 .68125 L F
.512 0 0 r
.55893 .71077 m .55549 .70805 L .55619 .7091 L F
.469 .111 .275 r
.52068 .76797 m .52285 .76781 L .52359 .76601 L F
.763 .61 .688 r
.52285 .76781 m .52584 .76585 L .52359 .76601 L F
.751 .524 .587 r
.60743 .65856 m .61113 .66118 L .61095 .65899 L F
.518 .313 .54 r
.42615 .67265 m .42604 .67488 L .42389 .67527 L F
.506 .244 .452 r
.42573 .67707 m .42389 .67527 L .42604 .67488 L F
.42573 .67707 m .42349 .67755 L .42389 .67527 L F
.558 .386 .604 r
.67172 .5965 m .6742 .598 L .67398 .59483 L F
.494 .049 .121 r
.49347 .74411 m .49284 .74523 L .48989 .74469 L F
.993 .81 .436 r
.49347 .74411 m .49344 .74649 L .49284 .74523 L F
.878 .655 .595 r
.56659 .75213 m .56492 .75382 L .5653 .7515 L F
.56659 .75213 m .56666 .75474 L .56492 .75382 L F
.85 .797 .799 r
.56797 .75011 m .56659 .75213 L .5653 .7515 L F
.705 .58 .711 r
.56969 .75206 m .56659 .75213 L .56797 .75011 L F
.738 .575 .672 r
.56969 .75206 m .56666 .75474 L .56659 .75213 L F
.74 .222 0 r
.71989 .6084 m .72239 .61009 L .72106 .60888 L F
.865 .771 .757 r
.60156 .67486 m .60273 .67232 L .60332 .67554 L F
.857 .572 .505 r
.60391 .67749 m .60156 .67486 L .60332 .67554 L F
.522 .396 .65 r
.42826 .6698 m .42821 .6722 L .42615 .67265 L F
.549 .368 .588 r
.42821 .6722 m .42604 .67488 L .42615 .67265 L F
.563 .639 .884 r
.44649 .77264 m .44569 .7749 L .44475 .77285 L F
.44649 .77264 m .44772 .77445 L .44569 .7749 L F
.654 .14 .008 r
.49851 .78427 m .50177 .78495 L .50044 .78437 L F
.608 .101 0 r
.72106 .60888 m .7189 .60674 L .71989 .6084 L F
.76 .642 .731 r
.54053 .73849 m .53939 .74006 L .53709 .73815 L F
.517 .326 .561 r
.58876 .73838 m .58878 .74073 L .58658 .74106 L F
.397 .346 .684 r
.44275 .76567 m .44146 .76819 L .44066 .76606 L F
.44275 .76567 m .44311 .76795 L .44146 .76819 L F
.534 .285 .484 r
.44412 .75983 m .44245 .75835 L .44434 .75729 L F
.44412 .75983 m .44239 .76048 L .44245 .75835 L F
.507 .912 .855 r
.5645 .67838 m .56289 .67866 L .56568 .67741 L F
.597 .455 .658 r
.31348 .6942 m .3155 .6914 L .3133 .69175 L F
.647 .433 .578 r
.5539 .75051 m .55115 .74894 L .55405 .74952 L F
.733 .331 .288 r
.55405 .74952 m .5563 .75167 L .5539 .75051 L F
.662 .538 .703 r
.55628 .74666 m .55634 .74948 L .55405 .74952 L F
.637 .374 .504 r
.55634 .74948 m .5563 .75167 L .55405 .74952 L F
.839 .391 .155 r
.7441 .61901 m .74538 .61885 L .74632 .62003 L F
.425 .264 .557 r
.74685 .6175 m .74538 .61885 L .7441 .61901 L F
.74685 .6175 m .74686 .6197 L .74538 .61885 L F
.832 .788 .81 r
.59454 .73655 m .5919 .73844 L .59328 .73748 L F
.629 .279 .359 r
.59328 .73748 m .59651 .73543 L .59454 .73655 L F
.698 .684 .833 r
.5328 .73225 m .53171 .7302 L .53277 .73026 L F
.794 .813 .867 r
.53171 .7302 m .53196 .73106 L .53277 .73026 L F
.548 .554 .812 r
.53277 .73026 m .53466 .73066 L .53373 .72635 L F
.519 .307 .532 r
.535 .73174 m .5328 .73225 L .53277 .73026 L F
.698 .684 .833 r
.5328 .73225 m .53027 .73284 L .53149 .7306 L F
.53194 .73064 m .53149 .7306 L .53171 .7302 L F
.5328 .73225 m .53149 .7306 L .53194 .73064 L F
.572 .004 0 r
.53234 .73068 m .53466 .73066 L .53277 .73026 L F
.53196 .73106 m .53365 .73081 L .53234 .73068 L F
.53365 .73081 m .53466 .73066 L .53234 .73068 L F
.738 .575 .672 r
.56969 .75206 m .57048 .75582 L .56666 .75474 L F
.239 .43 .848 r
.56797 .75011 m .57069 .75178 L .56969 .75206 L F
.64 .511 .69 r
.57374 .75374 m .56969 .75206 L .57069 .75178 L F
.57374 .75374 m .57048 .75582 L .56969 .75206 L F
.55 .538 .794 r
.54791 .74001 m .54727 .74373 L .5463 .74093 L F
.54791 .74001 m .54944 .7436 L .54727 .74373 L F
.569 .862 .545 r
.60387 .71643 m .60111 .71928 L .60156 .71879 L F
0 0 .269 r
.60306 .71817 m .60261 .72076 L .60341 .71952 L F
.874 .556 .445 r
.60341 .71952 m .60309 .71902 L .60306 .71817 L F
.569 .862 .545 r
.60302 .71729 m .60156 .71879 L .60306 .71817 L F
.531 .493 .759 r
.60135 .72021 m .60306 .71817 L .60156 .71879 L F
.60135 .72021 m .60261 .72076 L .60306 .71817 L F
.874 .556 .445 r
.60309 .71902 m .60204 .71737 L .60306 .71817 L F
.569 .862 .545 r
.60387 .71643 m .60302 .71729 L .60306 .71817 L F
.779 .92 .543 r
.60387 .71643 m .60383 .71606 L .60553 .71321 L F
.795 .828 .356 r
.60387 .71643 m .60306 .71817 L .60383 .71606 L F
.627 .625 .828 r
.71078 .72446 m .71198 .72731 L .71428 .72667 L F
.543 .48 .735 r
.31066 .70578 m .31128 .70834 L .31323 .70784 L F
.546 .789 .989 r
.31323 .70784 m .31128 .70834 L .3098 .70726 L F
.827 .445 .329 r
.60228 .66999 m .60112 .6714 L .5995 .66914 L F
.915 .585 .406 r
.60228 .66999 m .60273 .67232 L .60112 .6714 L F
.862 .584 .516 r
.47883 .74389 m .47716 .74569 L .47598 .74501 L F
.47883 .74389 m .47885 .74607 L .47716 .74569 L F
.703 .498 .607 r
.48144 .74366 m .47885 .74607 L .47883 .74389 L F
.994 .79 .419 r
.57244 .67937 m .57284 .68286 L .57223 .68254 L F
.85 .797 .799 r
.56797 .75011 m .5653 .7515 L .56862 .74912 L F
.959 .734 .556 r
.5695 .74837 m .57069 .75178 L .56797 .75011 L F
.311 0 0 r
.37305 .67088 m .37095 .67105 L .37124 .67034 L F
.584 .601 .835 r
.5857 .76306 m .58642 .75972 L .58461 .7605 L F
.5857 .76306 m .58794 .76268 L .58642 .75972 L F
.549 .028 0 r
.5657 .74784 m .56422 .74857 L .56188 .7477 L F
.262 .27 .68 r
.56761 .74641 m .56862 .74912 L .5657 .74784 L F
.7 .449 .541 r
.64196 .5247 m .63856 .52662 L .63842 .52425 L F
.64196 .5247 m .64199 .52691 L .63856 .52662 L F
.642 .487 .658 r
.64416 .52199 m .64451 .5247 L .64196 .5247 L F
.61 .364 .52 r
.64451 .5247 m .64199 .52691 L .64196 .5247 L F
0 0 .012 r
.57797 .68259 m .57657 .68574 L .57719 .68383 L F
.566 .119 .148 r
.50434 .73515 m .50413 .73615 L .50226 .73545 L F
.164 0 .059 r
.50667 .73467 m .50413 .73615 L .50434 .73515 L F
.907 .927 .816 r
.72888 .59095 m .73002 .58972 L .72904 .58896 L F
.295 .708 .974 r
.72904 .58896 m .73002 .58972 L .7327 .5898 L F
.924 .712 .597 r
.60994 .68682 m .60827 .68825 L .60828 .68588 L F
.60994 .68682 m .60956 .68903 L .60827 .68825 L F
.461 .619 .919 r
.4036 .65414 m .40259 .65566 L .40141 .65445 L F
.4036 .65414 m .40458 .65574 L .40259 .65566 L F
.532 .406 .654 r
.41616 .75759 m .41823 .75723 L .41805 .75482 L F
.586 .467 .685 r
.41633 .76007 m .41823 .75723 L .41616 .75759 L F
.786 .307 .091 r
.56799 .70399 m .56975 .70566 L .57023 .70508 L F
.523 .504 .777 r
.57023 .70508 m .57307 .70541 L .57202 .70396 L F
.647 .545 .724 r
.57202 .70396 m .57479 .70475 L .57594 .70551 L F
.57202 .70396 m .57307 .70541 L .57479 .70475 L F
.52 .511 .786 r
.57138 .70204 m .57307 .70541 L .57023 .70508 L F
.57138 .70204 m .57023 .70508 L .57157 .7046 L F
0 0 0 r
.57023 .70508 m .56975 .70566 L .57157 .7046 L F
.703 .778 .91 r
.6925 .5989 m .69581 .59943 L .69462 .59786 L F
.724 .699 .827 r
.69462 .59786 m .69581 .59943 L .69793 .59841 L F
.44 .301 .595 r
.56247 .73614 m .56107 .73344 L .56216 .7351 L F
.554 .509 .76 r
.56403 .73541 m .56247 .73614 L .56216 .7351 L F
.345 .281 .641 r
.56403 .73541 m .56343 .73816 L .56247 .73614 L F
.184 0 0 r
.4614 .78521 m .45758 .78583 L .45922 .78501 L F
.449 .644 .941 r
.39272 .66614 m .39349 .66746 L .39445 .66598 L F
.42 .605 .924 r
.39349 .66746 m .3953 .66746 L .39445 .66598 L F
.778 .638 .706 r
.53939 .74006 m .53757 .74115 L .53709 .73815 L F
.689 .427 .522 r
.53753 .74347 m .53757 .74115 L .53939 .74006 L F
.677 .424 .532 r
.54061 .74248 m .53753 .74347 L .53939 .74006 L F
.54 .382 .615 r
.4201 .74954 m .42234 .74919 L .42219 .7464 L F
.576 .444 .663 r
.42029 .75187 m .42234 .74919 L .4201 .74954 L F
.409 .2 .482 r
.30609 .63174 m .30822 .62889 L .30772 .63101 L F
.28 .02 .329 r
.30543 .63372 m .30609 .63174 L .30772 .63101 L F
.767 .548 .6 r
.45334 .77635 m .45669 .7766 L .45682 .774 L F
.648 .492 .657 r
.64618 .52242 m .64416 .52199 L .64675 .52163 L F
.64618 .52242 m .64451 .5247 L .64416 .52199 L F
.621 .593 .8 r
.42392 .66463 m .42178 .66526 L .42027 .66186 L F
.485 0 0 r
.35722 .64924 m .35936 .64962 L .3609 .64864 L F
.162 0 0 r
.35936 .64962 m .36289 .64855 L .3609 .64864 L F
.794 .652 .706 r
.46377 .74987 m .46321 .75231 L .45989 .75157 L F
.696 .301 .294 r
.29064 .72159 m .29183 .72169 L .29116 .72102 L F
.2 0 0 r
.37263 .71589 m .37118 .71746 L .36918 .71801 L F
.22 0 0 r
.37408 .71614 m .37118 .71746 L .37263 .71589 L F
.78 .407 .349 r
.48858 .74629 m .49 .74858 L .49171 .74784 L F
.772 .526 .564 r
.49 .74858 m .49344 .74649 L .49171 .74784 L F
.49 .74858 m .49397 .74893 L .49344 .74649 L F
0 0 .558 r
.4944 .74842 m .49344 .74649 L .49397 .74893 L F
.4944 .74842 m .49284 .74523 L .49344 .74649 L F
.443 .315 .611 r
.4944 .74842 m .49397 .74893 L .49344 .74649 L F
.098 0 0 r
.3782 .6687 m .3794 .66783 L .3814 .66728 L F
.673 .264 .261 r
.59669 .65887 m .59885 .66067 L .60001 .65899 L F
.736 .341 .302 r
.59885 .66067 m .60219 .66117 L .60001 .65899 L F
.642 .374 .498 r
.60001 .65899 m .60219 .66117 L .60233 .65898 L F
.511 .429 .699 r
.42857 .73752 m .43132 .74048 L .43209 .73823 L F
.42857 .73752 m .4294 .74099 L .43132 .74048 L F
.149 .045 .47 r
.61919 .71069 m .619 .71353 L .61818 .71367 L F
.158 .085 .517 r
.619 .71353 m .61894 .71472 L .61818 .71367 L F
.118 .075 .529 r
.61894 .71472 m .61806 .716 L .61818 .71367 L F
.538 .538 .802 r
.41722 .77698 m .41831 .77962 L .42024 .77912 L F
.421 .351 .674 r
.41831 .77962 m .42035 .78072 L .42024 .77912 L F
.41831 .77962 m .41858 .78278 L .42035 .78072 L F
.61 .157 .152 r
.58547 .73066 m .58977 .73018 L .58975 .73258 L F
.58547 .73066 m .58929 .732 L .58977 .73018 L F
.672 .554 .713 r
.58977 .73018 m .59241 .72958 L .59195 .7273 L F
.709 .523 .635 r
.59241 .72958 m .58975 .73258 L .58977 .73018 L F
.416 0 .103 r
.58929 .732 m .59241 .72958 L .58977 .73018 L F
.672 .554 .713 r
.58977 .73018 m .59241 .72958 L .59195 .7273 L F
.543 .449 .699 r
.31534 .68897 m .31707 .68631 L .31497 .68669 L F
.484 .34 .609 r
.74485 .72641 m .7433 .72732 L .74488 .72522 L F
0 0 .432 r
.74432 .72831 m .7433 .72732 L .74485 .72641 L F
.74432 .72831 m .74377 .73006 L .7433 .72732 L F
.403 .174 .448 r
.32506 .6671 m .32274 .66995 L .32468 .66926 L F
.353 .233 .574 r
.32274 .66995 m .32445 .67209 L .32468 .66926 L F
.32274 .66995 m .32279 .67233 L .32445 .67209 L F
.447 .068 .226 r
.30769 .70749 m .3098 .70726 L .31066 .70578 L F
.498 .343 .602 r
.31066 .70578 m .31268 .70561 L .31234 .70281 L F
.543 .48 .735 r
.31066 .70578 m .31323 .70784 L .31268 .70561 L F
.86 .843 .826 r
.57479 .70475 m .57391 .70753 L .57594 .70551 L F
.348 .449 .823 r
.57594 .70551 m .57859 .70649 L .57716 .70402 L F
.105 0 .259 r
.32694 .66447 m .32506 .6671 L .32732 .66685 L F
.563 .299 .474 r
.32668 .66896 m .32506 .6671 L .32468 .66926 L F
.32668 .66896 m .32732 .66685 L .32506 .6671 L F
.287 0 .029 r
.29001 .65039 m .29057 .65168 L .28857 .65225 L F
.29001 .65039 m .29195 .64993 L .29057 .65168 L F
.665 .681 .856 r
.69793 .59841 m .70126 .59915 L .7003 .5976 L F
.695 .713 .863 r
.70126 .59915 m .70256 .59566 L .7003 .5976 L F
.70126 .59915 m .70362 .59836 L .70256 .59566 L F
.746 .509 .572 r
.61126 .6639 m .61442 .6617 L .61113 .66118 L F
.61126 .6639 m .61458 .66395 L .61442 .6617 L F
.782 .537 .565 r
.61442 .6617 m .61458 .66395 L .61796 .66432 L F
.134 0 .232 r
.61806 .716 m .61742 .71836 L .6162 .71891 L F
0 0 .03 r
.61894 .71472 m .61742 .71836 L .61806 .716 L F
.869 .934 .862 r
.48879 .74436 m .48858 .74629 L .48989 .74469 L F
.26 .609 .955 r
.48989 .74469 m .49129 .74386 L .48879 .74436 L F
.48989 .74469 m .49284 .74523 L .49129 .74386 L F
.793 .581 .615 r
.61447 .66637 m .61796 .66432 L .61458 .66395 L F
.61447 .66637 m .61615 .66663 L .61796 .66432 L F
.793 .582 .616 r
.61615 .66663 m .61941 .66708 L .61796 .66432 L F
.467 .783 .998 r
.58983 .7372 m .58876 .73838 L .58808 .73499 L F
.58983 .7372 m .5919 .73844 L .58876 .73838 L F
.679 .473 .601 r
.5919 .73844 m .58878 .74073 L .58876 .73838 L F
.712 .387 .426 r
.51727 .73719 m .51343 .73571 L .51688 .73563 L F
0 0 0 r
.51871 .73235 m .51785 .73451 L .51688 .73563 L F
.492 .514 .808 r
.51785 .73451 m .51727 .73719 L .51688 .73563 L F
.619 .092 0 r
.51168 .79124 m .51117 .79218 L .51082 .78955 L F
.51168 .79124 m .5145 .79261 L .51117 .79218 L F
.342 .691 .981 r
.72145 .72894 m .72289 .72817 L .71974 .72789 L F
.72145 .72894 m .72358 .72909 L .72289 .72817 L F
0 0 0 r
.5215 .73123 m .52031 .73211 L .51871 .73235 L F
.062 0 .465 r
.51871 .73235 m .51994 .73427 L .51785 .73451 L F
.51871 .73235 m .52031 .73211 L .51994 .73427 L F
.424 .101 .312 r
.35981 .67974 m .35873 .67774 L .36083 .6773 L F
.35981 .67974 m .35774 .68024 L .35873 .67774 L F
.177 .361 .809 r
.74099 .71555 m .74219 .71571 L .74083 .71663 L F
.226 .461 .875 r
.74219 .71571 m .74385 .71848 L .74083 .71663 L F
.399 .275 .594 r
.61567 .72177 m .61572 .72425 L .61435 .72467 L F
.436 .243 .519 r
.61572 .72425 m .6142 .72728 L .61435 .72467 L F
.917 .879 .453 r
.5422 .69458 m .54126 .69741 L .54142 .69586 L F
.228 0 .332 r
.5445 .69155 m .5422 .69458 L .54414 .693 L F
0 0 0 r
.5422 .69458 m .54358 .69386 L .54414 .693 L F
.5422 .69458 m .54142 .69586 L .54358 .69386 L F
.542 .711 .949 r
.39079 .64967 m .39017 .65158 L .38883 .64979 L F
.39079 .64967 m .39236 .65127 L .39017 .65158 L F
.614 .455 .642 r
.52609 .75201 m .52389 .75474 L .52626 .75411 L F
.269 .77 .878 r
.50969 .70542 m .51185 .70509 L .5131 .70521 L F
.154 0 0 r
.45911 .7769 m .46022 .77691 L .45669 .7766 L F
.603 .055 0 r
.45911 .7769 m .46221 .77794 L .46022 .77691 L F
.569 .654 .894 r
.31982 .60429 m .31672 .60295 L .31884 .6026 L F
.437 .598 .912 r
.32054 .60251 m .31982 .60429 L .31884 .6026 L F
.541 .718 .954 r
.32054 .60251 m .32184 .60392 L .31982 .60429 L F
.454 .536 .852 r
.32295 .60701 m .31982 .60429 L .32184 .60392 L F
.494 .231 .444 r
.41422 .68372 m .41379 .68559 L .41171 .68597 L F
.445 .187 .426 r
.41584 .68501 m .41422 .68372 L .41638 .68331 L F
.41584 .68501 m .41379 .68559 L .41422 .68372 L F
.454 .659 .949 r
.26612 .58983 m .26572 .59148 L .2643 .59004 L F
.26612 .58983 m .26806 .59175 L .26572 .59148 L F
.455 .077 .231 r
.47598 .74501 m .47147 .74583 L .47298 .7452 L F
.592 .542 .767 r
.57152 .68571 m .57237 .68923 L .57458 .68865 L F
.142 .369 .825 r
.54295 .70038 m .54381 .69936 L .54257 .69887 L F
.181 .43 .863 r
.54295 .70038 m .54567 .70187 L .54381 .69936 L F
.141 0 .366 r
.61465 .74554 m .61308 .74887 L .61307 .74639 L F
.584 .418 .623 r
.41819 .75225 m .42027 .75442 L .42029 .75187 L F
.41819 .75225 m .41805 .75482 L .42027 .75442 L F
.65 .144 .029 r
.49783 .7894 m .49971 .79042 L .49619 .7897 L F
0 .04 .602 r
.56043 .73208 m .56216 .7351 L .56107 .73344 L F
.328 .72 .982 r
.56276 .73388 m .56216 .7351 L .56043 .73208 L F
.56276 .73388 m .56507 .73514 L .56216 .7351 L F
.554 .509 .76 r
.56403 .73541 m .56216 .7351 L .56507 .73514 L F
.372 .728 .989 r
.5197 .70402 m .51884 .70496 L .51751 .7042 L F
.5197 .70402 m .52096 .70494 L .51884 .70496 L F
.903 .724 .651 r
.70366 .58095 m .70561 .57964 L .7024 .57889 L F
.70366 .58095 m .70535 .58216 L .70561 .57964 L F
.866 .679 .648 r
.50178 .72598 m .50392 .72398 L .50309 .72358 L F
.50178 .72598 m .50407 .72701 L .50392 .72398 L F
.46 .239 .49 r
.50407 .72701 m .50621 .72467 L .50392 .72398 L F
0 .139 .67 r
.5802 .75523 m .58132 .75712 L .58028 .7541 L F
.499 .67 .94 r
.27584 .60339 m .27699 .60494 L .27899 .6047 L F
.664 .792 .943 r
.67249 .61264 m .67602 .61305 L .67458 .61159 L F
.805 .76 .812 r
.67458 .61159 m .67602 .61305 L .67736 .61149 L F
.744 .63 .732 r
.46482 .77311 m .46583 .7769 L .46785 .77431 L F
.544 .353 .572 r
.46785 .77431 m .46583 .7769 L .46821 .77455 L F
.081 0 0 r
.36942 .70561 m .37263 .70495 L .37044 .70485 L F
.825 .9 .893 r
.71439 .71485 m .71186 .71601 L .71411 .7138 L F
.391 .399 .748 r
.7163 .71341 m .71439 .71485 L .71411 .7138 L F
.7163 .71341 m .71623 .71506 L .71439 .71485 L F
0 0 0 r
.38066 .70005 m .38194 .69939 L .38293 .69737 L F
.253 0 .134 r
.38293 .69737 m .38365 .6988 L .38504 .69695 L F
.38293 .69737 m .38194 .69939 L .38365 .6988 L F
.655 .102 0 r
.29453 .72294 m .29183 .72169 L .29107 .72245 L F
.815 .701 .74 r
.72717 .60363 m .72517 .60657 L .72821 .60675 L F
.308 .609 .953 r
.3875 .64834 m .38704 .64959 L .38521 .64821 L F
.3875 .64834 m .38883 .64979 L .38704 .64959 L F
.425 .024 .173 r
.3849 .71035 m .38153 .71254 L .38311 .71115 L F
.371 0 0 r
.55355 .72729 m .55721 .72904 L .5547 .72795 L F
.026 .598 .739 r
.38952 .66569 m .38893 .66564 L .38731 .66564 L F
.281 .744 .949 r
.39272 .66614 m .38893 .66564 L .38952 .66569 L F
.286 .064 .392 r
.30772 .63101 m .30822 .62889 L .30976 .62815 L F
.307 0 .043 r
.37718 .70227 m .37926 .70185 L .38066 .70005 L F
.213 0 0 r
.38066 .70005 m .38128 .70122 L .38194 .69939 L F
.38066 .70005 m .37926 .70185 L .38128 .70122 L F
.587 .143 .162 r
.46221 .77794 m .46449 .77849 L .46583 .7769 L F
.52 .194 .354 r
.46449 .77849 m .46821 .77455 L .46583 .7769 L F
.937 .893 .76 r
.60955 .6938 m .61062 .69453 L .60938 .69603 L F
.787 .434 .388 r
.46321 .75231 m .46185 .75373 L .45989 .75157 L F
.377 .789 .98 r
.46453 .75334 m .46185 .75373 L .46321 .75231 L F
.635 .759 .938 r
.53974 .7545 m .53815 .75501 L .53508 .75465 L F
.709 .361 .384 r
.53815 .75501 m .53769 .75725 L .53508 .75465 L F
.565 .413 .634 r
.54056 .75458 m .53815 .75501 L .53974 .7545 L F
.555 .445 .683 r
.54056 .75458 m .53863 .75745 L .53815 .75501 L F
.785 .987 .738 r
.46123 .75515 m .45881 .75786 L .45974 .75587 L F
.202 .325 .767 r
.45881 .75786 m .46092 .75957 L .45974 .75587 L F
0 .215 .731 r
.56933 .72336 m .57094 .72405 L .57086 .72401 L F
.56933 .72336 m .57086 .72401 L .56783 .72257 L F
0 .081 .623 r
.56817 .72287 m .56933 .72336 L .56796 .72112 L F
.56825 .72353 m .56933 .72336 L .56817 .72287 L F
0 .185 .714 r
.56825 .72353 m .57076 .72633 L .56933 .72336 L F
.435 .169 .41 r
.54209 .74435 m .54149 .74597 L .54333 .74502 L F
.512 .482 .76 r
.41858 .78278 m .42054 .78251 L .42035 .78072 L F
.76 .951 .939 r
.52741 .72752 m .5256 .72981 L .5296 .72769 L F
.276 0 0 r
.55419 .70756 m .55235 .70738 L .55122 .70714 L F
.37 0 0 r
.55419 .70756 m .55549 .70805 L .55235 .70738 L F
.432 0 0 r
.4614 .78521 m .46481 .7849 L .46383 .7859 L F
.57 .053 0 r
.46383 .7859 m .46481 .7849 L .46697 .7862 L F
.733 .524 .609 r
.47598 .74501 m .47202 .74814 L .47147 .74583 L F
.379 .294 .633 r
.46333 .77049 m .46139 .77138 L .4618 .77035 L F
.205 0 .283 r
.46333 .77049 m .46112 .77326 L .46139 .77138 L F
.201 0 0 r
.27688 .65616 m .27887 .65577 L .27673 .65629 L F
.594 .259 .372 r
.46963 .73062 m .47176 .732 L .47285 .72949 L F
.515 .172 .323 r
.47176 .732 m .47505 .72946 L .47285 .72949 L F
.469 .049 .16 r
.47727 .72914 m .47955 .72904 L .48073 .72725 L F
.585 .24 .35 r
.47955 .72904 m .48292 .72689 L .48073 .72725 L F
0 0 0 r
.55278 .7439 m .55398 .74304 L .5551 .74107 L F
.101 0 0 r
.5551 .74107 m .55592 .74183 L .55719 .74043 L F
.5551 .74107 m .55398 .74304 L .55592 .74183 L F
.543 .651 .905 r
.31884 .6026 m .31672 .60295 L .31503 .60058 L F
.421 .809 .573 r
.50786 .7064 m .50819 .70615 L .50969 .70542 L F
.50786 .7064 m .50651 .70738 L .50819 .70615 L F
.37 .061 .305 r
.58931 .66209 m .59092 .663 L .59159 .66156 L F
.58931 .66209 m .5888 .6637 L .59092 .663 L F
.37 .787 .977 r
.54944 .7436 m .5516 .74335 L .55278 .7439 L F
.397 .802 .982 r
.5516 .74335 m .55398 .74304 L .55278 .7439 L F
.909 .613 .473 r
.72629 .59777 m .72664 .60083 L .72886 .60068 L F
.932 .837 .728 r
.72664 .60083 m .72717 .60363 L .72886 .60068 L F
.647 .433 .578 r
.5539 .75051 m .55114 .75149 L .55115 .74894 L F
.53 .484 .75 r
.44197 .76263 m .44066 .76606 L .4397 .76297 L F
.44197 .76263 m .44275 .76567 L .44066 .76606 L F
.039 0 0 r
.57339 .67183 m .57535 .67116 L .57689 .6703 L F
0 0 0 r
.57689 .6703 m .57742 .6704 L .57882 .66938 L F
.57689 .6703 m .57535 .67116 L .57742 .6704 L F
.089 0 0 r
.36289 .64855 m .36497 .64859 L .36652 .64833 L F
.577 .126 .144 r
.36497 .64859 m .3686 .64768 L .36652 .64833 L F
.537 .521 .785 r
.52609 .75201 m .52729 .74855 L .52492 .74888 L F
.52609 .75201 m .52801 .75164 L .52729 .74855 L F
.556 .411 .639 r
.52609 .75201 m .5287 .75346 L .52801 .75164 L F
.52609 .75201 m .52626 .75411 L .5287 .75346 L F
.227 .747 .821 r
.45381 .75606 m .45286 .75643 L .45498 .75462 L F
.45381 .75606 m .45153 .75644 L .45286 .75643 L F
.013 .587 .749 r
.26172 .58995 m .26364 .59003 L .26241 .59 L F
0 .143 .664 r
.52096 .70494 m .5228 .7074 L .52193 .7085 L F
.133 .368 .826 r
.5228 .7074 m .52431 .70993 L .52193 .7085 L F
.774 .301 .118 r
.45974 .75587 m .46243 .75672 L .46123 .75515 L F
.031 .509 .88 r
.53713 .71769 m .53712 .71838 L .53433 .71601 L F
.53713 .71769 m .53813 .71852 L .53712 .71838 L F
.642 .531 .713 r
.5219 .73173 m .52297 .73574 L .51994 .73427 L F
.5223 .73122 m .52236 .73162 L .5219 .73173 L F
.52236 .73162 m .52297 .73574 L .5219 .73173 L F
.478 .897 .84 r
.52301 .73116 m .52035 .73209 L .5215 .73123 L F
.52035 .73209 m .52031 .73211 L .52032 .7321 L F
.52035 .73209 m .52032 .7321 L .5215 .73123 L F
0 .378 .712 r
.58276 .72963 m .58547 .73066 L .58391 .7305 L F
.474 .514 .819 r
.58691 .73206 m .58391 .7305 L .58547 .73066 L F
.499 0 0 r
.48577 .74859 m .48607 .74891 L .48404 .74702 L F
.259 .442 .852 r
.50753 .71982 m .50873 .71879 L .50689 .71838 L F
.50753 .71982 m .50981 .72092 L .50873 .71879 L F
.4 .388 .73 r
.74437 .59205 m .74236 .59345 L .74174 .58994 L F
0 0 .14 r
.74437 .59205 m .74356 .59573 L .74236 .59345 L F
.568 .466 .698 r
.41494 .76575 m .41709 .76542 L .41682 .76286 L F
.56 .426 .655 r
.41494 .76575 m .41518 .76826 L .41709 .76542 L F
.681 .188 .069 r
.50098 .78618 m .50177 .78495 L .49851 .78427 L F
.643 .143 .048 r
.50098 .78618 m .50408 .78657 L .50177 .78495 L F
.627 .139 .075 r
.50332 .7897 m .50507 .79053 L .50161 .79015 L F
.514 .496 .775 r
.41518 .76826 m .41607 .77116 L .41794 .77065 L F
.349 .064 .331 r
.41565 .77292 m .41794 .77065 L .41607 .77116 L F
.58 .427 .639 r
.31707 .68631 m .31901 .68298 L .31681 .68368 L F
.911 .741 .658 r
.71823 .60104 m .71835 .60485 L .71933 .60413 L F
.389 0 .067 r
.71933 .60413 m .71835 .60485 L .71843 .6056 L F
.989 .84 .467 r
.71843 .6056 m .7189 .60674 L .71933 .60413 L F
.719 .656 .787 r
.71823 .60104 m .71933 .60413 L .72041 .60274 L F
.7 .627 .772 r
.72041 .60274 m .71933 .60413 L .72233 .60381 L F
.199 .168 .596 r
.31429 .71091 m .31633 .71132 L .31532 .70744 L F
.31452 .71014 m .31532 .70744 L .31466 .71026 L F
.73 .44 .488 r
.31158 .70935 m .31466 .71026 L .31532 .70744 L F
.908 .694 .602 r
.31474 .71032 m .31466 .71026 L .31392 .70958 L F
.541 .553 .816 r
.31411 .71344 m .31633 .71132 L .31429 .71091 L F
.31411 .71344 m .31654 .71331 L .31633 .71132 L F
.704 .482 .583 r
.31532 .70744 m .31633 .71132 L .31899 .71102 L F
.51 .337 .582 r
.31654 .71331 m .31899 .71102 L .31633 .71132 L F
.46 .505 .818 r
.31672 .7098 m .31654 .71331 L .31466 .71026 L F
.908 .694 .602 r
.3154 .71093 m .31672 .7098 L .31466 .71026 L F
.3154 .71093 m .31466 .71026 L .31474 .71032 L F
.199 .168 .596 r
.31429 .71091 m .31452 .71014 L .31466 .71026 L F
.532 .602 .869 r
.31466 .71026 m .31411 .71344 L .31429 .71091 L F
.657 .58 .756 r
.55863 .746 m .55634 .74948 L .55628 .74666 L F
0 0 .074 r
.45682 .75182 m .45627 .75369 L .45498 .75462 L F
0 0 0 r
.45627 .75369 m .45381 .75606 L .45498 .75462 L F
.4 .611 .935 r
.28838 .60831 m .2895 .60987 L .29016 .60837 L F
.213 .385 .818 r
.2895 .60987 m .2917 .61148 L .29016 .60837 L F
.713 .713 .849 r
.69462 .59786 m .69793 .59841 L .69677 .59555 L F
.665 .683 .857 r
.69793 .59841 m .69918 .59489 L .69677 .59555 L F
.69793 .59841 m .7003 .5976 L .69918 .59489 L F
.787 .804 .866 r
.67458 .61159 m .67736 .61149 L .67716 .60921 L F
.848 .845 .84 r
.67716 .60921 m .67736 .61149 L .67962 .6088 L F
.462 .801 .999 r
.52618 .76821 m .52998 .76872 L .5284 .76777 L F
.72 .917 .565 r
.53065 .76731 m .52998 .76872 L .53212 .76573 L F
.529 .806 .997 r
.5284 .76777 m .52998 .76872 L .53065 .76731 L F
.447 .195 .437 r
.41171 .68597 m .41074 .68832 L .40907 .68836 L F
.494 .246 .467 r
.41208 .69017 m .40907 .68836 L .41074 .68832 L F
.41208 .69017 m .40884 .6913 L .40907 .68836 L F
0 0 0 r
.32279 .72206 m .32365 .7208 L .32381 .71907 L F
.539 .919 .928 r
.32279 .72206 m .32168 .7219 L .32365 .7208 L F
.869 .934 .862 r
.48879 .74436 m .4871 .74603 L .48858 .74629 L F
.727 .607 .723 r
.4871 .74603 m .49 .74858 L .48858 .74629 L F
.536 .4 .643 r
.34872 .68845 m .34616 .68693 L .34854 .68693 L F
.34872 .68845 m .3465 .69012 L .34616 .68693 L F
.345 .281 .641 r
.56403 .73541 m .56481 .73838 L .56343 .73816 L F
.56 .745 .964 r
.71804 .57815 m .71671 .57989 L .71575 .57868 L F
.71804 .57815 m .71889 .57951 L .71671 .57989 L F
.663 .947 .701 r
.49997 .74519 m .49915 .74645 L .50145 .74433 L F
.648 .565 .747 r
.50333 .74105 m .50145 .74433 L .50103 .74159 L F
.239 0 0 r
.50319 .74437 m .49997 .74519 L .50145 .74433 L F
.221 0 0 r
.3686 .64768 m .37076 .64798 L .37203 .64792 L F
.437 0 0 r
.37076 .64798 m .37407 .64811 L .37203 .64792 L F
.438 0 0 r
.47036 .785 m .47126 .78609 L .46899 .78622 L F
.47036 .785 m .47269 .78548 L .47126 .78609 L F
.636 .911 .982 r
.51421 .79509 m .51577 .79354 L .5145 .79261 L F
.51421 .79509 m .51776 .79394 L .51577 .79354 L F
.657 .58 .756 r
.55863 .746 m .55938 .74933 L .55634 .74948 L F
.633 .371 .504 r
.5592 .75133 m .55634 .74948 L .55938 .74933 L F
.5592 .75133 m .5563 .75167 L .55634 .74948 L F
.576 .548 .787 r
.52997 .75701 m .53168 .75546 L .52933 .75549 L F
.52997 .75701 m .53255 .75735 L .53168 .75546 L F
.599 .457 .659 r
.53043 .76008 m .53255 .75735 L .52997 .75701 L F
.613 .931 .964 r
.37745 .66848 m .37672 .66967 L .3782 .6687 L F
.678 .972 .787 r
.37745 .66848 m .37603 .66978 L .37672 .66967 L F
.508 .363 .619 r
.56875 .75668 m .56666 .75474 L .57048 .75582 L F
.508 .896 .733 r
.56875 .75668 m .57048 .75582 L .57275 .75436 L F
.57282 .75428 m .57275 .75436 L .57374 .75374 L F
.56875 .75668 m .57275 .75436 L .57282 .75428 L F
.56875 .75668 m .57374 .75374 L .57 .7562 L F
.669 .974 .886 r
.57434 .75423 m .57 .7562 L .57374 .75374 L F
.665 .113 0 r
.57364 .75376 m .5735 .75415 L .57434 .75423 L F
.57069 .75178 m .5735 .75415 L .57364 .75376 L F
.57069 .75178 m .57434 .75423 L .57374 .75374 L F
.562 .935 .894 r
.57541 .75315 m .5735 .75415 L .57434 .75423 L F
.57541 .75315 m .5735 .75415 L .57434 .75423 L F
.878 .963 .85 r
.57541 .75315 m .57337 .75453 L .5735 .75415 L F
.669 .974 .886 r
.57434 .75423 m .5735 .75415 L .57 .7562 L F
.878 .963 .85 r
.57337 .75453 m .57259 .75505 L .5735 .75415 L F
0 .266 .773 r
.57363 .75345 m .5735 .75415 L .57315 .75385 L F
.57352 .75339 m .57315 .75385 L .57069 .75178 L F
.57363 .75345 m .57315 .75385 L .57352 .75339 L F
.593 .422 .62 r
.42219 .7464 m .42461 .74882 L .42437 .74564 L F
.42219 .7464 m .42234 .74919 L .42461 .74882 L F
.633 .642 .841 r
.35599 .70527 m .35227 .70315 L .35465 .70386 L F
.643 .746 .924 r
.35835 .70454 m .35599 .70527 L .35465 .70386 L F
.373 .778 .983 r
.28998 .59569 m .28937 .59654 L .28773 .59556 L F
.28998 .59569 m .29149 .59635 L .28937 .59654 L F
.552 .328 .528 r
.42437 .74564 m .42701 .7432 L .42401 .74373 L F
.543 .449 .699 r
.31534 .68897 m .31736 .68856 L .31707 .68631 L F
.576 .435 .653 r
.31534 .68897 m .31774 .69102 L .31736 .68856 L F
.31534 .68897 m .3155 .6914 L .31774 .69102 L F
.469 .339 .621 r
.31866 .67797 m .32064 .67993 L .32063 .67753 L F
.31866 .67797 m .31885 .68036 L .32064 .67993 L F
.443 .486 .809 r
.32493 .60693 m .32295 .60701 L .32184 .60392 L F
.447 .421 .737 r
.32493 .60693 m .32537 .60865 L .32295 .60701 L F
.469 .419 .72 r
.32295 .60701 m .32537 .60865 L .32363 .60911 L F
.605 .428 .615 r
.31234 .70281 m .3148 .70263 L .31495 .70007 L F
.594 .412 .605 r
.31234 .70281 m .31479 .70489 L .3148 .70263 L F
.31234 .70281 m .31268 .70561 L .31479 .70489 L F
.409 .147 .402 r
.40198 .69692 m .39955 .69941 L .40006 .69742 L F
.703 .498 .607 r
.48144 .74366 m .48296 .7467 L .47885 .74607 L F
.144 .682 .84 r
.53497 .75735 m .53769 .75725 L .53863 .75745 L F
.956 .946 .714 r
.53809 .75633 m .53769 .75725 L .53863 .75745 L F
.555 .445 .683 r
.54056 .75458 m .54072 .7571 L .53863 .75745 L F
.956 .946 .714 r
.53863 .75745 m .53769 .75725 L .53809 .75633 L F
.485 .287 .536 r
.54062 .75924 m .53863 .75745 L .54072 .7571 L F
.54062 .75924 m .53853 .75992 L .53863 .75745 L F
.866 .903 .856 r
.56666 .75474 m .5643 .75749 L .56308 .75681 L F
.582 .42 .627 r
.56666 .75474 m .5668 .75763 L .5643 .75749 L F
.01 .562 .825 r
.5668 .75763 m .56308 .75681 L .5643 .75749 L F
.216 0 0 r
.47143 .77685 m .47309 .77713 L .47383 .7766 L F
.165 .256 .713 r
.47257 .77548 m .47309 .77713 L .47143 .77685 L F
.526 .473 .74 r
.34675 .69348 m .34565 .69733 L .34465 .69391 L F
.34675 .69348 m .34759 .69715 L .34565 .69733 L F
.191 0 0 r
.49026 .72124 m .49208 .72093 L .49332 .7194 L F
.339 0 .07 r
.49332 .7194 m .4945 .72048 L .49515 .71856 L F
.49332 .7194 m .49208 .72093 L .4945 .72048 L F
.534 .383 .621 r
.30553 .71195 m .30679 .70876 L .30406 .7124 L F
.896 .946 .832 r
.5286 .71228 m .52927 .7133 L .53111 .71075 L F
.692 .161 0 r
.5286 .71228 m .5307 .71404 L .52927 .7133 L F
.394 .662 .966 r
.53365 .71487 m .53248 .71603 L .5307 .71404 L F
.497 0 0 r
.53043 .71445 m .53214 .71467 L .5307 .71404 L F
.53214 .71467 m .53365 .71487 L .5307 .71404 L F
.614 .573 .784 r
.53248 .71603 m .52956 .71354 L .5307 .71404 L F
.52956 .71354 m .52927 .7133 L .5307 .71404 L F
.278 0 .036 r
.36033 .72341 m .35969 .72204 L .36164 .72139 L F
.36033 .72341 m .35825 .72391 L .35969 .72204 L F
.63 .342 .462 r
.44827 .73768 m .45062 .73782 L .45098 .73587 L F
.572 .291 .452 r
.45062 .73782 m .45383 .73496 L .45098 .73587 L F
.984 .727 .458 r
.33067 .72406 m .33136 .72611 L .33164 .72439 L F
.539 .893 .977 r
.33221 .72331 m .33164 .72439 L .3337 .72405 L F
.33221 .72331 m .33067 .72406 L .33164 .72439 L F
.578 .359 .547 r
.33136 .72611 m .3337 .72405 L .33164 .72439 L F
.528 .63 .896 r
.71761 .72817 m .71905 .72614 L .71674 .72643 L F
.71761 .72817 m .71974 .72789 L .71905 .72614 L F
.743 .565 .653 r
.73219 .59027 m .73356 .59327 L .7305 .59304 L F
.73219 .59027 m .7305 .59304 L .7327 .5898 L F
0 0 .405 r
.61526 .7348 m .61537 .73768 L .61409 .73856 L F
.189 .274 .721 r
.61537 .73768 m .61495 .7408 L .61409 .73856 L F
.035 0 .165 r
.49595 .71671 m .49515 .71856 L .49721 .7157 L F
.361 .718 .987 r
.27492 .59457 m .27132 .59363 L .27329 .59328 L F
.467 .742 .988 r
.2757 .59327 m .27492 .59457 L .27329 .59328 L F
.2757 .59327 m .27689 .59443 L .27492 .59457 L F
.578 .237 .355 r
.52419 .78691 m .52614 .78692 L .52773 .78467 L F
.794 .509 .504 r
.52773 .78467 m .52614 .78692 L .52808 .78708 L F
.794 .563 .588 r
.6181 .66895 m .61941 .66708 L .61615 .66663 L F
.6181 .66895 m .61953 .66953 L .61941 .66708 L F
0 0 .006 r
.62431 .69637 m .62329 .70006 L .62448 .69668 L F
.62381 .69817 m .62376 .69923 L .62329 .70006 L F
.898 .479 .118 r
.62266 .69859 m .62373 .69986 L .62376 .69923 L F
.083 0 .227 r
.62457 .70087 m .62329 .70006 L .62376 .69923 L F
.898 .479 .118 r
.62373 .69986 m .62457 .70087 L .62376 .69923 L F
0 0 .006 r
.62431 .69637 m .62376 .69923 L .62381 .69817 L F
.083 0 .227 r
.62457 .70087 m .62268 .70205 L .62329 .70006 L F
.725 .446 .504 r
.60233 .65898 m .60564 .66108 L .60566 .65876 L F
.60233 .65898 m .60219 .66117 L .60564 .66108 L F
.231 .353 .782 r
.57434 .73819 m .57679 .73995 L .57576 .73776 L F
.47 .607 .905 r
.75039 .60707 m .74894 .60892 L .74759 .60802 L F
.75039 .60707 m .75105 .6088 L .74894 .60892 L F
.448 .178 .409 r
.75105 .6088 m .74838 .61113 L .74894 .60892 L F
.665 .956 .729 r
.49997 .74519 m .49841 .7467 L .49915 .74645 L F
.496 .645 .923 r
.72233 .60381 m .72378 .60346 L .72041 .60274 L F
.405 .45 .794 r
.72233 .60381 m .72517 .60657 L .72378 .60346 L F
.642 .34 .443 r
.4425 .73998 m .44584 .7377 L .44303 .73861 L F
.31 .091 .412 r
.39429 .68582 m .39615 .68527 L .39647 .68339 L F
.52 .348 .588 r
.39402 .68831 m .39615 .68527 L .39429 .68582 L F
.553 .483 .731 r
.31495 .70007 m .31628 .69687 L .31418 .69735 L F
.31495 .70007 m .31701 .6998 L .31628 .69687 L F
.428 .279 .576 r
.31495 .70007 m .31672 .70182 L .31701 .6998 L F
.31495 .70007 m .3148 .70263 L .31672 .70182 L F
.267 .055 .394 r
.30976 .62815 m .31024 .626 L .31172 .62525 L F
.446 .795 .998 r
.72669 .72998 m .72796 .72899 L .72568 .72925 L F
.37 .649 .964 r
.72669 .72998 m .72857 .73004 L .72796 .72899 L F
.467 .203 .429 r
.41379 .68559 m .41074 .68832 L .41171 .68597 L F
.731 .882 .95 r
.29699 .73539 m .29678 .73551 L .29526 .7348 L F
.493 .296 .542 r
.29678 .73551 m .29547 .7349 L .29526 .7348 L F
.416 0 .103 r
.58929 .732 m .59114 .73144 L .59241 .72958 L F
.604 .561 .779 r
.59241 .72958 m .59413 .72696 L .59195 .7273 L F
.062 0 .257 r
.5445 .69155 m .54588 .69124 L .54632 .69116 L F
.5445 .69155 m .54579 .69158 L .54588 .69124 L F
.5445 .69155 m .54414 .693 L .54579 .69158 L F
.493 .321 .576 r
.59195 .7273 m .59413 .72696 L .59398 .72462 L F
.572 .631 .871 r
.70813 .60667 m .71191 .60898 L .71083 .60651 L F
.412 .559 .892 r
.71083 .60651 m .71191 .60898 L .71342 .60874 L F
.342 .129 .439 r
.71342 .60874 m .71191 .60898 L .71164 .61126 L F
.102 0 0 r
.53644 .78797 m .53749 .78832 L .53904 .78898 L F
0 0 0 r
.3316 .65862 m .32894 .66122 L .33095 .66077 L F
.529 .2 .355 r
.33289 .66054 m .3316 .65862 L .33095 .66077 L F
.33289 .66054 m .33384 .65842 L .3316 .65862 L F
0 .462 .86 r
.39634 .65182 m .39467 .65165 L .3938 .65078 L F
.39634 .65182 m .39754 .65276 L .39467 .65165 L F
.633 .398 .544 r
.42701 .7432 m .42919 .74318 L .4294 .74099 L F
.528 .343 .574 r
.42919 .74318 m .43132 .74048 L .4294 .74099 L F
.036 0 .044 r
.39955 .69941 m .39711 .70188 L .39804 .70037 L F
.217 .684 .943 r
.43665 .78746 m .43546 .78689 L .43347 .78684 L F
.36 .804 .955 r
.43857 .78684 m .43546 .78689 L .43665 .78746 L F
.865 .681 .651 r
.50102 .72612 m .50407 .72701 L .50178 .72598 L F
.857 .513 .401 r
.50102 .72612 m .50214 .72868 L .50407 .72701 L F
.573 .163 .227 r
.50214 .72868 m .50566 .72714 L .50407 .72701 L F
.46 .239 .49 r
.50407 .72701 m .50566 .72714 L .50621 .72467 L F
.422 .222 .501 r
.27286 .6443 m .27509 .64258 L .27372 .64236 L F
.635 .518 .704 r
.64899 .51828 m .64948 .5218 L .64675 .52163 L F
.58 .301 .457 r
.64948 .5218 m .64618 .52242 L .64675 .52163 L F
.52 .194 .354 r
.46449 .77849 m .46684 .77841 L .46821 .77455 L F
.336 .021 .275 r
.46821 .77455 m .46684 .77841 L .4688 .77765 L F
0 0 0 r
.71698 .71382 m .72227 .71337 L .72292 .7133 L F
.72462 .7125 m .72411 .71277 L .72292 .7133 L F
.35 .823 .783 r
.72292 .7133 m .72227 .71337 L .72462 .7125 L F
.959 .716 .525 r
.30185 .72882 m .30333 .72956 L .3035 .72678 L F
.562 .536 .783 r
.30259 .72385 m .3035 .72678 L .30585 .72626 L F
.244 0 0 r
.58581 .67303 m .58541 .67412 L .58206 .67439 L F
.362 0 0 r
.58668 .67393 m .58581 .67303 L .58797 .67258 L F
.58668 .67393 m .58541 .67412 L .58581 .67303 L F
.545 .609 .868 r
.58088 .72067 m .58189 .72263 L .57939 .72275 L F
.933 .642 .468 r
.53064 .76512 m .53065 .76731 L .53212 .76573 L F
.844 .848 .847 r
.53064 .76512 m .53212 .76573 L .53412 .76322 L F
.933 .642 .468 r
.53064 .76512 m .53065 .76731 L .53212 .76573 L F
.597 .455 .658 r
.31348 .6942 m .31572 .69403 L .3155 .6914 L F
.577 .483 .711 r
.31348 .6942 m .31628 .69687 L .31572 .69403 L F
.31348 .6942 m .31418 .69735 L .31628 .69687 L F
.255 .766 .784 r
.27887 .65577 m .27515 .65653 L .27673 .65629 L F
.414 .721 .988 r
.73282 .73395 m .73468 .7338 L .732 .73302 L F
.73282 .73395 m .73513 .73416 L .73468 .7338 L F
.143 .345 .804 r
.73085 .73235 m .73171 .73141 L .72857 .73004 L F
.73085 .73235 m .732 .73302 L .73171 .73141 L F
.394 .662 .966 r
.53365 .71487 m .53433 .71601 L .53248 .71603 L F
.069 .491 .894 r
.3308 .73241 m .3311 .73175 L .32913 .73234 L F
.3308 .73241 m .33285 .73323 L .3311 .73175 L F
.731 .882 .95 r
.29699 .73539 m .29432 .73263 L .29612 .73267 L F
.29699 .73539 m .29526 .7348 L .29432 .73263 L F
.931 .842 .734 r
.29697 .73212 m .29699 .73539 L .29612 .73267 L F
.29697 .73212 m .29547 .7349 L .29699 .73539 L F
.955 .701 .512 r
.29547 .7349 m .29688 .738 L .29699 .73539 L F
.389 .805 .607 r
.59769 .75927 m .60104 .75716 L .59961 .75859 L F
0 0 0 r
.60104 .75716 m .604 .7555 L .60253 .75641 L F
.59961 .75859 m .60104 .75716 L .60253 .75641 L F
.634 .664 .862 r
.32553 .73487 m .32845 .73569 L .32676 .73308 L F
.466 .597 .899 r
.31344 .59816 m .31313 .60066 L .31153 .59856 L F
.31344 .59816 m .31503 .60058 L .31313 .60066 L F
.419 .69 .975 r
.30405 .59828 m .3009 .5971 L .30275 .59703 L F
.309 .637 .965 r
.30453 .59719 m .30405 .59828 L .30275 .59703 L F
.383 .721 .989 r
.30597 .59822 m .30405 .59828 L .30453 .59719 L F
.629 .279 .359 r
.59328 .73748 m .59555 .73757 L .59651 .73543 L F
0 0 .352 r
.59651 .73543 m .59776 .73199 L .59785 .73273 L F
.59651 .73543 m .59769 .7344 L .59776 .73199 L F
0 0 0 r
.59651 .73543 m .59555 .73757 L .59769 .7344 L F
.533 .692 .941 r
.37834 .64654 m .37783 .64869 L .37637 .64773 L F
.37834 .64654 m .37992 .64841 L .37783 .64869 L F
.566 .305 .48 r
.59862 .72363 m .60135 .72021 L .59944 .72164 L F
.722 .736 .862 r
.32357 .73229 m .32553 .73487 L .32676 .73308 L F
0 0 .385 r
.64899 .51828 m .6491 .51799 L .64856 .51631 L F
.64856 .51631 m .6491 .51799 L .64899 .51828 L F
.311 .776 .649 r
.604 .7555 m .6041 .75543 L .60253 .75641 L F
.604 .7555 m .60605 .75453 L .6041 .75543 L F
0 .348 .759 r
.305 .71163 m .30738 .71269 L .30553 .71195 L F
.484 0 0 r
.55934 .73135 m .55824 .73036 L .55721 .72904 L F
.55934 .73135 m .56043 .73208 L .55824 .73036 L F
.72 .618 .743 r
.53168 .75546 m .53508 .75465 L .53391 .75431 L F
.53168 .75546 m .53497 .75735 L .53508 .75465 L F
0 .249 .757 r
.53508 .75465 m .53582 .7539 L .53391 .75431 L F
.53508 .75465 m .53769 .75725 L .53582 .7539 L F
.475 0 0 r
.476 .78486 m .47686 .78613 L .47477 .78596 L F
.476 .78486 m .478 .78535 L .47686 .78613 L F
.993 .762 .477 r
.53757 .74115 m .53617 .74061 L .53709 .73815 L F
.869 .98 .685 r
.53757 .74115 m .53581 .74219 L .53557 .74037 L F
0 0 .054 r
.53583 .74215 m .5367 .74116 L .53732 .73885 L F
.53581 .74219 m .53583 .74218 L .53583 .74215 L F
.53583 .74218 m .5367 .74116 L .53583 .74215 L F
.993 .762 .477 r
.53617 .74061 m .53557 .74037 L .53652 .73899 L F
.53617 .74061 m .53652 .73899 L .53709 .73815 L F
.869 .98 .685 r
.53757 .74115 m .53551 .74369 L .53581 .74219 L F
.689 .427 .522 r
.53753 .74347 m .53551 .74369 L .53757 .74115 L F
0 0 0 r
.27027 .60384 m .27384 .60366 L .27237 .60376 L F
.138 .684 .754 r
.27384 .60366 m .27416 .60353 L .27237 .60376 L F
.27384 .60366 m .27584 .60339 L .27416 .60353 L F
.541 .309 .512 r
.64679 .52618 m .64451 .5247 L .64618 .52242 L F
.58 .301 .457 r
.64948 .5218 m .64942 .52355 L .64618 .52242 L F
.562 .352 .553 r
.64901 .52573 m .64618 .52242 L .64942 .52355 L F
.64901 .52573 m .64679 .52618 L .64618 .52242 L F
.623 .561 .764 r
.53566 .73712 m .53709 .73815 L .53621 .73506 L F
.603 .423 .611 r
.67398 .59483 m .67703 .59432 L .67621 .59267 L F
.511 .302 .532 r
.6742 .598 m .67703 .59432 L .67398 .59483 L F
.117 .613 .906 r
.43347 .78684 m .42953 .78577 L .43073 .78654 L F
.59 .316 .47 r
.48505 .72631 m .48775 .72422 L .48579 .72461 L F
.51 .318 .555 r
.32363 .60911 m .32354 .61201 L .32131 .61244 L F
.393 .193 .486 r
.32363 .60911 m .32504 .61101 L .32354 .61201 L F
.32363 .60911 m .32537 .60865 L .32504 .61101 L F
.446 .564 .881 r
.70256 .59566 m .70362 .59836 L .7047 .59787 L F
.275 .139 .507 r
.7047 .59787 m .70362 .59836 L .70506 .59998 L F
.549 .322 .524 r
.42115 .67801 m .42091 .68044 L .41868 .68086 L F
.496 .261 .488 r
.42349 .67755 m .42091 .68044 L .42115 .67801 L F
.564 .461 .696 r
.67315 .60678 m .6748 .60287 L .67237 .60402 L F
.466 .171 .379 r
.35338 .68062 m .35294 .68286 L .35052 .68304 L F
.471 .175 .381 r
.35506 .6822 m .35338 .68062 L .35587 .68087 L F
.35506 .6822 m .35294 .68286 L .35338 .68062 L F
.864 .537 .43 r
.70403 .5835 m .70535 .58216 L .70366 .58095 L F
.70403 .5835 m .70569 .58427 L .70535 .58216 L F
.836 .872 .87 r
.67716 .60921 m .67962 .6088 L .67874 .60779 L F
.792 .865 .903 r
.67874 .60779 m .67962 .6088 L .68249 .60668 L F
.586 .467 .685 r
.41633 .76007 m .41853 .75987 L .41823 .75723 L F
.462 .357 .65 r
.41633 .76007 m .41844 .76214 L .41853 .75987 L F
.41633 .76007 m .41682 .76286 L .41844 .76214 L F
.807 .318 0 r
.56332 .6878 m .56419 .68822 L .56416 .68818 L F
.56332 .6878 m .56416 .68818 L .56204 .68567 L F
.891 .487 .239 r
.56444 .68712 m .56332 .6878 L .56204 .68567 L F
.28 .725 .962 r
.56332 .6878 m .56373 .68728 L .56212 .68726 L F
.56332 .6878 m .56212 .68726 L .56092 .68724 L F
.807 .318 0 r
.56332 .6878 m .56498 .68908 L .56419 .68822 L F
.891 .487 .239 r
.56444 .68712 m .56498 .68908 L .56332 .6878 L F
0 .009 .551 r
.56775 .74331 m .56845 .74553 L .56761 .74641 L F
.021 .213 .72 r
.56845 .74553 m .5695 .74837 L .56761 .74641 L F
.81 .562 .564 r
.74632 .62003 m .74308 .62228 L .7441 .61901 L F
.74632 .62003 m .74646 .623 L .74308 .62228 L F
.418 .2 .474 r
.50621 .72467 m .50566 .72714 L .50757 .72629 L F
.266 0 0 r
.26813 .60386 m .26841 .60464 L .26642 .60501 L F
.26813 .60386 m .27027 .60384 L .26841 .60464 L F
.663 .655 .831 r
.56142 .69632 m .56006 .69939 L .55894 .69673 L F
.56142 .69632 m .56208 .69872 L .56006 .69939 L F
.645 .638 .829 r
.29422 .72933 m .29337 .73272 L .29215 .72985 L F
.29422 .72933 m .29432 .73263 L .29337 .73272 L F
.876 .479 .277 r
.29432 .73263 m .29188 .73413 L .29337 .73272 L F
.771 .471 .479 r
.52808 .78708 m .52985 .78959 L .53184 .78729 L F
.762 .459 .472 r
.52985 .78959 m .53355 .78991 L .53184 .78729 L F
.915 .959 .801 r
.44025 .65786 m .44095 .65707 L .4417 .65524 L F
.4417 .65524 m .44095 .65707 L .44025 .65786 L F
.679 .473 .601 r
.5919 .73844 m .59247 .7409 L .58878 .74073 L F
.542 .814 .996 r
.58983 .7372 m .59328 .73748 L .5919 .73844 L F
.786 .54 .564 r
.5929 .7403 m .59247 .7409 L .5919 .73844 L F
.355 .305 .663 r
.32694 .66447 m .32863 .66591 L .32885 .66368 L F
.32694 .66447 m .32732 .66685 L .32863 .66591 L F
0 .423 .845 r
.53825 .71974 m .53951 .7209 L .53813 .71852 L F
.53825 .71974 m .54124 .7216 L .53951 .7209 L F
.61 .364 .52 r
.64451 .5247 m .64448 .52666 L .64199 .52691 L F
.541 .309 .512 r
.64679 .52618 m .64448 .52666 L .64451 .5247 L F
.841 .947 .889 r
.64102 .51998 m .63887 .52176 L .63962 .51953 L F
.568 .9 .982 r
.64102 .51998 m .64163 .51899 L .64303 .51894 L F
.64102 .51998 m .63962 .51953 L .64163 .51899 L F
.767 .522 .563 r
.49881 .73747 m .50226 .73545 L .49888 .73511 L F
.49881 .73747 m .50225 .73787 L .50226 .73545 L F
.695 .266 .226 r
.49888 .73511 m .50226 .73545 L .50145 .73726 L F
.838 .963 .888 r
.50413 .73615 m .50145 .73726 L .50226 .73545 L F
.705 .172 0 r
.54509 .73762 m .54791 .74001 L .5463 .74093 L F
.472 .133 .311 r
.33606 .65819 m .33818 .65793 L .33929 .65552 L F
.466 .132 .315 r
.33818 .65793 m .34143 .65518 L .33929 .65552 L F
0 .524 .706 r
.46333 .77049 m .4618 .77035 L .45988 .77018 L F
.458 .862 .69 r
.55635 .68274 m .55737 .68193 L .5588 .68067 L F
.55635 .68274 m .55562 .68306 L .55737 .68193 L F
.692 .495 .616 r
.68084 .58978 m .68396 .58695 L .6809 .58755 L F
.636 .075 0 r
.53112 .74321 m .53529 .74538 L .53291 .74575 L F
0 0 .498 r
.58179 .70443 m .58091 .70557 L .58128 .70465 L F
.744 .405 0 r
.58179 .70443 m .5828 .707 L .58091 .70557 L F
.295 .288 .681 r
.5828 .707 m .58185 .70827 L .58091 .70557 L F
.402 0 0 r
.5327 .79232 m .53121 .79278 L .52879 .79263 L F
.691 .259 .218 r
.5327 .79232 m .53453 .79317 L .53121 .79278 L F
.576 .444 .663 r
.42029 .75187 m .42251 .75155 L .42234 .74919 L F
.566 .377 .585 r
.42029 .75187 m .42249 .75405 L .42251 .75155 L F
.42029 .75187 m .42027 .75442 L .42249 .75405 L F
.429 .11 .321 r
.32131 .61244 m .32266 .61352 L .32073 .61416 L F
.32131 .61244 m .32354 .61201 L .32266 .61352 L F
.526 .363 .603 r
.43586 .65491 m .4386 .65657 L .438 .65418 L F
.642 .34 .443 r
.4425 .73998 m .44494 .74027 L .44584 .7377 L F
.565 .257 .406 r
.44494 .74027 m .44827 .73768 L .44584 .7377 L F
.702 .543 .669 r
.29918 .73061 m .29925 .73288 L .30155 .73055 L F
.618 .793 .966 r
.29918 .73061 m .30155 .73055 L .29819 .73039 L F
.217 .729 .685 r
.69223 .58512 m .68878 .58617 L .69124 .58602 L F
.374 .091 .349 r
.69391 .5861 m .69223 .58512 L .69124 .58602 L F
.5 .296 .535 r
.67621 .59267 m .67932 .59243 L .68014 .59 L F
.475 .319 .589 r
.67703 .59432 m .67932 .59243 L .67621 .59267 L F
.578 .515 .748 r
.29048 .61515 m .29236 .61465 L .2917 .61148 L F
.526 .424 .683 r
.29048 .61515 m .29277 .61696 L .29236 .61465 L F
.29048 .61515 m .29081 .61737 L .29277 .61696 L F
.542 .735 .964 r
.28619 .60866 m .28689 .60689 L .28452 .60677 L F
.28619 .60866 m .28838 .60831 L .28689 .60689 L F
.629 .494 .68 r
.34679 .69135 m .34465 .69391 L .34453 .69185 L F
.903 .707 .628 r
.60866 .68386 m .60828 .68588 L .60698 .68278 L F
.085 0 0 r
.28669 .65304 m .28288 .6542 L .28453 .65333 L F
.92 .921 .538 r
.63842 .52425 m .63962 .51953 L .63887 .52176 L F
.314 .035 .319 r
.29955 .64261 m .29887 .64451 L .29708 .64519 L F
0 0 0 r
.29955 .64261 m .30173 .63961 L .30126 .64195 L F
.289 .011 .307 r
.30126 .64195 m .29887 .64451 L .29955 .64261 L F
.44 .48 .804 r
.35005 .6985 m .34884 .70062 L .34759 .69715 L F
.406 .436 .779 r
.35005 .6985 m .35119 .70186 L .34884 .70062 L F
.748 .684 .79 r
.29107 .72245 m .29183 .72169 L .29064 .72159 L F
.544 .573 .834 r
.51082 .78955 m .50847 .79002 L .50732 .78759 L F
.719 .433 .492 r
.51082 .78955 m .508 .79133 L .50847 .79002 L F
.667 .884 .978 r
.29996 .72983 m .30155 .73055 L .30333 .72956 L F
.435 .056 .22 r
.58562 .666 m .5888 .6637 L .58662 .66423 L F
.683 .367 .435 r
.51343 .73571 m .51052 .73697 L .51149 .73354 L F
.51343 .73571 m .51377 .73745 L .51052 .73697 L F
.712 .387 .426 r
.51727 .73719 m .51377 .73745 L .51343 .73571 L F
.682 .385 .465 r
.52259 .74268 m .52364 .74038 L .52275 .74051 L F
.52259 .74268 m .52565 .74318 L .52364 .74038 L F
.7 .388 .444 r
.52364 .74038 m .52565 .74318 L .5262 .74113 L F
.98 .716 .456 r
.52275 .74051 m .52364 .74038 L .52192 .73754 L F
.726 .655 .78 r
.71823 .60104 m .72041 .60274 L .72103 .59995 L F
.505 .437 .714 r
.72103 .59995 m .72041 .60274 L .72283 .60011 L F
.592 .57 .798 r
.72041 .60274 m .72378 .60346 L .72283 .60011 L F
.418 .119 .349 r
.39711 .70188 m .39447 .70418 L .39517 .70254 L F
.646 .868 .982 r
.48267 .77881 m .48081 .7797 L .47971 .7788 L F
.837 .496 .408 r
.5995 .66914 m .5973 .66674 L .59952 .66695 L F
.866 .903 .856 r
.56666 .75474 m .56308 .75681 L .56492 .75382 L F
.508 .363 .619 r
.56875 .75668 m .5668 .75763 L .56666 .75474 L F
.933 .946 .775 r
.73246 .62935 m .73298 .63056 L .73443 .62759 L F
.633 .07 0 r
.31524 .72645 m .31269 .72574 L .31124 .72435 L F
.534 .357 .587 r
.31755 .72467 m .31702 .72738 L .31524 .72645 L F
.211 0 0 r
.34454 .65337 m .3455 .654 L .34654 .65298 L F
.34454 .65337 m .34344 .65471 L .3455 .654 L F
0 0 0 r
.73087 .71048 m .72612 .71363 L .73026 .71083 L F
.2 .728 .81 r
.73232 .71011 m .73087 .71048 L .73026 .71083 L F
.73232 .71011 m .73331 .71013 L .73087 .71048 L F
.029 0 0 r
.27828 .6391 m .27509 .64258 L .27735 .64192 L F
.332 .008 .257 r
.27828 .6391 m .27929 .64101 L .27915 .63693 L F
.27828 .6391 m .27735 .64192 L .27929 .64101 L F
.651 .581 .763 r
.50225 .73787 m .50333 .74105 L .50103 .74159 L F
.637 .431 .588 r
.60564 .66108 m .60743 .65856 L .60566 .65876 L F
.60564 .66108 m .60744 .66133 L .60743 .65856 L F
.751 .524 .587 r
.60743 .65856 m .60744 .66133 L .61113 .66118 L F
.652 .64 .826 r
.41632 .77569 m .41722 .77698 L .41952 .77642 L F
.538 .538 .802 r
.41722 .77698 m .42024 .77912 L .41952 .77642 L F
0 .242 .748 r
.72672 .62473 m .72719 .62512 L .72524 .62289 L F
.357 .583 .928 r
.743 .58875 m .74174 .58994 L .74106 .58849 L F
.228 .366 .795 r
.743 .58875 m .74437 .59205 L .74174 .58994 L F
.484 .34 .609 r
.74485 .72641 m .74488 .72522 L .7446 .72405 L F
.629 .422 .583 r
.51052 .73697 m .50979 .73524 L .51149 .73354 L F
.653 .438 .579 r
.51812 .74538 m .52051 .74326 L .51867 .74417 L F
.896 .946 .832 r
.5286 .71228 m .53111 .71075 L .5277 .71041 L F
.09 .202 .688 r
.53621 .73506 m .53709 .73815 L .5381 .73704 L F
0 0 0 r
.53709 .73815 m .53588 .73992 L .5381 .73704 L F
.53588 .73992 m .53614 .73961 L .5381 .73704 L F
.625 .263 .336 r
.5381 .73704 m .53471 .73748 L .53621 .73506 L F
0 0 0 r
.53588 .73992 m .53557 .74037 L .53614 .73961 L F
.724 .539 .64 r
.5381 .73704 m .53635 .73934 L .53471 .73748 L F
.53635 .73934 m .53557 .74037 L .535 .73848 L F
.53635 .73934 m .53508 .73853 L .53471 .73748 L F
.635 .492 .671 r
.53471 .73748 m .5357 .73881 L .53508 .73853 L F
.53471 .73748 m .53508 .73853 L .5325 .73735 L F
.724 .539 .64 r
.53508 .73853 m .535 .73848 L .53471 .73748 L F
.587 .22 .313 r
.53621 .73506 m .53471 .73748 L .5325 .73735 L F
.402 .569 .904 r
.53275 .73704 m .5357 .73881 L .53359 .73597 L F
.5325 .73735 m .53508 .73853 L .53275 .73704 L F
.53508 .73853 m .5357 .73881 L .53275 .73704 L F
.284 .381 .786 r
.5357 .73881 m .53682 .73884 L .53585 .7356 L F
.53682 .73884 m .53732 .73885 L .53714 .73846 L F
.53682 .73884 m .53714 .73846 L .53585 .7356 L F
.168 .688 .882 r
.60327 .72715 m .60158 .72677 L .5998 .72683 L F
.938 .614 .394 r
.60327 .72715 m .60273 .72932 L .60158 .72677 L F
.572 .291 .452 r
.45062 .73782 m .45297 .73772 L .45383 .73496 L F
.517 .215 .392 r
.45297 .73772 m .45609 .73493 L .45383 .73496 L F
.194 .078 .483 r
.61742 .71836 m .61567 .72177 L .6162 .71891 L F
.672 .918 .975 r
.51577 .79354 m .51776 .79394 L .5199 .79278 L F
.655 .938 .675 r
.43747 .73864 m .43838 .73731 L .4394 .73776 L F
.302 .212 .585 r
.62089 .70735 m .62121 .70989 L .61919 .71069 L F
0 0 .062 r
.62121 .70989 m .619 .71353 L .61919 .71069 L F
.311 0 .189 r
.39901 .68079 m .39974 .68089 L .40116 .67993 L F
.461 .216 .456 r
.39849 .68291 m .39974 .68089 L .39901 .68079 L F
.452 0 0 r
.73391 .58537 m .73446 .58528 L .73159 .58411 L F
.55 .39 .617 r
.44239 .76048 m .44197 .76263 L .4397 .76297 L F
.652 .418 .552 r
.70722 .58737 m .70932 .58441 L .70569 .58427 L F
.70722 .58737 m .7098 .58665 L .70932 .58441 L F
.749 .708 .814 r
.71357 .5796 m .71092 .58178 L .71013 .57878 L F
.161 .301 .759 r
.71092 .58178 m .7116 .58248 L .71013 .57878 L F
.013 0 .202 r
.71092 .58178 m .71125 .58177 L .7116 .58248 L F
.71125 .58177 m .7125 .58173 L .7116 .58248 L F
.91 .714 .624 r
.70986 .57898 m .71125 .58177 L .70799 .58036 L F
.71125 .58177 m .71109 .58218 L .70799 .58036 L F
.71013 .57878 m .7116 .58248 L .70986 .57898 L F
.718 .531 .636 r
.7125 .58173 m .70799 .58036 L .71109 .58218 L F
.91 .714 .624 r
.71125 .58177 m .7116 .58248 L .71109 .58218 L F
.718 .531 .636 r
.7125 .58173 m .71109 .58218 L .7116 .58248 L F
.013 0 .202 r
.71084 .58226 m .70932 .58441 L .71068 .58327 L F
.71092 .58178 m .71058 .58234 L .71084 .58226 L F
.71058 .58234 m .70932 .58441 L .71084 .58226 L F
.71125 .58177 m .71068 .58327 L .7125 .58173 L F
.71092 .58178 m .71068 .58327 L .71125 .58177 L F
.897 .575 .081 r
.70932 .58441 m .7098 .58665 L .70913 .58574 L F
.70932 .58441 m .70913 .58574 L .7125 .58173 L F
.43 0 0 r
.37834 .64654 m .38172 .64786 L .37992 .64841 L F
.212 0 0 r
.38048 .64762 m .38059 .64764 L .38172 .64786 L F
.421 .861 .916 r
.37992 .64841 m .38172 .64786 L .38245 .64799 L F
.212 0 0 r
.38059 .64764 m .38381 .64842 L .38172 .64786 L F
.421 .861 .916 r
.38245 .64799 m .38172 .64786 L .38312 .64788 L F
.347 0 0 r
.38172 .64786 m .38521 .64821 L .38312 .64788 L F
0 0 .372 r
.50801 .74061 m .50691 .7436 L .50564 .74052 L F
.50801 .74061 m .50787 .74289 L .50691 .7436 L F
.203 .327 .768 r
.50787 .74289 m .50899 .74541 L .50691 .7436 L F
.409 .138 .388 r
.31649 .61747 m .31904 .61499 L .31836 .6169 L F
.284 .02 .326 r
.31836 .6169 m .31904 .61499 L .32073 .61416 L F
.319 .043 .328 r
.29708 .64519 m .29887 .64451 L .2964 .64705 L F
.194 .078 .483 r
.61742 .71836 m .61736 .72075 L .61567 .72177 L F
.131 .034 .468 r
.61736 .72075 m .61572 .72425 L .61567 .72177 L F
.356 .144 .448 r
.27915 .63693 m .28257 .63575 L .28 .63634 L F
.27915 .63693 m .2823 .63825 L .28257 .63575 L F
.417 .16 .414 r
.27915 .63693 m .28126 .64028 L .2823 .63825 L F
.27915 .63693 m .27929 .64101 L .28126 .64028 L F
.258 .644 .964 r
.28088 .59409 m .28041 .59493 L .27898 .59401 L F
.28088 .59409 m .28235 .59518 L .28041 .59493 L F
.659 .613 .792 r
.3194 .73408 m .32144 .733 L .32005 .72946 L F
.572 .004 0 r
.53196 .73106 m .535 .73174 L .53466 .73066 L F
.363 .421 .788 r
.53373 .72635 m .53466 .73066 L .53643 .72868 L F
.553 .57 .826 r
.53621 .73506 m .5328 .73225 L .535 .73174 L F
.52 .553 .83 r
.5369 .73155 m .53621 .73506 L .535 .73174 L F
.613 .179 .192 r
.53338 .73178 m .53625 .73356 L .53644 .73296 L F
.5358 .73162 m .53644 .73296 L .5369 .73155 L F
.459 .42 .727 r
.535 .73174 m .5369 .73155 L .53643 .72868 L F
.613 .179 .192 r
.53338 .73178 m .5369 .73155 L .535 .73174 L F
.53338 .73178 m .53644 .73296 L .5358 .73162 L F
.459 .42 .727 r
.535 .73174 m .53542 .73084 L .53466 .73066 L F
.53542 .73084 m .53643 .72868 L .5351 .73017 L F
.53542 .73084 m .5351 .73017 L .53466 .73066 L F
.614 .631 .845 r
.52626 .75411 m .52933 .75549 L .5287 .75346 L F
.503 .729 .974 r
.52933 .75549 m .53022 .75403 L .5287 .75346 L F
.52933 .75549 m .53168 .75546 L .53022 .75403 L F
.228 .74 .876 r
.4067 .65534 m .40885 .65512 L .41051 .65535 L F
.395 .841 .931 r
.41051 .65535 m .41093 .65461 L .41274 .65484 L F
.41051 .65535 m .40885 .65512 L .41093 .65461 L F
.173 .654 .927 r
.36146 .70634 m .3636 .70654 L .36453 .70704 L F
.02 0 0 r
.3636 .70654 m .36648 .70647 L .36453 .70704 L F
.284 .748 .947 r
.29501 .59667 m .29149 .59635 L .29337 .59619 L F
.459 .847 .982 r
.29667 .59625 m .29501 .59667 L .29337 .59619 L F
.018 .486 .875 r
.57152 .68571 m .57222 .68531 L .57025 .6859 L F
.57152 .68571 m .57318 .68619 L .57222 .68531 L F
.592 .542 .767 r
.57152 .68571 m .57458 .68865 L .57318 .68619 L F
.603 .482 .687 r
.41709 .76542 m .41518 .76826 L .41743 .76789 L F
.514 .496 .775 r
.41518 .76826 m .41794 .77065 L .41743 .76789 L F
.233 .558 .934 r
.73903 .58662 m .73813 .58753 L .73728 .58647 L F
.73903 .58662 m .74106 .58849 L .73813 .58753 L F
.752 .654 .753 r
.53274 .75982 m .536 .76221 L .53611 .76114 L F
.53274 .75982 m .53412 .76322 L .536 .76221 L F
.264 0 0 r
.53853 .75992 m .53611 .76114 L .536 .76221 L F
.674 .329 .382 r
.53164 .72628 m .52741 .72752 L .5296 .72769 L F
.152 0 .008 r
.3754 .703 m .37447 .70419 L .37718 .70227 L F
.488 .081 .195 r
.46624 .73236 m .46855 .7323 L .46963 .73062 L F
.618 .223 .272 r
.46963 .73062 m .46855 .7323 L .47176 .732 L F
.508 .113 .228 r
.59345 .66079 m .59573 .66058 L .59669 .65887 L F
.66 .278 .31 r
.59573 .66058 m .59885 .66067 L .59669 .65887 L F
.328 0 .061 r
.36717 .71871 m .36579 .72054 L .3637 .72093 L F
.184 0 0 r
.36772 .71989 m .36717 .71871 L .36918 .71801 L F
.36772 .71989 m .36579 .72054 L .36717 .71871 L F
.223 0 0 r
.7305 .59304 m .73356 .59327 L .7329 .59352 L F
0 .385 .688 r
.73356 .59327 m .7353 .59379 L .7329 .59352 L F
.73356 .59327 m .73734 .59446 L .7353 .59379 L F
.68 .217 .148 r
.7442 .59424 m .74676 .596 L .74436 .59569 L F
.877 .883 .835 r
.7442 .59424 m .74378 .59638 L .74356 .59573 L F
.74378 .59638 m .74348 .59789 L .74354 .59608 L F
.74378 .59638 m .74354 .59608 L .74356 .59573 L F
0 0 .14 r
.7441 .59328 m .7442 .59424 L .74356 .59573 L F
.877 .883 .835 r
.7442 .59424 m .74198 .59702 L .74348 .59789 L F
.109 .325 .797 r
.74441 .59681 m .74348 .59789 L .74198 .59702 L F
.174 .042 .45 r
.74198 .59702 m .74379 .59742 L .74424 .59697 L F
.74413 .59683 m .74424 .59697 L .74441 .59681 L F
.74198 .59702 m .74424 .59697 L .74413 .59683 L F
.68 .217 .148 r
.7442 .59424 m .74436 .59569 L .74344 .59557 L F
0 0 .14 r
.74437 .59205 m .7442 .59424 L .7441 .59328 L F
.513 .648 .918 r
.70813 .60667 m .70933 .60535 L .70748 .60545 L F
.70813 .60667 m .71083 .60651 L .70933 .60535 L F
0 0 .383 r
.56596 .71585 m .56681 .71909 L .56674 .71806 L F
0 0 .416 r
.56681 .71909 m .56764 .72025 L .56674 .71806 L F
.56681 .71909 m .56796 .72112 L .56764 .72025 L F
.261 .073 .427 r
.30173 .63961 m .30349 .63662 L .30315 .63885 L F
.244 .04 .392 r
.30126 .64195 m .30173 .63961 L .30315 .63885 L F
.852 .598 .553 r
.62499 .68577 m .62508 .688 L .6271 .68727 L F
.893 .729 .671 r
.62508 .688 m .62676 .68941 L .6271 .68727 L F
.59 .45 .659 r
.41805 .75482 m .42048 .75685 L .42027 .75442 L F
.41805 .75482 m .41823 .75723 L .42048 .75685 L F
.425 .264 .557 r
.74685 .6175 m .7441 .61901 L .74749 .61649 L F
.387 .555 .898 r
.74822 .61602 m .74685 .6175 L .74749 .61649 L F
.005 0 .423 r
.74775 .6193 m .74685 .6175 L .74822 .61602 L F
.74775 .6193 m .74686 .6197 L .74685 .6175 L F
.822 .781 .814 r
.69961 .57905 m .69652 .58152 L .69895 .5795 L F
.522 .09 .162 r
.69961 .57905 m .69895 .5795 L .7024 .57889 L F
.417 .181 .446 r
.32279 .67233 m .32049 .67512 L .32263 .67467 L F
.66 .553 .723 r
.32263 .67467 m .32445 .67209 L .32279 .67233 L F
.799 .594 .625 r
.62264 .67475 m .62264 .67237 L .61939 .67196 L F
.796 .995 .871 r
.32074 .72496 m .32036 .72645 L .32219 .72568 L F
.32074 .72496 m .31916 .72645 L .32036 .72645 L F
.331 .01 .26 r
.36344 .67515 m .36277 .67668 L .36083 .6773 L F
.427 .145 .38 r
.36528 .67448 m .36277 .67668 L .36344 .67515 L F
.03 0 0 r
.7101 .71733 m .71084 .71767 L .71186 .71601 L F
.7101 .71733 m .70896 .71826 L .71084 .71767 L F
.36 .599 .938 r
.35329 .702 m .35227 .70315 L .35119 .70186 L F
.35329 .702 m .35465 .70386 L .35227 .70315 L F
.658 .18 .105 r
.48718 .78725 m .49054 .78768 L .48943 .78892 L F
.663 .186 .108 r
.49054 .78768 m .49277 .78936 L .48943 .78892 L F
.967 .936 .66 r
.63842 .52425 m .63707 .52493 L .63811 .52361 L F
.63842 .52425 m .63683 .5269 L .63707 .52493 L F
.859 .658 .629 r
.63856 .52662 m .63683 .5269 L .63842 .52425 L F
.92 .921 .538 r
.63842 .52425 m .63811 .52361 L .63962 .51953 L F
.396 .635 .951 r
.28081 .60433 m .28303 .60634 L .28364 .60504 L F
.222 .422 .846 r
.28303 .60634 m .28452 .60677 L .28364 .60504 L F
.329 .426 .809 r
.56724 .73993 m .56602 .74163 L .56481 .73838 L F
.202 .25 .689 r
.56724 .73993 m .56775 .74331 L .56602 .74163 L F
.301 .471 .862 r
.54287 .72161 m .54297 .7238 L .54124 .7216 L F
.54287 .72161 m .54418 .72289 L .54297 .7238 L F
.251 .376 .796 r
.54418 .72289 m .5437 .72443 L .54297 .7238 L F
.151 0 .15 r
.28531 .63124 m .28282 .6338 L .28443 .63278 L F
.219 .001 .354 r
.28443 .63278 m .287 .62994 L .28531 .63124 L F
.215 0 .08 r
.59582 .66726 m .59444 .66903 L .59302 .66918 L F
.631 .291 .378 r
.59582 .66726 m .59768 .66893 L .59444 .66903 L F
.567 .309 .484 r
.5973 .66674 m .59768 .66893 L .59582 .66726 L F
.645 .638 .829 r
.29422 .72933 m .29612 .73267 L .29432 .73263 L F
.876 .479 .277 r
.29432 .73263 m .2934 .73414 L .29188 .73413 L F
.29432 .73263 m .29526 .7348 L .2934 .73414 L F
.794 .813 .867 r
.53171 .7302 m .53027 .73284 L .5286 .73064 L F
0 0 .17 r
.70506 .59998 m .7054 .60364 L .70492 .60124 L F
0 .296 .793 r
.7054 .60364 m .70615 .60312 L .70492 .60124 L F
.7054 .60364 m .70748 .60545 L .70615 .60312 L F
.588 .453 .665 r
.31572 .69403 m .31774 .69102 L .3155 .6914 L F
.453 .877 .775 r
.59761 .72533 m .59774 .72584 L .59708 .72482 L F
.681 .463 .584 r
.59398 .72462 m .59413 .72696 L .59761 .72533 L F
.453 .877 .775 r
.59761 .72533 m .59708 .72482 L .59398 .72462 L F
.117 .613 .906 r
.43347 .78684 m .43238 .78622 L .42953 .78577 L F
.233 .686 .952 r
.43347 .78684 m .43415 .78622 L .43238 .78622 L F
.43347 .78684 m .43546 .78689 L .43415 .78622 L F
0 0 .156 r
.31097 .72608 m .30946 .72747 L .31124 .72435 L F
.533 .921 .819 r
.30999 .72663 m .30946 .72747 L .31097 .72608 L F
.189 .274 .721 r
.61537 .73768 m .61621 .73959 L .61495 .7408 L F
.082 .044 .51 r
.61621 .73959 m .61508 .74333 L .61495 .7408 L F
.104 0 0 r
.37807 .71494 m .3777 .71397 L .37973 .71337 L F
.37807 .71494 m .37614 .71563 L .3777 .71397 L F
.25 0 0 r
.35192 .65073 m .35409 .65042 L .35498 .6496 L F
0 0 0 r
.35409 .65042 m .35722 .64924 L .35498 .6496 L F
.45 .192 .43 r
.49026 .72124 m .49199 .72324 L .49208 .72093 L F
.49026 .72124 m .49003 .72367 L .49199 .72324 L F
.301 .052 .36 r
.39359 .70646 m .39171 .70516 L .39447 .70418 L F
.39359 .70646 m .39179 .70737 L .39171 .70516 L F
.865 .831 .811 r
.71402 .61119 m .71556 .61252 L .71719 .60974 L F
.469 .708 .973 r
.41433 .65505 m .41344 .65638 L .41274 .65484 L F
.41433 .65505 m .41539 .65615 L .41344 .65638 L F
.204 0 0 r
.45581 .78546 m .45438 .78606 L .4523 .78609 L F
.189 .72 .82 r
.45758 .78583 m .45438 .78606 L .45581 .78546 L F
.086 0 .255 r
.32863 .66591 m .32732 .66685 L .32668 .66896 L F
.692 .495 .616 r
.68084 .58978 m .68371 .58892 L .68396 .58695 L F
.568 .331 .516 r
.68371 .58892 m .68638 .58698 L .68396 .58695 L F
.906 .582 .42 r
.57258 .70753 m .57485 .70959 L .57391 .70753 L F
.57258 .70753 m .573 .70964 L .57485 .70959 L F
.853 .396 .068 r
.573 .70964 m .57589 .71295 L .57485 .70959 L F
.549 .383 .61 r
.34675 .69348 m .34465 .69391 L .34679 .69135 L F
.51 .334 .579 r
.29928 .71935 m .29869 .72252 L .30114 .72166 L F
.653 .779 .941 r
.29836 .72259 m .30122 .72198 L .30114 .72166 L F
.29796 .72273 m .30122 .72198 L .29836 .72259 L F
.51 .334 .579 r
.29869 .72252 m .29864 .72276 L .30114 .72166 L F
.653 .779 .941 r
.29837 .72263 m .30139 .72272 L .30122 .72198 L F
.29796 .72273 m .2981 .72273 L .29837 .72263 L F
.2981 .72273 m .30139 .72272 L .29837 .72263 L F
.599 .417 .606 r
.29618 .72233 m .29807 .72266 L .29928 .71935 L F
.557 .439 .674 r
.29836 .72259 m .29864 .72276 L .29796 .72273 L F
.599 .417 .606 r
.29836 .72259 m .29864 .72276 L .29869 .72252 L F
.557 .439 .674 r
.30114 .72166 m .29864 .72276 L .29836 .72259 L F
.599 .417 .606 r
.29807 .72266 m .29864 .72276 L .29836 .72259 L F
.29807 .72266 m .29869 .72252 L .29928 .71935 L F
.528 .584 .854 r
.29796 .72273 m .29864 .72276 L .29618 .72233 L F
.915 .959 .801 r
.44025 .65786 m .43988 .65533 L .4386 .65657 L F
.44025 .65786 m .4417 .65524 L .43988 .65533 L F
.558 .519 .767 r
.57533 .74364 m .57737 .74322 L .57679 .73995 L F
.481 .251 .488 r
.38984 .69144 m .39189 .69102 L .39228 .68885 L F
.46 .25 .507 r
.39189 .69102 m .39402 .68831 L .39228 .68885 L F
.627 .625 .828 r
.71078 .72446 m .71428 .72667 L .71363 .7253 L F
.589 .582 .813 r
.71428 .72667 m .71547 .72368 L .71363 .7253 L F
.71428 .72667 m .71674 .72643 L .71547 .72368 L F
.549 .26 .43 r
.45609 .73493 m .45834 .73481 L .45883 .73294 L F
.592 .332 .492 r
.45834 .73481 m .46089 .73246 L .45883 .73294 L F
.553 .288 .468 r
.59444 .66903 m .5924 .67153 L .59302 .66918 L F
.86 .843 .826 r
.57479 .70475 m .57258 .70753 L .57391 .70753 L F
.259 0 .208 r
.29374 .64932 m .29465 .6478 L .2964 .64705 L F
.876 .818 .788 r
.6835 .60266 m .68657 .60102 L .68557 .60008 L F
.6835 .60266 m .6846 .60384 L .68657 .60102 L F
.681 .874 .971 r
.68557 .60008 m .68657 .60102 L .68908 .5996 L F
.039 0 0 r
.57339 .67183 m .57347 .67217 L .57535 .67116 L F
.768 .756 .842 r
.48296 .7467 m .48404 .74702 L .48281 .74564 L F
.536 .401 .643 r
.48404 .74702 m .48607 .74891 L .4871 .74603 L F
.565 .337 .528 r
.56188 .7477 m .55938 .74933 L .55863 .746 L F
.56188 .7477 m .56299 .74932 L .55938 .74933 L F
.175 .004 .395 r
.56076 .75055 m .55938 .74933 L .56299 .74932 L F
.56076 .75055 m .5592 .75133 L .55938 .74933 L F
.509 .309 .544 r
.43061 .66933 m .42821 .6722 L .42826 .6698 L F
.621 .593 .8 r
.42392 .66463 m .42027 .66186 L .42245 .66173 L F
.6 .62 .842 r
.42581 .66415 m .42392 .66463 L .42245 .66173 L F
.45 .379 .686 r
.29081 .61737 m .29285 .6192 L .29277 .61696 L F
.29081 .61737 m .2915 .61925 L .29285 .6192 L F
.088 0 0 r
.57347 .67217 m .57141 .67293 L .57043 .67381 L F
.33 .066 .354 r
.31412 .62013 m .31649 .61747 L .31607 .61956 L F
.449 .215 .466 r
.31836 .6169 m .31607 .61956 L .31649 .61747 L F
0 0 0 r
.55719 .74043 m .55869 .74022 L .55814 .74014 L F
.55814 .74014 m .55869 .74022 L .56058 .73918 L F
.5 .29 .526 r
.38984 .69144 m .39167 .6935 L .39189 .69102 L F
.38984 .69144 m .3896 .69398 L .39167 .6935 L F
.313 .523 .899 r
.56782 .6903 m .56676 .69149 L .56498 .68908 L F
0 0 0 r
.56782 .6903 m .5655 .69315 L .56676 .69149 L F
.849 .399 .135 r
.30256 .71658 m .30496 .71854 L .30665 .71616 L F
.764 .659 .747 r
.53062 .76254 m .53412 .76322 L .53274 .75982 L F
.844 .848 .847 r
.53064 .76512 m .53412 .76322 L .53062 .76254 L F
.544 .409 .647 r
.32063 .67753 m .32263 .67467 L .32049 .67512 L F
.924 .712 .599 r
.60827 .68825 m .60956 .68903 L .60967 .69136 L F
.585 .603 .837 r
.41757 .65572 m .41676 .65907 L .41539 .65615 L F
.41757 .65572 m .41898 .65856 L .41676 .65907 L F
.068 0 0 r
.73722 .60803 m .73868 .60815 L .73712 .60804 L F
.73712 .60804 m .73868 .60815 L .73722 .60803 L F
.722 .252 .133 r
.48812 .78364 m .49144 .78441 L .48922 .78259 L F
.148 0 0 r
.44468 .78576 m .44314 .78623 L .44075 .78638 L F
.405 0 0 r
.44643 .78625 m .44314 .78623 L .44468 .78576 L F
.524 .735 .97 r
.27181 .59195 m .27132 .59363 L .26987 .59192 L F
.27181 .59195 m .27329 .59328 L .27132 .59363 L F
.453 .125 .319 r
.30679 .70876 m .3098 .70726 L .30769 .70749 L F
.849 .399 .135 r
.30256 .71658 m .30384 .71866 L .30496 .71854 L F
.84 .397 0 r
.30513 .7201 m .30496 .71854 L .30384 .71866 L F
.291 .72 .97 r
.30275 .59703 m .3009 .5971 L .29915 .59628 L F
.807 .749 .798 r
.69362 .59504 m .69147 .59773 L .69462 .59786 L F
.785 .795 .861 r
.69147 .59773 m .6925 .5989 L .69462 .59786 L F
.702 .694 .84 r
.69362 .59504 m .69462 .59786 L .69677 .59555 L F
.617 .433 .61 r
.5282 .76277 m .53062 .76254 L .53043 .76008 L F
.599 .457 .659 r
.53043 .76008 m .53274 .75982 L .53255 .75735 L F
.59 .412 .609 r
.53043 .76008 m .53062 .76254 L .53274 .75982 L F
.636 .701 .893 r
.58878 .74073 m .59247 .7409 L .59254 .74158 L F
.969 .906 .697 r
.59254 .74158 m .59247 .7409 L .5929 .7403 L F
.463 .135 .324 r
.28691 .62776 m .28888 .62733 L .28975 .62572 L F
.894 .848 .791 r
.2914 .6225 m .28975 .62572 L .29009 .62386 L F
.33 .148 .475 r
.28888 .62733 m .29009 .62386 L .28975 .62572 L F
.341 .792 .951 r
.55568 .78465 m .55464 .78427 L .55222 .78456 L F
.55222 .78456 m .55464 .78427 L .55568 .78465 L F
.481 .735 .983 r
.52068 .76797 m .52397 .76863 L .52285 .76781 L F
.646 .784 .948 r
.52285 .76781 m .52397 .76863 L .52618 .76821 L F
.656 .217 .195 r
.72267 .6199 m .72751 .62087 L .72564 .61939 L F
.184 0 0 r
.4614 .78521 m .46033 .78579 L .45758 .78583 L F
.592 .089 .027 r
.46383 .7859 m .46033 .78579 L .4614 .78521 L F
.516 .542 .82 r
.42168 .65997 m .42027 .66186 L .41898 .65856 L F
.541 .576 .839 r
.42168 .65997 m .42245 .66173 L .42027 .66186 L F
.937 .893 .76 r
.60955 .6938 m .60938 .69603 L .60736 .69646 L F
.851 .702 .696 r
.60736 .69646 m .60938 .69603 L .60887 .69966 L F
.219 .332 .767 r
.58132 .75712 m .58249 .75616 L .58028 .7541 L F
.262 .409 .822 r
.58132 .75712 m .58367 .75887 L .58249 .75616 L F
.331 .041 .313 r
.38765 .69459 m .3889 .69567 L .3896 .69398 L F
.38765 .69459 m .38703 .69638 L .3889 .69567 L F
.463 .254 .51 r
.31412 .62013 m .31574 .62172 L .31386 .62237 L F
.31412 .62013 m .31607 .61956 L .31574 .62172 L F
.43 .822 .986 r
.31022 .59799 m .30952 .59894 L .30801 .59825 L F
.31022 .59799 m .31153 .59856 L .30952 .59894 L F
.257 0 .214 r
.28 .63634 m .28257 .63575 L .28282 .6338 L F
.201 0 .2 r
.28282 .6338 m .28373 .63518 L .28443 .63278 L F
.28282 .6338 m .28257 .63575 L .28373 .63518 L F
.749 .735 .84 r
.2961 .7273 m .29819 .73039 L .29422 .72933 L F
.786 .692 .761 r
.29819 .73039 m .29612 .73267 L .29422 .72933 L F
.804 .75 .802 r
.2999 .72786 m .29819 .73039 L .2961 .7273 L F
.213 0 .2 r
.29996 .72983 m .29697 .73212 L .29819 .73039 L F
.053 0 .079 r
.29697 .73212 m .29612 .73267 L .29819 .73039 L F
.822 .984 .882 r
.30166 .71733 m .29928 .71935 L .29945 .71784 L F
.51 .334 .579 r
.29928 .71935 m .30114 .72166 L .29945 .71784 L F
.732 .408 .432 r
.29945 .71784 m .30256 .71658 L .30166 .71733 L F
.031 .377 .842 r
.72719 .62512 m .7277 .62437 L .72524 .62289 L F
0 .327 .812 r
.72719 .62512 m .72921 .62643 L .7277 .62437 L F
.448 .109 .298 r
.36203 .67927 m .36083 .6773 L .36277 .67668 L F
.36203 .67927 m .35981 .67974 L .36083 .6773 L F
0 0 .432 r
.74432 .72831 m .74485 .72641 L .74542 .72676 L F
0 0 .482 r
.7446 .72405 m .74542 .72676 L .74485 .72641 L F
.493 .153 .318 r
.31269 .72574 m .31097 .72608 L .31124 .72435 L F
.358 .498 .863 r
.70723 .72176 m .71004 .72305 L .7088 .72051 L F
.829 .614 .612 r
.60788 .6631 m .61113 .66118 L .60744 .66133 L F
.60788 .6631 m .61126 .6639 L .61113 .66118 L F
.726 .627 .747 r
.58691 .73206 m .58975 .73258 L .58808 .73499 L F
.573 0 0 r
.58711 .73394 m .58823 .73453 L .58842 .73432 L F
.629 .842 .453 r
.58808 .73499 m .58883 .7339 L .58842 .73432 L F
0 .053 .62 r
.58842 .73432 m .58983 .7372 L .58808 .73499 L F
.28 .428 .832 r
.58854 .73456 m .59099 .736 L .58983 .7372 L F
.58842 .73432 m .58899 .73469 L .58854 .73456 L F
.58899 .73469 m .59099 .736 L .58854 .73456 L F
.573 0 0 r
.58823 .73453 m .59099 .736 L .58842 .73432 L F
.66 .301 .353 r
.59222 .73269 m .59322 .73465 L .58975 .73258 L F
.37 .448 .811 r
.58975 .73258 m .59322 .73465 L .59114 .73144 L F
.349 .176 .5 r
.5942 .73414 m .59222 .73269 L .59485 .73217 L F
.5942 .73414 m .59322 .73465 L .59308 .73437 L F
.59356 .73367 m .59308 .73437 L .59222 .73269 L F
.5942 .73414 m .59308 .73437 L .59356 .73367 L F
.509 .512 .795 r
.59342 .73346 m .59322 .73465 L .5942 .73414 L F
.59114 .73144 m .593 .73432 L .59342 .73346 L F
.593 .73432 m .59322 .73465 L .59342 .73346 L F
.59114 .73144 m .59304 .73312 L .59266 .73352 L F
.59304 .73312 m .5942 .73414 L .59341 .73382 L F
.59304 .73312 m .59341 .73382 L .59266 .73352 L F
.59114 .73144 m .59266 .73352 L .59329 .73313 L F
.59266 .73174 m .59329 .73313 L .59485 .73217 L F
.59114 .73144 m .59329 .73313 L .59266 .73174 L F
.873 .994 .768 r
.59438 .73246 m .59266 .73352 L .59481 .73182 L F
.755 .518 .574 r
.59776 .73199 m .5942 .73414 L .59485 .73217 L F
.59776 .73199 m .59769 .7344 L .5942 .73414 L F
.949 .636 .202 r
.59555 .73757 m .5942 .73414 L .59769 .7344 L F
0 0 .44 r
.59381 .73426 m .59467 .73464 L .59406 .73227 L F
.737 .615 .722 r
.59373 .73486 m .59266 .73352 L .5942 .73414 L F
0 0 .44 r
.59377 .73451 m .59393 .73453 L .59381 .73426 L F
.946 .605 .341 r
.5942 .73414 m .59423 .7345 L .59373 .73486 L F
.59423 .7345 m .59444 .73659 L .59373 .73486 L F
.78 .577 .625 r
.58986 .73959 m .59328 .73748 L .58983 .7372 L F
.58986 .73959 m .59334 .74016 L .59328 .73748 L F
.641 .319 .41 r
.59328 .73748 m .59531 .73931 L .59555 .73757 L F
.484 .343 .613 r
.59328 .73748 m .59334 .74016 L .59531 .73931 L F
.639 .576 .767 r
.59427 .7386 m .59099 .736 L .59373 .73486 L F
.478 .281 .533 r
.5921 .73596 m .59238 .73582 L .59373 .73486 L F
.949 .636 .202 r
.59555 .73757 m .59444 .73659 L .59423 .7345 L F
.59431 .73443 m .59423 .7345 L .5942 .73414 L F
.59555 .73757 m .59423 .7345 L .59431 .73443 L F
.478 .281 .533 r
.59238 .73582 m .59321 .73539 L .59373 .73486 L F
.604 .483 .688 r
.59444 .73659 m .59427 .7386 L .59373 .73486 L F
.478 .281 .533 r
.59321 .73539 m .59467 .73464 L .59385 .73483 L F
.59321 .73539 m .59385 .73483 L .59373 .73486 L F
0 0 .44 r
.59393 .73453 m .59467 .73464 L .59381 .73426 L F
.59373 .73486 m .59394 .73481 L .59377 .73451 L F
.59394 .73481 m .59467 .73464 L .59377 .73451 L F
.873 .994 .768 r
.59471 .73082 m .59266 .73352 L .59469 .73065 L F
.59481 .73182 m .59385 .73257 L .59471 .73082 L F
.59385 .73257 m .59266 .73352 L .59471 .73082 L F
.59485 .73217 m .59438 .73246 L .59481 .73182 L F
.737 .615 .722 r
.59266 .73352 m .59099 .736 L .59373 .73486 L F
.59373 .73486 m .59099 .736 L .59266 .73352 L F
.573 0 0 r
.58711 .73394 m .58979 .73575 L .59099 .736 L F
.425 0 0 r
.58979 .73575 m .59373 .73486 L .59099 .736 L F
.59139 .73539 m .59248 .73571 L .59373 .73486 L F
.58979 .73575 m .59248 .73571 L .59139 .73539 L F
.478 .281 .533 r
.5921 .73596 m .59432 .73696 L .59467 .73464 L F
.292 .394 .795 r
.59331 .73394 m .5942 .7366 L .5921 .73596 L F
.5942 .7366 m .59432 .73696 L .5921 .73596 L F
.425 0 0 r
.59133 .73573 m .5921 .73596 L .59248 .73571 L F
.58979 .73575 m .5921 .73596 L .59133 .73573 L F
.629 .842 .453 r
.58883 .7339 m .58975 .73258 L .58842 .73432 L F
.504 .341 .594 r
.32894 .66122 m .33072 .66294 L .33095 .66077 L F
.32894 .66122 m .32885 .66368 L .33072 .66294 L F
.474 .169 .368 r
.42091 .68044 m .41828 .68262 L .41868 .68086 L F
.955 .862 .707 r
.51095 .73136 m .50979 .73524 L .51007 .7328 L F
.081 0 0 r
.36942 .70561 m .3716 .70535 L .37263 .70495 L F
0 0 0 r
.37263 .70495 m .37373 .70479 L .37447 .70419 L F
.37263 .70495 m .3716 .70535 L .37373 .70479 L F
.447 .128 .331 r
.52565 .74318 m .52845 .74082 L .5262 .74113 L F
.525 .393 .643 r
.31885 .68036 m .32093 .68244 L .32064 .67993 L F
.31885 .68036 m .31901 .68298 L .32093 .68244 L F
.508 .483 .764 r
.44411 .77115 m .44649 .77264 L .44475 .77285 L F
.669 .685 .856 r
.69918 .59489 m .7003 .5976 L .70256 .59566 L F
.288 0 0 r
.45571 .77676 m .45669 .7766 L .45334 .77635 L F
.037 .586 .834 r
.45799 .77651 m .45669 .7766 L .45571 .77676 L F
.45799 .77651 m .45911 .7769 L .45669 .7766 L F
.796 .405 .313 r
.56608 .70414 m .56975 .70566 L .56799 .70399 L F
.277 0 0 r
.35417 .725 m .35345 .72576 L .35141 .7261 L F
.263 0 0 r
.35572 .72521 m .35417 .725 L .3564 .72454 L F
.35572 .72521 m .35345 .72576 L .35417 .725 L F
.547 .355 .573 r
.44633 .75693 m .44412 .75983 L .44434 .75729 L F
.792 .865 .903 r
.67874 .60779 m .68249 .60668 L .68145 .60583 L F
.892 .905 .829 r
.68145 .60583 m .68249 .60668 L .6846 .60384 L F
.479 0 0 r
.54807 .72581 m .55191 .72647 L .55053 .72584 L F
.635 .113 0 r
.55021 .7265 m .55355 .72729 L .55191 .72647 L F
.329 .454 .836 r
.73894 .71162 m .73612 .71148 L .73542 .71049 L F
.73894 .71162 m .73885 .71275 L .73612 .71148 L F
.131 0 0 r
.64529 .51854 m .64757 .51854 L .64899 .51828 L F
.568 0 0 r
.64757 .51854 m .6491 .51799 L .64899 .51828 L F
.18 .186 .629 r
.65054 .52031 m .64899 .51828 L .6491 .51799 L F
.555 .28 .454 r
.65211 .52305 m .64948 .5218 L .65054 .52031 L F
.704 .579 .713 r
.65462 .52296 m .65211 .52305 L .65054 .52031 L F
.269 .691 .967 r
.64999 .52053 m .65209 .52115 L .65054 .52031 L F
.704 .579 .713 r
.65462 .52296 m .65054 .52031 L .65355 .52157 L F
.269 .691 .967 r
.65209 .52115 m .65355 .52157 L .65054 .52031 L F
.18 .186 .629 r
.65054 .52031 m .64948 .5218 L .64917 .51957 L F
.65054 .52031 m .64917 .51957 L .64899 .51828 L F
.847 .778 .784 r
.74348 .59789 m .74239 .60085 L .74159 .6002 L F
.685 .167 0 r
.74239 .60085 m .74327 .60219 L .74159 .6002 L F
.48 .367 .649 r
.74348 .59789 m .74594 .59986 L .74239 .60085 L F
.613 .407 .579 r
.74594 .59986 m .74327 .60219 L .74239 .60085 L F
.265 0 .176 r
.74014 .60895 m .74204 .60848 L .74147 .60798 L F
.464 .786 .999 r
.56276 .73388 m .56651 .73456 L .56507 .73514 L F
.45 .831 .989 r
.56507 .73514 m .56651 .73456 L .56403 .73541 L F
0 .029 .553 r
.56574 .73748 m .56403 .73541 L .56651 .73456 L F
.56574 .73748 m .56481 .73838 L .56403 .73541 L F
.104 0 .272 r
.56394 .77556 m .56265 .77672 L .5646 .7736 L F
.5646 .7736 m .56265 .77672 L .56394 .77556 L F
.56394 .77556 m .56265 .77672 L .5646 .7736 L F
.696 .853 .958 r
.56112 .77566 m .56265 .77672 L .56394 .77556 L F
.56394 .77556 m .56265 .77672 L .56112 .77566 L F
.716 .857 .434 r
.60604 .71039 m .60637 .70951 L .60743 .7079 L F
.965 .798 .365 r
.60743 .7079 m .60697 .70727 L .60728 .70488 L F
.974 .876 .497 r
.60743 .7079 m .60637 .70951 L .60697 .70727 L F
.888 .878 .819 r
.31731 .71877 m .3208 .71658 L .32083 .71591 L F
.354 .417 .788 r
.3208 .71658 m .32204 .71524 L .32083 .71591 L F
.3208 .71658 m .32253 .71648 L .32204 .71524 L F
.674 .329 .382 r
.53164 .72628 m .52866 .72955 L .52741 .72752 L F
.353 0 .13 r
.53232 .72883 m .53164 .72628 L .53373 .72635 L F
.53173 .72661 m .52866 .72955 L .53164 .72628 L F
.52923 .72944 m .52866 .72955 L .53173 .72661 L F
0 .022 .583 r
.52741 .72752 m .52866 .72955 L .52776 .72721 L F
.794 .813 .867 r
.53171 .7302 m .5286 .73064 L .53196 .73106 L F
.367 .054 .296 r
.5286 .73064 m .53013 .73137 L .53196 .73106 L F
.579 .418 .628 r
.53228 .73049 m .52944 .72975 L .53232 .72883 L F
.52944 .72975 m .52866 .72955 L .52923 .72944 L F
.52944 .72975 m .52923 .72944 L .53232 .72883 L F
.583 .576 .811 r
.52911 .72958 m .52776 .72721 L .52781 .72732 L F
.52911 .72958 m .52781 .72732 L .52866 .72955 L F
.579 .418 .628 r
.53228 .73049 m .53013 .73137 L .52866 .72955 L F
.583 .576 .811 r
.53013 .73137 m .52911 .72958 L .52866 .72955 L F
.52911 .72958 m .52692 .72866 L .52775 .72723 L F
.52791 .72746 m .52775 .72723 L .52776 .72721 L F
.52911 .72958 m .52775 .72723 L .52791 .72746 L F
.53013 .73137 m .52864 .73011 L .52911 .72958 L F
.52864 .73011 m .52692 .72866 L .52911 .72958 L F
.353 0 .13 r
.53232 .72883 m .52923 .72944 L .53173 .72661 L F
.423 0 0 r
.45099 .75876 m .44836 .75904 L .44977 .75772 L F
.384 .797 .979 r
.28235 .59518 m .2844 .5949 L .28593 .59543 L F
.298 .656 .971 r
.28637 .59443 m .28593 .59543 L .2844 .5949 L F
.28637 .59443 m .28773 .59556 L .28593 .59543 L F
.555 .522 .773 r
.58451 .72322 m .5822 .72543 L .58189 .72263 L F
.141 0 .298 r
.58451 .72322 m .58257 .72651 L .5822 .72543 L F
0 0 .533 r
.57787 .71477 m .57702 .71409 L .57589 .71295 L F
.57787 .71477 m .57852 .71602 L .57702 .71409 L F
0 0 0 r
.71186 .71601 m .71259 .71563 L .71411 .7138 L F
.71186 .71601 m .71084 .71767 L .71259 .71563 L F
.837 .496 .408 r
.5995 .66914 m .59768 .66893 L .5973 .66674 L F
.839 .997 .766 r
.74432 .72831 m .74204 .73099 L .74377 .73006 L F
.566 .337 .528 r
.56422 .74857 m .56299 .74932 L .56188 .7477 L F
.549 .368 .588 r
.42821 .6722 m .42819 .67452 L .42604 .67488 L F
.524 .27 .473 r
.42792 .67667 m .42604 .67488 L .42819 .67452 L F
.42792 .67667 m .42573 .67707 L .42604 .67488 L F
.028 .598 .762 r
.2643 .59004 m .26364 .59003 L .26172 .58995 L F
.671 .59 .756 r
.67249 .61264 m .67458 .61159 L .67358 .60844 L F
0 0 0 r
.55719 .74043 m .55592 .74183 L .55869 .74022 L F
.419 .271 .573 r
.34872 .68845 m .34679 .69135 L .3465 .69012 L F
.836 .729 .747 r
.50979 .73524 m .50786 .73765 L .50667 .73467 L F
.629 .422 .583 r
.51052 .73697 m .50786 .73765 L .50979 .73524 L F
.668 .455 .586 r
.40116 .67993 m .40372 .68008 L .40379 .67773 L F
.212 .369 .804 r
.40243 .67467 m .40379 .67773 L .40455 .67652 L F
.096 0 .442 r
.40379 .67773 m .40489 .67888 L .40455 .67652 L F
.40379 .67773 m .40372 .68008 L .40489 .67888 L F
0 0 0 r
.49098 .75125 m .49397 .74893 L .49 .74858 L F
.658 .437 .573 r
.49397 .74893 m .49366 .75154 L .49098 .75125 L F
0 0 0 r
.49098 .75125 m .49215 .75065 L .49397 .74893 L F
.966 .74 .546 r
.49215 .75065 m .49366 .75154 L .49397 .74893 L F
.529 .634 .898 r
.58794 .76268 m .58913 .76133 L .58642 .75972 L F
.58794 .76268 m .59041 .76254 L .58913 .76133 L F
.202 0 0 r
.29195 .64993 m .29253 .65107 L .29057 .65168 L F
.29195 .64993 m .29374 .64932 L .29253 .65107 L F
.886 .737 .691 r
.55999 .69077 m .56074 .69406 L .56192 .69135 L F
.938 .952 .633 r
.56092 .68724 m .55999 .69077 L .56168 .68917 L F
.56105 .68733 m .56168 .68917 L .56255 .68835 L F
.56092 .68724 m .56168 .68917 L .56105 .68733 L F
.77 .997 .837 r
.56255 .68835 m .55999 .69077 L .56038 .69031 L F
.78 .761 .836 r
.56092 .68724 m .56255 .68835 L .56319 .68777 L F
.77 .997 .837 r
.56255 .68835 m .56038 .69031 L .56246 .68777 L F
.78 .761 .836 r
.56319 .68777 m .56255 .68835 L .56332 .6878 L F
.397 .534 .876 r
.56207 .69034 m .56321 .69179 L .56246 .68777 L F
.56192 .69135 m .56248 .69154 L .56207 .69034 L F
.56248 .69154 m .56321 .69179 L .56207 .69034 L F
.734 .852 .936 r
.56246 .68777 m .55999 .69077 L .56192 .69135 L F
.522 .598 .871 r
.30259 .72385 m .30447 .72343 L .30139 .72272 L F
.562 .536 .783 r
.30259 .72385 m .30585 .72626 L .30447 .72343 L F
.889 .85 .799 r
.62432 .69007 m .62676 .68941 L .62508 .688 L F
.62432 .69007 m .62569 .69088 L .62676 .68941 L F
.738 .559 .651 r
.47613 .77624 m .47882 .77635 L .47846 .77364 L F
.784 .661 .728 r
.55402 .73517 m .55075 .73555 L .55282 .73263 L F
.691 .477 .592 r
.55402 .73517 m .55014 .73755 L .55075 .73555 L F
.55402 .73517 m .55341 .73764 L .55014 .73755 L F
.472 .165 .363 r
.55564 .73578 m .55341 .73764 L .55402 .73517 L F
.425 0 0 r
.74204 .60848 m .7457 .60813 L .74147 .60798 L F
.515 .172 .323 r
.47176 .732 m .47395 .73205 L .47505 .72946 L F
.519 .197 .362 r
.47395 .73205 m .47727 .72914 L .47505 .72946 L F
.836 .65 .652 r
.62279 .67734 m .62406 .67774 L .62264 .67475 L F
.82 .599 .603 r
.62279 .67734 m .62406 .68011 L .62406 .67774 L F
0 0 0 r
.5929 .7403 m .59247 .7409 L .59334 .74016 L F
.28 0 .148 r
.38698 .7096 m .3849 .71035 L .38768 .70835 L F
.375 .005 .201 r
.38913 .70912 m .38768 .70835 L .38968 .70785 L F
.38913 .70912 m .38698 .7096 L .38768 .70835 L F
.303 .682 .976 r
.45117 .77538 m .44772 .77445 L .44986 .77398 L F
.437 .566 .886 r
.45208 .77385 m .45117 .77538 L .44986 .77398 L F
.45208 .77385 m .45334 .77635 L .45117 .77538 L F
.548 .372 .595 r
.35277 .68524 m .35052 .68304 L .35294 .68286 L F
.35277 .68524 m .35096 .68614 L .35052 .68304 L F
.78 .511 .529 r
.61126 .6639 m .61447 .66637 L .61458 .66395 L F
.735 .9 .953 r
.68908 .5996 m .6925 .5989 L .69147 .59773 L F
.335 0 0 r
.34379 .7296 m .34266 .73023 L .34039 .73018 L F
.47 0 .053 r
.34601 .72948 m .34266 .73023 L .34379 .7296 L F
.874 .622 .555 r
.60693 .68054 m .60446 .682 L .60518 .68028 L F
.60693 .68054 m .60698 .68278 L .60446 .682 L F
.755 .487 .527 r
.47309 .77713 m .47613 .77624 L .47383 .7766 L F
0 0 0 r
.56868 .67485 m .57013 .67423 L .57043 .67381 L F
.56868 .67485 m .56748 .67632 L .57013 .67423 L F
.812 .496 .455 r
.52845 .74082 m .53112 .74321 L .53102 .74076 L F
0 0 .453 r
.71843 .6056 m .71989 .6084 L .7189 .60674 L F
.524 .493 .764 r
.44519 .76757 m .44411 .77115 L .44311 .76795 L F
.44519 .76757 m .44616 .77086 L .44411 .77115 L F
.523 .48 .75 r
.44616 .77086 m .44649 .77264 L .44411 .77115 L F
.163 0 .309 r
.30349 .63662 m .30543 .63372 L .30516 .63596 L F
.371 .167 .469 r
.30315 .63885 m .30349 .63662 L .30516 .63596 L F
.892 .905 .829 r
.68145 .60583 m .6846 .60384 L .6835 .60266 L F
.543 .127 .203 r
.69895 .5795 m .7014 .58067 L .7024 .57889 L F
.854 .496 .372 r
.7024 .57889 m .7014 .58067 L .70366 .58095 L F
.552 .328 .528 r
.42437 .74564 m .42659 .74558 L .42701 .7432 L F
.531 .309 .522 r
.42701 .7432 m .42882 .74478 L .42919 .74318 L F
.42701 .7432 m .42659 .74558 L .42882 .74478 L F
.582 .817 .988 r
.71944 .58564 m .72056 .58665 L .71804 .58725 L F
.71944 .58564 m .72056 .58665 L .71804 .58725 L F
.748 .706 .812 r
.56452 .69651 m .56208 .69872 L .56142 .69632 L F
.581 .558 .793 r
.52492 .74888 m .52617 .74555 L .52362 .74581 L F
.52492 .74888 m .52729 .74855 L .52617 .74555 L F
.825 .739 .769 r
.5653 .7515 m .5623 .75126 L .56422 .74857 L F
.817 .648 .673 r
.56492 .75382 m .5623 .75126 L .5653 .7515 L F
.763 .71 .802 r
.56862 .74912 m .5653 .7515 L .56422 .74857 L F
.538 .408 .651 r
.31479 .70489 m .31672 .70182 L .3148 .70263 L F
.585 .4 .597 r
.52584 .76585 m .52837 .76535 L .5282 .76277 L F
.695 .483 .596 r
.5282 .76277 m .53064 .76512 L .53062 .76254 L F
.5282 .76277 m .52837 .76535 L .53064 .76512 L F
.62 .194 .212 r
.57657 .68574 m .57318 .68619 L .57458 .68865 L F
.544 .453 .701 r
.55109 .74077 m .54944 .7436 L .54791 .74001 L F
.55109 .74077 m .5516 .74335 L .54944 .7436 L F
.58 .647 .881 r
.44986 .77398 m .44772 .77445 L .44649 .77264 L F
.555 .28 .454 r
.65211 .52305 m .64942 .52355 L .64948 .5218 L F
.278 .725 .96 r
.3098 .70726 m .31136 .70723 L .31323 .70784 L F
.569 .471 .704 r
.31323 .70784 m .31479 .70489 L .31268 .70561 L F
.31323 .70784 m .31532 .70744 L .31479 .70489 L F
.73 .44 .488 r
.31158 .70935 m .31323 .70784 L .31136 .70723 L F
.31158 .70935 m .31532 .70744 L .31323 .70784 L F
.374 .557 .905 r
.39462 .81947 m .39726 .82154 L .3965 .81964 L F
.668 .816 .954 r
.39726 .82154 m .39862 .8193 L .3965 .81964 L F
.886 .895 .831 r
.7327 .5898 m .7305 .59304 L .72897 .5921 L F
.259 0 0 r
.72997 .5935 m .7305 .59304 L .7329 .59352 L F
.718 .714 .845 r
.72378 .60346 m .72717 .60363 L .72664 .60083 L F
.744 .599 .695 r
.72378 .60346 m .72517 .60657 L .72717 .60363 L F
.223 .644 .956 r
.26834 .59095 m .26806 .59175 L .26612 .58983 L F
.26834 .59095 m .26987 .59192 L .26806 .59175 L F
.414 .16 .417 r
.39615 .68527 m .39849 .68291 L .39647 .68339 L F
.851 .702 .696 r
.60736 .69646 m .60887 .69966 L .60747 .6989 L F
.968 .752 .557 r
.60887 .69966 m .60858 .70204 L .60747 .6989 L F
0 0 0 r
.6227 .70438 m .62089 .70735 L .62168 .7055 L F
.447 .195 .439 r
.53621 .73506 m .53823 .73476 L .53858 .73276 L F
.484 .784 .998 r
.53858 .73276 m .54063 .73254 L .5369 .73155 L F
.505 .247 .457 r
.53858 .73276 m .54029 .7344 L .54063 .73254 L F
.53858 .73276 m .53823 .73476 L .54029 .7344 L F
.553 .693 .933 r
.71004 .72305 m .71078 .72446 L .71243 .72287 L F
.464 .541 .85 r
.71078 .72446 m .71363 .7253 L .71243 .72287 L F
.076 0 0 r
.50819 .70615 m .51185 .70509 L .50969 .70542 L F
.506 .303 .539 r
.58878 .74073 m .59073 .74204 L .58875 .74318 L F
.58878 .74073 m .59073 .74204 L .58875 .74318 L F
.509 .309 .544 r
.43061 .66933 m .43031 .67171 L .42821 .6722 L F
.505 .325 .57 r
.43031 .67171 m .42819 .67452 L .42821 .6722 L F
.443 .284 .569 r
.31347 .62449 m .31187 .62304 L .31386 .62237 L F
.31347 .62449 m .31172 .62525 L .31187 .62304 L F
.337 .249 .607 r
.2914 .6225 m .29285 .6192 L .2915 .61925 L F
.2914 .6225 m .29441 .62183 L .29285 .6192 L F
.482 .378 .659 r
.29009 .62386 m .29441 .62183 L .2914 .6225 L F
.52 .553 .83 r
.5369 .73155 m .53823 .73476 L .53621 .73506 L F
.625 .263 .336 r
.5381 .73704 m .53621 .73506 L .53823 .73476 L F
.09 .202 .688 r
.53621 .73506 m .5381 .73704 L .53823 .73476 L F
.718 .246 .129 r
.52603 .79216 m .52879 .79263 L .52799 .79398 L F
.566 .203 .312 r
.52879 .79263 m .53101 .79434 L .52799 .79398 L F
.52879 .79263 m .53121 .79278 L .53101 .79434 L F
0 0 0 r
.59639 .76038 m .59769 .75927 L .59419 .7631 L F
.865 .831 .811 r
.71402 .61119 m .71719 .60974 L .71618 .60867 L F
.679 .895 .975 r
.71618 .60867 m .71719 .60974 L .71989 .6084 L F
.655 .792 .948 r
.3242 .7256 m .32588 .7268 L .32819 .72611 L F
.563 .422 .648 r
.32588 .7268 m .32825 .72874 L .32819 .72611 L F
.32588 .7268 m .3262 .72944 L .32825 .72874 L F
.612 .643 .857 r
.41632 .77569 m .41739 .77271 L .41565 .77292 L F
.41632 .77569 m .4185 .7754 L .41739 .77271 L F
.607 .677 .89 r
.41632 .77569 m .41952 .77642 L .4185 .7754 L F
.507 .173 .335 r
.33534 .65976 m .33384 .65842 L .33289 .66054 L F
.33534 .65976 m .33606 .65819 L .33384 .65842 L F
.241 .342 .767 r
.54567 .70187 m .54671 .70513 L .54794 .70379 L F
.419 0 0 r
.54869 .70601 m .54995 .70673 L .54671 .70513 L F
.55122 .70714 m .54995 .70673 L .54869 .70601 L F
.779 .334 .192 r
.55235 .70738 m .54995 .70673 L .55122 .70714 L F
.55235 .70738 m .5507 .70741 L .54995 .70673 L F
0 .255 .764 r
.54995 .70673 m .5507 .70741 L .55052 .70706 L F
.54995 .70673 m .55052 .70706 L .54991 .70589 L F
.307 .444 .836 r
.54671 .70513 m .54995 .70673 L .54794 .70379 L F
.672 .481 .618 r
.63856 .52662 m .63641 .52928 L .63683 .5269 L F
.63856 .52662 m .64054 .52965 L .63641 .52928 L F
.673 .481 .617 r
.64206 .52907 m .63856 .52662 L .64199 .52691 L F
.64206 .52907 m .64054 .52965 L .63856 .52662 L F
.578 .43 .644 r
.42251 .75155 m .42461 .74882 L .42234 .74919 L F
.933 .946 .775 r
.73246 .62935 m .73443 .62759 L .73484 .62829 L F
0 0 0 r
.73503 .6276 m .73484 .62829 L .73443 .62759 L F
.994 .79 .419 r
.57244 .67937 m .57222 .68239 L .57284 .68286 L F
.763 .971 .924 r
.57284 .68286 m .57475 .68063 L .57559 .6804 L F
.57284 .68286 m .57222 .68239 L .57492 .68043 L F
.526 .332 .561 r
.57296 .68225 m .57457 .68449 L .57441 .68198 L F
.57222 .68239 m .57252 .68265 L .57296 .68225 L F
.57252 .68265 m .57457 .68449 L .57296 .68225 L F
.763 .971 .924 r
.57475 .68063 m .57492 .68043 L .57497 .68043 L F
.57475 .68063 m .57497 .68043 L .57559 .6804 L F
.311 0 0 r
.37305 .67088 m .37221 .67166 L .37095 .67105 L F
.28 0 .049 r
.37221 .67166 m .36921 .67323 L .37095 .67105 L F
.509 .433 .705 r
.41709 .76542 m .41844 .76214 L .41682 .76286 L F
.59 .468 .681 r
.41853 .75987 m .42048 .75685 L .41823 .75723 L F
.752 .762 .861 r
.59041 .76254 m .59415 .76276 L .59281 .76241 L F
.713 .491 .586 r
.5911 .76397 m .59422 .76277 L .59041 .76254 L F
.5911 .76397 m .59361 .76514 L .59422 .76277 L F
.59422 .76277 m .59361 .76514 L .5911 .76397 L F
.503 0 0 r
.59281 .76241 m .58913 .76133 L .59041 .76254 L F
.59281 .76241 m .59423 .76368 L .58965 .76158 L F
.59281 .76241 m .58965 .76158 L .58913 .76133 L F
.752 .762 .861 r
.59415 .76276 m .59422 .76277 L .59281 .76241 L F
.758 .557 0 r
.59422 .76277 m .59393 .76088 L .59281 .76241 L F
.59422 .76277 m .59419 .7631 L .59393 .76088 L F
.096 0 .205 r
.69489 .58267 m .69557 .58307 L .69652 .58152 L F
.503 .855 .598 r
.69652 .58152 m .69796 .5802 L .69895 .5795 L F
.687 .249 .205 r
.53121 .79278 m .53453 .79317 L .53325 .79458 L F
.55 .145 .228 r
.537 .79297 m .53325 .79458 L .53453 .79317 L F
.301 .673 .975 r
.36225 .70555 m .36146 .70634 L .36 .70473 L F
.36225 .70555 m .3636 .70654 L .36146 .70634 L F
.72 .618 .743 r
.53168 .75546 m .53255 .75735 L .53497 .75735 L F
.468 .204 .429 r
.53274 .75982 m .53497 .75735 L .53255 .75735 L F
.53274 .75982 m .53463 .7596 L .53497 .75735 L F
.314 .075 .383 r
.53497 .75735 m .53672 .75858 L .53769 .75725 L F
.53497 .75735 m .53463 .7596 L .53672 .75858 L F
0 0 0 r
.3782 .6687 m .3814 .66728 L .3802 .66785 L F
.154 0 0 r
.3802 .66785 m .3814 .66728 L .38254 .66755 L F
.134 0 0 r
.3814 .66728 m .38354 .66686 L .38254 .66755 L F
.419 .271 .573 r
.34872 .68845 m .34868 .6912 L .34679 .69135 L F
.433 .375 .693 r
.34868 .6912 m .34884 .69311 L .34679 .69135 L F
.537 .374 .607 r
.34679 .69135 m .34884 .69311 L .34675 .69348 L F
.62 .194 .212 r
.57657 .68574 m .57565 .68745 L .57318 .68619 L F
.033 .015 .501 r
.57735 .6821 m .57657 .68574 L .57797 .68259 L F
.57735 .6821 m .57786 .68467 L .57657 .68574 L F
0 0 0 r
.57786 .68467 m .57565 .68745 L .57657 .68574 L F
.411 .461 .802 r
.31731 .71877 m .31803 .72043 L .31558 .71901 L F
.66 .821 .961 r
.73468 .7338 m .73513 .73416 L .73846 .73326 L F
.34 0 .107 r
.35141 .7261 m .3507 .72708 L .34876 .72744 L F
.366 0 .139 r
.35345 .72576 m .3507 .72708 L .35141 .7261 L F
.969 .842 .661 r
.62352 .69331 m .62569 .69088 L .62432 .69007 L F
.62352 .69331 m .62487 .69416 L .62569 .69088 L F
.677 .818 .951 r
.39821 .82143 m .40035 .82041 L .39862 .8193 L F
.426 .222 .498 r
.43132 .74048 m .43277 .73854 L .43209 .73823 L F
.417 .058 .247 r
.53834 .74846 m .54061 .74804 L .54149 .74597 L F
.048 0 0 r
.54061 .74804 m .54333 .74502 L .54149 .74597 L F
.477 0 0 r
.49619 .7897 m .49971 .79042 L .4985 .79073 L F
.057 0 0 r
.49971 .79042 m .50051 .79068 L .4985 .79073 L F
.49971 .79042 m .50161 .79015 L .50051 .79068 L F
.391 .465 .817 r
.57958 .7511 m .57912 .75204 L .58089 .7507 L F
.205 .287 .727 r
.57912 .75204 m .58151 .75293 L .58089 .7507 L F
.57912 .75204 m .58028 .7541 L .58151 .75293 L F
.405 0 0 r
.57559 .6804 m .57492 .68043 L .57244 .67937 L F
.643 .746 .924 r
.35835 .70454 m .35465 .70386 L .35712 .70333 L F
.299 .573 .935 r
.35891 .70332 m .35835 .70454 L .35712 .70333 L F
.35891 .70332 m .36 .70473 L .35835 .70454 L F
.845 .603 .573 r
.47885 .74607 m .47715 .74822 L .47716 .74569 L F
.47885 .74607 m .47724 .75028 L .47715 .74822 L F
.654 .386 .501 r
.48081 .74761 m .47724 .75028 L .47885 .74607 L F
.689 .362 .417 r
.48296 .7467 m .48081 .74761 L .47885 .74607 L F
.659 .586 .762 r
.50564 .74052 m .50333 .74105 L .50225 .73787 L F
.61 .157 .152 r
.58547 .73066 m .58975 .73258 L .58691 .73206 L F
.37 .448 .811 r
.58975 .73258 m .58929 .732 L .58842 .73432 L F
.58975 .73258 m .59114 .73144 L .58929 .732 L F
.089 .296 .777 r
.72921 .62643 m .72975 .62843 L .72993 .62735 L F
.146 .531 .92 r
.72975 .62843 m .73145 .62827 L .72993 .62735 L F
.72975 .62843 m .73246 .62935 L .73145 .62827 L F
.857 .572 .505 r
.60391 .67749 m .60201 .67739 L .60156 .67486 L F
.799 .405 .307 r
.60391 .67749 m .60273 .67907 L .60201 .67739 L F
.883 .528 .371 r
.60391 .67749 m .60518 .68028 L .60273 .67907 L F
0 .468 .806 r
.72568 .72925 m .72289 .72817 L .72358 .72909 L F
.028 .598 .762 r
.2643 .59004 m .26172 .58995 L .26084 .58972 L F
.622 .402 .562 r
.64448 .52666 m .64206 .52907 L .64199 .52691 L F
.566 .305 .48 r
.59862 .72363 m .60087 .72349 L .60135 .72021 L F
.537 .251 .428 r
.60087 .72349 m .60261 .72076 L .60135 .72021 L F
.63 .113 0 r
.72751 .62087 m .72881 .62225 L .72938 .62255 L F
0 .135 .653 r
.73098 .62358 m .73155 .62447 L .72938 .62255 L F
.73098 .62358 m .72938 .62255 L .72881 .62225 L F
0 .446 .84 r
.57859 .70649 m .58185 .70827 L .5803 .70712 L F
.693 .861 .962 r
.5803 .70712 m .58185 .70827 L .5828 .707 L F
.585 .24 .35 r
.47955 .72904 m .48201 .7292 L .48292 .72689 L F
.467 .154 .352 r
.48201 .7292 m .48505 .72631 L .48292 .72689 L F
.577 .126 .144 r
.36497 .64859 m .36703 .64915 L .3686 .64768 L F
.167 0 0 r
.36703 .64915 m .37076 .64798 L .3686 .64768 L F
.57 .708 .935 r
.40568 .65386 m .40458 .65574 L .4036 .65414 L F
.40568 .65386 m .4067 .65534 L .40458 .65574 L F
.647 .252 .282 r
.47477 .78596 m .47126 .78609 L .47269 .78548 L F
.436 .154 .385 r
.41781 .68449 m .41638 .68331 L .41828 .68262 L F
.41781 .68449 m .41584 .68501 L .41638 .68331 L F
.451 .883 .877 r
.51529 .70506 m .51651 .70419 L .51751 .7042 L F
.425 0 0 r
.74204 .60848 m .74435 .60868 L .7457 .60813 L F
.139 0 0 r
.7457 .60813 m .74435 .60868 L .74759 .60802 L F
.816 .667 .698 r
.71498 .60291 m .71835 .60485 L .71823 .60104 L F
.253 .012 .342 r
.71591 .6053 m .71557 .60781 L .71734 .60556 L F
.776 .276 .009 r
.71843 .6056 m .71835 .60485 L .71658 .60383 L F
.71843 .6056 m .71658 .60383 L .7168 .60433 L F
.71843 .6056 m .71498 .60291 L .71591 .6053 L F
.71843 .6056 m .71591 .6053 L .71807 .60463 L F
.253 .012 .342 r
.71707 .60494 m .71734 .60556 L .71807 .60463 L F
.71591 .6053 m .71734 .60556 L .71707 .60494 L F
.776 .276 .009 r
.7168 .60433 m .71658 .60383 L .71498 .60291 L F
.501 .342 .598 r
.42461 .74882 m .42659 .74558 L .42437 .74564 L F
.951 .6 .24 r
.54821 .68871 m .54717 .68954 L .54737 .68778 L F
.86 .914 .867 r
.55099 .68582 m .54821 .68871 L .54737 .68778 L F
.917 .712 .61 r
.60827 .68825 m .60967 .69136 L .60797 .69079 L F
.91 .592 .431 r
.60967 .69136 m .60836 .69297 L .60797 .69079 L F
.981 .746 .508 r
.60967 .69136 m .60955 .6938 L .60836 .69297 L F
.162 0 0 r
.35936 .64962 m .36148 .64935 L .36289 .64855 L F
.231 0 0 r
.36148 .64935 m .36497 .64859 L .36289 .64855 L F
.658 .523 .689 r
.54294 .75419 m .54072 .7571 L .54056 .75458 L F
.623 .559 .762 r
.432 .66554 m .43061 .66933 L .42969 .6661 L F
.432 .66554 m .43288 .66933 L .43061 .66933 L F
.471 .199 .419 r
.43288 .66933 m .43031 .67171 L .43061 .66933 L F
.579 .809 .987 r
.39286 .64976 m .39236 .65127 L .39079 .64967 L F
.39286 .64976 m .3938 .65078 L .39236 .65127 L F
.441 .073 .242 r
.38365 .6988 m .38703 .69638 L .38504 .69695 L F
0 .251 .761 r
.73814 .59589 m .73813 .59503 L .73734 .59446 L F
.579 .624 .861 r
.73728 .59789 m .73813 .59503 L .73814 .59589 L F
.893 .705 .64 r
.60698 .68278 m .60828 .68588 L .60664 .68518 L F
.878 .64 .576 r
.60828 .68588 m .60648 .68752 L .60664 .68518 L F
.60828 .68588 m .60827 .68825 L .60648 .68752 L F
.522 .861 .994 r
.72757 .59665 m .72629 .59777 L .72508 .59725 L F
.809 .538 .529 r
.72476 .59938 m .72664 .60083 L .72629 .59777 L F
.692 .595 .743 r
.72476 .59938 m .72664 .60083 L .72563 .59852 L F
.72476 .59938 m .72563 .59852 L .72508 .59725 L F
.809 .538 .529 r
.72563 .59852 m .72629 .59777 L .72722 .59695 L F
.72496 .59917 m .72629 .59777 L .72563 .59852 L F
.72476 .59938 m .72496 .59917 L .72563 .59852 L F
.692 .595 .743 r
.72476 .59938 m .72664 .60083 L .72508 .59725 L F
.809 .538 .529 r
.72476 .59938 m .72722 .59695 L .72757 .59665 L F
.611 .555 .767 r
.72508 .59725 m .72563 .59852 L .72757 .59665 L F
.72563 .59852 m .72664 .60083 L .72757 .59665 L F
.332 0 0 r
.58963 .71903 m .58836 .71898 L .5862 .71837 L F
.5862 .71837 m .58836 .71898 L .58963 .71903 L F
.178 0 0 r
.59194 .71879 m .58836 .71898 L .58963 .71903 L F
.547 .047 .018 r
.59194 .71879 m .58836 .71898 L .58963 .71903 L F
.333 .414 .796 r
.54126 .69741 m .54257 .69887 L .54142 .69586 L F
.543 .718 .954 r
.32384 .60352 m .32184 .60392 L .32054 .60251 L F
.443 .486 .809 r
.32493 .60693 m .32184 .60392 L .32384 .60352 L F
.126 .338 .803 r
.7122 .5755 m .71296 .57804 L .71134 .57496 L F
.614 .253 .334 r
.71218 .57562 m .71296 .57804 L .7122 .5755 L F
.749 .708 .814 r
.71346 .57957 m .71013 .57878 L .71296 .57804 L F
.684 .808 .942 r
.71296 .57804 m .71013 .57878 L .70909 .57772 L F
.71296 .57804 m .70909 .57772 L .71134 .57496 L F
.614 .253 .334 r
.71139 .57982 m .71296 .57804 L .71218 .57562 L F
.749 .708 .814 r
.71357 .5796 m .71346 .57957 L .71296 .57804 L F
0 .484 .746 r
.71296 .57804 m .71575 .57868 L .71357 .5796 L F
.588 .453 .665 r
.31572 .69403 m .31803 .69413 L .31774 .69102 L F
.568 .451 .68 r
.31628 .69687 m .31803 .69413 L .31572 .69403 L F
.692 .338 .37 r
.51727 .73719 m .51544 .73964 L .51377 .73745 L F
.492 .514 .808 r
.51785 .73451 m .51918 .73736 L .51727 .73719 L F
.511 .134 .261 r
.51918 .73736 m .51544 .73964 L .51727 .73719 L F
.186 .249 .695 r
.61441 .72946 m .6162 .73154 L .61494 .73272 L F
.117 .098 .558 r
.6162 .73154 m .61526 .7348 L .61494 .73272 L F
.509 .433 .705 r
.41709 .76542 m .41899 .76498 L .41844 .76214 L F
.494 .379 .651 r
.41709 .76542 m .41931 .76749 L .41899 .76498 L F
.457 .376 .677 r
.41743 .76789 m .41931 .76749 L .41709 .76542 L F
.203 .459 .879 r
.73294 .62503 m .73174 .62593 L .73155 .62447 L F
.73294 .62503 m .73503 .6276 L .73174 .62593 L F
.763 .61 .688 r
.52285 .76781 m .52618 .76821 L .52584 .76585 L F
.577 .456 .677 r
.52618 .76821 m .52837 .76535 L .52584 .76585 L F
.406 0 0 r
.60219 .66117 m .60498 .66183 L .60564 .66108 L F
.72 .196 0 r
.60541 .66184 m .60564 .66108 L .60498 .66183 L F
.60541 .66184 m .60788 .6631 L .60564 .66108 L F
.632 .349 .472 r
.60564 .66108 m .60788 .6631 L .60744 .66133 L F
.356 .578 .926 r
.54538 .72298 m .5437 .72443 L .54418 .72289 L F
.54538 .72298 m .54698 .725 L .5437 .72443 L F
.867 .714 .69 r
.62379 .68257 m .62499 .68577 L .62541 .68338 L F
.789 .593 .636 r
.61603 .67147 m .61953 .66953 L .6181 .66895 L F
.61603 .67147 m .61939 .67196 L .61953 .66953 L F
.804 .75 .802 r
.2999 .72786 m .2961 .7273 L .29795 .72672 L F
0 .34 .809 r
.29972 .72715 m .2999 .72786 L .29795 .72672 L F
.29972 .72715 m .30185 .72882 L .2999 .72786 L F
.336 0 0 r
.50161 .79015 m .50507 .79053 L .50396 .7908 L F
.547 0 0 r
.50738 .7916 m .50936 .79215 L .50867 .7924 L F
.50632 .79095 m .50751 .79142 L .50738 .7916 L F
.50751 .79142 m .50936 .79215 L .50738 .7916 L F
.343 0 0 r
.50396 .7908 m .50507 .79053 L .50766 .79123 L F
.50762 .79128 m .50766 .79123 L .508 .79133 L F
.50396 .7908 m .50766 .79123 L .50762 .79128 L F
.636 .685 .879 r
.4185 .7754 m .41952 .77642 L .42188 .77607 L F
.557 .438 .673 r
.42024 .77912 m .42188 .77607 L .41952 .77642 L F
.806 .767 .817 r
.71529 .60051 m .71823 .60104 L .7173 .59848 L F
.816 .667 .698 r
.71498 .60291 m .71823 .60104 L .71529 .60051 L F
.744 .75 .857 r
.71823 .60104 m .71929 .59761 L .7173 .59848 L F
.71823 .60104 m .72103 .59995 L .71929 .59761 L F
0 0 .558 r
.4944 .74842 m .49471 .74805 L .49284 .74523 L F
.378 .841 .799 r
.49665 .74726 m .4944 .74842 L .49841 .7467 L F
.49665 .74726 m .49471 .74805 L .4944 .74842 L F
.442 .167 .4 r
.40458 .69444 m .40402 .69645 L .40198 .69692 L F
.376 .107 .373 r
.40592 .69574 m .40458 .69444 L .4065 .69384 L F
.40592 .69574 m .40402 .69645 L .40458 .69444 L F
.49 0 0 r
.42823 .66482 m .43209 .66438 L .42969 .6661 L F
.55 .435 .674 r
.43209 .66438 m .432 .66554 L .42969 .6661 L F
.706 .377 .418 r
.5956 .72897 m .59882 .729 L .59761 .72533 L F
.806 .432 .348 r
.59761 .72533 m .60013 .7284 L .5998 .72683 L F
.745 .52 .589 r
.55111 .75395 m .54856 .75154 L .55114 .75149 L F
.625 .449 .624 r
.55398 .75321 m .55114 .75149 L .5539 .75051 L F
.55398 .75321 m .55111 .75395 L .55114 .75149 L F
0 .03 .601 r
.52154 .70466 m .52096 .70494 L .5197 .70402 L F
.52154 .70466 m .5228 .7074 L .52096 .70494 L F
.565 .559 .806 r
.30139 .72272 m .30318 .72026 L .30114 .72166 L F
.30139 .72272 m .30447 .72343 L .30318 .72026 L F
.325 .615 .954 r
.7201 .57839 m .71889 .57951 L .71804 .57815 L F
.557 .438 .673 r
.42024 .77912 m .42241 .77878 L .42188 .77607 L F
.617 .483 .677 r
.42035 .78072 m .42241 .77878 L .42024 .77912 L F
.442 0 0 r
.49496 .78434 m .49742 .78475 L .49851 .78427 L F
.649 .093 0 r
.49938 .78576 m .49851 .78427 L .49742 .78475 L F
.49938 .78576 m .50098 .78618 L .49851 .78427 L F
.712 .435 .504 r
.45989 .75157 m .45627 .75369 L .45682 .75182 L F
.45989 .75157 m .45957 .75392 L .45627 .75369 L F
.731 .453 .506 r
.46185 .75373 m .45957 .75392 L .45989 .75157 L F
.5 .3 .541 r
.32468 .66926 m .3265 .67137 L .32668 .66896 L F
.32468 .66926 m .32445 .67209 L .3265 .67137 L F
.859 .764 .756 r
.60112 .6714 m .60273 .67232 L .60156 .67486 L F
.577 .456 .677 r
.52618 .76821 m .5284 .76777 L .52837 .76535 L F
.568 .331 .516 r
.68371 .58892 m .68691 .5896 L .68638 .58698 L F
.661 .474 .621 r
.68691 .5896 m .68878 .58617 L .68638 .58698 L F
.417 .693 .977 r
.72706 .58324 m .7281 .58455 L .72588 .5844 L F
.766 .756 .844 r
.71929 .59761 m .72103 .59995 L .72275 .59773 L F
.524 .045 .06 r
.64163 .51899 m .64529 .51854 L .64303 .51894 L F
.038 0 0 r
.57882 .66938 m .57956 .6698 L .58077 .66851 L F
.57882 .66938 m .57742 .6704 L .57956 .6698 L F
.389 0 .143 r
.35728 .68156 m .35587 .68087 L .35774 .68024 L F
.35728 .68156 m .35506 .6822 L .35587 .68087 L F
.58 .427 .639 r
.31707 .68631 m .31913 .68579 L .31901 .68298 L F
.568 .467 .7 r
.31707 .68631 m .31946 .68813 L .31913 .68579 L F
.31707 .68631 m .31736 .68856 L .31946 .68813 L F
.436 .243 .519 r
.61572 .72425 m .61631 .72685 L .6142 .72728 L F
.131 .034 .468 r
.61736 .72075 m .61731 .72314 L .61572 .72425 L F
.155 .072 .502 r
.61731 .72314 m .61631 .72685 L .61572 .72425 L F
.767 .674 .76 r
.58729 .71006 m .58839 .71322 L .58501 .71288 L F
.722 .333 .312 r
.58839 .71322 m .58681 .71464 L .58501 .71288 L F
0 0 .474 r
.5873 .70943 m .58839 .71322 L .58729 .71006 L F
0 0 0 r
.58729 .71006 m .58522 .71261 L .58644 .7117 L F
.58522 .71261 m .58501 .71288 L .58644 .7117 L F
.58729 .71006 m .58644 .7117 L .58462 .70852 L F
.959 .819 .663 r
.58644 .7117 m .58681 .71464 L .58725 .70994 L F
.58644 .7117 m .58725 .70994 L .58714 .70987 L F
.98 .84 .633 r
.5873 .70943 m .58681 .71464 L .58839 .71322 L F
.456 .237 .491 r
.58714 .70987 m .58715 .70988 L .58644 .7117 L F
.58715 .70988 m .58833 .71151 L .58653 .71169 L F
.58715 .70988 m .58653 .71169 L .58644 .7117 L F
.98 .863 .649 r
.58695 .70974 m .5873 .70943 L .58729 .71006 L F
.959 .819 .663 r
.58714 .70987 m .58725 .70994 L .5873 .70943 L F
.456 .237 .491 r
.5873 .70943 m .58764 .71011 L .58714 .70987 L F
.58764 .71011 m .58833 .71151 L .58714 .70987 L F
0 .302 .708 r
.58462 .70852 m .5869 .70971 L .58699 .70979 L F
.58595 .70929 m .58699 .70979 L .58729 .71006 L F
.58462 .70852 m .58699 .70979 L .58595 .70929 L F
.5869 .70971 m .58695 .70974 L .58697 .70976 L F
.5869 .70971 m .58697 .70976 L .58729 .71006 L F
.861 .982 .694 r
.58755 .71087 m .58644 .7117 L .58833 .71151 L F
.58657 .71006 m .58644 .7117 L .58755 .71087 L F
.164 .423 .861 r
.57115 .72785 m .574 .72877 L .57076 .72633 L F
.57115 .72785 m .57353 .72935 L .574 .72877 L F
.425 .024 .173 r
.3849 .71035 m .38373 .71234 L .38153 .71254 L F
.219 0 .062 r
.38569 .71158 m .3849 .71035 L .38698 .7096 L F
.38569 .71158 m .38373 .71234 L .3849 .71035 L F
.565 .257 .406 r
.44494 .74027 m .44734 .7402 L .44827 .73768 L F
.535 .227 .393 r
.44827 .73768 m .44964 .7399 L .45062 .73782 L F
.44827 .73768 m .44734 .7402 L .44964 .7399 L F
.329 .078 .373 r
.30543 .63372 m .30772 .63101 L .307 .63318 L F
.38 .187 .49 r
.30516 .63596 m .30543 .63372 L .307 .63318 L F
.446 .253 .525 r
.30956 .63043 m .30772 .63101 L .30976 .62815 L F
.395 .139 .405 r
.307 .63318 m .30772 .63101 L .30956 .63043 L F
.584 .571 .806 r
.32005 .72946 m .32144 .733 L .32357 .73229 L F
.856 .812 .806 r
.48281 .74564 m .48081 .74761 L .48296 .7467 L F
.34 0 .059 r
.34924 .65193 m .35112 .65172 L .35192 .65073 L F
.237 0 0 r
.35192 .65073 m .35325 .65106 L .35409 .65042 L F
.35192 .65073 m .35112 .65172 L .35325 .65106 L F
.448 .882 .848 r
.5539 .75051 m .55146 .75099 L .55232 .75062 L F
0 0 0 r
.5539 .75051 m .55172 .75099 L .55146 .75099 L F
.982 .907 .646 r
.5539 .75051 m .55172 .75099 L .55177 .75065 L F
.63 .887 .987 r
.55232 .75062 m .55012 .75018 L .55146 .75099 L F
.982 .907 .646 r
.5539 .75051 m .55232 .75062 L .5522 .74814 L F
.55232 .75062 m .5519 .75012 L .5522 .74814 L F
.801 .754 .809 r
.55196 .74954 m .55012 .75018 L .5519 .75012 L F
.796 .72 .78 r
.5522 .74814 m .55196 .74954 L .55012 .75018 L F
.801 .754 .809 r
.55207 .74843 m .55012 .75018 L .55196 .74954 L F
.63 .887 .987 r
.5519 .75012 m .55012 .75018 L .55232 .75062 L F
.796 .72 .78 r
.55196 .74954 m .55172 .75099 L .55012 .75018 L F
.982 .907 .646 r
.5519 .75012 m .55196 .74954 L .5522 .74814 L F
.796 .72 .78 r
.5522 .74814 m .55012 .75018 L .55226 .74826 L F
.578 .137 0 r
.5522 .74814 m .55358 .75008 L .5539 .75051 L F
.801 .754 .809 r
.55217 .74748 m .5519 .75012 L .55358 .75008 L F
.796 .72 .78 r
.55226 .74826 m .55012 .75018 L .55302 .74964 L F
.801 .754 .809 r
.55217 .74748 m .55012 .75018 L .55207 .74843 L F
.982 .907 .646 r
.5519 .75012 m .55187 .75008 L .55196 .74954 L F
.801 .754 .809 r
.55266 .74683 m .55358 .75008 L .5522 .74814 L F
.232 .171 .579 r
.5522 .74814 m .55226 .74826 L .55266 .74683 L F
.801 .754 .809 r
.55266 .74683 m .55237 .74786 L .55358 .75008 L F
.232 .171 .579 r
.55226 .74826 m .55302 .74964 L .55266 .74683 L F
.801 .754 .809 r
.55266 .74683 m .55217 .74748 L .55237 .74786 L F
.63 .887 .987 r
.55358 .75008 m .5519 .75012 L .55232 .75062 L F
.982 .907 .646 r
.55232 .75062 m .55177 .75065 L .55187 .75008 L F
.448 .882 .848 r
.5539 .75051 m .55232 .75062 L .55358 .75008 L F
.493 .146 .306 r
.5563 .75167 m .55398 .75321 L .5539 .75051 L F
.799 .594 .625 r
.62264 .67475 m .61939 .67196 L .6193 .67439 L F
.815 .603 .616 r
.6193 .67439 m .62279 .67734 L .62264 .67475 L F
.467 .203 .429 r
.41379 .68559 m .41301 .68813 L .41074 .68832 L F
.49 .24 .462 r
.41584 .68501 m .41301 .68813 L .41379 .68559 L F
.531 .773 .987 r
.27898 .59401 m .27689 .59443 L .2757 .59327 L F
.546 .625 .881 r
.32253 .71648 m .32381 .71907 L .32578 .71833 L F
.493 .065 .156 r
.32381 .71907 m .32522 .7203 L .32578 .71833 L F
.32381 .71907 m .32365 .7208 L .32522 .7203 L F
.859 .764 .756 r
.60112 .6714 m .60156 .67486 L .59968 .67405 L F
.894 .597 .477 r
.60156 .67486 m .59975 .6762 L .59968 .67405 L F
.60156 .67486 m .60201 .67739 L .59975 .6762 L F
0 0 0 r
.54414 .693 m .54358 .69386 L .54579 .69158 L F
.511 .302 .532 r
.6742 .598 m .67743 .59814 L .67703 .59432 L F
.475 .319 .589 r
.67703 .59432 m .67899 .59461 L .67932 .59243 L F
.538 .321 .533 r
.67703 .59432 m .67906 .59702 L .67899 .59461 L F
.67703 .59432 m .67743 .59814 L .67906 .59702 L F
.664 .834 .965 r
.58461 .7605 m .5858 .75867 L .58367 .75887 L F
.58461 .7605 m .58642 .75972 L .5858 .75867 L F
0 0 0 r
.55099 .68582 m .55228 .68498 L .5535 .68385 L F
.5535 .68385 m .55399 .68387 L .55562 .68306 L F
.5535 .68385 m .55228 .68498 L .55399 .68387 L F
.452 .162 .381 r
.59092 .663 m .59345 .66079 L .59159 .66156 L F
.777 .781 .856 r
.71083 .60651 m .7135 .60627 L .71308 .60569 L F
.412 .559 .892 r
.71083 .60651 m .71342 .60874 L .7135 .60627 L F
.637 .732 .917 r
.71308 .60569 m .7135 .60627 L .71591 .6053 L F
.172 0 .314 r
.71342 .60874 m .71591 .6053 L .7135 .60627 L F
.363 .833 .809 r
.29058 .73038 m .29422 .72933 L .29215 .72985 L F
.228 0 .096 r
.34039 .73018 m .33962 .73151 L .33798 .73194 L F
.396 .846 .763 r
.34266 .73023 m .33962 .73151 L .34039 .73018 L F
.846 .99 .728 r
.46953 .74629 m .46767 .74878 L .46866 .74734 L F
.405 .191 .472 r
.46953 .74629 m .46935 .74867 L .46767 .74878 L F
.562 .417 .641 r
.47014 .75095 m .46767 .74878 L .46935 .74867 L F
.47014 .75095 m .46798 .75185 L .46767 .74878 L F
.668 .72 .888 r
.39818 .66843 m .39904 .66973 L .40132 .66909 L F
.628 .482 .665 r
.54294 .75419 m .54321 .75718 L .54072 .7571 L F
.498 .199 .389 r
.54321 .75718 m .54062 .75924 L .54072 .7571 L F
0 0 0 r
.71504 .71364 m .71599 .71307 L .7163 .71341 L F
.603 .316 .454 r
.71472 .71418 m .71647 .71279 L .71599 .71307 L F
.566 .723 .947 r
.71779 .71174 m .7163 .71341 L .71599 .71307 L F
.603 .316 .454 r
.71647 .71279 m .71779 .71174 L .71599 .71307 L F
0 0 0 r
.71411 .7138 m .71599 .71307 L .71504 .71364 L F
.71411 .7138 m .71259 .71563 L .71599 .71307 L F
.59 .468 .681 r
.41853 .75987 m .42087 .7596 L .42048 .75685 L F
.576 .376 .572 r
.41844 .76214 m .42087 .7596 L .41853 .75987 L F
.551 .06 .043 r
.48156 .78656 m .48573 .78665 L .48378 .78663 L F
.663 .164 .052 r
.48573 .78665 m .48718 .78725 L .48378 .78663 L F
.472 .165 .363 r
.55564 .73578 m .55605 .73717 L .55341 .73764 L F
.62 .251 .32 r
.55564 .73578 m .55848 .73713 L .55605 .73717 L F
.794 .561 .584 r
.61447 .6686 m .61615 .66663 L .61447 .66637 L F
.61447 .6686 m .6181 .66895 L .61615 .66663 L F
.86 .914 .867 r
.55099 .68582 m .54737 .68778 L .55029 .68609 L F
.411 .839 .69 r
.55099 .68582 m .55029 .68609 L .55228 .68498 L F
.992 .81 .435 r
.52801 .75164 m .52719 .75393 L .5274 .75108 L F
.288 0 0 r
.52363 .75299 m .5274 .75108 L .52658 .75226 L F
.404 .055 .256 r
.52583 .7526 m .52688 .75188 L .5274 .75108 L F
.97 .712 .288 r
.52801 .75164 m .5274 .75108 L .52775 .75055 L F
.992 .81 .435 r
.52801 .75164 m .52719 .75393 L .5274 .75108 L F
.736 .549 .64 r
.5274 .75108 m .52719 .75393 L .52658 .75226 L F
.404 .055 .256 r
.52688 .75188 m .52852 .75073 L .5274 .75108 L F
.97 .712 .288 r
.52775 .75055 m .5274 .75108 L .52729 .74855 L F
.337 .324 .698 r
.5287 .75346 m .53022 .75403 L .52801 .75164 L F
.705 .352 .375 r
.52801 .75164 m .53022 .75403 L .52719 .75393 L F
.115 0 0 r
.56723 .75742 m .56619 .75723 L .5668 .75763 L F
.56875 .75668 m .56743 .75696 L .56723 .75742 L F
.56743 .75696 m .56619 .75723 L .56723 .75742 L F
.908 .61 .468 r
.57 .7562 m .5685 .75712 L .56875 .75668 L F
.881 .663 .603 r
.5685 .75712 m .57076 .75542 L .5679 .75713 L F
0 .346 .822 r
.5685 .75712 m .5679 .75713 L .5678 .75702 L F
.115 0 0 r
.56743 .75696 m .5685 .75712 L .56619 .75723 L F
.776 .664 .739 r
.56654 .75282 m .56786 .757 L .57076 .75542 L F
.56786 .757 m .5679 .75713 L .56818 .75696 L F
.115 0 0 r
.56875 .75668 m .56863 .75689 L .56743 .75696 L F
.56863 .75689 m .56779 .75701 L .56743 .75696 L F
.776 .664 .739 r
.56786 .757 m .56818 .75696 L .57076 .75542 L F
.115 0 0 r
.56863 .75689 m .5685 .75712 L .56779 .75701 L F
0 .346 .822 r
.5685 .75712 m .5678 .75702 L .56754 .75671 L F
.903 .723 .648 r
.56679 .75585 m .5679 .75713 L .56722 .75499 L F
.56679 .75585 m .56722 .75499 L .56654 .75282 L F
0 .346 .822 r
.56729 .75733 m .56437 .75783 L .56619 .75723 L F
.56437 .75783 m .56405 .75788 L .5643 .75781 L F
.56437 .75783 m .5643 .75781 L .56619 .75723 L F
.01 .562 .825 r
.5668 .75763 m .56619 .75723 L .56418 .75705 L F
.078 0 .277 r
.56606 .75723 m .56571 .75826 L .56431 .75756 L F
.56571 .75826 m .56533 .75941 L .56448 .75786 L F
.56571 .75826 m .56448 .75786 L .56431 .75756 L F
.01 .562 .825 r
.56418 .75705 m .56619 .75723 L .56308 .75681 L F
.277 0 0 r
.56619 .75723 m .56185 .75791 L .56308 .75681 L F
.56254 .7578 m .56405 .75788 L .56185 .75791 L F
.56619 .75723 m .56405 .75788 L .56254 .7578 L F
0 .346 .822 r
.56591 .75756 m .56628 .75685 L .56405 .75788 L F
.56628 .75685 m .56679 .75585 L .56444 .75759 L F
.56628 .75685 m .56444 .75759 L .56442 .75771 L F
.281 0 .234 r
.5644 .75772 m .56405 .75788 L .56431 .75756 L F
.144 0 0 r
.56431 .75756 m .56405 .75788 L .56679 .75585 L F
0 0 .379 r
.56747 .7542 m .56679 .75585 L .56654 .75282 L F
.087 0 .322 r
.56747 .7542 m .56431 .75756 L .56679 .75585 L F
.56747 .7542 m .56606 .75723 L .56445 .75754 L F
.56448 .75738 m .56445 .75754 L .56431 .75756 L F
.56747 .7542 m .56445 .75754 L .56448 .75738 L F
0 .346 .822 r
.56442 .75771 m .56444 .75759 L .56405 .75788 L F
.281 0 .234 r
.5645 .75791 m .56405 .75788 L .5644 .75772 L F
.56533 .75941 m .56405 .75788 L .5645 .75791 L F
0 .346 .822 r
.56764 .75648 m .56754 .75671 L .56679 .75585 L F
.5685 .75712 m .56754 .75671 L .56764 .75648 L F
.5685 .75712 m .56729 .75733 L .56619 .75723 L F
.5685 .75712 m .56679 .75585 L .56591 .75756 L F
.605 .442 .634 r
.44412 .75983 m .44197 .76263 L .44239 .76048 L F
.667 .435 .56 r
.68108 .5919 m .68371 .58892 L .68084 .58978 L F
.68108 .5919 m .68438 .59206 L .68371 .58892 L F
.674 .536 .689 r
.68438 .59206 m .68691 .5896 L .68371 .58892 L F
0 0 0 r
.56073 .67953 m .56234 .67934 L .56289 .67866 L F
.56073 .67953 m .5601 .67985 L .56234 .67934 L F
.52 0 0 r
.69796 .5802 m .7014 .58067 L .69895 .5795 L F
.281 0 0 r
.27266 .60467 m .2709 .6043 L .27063 .60424 L F
.123 0 0 r
.26979 .60404 m .27063 .60424 L .26841 .60464 L F
.435 .849 .963 r
.26909 .60393 m .26841 .60464 L .27063 .60424 L F
.281 0 0 r
.2709 .6043 m .26909 .60393 L .27063 .60424 L F
.123 0 0 r
.27027 .60384 m .27063 .60424 L .26979 .60404 L F
.27027 .60384 m .27237 .60376 L .27063 .60424 L F
.255 .766 .784 r
.27887 .65577 m .27759 .65594 L .27515 .65653 L F
0 0 0 r
.28079 .65482 m .27759 .65594 L .27887 .65577 L F
.517 .215 .392 r
.45297 .73772 m .45523 .73743 L .45609 .73493 L F
.511 .208 .39 r
.45609 .73493 m .45808 .73623 L .45834 .73481 L F
.45609 .73493 m .45523 .73743 L .45808 .73623 L F
.388 .6 .931 r
.3953 .66746 m .3963 .66614 L .39445 .66598 L F
.3953 .66746 m .39818 .66843 L .3963 .66614 L F
.62 .769 .951 r
.42635 .78489 m .42953 .78577 L .42862 .78451 L F
.424 .62 .933 r
.42953 .78577 m .43059 .78402 L .42862 .78451 L F
.42953 .78577 m .43238 .78622 L .43059 .78402 L F
.281 .744 .949 r
.39272 .66614 m .39094 .66558 L .38893 .66564 L F
.275 .74 .947 r
.39272 .66614 m .39445 .66598 L .39094 .66558 L F
.291 .733 .964 r
.29337 .59619 m .29149 .59635 L .28998 .59569 L F
.634 .332 .442 r
.58225 .67498 m .57996 .67653 L .58206 .67439 L F
.731 .928 .956 r
.57898 .67727 m .57994 .67676 L .57996 .67653 L F
.634 .332 .442 r
.58225 .67498 m .57831 .67786 L .57996 .67653 L F
.354 .145 .451 r
.58541 .67412 m .58225 .67498 L .58206 .67439 L F
.288 0 0 r
.58449 .67623 m .5811 .67778 L .58225 .67498 L F
.499 .67 .94 r
.27584 .60339 m .27899 .6047 L .27769 .60372 L F
.512 .784 .994 r
.27899 .6047 m .27949 .60348 L .27769 .60372 L F
.27899 .6047 m .28081 .60433 L .27949 .60348 L F
.577 .413 .623 r
.35096 .68614 m .34872 .68845 L .34854 .68693 L F
.543 .651 .905 r
.31884 .6026 m .31503 .60058 L .31704 .60019 L F
.439 .593 .908 r
.32054 .60251 m .31884 .6026 L .31704 .60019 L F
.286 0 0 r
.51622 .78873 m .51293 .78913 L .51504 .78849 L F
0 0 0 r
.51737 .78816 m .51622 .78873 L .51504 .78849 L F
.51737 .78816 m .51882 .78742 L .51622 .78873 L F
.532 .602 .869 r
.31466 .71026 m .31654 .71331 L .31411 .71344 L F
0 0 .258 r
.31612 .71333 m .31489 .71453 L .31654 .71331 L F
.31411 .71344 m .31489 .71453 L .31612 .71333 L F
.31411 .71344 m .31374 .71557 L .31489 .71453 L F
.557 .11 .143 r
.31654 .71331 m .31489 .71453 L .31328 .71356 L F
.667 .686 .858 r
.30959 .71218 m .31142 .71542 L .31328 .71356 L F
.626 .518 .712 r
.31142 .71542 m .31374 .71557 L .31328 .71356 L F
.565 .043 0 r
.31328 .71356 m .31489 .71453 L .31017 .71318 L F
.626 .518 .712 r
.31142 .71542 m .31184 .71602 L .31374 .71557 L F
.541 .373 .603 r
.31186 .71803 m .31374 .71557 L .31184 .71602 L F
.36 .228 .563 r
.31329 .71616 m .31017 .71318 L .31489 .71453 L F
.557 .11 .143 r
.31654 .71331 m .31328 .71356 L .31411 .71344 L F
.51 .337 .582 r
.31654 .71331 m .31847 .71357 L .31899 .71102 L F
.46 .505 .818 r
.31672 .7098 m .31847 .71357 L .31654 .71331 L F
0 0 .113 r
.3154 .71093 m .31489 .71453 L .31703 .71204 L F
.3154 .71093 m .31532 .71346 L .31489 .71453 L F
.717 .926 .589 r
.31532 .71346 m .31345 .71594 L .31489 .71453 L F
.252 .157 .548 r
.31374 .71557 m .31526 .71707 L .31489 .71453 L F
.717 .926 .589 r
.31345 .71594 m .31329 .71616 L .31489 .71453 L F
.592 .332 .492 r
.45834 .73481 m .46074 .73478 L .46089 .73246 L F
.47 .126 .301 r
.46074 .73478 m .46395 .7322 L .46089 .73246 L F
.578 .464 .687 r
.31736 .68856 m .31986 .6906 L .31946 .68813 L F
.31736 .68856 m .31774 .69102 L .31986 .6906 L F
.16 0 .141 r
.34963 .72822 m .34876 .72744 L .3507 .72708 L F
.34963 .72822 m .348 .729 L .34876 .72744 L F
.815 .479 .418 r
.60112 .6714 m .59768 .66893 L .5995 .66914 L F
.721 .319 .286 r
.438 .65418 m .43988 .65533 L .4417 .65524 L F
.684 .598 .753 r
.67358 .60844 m .67458 .61159 L .67716 .60921 L F
.647 .328 .419 r
.59031 .67219 m .58668 .67393 L .58797 .67258 L F
.635 .383 .519 r
.47202 .74814 m .46935 .74867 L .46953 .74629 L F
.715 .497 .592 r
.54856 .75154 m .54511 .7537 L .54546 .75147 L F
.54856 .75154 m .54869 .75412 L .54511 .7537 L F
.745 .52 .589 r
.55111 .75395 m .54869 .75412 L .54856 .75154 L F
.544 .347 .565 r
.49888 .73511 m .50145 .73726 L .49881 .73747 L F
.109 .325 .797 r
.74441 .59681 m .74594 .59986 L .74348 .59789 L F
.081 0 0 r
.36218 .72242 m .36164 .72139 L .3637 .72093 L F
.36218 .72242 m .36033 .72341 L .36164 .72139 L F
.19 0 .349 r
.539 .74388 m .53753 .74347 L .54061 .74248 L F
.399 0 0 r
.54267 .74294 m .539 .74388 L .54061 .74248 L F
.542 .476 .731 r
.31628 .69687 m .31701 .6998 L .31914 .69922 L F
.499 .274 .504 r
.31701 .6998 m .31861 .70127 L .31914 .69922 L F
.31701 .6998 m .31672 .70182 L .31861 .70127 L F
.917 .729 .634 r
.62361 .68476 m .62499 .68577 L .62379 .68257 L F
.843 .655 .648 r
.62361 .68476 m .62508 .688 L .62499 .68577 L F
.545 .41 .648 r
.31913 .68579 m .32093 .68244 L .31901 .68298 L F
0 .416 .721 r
.50472 .78668 m .506 .78715 L .50408 .78657 L F
.391 0 0 r
.50484 .78675 m .506 .78715 L .50472 .78668 L F
0 .402 .701 r
.506 .78715 m .50701 .78749 L .50408 .78657 L F
.391 0 0 r
.50706 .78804 m .506 .78715 L .50484 .78675 L F
0 .402 .701 r
.506 .78715 m .50732 .78759 L .50701 .78749 L F
0 .45 .79 r
.50868 .78777 m .50732 .78759 L .506 .78715 L F
.50868 .78777 m .51005 .78849 L .50732 .78759 L F
.544 .573 .834 r
.51082 .78955 m .50732 .78759 L .51005 .78849 L F
.615 .575 .786 r
.41794 .77065 m .41931 .76749 L .41743 .76789 L F
.525 .355 .594 r
.32064 .67993 m .32269 .6771 L .32063 .67753 L F
.544 .409 .647 r
.32063 .67753 m .32269 .6771 L .32263 .67467 L F
.546 .741 .966 r
.4007 .6522 m .40141 .65445 L .3994 .65243 L F
.4007 .6522 m .4036 .65414 L .40141 .65445 L F
.564 .522 .766 r
.42035 .78072 m .42054 .78251 L .4227 .78176 L F
.787 .646 .707 r
.32357 .73229 m .32676 .73308 L .3262 .72944 L F
.601 .518 .733 r
.3262 .72944 m .32676 .73308 L .32913 .73234 L F
.886 .895 .831 r
.7327 .5898 m .72897 .5921 L .72904 .58896 L F
.496 .261 .488 r
.42349 .67755 m .42315 .68006 L .42091 .68044 L F
.457 .202 .438 r
.42573 .67707 m .42315 .68006 L .42349 .67755 L F
.578 .43 .644 r
.42251 .75155 m .42473 .75122 L .42461 .74882 L F
.573 .387 .592 r
.42251 .75155 m .42473 .75367 L .42473 .75122 L F
.42251 .75155 m .42249 .75405 L .42473 .75367 L F
0 0 0 r
.57996 .67653 m .57831 .67786 L .57898 .67727 L F
.742 .41 .419 r
.57658 .67902 m .57898 .67727 L .57831 .67786 L F
0 0 .332 r
.56655 .703 m .56608 .70414 L .56567 .70207 L F
.458 .433 .742 r
.2917 .61148 m .29236 .61465 L .29404 .61311 L F
.546 .479 .732 r
.29277 .61696 m .29404 .61311 L .29236 .61465 L F
0 0 .392 r
.47967 .77799 m .47971 .7788 L .47961 .77853 L F
.47967 .77799 m .47961 .77853 L .47882 .77635 L F
.47967 .77799 m .47882 .77635 L .47613 .77624 L F
.755 .487 .527 r
.47309 .77713 m .47575 .77868 L .47613 .77624 L F
0 0 .392 r
.47967 .77799 m .47613 .77624 L .47575 .77868 L F
.272 .679 .969 r
.47972 .77765 m .47967 .77799 L .47673 .7768 L F
.47972 .77765 m .47673 .7768 L .47725 .77688 L F
.47982 .77768 m .47967 .77799 L .47972 .77765 L F
0 .199 .728 r
.47982 .77768 m .47971 .7788 L .47967 .77799 L F
.654 .199 .16 r
.48122 .78018 m .48267 .77881 L .47971 .7788 L F
0 .175 .711 r
.47982 .77768 m .48122 .78018 L .47971 .7788 L F
.612 .764 .952 r
.47967 .77799 m .47575 .77868 L .475 .77756 L F
.47967 .77799 m .475 .77756 L .47587 .77645 L F
.749 .323 .239 r
.48122 .78018 m .48486 .78148 L .48267 .77881 L F
0 .155 .697 r
.47982 .77768 m .48213 .7803 L .48122 .78018 L F
.272 .679 .969 r
.47982 .77768 m .47725 .77688 L .47932 .77455 L F
.47725 .77688 m .47587 .77645 L .47876 .77486 L F
.47725 .77688 m .47876 .77486 L .47932 .77455 L F
.082 .13 .614 r
.47949 .77491 m .47982 .77768 L .47932 .77455 L F
.47992 .77589 m .47982 .77768 L .47947 .77473 L F
.48039 .77708 m .47995 .77754 L .47992 .77589 L F
.47995 .77754 m .47982 .77768 L .47992 .77589 L F
.272 .679 .969 r
.47725 .77688 m .47673 .7768 L .47587 .77645 L F
.627 .429 .594 r
.47586 .77762 m .47992 .77589 L .47587 .77645 L F
.47992 .77589 m .48027 .77574 L .47992 .7758 L F
.47992 .77589 m .47992 .7758 L .47587 .77645 L F
.658 .4 .519 r
.47932 .77455 m .47587 .77645 L .47992 .7758 L F
.47932 .77455 m .47992 .7758 L .48027 .77574 L F
.082 .13 .614 r
.47948 .77479 m .47949 .77491 L .47932 .77455 L F
.658 .4 .519 r
.47932 .77455 m .48027 .77574 L .47997 .77553 L F
.488 .839 .995 r
.47932 .77455 m .47543 .77425 L .47752 .77376 L F
.658 .4 .519 r
.47932 .77455 m .47997 .77553 L .47752 .77376 L F
.082 .13 .614 r
.47947 .77473 m .47948 .77479 L .47932 .77455 L F
.627 .429 .594 r
.48013 .7758 m .4807 .77743 L .48027 .77574 L F
.4775 .77692 m .48045 .77739 L .48013 .7758 L F
.48045 .77739 m .4807 .77743 L .48013 .7758 L F
.48052 .77743 m .48107 .77883 L .4807 .77743 L F
0 0 .311 r
.481 .77857 m .48094 .77649 L .48027 .77574 L F
0 .15 .693 r
.481 .77857 m .48213 .7803 L .48053 .77849 L F
.4813 .77863 m .48167 .77937 L .481 .77857 L F
.48167 .77937 m .48213 .7803 L .481 .77857 L F
.627 .429 .594 r
.47672 .77759 m .48107 .77883 L .48094 .7785 L F
0 .15 .693 r
.48059 .77808 m .47982 .77768 L .48039 .77708 L F
.627 .429 .594 r
.48006 .77745 m .48094 .7785 L .48052 .77743 L F
0 .15 .693 r
.4813 .77863 m .48053 .77849 L .47982 .77768 L F
.627 .429 .594 r
.47672 .77759 m .48094 .7785 L .48006 .77745 L F
0 0 .311 r
.48108 .77887 m .48106 .77858 L .481 .77857 L F
.48106 .77858 m .48094 .77649 L .481 .77857 L F
0 .15 .693 r
.48119 .77839 m .4813 .77863 L .47982 .77768 L F
0 0 .311 r
.48108 .77887 m .48119 .77839 L .48094 .77649 L F
0 .15 .693 r
.48119 .77839 m .48059 .77808 L .48094 .77649 L F
.48059 .77808 m .48039 .77708 L .48094 .77649 L F
.223 0 .293 r
.48027 .77574 m .48162 .77461 L .48024 .77525 L F
.48027 .77574 m .48094 .77649 L .48162 .77461 L F
.082 .13 .614 r
.48094 .77649 m .48 .77536 L .48162 .77461 L F
.48 .77536 m .47932 .77455 L .48162 .77461 L F
.223 0 .293 r
.48024 .77525 m .48162 .77461 L .48018 .77431 L F
.082 .13 .614 r
.48 .77536 m .47991 .77586 L .47947 .77473 L F
.208 .685 .935 r
.47752 .77376 m .48162 .77461 L .47932 .77455 L F
.223 0 .293 r
.47997 .77553 m .48018 .77431 L .47752 .77376 L F
.48027 .77574 m .48018 .77431 L .47997 .77553 L F
.082 .13 .614 r
.48094 .77649 m .48039 .77708 L .47991 .77586 L F
.48094 .77649 m .47991 .77586 L .48 .77536 L F
.627 .429 .594 r
.47672 .77759 m .48108 .77887 L .48107 .77883 L F
.47586 .77762 m .47657 .77779 L .47672 .77759 L F
.47657 .77779 m .48108 .77887 L .47672 .77759 L F
.47586 .77762 m .4807 .77743 L .4775 .77692 L F
.592 .525 .748 r
.4449 .76517 m .44275 .76567 L .44197 .76263 L F
.542 .45 .7 r
.44519 .76757 m .44275 .76567 L .4449 .76517 L F
.44519 .76757 m .44311 .76795 L .44275 .76567 L F
.798 .868 .9 r
.50339 .74806 m .50486 .74904 L .50574 .74743 L F
0 0 .062 r
.62121 .70989 m .62053 .71202 L .619 .71353 L F
.144 .123 .573 r
.62053 .71202 m .61894 .71472 L .619 .71353 L F
.568 .451 .68 r
.31628 .69687 m .31836 .69641 L .31803 .69413 L F
.542 .476 .731 r
.31628 .69687 m .31914 .69922 L .31836 .69641 L F
.528 .343 .574 r
.42919 .74318 m .4313 .74276 L .43132 .74048 L F
.476 .174 .374 r
.42919 .74318 m .4308 .74401 L .4313 .74276 L F
.42919 .74318 m .42882 .74478 L .4308 .74401 L F
.64 .145 .059 r
.52431 .70993 m .5272 .71167 L .5277 .71041 L F
.902 .489 .177 r
.5277 .71041 m .5272 .71167 L .5286 .71228 L F
.466 .132 .315 r
.33818 .65793 m .34042 .6576 L .34143 .65518 L F
.374 .044 .271 r
.34143 .65518 m .34239 .65702 L .34344 .65471 L F
.34143 .65518 m .34042 .6576 L .34239 .65702 L F
.264 0 0 r
.53853 .75992 m .53728 .76146 L .53611 .76114 L F
.588 .447 .657 r
.42027 .75442 m .42273 .75647 L .42249 .75405 L F
.42027 .75442 m .42048 .75685 L .42273 .75647 L F
.121 0 .242 r
.49515 .71856 m .4968 .71791 L .49721 .7157 L F
.413 .179 .447 r
.4945 .72048 m .4968 .71791 L .49515 .71856 L F
.578 .359 .547 r
.33136 .72611 m .33337 .72642 L .3337 .72405 L F
0 0 .159 r
.3337 .72405 m .33337 .72642 L .33417 .72505 L F
.3337 .72405 m .33417 .72505 L .33221 .72331 L F
.514 .446 .718 r
.34884 .69311 m .34759 .69715 L .34675 .69348 L F
.34884 .69311 m .35003 .69741 L .34759 .69715 L F
.509 .464 .743 r
.35003 .69741 m .35005 .6985 L .34759 .69715 L F
.684 .658 .819 r
.50667 .73467 m .50786 .73765 L .5045 .73699 L F
.719 .585 .704 r
.50786 .73765 m .50564 .74052 L .5045 .73699 L F
.667 .511 .663 r
.50786 .73765 m .50801 .74061 L .50564 .74052 L F
.713 .579 .703 r
.51052 .73697 m .50801 .74061 L .50786 .73765 L F
.512 0 0 r
.55893 .71077 m .55786 .71003 L .558 .71004 L F
0 .383 .829 r
.55893 .71077 m .56081 .7112 L .55786 .71003 L F
0 .499 .848 r
.56081 .7112 m .55771 .71002 L .55786 .71003 L F
.55771 .71002 m .55674 .70965 L .55786 .71003 L F
.512 0 0 r
.558 .71004 m .55786 .71003 L .55549 .70805 L F
0 .383 .829 r
.55893 .71077 m .56169 .71221 L .56081 .7112 L F
.339 .055 .328 r
.287 .62994 m .28888 .62733 L .28691 .62776 L F
.448 .687 .967 r
.39079 .64967 m .38883 .64979 L .3875 .64834 L F
.652 .146 .031 r
.55549 .70805 m .55465 .70902 L .55235 .70738 L F
.718 .228 .077 r
.55549 .70805 m .55786 .71003 L .55465 .70902 L F
.486 .272 .513 r
.41301 .68813 m .41208 .69017 L .41074 .68832 L F
.733 .524 .609 r
.47598 .74501 m .47665 .74891 L .47202 .74814 L F
.442 .326 .626 r
.47715 .74822 m .47598 .74501 L .47716 .74569 L F
.47715 .74822 m .47665 .74891 L .47598 .74501 L F
.77 .377 .31 r
.51117 .79218 m .5145 .79261 L .51262 .79375 L F
.622 .165 .146 r
.51262 .79375 m .5145 .79261 L .51577 .79354 L F
.605 .566 .784 r
.40227 .67208 m .40342 .66866 L .40132 .66909 L F
.40227 .67208 m .40452 .67168 L .40342 .66866 L F
.555 .409 .638 r
.40227 .67208 m .40456 .67413 L .40452 .67168 L F
.40227 .67208 m .40243 .67467 L .40456 .67413 L F
0 .25 .713 r
.56239 .71325 m .56428 .71418 L .56169 .71221 L F
.56239 .71325 m .56508 .71499 L .56428 .71418 L F
.267 .055 .394 r
.30976 .62815 m .31172 .62525 L .31134 .62758 L F
.427 .238 .52 r
.31132 .62988 m .30976 .62815 L .31134 .62758 L F
.31132 .62988 m .30956 .63043 L .30976 .62815 L F
.631 .165 .128 r
.56142 .69632 m .56397 .69811 L .56452 .69651 L F
.713 .749 .241 r
.56452 .69651 m .5655 .69315 L .56704 .69608 L F
.56452 .69651 m .56397 .69811 L .5655 .69315 L F
.666 .616 .789 r
.72283 .60011 m .72378 .60346 L .72664 .60083 L F
.433 0 0 r
.74219 .71571 m .74525 .71793 L .74385 .71848 L F
.289 .223 .608 r
.74525 .71793 m .74444 .72093 L .74385 .71848 L F
.658 .577 .753 r
.57479 .70475 m .57307 .70541 L .57138 .70204 L F
.797 .603 .64 r
.61447 .6686 m .61603 .67147 L .6181 .66895 L F
.635 .415 .566 r
.67932 .59243 m .68084 .58978 L .68014 .59 L F
.67932 .59243 m .68108 .5919 L .68084 .58978 L F
.676 .237 .2 r
.53391 .75431 m .53022 .75403 L .53168 .75546 L F
.995 .87 .556 r
.60604 .71039 m .60477 .7127 L .60637 .70951 L F
.60604 .71039 m .60553 .71321 L .60477 .7127 L F
.571 .04 0 r
.47686 .78613 m .478 .78535 L .48028 .7865 L F
.538 0 0 r
.478 .78535 m .48156 .78656 L .48028 .7865 L F
.028 .598 .762 r
.2643 .59004 m .26084 .58972 L .26291 .58953 L F
.352 .769 .978 r
.26471 .58932 m .2643 .59004 L .26291 .58953 L F
.26471 .58932 m .26612 .58983 L .2643 .59004 L F
.47 .126 .301 r
.46074 .73478 m .46293 .73452 L .46395 .7322 L F
.531 .187 .33 r
.46395 .7322 m .46593 .73352 L .46624 .73236 L F
.46395 .7322 m .46293 .73452 L .46593 .73352 L F
.649 .783 .946 r
.3311 .73175 m .33285 .73323 L .33468 .73263 L F
.582 .056 0 r
.73391 .58537 m .73159 .58411 L .73083 .58495 L F
.943 .731 .588 r
.62289 .69553 m .62487 .69416 L .62352 .69331 L F
.62289 .69553 m .62431 .69637 L .62487 .69416 L F
.703 .287 .254 r
.59741 .71587 m .59635 .71751 L .59403 .71553 L F
.815 .887 .462 r
.59769 .71457 m .59708 .71589 L .59741 .71587 L F
.59717 .71589 m .59635 .71751 L .59741 .71587 L F
.614 .345 .487 r
.59717 .71589 m .59635 .71751 L .59756 .71593 L F
.59403 .71553 m .59635 .71751 L .59717 .71589 L F
.815 .887 .462 r
.59708 .71589 m .59635 .71751 L .59717 .71589 L F
.117 0 0 r
.59403 .71553 m .59717 .71589 L .59741 .71587 L F
.59717 .71589 m .59756 .71593 L .59741 .71587 L F
0 0 .095 r
.59741 .71587 m .59756 .71593 L .59769 .71457 L F
.466 .442 .747 r
.5998 .72683 m .60087 .72349 L .59862 .72363 L F
.5998 .72683 m .60158 .72677 L .60087 .72349 L F
.444 .224 .484 r
.5998 .72683 m .60013 .7284 L .60158 .72677 L F
.085 0 0 r
.28669 .65304 m .2849 .65388 L .28288 .6542 L F
.204 0 0 r
.28857 .65225 m .2849 .65388 L .28669 .65304 L F
.349 .064 .331 r
.41565 .77292 m .41739 .77271 L .41794 .77065 L F
.615 .575 .786 r
.41794 .77065 m .42027 .77048 L .41931 .76749 L F
.744 .548 .63 r
.41739 .77271 m .42027 .77048 L .41794 .77065 L F
.647 .496 .665 r
.54632 .75622 m .54294 .75419 L .54511 .7537 L F
.54632 .75622 m .54321 .75718 L .54294 .75419 L F
.54 .386 .621 r
.67453 .60023 m .67743 .59814 L .6742 .598 L F
.295 .005 .29 r
.40118 .69875 m .39955 .69941 L .40198 .69692 L F
.358 .042 .285 r
.40402 .69645 m .40118 .69875 L .40198 .69692 L F
.734 .623 .735 r
.44454 .76165 m .44197 .76263 L .44412 .75983 L F
.592 .525 .748 r
.4449 .76517 m .44197 .76263 L .44454 .76165 L F
.588 .522 .748 r
.44627 .75932 m .44454 .76165 L .44412 .75983 L F
.44627 .75932 m .44667 .76176 L .44454 .76165 L F
.562 .418 .643 r
.44713 .76477 m .44454 .76165 L .44667 .76176 L F
.44713 .76477 m .4449 .76517 L .44454 .76165 L F
.657 .444 .583 r
.438 .65418 m .4386 .65657 L .43988 .65533 L F
0 0 .194 r
.74646 .623 m .74686 .6197 L .74716 .62139 L F
0 0 .216 r
.74716 .62139 m .74686 .6197 L .74775 .6193 L F
.579 .624 .861 r
.73728 .59789 m .73962 .59753 L .73813 .59503 L F
.2 0 0 r
.27584 .60339 m .27593 .60368 L .27416 .60353 L F
.27584 .60339 m .27769 .60372 L .27593 .60368 L F
.351 0 0 r
.36563 .70652 m .36942 .70561 L .36648 .70647 L F
.36563 .70652 m .36778 .70661 L .36942 .70561 L F
.017 0 0 r
.36942 .70561 m .36983 .70606 L .3716 .70535 L F
.36942 .70561 m .36778 .70661 L .36983 .70606 L F
.063 .414 .863 r
.486 .7814 m .48267 .77881 L .48486 .78148 L F
.733 .599 .707 r
.52029 .74582 m .52175 .74382 L .52051 .74326 L F
.52029 .74582 m .52362 .74581 L .52259 .74268 L F
.864 .641 .598 r
.52142 .74631 m .5207 .74812 L .51893 .74467 L F
.52321 .74748 m .5212 .748 L .52142 .74631 L F
.5212 .748 m .5207 .74812 L .52142 .74631 L F
.733 .599 .707 r
.52175 .74382 m .52259 .74268 L .52188 .74288 L F
.52175 .74382 m .52188 .74288 L .52051 .74326 L F
.459 .847 .982 r
.29667 .59625 m .29337 .59619 L .29547 .59586 L F
.246 .707 .95 r
.2976 .59563 m .29667 .59625 L .29547 .59586 L F
.2976 .59563 m .29915 .59628 L .29667 .59625 L F
.791 .672 .733 r
.55282 .73263 m .5493 .73481 L .54959 .7322 L F
.55282 .73263 m .55075 .73555 L .5493 .73481 L F
0 0 0 r
.52078 .78693 m .51882 .78742 L .51737 .78816 L F
.671 .504 .65 r
.40116 .67993 m .39974 .68089 L .40372 .68008 L F
.33 .148 .475 r
.28888 .62733 m .2904 .62755 L .29009 .62386 L F
.482 .378 .659 r
.29009 .62386 m .29339 .62353 L .29441 .62183 L F
.519 .282 .495 r
.29009 .62386 m .29256 .62632 L .29339 .62353 L F
.29009 .62386 m .2904 .62755 L .29256 .62632 L F
.732 .408 .432 r
.29945 .71784 m .30384 .71866 L .30256 .71658 L F
.534 .383 .621 r
.30553 .71195 m .30738 .71269 L .30679 .70876 L F
.453 .125 .319 r
.30679 .70876 m .30917 .70906 L .3098 .70726 L F
.576 .412 .621 r
.30679 .70876 m .30959 .71218 L .30917 .70906 L F
.30679 .70876 m .30738 .71269 L .30959 .71218 L F
0 0 0 r
.60732 .75369 m .60605 .75453 L .60735 .75334 L F
.416 .844 .697 r
.6041 .75543 m .60605 .75453 L .60732 .75369 L F
.631 .489 .671 r
.56142 .69632 m .55894 .69673 L .56074 .69406 L F
.56142 .69632 m .55894 .69673 L .56074 .69406 L F
.057 0 .042 r
.49976 .71323 m .49721 .7157 L .49876 .71476 L F
.278 0 .158 r
.49876 .71476 m .50176 .71259 L .49976 .71323 L F
.616 .592 .804 r
.42396 .78516 m .42483 .78129 L .4227 .78176 L F
.42396 .78516 m .42635 .78489 L .42483 .78129 L F
.655 .95 .72 r
.31835 .71751 m .32083 .71591 L .31842 .71487 L F
.52 .819 .999 r
.31842 .71487 m .32083 .71591 L .32204 .71524 L F
.655 .95 .72 r
.31873 .71727 m .31731 .71877 L .32083 .71591 L F
.662 .199 .144 r
.32204 .71524 m .32077 .71664 L .31842 .71487 L F
.419 .332 .652 r
.31842 .71487 m .31995 .71602 L .31969 .71471 L F
.31995 .71602 m .32077 .71664 L .32025 .71572 L F
.31995 .71602 m .32025 .71572 L .31969 .71471 L F
.655 .95 .72 r
.31835 .71751 m .31761 .7184 L .31873 .71727 L F
.31761 .7184 m .31731 .71877 L .31873 .71727 L F
.628 .238 0 r
.56674 .71806 m .56508 .71499 L .56596 .71585 L F
.667 .884 .978 r
.29996 .72983 m .30333 .72956 L .30185 .72882 L F
.319 0 0 r
.38731 .66564 m .38589 .66657 L .38354 .66686 L F
.342 0 0 r
.38893 .66564 m .38589 .66657 L .38731 .66564 L F
.461 .216 .456 r
.39849 .68291 m .4005 .68252 L .39974 .68089 L F
.499 .233 .442 r
.39974 .68089 m .40255 .68188 L .40372 .68008 L F
.39974 .68089 m .4005 .68252 L .40255 .68188 L F
.344 .729 .985 r
.49098 .75125 m .49366 .75154 L .49215 .75065 L F
.718 .637 .766 r
.33067 .72406 m .32819 .72611 L .33136 .72611 L F
.447 .127 .329 r
.32825 .72874 m .33136 .72611 L .32819 .72611 L F
.32825 .72874 m .32995 .72854 L .33136 .72611 L F
.678 .436 .548 r
.32995 .72854 m .33337 .72642 L .33136 .72611 L F
.771 .504 .53 r
.60778 .6658 m .61126 .6639 L .60788 .6631 L F
.60778 .6658 m .61135 .66609 L .61126 .6639 L F
.78 .511 .529 r
.61126 .6639 m .61135 .66609 L .61447 .66637 L F
.474 .64 .929 r
.71974 .72789 m .7209 .72605 L .71905 .72614 L F
.71974 .72789 m .72289 .72817 L .7209 .72605 L F
.815 .603 .616 r
.6193 .67439 m .6193 .67683 L .62279 .67734 L F
.806 .578 .592 r
.61931 .67923 m .62279 .67734 L .6193 .67683 L F
.61931 .67923 m .62094 .67984 L .62279 .67734 L F
.82 .599 .603 r
.62279 .67734 m .62094 .67984 L .62406 .68011 L F
.434 .69 .972 r
.732 .73302 m .73366 .73172 L .73171 .73141 L F
.732 .73302 m .73468 .7338 L .73366 .73172 L F
.672 .918 .975 r
.51577 .79354 m .5199 .79278 L .51904 .79368 L F
.321 0 0 r
.5199 .79278 m .52078 .79398 L .51904 .79368 L F
.5199 .79278 m .52208 .79248 L .52078 .79398 L F
.207 .727 .861 r
.44997 .7862 m .4489 .78605 L .44643 .78625 L F
.271 0 0 r
.4523 .78609 m .4489 .78605 L .44997 .7862 L F
.415 0 0 r
.33798 .73194 m .33736 .73334 L .33468 .73263 L F
.509 .013 .014 r
.3387 .73354 m .33724 .73359 L .33798 .73194 L F
.729 .558 .66 r
.33534 .73079 m .33847 .73336 L .33738 .73041 L F
.33847 .73336 m .3387 .73354 L .33862 .73336 L F
.33847 .73336 m .33862 .73336 L .33738 .73041 L F
.415 0 0 r
.33736 .73334 m .33724 .73359 L .33653 .73332 L F
.33736 .73334 m .33653 .73332 L .33468 .73263 L F
.509 .013 .014 r
.3387 .73354 m .33798 .73194 L .33962 .73151 L F
.271 .37 .782 r
.74204 .60848 m .74312 .61166 L .7445 .61031 L F
.488 .734 .98 r
.74312 .61166 m .74556 .61174 L .7445 .61031 L F
.757 .278 .105 r
.5442 .73893 m .54509 .73762 L .54456 .73692 L F
.5442 .73893 m .54713 .73982 L .54509 .73762 L F
.68 .469 .593 r
.54723 .74132 m .54791 .74074 L .54713 .73982 L F
.705 .172 0 r
.54567 .73811 m .54713 .73982 L .54791 .74001 L F
.351 .82 .906 r
.54791 .74001 m .5491 .73706 L .55014 .73755 L F
.682 .545 .693 r
.55014 .73755 m .55109 .74077 L .54791 .74001 L F
.351 .82 .906 r
.54791 .74001 m .5495 .73936 L .5491 .73706 L F
.54791 .74001 m .54713 .73982 L .5495 .73936 L F
.68 .469 .593 r
.54791 .74074 m .5495 .73936 L .54713 .73982 L F
.705 .172 0 r
.54509 .73762 m .54713 .73982 L .54567 .73811 L F
.659 .586 .762 r
.50564 .74052 m .50225 .73787 L .5045 .73699 L F
.426 .222 .498 r
.43132 .74048 m .43319 .73998 L .43277 .73854 L F
.54 .394 .631 r
.4313 .74276 m .43319 .73998 L .43132 .74048 L F
.464 .333 .617 r
.6142 .72728 m .61596 .72877 L .61441 .72946 L F
.6142 .72728 m .61631 .72685 L .61596 .72877 L F
.59 .316 .47 r
.48505 .72631 m .4874 .72629 L .48775 .72422 L F
.538 .292 .49 r
.4874 .72629 m .49003 .72367 L .48775 .72422 L F
.418 .119 .349 r
.39711 .70188 m .39647 .70455 L .39447 .70418 L F
.379 .117 .386 r
.39955 .69941 m .39892 .70147 L .39711 .70188 L F
.425 .126 .352 r
.39843 .70399 m .39711 .70188 L .39892 .70147 L F
.39843 .70399 m .39647 .70455 L .39711 .70188 L F
.802 .562 .576 r
.71243 .72287 m .71534 .7213 L .7147 .7208 L F
.71243 .72287 m .71547 .72368 L .71534 .7213 L F
.65 .5 .666 r
.71881 .72097 m .71824 .72132 L .71534 .7213 L F
.584 .922 .964 r
.71821 .7213 m .71534 .7213 L .71824 .72132 L F
.607 .387 .557 r
.71547 .72368 m .71841 .7213 L .71534 .7213 L F
.71841 .7213 m .71881 .72097 L .71568 .72127 L F
.71616 .72127 m .71568 .72127 L .71568 .72127 L F
.71841 .7213 m .71568 .72127 L .71616 .72127 L F
.214 .735 .845 r
.72107 .72109 m .71824 .72132 L .71881 .72097 L F
.717 .492 .583 r
.71881 .72097 m .71907 .72124 L .72107 .72109 L F
.607 .387 .557 r
.71547 .72368 m .71832 .72358 L .71876 .72127 L F
.71841 .7213 m .71876 .72127 L .71881 .72097 L F
.71547 .72368 m .71876 .72127 L .71841 .7213 L F
.717 .492 .583 r
.71907 .72124 m .71832 .72358 L .7212 .72348 L F
.71881 .72097 m .71876 .72127 L .71907 .72124 L F
.71876 .72127 m .71832 .72358 L .71907 .72124 L F
.214 .735 .845 r
.71872 .72127 m .71874 .72127 L .71859 .72128 L F
.71874 .72127 m .72183 .72086 L .71862 .72128 L F
.71874 .72127 m .71862 .72128 L .71859 .72128 L F
.72107 .72109 m .7214 .72099 L .71872 .72127 L F
.7214 .72099 m .72183 .72086 L .71872 .72127 L F
.72107 .72109 m .71859 .72128 L .71824 .72132 L F
.717 .492 .583 r
.71907 .72124 m .71916 .72134 L .72107 .72109 L F
.71916 .72134 m .7212 .72348 L .7211 .72155 L F
.71916 .72134 m .7211 .72155 L .72107 .72109 L F
.478 .77 .995 r
.71828 .72124 m .72183 .72086 L .71928 .71955 L F
.71825 .7213 m .71849 .72127 L .71828 .72124 L F
.71849 .72127 m .72183 .72086 L .71828 .72124 L F
.71824 .72132 m .71843 .7213 L .71825 .7213 L F
.71843 .7213 m .72183 .72086 L .71825 .7213 L F
.607 .387 .557 r
.71821 .7213 m .71568 .72127 L .71534 .7213 L F
.71841 .7213 m .71568 .72127 L .71821 .7213 L F
.584 .922 .964 r
.71667 .71984 m .71534 .7213 L .71821 .7213 L F
.71667 .71984 m .7147 .7208 L .71534 .7213 L F
.252 0 .212 r
.71667 .71984 m .7137 .72183 L .7147 .7208 L F
.71664 .71986 m .71646 .72074 L .7137 .72183 L F
.71646 .72074 m .71643 .72085 L .71621 .72093 L F
.71646 .72074 m .71621 .72093 L .7137 .72183 L F
.71666 .71988 m .71643 .72085 L .71664 .71986 L F
.478 .77 .995 r
.71824 .72132 m .71825 .7213 L .71821 .7213 L F
.724 .353 .348 r
.71911 .722 m .71619 .72188 L .71667 .71984 L F
.549 0 0 r
.71246 .71893 m .71504 .72031 L .71706 .72029 L F
.71246 .71893 m .71706 .72029 L .71705 .72028 L F
.252 0 .212 r
.71667 .71984 m .71666 .71988 L .71664 .71986 L F
.776 .68 .758 r
.71246 .71893 m .71705 .72028 L .71659 .71914 L F
.478 .77 .995 r
.71821 .7213 m .71914 .71979 L .71667 .71984 L F
.71914 .71979 m .71928 .71955 L .71854 .71964 L F
.71914 .71979 m .71854 .71964 L .71667 .71984 L F
.71825 .7213 m .71928 .71955 L .71821 .7213 L F
.724 .353 .348 r
.71911 .722 m .71667 .71984 L .71928 .71955 L F
.776 .68 .758 r
.71705 .72028 m .71707 .72025 L .71659 .71914 L F
.048 .246 .744 r
.71527 .71609 m .71709 .72029 L .7177 .71826 L F
.757 .986 .902 r
.71709 .72026 m .71504 .72031 L .7177 .71826 L F
.549 0 0 r
.71705 .72028 m .71706 .72029 L .71709 .72029 L F
.776 .68 .758 r
.71705 .72028 m .71709 .72029 L .71707 .72025 L F
.757 .986 .902 r
.71709 .72029 m .71706 .72029 L .71709 .72026 L F
.71706 .72029 m .71504 .72031 L .71709 .72026 L F
.252 0 .212 r
.71643 .72085 m .71619 .72188 L .71534 .72186 L F
.71643 .72085 m .71534 .72186 L .7137 .72183 L F
0 .034 .555 r
.71476 .7159 m .71441 .7179 L .71392 .71796 L F
.069 .622 .821 r
.71392 .71796 m .71441 .7179 L .7137 .71786 L F
.71392 .71796 m .7137 .71786 L .71084 .71767 L F
.706 .354 .379 r
.71084 .71767 m .71288 .71887 L .71392 .71796 L F
.818 .987 .721 r
.71392 .71796 m .71288 .71887 L .71356 .71779 L F
.628 .47 .649 r
.71084 .71767 m .7137 .71786 L .71259 .71563 L F
.818 .987 .721 r
.71392 .71796 m .7137 .71786 L .71424 .71718 L F
.628 .47 .649 r
.7137 .71786 m .71441 .7179 L .71404 .71744 L F
.7137 .71786 m .71404 .71744 L .71259 .71563 L F
.71084 .71767 m .71441 .7179 L .71259 .71563 L F
.299 .371 .769 r
.71259 .71563 m .71404 .71744 L .71476 .7159 L F
.818 .987 .721 r
.71424 .71718 m .71409 .71731 L .71476 .7159 L F
.299 .371 .769 r
.71404 .71744 m .71441 .7179 L .71476 .7159 L F
.818 .987 .721 r
.71409 .71731 m .71356 .71779 L .71476 .7159 L F
.7137 .71786 m .71356 .71779 L .71424 .71718 L F
.072 .031 .5 r
.71084 .71767 m .71246 .71893 L .71288 .71887 L F
.776 .68 .758 r
.7128 .71888 m .71476 .7159 L .71288 .71887 L F
.71246 .71893 m .71464 .71606 L .7128 .71888 L F
.71464 .71606 m .71476 .7159 L .7128 .71888 L F
.71246 .71893 m .71527 .71609 L .71476 .7159 L F
.299 .371 .769 r
.71259 .71563 m .71476 .7159 L .71527 .71609 L F
.71259 .71563 m .71468 .71599 L .71472 .71418 L F
.71468 .71599 m .71527 .71609 L .71507 .7154 L F
.71468 .71599 m .71507 .7154 L .71472 .71418 L F
.776 .68 .758 r
.71313 .71825 m .71659 .71914 L .71527 .71609 L F
.71246 .71893 m .71659 .71914 L .71313 .71825 L F
.345 .195 .53 r
.32885 .66368 m .33042 .66528 L .33072 .66294 L F
.32885 .66368 m .32863 .66591 L .33042 .66528 L F
.727 .639 .76 r
.5045 .73699 m .50225 .73787 L .50413 .73615 L F
.684 .658 .819 r
.50667 .73467 m .5045 .73699 L .50413 .73615 L F
.342 .699 .983 r
.30801 .59825 m .30597 .59822 L .30453 .59719 L F
.192 .621 .946 r
.73453 .70969 m .73331 .71013 L .73232 .71011 L F
.73453 .70969 m .73542 .71049 L .73331 .71013 L F
.705 .295 .267 r
.50097 .73947 m .50225 .73787 L .49881 .73747 L F
.838 .963 .888 r
.50413 .73615 m .50225 .73787 L .50145 .73726 L F
.998 .847 .551 r
.50145 .73726 m .50225 .73787 L .50097 .73947 L F
.347 .091 .376 r
.4968 .71791 m .49876 .71476 L .49721 .7157 L F
.815 .738 .779 r
.50873 .71879 m .51216 .71858 L .51026 .71852 L F
.50873 .71879 m .50981 .72092 L .51216 .71858 L F
.607 .396 .57 r
.50981 .72092 m .51208 .72098 L .51216 .71858 L F
.334 .807 .912 r
.51456 .71817 m .51216 .71858 L .51228 .71796 L F
.545 .817 .996 r
.51228 .71796 m .51216 .71858 L .51456 .71817 L F
.334 .807 .912 r
.51456 .71817 m .51026 .71852 L .51216 .71858 L F
.604 .412 .594 r
.51208 .72098 m .51456 .71817 L .51216 .71858 L F
.529 .41 .661 r
.31774 .69102 m .32004 .69364 L .31986 .6906 L F
.31774 .69102 m .31803 .69413 L .32004 .69364 L F
.657 .153 .037 r
.48378 .78663 m .48718 .78725 L .48628 .78829 L F
.659 .156 .039 r
.48628 .78829 m .48718 .78725 L .48943 .78892 L F
.405 .623 .941 r
.58231 .72105 m .58189 .72263 L .58088 .72067 L F
.58231 .72105 m .58451 .72322 L .58189 .72263 L F
.074 0 .302 r
.61894 .71472 m .61919 .71738 L .61742 .71836 L F
.144 .123 .573 r
.62053 .71202 m .62083 .71432 L .61894 .71472 L F
.085 0 .304 r
.62083 .71432 m .61919 .71738 L .61894 .71472 L F
.573 .163 .227 r
.50214 .72868 m .50465 .72876 L .50566 .72714 L F
.236 0 .042 r
.50566 .72714 m .5065 .72813 L .50757 .72629 L F
.50566 .72714 m .50465 .72876 L .5065 .72813 L F
.526 .611 .881 r
.53274 .75982 m .53611 .76114 L .53463 .7596 L F
.435 .056 .22 r
.58562 .666 m .58797 .6657 L .5888 .6637 L F
.339 0 .177 r
.5888 .6637 m .59008 .66515 L .59092 .663 L F
.5888 .6637 m .58797 .6657 L .59008 .66515 L F
0 .491 .789 r
.50689 .71838 m .50873 .71879 L .50522 .71777 L F
.326 .025 .292 r
.50689 .72059 m .50689 .71838 L .50522 .71777 L F
.229 .221 .641 r
.74254 .71447 m .74099 .71555 L .73885 .71275 L F
.74254 .71447 m .74219 .71571 L .74099 .71555 L F
.437 0 0 r
.37076 .64798 m .37257 .64863 L .37407 .64811 L F
.277 .779 .779 r
.37257 .64863 m .37637 .64773 L .37407 .64811 L F
.379 .632 .953 r
.28838 .60831 m .2889 .60692 L .28689 .60689 L F
.28838 .60831 m .29016 .60837 L .2889 .60692 L F
.993 .753 .455 r
.43838 .73731 m .43917 .73982 L .4394 .73776 L F
.754 .492 .536 r
.4394 .73776 m .43917 .73982 L .4425 .73998 L F
.6 .62 .842 r
.42581 .66415 m .42245 .66173 L .42453 .66159 L F
.443 .496 .819 r
.42715 .66197 m .42581 .66415 L .42453 .66159 L F
.182 .543 .928 r
.42761 .66473 m .42823 .66482 L .42581 .66415 L F
.887 .766 .723 r
.70527 .58929 m .70689 .5897 L .70722 .58737 L F
.761 .526 .577 r
.70379 .59149 m .70689 .5897 L .70527 .58929 L F
.70379 .59149 m .70702 .59202 L .70689 .5897 L F
0 0 0 r
.70795 .58739 m .70722 .58737 L .70689 .5897 L F
.945 .699 .232 r
.70689 .5897 m .70647 .59113 L .70795 .58739 L F
.70689 .5897 m .70702 .59202 L .70647 .59113 L F
0 0 0 r
.30585 .72626 m .30614 .72333 L .30447 .72343 L F
.30585 .72626 m .30596 .72547 L .30595 .72532 L F
.943 .951 .635 r
.30596 .72547 m .30462 .72843 L .30435 .7272 L F
0 0 0 r
.30596 .72547 m .30435 .7272 L .30599 .72566 L F
.30596 .72547 m .30599 .72566 L .30703 .72467 L F
.30595 .72532 m .30596 .72547 L .30614 .72333 L F
.818 .689 .722 r
.30652 .72849 m .30596 .72547 L .30585 .72626 L F
.457 .227 .476 r
.40118 .69875 m .39892 .70147 L .39955 .69941 L F
.903 .827 .762 r
.63641 .52928 m .63328 .53116 L .63505 .5282 L F
.63641 .52928 m .63447 .5319 L .63328 .53116 L F
.764 .595 .667 r
.63641 .52928 m .63656 .53186 L .63447 .5319 L F
.918 .843 .755 r
.63683 .5269 m .63641 .52928 L .63505 .5282 L F
.672 .497 .641 r
.63641 .52928 m .63967 .53154 L .63656 .53186 L F
.63641 .52928 m .64054 .52965 L .63967 .53154 L F
.817 .648 .673 r
.56492 .75382 m .5619 .75365 L .5623 .75126 L F
.815 .684 .719 r
.56492 .75382 m .56308 .75681 L .5619 .75365 L F
0 .378 .712 r
.58276 .72963 m .58699 .73115 L .58547 .73066 L F
0 .374 .697 r
.58694 .73114 m .58696 .73114 L .58699 .73115 L F
.292 .542 .918 r
.58401 .72857 m .58699 .73115 L .58276 .72963 L F
0 .296 .775 r
.58401 .72857 m .58694 .73114 L .58699 .73115 L F
.58632 .73059 m .58657 .73028 L .58694 .73114 L F
.58401 .72857 m .58657 .73028 L .58632 .73059 L F
.755 .865 .434 r
.58822 .7268 m .58657 .73028 L .58609 .7279 L F
.58822 .7268 m .58705 .72879 L .58657 .73028 L F
.871 .861 .411 r
.58705 .72879 m .5868 .72999 L .58657 .73028 L F
.925 .801 .333 r
.58694 .73114 m .58657 .73028 L .58646 .73101 L F
0 .374 .697 r
.58694 .73114 m .58547 .73066 L .58696 .73114 L F
.58694 .73114 m .58929 .732 L .58547 .73066 L F
.871 .861 .411 r
.5868 .72999 m .5862 .73275 L .58657 .73028 L F
.925 .801 .333 r
.58694 .73114 m .58646 .73101 L .5862 .73275 L F
.622 .402 .562 r
.64448 .52666 m .64445 .52914 L .64206 .52907 L F
.538 .326 .54 r
.64679 .52618 m .64445 .52914 L .64448 .52666 L F
.413 0 0 r
.26454 .60459 m .26642 .60501 L .26331 .60524 L F
.749 .56 .64 r
.32192 .7291 m .3262 .72944 L .32407 .72969 L F
.601 .518 .733 r
.3262 .72944 m .32913 .73234 L .32825 .72874 L F
.36 .804 .955 r
.43857 .78684 m .4376 .78657 L .43546 .78689 L F
.081 .641 .741 r
.44075 .78638 m .4376 .78657 L .43857 .78684 L F
.169 0 0 r
.3455 .654 m .34924 .65193 L .34654 .65298 L F
0 .231 .75 r
.74159 .6002 m .74189 .59947 L .73962 .59753 L F
0 .095 .652 r
.74159 .6002 m .74327 .60219 L .74189 .59947 L F
0 .262 .768 r
.45413 .77561 m .45334 .77635 L .45208 .77385 L F
.219 .63 .954 r
.45413 .77561 m .45571 .77676 L .45334 .77635 L F
.64 .121 0 r
.56321 .69179 m .5655 .69315 L .56262 .69257 L F
0 .364 .763 r
.54257 .69887 m .54254 .69857 L .54142 .69586 L F
.629 .221 0 r
.54254 .69857 m .54341 .70009 L .54235 .69829 L F
.54254 .69857 m .54235 .69829 L .54182 .6974 L F
0 .364 .763 r
.54257 .69887 m .5428 .69896 L .54254 .69857 L F
.5428 .69896 m .54381 .69936 L .54254 .69857 L F
.234 .336 .764 r
.58028 .7541 m .58249 .75616 L .58151 .75293 L F
.582 .717 .936 r
.35712 .70333 m .35465 .70386 L .35329 .702 L F
.493 .146 .306 r
.5563 .75167 m .55615 .7532 L .55398 .75321 L F
.567 .206 .317 r
.5592 .75133 m .55615 .7532 L .5563 .75167 L F
.805 .329 0 r
.52862 .78873 m .52808 .78708 L .52614 .78692 L F
.52862 .78873 m .52985 .78959 L .52808 .78708 L F
.581 .805 .985 r
.73468 .7338 m .73605 .7314 L .73366 .73172 L F
.73468 .7338 m .73722 .73247 L .73605 .7314 L F
.66 .821 .961 r
.73468 .7338 m .73846 .73326 L .73722 .73247 L F
.049 0 .081 r
.32266 .61352 m .32354 .61201 L .32504 .61101 L F
.169 0 0 r
.3455 .654 m .34768 .65339 L .34924 .65193 L F
.313 0 0 r
.34768 .65339 m .35112 .65172 L .34924 .65193 L F
.537 .251 .428 r
.60087 .72349 m .60386 .72313 L .60261 .72076 L F
0 0 .53 r
.60261 .72076 m .60386 .72313 L .60341 .71952 L F
.959 .734 .556 r
.5695 .74837 m .56947 .75156 L .57069 .75178 L F
0 .266 .773 r
.57363 .75345 m .57069 .75178 L .56947 .75156 L F
.28 .526 .909 r
.72857 .73004 m .73116 .7301 L .72796 .72899 L F
.72857 .73004 m .73171 .73141 L .73116 .7301 L F
.547 .355 .573 r
.44633 .75693 m .44627 .75932 L .44412 .75983 L F
0 0 0 r
.3782 .6687 m .3802 .66785 L .37745 .66848 L F
.574 .414 .627 r
.71164 .61126 m .71402 .61119 L .71342 .60874 L F
.911 .619 .127 r
.59393 .76088 m .59423 .76368 L .59281 .76241 L F
.608 .327 .466 r
.43319 .73998 m .43581 .73982 L .43277 .73854 L F
.082 .044 .51 r
.61621 .73959 m .61651 .74228 L .61508 .74333 L F
0 0 .282 r
.61651 .74228 m .61465 .74554 L .61508 .74333 L F
.953 .704 .523 r
.3149 .72957 m .31291 .7289 L .31269 .72574 L F
.953 .74 .576 r
.3149 .72957 m .31438 .7319 L .31291 .7289 L F
.762 .691 .783 r
.31702 .72738 m .3149 .72957 L .31269 .72574 L F
.735 .975 .728 r
.31702 .72738 m .31529 .72839 L .3149 .72957 L F
.861 .976 .673 r
.31729 .73114 m .31792 .72923 L .31765 .73086 L F
0 .126 .671 r
.31619 .73057 m .31657 .73151 L .31542 .73018 L F
.521 .292 .508 r
.3149 .72957 m .31657 .73151 L .31438 .7319 L F
.269 0 0 r
.31438 .7319 m .31657 .73151 L .31483 .73307 L F
.756 .689 .788 r
.31792 .72923 m .31657 .73151 L .31529 .72839 L F
.861 .976 .673 r
.31483 .73307 m .31657 .73151 L .31792 .72923 L F
.31483 .73307 m .31665 .73081 L .31729 .73114 L F
.31665 .73081 m .31792 .72923 L .31729 .73114 L F
0 .126 .671 r
.31529 .72839 m .31619 .73057 L .3149 .72957 L F
.31619 .73057 m .31542 .73018 L .3149 .72957 L F
.614 .8 .971 r
.54063 .73254 m .54333 .73261 L .54342 .73144 L F
.731 .439 .484 r
.54063 .73254 m .54405 .73449 L .54333 .73261 L F
.719 .466 .542 r
.54333 .73261 m .54473 .73182 L .54342 .73144 L F
.54333 .73261 m .54516 .73439 L .54473 .73182 L F
.54333 .73261 m .54405 .73449 L .54516 .73439 L F
.76 .647 .737 r
.30738 .71269 m .31142 .71542 L .30959 .71218 L F
.30738 .71269 m .30893 .71587 L .31142 .71542 L F
.74 .546 .632 r
.30893 .71587 m .31184 .71602 L .31142 .71542 L F
.446 .564 .881 r
.70256 .59566 m .7047 .59787 L .70463 .59483 L F
.275 .139 .507 r
.7047 .59787 m .70506 .59998 L .7053 .59933 L F
.262 .28 .69 r
.7047 .59787 m .70696 .59646 L .70463 .59483 L F
.5 .45 .733 r
.7053 .59933 m .70696 .59646 L .7047 .59787 L F
.474 .169 .368 r
.42091 .68044 m .42044 .68225 L .41828 .68262 L F
.431 .13 .353 r
.42253 .68175 m .42091 .68044 L .42315 .68006 L F
.42253 .68175 m .42044 .68225 L .42091 .68044 L F
.812 .609 .627 r
.74646 .623 m .74254 .6246 L .74308 .62228 L F
.74646 .623 m .74564 .62494 L .74254 .6246 L F
.678 .776 .298 r
.74629 .62328 m .74646 .623 L .74716 .62139 L F
.74629 .62328 m .74564 .62494 L .74646 .623 L F
.321 0 0 r
.29526 .7348 m .29394 .73415 L .2934 .73414 L F
.29526 .7348 m .29547 .7349 L .29394 .73415 L F
.919 .82 .733 r
.29394 .73415 m .29547 .7349 L .29697 .73212 L F
.29394 .73415 m .29697 .73212 L .29527 .73332 L F
.75 .948 .629 r
.29867 .72927 m .29697 .73212 L .29996 .72983 L F
.29867 .72927 m .29681 .73174 L .29697 .73212 L F
.707 .959 .697 r
.29681 .73174 m .29527 .73332 L .29697 .73212 L F
.048 0 0 r
.54061 .74804 m .542 .74755 L .54333 .74502 L F
0 0 0 r
.54333 .74502 m .542 .74755 L .54406 .74392 L F
.407 .429 .77 r
.56262 .69257 m .56074 .69406 L .55999 .69077 L F
.351 .323 .687 r
.56262 .69257 m .56142 .69632 L .56074 .69406 L F
0 .57 .723 r
.48156 .78656 m .48378 .78663 L .48028 .7865 L F
.97 .658 .288 r
.53737 .71896 m .53813 .71852 L .53713 .71769 L F
.53737 .71896 m .53825 .71974 L .53813 .71852 L F
.407 .21 .498 r
.31134 .62758 m .31172 .62525 L .31347 .62449 L F
.655 .792 .948 r
.3242 .7256 m .32819 .72611 L .32648 .72375 L F
.78 .771 .845 r
.32648 .72375 m .32819 .72611 L .33067 .72406 L F
0 .238 .668 r
.53574 .71672 m .53433 .71601 L .53365 .71487 L F
.53574 .71672 m .53713 .71769 L .53433 .71601 L F
.287 .787 .797 r
.52469 .73058 m .52456 .72954 L .52431 .72859 L F
.52469 .73058 m .52301 .73116 L .52456 .72954 L F
.377 0 0 r
.52741 .72752 m .52431 .72859 L .52456 .72954 L F
.636 .075 0 r
.53112 .74321 m .53426 .74544 L .53529 .74538 L F
.446 .186 .425 r
.53753 .74347 m .53529 .74538 L .53551 .74369 L F
.944 .961 .705 r
.53529 .74538 m .53581 .74219 L .53551 .74369 L F
.53529 .74538 m .53426 .74544 L .53581 .74219 L F
.446 .186 .425 r
.53753 .74347 m .53732 .74541 L .53529 .74538 L F
.734 .523 .606 r
.53834 .74846 m .53529 .74538 L .53732 .74541 L F
.441 .851 .677 r
.50654 .72146 m .50336 .72329 L .50309 .72358 L F
.825 .989 .87 r
.50336 .72329 m .50178 .72598 L .50309 .72358 L F
.56 .671 .913 r
.31585 .59843 m .31503 .60058 L .31344 .59816 L F
.31585 .59843 m .31704 .60019 L .31503 .60058 L F
.565 .529 .774 r
.71674 .72643 m .71832 .72358 L .71547 .72368 L F
.71674 .72643 m .71905 .72614 L .71832 .72358 L F
.595 .91 .98 r
.73846 .73326 m .73977 .7318 L .73722 .73247 L F
.73846 .73326 m .74073 .73233 L .73977 .7318 L F
.745 .665 .771 r
.51123 .74284 m .51245 .74594 L .50899 .74541 L F
.393 .236 .546 r
.51074 .74706 m .50899 .74541 L .51245 .74594 L F
.578 .546 .783 r
.51372 .74252 m .51245 .74594 L .51123 .74284 L F
.51372 .74252 m .51463 .74555 L .51245 .74594 L F
0 0 0 r
.51332 .74591 m .51245 .74594 L .51463 .74555 L F
.51332 .74591 m .51074 .74706 L .51245 .74594 L F
0 0 .401 r
.62373 .70329 m .62268 .70205 L .62457 .70087 L F
.62373 .70329 m .6227 .70438 L .62268 .70205 L F
.768 .689 .775 r
.29016 .60837 m .2917 .61148 L .29379 .60865 L F
.495 .315 .566 r
.2917 .61148 m .2937 .61102 L .29379 .60865 L F
.458 .433 .742 r
.2917 .61148 m .29404 .61311 L .2937 .61102 L F
.621 .441 .617 r
.54959 .7322 m .5493 .73481 L .54711 .73493 L F
.237 0 .004 r
.36974 .71931 m .36918 .71801 L .37118 .71746 L F
.36974 .71931 m .36772 .71989 L .36918 .71801 L F
.503 .91 .865 r
.48486 .78148 m .48688 .78056 L .486 .7814 L F
0 0 .51 r
.57455 .73221 m .57472 .7318 L .57353 .72935 L F
0 0 0 r
.57455 .73221 m .5738 .73425 L .57472 .7318 L F
.646 .389 .516 r
.30917 .70906 m .31136 .70723 L .3098 .70726 L F
.99 .734 .432 r
.55014 .73755 m .5491 .73706 L .5493 .73481 L F
.786 .676 .743 r
.55075 .73555 m .55014 .73755 L .5493 .73481 L F
.16 .215 .671 r
.55235 .73923 m .55014 .73755 L .55341 .73764 L F
.55235 .73923 m .55109 .74077 L .55014 .73755 L F
.616 .944 .944 r
.50178 .72598 m .5007 .72562 L .50102 .72612 L F
.825 .989 .87 r
.50336 .72329 m .5007 .72562 L .50178 .72598 L F
.56 .202 .318 r
.45062 .73782 m .44964 .7399 L .45249 .73935 L F
.544 .209 .349 r
.45062 .73782 m .45249 .73935 L .45297 .73772 L F
.471 .199 .419 r
.43288 .66933 m .43251 .67125 L .43031 .67171 L F
.582 .651 .884 r
.43369 .66644 m .43288 .66933 L .432 .66554 L F
.43369 .66644 m .43505 .66881 L .43288 .66933 L F
.558 .277 .446 r
.43288 .66933 m .43479 .67098 L .43251 .67125 L F
.498 .288 .524 r
.43505 .66881 m .43479 .67098 L .43288 .66933 L F
.693 .297 .293 r
.59927 .66232 m .60219 .66117 L .59885 .66067 L F
.59927 .66232 m .6011 .66292 L .60219 .66117 L F
.413 0 .135 r
.60219 .66117 m .60337 .66234 L .60498 .66183 L F
.60219 .66117 m .6011 .66292 L .60337 .66234 L F
.825 .627 .636 r
.61615 .67388 m .61939 .67196 L .61603 .67147 L F
.61615 .67388 m .6193 .67439 L .61939 .67196 L F
.845 .703 .705 r
.46185 .75373 m .46243 .75672 L .45974 .75587 L F
.835 .723 .74 r
.45974 .75587 m .46092 .75957 L .46243 .75672 L F
.282 0 0 r
.46243 .75672 m .46244 .75681 L .45974 .75587 L F
.117 .193 .667 r
.4638 .7555 m .46243 .75672 L .46185 .75373 L F
0 0 0 r
.4638 .7555 m .46244 .75681 L .46243 .75672 L F
.983 .757 .519 r
.57208 .68228 m .57224 .68212 L .57244 .67937 L F
.57106 .68147 m .57208 .68228 L .57244 .67937 L F
.746 .51 .573 r
.56894 .68413 m .57222 .68239 L .57106 .68147 L F
.56894 .68413 m .57222 .68531 L .57222 .68239 L F
.501 .818 .503 r
.57325 .68111 m .57121 .68314 L .57106 .68147 L F
.57325 .68111 m .57186 .68249 L .57127 .68308 L F
.57139 .68296 m .57127 .68308 L .57121 .68314 L F
.57325 .68111 m .57127 .68308 L .57139 .68296 L F
.983 .757 .519 r
.57208 .68228 m .57222 .68239 L .57224 .68212 L F
.964 .845 .675 r
.57492 .68043 m .57106 .68147 L .57244 .67937 L F
.47 0 .053 r
.34601 .72948 m .34444 .73097 L .34266 .73023 L F
.482 .074 .188 r
.348 .729 m .34444 .73097 L .34601 .72948 L F
.356 .055 .31 r
.75008 .61039 m .74838 .61113 L .75105 .6088 L F
0 0 .248 r
.75272 .60557 m .75105 .6088 L .75039 .60707 L F
.75272 .60557 m .75246 .60751 L .75105 .6088 L F
.245 .095 .47 r
.75246 .60751 m .75008 .61039 L .75105 .6088 L F
.718 .581 .701 r
.30893 .71587 m .31186 .71803 L .31184 .71602 L F
.93 .941 .782 r
.60553 .71321 m .60383 .71606 L .60322 .71456 L F
.98 .844 .637 r
.60383 .71606 m .60204 .71737 L .60322 .71456 L F
.60383 .71606 m .60306 .71817 L .60204 .71737 L F
.636 .685 .879 r
.4185 .7754 m .42188 .77607 L .42053 .77299 L F
.363 .376 .74 r
.42188 .77607 m .42261 .77262 L .42053 .77299 L F
.42188 .77607 m .42345 .77561 L .42261 .77262 L F
.357 .353 .718 r
.42188 .77607 m .42404 .77814 L .42345 .77561 L F
.452 .367 .669 r
.42188 .77607 m .42241 .77878 L .42404 .77814 L F
.715 .699 .833 r
.41739 .77271 m .4185 .7754 L .42053 .77299 L F
.035 0 0 r
.37447 .70419 m .37572 .70413 L .37718 .70227 L F
.316 0 .049 r
.37718 .70227 m .37785 .70369 L .37926 .70185 L F
.37718 .70227 m .37572 .70413 L .37785 .70369 L F
0 0 0 r
.35409 .65042 m .35595 .64989 L .35722 .64924 L F
.226 0 0 r
.35595 .64989 m .35936 .64962 L .35722 .64924 L F
.983 .698 .355 r
.57138 .70204 m .57157 .7046 L .57041 .7008 L F
.946 .771 .633 r
.57157 .7046 m .57115 .70688 L .57258 .70753 L F
.945 .633 .413 r
.57115 .70688 m .57147 .70908 L .57258 .70753 L F
.211 .689 .935 r
.57041 .7008 m .5737 .70143 L .57138 .70204 L F
.658 .577 .753 r
.57479 .70475 m .57138 .70204 L .5737 .70143 L F
.79 .713 .779 r
.57157 .7046 m .57258 .70753 L .57479 .70475 L F
.925 .595 .395 r
.57258 .70753 m .57147 .70908 L .573 .70964 L F
.501 .342 .598 r
.42461 .74882 m .42663 .74847 L .42659 .74558 L F
.516 .385 .641 r
.42473 .75122 m .42663 .74847 L .42461 .74882 L F
.111 0 0 r
.38008 .71428 m .37973 .71337 L .38153 .71254 L F
.38008 .71428 m .37807 .71494 L .37973 .71337 L F
.724 .587 .702 r
.7054 .58653 m .70722 .58737 L .70569 .58427 L F
.887 .766 .723 r
.70527 .58929 m .70722 .58737 L .7054 .58653 L F
0 0 0 r
.70795 .58739 m .7098 .58665 L .70722 .58737 L F
.617 .483 .677 r
.42035 .78072 m .4227 .78176 L .42241 .77878 L F
.713 .579 .703 r
.51052 .73697 m .51208 .74175 L .50801 .74061 L F
.412 .401 .737 r
.51396 .74121 m .51052 .73697 L .51377 .73745 L F
.51396 .74121 m .51208 .74175 L .51052 .73697 L F
.796 .405 .313 r
.56608 .70414 m .56789 .7067 L .56975 .70566 L F
.647 .185 .142 r
.56975 .70566 m .56789 .7067 L .57115 .70688 L F
.422 .259 .553 r
.56975 .70566 m .57115 .70688 L .57157 .7046 L F
.56975 .70566 m .57115 .70688 L .57157 .7046 L F
.916 .957 .8 r
.70913 .58574 m .7098 .58665 L .70795 .58739 L F
.181 .41 .848 r
.56574 .73748 m .56724 .73993 L .56481 .73838 L F
.538 .408 .651 r
.31479 .70489 m .3169 .70464 L .31672 .70182 L F
.625 .553 .754 r
.31532 .70744 m .3169 .70464 L .31479 .70489 L F
.902 .976 .804 r
.60553 .71321 m .60322 .71456 L .60477 .7127 L F
.161 .313 .771 r
.72198 .61947 m .72435 .62159 L .72267 .6199 L F
.19 0 .349 r
.539 .74388 m .53732 .74541 L .53753 .74347 L F
.466 .781 .998 r
.28286 .59398 m .28235 .59518 L .28088 .59409 L F
.28286 .59398 m .2844 .5949 L .28235 .59518 L F
.812 .528 .509 r
.61135 .66609 m .61447 .6686 L .61447 .66637 L F
.823 .77 .802 r
.71698 .71382 m .71623 .71506 L .7163 .71341 L F
.245 .289 .711 r
.57679 .73995 m .57737 .74322 L .57888 .74208 L F
0 0 .431 r
.57794 .74567 m .57888 .74208 L .57737 .74322 L F
.575 .513 .748 r
.67315 .60678 m .67358 .60844 L .6758 .60622 L F
.654 .642 .826 r
.67358 .60844 m .67716 .60921 L .6758 .60622 L F
.409 .396 .734 r
.32685 .60833 m .32537 .60865 L .32493 .60693 L F
.342 .149 .468 r
.32504 .61101 m .32537 .60865 L .32685 .60833 L F
.863 .619 .568 r
.62094 .67984 m .62379 .68257 L .62406 .68011 L F
.02 0 0 r
.3636 .70654 m .36563 .70652 L .36648 .70647 L F
.679 .385 .468 r
.51208 .74175 m .50787 .74289 L .50801 .74061 L F
.51208 .74175 m .51123 .74284 L .50787 .74289 L F
.53 .201 .354 r
.51372 .74252 m .51208 .74175 L .51396 .74121 L F
.51372 .74252 m .51123 .74284 L .51208 .74175 L F
.763 .677 .768 r
.71083 .60651 m .71308 .60569 L .71177 .60289 L F
.72 .659 .788 r
.71177 .60289 m .71308 .60569 L .71498 .60291 L F
.637 .732 .917 r
.71308 .60569 m .71591 .6053 L .71498 .60291 L F
.819 .676 .705 r
.70243 .58606 m .70569 .58427 L .70403 .5835 L F
.70243 .58606 m .7054 .58653 L .70569 .58427 L F
.568 0 0 r
.64757 .51854 m .65054 .52031 L .6491 .51799 L F
.172 0 .314 r
.71342 .60874 m .71557 .60781 L .71591 .6053 L F
.507 .372 .631 r
.71342 .60874 m .71618 .60867 L .71557 .60781 L F
.71342 .60874 m .71402 .61119 L .71618 .60867 L F
.652 .279 .326 r
.53121 .79278 m .53325 .79458 L .53101 .79434 L F
.99 .816 .573 r
.53199 .79161 m .53355 .78991 L .52985 .78959 L F
.53199 .79161 m .53266 .79212 L .53355 .78991 L F
.097 0 .19 r
.53355 .78991 m .53266 .79212 L .5351 .78888 L F
.475 .227 .458 r
.33278 .66247 m .33095 .66077 L .33072 .66294 L F
.33278 .66247 m .33289 .66054 L .33095 .66077 L F
.842 .754 .766 r
.60682 .70113 m .60858 .70204 L .60728 .70488 L F
.975 .746 .528 r
.60728 .70488 m .60561 .70642 L .60516 .70395 L F
.60728 .70488 m .60697 .70727 L .60561 .70642 L F
.693 .73 .879 r
.58128 .70465 m .57716 .70402 L .57925 .70392 L F
.19 .673 .929 r
.57925 .70392 m .58179 .70443 L .58128 .70465 L F
.449 .215 .466 r
.31836 .6169 m .31795 .61893 L .31607 .61956 L F
.284 .02 .326 r
.31836 .6169 m .32073 .61416 L .32023 .61622 L F
.415 .185 .454 r
.31963 .61813 m .31836 .6169 L .32023 .61622 L F
.31963 .61813 m .31795 .61893 L .31836 .6169 L F
.775 .632 .703 r
.54405 .73449 m .54443 .73588 L .54711 .73493 L F
.618 .662 .87 r
.54711 .73493 m .5493 .73481 L .54849 .73217 L F
.841 .374 .042 r
.56796 .72112 m .56783 .72257 L .56764 .72025 L F
.56796 .72112 m .56933 .72336 L .56783 .72257 L F
.219 .001 .354 r
.28443 .63278 m .28619 .63278 L .287 .62994 L F
.139 0 .186 r
.28443 .63278 m .28515 .63441 L .28619 .63278 L F
.28443 .63278 m .28373 .63518 L .28515 .63441 L F
.822 .582 .576 r
.70124 .58289 m .70366 .58095 L .7014 .58067 L F
.70124 .58289 m .70403 .5835 L .70366 .58095 L F
.668 .72 .888 r
.39818 .66843 m .40132 .66909 L .40017 .668 L F
.54 .782 .987 r
.40132 .66909 m .40342 .66866 L .40017 .668 L F
.633 .403 .551 r
.55111 .75395 m .5485 .7566 L .54869 .75412 L F
.55111 .75395 m .55105 .75678 L .5485 .7566 L F
.552 .315 .509 r
.55398 .75321 m .55105 .75678 L .55111 .75395 L F
.87 .943 .579 r
.31949 .72527 m .31803 .72766 L .31836 .72853 L F
0 .162 .697 r
.31803 .72766 m .31928 .72937 L .31822 .72926 L F
.31794 .72899 m .31822 .72926 L .31792 .72923 L F
.756 .689 .788 r
.31792 .72923 m .31529 .72839 L .31836 .72853 L F
.659 .171 .081 r
.31836 .72853 m .31741 .72849 L .31702 .72738 L F
0 .162 .697 r
.31803 .72766 m .31792 .72923 L .31836 .72853 L F
.31803 .72766 m .31822 .72926 L .31794 .72899 L F
.659 .171 .081 r
.31741 .72849 m .31529 .72839 L .31654 .72766 L F
.31741 .72849 m .31654 .72766 L .31702 .72738 L F
.393 .006 .181 r
.40372 .68008 m .405 .68121 L .40489 .67888 L F
.40372 .68008 m .40255 .68188 L .405 .68121 L F
.445 .186 .427 r
.32266 .61352 m .32023 .61622 L .32073 .61416 L F
.505 .325 .57 r
.43031 .67171 m .43025 .67407 L .42819 .67452 L F
.521 .273 .481 r
.43012 .67625 m .42819 .67452 L .43025 .67407 L F
.43012 .67625 m .42792 .67667 L .42819 .67452 L F
.09 0 0 r
.55536 .73807 m .55341 .73764 L .55605 .73717 L F
.55536 .73807 m .55235 .73923 L .55341 .73764 L F
.559 .445 .681 r
.42048 .75685 m .42304 .75916 L .42273 .75647 L F
.42048 .75685 m .42087 .7596 L .42304 .75916 L F
.395 0 .115 r
.33705 .65973 m .33606 .65819 L .33534 .65976 L F
.33705 .65973 m .33818 .65793 L .33606 .65819 L F
.447 .128 .331 r
.52565 .74318 m .52786 .74276 L .52845 .74082 L F
.812 .496 .455 r
.52845 .74082 m .52786 .74276 L .53112 .74321 L F
.535 .565 .832 r
.42051 .65653 m .41898 .65856 L .41757 .65572 L F
.42051 .65653 m .4209 .65816 L .41898 .65856 L F
.516 .542 .82 r
.42168 .65997 m .41898 .65856 L .4209 .65816 L F
.658 .577 .753 r
.57479 .70475 m .57316 .70316 L .57157 .7046 L F
.57479 .70475 m .5737 .70143 L .57316 .70316 L F
.66 .368 .467 r
.74836 .61272 m .74556 .61174 L .74838 .61113 L F
.417 .165 .421 r
.75008 .61039 m .74836 .61272 L .74838 .61113 L F
.92 .733 .633 r
.60698 .68278 m .60507 .68412 L .60446 .682 L F
.60698 .68278 m .60664 .68518 L .60507 .68412 L F
.577 .413 .623 r
.35096 .68614 m .35067 .68828 L .34872 .68845 L F
.582 .403 .604 r
.35081 .69053 m .34872 .68845 L .35067 .68828 L F
.35081 .69053 m .34868 .6912 L .34872 .68845 L F
0 .078 .558 r
.49284 .74523 m .49259 .74496 L .49129 .74386 L F
.938 .571 .268 r
.49471 .74805 m .49259 .74496 L .49284 .74523 L F
.34 .316 .685 r
.74654 .7227 m .7446 .72405 L .74444 .72093 L F
0 0 .315 r
.74654 .7227 m .74542 .72676 L .7446 .72405 L F
.46 .25 .507 r
.39189 .69102 m .39381 .69055 L .39402 .68831 L F
.469 .268 .524 r
.39189 .69102 m .39367 .69294 L .39381 .69055 L F
.39189 .69102 m .39167 .6935 L .39367 .69294 L F
.338 .055 .329 r
.50718 .72345 m .50897 .72346 L .50981 .72092 L F
.546 .476 .728 r
.50757 .72629 m .50897 .72346 L .50718 .72345 L F
.824 .589 .583 r
.70527 .58929 m .7054 .58653 L .70243 .58606 L F
.587 .592 .824 r
.54029 .7344 m .5369 .73155 L .54063 .73254 L F
.573 .886 .99 r
.54226 .73148 m .54063 .73254 L .54342 .73144 L F
.731 .439 .484 r
.54063 .73254 m .54029 .7344 L .54405 .73449 L F
0 0 .17 r
.54173 .73253 m .54029 .7344 L .54063 .73254 L F
.587 .592 .824 r
.54029 .7344 m .53823 .73476 L .5369 .73155 L F
.529 .087 .144 r
.54028 .73177 m .53838 .73319 L .54173 .73253 L F
.53973 .73149 m .5394 .7319 L .54028 .73177 L F
.5394 .7319 m .53838 .73319 L .54028 .73177 L F
.573 .886 .99 r
.54097 .73153 m .54095 .73167 L .54226 .73148 L F
.54092 .73168 m .54063 .73254 L .54226 .73148 L F
.23 0 0 r
.54473 .73182 m .54097 .73153 L .54342 .73144 L F
.54473 .73182 m .54173 .73253 L .54097 .73153 L F
0 0 .501 r
.54173 .73253 m .54109 .73058 L .54097 .73153 L F
.54109 .73058 m .54092 .73005 L .54097 .73153 L F
.573 .886 .99 r
.54097 .73153 m .54092 .73168 L .54095 .73167 L F
0 0 .17 r
.54173 .73253 m .54063 .73254 L .54097 .73153 L F
.382 0 0 r
.50051 .79068 m .50161 .79015 L .50396 .7908 L F
.414 .813 .983 r
.31344 .59816 m .31153 .59856 L .31022 .59799 L F
0 0 0 r
.30028 .6434 m .29887 .64451 L .30126 .64195 L F
.006 0 .009 r
.30028 .6434 m .30126 .64195 L .30276 .64094 L F
.244 .04 .392 r
.30126 .64195 m .30315 .63885 L .30276 .64094 L F
.259 0 .208 r
.29374 .64932 m .2964 .64705 L .29544 .64946 L F
.125 0 .137 r
.2964 .64705 m .29887 .64451 L .2977 .64632 L F
.189 0 .242 r
.2964 .64705 m .2973 .64867 L .29544 .64946 L F
.2964 .64705 m .2977 .64632 L .2973 .64867 L F
.456 .241 .498 r
.31347 .62449 m .31386 .62237 L .31574 .62172 L F
.563 .519 .764 r
.32652 .6048 m .32493 .60693 L .32384 .60352 L F
.409 .396 .734 r
.32685 .60833 m .32493 .60693 L .32652 .6048 L F
.427 .145 .38 r
.36528 .67448 m .3647 .67637 L .36277 .67668 L F
.375 .09 .348 r
.3672 .67391 m .3647 .67637 L .36528 .67448 L F
.585 .29 .435 r
.50981 .72092 m .51196 .72288 L .51208 .72098 L F
.50981 .72092 m .50897 .72346 L .51196 .72288 L F
.546 .479 .732 r
.29277 .61696 m .29475 .6165 L .29404 .61311 L F
.588 .474 .691 r
.29285 .6192 m .29475 .6165 L .29277 .61696 L F
0 .358 .728 r
.54698 .725 m .55021 .7265 L .54807 .72581 L F
.613 .161 .154 r
.52419 .78691 m .52078 .78693 L .52317 .78837 L F
.722 .288 .22 r
.52317 .78837 m .52634 .78897 L .52419 .78691 L F
.608 .341 .486 r
.52419 .78691 m .52634 .78897 L .52614 .78692 L F
.485 0 0 r
.49374 .78538 m .49496 .78434 L .49144 .78441 L F
.489 0 0 r
.49587 .78582 m .49496 .78434 L .49374 .78538 L F
.49587 .78582 m .49742 .78475 L .49496 .78434 L F
.229 0 .011 r
.29253 .65107 m .29374 .64932 L .29544 .64946 L F
.572 .627 .868 r
.70748 .60545 m .70854 .60217 L .70615 .60312 L F
.70748 .60545 m .70933 .60535 L .70854 .60217 L F
.558 .44 .675 r
.52837 .76535 m .53065 .76731 L .53064 .76512 L F
.678 .47 .597 r
.63656 .53186 m .63427 .53433 L .63447 .5319 L F
.63656 .53186 m .63739 .53416 L .63427 .53433 L F
.581 .371 .56 r
.63967 .53154 m .63739 .53416 L .63656 .53186 L F
.292 .542 .918 r
.58401 .72857 m .58276 .72963 L .58254 .7278 L F
.098 0 0 r
.35825 .72391 m .35572 .72521 L .3564 .72454 L F
0 0 .038 r
.2977 .64632 m .29887 .64451 L .30028 .6434 L F
.541 .291 .486 r
.48281 .74564 m .48294 .74825 L .48081 .74761 L F
.674 .603 .767 r
.48281 .74564 m .48564 .74266 L .48319 .74434 L F
0 0 .17 r
.48329 .74471 m .48281 .74564 L .48319 .74434 L F
.674 .603 .767 r
.48281 .74564 m .4871 .74603 L .48564 .74266 L F
.501 .261 .483 r
.48525 .74771 m .48281 .74564 L .48329 .74471 L F
.48525 .74771 m .48294 .74825 L .48281 .74564 L F
.52 .348 .588 r
.39402 .68831 m .39612 .68787 L .39615 .68527 L F
.501 .287 .52 r
.39381 .69055 m .39612 .68787 L .39402 .68831 L F
.867 .729 .708 r
.60747 .6989 m .60858 .70204 L .60682 .70113 L F
.727 .607 .723 r
.4871 .74603 m .48607 .74891 L .49 .74858 L F
0 0 .56 r
.57952 .71762 m .58088 .72067 L .58087 .71843 L F
.356 .02 .25 r
.39565 .70591 m .39447 .70418 L .39647 .70455 L F
.39565 .70591 m .39359 .70646 L .39447 .70418 L F
.419 .31 .623 r
.61596 .72877 m .6162 .73154 L .61441 .72946 L F
.155 .315 .774 r
.57679 .73995 m .57544 .73677 L .57576 .73776 L F
.572 .004 0 r
.53196 .73106 m .53338 .73178 L .535 .73174 L F
.564 .461 .696 r
.67315 .60678 m .6758 .60622 L .6748 .60287 L F
.477 .68 .955 r
.2738 .59165 m .27329 .59328 L .27181 .59195 L F
.2738 .59165 m .2757 .59327 L .27329 .59328 L F
.578 .055 0 r
.49277 .78936 m .49619 .7897 L .49501 .79016 L F
.529 0 0 r
.49501 .79016 m .49619 .7897 L .4985 .79073 L F
.719 .433 .492 r
.51082 .78955 m .50936 .79215 L .508 .79133 L F
.599 .865 .993 r
.51182 .7884 m .51082 .78955 L .51005 .78849 L F
.51182 .7884 m .51293 .78913 L .51082 .78955 L F
.831 .577 .556 r
.51117 .79218 m .50936 .79215 L .51082 .78955 L F
.455 .228 .479 r
.31607 .61956 m .31756 .62057 L .31574 .62172 L F
.31607 .61956 m .31795 .61893 L .31756 .62057 L F
.567 .206 .317 r
.5592 .75133 m .55889 .7533 L .55615 .7532 L F
.782 .41 .352 r
.5619 .75365 m .5592 .75133 L .56076 .75055 L F
.421 .007 .146 r
.55835 .75416 m .55759 .75526 L .55602 .75465 L F
.998 .85 .557 r
.55841 .75402 m .55784 .75535 L .55759 .75526 L F
.55889 .7533 m .55784 .75535 L .55841 .75402 L F
.421 .007 .146 r
.55875 .75408 m .55759 .75526 L .55835 .75416 L F
.998 .85 .557 r
.55872 .75363 m .55847 .75558 L .55784 .75535 L F
.55889 .7533 m .55887 .75342 L .55872 .75363 L F
.55887 .75342 m .55847 .75558 L .55872 .75363 L F
.421 .007 .146 r
.55843 .75397 m .55602 .75465 L .55615 .7532 L F
.55875 .75408 m .55835 .75416 L .55841 .75402 L F
.55875 .75408 m .55841 .75402 L .55844 .75398 L F
.454 .402 .71 r
.55864 .75378 m .55875 .75408 L .55844 .75398 L F
.782 .41 .352 r
.5619 .75365 m .55889 .7533 L .55981 .75186 L F
.883 .867 .818 r
.5619 .75365 m .55847 .75558 L .55889 .7533 L F
.998 .85 .557 r
.55889 .7533 m .55861 .75371 L .55862 .75372 L F
.55861 .75371 m .55843 .75399 L .55862 .75372 L F
.55862 .75372 m .55843 .75399 L .55847 .75395 L F
.454 .402 .71 r
.55736 .75023 m .55615 .7532 L .55889 .7533 L F
.55736 .75023 m .55864 .75378 L .55615 .7532 L F
.55864 .75378 m .55844 .75398 L .55615 .7532 L F
.939 .638 .443 r
.55762 .75315 m .55855 .75392 L .55813 .75262 L F
.55855 .75392 m .55864 .75378 L .55736 .75023 L F
.998 .85 .557 r
.55906 .75317 m .55864 .75378 L .55995 .75247 L F
.55889 .7533 m .5585 .7539 L .55906 .75317 L F
.782 .41 .352 r
.55981 .75186 m .55889 .7533 L .5592 .75133 L F
.185 .337 .785 r
.55889 .7533 m .55995 .75247 L .55736 .75023 L F
.421 .007 .146 r
.55835 .75416 m .55602 .75465 L .55843 .75397 L F
.955 .789 .636 r
.55622 .75443 m .55841 .75412 L .55612 .75191 L F
.55841 .75412 m .55875 .75408 L .55855 .75392 L F
.998 .85 .557 r
.5585 .7539 m .55794 .75478 L .55906 .75317 L F
.955 .789 .636 r
.55841 .75412 m .55759 .75526 L .55875 .75408 L F
.998 .85 .557 r
.55794 .75478 m .55775 .75507 L .55819 .75443 L F
.55794 .75478 m .55819 .75443 L .55906 .75317 L F
.55847 .75395 m .55759 .75526 L .55775 .75507 L F
.55843 .75399 m .55759 .75526 L .55847 .75395 L F
.955 .789 .636 r
.55622 .75443 m .55759 .75526 L .55841 .75412 L F
.421 .007 .146 r
.55844 .75398 m .55841 .75402 L .55843 .75397 L F
.955 .789 .636 r
.55841 .75412 m .55855 .75392 L .55612 .75191 L F
.939 .638 .443 r
.55855 .75392 m .55875 .75408 L .55864 .75378 L F
.998 .85 .557 r
.55865 .75377 m .55802 .75475 L .55995 .75247 L F
.55864 .75378 m .55855 .75392 L .55865 .75377 L F
.55855 .75392 m .55802 .75475 L .55865 .75377 L F
.55864 .75378 m .55775 .75507 L .55802 .75475 L F
.87 .867 .833 r
.55771 .75364 m .55759 .75526 L .55622 .75443 L F
.55995 .75247 m .55819 .75454 L .55771 .75364 L F
.55819 .75454 m .55759 .75526 L .55771 .75364 L F
.939 .638 .443 r
.55612 .75191 m .55762 .75315 L .55736 .75023 L F
.55762 .75315 m .55813 .75262 L .55736 .75023 L F
0 .494 .706 r
.55995 .75247 m .55612 .75191 L .55736 .75023 L F
.376 .664 .97 r
.55612 .75191 m .5589 .75231 L .55528 .74971 L F
.55612 .75191 m .55528 .74971 L .55524 .7497 L F
.544 .356 .576 r
.55645 .75131 m .55612 .75191 L .55524 .74968 L F
.376 .664 .97 r
.5589 .75231 m .55855 .75182 L .55524 .74968 L F
.87 .867 .833 r
.55995 .75247 m .55658 .75423 L .55842 .75393 L F
.992 .83 .582 r
.55995 .75247 m .55915 .75235 L .55856 .75082 L F
0 .494 .706 r
.55995 .75247 m .55942 .75238 L .5589 .75231 L F
.55995 .75247 m .5589 .75231 L .55612 .75191 L F
.992 .83 .582 r
.55995 .75247 m .55939 .753 L .55915 .75235 L F
.838 .703 .715 r
.55524 .74968 m .55855 .75182 L .55856 .75082 L F
.992 .83 .582 r
.55939 .753 m .55855 .75182 L .55856 .75082 L F
.838 .703 .715 r
.55855 .75182 m .55942 .75238 L .55856 .75082 L F
.992 .83 .582 r
.55855 .75182 m .55852 .75179 L .55856 .75082 L F
.841 .697 .704 r
.55856 .75082 m .55842 .75393 L .55527 .74972 L F
.376 .664 .97 r
.55524 .7497 m .55528 .74971 L .55524 .74968 L F
.841 .697 .704 r
.55532 .74971 m .55527 .74972 L .55524 .74968 L F
.55856 .75082 m .55527 .74972 L .55532 .74971 L F
.693 .321 .338 r
.55311 .75057 m .55638 .75076 L .55524 .74973 L F
.55487 .74983 m .55524 .74973 L .5552 .74969 L F
.55311 .75057 m .55524 .74973 L .55487 .74983 L F
.5536 .74922 m .5552 .74969 L .55386 .74848 L F
.55311 .75057 m .5552 .74969 L .5536 .74922 L F
.376 .664 .97 r
.5589 .75231 m .55942 .75238 L .55855 .75182 L F
.992 .83 .582 r
.55939 .753 m .55842 .75393 L .55852 .75179 L F
.544 .356 .576 r
.55842 .75393 m .55737 .75301 L .55645 .75131 L F
.55737 .75301 m .55612 .75191 L .55645 .75131 L F
.87 .867 .833 r
.55658 .75423 m .55622 .75443 L .55645 .75437 L F
.55658 .75423 m .55645 .75437 L .55842 .75393 L F
.805 .782 .831 r
.67716 .60921 m .67802 .60537 L .6758 .60622 L F
.67716 .60921 m .67874 .60779 L .67802 .60537 L F
.558 .44 .675 r
.52837 .76535 m .5284 .76777 L .53065 .76731 L F
.728 .65 .772 r
.69362 .59504 m .69677 .59555 L .6958 .5925 L F
.663 .612 .787 r
.69677 .59555 m .69805 .59168 L .6958 .5925 L F
.69677 .59555 m .69918 .59489 L .69805 .59168 L F
0 .106 .649 r
.54381 .69936 m .54567 .70187 L .54533 .70103 L F
.83 .356 .016 r
.54794 .70379 m .54533 .70103 L .54567 .70187 L F
.573 .668 .903 r
.32219 .72568 m .32311 .72295 L .32074 .72496 L F
.32219 .72568 m .3242 .7256 L .32311 .72295 L F
.498 .199 .389 r
.54321 .75718 m .54273 .75907 L .54062 .75924 L F
.624 .364 .504 r
.54632 .75622 m .54273 .75907 L .54321 .75718 L F
.625 .553 .754 r
.31532 .70744 m .31774 .70729 L .3169 .70464 L F
.704 .482 .583 r
.31532 .70744 m .31819 .71024 L .31774 .70729 L F
.31819 .71024 m .31868 .7101 L .31774 .70729 L F
.701 .531 .654 r
.31774 .70729 m .31899 .71102 L .32075 .70973 L F
.817 .677 .709 r
.31991 .70974 m .31672 .7098 L .32047 .70959 L F
.701 .531 .654 r
.31774 .70729 m .32075 .70973 L .31957 .70681 L F
.704 .482 .583 r
.31819 .71024 m .31899 .71102 L .31868 .7101 L F
.686 .503 .634 r
.31899 .71102 m .31847 .71357 L .32075 .70973 L F
.817 .677 .709 r
.32075 .70973 m .31847 .71357 L .31672 .7098 L F
.58 .886 .991 r
.32075 .70973 m .32287 .70677 L .31957 .70681 L F
.32075 .70973 m .32409 .70819 L .32287 .70677 L F
.32075 .70973 m .31959 .70915 L .32409 .70819 L F
.817 .677 .709 r
.32047 .70959 m .31946 .70964 L .31959 .70915 L F
.32075 .70973 m .31991 .70974 L .32047 .70959 L F
.982 .823 .609 r
.32075 .70973 m .31887 .71249 L .31959 .70915 L F
.649 .854 .978 r
.32252 .70799 m .31959 .70915 L .31997 .70767 L F
.32409 .70819 m .32155 .70873 L .32252 .70799 L F
.32155 .70873 m .31959 .70915 L .32252 .70799 L F
.883 .645 .574 r
.32409 .70819 m .3251 .70662 L .32287 .70677 L F
.32409 .70819 m .32277 .70778 L .3251 .70662 L F
.203 0 0 r
.32277 .70778 m .32696 .7085 L .3251 .70662 L F
.735 .831 .924 r
.32409 .70819 m .31997 .70767 L .32277 .70778 L F
.808 .609 .634 r
.32745 .70968 m .33052 .71128 L .32962 .70813 L F
.32724 .70983 m .32962 .70813 L .32696 .7085 L F
0 .277 .78 r
.32816 .71015 m .32745 .70917 L .32823 .70823 L F
.32745 .70917 m .32696 .7085 L .32745 .70839 L F
.32745 .70917 m .32745 .70839 L .32824 .70821 L F
.808 .609 .634 r
.32745 .70992 m .33052 .71128 L .32745 .70968 L F
.32724 .70983 m .32745 .70992 L .32745 .70968 L F
0 .277 .78 r
.32816 .71015 m .32724 .70983 L .32696 .7085 L F
.203 0 0 r
.32277 .70778 m .32741 .70868 L .32696 .7085 L F
.506 .308 .545 r
.3251 .70662 m .32696 .7085 L .32723 .70615 L F
.544 .341 .555 r
.32696 .7085 m .32962 .70813 L .32723 .70615 L F
.713 .699 .835 r
.32827 .70705 m .32823 .70823 L .32628 .70743 L F
.436 .707 .98 r
.32628 .70743 m .32824 .70821 L .32821 .70823 L F
0 0 0 r
.32741 .70868 m .32821 .70823 L .32696 .7085 L F
.186 .325 .773 r
.32723 .70615 m .32962 .70813 L .32813 .70539 L F
.381 .654 .965 r
.32962 .70813 m .32992 .70546 L .32813 .70539 L F
.32985 .70611 m .3299 .70673 L .32992 .70546 L F
.32962 .70813 m .3299 .70673 L .32985 .70611 L F
.713 .699 .835 r
.3299 .70673 m .32816 .71015 L .32827 .70705 L F
.944 .824 .697 r
.333 .71099 m .32962 .70813 L .33052 .71128 L F
.333 .71099 m .3318 .70812 L .32962 .70813 L F
.381 .654 .965 r
.32962 .70813 m .3318 .70812 L .3299 .70673 L F
.6 .54 .758 r
.3309 .71025 m .32816 .71015 L .3299 .70673 L F
.597 .494 .708 r
.32889 .70661 m .3294 .70697 L .3299 .70673 L F
.3294 .70697 m .32995 .70735 L .3299 .70673 L F
.706 .651 .793 r
.32287 .70677 m .3251 .70662 L .32367 .70342 L F
.925 .965 .663 r
.32405 .70698 m .32291 .70825 L .3238 .70619 L F
.57 .55 .792 r
.3251 .70662 m .32604 .70304 L .32367 .70342 L F
.925 .965 .663 r
.32405 .70698 m .3238 .70619 L .32478 .70391 L F
.274 .648 .967 r
.32405 .70698 m .32741 .70868 L .32441 .7081 L F
.32405 .70698 m .32441 .7081 L .32277 .70778 L F
.436 .707 .98 r
.32628 .70743 m .32741 .70868 L .32405 .70698 L F
.525 .419 .677 r
.32519 .70779 m .326 .7068 L .32517 .70777 L F
.57 .55 .792 r
.3251 .70662 m .32723 .70615 L .32604 .70304 L F
.172 .299 .754 r
.32604 .70304 m .32723 .70615 L .32813 .70539 L F
.512 .564 .845 r
.32751 .70495 m .32628 .70743 L .32478 .70391 L F
.525 .419 .677 r
.326 .7068 m .32751 .70495 L .32598 .7068 L F
.925 .965 .663 r
.32405 .70698 m .32478 .70391 L .32628 .70743 L F
.525 .419 .677 r
.326 .7068 m .32598 .7068 L .32517 .70777 L F
.32607 .70875 m .32654 .70751 L .32519 .70779 L F
0 0 0 r
.32628 .70743 m .32858 .70709 L .3299 .70673 L F
.32858 .70709 m .3294 .70697 L .32958 .70689 L F
.512 .564 .845 r
.32726 .70546 m .3294 .70697 L .32628 .70743 L F
.525 .419 .677 r
.32654 .70751 m .32751 .70495 L .32519 .70779 L F
0 0 0 r
.32858 .70709 m .32958 .70689 L .3299 .70673 L F
.3294 .70697 m .3297 .70692 L .3299 .70673 L F
.597 .494 .708 r
.3284 .70655 m .32995 .70735 L .32889 .70661 L F
.415 0 0 r
.32889 .70661 m .3297 .70692 L .3284 .70655 L F
.3299 .70673 m .3297 .70692 L .32889 .70661 L F
.512 .564 .845 r
.32917 .70672 m .3297 .70692 L .3294 .70697 L F
.32751 .70495 m .3297 .70692 L .32917 .70672 L F
.32751 .70495 m .3294 .70697 L .32726 .70546 L F
.597 .494 .708 r
.3284 .70655 m .32996 .70748 L .32995 .70735 L F
.6 .54 .758 r
.3309 .71025 m .3299 .70673 L .3318 .70812 L F
.597 .494 .708 r
.32996 .70748 m .33104 .70812 L .3299 .70673 L F
0 0 0 r
.32821 .70823 m .32824 .70821 L .32823 .70822 L F
.32821 .70823 m .32823 .70822 L .32696 .7085 L F
.436 .707 .98 r
.32628 .70743 m .32821 .70823 L .32741 .70868 L F
.713 .699 .835 r
.32783 .70858 m .32715 .70869 L .32628 .70743 L F
.3282 .70886 m .32763 .70876 L .32783 .70858 L F
.32763 .70876 m .32715 .70869 L .32783 .70858 L F
.32823 .70823 m .3282 .70886 L .32628 .70743 L F
.3282 .70886 m .32816 .71015 L .32715 .70869 L F
0 .277 .78 r
.32816 .71015 m .32823 .70823 L .32824 .70821 L F
0 0 0 r
.32285 .70774 m .32257 .70814 L .32405 .70698 L F
.32277 .70778 m .32277 .7078 L .32285 .70774 L F
.32277 .7078 m .32257 .70814 L .32285 .70774 L F
.443 .39 .704 r
.31887 .71249 m .31984 .70825 L .31959 .70915 L F
.31984 .70825 m .31997 .70767 L .31959 .70915 L F
.817 .677 .709 r
.31946 .70964 m .31672 .7098 L .31959 .70915 L F
.425 .105 .316 r
.3896 .69398 m .391 .69516 L .39167 .6935 L F
.3896 .69398 m .3889 .69567 L .391 .69516 L F
.823 .77 .802 r
.71698 .71382 m .7163 .71341 L .71904 .71292 L F
.652 .768 .934 r
.72145 .71198 m .71698 .71382 L .71904 .71292 L F
.72145 .71198 m .72227 .71337 L .71698 .71382 L F
.899 .853 .789 r
.72693 .59049 m .72904 .58896 L .72826 .58824 L F
.72693 .59049 m .72724 .59185 L .72904 .58896 L F
.991 .75 .381 r
.72826 .58824 m .72904 .58896 L .72897 .5921 L F
.028 .588 .808 r
.73712 .60804 m .73868 .60815 L .73544 .60768 L F
.73712 .60804 m .73868 .60815 L .73544 .60768 L F
.193 .483 .896 r
.39539 .65033 m .3938 .65078 L .39286 .64976 L F
.39539 .65033 m .39634 .65182 L .3938 .65078 L F
.768 .689 .775 r
.29016 .60837 m .29379 .60865 L .29222 .60862 L F
.392 .478 .828 r
.2937 .61102 m .29222 .60862 L .29379 .60865 L F
0 0 0 r
.57043 .67381 m .57206 .67329 L .57347 .67217 L F
.36 0 .091 r
.57206 .67329 m .57535 .67116 L .57347 .67217 L F
.117 .098 .558 r
.6162 .73154 m .6167 .73378 L .61526 .7348 L F
.106 .03 .479 r
.6167 .73378 m .61537 .73768 L .61526 .7348 L F
.872 .667 .622 r
.60648 .68752 m .60827 .68825 L .60797 .69079 L F
.553 .57 .825 r
.42382 .6595 m .42245 .66173 L .42168 .65997 L F
.42382 .6595 m .42453 .66159 L .42245 .66173 L F
.573 .602 .844 r
.55231 .73945 m .55398 .74304 L .5516 .74335 L F
.55235 .73923 m .55257 .73973 L .55231 .73945 L F
.55257 .73973 m .55398 .74304 L .55231 .73945 L F
.529 .893 .684 r
.5491 .73706 m .55192 .73493 L .5493 .73481 L F
.54992 .73644 m .55004 .73612 L .55192 .73493 L F
.5491 .73706 m .55004 .73612 L .54992 .73644 L F
.403 .482 .827 r
.5493 .73481 m .55192 .73493 L .55015 .73171 L F
.373 .466 .827 r
.55015 .73171 m .55192 .73493 L .55229 .73285 L F
.917 .97 .786 r
.55192 .73493 m .55004 .73612 L .55229 .73285 L F
.905 .895 .808 r
.55229 .73285 m .55004 .73612 L .549 .73533 L F
.088 .358 .826 r
.55004 .73612 m .5524 .73686 L .55014 .73584 L F
.55004 .73612 m .55014 .73584 L .549 .73533 L F
.203 .45 .873 r
.54962 .73654 m .55248 .7394 L .55004 .73612 L F
.747 .317 .228 r
.55235 .73923 m .5491 .73706 L .5495 .73936 L F
.573 .602 .844 r
.55212 .73952 m .5516 .74335 L .55109 .74077 L F
.55235 .73923 m .55231 .73945 L .55212 .73952 L F
.55231 .73945 m .5516 .74335 L .55212 .73952 L F
.581 .386 .582 r
.5495 .73936 m .55229 .74166 L .55235 .73923 L F
.706 .673 .816 r
.55592 .74183 m .55398 .74304 L .55235 .73923 L F
.747 .317 .228 r
.55235 .73923 m .55248 .73941 L .55241 .73936 L F
.55235 .73923 m .55241 .73936 L .5491 .73706 L F
.272 .102 .458 r
.55235 .73923 m .55229 .74166 L .55325 .74122 L F
.706 .673 .816 r
.55557 .73945 m .55235 .73923 L .55536 .73807 L F
.55592 .74183 m .55323 .73986 L .55557 .73945 L F
.55323 .73986 m .55235 .73923 L .55557 .73945 L F
.758 .797 .885 r
.55869 .74022 m .55828 .74046 L .55542 .73812 L F
.55869 .74022 m .55542 .73812 L .55543 .73811 L F
.55828 .74046 m .55557 .73945 L .55536 .73807 L F
.55852 .7397 m .55536 .73807 L .55843 .73944 L F
.55869 .74022 m .55822 .73991 L .55852 .7397 L F
.55822 .73991 m .55536 .73807 L .55852 .7397 L F
.779 .688 .763 r
.55916 .73913 m .55746 .74154 L .55884 .74083 L F
0 0 0 r
.55846 .74072 m .55746 .74154 L .55899 .73938 L F
.707 .311 .297 r
.56058 .73918 m .55843 .73944 L .55848 .73713 L F
0 0 0 r
.55908 .73931 m .55899 .73938 L .55916 .73913 L F
.657 .925 .974 r
.55843 .73944 m .55869 .74022 L .56058 .73918 L F
0 0 0 r
.55846 .74072 m .55899 .73938 L .55908 .73931 L F
.518 .79 .995 r
.55434 .73899 m .5565 .73928 L .55615 .73841 L F
.55406 .73907 m .55472 .73913 L .55434 .73899 L F
.55472 .73913 m .5565 .73928 L .55434 .73899 L F
.349 .094 .379 r
.55406 .73907 m .55615 .73841 L .55843 .73944 L F
.55434 .73899 m .5536 .74106 L .55615 .73841 L F
.55406 .73907 m .55402 .73924 L .55434 .73899 L F
.55402 .73924 m .5536 .74106 L .55434 .73899 L F
.758 .797 .885 r
.55543 .73811 m .55542 .73812 L .55536 .73807 L F
.55828 .74046 m .55592 .74183 L .55557 .73945 L F
.518 .79 .995 r
.5565 .73928 m .55843 .73944 L .55762 .73908 L F
.5565 .73928 m .55762 .73908 L .55615 .73841 L F
.753 .684 .785 r
.5536 .74106 m .55489 .74399 L .55746 .74154 L F
.5536 .74106 m .55746 .74154 L .55651 .7416 L F
.642 .106 0 r
.55651 .7416 m .55477 .74108 L .5536 .74106 L F
.272 .102 .458 r
.55235 .73923 m .55317 .74105 L .5536 .74106 L F
.428 .26 .549 r
.55235 .73923 m .55406 .73907 L .55248 .73941 L F
.203 .45 .873 r
.55248 .7394 m .55248 .73941 L .55248 .7394 L F
.272 .102 .458 r
.55235 .73923 m .5536 .74106 L .55406 .73907 L F
.455 .76 .995 r
.55248 .73941 m .55406 .73907 L .55251 .73789 L F
.937 .627 .171 r
.5536 .74106 m .55299 .74055 L .55251 .73789 L F
.518 .79 .995 r
.55251 .73789 m .55406 .73907 L .55615 .73841 L F
.743 .657 .764 r
.55615 .73841 m .5536 .74106 L .55251 .73789 L F
.642 .106 0 r
.55477 .74108 m .55299 .74055 L .5536 .74106 L F
.272 .102 .458 r
.55317 .74105 m .55325 .74122 L .5536 .74106 L F
.203 .45 .873 r
.5491 .73706 m .55188 .73899 L .54962 .73654 L F
.55188 .73899 m .55248 .7394 L .54962 .73654 L F
.55248 .7394 m .55248 .7394 L .55004 .73612 L F
.923 .972 .766 r
.51751 .7042 m .51846 .7011 L .5197 .70402 L F
.51751 .7042 m .51651 .70419 L .51846 .7011 L F
.012 0 0 r
.37447 .70419 m .37373 .70479 L .37572 .70413 L F
.766 .675 .761 r
.45988 .77018 m .46112 .77326 L .46333 .77049 L F
.086 0 .255 r
.32863 .66591 m .32668 .66896 L .32839 .66813 L F
.548 .403 .636 r
.3265 .67137 m .32839 .66813 L .32668 .66896 L F
.545 .41 .648 r
.31913 .68579 m .32108 .68544 L .32093 .68244 L F
.559 .441 .675 r
.31913 .68579 m .32155 .68771 L .32108 .68544 L F
.31913 .68579 m .31946 .68813 L .32155 .68771 L F
0 .484 .746 r
.71296 .57804 m .71476 .57839 L .71575 .57868 L F
.583 .117 .114 r
.71476 .57839 m .71804 .57815 L .71575 .57868 L F
.519 .197 .362 r
.47395 .73205 m .47603 .73207 L .47727 .72914 L F
.52 .192 .352 r
.47603 .73207 m .47955 .72904 L .47727 .72914 L F
.66 .553 .723 r
.32263 .67467 m .325 .67435 L .32445 .67209 L F
.649 .492 .657 r
.32263 .67467 m .32269 .6771 L .325 .67435 L F
.295 .744 .96 r
.41093 .65461 m .41433 .65505 L .41274 .65484 L F
.883 .78 .743 r
.47094 .75391 m .46798 .75185 L .47014 .75095 L F
.951 .79 .646 r
.46886 .7527 m .46933 .7538 L .46954 .75307 L F
.883 .78 .743 r
.47042 .75355 m .46954 .75307 L .46798 .75185 L F
.46954 .75307 m .46886 .7527 L .46805 .75192 L F
.46954 .75307 m .46805 .75192 L .46798 .75185 L F
.048 .167 .668 r
.47154 .75296 m .47094 .75391 L .47014 .75095 L F
.539 .342 .562 r
.47014 .75095 m .46954 .75307 L .47154 .75296 L F
.46954 .75307 m .46933 .7538 L .46968 .75317 L F
.883 .78 .743 r
.46968 .75317 m .46933 .7538 L .46886 .7527 L F
.47094 .75391 m .46933 .7538 L .46968 .75317 L F
.539 .342 .562 r
.46968 .75317 m .46933 .7538 L .47011 .75351 L F
.883 .78 .743 r
.47094 .75391 m .46958 .75312 L .47042 .75355 L F
.46958 .75312 m .46886 .7527 L .46944 .75302 L F
.46958 .75312 m .46944 .75302 L .47042 .75355 L F
.844 .487 .377 r
.47094 .75391 m .46962 .75561 L .46933 .7538 L F
.696 .378 .435 r
.46933 .7538 m .47038 .75459 L .47061 .75427 L F
.724 .537 .638 r
.47119 .75352 m .47009 .755 L .47094 .75391 L F
.47154 .75296 m .47038 .75459 L .47119 .75352 L F
.47038 .75459 m .47009 .755 L .47119 .75352 L F
.696 .378 .435 r
.47038 .75459 m .46962 .75561 L .47177 .75563 L F
.46933 .7538 m .46962 .75561 L .47038 .75459 L F
.47011 .75351 m .47168 .75467 L .47154 .75296 L F
.46933 .7538 m .47168 .75467 L .47011 .75351 L F
.724 .537 .638 r
.47154 .75296 m .46962 .75561 L .47009 .755 L F
.696 .378 .435 r
.47061 .75427 m .47177 .75563 L .47168 .75467 L F
.47038 .75459 m .47177 .75563 L .47061 .75427 L F
.539 .342 .562 r
.46954 .75307 m .47011 .75351 L .47154 .75296 L F
.951 .79 .646 r
.46886 .7527 m .46954 .75307 L .47014 .75095 L F
.569 0 0 r
.53825 .71974 m .54011 .72113 L .54124 .7216 L F
0 .512 .744 r
.54011 .72113 m .54287 .72161 L .54124 .7216 L F
.692 .161 0 r
.5286 .71228 m .53043 .71445 L .5307 .71404 L F
.426 .081 .276 r
.39179 .70737 m .38913 .70912 L .38968 .70785 L F
.877 .885 .836 r
.60836 .69297 m .60736 .69646 L .60644 .69565 L F
.60836 .69297 m .60955 .6938 L .60736 .69646 L F
.979 .7 .315 r
.60747 .6989 m .60644 .69565 L .60736 .69646 L F
.575 .757 .964 r
.41757 .65572 m .41539 .65615 L .41433 .65505 L F
.73 .741 .86 r
.67802 .60537 m .67874 .60779 L .68145 .60583 L F
.766 .756 .844 r
.71929 .59761 m .72275 .59773 L .72188 .59915 L F
.152 .48 .898 r
.58642 .75972 m .58767 .75933 L .5858 .75867 L F
.58642 .75972 m .58913 .76133 L .58767 .75933 L F
.489 .306 .559 r
.51377 .73745 m .51544 .73964 L .51396 .74121 L F
.076 0 0 r
.50819 .70615 m .51065 .70577 L .51185 .70509 L F
.602 .131 .108 r
.51065 .70577 m .5145 .70521 L .51185 .70509 L F
.688 .595 .746 r
.32168 .7219 m .31889 .72388 L .31803 .72043 L F
.78 .771 .845 r
.32648 .72375 m .33067 .72406 L .32846 .72323 L F
.789 .871 .909 r
.33219 .72234 m .33067 .72406 L .33221 .72331 L F
.33219 .72234 m .32846 .72323 L .33067 .72406 L F
.212 .369 .804 r
.40243 .67467 m .40455 .67652 L .40456 .67413 L F
.588 .526 .753 r
.44837 .77062 m .44649 .77264 L .44616 .77086 L F
.648 .62 .808 r
.44837 .77062 m .44986 .77398 L .44649 .77264 L F
.346 0 .001 r
.38354 .66686 m .38517 .66749 L .38254 .66755 L F
.38354 .66686 m .38589 .66657 L .38517 .66749 L F
0 0 0 r
.57043 .67381 m .57013 .67423 L .57206 .67329 L F
.46 .757 .994 r
.3994 .65243 m .39754 .65276 L .39634 .65182 L F
.19 .31 .757 r
.52617 .74555 m .52729 .74855 L .52831 .74729 L F
.123 .091 .546 r
.5274 .75108 m .52831 .74729 L .52729 .74855 L F
.503 .232 .437 r
.3647 .67637 m .36203 .67927 L .36277 .67668 L F
.718 .581 .701 r
.30893 .71587 m .30843 .71915 L .31186 .71803 L F
.477 .082 .212 r
.30843 .71915 m .3105 .72009 L .31186 .71803 L F
.541 .373 .603 r
.31186 .71803 m .31389 .7179 L .31374 .71557 L F
.325 0 .069 r
.3105 .72009 m .31389 .7179 L .31186 .71803 L F
.444 .317 .613 r
.31836 .69641 m .32004 .69364 L .31803 .69413 L F
.681 .874 .971 r
.68557 .60008 m .68908 .5996 L .68835 .59758 L F
.785 .767 .837 r
.68835 .59758 m .68908 .5996 L .69147 .59773 L F
0 .023 .595 r
.7195 .60726 m .7196 .60784 L .71889 .60648 L F
.7193 .60695 m .71889 .60648 L .71843 .6056 L F
.7195 .60726 m .71889 .60648 L .7193 .60695 L F
.725 .935 .957 r
.71618 .60867 m .7195 .60726 L .71764 .60655 L F
.7195 .60726 m .71948 .60716 L .71764 .60655 L F
.7195 .60726 m .71962 .60721 L .71948 .60716 L F
0 0 .532 r
.72039 .60821 m .71989 .6084 L .71962 .60721 L F
.681 .135 0 r
.71948 .60716 m .71962 .60721 L .72039 .60821 L F
.679 .895 .975 r
.7195 .60726 m .71989 .6084 L .71962 .60721 L F
0 .023 .595 r
.72039 .60821 m .71989 .6084 L .71935 .60682 L F
.7195 .60726 m .71989 .6084 L .7196 .60784 L F
.679 .895 .975 r
.71618 .60867 m .71989 .6084 L .7195 .60726 L F
.681 .135 0 r
.71764 .60655 m .71948 .60716 L .72039 .60821 L F
0 .023 .595 r
.71935 .60682 m .7195 .60726 L .71843 .6056 L F
0 0 .276 r
.61919 .71738 m .61736 .72075 L .61742 .71836 L F
.579 .077 .027 r
.43917 .73982 m .44155 .74041 L .4425 .73998 L F
0 0 0 r
.44155 .74041 m .44494 .74027 L .4425 .73998 L F
.347 0 0 r
.38172 .64786 m .38381 .64842 L .38521 .64821 L F
.053 0 0 r
.38596 .64828 m .38521 .64821 L .38381 .64842 L F
.38596 .64828 m .3875 .64834 L .38521 .64821 L F
.911 .747 .665 r
.54546 .75147 m .54511 .7537 L .5439 .75073 L F
.402 .428 .773 r
.57859 .70649 m .57925 .70392 L .57716 .70402 L F
.57859 .70649 m .5803 .70712 L .57925 .70392 L F
.549 .571 .829 r
.45055 .77064 m .44986 .77398 L .44837 .77062 L F
.45055 .77064 m .45208 .77385 L .44986 .77398 L F
.376 .174 .473 r
.30481 .63812 m .30315 .63885 L .30516 .63596 L F
.369 .16 .46 r
.30276 .64094 m .30315 .63885 L .30481 .63812 L F
.528 .345 .577 r
.43251 .67125 m .43025 .67407 L .43031 .67171 L F
.524 .045 .06 r
.64163 .51899 m .64419 .51976 L .64445 .51864 L F
.286 .53 .91 r
.64337 .51806 m .64419 .51976 L .64163 .51899 L F
.937 .643 .18 r
.64337 .51806 m .64398 .52067 L .64419 .51976 L F
.64398 .52067 m .64404 .52093 L .64419 .51976 L F
.524 .045 .06 r
.64445 .51864 m .64419 .51976 L .64529 .51854 L F
.366 0 0 r
.64419 .51976 m .64757 .51854 L .64529 .51854 L F
.635 .113 0 r
.55021 .7265 m .5526 .72814 L .55355 .72729 L F
.582 .051 0 r
.5526 .72814 m .556 .72854 L .55355 .72729 L F
.371 0 0 r
.55355 .72729 m .556 .72854 L .55721 .72904 L F
0 .236 .691 r
.45978 .77707 m .45911 .7769 L .45799 .77651 L F
.603 .055 0 r
.45911 .7769 m .46103 .7781 L .46221 .77794 L F
0 .236 .691 r
.45978 .77707 m .46103 .7781 L .45911 .7769 L F
.451 .807 .997 r
.43546 .78689 m .4376 .78657 L .43415 .78622 L F
.547 .047 .018 r
.59194 .71879 m .59071 .71993 L .58836 .71898 L F
.5 .293 .53 r
.59048 .71908 m .59071 .71993 L .59121 .71912 L F
.178 0 0 r
.59194 .71879 m .59048 .71908 L .58853 .71897 L F
.726 .989 .866 r
.59194 .71879 m .59048 .71908 L .59194 .71793 L F
.5 .293 .53 r
.59048 .71908 m .59121 .71912 L .59194 .71793 L F
.178 0 0 r
.58853 .71897 m .59048 .71908 L .58836 .71898 L F
.828 .948 .595 r
.59194 .71793 m .59071 .71993 L .59194 .71879 L F
.551 .352 .565 r
.59194 .71793 m .59071 .71993 L .59174 .71969 L F
.726 .989 .866 r
.59194 .71879 m .59194 .71793 L .59201 .71728 L F
.828 .948 .595 r
.59194 .71793 m .59194 .71879 L .59202 .71719 L F
.551 .352 .565 r
.59194 .71793 m .59174 .71969 L .59309 .71938 L F
.726 .989 .866 r
.59201 .71728 m .59194 .71793 L .59202 .71719 L F
.282 .334 .739 r
.58501 .71288 m .58681 .71464 L .58644 .7117 L F
.836 .417 .24 r
.556 .72854 m .55934 .73135 L .55721 .72904 L F
.131 .365 .824 r
.57793 .74917 m .57958 .7511 L .57767 .74793 L F
.904 .842 .385 r
.53832 .7907 m .53904 .78898 L .53749 .78832 L F
.53832 .7907 m .53838 .79158 L .53904 .78898 L F
.844 .594 .561 r
.54881 .69093 m .5489 .6934 L .54632 .69116 L F
.54632 .69116 m .5489 .6934 L .54881 .69093 L F
.576 .402 .609 r
.42659 .74558 m .4289 .74802 L .42882 .74478 L F
.42659 .74558 m .42663 .74847 L .4289 .74802 L F
.851 .831 .827 r
.72344 .59512 m .72724 .59185 L .72693 .59049 L F
.498 .463 .748 r
.35219 .69823 m .35119 .70186 L .35005 .6985 L F
.35219 .69823 m .35329 .702 L .35119 .70186 L F
.649 .783 .946 r
.3311 .73175 m .33468 .73263 L .33321 .73148 L F
.164 .327 .782 r
.33468 .73263 m .33534 .73079 L .33321 .73148 L F
.33468 .73263 m .33724 .73359 L .33534 .73079 L F
.763 .677 .768 r
.71083 .60651 m .71177 .60289 L .70933 .60535 L F
.351 .323 .687 r
.56262 .69257 m .56397 .69811 L .56142 .69632 L F
.627 .087 0 r
.5325 .73735 m .52903 .73442 L .53142 .73684 L F
0 0 0 r
.37404 .6709 m .37305 .67088 L .37603 .66978 L F
.37404 .6709 m .37221 .67166 L .37305 .67088 L F
.519 .119 .222 r
.46593 .73352 m .46818 .73357 L .46624 .73236 L F
.509 .13 .258 r
.46624 .73236 m .46818 .73357 L .46855 .7323 L F
.167 0 0 r
.36703 .64915 m .3691 .64889 L .37076 .64798 L F
.457 0 0 r
.37076 .64798 m .3691 .64889 L .37257 .64863 L F
.291 .72 .97 r
.30275 .59703 m .29915 .59628 L .30112 .59625 L F
.212 .647 .952 r
.30306 .59631 m .30275 .59703 L .30112 .59625 L F
.30306 .59631 m .30453 .59719 L .30275 .59703 L F
.43 .634 .941 r
.40762 .65388 m .4067 .65534 L .40568 .65386 L F
.507 .735 .976 r
.40762 .65388 m .40885 .65512 L .4067 .65534 L F
.422 .222 .501 r
.27286 .6443 m .27465 .64337 L .27509 .64258 L F
.27286 .6443 m .27304 .64425 L .27465 .64337 L F
.186 0 0 r
.27284 .64433 m .27304 .64425 L .27286 .6443 L F
.569 .344 .534 r
.64206 .52907 m .63967 .53154 L .64054 .52965 L F
.64206 .52907 m .64192 .53108 L .63967 .53154 L F
.59 .262 .382 r
.64206 .52907 m .64413 .5305 L .64192 .53108 L F
.64206 .52907 m .64445 .52914 L .64413 .5305 L F
.384 .676 .974 r
.28836 .59424 m .28773 .59556 L .28637 .59443 L F
.28836 .59424 m .28998 .59569 L .28773 .59556 L F
.206 0 .005 r
.58077 .66851 m .5824 .66855 L .58364 .66678 L F
.348 0 .087 r
.58364 .66678 m .58516 .66729 L .58562 .666 L F
.58364 .66678 m .5824 .66855 L .58516 .66729 L F
.525 .355 .594 r
.32064 .67993 m .3227 .67949 L .32269 .6771 L F
.55 .439 .68 r
.32093 .68244 m .3227 .67949 L .32064 .67993 L F
.414 .16 .417 r
.39615 .68527 m .39806 .68484 L .39849 .68291 L F
.507 .337 .586 r
.39615 .68527 m .39816 .68737 L .39806 .68484 L F
.39615 .68527 m .39612 .68787 L .39816 .68737 L F
.421 0 0 r
.46103 .7781 m .46449 .77849 L .46221 .77794 L F
0 0 0 r
.72107 .72109 m .72095 .72131 L .72183 .72086 L F
.558 .377 .591 r
.72107 .72109 m .7212 .72348 L .72356 .72305 L F
0 .14 .619 r
.72107 .72109 m .72262 .72215 L .72095 .72131 L F
.492 .798 .999 r
.72356 .72305 m .72583 .72266 L .72262 .72215 L F
.267 0 .211 r
.72356 .72305 m .72262 .72215 L .72583 .72266 L F
0 .266 .761 r
.72262 .72215 m .72518 .72408 L .72407 .72271 L F
.72262 .72215 m .72407 .72271 L .72358 .72277 L F
0 .14 .619 r
.72151 .72144 m .72356 .72305 L .72262 .72215 L F
0 .266 .761 r
.72262 .72215 m .72358 .72277 L .72152 .72301 L F
0 .14 .619 r
.72107 .72109 m .72151 .72144 L .72262 .72215 L F
.544 .003 0 r
.7277 .62437 m .72435 .62159 L .72524 .62289 L F
.532 .201 .352 r
.45808 .73623 m .46013 .73629 L .45834 .73481 L F
.549 .195 .319 r
.45834 .73481 m .46013 .73629 L .46074 .73478 L F
.286 0 .262 r
.39806 .68484 m .4005 .68252 L .39849 .68291 L F
.985 .873 .639 r
.7441 .61901 m .74262 .62008 L .74335 .61854 L F
.7441 .61901 m .74308 .62228 L .74262 .62008 L F
.967 .935 .677 r
.7441 .61901 m .74428 .61655 L .74749 .61649 L F
.7441 .61901 m .74335 .61854 L .74428 .61655 L F
.91 .714 .624 r
.71013 .57878 m .70799 .58036 L .70909 .57772 L F
.765 .661 .747 r
.5619 .75365 m .56308 .75681 L .55975 .75654 L F
.62 .134 .078 r
.56308 .75681 m .56185 .75791 L .55975 .75654 L F
.481 0 0 r
.55465 .70902 m .5507 .70741 L .55235 .70738 L F
.133 .178 .643 r
.53611 .76114 m .53672 .75858 L .53463 .7596 L F
.53611 .76114 m .53728 .76146 L .53672 .75858 L F
.337 .442 .821 r
.57318 .68619 m .57457 .68449 L .57222 .68531 L F
.57318 .68619 m .57565 .68745 L .57457 .68449 L F
.55 .145 .228 r
.537 .79297 m .53583 .79476 L .53325 .79458 L F
.495 .305 .552 r
.53832 .7907 m .537 .79297 L .53838 .79158 L F
.53832 .7907 m .53583 .79476 L .537 .79297 L F
.713 .417 .474 r
.5282 .74504 m .53112 .74321 L .52786 .74276 L F
.5282 .74504 m .53322 .74571 L .53112 .74321 L F
.551 .403 .633 r
.53112 .74321 m .53322 .74571 L .53426 .74544 L F
.42 .701 .98 r
.57958 .7511 m .58103 .74996 L .57767 .74793 L F
.57958 .7511 m .58089 .7507 L .58103 .74996 L F
.339 .055 .328 r
.287 .62994 m .2883 .62984 L .28888 .62733 L F
.348 .063 .331 r
.28888 .62733 m .29009 .62917 L .2904 .62755 L F
.28888 .62733 m .2883 .62984 L .29009 .62917 L F
.361 0 .008 r
.27122 .64491 m .27304 .64425 L .27284 .64433 L F
.563 .85 .997 r
.51504 .78849 m .51293 .78913 L .51182 .7884 L F
.912 .879 .789 r
.48607 .74891 m .48309 .75031 L .48525 .74771 L F
.48607 .74891 m .48432 .75126 L .48309 .75031 L F
.556 .334 .533 r
.48607 .74891 m .48699 .75127 L .48432 .75126 L F
.146 .335 .795 r
.4873 .74754 m .48607 .74891 L .48525 .74771 L F
.4873 .74754 m .48883 .7506 L .48607 .74891 L F
.453 .281 .557 r
.48883 .7506 m .48699 .75127 L .48607 .74891 L F
.576 .376 .572 r
.41844 .76214 m .42072 .76186 L .42087 .7596 L F
.548 .352 .567 r
.42087 .7596 m .4229 .76139 L .42304 .75916 L F
.42087 .7596 m .42072 .76186 L .4229 .76139 L F
.366 0 .139 r
.35345 .72576 m .35289 .72672 L .3507 .72708 L F
.322 0 .116 r
.35502 .72616 m .35345 .72576 L .35572 .72521 L F
.35502 .72616 m .35289 .72672 L .35345 .72576 L F
.362 .58 .925 r
.74244 .5873 m .74106 .58849 L .73903 .58662 L F
.74244 .5873 m .743 .58875 L .74106 .58849 L F
.469 .21 .438 r
.41052 .69285 m .40884 .6913 L .41208 .69017 L F
.41052 .69285 m .40843 .6933 L .40884 .6913 L F
.478 .897 .84 r
.52301 .73116 m .5223 .73122 L .52031 .73211 L F
.287 .787 .797 r
.52469 .73058 m .5223 .73122 L .52301 .73116 L F
.749 .638 .737 r
.48564 .74266 m .4871 .74603 L .48879 .74436 L F
.48575 .74272 m .48879 .74436 L .4874 .74396 L F
.547 .651 .904 r
.48879 .74436 m .48969 .74196 L .4874 .74396 L F
.48879 .74436 m .49129 .74386 L .48969 .74196 L F
.508 .327 .57 r
.49131 .74421 m .48962 .74561 L .4874 .74396 L F
.48962 .74561 m .4873 .74754 L .4874 .74396 L F
.749 .638 .737 r
.48564 .74266 m .48575 .74272 L .4874 .74396 L F
.266 0 .036 r
.53496 .72768 m .53373 .72635 L .53438 .72698 L F
.53496 .72768 m .53232 .72883 L .53373 .72635 L F
.363 .421 .788 r
.53373 .72635 m .53643 .72868 L .53438 .72698 L F
.584 .571 .806 r
.32005 .72946 m .32357 .73229 L .32192 .7291 L F
.842 .614 .593 r
.30843 .71915 m .30513 .7201 L .30715 .71727 L F
.278 .3 .705 r
.30989 .71718 m .30843 .71915 L .30715 .71727 L F
.30989 .71718 m .3105 .72009 L .30843 .71915 L F
.716 .626 .756 r
.69918 .59489 m .70256 .59566 L .70151 .59439 L F
.683 .62 .779 r
.70151 .59439 m .70256 .59566 L .70463 .59483 L F
0 0 0 r
.28079 .65482 m .27955 .65538 L .27759 .65594 L F
.106 0 0 r
.28288 .6542 m .27955 .65538 L .28079 .65482 L F
.811 .659 .694 r
.68835 .59758 m .69147 .59773 L .69013 .5946 L F
.731 .625 .74 r
.69013 .5946 m .69147 .59773 L .69362 .59504 L F
0 .468 .806 r
.72568 .72925 m .72469 .7287 L .72289 .72817 L F
.197 .706 .897 r
.72796 .72899 m .72469 .7287 L .72568 .72925 L F
.539 .371 .602 r
.35277 .68524 m .35067 .68828 L .35096 .68614 L F
.927 .79 .69 r
.56246 .68777 m .56498 .68908 L .56332 .6878 L F
.56246 .68777 m .56332 .6878 L .56255 .68835 L F
.56246 .68777 m .56369 .69081 L .56498 .68908 L F
.707 .729 .867 r
.56332 .6878 m .56498 .68908 L .5678 .68794 L F
.625 .341 .466 r
.56498 .68908 m .56369 .69081 L .56782 .6903 L F
.306 .125 .464 r
.62263 .7064 m .62089 .70735 L .6227 .70438 L F
0 0 .464 r
.6223 .70856 m .62089 .70735 L .62263 .7064 L F
.62208 .70837 m .62121 .70989 L .62089 .70735 L F
.905 .754 .684 r
.62081 .70781 m .62231 .70659 L .6224 .70487 L F
0 0 .275 r
.62373 .70329 m .62263 .7064 L .6227 .70438 L F
.62373 .70329 m .6233 .70579 L .62263 .7064 L F
.905 .754 .684 r
.62231 .70659 m .6233 .70579 L .62252 .705 L F
.62231 .70659 m .62252 .705 L .6224 .70487 L F
0 0 .464 r
.6223 .70856 m .62201 .70891 L .62208 .70837 L F
.62201 .70891 m .62121 .70989 L .62208 .70837 L F
.918 .843 .755 r
.63683 .5269 m .63505 .5282 L .63707 .52493 L F
.744 .548 .63 r
.41739 .77271 m .42053 .77299 L .42027 .77048 L F
.521 .475 .746 r
.42027 .77048 m .42153 .76713 L .41931 .76749 L F
.42027 .77048 m .42234 .77011 L .42153 .76713 L F
.547 .428 .669 r
.42053 .77299 m .42234 .77011 L .42027 .77048 L F
.239 0 0 r
.50319 .74437 m .50187 .74501 L .49997 .74519 L F
.754 .336 .255 r
.50319 .74437 m .5048 .74584 L .50187 .74501 L F
.4 .828 .666 r
.58875 .74318 m .59005 .74235 L .59073 .74204 L F
.58875 .74318 m .59005 .74235 L .59073 .74204 L F
.423 .449 .783 r
.30447 .72343 m .30513 .7201 L .30318 .72026 L F
.30447 .72343 m .30614 .72333 L .30513 .7201 L F
.601 .472 .677 r
.42241 .77878 m .42483 .78129 L .42404 .77814 L F
.42241 .77878 m .4227 .78176 L .42483 .78129 L F
.325 .72 .981 r
.36429 .70574 m .3636 .70654 L .36225 .70555 L F
.36429 .70574 m .36563 .70652 L .3636 .70654 L F
.289 .223 .608 r
.74525 .71793 m .74575 .72049 L .74444 .72093 L F
.34 .316 .685 r
.74654 .7227 m .74444 .72093 L .74575 .72049 L F
.441 .073 .242 r
.38365 .6988 m .38603 .69852 L .38703 .69638 L F
.265 0 .157 r
.38703 .69638 m .38791 .69785 L .3889 .69567 L F
.38703 .69638 m .38603 .69852 L .38791 .69785 L F
0 .3 .768 r
.55934 .73135 m .56276 .73388 L .56043 .73208 L F
.32 0 .083 r
.37745 .66848 m .37404 .6709 L .37603 .66978 L F
.517 .349 .592 r
.32839 .66813 m .33042 .66528 L .32863 .66591 L F
.675 .567 .725 r
.52362 .74581 m .52565 .74318 L .52259 .74268 L F
.654 .538 .71 r
.52362 .74581 m .52617 .74555 L .52565 .74318 L F
.758 .552 .618 r
.46185 .75373 m .45974 .75587 L .45957 .75392 L F
.377 .789 .98 r
.46453 .75334 m .46411 .75328 L .46185 .75373 L F
.117 .193 .667 r
.4638 .7555 m .46185 .75373 L .46411 .75328 L F
.321 0 .171 r
.27735 .64192 m .27509 .64258 L .27465 .64337 L F
.93 .708 .581 r
.52192 .73754 m .52275 .74051 L .52107 .74012 L F
.115 .101 .563 r
.52353 .73684 m .52275 .74051 L .52192 .73754 L F
.52353 .73684 m .52386 .73992 L .52275 .74051 L F
.597 .282 .407 r
.52386 .73992 m .52107 .74012 L .52275 .74051 L F
.594 .813 .983 r
.31495 .77555 m .31318 .77632 L .3113 .77515 L F
.31495 .77555 m .31318 .77632 L .3113 .77515 L F
.499 .582 .87 r
.58367 .75887 m .58421 .75596 L .58249 .75616 L F
.58367 .75887 m .5858 .75867 L .58421 .75596 L F
.908 .519 .267 r
.50064 .72794 m .50102 .72612 L .5007 .72562 L F
.633 .388 .53 r
.50168 .73098 m .50423 .73088 L .50214 .72868 L F
.645 .388 .515 r
.50214 .72868 m .50316 .72975 L .50465 .72876 L F
.50316 .72975 m .50423 .73088 L .50458 .72912 L F
.50316 .72975 m .50458 .72912 L .50465 .72876 L F
.38 .841 .892 r
.49874 .73171 m .4998 .73159 L .50168 .73098 L F
.243 0 .15 r
.50168 .73098 m .4998 .73159 L .49832 .73393 L F
.633 .388 .53 r
.50163 .73023 m .50214 .72868 L .50064 .72794 L F
.908 .519 .267 r
.50074 .72748 m .50214 .72868 L .50102 .72612 L F
.50064 .72794 m .50114 .72818 L .50074 .72748 L F
.50114 .72818 m .50214 .72868 L .50074 .72748 L F
.528 .447 .708 r
.50309 .7261 m .50148 .72989 L .50064 .72794 L F
.50148 .72989 m .50119 .73058 L .50064 .72794 L F
.633 .388 .53 r
.50153 .73053 m .50163 .73023 L .50064 .72794 L F
.50168 .73098 m .50181 .73032 L .50153 .73053 L F
.50181 .73032 m .50214 .72868 L .50158 .73037 L F
.50181 .73032 m .50158 .73037 L .5016 .73048 L F
.528 .447 .708 r
.50176 .72924 m .50236 .73028 L .5016 .73048 L F
.50148 .72989 m .5016 .73048 L .50119 .73058 L F
.50176 .72924 m .5016 .73048 L .50148 .72989 L F
.633 .388 .53 r
.5016 .73048 m .50158 .73037 L .50153 .73053 L F
.38 .841 .892 r
.49874 .73171 m .50168 .73098 L .50153 .73053 L F
.347 0 .017 r
.50152 .73054 m .50112 .73068 L .50115 .73064 L F
.50138 .73053 m .50115 .73064 L .50119 .73058 L F
.688 .624 .779 r
.50119 .73058 m .49874 .73171 L .50064 .72794 L F
.38 .841 .892 r
.49887 .73144 m .50153 .73053 L .50064 .72794 L F
.49874 .73171 m .50153 .73053 L .49887 .73144 L F
.347 0 .017 r
.50153 .73054 m .50075 .73114 L .50112 .73068 L F
.50153 .73054 m .50112 .73068 L .50152 .73054 L F
.243 0 .15 r
.50168 .73098 m .49832 .73393 L .50192 .73349 L F
.64 .427 .578 r
.50192 .73349 m .50423 .73088 L .50168 .73098 L F
.347 0 .017 r
.50425 .72979 m .49989 .73222 L .50075 .73114 L F
.50425 .72979 m .50075 .73114 L .50153 .73054 L F
.50425 .72979 m .50115 .73064 L .50138 .73053 L F
.528 .447 .708 r
.50309 .7261 m .50425 .72979 L .50236 .73028 L F
.50309 .7261 m .50236 .73028 L .50176 .72924 L F
.361 0 .008 r
.27122 .64491 m .27465 .64337 L .27304 .64425 L F
.589 .539 .767 r
.44733 .7672 m .44616 .77086 L .44519 .76757 L F
.44733 .7672 m .44837 .77062 L .44616 .77086 L F
.541 .422 .667 r
.41899 .76498 m .42072 .76186 L .41844 .76214 L F
.863 .619 .568 r
.62094 .67984 m .62114 .68222 L .62379 .68257 L F
.856 .683 .667 r
.62114 .68222 m .62361 .68476 L .62379 .68257 L F
.464 .756 .993 r
.26133 .58843 m .26084 .58972 L .25962 .58871 L F
.26133 .58843 m .26291 .58953 L .26084 .58972 L F
.516 .385 .641 r
.42473 .75122 m .42674 .75088 L .42663 .74847 L F
.573 .392 .598 r
.42473 .75122 m .42698 .75333 L .42674 .75088 L F
.42473 .75122 m .42473 .75367 L .42698 .75333 L F
.925 .578 .133 r
.74556 .61174 m .74519 .61302 L .7445 .61031 L F
.74556 .61174 m .74596 .61387 L .74519 .61302 L F
.66 .368 .467 r
.74836 .61272 m .74596 .61387 L .74556 .61174 L F
.867 .812 .793 r
.56422 .74857 m .56076 .75055 L .56299 .74932 L F
.59 .452 .661 r
.42249 .75405 m .42273 .75647 L .42473 .75367 L F
.23 0 0 r
.27237 .60376 m .27266 .60467 L .27063 .60424 L F
.27237 .60376 m .27416 .60353 L .27266 .60467 L F
.73 .58 .687 r
.47561 .74935 m .46935 .74867 L .47202 .74814 L F
.47561 .74935 m .47014 .75095 L .46935 .74867 L F
.724 .537 .638 r
.47188 .75557 m .47271 .75606 L .47192 .75594 L F
.47154 .75296 m .47243 .7553 L .47188 .75557 L F
.47243 .7553 m .47271 .75606 L .47188 .75557 L F
.048 .167 .668 r
.47154 .75296 m .47121 .75063 L .47561 .74935 L F
.682 .468 .59 r
.47576 .75061 m .47154 .75296 L .47561 .74935 L F
.47576 .75061 m .47528 .75305 L .47154 .75296 L F
.627 .488 .673 r
.47505 .75517 m .47154 .75296 L .47528 .75305 L F
.47505 .75517 m .47271 .75606 L .47154 .75296 L F
0 .14 .657 r
.47177 .75559 m .47295 .75441 L .47187 .75191 L F
.47177 .75563 m .47178 .75562 L .47177 .75559 L F
.47178 .75562 m .47295 .75441 L .47177 .75559 L F
.724 .537 .638 r
.47154 .75296 m .47192 .75594 L .47177 .75559 L F
.532 .92 .816 r
.47177 .75563 m .47174 .75564 L .47178 .75562 L F
0 .14 .657 r
.47177 .75563 m .47177 .75559 L .47154 .75296 L F
.921 .598 .412 r
.46962 .75561 m .47174 .75564 L .47177 .75563 L F
.724 .537 .638 r
.47154 .75296 m .47177 .75564 L .46962 .75561 L F
.47177 .75564 m .4718 .75592 L .46962 .75561 L F
.921 .598 .412 r
.46962 .75561 m .47016 .75592 L .47174 .75564 L F
0 .14 .657 r
.47177 .75559 m .47179 .75479 L .47154 .75296 L F
.562 .454 .689 r
.47271 .75606 m .47019 .7581 L .46962 .75561 L F
.532 .92 .816 r
.47178 .75562 m .47016 .75592 L .47295 .75441 L F
.47174 .75564 m .47016 .75592 L .47178 .75562 L F
.724 .537 .638 r
.47177 .75559 m .47192 .75594 L .4718 .75592 L F
0 .14 .657 r
.47179 .75479 m .47187 .75191 L .47154 .75296 L F
.048 .167 .668 r
.47154 .75296 m .47014 .75095 L .47121 .75063 L F
.417 .114 .341 r
.47665 .74891 m .47561 .74935 L .47202 .74814 L F
.47665 .74891 m .47576 .75061 L .47561 .74935 L F
.38 .187 .49 r
.30516 .63596 m .307 .63318 L .30689 .63533 L F
.43 .22 .492 r
.30481 .63812 m .30516 .63596 L .30689 .63533 L F
.543 .718 .954 r
.32384 .60352 m .32054 .60251 L .32254 .60237 L F
.467 .723 .981 r
.3256 .60308 m .32384 .60352 L .32254 .60237 L F
.563 .519 .764 r
.32652 .6048 m .32384 .60352 L .3256 .60308 L F
.824 .612 .616 r
.61615 .67388 m .6193 .67683 L .6193 .67439 L F
.363 .833 .809 r
.29058 .73038 m .29295 .72956 L .29422 .72933 L F
0 0 0 r
.29422 .72933 m .29497 .72892 L .2961 .7273 L F
.518 .183 .34 r
.29295 .72956 m .29497 .72892 L .29422 .72933 L F
.526 .182 .327 r
.50689 .72059 m .50734 .72219 L .50524 .72205 L F
.343 .7 .983 r
.50524 .72205 m .50734 .72219 L .50612 .72121 L F
.338 .103 .402 r
.50619 .72235 m .50524 .72205 L .50612 .72121 L F
.467 .868 .695 r
.50524 .72205 m .50336 .72329 L .50654 .72146 L F
.338 .103 .402 r
.5063 .72415 m .50524 .72205 L .50619 .72235 L F
.467 .868 .695 r
.50524 .72205 m .50654 .72146 L .5043 .72176 L F
.50524 .72205 m .5043 .72176 L .50391 .72181 L F
.476 .174 .374 r
.35981 .67974 m .35728 .68156 L .35774 .68024 L F
.506 .721 .969 r
.39818 .66843 m .39937 .66677 L .3963 .66614 L F
.39818 .66843 m .40017 .668 L .39937 .66677 L F
.434 .155 .389 r
.42044 .68225 m .41781 .68449 L .41828 .68262 L F
.49 0 0 r
.42823 .66482 m .43018 .66533 L .43209 .66438 L F
.953 .794 .648 r
.43209 .66438 m .43018 .66533 L .432 .66554 L F
.6 .477 .685 r
.43209 .66438 m .432 .66554 L .43381 .66308 L F
.43209 .66438 m .432 .66554 L .43381 .66308 L F
.559 .431 .663 r
.44713 .76477 m .44519 .76757 L .4449 .76517 L F
.641 .617 .81 r
.40452 .67168 m .40554 .66822 L .40342 .66866 L F
.40452 .67168 m .40688 .67144 L .40554 .66822 L F
.482 .257 .495 r
.40456 .67413 m .40688 .67144 L .40452 .67168 L F
0 .247 .76 r
.5228 .7074 m .5249 .70929 L .52431 .70993 L F
.383 0 0 r
.52584 .7109 m .5272 .71167 L .52638 .71118 L F
.52584 .7109 m .52638 .71118 L .52431 .70993 L F
.911 .611 .122 r
.52506 .70821 m .52584 .7109 L .5249 .70929 L F
.52506 .70821 m .52524 .71059 L .52584 .7109 L F
.52524 .71059 m .52528 .71117 L .52584 .7109 L F
.383 0 0 r
.52584 .7109 m .52431 .70993 L .5249 .70929 L F
.843 .655 .648 r
.62361 .68476 m .62216 .68763 L .62508 .688 L F
.86 .672 .646 r
.62216 .68763 m .62432 .69007 L .62508 .688 L F
.252 .157 .548 r
.31374 .71557 m .31389 .7179 L .31526 .71707 L F
.467 .154 .352 r
.48201 .7292 m .48428 .72878 L .48505 .72631 L F
.387 .081 .319 r
.48505 .72631 m .48628 .72821 L .4874 .72629 L F
.48505 .72631 m .48428 .72878 L .48628 .72821 L F
.56 .457 .694 r
.31986 .6906 m .32155 .68771 L .31946 .68813 L F
.546 .238 .396 r
.48081 .74761 m .4776 .75054 L .47724 .75028 L F
.48081 .74761 m .48022 .75058 L .4776 .75054 L F
.67 .353 .427 r
.48309 .75031 m .48081 .74761 L .48294 .74825 L F
.48309 .75031 m .48022 .75058 L .48081 .74761 L F
.558 .505 .753 r
.44836 .75904 m .44667 .76176 L .44627 .75932 L F
.44836 .75904 m .44901 .76185 L .44667 .76176 L F
.508 .364 .621 r
.4492 .76396 m .44667 .76176 L .44901 .76185 L F
.4492 .76396 m .44713 .76477 L .44667 .76176 L F
.661 .474 .621 r
.68691 .5896 m .68901 .58902 L .68878 .58617 L F
.584 .417 .621 r
.68878 .58617 m .68901 .58902 L .69124 .58602 L F
.607 .588 .805 r
.42483 .78129 m .42635 .78489 L .42862 .78451 L F
.554 .49 .738 r
.32825 .72874 m .32913 .73234 L .3311 .73175 L F
.528 .639 .903 r
.28452 .60677 m .28529 .60471 L .28364 .60504 L F
.28452 .60677 m .28689 .60689 L .28529 .60471 L F
0 .309 .78 r
.43224 .66503 m .432 .66554 L .43018 .66533 L F
.43224 .66503 m .43369 .66644 L .432 .66554 L F
.588 .474 .691 r
.29285 .6192 m .29521 .61924 L .29475 .6165 L F
.614 .35 .493 r
.29285 .6192 m .29504 .62116 L .29521 .61924 L F
.29285 .6192 m .29441 .62183 L .29504 .62116 L F
.457 .202 .438 r
.42573 .67707 m .42519 .67961 L .42315 .68006 L F
.463 .187 .408 r
.42792 .67667 m .42519 .67961 L .42573 .67707 L F
.689 .532 .669 r
.54869 .75412 m .54632 .75622 L .54511 .7537 L F
.54869 .75412 m .5485 .7566 L .54632 .75622 L F
.48 0 .028 r
.52208 .79248 m .52603 .79216 L .52423 .7927 L F
.717 .249 .138 r
.52603 .79216 m .52329 .79411 L .52423 .7927 L F
.52603 .79216 m .52546 .79337 L .52329 .79411 L F
.52603 .79216 m .52799 .79398 L .52546 .79337 L F
.511 .134 .261 r
.51918 .73736 m .51816 .73964 L .51544 .73964 L F
.683 .625 .785 r
.51994 .73427 m .51918 .73736 L .51785 .73451 L F
.51994 .73427 m .52192 .73754 L .51918 .73736 L F
.787 .434 .387 r
.51918 .73736 m .52107 .74012 L .51816 .73964 L F
.93 .708 .581 r
.52192 .73754 m .52107 .74012 L .51918 .73736 L F
.654 .769 .934 r
.72462 .7125 m .72227 .71337 L .72145 .71198 L F
.543 .346 .564 r
.50145 .73726 m .50097 .73947 L .49881 .73747 L F
.4 .635 .95 r
.28081 .60433 m .28434 .6042 L .27949 .60348 L F
.28081 .60433 m .28364 .60504 L .28434 .6042 L F
.444 .317 .613 r
.31836 .69641 m .32019 .69595 L .32004 .69364 L F
.471 .411 .708 r
.31836 .69641 m .32065 .69839 L .32019 .69595 L F
.31836 .69641 m .31914 .69922 L .32065 .69839 L F
.49 .24 .462 r
.41584 .68501 m .4157 .68823 L .41301 .68813 L F
.469 .224 .458 r
.41777 .68657 m .41584 .68501 L .41781 .68449 L F
.41777 .68657 m .4157 .68823 L .41584 .68501 L F
.481 .716 .974 r
.56815 .69435 m .56704 .69608 L .5655 .69315 L F
.56815 .69435 m .56902 .69579 L .56704 .69608 L F
.541 .443 .692 r
.56945 .69822 m .56704 .69608 L .56902 .69579 L F
.539 .328 .542 r
.5381 .73704 m .54029 .7344 L .53823 .73476 L F
.5381 .73704 m .54029 .7344 L .53823 .73476 L F
.5 .227 .431 r
.45381 .75606 m .45099 .75876 L .45153 .75644 L F
.934 .722 .593 r
.60518 .68028 m .60303 .68142 L .60273 .67907 L F
.60518 .68028 m .60446 .682 L .60303 .68142 L F
.724 .649 .774 r
.69013 .5946 m .69362 .59504 L .69244 .59178 L F
.728 .651 .772 r
.69244 .59178 m .69362 .59504 L .6958 .5925 L F
.35 .695 .983 r
.27031 .59087 m .26987 .59192 L .26834 .59095 L F
.27031 .59087 m .27181 .59195 L .26987 .59192 L F
.326 0 .112 r
.38776 .71108 m .38698 .7096 L .38913 .70912 L F
.38776 .71108 m .38569 .71158 L .38698 .7096 L F
.309 0 0 r
.59769 .75927 m .59393 .76088 L .59419 .7631 L F
.59769 .75927 m .59632 .7607 L .59393 .76088 L F
.178 0 0 r
.59961 .75859 m .59932 .75923 L .59769 .75927 L F
0 0 0 r
.59932 .75923 m .59632 .7607 L .59769 .75927 L F
.947 .771 .632 r
.63447 .5319 m .63427 .53433 L .63328 .53116 L F
.734 .523 .606 r
.53834 .74846 m .53732 .74541 L .53687 .74784 L F
.664 .491 .64 r
.67932 .59243 m .67899 .59461 L .68108 .5919 L F
.714 .614 .745 r
.51123 .74284 m .50899 .74541 L .50787 .74289 L F
.393 .236 .546 r
.51074 .74706 m .50902 .74805 L .50899 .74541 L F
.636 .446 .609 r
.65211 .52305 m .64901 .52573 L .64942 .52355 L F
.867 .812 .793 r
.56422 .74857 m .5623 .75126 L .56076 .75055 L F
.742 .975 .724 r
.35152 .72611 m .3512 .72652 L .35137 .72661 L F
0 0 0 r
.35137 .72661 m .34963 .72822 L .3507 .72708 L F
.629 .534 .728 r
.35137 .72661 m .3487 .72792 L .34963 .72822 L F
.35137 .72661 m .34915 .72911 L .3487 .72792 L F
.742 .975 .724 r
.3512 .72652 m .34915 .72911 L .35137 .72661 L F
0 0 0 r
.35137 .72661 m .3507 .72708 L .35193 .72688 L F
.35137 .72661 m .35193 .72688 L .35289 .72672 L F
.452 .162 .381 r
.59092 .663 m .59326 .66252 L .59345 .66079 L F
.671 .409 .517 r
.59326 .66252 m .59573 .66058 L .59345 .66079 L F
.54 .371 .601 r
.35506 .6822 m .35277 .68524 L .35294 .68286 L F
.791 .905 .921 r
.5677 .76938 m .56554 .77012 L .56824 .76838 L F
.659 .329 .403 r
.5677 .76938 m .56778 .77215 L .56554 .77012 L F
.422 .322 .636 r
.56998 .76697 m .5677 .76938 L .56824 .76838 L F
.56998 .76697 m .5705 .76974 L .5677 .76938 L F
0 0 .252 r
.56846 .77087 m .5677 .76938 L .5705 .76974 L F
.56846 .77087 m .56778 .77215 L .5677 .76938 L F
.414 .137 .381 r
.40794 .69514 m .4065 .69384 L .40843 .6933 L F
.40794 .69514 m .40592 .69574 L .4065 .69384 L F
.501 .729 .975 r
.40408 .65262 m .4036 .65414 L .4007 .6522 L F
.40408 .65262 m .40568 .65386 L .4036 .65414 L F
.531 .773 .987 r
.27898 .59401 m .2757 .59327 L .27729 .59372 L F
.061 .617 .815 r
.28088 .59409 m .27898 .59401 L .27729 .59372 L F
.676 .237 .2 r
.53391 .75431 m .53268 .75566 L .53022 .75403 L F
.533 .152 .265 r
.53582 .7539 m .53268 .75566 L .53391 .75431 L F
.691 .256 .211 r
.52859 .71408 m .5286 .71228 L .5272 .71167 L F
.52859 .71408 m .53043 .71445 L .5286 .71228 L F
.435 .087 .274 r
.34344 .65471 m .34462 .65657 L .3455 .654 L F
.34344 .65471 m .34239 .65702 L .34462 .65657 L F
.541 .422 .667 r
.41899 .76498 m .42116 .76467 L .42072 .76186 L F
.586 .445 .656 r
.41899 .76498 m .42153 .76713 L .42116 .76467 L F
.41899 .76498 m .41931 .76749 L .42153 .76713 L F
.57 .383 .589 r
.32269 .6771 m .32496 .67677 L .325 .67435 L F
.418 .261 .559 r
.325 .67435 m .32496 .67677 L .32669 .67618 L F
.443 .412 .729 r
.32445 .67209 m .325 .67435 L .32663 .67379 L F
.387 .257 .58 r
.32663 .67379 m .325 .67435 L .32669 .67618 L F
.666 .616 .789 r
.72283 .60011 m .72664 .60083 L .72476 .59938 L F
.403 .482 .827 r
.5493 .73481 m .55015 .73171 L .54849 .73217 L F
.591 .06 0 r
.50283 .78687 m .50408 .78657 L .50098 .78618 L F
0 .416 .721 r
.50472 .78668 m .50408 .78657 L .50283 .78687 L F
.401 0 .126 r
.57956 .6698 m .5824 .66855 L .58077 .66851 L F
.486 .279 .524 r
.3227 .67949 m .32496 .67677 L .32269 .6771 L F
.552 .315 .509 r
.55398 .75321 m .55335 .75645 L .55105 .75678 L F
.464 .235 .481 r
.55602 .75465 m .55398 .75321 L .55615 .7532 L F
.55602 .75465 m .55335 .75645 L .55398 .75321 L F
.562 .094 .101 r
.51456 .71817 m .51299 .71974 L .51026 .71852 L F
.604 .412 .594 r
.51208 .72098 m .51458 .72073 L .51456 .71817 L F
.501 .814 1 r
.51456 .71817 m .51683 .71771 L .51228 .71796 L F
.542 .362 .587 r
.51456 .71817 m .51686 .72021 L .51683 .71771 L F
.51456 .71817 m .51458 .72073 L .51686 .72021 L F
.64 .289 .361 r
.51683 .71771 m .51299 .71974 L .51456 .71817 L F
.501 .814 1 r
.51456 .71817 m .51683 .71771 L .51228 .71796 L F
.805 .329 0 r
.52862 .78873 m .52614 .78692 L .52634 .78897 L F
.615 .923 .673 r
.54142 .69586 m .54199 .69494 L .54358 .69386 L F
.747 .367 0 r
.54142 .69586 m .54182 .6974 L .54199 .69494 L F
.54142 .69586 m .54254 .69857 L .54182 .6974 L F
.306 0 0 r
.36579 .72054 m .36218 .72242 L .3637 .72093 L F
.576 .624 .863 r
.71004 .72305 m .71108 .72008 L .7088 .72051 L F
.86 .527 .421 r
.7137 .72183 m .71243 .72287 L .7147 .7208 L F
.7137 .72183 m .71108 .72008 L .71243 .72287 L F
.081 0 0 r
.71464 .72187 m .71187 .72219 L .71333 .7219 L F
.71412 .72185 m .71333 .7219 L .7137 .72183 L F
.71464 .72187 m .71333 .7219 L .71412 .72185 L F
.576 .624 .863 r
.71004 .72305 m .71243 .72287 L .712 .72199 L F
.71037 .7221 m .712 .72199 L .71108 .72008 L F
.71004 .72305 m .712 .72199 L .71037 .7221 L F
.216 0 0 r
.56234 .67934 m .56568 .67741 L .56289 .67866 L F
.901 .684 .601 r
.60664 .68518 m .60419 .68696 L .60507 .68412 L F
.60664 .68518 m .60648 .68752 L .60419 .68696 L F
.55 .439 .68 r
.32093 .68244 m .32318 .68203 L .3227 .67949 L F
.498 .374 .641 r
.32093 .68244 m .323 .6853 L .32318 .68203 L F
.32093 .68244 m .32108 .68544 L .323 .6853 L F
.556 .421 .653 r
.3169 .70464 m .31861 .70127 L .31672 .70182 L F
.553 .288 .468 r
.59444 .66903 m .59441 .67126 L .5924 .67153 L F
.67 .382 .476 r
.59831 .67104 m .59444 .66903 L .59768 .66893 L F
.59831 .67104 m .59441 .67126 L .59444 .66903 L F
.624 .781 .957 r
.71844 .59237 m .72044 .59184 L .71905 .59011 L F
.662 .411 .531 r
.71837 .59389 m .72044 .59184 L .71844 .59237 L F
0 0 .058 r
.71837 .59389 m .71844 .59237 L .71905 .59011 L F
.762 .689 .781 r
.71243 .72287 m .71363 .7253 L .71547 .72368 L F
.804 .686 .734 r
.68026 .60246 m .6835 .60266 L .68228 .59967 L F
.804 .685 .733 r
.68145 .60583 m .6835 .60266 L .68026 .60246 L F
.741 .658 .768 r
.68228 .59967 m .6835 .60266 L .68557 .60008 L F
.857 .483 .339 r
.60273 .67907 m .59975 .6762 L .60201 .67739 L F
.647 .328 .419 r
.59031 .67219 m .58915 .67562 L .58668 .67393 L F
.301 0 .276 r
.59156 .67341 m .59031 .67219 L .5924 .67153 L F
.59156 .67341 m .58915 .67562 L .59031 .67219 L F
.819 .736 .773 r
.74749 .61649 m .74428 .61655 L .74596 .61387 L F
.153 .084 .519 r
.74836 .61272 m .74749 .61649 L .74596 .61387 L F
.74836 .61272 m .74822 .61602 L .74749 .61649 L F
.275 0 0 r
.35325 .65106 m .35595 .64989 L .35409 .65042 L F
.7 .788 .919 r
.54473 .73182 m .54516 .73439 L .54849 .73217 L F
.43 0 0 r
.37834 .64654 m .38048 .64762 L .38172 .64786 L F
0 0 0 r
.55562 .68306 m .55648 .68309 L .55737 .68193 L F
.55562 .68306 m .55399 .68387 L .55648 .68309 L F
.499 .028 .069 r
.52078 .79398 m .52208 .79248 L .52329 .79411 L F
.503 .03 .064 r
.52208 .79248 m .52423 .7927 L .52329 .79411 L F
.741 .292 .186 r
.49025 .78577 m .49144 .78441 L .48812 .78364 L F
.491 0 .016 r
.49374 .78538 m .49144 .78441 L .49025 .78577 L F
.155 .315 .774 r
.57679 .73995 m .57653 .73722 L .57544 .73677 L F
.57679 .73995 m .57777 .7401 L .57653 .73722 L F
.173 .272 .726 r
.57679 .73995 m .57888 .74208 L .57777 .7401 L F
.54 .394 .631 r
.4313 .74276 m .43343 .74256 L .43319 .73998 L F
.605 .404 .583 r
.4308 .74401 m .43343 .74256 L .4313 .74276 L F
.443 .412 .729 r
.32445 .67209 m .32663 .67379 L .3265 .67137 L F
.395 .139 .405 r
.307 .63318 m .30956 .63043 L .30839 .63264 L F
.354 .077 .348 r
.30839 .63264 m .30956 .63043 L .31132 .62988 L F
.624 .364 .504 r
.54632 .75622 m .54526 .75887 L .54273 .75907 L F
.599 .29 .418 r
.5485 .7566 m .54526 .75887 L .54632 .75622 L F
.479 0 0 r
.53898 .72043 m .53825 .71974 L .53737 .71896 L F
.53898 .72043 m .54011 .72113 L .53825 .71974 L F
.467 .462 .769 r
.52297 .73574 m .52192 .73754 L .51994 .73427 L F
.52297 .73574 m .52353 .73684 L .52192 .73754 L F
.124 .319 .788 r
.57076 .72633 m .57164 .72528 L .56933 .72336 L F
0 .125 .65 r
.574 .72877 m .57353 .72935 L .57417 .72791 L F
.168 .386 .832 r
.57076 .72633 m .574 .72877 L .57164 .72528 L F
.444 .521 .842 r
.31835 .71751 m .31803 .72043 L .31731 .71877 L F
.31835 .71751 m .31967 .72026 L .31803 .72043 L F
.688 .595 .746 r
.32168 .7219 m .31803 .72043 L .31967 .72026 L F
.54 .386 .621 r
.67453 .60023 m .6768 .59976 L .67743 .59814 L F
.593 .491 .707 r
.6748 .60287 m .6768 .59976 L .67453 .60023 L F
.351 0 0 r
.55999 .69077 m .55932 .69099 L .55668 .69041 L F
.423 .27 .567 r
.55668 .69041 m .55932 .69099 L .55999 .69077 L F
.938 .952 .633 r
.56092 .68724 m .55932 .69099 L .55999 .69077 L F
.691 .183 .027 r
.55929 .69188 m .55999 .69077 L .55932 .69099 L F
.55929 .69188 m .56262 .69257 L .55999 .69077 L F
.554 .49 .738 r
.32825 .72874 m .3311 .73175 L .32995 .72854 L F
.538 .326 .54 r
.64679 .52618 m .64676 .52877 L .64445 .52914 L F
.582 .372 .561 r
.64901 .52573 m .64676 .52877 L .64679 .52618 L F
.56 .457 .694 r
.31986 .6906 m .32219 .69052 L .32155 .68771 L F
.448 .327 .621 r
.31986 .6906 m .3218 .69254 L .32219 .69052 L F
.31986 .6906 m .32004 .69364 L .3218 .69254 L F
.72 .655 .785 r
.69918 .59489 m .70063 .59126 L .69805 .59168 L F
.69918 .59489 m .70151 .59439 L .70063 .59126 L F
.581 .371 .56 r
.63967 .53154 m .6392 .5332 L .63739 .53416 L F
.56 .35 .552 r
.64109 .53193 m .63967 .53154 L .64192 .53108 L F
.64109 .53193 m .6392 .5332 L .63967 .53154 L F
.864 .641 .598 r
.52321 .74748 m .51893 .74467 L .52174 .7445 L F
.44 0 .077 r
.52321 .74748 m .51889 .75019 L .5207 .74812 L F
0 0 .157 r
.52402 .7444 m .52321 .74748 L .52174 .7445 L F
.52402 .7444 m .52394 .74648 L .52321 .74748 L F
.728 .66 .783 r
.70063 .59126 m .70151 .59439 L .70379 .59149 L F
.683 .62 .779 r
.70151 .59439 m .70463 .59483 L .70379 .59149 L F
.239 .634 .959 r
.73903 .58662 m .73728 .58647 L .73629 .58555 L F
.563 .708 .939 r
.32365 .7208 m .32168 .7219 L .31967 .72026 L F
.704 .546 .671 r
.68108 .5919 m .67899 .59461 L .68116 .5944 L F
.656 .49 .647 r
.68116 .5944 m .68438 .59206 L .68108 .5919 L F
.225 0 0 r
.37408 .71614 m .37269 .71771 L .37118 .71746 L F
.082 0 0 r
.37459 .71697 m .37408 .71614 L .37614 .71563 L F
.37459 .71697 m .37269 .71771 L .37408 .71614 L F
.783 .678 .748 r
.53582 .7539 m .53769 .75725 L .53809 .75633 L F
.391 0 .137 r
.53769 .75725 m .53787 .75596 L .53809 .75633 L F
.53769 .75725 m .53963 .75796 L .53787 .75596 L F
.53769 .75725 m .53672 .75858 L .53963 .75796 L F
.566 .723 .947 r
.71779 .71174 m .71904 .71292 L .7163 .71341 L F
.678 .436 .548 r
.32995 .72854 m .33228 .72867 L .33337 .72642 L F
.545 .471 .723 r
.33228 .72867 m .33417 .72505 L .33337 .72642 L F
.6 .314 .455 r
.45249 .73935 m .45523 .73743 L .45297 .73772 L F
.314 .418 .809 r
.57107 .74738 m .5695 .74837 L .56845 .74553 L F
.088 .023 .481 r
.571 .74964 m .5695 .74837 L .57107 .74738 L F
.571 .74964 m .56947 .75156 L .5695 .74837 L F
.271 .37 .782 r
.74204 .60848 m .7445 .61031 L .74435 .60868 L F
.72 .283 .213 r
.74254 .6246 m .74564 .62494 L .74487 .62646 L F
.696 .802 .338 r
.74487 .62646 m .74564 .62494 L .74629 .62328 L F
.614 .253 .334 r
.71139 .57982 m .71476 .57839 L .71296 .57804 L F
.324 .793 .928 r
.36522 .84956 m .36322 .84988 L .36167 .84966 L F
.36167 .84966 m .36322 .84988 L .36522 .84956 L F
.377 0 0 r
.52741 .72752 m .52692 .72866 L .52431 .72859 L F
0 .022 .583 r
.52741 .72752 m .52776 .72721 L .52692 .72866 L F
.388 .469 .822 r
.743 .58875 m .74617 .5907 L .74437 .59205 L F
.235 .073 .447 r
.7462 .59284 m .74437 .59205 L .74617 .5907 L F
.7462 .59284 m .7442 .59424 L .74437 .59205 L F
.559 .359 .566 r
.49199 .72324 m .4945 .72048 L .49208 .72093 L F
.429 .048 .213 r
.72735 .71376 m .73026 .71083 L .72612 .71363 L F
.243 0 .06 r
.73232 .71011 m .73026 .71083 L .72735 .71376 L F
.798 .868 .9 r
.50339 .74806 m .50574 .74743 L .50555 .74723 L F
.411 .241 .538 r
.30841 .63435 m .307 .63318 L .30839 .63264 L F
.30841 .63435 m .30689 .63533 L .307 .63318 L F
.783 .678 .748 r
.53582 .7539 m .53809 .75633 L .53787 .75596 L F
.416 .013 .164 r
.54062 .75924 m .53938 .76172 L .53728 .76146 L F
0 0 0 r
.54273 .75907 m .54223 .75915 L .54062 .75924 L F
.514 .109 .211 r
.54304 .76005 m .54062 .75924 L .54223 .75915 L F
.54308 .76006 m .53938 .76172 L .54062 .75924 L F
.225 .53 .92 r
.53963 .75796 m .54223 .75915 L .54143 .75845 L F
.53987 .7577 m .54143 .75845 L .54019 .75736 L F
.53963 .75796 m .54143 .75845 L .53987 .7577 L F
.514 .109 .211 r
.54308 .76006 m .54304 .76005 L .54223 .75915 L F
.843 .422 0 r
.54273 .75907 m .54308 .76006 L .54223 .75915 L F
.69 .433 .53 r
.54526 .75887 m .54308 .76006 L .54273 .75907 L F
.202 0 0 r
.54158 .76117 m .53938 .76172 L .54308 .76006 L F
.153 0 0 r
.54392 .76054 m .54158 .76117 L .54308 .76006 L F
.635 .462 .632 r
.54048 .75998 m .54392 .76054 L .54381 .75958 L F
.718 .694 .827 r
.54019 .75736 m .54223 .75915 L .54359 .75749 L F
.635 .462 .632 r
.54193 .75882 m .54359 .75749 L .54223 .75915 L F
.711 .946 .649 r
.54359 .75749 m .54223 .75915 L .54273 .75907 L F
.54359 .75749 m .54223 .75915 L .54273 .75907 L F
.635 .462 .632 r
.54203 .75873 m .54381 .75958 L .54359 .75749 L F
.577 .334 .512 r
.53963 .75796 m .54048 .75998 L .54223 .75915 L F
.635 .462 .632 r
.54048 .75998 m .54193 .75882 L .54223 .75915 L F
.54048 .75998 m .54381 .75958 L .54203 .75873 L F
.441 .654 .95 r
.36085 .7033 m .36 .70473 L .35891 .70332 L F
.328 .508 .882 r
.36085 .7033 m .36225 .70555 L .36 .70473 L F
.815 .479 .418 r
.60112 .6714 m .59831 .67104 L .59768 .66893 L F
.889 .763 .716 r
.60112 .6714 m .59804 .67337 L .59831 .67104 L F
.60112 .6714 m .59968 .67405 L .59804 .67337 L F
0 0 0 r
.60735 .75334 m .609 .75262 L .60732 .75369 L F
.60735 .75334 m .6103 .75117 L .609 .75262 L F
.322 .036 .313 r
.38194 .69939 m .38312 .70054 L .38365 .6988 L F
.38194 .69939 m .38128 .70122 L .38312 .70054 L F
.593 .189 .247 r
.46818 .73357 m .47176 .732 L .46855 .7323 L F
.46818 .73357 m .47054 .73384 L .47176 .732 L F
.485 .077 .189 r
.47054 .73384 m .47395 .73205 L .47176 .732 L F
0 0 0 r
.50033 .74625 m .49841 .7467 L .49997 .74519 L F
.50033 .74625 m .49665 .74726 L .49841 .7467 L F
.916 .749 .66 r
.5623 .75126 m .5619 .75365 L .56076 .75055 L F
.538 .292 .49 r
.4874 .72629 m .48967 .72609 L .49003 .72367 L F
.473 .235 .472 r
.49003 .72367 m .49181 .72551 L .49199 .72324 L F
.49003 .72367 m .48967 .72609 L .49181 .72551 L F
.246 .706 .95 r
.51182 .7884 m .51005 .78849 L .50868 .78777 L F
.362 .137 .433 r
.33278 .66247 m .33072 .66294 L .33042 .66528 L F
.57 .053 0 r
.46383 .7859 m .46697 .7862 L .46563 .78631 L F
.112 0 0 r
.46697 .7862 m .46899 .78622 L .46563 .78631 L F
.679 .228 .175 r
.70608 .5934 m .70702 .59202 L .70379 .59149 L F
.988 .839 .461 r
.70647 .59113 m .70702 .59202 L .70608 .5934 L F
.719 .661 .792 r
.71177 .60289 m .71498 .60291 L .71392 .59971 L F
.846 .725 .73 r
.71392 .59971 m .71498 .60291 L .71529 .60051 L F
.439 .193 .442 r
.74435 .60868 m .74692 .60904 L .74759 .60802 L F
.438 .002 .112 r
.74692 .60904 m .75039 .60707 L .74759 .60802 L F
0 0 0 r
.44155 .74041 m .44278 .74039 L .44494 .74027 L F
.039 .605 .778 r
.44278 .74039 m .44669 .74062 L .44494 .74027 L F
.179 0 0 r
.44494 .74027 m .44669 .74062 L .44734 .7402 L F
0 .007 .527 r
.72784 .6211 m .72267 .6199 L .72435 .62159 L F
.72784 .6211 m .72751 .62087 L .72315 .62 L F
.72342 .62007 m .72315 .62 L .72277 .61993 L F
.72784 .6211 m .72315 .62 L .72342 .62007 L F
.72784 .6211 m .72277 .61993 L .72287 .61995 L F
.449 .766 .996 r
.72584 .62043 m .72784 .6211 L .72463 .62155 L F
.72584 .62043 m .72463 .62155 L .72435 .62159 L F
.544 .003 0 r
.7277 .62437 m .72659 .62359 L .72435 .62159 L F
.158 .273 .734 r
.72626 .62085 m .72659 .62359 L .72808 .62269 L F
.72584 .62043 m .72592 .62076 L .72626 .62085 L F
.72592 .62076 m .72659 .62359 L .72626 .62085 L F
.211 .314 .752 r
.72435 .62159 m .72659 .62359 L .72592 .62076 L F
.72554 .62066 m .72592 .62076 L .72584 .62043 L F
.72435 .62159 m .72592 .62076 L .72554 .62066 L F
0 .007 .527 r
.72287 .61995 m .72277 .61993 L .72267 .6199 L F
.406 .205 .493 r
.70896 .71826 m .7088 .72051 L .71084 .71767 L F
.204 0 0 r
.28857 .65225 m .28689 .65354 L .2849 .65388 L F
.097 0 0 r
.29057 .65168 m .28689 .65354 L .28857 .65225 L F
.556 .409 .637 r
.40783 .66304 m .40811 .66586 L .40566 .6662 L F
.465 .199 .425 r
.40554 .66822 m .40811 .66586 L .40566 .6662 L F
.556 .409 .637 r
.40783 .66304 m .40811 .66586 L .40566 .6662 L F
.465 .199 .425 r
.40554 .66822 m .40811 .66586 L .40566 .6662 L F
0 0 .431 r
.57794 .74567 m .57906 .74458 L .57888 .74208 L F
0 0 .102 r
.57767 .74793 m .57906 .74458 L .57794 .74567 L F
.396 .846 .763 r
.34266 .73023 m .3409 .73076 L .33962 .73151 L F
.217 0 0 r
.34444 .73097 m .3409 .73076 L .34266 .73023 L F
.679 .228 .175 r
.70608 .5934 m .70379 .59149 L .70463 .59483 L F
.239 .281 .705 r
.70463 .59483 m .70696 .59646 L .70608 .5934 L F
.546 .03 0 r
.72413 .71351 m .72411 .71277 L .72462 .7125 L F
.977 .801 .6 r
.62266 .69859 m .62431 .69637 L .62289 .69553 L F
.62266 .69859 m .62376 .69923 L .62431 .69637 L F
.183 0 .192 r
.50422 .71005 m .50176 .71259 L .50347 .7116 L F
0 0 .042 r
.50651 .70738 m .50422 .71005 L .50557 .7091 L F
.204 0 .28 r
.50347 .7116 m .50557 .7091 L .50422 .71005 L F
.526 .182 .327 r
.50689 .72059 m .50524 .72205 L .50391 .72181 L F
0 0 0 r
.52078 .78693 m .51737 .78816 L .51959 .78834 L F
.614 .151 .131 r
.52317 .78837 m .52078 .78693 L .51959 .78834 L F
0 0 0 r
.61193 .75019 m .609 .75262 L .6103 .75117 L F
.571 .438 .661 r
.31861 .70127 m .32065 .69839 L .31914 .69922 L F
.611 .64 .854 r
.73813 .59503 m .73962 .59753 L .74198 .59702 L F
.546 .337 .549 r
.73962 .59753 m .74189 .59947 L .74198 .59702 L F
0 0 .17 r
.48329 .74471 m .48319 .74434 L .48564 .74266 L F
.973 .83 .641 r
.29972 .72715 m .29996 .72983 L .30185 .72882 L F
.29972 .72715 m .29867 .72927 L .29996 .72983 L F
.141 0 .366 r
.61465 .74554 m .61425 .7476 L .61308 .74887 L F
0 0 0 r
.61308 .74887 m .61425 .7476 L .61193 .75019 L F
0 0 .56 r
.57952 .71762 m .58141 .7206 L .58088 .72067 L F
.618 .065 0 r
.58141 .7206 m .58231 .72105 L .58088 .72067 L F
.803 .717 .77 r
.57658 .67902 m .57441 .68198 L .57735 .6821 L F
.786 .516 .529 r
.57441 .68198 m .57786 .68467 L .57735 .6821 L F
.735 .677 .794 r
.57658 .67902 m .57735 .6821 L .58005 .67954 L F
.735 .475 .536 r
.54032 .73669 m .54405 .73449 L .54029 .7344 L F
.54032 .73669 m .54456 .73692 L .54405 .73449 L F
.278 0 .158 r
.49876 .71476 m .50095 .71458 L .50176 .71259 L F
.165 0 .108 r
.50176 .71259 m .50265 .71382 L .50347 .7116 L F
.50176 .71259 m .50095 .71458 L .50265 .71382 L F
.358 .042 .285 r
.40402 .69645 m .40342 .69834 L .40118 .69875 L F
.421 .098 .31 r
.40536 .69761 m .40402 .69645 L .40592 .69574 L F
.40536 .69761 m .40342 .69834 L .40402 .69645 L F
.656 .41 .535 r
.51196 .72288 m .51458 .72073 L .51208 .72098 L F
.278 .775 .732 r
.39253 .66593 m .39296 .66588 L .39507 .66515 L F
.302 0 0 r
.39094 .66558 m .39296 .66588 L .39147 .66625 L F
.278 .775 .732 r
.39147 .66625 m .39296 .66588 L .39253 .66593 L F
.16 0 0 r
.39325 .66585 m .39296 .66588 L .39094 .66558 L F
.39445 .66598 m .39296 .66588 L .39325 .66585 L F
.255 .634 .962 r
.39445 .66598 m .39507 .66515 L .39296 .66588 L F
.39445 .66598 m .3963 .66614 L .39507 .66515 L F
.828 .726 .752 r
.63328 .53116 m .63427 .53433 L .63128 .53355 L F
.837 .609 .593 r
.63427 .53433 m .63123 .53601 L .63128 .53355 L F
.63427 .53433 m .63434 .53685 L .63123 .53601 L F
.686 .521 .657 r
.63427 .53433 m .63584 .5347 L .63434 .53685 L F
.63427 .53433 m .63739 .53416 L .63584 .5347 L F
0 0 0 r
.47715 .74822 m .47576 .75061 L .47665 .74891 L F
.744 .405 0 r
.58179 .70443 m .5827 .70693 L .5828 .707 L F
.693 .861 .962 r
.5803 .70712 m .5828 .707 L .5827 .70693 L F
.539 .371 .602 r
.35277 .68524 m .35292 .68796 L .35067 .68828 L F
.648 .525 .7 r
.35292 .68796 m .35081 .69053 L .35067 .68828 L F
.599 .29 .418 r
.5485 .7566 m .5485 .7588 L .54526 .75887 L F
.583 .278 .417 r
.55065 .75855 m .5485 .7588 L .5485 .7566 L F
.606 .271 .377 r
.55105 .75678 m .55065 .75855 L .5485 .7566 L F
.713 .316 .295 r
.31489 .71453 m .31842 .71487 L .31654 .71331 L F
.31489 .71453 m .31842 .71487 L .31654 .71331 L F
.888 .722 .671 r
.31847 .71357 m .31769 .71378 L .31654 .71331 L F
.31769 .71378 m .31489 .71453 L .3164 .71341 L F
.31769 .71378 m .3164 .71341 L .31654 .71331 L F
.31847 .71357 m .31703 .71204 L .31489 .71453 L F
.31847 .71357 m .31842 .71487 L .31703 .71204 L F
.328 .741 .979 r
.31792 .71385 m .31999 .71434 L .31703 .71204 L F
.31842 .71487 m .31981 .7144 L .31792 .71385 L F
.31981 .7144 m .31999 .71434 L .31792 .71385 L F
0 0 .417 r
.57787 .71477 m .57952 .71762 L .57852 .71602 L F
.651 .344 .439 r
.59563 .66282 m .59885 .66067 L .59573 .66058 L F
.59563 .66282 m .59927 .66232 L .59885 .66067 L F
.521 0 0 r
.48378 .78663 m .48241 .78704 L .48028 .7865 L F
.654 .139 .006 r
.48378 .78663 m .48454 .78839 L .48241 .78704 L F
.48378 .78663 m .48628 .78829 L .48454 .78839 L F
.856 .683 .667 r
.62114 .68222 m .6207 .68454 L .62361 .68476 L F
.862 .68 .656 r
.62048 .68692 m .62361 .68476 L .6207 .68454 L F
.62048 .68692 m .62216 .68763 L .62361 .68476 L F
.405 0 0 r
.44643 .78625 m .44543 .78661 L .44314 .78623 L F
.13 .676 .714 r
.4489 .78605 m .44543 .78661 L .44643 .78625 L F
.993 .751 .455 r
.56655 .703 m .56789 .7067 L .56608 .70414 L F
.55 .508 .762 r
.3169 .70464 m .31774 .70729 L .31957 .70681 L F
.381 0 .021 r
.38517 .66749 m .38893 .66564 L .38716 .66736 L F
.38517 .66749 m .38589 .66657 L .38893 .66564 L F
.093 0 0 r
.38926 .66659 m .38893 .66564 L .39094 .66558 L F
.38926 .66659 m .38716 .66736 L .38893 .66564 L F
.813 .4 0 r
.57353 .72935 m .57472 .7318 L .57378 .73077 L F
.57353 .72935 m .57378 .73077 L .57417 .72791 L F
.561 .452 .687 r
.52565 .74318 m .5282 .74504 L .52786 .74276 L F
.53 .456 .717 r
.52565 .74318 m .52617 .74555 L .5282 .74504 L F
.559 .431 .663 r
.44713 .76477 m .44733 .7672 L .44519 .76757 L F
.773 .457 .452 r
.48699 .75127 m .48309 .75031 L .48432 .75126 L F
.578 .589 .827 r
.51589 .75118 m .51657 .74765 L .51646 .74847 L F
.51589 .75118 m .51853 .75099 L .51657 .74765 L F
.026 .035 .53 r
.70492 .60124 m .7053 .59933 L .70506 .59998 L F
.70492 .60124 m .70557 .60093 L .7053 .59933 L F
.089 .193 .679 r
.70492 .60124 m .70615 .60312 L .70557 .60093 L F
.399 0 0 r
.54267 .74294 m .54162 .74396 L .539 .74388 L F
.811 .777 .821 r
.70854 .60217 m .70933 .60535 L .71177 .60289 L F
.473 .872 .962 r
.27515 .65653 m .27565 .65554 L .2736 .6563 L F
.27515 .65653 m .27759 .65594 L .27565 .65554 L F
.567 .557 .803 r
.4209 .65816 m .42382 .6595 L .42168 .65997 L F
.508 .749 .982 r
.73145 .62827 m .73246 .62935 L .73484 .62829 L F
.646 .389 .516 r
.30917 .70906 m .31158 .70935 L .31136 .70723 L F
.628 .238 0 r
.56674 .71806 m .56631 .71727 L .56508 .71499 L F
.746 .369 0 r
.56674 .71806 m .56711 .7194 L .56631 .71727 L F
.56674 .71806 m .56762 .72018 L .56711 .7194 L F
0 0 .322 r
.56631 .71727 m .56711 .7194 L .56606 .71632 L F
.96 .665 .24 r
.56606 .71632 m .56711 .7194 L .56634 .71835 L F
0 .088 .623 r
.56711 .7194 m .56851 .72041 L .56658 .71858 L F
.56711 .7194 m .56658 .71858 L .56634 .71835 L F
.746 .369 0 r
.56762 .72018 m .56764 .72025 L .56711 .7194 L F
.439 .593 .908 r
.32054 .60251 m .31704 .60019 L .31892 .6001 L F
.481 .678 .952 r
.32127 .60083 m .32054 .60251 L .31892 .6001 L F
.32127 .60083 m .32254 .60237 L .32054 .60251 L F
.81 .672 .71 r
.70243 .58606 m .70403 .5835 L .70124 .58289 L F
.775 .963 .926 r
.73977 .7318 m .74073 .73233 L .74204 .73099 L F
.713 .747 .878 r
.32311 .72295 m .3242 .7256 L .32648 .72375 L F
.088 .237 .723 r
.57323 .6995 m .57245 .70086 L .57162 .69923 L F
.704 .985 .842 r
.57323 .6995 m .57221 .70033 L .57245 .70086 L F
.211 .689 .935 r
.57041 .7008 m .57245 .70086 L .57261 .70122 L F
.71 .607 .739 r
.57041 .7008 m .57157 .7046 L .57316 .70316 L F
.57041 .7008 m .57316 .70316 L .57245 .70086 L F
.515 .471 .745 r
.57162 .69923 m .57245 .70086 L .57041 .7008 L F
.257 0 0 r
.57024 .70192 m .57041 .7008 L .57245 .70086 L F
.704 .985 .842 r
.57221 .70033 m .57024 .70192 L .57245 .70086 L F
.211 .689 .935 r
.57261 .70122 m .57245 .70086 L .5737 .70143 L F
.969 .832 .653 r
.57245 .70086 m .57316 .70316 L .5737 .70143 L F
0 0 0 r
.5838 .72489 m .58257 .72651 L .58451 .72322 L F
.599 .137 0 r
.58451 .72322 m .58536 .72445 L .5838 .72489 L F
.58489 .72378 m .5846 .72353 L .58536 .72445 L F
.58451 .72322 m .5846 .72353 L .58489 .72378 L F
.795 .344 .172 r
.58227 .72141 m .58398 .7237 L .5846 .72353 L F
.538 .109 .174 r
.58398 .7237 m .58454 .72348 L .5846 .72353 L F
.58454 .72348 m .58716 .72242 L .5846 .72353 L F
.687 .68 .837 r
.58716 .72242 m .58536 .72445 L .5846 .72353 L F
.538 .109 .174 r
.58452 .72349 m .58611 .72388 L .58716 .72242 L F
.58398 .7237 m .58478 .72377 L .58452 .72349 L F
.58478 .72377 m .58611 .72388 L .58452 .72349 L F
.555 .05 0 r
.58249 .72123 m .5846 .72353 L .58451 .72322 L F
.58231 .72105 m .58316 .72197 L .58249 .72123 L F
.58316 .72197 m .5846 .72353 L .58249 .72123 L F
.812 .528 .509 r
.61135 .66609 m .61135 .66815 L .61447 .6686 L F
.819 .632 .65 r
.61135 .66815 m .61285 .67084 L .61447 .6686 L F
.8 .604 .636 r
.61285 .67084 m .61603 .67147 L .61447 .6686 L F
.623 .52 .716 r
.35081 .69053 m .34884 .69311 L .34868 .6912 L F
.598 .486 .696 r
.35133 .69244 m .34884 .69311 L .35081 .69053 L F
.589 .493 .713 r
.3518 .69649 m .34884 .69311 L .35133 .69244 L F
.3518 .69649 m .35003 .69741 L .34884 .69311 L F
0 0 0 r
.3716 .70535 m .37179 .70528 L .37373 .70479 L F
.3716 .70535 m .36983 .70606 L .37179 .70528 L F
.523 .336 .569 r
.43023 .66283 m .42823 .66482 L .42761 .66473 L F
.545 .394 .627 r
.42273 .75647 m .42486 .75611 L .42473 .75367 L F
.536 .408 .653 r
.42273 .75647 m .42511 .75864 L .42486 .75611 L F
.42273 .75647 m .42304 .75916 L .42511 .75864 L F
.974 .678 .397 r
.59555 .73757 m .59427 .7386 L .59444 .73659 L F
.59555 .73757 m .59531 .73931 L .59427 .7386 L F
0 .122 .664 r
.72993 .62735 m .7277 .62437 L .72921 .62643 L F
.568 .482 .718 r
.3518 .69649 m .35005 .6985 L .35003 .69741 L F
.3518 .69649 m .35219 .69823 L .35005 .6985 L F
.407 .21 .498 r
.31134 .62758 m .31347 .62449 L .31281 .62731 L F
.4 .231 .534 r
.31132 .62988 m .31134 .62758 L .31281 .62731 L F
0 .286 .68 r
.26682 .59007 m .26612 .58983 L .26471 .58932 L F
.26682 .59007 m .26834 .59095 L .26612 .58983 L F
.417 .165 .421 r
.75008 .61039 m .7507 .61281 L .74836 .61272 L F
.245 .095 .47 r
.75246 .60751 m .75238 .60972 L .75008 .61039 L F
.298 .096 .429 r
.75237 .61189 m .75008 .61039 L .75238 .60972 L F
.75237 .61189 m .7507 .61281 L .75008 .61039 L F
.188 0 .224 r
.50557 .7091 m .50819 .70615 L .50651 .70738 L F
.872 .667 .622 r
.60648 .68752 m .60797 .69079 L .60583 .69006 L F
.838 .542 .489 r
.60797 .69079 m .6057 .69255 L .60583 .69006 L F
.60797 .69079 m .60836 .69297 L .6057 .69255 L F
.226 0 0 r
.35595 .64989 m .35772 .65018 L .35936 .64962 L F
.411 0 0 r
.35772 .65018 m .36148 .64935 L .35936 .64962 L F
.19 .31 .757 r
.52617 .74555 m .52831 .74729 L .5282 .74504 L F
.739 .636 .746 r
.68666 .5942 m .69013 .5946 L .68916 .59135 L F
.748 .573 .658 r
.68835 .59758 m .69013 .5946 L .68666 .5942 L F
.702 .615 .757 r
.68916 .59135 m .69013 .5946 L .69244 .59178 L F
.546 .476 .728 r
.50757 .72629 m .50971 .72583 L .50897 .72346 L F
.637 .369 .497 r
.5065 .72813 m .50971 .72583 L .50757 .72629 L F
.081 .641 .741 r
.44075 .78638 m .4397 .78641 L .4376 .78657 L F
.068 .631 .733 r
.44314 .78623 m .4397 .78641 L .44075 .78638 L F
.216 0 0 r
.56234 .67934 m .56463 .67877 L .56568 .67741 L F
0 0 0 r
.56568 .67741 m .5664 .67787 L .56748 .67632 L F
.56568 .67741 m .56463 .67877 L .5664 .67787 L F
.448 .687 .967 r
.39079 .64967 m .3875 .64834 L .38944 .64876 L F
.251 .699 .957 r
.39124 .64905 m .39079 .64967 L .38944 .64876 L F
.39124 .64905 m .39286 .64976 L .39079 .64967 L F
0 .007 .527 r
.72784 .6211 m .72881 .62225 L .72751 .62087 L F
.707 .729 .867 r
.56332 .6878 m .5678 .68794 L .56675 .68536 L F
.791 .758 .823 r
.56675 .68536 m .5678 .68794 L .57025 .6859 L F
.542 .875 .991 r
.31182 .72296 m .31053 .72247 L .30977 .72361 L F
.879 .696 .65 r
.31068 .72463 m .31182 .72296 L .30977 .72361 L F
0 0 .267 r
.31053 .72247 m .31068 .72463 L .30977 .72361 L F
.818 .573 .569 r
.61436 .67348 m .61603 .67147 L .61285 .67084 L F
.61436 .67348 m .61615 .67388 L .61603 .67147 L F
.593 .491 .707 r
.6748 .60287 m .67715 .60258 L .6768 .59976 L F
.631 .502 .686 r
.6748 .60287 m .67802 .60537 L .67715 .60258 L F
.6748 .60287 m .6758 .60622 L .67802 .60537 L F
.265 0 .034 r
.37269 .71771 m .36974 .71931 L .37118 .71746 L F
.591 .018 0 r
.32253 .71648 m .32578 .71833 L .32209 .71677 L F
.628 .824 .976 r
.32209 .71677 m .32578 .71833 L .32779 .71753 L F
.714 .568 .689 r
.32522 .7203 m .32779 .71753 L .32578 .71833 L F
.809 .538 .529 r
.72476 .59938 m .72757 .59665 L .72508 .59725 L F
.598 .591 .816 r
.51563 .74205 m .51463 .74555 L .51372 .74252 L F
.51563 .74205 m .51759 .74578 L .51463 .74555 L F
.617 .105 .007 r
.51759 .74578 m .51332 .74591 L .51463 .74555 L F
.745 .643 .747 r
.68228 .59967 m .68557 .60008 L .68454 .59686 L F
.685 .61 .766 r
.68454 .59686 m .68557 .60008 L .68835 .59758 L F
.799 .752 .81 r
.71392 .59971 m .71529 .60051 L .7173 .59848 L F
.789 .711 .777 r
.63962 .51953 m .63631 .51999 L .63867 .51713 L F
.786 .65 .712 r
.63962 .51953 m .63811 .52361 L .63631 .51999 L F
.695 .664 .816 r
.64163 .51899 m .63962 .51953 L .63867 .51713 L F
.789 .509 .512 r
.6081 .66775 m .61135 .66609 L .60778 .6658 L F
.6081 .66775 m .61135 .66815 L .61135 .66609 L F
.339 .495 .868 r
.58913 .76133 m .59024 .75918 L .58767 .75933 L F
.58913 .76133 m .59423 .76368 L .59024 .75918 L F
0 0 .282 r
.61651 .74228 m .61607 .74455 L .61465 .74554 L F
0 0 .209 r
.61465 .74554 m .61552 .74657 L .61425 .7476 L F
.61465 .74554 m .61607 .74455 L .61552 .74657 L F
.098 .169 .65 r
.56902 .74263 m .56775 .74331 L .56724 .73993 L F
.283 .247 .641 r
.57011 .74388 m .56775 .74331 L .56902 .74263 L F
.57011 .74388 m .56845 .74553 L .56775 .74331 L F
.906 .66 .555 r
.46814 .74998 m .47014 .75095 L .46935 .74867 L F
.693 .375 .433 r
.5286 .73064 m .52808 .73207 L .52497 .72977 L F
.987 .762 .512 r
.5286 .73064 m .52808 .73207 L .52497 .72977 L F
.37 .441 .803 r
.52692 .72866 m .52808 .73207 L .52497 .72977 L F
0 0 0 r
.52808 .73207 m .52469 .73058 L .52497 .72977 L F
.37 .441 .803 r
.52692 .72866 m .52497 .72977 L .52469 .73058 L F
.37 .682 .978 r
.43238 .78622 m .43287 .78513 L .43059 .78402 L F
.43238 .78622 m .43415 .78622 L .43287 .78513 L F
.479 .145 .321 r
.59008 .66515 m .59326 .66252 L .59092 .663 L F
.426 0 0 r
.59882 .729 m .60212 .73119 L .60013 .7284 L F
.669 .534 .691 r
.60013 .7284 m .60273 .72932 L .60158 .72677 L F
.706 .433 .508 r
.60013 .7284 m .60212 .73119 L .60273 .72932 L F
0 .358 .728 r
.54698 .725 m .54904 .72585 L .55021 .7265 L F
.839 .733 .747 r
.70854 .60217 m .71177 .60289 L .71151 .60039 L F
.719 .661 .792 r
.71177 .60289 m .71392 .59971 L .71151 .60039 L F
.313 0 0 r
.34768 .65339 m .34976 .65314 L .35112 .65172 L F
.307 0 .017 r
.34976 .65314 m .35325 .65106 L .35112 .65172 L F
.428 .058 .232 r
.64445 .52914 m .6467 .52999 L .64413 .5305 L F
.64445 .52914 m .64676 .52877 L .6467 .52999 L F
.338 .261 .621 r
.5838 .72489 m .58254 .7278 L .58257 .72651 L F
.777 .443 .422 r
.45974 .75587 m .45627 .75369 L .45957 .75392 L F
.747 .604 .698 r
.69244 .59178 m .6958 .5925 L .69466 .58891 L F
.65 .56 .739 r
.6958 .5925 m .69707 .58822 L .69466 .58891 L F
.6958 .5925 m .69805 .59168 L .69707 .58822 L F
.277 .779 .779 r
.37257 .64863 m .37472 .64802 L .37637 .64773 L F
.418 0 .036 r
.37472 .64802 m .37834 .64654 L .37637 .64773 L F
.457 .227 .476 r
.40118 .69875 m .40033 .70195 L .39892 .70147 L F
.437 .209 .468 r
.40236 .7002 m .40118 .69875 L .40342 .69834 L F
.40236 .7002 m .40033 .70195 L .40118 .69875 L F
.75 .682 .786 r
.43838 .73731 m .43581 .73982 L .43917 .73982 L F
.273 0 0 r
.43581 .73982 m .43782 .74003 L .43917 .73982 L F
.491 0 0 r
.43782 .74003 m .44155 .74041 L .43917 .73982 L F
.303 .605 .951 r
.73671 .70962 m .73542 .71049 L .73453 .70969 L F
.73671 .70962 m .73894 .71162 L .73542 .71049 L F
.632 .933 .968 r
.715 .58201 m .71363 .58365 L .71286 .58319 L F
.715 .58201 m .71363 .58365 L .71286 .58319 L F
0 .084 .64 r
.71995 .60649 m .71843 .6056 L .71807 .60463 L F
.71995 .60649 m .72039 .60821 L .71843 .6056 L F
.445 .186 .427 r
.32266 .61352 m .32259 .61542 L .32023 .61622 L F
.384 .137 .411 r
.32459 .61313 m .32266 .61352 L .32504 .61101 L F
.528 .324 .546 r
.32459 .61313 m .32259 .61542 L .32266 .61352 L F
0 .084 .644 r
.31291 .7289 m .31438 .7319 L .31469 .73134 L F
.269 0 0 r
.31438 .7319 m .31483 .73307 L .31469 .73134 L F
.239 0 0 r
.33862 .65891 m .33818 .65793 L .33705 .65973 L F
.33862 .65891 m .34042 .6576 L .33818 .65793 L F
.838 .777 .794 r
.72264 .59447 m .72344 .59512 L .72422 .5921 L F
.731 .253 0 r
.7241 .59636 m .72344 .59512 L .72264 .59447 L F
.7241 .59636 m .72508 .59725 L .72344 .59512 L F
.851 .831 .827 r
.72344 .59512 m .72693 .59049 L .72422 .5921 L F
.501 .254 .472 r
.63662 .53821 m .63434 .53685 L .63584 .5347 L F
.519 .26 .462 r
.63739 .53416 m .63926 .536 L .63584 .5347 L F
.565 .3 .474 r
.63926 .536 m .63662 .53821 L .63584 .5347 L F
.735 .538 .626 r
.67906 .59702 m .68116 .5944 L .67899 .59461 L F
.67906 .59702 m .68272 .59768 L .68116 .5944 L F
.656 .49 .647 r
.68116 .5944 m .68455 .59499 L .68438 .59206 L F
.699 .523 .646 r
.68116 .5944 m .68454 .59686 L .68455 .59499 L F
.68116 .5944 m .68272 .59768 L .68454 .59686 L F
.347 .091 .376 r
.4968 .71791 m .49861 .71728 L .49876 .71476 L F
.345 .089 .376 r
.49876 .71476 m .50044 .71661 L .50095 .71458 L F
.49876 .71476 m .49861 .71728 L .50044 .71661 L F
.582 .717 .936 r
.35712 .70333 m .35329 .702 L .35531 .70113 L F
.483 .56 .858 r
.35746 .7006 m .35712 .70333 L .35531 .70113 L F
.35746 .7006 m .35891 .70332 L .35712 .70333 L F
.791 .758 .823 r
.56675 .68536 m .57025 .6859 L .56894 .68413 L F
.549 .677 .923 r
.57025 .6859 m .57222 .68531 L .56894 .68413 L F
.483 .632 .919 r
.31585 .59843 m .31787 .59835 L .31704 .60019 L F
.478 .627 .917 r
.31787 .59835 m .31892 .6001 L .31704 .60019 L F
.557 .011 0 r
.48943 .78892 m .49277 .78936 L .49125 .79017 L F
.478 0 0 r
.49277 .78936 m .49364 .79047 L .49125 .79017 L F
.49277 .78936 m .49501 .79016 L .49364 .79047 L F
.52 .192 .352 r
.47603 .73207 m .47827 .7319 L .47955 .72904 L F
.561 .234 .372 r
.47955 .72904 m .47827 .7319 L .48147 .73051 L F
.58 .222 .326 r
.47955 .72904 m .48147 .73051 L .48201 .7292 L F
.769 .668 .751 r
.67802 .60537 m .68145 .60583 L .68026 .60246 L F
.519 .26 .462 r
.63739 .53416 m .6392 .5332 L .63926 .536 L F
0 .112 .639 r
.53066 .79006 m .52985 .78959 L .52862 .78873 L F
.53066 .79006 m .53199 .79161 L .52985 .78959 L F
.963 .935 .702 r
.31068 .72463 m .30999 .72663 L .31097 .72608 L F
.621 .773 .953 r
.31068 .72463 m .31097 .72608 L .31269 .72574 L F
.86 .672 .646 r
.62216 .68763 m .62189 .68999 L .62432 .69007 L F
.933 .756 .64 r
.62204 .69253 m .62432 .69007 L .62189 .68999 L F
.62204 .69253 m .62352 .69331 L .62432 .69007 L F
.271 0 0 r
.4523 .78609 m .45097 .78628 L .4489 .78605 L F
.101 0 0 r
.45438 .78606 m .45097 .78628 L .4523 .78609 L F
.54 .371 .601 r
.35506 .6822 m .35466 .68501 L .35277 .68524 L F
.56 .387 .604 r
.35492 .6873 m .35277 .68524 L .35466 .68501 L F
.35492 .6873 m .35292 .68796 L .35277 .68524 L F
.547 .428 .669 r
.42053 .77299 m .42261 .77262 L .42234 .77011 L F
.268 0 .024 r
.37926 .70185 m .37992 .70316 L .38128 .70122 L F
.37926 .70185 m .37791 .7036 L .37992 .70316 L F
.322 0 .085 r
.38128 .70122 m .37992 .70316 L .38205 .70271 L F
.163 .702 .755 r
.37787 .70328 m .38186 .70274 L .37992 .70316 L F
.38186 .70274 m .38205 .70271 L .37992 .70316 L F
.268 0 .024 r
.37791 .7036 m .37785 .70369 L .37992 .70316 L F
.423 .543 .873 r
.73894 .71162 m .74046 .71138 L .73885 .71275 L F
.425 .547 .875 r
.74046 .71138 m .74254 .71447 L .73885 .71275 L F
.799 .752 .81 r
.71392 .59971 m .7173 .59848 L .71643 .5978 L F
.714 .89 .961 r
.71643 .5978 m .7173 .59848 L .71929 .59761 L F
.591 .018 0 r
.32253 .71648 m .32209 .71677 L .32204 .71524 L F
.416 .103 .323 r
.42462 .68123 m .42315 .68006 L .42519 .67961 L F
.42462 .68123 m .42253 .68175 L .42315 .68006 L F
.569 .645 .886 r
.43697 .66819 m .43505 .66881 L .43369 .66644 L F
.443 .241 .509 r
.43697 .66819 m .43479 .67098 L .43505 .66881 L F
.706 .611 .749 r
.29945 .71784 m .30114 .72166 L .30318 .72026 L F
.581 .409 .613 r
.42882 .74478 m .43099 .74758 L .4308 .74401 L F
.42882 .74478 m .4289 .74802 L .43099 .74758 L F
.724 .615 .735 r
.69247 .58932 m .69466 .58891 L .69391 .5861 L F
.712 .552 .67 r
.69244 .59178 m .69466 .58891 L .69247 .58932 L F
.64 .586 .779 r
.69466 .58891 m .69586 .58548 L .69391 .5861 L F
.69466 .58891 m .69707 .58822 L .69586 .58548 L F
.822 .787 .819 r
.46814 .74998 m .4667 .75102 L .47014 .75095 L F
.951 .79 .646 r
.46886 .7527 m .47014 .75095 L .4667 .75102 L F
.453 .757 .994 r
.46814 .74998 m .47014 .75095 L .47095 .74962 L F
.539 .342 .562 r
.47014 .75095 m .47154 .75296 L .47095 .74962 L F
.342 .699 .983 r
.30801 .59825 m .30453 .59719 L .30655 .59718 L F
.472 .759 .993 r
.30859 .59696 m .30801 .59825 L .30655 .59718 L F
.30859 .59696 m .31022 .59799 L .30801 .59825 L F
.731 .63 .747 r
.71832 .72358 m .71905 .72614 L .7212 .72348 L F
.402 .185 .466 r
.71905 .72614 m .7209 .72605 L .7212 .72348 L F
.622 .165 .146 r
.51262 .79375 m .51577 .79354 L .51481 .79322 L F
.137 0 0 r
.51577 .79354 m .51732 .79382 L .51481 .79322 L F
.51577 .79354 m .51904 .79368 L .51732 .79382 L F
.482 .257 .495 r
.40456 .67413 m .4066 .67379 L .40688 .67144 L F
.6 .595 .818 r
.40554 .66822 m .40688 .67144 L .4091 .671 L F
.616 .373 .527 r
.40688 .67144 m .40913 .67295 L .4091 .671 L F
.40688 .67144 m .4066 .67379 L .40913 .67295 L F
.47 .365 .653 r
.60158 .72677 m .60386 .72313 L .60087 .72349 L F
.60158 .72677 m .60332 .72622 L .60386 .72313 L F
.943 .581 .273 r
.60433 .72841 m .60332 .72622 L .60158 .72677 L F
.485 .442 .735 r
.60273 .72932 m .60433 .72841 L .60158 .72677 L F
.392 .478 .828 r
.2937 .61102 m .29387 .60817 L .29222 .60862 L F
.2937 .61102 m .29509 .61055 L .29387 .60817 L F
.361 .369 .733 r
.2937 .61102 m .29584 .61289 L .29509 .61055 L F
.462 .377 .674 r
.29404 .61311 m .29584 .61289 L .2937 .61102 L F
.482 .074 .188 r
.348 .729 m .3467 .73078 L .34444 .73097 L F
.555 .896 .981 r
.3487 .72792 m .348 .729 L .34963 .72822 L F
.546 .398 .632 r
.3487 .72792 m .3467 .73078 L .348 .729 L F
.486 .272 .513 r
.41301 .68813 m .41305 .69046 L .41208 .69017 L F
.505 .287 .516 r
.41535 .68995 m .41301 .68813 L .4157 .68823 L F
.41535 .68995 m .41305 .69046 L .41301 .68813 L F
.504 .367 .627 r
.43319 .73998 m .43537 .74206 L .43581 .73982 L F
.43319 .73998 m .43343 .74256 L .43537 .74206 L F
.446 .087 .261 r
.46013 .73629 m .46293 .73452 L .46074 .73478 L F
.291 .733 .964 r
.29337 .59619 m .28998 .59569 L .29206 .59545 L F
.202 .701 .913 r
.29206 .59545 m .29547 .59586 L .29337 .59619 L F
.674 .536 .689 r
.68438 .59206 m .68679 .59182 L .68691 .5896 L F
.724 .542 .644 r
.68438 .59206 m .68666 .5942 L .68679 .59182 L F
.68438 .59206 m .68455 .59499 L .68666 .5942 L F
.568 .299 .468 r
.4874 .74396 m .48329 .74471 L .48564 .74266 L F
.511 .821 1 r
.28492 .59367 m .2844 .5949 L .28286 .59398 L F
.28492 .59367 m .28637 .59443 L .2844 .5949 L F
.456 .241 .498 r
.31347 .62449 m .31574 .62172 L .31506 .62355 L F
.431 .226 .499 r
.31281 .62731 m .31347 .62449 L .31506 .62355 L F
.526 .332 .561 r
.57222 .68239 m .57222 .68531 L .57457 .68449 L F
.986 .718 .35 r
.58986 .73959 m .59005 .74235 L .59073 .74204 L F
.749 .699 .804 r
.59073 .74204 m .59334 .74016 L .58986 .73959 L F
.295 .417 .816 r
.59073 .74204 m .59125 .74012 L .58986 .73959 L F
.871 .963 .63 r
.59005 .74235 m .59125 .74012 L .59073 .74204 L F
.885 .682 .624 r
.74308 .62228 m .741 .62372 L .74262 .62008 L F
.74308 .62228 m .74254 .6246 L .741 .62372 L F
.242 .751 .873 r
.27769 .60372 m .27816 .60325 L .27593 .60368 L F
.27769 .60372 m .27949 .60348 L .27816 .60325 L F
.385 0 0 r
.40342 .66866 m .40209 .66863 L .40017 .668 L F
.089 .646 .709 r
.40554 .66822 m .40209 .66863 L .40342 .66866 L F
.671 .409 .517 r
.59326 .66252 m .59563 .66282 L .59573 .66058 L F
.443 .756 .995 r
.45799 .77651 m .45571 .77676 L .45413 .77561 L F
.883 .867 .818 r
.5619 .75365 m .55975 .75654 L .55847 .75558 L F
.586 .012 0 r
.73734 .59446 m .73813 .59503 L .7353 .59379 L F
.556 .421 .653 r
.3169 .70464 m .31908 .70424 L .31861 .70127 L F
.55 .508 .762 r
.3169 .70464 m .31957 .70681 L .31908 .70424 L F
0 0 0 r
.3409 .73076 m .3387 .73354 L .33962 .73151 L F
.589 .814 .419 r
.74542 .72676 m .74429 .72833 L .74432 .72831 L F
0 0 .315 r
.74654 .7227 m .74646 .72542 L .74542 .72676 L F
0 0 0 r
.74646 .72542 m .74429 .72833 L .74542 .72676 L F
.477 .683 .956 r
.2889 .60692 m .29016 .60837 L .29082 .60675 L F
.43 .629 .937 r
.29016 .60837 m .29222 .60862 L .29082 .60675 L F
.955 .689 .49 r
.5595 .75761 m .55847 .75558 L .55975 .75654 L F
.59 .219 .307 r
.55975 .75654 m .56185 .75791 L .5595 .75761 L F
0 .122 .664 r
.72993 .62735 m .73009 .62677 L .7277 .62437 L F
0 .304 .781 r
.72993 .62735 m .73145 .62827 L .73009 .62677 L F
.231 0 0 r
.36148 .64935 m .36357 .6492 L .36497 .64859 L F
.549 .05 .023 r
.36497 .64859 m .36357 .6492 L .36703 .64915 L F
.342 .149 .468 r
.32504 .61101 m .32685 .60833 L .327 .61035 L F
.465 .231 .473 r
.327 .61035 m .32459 .61313 L .32504 .61101 L F
.401 .171 .446 r
.31506 .62355 m .31574 .62172 L .31756 .62057 L F
.575 .757 .964 r
.41757 .65572 m .41433 .65505 L .41638 .65474 L F
.322 .635 .963 r
.41863 .65492 m .41757 .65572 L .41638 .65474 L F
.41863 .65492 m .42051 .65653 L .41757 .65572 L F
.487 .214 .425 r
.40033 .70195 m .39843 .70399 L .39892 .70147 L F
.722 .607 .728 r
.68901 .58902 m .69247 .58932 L .69124 .58602 L F
.714 .554 .67 r
.68916 .59135 m .69247 .58932 L .68901 .58902 L F
.68916 .59135 m .69244 .59178 L .69247 .58932 L F
.724 .615 .735 r
.69247 .58932 m .69391 .5861 L .69124 .58602 L F
0 .383 .807 r
.73198 .6242 m .73155 .62447 L .73098 .62358 L F
.73198 .6242 m .73294 .62503 L .73155 .62447 L F
.554 .363 .576 r
.55668 .69041 m .55447 .69368 L .55702 .69322 L F
0 0 .032 r
.55638 .6921 m .55447 .69368 L .55668 .69041 L F
.55638 .6921 m .55668 .69041 L .5554 .68965 L F
.469 .542 .849 r
.55668 .69041 m .55823 .6876 L .5554 .68965 L F
.55668 .69041 m .55932 .69099 L .55823 .6876 L F
.423 .27 .567 r
.55668 .69041 m .55929 .69188 L .55932 .69099 L F
.55668 .69041 m .55702 .69322 L .55929 .69188 L F
.956 .782 .627 r
.60697 .70727 m .60504 .70872 L .60561 .70642 L F
.60697 .70727 m .60637 .70951 L .60504 .70872 L F
.205 0 0 r
.38211 .71366 m .38153 .71254 L .38373 .71234 L F
.38211 .71366 m .38008 .71428 L .38153 .71254 L F
.742 .296 0 r
.57361 .71122 m .573 .70964 L .57147 .70908 L F
.188 .415 .85 r
.57266 .71012 m .57361 .71122 L .57261 .71012 L F
.742 .296 0 r
.57361 .71122 m .57452 .71227 L .573 .70964 L F
.853 .396 .068 r
.573 .70964 m .57463 .71247 L .57589 .71295 L F
.188 .415 .85 r
.57491 .71038 m .57361 .71122 L .57266 .71012 L F
.742 .296 0 r
.57361 .71122 m .57463 .71247 L .57452 .71227 L F
.996 .793 .511 r
.33314 .80828 m .3331 .81072 L .33381 .80822 L F
.33314 .80828 m .3331 .81072 L .33381 .80822 L F
.683 .468 .589 r
.4776 .75054 m .47715 .74822 L .47724 .75028 L F
.4776 .75054 m .47576 .75061 L .47715 .74822 L F
.752 .234 0 r
.51117 .79218 m .5117 .79362 L .50936 .79215 L F
.51117 .79218 m .51262 .79375 L .5117 .79362 L F
.824 .612 .616 r
.61615 .67388 m .61608 .67629 L .6193 .67683 L F
.824 .605 .606 r
.61604 .67871 m .6193 .67683 L .61608 .67629 L F
.61604 .67871 m .61931 .67923 L .6193 .67683 L F
.189 .72 .82 r
.45758 .78583 m .45659 .78579 L .45438 .78606 L F
.257 0 0 r
.46033 .78579 m .45659 .78579 L .45758 .78583 L F
.505 .41 .681 r
.32108 .68544 m .32344 .68727 L .323 .6853 L F
.32108 .68544 m .32155 .68771 L .32344 .68727 L F
.422 .197 .466 r
.31756 .62057 m .31795 .61893 L .31963 .61813 L F
.631 .552 .747 r
.32522 .7203 m .32768 .72253 L .32981 .7218 L F
.32768 .72253 m .32846 .72323 L .32923 .72241 L F
.32768 .72253 m .32923 .72241 L .32981 .7218 L F
.567 .121 .152 r
.33301 .7216 m .32924 .72187 L .33152 .72223 L F
.33239 .72216 m .33152 .72223 L .33219 .72234 L F
.33301 .7216 m .33152 .72223 L .33239 .72216 L F
.702 .943 .65 r
.32981 .7218 m .32846 .72323 L .32924 .72187 L F
.654 .94 .964 r
.32924 .72187 m .32846 .72323 L .33219 .72234 L F
.151 .317 .778 r
.33221 .72331 m .33301 .7216 L .33219 .72234 L F
0 0 0 r
.54737 .68778 m .54923 .68694 L .55029 .68609 L F
.423 .108 .325 r
.54737 .68778 m .54868 .68906 L .54923 .68694 L F
.54737 .68778 m .54717 .68954 L .54868 .68906 L F
.658 .575 .75 r
.40455 .67652 m .4066 .67379 L .40456 .67413 L F
.985 .896 .64 r
.60682 .70113 m .60591 .7004 L .60747 .6989 L F
.979 .7 .315 r
.60747 .6989 m .60667 .69818 L .60644 .69565 L F
.987 .882 .633 r
.60591 .7004 m .60667 .69818 L .60747 .6989 L F
.577 .349 .534 r
.45627 .75369 m .45614 .75594 L .45381 .75606 L F
.699 .452 .547 r
.45627 .75369 m .45852 .75636 L .45614 .75594 L F
.777 .443 .422 r
.45974 .75587 m .45852 .75636 L .45627 .75369 L F
.667 .686 .858 r
.30959 .71218 m .31081 .71263 L .31121 .71203 L F
.459 .37 .668 r
.31017 .71318 m .31096 .7124 L .31121 .71203 L F
.31096 .7124 m .3133 .71009 L .31121 .71203 L F
.667 .686 .858 r
.31081 .71263 m .31328 .71356 L .31163 .71234 L F
.565 .043 0 r
.31328 .71356 m .31017 .71318 L .31163 .71234 L F
.667 .686 .858 r
.31081 .71263 m .31163 .71234 L .31096 .7124 L F
.459 .37 .668 r
.31017 .71318 m .31392 .71213 L .31096 .7124 L F
.31096 .7124 m .31163 .71234 L .3133 .71009 L F
.667 .686 .858 r
.31096 .7124 m .31163 .71234 L .31121 .71203 L F
.565 .043 0 r
.31163 .71234 m .31017 .71318 L .31121 .71203 L F
.459 .37 .668 r
.31163 .71234 m .31392 .71213 L .31363 .71118 L F
.31163 .71234 m .31363 .71118 L .3133 .71009 L F
.31017 .71318 m .3146 .71436 L .31392 .71213 L F
.496 .6 .886 r
.2934 .73414 m .29045 .73234 L .29188 .73413 L F
.556 .06 .033 r
.49938 .78576 m .49742 .78475 L .49587 .78582 L F
.528 .345 .577 r
.43251 .67125 m .43242 .67358 L .43025 .67407 L F
.463 .234 .48 r
.43242 .67358 m .43012 .67625 L .43025 .67407 L F
0 0 .276 r
.61919 .71738 m .61881 .7196 L .61736 .72075 L F
0 0 .386 r
.61881 .7196 m .61731 .72314 L .61736 .72075 L F
.824 .589 .583 r
.70527 .58929 m .70243 .58606 L .70264 .58844 L F
.778 .664 .737 r
.70264 .58844 m .70379 .59149 L .70527 .58929 L F
.414 .021 .182 r
.33416 .66173 m .33289 .66054 L .33278 .66247 L F
.33416 .66173 m .33534 .65976 L .33289 .66054 L F
.064 .607 .846 r
.2976 .59563 m .30112 .59625 L .29915 .59628 L F
.411 .421 .76 r
.47257 .77548 m .475 .77756 L .47309 .77713 L F
.238 .541 .925 r
.475 .77756 m .47575 .77868 L .47309 .77713 L F
.583 .117 .114 r
.71476 .57839 m .7172 .57947 L .71804 .57815 L F
.395 0 .014 r
.7172 .57947 m .7201 .57839 L .71804 .57815 L F
.695 .664 .816 r
.64163 .51899 m .63867 .51713 L .64069 .51692 L F
.286 .53 .91 r
.64337 .51806 m .64163 .51899 L .64069 .51692 L F
.755 .994 .823 r
.31949 .72527 m .31916 .72645 L .32074 .72496 L F
.679 .431 .539 r
.29497 .72892 m .29795 .72672 L .2961 .7273 L F
.458 .806 .998 r
.46319 .77778 m .46449 .77849 L .46103 .7781 L F
.207 .717 .893 r
.4651 .77809 m .46449 .77849 L .46319 .77778 L F
.4651 .77809 m .46684 .77841 L .46449 .77849 L F
0 0 .038 r
.2977 .64632 m .30028 .6434 L .29987 .64613 L F
.287 0 .215 r
.2977 .64632 m .29899 .64775 L .2973 .64867 L F
.2977 .64632 m .29987 .64613 L .29899 .64775 L F
.539 .377 .61 r
.42674 .75088 m .4289 .74802 L .42663 .74847 L F
.478 .436 .732 r
.29475 .6165 m .29584 .61289 L .29404 .61311 L F
.29475 .6165 m .29658 .61617 L .29584 .61289 L F
.518 .425 .689 r
.29475 .6165 m .29715 .61872 L .29658 .61617 L F
.29475 .6165 m .29521 .61924 L .29715 .61872 L F
.528 .372 .613 r
.41 .66248 m .40811 .66586 L .40783 .66304 L F
.40811 .66586 m .41 .66248 L .40783 .66304 L F
.426 .081 .276 r
.39179 .70737 m .3912 .70879 L .38913 .70912 L F
.31 0 .221 r
.39318 .70812 m .39179 .70737 L .39359 .70646 L F
.39318 .70812 m .3912 .70879 L .39179 .70737 L F
.609 .609 .825 r
.463 .76394 m .46208 .7674 L .46175 .76778 L F
.463 .76394 m .46438 .76701 L .46208 .7674 L F
.341 0 .02 r
.46208 .7674 m .4629 .76875 L .46175 .76778 L F
.46208 .7674 m .46438 .76701 L .4629 .76875 L F
.311 0 .039 r
.48628 .72821 m .48967 .72609 L .4874 .72629 L F
.706 .611 .749 r
.29945 .71784 m .30318 .72026 L .30384 .71866 L F
.84 .397 0 r
.30513 .7201 m .30384 .71866 L .30318 .72026 L F
.501 .287 .52 r
.39381 .69055 m .39588 .69022 L .39612 .68787 L F
.513 .309 .541 r
.39588 .69022 m .39816 .68737 L .39612 .68787 L F
.683 .544 .69 r
.68679 .59182 m .68901 .58902 L .68691 .5896 L F
.551 .57 .826 r
.42582 .65904 m .42453 .66159 L .42382 .6595 L F
.42582 .65904 m .42715 .66197 L .42453 .66159 L F
.373 .06 .299 r
.39167 .6935 m .391 .69516 L .39367 .69294 L F
.806 .404 .289 r
.55848 .73713 m .55536 .73807 L .55605 .73717 L F
.006 0 .009 r
.30028 .6434 m .30276 .64094 L .30217 .64252 L F
.344 .081 .364 r
.30168 .64541 m .30028 .6434 L .30217 .64252 L F
.30168 .64541 m .29987 .64613 L .30028 .6434 L F
.831 .626 .625 r
.60474 .66487 m .60788 .6631 L .60541 .66184 L F
.60474 .66487 m .60778 .6658 L .60788 .6631 L F
.558 .847 .998 r
.72508 .59725 m .72757 .59665 L .72643 .59588 L F
.72508 .59725 m .72757 .59665 L .72643 .59588 L F
.275 0 .046 r
.35825 .72391 m .35502 .72616 L .35572 .72521 L F
.35825 .72391 m .35688 .72576 L .35502 .72616 L F
.209 0 .006 r
.359 .72512 m .35825 .72391 L .36033 .72341 L F
.359 .72512 m .35688 .72576 L .35825 .72391 L F
.948 .774 .315 r
.7212 .72348 m .7209 .72605 L .72064 .72457 L F
.616 .237 .301 r
.72064 .72457 m .72356 .72305 L .7212 .72348 L F
.547 .89 .649 r
.54358 .69386 m .54455 .69287 L .54579 .69158 L F
.54358 .69386 m .54199 .69494 L .54455 .69287 L F
.553 .531 .785 r
.59099 .736 m .58986 .73959 L .58983 .7372 L F
.057 .525 .893 r
.72289 .72817 m .7237 .72789 L .7209 .72605 L F
.72289 .72817 m .72469 .7287 L .7237 .72789 L F
.366 0 0 r
.64419 .51976 m .64673 .5196 L .64757 .51854 L F
.649 .17 .102 r
.64673 .5196 m .64955 .52003 L .64757 .51854 L F
.568 0 0 r
.64757 .51854 m .64955 .52003 L .65054 .52031 L F
.977 .735 .503 r
.54061 .74804 m .54105 .74914 L .542 .74755 L F
.191 .065 .468 r
.54105 .74914 m .5446 .74456 L .542 .74755 L F
.54105 .74914 m .54394 .74945 L .5446 .74456 L F
0 0 0 r
.62138 .71081 m .62121 .70989 L .6223 .70856 L F
.62138 .71081 m .62053 .71202 L .62121 .70989 L F
.818 .66 .687 r
.63631 .51999 m .63811 .52361 L .63473 .52276 L F
.829 .668 .683 r
.63707 .52493 m .63473 .52276 L .63811 .52361 L F
.363 .183 .499 r
.39381 .69055 m .39536 .6922 L .39588 .69022 L F
.39381 .69055 m .39367 .69294 L .39536 .6922 L F
.375 .09 .348 r
.3672 .67391 m .36674 .67625 L .3647 .67637 L F
.252 0 .306 r
.36833 .67548 m .3672 .67391 L .36921 .67323 L F
.36833 .67548 m .36674 .67625 L .3672 .67391 L F
.439 .193 .442 r
.74435 .60868 m .7445 .61031 L .74692 .60904 L F
.491 .238 .459 r
.63926 .536 m .6392 .5332 L .64109 .53193 L F
.481 .731 .981 r
.50522 .71777 m .50873 .71879 L .50799 .71773 L F
.621 .313 .427 r
.51203 .7199 m .50873 .71879 L .51026 .71852 L F
.51203 .7199 m .50689 .72059 L .50873 .71879 L F
.113 .293 .768 r
.51846 .7011 m .52065 .70305 L .5197 .70402 L F
.208 .449 .871 r
.52065 .70305 m .52154 .70466 L .5197 .70402 L F
.602 .08 0 r
.32209 .71677 m .32077 .71664 L .32204 .71524 L F
.613 .49 .689 r
.42116 .76467 m .4229 .76139 L .42072 .76186 L F
.636 .446 .609 r
.65211 .52305 m .65221 .52551 L .64901 .52573 L F
.639 .448 .609 r
.65446 .52526 m .65211 .52305 L .65462 .52296 L F
.65446 .52526 m .65221 .52551 L .65211 .52305 L F
.432 .493 .822 r
.42221 .65644 m .4209 .65816 L .42051 .65653 L F
.491 .577 .869 r
.42221 .65644 m .42382 .6595 L .4209 .65816 L F
.318 .09 .401 r
.287 .62994 m .28775 .6318 L .2883 .62984 L F
.287 .62994 m .28619 .63278 L .28775 .6318 L F
.36 0 .091 r
.57206 .67329 m .57431 .67291 L .57535 .67116 L F
.456 .094 .261 r
.57431 .67291 m .57742 .6704 L .57535 .67116 L F
.32 0 .083 r
.37745 .66848 m .37612 .67044 L .37404 .6709 L F
.448 .1 .282 r
.3802 .66785 m .37612 .67044 L .37745 .66848 L F
.325 0 .069 r
.31135 .71954 m .31256 .71969 L .31389 .7179 L F
.467 .047 .157 r
.31389 .7179 m .31256 .71969 L .31553 .71913 L F
.65 .647 .834 r
.31256 .71969 m .3138 .7226 L .31643 .72149 L F
.31256 .71969 m .31643 .72149 L .31553 .71913 L F
0 .007 .55 r
.31224 .71863 m .3133 .72083 L .31313 .72091 L F
.899 .911 .823 r
.31256 .71969 m .31182 .72296 L .3138 .7226 L F
.31256 .71969 m .31053 .72247 L .31182 .72296 L F
0 .007 .55 r
.31212 .72013 m .31313 .72091 L .31201 .72139 L F
.325 0 .069 r
.31175 .71984 m .31256 .71969 L .31135 .71954 L F
.3105 .72009 m .31175 .71984 L .31135 .71954 L F
.569 .531 .772 r
.31179 .71675 m .31256 .71969 L .3105 .72009 L F
.863 .829 .812 r
.31201 .72139 m .31053 .72247 L .31256 .71969 L F
0 .007 .55 r
.31224 .71863 m .31201 .72139 L .31256 .71969 L F
.31224 .71863 m .31313 .72091 L .31212 .72013 L F
.467 .047 .157 r
.31389 .7179 m .31553 .71913 L .31526 .71707 L F
.53 .355 .588 r
.42486 .75611 m .42698 .75333 L .42473 .75367 L F
.555 .923 .766 r
.56824 .76838 m .56554 .77012 L .5666 .76906 L F
.158 .306 .765 r
.56554 .77012 m .56778 .77215 L .5666 .76906 L F
.467 .248 .497 r
.35728 .68156 m .35466 .68501 L .35506 .6822 L F
.901 .679 .594 r
.60419 .68696 m .60648 .68752 L .60583 .69006 L F
.369 .16 .46 r
.30276 .64094 m .30481 .63812 L .30437 .64006 L F
.251 0 .294 r
.30217 .64252 m .30276 .64094 L .30437 .64006 L F
.155 .072 .502 r
.61731 .72314 m .61749 .72551 L .61631 .72685 L F
.097 0 .44 r
.61749 .72551 m .61596 .72877 L .61631 .72685 L F
.592 .089 .027 r
.46383 .7859 m .46217 .7863 L .46033 .78579 L F
.487 0 0 r
.46563 .78631 m .46217 .7863 L .46383 .7859 L F
.137 .504 .909 r
.65355 .52157 m .65542 .52283 L .65462 .52296 L F
.587 .358 .536 r
.65709 .52482 m .65462 .52296 L .65542 .52283 L F
.65709 .52482 m .65446 .52526 L .65462 .52296 L F
.732 .642 .758 r
.70063 .59126 m .70379 .59149 L .70264 .58844 L F
.806 .404 .289 r
.55848 .73713 m .55843 .73944 L .55536 .73807 L F
.614 .049 0 r
.64955 .52003 m .64999 .52053 L .65054 .52031 L F
.714 .89 .961 r
.71643 .5978 m .71929 .59761 L .71834 .59715 L F
0 .29 .738 r
.71929 .59761 m .72089 .59826 L .71834 .59715 L F
.71929 .59761 m .72188 .59915 L .72089 .59826 L F
.834 .362 .015 r
.54381 .69936 m .54341 .70009 L .54254 .69857 L F
.794 .298 0 r
.54381 .69936 m .54533 .70103 L .54341 .70009 L F
.423 0 0 r
.58986 .73959 m .59125 .74012 L .59334 .74016 L F
.686 .943 .962 r
.59334 .74016 m .59427 .7386 L .59531 .73931 L F
.553 .531 .785 r
.59099 .736 m .59259 .73954 L .58986 .73959 L F
.686 .943 .962 r
.59334 .74016 m .59178 .74013 L .59219 .73988 L F
.59375 .73947 m .59219 .73988 L .59427 .7386 L F
.59334 .74016 m .59219 .73988 L .59375 .73947 L F
.515 .057 .104 r
.59209 .7399 m .59125 .74012 L .58986 .73959 L F
.59279 .74 m .59125 .74012 L .59209 .7399 L F
.553 .531 .785 r
.59259 .73954 m .59279 .74 L .59209 .7399 L F
.59259 .73954 m .59209 .7399 L .58986 .73959 L F
.686 .943 .962 r
.59178 .74013 m .59302 .73923 L .59427 .7386 L F
.639 .576 .767 r
.59427 .7386 m .59279 .74 L .59259 .73954 L F
.59427 .7386 m .59259 .73954 L .59099 .736 L F
.686 .943 .962 r
.59259 .73954 m .59125 .74012 L .59302 .73923 L F
.59178 .74013 m .59154 .74012 L .59259 .73954 L F
.59154 .74012 m .59125 .74012 L .59259 .73954 L F
.747 .761 .864 r
.35361 .86637 m .35552 .8689 L .35209 .869 L F
.569 .087 .07 r
.35209 .869 m .35552 .8689 L .35387 .87026 L F
.262 .529 .915 r
.35654 .86811 m .35552 .8689 L .35361 .86637 L F
0 0 0 r
.35387 .87026 m .35552 .8689 L .35654 .86811 L F
.602 .131 .108 r
.51065 .70577 m .51289 .70631 L .5145 .70521 L F
0 .512 .744 r
.54011 .72113 m .5428 .72154 L .54287 .72161 L F
0 .289 .714 r
.5444 .72226 m .54287 .72161 L .5428 .72154 L F
.5444 .72226 m .54538 .72298 L .54287 .72161 L F
.196 .428 .858 r
.54287 .72161 m .54538 .72298 L .54418 .72289 L F
.685 .547 .691 r
.68679 .59182 m .68916 .59135 L .68901 .58902 L F
.739 .636 .746 r
.68666 .5942 m .68916 .59135 L .68679 .59182 L F
.153 .677 .877 r
.4376 .78657 m .43617 .78621 L .43415 .78622 L F
.398 .81 .978 r
.4397 .78641 m .43617 .78621 L .4376 .78657 L F
.662 .411 .531 r
.71837 .59389 m .72051 .59417 L .72044 .59184 L F
.755 .829 .909 r
.71905 .59011 m .72044 .59184 L .72302 .58934 L F
.653 .63 .814 r
.72044 .59184 m .72422 .5921 L .72302 .58934 L F
.805 .725 .777 r
.72051 .59417 m .72422 .5921 L .72044 .59184 L F
.433 0 0 r
.74219 .71571 m .74477 .7176 L .74525 .71793 L F
.944 .639 .191 r
.74477 .7176 m .74575 .72049 L .74525 .71793 L F
.232 0 .307 r
.60273 .72932 m .60212 .73119 L .60433 .72841 L F
.334 0 .136 r
.58516 .66729 m .58797 .6657 L .58562 .666 L F
.987 .762 .512 r
.5286 .73064 m .52903 .73442 L .52808 .73207 L F
.367 .054 .296 r
.5286 .73064 m .52808 .73207 L .53013 .73137 L F
.155 0 .33 r
.69557 .58307 m .69391 .5861 L .69586 .58548 L F
.626 .552 .752 r
.69557 .58307 m .69952 .58347 L .69796 .5802 L F
.687 .541 .682 r
.69586 .58548 m .69952 .58347 L .69557 .58307 L F
.612 .616 .83 r
.73239 .72302 m .7339 .71972 L .73125 .72208 L F
.73239 .72302 m .73503 .72254 L .7339 .71972 L F
.679 .24 .201 r
.73125 .72208 m .73503 .72254 L .73239 .72302 L F
.537 .32 .532 r
.43479 .67098 m .43242 .67358 L .43251 .67125 L F
.883 .955 .609 r
.54579 .69158 m .54455 .69287 L .54588 .69124 L F
.204 .287 .728 r
.44939 .76932 m .44837 .77062 L .44733 .7672 L F
.474 .68 .955 r
.44939 .76932 m .45055 .77064 L .44837 .77062 L F
.407 .739 .992 r
.47326 .77445 m .47257 .77548 L .47117 .77451 L F
.12 .352 .816 r
.47326 .77445 m .475 .77756 L .47257 .77548 L F
.416 .624 .938 r
.73116 .7301 m .73171 .73141 L .73297 .73018 L F
.346 .507 .875 r
.73171 .73141 m .73366 .73172 L .73297 .73018 L F
.484 .216 .432 r
.64192 .53108 m .64573 .53137 L .64109 .53193 L F
.64192 .53108 m .64413 .5305 L .64573 .53137 L F
.361 0 .008 r
.27122 .64491 m .273 .64502 L .27465 .64337 L F
0 0 0 r
.27465 .64337 m .27576 .6432 L .27735 .64192 L F
.27465 .64337 m .273 .64502 L .27576 .6432 L F
.607 .588 .805 r
.42483 .78129 m .42862 .78451 L .42694 .78107 L F
.526 .566 .839 r
.42694 .78107 m .42862 .78451 L .43059 .78402 L F
.56 .405 .628 r
.32004 .69364 m .32238 .6955 L .3218 .69254 L F
.32004 .69364 m .32019 .69595 L .32238 .6955 L F
.262 .502 .897 r
.27575 .59159 m .2757 .59327 L .2738 .59165 L F
.27575 .59159 m .27729 .59372 L .2757 .59327 L F
.753 .629 .723 r
.68455 .59499 m .68454 .59686 L .68666 .5942 L F
.704 .556 .683 r
.68454 .59686 m .68835 .59758 L .68666 .5942 L F
.986 .712 .353 r
.72445 .71542 m .72492 .7183 L .72562 .71809 L F
.815 .755 .797 r
.72445 .71542 m .72562 .71809 L .72783 .71514 L F
.393 .835 .941 r
.72492 .7183 m .72805 .7181 L .72562 .71809 L F
.574 .407 .618 r
.72562 .71809 m .72805 .7181 L .72783 .71514 L F
.573 .766 .97 r
.55702 .69322 m .55447 .69368 L .55638 .6921 L F
.445 .186 .427 r
.32023 .61622 m .32187 .6183 L .31963 .61813 L F
.32023 .61622 m .32259 .61542 L .32187 .6183 L F
.414 .813 .983 r
.31344 .59816 m .31022 .59799 L .31207 .59748 L F
.265 .685 .967 r
.31426 .59751 m .31344 .59816 L .31207 .59748 L F
.31426 .59751 m .31585 .59843 L .31344 .59816 L F
.25 0 0 r
.38596 .64828 m .38944 .64876 L .3875 .64834 L F
.486 .279 .524 r
.3227 .67949 m .32469 .67906 L .32496 .67677 L F
.499 .404 .679 r
.3227 .67949 m .32492 .68159 L .32469 .67906 L F
.3227 .67949 m .32318 .68203 L .32492 .68159 L F
.228 .056 .429 r
.7507 .61281 m .74822 .61602 L .74836 .61272 L F
.525 .584 .857 r
.32762 .60246 m .32652 .6048 L .3256 .60308 L F
.32762 .60246 m .32855 .60444 L .32652 .6048 L F
.465 .389 .686 r
.32881 .60747 m .32652 .6048 L .32855 .60444 L F
.32881 .60747 m .32685 .60833 L .32652 .6048 L F
.812 .797 .838 r
.72422 .5921 m .72693 .59049 L .72513 .58853 L F
.803 .796 .846 r
.72513 .58853 m .72693 .59049 L .72826 .58824 L F
.463 .187 .408 r
.42792 .67667 m .42717 .67923 L .42519 .67961 L F
.523 .243 .431 r
.42943 .67885 m .42792 .67667 L .43012 .67625 L F
.42943 .67885 m .42717 .67923 L .42792 .67667 L F
.106 0 0 r
.28288 .6542 m .28302 .65492 L .27955 .65538 L F
.447 0 0 r
.2849 .65388 m .28302 .65492 L .28288 .6542 L F
.902 .958 .822 r
.60372 .70337 m .60682 .70113 L .60516 .70395 L F
.60372 .70337 m .60591 .7004 L .60682 .70113 L F
.793 .664 .721 r
.69915 .58568 m .70243 .58606 L .70124 .58289 L F
.753 .553 .626 r
.69951 .58801 m .70243 .58606 L .69915 .58568 L F
.69951 .58801 m .70264 .58844 L .70243 .58606 L F
.438 .002 .112 r
.74692 .60904 m .74908 .6091 L .75039 .60707 L F
.519 .264 .468 r
.75039 .60707 m .75246 .60751 L .75272 .60557 L F
.333 0 .055 r
.75039 .60707 m .75103 .6085 L .75246 .60751 L F
.75039 .60707 m .74908 .6091 L .75103 .6085 L F
.58 .767 .968 r
.41093 .65461 m .40885 .65512 L .40762 .65388 L F
.269 0 0 r
.46899 .78622 m .46778 .78649 L .46563 .78631 L F
.285 0 0 r
.46899 .78622 m .47028 .78695 L .46778 .78649 L F
.46899 .78622 m .47126 .78609 L .47028 .78695 L F
.55 .572 .829 r
.45385 .77204 m .45208 .77385 L .45055 .77064 L F
.401 .341 .675 r
.45385 .77204 m .45413 .77561 L .45208 .77385 L F
.83 .594 .582 r
.61936 .68147 m .62094 .67984 L .61931 .67923 L F
.61936 .68147 m .62114 .68222 L .62094 .67984 L F
.554 .392 .615 r
.4229 .76139 m .42511 .75864 L .42304 .75916 L F
.563 .85 .997 r
.51504 .78849 m .51182 .7884 L .51396 .78826 L F
.569 .091 .08 r
.51396 .78826 m .51737 .78816 L .51504 .78849 L F
0 0 0 r
.26642 .60501 m .26288 .60562 L .26331 .60524 L F
.26642 .60501 m .26531 .60529 L .26288 .60562 L F
.372 .817 .949 r
.26841 .60464 m .26714 .60439 L .26642 .60501 L F
.451 .88 .802 r
.26714 .60439 m .26531 .60529 L .26642 .60501 L F
.796 .606 .645 r
.5655 .69315 m .56397 .69811 L .56262 .69257 L F
.872 .925 .858 r
.5645 .69214 m .5655 .69315 L .56782 .6903 L F
.681 .136 0 r
.5645 .69214 m .56815 .69435 L .5655 .69315 L F
.654 .769 .934 r
.72462 .7125 m .72145 .71198 L .72393 .71248 L F
.655 .969 .827 r
.72462 .7125 m .72393 .71248 L .72559 .7112 L F
.71 .71 .848 r
.32779 .71753 m .33107 .71796 L .32945 .71466 L F
.617 .524 .727 r
.32779 .71753 m .33117 .72004 L .33107 .71796 L F
.564 .636 .881 r
.32945 .71466 m .33107 .71796 L .33304 .71746 L F
.787 .681 .747 r
.33117 .72004 m .33304 .71746 L .33107 .71796 L F
.288 0 0 r
.52363 .75299 m .52583 .7526 L .5274 .75108 L F
.123 .091 .546 r
.5274 .75108 m .52852 .75073 L .52831 .74729 L F
0 0 0 r
.56512 .68539 m .56332 .6878 L .56675 .68536 L F
.56512 .68539 m .56373 .68728 L .56332 .6878 L F
.097 0 .44 r
.61749 .72551 m .61736 .728 L .61596 .72877 L F
.136 .094 .542 r
.61736 .728 m .6162 .73154 L .61596 .72877 L F
.197 .706 .897 r
.72796 .72899 m .72695 .72867 L .72469 .7287 L F
.196 .558 .934 r
.72796 .72899 m .72938 .7285 L .72695 .72867 L F
.72796 .72899 m .73116 .7301 L .72938 .7285 L F
.582 .372 .561 r
.64901 .52573 m .64924 .52848 L .64676 .52877 L F
.634 .411 .561 r
.65212 .5273 m .64901 .52573 L .65221 .52551 L F
.65212 .5273 m .64924 .52848 L .64901 .52573 L F
.952 .644 .413 r
.59975 .6762 m .59804 .67337 L .59968 .67405 L F
0 0 0 r
.57977 .67689 m .57658 .67902 L .57831 .67786 L F
.364 .1 .373 r
.57831 .67786 m .5811 .67778 L .57977 .67689 L F
.32 .325 .709 r
.52903 .73442 m .53013 .73137 L .52808 .73207 L F
.52903 .73442 m .53058 .73403 L .53013 .73137 L F
.627 .087 0 r
.5325 .73735 m .53171 .73702 L .52903 .73442 L F
.323 .337 .72 r
.52903 .73442 m .53171 .73702 L .53058 .73403 L F
.439 .229 .497 r
.29504 .62116 m .29715 .61872 L .29521 .61924 L F
.523 .306 .527 r
.58836 .71898 m .59071 .71993 L .59048 .71908 L F
.551 .22 .362 r
.55298 .75827 m .55105 .75678 L .55335 .75645 L F
.55298 .75827 m .55065 .75855 L .55105 .75678 L F
.484 .277 .523 r
.32496 .67677 m .32669 .67858 L .32669 .67618 L F
.32496 .67677 m .32469 .67906 L .32669 .67858 L F
.391 0 0 r
.50706 .78804 m .50868 .78777 L .506 .78715 L F
.418 0 .036 r
.37472 .64802 m .37685 .64807 L .37834 .64654 L F
.272 .777 .847 r
.37685 .64807 m .38048 .64762 L .37834 .64654 L F
.402 .569 .904 r
.5325 .73735 m .53359 .73597 L .53171 .73702 L F
.571 .438 .661 r
.31861 .70127 m .32099 .70098 L .32065 .69839 L F
.601 .452 .652 r
.31861 .70127 m .32138 .7039 L .32099 .70098 L F
.31861 .70127 m .31908 .70424 L .32138 .7039 L F
.759 .608 .69 r
.67906 .59702 m .68228 .59967 L .68272 .59768 L F
.67906 .59702 m .68088 .60045 L .68228 .59967 L F
.77 .635 .711 r
.68088 .60045 m .68026 .60246 L .68228 .59967 L F
.744 .642 .746 r
.68272 .59768 m .68228 .59967 L .68454 .59686 L F
.539 .328 .542 r
.5381 .73704 m .54032 .73669 L .54029 .7344 L F
.5381 .73704 m .54032 .73669 L .54029 .7344 L F
.619 .556 .761 r
.54173 .73253 m .54032 .73669 L .54029 .7344 L F
.649 .96 .776 r
.539 .74388 m .538 .74433 L .53732 .74541 L F
.983 .788 .563 r
.536 .74513 m .53732 .74541 L .538 .74433 L F
.536 .74513 m .53687 .74784 L .53732 .74541 L F
.443 .344 .648 r
.44903 .76659 m .44713 .76477 L .4492 .76396 L F
.44903 .76659 m .44733 .7672 L .44713 .76477 L F
.416 0 .139 r
.5666 .76906 m .56998 .76697 L .56824 .76838 L F
.611 .581 .795 r
.50555 .74723 m .50187 .74501 L .5048 .74584 L F
.476 .174 .374 r
.35981 .67974 m .35932 .68129 L .35728 .68156 L F
.436 .137 .358 r
.35981 .67974 m .36153 .68085 L .35932 .68129 L F
.455 .124 .315 r
.36203 .67927 m .36153 .68085 L .35981 .67974 L F
.434 .155 .389 r
.42044 .68225 m .41971 .68417 L .41781 .68449 L F
.484 .204 .413 r
.42204 .68371 m .42044 .68225 L .42253 .68175 L F
.42204 .68371 m .41971 .68417 L .42044 .68225 L F
.182 0 .36 r
.73669 .62678 m .73503 .6276 L .73294 .62503 L F
.73669 .62678 m .73568 .62789 L .73503 .6276 L F
0 .246 .754 r
.73568 .62789 m .7369 .62911 L .73503 .6276 L F
.713 .2 .005 r
.73503 .6276 m .7369 .62911 L .73484 .62829 L F
0 0 0 r
.60134 .75799 m .59961 .75859 L .60253 .75641 L F
.60405 .75563 m .60253 .75641 L .6041 .75543 L F
.60405 .75563 m .60134 .75799 L .60253 .75641 L F
.194 0 0 r
.27266 .60467 m .27416 .60353 L .27593 .60368 L F
.415 .857 .916 r
.27759 .65594 m .27777 .65521 L .27565 .65554 L F
.27759 .65594 m .27955 .65538 L .27777 .65521 L F
.648 .539 .717 r
.52031 .73211 m .5223 .73122 L .51994 .73427 L F
.605 .404 .583 r
.4308 .74401 m .4335 .74478 L .43343 .74256 L F
.445 .208 .459 r
.43099 .74758 m .4335 .74478 L .4308 .74401 L F
.494 .413 .694 r
.32155 .68771 m .32386 .68979 L .32344 .68727 L F
.32155 .68771 m .32219 .69052 L .32386 .68979 L F
.503 .232 .437 r
.3647 .67637 m .36428 .67894 L .36203 .67927 L F
.376 .124 .399 r
.36614 .67827 m .3647 .67637 L .36674 .67625 L F
.36614 .67827 m .36428 .67894 L .3647 .67637 L F
.477 .625 .916 r
.28689 .60689 m .28688 .60446 L .28529 .60471 L F
.28689 .60689 m .2889 .60692 L .28688 .60446 L F
.847 .62 .595 r
.56352 .7361 m .56651 .73456 L .56276 .73388 L F
.56352 .7361 m .56574 .73748 L .56651 .73456 L F
.552 .485 .734 r
.42483 .78129 m .42621 .77777 L .42404 .77814 L F
.42483 .78129 m .42694 .78107 L .42621 .77777 L F
.571 .459 .687 r
.32881 .60747 m .327 .61035 L .32685 .60833 L F
.403 .465 .81 r
.571 .74964 m .57363 .75345 L .56947 .75156 L F
.879 .696 .65 r
.31068 .72463 m .31269 .72574 L .31182 .72296 L F
.602 .544 .762 r
.31269 .72574 m .3138 .7226 L .31182 .72296 L F
.31269 .72574 m .31499 .72591 L .3138 .7226 L F
.58 .418 .627 r
.31269 .72574 m .31529 .72839 L .31499 .72591 L F
.31269 .72574 m .31291 .7289 L .31529 .72839 L F
.58 .393 .592 r
.50187 .74501 m .50033 .74625 L .49997 .74519 L F
.43 .22 .492 r
.30481 .63812 m .30689 .63533 L .30639 .63752 L F
.413 .188 .461 r
.30437 .64006 m .30481 .63812 L .30639 .63752 L F
.491 .238 .459 r
.63926 .536 m .64109 .53193 L .64142 .53534 L F
.489 .238 .46 r
.64109 .53193 m .64365 .53477 L .64142 .53534 L F
.64109 .53193 m .64573 .53137 L .64365 .53477 L F
.448 .729 .986 r
.28364 .60504 m .28529 .60471 L .28476 .60425 L F
.28387 .60408 m .28398 .60358 L .28434 .6042 L F
.28387 .60408 m .28404 .60411 L .28398 .60358 L F
.543 .805 .994 r
.28031 .60295 m .28404 .60411 L .28398 .60358 L F
.28404 .60411 m .28434 .6042 L .28398 .60358 L F
.448 .729 .986 r
.28404 .60411 m .28476 .60425 L .28398 .60358 L F
.169 .652 .925 r
.28387 .60408 m .28434 .6042 L .28404 .60411 L F
.448 .729 .986 r
.28364 .60504 m .28387 .60408 L .28434 .6042 L F
.28364 .60504 m .28476 .60425 L .28387 .60408 L F
.169 .652 .925 r
.28011 .60308 m .28387 .60408 L .28031 .60295 L F
.28387 .60408 m .28404 .60411 L .28031 .60295 L F
.27949 .60348 m .28434 .6042 L .28011 .60308 L F
.679 .431 .539 r
.29497 .72892 m .29867 .72927 L .29795 .72672 L F
.702 .444 .531 r
.29795 .72672 m .29867 .72927 L .29972 .72715 L F
.5 .227 .431 r
.45381 .75606 m .45299 .75867 L .45099 .75876 L F
.576 .3 .462 r
.45581 .75788 m .45381 .75606 L .45614 .75594 L F
.45581 .75788 m .45299 .75867 L .45381 .75606 L F
.286 0 .262 r
.39806 .68484 m .3999 .68438 L .4005 .68252 L F
.601 .274 .387 r
.4005 .68252 m .4023 .68408 L .40255 .68188 L F
.4005 .68252 m .3999 .68438 L .4023 .68408 L F
.625 .17 .153 r
.46244 .75681 m .45852 .75636 L .45974 .75587 L F
.699 .629 .775 r
.69805 .59168 m .69951 .58801 L .69707 .58822 L F
.69805 .59168 m .70063 .59126 L .69951 .58801 L F
.377 .099 .358 r
.56262 .69257 m .56369 .69081 L .56246 .68777 L F
.56262 .69257 m .5645 .69214 L .56369 .69081 L F
.872 .925 .858 r
.5645 .69214 m .56782 .6903 L .56369 .69081 L F
.814 .526 .501 r
.44669 .74062 m .44964 .7399 L .44734 .7402 L F
.327 .335 .715 r
.29537 .74612 m .29468 .74807 L .29417 .74696 L F
.29537 .74612 m .29639 .74785 L .29468 .74807 L F
.17 0 .004 r
.29468 .74807 m .29639 .74785 L .29405 .74895 L F
.656 .41 .535 r
.51196 .72288 m .51434 .72294 L .51458 .72073 L F
.574 .368 .563 r
.51434 .72294 m .51686 .72021 L .51458 .72073 L F
.815 .755 .797 r
.72445 .71542 m .72783 .71514 L .72635 .71504 L F
0 .27 .766 r
.72783 .71514 m .72869 .71505 L .72635 .71504 L F
.72783 .71514 m .73078 .71737 L .72869 .71505 L F
.565 .401 .617 r
.72783 .71514 m .72805 .7181 L .73078 .71737 L F
0 .408 .707 r
.55786 .71003 m .55674 .70965 L .55465 .70902 L F
0 .349 .806 r
.56169 .71221 m .56183 .71169 L .56081 .7112 L F
0 .237 .74 r
.56169 .71221 m .56428 .71418 L .56183 .71169 L F
.6 .314 .455 r
.45249 .73935 m .45485 .73935 L .45523 .73743 L F
.543 .264 .442 r
.45485 .73935 m .45808 .73623 L .45523 .73743 L F
.234 0 .083 r
.33705 .65973 m .33534 .65976 L .33416 .66173 L F
.468 .76 .994 r
.26334 .58822 m .26291 .58953 L .26133 .58843 L F
.26334 .58822 m .26471 .58932 L .26291 .58953 L F
.62 .162 .144 r
.53022 .75403 m .52925 .75532 L .52719 .75393 L F
.306 .408 .802 r
.53022 .75403 m .53115 .75289 L .52925 .75532 L F
.53022 .75403 m .53268 .75566 L .53115 .75289 L F
.901 .914 .822 r
.5351 .78888 m .53266 .79212 L .53199 .79161 L F
.5351 .78888 m .53199 .79161 L .53467 .79171 L F
.5351 .78888 m .53467 .79171 L .53424 .78867 L F
.453 .272 .545 r
.30989 .71718 m .31017 .71318 L .30939 .71569 L F
.30989 .71718 m .31179 .71675 L .31017 .71318 L F
.31017 .71318 m .30989 .71718 L .30939 .71569 L F
.31017 .71318 m .31179 .71675 L .30989 .71718 L F
.36 .228 .563 r
.31017 .71318 m .31329 .71616 L .3146 .71436 L F
.31017 .71318 m .31179 .71675 L .31329 .71616 L F
.31329 .71616 m .31179 .71675 L .31017 .71318 L F
.291 0 0 r
.44314 .78623 m .44187 .78658 L .4397 .78641 L F
.426 .826 .98 r
.44543 .78661 m .44187 .78658 L .44314 .78623 L F
.474 .501 .806 r
.58505 .70621 m .58695 .70974 L .58462 .70852 L F
.58505 .70621 m .58462 .70852 L .58463 .70878 L F
.828 .427 0 r
.58644 .7117 m .58463 .70878 L .58462 .70852 L F
.477 .348 .625 r
.51544 .73964 m .51372 .74252 L .51396 .74121 L F
.51544 .73964 m .51563 .74205 L .51372 .74252 L F
.523 .336 .569 r
.43023 .66283 m .43018 .66533 L .42823 .66482 L F
.641 .369 .491 r
.49856 .73186 m .49632 .73365 L .49761 .73175 L F
.49856 .73186 m .49832 .73393 L .49632 .73365 L F
.808 .523 .506 r
.49832 .73393 m .49956 .73197 L .49856 .73186 L F
.641 .369 .491 r
.49874 .73171 m .49832 .73393 L .49856 .73186 L F
.808 .523 .506 r
.49832 .73393 m .49856 .73186 L .49761 .73175 L F
.49956 .73197 m .4998 .73159 L .49761 .73175 L F
.641 .369 .491 r
.49874 .73171 m .49856 .73186 L .49761 .73175 L F
.518 0 0 r
.49761 .73175 m .4998 .73159 L .49874 .73171 L F
.648 .525 .7 r
.35292 .68796 m .35348 .69048 L .35081 .69053 L F
.619 .348 .484 r
.35348 .69048 m .35281 .69249 L .35081 .69053 L F
.362 .335 .694 r
.35281 .69249 m .35133 .69244 L .35081 .69053 L F
.613 .407 .579 r
.74594 .59986 m .74601 .60262 L .74327 .60219 L F
.112 .114 .58 r
.74676 .596 m .74594 .59986 L .74441 .59681 L F
.74676 .596 m .74794 .59844 L .74594 .59986 L F
0 0 .232 r
.74684 .60063 m .74594 .59986 L .74794 .59844 L F
.74684 .60063 m .74645 .60127 L .74594 .59986 L F
0 0 .248 r
.74594 .59986 m .74645 .60127 L .74601 .60262 L F
.338 .261 .621 r
.5838 .72489 m .58401 .72857 L .58254 .7278 L F
.658 .575 .75 r
.40455 .67652 m .40758 .67658 L .4066 .67379 L F
.592 .403 .595 r
.40489 .67888 m .40758 .67658 L .40455 .67652 L F
.495 .245 .466 r
.4199 .68608 m .41781 .68449 L .41971 .68417 L F
.4199 .68608 m .41777 .68657 L .41781 .68449 L F
.359 .155 .461 r
.30639 .63752 m .30689 .63533 L .30841 .63435 L F
.588 .832 .991 r
.75364 .60379 m .75468 .60473 L .75272 .60557 L F
.363 .132 .424 r
.75272 .60557 m .75468 .60473 L .75364 .60379 L F
.75272 .60557 m .75246 .60751 L .75468 .60473 L F
.75468 .60473 m .75246 .60751 L .75272 .60557 L F
.46 .757 .994 r
.3994 .65243 m .39634 .65182 L .39835 .65161 L F
.403 .727 .99 r
.3989 .65118 m .3994 .65243 L .39835 .65161 L F
.3989 .65118 m .4007 .6522 L .3994 .65243 L F
.818 .625 .642 r
.58842 .73432 m .58929 .732 L .58694 .73114 L F
.412 .103 .329 r
.43537 .74206 m .43782 .74003 L .43581 .73982 L F
.497 0 0 r
.53043 .71445 m .53171 .71471 L .53365 .71487 L F
.854 .534 .447 r
.53171 .71471 m .53206 .71691 L .53365 .71487 L F
.663 .277 .304 r
.53365 .71487 m .53206 .71691 L .53574 .71672 L F
.185 .477 .894 r
.54826 .72445 m .54698 .725 L .54538 .72298 L F
.54826 .72445 m .54904 .72585 L .54698 .725 L F
.106 .03 .479 r
.6167 .73378 m .61679 .73618 L .61537 .73768 L F
0 0 .498 r
.61679 .73618 m .61621 .73959 L .61537 .73768 L F
.522 .39 .642 r
.3311 .73175 m .33228 .72867 L .32995 .72854 L F
.3311 .73175 m .33321 .73148 L .33228 .72867 L F
.216 0 .129 r
.55737 .68193 m .55913 .68183 L .5601 .67985 L F
.218 0 0 r
.55737 .68193 m .55983 .68221 L .55913 .68183 L F
.55737 .68193 m .55648 .68309 L .55983 .68221 L F
.491 0 0 r
.43782 .74003 m .43987 .74097 L .44155 .74041 L F
.217 0 0 r
.43987 .74097 m .44278 .74039 L .44155 .74041 L F
.367 .404 .768 r
.51026 .71852 m .51299 .71974 L .51203 .7199 L F
0 .269 .668 r
.5507 .70741 m .55197 .70797 L .54991 .70589 L F
.734 .207 0 r
.55197 .70797 m .55167 .70774 L .54991 .70589 L F
0 .255 .764 r
.54995 .70673 m .54991 .70589 L .548 .70387 L F
.734 .207 0 r
.55167 .70774 m .54861 .70541 L .54991 .70589 L F
0 .255 .764 r
.548 .70387 m .54991 .70589 L .54794 .70379 L F
.671 .214 .158 r
.47686 .78613 m .48028 .7865 L .47908 .78781 L F
.577 .116 .123 r
.48028 .7865 m .48123 .78845 L .47908 .78781 L F
.48028 .7865 m .48241 .78704 L .48123 .78845 L F
.426 .596 .915 r
.58249 .75616 m .58426 .75491 L .58151 .75293 L F
.58249 .75616 m .58421 .75596 L .58426 .75491 L F
.548 .403 .636 r
.3265 .67137 m .32837 .67085 L .32839 .66813 L F
.497 .369 .636 r
.3265 .67137 m .32864 .6733 L .32837 .67085 L F
.3265 .67137 m .32663 .67379 L .32864 .6733 L F
0 .243 .758 r
.56691 .73876 m .56724 .73993 L .56574 .73748 L F
0 0 .456 r
.56833 .74134 m .56724 .73993 L .56691 .73876 L F
.56833 .74134 m .56902 .74263 L .56724 .73993 L F
.351 .714 .986 r
.30505 .59621 m .30453 .59719 L .30306 .59631 L F
.30505 .59621 m .30655 .59718 L .30453 .59719 L F
0 0 0 r
.60134 .75799 m .59932 .75923 L .59961 .75859 L F
.483 .215 .431 r
.41305 .69046 m .41052 .69285 L .41208 .69017 L F
.477 .897 .873 r
.53196 .73106 m .53228 .73049 L .53338 .73178 L F
.53196 .73106 m .53013 .73137 L .53228 .73049 L F
.151 .317 .778 r
.33221 .72331 m .33417 .72505 L .33301 .7216 L F
.387 .067 .297 r
.34462 .65657 m .34768 .65339 L .3455 .654 L F
.476 .703 .968 r
.29023 .59385 m .28998 .59569 L .28836 .59424 L F
.29023 .59385 m .29206 .59545 L .28998 .59569 L F
.422 .422 .754 r
.74254 .71447 m .74434 .71426 L .74219 .71571 L F
.058 .369 .837 r
.74421 .71636 m .74219 .71571 L .74434 .71426 L F
.74421 .71636 m .74477 .7176 L .74219 .71571 L F
.717 .987 .827 r
.32204 .72272 m .32074 .72496 L .32311 .72295 L F
.32204 .72272 m .31949 .72527 L .32074 .72496 L F
.351 .174 .496 r
.45099 .75876 m .44901 .76185 L .44836 .75904 L F
.45099 .75876 m .45094 .76147 L .44901 .76185 L F
0 0 .157 r
.45094 .76147 m .4492 .76396 L .44901 .76185 L F
.574 .217 .325 r
.5949 .67307 m .59156 .67341 L .5924 .67153 L F
.541 .254 .428 r
.59441 .67126 m .5949 .67307 L .5924 .67153 L F
.295 .744 .96 r
.41093 .65461 m .41303 .65453 L .41433 .65505 L F
.18 .7 .88 r
.41303 .65453 m .41638 .65474 L .41433 .65505 L F
.287 0 .082 r
.38979 .71052 m .38913 .70912 L .3912 .70879 L F
.38979 .71052 m .38776 .71108 L .38913 .70912 L F
.991 .75 .381 r
.72826 .58824 m .72897 .5921 L .72939 .59126 L F
0 0 .561 r
.72897 .5921 m .72963 .59251 L .72939 .59126 L F
.72897 .5921 m .72997 .5935 L .72963 .59251 L F
.631 .483 .663 r
.5803 .70712 m .58179 .70443 L .57925 .70392 L F
.5803 .70712 m .5827 .70693 L .58179 .70443 L F
.288 0 0 r
.50152 .78645 m .50098 .78618 L .49938 .78576 L F
.50152 .78645 m .50283 .78687 L .50098 .78618 L F
.306 0 0 r
.36579 .72054 m .36427 .72212 L .36218 .72242 L F
.1 0 0 r
.36625 .72137 m .36579 .72054 L .36772 .71989 L F
.36625 .72137 m .36427 .72212 L .36579 .72054 L F
.538 .439 .69 r
.39816 .68737 m .3999 .68438 L .39806 .68484 L F
.825 .484 .41 r
.63123 .53601 m .63434 .53685 L .63425 .53855 L F
.53 .228 .4 r
.63425 .53855 m .63434 .53685 L .63662 .53821 L F
.839 .733 .747 r
.70854 .60217 m .71151 .60039 L .71059 .59926 L F
.71 .754 .887 r
.71151 .60039 m .71392 .59971 L .71059 .59926 L F
.227 0 .026 r
.55913 .68183 m .56234 .67934 L .5601 .67985 L F
.275 0 0 r
.35325 .65106 m .355 .65106 L .35595 .64989 L F
.3 0 0 r
.35595 .64989 m .355 .65106 L .35772 .65018 L F
.829 .668 .683 r
.63707 .52493 m .63423 .52501 L .63473 .52276 L F
.827 .736 .765 r
.63707 .52493 m .63505 .5282 L .63423 .52501 L F
.515 .471 .745 r
.57162 .69923 m .57041 .7008 L .56945 .69822 L F
.257 0 0 r
.57024 .70192 m .56803 .70253 L .57041 .7008 L F
.787 .681 .747 r
.33117 .72004 m .33434 .72058 L .33304 .71746 L F
.662 .162 .049 r
.33117 .72004 m .33301 .7216 L .33434 .72058 L F
.961 .641 .244 r
.33434 .72058 m .33363 .72025 L .33304 .71746 L F
.998 .849 .529 r
.33434 .72058 m .33301 .7216 L .33363 .72025 L F
.151 0 .377 r
.28257 .63575 m .2831 .63703 L .28373 .63518 L F
.28257 .63575 m .2823 .63825 L .2831 .63703 L F
.539 .377 .61 r
.42674 .75088 m .42885 .75053 L .4289 .74802 L F
.578 .452 .673 r
.42698 .75333 m .42885 .75053 L .42674 .75088 L F
.931 .838 .73 r
.59756 .71593 m .59635 .71751 L .59769 .71457 L F
.738 .65 .762 r
.70063 .59126 m .70264 .58844 L .69951 .58801 L F
.756 .365 .312 r
.50902 .74805 m .5077 .7498 L .50555 .74723 L F
0 0 0 r
.51044 .74761 m .50902 .74805 L .51074 .74706 L F
.51044 .74761 m .5077 .7498 L .50902 .74805 L F
0 .344 .819 r
.72875 .6214 m .72881 .62225 L .72784 .6211 L F
.72875 .6214 m .73098 .62358 L .72881 .62225 L F
.118 .328 .797 r
.52349 .70615 m .5228 .7074 L .52154 .70466 L F
.091 .291 .772 r
.52349 .70615 m .5249 .70929 L .5228 .7074 L F
.133 0 0 r
.27576 .6432 m .27929 .64101 L .27735 .64192 L F
.705 .593 .728 r
.53643 .72868 m .5369 .73155 L .53973 .73149 L F
.561 .128 .175 r
.5369 .73155 m .53838 .73319 L .53973 .73149 L F
.5369 .73155 m .53625 .73356 L .53838 .73319 L F
.143 0 .109 r
.3889 .69567 m .38968 .69692 L .391 .69516 L F
.3889 .69567 m .38791 .69785 L .38968 .69692 L F
.441 .265 .545 r
.30959 .71218 m .31158 .70935 L .30917 .70906 L F
0 0 .443 r
.56508 .71499 m .56606 .71632 L .56428 .71418 L F
.56508 .71499 m .56631 .71727 L .56606 .71632 L F
.964 .845 .675 r
.57492 .68043 m .57325 .68111 L .57333 .68086 L F
.57492 .68043 m .57441 .68198 L .57325 .68111 L F
.895 .892 .819 r
.57325 .68111 m .57441 .68198 L .57658 .67902 L F
0 0 0 r
.57459 .68037 m .57313 .6815 L .57325 .68111 L F
.57313 .6815 m .57186 .68249 L .57325 .68111 L F
.964 .845 .675 r
.57333 .68086 m .57325 .68111 L .57106 .68147 L F
.318 .716 .98 r
.36429 .70574 m .36633 .70576 L .36563 .70652 L F
.319 .717 .98 r
.36633 .70576 m .36778 .70661 L .36563 .70652 L F
.612 .534 .742 r
.35531 .70113 m .35329 .702 L .35219 .69823 L F
.13 .676 .714 r
.4489 .78605 m .44749 .78626 L .44543 .78661 L F
.269 0 0 r
.45097 .78628 m .44749 .78626 L .4489 .78605 L F
.932 .651 .486 r
.60507 .68412 m .60303 .68142 L .60446 .682 L F
.705 .593 .728 r
.53643 .72868 m .53973 .73149 L .53832 .72805 L F
.45 .517 .835 r
.53973 .73149 m .54011 .72764 L .53832 .72805 L F
.53973 .73149 m .54097 .73153 L .54011 .72764 L F
.529 .087 .144 r
.53973 .73149 m .54173 .73253 L .54097 .73153 L F
.322 0 .077 r
.54588 .69124 m .54677 .69238 L .54717 .68954 L F
.54588 .69124 m .54455 .69287 L .54677 .69238 L F
.637 .491 .667 r
.67743 .59814 m .6768 .59976 L .67906 .59702 L F
.302 0 0 r
.39094 .66558 m .39147 .66625 L .38926 .66659 L F
.465 .125 .304 r
.48147 .73051 m .48428 .72878 L .48201 .7292 L F
.611 .64 .854 r
.73813 .59503 m .74198 .59702 L .74118 .59559 L F
.861 .844 .827 r
.74118 .59559 m .74198 .59702 L .7442 .59424 L F
.174 .042 .45 r
.74198 .59702 m .74189 .59947 L .74379 .59742 L F
.621 .058 0 r
.56789 .7067 m .57147 .70908 L .57115 .70688 L F
.806 .522 .507 r
.35502 .72616 m .35137 .72661 L .35289 .72672 L F
.396 .423 .771 r
.57011 .74388 m .57107 .74738 L .56845 .74553 L F
0 .215 .731 r
.56933 .72336 m .57164 .72528 L .57094 .72405 L F
.805 .725 .777 r
.72051 .59417 m .72264 .59447 L .72422 .5921 L F
.774 .387 .322 r
.72153 .59618 m .72264 .59447 L .72051 .59417 L F
.72153 .59618 m .7241 .59636 L .72264 .59447 L F
.496 .305 .551 r
.4874 .74396 m .48525 .74771 L .48329 .74471 L F
.575 .51 .745 r
.42153 .76713 m .42234 .77011 L .42434 .76964 L F
.463 .366 .66 r
.42234 .77011 m .4242 .7708 L .42434 .76964 L F
.42234 .77011 m .42261 .77262 L .4242 .7708 L F
.455 .177 .401 r
.41052 .69285 m .40794 .69514 L .40843 .6933 L F
.743 .636 .741 r
.48969 .74196 m .49209 .73907 L .49027 .74002 L F
.48969 .74196 m .49251 .74212 L .49209 .73907 L F
.068 0 .234 r
.49066 .74134 m .49027 .74002 L .49209 .73907 L F
.49066 .74134 m .48969 .74196 L .49027 .74002 L F
.278 .464 .864 r
.5738 .73425 m .57544 .73677 L .57653 .73568 L F
.2 .337 .779 r
.57544 .73677 m .57653 .73722 L .57653 .73568 L F
.422 .235 .52 r
.4335 .74478 m .43537 .74206 L .43343 .74256 L F
.243 0 .06 r
.73232 .71011 m .72735 .71376 L .73145 .7096 L F
.419 .823 .979 r
.73453 .70969 m .73232 .71011 L .73145 .7096 L F
.613 .49 .689 r
.42116 .76467 m .42351 .76439 L .4229 .76139 L F
.613 .495 .695 r
.42116 .76467 m .42153 .76713 L .42351 .76439 L F
.442 .305 .599 r
.32318 .68203 m .325 .68405 L .32492 .68159 L F
.32318 .68203 m .323 .6853 L .325 .68405 L F
.467 .248 .497 r
.35728 .68156 m .35681 .68505 L .35466 .68501 L F
.38 .174 .47 r
.35911 .68339 m .35728 .68156 L .35932 .68129 L F
.35911 .68339 m .35681 .68505 L .35728 .68156 L F
0 0 .102 r
.57767 .74793 m .57856 .74693 L .57906 .74458 L F
.193 .451 .875 r
.57767 .74793 m .58103 .74996 L .57856 .74693 L F
.314 .454 .842 r
.74327 .60219 m .74464 .60111 L .74189 .59947 L F
.427 .671 .964 r
.74327 .60219 m .74601 .60262 L .74464 .60111 L F
.64 .289 .361 r
.51683 .71771 m .51573 .72008 L .51299 .71974 L F
.698 .353 .388 r
.51899 .71979 m .51683 .71771 L .51864 .71724 L F
.565 .445 .675 r
.51686 .72021 m .51765 .71889 L .51683 .71771 L F
.51686 .72021 m .51899 .71979 L .51765 .71889 L F
.698 .353 .388 r
.51899 .71979 m .51832 .71985 L .51765 .71889 L F
.51899 .71979 m .51765 .71889 L .51683 .71771 L F
.565 .445 .675 r
.51765 .71889 m .51899 .71979 L .51864 .71724 L F
.51765 .71889 m .51864 .71724 L .51683 .71771 L F
.698 .353 .388 r
.51832 .71985 m .51573 .72008 L .51683 .71771 L F
.679 .606 .767 r
.69586 .58548 m .69707 .58822 L .69915 .58568 L F
.623 .523 .72 r
.69707 .58822 m .69951 .58801 L .69915 .58568 L F
.948 .791 .652 r
.63423 .52501 m .63505 .5282 L .6339 .52694 L F
.911 .86 .778 r
.63505 .5282 m .63211 .53011 L .6339 .52694 L F
.63505 .5282 m .63328 .53116 L .63211 .53011 L F
0 0 .347 r
.74826 .61805 m .74775 .6193 L .74822 .61602 L F
0 0 0 r
.74806 .61985 m .74775 .6193 L .74826 .61805 L F
.74806 .61985 m .74716 .62139 L .74775 .6193 L F
.581 .517 .748 r
.42404 .77814 m .42538 .77528 L .42345 .77561 L F
.555 .498 .747 r
.42406 .77095 m .42547 .77571 L .4242 .7708 L F
.621 .509 .706 r
.42538 .77528 m .42261 .77262 L .42345 .77561 L F
.42538 .77528 m .42547 .77571 L .42261 .77262 L F
.555 .498 .747 r
.42261 .77262 m .42453 .7747 L .42406 .77095 L F
.42453 .7747 m .42547 .77571 L .42406 .77095 L F
.581 .517 .748 r
.42477 .77658 m .42621 .77777 L .42538 .77528 L F
.42404 .77814 m .42495 .77799 L .42477 .77658 L F
.42495 .77799 m .42621 .77777 L .42477 .77658 L F
.343 0 0 r
.50396 .7908 m .508 .79133 L .50632 .79095 L F
.67 .126 0 r
.508 .79133 m .50936 .79215 L .50632 .79095 L F
0 0 .498 r
.61679 .73618 m .61724 .73851 L .61621 .73959 L F
0 0 .437 r
.61724 .73851 m .61651 .74228 L .61621 .73959 L F
.703 .587 .723 r
.6768 .59976 m .68088 .60045 L .67906 .59702 L F
.701 .56 .692 r
.67715 .60258 m .68088 .60045 L .6768 .59976 L F
.557 .463 .704 r
.3539 .69587 m .35133 .69244 L .35281 .69249 L F
.3539 .69587 m .3518 .69649 L .35133 .69244 L F
.485 .077 .189 r
.47054 .73384 m .4728 .73375 L .47395 .73205 L F
.504 .096 .2 r
.47395 .73205 m .4728 .73375 L .47595 .73293 L F
.496 .129 .272 r
.47395 .73205 m .47595 .73293 L .47603 .73207 L F
.435 .629 .935 r
.4056 .65204 m .40568 .65386 L .40408 .65262 L F
.4056 .65204 m .40762 .65388 L .40568 .65386 L F
.882 .986 .816 r
.74155 .73054 m .74432 .72831 L .74429 .72833 L F
.74155 .73054 m .74204 .73099 L .74432 .72831 L F
.725 .935 .957 r
.71618 .60867 m .71764 .60655 L .71557 .60781 L F
.701 .56 .692 r
.67715 .60258 m .68026 .60246 L .68088 .60045 L F
.354 .077 .348 r
.30839 .63264 m .31132 .62988 L .31089 .63395 L F
.616 .087 0 r
.30839 .63264 m .31076 .6344 L .30841 .63435 L F
.30839 .63264 m .31089 .63395 L .31076 .6344 L F
.953 .604 .254 r
.52658 .75226 m .52569 .75331 L .52438 .7528 L F
.52569 .75331 m .52397 .75535 L .52438 .7528 L F
.52658 .75226 m .52583 .7526 L .52397 .75535 L F
.52658 .75226 m .52719 .75393 L .52583 .7526 L F
.075 .316 .797 r
.52715 .75389 m .52773 .75252 L .52583 .7526 L F
.52719 .75393 m .5272 .75391 L .52715 .75389 L F
.5272 .75391 m .52773 .75252 L .52715 .75389 L F
.953 .604 .254 r
.52438 .7528 m .52397 .75535 L .52363 .75299 L F
.582 .056 0 r
.73391 .58537 m .73083 .58495 L .733 .58538 L F
.111 0 0 r
.733 .58538 m .73629 .58555 L .73391 .58537 L F
.441 .265 .545 r
.30959 .71218 m .31121 .71203 L .31158 .70935 L F
.097 0 0 r
.29057 .65168 m .28888 .65299 L .28689 .65354 L F
.166 0 0 r
.29253 .65107 m .28888 .65299 L .29057 .65168 L F
.324 .793 .928 r
.36522 .84956 m .36167 .84966 L .36346 .84694 L F
.36167 .84966 m .36522 .84956 L .36369 .85052 L F
.193 .427 .858 r
.36574 .84959 m .36522 .84956 L .36346 .84694 L F
.169 0 0 r
.36369 .85052 m .36522 .84956 L .36574 .84959 L F
.483 .786 .998 r
.27234 .59071 m .27181 .59195 L .27031 .59087 L F
.27234 .59071 m .2738 .59165 L .27181 .59195 L F
.533 .152 .265 r
.53582 .7539 m .53472 .75561 L .53268 .75566 L F
.718 .366 .38 r
.53582 .7539 m .53787 .75596 L .53472 .75561 L F
.911 .619 .127 r
.59393 .76088 m .59352 .76086 L .59423 .76368 L F
.082 .642 .743 r
.59393 .76088 m .59632 .7607 L .59352 .76086 L F
.387 .437 .79 r
.74379 .59742 m .74317 .59609 L .74344 .59557 L F
.861 .844 .827 r
.74118 .59559 m .74412 .59427 L .74344 .59557 L F
.375 .713 .987 r
.74118 .59559 m .74344 .59557 L .74249 .59462 L F
.387 .437 .79 r
.74317 .59609 m .74249 .59462 L .74344 .59557 L F
.861 .844 .827 r
.74412 .59427 m .7442 .59424 L .74344 .59557 L F
.197 .456 .878 r
.74407 .58791 m .743 .58875 L .74244 .5873 L F
.192 .446 .872 r
.74407 .58791 m .74617 .5907 L .743 .58875 L F
.422 .398 .727 r
.7462 .59284 m .74676 .596 L .7442 .59424 L F
.545 .471 .723 r
.33228 .72867 m .33424 .72888 L .33417 .72505 L F
.59 .429 .631 r
.33228 .72867 m .33534 .73079 L .33424 .72888 L F
.33228 .72867 m .33321 .73148 L .33534 .73079 L F
.511 .301 .532 r
.32219 .69052 m .32399 .69174 L .32386 .68979 L F
.32219 .69052 m .3218 .69254 L .32399 .69174 L F
.326 .025 .292 r
.50689 .72059 m .50522 .71777 L .50799 .71773 L F
.812 .797 .838 r
.72422 .5921 m .72513 .58853 L .72302 .58934 L F
.881 .663 .603 r
.5685 .75712 m .56863 .75732 L .57076 .75542 L F
.908 .61 .468 r
.57027 .75713 m .57085 .75911 L .57011 .75849 L F
0 0 0 r
.57072 .75584 m .5735 .75415 L .57083 .75583 L F
.57091 .75566 m .5735 .75415 L .57064 .75588 L F
.908 .61 .468 r
.57 .7562 m .57027 .75713 L .5685 .75712 L F
.57027 .75713 m .57011 .75849 L .5685 .75712 L F
.541 .472 .727 r
.57046 .75599 m .57052 .75653 L .57 .7562 L F
.57052 .75653 m .57085 .75911 L .57027 .75713 L F
.57052 .75653 m .57027 .75713 L .57 .7562 L F
0 0 .21 r
.57067 .75584 m .57052 .75653 L .57083 .75583 L F
.881 .663 .603 r
.57046 .75599 m .57052 .75653 L .57067 .75584 L F
.541 .472 .727 r
.57259 .75505 m .57085 .75911 L .57046 .75599 L F
0 0 .21 r
.57083 .75583 m .57011 .75849 L .57099 .75582 L F
.57052 .75653 m .57011 .75849 L .57083 .75583 L F
.881 .663 .603 r
.56869 .75728 m .57011 .75849 L .57052 .75653 L F
.56869 .75728 m .57052 .75653 L .57046 .75599 L F
.541 .472 .727 r
.57259 .75505 m .57088 .75923 L .57085 .75911 L F
0 0 0 r
.5706 .75589 m .57064 .75588 L .57046 .75599 L F
.57091 .75566 m .57064 .75588 L .5706 .75589 L F
0 0 .21 r
.57175 .75569 m .57167 .75698 L .57234 .75584 L F
0 0 0 r
.57083 .75583 m .5712 .7556 L .57131 .75562 L F
0 0 .21 r
.57076 .75542 m .57099 .75582 L .57175 .75569 L F
.57099 .75582 m .57167 .75698 L .57175 .75569 L F
0 .353 .731 r
.57076 .75542 m .57175 .75569 L .56983 .75479 L F
.57175 .75569 m .57234 .75584 L .57211 .75575 L F
0 0 0 r
.57131 .75562 m .57293 .75453 L .57259 .75505 L F
.57293 .75453 m .5735 .75415 L .57259 .75505 L F
.774 .399 .346 r
.57212 .75578 m .57259 .75505 L .57255 .7546 L F
0 0 0 r
.5712 .7556 m .5735 .75415 L .57131 .75562 L F
0 .353 .731 r
.57175 .75569 m .57211 .75575 L .56983 .75479 L F
.776 .664 .739 r
.56654 .75282 m .56879 .75421 L .56983 .75479 L F
.56879 .75421 m .57076 .75542 L .56983 .75479 L F
.373 0 0 r
.56983 .75479 m .57214 .75576 L .57068 .75527 L F
.56983 .75479 m .57068 .75527 L .56747 .7542 L F
.774 .399 .346 r
.57167 .75698 m .57231 .75563 L .57212 .75578 L F
0 0 0 r
.57046 .75599 m .57072 .75584 L .57083 .75583 L F
0 0 .21 r
.57099 .75582 m .57011 .75849 L .57167 .75698 L F
.57076 .75542 m .57067 .75584 L .57099 .75582 L F
0 0 0 r
.57 .7562 m .57091 .75566 L .57046 .75599 L F
.881 .663 .603 r
.56863 .75732 m .57067 .75584 L .57076 .75542 L F
.487 0 0 r
.57167 .75698 m .56747 .7542 L .57212 .75577 L F
.774 .399 .346 r
.57167 .75698 m .57212 .75578 L .57212 .75578 L F
.541 .472 .727 r
.57259 .75505 m .57238 .7586 L .57088 .75923 L F
0 0 .461 r
.57346 .75772 m .57238 .7586 L .57259 .75505 L F
.774 .399 .346 r
.57167 .75698 m .57346 .75772 L .57259 .75505 L F
.487 0 0 r
.57167 .75698 m .57212 .75577 L .57234 .75584 L F
.373 0 0 r
.57214 .75576 m .57234 .75584 L .57212 .75577 L F
.57214 .75576 m .57212 .75577 L .56747 .7542 L F
.774 .399 .346 r
.57231 .75563 m .57259 .75505 L .57213 .75577 L F
.57231 .75563 m .57213 .75577 L .57212 .75578 L F
0 0 .21 r
.57011 .75854 m .56992 .75941 L .57003 .75926 L F
.57011 .75851 m .56992 .75941 L .57011 .75854 L F
.881 .663 .603 r
.56863 .75732 m .56992 .75941 L .57011 .75849 L F
.56863 .75732 m .57011 .75849 L .56869 .75728 L F
.917 .524 .137 r
.5685 .75712 m .5699 .76044 L .56992 .75941 L F
.911 .559 .357 r
.57011 .75854 m .5699 .76044 L .5685 .75712 L F
.57088 .75923 m .57004 .76026 L .57008 .75919 L F
.57088 .75923 m .57008 .75919 L .57017 .7586 L F
.57004 .76026 m .5699 .76044 L .57011 .75854 L F
0 0 .21 r
.57011 .75849 m .57011 .75851 L .57011 .75854 L F
.908 .61 .468 r
.57085 .75911 m .57088 .75923 L .5685 .75712 L F
.107 0 .421 r
.5699 .76044 m .57167 .75698 L .57008 .75919 L F
.5699 .76044 m .57008 .75919 L .56992 .75941 L F
.911 .559 .357 r
.57017 .7586 m .57008 .75919 L .57011 .75854 L F
0 0 .21 r
.57011 .75849 m .57003 .75926 L .57167 .75698 L F
.736 .965 .937 r
.57363 .75345 m .57541 .75315 L .5735 .75415 L F
.617 .105 .007 r
.51759 .74578 m .51614 .74662 L .51332 .74591 L F
.591 .588 .818 r
.51893 .74467 m .51759 .74578 L .51563 .74205 L F
.559 .359 .566 r
.49199 .72324 m .49451 .72283 L .4945 .72048 L F
.413 .179 .447 r
.4945 .72048 m .49643 .72002 L .4968 .71791 L F
.402 .216 .511 r
.49451 .72283 m .49643 .72002 L .4945 .72048 L F
0 0 0 r
.70799 .58036 m .70831 .5798 L .70909 .57772 L F
.103 0 .185 r
.70909 .57772 m .71074 .57682 L .71134 .57496 L F
.717 .351 .355 r
.70909 .57772 m .71139 .57982 L .71074 .57682 L F
.70909 .57772 m .70831 .5798 L .71139 .57982 L F
.061 .617 .815 r
.28088 .59409 m .27729 .59372 L .27938 .59307 L F
.451 .757 .994 r
.27938 .59307 m .28138 .59286 L .28088 .59409 L F
.424 .728 .989 r
.28138 .59286 m .28286 .59398 L .28088 .59409 L F
.702 .568 .701 r
.67802 .60537 m .68026 .60246 L .67715 .60258 L F
.543 .264 .442 r
.45485 .73935 m .45714 .73908 L .45808 .73623 L F
.569 .297 .463 r
.45714 .73908 m .46013 .73629 L .45808 .73623 L F
.44 .335 .639 r
.44903 .76659 m .44939 .76932 L .44733 .7672 L F
.831 .46 .352 r
.5442 .73893 m .54584 .74143 L .54713 .73982 L F
.876 .528 .388 r
.54713 .73982 m .54584 .74143 L .54723 .74132 L F
.647 .252 .282 r
.47477 .78596 m .47348 .78656 L .47126 .78609 L F
.522 .072 .123 r
.47686 .78613 m .47348 .78656 L .47477 .78596 L F
.596 .462 .668 r
.57165 .69544 m .56945 .69822 L .56902 .69579 L F
.57165 .69544 m .57162 .69923 L .56945 .69822 L F
.819 .888 .893 r
.60498 .66183 m .60337 .66234 L .60541 .66184 L F
.806 .574 .587 r
.60337 .66234 m .60474 .66487 L .60541 .66184 L F
.373 .068 .314 r
.38365 .6988 m .38506 .6999 L .38603 .69852 L F
.38365 .6988 m .38312 .70054 L .38506 .6999 L F
.67 .782 .933 r
.71059 .59926 m .71392 .59971 L .71302 .59837 L F
.761 .817 .897 r
.71302 .59837 m .71392 .59971 L .71643 .5978 L F
.537 .293 .493 r
.49199 .72324 m .49181 .72551 L .49451 .72283 L F
.449 .721 .983 r
.45813 .64638 m .46027 .64638 L .45899 .64509 L F
.45813 .64638 m .46027 .64638 L .45899 .64509 L F
.772 .582 .642 r
.48468 .78344 m .48812 .78364 L .48486 .78148 L F
.48468 .78344 m .48812 .78364 L .48486 .78148 L F
.665 .624 .799 r
.48486 .78148 m .48812 .78364 L .48688 .78056 L F
.766 .675 .762 r
.48688 .78056 m .48812 .78364 L .48468 .78344 L F
.579 .071 .011 r
.48736 .78477 m .48812 .78364 L .48468 .78344 L F
.748 .269 .107 r
.48736 .78477 m .49025 .78577 L .48812 .78364 L F
.766 .675 .762 r
.48468 .78344 m .48812 .78364 L .48688 .78056 L F
.598 .951 .851 r
.37373 .70479 m .37371 .70399 L .37572 .70413 L F
.37373 .70479 m .37179 .70528 L .37371 .70399 L F
.55 .47 .718 r
.35424 .69778 m .3518 .69649 L .3539 .69587 L F
.35424 .69778 m .35219 .69823 L .3518 .69649 L F
.228 .056 .429 r
.7507 .61281 m .75054 .61494 L .74822 .61602 L F
.11 0 .345 r
.75054 .61494 m .74826 .61805 L .74822 .61602 L F
.628 .351 .479 r
.28994 .73105 m .29295 .72956 L .29058 .73038 L F
.734 .49 .559 r
.56815 .69435 m .57157 .69339 L .56902 .69579 L F
.661 .613 .79 r
.57165 .69544 m .56902 .69579 L .57157 .69339 L F
.067 0 0 r
.37654 .71634 m .37614 .71563 L .37807 .71494 L F
.37654 .71634 m .37459 .71697 L .37614 .71563 L F
.812 .579 .586 r
.61604 .67871 m .61936 .68147 L .61931 .67923 L F
.023 .39 .849 r
.39937 .66677 m .40017 .668 L .40054 .66719 L F
.135 .532 .919 r
.40017 .668 m .40209 .66863 L .40054 .66719 L F
.435 .32 .623 r
.49129 .74386 m .49251 .74212 L .48969 .74196 L F
.49129 .74386 m .49259 .74496 L .49251 .74212 L F
.431 .226 .499 r
.31281 .62731 m .31506 .62355 L .31524 .6262 L F
.401 .171 .446 r
.31506 .62355 m .31756 .62057 L .31722 .62328 L F
.32 .123 .449 r
.31524 .6262 m .31506 .62355 L .31722 .62328 L F
.53 .643 .905 r
.53643 .72868 m .53832 .72805 L .53438 .72698 L F
0 .254 .766 r
.25935 .58826 m .25961 .58847 L .25962 .58871 L F
.464 .756 .993 r
.26133 .58843 m .25962 .58871 L .25961 .58847 L F
.843 .609 .584 r
.61436 .67348 m .61608 .67629 L .61615 .67388 L F
.219 .421 .847 r
.5858 .75867 m .58678 .75767 L .58421 .75596 L F
.27 .504 .896 r
.5858 .75867 m .58767 .75933 L .58678 .75767 L F
.592 .403 .595 r
.40489 .67888 m .40749 .67896 L .40758 .67658 L F
.481 .228 .453 r
.405 .68121 m .40749 .67896 L .40489 .67888 L F
.775 .963 .926 r
.73977 .7318 m .74204 .73099 L .74155 .73054 L F
.612 .534 .742 r
.35531 .70113 m .35219 .69823 L .35424 .69778 L F
0 .047 .595 r
.53574 .71672 m .53737 .71896 L .53713 .71769 L F
.965 .91 .555 r
.57472 .7318 m .57392 .73236 L .57378 .73077 L F
.57472 .7318 m .57408 .73349 L .57392 .73236 L F
0 .032 .602 r
.57392 .73236 m .57469 .73315 L .57367 .73059 L F
.57392 .73236 m .57352 .73021 L .57378 .73077 L F
.57392 .73236 m .57367 .73059 L .57352 .73021 L F
.965 .91 .555 r
.57408 .73349 m .5738 .73425 L .57392 .73236 L F
.4 .231 .534 r
.31132 .62988 m .31281 .62731 L .31283 .62957 L F
.294 .14 .494 r
.31297 .63141 m .31132 .62988 L .31283 .62957 L F
.31297 .63141 m .31089 .63395 L .31132 .62988 L F
.465 .199 .425 r
.40554 .66822 m .40796 .66834 L .40811 .66586 L F
.40554 .66822 m .40796 .66834 L .40811 .66586 L F
.528 .372 .613 r
.41 .66248 m .41023 .66516 L .40811 .66586 L F
.584 .295 .444 r
.40988 .66717 m .40811 .66586 L .41023 .66516 L F
.40988 .66717 m .40796 .66834 L .40811 .66586 L F
.528 .372 .613 r
.40811 .66586 m .41023 .66516 L .41 .66248 L F
.584 .295 .444 r
.40811 .66586 m .40988 .66717 L .41023 .66516 L F
.40811 .66586 m .40796 .66834 L .40988 .66717 L F
.616 .537 .742 r
.31908 .70424 m .31957 .70681 L .32138 .7039 L F
.665 .602 .774 r
.31957 .70681 m .32287 .70677 L .32138 .7039 L F
.755 .607 .694 r
.69952 .58347 m .7014 .58067 L .69796 .5802 L F
.69952 .58347 m .70124 .58289 L .7014 .58067 L F
0 0 0 r
.61193 .75019 m .61193 .75057 L .609 .75262 L F
.61425 .7476 m .6132 .74923 L .61193 .75019 L F
.61193 .75019 m .6132 .74923 L .61193 .75057 L F
.5 .45 .733 r
.7053 .59933 m .70724 .59898 L .70696 .59646 L F
.632 .567 .763 r
.70557 .60093 m .70724 .59898 L .7053 .59933 L F
.685 .672 .832 r
.43023 .66283 m .42715 .66197 L .42919 .66151 L F
.398 .648 .958 r
.43107 .66153 m .43023 .66283 L .42919 .66151 L F
.553 .539 .793 r
.43107 .66153 m .43018 .66533 L .43023 .66283 L F
0 0 .336 r
.29329 .74741 m .29537 .74612 L .29417 .74696 L F
.134 .397 .848 r
.58089 .7507 m .58153 .74966 L .58103 .74996 L F
.076 .184 .674 r
.58151 .75293 m .58153 .74966 L .58089 .7507 L F
.864 .529 .416 r
.60645 .66716 m .60778 .6658 L .60474 .66487 L F
.60645 .66716 m .6081 .66775 L .60778 .6658 L F
.945 .903 .75 r
.60637 .70951 m .6041 .71134 L .60504 .70872 L F
.60637 .70951 m .60477 .7127 L .6041 .71134 L F
.411 0 0 r
.35772 .65018 m .35987 .65036 L .36148 .64935 L F
.472 0 .024 r
.35987 .65036 m .36357 .6492 L .36148 .64935 L F
.53 .355 .588 r
.42486 .75611 m .42699 .75574 L .42698 .75333 L F
.522 .388 .639 r
.42486 .75611 m .42709 .75813 L .42699 .75574 L F
.42486 .75611 m .42511 .75864 L .42709 .75813 L F
.773 .641 .716 r
.63638 .51774 m .63631 .51999 L .63283 .51954 L F
.78 .608 .667 r
.63631 .51999 m .63244 .52159 L .63283 .51954 L F
.63631 .51999 m .63473 .52276 L .63244 .52159 L F
.714 .592 .717 r
.63867 .51713 m .63631 .51999 L .63638 .51774 L F
.399 .167 .442 r
.4968 .71791 m .49831 .71945 L .49861 .71728 L F
.4968 .71791 m .49643 .72002 L .49831 .71945 L F
0 0 0 r
.61552 .74657 m .6132 .74923 L .61425 .7476 L F
.646 .54 .719 r
.42351 .76439 m .42153 .76713 L .42402 .76664 L F
.575 .51 .745 r
.42153 .76713 m .42434 .76964 L .42402 .76664 L F
.193 0 0 r
.45438 .78606 m .45314 .78633 L .45097 .78628 L F
.257 0 0 r
.45659 .78579 m .45314 .78633 L .45438 .78606 L F
.076 0 0 r
.54923 .68694 m .55228 .68498 L .55029 .68609 L F
.628 .824 .976 r
.32209 .71677 m .32779 .71753 L .32698 .71617 L F
.714 .568 .689 r
.32522 .7203 m .32981 .7218 L .32779 .71753 L F
.99 .751 .372 r
.32798 .71091 m .32883 .71404 L .32835 .71107 L F
0 .084 .632 r
.32798 .71091 m .32894 .71315 L .32883 .71404 L F
.564 .636 .881 r
.32945 .71466 m .33304 .71746 L .33234 .71455 L F
.626 .837 .981 r
.32883 .71404 m .33234 .71455 L .33052 .71128 L F
.32883 .71404 m .32945 .71466 L .33234 .71455 L F
.719 .432 .49 r
.32886 .71568 m .32698 .71617 L .32779 .71753 L F
.32894 .71555 m .32698 .71617 L .32886 .71568 L F
.66 .185 .113 r
.32698 .71617 m .32851 .71662 L .32622 .71637 L F
.224 0 .31 r
.32412 .71615 m .32211 .71677 L .32629 .71626 L F
.32412 .71615 m .32629 .71626 L .32698 .71617 L F
.66 .185 .113 r
.32698 .71617 m .32622 .71637 L .32412 .71615 L F
.617 .524 .727 r
.32779 .71753 m .32981 .7218 L .33117 .72004 L F
.813 .51 .478 r
.3278 .71881 m .32412 .71615 L .32851 .71662 L F
.3278 .71881 m .32478 .71875 L .32412 .71615 L F
0 0 .41 r
.32412 .71615 m .32449 .71668 L .32576 .71564 L F
.32412 .71615 m .32576 .71564 L .32578 .71557 L F
.55 .222 .365 r
.32578 .71557 m .32602 .71583 L .32569 .71584 L F
0 0 .41 r
.32576 .71564 m .32576 .71564 L .32578 .71557 L F
.55 .222 .365 r
.32578 .71557 m .32266 .71598 L .32412 .71615 L F
.32578 .71557 m .32569 .71584 L .32266 .71598 L F
.611 .593 .808 r
.32266 .71598 m .32569 .71584 L .32382 .7116 L F
.374 .055 .291 r
.32595 .71574 m .32511 .71757 L .32713 .71692 L F
.32578 .71557 m .32569 .71584 L .32595 .71574 L F
.611 .593 .808 r
.32569 .71584 m .32602 .71583 L .32597 .71574 L F
.32569 .71584 m .32597 .71574 L .32569 .71584 L F
.374 .055 .291 r
.32569 .71584 m .32511 .71757 L .32595 .71574 L F
.611 .593 .808 r
.32569 .71584 m .32597 .71574 L .32594 .71567 L F
.323 .205 .56 r
.32784 .71305 m .32578 .71557 L .32799 .71487 L F
.32784 .71305 m .32616 .71561 L .32578 .71557 L F
.32616 .71561 m .32602 .71583 L .32578 .71557 L F
.374 .055 .291 r
.32578 .71557 m .32595 .71575 L .32616 .71561 L F
.32578 .71557 m .32762 .71577 L .32799 .71487 L F
.636 .605 .802 r
.32382 .7116 m .32597 .71573 L .32784 .71305 L F
.32597 .71573 m .32602 .71583 L .32616 .71561 L F
.32597 .71573 m .32616 .71561 L .32784 .71305 L F
.374 .055 .291 r
.32616 .71561 m .32713 .71692 L .32762 .71577 L F
.32595 .71575 m .32713 .71692 L .32616 .71561 L F
.611 .593 .808 r
.32569 .71584 m .32594 .71567 L .32382 .7116 L F
0 0 .41 r
.32449 .71668 m .32511 .71757 L .32569 .71584 L F
.32449 .71668 m .32569 .71584 L .32576 .71564 L F
.224 0 .31 r
.32412 .71615 m .32209 .71677 L .32211 .71677 L F
.778 .885 .923 r
.32266 .71598 m .32253 .71606 L .32412 .71615 L F
.787 .37 .26 r
.31835 .71751 m .32182 .71759 L .31967 .72026 L F
.673 .545 .701 r
.32182 .71759 m .32365 .7208 L .31967 .72026 L F
.787 .37 .26 r
.31835 .71751 m .32189 .7198 L .32182 .71759 L F
.602 .08 0 r
.32209 .71677 m .32261 .71752 L .32077 .71664 L F
.755 .572 .649 r
.32522 .7203 m .32365 .7208 L .32182 .71759 L F
.32522 .7203 m .32182 .71759 L .32189 .7198 L F
.368 .691 .981 r
.31973 .71798 m .32216 .7189 L .31973 .71798 L F
.781 .38 .294 r
.31966 .71796 m .32216 .7189 L .31957 .71807 L F
.32077 .71664 m .32162 .71802 L .31966 .71796 L F
.31966 .71796 m .31966 .71796 L .31966 .71796 L F
.32077 .71664 m .31971 .7179 L .31971 .7179 L F
.865 .469 .288 r
.31969 .71471 m .32077 .71664 L .3189 .71609 L F
.781 .38 .294 r
.32077 .71664 m .31957 .71807 L .3189 .71609 L F
.602 .08 0 r
.32261 .71752 m .3221 .71753 L .32077 .71664 L F
.414 .277 .584 r
.3221 .71753 m .32162 .71802 L .32077 .71664 L F
.778 .885 .923 r
.32253 .71606 m .32038 .71754 L .32304 .71655 L F
.32346 .71611 m .32304 .71655 L .32412 .71615 L F
.32253 .71606 m .32304 .71655 L .32346 .71611 L F
.414 .277 .584 r
.32254 .71782 m .32216 .7189 L .32162 .71802 L F
.32254 .71782 m .32162 .71802 L .3221 .71753 L F
.368 .691 .981 r
.32252 .71789 m .32216 .7189 L .32289 .71788 L F
.18 0 .28 r
.32412 .71615 m .32216 .7189 L .32307 .71817 L F
.414 .277 .584 r
.32307 .71817 m .32216 .7189 L .32254 .71782 L F
.781 .38 .294 r
.32162 .71802 m .32216 .7189 L .31973 .71798 L F
.32162 .71802 m .31973 .71798 L .31966 .71796 L F
.368 .691 .981 r
.31973 .71798 m .32216 .7189 L .32252 .71789 L F
.755 .773 .868 r
.32048 .71454 m .31973 .71798 L .32266 .71598 L F
.381 .682 .977 r
.3209 .71647 m .31973 .71798 L .32048 .71454 L F
.781 .38 .294 r
.31971 .7179 m .31966 .71796 L .31966 .71796 L F
.31971 .7179 m .31966 .71796 L .31971 .7179 L F
.778 .885 .923 r
.32038 .71754 m .31973 .71798 L .3208 .71753 L F
.602 .08 0 r
.32261 .71752 m .32286 .71787 L .3221 .71753 L F
.32286 .71787 m .32254 .71782 L .3221 .71753 L F
.224 0 .31 r
.32412 .71615 m .32286 .71787 L .32209 .71677 L F
.368 .691 .981 r
.3208 .71753 m .32286 .71787 L .32412 .71615 L F
.32286 .71787 m .32289 .71788 L .32412 .71615 L F
.224 0 .31 r
.32412 .71615 m .32307 .71817 L .32286 .71787 L F
.368 .691 .981 r
.31973 .71798 m .32289 .71788 L .3208 .71753 L F
.778 .885 .923 r
.32038 .71754 m .3208 .71753 L .32412 .71615 L F
.381 .682 .977 r
.3209 .71647 m .32276 .71783 L .31973 .71798 L F
.602 .08 0 r
.32286 .71787 m .32307 .71817 L .32254 .71782 L F
.719 .432 .49 r
.32945 .71466 m .32894 .71497 L .32894 .71555 L F
.32894 .71497 m .32698 .71617 L .32894 .71555 L F
.32945 .71466 m .32851 .71662 L .32698 .71617 L F
.218 0 .219 r
.33013 .71591 m .32851 .71662 L .32945 .71466 L F
.33013 .71591 m .32945 .71466 L .32883 .71404 L F
.626 .837 .981 r
.32883 .71404 m .33052 .71128 L .32835 .71107 L F
0 .084 .632 r
.32894 .71315 m .33013 .71591 L .32894 .7142 L F
.32894 .71315 m .32894 .7142 L .32883 .71404 L F
.9 .684 .601 r
.74294 .62722 m .741 .62372 L .74254 .6246 L F
.72 .283 .213 r
.74254 .6246 m .74487 .62646 L .74294 .62722 L F
.307 0 .017 r
.34976 .65314 m .35193 .65275 L .35325 .65106 L F
.47 .085 .226 r
.35193 .65275 m .355 .65106 L .35325 .65106 L F
.558 .235 .378 r
.71134 .57496 m .71074 .57682 L .7122 .5755 L F
.719 .353 .356 r
.53101 .79434 m .53044 .7951 L .52799 .79398 L F
0 0 0 r
.53203 .79387 m .53101 .79434 L .53325 .79458 L F
.53203 .79387 m .53044 .7951 L .53101 .79434 L F
.792 .635 .687 r
.32311 .72295 m .32648 .72375 L .32522 .7203 L F
.631 .552 .747 r
.32522 .7203 m .32648 .72375 L .32846 .72323 L F
.895 .892 .819 r
.57325 .68111 m .57658 .67902 L .57539 .67977 L F
0 0 0 r
.57806 .67883 m .57658 .67902 L .57977 .67689 L F
.57806 .67883 m .57539 .67977 L .57658 .67902 L F
.517 .349 .592 r
.32839 .66813 m .33047 .66776 L .33042 .66528 L F
.474 .343 .622 r
.32839 .66813 m .33044 .66984 L .33047 .66776 L F
.32839 .66813 m .32837 .67085 L .33044 .66984 L F
.446 .391 .703 r
.35498 .68967 m .35292 .68796 L .35492 .6873 L F
.35498 .68967 m .35348 .69048 L .35292 .68796 L F
.735 .532 .619 r
.52831 .74729 m .53322 .74571 L .5282 .74504 L F
.52831 .74729 m .5312 .74791 L .53322 .74571 L F
.509 .223 .415 r
.53322 .74571 m .5338 .74745 L .53426 .74544 L F
.53322 .74571 m .5312 .74791 L .5338 .74745 L F
.684 .201 .097 r
.48628 .78829 m .48943 .78892 L .48818 .78993 L F
.553 .042 0 r
.48818 .78993 m .48943 .78892 L .49125 .79017 L F
.536 .366 .598 r
.7088 .72051 m .71108 .72008 L .71084 .71767 L F
.298 .553 .923 r
.39539 .65033 m .39706 .65059 L .39634 .65182 L F
.456 .753 .993 r
.39706 .65059 m .39835 .65161 L .39634 .65182 L F
.941 .672 .499 r
.60516 .70395 m .60383 .70559 L .60372 .70337 L F
.9 .595 .46 r
.60516 .70395 m .60561 .70642 L .60383 .70559 L F
.513 .388 .647 r
.35681 .68505 m .35492 .6873 L .35466 .68501 L F
.726 .645 .768 r
.63867 .51713 m .63504 .51569 L .63735 .51343 L F
.63867 .51713 m .63638 .51774 L .63504 .51569 L F
.505 .427 .702 r
.63995 .51428 m .63867 .51713 L .63735 .51343 L F
.63995 .51428 m .64069 .51692 L .63867 .51713 L F
0 0 0 r
.30596 .72547 m .3083 .72287 L .30614 .72333 L F
.814 .631 .655 r
.61135 .66815 m .61132 .67101 L .61285 .67084 L F
.774 .48 .49 r
.61132 .67101 m .61139 .6729 L .61285 .67084 L F
.825 .552 .526 r
.61139 .6729 m .61436 .67348 L .61285 .67084 L F
.422 .197 .466 r
.31756 .62057 m .31963 .61813 L .31943 .6207 L F
.292 .04 .35 r
.31722 .62328 m .31756 .62057 L .31943 .6207 L F
.451 .176 .404 r
.40762 .69705 m .40592 .69574 L .40794 .69514 L F
.40762 .69705 m .40536 .69761 L .40592 .69574 L F
.681 .794 .935 r
.51923 .75615 m .51588 .75596 L .5184 .75559 L F
.463 .058 .186 r
.51923 .75615 m .51579 .75822 L .51588 .75596 L F
.51923 .75615 m .51826 .75805 L .51579 .75822 L F
.381 .788 .982 r
.52057 .75532 m .51923 .75615 L .5184 .75559 L F
.52057 .75532 m .52152 .75596 L .51923 .75615 L F
0 0 0 r
.52057 .75532 m .51923 .75615 L .52152 .75596 L F
.52057 .75532 m .51826 .75805 L .51923 .75615 L F
.532 .345 .572 r
.48525 .74771 m .48309 .75031 L .48294 .74825 L F
.288 0 .217 r
.56748 .67632 m .56927 .67587 L .57013 .67423 L F
.301 0 0 r
.56748 .67632 m .56868 .6774 L .56927 .67587 L F
.56748 .67632 m .5664 .67787 L .56868 .6774 L F
.399 .105 .346 r
.56927 .67587 m .57206 .67329 L .57013 .67423 L F
.377 0 0 r
.49364 .79047 m .49501 .79016 L .49715 .79087 L F
.529 0 0 r
.49501 .79016 m .4985 .79073 L .49715 .79087 L F
.581 .486 .712 r
.32019 .69595 m .32065 .69839 L .32238 .6955 L F
.469 .089 .236 r
.6467 .52999 m .64676 .52877 L .64901 .52956 L F
.47 .083 .224 r
.64676 .52877 m .64924 .52848 L .64901 .52956 L F
.02 .513 .873 r
.7353 .59379 m .73813 .59503 L .7379 .59449 L F
.06 .583 .872 r
.73813 .59503 m .74002 .59502 L .7379 .59449 L F
.73813 .59503 m .74118 .59559 L .74002 .59502 L F
.056 0 0 r
.34239 .65702 m .34042 .6576 L .33862 .65891 L F
.739 .77 .878 r
.72145 .71198 m .71904 .71292 L .71779 .71174 L F
.481 0 0 r
.55465 .70902 m .5533 .70876 L .5507 .70741 L F
0 .269 .668 r
.5507 .70741 m .5533 .70876 L .55197 .70797 L F
.786 .516 .529 r
.57441 .68198 m .57457 .68449 L .57786 .68467 L F
.6 .595 .818 r
.40554 .66822 m .4091 .671 L .40796 .66834 L F
.563 .53 .776 r
.4091 .671 m .40988 .66717 L .40796 .66834 L F
.4091 .671 m .41114 .67052 L .40988 .66717 L F
.544 .399 .634 r
.40913 .67295 m .41114 .67052 L .4091 .671 L F
.554 .665 .911 r
.42398 .65662 m .42382 .6595 L .42221 .65644 L F
.42398 .65662 m .42582 .65904 L .42382 .6595 L F
.921 .78 .688 r
.62204 .69253 m .62289 .69553 L .62352 .69331 L F
.243 0 0 r
.5811 .67778 m .57806 .67883 L .57977 .67689 L F
0 .415 .714 r
.39124 .64905 m .39539 .65033 L .39286 .64976 L F
.741 .649 .758 r
.63504 .51569 m .63638 .51774 L .6336 .51741 L F
.773 .641 .716 r
.63638 .51774 m .63283 .51954 L .6336 .51741 L F
.087 0 0 r
.37111 .67255 m .36921 .67323 L .37221 .67166 L F
.341 0 .155 r
.37404 .6709 m .37111 .67255 L .37221 .67166 L F
.278 .631 .963 r
.54093 .72021 m .54011 .72113 L .53898 .72043 L F
.54093 .72021 m .5428 .72154 L .54011 .72113 L F
.624 .38 .528 r
.58668 .67393 m .58449 .67623 L .58541 .67412 L F
.58668 .67393 m .58684 .67606 L .58449 .67623 L F
.257 0 0 r
.58915 .67562 m .58684 .67606 L .58668 .67393 L F
.204 0 .28 r
.50347 .7116 m .50526 .71144 L .50557 .7091 L F
.177 0 .142 r
.50347 .7116 m .50265 .71382 L .50526 .71144 L F
.655 .429 .564 r
.4776 .75054 m .47528 .75305 L .47576 .75061 L F
.51 .354 .604 r
.4289 .74802 m .43098 .75001 L .43099 .74758 L F
.4289 .74802 m .42885 .75053 L .43098 .75001 L F
.767 .673 .759 r
.46376 .64634 m .46027 .64638 L .46249 .64314 L F
.471 .844 .988 r
.4625 .64576 m .46027 .64638 L .46376 .64634 L F
.379 .454 .812 r
.46394 .64381 m .46376 .64634 L .46249 .64314 L F
.921 .92 .796 r
.46394 .64381 m .4625 .64576 L .46376 .64634 L F
.931 .563 .163 r
.72105 .60999 m .72195 .61061 L .72039 .60821 L F
.766 .723 .813 r
.72095 .60702 m .72195 .61061 L .72039 .60821 L F
.998 .792 .491 r
.72105 .60999 m .72195 .61061 L .72095 .60702 L F
.754 .605 .693 r
.69915 .58568 m .70124 .58289 L .69952 .58347 L F
.895 .865 .803 r
.63211 .53011 m .63328 .53116 L .63128 .53355 L F
0 0 .085 r
.6233 .70579 m .6223 .70856 L .62263 .7064 L F
.396 .618 .94 r
.42144 .65503 m .42051 .65653 L .41863 .65492 L F
.42144 .65503 m .42221 .65644 L .42051 .65653 L F
.597 .191 .244 r
.50033 .74625 m .49917 .74932 L .49665 .74726 L F
.715 .315 .289 r
.50128 .7495 m .50033 .74625 L .502 .748 L F
.50128 .7495 m .49917 .74932 L .50033 .74625 L F
.587 .436 .644 r
.50971 .72583 m .51196 .72288 L .50897 .72346 L F
.567 .47 .703 r
.32065 .69839 m .3227 .69803 L .32238 .6955 L F
.526 .391 .639 r
.32099 .70098 m .3227 .69803 L .32065 .69839 L F
.655 .353 .449 r
.46246 .73609 m .46593 .73352 L .46293 .73452 L F
.46246 .73609 m .46483 .73613 L .46593 .73352 L F
.582 .282 .425 r
.46483 .73613 m .46818 .73357 L .46593 .73352 L F
0 0 .386 r
.61881 .7196 m .61874 .72194 L .61731 .72314 L F
0 0 .387 r
.61874 .72194 m .61749 .72551 L .61731 .72314 L F
.259 0 0 r
.72997 .5935 m .7329 .59352 L .73192 .59382 L F
.436 0 0 r
.7329 .59352 m .7353 .59379 L .73192 .59382 L F
.446 .087 .261 r
.46013 .73629 m .46246 .73609 L .46293 .73452 L F
.467 .723 .981 r
.3256 .60308 m .32254 .60237 L .32464 .60243 L F
.508 .787 .995 r
.32762 .60246 m .3256 .60308 L .32464 .60243 L F
.659 .575 .75 r
.4066 .67379 m .40758 .67658 L .40996 .67632 L F
.607 .415 .597 r
.40758 .67658 m .40989 .67864 L .40996 .67632 L F
.40758 .67658 m .40749 .67896 L .40989 .67864 L F
.788 .381 0 r
.57882 .71677 m .57952 .71762 L .5785 .71586 L F
0 0 .351 r
.57932 .7164 m .57923 .71796 L .57882 .71677 L F
.852 .403 .134 r
.57917 .71905 m .57952 .71762 L .57882 .71677 L F
0 0 .351 r
.57923 .71796 m .57917 .71905 L .57882 .71677 L F
.788 .381 0 r
.57882 .71677 m .5785 .71586 L .57787 .71477 L F
.852 .403 .134 r
.57917 .71905 m .58141 .7206 L .57952 .71762 L F
.537 .32 .532 r
.43479 .67098 m .43463 .6732 L .43242 .67358 L F
.552 .379 .601 r
.43697 .66819 m .43698 .67059 L .43479 .67098 L F
.551 .342 .549 r
.43698 .67059 m .43463 .6732 L .43479 .67098 L F
.552 .379 .601 r
.43697 .66819 m .43698 .67059 L .43479 .67098 L F
.377 .104 .367 r
.31943 .6207 m .31963 .61813 L .32187 .6183 L F
.83 .356 .016 r
.54794 .70379 m .54656 .70314 L .54533 .70103 L F
.747 .226 0 r
.54991 .70589 m .54656 .70314 L .54794 .70379 L F
0 .086 .644 r
.46435 .76617 m .46438 .76701 L .463 .76394 L F
.906 .944 .586 r
.4629 .76875 m .46438 .76701 L .46435 .76617 L F
.864 .994 .815 r
.46435 .76617 m .46438 .76701 L .46666 .76435 L F
.638 .199 .191 r
.54032 .73669 m .54266 .73819 L .54456 .73692 L F
.911 .645 .523 r
.54266 .73819 m .5442 .73893 L .54456 .73692 L F
.337 .599 .943 r
.32313 .60106 m .32254 .60237 L .32127 .60083 L F
.409 .684 .974 r
.32313 .60106 m .32464 .60243 L .32254 .60237 L F
.496 .6 .886 r
.2934 .73414 m .29275 .73168 L .29045 .73234 L F
.2934 .73414 m .29394 .73415 L .29275 .73168 L F
.136 .094 .542 r
.61736 .728 m .6178 .73028 L .6162 .73154 L F
.077 .043 .513 r
.6178 .73028 m .6167 .73378 L .6162 .73154 L F
.91 .827 .753 r
.48898 .75323 m .48764 .7533 L .48883 .7506 L F
.603 .21 .271 r
.48898 .75323 m .48673 .75515 L .48764 .7533 L F
.48898 .75323 m .48944 .75514 L .48673 .75515 L F
.654 .499 .661 r
.49215 .75065 m .48898 .75323 L .48883 .7506 L F
.49215 .75065 m .49464 .75349 L .48898 .75323 L F
.198 0 .331 r
.49081 .75427 m .48898 .75323 L .49464 .75349 L F
.49081 .75427 m .48944 .75514 L .48898 .75323 L F
.824 .753 .785 r
.6057 .69255 m .60836 .69297 L .60644 .69565 L F
.98 .863 .649 r
.58695 .70974 m .58644 .7117 L .5873 .70943 L F
.824 .753 .785 r
.6057 .69255 m .60644 .69565 L .60551 .69498 L F
.955 .672 .461 r
.60644 .69565 m .60519 .69733 L .60551 .69498 L F
.60644 .69565 m .60667 .69818 L .60519 .69733 L F
.773 .457 .452 r
.48699 .75127 m .48496 .75291 L .48309 .75031 L F
.777 .464 .457 r
.48699 .75127 m .48764 .7533 L .48496 .75291 L F
.455 .285 .561 r
.48883 .7506 m .48764 .7533 L .48699 .75127 L F
.48883 .7506 m .48764 .7533 L .48699 .75127 L F
.83 .791 .815 r
.74294 .62722 m .74259 .62754 L .7395 .62798 L F
.74259 .62754 m .74025 .62962 L .73994 .62895 L F
.523 .27 .473 r
.74294 .62722 m .74276 .62922 L .74025 .62962 L F
.681 .726 .884 r
.7395 .62798 m .74025 .62962 L .7369 .62911 L F
.723 .493 .578 r
.74025 .62962 m .73775 .62962 L .7369 .62911 L F
.74025 .62962 m .74042 .63204 L .73775 .62962 L F
.554 .366 .58 r
.74276 .62922 m .74042 .63204 L .74025 .62962 L F
.655 .505 .668 r
.73948 .62948 m .74042 .63204 L .74276 .62922 L F
.73775 .62962 m .73865 .63043 L .73948 .62948 L F
.73865 .63043 m .74042 .63204 L .73948 .62948 L F
.83 .791 .815 r
.74033 .6285 m .73994 .62895 L .73983 .62871 L F
.74259 .62754 m .73994 .62895 L .74033 .6285 L F
.74259 .62754 m .73983 .62871 L .7395 .62798 L F
.74168 .6275 m .7395 .62798 L .74175 .62788 L F
.9 .684 .601 r
.74294 .62722 m .74175 .62788 L .741 .62372 L F
.841 .648 .641 r
.741 .62372 m .74175 .62788 L .73813 .62552 L F
.745 .7 .809 r
.74175 .62788 m .7395 .62798 L .73813 .62552 L F
.306 .78 .675 r
.74286 .62733 m .73823 .62935 L .73812 .62941 L F
.73933 .6289 m .73812 .62941 L .7379 .62954 L F
.74286 .62733 m .73812 .62941 L .73933 .6289 L F
.73869 .6292 m .7379 .62954 L .73775 .62962 L F
.74286 .62733 m .7379 .62954 L .73869 .6292 L F
.358 .135 .432 r
.74487 .62646 m .74276 .62922 L .74294 .62722 L F
.391 .81 .973 r
.46186 .77734 m .46103 .7781 L .45978 .77707 L F
.46186 .77734 m .46319 .77778 L .46103 .7781 L F
.451 .274 .55 r
.29339 .62353 m .29504 .62116 L .29441 .62183 L F
.29339 .62353 m .29536 .62293 L .29504 .62116 L F
.379 .178 .477 r
.29256 .62632 m .29536 .62293 L .29339 .62353 L F
.864 .675 .646 r
.62048 .68692 m .62189 .68999 L .62216 .68763 L F
.212 0 0 r
.36357 .6492 m .36543 .64949 L .36703 .64915 L F
.434 .871 .904 r
.36543 .64949 m .3691 .64889 L .36703 .64915 L F
.655 .429 .564 r
.4776 .75054 m .47787 .75312 L .47528 .75305 L F
.458 .287 .561 r
.47967 .75251 m .4776 .75054 L .48022 .75058 L F
.47967 .75251 m .47787 .75312 L .4776 .75054 L F
.499 .029 .071 r
.53325 .79458 m .53428 .79623 L .53203 .79387 L F
.53325 .79458 m .53583 .79476 L .53428 .79623 L F
.486 .334 .599 r
.32663 .67379 m .32856 .67569 L .32864 .6733 L F
.32663 .67379 m .32669 .67618 L .32856 .67569 L F
.169 .652 .925 r
.27949 .60348 m .28031 .60295 L .27816 .60325 L F
.555 .305 .492 r
.65446 .52526 m .65212 .5273 L .65221 .52551 L F
.602 .066 0 r
.52536 .78932 m .52634 .78897 L .52317 .78837 L F
.468 .094 .247 r
.52759 .79076 m .52634 .78897 L .52536 .78932 L F
.52759 .79076 m .52862 .78873 L .52634 .78897 L F
.075 .316 .797 r
.52719 .75393 m .52925 .75532 L .52773 .75252 L F
.637 .369 .497 r
.5065 .72813 m .50997 .72775 L .50971 .72583 L F
.587 .436 .644 r
.50971 .72583 m .51201 .72557 L .51196 .72288 L F
.69 .502 .628 r
.50997 .72775 m .51201 .72557 L .50971 .72583 L F
.239 .634 .959 r
.73903 .58662 m .73629 .58555 L .73849 .58537 L F
.355 .649 .966 r
.74152 .58601 m .73903 .58662 L .73849 .58537 L F
.74152 .58601 m .74244 .5873 L .73903 .58662 L F
.41 .225 .516 r
.41225 .66191 m .41023 .66516 L .41 .66248 L F
.41225 .66191 m .41023 .66516 L .41 .66248 L F
.223 0 .307 r
.35498 .68967 m .35281 .69249 L .35348 .69048 L F
.518 .443 .711 r
.52513 .73385 m .5223 .73122 L .52469 .73058 L F
.52513 .73385 m .52297 .73574 L .5223 .73122 L F
.799 .704 .76 r
.51846 .7011 m .51651 .70419 L .51781 .70299 L F
.375 0 .189 r
.51651 .70419 m .51763 .70556 L .51781 .70299 L F
.471 .348 .631 r
.51846 .7011 m .52065 .70305 L .51781 .70299 L F
.441 .089 .27 r
.51781 .70299 m .51968 .70517 L .52065 .70305 L F
.51781 .70299 m .51763 .70556 L .51968 .70517 L F
.644 .831 .972 r
.71957 .71107 m .72145 .71198 L .71779 .71174 L F
.257 .68 .964 r
.71957 .71107 m .72264 .71132 L .72145 .71198 L F
.22 .604 .95 r
.72264 .71132 m .72393 .71248 L .72145 .71198 L F
.789 .711 .778 r
.57457 .68449 m .57565 .68745 L .57786 .68467 L F
.932 .651 .486 r
.60507 .68412 m .60325 .68394 L .60303 .68142 L F
.963 .769 .595 r
.60419 .68696 m .60325 .68394 L .60507 .68412 L F
.634 .565 .759 r
.70615 .60312 m .70854 .60217 L .70557 .60093 L F
.541 .499 .759 r
.52734 .73565 m .52297 .73574 L .52513 .73385 L F
.52734 .73565 m .52353 .73684 L .52297 .73574 L F
.893 .86 .8 r
.74596 .61387 m .74428 .61655 L .74292 .6156 L F
.872 .739 .713 r
.74428 .61655 m .74174 .61751 L .74292 .6156 L F
.74428 .61655 m .74335 .61854 L .74174 .61751 L F
.778 .781 .855 r
.4667 .75102 m .46453 .75334 L .46886 .7527 L F
.4667 .75102 m .46411 .75328 L .46453 .75334 L F
.614 .253 .334 r
.71139 .57982 m .71485 .57978 L .71476 .57839 L F
.581 .228 .336 r
.71476 .57839 m .71485 .57978 L .7172 .57947 L F
.952 .644 .413 r
.59975 .6762 m .5984 .67586 L .59804 .67337 L F
.764 .463 .476 r
.59975 .6762 m .59783 .6781 L .5984 .67586 L F
.59975 .6762 m .60108 .67876 L .59783 .6781 L F
.857 .483 .339 r
.60273 .67907 m .60108 .67876 L .59975 .6762 L F
.202 .701 .913 r
.29206 .59545 m .29395 .59542 L .29547 .59586 L F
.045 .61 .779 r
.29395 .59542 m .2976 .59563 L .29547 .59586 L F
.708 .708 .847 r
.35361 .86637 m .35209 .869 L .35373 .86692 L F
.354 .214 .549 r
.35373 .86692 m .35209 .869 L .35387 .87026 L F
.089 .646 .709 r
.40554 .66822 m .40424 .66837 L .40209 .66863 L F
.268 .669 .968 r
.40554 .66822 m .40677 .66756 L .40424 .66837 L F
.40554 .66822 m .40796 .66834 L .40677 .66756 L F
.553 .534 .788 r
.57148 .76181 m .57234 .76212 L .57088 .75923 L F
.976 .784 .579 r
.57242 .76432 m .57234 .76212 L .57148 .76181 L F
0 0 .347 r
.57197 .76159 m .57219 .76283 L .57148 .76181 L F
.572 .76158 m .57203 .76179 L .57197 .76159 L F
.57203 .76179 m .57219 .76283 L .57197 .76159 L F
.57219 .76283 m .57224 .76385 L .57148 .76181 L F
.901 .661 .566 r
.57216 .76221 m .57117 .76494 L .56936 .76358 L F
.57234 .76212 m .57222 .76241 L .57216 .76221 L F
.57222 .76241 m .57117 .76494 L .57216 .76221 L F
.47 .478 .784 r
.572 .76158 m .57148 .76181 L .57088 .75923 L F
.901 .661 .566 r
.57215 .76199 m .56936 .76358 L .5699 .76044 L F
.57234 .76212 m .57216 .76221 L .57215 .76199 L F
.57216 .76221 m .56936 .76358 L .57215 .76199 L F
0 0 .347 r
.57219 .76283 m .57242 .76432 L .57224 .76385 L F
.955 .644 .402 r
.572 .76158 m .57234 .76212 L .57222 .76204 L F
.57183 .76111 m .57234 .76212 L .572 .76158 L F
0 0 .347 r
.57389 .76076 m .57272 .76359 L .572 .76158 L F
.57218 .7621 m .57242 .76432 L .572 .76158 L F
.976 .784 .579 r
.57242 .76432 m .57117 .76494 L .57222 .76241 L F
.57242 .76432 m .57222 .76241 L .57234 .76212 L F
0 0 .347 r
.57272 .76359 m .57242 .76432 L .57218 .7621 L F
.955 .644 .402 r
.57088 .75923 m .57183 .76111 L .572 .76158 L F
.57088 .75923 m .57222 .76204 L .5699 .76044 L F
.47 .478 .784 r
.57389 .76076 m .572 .76158 L .57088 .75923 L F
.483 .352 .626 r
.53424 .78867 m .53645 .79073 L .53749 .78832 L F
.904 .842 .385 r
.53832 .7907 m .53749 .78832 L .53986 .79104 L F
.495 .305 .552 r
.53832 .7907 m .53792 .7942 L .53583 .79476 L F
.026 0 .374 r
.53884 .79288 m .53832 .7907 L .53986 .79104 L F
.53884 .79288 m .53792 .7942 L .53832 .7907 L F
.733 .369 .361 r
.53645 .79073 m .53986 .79104 L .53749 .78832 L F
.646 .087 0 r
.25856 .58809 m .25961 .58847 L .25935 .58826 L F
.893 .86 .8 r
.74596 .61387 m .74292 .6156 L .74519 .61302 L F
.091 0 0 r
.52734 .73565 m .52505 .73659 L .52353 .73684 L F
.568 .435 .659 r
.52609 .73941 m .52353 .73684 L .52505 .73659 L F
.52609 .73941 m .52386 .73992 L .52353 .73684 L F
.578 .452 .673 r
.42698 .75333 m .42924 .753 L .42885 .75053 L F
.522 .349 .587 r
.42698 .75333 m .42907 .75534 L .42924 .753 L F
.42698 .75333 m .42699 .75574 L .42907 .75534 L F
.322 0 .085 r
.38128 .70122 m .38205 .70271 L .38312 .70054 L F
.591 .835 .991 r
.73722 .73247 m .73873 .73087 L .73605 .7314 L F
.73722 .73247 m .73977 .7318 L .73873 .73087 L F
.538 0 0 r
.50867 .7924 m .50936 .79215 L .5117 .79362 L F
.554 .392 .615 r
.4229 .76139 m .42508 .76113 L .42511 .75864 L F
.592 .476 .69 r
.4229 .76139 m .42573 .76396 L .42508 .76113 L F
.4229 .76139 m .42351 .76439 L .42573 .76396 L F
.372 0 0 r
.46563 .78631 m .46428 .78664 L .46217 .7863 L F
.195 0 0 r
.46563 .78631 m .46656 .78671 L .46428 .78664 L F
.46563 .78631 m .46778 .78649 L .46656 .78671 L F
.69 .433 .53 r
.54526 .75887 m .54518 .76141 L .54308 .76006 L F
.559 .282 .452 r
.5485 .7588 m .54518 .76141 L .54526 .75887 L F
.793 .704 .767 r
.43924 .66547 m .4359 .66559 L .43785 .66464 L F
.43924 .66547 m .43697 .66819 L .4359 .66559 L F
.571 .377 .58 r
.43924 .66547 m .43905 .66825 L .43697 .66819 L F
0 0 .309 r
.4402 .66574 m .43924 .66547 L .43785 .66464 L F
.4402 .66574 m .43905 .66825 L .43924 .66547 L F
.431 .237 .515 r
.45272 .76077 m .45099 .75876 L .45299 .75867 L F
.45272 .76077 m .45094 .76147 L .45099 .75876 L F
.702 .943 .65 r
.32981 .7218 m .32924 .72187 L .33117 .72004 L F
.907 .596 .447 r
.60303 .68142 m .60108 .67876 L .60273 .67907 L F
0 0 .378 r
.60322 .71456 m .6041 .71134 L .60477 .7127 L F
0 .243 .643 r
.72239 .57965 m .72357 .58034 L .7201 .57839 L F
0 0 .332 r
.30715 .71727 m .30699 .72117 L .30789 .71824 L F
.605 .564 .782 r
.30657 .72136 m .3083 .72287 L .30699 .72117 L F
0 0 .332 r
.30699 .72117 m .30698 .72132 L .30702 .72115 L F
.605 .564 .782 r
.30513 .7201 m .30657 .72136 L .30699 .72117 L F
.57 .36 .557 r
.30513 .7201 m .30699 .72117 L .30715 .71727 L F
.605 .564 .782 r
.30513 .7201 m .3074 .72141 L .30737 .72135 L F
.57 .36 .557 r
.30513 .7201 m .30698 .72132 L .30699 .72117 L F
.491 .389 .667 r
.30513 .7201 m .30702 .72115 L .30698 .72132 L F
.605 .564 .782 r
.30699 .72117 m .3083 .72287 L .3074 .72141 L F
.491 .389 .667 r
.30702 .72115 m .30737 .72135 L .30698 .72132 L F
0 0 .332 r
.30702 .72115 m .30698 .72132 L .30703 .72115 L F
.30699 .72117 m .30703 .72115 L .30789 .71824 L F
.599 .575 .798 r
.30715 .71727 m .30989 .71718 L .30939 .71569 L F
0 0 .332 r
.30715 .71727 m .30789 .71824 L .30989 .71718 L F
.599 .575 .798 r
.30715 .71727 m .30989 .71718 L .30939 .71569 L F
.814 .338 0 r
.54533 .70103 m .54536 .70237 L .54341 .70009 L F
.54533 .70103 m .54656 .70314 L .54536 .70237 L F
.479 .145 .321 r
.59008 .66515 m .59215 .66493 L .59326 .66252 L F
.656 .329 .408 r
.59326 .66252 m .59215 .66493 L .59562 .66426 L F
.657 .328 .405 r
.59326 .66252 m .59562 .66426 L .59563 .66282 L F
.072 .031 .5 r
.71084 .71767 m .71108 .72008 L .71246 .71893 L F
.4 .744 .993 r
.28681 .59337 m .28637 .59443 L .28492 .59367 L F
.28681 .59337 m .28836 .59424 L .28637 .59443 L F
.489 .166 .344 r
.39843 .70399 m .39565 .70591 L .39647 .70455 L F
0 0 0 r
.38211 .71366 m .38373 .71234 L .38569 .71158 L F
.435 .478 .806 r
.74477 .7176 m .74776 .71899 L .74575 .72049 L F
.367 .353 .711 r
.74776 .71899 m .74803 .72248 L .74575 .72049 L F
.387 .355 .701 r
.74575 .72049 m .74803 .72248 L .74654 .7227 L F
0 .057 .616 r
.32189 .7198 m .32311 .72295 L .32522 .7203 L F
0 .187 .719 r
.7277 .62437 m .72931 .62508 L .72659 .62359 L F
.7277 .62437 m .73009 .62677 L .72931 .62508 L F
.466 .555 .863 r
.36286 .70308 m .36225 .70555 L .36085 .7033 L F
.36286 .70308 m .36429 .70574 L .36225 .70555 L F
.425 .113 .331 r
.42675 .68074 m .42519 .67961 L .42717 .67923 L F
.42675 .68074 m .42462 .68123 L .42519 .67961 L F
.437 .657 .953 r
.43415 .78622 m .43532 .78496 L .43287 .78513 L F
.43415 .78622 m .43617 .78621 L .43532 .78496 L F
.495 .536 .828 r
.35951 .70023 m .35891 .70332 L .35746 .7006 L F
.35951 .70023 m .36085 .7033 L .35891 .70332 L F
.414 .628 .942 r
.74033 .71027 m .73894 .71162 L .73671 .70962 L F
.74033 .71027 m .74046 .71138 L .73894 .71162 L F
.566 .314 .493 r
.50465 .72876 m .50681 .73052 L .5065 .72813 L F
.50465 .72876 m .50423 .73088 L .50681 .73052 L F
.474 0 0 r
.4651 .77809 m .4688 .77765 L .46684 .77841 L F
.408 .25 .552 r
.31528 .62848 m .31281 .62731 L .31524 .6262 L F
.31528 .62848 m .31283 .62957 L .31281 .62731 L F
.454 .299 .58 r
.58986 .73959 m .59125 .74012 L .59005 .74235 L F
.803 .796 .846 r
.72513 .58853 m .72826 .58824 L .72764 .5898 L F
.951 .602 .289 r
.72826 .58824 m .72939 .59126 L .72764 .5898 L F
.813 .639 .666 r
.61936 .68147 m .6207 .68454 L .62114 .68222 L F
.715 .507 .606 r
.31526 .71707 m .31842 .71487 L .31489 .71453 L F
.31526 .71707 m .31835 .71751 L .31842 .71487 L F
.328 .741 .979 r
.31842 .71487 m .31969 .71471 L .31999 .71434 L F
.311 0 .039 r
.48628 .72821 m .48844 .72779 L .48967 .72609 L F
.328 0 .083 r
.48844 .72779 m .49181 .72551 L .48967 .72609 L F
.616 .237 .301 r
.72064 .72457 m .72321 .72484 L .72356 .72305 L F
.267 0 .211 r
.72356 .72305 m .72518 .72408 L .72262 .72215 L F
.72356 .72305 m .72321 .72484 L .72518 .72408 L F
.822 .638 .653 r
.60798 .67015 m .61135 .66815 L .6081 .66775 L F
.60798 .67015 m .61132 .67101 L .61135 .66815 L F
.498 .239 .452 r
.5827 .70693 m .58463 .70878 L .58505 .70621 L F
.474 .501 .806 r
.58505 .70621 m .58463 .70878 L .5827 .70693 L F
.188 0 .224 r
.50557 .7091 m .50749 .7086 L .50819 .70615 L F
0 0 .132 r
.50819 .70615 m .50893 .70738 L .51065 .70577 L F
.50819 .70615 m .50749 .7086 L .50893 .70738 L F
.805 .768 .819 r
.71163 .58227 m .70913 .58574 L .70705 .58509 L F
.71242 .58179 m .7115 .58289 L .71163 .58227 L F
.7115 .58289 m .70913 .58574 L .71163 .58227 L F
.581 .546 .78 r
.71206 .58023 m .71286 .58319 L .715 .58201 L F
.71139 .57982 m .7119 .58099 L .71206 .58023 L F
.805 .768 .819 r
.7125 .58173 m .71243 .58181 L .71242 .58179 L F
.71243 .58181 m .70913 .58574 L .71242 .58179 L F
.718 .531 .636 r
.71024 .58104 m .70767 .58296 L .70799 .58036 L F
.7125 .58173 m .71142 .58201 L .71024 .58104 L F
.71142 .58201 m .70767 .58296 L .71024 .58104 L F
.805 .768 .819 r
.7125 .58173 m .70705 .58509 L .70767 .58296 L F
.581 .546 .78 r
.7119 .58099 m .71285 .58318 L .71206 .58023 L F
.71285 .58318 m .71286 .58319 L .71285 .58318 L F
.71285 .58318 m .71285 .58318 L .71206 .58023 L F
.954 .613 .23 r
.71172 .58175 m .71286 .58319 L .7119 .58099 L F
.71148 .58034 m .7119 .58099 L .71139 .57982 L F
.71172 .58175 m .7119 .58099 L .71148 .58034 L F
.827 .745 .773 r
.70705 .58509 m .70913 .58574 L .70795 .58739 L F
.533 .682 .934 r
.29082 .60675 m .29222 .60862 L .29387 .60817 L F
.387 .836 .929 r
.51262 .79375 m .51383 .79299 L .5117 .79362 L F
.51262 .79375 m .51481 .79322 L .51383 .79299 L F
.343 .678 .978 r
.31392 .70958 m .31466 .71026 L .31158 .70935 L F
.44 .264 .545 r
.31158 .70935 m .3133 .71009 L .31392 .70958 L F
.31158 .70935 m .31121 .71203 L .3133 .71009 L F
.463 .234 .48 r
.43242 .67358 m .43211 .67586 L .43012 .67625 L F
.487 .237 .461 r
.43463 .6732 m .43211 .67586 L .43242 .67358 L F
.86 .527 .421 r
.7137 .72183 m .71187 .72219 L .71108 .72008 L F
.075 0 0 r
.7137 .72183 m .71619 .72188 L .71464 .72187 L F
.615 .402 .57 r
.4023 .68408 m .405 .68121 L .40255 .68188 L F
.892 .499 .273 r
.72183 .72086 m .72095 .72131 L .71928 .71955 L F
.318 .794 .71 r
.52107 .74012 m .51818 .74125 L .51816 .73964 L F
.52107 .74012 m .52068 .74026 L .51818 .74125 L F
.646 .109 0 r
.52107 .74012 m .52338 .74176 L .52068 .74026 L F
.597 .282 .407 r
.52386 .73992 m .52338 .74176 L .52107 .74012 L F
.154 0 0 r
.3802 .66785 m .38254 .66755 L .38176 .66757 L F
0 0 0 r
.38517 .66749 m .38176 .66757 L .38254 .66755 L F
.758 .386 .349 r
.59804 .67337 m .59441 .67126 L .59831 .67104 L F
.362 .534 .891 r
.31968 .59844 m .31892 .6001 L .31787 .59835 L F
.31968 .59844 m .32127 .60083 L .31892 .6001 L F
.597 .034 0 r
.48396 .78149 m .48477 .78145 L .48122 .78018 L F
0 .386 .786 r
.48213 .7803 m .48396 .78149 L .48279 .78093 L F
.48213 .7803 m .48279 .78093 L .48122 .78018 L F
.732 .204 0 r
.48137 .77958 m .48213 .7803 L .48119 .77839 L F
.48166 .78147 m .48213 .7803 L .48137 .77958 L F
0 0 .543 r
.48213 .7803 m .48307 .78153 L .48396 .78149 L F
.48307 .78153 m .48368 .78233 L .48396 .78149 L F
.597 .034 0 r
.48396 .78149 m .48486 .78148 L .48477 .78145 L F
.967 .77 .586 r
.48396 .78149 m .48468 .78344 L .48486 .78148 L F
.766 .675 .762 r
.48688 .78056 m .48468 .78344 L .48486 .78148 L F
.362 .137 .433 r
.33278 .66247 m .33042 .66528 L .33266 .66487 L F
.515 .347 .592 r
.33042 .66528 m .33258 .66729 L .33266 .66487 L F
.33042 .66528 m .33047 .66776 L .33258 .66729 L F
.233 .366 .794 r
.57653 .73722 m .57777 .7401 L .5787 .73872 L F
0 0 .292 r
.57888 .74208 m .5787 .73872 L .57777 .7401 L F
.814 .526 .501 r
.44669 .74062 m .44925 .74191 L .44964 .7399 L F
.491 .153 .322 r
.44925 .74191 m .45249 .73935 L .44964 .7399 L F
.654 .499 .661 r
.49215 .75065 m .48883 .7506 L .4908 .74966 L F
.698 .835 .948 r
.49365 .74977 m .49215 .75065 L .4908 .74966 L F
.848 .436 .256 r
.49271 .75257 m .49464 .75349 L .49215 .75065 L F
.49271 .75257 m .49215 .75065 L .49365 .74977 L F
.633 .105 0 r
.72312 .58144 m .72635 .58204 L .72372 .58043 L F
.242 0 0 r
.3691 .64889 m .37131 .64904 L .37257 .64863 L F
.003 0 0 r
.37131 .64904 m .37472 .64802 L .37257 .64863 L F
0 0 0 r
.71599 .71307 m .71259 .71563 L .71472 .71418 L F
.818 .689 .722 r
.30652 .72849 m .30462 .72843 L .30596 .72547 L F
.761 .398 .366 r
.30652 .72849 m .30582 .73041 L .30462 .72843 L F
0 0 0 r
.30999 .72663 m .30818 .72811 L .30652 .72849 L F
.109 0 .106 r
.30818 .72811 m .30582 .73041 L .30652 .72849 L F
.554 .588 .843 r
.42775 .65869 m .42715 .66197 L .42582 .65904 L F
.42775 .65869 m .42919 .66151 L .42715 .66197 L F
.045 0 0 r
.4985 .79073 m .50051 .79068 L .49715 .79087 L F
.325 0 .228 r
.37025 .6749 m .36921 .67323 L .37111 .67255 L F
.37025 .6749 m .36833 .67548 L .36921 .67323 L F
.208 0 .281 r
.50557 .7091 m .50526 .71144 L .50749 .7086 L F
.605 .087 0 r
.5526 .72814 m .55493 .72901 L .556 .72854 L F
.721 .254 0 r
.55668 .73011 m .556 .72854 L .55493 .72901 L F
.324 0 0 r
.55609 .73008 m .55637 .73017 L .55668 .73011 L F
.721 .254 0 r
.55668 .73011 m .55769 .73108 L .557 .73004 L F
.836 .417 .24 r
.556 .72854 m .55769 .73108 L .55934 .73135 L F
.3 .552 .922 r
.56008 .73143 m .55759 .73071 L .55668 .73011 L F
.324 0 0 r
.55637 .73017 m .56008 .73143 L .55668 .73011 L F
.721 .254 0 r
.55668 .73011 m .557 .73004 L .556 .72854 L F
.569 .645 .886 r
.43697 .66819 m .43369 .66644 L .4359 .66559 L F
.572 .396 .604 r
.43905 .66825 m .43698 .67059 L .43697 .66819 L F
.43905 .66825 m .43698 .67059 L .43697 .66819 L F
.505 .487 .771 r
.3138 .7226 m .31499 .72591 L .31693 .72486 L F
.629 .881 .988 r
.31529 .72839 m .31693 .72486 L .31499 .72591 L F
.898 .479 .118 r
.62266 .69859 m .62328 .70011 L .62457 .70087 L F
.973 .819 .63 r
.62272 .70263 m .62457 .70087 L .62328 .70011 L F
.62272 .70263 m .62373 .70329 L .62457 .70087 L F
.687 .541 .682 r
.69586 .58548 m .69915 .58568 L .69952 .58347 L F
0 0 .177 r
.49989 .73222 m .49874 .73171 L .50119 .73058 L F
.49989 .73222 m .49832 .73393 L .49874 .73171 L F
.586 .861 .995 r
.31069 .59675 m .31022 .59799 L .30859 .59696 L F
.31069 .59675 m .31207 .59748 L .31022 .59799 L F
.382 0 0 r
.50051 .79068 m .50396 .7908 L .50274 .79078 L F
.272 0 0 r
.50396 .7908 m .50503 .79128 L .50274 .79078 L F
.50396 .7908 m .50632 .79095 L .50503 .79128 L F
.584 .428 .636 r
.51544 .73964 m .51816 .73964 L .51563 .74205 L F
.758 .386 .349 r
.59804 .67337 m .5949 .67307 L .59441 .67126 L F
.7 .788 .919 r
.54473 .73182 m .54849 .73217 L .547 .73127 L F
.618 .122 .053 r
.55015 .73171 m .547 .73127 L .54849 .73217 L F
.278 .755 .933 r
.50472 .78668 m .50283 .78687 L .50152 .78645 L F
.386 .086 .329 r
.29009 .62917 m .29256 .62632 L .2904 .62755 L F
.619 .271 .357 r
.5979 .66463 m .59927 .66232 L .59563 .66282 L F
.653 .309 .377 r
.5979 .66463 m .60128 .6643 L .59927 .66232 L F
.692 .293 .287 r
.59927 .66232 m .60128 .6643 L .6011 .66292 L F
.191 .719 .843 r
.27955 .65538 m .27975 .65501 L .27777 .65521 L F
.27955 .65538 m .28302 .65492 L .27975 .65501 L F
.467 .232 .473 r
.64573 .53137 m .64413 .5305 L .6467 .52999 L F
.99 .729 .393 r
.70705 .58509 m .70795 .58739 L .70689 .58552 L F
.939 .838 .718 r
.70777 .58756 m .70527 .59001 L .70689 .58552 L F
.711 .774 .284 r
.70689 .58552 m .70527 .59001 L .70545 .5894 L F
.70623 .5872 m .70545 .5894 L .70568 .58861 L F
.70689 .58552 m .70545 .5894 L .70623 .5872 L F
.939 .838 .718 r
.70795 .58739 m .70777 .58756 L .70689 .58552 L F
.513 .378 .634 r
.70652 .58729 m .70861 .5837 L .7075 .58365 L F
.711 .774 .284 r
.70646 .58662 m .70568 .58861 L .70652 .58729 L F
.993 .746 .393 r
.7062 .58391 m .70689 .58552 L .70652 .58729 L F
.70617 .5836 m .70689 .58552 L .7062 .58391 L F
.963 .852 .684 r
.70767 .58296 m .70705 .58509 L .70617 .5836 L F
.993 .746 .393 r
.70617 .5836 m .70705 .58509 L .70689 .58552 L F
.513 .378 .634 r
.70646 .58658 m .7075 .58365 L .70617 .5836 L F
.70652 .58729 m .7075 .58365 L .70646 .58658 L F
.939 .838 .718 r
.70795 .58739 m .70647 .59113 L .70527 .59001 L F
.227 0 .026 r
.55913 .68183 m .56141 .68115 L .56234 .67934 L F
0 0 0 r
.56234 .67934 m .56311 .68011 L .56463 .67877 L F
.56234 .67934 m .56141 .68115 L .56311 .68011 L F
.246 .706 .95 r
.51182 .7884 m .50868 .78777 L .51046 .78849 L F
0 0 0 r
.51396 .78826 m .51182 .7884 L .51046 .78849 L F
.228 .728 .907 r
.55769 .73108 m .55759 .73071 L .55934 .73135 L F
0 .3 .768 r
.55934 .73135 m .56212 .73297 L .56276 .73388 L F
0 .306 .796 r
.56039 .73267 m .56265 .73517 L .56212 .73297 L F
0 .192 .659 r
.56209 .73366 m .56039 .73267 L .56026 .73213 L F
.827 .432 .302 r
.5597 .73176 m .56212 .73297 L .55876 .73113 L F
.55759 .73071 m .56039 .73267 L .56212 .73297 L F
0 .192 .659 r
.5614 .7329 m .56026 .73213 L .56008 .73143 L F
.56209 .73366 m .56026 .73213 L .5614 .7329 L F
.827 .432 .302 r
.55876 .73113 m .56212 .73297 L .55934 .73135 L F
.55759 .73071 m .5597 .73176 L .55876 .73113 L F
.535 .266 .453 r
.43197 .67811 m .43012 .67625 L .43211 .67586 L F
.43197 .67811 m .42943 .67885 L .43012 .67625 L F
0 0 .058 r
.71837 .59389 m .71905 .59011 L .71736 .59325 L F
.652 .344 .438 r
.72153 .59618 m .71837 .59389 L .71736 .59325 L F
.72153 .59618 m .72051 .59417 L .71837 .59389 L F
.391 .639 .955 r
.3963 .66614 m .39714 .66494 L .39507 .66515 L F
.3963 .66614 m .39937 .66677 L .39714 .66494 L F
.52 .145 .269 r
.51289 .70631 m .51537 .70621 L .51651 .70419 L F
.375 0 .189 r
.51651 .70419 m .51537 .70621 L .51763 .70556 L F
.642 .343 .448 r
.55654 .75753 m .55335 .75645 L .55602 .75465 L F
.55654 .75753 m .55298 .75827 L .55335 .75645 L F
.004 0 0 r
.4667 .75102 m .46562 .7527 L .46411 .75328 L F
.077 0 .321 r
.46562 .7527 m .4638 .7555 L .46411 .75328 L F
.836 .569 .535 r
.55937 .69429 m .56262 .69257 L .55929 .69188 L F
.55937 .69429 m .56399 .69611 L .56262 .69257 L F
.482 .394 .679 r
.56262 .69257 m .56399 .69611 L .5645 .69214 L F
0 0 .418 r
.56262 .69257 m .5638 .69465 L .5645 .69214 L F
.56262 .69257 m .56399 .69611 L .5638 .69465 L F
.938 .571 .268 r
.49471 .74805 m .49332 .74738 L .49259 .74496 L F
.591 .88 .993 r
.49665 .74726 m .49332 .74738 L .49471 .74805 L F
.064 .607 .846 r
.2976 .59563 m .29954 .59581 L .30112 .59625 L F
.143 .663 .886 r
.29954 .59581 m .30306 .59631 L .30112 .59625 L F
.513 .309 .541 r
.39588 .69022 m .39798 .6898 L .39816 .68737 L F
.538 .439 .69 r
.39816 .68737 m .40017 .68702 L .3999 .68438 L F
.387 .205 .509 r
.39816 .68737 m .39978 .68904 L .40017 .68702 L F
.39816 .68737 m .39798 .6898 L .39978 .68904 L F
.679 .24 .201 r
.73125 .72208 m .73367 .72406 L .73503 .72254 L F
.368 .703 .985 r
.73503 .72254 m .7363 .72159 L .7339 .71972 L F
.73503 .72254 m .73712 .72254 L .7363 .72159 L F
0 0 0 r
.73503 .72254 m .7363 .72159 L .73712 .72254 L F
.73503 .72254 m .73367 .72406 L .7363 .72159 L F
.933 .784 .673 r
.62204 .69253 m .622 .69567 L .62289 .69553 L F
.892 .608 .098 r
.622 .69567 m .62266 .69859 L .62289 .69553 L F
.37 .441 .803 r
.52692 .72866 m .52469 .73058 L .52431 .72859 L F
0 0 0 r
.3606 .72383 m .36033 .72341 L .36218 .72242 L F
.3606 .72383 m .359 .72512 L .36033 .72341 L F
.465 .231 .473 r
.327 .61035 m .32677 .61208 L .32459 .61313 L F
.571 .459 .687 r
.32881 .60747 m .32908 .60994 L .327 .61035 L F
.483 .23 .455 r
.32908 .60994 m .32677 .61208 L .327 .61035 L F
.319 .723 .979 r
.72695 .72867 m .7237 .72789 L .72469 .7287 L F
.706 .651 .793 r
.32287 .70677 m .32367 .70342 L .32138 .7039 L F
.454 .235 .491 r
.5743 .69281 m .57165 .69544 L .57157 .69339 L F
.5743 .69281 m .57389 .69494 L .57165 .69544 L F
.448 .341 .64 r
.57416 .69771 m .57165 .69544 L .57389 .69494 L F
.57416 .69771 m .57162 .69923 L .57165 .69544 L F
.659 .575 .75 r
.4066 .67379 m .40996 .67632 L .40913 .67295 L F
.943 .581 .273 r
.60433 .72841 m .60309 .72765 L .60332 .72622 L F
0 .044 .61 r
.60394 .72434 m .6043 .72416 L .6042 .724 L F
.60394 .72434 m .60281 .72188 L .60386 .72313 L F
.60394 .72434 m .6042 .724 L .60281 .72188 L F
.274 .773 .741 r
.60213 .72485 m .60417 .7242 L .60394 .72434 L F
.60417 .7242 m .6043 .72416 L .60394 .72434 L F
0 0 .092 r
.60386 .72313 m .60362 .72453 L .60394 .72434 L F
.60362 .72453 m .60356 .72483 L .60394 .72434 L F
.60356 .72483 m .60332 .72622 L .60394 .72434 L F
0 0 0 r
.60332 .72622 m .60309 .72765 L .60394 .72434 L F
.491 .153 .322 r
.44925 .74191 m .45147 .74165 L .45249 .73935 L F
.544 .207 .348 r
.45249 .73935 m .45383 .74135 L .45485 .73935 L F
.45249 .73935 m .45147 .74165 L .45383 .74135 L F
.498 .114 .242 r
.45852 .75636 m .45581 .75788 L .45614 .75594 L F
.596 .328 .48 r
.36428 .67894 m .36153 .68085 L .36203 .67927 L F
.39 .724 .989 r
.31634 .59724 m .31585 .59843 L .31426 .59751 L F
.31634 .59724 m .31787 .59835 L .31585 .59843 L F
.286 .611 .956 r
.73083 .58495 m .72706 .58324 L .72969 .58459 L F
0 .504 .773 r
.72969 .58459 m .733 .58538 L .73083 .58495 L F
.579 .415 .623 r
.31291 .7289 m .31469 .73134 L .31529 .72839 L F
.076 0 0 r
.54923 .68694 m .55104 .68637 L .55228 .68498 L F
.034 0 0 r
.55228 .68498 m .55296 .68562 L .55399 .68387 L F
.55228 .68498 m .55104 .68637 L .55296 .68562 L F
.398 .81 .978 r
.4397 .78641 m .43829 .78593 L .43617 .78621 L F
.148 .658 .9 r
.44187 .78658 m .43829 .78593 L .4397 .78641 L F
.275 .02 .334 r
.39588 .69022 m .39705 .69153 L .39798 .6898 L F
.39588 .69022 m .39536 .6922 L .39705 .69153 L F
.625 .17 .153 r
.46244 .75681 m .46057 .75794 L .45852 .75636 L F
.02 0 0 r
.46265 .75735 m .46244 .75681 L .4638 .7555 L F
.46265 .75735 m .46057 .75794 L .46244 .75681 L F
.423 .523 .855 r
.74241 .71124 m .74254 .71447 L .74046 .71138 L F
.74241 .71124 m .74434 .71426 L .74254 .71447 L F
.251 0 .294 r
.30217 .64252 m .30437 .64006 L .30397 .64269 L F
.316 .057 .353 r
.30168 .64541 m .30217 .64252 L .30397 .64269 L F
.334 0 .136 r
.58516 .66729 m .58728 .66669 L .58797 .6657 L F
.288 0 .091 r
.58728 .66669 m .59008 .66515 L .58797 .6657 L F
.74 .727 .839 r
.29275 .73168 m .29394 .73415 L .29527 .73332 L F
.376 .723 .989 r
.25977 .58741 m .25961 .58847 L .25856 .58809 L F
.25977 .58741 m .26133 .58843 L .25961 .58847 L F
.439 .229 .497 r
.29504 .62116 m .29708 .62119 L .29715 .61872 L F
.292 .066 .389 r
.29536 .62293 m .29708 .62119 L .29504 .62116 L F
.818 .625 .642 r
.58842 .73432 m .58694 .73114 L .58711 .73394 L F
.369 .054 .294 r
.39367 .69294 m .391 .69516 L .39306 .6945 L F
.4 .083 .309 r
.39367 .69294 m .39507 .69398 L .39536 .6922 L F
.39367 .69294 m .39306 .6945 L .39507 .69398 L F
.58 .767 .968 r
.41093 .65461 m .40762 .65388 L .40954 .65371 L F
.355 .75 .985 r
.4116 .65377 m .41093 .65461 L .40954 .65371 L F
.4116 .65377 m .41303 .65453 L .41093 .65461 L F
.416 0 .139 r
.5666 .76906 m .56902 .76875 L .56998 .76697 L F
0 0 .512 r
.57071 .76794 m .5705 .76974 L .5701 .76762 L F
.57071 .76794 m .5701 .76762 L .56998 .76697 L F
.909 .892 .801 r
.57071 .76794 m .56846 .77087 L .5705 .76974 L F
.862 .787 .775 r
.56902 .76875 m .56846 .77087 L .57071 .76794 L F
.246 0 0 r
.57071 .76794 m .56902 .76875 L .57142 .76831 L F
.57071 .76794 m .57142 .76831 L .57155 .76829 L F
.517 .1 .188 r
.56998 .76697 m .56902 .76875 L .57071 .76794 L F
.687 .197 .076 r
.47028 .78695 m .47126 .78609 L .47333 .78787 L F
.649 .257 .289 r
.47126 .78609 m .47348 .78656 L .47333 .78787 L F
.284 .381 .786 r
.5357 .73881 m .53585 .7356 L .53359 .73597 L F
.299 .196 .565 r
.5357 .73881 m .53557 .74037 L .53732 .73885 L F
.382 .735 .991 r
.2688 .58992 m .26834 .59095 L .26682 .59007 L F
.2688 .58992 m .27031 .59087 L .26834 .59095 L F
.446 .286 .57 r
.53426 .74544 m .536 .74513 L .53581 .74219 L F
.397 .136 .397 r
.53426 .74544 m .5338 .74745 L .536 .74513 L F
.456 .094 .261 r
.57431 .67291 m .5766 .67259 L .57742 .6704 L F
.504 .184 .357 r
.5766 .67259 m .57956 .6698 L .57742 .6704 L F
.652 .477 .635 r
.51201 .72557 m .51434 .72294 L .51196 .72288 L F
.429 .048 .213 r
.72735 .71376 m .72612 .71363 L .72413 .71351 L F
.647 .806 .959 r
.55929 .69188 m .55702 .69322 L .55638 .6921 L F
.779 .744 .821 r
.73453 .60534 m .73544 .60768 L .73231 .60738 L F
.778 .827 .891 r
.73528 .60586 m .73499 .60589 L .73512 .60584 L F
.769 .762 .847 r
.73499 .60601 m .73544 .60768 L .73528 .60586 L F
.416 .488 .826 r
.73528 .60586 m .73544 .60768 L .73699 .60604 L F
.464 .564 .872 r
.73699 .60604 m .73544 .60768 L .73499 .60601 L F
.73499 .60547 m .73499 .60601 L .73482 .60543 L F
.778 .827 .891 r
.73528 .60586 m .73499 .60601 L .73499 .60589 L F
.464 .564 .872 r
.73699 .60604 m .73499 .60583 L .73499 .60547 L F
.815 .83 .861 r
.73453 .60534 m .73231 .60738 L .7311 .60632 L F
0 .52 .717 r
.73358 .60564 m .73512 .60584 L .73699 .60604 L F
.73512 .60584 m .73528 .60586 L .73699 .60604 L F
.464 .564 .872 r
.73699 .60604 m .73499 .60601 L .73499 .60583 L F
.778 .827 .891 r
.73499 .60589 m .73231 .60738 L .7311 .60632 L F
.73499 .60601 m .73231 .60738 L .73499 .60589 L F
.73512 .60584 m .7311 .60632 L .73358 .60564 L F
.73499 .60589 m .7311 .60632 L .73512 .60584 L F
.464 .564 .872 r
.73482 .60543 m .73496 .60591 L .73453 .60534 L F
.73496 .60591 m .73544 .60768 L .73478 .60598 L F
.73496 .60591 m .73478 .60598 L .73453 .60534 L F
.769 .762 .847 r
.73231 .60738 m .73544 .60768 L .73499 .60601 L F
.632 .567 .763 r
.70557 .60093 m .70854 .60217 L .70724 .59898 L F
.628 .351 .479 r
.28994 .73105 m .29275 .73168 L .29295 .72956 L F
.475 .222 .449 r
.29275 .73168 m .29463 .73056 L .29295 .72956 L F
.518 .183 .34 r
.29295 .72956 m .29463 .73056 L .29497 .72892 L F
.393 .835 .941 r
.72492 .7183 m .72679 .71784 L .72805 .7181 L F
0 .293 .701 r
.72968 .71877 m .72805 .7181 L .72679 .71784 L F
.517 .276 .489 r
.72805 .7181 m .73098 .71958 L .73078 .71737 L F
0 .293 .701 r
.72968 .71877 m .73098 .71958 L .72805 .7181 L F
0 0 .085 r
.31928 .72937 m .31765 .73086 L .31792 .72923 L F
.864 .88 .847 r
.63504 .51569 m .6336 .51741 L .63245 .51644 L F
.946 .831 .699 r
.6336 .51741 m .63162 .51855 L .63245 .51644 L F
.6336 .51741 m .63283 .51954 L .63162 .51855 L F
.483 .215 .431 r
.41305 .69046 m .4126 .69248 L .41052 .69285 L F
.482 .218 .437 r
.41535 .68995 m .4126 .69248 L .41305 .69046 L F
.44 .342 .647 r
.32344 .68727 m .325 .68405 L .323 .6853 L F
.192 .669 .934 r
.52546 .79337 m .52799 .79398 L .52863 .79358 L F
.093 .514 .905 r
.52799 .79398 m .53044 .7951 L .52863 .79358 L F
.599 .552 .773 r
.35746 .7006 m .35531 .70113 L .35424 .69778 L F
.955 .689 .49 r
.5595 .75761 m .55886 .75892 L .55847 .75558 L F
.354 0 .196 r
.56062 .75852 m .5595 .75761 L .56185 .75791 L F
.56062 .75852 m .55886 .75892 L .5595 .75761 L F
.805 .735 .786 r
.536 .74513 m .5338 .74745 L .53687 .74784 L F
.744 .317 .236 r
.5338 .74745 m .53603 .74958 L .53687 .74784 L F
.356 .361 .727 r
.53433 .74939 m .53603 .74958 L .5338 .74745 L F
.53433 .74939 m .53603 .74958 L .5338 .74745 L F
.014 0 .007 r
.5354 .74898 m .53528 .74725 L .53603 .74958 L F
.5338 .74745 m .53528 .74725 L .5354 .74898 L F
.649 .55 .729 r
.5338 .74745 m .53151 .75018 L .53433 .74939 L F
.585 .458 .674 r
.5312 .74791 m .53151 .75018 L .53323 .74813 L F
.53291 .74761 m .53323 .74813 L .5338 .74745 L F
.5312 .74791 m .53323 .74813 L .53291 .74761 L F
.867 .516 .383 r
.53391 .74923 m .53239 .74975 L .53187 .74841 L F
.53433 .74939 m .53405 .74945 L .53391 .74923 L F
.53405 .74945 m .53239 .74975 L .53391 .74923 L F
.53433 .74939 m .53239 .74975 L .53187 .74841 L F
.014 0 .007 r
.5338 .74745 m .53239 .74975 L .53528 .74725 L F
.805 .936 .917 r
.53528 .74725 m .53239 .74975 L .53204 .74867 L F
.53528 .74725 m .53204 .74867 L .53329 .74823 L F
.95 .936 .743 r
.53528 .74725 m .53329 .74823 L .53512 .74511 L F
.53528 .74725 m .53512 .74511 L .53517 .74504 L F
.907 .537 .319 r
.53687 .74784 m .53603 .74958 L .53754 .74967 L F
.165 .333 .788 r
.5369 .74853 m .53603 .74958 L .53528 .74725 L F
.579 .929 .949 r
.5369 .74853 m .53462 .7495 L .53603 .74958 L F
.719 .552 .662 r
.53151 .75018 m .53487 .75287 L .53433 .74939 L F
.743 .627 .73 r
.53433 .74939 m .53487 .75287 L .53671 .75016 L F
.319 0 0 r
.53603 .74958 m .53346 .74998 L .53239 .74975 L F
.579 .929 .949 r
.53462 .7495 m .53346 .74998 L .53603 .74958 L F
.907 .537 .319 r
.53754 .74967 m .53603 .74958 L .53763 .7499 L F
.284 .288 .687 r
.53672 .75858 m .53728 .76146 L .53875 .76056 L F
.378 .487 .844 r
.53728 .76146 m .53938 .76172 L .53875 .76056 L F
.925 .801 .333 r
.58694 .73114 m .5862 .73275 L .58711 .73394 L F
.779 .956 .928 r
.56768 .68359 m .56675 .68536 L .56894 .68413 L F
.698 .938 .963 r
.57121 .68314 m .56894 .68413 L .57106 .68147 L F
.57121 .68314 m .56768 .68359 L .56894 .68413 L F
.605 .938 .745 r
.57242 .76432 m .57048 .76535 L .57117 .76494 L F
0 0 .347 r
.57389 .76076 m .57367 .76337 L .57242 .76432 L F
.458 .861 .686 r
.57242 .76432 m .57367 .76337 L .57048 .76535 L F
0 .047 .595 r
.53574 .71672 m .53775 .71894 L .53737 .71896 L F
0 .113 .635 r
.53775 .71894 m .53898 .72043 L .53737 .71896 L F
.257 0 0 r
.46033 .78579 m .45863 .78595 L .45659 .78579 L F
.571 .047 0 r
.46033 .78579 m .46217 .7863 L .45863 .78595 L F
.696 .281 .255 r
.44939 .76932 m .45297 .76955 L .45055 .77064 L F
.55 .572 .829 r
.45385 .77204 m .45055 .77064 L .45297 .76955 L F
.443 .756 .995 r
.45799 .77651 m .45413 .77561 L .456 .77519 L F
.028 .495 .879 r
.45978 .77707 m .45799 .77651 L .456 .77519 L F
.532 .424 .676 r
.42402 .76664 m .42573 .76396 L .42351 .76439 L F
.42402 .76664 m .42609 .76637 L .42573 .76396 L F
.437 .361 .673 r
.42402 .76664 m .42635 .76902 L .42609 .76637 L F
.42402 .76664 m .42434 .76964 L .42635 .76902 L F
0 0 .191 r
.60204 .71737 m .60341 .71646 L .60322 .71456 L F
0 0 .378 r
.60322 .71456 m .60395 .71414 L .6041 .71134 L F
0 0 .181 r
.60322 .71456 m .60341 .71646 L .60395 .71414 L F
.582 .456 .673 r
.32864 .6733 m .33044 .66984 L .32837 .67085 L F
.643 .383 .51 r
.53058 .73403 m .53338 .73178 L .53228 .73049 L F
.53058 .73403 m .53408 .735 L .53338 .73178 L F
.515 .301 .528 r
.53338 .73178 m .53408 .735 L .53625 .73356 L F
.611 .156 .146 r
.48123 .78845 m .48241 .78704 L .48454 .78839 L F
.435 .849 .963 r
.26909 .60393 m .26714 .60439 L .26841 .60464 L F
.562 .454 .689 r
.47271 .75606 m .47086 .7587 L .47019 .7581 L F
.47271 .75606 m .47315 .7584 L .47086 .7587 L F
.5 .106 .225 r
.47315 .7584 m .47019 .7581 L .47086 .7587 L F
.133 0 0 r
.27576 .6432 m .27774 .64258 L .27929 .64101 L F
0 0 0 r
.27929 .64101 m .27952 .6417 L .28126 .64028 L F
.27929 .64101 m .27774 .64258 L .27952 .6417 L F
.619 .271 .357 r
.5979 .66463 m .59563 .66282 L .59562 .66426 L F
.577 .507 .74 r
.40996 .67632 m .41121 .67279 L .40913 .67295 L F
.40996 .67632 m .41213 .67595 L .41121 .67279 L F
.537 .336 .556 r
.40996 .67632 m .40989 .67864 L .41213 .67595 L F
.413 .188 .461 r
.30437 .64006 m .30639 .63752 L .30581 .6395 L F
.368 .101 .372 r
.30397 .64269 m .30437 .64006 L .30581 .6395 L F
.895 .865 .803 r
.63211 .53011 m .63128 .53355 L .63012 .5328 L F
.953 .735 .57 r
.63128 .53355 m .62989 .53514 L .63012 .5328 L F
.63128 .53355 m .63123 .53601 L .62989 .53514 L F
.447 0 0 r
.2849 .65388 m .28265 .65497 L .28302 .65492 L F
.165 0 0 r
.2864 .65419 m .2849 .65388 L .28689 .65354 L F
.2864 .65419 m .28265 .65497 L .2849 .65388 L F
.045 0 0 r
.26531 .60529 m .26157 .60664 L .26288 .60562 L F
.284 .288 .687 r
.53672 .75858 m .53875 .76056 L .53963 .75796 L F
.585 .45 .663 r
.42508 .76113 m .42709 .75813 L .42511 .75864 L F
.555 .305 .492 r
.65446 .52526 m .65453 .52719 L .65212 .5273 L F
.676 .47 .6 r
.65709 .52482 m .65453 .52719 L .65446 .52526 L F
.999 .792 .479 r
.60341 .71952 m .60386 .72313 L .60281 .72188 L F
.497 .363 .628 r
.41982 .81391 m .41978 .81636 L .41764 .81637 L F
.41982 .81391 m .41978 .81636 L .41764 .81637 L F
.359 .155 .461 r
.30639 .63752 m .30841 .63435 L .30867 .6373 L F
.364 .143 .439 r
.30581 .6395 m .30639 .63752 L .30867 .6373 L F
.526 .391 .639 r
.32099 .70098 m .32287 .70056 L .3227 .69803 L F
.63 .493 .676 r
.32099 .70098 m .32367 .70342 L .32287 .70056 L F
.32099 .70098 m .32138 .7039 L .32367 .70342 L F
.544 .399 .634 r
.40913 .67295 m .41121 .67279 L .41114 .67052 L F
.642 .279 .34 r
.47686 .78613 m .47333 .78787 L .47348 .78656 L F
.47686 .78613 m .47557 .78839 L .47333 .78787 L F
.636 .272 .336 r
.47908 .78781 m .47557 .78839 L .47686 .78613 L F
.919 .531 .137 r
.56265 .73517 m .56276 .73388 L .56212 .73297 L F
.56265 .73517 m .56352 .7361 L .56276 .73388 L F
.591 .197 .263 r
.50555 .74723 m .50431 .74936 L .502 .748 L F
.741 .369 .348 r
.50555 .74723 m .5077 .7498 L .50431 .74936 L F
.223 .651 .955 r
.72997 .5935 m .73087 .59299 L .72963 .59251 L F
.72997 .5935 m .73192 .59382 L .73087 .59299 L F
.552 .437 .676 r
.32492 .68159 m .32669 .67858 L .32469 .67906 L F
.522 .717 .961 r
.73145 .62827 m .73263 .62645 L .73009 .62677 L F
.73145 .62827 m .7342 .62802 L .73263 .62645 L F
.508 .749 .982 r
.73145 .62827 m .73484 .62829 L .7342 .62802 L F
.715 .65 .783 r
.59634 .71987 m .59751 .72299 L .59432 .72236 L F
.595 .381 .561 r
.59674 .722 m .59432 .72236 L .59751 .72299 L F
.319 .412 .8 r
.59872 .72172 m .59751 .72299 L .59634 .71987 L F
.445 .233 .497 r
.59872 .72172 m .59674 .722 L .59751 .72299 L F
.296 0 0 r
.38048 .64762 m .38248 .64823 L .38381 .64842 L F
.504 .848 .995 r
.38248 .64823 m .38596 .64828 L .38381 .64842 L F
.528 .324 .546 r
.32459 .61313 m .32412 .6146 L .32259 .61542 L F
.361 .16 .467 r
.32618 .61504 m .32459 .61313 L .32677 .61208 L F
.32618 .61504 m .32412 .6146 L .32459 .61313 L F
.668 .761 .92 r
.4359 .66559 m .43369 .66644 L .43224 .66503 L F
.498 .114 .242 r
.45852 .75636 m .45813 .7577 L .45581 .75788 L F
.595 .205 .274 r
.45852 .75636 m .46057 .75794 L .45813 .7577 L F
.713 .781 .906 r
.74335 .61854 m .74018 .61819 L .74174 .61751 L F
.946 .863 .726 r
.74335 .61854 m .74142 .61943 L .74018 .61819 L F
.74335 .61854 m .74262 .62008 L .74142 .61943 L F
0 0 .054 r
.53581 .74219 m .53732 .73885 L .53557 .74037 L F
.547 .361 .581 r
.53581 .74219 m .538 .74433 L .5367 .74116 L F
.53581 .74219 m .536 .74513 L .538 .74433 L F
.443 .169 .401 r
.39565 .70591 m .39318 .70812 L .39359 .70646 L F
.4 .105 .345 r
.32259 .61542 m .32357 .61746 L .32187 .6183 L F
.32259 .61542 m .32412 .6146 L .32357 .61746 L F
0 .451 .854 r
.26682 .59007 m .26471 .58932 L .26334 .58822 L F
.68 .469 .593 r
.54723 .74132 m .54938 .74216 L .5495 .73936 L F
.581 .386 .582 r
.5495 .73936 m .54938 .74216 L .55229 .74166 L F
.618 .065 0 r
.58141 .7206 m .58227 .72141 L .58231 .72105 L F
.641 .101 0 r
.58227 .72141 m .5846 .72353 L .58231 .72105 L F
.487 .214 .425 r
.40033 .70195 m .40058 .70358 L .39843 .70399 L F
.427 .174 .426 r
.40269 .70291 m .40033 .70195 L .40236 .7002 L F
.40269 .70291 m .40058 .70358 L .40033 .70195 L F
.574 .368 .563 r
.51434 .72294 m .51676 .72257 L .51686 .72021 L F
.52 .317 .545 r
.51676 .72257 m .51899 .71979 L .51686 .72021 L F
.935 .675 .199 r
.56764 .72025 m .56783 .72257 L .56711 .7194 L F
.398 .116 .364 r
.50336 .72329 m .50257 .72524 L .5007 .72562 L F
.416 .174 .436 r
.50524 .72205 m .50257 .72524 L .50336 .72329 L F
0 0 0 r
.60732 .75369 m .60652 .75521 L .60542 .75473 L F
.367 .097 .366 r
.60734 .75639 m .60542 .75473 L .60705 .75543 L F
0 0 0 r
.60652 .75521 m .60651 .75522 L .60542 .75473 L F
.60418 .75539 m .60732 .75369 L .60542 .75473 L F
.60732 .75369 m .609 .75262 L .60653 .7552 L F
.60652 .75521 m .60653 .7552 L .60651 .75522 L F
.60732 .75369 m .60653 .7552 L .60652 .75521 L F
.609 .75262 m .61031 .75169 L .60654 .7552 L F
.367 .097 .366 r
.60705 .75543 m .60652 .75521 L .60693 .75506 L F
0 0 0 r
.60653 .7552 m .60654 .7552 L .60651 .75522 L F
.609 .75262 m .60654 .7552 L .60653 .7552 L F
.367 .097 .366 r
.6069 .75495 m .60542 .75473 L .60657 .75387 L F
.60693 .75506 m .60679 .75503 L .6069 .75495 L F
.60679 .75503 m .60542 .75473 L .6069 .75495 L F
.60652 .75521 m .60655 .75497 L .60654 .7552 L F
.545 .916 .751 r
.60654 .7552 m .60657 .75387 L .60651 .75522 L F
.61031 .75169 m .60657 .75387 L .60654 .7552 L F
.367 .097 .366 r
.60652 .75521 m .60542 .75473 L .60655 .75497 L F
.60654 .7552 m .60655 .75497 L .60693 .75506 L F
.062 .095 .583 r
.60542 .75473 m .60651 .75522 L .60656 .75412 L F
.60542 .75473 m .60656 .75412 L .60657 .75387 L F
0 0 0 r
.6041 .75543 m .60418 .75539 L .60542 .75473 L F
.43 0 0 r
.55674 .70965 m .5533 .70876 L .55465 .70902 L F
.465 .207 .437 r
.42429 .68317 m .42253 .68175 L .42462 .68123 L F
.42429 .68317 m .42204 .68371 L .42253 .68175 L F
.901 .679 .594 r
.60419 .68696 m .60583 .69006 L .60425 .68943 L F
.915 .673 .558 r
.60583 .69006 m .60404 .6918 L .60425 .68943 L F
.60583 .69006 m .6057 .69255 L .60404 .6918 L F
0 .375 .753 r
.55012 .75018 m .55172 .75099 L .55146 .75099 L F
.414 .199 .475 r
.30867 .6373 m .30841 .63435 L .31076 .6344 L F
.417 .262 .561 r
.33278 .66247 m .33437 .66434 L .33416 .66173 L F
.33278 .66247 m .33266 .66487 L .33437 .66434 L F
.426 .826 .98 r
.44543 .78661 m .44407 .78612 L .44187 .78658 L F
.343 .792 .954 r
.44749 .78626 m .44407 .78612 L .44543 .78661 L F
.252 0 0 r
.73192 .59382 m .7353 .59379 L .73439 .59403 L F
.377 0 0 r
.73439 .59403 m .7353 .59379 L .7379 .59449 L F
.488 .834 .997 r
.73538 .5849 m .73629 .58555 L .733 .58538 L F
.373 .77 .986 r
.73849 .58537 m .73629 .58555 L .73538 .5849 L F
.73849 .58537 m .73629 .58555 L .73538 .5849 L F
.797 .572 .597 r
.60128 .6643 m .60337 .66234 L .6011 .66292 L F
.864 .88 .847 r
.63504 .51569 m .63245 .51644 L .63365 .51502 L F
.846 .886 .868 r
.63735 .51343 m .63504 .51569 L .63365 .51502 L F
.412 .103 .329 r
.43537 .74206 m .43789 .74156 L .43782 .74003 L F
.496 .163 .333 r
.43782 .74003 m .43789 .74156 L .43987 .74097 L F
.31 0 .25 r
.5956 .72897 m .59788 .72828 L .59882 .729 L F
.475 .347 .625 r
.60128 .7282 m .59882 .729 L .59788 .72828 L F
.426 0 0 r
.59882 .729 m .60115 .7306 L .60212 .73119 L F
.475 .347 .625 r
.60128 .7282 m .60115 .7306 L .59882 .729 L F
0 0 .01 r
.36346 .84694 m .36167 .84966 L .36286 .84857 L F
.407 .527 .866 r
.36167 .84966 m .36369 .85052 L .36286 .84857 L F
.524 .346 .581 r
.50309 .7261 m .5007 .72562 L .50257 .72524 L F
.50309 .7261 m .50064 .72794 L .5007 .72562 L F
.843 .609 .584 r
.61436 .67348 m .61314 .67566 L .61608 .67629 L F
.856 .633 .599 r
.61317 .67804 m .61608 .67629 L .61314 .67566 L F
.61317 .67804 m .61604 .67871 L .61608 .67629 L F
.209 0 0 r
.57121 .68314 m .57013 .68366 L .56768 .68359 L F
.463 .86 .672 r
.57186 .68249 m .57013 .68366 L .57121 .68314 L F
.076 .184 .674 r
.58151 .75293 m .58259 .75194 L .58153 .74966 L F
.192 .384 .824 r
.58151 .75293 m .58426 .75491 L .58259 .75194 L F
.092 0 .202 r
.2831 .63703 m .28515 .63441 L .28373 .63518 L F
.35 .178 .502 r
.74803 .72248 m .74646 .72542 L .74654 .7227 L F
0 0 .216 r
.33304 .71746 m .33372 .71391 L .33234 .71455 L F
.33304 .71746 m .33365 .71631 L .33372 .71391 L F
0 0 .352 r
.33304 .71746 m .33378 .71863 L .33365 .71631 L F
0 0 0 r
.3344 .71864 m .33378 .71863 L .33561 .7189 L F
.3344 .71864 m .3343 .7187 L .33378 .71863 L F
0 0 .352 r
.33327 .71857 m .33363 .72025 L .33378 .71863 L F
.252 .479 .883 r
.33363 .72025 m .33494 .72012 L .33378 .71863 L F
.742 .688 .799 r
.33378 .71863 m .33494 .72012 L .33705 .71902 L F
.681 .553 .703 r
.33013 .71591 m .33183 .71978 L .3278 .71881 L F
.33183 .71978 m .33232 .72092 L .33095 .72028 L F
.33183 .71978 m .33095 .72028 L .3278 .71881 L F
.115 0 0 r
.33117 .72004 m .33179 .72082 L .33301 .7216 L F
.758 .975 .71 r
.33378 .71863 m .33179 .72082 L .33232 .72092 L F
.33378 .71863 m .33188 .72066 L .33179 .72082 L F
.115 0 0 r
.33117 .72004 m .32924 .72187 L .33179 .72082 L F
.627 .597 .8 r
.33179 .72082 m .3278 .71881 L .33186 .7207 L F
.758 .975 .71 r
.33188 .72066 m .33179 .72075 L .33179 .72082 L F
.627 .597 .8 r
.33179 .72082 m .33186 .7207 L .33232 .72092 L F
.731 .576 .681 r
.33378 .71863 m .33232 .72092 L .33211 .72042 L F
.33378 .71863 m .33211 .72042 L .33013 .71591 L F
.738 .222 0 r
.33071 .71969 m .33138 .72008 L .33182 .72008 L F
.758 .975 .71 r
.33243 .72008 m .33182 .72008 L .33179 .72075 L F
.168 0 .149 r
.33363 .72025 m .33301 .7216 L .33494 .72012 L F
.611 .63 .845 r
.33301 .7216 m .33662 .72458 L .33546 .7214 L F
.714 .702 .837 r
.33494 .72012 m .33301 .7216 L .33546 .7214 L F
.567 .121 .152 r
.33301 .7216 m .33133 .72306 L .32924 .72187 L F
.955 .729 .556 r
.33179 .72082 m .33133 .72306 L .33301 .7216 L F
0 0 .537 r
.33182 .72008 m .33344 .72341 L .33179 .72082 L F
.611 .63 .845 r
.33301 .7216 m .33417 .72505 L .33662 .72458 L F
.515 .675 .937 r
.33431 .72177 m .33344 .72341 L .3333 .72312 L F
.33431 .72177 m .3333 .72312 L .33182 .72008 L F
.738 .222 0 r
.33138 .72008 m .33431 .72177 L .33182 .72008 L F
.33071 .71969 m .33246 .72156 L .33431 .72177 L F
.678 .948 .958 r
.33431 .72177 m .33246 .72156 L .33538 .72034 L F
.458 .33 .617 r
.33546 .7214 m .33705 .71902 L .33494 .72012 L F
.33546 .7214 m .33741 .72136 L .33705 .71902 L F
0 .303 .798 r
.33741 .72136 m .33561 .7189 L .33705 .71902 L F
.33741 .72136 m .33757 .72026 L .33561 .7189 L F
.364 .386 .75 r
.33662 .72458 m .33741 .72136 L .33546 .7214 L F
.33662 .72458 m .33817 .72462 L .33741 .72136 L F
0 .239 .73 r
.33561 .7189 m .33757 .72026 L .33637 .71895 L F
.599 .709 .921 r
.33745 .72264 m .33431 .72177 L .33637 .71895 L F
.618 .559 .766 r
.33741 .72136 m .33817 .72462 L .3404 .72401 L F
.33741 .72136 m .3404 .72401 L .33884 .72292 L F
0 .111 .664 r
.33741 .72136 m .33884 .72292 L .33757 .72026 L F
.616 .6 .811 r
.33884 .72292 m .33989 .71965 L .33757 .72026 L F
.562 .89 .987 r
.33989 .71965 m .33822 .7191 L .33757 .72026 L F
.339 .631 .96 r
.33757 .72026 m .33822 .7191 L .33637 .71895 L F
0 0 .403 r
.33822 .7191 m .33745 .72264 L .33637 .71895 L F
.678 .948 .958 r
.33431 .72177 m .3369 .7197 L .33637 .71895 L F
.33431 .72177 m .33538 .72034 L .3369 .7197 L F
.758 .975 .71 r
.33378 .71863 m .33182 .72008 L .33243 .72008 L F
0 0 0 r
.3343 .7187 m .33182 .72008 L .33351 .71884 L F
.33385 .71864 m .33351 .71884 L .33378 .71863 L F
.3343 .7187 m .33351 .71884 L .33385 .71864 L F
0 0 .352 r
.33304 .71746 m .33327 .71857 L .33378 .71863 L F
.566 .15 .213 r
.55932 .69099 m .55707 .69212 L .55929 .69188 L F
.864 .771 .758 r
.55895 .68751 m .55932 .69099 L .56092 .68724 L F
.55823 .6876 m .56092 .68724 L .55904 .68786 L F
.889 .735 .685 r
.55983 .68409 m .55904 .68786 L .56092 .68724 L F
.412 .269 .575 r
.56066 .68716 m .55904 .68786 L .55932 .68654 L F
.56 .68473 m .55932 .68654 L .55983 .68409 L F
.56066 .68716 m .55932 .68654 L .56 .68473 L F
.864 .771 .758 r
.55823 .6876 m .55855 .68859 L .55895 .68751 L F
.55855 .68859 m .55932 .69099 L .55895 .68751 L F
.566 .15 .213 r
.55932 .69099 m .55707 .69212 L .55929 .69188 L F
.588 .229 .328 r
.51203 .7199 m .50734 .72219 L .50689 .72059 L F
0 0 0 r
.36811 .84833 m .36574 .84959 L .36648 .84936 L F
.36811 .84833 m .36574 .84959 L .36648 .84936 L F
.193 .427 .858 r
.36574 .84959 m .36346 .84694 L .36648 .84936 L F
.169 0 0 r
.36369 .85052 m .36574 .84959 L .36648 .84936 L F
.885 .68 .621 r
.62045 .68955 m .62189 .68999 L .62048 .68692 L F
.843 .59 .557 r
.619 .69154 m .62189 .68999 L .62045 .68955 L F
.619 .69154 m .62204 .69253 L .62189 .68999 L F
.801 .481 0 r
.56092 .68724 m .56066 .68716 L .55983 .68409 L F
.284 0 0 r
.56092 .68724 m .56165 .68804 L .56066 .68716 L F
.56092 .68724 m .56373 .68728 L .56165 .68804 L F
.798 .548 .56 r
.61144 .67545 m .61436 .67348 L .61139 .6729 L F
.61144 .67545 m .61314 .67566 L .61436 .67348 L F
.74 .727 .839 r
.29275 .73168 m .29527 .73332 L .29463 .73056 L F
.82 .785 .819 r
.29463 .73056 m .29527 .73332 L .29681 .73174 L F
.387 .137 .408 r
.2883 .62984 m .28775 .6318 L .29009 .62917 L F
0 0 .362 r
.70799 .58036 m .70913 .58138 L .70831 .5798 L F
.70799 .58036 m .70767 .58296 L .70913 .58138 L F
.761 .817 .897 r
.71302 .59837 m .71643 .5978 L .71482 .59809 L F
.662 .844 .97 r
.71643 .5978 m .71787 .5959 L .71482 .59809 L F
.71643 .5978 m .71834 .59715 L .71787 .5959 L F
.498 .415 .693 r
.42694 .78107 m .42838 .77742 L .42621 .77777 L F
.42694 .78107 m .42886 .78071 L .42838 .77742 L F
.515 .519 .798 r
.42694 .78107 m .42983 .78255 L .42886 .78071 L F
.526 .566 .839 r
.42694 .78107 m .43059 .78402 L .42983 .78255 L F
.819 .785 .821 r
.29463 .73056 m .29867 .72927 L .29497 .72892 L F
.29463 .73056 m .29681 .73174 L .29867 .72927 L F
.922 .931 .797 r
.60212 .73119 m .60309 .72765 L .60433 .72841 L F
.60212 .73119 m .60115 .7306 L .60309 .72765 L F
.267 .388 .8 r
.58758 .70851 m .58695 .70974 L .58505 .70621 L F
.129 .213 .683 r
.58758 .70851 m .58833 .71151 L .58695 .70974 L F
0 .499 .828 r
.73775 .62962 m .73559 .62862 L .7369 .62911 L F
.73775 .62962 m .73823 .62935 L .73559 .62862 L F
.306 .78 .675 r
.74286 .62733 m .73775 .62962 L .74241 .62844 L F
.655 .505 .668 r
.73775 .62962 m .74276 .62922 L .74241 .62844 L F
.555 .508 .757 r
.29658 .61617 m .29766 .6124 L .29584 .61289 L F
.29658 .61617 m .29842 .61582 L .29766 .6124 L F
.509 .425 .697 r
.29715 .61872 m .29842 .61582 L .29658 .61617 L F
.505 .487 .771 r
.3138 .7226 m .31693 .72486 L .31643 .72149 L F
.779 .956 .928 r
.56768 .68359 m .56512 .68539 L .56675 .68536 L F
.223 0 0 r
.31042 .72749 m .30999 .72663 L .31068 .72463 L F
.31042 .72749 m .30818 .72811 L .30999 .72663 L F
0 0 .157 r
.45094 .76147 m .45031 .76349 L .4492 .76396 L F
.28 .164 .537 r
.45066 .76564 m .4492 .76396 L .45031 .76349 L F
.45066 .76564 m .44903 .76659 L .4492 .76396 L F
.246 0 .136 r
.46747 .75208 m .4667 .75102 L .46814 .74998 L F
.441 .04 .182 r
.46976 .75172 m .46814 .74998 L .47095 .74962 L F
.46976 .75172 m .46747 .75208 L .46814 .74998 L F
0 0 .501 r
.54173 .73253 m .54219 .7323 L .54092 .73005 L F
.7 .359 .395 r
.54219 .7323 m .54185 .7323 L .54092 .73005 L F
0 0 .405 r
.54034 .72865 m .54097 .73153 L .54092 .73005 L F
.7 .359 .395 r
.54185 .7323 m .53865 .73228 L .54092 .73005 L F
0 0 .405 r
.54011 .72764 m .54034 .72865 L .54092 .73005 L F
.654 .554 .729 r
.32238 .6955 m .32399 .69174 L .3218 .69254 L F
.502 0 0 r
.53832 .72805 m .53496 .72768 L .53438 .72698 L F
.855 .654 .63 r
.61953 .68377 m .6207 .68454 L .61936 .68147 L F
.818 .646 .669 r
.61953 .68377 m .62048 .68692 L .6207 .68454 L F
.993 .751 .455 r
.56655 .703 m .56681 .70591 L .56789 .7067 L F
.611 .063 0 r
.56681 .70591 m .57017 .70859 L .56789 .7067 L F
.621 .058 0 r
.56789 .7067 m .57017 .70859 L .57147 .70908 L F
.229 0 .011 r
.29253 .65107 m .29544 .64946 L .29458 .65016 L F
0 0 0 r
.29458 .65016 m .29544 .64946 L .2973 .64867 L F
.79 .556 .583 r
.60798 .67015 m .61139 .6729 L .61132 .67101 L F
.619 .556 .761 r
.54173 .73253 m .54215 .73697 L .54032 .73669 L F
.618 .251 .326 r
.54215 .73697 m .54266 .73819 L .54032 .73669 L F
.565 .557 .804 r
.29045 .73234 m .29275 .73168 L .28994 .73105 L F
.736 .965 .937 r
.57363 .75345 m .57436 .75284 L .57541 .75315 L F
.878 .963 .85 r
.57541 .75315 m .57436 .75284 L .57259 .75505 L F
.257 .437 .848 r
.57164 .72528 m .574 .72877 L .57417 .72791 L F
.445 .208 .459 r
.43099 .74758 m .4329 .74735 L .4335 .74478 L F
.422 .235 .52 r
.4335 .74478 m .43526 .74461 L .43537 .74206 L F
.631 .382 .522 r
.4335 .74478 m .43564 .747 L .43526 .74461 L F
.4335 .74478 m .4329 .74735 L .43564 .747 L F
.509 .425 .697 r
.29715 .61872 m .29919 .61816 L .29842 .61582 L F
.416 .212 .492 r
.29715 .61872 m .29877 .62032 L .29919 .61816 L F
.29715 .61872 m .29708 .62119 L .29877 .62032 L F
.387 .067 .297 r
.34462 .65657 m .3466 .65607 L .34768 .65339 L F
.399 .06 .271 r
.3466 .65607 m .34976 .65314 L .34768 .65339 L F
.264 .284 .694 r
.49251 .74212 m .49407 .7412 L .49209 .73907 L F
.863 .678 .147 r
.49251 .74212 m .49259 .74496 L .49234 .74418 L F
.49251 .74212 m .49234 .74418 L .49407 .7412 L F
.011 0 .166 r
.54433 .74424 m .542 .74755 L .5446 .74456 L F
.54406 .74392 m .54386 .74427 L .54433 .74424 L F
.54386 .74427 m .542 .74755 L .54433 .74424 L F
.55 .11 .157 r
.54503 .74421 m .54281 .7454 L .54377 .74459 L F
.557 .563 .816 r
.5446 .74456 m .54588 .74395 L .54377 .74459 L F
.55 .11 .157 r
.54588 .74395 m .54537 .74419 L .54503 .74421 L F
.54537 .74419 m .54281 .7454 L .54503 .74421 L F
.504 0 0 r
.54406 .74392 m .54377 .74459 L .54162 .74396 L F
.011 0 .166 r
.54406 .74392 m .5446 .74456 L .54377 .74459 L F
0 0 0 r
.52808 .73207 m .52513 .73385 L .52469 .73058 L F
.52808 .73207 m .52647 .73308 L .52513 .73385 L F
.583 .576 .811 r
.53013 .73137 m .52808 .73207 L .52692 .72866 L F
.217 0 0 r
.52895 .73267 m .52808 .73207 L .53013 .73137 L F
.52895 .73267 m .52647 .73308 L .52808 .73207 L F
0 0 .393 r
.47154 .75296 m .47187 .75191 L .47095 .74962 L F
.546 .265 .44 r
.51579 .75822 m .5184 .75559 L .51588 .75596 L F
.6 .946 .921 r
.74692 .60904 m .7445 .61031 L .74589 .60896 L F
0 0 .485 r
.7445 .61031 m .74578 .61101 L .74589 .60896 L F
.7445 .61031 m .74519 .61302 L .74578 .61101 L F
.744 .678 .787 r
.70724 .59898 m .71059 .59926 L .70944 .59611 L F
.755 .628 .72 r
.70854 .60217 m .71059 .59926 L .70724 .59898 L F
.66 .668 .847 r
.71059 .59926 m .71181 .59571 L .70944 .59611 L F
.71059 .59926 m .71302 .59837 L .71181 .59571 L F
.461 .22 .461 r
.40536 .69761 m .40236 .7002 L .40342 .69834 L F
.253 0 .047 r
.5824 .66855 m .58381 .66891 L .58516 .66729 L F
.248 0 0 r
.58516 .66729 m .58686 .66756 L .58728 .66669 L F
.58516 .66729 m .58381 .66891 L .58686 .66756 L F
.461 .706 .974 r
.2889 .60692 m .28958 .60542 L .28688 .60446 L F
.2889 .60692 m .29082 .60675 L .28958 .60542 L F
.505 .145 .289 r
.38968 .69692 m .39306 .6945 L .391 .69516 L F
.006 .582 .715 r
.45097 .78628 m .44977 .78626 L .44749 .78626 L F
.097 .644 .833 r
.45097 .78628 m .45189 .78607 L .44977 .78626 L F
.45097 .78628 m .45314 .78633 L .45189 .78607 L F
.18 .7 .88 r
.41303 .65453 m .41526 .65448 L .41638 .65474 L F
.212 .673 .945 r
.41751 .6542 m .41638 .65474 L .41526 .65448 L F
.41751 .6542 m .41863 .65492 L .41638 .65474 L F
.504 .195 .376 r
.52568 .74117 m .52386 .73992 L .52609 .73941 L F
.52568 .74117 m .52338 .74176 L .52386 .73992 L F
.513 .388 .647 r
.35681 .68505 m .35669 .68688 L .35492 .6873 L F
.487 .325 .587 r
.35669 .68688 m .35498 .68967 L .35492 .6873 L F
.526 .422 .679 r
.4242 .7708 m .42635 .76902 L .42434 .76964 L F
.201 0 0 r
.39185 .70985 m .3912 .70879 L .39318 .70812 L F
.39185 .70985 m .38979 .71052 L .3912 .70879 L F
.992 .74 .426 r
.48368 .78233 m .48468 .78344 L .48396 .78149 L F
0 .38 .828 r
.48736 .78477 m .48468 .78344 L .48368 .78233 L F
.625 .587 .791 r
.7278 .70944 m .72413 .71351 L .72559 .7112 L F
.7278 .70944 m .72735 .71376 L .72413 .71351 L F
.439 .31 .607 r
.42924 .753 m .43098 .75001 L .42885 .75053 L F
0 0 .336 r
.29329 .74741 m .29482 .74427 L .29537 .74612 L F
.673 .849 .967 r
.29405 .74895 m .29378 .74688 L .29329 .74741 L F
.29405 .74895 m .29469 .74706 L .29378 .74688 L F
.29405 .74895 m .29639 .74785 L .29469 .74706 L F
.386 .086 .329 r
.29009 .62917 m .29204 .6286 L .29256 .62632 L F
.379 .178 .477 r
.29256 .62632 m .29478 .62689 L .29536 .62293 L F
.326 .035 .308 r
.29256 .62632 m .29391 .62781 L .29478 .62689 L F
.29256 .62632 m .29204 .6286 L .29391 .62781 L F
0 0 .034 r
.74806 .61985 m .74629 .62328 L .74716 .62139 L F
.776 .613 .678 r
.63473 .52276 m .63423 .52501 L .63244 .52159 L F
.546 .825 .998 r
.36983 .70606 m .36778 .70661 L .36633 .70576 L F
.614 .767 .953 r
.27812 .5916 m .27729 .59372 L .27575 .59159 L F
.27812 .5916 m .27938 .59307 L .27729 .59372 L F
.919 .61 .444 r
.52584 .7109 m .52859 .71408 L .5272 .71167 L F
.178 0 .273 r
.71807 .60463 m .71557 .60781 L .71764 .60655 L F
0 0 0 r
.60121 .71938 m .60204 .71737 L .60235 .71948 L F
.874 .556 .445 r
.60341 .71952 m .60235 .71948 L .60204 .71737 L F
0 0 0 r
.60121 .71938 m .60341 .71646 L .60204 .71737 L F
.546 .265 .44 r
.51579 .75822 m .51826 .75805 L .5184 .75559 L F
.306 .076 .392 r
.5184 .75559 m .51826 .75805 L .52057 .75532 L F
.846 .886 .868 r
.63735 .51343 m .63365 .51502 L .6361 .51222 L F
.702 .817 .936 r
.63965 .51221 m .63735 .51343 L .6361 .51222 L F
.642 .596 .787 r
.63965 .51221 m .63995 .51428 L .63735 .51343 L F
.806 .522 .507 r
.35502 .72616 m .35431 .72786 L .35137 .72661 L F
.942 .886 .479 r
.35445 .72658 m .35502 .72616 L .35688 .72576 L F
.35445 .72658 m .35431 .72786 L .35502 .72616 L F
.44 .342 .647 r
.32344 .68727 m .32524 .68695 L .325 .68405 L F
.458 .428 .737 r
.32344 .68727 m .3258 .68938 L .32524 .68695 L F
.534 .433 .687 r
.32386 .68979 m .3258 .68938 L .32344 .68727 L F
.514 .714 .963 r
.74601 .60262 m .74645 .60127 L .74464 .60111 L F
.343 .475 .849 r
.32994 .60432 m .32855 .60444 L .32762 .60246 L F
.497 .444 .728 r
.32994 .60432 m .32881 .60747 L .32855 .60444 L F
.496 .305 .551 r
.4874 .74396 m .4873 .74754 L .48525 .74771 L F
.489 .27 .508 r
.48969 .74196 m .49131 .74421 L .4874 .74396 L F
.47 0 0 r
.73198 .6242 m .73669 .62678 L .73294 .62503 L F
.498 .453 .737 r
.7209 .72605 m .72321 .72484 L .72064 .72457 L F
.7209 .72605 m .7237 .72789 L .72321 .72484 L F
.743 .657 .765 r
.5743 .69281 m .57157 .69339 L .57274 .69106 L F
0 .281 .781 r
.57261 .69075 m .5743 .69281 L .57274 .69106 L F
.918 .69 .577 r
.57261 .69075 m .57389 .69494 L .5743 .69281 L F
.604 .453 .649 r
.43098 .75001 m .4329 .74735 L .43099 .74758 L F
.582 .551 .786 r
.42621 .77777 m .42732 .77444 L .42538 .77528 L F
.42621 .77777 m .42838 .77742 L .42732 .77444 L F
.465 .125 .304 r
.48147 .73051 m .48363 .73022 L .48428 .72878 L F
.353 .016 .247 r
.48428 .72878 m .48363 .73022 L .48628 .72821 L F
.652 .477 .635 r
.51201 .72557 m .51454 .72547 L .51434 .72294 L F
.557 .387 .606 r
.51454 .72547 m .51676 .72257 L .51434 .72294 L F
.473 .59 .89 r
.42983 .78255 m .43059 .78402 L .43164 .78245 L F
.418 .517 .852 r
.43059 .78402 m .43287 .78513 L .43164 .78245 L F
.123 0 .113 r
.28775 .6318 m .28619 .63278 L .28515 .63441 L F
.569 .297 .463 r
.45714 .73908 m .45947 .7388 L .46013 .73629 L F
.586 .313 .469 r
.46013 .73629 m .4624 .73812 L .46246 .73609 L F
.46013 .73629 m .45947 .7388 L .4624 .73812 L F
.808 .523 .506 r
.49832 .73393 m .49761 .73175 L .49632 .73365 L F
.527 .552 .824 r
.29387 .60817 m .29509 .61055 L .29666 .6088 L F
.51 .488 .768 r
.29584 .61289 m .29666 .6088 L .29509 .61055 L F
.29584 .61289 m .29766 .6124 L .29666 .6088 L F
.088 .237 .723 r
.57323 .6995 m .57162 .69923 L .57416 .69771 L F
.346 .763 .978 r
.38596 .64828 m .38804 .64814 L .38944 .64876 L F
.13 .606 .919 r
.38969 .64821 m .38944 .64876 L .38804 .64814 L F
.38969 .64821 m .39124 .64905 L .38944 .64876 L F
.569 .091 .08 r
.51396 .78826 m .51623 .78883 L .51737 .78816 L F
.429 0 0 r
.51737 .78816 m .51623 .78883 L .51959 .78834 L F
.519 .29 .507 r
.42204 .68371 m .4199 .68608 L .41971 .68417 L F
0 0 0 r
.36153 .68085 m .35911 .68339 L .35932 .68129 L F
.30596 .72547 m .30703 .72467 L .3083 .72287 L F
0 0 .437 r
.61724 .73851 m .61748 .74115 L .61651 .74228 L F
0 0 .145 r
.61651 .74228 m .61705 .7434 L .61607 .74455 L F
.61651 .74228 m .61748 .74115 L .61705 .7434 L F
.391 .732 .991 r
.4017 .65162 m .4007 .6522 L .3989 .65118 L F
.4017 .65162 m .40408 .65262 L .4007 .6522 L F
0 0 .416 r
.57888 .74208 m .58004 .74333 L .57913 .7412 L F
.839 .449 0 r
.57913 .7412 m .58004 .74333 L .5794 .74216 L F
0 0 .292 r
.57888 .74208 m .57913 .7412 L .57877 .73991 L F
.839 .449 0 r
.57913 .7412 m .5794 .74216 L .57843 .74037 L F
0 0 .292 r
.57877 .73991 m .57913 .7412 L .5787 .73872 L F
0 0 .416 r
.57888 .74208 m .57906 .74458 L .58004 .74333 L F
.105 0 0 r
.36834 .72058 m .36772 .71989 L .36974 .71931 L F
.36834 .72058 m .36625 .72137 L .36772 .71989 L F
.578 .264 .401 r
.47595 .73293 m .47827 .7319 L .47603 .73207 L F
0 0 0 r
.6041 .75543 m .60542 .75473 L .60405 .75563 L F
.47 .478 .784 r
.57389 .76076 m .57088 .75923 L .57238 .7586 L F
.755 .829 .909 r
.71905 .59011 m .72302 .58934 L .72199 .58785 L F
.645 .623 .813 r
.72199 .58785 m .72302 .58934 L .72513 .58853 L F
.588 .229 .328 r
.51203 .7199 m .50964 .72245 L .50734 .72219 L F
.523 .15 .275 r
.51418 .72076 m .51203 .7199 L .51299 .71974 L F
.51418 .72076 m .50964 .72245 L .51203 .7199 L F
.68 .404 .497 r
.65212 .5273 m .64901 .52956 L .64924 .52848 L F
.898 .783 .726 r
.63244 .52159 m .63162 .51855 L .63283 .51954 L F
.166 0 0 r
.29253 .65107 m .29086 .6525 L .28888 .65299 L F
.047 0 0 r
.29296 .6517 m .29253 .65107 L .29458 .65016 L F
.29296 .6517 m .29086 .6525 L .29253 .65107 L F
0 0 .498 r
.62178 .71322 m .62053 .71202 L .62138 .71081 L F
.62178 .71322 m .62083 .71432 L .62053 .71202 L F
.412 .533 .869 r
.47587 .77645 m .475 .77756 L .47326 .77445 L F
.839 .672 .675 r
.71074 .57682 m .71139 .57982 L .7122 .5755 L F
.396 .847 .913 r
.37572 .70413 m .37568 .70341 L .37785 .70369 L F
.37572 .70413 m .37371 .70399 L .37568 .70341 L F
.983 .907 .638 r
.741 .62372 m .74142 .61943 L .74262 .62008 L F
.332 0 0 r
.54162 .74396 m .538 .74433 L .539 .74388 L F
0 0 .329 r
.70647 .59113 m .70608 .5934 L .7077 .59288 L F
.70647 .59113 m .7077 .59288 L .70527 .59001 L F
.234 .462 .874 r
.5738 .73425 m .57469 .73315 L .57392 .73236 L F
.5738 .73425 m .57653 .73568 L .57469 .73315 L F
.591 .588 .818 r
.51893 .74467 m .51563 .74205 L .51818 .74125 L F
.66 .572 .745 r
.52152 .74288 m .51893 .74467 L .51818 .74125 L F
.678 .61 .772 r
.52152 .74288 m .52174 .7445 L .51893 .74467 L F
.222 .491 .897 r
.30737 .72135 m .3083 .72287 L .30888 .72172 L F
.663 .847 .442 r
.3083 .72287 m .30703 .72467 L .30888 .72172 L F
.876 .853 .817 r
.46249 .64314 m .46027 .64638 L .45899 .64509 L F
.54 .766 .981 r
.45899 .64509 m .46027 .64638 L .4625 .64576 L F
.446 .391 .703 r
.33417 .72505 m .33424 .72888 L .33642 .72728 L F
.561 .514 .759 r
.33534 .73079 m .33642 .72728 L .33424 .72888 L F
.465 .19 .412 r
.41052 .69285 m .41004 .69468 L .40794 .69514 L F
.446 .159 .382 r
.4126 .69248 m .41004 .69468 L .41052 .69285 L F
.457 .3 .578 r
.32669 .67618 m .32853 .67805 L .32856 .67569 L F
.32669 .67618 m .32669 .67858 L .32853 .67805 L F
.341 .716 .984 r
.27575 .59159 m .2738 .59165 L .27234 .59071 L F
0 .022 .534 r
.57261 .71012 m .57147 .70908 L .57017 .70859 L F
.57261 .71012 m .57314 .71075 L .57147 .70908 L F
.495 0 0 r
.5715 .70938 m .57214 .70957 L .57261 .71012 L F
.57214 .70957 m .57491 .71038 L .57261 .71012 L F
0 .022 .534 r
.57261 .71012 m .57361 .71122 L .57314 .71075 L F
.147 0 .322 r
.73813 .62552 m .73568 .62789 L .73669 .62678 L F
.64 .571 .761 r
.7395 .62798 m .73568 .62789 L .73813 .62552 L F
.7395 .62798 m .7369 .62911 L .73568 .62789 L F
.395 0 .014 r
.7172 .57947 m .71952 .57928 L .7201 .57839 L F
.678 .223 .164 r
.71952 .57928 m .72239 .57965 L .7201 .57839 L F
.333 0 0 r
.27053 .64544 m .273 .64502 L .27122 .64491 L F
.736 .56 .654 r
.52831 .74729 m .53151 .75018 L .5312 .74791 L F
.295 0 0 r
.7369 .62911 m .73559 .62862 L .73484 .62829 L F
.288 0 0 r
.58449 .67623 m .58354 .67728 L .5811 .67778 L F
.316 0 0 r
.58684 .67606 m .58354 .67728 L .58449 .67623 L F
.246 0 .136 r
.46747 .75208 m .46562 .7527 L .4667 .75102 L F
.54 .417 .661 r
.58609 .7279 m .5838 .72489 L .58536 .72445 L F
.58609 .7279 m .58401 .72857 L .5838 .72489 L F
.773 .711 .793 r
.59309 .71938 m .59432 .72236 L .59076 .7223 L F
.762 .55 .611 r
.59392 .72537 m .59076 .7223 L .59432 .72236 L F
.745 .698 .806 r
.59634 .71987 m .59432 .72236 L .59309 .71938 L F
.595 .381 .561 r
.59674 .722 m .59392 .72537 L .59432 .72236 L F
.68 .404 .497 r
.65212 .5273 m .65129 .52957 L .64901 .52956 L F
.625 .388 .538 r
.65453 .52719 m .65129 .52957 L .65212 .5273 L F
0 0 0 r
.49181 .72551 m .49327 .72486 L .49451 .72283 L F
.097 0 0 r
.49451 .72283 m .495 .72405 L .49631 .72232 L F
.49451 .72283 m .49327 .72486 L .495 .72405 L F
.402 .216 .511 r
.49451 .72283 m .49631 .72232 L .49643 .72002 L F
.685 .195 .078 r
.48628 .78829 m .48676 .79023 L .48454 .78839 L F
.48628 .78829 m .48818 .78993 L .48676 .79023 L F
.582 .282 .425 r
.46483 .73613 m .4673 .73609 L .46818 .73357 L F
.557 .257 .414 r
.46818 .73357 m .47016 .73515 L .47054 .73384 L F
.46818 .73357 m .4673 .73609 L .47016 .73515 L F
.153 0 0 r
.54392 .76054 m .54308 .76006 L .54518 .76141 L F
.828 .427 0 r
.58644 .7117 m .58587 .71143 L .58463 .70878 L F
.861 .982 .694 r
.58657 .71006 m .58587 .71143 L .58644 .7117 L F
.432 .773 .997 r
.30698 .59611 m .30655 .59718 L .30505 .59621 L F
.30698 .59611 m .30859 .59696 L .30655 .59718 L F
.559 .282 .452 r
.5485 .7588 m .54722 .76133 L .54518 .76141 L F
.724 .47 .542 r
.5508 .76109 m .5485 .7588 L .55065 .75855 L F
.5508 .76109 m .54722 .76133 L .5485 .7588 L F
.198 .243 .683 r
.45297 .76955 m .45465 .77166 L .45385 .77204 L F
.696 .281 .255 r
.44939 .76932 m .45339 .77037 L .45297 .76955 L F
0 0 .112 r
.45245 .76876 m .45339 .77037 L .45139 .7691 L F
.697 .189 0 r
.4532 .77005 m .45297 .76955 L .45339 .77037 L F
0 0 .112 r
.45369 .76837 m .45339 .77037 L .45245 .76876 L F
.697 .189 0 r
.45361 .77094 m .4532 .77005 L .45339 .77037 L F
0 0 .112 r
.45341 .77023 m .45361 .77094 L .45339 .77037 L F
.45369 .76837 m .45361 .77094 L .45341 .77023 L F
.697 .189 0 r
.45361 .77094 m .45465 .77166 L .45336 .77004 L F
.45361 .77094 m .45336 .77004 L .45297 .76955 L F
.812 .579 .586 r
.61604 .67871 m .61604 .68107 L .61936 .68147 L F
.823 .616 .624 r
.61604 .68107 m .61953 .68377 L .61936 .68147 L F
.431 .229 .503 r
.41716 .68919 m .4157 .68823 L .41777 .68657 L F
.41716 .68919 m .41535 .68995 L .4157 .68823 L F
.384 .349 .696 r
.42662 .77191 m .42538 .77528 L .42732 .77444 L F
.42662 .77191 m .42547 .77571 L .42538 .77528 L F
.481 .228 .453 r
.405 .68121 m .40708 .6809 L .40749 .67896 L F
.555 .285 .46 r
.40708 .6809 m .40989 .67864 L .40749 .67896 L F
.456 .448 .761 r
.74189 .59947 m .74464 .60111 L .74379 .59742 L F
.472 0 .024 r
.35987 .65036 m .36218 .65044 L .36357 .6492 L F
.371 0 0 r
.36218 .65044 m .36543 .64949 L .36357 .6492 L F
.248 .692 .958 r
.31426 .59751 m .31207 .59748 L .31069 .59675 L F
.682 .583 .739 r
.51816 .73964 m .51818 .74125 L .51563 .74205 L F
.257 0 0 r
.45659 .78579 m .45518 .78629 L .45314 .78633 L F
.445 0 0 r
.45863 .78595 m .45518 .78629 L .45659 .78579 L F
.48 .449 .746 r
.4242 .7708 m .42547 .77571 L .42662 .77191 L F
.614 .29 .398 r
.48309 .75031 m .47967 .75251 L .48022 .75058 L F
.48309 .75031 m .48198 .75244 L .47967 .75251 L F
.952 .678 .48 r
.48429 .75581 m .48297 .75753 L .48284 .75516 L F
.758 .457 .475 r
.48309 .75031 m .48496 .75291 L .48198 .75244 L F
.882 .861 .815 r
.48429 .75581 m .48496 .75291 L .4852 .75472 L F
.48429 .75581 m .48284 .75516 L .48496 .75291 L F
0 0 0 r
.4852 .75472 m .48297 .75753 L .48429 .75581 L F
.217 0 0 r
.34444 .73097 m .34385 .73113 L .3409 .73076 L F
0 0 0 r
.34444 .73097 m .34343 .73127 L .34385 .73113 L F
.701 .786 .917 r
.34661 .73349 m .34343 .73127 L .34444 .73097 L F
.6 .379 .552 r
.3467 .73078 m .34661 .73349 L .34444 .73097 L F
.904 .492 .124 r
.72764 .5898 m .72939 .59126 L .72963 .59251 L F
.244 .181 .584 r
.56693 .70075 m .5682 .6973 L .5655 .69937 L F
.56693 .70075 m .56852 .69999 L .5682 .6973 L F
.256 .207 .609 r
.56693 .70075 m .56803 .70253 L .56852 .69999 L F
.421 .619 .933 r
.73116 .7301 m .73172 .72808 L .72938 .7285 L F
.73116 .7301 m .73297 .73018 L .73172 .72808 L F
.342 0 0 r
.51904 .79368 m .52078 .79398 L .51732 .79382 L F
.553 .539 .793 r
.43107 .66153 m .43224 .66503 L .43018 .66533 L F
0 0 .267 r
.31053 .72247 m .31091 .7249 L .31068 .72463 L F
.223 0 0 r
.31042 .72749 m .31068 .72463 L .31091 .7249 L F
.381 .694 .982 r
.28398 .60358 m .28529 .60471 L .28582 .60354 L F
.408 .725 .989 r
.28529 .60471 m .28688 .60446 L .28582 .60354 L F
.569 .531 .772 r
.31179 .71675 m .3105 .72009 L .30989 .71718 L F
.786 .29 .017 r
.56352 .7361 m .56524 .73813 L .56574 .73748 L F
.816 .336 .042 r
.56524 .73813 m .56691 .73876 L .56574 .73748 L F
.797 .572 .597 r
.60128 .6643 m .60474 .66487 L .60337 .66234 L F
0 0 0 r
.59932 .75923 m .59796 .76009 L .59632 .7607 L F
.60134 .75799 m .59796 .76009 L .59932 .75923 L F
.718 .477 .56 r
.59804 .67337 m .59449 .67555 L .5949 .67307 L F
.59804 .67337 m .5984 .67586 L .59449 .67555 L F
.906 .954 .818 r
.52363 .75299 m .52152 .75596 L .52057 .75532 L F
.576 .415 .627 r
.52397 .75535 m .52152 .75596 L .52363 .75299 L F
.559 .368 .578 r
.52152 .75596 m .52397 .75535 L .52057 .75532 L F
.52152 .75596 m .52382 .75803 L .52397 .75535 L F
.52397 .75535 m .52382 .75803 L .52152 .75596 L F
.419 .823 .979 r
.73453 .70969 m .73145 .7096 L .73368 .70903 L F
.379 .733 .99 r
.7356 .70873 m .73453 .70969 L .73368 .70903 L F
.7356 .70873 m .73671 .70962 L .73453 .70969 L F
.11 0 .345 r
.75054 .61494 m .75013 .61701 L .74826 .61805 L F
0 0 .12 r
.75013 .61701 m .74806 .61985 L .74826 .61805 L F
.282 0 .077 r
.53583 .79476 m .53657 .79622 L .53428 .79623 L F
.53583 .79476 m .53792 .7942 L .53657 .79622 L F
.782 .527 .55 r
.52863 .79358 m .53199 .79161 L .53066 .79006 L F
.52863 .79358 m .53203 .79387 L .53199 .79161 L F
.575 .361 .552 r
.53203 .79387 m .53467 .79171 L .53199 .79161 L F
.979 .685 .325 r
.74441 .59681 m .74344 .59557 L .74676 .596 L F
.74441 .59681 m .74379 .59742 L .74344 .59557 L F
.602 .098 .027 r
.45863 .78595 m .46217 .7863 L .46072 .78726 L F
.324 0 0 r
.46217 .7863 m .46295 .78702 L .46072 .78726 L F
.46217 .7863 m .46428 .78664 L .46295 .78702 L F
.55 .374 .595 r
.43526 .74461 m .43789 .74156 L .43537 .74206 L F
.654 .554 .729 r
.32238 .6955 m .32476 .69515 L .32399 .69174 L F
.593 .454 .661 r
.3227 .69803 m .32476 .69515 L .32238 .6955 L F
.549 .46 .708 r
.35544 .69188 m .3539 .69587 L .35281 .69249 L F
.35544 .69188 m .35533 .69569 L .3539 .69587 L F
.528 .436 .694 r
.35533 .69569 m .35424 .69778 L .3539 .69587 L F
.552 .437 .676 r
.32492 .68159 m .32721 .68122 L .32669 .67858 L F
.507 .339 .588 r
.32492 .68159 m .32691 .68352 L .32721 .68122 L F
.32492 .68159 m .325 .68405 L .32691 .68352 L F
.473 .336 .613 r
.59194 .71793 m .59309 .71938 L .59202 .71719 L F
.577 .365 .555 r
.47528 .75305 m .47733 .75503 L .47505 .75517 L F
.64 .357 .474 r
.47787 .75312 m .47733 .75503 L .47528 .75305 L F
.698 .835 .948 r
.49365 .74977 m .4908 .74966 L .49332 .74738 L F
.5 .568 .856 r
.496 .74881 m .49365 .74977 L .49332 .74738 L F
.596 .467 .674 r
.496 .74881 m .49271 .75257 L .49365 .74977 L F
.584 .295 .444 r
.40988 .66717 m .41023 .66516 L .40846 .66609 L F
.41 .225 .516 r
.41225 .66191 m .41199 .66457 L .41023 .66516 L F
.598 .484 .695 r
.40988 .66717 m .41199 .66457 L .41023 .66516 L F
0 0 0 r
.41199 .66457 m .40846 .66609 L .41023 .66516 L F
.41 .225 .516 r
.41225 .66191 m .41199 .66457 L .41023 .66516 L F
.615 .402 .57 r
.4023 .68408 m .40493 .68382 L .405 .68121 L F
.507 .313 .552 r
.40493 .68382 m .40708 .6809 L .405 .68121 L F
.69 .502 .628 r
.50997 .72775 m .51204 .72817 L .51201 .72557 L F
.587 .38 .567 r
.51204 .72817 m .51454 .72547 L .51201 .72557 L F
.079 0 0 r
.3785 .71569 m .37807 .71494 L .38008 .71428 L F
.3785 .71569 m .37654 .71634 L .37807 .71494 L F
.695 .806 .934 r
.52863 .79358 m .53044 .7951 L .53203 .79387 L F
.472 0 0 r
.51959 .78834 m .52173 .78879 L .52317 .78837 L F
.542 0 0 r
.52424 .78975 m .52317 .78837 L .52173 .78879 L F
.52424 .78975 m .52536 .78932 L .52317 .78837 L F
.227 0 .085 r
.38603 .69852 m .38506 .6999 L .38791 .69785 L F
.45 .883 .861 r
.51332 .74591 m .51196 .74625 L .51074 .74706 L F
0 0 0 r
.51196 .74625 m .51044 .74761 L .51074 .74706 L F
.695 .403 .476 r
.64404 .52093 m .64673 .5196 L .64419 .51976 L F
.876 .853 .817 r
.46249 .64314 m .45899 .64509 L .4625 .64576 L F
.56 .344 .544 r
.46249 .64314 m .4625 .64576 L .46394 .64381 L F
.45 .66 .951 r
.29203 .59343 m .29206 .59545 L .29023 .59385 L F
.29203 .59343 m .29395 .59542 L .29206 .59545 L F
.461 .22 .461 r
.40536 .69761 m .40516 .7004 L .40236 .7002 L F
.415 .181 .449 r
.40458 .70228 m .40236 .7002 L .40516 .7004 L F
.40458 .70228 m .40269 .70291 L .40236 .7002 L F
.401 0 .126 r
.57956 .6698 m .58177 .66958 L .5824 .66855 L F
.253 0 .047 r
.5824 .66855 m .58177 .66958 L .58381 .66891 L F
.652 .305 .371 r
.45485 .73935 m .45383 .74135 L .45691 .74128 L F
.563 .324 .511 r
.45485 .73935 m .45691 .74128 L .45714 .73908 L F
.371 .081 .336 r
.32357 .61746 m .32412 .6146 L .32618 .61504 L F
.435 .443 .769 r
.64183 .51285 m .63995 .51428 L .63965 .51221 L F
0 0 .398 r
.64183 .51285 m .64069 .51692 L .63995 .51428 L F
.56 .418 .645 r
.42709 .75813 m .42907 .75534 L .42699 .75574 L F
.178 0 .273 r
.71807 .60463 m .71764 .60655 L .7165 .60464 L F
.592 .937 .941 r
.71917 .60343 m .71807 .60463 L .7165 .60464 L F
.165 .277 .734 r
.71917 .60343 m .71995 .60649 L .71807 .60463 L F
.492 .337 .598 r
.32399 .69174 m .3258 .68938 L .32386 .68979 L F
.841 .648 .641 r
.741 .62372 m .73813 .62552 L .74026 .62279 L F
.983 .907 .638 r
.741 .62372 m .74026 .62279 L .74142 .61943 L F
.593 .454 .661 r
.3227 .69803 m .32492 .69774 L .32476 .69515 L F
.618 .476 .666 r
.32287 .70056 m .32492 .69774 L .3227 .69803 L F
.734 .49 .559 r
.56815 .69435 m .56832 .69625 L .57157 .69339 L F
0 0 .028 r
.57274 .69106 m .57157 .69339 L .57247 .69228 L F
.64 .928 .662 r
.57157 .69339 m .56832 .69625 L .57247 .69228 L F
.459 .797 .999 r
.28334 .59289 m .28286 .59398 L .28138 .59286 L F
.28334 .59289 m .28492 .59367 L .28286 .59398 L F
0 .057 .616 r
.32189 .7198 m .32352 .72206 L .32311 .72295 L F
.621 .958 .891 r
.32352 .72206 m .32204 .72272 L .32311 .72295 L F
.876 .617 .092 r
.72432 .71575 m .72492 .7183 L .72445 .71542 L F
.484 .012 .058 r
.72635 .71504 m .72432 .71575 L .72445 .71542 L F
.528 .436 .694 r
.35533 .69569 m .35624 .69735 L .35424 .69778 L F
.599 .552 .773 r
.35746 .7006 m .35424 .69778 L .35624 .69735 L F
.728 .374 .38 r
.52759 .79076 m .53066 .79006 L .52862 .78873 L F
.512 0 0 r
.49715 .79087 m .50051 .79068 L .49957 .79138 L F
.057 .615 .807 r
.50051 .79068 m .50274 .79078 L .50174 .79058 L F
0 0 0 r
.49957 .79138 m .50051 .79068 L .50174 .79058 L F
.31 .802 .841 r
.27565 .65554 m .27249 .6562 L .2736 .6563 L F
.736 .56 .654 r
.52831 .74729 m .52852 .75073 L .53151 .75018 L F
.514 .264 .474 r
.34462 .65657 m .34239 .65702 L .3442 .65868 L F
.056 0 0 r
.34239 .65702 m .33862 .65891 L .34072 .65874 L F
.648 .225 .227 r
.3442 .65868 m .34239 .65702 L .34072 .65874 L F
0 .144 .674 r
.29637 .74591 m .29537 .74612 L .29482 .74427 L F
.29637 .74591 m .29639 .74785 L .29537 .74612 L F
.622 .201 .223 r
.38517 .66749 m .38326 .66886 L .38176 .66757 L F
0 0 0 r
.38496 .66812 m .38517 .66749 L .38716 .66736 L F
.38496 .66812 m .38326 .66886 L .38517 .66749 L F
.297 .496 .883 r
.74617 .71645 m .74477 .7176 L .74421 .71636 L F
.74617 .71645 m .74776 .71899 L .74477 .7176 L F
.551 .342 .549 r
.43698 .67059 m .43684 .67287 L .43463 .6732 L F
.412 .184 .455 r
.43887 .67005 m .43698 .67059 L .43905 .66825 L F
.532 .364 .6 r
.43887 .67005 m .43684 .67287 L .43698 .67059 L F
.696 .502 .621 r
.55847 .75558 m .55654 .75753 L .55602 .75465 L F
.55847 .75558 m .55886 .75892 L .55654 .75753 L F
.077 .043 .513 r
.6178 .73028 m .61809 .73264 L .6167 .73378 L F
.322 .282 .657 r
.61809 .73264 m .61679 .73618 L .6167 .73378 L F
.657 .779 .939 r
.715 .58201 m .71286 .58319 L .71172 .58175 L F
.691 .419 .507 r
.5298 .71599 m .53171 .71471 L .53043 .71445 L F
.5298 .71599 m .53206 .71691 L .53171 .71471 L F
.507 0 0 r
.52218 .70535 m .52154 .70466 L .52065 .70305 L F
.52218 .70535 m .52349 .70615 L .52154 .70466 L F
0 0 .188 r
.62083 .71432 m .62066 .71654 L .61919 .71738 L F
.743 .922 .565 r
.62066 .71654 m .61881 .7196 L .61919 .71738 L F
.748 .604 .697 r
.63244 .52159 m .63423 .52501 L .63063 .52457 L F
.762 .581 .652 r
.6339 .52694 m .63063 .52457 L .63423 .52501 L F
0 .108 .626 r
.57931 .71555 m .57787 .71477 L .57726 .71351 L F
.57931 .71555 m .57882 .71677 L .57787 .71477 L F
.793 .685 .745 r
.715 .58201 m .71828 .58266 L .7172 .57947 L F
.63 .098 0 r
.71672 .58271 m .71828 .58266 L .715 .58201 L F
.377 .437 .797 r
.7172 .57947 m .71828 .58266 L .71986 .58062 L F
.717 .953 .951 r
.71986 .58062 m .71828 .58266 L .71672 .58271 L F
.885 .905 .837 r
.72089 .59826 m .72188 .59915 L .7241 .59636 L F
.826 .906 .895 r
.52068 .74026 m .51877 .73899 L .51658 .74095 L F
.66 .572 .745 r
.52152 .74288 m .51818 .74125 L .52068 .74026 L F
.327 0 .031 r
.51661 .74332 m .52068 .74026 L .51658 .74095 L F
.51661 .74332 m .51874 .7428 L .52068 .74026 L F
.09 .524 .906 r
.52068 .74026 m .52111 .73913 L .51877 .73899 L F
.614 .843 .986 r
.52416 .74036 m .52374 .74111 L .52568 .74117 L F
.5239 .74127 m .52338 .74176 L .52418 .74155 L F
.52364 .74129 m .52338 .74176 L .5239 .74127 L F
.567 .459 .691 r
.52068 .74026 m .52338 .74176 L .52152 .74288 L F
.692 .369 .425 r
.51874 .7428 m .52458 .74148 L .5239 .74127 L F
.51964 .74162 m .5239 .74127 L .52068 .74026 L F
.51874 .7428 m .5239 .74127 L .51964 .74162 L F
.09 .524 .906 r
.52068 .74026 m .5239 .74127 L .52111 .73913 L F
.614 .843 .986 r
.52374 .74111 m .52364 .74129 L .5239 .74127 L F
.52374 .74111 m .52418 .74155 L .52568 .74117 L F
.09 .524 .906 r
.5239 .74127 m .52458 .74148 L .52314 .74051 L F
.5239 .74127 m .52314 .74051 L .52111 .73913 L F
.608 .048 0 r
.65355 .52157 m .65588 .52355 L .65542 .52283 L F
.471 .502 .809 r
.65542 .52283 m .6588 .52441 L .65709 .52482 L F
.544 0 0 r
.65588 .52355 m .6588 .52441 L .65542 .52283 L F
.688 .308 .321 r
.49234 .74418 m .48969 .74196 L .49066 .74134 L F
.49234 .74418 m .49131 .74421 L .48969 .74196 L F
0 0 .237 r
.71187 .72219 m .71246 .71893 L .71108 .72008 L F
.497 .444 .728 r
.32994 .60432 m .33064 .60797 L .32881 .60747 L F
.502 .401 .672 r
.33064 .60797 m .32908 .60994 L .32881 .60747 L F
.018 .229 .736 r
.5787 .73872 m .57653 .73568 L .57653 .73722 L F
.802 .498 .474 r
.31672 .7098 m .3154 .71093 L .31568 .70986 L F
.908 .694 .602 r
.3154 .71093 m .31703 .71204 L .31672 .7098 L F
.834 .782 .803 r
.31672 .7098 m .31796 .70584 L .31959 .70915 L F
.498 0 0 r
.31392 .70958 m .31568 .70986 L .31672 .7098 L F
.834 .782 .803 r
.31672 .7098 m .31568 .70986 L .31796 .70584 L F
0 0 0 r
.31829 .70899 m .31672 .7098 L .31959 .70915 L F
.568 .384 .592 r
.31959 .70915 m .31703 .71204 L .31672 .7098 L F
0 0 0 r
.31829 .70899 m .3154 .71093 L .31672 .7098 L F
0 0 .387 r
.61874 .72194 m .61873 .72431 L .61749 .72551 L F
0 0 .398 r
.61873 .72431 m .61736 .728 L .61749 .72551 L F
.399 .105 .346 r
.56927 .67587 m .57102 .67588 L .57206 .67329 L F
.297 .009 .294 r
.57206 .67329 m .57338 .67484 L .57431 .67291 L F
.57206 .67329 m .57102 .67588 L .57338 .67484 L F
.999 .792 .479 r
.60341 .71952 m .60281 .72188 L .60235 .71948 L F
.764 .893 .935 r
.73873 .73087 m .73977 .7318 L .74155 .73054 L F
.477 .222 .447 r
.4199 .68608 m .41716 .68919 L .41777 .68657 L F
.413 .652 .957 r
.585 .70527 m .5868 .70601 L .58505 .70621 L F
.267 .388 .8 r
.58758 .70851 m .58505 .70621 L .5868 .70601 L F
0 0 .243 r
.58505 .70621 m .58598 .70744 L .585 .70527 L F
.58505 .70621 m .58463 .70878 L .58598 .70744 L F
.31 0 .25 r
.5956 .72897 m .59469 .73065 L .59788 .72828 L F
.439 .31 .607 r
.42924 .753 m .4311 .75254 L .43098 .75001 L F
.57 .363 .561 r
.42924 .753 m .43138 .75499 L .4311 .75254 L F
.42924 .753 m .42907 .75534 L .43138 .75499 L F
.503 .762 .989 r
.40209 .66863 m .40256 .667 L .40054 .66719 L F
.40209 .66863 m .40424 .66837 L .40256 .667 L F
0 0 .468 r
.49556 .75579 m .49629 .75247 L .4967 .75414 L F
.534 .593 .86 r
.49997 .7549 m .4983 .75564 L .4967 .75414 L F
.534 0 0 r
.49629 .75247 m .49997 .7549 L .4967 .75414 L F
0 0 .468 r
.49556 .75579 m .49718 .75501 L .49629 .75247 L F
.627 .612 .816 r
.4967 .75414 m .4983 .75564 L .49556 .75579 L F
.606 .373 .537 r
.4983 .75564 m .49777 .75809 L .49556 .75579 L F
.875 .879 .835 r
.49777 .75809 m .49718 .75501 L .49556 .75579 L F
.741 .394 .394 r
.30462 .72843 m .30228 .73007 L .30435 .7272 L F
.30462 .72843 m .30582 .73041 L .30228 .73007 L F
.611 .557 .769 r
.40988 .66717 m .41114 .67052 L .41342 .67008 L F
.626 .488 .674 r
.41121 .67279 m .41342 .67008 L .41114 .67052 L F
.486 .316 .576 r
.33047 .66776 m .33246 .66952 L .33258 .66729 L F
.33047 .66776 m .33044 .66984 L .33246 .66952 L F
.906 .954 .818 r
.52363 .75299 m .52057 .75532 L .52397 .75535 L F
.55 .397 .626 r
.52363 .75299 m .52397 .75535 L .52583 .7526 L F
.332 .1 .404 r
.31297 .63141 m .31283 .62957 L .31528 .62848 L F
.59 .674 .898 r
.73366 .73172 m .73542 .72985 L .73297 .73018 L F
.73366 .73172 m .73605 .7314 L .73542 .72985 L F
.95 .746 .592 r
.63123 .53601 m .63103 .53838 L .62989 .53514 L F
.825 .484 .41 r
.63123 .53601 m .63425 .53855 L .63103 .53838 L F
.968 .901 .701 r
.73098 .71958 m .73125 .72208 L .7339 .71972 L F
.973 .831 .642 r
.72968 .71877 m .72886 .72155 L .73014 .7217 L F
.435 .516 .843 r
.72904 .72148 m .73014 .7217 L .72886 .72155 L F
.968 .901 .701 r
.73098 .71958 m .73014 .7217 L .73123 .72192 L F
.91 .804 .729 r
.72968 .71877 m .73014 .7217 L .73098 .71958 L F
.435 .516 .843 r
.73209 .72034 m .73014 .7217 L .72904 .72148 L F
.968 .901 .701 r
.73123 .72192 m .73014 .7217 L .73125 .72208 L F
0 .266 .773 r
.73343 .72298 m .73367 .72406 L .73125 .72208 L F
.73343 .72298 m .73125 .72208 L .73014 .7217 L F
.341 0 .155 r
.37404 .6709 m .37293 .67279 L .37111 .67255 L F
.333 0 .151 r
.37495 .67236 m .37404 .6709 L .37612 .67044 L F
.37495 .67236 m .37293 .67279 L .37404 .6709 L F
0 0 0 r
.31553 .71913 m .31835 .71751 L .31526 .71707 L F
.31553 .71913 m .31669 .71888 L .31835 .71751 L F
.688 .313 .332 r
.32124 .72177 m .32352 .72206 L .3223 .72037 L F
.32169 .7204 m .3223 .72037 L .32189 .7198 L F
.32124 .72177 m .3223 .72037 L .32169 .7204 L F
.409 .001 .151 r
.31823 .72187 m .32189 .7198 L .32169 .7204 L F
.777 .696 .775 r
.32145 .72042 m .31823 .72187 L .32169 .7204 L F
.409 .001 .151 r
.31823 .72187 m .32145 .72042 L .32189 .7198 L F
.777 .696 .775 r
.31758 .72061 m .31823 .72187 L .32145 .72042 L F
.727 .511 .597 r
.32054 .72168 m .32204 .72272 L .32352 .72206 L F
.715 .413 .465 r
.32054 .72168 m .32222 .72268 L .32352 .72206 L F
.214 .493 .9 r
.32054 .72168 m .32222 .72268 L .32177 .72194 L F
.409 .001 .151 r
.31925 .72141 m .32054 .72168 L .32145 .72042 L F
.688 .313 .332 r
.32054 .72168 m .32124 .72177 L .32139 .72131 L F
.32054 .72168 m .32139 .72131 L .32189 .7198 L F
.777 .696 .775 r
.31758 .72061 m .32169 .7204 L .32189 .72032 L F
.31669 .71888 m .31758 .72061 L .32189 .72032 L F
.409 .001 .151 r
.32169 .7204 m .32189 .7198 L .32189 .72032 L F
.785 .388 .302 r
.31669 .71888 m .32173 .72028 L .31835 .71751 L F
.32173 .72028 m .32189 .72032 L .32178 .72023 L F
.32173 .72028 m .32178 .72023 L .31835 .71751 L F
.787 .37 .26 r
.31835 .71751 m .32189 .72032 L .32189 .7198 L F
.825 .953 .608 r
.32216 .7189 m .32082 .7212 L .3208 .72034 L F
.32082 .7212 m .32054 .72168 L .32059 .72144 L F
.32082 .7212 m .32059 .72144 L .3208 .72034 L F
.715 .623 .754 r
.32216 .7189 m .32352 .72206 L .32054 .72168 L F
.214 .493 .9 r
.32054 .72168 m .32177 .72194 L .3208 .72034 L F
.409 .001 .151 r
.31823 .72187 m .32054 .72168 L .31925 .72141 L F
.711 .385 .424 r
.36286 .84857 m .36648 .84936 L .36346 .84694 L F
.423 .183 .443 r
.54717 .68954 m .5489 .69144 L .54868 .68906 L F
.54717 .68954 m .54677 .69238 L .5489 .69144 L F
0 .203 .729 r
.55037 .72626 m .54904 .72585 L .54826 .72445 L F
.717 .188 0 r
.54904 .72585 m .55109 .72774 L .5526 .72814 L F
0 .203 .729 r
.55037 .72626 m .55109 .72774 L .54904 .72585 L F
.487 .231 .452 r
.41004 .69468 m .40762 .69705 L .40794 .69514 L F
.469 .689 .963 r
.40848 .65236 m .40762 .65388 L .4056 .65204 L F
.40848 .65236 m .40954 .65371 L .40762 .65388 L F
.369 .721 .988 r
.39706 .65059 m .3989 .65118 L .39835 .65161 L F
.6 .33 .48 r
.49209 .73907 m .49407 .7412 L .49066 .74134 L F
.818 .646 .669 r
.61953 .68377 m .61736 .68651 L .62048 .68692 L F
.84 .615 .597 r
.61736 .68651 m .62045 .68955 L .62048 .68692 L F
.141 .465 .891 r
.71787 .5959 m .71834 .59715 L .72089 .59826 L F
.454 .527 .843 r
.33052 .71128 m .33234 .71455 L .33372 .71391 L F
.516 .438 .706 r
.52338 .74176 m .52174 .7445 L .52152 .74288 L F
.52338 .74176 m .52402 .7444 L .52174 .7445 L F
.489 .166 .344 r
.39843 .70399 m .39783 .70561 L .39565 .70591 L F
.468 .153 .348 r
.40058 .70358 m .39783 .70561 L .39843 .70399 L F
.456 .053 .185 r
.49271 .75257 m .49081 .75427 L .49464 .75349 L F
.161 .199 .653 r
.54373 .73553 m .54215 .73697 L .54173 .73253 L F
0 0 0 r
.54373 .73553 m .54118 .73854 L .54215 .73697 L F
.654 .381 .493 r
.30789 .71824 m .31179 .71675 L .30989 .71718 L F
.198 .05 .443 r
.41225 .66191 m .41199 .66457 L .41305 .66205 L F
.41225 .66191 m .41199 .66457 L .41305 .66205 L F
.639 .116 0 r
.54584 .74143 m .54938 .74216 L .54723 .74132 L F
.885 .905 .837 r
.72089 .59826 m .7241 .59636 L .72153 .59618 L F
.705 .243 .152 r
.46186 .77734 m .4651 .77809 L .46319 .77778 L F
.228 0 .127 r
.50681 .73052 m .50997 .72775 L .5065 .72813 L F
.434 .871 .904 r
.36543 .64949 m .36781 .64888 L .3691 .64889 L F
.027 .591 .794 r
.36991 .64875 m .3691 .64889 L .36781 .64888 L F
.36991 .64875 m .37131 .64904 L .3691 .64889 L F
.936 .788 .672 r
.60519 .69733 m .60667 .69818 L .60591 .7004 L F
.531 .021 0 r
.49814 .78667 m .49938 .78576 L .49587 .78582 L F
.448 0 0 r
.50043 .7868 m .49938 .78576 L .49814 .78667 L F
.50043 .7868 m .50152 .78645 L .49938 .78576 L F
.585 .45 .663 r
.42508 .76113 m .42749 .76123 L .42709 .75813 L F
.49 .368 .64 r
.42573 .76396 m .42749 .76123 L .42508 .76113 L F
.201 .381 .818 r
.58421 .75596 m .5853 .75511 L .58426 .75491 L F
.223 .422 .846 r
.58421 .75596 m .58678 .75767 L .5853 .75511 L F
0 0 .03 r
.2823 .63825 m .28126 .64028 L .2831 .63703 L F
.824 .505 .449 r
.52852 .75073 m .53115 .75289 L .53151 .75018 L F
.719 .552 .662 r
.53151 .75018 m .53115 .75289 L .53487 .75287 L F
.269 0 0 r
.46656 .78671 m .46778 .78649 L .47028 .78695 L F
.487 .237 .461 r
.43463 .6732 m .43437 .67543 L .43211 .67586 L F
.561 .3 .478 r
.43663 .675 m .43463 .6732 L .43684 .67287 L F
.43663 .675 m .43437 .67543 L .43463 .6732 L F
.883 .713 .665 r
.60561 .70642 m .60504 .70872 L .60383 .70559 L F
.649 .555 .735 r
.52084 .71683 m .51899 .71979 L .51864 .71724 L F
.59 .479 .696 r
.51899 .71979 m .52084 .71683 L .51864 .71724 L F
.483 .352 .626 r
.53424 .78867 m .53467 .79171 L .53645 .79073 L F
.974 .705 .459 r
.56564 .77498 m .56386 .77577 L .5644 .77425 L F
.56564 .77498 m .56465 .77709 L .56386 .77577 L F
.464 .805 .999 r
.5644 .77425 m .56695 .77403 L .56564 .77498 L F
.264 0 .126 r
.5667 .77635 m .56564 .77498 L .56695 .77403 L F
.5667 .77635 m .56465 .77709 L .56564 .77498 L F
.547 .297 .488 r
.44119 .66968 m .43905 .66825 L .4402 .66574 L F
.44119 .66968 m .43887 .67005 L .43905 .66825 L F
.888 .877 .819 r
.49287 .73573 m .49423 .73664 L .49632 .73365 L F
.476 .757 .992 r
.49506 .7353 m .49423 .73664 L .49287 .73573 L F
.555 .384 .604 r
.49423 .73664 m .49665 .73645 L .49632 .73365 L F
.476 .757 .992 r
.49506 .7353 m .49665 .73645 L .49423 .73664 L F
.421 0 0 r
.49261 .78597 m .49374 .78538 L .49025 .78577 L F
.351 0 0 r
.49437 .7859 m .49374 .78538 L .49261 .78597 L F
.49437 .7859 m .49587 .78582 L .49374 .78538 L F
.244 .487 .89 r
.54652 .72218 m .54538 .72298 L .5444 .72226 L F
.54652 .72218 m .54826 .72445 L .54538 .72298 L F
.603 .316 .454 r
.71472 .71418 m .72009 .71417 L .71779 .71174 L F
.671 .307 .347 r
.71779 .71174 m .72022 .7137 L .71957 .71107 L F
.71779 .71174 m .72009 .71417 L .72022 .7137 L F
0 .086 .644 r
.46435 .76617 m .46357 .76489 L .4638 .76733 L F
.46357 .76489 m .463 .76394 L .46346 .76589 L F
.46357 .76489 m .46346 .76589 L .4638 .76733 L F
.464 .258 .514 r
.46175 .76778 m .4629 .76875 L .46328 .76746 L F
.46344 .76606 m .46328 .76746 L .46379 .7657 L F
.46175 .76778 m .46328 .76746 L .46344 .76606 L F
.532 .383 .623 r
.46379 .7657 m .4638 .76733 L .463 .76394 L F
.564 .398 .614 r
.463 .76394 m .46175 .76778 L .46379 .7657 L F
.714 .477 .564 r
.32762 .60246 m .3303 .60186 L .32994 .60432 L F
.954 .722 .55 r
.32994 .60432 m .3303 .60186 L .32885 .60183 L F
.43 .239 .518 r
.49643 .72002 m .49631 .72232 L .49831 .71945 L F
.892 .551 .396 r
.49259 .74496 m .49332 .74738 L .49151 .74623 L F
.938 .933 .579 r
.49259 .74496 m .49151 .74623 L .49234 .74418 L F
.892 .551 .396 r
.49259 .74496 m .49332 .74738 L .49151 .74623 L F
.608 .781 .964 r
.53514 .76879 m .53285 .76938 L .53131 .76834 L F
.602 .104 .045 r
.53514 .76879 m .53131 .76834 L .53285 .76938 L F
.376 .723 .989 r
.25977 .58741 m .25856 .58809 L .25779 .5877 L F
.512 .646 .916 r
.42775 .65869 m .42582 .65904 L .42398 .65662 L F
.645 .293 .361 r
.56405 .75788 m .56062 .75852 L .56185 .75791 L F
.116 0 .207 r
.4688 .77765 m .47055 .77711 L .47117 .77451 L F
0 0 .082 r
.47117 .77451 m .47134 .77631 L .47326 .77445 L F
.47117 .77451 m .47076 .77625 L .47134 .77631 L F
.641 .612 .805 r
.47057 .77556 m .47178 .77636 L .47134 .77631 L F
.906 .812 .744 r
.47487 .77664 m .47309 .77973 L .47586 .77762 L F
.928 .855 .749 r
.47181 .77865 m .47487 .77664 L .47134 .77631 L F
.47181 .77865 m .47309 .77973 L .47395 .77823 L F
.47331 .77767 m .47395 .77823 L .47487 .77664 L F
.47181 .77865 m .47395 .77823 L .47331 .77767 L F
.641 .612 .805 r
.47178 .77636 m .47194 .77647 L .47134 .77631 L F
.47194 .77647 m .47431 .77805 L .47261 .77706 L F
.47194 .77647 m .47261 .77706 L .47134 .77631 L F
0 0 .082 r
.47076 .77625 m .47055 .77711 L .47134 .77631 L F
.676 .47 .6 r
.65709 .52482 m .65697 .52727 L .65453 .52719 L F
.604 .41 .591 r
.66003 .52674 m .65709 .52482 L .6588 .52441 L F
.66003 .52674 m .65697 .52727 L .65709 .52482 L F
.414 .047 .229 r
.47822 .73311 m .48147 .73051 L .47827 .7319 L F
.47822 .73311 m .4804 .73274 L .48147 .73051 L F
.503 .153 .306 r
.4804 .73274 m .48363 .73022 L .48147 .73051 L F
.907 .596 .447 r
.60303 .68142 m .60135 .68087 L .60108 .67876 L F
.901 .626 .511 r
.60303 .68142 m .60143 .6832 L .60135 .68087 L F
.60303 .68142 m .60325 .68394 L .60143 .6832 L F
.898 .783 .726 r
.63244 .52159 m .63014 .5215 L .63162 .51855 L F
.89 .814 .767 r
.63244 .52159 m .63063 .52457 L .63014 .5215 L F
.467 .854 .98 r
.41774 .8537 m .41928 .8541 L .41695 .8546 L F
.41774 .8537 m .41928 .8541 L .41695 .8546 L F
.501 .564 .852 r
.35373 .86692 m .35654 .86811 L .35361 .86637 L F
0 0 0 r
.35387 .87026 m .35654 .86811 L .35612 .87056 L F
.665 .437 .565 r
.35612 .87056 m .35373 .86692 L .35387 .87026 L F
.35612 .87056 m .35654 .86811 L .35373 .86692 L F
.55 .002 0 r
.50706 .78804 m .51046 .78849 L .50868 .78777 L F
.823 .616 .624 r
.61604 .68107 m .61589 .68346 L .61953 .68377 L F
.823 .654 .673 r
.61589 .68346 m .61736 .68651 L .61953 .68377 L F
0 0 0 r
.52329 .79411 m .52546 .79337 L .52543 .79352 L F
.133 0 0 r
.52546 .79337 m .52863 .79358 L .52543 .79352 L F
.466 .132 .315 r
.42943 .67885 m .42675 .68074 L .42717 .67923 L F
0 0 0 r
.38211 .71366 m .38569 .71158 L .38412 .713 L F
.143 0 0 r
.38618 .71244 m .38569 .71158 L .38776 .71108 L F
.38618 .71244 m .38412 .713 L .38569 .71158 L F
0 .259 .689 r
.57361 .71122 m .57726 .71351 L .57463 .71247 L F
.963 .769 .595 r
.60419 .68696 m .60291 .68631 L .60325 .68394 L F
.935 .68 .525 r
.60419 .68696 m .60268 .68869 L .60291 .68631 L F
.60419 .68696 m .60425 .68943 L .60268 .68869 L F
.972 .821 .634 r
.31529 .72839 m .31469 .73134 L .31339 .7301 L F
.971 .815 .631 r
.31529 .72839 m .31339 .7301 L .31415 .72775 L F
.424 .321 .634 r
.31339 .7301 m .3143 .72847 L .31415 .72775 L F
.629 .881 .988 r
.31529 .72839 m .31415 .72775 L .31513 .72664 L F
.424 .321 .634 r
.3143 .72847 m .31544 .72642 L .31512 .72676 L F
.3143 .72847 m .31512 .72676 L .31415 .72775 L F
.629 .881 .988 r
.31529 .72839 m .31514 .72672 L .31693 .72486 L F
.31514 .72672 m .31513 .72664 L .31521 .72656 L F
.31514 .72672 m .31521 .72656 L .31693 .72486 L F
.003 0 0 r
.37131 .64904 m .37344 .64858 L .37472 .64802 L F
.246 0 0 r
.37344 .64858 m .37685 .64807 L .37472 .64802 L F
.992 .876 .6 r
.32336 .7307 m .32409 .73095 L .32255 .73263 L F
.616 .942 .948 r
.32471 .72982 m .32409 .73095 L .32336 .7307 L F
.672 .896 .545 r
.32255 .73263 m .32409 .73095 L .32471 .72982 L F
.446 .391 .703 r
.33417 .72505 m .33642 .72728 L .33662 .72458 L F
.475 .41 .704 r
.45066 .76564 m .44939 .76932 L .44903 .76659 L F
.526 .422 .679 r
.4242 .7708 m .42662 .77191 L .42635 .76902 L F
.045 .61 .779 r
.29395 .59542 m .29596 .59547 L .2976 .59563 L F
0 .525 .71 r
.2976 .59563 m .29596 .59547 L .29954 .59581 L F
.272 .777 .847 r
.37685 .64807 m .37895 .64764 L .38048 .64762 L F
.307 .739 .97 r
.37895 .64764 m .38248 .64823 L .38048 .64762 L F
.661 .417 .54 r
.63425 .53855 m .63103 .54077 L .63103 .53838 L F
.63425 .53855 m .63434 .54064 L .63103 .54077 L F
.578 .356 .542 r
.63662 .53821 m .63434 .54064 L .63425 .53855 L F
.523 .657 .92 r
.58767 .75933 m .58896 .75744 L .58678 .75767 L F
.58767 .75933 m .59024 .75918 L .58896 .75744 L F
.805 .702 .751 r
.72017 .58846 m .72199 .58785 L .72078 .58606 L F
.755 .829 .909 r
.71905 .59011 m .72199 .58785 L .72017 .58846 L F
.604 .662 .879 r
.72199 .58785 m .72342 .58532 L .72078 .58606 L F
.72199 .58785 m .72513 .58853 L .72342 .58532 L F
.963 .852 .684 r
.70767 .58296 m .70617 .5836 L .70913 .58138 L F
.009 .037 .54 r
.45502 .774 m .45385 .77204 L .45465 .77166 L F
.45502 .774 m .45413 .77561 L .45385 .77204 L F
.58 .311 .474 r
.45495 .76049 m .45299 .75867 L .45581 .75788 L F
.45495 .76049 m .45272 .76077 L .45299 .75867 L F
.376 .033 .25 r
.37228 .67439 m .37111 .67255 L .37293 .67279 L F
.37228 .67439 m .37025 .6749 L .37111 .67255 L F
.632 .47 .645 r
.55298 .75827 m .5508 .76109 L .55065 .75855 L F
.77 .416 .385 r
.60128 .6643 m .60346 .66674 L .60474 .66487 L F
.807 .465 .41 r
.60474 .66487 m .60346 .66674 L .60645 .66716 L F
.474 0 0 r
.4651 .77809 m .46752 .7787 L .4688 .77765 L F
.571 .29 .45 r
.46752 .7787 m .47055 .77711 L .4688 .77765 L F
.568 .384 .592 r
.31959 .70915 m .31887 .71249 L .31703 .71204 L F
.545 .447 .694 r
.31703 .71204 m .31999 .71434 L .31887 .71249 L F
.483 .23 .455 r
.32908 .60994 m .32882 .61087 L .32677 .61208 L F
.502 .401 .672 r
.33064 .60797 m .33036 .60914 L .32908 .60994 L F
.469 .274 .533 r
.33036 .60914 m .32882 .61087 L .32908 .60994 L F
.888 .877 .819 r
.49287 .73573 m .49632 .73365 L .49506 .7353 L F
.644 .448 .603 r
.49632 .73365 m .49665 .73645 L .49832 .73393 L F
.335 .226 .579 r
.49632 .73365 m .49821 .73525 L .49832 .73393 L F
.49632 .73365 m .49665 .73645 L .49821 .73525 L F
.616 .192 .214 r
.49832 .73393 m .49506 .7353 L .49632 .73365 L F
.668 .761 .92 r
.4359 .66559 m .43224 .66503 L .43429 .66492 L F
.314 0 0 r
.43429 .66492 m .43785 .66464 L .4359 .66559 L F
.681 .585 .741 r
.70696 .59646 m .70724 .59898 L .70944 .59611 L F
0 .369 .675 r
.55109 .72774 m .55493 .72901 L .5526 .72814 L F
.406 .471 .814 r
.5666 .76906 m .56778 .77215 L .56846 .77087 L F
.383 .166 .456 r
.49861 .71728 m .49831 .71945 L .50044 .71661 L F
.812 .548 .538 r
.52859 .71408 m .5298 .71599 L .53043 .71445 L F
.658 .629 .809 r
.4908 .74966 m .48883 .7506 L .4873 .74754 L F
.416 .183 .451 r
.40711 .69973 m .40536 .69761 L .40762 .69705 L F
.40711 .69973 m .40516 .7004 L .40536 .69761 L F
.316 0 0 r
.58684 .67606 m .58566 .67723 L .58354 .67728 L F
.49 .041 .111 r
.58899 .67586 m .58566 .67723 L .58684 .67606 L F
.257 0 0 r
.58915 .67562 m .58899 .67586 L .58684 .67606 L F
.989 .824 .587 r
.6224 .70487 m .62373 .70329 L .62272 .70263 L F
.6224 .70487 m .6233 .70579 L .62373 .70329 L F
.328 0 .083 r
.48844 .72779 m .49065 .72732 L .49181 .72551 L F
.185 0 .005 r
.49181 .72551 m .49258 .72664 L .49327 .72486 L F
.49181 .72551 m .49065 .72732 L .49258 .72664 L F
.517 .776 .991 r
.32527 .60098 m .32464 .60243 L .32313 .60106 L F
.32527 .60098 m .32678 .60206 L .32464 .60243 L F
.508 .787 .995 r
.32762 .60246 m .32464 .60243 L .32678 .60206 L F
.602 .16 .173 r
.50431 .74936 m .50128 .7495 L .502 .748 L F
.873 .649 .595 r
.60645 .66716 m .60798 .67015 L .6081 .66775 L F
0 0 .336 r
.29329 .74741 m .29379 .74451 L .29482 .74427 L F
.29329 .74741 m .29378 .74688 L .29379 .74451 L F
.975 .704 .454 r
.53268 .75566 m .53247 .75741 L .53149 .75544 L F
0 0 0 r
.53268 .75566 m .53487 .75287 L .53115 .75289 L F
.53268 .75566 m .53377 .75482 L .53487 .75287 L F
.591 .317 .47 r
.53472 .75561 m .53483 .75737 L .53268 .75566 L F
.53483 .75737 m .53485 .75762 L .53458 .75738 L F
.53483 .75737 m .53458 .75738 L .53268 .75566 L F
.117 .281 .755 r
.53377 .75482 m .53485 .75762 L .53268 .75566 L F
.569 .574 .818 r
.53377 .75482 m .53248 .75739 L .53149 .75544 L F
.53248 .75739 m .53247 .75741 L .53247 .7574 L F
.53248 .75739 m .53247 .7574 L .53149 .75544 L F
.55 .369 .589 r
.40017 .68702 m .4023 .68408 L .3999 .68438 L F
0 0 .398 r
.64183 .51285 m .64187 .51544 L .6407 .51689 L F
.993 .742 .404 r
.64096 .51416 m .64187 .51544 L .64187 .5153 L F
.64096 .51416 m .64187 .5153 L .64183 .51285 L F
.2 .531 .923 r
.64183 .51285 m .63965 .51221 L .63887 .51092 L F
.64183 .51285 m .63887 .51092 L .64086 .50968 L F
.29 .379 .781 r
.64325 .5114 m .64183 .51285 L .64086 .50968 L F
0 0 0 r
.64096 .51416 m .64183 .51285 L .64325 .5114 L F
.875 .888 .839 r
.64008 .51306 m .64096 .51416 L .64325 .5114 L F
.63988 .51317 m .64096 .51416 L .64008 .51306 L F
.688 .177 .015 r
.64096 .51416 m .64248 .51469 L .64187 .51544 L F
.64248 .51469 m .64453 .51539 L .64187 .51544 L F
0 0 .398 r
.6407 .51689 m .64187 .51544 L .64069 .51692 L F
.352 .509 .874 r
.64187 .51544 m .64337 .51806 L .64069 .51692 L F
0 0 .061 r
.62098 .71578 m .62083 .71432 L .62178 .71322 L F
.62098 .71578 m .62066 .71654 L .62083 .71432 L F
.23 0 0 r
.54473 .73182 m .54345 .73271 L .54173 .73253 L F
.356 0 0 r
.54588 .73256 m .54473 .73182 L .547 .73127 L F
.54588 .73256 m .54345 .73271 L .54473 .73182 L F
.564 .747 .963 r
.45502 .774 m .456 .77519 L .45413 .77561 L F
.169 0 0 r
.51481 .79322 m .51732 .79382 L .51383 .79299 L F
0 0 .425 r
.47357 .75705 m .47271 .75606 L .47505 .75517 L F
.47357 .75705 m .47315 .7584 L .47271 .75606 L F
.762 .581 .652 r
.6339 .52694 m .62997 .5276 L .63063 .52457 L F
.769 .617 .69 r
.6339 .52694 m .63211 .53011 L .62997 .5276 L F
.375 .713 .987 r
.74118 .59559 m .74249 .59462 L .74002 .59502 L F
.045 0 0 r
.26531 .60529 m .26345 .60628 L .26157 .60664 L F
0 0 0 r
.26529 .60542 m .26531 .60529 L .26714 .60439 L F
.26529 .60542 m .26345 .60628 L .26531 .60529 L F
.49 .368 .64 r
.42573 .76396 m .42772 .76375 L .42749 .76123 L F
.59 .465 .678 r
.42573 .76396 m .42816 .76581 L .42772 .76375 L F
.42573 .76396 m .42609 .76637 L .42816 .76581 L F
.858 .615 .57 r
.61317 .67804 m .61604 .68107 L .61604 .67871 L F
.414 .185 .455 r
.64673 .5196 m .64999 .52053 L .64955 .52003 L F
.593 .787 .973 r
.4056 .65204 m .40408 .65262 L .4017 .65162 L F
.917 .771 .685 r
.61936 .69454 m .622 .69567 L .62204 .69253 L F
.835 .514 .445 r
.61874 .69673 m .622 .69567 L .61936 .69454 L F
.745 .238 .009 r
.62266 .69859 m .62209 .69942 L .62328 .70011 L F
.62266 .69859 m .62247 .69957 L .62209 .69942 L F
.835 .514 .445 r
.61874 .69673 m .62247 .69957 L .622 .69567 L F
.892 .608 .098 r
.622 .69567 m .62247 .69957 L .62266 .69859 L F
.209 0 0 r
.59352 .76086 m .59632 .7607 L .59499 .76108 L F
.367 .836 .844 r
.59632 .7607 m .59796 .76009 L .59779 .75998 L F
.343 .814 .741 r
.59499 .76108 m .59632 .7607 L .59779 .75998 L F
.823 .443 .335 r
.55937 .69429 m .56152 .69756 L .56399 .69611 L F
0 0 0 r
.56399 .69611 m .56366 .6964 L .5638 .69465 L F
.56399 .69611 m .56152 .69756 L .56366 .6964 L F
.077 0 .321 r
.46562 .7527 m .4653 .75472 L .4638 .7555 L F
.557 .14 .207 r
.4651 .75723 m .4638 .7555 L .4653 .75472 L F
.4651 .75723 m .46265 .75735 L .4638 .7555 L F
.354 .701 .984 r
.73192 .59382 m .73343 .59289 L .73087 .59299 L F
.73192 .59382 m .73439 .59403 L .73343 .59289 L F
.484 .012 .058 r
.72635 .71504 m .72576 .71648 L .72432 .71575 L F
0 0 0 r
.72813 .7143 m .72635 .71504 L .72869 .71505 L F
.72813 .7143 m .72576 .71648 L .72635 .71504 L F
.72813 .7143 m .72576 .71648 L .72635 .71504 L F
.448 .1 .282 r
.3802 .66785 m .37842 .67012 L .37612 .67044 L F
.092 0 .021 r
.38019 .66905 m .3802 .66785 L .38176 .66757 L F
.38019 .66905 m .37842 .67012 L .3802 .66785 L F
.513 .284 .504 r
.47967 .75251 m .47733 .75503 L .47787 .75312 L F
.433 .268 .557 r
.33266 .66487 m .33434 .66676 L .33437 .66434 L F
.33266 .66487 m .33258 .66729 L .33434 .66676 L F
.455 .76 .995 r
.55248 .73941 m .55251 .73789 L .55004 .73612 L F
.67 .975 .883 r
.5639 .69927 m .5636 .69875 L .5655 .69937 L F
.5639 .69927 m .56231 .69962 L .5636 .69875 L F
.5639 .69927 m .5636 .69875 L .5655 .69937 L F
.5639 .69927 m .56231 .69962 L .5636 .69875 L F
.31 .068 .376 r
.50095 .71458 m .50044 .71661 L .50265 .71382 L F
0 0 .379 r
.56747 .7542 m .56654 .75282 L .56983 .75479 L F
.96 .762 .315 r
.57261 .69075 m .57247 .69228 L .57274 .69106 L F
.881 .761 .257 r
.57274 .69106 m .57247 .69228 L .57275 .69055 L F
0 .163 .702 r
.57247 .69228 m .57389 .69494 L .57268 .691 L F
.57247 .69228 m .57268 .691 L .57261 .69075 L F
.881 .761 .257 r
.57275 .69055 m .57247 .69228 L .57277 .68972 L F
.57274 .69106 m .57247 .69228 L .57277 .68972 L F
.561 .574 .824 r
.3582 .69716 m .35746 .7006 L .35624 .69735 L F
.3582 .69716 m .35951 .70023 L .35746 .7006 L F
.304 .053 .358 r
.3678 .67752 m .36674 .67625 L .36833 .67548 L F
.3678 .67752 m .36614 .67827 L .36674 .67625 L F
.533 .397 .641 r
.58609 .7279 m .58657 .73028 L .58401 .72857 L F
.554 .89 .64 r
.31999 .71434 m .31969 .71471 L .3211 .71331 L F
.865 .469 .288 r
.31969 .71471 m .3189 .71609 L .3211 .71331 L F
0 0 0 r
.31076 .6344 m .31089 .63395 L .31297 .63141 L F
.655 .286 .332 r
.53832 .72805 m .53453 .72973 L .53496 .72768 L F
.53832 .72805 m .53659 .73009 L .53453 .72973 L F
.666 .299 .34 r
.54092 .73005 m .53832 .72805 L .54011 .72764 L F
.54092 .73005 m .53659 .73009 L .53832 .72805 L F
.006 .015 .515 r
.31143 .72443 m .31053 .72247 L .31201 .72139 L F
0 0 .18 r
.31288 .7233 m .31201 .72139 L .3133 .72083 L F
.31288 .7233 m .31143 .72443 L .31201 .72139 L F
.171 0 0 r
.50893 .70738 m .51289 .70631 L .51065 .70577 L F
.746 .305 0 r
.56741 .74024 m .56691 .73876 L .56524 .73813 L F
.56741 .74024 m .56833 .74134 L .56691 .73876 L F
.582 .456 .673 r
.32864 .6733 m .33062 .67273 L .33044 .66984 L F
.386 .181 .475 r
.32856 .67569 m .33062 .67273 L .32864 .6733 L F
.632 .115 0 r
.50632 .79095 m .50709 .7927 L .50503 .79128 L F
.50632 .79095 m .50867 .7924 L .50709 .7927 L F
.56 .492 .736 r
.32399 .69174 m .32476 .69515 L .3268 .69471 L F
.599 .486 .696 r
.32492 .69774 m .3268 .69471 L .32476 .69515 L F
.587 .38 .567 r
.51204 .72817 m .51451 .72786 L .51454 .72547 L F
.557 .387 .606 r
.51454 .72547 m .51694 .72512 L .51676 .72257 L F
.528 .323 .545 r
.51451 .72786 m .51694 .72512 L .51454 .72547 L F
.134 .311 .777 r
.31997 .70767 m .31959 .70915 L .31796 .70584 L F
.777 .965 .924 r
.31997 .70767 m .31829 .70899 L .31959 .70915 L F
.368 .101 .372 r
.30397 .64269 m .30581 .6395 L .30579 .64202 L F
.364 .143 .439 r
.30581 .6395 m .30867 .6373 L .30798 .63918 L F
.258 .011 .335 r
.30579 .64202 m .30581 .6395 L .30798 .63918 L F
.319 .074 .376 r
.32789 .61424 m .32677 .61208 L .32882 .61087 L F
.32789 .61424 m .32618 .61504 L .32677 .61208 L F
.148 .658 .9 r
.44187 .78658 m .44031 .78603 L .43829 .78593 L F
.474 .837 .993 r
.44407 .78612 m .44031 .78603 L .44187 .78658 L F
.596 .328 .48 r
.36428 .67894 m .36376 .68096 L .36153 .68085 L F
.376 .124 .399 r
.36614 .67827 m .36376 .68096 L .36428 .67894 L F
0 0 .496 r
.54469 .73933 m .5442 .73893 L .54266 .73819 L F
.54469 .73933 m .54584 .74143 L .5442 .73893 L F
.083 .421 .867 r
.72875 .6214 m .73117 .62263 L .73098 .62358 L F
.003 .326 .812 r
.73117 .62263 m .73198 .6242 L .73098 .62358 L F
.269 .691 .967 r
.64999 .52053 m .65227 .52077 L .65355 .52157 L F
.057 .283 .774 r
.6544 .5207 m .65355 .52157 L .65227 .52077 L F
.6544 .5207 m .65588 .52355 L .65355 .52157 L F
.533 .682 .934 r
.29082 .60675 m .29387 .60817 L .29264 .60676 L F
.291 .631 .963 r
.29387 .60817 m .29494 .60727 L .29264 .60676 L F
.29387 .60817 m .29666 .6088 L .29494 .60727 L F
.689 .35 .397 r
.3133 .71009 m .3154 .71093 L .31392 .70958 L F
.669 .359 .44 r
.31392 .70958 m .3154 .71093 L .31568 .70986 L F
.633 .479 .655 r
.35498 .68967 m .35544 .69188 L .35281 .69249 L F
.5 .568 .856 r
.496 .74881 m .49332 .74738 L .49665 .74726 L F
.594 .193 .253 r
.49665 .74726 m .49763 .74935 L .496 .74881 L F
.49665 .74726 m .49917 .74932 L .49763 .74935 L F
.891 .67 .597 r
.48764 .7533 m .4852 .75472 L .48496 .75291 L F
.48764 .7533 m .48673 .75515 L .4852 .75472 L F
.545 .171 .282 r
.47016 .73515 m .47245 .73522 L .47054 .73384 L F
.53 .181 .321 r
.47054 .73384 m .47245 .73522 L .4728 .73375 L F
.319 .723 .979 r
.72695 .72867 m .72624 .72794 L .7237 .72789 L F
.509 .66 .929 r
.72695 .72867 m .72844 .72692 L .72624 .72794 L F
.72695 .72867 m .72938 .7285 L .72844 .72692 L F
.743 .627 .73 r
.53433 .74939 m .53671 .75016 L .53603 .74958 L F
.169 0 .02 r
.53487 .75287 m .53596 .75386 L .53671 .75016 L F
.539 .249 .422 r
.53671 .75016 m .53763 .7499 L .53603 .74958 L F
.53671 .75016 m .53937 .75113 L .53763 .7499 L F
.676 .385 .472 r
.53596 .75386 m .53937 .75113 L .53671 .75016 L F
.675 .38 .466 r
.53705 .75708 m .53472 .75561 L .53787 .75596 L F
.225 .53 .92 r
.53963 .75796 m .54019 .75736 L .53787 .75596 L F
.609 .209 .259 r
.53787 .75596 m .54019 .75736 L .53705 .75708 L F
.169 0 .02 r
.53487 .75287 m .53377 .75482 L .53596 .75386 L F
.711 .475 0 r
.57031 .74334 m .57107 .74738 L .57011 .74388 L F
.57031 .74334 m .57091 .74664 L .57107 .74738 L F
.87 .574 .484 r
.57091 .74664 m .57312 .74928 L .57107 .74738 L F
.505 .331 .58 r
.57107 .74738 m .57312 .74928 L .571 .74964 L F
.706 .917 .966 r
.42056 .81249 m .42215 .81308 L .41982 .81391 L F
.655 .423 .556 r
.42215 .81308 m .42116 .81438 L .41982 .81391 L F
.314 .759 .962 r
.42056 .81249 m .42411 .81291 L .42215 .81308 L F
.458 .18 .402 r
.42411 .81291 m .42116 .81438 L .42215 .81308 L F
.292 .066 .389 r
.29536 .62293 m .29654 .62292 L .29708 .62119 L F
.476 .262 .509 r
.29536 .62293 m .29659 .62573 L .29654 .62292 L F
.29536 .62293 m .29478 .62689 L .29659 .62573 L F
.565 .3 .474 r
.63926 .536 m .63901 .53792 L .63662 .53821 L F
.544 .317 .522 r
.64142 .53534 m .63901 .53792 L .63926 .536 L F
.44 .769 .997 r
.26166 .58728 m .26133 .58843 L .25977 .58741 L F
.26166 .58728 m .26334 .58822 L .26133 .58843 L F
.921 .598 .412 r
.46962 .75561 m .47019 .7581 L .46807 .75738 L F
.46962 .75561 m .46807 .75738 L .47016 .75592 L F
.577 .334 .512 r
.53963 .75796 m .53875 .76056 L .54048 .75998 L F
.469 .561 .867 r
.71181 .59571 m .71302 .59837 L .71482 .59809 L F
.628 .538 .733 r
.32287 .70056 m .32367 .70342 L .32604 .70304 L F
0 .499 .848 r
.56081 .7112 m .56045 .71075 L .55674 .70965 L F
.321 0 0 r
.56081 .7112 m .56063 .71115 L .56045 .71075 L F
.56081 .7112 m .56183 .71169 L .56063 .71115 L F
.12 0 0 r
.36278 .72312 m .36218 .72242 L .36427 .72212 L F
.36278 .72312 m .3606 .72383 L .36218 .72242 L F
.177 0 .106 r
.39798 .6898 m .39705 .69153 L .39978 .68904 L F
.842 .99 .856 r
.74325 .62733 m .74276 .62922 L .74487 .62646 L F
.74325 .62733 m .74241 .62844 L .74276 .62922 L F
.278 0 .156 r
.38312 .70054 m .38401 .70199 L .38506 .6999 L F
.38312 .70054 m .38205 .70271 L .38401 .70199 L F
.317 0 .012 r
.55823 .6876 m .55532 .68916 L .5554 .68965 L F
.606 .723 .927 r
.55703 .68922 m .5554 .68965 L .55532 .68916 L F
.55703 .68922 m .55638 .6921 L .5554 .68965 L F
.395 .007 .18 r
.56868 .6774 m .57102 .67588 L .56927 .67587 L F
.289 0 0 r
.73484 .62829 m .73559 .62862 L .7342 .62802 L F
.778 .725 .803 r
.73145 .7096 m .72735 .71376 L .7278 .70944 L F
.55 .369 .589 r
.40017 .68702 m .40231 .68678 L .4023 .68408 L F
.349 .105 .395 r
.40017 .68702 m .40162 .68836 L .40231 .68678 L F
.40017 .68702 m .39978 .68904 L .40162 .68836 L F
.64 .427 .578 r
.50192 .73349 m .50418 .73324 L .50423 .73088 L F
.622 .433 .605 r
.50418 .73324 m .50681 .73052 L .50423 .73088 L F
.228 0 .127 r
.50681 .73052 m .50853 .73004 L .50997 .72775 L F
.252 0 0 r
.50853 .73004 m .51204 .72817 L .50997 .72775 L F
.278 .755 .933 r
.50472 .78668 m .50152 .78645 L .50367 .78782 L F
.641 .19 .164 r
.50367 .78782 m .50706 .78804 L .50472 .78668 L F
.472 .508 .814 r
.42983 .65836 m .42919 .66151 L .42775 .65869 L F
.42983 .65836 m .43107 .66153 L .42919 .66151 L F
.532 .547 .816 r
.36154 .6999 m .36085 .7033 L .35951 .70023 L F
.36154 .6999 m .36286 .70308 L .36085 .7033 L F
.625 .94 .956 r
.74174 .61751 m .74018 .61819 L .7414 .61681 L F
.975 .904 .679 r
.74142 .61943 m .7414 .61681 L .74018 .61819 L F
.487 .325 .587 r
.35669 .68688 m .35682 .68923 L .35498 .68967 L F
.485 .319 .581 r
.35682 .68923 m .35693 .6917 L .35498 .68967 L F
.372 .305 .652 r
.35693 .6917 m .35544 .69188 L .35498 .68967 L F
.033 .598 .79 r
.49751 .74153 m .50018 .74169 L .50095 .74185 L F
.705 .295 .267 r
.49751 .74153 m .49968 .74353 L .50095 .74185 L F
.585 .941 .917 r
.50189 .74074 m .50018 .74169 L .50095 .74185 L F
0 0 0 r
.50095 .74185 m .49968 .74353 L .50189 .74074 L F
.585 .941 .917 r
.50095 .74185 m .50018 .74169 L .50189 .74074 L F
.161 0 0 r
.38236 .66834 m .38176 .66757 L .38326 .66886 L F
.38236 .66834 m .38019 .66905 L .38176 .66757 L F
.507 .567 .851 r
.36491 .70281 m .36429 .70574 L .36286 .70308 L F
.36491 .70281 m .36633 .70576 L .36429 .70574 L F
.373 .472 .832 r
.74741 .58883 m .74617 .5907 L .74407 .58791 L F
.74741 .58883 m .74735 .59025 L .74617 .5907 L F
.455 .383 .686 r
.74735 .59025 m .7462 .59284 L .74617 .5907 L F
.542 .319 .526 r
.40231 .68678 m .40493 .68382 L .4023 .68408 L F
.551 .75 .97 r
.72576 .71648 m .72492 .7183 L .72432 .71575 L F
.72576 .71648 m .72679 .71784 L .72492 .7183 L F
.636 .471 .642 r
.41213 .67595 m .40989 .67864 L .4123 .67838 L F
.584 .511 .739 r
.41121 .67279 m .41213 .67595 L .41432 .67553 L F
.538 .384 .62 r
.4123 .67838 m .41432 .67553 L .41213 .67595 L F
.837 .985 .707 r
.74668 .62326 m .74487 .62646 L .74629 .62328 L F
0 0 .034 r
.74806 .61985 m .74668 .62326 L .74629 .62328 L F
0 0 0 r
.59463 .72001 m .59464 .72117 L .59474 .72105 L F
.745 .698 .806 r
.59634 .71987 m .59458 .7196 L .59463 .72001 L F
0 .119 .584 r
.59708 .72038 m .59634 .71987 L .59463 .72001 L F
0 0 0 r
.59463 .72001 m .59617 .71929 L .59708 .72038 L F
.59463 .72001 m .59474 .72105 L .59617 .71929 L F
.745 .698 .806 r
.59458 .7196 m .59309 .71938 L .59463 .72001 L F
0 .119 .584 r
.59708 .72038 m .59872 .72172 L .59634 .71987 L F
.561 .514 .759 r
.33534 .73079 m .33738 .73041 L .33642 .72728 L F
.729 .558 .66 r
.33534 .73079 m .33724 .73359 L .3387 .73354 L F
.931 .562 .162 r
.72039 .60821 m .72105 .60999 L .71998 .60886 L F
.681 .135 0 r
.71764 .60655 m .72039 .60821 L .71995 .60649 L F
.703 .823 .374 r
.72039 .60821 m .71998 .60886 L .72095 .60702 L F
.948 .727 .263 r
.71995 .60649 m .71998 .60886 L .72039 .60821 L F
.083 .458 .886 r
.74407 .58791 m .74244 .5873 L .74152 .58601 L F
.678 .31 .341 r
.51275 .79045 m .51396 .78826 L .51046 .78849 L F
.605 .2 .248 r
.51495 .79053 m .51396 .78826 L .51275 .79045 L F
.51495 .79053 m .51623 .78883 L .51396 .78826 L F
.315 .125 .456 r
.75237 .61189 m .75054 .61494 L .7507 .61281 L F
.618 .884 .989 r
.73413 .71883 m .73098 .71958 L .7339 .71972 L F
.042 .269 .765 r
.7339 .71972 m .73495 .71901 L .73413 .71883 L F
.064 .313 .797 r
.7339 .71972 m .7363 .72159 L .73495 .71901 L F
.17 .655 .925 r
.73202 .58482 m .733 .58538 L .72969 .58459 L F
.469 .838 .991 r
.73538 .5849 m .733 .58538 L .73202 .58482 L F
.332 .593 .941 r
.43532 .78496 m .43617 .78621 L .437 .78513 L F
.483 .801 1 r
.43617 .78621 m .43829 .78593 L .437 .78513 L F
.491 .643 .924 r
.72869 .71505 m .73078 .71737 L .73182 .71579 L F
.387 .503 .854 r
.73078 .71737 m .73413 .71883 L .73182 .71579 L F
.704 .69 .834 r
.59427 .7386 m .59125 .74012 L .59279 .74 L F
.643 .383 .51 r
.53058 .73403 m .53228 .73049 L .53013 .73137 L F
.656 .527 .694 r
.53058 .73403 m .53359 .73597 L .53408 .735 L F
.53058 .73403 m .53171 .73702 L .53359 .73597 L F
0 .415 .714 r
.39124 .64905 m .3937 .64976 L .39539 .65033 L F
0 .538 .814 r
.3937 .64976 m .39706 .65059 L .39539 .65033 L F
.919 .61 .444 r
.52584 .7109 m .5266 .71399 L .52859 .71408 L F
.963 .664 .413 r
.52701 .71594 m .52859 .71408 L .5266 .71399 L F
.52701 .71594 m .52895 .71731 L .52859 .71408 L F
.812 .548 .538 r
.52859 .71408 m .52895 .71731 L .5298 .71599 L F
.938 .62 .171 r
.30033 .74171 m .29994 .7418 L .29922 .73875 L F
.028 .211 .717 r
.29922 .73875 m .30099 .74062 L .30033 .74171 L F
.884 .618 .531 r
.29994 .7418 m .29982 .74189 L .2969 .74053 L F
.29989 .7416 m .29994 .7418 L .29977 .74173 L F
.666 .945 .69 r
.30099 .74062 m .29972 .74185 L .29994 .7418 L F
0 0 0 r
.29842 .7431 m .29722 .74357 L .29946 .74226 L F
.666 .945 .69 r
.30006 .74177 m .29842 .7431 L .30033 .74171 L F
0 0 0 r
.29842 .7431 m .29946 .74226 L .29997 .74196 L F
.666 .945 .69 r
.29992 .7418 m .29842 .7431 L .30006 .74177 L F
.951 .6 .236 r
.29842 .7431 m .2969 .74053 L .29982 .74189 L F
.666 .945 .69 r
.29972 .74185 m .29842 .7431 L .29992 .7418 L F
.951 .6 .236 r
.29842 .7431 m .29982 .74189 L .29997 .74196 L F
0 0 0 r
.30099 .74062 m .29941 .74236 L .29866 .74292 L F
.29916 .74239 m .29866 .74292 L .29842 .7431 L F
.30099 .74062 m .29866 .74292 L .29916 .74239 L F
.884 .618 .531 r
.29922 .73875 m .29989 .7416 L .2969 .74053 L F
.29989 .7416 m .29977 .74173 L .2969 .74053 L F
.29994 .7418 m .29997 .74196 L .29982 .74189 L F
.666 .945 .69 r
.30056 .74133 m .29994 .7418 L .30033 .74171 L F
.30099 .74062 m .29994 .7418 L .30056 .74133 L F
.938 .62 .171 r
.30033 .74171 m .29997 .74196 L .29994 .7418 L F
.433 .817 .58 r
.29997 .74196 m .29842 .7431 L .30033 .74171 L F
.30033 .74171 m .29842 .7431 L .29997 .74196 L F
.3 .738 .966 r
.58103 .74996 m .58081 .74915 L .57856 .74693 L F
.58103 .74996 m .58153 .74966 L .58081 .74915 L F
.504 .184 .357 r
.5766 .67259 m .57891 .67233 L .57956 .6698 L F
.378 .072 .314 r
.57956 .6698 m .58109 .67167 L .58177 .66958 L F
.57956 .6698 m .57891 .67233 L .58109 .67167 L F
.837 .518 .449 r
.70913 .58138 m .71139 .57982 L .70831 .5798 L F
.70913 .58138 m .71172 .58175 L .71139 .57982 L F
.581 .546 .78 r
.71139 .57982 m .715 .58201 L .71485 .57978 L F
.633 .474 .65 r
.42116 .81438 m .41978 .81636 L .41982 .81391 L F
.443 .597 .909 r
.41982 .81391 m .42116 .81438 L .42056 .81249 L F
.633 .474 .65 r
.41982 .81391 m .41978 .81636 L .42116 .81438 L F
.43 0 0 r
.55674 .70965 m .55524 .70976 L .5533 .70876 L F
0 .472 .807 r
.55674 .70965 m .55819 .70978 L .55524 .70976 L F
.55674 .70965 m .56045 .71075 L .55819 .70978 L F
.367 .77 .984 r
.30154 .59564 m .30306 .59631 L .29954 .59581 L F
.318 .743 .973 r
.30505 .59621 m .30306 .59631 L .30154 .59564 L F
.551 .137 .211 r
.51899 .71979 m .51519 .7217 L .51573 .72008 L F
.51899 .71979 m .5173 .72178 L .51519 .7217 L F
.52 .317 .545 r
.51676 .72257 m .51886 .72215 L .51899 .71979 L F
.649 .555 .735 r
.52084 .71683 m .5214 .71921 L .51899 .71979 L F
.7 .318 .321 r
.52118 .72176 m .51899 .71979 L .5214 .71921 L F
.575 .362 .555 r
.51899 .71979 m .51886 .72215 L .52118 .72176 L F
.7 .318 .321 r
.52118 .72176 m .5173 .72178 L .51899 .71979 L F
.59 .479 .696 r
.52145 .71887 m .52155 .71883 L .52084 .71683 L F
0 0 .564 r
.52155 .71883 m .52236 .71959 L .52084 .71683 L F
0 .048 .587 r
.52084 .71683 m .52236 .71959 L .52157 .71928 L F
.517 .3 .524 r
.52389 .72081 m .5214 .71921 L .52165 .71931 L F
.52387 .7208 m .52165 .71931 L .52236 .71959 L F
.52389 .72081 m .52165 .71931 L .52387 .7208 L F
.575 .362 .555 r
.51899 .71979 m .52118 .72176 L .52151 .71921 L F
0 .048 .587 r
.52117 .71827 m .52157 .71928 L .5214 .71921 L F
.575 .362 .555 r
.52133 .71909 m .52151 .71921 L .52153 .71904 L F
.51899 .71979 m .52151 .71921 L .52133 .71909 L F
.52145 .71887 m .52153 .71904 L .52155 .71883 L F
.51899 .71979 m .52153 .71904 L .52145 .71887 L F
0 .048 .587 r
.52084 .71683 m .52145 .71887 L .52117 .71827 L F
.52145 .71887 m .52157 .71928 L .52117 .71827 L F
.59 .479 .696 r
.51899 .71979 m .52145 .71887 L .52084 .71683 L F
.147 0 .169 r
.59674 .722 m .59505 .72534 L .59392 .72537 L F
.551 .244 .4 r
.59866 .72422 m .59505 .72534 L .59674 .722 L F
.445 .233 .497 r
.59872 .72172 m .59866 .72422 L .59674 .722 L F
.265 0 .034 r
.37269 .71771 m .37172 .71879 L .36974 .71931 L F
.145 0 0 r
.37459 .71697 m .37172 .71879 L .37269 .71771 L F
.128 .317 .784 r
.52506 .70821 m .5249 .70929 L .52349 .70615 L F
.555 .285 .46 r
.40708 .6809 m .40954 .6806 L .40989 .67864 L F
.567 .295 .463 r
.40989 .67864 m .41183 .68031 L .4123 .67838 L F
.40989 .67864 m .40954 .6806 L .41183 .68031 L F
.407 .744 .993 r
.4138 .65345 m .41303 .65453 L .4116 .65377 L F
.4138 .65345 m .41526 .65448 L .41303 .65453 L F
.552 .352 .564 r
.43437 .67543 m .43197 .67811 L .43211 .67586 L F
.249 .518 .91 r
.42144 .65503 m .42291 .65528 L .42221 .65644 L F
.313 .602 .949 r
.42291 .65528 m .42398 .65662 L .42221 .65644 L F
.288 0 .091 r
.58728 .66669 m .58908 .66699 L .59008 .66515 L F
.452 .053 .193 r
.58908 .66699 m .59215 .66493 L .59008 .66515 L F
.546 .398 .632 r
.3487 .72792 m .34915 .73062 L .3467 .73078 L F
0 0 .281 r
.34769 .73082 m .34661 .73349 L .34664 .73261 L F
.34769 .73082 m .34664 .73261 L .3467 .73078 L F
.74 .992 .862 r
.34769 .73082 m .34676 .73151 L .34743 .73126 L F
.34769 .73082 m .34743 .73126 L .34915 .73062 L F
.403 0 0 r
.34343 .73127 m .34676 .73151 L .34717 .73086 L F
.34389 .73112 m .34717 .73086 L .34775 .72992 L F
.34343 .73127 m .34717 .73086 L .34389 .73112 L F
0 0 .281 r
.34771 .73082 m .3467 .73078 L .34915 .73062 L F
.34769 .73082 m .34768 .73082 L .34771 .73082 L F
.34768 .73082 m .3467 .73078 L .34771 .73082 L F
.48 .595 .89 r
.72342 .58532 m .72513 .58853 L .72647 .58669 L F
.577 .021 0 r
.72513 .58853 m .72764 .5898 L .72479 .58936 L F
.72513 .58853 m .72479 .58936 L .72647 .58669 L F
.257 0 .198 r
.29899 .64775 m .29987 .64613 L .30168 .64541 L F
.409 .817 .978 r
.28907 .59341 m .28836 .59424 L .28681 .59337 L F
.28907 .59341 m .29023 .59385 L .28836 .59424 L F
.618 .476 .666 r
.32287 .70056 m .32531 .70068 L .32492 .69774 L F
.628 .538 .733 r
.32287 .70056 m .32604 .70304 L .32531 .70068 L F
0 0 .003 r
.2831 .63703 m .28126 .64028 L .28224 .63958 L F
0 0 0 r
.28126 .64028 m .28122 .64056 L .28224 .63958 L F
.28126 .64028 m .27952 .6417 L .28122 .64056 L F
.492 .337 .598 r
.32399 .69174 m .32572 .69152 L .3258 .68938 L F
.56 .492 .736 r
.32399 .69174 m .3268 .69471 L .32572 .69152 L F
.831 .857 .865 r
.40677 .66756 m .40988 .66717 L .40846 .66609 L F
.40677 .66756 m .40796 .66834 L .40988 .66717 L F
.598 .484 .695 r
.40988 .66717 m .41206 .66664 L .41199 .66457 L F
.611 .557 .769 r
.40988 .66717 m .41342 .67008 L .41206 .66664 L F
.47 0 0 r
.73198 .6242 m .73506 .62613 L .73669 .62678 L F
.983 .863 .639 r
.73669 .62678 m .73554 .62437 L .73813 .62552 L F
.73669 .62678 m .73506 .62613 L .73554 .62437 L F
.639 .666 .859 r
.36286 .84857 m .36369 .85052 L .36648 .84936 L F
.054 0 0 r
.56463 .67877 m .56515 .67943 L .5664 .67787 L F
.56463 .67877 m .56311 .68011 L .56515 .67943 L F
.518 .102 .191 r
.55654 .75753 m .55528 .7597 L .55298 .75827 L F
.494 .077 .178 r
.55704 .75941 m .55726 .75796 L .55886 .75892 L F
.374 .835 .768 r
.55959 .75826 m .55866 .75868 L .55886 .75892 L F
.55866 .75868 m .55704 .75941 L .55822 .75909 L F
.55866 .75868 m .55822 .75909 L .55886 .75892 L F
.023 .367 .837 r
.56062 .75852 m .5623 .75866 L .55959 .75826 L F
.374 .835 .768 r
.55959 .75826 m .55886 .75892 L .56062 .75852 L F
.468 .89 .899 r
.55839 .75848 m .55704 .75941 L .55959 .75826 L F
.209 .721 .887 r
.5623 .75866 m .55839 .75848 L .55959 .75826 L F
.5623 .75866 m .56068 .75836 L .5589 .75845 L F
.55885 .7585 m .5589 .75845 L .55839 .75848 L F
.5623 .75866 m .5589 .75845 L .55885 .7585 L F
0 0 0 r
.55839 .75848 m .55684 .76075 L .55704 .75941 L F
.55684 .76075 m .55595 .76206 L .55704 .75941 L F
.494 .077 .178 r
.55704 .75941 m .55654 .75753 L .55726 .75796 L F
.55704 .75941 m .55528 .7597 L .55654 .75753 L F
.482 .218 .437 r
.41535 .68995 m .41472 .69206 L .4126 .69248 L F
.549 .339 .548 r
.41716 .68919 m .41472 .69206 L .41535 .68995 L F
.847 .551 .488 r
.60108 .67876 m .59843 .68016 L .59783 .6781 L F
.60108 .67876 m .60135 .68087 L .59843 .68016 L F
.343 .792 .954 r
.44749 .78626 m .44603 .78587 L .44407 .78612 L F
.057 .621 .776 r
.44749 .78626 m .44837 .78611 L .44603 .78587 L F
.44749 .78626 m .44977 .78626 L .44837 .78611 L F
.837 .985 .707 r
.74668 .62326 m .74461 .62603 L .74487 .62646 L F
.796 .995 .77 r
.74461 .62603 m .74325 .62733 L .74487 .62646 L F
.908 .712 .625 r
.60404 .6918 m .6057 .69255 L .60551 .69498 L F
.679 .563 .717 r
.70608 .5934 m .70696 .59646 L .70944 .59611 L F
.469 .289 .553 r
.51694 .72512 m .51886 .72215 L .51676 .72257 L F
.502 .154 .309 r
.55296 .68562 m .55648 .68309 L .55399 .68387 L F
.5 .106 .225 r
.47315 .7584 m .46952 .76044 L .47019 .7581 L F
.47315 .7584 m .47211 .76046 L .46952 .76044 L F
.73 .822 .362 r
.47357 .75705 m .47211 .76046 L .47315 .7584 L F
.087 .375 .839 r
.39937 .66677 m .399 .66501 L .39714 .66494 L F
.39937 .66677 m .40054 .66719 L .399 .66501 L F
.424 .278 .577 r
.35911 .68339 m .35669 .68688 L .35681 .68505 L F
.353 .082 .356 r
.45272 .76077 m .45031 .76349 L .45094 .76147 L F
.702 .817 .936 r
.63965 .51221 m .6361 .51222 L .63887 .51092 L F
.899 .818 .76 r
.63063 .52457 m .62847 .5241 L .63014 .5215 L F
.9 .752 .689 r
.63063 .52457 m .6278 .52616 L .62847 .5241 L F
.63063 .52457 m .62939 .52704 L .6278 .52616 L F
.82 .641 .659 r
.63063 .52457 m .62997 .5276 L .62939 .52704 L F
.626 .488 .674 r
.41121 .67279 m .41398 .67338 L .41342 .67008 L F
.584 .511 .739 r
.41121 .67279 m .41432 .67553 L .41398 .67338 L F
0 0 0 r
.28888 .65299 m .2864 .65419 L .28689 .65354 L F
.869 .856 .826 r
.60447 .69978 m .60372 .70337 L .60381 .70261 L F
.60447 .69978 m .60591 .7004 L .60372 .70337 L F
.861 .722 .199 r
.60383 .70559 m .60381 .70261 L .60372 .70337 L F
.428 .525 .854 r
.31643 .72149 m .31669 .71888 L .31553 .71913 L F
.31643 .72149 m .31823 .72187 L .31669 .71888 L F
.275 .25 .649 r
.31643 .72149 m .31846 .72376 L .31823 .72187 L F
.31643 .72149 m .31693 .72486 L .31846 .72376 L F
0 0 0 r
.38845 .66709 m .38716 .66736 L .38926 .66659 L F
.38845 .66709 m .38496 .66812 L .38716 .66736 L F
.281 0 0 r
.58728 .66669 m .58686 .66756 L .58908 .66699 L F
.639 .116 0 r
.54584 .74143 m .54808 .74296 L .54938 .74216 L F
.55 .295 .482 r
.54938 .74216 m .55155 .74348 L .55229 .74166 L F
0 .26 .716 r
.55038 .74247 m .55155 .74348 L .54938 .74216 L F
.55038 .74247 m .54938 .74216 L .54808 .74296 L F
.21 .635 .952 r
.7077 .59288 m .70608 .5934 L .70851 .59359 L F
.679 .563 .717 r
.70608 .5934 m .70944 .59611 L .70851 .59359 L F
.404 .055 .256 r
.52583 .7526 m .52773 .75252 L .52852 .75073 L F
.824 .505 .449 r
.52852 .75073 m .52773 .75252 L .53115 .75289 L F
.504 .848 .995 r
.38248 .64823 m .38457 .64771 L .38596 .64828 L F
.397 .785 .989 r
.38457 .64771 m .38804 .64814 L .38596 .64828 L F
.839 .725 .738 r
.52773 .75252 m .52925 .75532 L .53115 .75289 L F
.457 .44 .752 r
.29766 .6124 m .29842 .61582 L .30018 .61413 L F
.451 .431 .745 r
.29842 .61582 m .30088 .61737 L .30018 .61413 L F
.501 .421 .697 r
.29842 .61582 m .29919 .61816 L .30088 .61737 L F
.405 .757 .994 r
.27075 .58983 m .27031 .59087 L .2688 .58992 L F
.27075 .58983 m .27234 .59071 L .27031 .59087 L F
.56 .418 .645 r
.42709 .75813 m .42926 .75787 L .42907 .75534 L F
.532 .412 .661 r
.42709 .75813 m .42931 .76013 L .42926 .75787 L F
.42709 .75813 m .42749 .76123 L .42931 .76013 L F
.009 .583 .742 r
.74589 .60896 m .74908 .6091 L .74692 .60904 L F
.697 .94 .962 r
.56165 .68804 m .55955 .68942 L .56103 .68958 L F
.56165 .68804 m .55955 .68942 L .56103 .68958 L F
.669 .682 .853 r
.52647 .73308 m .52734 .73565 L .52513 .73385 L F
.498 .249 .468 r
.42675 .68074 m .42429 .68317 L .42462 .68123 L F
.917 .771 .685 r
.61936 .69454 m .62204 .69253 L .619 .69154 L F
.203 .29 .732 r
.56783 .72257 m .56919 .72146 L .56711 .7194 L F
.301 .467 .858 r
.56783 .72257 m .57094 .72405 L .56919 .72146 L F
.578 .264 .401 r
.47595 .73293 m .47822 .73311 L .47827 .7319 L F
.244 .664 .962 r
.31827 .59756 m .31787 .59835 L .31634 .59724 L F
.31827 .59756 m .31968 .59844 L .31787 .59835 L F
.764 .893 .935 r
.73873 .73087 m .74155 .73054 L .74046 .72972 L F
.815 .881 .893 r
.74046 .72972 m .74155 .73054 L .74429 .72833 L F
.544 .71 .948 r
.54518 .76141 m .5467 .75989 L .54392 .76054 L F
.54518 .76141 m .54722 .76133 L .5467 .75989 L F
.228 .316 .747 r
.52505 .73659 m .52684 .73882 L .52609 .73941 L F
.496 .353 .616 r
.52684 .73882 m .52568 .74117 L .52609 .73941 L F
.493 .35 .614 r
.42609 .76637 m .4281 .76861 L .42816 .76581 L F
.42609 .76637 m .42635 .76902 L .4281 .76861 L F
.567 .296 .464 r
.45813 .7577 m .45495 .76049 L .45581 .75788 L F
.457 .372 .672 r
.32669 .67858 m .32884 .68052 L .32853 .67805 L F
.32669 .67858 m .32721 .68122 L .32884 .68052 L F
.762 .667 .758 r
.33738 .73041 m .3387 .73354 L .3409 .73076 L F
.555 .374 .591 r
.34084 .73318 m .3387 .73354 L .3409 .73076 L F
.34084 .73318 m .3387 .73354 L .3409 .73076 L F
.84 .615 .597 r
.61736 .68651 m .61733 .68892 L .62045 .68955 L F
.822 .619 .628 r
.61733 .68892 m .619 .69154 L .62045 .68955 L F
.475 .326 .598 r
.31796 .70584 m .31568 .70986 L .31829 .70899 L F
.359 .071 .333 r
.31568 .70986 m .3154 .71093 L .31829 .70899 L F
.092 0 .202 r
.2831 .63703 m .28446 .6364 L .28515 .63441 L F
.387 .135 .406 r
.28224 .63958 m .28446 .6364 L .2831 .63703 L F
.751 .851 .925 r
.72559 .7112 m .72393 .71248 L .72264 .71132 L F
.828 .842 .858 r
.71687 .58985 m .71905 .59011 L .71876 .58791 L F
.941 .963 .706 r
.7169 .59252 m .71905 .59011 L .71687 .58985 L F
.7169 .59252 m .71736 .59325 L .71905 .59011 L F
.875 .869 .829 r
.71876 .58791 m .71905 .59011 L .72017 .58846 L F
.416 .174 .436 r
.50524 .72205 m .50444 .72505 L .50257 .72524 L F
.338 .103 .402 r
.5063 .72415 m .50444 .72505 L .50524 .72205 L F
.252 0 0 r
.50853 .73004 m .51074 .72961 L .51204 .72817 L F
.697 .253 .192 r
.51074 .72961 m .51427 .73005 L .51204 .72817 L F
.573 .333 .513 r
.51204 .72817 m .51427 .73005 L .51451 .72786 L F
0 0 .102 r
.54868 .68906 m .55104 .68637 L .54923 .68694 L F
.426 .492 .825 r
.32885 .60183 m .32762 .60246 L .32678 .60206 L F
.32885 .60183 m .32994 .60432 L .32762 .60246 L F
.618 .122 .053 r
.55015 .73171 m .54937 .73272 L .547 .73127 L F
.645 .153 .069 r
.55229 .73285 m .54937 .73272 L .55015 .73171 L F
.398 .554 .893 r
.32313 .60106 m .32127 .60083 L .31968 .59844 L F
.309 0 0 r
.54285 .72159 m .5428 .72154 L .54093 .72021 L F
.54285 .72159 m .5444 .72226 L .5428 .72154 L F
.743 .854 .932 r
.29469 .74706 m .29639 .74785 L .29637 .74591 L F
0 .442 .782 r
.27812 .5916 m .28138 .59286 L .27938 .59307 L F
.467 .392 .689 r
.35728 .69385 m .35533 .69569 L .35544 .69188 L F
.506 .44 .716 r
.35728 .69385 m .35624 .69735 L .35533 .69569 L F
.457 .664 .951 r
.74241 .71124 m .74046 .71138 L .74033 .71027 L F
.486 .523 .821 r
.42983 .78255 m .43034 .77939 L .42886 .78071 L F
.42983 .78255 m .43164 .78245 L .43034 .77939 L F
.686 .33 .366 r
.53206 .71691 m .53433 .71905 L .53574 .71672 L F
.705 .353 .377 r
.53574 .71672 m .53433 .71905 L .53775 .71894 L F
.522 0 0 r
.57164 .72528 m .57292 .72653 L .57094 .72405 L F
.257 .437 .848 r
.57164 .72528 m .57417 .72791 L .57424 .72738 L F
.522 0 0 r
.57164 .72528 m .57424 .72738 L .57292 .72653 L F
.409 .808 .585 r
.609 .75262 m .61193 .75057 L .61031 .75169 L F
.554 .229 .372 r
.5645 .69214 m .5638 .69465 L .56571 .69335 L F
.681 .136 0 r
.56474 .69229 m .56626 .69358 L .56815 .69435 L F
.511 .346 .594 r
.56667 .69269 m .5668 .69404 L .5689 .69403 L F
.5668 .69404 m .56689 .69495 L .56753 .69466 L F
.681 .136 0 r
.56571 .69335 m .56595 .69358 L .56815 .69435 L F
.87 .891 .847 r
.56366 .6964 m .5668 .69404 L .56595 .69358 L F
.681 .136 0 r
.56595 .69358 m .56631 .69392 L .5668 .69404 L F
.56595 .69358 m .5668 .69404 L .56815 .69435 L F
.87 .891 .847 r
.56366 .6964 m .56689 .69495 L .5668 .69404 L F
.56595 .69358 m .5668 .69404 L .56667 .69269 L F
0 0 .361 r
.5689 .69403 m .56815 .69435 L .56582 .69381 L F
.511 .346 .594 r
.5668 .69404 m .56753 .69466 L .5689 .69403 L F
.681 .136 0 r
.5645 .69214 m .56571 .69335 L .56626 .69358 L F
.5645 .69214 m .56626 .69358 L .56474 .69229 L F
.56571 .69335 m .56627 .69391 L .56631 .69392 L F
.87 .891 .847 r
.56366 .6964 m .56595 .69358 L .5638 .69465 L F
.56595 .69358 m .56667 .69269 L .56571 .69335 L F
.56595 .69358 m .56571 .69335 L .5638 .69465 L F
.554 .229 .372 r
.5645 .69214 m .56571 .69335 L .56667 .69269 L F
.681 .136 0 r
.5645 .69214 m .56582 .69381 L .56627 .69391 L F
.554 .229 .372 r
.5645 .69214 m .56667 .69269 L .56582 .69381 L F
.661 .155 0 r
.56428 .71418 m .56366 .7139 L .56183 .71169 L F
.627 .129 0 r
.56428 .71418 m .56503 .71536 L .56366 .7139 L F
.56428 .71418 m .56606 .71632 L .56503 .71536 L F
.044 .218 .719 r
.57346 .75772 m .57389 .76076 L .57238 .7586 L F
.95 .679 .488 r
.51362 .76116 m .51246 .76305 L .51236 .76115 L F
.896 .717 .652 r
.60383 .70559 m .60504 .70872 L .60251 .70814 L F
.9 .769 .707 r
.60504 .70872 m .60221 .71034 L .60251 .70814 L F
.60504 .70872 m .6041 .71134 L .60221 .71034 L F
.91 .738 .656 r
.62989 .53514 m .63103 .53838 L .6294 .53733 L F
.896 .695 .622 r
.63103 .53838 m .62852 .53971 L .6294 .53733 L F
.63103 .53838 m .63103 .54077 L .62852 .53971 L F
.427 .386 .71 r
.74813 .59234 m .74676 .596 L .7462 .59284 L F
.74813 .59234 m .7484 .59541 L .74676 .596 L F
.001 0 .388 r
.7484 .59541 m .74794 .59844 L .74676 .596 L F
.399 .06 .271 r
.3466 .65607 m .34861 .65563 L .34976 .65314 L F
.502 .184 .361 r
.34861 .65563 m .35193 .65275 L .34976 .65314 L F
.481 0 0 r
.51732 .79382 m .52078 .79398 L .51991 .79489 L F
.382 0 .013 r
.52078 .79398 m .52176 .79534 L .51991 .79489 L F
.499 .028 .069 r
.52078 .79398 m .52329 .79411 L .52305 .79385 L F
.382 0 .013 r
.52078 .79398 m .52305 .79385 L .52176 .79534 L F
0 0 .102 r
.54868 .68906 m .55027 .68824 L .55104 .68637 L F
.068 0 .357 r
.54868 .68906 m .5489 .69144 L .55027 .68824 L F
.504 .311 .552 r
.29378 .74688 m .29482 .74427 L .29379 .74451 L F
.445 0 0 r
.45863 .78595 m .45748 .78697 L .45518 .78629 L F
.596 .063 0 r
.45863 .78595 m .45943 .78755 L .45748 .78697 L F
.45863 .78595 m .46072 .78726 L .45943 .78755 L F
.965 .709 .497 r
.34084 .73318 m .34074 .7357 L .34218 .73631 L F
.872 .896 .847 r
.34296 .7333 m .34218 .73631 L .34084 .73318 L F
.34296 .7333 m .34074 .7357 L .34218 .73631 L F
.065 .628 .766 r
.45314 .78633 m .45405 .7862 L .45189 .78607 L F
.45314 .78633 m .45518 .78629 L .45405 .7862 L F
.752 .696 .799 r
.33738 .73041 m .3409 .73076 L .33965 .72785 L F
.558 .499 .746 r
.3409 .73076 m .34224 .7271 L .33965 .72785 L F
.3409 .73076 m .34385 .73113 L .34224 .7271 L F
.205 0 .237 r
.29009 .62917 m .28775 .6318 L .28924 .63113 L F
.243 0 .185 r
.28924 .63113 m .29204 .6286 L .29009 .62917 L F
.35 .408 .781 r
.42732 .77444 m .42838 .77742 L .42981 .77701 L F
.328 .292 .665 r
.42838 .77742 m .43034 .77939 L .42981 .77701 L F
.42838 .77742 m .42886 .78071 L .43034 .77939 L F
.132 .554 .923 r
.44805 .74086 m .44925 .74191 L .44669 .74062 L F
.401 0 .099 r
.44925 .74191 m .45104 .74286 L .45147 .74165 L F
.729 .257 .125 r
.44805 .74086 m .45104 .74286 L .44925 .74191 L F
.599 .352 .514 r
.59156 .67341 m .58899 .67586 L .58915 .67562 L F
.59156 .67341 m .59114 .67584 L .58899 .67586 L F
.745 .49 .545 r
.59449 .67555 m .59156 .67341 L .5949 .67307 L F
.59449 .67555 m .59114 .67584 L .59156 .67341 L F
.655 .789 .946 r
.73772 .58404 m .73849 .58537 L .73538 .5849 L F
.259 .612 .956 r
.73942 .58451 m .73849 .58537 L .73772 .58404 L F
.73942 .58451 m .74152 .58601 L .73849 .58537 L F
.972 .658 .32 r
.31469 .73134 m .31483 .73307 L .31339 .7301 L F
.604 .183 .215 r
.54162 .74396 m .54012 .74563 L .538 .74433 L F
.156 0 0 r
.54377 .74459 m .54012 .74563 L .54162 .74396 L F
.906 .944 .586 r
.4629 .76875 m .46435 .76617 L .4638 .76733 L F
.424 .278 .577 r
.35911 .68339 m .35869 .68652 L .35669 .68688 L F
.457 .318 .604 r
.35869 .68652 m .35682 .68923 L .35669 .68688 L F
.626 .917 .642 r
.61193 .75057 m .6129 .74928 L .61031 .75169 L F
.61193 .75057 m .6132 .74923 L .6129 .74928 L F
.443 .169 .401 r
.39565 .70591 m .39511 .70766 L .39318 .70812 L F
.356 .017 .245 r
.39783 .70561 m .39511 .70766 L .39565 .70591 L F
.932 .786 .678 r
.60519 .69733 m .60591 .7004 L .60447 .69978 L F
.4 .183 .466 r
.57906 .74458 m .58006 .74644 L .58004 .74333 L F
.57906 .74458 m .57856 .74693 L .58006 .74644 L F
.616 .192 .214 r
.49832 .73393 m .49821 .73525 L .49506 .7353 L F
.481 .056 .155 r
.49821 .73525 m .50192 .73349 L .49832 .73393 L F
.49821 .73525 m .50067 .73505 L .50192 .73349 L F
.557 .536 .788 r
.49896 .73359 m .50067 .73505 L .49989 .73222 L F
.643 .591 .781 r
.5001 .73299 m .50067 .73505 L .49917 .73353 L F
.789 .549 .574 r
.50067 .73505 m .50418 .73324 L .50192 .73349 L F
.50067 .73505 m .50414 .73568 L .50418 .73324 L F
.766 .412 .386 r
.50067 .73505 m .50286 .73758 L .50414 .73568 L F
.61 .113 0 r
.49916 .73381 m .50067 .73505 L .49896 .73359 L F
.50171 .73651 m .50067 .73505 L .49916 .73381 L F
.643 .591 .781 r
.49927 .7339 m .50067 .73505 L .49963 .73513 L F
.49917 .73353 m .50067 .73505 L .49927 .7339 L F
0 .116 .654 r
.50058 .73334 m .50171 .73651 L .49916 .73381 L F
.643 .591 .781 r
.49989 .73222 m .5001 .73299 L .49996 .73307 L F
.557 .536 .788 r
.49909 .73352 m .49989 .73222 L .49996 .73307 L F
0 0 0 r
.49996 .73307 m .49917 .73353 L .49909 .73352 L F
.643 .591 .781 r
.49989 .73222 m .49996 .73307 L .49917 .73353 L F
.557 .536 .788 r
.49996 .73307 m .49989 .73222 L .50192 .73206 L F
.643 .591 .781 r
.49989 .73222 m .49917 .73353 L .4987 .73352 L F
.557 .536 .788 r
.49896 .73359 m .49989 .73222 L .49909 .73352 L F
.643 .591 .781 r
.49917 .73353 m .4991 .73364 L .49903 .73362 L F
.49909 .73352 m .49903 .73362 L .4987 .73352 L F
.49917 .73353 m .49903 .73362 L .49909 .73352 L F
.4991 .73364 m .49821 .73525 L .4986 .73384 L F
.4991 .73364 m .4986 .73384 L .4987 .73352 L F
0 .116 .654 r
.49908 .73358 m .4991 .73364 L .49896 .73359 L F
.4991 .73364 m .49916 .73381 L .49903 .73367 L F
.4991 .73364 m .49903 .73367 L .49896 .73359 L F
.50058 .73334 m .49916 .73381 L .49908 .73358 L F
.643 .591 .781 r
.4991 .73364 m .49963 .73513 L .49821 .73525 L F
.49917 .73353 m .49963 .73513 L .4991 .73364 L F
0 0 0 r
.50192 .73206 m .49937 .73353 L .49917 .73353 L F
.50192 .73206 m .49917 .73353 L .49996 .73307 L F
.50192 .73206 m .50058 .73334 L .49937 .73353 L F
.49909 .73352 m .49937 .73353 L .49896 .73359 L F
.643 .591 .781 r
.4987 .73352 m .49821 .73525 L .49832 .73393 L F
.47 .085 .226 r
.35193 .65275 m .35402 .6527 L .355 .65106 L F
.414 .022 .183 r
.35402 .6527 m .35772 .65018 L .355 .65106 L F
.836 .667 .672 r
.52863 .79358 m .53066 .79006 L .52759 .79076 L F
.1 0 0 r
.53105 .73192 m .53013 .73137 L .53228 .73049 L F
.53105 .73192 m .52895 .73267 L .53013 .73137 L F
0 .163 .702 r
.57247 .69228 m .57418 .69385 L .57389 .69494 L F
0 0 .453 r
.57418 .69385 m .57451 .69556 L .57389 .69494 L F
0 0 .375 r
.57451 .69556 m .57416 .69771 L .57389 .69494 L F
.543 .67 .92 r
.43287 .78513 m .4334 .7826 L .43164 .78245 L F
.43287 .78513 m .43532 .78496 L .4334 .7826 L F
.234 0 .083 r
.33705 .65973 m .33416 .66173 L .33615 .66134 L F
.157 0 .141 r
.33862 .65891 m .33705 .65973 L .33615 .66134 L F
.329 .041 .315 r
.28515 .63441 m .2871 .63389 L .28775 .6318 L F
.46 .161 .37 r
.28775 .6318 m .28913 .63318 L .28924 .63113 L F
.28775 .6318 m .2871 .63389 L .28913 .63318 L F
.226 0 .019 r
.29458 .65016 m .2973 .64867 L .29633 .6498 L F
.182 0 0 r
.29633 .6498 m .29296 .6517 L .29458 .65016 L F
.656 .808 .956 r
.36983 .70606 m .36633 .70576 L .36844 .70494 L F
.63 .801 .964 r
.37179 .70528 m .36983 .70606 L .36844 .70494 L F
.594 .356 .525 r
.45691 .74128 m .45947 .7388 L .45714 .73908 L F
.477 0 .026 r
.51959 .78834 m .51623 .78883 L .51836 .78978 L F
.52 .019 .006 r
.52055 .78992 m .51959 .78834 L .51836 .78978 L F
.52055 .78992 m .52173 .78879 L .51959 .78834 L F
.255 0 .146 r
.29899 .64775 m .29633 .6498 L .2973 .64867 L F
0 0 .44 r
.59373 .73486 m .59406 .73227 L .59266 .73352 L F
.304 .059 .368 r
.55256 .76012 m .5508 .76109 L .55298 .75827 L F
.437 .176 .419 r
.55298 .75827 m .55528 .7597 L .55256 .76012 L F
.678 .505 .645 r
.71485 .57978 m .715 .58201 L .7172 .57947 L F
.319 0 0 r
.53603 .74958 m .53239 .74975 L .53433 .74939 L F
.58 .393 .592 r
.51579 .75822 m .51585 .76072 L .51826 .75805 L F
.51579 .75822 m .51585 .76072 L .51826 .75805 L F
.599 .486 .696 r
.32492 .69774 m .32748 .6974 L .3268 .69471 L F
.535 .384 .623 r
.32531 .70068 m .32748 .6974 L .32492 .69774 L F
.881 .986 .715 r
.74292 .6156 m .74174 .61751 L .7414 .61681 L F
.61 .46 .654 r
.49997 .7549 m .49777 .75809 L .4983 .75564 L F
.467 .232 .473 r
.64573 .53137 m .6467 .52999 L .64709 .5321 L F
.651 .443 .589 r
.64901 .52956 m .64709 .5321 L .6467 .52999 L F
.498 .317 .566 r
.52589 .75743 m .52382 .75803 L .52397 .75535 L F
.52589 .75743 m .52382 .75803 L .52397 .75535 L F
.561 .444 .678 r
.32524 .68695 m .32691 .68352 L .325 .68405 L F
.505 .145 .289 r
.38968 .69692 m .39194 .69678 L .39306 .6945 L F
.471 .142 .325 r
.39194 .69678 m .39507 .69398 L .39306 .6945 L F
.519 .29 .507 r
.42204 .68371 m .42164 .68586 L .4199 .68608 L F
.488 .262 .497 r
.42432 .68508 m .42204 .68371 L .42429 .68317 L F
.42432 .68508 m .42164 .68586 L .42204 .68371 L F
.469 .274 .533 r
.33036 .60914 m .33041 .61028 L .32882 .61087 L F
.334 .014 .265 r
.32882 .61087 m .32959 .61336 L .32789 .61424 L F
.32882 .61087 m .33041 .61028 L .32959 .61336 L F
.588 .149 .173 r
.5508 .76109 m .54949 .76272 L .54722 .76133 L F
0 0 0 r
.55079 .76187 m .5508 .76109 L .55256 .76012 L F
.55079 .76187 m .54949 .76272 L .5508 .76109 L F
.042 .611 .708 r
.37568 .70341 m .37992 .70316 L .37785 .70369 L F
.7 .184 0 r
.56437 .73761 m .56352 .7361 L .56265 .73517 L F
.56437 .73761 m .56524 .73813 L .56352 .7361 L F
.536 .876 .989 r
.71464 .72187 m .71247 .72115 L .71187 .72219 L F
.255 .567 .938 r
.71464 .72187 m .71504 .72031 L .71247 .72115 L F
.71464 .72187 m .71619 .72188 L .71504 .72031 L F
0 0 0 r
.61607 .74455 m .6154 .74655 L .61552 .74657 L F
.61607 .74455 m .61705 .7434 L .6154 .74655 L F
.593 .629 .857 r
.70944 .59611 m .7102 .59276 L .70851 .59359 L F
.70944 .59611 m .71181 .59571 L .7102 .59276 L F
.452 .356 .656 r
.33044 .66984 m .33232 .67215 L .33246 .66952 L F
.33044 .66984 m .33062 .67273 L .33232 .67215 L F
.377 .152 .441 r
.39536 .6922 m .39694 .69312 L .39705 .69153 L F
.39536 .6922 m .39507 .69398 L .39694 .69312 L F
.729 .233 .057 r
.48874 .78581 m .49025 .78577 L .48736 .78477 L F
.461 0 .003 r
.49111 .78722 m .49025 .78577 L .48874 .78581 L F
.49111 .78722 m .49261 .78597 L .49025 .78577 L F
.625 .388 .538 r
.65453 .52719 m .65473 .52948 L .65129 .52957 L F
.671 .422 .535 r
.65453 .52719 m .65692 .52938 L .65473 .52948 L F
.669 .423 .54 r
.65453 .52719 m .65697 .52727 L .65692 .52938 L F
0 0 0 r
.72075 .58721 m .72072 .58671 L .72137 .58661 L F
.72072 .58671 m .72017 .58846 L .72071 .58637 L F
.72031 .58763 m .72072 .58671 L .72075 .58721 L F
.72072 .58671 m .72071 .58637 L .72078 .58606 L F
.875 .869 .829 r
.71876 .58791 m .72017 .58846 L .72072 .58671 L F
.695 .403 .476 r
.64404 .52093 m .64676 .52133 L .64673 .5196 L F
.414 .185 .455 r
.64673 .5196 m .64893 .52021 L .64999 .52053 L F
.64673 .5196 m .64676 .52133 L .64893 .52021 L F
.435 .846 .968 r
.71282 .59021 m .71394 .59054 L .71687 .58985 L F
.71687 .58985 m .71394 .59054 L .71282 .59021 L F
.285 .418 .821 r
.7342 .62802 m .73506 .62613 L .73263 .62645 L F
.7342 .62802 m .73559 .62862 L .73506 .62613 L F
.789 .884 .915 r
.5636 .69875 m .5655 .69937 L .5682 .6973 L F
.895 .487 .076 r
.56563 .70157 m .5655 .69937 L .5636 .69875 L F
0 .03 .573 r
.56676 .70238 m .56655 .703 L .5655 .69937 L F
.895 .487 .076 r
.56563 .70157 m .56676 .70238 L .5655 .69937 L F
.778 .725 .803 r
.73145 .7096 m .7278 .70944 L .73049 .70891 L F
.521 .849 .997 r
.73279 .70839 m .73145 .7096 L .73049 .70891 L F
.73279 .70839 m .73368 .70903 L .73145 .7096 L F
.475 .41 .704 r
.45066 .76564 m .45139 .7691 L .44939 .76932 L F
.43 .705 .98 r
.45139 .7691 m .45339 .77037 L .44939 .76932 L F
.986 .783 .545 r
.71998 .60886 m .72105 .60999 L .72095 .60702 L F
.815 .83 .861 r
.73453 .60534 m .7311 .60632 L .73358 .60564 L F
.436 0 0 r
.73358 .60564 m .73699 .60604 L .73453 .60534 L F
.028 .495 .879 r
.45869 .77653 m .456 .77519 L .45852 .77639 L F
.77 .541 .587 r
.45502 .774 m .45852 .77639 L .456 .77519 L F
.45502 .774 m .45497 .77641 L .45852 .77639 L F
.072 .566 .893 r
.45824 .77618 m .45852 .77639 L .45704 .77628 L F
.45932 .77609 m .45852 .77639 L .45824 .77618 L F
.028 .495 .879 r
.45978 .77707 m .45869 .77653 L .45852 .77639 L F
.076 .602 .872 r
.46051 .77682 m .45978 .77707 L .45852 .77639 L F
.46051 .77682 m .46186 .77734 L .45978 .77707 L F
.446 .159 .382 r
.4126 .69248 m .41208 .69428 L .41004 .69468 L F
.428 .143 .375 r
.41432 .69365 m .4126 .69248 L .41472 .69206 L F
.41432 .69365 m .41208 .69428 L .4126 .69248 L F
.905 .754 .684 r
.62081 .70781 m .6223 .70856 L .6233 .70579 L F
.69 .272 .247 r
.58716 .72242 m .59076 .7223 L .5886 .7251 L F
.604 .428 .618 r
.59076 .7223 m .59094 .7254 L .5886 .7251 L F
.69 .272 .247 r
.58716 .72242 m .58952 .72405 L .59076 .7223 L F
.71 .612 .746 r
.59309 .71938 m .59076 .7223 L .59442 .72038 L F
.356 0 .047 r
.59076 .7223 m .59238 .72345 L .59442 .72038 L F
.762 .55 .611 r
.59392 .72537 m .59094 .7254 L .59076 .7223 L F
.356 0 .047 r
.59076 .7223 m .58952 .72405 L .59238 .72345 L F
.328 0 .002 r
.47733 .75503 m .47357 .75705 L .47505 .75517 L F
0 0 0 r
.31693 .72486 m .31513 .72664 L .31846 .72376 L F
.46 .404 .708 r
.50444 .72505 m .50309 .7261 L .50257 .72524 L F
.164 0 0 r
.37172 .71879 m .36834 .72058 L .36974 .71931 L F
.675 .38 .466 r
.53705 .75708 m .53485 .75762 L .53472 .75561 L F
.32 0 .21 r
.48628 .72821 m .48363 .73022 L .48563 .72961 L F
.38 .019 .221 r
.48563 .72961 m .48844 .72779 L .48628 .72821 L F
.597 .212 .283 r
.59215 .66493 m .59449 .66635 L .59562 .66426 L F
.632 .273 .344 r
.59449 .66635 m .5979 .66463 L .59562 .66426 L F
.87 .426 .082 r
.62997 .5276 m .63211 .53011 L .62918 .5272 L F
.793 .694 .755 r
.62918 .5272 m .63211 .53011 L .63012 .5328 L F
.006 .015 .515 r
.31143 .72443 m .31091 .7249 L .31053 .72247 L F
.604 .453 .649 r
.43098 .75001 m .43329 .74974 L .4329 .74735 L F
.621 .45 .629 r
.43098 .75001 m .43343 .75221 L .43329 .74974 L F
.43098 .75001 m .4311 .75254 L .43343 .75221 L F
0 .275 .73 r
.55668 .73011 m .55759 .73071 L .55769 .73108 L F
0 0 0 r
.72022 .7137 m .72264 .71132 L .71957 .71107 L F
.54199 .69494 m .54356 .6944 L .54455 .69287 L F
.54455 .69287 m .54518 .69308 L .54677 .69238 L F
.54455 .69287 m .54356 .6944 L .54518 .69308 L F
.697 .86 .451 r
.52895 .71731 m .5284 .71797 L .5298 .71599 L F
.769 .395 .347 r
.5284 .71797 m .53206 .71691 L .5298 .71599 L F
.877 .972 .844 r
.56407 .68507 m .56373 .68728 L .56512 .68539 L F
.887 .977 .826 r
.56165 .68804 m .56373 .68728 L .56407 .68507 L F
0 0 0 r
.359 .72512 m .35445 .72658 L .35688 .72576 L F
0 .169 .703 r
.56833 .74134 m .57011 .74388 L .56902 .74263 L F
.34 .692 .981 r
.29082 .60675 m .29119 .60568 L .28958 .60542 L F
.29082 .60675 m .29264 .60676 L .29119 .60568 L F
.593 .664 .888 r
.59352 .76086 m .59024 .75918 L .59423 .76368 L F
.627 .072 0 r
.51299 .71974 m .51519 .7217 L .51418 .72076 L F
.648 .32 .403 r
.51573 .72008 m .51519 .7217 L .51299 .71974 L F
.692 .598 .746 r
.41206 .66664 m .41342 .67008 L .4154 .66727 L F
.585 .453 .667 r
.41342 .67008 m .41566 .66963 L .4154 .66727 L F
.567 .439 .665 r
.41398 .67338 m .41566 .66963 L .41342 .67008 L F
0 .497 .859 r
.39237 .64893 m .39124 .64905 L .38969 .64821 L F
.39237 .64893 m .3937 .64976 L .39124 .64905 L F
.422 .034 .195 r
.39511 .70766 m .39185 .70985 L .39318 .70812 L F
.815 .881 .893 r
.74046 .72972 m .74429 .72833 L .74356 .72788 L F
.881 .992 .768 r
.74475 .72644 m .74429 .72833 L .74646 .72542 L F
.864 .988 .837 r
.74475 .72644 m .74356 .72788 L .74429 .72833 L F
.628 .07 0 r
.52424 .78975 m .52759 .79076 L .52536 .78932 L F
.713 .854 .429 r
.74727 .72361 m .74646 .72542 L .74803 .72248 L F
.808 .996 .769 r
.74727 .72361 m .74475 .72644 L .74646 .72542 L F
.716 .774 .898 r
.42056 .81249 m .42116 .81438 L .42411 .81291 L F
.79 .556 .583 r
.60798 .67015 m .60805 .67253 L .61139 .6729 L F
.818 .597 .604 r
.60813 .67483 m .61139 .6729 L .60805 .67253 L F
.60813 .67483 m .61144 .67545 L .61139 .6729 L F
.926 .613 .429 r
.71647 .59422 m .71736 .59325 L .7169 .59252 L F
.71647 .59422 m .71787 .5959 L .71736 .59325 L F
.652 .344 .438 r
.72153 .59618 m .71736 .59325 L .71787 .5959 L F
.32 .123 .449 r
.31524 .6262 m .31722 .62328 L .31708 .62574 L F
.426 .251 .54 r
.31528 .62848 m .31524 .6262 L .31708 .62574 L F
.687 .68 .837 r
.58716 .72242 m .5886 .7251 L .58536 .72445 L F
.319 .028 .304 r
.5886 .7251 m .58609 .7279 L .58536 .72445 L F
.5886 .7251 m .58822 .7268 L .58609 .7279 L F
0 0 .076 r
.58919 .7258 m .5886 .7251 L .59046 .72576 L F
.58919 .7258 m .58822 .7268 L .5886 .7251 L F
.39 0 0 r
.59094 .7254 m .59046 .72576 L .5886 .7251 L F
.171 0 0 r
.50893 .70738 m .51181 .70708 L .51222 .70649 L F
0 0 0 r
.51123 .70714 m .51032 .70675 L .51181 .70708 L F
.50893 .70738 m .51032 .70675 L .51123 .70714 L F
.961 .629 .317 r
.50909 .70599 m .50923 .70629 L .51032 .70675 L F
0 0 0 r
.50893 .70738 m .50855 .70783 L .51032 .70675 L F
.528 .248 .434 r
.5077 .70883 m .51032 .70675 L .50855 .70783 L F
.5077 .70883 m .51038 .70867 L .51032 .70675 L F
.961 .629 .317 r
.50923 .70629 m .51038 .70867 L .51032 .70675 L F
.757 .34 .257 r
.51032 .70675 m .5116 .70737 L .51181 .70708 L F
.5116 .70737 m .51368 .70838 L .51181 .70708 L F
.171 0 0 r
.51222 .70649 m .51181 .70708 L .51289 .70631 L F
.476 0 0 r
.51289 .70631 m .51181 .70708 L .51495 .70725 L F
.489 .077 .184 r
.51289 .70631 m .51495 .70725 L .51537 .70621 L F
.658 .629 .809 r
.4908 .74966 m .4873 .74754 L .48899 .74827 L F
.743 .707 .818 r
.49332 .74738 m .4908 .74966 L .48899 .74827 L F
.721 .443 0 r
.31224 .71863 m .31256 .71969 L .31179 .71675 L F
.279 .717 .964 r
.41949 .65423 m .41863 .65492 L .41751 .6542 L F
.41949 .65423 m .42144 .65503 L .41863 .65492 L F
.6 .258 .362 r
.47245 .73522 m .47595 .73293 L .4728 .73375 L F
.47245 .73522 m .47485 .73539 L .47595 .73293 L F
.442 .053 .205 r
.47485 .73539 m .47822 .73311 L .47595 .73293 L F
.377 .437 .797 r
.7172 .57947 m .71986 .58062 L .71952 .57928 L F
.4 .133 .39 r
.28446 .6364 m .2871 .63389 L .28515 .63441 L F
.631 .743 .928 r
.75355 .60852 m .75238 .60972 L .75103 .6085 L F
.342 .218 .562 r
.75355 .60852 m .75237 .61189 L .75238 .60972 L F
.467 .392 .689 r
.35728 .69385 m .35544 .69188 L .35693 .6917 L F
.396 .087 .32 r
.34593 .65776 m .34462 .65657 L .3442 .65868 L F
.34593 .65776 m .3466 .65607 L .34462 .65657 L F
.354 .022 .256 r
.55983 .68221 m .56141 .68115 L .55913 .68183 L F
.895 .837 .374 r
.57378 .73077 m .57424 .72738 L .57417 .72791 L F
.278 .775 .732 r
.39147 .66625 m .39507 .66515 L .39322 .66546 L F
0 0 0 r
.39507 .66515 m .39585 .66513 L .39322 .66546 L F
.39507 .66515 m .39714 .66494 L .39585 .66513 L F
0 .271 .757 r
.58869 .73448 m .58711 .73394 L .5862 .73275 L F
.58869 .73448 m .58979 .73575 L .58711 .73394 L F
.455 .383 .686 r
.74735 .59025 m .74813 .59234 L .7462 .59284 L F
0 0 0 r
.54182 .6974 m .54356 .6944 L .54199 .69494 L F
.641 .946 .723 r
.35131 .72606 m .35077 .72654 L .35012 .72734 L F
.179 .263 .715 r
.3487 .72792 m .349 .72873 L .35012 .72734 L F
.914 .931 .809 r
.3484 .72864 m .34915 .73062 L .34893 .72931 L F
.3484 .72864 m .34893 .72931 L .3487 .72792 L F
.3484 .72864 m .3487 .72792 L .34927 .72769 L F
.3484 .72864 m .34927 .72769 L .35012 .72734 L F
.734 .991 .859 r
.34984 .72707 m .34809 .72825 L .3484 .72864 L F
.34809 .72825 m .34782 .72844 L .3484 .72864 L F
.641 .946 .723 r
.35077 .72654 m .3484 .72864 L .35012 .72734 L F
.179 .263 .715 r
.349 .72873 m .34915 .72911 L .35012 .72734 L F
0 0 .361 r
.5689 .69403 m .56832 .69625 L .56815 .69435 L F
.653 .413 .544 r
.4624 .73812 m .46483 .73613 L .46246 .73609 L F
0 0 0 r
.57539 .67977 m .57459 .68037 L .57325 .68111 L F
0 0 .398 r
.61873 .72431 m .61874 .72683 L .61736 .728 L F
.108 .103 .569 r
.61874 .72683 m .6178 .73028 L .61736 .728 L F
.689 .683 .839 r
.52809 .73624 m .52505 .73659 L .52734 .73565 L F
.662 .439 .571 r
.52809 .73624 m .52695 .7386 L .52505 .73659 L F
.52695 .7386 m .52679 .73877 L .52505 .73659 L F
.496 .353 .616 r
.52494 .74077 m .52648 .73698 L .52416 .74036 L F
.52568 .74117 m .52597 .73965 L .52494 .74077 L F
.52597 .73965 m .52648 .73698 L .52494 .74077 L F
.662 .439 .571 r
.52695 .7386 m .52684 .73882 L .52679 .73877 L F
0 0 0 r
.36153 .68085 m .36007 .6829 L .35911 .68339 L F
.303 0 .102 r
.36212 .68247 m .36153 .68085 L .36376 .68096 L F
.36212 .68247 m .36007 .6829 L .36153 .68085 L F
.271 0 .037 r
.53832 .73504 m .54173 .73253 L .53838 .73319 L F
.53832 .73504 m .54018 .73476 L .54173 .73253 L F
.161 .199 .653 r
.54373 .73553 m .54173 .73253 L .54345 .73271 L F
.33 0 .071 r
.54173 .73253 m .54264 .73403 L .54345 .73271 L F
.54173 .73253 m .54018 .73476 L .54264 .73403 L F
.765 .99 .768 r
.35012 .72734 m .34915 .72911 L .35152 .72611 L F
.322 .282 .657 r
.61809 .73264 m .61878 .73512 L .61679 .73618 L F
.057 0 .412 r
.61878 .73512 m .61724 .73851 L .61679 .73618 L F
.305 .275 .66 r
.3133 .71009 m .31532 .71346 L .3154 .71093 L F
.3133 .71009 m .3146 .71436 L .31532 .71346 L F
0 0 0 r
.59266 .73352 m .59406 .73227 L .59469 .73065 L F
.141 0 0 r
.46295 .78702 m .46428 .78664 L .46656 .78671 L F
.455 0 0 r
.49814 .78667 m .49587 .78582 L .49437 .7859 L F
.065 0 0 r
.26959 .64576 m .273 .64502 L .27053 .64544 L F
.887 .956 .841 r
.74519 .61302 m .74292 .6156 L .74328 .61346 L F
.835 .981 .876 r
.74519 .61302 m .74328 .61346 L .74578 .61101 L F
.789 .412 .344 r
.72118 .58112 m .72239 .57965 L .71952 .57928 L F
.72118 .58112 m .72312 .58144 L .72239 .57965 L F
.314 0 0 r
.43429 .66492 m .43659 .66505 L .43785 .66464 L F
.209 .677 .941 r
.43659 .66505 m .4402 .66574 L .43785 .66464 L F
.19 .683 .92 r
.30698 .59611 m .31069 .59675 L .30859 .59696 L F
.321 .115 .435 r
.29919 .61816 m .30027 .61958 L .30088 .61737 L F
.29919 .61816 m .29877 .62032 L .30027 .61958 L F
.393 .342 .681 r
.30737 .72135 m .30789 .71824 L .30698 .72132 L F
.12 0 0 r
.3805 .71511 m .38008 .71428 L .38211 .71366 L F
.3805 .71511 m .3785 .71569 L .38008 .71428 L F
.386 .181 .475 r
.32856 .67569 m .33029 .67529 L .33062 .67273 L F
.477 .303 .565 r
.32856 .67569 m .33047 .67764 L .33029 .67529 L F
.32856 .67569 m .32853 .67805 L .33047 .67764 L F
.81 .707 .751 r
.48944 .75514 m .48988 .75814 L .48661 .75627 L F
.879 .561 .443 r
.48988 .75814 m .48879 .76027 L .48661 .75627 L F
.582 .89 .99 r
.48907 .75735 m .48742 .75698 L .48822 .75672 L F
.48907 .75735 m .48822 .75672 L .48963 .75626 L F
.999 .798 .471 r
.48907 .75735 m .48988 .75814 L .48985 .75794 L F
.48907 .75735 m .48985 .75794 L .48944 .75514 L F
.597 .429 .625 r
.48907 .75735 m .48879 .76027 L .48988 .75814 L F
.578 .356 .542 r
.63662 .53821 m .63655 .54037 L .63434 .54064 L F
.569 .312 .488 r
.63662 .53821 m .63893 .53986 L .63655 .54037 L F
.63662 .53821 m .63901 .53792 L .63893 .53986 L F
.763 .429 .42 r
.55707 .69212 m .55937 .69429 L .55929 .69188 L F
.591 .2 .269 r
.55638 .6921 m .55707 .69212 L .55929 .69188 L F
.831 .625 .625 r
.63012 .5328 m .62723 .53496 L .62856 .53182 L F
.63012 .5328 m .62989 .53514 L .62723 .53496 L F
.793 .694 .755 r
.62918 .5272 m .63012 .5328 L .62856 .53182 L F
.629 .075 0 r
.53775 .71894 m .54093 .72021 L .53898 .72043 L F
.559 .552 .803 r
.43309 .66131 m .43224 .66503 L .43107 .66153 L F
.43309 .66131 m .43429 .66492 L .43224 .66503 L F
.599 .05 0 r
.58075 .72041 m .58141 .7206 L .57917 .71905 L F
.58075 .72041 m .58227 .72141 L .58141 .7206 L F
.537 .246 .42 r
.41183 .68031 m .41407 .68014 L .4123 .67838 L F
.538 .384 .62 r
.4123 .67838 m .41444 .67795 L .41432 .67553 L F
.492 .249 .473 r
.4123 .67838 m .41407 .68014 L .41444 .67795 L F
.956 .655 .424 r
.60235 .71948 m .60281 .72188 L .60121 .71938 L F
.606 .723 .927 r
.55703 .68922 m .55707 .69212 L .55638 .6921 L F
.852 .393 .05 r
.55578 .69322 m .55761 .69442 L .55638 .6921 L F
.643 .353 .464 r
.55707 .69212 m .55761 .69442 L .55638 .6921 L F
.852 .393 .05 r
.55578 .69322 m .55638 .6921 L .55707 .69212 L F
.59 .77 .965 r
.73605 .7314 m .7375 .72972 L .73542 .72985 L F
.73605 .7314 m .73873 .73087 L .7375 .72972 L F
0 0 .351 r
.57932 .7164 m .57882 .71677 L .57931 .71555 L F
.154 0 .082 r
.53294 .79388 m .53467 .79171 L .53203 .79387 L F
.639 .113 0 r
.53203 .79387 m .53428 .79623 L .53332 .7956 L F
.53203 .79387 m .53332 .7956 L .53294 .79388 L F
.414 .022 .183 r
.35402 .6527 m .3562 .65239 L .35772 .65018 L F
.479 .071 .187 r
.3562 .65239 m .35987 .65036 L .35772 .65018 L F
.466 .132 .315 r
.42943 .67885 m .42893 .68042 L .42675 .68074 L F
.555 .253 .411 r
.43197 .67811 m .42893 .68042 L .42943 .67885 L F
.002 0 .248 r
.53884 .79288 m .53874 .79536 L .53657 .79622 L F
.53883 .79311 m .53936 .793 L .53874 .79536 L F
.53884 .79288 m .53936 .793 L .53883 .79311 L F
0 0 0 r
.54 .79286 m .53936 .793 L .53836 .79365 L F
.312 .084 .397 r
.53874 .79536 m .53936 .793 L .54088 .79244 L F
0 0 0 r
.54088 .79244 m .53936 .793 L .54 .79286 L F
.53825 .79383 m .53836 .79365 L .53736 .79431 L F
.54088 .79244 m .53836 .79365 L .53825 .79383 L F
.002 0 .248 r
.53867 .79313 m .53657 .79622 L .53792 .7942 L F
.53884 .79288 m .53863 .7932 L .53867 .79313 L F
.53863 .7932 m .53657 .79622 L .53867 .79313 L F
.278 .527 .91 r
.52236 .71959 m .52525 .72077 L .52389 .72081 L F
.425 .51 .842 r
.5233 .7211 m .52525 .72077 L .52236 .71959 L F
.52356 .72152 m .52413 .72127 L .5233 .7211 L F
.493 .328 .585 r
.52381 .72119 m .52525 .72077 L .52389 .72081 L F
.425 .51 .842 r
.52413 .72127 m .52525 .72077 L .52378 .7212 L F
.493 .328 .585 r
.52328 .72363 m .52525 .72077 L .52356 .72152 L F
.52328 .72363 m .52525 .72077 L .52381 .72119 L F
.425 .51 .842 r
.52378 .7212 m .52525 .72077 L .5233 .7211 L F
.517 .3 .524 r
.52389 .72081 m .52315 .72107 L .5214 .71921 L F
.52315 .72107 m .52118 .72176 L .52127 .7207 L F
.52315 .72107 m .52127 .7207 L .5214 .71921 L F
.477 .222 .447 r
.4199 .68608 m .41927 .68876 L .41716 .68919 L F
.504 .245 .456 r
.42164 .68586 m .41927 .68876 L .4199 .68608 L F
.798 .598 .631 r
.46379 .7657 m .4629 .76875 L .4638 .76733 L F
.881 .986 .715 r
.74292 .6156 m .7414 .61681 L .74328 .61346 L F
.133 0 .066 r
.53645 .79073 m .53467 .79171 L .53294 .79388 L F
.873 .649 .595 r
.60645 .66716 m .60496 .66974 L .60798 .67015 L F
.778 .547 .585 r
.60469 .67219 m .60798 .67015 L .60496 .66974 L F
.60469 .67219 m .60805 .67253 L .60798 .67015 L F
.414 .404 .739 r
.29766 .6124 m .29846 .60861 L .29666 .6088 L F
.29766 .6124 m .29921 .61192 L .29846 .60861 L F
.457 .44 .752 r
.29766 .6124 m .30018 .61413 L .29921 .61192 L F
.628 .421 .583 r
.64709 .5321 m .64365 .53477 L .64573 .53137 L F
.383 .207 .515 r
.56066 .68716 m .55955 .68942 L .55904 .68786 L F
.803 .441 .37 r
.55904 .68786 m .55955 .68942 L .55823 .6876 L F
0 .188 .715 r
.54656 .70314 m .54837 .70406 L .54536 .70237 L F
.747 .226 0 r
.54991 .70589 m .54861 .70541 L .54656 .70314 L F
0 .188 .715 r
.54656 .70314 m .54861 .70541 L .54837 .70406 L F
.56 .428 .657 r
.32691 .68352 m .32884 .68052 L .32721 .68122 L F
.573 .428 .646 r
.42907 .75534 m .43153 .75745 L .43138 .75499 L F
.42907 .75534 m .42926 .75787 L .43153 .75745 L F
0 0 0 r
.59442 .72038 m .59463 .72001 L .59309 .71938 L F
.59442 .72038 m .59464 .72117 L .59463 .72001 L F
.129 0 .179 r
.59238 .72345 m .59464 .72117 L .59442 .72038 L F
.618 .402 .567 r
.66003 .52674 m .65692 .52938 L .65697 .52727 L F
.529 .313 .53 r
.35612 .87056 m .35654 .86811 L .35828 .87039 L F
.35828 .87039 m .35654 .86811 L .35612 .87056 L F
.174 0 0 r
.72072 .58671 m .72078 .58606 L .72342 .58532 L F
.578 .434 .65 r
.4329 .74735 m .43551 .74937 L .43564 .747 L F
.4329 .74735 m .43329 .74974 L .43551 .74937 L F
.908 .712 .625 r
.60404 .6918 m .60551 .69498 L .60357 .69425 L F
.89 .672 .602 r
.60357 .69425 m .60551 .69498 L .60519 .69733 L F
.954 .658 .436 r
.72064 .72457 m .71931 .72437 L .71911 .722 L F
.73 .958 .945 r
.72152 .72301 m .72064 .72457 L .71911 .722 L F
.72152 .72301 m .71931 .72437 L .72064 .72457 L F
.532 .364 .6 r
.43887 .67005 m .43897 .67244 L .43684 .67287 L F
.56 .351 .554 r
.43897 .67244 m .43663 .675 L .43684 .67287 L F
.226 .414 .839 r
.74241 .71124 m .74517 .71303 L .74434 .71426 L F
.425 .44 .772 r
.74517 .71303 m .74421 .71636 L .74434 .71426 L F
.83 .473 .381 r
.59783 .6781 m .59449 .67555 L .5984 .67586 L F
.377 0 0 r
.49364 .79047 m .49715 .79087 L .49592 .79121 L F
.841 .459 .328 r
.49592 .79121 m .49715 .79087 L .49598 .79246 L F
.583 .173 .231 r
.49715 .79087 m .49928 .79252 L .49598 .79246 L F
.49715 .79087 m .49957 .79138 L .49928 .79252 L F
.447 .792 .998 r
.28681 .59337 m .28492 .59367 L .28334 .59289 L F
.456 .078 .232 r
.57338 .67484 m .5766 .67259 L .57431 .67291 L F
.979 .723 .475 r
.50245 .76368 m .5023 .76593 L .50107 .76283 L F
.787 .619 .673 r
.50107 .76283 m .50488 .76147 L .50245 .76368 L F
.575 .448 .669 r
.50488 .76147 m .5049 .76355 L .50245 .76368 L F
.554 .327 .526 r
.5049 .76355 m .5023 .76593 L .50245 .76368 L F
.542 .319 .526 r
.40231 .68678 m .40469 .68651 L .40493 .68382 L F
.507 .313 .552 r
.40493 .68382 m .407 .68347 L .40708 .6809 L F
.466 .256 .509 r
.40493 .68382 m .4067 .68579 L .407 .68347 L F
.40493 .68382 m .40469 .68651 L .4067 .68579 L F
.575 .459 .683 r
.53359 .73597 m .53625 .73356 L .53408 .735 L F
.53359 .73597 m .53585 .7356 L .53625 .73356 L F
.411 .315 .636 r
.3324 .60582 m .33036 .60914 L .33064 .60797 L F
.3324 .60582 m .33277 .60862 L .33036 .60914 L F
.362 .18 .495 r
.33277 .60862 m .33041 .61028 L .33036 .60914 L F
.736 .879 .471 r
.31841 .7267 m .31803 .72766 L .31949 .72527 L F
.72 .824 .93 r
.31846 .72376 m .31949 .72527 L .32204 .72272 L F
.995 .755 .427 r
.31846 .72376 m .31841 .7267 L .31949 .72527 L F
.571 .504 .741 r
.32524 .68695 m .3258 .68938 L .32737 .68661 L F
.596 .534 .756 r
.32737 .68661 m .3258 .68938 L .3281 .68895 L F
.624 .483 .669 r
.32572 .69152 m .3281 .68895 L .3258 .68938 L F
.381 .149 .432 r
.29708 .62119 m .29654 .62292 L .29877 .62032 L F
.608 .781 .964 r
.53514 .76879 m .53131 .76834 L .53386 .76576 L F
.602 .104 .045 r
.53514 .76879 m .53373 .76947 L .53131 .76834 L F
.553 .494 .744 r
.53655 .76523 m .53514 .76879 L .53386 .76576 L F
.53655 .76523 m .53734 .76859 L .53514 .76879 L F
.163 0 0 r
.53734 .76859 m .53373 .76947 L .53514 .76879 L F
.593 .664 .888 r
.59352 .76086 m .59255 .75852 L .59024 .75918 L F
.191 .398 .836 r
.59352 .76086 m .59447 .75984 L .59255 .75852 L F
.215 .436 .859 r
.59352 .76086 m .59499 .76108 L .59447 .75984 L F
.24 .451 .864 r
.72659 .62359 m .72931 .62508 L .72808 .62269 L F
.532 .306 .517 r
.407 .68347 m .40954 .6806 L .40708 .6809 L F
.834 .596 .58 r
.61142 .67771 m .61314 .67566 L .61144 .67545 L F
.61142 .67771 m .61317 .67804 L .61314 .67566 L F
.451 .331 .625 r
.33416 .66173 m .33615 .66383 L .33615 .66134 L F
.33416 .66173 m .33437 .66434 L .33615 .66383 L F
.891 .541 .376 r
.62852 .53971 m .63103 .54077 L .63116 .54271 L F
.65 .355 .457 r
.63434 .54064 m .63116 .54271 L .63103 .54077 L F
0 .369 .675 r
.55109 .72774 m .55429 .72879 L .55493 .72901 L F
.417 0 0 r
.55429 .72879 m .55668 .73011 L .55493 .72901 L F
.527 .464 .729 r
.32604 .70304 m .32736 .70022 L .32531 .70068 L F
.32604 .70304 m .32795 .70262 L .32736 .70022 L F
.172 .299 .754 r
.32604 .70304 m .32813 .70539 L .32795 .70262 L F
.199 0 0 r
.59392 .72537 m .59046 .72576 L .59094 .7254 L F
.42 0 0 r
.59505 .72534 m .59557 .72606 L .59355 .72574 L F
.438 .518 .843 r
.59355 .72574 m .59557 .72606 L .59545 .72587 L F
.199 0 0 r
.59392 .72537 m .59355 .72574 L .59174 .72561 L F
.42 0 0 r
.59505 .72534 m .59355 .72574 L .59392 .72537 L F
.438 .518 .843 r
.59355 .72574 m .59545 .72587 L .59354 .72293 L F
.199 0 0 r
.59174 .72561 m .59355 .72574 L .59046 .72576 L F
.592 .799 .978 r
.40256 .667 m .40424 .66837 L .40677 .66756 L F
.468 .153 .348 r
.40058 .70358 m .39999 .70526 L .39783 .70561 L F
.427 .114 .33 r
.40208 .70477 m .40058 .70358 L .40269 .70291 L F
.40208 .70477 m .39999 .70526 L .40058 .70358 L F
.995 .81 .443 r
.6041 .71134 m .6031 .71263 L .60221 .71034 L F
.6041 .71134 m .60395 .71414 L .6031 .71263 L F
0 0 .547 r
.54341 .70009 m .54327 .69929 L .54182 .6974 L F
.941 .643 .446 r
.54536 .70237 m .54327 .69929 L .54341 .70009 L F
0 0 0 r
.273 .64502 m .27406 .64466 L .27576 .6432 L F
.27576 .6432 m .27578 .64374 L .27774 .64258 L F
.27576 .6432 m .27505 .64381 L .27578 .64374 L F
.364 .822 .927 r
.27445 .64382 m .27618 .6437 L .27578 .64374 L F
.418 0 .117 r
.27578 .64374 m .27803 .64357 L .27952 .6417 L F
.364 .822 .927 r
.27618 .6437 m .27803 .64357 L .27578 .64374 L F
0 0 0 r
.27505 .64381 m .27406 .64466 L .27578 .64374 L F
.406 .677 .972 r
.52689 .75146 m .52773 .75252 L .52583 .7526 L F
.566 .69 .924 r
.73297 .73018 m .73373 .72775 L .73172 .72808 L F
.73297 .73018 m .73542 .72985 L .73373 .72775 L F
.333 0 .133 r
.37728 .67185 m .37612 .67044 L .37842 .67012 L F
.37728 .67185 m .37495 .67236 L .37612 .67044 L F
.048 .219 .719 r
.55797 .69003 m .55707 .69212 L .55703 .68922 L F
.743 .927 .578 r
.55797 .69003 m .55578 .69322 L .55707 .69212 L F
.763 .429 .42 r
.55707 .69212 m .55761 .69442 L .55937 .69429 L F
0 .192 .704 r
.56833 .74134 m .57031 .74334 L .57011 .74388 L F
.742 .975 .724 r
.35152 .72611 m .35137 .72661 L .35431 .72786 L F
.778 .772 .847 r
.35152 .72611 m .35431 .72786 L .35445 .72658 L F
.55 .374 .595 r
.43526 .74461 m .43742 .74435 L .43789 .74156 L F
.571 .456 .684 r
.43526 .74461 m .43785 .74663 L .43742 .74435 L F
.43526 .74461 m .43564 .747 L .43785 .74663 L F
.46 .404 .708 r
.50444 .72505 m .50513 .72728 L .50309 .7261 L F
.731 .796 .315 r
.50513 .72728 m .50425 .72979 L .50309 .7261 L F
0 .017 .543 r
.74892 .72133 m .74803 .72248 L .74776 .71899 L F
0 0 0 r
.74892 .72133 m .74727 .72361 L .74803 .72248 L F
.743 .922 .565 r
.62066 .71654 m .61927 .7182 L .61881 .7196 L F
0 0 .314 r
.61973 .72084 m .61881 .7196 L .61927 .7182 L F
.61973 .72084 m .61874 .72194 L .61881 .7196 L F
.582 .436 .647 r
.42749 .76123 m .42998 .76332 L .42931 .76013 L F
.42749 .76123 m .42772 .76375 L .42998 .76332 L F
.747 .5 .558 r
.72095 .72131 m .71911 .722 L .71928 .71955 L F
.72095 .72131 m .72262 .72215 L .71911 .722 L F
.487 .231 .452 r
.41004 .69468 m .40973 .69663 L .40762 .69705 L F
.493 .247 .47 r
.41208 .69428 m .40973 .69663 L .41004 .69468 L F
0 0 .237 r
.71187 .72219 m .71247 .72115 L .71246 .71893 L F
.405 .197 .481 r
.33062 .67273 m .33233 .67425 L .33232 .67215 L F
.33062 .67273 m .33029 .67529 L .33233 .67425 L F
.653 .413 .544 r
.4624 .73812 m .46472 .7384 L .46483 .73613 L F
.522 .255 .451 r
.46472 .7384 m .4673 .73609 L .46483 .73613 L F
.613 .188 .213 r
.547 .73127 m .54937 .73272 L .54588 .73256 L F
.503 .153 .306 r
.4804 .73274 m .48264 .73263 L .48363 .73022 L F
.511 .211 .394 r
.48264 .73263 m .48563 .72961 L .48363 .73022 L F
.281 0 0 r
.27266 .60467 m .2711 .60445 L .26909 .60393 L F
.087 .607 .88 r
.27435 .60508 m .2711 .60445 L .27266 .60467 L F
.344 0 .006 r
.27593 .60368 m .27435 .60508 L .27266 .60467 L F
.459 .664 .951 r
.29499 .594 m .29395 .59542 L .29203 .59343 L F
.29499 .594 m .29596 .59547 L .29395 .59542 L F
.808 .609 .634 r
.32724 .70983 m .32835 .71107 L .33052 .71128 L F
.454 .527 .843 r
.33052 .71128 m .33372 .71391 L .333 .71099 L F
.381 .678 .976 r
.73884 .70854 m .73671 .70962 L .7356 .70873 L F
.73884 .70854 m .74033 .71027 L .73671 .70962 L F
.293 0 0 r
.27593 .60368 m .27638 .60471 L .27435 .60508 L F
.27593 .60368 m .27816 .60325 L .27638 .60471 L F
.672 .617 .785 r
.33642 .72728 m .33817 .72462 L .33662 .72458 L F
.56 .072 .054 r
.59783 .6781 m .59716 .67933 L .59407 .67807 L F
.59716 .67933 m .59701 .67959 L .59544 .67878 L F
.59716 .67933 m .59544 .67878 L .59407 .67807 L F
.59783 .6781 m .59407 .67807 L .59603 .6789 L F
.553 .144 .22 r
.59239 .67818 m .59603 .6789 L .59407 .67807 L F
.576 .371 .566 r
.5954 .67871 m .59603 .6789 L .59544 .67878 L F
.59449 .67555 m .59603 .6789 L .5954 .67871 L F
.803 .506 .486 r
.59544 .67878 m .594 .67791 L .59407 .67807 L F
.576 .371 .566 r
.59449 .67555 m .59512 .67772 L .59262 .67789 L F
.526 .828 .999 r
.594 .67791 m .59239 .67818 L .59407 .67807 L F
.576 .371 .566 r
.59512 .67772 m .59542 .67877 L .59314 .67806 L F
.59512 .67772 m .59314 .67806 L .59262 .67789 L F
.526 .828 .999 r
.59356 .67691 m .59239 .67818 L .594 .67791 L F
.803 .506 .486 r
.59701 .67959 m .59356 .67691 L .594 .67791 L F
.576 .371 .566 r
.5954 .67871 m .59544 .67878 L .59541 .67876 L F
.803 .506 .486 r
.59701 .67959 m .594 .67791 L .59544 .67878 L F
.576 .371 .566 r
.59541 .67876 m .59544 .67878 L .59542 .67877 L F
.59262 .67789 m .59542 .67877 L .59239 .67818 L F
.83 .473 .381 r
.59783 .6781 m .59603 .6789 L .59449 .67555 L F
.864 .443 .216 r
.59783 .6781 m .59843 .68016 L .59701 .67959 L F
.938 .714 .574 r
.60425 .68943 m .60253 .69107 L .60268 .68869 L F
.60425 .68943 m .60404 .6918 L .60253 .69107 L F
.218 .625 .954 r
.50274 .79078 m .50503 .79128 L .50372 .79023 L F
0 0 .338 r
.50367 .78782 m .50278 .79064 L .50372 .79023 L F
.483 .274 .519 r
.50372 .79023 m .50367 .78782 L .50174 .79058 L F
.594 .103 .058 r
.50609 .78918 m .50367 .78782 L .50372 .79023 L F
0 0 0 r
.50456 .78986 m .50372 .79023 L .50255 .79017 L F
.50462 .78985 m .50609 .78918 L .50372 .79023 L F
.50462 .78985 m .50372 .79023 L .50456 .78986 L F
0 0 .338 r
.50278 .79064 m .50274 .79078 L .50372 .79023 L F
.397 .798 .984 r
.25817 .58686 m .25779 .5877 L .25622 .58725 L F
.25817 .58686 m .25977 .58741 L .25779 .5877 L F
.196 0 .051 r
.38506 .6999 m .38668 .69982 L .38791 .69785 L F
.229 0 .07 r
.38791 .69785 m .38857 .69918 L .38968 .69692 L F
.38791 .69785 m .38668 .69982 L .38857 .69918 L F
.506 .44 .716 r
.35728 .69385 m .3582 .69716 L .35624 .69735 L F
.669 .682 .853 r
.52647 .73308 m .52809 .73624 L .52734 .73565 L F
.964 .853 .684 r
.52648 .73698 m .52684 .73882 L .52809 .73624 L F
.905 .551 .085 r
.52647 .73308 m .52741 .73581 L .52809 .73624 L F
.861 .996 .811 r
.52741 .73581 m .52648 .73698 L .52809 .73624 L F
.341 .716 .984 r
.27575 .59159 m .27234 .59071 L .27438 .59046 L F
.375 .714 .987 r
.27535 .59029 m .27575 .59159 L .27438 .59046 L F
.27535 .59029 m .27812 .5916 L .27575 .59159 L F
.595 .563 .788 r
.57312 .74928 m .57363 .75345 L .571 .74964 L F
.57312 .74928 m .57436 .75284 L .57363 .75345 L F
.541 .373 .603 r
.31796 .70584 m .31829 .70899 L .31997 .70767 L F
.736 .634 .746 r
.58802 .71325 m .58657 .71006 L .58833 .71151 L F
.623 .578 .783 r
.5901 .70774 m .58833 .71151 L .58758 .70851 L F
.5901 .70774 m .59101 .71112 L .58833 .71151 L F
.624 .31 .419 r
.58833 .71151 m .59063 .71331 L .58802 .71325 L F
.571 .334 .517 r
.59101 .71112 m .59063 .71331 L .58833 .71151 L F
.702 .216 .089 r
.55524 .70976 m .55197 .70797 L .5533 .70876 L F
.719 .808 .92 r
.41629 .66316 m .41406 .66433 L .41779 .6646 L F
.79 .694 .759 r
.41406 .66433 m .4154 .66727 L .41779 .6646 L F
.601 .406 .589 r
.41779 .6646 m .4154 .66727 L .41779 .66691 L F
.53 .801 .995 r
.41779 .6646 m .419 .66304 L .41629 .66316 L F
.41779 .6646 m .41987 .66409 L .419 .66304 L F
.499 .326 .578 r
.41779 .66691 m .41987 .66409 L .41779 .6646 L F
.504 .311 .552 r
.29378 .74688 m .29469 .74706 L .29482 .74427 L F
.486 .296 .548 r
.29482 .74427 m .29637 .74591 L .29722 .74357 L F
.29482 .74427 m .29469 .74706 L .29637 .74591 L F
0 .144 .674 r
.29637 .74591 m .29482 .74427 L .29722 .74357 L F
.858 .615 .57 r
.61317 .67804 m .61311 .6805 L .61604 .68107 L F
.856 .65 .623 r
.61311 .6805 m .61589 .68346 L .61604 .68107 L F
.456 .053 .185 r
.49271 .75257 m .49309 .75417 L .49081 .75427 L F
.596 .467 .674 r
.496 .74881 m .49629 .75247 L .49271 .75257 L F
.656 .327 .404 r
.49629 .75247 m .49309 .75417 L .49271 .75257 L F
.392 0 0 r
.26909 .60393 m .26529 .60542 L .26714 .60439 L F
.762 .619 .701 r
.48496 .75291 m .48284 .75516 L .48198 .75244 L F
.73 .958 .945 r
.72152 .72301 m .71911 .722 L .72262 .72215 L F
.444 .266 .544 r
.33258 .66729 m .33423 .66905 L .33434 .66676 L F
.33258 .66729 m .33246 .66952 L .33423 .66905 L F
.51 .453 .728 r
.3324 .60582 m .33064 .60797 L .32994 .60432 L F
.406 .471 .814 r
.5666 .76906 m .56846 .77087 L .56902 .76875 L F
.906 .812 .744 r
.47487 .77664 m .47586 .77762 L .47587 .77645 L F
.505 .123 .25 r
.47309 .77973 m .47531 .77973 L .47586 .77762 L F
.601 .196 .247 r
.47531 .77973 m .48108 .77887 L .47586 .77762 L F
.143 .591 .928 r
.72834 .62068 m .72784 .6211 L .72584 .62043 L F
.72834 .62068 m .72875 .6214 L .72784 .6211 L F
.531 .476 .74 r
.72321 .72484 m .7237 .72789 L .72438 .72481 L F
.552 .497 .748 r
.7237 .72789 m .72624 .72794 L .72438 .72481 L F
.561 .444 .678 r
.32524 .68695 m .32737 .68661 L .32691 .68352 L F
.243 0 0 r
.5811 .67778 m .58026 .67854 L .57806 .67883 L F
.046 0 0 r
.58354 .67728 m .5822 .67788 L .5811 .67778 L F
.032 0 0 r
.5822 .67788 m .58026 .67854 L .5811 .67778 L F
.23 0 0 r
.38979 .71052 m .38618 .71244 L .38776 .71108 L F
.622 .433 .605 r
.50418 .73324 m .5065 .73334 L .50681 .73052 L F
.74 .668 .78 r
.5065 .73334 m .50853 .73004 L .50681 .73052 L F
.443 .39 .704 r
.31887 .71249 m .32092 .71335 L .31997 .70767 L F
.357 .329 .69 r
.31997 .70767 m .32092 .71335 L .32319 .70939 L F
.827 .976 .677 r
.3211 .71331 m .32319 .70939 L .32092 .71335 L F
.406 .388 .727 r
.31887 .71249 m .3211 .71331 L .32092 .71335 L F
.31887 .71249 m .31999 .71434 L .3211 .71331 L F
.799 .463 .42 r
.72532 .58408 m .72635 .58204 L .72312 .58144 L F
.726 .375 .383 r
.72532 .58408 m .72844 .58444 L .72635 .58204 L F
.475 .347 .625 r
.60128 .7282 m .59788 .72828 L .59951 .72722 L F
.694 .673 .825 r
.60213 .72485 m .60128 .7282 L .59951 .72722 L F
.60213 .72485 m .60309 .72765 L .60128 .7282 L F
.65 .494 .659 r
.60309 .72765 m .60115 .7306 L .60128 .7282 L F
.87 .426 .082 r
.62997 .5276 m .62918 .5272 L .62939 .52704 L F
.722 .394 .424 r
.7139 .5842 m .715 .58201 L .71172 .58175 L F
.706 .375 .415 r
.7139 .5842 m .71672 .58271 L .715 .58201 L F
.039 .605 .778 r
.44278 .74039 m .44772 .74061 L .44669 .74062 L F
.132 .554 .923 r
.44805 .74086 m .44669 .74062 L .44772 .74061 L F
.393 .342 .681 r
.30737 .72135 m .30888 .72172 L .30789 .71824 L F
0 0 0 r
.59449 .67555 m .59239 .67818 L .59356 .67691 L F
.59449 .67555 m .59356 .67691 L .59114 .67584 L F
.895 .837 .374 r
.57378 .73077 m .57352 .73021 L .57424 .72738 L F
0 0 0 r
.41199 .66457 m .41133 .665 L .40846 .66609 L F
.669 .64 .812 r
.41206 .66664 m .41406 .66433 L .41199 .66457 L F
.426 .869 .881 r
.41406 .66433 m .41133 .665 L .41199 .66457 L F
.593 .787 .973 r
.4056 .65204 m .4017 .65162 L .40592 .65177 L F
.345 .651 .968 r
.40734 .6511 m .4056 .65204 L .40592 .65177 L F
.40734 .6511 m .40848 .65236 L .4056 .65204 L F
.412 .533 .869 r
.47587 .77645 m .47326 .77445 L .47543 .77425 L F
.794 .438 .383 r
.47326 .77445 m .47487 .77664 L .47543 .77425 L F
.47326 .77445 m .47134 .77631 L .47487 .77664 L F
.748 .388 .372 r
.50924 .79059 m .51046 .78849 L .50706 .78804 L F
.681 .308 .334 r
.50924 .79059 m .51275 .79045 L .51046 .78849 L F
.697 .926 .604 r
.57259 .75505 m .57436 .75284 L .57255 .7546 L F
.535 .384 .623 r
.32531 .70068 m .32736 .70022 L .32748 .6974 L F
0 .271 .768 r
.53645 .79073 m .53884 .79288 L .53986 .79104 L F
.691 .36 .411 r
.51968 .70517 m .52218 .70535 L .52065 .70305 L F
.25 0 .202 r
.60405 .75563 m .60335 .75714 L .60134 .75799 L F
.319 .06 .356 r
.60542 .75473 m .60335 .75714 L .60405 .75563 L F
.108 0 .246 r
.49831 .71945 m .49631 .72232 L .49758 .72142 L F
.426 .095 .299 r
.495 .72405 m .49758 .72142 L .49631 .72232 L F
.64 .818 .968 r
.49821 .73525 m .49665 .73645 L .49506 .7353 L F
.743 .478 .53 r
.44574 .6618 m .44533 .66416 L .44727 .66396 L F
.768 .574 .636 r
.44533 .66416 m .44563 .66649 L .44727 .66396 L F
.483 .239 .467 r
.44528 .66442 m .44294 .66496 L .44574 .6618 L F
.551 .435 .675 r
.44517 .66445 m .44563 .66649 L .44294 .66496 L F
.44592 .66427 m .44563 .66649 L .44517 .66445 L F
.768 .574 .636 r
.44426 .66427 m .44479 .66514 L .44517 .66445 L F
.44511 .66419 m .44517 .66445 L .44533 .66416 L F
.44426 .66427 m .44517 .66445 L .44511 .66419 L F
.44479 .66514 m .44563 .66649 L .44533 .66416 L F
.483 .239 .467 r
.44592 .66427 m .44528 .66442 L .44533 .66416 L F
.44584 .66322 m .44533 .66416 L .44574 .6618 L F
.44592 .66427 m .44533 .66416 L .44584 .66322 L F
.743 .478 .53 r
.44574 .6618 m .44426 .66427 L .44533 .66416 L F
.108 0 .124 r
.44574 .6618 m .44294 .66496 L .44426 .66427 L F
.801 .48 .446 r
.44727 .66396 m .44592 .66427 L .44574 .6618 L F
.358 .55 .905 r
.28688 .60446 m .28767 .60297 L .28582 .60354 L F
.28688 .60446 m .28958 .60542 L .28767 .60297 L F
.508 .327 .57 r
.49131 .74421 m .48991 .74712 L .4873 .74754 L F
.549 .534 .79 r
.48991 .74712 m .48899 .74827 L .4873 .74754 L F
.902 .702 .623 r
.60325 .68394 m .60121 .68557 L .60143 .6832 L F
.60325 .68394 m .60291 .68631 L .60121 .68557 L F
.874 .913 .852 r
.63365 .51502 m .63245 .51644 L .63168 .51532 L F
.961 .934 .613 r
.63245 .51644 m .63123 .51762 L .63168 .51532 L F
.63245 .51644 m .63162 .51855 L .63123 .51762 L F
.504 .486 .77 r
.42732 .77444 m .42928 .77391 L .42662 .77191 L F
.35 .408 .781 r
.42732 .77444 m .42981 .77701 L .42928 .77391 L F
.292 .04 .35 r
.31722 .62328 m .31943 .6207 L .31873 .62264 L F
.317 .159 .503 r
.31856 .62494 m .31722 .62328 L .31873 .62264 L F
.31856 .62494 m .31708 .62574 L .31722 .62328 L F
.911 .707 .615 r
.60374 .66895 m .60645 .66716 L .60346 .66674 L F
.60374 .66895 m .60496 .66974 L .60645 .66716 L F
.637 .622 .819 r
.53971 .76077 m .53938 .76172 L .54158 .76117 L F
.53875 .76056 m .54158 .76117 L .54048 .75998 L F
.607 .561 .777 r
.54048 .75998 m .54158 .76117 L .54392 .76054 L F
.448 .264 .538 r
.54228 .75924 m .53961 .76191 L .5404 .76014 L F
.54067 .7599 m .5404 .76014 L .54048 .75998 L F
.54228 .75924 m .5404 .76014 L .54067 .7599 L F
.637 .622 .819 r
.53875 .76056 m .53914 .76128 L .53971 .76077 L F
.53914 .76128 m .53938 .76172 L .53971 .76077 L F
.065 0 0 r
.26959 .64576 m .27198 .64541 L .273 .64502 L F
0 0 0 r
.273 .64502 m .27198 .64541 L .27406 .64466 L F
.383 .421 .776 r
.73037 .61933 m .72875 .6214 L .72834 .62068 L F
.73037 .61933 m .73117 .62263 L .72875 .6214 L F
0 .451 .854 r
.26682 .59007 m .26334 .58822 L .26562 .58843 L F
.278 .541 .92 r
.26732 .58877 m .26682 .59007 L .26562 .58843 L F
.447 .734 .988 r
.26732 .58877 m .2688 .58992 L .26682 .59007 L F
.645 .293 .361 r
.56405 .75788 m .56337 .76027 L .56062 .75852 L F
.281 0 .234 r
.56533 .75941 m .56337 .76027 L .56405 .75788 L F
.246 0 0 r
.37344 .64858 m .37538 .6488 L .37685 .64807 L F
.014 0 0 r
.37538 .6488 m .37895 .64764 L .37685 .64807 L F
.705 .243 .152 r
.46186 .77734 m .46403 .77918 L .4651 .77809 L F
.097 0 0 r
.4651 .77809 m .46631 .77846 L .4662 .77837 L F
.617 .707 .909 r
.46631 .77846 m .46278 .77754 L .46637 .77796 L F
.817 .802 .837 r
.46622 .77694 m .46602 .77787 L .46363 .77726 L F
0 0 .435 r
.46589 .77783 m .466 .77798 L .46622 .77694 L F
.466 .77798 m .46631 .77846 L .46622 .77694 L F
0 0 .279 r
.46631 .77846 m .46637 .77796 L .46622 .77694 L F
.817 .802 .837 r
.46622 .77694 m .46637 .77796 L .46602 .77787 L F
0 0 .435 r
.46589 .77783 m .46641 .77854 L .46631 .77846 L F
.766 .409 .379 r
.46631 .77846 m .46836 .78124 L .46966 .77913 L F
0 0 .435 r
.46641 .77854 m .46836 .78124 L .46631 .77846 L F
.097 0 0 r
.4662 .77837 m .46631 .77846 L .46752 .7787 L F
.4651 .77809 m .46403 .77918 L .46631 .77846 L F
.524 .327 .556 r
.44119 .66968 m .43897 .67244 L .43887 .67005 L F
.122 0 0 r
.73141 .58488 m .72969 .58459 L .72844 .58444 L F
.73141 .58488 m .73202 .58482 L .72969 .58459 L F
.669 .64 .812 r
.41206 .66664 m .4154 .66727 L .41406 .66433 L F
.521 .441 .706 r
.52602 .74382 m .52338 .74176 L .52568 .74117 L F
.52485 .74291 m .52402 .7444 L .52338 .74176 L F
.692 .369 .425 r
.51874 .7428 m .52237 .74331 L .52458 .74148 L F
.675 .77 .922 r
.52111 .73913 m .52458 .74148 L .52416 .74036 L F
.937 .877 .752 r
.52458 .74148 m .52237 .74331 L .52416 .74036 L F
.824 .588 .582 r
.52237 .74331 m .5251 .74154 L .52416 .74036 L F
.5251 .74154 m .52568 .74117 L .52522 .74092 L F
.5251 .74154 m .52522 .74092 L .52416 .74036 L F
.521 .441 .706 r
.52602 .74382 m .52461 .74423 L .52485 .74291 L F
.52461 .74423 m .52402 .7444 L .52485 .74291 L F
.577 .343 .524 r
.49751 .74153 m .49968 .74353 L .50018 .74169 L F
.354 .624 .954 r
.4103 .65249 m .40954 .65371 L .40848 .65236 L F
.407 .691 .978 r
.4103 .65249 m .4116 .65377 L .40954 .65371 L F
.769 .834 .902 r
.72559 .7112 m .72264 .71132 L .72419 .71041 L F
.553 .152 .237 r
.72419 .71041 m .7278 .70944 L .72559 .7112 L F
.317 0 .012 r
.55823 .6876 m .55703 .68922 L .55532 .68916 L F
.846 .396 .141 r
.55823 .6876 m .5578 .68894 L .55703 .68922 L F
.55823 .6876 m .55955 .68942 L .5578 .68894 L F
.119 .656 .853 r
.29596 .59547 m .29807 .59551 L .29954 .59581 L F
.299 .761 .948 r
.30015 .59521 m .29954 .59581 L .29807 .59551 L F
.30015 .59521 m .30154 .59564 L .29954 .59581 L F
0 0 .488 r
.56676 .70238 m .56681 .70591 L .56655 .703 L F
.63 .479 .659 r
.49407 .7412 m .49234 .74418 L .49066 .74134 L F
.645 .591 .779 r
.40201 .64729 m .4017 .65162 L .3989 .65118 L F
.40201 .64729 m .3989 .65118 L .39996 .65087 L F
.369 .721 .988 r
.39706 .65059 m .39996 .65087 L .3989 .65118 L F
.587 .94 .79 r
.59779 .75998 m .59796 .76009 L .60134 .75799 L F
.59779 .75998 m .60134 .75799 L .59957 .75899 L F
.362 0 0 r
.60335 .75714 m .59957 .75899 L .60134 .75799 L F
.642 .299 .375 r
.47095 .74962 m .47187 .75191 L .46976 .75172 L F
.567 .296 .464 r
.45813 .7577 m .4573 .76037 L .45495 .76049 L F
.573 .302 .467 r
.46031 .75965 m .45813 .7577 L .46057 .75794 L F
.46031 .75965 m .4573 .76037 L .45813 .7577 L F
.471 .052 .161 r
.51836 .78978 m .51623 .78883 L .51495 .79053 L F
.703 .384 .434 r
.5979 .66463 m .60165 .66634 L .60128 .6643 L F
.715 .431 .494 r
.60165 .66634 m .60346 .66674 L .60128 .6643 L F
.651 .443 .589 r
.64901 .52956 m .64904 .53205 L .64709 .5321 L F
.706 .494 .598 r
.65129 .52957 m .64904 .53205 L .64901 .52956 L F
.538 0 0 r
.50867 .7924 m .5117 .79362 L .51044 .79334 L F
0 0 0 r
.5117 .79362 m .51273 .79345 L .51044 .79334 L F
.5117 .79362 m .51383 .79299 L .51273 .79345 L F
.204 .352 .792 r
.3307 .60277 m .32994 .60432 L .32885 .60183 L F
.29 .461 .857 r
.3307 .60277 m .3324 .60582 L .32994 .60432 L F
.044 .218 .719 r
.57346 .75772 m .57476 .76008 L .57389 .76076 L F
0 0 .107 r
.57418 .76201 m .57389 .76076 L .57476 .76008 L F
.57418 .76201 m .57367 .76337 L .57389 .76076 L F
.198 .339 .781 r
.54722 .76133 m .54837 .75959 L .5467 .75989 L F
.54722 .76133 m .54949 .76272 L .54837 .75959 L F
.3 .687 .976 r
.43829 .78593 m .43908 .78514 L .437 .78513 L F
.43829 .78593 m .44031 .78603 L .43908 .78514 L F
.81 .329 .054 r
.70831 .5798 m .70913 .58138 L .70746 .5806 L F
.70831 .5798 m .70913 .58138 L .70746 .5806 L F
.65 .355 .457 r
.63434 .54064 m .63348 .5429 L .63116 .54271 L F
.59 .313 .465 r
.63655 .54037 m .63348 .5429 L .63434 .54064 L F
0 0 0 r
.52329 .79411 m .52543 .79352 L .52305 .79385 L F
.549 .76 .975 r
.32722 .60039 m .32678 .60206 L .32527 .60098 L F
.32722 .60039 m .32885 .60183 L .32678 .60206 L F
.706 .494 .598 r
.65129 .52957 m .65143 .53214 L .64904 .53205 L F
.639 .442 .6 r
.65471 .53171 m .65129 .52957 L .65473 .52948 L F
.65471 .53171 m .65143 .53214 L .65129 .52957 L F
.567 .439 .665 r
.41398 .67338 m .41612 .67285 L .41566 .66963 L F
.604 .503 .712 r
.41398 .67338 m .41658 .67518 L .41612 .67285 L F
.41398 .67338 m .41432 .67553 L .41658 .67518 L F
.361 0 .102 r
.71527 .71609 m .72009 .71417 L .71472 .71418 L F
.166 0 0 r
.2969 .74053 m .30099 .74062 L .29922 .73875 L F
.511 .728 .971 r
.73439 .59403 m .73561 .59217 L .73343 .59289 L F
.73439 .59403 m .73662 .59379 L .73561 .59217 L F
.377 0 0 r
.73439 .59403 m .7379 .59449 L .73662 .59379 L F
.6 .537 .756 r
.42772 .76375 m .42816 .76581 L .43069 .76532 L F
.595 .412 .603 r
.4281 .76861 m .43069 .76532 L .42816 .76581 L F
.486 .86 .635 r
.59788 .72828 m .59469 .73065 L .59639 .72926 L F
0 0 0 r
.59469 .73065 m .59406 .73227 L .59639 .72926 L F
.555 .392 .615 r
.41566 .66963 m .41779 .66691 L .4154 .66727 L F
.377 .104 .367 r
.31943 .6207 m .32187 .6183 L .32094 .61983 L F
.159 0 .107 r
.32094 .61983 m .32187 .6183 L .32357 .61746 L F
.595 .406 .596 r
.43551 .74937 m .43785 .74663 L .43564 .747 L F
.874 .913 .852 r
.63365 .51502 m .63168 .51532 L .63338 .5128 L F
.867 .877 .842 r
.63338 .5128 m .6361 .51222 L .63365 .51502 L F
0 .229 .674 r
.73383 .6252 m .73198 .6242 L .73117 .62263 L F
.73383 .6252 m .73506 .62613 L .73198 .6242 L F
.47 .301 .569 r
.43789 .74156 m .43893 .74253 L .43987 .74097 L F
.43789 .74156 m .43742 .74435 L .43893 .74253 L F
.567 .352 .548 r
.41432 .67553 m .41643 .67747 L .41658 .67518 L F
.5 .355 .615 r
.41444 .67795 m .41643 .67747 L .41432 .67553 L F
.761 .975 .92 r
.56407 .68507 m .56512 .68539 L .56768 .68359 L F
.325 .076 .374 r
.40887 .69895 m .40762 .69705 L .40973 .69663 L F
.40887 .69895 m .40711 .69973 L .40762 .69705 L F
.892 .784 .735 r
.62209 .69942 m .62272 .70263 L .62328 .70011 L F
.365 0 .151 r
.40162 .68836 m .40469 .68651 L .40231 .68678 L F
.611 .545 .756 r
.3268 .69471 m .32846 .69211 L .32572 .69152 L F
.3268 .69471 m .3291 .6944 L .32846 .69211 L F
.503 .425 .701 r
.3268 .69471 m .32927 .69681 L .3291 .6944 L F
.3268 .69471 m .32748 .6974 L .32927 .69681 L F
.528 .323 .545 r
.51451 .72786 m .51679 .72739 L .51694 .72512 L F
.469 .289 .553 r
.51694 .72512 m .51887 .72456 L .51886 .72215 L F
.48 .291 .546 r
.51679 .72739 m .51887 .72456 L .51694 .72512 L F
.479 .295 .553 r
.50418 .73324 m .50633 .73489 L .5065 .73334 L F
.50418 .73324 m .50414 .73568 L .50633 .73489 L F
.904 .492 .124 r
.72764 .5898 m .72963 .59251 L .73087 .59299 L F
.857 .663 .64 r
.61589 .68346 m .61557 .68614 L .61736 .68651 L F
.89 .659 .581 r
.61559 .68835 m .61736 .68651 L .61557 .68614 L F
.61559 .68835 m .61733 .68892 L .61736 .68651 L F
.59 .386 .573 r
.51427 .73005 m .51679 .72739 L .51451 .72786 L F
.248 .692 .958 r
.31426 .59751 m .31069 .59675 L .31283 .59666 L F
.442 .779 .998 r
.31634 .59724 m .31426 .59751 L .31283 .59666 L F
.594 .356 .525 r
.45691 .74128 m .45933 .7412 L .45947 .7388 L F
.521 .248 .442 r
.45933 .7412 m .4624 .73812 L .45947 .7388 L F
.548 .455 .702 r
.53453 .72973 m .53228 .73049 L .53232 .72883 L F
.571 .217 .33 r
.53453 .72973 m .53105 .73192 L .53228 .73049 L F
.49 .041 .111 r
.58899 .67586 m .58795 .67744 L .58566 .67723 L F
.304 0 0 r
.59114 .67584 m .58795 .67744 L .58899 .67586 L F
.544 .317 .522 r
.64142 .53534 m .64131 .53747 L .63901 .53792 L F
.597 .394 .576 r
.64365 .53477 m .64131 .53747 L .64142 .53534 L F
.654 .381 .493 r
.30789 .71824 m .31224 .71863 L .31179 .71675 L F
.343 .19 .524 r
.31179 .71675 m .31224 .71863 L .31329 .71616 L F
.721 .443 0 r
.31224 .71863 m .31179 .71675 L .31329 .71616 L F
.769 .395 .347 r
.5284 .71797 m .53087 .71868 L .53206 .71691 L F
.707 .317 .307 r
.53087 .71868 m .53433 .71905 L .53206 .71691 L F
.454 .368 .669 r
.42635 .76902 m .42806 .76993 L .4281 .76861 L F
.42635 .76902 m .42662 .77191 L .42806 .76993 L F
.66 .107 0 r
.62939 .52704 m .62918 .5272 L .62985 .52815 L F
.986 .854 .624 r
.62908 .52736 m .62856 .53182 L .6279 .52915 L F
.62918 .5272 m .62915 .52742 L .62908 .52736 L F
.62915 .52742 m .62856 .53182 L .62908 .52736 L F
.62918 .5272 m .6279 .52915 L .62985 .52815 L F
.527 .011 0 r
.62821 .5266 m .62985 .52815 L .62875 .52718 L F
.6278 .52616 m .62862 .52696 L .62821 .5266 L F
.62862 .52696 m .62985 .52815 L .62821 .5266 L F
.66 .107 0 r
.62939 .52704 m .62985 .52815 L .6278 .52616 L F
.866 .879 .844 r
.63541 .51045 m .6361 .51222 L .63338 .5128 L F
.681 .793 .934 r
.63887 .51092 m .6361 .51222 L .63541 .51045 L F
.552 .518 .771 r
.36055 .6965 m .35951 .70023 L .3582 .69716 L F
.36055 .6965 m .36154 .6999 L .35951 .70023 L F
.77 .425 0 r
.538 .74433 m .53764 .74382 L .5367 .74116 L F
.936 .912 .527 r
.538 .74433 m .53687 .74606 L .53764 .74382 L F
.6 .194 .244 r
.54012 .74563 m .53687 .74606 L .538 .74433 L F
.452 .053 .193 r
.58908 .66699 m .59139 .66673 L .59215 .66493 L F
.601 .201 .257 r
.59215 .66493 m .59139 .66673 L .59449 .66635 L F
.149 0 0 r
.36625 .72137 m .36278 .72312 L .36427 .72212 L F
.549 .722 .954 r
.73009 .62677 m .73154 .62507 L .72931 .62508 L F
.73009 .62677 m .73263 .62645 L .73154 .62507 L F
.804 .742 .795 r
.56689 .69495 m .56492 .69715 L .5682 .6973 L F
.789 .884 .915 r
.5636 .69875 m .5682 .6973 L .56492 .69715 L F
.861 .936 .871 r
.57247 .69228 m .56832 .69625 L .5689 .69403 L F
.397 .436 .784 r
.5682 .6973 m .5689 .69403 L .56689 .69495 L F
.5682 .6973 m .56994 .69703 L .5689 .69403 L F
.371 .275 .614 r
.5682 .6973 m .57009 .69934 L .56994 .69703 L F
.375 .275 .612 r
.56852 .69999 m .57009 .69934 L .5682 .6973 L F
.069 .612 .846 r
.64893 .52021 m .65227 .52077 L .64999 .52053 L F
.141 .465 .891 r
.71787 .5959 m .72089 .59826 L .72153 .59618 L F
.192 0 .271 r
.31873 .62264 m .31943 .6207 L .32094 .61983 L F
.664 .627 .802 r
.7165 .60464 m .7177 .60027 L .71903 .60125 L F
.592 .937 .941 r
.71917 .60343 m .7165 .60464 L .71903 .60125 L F
.537 .828 .999 r
.721 .60057 m .71903 .60125 L .7177 .60027 L F
.412 .216 .502 r
.721 .60057 m .71917 .60343 L .71903 .60125 L F
.534 .553 .821 r
.74464 .60111 m .74576 .59781 L .74379 .59742 L F
.74464 .60111 m .74684 .60063 L .74576 .59781 L F
.531 .705 .951 r
.74464 .60111 m .74645 .60127 L .74684 .60063 L F
.858 .667 .643 r
.57048 .76535 m .56936 .76358 L .57117 .76494 L F
.616 .599 .81 r
.52118 .72176 m .52236 .71959 L .52155 .71883 L F
.519 0 0 r
.36991 .64875 m .37344 .64858 L .37131 .64904 L F
.513 .284 .504 r
.47967 .75251 m .47958 .75467 L .47733 .75503 L F
.798 .638 .683 r
.48198 .75244 m .47958 .75467 L .47967 .75251 L F
0 0 0 r
.60251 .70814 m .60326 .70735 L .60383 .70559 L F
.861 .722 .199 r
.60383 .70559 m .60362 .70486 L .60381 .70261 L F
.882 .775 .277 r
.60383 .70559 m .60326 .70735 L .60362 .70486 L F
.743 .707 .818 r
.49332 .74738 m .48899 .74827 L .49151 .74623 L F
.186 .28 .729 r
.72432 .71575 m .72521 .71336 L .72242 .71576 L F
.72432 .71575 m .72576 .71648 L .72521 .71336 L F
.281 0 0 r
.72277 .71805 m .72432 .71575 L .72242 .71576 L F
.72277 .71805 m .72576 .71648 L .72432 .71575 L F
.674 .608 .773 r
.56852 .69999 m .56803 .70253 L .57024 .70192 L F
.274 .773 .741 r
.60213 .72485 m .60394 .72434 L .60309 .72765 L F
.015 0 .132 r
.50044 .71661 m .49831 .71945 L .49953 .71839 L F
.009 0 .166 r
.49758 .72142 m .49953 .71839 L .49831 .71945 L F
.001 .495 .864 r
.58426 .75491 m .5842 .75432 L .58259 .75194 L F
.58426 .75491 m .5853 .75511 L .5842 .75432 L F
.548 .455 .702 r
.53453 .72973 m .53232 .72883 L .53496 .72768 L F
.314 .068 .372 r
.46747 .75208 m .4653 .75472 L .46562 .7527 L F
.654 .113 0 r
.50043 .7868 m .50367 .78782 L .50152 .78645 L F
.254 0 .132 r
.38506 .6999 m .38596 .70125 L .38668 .69982 L F
.38506 .6999 m .38401 .70199 L .38596 .70125 L F
.142 .407 .853 r
.57653 .73568 m .57736 .73476 L .57469 .73315 L F
.132 .39 .843 r
.57653 .73568 m .57756 .73575 L .57736 .73476 L F
.018 .229 .736 r
.5787 .73872 m .57756 .73575 L .57653 .73568 L F
.31 .802 .841 r
.27565 .65554 m .27413 .6557 L .27249 .6562 L F
.152 .694 .752 r
.27777 .65521 m .27413 .6557 L .27565 .65554 L F
.789 .699 .765 r
.53247 .75741 m .5294 .75751 L .53149 .75544 L F
.773 .499 .52 r
.53247 .75741 m .52937 .75969 L .5294 .75751 L F
.53247 .75741 m .53346 .76079 L .52937 .75969 L F
.569 .574 .818 r
.53377 .75482 m .53485 .75762 L .53247 .75741 L F
.614 .408 .579 r
.53487 .76011 m .53247 .75741 L .53485 .75762 L F
.53487 .76011 m .53346 .76079 L .53247 .75741 L F
0 .088 .623 r
.56711 .7194 m .56919 .72146 L .56851 .72041 L F
.685 .587 .741 r
.33642 .72728 m .33738 .73041 L .33965 .72785 L F
.191 .659 .938 r
.26391 .58762 m .26334 .58822 L .26166 .58728 L F
.26391 .58762 m .26562 .58843 L .26334 .58822 L F
.408 .206 .492 r
.52602 .74382 m .52394 .74648 L .52402 .7444 L F
.364 0 0 r
.47908 .78781 m .47771 .78845 L .47557 .78839 L F
.568 .054 0 r
.47908 .78781 m .4799 .78948 L .47771 .78845 L F
.47908 .78781 m .48123 .78845 L .4799 .78948 L F
.531 .476 .74 r
.72321 .72484 m .72438 .72481 L .72518 .72408 L F
.145 0 .132 r
.58177 .66958 m .5829 .67062 L .58381 .66891 L F
.58177 .66958 m .58109 .67167 L .5829 .67062 L F
.512 .646 .916 r
.42775 .65869 m .42398 .65662 L .42643 .65624 L F
.55 .562 .819 r
.42855 .65522 m .42775 .65869 L .42643 .65624 L F
.42855 .65522 m .42983 .65836 L .42775 .65869 L F
0 0 0 r
.53732 .73885 m .53832 .73504 L .53585 .7356 L F
.53732 .73885 m .53716 .73964 L .53832 .73504 L F
0 0 .322 r
.5367 .74116 m .53716 .73964 L .53732 .73885 L F
0 0 0 r
.27249 .6562 m .27413 .6557 L .27202 .65637 L F
.217 .685 .942 r
.34084 .73318 m .34296 .7333 L .34145 .73259 L F
.545 .337 .548 r
.34084 .73318 m .34296 .7333 L .34145 .73259 L F
.34084 .73318 m .34074 .7357 L .34296 .7333 L F
.57 .505 .743 r
.5901 .70774 m .58758 .70851 L .5868 .70601 L F
.74 .679 .791 r
.55155 .74348 m .5536 .74106 L .55229 .74166 L F
.347 0 .017 r
.50425 .72979 m .50192 .73206 L .49989 .73222 L F
.731 .796 .315 r
.50513 .72728 m .50433 .72914 L .50425 .72979 L F
0 0 0 r
.50345 .73118 m .50192 .73206 L .50425 .72979 L F
.50345 .73118 m .50425 .72979 L .50433 .72914 L F
.572 .924 .953 r
.31684 .79369 m .31568 .79349 L .31744 .79267 L F
.31684 .79369 m .31568 .79349 L .31744 .79267 L F
.952 .812 .669 r
.62043 .71025 m .6223 .70856 L .62081 .70781 L F
.62043 .71025 m .62138 .71081 L .6223 .70856 L F
.506 .808 .999 r
.50431 .74936 m .5077 .7498 L .50666 .74895 L F
0 0 0 r
.51044 .74761 m .5091 .74924 L .5077 .7498 L F
.317 .703 .98 r
.5077 .7498 m .5091 .74924 L .50666 .74895 L F
.5077 .7498 m .5091 .74924 L .50666 .74895 L F
.527 .355 .591 r
.43138 .75499 m .43343 .75221 L .4311 .75254 L F
.528 .854 .997 r
.59024 .75918 m .59112 .75805 L .58896 .75744 L F
.59024 .75918 m .59255 .75852 L .59112 .75805 L F
.469 .838 .991 r
.73538 .5849 m .73202 .58482 L .73472 .5847 L F
.405 .858 .842 r
.73655 .58418 m .73772 .58404 L .73538 .5849 L F
.404 .853 .907 r
.73655 .58418 m .73538 .5849 L .73472 .5847 L F
.307 .739 .97 r
.37895 .64764 m .38103 .64758 L .38248 .64823 L F
.376 0 0 r
.38103 .64758 m .38457 .64771 L .38248 .64823 L F
.425 .44 .772 r
.74517 .71303 m .74617 .71645 L .74421 .71636 L F
0 .423 .757 r
.72818 .71813 m .72679 .71784 L .72576 .71648 L F
.72818 .71813 m .72968 .71877 L .72679 .71784 L F
.543 0 0 r
.51383 .79299 m .51732 .79382 L .51596 .79432 L F
.451 0 0 r
.51596 .79432 m .51732 .79382 L .51991 .79489 L F
0 0 .543 r
.48213 .7803 m .48426 .78271 L .48368 .78233 L F
0 .38 .828 r
.48736 .78477 m .48368 .78233 L .48594 .78414 L F
0 .109 .583 r
.48426 .78271 m .48594 .78414 L .48368 .78233 L F
.41 .746 .993 r
.41751 .6542 m .41526 .65448 L .4138 .65345 L F
.751 .232 0 r
.56183 .71169 m .56178 .71259 L .56063 .71115 L F
.758 .243 0 r
.56183 .71169 m .56366 .7139 L .56178 .71259 L F
.457 .806 .998 r
.40355 .6502 m .40592 .65177 L .4017 .65162 L F
.313 .726 .977 r
.40734 .6511 m .40592 .65177 L .40355 .6502 L F
.579 .099 .08 r
.48123 .78845 m .48454 .78839 L .48334 .7897 L F
.693 .235 .161 r
.48454 .78839 m .48676 .79023 L .48334 .7897 L F
.687 .197 .076 r
.47028 .78695 m .47333 .78787 L .47211 .78756 L F
.391 0 0 r
.47333 .78787 m .47431 .78866 L .47211 .78756 L F
.47333 .78787 m .47557 .78839 L .47431 .78866 L F
.553 .042 0 r
.48818 .78993 m .49125 .79017 L .49021 .79036 L F
.374 0 0 r
.49125 .79017 m .49364 .79047 L .49021 .79036 L F
.425 .701 .979 r
.29666 .6088 m .29693 .60724 L .29494 .60727 L F
.29666 .6088 m .29846 .60861 L .29693 .60724 L F
.535 .341 .564 r
.51886 .72215 m .52108 .72403 L .52118 .72176 L F
.51886 .72215 m .51887 .72456 L .52108 .72403 L F
0 .406 .707 r
.45518 .78629 m .45616 .78652 L .45405 .7862 L F
.45518 .78629 m .45748 .78697 L .45616 .78652 L F
.404 .609 .932 r
.7379 .59449 m .73921 .59362 L .73662 .59379 L F
.7379 .59449 m .74002 .59502 L .73921 .59362 L F
.582 .437 .649 r
.42931 .76013 m .43153 .75745 L .42926 .75787 L F
.763 .494 .527 r
.45104 .74286 m .45383 .74135 L .45147 .74165 L F
.457 .318 .604 r
.35869 .68652 m .35859 .68914 L .35682 .68923 L F
.551 .415 .649 r
.35859 .68914 m .35693 .6917 L .35682 .68923 L F
.91 .779 .705 r
.47543 .77425 m .47487 .77664 L .47587 .77645 L F
.999 .841 .519 r
.60395 .71414 m .60263 .71557 L .6031 .71263 L F
.60395 .71414 m .60341 .71646 L .60263 .71557 L F
.188 0 0 r
.37459 .71697 m .37321 .71894 L .37172 .71879 L F
.17 0 0 r
.37516 .71819 m .37459 .71697 L .37654 .71634 L F
.37516 .71819 m .37321 .71894 L .37459 .71697 L F
0 0 0 r
.53366 .76612 m .53131 .76834 L .53313 .7671 L F
.53362 .766 m .53131 .76834 L .53366 .76612 L F
.53386 .76576 m .53362 .766 L .53366 .76612 L F
.53386 .76576 m .53313 .7671 L .53227 .76495 L F
.376 .31 .655 r
.53227 .76495 m .53313 .7671 L .53479 .76758 L F
.615 .086 0 r
.53227 .76495 m .5338 .76655 L .53384 .76692 L F
.5338 .76655 m .53479 .76758 L .53395 .767 L F
.5338 .76655 m .53394 .76696 L .53384 .76692 L F
.53227 .76495 m .53384 .76692 L .53174 .76628 L F
.528 .921 .877 r
.53483 .76601 m .53336 .76673 L .53384 .76692 L F
.493 0 0 r
.53384 .76692 m .53028 .76685 L .53174 .76628 L F
.528 .921 .877 r
.53336 .76673 m .53287 .76697 L .53384 .76692 L F
.615 .086 0 r
.53394 .76696 m .53395 .767 L .53384 .76692 L F
.357 .464 .832 r
.53131 .76834 m .53373 .76947 L .53313 .7671 L F
0 0 0 r
.50044 .71661 m .50167 .71563 L .50265 .71382 L F
0 0 .116 r
.49953 .71839 m .50167 .71563 L .50044 .71661 L F
.356 .017 .245 r
.39783 .70561 m .39686 .70809 L .39511 .70766 L F
.274 0 .208 r
.39877 .70726 m .39783 .70561 L .39999 .70526 L F
.39877 .70726 m .39686 .70809 L .39783 .70561 L F
.78 .911 .522 r
.63089 .51989 m .63123 .51874 L .63139 .51878 L F
.666 .8 .347 r
.63162 .51855 m .63036 .52106 L .63089 .51989 L F
.227 0 0 r
.63162 .51855 m .63089 .51989 L .63315 .51931 L F
.78 .911 .522 r
.63089 .51989 m .63139 .51878 L .63315 .51931 L F
.666 .8 .347 r
.63036 .52106 m .63014 .5215 L .63089 .51989 L F
.227 0 0 r
.63162 .51855 m .63315 .51931 L .63123 .51762 L F
.576 .43 .645 r
.43329 .74974 m .43343 .75221 L .43551 .74937 L F
0 0 .396 r
.585 .70527 m .58598 .70744 L .5852 .70523 L F
0 .4 .755 r
.5852 .70523 m .5868 .70601 L .585 .70527 L F
.771 .545 .592 r
.33372 .71391 m .33365 .71631 L .33013 .71591 L F
.33372 .71391 m .33013 .71591 L .33216 .71514 L F
0 0 0 r
.33372 .71391 m .33473 .71054 L .333 .71099 L F
.33372 .71391 m .3342 .71309 L .33473 .71054 L F
.614 .913 .642 r
.33372 .71391 m .33216 .71514 L .3342 .71309 L F
.53 .11 .189 r
.7162 .58509 m .71672 .58271 L .7139 .5842 L F
.047 0 0 r
.71986 .58062 m .71672 .58271 L .71877 .58261 L F
.057 0 .069 r
.71877 .58261 m .71672 .58271 L .7162 .58509 L F
.913 .745 .659 r
.47019 .7581 m .46791 .75946 L .46807 .75738 L F
.47019 .7581 m .46952 .76044 L .46791 .75946 L F
.548 .831 .998 r
.58772 .70522 m .5868 .70601 L .5852 .70523 L F
.88 .453 .169 r
.58772 .70522 m .5901 .70774 L .5868 .70601 L F
.527 0 0 r
.54118 .73854 m .54469 .73933 L .54266 .73819 L F
.166 .686 .883 r
.30582 .73041 m .3045 .73007 L .30228 .73007 L F
.566 .372 .577 r
.30435 .7272 m .3059 .72825 L .30703 .72467 L F
.3059 .72825 m .30605 .72836 L .30609 .72821 L F
.3059 .72825 m .30609 .72821 L .30703 .72467 L F
0 0 .24 r
.30703 .72467 m .30609 .72821 L .30762 .72583 L F
.30609 .72821 m .30605 .72836 L .30616 .72817 L F
.30609 .72821 m .30616 .72817 L .30762 .72583 L F
.496 .871 .979 r
.30616 .72817 m .30905 .72758 L .30762 .72583 L F
.311 .801 .869 r
.30905 .72758 m .30634 .72814 L .30631 .72816 L F
.30903 .72759 m .30631 .72816 L .30818 .72811 L F
.30905 .72758 m .30631 .72816 L .30903 .72759 L F
.496 .871 .979 r
.30605 .72836 m .30905 .72758 L .30616 .72817 L F
.311 .801 .869 r
.30905 .72758 m .30646 .72803 L .30634 .72814 L F
.30646 .72803 m .30561 .72818 L .30618 .72817 L F
.30646 .72803 m .30618 .72817 L .30631 .72816 L F
.867 .942 .865 r
.30561 .72818 m .30582 .73041 L .30818 .72811 L F
.30561 .72818 m .3045 .73007 L .30582 .73041 L F
.625 .864 .505 r
.50749 .7086 m .50526 .71144 L .50609 .71019 L F
0 0 0 r
.50749 .7086 m .50855 .70783 L .50893 .70738 L F
.50749 .7086 m .50609 .71019 L .50855 .70783 L F
.067 0 .108 r
.36553 .67935 m .36376 .68096 L .36614 .67827 L F
.273 0 .266 r
.3678 .67752 m .36553 .67935 L .36614 .67827 L F
.474 .837 .993 r
.44407 .78612 m .44277 .78558 L .44031 .78603 L F
.361 .796 .965 r
.44407 .78612 m .44454 .78547 L .44277 .78558 L F
.44407 .78612 m .44603 .78587 L .44454 .78547 L F
.506 .81 1 r
.71764 .60655 m .71888 .60567 L .7165 .60464 L F
.71764 .60655 m .71995 .60649 L .71888 .60567 L F
.985 .709 .407 r
.57346 .75287 m .57436 .75284 L .57312 .74928 L F
.98 .91 .651 r
.57255 .7546 m .57436 .75284 L .57346 .75287 L F
.531 .567 .837 r
.36358 .69996 m .36286 .70308 L .36154 .6999 L F
.36358 .69996 m .36491 .70281 L .36286 .70308 L F
.357 .329 .69 r
.31997 .70767 m .32257 .70814 L .32277 .70778 L F
0 0 0 r
.28888 .65299 m .28724 .6541 L .2864 .65419 L F
.141 0 0 r
.29086 .6525 m .28724 .6541 L .28888 .65299 L F
0 .045 .571 r
.48661 .75627 m .4852 .75472 L .48673 .75515 L F
.81 .707 .751 r
.48944 .75514 m .48661 .75627 L .48673 .75515 L F
0 0 0 r
.50265 .71382 m .5041 .7131 L .50526 .71144 L F
.598 .815 .414 r
.50526 .71144 m .5041 .7131 L .50609 .71019 L F
.624 .483 .669 r
.32572 .69152 m .32846 .69211 L .3281 .68895 L F
.639 .637 .832 r
.36844 .70494 m .36633 .70576 L .36491 .70281 L F
.549 .339 .548 r
.41716 .68919 m .417 .69171 L .41472 .69206 L F
.51 .307 .54 r
.41912 .69117 m .41716 .68919 L .41927 .68876 L F
.41912 .69117 m .417 .69171 L .41716 .68919 L F
.424 0 0 r
.65588 .52355 m .65817 .52459 L .6588 .52441 L F
.435 .435 .76 r
.66149 .5258 m .66003 .52674 L .6588 .52441 L F
0 .34 .767 r
.66023 .52481 m .6588 .52441 L .65817 .52459 L F
.66023 .52481 m .66149 .5258 L .6588 .52441 L F
.552 .352 .564 r
.43437 .67543 m .43408 .6778 L .43197 .67811 L F
.511 .317 .553 r
.43635 .67706 m .43437 .67543 L .43663 .675 L F
.43635 .67706 m .43408 .6778 L .43437 .67543 L F
0 0 .234 r
.52633 .71232 m .52584 .7109 L .52528 .71117 L F
.52633 .71232 m .52629 .71272 L .52584 .7109 L F
.696 .165 0 r
.52298 .70947 m .52633 .71232 L .52528 .71117 L F
.048 .565 .873 r
.52636 .71192 m .52633 .71232 L .52503 .71163 L F
.52711 .71208 m .52633 .71232 L .52636 .71192 L F
0 0 .234 r
.52633 .71232 m .5266 .71399 L .52629 .71272 L F
.597 .48 .69 r
.53625 .73356 m .53832 .73504 L .53838 .73319 L F
.167 0 0 r
.26157 .60664 m .26345 .60628 L .26119 .60698 L F
.543 .805 .994 r
.28031 .60295 m .28398 .60358 L .28362 .60274 L F
.378 .696 .982 r
.28398 .60358 m .28439 .60238 L .28362 .60274 L F
.28398 .60358 m .28582 .60354 L .28439 .60238 L F
0 0 0 r
.31143 .72443 m .31042 .72749 L .31091 .7249 L F
.182 0 .352 r
.7519 .6138 m .75054 .61494 L .75237 .61189 L F
0 0 .176 r
.7519 .6138 m .75013 .61701 L .75054 .61494 L F
.413 .163 .423 r
.37025 .6749 m .3678 .67752 L .36833 .67548 L F
.6 .537 .756 r
.42772 .76375 m .43069 .76532 L .42998 .76332 L F
.798 .638 .683 r
.48198 .75244 m .48284 .75516 L .47958 .75467 L F
.859 .599 .545 r
.48284 .75516 m .48092 .75581 L .47958 .75467 L F
.48284 .75516 m .48297 .75753 L .48092 .75581 L F
.29 .277 .671 r
.70527 .59001 m .70884 .59148 L .70568 .58861 L F
.70527 .59001 m .7077 .59288 L .70884 .59148 L F
.555 .253 .411 r
.43197 .67811 m .43123 .68034 L .42893 .68042 L F
.536 .249 .427 r
.43408 .6778 m .43123 .68034 L .43197 .67811 L F
.748 .565 .648 r
.62989 .53514 m .6259 .53753 L .62723 .53496 L F
.62989 .53514 m .62786 .5371 L .6259 .53753 L F
.62989 .53514 m .6294 .53733 L .62786 .5371 L F
.559 .807 .991 r
.50612 .72121 m .50734 .72219 L .50871 .72074 L F
.598 .268 .382 r
.50964 .72245 m .50953 .72391 L .50734 .72219 L F
.251 .313 .733 r
.50734 .72219 m .50953 .72391 L .50871 .72074 L F
.936 .93 .57 r
.57451 .69556 m .57323 .6995 L .57416 .69771 L F
.058 .333 .812 r
.54469 .73933 m .54644 .74052 L .54584 .74143 L F
.557 .563 .816 r
.5446 .74456 m .54766 .7464 L .54588 .74395 L F
.723 .675 .803 r
.54766 .7464 m .54808 .74296 L .54588 .74395 L F
.722 .533 .635 r
.5446 .74456 m .54923 .74822 L .54766 .7464 L F
.5446 .74456 m .54394 .74945 L .54923 .74822 L F
.585 .256 .378 r
.54808 .74296 m .54475 .74547 L .54588 .74395 L F
.555 0 0 r
.54644 .74052 m .55038 .74247 L .54808 .74296 L F
0 0 0 r
.54604 .74434 m .54644 .74421 L .54811 .74198 L F
.5481 .74199 m .54811 .74198 L .54814 .74194 L F
.54604 .74434 m .54811 .74198 L .5481 .74199 L F
.055 .328 .809 r
.54644 .74052 m .54767 .74234 L .54584 .74143 L F
.54767 .74234 m .54808 .74296 L .54744 .74253 L F
.54767 .74234 m .54744 .74253 L .54584 .74143 L F
.362 .18 .495 r
.33277 .60862 m .33264 .61129 L .33041 .61028 L F
.425 .097 .304 r
.33041 .61028 m .33173 .61293 L .32959 .61336 L F
.33041 .61028 m .33264 .61129 L .33173 .61293 L F
.789 .412 .344 r
.72118 .58112 m .71952 .57928 L .71986 .58062 L F
.328 0 .002 r
.47733 .75503 m .47646 .75679 L .47357 .75705 L F
.492 .024 .07 r
.47816 .75591 m .47733 .75503 L .47958 .75467 L F
.47816 .75591 m .47646 .75679 L .47733 .75503 L F
.855 .591 .538 r
.60846 .67681 m .61144 .67545 L .60813 .67483 L F
.60846 .67681 m .61142 .67771 L .61144 .67545 L F
.316 .057 .353 r
.30168 .64541 m .30397 .64269 L .30325 .64452 L F
.309 .019 .299 r
.30325 .64452 m .30397 .64269 L .30579 .64202 L F
0 0 0 r
.50265 .71382 m .50167 .71563 L .5041 .7131 L F
.435 .065 .235 r
.36553 .67935 m .36212 .68247 L .36376 .68096 L F
.414 .199 .475 r
.30867 .6373 m .31076 .6344 L .31035 .63656 L F
0 0 0 r
.31076 .6344 m .31297 .63141 L .31278 .63385 L F
.414 .173 .438 r
.31035 .63656 m .31076 .6344 L .31278 .63385 L F
.498 .249 .468 r
.42675 .68074 m .42657 .6828 L .42429 .68317 L F
.535 .288 .488 r
.42893 .68042 m .42657 .6828 L .42675 .68074 L F
.486 0 0 r
.52424 .78975 m .52173 .78879 L .52055 .78992 L F
.815 .583 .588 r
.53875 .76056 m .53485 .75762 L .53705 .75708 L F
.53875 .76056 m .53487 .76011 L .53485 .75762 L F
.471 .185 .397 r
.53875 .76056 m .53588 .76365 L .53487 .76011 L F
.53875 .76056 m .53799 .76337 L .53588 .76365 L F
.672 .583 .747 r
.54048 .75998 m .53875 .76056 L .53705 .75708 L F
.191 0 .282 r
.53961 .76191 m .53875 .76056 L .54048 .75998 L F
.53961 .76191 m .53799 .76337 L .53875 .76056 L F
.543 .485 .742 r
.42662 .77191 m .42928 .77391 L .42806 .76993 L F
.909 .95 .814 r
.5131 .74298 m .51196 .74625 L .5134 .74552 L F
.5131 .74298 m .51046 .7468 L .51196 .74625 L F
.729 .751 .87 r
.5131 .74298 m .5134 .74552 L .51661 .74332 L F
.755 .658 .755 r
.51367 .7449 m .51046 .7468 L .5131 .74298 L F
.363 .699 .984 r
.51332 .74591 m .5134 .74552 L .51196 .74625 L F
.51332 .74591 m .51614 .74662 L .5134 .74552 L F
.755 .658 .755 r
.51394 .74583 m .51255 .74622 L .51367 .7449 L F
.51255 .74622 m .51046 .7468 L .51367 .7449 L F
.138 0 0 r
.51162 .74732 m .51044 .74761 L .51196 .74625 L F
.51127 .74844 m .51095 .74812 L .51162 .74732 L F
.51095 .74812 m .51044 .74761 L .51162 .74732 L F
.51127 .74844 m .5091 .74924 L .51044 .74761 L F
.489 .322 .581 r
.33437 .66434 m .3363 .66623 L .33615 .66383 L F
.33437 .66434 m .33434 .66676 L .3363 .66623 L F
.474 .333 .609 r
.32748 .6974 m .32933 .69926 L .32927 .69681 L F
.32748 .6974 m .32736 .70022 L .32933 .69926 L F
.311 .801 .869 r
.30905 .72758 m .30818 .72811 L .31042 .72749 L F
.69 .354 .402 r
.5181 .76272 m .51505 .76309 L .51585 .76072 L F
.14 .589 .927 r
.51451 .76141 m .5181 .76272 L .51585 .76072 L F
.397 .785 .989 r
.38457 .64771 m .38666 .64748 L .38804 .64814 L F
.007 .58 .756 r
.38882 .64807 m .38804 .64814 L .38666 .64748 L F
.38882 .64807 m .38969 .64821 L .38804 .64814 L F
.318 .743 .973 r
.30505 .59621 m .30154 .59564 L .30364 .59557 L F
.367 .746 .989 r
.3058 .59533 m .30505 .59621 L .30364 .59557 L F
.3058 .59533 m .30698 .59611 L .30505 .59621 L F
.611 .063 0 r
.56681 .70591 m .56895 .70788 L .57017 .70859 L F
0 .193 .617 r
.5715 .70938 m .57017 .70859 L .56895 .70788 L F
.5715 .70938 m .57261 .71012 L .57017 .70859 L F
.508 .205 .388 r
.52305 .79385 m .52485 .7952 L .52176 .79534 L F
.52305 .79385 m .52543 .79352 L .52485 .7952 L F
.627 .346 .473 r
.51495 .70725 m .51763 .70556 L .51537 .70621 L F
.505 .272 .496 r
.45272 .76077 m .45265 .76315 L .45031 .76349 L F
.609 .356 .509 r
.45493 .76265 m .45265 .76315 L .45272 .76077 L F
.596 .36 .529 r
.45495 .76049 m .45493 .76265 L .45272 .76077 L F
0 .209 .73 r
.54652 .72218 m .54877 .72413 L .54826 .72445 L F
0 .199 .724 r
.54877 .72413 m .55037 .72626 L .54826 .72445 L F
0 0 0 r
.57673 .67972 m .57539 .67977 L .57806 .67883 L F
.57673 .67972 m .57459 .68037 L .57539 .67977 L F
.462 .463 .773 r
.44294 .66496 m .44563 .66649 L .44426 .66427 L F
.265 .545 .924 r
.58896 .75744 m .5853 .75511 L .58678 .75767 L F
.975 .904 .679 r
.74142 .61943 m .74011 .61997 L .7414 .61681 L F
.923 .794 .701 r
.74142 .61943 m .7389 .62193 L .74011 .61997 L F
.74142 .61943 m .74026 .62279 L .7389 .62193 L F
.138 .238 .706 r
.74799 .71603 m .74776 .71899 L .74617 .71645 L F
.74799 .71603 m .74946 .71846 L .74776 .71899 L F
0 0 .378 r
.74863 .72043 m .74776 .71899 L .74946 .71846 L F
.74863 .72043 m .74892 .72133 L .74776 .71899 L F
.841 .589 .557 r
.60135 .68087 m .59862 .68262 L .59843 .68016 L F
.60135 .68087 m .60143 .6832 L .59862 .68262 L F
.632 .273 .344 r
.59449 .66635 m .59837 .6661 L .5979 .66463 L F
.772 .356 .262 r
.59837 .6661 m .59984 .6668 L .5979 .66463 L F
.703 .384 .434 r
.5979 .66463 m .59984 .6668 L .60165 .66634 L F
.597 .876 .556 r
.61552 .74657 m .6129 .74928 L .6132 .74923 L F
.565 .309 .487 r
.63901 .53792 m .6413 .53958 L .63893 .53986 L F
.544 .318 .523 r
.64131 .53747 m .6413 .53958 L .63901 .53792 L F
.988 .834 .602 r
.59788 .72828 m .59655 .72696 L .59951 .72722 L F
.59788 .72828 m .59639 .72926 L .59655 .72696 L F
.972 .659 .305 r
.45361 .77094 m .45502 .774 L .45465 .77166 L F
.921 .537 .256 r
.52218 .70535 m .52291 .70731 L .52349 .70615 L F
.882 .471 .23 r
.52291 .70731 m .52506 .70821 L .52349 .70615 L F
.53 0 0 r
.45189 .78607 m .44837 .78611 L .44977 .78626 L F
.28 .005 .305 r
.30798 .63918 m .30867 .6373 L .31035 .63656 L F
.205 .686 .932 r
.27075 .58983 m .27438 .59046 L .27234 .59071 L F
.783 .666 .735 r
.33817 .72462 m .34178 .72487 L .3404 .72401 L F
.33817 .72462 m .33965 .72785 L .34178 .72487 L F
.687 .53 .668 r
.34178 .72487 m .33965 .72785 L .34224 .7271 L F
0 .191 .718 r
.34178 .72487 m .34208 .72423 L .3404 .72401 L F
.34178 .72487 m .34389 .72674 L .34208 .72423 L F
.404 .341 .673 r
.34224 .7271 m .34389 .72674 L .34178 .72487 L F
.72 .824 .93 r
.31846 .72376 m .32054 .72168 L .31823 .72187 L F
.63 .801 .964 r
.37179 .70528 m .36844 .70494 L .37052 .70421 L F
.687 .809 .94 r
.37371 .70399 m .37179 .70528 L .37052 .70421 L F
0 0 .488 r
.56676 .70238 m .56769 .70477 L .5668 .70534 L F
.842 .407 0 r
.56563 .70157 m .56769 .70477 L .56676 .70238 L F
.56563 .70157 m .56734 .70485 L .56769 .70477 L F
0 0 .488 r
.5668 .70534 m .56769 .70477 L .56681 .70591 L F
.317 0 0 r
.5675 .70514 m .56649 .70524 L .56769 .70477 L F
.842 .407 0 r
.56734 .70485 m .5675 .70514 L .56769 .70477 L F
.812 .483 .433 r
.56341 .70329 m .56709 .70496 L .56563 .70157 L F
.068 .302 .787 r
.56734 .70485 m .56769 .70477 L .56662 .70517 L F
.812 .483 .433 r
.56709 .70496 m .5675 .70514 L .56734 .70485 L F
.56709 .70496 m .56734 .70485 L .56563 .70157 L F
.813 .564 .563 r
.56364 .70463 m .56688 .70506 L .56341 .70329 L F
.068 .302 .787 r
.5667 .70514 m .56769 .70477 L .56652 .70523 L F
.813 .564 .563 r
.56688 .70506 m .5675 .70514 L .56709 .70496 L F
.56688 .70506 m .56709 .70496 L .56341 .70329 L F
.068 .302 .787 r
.56653 .70522 m .56769 .70477 L .56649 .70524 L F
.813 .564 .563 r
.56688 .70506 m .56649 .70524 L .5675 .70514 L F
.56364 .70463 m .56649 .70524 L .56688 .70506 L F
.068 .302 .787 r
.56652 .70523 m .56653 .70522 L .56649 .70524 L F
.56662 .70517 m .5667 .70514 L .56652 .70523 L F
.56717 .70489 m .56734 .70485 L .56662 .70517 L F
.56868 .70412 m .56769 .70477 L .56717 .70489 L F
.5687 .7041 m .56769 .70477 L .56868 .70412 L F
.125 .296 .767 r
.56769 .70477 m .56895 .70788 L .56681 .70591 L F
.841 .537 .473 r
.71058 .58366 m .71172 .58175 L .70913 .58138 L F
.731 .392 .407 r
.71058 .58366 m .7139 .5842 L .71172 .58175 L F
.555 .392 .615 r
.41566 .66963 m .41786 .66911 L .41779 .66691 L F
.532 .414 .664 r
.41566 .66963 m .41818 .67182 L .41786 .66911 L F
.41566 .66963 m .41612 .67285 L .41818 .67182 L F
.514 .743 .978 r
.72938 .7285 m .73062 .72705 L .72844 .72692 L F
.72938 .7285 m .73172 .72808 L .73062 .72705 L F
.062 .098 .587 r
.51614 .74662 m .51661 .74332 L .5134 .74552 L F
.51614 .74662 m .51686 .74667 L .51661 .74332 L F
.854 .406 .007 r
.51614 .74662 m .51756 .74941 L .51648 .7484 L F
.51614 .74662 m .51648 .7484 L .51686 .74667 L F
.914 .931 .809 r
.3484 .72864 m .34775 .72992 L .34915 .73062 L F
.692 .547 .685 r
.34775 .72992 m .34769 .73082 L .34915 .73062 L F
.73 .215 0 r
.34915 .73062 m .35057 .73229 L .34769 .73082 L F
.591 .407 .601 r
.43893 .74253 m .44194 .74085 L .43987 .74097 L F
.217 0 0 r
.43987 .74097 m .44194 .74085 L .44278 .74039 L F
.365 .818 .937 r
.29124 .59315 m .29023 .59385 L .28907 .59341 L F
.29124 .59315 m .29203 .59343 L .29023 .59385 L F
.653 .358 .459 r
.51418 .72076 m .50953 .72391 L .50964 .72245 L F
.51418 .72076 m .51208 .72414 L .50953 .72391 L F
.423 .059 .241 r
.51519 .7217 m .51208 .72414 L .51418 .72076 L F
.457 .806 .998 r
.40355 .6502 m .40175 .65095 L .40201 .64729 L F
.839 .371 .036 r
.40174 .64917 m .40355 .6502 L .4028 .6488 L F
.40174 .64917 m .4028 .6488 L .40201 .64729 L F
.863 .814 .799 r
.40201 .64729 m .40001 .65079 L .39785 .64967 L F
.40001 .65079 m .39996 .65087 L .39785 .64967 L F
.123 .615 .91 r
.39604 .64916 m .39746 .64947 L .39785 .64967 L F
.863 .814 .799 r
.40201 .64729 m .39785 .64967 L .39854 .64971 L F
.123 .615 .91 r
.39746 .64947 m .39854 .64971 L .39785 .64967 L F
.839 .371 .036 r
.40174 .64917 m .40201 .64729 L .39854 .64971 L F
.241 0 0 r
.39733 .64875 m .40174 .64917 L .39854 .64971 L F
.089 .6 .889 r
.40075 .64922 m .4012 .64935 L .40174 .64917 L F
.4012 .64935 m .4042 .65019 L .40174 .64917 L F
.499 0 0 r
.40174 .64917 m .40424 .64992 L .40355 .6502 L F
.40424 .64992 m .40556 .65031 L .40355 .6502 L F
.457 .806 .998 r
.40355 .6502 m .4017 .65162 L .40175 .65095 L F
0 .259 .689 r
.57361 .71122 m .57626 .71276 L .57726 .71351 L F
0 .201 .729 r
.57901 .71444 m .57726 .71351 L .57626 .71276 L F
.57901 .71444 m .57931 .71555 L .57726 .71351 L F
0 0 .04 r
.48963 .75626 m .48944 .75514 L .49081 .75427 L F
.48963 .75626 m .48907 .75735 L .48944 .75514 L F
.257 0 .198 r
.29899 .64775 m .30168 .64541 L .30075 .64705 L F
.111 0 .111 r
.30075 .64705 m .30168 .64541 L .30325 .64452 L F
.502 .184 .361 r
.34861 .65563 m .35083 .65544 L .35193 .65275 L F
.445 .108 .299 r
.35083 .65544 m .35402 .6527 L .35193 .65275 L F
.442 .053 .205 r
.47485 .73539 m .47713 .73507 L .47822 .73311 L F
.552 .216 .353 r
.47713 .73507 m .4804 .73274 L .47822 .73311 L F
.509 .346 .595 r
.52589 .75743 m .52601 .76003 L .52382 .75803 L F
.52589 .75743 m .52601 .76003 L .52382 .75803 L F
0 .301 .796 r
.32253 .88679 m .3228 .88699 L .32275 .88712 L F
.667 .792 .332 r
.32275 .88712 m .3228 .88699 L .32249 .88765 L F
.761 .975 .92 r
.56407 .68507 m .56768 .68359 L .56557 .6844 L F
.277 .763 .674 r
.56914 .68298 m .56768 .68359 L .57013 .68366 L F
.56914 .68298 m .56557 .6844 L .56768 .68359 L F
.267 0 0 r
.74589 .60896 m .74838 .60929 L .74908 .6091 L F
.238 .745 .706 r
.74838 .60929 m .75103 .6085 L .74908 .6091 L F
.533 .544 .812 r
.43185 .65805 m .43107 .66153 L .42983 .65836 L F
.43185 .65805 m .43309 .66131 L .43107 .66153 L F
.397 .254 .568 r
.36062 .68507 m .35911 .68339 L .36007 .6829 L F
.36062 .68507 m .35869 .68652 L .35911 .68339 L F
.861 .936 .871 r
.57247 .69228 m .5689 .69403 L .57116 .69343 L F
.656 .179 .107 r
.57116 .69343 m .57418 .69385 L .57247 .69228 L F
0 .442 .782 r
.27812 .5916 m .27984 .59214 L .28138 .59286 L F
.315 .71 .979 r
.2819 .59199 m .28138 .59286 L .27984 .59214 L F
.2819 .59199 m .28334 .59289 L .28138 .59286 L F
.114 .164 .637 r
.6442 .52006 m .64404 .52093 L .64337 .51806 L F
.521 .574 .849 r
.64453 .51539 m .64337 .51806 L .64187 .51544 L F
.64453 .51539 m .64548 .51782 L .64337 .51806 L F
.728 .653 .775 r
.64548 .51782 m .6442 .52006 L .64337 .51806 L F
.302 0 0 r
.49437 .7859 m .49261 .78597 L .49111 .78722 L F
.266 .769 .87 r
.39147 .66625 m .3903 .66617 L .38926 .66659 L F
0 0 0 r
.3903 .66617 m .38845 .66709 L .38926 .66659 L F
.218 0 0 r
.44194 .74085 m .44772 .74061 L .44278 .74039 L F
.436 .383 .7 r
.58463 .70878 m .58657 .71006 L .58598 .70744 L F
.58463 .70878 m .58587 .71143 L .58657 .71006 L F
.332 .1 .404 r
.31297 .63141 m .31528 .62848 L .31468 .63087 L F
.394 .201 .496 r
.31278 .63385 m .31297 .63141 L .31468 .63087 L F
.339 .019 .268 r
.39978 .68904 m .39705 .69153 L .39881 .69099 L F
.496 .244 .462 r
.39881 .69099 m .40162 .68836 L .39978 .68904 L F
.701 .786 .917 r
.34661 .73349 m .34296 .7333 L .34343 .73127 L F
.294 .763 .94 r
.34661 .73349 m .34522 .73305 L .34296 .7333 L F
.837 .949 .892 r
.34676 .73151 m .34661 .73349 L .34769 .73082 L F
.34676 .73151 m .34522 .73305 L .34661 .73349 L F
.188 .415 .85 r
.57491 .71038 m .57626 .71276 L .57361 .71122 L F
.56 .428 .657 r
.32691 .68352 m .32907 .68302 L .32884 .68052 L F
.562 .443 .676 r
.32737 .68661 m .32907 .68302 L .32691 .68352 L F
.66 .661 .84 r
.7102 .59276 m .71181 .59571 L .71414 .59494 L F
.469 .561 .867 r
.71181 .59571 m .71482 .59809 L .71414 .59494 L F
.672 .617 .785 r
.33642 .72728 m .33965 .72785 L .33817 .72462 L F
.978 .689 .31 r
.71911 .722 m .71821 .72124 L .71619 .72188 L F
.71911 .722 m .71931 .72437 L .71821 .72124 L F
.597 .876 .556 r
.61552 .74657 m .61404 .74799 L .6129 .74928 L F
.606 .881 .56 r
.61552 .74657 m .6154 .74655 L .61404 .74799 L F
.522 .255 .451 r
.46472 .7384 m .46694 .73811 L .4673 .73609 L F
.561 .279 .445 r
.46694 .73811 m .47016 .73515 L .4673 .73609 L F
.74 .679 .791 r
.55155 .74348 m .55489 .74399 L .5536 .74106 L F
.643 .551 .736 r
.55155 .74348 m .55501 .74651 L .55489 .74399 L F
.714 .615 .745 r
.55746 .74154 m .55489 .74399 L .55773 .74299 L F
.518 .27 .477 r
.55501 .74651 m .55773 .74299 L .55489 .74399 L F
0 0 0 r
.5664 .67787 m .56727 .67818 L .56868 .6774 L F
.5664 .67787 m .56515 .67943 L .56727 .67818 L F
.684 .259 .231 r
.54285 .72159 m .54652 .72218 L .5444 .72226 L F
.243 0 .185 r
.28924 .63113 m .29108 .63058 L .29204 .6286 L F
.372 .06 .3 r
.29108 .63058 m .29391 .62781 L .29204 .6286 L F
.618 .402 .567 r
.66003 .52674 m .65954 .52908 L .65692 .52938 L F
.649 .551 .73 r
.66149 .5258 m .65954 .52908 L .66003 .52674 L F
.856 .65 .623 r
.61311 .6805 m .613 .68304 L .61589 .68346 L F
.835 .642 .642 r
.61273 .68553 m .61589 .68346 L .613 .68304 L F
.61273 .68553 m .61557 .68614 L .61589 .68346 L F
.794 .94 .923 r
.49151 .74623 m .48899 .74827 L .48991 .74712 L F
.778 .772 .847 r
.35152 .72611 m .35445 .72658 L .35498 .72672 L F
.479 .895 .815 r
.359 .72512 m .35498 .72672 L .35445 .72658 L F
.057 0 .412 r
.61878 .73512 m .61872 .7376 L .61724 .73851 L F
0 0 .199 r
.61872 .7376 m .61748 .74115 L .61724 .73851 L F
.521 .248 .442 r
.45933 .7412 m .46153 .74089 L .4624 .73812 L F
.515 .184 .344 r
.46153 .74089 m .46472 .7384 L .4624 .73812 L F
.989 .777 .524 r
.71888 .60567 m .71995 .60649 L .71917 .60343 L F
.699 .66 .807 r
.60121 .71938 m .60281 .72188 L .59872 .72172 L F
.761 .56 .625 r
.60281 .72188 m .59866 .72422 L .59872 .72172 L F
.60281 .72188 m .60213 .72485 L .59866 .72422 L F
.553 .356 .568 r
.60281 .72188 m .6043 .72416 L .60213 .72485 L F
.195 .495 .903 r
.55227 .72694 m .55109 .72774 L .55037 .72626 L F
.55227 .72694 m .55429 .72879 L .55109 .72774 L F
.471 .142 .325 r
.39194 .69678 m .39415 .69648 L .39507 .69398 L F
.374 .05 .282 r
.39507 .69398 m .39617 .69591 L .39694 .69312 L F
.39507 .69398 m .39415 .69648 L .39617 .69591 L F
.156 0 0 r
.54377 .74459 m .54281 .7454 L .54012 .74563 L F
.467 .835 .587 r
.31483 .73307 m .31634 .73187 L .31339 .7301 L F
.31483 .73307 m .31765 .73086 L .31634 .73187 L F
.577 .419 .631 r
.55773 .74299 m .55884 .74083 L .55746 .74154 L F
.55773 .74299 m .56027 .74276 L .55884 .74083 L F
.384 .309 .648 r
.55884 .74083 m .56186 .74035 L .55916 .73913 L F
.56186 .74035 m .56185 .7403 L .55916 .73913 L F
.153 .054 .481 r
.56027 .74276 m .56189 .74041 L .55884 .74083 L F
.662 .48 .628 r
.56387 .74006 m .56235 .74214 L .56178 .74004 L F
.153 .054 .481 r
.56189 .74041 m .56194 .74034 L .56186 .74035 L F
.56189 .74041 m .56186 .74035 L .55884 .74083 L F
.325 0 .088 r
.55976 .74003 m .55916 .73913 L .56185 .7403 L F
.662 .48 .628 r
.56235 .74214 m .56171 .74302 L .56189 .74045 L F
.153 .054 .481 r
.56189 .74041 m .56171 .74302 L .56194 .74034 L F
.56027 .74276 m .56171 .74302 L .56189 .74041 L F
.662 .48 .628 r
.56189 .74045 m .56171 .74302 L .56178 .74004 L F
.5617 .74028 m .56171 .74302 L .55976 .74003 L F
.56177 .74019 m .56171 .74302 L .5617 .74004 L F
.384 .309 .648 r
.56186 .74035 m .56194 .74034 L .56185 .7403 L F
.325 0 .088 r
.55976 .74003 m .56185 .7403 L .56194 .74034 L F
.662 .48 .628 r
.5617 .74004 m .5617 .74028 L .55976 .74003 L F
.56178 .74004 m .56177 .74019 L .5617 .74004 L F
0 0 0 r
.57873 .67881 m .57806 .67883 L .57907 .67869 L F
.568 .876 .583 r
.58009 .6773 m .57846 .67889 L .57873 .67881 L F
.006 0 0 r
.57873 .67881 m .57751 .67982 L .57533 .6806 L F
.568 .876 .583 r
.57846 .67889 m .57751 .67982 L .57873 .67881 L F
0 0 0 r
.57873 .67881 m .57907 .67869 L .58026 .67854 L F
.57873 .67881 m .57673 .67972 L .57806 .67883 L F
.437 0 0 r
.48818 .78993 m .49021 .79036 L .48676 .79023 L F
.502 .183 .359 r
.41472 .69206 m .41652 .69333 L .41432 .69365 L F
.494 .187 .375 r
.417 .69171 m .41652 .69333 L .41472 .69206 L F
.674 .608 .773 r
.56852 .69999 m .57024 .70192 L .57009 .69934 L F
.747 .767 .869 r
.57009 .69934 m .57024 .70192 L .57323 .6995 L F
.527 .355 .591 r
.43138 .75499 m .43349 .75459 L .43343 .75221 L F
.535 .387 .627 r
.43138 .75499 m .43364 .75695 L .43349 .75459 L F
.43138 .75499 m .43153 .75745 L .43364 .75695 L F
.416 .794 .992 r
.7356 .70873 m .73368 .70903 L .73279 .70839 L F
.476 .37 .654 r
.57856 .74693 m .58081 .74915 L .58006 .74644 L F
.796 .751 .812 r
.74026 .62279 m .73813 .62552 L .73554 .62437 L F
.504 .245 .456 r
.42164 .68586 m .42135 .6886 L .41927 .68876 L F
.502 .258 .477 r
.42432 .68508 m .42135 .6886 L .42164 .68586 L F
.532 .306 .517 r
.407 .68347 m .4092 .68323 L .40954 .6806 L F
.476 .257 .502 r
.40954 .6806 m .41122 .68271 L .41183 .68031 L F
.40954 .6806 m .4092 .68323 L .41122 .68271 L F
.616 .284 .385 r
.46057 .75794 m .46262 .75977 L .46031 .75965 L F
.48 .307 .568 r
.46265 .75735 m .46262 .75977 L .46057 .75794 L F
.46265 .75735 m .46262 .75977 L .46057 .75794 L F
.19 .683 .92 r
.30698 .59611 m .30915 .59614 L .31069 .59675 L F
.286 .728 .964 r
.31124 .59599 m .31069 .59675 L .30915 .59614 L F
.31124 .59599 m .31283 .59666 L .31069 .59675 L F
.313 .604 .95 r
.43532 .78496 m .43579 .78382 L .4334 .7826 L F
.43532 .78496 m .437 .78513 L .43579 .78382 L F
.042 .611 .708 r
.37568 .70341 m .37787 .70328 L .37992 .70316 L F
.518 .27 .477 r
.55501 .74651 m .55751 .74635 L .55773 .74299 L F
.206 .022 .397 r
.55773 .74299 m .55915 .74459 L .56027 .74276 L F
.55773 .74299 m .55751 .74635 L .55915 .74459 L F
.479 .071 .187 r
.3562 .65239 m .35847 .65228 L .35987 .65036 L F
.295 0 0 r
.35847 .65228 m .36218 .65044 L .35987 .65036 L F
.947 .707 .242 r
.54923 .74822 m .5491 .74669 L .54766 .7464 L F
.589 .225 .318 r
.54394 .74945 m .54598 .75099 L .54923 .74822 L F
.396 0 .087 r
.54598 .75099 m .54911 .74921 L .54923 .74822 L F
.947 .707 .242 r
.54923 .74822 m .54911 .74921 L .5491 .74669 L F
.394 0 .08 r
.54826 .75076 m .5484 .75069 L .54911 .74921 L F
.985 .706 .377 r
.54911 .74921 m .55012 .75018 L .54956 .74828 L F
.701 .599 .739 r
.5491 .74669 m .55012 .75018 L .55266 .74683 L F
.344 .763 .977 r
.54911 .74921 m .55302 .74964 L .55012 .75018 L F
.54966 .74927 m .55168 .74906 L .55302 .74964 L F
.54911 .74921 m .55168 .74906 L .54966 .74927 L F
.625 .451 .627 r
.55266 .74683 m .55302 .74964 L .55501 .74651 L F
.55266 .74683 m .55302 .74964 L .55501 .74651 L F
.574 .868 .995 r
.55302 .74964 m .55168 .74906 L .55386 .74848 L F
.54 .166 .28 r
.55053 .75056 m .55319 .7489 L .55168 .74906 L F
.55319 .7489 m .55386 .74848 L .55168 .74906 L F
.394 0 .08 r
.5484 .75069 m .55168 .74906 L .54911 .74921 L F
.985 .706 .377 r
.54911 .74921 m .54956 .74828 L .5491 .74669 L F
.502 .387 .655 r
.32853 .67805 m .32884 .68052 L .33075 .68008 L F
.502 .387 .654 r
.32853 .67805 m .33075 .68008 L .33047 .67764 L F
.718 .627 .755 r
.71482 .59809 m .71787 .5959 L .71414 .59494 L F
.018 .229 .736 r
.5787 .73872 m .57904 .73798 L .57756 .73575 L F
.998 .853 .555 r
.57913 .7412 m .57904 .73798 L .5787 .73872 L F
.102 .615 .891 r
.3937 .64976 m .39577 .65004 L .39706 .65059 L F
.361 .721 .987 r
.39785 .64967 m .39706 .65059 L .39577 .65004 L F
.39785 .64967 m .39996 .65087 L .39706 .65059 L F
.164 0 0 r
.37172 .71879 m .37058 .71992 L .36834 .72058 L F
.176 0 0 r
.37172 .71879 m .37321 .71894 L .37058 .71992 L F
.893 .673 .598 r
.60357 .69425 m .60519 .69733 L .60339 .69684 L F
.866 .706 .682 r
.60519 .69733 m .60168 .69953 L .60339 .69684 L F
.60519 .69733 m .60447 .69978 L .60168 .69953 L F
.892 .784 .735 r
.62209 .69942 m .62035 .70232 L .62272 .70263 L F
.863 .71 .691 r
.62035 .70232 m .6224 .70487 L .62272 .70263 L F
.342 .218 .562 r
.75355 .60852 m .75469 .6112 L .75237 .61189 L F
.235 .002 .343 r
.75469 .6112 m .7519 .6138 L .75237 .61189 L F
.278 .023 .336 r
.29654 .62292 m .29807 .62257 L .29877 .62032 L F
.371 .298 .644 r
.29654 .62292 m .29841 .62489 L .29807 .62257 L F
.474 .312 .581 r
.29654 .62292 m .29659 .62573 L .29841 .62489 L F
.545 0 0 r
.48729 .78503 m .48736 .78477 L .48594 .78414 L F
.48729 .78503 m .48874 .78581 L .48736 .78477 L F
.787 .619 .673 r
.50107 .76283 m .5049 .76355 L .50488 .76147 L F
.47 .363 .651 r
.50666 .76273 m .5049 .76355 L .50488 .76147 L F
.568 .334 .521 r
.50675 .76054 m .50666 .76273 L .50488 .76147 L F
.47 .363 .651 r
.50666 .76273 m .5049 .76355 L .50488 .76147 L F
.568 .334 .521 r
.50488 .76147 m .50666 .76273 L .50675 .76054 L F
.50675 .76054 m .50666 .76273 L .50488 .76147 L F
.50675 .76054 m .50666 .76273 L .50488 .76147 L F
.083 .458 .886 r
.74407 .58791 m .74152 .58601 L .74336 .58656 L F
.374 .612 .943 r
.74557 .5868 m .74407 .58791 L .74336 .58656 L F
.74557 .5868 m .74741 .58883 L .74407 .58791 L F
.151 .383 .834 r
.58259 .75194 m .58081 .74915 L .58153 .74966 L F
.267 0 0 r
.27816 .60325 m .2785 .60416 L .27638 .60471 L F
.27816 .60325 m .28031 .60295 L .2785 .60416 L F
.775 .814 .884 r
.60121 .71938 m .59872 .72172 L .59708 .72038 L F
.261 .029 .36 r
.29842 .7431 m .29637 .74591 L .29722 .74357 L F
.29842 .7431 m .29637 .74591 L .29722 .74357 L F
0 0 0 r
.29842 .7431 m .29781 .7435 L .29722 .74357 L F
.905 .895 .808 r
.55229 .73285 m .549 .73533 L .54937 .73272 L F
.506 .754 .985 r
.42502 .65521 m .42398 .65662 L .42291 .65528 L F
.42502 .65521 m .42643 .65624 L .42398 .65662 L F
.502 .154 .309 r
.55296 .68562 m .55535 .68536 L .55648 .68309 L F
.155 0 .123 r
.55648 .68309 m .55684 .68452 L .55983 .68221 L F
.55648 .68309 m .55535 .68536 L .55684 .68452 L F
.824 .588 .582 r
.52237 .74331 m .52602 .74382 L .52568 .74117 L F
.496 .353 .616 r
.52568 .74117 m .52684 .73882 L .52648 .73698 L F
.52568 .74117 m .52777 .74096 L .52684 .73882 L F
.553 .424 .659 r
.52777 .74096 m .52602 .74382 L .52568 .74117 L F
.496 .353 .616 r
.52684 .73882 m .52777 .74096 L .52568 .74117 L F
.553 .424 .659 r
.52777 .74096 m .52602 .74382 L .52568 .74117 L F
.279 0 .192 r
.54677 .69238 m .54726 .69413 L .5489 .69144 L F
0 0 .237 r
.5474 .69289 m .54726 .69413 L .54677 .69238 L F
.5474 .69289 m .54677 .69238 L .54518 .69308 L F
.422 .034 .195 r
.39511 .70766 m .39462 .70857 L .39185 .70985 L F
.357 0 .161 r
.39686 .70809 m .39462 .70857 L .39511 .70766 L F
.38 .019 .221 r
.48563 .72961 m .48711 .72981 L .48844 .72779 L F
.447 .089 .264 r
.48844 .72779 m .49017 .72885 L .49065 .72732 L F
.48844 .72779 m .48711 .72981 L .49017 .72885 L F
.357 0 .087 r
.54356 .6944 m .54223 .69605 L .54277 .69584 L F
.54356 .6944 m .54277 .69584 L .54579 .69465 L F
.404 .089 .313 r
.54277 .69584 m .54376 .69595 L .54579 .69465 L F
0 0 0 r
.54182 .6974 m .54277 .69584 L .54349 .69453 L F
.404 .089 .313 r
.54223 .69605 m .5427 .69597 L .54277 .69584 L F
.987 .881 .634 r
.54274 .69589 m .5427 .69597 L .54223 .69605 L F
0 0 0 r
.54182 .6974 m .54273 .69591 L .54277 .69584 L F
.987 .881 .634 r
.5427 .69597 m .54172 .69766 L .54223 .69605 L F
.404 .089 .313 r
.54223 .69605 m .54267 .69602 L .5427 .69597 L F
.54267 .69602 m .54376 .69595 L .54277 .69584 L F
0 0 0 r
.54349 .69453 m .54277 .69584 L .54356 .6944 L F
.54273 .69591 m .54274 .69589 L .54356 .6944 L F
.983 .878 .65 r
.54327 .69929 m .54274 .69589 L .54182 .6974 L F
.534 .312 .525 r
.42657 .6828 m .42432 .68508 L .42429 .68317 L F
.848 .585 .541 r
.60503 .6739 m .60805 .67253 L .60469 .67219 L F
.60503 .6739 m .60813 .67483 L .60805 .67253 L F
.255 0 .146 r
.29899 .64775 m .29777 .65006 L .29633 .6498 L F
.377 .044 .268 r
.30075 .64705 m .29777 .65006 L .29899 .64775 L F
.39 .377 .725 r
.43164 .78245 m .43256 .77904 L .43034 .77939 L F
.43164 .78245 m .4334 .7826 L .43256 .77904 L F
.426 .251 .54 r
.31528 .62848 m .31708 .62574 L .3165 .62781 L F
.148 0 .336 r
.31468 .63087 m .31528 .62848 L .3165 .62781 L F
.681 .553 .703 r
.33013 .71591 m .3278 .71881 L .32851 .71662 L F
.905 .686 .595 r
.60121 .68557 m .60291 .68631 L .60268 .68869 L F
.601 .927 .705 r
.31634 .73187 m .31765 .73086 L .31928 .72937 L F
.791 .557 .582 r
.61164 .6802 m .61317 .67804 L .61142 .67771 L F
.61164 .6802 m .61311 .6805 L .61317 .67804 L F
.875 .879 .835 r
.49777 .75809 m .49581 .75748 L .49718 .75501 L F
.93 .602 .395 r
.49777 .75809 m .4964 .75941 L .49581 .75748 L F
0 0 0 r
.49963 .75895 m .4964 .75941 L .49777 .75809 L F
.61 .46 .654 r
.49997 .7549 m .50033 .75803 L .49777 .75809 L F
.487 .06 .154 r
.50033 .75803 m .49963 .75895 L .49777 .75809 L F
.99 .751 .372 r
.32798 .71091 m .32835 .71107 L .32724 .70983 L F
.803 .854 .888 r
.53588 .76365 m .53386 .76576 L .53227 .76495 L F
.666 .595 .767 r
.53655 .76523 m .53386 .76576 L .53588 .76365 L F
.672 .583 .747 r
.54048 .75998 m .53705 .75708 L .54019 .75736 L F
.718 .694 .827 r
.54019 .75736 m .54359 .75749 L .54295 .75702 L F
.42 .827 .976 r
.54295 .75702 m .54151 .75652 L .54019 .75736 L F
.148 .201 .662 r
.54151 .75652 m .54048 .75998 L .54019 .75736 L F
.54151 .75652 m .54228 .75924 L .54048 .75998 L F
.919 .72 .618 r
.32336 .7307 m .32255 .73263 L .32117 .72949 L F
.632 .812 .969 r
.32471 .72982 m .32336 .7307 L .32117 .72949 L F
.633 .682 .879 r
.6442 .52006 m .64676 .52133 L .64404 .52093 L F
.395 .007 .18 r
.56868 .6774 m .57087 .67704 L .57102 .67588 L F
.215 0 .146 r
.57102 .67588 m .57274 .67605 L .57338 .67484 L F
.57102 .67588 m .57087 .67704 L .57274 .67605 L F
.023 .367 .837 r
.56062 .75852 m .56337 .76027 L .5623 .75866 L F
.499 0 0 r
.52744 .71799 m .52895 .71731 L .52701 .71594 L F
.52744 .71799 m .5284 .71797 L .52895 .71731 L F
0 .306 .796 r
.56039 .73267 m .56287 .73441 L .56265 .73517 L F
0 .008 .583 r
.56287 .73441 m .56437 .73761 L .56265 .73517 L F
.576 .47 .696 r
.45285 .76516 m .45031 .76349 L .45265 .76315 L F
.45285 .76516 m .45066 .76564 L .45031 .76349 L F
.927 .757 .651 r
.60253 .69107 m .60404 .6918 L .60357 .69425 L F
.662 .248 .25 r
.32236 .88697 m .3228 .88699 L .32253 .88679 L F
.22 0 0 r
.58566 .67723 m .5822 .67788 L .58354 .67728 L F
.572 .589 .832 r
.43498 .66119 m .43429 .66492 L .43309 .66131 L F
.43498 .66119 m .43659 .66505 L .43429 .66492 L F
.883 .774 .736 r
.59951 .72722 m .59655 .72696 L .59866 .72422 L F
.721 .688 .818 r
.60213 .72485 m .59951 .72722 L .59866 .72422 L F
.108 .103 .569 r
.61874 .72683 m .61919 .72921 L .6178 .73028 L F
0 0 .078 r
.61919 .72921 m .61809 .73264 L .6178 .73028 L F
.348 .064 .332 r
.33778 .66136 m .33862 .65891 L .33615 .66134 L F
.491 .181 .367 r
.33959 .66125 m .33862 .65891 L .33778 .66136 L F
.33959 .66125 m .34072 .65874 L .33862 .65891 L F
.944 .824 .697 r
.333 .71099 m .3309 .71025 L .3318 .70812 L F
.523 .577 .851 r
.333 .71099 m .3318 .70812 L .3309 .71025 L F
.333 .71099 m .33297 .70775 L .3318 .70812 L F
.333 .71099 m .33473 .71054 L .33297 .70775 L F
.269 0 0 r
.46656 .78671 m .47028 .78695 L .46878 .78683 L F
.374 0 0 r
.47028 .78695 m .47211 .78756 L .46878 .78683 L F
.533 .496 .761 r
.3281 .68895 m .33 .68846 L .32737 .68661 L F
.548 .442 .686 r
.32846 .69211 m .33 .68846 L .3281 .68895 L F
.457 .664 .951 r
.74241 .71124 m .74033 .71027 L .74208 .7102 L F
.429 .538 .866 r
.74707 .71173 m .74704 .71317 L .74634 .71312 L F
.445 .419 .736 r
.74617 .713 m .74517 .71303 L .74241 .71124 L F
.429 .538 .866 r
.74617 .713 m .74634 .71312 L .74517 .71303 L F
.445 .419 .736 r
.74622 .71303 m .74517 .71303 L .74617 .713 L F
.429 .538 .866 r
.7457 .71267 m .74617 .713 L .74517 .71303 L F
.74707 .71173 m .74634 .71312 L .7457 .71267 L F
.445 .419 .736 r
.7457 .71267 m .74241 .71124 L .74209 .71021 L F
.74622 .71303 m .74617 .713 L .7457 .71267 L F
.74617 .713 m .74241 .71124 L .7457 .71267 L F
.425 .53 .86 r
.74707 .71173 m .7457 .71267 L .74622 .71303 L F
.7457 .71267 m .74517 .71303 L .74622 .71303 L F
.445 .419 .736 r
.74622 .71303 m .74209 .71021 L .74208 .7102 L F
.456 .078 .232 r
.57338 .67484 m .57589 .67468 L .5766 .67259 L F
.163 0 .12 r
.5766 .67259 m .57772 .67371 L .57891 .67233 L F
.5766 .67259 m .57589 .67468 L .57772 .67371 L F
.353 .682 .979 r
.32019 .59739 m .31968 .59844 L .31827 .59756 L F
.32019 .59739 m .3214 .59845 L .31968 .59844 L F
.398 .554 .893 r
.32313 .60106 m .31968 .59844 L .3214 .59845 L F
.553 .152 .237 r
.72419 .71041 m .72543 .71149 L .7278 .70944 L F
.329 .19 .536 r
.72679 .70899 m .72543 .71149 L .72419 .71041 L F
.553 .152 .237 r
.72543 .71149 m .72589 .71147 L .7278 .70944 L F
.662 .584 .757 r
.72418 .71153 m .72589 .71147 L .72679 .70899 L F
.72589 .71147 m .72718 .71143 L .72703 .71046 L F
0 0 0 r
.7278 .70944 m .72954 .70811 L .73049 .70891 L F
.7278 .70944 m .72636 .71097 L .72954 .70811 L F
.72636 .71097 m .72589 .71147 L .72682 .71062 L F
.72636 .71097 m .72682 .71062 L .72954 .70811 L F
.72589 .71147 m .72673 .71072 L .72954 .70811 L F
.765 .671 .759 r
.72954 .70811 m .72673 .71072 L .72679 .70899 L F
.582 .626 .861 r
.72703 .71046 m .72843 .70897 L .72679 .70899 L F
.7273 .71218 m .72823 .70953 L .72703 .71046 L F
.72823 .70953 m .72843 .70897 L .72703 .71046 L F
.662 .584 .757 r
.72589 .71147 m .72673 .71072 L .72679 .70899 L F
0 0 0 r
.72589 .71147 m .72568 .7117 L .72673 .71072 L F
.765 .671 .759 r
.72673 .71072 m .72568 .7117 L .72679 .70899 L F
.662 .584 .757 r
.72673 .71072 m .72703 .71046 L .72679 .70899 L F
.72543 .71149 m .7273 .71218 L .72718 .71143 L F
.553 .152 .237 r
.72543 .71149 m .72568 .7117 L .72589 .71147 L F
.329 .19 .536 r
.72679 .70899 m .72568 .7117 L .72543 .71149 L F
.662 .584 .757 r
.72418 .71153 m .72528 .71176 L .72543 .71149 L F
.72528 .71176 m .7273 .71218 L .72543 .71149 L F
.72366 .71143 m .72418 .71153 L .72679 .70899 L F
.523 .514 .787 r
.59283 .71049 m .59101 .71112 L .5901 .70774 L F
.395 .177 .461 r
.59283 .71049 m .59063 .71331 L .59101 .71112 L F
.465 .556 .864 r
.74924 .58863 m .74735 .59025 L .74741 .58883 L F
.49 .483 .776 r
.74924 .58863 m .74813 .59234 L .74735 .59025 L F
.072 0 0 r
.3826 .71441 m .38211 .71366 L .38412 .713 L F
.3826 .71441 m .3805 .71511 L .38211 .71366 L F
.376 .702 .984 r
.58075 .72041 m .58325 .72064 L .58227 .72141 L F
.106 .2 .68 r
.58325 .72064 m .58398 .7237 L .58227 .72141 L F
.347 .51 .877 r
.32387 .59936 m .32313 .60106 L .3214 .59845 L F
.485 .674 .948 r
.32387 .59936 m .32527 .60098 L .32313 .60106 L F
.531 .72 .96 r
.31513 .72664 m .31415 .72775 L .31544 .72642 L F
.628 .421 .583 r
.64709 .5321 m .64783 .5345 L .64365 .53477 L F
.655 .44 .58 r
.64904 .53205 m .64783 .5345 L .64709 .5321 L F
.511 .154 .297 r
.45347 .74358 m .45691 .74128 L .45383 .74135 L F
.45347 .74358 m .4558 .74333 L .45691 .74128 L F
.565 .211 .327 r
.45691 .74128 m .4558 .74333 L .45881 .74281 L F
.552 .217 .354 r
.45691 .74128 m .45881 .74281 L .45933 .7412 L F
.773 .819 .889 r
.7375 .72972 m .73873 .73087 L .74046 .72972 L F
.103 0 0 r
.39585 .66513 m .39714 .66494 L .399 .66501 L F
.822 .619 .628 r
.61733 .68892 m .61714 .69142 L .619 .69154 L F
.839 .595 .57 r
.61727 .69363 m .619 .69154 L .61714 .69142 L F
.61727 .69363 m .61936 .69454 L .619 .69154 L F
.952 .746 .589 r
.58033 .70275 m .57935 .70288 L .57941 .69937 L F
.887 .531 .366 r
.58033 .70275 m .57939 .70446 L .57935 .70288 L F
.583 .673 .901 r
.57982 .69986 m .58033 .70275 L .57941 .69937 L F
.57982 .69986 m .58257 .70233 L .58033 .70275 L F
0 0 0 r
.58033 .70275 m .58207 .70218 L .58257 .70233 L F
.58033 .70275 m .57939 .70446 L .58207 .70218 L F
.58207 .70218 m .57939 .70446 L .58033 .70275 L F
.625 .22 .256 r
.56667 .69269 m .5689 .69403 L .56582 .69381 L F
.604 .27 .377 r
.55528 .7597 m .55079 .76187 L .55256 .76012 L F
.088 .358 .826 r
.55004 .73612 m .55251 .73789 L .5524 .73686 L F
.597 .48 .69 r
.53625 .73356 m .53585 .7356 L .53832 .73504 L F
.303 0 .15 r
.49928 .79252 m .49957 .79138 L .50174 .79058 L F
.499 .326 .578 r
.41779 .66691 m .41984 .66642 L .41987 .66409 L F
.719 .642 .771 r
.41786 .66911 m .41984 .66642 L .41779 .66691 L F
0 .169 .691 r
.73506 .62613 m .73559 .62862 L .73584 .62669 L F
.36 .57 .918 r
.73559 .62862 m .73823 .62935 L .73584 .62669 L F
.582 .437 .649 r
.42931 .76013 m .43182 .76072 L .43153 .75745 L F
.608 .479 .68 r
.42931 .76013 m .43223 .76284 L .43182 .76072 L F
.42931 .76013 m .42998 .76332 L .43223 .76284 L F
.561 .279 .445 r
.46694 .73811 m .46927 .73798 L .47016 .73515 L F
.534 .232 .401 r
.46927 .73798 m .47245 .73522 L .47016 .73515 L F
.873 .681 .641 r
.52707 .79244 m .52863 .79358 L .52759 .79076 L F
.733 .733 .851 r
.52543 .79352 m .52863 .79358 L .52707 .79244 L F
.664 .627 .802 r
.7165 .60464 m .71917 .60343 L .7177 .60027 L F
.543 .338 .552 r
.71888 .60567 m .71917 .60343 L .7165 .60464 L F
0 .007 .513 r
.49732 .75099 m .496 .74881 L .49763 .74935 L F
.836 .617 .607 r
.49969 .75072 m .49788 .75119 L .49732 .75099 L F
.534 0 0 r
.49938 .75451 m .49864 .75422 L .49997 .7549 L F
.49629 .75247 m .49864 .75422 L .49938 .75451 L F
.971 .663 .283 r
.49732 .75099 m .4978 .75359 L .49629 .75247 L F
.49732 .75099 m .49786 .75391 L .49864 .75422 L F
.49786 .75391 m .49791 .75421 L .49864 .75422 L F
.924 .627 .15 r
.49715 .7526 m .49732 .75099 L .49629 .7516 L F
.49715 .7526 m .49791 .75421 L .49732 .75099 L F
.836 .617 .607 r
.49788 .75119 m .49629 .7516 L .49732 .75099 L F
0 .007 .513 r
.49732 .75099 m .49629 .75247 L .49614 .75056 L F
.49732 .75099 m .49614 .75056 L .496 .74881 L F
.445 .208 .459 r
.41444 .67795 m .41407 .68014 L .41643 .67747 L F
0 .197 .717 r
.46278 .77754 m .46186 .77734 L .46051 .77682 L F
.46278 .77754 m .46403 .77918 L .46186 .77734 L F
.425 .114 .333 r
.34593 .65776 m .34861 .65563 L .3466 .65607 L F
0 0 0 r
.55027 .68824 m .55296 .68562 L .55104 .68637 L F
.92 .787 .31 r
.34385 .73113 m .34389 .72674 L .34224 .7271 L F
.286 .03 .34 r
.29877 .62032 m .29932 .62185 L .30027 .61958 L F
.29877 .62032 m .29807 .62257 L .29932 .62185 L F
.92 .787 .31 r
.34385 .73113 m .34343 .73127 L .34389 .72674 L F
.494 .263 .492 r
.46499 .76849 m .46366 .77065 L .4629 .76875 L F
.304 0 0 r
.59114 .67584 m .59023 .67722 L .58795 .67744 L F
.522 .026 .019 r
.59356 .67691 m .59023 .67722 L .59114 .67584 L F
.387 .437 .79 r
.74379 .59742 m .74599 .59665 L .74249 .59462 L F
.74379 .59742 m .74576 .59781 L .74599 .59665 L F
.74 .668 .78 r
.5065 .73334 m .50883 .73169 L .50853 .73004 L F
.611 .354 .502 r
.50633 .73489 m .50883 .73169 L .5065 .73334 L F
0 0 0 r
.30888 .72172 m .31224 .71863 L .30789 .71824 L F
.973 .709 .472 r
.56386 .77577 m .56465 .77709 L .5644 .77425 L F
.507 .361 .616 r
.5667 .77635 m .5644 .77425 L .56695 .77403 L F
.5667 .77635 m .56465 .77709 L .5644 .77425 L F
.501 .639 .917 r
.72869 .71505 m .73097 .7136 L .72813 .7143 L F
.72869 .71505 m .73182 .71579 L .73097 .7136 L F
.17 .55 .929 r
.42166 .65407 m .42144 .65503 L .41949 .65423 L F
.42166 .65407 m .42291 .65528 L .42144 .65503 L F
.59 .313 .465 r
.63655 .54037 m .6366 .54171 L .63348 .5429 L F
.526 .286 .494 r
.63655 .54037 m .6388 .54142 L .6366 .54171 L F
.63655 .54037 m .63893 .53986 L .6388 .54142 L F
.392 0 0 r
.26909 .60393 m .26736 .6054 L .26529 .60542 L F
.413 0 0 r
.2711 .60445 m .26736 .6054 L .26909 .60393 L F
.534 .424 .675 r
.33615 .66383 m .33778 .66136 L .33615 .66134 L F
0 0 0 r
.3146 .71436 m .31329 .71616 L .31532 .71346 L F
.516 .616 .89 r
.40054 .66719 m .40193 .66551 L .399 .66501 L F
.40054 .66719 m .40256 .667 L .40193 .66551 L F
.472 .638 .928 r
.54359 .75749 m .54507 .75645 L .54295 .75702 L F
.54359 .75749 m .5457 .75785 L .54507 .75645 L F
.67 .488 .63 r
.54359 .75749 m .5467 .75989 L .5457 .75785 L F
.54359 .75749 m .54392 .76054 L .5467 .75989 L F
.805 .529 .52 r
.55323 .69718 m .5567 .69983 L .55548 .69668 L F
.55323 .69718 m .55333 .69937 L .5567 .69983 L F
.577 .031 0 r
.55333 .69937 m .55534 .70046 L .5567 .69983 L F
.653 .626 .81 r
.55548 .69668 m .5567 .69983 L .55903 .69907 L F
.516 .251 .452 r
.5567 .69983 m .55871 .7012 L .55903 .69907 L F
0 .234 .726 r
.55827 .70052 m .55871 .7012 L .5567 .69983 L F
.55828 .70053 m .55828 .70054 L .55827 .70052 L F
.55828 .70054 m .55871 .7012 L .55827 .70052 L F
.487 .846 .992 r
.55548 .69668 m .55307 .69648 L .55323 .69718 L F
.653 .626 .81 r
.55548 .69668 m .55903 .69907 L .55752 .69662 L F
.478 .231 .461 r
.55548 .69668 m .55752 .69662 L .55761 .69442 L F
0 0 0 r
.5569 .6952 m .55548 .69668 L .55761 .69442 L F
.789 .425 .368 r
.55548 .69668 m .55741 .70037 L .55307 .69648 L F
0 .234 .726 r
.55828 .70053 m .5567 .69983 L .55534 .70046 L F
.459 .639 .934 r
.55548 .69668 m .55752 .69662 L .5569 .6952 L F
.161 .169 .619 r
.5569 .6952 m .55741 .70037 L .55548 .69668 L F
.685 .566 .715 r
.55437 .69615 m .55633 .69887 L .5569 .6952 L F
.55633 .69887 m .55741 .70037 L .55735 .69974 L F
.55633 .69887 m .55735 .69974 L .5569 .6952 L F
.487 .902 .857 r
.55651 .7416 m .55746 .74154 L .55846 .74072 L F
.464 .338 .623 r
.33246 .66952 m .33444 .67162 L .33423 .66905 L F
.33246 .66952 m .33232 .67215 L .33444 .67162 L F
.371 0 0 r
.36218 .65044 m .36445 .65017 L .36543 .64949 L F
0 0 0 r
.36445 .65017 m .36781 .64888 L .36543 .64949 L F
.461 .34 .629 r
.43785 .74663 m .43893 .74253 L .43742 .74435 L F
.728 .653 .775 r
.64548 .51782 m .64676 .52133 L .6442 .52006 L F
.608 .587 .804 r
.64893 .52021 m .64676 .52133 L .64548 .51782 L F
.6 .22 .294 r
.50508 .79247 m .50503 .79128 L .50709 .7927 L F
.932 .552 .193 r
.50372 .79023 m .50503 .79128 L .50508 .79247 L F
.56 .351 .554 r
.43897 .67244 m .43887 .6747 L .43663 .675 L F
.524 .327 .556 r
.44119 .66968 m .44115 .67202 L .43897 .67244 L F
.598 .422 .615 r
.44115 .67202 m .43887 .6747 L .43897 .67244 L F
.633 .41 .561 r
.65692 .52938 m .65471 .53171 L .65473 .52948 L F
.554 .401 .628 r
.43343 .75221 m .43567 .75188 L .43551 .74937 L F
.415 .202 .479 r
.43349 .75459 m .43567 .75188 L .43343 .75221 L F
.763 .494 .527 r
.45104 .74286 m .45347 .74358 L .45383 .74135 L F
0 0 0 r
.36445 .65017 m .36643 .64952 L .36781 .64888 L F
.204 .728 .736 r
.36643 .64952 m .36991 .64875 L .36781 .64888 L F
.77 .677 .76 r
.50107 .76283 m .5023 .76593 L .5049 .76355 L F
0 .328 .78 r
.3307 .60277 m .32885 .60183 L .32722 .60039 L F
.885 .504 .04 r
.55856 .75082 m .55942 .75238 L .55995 .75247 L F
.1 .566 .911 r
.29264 .60676 m .29311 .60619 L .29119 .60568 L F
.29264 .60676 m .29494 .60727 L .29311 .60619 L F
.475 .484 .787 r
.44217 .66648 m .44119 .66968 L .4402 .66574 L F
.44217 .66648 m .44329 .66943 L .44119 .66968 L F
.633 .415 .57 r
.44361 .67179 m .44119 .66968 L .44329 .66943 L F
.44361 .67179 m .44115 .67202 L .44119 .66968 L F
.839 .468 .351 r
.52298 .70947 m .52506 .70821 L .52291 .70731 L F
.52298 .70947 m .52528 .71117 L .52506 .70821 L F
.133 0 .066 r
.53645 .79073 m .53294 .79388 L .53549 .79329 L F
0 .271 .768 r
.53645 .79073 m .53936 .793 L .53884 .79288 L F
.692 .383 .447 r
.53549 .79329 m .53936 .793 L .53645 .79073 L F
0 0 .305 r
.61973 .72084 m .61873 .72431 L .61874 .72194 L F
.564 .422 .646 r
.57155 .76829 m .56902 .76875 L .57048 .76535 L F
.572 .378 .58 r
.57155 .76829 m .56885 .77109 L .56902 .76875 L F
0 0 .328 r
.56903 .7687 m .57006 .77 L .56922 .76782 L F
.56902 .76875 m .56909 .76883 L .56903 .7687 L F
.56909 .76883 m .57006 .77 L .56903 .7687 L F
.572 .378 .58 r
.57155 .76829 m .57133 .77094 L .57005 .77102 L F
.56969 .77021 m .57005 .77102 L .56885 .77109 L F
.57155 .76829 m .57005 .77102 L .56969 .77021 L F
.899 .53 .071 r
.56922 .76782 m .57006 .77 L .56904 .76805 L F
.695 .286 .267 r
.56783 .7664 m .56922 .76782 L .56651 .7675 L F
.899 .53 .071 r
.56922 .76782 m .56863 .76726 L .56651 .7675 L F
.56922 .76782 m .56904 .76805 L .56863 .76726 L F
.736 .829 .372 r
.57048 .76535 m .5697 .76717 L .56922 .76782 L F
.5697 .76717 m .56902 .76875 L .56922 .76782 L F
0 0 .328 r
.56902 .76875 m .56885 .77109 L .57006 .77 L F
.238 .745 .706 r
.74838 .60929 m .75089 .6085 L .75103 .6085 L F
.748 .994 .842 r
.75376 .6061 m .75103 .6085 L .75202 .60664 L F
.677 .858 .457 r
.75103 .6085 m .75089 .6085 L .75202 .60664 L F
.631 .743 .928 r
.75355 .60852 m .75103 .6085 L .75376 .6061 L F
.856 .409 .137 r
.55937 .69429 m .55752 .69662 L .55761 .69442 L F
.55937 .69429 m .55981 .69662 L .55752 .69662 L F
.55937 .69429 m .56152 .69756 L .55981 .69662 L F
.55981 .69662 m .56152 .69756 L .55937 .69429 L F
0 .277 .78 r
.32816 .71015 m .32867 .71075 L .32724 .70983 L F
.99 .751 .372 r
.32798 .71091 m .32724 .70983 L .32867 .71075 L F
.397 .196 .487 r
.50844 .76019 m .50666 .76273 L .50675 .76054 L F
.50844 .76019 m .50666 .76273 L .50675 .76054 L F
.475 .32 .59 r
.28913 .63318 m .29108 .63058 L .28924 .63113 L F
.3 .287 .677 r
.30088 .61737 m .30168 .61373 L .30018 .61413 L F
.30088 .61737 m .30216 .61657 L .30168 .61373 L F
.257 .034 .372 r
.30088 .61737 m .30193 .61865 L .30216 .61657 L F
.30088 .61737 m .30027 .61958 L .30193 .61865 L F
.594 .103 .058 r
.50609 .78918 m .50706 .78804 L .50367 .78782 L F
.679 .168 0 r
.50799 .78967 m .50706 .78804 L .50609 .78918 L F
.337 0 0 r
.50829 .79032 m .50799 .78967 L .50676 .79087 L F
.679 .168 0 r
.50799 .78967 m .50924 .79059 L .50747 .78852 L F
.256 .643 .964 r
.51006 .78968 m .50924 .79059 L .50799 .78967 L F
.337 0 0 r
.51006 .78968 m .50799 .78967 L .50829 .79032 L F
.679 .168 0 r
.50799 .78967 m .50747 .78852 L .50706 .78804 L F
.555 .464 .707 r
.45369 .76837 m .45066 .76564 L .45285 .76516 L F
.45369 .76837 m .45139 .7691 L .45066 .76564 L F
.505 .905 .79 r
.72009 .71417 m .72001 .71401 L .72022 .7137 L F
0 0 0 r
.72022 .7137 m .72167 .71268 L .72264 .71132 L F
.72001 .71401 m .72167 .71268 L .72022 .7137 L F
.524 .545 .819 r
.50093 .75141 m .49997 .7549 L .49864 .75422 L F
.50093 .75141 m .50196 .75478 L .49997 .7549 L F
.627 .473 .653 r
.5027 .75775 m .49997 .7549 L .50196 .75478 L F
.5027 .75775 m .50033 .75803 L .49997 .7549 L F
.697 .656 .806 r
.71414 .59494 m .71787 .5959 L .71647 .59422 L F
.354 0 0 r
.47557 .78839 m .47636 .78947 L .47431 .78866 L F
.47557 .78839 m .47771 .78845 L .47636 .78947 L F
.325 0 .088 r
.55976 .74003 m .55846 .74072 L .55916 .73913 L F
.364 .095 .365 r
.40645 .70165 m .40516 .7004 L .40711 .69973 L F
.40645 .70165 m .40458 .70228 L .40516 .7004 L F
.447 .792 .998 r
.28681 .59337 m .28334 .59289 L .28557 .5929 L F
.235 .697 .948 r
.28754 .59271 m .28681 .59337 L .28557 .5929 L F
.28754 .59271 m .28907 .59341 L .28681 .59337 L F
.749 .543 .616 r
.62786 .5371 m .6294 .53733 L .62852 .53971 L F
0 0 0 r
.37865 .67071 m .37842 .67012 L .38019 .66905 L F
.37865 .67071 m .37728 .67185 L .37842 .67012 L F
0 .192 .704 r
.56833 .74134 m .5705 .74313 L .57031 .74334 L F
.826 .568 .016 r
.57047 .74558 m .57091 .74664 L .57031 .74334 L F
.57047 .74558 m .57031 .74334 L .5705 .74313 L F
.526 .558 .831 r
.72438 .72481 m .72724 .72395 L .72518 .72408 L F
.72438 .72481 m .72844 .72692 L .72724 .72395 L F
.623 .526 .724 r
.72438 .72481 m .72624 .72794 L .72844 .72692 L F
.531 .451 .711 r
.41658 .67518 m .41818 .67182 L .41612 .67285 L F
.41658 .67518 m .41859 .67467 L .41818 .67182 L F
.473 .273 .528 r
.41658 .67518 m .41643 .67747 L .41859 .67467 L F
.737 .591 .694 r
.49151 .74623 m .49131 .74421 L .49234 .74418 L F
.182 0 0 r
.29633 .6498 m .29511 .6511 L .29296 .6517 L F
.273 0 0 r
.29777 .65006 m .29511 .6511 L .29633 .6498 L F
.891 .938 .567 r
.55307 .69648 m .55196 .69877 L .55323 .69718 L F
.935 .641 .458 r
.55196 .69877 m .55333 .69937 L .55323 .69718 L F
.633 .41 .561 r
.65692 .52938 m .65694 .53162 L .65471 .53171 L F
.643 .435 .587 r
.65954 .52908 m .65694 .53162 L .65692 .52938 L F
.875 .679 .634 r
.61559 .68835 m .61714 .69142 L .61733 .68892 L F
.551 .499 .751 r
.3291 .6944 m .33037 .69161 L .32846 .69211 L F
.3291 .6944 m .33113 .69397 L .33037 .69161 L F
.465 .327 .609 r
.3291 .6944 m .33097 .6963 L .33113 .69397 L F
.3291 .6944 m .32927 .69681 L .33097 .6963 L F
.481 .251 .488 r
.407 .68347 m .40873 .68531 L .4092 .68323 L F
.407 .68347 m .4067 .68579 L .40873 .68531 L F
.88 .74 .704 r
.44727 .66396 m .44563 .66649 L .44592 .66427 L F
.151 .691 .822 r
.34279 .65858 m .3442 .65868 L .34072 .65874 L F
.571 .925 .95 r
.34593 .65776 m .3442 .65868 L .34279 .65858 L F
.478 .643 .929 r
.73542 .72985 m .73571 .72824 L .73373 .72775 L F
.73542 .72985 m .7375 .72972 L .73571 .72824 L F
.175 0 0 r
.53878 .76909 m .53623 .76917 L .53734 .76859 L F
.376 .657 .967 r
.53873 .76907 m .53623 .76917 L .53878 .76909 L F
.163 0 0 r
.53734 .76859 m .53623 .76917 L .53469 .76924 L F
.466 .436 .741 r
.539 .76804 m .53734 .76859 L .53655 .76523 L F
.376 .657 .967 r
.53479 .76758 m .53623 .76917 L .53873 .76907 L F
.163 0 0 r
.53469 .76924 m .53623 .76917 L .53373 .76947 L F
.175 0 0 r
.53878 .76909 m .53734 .76859 L .539 .76804 L F
.692 .199 .071 r
.72479 .58936 m .72764 .5898 L .72635 .59077 L F
.904 .492 .124 r
.72764 .5898 m .73087 .59299 L .72916 .59042 L F
.491 0 0 r
.72764 .5898 m .72901 .59095 L .72635 .59077 L F
.72764 .5898 m .72916 .59042 L .72901 .59095 L F
.611 .354 .502 r
.50633 .73489 m .50877 .73506 L .50883 .73169 L F
.38 .413 .77 r
.50853 .73004 m .50883 .73169 L .51126 .73267 L F
.109 0 .08 r
.50877 .73506 m .51126 .73267 L .50883 .73169 L F
.751 .597 .686 r
.32249 .88765 m .3228 .88699 L .32236 .88697 L F
.713 .884 .493 r
.63014 .5215 m .6287 .52374 L .62913 .52281 L F
.734 .893 .501 r
.63014 .5215 m .62913 .52281 L .63089 .51989 L F
.748 .903 .516 r
.63089 .51989 m .62913 .52281 L .62983 .52113 L F
0 0 .089 r
.62913 .52281 m .62988 .5234 L .62983 .52128 L F
.62913 .52281 m .62983 .52128 L .62983 .52113 L F
.713 .884 .493 r
.6287 .52374 m .62847 .5241 L .62913 .52281 L F
.562 .443 .676 r
.32737 .68661 m .3294 .68611 L .32907 .68302 L F
.575 .492 .724 r
.32737 .68661 m .33 .68846 L .3294 .68611 L F
.234 .523 .916 r
.29644 .59428 m .29596 .59547 L .29499 .594 L F
.396 .71 .986 r
.29644 .59428 m .29807 .59551 L .29596 .59547 L F
.411 .636 .948 r
.31339 .7301 m .31634 .73187 L .3153 .7299 L F
.615 .759 .948 r
.3153 .7299 m .31634 .73187 L .31762 .72956 L F
.601 .927 .705 r
.31634 .73187 m .31928 .72937 L .31762 .72956 L F
.409 .732 .991 r
.47181 .77865 m .47309 .77973 L .47093 .77969 L F
.47093 .77969 m .47309 .77973 L .47181 .77865 L F
.488 .84 .995 r
.47093 .77969 m .46966 .77913 L .47181 .77865 L F
.858 .667 .643 r
.57048 .76535 m .56783 .7664 L .56936 .76358 L F
.736 .829 .372 r
.57048 .76535 m .56922 .76782 L .56783 .7664 L F
.39 .06 .281 r
.57367 .76337 m .57237 .76505 L .57048 .76535 L F
0 0 .18 r
.57237 .76505 m .57155 .76829 L .57048 .76535 L F
.479 .895 .815 r
.359 .72512 m .35635 .72569 L .35498 .72672 L F
.463 0 0 r
.3606 .72383 m .35635 .72569 L .359 .72512 L F
.418 0 .117 r
.27578 .64374 m .27952 .6417 L .27774 .64258 L F
.493 .247 .47 r
.41208 .69428 m .41151 .69628 L .40973 .69663 L F
.418 .157 .41 r
.41432 .69365 m .41151 .69628 L .41208 .69428 L F
.629 .075 0 r
.53775 .71894 m .54024 .72067 L .54093 .72021 L F
.676 .135 0 r
.54024 .72067 m .54285 .72159 L .54093 .72021 L F
.001 0 .388 r
.7484 .59541 m .74855 .59764 L .74794 .59844 L F
.431 .368 .687 r
.75018 .59196 m .7484 .59541 L .74813 .59234 L F
.75018 .59196 m .75087 .59431 L .7484 .59541 L F
.461 .303 .58 r
.75087 .59431 m .74855 .59764 L .7484 .59541 L F
.164 0 0 r
.27413 .6557 m .27043 .65644 L .27202 .65637 L F
.571 .51 .748 r
.35905 .69128 m .35728 .69385 L .35693 .6917 L F
.35905 .69128 m .36017 .69493 L .35728 .69385 L F
.631 .518 .706 r
.36055 .6965 m .35728 .69385 L .36017 .69493 L F
.36055 .6965 m .3582 .69716 L .35728 .69385 L F
.355 .663 .972 r
.74208 .7102 m .74033 .71027 L .73884 .70854 L F
.495 .311 .561 r
.70913 .58138 m .70617 .5836 L .70861 .5837 L F
.347 .37 .742 r
.57932 .7164 m .58075 .72041 L .57917 .71905 L F
.555 .312 .501 r
.4573 .76037 m .45493 .76265 L .45495 .76049 L F
.827 .797 .823 r
.40492 .66639 m .40846 .66609 L .40707 .66569 L F
.40492 .66639 m .40677 .66756 L .40846 .66609 L F
.362 0 0 r
.41133 .665 m .40707 .66569 L .40846 .66609 L F
.548 .297 .487 r
.43887 .6747 m .43635 .67706 L .43663 .675 L F
.669 .275 .291 r
.49021 .79036 m .49364 .79047 L .49249 .79219 L F
.695 .333 .357 r
.49364 .79047 m .49598 .79246 L .49249 .79219 L F
.49364 .79047 m .49592 .79121 L .49598 .79246 L F
.791 .619 .668 r
.46929 .76212 m .46791 .75946 L .46952 .76044 L F
.257 0 .051 r
.47211 .76046 m .46929 .76212 L .46952 .76044 L F
.597 .394 .576 r
.64365 .53477 m .64358 .53727 L .64131 .53747 L F
.631 .422 .58 r
.64696 .53626 m .64365 .53477 L .64783 .5345 L F
.64696 .53626 m .64358 .53727 L .64365 .53477 L F
.572 .494 .728 r
.32736 .70022 m .32795 .70262 L .33005 .7022 L F
.548 .418 .656 r
.32813 .70539 m .33005 .7022 L .32795 .70262 L F
.435 .516 .843 r
.73209 .72034 m .73343 .72298 L .73014 .7217 L F
.435 .846 .968 r
.71282 .59021 m .71687 .58985 L .71496 .58712 L F
.71687 .58985 m .71282 .59021 L .71495 .59143 L F
.729 .645 .766 r
.71496 .58712 m .71687 .58985 L .71876 .58791 L F
.923 .693 .572 r
.71495 .59143 m .7169 .59252 L .71687 .58985 L F
.796 .751 .812 r
.74026 .62279 m .73554 .62437 L .7389 .62193 L F
.715 .864 .952 r
.7375 .72972 m .74046 .72972 L .73949 .72897 L F
.744 .87 .938 r
.73949 .72897 m .74046 .72972 L .74356 .72788 L F
.23 0 0 r
.38979 .71052 m .38825 .71203 L .38618 .71244 L F
.322 0 .034 r
.39185 .70985 m .38825 .71203 L .38979 .71052 L F
.42 .139 .378 r
.40412 .7041 m .40269 .70291 L .40458 .70228 L F
.40412 .7041 m .40208 .70477 L .40269 .70291 L F
.635 .119 .001 r
.50867 .7924 m .51044 .79334 L .50709 .7927 L F
.723 .675 .803 r
.54766 .7464 m .5491 .74669 L .54808 .74296 L F
.786 .711 .782 r
.54808 .74296 m .5491 .74669 L .55155 .74348 L F
.702 .585 .721 r
.5491 .74669 m .55266 .74683 L .55155 .74348 L F
.309 .752 .964 r
.26166 .58728 m .25977 .58741 L .25817 .58686 L F
.572 .494 .728 r
.32736 .70022 m .33005 .7022 L .32933 .69926 L F
.552 .047 0 r
.55978 .68228 m .56051 .68298 L .55983 .68221 L F
0 0 0 r
.55983 .68221 m .55684 .68452 L .55978 .68228 L F
.354 .022 .256 r
.55983 .68221 m .56051 .68298 L .56141 .68115 L F
.688 .281 .269 r
.58716 .72242 m .58611 .72388 L .58952 .72405 L F
.451 .345 .643 r
.7542 .60621 m .75355 .60852 L .75376 .6061 L F
.7542 .60621 m .7565 .60808 L .75355 .60852 L F
.323 .208 .564 r
.75618 .61003 m .75355 .60852 L .7565 .60808 L F
.75618 .61003 m .75469 .6112 L .75355 .60852 L F
.206 0 .284 r
.48162 .77461 m .48094 .77649 L .48315 .7737 L F
.48162 .77461 m .48094 .77649 L .48315 .7737 L F
.606 .615 .834 r
.36128 .86159 m .36297 .86473 L .36053 .86498 L F
.36128 .86159 m .36053 .86498 L .36133 .86467 L F
.575 .36 .551 r
.36053 .86498 m .36297 .86473 L .3626 .86737 L F
0 .154 .695 r
.36053 .86498 m .3626 .86737 L .36133 .86467 L F
0 0 .286 r
.53204 .74867 m .53239 .74975 L .53187 .74841 L F
.53204 .74867 m .53239 .74975 L .53187 .74841 L F
.672 .429 .546 r
.65143 .53214 m .64911 .53429 L .64904 .53205 L F
.65143 .53214 m .6515 .53467 L .64911 .53429 L F
.627 .394 .545 r
.65473 .53336 m .65143 .53214 L .65471 .53171 L F
.65473 .53336 m .6515 .53467 L .65143 .53214 L F
.458 .099 .269 r
.26345 .60628 m .2603 .60832 L .26119 .60698 L F
.346 0 .19 r
.29478 .62689 m .29592 .62735 L .29659 .62573 L F
.29478 .62689 m .29391 .62781 L .29592 .62735 L F
0 0 0 r
.5294 .75751 m .53056 .75701 L .53149 .75544 L F
.137 0 0 r
.53149 .75544 m .53244 .75626 L .53377 .75482 L F
.53149 .75544 m .53056 .75701 L .53244 .75626 L F
.515 .184 .344 r
.46153 .74089 m .46382 .74066 L .46472 .7384 L F
.464 .134 .321 r
.46472 .7384 m .46659 .73945 L .46694 .73811 L F
.46472 .7384 m .46382 .74066 L .46659 .73945 L F
.225 0 .34 r
.3165 .62781 m .31708 .62574 L .31856 .62494 L F
.534 .133 .227 r
.52118 .72176 m .51747 .72378 L .5173 .72178 L F
.52118 .72176 m .5198 .72399 L .51747 .72378 L F
.616 .599 .81 r
.52118 .72176 m .52356 .72152 L .5233 .7211 L F
.636 .245 .286 r
.52387 .72092 m .52118 .72176 L .52389 .72081 L F
.616 .599 .81 r
.52118 .72176 m .5233 .7211 L .52236 .71959 L F
.469 .2 .422 r
.52108 .72403 m .52356 .72152 L .52118 .72176 L F
.52108 .72403 m .52328 .72363 L .52356 .72152 L F
.636 .245 .286 r
.52328 .72363 m .52118 .72176 L .52387 .72092 L F
.52328 .72363 m .5198 .72399 L .52118 .72176 L F
.424 .218 .494 r
.39694 .69312 m .39881 .69099 L .39705 .69153 L F
.655 .44 .58 r
.64904 .53205 m .64911 .53429 L .64783 .5345 L F
.171 .08 .502 r
.5063 .72415 m .50513 .72728 L .50444 .72505 L F
.578 .066 0 r
.48123 .78845 m .48334 .7897 L .4799 .78948 L F
.558 .869 .995 r
.38446 .66764 m .38326 .66886 L .38496 .66812 L F
.38446 .66764 m .38236 .66834 L .38326 .66886 L F
.098 .16 .639 r
.73413 .71883 m .73427 .7157 L .73182 .71579 L F
.73413 .71883 m .73495 .71901 L .73427 .7157 L F
.937 .842 .402 r
.56936 .76358 m .56906 .76243 L .5699 .76044 L F
.107 0 .421 r
.5699 .76044 m .57147 .75976 L .57167 .75698 L F
0 0 0 r
.5699 .76044 m .56995 .76163 L .57147 .75976 L F
.5699 .76044 m .56906 .76243 L .56995 .76163 L F
.643 .551 .736 r
.55155 .74348 m .55266 .74683 L .55501 .74651 L F
.511 .211 .394 r
.48264 .73263 m .48488 .73253 L .48563 .72961 L F
.537 .281 .474 r
.48488 .73253 m .48711 .72981 L .48563 .72961 L F
.454 .285 .561 r
.56165 .68804 m .55955 .68942 L .56066 .68716 L F
.706 .914 .966 r
.5578 .68894 m .55955 .68942 L .56165 .68804 L F
.192 .686 .92 r
.64893 .52021 m .65141 .52032 L .65227 .52077 L F
.255 .729 .94 r
.65227 .52077 m .65141 .52032 L .6544 .5207 L F
.65227 .52077 m .65141 .52032 L .6544 .5207 L F
.557 .024 0 r
.51273 .79345 m .51383 .79299 L .51596 .79432 L F
.014 0 0 r
.37538 .6488 m .37741 .6484 L .37895 .64764 L F
.548 .067 .066 r
.37741 .6484 m .38103 .64758 L .37895 .64764 L F
.948 .688 .509 r
.62043 .71025 m .62178 .71322 L .62138 .71081 L F
.147 0 0 r
.58381 .66891 m .58564 .66883 L .58686 .66756 L F
.319 0 0 r
.58686 .66756 m .58872 .66795 L .58908 .66699 L F
.58686 .66756 m .58564 .66883 L .58872 .66795 L F
.526 .577 .85 r
.72916 .59042 m .73087 .59299 L .73336 .59162 L F
.53 .587 .856 r
.73087 .59299 m .73343 .59289 L .73336 .59162 L F
.741 .65 .759 r
.3278 .71881 m .32924 .72187 L .32591 .72127 L F
0 0 0 r
.32924 .72187 m .32572 .7242 L .32591 .72127 L F
.32924 .72187 m .32767 .72346 L .32572 .7242 L F
.627 .597 .8 r
.33179 .72082 m .32924 .72187 L .3278 .71881 L F
.567 .119 .147 r
.33133 .72306 m .32767 .72346 L .32924 .72187 L F
.554 .158 .245 r
.73343 .72298 m .7363 .72159 L .73367 .72406 L F
.532 .407 .655 r
.32884 .68052 m .33104 .68266 L .33075 .68008 L F
.32884 .68052 m .32907 .68302 L .33104 .68266 L F
.128 0 .132 r
.56141 .68115 m .56051 .68298 L .56311 .68011 L F
.595 .406 .596 r
.43551 .74937 m .43781 .7491 L .43785 .74663 L F
.461 .34 .629 r
.43785 .74663 m .43975 .74629 L .43893 .74253 L F
.595 .476 .686 r
.43781 .7491 m .43975 .74629 L .43785 .74663 L F
.519 0 0 r
.36991 .64875 m .37186 .64929 L .37344 .64858 L F
.256 0 0 r
.37344 .64858 m .37186 .64929 L .37538 .6488 L F
.595 .412 .603 r
.4281 .76861 m .43051 .76841 L .43069 .76532 L F
.462 .344 .634 r
.43069 .76532 m .43223 .76284 L .42998 .76332 L F
.43069 .76532 m .4325 .76528 L .43223 .76284 L F
.512 .342 .587 r
.43069 .76532 m .43249 .7679 L .4325 .76528 L F
.43069 .76532 m .43051 .76841 L .43249 .7679 L F
.72 .359 .365 r
.6259 .53753 m .62786 .5371 L .62683 .53893 L F
.749 .543 .616 r
.62786 .5371 m .62852 .53971 L .62683 .53893 L F
0 .119 .668 r
.41987 .66409 m .42148 .66504 L .419 .66304 L F
0 .355 .702 r
.42148 .66504 m .42188 .66517 L .42188 .66517 L F
0 .119 .668 r
.41987 .66409 m .42041 .66469 L .42148 .66504 L F
.416 .26 .56 r
.41984 .66642 m .42162 .66604 L .41987 .66409 L F
.659 .104 0 r
.419 .66304 m .42024 .66403 L .41917 .66403 L F
.42024 .66403 m .42148 .66504 L .41917 .66403 L F
.863 .486 0 r
.42188 .66517 m .42114 .66436 L .41917 .66403 L F
.482 .803 1 r
.42114 .66436 m .41851 .66402 L .41917 .66403 L F
.659 .104 0 r
.419 .66304 m .41917 .66403 L .41694 .66418 L F
.2 .72 .691 r
.41777 .66393 m .41694 .66418 L .41917 .66403 L F
.482 .803 1 r
.41851 .66402 m .41777 .66393 L .41917 .66403 L F
0 .355 .702 r
.42148 .66504 m .42188 .66517 L .41917 .66403 L F
0 .119 .668 r
.42041 .66469 m .42162 .66604 L .42148 .66504 L F
.435 .065 .235 r
.36553 .67935 m .36429 .68203 L .36212 .68247 L F
.273 0 .266 r
.3678 .67752 m .36709 .68 L .36553 .67935 L F
.357 0 .197 r
.36631 .68165 m .36553 .67935 L .36709 .68 L F
.36631 .68165 m .36429 .68203 L .36553 .67935 L F
.834 .808 .825 r
.6279 .52915 m .62856 .53182 L .62701 .53091 L F
.926 .813 .716 r
.62856 .53182 m .62634 .53205 L .62701 .53091 L F
.62856 .53182 m .62723 .53496 L .62634 .53205 L F
.719 .642 .771 r
.41786 .66911 m .42095 .6696 L .41984 .66642 L F
.547 .243 .404 r
.41818 .67182 m .42095 .6696 L .41786 .66911 L F
.41818 .67182 m .42053 .67152 L .42095 .6696 L F
.614 .636 .849 r
.42095 .6696 m .42162 .66604 L .41984 .66642 L F
.42095 .6696 m .42357 .66968 L .42162 .66604 L F
.588 .281 .416 r
.42053 .67152 m .4229 .67136 L .42095 .6696 L F
.6 .278 .395 r
.42095 .6696 m .4229 .67136 L .42357 .66968 L F
0 0 .005 r
.57418 .76201 m .57237 .76505 L .57367 .76337 L F
.429 .86 .934 r
.28302 .65492 m .2817 .65479 L .27975 .65501 L F
.431 .861 .934 r
.2817 .65479 m .28265 .65497 L .2864 .65419 L F
.429 .86 .934 r
.28302 .65492 m .28265 .65497 L .2817 .65479 L F
.955 .885 .489 r
.52615 .79283 m .52759 .79076 L .52424 .78975 L F
.52615 .79283 m .52707 .79244 L .52759 .79076 L F
.87 .574 .484 r
.57091 .74664 m .57131 .74919 L .57312 .74928 L F
.836 .472 .365 r
.57131 .74919 m .57189 .75107 L .57312 .74928 L F
.965 .693 .467 r
.57189 .75107 m .57346 .75287 L .57312 .74928 L F
.904 .721 .644 r
.60381 .70261 m .60168 .69953 L .60447 .69978 L F
.527 .411 .664 r
.36062 .68507 m .35859 .68914 L .35869 .68652 L F
.115 .53 .914 r
.74336 .58656 m .74152 .58601 L .73942 .58451 L F
.428 .838 .971 r
.26803 .64542 m .27198 .64541 L .26959 .64576 L F
.213 0 .2 r
.37407 .67351 m .37293 .67279 L .37495 .67236 L F
.37407 .67351 m .37228 .67439 L .37293 .67279 L F
0 .084 .61 r
.56677 .73941 m .56524 .73813 L .56437 .73761 L F
.56677 .73941 m .56741 .74024 L .56524 .73813 L F
.149 0 0 r
.36625 .72137 m .36476 .72265 L .36278 .72312 L F
.044 0 0 r
.36834 .72058 m .3674 .72146 L .36625 .72137 L F
.045 0 0 r
.3674 .72146 m .36476 .72265 L .36625 .72137 L F
.592 .799 .978 r
.40256 .667 m .40677 .66756 L .40492 .66639 L F
.343 0 0 r
.73942 .58451 m .73772 .58404 L .73655 .58418 L F
.39 .165 .448 r
.50189 .74074 m .49968 .74353 L .50018 .74169 L F
.762 .456 .468 r
.50435 .75163 m .50128 .7495 L .50431 .74936 L F
.521 .318 .546 r
.50632 .75126 m .50431 .74936 L .50666 .74895 L F
.50632 .75126 m .50435 .75163 L .50431 .74936 L F
.559 .175 .271 r
.54092 .73005 m .5367 .73219 L .53659 .73009 L F
.54092 .73005 m .53865 .73228 L .5367 .73219 L F
.939 .766 .641 r
.31841 .7267 m .31928 .72937 L .31803 .72766 L F
.371 .743 .99 r
.30205 .59466 m .30154 .59564 L .30015 .59521 L F
.30205 .59466 m .30364 .59557 L .30154 .59564 L F
.152 .694 .752 r
.27777 .65521 m .27619 .65538 L .27413 .6557 L F
0 0 0 r
.27975 .65501 m .27619 .65538 L .27777 .65521 L F
.59 .386 .573 r
.51427 .73005 m .51675 .72963 L .51679 .72739 L F
.48 .291 .546 r
.51679 .72739 m .5187 .72693 L .51887 .72456 L F
.472 .286 .547 r
.51675 .72963 m .5187 .72693 L .51679 .72739 L F
.422 .092 .299 r
.41151 .69628 m .40887 .69895 L .40973 .69663 L F
.408 .206 .492 r
.52602 .74382 m .52577 .74609 L .52394 .74648 L F
.405 .223 .519 r
.52561 .7484 m .52394 .74648 L .52577 .74609 L F
.52557 .74836 m .52387 .74945 L .52394 .74648 L F
.766 .523 .567 r
.52211 .74808 m .52571 .74613 L .52209 .74574 L F
.52571 .74613 m .52577 .74609 L .52571 .74609 L F
.52571 .74613 m .52571 .74609 L .52209 .74574 L F
.405 .223 .519 r
.52561 .7484 m .52557 .74843 L .52557 .74836 L F
.52557 .74843 m .52387 .74945 L .52557 .74836 L F
.676 .385 .472 r
.53596 .75386 m .53826 .75421 L .53937 .75113 L F
.611 .349 .496 r
.53826 .75421 m .54126 .75124 L .53937 .75113 L F
.516 .382 .636 r
.33047 .67764 m .33233 .67425 L .33029 .67529 L F
.365 0 .151 r
.40162 .68836 m .40382 .68797 L .40469 .68651 L F
.581 .298 .45 r
.40382 .68797 m .4067 .68579 L .40469 .68651 L F
.497 .771 .993 r
.41237 .65238 m .4116 .65377 L .4103 .65249 L F
.41237 .65238 m .4138 .65345 L .4116 .65377 L F
.639 .637 .832 r
.36844 .70494 m .36491 .70281 L .36703 .70228 L F
.634 .649 .848 r
.37052 .70421 m .36844 .70494 L .36703 .70228 L F
.425 .72 .986 r
.26926 .58864 m .2688 .58992 L .26732 .58877 L F
.26926 .58864 m .27075 .58983 L .2688 .58992 L F
.718 .256 .152 r
.50844 .76019 m .51236 .76115 L .51246 .76305 L F
.608 .442 .632 r
.51246 .76305 m .51451 .76141 L .51236 .76115 L F
.146 0 0 r
.51328 .76405 m .51246 .76305 L .51461 .76416 L F
.608 .442 .632 r
.51359 .76215 m .51505 .76309 L .51451 .76141 L F
.51269 .76287 m .51501 .76309 L .51359 .76215 L F
.51271 .76306 m .51501 .76309 L .51269 .76287 L F
.518 .11 .206 r
.51505 .76309 m .51461 .76416 L .51246 .76305 L F
0 0 .398 r
.51244 .76119 m .5135 .76382 L .51336 .7616 L F
.51236 .76115 m .51248 .76142 L .51244 .76119 L F
.51248 .76142 m .5135 .76382 L .51244 .76119 L F
.608 .442 .632 r
.51246 .76305 m .51271 .76306 L .51269 .76287 L F
.51501 .76309 m .51505 .76309 L .51359 .76215 L F
.718 .256 .152 r
.50844 .76019 m .5135 .76382 L .51248 .76142 L F
.5119 .76104 m .51248 .76142 L .51236 .76115 L F
.50844 .76019 m .51248 .76142 L .5119 .76104 L F
0 0 .398 r
.51236 .76115 m .51336 .7616 L .51451 .76141 L F
.426 .869 .881 r
.41406 .66433 m .41327 .66426 L .41133 .665 L F
.396 .853 .876 r
.41509 .6637 m .41406 .66433 L .41629 .66316 L F
.41509 .6637 m .41327 .66426 L .41406 .66433 L F
.057 0 0 r
.50414 .73568 m .50492 .73657 L .50633 .73489 L F
.50414 .73568 m .50286 .73758 L .50492 .73657 L F
.506 .509 .794 r
.53588 .76365 m .53881 .76498 L .53655 .76523 L F
.466 .436 .741 r
.539 .76804 m .53655 .76523 L .53881 .76498 L F
.737 .591 .694 r
.49151 .74623 m .48991 .74712 L .49131 .74421 L F
.327 0 0 r
.7334 .58564 m .73202 .58482 L .73141 .58488 L F
.7334 .58564 m .73472 .5847 L .73202 .58482 L F
.572 .728 .948 r
.74002 .59502 m .74166 .59323 L .73921 .59362 L F
.74002 .59502 m .74249 .59462 L .74166 .59323 L F
.548 .442 .686 r
.32846 .69211 m .33037 .69161 L .33 .68846 L F
.387 .135 .406 r
.28224 .63958 m .28419 .63883 L .28446 .6364 L F
.4 .133 .39 r
.28446 .6364 m .2866 .63627 L .2871 .63389 L F
.148 0 .332 r
.28446 .6364 m .28543 .6377 L .2866 .63627 L F
.28446 .6364 m .28419 .63883 L .28543 .6377 L F
.39 0 .172 r
.38857 .69918 m .39194 .69678 L .38968 .69692 L F
.371 .081 .336 r
.32357 .61746 m .32618 .61504 L .3253 .61663 L F
.194 0 .154 r
.3253 .61663 m .32618 .61504 L .32789 .61424 L F
0 .216 .728 r
.56634 .71835 m .56503 .71536 L .56606 .71632 L F
.786 .711 .782 r
.54808 .74296 m .55155 .74348 L .55038 .74247 L F
.023 0 .447 r
.55299 .74055 m .55155 .74348 L .55038 .74247 L F
.55299 .74055 m .55296 .74303 L .55155 .74348 L F
.206 .603 .948 r
.55155 .74348 m .55296 .74303 L .55038 .74247 L F
.207 0 .318 r
.2871 .63389 m .28809 .63527 L .28913 .63318 L F
.2871 .63389 m .2866 .63627 L .28809 .63527 L F
.951 .762 .611 r
.60253 .69107 m .60357 .69425 L .6021 .69381 L F
.661 .314 0 r
.60339 .69684 m .6021 .69381 L .60357 .69425 L F
.425 .227 .505 r
.33444 .67162 m .33232 .67215 L .33233 .67425 L F
.185 0 0 r
.58381 .66891 m .5829 .67062 L .58564 .66883 L F
.537 .359 .588 r
.30228 .73007 m .3045 .73007 L .30435 .7272 L F
.858 .561 .484 r
.61273 .68553 m .61559 .68835 L .61557 .68614 L F
.665 .712 .884 r
.55903 .69907 m .56231 .69962 L .56152 .69756 L F
.278 0 0 r
.55871 .7012 m .56231 .69962 L .55903 .69907 L F
.55871 .7012 m .56087 .701 L .56231 .69962 L F
.73 .748 .866 r
.56152 .69756 m .56231 .69962 L .5636 .69875 L F
.709 .371 .403 r
.56087 .701 m .5636 .69875 L .56231 .69962 L F
.578 .345 .527 r
.43551 .74937 m .4376 .75137 L .43781 .7491 L F
.482 .346 .619 r
.43551 .74937 m .43567 .75188 L .4376 .75137 L F
0 .478 .843 r
.27833 .59123 m .27812 .5916 L .27535 .59029 L F
.27833 .59123 m .27984 .59214 L .27812 .5916 L F
.66 .661 .84 r
.7102 .59276 m .71414 .59494 L .71342 .59339 L F
.703 .791 .919 r
.71342 .59339 m .71414 .59494 L .71647 .59422 L F
.451 .703 .975 r
.52689 .75146 m .52943 .75165 L .52773 .75252 L F
.52689 .75146 m .52943 .75165 L .52773 .75252 L F
.328 .779 .955 r
.5283 .75722 m .53056 .75701 L .5294 .75751 L F
.84 .829 .837 r
.52937 .75969 m .53056 .75701 L .5294 .75751 L F
.656 .327 .404 r
.49629 .75247 m .49718 .75501 L .49309 .75417 L F
.439 .45 .773 r
.30018 .61413 m .30168 .61373 L .29921 .61192 L F
.681 .793 .934 r
.63887 .51092 m .63541 .51045 L .63753 .50937 L F
.728 .805 .912 r
.64086 .50968 m .63887 .51092 L .63753 .50937 L F
.559 .419 .648 r
.43153 .75745 m .43396 .76003 L .43364 .75695 L F
.43153 .75745 m .43182 .76072 L .43396 .76003 L F
0 0 .322 r
.5367 .74116 m .53807 .74016 L .53716 .73964 L F
.647 .537 .716 r
.53832 .73504 m .53716 .73964 L .54118 .73854 L F
.018 0 0 r
.53807 .74016 m .54118 .73854 L .53716 .73964 L F
.554 .158 .245 r
.73343 .72298 m .73528 .72363 L .7363 .72159 L F
.486 .583 .877 r
.73495 .71901 m .7363 .72159 L .73805 .72032 L F
.613 .404 .575 r
.73528 .72363 m .73805 .72032 L .7363 .72159 L F
0 0 0 r
.58919 .7258 m .58705 .72879 L .58822 .7268 L F
.547 .388 .617 r
.33423 .66905 m .3363 .66623 L .33434 .66676 L F
.489 .715 .971 r
.73561 .59217 m .73662 .59379 L .73921 .59362 L F
0 .249 .761 r
.56996 .74192 m .56833 .74134 L .56741 .74024 L F
.56996 .74192 m .5705 .74313 L .56833 .74134 L F
.731 .576 .681 r
.33378 .71863 m .33013 .71591 L .33365 .71631 L F
.562 .394 .611 r
.33589 .71598 m .33378 .71863 L .33365 .71631 L F
.33589 .71598 m .33378 .71863 L .33365 .71631 L F
.476 .194 .406 r
.41183 .68031 m .41323 .68217 L .41407 .68014 L F
.41183 .68031 m .41122 .68271 L .41323 .68217 L F
.338 .818 .864 r
.52387 .74945 m .51946 .7504 L .52178 .75005 L F
.551 .415 .649 r
.35859 .68914 m .35905 .69128 L .35693 .6917 L F
.295 0 0 r
.35847 .65228 m .36062 .65196 L .36218 .65044 L F
.31 0 0 r
.36062 .65196 m .36445 .65017 L .36218 .65044 L F
.627 .346 .473 r
.51495 .70725 m .51721 .7076 L .51763 .70556 L F
.534 .272 .464 r
.51721 .7076 m .51968 .70517 L .51763 .70556 L F
.658 .549 .72 r
.42806 .76993 m .43051 .76841 L .4281 .76861 L F
.802 .462 .412 r
.72187 .58314 m .72312 .58144 L .72118 .58112 L F
.596 .566 .79 r
.72342 .58532 m .72532 .58408 L .72352 .58357 L F
.255 0 0 r
.72352 .58357 m .72532 .58408 L .72187 .58314 L F
.802 .462 .412 r
.72187 .58314 m .72532 .58408 L .72312 .58144 L F
.729 .645 .766 r
.71496 .58712 m .71876 .58791 L .71741 .587 L F
0 0 0 r
.71876 .58791 m .72072 .58671 L .72031 .58763 L F
.71876 .58791 m .72031 .58763 L .71741 .587 L F
.174 0 0 r
.72072 .58671 m .72342 .58532 L .72352 .58357 L F
.596 .566 .79 r
.72342 .58532 m .72647 .58669 L .72532 .58408 L F
.49 .483 .776 r
.74924 .58863 m .75018 .59196 L .74813 .59234 L F
.591 .407 .601 r
.43893 .74253 m .44206 .74328 L .44194 .74085 L F
.532 .386 .629 r
.43893 .74253 m .44185 .74584 L .44206 .74328 L F
.43893 .74253 m .43975 .74629 L .44185 .74584 L F
.493 .465 .755 r
.36261 .69617 m .36154 .6999 L .36055 .6965 L F
.36261 .69617 m .36358 .69996 L .36154 .6999 L F
.785 .951 .618 r
.74286 .62733 m .74241 .62844 L .74296 .62698 L F
.795 .991 .75 r
.74296 .62698 m .74241 .62844 L .74325 .62733 L F
.191 .222 .664 r
.42928 .77391 m .42981 .77701 L .43112 .77604 L F
.588 .61 .841 r
.43034 .77939 m .43112 .77604 L .42981 .77701 L F
.273 .423 .83 r
.6544 .5207 m .65696 .52224 L .65588 .52355 L F
.267 .414 .825 r
.65696 .52224 m .65817 .52459 L .65588 .52355 L F
.009 0 .166 r
.49758 .72142 m .4992 .72066 L .49953 .71839 L F
0 0 .116 r
.49953 .71839 m .50091 .71774 L .50167 .71563 L F
0 0 .131 r
.49953 .71839 m .4992 .72066 L .50091 .71774 L F
.369 .493 .853 r
.55532 .68916 m .55703 .68922 L .55527 .68705 L F
.55532 .68916 m .55703 .68922 L .55527 .68705 L F
.536 .249 .427 r
.43408 .6778 m .43346 .68014 L .43123 .68034 L F
.551 .263 .432 r
.43601 .67914 m .43408 .6778 L .43635 .67706 L F
.43601 .67914 m .43346 .68014 L .43408 .6778 L F
.94 .574 .268 r
.5367 .74116 m .53764 .74382 L .53609 .74287 L F
.5367 .74116 m .53609 .74287 L .53807 .74016 L F
.376 0 0 r
.38103 .64758 m .3831 .64819 L .38457 .64771 L F
.496 0 0 r
.3831 .64819 m .38666 .64748 L .38457 .64771 L F
0 0 .124 r
.5711 .74763 m .57091 .74664 L .57047 .74558 L F
.5711 .74763 m .57131 .74919 L .57091 .74664 L F
.176 0 0 r
.72264 .71132 m .72366 .71143 L .72419 .71041 L F
.72264 .71132 m .72167 .71268 L .72366 .71143 L F
.99 .792 .546 r
.71187 .59027 m .71276 .58762 L .71187 .58612 L F
.71187 .59027 m .71282 .59021 L .71276 .58762 L F
.657 .584 .761 r
.71276 .58762 m .7139 .5842 L .71187 .58612 L F
.71276 .58762 m .71496 .58712 L .7139 .5842 L F
.642 .516 .694 r
.71276 .58762 m .71282 .59021 L .71496 .58712 L F
.479 0 0 r
.4446 .74091 m .44805 .74086 L .44772 .74061 L F
.316 0 .034 r
.44468 .74286 m .44645 .74275 L .44805 .74086 L F
.44468 .74286 m .44805 .74086 L .44782 .74133 L F
.479 0 0 r
.4446 .74091 m .44782 .74133 L .44805 .74086 L F
.682 .285 .288 r
.44805 .74086 m .44645 .74275 L .44994 .74291 L F
.729 .257 .125 r
.44805 .74086 m .44994 .74291 L .45104 .74286 L F
.316 0 0 r
.53433 .71905 m .53687 .71952 L .53775 .71894 L F
.631 .08 0 r
.53687 .71952 m .54024 .72067 L .53775 .71894 L F
.151 .383 .834 r
.58259 .75194 m .58342 .75088 L .58081 .74915 L F
0 .112 .637 r
.58259 .75194 m .5842 .75432 L .58342 .75088 L F
.777 .788 .861 r
.75581 .60396 m .7542 .60621 L .75376 .6061 L F
.55 .461 .708 r
.75581 .60396 m .75851 .60515 L .7542 .60621 L F
.512 .339 .583 r
.75851 .60515 m .7565 .60808 L .7542 .60621 L F
.063 0 0 r
.74578 .61101 m .74838 .60929 L .74589 .60896 L F
.136 0 .009 r
.40065 .70639 m .39999 .70526 L .40208 .70477 L F
.40065 .70639 m .39877 .70726 L .39999 .70526 L F
.505 .773 .992 r
.73263 .62645 m .73383 .6252 L .73154 .62507 L F
.73263 .62645 m .73506 .62613 L .73383 .6252 L F
.171 .08 .502 r
.5063 .72415 m .50677 .72689 L .50513 .72728 L F
0 0 0 r
.50577 .72775 m .50513 .72728 L .50677 .72689 L F
.50577 .72775 m .50433 .72914 L .50513 .72728 L F
.273 .161 .539 r
.30435 .7272 m .30561 .72818 L .30605 .72836 L F
.30435 .7272 m .3045 .73007 L .30561 .72818 L F
.559 .314 .501 r
.64358 .53727 m .6413 .53958 L .64131 .53747 L F
.898 .985 .787 r
.74495 .62394 m .74461 .62603 L .74668 .62326 L F
0 0 0 r
.74847 .62047 m .74901 .62045 L .74771 .62162 L F
.74969 .61863 m .74901 .62045 L .74847 .62047 L F
.74942 .62043 m .74901 .62045 L .7513 .61975 L F
0 0 .032 r
.74969 .61863 m .74771 .62162 L .74806 .61985 L F
0 0 0 r
.74771 .62162 m .74707 .6223 L .74806 .61985 L F
.603 .937 .742 r
.7475 .62111 m .74634 .62244 L .74901 .62045 L F
0 0 0 r
.7475 .62111 m .74901 .62045 L .74942 .62043 L F
.519 .882 .661 r
.74901 .62045 m .74833 .62095 L .74771 .62162 L F
.74833 .62095 m .74634 .62244 L .74771 .62162 L F
0 0 0 r
.74771 .62162 m .74668 .62326 L .74707 .6223 L F
.73 .989 .815 r
.74495 .62394 m .74668 .62326 L .74771 .62162 L F
.464 .838 .989 r
.44031 .78603 m .44148 .78507 L .43908 .78514 L F
.44031 .78603 m .44277 .78558 L .44148 .78507 L F
.31 0 .169 r
.53498 .79456 m .53294 .79388 L .53332 .7956 L F
.53498 .79456 m .53549 .79329 L .53294 .79388 L F
.863 .71 .691 r
.62035 .70232 m .6199 .70467 L .6224 .70487 L F
.856 .75 .745 r
.6199 .70467 m .62081 .70781 L .6224 .70487 L F
.904 .721 .644 r
.60381 .70261 m .60227 .7025 L .60168 .69953 L F
.931 .681 .538 r
.60381 .70261 m .60178 .70409 L .60227 .7025 L F
.60381 .70261 m .60362 .70486 L .60178 .70409 L F
.442 .779 .998 r
.31634 .59724 m .31283 .59666 L .31482 .59659 L F
.057 .578 .873 r
.31482 .59659 m .31827 .59756 L .31634 .59724 L F
.742 .688 .799 r
.33378 .71863 m .33705 .71902 L .33561 .7189 L F
.147 0 0 r
.44837 .78611 m .44454 .78547 L .44603 .78587 L F
.627 .461 .638 r
.5187 .72693 m .52108 .72403 L .51887 .72456 L F
.426 .095 .299 r
.495 .72405 m .49715 .72365 L .49758 .72142 L F
.26 0 .249 r
.49758 .72142 m .49898 .72283 L .4992 .72066 L F
.49758 .72142 m .49715 .72365 L .49898 .72283 L F
.514 .53 .81 r
.29921 .61192 m .29992 .60844 L .29846 .60861 L F
.29921 .61192 m .30099 .61145 L .29992 .60844 L F
.497 .449 .734 r
.29921 .61192 m .30168 .61373 L .30099 .61145 L F
0 0 0 r
.31143 .72443 m .31095 .72648 L .31042 .72749 L F
.606 .952 .9 r
.31095 .72648 m .30905 .72758 L .31042 .72749 L F
.571 .217 .33 r
.53453 .72973 m .53309 .73204 L .53105 .73192 L F
.715 .385 .419 r
.5367 .73219 m .53309 .73204 L .53453 .72973 L F
.676 .389 .48 r
.53659 .73009 m .5367 .73219 L .53453 .72973 L F
.329 .022 .283 r
.32094 .61983 m .32357 .61746 L .32283 .61924 L F
.241 0 .238 r
.32283 .61924 m .32357 .61746 L .3253 .61663 L F
.391 0 0 r
.49111 .78722 m .48874 .78581 L .48729 .78503 L F
.369 .074 .327 r
.52485 .7952 m .52543 .79352 L .52707 .79244 L F
.353 0 0 r
.31762 .85935 m .31694 .85952 L .3162 .85877 L F
.31762 .85935 m .31872 .85965 L .31694 .85952 L F
.31694 .85952 m .31762 .85935 L .3162 .85877 L F
.31694 .85952 m .31872 .85965 L .31762 .85935 L F
.665 .885 .523 r
.60204 .71801 m .60341 .71646 L .60121 .71938 L F
.996 .865 .568 r
.60263 .71557 m .60341 .71646 L .60204 .71801 L F
0 0 0 r
.75013 .61701 m .74969 .61863 L .74806 .61985 L F
.141 0 0 r
.29086 .6525 m .28904 .65377 L .28724 .6541 L F
.071 0 0 r
.29086 .65329 m .29086 .6525 L .29296 .6517 L F
.29086 .65329 m .28904 .65377 L .29086 .6525 L F
.834 .914 .89 r
.34343 .73127 m .34296 .7333 L .34145 .73259 L F
.672 .221 .173 r
.34522 .73305 m .34145 .73259 L .34296 .7333 L F
.685 .892 .973 r
.7077 .59288 m .70851 .59359 L .7102 .59276 L F
.138 0 0 r
.51127 .74844 m .51196 .74625 L .51046 .7468 L F
.285 .561 .931 r
.28958 .60542 m .289 .60329 L .28767 .60297 L F
.28958 .60542 m .29119 .60568 L .289 .60329 L F
.209 .677 .941 r
.43659 .66505 m .43916 .66515 L .4402 .66574 L F
.001 .526 .852 r
.43916 .66515 m .44081 .6655 L .4402 .66574 L F
0 .435 .834 r
.44081 .6655 m .44217 .66648 L .4402 .66574 L F
.535 .288 .488 r
.42893 .68042 m .42876 .68256 L .42657 .6828 L F
.486 .2 .404 r
.43123 .68034 m .42876 .68256 L .42893 .68042 L F
.814 .342 .092 r
.56045 .71075 m .56063 .71115 L .55819 .70978 L F
.732 .204 0 r
.48166 .78147 m .48426 .78271 L .48213 .7803 L F
.655 .378 .488 r
.51126 .73267 m .51427 .73005 L .51074 .72961 L F
.51126 .73267 m .51418 .73205 L .51427 .73005 L F
.792 .661 .718 r
.51418 .73205 m .51675 .72963 L .51427 .73005 L F
.548 .418 .656 r
.32813 .70539 m .32992 .70546 L .33005 .7022 L F
.565 .751 .965 r
.71504 .72031 m .71619 .72188 L .71821 .72124 L F
.815 .572 .57 r
.48297 .75753 m .48026 .75932 L .48092 .75581 L F
.48297 .75753 m .48295 .75991 L .48026 .75932 L F
.524 .337 .569 r
.48516 .75738 m .48297 .75753 L .4852 .75472 L F
.703 .477 .579 r
.48712 .7593 m .48297 .75753 L .48516 .75738 L F
.48712 .7593 m .48295 .75991 L .48297 .75753 L F
.988 .769 .52 r
.71107 .59198 m .71282 .59021 L .71187 .59027 L F
.586 .126 .128 r
.71495 .59143 m .71282 .59021 L .71107 .59198 L F
.557 .624 .875 r
.33279 .60256 m .3324 .60582 L .3307 .60277 L F
.33279 .60256 m .33442 .60535 L .3324 .60582 L F
.442 .338 .64 r
.33445 .60813 m .3324 .60582 L .33442 .60535 L F
.33445 .60813 m .33277 .60862 L .3324 .60582 L F
.319 .06 .356 r
.60542 .75473 m .60527 .75728 L .60335 .75714 L F
.367 .097 .366 r
.60734 .75639 m .60527 .75728 L .60542 .75473 L F
.834 .404 0 r
.57094 .72405 m .57016 .72353 L .56919 .72146 L F
.767 .259 0 r
.57094 .72405 m .57157 .72578 L .57016 .72353 L F
.57094 .72405 m .57292 .72653 L .57157 .72578 L F
0 0 .566 r
.71576 .71523 m .71527 .71609 L .71368 .71539 L F
.361 0 .102 r
.71527 .71609 m .71562 .71641 L .72009 .71417 L F
0 0 .566 r
.71576 .71523 m .71562 .71641 L .71527 .71609 L F
0 .079 .584 r
.71527 .71609 m .71578 .71637 L .71368 .71539 L F
.71527 .71609 m .7177 .71826 L .71578 .71637 L F
0 0 .176 r
.7519 .6138 m .75184 .61575 L .75013 .61701 L F
0 0 0 r
.75184 .61575 m .74969 .61863 L .75013 .61701 L F
.848 .975 .67 r
.74495 .62394 m .74325 .62733 L .74461 .62603 L F
0 0 .199 r
.61872 .7376 m .61843 .73996 L .61748 .74115 L F
0 0 0 r
.61843 .73996 m .61705 .7434 L .61748 .74115 L F
.864 .675 .646 r
.56936 .76358 m .56665 .76424 L .56906 .76243 L F
.56936 .76358 m .56783 .7664 L .56665 .76424 L F
.536 .557 .824 r
.43055 .65494 m .42983 .65836 L .42855 .65522 L F
.43055 .65494 m .43185 .65805 L .42983 .65836 L F
.863 .628 .582 r
.60121 .68557 m .59862 .68262 L .60143 .6832 L F
.991 .831 .587 r
.57424 .72738 m .57259 .72909 L .57292 .72653 L F
.57424 .72738 m .57352 .73021 L .57259 .72909 L F
.184 .643 .939 r
.39421 .64921 m .3937 .64976 L .39237 .64893 L F
.39421 .64921 m .39577 .65004 L .3937 .64976 L F
.505 .905 .79 r
.72009 .71417 m .71562 .71641 L .72001 .71401 L F
.362 0 0 r
.60335 .75714 m .60228 .7585 L .59957 .75899 L F
0 0 0 r
.60527 .75728 m .60228 .7585 L .60335 .75714 L F
.651 .283 .334 r
.59984 .6668 m .60035 .66821 L .60165 .66634 L F
.781 .485 .487 r
.60035 .66821 m .60346 .66674 L .60165 .66634 L F
.455 0 0 r
.49814 .78667 m .49437 .7859 L .49674 .78717 L F
.298 0 0 r
.49674 .78717 m .50043 .7868 L .49814 .78667 L F
0 .045 .571 r
.48661 .75627 m .48742 .75698 L .4852 .75472 L F
.686 .515 .65 r
.48661 .75627 m .48712 .7593 L .48516 .75738 L F
.48661 .75627 m .48879 .76027 L .48712 .7593 L F
.48661 .75627 m .48516 .75738 L .48742 .75698 L F
.506 .901 .936 r
.39235 .66536 m .39147 .66625 L .39322 .66546 L F
.39235 .66536 m .3903 .66617 L .39147 .66625 L F
.997 .795 .439 r
.57941 .69937 m .57935 .70288 L .57865 .70119 L F
.287 0 .215 r
.57865 .70119 m .57982 .69986 L .57941 .69937 L F
.736 .634 .746 r
.58802 .71325 m .58493 .71345 L .58657 .71006 L F
.681 .369 .44 r
.58802 .71325 m .58714 .71569 L .58493 .71345 L F
.637 .323 .422 r
.59019 .7152 m .58802 .71325 L .59063 .71331 L F
.59019 .7152 m .58714 .71569 L .58802 .71325 L F
.345 .173 .499 r
.42083 .69037 m .41927 .68876 L .42135 .6886 L F
.42083 .69037 m .41912 .69117 L .41927 .68876 L F
.772 .653 .73 r
.53487 .76011 m .53588 .76365 L .5329 .76291 L F
.803 .854 .888 r
.53588 .76365 m .53227 .76495 L .5329 .76291 L F
.549 .488 .74 r
.53799 .76337 m .53881 .76498 L .53588 .76365 L F
.38 .413 .77 r
.50853 .73004 m .51126 .73267 L .51074 .72961 L F
.314 .341 .729 r
.74855 .59764 m .74932 .60018 L .74794 .59844 L F
.588 .42 .621 r
.74932 .60018 m .74684 .60063 L .74794 .59844 L F
.662 .584 .757 r
.72366 .71143 m .72679 .70899 L .72419 .71041 L F
.481 .333 .602 r
.42928 .77391 m .43113 .77107 L .42806 .76993 L F
.42928 .77391 m .43121 .77355 L .43113 .77107 L F
.191 .222 .664 r
.42928 .77391 m .43112 .77604 L .43121 .77355 L F
0 0 0 r
.30888 .72172 m .30703 .72467 L .30781 .72347 L F
.30888 .72172 m .30979 .72149 L .31224 .71863 L F
.091 0 0 r
.30888 .72172 m .30944 .72283 L .30979 .72149 L F
.30888 .72172 m .30781 .72347 L .30944 .72283 L F
.507 0 0 r
.59255 .75852 m .59339 .75935 L .59112 .75805 L F
.59255 .75852 m .59447 .75984 L .59339 .75935 L F
.083 0 0 r
.377 .71734 m .37654 .71634 L .3785 .71569 L F
.377 .71734 m .37516 .71819 L .37654 .71634 L F
0 0 0 r
.6278 .52616 m .62913 .52281 L .62847 .5241 L F
.049 0 0 r
.48676 .79023 m .49021 .79036 L .48892 .79032 L F
.695 .212 .096 r
.49021 .79036 m .49086 .79243 L .48892 .79032 L F
.49021 .79036 m .49249 .79219 L .49086 .79243 L F
.382 .463 .819 r
.57352 .73021 m .57469 .73315 L .57637 .73161 L F
.358 .422 .791 r
.57469 .73315 m .57736 .73476 L .57637 .73161 L F
.314 .068 .372 r
.46747 .75208 m .46699 .7542 L .4653 .75472 L F
.647 .573 .758 r
.46699 .7542 m .4651 .75723 L .4653 .75472 L F
.781 .485 .487 r
.60035 .66821 m .60374 .66895 L .60346 .66674 L F
.13 .676 .812 r
.45497 .77641 m .45704 .77628 L .45852 .77639 L F
.072 .566 .893 r
.45932 .77609 m .46051 .77682 L .45852 .77639 L F
.419 .2 .473 r
.31873 .62264 m .32094 .61983 L .32062 .62205 L F
.443 .255 .53 r
.31856 .62494 m .31873 .62264 L .32062 .62205 L F
.891 .541 .376 r
.62852 .53971 m .63116 .54271 L .62832 .54207 L F
.782 .4 .332 r
.62832 .54207 m .63116 .54271 L .63178 .54442 L F
.648 .329 .419 r
.63116 .54271 m .63348 .54462 L .63178 .54442 L F
.645 .331 .426 r
.63116 .54271 m .63348 .5429 L .63348 .54462 L F
0 0 .24 r
.30703 .72467 m .30762 .72583 L .30781 .72347 L F
.861 .678 .653 r
.60121 .68557 m .60268 .68869 L .60005 .68784 L F
.942 .714 .564 r
.60268 .68869 m .60116 .69037 L .60005 .68784 L F
.60268 .68869 m .60253 .69107 L .60116 .69037 L F
.998 .853 .555 r
.57913 .7412 m .57843 .74037 L .57904 .73798 L F
.768 .522 .561 r
.52209 .74574 m .52602 .74382 L .52237 .74331 L F
.52209 .74574 m .52577 .74609 L .52602 .74382 L F
.553 .424 .659 r
.52777 .74096 m .52807 .74354 L .52602 .74382 L F
.461 .224 .466 r
.52807 .74354 m .52577 .74609 L .52602 .74382 L F
.553 .424 .659 r
.52777 .74096 m .52807 .74354 L .52602 .74382 L F
.461 .224 .466 r
.52807 .74354 m .52577 .74609 L .52602 .74382 L F
.581 .295 .446 r
.45881 .74281 m .46153 .74089 L .45933 .7412 L F
.721 .447 .511 r
.48092 .75581 m .47816 .75591 L .47958 .75467 L F
.445 .108 .299 r
.35083 .65544 m .35298 .65505 L .35402 .6527 L F
.465 .128 .309 r
.35298 .65505 m .3562 .65239 L .35402 .6527 L F
.669 .359 .44 r
.31224 .71863 m .30979 .72149 L .3133 .72083 L F
.792 .682 .743 r
.50174 .79058 m .50367 .78782 L .50043 .7868 L F
.914 .969 .669 r
.60221 .71034 m .60326 .70735 L .60251 .70814 L F
.643 .435 .587 r
.65954 .52908 m .65958 .53159 L .65694 .53162 L F
.649 .551 .73 r
.66149 .5258 m .662 .52847 L .65954 .52908 L F
.582 .387 .582 r
.66208 .53045 m .65954 .52908 L .662 .52847 L F
.66208 .53045 m .65958 .53159 L .65954 .52908 L F
.218 0 0 r
.44194 .74085 m .4446 .74091 L .44772 .74061 L F
.71 .473 .564 r
.32352 .72206 m .32295 .7242 L .32204 .72272 L F
.32352 .72206 m .32295 .7242 L .32204 .72272 L F
.706 .619 .757 r
.32591 .72127 m .32352 .72206 L .32216 .7189 L F
.785 .552 .583 r
.32352 .72206 m .32295 .7242 L .32222 .72268 L F
.789 .556 .584 r
.32572 .7242 m .32352 .72206 L .32591 .72127 L F
.32572 .7242 m .32309 .7242 L .32352 .72206 L F
.32309 .7242 m .323 .72403 L .32352 .72206 L F
.009 .196 .708 r
.32222 .72267 m .32359 .72324 L .32213 .71977 L F
.32222 .72268 m .32223 .72269 L .32222 .72267 L F
.32223 .72269 m .32359 .72324 L .32222 .72267 L F
.789 .556 .584 r
.32309 .7242 m .32295 .7242 L .323 .72403 L F
.663 .707 .88 r
.55752 .69662 m .55903 .69907 L .56152 .69756 L F
.059 .268 .76 r
.45579 .773 m .45502 .774 L .45361 .77094 L F
.512 .523 .804 r
.45579 .773 m .45497 .77641 L .45502 .774 L F
.236 0 0 r
.28031 .60295 m .28073 .60358 L .2785 .60416 L F
.28031 .60295 m .28362 .60274 L .28073 .60358 L F
.431 .861 .934 r
.2817 .65479 m .2864 .65419 L .28378 .65439 L F
.08 .64 .739 r
.2864 .65419 m .28585 .65416 L .28378 .65439 L F
.2864 .65419 m .28724 .6541 L .28585 .65416 L F
.423 0 .114 r
.50229 .75842 m .50033 .75803 L .5027 .75775 L F
.50229 .75842 m .49963 .75895 L .50033 .75803 L F
.357 .329 .69 r
.31997 .70767 m .32319 .70939 L .32257 .70814 L F
.703 .791 .919 r
.71342 .59339 m .71647 .59422 L .71495 .59143 L F
.872 .781 .758 r
.71495 .59143 m .71647 .59422 L .7169 .59252 L F
0 0 0 r
.56868 .6774 m .57028 .67719 L .57087 .67704 L F
.56868 .6774 m .56727 .67818 L .57028 .67719 L F
.505 .389 .655 r
.3294 .68611 m .33104 .68266 L .32907 .68302 L F
.552 .216 .353 r
.47713 .73507 m .47954 .73488 L .4804 .73274 L F
.51 .175 .334 r
.4804 .73274 m .48217 .73406 L .48264 .73263 L F
.4804 .73274 m .47954 .73488 L .48217 .73406 L F
.88 .453 .169 r
.58772 .70522 m .58827 .70705 L .5901 .70774 L F
.39 .796 .982 r
.5901 .70774 m .58827 .70705 L .59166 .70736 L F
.523 .514 .787 r
.59283 .71049 m .5901 .70774 L .59166 .70736 L F
.868 .644 .598 r
.60853 .67938 m .61142 .67771 L .60846 .67681 L F
.60853 .67938 m .61164 .6802 L .61142 .67771 L F
.547 .356 .573 r
.4852 .75472 m .48742 .75698 L .48516 .75738 L F
.535 .272 .462 r
.41912 .69117 m .41652 .69333 L .417 .69171 L F
.531 .834 .999 r
.73279 .70839 m .73049 .70891 L .72954 .70811 L F
.747 .767 .869 r
.57009 .69934 m .57323 .6995 L .57249 .69903 L F
.838 .979 .876 r
.57509 .69671 m .57323 .6995 L .57451 .69556 L F
.57509 .69671 m .57249 .69903 L .57323 .6995 L F
.412 .194 .47 r
.32062 .62205 m .32094 .61983 L .32283 .61924 L F
.517 .347 .59 r
.72931 .62508 m .73154 .62507 L .73117 .62263 L F
.806 .761 .811 r
.72808 .62269 m .72931 .62508 L .73117 .62263 L F
.015 .538 .858 r
.26732 .58877 m .26562 .58843 L .26391 .58762 L F
.332 .69 .98 r
.30798 .59517 m .30698 .59611 L .3058 .59533 L F
.30798 .59517 m .30915 .59614 L .30698 .59611 L F
.534 .232 .401 r
.46927 .73798 m .47164 .73773 L .47245 .73522 L F
.485 .13 .287 r
.47164 .73773 m .47485 .73539 L .47245 .73522 L F
.655 .377 .487 r
.46972 .75391 m .46747 .75208 L .46976 .75172 L F
.46972 .75391 m .46699 .7542 L .46747 .75208 L F
.471 .055 .169 r
.53428 .79623 m .53543 .79801 L .53304 .7981 L F
.53428 .79623 m .53657 .79622 L .53543 .79801 L F
.775 .814 .884 r
.60121 .71938 m .59708 .72038 L .60014 .71921 L F
.687 .962 .941 r
.60121 .71938 m .60014 .71921 L .60204 .71801 L F
.658 .549 .72 r
.42806 .76993 m .43113 .77107 L .43051 .76841 L F
.571 .29 .45 r
.46752 .7787 m .46966 .77913 L .47055 .77711 L F
.464 .179 .394 r
.47055 .77711 m .47181 .77865 L .47134 .77631 L F
.47055 .77711 m .46966 .77913 L .47181 .77865 L F
.466 .223 .46 r
.49258 .72664 m .495 .72405 L .49327 .72486 L F
.954 .835 .687 r
.60343 .67137 m .60469 .67219 L .60496 .66974 L F
.918 .608 .442 r
.60343 .67137 m .60503 .6739 L .60469 .67219 L F
.823 .606 .609 r
.32478 .72554 m .32295 .7242 L .32572 .7242 L F
.415 .268 .571 r
.32767 .72346 m .32478 .72554 L .32572 .7242 L F
.748 .994 .842 r
.75376 .6061 m .75202 .60664 L .75275 .60508 L F
.817 .88 .891 r
.75581 .60396 m .75376 .6061 L .75275 .60508 L F
.34 .774 .968 r
.51312 .74064 m .51658 .74095 L .51661 .74066 L F
.775 .55 .594 r
.51356 .74271 m .51658 .74095 L .51312 .74092 L F
.5131 .74298 m .51661 .74332 L .51658 .74095 L F
0 0 .476 r
.51419 .74183 m .51481 .74449 L .51422 .7454 L F
.51402 .74458 m .51422 .7454 L .51394 .74583 L F
.51419 .74183 m .51422 .7454 L .51402 .74458 L F
.775 .55 .594 r
.51312 .74092 m .51658 .74095 L .51312 .74064 L F
.5131 .74298 m .51356 .74271 L .51312 .74092 L F
0 0 0 r
.51877 .73899 m .51661 .74066 L .51658 .74095 L F
.776 .677 .754 r
.7177 .60027 m .71917 .60343 L .721 .60057 L F
.579 .32 .488 r
.65694 .53162 m .65473 .53336 L .65471 .53171 L F
.73 .748 .866 r
.56152 .69756 m .5636 .69875 L .56366 .6964 L F
.709 .371 .403 r
.56087 .701 m .56312 .70167 L .5636 .69875 L F
.878 .889 .836 r
.56366 .6964 m .5636 .69875 L .56492 .69715 L F
.753 .414 .409 r
.5636 .69875 m .56312 .70167 L .56563 .70157 L F
.458 .289 .563 r
.56886 .77351 m .56695 .77403 L .56885 .77109 L F
.431 .222 .492 r
.56886 .77351 m .5667 .77635 L .56695 .77403 L F
.458 .289 .563 r
.56885 .77109 m .56695 .77403 L .56886 .77351 L F
.431 .222 .492 r
.56695 .77403 m .5667 .77635 L .56886 .77351 L F
.458 .289 .563 r
.56886 .77351 m .56695 .77403 L .56885 .77109 L F
.548 .576 .834 r
.43797 .66232 m .43659 .66505 L .43498 .66119 L F
.48 .493 .793 r
.43797 .66232 m .43916 .66515 L .43659 .66505 L F
.553 .343 .55 r
.71246 .71893 m .71247 .72115 L .71504 .72031 L F
.588 .61 .841 r
.43034 .77939 m .43256 .77904 L .43112 .77604 L F
.272 0 0 r
.46072 .78726 m .46161 .78833 L .45943 .78755 L F
.46072 .78726 m .46295 .78702 L .46161 .78833 L F
.076 0 .096 r
.36932 .67636 m .3678 .67752 L .37025 .6749 L F
.332 0 .23 r
.37228 .67439 m .36932 .67636 L .37025 .6749 L F
.141 0 0 r
.46295 .78702 m .46656 .78671 L .46517 .78699 L F
.208 0 0 r
.46656 .78671 m .46878 .78683 L .46517 .78699 L F
.87 .891 .847 r
.56366 .6964 m .56492 .69715 L .56689 .69495 L F
0 .474 .739 r
.38882 .64807 m .39237 .64893 L .38969 .64821 L F
.875 .679 .634 r
.61559 .68835 m .61457 .69083 L .61714 .69142 L F
.835 .628 .623 r
.61457 .69083 m .61727 .69363 L .61714 .69142 L F
0 0 .167 r
.52633 .71232 m .52701 .71594 L .5266 .71399 L F
0 0 .078 r
.61919 .72921 m .61878 .73166 L .61809 .73264 L F
0 0 .291 r
.61878 .73166 m .61904 .73396 L .61809 .73264 L F
0 .045 .57 r
.61904 .73396 m .61878 .73512 L .61809 .73264 L F
.302 0 0 r
.49437 .7859 m .49111 .78722 L .49347 .78708 L F
.627 .158 .12 r
.49347 .78708 m .49674 .78717 L .49437 .7859 L F
.497 .549 .839 r
.72518 .72408 m .72622 .72114 L .72407 .72271 L F
.72518 .72408 m .72724 .72395 L .72622 .72114 L F
0 0 0 r
.55501 .74651 m .55302 .74964 L .55386 .74848 L F
.375 0 .135 r
.55501 .74651 m .55659 .74776 L .55751 .74635 L F
.55501 .74651 m .55386 .74848 L .55659 .74776 L F
.612 .61 .825 r
.36703 .70228 m .36491 .70281 L .36358 .69996 L F
.55 .11 .157 r
.54588 .74395 m .54475 .74547 L .54281 .7454 L F
.385 .46 .815 r
.74576 .59781 m .74684 .60063 L .74715 .59753 L F
.946 .595 .306 r
.74932 .60018 m .74715 .59753 L .74684 .60063 L F
.489 .33 .592 r
.52589 .75743 m .52801 .75943 L .5283 .75722 L F
.52589 .75743 m .52601 .76003 L .52801 .75943 L F
.52589 .75743 m .52801 .75943 L .5283 .75722 L F
.52589 .75743 m .52601 .76003 L .52801 .75943 L F
.423 .059 .241 r
.51519 .7217 m .51401 .7236 L .51208 .72414 L F
.704 .373 .413 r
.51519 .7217 m .51747 .72378 L .51401 .7236 L F
.629 .397 .547 r
.5173 .72178 m .51747 .72378 L .51519 .7217 L F
0 0 0 r
.6278 .52616 m .62851 .52476 L .62913 .52281 L F
.527 .011 0 r
.6278 .52616 m .62875 .52718 L .62851 .52476 L F
.265 .545 .924 r
.58896 .75744 m .58965 .75696 L .5853 .75511 L F
.436 .872 .798 r
.58896 .75744 m .58956 .75687 L .58965 .75696 L F
.872 .429 .094 r
.59112 .75805 m .58956 .75687 L .5894 .75757 L F
.59112 .75805 m .59047 .7588 L .58956 .75687 L F
0 0 .453 r
.58956 .75687 m .59047 .7588 L .58967 .75642 L F
.58956 .75687 m .58967 .75642 L .58938 .75555 L F
.872 .429 .094 r
.5894 .75757 m .58956 .75687 L .58896 .75744 L F
.235 .002 .343 r
.75469 .6112 m .75423 .61312 L .7519 .6138 L F
.19 0 .224 r
.75423 .61312 m .75184 .61575 L .7519 .6138 L F
.311 0 0 r
.5853 .75511 m .58762 .75622 L .5842 .75432 L F
.5853 .75511 m .58965 .75696 L .58762 .75622 L F
.331 .027 .29 r
.36903 .67917 m .3678 .67752 L .36932 .67636 L F
.36903 .67917 m .36709 .68 L .3678 .67752 L F
.501 .657 .93 r
.54507 .75645 m .5457 .75785 L .54724 .75635 L F
.348 .402 .776 r
.5457 .75785 m .54837 .75959 L .54724 .75635 L F
.384 .4 .754 r
.5467 .75989 m .54837 .75959 L .5457 .75785 L F
.687 .809 .94 r
.37371 .70399 m .37052 .70421 L .37261 .70334 L F
.547 .817 .996 r
.37568 .70341 m .37371 .70399 L .37261 .70334 L F
.55 .429 .668 r
.32933 .69926 m .33097 .6963 L .32927 .69681 L F
.562 .582 .832 r
.73182 .71579 m .73288 .71233 L .73097 .7136 L F
.73182 .71579 m .73427 .7157 L .73288 .71233 L F
.313 .016 .29 r
.29659 .62573 m .29592 .62735 L .29841 .62489 L F
.424 .321 .634 r
.31339 .7301 m .3153 .7299 L .31544 .72642 L F
.914 .969 .669 r
.60221 .71034 m .60177 .70971 L .60326 .70735 L F
.877 .479 .022 r
.60221 .71034 m .60215 .71152 L .60177 .70971 L F
.60221 .71034 m .6031 .71263 L .60215 .71152 L F
.194 0 .045 r
.56027 .74276 m .55915 .74459 L .56171 .74302 L F
.706 .619 .757 r
.32591 .72127 m .32216 .7189 L .32478 .71875 L F
.823 .783 .815 r
.3278 .71881 m .32591 .72127 L .32478 .71875 L F
.792 .661 .718 r
.51418 .73205 m .51759 .73266 L .51675 .72963 L F
.759 .365 .308 r
.51635 .73434 m .51759 .73266 L .51418 .73205 L F
.205 .162 .585 r
.51759 .73266 m .5187 .7292 L .51675 .72963 L F
.51759 .73266 m .51906 .73186 L .5187 .7292 L F
.631 .419 .577 r
.51635 .73434 m .51906 .73186 L .51759 .73266 L F
.565 .78 .98 r
.28439 .60238 m .28582 .60354 L .28767 .60297 L F
.228 0 0 r
.57891 .67233 m .57992 .67324 L .58109 .67167 L F
.57891 .67233 m .57772 .67371 L .57992 .67324 L F
.828 .952 .899 r
.57079 .68152 m .57013 .68366 L .57186 .68249 L F
.57079 .68152 m .56914 .68298 L .57013 .68366 L F
.53 0 0 r
.45189 .78607 m .45045 .78673 L .44837 .78611 L F
.515 .036 .056 r
.45405 .7862 m .45045 .78673 L .45189 .78607 L F
.647 .537 .716 r
.53832 .73504 m .54118 .73854 L .54018 .73476 L F
.654 .385 .501 r
.72187 .58314 m .71986 .58062 L .71877 .58261 L F
.72187 .58314 m .72118 .58112 L .71986 .58062 L F
.465 .72 .979 r
.29693 .60724 m .29846 .60861 L .29901 .60711 L F
.319 .555 .92 r
.29846 .60861 m .29992 .60844 L .29901 .60711 L F
.72 .824 .93 r
.31846 .72376 m .32204 .72272 L .32054 .72168 L F
.897 .768 .711 r
.6199 .70467 m .61911 .70731 L .62081 .70781 L F
.966 .702 .48 r
.61911 .70731 m .62043 .71025 L .62081 .70781 L F
.248 .656 .963 r
.40897 .65157 m .40848 .65236 L .40734 .6511 L F
.40897 .65157 m .4103 .65249 L .40848 .65236 L F
.099 .116 .59 r
.58006 .74644 m .58138 .74542 L .58004 .74333 L F
.132 .152 .614 r
.58006 .74644 m .58215 .74777 L .58138 .74542 L F
.58006 .74644 m .58081 .74915 L .58215 .74777 L F
.941 .643 .446 r
.54536 .70237 m .54403 .7023 L .54327 .69929 L F
.878 .443 .07 r
.55048 .70735 m .54775 .7042 L .54861 .70541 L F
.852 .903 .87 r
.54837 .70406 m .54861 .70541 L .54716 .70354 L F
0 .348 .692 r
.54837 .70406 m .54703 .70352 L .54648 .703 L F
.852 .903 .87 r
.54837 .70406 m .54716 .70354 L .54708 .70343 L F
0 .348 .692 r
.54837 .70406 m .5467 .70333 L .54668 .70332 L F
.54703 .70352 m .54403 .7023 L .54648 .703 L F
.878 .443 .07 r
.54775 .7042 m .54748 .70395 L .54861 .70541 L F
.734 .207 0 r
.55197 .70797 m .55048 .70735 L .54861 .70541 L F
.878 .443 .07 r
.55048 .70735 m .54931 .7067 L .54715 .70352 L F
.54775 .7042 m .54708 .70343 L .54748 .70395 L F
.916 .875 .781 r
.54708 .70343 m .5467 .70333 L .54837 .70406 L F
.878 .443 .07 r
.54718 .70354 m .54715 .70352 L .54708 .70343 L F
.55048 .70735 m .54715 .70352 L .54718 .70354 L F
.901 .552 .372 r
.54709 .7035 m .54931 .7067 L .54731 .70588 L F
.54708 .70343 m .54715 .70352 L .54709 .7035 L F
.54715 .70352 m .54931 .7067 L .54709 .7035 L F
0 .348 .692 r
.5481 .70395 m .54677 .70336 L .54403 .7023 L F
.54677 .70336 m .54668 .70332 L .54664 .70331 L F
.54677 .70336 m .54664 .70331 L .54403 .7023 L F
.54837 .70406 m .54745 .70366 L .5481 .70395 L F
.54745 .70366 m .54668 .70332 L .5481 .70395 L F
.54648 .703 m .54403 .7023 L .54536 .70237 L F
.544 .356 .576 r
.55842 .75393 m .55622 .75443 L .55612 .75191 L F
.415 .202 .479 r
.43349 .75459 m .43538 .75418 L .43567 .75188 L F
.538 .427 .676 r
.43364 .75695 m .43538 .75418 L .43349 .75459 L F
.789 .591 .633 r
.61164 .6802 m .613 .68304 L .61311 .6805 L F
0 0 0 r
.5569 .6952 m .55761 .69442 L .55578 .69322 L F
.871 .861 .411 r
.58705 .72879 m .58616 .73191 L .5862 .73275 L F
.777 .278 0 r
.58616 .73191 m .58869 .73448 L .5862 .73275 L F
.601 .196 .247 r
.47531 .77973 m .47746 .78111 L .48108 .77887 L F
.543 .185 .31 r
.47746 .78111 m .48119 .77839 L .48108 .77887 L F
.671 .508 .655 r
.52895 .73267 m .52741 .73581 L .52647 .73308 L F
.084 0 0 r
.59499 .76108 m .59779 .75998 L .59674 .761 L F
.59499 .76108 m .59674 .761 L .59447 .75984 L F
.303 0 .15 r
.49928 .79252 m .50174 .79058 L .50145 .79277 L F
.792 .682 .743 r
.50174 .79058 m .50043 .7868 L .50016 .78988 L F
.446 .805 .996 r
.50372 .79023 m .50174 .79058 L .50016 .78988 L F
.445 .703 .976 r
.28392 .59145 m .28334 .59289 L .2819 .59199 L F
.28392 .59145 m .28557 .5929 L .28334 .59289 L F
.468 .818 .998 r
.49763 .74935 m .49917 .74932 L .50128 .7495 L F
.965 .691 .464 r
.50128 .7495 m .49732 .75099 L .49763 .74935 L F
.50128 .7495 m .49969 .75072 L .49732 .75099 L F
.50128 .7495 m .50093 .75141 L .49969 .75072 L F
.762 .456 .468 r
.50435 .75163 m .50093 .75141 L .50128 .7495 L F
.527 .411 .664 r
.36062 .68507 m .3611 .68973 L .35859 .68914 L F
.559 .452 .688 r
.3611 .68973 m .35905 .69128 L .35859 .68914 L F
.905 .806 .74 r
.62634 .53205 m .62723 .53496 L .6259 .53753 L F
.163 .702 .755 r
.37787 .70328 m .38005 .70292 L .38205 .70271 L F
.192 .723 .77 r
.38205 .70271 m .38205 .70253 L .38401 .70199 L F
.38205 .70271 m .38005 .70292 L .38205 .70253 L F
.49 .509 .804 r
.43382 .65786 m .43309 .66131 L .43185 .65805 L F
.43382 .65786 m .43498 .66119 L .43309 .66131 L F
.585 .357 .537 r
.49017 .72885 m .49258 .72664 L .49065 .72732 L F
.055 .243 .739 r
.48963 .75626 m .49123 .76009 L .48907 .75735 L F
.597 .429 .625 r
.48907 .75735 m .49123 .76009 L .48879 .76027 L F
0 0 .04 r
.31288 .7233 m .31095 .72648 L .31143 .72443 L F
.142 0 0 r
.29299 .59363 m .29203 .59343 L .29124 .59315 L F
.29299 .59363 m .29499 .594 L .29203 .59343 L F
.372 .06 .3 r
.29108 .63058 m .29303 .63005 L .29391 .62781 L F
.424 .109 .325 r
.29391 .62781 m .29526 .6295 L .29592 .62735 L F
.29391 .62781 m .29303 .63005 L .29526 .6295 L F
0 0 0 r
.72137 .58661 m .72072 .58671 L .72352 .58357 L F
.713 .419 0 r
.52566 .79292 m .52615 .79283 L .52503 .79149 L F
.369 .074 .327 r
.52485 .7952 m .52687 .79269 L .52615 .79283 L F
.52485 .7952 m .52615 .79283 L .52672 .79479 L F
.987 .785 .546 r
.52672 .79479 m .52427 .79603 L .52485 .7952 L F
.52672 .79479 m .52698 .79598 L .52626 .79722 L F
.52698 .79598 m .52738 .79777 L .52626 .79722 L F
.52626 .79722 m .52738 .79777 L .52672 .79479 L F
.661 .55 .718 r
.52748 .79597 m .5252 .79904 L .52626 .79722 L F
.5252 .79904 m .52519 .79905 L .52626 .79722 L F
.987 .785 .546 r
.52672 .79479 m .52626 .79722 L .52427 .79603 L F
0 0 .01 r
.52631 .79696 m .52672 .79479 L .52689 .79563 L F
.588 .02 0 r
.52276 .79618 m .52427 .79603 L .52557 .7968 L F
.52538 .79696 m .52557 .7968 L .52626 .79722 L F
.52276 .79618 m .52557 .7968 L .52538 .79696 L F
.818 .496 .445 r
.52626 .79722 m .52519 .79905 L .52276 .79618 L F
0 0 0 r
.52676 .79638 m .52653 .79638 L .52473 .79749 L F
.79 .505 .506 r
.52276 .79618 m .52519 .79905 L .52182 .7987 L F
0 0 0 r
.52453 .79764 m .52473 .79749 L .52368 .79813 L F
.52676 .79638 m .52473 .79749 L .52453 .79764 L F
0 0 .01 r
.52626 .79722 m .52669 .79637 L .52748 .79597 L F
0 0 0 r
.52748 .79597 m .52657 .79636 L .52669 .79637 L F
.333 .56 .92 r
.52692 .79558 m .52657 .79636 L .52748 .79597 L F
0 0 .01 r
.52669 .79637 m .52694 .79587 L .52748 .79597 L F
0 0 0 r
.52748 .79597 m .52669 .79637 L .52676 .79638 L F
0 0 .01 r
.52677 .79617 m .52689 .79563 L .52694 .79587 L F
.52631 .79696 m .52677 .79591 L .52677 .79617 L F
.52677 .79591 m .52689 .79563 L .52677 .79617 L F
0 0 0 r
.52676 .79685 m .52368 .79813 L .52591 .79788 L F
.52748 .79597 m .52676 .79638 L .52676 .79685 L F
0 0 .01 r
.52626 .79722 m .52631 .79696 L .52665 .79637 L F
.52626 .79722 m .52665 .79637 L .52669 .79637 L F
0 0 0 r
.52676 .79638 m .52368 .79813 L .52676 .79685 L F
.52657 .79636 m .52653 .79638 L .52676 .79638 L F
0 0 .01 r
.52669 .79637 m .52665 .79637 L .52694 .79587 L F
.333 .56 .92 r
.52371 .79336 m .52653 .79638 L .52657 .79636 L F
.52371 .79336 m .52657 .79636 L .52692 .79558 L F
.52371 .79336 m .52686 .79554 L .52694 .79587 L F
.52686 .79554 m .52748 .79597 L .52694 .79587 L F
.713 .419 0 r
.52694 .79587 m .52672 .79479 L .52655 .7942 L F
.52694 .79587 m .52655 .7942 L .52615 .79283 L F
.52694 .79587 m .52615 .79283 L .52566 .79292 L F
.369 .074 .327 r
.52687 .79269 m .52707 .79244 L .52615 .79283 L F
.79 .94 .588 r
.62098 .71578 m .61927 .7182 L .62066 .71654 L F
.459 .149 .351 r
.34279 .65858 m .34072 .65874 L .33959 .66125 L F
.538 .688 .936 r
.31879 .85692 m .31872 .85965 L .31694 .85952 L F
.31879 .85692 m .32099 .85941 L .31872 .85965 L F
.217 .735 .861 r
.32099 .85941 m .31694 .85952 L .31872 .85965 L F
.808 .553 .553 r
.60503 .6739 m .60846 .67681 L .60813 .67483 L F
.28 .005 .305 r
.30798 .63918 m .31035 .63656 L .30954 .63833 L F
.414 .173 .438 r
.31035 .63656 m .31278 .63385 L .31195 .63572 L F
.196 0 .225 r
.30954 .63833 m .31035 .63656 L .31195 .63572 L F
.248 0 .238 r
.30325 .64452 m .30579 .64202 L .30499 .64382 L F
.198 0 .281 r
.30579 .64202 m .30798 .63918 L .30728 .64116 L F
.135 0 .177 r
.30499 .64382 m .30579 .64202 L .30728 .64116 L F
.205 .686 .932 r
.27075 .58983 m .2728 .58992 L .27438 .59046 L F
.167 .706 .786 r
.27486 .59024 m .27438 .59046 L .2728 .58992 L F
.27486 .59024 m .27535 .59029 L .27438 .59046 L F
.695 .639 .789 r
.71821 .72124 m .71931 .72437 L .72152 .72301 L F
.413 0 0 r
.2711 .60445 m .26982 .60546 L .26736 .6054 L F
.087 .607 .88 r
.27435 .60508 m .27292 .6045 L .2711 .60445 L F
.179 0 0 r
.27292 .6045 m .26982 .60546 L .2711 .60445 L F
.713 .882 .959 r
.42475 .66427 m .42312 .66588 L .42627 .66516 L F
.751 .651 .75 r
.42475 .66427 m .42392 .66532 L .42312 .66588 L F
.585 .694 .917 r
.42357 .66968 m .42312 .66588 L .42197 .66669 L F
.42357 .66968 m .42557 .66905 L .42312 .66588 L F
.562 .684 .921 r
.42312 .66588 m .42557 .66905 L .42717 .66814 L F
.42312 .66588 m .42717 .66814 L .42627 .66516 L F
.751 .651 .75 r
.42392 .66532 m .42254 .66707 L .42312 .66588 L F
.585 .694 .917 r
.42197 .66669 m .42312 .66588 L .42162 .66604 L F
0 0 .068 r
.42357 .66968 m .42439 .67001 L .42557 .66905 L F
.42357 .66968 m .4229 .67136 L .42439 .67001 L F
.402 0 0 r
.58493 .71345 m .58158 .713 L .58382 .7125 L F
.58493 .71345 m .58053 .71428 L .58158 .713 L F
.766 .301 .142 r
.58493 .71345 m .58714 .71569 L .58378 .71496 L F
.629 .483 .666 r
.58336 .71464 m .58404 .71711 L .58509 .71596 L F
.766 .301 .142 r
.58356 .71479 m .58378 .71496 L .58347 .71489 L F
.58493 .71345 m .58378 .71496 L .58356 .71479 L F
.402 0 0 r
.58068 .71426 m .58357 .71477 L .58053 .71428 L F
.58471 .71349 m .58371 .71461 L .58068 .71426 L F
.58371 .71461 m .58357 .71477 L .58068 .71426 L F
.58479 .71359 m .58347 .71489 L .58471 .71349 L F
.629 .483 .666 r
.58324 .71421 m .5854 .71482 L .58495 .7138 L F
.5854 .71482 m .58599 .71498 L .5859 .71488 L F
.5854 .71482 m .5859 .71488 L .58495 .7138 L F
.402 0 0 r
.58357 .71477 m .58348 .71478 L .58053 .71428 L F
.58349 .71478 m .58295 .71478 L .58053 .71428 L F
.58355 .71479 m .5834 .71479 L .58349 .71478 L F
.5834 .71479 m .58295 .71478 L .58349 .71478 L F
.538 .491 .752 r
.58053 .71428 m .58242 .71879 L .57932 .7164 L F
.339 .378 .755 r
.58404 .71711 m .58242 .71879 L .58053 .71428 L F
.58404 .71711 m .58053 .71428 L .58312 .71482 L F
.728 .542 .64 r
.5834 .71479 m .58318 .71496 L .58404 .71711 L F
.5826 .71487 m .58045 .7171 L .5834 .71479 L F
.73 .56 .662 r
.58314 .71482 m .58404 .71711 L .5834 .71479 L F
.339 .378 .755 r
.58404 .71711 m .58312 .71482 L .58314 .71482 L F
.728 .542 .64 r
.58318 .71496 m .58045 .7171 L .58404 .71711 L F
.73 .56 .662 r
.58133 .71506 m .58404 .71711 L .58314 .71482 L F
.339 .378 .755 r
.58404 .71711 m .58314 .71482 L .58347 .71489 L F
.728 .542 .64 r
.58324 .71421 m .5826 .71487 L .5834 .71479 L F
.73 .56 .662 r
.58087 .71471 m .58133 .71506 L .58324 .71421 L F
.58133 .71506 m .5834 .71479 L .58324 .71421 L F
.402 0 0 r
.58357 .71477 m .58355 .71479 L .58348 .71478 L F
.58355 .71479 m .58347 .71489 L .58295 .71478 L F
.629 .483 .666 r
.58324 .71421 m .58336 .71464 L .58465 .71481 L F
.5854 .71482 m .58465 .71481 L .58599 .71498 L F
.58324 .71421 m .58465 .71481 L .5854 .71482 L F
.58336 .71464 m .58378 .71496 L .58599 .71498 L F
.664 .536 .698 r
.58599 .71498 m .58347 .71489 L .58378 .71496 L F
.58599 .71498 m .58378 .71496 L .58714 .71569 L F
.629 .483 .666 r
.58378 .71496 m .58509 .71596 L .58599 .71498 L F
.539 .059 0 r
.58495 .7138 m .5859 .71488 L .58382 .7125 L F
.5859 .71488 m .58599 .71498 L .58581 .71478 L F
.5859 .71488 m .58581 .71478 L .58382 .7125 L F
.402 0 0 r
.58493 .71345 m .58479 .71359 L .58471 .71349 L F
.634 .332 .442 r
.58382 .7125 m .58657 .71006 L .58493 .71345 L F
.521 .917 .837 r
.58124 .67755 m .58026 .67854 L .5822 .67788 L F
.58124 .67755 m .57873 .67881 L .58026 .67854 L F
.544 .25 .419 r
.63893 .53986 m .64131 .54093 L .6388 .54142 L F
.63893 .53986 m .6413 .53958 L .64131 .54093 L F
.915 .878 .785 r
.55027 .68824 m .5489 .69144 L .54761 .69049 L F
.978 .918 .615 r
.5489 .69144 m .5474 .69289 L .54761 .69049 L F
.5489 .69144 m .54726 .69413 L .5474 .69289 L F
.394 .201 .496 r
.31278 .63385 m .31468 .63087 L .31412 .6329 L F
.044 0 .148 r
.31412 .6329 m .31195 .63572 L .31278 .63385 L F
.818 .652 .677 r
.61727 .69363 m .61874 .69673 L .61936 .69454 L F
.53 .11 .189 r
.7162 .58509 m .7139 .5842 L .71496 .58712 L F
.557 .668 .911 r
.71496 .58712 m .71741 .587 L .7162 .58509 L F
.143 0 0 r
.46631 .77846 m .46966 .77913 L .46752 .7787 L F
.167 .7 .703 r
.32798 .71091 m .3309 .71025 L .33011 .71097 L F
.32798 .71091 m .32867 .71075 L .3309 .71025 L F
.631 .528 .718 r
.33216 .71514 m .32798 .71091 L .33011 .71097 L F
.33216 .71514 m .33013 .71591 L .32798 .71091 L F
.684 .259 .231 r
.54285 .72159 m .54553 .72364 L .54652 .72218 L F
.714 .295 .25 r
.54553 .72364 m .54877 .72413 L .54652 .72218 L F
.458 .099 .269 r
.26345 .60628 m .26228 .6078 L .2603 .60832 L F
.455 .162 .377 r
.26529 .60542 m .26228 .6078 L .26345 .60628 L F
.242 0 .303 r
.30728 .64116 m .30798 .63918 L .30954 .63833 L F
.923 .576 .362 r
.55197 .70797 m .551 .70954 L .55048 .70735 L F
.695 .261 .216 r
.55197 .70797 m .55441 .70991 L .551 .70954 L F
.702 .216 .089 r
.55524 .70976 m .55441 .70991 L .55197 .70797 L F
.9 .682 .598 r
.62852 .53971 m .62662 .54156 L .62683 .53893 L F
.62852 .53971 m .62832 .54207 L .62662 .54156 L F
.416 .794 .992 r
.7356 .70873 m .73279 .70839 L .73514 .70804 L F
.48 .687 .958 r
.73717 .70723 m .7356 .70873 L .73514 .70804 L F
.73717 .70723 m .73884 .70854 L .7356 .70873 L F
.647 .129 0 r
.53346 .74998 m .53204 .74867 L .53239 .74975 L F
0 .37 .83 r
.57982 .69986 m .58223 .70132 L .58257 .70233 L F
.926 .953 .624 r
.58257 .70233 m .58207 .70218 L .58223 .70132 L F
.873 .87 .831 r
.3211 .71331 m .3189 .71609 L .31743 .71534 L F
.926 .547 .261 r
.31957 .71807 m .31743 .71534 L .3189 .71609 L F
.534 .424 .675 r
.33615 .66383 m .33815 .66335 L .33778 .66136 L F
.513 .353 .601 r
.33615 .66383 m .33821 .66576 L .33815 .66335 L F
.49 .353 .621 r
.33615 .66383 m .3363 .66623 L .33821 .66576 L F
.527 .468 .733 r
.3621 .69432 m .36055 .6965 L .36017 .69493 L F
.3621 .69432 m .36261 .69617 L .36055 .6965 L F
.842 .454 .312 r
.62209 .69942 m .62247 .69957 L .61874 .69673 L F
.287 0 .286 r
.30254 .64645 m .30075 .64705 L .30325 .64452 L F
.267 0 .276 r
.30254 .64645 m .30325 .64452 L .30499 .64382 L F
.555 .312 .501 r
.4573 .76037 m .4572 .76246 L .45493 .76265 L F
.556 .292 .472 r
.46031 .75965 m .4572 .76246 L .4573 .76037 L F
.766 .671 .758 r
.32117 .72949 m .32255 .73263 L .32471 .72982 L F
.867 .529 .409 r
.59557 .72606 m .59424 .72793 L .59431 .72767 L F
0 .206 .733 r
.59354 .72293 m .59557 .72606 L .59516 .72446 L F
.867 .529 .409 r
.59557 .72606 m .59431 .72767 L .59516 .72446 L F
.871 .751 .728 r
.59647 .7249 m .59557 .72606 L .59505 .72534 L F
.59866 .72422 m .59557 .72606 L .59647 .7249 L F
.534 .312 .525 r
.42657 .6828 m .42705 .68525 L .42432 .68508 L F
.551 .324 .524 r
.42886 .68449 m .42657 .6828 L .42876 .68256 L F
.42886 .68449 m .42705 .68525 L .42657 .6828 L F
.513 .129 .249 r
.49235 .75594 m .49081 .75427 L .49309 .75417 L F
.49235 .75594 m .48963 .75626 L .49081 .75427 L F
.164 0 0 r
.27413 .6557 m .2737 .65653 L .27043 .65644 L F
.856 .65 .113 r
.27366 .65566 m .27413 .6557 L .27619 .65538 L F
.27366 .65566 m .2737 .65653 L .27413 .6557 L F
.389 0 0 r
.419 .66304 m .41509 .6637 L .41629 .66316 L F
.744 .87 .938 r
.73949 .72897 m .74356 .72788 L .7423 .72691 L F
.858 .901 .863 r
.7423 .72691 m .74356 .72788 L .74475 .72644 L F
.315 0 0 r
.38618 .71244 m .3826 .71441 L .38412 .713 L F
.501 0 0 r
.72785 .5852 m .72844 .58444 L .72532 .58408 L F
.34 0 0 r
.73141 .58488 m .72844 .58444 L .72785 .5852 L F
0 0 .305 r
.61956 .72142 m .61971 .72328 L .61873 .72431 L F
.957 .638 .229 r
.619 .72248 m .6198 .72446 L .61971 .72328 L F
.087 0 .447 r
.62028 .72564 m .61873 .72431 L .61971 .72328 L F
.957 .638 .229 r
.6198 .72446 m .62028 .72564 L .61971 .72328 L F
0 0 .305 r
.61973 .72084 m .61971 .72328 L .61956 .72142 L F
.087 0 .447 r
.62028 .72564 m .61874 .72683 L .61873 .72431 L F
.674 .564 .723 r
.45493 .76265 m .45285 .76516 L .45265 .76315 L F
.637 .51 .692 r
.45493 .76265 m .45533 .76624 L .45285 .76516 L F
.68 .53 .675 r
.45611 .76807 m .45285 .76516 L .45533 .76624 L F
.45611 .76807 m .45369 .76837 L .45285 .76516 L F
.424 .218 .494 r
.39694 .69312 m .39872 .69346 L .39881 .69099 L F
.537 .279 .471 r
.39617 .69591 m .39872 .69346 L .39694 .69312 L F
.665 .464 .603 r
.44194 .74085 m .44468 .74286 L .4446 .74091 L F
.44194 .74085 m .44206 .74328 L .44468 .74286 L F
.944 .645 .441 r
.31735 .72485 m .31684 .72612 L .31841 .7267 L F
.27 .152 .528 r
.31544 .72642 m .31796 .72419 L .31513 .72664 L F
.31796 .72419 m .31801 .72415 L .31513 .72664 L F
.31796 .72419 m .31846 .72376 L .31801 .72415 L F
.31544 .72642 m .31656 .72347 L .31846 .72376 L F
.944 .645 .441 r
.31656 .72347 m .31677 .72546 L .31735 .72485 L F
.31677 .72546 m .31684 .72612 L .31735 .72485 L F
.31656 .72347 m .31841 .7267 L .31846 .72376 L F
.377 .044 .268 r
.30075 .64705 m .29984 .64946 L .29777 .65006 L F
.313 0 .239 r
.30181 .64871 m .30075 .64705 L .30254 .64645 L F
.30181 .64871 m .29984 .64946 L .30075 .64705 L F
.604 .341 .491 r
.63348 .5429 m .63612 .54475 L .63348 .54462 L F
.63348 .5429 m .6366 .54171 L .63612 .54475 L F
.393 .672 .972 r
.59068 .73453 m .58979 .73575 L .58869 .73448 L F
.413 .7 .98 r
.59068 .73453 m .5921 .73596 L .58979 .73575 L F
.574 .5 .733 r
.32804 .88994 m .32805 .89237 L .3258 .89224 L F
.3258 .89224 m .32805 .89237 L .32804 .88994 L F
.32804 .88994 m .32805 .89237 L .3258 .89224 L F
.477 .855 .983 r
.54507 .75645 m .54151 .75652 L .54295 .75702 L F
.428 .838 .971 r
.26803 .64542 m .26988 .64494 L .27198 .64541 L F
.295 .787 .885 r
.26988 .64494 m .27406 .64466 L .27198 .64541 L F
.513 .755 .983 r
.64667 .51634 m .64548 .51782 L .64453 .51539 L F
.64667 .51634 m .64767 .51747 L .64548 .51782 L F
.608 .587 .804 r
.64893 .52021 m .64548 .51782 L .64767 .51747 L F
.519 0 0 r
.47636 .78947 m .47771 .78845 L .4799 .78948 L F
0 0 .556 r
.73037 .61933 m .73184 .6219 L .73117 .62263 L F
.806 .761 .811 r
.72808 .62269 m .73117 .62263 L .73144 .62245 L F
0 .233 .75 r
.73117 .62263 m .73383 .6252 L .73184 .6219 L F
.203 .399 .833 r
.73184 .6219 m .73383 .6252 L .73176 .62282 L F
0 .233 .75 r
.73172 .6232 m .73184 .6219 L .73258 .62406 L F
.73117 .62263 m .73184 .6219 L .73172 .6232 L F
.203 .399 .833 r
.73184 .6219 m .73176 .62282 L .73144 .62245 L F
0 0 0 r
.73117 .62263 m .73144 .62245 L .73184 .6219 L F
0 .233 .75 r
.73117 .62263 m .73258 .62406 L .73154 .62507 L F
0 0 0 r
.73184 .6219 m .73144 .62245 L .73117 .62263 L F
.526 0 0 r
.55429 .72879 m .55609 .73008 L .55668 .73011 L F
.848 .975 .67 r
.74495 .62394 m .74296 .62698 L .74325 .62733 L F
.948 .688 .509 r
.62043 .71025 m .62048 .71276 L .62178 .71322 L F
.993 .861 .599 r
.62033 .71486 m .62178 .71322 L .62048 .71276 L F
.62033 .71486 m .62098 .71578 L .62178 .71322 L F
.232 0 0 r
.39185 .70985 m .39462 .70857 L .39389 .70932 L F
.26 0 0 r
.39389 .70932 m .39462 .70857 L .39686 .70809 L F
.035 0 0 r
.34737 .65752 m .34861 .65563 L .34593 .65776 L F
.267 0 0 r
.34909 .65659 m .34861 .65563 L .34737 .65752 L F
.34909 .65659 m .35083 .65544 L .34861 .65563 L F
.368 0 .054 r
.57901 .71444 m .58158 .713 L .57931 .71555 L F
0 0 0 r
.58053 .71428 m .57931 .71555 L .58158 .713 L F
.538 .491 .752 r
.58053 .71428 m .57932 .7164 L .57931 .71555 L F
.951 .6 .236 r
.29842 .7431 m .29781 .7435 L .2969 .74053 L F
.428 .821 .598 r
.29941 .74236 m .29781 .7435 L .29842 .7431 L F
.942 .919 .762 r
.72555 .586 m .72647 .58669 L .72479 .58936 L F
.501 0 0 r
.72785 .5852 m .72532 .58408 L .72647 .58669 L F
.59 .876 .993 r
.72785 .5852 m .72647 .58669 L .72555 .586 L F
.525 .243 .428 r
.6366 .54171 m .63838 .54413 L .63612 .54475 L F
.6366 .54171 m .6388 .54142 L .63838 .54413 L F
.516 .382 .636 r
.33047 .67764 m .33257 .67722 L .33233 .67425 L F
.576 .469 .695 r
.33075 .68008 m .33257 .67722 L .33047 .67764 L F
.475 .32 .59 r
.28913 .63318 m .29095 .63268 L .29108 .63058 L F
.144 0 .091 r
.28913 .63318 m .28989 .63439 L .29095 .63268 L F
.28913 .63318 m .28809 .63527 L .28989 .63439 L F
.692 .49 .609 r
.4651 .75723 m .46262 .75977 L .46265 .75735 L F
.112 0 0 r
.38063 .67004 m .38019 .66905 L .38236 .66834 L F
.38063 .67004 m .37865 .67071 L .38019 .66905 L F
.548 .297 .487 r
.43887 .6747 m .43861 .67679 L .43635 .67706 L F
.598 .422 .615 r
.44115 .67202 m .4412 .67449 L .43887 .6747 L F
.516 .269 .48 r
.44074 .67637 m .43887 .6747 L .4412 .67449 L F
.44074 .67637 m .43861 .67679 L .43887 .6747 L F
.632 .812 .969 r
.32471 .72982 m .3216 .72953 L .32349 .72772 L F
.32349 .72772 m .32117 .72949 L .32283 .72658 L F
.3216 .72953 m .32117 .72949 L .32349 .72772 L F
.968 .682 .432 r
.32332 .72915 m .32471 .72982 L .32283 .72658 L F
.32332 .72915 m .32416 .72707 L .32555 .72677 L F
.32416 .72707 m .32478 .72554 L .32515 .72613 L F
.32416 .72707 m .32515 .72613 L .32555 .72677 L F
.766 .671 .758 r
.32117 .72949 m .32471 .72982 L .32332 .72915 L F
.873 .87 .831 r
.3211 .71331 m .31743 .71534 L .32053 .71334 L F
.827 .976 .677 r
.3211 .71331 m .32053 .71334 L .32319 .70939 L F
.527 0 0 r
.54118 .73854 m .54377 .73969 L .54469 .73933 L F
.632 .09 0 r
.54377 .73969 m .54644 .74052 L .54469 .73933 L F
.07 0 0 r
.28122 .64056 m .28419 .63883 L .28224 .63958 L F
.435 .219 .485 r
.43567 .75188 m .43538 .75418 L .4376 .75137 L F
.954 .835 .687 r
.60343 .67137 m .60496 .66974 L .60374 .66895 L F
.148 0 .336 r
.31468 .63087 m .3165 .62781 L .31643 .63018 L F
.343 .094 .384 r
.31412 .6329 m .31468 .63087 L .31643 .63018 L F
0 .163 .702 r
.36328 .86374 m .36297 .86473 L .36128 .86159 L F
0 .063 .626 r
.36461 .86685 m .36297 .86473 L .36328 .86374 L F
.488 .283 .527 r
.3626 .86737 m .36297 .86473 L .36461 .86685 L F
.516 .69 .947 r
.47431 .77805 m .47309 .77973 L .47181 .77865 L F
.47431 .77805 m .47531 .77973 L .47309 .77973 L F
.417 .825 .976 r
.73172 .72808 m .7332 .72734 L .73062 .72705 L F
.73172 .72808 m .73373 .72775 L .7332 .72734 L F
.648 .455 .608 r
.32295 .7242 m .32283 .72658 L .32204 .72272 L F
.32295 .7242 m .32283 .72658 L .32204 .72272 L F
.505 .389 .655 r
.3294 .68611 m .33143 .68582 L .33104 .68266 L F
.564 .513 .756 r
.33 .68846 m .33143 .68582 L .3294 .68611 L F
.89 .924 .837 r
.58949 .71231 m .59063 .71331 L .59283 .71049 L F
.276 .35 .759 r
.58949 .71231 m .59019 .7152 L .59063 .71331 L F
.745 .791 .89 r
.63953 .50854 m .64086 .50968 L .63753 .50937 L F
.81 .794 .838 r
.64279 .50695 m .64086 .50968 L .63953 .50854 L F
.739 .683 .797 r
.64288 .50793 m .64086 .50968 L .64279 .50695 L F
.29 .379 .781 r
.64325 .5114 m .64086 .50968 L .64288 .50793 L F
.596 .472 .681 r
.54602 .73488 m .54345 .73271 L .54588 .73256 L F
.54602 .73488 m .54373 .73553 L .54345 .73271 L F
.587 .381 .568 r
.44361 .67179 m .4412 .67449 L .44115 .67202 L F
.643 .404 .542 r
.64783 .5345 m .64904 .5363 L .64696 .53626 L F
.64783 .5345 m .64911 .53429 L .64904 .5363 L F
.502 .258 .477 r
.42432 .68508 m .42349 .68821 L .42135 .6886 L F
.544 .305 .504 r
.42705 .68525 m .42349 .68821 L .42432 .68508 L F
.463 0 0 r
.3606 .72383 m .3589 .72612 L .35725 .72585 L F
.3606 .72383 m .35725 .72585 L .35696 .72543 L F
.35696 .72543 m .35725 .72585 L .35635 .72569 L F
.495 .497 .787 r
.35635 .72569 m .3589 .72612 L .35772 .72496 L F
.229 0 0 r
.36128 .72486 m .3589 .72612 L .3606 .72383 L F
.769 .502 .531 r
.35772 .72496 m .3589 .72612 L .36128 .72486 L F
.35772 .72496 m .36128 .72486 L .36012 .72496 L F
0 0 .338 r
.35879 .72476 m .35772 .72496 L .36012 .72496 L F
.35879 .72476 m .35791 .72677 L .35772 .72496 L F
.35791 .72677 m .35703 .72879 L .3575 .72619 L F
.35791 .72677 m .3575 .72619 L .35772 .72496 L F
.139 0 0 r
.36278 .72312 m .36199 .72393 L .3606 .72383 L F
.229 0 0 r
.36128 .72486 m .3606 .72383 L .36199 .72393 L F
.382 .244 .566 r
.43223 .76284 m .43396 .76003 L .43182 .76072 L F
.725 .206 0 r
.56063 .71115 m .56057 .71187 L .55819 .70978 L F
.56063 .71115 m .56178 .71259 L .56057 .71187 L F
.462 .575 .882 r
.72844 .72692 m .73021 .72544 L .72724 .72395 L F
.72844 .72692 m .73062 .72705 L .73021 .72544 L F
.484 .048 .135 r
.58872 .66795 m .59105 .66798 L .58908 .66699 L F
.469 .088 .235 r
.58908 .66699 m .59105 .66798 L .59139 .66673 L F
.724 .287 .211 r
.46878 .78683 m .47211 .78756 L .47073 .78889 L F
.553 .011 0 r
.47211 .78756 m .47294 .78901 L .47073 .78889 L F
.47211 .78756 m .47431 .78866 L .47294 .78901 L F
.3 .552 .922 r
.56008 .73143 m .56039 .73267 L .55759 .73071 L F
0 .192 .659 r
.56209 .73366 m .56287 .73441 L .56039 .73267 L F
.741 .571 .663 r
.46848 .7711 m .46499 .76849 L .46654 .76827 L F
.46848 .7711 m .46555 .77151 L .46499 .76849 L F
.749 .576 .661 r
.46499 .76849 m .46555 .77151 L .46366 .77065 L F
.773 .36 .268 r
.46366 .77065 m .46555 .77151 L .46234 .77135 L F
.584 .89 .99 r
.46234 .77135 m .46848 .7711 L .46785 .77096 L F
.46234 .77135 m .46555 .77151 L .46848 .7711 L F
.895 .492 .07 r
.46654 .76827 m .46785 .77096 L .46848 .7711 L F
0 .453 .759 r
.72916 .59042 m .73146 .59089 L .72901 .59095 L F
.72916 .59042 m .73336 .59162 L .73146 .59089 L F
.794 .632 .68 r
.53346 .76079 m .52962 .76238 L .52937 .75969 L F
.53346 .76079 m .5329 .76291 L .52962 .76238 L F
.649 .481 .643 r
.53487 .76011 m .5329 .76291 L .53346 .76079 L F
0 0 0 r
.51877 .73899 m .5181 .73968 L .51661 .74066 L F
.779 .547 .584 r
.52111 .73913 m .5181 .73968 L .51877 .73899 L F
.41 .746 .993 r
.41751 .6542 m .4138 .65345 L .41596 .65317 L F
.351 .719 .986 r
.41818 .65332 m .41751 .6542 L .41596 .65317 L F
.41818 .65332 m .41949 .65423 L .41751 .6542 L F
.625 .453 .63 r
.52895 .73267 m .52843 .7357 L .52741 .73581 L F
.371 .221 .545 r
.53135 .73421 m .52895 .73267 L .53105 .73192 L F
.53135 .73421 m .52843 .7357 L .52895 .73267 L F
.564 .513 .756 r
.33 .68846 m .33205 .68802 L .33143 .68582 L F
.509 .414 .683 r
.33 .68846 m .33252 .69069 L .33205 .68802 L F
.33 .68846 m .33037 .69161 L .33252 .69069 L F
.535 .916 .934 r
.59903 .7589 m .59779 .75998 L .59957 .75899 L F
0 0 0 r
.59674 .761 m .59779 .75998 L .59903 .7589 L F
.765 .99 .768 r
.35012 .72734 m .35152 .72611 L .35131 .72606 L F
.434 .794 .996 r
.35498 .72672 m .35131 .72606 L .35152 .72611 L F
.461 .771 .997 r
.56885 .77109 m .57133 .77094 L .57006 .77 L F
.321 0 0 r
.51136 .79086 m .51275 .79045 L .50924 .79059 L F
.598 .306 .443 r
.51275 .79045 m .5149 .79237 L .51495 .79053 L F
.299 .312 .706 r
.51517 .79151 m .5149 .79237 L .51275 .79045 L F
.51648 .79208 m .5149 .79237 L .51517 .79151 L F
0 0 .171 r
.51495 .79053 m .5149 .79222 L .51529 .79112 L F
.5149 .79222 m .5149 .79237 L .51496 .79215 L F
.5149 .79222 m .51496 .79215 L .51529 .79112 L F
.299 .312 .706 r
.51529 .7918 m .51275 .79045 L .51136 .79086 L F
.51517 .79151 m .51275 .79045 L .51529 .7918 L F
.227 .615 .954 r
.51333 .79033 m .51552 .79155 L .51136 .79086 L F
.299 .312 .706 r
.51648 .79208 m .51517 .79151 L .51528 .79178 L F
.316 .603 .949 r
.51528 .79178 m .5149 .79237 L .51648 .79208 L F
.299 .312 .706 r
.51648 .79208 m .51528 .79178 L .51529 .7918 L F
.316 .603 .949 r
.51549 .79147 m .51528 .79178 L .51648 .79208 L F
.227 .615 .954 r
.51552 .79155 m .51648 .79208 L .51529 .7918 L F
0 0 .171 r
.51517 .79151 m .51528 .79178 L .51549 .79147 L F
.227 .615 .954 r
.51552 .79155 m .51529 .7918 L .51136 .79086 L F
0 0 .171 r
.51529 .79112 m .51517 .79151 L .51549 .79147 L F
.51517 .79151 m .5149 .79237 L .51528 .79178 L F
.609 .728 .93 r
.32722 .60039 m .32527 .60098 L .32387 .59936 L F
.496 .244 .462 r
.39881 .69099 m .40079 .6907 L .40162 .68836 L F
.578 .326 .499 r
.40162 .68836 m .40372 .69032 L .40382 .68797 L F
.40162 .68836 m .40079 .6907 L .40372 .69032 L F
.181 .518 .917 r
.32276 .59805 m .3214 .59845 L .32019 .59739 L F
.32276 .59805 m .32387 .59936 L .3214 .59845 L F
.547 .745 .968 r
.53373 .76947 m .53479 .76758 L .53313 .7671 L F
.53373 .76947 m .53623 .76917 L .53479 .76758 L F
.382 .244 .566 r
.43223 .76284 m .43385 .7625 L .43396 .76003 L F
.411 .352 .681 r
.43223 .76284 m .43439 .76488 L .43385 .7625 L F
.48 .358 .636 r
.4325 .76528 m .43439 .76488 L .43223 .76284 L F
.595 .476 .686 r
.43781 .7491 m .44023 .74889 L .43975 .74629 L F
.508 .254 .464 r
.4376 .75137 m .44023 .74889 L .43781 .7491 L F
.109 .309 .783 r
.64767 .51747 m .6501 .51936 L .64893 .52021 L F
.325 .715 .981 r
.64893 .52021 m .6501 .51936 L .65141 .52032 L F
.479 .232 .462 r
.40873 .68531 m .41122 .68271 L .4092 .68323 L F
.626 .793 .354 r
.74328 .61346 m .74245 .6149 L .74316 .61374 L F
.732 .935 .605 r
.7414 .61681 m .74026 .61783 L .74245 .6149 L F
0 0 0 r
.74245 .6149 m .7422 .61532 L .74221 .61532 L F
.74245 .6149 m .74221 .61532 L .7445 .61453 L F
.626 .793 .354 r
.74328 .61346 m .74283 .61426 L .74245 .6149 L F
.74283 .61426 m .7414 .61681 L .74245 .6149 L F
0 0 0 r
.74328 .61346 m .74525 .61285 L .74578 .61101 L F
.74328 .61346 m .74316 .61374 L .74525 .61285 L F
.445 .648 .945 r
.74924 .58863 m .74741 .58883 L .74557 .5868 L F
.31 0 0 r
.36062 .65196 m .3628 .65171 L .36445 .65017 L F
.375 0 .096 r
.3628 .65171 m .36643 .64952 L .36445 .65017 L F
.475 .64 .928 r
.437 .78513 m .43808 .7837 L .43579 .78382 L F
.437 .78513 m .43908 .78514 L .43808 .7837 L F
.377 .025 .236 r
.54126 .75124 m .54381 .75105 L .54394 .74945 L F
.606 .21 .266 r
.54394 .74945 m .54381 .75105 L .54598 .75099 L F
0 0 .18 r
.57237 .76505 m .57242 .76723 L .57155 .76829 L F
0 0 .328 r
.57252 .76974 m .57155 .76829 L .57242 .76723 L F
.57252 .76974 m .57133 .77094 L .57155 .76829 L F
.269 0 0 r
.58566 .67723 m .58441 .67781 L .5822 .67788 L F
.074 0 0 r
.58795 .67744 m .58441 .67781 L .58566 .67723 L F
.804 .932 .561 r
.46366 .77065 m .4636 .77012 L .46499 .76849 L F
0 0 0 r
.46499 .76849 m .46612 .76796 L .46654 .76827 L F
.46499 .76849 m .4636 .77012 L .46612 .76796 L F
.685 .892 .973 r
.7077 .59288 m .7102 .59276 L .70968 .59176 L F
.331 .67 .976 r
.7102 .59276 m .71153 .59205 L .70968 .59176 L F
.7102 .59276 m .71342 .59339 L .71153 .59205 L F
.386 .826 .948 r
.25658 .58648 m .25622 .58725 L .25467 .58645 L F
.25658 .58648 m .25817 .58686 L .25622 .58725 L F
.578 .59 .829 r
.33473 .71054 m .33703 .70657 L .33297 .70775 L F
.33473 .71054 m .33703 .71015 L .33703 .70657 L F
.455 .197 .433 r
.33473 .71054 m .33644 .71251 L .33703 .71015 L F
.33473 .71054 m .3342 .71309 L .33644 .71251 L F
.907 .937 .818 r
.63338 .5128 m .63168 .51532 L .63105 .5138 L F
0 0 .082 r
.63168 .51532 m .632 .51606 L .63105 .5138 L F
.63168 .51532 m .63123 .51762 L .632 .51606 L F
.574 .581 .822 r
.74704 .71317 m .74617 .71645 L .74517 .71303 L F
.74704 .71317 m .74799 .71603 L .74617 .71645 L F
.537 .186 .32 r
.46659 .73945 m .46888 .73951 L .46694 .73811 L F
.53 .19 .336 r
.46694 .73811 m .46888 .73951 L .46927 .73798 L F
.718 .256 .152 r
.50844 .76019 m .51246 .76305 L .50889 .76288 L F
.668 .237 .217 r
.51246 .76305 m .51136 .76473 L .50889 .76288 L F
.146 0 0 r
.51305 .76377 m .51159 .76437 L .51246 .76305 L F
.554 .426 .66 r
.50889 .76288 m .51311 .76374 L .50844 .76019 L F
.51311 .76374 m .5135 .76382 L .51329 .76367 L F
.51311 .76374 m .51329 .76367 L .50844 .76019 L F
.571 .322 .499 r
.51311 .76374 m .51136 .76473 L .5135 .76382 L F
.146 0 0 r
.51221 .76425 m .51136 .76473 L .51159 .76437 L F
.571 .322 .499 r
.50889 .76288 m .51136 .76473 L .51311 .76374 L F
0 0 0 r
.5135 .76382 m .51136 .76473 L .51328 .76405 L F
.146 0 0 r
.51328 .76405 m .51136 .76473 L .51221 .76425 L F
.51328 .76405 m .51159 .76437 L .51305 .76377 L F
.587 .522 .749 r
.32933 .69926 m .33005 .7022 L .33223 .70173 L F
.643 .498 .671 r
.33005 .7022 m .33291 .70493 L .33223 .70173 L F
.33005 .7022 m .32992 .70546 L .33291 .70493 L F
.724 .438 .494 r
.51968 .70517 m .52291 .70731 L .52218 .70535 L F
.579 .32 .488 r
.65694 .53162 m .65701 .53352 L .65473 .53336 L F
.614 .347 .489 r
.65694 .53162 m .65941 .53353 L .65701 .53352 L F
.622 .342 .472 r
.65958 .53159 m .65941 .53353 L .65694 .53162 L F
.558 .335 .532 r
.64911 .53429 m .65143 .53599 L .64904 .5363 L F
.646 .277 .329 r
.6515 .53467 m .65143 .53599 L .64911 .53429 L F
.504 .283 .512 r
.41643 .67747 m .41407 .68014 L .4162 .67963 L F
.505 .314 .555 r
.41643 .67747 m .4185 .67701 L .41859 .67467 L F
.503 .282 .512 r
.41643 .67747 m .4183 .67917 L .4185 .67701 L F
.41643 .67747 m .4162 .67963 L .4183 .67917 L F
.362 0 0 r
.41133 .665 m .40939 .66581 L .40707 .66569 L F
.25 0 0 r
.41327 .66426 m .40939 .66581 L .41133 .665 L F
.842 .454 .312 r
.62209 .69942 m .61874 .69673 L .61866 .69913 L F
.836 .696 .709 r
.61858 .70153 m .62209 .69942 L .61866 .69913 L F
.61858 .70153 m .62035 .70232 L .62209 .69942 L F
.939 .766 .641 r
.31841 .7267 m .31762 .72956 L .31928 .72937 L F
.608 .567 .783 r
.56994 .69703 m .57116 .69343 L .5689 .69403 L F
.56994 .69703 m .57195 .69659 L .57116 .69343 L F
.565 .415 .637 r
.57009 .69934 m .57195 .69659 L .56994 .69703 L F
.749 .566 .647 r
.54937 .73272 m .54602 .73488 L .54588 .73256 L F
.54937 .73272 m .549 .73533 L .54602 .73488 L F
.513 .378 .634 r
.70652 .58729 m .70829 .58675 L .70861 .5837 L F
.295 0 .145 r
.70568 .58861 m .70715 .58757 L .70652 .58729 L F
.70715 .58757 m .70829 .58675 L .70742 .58701 L F
.677 .47 .599 r
.70698 .58738 m .70829 .58675 L .70568 .58861 L F
.774 .275 .021 r
.70568 .58861 m .70883 .59147 L .70564 .58971 L F
.70883 .59147 m .70884 .59148 L .70883 .59147 L F
.70883 .59147 m .70883 .59147 L .70564 .58971 L F
0 0 0 r
.7077 .59288 m .70737 .59351 L .70884 .59148 L F
.792 .731 .795 r
.70883 .59148 m .70737 .59351 L .70435 .59309 L F
.70883 .59148 m .70435 .59309 L .70572 .59233 L F
.70884 .59148 m .70883 .59149 L .70883 .59148 L F
0 0 0 r
.70871 .59273 m .7077 .59288 L .70968 .59176 L F
.792 .731 .795 r
.70884 .59148 m .70341 .59297 L .70564 .58971 L F
0 0 0 r
.70871 .59273 m .70968 .59176 L .70872 .59063 L F
.253 0 0 r
.70968 .59176 m .7112 .59233 L .70872 .59063 L F
.597 .317 .462 r
.70872 .59067 m .7112 .59233 L .70871 .59273 L F
.70872 .59063 m .70875 .59065 L .70872 .59067 L F
.70875 .59065 m .7112 .59233 L .70872 .59067 L F
.792 .731 .795 r
.70572 .59233 m .70435 .59309 L .70341 .59297 L F
.70883 .59149 m .70737 .59351 L .70883 .59148 L F
.875 .666 .14 r
.70871 .59063 m .70871 .59195 L .70845 .59049 L F
.70872 .59063 m .70872 .59067 L .70871 .59063 L F
.70872 .59067 m .70871 .59195 L .70871 .59063 L F
.70871 .59195 m .70871 .59273 L .70865 .59221 L F
.70871 .59195 m .70865 .59221 L .70845 .59049 L F
.802 .454 .398 r
.70564 .58971 m .70602 .58983 L .70698 .58738 L F
.70602 .58983 m .70872 .59063 L .70712 .58763 L F
.70602 .58983 m .70712 .58763 L .70698 .58738 L F
.295 0 .145 r
.70715 .58757 m .70742 .58701 L .70652 .58729 L F
.634 .649 .848 r
.37052 .70421 m .36703 .70228 L .36918 .70196 L F
.632 .686 .883 r
.37261 .70334 m .37052 .70421 L .36918 .70196 L F
.559 .314 .501 r
.64358 .53727 m .64365 .53929 L .6413 .53958 L F
.552 .279 .456 r
.64696 .53626 m .64365 .53929 L .64358 .53727 L F
.568 .497 .736 r
.43113 .77107 m .43249 .7679 L .43051 .76841 L F
.43113 .77107 m .43323 .77071 L .43249 .7679 L F
.542 .379 .611 r
.43121 .77355 m .43323 .77071 L .43113 .77107 L F
.732 .817 .918 r
.42855 .65522 m .42643 .65624 L .42502 .65521 L F
0 0 .33 r
.57904 .73798 m .57736 .73476 L .57756 .73575 L F
.586 .494 .717 r
.52923 .7413 m .52807 .74354 L .52777 .74096 L F
.52923 .7413 m .52807 .74354 L .52777 .74096 L F
.486 .212 .424 r
.58598 .70744 m .58772 .70522 L .5852 .70523 L F
.58598 .70744 m .58827 .70705 L .58772 .70522 L F
.495 .311 .561 r
.70913 .58138 m .70861 .5837 L .70746 .5806 L F
.903 .723 .648 r
.70746 .5806 m .70861 .5837 L .70913 .58138 L F
.841 .537 .473 r
.71058 .58366 m .70913 .58138 L .70861 .5837 L F
.337 .16 .488 r
.33427 .61036 m .33277 .60862 L .33445 .60813 L F
.33427 .61036 m .33264 .61129 L .33277 .60862 L F
.338 .415 .794 r
.57451 .69556 m .57681 .6957 L .57418 .69385 L F
.362 .141 .438 r
.57681 .6957 m .57509 .69671 L .57451 .69556 L F
0 0 .41 r
.32412 .71615 m .32471 .71849 L .32511 .71757 L F
.251 .76 .866 r
.32258 .71727 m .32533 .71706 L .32511 .71757 L F
.32533 .71706 m .32713 .71692 L .32511 .71757 L F
0 0 .41 r
.32471 .71849 m .32478 .71875 L .32511 .71757 L F
.661 .314 0 r
.60339 .69684 m .60293 .69579 L .6021 .69381 L F
.85 .892 .468 r
.60168 .69953 m .60293 .69579 L .60339 .69684 L F
.432 .377 .696 r
.66385 .52605 m .662 .52847 L .66149 .5258 L F
.66385 .52605 m .66429 .52805 L .662 .52847 L F
.105 0 .228 r
.66429 .52805 m .66208 .53045 L .662 .52847 L F
.615 .534 .739 r
.51661 .74332 m .51686 .74667 L .52108 .7455 L F
.615 .388 .55 r
.51648 .7484 m .52108 .7455 L .51686 .74667 L F
.523 .514 .787 r
.59283 .71049 m .59166 .70736 L .59114 .71033 L F
.89 .924 .837 r
.58949 .71231 m .59283 .71049 L .59114 .71033 L F
.39 0 .172 r
.38857 .69918 m .39069 .69885 L .39194 .69678 L F
.36 0 .155 r
.39194 .69678 m .39281 .69842 L .39415 .69648 L F
.39194 .69678 m .39069 .69885 L .39281 .69842 L F
.692 .49 .609 r
.4651 .75723 m .46613 .75988 L .46262 .75977 L F
.647 .573 .758 r
.46699 .7542 m .46807 .75738 L .4651 .75723 L F
.735 .511 .588 r
.46791 .75946 m .4651 .75723 L .46807 .75738 L F
.46791 .75946 m .46613 .75988 L .4651 .75723 L F
.664 .208 .16 r
.51181 .70708 m .51368 .70838 L .51495 .70725 L F
.419 0 0 r
.51368 .70838 m .51721 .7076 L .51495 .70725 L F
.103 0 0 r
.39585 .66513 m .399 .66501 L .39794 .66505 L F
0 .506 .743 r
.399 .66501 m .40007 .66511 L .39794 .66505 L F
.399 .66501 m .40193 .66551 L .40007 .66511 L F
.958 .934 .606 r
.7414 .61681 m .74011 .61997 L .74026 .61783 L F
.928 .652 .172 r
.57935 .70288 m .57939 .70446 L .57865 .70119 L F
0 0 .076 r
.58919 .7258 m .59046 .72576 L .58952 .72405 L F
.648 .628 .817 r
.59046 .72576 m .59238 .72345 L .58952 .72405 L F
.59046 .72576 m .59355 .72574 L .59238 .72345 L F
.54 0 0 r
.50709 .7927 m .51044 .79334 L .50935 .79382 L F
.34 0 0 r
.51044 .79334 m .51143 .79426 L .50935 .79382 L F
.51044 .79334 m .51273 .79345 L .51143 .79426 L F
.422 .092 .299 r
.41151 .69628 m .41086 .69854 L .40887 .69895 L F
.418 .157 .41 r
.41432 .69365 m .41367 .6963 L .41151 .69628 L F
.599 .353 .515 r
.41367 .6963 m .41086 .69854 L .41151 .69628 L F
.739 .519 .595 r
.48092 .75581 m .48026 .75932 L .47816 .75591 L F
.638 .688 .88 r
.40193 .66551 m .40256 .667 L .40492 .66639 L F
.546 .202 .336 r
.53244 .75626 m .53596 .75386 L .53377 .75482 L F
.374 .125 .402 r
.30027 .61958 m .30155 .62106 L .30193 .61865 L F
.30027 .61958 m .29932 .62185 L .30155 .62106 L F
1 .813 .495 r
.52648 .73698 m .52541 .73699 L .52577 .73464 L F
.836 .738 .756 r
.5232 .73738 m .52648 .73698 L .52541 .73699 L F
.5232 .73738 m .52416 .74036 L .52648 .73698 L F
.81 .792 .836 r
.52577 .73464 m .52648 .73698 L .52741 .73581 L F
.539 .492 .752 r
.33037 .69161 m .33113 .69397 L .3331 .69345 L F
.599 .46 .664 r
.33097 .6963 m .3331 .69345 L .33113 .69397 L F
.823 .606 .609 r
.32478 .72554 m .32283 .72658 L .32295 .7242 L F
.968 .682 .432 r
.32332 .72915 m .32283 .72658 L .32478 .72554 L F
.415 .268 .571 r
.32767 .72346 m .32768 .7261 L .32478 .72554 L F
.43 .139 .368 r
.32768 .7261 m .32555 .72677 L .32478 .72554 L F
.43 .798 .995 r
.29856 .5945 m .29807 .59551 L .29644 .59428 L F
.29856 .5945 m .30015 .59521 L .29807 .59551 L F
.96 .696 .49 r
.59843 .68016 m .59737 .682 L .59701 .67959 L F
.59843 .68016 m .59862 .68262 L .59737 .682 L F
.566 .507 .749 r
.3621 .69432 m .36017 .69493 L .35905 .69128 L F
.445 .493 .815 r
.5035 .75372 m .50196 .75478 L .50093 .75141 L F
.339 .289 .655 r
.5035 .75372 m .50361 .75664 L .50196 .75478 L F
.234 .263 .687 r
.50361 .75664 m .5027 .75775 L .50196 .75478 L F
.096 0 0 r
.36947 .72082 m .36834 .72058 L .37058 .71992 L F
.36947 .72082 m .3674 .72146 L .36834 .72058 L F
.652 .336 .425 r
.48712 .7593 m .48511 .76198 L .48295 .75991 L F
.284 0 0 r
.48879 .76027 m .48511 .76198 L .48712 .7593 L F
.166 0 0 r
.2969 .74053 m .30039 .74075 L .30099 .74062 L F
.462 .729 .984 r
.29851 .73957 m .30037 .74057 L .2969 .74053 L F
.932 .951 .623 r
.30045 .7403 m .30039 .74075 L .30099 .74062 L F
.777 .758 .835 r
.30079 .73917 m .30037 .74057 L .29851 .73957 L F
.932 .951 .623 r
.30033 .74023 m .30037 .74057 L .30045 .7403 L F
.30037 .74057 m .30039 .74075 L .30045 .7403 L F
.30079 .73917 m .30033 .74023 L .30099 .74062 L F
.30008 .74081 m .29941 .74236 L .30099 .74062 L F
.166 0 0 r
.30039 .74075 m .30074 .74077 L .30099 .74062 L F
.777 .758 .835 r
.30079 .73917 m .30074 .74077 L .30037 .74057 L F
.462 .729 .984 r
.30037 .74057 m .30074 .74077 L .30039 .74075 L F
.30037 .74057 m .30039 .74075 L .2969 .74053 L F
.932 .951 .623 r
.30033 .74023 m .30008 .74081 L .30039 .74075 L F
.873 .763 .258 r
.30079 .73917 m .30074 .74077 L .30099 .74062 L F
.634 .332 .442 r
.58382 .7125 m .58605 .71289 L .58657 .71006 L F
.538 .512 .775 r
.58657 .71006 m .58827 .70705 L .58598 .70744 L F
.58657 .71006 m .58963 .70996 L .58827 .70705 L F
.638 .336 .443 r
.58657 .71006 m .58949 .71231 L .58963 .70996 L F
.58657 .71006 m .58605 .71289 L .58949 .71231 L F
.257 0 .051 r
.47211 .76046 m .471 .76224 L .46929 .76212 L F
0 0 .277 r
.47346 .75858 m .47211 .76046 L .47357 .75705 L F
0 0 0 r
.47191 .76113 m .47211 .76046 L .47346 .75858 L F
.47191 .76113 m .471 .76224 L .47211 .76046 L F
.27975 .65501 m .27839 .65519 L .27619 .65538 L F
.414 .864 .859 r
.28028 .65447 m .27975 .65501 L .2817 .65479 L F
.28028 .65447 m .27839 .65519 L .27975 .65501 L F
.547 .388 .617 r
.33423 .66905 m .33637 .66867 L .3363 .66623 L F
.5 .361 .623 r
.33423 .66905 m .33633 .67101 L .33637 .66867 L F
.33423 .66905 m .33444 .67162 L .33633 .67101 L F
.302 0 0 r
.59674 .66798 m .59984 .6668 L .59837 .6661 L F
.59674 .66798 m .60035 .66821 L .59984 .6668 L F
.858 .901 .863 r
.7423 .72691 m .74475 .72644 L .74404 .72563 L F
.874 .95 .857 r
.74404 .72563 m .74475 .72644 L .74727 .72361 L F
.158 0 0 r
.27952 .6417 m .27996 .64284 L .28122 .64056 L F
.27952 .6417 m .27803 .64357 L .27996 .64284 L F
.358 .732 .988 r
.31337 .59571 m .31283 .59666 L .31124 .59599 L F
.31337 .59571 m .31482 .59659 L .31283 .59666 L F
.79 .414 .343 r
.32216 .7189 m .3208 .72034 L .31957 .71807 L F
.368 .691 .981 r
.31973 .71798 m .32276 .71783 L .32216 .7189 L F
.663 .896 .551 r
.32276 .71783 m .3208 .72034 L .32216 .7189 L F
.32276 .71783 m .32216 .7189 L .32478 .71875 L F
.32276 .71783 m .3208 .72034 L .32216 .7189 L F
0 0 0 r
.50361 .75664 m .50229 .75842 L .5027 .75775 L F
.873 .625 .561 r
.60853 .67938 m .61145 .68238 L .61164 .6802 L F
.849 .61 .576 r
.61145 .68238 m .613 .68304 L .61164 .6802 L F
.64 .631 .825 r
.52069 .76249 m .5181 .76272 L .51924 .76115 L F
.065 .19 .684 r
.51858 .76205 m .51904 .76192 L .51924 .76115 L F
.5181 .76272 m .51868 .76222 L .51858 .76205 L F
.51868 .76222 m .51904 .76192 L .51858 .76205 L F
.5181 .76272 m .51934 .76247 L .51904 .76192 L F
.14 .589 .927 r
.51451 .76141 m .51934 .76247 L .5181 .76272 L F
.3 0 0 r
.51336 .7616 m .51878 .76239 L .51451 .76141 L F
.51878 .76239 m .51934 .76247 L .51876 .76234 L F
.51878 .76239 m .51876 .76234 L .51451 .76141 L F
.847 .646 .63 r
.5181 .76272 m .51461 .76416 L .51505 .76309 L F
.5181 .76272 m .51777 .76519 L .51461 .76416 L F
.594 .392 .577 r
.52069 .76249 m .51777 .76519 L .5181 .76272 L F
.863 .628 .582 r
.60121 .68557 m .59856 .68513 L .59862 .68262 L F
.875 .682 .637 r
.60005 .68784 m .59856 .68513 L .60121 .68557 L F
.534 .272 .464 r
.51721 .7076 m .51946 .70733 L .51968 .70517 L F
.724 .438 .494 r
.51968 .70517 m .51946 .70733 L .52291 .70731 L F
.472 .286 .547 r
.51675 .72963 m .5187 .7292 L .5187 .72693 L F
.49 .193 .388 r
.41323 .68217 m .4162 .67963 L .41407 .68014 L F
.018 0 0 r
.53807 .74016 m .53995 .73963 L .54118 .73854 L F
.762 .67 .76 r
.54018 .73476 m .54118 .73854 L .54373 .73553 L F
.109 0 0 r
.53995 .73963 m .54377 .73969 L .54118 .73854 L F
.353 .322 .684 r
.41818 .67182 m .41996 .6735 L .42053 .67152 L F
.41818 .67182 m .41859 .67467 L .41996 .6735 L F
0 .216 .728 r
.56634 .71835 m .56706 .71751 L .56503 .71536 L F
.021 .251 .754 r
.56634 .71835 m .56851 .72041 L .56706 .71751 L F
.151 .693 .746 r
.38845 .66709 m .38446 .66764 L .38496 .66812 L F
.47 .187 .402 r
.40858 .70122 m .40711 .69973 L .40887 .69895 L F
.40858 .70122 m .40645 .70165 L .40711 .69973 L F
.871 .751 .728 r
.59866 .72422 m .59655 .72696 L .59557 .72606 L F
.384 .268 .596 r
.4185 .67701 m .41996 .6735 L .41859 .67467 L F
.616 .468 .659 r
.50844 .76019 m .50889 .76288 L .50666 .76273 L F
.50844 .76019 m .50889 .76288 L .50666 .76273 L F
.449 .186 .421 r
.41574 .69575 m .41432 .69365 L .41652 .69333 L F
.41574 .69575 m .41367 .6963 L .41432 .69365 L F
.322 0 .034 r
.39185 .70985 m .39044 .71164 L .38825 .71203 L F
.329 0 .065 r
.39389 .70932 m .39044 .71164 L .39185 .70985 L F
0 0 0 r
.55027 .68824 m .55178 .68719 L .55296 .68562 L F
.209 0 0 r
.55296 .68562 m .55373 .68649 L .55535 .68536 L F
.55296 .68562 m .55178 .68719 L .55373 .68649 L F
.281 0 0 r
.72277 .71805 m .72511 .71764 L .72576 .71648 L F
.751 .695 .798 r
.72521 .71336 m .72576 .71648 L .72813 .7143 L F
.688 .212 .115 r
.72511 .71764 m .72818 .71813 L .72576 .71648 L F
.321 0 0 r
.53087 .71868 m .53275 .71926 L .53433 .71905 L F
.437 .811 .993 r
.53275 .71926 m .53687 .71952 L .53433 .71905 L F
.775 .646 .719 r
.70829 .58675 m .71187 .58612 L .71058 .58366 L F
.991 .764 .494 r
.71023 .58864 m .71187 .58612 L .70829 .58675 L F
.71023 .58864 m .71187 .59027 L .71187 .58612 L F
.735 .631 .744 r
.71187 .58612 m .7139 .5842 L .71058 .58366 L F
.233 0 0 r
.27638 .60471 m .27292 .6045 L .27435 .60508 L F
.943 .801 .673 r
.73554 .62437 m .73383 .6252 L .73571 .62359 L F
.73554 .62437 m .73506 .62613 L .73383 .6252 L F
.77 .979 .913 r
.7389 .62193 m .73554 .62437 L .73571 .62359 L F
.905 .806 .74 r
.62634 .53205 m .6259 .53753 L .62492 .53599 L F
0 0 .399 r
.62492 .53599 m .6259 .53753 L .62683 .53893 L F
.61 .113 0 r
.50171 .73651 m .50286 .73758 L .50067 .73505 L F
.509 .307 .542 r
.55196 .69877 m .55534 .70046 L .55333 .69937 L F
.151 .693 .746 r
.38845 .66709 m .38663 .66728 L .38446 .66764 L F
.234 0 0 r
.3903 .66617 m .38663 .66728 L .38845 .66709 L F
.485 .13 .287 r
.47164 .73773 m .47391 .73751 L .47485 .73539 L F
.572 .217 .328 r
.47485 .73539 m .47391 .73751 L .47681 .73694 L F
.525 .239 .422 r
.47485 .73539 m .47681 .73694 L .47713 .73507 L F
.309 .752 .964 r
.26166 .58728 m .25817 .58686 L .26027 .58708 L F
0 .505 .736 r
.26222 .58729 m .26166 .58728 L .26027 .58708 L F
.26222 .58729 m .26391 .58762 L .26166 .58728 L F
.508 .173 .334 r
.54012 .74563 m .5369 .74853 L .53687 .74606 L F
.54012 .74563 m .53943 .74822 L .5369 .74853 L F
.18 .708 .851 r
.54281 .7454 m .54022 .74531 L .54012 .74563 L F
0 0 .115 r
.54057 .74701 m .54012 .74563 L .54022 .74531 L F
.54057 .74701 m .53943 .74822 L .54012 .74563 L F
.526 .306 .523 r
.39872 .69346 m .40079 .6907 L .39881 .69099 L F
.612 .227 .29 r
.59449 .66635 m .59674 .66798 L .59837 .6661 L F
.456 .464 .778 r
.66254 .52218 m .66149 .5258 L .66023 .52481 L F
.66254 .52218 m .66385 .52605 L .66149 .5258 L F
.834 .803 .822 r
.63541 .51045 m .63338 .5128 L .63212 .51151 L F
.923 .782 .687 r
.63212 .51151 m .63338 .5128 L .63105 .5138 L F
.539 .492 .752 r
.33037 .69161 m .3331 .69345 L .33252 .69069 L F
.803 .647 .689 r
.61546 .69604 m .61874 .69673 L .61727 .69363 L F
.903 .68 .59 r
.61698 .69849 m .61874 .69673 L .61546 .69604 L F
.61698 .69849 m .61866 .69913 L .61874 .69673 L F
.486 .2 .404 r
.43123 .68034 m .43088 .68217 L .42876 .68256 L F
.492 .205 .405 r
.43299 .68169 m .43088 .68217 L .43123 .68034 L F
.516 .195 .362 r
.43346 .68014 m .43299 .68169 L .43123 .68034 L F
.009 .196 .708 r
.32222 .72268 m .32213 .71977 L .3208 .72034 L F
.036 .175 .679 r
.32222 .72268 m .32295 .7242 L .32359 .72324 L F
.762 .67 .76 r
.54018 .73476 m .54373 .73553 L .54264 .73403 L F
.558 .364 .574 r
.54602 .73488 m .54547 .73747 L .54373 .73553 L F
.864 .603 .071 r
.54547 .73747 m .54264 .73403 L .54373 .73553 L F
.758 .271 .078 r
.54024 .72067 m .54231 .7228 L .54285 .72159 L F
.691 .19 .047 r
.54231 .7228 m .54553 .72364 L .54285 .72159 L F
.706 .914 .966 r
.5578 .68894 m .56165 .68804 L .56095 .68768 L F
.903 .981 .789 r
.56348 .6842 m .56165 .68804 L .56407 .68507 L F
.56348 .6842 m .56095 .68768 L .56165 .68804 L F
.465 .383 .68 r
.45739 .7649 m .45493 .76265 L .4572 .76246 L F
.45739 .7649 m .45533 .76624 L .45493 .76265 L F
.381 .13 .403 r
.40645 .70165 m .40412 .7041 L .40458 .70228 L F
.575 .535 .773 r
.58242 .71879 m .58075 .72041 L .57932 .7164 L F
.58242 .71879 m .58325 .72064 L .58075 .72041 L F
0 0 .005 r
.57418 .76201 m .5734 .76413 L .57237 .76505 L F
0 0 .201 r
.5734 .76413 m .57242 .76723 L .57237 .76505 L F
.467 .476 .784 r
.6444 .50771 m .64288 .50793 L .64279 .50695 L F
.434 .276 .567 r
.6444 .50771 m .64325 .5114 L .64288 .50793 L F
.695 .639 .789 r
.71821 .72124 m .72152 .72301 L .72054 .72084 L F
.593 .668 .891 r
.72152 .72301 m .72288 .72043 L .72054 .72084 L F
.72152 .72301 m .72407 .72271 L .72288 .72043 L F
.744 .224 0 r
.56366 .7139 m .56359 .71463 L .56178 .71259 L F
.56366 .7139 m .56503 .71536 L .56359 .71463 L F
.571 .925 .95 r
.34593 .65776 m .34279 .65858 L .34516 .65826 L F
0 0 0 r
.34737 .65752 m .34593 .65776 L .34516 .65826 L F
.447 .246 .513 r
.50833 .75034 m .50632 .75126 L .50666 .74895 L F
.587 .204 .285 r
.5091 .74924 m .50833 .75034 L .50666 .74895 L F
.915 .878 .785 r
.55027 .68824 m .54761 .69049 L .55015 .68851 L F
0 0 0 r
.55027 .68824 m .55015 .68851 L .55178 .68719 L F
0 0 .158 r
.61904 .73396 m .61872 .7376 L .61878 .73512 L F
.858 .561 .484 r
.61273 .68553 m .61292 .68779 L .61559 .68835 L F
.865 .665 .631 r
.61292 .68779 m .61457 .69083 L .61559 .68835 L F
.763 .462 .477 r
.45104 .74286 m .4533 .74553 L .45347 .74358 L F
.606 .348 .5 r
.4533 .74553 m .4558 .74333 L .45347 .74358 L F
.705 .7 .843 r
.73584 .62669 m .73823 .62935 L .74286 .62733 L F
.548 .067 .066 r
.37741 .6484 m .3796 .64873 L .38103 .64758 L F
.443 0 0 r
.38103 .64758 m .3796 .64873 L .3831 .64819 L F
.46 .344 .635 r
.48119 .77839 m .48308 .77854 L .48094 .77649 L F
.48119 .77839 m .48308 .77854 L .48094 .77649 L F
.211 .393 .826 r
.58004 .74333 m .58104 .74213 L .57843 .74037 L F
.009 .083 .593 r
.58004 .74333 m .58138 .74542 L .58104 .74213 L F
.581 .298 .45 r
.40382 .68797 m .40618 .68776 L .4067 .68579 L F
.45 .175 .403 r
.4067 .68579 m .40823 .6873 L .40873 .68531 L F
.4067 .68579 m .40618 .68776 L .40823 .6873 L F
.55 .429 .668 r
.32933 .69926 m .33126 .69871 L .33097 .6963 L F
.587 .522 .749 r
.32933 .69926 m .33223 .70173 L .33126 .69871 L F
.718 .537 .645 r
.47187 .75191 m .46972 .75391 L .46976 .75172 L F
.43 .316 .623 r
.45576 .76908 m .45369 .76837 L .45611 .76807 L F
.45576 .76908 m .45361 .77094 L .45369 .76837 L F
.433 .648 .949 r
.74166 .59323 m .74249 .59462 L .74383 .5933 L F
.357 .522 .883 r
.74249 .59462 m .74599 .59665 L .74383 .5933 L F
.865 .618 .563 r
.53227 .76495 m .52962 .76238 L .5329 .76291 L F
.549 .818 .458 r
.50929 .71744 m .50806 .71889 L .50704 .72014 L F
0 0 0 r
.50806 .71889 m .50793 .71908 L .50704 .72014 L F
.489 .839 .996 r
.50614 .7212 m .50704 .72014 L .50871 .72074 L F
.50612 .72121 m .50704 .72014 L .50871 .72074 L F
.683 .55 .697 r
.50953 .72391 m .50612 .72121 L .50871 .72074 L F
.50953 .72391 m .5063 .72415 L .50612 .72121 L F
.551 .138 .213 r
.50599 .72171 m .50883 .7215 L .50704 .72014 L F
.189 .224 .667 r
.50871 .72074 m .50929 .71744 L .50704 .72014 L F
.50871 .72074 m .51 .71951 L .50929 .71744 L F
.511 .163 .313 r
.50704 .72014 m .51 .71951 L .50871 .72074 L F
.50704 .72014 m .50883 .7215 L .51 .71951 L F
0 0 0 r
.50793 .71908 m .50599 .72171 L .50704 .72014 L F
.489 .839 .996 r
.50612 .72121 m .50704 .72014 L .50614 .7212 L F
.611 .349 .496 r
.53826 .75421 m .54182 .75492 L .54126 .75124 L F
.535 .298 .502 r
.54126 .75124 m .54375 .75346 L .54381 .75105 L F
.54126 .75124 m .54182 .75492 L .54375 .75346 L F
.497 .367 .633 r
.36212 .68247 m .36213 .68467 L .36007 .6829 L F
.421 .366 .691 r
.36007 .6829 m .36213 .68467 L .36062 .68507 L F
0 .131 .677 r
.57016 .72353 m .56851 .72041 L .56919 .72146 L F
.392 .313 .647 r
.29807 .62257 m .29987 .62408 L .29932 .62185 L F
.29807 .62257 m .29841 .62489 L .29987 .62408 L F
.834 .803 .822 r
.63541 .51045 m .63212 .51151 L .63415 .50864 L F
.664 .692 .866 r
.63753 .50937 m .63541 .51045 L .63415 .50864 L F
.606 .91 .982 r
.75473 .60343 m .75542 .60397 L .75275 .60508 L F
.605 .095 0 r
.75473 .60343 m .75525 .60394 L .75542 .60397 L F
.817 .88 .891 r
.75564 .60402 m .75275 .60508 L .75542 .60397 L F
.605 .095 0 r
.75525 .60394 m .75692 .60555 L .75542 .60397 L F
.817 .88 .891 r
.75581 .60396 m .75564 .60402 L .75542 .60397 L F
.634 .16 .111 r
.75692 .60555 m .75581 .60396 L .75542 .60397 L F
.75692 .60555 m .75851 .60515 L .75581 .60396 L F
.438 .245 .52 r
.31837 .62722 m .3165 .62781 L .31856 .62494 L F
.435 .268 .554 r
.31825 .62952 m .3165 .62781 L .31837 .62722 L F
.31825 .62952 m .31643 .63018 L .3165 .62781 L F
.559 .452 .688 r
.3611 .68973 m .36117 .69081 L .35905 .69128 L F
.566 .507 .749 r
.3621 .69432 m .35905 .69128 L .36117 .69081 L F
.926 .619 .442 r
.72818 .71813 m .72851 .72037 L .72968 .71877 L F
.981 .894 .55 r
.72851 .72037 m .72886 .72155 L .72968 .71877 L F
.72936 .71922 m .72945 .71956 L .72968 .71877 L F
.521 .333 .566 r
.72818 .71813 m .73209 .72034 L .72968 .71877 L F
.72922 .71872 m .73096 .7186 L .73209 .72034 L F
.72818 .71813 m .72911 .71829 L .72922 .71872 L F
.72911 .71829 m .73096 .7186 L .72922 .71872 L F
.981 .894 .55 r
.72851 .72037 m .72886 .72155 L .72945 .71956 L F
.72851 .72037 m .72945 .71956 L .72936 .71922 L F
.288 .624 .96 r
.42166 .65407 m .42361 .65434 L .42291 .65528 L F
.371 .732 .989 r
.42361 .65434 m .42502 .65521 L .42291 .65528 L F
.545 .916 .751 r
.61031 .75169 m .60982 .75175 L .60657 .75387 L F
.726 .981 .767 r
.61031 .75169 m .6129 .74928 L .6111 .75023 L F
.722 .965 .704 r
.61031 .75169 m .6111 .75023 L .60982 .75175 L F
.142 0 0 r
.29296 .6517 m .29511 .6511 L .29398 .65203 L F
.146 0 0 r
.29398 .65203 m .29086 .65329 L .29296 .6517 L F
.737 .745 .858 r
.6544 .5207 m .65141 .52032 L .65351 .51904 L F
.578 .668 .901 r
.65622 .51862 m .6544 .5207 L .65351 .51904 L F
.413 .417 .755 r
.65622 .51862 m .65696 .52224 L .6544 .5207 L F
.445 .493 .815 r
.5035 .75372 m .50093 .75141 L .50435 .75163 L F
.415 .098 .317 r
.50632 .75126 m .5035 .75372 L .50435 .75163 L F
.383 .766 .99 r
.44277 .78558 m .44353 .78472 L .44148 .78507 L F
.44277 .78558 m .44454 .78547 L .44353 .78472 L F
.717 .69 .824 r
.73571 .72824 m .7375 .72972 L .73949 .72897 L F
.874 .95 .857 r
.74404 .72563 m .74727 .72361 L .74652 .72318 L F
.885 .981 .823 r
.74652 .72318 m .74727 .72361 L .74892 .72133 L F
.538 .427 .676 r
.43364 .75695 m .43573 .75654 L .43538 .75418 L F
.556 .426 .658 r
.43364 .75695 m .436 .75954 L .43573 .75654 L F
.43364 .75695 m .43396 .76003 L .436 .75954 L F
.353 .824 .774 r
.28073 .60358 m .28362 .60274 L .28439 .60238 L F
.627 .461 .638 r
.5187 .72693 m .52104 .72689 L .52108 .72403 L F
.56 .407 .63 r
.52108 .72403 m .52371 .7263 L .52328 .72363 L F
.52108 .72403 m .52104 .72689 L .52371 .7263 L F
0 .521 .705 r
.56557 .6844 m .56348 .6842 L .56407 .68507 L F
.476 .126 .292 r
.57338 .67484 m .57274 .67605 L .57589 .67468 L F
.551 .427 .664 r
.33104 .68266 m .3329 .67964 L .33075 .68008 L F
.576 .469 .695 r
.33075 .68008 m .3329 .67964 L .33257 .67722 L F
.922 .728 .624 r
.60253 .69107 m .60047 .69337 L .60116 .69037 L F
.60253 .69107 m .6021 .69381 L .60047 .69337 L F
.891 .898 .826 r
.56311 .68011 m .56051 .68298 L .55978 .68228 L F
.56311 .68011 m .55978 .68228 L .56184 .68145 L F
.147 0 0 r
.56184 .68145 m .56515 .67943 L .56311 .68011 L F
.6 .376 .548 r
.5187 .7292 m .52104 .72689 L .5187 .72693 L F
.914 .69 .585 r
.61145 .68238 m .61273 .68553 L .613 .68304 L F
.07 .482 .892 r
.48426 .78271 m .48717 .784 L .48594 .78414 L F
.055 .342 .82 r
.48717 .784 m .48657 .78456 L .48594 .78414 L F
.641 .17 .12 r
.48302 .78354 m .48717 .784 L .48426 .78271 L F
.675 .239 .208 r
.48535 .7853 m .48717 .784 L .48302 .78354 L F
.487 .852 .612 r
.48783 .78338 m .48717 .784 L .48535 .7853 L F
.793 .664 .722 r
.48992 .78399 m .48717 .784 L .48891 .78086 L F
0 0 0 r
.48891 .78086 m .48717 .784 L .48835 .78298 L F
.487 .852 .612 r
.48835 .78298 m .48717 .784 L .48783 .78338 L F
.055 .342 .82 r
.48717 .784 m .48729 .78503 L .48657 .78456 L F
.421 .782 .995 r
.30418 .59453 m .30364 .59557 L .30205 .59466 L F
.30418 .59453 m .3058 .59533 L .30364 .59557 L F
.411 0 0 r
.48334 .7897 m .48676 .79023 L .48562 .79035 L F
.651 .887 .54 r
.48315 .7737 m .48362 .77284 L .48536 .77092 L F
.646 .497 .666 r
.48536 .77092 m .48548 .77362 L .48315 .7737 L F
.579 .349 .531 r
.48548 .77362 m .48311 .77612 L .48315 .7737 L F
.96 .743 .566 r
.48536 .77092 m .48362 .77284 L .48548 .77362 L F
.594 .928 .718 r
.48501 .77307 m .48407 .77362 L .48493 .77259 L F
0 0 .384 r
.48373 .77413 m .48399 .77374 L .48362 .77284 L F
.48315 .7737 m .48311 .77612 L .48433 .77457 L F
.788 .32 .126 r
.48433 .77457 m .48548 .77362 L .48408 .77303 L F
.48384 .77337 m .48408 .77303 L .48362 .77284 L F
.48433 .77457 m .48408 .77303 L .48384 .77337 L F
0 0 .384 r
.48373 .77413 m .48433 .77457 L .48399 .77374 L F
.579 .349 .531 r
.48548 .77362 m .48537 .77601 L .48311 .77612 L F
0 0 .384 r
.48315 .7737 m .48373 .77413 L .48362 .77284 L F
.899 .537 .346 r
.48433 .77457 m .48268 .77443 L .48362 .77284 L F
.475 0 0 r
.48501 .77307 m .48512 .77474 L .48306 .77448 L F
.48338 .77402 m .48306 .77448 L .48268 .77443 L F
.48501 .77307 m .48306 .77448 L .48338 .77402 L F
.594 .928 .718 r
.48407 .77362 m .48268 .77443 L .48454 .77291 L F
.48407 .77362 m .48454 .77291 L .48493 .77259 L F
.412 0 0 r
.48676 .79023 m .48766 .79158 L .48562 .79035 L F
.48676 .79023 m .48892 .79032 L .48766 .79158 L F
.41 .068 .271 r
.7366 .58498 m .73472 .5847 L .7334 .58564 L F
.7366 .58498 m .73655 .58418 L .73472 .5847 L F
.588 .186 .247 r
.59105 .66798 m .59449 .66635 L .59139 .66673 L F
.59105 .66798 m .59341 .66812 L .59449 .66635 L F
.618 .219 .264 r
.59341 .66812 m .59674 .66798 L .59449 .66635 L F
.444 .18 .418 r
.43861 .67679 m .43601 .67914 L .43635 .67706 L F
0 .516 .715 r
.28754 .59271 m .29124 .59315 L .28907 .59341 L F
.555 .777 .982 r
.33884 .72292 m .3404 .72401 L .34134 .72263 L F
.332 .472 .851 r
.3404 .72401 m .34208 .72423 L .34134 .72263 L F
0 0 0 r
.52211 .74808 m .51946 .7504 L .52387 .74945 L F
.52211 .74808 m .51985 .75033 L .51946 .7504 L F
0 .412 .808 r
.51946 .7504 m .51985 .75033 L .51756 .74941 L F
.587 .381 .568 r
.44361 .67179 m .44352 .67437 L .4412 .67449 L F
.647 .55 .731 r
.44556 .66893 m .44361 .67179 L .44329 .66943 L F
.655 .561 .737 r
.44579 .67054 m .44361 .67179 L .44556 .66893 L F
.599 .409 .596 r
.44579 .67054 m .44352 .67437 L .44361 .67179 L F
.229 0 0 r
.37728 .67185 m .37407 .67351 L .37495 .67236 L F
.743 .742 .851 r
.3299 .70673 m .33291 .70493 L .32992 .70546 L F
.618 .445 .626 r
.47646 .75679 m .47346 .75858 L .47357 .75705 L F
.469 .776 .997 r
.41457 .65221 m .4138 .65345 L .41237 .65238 L F
.41457 .65221 m .41596 .65317 L .4138 .65345 L F
.556 .292 .472 r
.46031 .75965 m .45957 .76242 L .4572 .76246 L F
.596 .331 .486 r
.46231 .76194 m .46031 .75965 L .46262 .75977 L F
.46231 .76194 m .45957 .76242 L .46031 .75965 L F
.374 .698 .983 r
.27134 .58866 m .27075 .58983 L .26926 .58864 L F
.27134 .58866 m .2728 .58992 L .27075 .58983 L F
.716 .951 .952 r
.72001 .71401 m .71562 .71641 L .71576 .71523 L F
.063 0 0 r
.74578 .61101 m .74819 .61045 L .74838 .60929 L F
.095 0 .077 r
.74578 .61101 m .74742 .61122 L .74819 .61045 L F
.74578 .61101 m .74525 .61285 L .74742 .61122 L F
.164 .323 .779 r
.56991 .70655 m .56895 .70788 L .56769 .70477 L F
.224 .408 .835 r
.56991 .70655 m .5715 .70938 L .56895 .70788 L F
0 0 0 r
.74838 .60929 m .74998 .60645 L .75089 .6085 L F
.74838 .60929 m .74847 .60979 L .74998 .60645 L F
.74838 .60929 m .74819 .61045 L .74847 .60979 L F
.306 .29 .677 r
.54075 .76704 m .539 .76804 L .53881 .76498 L F
.61 .402 .575 r
.54075 .76704 m .53878 .76909 L .539 .76804 L F
.448 .051 .192 r
.40412 .7041 m .40065 .70639 L .40208 .70477 L F
.284 0 0 r
.48879 .76027 m .48731 .76168 L .48511 .76198 L F
.511 .033 .056 r
.49033 .76112 m .48731 .76168 L .48879 .76027 L F
.486 .096 .226 r
.49123 .76009 m .49033 .76112 L .48879 .76027 L F
.925 .759 .657 r
.57189 .75107 m .57255 .7546 L .57346 .75287 L F
.929 .805 .702 r
.53764 .74382 m .53517 .74504 L .53609 .74287 L F
.53764 .74382 m .53687 .74606 L .53517 .74504 L F
.552 .279 .456 r
.64696 .53626 m .64595 .53913 L .64365 .53929 L F
.582 .309 .468 r
.64928 .53721 m .64696 .53626 L .64904 .5363 L F
.64928 .53721 m .64595 .53913 L .64696 .53626 L F
.335 .187 .527 r
.50825 .72569 m .5063 .72415 L .50953 .72391 L F
.50825 .72569 m .50677 .72689 L .5063 .72415 L F
.609 .311 .438 r
.65473 .53336 m .65143 .53599 L .6515 .53467 L F
.749 .715 .82 r
.72333 .58704 m .72479 .58936 L .72134 .58833 L F
.795 .419 .345 r
.72134 .58833 m .72479 .58936 L .72344 .59051 L F
.942 .919 .762 r
.72555 .586 m .72479 .58936 L .72333 .58704 L F
.667 .24 .223 r
.72344 .59051 m .72479 .58936 L .72635 .59077 L F
.323 .769 .961 r
.51312 .74064 m .51661 .74066 L .51484 .74014 L F
0 0 .376 r
.51419 .74183 m .51312 .74064 L .51484 .74014 L F
0 0 .476 r
.51419 .74183 m .51394 .74583 L .5131 .74298 L F
.263 .064 .412 r
.51628 .74196 m .51481 .74449 L .51464 .74374 L F
.51628 .74196 m .51464 .74374 L .51419 .74183 L F
0 0 .376 r
.51419 .74183 m .5131 .74298 L .51312 .74085 L F
.34 0 0 r
.51291 .74275 m .51506 .74287 L .51628 .74196 L F
.038 0 0 r
.51506 .74287 m .51677 .74142 L .51628 .74196 L F
.745 .474 .52 r
.5181 .73968 m .51967 .74218 L .51628 .74196 L F
.514 .824 1 r
.51661 .74066 m .51611 .73961 L .51484 .74014 L F
.51661 .74066 m .5181 .73968 L .51611 .73961 L F
.745 .474 .52 r
.5181 .73968 m .51628 .74196 L .51611 .73961 L F
.241 .259 .679 r
.51709 .74115 m .51611 .73961 L .51628 .74196 L F
.038 0 0 r
.51677 .74142 m .51709 .74115 L .51628 .74196 L F
.34 0 0 r
.51291 .74275 m .51473 .74232 L .51419 .74183 L F
.51473 .74232 m .51628 .74196 L .51419 .74183 L F
0 0 .376 r
.51419 .74183 m .51312 .74085 L .51312 .74064 L F
.115 .53 .914 r
.74336 .58656 m .73942 .58451 L .74248 .58552 L F
.311 .652 .97 r
.74557 .5868 m .74336 .58656 L .74248 .58552 L F
.732 .817 .918 r
.42855 .65522 m .42502 .65521 L .42718 .65458 L F
.451 .762 .996 r
.42932 .65403 m .42855 .65522 L .42718 .65458 L F
.42932 .65403 m .43055 .65494 L .42855 .65522 L F
.496 0 0 r
.3831 .64819 m .38521 .64853 L .38666 .64748 L F
0 0 0 r
.38666 .64748 m .38746 .64769 L .38882 .64807 L F
.38666 .64748 m .38521 .64853 L .38746 .64769 L F
.581 .295 .446 r
.45881 .74281 m .46115 .74281 L .46153 .74089 L F
.552 .272 .444 r
.46115 .74281 m .46382 .74066 L .46153 .74089 L F
.791 .619 .668 r
.46929 .76212 m .46656 .76235 L .46791 .75946 L F
.751 .458 .487 r
.46929 .76212 m .46823 .76478 L .46656 .76235 L F
.113 0 .183 r
.47 .76368 m .46929 .76212 L .471 .76224 L F
.47 .76368 m .46823 .76478 L .46929 .76212 L F
.374 .727 .989 r
.29494 .60727 m .2954 .60626 L .29311 .60619 L F
.29494 .60727 m .29693 .60724 L .2954 .60626 L F
.799 .455 .406 r
.48295 .75991 m .48151 .76195 L .48026 .75932 L F
.694 .32 .334 r
.48511 .76198 m .48151 .76195 L .48295 .75991 L F
.259 .383 .799 r
.34389 .72674 m .34398 .72393 L .34208 .72423 L F
.34389 .72674 m .34537 .7272 L .34398 .72393 L F
.193 .42 .852 r
.34389 .72674 m .34662 .7289 L .34537 .7272 L F
.698 .523 .647 r
.34389 .72674 m .34775 .72992 L .34662 .7289 L F
.34389 .72674 m .34343 .73127 L .34775 .72992 L F
0 0 0 r
.72137 .58661 m .72352 .58357 L .72187 .58314 L F
.739 .634 .743 r
.50372 .79023 m .50508 .79247 L .50145 .79277 L F
.629 .248 .304 r
.50145 .79277 m .50508 .79247 L .50363 .79421 L F
.57 .139 .183 r
.50508 .79247 m .50579 .7944 L .50363 .79421 L F
.50508 .79247 m .50709 .7927 L .50579 .7944 L F
.993 .795 .534 r
.60362 .70486 m .60218 .70653 L .60178 .70409 L F
.60362 .70486 m .60326 .70735 L .60218 .70653 L F
.416 0 .002 r
.50492 .73657 m .50877 .73506 L .50633 .73489 L F
.966 .702 .48 r
.61911 .70731 m .6191 .70962 L .62043 .71025 L F
.962 .702 .493 r
.61904 .71193 m .62043 .71025 L .6191 .70962 L F
.61904 .71193 m .62048 .71276 L .62043 .71025 L F
.543 .481 .736 r
.43256 .77904 m .4334 .7826 L .43515 .78195 L F
.546 .49 .744 r
.4334 .7826 m .43579 .78382 L .43515 .78195 L F
.425 .227 .505 r
.33444 .67162 m .33233 .67425 L .3342 .67378 L F
.583 .462 .68 r
.33257 .67722 m .3342 .67378 L .33233 .67425 L F
.515 .363 .613 r
.3363 .66623 m .33847 .66819 L .33821 .66576 L F
.3363 .66623 m .33637 .66867 L .33847 .66819 L F
0 .403 .704 r
.45748 .78697 m .45943 .78755 L .45616 .78652 L F
.615 .534 .739 r
.51661 .74332 m .52108 .7455 L .51874 .7428 L F
.609 .311 .438 r
.65473 .53336 m .65382 .53611 L .65143 .53599 L F
.598 .299 .433 r
.65683 .53498 m .65473 .53336 L .65701 .53352 L F
.65683 .53498 m .65382 .53611 L .65473 .53336 L F
.852 .631 .603 r
.72834 .62068 m .72597 .62 L .72671 .61995 L F
.72834 .62068 m .72808 .62269 L .72597 .62 L F
.611 .192 .224 r
.72671 .61995 m .73037 .61933 L .72834 .62068 L F
.447 .507 .827 r
.54837 .75959 m .54949 .76272 L .55079 .76187 L F
.573 .035 0 r
.54949 .76272 m .5518 .76483 L .55058 .76401 L F
.395 .4 .747 r
.55079 .76187 m .5518 .76483 L .54949 .76272 L F
.573 .035 0 r
.54949 .76272 m .55058 .76401 L .55079 .76187 L F
.865 .618 .563 r
.53227 .76495 m .52905 .76488 L .52962 .76238 L F
.697 .215 .101 r
.53227 .76495 m .53174 .76628 L .52905 .76488 L F
.591 .87 .547 r
.61404 .74799 m .61392 .748 L .6129 .74928 L F
.637 .951 .748 r
.6129 .74928 m .61392 .748 L .6111 .75023 L F
.246 .184 .587 r
.45739 .7649 m .45611 .76807 L .45533 .76624 L F
.45739 .7649 m .45725 .76758 L .45611 .76807 L F
.186 0 .173 r
.45725 .76758 m .45576 .76908 L .45611 .76807 L F
.476 .205 .423 r
.53332 .7956 m .53111 .79593 L .53078 .79763 L F
0 .17 .7 r
.54877 .72413 m .55124 .72639 L .55037 .72626 L F
0 .396 .754 r
.55037 .72626 m .55124 .72639 L .55227 .72694 L F
.946 .595 .306 r
.74932 .60018 m .74859 .60156 L .74715 .59753 L F
.242 .292 .715 r
.75068 .59874 m .74932 .60018 L .74855 .59764 L F
.763 .644 .731 r
.75068 .59874 m .74859 .60156 L .74932 .60018 L F
.512 .523 .804 r
.45579 .773 m .45704 .77628 L .45497 .77641 L F
.245 0 .17 r
.38668 .69982 m .38785 .70046 L .38857 .69918 L F
.38668 .69982 m .38596 .70125 L .38785 .70046 L F
.414 .044 .223 r
.48217 .73406 m .48488 .73253 L .48264 .73263 L F
.675 .77 .922 r
.52111 .73913 m .52416 .74036 L .5232 .73738 L F
0 0 .33 r
.57904 .73798 m .57857 .73707 L .57736 .73476 L F
.18 .268 .718 r
.57843 .74037 m .57857 .73707 L .57904 .73798 L F
.324 .022 .288 r
.3253 .61663 m .32789 .61424 L .32716 .61605 L F
.224 0 .238 r
.32716 .61605 m .32789 .61424 L .32959 .61336 L F
.465 .128 .309 r
.35298 .65505 m .35524 .6547 L .3562 .65239 L F
.381 .048 .27 r
.3562 .65239 m .35731 .65413 L .35847 .65228 L F
.3562 .65239 m .35524 .6547 L .35731 .65413 L F
.118 .454 .885 r
.57352 .73021 m .57411 .72937 L .57259 .72909 L F
.57352 .73021 m .57637 .73161 L .57411 .72937 L F
0 .144 .621 r
.73506 .62613 m .73482 .6258 L .73383 .6252 L F
.73506 .62613 m .73584 .62669 L .73482 .6258 L F
.291 .401 .802 r
.58081 .74915 m .58342 .75088 L .58215 .74777 L F
.61 .652 .867 r
.73336 .59162 m .73343 .59289 L .73561 .59217 L F
.565 .415 .637 r
.57009 .69934 m .57249 .69903 L .57195 .69659 L F
.751 .695 .798 r
.72521 .71336 m .72813 .7143 L .7273 .71218 L F
.616 .659 .869 r
.72813 .7143 m .72978 .71183 L .7273 .71218 L F
.72813 .7143 m .73097 .7136 L .72978 .71183 L F
.612 .61 .825 r
.36703 .70228 m .36358 .69996 L .36571 .69945 L F
.57 .579 .823 r
.36788 .69878 m .36703 .70228 L .36571 .69945 L F
.36788 .69878 m .36918 .70196 L .36703 .70228 L F
.179 .71 .837 r
.59617 .71929 m .60014 .71921 L .59708 .72038 L F
.895 .699 .629 r
.47816 .75591 m .47625 .75897 L .47646 .75679 L F
.777 .527 .557 r
.48026 .75932 m .47625 .75897 L .47816 .75591 L F
.585 .256 .378 r
.54808 .74296 m .54709 .74557 L .54475 .74547 L F
.493 .165 .339 r
.54938 .74523 m .54808 .74296 L .55038 .74247 L F
.54938 .74523 m .54709 .74557 L .54808 .74296 L F
.443 .255 .53 r
.31856 .62494 m .32062 .62205 L .32038 .62437 L F
.417 .228 .514 r
.31837 .62722 m .31856 .62494 L .32038 .62437 L F
.717 .69 .824 r
.73571 .72824 m .73949 .72897 L .73878 .72639 L F
.689 .743 .893 r
.73878 .72639 m .73949 .72897 L .7423 .72691 L F
.425 .738 .992 r
.28038 .59093 m .27984 .59214 L .27833 .59123 L F
.28038 .59093 m .2819 .59199 L .27984 .59214 L F
.654 .586 .767 r
.44556 .66893 m .44329 .66943 L .44217 .66648 L F
.461 .224 .466 r
.52807 .74354 m .52782 .74562 L .52577 .74609 L F
.52807 .74354 m .52782 .74562 L .52577 .74609 L F
.586 .494 .717 r
.52923 .7413 m .53064 .74341 L .52807 .74354 L F
.393 .166 .447 r
.53045 .7443 m .52807 .74354 L .53064 .74341 L F
.53045 .7443 m .52782 .74562 L .52807 .74354 L F
.586 .494 .717 r
.52923 .7413 m .53064 .74341 L .52807 .74354 L F
.393 .166 .447 r
.52807 .74354 m .53045 .7443 L .53064 .74341 L F
.52807 .74354 m .52782 .74562 L .53045 .7443 L F
.396 0 .087 r
.54598 .75099 m .54826 .75076 L .54911 .74921 L F
.514 .253 .457 r
.66208 .53045 m .65941 .53353 L .65958 .53159 L F
.324 .122 .444 r
.29095 .63268 m .29303 .63005 L .29108 .63058 L F
0 0 .388 r
.57753 .70962 m .57626 .71276 L .57491 .71038 L F
.57703 .71085 m .57745 .71172 L .57626 .71276 L F
.297 .453 .848 r
.57745 .71172 m .57901 .71444 L .57626 .71276 L F
.608 .054 0 r
.57585 .7113 m .57805 .71296 L .57745 .71172 L F
.104 .567 .913 r
.57917 .71379 m .57901 .71444 L .57745 .71172 L F
.608 .054 0 r
.57805 .71296 m .57917 .71379 L .57745 .71172 L F
0 0 .388 r
.57753 .70962 m .57745 .71172 L .57703 .71085 L F
.823 .855 .872 r
.57079 .68152 m .57459 .68037 L .57263 .68037 L F
.57079 .68152 m .57186 .68249 L .57459 .68037 L F
.324 0 0 r
.57673 .67972 m .57263 .68037 L .57459 .68037 L F
.641 .242 .271 r
.49598 .79246 m .49928 .79252 L .49814 .79401 L F
.606 .186 .218 r
.49928 .79252 m .50015 .79449 L .49814 .79401 L F
.49928 .79252 m .50145 .79277 L .50015 .79449 L F
.355 .663 .972 r
.74208 .7102 m .73884 .70854 L .74208 .70934 L F
.248 .552 .93 r
.74208 .70934 m .743 .7093 L .74208 .7102 L F
.26 .52 .909 r
.74307 .70845 m .74208 .70934 L .73941 .70688 L F
0 0 .456 r
.74324 .70737 m .743 .7093 L .74328 .70854 L F
.26 .52 .909 r
.74328 .70854 m .74305 .70869 L .74307 .70845 L F
.74305 .70869 m .74208 .70934 L .74307 .70845 L F
.74305 .70869 m .743 .7093 L .74208 .70934 L F
.666 .201 .139 r
.74303 .70896 m .743 .7093 L .74301 .70923 L F
.26 .52 .909 r
.74328 .70854 m .743 .7093 L .74305 .70869 L F
.666 .201 .139 r
.7431 .70805 m .743 .7093 L .74303 .70896 L F
.331 0 0 r
.74071 .70752 m .74306 .70845 L .73941 .70688 L F
.74306 .70845 m .74328 .70854 L .74307 .70845 L F
.74306 .70845 m .74307 .70845 L .73941 .70688 L F
.666 .201 .139 r
.74308 .70831 m .74307 .70845 L .74324 .70737 L F
.74307 .70845 m .74311 .70844 L .74324 .70737 L F
.7431 .70805 m .74301 .70923 L .74311 .70801 L F
.771 .748 .833 r
.74306 .70845 m .74324 .70737 L .74328 .70854 L F
.74071 .70752 m .74324 .70737 L .74306 .70845 L F
.666 .201 .139 r
.74311 .70801 m .74308 .70831 L .74324 .70737 L F
.74307 .70845 m .74301 .70923 L .74311 .70844 L F
.74251 .71084 m .743 .7093 L .7431 .70805 L F
.201 .477 .892 r
.743 .7093 m .74622 .71303 L .74289 .71075 L F
.743 .7093 m .74289 .71075 L .74208 .7102 L F
.332 0 .23 r
.37228 .67439 m .37116 .67666 L .36932 .67636 L F
.337 .073 .357 r
.37081 .67847 m .36932 .67636 L .37116 .67666 L F
.37081 .67847 m .36903 .67917 L .36932 .67636 L F
.758 .545 .608 r
.44994 .74291 m .4533 .74553 L .45104 .74286 L F
.725 .982 .774 r
.46366 .77065 m .46234 .77135 L .4636 .77012 L F
.874 .723 .691 r
.63315 .51931 m .632 .51606 L .63123 .51762 L F
.493 0 .004 r
.53736 .79431 m .53936 .793 L .53549 .79329 L F
.92 .575 .368 r
.57287 .75714 m .57476 .76008 L .57346 .75772 L F
.497 .352 .613 r
.52801 .75943 m .52791 .76186 L .52601 .76003 L F
.52801 .75943 m .52791 .76186 L .52601 .76003 L F
.718 .537 .645 r
.47187 .75191 m .47295 .75441 L .46972 .75391 L F
.538 .254 .432 r
.6413 .53958 m .64355 .54095 L .64131 .54093 L F
.6413 .53958 m .64365 .53929 L .64355 .54095 L F
.574 .462 .688 r
.43249 .7679 m .43439 .76488 L .4325 .76528 L F
.767 .542 .593 r
.5279 .73655 m .52577 .73464 L .52843 .7357 L F
.474 .262 .51 r
.53135 .73421 m .5279 .73655 L .52843 .7357 L F
.544 .715 .952 r
.39604 .64916 m .39577 .65004 L .39421 .64921 L F
.39604 .64916 m .39785 .64967 L .39577 .65004 L F
.895 .592 .466 r
.62662 .54156 m .62832 .54207 L .62867 .54423 L F
.782 .4 .332 r
.62832 .54207 m .63178 .54442 L .62867 .54423 L F
.908 .778 .706 r
.46791 .75946 m .46482 .76167 L .46613 .75988 L F
.46791 .75946 m .46656 .76235 L .46482 .76167 L F
.54 .416 .66 r
.43975 .74629 m .44216 .7483 L .44185 .74584 L F
.51 .417 .686 r
.43975 .74629 m .44023 .74889 L .44216 .7483 L F
0 0 0 r
.61776 .74203 m .61721 .74399 L .61623 .74526 L F
.573 .834 .475 r
.61623 .74526 m .61721 .74399 L .61679 .74451 L F
0 0 0 r
.61705 .7434 m .61623 .74526 L .61571 .74597 L F
.573 .834 .475 r
.61623 .74526 m .61679 .74451 L .61493 .74678 L F
0 0 0 r
.61571 .74597 m .61623 .74526 L .6154 .74655 L F
.61843 .73996 m .61776 .74203 L .61705 .7434 L F
.61705 .7434 m .61776 .74203 L .61623 .74526 L F
.496 .871 .979 r
.30605 .72836 m .30561 .72818 L .30905 .72758 L F
.38 .43 .787 r
.74599 .59665 m .74576 .59781 L .74765 .59622 L F
0 0 .061 r
.74715 .59753 m .74765 .59622 L .74576 .59781 L F
.252 .234 .643 r
.32283 .72658 m .32359 .72324 L .32295 .7242 L F
.171 0 .003 r
.53543 .79801 m .53657 .79622 L .53874 .79536 L F
.531 .834 .999 r
.73279 .70839 m .72954 .70811 L .73167 .70732 L F
.515 .767 .988 r
.73407 .707 m .73279 .70839 L .73167 .70732 L F
.73407 .707 m .73514 .70804 L .73279 .70839 L F
.287 0 .042 r
.54274 .69589 m .54223 .69605 L .54356 .6944 L F
.357 0 .087 r
.54356 .6944 m .54579 .69465 L .54518 .69308 L F
.461 .303 .58 r
.75087 .59431 m .75096 .59677 L .74855 .59764 L F
.242 .292 .715 r
.75068 .59874 m .74855 .59764 L .75096 .59677 L F
0 .234 .75 r
.55251 .73789 m .55294 .73689 L .5524 .73686 L F
0 .04 .57 r
.55299 .74055 m .55294 .73689 L .55251 .73789 L F
.568 .441 .668 r
.36312 .6887 m .36062 .68507 L .36213 .68467 L F
.36312 .6887 m .3611 .68973 L .36062 .68507 L F
.55 .55 .807 r
.43256 .77904 m .4334 .77554 L .43112 .77604 L F
.43256 .77904 m .43462 .77868 L .4334 .77554 L F
.543 .481 .736 r
.43256 .77904 m .43515 .78195 L .43462 .77868 L F
.535 .272 .462 r
.41912 .69117 m .41871 .69318 L .41652 .69333 L F
.278 .046 .371 r
.42083 .69037 m .41871 .69318 L .41912 .69117 L F
.443 .142 .358 r
.42299 .6899 m .42135 .6886 L .42349 .68821 L F
.42299 .6899 m .42083 .69037 L .42135 .6886 L F
.604 .27 .377 r
.55528 .7597 m .55381 .76213 L .55079 .76187 L F
.488 .123 .273 r
.55704 .75941 m .55381 .76213 L .55528 .7597 L F
.534 .924 .874 r
.57087 .67704 m .57201 .676 L .57274 .67605 L F
.525 .905 .741 r
.57087 .67704 m .57028 .67719 L .57201 .676 L F
.818 .365 0 r
.72471 .6194 m .72447 .61985 L .72465 .61994 L F
0 0 0 r
.72471 .6194 m .72465 .61994 L .72642 .61808 L F
.96 .694 .485 r
.72273 .6152 m .72456 .61973 L .72276 .61825 L F
.72456 .61973 m .72465 .61994 L .72449 .6198 L F
.72456 .61973 m .72449 .6198 L .72276 .61825 L F
.621 .568 .774 r
.72642 .61808 m .72465 .61994 L .72456 .61973 L F
.622 .707 .907 r
.72517 .61905 m .72456 .61973 L .72471 .6194 L F
.72456 .61973 m .72452 .61976 L .72471 .6194 L F
.72642 .61808 m .72451 .61979 L .72517 .61905 L F
.621 .568 .774 r
.72642 .61808 m .72456 .61973 L .72273 .6152 L F
.622 .707 .907 r
.72456 .61973 m .72451 .61979 L .72452 .61976 L F
.72642 .61808 m .72447 .61985 L .72451 .61979 L F
.449 .033 .157 r
.46295 .78702 m .46384 .78891 L .46161 .78833 L F
.46295 .78702 m .46517 .78699 L .46384 .78891 L F
0 0 .171 r
.51495 .79053 m .51549 .79147 L .51836 .78978 L F
.81 .794 .838 r
.64279 .50695 m .63953 .50854 L .64203 .50552 L F
.615 .673 .882 r
.64502 .50603 m .64279 .50695 L .64203 .50552 L F
.934 .95 .622 r
.64502 .50603 m .6444 .50771 L .64279 .50695 L F
.705 .696 .838 r
.32824 .70821 m .32816 .71015 L .32628 .70743 L F
.961 .63 .327 r
.32628 .70743 m .32816 .71015 L .32607 .70875 L F
.32628 .70743 m .32816 .71015 L .32607 .70875 L F
.6 .54 .758 r
.3309 .71025 m .32867 .71075 L .32816 .71015 L F
.368 .446 .81 r
.51756 .74941 m .51864 .7485 L .51648 .7484 L F
.51756 .74941 m .51985 .75033 L .51864 .7485 L F
.438 .518 .843 r
.59355 .72574 m .59354 .72293 L .59238 .72345 L F
.211 .661 .949 r
.3168 .59676 m .31827 .59756 L .31482 .59659 L F
.436 .757 .995 r
.31884 .5964 m .31827 .59756 L .3168 .59676 L F
.31884 .5964 m .32019 .59739 L .31827 .59756 L F
.146 0 0 r
.29299 .59363 m .29644 .59428 L .29499 .594 L F
.49 .394 .673 r
.33778 .66136 m .34003 .66294 L .33959 .66125 L F
.33778 .66136 m .33815 .66335 L .34003 .66294 L F
.489 .715 .971 r
.73561 .59217 m .73921 .59362 L .7375 .59182 L F
.538 .734 .965 r
.7375 .59182 m .73921 .59362 L .74166 .59323 L F
.456 .833 .99 r
.49123 .76009 m .49337 .75942 L .4945 .7601 L F
.151 0 0 r
.49337 .75942 m .49123 .76009 L .4945 .7601 L F
.538 .873 .991 r
.4964 .75941 m .49337 .75942 L .4945 .7601 L F
.4964 .75941 m .49337 .75942 L .4945 .7601 L F
.153 0 0 r
.37897 .71672 m .3785 .71569 L .3805 .71511 L F
.37897 .71672 m .377 .71734 L .3785 .71569 L F
.829 .833 .85 r
.7389 .62193 m .73657 .62162 L .73876 .61924 L F
.77 .979 .913 r
.7389 .62193 m .73571 .62359 L .73657 .62162 L F
.899 .878 .806 r
.74011 .61997 m .7389 .62193 L .73876 .61924 L F
0 0 .171 r
.53961 .76191 m .53881 .76498 L .53799 .76337 L F
.67 .471 .607 r
.55032 .73626 m .54602 .73488 L .549 .73533 L F
.64 .165 .11 r
.549 .73533 m .5524 .73686 L .55032 .73626 L F
.45 .349 .648 r
.45576 .76908 m .45579 .773 L .45361 .77094 L F
0 0 .303 r
.5711 .74763 m .57189 .75107 L .57131 .74919 L F
.792 .409 .331 r
.58611 .72388 m .58919 .7258 L .58952 .72405 L F
.72 .614 .738 r
.47016 .75592 m .46807 .75738 L .46699 .7542 L F
.914 .69 .585 r
.61145 .68238 m .61136 .68546 L .61273 .68553 L F
.889 .586 .467 r
.6115 .6871 m .61273 .68553 L .61136 .68546 L F
.6115 .6871 m .61292 .68779 L .61273 .68553 L F
.884 .882 .826 r
.6279 .52915 m .62701 .53091 L .62612 .52946 L F
.982 .857 .639 r
.62612 .52946 m .62701 .53091 L .62634 .53205 L F
.551 .427 .664 r
.33104 .68266 m .33332 .68225 L .3329 .67964 L F
.552 .423 .659 r
.33143 .68582 m .33332 .68225 L .33104 .68266 L F
.488 .589 .881 r
.33615 .60499 m .33442 .60535 L .33279 .60256 L F
.508 .379 .64 r
.33615 .60499 m .33445 .60813 L .33442 .60535 L F
.656 .903 .574 r
.6154 .74655 m .61392 .748 L .61404 .74799 L F
.6154 .74655 m .61623 .74526 L .61392 .748 L F
.661 .796 .947 r
.52211 .74808 m .52387 .74945 L .52561 .7484 L F
.775 .646 .719 r
.70829 .58675 m .71058 .58366 L .70861 .5837 L F
.241 0 .238 r
.32283 .61924 m .3253 .61663 L .32495 .61869 L F
.573 .389 .594 r
.32716 .61605 m .32495 .61869 L .3253 .61663 L F
.7 .699 .845 r
.3342 .71309 m .33216 .71514 L .33011 .71097 L F
.835 .628 .623 r
.61457 .69083 m .61421 .69328 L .61727 .69363 L F
.859 .7 .684 r
.61421 .69328 m .61546 .69604 L .61727 .69363 L F
.547 .323 .527 r
.5283 .75722 m .52801 .75943 L .53056 .75701 L F
.95 .936 .743 r
.53528 .74725 m .53517 .74504 L .53687 .74606 L F
.165 .333 .788 r
.5369 .74853 m .53528 .74725 L .53687 .74606 L F
.84 .829 .837 r
.52937 .75969 m .52801 .75943 L .53056 .75701 L F
.853 .626 .594 r
.52937 .75969 m .52791 .76186 L .52801 .75943 L F
.52937 .75969 m .52962 .76238 L .52791 .76186 L F
.766 .523 .567 r
.52211 .74808 m .52561 .7484 L .52577 .74609 L F
0 0 0 r
.51394 .74583 m .51127 .74844 L .51046 .7468 L F
.51394 .74583 m .51258 .74766 L .51127 .74844 L F
.499 .027 .064 r
.5153 .74743 m .51394 .74583 L .51481 .74449 L F
.5153 .74743 m .51258 .74766 L .51394 .74583 L F
.486 .201 .406 r
.44304 .67592 m .4412 .67449 L .44352 .67437 L F
.44304 .67592 m .44074 .67637 L .4412 .67449 L F
.491 0 0 r
.50953 .72391 m .51088 .72516 L .50825 .72569 L F
.50953 .72391 m .51183 .72596 L .51088 .72516 L F
.646 .327 .418 r
.51208 .72414 m .51183 .72596 L .50953 .72391 L F
.718 .483 .569 r
.32804 .88994 m .33072 .88932 L .33011 .89194 L F
.33011 .89194 m .33072 .88932 L .32804 .88994 L F
.327 .116 .434 r
.33011 .89194 m .33072 .88932 L .33216 .88887 L F
.33216 .88887 m .33072 .88932 L .33011 .89194 L F
.513 .538 .819 r
.43259 .65475 m .43185 .65805 L .43055 .65494 L F
.43259 .65475 m .43382 .65786 L .43185 .65805 L F
.589 .59 .821 r
.36433 .6964 m .36358 .69996 L .36261 .69617 L F
.36433 .6964 m .36571 .69945 L .36358 .69996 L F
.518 .044 .067 r
.39585 .66513 m .39235 .66536 L .39322 .66546 L F
.557 .555 .808 r
.29992 .60844 m .30099 .61145 L .30266 .61001 L F
.555 .509 .759 r
.30168 .61373 m .30266 .61001 L .30099 .61145 L F
.844 .683 .683 r
.54726 .69413 m .54838 .69652 L .54993 .69512 L F
.774 .302 .12 r
.54838 .69652 m .55307 .69648 L .54993 .69512 L F
0 .408 .755 r
.55307 .69648 m .54726 .69413 L .54993 .69512 L F
.537 .281 .474 r
.48488 .73253 m .48718 .73221 L .48711 .72981 L F
.494 .216 .421 r
.48718 .73221 m .49017 .72885 L .48711 .72981 L F
.368 0 .054 r
.57901 .71444 m .58087 .71471 L .58158 .713 L F
.497 .042 .101 r
.58158 .713 m .58324 .71421 L .58382 .7125 L F
.58158 .713 m .58087 .71471 L .58324 .71421 L F
.72 .614 .738 r
.47016 .75592 m .46699 .7542 L .46972 .75391 L F
.7 .617 .76 r
.47295 .75441 m .47016 .75592 L .46972 .75391 L F
.555 .509 .759 r
.30168 .61373 m .30373 .61328 L .30266 .61001 L F
.534 .454 .712 r
.30168 .61373 m .30442 .61583 L .30373 .61328 L F
.30168 .61373 m .30216 .61657 L .30442 .61583 L F
.14 .452 .883 r
.56337 .76027 m .56394 .75942 L .5623 .75866 L F
.896 .547 .375 r
.56533 .75941 m .56394 .75942 L .56337 .76027 L F
.417 .075 .275 r
.3736 .67589 m .37228 .67439 L .37407 .67351 L F
.3736 .67589 m .37116 .67666 L .37228 .67439 L F
.899 .878 .806 r
.74011 .61997 m .73876 .61924 L .74026 .61783 L F
.601 .513 .728 r
.73427 .7157 m .73495 .71901 L .73765 .71846 L F
.486 .583 .877 r
.73495 .71901 m .73805 .72032 L .73765 .71846 L F
.487 0 0 r
.57167 .75698 m .57029 .75623 L .56747 .7542 L F
0 0 .223 r
.57167 .75698 m .57147 .75976 L .57182 .75842 L F
.889 .671 .601 r
.57182 .75842 m .57029 .75623 L .57167 .75698 L F
.663 .588 .76 r
.57255 .7546 m .57287 .75714 L .57167 .75698 L F
.505 .319 .562 r
.44206 .74328 m .44403 .74499 L .44468 .74286 L F
.44206 .74328 m .44185 .74584 L .44403 .74499 L F
.983 .878 .65 r
.54327 .69929 m .54248 .69867 L .54274 .69589 L F
.968 .645 .295 r
.54327 .69929 m .54282 .70115 L .54248 .69867 L F
.54327 .69929 m .54403 .7023 L .54282 .70115 L F
.256 .643 .964 r
.51006 .78968 m .51136 .79086 L .50924 .79059 L F
.497 .253 .474 r
.29592 .62735 m .29793 .627 L .29841 .62489 L F
.334 .106 .411 r
.29841 .62489 m .29945 .62639 L .29987 .62408 L F
.29841 .62489 m .29793 .627 L .29945 .62639 L F
.488 .123 .273 r
.55704 .75941 m .55595 .76206 L .55381 .76213 L F
.494 .656 .932 r
.73373 .72775 m .7357 .7263 L .7332 .72734 L F
.73373 .72775 m .73571 .72824 L .7357 .7263 L F
.903 .789 .725 r
.72114 .71516 m .72242 .71576 L .72167 .71268 L F
.625 .74 .93 r
.71921 .71763 m .72242 .71576 L .72114 .71516 L F
.71921 .71763 m .72277 .71805 L .72242 .71576 L F
.732 .695 .815 r
.72167 .71268 m .72242 .71576 L .72521 .71336 L F
.565 .751 .965 r
.71504 .72031 m .71821 .72124 L .7167 .72039 L F
.564 .43 .657 r
.71821 .72124 m .7177 .71826 L .7167 .72039 L F
.71821 .72124 m .72028 .71834 L .7177 .71826 L F
.71821 .72124 m .72054 .72084 L .72028 .71834 L F
.515 .056 .101 r
.5195 .79184 m .51836 .78978 L .51549 .79147 L F
.5195 .79184 m .52055 .78992 L .51836 .78978 L F
.41 .45 .79 r
.7344 .72022 m .73343 .72298 L .73209 .72034 L F
.7344 .72022 m .73528 .72363 L .73343 .72298 L F
.594 .392 .577 r
.52069 .76249 m .52117 .76544 L .51777 .76519 L F
.583 .615 .85 r
.5234 .76192 m .52069 .76249 L .51924 .76115 L F
.5234 .76192 m .52304 .76249 L .52069 .76249 L F
.725 .559 .665 r
.52304 .76249 m .52117 .76544 L .52069 .76249 L F
.469 .123 .296 r
.26228 .6078 m .25939 .61021 L .2603 .60832 L F
.13 0 0 r
.38275 .6694 m .38236 .66834 L .38446 .66764 L F
.38275 .6694 m .38063 .67004 L .38236 .66834 L F
.887 .711 .659 r
.60168 .69953 m .60227 .7025 L .59895 .70013 L F
.952 .673 .473 r
.60227 .7025 m .60033 .70319 L .59895 .70013 L F
.60227 .7025 m .60178 .70409 L .60033 .70319 L F
.461 .272 .537 r
.30216 .61657 m .30392 .61792 L .30442 .61583 L F
.30216 .61657 m .30193 .61865 L .30392 .61792 L F
0 0 .472 r
.5849 .72059 m .58398 .7237 L .58325 .72064 L F
.5849 .72059 m .58507 .72303 L .58398 .7237 L F
.301 .715 .975 r
.58398 .7237 m .58507 .72303 L .58611 .72388 L F
.419 0 0 r
.51368 .70838 m .5159 .70862 L .51721 .7076 L F
.539 .093 .138 r
.5159 .70862 m .51946 .70733 L .51721 .7076 L F
0 .471 .822 r
.46149 .77678 m .46051 .77682 L .45932 .77609 L F
.46149 .77678 m .46278 .77754 L .46051 .77682 L F
.543 .185 .31 r
.47746 .78111 m .47991 .78106 L .48119 .77839 L F
.732 .204 0 r
.48166 .78147 m .48119 .77839 L .48308 .77854 L F
.584 .277 .415 r
.47991 .78106 m .48308 .77854 L .48119 .77839 L F
.584 .475 .696 r
.27641 .68466 m .2767 .68453 L .27714 .68543 L F
.624 .43 .599 r
.2767 .68453 m .27633 .68588 L .27714 .68543 L F
.49 .199 .398 r
.6388 .54142 m .64041 .54359 L .63838 .54413 L F
.6388 .54142 m .64131 .54093 L .64041 .54359 L F
.617 .707 .909 r
.46631 .77846 m .46403 .77918 L .46278 .77754 L F
.776 .567 .616 r
.49675 .78954 m .50043 .7868 L .49674 .78717 L F
.49675 .78954 m .50016 .78988 L .50043 .7868 L F
0 0 0 r
.5395 .76451 m .54141 .76398 L .54058 .76443 L F
.5395 .76451 m .54058 .76443 L .54023 .76442 L F
0 0 .171 r
.53961 .76191 m .5395 .76451 L .53891 .76459 L F
0 0 0 r
.5395 .76451 m .54023 .76442 L .53804 .76432 L F
0 0 .171 r
.53891 .76459 m .5395 .76451 L .53881 .76498 L F
0 .171 .706 r
.5395 .76451 m .54075 .76704 L .53881 .76498 L F
.874 .654 .601 r
.58827 .70705 m .59114 .71033 L .59166 .70736 L F
.58827 .70705 m .58963 .70996 L .59114 .71033 L F
.873 .669 .624 r
.58963 .70996 m .58949 .71231 L .59114 .71033 L F
.841 .688 .692 r
.61858 .70153 m .6199 .70467 L .62035 .70232 L F
.516 .014 .003 r
.52176 .79534 m .52485 .7952 L .52427 .79603 L F
.611 .192 .224 r
.72671 .61995 m .72963 .62132 L .73037 .61933 L F
0 .046 .58 r
.73192 .62026 m .73184 .6219 L .73037 .61933 L F
.73192 .62026 m .73037 .61933 L .72963 .62132 L F
.585 .704 .925 r
.289 .60329 m .29119 .60568 L .29244 .60386 L F
.389 .434 .787 r
.29119 .60568 m .29311 .60619 L .29244 .60386 L F
.662 .259 .27 r
.46517 .78699 m .46878 .78683 L .46741 .78881 L F
.698 .301 .292 r
.46741 .78881 m .46878 .78683 L .47073 .78889 L F
.292 .394 .795 r
.59331 .73394 m .5921 .73596 L .59068 .73453 L F
.344 0 0 r
.59339 .75935 m .59447 .75984 L .59674 .761 L F
.648 .87 .982 r
.31971 .72875 m .32117 .72949 L .31762 .72956 L F
.31971 .72875 m .32117 .72949 L .31762 .72956 L F
.763 .555 .616 r
.31971 .72875 m .32283 .72658 L .32117 .72949 L F
.448 .798 .998 r
.31971 .72875 m .32332 .72915 L .32117 .72949 L F
.514 .301 .528 r
.43036 .68415 m .42876 .68256 L .43088 .68217 L F
.43036 .68415 m .42886 .68449 L .42876 .68256 L F
.343 0 0 r
.73942 .58451 m .73655 .58418 L .73933 .58451 L F
0 .395 .712 r
.7414 .5851 m .74248 .58552 L .73942 .58451 L F
.7414 .5851 m .73942 .58451 L .73933 .58451 L F
.412 .194 .47 r
.32062 .62205 m .32283 .61924 L .32254 .62147 L F
.458 .257 .518 r
.32038 .62437 m .32062 .62205 L .32254 .62147 L F
.542 .379 .611 r
.43121 .77355 m .43336 .77318 L .43323 .77071 L F
.57 .367 .567 r
.43121 .77355 m .4334 .77554 L .43336 .77318 L F
.43121 .77355 m .43112 .77604 L .4334 .77554 L F
.657 .209 .175 r
.49249 .79219 m .49598 .79246 L .49453 .7931 L F
.656 .207 .174 r
.49453 .7931 m .49598 .79246 L .49814 .79401 L F
.558 .544 .795 r
.73427 .7157 m .73579 .71187 L .73288 .71233 L F
.73427 .7157 m .73656 .71516 L .73579 .71187 L F
.601 .513 .728 r
.73427 .7157 m .73765 .71846 L .73656 .71516 L F
.466 .223 .46 r
.49258 .72664 m .49465 .72618 L .495 .72405 L F
.487 .241 .466 r
.495 .72405 m .49465 .72618 L .49715 .72365 L F
.554 .395 .621 r
.3342 .67378 m .33633 .67101 L .33444 .67162 L F
.885 .981 .823 r
.74652 .72318 m .74892 .72133 L .74863 .72043 L F
.374 .567 .912 r
.7162 .58509 m .71741 .587 L .72031 .58763 L F
.565 .78 .98 r
.28439 .60238 m .28767 .60297 L .2861 .60255 L F
0 .432 .705 r
.2861 .60255 m .28767 .60297 L .289 .60329 L F
.663 .707 .88 r
.55752 .69662 m .56152 .69756 L .55981 .69662 L F
.712 .815 .929 r
.56366 .6964 m .56152 .69756 L .55981 .69662 L F
.56366 .6964 m .56152 .69756 L .55981 .69662 L F
.638 .481 .653 r
.57195 .69659 m .57418 .69385 L .57116 .69343 L F
.57195 .69659 m .57509 .69671 L .57418 .69385 L F
.637 .462 .629 r
.57195 .69659 m .57249 .69903 L .57509 .69671 L F
.941 .702 .549 r
.35484 .72559 m .35369 .72605 L .35558 .72543 L F
.434 .794 .996 r
.35294 .72635 m .35369 .72605 L .35131 .72606 L F
.941 .702 .549 r
.35116 .72637 m .35369 .72605 L .35484 .72559 L F
.434 .794 .996 r
.35498 .72672 m .35369 .72605 L .35294 .72635 L F
.349 .619 .952 r
.35498 .72672 m .35558 .72543 L .35369 .72605 L F
.35498 .72672 m .35635 .72569 L .35558 .72543 L F
.754 .743 .843 r
.52566 .7625 m .52699 .76543 L .52362 .76499 L F
.737 .763 .873 r
.52624 .76418 m .52699 .76543 L .52362 .76499 L F
.422 .383 .71 r
.52791 .76186 m .52699 .76543 L .52566 .7625 L F
.52791 .76186 m .52905 .76488 L .52699 .76543 L F
.101 0 0 r
.52699 .76543 m .52905 .76488 L .52804 .76607 L F
.52699 .76543 m .52804 .76607 L .52624 .76418 L F
.613 .326 .459 r
.46888 .73951 m .47164 .73773 L .46927 .73798 L F
.216 .73 .694 r
.38459 .70177 m .3851 .70163 L .38596 .70125 L F
.358 .792 .967 r
.38297 .70144 m .38552 .70153 L .3851 .70163 L F
.087 0 0 r
.3851 .70163 m .38645 .70156 L .38785 .70046 L F
.358 .792 .967 r
.38552 .70153 m .38645 .70156 L .3851 .70163 L F
.216 .73 .694 r
.38401 .70199 m .3851 .70163 L .38459 .70177 L F
.38401 .70199 m .38205 .70253 L .3851 .70163 L F
.587 .294 .438 r
.46482 .76167 m .46231 .76194 L .46262 .75977 L F
.637 .272 .335 r
.46613 .75988 m .46482 .76167 L .46262 .75977 L F
.415 .077 .281 r
.41996 .6735 m .4229 .67136 L .42053 .67152 L F
.398 .203 .496 r
.48693 .77608 m .48537 .77601 L .48548 .77362 L F
.788 .32 .126 r
.48433 .77457 m .48693 .77608 L .48548 .77362 L F
.482 .082 .205 r
.51049 .73419 m .51418 .73205 L .51126 .73267 L F
.51049 .73419 m .51291 .73399 L .51339 .73314 L F
.51252 .73301 m .51339 .73314 L .51394 .73219 L F
.51049 .73419 m .51339 .73314 L .51252 .73301 L F
.51394 .73219 m .51291 .73399 L .51418 .73205 L F
.74 .376 .364 r
.51346 .73315 m .51635 .73434 L .51418 .73205 L F
.416 .55 .882 r
.51339 .73314 m .5135 .73317 L .51291 .73399 L F
.74 .376 .364 r
.51398 .7341 m .51537 .73424 L .514 .73402 L F
.51291 .73399 m .51502 .73404 L .5135 .73317 L F
.51537 .73424 m .51635 .73434 L .51346 .73315 L F
.753 .5 .55 r
.51395 .73576 m .51635 .73434 L .51419 .73412 L F
.74 .376 .364 r
.514 .73402 m .51537 .73424 L .51502 .73404 L F
.753 .5 .55 r
.51289 .73639 m .51627 .73661 L .51635 .73434 L F
.236 .068 .438 r
.51462 .73571 m .51503 .73299 L .51501 .733 L F
0 0 .153 r
.51429 .73345 m .51506 .73263 L .51462 .73571 L F
.51428 .73341 m .51429 .73339 L .51429 .73345 L F
.753 .5 .55 r
.51289 .73639 m .51395 .73576 L .51398 .7341 L F
.51395 .73576 m .51419 .73412 L .51398 .7341 L F
.024 0 .159 r
.514 .73402 m .51289 .73639 L .51291 .73399 L F
.753 .5 .55 r
.51289 .73639 m .51398 .7341 L .51291 .73399 L F
.024 0 .159 r
.51424 .73354 m .51462 .73571 L .51357 .73612 L F
.51428 .73341 m .51429 .73345 L .51424 .73354 L F
.51429 .73345 m .51462 .73571 L .51424 .73354 L F
.514 .73402 m .51357 .73612 L .51289 .73639 L F
.51428 .73341 m .51357 .73612 L .514 .73402 L F
.74 .376 .364 r
.51291 .73399 m .51398 .7341 L .514 .73402 L F
.024 0 .159 r
.51428 .73341 m .514 .73402 L .51291 .73399 L F
.416 .55 .882 r
.5135 .73317 m .51428 .73341 L .51291 .73399 L F
.74 .376 .364 r
.51291 .73399 m .5135 .73317 L .51346 .73315 L F
.416 .55 .882 r
.51339 .73314 m .51426 .73326 L .51428 .73341 L F
0 .138 .671 r
.51389 .73046 m .51541 .73226 L .51428 .73341 L F
.236 .068 .438 r
.51462 .73571 m .51501 .733 L .51321 .73334 L F
0 0 .133 r
.51541 .73226 m .51503 .73299 L .51462 .73571 L F
0 0 .153 r
.51506 .73263 m .51541 .73226 L .51462 .73571 L F
.5152 .73247 m .5152 .73249 L .51429 .73345 L F
.416 .55 .882 r
.51322 .73301 m .51389 .73046 L .51426 .73326 L F
.51199 .7327 m .51426 .73326 L .51339 .73314 L F
.294 .301 .697 r
.51321 .73334 m .51501 .733 L .51389 .73046 L F
.51501 .733 m .51503 .73299 L .51502 .73297 L F
.51501 .733 m .51502 .73297 L .51389 .73046 L F
0 0 .153 r
.51429 .73339 m .5152 .73247 L .51429 .73345 L F
.5152 .73247 m .51541 .73226 L .5152 .73249 L F
.416 .55 .882 r
.51199 .7327 m .51222 .73243 L .51322 .73301 L F
.51222 .73243 m .51389 .73046 L .51322 .73301 L F
.51199 .7327 m .51339 .73314 L .51291 .73399 L F
.204 .728 .736 r
.36643 .64952 m .36832 .64907 L .36991 .64875 L F
.504 0 0 r
.36991 .64875 m .36832 .64907 L .37186 .64929 L F
.218 0 0 r
.55819 .70978 m .55441 .70991 L .55524 .70976 L F
.831 .453 .338 r
.51461 .76416 m .51777 .76519 L .51729 .76652 L F
.357 0 0 r
.51777 .76519 m .51948 .76581 L .51729 .76652 L F
.768 .977 .708 r
.51786 .76576 m .51664 .76685 L .51729 .76652 L F
.51902 .76422 m .5174 .76602 L .51786 .76576 L F
.5174 .76602 m .51664 .76685 L .51786 .76576 L F
.357 0 0 r
.51844 .76543 m .52117 .76544 L .51948 .76581 L F
.51777 .76519 m .51874 .76526 L .51844 .76543 L F
.51874 .76526 m .52117 .76544 L .51844 .76543 L F
.753 .339 .266 r
.52744 .71799 m .53087 .71868 L .5284 .71797 L F
.193 0 0 r
.53087 .71868 m .52769 .7204 L .52744 .71799 L F
.53087 .71868 m .52974 .72002 L .52769 .7204 L F
0 0 0 r
.53087 .71868 m .53144 .71863 L .53275 .71926 L F
.53087 .71868 m .52974 .72002 L .53144 .71863 L F
.198 .343 .786 r
.47617 .77792 m .47531 .77973 L .47431 .77805 L F
.47617 .77792 m .47746 .78111 L .47531 .77973 L F
.644 .126 0 r
.50145 .79277 m .50229 .79453 L .50015 .79449 L F
.50145 .79277 m .50363 .79421 L .50229 .79453 L F
.51 .407 .673 r
.57681 .6957 m .57509 .69671 L .57418 .69385 L F
.585 .544 .775 r
.75235 .5911 m .75018 .59196 L .74924 .58863 L F
.313 .181 .535 r
.75235 .5911 m .75087 .59431 L .75018 .59196 L F
.946 .954 .735 r
.61909 .71773 m .62098 .71578 L .62033 .71486 L F
.61909 .71773 m .61927 .7182 L .62098 .71578 L F
.718 .483 .569 r
.32804 .88994 m .33011 .89194 L .32805 .89237 L F
.33011 .89194 m .32804 .88994 L .32805 .89237 L F
.93 .674 .53 r
.56783 .7664 m .56651 .7675 L .56665 .76424 L F
.547 .817 .996 r
.37568 .70341 m .37261 .70334 L .37474 .70294 L F
.464 .771 .997 r
.37697 .70254 m .37568 .70341 L .37474 .70294 L F
.37697 .70254 m .37787 .70328 L .37568 .70341 L F
.271 .293 .701 r
.57402 .75465 m .57287 .75714 L .57255 .7546 L F
.885 .599 .498 r
.57182 .75842 m .57287 .75714 L .57402 .75465 L F
.57182 .75842 m .57476 .76008 L .57287 .75714 L F
.876 .829 .358 r
.57413 .76032 m .57476 .76008 L .57182 .75842 L F
.57413 .76032 m .57418 .76201 L .57476 .76008 L F
.397 .68 .974 r
.28754 .59271 m .28557 .5929 L .28392 .59145 L F
.145 0 0 r
.36397 .72334 m .36278 .72312 L .36476 .72265 L F
.36397 .72334 m .36199 .72393 L .36278 .72312 L F
.507 .332 .579 r
.43385 .7625 m .436 .75954 L .43396 .76003 L F
.747 .4 .394 r
.49309 .75417 m .49525 .75711 L .49235 .75594 L F
.701 .215 0 r
.49581 .75748 m .49309 .75417 L .49718 .75501 L F
.49581 .75748 m .49525 .75711 L .49309 .75417 L F
.638 .688 .88 r
.40193 .66551 m .40492 .66639 L .40371 .66513 L F
.604 .85 .991 r
.40492 .66639 m .40572 .66489 L .40371 .66513 L F
.40492 .66639 m .40707 .66569 L .40572 .66489 L F
.508 .254 .464 r
.4376 .75137 m .43978 .751 L .44023 .74889 L F
.511 .295 .522 r
.43978 .751 m .44216 .7483 L .44023 .74889 L F
.599 .46 .664 r
.33097 .6963 m .33327 .69603 L .3331 .69345 L F
.631 .508 .694 r
.33126 .69871 m .33327 .69603 L .33097 .6963 L F
.245 0 0 r
.35212 .65594 m .35298 .65505 L .35083 .65544 L F
.258 0 0 r
.35212 .65594 m .35083 .65544 L .34909 .65659 L F
.672 .221 .173 r
.34522 .73305 m .3434 .73402 L .34145 .73259 L F
.948 .738 .586 r
.34365 .73157 m .34522 .73305 L .34676 .73151 L F
.34365 .73157 m .3434 .73402 L .34522 .73305 L F
.295 .787 .885 r
.26988 .64494 m .27183 .64457 L .27406 .64466 L F
.503 .896 .948 r
.27406 .64466 m .27445 .64382 L .27578 .64374 L F
.27406 .64466 m .27183 .64457 L .27445 .64382 L F
.472 .231 .467 r
.32283 .61924 m .32445 .62082 L .32254 .62147 L F
.32283 .61924 m .32495 .61869 L .32445 .62082 L F
.926 .547 .261 r
.31957 .71807 m .31828 .71776 L .31743 .71534 L F
.828 .37 0 r
.31957 .71807 m .31946 .71913 L .31828 .71776 L F
.31957 .71807 m .3208 .72034 L .31946 .71913 L F
.225 .746 .782 r
.27588 .65523 m .27619 .65538 L .27839 .65519 L F
.27588 .65523 m .27366 .65566 L .27619 .65538 L F
.696 .57 .71 r
.4446 .74091 m .44468 .74286 L .44782 .74133 L F
.41 .113 .346 r
.44468 .74286 m .44403 .74499 L .44645 .74275 L F
.599 .409 .596 r
.44579 .67054 m .44589 .6742 L .44352 .67437 L F
.574 .463 .69 r
.44771 .66823 m .44579 .67054 L .44556 .66893 L F
.44771 .66823 m .448 .67006 L .44579 .67054 L F
.549 .371 .592 r
.448 .67006 m .44589 .6742 L .44579 .67054 L F
.217 .735 .861 r
.32099 .85941 m .31954 .85923 L .31694 .85952 L F
.624 .721 .917 r
.32273 .85858 m .32099 .85941 L .31879 .85692 L F
.847 .975 .873 r
.32094 .85774 m .32099 .85941 L .32273 .85858 L F
.624 .721 .917 r
.32273 .85858 m .31879 .85692 L .32094 .85774 L F
.847 .975 .873 r
.32094 .85774 m .31954 .85923 L .32099 .85941 L F
.446 .805 .996 r
.50372 .79023 m .50016 .78988 L .50255 .79017 L F
.609 .728 .93 r
.32722 .60039 m .32387 .59936 L .32582 .59939 L F
.291 .57 .934 r
.32781 .59916 m .32722 .60039 L .32582 .59939 L F
.32781 .59916 m .32965 .601 L .32722 .60039 L F
0 .328 .78 r
.3307 .60277 m .32722 .60039 L .32965 .601 L F
.186 .453 .878 r
.33133 .60165 m .3307 .60277 L .32965 .601 L F
.43 .758 .996 r
.33133 .60165 m .33279 .60256 L .3307 .60277 L F
.944 .703 .543 r
.59862 .68262 m .59715 .68441 L .59737 .682 L F
.59862 .68262 m .59856 .68513 L .59715 .68441 L F
.436 .039 .186 r
.46966 .77913 m .4716 .77965 L .47181 .77865 L F
.46966 .77913 m .46836 .78124 L .4716 .77965 L F
.646 .93 .661 r
.55915 .74459 m .55751 .74635 L .55849 .74503 L F
.395 .212 .511 r
.55659 .74776 m .55849 .74503 L .55751 .74635 L F
.327 .033 .304 r
.29592 .62735 m .29709 .62879 L .29793 .627 L F
.29592 .62735 m .29526 .6295 L .29709 .62879 L F
.472 .13 .306 r
.57992 .67324 m .5829 .67062 L .58109 .67167 L F
.818 .977 .683 r
.59406 .73227 m .59509 .7299 L .59639 .72926 L F
.59406 .73227 m .59404 .73167 L .59509 .7299 L F
.953 .615 .334 r
.59406 .73227 m .59331 .73394 L .59404 .73167 L F
.59406 .73227 m .59467 .73464 L .59331 .73394 L F
.39 .689 .979 r
.73154 .62507 m .73383 .6252 L .73258 .62406 L F
.455 .162 .377 r
.26529 .60542 m .26558 .60735 L .26228 .6078 L F
.522 .206 .373 r
.26729 .60645 m .26529 .60542 L .26736 .6054 L F
.26729 .60645 m .26558 .60735 L .26529 .60542 L F
0 0 .148 r
.62028 .72564 m .61919 .72921 L .61874 .72683 L F
.695 .736 .226 r
.49864 .75422 m .49969 .75072 L .50093 .75141 L F
.49864 .75422 m .49865 .75407 L .49969 .75072 L F
.149 .692 .771 r
.49791 .75421 m .49865 .75407 L .49864 .75422 L F
.556 .427 .659 r
.33821 .66576 m .34003 .66294 L .33815 .66335 L F
0 0 0 r
.42557 .66905 m .42439 .67001 L .42717 .66814 L F
.12 .661 .841 r
.58441 .67781 m .58124 .67755 L .5822 .67788 L F
.892 .663 .584 r
.61686 .70079 m .61866 .69913 L .61698 .69849 L F
.61686 .70079 m .61858 .70153 L .61866 .69913 L F
.875 .518 .371 r
.60035 .66821 m .60343 .67137 L .60374 .66895 L F
.642 .106 0 r
.55651 .7416 m .55483 .74197 L .55299 .74055 L F
.807 .999 .84 r
.55742 .73962 m .55651 .7416 L .55846 .74072 L F
.55742 .73962 m .55483 .74197 L .55651 .7416 L F
.315 0 0 r
.38618 .71244 m .3847 .71408 L .3826 .71441 L F
.267 0 0 r
.38686 .7136 m .38618 .71244 L .38825 .71203 L F
.38686 .7136 m .3847 .71408 L .38618 .71244 L F
.927 .746 .639 r
.6031 .71263 m .60096 .71471 L .60215 .71152 L F
.6031 .71263 m .60263 .71557 L .60096 .71471 L F
.582 .153 .191 r
.50579 .7944 m .50709 .7927 L .50935 .79382 L F
.753 .855 .416 r
.56646 .75594 m .56606 .75723 L .56747 .7542 L F
0 0 .384 r
.56646 .75594 m .56533 .75941 L .56606 .75723 L F
0 .559 .789 r
.26027 .58708 m .25817 .58686 L .25658 .58648 L F
.246 .363 .785 r
.74899 .71439 m .74799 .71603 L .74704 .71317 L F
0 .144 .673 r
.74907 .71607 m .74799 .71603 L .74899 .71439 L F
.74907 .71607 m .74946 .71846 L .74799 .71603 L F
.743 .742 .851 r
.3299 .70673 m .33297 .70775 L .33291 .70493 L F
.539 .461 .716 r
.33291 .70493 m .33432 .70131 L .33223 .70173 L F
.33291 .70493 m .33481 .70476 L .33432 .70131 L F
.555 .454 .695 r
.33291 .70493 m .33703 .70657 L .33481 .70476 L F
.33291 .70493 m .33297 .70775 L .33703 .70657 L F
.451 0 0 r
.51596 .79432 m .51991 .79489 L .51836 .79488 L F
.452 0 0 r
.51991 .79489 m .52176 .79534 L .51836 .79488 L F
.476 .779 .997 r
.57006 .77 m .57133 .77094 L .57252 .76974 L F
.28 .479 .875 r
.32319 .70939 m .32405 .70698 L .32257 .70814 L F
.6 .376 .548 r
.5187 .7292 m .52105 .72908 L .52104 .72689 L F
.707 .462 .551 r
.52104 .72689 m .52609 .72862 L .52371 .7263 L F
.52104 .72689 m .52105 .72908 L .52609 .72862 L F
.548 .455 .701 r
.33223 .70173 m .33387 .6989 L .33126 .69871 L F
.33223 .70173 m .33432 .70131 L .33387 .6989 L F
0 0 0 r
.49963 .75895 m .49869 .75916 L .4964 .75941 L F
.746 .993 .82 r
.50082 .75722 m .49963 .75895 L .50229 .75842 L F
.50082 .75722 m .49869 .75916 L .49963 .75895 L F
.43 .097 .297 r
.41871 .69318 m .41574 .69575 L .41652 .69333 L F
.606 .348 .5 r
.4533 .74553 m .45557 .74566 L .4558 .74333 L F
.574 .287 .441 r
.45557 .74566 m .45881 .74281 L .4558 .74333 L F
.743 .742 .851 r
.3299 .70673 m .3318 .70812 L .33297 .70775 L F
.628 .361 .495 r
.3318 .70812 m .33323 .70954 L .33297 .70775 L F
.804 .807 .853 r
.71153 .59205 m .71342 .59339 L .71495 .59143 L F
0 0 0 r
.71497 .59189 m .71342 .59339 L .71495 .59143 L F
.71497 .59201 m .71462 .59233 L .71497 .59189 L F
.71462 .59233 m .71342 .59339 L .71497 .59189 L F
.804 .807 .853 r
.71153 .59205 m .71495 .59143 L .71357 .59191 L F
.71203 .59203 m .71357 .59191 L .71337 .59198 L F
.71153 .59205 m .71357 .59191 L .71203 .59203 L F
.353 0 0 r
.71761 .59332 m .71495 .59143 L .71689 .59028 L F
0 0 0 r
.71495 .59143 m .71515 .59189 L .71517 .59187 L F
.353 0 0 r
.71761 .59332 m .71524 .59202 L .71517 .59187 L F
.71707 .59294 m .71517 .59187 L .71495 .59143 L F
.71761 .59332 m .71517 .59187 L .71707 .59294 L F
0 0 0 r
.71495 .59143 m .71517 .59187 L .71689 .59028 L F
.676 .637 .804 r
.71526 .59178 m .71517 .59187 L .7151 .59179 L F
.71517 .59187 m .71515 .59189 L .71513 .59185 L F
.353 0 0 r
.71524 .59202 m .71507 .59192 L .71504 .5918 L F
.586 .126 .128 r
.71495 .59143 m .71497 .59189 L .71515 .59189 L F
.353 0 0 r
.71517 .59187 m .71504 .5918 L .71495 .59143 L F
.684 .641 .801 r
.71513 .59185 m .71515 .59189 L .71504 .5918 L F
.353 0 0 r
.71524 .59202 m .71504 .5918 L .71517 .59187 L F
.684 .641 .801 r
.71504 .5918 m .71515 .59189 L .71497 .59189 L F
.71508 .59175 m .71513 .59185 L .71504 .5918 L F
.676 .637 .804 r
.71517 .59187 m .71513 .59185 L .7151 .59179 L F
.71689 .59028 m .71526 .59178 L .7131 .5879 L F
.586 .126 .128 r
.71495 .59143 m .71107 .59198 L .71354 .59192 L F
.676 .637 .804 r
.71526 .59178 m .7151 .59179 L .7131 .5879 L F
.586 .126 .128 r
.71495 .59143 m .71354 .59192 L .71497 .59189 L F
0 0 0 r
.71507 .59192 m .71497 .59201 L .71495 .59143 L F
.684 .641 .801 r
.71508 .59175 m .71504 .5918 L .71107 .59198 L F
.71504 .5918 m .71497 .59189 L .71354 .59192 L F
.71504 .5918 m .71354 .59192 L .71107 .59198 L F
.804 .807 .853 r
.71337 .59198 m .71354 .59192 L .71507 .59192 L F
.71354 .59192 m .71495 .59143 L .71504 .5918 L F
.71354 .59192 m .71504 .5918 L .71507 .59192 L F
.684 .641 .801 r
.71301 .58808 m .71508 .59175 L .71107 .59198 L F
.99 .778 .521 r
.71023 .58864 m .71107 .59198 L .71187 .59027 L F
.684 .641 .801 r
.7131 .5879 m .71107 .59198 L .71023 .58864 L F
.231 0 0 r
.71283 .58893 m .7103 .58865 L .70961 .58932 L F
.7103 .58865 m .71023 .58864 L .7102 .58867 L F
.7103 .58865 m .7102 .58867 L .70961 .58932 L F
.684 .641 .801 r
.7131 .5879 m .71318 .58805 L .71301 .58808 L F
.71318 .58805 m .71508 .59175 L .71301 .58808 L F
.791 .615 .663 r
.55535 .68536 m .55703 .68922 L .55527 .68705 L F
.55535 .68536 m .55703 .68922 L .55527 .68705 L F
.64 .591 .784 r
.55703 .68922 m .5578 .68894 L .55527 .68705 L F
.55527 .68705 m .5578 .68894 L .55703 .68922 L F
.49 .229 .445 r
.5578 .68894 m .55797 .69003 L .55703 .68922 L F
.616 .094 0 r
.51273 .79345 m .51487 .79484 L .51143 .79426 L F
.557 .024 0 r
.51273 .79345 m .51596 .79432 L .51487 .79484 L F
.585 .357 .537 r
.49017 .72885 m .49241 .72877 L .49258 .72664 L F
.515 .312 .542 r
.49241 .72877 m .49465 .72618 L .49258 .72664 L F
.459 .149 .351 r
.34279 .65858 m .33959 .66125 L .34189 .65957 L F
.369 0 .04 r
.34429 .65939 m .34279 .65858 L .34189 .65957 L F
.34429 .65939 m .34516 .65826 L .34279 .65858 L F
.491 .37 .643 r
.2969 .74053 m .29941 .74236 L .29851 .73957 L F
.2969 .74053 m .29781 .7435 L .29941 .74236 L F
.584 .01 0 r
.56747 .7542 m .56855 .75551 L .56646 .75594 L F
.56747 .7542 m .57029 .75623 L .56855 .75551 L F
.109 0 .08 r
.50877 .73506 m .51049 .73419 L .51126 .73267 L F
.661 .121 0 r
.33104 .70812 m .3318 .70812 L .3299 .70673 L F
.33104 .70812 m .33323 .70954 L .3318 .70812 L F
0 .197 .717 r
.56287 .73441 m .56489 .73658 L .56437 .73761 L F
.102 .377 .838 r
.56489 .73658 m .56677 .73941 L .56437 .73761 L F
.887 .702 .646 r
.61823 .7039 m .6199 .70467 L .61858 .70153 L F
.858 .729 .721 r
.61823 .7039 m .61911 .70731 L .6199 .70467 L F
.206 0 .046 r
.51127 .74844 m .50833 .75034 L .5091 .74924 L F
0 0 0 r
.54896 .74213 m .54676 .74396 L .54897 .74268 L F
.555 0 0 r
.54895 .74176 m .54896 .74213 L .55038 .74247 L F
.79 .96 .921 r
.55038 .74247 m .54896 .74213 L .5516 .74016 L F
0 0 0 r
.54896 .74213 m .54897 .74268 L .5506 .74174 L F
.555 0 0 r
.54644 .74052 m .54896 .74213 L .54895 .74176 L F
.79 .96 .921 r
.55038 .74247 m .5516 .74016 L .55299 .74055 L F
.546 .205 .341 r
.55317 .74412 m .55038 .74247 L .55296 .74303 L F
.55317 .74412 m .54938 .74523 L .55038 .74247 L F
.215 .699 .93 r
.44081 .6655 m .44405 .66603 L .44217 .66648 L F
.654 .586 .767 r
.44556 .66893 m .44217 .66648 L .44405 .66603 L F
0 0 0 r
.3714 .72005 m .37058 .71992 L .37321 .71894 L F
.3714 .72005 m .36947 .72082 L .37058 .71992 L F
.564 .507 .75 r
.33205 .68802 m .33345 .6854 L .33143 .68582 L F
.33205 .68802 m .33413 .68766 L .33345 .6854 L F
.435 .34 .649 r
.33205 .68802 m .33405 .69009 L .33413 .68766 L F
.33205 .68802 m .33252 .69069 L .33405 .69009 L F
0 0 0 r
.55535 .68536 m .55659 .68482 L .55684 .68452 L F
.55535 .68536 m .55373 .68649 L .55659 .68482 L F
.486 0 0 r
.52424 .78975 m .52055 .78992 L .52273 .79012 L F
.742 .281 0 r
.52503 .79149 m .52424 .78975 L .52273 .79012 L F
.52503 .79149 m .52615 .79283 L .52424 .78975 L F
.26 0 0 r
.39389 .70932 m .39686 .70809 L .39561 .70904 L F
.223 0 .023 r
.39877 .70726 m .39561 .70904 L .39686 .70809 L F
.688 .177 .015 r
.64096 .51416 m .64328 .51595 L .64453 .51539 L F
.523 0 0 r
.64328 .51595 m .64667 .51634 L .64453 .51539 L F
.67 .471 .607 r
.55032 .73626 m .54547 .73747 L .54602 .73488 L F
.155 .653 .912 r
.41818 .65332 m .42166 .65407 L .41949 .65423 L F
.015 .538 .858 r
.26732 .58877 m .26391 .58762 L .26577 .5881 L F
.409 .736 .992 r
.26778 .58762 m .26732 .58877 L .26577 .5881 L F
.26778 .58762 m .26926 .58864 L .26732 .58877 L F
.232 .372 .799 r
.72724 .72395 m .72856 .72291 L .72622 .72114 L F
.298 .496 .883 r
.72724 .72395 m .73021 .72544 L .72856 .72291 L F
.274 0 0 r
.27486 .59024 m .27833 .59123 L .27535 .59029 L F
.649 .618 .805 r
.44771 .66823 m .44556 .66893 L .44405 .66603 L F
.887 .711 .659 r
.60168 .69953 m .59895 .70013 L .60059 .69879 L F
.85 .892 .468 r
.60168 .69953 m .60196 .69811 L .60293 .69579 L F
.721 .868 .951 r
.60059 .69879 m .60196 .69811 L .60168 .69953 L F
.647 .129 0 r
.53346 .74998 m .53345 .75036 L .53204 .74867 L F
0 0 0 r
.53552 .74848 m .53346 .74998 L .5369 .74853 L F
.53552 .74848 m .53345 .75036 L .53346 .74998 L F
.154 .523 .918 r
.56677 .73941 m .56812 .73954 L .56741 .74024 L F
.771 .262 0 r
.56785 .73842 m .56812 .73954 L .56784 .73839 L F
.053 .364 .834 r
.56812 .73954 m .56996 .74192 L .56845 .74092 L F
.771 .262 0 r
.56862 .74119 m .57008 .74178 L .56812 .73954 L F
.56862 .74119 m .56812 .73954 L .56785 .73842 L F
.053 .364 .834 r
.56812 .73954 m .56845 .74092 L .56741 .74024 L F
.481 0 0 r
.55828 .70053 m .56087 .701 L .55871 .7012 L F
0 0 0 r
.2866 .63627 m .28543 .6377 L .28809 .63527 L F
.632 .686 .883 r
.37261 .70334 m .36918 .70196 L .37126 .7015 L F
.579 .715 .936 r
.37335 .70125 m .37261 .70334 L .37126 .7015 L F
.37335 .70125 m .37474 .70294 L .37261 .70334 L F
.742 .388 .381 r
.31618 .72815 m .31841 .7267 L .31684 .72612 L F
.648 .87 .982 r
.31971 .72875 m .31762 .72956 L .31841 .7267 L F
.742 .388 .381 r
.31618 .72815 m .31971 .72875 L .31841 .7267 L F
.488 .424 .711 r
.54399 .75853 m .54151 .75652 L .54507 .75645 L F
.306 0 .147 r
.54599 .75728 m .54507 .75645 L .54724 .75635 L F
.54599 .75728 m .54399 .75853 L .54507 .75645 L F
.628 .362 .495 r
.47681 .73694 m .47954 .73488 L .47713 .73507 L F
.957 .639 .226 r
.47134 .77631 m .47181 .77865 L .47057 .77556 L F
.928 .855 .749 r
.47181 .77865 m .47134 .77631 L .47431 .77805 L F
.725 .506 .595 r
.51401 .7236 m .51183 .72596 L .51208 .72414 L F
.074 0 0 r
.58795 .67744 m .58696 .67772 L .58441 .67781 L F
.239 0 0 r
.59023 .67722 m .58696 .67772 L .58795 .67744 L F
.518 .186 .344 r
.71023 .58864 m .70829 .58675 L .70698 .58738 L F
.39 .743 .992 r
.41106 .65148 m .4103 .65249 L .40897 .65157 L F
.41106 .65148 m .41237 .65238 L .4103 .65249 L F
.595 .668 .89 r
.44217 .66128 m .44231 .66483 L .43987 .66178 L F
.344 0 0 r
.44231 .66483 m .44081 .6655 L .43987 .66178 L F
.44231 .66483 m .443 .66555 L .44081 .6655 L F
.514 .601 .878 r
.44423 .66111 m .44231 .66483 L .44217 .66128 L F
.536 .473 .732 r
.44423 .66111 m .443 .66555 L .44231 .66483 L F
.343 0 .137 r
.39281 .69842 m .39617 .69591 L .39415 .69648 L F
.514 .253 .457 r
.66208 .53045 m .66193 .53309 L .65941 .53353 L F
.105 0 .228 r
.66429 .52805 m .66362 .52989 L .66208 .53045 L F
.156 0 .367 r
.66336 .53177 m .66208 .53045 L .66362 .52989 L F
.66336 .53177 m .66193 .53309 L .66208 .53045 L F
.395 .292 .619 r
.43323 .77071 m .43472 .76767 L .43249 .7679 L F
.43323 .77071 m .4349 .77036 L .43472 .76767 L F
.578 .488 .716 r
.43336 .77318 m .4349 .77036 L .43323 .77071 L F
.242 0 .303 r
.30728 .64116 m .30954 .63833 L .30894 .64047 L F
.265 0 .292 r
.30954 .63833 m .31195 .63572 L .31128 .63767 L F
.408 .166 .433 r
.31128 .63767 m .30894 .64047 L .30954 .63833 L F
0 .063 .626 r
.36461 .86685 m .36133 .86467 L .3626 .86737 L F
.873 .625 .561 r
.60853 .67938 m .60856 .68178 L .61145 .68238 L F
.879 .659 .6 r
.60851 .68419 m .61145 .68238 L .60856 .68178 L F
.60851 .68419 m .61136 .68546 L .61145 .68238 L F
.401 .826 .964 r
.28378 .65439 m .28028 .65447 L .2817 .65479 L F
.909 .557 .095 r
.49581 .75748 m .4964 .75941 L .49525 .75711 L F
.581 .564 .8 r
.4373 .66065 m .43498 .66119 L .43382 .65786 L F
.548 .576 .834 r
.43797 .66232 m .43498 .66119 L .4373 .66065 L F
.394 .04 .242 r
.43601 .67914 m .43299 .68169 L .43346 .68014 L F
.412 .359 .689 r
.36346 .69218 m .36261 .69617 L .3621 .69432 L F
.36346 .69218 m .36433 .6964 L .36261 .69617 L F
.324 .122 .444 r
.29095 .63268 m .29267 .63242 L .29303 .63005 L F
.547 .244 .406 r
.28989 .63439 m .29267 .63242 L .29095 .63268 L F
0 .276 .78 r
.64899 .51758 m .64767 .51747 L .64667 .51634 L F
.64899 .51758 m .6501 .51936 L .64767 .51747 L F
.183 .657 .933 r
.30798 .59517 m .31124 .59599 L .30915 .59614 L F
.456 .1 .272 r
.73933 .58451 m .73655 .58418 L .7366 .58498 L F
.761 .443 .447 r
.6021 .69381 m .59961 .69548 L .60047 .69337 L F
.6021 .69381 m .60293 .69579 L .59961 .69548 L F
.716 .951 .952 r
.72001 .71401 m .71576 .71523 L .71853 .71471 L F
.765 .292 .121 r
.72001 .71401 m .71853 .71471 L .72114 .71516 L F
.713 .55 .667 r
.52108 .7455 m .52237 .74331 L .51874 .7428 L F
.537 .486 .746 r
.36346 .69218 m .3621 .69432 L .36117 .69081 L F
.771 .369 .291 r
.51946 .70733 m .52298 .70947 L .52291 .70731 L F
.751 .878 .938 r
.62875 .52718 m .6279 .52915 L .62612 .52946 L F
.62875 .52718 m .62985 .52815 L .6279 .52915 L F
.478 .711 .972 r
.57148 .74177 m .5705 .74313 L .56996 .74192 L F
0 0 .015 r
.57051 .74478 m .5705 .74313 L .57148 .74177 L F
.57051 .74478 m .57047 .74558 L .5705 .74313 L F
.569 .084 .065 r
.51924 .76115 m .51904 .76192 L .5234 .76192 L F
.444 .237 .503 r
.31412 .6329 m .31386 .63508 L .31195 .63572 L F
.372 .088 .346 r
.31195 .63572 m .3132 .63716 L .31128 .63767 L F
.31195 .63572 m .31386 .63508 L .3132 .63716 L F
.479 .232 .462 r
.40873 .68531 m .41078 .68488 L .41122 .68271 L F
.535 .295 .499 r
.41078 .68488 m .41323 .68217 L .41122 .68271 L F
.533 .259 .445 r
.64904 .5363 m .65143 .53761 L .64928 .53721 L F
.64904 .5363 m .65143 .53599 L .65143 .53761 L F
.329 0 .065 r
.39389 .70932 m .39254 .71123 L .39044 .71164 L F
.299 0 .048 r
.39452 .7107 m .39389 .70932 L .39561 .70904 L F
.39452 .7107 m .39254 .71123 L .39389 .70932 L F
.493 0 .004 r
.53736 .79431 m .53549 .79329 L .53498 .79456 L F
.366 .741 .989 r
.33703 .71015 m .33718 .70657 L .33703 .70657 L F
.33703 .71015 m .33781 .7092 L .33718 .70657 L F
.33703 .71015 m .33753 .70934 L .33781 .7092 L F
.545 .257 .429 r
.33703 .71015 m .33858 .71195 L .33753 .70934 L F
.33703 .71015 m .33644 .71251 L .33858 .71195 L F
.526 .341 .574 r
.36128 .86159 m .36133 .86467 L .36328 .86374 L F
.27 .152 .528 r
.31544 .72642 m .31684 .72612 L .31656 .72347 L F
0 0 .453 r
.31544 .72642 m .31618 .72815 L .31684 .72612 L F
.31544 .72642 m .3153 .7299 L .31618 .72815 L F
0 0 .543 r
.59639 .72926 m .59557 .72606 L .59655 .72696 L F
.59639 .72926 m .59676 .72878 L .59557 .72606 L F
.543 .904 .705 r
.59639 .72926 m .59509 .7299 L .59676 .72878 L F
.135 0 .177 r
.30499 .64382 m .30728 .64116 L .30684 .64328 L F
.283 .066 .398 r
.30684 .64328 m .30728 .64116 L .30894 .64047 L F
.281 0 .083 r
.28315 .64003 m .28419 .63883 L .28122 .64056 L F
0 0 0 r
.28543 .6377 m .28419 .63883 L .28315 .64003 L F
.70871 .59273 m .70737 .59351 L .7077 .59288 L F
.538 .351 .575 r
.55093 .75543 m .55057 .75678 L .55278 .75399 L F
.65 .221 .213 r
.55182 .75701 m .55057 .75678 L .55133 .75614 L F
.073 0 .438 r
.55189 .75886 m .55256 .75735 L .55057 .75678 L F
.601 .401 .583 r
.5534 .75773 m .55256 .75735 L .55254 .75707 L F
.5534 .75773 m .55133 .75614 L .55142 .75589 L F
.55502 .75602 m .5534 .75773 L .55142 .75589 L F
.55157 .75552 m .55142 .75589 L .55093 .75543 L F
.55502 .75602 m .55142 .75589 L .55157 .75552 L F
.538 .351 .575 r
.55278 .75399 m .55502 .75602 L .55157 .75552 L F
.55278 .75399 m .55157 .75552 L .55093 .75543 L F
.388 .163 .446 r
.55157 .75552 m .55286 .75485 L .55278 .75399 L F
.55057 .75678 m .55133 .75614 L .55157 .75552 L F
.55133 .75614 m .55286 .75485 L .55157 .75552 L F
.601 .401 .583 r
.5534 .75773 m .55265 .75852 L .55182 .75701 L F
.073 0 .438 r
.55256 .75735 m .55265 .75852 L .55299 .75641 L F
.55189 .75886 m .55265 .75852 L .55256 .75735 L F
.601 .401 .583 r
.55254 .75707 m .55182 .75701 L .55133 .75614 L F
.55256 .75735 m .55182 .75701 L .55254 .75707 L F
.55142 .75589 m .55133 .75614 L .55093 .75543 L F
.388 .163 .446 r
.55133 .75614 m .55299 .75641 L .55286 .75485 L F
.55057 .75678 m .55111 .7567 L .55133 .75614 L F
.55111 .7567 m .55299 .75641 L .55133 .75614 L F
.073 0 .438 r
.55256 .75735 m .55265 .75717 L .55182 .75701 L F
.55256 .75735 m .55182 .75701 L .55057 .75678 L F
.65 .221 .213 r
.55265 .75852 m .55057 .75678 L .55182 .75701 L F
.073 0 .438 r
.55265 .75717 m .55299 .75641 L .55057 .75678 L F
.65 .221 .213 r
.55133 .75614 m .55057 .75678 L .55093 .75543 L F
.513 .343 .588 r
.33633 .67101 m .33847 .66819 L .33637 .66867 L F
.583 .462 .68 r
.33257 .67722 m .33465 .67692 L .3342 .67378 L F
.573 .459 .686 r
.3329 .67964 m .33465 .67692 L .33257 .67722 L F
.368 .809 .956 r
.40193 .66551 m .40371 .66513 L .40007 .66511 L F
.568 .373 .577 r
.40382 .68797 m .40597 .68988 L .40618 .68776 L F
.40382 .68797 m .40372 .69032 L .40597 .68988 L F
.388 .247 .565 r
.45906 .76427 m .4572 .76246 L .45957 .76242 L F
.45906 .76427 m .45739 .7649 L .4572 .76246 L F
.732 .695 .815 r
.72167 .71268 m .72521 .71336 L .72366 .71143 L F
.679 .541 .69 r
.72366 .71143 m .72521 .71336 L .7273 .71218 L F
.384 .268 .596 r
.4185 .67701 m .42018 .6764 L .41996 .6735 L F
.419 .22 .501 r
.4185 .67701 m .42019 .67853 L .42018 .6764 L F
.4185 .67701 m .4183 .67917 L .42019 .67853 L F
.52 .47 .741 r
.52923 .7413 m .53064 .74341 L .53232 .74231 L F
.52923 .7413 m .53064 .74341 L .53232 .74231 L F
.574 .462 .688 r
.43249 .7679 m .43472 .76767 L .43439 .76488 L F
.705 .7 .843 r
.73584 .62669 m .74286 .62733 L .73994 .62683 L F
.607 .89 .99 r
.74213 .62627 m .74286 .62733 L .74296 .62698 L F
.74213 .62627 m .73994 .62683 L .74286 .62733 L F
.875 .682 .637 r
.60005 .68784 m .59825 .68745 L .59856 .68513 L F
.893 .578 .444 r
.60005 .68784 m .59888 .68967 L .59825 .68745 L F
.60005 .68784 m .60116 .69037 L .59888 .68967 L F
.704 .341 .356 r
.63178 .54442 m .6305 .54621 L .62867 .54423 L F
.773 .491 .509 r
.63348 .54462 m .6305 .54621 L .63178 .54442 L F
.61 .062 0 r
.59112 .75805 m .59339 .75935 L .59047 .7588 L F
.559 .377 .591 r
.4376 .75137 m .43538 .75418 L .4376 .7538 L F
.4376 .75137 m .43538 .75418 L .4376 .7538 L F
.546 .413 .651 r
.43573 .75654 m .4376 .7538 L .43538 .75418 L F
.582 .298 .452 r
.5334 .73375 m .53105 .73192 L .53309 .73204 L F
.5334 .73375 m .53135 .73421 L .53105 .73192 L F
.693 .821 .944 r
.7357 .7263 m .73571 .72824 L .73878 .72639 L F
.574 .287 .441 r
.45557 .74566 m .45798 .74553 L .45881 .74281 L F
.546 .259 .43 r
.45881 .74281 m .46091 .7444 L .46115 .74281 L F
.45881 .74281 m .45798 .74553 L .46091 .7444 L F
.462 .32 .602 r
.29932 .62185 m .30158 .62332 L .30155 .62106 L F
.29932 .62185 m .29987 .62408 L .30158 .62332 L F
.726 .962 .942 r
.65351 .51904 m .65141 .52032 L .6524 .51855 L F
.65 .871 .982 r
.65141 .52032 m .6501 .51936 L .6524 .51855 L F
.759 .734 .83 r
.30681 .75689 m .30337 .75698 L .30571 .75425 L F
.337 .8 .935 r
.30537 .75662 m .30337 .75698 L .30681 .75689 L F
0 0 .109 r
.30795 .75356 m .30681 .75689 L .30571 .75425 L F
.30795 .75356 m .30755 .75607 L .30681 .75689 L F
.448 .858 .962 r
.30681 .75689 m .30755 .75607 L .30537 .75662 L F
.49 .193 .388 r
.41323 .68217 m .41541 .68197 L .4162 .67963 L F
.392 .082 .315 r
.41541 .68197 m .4183 .67917 L .4162 .67963 L F
.134 0 .298 r
.75618 .61003 m .75423 .61312 L .75469 .6112 L F
.398 0 0 r
.42737 .83986 m .42742 .83975 L .4253 .83953 L F
.4253 .83953 m .42742 .83975 L .42737 .83986 L F
.802 .454 .398 r
.70564 .58971 m .70698 .58738 L .70568 .58861 L F
.009 .117 .63 r
.70698 .58738 m .70961 .58932 L .71023 .58864 L F
.70698 .58738 m .70872 .59063 L .70961 .58932 L F
.646 .117 0 r
.56503 .71536 m .56591 .71674 L .56359 .71463 L F
.56503 .71536 m .56706 .71751 L .56591 .71674 L F
.615 .721 .921 r
.63668 .50794 m .63753 .50937 L .63415 .50864 L F
.744 .778 .881 r
.63953 .50854 m .63753 .50937 L .63668 .50794 L F
.63953 .50854 m .63753 .50937 L .63668 .50794 L F
.808 .553 .553 r
.60503 .6739 m .60692 .67672 L .60846 .67681 L F
.837 .601 .581 r
.60689 .67907 m .60846 .67681 L .60692 .67672 L F
.60689 .67907 m .60853 .67938 L .60846 .67681 L F
.416 0 .002 r
.50492 .73657 m .50727 .73652 L .50877 .73506 L F
.527 .336 .564 r
.50816 .73566 m .51049 .73419 L .50877 .73506 L F
.5087 .73548 m .51049 .73419 L .50816 .73566 L F
.50727 .73652 m .5087 .73548 L .50816 .73566 L F
.50727 .73652 m .50911 .73389 L .51049 .73419 L F
.46 0 .008 r
.51037 .73491 m .50911 .73389 L .50935 .73527 L F
.51033 .73496 m .50935 .73527 L .50949 .73608 L F
.51037 .73491 m .50935 .73527 L .51033 .73496 L F
.279 .58 .942 r
.71273 .60639 m .71373 .60779 L .71336 .60624 L F
.71273 .60639 m .71373 .60779 L .71336 .60624 L F
.713 .55 .667 r
.52108 .7455 m .52209 .74574 L .52237 .74331 L F
.714 .646 .779 r
.34662 .7289 m .34775 .72992 L .3484 .72864 L F
.692 .547 .685 r
.34775 .72992 m .34676 .73151 L .34769 .73082 L F
.545 .366 .589 r
.4376 .75137 m .4376 .7538 L .43978 .751 L F
0 .408 .755 r
.55307 .69648 m .55302 .69643 L .54726 .69413 L F
.774 .302 .12 r
.54838 .69652 m .55196 .69877 L .55307 .69648 L F
.418 .504 .84 r
.55307 .69648 m .55306 .69329 L .55302 .69643 L F
.55307 .69648 m .55437 .69615 L .55306 .69329 L F
.412 .469 .81 r
.55307 .69648 m .55741 .70037 L .55437 .69615 L F
.537 .653 .91 r
.43908 .78514 m .44034 .78335 L .43808 .7837 L F
.43908 .78514 m .44148 .78507 L .44034 .78335 L F
.271 .617 .958 r
.44454 .78547 m .44621 .78483 L .44353 .78472 L F
.147 0 0 r
.44837 .78611 m .44735 .78597 L .44454 .78547 L F
.271 .617 .958 r
.44454 .78547 m .44735 .78597 L .44621 .78483 L F
.402 .165 .437 r
.31412 .6329 m .31643 .63018 L .31599 .63232 L F
.439 .233 .501 r
.31571 .63448 m .31412 .6329 L .31599 .63232 L F
.31571 .63448 m .31386 .63508 L .31412 .6329 L F
.688 .715 .87 r
.72288 .72043 m .72407 .72271 L .72622 .72114 L F
.379 .145 .429 r
.31599 .63232 m .31643 .63018 L .31825 .62952 L F
.526 .306 .523 r
.39872 .69346 m .40083 .69325 L .40079 .6907 L F
.589 .355 .529 r
.40079 .6907 m .40327 .69184 L .40372 .69032 L F
.40079 .6907 m .40083 .69325 L .40327 .69184 L F
.661 .291 .333 r
.5367 .73219 m .5334 .73375 L .53309 .73204 L F
.5367 .73219 m .53571 .73423 L .5334 .73375 L F
.588 .212 .297 r
.5393 .7332 m .5367 .73219 L .53865 .73228 L F
.5393 .7332 m .53571 .73423 L .5367 .73219 L F
.469 .123 .296 r
.26228 .6078 m .26159 .60994 L .25939 .61021 L F
.272 0 .219 r
.26342 .6092 m .26228 .6078 L .26558 .60735 L F
.26342 .6092 m .26159 .60994 L .26228 .6078 L F
.748 .278 0 r
.72597 .62 m .72808 .62269 L .72734 .62207 L F
.546 .795 .991 r
.72808 .62269 m .72963 .62132 L .72734 .62207 L F
.72808 .62269 m .73144 .62245 L .72963 .62132 L F
.335 0 0 r
.37186 .64929 m .37407 .64923 L .37538 .6488 L F
.112 0 0 r
.37538 .6488 m .37643 .64875 L .37741 .6484 L F
.37538 .6488 m .37407 .64923 L .37643 .64875 L F
.81 .562 .564 r
.54219 .7323 m .5393 .7332 L .53865 .73228 L F
.54219 .7323 m .54264 .73403 L .5393 .7332 L F
.484 .365 .641 r
.54219 .7323 m .54466 .73402 L .54264 .73403 L F
.54219 .7323 m .54466 .73402 L .54264 .73403 L F
.523 .837 .999 r
.30205 .59466 m .30015 .59521 L .29856 .5945 L F
.444 .18 .418 r
.43861 .67679 m .43799 .67953 L .43601 .67914 L F
.515 .244 .442 r
.43988 .67918 m .43861 .67679 L .44074 .67637 L F
.43988 .67918 m .43799 .67953 L .43861 .67679 L F
.233 0 0 r
.27638 .60471 m .27508 .60479 L .27292 .6045 L F
0 0 0 r
.2785 .60416 m .27508 .60479 L .27638 .60471 L F
.552 .423 .659 r
.33143 .68582 m .33345 .6854 L .33332 .68225 L F
.46 .418 .724 r
.49235 .75594 m .49123 .76009 L .48963 .75626 L F
.49235 .75594 m .49337 .75942 L .49123 .76009 L F
.151 0 0 r
.49337 .75942 m .49033 .76112 L .49123 .76009 L F
.25 0 0 r
.41327 .66426 m .41156 .66548 L .40939 .66581 L F
0 0 0 r
.41349 .66457 m .41327 .66426 L .41509 .6637 L F
.126 0 0 r
.41694 .66418 m .41573 .6645 L .41349 .66457 L F
.142 .683 .827 r
.41573 .6645 m .41395 .6645 L .41349 .66457 L F
0 0 0 r
.41349 .66457 m .41265 .6647 L .41327 .66426 L F
.142 .683 .827 r
.41395 .6645 m .41196 .66449 L .41349 .66457 L F
0 0 0 r
.41349 .66457 m .41156 .66548 L .41265 .6647 L F
.631 .508 .694 r
.33126 .69871 m .33387 .6989 L .33327 .69603 L F
0 0 .374 r
.55917 .68843 m .5578 .68894 L .56095 .68768 L F
.55917 .68843 m .55797 .69003 L .5578 .68894 L F
.5 0 0 r
.55819 .70978 m .55723 .7109 L .55441 .70991 L F
.648 .112 0 r
.56057 .71187 m .55723 .7109 L .55819 .70978 L F
.755 .773 .868 r
.32048 .71454 m .32266 .71598 L .32179 .71253 L F
.611 .593 .808 r
.32266 .71598 m .32382 .7116 L .32179 .71253 L F
.734 .503 .577 r
.51747 .72378 m .51539 .7248 L .51401 .7236 L F
.723 .479 .557 r
.51747 .72378 m .51785 .7265 L .51539 .7248 L F
.286 .175 .548 r
.51913 .72551 m .51747 .72378 L .5198 .72399 L F
.51913 .72551 m .51785 .7265 L .51747 .72378 L F
0 0 0 r
.5041 .7131 m .50167 .71563 L .50407 .71371 L F
.36 .174 .488 r
.50091 .71774 m .50407 .71371 L .50167 .71563 L F
.308 .79 .908 r
.28724 .6541 m .28789 .6536 L .28585 .65416 L F
.28724 .6541 m .28904 .65377 L .28789 .6536 L F
.267 0 .276 r
.30254 .64645 m .30499 .64382 L .30443 .64595 L F
.429 .175 .426 r
.30443 .64595 m .30499 .64382 L .30684 .64328 L F
.552 .272 .444 r
.46115 .74281 m .46345 .74262 L .46382 .74066 L F
.563 .294 .466 r
.46345 .74262 m .46659 .73945 L .46382 .74066 L F
.858 .729 .721 r
.61823 .7039 m .61661 .70668 L .61911 .70731 L F
.812 .56 .558 r
.6165 .7092 m .61911 .70731 L .61661 .70668 L F
.6165 .7092 m .6191 .70962 L .61911 .70731 L F
.292 .343 .744 r
.58404 .71711 m .58325 .72064 L .58242 .71879 L F
.58404 .71711 m .5849 .72059 L .58325 .72064 L F
.285 .539 .917 r
.55227 .72694 m .55512 .72811 L .55429 .72879 L F
.18 .348 .797 r
.55512 .72811 m .55609 .73008 L .55429 .72879 L F
0 0 0 r
.37337 .71925 m .37321 .71894 L .37516 .71819 L F
.37337 .71925 m .3714 .72005 L .37321 .71894 L F
.403 0 0 r
.34343 .73127 m .34365 .73157 L .34676 .73151 L F
0 .521 .705 r
.56557 .6844 m .56535 .68438 L .56348 .6842 L F
.351 0 0 r
.56914 .68298 m .56535 .68438 L .56557 .6844 L F
.607 .508 .716 r
.36312 .6887 m .36117 .69081 L .3611 .68973 L F
.389 0 0 r
.419 .66304 m .41694 .66418 L .41509 .6637 L F
.415 .098 .317 r
.50632 .75126 m .50589 .75359 L .5035 .75372 L F
.172 0 .241 r
.50742 .75268 m .50632 .75126 L .50833 .75034 L F
.50742 .75268 m .50589 .75359 L .50632 .75126 L F
.394 .04 .242 r
.43601 .67914 m .4352 .68124 L .43299 .68169 L F
.45 .096 .273 r
.43799 .67953 m .4352 .68124 L .43601 .67914 L F
.287 0 .215 r
.57865 .70119 m .58025 .70087 L .57982 .69986 L F
.668 .155 .012 r
.58025 .70087 m .58223 .70132 L .57982 .69986 L F
.176 .712 .797 r
.59356 .67691 m .59167 .67702 L .59023 .67722 L F
.937 .583 .318 r
.59356 .67691 m .59278 .67854 L .59167 .67702 L F
.59356 .67691 m .59423 .67948 L .59278 .67854 L F
.803 .506 .486 r
.59701 .67959 m .59423 .67948 L .59356 .67691 L F
.202 .253 .692 r
.33252 .69069 m .3331 .69345 L .33399 .69224 L F
.313 .408 .799 r
.33399 .69224 m .3331 .69345 L .33468 .69328 L F
.565 .434 .661 r
.3331 .69345 m .33554 .69557 L .33468 .69328 L F
.3331 .69345 m .33327 .69603 L .33554 .69557 L F
.496 .389 .662 r
.3329 .67964 m .33516 .68163 L .3351 .67921 L F
.3329 .67964 m .33332 .68225 L .33516 .68163 L F
.573 .459 .686 r
.3329 .67964 m .3351 .67921 L .33465 .67692 L F
.313 .181 .535 r
.75235 .5911 m .75243 .5937 L .75087 .59431 L F
.341 .246 .6 r
.75243 .5937 m .75266 .59605 L .75087 .59431 L F
.39 .249 .567 r
.75266 .59605 m .75096 .59677 L .75087 .59431 L F
0 .562 .71 r
.27043 .65644 m .27102 .65645 L .26899 .65675 L F
.27043 .65644 m .2737 .65653 L .27102 .65645 L F
.513 .79 .996 r
.26801 .64403 m .26803 .64542 L .26647 .64491 L F
.26801 .64403 m .26988 .64494 L .26803 .64542 L F
.546 .202 .336 r
.53244 .75626 m .53472 .75629 L .53596 .75386 L F
.716 .39 .426 r
.53596 .75386 m .53472 .75629 L .53806 .75626 L F
.677 .394 .484 r
.53596 .75386 m .53806 .75626 L .53826 .75421 L F
.176 0 0 r
.63668 .50794 m .63922 .50851 L .63953 .50854 L F
0 0 .214 r
.63953 .50854 m .64059 .50613 L .64203 .50552 L F
.63953 .50854 m .64096 .50711 L .64059 .50613 L F
.56 .909 .699 r
.63953 .50854 m .63922 .50851 L .64096 .50711 L F
.418 .41 .744 r
.52826 .71263 m .52701 .71594 L .52633 .71232 L F
.52826 .71263 m .52932 .71691 L .52701 .71594 L F
.479 .366 .647 r
.52701 .71594 m .52902 .71786 L .52744 .71799 L F
.52701 .71594 m .52932 .71691 L .52902 .71786 L F
.515 .036 .056 r
.45405 .7862 m .45279 .78703 L .45045 .78673 L F
.483 0 .028 r
.45405 .7862 m .45616 .78652 L .45279 .78703 L F
.234 0 0 r
.3903 .66617 m .38863 .66718 L .38663 .66728 L F
.246 0 0 r
.39235 .66536 m .38863 .66718 L .3903 .66617 L F
.377 .743 .991 r
.55752 .69662 m .55844 .69578 L .5569 .6952 L F
.55752 .69662 m .55981 .69662 L .55844 .69578 L F
.55752 .69662 m .55844 .69578 L .5569 .6952 L F
.55752 .69662 m .55981 .69662 L .55844 .69578 L F
.494 .216 .421 r
.48718 .73221 m .4894 .73208 L .49017 .72885 L F
.413 .093 .312 r
.4894 .73208 m .49241 .72877 L .49017 .72885 L F
0 0 .089 r
.62913 .52281 m .62851 .52476 L .62988 .5234 L F
.283 0 .085 r
.35847 .65228 m .35923 .65357 L .36062 .65196 L F
.35847 .65228 m .35731 .65413 L .35923 .65357 L F
.273 0 0 r
.29777 .65006 m .29696 .65082 L .29511 .6511 L F
.18 0 0 r
.29984 .64946 m .29696 .65082 L .29777 .65006 L F
.415 .077 .281 r
.41996 .6735 m .42244 .6733 L .4229 .67136 L F
.627 .953 .779 r
.4229 .67136 m .423 .67085 L .42439 .67001 L F
.061 0 .159 r
.4229 .67136 m .42371 .6726 L .423 .67085 L F
.4229 .67136 m .42244 .6733 L .42371 .6726 L F
.528 .737 .971 r
.48311 .77612 m .48537 .77601 L .48433 .77457 L F
.587 .389 .58 r
.48537 .77601 m .48308 .77854 L .48311 .77612 L F
.48537 .77601 m .48308 .77854 L .48311 .77612 L F
.77 .743 .828 r
.71921 .71763 m .7177 .71826 L .72028 .71834 L F
.625 .74 .93 r
.71921 .71763 m .72028 .71834 L .72277 .71805 L F
.074 .069 .545 r
.72028 .71834 m .72189 .71969 L .72277 .71805 L F
.72028 .71834 m .72054 .72084 L .72189 .71969 L F
.284 .326 .73 r
.57189 .75107 m .57409 .75304 L .57255 .7546 L F
0 0 .069 r
.57409 .75304 m .57402 .75465 L .57255 .7546 L F
.607 .508 .716 r
.36312 .6887 m .36345 .69034 L .36117 .69081 L F
.537 .486 .746 r
.36346 .69218 m .36117 .69081 L .36345 .69034 L F
0 .019 .54 r
.3162 .85877 m .31694 .85952 L .31564 .85804 L F
.31564 .85804 m .31694 .85952 L .3162 .85877 L F
.3162 .85877 m .31694 .85952 L .31564 .85804 L F
.498 .042 .1 r
.52151 .79146 m .52055 .78992 L .5195 .79184 L F
.52151 .79146 m .52273 .79012 L .52055 .78992 L F
.763 .555 .616 r
.31971 .72875 m .32332 .72915 L .32283 .72658 L F
.252 .234 .643 r
.32283 .72658 m .32422 .72609 L .32359 .72324 L F
.665 .95 .707 r
.325 .72476 m .32477 .72498 L .32422 .72609 L F
.642 .475 .642 r
.32283 .72658 m .32332 .72915 L .32555 .72677 L F
.804 .595 .619 r
.32359 .72324 m .32422 .72609 L .32045 .72522 L F
.732 .28 .178 r
.32422 .72609 m .3224 .72721 L .32045 .72522 L F
.665 .95 .707 r
.32477 .72498 m .3224 .72721 L .32422 .72609 L F
.642 .475 .642 r
.32283 .72658 m .32394 .72666 L .32422 .72609 L F
.32394 .72666 m .32555 .72677 L .32422 .72609 L F
.269 .682 .968 r
.31337 .59571 m .31529 .59581 L .31482 .59659 L F
.254 .665 .965 r
.31529 .59581 m .3168 .59676 L .31482 .59659 L F
0 0 0 r
.50609 .71019 m .5041 .7131 L .5054 .71155 L F
.331 .068 .356 r
.50407 .71371 m .5054 .71155 L .5041 .7131 L F
.376 .512 .867 r
.73021 .72544 m .73062 .72705 L .73208 .72569 L F
.459 .655 .945 r
.73062 .72705 m .7332 .72734 L .73208 .72569 L F
.691 .275 .252 r
.4799 .78948 m .48334 .7897 L .48195 .79136 L F
.566 .081 .063 r
.48334 .7897 m .48419 .79145 L .48195 .79136 L F
.48334 .7897 m .48562 .79035 L .48419 .79145 L F
.607 .42 .603 r
.32994 .72399 m .32768 .7261 L .32767 .72346 L F
.891 .893 .824 r
.32791 .72455 m .32633 .72535 L .32768 .7261 L F
.583 .146 .177 r
.33133 .72306 m .33112 .7232 L .32767 .72346 L F
.33112 .7232 m .3295 .72389 L .32767 .72346 L F
.891 .893 .824 r
.32819 .72267 m .32645 .72517 L .32791 .72455 L F
.32645 .72517 m .32633 .72535 L .32791 .72455 L F
.583 .146 .177 r
.33112 .7232 m .32994 .72399 L .3295 .72389 L F
.161 0 0 r
.33344 .72341 m .32994 .72399 L .33133 .72306 L F
0 .474 .739 r
.38882 .64807 m .39083 .64851 L .39237 .64893 L F
.024 .567 .841 r
.39228 .64864 m .39237 .64893 L .39083 .64851 L F
.39228 .64864 m .39421 .64921 L .39237 .64893 L F
.982 .732 .478 r
.56665 .76424 m .56651 .7675 L .56531 .76662 L F
.456 .22 .466 r
.56923 .76306 m .56906 .76243 L .56665 .76424 L F
.781 .567 .61 r
.56531 .76662 m .56923 .76306 L .56665 .76424 L F
.459 0 0 r
.51836 .79488 m .52176 .79534 L .52053 .79553 L F
.362 0 0 r
.52176 .79534 m .52276 .79618 L .52053 .79553 L F
.52176 .79534 m .52427 .79603 L .52276 .79618 L F
.768 .509 .543 r
.49675 .78954 m .49674 .78717 L .49347 .78708 L F
.918 .608 .442 r
.60343 .67137 m .60379 .67369 L .60503 .6739 L F
.814 .553 .545 r
.60347 .67606 m .60503 .6739 L .60379 .67369 L F
.60347 .67606 m .60692 .67672 L .60503 .6739 L F
.785 .309 0 r
.46656 .76235 m .46691 .76373 L .46482 .76167 L F
.46656 .76235 m .46818 .76471 L .46691 .76373 L F
.397 .749 .993 r
.46691 .76373 m .46775 .76276 L .46579 .76286 L F
.644 .106 0 r
.46482 .76167 m .46691 .76373 L .46558 .76287 L F
.397 .749 .993 r
.46691 .76373 m .46579 .76286 L .46558 .76287 L F
.785 .309 0 r
.46818 .76471 m .46823 .76478 L .46691 .76373 L F
.802 .507 .49 r
.55976 .74003 m .56045 .74253 L .55846 .74072 L F
.55976 .74003 m .56171 .74302 L .56045 .74253 L F
.653 .42 .553 r
.56194 .74034 m .56387 .74006 L .55976 .74003 L F
.854 .605 .562 r
.52962 .76238 m .52905 .76488 L .52791 .76186 L F
.784 .541 .569 r
.65696 .52224 m .66023 .52481 L .65817 .52459 L F
.834 .914 .89 r
.34343 .73127 m .34145 .73259 L .34365 .73157 L F
.415 .144 .392 r
.40873 .68531 m .41026 .68671 L .41078 .68488 L F
.40873 .68531 m .40823 .6873 L .41026 .68671 L F
.391 0 0 r
.49111 .78722 m .48729 .78503 L .48962 .78674 L F
.064 .628 .732 r
.49215 .78711 m .49111 .78722 L .48962 .78674 L F
.49215 .78711 m .49347 .78708 L .49111 .78722 L F
.786 .643 .703 r
.54146 .74266 m .54604 .74434 L .54377 .73969 L F
.858 .693 .677 r
.54146 .74266 m .54475 .74547 L .54604 .74434 L F
.644 .583 .772 r
.54377 .73969 m .54604 .74434 L .54814 .74194 L F
0 0 0 r
.54604 .74434 m .54475 .74547 L .54644 .74421 L F
.306 0 0 r
.44837 .78611 m .45045 .78673 L .44735 .78597 L F
.585 .891 .989 r
.73146 .59089 m .73336 .59162 L .73454 .59076 L F
.61 .652 .867 r
.73336 .59162 m .73561 .59217 L .73454 .59076 L F
.49 .147 .312 r
.65941 .53353 m .65683 .53498 L .65701 .53352 L F
.076 0 .04 r
.28122 .64056 m .28168 .64179 L .28315 .64003 L F
.28122 .64056 m .27996 .64284 L .28168 .64179 L F
.526 .244 .43 r
.64355 .54095 m .64365 .53929 L .64588 .54069 L F
.537 .235 .402 r
.64365 .53929 m .64595 .53913 L .64588 .54069 L F
.249 0 .249 r
.30352 .64787 m .30254 .64645 L .30443 .64595 L F
.30352 .64787 m .30181 .64871 L .30254 .64645 L F
.615 .759 .948 r
.3153 .7299 m .31762 .72956 L .31618 .72815 L F
.543 .403 .64 r
.5187 .7292 m .52123 .73124 L .52105 .72908 L F
.5187 .7292 m .51906 .73186 L .52123 .73124 L F
.421 .403 .733 r
.43987 .66178 m .43916 .66515 L .43797 .66232 L F
.43987 .66178 m .44081 .6655 L .43916 .66515 L F
.459 .245 .501 r
.73805 .72032 m .73956 .71823 L .73765 .71846 L F
.73805 .72032 m .74032 .7204 L .73969 .71861 L F
.73901 .71899 m .73969 .71861 L .73956 .71823 L F
.73805 .72032 m .73969 .71861 L .73901 .71899 L F
.424 0 0 r
.73956 .71823 m .74058 .71835 L .74 .71837 L F
.73956 .71823 m .74 .71837 L .73765 .71846 L F
.402 .215 .51 r
.73956 .71823 m .74032 .7204 L .74129 .71878 L F
.51 .55 .833 r
.7421 .71745 m .74058 .71835 L .73956 .71823 L F
.67 .696 .865 r
.73765 .71846 m .74 .71837 L .73859 .71519 L F
.74 .71837 m .74011 .71837 L .74008 .71831 L F
.74 .71837 m .74008 .71831 L .73859 .71519 L F
.402 .215 .51 r
.74063 .7179 m .74129 .71878 L .7421 .71745 L F
.73956 .71823 m .74 .71837 L .74063 .7179 L F
.67 .696 .865 r
.74011 .71837 m .74058 .71835 L .74047 .71817 L F
.402 .215 .51 r
.74 .71837 m .74129 .71878 L .74063 .7179 L F
.67 .696 .865 r
.74011 .71837 m .74047 .71817 L .73859 .71519 L F
.78 .911 .522 r
.63089 .51989 m .62983 .52113 L .63123 .51874 L F
.734 .487 .556 r
.59701 .67959 m .59353 .68183 L .59423 .67948 L F
.59701 .67959 m .59737 .682 L .59353 .68183 L F
.955 .915 .735 r
.60326 .70735 m .60177 .70971 L .60113 .70875 L F
.959 .88 .712 r
.60326 .70735 m .60113 .70875 L .60218 .70653 L F
0 .239 .73 r
.33561 .7189 m .33637 .71895 L .3344 .71864 L F
.253 0 0 r
.70968 .59176 m .71153 .59205 L .7112 .59233 L F
.109 0 .113 r
.33173 .61293 m .33264 .61129 L .33427 .61036 L F
0 0 .269 r
.57736 .73476 m .57716 .73396 L .57637 .73161 L F
0 0 .529 r
.57736 .73476 m .57871 .736 L .57716 .73396 L F
.57736 .73476 m .57857 .73707 L .57871 .736 L F
.75 .696 .8 r
.75157 .60208 m .75275 .60508 L .7487 .60448 L F
.866 .652 .612 r
.75275 .60508 m .74998 .60645 L .7487 .60448 L F
.75275 .60508 m .75202 .60664 L .74998 .60645 L F
.606 .91 .982 r
.75473 .60343 m .75275 .60508 L .75157 .60208 L F
.18 .268 .718 r
.57843 .74037 m .57968 .73914 L .57857 .73707 L F
.261 .399 .814 r
.57843 .74037 m .58104 .74213 L .57968 .73914 L F
.803 .652 .694 r
.61277 .69036 m .61457 .69083 L .61292 .68779 L F
.818 .611 .623 r
.61288 .69253 m .61457 .69083 L .61277 .69036 L F
.61288 .69253 m .61421 .69328 L .61457 .69083 L F
.859 .7 .684 r
.61421 .69328 m .61389 .6957 L .61546 .69604 L F
.776 .572 .623 r
.61389 .6957 m .61698 .69849 L .61546 .69604 L F
0 0 .487 r
.46712 .76851 m .46654 .76827 L .46612 .76796 L F
.46712 .76851 m .46785 .77096 L .46654 .76827 L F
.509 0 0 r
.45616 .78652 m .45943 .78755 L .45831 .78772 L F
.343 0 0 r
.45831 .78772 m .45943 .78755 L .46161 .78833 L F
.832 .849 .859 r
.50082 .75722 m .50229 .75842 L .50361 .75664 L F
.306 .004 .277 r
.74876 .60383 m .74707 .6052 L .7487 .60448 L F
.494 .36 .627 r
.74998 .60645 m .74707 .6052 L .7487 .60448 L F
.306 .004 .277 r
.74876 .60383 m .74707 .6052 L .7487 .60448 L F
.494 .36 .627 r
.74998 .60645 m .74707 .6052 L .7487 .60448 L F
.448 .051 .192 r
.40412 .7041 m .40287 .70619 L .40065 .70639 L F
.456 .226 .475 r
.40645 .70165 m .40597 .70366 L .40412 .7041 L F
.426 .057 .233 r
.40597 .70366 m .40287 .70619 L .40412 .7041 L F
.238 0 0 r
.29511 .6511 m .29696 .65082 L .29398 .65203 L F
.789 .399 0 r
.59516 .72446 m .59441 .72297 L .59354 .72293 L F
.129 0 .179 r
.59292 .7229 m .59354 .72293 L .59464 .72117 L F
.789 .399 0 r
.59441 .72297 m .59382 .72178 L .59354 .72293 L F
.129 0 .179 r
.59238 .72345 m .59354 .72293 L .59292 .7229 L F
.786 .554 .585 r
.30944 .72283 m .3133 .72083 L .30979 .72149 L F
.30944 .72283 m .31288 .7233 L .3133 .72083 L F
.773 .491 .509 r
.63348 .54462 m .63339 .54648 L .6305 .54621 L F
.593 .337 .499 r
.63348 .54462 m .63579 .54642 L .63339 .54648 L F
.631 .318 .422 r
.63612 .54475 m .63579 .54642 L .63348 .54462 L F
.753 .321 .224 r
.48892 .79032 m .49086 .79243 L .48766 .79158 L F
.115 .096 .557 r
.58739 .72247 m .58611 .72388 L .58507 .72303 L F
.792 .409 .331 r
.58611 .72388 m .58677 .72581 L .58919 .7258 L F
.115 .096 .557 r
.58739 .72247 m .58677 .72581 L .58611 .72388 L F
.508 .379 .64 r
.33615 .60499 m .33655 .60779 L .33445 .60813 L F
.319 .119 .445 r
.33614 .60902 m .33445 .60813 L .33655 .60779 L F
.33614 .60902 m .33427 .61036 L .33445 .60813 L F
.147 0 0 r
.56184 .68145 m .56366 .68097 L .56515 .67943 L F
.056 0 0 r
.56515 .67943 m .56692 .6792 L .56727 .67818 L F
.56515 .67943 m .56366 .68097 L .56692 .6792 L F
.737 .835 .925 r
.63415 .50864 m .63083 .50837 L .63361 .50719 L F
.819 .721 .757 r
.63415 .50864 m .63212 .51151 L .63083 .50837 L F
0 .495 .766 r
.63361 .50719 m .63668 .50794 L .63415 .50864 L F
0 0 .282 r
.75441 .60623 m .75616 .60578 L .75405 .606 L F
.897 .905 .822 r
.75616 .60578 m .7565 .60808 L .75849 .60517 L F
.418 .476 .813 r
.75673 .60735 m .7565 .60808 L .75616 .60578 L F
.75673 .60735 m .75618 .61003 L .7565 .60808 L F
.75673 .60735 m .75833 .60926 L .75618 .61003 L F
0 0 .282 r
.75697 .60787 m .75673 .60735 L .75616 .60578 L F
.75697 .60787 m .75616 .60578 L .75441 .60623 L F
.897 .905 .822 r
.75616 .60578 m .75849 .60517 L .75851 .60515 L F
.86 .933 .871 r
.58956 .75687 m .58762 .75622 L .58965 .75696 L F
0 0 .399 r
.62492 .53599 m .62683 .53893 L .62327 .53876 L F
.805 .618 .649 r
.62683 .53893 m .6234 .54105 L .62327 .53876 L F
.62683 .53893 m .62662 .54156 L .6234 .54105 L F
0 0 0 r
.50855 .70783 m .50609 .71019 L .5077 .70883 L F
0 0 .105 r
.61913 .73629 m .61872 .7376 L .61904 .73396 L F
.782 .762 .249 r
.61913 .73629 m .61843 .73996 L .61872 .7376 L F
.494 .28 .518 r
.41067 .70073 m .40887 .69895 L .41086 .69854 L F
.41067 .70073 m .40858 .70122 L .40887 .69895 L F
.962 .746 .565 r
.57292 .72653 m .57259 .72909 L .57157 .72578 L F
.57292 .72653 m .57259 .72909 L .57157 .72578 L F
.445 .648 .945 r
.74924 .58863 m .74557 .5868 L .74888 .58722 L F
.494 .617 .902 r
.75139 .58851 m .74924 .58863 L .74888 .58722 L F
.585 .544 .775 r
.75235 .5911 m .74924 .58863 L .75139 .58851 L F
.375 0 .096 r
.3628 .65171 m .36501 .65139 L .36643 .64952 L F
.363 0 .126 r
.36501 .65139 m .36832 .64907 L .36643 .64952 L F
.448 .23 .489 r
.5054 .71155 m .5077 .70883 L .50609 .71019 L F
.958 .706 .513 r
.61907 .71381 m .62048 .71276 L .61904 .71193 L F
.61907 .71381 m .62033 .71486 L .62048 .71276 L F
.767 .649 .731 r
.54724 .75635 m .54837 .75959 L .55057 .75678 L F
.642 .469 .634 r
.55057 .75678 m .54837 .75959 L .55189 .75886 L F
.767 .649 .731 r
.54724 .75635 m .55057 .75678 L .54949 .75852 L F
.65 .221 .213 r
.55265 .75852 m .54949 .75852 L .55057 .75678 L F
.353 .824 .774 r
.28073 .60358 m .28439 .60238 L .28259 .60349 L F
.267 0 0 r
.28439 .60238 m .28474 .60301 L .28259 .60349 L F
.28439 .60238 m .2861 .60255 L .28474 .60301 L F
.699 .174 0 r
.56359 .71463 m .56057 .71187 L .56178 .71259 L F
.582 .553 .788 r
.43579 .78382 m .4373 .78105 L .43515 .78195 L F
.43579 .78382 m .43808 .7837 L .4373 .78105 L F
.546 .413 .651 r
.43573 .75654 m .43787 .75615 L .4376 .7538 L F
.519 .396 .652 r
.436 .75954 m .43787 .75615 L .43573 .75654 L F
.792 .493 0 r
.55048 .70735 m .55052 .70827 L .54931 .7067 L F
.55069 .70826 m .551 .70954 L .55052 .70827 L F
.158 .445 .877 r
.551 .70954 m .55196 .70875 L .55052 .70827 L F
.251 0 0 r
.55052 .70827 m .55196 .70875 L .55039 .70828 L F
.55052 .70827 m .55039 .70828 L .5487 .70778 L F
.792 .493 0 r
.55048 .70735 m .55069 .70826 L .55052 .70827 L F
.068 .302 .787 r
.5687 .7041 m .56991 .70655 L .56769 .70477 L F
.544 .305 .504 r
.42705 .68525 m .42587 .68792 L .42349 .68821 L F
.464 .221 .461 r
.42796 .68732 m .42705 .68525 L .42886 .68449 L F
.42796 .68732 m .42587 .68792 L .42705 .68525 L F
.398 .535 .877 r
.74599 .59665 m .74573 .59339 L .74383 .5933 L F
.74599 .59665 m .74765 .59622 L .74573 .59339 L F
.683 .242 .197 r
.48026 .75932 m .4789 .76096 L .47625 .75897 L F
.874 .472 .264 r
.48026 .75932 m .47992 .76171 L .4789 .76096 L F
.48026 .75932 m .48151 .76195 L .47992 .76171 L F
.524 .18 .327 r
.44352 .67437 m .44531 .67578 L .44304 .67592 L F
.527 .179 .321 r
.44589 .6742 m .44531 .67578 L .44352 .67437 L F
.179 .71 .837 r
.59704 .71927 m .5978 .71909 L .60014 .71921 L F
0 0 0 r
.5978 .71909 m .59729 .71961 L .59893 .71883 L F
.749 .951 .943 r
.60014 .71921 m .5978 .71909 L .60098 .71733 L F
0 0 0 r
.5978 .71909 m .59893 .71883 L .5994 .7186 L F
.179 .71 .837 r
.59617 .71929 m .5978 .71909 L .59704 .71927 L F
.749 .951 .943 r
.60014 .71921 m .60098 .71733 L .60204 .71801 L F
0 .119 .668 r
.42162 .66604 m .42188 .66517 L .42148 .66504 L F
.856 .514 .406 r
.42312 .66588 m .42188 .66517 L .42162 .66604 L F
.295 .572 .935 r
.27311 .58825 m .2728 .58992 L .27134 .58866 L F
.27311 .58825 m .27486 .59024 L .2728 .58992 L F
.641 .361 .478 r
.59091 .71606 m .58714 .71569 L .59019 .7152 L F
.276 .35 .759 r
.58949 .71231 m .59178 .71464 L .59019 .7152 L F
.433 .483 .812 r
.59178 .71464 m .59091 .71606 L .59019 .7152 L F
.762 .633 .718 r
.54547 .73747 m .54644 .74052 L .54377 .73969 L F
.244 .667 .961 r
.54644 .74052 m .54574 .73982 L .54377 .73969 L F
.644 .583 .772 r
.54377 .73969 m .54814 .74194 L .54644 .74052 L F
0 0 .032 r
.55032 .73626 m .54644 .74052 L .54547 .73747 L F
.55032 .73626 m .54832 .73964 L .54644 .74052 L F
.421 .783 .995 r
.54644 .74052 m .54832 .73964 L .54574 .73982 L F
.266 .408 .819 r
.54814 .74194 m .54896 .74213 L .54644 .74052 L F
.496 .625 .908 r
.74707 .71173 m .74622 .71303 L .743 .7093 L F
.51 .458 .734 r
.43462 .77868 m .43515 .78195 L .4373 .78105 L F
.934 .95 .622 r
.64502 .50603 m .64392 .50748 L .6444 .50771 L F
.981 .897 .658 r
.64238 .51075 m .6444 .50771 L .64392 .50748 L F
.64238 .51075 m .64325 .5114 L .6444 .50771 L F
.332 0 0 r
.52328 .72363 m .51913 .72551 L .5198 .72399 L F
.52328 .72363 m .52183 .72524 L .51913 .72551 L F
.493 .328 .585 r
.52328 .72363 m .5253 .72319 L .52525 .72077 L F
.557 .443 .679 r
.52371 .7263 m .5253 .72319 L .52328 .72363 L F
.406 0 0 r
.52385 .72496 m .52328 .72363 L .5253 .72319 L F
.52385 .72496 m .52183 .72524 L .52328 .72363 L F
.493 .328 .585 r
.52328 .72363 m .5253 .72319 L .52525 .72077 L F
.448 .264 .538 r
.54228 .75924 m .54184 .76195 L .53961 .76191 L F
.462 .201 .431 r
.54184 .76195 m .5395 .76451 L .53961 .76191 L F
.812 .483 .433 r
.56341 .70329 m .56563 .70157 L .56312 .70167 L F
.613 .404 .575 r
.73528 .72363 m .73795 .72323 L .73805 .72032 L F
.508 .319 .559 r
.73805 .72032 m .74025 .72246 L .74032 .7204 L F
.73805 .72032 m .73795 .72323 L .74025 .72246 L F
.367 .749 .989 r
.30645 .59435 m .3058 .59533 L .30418 .59453 L F
.30645 .59435 m .30798 .59517 L .3058 .59533 L F
.351 .068 .335 r
.40858 .70122 m .40597 .70366 L .40645 .70165 L F
.982 .857 .639 r
.62612 .52946 m .62634 .53205 L .62462 .53276 L F
.959 .871 .708 r
.62634 .53205 m .62403 .53477 L .62462 .53276 L F
.62634 .53205 m .62492 .53599 L .62403 .53477 L F
.26 .335 .751 r
.34662 .7289 m .34681 .72521 L .34537 .7272 L F
.34662 .7289 m .34782 .72844 L .34681 .72521 L F
.714 .646 .779 r
.34662 .7289 m .3484 .72864 L .34782 .72844 L F
.757 .282 .115 r
.35116 .72637 m .35046 .72592 L .34984 .72707 L F
.35046 .72592 m .34873 .72481 L .34984 .72707 L F
.734 .991 .859 r
.34984 .72707 m .3484 .72864 L .34954 .72763 L F
.34984 .72707 m .34954 .72763 L .35131 .72606 L F
.282 .677 .972 r
.41818 .65332 m .41596 .65317 L .41457 .65221 L F
.569 .401 .614 r
.71504 .72031 m .7167 .72039 L .7177 .71826 L F
.7177 .71826 m .7167 .72039 L .71504 .72031 L F
.784 .75 .822 r
.51142 .72868 m .51199 .7327 L .50947 .73134 L F
.529 .187 .332 r
.51199 .7327 m .51049 .73419 L .50947 .73134 L F
.51199 .7327 m .51291 .73399 L .51049 .73419 L F
.317 .402 .792 r
.51142 .72868 m .51389 .73046 L .51199 .7327 L F
.615 .388 .55 r
.51648 .7484 m .51864 .7485 L .52108 .7455 L F
.675 .47 .599 r
.52108 .7455 m .52211 .74808 L .52209 .74574 L F
.52108 .7455 m .51864 .7485 L .52211 .74808 L F
.712 .815 .929 r
.56366 .6964 m .55981 .69662 L .56232 .6957 L F
.56366 .6964 m .55981 .69662 L .56232 .6957 L F
.936 .901 .506 r
.48717 .784 m .48632 .78646 L .48729 .78503 L F
.68 .256 .232 r
.48632 .78646 m .48962 .78674 L .48729 .78503 L F
0 0 .177 r
.58342 .75088 m .5842 .75432 L .58385 .75272 L F
.038 .32 .805 r
.5842 .75432 m .58494 .75349 L .58385 .75272 L F
.5842 .75432 m .58762 .75622 L .58494 .75349 L F
.313 .726 .977 r
.40734 .6511 m .40355 .6502 L .40556 .65031 L F
0 .488 .856 r
.40763 .6507 m .40734 .6511 L .40556 .65031 L F
.40763 .6507 m .40897 .65157 L .40734 .6511 L F
.582 .626 .861 r
.7273 .71218 m .72978 .71183 L .72843 .70897 L F
.399 .649 .959 r
.32452 .59796 m .32387 .59936 L .32276 .59805 L F
.409 .662 .963 r
.32582 .59939 m .32387 .59936 L .32452 .59796 L F
.563 .294 .466 r
.46345 .74262 m .46584 .74241 L .46659 .73945 L F
.494 .2 .395 r
.46584 .74241 m .46888 .73951 L .46659 .73945 L F
.542 0 0 r
.49249 .79219 m .4935 .79349 L .49086 .79243 L F
.49249 .79219 m .49453 .7931 L .4935 .79349 L F
.63 .336 .453 r
.55278 .75399 m .55299 .75641 L .55502 .75602 L F
.531 .786 .991 r
.32511 .71757 m .32478 .71875 L .32276 .71783 L F
.875 .518 .371 r
.60035 .66821 m .60177 .67096 L .60343 .67137 L F
.893 .59 .467 r
.60202 .67282 m .60343 .67137 L .60177 .67096 L F
.60202 .67282 m .60379 .67369 L .60343 .67137 L F
.416 .791 .993 r
.29992 .60844 m .30088 .60763 L .29901 .60711 L F
.29992 .60844 m .30193 .608 L .30088 .60763 L F
.557 .555 .808 r
.29992 .60844 m .30266 .61001 L .30193 .608 L F
.622 .96 .87 r
.57274 .67605 m .57438 .67456 L .57589 .67468 L F
.114 0 0 r
.57438 .67456 m .57772 .67371 L .57589 .67468 L F
.748 .727 .832 r
.53806 .75626 m .54182 .75492 L .53826 .75421 L F
.507 .332 .579 r
.43385 .7625 m .43598 .76226 L .436 .75954 L F
.545 .453 .701 r
.43439 .76488 m .43598 .76226 L .43385 .7625 L F
.325 .589 .94 r
.27693 .68352 m .27641 .68466 L .27549 .68458 L F
.584 .475 .696 r
.27641 .68466 m .27891 .68547 L .2767 .68453 L F
.564 .491 .731 r
.2767 .68453 m .27891 .68547 L .28082 .68438 L F
.356 .549 .905 r
.2785 .68469 m .27891 .68547 L .2767 .68453 L F
.655 .722 .898 r
.28082 .68438 m .27891 .68547 L .2785 .68469 L F
.356 .549 .905 r
.27949 .68477 m .27891 .68547 L .2785 .68469 L F
.655 .722 .898 r
.2785 .68469 m .27891 .68547 L .27816 .68473 L F
.356 .549 .905 r
.28062 .6844 m .2767 .68453 L .28082 .68438 L F
.27851 .68469 m .2767 .68453 L .28074 .6844 L F
.655 .722 .898 r
.28082 .68438 m .27816 .68473 L .27693 .68352 L F
.356 .549 .905 r
.28074 .6844 m .28062 .6844 L .28082 .68438 L F
.27949 .68477 m .27851 .68469 L .28074 .6844 L F
.325 .589 .94 r
.27693 .68352 m .27891 .68547 L .27641 .68466 L F
.624 .43 .599 r
.2767 .68453 m .27891 .68547 L .27633 .68588 L F
.649 .721 .901 r
.27633 .68588 m .27891 .68547 L .27816 .68473 L F
.27657 .68494 m .27816 .68473 L .27693 .68352 L F
.27633 .68588 m .27816 .68473 L .27657 .68494 L F
0 0 .291 r
.61878 .73166 m .61925 .73392 L .61904 .73396 L F
0 0 .105 r
.61913 .73629 m .61904 .73396 L .61925 .73392 L F
.786 .656 .72 r
.33323 .70954 m .33011 .71097 L .3309 .71025 L F
.857 .973 .866 r
.65351 .51904 m .65455 .51614 L .65622 .51862 L F
.65351 .51904 m .6524 .51855 L .65455 .51614 L F
.631 .08 0 r
.53687 .71952 m .53855 .72045 L .54024 .72067 L F
.535 0 0 r
.53855 .72045 m .54231 .7228 L .54024 .72067 L F
.431 .742 .992 r
.29693 .60724 m .29752 .60603 L .2954 .60626 L F
.29693 .60724 m .29901 .60711 L .29752 .60603 L F
.417 .228 .514 r
.31837 .62722 m .32038 .62437 L .32024 .62674 L F
.49 .303 .554 r
.32023 .62894 m .31837 .62722 L .32024 .62674 L F
.32023 .62894 m .31825 .62952 L .31837 .62722 L F
.51 .689 .948 r
.73454 .59076 m .73561 .59217 L .7375 .59182 L F
.817 .83 .859 r
.75202 .60664 m .75089 .6085 L .74998 .60645 L F
0 0 0 r
.53045 .7443 m .53232 .74231 L .53064 .74341 L F
.739 .564 .656 r
.53232 .74231 m .53045 .7443 L .53064 .74341 L F
.615 .673 .882 r
.64502 .50603 m .64203 .50552 L .64436 .50495 L F
.095 0 0 r
.64203 .50552 m .64059 .50613 L .64436 .50495 L F
.585 .588 .821 r
.37126 .7015 m .36918 .70196 L .36788 .69878 L F
.935 .762 .289 r
.58677 .72581 m .58705 .72879 L .58919 .7258 L F
.6 .83 .987 r
.42718 .65458 m .42502 .65521 L .42361 .65434 L F
.414 .044 .223 r
.48217 .73406 m .48455 .73367 L .48488 .73253 L F
.547 .164 .267 r
.48455 .73367 m .48679 .73368 L .48488 .73253 L F
.51 .208 .39 r
.48488 .73253 m .48679 .73368 L .48718 .73221 L F
.622 .96 .87 r
.57274 .67605 m .57201 .676 L .57438 .67456 L F
.725 .559 .665 r
.52304 .76249 m .52362 .76499 L .52117 .76544 L F
.236 .172 .578 r
.52452 .76181 m .52304 .76249 L .5234 .76192 L F
.562 .455 .689 r
.52566 .7625 m .52304 .76249 L .52452 .76181 L F
.52566 .7625 m .52362 .76499 L .52304 .76249 L F
.75 .38 .353 r
.56045 .74253 m .55681 .74218 L .55846 .74072 L F
.977 .864 .658 r
.55846 .74072 m .55681 .74218 L .55742 .73962 L F
.574 0 0 r
.5467 .70333 m .54282 .70115 L .54403 .7023 L F
.779 .817 .882 r
.72333 .58704 m .72134 .58833 L .72031 .58763 L F
.666 .143 0 r
.72137 .58838 m .72246 .5899 L .7213 .58868 L F
.72137 .58838 m .72344 .59051 L .72246 .5899 L F
.72134 .58833 m .72137 .58837 L .72137 .58838 L F
.72137 .58837 m .72344 .59051 L .72137 .58838 L F
0 0 0 r
.72422 .58687 m .72333 .58704 L .72132 .58877 L F
.691 .349 .391 r
.72031 .58763 m .72246 .5899 L .71923 .58975 L F
0 0 0 r
.72132 .58878 m .72132 .58877 L .72127 .58881 L F
.72422 .58687 m .72132 .58877 L .72132 .58878 L F
.72126 .58888 m .72127 .58881 L .72095 .58909 L F
.72422 .58687 m .72127 .58881 L .72126 .58888 L F
.666 .143 0 r
.72134 .58833 m .72137 .58838 L .72031 .58763 L F
.72137 .58838 m .7213 .58868 L .72031 .58763 L F
.532 .347 .575 r
.30155 .62106 m .30392 .61792 L .30193 .61865 L F
0 0 0 r
.42959 .83887 m .42742 .83975 L .42737 .83986 L F
.42737 .83986 m .42742 .83975 L .42959 .83887 L F
.554 .395 .621 r
.3342 .67378 m .33643 .67353 L .33633 .67101 L F
.476 .345 .623 r
.33465 .67692 m .33643 .67353 L .3342 .67378 L F
.523 .163 .296 r
.52123 .73124 m .52609 .72862 L .52105 .72908 L F
.52123 .73124 m .52372 .73117 L .52609 .72862 L F
0 0 .538 r
.52609 .72862 m .52592 .72594 L .52371 .7263 L F
.52609 .72862 m .52649 .72897 L .52592 .72594 L F
.671 .349 .42 r
.52609 .72862 m .52641 .73107 L .52649 .72897 L F
.52609 .72862 m .52372 .73117 L .52641 .73107 L F
.925 .75 .646 r
.60096 .71471 m .60263 .71557 L .60204 .71801 L F
.803 .597 .623 r
.72137 .58661 m .72187 .58314 L .71877 .58261 L F
.834 .68 .692 r
.54579 .69465 m .54838 .69652 L .54726 .69413 L F
.875 .462 .234 r
.54579 .69465 m .54741 .69763 L .54838 .69652 L F
.772 .31 .147 r
.54741 .69763 m .55061 .6989 L .54838 .69652 L F
.774 .302 .12 r
.54838 .69652 m .55061 .6989 L .55196 .69877 L F
.202 .253 .692 r
.33252 .69069 m .33399 .69224 L .33405 .69009 L F
.704 .597 .734 r
.57865 .70119 m .57939 .70446 L .58207 .70218 L F
.52 .429 .693 r
.71368 .71539 m .71578 .71637 L .71576 .71523 L F
.297 0 .275 r
.75157 .60208 m .74876 .60383 L .7487 .60448 L F
.75 .696 .8 r
.75157 .60208 m .7487 .60448 L .74876 .60383 L F
.59 .441 .647 r
.36429 .68203 m .36213 .68467 L .36212 .68247 L F
.519 .684 .942 r
.54726 .69413 m .55302 .69643 L .5497 .69342 L F
.723 .738 .862 r
.5497 .69342 m .55302 .69643 L .55306 .69329 L F
.8 .58 .605 r
.44647 .74477 m .44994 .74291 L .44645 .74275 L F
.44647 .74477 m .44988 .74544 L .44994 .74291 L F
.758 .545 .608 r
.44994 .74291 m .44988 .74544 L .4533 .74553 L F
.537 .279 .471 r
.39617 .69591 m .39842 .6957 L .39872 .69346 L F
.455 .208 .45 r
.39872 .69346 m .40048 .69513 L .40083 .69325 L F
.39872 .69346 m .39842 .6957 L .40048 .69513 L F
.479 .198 .408 r
.59091 .71606 m .58729 .72022 L .58918 .71765 L F
.59091 .71606 m .58898 .72028 L .58729 .72022 L F
.498 .411 .688 r
.58729 .72022 m .58898 .72028 L .58915 .71783 L F
.641 .361 .478 r
.59048 .71602 m .58918 .71765 L .58714 .71569 L F
.59091 .71606 m .58918 .71765 L .59048 .71602 L F
.498 .411 .688 r
.58729 .72022 m .58791 .71924 L .58918 .71765 L F
0 0 .295 r
.58918 .71765 m .58726 .71604 L .58714 .71569 L F
.58726 .71604 m .58599 .71498 L .5864 .71524 L F
.58726 .71604 m .5864 .71524 L .58714 .71569 L F
.58918 .71765 m .58835 .71415 L .58599 .71498 L F
.58918 .71765 m .5892 .71722 L .58835 .71415 L F
.498 .411 .688 r
.58791 .71924 m .5892 .71722 L .58918 .71765 L F
.58894 .71763 m .58915 .71783 L .5892 .71722 L F
.58729 .72022 m .58915 .71783 L .58894 .71763 L F
.484 .16 .341 r
.42587 .68792 m .42299 .6899 L .42349 .68821 L F
.765 .671 .759 r
.72954 .70811 m .72679 .70899 L .72843 .70897 L F
.259 0 0 r
.72843 .70897 m .73167 .70732 L .72954 .70811 L F
.897 .905 .822 r
.75616 .60578 m .75851 .60515 L .75692 .60555 L F
.644 .151 .065 r
.54553 .72364 m .54782 .72519 L .54877 .72413 L F
.722 .247 .12 r
.54782 .72519 m .55124 .72639 L .54877 .72413 L F
.613 .326 .459 r
.46888 .73951 m .47122 .73969 L .47164 .73773 L F
.512 .224 .413 r
.47122 .73969 m .47391 .73751 L .47164 .73773 L F
.167 0 .138 r
.53056 .75701 m .52801 .75943 L .52965 .75845 L F
.322 .008 .267 r
.52965 .75845 m .53244 .75626 L .53056 .75701 L F
.725 .506 .595 r
.51401 .7236 m .51539 .7248 L .51183 .72596 L F
.787 .717 .786 r
.48821 .7534 m .49226 .7547 L .49055 .75044 L F
.674 .139 0 r
.48821 .7534 m .49045 .75519 L .49226 .7547 L F
.229 .385 .813 r
.49055 .75044 m .49226 .7547 L .49348 .75275 L F
.508 .26 .474 r
.49045 .75519 m .49348 .75275 L .49226 .7547 L F
0 0 .428 r
.62042 .72836 m .61996 .72817 L .61969 .72687 L F
.62075 .72903 m .61996 .72817 L .62042 .72836 L F
0 0 .148 r
.61956 .72801 m .61996 .72817 L .61919 .72921 L F
.62028 .72564 m .61996 .72817 L .61956 .72801 L F
.309 .278 .66 r
.61996 .72817 m .61878 .73166 L .61919 .72921 L F
.466 .051 .167 r
.58564 .66883 m .58773 .66978 L .58872 .66795 L F
.662 .322 .386 r
.58773 .66978 m .59105 .66798 L .58872 .66795 L F
.229 0 0 r
.37728 .67185 m .37596 .67304 L .37407 .67351 L F
0 0 0 r
.37865 .67071 m .37596 .67304 L .37728 .67185 L F
.777 .278 0 r
.58616 .73191 m .58748 .73383 L .58869 .73448 L F
.407 .663 .964 r
.58974 .73333 m .58869 .73448 L .58748 .73383 L F
.58974 .73333 m .59068 .73453 L .58869 .73448 L F
.405 .03 .209 r
.38857 .69918 m .38785 .70046 L .39069 .69885 L F
.539 .093 .138 r
.5159 .70862 m .51814 .709 L .51946 .70733 L F
.77 .37 .296 r
.51814 .709 m .5214 .70978 L .51946 .70733 L F
.771 .369 .291 r
.51946 .70733 m .5214 .70978 L .52298 .70947 L F
0 .516 .715 r
.28754 .59271 m .28944 .59293 L .29124 .59315 L F
.29 0 0 r
.28944 .59293 m .29299 .59363 L .29124 .59315 L F
.985 .706 .387 r
.55102 .70024 m .55196 .69877 L .55061 .6989 L F
.55102 .70024 m .55205 .70134 L .55196 .69877 L F
.509 .307 .542 r
.55196 .69877 m .55425 .7005 L .55534 .70046 L F
.55196 .69877 m .55205 .70134 L .55425 .7005 L F
.895 .592 .466 r
.62662 .54156 m .62867 .54423 L .62651 .54403 L F
.72 .468 .545 r
.6305 .54621 m .62651 .54403 L .62867 .54423 L F
.724 .699 .827 r
.72978 .71183 m .73097 .7136 L .73288 .71233 L F
.867 .584 .507 r
.31461 .72473 m .31656 .72347 L .31527 .72234 L F
.31461 .72473 m .31684 .72612 L .31656 .72347 L F
.321 .662 .973 r
.31656 .72347 m .3168 .72239 L .31527 .72234 L F
.867 .584 .507 r
.31461 .72473 m .31656 .72347 L .3168 .72239 L F
.31461 .72473 m .31684 .72612 L .31656 .72347 L F
.616 .498 .696 r
.33327 .69603 m .33607 .69846 L .33554 .69557 L F
.33327 .69603 m .33387 .6989 L .33607 .69846 L F
.622 .423 .592 r
.53078 .79763 m .53304 .7981 L .53332 .7956 L F
.53078 .79763 m .53304 .7981 L .53332 .7956 L F
.554 .932 .841 r
.53498 .79456 m .53332 .7956 L .53491 .79429 L F
0 0 .305 r
.53332 .7956 m .53423 .79678 L .53491 .79429 L F
.53332 .7956 m .53304 .7981 L .53423 .79678 L F
.486 .633 .918 r
.73281 .71848 m .73209 .72034 L .73096 .7186 L F
.73281 .71848 m .7344 .72022 L .73209 .72034 L F
.307 .247 .625 r
.44185 .74584 m .44358 .7476 L .44403 .74499 L F
.44185 .74584 m .44216 .7483 L .44358 .7476 L F
.447 .507 .827 r
.54837 .75959 m .55079 .76187 L .55189 .75886 L F
.799 .683 .737 r
.73571 .62359 m .73184 .6219 L .73479 .62072 L F
.73571 .62359 m .73383 .6252 L .73184 .6219 L F
.783 .751 .824 r
.73657 .62162 m .73571 .62359 L .73479 .62072 L F
.628 .362 .495 r
.47681 .73694 m .47926 .7371 L .47954 .73488 L F
.477 .183 .386 r
.47926 .7371 m .48217 .73406 L .47954 .73488 L F
.669 .782 .934 r
.34365 .73157 m .34145 .73259 L .33998 .73129 L F
.52 .344 .582 r
.34145 .73259 m .34365 .73157 L .33998 .73129 L F
.34145 .73259 m .3434 .73402 L .34365 .73157 L F
.168 0 0 r
.38114 .71613 m .3805 .71511 L .3826 .71441 L F
.38114 .71613 m .37897 .71672 L .3805 .71511 L F
.649 .618 .805 r
.44771 .66823 m .44405 .66603 L .44657 .66661 L F
.822 .806 .836 r
.44994 .66561 m .44771 .66823 L .44657 .66661 L F
.548 .379 .604 r
.44985 .66742 m .44771 .66823 L .44994 .66561 L F
.55 .425 .663 r
.44985 .66742 m .448 .67006 L .44771 .66823 L F
.483 .7 .965 r
.43147 .65347 m .43055 .65494 L .42932 .65403 L F
.43147 .65347 m .43259 .65475 L .43055 .65494 L F
.663 .678 .854 r
.30762 .72583 m .30905 .72758 L .31095 .72648 L F
.556 .427 .659 r
.33821 .66576 m .34033 .66534 L .34003 .66294 L F
.523 .317 .542 r
.33821 .66576 m .34014 .66767 L .34033 .66534 L F
.421 .311 .623 r
.33821 .66576 m .33847 .66819 L .34014 .66767 L F
.618 .445 .626 r
.47646 .75679 m .47625 .75897 L .47346 .75858 L F
.355 0 .034 r
.47625 .75897 m .47191 .76113 L .47346 .75858 L F
.609 .601 .817 r
.36788 .69878 m .36571 .69945 L .36433 .6964 L F
.076 .092 .573 r
.58671 .72813 m .58616 .73191 L .58705 .72879 L F
.935 .762 .289 r
.58677 .72581 m .58671 .72813 L .58705 .72879 L F
.658 .264 .287 r
.46384 .78891 m .46517 .78699 L .46741 .78881 L F
.324 0 0 r
.57673 .67972 m .5756 .68043 L .57333 .68039 L F
.57353 .68023 m .57333 .68039 L .57263 .68037 L F
.57673 .67972 m .57333 .68039 L .57353 .68023 L F
0 0 0 r
.57154 .68174 m .57079 .68152 L .57333 .68039 L F
.324 0 0 r
.5756 .68043 m .57533 .6806 L .57263 .68037 L F
0 0 0 r
.57328 .68043 m .57333 .68039 L .57378 .68019 L F
.566 .396 .61 r
.57378 .68019 m .57333 .68039 L .57263 .68037 L F
.47 .136 .318 r
.57263 .68037 m .57328 .68043 L .57378 .68019 L F
.57328 .68043 m .57533 .6806 L .57378 .68019 L F
0 0 0 r
.57171 .68163 m .57328 .68043 L .57378 .68019 L F
.57154 .68174 m .57333 .68039 L .57171 .68163 L F
.566 .396 .61 r
.57333 .68039 m .57079 .68152 L .57263 .68037 L F
.006 0 0 r
.57873 .67881 m .57533 .6806 L .57673 .67972 L F
.292 .594 .948 r
.3208 .59619 m .32019 .59739 L .31884 .5964 L F
.3208 .59619 m .32276 .59805 L .32019 .59739 L F
.832 .726 .748 r
.63083 .50837 m .63212 .51151 L .63069 .51095 L F
.883 .722 .678 r
.63212 .51151 m .62923 .51331 L .63069 .51095 L F
.63212 .51151 m .63105 .5138 L .62923 .51331 L F
.521 .647 .913 r
.73941 .70688 m .73884 .70854 L .73717 .70723 L F
.73941 .70688 m .74208 .70934 L .73884 .70854 L F
.473 .81 .999 r
.37898 .70228 m .37787 .70328 L .37697 .70254 L F
.37898 .70228 m .38005 .70292 L .37787 .70328 L F
.076 .092 .573 r
.58671 .72813 m .58723 .73122 L .58616 .73191 L F
.107 .156 .631 r
.58723 .73122 m .58748 .73383 L .58616 .73191 L F
.517 .299 .521 r
.29267 .63242 m .29526 .6295 L .29303 .63005 L F
.67 .696 .865 r
.73765 .71846 m .73859 .71519 L .73656 .71516 L F
.549 .858 .997 r
.59957 .75899 m .6013 .75805 L .59903 .7589 L F
.59957 .75899 m .60228 .7585 L .6013 .75805 L F
0 0 .553 r
.55826 .73047 m .5588 .73125 L .55826 .73091 L F
.8 .342 .148 r
.55826 .73091 m .56021 .73328 L .56209 .73366 L F
0 0 .553 r
.5588 .73125 m .56021 .73328 L .55826 .73091 L F
.324 0 0 r
.55796 .73071 m .55826 .73091 L .56008 .73143 L F
.55609 .73008 m .55826 .73091 L .55796 .73071 L F
.8 .342 .148 r
.55826 .73091 m .56209 .73366 L .56008 .73143 L F
.471 .255 .503 r
.40618 .68776 m .40788 .68931 L .40823 .6873 L F
.40618 .68776 m .40597 .68988 L .40788 .68931 L F
.442 .182 .423 r
.43299 .68169 m .43036 .68415 L .43088 .68217 L F
.219 0 0 r
.26222 .58729 m .26577 .5881 L .26391 .58762 L F
.813 .676 .713 r
.61686 .70079 m .61823 .7039 L .61858 .70153 L F
.997 .796 .443 r
.50171 .73651 m .50242 .73849 L .50286 .73758 L F
.178 0 .164 r
.50492 .73657 m .50286 .73758 L .50242 .73849 L F
.786 .656 .72 r
.33323 .70954 m .3342 .71309 L .33011 .71097 L F
.565 .522 .766 r
.33644 .71251 m .3342 .71309 L .33323 .70954 L F
.53 .301 .512 r
.32053 .71334 m .31743 .71534 L .32048 .71454 L F
.859 .981 .69 r
.31828 .71776 m .32048 .71454 L .31743 .71534 L F
.239 0 0 r
.49886 .7899 m .50016 .78988 L .49675 .78954 L F
.213 0 0 r
.50168 .79041 m .50016 .78988 L .49886 .7899 L F
.50168 .79041 m .50199 .7901 L .50016 .78988 L F
.008 .539 .85 r
.50168 .79041 m .49886 .7899 L .49758 .78925 L F
.50168 .79041 m .50082 .79017 L .49958 .7891 L F
.50082 .79017 m .49758 .78925 L .49958 .7891 L F
.768 .509 .543 r
.49675 .78954 m .49347 .78708 L .49399 .78832 L F
.681 .139 0 r
.49558 .78953 m .49675 .78954 L .49399 .78832 L F
.084 .596 .887 r
.49758 .78925 m .49675 .78954 L .49558 .78953 L F
.49758 .78925 m .49886 .7899 L .49675 .78954 L F
.002 0 0 r
.49958 .7891 m .49758 .78925 L .4958 .78957 L F
.49958 .7891 m .4958 .78957 L .49809 .78782 L F
.49958 .7891 m .49809 .78782 L .49869 .78736 L F
.537 0 0 r
.50146 .79062 m .50168 .79041 L .49958 .7891 L F
.50148 .79064 m .50168 .79041 L .50146 .79062 L F
.213 0 0 r
.50168 .79041 m .50255 .79017 L .50199 .7901 L F
0 .548 .714 r
.36832 .64907 m .37082 .64922 L .37186 .64929 L F
.049 0 0 r
.37082 .64922 m .37407 .64923 L .37186 .64929 L F
.685 .25 .211 r
.63981 .51552 m .64096 .51416 L .63988 .51317 L F
.63981 .51552 m .64328 .51595 L .64096 .51416 L F
.617 .812 .975 r
.73717 .70723 m .73514 .70804 L .73407 .707 L F
.502 0 0 r
.44988 .74544 m .45183 .74671 L .4533 .74553 L F
.553 .054 .024 r
.45183 .74671 m .45557 .74566 L .4533 .74553 L F
.533 .16 .279 r
.52299 .73946 m .52111 .73913 L .5232 .73738 L F
.574 .353 .543 r
.52541 .73699 m .52299 .73946 L .5232 .73738 L F
0 0 .204 r
.52791 .76186 m .52965 .75845 L .52801 .75943 L F
.538 .428 .677 r
.33345 .6854 m .33516 .68163 L .33332 .68225 L F
.188 .687 .914 r
.40707 .66569 m .40769 .66524 L .40572 .66489 L F
.40707 .66569 m .40939 .66581 L .40769 .66524 L F
.622 .707 .907 r
.72642 .61808 m .72671 .61995 L .72597 .62 L F
.72642 .61808 m .72597 .62 L .72618 .62045 L F
.632 .19 0 r
.72597 .62 m .72734 .62207 L .72618 .62045 L F
.42 .414 .746 r
.43462 .77868 m .43552 .77523 L .4334 .77554 L F
.43462 .77868 m .43632 .77849 L .43552 .77523 L F
.51 .458 .734 r
.43462 .77868 m .4373 .78105 L .43632 .77849 L F
.779 .817 .882 r
.72333 .58704 m .72031 .58763 L .72095 .58909 L F
0 0 0 r
.72422 .58687 m .72555 .586 L .72333 .58704 L F
.224 0 .238 r
.32716 .61605 m .32959 .61336 L .32925 .61556 L F
.503 .262 .482 r
.32959 .61336 m .33132 .61503 L .32925 .61556 L F
.32959 .61336 m .33173 .61293 L .33132 .61503 L F
.565 .822 .994 r
.28232 .59057 m .2819 .59199 L .28038 .59093 L F
.28232 .59057 m .28392 .59145 L .2819 .59199 L F
.494 .816 1 r
.72054 .72084 m .72288 .72043 L .72189 .71969 L F
.713 .664 .801 r
.55306 .69329 m .55578 .69322 L .5552 .69232 L F
.55306 .69329 m .5569 .6952 L .55578 .69322 L F
.902 .962 .82 r
.5552 .69232 m .55578 .69322 L .55797 .69003 L F
.277 .204 .591 r
.53204 .74867 m .53345 .75036 L .53329 .74823 L F
.5 .244 .458 r
.53124 .75074 m .53345 .75036 L .53204 .74867 L F
0 .131 .677 r
.57016 .72353 m .57038 .72265 L .56851 .72041 L F
0 .047 .612 r
.57016 .72353 m .57157 .72578 L .57038 .72265 L F
.302 0 0 r
.59674 .66798 m .59886 .66823 L .60035 .66821 L F
.838 .515 .442 r
.59905 .67018 m .60035 .66821 L .59886 .66823 L F
.59905 .67018 m .60177 .67096 L .60035 .66821 L F
.49 0 0 r
.50799 .78967 m .50609 .78918 L .50462 .78985 L F
.688 .185 .043 r
.54264 .73403 m .54144 .73466 L .5393 .7332 L F
.864 .603 .071 r
.54547 .73747 m .54466 .73402 L .54264 .73403 L F
.563 .117 .15 r
.54466 .73402 m .54144 .73466 L .54264 .73403 L F
.52 .386 .638 r
.34003 .66294 m .34189 .65957 L .33959 .66125 L F
.549 .272 .447 r
.64131 .54093 m .64436 .54253 L .64041 .54359 L F
.64131 .54093 m .64355 .54095 L .64436 .54253 L F
0 .04 .57 r
.55299 .74055 m .55378 .73944 L .55294 .73689 L F
.109 .28 .757 r
.55378 .73944 m .55483 .74197 L .55299 .74055 L F
.55378 .73944 m .55299 .74055 L .5516 .74016 L F
.55378 .73944 m .55483 .74197 L .55299 .74055 L F
.425 .285 .586 r
.55483 .74197 m .55296 .74303 L .55299 .74055 L F
.225 0 .043 r
.5829 .67062 m .58475 .6705 L .58564 .66883 L F
.467 .047 .159 r
.58564 .66883 m .58475 .6705 L .58773 .66978 L F
.311 .652 .97 r
.74557 .5868 m .74248 .58552 L .74457 .58554 L F
.454 .703 .974 r
.74714 .58551 m .74557 .5868 L .74457 .58554 L F
.74714 .58551 m .74888 .58722 L .74557 .5868 L F
.366 0 0 r
.41694 .66418 m .41349 .66457 L .41509 .6637 L F
.394 0 .08 r
.54826 .75076 m .55053 .75056 L .55168 .74906 L F
.39 .447 .799 r
.45844 .77472 m .45704 .77628 L .45579 .773 L F
.554 .704 .94 r
.45844 .77472 m .45932 .77609 L .45704 .77628 L F
.566 .603 .849 r
.4964 .75941 m .49756 .75635 L .49525 .75711 L F
.4964 .75941 m .49869 .75916 L .49756 .75635 L F
.68 .718 .878 r
.64763 .50577 m .64502 .50603 L .64436 .50495 L F
.64763 .50577 m .64436 .50495 L .64661 .50455 L F
0 0 0 r
.64661 .50455 m .64502 .50603 L .64763 .50577 L F
.64661 .50455 m .64392 .50748 L .64502 .50603 L F
.611 .145 .123 r
.51596 .79432 m .51836 .79488 L .51487 .79484 L F
.539 .059 0 r
.58495 .7138 m .58382 .7125 L .58324 .71421 L F
.632 .316 .418 r
.58382 .7125 m .58599 .71498 L .58605 .71289 L F
.675 .497 .638 r
.56194 .74034 m .56171 .74302 L .56387 .74006 L F
.519 .396 .652 r
.436 .75954 m .43809 .75911 L .43787 .75615 L F
.513 .343 .588 r
.43598 .76226 m .43809 .75911 L .436 .75954 L F
.937 .746 .618 r
.59856 .68513 m .59825 .68745 L .59715 .68441 L F
.875 .888 .839 r
.63988 .51317 m .64325 .5114 L .64238 .51075 L F
.96 .645 .384 r
.72722 .71953 m .72818 .71813 L .72511 .71764 L F
.72722 .71953 m .72851 .72037 L .72818 .71813 L F
.521 .333 .566 r
.72818 .71813 m .72851 .72037 L .73096 .7186 L F
0 .525 .717 r
.55441 .70991 m .55345 .70979 L .551 .70954 L F
0 .451 .847 r
.55441 .70991 m .55447 .70939 L .55345 .70979 L F
.55441 .70991 m .55723 .7109 L .55447 .70939 L F
.109 0 0 r
.53995 .73963 m .54241 .73975 L .54377 .73969 L F
.797 .989 .738 r
.54504 .73672 m .54241 .73975 L .54317 .73798 L F
0 0 0 r
.54504 .73672 m .54317 .73798 L .54474 .73709 L F
.864 .603 .071 r
.54547 .73747 m .54504 .73672 L .54524 .73648 L F
0 0 0 r
.54504 .73672 m .54474 .73709 L .54606 .73634 L F
.864 .603 .071 r
.54524 .73648 m .54504 .73672 L .54466 .73402 L F
.881 .973 .839 r
.54377 .73969 m .54504 .73672 L .54547 .73747 L F
0 .558 .765 r
.39228 .64864 m .39604 .64916 L .39421 .64921 L F
.39228 .64864 m .39506 .64888 L .39604 .64916 L F
.209 .729 .716 r
.39708 .64879 m .39604 .64916 L .39506 .64888 L F
.39708 .64879 m .39733 .64875 L .39604 .64916 L F
.123 .615 .91 r
.39604 .64916 m .39733 .64875 L .39854 .64971 L F
.578 .488 .716 r
.43336 .77318 m .43556 .77284 L .4349 .77036 L F
.522 .339 .574 r
.4334 .77554 m .43556 .77284 L .43336 .77318 L F
.422 .341 .659 r
.30373 .61328 m .30505 .61032 L .30266 .61001 L F
.30373 .61328 m .30543 .61287 L .30505 .61032 L F
.497 .425 .705 r
.30373 .61328 m .30492 .6143 L .30543 .61287 L F
.30373 .61328 m .30442 .61583 L .30492 .6143 L F
.767 .542 .593 r
.5279 .73655 m .52541 .73699 L .52577 .73464 L F
.402 0 .156 r
.3544 .65593 m .35298 .65505 L .35212 .65594 L F
.3544 .65593 m .35524 .6547 L .35298 .65505 L F
.171 0 0 r
.38474 .66881 m .38446 .66764 L .38663 .66728 L F
.38474 .66881 m .38275 .6694 L .38446 .66764 L F
.12 .661 .841 r
.58441 .67781 m .58366 .67751 L .58124 .67755 L F
.621 .12 .042 r
.58696 .67772 m .58366 .67751 L .58441 .67781 L F
.991 .733 .387 r
.61892 .72009 m .61927 .7182 L .61909 .71773 L F
.61892 .72009 m .61973 .72084 L .61927 .7182 L F
.821 .57 .559 r
.6036 .67846 m .60692 .67672 L .60347 .67606 L F
.6036 .67846 m .60689 .67907 L .60692 .67672 L F
.704 .597 .734 r
.57865 .70119 m .58207 .70218 L .58025 .70087 L F
.696 .775 .912 r
.58223 .70132 m .58207 .70218 L .58025 .70087 L F
.97 .803 .619 r
.60116 .69037 m .59922 .69248 L .59888 .68967 L F
.60116 .69037 m .60047 .69337 L .59922 .69248 L F
.505 .19 .365 r
.26736 .6054 m .2691 .60652 L .26729 .60645 L F
.545 .15 .243 r
.26982 .60546 m .2691 .60652 L .26736 .6054 L F
.171 0 .003 r
.53543 .79801 m .53874 .79536 L .53757 .7972 L F
0 0 0 r
.53757 .7972 m .53966 .7944 L .53944 .7964 L F
.992 .756 .388 r
.53916 .79528 m .53966 .7944 L .53944 .7964 L F
0 0 0 r
.53913 .79484 m .53966 .7944 L .53874 .79536 L F
.54037 .79313 m .53966 .7944 L .53913 .79484 L F
.54088 .79244 m .53966 .7944 L .54037 .79313 L F
.54088 .79244 m .53747 .79425 L .53966 .7944 L F
.53747 .79425 m .53736 .79431 L .53966 .7944 L F
.218 .688 .94 r
.54034 .79383 m .53966 .7944 L .53879 .79381 L F
.54114 .79384 m .53966 .7944 L .54034 .79383 L F
.274 .725 .958 r
.5365 .79375 m .53966 .7944 L .53736 .79431 L F
.241 .708 .945 r
.53879 .79381 m .53966 .7944 L .5365 .79375 L F
.992 .756 .388 r
.53879 .79381 m .53966 .7944 L .53916 .79528 L F
0 0 0 r
.53757 .7972 m .53874 .79536 L .53966 .7944 L F
.652 .122 0 r
.56374 .73582 m .56287 .73441 L .56209 .73366 L F
.56374 .73582 m .56489 .73658 L .56287 .73441 L F
.549 .371 .592 r
.448 .67006 m .44809 .67379 L .44589 .6742 L F
.55 .425 .663 r
.44985 .66742 m .4504 .66985 L .448 .67006 L F
.632 .436 .599 r
.4507 .67283 m .448 .67006 L .4504 .66985 L F
.4507 .67283 m .44809 .67379 L .448 .67006 L F
.554 .521 .773 r
.43932 .66012 m .43797 .66232 L .4373 .66065 L F
.43932 .66012 m .43987 .66178 L .43797 .66232 L F
.888 .918 .838 r
.72189 .71969 m .72511 .71764 L .72277 .71805 L F
.937 .88 .754 r
.62403 .53477 m .62492 .53599 L .62327 .53876 L F
.458 .257 .518 r
.32038 .62437 m .32254 .62147 L .32224 .62375 L F
.36 .204 .53 r
.32212 .62631 m .32038 .62437 L .32224 .62375 L F
.32212 .62631 m .32024 .62674 L .32038 .62437 L F
.375 .579 .92 r
.56995 .76163 m .56906 .76243 L .56999 .76091 L F
.131 .19 .657 r
.56923 .76306 m .56999 .76091 L .56906 .76243 L F
0 0 0 r
.60527 .75728 m .60455 .75768 L .60228 .7585 L F
.60734 .75639 m .60455 .75768 L .60527 .75728 L F
.5 0 0 r
.73584 .62669 m .73639 .62721 L .73482 .6258 L F
.387 .717 .988 r
.73584 .62669 m .73994 .62683 L .73841 .6258 L F
.73584 .62669 m .73841 .6258 L .73639 .62721 L F
.601 .44 .635 r
.52769 .7204 m .52525 .72077 L .52744 .71799 L F
.532 .324 .544 r
.52769 .7204 m .5253 .72319 L .52525 .72077 L F
.601 .44 .635 r
.52769 .7204 m .52525 .72077 L .52744 .71799 L F
.532 .324 .544 r
.52769 .7204 m .5253 .72319 L .52525 .72077 L F
.945 .956 .666 r
.57147 .75976 m .56995 .76163 L .57182 .75842 L F
.565 .351 .549 r
.54518 .69308 m .54579 .69465 L .5474 .69289 L F
.539 .279 .469 r
.63838 .54413 m .63579 .54642 L .63612 .54475 L F
.538 .734 .965 r
.7375 .59182 m .74166 .59323 L .73986 .59162 L F
.447 .634 .934 r
.74166 .59323 m .74297 .5918 L .73986 .59162 L F
.74166 .59323 m .74383 .5933 L .74297 .5918 L F
.351 0 0 r
.56914 .68298 m .568 .68411 L .56535 .68438 L F
.663 .902 .567 r
.5692 .68247 m .56914 .68298 L .57079 .68152 L F
.5692 .68247 m .568 .68411 L .56914 .68298 L F
.545 .453 .701 r
.43439 .76488 m .43648 .76451 L .43598 .76226 L F
.506 .411 .682 r
.43439 .76488 m .43685 .76699 L .43648 .76451 L F
.43439 .76488 m .43472 .76767 L .43685 .76699 L F
.991 .737 .385 r
.619 .72248 m .61973 .72084 L .61892 .72009 L F
.619 .72248 m .61971 .72328 L .61973 .72084 L F
.296 0 .104 r
.34639 .65891 m .34516 .65826 L .34429 .65939 L F
.34639 .65891 m .34737 .65752 L .34516 .65826 L F
.896 .547 .375 r
.56533 .75941 m .56404 .76068 L .56394 .75942 L F
0 0 .384 r
.56646 .75594 m .56637 .75856 L .56533 .75941 L F
.513 .261 .471 r
.56637 .75856 m .56404 .76068 L .56533 .75941 L F
.294 .042 .35 r
.4297 .68647 m .42886 .68449 L .43036 .68415 L F
.4297 .68647 m .42796 .68732 L .42886 .68449 L F
.447 0 0 r
.52202 .71048 m .52362 .71128 L .52503 .71163 L F
.73 .315 .261 r
.52362 .71128 m .52439 .71145 L .52503 .71163 L F
.696 .165 0 r
.52298 .70947 m .52503 .71163 L .52575 .71183 L F
.73 .315 .261 r
.52439 .71145 m .52711 .71208 L .52503 .71163 L F
.696 .165 0 r
.52575 .71183 m .52503 .71163 L .52633 .71232 L F
.048 .565 .873 r
.52711 .71208 m .52826 .71263 L .52633 .71232 L F
.418 0 .123 r
.52362 .76499 m .52624 .76418 L .52458 .76654 L F
.589 .177 .228 r
.52458 .76654 m .52624 .76418 L .52804 .76607 L F
.419 .257 .552 r
.42018 .6764 m .42244 .6733 L .41996 .6735 L F
.418 0 .123 r
.52362 .76499 m .52458 .76654 L .5227 .76555 L F
0 .411 .842 r
.5227 .76555 m .52458 .76654 L .52343 .76566 L F
.133 0 0 r
.52151 .76537 m .52362 .76499 L .5227 .76555 L F
0 .411 .842 r
.5227 .76555 m .52343 .76566 L .52238 .76486 L F
.133 0 0 r
.52117 .76544 m .52151 .76537 L .5227 .76555 L F
0 0 0 r
.72785 .5852 m .72555 .586 L .72422 .58687 L F
.552 .256 .418 r
.64928 .53721 m .64588 .54069 L .64595 .53913 L F
.64928 .53721 m .64826 .54046 L .64588 .54069 L F
.585 .312 .47 r
.65143 .53761 m .64826 .54046 L .64928 .53721 L F
.215 .699 .93 r
.44081 .6655 m .443 .66555 L .44405 .66603 L F
.217 .598 .948 r
.4451 .6654 m .44405 .66603 L .443 .66555 L F
.4451 .6654 m .44657 .66661 L .44405 .66603 L F
.576 .281 .43 r
.46091 .7444 m .46345 .74262 L .46115 .74281 L F
.659 .963 .774 r
.55015 .68851 m .54761 .69049 L .54843 .68931 L F
.494 .484 .775 r
.5474 .69289 m .54843 .68931 L .54761 .69049 L F
.275 0 .258 r
.49715 .72365 m .49465 .72618 L .49641 .72549 L F
.409 .142 .394 r
.49641 .72549 m .49898 .72283 L .49715 .72365 L F
.175 0 .364 r
.33432 .70131 m .33607 .69846 L .33387 .6989 L F
.327 .116 .434 r
.33011 .89194 m .33216 .88887 L .33204 .89136 L F
.33216 .88887 m .33011 .89194 L .33204 .89136 L F
.02 0 0 r
.55425 .7005 m .55828 .70053 L .55534 .70046 L F
.832 .849 .859 r
.50082 .75722 m .50361 .75664 L .50339 .75694 L F
.12 .114 .576 r
.50508 .75545 m .50361 .75664 L .5035 .75372 L F
0 0 0 r
.50508 .75545 m .50339 .75694 L .50361 .75664 L F
.455 .052 .184 r
.54843 .68931 m .55178 .68719 L .55015 .68851 L F
.43 .097 .297 r
.41871 .69318 m .41783 .69546 L .41574 .69575 L F
.457 .261 .525 r
.42066 .69251 m .41871 .69318 L .42083 .69037 L F
.458 .159 .37 r
.42066 .69251 m .41783 .69546 L .41871 .69318 L F
.535 .295 .499 r
.41078 .68488 m .41307 .68458 L .41323 .68217 L F
.468 .24 .485 r
.41323 .68217 m .41513 .684 L .41541 .68197 L F
.41323 .68217 m .41307 .68458 L .41513 .684 L F
.093 .45 .883 r
.72852 .61992 m .72671 .61995 L .72642 .61808 L F
.72852 .61992 m .72963 .62132 L .72671 .61995 L F
.323 0 .249 r
.29709 .62879 m .29945 .62639 L .29793 .627 L F
.546 .639 .894 r
.73859 .71519 m .74058 .71835 L .7421 .71745 L F
.973 .763 .56 r
.59467 .73464 m .59432 .73696 L .59331 .73394 L F
.513 .343 .588 r
.33633 .67101 m .33839 .67057 L .33847 .66819 L F
.517 .367 .616 r
.33633 .67101 m .33852 .67315 L .33839 .67057 L F
.33633 .67101 m .33643 .67353 L .33852 .67315 L F
.637 .169 0 r
.73144 .62245 m .7317 .62306 L .72963 .62132 L F
.73144 .62245 m .73258 .62406 L .7317 .62306 L F
.256 0 .173 r
.74525 .61285 m .74316 .61374 L .74245 .6149 L F
.641 .612 .805 r
.47057 .77556 m .47181 .77865 L .47431 .77805 L F
.37 0 .192 r
.4716 .77965 m .47431 .77805 L .47181 .77865 L F
.182 0 .166 r
.55124 .73768 m .55032 .73626 L .5524 .73686 L F
.55124 .73768 m .54832 .73964 L .55032 .73626 L F
.599 .353 .515 r
.41367 .6963 m .41331 .69855 L .41086 .69854 L F
.506 .284 .511 r
.41574 .69575 m .41331 .69855 L .41367 .6963 L F
.554 .916 .955 r
.75473 .58986 m .75235 .5911 L .75139 .58851 L F
.75473 .58986 m .75481 .59008 L .75235 .5911 L F
.471 .282 .542 r
.75481 .59008 m .75243 .5937 L .75235 .5911 L F
.087 0 0 r
.3851 .70163 m .38785 .70046 L .38596 .70125 L F
.457 .878 .929 r
.27892 .65444 m .27839 .65519 L .28028 .65447 L F
.27892 .65444 m .27588 .65523 L .27839 .65519 L F
.439 .236 .505 r
.32224 .62375 m .32254 .62147 L .32445 .62082 L F
.49 .147 .312 r
.65941 .53353 m .65906 .53489 L .65683 .53498 L F
.38 .012 .208 r
.66193 .53309 m .65906 .53489 L .65941 .53353 L F
.578 .043 0 r
.47431 .78866 m .47636 .78947 L .47294 .78901 L F
.591 .833 .99 r
.32422 .72609 m .32555 .72677 L .32768 .7261 L F
.476 .345 .623 r
.33465 .67692 m .33647 .67644 L .33643 .67353 L F
.454 .379 .682 r
.33465 .67692 m .33683 .67876 L .33647 .67644 L F
.33465 .67692 m .3351 .67921 L .33683 .67876 L F
.663 .623 .799 r
.43626 .65704 m .43382 .65786 L .43259 .65475 L F
.581 .564 .8 r
.4373 .66065 m .43382 .65786 L .43626 .65704 L F
.623 .29 .387 r
.51183 .72596 m .51539 .7248 L .51318 .72845 L F
.739 .985 .903 r
.51785 .7265 m .51318 .72845 L .51539 .7248 L F
.304 .654 .971 r
.25449 .58507 m .25467 .58645 L .25314 .58526 L F
.25449 .58507 m .25658 .58648 L .25467 .58645 L F
.495 0 0 r
.5715 .70938 m .57392 .7107 L .57491 .71038 L F
.715 .396 .437 r
.57392 .7107 m .57753 .70962 L .57491 .71038 L F
.477 .183 .386 r
.47926 .7371 m .48146 .73675 L .48217 .73406 L F
.472 .176 .381 r
.48146 .73675 m .48455 .73367 L .48217 .73406 L F
.932 .638 .462 r
.48166 .78147 m .48302 .78354 L .48426 .78271 L F
.891 .713 .655 r
.6115 .6871 m .61277 .69036 L .61292 .68779 L F
.667 .751 .913 r
.31618 .72815 m .31762 .72956 L .31971 .72875 L F
.647 .579 .764 r
.66591 .52461 m .66385 .52605 L .66254 .52218 L F
.493 .303 .551 r
.66566 .52678 m .66385 .52605 L .66591 .52461 L F
.427 .373 .696 r
.66566 .52678 m .66429 .52805 L .66385 .52605 L F
.821 .88 .888 r
.59617 .71929 m .59464 .72117 L .59339 .71988 L F
.845 .945 .584 r
.59464 .72117 m .59382 .72178 L .59339 .71988 L F
.59464 .72117 m .59354 .72293 L .59382 .72178 L F
.813 .601 .617 r
.62662 .54156 m .62333 .54338 L .6234 .54105 L F
.62662 .54156 m .62651 .54403 L .62333 .54338 L F
.12 .114 .576 r
.50508 .75545 m .5035 .75372 L .50589 .75359 L F
.573 .389 .594 r
.32716 .61605 m .32711 .61829 L .32495 .61869 L F
.504 .202 .388 r
.32495 .61869 m .32647 .62027 L .32445 .62082 L F
.32495 .61869 m .32711 .61829 L .32647 .62027 L F
.851 .623 .593 r
.60851 .68419 m .6115 .6871 L .61136 .68546 L F
.525 .785 .992 r
.30177 .75586 m .30337 .75698 L .30166 .75589 L F
.30166 .75589 m .30337 .75698 L .30177 .75586 L F
.818 .847 .871 r
.30571 .75425 m .30471 .75542 L .30467 .75467 L F
.30571 .75425 m .30177 .75586 L .3045 .75294 L F
.532 .848 .998 r
.30537 .75662 m .30597 .75538 L .30458 .75307 L F
.3046 .75334 m .30458 .75307 L .3045 .75294 L F
.30537 .75662 m .30458 .75307 L .3046 .75334 L F
.818 .847 .871 r
.30467 .75467 m .30337 .75698 L .30177 .75586 L F
.30471 .75542 m .30337 .75698 L .30467 .75467 L F
.494 .772 .994 r
.30177 .75586 m .30337 .75698 L .30537 .75662 L F
.062 0 0 r
.36628 .72258 m .36476 .72265 L .3674 .72146 L F
.36628 .72258 m .36397 .72334 L .36476 .72265 L F
.28 .479 .875 r
.32319 .70939 m .32291 .70825 L .32405 .70698 L F
.98 .688 .364 r
.5518 .76483 m .55182 .76703 L .55058 .76401 L F
.642 .548 .733 r
.55406 .76416 m .5518 .76483 L .55079 .76187 L F
.442 .219 .478 r
.55368 .76673 m .5518 .76483 L .55406 .76416 L F
.55368 .76673 m .55182 .76703 L .5518 .76483 L F
.642 .548 .733 r
.55406 .76416 m .55079 .76187 L .55381 .76213 L F
.623 .537 .737 r
.55381 .76213 m .5518 .76483 L .55079 .76187 L F
.858 .693 .677 r
.54146 .74266 m .54281 .7454 L .54475 .74547 L F
.54146 .74266 m .54022 .74531 L .54281 .7454 L F
.521 .749 .979 r
.64884 .50422 m .64763 .50577 L .64661 .50455 L F
.64884 .50422 m .64763 .50577 L .64661 .50455 L F
.532 .889 .667 r
.55978 .68228 m .55684 .68452 L .55824 .68319 L F
0 0 0 r
.55684 .68452 m .55659 .68482 L .55824 .68319 L F
.697 .633 .782 r
.30762 .72583 m .30944 .72283 L .30781 .72347 L F
.667 .298 .336 r
.5279 .73655 m .52757 .73889 L .52541 .73699 L F
.474 .262 .51 r
.53135 .73421 m .53006 .73614 L .5279 .73655 L F
.428 .091 .291 r
.52984 .73845 m .5279 .73655 L .53006 .73614 L F
.52984 .73845 m .52757 .73889 L .5279 .73655 L F
.489 .321 .579 r
.32902 .61772 m .32716 .61605 L .32925 .61556 L F
.32902 .61772 m .32711 .61829 L .32716 .61605 L F
.752 .663 .763 r
.71578 .71637 m .71921 .71763 L .71853 .71471 L F
.71578 .71637 m .7177 .71826 L .71921 .71763 L F
.851 .818 .816 r
.71853 .71471 m .71921 .71763 L .72114 .71516 L F
.489 .35 .618 r
.52902 .71786 m .52769 .7204 L .52744 .71799 L F
0 .318 .803 r
.74889 .7138 m .74704 .71317 L .74707 .71173 L F
.74889 .7138 m .74899 .71439 L .74704 .71317 L F
.505 .825 .517 r
.50291 .73107 m .50192 .73206 L .50345 .73118 L F
.50291 .73107 m .50058 .73334 L .50192 .73206 L F
.126 .642 .89 r
.29502 .59379 m .29644 .59428 L .29299 .59363 L F
.19 .654 .939 r
.29692 .59369 m .29644 .59428 L .29502 .59379 L F
.29692 .59369 m .29856 .5945 L .29644 .59428 L F
.867 .529 .409 r
.59557 .72606 m .59676 .72878 L .59424 .72793 L F
.651 .527 .699 r
.36429 .68203 m .36499 .68435 L .36213 .68467 L F
.547 .471 .721 r
.36495 .68794 m .36213 .68467 L .36499 .68435 L F
.36495 .68794 m .36312 .6887 L .36213 .68467 L F
.586 .23 .332 r
.65143 .53599 m .65372 .53743 L .65143 .53761 L F
.65143 .53599 m .65382 .53611 L .65372 .53743 L F
.779 .547 .584 r
.52111 .73913 m .51975 .74003 L .5181 .73968 L F
.533 .16 .279 r
.52299 .73946 m .51975 .74003 L .52111 .73913 L F
.375 .341 .693 r
.33432 .70131 m .33481 .70476 L .33624 .70358 L F
0 0 .524 r
.33703 .70657 m .33624 .70358 L .33481 .70476 L F
.72 .301 .25 r
.46785 .77096 m .4636 .77012 L .46234 .77135 L F
.46785 .77096 m .46585 .77214 L .4636 .77012 L F
.962 .908 .716 r
.46712 .76851 m .46585 .77214 L .46785 .77096 L F
.191 0 0 r
.38872 .71309 m .38825 .71203 L .39044 .71164 L F
.38872 .71309 m .38686 .7136 L .38825 .71203 L F
.616 .6 .811 r
.33884 .72292 m .34134 .72263 L .33989 .71965 L F
.518 .044 .067 r
.39585 .66513 m .3946 .66564 L .39235 .66536 L F
.398 0 0 r
.39794 .66505 m .3946 .66564 L .39585 .66513 L F
.468 .2 .424 r
.37588 .67539 m .37407 .67351 L .37596 .67304 L F
.37588 .67539 m .3736 .67589 L .37407 .67351 L F
.557 .694 .931 r
.37537 .70076 m .37474 .70294 L .37335 .70125 L F
.37537 .70076 m .37697 .70254 L .37474 .70294 L F
.822 .806 .836 r
.44994 .66561 m .44657 .66661 L .44859 .6661 L F
.355 .219 .554 r
.45204 .66641 m .44994 .66561 L .45208 .66523 L F
.45204 .66641 m .44985 .66742 L .44994 .66561 L F
.358 0 0 r
.44859 .6661 m .45208 .66523 L .44994 .66561 L F
.155 .653 .912 r
.41818 .65332 m .42022 .65348 L .42166 .65407 L F
.247 .628 .959 r
.42234 .65325 m .42166 .65407 L .42022 .65348 L F
.42234 .65325 m .42361 .65434 L .42166 .65407 L F
.951 .87 .721 r
.74907 .71607 m .74863 .72043 L .74946 .71846 L F
.553 .606 .86 r
.34134 .72263 m .34208 .72423 L .34398 .72393 L F
.488 .589 .881 r
.33615 .60499 m .33279 .60256 L .33509 .60145 L F
.346 .392 .766 r
.33572 .60199 m .33528 .6021 L .33509 .60145 L F
.33751 .60352 m .33509 .60145 L .33686 .60177 L F
.199 0 0 r
.33686 .60177 m .33509 .60145 L .33347 .60139 L F
.33674 .60172 m .33347 .60139 L .33555 .60124 L F
.33686 .60177 m .33665 .60175 L .33674 .60172 L F
.33665 .60175 m .33347 .60139 L .33674 .60172 L F
.346 .392 .766 r
.33751 .60352 m .33615 .60499 L .33528 .6021 L F
.33751 .60352 m .33528 .6021 L .33572 .60199 L F
.297 .317 .713 r
.33751 .60352 m .33817 .60682 L .33615 .60499 L F
.438 .33 .634 r
.33817 .60682 m .33655 .60779 L .33615 .60499 L F
.864 .949 .868 r
.74464 .62375 m .74296 .62698 L .74495 .62394 L F
.74464 .62375 m .74213 .62627 L .74296 .62698 L F
.365 .05 .293 r
.40327 .69184 m .40597 .68988 L .40372 .69032 L F
.689 .743 .893 r
.73878 .72639 m .7423 .72691 L .74115 .7255 L F
.764 .711 .803 r
.74115 .7255 m .7423 .72691 L .74404 .72563 L F
.227 .615 .954 r
.51333 .79033 m .51136 .79086 L .51006 .78968 L F
.649 .721 .901 r
.27633 .68588 m .27693 .68352 L .27549 .68458 L F
.488 .21 .419 r
.36903 .67917 m .36631 .68165 L .36709 .68 L F
.016 0 0 r
.56727 .67818 m .56876 .67815 L .57028 .67719 L F
.038 0 0 r
.56727 .67818 m .56692 .6792 L .56876 .67815 L F
.856 .754 .75 r
.53807 .74016 m .53609 .74287 L .53449 .74189 L F
.53807 .74016 m .53449 .74189 L .53671 .74155 L F
.775 .549 .592 r
.53671 .74155 m .53995 .73963 L .53807 .74016 L F
.574 .404 .613 r
.43978 .751 m .4376 .7538 L .43987 .75345 L F
.513 .349 .596 r
.43787 .75615 m .43987 .75345 L .4376 .7538 L F
.571 .512 .75 r
.33345 .6854 m .33413 .68766 L .33627 .6872 L F
.564 .38 .59 r
.33413 .68766 m .33637 .68967 L .33627 .6872 L F
.33413 .68766 m .33405 .69009 L .33637 .68967 L F
.53 .23 .403 r
.51461 .76416 m .51934 .76247 L .51336 .7616 L F
.51461 .76416 m .51746 .76459 L .51934 .76247 L F
.693 .445 .543 r
.51934 .76247 m .51746 .76459 L .51902 .76422 L F
.51934 .76247 m .51902 .76422 L .51904 .76192 L F
.459 .045 .166 r
.51902 .76422 m .5234 .76192 L .51904 .76192 L F
.51902 .76422 m .52189 .76398 L .5234 .76192 L F
0 0 0 r
.5234 .76192 m .52334 .7632 L .52452 .76181 L F
.5234 .76192 m .52189 .76398 L .52334 .7632 L F
.696 .265 .221 r
.53765 .74917 m .5369 .74853 L .53943 .74822 L F
.53765 .74917 m .53552 .74848 L .5369 .74853 L F
.161 0 0 r
.33344 .72341 m .33183 .72401 L .32994 .72399 L F
.515 .675 .937 r
.33431 .72177 m .33566 .72327 L .33344 .72341 L F
.599 .709 .921 r
.33745 .72264 m .33576 .72338 L .33431 .72177 L F
0 0 .403 r
.33822 .7191 m .33835 .7221 L .33745 .72264 L F
.356 .83 .82 r
.33835 .7221 m .33458 .7233 L .33706 .72273 L F
.33773 .72247 m .33706 .72273 L .33745 .72264 L F
.33835 .7221 m .33706 .72273 L .33773 .72247 L F
.515 .675 .937 r
.33566 .72327 m .33576 .72338 L .33537 .72339 L F
.33566 .72327 m .33537 .72339 L .33344 .72341 L F
0 0 0 r
.33576 .72338 m .33183 .72401 L .33344 .72341 L F
.511 .786 .995 r
.72978 .71183 m .73288 .71233 L .73211 .71134 L F
0 .533 .749 r
.73579 .71187 m .73211 .71134 L .73288 .71233 L F
0 0 0 r
.36766 .72168 m .3674 .72146 L .36947 .72082 L F
.36766 .72168 m .36628 .72258 L .3674 .72146 L F
.597 .414 .605 r
.59277 .69006 m .59281 .69289 L .5903 .69041 L F
.59277 .69006 m .59281 .69289 L .5903 .69041 L F
.631 .419 .577 r
.51635 .73434 m .51881 .7343 L .51906 .73186 L F
.54 .353 .576 r
.51881 .7343 m .52123 .73124 L .51906 .73186 L F
.891 .827 .778 r
.54015 .74203 m .54377 .73969 L .54241 .73975 L F
.54015 .74203 m .54146 .74266 L .54377 .73969 L F
.881 .973 .839 r
.54377 .73969 m .54241 .73975 L .54504 .73672 L F
.065 0 0 r
.54574 .73982 m .54241 .73975 L .54377 .73969 L F
0 .4 .775 r
.55358 .72721 m .55227 .72694 L .55124 .72639 L F
.55358 .72721 m .55512 .72811 L .55227 .72694 L F
.175 0 .364 r
.33432 .70131 m .33574 .70083 L .33607 .69846 L F
.375 .341 .693 r
.33432 .70131 m .33624 .70358 L .33574 .70083 L F
.628 .503 .691 r
.55079 .76187 m .55381 .76213 L .55189 .75886 L F
.613 .576 .788 r
.55265 .75852 m .55079 .76187 L .55189 .75886 L F
.55265 .75852 m .55381 .76213 L .55079 .76187 L F
0 0 0 r
.55058 .76401 m .55381 .76213 L .55079 .76187 L F
.63 .959 .811 r
.74634 .62244 m .74495 .62394 L .74771 .62162 L F
.74634 .62244 m .74464 .62375 L .74495 .62394 L F
.891 .713 .655 r
.6115 .6871 m .60988 .68978 L .61277 .69036 L F
.847 .697 .696 r
.60988 .68978 m .61288 .69253 L .61277 .69036 L F
.413 .093 .312 r
.4894 .73208 m .4913 .73185 L .49241 .72877 L F
.515 .312 .542 r
.49241 .72877 m .49449 .72838 L .49465 .72618 L F
.431 .109 .316 r
.4913 .73185 m .49449 .72838 L .49241 .72877 L F
.498 .353 .615 r
.30392 .61792 m .30492 .6143 L .30442 .61583 L F
0 0 0 r
.2785 .60416 m .2772 .60444 L .27508 .60479 L F
.28073 .60358 m .2772 .60444 L .2785 .60416 L F
.266 .324 .737 r
.57333 .74972 m .57189 .75107 L .5711 .74763 L F
.266 .323 .736 r
.57333 .74972 m .57409 .75304 L .57189 .75107 L F
.402 .482 .827 r
.73656 .71516 m .73777 .71355 L .73579 .71187 L F
.73656 .71516 m .73859 .71519 L .73777 .71355 L F
.498 .434 .715 r
.36533 .68998 m .36312 .6887 L .36495 .68794 L F
.36533 .68998 m .36345 .69034 L .36312 .6887 L F
.085 .615 .868 r
.46363 .77726 m .46278 .77754 L .46149 .77678 L F
.052 .554 .883 r
.46249 .7766 m .46363 .77726 L .46149 .77678 L F
.547 0 0 r
.46284 .77689 m .46363 .77726 L .46249 .7766 L F
.085 .615 .868 r
.46363 .77726 m .46466 .77776 L .46278 .77754 L F
.547 0 0 r
.46466 .77834 m .46363 .77726 L .46284 .77689 L F
.085 .615 .868 r
.46363 .77726 m .46637 .77796 L .46466 .77776 L F
0 0 .521 r
.57051 .74478 m .5711 .74763 L .57047 .74558 L F
.864 .618 .564 r
.6069 .68132 m .60853 .67938 L .60689 .67907 L F
.6069 .68132 m .60856 .68178 L .60853 .67938 L F
.741 .565 .656 r
.31564 .85804 m .31879 .85692 L .31694 .85952 L F
.79 .798 .859 r
.31564 .85804 m .31694 .85952 L .31879 .85692 L F
.527 .709 .955 r
.31564 .85804 m .31954 .85923 L .31694 .85952 L F
0 0 0 r
.57418 .76201 m .57346 .76433 L .5734 .76413 L F
.868 .814 .332 r
.57413 .76032 m .57346 .76433 L .57418 .76201 L F
.104 .567 .913 r
.57917 .71379 m .58087 .71471 L .57901 .71444 L F
.557 .443 .679 r
.52371 .7263 m .52592 .72594 L .5253 .72319 L F
.676 .818 .952 r
.74297 .72449 m .74115 .7255 L .74404 .72563 L F
.83 .854 .865 r
.74297 .72449 m .74404 .72563 L .74652 .72318 L F
.231 .322 .751 r
.73667 .72229 m .73528 .72363 L .7344 .72022 L F
.622 .437 .611 r
.73528 .72363 m .73731 .72441 L .73795 .72323 L F
.887 .878 .821 r
.73667 .72229 m .73731 .72441 L .73528 .72363 L F
.466 .173 .384 r
.46121 .76385 m .45957 .76242 L .46231 .76194 L F
.46121 .76385 m .45906 .76427 L .45957 .76242 L F
.973 .902 .687 r
.30079 .73917 m .30074 .74077 L .30185 .73724 L F
.30079 .73917 m .30074 .74077 L .30185 .73724 L F
0 0 0 r
.50825 .72569 m .50577 .72775 L .50677 .72689 L F
.511 .295 .522 r
.43978 .751 m .44192 .75061 L .44216 .7483 L F
.464 .332 .616 r
.44192 .75061 m .44358 .7476 L .44216 .7483 L F
.494 .284 .523 r
.42299 .6899 m .42066 .69251 L .42083 .69037 L F
.553 .44 .679 r
.4349 .77036 m .43685 .76699 L .43472 .76767 L F
.598 .5 .715 r
.30266 .61001 m .30452 .60727 L .30193 .608 L F
.30266 .61001 m .30505 .61032 L .30452 .60727 L F
.507 .536 .82 r
.34398 .72393 m .34537 .7272 L .34681 .72521 L F
.557 .476 .719 r
.36533 .68998 m .36346 .69218 L .36345 .69034 L F
.473 .821 .998 r
.30185 .73724 m .30392 .73685 L .30178 .73654 L F
.30185 .73724 m .30392 .73685 L .30178 .73654 L F
.75 .534 .603 r
.30185 .73724 m .29851 .73957 L .30079 .73917 L F
.293 .596 .948 r
.48433 .77457 m .48537 .77601 L .48693 .77608 L F
.274 .379 .789 r
.48893 .77755 m .48812 .77857 L .48693 .77608 L F
.054 .059 .544 r
.48886 .77764 m .48859 .77894 L .48812 .77857 L F
.48893 .77755 m .48859 .77894 L .48886 .77764 L F
.373 .385 .743 r
.48693 .77608 m .4887 .77914 L .48893 .77755 L F
0 0 .309 r
.4887 .77914 m .48869 .77995 L .48893 .77755 L F
.054 .059 .544 r
.48893 .77755 m .48878 .7791 L .48859 .77894 L F
0 .084 .642 r
.48693 .77608 m .48859 .77894 L .48812 .77857 L F
.48859 .77894 m .4887 .77914 L .48812 .77857 L F
.392 .394 .742 r
.48537 .77601 m .48857 .77902 L .48693 .77608 L F
.48857 .77902 m .4887 .77914 L .48859 .77894 L F
.48857 .77902 m .48859 .77894 L .48693 .77608 L F
.189 .127 .552 r
.48812 .77857 m .48869 .77995 L .4887 .77914 L F
.054 .059 .544 r
.48878 .7791 m .48869 .77995 L .48812 .77857 L F
.392 .394 .742 r
.48537 .77601 m .4887 .77914 L .48693 .77608 L F
0 0 0 r
.57154 .68174 m .5692 .68247 L .57079 .68152 L F
.183 .657 .933 r
.30798 .59517 m .30976 .59529 L .31124 .59599 L F
.182 .691 .901 r
.30976 .59529 m .31337 .59571 L .31124 .59599 L F
.527 .567 .839 r
.65809 .51944 m .65696 .52224 L .65622 .51862 L F
.65809 .51944 m .66023 .52189 L .65696 .52224 L F
.784 .541 .569 r
.65696 .52224 m .65696 .52449 L .66023 .52481 L F
.55 .391 .619 r
.66023 .52189 m .65696 .52449 L .65696 .52224 L F
0 .344 .819 r
.73383 .6252 m .73543 .62542 L .73258 .62406 L F
.73383 .6252 m .73482 .6258 L .73543 .62542 L F
.58 .314 .477 r
.4427 .67825 m .44074 .67637 L .44304 .67592 L F
.4427 .67825 m .43988 .67918 L .44074 .67637 L F
.788 .661 .722 r
.71578 .71637 m .7167 .72039 L .7177 .71826 L F
.71578 .71637 m .7167 .72039 L .7177 .71826 L F
.223 0 .023 r
.39877 .70726 m .39748 .70916 L .39561 .70904 L F
.377 .012 .212 r
.40065 .70639 m .39748 .70916 L .39877 .70726 L F
.29 .776 .911 r
.28378 .65439 m .28229 .65419 L .28028 .65447 L F
.025 .597 .724 r
.28585 .65416 m .28229 .65419 L .28378 .65439 L F
.133 0 0 r
.52117 .76544 m .5227 .76555 L .51948 .76581 L F
.253 .19 .59 r
.45902 .76652 m .45739 .7649 L .45906 .76427 L F
.45902 .76652 m .45725 .76758 L .45739 .7649 L F
.402 .219 .515 r
.49449 .72838 m .49641 .72549 L .49465 .72618 L F
.662 .186 .112 r
.5214 .70978 m .52202 .71048 L .52298 .70947 L F
.447 0 0 r
.52202 .71048 m .52503 .71163 L .52298 .70947 L F
.186 0 .173 r
.45725 .76758 m .45665 .76959 L .45576 .76908 L F
0 0 .093 r
.45902 .76652 m .45665 .76959 L .45725 .76758 L F
.01 0 .176 r
.66566 .52678 m .66362 .52989 L .66429 .52805 L F
.915 .547 .11 r
.74715 .59753 m .74859 .60156 L .74714 .59877 L F
0 0 .061 r
.74715 .59753 m .74714 .59877 L .74765 .59622 L F
.717 .986 .811 r
.5046 .72945 m .50433 .72914 L .50577 .72775 L F
.5046 .72945 m .50345 .73118 L .50433 .72914 L F
.63 .948 .944 r
.33347 .60139 m .33279 .60256 L .33133 .60165 L F
.33347 .60139 m .33509 .60145 L .33279 .60256 L F
.399 .798 .985 r
.65696 .52449 m .65942 .52419 L .66023 .52481 L F
.948 .942 .745 r
.66023 .52481 m .66116 .52112 L .66254 .52218 L F
.66023 .52481 m .65942 .52419 L .66116 .52112 L F
.667 .24 .223 r
.72344 .59051 m .72635 .59077 L .72564 .59095 L F
.274 0 0 r
.72635 .59077 m .72901 .59095 L .72564 .59095 L F
.37 .202 .519 r
.4992 .72066 m .50101 .72002 L .50091 .71774 L F
.385 .19 .489 r
.4992 .72066 m .50092 .72192 L .50101 .72002 L F
.4992 .72066 m .49898 .72283 L .50092 .72192 L F
0 .063 .626 r
.36461 .86685 m .36328 .86374 L .36133 .86467 L F
.834 .68 .692 r
.54579 .69465 m .54726 .69413 L .5474 .69289 L F
.519 .684 .942 r
.54726 .69413 m .5497 .69342 L .5474 .69289 L F
.22 0 0 r
.39561 .70904 m .39748 .70916 L .39452 .7107 L F
.748 .727 .832 r
.53806 .75626 m .54151 .75652 L .54182 .75492 L F
.517 0 0 r
.53806 .75626 m .54014 .75703 L .54151 .75652 L F
0 0 .449 r
.54182 .75492 m .54151 .75652 L .54255 .75565 L F
.488 .892 .762 r
.54151 .75652 m .54014 .75703 L .54255 .75565 L F
.488 .424 .711 r
.54399 .75853 m .54228 .75924 L .54151 .75652 L F
.955 .68 .476 r
.54014 .75703 m .54228 .75924 L .54151 .75652 L F
.21 0 .329 r
.29945 .62639 m .30158 .62332 L .29987 .62408 L F
.585 .445 .658 r
.75266 .59605 m .75068 .59874 L .75096 .59677 L F
.343 0 .137 r
.39281 .69842 m .3949 .69797 L .39617 .69591 L F
.307 0 .117 r
.39617 .69591 m .39695 .69744 L .39842 .6957 L F
.39617 .69591 m .3949 .69797 L .39695 .69744 L F
0 0 .545 r
.56851 .72041 m .5687 .71994 L .56706 .71751 L F
0 .047 .609 r
.56851 .72041 m .57038 .72265 L .5687 .71994 L F
.835 .976 .673 r
.55915 .74459 m .56045 .74253 L .56171 .74302 L F
.55915 .74459 m .55849 .74503 L .56045 .74253 L F
.523 .358 .599 r
.43987 .75345 m .44192 .75061 L .43978 .751 L F
.869 .675 .637 r
.61288 .69253 m .61389 .6957 L .61421 .69328 L F
.219 .014 .374 r
.32053 .71334 m .32179 .71253 L .32319 .70939 L F
.267 .093 .45 r
.32053 .71334 m .32048 .71454 L .32179 .71253 L F
.97 .776 .585 r
.60215 .71152 m .60113 .70875 L .60177 .70971 L F
.538 .428 .677 r
.33345 .6854 m .33552 .68512 L .33516 .68163 L F
.571 .512 .75 r
.33345 .6854 m .33627 .6872 L .33552 .68512 L F
0 0 0 r
.55978 .68228 m .56047 .68195 L .56184 .68145 L F
.55978 .68228 m .55824 .68319 L .56047 .68195 L F
.392 .082 .315 r
.41541 .68197 m .41754 .68147 L .4183 .67917 L F
.458 .143 .342 r
.4183 .67917 m .41971 .68098 L .42019 .67853 L F
.4183 .67917 m .41754 .68147 L .41971 .68098 L F
.472 .13 .306 r
.57992 .67324 m .58228 .6729 L .5829 .67062 L F
.358 .03 .266 r
.5829 .67062 m .58438 .67226 L .58475 .6705 L F
.5829 .67062 m .58228 .6729 L .58438 .67226 L F
.29 0 .089 r
.27121 .60592 m .26982 .60546 L .27292 .6045 L F
.167 0 0 r
.27508 .60479 m .27121 .60592 L .27292 .6045 L F
.239 0 0 r
.59023 .67722 m .58908 .67781 L .58696 .67772 L F
.66 .229 .212 r
.59167 .67702 m .58908 .67781 L .59023 .67722 L F
.356 .696 .983 r
.26974 .58755 m .26926 .58864 L .26778 .58762 L F
.26974 .58755 m .27134 .58866 L .26926 .58864 L F
.577 .521 .755 r
.43932 .66012 m .4373 .66065 L .43626 .65704 L F
.424 .823 .982 r
.60673 .75331 m .60712 .7527 L .6072 .75262 L F
.354 .049 .301 r
.6072 .75262 m .6072 .75263 L .60673 .75331 L F
.627 .96 .826 r
.60657 .75387 m .60706 .75283 L .60673 .75331 L F
.998 .794 .495 r
.60673 .75331 m .60734 .75639 L .60657 .75387 L F
.60675 .75339 m .60631 .75573 L .60734 .75639 L F
.60673 .75331 m .60672 .75339 L .60675 .75339 L F
.60672 .75339 m .60631 .75573 L .60675 .75339 L F
.627 .96 .826 r
.60681 .75338 m .60982 .75175 L .60715 .75269 L F
.60657 .75387 m .6075 .75326 L .60681 .75338 L F
.6075 .75326 m .60982 .75175 L .60681 .75338 L F
.60706 .75283 m .60715 .75269 L .60712 .7527 L F
.60657 .75387 m .60715 .75269 L .60706 .75283 L F
.354 .049 .301 r
.6072 .75263 m .60631 .75573 L .60672 .75339 L F
.60706 .75283 m .60672 .75339 L .60673 .75331 L F
.6072 .75263 m .60672 .75339 L .60706 .75283 L F
.627 .96 .826 r
.60706 .75283 m .60712 .7527 L .60673 .75331 L F
.34 0 0 r
.73141 .58488 m .72785 .5852 L .7299 .58557 L F
.69 .331 .361 r
.7299 .58557 m .7334 .58564 L .73141 .58488 L F
.902 .962 .82 r
.5552 .69232 m .55797 .69003 L .55805 .69022 L F
0 0 0 r
.55917 .68843 m .55805 .69022 L .55797 .69003 L F
.638 .203 .2 r
.47636 .78947 m .4799 .78948 L .47874 .79104 L F
.694 .271 .237 r
.47874 .79104 m .4799 .78948 L .48195 .79136 L F
.574 .888 .99 r
.60228 .7585 m .60403 .7573 L .6013 .75805 L F
.60228 .7585 m .60455 .75768 L .60403 .7573 L F
.626 .277 .359 r
.7334 .58564 m .73592 .5873 L .7366 .58498 L F
.533 .277 .474 r
.73869 .58704 m .7366 .58498 L .73592 .5873 L F
.73869 .58704 m .73933 .58451 L .7366 .58498 L F
.503 .183 .356 r
.44809 .67379 m .44531 .67578 L .44589 .6742 L F
.668 .881 .512 r
.56182 .68621 m .56095 .68768 L .56348 .6842 L F
.311 0 .054 r
.56539 .68508 m .56348 .6842 L .56535 .68438 L F
.56539 .68508 m .56182 .68621 L .56348 .6842 L F
.52 .386 .638 r
.34003 .66294 m .34204 .66267 L .34189 .65957 L F
.562 .451 .685 r
.34033 .66534 m .34204 .66267 L .34003 .66294 L F
.608 .168 .178 r
.52503 .79149 m .52273 .79012 L .52151 .79146 L F
.254 .191 .591 r
.45758 .77135 m .45576 .76908 L .45665 .76959 L F
.45758 .77135 m .45579 .773 L .45576 .76908 L F
.481 .331 .6 r
.3351 .67921 m .33702 .68117 L .33683 .67876 L F
.3351 .67921 m .33516 .68163 L .33702 .68117 L F
.744 .64 .745 r
.72288 .72043 m .72622 .72114 L .72511 .71764 L F
.264 .34 .755 r
.72511 .71764 m .72622 .72114 L .72722 .71953 L F
.295 .381 .781 r
.72622 .72114 m .72856 .72291 L .72722 .71953 L F
.424 .729 .989 r
.33407 .70847 m .33323 .70954 L .33104 .70812 L F
.219 .437 .859 r
.33407 .70847 m .33561 .71046 L .33323 .70954 L F
.565 .522 .766 r
.33644 .71251 m .33323 .70954 L .33561 .71046 L F
.677 .301 .327 r
.54724 .75635 m .54949 .75852 L .54599 .75728 L F
.722 .986 .8 r
.56182 .68621 m .55917 .68843 L .56095 .68768 L F
.813 .676 .713 r
.61686 .70079 m .61533 .70357 L .61823 .7039 L F
.814 .666 .699 r
.61533 .70357 m .61661 .70668 L .61823 .7039 L F
.725 .293 .223 r
.55294 .73689 m .55124 .73768 L .5524 .73686 L F
.462 .738 .988 r
.41309 .65105 m .41237 .65238 L .41106 .65148 L F
.41309 .65105 m .41457 .65221 L .41237 .65238 L F
.61 .428 .611 r
.54381 .75105 m .54547 .75304 L .54598 .75099 L F
.54381 .75105 m .54375 .75346 L .54547 .75304 L F
.856 .404 .113 r
.49399 .78832 m .49347 .78708 L .49215 .78711 L F
.568 .324 .507 r
.44403 .74499 m .44647 .74477 L .44645 .74275 L F
.457 .177 .399 r
.54547 .75304 m .54826 .75076 L .54598 .75099 L F
.925 .75 .646 r
.60096 .71471 m .60204 .71801 L .60098 .71733 L F
.584 .277 .415 r
.47991 .78106 m .48166 .78147 L .48308 .77854 L F
.369 .085 .345 r
.3132 .63716 m .31386 .63508 L .31571 .63448 L F
0 0 0 r
.28543 .6377 m .28315 .64003 L .28478 .63904 L F
.528 .856 .573 r
.28543 .6377 m .28642 .63668 L .28809 .63527 L F
.136 0 .418 r
.28478 .63904 m .28642 .63668 L .28543 .6377 L F
.607 .077 0 r
.64059 .50613 m .64392 .50748 L .64436 .50495 L F
.64059 .50613 m .64096 .50711 L .64392 .50748 L F
.79 .787 .849 r
.52791 .76186 m .52566 .7625 L .52452 .76181 L F
.52791 .76186 m .52452 .76181 L .52686 .76185 L F
0 0 .204 r
.52791 .76186 m .52918 .76132 L .52965 .75845 L F
.615 .24 .309 r
.52559 .76439 m .52755 .76213 L .52334 .7632 L F
0 0 .231 r
.52771 .76218 m .52791 .76186 L .52686 .76185 L F
.52914 .76274 m .52892 .76258 L .52771 .76218 L F
.52892 .76258 m .52791 .76186 L .52771 .76218 L F
.505 .131 .264 r
.52686 .76185 m .52787 .76175 L .52914 .76274 L F
.615 .24 .309 r
.52755 .76213 m .52787 .76175 L .52713 .76199 L F
.52755 .76213 m .52713 .76199 L .52334 .7632 L F
0 0 .231 r
.52914 .76274 m .52918 .76132 L .52791 .76186 L F
.775 .76 .84 r
.62875 .52718 m .63173 .52712 L .6304 .52464 L F
.017 0 0 r
.63129 .52716 m .63173 .52712 L .62875 .52718 L F
.333 .524 .894 r
.6304 .52464 m .63173 .52712 L .63331 .52612 L F
.428 .862 .757 r
.63331 .52612 m .63173 .52712 L .63129 .52716 L F
0 0 0 r
.71802 .58391 m .71877 .58261 L .7162 .58509 L F
.374 .567 .912 r
.7162 .58509 m .72031 .58763 L .71957 .58797 L F
.27 .35 .762 r
.7162 .58509 m .71957 .58797 L .71802 .58391 L F
.543 0 0 r
.44735 .78597 m .45045 .78673 L .44852 .7867 L F
.336 0 0 r
.45045 .78673 m .45405 .78761 L .44852 .7867 L F
.45045 .78673 m .45279 .78703 L .45405 .78761 L F
.941 .702 .549 r
.35369 .72605 m .34984 .72707 L .35131 .72606 L F
.406 0 .098 r
.35923 .65357 m .3628 .65171 L .36062 .65196 L F
.452 .14 .345 r
.51127 .74844 m .51067 .75015 L .50833 .75034 L F
.506 .365 .623 r
.51258 .74766 m .51067 .75015 L .51127 .74844 L F
.186 .687 .912 r
.74457 .58554 m .74248 .58552 L .7414 .5851 L F
.502 .334 .586 r
.33847 .66819 m .34046 .67012 L .34014 .66767 L F
.33847 .66819 m .33839 .67057 L .34046 .67012 L F
.19 0 .289 r
.75158 .61764 m .74969 .61863 L .75184 .61575 L F
.303 0 .121 r
.7513 .61975 m .74969 .61863 L .75158 .61764 L F
.7513 .61975 m .74901 .62045 L .74969 .61863 L F
.564 .701 .933 r
.44148 .78507 m .44228 .78305 L .44034 .78335 L F
.44148 .78507 m .44353 .78472 L .44228 .78305 L F
.557 .476 .719 r
.36533 .68998 m .3657 .69188 L .36346 .69218 L F
.57 .472 .704 r
.3657 .69188 m .36433 .6964 L .36346 .69218 L F
.246 0 0 r
.39235 .66536 m .39089 .66677 L .38863 .66718 L F
.559 .085 .086 r
.39439 .66662 m .39235 .66536 L .3946 .66564 L F
.39439 .66662 m .39089 .66677 L .39235 .66536 L F
.628 .849 .984 r
.56232 .6957 m .55981 .69662 L .55844 .69578 L F
.595 .132 .125 r
.56232 .6957 m .55844 .69578 L .55981 .69662 L F
.066 .595 .867 r
.38746 .64769 m .39083 .64851 L .38882 .64807 L F
.048 0 0 r
.54709 .74557 m .54685 .74558 L .54475 .74547 L F
.281 .265 .664 r
.54475 .74547 m .54685 .74558 L .54644 .74421 L F
.829 .648 .657 r
.60218 .70653 m .60033 .70319 L .60178 .70409 L F
.776 .572 .623 r
.61389 .6957 m .61413 .69837 L .61698 .69849 L F
.797 .559 .577 r
.61413 .69837 m .61686 .70079 L .61698 .69849 L F
0 .368 .833 r
.57637 .73161 m .57663 .73093 L .57411 .72937 L F
0 .028 .588 r
.57716 .73396 m .57663 .73093 L .57637 .73161 L F
.469 0 0 r
.37228 .6493 m .37643 .64875 L .37407 .64923 L F
.37228 .6493 m .37456 .64982 L .37643 .64875 L F
0 0 0 r
.37456 .64982 m .37777 .64926 L .37643 .64875 L F
.221 0 0 r
.37643 .64875 m .3796 .64873 L .37741 .6484 L F
.37643 .64875 m .37777 .64926 L .3796 .64873 L F
.429 .175 .426 r
.30443 .64595 m .30684 .64328 L .30624 .64561 L F
.283 .066 .398 r
.30684 .64328 m .30894 .64047 L .30874 .64305 L F
.266 0 .187 r
.30684 .64328 m .30782 .64465 L .30624 .64561 L F
.30684 .64328 m .30874 .64305 L .30782 .64465 L F
.397 .004 .171 r
.28642 .63668 m .28989 .63439 L .28809 .63527 L F
.715 .396 .437 r
.57392 .7107 m .57694 .70968 L .57753 .70962 L F
.96 .772 .605 r
.57694 .70968 m .57745 .71172 L .57753 .70962 L F
.809 .571 .577 r
.6165 .7092 m .61904 .71193 L .6191 .70962 L F
.658 .236 .231 r
.51487 .79484 m .51836 .79488 L .51698 .79669 L F
.012 .52 .865 r
.51836 .79488 m .52053 .79553 L .51948 .79496 L F
.068 0 0 r
.51805 .79496 m .51836 .79488 L .51948 .79496 L F
.538 .048 0 r
.51763 .79489 m .51805 .79496 L .51592 .79372 L F
.812 .915 .521 r
.51805 .79496 m .51827 .795 L .51698 .79669 L F
.538 .048 0 r
.51845 .79546 m .51805 .79496 L .51763 .79489 L F
.812 .915 .521 r
.51805 .79496 m .51836 .79488 L .51827 .795 L F
.049 0 0 r
.37082 .64922 m .37228 .6493 L .37407 .64923 L F
.481 0 0 r
.55828 .70053 m .5595 .70098 L .56087 .701 L F
.867 .538 .427 r
.5595 .70098 m .55988 .70309 L .56087 .701 L F
.703 .336 .351 r
.56087 .701 m .55988 .70309 L .56341 .70329 L F
.704 .336 .347 r
.56087 .701 m .56341 .70329 L .56312 .70167 L F
.864 .739 .723 r
.70737 .59351 m .70715 .59681 L .70504 .59625 L F
.778 .532 .563 r
.70715 .59681 m .70436 .59854 L .70504 .59625 L F
.70715 .59681 m .70769 .59894 L .70436 .59854 L F
.159 .126 .569 r
.70871 .59521 m .70715 .59681 L .70737 .59351 L F
.949 .611 .207 r
.70687 .59839 m .70769 .59894 L .70715 .59681 L F
.70687 .59839 m .70715 .59681 L .70871 .59521 L F
.349 0 0 r
.3796 .64873 m .38187 .64867 L .3831 .64819 L F
.893 .946 .836 r
.3831 .64819 m .38261 .64818 L .38521 .64853 L F
.3831 .64819 m .38187 .64867 L .38261 .64818 L F
.521 .227 .408 r
.58605 .71289 m .58835 .71415 L .58949 .71231 L F
.74 .377 .365 r
.58835 .71415 m .59178 .71464 L .58949 .71231 L F
.523 .837 .999 r
.30205 .59466 m .29856 .5945 L .30064 .59405 L F
.266 .744 .934 r
.30256 .59405 m .30205 .59466 L .30064 .59405 L F
.30256 .59405 m .30418 .59453 L .30205 .59466 L F
.788 .748 .816 r
.73876 .61924 m .73657 .62162 L .73479 .62072 L F
0 0 .493 r
.56991 .70655 m .57144 .70884 L .5715 .70938 L F
.809 .506 .477 r
.57144 .70884 m .57392 .7107 L .5715 .70938 L F
.696 .577 .718 r
.51864 .7485 m .51985 .75033 L .52211 .74808 L F
.194 .484 .897 r
.56784 .73839 m .56677 .73941 L .56489 .73658 L F
.56784 .73839 m .56812 .73954 L .56677 .73941 L F
.186 0 0 r
.29984 .64946 m .29819 .65077 L .29696 .65082 L F
.019 0 0 r
.30012 .65025 m .29984 .64946 L .30181 .64871 L F
.30012 .65025 m .29819 .65077 L .29984 .64946 L F
.437 0 0 r
.5623 .75866 m .56394 .75942 L .56068 .75836 L F
.441 .355 .663 r
.36631 .68165 m .36499 .68435 L .36429 .68203 L F
0 0 0 r
.37543 .71859 m .37516 .71819 L .377 .71734 L F
.37543 .71859 m .37337 .71925 L .37516 .71819 L F
.683 .694 .854 r
.55595 .76206 m .55764 .76453 L .55406 .76416 L F
.793 .477 .453 r
.55606 .76564 m .55406 .76416 L .55764 .76453 L F
.344 .531 .895 r
.55866 .76325 m .55764 .76453 L .55595 .76206 L F
.268 .116 .481 r
.55866 .76325 m .55606 .76564 L .55764 .76453 L F
.611 .135 .101 r
.48419 .79145 m .48562 .79035 L .48766 .79158 L F
.485 .464 .759 r
.27506 .68136 m .27656 .68157 L .27524 .68201 L F
.332 .079 .372 r
.27524 .68201 m .27656 .68157 L .27493 .68322 L F
.395 .03 .223 r
.51067 .75015 m .50742 .75268 L .50833 .75034 L F
.401 .843 .934 r
.28789 .6536 m .28904 .65377 L .29086 .65329 L F
.333 0 0 r
.45279 .78703 m .45616 .78652 L .45448 .78762 L F
.575 .059 0 r
.45448 .78762 m .45616 .78652 L .45831 .78772 L F
.297 0 .275 r
.75157 .60208 m .7487 .60448 L .74925 .6038 L F
.849 .413 .184 r
.7487 .60448 m .74998 .60645 L .74867 .60602 L F
0 0 .084 r
.7487 .60448 m .74867 .60602 L .74925 .6038 L F
.543 .587 .849 r
.29311 .60619 m .29412 .60364 L .29244 .60386 L F
.29311 .60619 m .2954 .60626 L .29412 .60364 L F
.258 0 .289 r
.75423 .61312 m .7537 .61503 L .75184 .61575 L F
.43 .133 .358 r
.75362 .61665 m .75184 .61575 L .7537 .61503 L F
.75362 .61665 m .75158 .61764 L .75184 .61575 L F
.938 .746 .617 r
.59825 .68745 m .59526 .68662 L .59715 .68441 L F
.641 .321 .415 r
.59825 .68745 m .59481 .68956 L .59526 .68662 L F
.59825 .68745 m .59661 .68983 L .59481 .68956 L F
.758 .469 .495 r
.59888 .68967 m .59661 .68983 L .59825 .68745 L F
.974 .751 .54 r
.48706 .75014 m .48821 .7534 L .48849 .75093 L F
.498 .821 1 r
.48706 .75014 m .48849 .75093 L .49055 .75044 L F
.787 .717 .786 r
.48821 .7534 m .49055 .75044 L .48849 .75093 L F
.53 .18 .318 r
.65683 .53498 m .65607 .5373 L .65382 .53611 L F
.544 .215 .361 r
.65906 .53489 m .65607 .5373 L .65683 .53498 L F
.433 .483 .812 r
.59178 .71464 m .59286 .71755 L .59091 .71606 L F
.725 .465 .533 r
.59339 .71988 m .59091 .71606 L .59286 .71755 L F
.59339 .71988 m .58898 .72028 L .59091 .71606 L F
.548 .354 .569 r
.54384 .761 m .54228 .75924 L .54399 .75853 L F
.54384 .761 m .54184 .76195 L .54228 .75924 L F
0 0 0 r
.54644 .74421 m .54896 .74213 L .54814 .74194 L F
.437 .811 .993 r
.53275 .71926 m .53562 .71899 L .53687 .71952 L F
0 .277 .689 r
.53736 .71965 m .53687 .71952 L .53562 .71899 L F
.53736 .71965 m .53855 .72045 L .53687 .71952 L F
.467 0 0 r
.4935 .79349 m .49453 .7931 L .49681 .79411 L F
.656 .207 .174 r
.49453 .7931 m .49814 .79401 L .49681 .79411 L F
.869 .675 .637 r
.61288 .69253 m .61119 .69529 L .61389 .6957 L F
.826 .609 .609 r
.61075 .69767 m .61389 .6957 L .61119 .69529 L F
.61075 .69767 m .61413 .69837 L .61389 .6957 L F
.535 0 0 r
.54231 .7228 m .5447 .72409 L .54553 .72364 L F
.64 .088 0 r
.5447 .72409 m .54782 .72519 L .54553 .72364 L F
.364 0 0 r
.48413 .76251 m .48151 .76195 L .48511 .76198 L F
.547 .078 .093 r
.48731 .76168 m .48413 .76251 L .48511 .76198 L F
.567 .567 .812 r
.43808 .7837 m .43911 .78046 L .4373 .78105 L F
.43808 .7837 m .44034 .78335 L .43911 .78046 L F
.471 .169 .372 r
.41078 .68488 m .41247 .68626 L .41307 .68458 L F
.41078 .68488 m .41026 .68671 L .41247 .68626 L F
.208 0 0 r
.49033 .76112 m .4894 .76161 L .48731 .76168 L F
.476 .212 .433 r
.4921 .76042 m .49033 .76112 L .49337 .75942 L F
.515 .084 .16 r
.4921 .76042 m .4894 .76161 L .49033 .76112 L F
.83 .854 .865 r
.74297 .72449 m .74652 .72318 L .74557 .72249 L F
.911 .926 .811 r
.7476 .71961 m .74652 .72318 L .74863 .72043 L F
.7476 .71961 m .74557 .72249 L .74652 .72318 L F
.578 .387 .587 r
.60293 .69579 m .60059 .69879 L .59961 .69548 L F
.60293 .69579 m .60196 .69811 L .60059 .69879 L F
0 0 .108 r
.75597 .61146 m .75423 .61312 L .75618 .61003 L F
.502 .354 .612 r
.75597 .61146 m .7537 .61503 L .75423 .61312 L F
.34 0 0 r
.49094 .78472 m .48856 .78422 L .48992 .78399 L F
.333 .553 .914 r
.49075 .78459 m .48856 .78422 L .49094 .78472 L F
.287 0 0 r
.48992 .78399 m .48856 .78422 L .48725 .784 L F
.333 .553 .914 r
.48835 .78298 m .48856 .78422 L .49075 .78459 L F
.287 0 0 r
.48725 .784 m .48856 .78422 L .48717 .784 L F
.534 .516 .782 r
.49195 .78352 m .48992 .78399 L .48891 .78086 L F
.34 0 0 r
.49094 .78472 m .48992 .78399 L .49195 .78352 L F
.837 .683 .692 r
.62187 .53748 m .62327 .53876 L .62047 .53888 L F
.816 .592 .599 r
.62327 .53876 m .62035 .54081 L .62047 .53888 L F
.62327 .53876 m .6234 .54105 L .62035 .54081 L F
.937 .88 .754 r
.62403 .53477 m .62327 .53876 L .62187 .53748 L F
.208 .309 .748 r
.57157 .72578 m .57259 .72909 L .57374 .72779 L F
.352 .53 .891 r
.57259 .72909 m .57411 .72937 L .57374 .72779 L F
.229 .667 .955 r
.27486 .59024 m .27684 .5904 L .27833 .59123 L F
.491 .763 .991 r
.27886 .58983 m .27833 .59123 L .27684 .5904 L F
.27886 .58983 m .28038 .59093 L .27833 .59123 L F
.259 0 0 r
.72843 .70897 m .73078 .70856 L .73167 .70732 L F
.319 0 0 r
.73167 .70732 m .73325 .70809 L .73407 .707 L F
.73167 .70732 m .73078 .70856 L .73325 .70809 L F
.626 .953 .779 r
.42439 .67001 m .4262 .66847 L .42717 .66814 L F
.085 .032 .493 r
.42717 .66814 m .42834 .66468 L .42627 .66516 L F
.42717 .66814 m .42845 .66769 L .42834 .66468 L F
.231 .734 .669 r
.4262 .66847 m .42845 .66769 L .42717 .66814 L F
.248 0 0 r
.40007 .66511 m .40335 .66512 L .40246 .66532 L F
.038 0 0 r
.40063 .66588 m .40007 .66511 L .40246 .66532 L F
.601 .95 .825 r
.40291 .66443 m .40098 .66566 L .40246 .66532 L F
.40098 .66566 m .40063 .66588 L .40246 .66532 L F
.248 0 0 r
.40335 .66512 m .40371 .66513 L .40246 .66532 L F
0 0 0 r
.40572 .66489 m .40246 .66532 L .40371 .66513 L F
.521 .227 .408 r
.58605 .71289 m .58599 .71498 L .58835 .71415 L F
.781 .567 .61 r
.56531 .76662 m .56863 .76726 L .56923 .76306 L F
.923 .959 .638 r
.57182 .75842 m .57056 .76059 L .56999 .76091 L F
.57056 .76059 m .56995 .76163 L .56999 .76091 L F
.131 .19 .657 r
.56923 .76306 m .5705 .76415 L .56999 .76091 L F
0 .071 .592 r
.5705 .76415 m .57122 .76359 L .56999 .76091 L F
0 0 .37 r
.56999 .76091 m .57085 .76237 L .56909 .76141 L F
.56999 .76091 m .56909 .76141 L .56863 .76115 L F
.987 .839 .46 r
.57231 .76657 m .57252 .76974 L .57242 .76723 L F
.574 .376 .575 r
.56923 .76306 m .57225 .76624 L .5705 .76415 L F
.57225 .76624 m .57224 .76622 L .5705 .76415 L F
.56923 .76306 m .56863 .76726 L .57225 .76634 L F
.946 .93 .577 r
.57211 .76537 m .57242 .76723 L .5734 .76413 L F
.574 .376 .575 r
.57225 .76624 m .57225 .76634 L .57232 .76632 L F
.56923 .76306 m .57225 .76634 L .57225 .76624 L F
.56 .338 .536 r
.56863 .76726 m .57187 .76907 L .57226 .76669 L F
.987 .839 .46 r
.57225 .76624 m .57252 .76974 L .57231 .76657 L F
.56 .338 .536 r
.57225 .76634 m .57226 .76669 L .57232 .76632 L F
.56863 .76726 m .57226 .76669 L .57225 .76634 L F
.987 .839 .46 r
.57225 .76624 m .57225 .76625 L .57225 .76624 L F
.57225 .76625 m .57252 .76974 L .57225 .76624 L F
.57217 .76585 m .57226 .76672 L .57225 .76624 L F
.57211 .76537 m .57224 .76622 L .57231 .76657 L F
.208 .337 .776 r
.57211 .76537 m .57224 .76622 L .57232 .76632 L F
.57211 .76537 m .57137 .76481 L .57224 .76622 L F
.987 .839 .46 r
.57211 .76537 m .57215 .76577 L .57224 .76622 L F
.574 .376 .575 r
.57225 .76624 m .57232 .76632 L .57224 .76622 L F
.951 .812 .367 r
.57232 .76632 m .57226 .76669 L .57211 .76537 L F
.208 .337 .776 r
.57137 .76481 m .5711 .76487 L .57224 .76622 L F
.951 .812 .367 r
.57226 .76669 m .57187 .76907 L .57211 .76537 L F
.987 .839 .46 r
.57215 .76577 m .57228 .76716 L .57226 .76672 L F
.57215 .76577 m .57226 .76672 L .57217 .76585 L F
.57228 .76716 m .57252 .76974 L .57225 .76624 L F
.802 .485 .452 r
.57163 .76475 m .56938 .7661 L .57109 .76493 L F
.208 .337 .776 r
.57211 .76537 m .57246 .76448 L .57122 .76359 L F
.802 .485 .452 r
.57246 .76448 m .57216 .76463 L .57163 .76475 L F
.208 .337 .776 r
.57211 .76537 m .57122 .76359 L .5705 .76415 L F
.802 .485 .452 r
.57216 .76463 m .56938 .7661 L .57163 .76475 L F
.208 .337 .776 r
.57137 .76481 m .5705 .76415 L .5711 .76487 L F
.494 .2 .395 r
.46584 .74241 m .46811 .74207 L .46888 .73951 L F
.376 0 .187 r
.46811 .74207 m .47122 .73969 L .46888 .73951 L F
.857 .797 .304 r
.58299 .74994 m .58274 .74953 L .58274 .74952 L F
.7 .357 0 r
.58215 .74777 m .58314 .75019 L .58299 .74994 L F
.857 .797 .304 r
.58299 .74994 m .58334 .74673 L .58215 .74777 L F
.58299 .74994 m .58274 .74952 L .58334 .74673 L F
.7 .357 0 r
.58314 .75019 m .58342 .75088 L .58299 .74994 L F
0 0 .327 r
.58342 .75088 m .58423 .7526 L .58299 .74994 L F
.58342 .75088 m .58385 .75272 L .58423 .7526 L F
.351 0 0 r
.27445 .68159 m .27656 .68157 L .27506 .68136 L F
.553 .054 .024 r
.45183 .74671 m .45409 .74692 L .45557 .74566 L F
.614 .127 .072 r
.45557 .74566 m .45409 .74692 L .45746 .74715 L F
.541 .193 .327 r
.45557 .74566 m .45746 .74715 L .45798 .74553 L F
.093 .454 .885 r
.33133 .60165 m .32965 .601 L .32781 .59916 L F
.534 0 0 r
.44647 .74477 m .44852 .74557 L .44988 .74544 L F
.557 .012 0 r
.44852 .74557 m .45183 .74671 L .44988 .74544 L F
.951 .87 .721 r
.74907 .71607 m .7476 .71961 L .74863 .72043 L F
.874 .723 .691 r
.63315 .51931 m .63123 .51874 L .632 .51606 L F
.557 .345 .549 r
.63315 .51931 m .63542 .52073 L .63558 .51854 L F
.63558 .51854 m .63542 .52073 L .63315 .51931 L F
.6 .83 .987 r
.42718 .65458 m .42361 .65434 L .42583 .65376 L F
.55 .83 .998 r
.42932 .65403 m .42718 .65458 L .42583 .65376 L F
.002 0 0 r
.28315 .64003 m .28336 .64094 L .28478 .63904 L F
.28315 .64003 m .28168 .64179 L .28336 .64094 L F
.651 .752 .923 r
.73208 .72569 m .7332 .72734 L .7357 .7263 L F
.54 .166 .28 r
.55053 .75056 m .55311 .75057 L .55386 .74848 L F
.346 .352 .723 r
.55386 .74848 m .55524 .74968 L .55659 .74776 L F
.55386 .74848 m .55638 .75076 L .55524 .74968 L F
.504 .283 .512 r
.41278 .70018 m .41086 .69854 L .41331 .69855 L F
.41278 .70018 m .41067 .70073 L .41086 .69854 L F
.405 .068 .278 r
.48679 .73368 m .4894 .73208 L .48718 .73221 L F
0 .432 .705 r
.2861 .60255 m .289 .60329 L .28855 .60316 L F
.373 0 0 r
.28474 .60301 m .2861 .60255 L .28855 .60316 L F
0 0 0 r
.5135 .76382 m .51328 .76405 L .51336 .7616 L F
.53 .23 .403 r
.51461 .76416 m .51336 .7616 L .51328 .76405 L F
.831 .453 .338 r
.51461 .76416 m .51709 .76635 L .51664 .76685 L F
.51709 .76635 m .51729 .76652 L .51664 .76685 L F
.777 .408 .357 r
.51461 .76416 m .51664 .76685 L .51316 .76626 L F
.758 .355 .288 r
.51664 .76685 m .51532 .76868 L .51316 .76626 L F
.798 .902 .497 r
.51655 .76639 m .51577 .76784 L .51664 .76685 L F
.51577 .76784 m .51532 .76868 L .51664 .76685 L F
.777 .408 .357 r
.51461 .76416 m .51586 .76548 L .51746 .76459 L F
.51461 .76416 m .51316 .76626 L .51586 .76548 L F
.572 .843 .497 r
.60982 .75175 m .61089 .75041 L .60712 .7527 L F
.60982 .75175 m .6111 .75023 L .61089 .75041 L F
.379 .145 .429 r
.31599 .63232 m .31825 .62952 L .31789 .63169 L F
.387 .194 .494 r
.3175 .63391 m .31599 .63232 L .31789 .63169 L F
.3175 .63391 m .31571 .63448 L .31599 .63232 L F
.706 .3 .275 r
.55296 .74303 m .55515 .74478 L .55317 .74412 L F
.48 .393 .679 r
.55483 .74197 m .55515 .74478 L .55296 .74303 L F
.55483 .74197 m .55515 .74478 L .55296 .74303 L F
.9 .801 .742 r
.61828 .71511 m .62033 .71486 L .61907 .71381 L F
.61828 .71511 m .61909 .71773 L .62033 .71486 L F
.987 .881 .634 r
.54274 .69589 m .54248 .69867 L .54172 .69766 L F
.953 .657 .22 r
.54248 .69867 m .54282 .70115 L .54172 .69766 L F
.363 0 .126 r
.36501 .65139 m .36714 .65099 L .36832 .64907 L F
.407 0 .151 r
.36832 .64907 m .37008 .64969 L .37082 .64922 L F
.36832 .64907 m .36714 .65099 L .37008 .64969 L F
.662 .322 .386 r
.58773 .66978 m .59007 .67028 L .59105 .66798 L F
.691 .353 .399 r
.59105 .66798 m .59343 .67008 L .59341 .66812 L F
.59105 .66798 m .59007 .67028 L .59343 .67008 L F
.577 .322 .494 r
.51627 .73661 m .51881 .7343 L .51635 .73434 L F
.465 .242 .491 r
.31789 .63169 m .31825 .62952 L .32023 .62894 L F
.794 .52 .524 r
.63105 .5138 m .62885 .51565 L .62923 .51331 L F
.63105 .5138 m .632 .51606 L .62885 .51565 L F
.697 .633 .782 r
.30762 .72583 m .31095 .72648 L .30944 .72283 L F
.776 .671 .748 r
.30944 .72283 m .31095 .72648 L .31288 .7233 L F
.395 .008 .182 r
.36397 .72334 m .36128 .72486 L .36199 .72393 L F
0 .495 .766 r
.63361 .50719 m .63508 .50748 L .63668 .50794 L F
.407 0 0 r
.63764 .50892 m .63668 .50794 L .63508 .50748 L F
.63764 .50892 m .63922 .50851 L .63668 .50794 L F
.177 0 0 r
.53304 .7981 m .53543 .79801 L .53539 .79823 L F
.341 .526 .892 r
.53423 .79678 m .53304 .7981 L .53539 .79823 L F
.426 .057 .233 r
.40597 .70366 m .40512 .70588 L .40287 .70619 L F
.351 .068 .335 r
.40858 .70122 m .40759 .70323 L .40597 .70366 L F
.172 0 .125 r
.40681 .70498 m .40597 .70366 L .40759 .70323 L F
.40681 .70498 m .40512 .70588 L .40597 .70366 L F
.554 .502 .751 r
.45204 .66641 m .4504 .66985 L .44985 .66742 L F
.494 .799 .999 r
.27059 .64379 m .26988 .64494 L .26801 .64403 L F
.27059 .64379 m .27183 .64457 L .26988 .64494 L F
.978 .738 .504 r
.63542 .52073 m .63664 .52209 L .63558 .51854 L F
.513 .349 .596 r
.43787 .75615 m .43997 .75582 L .43987 .75345 L F
.52 .396 .652 r
.43787 .75615 m .44025 .75834 L .43997 .75582 L F
.43787 .75615 m .43809 .75911 L .44025 .75834 L F
.739 .985 .903 r
.51785 .7265 m .51624 .7263 L .51318 .72845 L F
.472 .889 .917 r
.51885 .7256 m .51785 .7265 L .51913 .72551 L F
.51885 .7256 m .51624 .7263 L .51785 .7265 L F
.647 .224 .227 r
.59737 .682 m .59608 .68362 L .59353 .68183 L F
.99 .776 .52 r
.59737 .682 m .59715 .68441 L .59608 .68362 L F
.512 .224 .413 r
.47122 .73969 m .47346 .73941 L .47391 .73751 L F
.522 .182 .332 r
.47346 .73941 m .47681 .73694 L .47391 .73751 L F
.397 .68 .974 r
.28754 .59271 m .28392 .59145 L .28595 .59151 L F
.358 .644 .964 r
.28823 .59161 m .28754 .59271 L .28595 .59151 L F
.28823 .59161 m .28944 .59293 L .28754 .59271 L F
.515 .067 .123 r
.39794 .66505 m .39645 .66671 L .3946 .66564 L F
.533 .108 .18 r
.40007 .66511 m .39645 .66671 L .39794 .66505 L F
.442 .182 .423 r
.43299 .68169 m .43263 .68377 L .43036 .68415 L F
.526 .282 .488 r
.4352 .68124 m .43263 .68377 L .43299 .68169 L F
.26 0 .186 r
.41067 .70073 m .40759 .70323 L .40858 .70122 L F
.498 .353 .615 r
.30392 .61792 m .30622 .61761 L .30492 .6143 L F
.519 .458 .728 r
.30492 .6143 m .30745 .61242 L .30543 .61287 L F
.30492 .6143 m .30825 .61517 L .30745 .61242 L F
.265 .018 .34 r
.30622 .61761 m .30825 .61517 L .30492 .6143 L F
.198 0 0 r
.29696 .65082 m .29531 .65225 L .29398 .65203 L F
.249 0 0 r
.29819 .65077 m .29531 .65225 L .29696 .65082 L F
.782 .762 .249 r
.61913 .73629 m .61854 .73866 L .61843 .73996 L F
0 0 0 r
.61842 .74052 m .61843 .73996 L .61854 .73866 L F
.61842 .74052 m .61776 .74203 L .61843 .73996 L F
.693 .376 .435 r
.51038 .70867 m .51255 .70903 L .51032 .70675 L F
.757 .34 .257 r
.51032 .70675 m .51255 .70903 L .51368 .70838 L F
.29 0 .089 r
.27121 .60592 m .2691 .60652 L .26982 .60546 L F
.898 .783 .726 r
.63083 .50837 m .63069 .51095 L .62815 .51016 L F
.911 .746 .665 r
.62815 .51016 m .63069 .51095 L .62923 .51331 L F
.683 .694 .854 r
.55595 .76206 m .55406 .76416 L .55381 .76213 L F
.793 .477 .453 r
.55606 .76564 m .55368 .76673 L .55406 .76416 L F
.441 .355 .663 r
.36631 .68165 m .36668 .68398 L .36499 .68435 L F
.428 .313 .62 r
.36672 .68587 m .36499 .68435 L .36668 .68398 L F
.36672 .68587 m .36495 .68794 L .36499 .68435 L F
.522 .182 .332 r
.47346 .73941 m .47578 .73921 L .47681 .73694 L F
.51 .169 .326 r
.47681 .73694 m .47804 .73874 L .47926 .7371 L F
.47681 .73694 m .47578 .73921 L .47804 .73874 L F
.889 .671 .601 r
.57182 .75842 m .56995 .75857 L .57029 .75623 L F
.923 .959 .638 r
.57182 .75842 m .56999 .76091 L .56995 .75857 L F
.104 0 .387 r
.57408 .75544 m .57182 .75842 L .57402 .75465 L F
.57408 .75544 m .57382 .75795 L .57182 .75842 L F
0 0 .445 r
.57382 .75795 m .57413 .76032 L .57182 .75842 L F
.997 .796 .443 r
.50171 .73651 m .50158 .73891 L .50242 .73849 L F
.50242 .73849 m .50171 .73651 L .50492 .73657 L F
.50242 .73849 m .50158 .73891 L .50171 .73651 L F
.585 .588 .821 r
.37126 .7015 m .36788 .69878 L .37022 .69806 L F
.555 .556 .81 r
.37198 .69784 m .37126 .7015 L .37022 .69806 L F
.37198 .69784 m .37335 .70125 L .37126 .7015 L F
.36 .174 .488 r
.50091 .71774 m .50358 .71689 L .50407 .71371 L F
.481 .346 .62 r
.50101 .72002 m .50358 .71689 L .50091 .71774 L F
.694 .79 .924 r
.66488 .52158 m .66254 .52218 L .66116 .52112 L F
.647 .579 .764 r
.66591 .52461 m .66254 .52218 L .66488 .52158 L F
.663 .623 .799 r
.43626 .65704 m .43259 .65475 L .43479 .65438 L F
.61 .649 .864 r
.43852 .6565 m .43626 .65704 L .43479 .65438 L F
.577 .521 .755 r
.43932 .66012 m .43626 .65704 L .43852 .6565 L F
.323 .745 .975 r
.31529 .59581 m .31884 .5964 L .3168 .59676 L F
.353 .263 .614 r
.33607 .69846 m .3375 .69514 L .33554 .69557 L F
.33607 .69846 m .33784 .69817 L .3375 .69514 L F
.614 .353 .498 r
.33607 .69846 m .33821 .7005 L .33784 .69817 L F
.33607 .69846 m .33574 .70083 L .33821 .7005 L F
.221 0 .147 r
.30624 .64561 m .30352 .64787 L .30443 .64595 L F
.412 .631 .945 r
.27693 .68352 m .27891 .68547 L .27949 .68477 L F
.375 .513 .868 r
.73021 .72544 m .73104 .72332 L .72856 .72291 L F
.73021 .72544 m .73208 .72569 L .73104 .72332 L F
.713 .664 .801 r
.55306 .69329 m .55437 .69615 L .5569 .6952 L F
.84 .702 .711 r
.59961 .69548 m .60059 .69879 L .59976 .69841 L F
.789 .622 .675 r
.60059 .69879 m .59838 .6995 L .59976 .69841 L F
.60059 .69879 m .59895 .70013 L .59838 .6995 L F
.484 .16 .341 r
.42587 .68792 m .4252 .68956 L .42299 .6899 L F
.498 .214 .414 r
.42796 .68732 m .4252 .68956 L .42587 .68792 L F
.779 .849 .904 r
.74026 .61783 m .73741 .61797 L .73955 .6164 L F
.818 .775 .812 r
.74026 .61783 m .73876 .61924 L .73741 .61797 L F
.868 .879 .842 r
.74245 .6149 m .74026 .61783 L .73955 .6164 L F
.513 .223 .41 r
.43263 .68377 m .4297 .68647 L .43036 .68415 L F
.522 .339 .574 r
.4334 .77554 m .43552 .77523 L .43556 .77284 L F
.077 .622 .842 r
.4789 .76096 m .47606 .76051 L .47625 .75897 L F
.4789 .76096 m .47699 .7606 L .47606 .76051 L F
.228 0 0 r
.47606 .76051 m .47699 .7606 L .47624 .76054 L F
.355 0 .034 r
.47399 .76009 m .47606 .76051 L .47191 .76113 L F
.508 .851 .995 r
.47335 .76033 m .47191 .76113 L .47606 .76051 L F
.228 0 0 r
.47606 .76051 m .47624 .76054 L .47335 .76033 L F
.355 0 .034 r
.47625 .75897 m .47606 .76051 L .47399 .76009 L F
.344 0 .194 r
.46336 .76313 m .46231 .76194 L .46482 .76167 L F
.46336 .76313 m .46121 .76385 L .46231 .76194 L F
.985 .744 .486 r
.46823 .76478 m .46791 .7672 L .46691 .76373 L F
.611 .838 .986 r
.46691 .76373 m .46823 .76478 L .47 .76368 L F
.435 .208 .469 r
.47003 .76661 m .46823 .76478 L .47 .76368 L F
.47003 .76661 m .46791 .7672 L .46823 .76478 L F
.414 .447 .786 r
.45758 .77135 m .45844 .77472 L .45579 .773 L F
.778 .35 .233 r
.72564 .59095 m .72246 .5899 L .72344 .59051 L F
.344 0 0 r
.59339 .75935 m .59674 .761 L .59563 .75913 L F
.837 .899 .883 r
.59674 .761 m .59809 .75803 L .59563 .75913 L F
.59674 .761 m .59903 .7589 L .59809 .75803 L F
.408 .166 .433 r
.31128 .63767 m .31103 .6401 L .30894 .64047 L F
.368 .134 .422 r
.31281 .63938 m .31128 .63767 L .3132 .63716 L F
.31281 .63938 m .31103 .6401 L .31128 .63767 L F
.513 .32 .556 r
.64436 .50495 m .64392 .50748 L .64661 .50455 L F
.847 .697 .696 r
.60988 .68978 m .60953 .69216 L .61288 .69253 L F
.908 .737 .658 r
.60966 .69453 m .61288 .69253 L .60953 .69216 L F
.60966 .69453 m .61119 .69529 L .61288 .69253 L F
.761 .495 .531 r
.72564 .59095 m .72901 .59095 L .72914 .59312 L F
.415 .669 .966 r
.73035 .58963 m .72901 .59095 L .73146 .59089 L F
.73035 .58963 m .72901 .59095 L .73146 .59089 L F
.712 .642 .778 r
.73146 .59089 m .72914 .59312 L .72901 .59095 L F
.74 .247 0 r
.72465 .61994 m .72447 .61985 L .72276 .61825 L F
.467 .338 .621 r
.33643 .67353 m .33841 .6756 L .33852 .67315 L F
.33643 .67353 m .33647 .67644 L .33841 .6756 L F
0 0 .352 r
.58104 .74213 m .58138 .74542 L .58155 .74459 L F
.128 .223 .695 r
.58215 .74777 m .58155 .74459 L .58138 .74542 L F
.824 .82 .846 r
.72031 .58763 m .72033 .58502 L .71957 .58797 L F
.72031 .58763 m .72137 .58661 L .72033 .58502 L F
0 0 .418 r
.72144 .58669 m .72031 .58763 L .72095 .58909 L F
.691 .349 .391 r
.72031 .58763 m .71957 .58797 L .72144 .58669 L F
.72031 .58763 m .71923 .58975 L .71957 .58797 L F
.941 .702 .549 r
.35369 .72605 m .35116 .72637 L .34984 .72707 L F
.35369 .72605 m .35344 .72837 L .35116 .72637 L F
.35116 .72637 m .35344 .72837 L .35369 .72605 L F
.532 .324 .544 r
.52769 .7204 m .52761 .72281 L .5253 .72319 L F
.52769 .7204 m .52761 .72281 L .5253 .72319 L F
.489 .35 .618 r
.52902 .71786 m .52974 .72002 L .52769 .7204 L F
.466 .271 .531 r
.52974 .72002 m .52761 .72281 L .52769 .7204 L F
.52974 .72002 m .52761 .72281 L .52769 .7204 L F
.529 .183 .325 r
.65382 .53611 m .65607 .5373 L .65372 .53743 L F
.724 .333 .308 r
.63339 .54648 m .6325 .54822 L .6305 .54621 L F
.635 .286 .361 r
.63579 .54642 m .6325 .54822 L .63339 .54648 L F
0 0 0 r
.57028 .67719 m .57073 .67734 L .57201 .676 L F
.57028 .67719 m .56876 .67815 L .57073 .67734 L F
.514 .234 .428 r
.25939 .61021 m .26159 .60994 L .25935 .61034 L F
.86 .933 .871 r
.58956 .75687 m .58938 .75555 L .58762 .75622 L F
.433 0 0 r
.51368 .70838 m .51255 .70903 L .5159 .70862 L F
.553 .599 .854 r
.72978 .71183 m .73078 .70856 L .72843 .70897 L F
.72978 .71183 m .73211 .71134 L .73078 .70856 L F
.864 .748 .732 r
.53609 .74287 m .53517 .74504 L .53449 .74189 L F
.609 .601 .817 r
.36788 .69878 m .36433 .6964 L .36662 .69588 L F
.672 .643 .813 r
.37022 .69806 m .36788 .69878 L .36662 .69588 L F
.709 .897 .964 r
.30795 .75356 m .30571 .75425 L .30599 .75238 L F
.424 .734 .991 r
.30769 .75223 m .30795 .75356 L .30599 .75238 L F
.30769 .75223 m .30992 .75323 L .30795 .75356 L F
.395 .166 .445 r
.30992 .75323 m .30755 .75607 L .30795 .75356 L F
.664 .363 .453 r
.59343 .67008 m .59674 .66798 L .59341 .66812 L F
.59343 .67008 m .59683 .6695 L .59674 .66798 L F
.691 .384 .45 r
.59683 .6695 m .59905 .67018 L .59674 .66798 L F
.671 .39 .486 r
.59674 .66798 m .59905 .67018 L .59886 .66823 L F
.404 0 .028 r
.32276 .71783 m .31946 .71913 L .3208 .72034 L F
.592 .84 .473 r
.32276 .71783 m .32162 .71919 L .3208 .72034 L F
.553 .897 .98 r
.32213 .71977 m .32162 .71919 L .3208 .72034 L F
.832 .402 .217 r
.71802 .58391 m .72033 .58502 L .71877 .58261 L F
.803 .597 .623 r
.72137 .58661 m .71877 .58261 L .72033 .58502 L F
.867 .863 .834 r
.6258 .5273 m .62612 .52946 L .62392 .52953 L F
.935 .829 .715 r
.62612 .52946 m .6234 .53185 L .62392 .52953 L F
.62612 .52946 m .62462 .53276 L .6234 .53185 L F
.788 .816 .875 r
.62875 .52718 m .62612 .52946 L .6258 .5273 L F
.369 .807 .959 r
.40939 .66581 m .40987 .66505 L .40769 .66524 L F
.40939 .66581 m .41156 .66548 L .40987 .66505 L F
.97 .776 .585 r
.60215 .71152 m .60092 .711 L .60113 .70875 L F
.987 .86 .624 r
.60096 .71471 m .60092 .711 L .60215 .71152 L F
0 .559 .789 r
.26027 .58708 m .25658 .58648 L .2587 .58654 L F
.094 .618 .877 r
.2587 .58654 m .26222 .58729 L .26027 .58708 L F
.37 0 .192 r
.4716 .77965 m .47292 .78026 L .47431 .77805 L F
.652 .3 .363 r
.47431 .77805 m .47675 .78019 L .47617 .77792 L F
.47431 .77805 m .47292 .78026 L .47675 .78019 L F
.539 .477 .735 r
.33554 .69557 m .33685 .6926 L .33468 .69328 L F
.33554 .69557 m .3375 .69514 L .33685 .6926 L F
.929 .705 .578 r
.50947 .73134 m .51049 .73419 L .50911 .73389 L F
.788 .748 .816 r
.73876 .61924 m .73479 .62072 L .73741 .61797 L F
.271 .015 .331 r
.40083 .69325 m .40222 .6942 L .40327 .69184 L F
.40083 .69325 m .40048 .69513 L .40222 .6942 L F
.562 .451 .685 r
.34033 .66534 m .34248 .66493 L .34204 .66267 L F
.523 .317 .542 r
.34014 .66767 m .34248 .66493 L .34033 .66534 L F
.553 .44 .679 r
.4349 .77036 m .4372 .77012 L .43685 .76699 L F
.595 .523 .743 r
.43556 .77284 m .4372 .77012 L .4349 .77036 L F
.57 .472 .704 r
.3657 .69188 m .36662 .69588 L .36433 .6964 L F
.842 .699 .705 r
.70737 .59351 m .70315 .59542 L .70341 .59297 L F
.70737 .59351 m .70504 .59625 L .70315 .59542 L F
.159 .126 .569 r
.70871 .59521 m .70737 .59351 L .70871 .59273 L F
.532 .347 .575 r
.30155 .62106 m .30369 .62071 L .30392 .61792 L F
.368 .159 .46 r
.30158 .62332 m .30369 .62071 L .30155 .62106 L F
.435 .21 .471 r
.75833 .60926 m .75597 .61146 L .75618 .61003 L F
.429 .22 .492 r
.44403 .74499 m .44586 .74623 L .44647 .74477 L F
.44403 .74499 m .44358 .7476 L .44586 .74623 L F
.484 .718 .974 r
.75092 .58685 m .74888 .58722 L .74714 .58551 L F
.494 .617 .902 r
.75139 .58851 m .74888 .58722 L .75092 .58685 L F
.572 .54 .781 r
.52649 .72897 m .52808 .725 L .52592 .72594 L F
.52649 .72897 m .52898 .72856 L .52808 .725 L F
.835 .998 .828 r
.52621 .73056 m .52649 .72897 L .52641 .73107 L F
.52621 .73056 m .52898 .72856 L .52649 .72897 L F
.265 .318 .731 r
.66734 .52332 m .66591 .52461 L .66488 .52158 L F
.142 .008 .425 r
.6675 .5256 m .66591 .52461 L .66734 .52332 L F
.6675 .5256 m .66566 .52678 L .66591 .52461 L F
.982 .725 .329 r
.62851 .52476 m .62875 .52718 L .6281 .52524 L F
.926 .657 .51 r
.62644 .52072 m .62847 .52485 L .62751 .52409 L F
.62847 .52485 m .6286 .5251 L .62841 .52491 L F
.602 .551 .769 r
.62988 .5234 m .6286 .5251 L .62847 .52485 L F
0 0 0 r
.62988 .5234 m .62897 .52431 L .62847 .52485 L F
.62897 .52431 m .62851 .52476 L .62841 .52491 L F
.602 .551 .769 r
.62988 .5234 m .62847 .52485 L .62644 .52072 L F
0 0 0 r
.62988 .5234 m .62847 .52485 L .62841 .52491 L F
.713 .713 .849 r
.62988 .5234 m .62841 .52491 L .6286 .5251 L F
.62841 .52491 m .6281 .52524 L .6286 .5251 L F
.926 .657 .51 r
.62841 .52491 m .6286 .5251 L .62841 .52492 L F
.62847 .52485 m .62841 .52492 L .62751 .52409 L F
.419 .864 .889 r
.62841 .52492 m .62655 .52522 L .62751 .52409 L F
.6286 .5251 m .62822 .52512 L .62841 .52492 L F
0 0 0 r
.62841 .52491 m .62851 .52476 L .6281 .52524 L F
.419 .864 .889 r
.62822 .52512 m .62655 .52522 L .62841 .52492 L F
.693 .821 .944 r
.7357 .7263 m .73878 .72639 L .73731 .72441 L F
.699 .599 .741 r
.73731 .72441 m .73878 .72639 L .74115 .7255 L F
.752 .491 .538 r
.62651 .54403 m .62315 .5461 L .62333 .54338 L F
.62651 .54403 m .62679 .54634 L .62315 .5461 L F
.72 .468 .545 r
.6305 .54621 m .62679 .54634 L .62651 .54403 L F
.576 .281 .43 r
.46091 .7444 m .46314 .74442 L .46345 .74262 L F
.6 .302 .436 r
.46314 .74442 m .46548 .74452 L .46345 .74262 L F
.568 .307 .482 r
.46345 .74262 m .46548 .74452 L .46584 .74241 L F
.888 .748 .701 r
.59423 .67948 m .5915 .68124 L .59278 .67854 L F
.59423 .67948 m .59353 .68183 L .5915 .68124 L F
.699 .599 .741 r
.73731 .72441 m .74025 .72246 L .73795 .72323 L F
.276 0 0 r
.50363 .79421 m .50579 .7944 L .50229 .79453 L F
.796 .623 .667 r
.56045 .74253 m .55849 .74503 L .55681 .74218 L F
.663 .279 .308 r
.52808 .725 m .5253 .72319 L .52761 .72281 L F
.493 .4 .679 r
.5253 .72319 m .52592 .72594 L .52808 .725 L F
.663 .279 .308 r
.52808 .725 m .52385 .72496 L .5253 .72319 L F
.493 .4 .679 r
.5253 .72319 m .52808 .725 L .52761 .72281 L F
.365 .05 .293 r
.40327 .69184 m .40516 .69233 L .40597 .68988 L F
.262 0 .157 r
.40327 .69184 m .40412 .69354 L .40516 .69233 L F
.40327 .69184 m .40222 .6942 L .40412 .69354 L F
.005 .482 .869 r
.29901 .60711 m .29888 .60637 L .29752 .60603 L F
.032 .509 .881 r
.29901 .60711 m .30088 .60763 L .29888 .60637 L F
.346 .046 .305 r
.26159 .60994 m .25899 .6124 L .25935 .61034 L F
.699 .355 .391 r
.73371 .5875 m .7334 .58564 L .7299 .58557 L F
.611 .295 .409 r
.73371 .5875 m .73592 .5873 L .7334 .58564 L F
.176 .6 .94 r
.51183 .72596 m .51206 .72525 L .51088 .72516 L F
0 0 .481 r
.51183 .72596 m .51318 .72845 L .51206 .72525 L F
.307 .721 .975 r
.28445 .59072 m .28392 .59145 L .28232 .59057 L F
.28445 .59072 m .28595 .59151 L .28392 .59145 L F
.322 .008 .267 r
.52965 .75845 m .53201 .75814 L .53244 .75626 L F
.494 .2 .397 r
.52965 .75845 m .53166 .76075 L .53201 .75814 L F
.52965 .75845 m .52918 .76132 L .53166 .76075 L F
.826 .769 .799 r
.61767 .71719 m .61909 .71773 L .61828 .71511 L F
.884 .648 .575 r
.61769 .71962 m .61909 .71773 L .61767 .71719 L F
.61769 .71962 m .61892 .72009 L .61909 .71773 L F
.359 0 .151 r
.38785 .70046 m .38993 .70007 L .39069 .69885 L F
.224 0 0 r
.38993 .70007 m .39281 .69842 L .39069 .69885 L F
.636 .956 .928 r
.58124 .67755 m .58009 .6773 L .57873 .67881 L F
.955 .832 .682 r
.59922 .69248 m .60047 .69337 L .59961 .69548 L F
.141 0 .16 r
.33614 .60902 m .33655 .60779 L .33817 .60682 L F
.424 .262 .555 r
.32198 .62826 m .32024 .62674 L .32212 .62631 L F
.32198 .62826 m .32023 .62894 L .32024 .62674 L F
.907 .725 .644 r
.60174 .67524 m .60379 .67369 L .60202 .67282 L F
.60174 .67524 m .60347 .67606 L .60379 .67369 L F
.763 .644 .731 r
.75068 .59874 m .75157 .60208 L .74859 .60156 L F
.297 0 .275 r
.75157 .60208 m .74925 .6038 L .74859 .60156 L F
.536 .468 .727 r
.75324 .59825 m .75157 .60208 L .75068 .59874 L F
.75324 .59825 m .75382 .60158 L .75157 .60208 L F
.531 .448 .707 r
.75382 .60158 m .75473 .60343 L .75157 .60208 L F
.821 .88 .888 r
.59617 .71929 m .59339 .71988 L .59518 .71722 L F
.801 .364 .208 r
.59518 .71722 m .5978 .71909 L .59617 .71929 L F
.461 .135 .326 r
.55606 .76564 m .55396 .76906 L .55368 .76673 L F
.55606 .76564 m .55618 .76869 L .55396 .76906 L F
.268 .116 .481 r
.55866 .76325 m .55855 .76605 L .55606 .76564 L F
.281 .009 .311 r
.55855 .76605 m .55618 .76869 L .55606 .76564 L F
.376 .16 .453 r
.31046 .6423 m .30894 .64047 L .31103 .6401 L F
.31046 .6423 m .30874 .64305 L .30894 .64047 L F
.249 .521 .912 r
.4599 .77485 m .45932 .77609 L .45844 .77472 L F
.4599 .77485 m .46149 .77678 L .45932 .77609 L F
.178 .682 .907 r
.59047 .7588 m .59339 .75935 L .59264 .75895 L F
.298 .766 .942 r
.59264 .75895 m .59339 .75935 L .59563 .75913 L F
.494 .484 .775 r
.5474 .69289 m .5497 .69342 L .54843 .68931 L F
.419 .257 .552 r
.42018 .6764 m .42215 .67577 L .42244 .6733 L F
.485 .344 .614 r
.42019 .67853 m .42215 .67577 L .42018 .6764 L F
.298 .681 .975 r
.551 .70954 m .55345 .70979 L .55196 .70875 L F
.428 .232 .511 r
.30369 .62071 m .30622 .61761 L .30392 .61792 L F
.38 0 0 r
.49814 .79401 m .50015 .79449 L .49681 .79411 L F
.688 .75 .899 r
.63808 .5038 m .6386 .50532 L .63522 .50481 L F
.588 .246 .357 r
.6386 .50532 m .63508 .50748 L .63522 .50481 L F
.6386 .50532 m .63867 .50831 L .63508 .50748 L F
.378 .547 .895 r
.63808 .5038 m .63981 .50385 L .6386 .50532 L F
.668 .974 .838 r
.64096 .50711 m .63922 .50851 L .63895 .50858 L F
.6396 .50785 m .63895 .50858 L .63764 .50892 L F
.64096 .50711 m .63895 .50858 L .6396 .50785 L F
.129 .097 .55 r
.64181 .50485 m .64074 .50657 L .63981 .50385 L F
.64074 .50657 m .63993 .50788 L .63992 .50749 L F
.64074 .50657 m .63992 .50749 L .63981 .50385 L F
.668 .974 .838 r
.64096 .50711 m .63764 .50892 L .63998 .50844 L F
.718 .189 0 r
.63915 .50783 m .63993 .50788 L .63998 .50844 L F
0 0 .228 r
.63894 .50723 m .63867 .50831 L .63862 .50631 L F
.63981 .50385 m .63894 .50723 L .6386 .50532 L F
.63894 .50723 m .63862 .50631 L .6386 .50532 L F
.765 .599 .672 r
.63981 .50385 m .63684 .5061 L .63867 .50831 L F
.718 .189 0 r
.63684 .5061 m .63898 .50733 L .63915 .50783 L F
.63898 .50733 m .63993 .50788 L .63915 .50783 L F
.923 .789 .694 r
.54015 .74203 m .54022 .74531 L .54146 .74266 L F
.768 .977 .708 r
.51902 .76422 m .51729 .76652 L .51948 .76581 L F
0 0 0 r
.47 .76368 m .471 .76224 L .47191 .76113 L F
.398 .802 .983 r
.5365 .79375 m .53498 .79456 L .53491 .79429 L F
.5365 .79375 m .53736 .79431 L .53498 .79456 L F
.387 .092 .338 r
.32647 .62027 m .32711 .61829 L .32902 .61772 L F
.212 .713 .909 r
.37898 .70228 m .38205 .70253 L .38005 .70292 L F
.539 .282 .475 r
.64355 .54095 m .64596 .54259 L .64436 .54253 L F
.64355 .54095 m .64588 .54069 L .64596 .54259 L F
.507 .35 .602 r
.34204 .66267 m .34429 .65939 L .34189 .65957 L F
.339 .064 .342 r
.33354 .61227 m .33173 .61293 L .33427 .61036 L F
.386 .158 .442 r
.33132 .61503 m .33173 .61293 L .33354 .61227 L F
.114 0 0 r
.57438 .67456 m .57749 .67412 L .57772 .67371 L F
.715 .365 .383 r
.57749 .67412 m .57992 .67324 L .57772 .67371 L F
.437 .22 .485 r
.33614 .60902 m .33354 .61227 L .33427 .61036 L F
.355 .748 .986 r
.28944 .59293 m .29147 .59286 L .29299 .59363 L F
.249 .677 .962 r
.29351 .5929 m .29299 .59363 L .29147 .59286 L F
.29351 .5929 m .29502 .59379 L .29299 .59363 L F
0 0 .188 r
.50603 .72418 m .50639 .72715 L .50758 .72524 L F
.50603 .72418 m .50642 .7267 L .50639 .72715 L F
.382 .215 .527 r
.50642 .7267 m .50637 .72712 L .50639 .72715 L F
.11 0 .216 r
.50639 .72715 m .50607 .72948 L .5046 .72945 L F
.382 .215 .527 r
.50637 .72712 m .50607 .72948 L .50639 .72715 L F
.484 .84 .578 r
.50642 .72721 m .50639 .72715 L .50577 .72775 L F
.50825 .72569 m .50639 .72715 L .50642 .72721 L F
0 0 0 r
.50639 .72715 m .5046 .72945 L .50577 .72775 L F
.616 .116 .04 r
.53174 .76628 m .52804 .76607 L .52905 .76488 L F
.02 0 0 r
.55425 .7005 m .5565 .70053 L .55828 .70053 L F
.464 0 0 r
.5565 .70053 m .5595 .70098 L .55828 .70053 L F
.774 .479 .487 r
.51975 .74003 m .51967 .74218 L .5181 .73968 L F
.635 .36 .485 r
.52268 .74138 m .51975 .74003 L .52299 .73946 L F
.52268 .74138 m .51967 .74218 L .51975 .74003 L F
.513 .722 .967 r
.30599 .75238 m .30571 .75425 L .3045 .75294 L F
.30599 .75238 m .30571 .75425 L .3045 .75294 L F
.109 .428 .871 r
.65689 .51768 m .65622 .51862 L .65455 .51614 L F
.65689 .51768 m .65809 .51944 L .65622 .51862 L F
.595 .523 .743 r
.43556 .77284 m .43784 .77253 L .4372 .77012 L F
.602 .424 .613 r
.43552 .77523 m .43784 .77253 L .43556 .77284 L F
.574 .353 .543 r
.52541 .73699 m .5253 .7392 L .52299 .73946 L F
.553 .336 .539 r
.52541 .73699 m .52757 .73889 L .5253 .7392 L F
.443 0 0 r
.29017 .60343 m .28855 .60316 L .289 .60329 L F
.585 .704 .925 r
.289 .60329 m .29244 .60386 L .29017 .60343 L F
.739 .564 .656 r
.53232 .74231 m .53386 .74642 L .53045 .7443 L F
0 0 0 r
.53045 .7443 m .53103 .74412 L .53232 .74231 L F
.749 .569 .651 r
.53517 .74504 m .53232 .74231 L .53449 .74189 L F
.53517 .74504 m .53386 .74642 L .53232 .74231 L F
.767 .526 .569 r
.53103 .74412 m .53449 .74189 L .53232 .74231 L F
.292 0 .089 r
.35731 .65413 m .35524 .6547 L .3544 .65593 L F
.694 .79 .924 r
.66488 .52158 m .66116 .52112 L .66382 .51871 L F
.508 .754 .985 r
.66672 .51987 m .66488 .52158 L .66382 .51871 L F
.66672 .51987 m .66735 .52109 L .66488 .52158 L F
.265 .318 .731 r
.66734 .52332 m .66488 .52158 L .66735 .52109 L F
.505 .711 .963 r
.32781 .59916 m .32582 .59939 L .32452 .59796 L F
.419 .555 .885 r
.75288 .58701 m .75139 .58851 L .75092 .58685 L F
.43 .573 .895 r
.75288 .58701 m .75473 .58986 L .75139 .58851 L F
.517 .299 .521 r
.29267 .63242 m .2948 .63204 L .29526 .6295 L F
.485 .269 .511 r
.29526 .6295 m .29695 .63143 L .29709 .62879 L F
.29526 .6295 m .2948 .63204 L .29695 .63143 L F
.397 .178 .461 r
.40823 .6873 m .40969 .68844 L .41026 .68671 L F
.40823 .6873 m .40788 .68931 L .40969 .68844 L F
.888 .918 .838 r
.72189 .71969 m .72288 .72043 L .72511 .71764 L F
.513 .343 .588 r
.43598 .76226 m .43808 .76192 L .43809 .75911 L F
.47 .364 .652 r
.43648 .76451 m .43808 .76192 L .43598 .76226 L F
.057 0 0 r
.34909 .65659 m .34737 .65752 L .34639 .65891 L F
.529 .379 .62 r
.59481 .68956 m .59281 .69289 L .59277 .69006 L F
.264 .153 .535 r
.59277 .69006 m .59401 .68983 L .59481 .68956 L F
.59277 .69006 m .59281 .69289 L .59401 .68983 L F
.567 .911 .97 r
.59903 .7589 m .60017 .7577 L .59809 .75803 L F
.59903 .7589 m .6013 .75805 L .60017 .7577 L F
.743 .658 .766 r
.33989 .71965 m .34134 .72263 L .3438 .71978 L F
.707 .601 .736 r
.3438 .71978 m .34134 .72263 L .3434 .72138 L F
.553 .606 .86 r
.34134 .72263 m .34398 .72393 L .3434 .72138 L F
.374 .059 .296 r
.40597 .68988 m .40714 .69169 L .40788 .68931 L F
.40597 .68988 m .40516 .69233 L .40714 .69169 L F
0 0 .521 r
.57051 .74478 m .57172 .74697 L .5711 .74763 L F
0 .225 .745 r
.57172 .74697 m .57333 .74972 L .5711 .74763 L F
.808 .7 .746 r
.5372 .76703 m .54075 .76704 L .5395 .76451 L F
.61 .402 .575 r
.53878 .76909 m .54075 .76704 L .5372 .76703 L F
.53878 .76909 m .54064 .7698 L .54075 .76704 L F
.54075 .76704 m .54064 .7698 L .53878 .76909 L F
.51 .689 .948 r
.73454 .59076 m .7375 .59182 L .73718 .59265 L F
.131 0 0 r
.7375 .59182 m .73948 .59198 L .73718 .59265 L F
.7375 .59182 m .73986 .59162 L .73948 .59198 L F
.28 .479 .875 r
.32319 .70939 m .32244 .70787 L .32291 .70825 L F
.32319 .70939 m .32459 .71038 L .32244 .70787 L F
.679 .502 .64 r
.32319 .70939 m .32382 .7116 L .32459 .71038 L F
.32319 .70939 m .32179 .71253 L .32382 .7116 L F
.176 .535 .924 r
.55759 .72988 m .55609 .73008 L .55512 .72811 L F
.55759 .72988 m .55826 .73091 L .55609 .73008 L F
.012 .201 .712 r
.48684 .77183 m .48501 .77307 L .48493 .77259 L F
.48684 .77183 m .48758 .77412 L .48501 .77307 L F
.531 .253 .438 r
.48758 .77412 m .48512 .77474 L .48501 .77307 L F
.456 .776 .998 r
.56651 .7675 m .56863 .76726 L .56531 .76662 L F
.816 .68 .714 r
.53517 .74504 m .53329 .74823 L .53386 .74642 L F
.138 0 0 r
.71153 .59205 m .71507 .59192 L .7112 .59233 L F
.267 .425 .835 r
.57006 .77 m .57187 .76907 L .56863 .76726 L F
.488 .165 .344 r
.57252 .76974 m .57129 .77158 L .57006 .77 L F
0 0 .284 r
.57129 .77158 m .57187 .76907 L .57006 .77 L F
.35 0 .034 r
.3847 .71408 m .38114 .71613 L .3826 .71441 L F
.245 0 0 r
.64333 .51811 m .64667 .51634 L .64328 .51595 L F
.64333 .51811 m .64566 .51762 L .64667 .51634 L F
0 0 0 r
.64667 .51634 m .6485 .51529 L .64834 .51583 L F
.64767 .51687 m .64834 .51583 L .64797 .51704 L F
.64667 .51634 m .64834 .51583 L .64767 .51687 L F
.075 0 .446 r
.64834 .51583 m .65022 .51404 L .6485 .51529 L F
.655 .748 .919 r
.65178 .51673 m .64899 .51758 L .64855 .51551 L F
.64867 .51537 m .64855 .51551 L .6485 .51529 L F
.075 0 .446 r
.64834 .51583 m .64868 .51536 L .65022 .51404 L F
.655 .748 .919 r
.64867 .51537 m .6485 .51529 L .65022 .51404 L F
.075 0 .446 r
.64868 .51536 m .64869 .51534 L .65022 .51404 L F
.655 .748 .919 r
.65178 .51673 m .64867 .51537 L .65022 .51404 L F
.65178 .51673 m .64855 .51551 L .64867 .51537 L F
.075 0 .446 r
.64869 .51534 m .6497 .51397 L .64992 .514 L F
.64869 .51534 m .64992 .514 L .65022 .51404 L F
.64752 .51662 m .64834 .51583 L .6485 .51529 L F
.64752 .51662 m .64895 .51488 L .64834 .51583 L F
.64895 .51488 m .6497 .51397 L .64834 .51583 L F
0 0 0 r
.64797 .51704 m .6485 .51529 L .64899 .51758 L F
.64667 .51634 m .64566 .51762 L .6485 .51529 L F
.572 .472 .702 r
.71576 .71523 m .71578 .71637 L .71853 .71471 L F
.699 .599 .741 r
.73731 .72441 m .74115 .7255 L .74025 .72246 L F
.61 .589 .804 r
.74025 .72246 m .74115 .7255 L .74297 .72449 L F
.309 .278 .66 r
.61996 .72817 m .62072 .73065 L .61878 .73166 L F
0 0 0 r
.62072 .73065 m .61925 .73392 L .61878 .73166 L F
.617 .812 .975 r
.73717 .70723 m .73407 .707 L .73629 .70648 L F
.3 .788 .896 r
.73886 .70668 m .73717 .70723 L .73629 .70648 L F
.73886 .70668 m .73941 .70688 L .73717 .70723 L F
.42 .127 .358 r
.37865 .67071 m .37795 .67272 L .37596 .67304 L F
.347 .052 .315 r
.38063 .67004 m .37795 .67272 L .37865 .67071 L F
.473 .248 .492 r
.4636 .77012 m .46593 .76988 L .46612 .76796 L F
.501 .369 .633 r
.4636 .77012 m .46585 .77214 L .46593 .76988 L F
.347 .029 .276 r
.53244 .75626 m .53397 .7575 L .53472 .75629 L F
.53244 .75626 m .53201 .75814 L .53397 .7575 L F
0 0 0 r
.72785 .5852 m .72422 .58687 L .72688 .58739 L F
.636 .302 .388 r
.72688 .58739 m .73036 .58708 L .72785 .5852 L F
.65 .288 .345 r
.73036 .58708 m .7299 .58557 L .72785 .5852 L F
.223 .664 .954 r
.30834 .59447 m .30798 .59517 L .30645 .59435 L F
.30834 .59447 m .30976 .59529 L .30798 .59517 L F
.087 0 0 r
.37008 .64969 m .37228 .6493 L .37082 .64922 L F
.859 .981 .69 r
.31828 .71776 m .31805 .71687 L .32048 .71454 L F
.732 .377 .378 r
.32048 .71454 m .31805 .71687 L .3209 .71647 L F
.282 .677 .972 r
.41818 .65332 m .41457 .65221 L .41686 .65223 L F
.407 .643 .953 r
.419 .65201 m .41818 .65332 L .41686 .65223 L F
.419 .65201 m .42022 .65348 L .41818 .65332 L F
0 0 0 r
.55058 .76401 m .55197 .76357 L .55381 .76213 L F
.57 .531 .772 r
.55381 .76213 m .55503 .75843 L .55265 .75852 L F
.55381 .76213 m .55595 .76206 L .55503 .75843 L F
.115 0 0 r
.55381 .76213 m .55453 .76285 L .55595 .76206 L F
.55381 .76213 m .55197 .76357 L .55453 .76285 L F
.539 .279 .469 r
.63838 .54413 m .63816 .54605 L .63579 .54642 L F
.551 .319 .516 r
.64041 .54359 m .63816 .54605 L .63838 .54413 L F
.582 .153 .191 r
.50579 .7944 m .50935 .79382 L .5079 .79448 L F
.482 0 0 r
.50935 .79382 m .51143 .79426 L .5079 .79448 L F
.626 .953 .779 r
.42439 .67001 m .423 .67085 L .4262 .66847 L F
.648 .531 .707 r
.33399 .69224 m .33637 .68967 L .33405 .69009 L F
.137 .569 .926 r
.72429 .7168 m .72634 .71754 L .72511 .71764 L F
.851 .623 .593 r
.60851 .68419 m .60842 .68661 L .6115 .6871 L F
.864 .671 .64 r
.60825 .68901 m .6115 .6871 L .60842 .68661 L F
.60825 .68901 m .60988 .68978 L .6115 .6871 L F
.455 .052 .184 r
.54843 .68931 m .55102 .68911 L .55178 .68719 L F
0 0 0 r
.55178 .68719 m .5533 .68669 L .55373 .68649 L F
.55178 .68719 m .55102 .68911 L .5533 .68669 L F
.845 .928 .884 r
.59509 .7299 m .59404 .73167 L .59294 .73082 L F
.985 .835 .612 r
.59331 .73394 m .59294 .73082 L .59404 .73167 L F
.396 .728 .99 r
.40977 .6505 m .40897 .65157 L .40763 .6507 L F
.40977 .6505 m .41106 .65148 L .40897 .65157 L F
0 .302 .795 r
.73482 .6258 m .73639 .62721 L .73543 .62542 L F
.737 .696 .812 r
.49756 .75635 m .49869 .75916 L .50082 .75722 L F
.703 .565 .696 r
.49525 .75711 m .49337 .75942 L .49235 .75594 L F
.19 .721 .765 r
.37777 .64926 m .38187 .64867 L .3796 .64873 L F
.887 .878 .821 r
.73667 .72229 m .73448 .72521 L .73731 .72441 L F
.896 .826 .771 r
.73448 .72521 m .7357 .7263 L .73731 .72441 L F
.79 .312 .092 r
.56812 .73954 m .57148 .74177 L .56996 .74192 L F
.844 .678 .676 r
.61533 .70357 m .61322 .70607 L .61661 .70668 L F
.827 .641 .651 r
.61322 .70864 m .61661 .70668 L .61322 .70607 L F
.61322 .70864 m .6165 .7092 L .61661 .70668 L F
.364 .822 .927 r
.27445 .64382 m .27613 .6434 L .27803 .64357 L F
.368 .833 .895 r
.27613 .6434 m .27996 .64284 L .27803 .64357 L F
.636 .09 0 r
.54376 .69595 m .54741 .69763 L .54579 .69465 L F
.533 .764 .982 r
.43356 .65331 m .43259 .65475 L .43147 .65347 L F
.43356 .65331 m .43479 .65438 L .43259 .65475 L F
.562 .05 0 r
.46741 .78881 m .47073 .78889 L .47012 .79024 L F
.492 .061 .149 r
.47073 .78889 m .47161 .7908 L .47012 .79024 L F
.47073 .78889 m .47294 .78901 L .47161 .7908 L F
.366 .295 .644 r
.53974 .7472 m .539 .74974 L .54071 .74896 L F
.53938 .74654 m .53924 .74775 L .53974 .7472 L F
.453 .375 .679 r
.53956 .7474 m .53943 .74822 L .53971 .74724 L F
.679 .261 .246 r
.53552 .74848 m .5375 .7492 L .53938 .74654 L F
.453 .375 .679 r
.53895 .74798 m .53765 .74917 L .5381 .74893 L F
.53834 .74849 m .53765 .74917 L .53895 .74798 L F
.53956 .7474 m .5381 .74893 L .53943 .74822 L F
.679 .261 .246 r
.53834 .74849 m .539 .74974 L .53924 .74774 L F
.366 .295 .644 r
.53924 .74775 m .539 .74974 L .53974 .74721 L F
.53924 .74775 m .53974 .74721 L .53956 .7474 L F
.453 .375 .679 r
.53971 .74724 m .53943 .74822 L .54057 .74701 L F
.53958 .74727 m .54071 .74896 L .53828 .74913 L F
.53834 .74849 m .53828 .74913 L .53765 .74917 L F
.679 .261 .246 r
.5375 .7492 m .53924 .74774 L .53938 .74654 L F
.453 .375 .679 r
.53958 .74727 m .53834 .74849 L .53895 .74798 L F
.53958 .74727 m .5381 .74893 L .53956 .7474 L F
.53958 .74727 m .53828 .74913 L .53834 .74849 L F
.679 .261 .246 r
.5375 .7492 m .53824 .74947 L .53834 .74849 L F
.649 .424 .564 r
.53871 .75013 m .53852 .74996 L .5388 .74983 L F
.669 .432 .553 r
.53765 .74917 m .53569 .75244 L .53671 .7503 L F
.53765 .74917 m .53933 .75262 L .53569 .75244 L F
.649 .424 .564 r
.54119 .75239 m .53933 .75262 L .53765 .74917 L F
0 0 0 r
.53569 .75244 m .53876 .74994 L .53671 .7503 L F
.53876 .74994 m .539 .74974 L .53881 .74979 L F
.53876 .74994 m .53881 .74979 L .53671 .7503 L F
.649 .424 .564 r
.54119 .75239 m .53871 .75013 L .54071 .74896 L F
.275 0 .011 r
.539 .74974 m .53901 .74985 L .54071 .74896 L F
.649 .424 .564 r
.53871 .75013 m .53875 .74999 L .54071 .74896 L F
.275 0 .011 r
.53901 .74985 m .53911 .7515 L .54071 .74896 L F
.649 .424 .564 r
.53875 .74999 m .5388 .74983 L .54071 .74896 L F
.53852 .74996 m .53765 .74917 L .53828 .74913 L F
.679 .261 .246 r
.53828 .74913 m .539 .74974 L .53834 .74849 L F
.53839 .74952 m .539 .74974 L .53828 .74913 L F
.649 .424 .564 r
.53852 .74996 m .53828 .74913 L .54071 .74896 L F
.679 .261 .246 r
.53824 .74947 m .53839 .74952 L .53828 .74913 L F
.366 .295 .644 r
.53956 .7474 m .53974 .74721 L .53974 .7472 L F
.453 .375 .679 r
.53958 .74727 m .53956 .7474 L .53971 .74724 L F
.824 .561 .541 r
.60374 .68072 m .60689 .67907 L .6036 .67846 L F
.60374 .68072 m .6069 .68132 L .60689 .67907 L F
.804 .595 .619 r
.32359 .72324 m .32045 .72522 L .32281 .72269 L F
.947 .609 .2 r
.32359 .72324 m .32281 .72269 L .32213 .71977 L F
.676 .718 .88 r
.33858 .71195 m .33644 .71251 L .33561 .71046 L F
.13 .646 .891 r
.58974 .73333 m .59331 .73394 L .59068 .73453 L F
.331 .068 .356 r
.50407 .71371 m .50491 .71414 L .5054 .71155 L F
.448 .23 .489 r
.5054 .71155 m .50746 .71202 L .5077 .70883 L F
.424 .131 .361 r
.50491 .71414 m .50746 .71202 L .5054 .71155 L F
0 0 .449 r
.54182 .75492 m .54255 .75565 L .54375 .75346 L F
.523 .358 .599 r
.43987 .75345 m .44197 .75308 L .44192 .75061 L F
.438 .251 .528 r
.43997 .75582 m .44197 .75308 L .43987 .75345 L F
.522 .252 .447 r
.3736 .67589 m .37081 .67847 L .37116 .67666 L F
.359 0 0 r
.50334 .7914 m .50255 .79017 L .50168 .79041 L F
.50334 .7914 m .50462 .78985 L .50255 .79017 L F
.454 .079 .237 r
.26729 .60645 m .26342 .6092 L .26558 .60735 L F
.26729 .60645 m .26558 .60892 L .26342 .6092 L F
.379 0 .144 r
.2691 .60652 m .26558 .60892 L .26729 .60645 L F
.626 .739 .928 r
.72618 .62045 m .72734 .62207 L .72963 .62132 L F
.582 .34 .515 r
.51419 .74183 m .51611 .73961 L .51484 .74014 L F
.829 .569 .546 r
.59905 .67018 m .60202 .67282 L .60177 .67096 L F
.409 0 .086 r
.5393 .7332 m .53515 .7357 L .53571 .73423 L F
.5393 .7332 m .53769 .73526 L .53515 .7357 L F
.623 .204 .226 r
.54006 .73541 m .5393 .7332 L .54144 .73466 L F
.54006 .73541 m .53753 .73546 L .5393 .7332 L F
.742 .632 .736 r
.53653 .7326 m .53937 .73486 L .54191 .73367 L F
.53937 .73486 m .54006 .73541 L .54106 .73447 L F
.53937 .73486 m .54106 .73447 L .54191 .73367 L F
.409 0 .086 r
.53741 .73532 m .53753 .73546 L .5363 .73558 L F
.53769 .73526 m .5363 .73558 L .53515 .7357 L F
.052 0 .4 r
.53653 .7326 m .53515 .7357 L .53753 .73546 L F
.919 .628 .475 r
.53753 .73546 m .53796 .73798 L .53626 .73517 L F
.756 .517 .572 r
.54003 .73803 m .53796 .73798 L .53753 .73546 L F
.919 .628 .475 r
.53753 .73546 m .53626 .73517 L .53867 .73679 L F
.53753 .73546 m .53867 .73679 L .53868 .73679 L F
.409 0 .086 r
.53769 .73526 m .53753 .73546 L .53741 .73532 L F
.606 .088 0 r
.47294 .78901 m .47636 .78947 L .47559 .79062 L F
.64 .126 .007 r
.47559 .79062 m .47636 .78947 L .47874 .79104 L F
.113 .513 .909 r
.44621 .78483 m .44735 .78597 L .44793 .78535 L F
0 .281 .784 r
.44793 .78535 m .44735 .78597 L .44852 .7867 L F
.733 .869 .945 r
.30088 .60763 m .30452 .60727 L .30311 .60692 L F
.30088 .60763 m .30193 .608 L .30452 .60727 L F
.167 .438 .871 r
.30452 .60727 m .30496 .60599 L .30311 .60692 L F
.30452 .60727 m .30546 .60715 L .30496 .60599 L F
.502 .434 .712 r
.30452 .60727 m .30716 .60929 L .30546 .60715 L F
.30452 .60727 m .30505 .61032 L .30716 .60929 L F
.77 .869 .921 r
.73096 .7186 m .72851 .72037 L .72722 .71953 L F
.591 .833 .99 r
.32422 .72609 m .32768 .7261 L .32633 .72535 L F
.891 .893 .824 r
.32819 .72267 m .32768 .7261 L .32994 .72399 L F
.595 .668 .89 r
.44217 .66128 m .43987 .66178 L .43932 .66012 L F
.547 .244 .406 r
.28989 .63439 m .29211 .63422 L .29267 .63242 L F
.411 .094 .313 r
.29211 .63422 m .2948 .63204 L .29267 .63242 L F
.906 .571 .093 r
.47675 .78019 m .47746 .78111 L .47617 .77792 L F
.551 .204 .334 r
.47746 .78111 m .4797 .78252 L .47991 .78106 L F
.811 .425 .323 r
.47675 .78019 m .4797 .78252 L .47746 .78111 L F
.404 .089 .313 r
.54223 .69605 m .54172 .69766 L .54376 .69595 L F
.707 .601 .736 r
.3438 .71978 m .3434 .72138 L .34316 .72184 L F
0 .204 .729 r
.3438 .71978 m .34519 .72027 L .34428 .71903 L F
.07 .276 .765 r
.34519 .72027 m .3457 .72196 L .34487 .72025 L F
.34519 .72027 m .34487 .72025 L .34428 .71903 L F
.112 0 .4 r
.3438 .71978 m .34369 .72015 L .34487 .72025 L F
.3438 .71978 m .34487 .72025 L .34488 .72016 L F
.927 .714 .594 r
.34492 .72035 m .34484 .72044 L .34487 .72025 L F
.3457 .72196 m .34486 .72047 L .34492 .72035 L F
.34486 .72047 m .34484 .72044 L .34492 .72035 L F
.323 .47 .853 r
.3434 .72138 m .3457 .72196 L .34486 .72047 L F
.521 .531 .806 r
.34398 .72393 m .3457 .72196 L .3434 .72138 L F
.323 .47 .853 r
.3434 .72138 m .34486 .72047 L .34316 .72184 L F
.34486 .72047 m .3457 .72196 L .34519 .72027 L F
.34486 .72047 m .34519 .72027 L .34482 .72055 L F
.34486 .72047 m .34482 .72055 L .34316 .72184 L F
.927 .714 .594 r
.3457 .72196 m .34462 .72196 L .34484 .72044 L F
.112 0 .4 r
.34369 .72015 m .34316 .72184 L .34519 .72027 L F
.927 .714 .594 r
.34487 .72025 m .34379 .72197 L .34428 .71903 L F
.34462 .72196 m .34379 .72197 L .34487 .72025 L F
.112 0 .4 r
.34488 .72016 m .34487 .72025 L .34519 .72027 L F
.842 .961 .885 r
.33292 .7175 m .33182 .72008 L .3344 .71864 L F
.33292 .7175 m .33071 .71969 L .33182 .72008 L F
.56 .224 .356 r
.46836 .78124 m .47054 .78249 L .4716 .77965 L F
.573 .314 .486 r
.47054 .78249 m .47292 .78026 L .4716 .77965 L F
.357 .584 .929 r
.32994 .72399 m .33036 .7222 L .32819 .72267 L F
.32994 .72399 m .33183 .72401 L .33036 .7222 L F
.508 .408 .676 r
.33552 .68512 m .33702 .68117 L .33516 .68163 L F
.823 .662 .683 r
.31461 .72473 m .31618 .72815 L .31684 .72612 L F
.31461 .72473 m .31618 .72815 L .31684 .72612 L F
.559 .474 .715 r
.30543 .61287 m .30716 .60929 L .30505 .61032 L F
.776 .658 .732 r
.29851 .73957 m .29941 .74236 L .30079 .73917 L F
.64 .818 .968 r
.55425 .7005 m .55205 .70134 L .55102 .70024 L F
.868 .879 .842 r
.74245 .6149 m .74027 .61603 L .7422 .61532 L F
.256 0 .173 r
.74525 .61285 m .74245 .6149 L .7445 .61453 L F
.635 .804 .964 r
.7444 .61451 m .7422 .61532 L .74088 .61393 L F
.7445 .61453 m .7422 .61532 L .7444 .61451 L F
.868 .879 .842 r
.74027 .61603 m .73955 .6164 L .7422 .61532 L F
.32 .8 .901 r
.28229 .65419 m .27892 .65444 L .28028 .65447 L F
.471 .208 .433 r
.32925 .61556 m .33084 .617 L .32902 .61772 L F
.32925 .61556 m .33132 .61503 L .33084 .617 L F
.609 .306 .431 r
.54255 .75565 m .54547 .75304 L .54375 .75346 L F
.836 .617 .607 r
.49969 .75072 m .49715 .7526 L .49629 .7516 L F
.49969 .75072 m .49865 .75407 L .49715 .7526 L F
.824 .99 .731 r
.49421 .75758 m .49337 .75942 L .49525 .75711 L F
.774 .525 .559 r
.49412 .75551 m .49697 .75621 L .49791 .75421 L F
.49697 .75621 m .49756 .75635 L .49766 .75572 L F
.49697 .75621 m .49766 .75572 L .49791 .75421 L F
.535 .16 .277 r
.49755 .75616 m .49599 .75836 L .49471 .7578 L F
.49625 .75671 m .49471 .7578 L .49421 .75758 L F
.49755 .75616 m .49471 .7578 L .49625 .75671 L F
.586 .349 .524 r
.49791 .75421 m .49756 .75635 L .49966 .75507 L F
.535 .16 .277 r
.49769 .7561 m .49765 .75615 L .49755 .75616 L F
.49765 .75615 m .49599 .75836 L .49755 .75616 L F
.992 .756 .474 r
.49697 .75621 m .49525 .75711 L .49756 .75635 L F
.49412 .75551 m .49474 .75638 L .49697 .75621 L F
.49474 .75638 m .49525 .75711 L .49697 .75621 L F
.49412 .75551 m .49421 .75758 L .49525 .75711 L F
.324 .293 .669 r
.53039 .7141 m .52902 .71786 L .52932 .71691 L F
.52993 .71537 m .53118 .71623 L .52902 .71786 L F
.521 .368 .614 r
.53144 .71863 m .52902 .71786 L .53118 .71623 L F
.383 .386 .739 r
.53039 .7141 m .52932 .71691 L .52826 .71263 L F
.456 0 0 r
.53118 .71623 m .53456 .71823 L .53144 .71863 L F
.765 .382 .328 r
.52937 .71576 m .533 .71748 L .53118 .71623 L F
.533 .71748 m .53331 .71763 L .53118 .71623 L F
.324 .293 .669 r
.53039 .7141 m .53118 .71623 L .52993 .71537 L F
.521 .368 .614 r
.53144 .71863 m .52974 .72002 L .52902 .71786 L F
.797 .559 .577 r
.61413 .69837 m .61395 .70053 L .61686 .70079 L F
.799 .657 .706 r
.61395 .70053 m .61533 .70357 L .61686 .70079 L F
.829 .416 .259 r
.54925 .7469 m .54772 .74679 L .5471 .74554 L F
.753 .407 .398 r
.54892 .74529 m .54708 .74555 L .54709 .74557 L F
.54836 .74537 m .54708 .74555 L .54892 .74529 L F
.54708 .74555 m .54685 .74558 L .54703 .74557 L F
.54708 .74555 m .54703 .74557 L .54709 .74557 L F
.54938 .74523 m .54836 .74537 L .54892 .74529 L F
.54938 .74523 m .54925 .7469 L .54685 .74558 L F
.829 .416 .259 r
.54925 .7469 m .54644 .74421 L .54685 .74558 L F
.54774 .74545 m .5471 .74554 L .54644 .74421 L F
.54925 .7469 m .5471 .74554 L .54774 .74545 L F
0 0 .351 r
.54719 .7455 m .54772 .74679 L .54726 .74564 L F
.54644 .74421 m .5471 .74554 L .54719 .7455 L F
.5471 .74554 m .54772 .74679 L .54719 .7455 L F
0 0 .354 r
.48812 .77857 m .48891 .78086 L .48869 .77995 L F
.454 .84 .984 r
.48891 .78086 m .4896 .77985 L .4912 .78032 L F
.534 .516 .782 r
.49195 .78352 m .48891 .78086 L .4912 .78032 L F
.024 0 .081 r
.48891 .78086 m .48952 .78268 L .4896 .77985 L F
.48891 .78086 m .48835 .78298 L .48952 .78268 L F
.47 .364 .652 r
.43648 .76451 m .43839 .76415 L .43808 .76192 L F
.469 .362 .649 r
.43648 .76451 m .43865 .76655 L .43839 .76415 L F
.466 .361 .652 r
.43685 .76699 m .43865 .76655 L .43648 .76451 L F
.66 .229 .212 r
.59167 .67702 m .59076 .67838 L .58908 .67781 L F
.76 .349 .273 r
.59278 .67854 m .59076 .67838 L .59167 .67702 L F
0 0 .524 r
.33703 .70657 m .33718 .70657 L .33624 .70358 L F
.225 .742 .853 r
.71336 .60624 m .71273 .60639 L .71133 .6063 L F
.732 .322 .273 r
.71336 .60624 m .71133 .6063 L .71273 .60639 L F
.471 .282 .542 r
.75481 .59008 m .75491 .59266 L .75243 .5937 L F
.431 .312 .616 r
.75492 .59453 m .75243 .5937 L .75491 .59266 L F
.75492 .59453 m .75266 .59605 L .75243 .5937 L F
.898 .783 .726 r
.63083 .50837 m .62815 .51016 L .62936 .50728 L F
.731 .728 .848 r
.63361 .50719 m .63083 .50837 L .62936 .50728 L F
.557 .32 .512 r
.5077 .70883 m .50987 .71125 L .51038 .70867 L F
.5077 .70883 m .50746 .71202 L .50987 .71125 L F
.423 .168 .421 r
.41541 .68197 m .4171 .68342 L .41754 .68147 L F
.41541 .68197 m .41513 .684 L .4171 .68342 L F
.289 .748 .952 r
.29017 .60343 m .29244 .60386 L .29412 .60364 L F
.38 .012 .208 r
.66193 .53309 m .66127 .53446 L .65906 .53489 L F
0 0 .012 r
.66299 .5335 m .66193 .53309 L .66336 .53177 L F
.66299 .5335 m .66127 .53446 L .66193 .53309 L F
.307 0 0 r
.53472 .75629 m .53665 .75677 L .53806 .75626 L F
.281 .767 .682 r
.53806 .75626 m .53957 .75562 L .54014 .75703 L F
.53806 .75626 m .53665 .75677 L .53957 .75562 L F
.798 .331 .121 r
.59353 .68183 m .59274 .68291 L .5915 .68124 L F
.655 .149 .029 r
.59353 .68183 m .59608 .68362 L .59274 .68291 L F
0 .533 .749 r
.73579 .71187 m .73414 .71159 L .73211 .71134 L F
0 .285 .786 r
.73579 .71187 m .73704 .71182 L .73414 .71159 L F
.73579 .71187 m .73777 .71355 L .73704 .71182 L F
.515 .084 .16 r
.4921 .76042 m .49156 .76247 L .4894 .76161 L F
.618 .427 .602 r
.49561 .75928 m .4921 .76042 L .49337 .75942 L F
.504 .124 .252 r
.49561 .75928 m .49156 .76247 L .4921 .76042 L F
.439 .236 .505 r
.32224 .62375 m .32445 .62082 L .32426 .62334 L F
.395 .184 .471 r
.32212 .62631 m .32224 .62375 L .32426 .62334 L F
.585 .891 .989 r
.73146 .59089 m .73454 .59076 L .73383 .59 L F
.569 .364 .563 r
.73454 .59076 m .73718 .59265 L .73477 .59281 L F
.961 .669 .242 r
.73454 .59076 m .73477 .59281 L .73383 .59 L F
.512 .5 .78 r
.43632 .77849 m .4373 .78105 L .43911 .78046 L F
.35 .733 .986 r
.2642 .58724 m .26577 .5881 L .26222 .58729 L F
.214 .711 .915 r
.2642 .58724 m .26778 .58762 L .26577 .5881 L F
.398 .65 .959 r
.32452 .59796 m .32276 .59805 L .3208 .59619 L F
.228 0 0 r
.42834 .66468 m .42475 .66427 L .42627 .66516 L F
.535 .378 .615 r
.43808 .76192 m .44025 .75834 L .43809 .75911 L F
.506 .284 .511 r
.41574 .69575 m .41564 .69819 L .41331 .69855 L F
.355 .163 .477 r
.41731 .69727 m .41574 .69575 L .41783 .69546 L F
.41731 .69727 m .41564 .69819 L .41574 .69575 L F
.903 .672 .578 r
.60693 .68361 m .60856 .68178 L .6069 .68132 L F
.60693 .68361 m .60851 .68419 L .60856 .68178 L F
.577 .322 .494 r
.51627 .73661 m .51867 .73647 L .51881 .7343 L F
.54 .353 .576 r
.51881 .7343 m .52105 .7341 L .52123 .73124 L F
.058 0 .35 r
.51881 .7343 m .51989 .73546 L .52105 .7341 L F
.51881 .7343 m .51867 .73647 L .51989 .73546 L F
.618 .427 .602 r
.49561 .75928 m .49337 .75942 L .49421 .75758 L F
.49 0 0 r
.50799 .78967 m .50462 .78985 L .50676 .79087 L F
.358 0 0 r
.44859 .6661 m .45087 .66637 L .45208 .66523 L F
.593 .21 .286 r
.45208 .66523 m .45419 .66685 L .45204 .66641 L F
.554 .502 .751 r
.45204 .66641 m .45256 .66939 L .4504 .66985 L F
.533 .463 .723 r
.45419 .66685 m .45256 .66939 L .45204 .66641 L F
.634 .153 .093 r
.45087 .66637 m .45419 .66685 L .45208 .66523 L F
.517 .368 .617 r
.33852 .67315 m .34046 .67012 L .33839 .67057 L F
.404 0 .028 r
.32276 .71783 m .32162 .71919 L .31946 .71913 L F
0 .405 .825 r
.3209 .71647 m .32258 .71727 L .32276 .71783 L F
.844 .931 .551 r
.32276 .71783 m .32162 .71919 L .32258 .71727 L F
.32276 .71783 m .32258 .71727 L .32511 .71757 L F
.32276 .71783 m .32162 .71919 L .32258 .71727 L F
.373 .796 .973 r
.75473 .58986 m .75652 .58946 L .75481 .59008 L F
.449 .266 .539 r
.7573 .59052 m .75481 .59008 L .75652 .58946 L F
.7573 .59052 m .75491 .59266 L .75481 .59008 L F
0 .027 .585 r
.31828 .71776 m .31946 .71913 L .31805 .71687 L F
.746 .944 .947 r
.60734 .75639 m .60403 .7573 L .60455 .75768 L F
.60734 .75639 m .60631 .75573 L .60403 .7573 L F
.19 .721 .765 r
.37777 .64926 m .37996 .64885 L .38187 .64867 L F
.307 0 0 r
.37881 .64907 m .37893 .64905 L .37996 .64885 L F
0 0 0 r
.37996 .64885 m .38228 .64839 L .38187 .64867 L F
.307 0 0 r
.37893 .64905 m .3821 .64849 L .37996 .64885 L F
0 0 0 r
.37996 .64885 m .38261 .64818 L .38228 .64839 L F
.37996 .64885 m .3821 .64849 L .38261 .64818 L F
.626 .693 .893 r
.38746 .64769 m .38261 .64818 L .38716 .6463 L F
.38746 .64769 m .38521 .64853 L .38261 .64818 L F
.391 0 0 r
.3821 .64849 m .38716 .6463 L .38261 .64818 L F
.924 .765 .665 r
.59976 .69841 m .59849 .69769 L .59961 .69548 L F
.914 .953 .615 r
.59838 .6995 m .59849 .69769 L .59976 .69841 L F
.51 .079 .158 r
.3946 .66564 m .39645 .66671 L .39439 .66662 L F
.864 .674 .644 r
.75473 .60343 m .75616 .60578 L .75692 .60555 L F
.533 .418 .667 r
.45256 .66939 m .4507 .67283 L .4504 .66985 L F
.812 .595 .608 r
.61075 .69767 m .61395 .70053 L .61413 .69837 L F
0 0 0 r
.28073 .60358 m .2792 .60404 L .2772 .60444 L F
.124 0 0 r
.28259 .60349 m .2792 .60404 L .28073 .60358 L F
.699 .174 0 r
.56359 .71463 m .56242 .71394 L .56057 .71187 L F
.763 .251 0 r
.56591 .71674 m .56242 .71394 L .56359 .71463 L F
0 0 .124 r
.51096 .72973 m .51142 .72868 L .50947 .73134 L F
.741 .629 .735 r
.50911 .73389 m .51096 .72973 L .50947 .73134 L F
.521 .531 .806 r
.34398 .72393 m .34681 .72521 L .3457 .72196 L F
.122 0 0 r
.39084 .71243 m .39044 .71164 L .39254 .71123 L F
.39084 .71243 m .38872 .71309 L .39044 .71164 L F
0 .169 .676 r
.58385 .75272 m .58494 .75349 L .58423 .7526 L F
.375 0 0 r
.51143 .79426 m .51487 .79484 L .51402 .79498 L F
.667 .117 0 r
.51402 .79498 m .51487 .79484 L .51698 .79669 L F
.458 .159 .37 r
.42066 .69251 m .41999 .69504 L .41783 .69546 L F
.494 .284 .523 r
.42299 .6899 m .42271 .69209 L .42066 .69251 L F
.463 .172 .386 r
.42271 .69209 m .41999 .69504 L .42066 .69251 L F
.631 .084 0 r
.50645 .75618 m .50987 .75891 L .50644 .75885 L F
.075 0 0 r
.50644 .75885 m .50903 .75857 L .50645 .75618 L F
.631 .084 0 r
.50645 .75618 m .50903 .75857 L .50987 .75891 L F
.644 .106 0 r
.46482 .76167 m .46558 .76287 L .46336 .76313 L F
.221 0 0 r
.57533 .6806 m .57154 .68174 L .57378 .68019 L F
.472 .176 .381 r
.48146 .73675 m .48363 .73635 L .48455 .73367 L F
.456 .112 .292 r
.48363 .73635 m .48679 .73368 L .48455 .73367 L F
.525 .477 .746 r
.33627 .6872 m .33747 .68375 L .33552 .68512 L F
.33627 .6872 m .33815 .68671 L .33747 .68375 L F
.491 .344 .609 r
.33627 .6872 m .33814 .68902 L .33815 .68671 L F
.33627 .6872 m .33637 .68967 L .33814 .68902 L F
.779 .658 .729 r
.34681 .72521 m .34984 .72707 L .34873 .72481 L F
.34681 .72521 m .34782 .72844 L .34984 .72707 L F
.457 .174 .395 r
.5334 .73375 m .53006 .73614 L .53135 .73421 L F
.741 .565 .656 r
.31564 .85804 m .31954 .85923 L .31879 .85692 L F
.624 .5 .69 r
.31879 .85692 m .31954 .85923 L .32094 .85774 L F
.54 .283 .474 r
.5253 .7392 m .52268 .74138 L .52299 .73946 L F
.487 .036 .105 r
.45448 .78762 m .45405 .78761 L .45279 .78703 L F
.376 0 .187 r
.46811 .74207 m .47012 .74164 L .47122 .73969 L F
.496 .118 .252 r
.47122 .73969 m .47323 .74082 L .47346 .73941 L F
.47122 .73969 m .47012 .74164 L .47323 .74082 L F
.503 .837 .998 r
.53384 .76692 m .53479 .76758 L .5372 .76703 L F
.376 .657 .967 r
.53479 .76758 m .53878 .76909 L .5372 .76703 L F
.487 .256 .489 r
.52105 .7341 m .52372 .73117 L .52123 .73124 L F
.55 .391 .619 r
.66023 .52189 m .65942 .52419 L .65696 .52449 L F
.774 .525 .559 r
.49412 .75551 m .49791 .75421 L .49715 .7526 L F
.187 .465 .886 r
.49791 .75421 m .49966 .75507 L .49865 .75407 L F
.647 .187 .147 r
.58366 .67751 m .58009 .6773 L .58124 .67755 L F
.488 .21 .419 r
.36903 .67917 m .36848 .68113 L .36631 .68165 L F
.337 .072 .357 r
.37081 .67847 m .36848 .68113 L .36903 .67917 L F
0 0 0 r
.33576 .72338 m .33375 .72378 L .33183 .72401 L F
.612 .949 .927 r
.33745 .72264 m .33375 .72378 L .33576 .72338 L F
.622 .707 .907 r
.72642 .61808 m .72618 .62045 L .72447 .61985 L F
.091 .476 .894 r
.72276 .61825 m .72447 .61985 L .72618 .62045 L F
.742 .667 .777 r
.33989 .71965 m .3438 .71978 L .34221 .71705 L F
0 .204 .729 r
.3438 .71978 m .34399 .71662 L .34221 .71705 L F
.3438 .71978 m .34428 .71903 L .34386 .71883 L F
.815 .596 .606 r
.34428 .71903 m .34379 .72197 L .34005 .72135 L F
.45 0 .049 r
.3424 .72009 m .34471 .71922 L .34428 .71903 L F
.34471 .71922 m .34596 .71876 L .34428 .71903 L F
0 .204 .729 r
.34386 .71883 m .34428 .71903 L .34399 .71662 L F
.431 .109 .316 r
.4913 .73185 m .49364 .73148 L .49449 .72838 L F
.402 .219 .515 r
.49449 .72838 m .49628 .7278 L .49641 .72549 L F
.397 .079 .304 r
.49449 .72838 m .49578 .73071 L .49628 .7278 L F
.49449 .72838 m .49364 .73148 L .49578 .73071 L F
.167 0 0 r
.27508 .60479 m .27331 .60569 L .27121 .60592 L F
.507 .045 .091 r
.2772 .60444 m .27331 .60569 L .27508 .60479 L F
.359 0 .104 r
.39695 .69744 m .40048 .69513 L .39842 .6957 L F
0 .202 .712 r
.73281 .71848 m .73492 .71996 L .7344 .72022 L F
0 .107 .624 r
.7358 .72125 m .7344 .72022 L .73492 .71996 L F
.7358 .72125 m .73667 .72229 L .7344 .72022 L F
.183 0 0 r
.29398 .65203 m .28996 .6532 L .29086 .65329 L F
.29398 .65203 m .2921 .65299 L .28996 .6532 L F
0 0 0 r
.29531 .65225 m .2921 .65299 L .29398 .65203 L F
.73 .522 .609 r
.6234 .54105 m .61967 .54341 L .62035 .54081 L F
.6234 .54105 m .62333 .54338 L .61967 .54341 L F
.549 .46 .706 r
.36672 .68587 m .36533 .68998 L .36495 .68794 L F
.607 .552 .767 r
.59384 .71403 m .59286 .71755 L .59178 .71464 L F
.59384 .71403 m .59518 .71722 L .59286 .71755 L F
.576 .386 .587 r
.59518 .71722 m .59339 .71988 L .59286 .71755 L F
.4 0 .146 r
.47926 .7371 m .48082 .73801 L .48146 .73675 L F
.47926 .7371 m .47804 .73874 L .48082 .73801 L F
.446 .176 .409 r
.44531 .67578 m .4427 .67825 L .44304 .67592 L F
.45 .096 .273 r
.43799 .67953 m .43736 .68099 L .4352 .68124 L F
.486 .146 .314 r
.43988 .67918 m .43736 .68099 L .43799 .67953 L F
.337 .766 .972 r
.70436 .59854 m .70769 .59894 L .70687 .59839 L F
0 .215 .706 r
.54009 .72117 m .53855 .72045 L .53736 .71965 L F
.535 0 0 r
.5391 .72079 m .54097 .72219 L .54231 .7228 L F
.53855 .72045 m .54097 .72219 L .5391 .72079 L F
.701 .187 .005 r
.54097 .72219 m .5447 .72409 L .54231 .7228 L F
.54097 .72219 m .54319 .72406 L .5447 .72409 L F
0 .25 .763 r
.5415 .72151 m .54293 .72367 L .54097 .72219 L F
.54293 .72367 m .54319 .72406 L .54097 .72219 L F
0 .215 .706 r
.54009 .72117 m .54097 .72219 L .53855 .72045 L F
0 0 0 r
.36968 .72115 m .36947 .72082 L .3714 .72005 L F
.36968 .72115 m .36766 .72168 L .36947 .72082 L F
.717 .986 .811 r
.5046 .72945 m .50291 .73107 L .50345 .73118 L F
.434 0 0 r
.30178 .73654 m .30392 .73685 L .30253 .73688 L F
.30253 .73688 m .30392 .73685 L .30178 .73654 L F
.244 .758 .84 r
.30601 .7365 m .30253 .73688 L .30392 .73685 L F
.30253 .73688 m .30601 .7365 L .30392 .73685 L F
.672 .643 .813 r
.37022 .69806 m .36662 .69588 L .36868 .6951 L F
.466 .508 .818 r
.37077 .69475 m .37022 .69806 L .36868 .6951 L F
.37077 .69475 m .37198 .69784 L .37022 .69806 L F
.361 .099 .376 r
.37795 .67272 m .37588 .67539 L .37596 .67304 L F
.96 .772 .605 r
.57694 .70968 m .57585 .7113 L .57745 .71172 L F
.328 .591 .94 r
.27311 .58825 m .27534 .58893 L .27486 .59024 L F
.378 .647 .962 r
.27534 .58893 m .27684 .5904 L .27486 .59024 L F
.602 .307 .441 r
.45746 .74715 m .46091 .7444 L .45798 .74553 L F
.449 .225 .48 r
.32426 .62334 m .32445 .62082 L .32647 .62027 L F
.025 .597 .724 r
.28585 .65416 m .28439 .65416 L .28229 .65419 L F
0 0 0 r
.28789 .6536 m .28439 .65416 L .28585 .65416 L F
.494 .772 .994 r
.30177 .75586 m .30537 .75662 L .3045 .75294 L F
.532 .848 .998 r
.30537 .75662 m .30755 .75607 L .30597 .75538 L F
.377 0 .001 r
.38645 .70156 m .38993 .70007 L .38785 .70046 L F
.818 .35 .102 r
.56706 .71751 m .56659 .71873 L .56591 .71674 L F
.56706 .71751 m .5687 .71994 L .56659 .71873 L F
.918 .899 .792 r
.62063 .53639 m .62187 .53748 L .62047 .53888 L F
.862 .91 .863 r
.62403 .53477 m .62187 .53748 L .62063 .53639 L F
.323 0 .249 r
.29709 .62879 m .29891 .6283 L .29945 .62639 L F
.21 0 .329 r
.29945 .62639 m .30124 .62577 L .30158 .62332 L F
.428 .191 .45 r
.29891 .6283 m .30124 .62577 L .29945 .62639 L F
.622 .955 .802 r
.74742 .61122 m .74525 .61285 L .74661 .61138 L F
.322 0 .101 r
.74525 .61285 m .74685 .61395 L .74661 .61138 L F
.74525 .61285 m .7445 .61453 L .74685 .61395 L F
.296 .772 .928 r
.50987 .75891 m .50903 .75857 L .50644 .75885 L F
.499 .693 .955 r
.37741 .70074 m .37697 .70254 L .37537 .70076 L F
.37741 .70074 m .37898 .70228 L .37697 .70254 L F
.503 .183 .356 r
.44809 .67379 m .44758 .67549 L .44531 .67578 L F
.517 .2 .368 r
.4507 .67283 m .44758 .67549 L .44809 .67379 L F
.648 .112 0 r
.56057 .71187 m .5587 .71167 L .55723 .7109 L F
.645 .128 0 r
.56057 .71187 m .56135 .71313 L .5587 .71167 L F
.56057 .71187 m .56242 .71394 L .56135 .71313 L F
.191 0 0 r
.47992 .76171 m .48151 .76195 L .48413 .76251 L F
.509 .467 .745 r
.44112 .65796 m .43932 .66012 L .43852 .6565 L F
.567 .551 .796 r
.44112 .65796 m .44217 .66128 L .43932 .66012 L F
.492 .283 .523 r
.42488 .69162 m .42299 .6899 L .4252 .68956 L F
.42488 .69162 m .42271 .69209 L .42299 .6899 L F
.698 .598 .74 r
.27493 .68322 m .27656 .68157 L .27445 .68159 L F
.899 .953 .609 r
.63666 .51503 m .63558 .51854 L .63765 .51821 L F
.63666 .51503 m .63526 .51802 L .63558 .51854 L F
.763 .542 .597 r
.63526 .51802 m .63542 .52073 L .63558 .51854 L F
.491 .29 .535 r
.63558 .51854 m .63542 .52073 L .63765 .51821 L F
.93 .651 .491 r
.60194 .67752 m .60347 .67606 L .60174 .67524 L F
.60194 .67752 m .6036 .67846 L .60347 .67606 L F
.493 .661 .936 r
.74297 .5918 m .74383 .5933 L .7453 .59169 L F
.429 .559 .884 r
.7453 .59169 m .74383 .5933 L .74573 .59339 L F
.489 .805 1 r
.53456 .71823 m .53275 .71926 L .53144 .71863 L F
.53456 .71823 m .53562 .71899 L .53275 .71926 L F
0 0 0 r
.38863 .66718 m .38474 .66881 L .38663 .66728 L F
.487 .379 .657 r
.33647 .67644 m .33874 .67841 L .33841 .6756 L F
.33647 .67644 m .33683 .67876 L .33874 .67841 L F
.413 .111 .341 r
.41483 .69958 m .41331 .69855 L .41564 .69819 L F
.41483 .69958 m .41278 .70018 L .41331 .69855 L F
.41 .777 .994 r
.30064 .59405 m .29856 .5945 L .29692 .59369 L F
.409 .142 .394 r
.49641 .72549 m .49838 .72512 L .49898 .72283 L F
.395 .154 .427 r
.49838 .72512 m .50092 .72192 L .49898 .72283 L F
.571 .213 .323 r
.56047 .68195 m .56366 .68097 L .56184 .68145 L F
0 .433 .725 r
.70845 .59049 m .70872 .59063 L .70564 .58971 L F
.661 .953 .723 r
.70961 .58932 m .70872 .59063 L .70845 .59049 L F
.597 .317 .462 r
.70872 .59063 m .7112 .59233 L .70871 .59273 L F
.921 .584 .384 r
.59895 .70013 m .59937 .70269 L .59838 .6995 L F
.59895 .70013 m .60033 .70319 L .59937 .70269 L F
.182 .691 .901 r
.30976 .59529 m .31178 .59529 L .31337 .59571 L F
.103 .637 .863 r
.31178 .59529 m .31529 .59581 L .31337 .59571 L F
.585 .445 .658 r
.75266 .59605 m .75324 .59825 L .75068 .59874 L F
.115 .096 .557 r
.58739 .72247 m .58784 .72524 L .58677 .72581 L F
.663 .752 .262 r
.58784 .72524 m .58671 .72813 L .58677 .72581 L F
0 0 0 r
.53539 .79823 m .53543 .79801 L .53757 .7972 L F
.406 0 .098 r
.35923 .65357 m .36144 .65335 L .3628 .65171 L F
.364 0 .071 r
.3628 .65171 m .36429 .65238 L .36501 .65139 L F
.3628 .65171 m .36144 .65335 L .36429 .65238 L F
.096 .261 .744 r
.57157 .72578 m .57245 .7247 L .57038 .72265 L F
.111 .285 .761 r
.57157 .72578 m .57374 .72779 L .57245 .7247 L F
.457 .177 .399 r
.54547 .75304 m .54739 .75319 L .54826 .75076 L F
.088 0 .215 r
.54826 .75076 m .5493 .75191 L .55053 .75056 L F
.54826 .75076 m .54739 .75319 L .5493 .75191 L F
.699 .355 .391 r
.73371 .5875 m .7299 .58557 L .73036 .58708 L F
.563 .117 .15 r
.54466 .73402 m .54335 .73567 L .54144 .73466 L F
0 .132 .661 r
.54466 .73402 m .54711 .73637 L .54521 .73403 L F
.562 .386 .6 r
.54504 .73672 m .54711 .73637 L .54466 .73402 L F
0 .132 .661 r
.54466 .73402 m .54521 .73403 L .54335 .73567 L F
.788 .816 .875 r
.62875 .52718 m .6258 .5273 L .6281 .52524 L F
.445 .323 .619 r
.63099 .52504 m .62875 .52718 L .6304 .52464 L F
.575 .525 .761 r
.63099 .52504 m .63129 .52716 L .62875 .52718 L F
.591 .779 .97 r
.73543 .62542 m .73639 .62721 L .73841 .6258 L F
.464 .332 .616 r
.44192 .75061 m .44385 .75027 L .44358 .7476 L F
.478 .395 .683 r
.44192 .75061 m .44418 .75278 L .44385 .75027 L F
.576 .4 .605 r
.44197 .75308 m .44418 .75278 L .44192 .75061 L F
.395 .212 .511 r
.55659 .74776 m .55827 .74732 L .55849 .74503 L F
.505 .326 .572 r
.55524 .74968 m .55827 .74732 L .55659 .74776 L F
.586 .151 .18 r
.74126 .58663 m .73933 .58451 L .73869 .58704 L F
.74126 .58663 m .7414 .5851 L .73933 .58451 L F
.731 .728 .848 r
.63361 .50719 m .62998 .50515 L .63188 .50421 L F
.63361 .50719 m .62936 .50728 L .62998 .50515 L F
.734 .631 .745 r
.63522 .50481 m .63361 .50719 L .63188 .50421 L F
.486 .31 .567 r
.63522 .50481 m .63508 .50748 L .63361 .50719 L F
.843 .743 .752 r
.59676 .72878 m .59509 .7299 L .59424 .72793 L F
.92 .704 .594 r
.57029 .75623 m .56995 .75857 L .56855 .75551 L F
.946 .93 .577 r
.57211 .76537 m .5734 .76413 L .57346 .76433 L F
0 0 .132 r
.74032 .7204 m .7418 .71959 L .7421 .71745 L F
.695 .255 .202 r
.74032 .7204 m .74164 .72135 L .7418 .71959 L F
.472 .323 .598 r
.74025 .72246 m .74234 .72222 L .74032 .7204 L F
.695 .255 .202 r
.74032 .7204 m .74234 .72222 L .73903 .72173 L F
.74032 .7204 m .73903 .72173 L .74164 .72135 L F
.559 0 0 r
.48766 .79158 m .49086 .79243 L .49042 .79319 L F
.467 0 0 r
.49042 .79319 m .49086 .79243 L .4935 .79349 L F
0 .442 .805 r
.51948 .79496 m .52053 .79553 L .52276 .79618 L F
.743 .785 .887 r
.73479 .62072 m .73184 .6219 L .73192 .62026 L F
.306 .111 .443 r
.46612 .76796 m .46593 .76988 L .46712 .76851 L F
.373 .06 .299 r
.46712 .76851 m .46612 .76796 L .46791 .7672 L F
.816 .733 .773 r
.32145 .70498 m .32291 .70825 L .32244 .70787 L F
.788 .722 .791 r
.32478 .70391 m .32291 .70825 L .32145 .70498 L F
.69 .632 .785 r
.32244 .70787 m .32459 .71038 L .32607 .70875 L F
.216 0 .324 r
.32459 .71038 m .32382 .7116 L .32607 .70875 L F
.377 .012 .212 r
.40065 .70639 m .39958 .70873 L .39748 .70916 L F
.217 0 .135 r
.40143 .70786 m .40065 .70639 L .40287 .70619 L F
.40143 .70786 m .39958 .70873 L .40065 .70639 L F
.648 .531 .707 r
.33399 .69224 m .33685 .6926 L .33637 .68967 L F
.644 .546 .729 r
.33399 .69224 m .33468 .69328 L .33685 .6926 L F
.901 .552 .372 r
.54708 .70343 m .54731 .70588 L .5467 .70333 L F
.457 .174 .395 r
.5334 .73375 m .53264 .73618 L .53006 .73614 L F
.637 .396 .536 r
.53264 .73618 m .52984 .73845 L .53006 .73614 L F
.461 .671 .954 r
.44353 .78472 m .44435 .783 L .44228 .78305 L F
.44353 .78472 m .44621 .78483 L .44435 .783 L F
.368 .159 .46 r
.30158 .62332 m .30362 .62304 L .30369 .62071 L F
.373 .11 .38 r
.30158 .62332 m .30304 .62512 L .30362 .62304 L F
.30158 .62332 m .30124 .62577 L .30304 .62512 L F
.59 .84 .992 r
.44783 .66506 m .44657 .66661 L .4451 .6654 L F
.44783 .66506 m .44859 .6661 L .44657 .66661 L F
.5 0 0 r
.56535 .68438 m .56632 .68532 L .56539 .68508 L F
.56535 .68438 m .5676 .68631 L .56632 .68532 L F
.57 .342 .53 r
.568 .68411 m .5676 .68631 L .56535 .68438 L F
.987 .86 .624 r
.60096 .71471 m .60015 .71368 L .60092 .711 L F
.828 .563 .013 r
.60098 .71733 m .60015 .71368 L .60096 .71471 L F
0 0 0 r
.54644 .74421 m .54676 .74396 L .54896 .74213 L F
.001 0 0 r
.54896 .74213 m .5506 .74174 L .5516 .74016 L F
0 .12 .669 r
.58104 .74213 m .58144 .74117 L .57968 .73914 L F
0 0 .216 r
.58155 .74459 m .58144 .74117 L .58104 .74213 L F
.809 .571 .577 r
.6165 .7092 m .61654 .71163 L .61904 .71193 L F
.836 .569 .535 r
.61654 .71163 m .61907 .71381 L .61904 .71193 L F
.807 .67 .713 r
.53386 .74642 m .53329 .74823 L .53256 .74587 L F
.6 .584 .807 r
.53329 .74823 m .53405 .747 L .53256 .74587 L F
.775 .301 .114 r
.53061 .7444 m .53386 .74642 L .53256 .74587 L F
.6 .584 .807 r
.53405 .747 m .53508 .74531 L .53256 .74587 L F
.775 .301 .114 r
.53045 .7443 m .53061 .7444 L .53256 .74587 L F
.693 .963 .941 r
.26535 .64504 m .26801 .64403 L .26647 .64491 L F
.462 .201 .431 r
.54184 .76195 m .54141 .76398 L .5395 .76451 L F
.749 .581 .667 r
.54384 .761 m .54141 .76398 L .54184 .76195 L F
.066 .595 .867 r
.38746 .64769 m .38911 .64798 L .39083 .64851 L F
0 0 0 r
.39022 .64714 m .39019 .64724 L .39009 .64732 L F
.367 .696 .983 r
.39009 .64732 m .39083 .64851 L .38914 .64799 L F
.39009 .64732 m .39228 .64864 L .39083 .64851 L F
.274 0 0 r
.39009 .64732 m .39506 .64888 L .39228 .64864 L F
.162 .68 .888 r
.39 .64812 m .39374 .64855 L .39009 .64732 L F
0 0 0 r
.39019 .64724 m .39 .64812 L .39009 .64732 L F
.367 .696 .983 r
.39009 .64732 m .38914 .64799 L .38911 .64798 L F
.937 .777 .308 r
.66362 .52989 m .66307 .5312 L .66336 .53177 L F
.057 0 .217 r
.66566 .52678 m .66557 .52881 L .66362 .52989 L F
0 0 0 r
.66557 .52881 m .66307 .5312 L .66362 .52989 L F
.585 .312 .47 r
.65143 .53761 m .65065 .54023 L .64826 .54046 L F
.595 .341 .502 r
.65372 .53743 m .65065 .54023 L .65143 .53761 L F
.496 .625 .908 r
.74707 .71173 m .743 .7093 L .74568 .711 L F
.732 .205 0 r
.74683 .71238 m .74707 .71173 L .74568 .711 L F
.74683 .71238 m .74889 .7138 L .74707 .71173 L F
.455 0 0 r
.48372 .78414 m .48535 .7853 L .48333 .78377 L F
.48372 .78414 m .48333 .78377 L .48302 .78354 L F
.578 .058 0 r
.4841 .7845 m .48372 .78414 L .48341 .78246 L F
0 .044 .612 r
.48438 .78445 m .48535 .7853 L .48372 .78414 L F
.979 .859 .65 r
.48535 .7853 m .4864 .78621 L .48717 .784 L F
0 .044 .612 r
.4861 .78527 m .48535 .7853 L .48438 .78445 L F
.657 .129 0 r
.48729 .78804 m .48632 .78646 L .48535 .7853 L F
.979 .859 .65 r
.48535 .7853 m .48632 .78646 L .4864 .78621 L F
.717 .345 .344 r
.48632 .78646 m .48845 .78875 L .48962 .78674 L F
0 .044 .612 r
.4861 .78527 m .48729 .78804 L .48535 .7853 L F
.578 .058 0 r
.48461 .78602 m .4861 .78527 L .48422 .78438 L F
.48461 .78602 m .48422 .78438 L .48372 .78414 L F
.653 .489 .649 r
.48371 .78861 m .48482 .7869 L .48461 .78602 L F
.657 .129 0 r
.48729 .78804 m .48845 .78875 L .48632 .78646 L F
.496 .54 .831 r
.48875 .78631 m .48729 .78804 L .4861 .78527 L F
.48875 .78631 m .4861 .78527 L .48892 .78476 L F
.062 0 0 r
.48892 .78476 m .4861 .78527 L .48461 .78602 L F
.48892 .78476 m .48461 .78602 L .48714 .78345 L F
.653 .489 .649 r
.48482 .7869 m .48614 .78488 L .48461 .78602 L F
.578 .058 0 r
.48461 .78602 m .48372 .78414 L .4841 .7845 L F
.355 .571 .921 r
.48717 .784 m .48856 .78422 L .48835 .78298 L F
.508 .408 .676 r
.33552 .68512 m .33747 .68375 L .33702 .68117 L F
.914 .953 .615 r
.59838 .6995 m .5987 .69714 L .59849 .69769 L F
.59838 .6995 m .59778 .69896 L .5987 .69714 L F
.908 .756 .681 r
.59937 .70269 m .59778 .69896 L .59838 .6995 L F
.803 .565 .579 r
.6132 .7111 m .6165 .7092 L .61322 .70864 L F
.6132 .7111 m .61654 .71163 L .6165 .7092 L F
.635 .286 .361 r
.63579 .54642 m .636 .54809 L .6325 .54822 L F
.603 .263 .366 r
.63579 .54642 m .63806 .54804 L .636 .54809 L F
.546 .299 .492 r
.63816 .54605 m .63806 .54804 L .63579 .54642 L F
.611 .623 .838 r
.50825 .72569 m .50883 .7215 L .50758 .72524 L F
.50825 .72569 m .51088 .72516 L .50883 .7215 L F
.957 .949 .688 r
.50758 .72524 m .50639 .72715 L .50825 .72569 L F
.545 .892 .66 r
.6111 .75023 m .61392 .748 L .61189 .74936 L F
.53 .834 .513 r
.6111 .75023 m .61189 .74936 L .61089 .75041 L F
.676 .718 .88 r
.33858 .71195 m .33781 .7092 L .33753 .70934 L F
.33858 .71195 m .33731 .71006 L .33781 .7092 L F
.33858 .71195 m .33561 .71046 L .33731 .71006 L F
0 0 .069 r
.57409 .75304 m .57408 .75544 L .57402 .75465 L F
.55 0 0 r
.72406 .6166 m .72273 .6152 L .72276 .61825 L F
.72406 .6166 m .72579 .6177 L .72273 .6152 L F
.621 .568 .774 r
.72642 .61808 m .72273 .6152 L .72579 .6177 L F
.523 .266 .466 r
.49222 .78813 m .48962 .78674 L .48845 .78875 L F
.49222 .78813 m .49215 .78711 L .48962 .78674 L F
.955 .832 .682 r
.59922 .69248 m .59961 .69548 L .59855 .6946 L F
0 0 .212 r
.59849 .69769 m .59855 .6946 L .59961 .69548 L F
.382 .525 .875 r
.3344 .71864 m .3348 .71637 L .33292 .7175 L F
.3344 .71864 m .33637 .71895 L .3348 .71637 L F
.551 .822 .466 r
.61392 .748 m .61623 .74526 L .61493 .74678 L F
.608 .924 .686 r
.61392 .748 m .61493 .74678 L .61189 .74936 L F
.581 .801 .983 r
.42583 .65376 m .42361 .65434 L .42234 .65325 L F
.628 .849 .984 r
.56232 .6957 m .55844 .69578 L .56169 .69506 L F
.595 .132 .125 r
.56232 .6957 m .56087 .69696 L .55844 .69578 L F
.977 .92 .636 r
.56169 .69506 m .56087 .69696 L .56232 .6957 L F
.559 .474 .715 r
.30543 .61287 m .30745 .61242 L .30716 .60929 L F
.42 .413 .746 r
.43552 .77523 m .43632 .77849 L .43804 .77776 L F
.45 .499 .818 r
.43632 .77849 m .43911 .78046 L .43804 .77776 L F
0 .341 .812 r
.53045 .7443 m .53256 .74587 L .53103 .74412 L F
.588 .857 .994 r
.50436 .73583 m .50492 .73657 L .50171 .73651 L F
.433 .767 .997 r
.50436 .73583 m .50727 .73652 L .50492 .73657 L F
.128 .223 .695 r
.58215 .74777 m .58334 .74673 L .58155 .74459 L F
0 .028 .588 r
.57716 .73396 m .57758 .73277 L .57663 .73093 L F
0 .114 .656 r
.57716 .73396 m .57871 .736 L .57758 .73277 L F
.966 .822 .651 r
.59715 .68441 m .59523 .68601 L .59608 .68362 L F
.59715 .68441 m .59526 .68662 L .59523 .68601 L F
.775 .549 .592 r
.53671 .74155 m .54015 .74203 L .53995 .73963 L F
.602 .42 .607 r
.53995 .73963 m .54015 .74203 L .54241 .73975 L F
.546 .639 .894 r
.73859 .71519 m .7421 .71745 L .7409 .71502 L F
.198 .398 .834 r
.7409 .71502 m .7421 .71745 L .74282 .71559 L F
0 0 0 r
.7421 .71745 m .7418 .71959 L .74282 .71559 L F
.558 .271 .436 r
.53515 .7357 m .53264 .73618 L .5334 .73375 L F
.655 .267 .298 r
.53571 .73423 m .53515 .7357 L .5334 .73375 L F
.609 .306 .431 r
.54255 .75565 m .54532 .75561 L .54547 .75304 L F
.494 .227 .439 r
.54532 .75561 m .54739 .75319 L .54547 .75304 L F
.737 .696 .812 r
.49756 .75635 m .50082 .75722 L .49966 .75507 L F
.658 .67 .85 r
.50082 .75722 m .50198 .75482 L .49966 .75507 L F
.50082 .75722 m .50339 .75694 L .50198 .75482 L F
.511 .236 .434 r
.41247 .68626 m .41513 .684 L .41307 .68458 L F
.948 .815 .68 r
.62462 .53276 m .62403 .53477 L .6234 .53185 L F
.052 .277 .769 r
.74859 .60156 m .74952 .60078 L .74714 .59877 L F
.136 .222 .69 r
.74925 .6038 m .74952 .60078 L .74859 .60156 L F
.065 0 0 r
.54574 .73982 m .54451 .73984 L .54241 .73975 L F
.516 .004 0 r
.54832 .73964 m .54451 .73984 L .54574 .73982 L F
.507 .35 .602 r
.34204 .66267 m .34412 .66191 L .34429 .65939 L F
.383 .328 .672 r
.34204 .66267 m .344 .66425 L .34412 .66191 L F
.34204 .66267 m .34248 .66493 L .344 .66425 L F
.676 .567 .725 r
.32382 .7116 m .32784 .71305 L .32607 .70875 L F
.368 .519 .876 r
.74573 .59339 m .74765 .59622 L .74878 .59467 L F
.25 .078 .443 r
.74765 .59622 m .74948 .59712 L .74878 .59467 L F
.74765 .59622 m .74714 .59877 L .74948 .59712 L F
.836 .679 .688 r
.632 .51606 m .62862 .51789 L .62885 .51565 L F
.632 .51606 m .63123 .51874 L .62862 .51789 L F
.401 .843 .934 r
.28789 .6536 m .29086 .65329 L .28996 .6532 L F
.444 .234 .498 r
.48761 .75103 m .48958 .75221 L .48915 .7523 L F
.994 .783 .415 r
.48761 .75103 m .48821 .7534 L .48728 .75076 L F
.48761 .75103 m .48744 .75264 L .48821 .7534 L F
.444 .234 .498 r
.48761 .75103 m .48915 .7523 L .48744 .75264 L F
.994 .783 .415 r
.48761 .75103 m .48728 .75076 L .48706 .75014 L F
.998 .82 .477 r
.48744 .75264 m .48725 .75465 L .48821 .7534 L F
.576 .009 0 r
.48898 .75446 m .48821 .7534 L .48725 .75465 L F
.48897 .75445 m .49045 .75519 L .4898 .75467 L F
.48869 .75407 m .4898 .75467 L .48821 .7534 L F
.48897 .75445 m .4898 .75467 L .48869 .75407 L F
.453 .017 .119 r
.4881 .75376 m .48725 .75465 L .48739 .75318 L F
.4881 .75376 m .48593 .75337 L .48725 .75465 L F
.48958 .75221 m .4881 .75376 L .48744 .75264 L F
.4881 .75376 m .48739 .75318 L .48744 .75264 L F
.48958 .75221 m .48685 .75308 L .4881 .75376 L F
.48685 .75308 m .48593 .75337 L .4881 .75376 L F
.576 .009 0 r
.48898 .75446 m .48899 .75447 L .48897 .75445 L F
.48899 .75447 m .49045 .75519 L .48897 .75445 L F
.669 .674 .846 r
.6524 .51855 m .6501 .51936 L .64899 .51758 L F
.379 .34 .689 r
.51 .71951 m .51147 .71942 L .50929 .71744 L F
.709 .279 .224 r
.50929 .71744 m .51147 .71942 L .50806 .71889 L F
.193 0 0 r
.26899 .65675 m .27102 .65645 L .26882 .65687 L F
.794 .72 .782 r
.73404 .61752 m .73479 .62072 L .73192 .62026 L F
.746 .691 .798 r
.73741 .61797 m .73479 .62072 L .73404 .61752 L F
.549 .46 .706 r
.36672 .68587 m .36739 .68959 L .36533 .68998 L F
.571 .498 .734 r
.36739 .68959 m .3657 .69188 L .36533 .68998 L F
.583 .017 0 r
.55358 .72721 m .55759 .72988 L .55512 .72811 L F
.469 .292 .557 r
.31527 .72234 m .31461 .72473 L .3168 .72239 L F
.757 .639 .73 r
.51611 .73961 m .51289 .73639 L .51298 .73886 L F
.51611 .73961 m .51627 .73661 L .51289 .73639 L F
.582 .34 .515 r
.51419 .74183 m .51611 .73961 L .51298 .73886 L F
.51419 .74183 m .51628 .74196 L .51611 .73961 L F
.51419 .74183 m .51628 .74196 L .51611 .73961 L F
0 0 0 r
.51611 .73961 m .51867 .73647 L .51627 .73661 L F
.51611 .73961 m .51769 .73824 L .51867 .73647 L F
.241 .259 .679 r
.51709 .74115 m .51769 .73824 L .51611 .73961 L F
.705 .686 .83 r
.63409 .50188 m .63522 .50481 L .63188 .50421 L F
.679 .672 .837 r
.63808 .5038 m .63522 .50481 L .63409 .50188 L F
.571 .498 .734 r
.36739 .68959 m .36801 .69148 L .3657 .69188 L F
.608 .497 .701 r
.36868 .6951 m .3657 .69188 L .36801 .69148 L F
.36868 .6951 m .36662 .69588 L .3657 .69188 L F
.665 .95 .707 r
.325 .72476 m .32422 .72609 L .32633 .72535 L F
.602 .307 .441 r
.45746 .74715 m .45988 .74707 L .46091 .7444 L F
.553 .249 .405 r
.45988 .74707 m .46314 .74442 L .46091 .7444 L F
.547 .078 .093 r
.48731 .76168 m .48587 .7631 L .48413 .76251 L F
.207 0 0 r
.48731 .76168 m .4863 .76224 L .48587 .7631 L F
.48731 .76168 m .4894 .76161 L .4863 .76224 L F
.567 .105 .117 r
.62911 .54758 m .62679 .54634 L .6305 .54621 L F
.739 .321 .255 r
.6305 .54621 m .6325 .54822 L .62911 .54758 L F
.402 .722 .989 r
.41534 .65109 m .41457 .65221 L .41309 .65105 L F
.41534 .65109 m .41686 .65223 L .41457 .65221 L F
.661 .593 .769 r
.58729 .72022 m .5849 .72059 L .58404 .71711 L F
.612 .467 .66 r
.58739 .72247 m .5849 .72059 L .58729 .72022 L F
.58739 .72247 m .58507 .72303 L .5849 .72059 L F
.369 .085 .345 r
.3132 .63716 m .31571 .63448 L .31521 .63686 L F
.223 0 .243 r
.3175 .63391 m .31521 .63686 L .31571 .63448 L F
.38 .17 .465 r
.49628 .7278 m .49838 .72512 L .49641 .72549 L F
.494 .727 .975 r
.2954 .60626 m .29618 .60476 L .29412 .60364 L F
.2954 .60626 m .29752 .60603 L .29618 .60476 L F
.6 .584 .807 r
.53329 .74823 m .53552 .74848 L .53508 .74531 L F
.627 .467 .646 r
.53329 .74823 m .53345 .75036 L .53552 .74848 L F
.533 .108 .18 r
.40007 .66511 m .39863 .66692 L .39645 .66671 L F
.038 0 0 r
.40063 .66588 m .39863 .66692 L .40007 .66511 L F
.517 .2 .368 r
.4507 .67283 m .4498 .67526 L .44758 .67549 L F
.533 .418 .667 r
.45256 .66939 m .45284 .67264 L .4507 .67283 L F
.645 .329 .422 r
.45257 .67503 m .4507 .67283 L .45284 .67264 L F
.45257 .67503 m .4498 .67526 L .4507 .67283 L F
.544 .215 .361 r
.65906 .53489 m .65852 .53716 L .65607 .5373 L F
.508 .213 .4 r
.66127 .53446 m .65852 .53716 L .65906 .53489 L F
.55 .83 .998 r
.42932 .65403 m .42583 .65376 L .42798 .65328 L F
.512 .825 1 r
.42932 .65403 m .43013 .65282 L .43147 .65347 L F
.42932 .65403 m .42798 .65328 L .43013 .65282 L F
.896 .686 .611 r
.61379 .70309 m .61533 .70357 L .61395 .70053 L F
.869 .722 .697 r
.61206 .70561 m .61533 .70357 L .61379 .70309 L F
.61206 .70561 m .61322 .70607 L .61533 .70357 L F
.508 .532 .816 r
.55058 .76401 m .55182 .76703 L .55368 .76673 L F
.479 .346 .622 r
.55368 .76673 m .55396 .76906 L .55182 .76703 L F
.55368 .76673 m .55396 .76906 L .55182 .76703 L F
.136 0 .418 r
.28478 .63904 m .28622 .63902 L .28642 .63668 L F
.097 0 0 r
.28478 .63904 m .28336 .64094 L .28622 .63902 L F
.954 .892 .728 r
.64159 .50937 m .64392 .50748 L .64096 .50711 L F
.64159 .50937 m .64238 .51075 L .64392 .50748 L F
.829 .648 .657 r
.60218 .70653 m .59913 .70609 L .60033 .70319 L F
.85 .674 .664 r
.60113 .70875 m .59913 .70609 L .60218 .70653 L F
.746 .371 0 r
.56898 .70495 m .56991 .70655 L .5687 .7041 L F
.786 .304 0 r
.57039 .70807 m .56991 .70655 L .56898 .70495 L F
.57039 .70807 m .57144 .70884 L .56991 .70655 L F
.353 0 0 r
.71761 .59332 m .71669 .59282 L .71507 .59192 L F
.977 .676 .357 r
.71761 .59332 m .71792 .59558 L .71669 .59282 L F
.484 .475 .771 r
.71941 .59149 m .71761 .59332 L .71689 .59028 L F
.684 .608 .765 r
.71941 .59149 m .71792 .59558 L .71761 .59332 L F
.177 0 0 r
.37758 .71814 m .377 .71734 L .37897 .71672 L F
.37758 .71814 m .37543 .71859 L .377 .71734 L F
0 0 0 r
.30193 .64943 m .30181 .64871 L .30352 .64787 L F
.30193 .64943 m .30012 .65025 L .30181 .64871 L F
.359 0 .043 r
.73325 .70809 m .73629 .70648 L .73407 .707 L F
.662 .108 0 r
.52711 .71208 m .53039 .7141 L .52826 .71263 L F
.516 .26 .465 r
.46548 .74452 m .46811 .74207 L .46584 .74241 L F
.566 .45 .68 r
.43685 .76699 m .43918 .76969 L .43865 .76655 L F
.43685 .76699 m .4372 .77012 L .43918 .76969 L F
.395 .008 .182 r
.36397 .72334 m .36333 .72468 L .36128 .72486 L F
.65 .421 .558 r
.36628 .72258 m .36333 .72468 L .36397 .72334 L F
.562 .402 .622 r
.6675 .5256 m .66557 .52881 L .66566 .52678 L F
.61 .649 .864 r
.43852 .6565 m .43479 .65438 L .4368 .65407 L F
.375 .563 .909 r
.43934 .65488 m .43852 .6565 L .4368 .65407 L F
.395 .587 .92 r
.43934 .65488 m .4403 .65652 L .43852 .6565 L F
.509 .467 .745 r
.44112 .65796 m .43852 .6565 L .4403 .65652 L F
.675 .127 0 r
.54741 .69763 m .55102 .70024 L .55061 .6989 L F
0 0 .455 r
.32213 .71977 m .32281 .72269 L .32309 .72122 L F
.32213 .71977 m .32309 .72122 L .32162 .71919 L F
.485 .344 .614 r
.42019 .67853 m .42232 .678 L .42215 .67577 L F
.535 .314 .527 r
.41971 .68098 m .42232 .678 L .42019 .67853 L F
.605 .577 .795 r
.51948 .76581 m .52189 .76398 L .51902 .76422 L F
.51948 .76581 m .5227 .76555 L .52189 .76398 L F
.856 .514 .406 r
.42312 .66588 m .42254 .66707 L .42188 .66517 L F
.514 .052 .095 r
.50676 .79087 m .50462 .78985 L .50334 .7914 L F
.601 .401 .583 r
.55502 .75602 m .55503 .75843 L .55265 .75852 L F
.55502 .75602 m .55265 .75852 L .55299 .75641 L F
.55502 .75602 m .55503 .75843 L .55265 .75852 L F
.35 .763 .98 r
.30483 .59368 m .30418 .59453 L .30256 .59405 L F
.30483 .59368 m .30645 .59435 L .30418 .59453 L F
.778 .35 .233 r
.72564 .59095 m .72444 .59183 L .72246 .5899 L F
.899 .55 .374 r
.72564 .59095 m .72608 .59307 L .72444 .59183 L F
.761 .495 .531 r
.72564 .59095 m .72914 .59312 L .72608 .59307 L F
.14 0 0 r
.44586 .74623 m .44852 .74557 L .44647 .74477 L F
.725 .513 .604 r
.56995 .75857 m .56646 .75594 L .56855 .75551 L F
.56995 .75857 m .56637 .75856 L .56646 .75594 L F
.651 .752 .923 r
.73208 .72569 m .7357 .7263 L .73448 .72521 L F
.828 .365 .109 r
.55052 .70827 m .54731 .70588 L .54931 .7067 L F
.491 .319 .575 r
.42244 .6733 m .42417 .6749 L .42371 .6726 L F
.42244 .6733 m .42215 .67577 L .42417 .6749 L F
.455 .765 .996 r
.27186 .58751 m .27134 .58866 L .26974 .58755 L F
.27186 .58751 m .27311 .58825 L .27134 .58866 L F
.513 .515 .795 r
.44034 .78335 m .44124 .78018 L .43911 .78046 L F
.44034 .78335 m .44228 .78305 L .44124 .78018 L F
.823 .427 .3 r
.5565 .70053 m .55988 .70309 L .5595 .70098 L F
0 0 0 r
.57201 .676 m .57294 .67629 L .57438 .67456 L F
.57201 .676 m .57073 .67734 L .57294 .67629 L F
.663 .752 .262 r
.58784 .72524 m .58706 .72723 L .58671 .72813 L F
.985 .707 .383 r
.58706 .72723 m .58822 .73027 L .58671 .72813 L F
.236 .207 .621 r
.58822 .73027 m .58723 .73122 L .58671 .72813 L F
.547 .397 .629 r
.59138 .73782 m .58874 .73982 L .58755 .7387 L F
.59138 .73782 m .59164 .73846 L .58874 .73982 L F
.568 .408 .624 r
.59241 .73814 m .59164 .73846 L .59138 .73782 L F
.674 .842 .964 r
.59253 .73804 m .59164 .73846 L .59253 .73804 L F
.59164 .73846 m .58874 .73982 L .59167 .73845 L F
.59164 .73846 m .59167 .73845 L .59253 .73804 L F
.454 .491 .807 r
.59253 .73804 m .59179 .73948 L .59299 .73832 L F
.616 .774 .956 r
.59299 .73832 m .59445 .73953 L .59179 .73948 L F
.59299 .73832 m .59445 .73953 L .59179 .73948 L F
0 0 0 r
.59179 .73948 m .59203 .73942 L .59299 .73832 L F
.568 .408 .624 r
.59299 .73832 m .59203 .73942 L .59164 .73846 L F
.671 .76 .917 r
.5925 .73811 m .58874 .73982 L .59179 .73948 L F
.568 .408 .624 r
.59243 .73814 m .59167 .73845 L .59241 .73814 L F
.671 .76 .917 r
.59253 .73804 m .59167 .73845 L .5925 .73811 L F
.59167 .73845 m .58874 .73982 L .5925 .73811 L F
.568 .408 .624 r
.59299 .73832 m .59164 .73846 L .59167 .73845 L F
.59299 .73832 m .59167 .73845 L .59243 .73814 L F
.547 .397 .629 r
.59164 .73846 m .59203 .73942 L .58874 .73982 L F
.674 .842 .964 r
.58755 .7387 m .58874 .73982 L .59253 .73804 L F
.112 .665 .736 r
.58874 .73982 m .59203 .73942 L .59179 .73948 L F
.856 .404 .113 r
.49399 .78832 m .49215 .78711 L .49222 .78813 L F
.715 .231 .095 r
.49409 .79023 m .49399 .78832 L .49222 .78813 L F
.49409 .79023 m .49558 .78953 L .49399 .78832 L F
.186 .687 .912 r
.74457 .58554 m .74152 .58511 L .74367 .58485 L F
.396 .731 .991 r
.7462 .58454 m .74457 .58554 L .74367 .58485 L F
.103 0 0 r
.74616 .58455 m .74367 .58485 L .74283 .58543 L F
.7462 .58454 m .74367 .58485 L .74616 .58455 L F
.186 .687 .912 r
.74152 .58511 m .7414 .5851 L .74367 .58485 L F
.396 .731 .991 r
.7462 .58454 m .74714 .58551 L .74457 .58554 L F
.653 .488 .648 r
.54599 .75728 m .54384 .761 L .54399 .75853 L F
.54599 .75728 m .54872 .76092 L .54384 .761 L F
.667 .509 .661 r
.54949 .75852 m .54872 .76092 L .54599 .75728 L F
.346 .046 .305 r
.26159 .60994 m .26103 .61137 L .25899 .6124 L F
.378 .076 .321 r
.26309 .61039 m .26159 .60994 L .26342 .6092 L F
.26309 .61039 m .26103 .61137 L .26159 .60994 L F
.616 .116 .04 r
.53174 .76628 m .53028 .76685 L .52804 .76607 L F
.393 0 0 r
.51814 .709 m .52202 .71048 L .5214 .70978 L F
.512 .792 .996 r
.28083 .58959 m .28038 .59093 L .27886 .58983 L F
.28083 .58959 m .28232 .59057 L .28038 .59093 L F
.913 .563 .363 r
.56394 .75942 m .56255 .76012 L .56068 .75836 L F
.56394 .75942 m .56404 .76068 L .56255 .76012 L F
.465 .242 .491 r
.31789 .63169 m .32023 .62894 L .31972 .63097 L F
.41 .17 .435 r
.32198 .62826 m .31972 .63097 L .32023 .62894 L F
.441 .839 .978 r
.27059 .64379 m .27445 .64382 L .27183 .64457 L F
.466 .874 .724 r
.55373 .68649 m .55496 .68552 L .55659 .68482 L F
.455 .847 .642 r
.55373 .68649 m .5533 .68669 L .55496 .68552 L F
.901 .772 .709 r
.54015 .74203 m .53934 .74503 L .54022 .74531 L F
.946 .621 .383 r
.53934 .74503 m .54057 .74701 L .54022 .74531 L F
.523 .322 .55 r
.46121 .76385 m .45902 .76652 L .45906 .76427 L F
.46121 .76385 m .45902 .76652 L .45906 .76427 L F
.994 .783 .415 r
.48761 .75103 m .48706 .75014 L .49055 .75044 L F
.723 .285 .209 r
.49055 .75044 m .48958 .75221 L .48761 .75103 L F
.49055 .75044 m .49348 .75275 L .48958 .75221 L F
.048 .611 .788 r
.25706 .58635 m .25658 .58648 L .25449 .58507 L F
.25706 .58635 m .2587 .58654 L .25658 .58648 L F
.539 .339 .558 r
.72618 .62045 m .72642 .61808 L .72579 .6177 L F
.72618 .62045 m .72852 .61992 L .72642 .61808 L F
0 0 0 r
.62072 .73065 m .62008 .73281 L .61925 .73392 L F
.041 .027 .512 r
.62008 .73281 m .61913 .73629 L .61925 .73392 L F
.508 .88 .976 r
.6013 .75805 m .60233 .75701 L .60017 .7577 L F
.6013 .75805 m .60403 .7573 L .60233 .75701 L F
.546 .354 .573 r
.36848 .68113 m .36836 .68355 L .36631 .68165 L F
.437 .352 .662 r
.36631 .68165 m .36836 .68355 L .36668 .68398 L F
.314 .084 .396 r
.31972 .63097 m .3175 .63391 L .31789 .63169 L F
.412 .631 .945 r
.27693 .68352 m .27949 .68477 L .28082 .68438 L F
.933 .73 .606 r
.58822 .73027 m .58748 .73383 L .58723 .73122 L F
.58822 .73027 m .58974 .73333 L .58748 .73383 L F
0 0 0 r
.61842 .74052 m .61721 .74399 L .61776 .74203 L F
.26 0 .186 r
.41067 .70073 m .40972 .703 L .40759 .70323 L F
.279 0 .195 r
.41167 .70225 m .41067 .70073 L .41278 .70018 L F
.41167 .70225 m .40972 .703 L .41067 .70073 L F
.666 .201 .139 r
.74251 .71084 m .74568 .711 L .743 .7093 L F
.504 .124 .252 r
.49561 .75928 m .49377 .76253 L .49156 .76247 L F
0 0 .568 r
.49599 .75836 m .49561 .75928 L .49421 .75758 L F
.49599 .75836 m .49711 .76103 L .49561 .75928 L F
.482 .106 .25 r
.49711 .76103 m .49377 .76253 L .49561 .75928 L F
.645 .161 .087 r
.49681 .79411 m .50015 .79449 L .49921 .79589 L F
.494 .105 .23 r
.50015 .79449 m .50102 .79654 L .49921 .79589 L F
.50015 .79449 m .50229 .79453 L .50102 .79654 L F
.505 .326 .572 r
.55524 .74968 m .5583 .74975 L .55827 .74732 L F
.507 .369 .627 r
.55524 .74968 m .55638 .75076 L .5583 .74975 L F
.77 .869 .921 r
.73096 .7186 m .72722 .71953 L .72974 .71697 L F
.554 .744 .965 r
.73172 .71695 m .73096 .7186 L .72974 .71697 L F
.73172 .71695 m .73281 .71848 L .73096 .7186 L F
.749 .249 0 r
.57663 .73093 m .57374 .72779 L .57411 .72937 L F
.621 .12 .042 r
.58696 .67772 m .58551 .67829 L .58366 .67751 L F
.267 0 0 r
.58908 .67781 m .58551 .67829 L .58696 .67772 L F
0 0 .506 r
.54172 .69766 m .54282 .70115 L .54252 .69953 L F
.574 0 0 r
.5467 .70333 m .54519 .7028 L .54282 .70115 L F
.879 .49 .295 r
.54519 .7028 m .54252 .69953 L .54282 .70115 L F
.331 .149 .477 r
.50407 .71371 m .50476 .71639 L .50491 .71414 L F
.50407 .71371 m .50358 .71689 L .50476 .71639 L F
.323 .745 .975 r
.31529 .59581 m .31741 .59574 L .31884 .5964 L F
.393 .764 .992 r
.31938 .59544 m .31884 .5964 L .31741 .59574 L F
.31938 .59544 m .3208 .59619 L .31884 .5964 L F
.446 .35 .653 r
.75492 .59453 m .75324 .59825 L .75266 .59605 L F
.725 .293 .223 r
.55294 .73689 m .55229 .73843 L .55124 .73768 L F
.536 .395 .636 r
.55586 .73868 m .55378 .73944 L .55294 .73689 L F
.665 .227 .199 r
.55586 .73868 m .55229 .73843 L .55294 .73689 L F
.025 .593 .777 r
.73986 .59162 m .74186 .59161 L .73948 .59198 L F
.73986 .59162 m .74297 .5918 L .74186 .59161 L F
.878 .913 .511 r
.74998 .60645 m .74858 .60878 L .74867 .60602 L F
.74998 .60645 m .74847 .60979 L .74858 .60878 L F
0 0 0 r
.40572 .66489 m .40387 .66524 L .40246 .66532 L F
.574 .868 .995 r
.40769 .66524 m .40387 .66524 L .40572 .66489 L F
.741 .629 .735 r
.50911 .73389 m .51321 .73334 L .51096 .72973 L F
.46 0 .008 r
.51037 .73491 m .51321 .73334 L .50911 .73389 L F
.294 .301 .697 r
.51321 .73334 m .51389 .73046 L .51096 .72973 L F
.236 .068 .438 r
.51462 .73571 m .51321 .73334 L .51037 .73491 L F
.816 .599 .608 r
.63666 .51503 m .63988 .51317 L .63944 .51317 L F
.63666 .51503 m .63981 .51552 L .63988 .51317 L F
.615 .912 .638 r
.64111 .51167 m .63988 .51317 L .64238 .51075 L F
.643 .951 .742 r
.63944 .51317 m .63988 .51317 L .64111 .51167 L F
.498 .214 .414 r
.42796 .68732 m .4274 .68923 L .4252 .68956 L F
.523 .315 .54 r
.4297 .68647 m .4274 .68923 L .42796 .68732 L F
.299 .61 .954 r
.28823 .59161 m .28999 .59184 L .28944 .59293 L F
.409 .74 .992 r
.28999 .59184 m .29147 .59286 L .28944 .59293 L F
.491 0 0 r
.56945 .74297 m .57115 .74329 L .57116 .74319 L F
0 0 .239 r
.57255 .74356 m .57172 .74697 L .57116 .74319 L F
.491 0 0 r
.57115 .74329 m .57255 .74356 L .57116 .74319 L F
0 0 0 r
.57116 .74319 m .57051 .74478 L .57127 .74242 L F
.57116 .74319 m .57127 .74242 L .57148 .74177 L F
0 0 .528 r
.57116 .74319 m .57172 .74697 L .57051 .74478 L F
.572 .566 .808 r
.37537 .70076 m .37335 .70125 L .37198 .69784 L F
.255 .673 .964 r
.28664 .5907 m .28595 .59151 L .28445 .59072 L F
.28664 .5907 m .28823 .59161 L .28595 .59151 L F
.856 .605 .559 r
.61599 .72153 m .61892 .72009 L .61769 .71962 L F
.61599 .72153 m .619 .72248 L .61892 .72009 L F
.591 .495 .714 r
.33702 .68117 m .33874 .67841 L .33683 .67876 L F
.447 0 .052 r
.53966 .7944 m .54282 .79353 L .54234 .79455 L F
.53966 .7944 m .54282 .79353 L .54234 .79455 L F
.071 0 0 r
.54234 .79455 m .54282 .79353 L .54422 .7936 L F
.54422 .7936 m .54282 .79353 L .54234 .79455 L F
.805 .988 .733 r
.74819 .61045 m .74742 .61122 L .74847 .60979 L F
.771 .656 .735 r
.55503 .75843 m .55595 .76206 L .55839 .75848 L F
.55503 .75843 m .55839 .75848 L .55727 .76046 L F
.612 .269 .364 r
.56068 .75836 m .55727 .76046 L .55839 .75848 L F
.967 .727 .522 r
.619 .72248 m .61894 .72497 L .62028 .72564 L F
.967 .741 .544 r
.61894 .72497 m .61996 .72817 L .62028 .72564 L F
.61894 .72497 m .61996 .72817 L .62028 .72564 L F
.608 .524 .734 r
.33624 .70358 m .33718 .70657 L .33957 .70592 L F
.431 .342 .655 r
.33718 .70657 m .33781 .7092 L .33998 .70822 L F
.551 0 0 r
.33718 .70657 m .33998 .70822 L .33789 .70763 L F
.33718 .70657 m .33789 .70763 L .33957 .70592 L F
.723 .738 .862 r
.5497 .69342 m .55306 .69329 L .55256 .69445 L F
0 0 0 r
.5537 .69369 m .55306 .69329 L .5552 .69232 L F
.5537 .69369 m .55256 .69445 L .55306 .69329 L F
.74 .608 .711 r
.55681 .74218 m .55849 .74503 L .55515 .74478 L F
.745 .505 .567 r
.55827 .74732 m .55515 .74478 L .55849 .74503 L F
.602 .424 .613 r
.43552 .77523 m .43792 .775 L .43784 .77253 L F
.547 .492 .746 r
.4372 .77012 m .43784 .77253 L .43992 .7721 L F
.489 .336 .599 r
.43784 .77253 m .4399 .77455 L .43992 .7721 L F
.43784 .77253 m .43792 .775 L .4399 .77455 L F
.434 .548 .872 r
.63981 .51552 m .64333 .51811 L .64328 .51595 L F
.431 .862 .932 r
.41349 .66457 m .40987 .66505 L .41156 .66548 L F
.405 .068 .278 r
.48679 .73368 m .48886 .73321 L .4894 .73208 L F
.248 0 .196 r
.4894 .73208 m .4908 .7323 L .4913 .73185 L F
.4894 .73208 m .48886 .73321 L .4908 .7323 L F
.397 .004 .171 r
.28642 .63668 m .28857 .63638 L .28989 .63439 L F
.147 0 .023 r
.28989 .63439 m .29044 .63552 L .29211 .63422 L F
.28989 .63439 m .28857 .63638 L .29044 .63552 L F
.37 .123 .403 r
.34196 .66716 m .34248 .66493 L .34014 .66767 L F
.224 0 .343 r
.344 .66425 m .34248 .66493 L .34196 .66716 L F
.624 .358 .495 r
.51096 .72973 m .51389 .73046 L .51142 .72868 L F
.526 .282 .488 r
.4352 .68124 m .43554 .68351 L .43263 .68377 L F
.571 .312 .486 r
.43739 .68314 m .4352 .68124 L .43736 .68099 L F
.43739 .68314 m .43554 .68351 L .4352 .68124 L F
.875 .768 .741 r
.61659 .71371 m .61767 .71719 L .61828 .71511 L F
.61659 .71371 m .61474 .71672 L .61767 .71719 L F
.83 .602 .593 r
.6144 .71894 m .61767 .71719 L .61474 .71672 L F
.6144 .71894 m .61769 .71962 L .61767 .71719 L F
.574 .14 .178 r
.51255 .70903 m .51452 .71042 L .5159 .70862 L F
.258 0 0 r
.5159 .70862 m .51714 .70973 L .51814 .709 L F
.5159 .70862 m .51452 .71042 L .51714 .70973 L F
0 0 .426 r
.32784 .71305 m .32799 .71487 L .32848 .71379 L F
0 0 0 r
.32799 .71487 m .32713 .71692 L .32848 .71379 L F
.419 .849 .945 r
.27102 .65645 m .26724 .65676 L .26882 .65687 L F
.42 .413 .746 r
.43552 .77523 m .43804 .77776 L .43792 .775 L F
.571 .307 .476 r
.64588 .54069 m .64825 .54234 L .64596 .54259 L F
.57 .307 .479 r
.64588 .54069 m .64826 .54046 L .64825 .54234 L F
.399 .816 .973 r
.34131 .71878 m .33989 .71965 L .34221 .71705 L F
.34131 .71878 m .33822 .7191 L .33989 .71965 L F
.935 .575 .307 r
.467 .78093 m .46836 .78124 L .46589 .77783 L F
0 .313 .782 r
.46952 .78139 m .46836 .78124 L .467 .78093 L F
.46952 .78139 m .47054 .78249 L .46836 .78124 L F
.013 0 0 r
.53397 .7575 m .53665 .75677 L .53472 .75629 L F
.647 .103 0 r
.4797 .78252 m .48166 .78147 L .47991 .78106 L F
.712 .642 .778 r
.73146 .59089 m .7326 .59304 L .72914 .59312 L F
.657 .321 .393 r
.72914 .59312 m .7326 .59304 L .73163 .59514 L F
.667 .632 .805 r
.73383 .59 m .7326 .59304 L .73146 .59089 L F
.73383 .59 m .73477 .59281 L .7326 .59304 L F
.507 .095 .194 r
.7326 .59304 m .73402 .59463 L .73163 .59514 L F
.7326 .59304 m .73477 .59281 L .73402 .59463 L F
.456 .112 .292 r
.48363 .73635 m .4859 .73602 L .48679 .73368 L F
.427 .093 .294 r
.4859 .73602 m .48886 .73321 L .48679 .73368 L F
.934 .664 .504 r
.59888 .68967 m .59737 .69136 L .59661 .68983 L F
.59888 .68967 m .59922 .69248 L .59737 .69136 L F
.786 .498 .5 r
.4912 .78032 m .49433 .78312 L .49195 .78352 L F
.284 0 0 r
.49309 .78333 m .49229 .78385 L .49195 .78352 L F
.49229 .78385 m .49094 .78472 L .49174 .78377 L F
.49229 .78385 m .49174 .78377 L .49195 .78352 L F
.49319 .78366 m .49094 .78472 L .49309 .78333 L F
.49319 .78366 m .49313 .78389 L .49094 .78472 L F
.49313 .78389 m .493 .78439 L .49213 .78453 L F
.49313 .78389 m .49213 .78453 L .49094 .78472 L F
.49433 .78312 m .49319 .78366 L .49309 .78333 L F
.786 .498 .5 r
.4912 .78032 m .49324 .78382 L .49433 .78312 L F
.49324 .78382 m .49352 .7843 L .49433 .78312 L F
0 0 .234 r
.4896 .77985 m .49016 .78126 L .49177 .78192 L F
.302 .401 .798 r
.49086 .78081 m .49177 .78192 L .49016 .78126 L F
.741 .306 0 r
.49177 .78192 m .4929 .78331 L .4912 .78032 L F
.49329 .78399 m .49329 .78398 L .4912 .78032 L F
.49329 .78399 m .49324 .78382 L .4912 .78032 L F
.302 .401 .798 r
.49268 .77963 m .49177 .78192 L .49086 .78081 L F
.741 .306 0 r
.49177 .78192 m .49329 .78399 L .4929 .78331 L F
.49329 .78399 m .49329 .78399 L .49329 .78398 L F
.49329 .78399 m .49352 .7843 L .49324 .78382 L F
.284 0 0 r
.49433 .78312 m .49332 .78408 L .49319 .78366 L F
.49332 .78408 m .493 .78439 L .49319 .78366 L F
.442 .768 .997 r
.49369 .78345 m .49357 .78403 L .49177 .78192 L F
.49357 .78403 m .49352 .7843 L .49331 .78401 L F
.49338 .784 m .49331 .78401 L .49329 .78399 L F
.49357 .78403 m .49331 .78401 L .49338 .784 L F
.316 0 .214 r
.49352 .7843 m .49468 .78324 L .49433 .78312 L F
.642 .469 .634 r
.49681 .78131 m .49674 .78332 L .49433 .78312 L F
.316 0 .214 r
.49468 .78324 m .49681 .78131 L .49433 .78312 L F
.49352 .7843 m .49615 .78376 L .49619 .78361 L F
.08 0 0 r
.49584 .78353 m .49433 .78312 L .4954 .78321 L F
.49597 .7835 m .4954 .78321 L .49674 .78332 L F
.49584 .78353 m .4954 .78321 L .49597 .7835 L F
.504 .355 .612 r
.49883 .78266 m .49681 .78131 L .49871 .78011 L F
.49883 .78266 m .49674 .78332 L .49681 .78131 L F
.625 .201 .218 r
.49883 .78266 m .49646 .78332 L .49674 .78332 L F
.08 0 0 r
.49468 .78324 m .49433 .78312 L .49584 .78353 L F
.316 0 .214 r
.49468 .78324 m .49584 .78353 L .49681 .78131 L F
.625 .201 .218 r
.49625 .7834 m .49584 .78353 L .49597 .7835 L F
.316 0 .214 r
.49584 .78353 m .49619 .78361 L .49625 .7834 L F
.49584 .78353 m .49625 .7834 L .49681 .78131 L F
.625 .201 .218 r
.49646 .78332 m .49521 .78367 L .49584 .78353 L F
.49646 .78332 m .49584 .78353 L .49625 .7834 L F
.49646 .78332 m .49597 .7835 L .49674 .78332 L F
.005 0 .103 r
.49681 .78131 m .49625 .7834 L .49791 .78186 L F
.625 .201 .218 r
.49883 .78266 m .49753 .78436 L .49637 .78402 L F
.005 0 .103 r
.49625 .7834 m .49619 .78361 L .49646 .78334 L F
.49625 .7834 m .49646 .78334 L .49646 .78332 L F
.49619 .78361 m .49615 .78376 L .49626 .78365 L F
.625 .201 .218 r
.49883 .78266 m .49637 .78402 L .49646 .78332 L F
.005 0 .103 r
.49646 .78332 m .49646 .78334 L .49649 .78331 L F
.49625 .7834 m .49649 .78331 L .49791 .78186 L F
.49619 .78361 m .49626 .78365 L .49791 .78186 L F
.803 .853 .888 r
.49791 .78186 m .49645 .78345 L .49543 .78306 L F
.49791 .78186 m .49543 .78306 L .4957 .7822 L F
.49645 .78345 m .49615 .78376 L .49581 .78357 L F
.625 .201 .218 r
.49646 .78332 m .49645 .78345 L .49521 .78367 L F
.803 .853 .888 r
.49645 .78345 m .49581 .78357 L .4939 .78247 L F
.49791 .78186 m .4939 .78247 L .49617 .7813 L F
.532 .563 .832 r
.49534 .78334 m .49753 .78436 L .49617 .7813 L F
.316 0 .214 r
.49352 .7843 m .49619 .78361 L .49468 .78324 L F
.08 0 0 r
.49543 .78362 m .49433 .78312 L .49567 .78357 L F
.442 .768 .997 r
.49596 .78366 m .49615 .78376 L .49494 .78364 L F
.08 0 0 r
.49509 .7836 m .49433 .7838 L .49433 .78312 L F
.442 .768 .997 r
.49509 .7836 m .49494 .78364 L .49368 .7835 L F
.49596 .78366 m .49494 .78364 L .49509 .7836 L F
.49358 .78399 m .49615 .78376 L .49352 .7843 L F
.08 0 0 r
.49433 .78395 m .4934 .784 L .49433 .78312 L F
.442 .768 .997 r
.49368 .7835 m .49494 .78364 L .49358 .78399 L F
.49494 .78364 m .49615 .78376 L .49358 .78399 L F
.08 0 0 r
.49433 .78395 m .493 .78439 L .49335 .78405 L F
.49358 .78399 m .49335 .78405 L .4934 .784 L F
.49433 .78395 m .49335 .78405 L .49358 .78399 L F
.49521 .78367 m .49433 .78395 L .49433 .7838 L F
.49521 .78367 m .49433 .7838 L .49509 .7836 L F
.49521 .78367 m .49509 .7836 L .49543 .78362 L F
.49509 .7836 m .49433 .78312 L .49543 .78362 L F
.625 .201 .218 r
.49578 .78357 m .49524 .78368 L .49521 .78367 L F
.49645 .78345 m .49581 .78357 L .49578 .78357 L F
.442 .768 .997 r
.49581 .78357 m .49596 .78366 L .49371 .78336 L F
.625 .201 .218 r
.49581 .78357 m .49524 .78368 L .49578 .78357 L F
.442 .768 .997 r
.49408 .78341 m .49596 .78366 L .49369 .78345 L F
.544 .605 .865 r
.49459 .78336 m .49433 .78395 L .49521 .78367 L F
.49177 .78192 m .49369 .78345 L .49459 .78336 L F
.442 .768 .997 r
.49369 .78345 m .49596 .78366 L .49368 .7835 L F
.544 .605 .865 r
.49369 .78345 m .49433 .78395 L .49459 .78336 L F
.442 .768 .997 r
.49371 .78336 m .49408 .78341 L .49369 .78345 L F
.08 0 0 r
.49567 .78357 m .49468 .78324 L .49584 .78353 L F
.74 .646 .756 r
.49617 .7813 m .4939 .78247 L .49268 .77963 L F
.528 .919 .816 r
.49399 .7823 m .4939 .78247 L .49617 .7813 L F
.544 .605 .865 r
.49177 .78192 m .49368 .78289 L .4939 .78247 L F
.442 .768 .997 r
.49357 .78403 m .49329 .78399 L .49177 .78192 L F
.544 .605 .865 r
.49177 .78192 m .493 .78439 L .49433 .78395 L F
.442 .768 .997 r
.4939 .78247 m .49369 .78345 L .49177 .78192 L F
.045 0 .071 r
.49242 .78301 m .49177 .78192 L .4939 .78247 L F
.528 .919 .816 r
.49242 .78301 m .4939 .78247 L .49399 .7823 L F
.544 .605 .865 r
.49368 .78289 m .49459 .78336 L .4939 .78247 L F
.442 .768 .997 r
.4939 .78247 m .49581 .78357 L .49467 .78346 L F
.544 .605 .865 r
.49459 .78336 m .49521 .78367 L .4939 .78247 L F
.442 .768 .997 r
.4939 .78247 m .49467 .78346 L .49371 .78336 L F
.532 .563 .832 r
.49521 .78367 m .49524 .78368 L .49534 .78334 L F
.625 .201 .218 r
.49645 .78345 m .49637 .78402 L .49524 .78368 L F
.532 .563 .832 r
.49524 .78368 m .49753 .78436 L .49534 .78334 L F
.803 .853 .888 r
.4957 .7822 m .49543 .78306 L .4939 .78247 L F
.639 .543 .73 r
.33624 .70358 m .33821 .7005 L .33574 .70083 L F
.33624 .70358 m .3386 .70372 L .33821 .7005 L F
.608 .524 .734 r
.33624 .70358 m .33957 .70592 L .3386 .70372 L F
.428 .232 .511 r
.30369 .62071 m .30598 .62019 L .30622 .61761 L F
.395 .18 .466 r
.30369 .62071 m .30547 .62224 L .30598 .62019 L F
.30369 .62071 m .30362 .62304 L .30547 .62224 L F
.331 0 0 r
.74071 .70752 m .73941 .70688 L .73886 .70668 L F
.457 .348 .641 r
.34014 .66767 m .34221 .66959 L .34196 .66716 L F
.453 .348 .644 r
.34014 .66767 m .34046 .67012 L .34221 .66959 L F
.438 .251 .528 r
.43997 .75582 m .44184 .75544 L .44197 .75308 L F
.519 .392 .648 r
.43997 .75582 m .4423 .75786 L .44184 .75544 L F
.43997 .75582 m .44025 .75834 L .4423 .75786 L F
.171 0 .24 r
.50742 .75268 m .50508 .75545 L .50589 .75359 L F
.715 .396 .437 r
.57392 .7107 m .57585 .7113 L .57694 .70968 L F
.653 .496 .659 r
.55233 .76106 m .54949 .75852 L .55265 .75852 L F
.576 .314 .482 r
.5549 .76058 m .55265 .75852 L .55503 .75843 L F
.5549 .76058 m .55233 .76106 L .55265 .75852 L F
.689 .573 .72 r
.32607 .70875 m .32784 .71305 L .32972 .71194 L F
.252 0 .103 r
.32784 .71305 m .32848 .71379 L .32972 .71194 L F
.32972 .71194 m .32848 .71379 L .32784 .71305 L F
.416 .087 .297 r
.40972 .703 m .40681 .70498 L .40759 .70323 L F
.19 0 .005 r
.5516 .74016 m .55285 .7409 L .55378 .73944 L F
.5516 .74016 m .5506 .74174 L .55285 .7409 L F
.355 0 0 r
.52334 .7632 m .52686 .76185 L .52452 .76181 L F
.886 .788 .747 r
.6234 .53185 m .62403 .53477 L .62262 .5338 L F
.862 .91 .863 r
.62403 .53477 m .62063 .53639 L .62262 .5338 L F
.522 .252 .447 r
.3736 .67589 m .37314 .67822 L .37081 .67847 L F
.28 .042 .363 r
.37483 .67726 m .3736 .67589 L .37588 .67539 L F
.37483 .67726 m .37314 .67822 L .3736 .67589 L F
.529 .379 .62 r
.59481 .68956 m .59523 .6924 L .59281 .69289 L F
.477 .225 .454 r
.59281 .69289 m .59523 .6924 L .59401 .68983 L F
.59281 .69289 m .59261 .69472 L .59523 .6924 L F
.59523 .6924 m .59261 .69472 L .59281 .69289 L F
.715 .365 .383 r
.57749 .67412 m .57855 .67513 L .57992 .67324 L F
.47 .093 .243 r
.57855 .67513 m .58228 .6729 L .57992 .67324 L F
.114 .667 .742 r
.2534 .58514 m .25314 .58526 L .25154 .58502 L F
.2534 .58514 m .25449 .58507 L .25314 .58526 L F
.616 .831 .982 r
.55742 .73962 m .55378 .73944 L .55586 .73868 L F
.698 .553 .686 r
.55742 .73962 m .55681 .74218 L .55483 .74197 L F
.765 .671 .76 r
.55742 .73962 m .55483 .74197 L .55378 .73944 L F
.481 .346 .62 r
.50101 .72002 m .50338 .71994 L .50358 .71689 L F
.514 .345 .589 r
.50092 .72192 m .50338 .71994 L .50101 .72002 L F
.798 .893 .912 r
.4262 .66847 m .423 .67085 L .42287 .66909 L F
0 0 .433 r
.423 .67085 m .42371 .6726 L .42287 .66909 L F
.196 .451 .875 r
.73258 .62406 m .73431 .62384 L .7317 .62306 L F
.73258 .62406 m .73543 .62542 L .73431 .62384 L F
0 .165 .682 r
.57857 .73707 m .57968 .73914 L .57871 .736 L F
.679 .824 .953 r
.73841 .6258 m .73994 .62683 L .74213 .62627 L F
0 .497 .75 r
.2587 .58654 m .26064 .5869 L .26222 .58729 L F
.237 .726 .924 r
.26064 .5869 m .2642 .58724 L .26222 .58729 L F
.224 0 0 r
.38993 .70007 m .39151 .70022 L .39281 .69842 L F
.135 0 0 r
.39281 .69842 m .39342 .69949 L .3949 .69797 L F
.39281 .69842 m .39151 .70022 L .39342 .69949 L F
.9 .937 .828 r
.5372 .76703 m .5395 .76451 L .53804 .76432 L F
.941 .702 .549 r
.35116 .72637 m .35558 .72543 L .35609 .72568 L F
.495 .497 .787 r
.35635 .72569 m .35772 .72496 L .35558 .72543 L F
.653 .482 .64 r
.35772 .72496 m .35609 .72568 L .35558 .72543 L F
.565 .485 .724 r
.33685 .6926 m .33814 .68902 L .33637 .68967 L F
.784 .334 0 r
.54731 .70588 m .54519 .7028 L .5467 .70333 L F
.551 .319 .516 r
.64041 .54359 m .64049 .54567 L .63816 .54605 L F
.563 .304 .481 r
.64436 .54253 m .64049 .54567 L .64041 .54359 L F
.793 .536 .548 r
.72608 .59307 m .72914 .59312 L .72922 .59516 L F
.657 .321 .393 r
.72914 .59312 m .73163 .59514 L .72922 .59516 L F
.395 .03 .223 r
.51067 .75015 m .50958 .7523 L .50742 .75268 L F
.506 .365 .623 r
.51258 .74766 m .5127 .74998 L .51067 .75015 L F
.579 .277 .42 r
.5127 .74998 m .50958 .7523 L .51067 .75015 L F
.517 .368 .617 r
.33852 .67315 m .34055 .67256 L .34046 .67012 L F
.524 .362 .603 r
.33841 .6756 m .34055 .67256 L .33852 .67315 L F
.689 .321 .345 r
.50229 .79453 m .50579 .7944 L .50457 .79649 L F
.539 .214 .365 r
.50579 .7944 m .50823 .79601 L .50457 .79649 L F
.50579 .7944 m .5079 .79448 L .50823 .79601 L F
.543 .48 .735 r
.33685 .6926 m .3375 .69514 L .3396 .69464 L F
.593 .438 .641 r
.3375 .69514 m .33997 .69761 L .3396 .69464 L F
.3375 .69514 m .33784 .69817 L .33997 .69761 L F
.61 .589 .804 r
.74025 .72246 m .74297 .72449 L .74234 .72222 L F
.751 .745 .847 r
.74234 .72222 m .74297 .72449 L .74557 .72249 L F
.754 .702 .802 r
.72608 .59307 m .72687 .59574 L .72353 .59558 L F
.064 .625 .79 r
.72353 .59558 m .72687 .59574 L .72528 .59552 L F
.793 .536 .548 r
.72608 .59307 m .72922 .59516 L .72687 .59574 L F
.376 .835 .907 r
.72528 .59552 m .72687 .59574 L .72922 .59516 L F
.998 .79 .445 r
.74833 .71564 m .74899 .71439 L .74889 .7138 L F
.74833 .71564 m .74907 .71607 L .74899 .71439 L F
.258 0 0 r
.35212 .65594 m .34909 .65659 L .35119 .65637 L F
.412 0 0 r
.35119 .65637 m .3544 .65593 L .35212 .65594 L F
.984 .9 .644 r
.70504 .59625 m .70404 .59681 L .70315 .59542 L F
.70504 .59625 m .70436 .59854 L .70404 .59681 L F
.329 0 0 r
.46384 .78891 m .46741 .78881 L .46581 .78913 L F
.461 0 0 r
.46741 .78881 m .46916 .79007 L .46581 .78913 L F
.46741 .78881 m .47012 .79024 L .46916 .79007 L F
.79 .312 .092 r
.56812 .73954 m .57008 .74178 L .57148 .74177 L F
0 0 0 r
.57116 .74319 m .57148 .74177 L .57008 .74178 L F
.864 .674 .644 r
.75473 .60343 m .75405 .606 L .75616 .60578 L F
.69 .632 .785 r
.32244 .70787 m .32607 .70875 L .32517 .70777 L F
.525 .419 .677 r
.32607 .70875 m .32808 .70853 L .32751 .70495 L F
.689 .573 .72 r
.32607 .70875 m .32972 .71194 L .32808 .70853 L F
.417 .196 .469 r
.52372 .73117 m .52537 .73303 L .52641 .73107 L F
.911 .877 .447 r
.52641 .73107 m .52537 .73303 L .52621 .73056 L F
.547 .492 .746 r
.4372 .77012 m .43992 .7721 L .43918 .76969 L F
.915 .682 .571 r
.60696 .68594 m .60851 .68419 L .60693 .68361 L F
.60696 .68594 m .60842 .68661 L .60851 .68419 L F
.656 .669 .85 r
.50198 .75482 m .50339 .75694 L .50508 .75545 L F
.499 0 0 r
.40174 .64917 m .4042 .65019 L .40556 .65031 L F
.199 0 0 r
.4042 .65019 m .40763 .6507 L .40556 .65031 L F
.711 .469 .557 r
.55317 .74412 m .54925 .7469 L .54938 .74523 L F
.827 .698 .722 r
.63123 .51874 m .62983 .52113 L .62862 .51789 L F
.74 .608 .711 r
.55681 .74218 m .55515 .74478 L .55483 .74197 L F
.602 .182 .218 r
.47161 .7908 m .47294 .78901 L .47559 .79062 L F
.798 .815 .865 r
.63188 .50421 m .62872 .50408 L .63096 .50149 L F
.63188 .50421 m .62998 .50515 L .62872 .50408 L F
.742 .754 .862 r
.63409 .50188 m .63188 .50421 L .63096 .50149 L F
.599 .063 0 r
.55595 .76206 m .55453 .76285 L .55866 .76325 L F
.555 .727 .955 r
.53256 .74587 m .53508 .74531 L .53103 .74412 L F
.212 .713 .909 r
.37898 .70228 m .38098 .70223 L .38205 .70253 L F
.568 .901 .981 r
.38205 .70253 m .38297 .70144 L .3851 .70163 L F
.38205 .70253 m .38098 .70223 L .38297 .70144 L F
.35 0 .034 r
.3847 .71408 m .38316 .71581 L .38114 .71613 L F
.153 0 0 r
.38503 .71525 m .3847 .71408 L .38686 .7136 L F
.38503 .71525 m .38316 .71581 L .3847 .71408 L F
.251 0 .16 r
.26103 .61137 m .25802 .61427 L .25899 .6124 L F
.295 0 .185 r
.50883 .7215 m .51147 .71942 L .51 .71951 L F
.565 .485 .724 r
.33685 .6926 m .33895 .69219 L .33814 .68902 L F
.543 .48 .735 r
.33685 .6926 m .3396 .69464 L .33895 .69219 L F
.292 0 .089 r
.35731 .65413 m .3544 .65593 L .35657 .65561 L F
.353 .001 .221 r
.35923 .65357 m .35731 .65413 L .35657 .65561 L F
.2 .72 .691 r
.41777 .66393 m .41573 .6645 L .41694 .66418 L F
.536 .473 .732 r
.44423 .66111 m .4451 .6654 L .443 .66555 L F
.387 .092 .338 r
.32647 .62027 m .32902 .61772 L .32848 .61989 L F
.298 .02 .312 r
.32848 .61989 m .32902 .61772 L .33084 .617 L F
.486 .146 .314 r
.43988 .67918 m .43963 .68067 L .43736 .68099 L F
.535 .207 .358 r
.4427 .67825 m .43963 .68067 L .43988 .67918 L F
.832 .912 .51 r
.55701 .68932 m .55584 .69182 L .5565 .69135 L F
.424 .812 .577 r
.55713 .6909 m .5565 .69135 L .5552 .69232 L F
0 0 0 r
.5565 .69135 m .55528 .69301 L .5537 .69369 L F
.832 .912 .51 r
.55584 .69182 m .55528 .69301 L .5565 .69135 L F
.424 .812 .577 r
.55805 .69022 m .5565 .69135 L .55713 .6909 L F
0 0 0 r
.5565 .69135 m .5537 .69369 L .5552 .69232 L F
.355 .039 .285 r
.40788 .68931 m .40912 .69106 L .40969 .68844 L F
.40788 .68931 m .40714 .69169 L .40912 .69106 L F
.213 0 .233 r
.31521 .63686 m .31281 .63938 L .3132 .63716 L F
.914 .813 .733 r
.62936 .50728 m .62781 .50657 L .62872 .50408 L F
.984 .899 .639 r
.62936 .50728 m .62753 .50869 L .62781 .50657 L F
.62936 .50728 m .62815 .51016 L .62753 .50869 L F
.889 .801 .756 r
.62998 .50515 m .62936 .50728 L .62872 .50408 L F
.512 .354 .603 r
.34429 .65939 m .34613 .66127 L .34639 .65891 L F
.34429 .65939 m .34412 .66191 L .34613 .66127 L F
.933 .838 .728 r
.74641 .71875 m .74907 .71607 L .74833 .71564 L F
.74641 .71875 m .7476 .71961 L .74907 .71607 L F
.772 .375 .301 r
.56364 .70463 m .56549 .70732 L .56649 .70524 L F
0 0 0 r
.56649 .70524 m .56731 .70529 L .5687 .7041 L F
.573 .3 .464 r
.56549 .70732 m .56731 .70529 L .56649 .70524 L F
.661 .593 .769 r
.58729 .72022 m .58404 .71711 L .58585 .71872 L F
.408 .681 .973 r
.58585 .71872 m .58827 .71937 L .58729 .72022 L F
.522 .384 .634 r
.58898 .72028 m .58739 .72247 L .58729 .72022 L F
.649 .329 .416 r
.59343 .67008 m .5957 .6721 L .59683 .6695 L F
.775 .524 .557 r
.5957 .6721 m .59905 .67018 L .59683 .6695 L F
.911 .746 .665 r
.62815 .51016 m .62923 .51331 L .6274 .51242 L F
.986 .811 .585 r
.62923 .51331 m .62786 .51446 L .6274 .51242 L F
.62923 .51331 m .62885 .51565 L .62786 .51446 L F
.54 .283 .474 r
.5253 .7392 m .52499 .74128 L .52268 .74138 L F
.428 .136 .364 r
.52757 .73889 m .52499 .74128 L .5253 .7392 L F
.693 .298 .295 r
.62315 .5461 m .62679 .54634 L .62574 .54811 L F
.56 .149 .221 r
.62574 .54811 m .62679 .54634 L .62911 .54758 L F
.835 .998 .828 r
.52621 .73056 m .52611 .73035 L .52898 .72856 L F
.887 .606 .092 r
.52808 .725 m .52898 .72856 L .52799 .72534 L F
.706 .466 .559 r
.52808 .725 m .52805 .72655 L .52564 .72742 L F
.92 .809 .721 r
.52898 .72856 m .52814 .72826 L .52827 .72626 L F
.52814 .72826 m .52704 .72787 L .52805 .72655 L F
.52814 .72826 m .52805 .72655 L .52827 .72626 L F
.706 .466 .559 r
.528 .72661 m .52802 .72819 L .52684 .72813 L F
.842 .674 .135 r
.52799 .72534 m .52805 .72655 L .52808 .725 L F
.706 .466 .559 r
.52805 .72655 m .52684 .72813 L .52409 .72798 L F
.92 .809 .721 r
.52827 .72626 m .52704 .72787 L .52799 .72534 L F
.842 .674 .135 r
.52799 .72534 m .52802 .72819 L .52805 .72655 L F
.686 .528 .666 r
.52799 .72534 m .52704 .72787 L .52802 .72819 L F
.92 .809 .721 r
.52898 .72856 m .52683 .7299 L .52704 .72787 L F
.857 .997 .795 r
.52675 .72985 m .52621 .73056 L .52595 .72998 L F
.52639 .7296 m .52595 .72998 L .52553 .729 L F
.52675 .72985 m .52595 .72998 L .52639 .7296 L F
.52684 .72813 m .52439 .72937 L .52409 .72798 L F
.92 .809 .721 r
.52684 .72978 m .52639 .7296 L .52698 .72804 L F
.52684 .72978 m .52698 .72804 L .52702 .72801 L F
.52702 .72801 m .52698 .72804 L .52704 .72787 L F
.686 .528 .666 r
.52704 .72787 m .52639 .7296 L .52802 .72819 L F
.857 .997 .795 r
.52802 .72819 m .52553 .729 L .52684 .72813 L F
.52553 .729 m .52439 .72937 L .52684 .72813 L F
.92 .809 .721 r
.52683 .7299 m .52675 .72985 L .52684 .72978 L F
.52675 .72985 m .52639 .7296 L .52684 .72978 L F
.857 .997 .795 r
.52675 .72985 m .52611 .73035 L .52621 .73056 L F
.52802 .72819 m .52675 .72985 L .52553 .729 L F
.52802 .72819 m .52611 .73035 L .52675 .72985 L F
.92 .809 .721 r
.52683 .7299 m .52611 .73035 L .52639 .7296 L F
.686 .528 .666 r
.52639 .7296 m .52611 .73035 L .52802 .72819 L F
.857 .997 .795 r
.52553 .729 m .52621 .73056 L .52439 .72937 L F
.706 .466 .559 r
.52509 .72724 m .52564 .72742 L .52409 .72798 L F
.52808 .725 m .52564 .72742 L .52509 .72724 L F
.812 .61 .63 r
.62333 .54338 m .61998 .54525 L .61967 .54341 L F
.62333 .54338 m .62315 .5461 L .61998 .54525 L F
.838 .629 .62 r
.62047 .53888 m .61853 .53962 L .62063 .53639 L F
.62047 .53888 m .62035 .54081 L .61853 .53962 L F
.711 .469 .557 r
.55317 .74412 m .55168 .74752 L .54925 .7469 L F
.719 .478 .56 r
.55476 .7474 m .55317 .74412 L .55515 .74478 L F
.55476 .7474 m .55168 .74752 L .55317 .74412 L F
.767 .526 .569 r
.53103 .74412 m .53508 .74531 L .53449 .74189 L F
.578 .398 .602 r
.53449 .74189 m .53667 .74375 L .53671 .74155 L F
.53449 .74189 m .53508 .74531 L .53667 .74375 L F
0 .056 .596 r
.55759 .72988 m .55826 .73047 L .55826 .73091 L F
.836 .569 .535 r
.61654 .71163 m .61659 .71371 L .61907 .71381 L F
.848 .71 .709 r
.61659 .71371 m .61828 .71511 L .61907 .71381 L F
.76 .617 .701 r
.66116 .52112 m .65809 .51944 L .6606 .51841 L F
.66116 .52112 m .66023 .52189 L .65809 .51944 L F
.763 .622 .704 r
.66116 .52112 m .65942 .52419 L .66023 .52189 L F
.754 .738 .838 r
.66382 .51871 m .66116 .52112 L .6606 .51841 L F
.559 .421 .649 r
.44385 .75027 m .44586 .74623 L .44358 .7476 L F
.902 .935 .564 r
.32848 .71379 m .32806 .71519 L .32972 .71194 L F
.529 .56 .831 r
.32808 .70853 m .32972 .71194 L .33118 .71105 L F
.288 .029 .335 r
.32972 .71194 m .33085 .71312 L .33118 .71105 L F
.32972 .71194 m .32806 .71519 L .33085 .71312 L F
.446 .176 .409 r
.44531 .67578 m .44484 .67779 L .4427 .67825 L F
.446 .138 .348 r
.44758 .67549 m .44484 .67779 L .44531 .67578 L F
.749 .581 .667 r
.54384 .761 m .54494 .76407 L .54141 .76398 L F
.694 .552 .689 r
.54869 .76368 m .54384 .761 L .54872 .76092 L F
.54869 .76368 m .54494 .76407 L .54384 .761 L F
.737 .384 .382 r
.55102 .70024 m .55339 .70292 L .55425 .7005 L F
.291 0 .206 r
.55425 .7005 m .55527 .70209 L .5565 .70053 L F
.55425 .7005 m .55339 .70292 L .55527 .70209 L F
.057 0 0 r
.34909 .65659 m .34639 .65891 L .3484 .65831 L F
.468 .103 .262 r
.3505 .65797 m .34909 .65659 L .3484 .65831 L F
.3505 .65797 m .35119 .65637 L .34909 .65659 L F
.463 .595 .899 r
.75513 .58725 m .75473 .58986 L .75288 .58701 L F
.75513 .58725 m .75652 .58946 L .75473 .58986 L F
0 .379 .696 r
.54782 .72519 m .55027 .72601 L .55124 .72639 L F
.384 0 0 r
.55027 .72601 m .55358 .72721 L .55124 .72639 L F
.505 .711 .963 r
.32781 .59916 m .32452 .59796 L .32637 .59809 L F
.367 .628 .954 r
.32831 .59772 m .32781 .59916 L .32637 .59809 L F
.32831 .59772 m .33045 .59974 L .32781 .59916 L F
.093 .454 .885 r
.33133 .60165 m .32781 .59916 L .33045 .59974 L F
.829 .569 .546 r
.59905 .67018 m .59912 .67247 L .60202 .67282 L F
.868 .602 .534 r
.59912 .67247 m .60174 .67524 L .60202 .67282 L F
.413 .54 .875 r
.33208 .59965 m .33133 .60165 L .33045 .59974 L F
.545 .69 .934 r
.33208 .59965 m .33347 .60139 L .33133 .60165 L F
.626 .739 .928 r
.72618 .62045 m .72963 .62132 L .72852 .61992 L F
.702 .788 .918 r
.73192 .62026 m .72963 .62132 L .72852 .61992 L F
0 .082 .56 r
.72963 .62132 m .73081 .62227 L .72852 .61992 L F
.72963 .62132 m .7317 .62306 L .73081 .62227 L F
.13 .646 .891 r
.58974 .73333 m .59223 .7335 L .59331 .73394 L F
.985 .835 .612 r
.59331 .73394 m .59223 .7335 L .59294 .73082 L F
.659 .668 .847 r
.32244 .70787 m .32301 .70456 L .32145 .70498 L F
.32244 .70787 m .32517 .70777 L .32301 .70456 L F
.997 .846 .567 r
.64111 .51167 m .64238 .51075 L .64159 .50937 L F
.606 .61 .828 r
.73859 .71519 m .74018 .71215 L .73777 .71355 L F
.73859 .71519 m .7409 .71502 L .74018 .71215 L F
.845 .928 .884 r
.59509 .7299 m .59294 .73082 L .59424 .72793 L F
.441 .839 .978 r
.27059 .64379 m .27256 .64332 L .27445 .64382 L F
.536 .88 .987 r
.27445 .64382 m .27444 .64272 L .27613 .6434 L F
.27445 .64382 m .27256 .64332 L .27444 .64272 L F
.749 .685 .79 r
.73633 .61699 m .73741 .61797 L .73404 .61752 L F
.722 .685 .814 r
.73955 .6164 m .73741 .61797 L .73633 .61699 L F
.902 .743 .675 r
.60033 .70319 m .59752 .70526 L .59937 .70269 L F
.60033 .70319 m .59913 .70609 L .59752 .70526 L F
.342 .73 .985 r
.29692 .59369 m .29502 .59379 L .29351 .5929 L F
.468 0 0 r
.71507 .59192 m .71379 .59269 L .7112 .59233 L F
.828 .479 .396 r
.71669 .59282 m .71379 .59269 L .71507 .59192 L F
.379 .753 .991 r
.55447 .70939 m .55196 .70875 L .55345 .70979 L F
.987 .839 .46 r
.57211 .76537 m .57187 .76907 L .57252 .76974 L F
0 0 .284 r
.57187 .76907 m .57129 .77158 L .57252 .76974 L F
.379 0 .144 r
.2691 .60652 m .26766 .60862 L .26558 .60892 L F
.393 .014 .195 r
.27121 .60592 m .26766 .60862 L .2691 .60652 L F
0 .26 .708 r
.5665 .7373 m .56784 .73839 L .56489 .73658 L F
.56627 .73718 m .56489 .73658 L .56374 .73582 L F
.5665 .7373 m .56631 .73721 L .56627 .73718 L F
.56631 .73721 m .56489 .73658 L .56627 .73718 L F
.403 0 0 r
.56504 .73669 m .56612 .73714 L .56374 .73582 L F
.56612 .73714 m .5665 .7373 L .56564 .73684 L F
.56612 .73714 m .56564 .73684 L .56374 .73582 L F
.671 .257 0 r
.56709 .73861 m .56803 .74034 L .56862 .74119 L F
.5662 .73711 m .56688 .73831 L .56709 .73861 L F
.56688 .73831 m .56803 .74034 L .56709 .73861 L F
.56617 .73708 m .56803 .74034 L .5662 .73711 L F
.943 .579 .247 r
.56593 .73664 m .56784 .73839 L .5665 .7373 L F
.954 .714 .537 r
.56504 .73669 m .56593 .73664 L .5665 .7373 L F
.671 .257 0 r
.56593 .73664 m .56862 .74119 L .56784 .73839 L F
0 .092 .641 r
.56777 .73867 m .56803 .74034 L .56626 .73723 L F
.671 .257 0 r
.56593 .73664 m .56617 .73708 L .5662 .73711 L F
0 .092 .641 r
.56673 .73753 m .56626 .73723 L .56593 .73664 L F
.56777 .73867 m .56626 .73723 L .56673 .73753 L F
.785 .285 0 r
.56413 .73567 m .56627 .73744 L .56504 .73669 L F
0 .092 .641 r
.56777 .73867 m .56593 .73664 L .56504 .73669 L F
.785 .285 0 r
.56627 .73744 m .56777 .73867 L .56648 .73773 L F
.56627 .73744 m .56648 .73773 L .56504 .73669 L F
.386 .158 .442 r
.33132 .61503 m .33354 .61227 L .33328 .61443 L F
.397 .141 .405 r
.33084 .617 m .33132 .61503 L .33328 .61443 L F
.298 .766 .942 r
.59264 .75895 m .59563 .75913 L .59453 .75782 L F
.705 .78 .91 r
.59563 .75913 m .59809 .75803 L .59453 .75782 L F
.556 .715 .946 r
.51913 .72551 m .52183 .72524 L .52048 .72396 L F
.614 .909 .629 r
.52048 .72396 m .51885 .7256 L .51913 .72551 L F
0 0 0 r
.59757 .71364 m .59518 .71722 L .59384 .71403 L F
.59757 .71364 m .5964 .71624 L .59518 .71722 L F
.781 .389 .313 r
.59398 .71861 m .59729 .71961 L .59518 .71722 L F
.801 .364 .208 r
.59518 .71722 m .59729 .71961 L .5978 .71909 L F
.781 .389 .313 r
.59398 .71861 m .59518 .71722 L .5964 .71624 L F
.411 .094 .313 r
.29211 .63422 m .29415 .63373 L .2948 .63204 L F
.512 .237 .433 r
.29415 .63373 m .29695 .63143 L .2948 .63204 L F
.85 .674 .664 r
.60113 .70875 m .59863 .70863 L .59913 .70609 L F
.843 .658 .653 r
.60092 .711 m .59863 .70863 L .60113 .70875 L F
.368 .833 .895 r
.27613 .6434 m .27791 .6428 L .27996 .64284 L F
.414 .858 .909 r
.27996 .64284 m .28062 .64219 L .28168 .64179 L F
.27996 .64284 m .27791 .6428 L .28062 .64219 L F
.676 .128 0 r
.56021 .73328 m .56374 .73582 L .56209 .73366 L F
.535 .452 .708 r
.36836 .68355 m .36672 .68587 L .36668 .68398 L F
.328 .003 .254 r
.40969 .68844 m .41247 .68626 L .41026 .68671 L F
.664 .536 .698 r
.58599 .71498 m .58404 .71711 L .58347 .71489 L F
0 0 .505 r
.51586 .76548 m .51902 .76422 L .51746 .76459 L F
.51586 .76548 m .51664 .76685 L .51902 .76422 L F
.487 .256 .489 r
.52105 .7341 m .52338 .7337 L .52372 .73117 L F
.417 .196 .469 r
.52372 .73117 m .52338 .7337 L .52537 .73303 L F
.444 .264 .541 r
.29709 .62879 m .29879 .63075 L .29891 .6283 L F
.29709 .62879 m .29695 .63143 L .29879 .63075 L F
.863 .486 0 r
.42188 .66517 m .42254 .66707 L .42114 .66436 L F
.535 .378 .615 r
.43808 .76192 m .44028 .76164 L .44025 .75834 L F
.555 .433 .668 r
.43839 .76415 m .44028 .76164 L .43808 .76192 L F
.521 .55 .826 r
.44298 .65793 m .44217 .66128 L .44112 .65796 L F
.44298 .65793 m .44423 .66111 L .44217 .66128 L F
.38 .512 .866 r
.44931 .66381 m .44859 .6661 L .44783 .66506 L F
.44931 .66381 m .45087 .66637 L .44859 .6661 L F
.476 .4 .691 r
.58835 .71415 m .59085 .71619 L .59178 .71464 L F
.035 .583 .834 r
.59118 .71337 m .59384 .71403 L .59178 .71464 L F
.52 .403 .66 r
.59085 .71619 m .59118 .71337 L .59178 .71464 L F
.488 .768 .993 r
.43569 .65317 m .43479 .65438 L .43356 .65331 L F
.43569 .65317 m .4368 .65407 L .43479 .65438 L F
.946 .621 .383 r
.53934 .74503 m .53958 .74727 L .54057 .74701 L F
.526 .307 .526 r
.33817 .60682 m .33796 .60904 L .33614 .60902 L F
.588 .579 .81 r
.33901 .60315 m .33817 .60682 L .33751 .60352 L F
.33901 .60315 m .3403 .60631 L .33817 .60682 L F
.594 .366 .54 r
.33817 .60682 m .34036 .60906 L .33796 .60904 L F
.535 .364 .597 r
.3403 .60631 m .34036 .60906 L .33817 .60682 L F
.529 .514 .784 r
.73211 .71134 m .73325 .70809 L .73078 .70856 L F
.73211 .71134 m .73414 .71159 L .73325 .70809 L F
.984 .724 .338 r
.33973 .71127 m .34055 .71392 L .3406 .71179 L F
.33975 .71201 m .34055 .71392 L .33973 .71127 L F
.681 .956 .949 r
.34056 .71053 m .33933 .71102 L .3406 .71179 L F
.989 .807 .568 r
.33995 .71251 m .33953 .71354 L .34055 .71392 L F
.33933 .71102 m .33953 .71354 L .33995 .71251 L F
.576 .428 .643 r
.33882 .71523 m .33887 .71516 L .33953 .71354 L F
.492 .533 .827 r
.34056 .71053 m .34055 .71392 L .33953 .71354 L F
.681 .956 .949 r
.34056 .71053 m .3406 .71179 L .34179 .71023 L F
.34056 .71053 m .34179 .71023 L .34293 .70874 L F
.703 .602 .741 r
.34293 .70874 m .3406 .71179 L .34362 .71165 L F
.566 .248 .389 r
.34055 .71392 m .34362 .71165 L .3406 .71179 L F
.34055 .71392 m .34417 .71466 L .34362 .71165 L F
.492 .533 .827 r
.34056 .71053 m .34417 .71466 L .34055 .71392 L F
.216 .083 .475 r
.34056 .71053 m .33976 .71288 L .3408 .71269 L F
.984 .724 .338 r
.33933 .71102 m .33975 .71201 L .33973 .71127 L F
.761 .651 .74 r
.33933 .71102 m .33953 .71354 L .34056 .71053 L F
.34056 .71053 m .33953 .71354 L .33933 .71102 L F
.619 .057 0 r
.33999 .71067 m .34056 .71053 L .34149 .71155 L F
.262 .004 .321 r
.33781 .7092 m .33731 .71006 L .33998 .70822 L F
.806 .84 .376 r
.33731 .71006 m .33789 .70763 L .33998 .70822 L F
.954 .615 .326 r
.33789 .70763 m .33933 .71102 L .33848 .70979 L F
.33789 .70763 m .33933 .71102 L .33848 .70979 L F
.619 .057 0 r
.33848 .70979 m .34056 .71053 L .33999 .71067 L F
.576 .428 .643 r
.33887 .71516 m .3408 .71269 L .33953 .71354 L F
.216 .083 .475 r
.33976 .71288 m .33953 .71354 L .33977 .71338 L F
.33976 .71288 m .33977 .71338 L .3408 .71269 L F
.295 .757 .949 r
.70436 .59854 m .70551 .59797 L .70404 .59681 L F
.70583 .59845 m .70687 .59839 L .70551 .59797 L F
.658 .912 .979 r
.70551 .59797 m .70931 .60012 L .70674 .59927 L F
0 0 .524 r
.70525 .59759 m .70551 .59797 L .70674 .59927 L F
.70439 .59663 m .70551 .59797 L .70525 .59759 L F
.295 .757 .949 r
.70436 .59854 m .70583 .59845 L .70551 .59797 L F
.988 .72 .368 r
.46691 .76373 m .46791 .7672 L .4668 .76521 L F
.812 .595 .608 r
.61075 .69767 m .61068 .7002 L .61395 .70053 L F
.875 .549 .431 r
.61068 .7002 m .61379 .70309 L .61395 .70053 L F
.39 .44 .792 r
.72722 .71953 m .72856 .72291 L .73015 .72128 L F
.451 .537 .854 r
.72856 .72291 m .73104 .72332 L .73015 .72128 L F
.32 .8 .901 r
.28229 .65419 m .28069 .65409 L .27892 .65444 L F
.208 .724 .877 r
.28439 .65416 m .28069 .65409 L .28229 .65419 L F
.648 .251 .279 r
.5079 .79448 m .51143 .79426 L .51019 .79622 L F
.59 .169 .211 r
.51143 .79426 m .51277 .79645 L .51019 .79622 L F
.51143 .79426 m .51402 .79498 L .51277 .79645 L F
.513 .223 .41 r
.43263 .68377 m .43187 .68614 L .4297 .68647 L F
.587 .34 .508 r
.43554 .68351 m .43187 .68614 L .43263 .68377 L F
.887 .718 .666 r
.57917 .71379 m .58045 .7171 L .58087 .71471 L F
.73 .56 .662 r
.58087 .71471 m .58045 .7171 L .58404 .71711 L F
.679 .824 .953 r
.73841 .6258 m .74213 .62627 L .74112 .6256 L F
.542 .849 .54 r
.74344 .62486 m .74213 .62627 L .74464 .62375 L F
.59 .885 .992 r
.74112 .6256 m .74213 .62627 L .74344 .62486 L F
.614 .259 .344 r
.47323 .74082 m .47548 .74116 L .47346 .73941 L F
.558 .278 .446 r
.47346 .73941 m .47548 .74116 L .47578 .73921 L F
.075 0 0 r
.50644 .75885 m .50712 .75929 L .50903 .75857 L F
.50903 .75857 m .50713 .7593 L .50644 .75885 L F
.317 .033 .313 r
.50911 .75646 m .5071 .7593 L .50623 .75688 L F
.5071 .7593 m .50675 .75979 L .50668 .75938 L F
.5071 .7593 m .50668 .75938 L .50623 .75688 L F
.075 0 0 r
.50712 .75929 m .50713 .7593 L .50715 .75929 L F
.50712 .75929 m .50715 .75929 L .50903 .75857 L F
.225 .742 .853 r
.71336 .60624 m .71133 .6063 L .7141 .60536 L F
.732 .322 .273 r
.71336 .60624 m .7137 .6085 L .71133 .6063 L F
.372 .564 .91 r
.71582 .60545 m .71336 .60624 L .7141 .60536 L F
.732 .644 .761 r
.71582 .60545 m .7137 .6085 L .71336 .60624 L F
.178 .713 .804 r
.36333 .72468 m .36012 .72496 L .36128 .72486 L F
.437 .22 .485 r
.33614 .60902 m .33554 .61172 L .33354 .61227 L F
.451 .254 .52 r
.33354 .61227 m .3353 .61384 L .33328 .61443 L F
.33354 .61227 m .33554 .61172 L .3353 .61384 L F
.326 0 0 r
.73477 .59281 m .73622 .59375 L .73402 .59463 L F
.73477 .59281 m .73718 .59265 L .73622 .59375 L F
.669 .674 .846 r
.6524 .51855 m .64899 .51758 L .65178 .51673 L F
.783 .756 .829 r
.65455 .51614 m .6524 .51855 L .65178 .51673 L F
.557 .349 .554 r
.44197 .75308 m .44408 .75507 L .44418 .75278 L F
.44197 .75308 m .44184 .75544 L .44408 .75507 L F
.89 .624 .529 r
.60423 .68269 m .6069 .68132 L .60374 .68072 L F
.60423 .68269 m .60693 .68361 L .6069 .68132 L F
.469 .426 .727 r
.75522 .59792 m .75382 .60158 L .75324 .59825 L F
.75522 .59792 m .75635 .60053 L .75382 .60158 L F
.14 .241 .708 r
.75594 .60277 m .75382 .60158 L .75635 .60053 L F
.75594 .60277 m .75473 .60343 L .75382 .60158 L F
.094 0 0 r
.39377 .71136 m .39254 .71123 L .39452 .7107 L F
.39377 .71136 m .39084 .71243 L .39254 .71123 L F
.806 .98 .697 r
.55869 .6885 m .55805 .69022 L .55917 .68843 L F
.55869 .6885 m .5565 .69135 L .55805 .69022 L F
.502 .354 .612 r
.75597 .61146 m .75637 .61437 L .7537 .61503 L F
.474 .283 .54 r
.75637 .61437 m .75362 .61665 L .7537 .61503 L F
.376 .366 .721 r
.34362 .71165 m .34451 .70851 L .34293 .70874 L F
.34362 .71165 m .34541 .71124 L .34451 .70851 L F
.08 0 .384 r
.34362 .71165 m .34487 .71323 L .34541 .71124 L F
.34362 .71165 m .34417 .71466 L .34487 .71323 L F
.343 0 0 r
.45831 .78772 m .46161 .78833 L .46042 .78802 L F
0 .483 .774 r
.46161 .78833 m .46238 .7884 L .46042 .78802 L F
.46161 .78833 m .46384 .78891 L .46238 .7884 L F
.676 .637 .804 r
.71689 .59028 m .7131 .5879 L .71687 .58922 L F
.875 .761 .733 r
.71687 .58922 m .71957 .58797 L .71689 .59028 L F
.6 .491 .701 r
.71957 .58797 m .71923 .58975 L .71689 .59028 L F
.484 .475 .771 r
.71941 .59149 m .71689 .59028 L .71923 .58975 L F
.347 .052 .315 r
.38063 .67004 m .38001 .67232 L .37795 .67272 L F
.385 .086 .33 r
.38204 .67176 m .38063 .67004 L .38275 .6694 L F
.38204 .67176 m .38001 .67232 L .38063 .67004 L F
.214 .711 .915 r
.2642 .58724 m .26633 .5872 L .26778 .58762 L F
.303 .73 .972 r
.26822 .58686 m .26778 .58762 L .26633 .5872 L F
.26822 .58686 m .26974 .58755 L .26778 .58762 L F
.745 .505 .567 r
.55827 .74732 m .55476 .7474 L .55515 .74478 L F
0 0 0 r
.34252 .71701 m .34221 .71705 L .34399 .71662 L F
.34252 .71701 m .34131 .71878 L .34221 .71705 L F
.386 0 .166 r
.55496 .68552 m .55824 .68319 L .55659 .68482 L F
.503 .254 .47 r
.42705 .69119 m .4252 .68956 L .4274 .68923 L F
.42705 .69119 m .42488 .69162 L .4252 .68956 L F
.771 .571 .628 r
.51067 .73918 m .51419 .74183 L .51298 .73886 L F
.51067 .73918 m .51081 .74214 L .51419 .74183 L F
.428 0 0 r
.51285 .74195 m .51336 .74243 L .51419 .74183 L F
.51081 .74214 m .51321 .74241 L .51285 .74195 L F
.51321 .74241 m .51336 .74243 L .51285 .74195 L F
0 0 .357 r
.51413 .73999 m .51329 .74251 L .51298 .73886 L F
.51329 .74251 m .51323 .74268 L .51321 .74241 L F
.51329 .74251 m .51321 .74241 L .51298 .73886 L F
.597 .401 .586 r
.51298 .73886 m .51321 .74241 L .51081 .74214 L F
.51321 .74241 m .51323 .74268 L .51081 .74214 L F
.322 0 0 r
.51323 .74268 m .51291 .74275 L .51081 .74214 L F
.428 0 0 r
.51081 .74214 m .51291 .74275 L .51336 .74243 L F
0 0 0 r
.74621 .62255 m .74464 .62375 L .74634 .62244 L F
.74621 .62255 m .74344 .62486 L .74464 .62375 L F
.854 .994 .748 r
.74742 .61122 m .74858 .60878 L .74847 .60979 L F
.74742 .61122 m .74661 .61138 L .74858 .60878 L F
.668 .633 .806 r
.53508 .74531 m .53552 .74848 L .53938 .74654 L F
.696 .265 .221 r
.53765 .74917 m .53671 .7503 L .53552 .74848 L F
.679 .261 .246 r
.53552 .74848 m .53671 .7503 L .539 .74974 L F
.647 .103 0 r
.4797 .78252 m .48302 .78354 L .48166 .78147 L F
.4797 .78252 m .48099 .78318 L .48302 .78354 L F
.852 .488 .361 r
.48302 .78354 m .48099 .78318 L .48173 .78522 L F
.455 0 0 r
.48372 .78414 m .48302 .78354 L .48173 .78522 L F
.679 .672 .837 r
.63808 .5038 m .63409 .50188 L .63646 .50104 L F
.397 .503 .849 r
.63839 .5007 m .63808 .5038 L .63646 .50104 L F
.63839 .5007 m .63981 .50385 L .63808 .5038 L F
.806 .745 .223 r
.59481 .68956 m .59523 .68601 L .59526 .68662 L F
.59481 .68956 m .59478 .68886 L .59523 .68601 L F
.283 .5 .89 r
.59401 .68983 m .59478 .68886 L .59481 .68956 L F
.373 .149 .44 r
.59661 .68983 m .59523 .6924 L .59481 .68956 L F
0 .35 .736 r
.53456 .71823 m .53736 .71965 L .53562 .71899 L F
0 0 0 r
.5497 .69342 m .55102 .68911 L .54843 .68931 L F
.915 .534 .277 r
.55256 .69445 m .55018 .69203 L .5497 .69342 L F
.923 .532 .217 r
.55018 .69203 m .5508 .69375 L .54991 .69315 L F
0 0 0 r
.55015 .69196 m .55018 .69203 L .55042 .69106 L F
.5497 .69342 m .55018 .69203 L .55015 .69196 L F
.923 .532 .217 r
.55018 .69203 m .55013 .69223 L .54947 .69285 L F
.55013 .69223 m .54991 .69315 L .54947 .69285 L F
.955 .944 .638 r
.54947 .69285 m .54818 .69606 L .54811 .69398 L F
0 0 0 r
.54947 .69285 m .54811 .69398 L .54869 .69358 L F
.915 .534 .277 r
.55256 .69445 m .5508 .69375 L .55018 .69203 L F
.87 .908 .499 r
.54842 .69638 m .54947 .69285 L .5508 .69375 L F
.54842 .69638 m .54818 .69606 L .54947 .69285 L F
0 0 0 r
.54947 .69285 m .54869 .69358 L .55089 .69204 L F
.55022 .69212 m .55018 .69203 L .54947 .69285 L F
.55202 .69041 m .55018 .69203 L .55022 .69212 L F
.55042 .69106 m .55018 .69203 L .55102 .68911 L F
.514 .526 .806 r
.3457 .72196 m .34681 .72521 L .34873 .72481 L F
.515 .291 .513 r
.33763 .61123 m .33614 .60902 L .33796 .60904 L F
.33763 .61123 m .33554 .61172 L .33614 .60902 L F
.535 .671 .925 r
.42128 .6516 m .42022 .65348 L .419 .65201 L F
.42128 .6516 m .42234 .65325 L .42022 .65348 L F
.249 0 0 r
.29819 .65077 m .29708 .65191 L .29531 .65225 L F
.018 0 0 r
.30012 .65025 m .29708 .65191 L .29819 .65077 L F
.507 .045 .091 r
.2772 .60444 m .2756 .60589 L .27331 .60569 L F
.225 0 0 r
.2792 .60404 m .2756 .60589 L .2772 .60444 L F
.231 0 0 r
.71283 .58893 m .7131 .5879 L .71023 .58864 L F
.568 .897 .645 r
.54172 .69766 m .54278 .6965 L .54376 .69595 L F
.643 .092 0 r
.54278 .6965 m .54457 .69698 L .54376 .69595 L F
.636 .09 0 r
.54376 .69595 m .54457 .69698 L .54741 .69763 L F
.527 .336 .564 r
.50727 .73652 m .50949 .73608 L .50911 .73389 L F
0 .119 .638 r
.57448 .75028 m .57409 .75304 L .57333 .74972 L F
.936 .731 .254 r
.57365 .75437 m .57409 .75304 L .57448 .75028 L F
.57365 .75437 m .57408 .75544 L .57409 .75304 L F
.516 .364 .613 r
.48138 .7526 m .48114 .7556 L .4792 .75321 L F
.48138 .7526 m .48114 .7556 L .4792 .75321 L F
.322 .722 .98 r
.30834 .59447 m .31178 .59529 L .30976 .59529 L F
.672 .32 .368 r
.58045 .7171 m .58266 .71913 L .58404 .71711 L F
.651 .295 .355 r
.58404 .71711 m .58266 .71913 L .58585 .71872 L F
.779 .563 .607 r
.56995 .75857 m .56636 .76041 L .56637 .75856 L F
.56995 .75857 m .56999 .76091 L .56636 .76041 L F
.314 .413 .804 r
.45866 .7719 m .45844 .77472 L .45758 .77135 L F
.45866 .7719 m .4599 .77485 L .45844 .77472 L F
0 0 0 r
.52105 .7341 m .52145 .73467 L .52338 .7337 L F
.52104 .73411 m .51989 .73546 L .52145 .73467 L F
.12 0 0 r
.51947 .73525 m .52145 .73467 L .51989 .73546 L F
.51947 .73525 m .5216 .73486 L .52145 .73467 L F
.5216 .73486 m .52176 .73483 L .52145 .73467 L F
0 0 0 r
.52105 .7341 m .52104 .73411 L .52145 .73467 L F
.621 .072 0 r
.6304 .52464 m .63331 .52612 L .63099 .52504 L F
.484 .718 .974 r
.75092 .58685 m .74714 .58551 L .75031 .58551 L F
.366 .61 .943 r
.75288 .58701 m .75092 .58685 L .75031 .58551 L F
.87 .885 .843 r
.30597 .75538 m .30755 .75607 L .30992 .75323 L F
.601 .628 .85 r
.73208 .72569 m .73382 .72292 L .73104 .72332 L F
.73208 .72569 m .73448 .72521 L .73382 .72292 L F
0 0 0 r
.5978 .71909 m .5994 .7186 L .60098 .71733 L F
.768 .702 .789 r
.42909 .6634 m .428 .66484 L .42545 .66383 L F
.428 .66484 m .4271 .66602 L .42604 .66461 L F
.228 0 0 r
.42834 .66468 m .42785 .66481 L .42475 .66427 L F
.42785 .66481 m .42782 .66482 L .42601 .66449 L F
.42785 .66481 m .42601 .66449 L .42475 .66427 L F
.673 .483 .621 r
.42834 .66468 m .42845 .66769 L .43083 .66683 L F
.229 0 0 r
.42845 .66769 m .43095 .66725 L .43083 .66683 L F
.47 0 0 r
.4271 .66602 m .43095 .66725 L .42845 .66769 L F
.42874 .66654 m .42919 .66688 L .43095 .66725 L F
.4271 .66602 m .42919 .66688 L .42874 .66654 L F
.627 .654 .857 r
.42901 .66753 m .42958 .66717 L .42919 .66688 L F
.673 .483 .621 r
.42834 .66468 m .43083 .66683 L .43056 .66424 L F
.049 .09 .584 r
.43056 .66424 m .43083 .66683 L .43146 .66574 L F
0 0 .077 r
.43083 .66683 m .43095 .66725 L .43146 .66574 L F
.837 .768 .785 r
.43095 .66725 m .42919 .66688 L .43146 .66574 L F
.627 .654 .857 r
.42958 .66717 m .43101 .66627 L .42919 .66688 L F
.577 .429 .643 r
.428 .66484 m .42919 .66688 L .4271 .66602 L F
.691 .939 .646 r
.42909 .6634 m .42834 .66468 L .43056 .66424 L F
.42909 .6634 m .4278 .66482 L .42834 .66468 L F
.577 .429 .643 r
.42909 .6634 m .42914 .66503 L .428 .66484 L F
.42914 .66503 m .42919 .66688 L .428 .66484 L F
.228 0 0 r
.42782 .66482 m .42769 .6648 L .42475 .66427 L F
.188 .618 .945 r
.42475 .66427 m .42769 .6648 L .42545 .66383 L F
.768 .702 .789 r
.428 .66484 m .42769 .6648 L .42545 .66383 L F
.228 0 0 r
.42782 .66482 m .4278 .66482 L .42769 .6648 L F
.188 .618 .945 r
.42769 .6648 m .4278 .66482 L .42545 .66383 L F
.768 .702 .789 r
.42769 .6648 m .42604 .66461 L .42545 .66383 L F
.59 .116 .097 r
.54141 .76398 m .54494 .76407 L .5438 .76536 L F
.44 0 .002 r
.5438 .76536 m .54494 .76407 L .54869 .76368 L F
.534 .786 .99 r
.41184 .65004 m .41106 .65148 L .40977 .6505 L F
.41184 .65004 m .41309 .65105 L .41106 .65148 L F
.091 0 0 r
.57626 .67444 m .57749 .67412 L .57438 .67456 L F
.321 0 .022 r
.57294 .67629 m .57626 .67444 L .57438 .67456 L F
.539 .321 .532 r
.55844 .69578 m .56087 .69696 L .56169 .69506 L F
.535 .207 .358 r
.4427 .67825 m .44192 .68048 L .43963 .68067 L F
.548 .27 .446 r
.44484 .67779 m .44192 .68048 L .4427 .67825 L F
.065 .59 .871 r
.36961 .86293 m .37124 .86358 L .36858 .86287 L F
.36961 .86293 m .37124 .86358 L .36858 .86287 L F
.492 .838 .997 r
.36961 .86293 m .37124 .86358 L .37313 .86307 L F
.36961 .86293 m .37124 .86358 L .37313 .86307 L F
.591 .495 .714 r
.33702 .68117 m .33923 .68083 L .33874 .67841 L F
.53 .423 .677 r
.33702 .68117 m .33947 .68307 L .33923 .68083 L F
.33702 .68117 m .33747 .68375 L .33947 .68307 L F
.595 .341 .502 r
.65372 .53743 m .65392 .5395 L .65065 .54023 L F
.587 .341 .512 r
.65607 .5373 m .65392 .5395 L .65372 .53743 L F
.466 .104 .266 r
.48082 .73801 m .48363 .73635 L .48146 .73675 L F
0 0 0 r
.28789 .6536 m .28648 .65383 L .28439 .65416 L F
.28996 .6532 m .28648 .65383 L .28789 .6536 L F
.553 .249 .405 r
.45988 .74707 m .46221 .74684 L .46314 .74442 L F
.531 .198 .348 r
.46221 .74684 m .46548 .74452 L .46314 .74442 L F
.446 .35 .653 r
.75492 .59453 m .75522 .59792 L .75324 .59825 L F
0 .098 .652 r
.57038 .72265 m .5703 .72193 L .5687 .71994 L F
.497 0 0 r
.57038 .72265 m .57245 .7247 L .57159 .72385 L F
.57038 .72265 m .57159 .72385 L .5703 .72193 L F
.763 .542 .597 r
.63526 .51802 m .63765 .51821 L .63542 .52073 L F
.441 .138 .355 r
.41999 .69504 m .41731 .69727 L .41783 .69546 L F
.653 .131 0 r
.5056 .73658 m .50727 .73652 L .50436 .73583 L F
.492 .01 .039 r
.5056 .73658 m .50949 .73608 L .50727 .73652 L F
.693 .963 .941 r
.26535 .64504 m .26685 .64376 L .26801 .64403 L F
.477 .88 .952 r
.26801 .64403 m .26897 .64311 L .27059 .64379 L F
.26801 .64403 m .26685 .64376 L .26897 .64311 L F
.463 .172 .386 r
.42271 .69209 m .42211 .69466 L .41999 .69504 L F
.449 .16 .381 r
.42413 .69418 m .42271 .69209 L .42488 .69162 L F
.42413 .69418 m .42211 .69466 L .42271 .69209 L F
.244 .758 .84 r
.30601 .7365 m .30501 .73644 L .30253 .73688 L F
.30253 .73688 m .30501 .73644 L .30601 .7365 L F
.69 .978 .897 r
.30653 .73529 m .30501 .73644 L .30601 .7365 L F
.30601 .7365 m .30501 .73644 L .30653 .73529 L F
.549 .305 .497 r
.64049 .54567 m .63806 .54804 L .63816 .54605 L F
.171 0 0 r
.40347 .70722 m .40287 .70619 L .40512 .70588 L F
.40347 .70722 m .40143 .70786 L .40287 .70619 L F
.305 .038 .334 r
.75341 .61871 m .75158 .61764 L .75362 .61665 L F
.75341 .61871 m .7513 .61975 L .75158 .61764 L F
.588 .357 .533 r
.51038 .70867 m .51223 .71059 L .51255 .70903 L F
.51038 .70867 m .50987 .71125 L .51223 .71059 L F
.265 .018 .34 r
.30622 .61761 m .30768 .61712 L .30825 .61517 L F
.282 .112 .465 r
.30622 .61761 m .3074 .61934 L .30768 .61712 L F
.30622 .61761 m .30598 .62019 L .3074 .61934 L F
.799 .657 .706 r
.53667 .74375 m .54015 .74203 L .53671 .74155 L F
.53667 .74375 m .53934 .74503 L .54015 .74203 L F
.37 0 .076 r
.36429 .65238 m .36644 .65207 L .36501 .65139 L F
.361 0 .12 r
.36501 .65139 m .36644 .65207 L .36714 .65099 L F
.316 .603 .949 r
.51549 .79147 m .51648 .79208 L .51579 .79151 L F
.605 .743 .942 r
.51579 .79151 m .51648 .79208 L .51333 .79033 L F
.647 .636 .826 r
.51805 .79496 m .51579 .79151 L .51592 .79372 L F
.512 .741 .978 r
.51807 .79098 m .5195 .79184 L .51549 .79147 L F
.647 .636 .826 r
.51805 .79496 m .51807 .79098 L .51579 .79151 L F
.51805 .79496 m .51948 .79496 L .51807 .79098 L F
.538 .048 0 r
.51845 .79546 m .51954 .7966 L .51805 .79496 L F
.622 .318 .434 r
.51805 .79496 m .51954 .7966 L .51948 .79496 L F
.24 .305 .73 r
.59047 .7588 m .59121 .75743 L .58938 .75555 L F
.543 .687 .933 r
.59047 .7588 m .59264 .75895 L .59121 .75743 L F
.108 .244 .723 r
.73464 .71834 m .73281 .71848 L .73172 .71695 L F
.73464 .71834 m .73492 .71996 L .73281 .71848 L F
.612 .949 .927 r
.33745 .72264 m .33458 .7233 L .33375 .72378 L F
.904 .745 .674 r
.60966 .69453 m .61075 .69767 L .61119 .69529 L F
.611 .309 .433 r
.52268 .74138 m .52197 .74391 L .51967 .74218 L F
.536 .237 .407 r
.52452 .74345 m .52268 .74138 L .52499 .74128 L F
.52452 .74345 m .52197 .74391 L .52268 .74138 L F
.618 .64 .85 r
.49966 .75507 m .5014 .75386 L .49865 .75407 L F
.49966 .75507 m .50198 .75482 L .5014 .75386 L F
.615 .433 .612 r
.59244 .71993 m .58898 .72028 L .59339 .71988 L F
.758 .991 .883 r
.59398 .71861 m .59244 .71993 L .59339 .71988 L F
0 0 .532 r
.59382 .72178 m .59398 .71861 L .59339 .71988 L F
.359 0 .104 r
.39695 .69744 m .39913 .69707 L .40048 .69513 L F
.301 0 .07 r
.40048 .69513 m .40127 .69651 L .40222 .6942 L F
.40048 .69513 m .39913 .69707 L .40127 .69651 L F
.394 0 .157 r
.74367 .58485 m .7414 .5851 L .74126 .58663 L F
.131 0 0 r
.56366 .68097 m .56561 .68066 L .56692 .6792 L F
.69 .438 .536 r
.56561 .68066 m .56876 .67815 L .56692 .6792 L F
.562 .888 .988 r
.30088 .60763 m .30192 .60639 L .29888 .60637 L F
.30088 .60763 m .30311 .60692 L .30192 .60639 L F
.533 .463 .723 r
.45419 .66685 m .45473 .6691 L .45256 .66939 L F
.548 .429 .669 r
.45473 .6718 m .45256 .66939 L .45473 .6691 L F
.45473 .6718 m .45284 .67264 L .45256 .66939 L F
.881 .842 .802 r
.70564 .58971 m .70214 .59212 L .70403 .59046 L F
.70564 .58971 m .70341 .59297 L .70214 .59212 L F
.033 .603 .743 r
.70403 .59046 m .70845 .59049 L .70564 .58971 L F
0 .337 .752 r
.55723 .7109 m .55748 .71078 L .55447 .70939 L F
.55723 .7109 m .5587 .71167 L .55748 .71078 L F
.787 .946 .927 r
.56843 .68249 m .568 .68411 L .5692 .68247 L F
.971 .752 .55 r
.56632 .68532 m .568 .68411 L .56843 .68249 L F
.56632 .68532 m .5676 .68631 L .568 .68411 L F
.519 .455 .724 r
.33821 .7005 m .3386 .70372 L .34081 .70277 L F
.454 .383 .688 r
.33957 .70592 m .34081 .70277 L .3386 .70372 L F
.789 .4 .317 r
.54451 .73984 m .54317 .73798 L .54241 .73975 L F
.491 .348 .613 r
.34046 .67012 m .34249 .67202 L .34221 .66959 L F
.34046 .67012 m .34055 .67256 L .34249 .67202 L F
0 0 0 r
.37181 .72028 m .3714 .72005 L .37337 .71925 L F
.37181 .72028 m .36968 .72115 L .3714 .72005 L F
.522 .368 .613 r
.44025 .75834 m .44242 .76054 L .4423 .75786 L F
.44025 .75834 m .44028 .76164 L .44242 .76054 L F
.671 .221 .174 r
.47874 .79104 m .48195 .79136 L .48081 .79261 L F
.476 .013 .073 r
.48195 .79136 m .48294 .793 L .48081 .79261 L F
.48195 .79136 m .48419 .79145 L .48294 .793 L F
.495 .025 .067 r
.5493 .75191 m .55235 .75153 L .55053 .75056 L F
.489 .049 .129 r
.55053 .75056 m .55235 .75153 L .55311 .75057 L F
.642 .243 .273 r
.59007 .67028 m .59227 .6719 L .59343 .67008 L F
.693 .302 .303 r
.59343 .67008 m .59227 .6719 L .5957 .6721 L F
.593 .586 .814 r
.39022 .64714 m .38746 .64769 L .38716 .6463 L F
.39022 .64714 m .38911 .64798 L .38746 .64769 L F
.121 .38 .837 r
.33812 .60136 m .33686 .60177 L .33555 .60124 L F
.33812 .60136 m .33901 .60315 L .33686 .60177 L F
.401 .394 .737 r
.33901 .60315 m .33751 .60352 L .33686 .60177 L F
.751 .651 .75 r
.42475 .66427 m .4262 .66847 L .42254 .66707 L F
.798 .893 .912 r
.4262 .66847 m .42287 .66909 L .42254 .66707 L F
.376 .427 .787 r
.4271 .66602 m .4262 .66847 L .42475 .66427 L F
.657 .74 .912 r
.4271 .66602 m .42845 .66769 L .4262 .66847 L F
.751 .719 .822 r
.53561 .76586 m .53384 .76692 L .5372 .76703 L F
.9 .937 .828 r
.5372 .76703 m .53804 .76432 L .53561 .76586 L F
.593 .464 .673 r
.42232 .678 m .42417 .6749 L .42215 .67577 L F
.377 0 .001 r
.38645 .70156 m .38855 .70146 L .38993 .70007 L F
.07 0 0 r
.38855 .70146 m .39151 .70022 L .38993 .70007 L F
0 0 .505 r
.51586 .76548 m .51655 .76639 L .51664 .76685 L F
.332 0 0 r
.28259 .60349 m .28087 .60449 L .2792 .60404 L F
.373 0 0 r
.28474 .60301 m .28087 .60449 L .28259 .60349 L F
.87 .885 .843 r
.30597 .75538 m .30992 .75323 L .30769 .75223 L F
.735 .655 .77 r
.62862 .51789 m .62983 .52113 L .62644 .52072 L F
.602 .551 .769 r
.62988 .5234 m .62644 .52072 L .62983 .52113 L F
.627 .164 .135 r
.48419 .79145 m .48766 .79158 L .48628 .79296 L F
.598 .13 .114 r
.48628 .79296 m .48766 .79158 L .49042 .79319 L F
.507 .314 .553 r
.74925 .6038 m .74867 .60602 L .75103 .60577 L F
.74925 .6038 m .75103 .60577 L .75099 .60573 L F
.136 .222 .69 r
.74925 .6038 m .75099 .60573 L .74952 .60078 L F
.828 .563 .013 r
.60098 .71733 m .60069 .71684 L .60015 .71368 L F
.88 .981 .692 r
.5994 .7186 m .60069 .71684 L .60098 .71733 L F
.052 .554 .883 r
.46249 .7766 m .46149 .77678 L .4599 .77485 L F
0 0 0 r
.54504 .73672 m .54606 .73634 L .54711 .73637 L F
.713 .583 .708 r
.63765 .51821 m .64372 .51894 L .63981 .51552 L F
.67 .348 .42 r
.63789 .52033 m .64372 .51894 L .63765 .51821 L F
.63789 .52033 m .64136 .52048 L .64372 .51894 L F
.181 0 0 r
.64372 .51894 m .6428 .51985 L .64333 .51811 L F
.446 .159 .383 r
.6428 .51985 m .6448 .51828 L .64333 .51811 L F
.6448 .51828 m .64566 .51762 L .64333 .51811 L F
.434 .548 .872 r
.63981 .51552 m .64268 .51803 L .64333 .51811 L F
.64268 .51803 m .64372 .51894 L .64333 .51811 L F
.181 0 0 r
.64372 .51894 m .64136 .52048 L .6428 .51985 L F
.775 .524 .557 r
.5957 .6721 m .59912 .67247 L .59905 .67018 L F
.775 .705 .785 r
.32301 .70456 m .32517 .70777 L .32751 .70495 L F
.544 .518 .776 r
.47126 .76066 m .47 .76368 L .47191 .76113 L F
.47126 .76066 m .47195 .76355 L .47 .76368 L F
.586 .398 .593 r
.47254 .76616 m .47 .76368 L .47195 .76355 L F
.47254 .76616 m .47003 .76661 L .47 .76368 L F
.678 .537 .686 r
.51067 .73918 m .51298 .73886 L .51289 .73639 L F
.597 .401 .586 r
.51298 .73886 m .51081 .74214 L .51067 .73918 L F
.678 .537 .686 r
.51067 .73918 m .51298 .73886 L .51289 .73639 L F
.541 .288 .48 r
.4171 .68342 m .41971 .68098 L .41754 .68147 L F
.788 .673 .737 r
.61853 .53962 m .61967 .54341 L .61645 .54285 L F
.779 .45 .431 r
.61967 .54341 m .61673 .54474 L .61645 .54285 L F
.61967 .54341 m .61998 .54525 L .61673 .54474 L F
.785 .671 .738 r
.62035 .54081 m .61967 .54341 L .61853 .53962 L F
.741 .306 0 r
.49177 .78192 m .4912 .78032 L .4896 .77985 L F
.822 .743 .777 r
.74415 .72122 m .7476 .71961 L .74641 .71875 L F
.74415 .72122 m .74557 .72249 L .7476 .71961 L F
.774 .562 .613 r
.6132 .7111 m .61659 .71371 L .61654 .71163 L F
.44 0 .002 r
.5438 .76536 m .54869 .76368 L .54603 .76582 L F
.669 .461 .594 r
.55233 .76106 m .54991 .76226 L .54914 .76149 L F
.427 .383 .707 r
.54991 .76226 m .54872 .76092 L .54914 .76149 L F
.54991 .76226 m .54869 .76368 L .54872 .76092 L F
.668 .407 .516 r
.54991 .76226 m .54603 .76582 L .54869 .76368 L F
.595 .524 .745 r
.33747 .68375 m .33815 .68671 L .34038 .68627 L F
.606 .462 .659 r
.33814 .68902 m .34038 .68627 L .33815 .68671 L F
.564 .073 .047 r
.54144 .73466 m .54335 .73567 L .54006 .73541 L F
.398 .329 .662 r
.74714 .59877 m .74952 .60078 L .74948 .59712 L F
.746 .344 .29 r
.55988 .70309 m .56364 .70463 L .56341 .70329 L F
.651 .36 .465 r
.51837 .74314 m .51628 .74196 L .51967 .74218 L F
.666 .254 .253 r
.51967 .74218 m .52197 .74391 L .51837 .74314 L F
.875 .595 .511 r
.60198 .68044 m .6036 .67846 L .60194 .67752 L F
.60198 .68044 m .60374 .68072 L .6036 .67846 L F
0 0 0 r
.51289 .73639 m .51286 .73819 L .51298 .73886 L F
.51289 .73639 m .51462 .73571 L .51286 .73819 L F
.519 .191 .351 r
.51223 .71059 m .51452 .71042 L .51255 .70903 L F
.392 .16 .438 r
.31281 .63938 m .31046 .6423 L .31103 .6401 L F
.415 .669 .966 r
.73035 .58963 m .73146 .59089 L .73036 .58708 L F
.597 .448 .65 r
.73146 .59089 m .73371 .5875 L .73036 .58708 L F
.73146 .59089 m .73383 .59 L .73371 .5875 L F
.628 .902 .985 r
.73284 .58941 m .73146 .59089 L .73035 .58963 L F
.73284 .58941 m .73383 .59 L .73146 .59089 L F
.956 .761 .6 r
.70341 .59297 m .70315 .59542 L .70214 .59212 L F
.419 .864 .889 r
.6286 .5251 m .6281 .52524 L .62655 .52522 L F
.86 .899 .861 r
.6281 .52524 m .62467 .52638 L .62655 .52522 L F
.6281 .52524 m .6258 .5273 L .62467 .52638 L F
.508 .532 .816 r
.55058 .76401 m .55368 .76673 L .55197 .76357 L F
.676 .601 .764 r
.59627 .71137 m .59757 .71364 L .59384 .71403 L F
.503 .909 .885 r
.59384 .71403 m .59508 .71297 L .59627 .71137 L F
.746 .628 .729 r
.59142 .71234 m .59268 .71324 L .59508 .71297 L F
.374 .593 .93 r
.59142 .71234 m .59316 .71359 L .59118 .71337 L F
.746 .628 .729 r
.59186 .71334 m .59328 .71361 L .59508 .71297 L F
.503 .909 .885 r
.59384 .71403 m .59328 .71361 L .59508 .71297 L F
.746 .628 .729 r
.59328 .71361 m .5944 .71382 L .59508 .71297 L F
.503 .909 .885 r
.59328 .71361 m .59326 .7136 L .59508 .71297 L F
.374 .593 .93 r
.59142 .71234 m .59326 .7136 L .59316 .71359 L F
.746 .628 .729 r
.59142 .71234 m .59186 .71334 L .59268 .71324 L F
.035 .583 .834 r
.59118 .71337 m .59316 .71359 L .59384 .71403 L F
.59316 .71359 m .59328 .71361 L .59384 .71403 L F
.746 .628 .729 r
.59186 .71334 m .59291 .71572 L .5944 .71382 L F
.035 .583 .834 r
.59316 .71359 m .59326 .7136 L .59328 .71361 L F
.789 .399 0 r
.59516 .72446 m .59455 .72366 L .59382 .72178 L F
.898 .813 .755 r
.59424 .72793 m .59455 .72366 L .59516 .72446 L F
.594 .538 .762 r
.63331 .52612 m .63129 .52716 L .63099 .52504 L F
0 0 .216 r
.58155 .74459 m .58173 .7436 L .58144 .74117 L F
0 .106 .66 r
.58155 .74459 m .58334 .74673 L .58173 .7436 L F
0 .078 .628 r
.57968 .73914 m .58034 .73833 L .57871 .736 L F
0 .144 .68 r
.57968 .73914 m .58144 .74117 L .58034 .73833 L F
.524 .877 .985 r
.50249 .73555 m .50436 .73583 L .50171 .73651 L F
.066 .217 .711 r
.50058 .73334 m .50249 .73555 L .50171 .73651 L F
.601 .95 .825 r
.40291 .66443 m .40246 .66532 L .40387 .66524 L F
.482 .297 .553 r
.7573 .59052 m .75492 .59453 L .75491 .59266 L F
.636 .226 .25 r
.52371 .79336 m .52503 .79149 L .52151 .79146 L F
.788 .415 .35 r
.52694 .79587 m .52503 .79149 L .52371 .79336 L F
.698 .666 .118 r
.57375 .76259 m .57346 .76433 L .57413 .76032 L F
.84 .987 .713 r
.57211 .76537 m .57346 .76433 L .57375 .76259 L F
.928 .732 .617 r
.48138 .7526 m .48114 .7556 L .48262 .75572 L F
.564 .568 .816 r
.48138 .7526 m .48262 .75572 L .48488 .755 L F
.706 .286 .246 r
.48114 .7556 m .48488 .755 L .48262 .75572 L F
.337 0 0 r
.51006 .78968 m .50676 .79087 L .50904 .79117 L F
.552 .143 .218 r
.50904 .79117 m .51333 .79033 L .51006 .78968 L F
.535 .452 .708 r
.36836 .68355 m .36878 .68565 L .36672 .68587 L F
.522 .436 .7 r
.36878 .68565 m .36739 .68959 L .36672 .68587 L F
.82 .654 .105 r
.66717 .52225 m .66735 .52109 L .66672 .51987 L F
.66717 .52225 m .66734 .52332 L .66735 .52109 L F
0 .192 .719 r
.51206 .72525 m .50883 .7215 L .51088 .72516 L F
.704 .777 .909 r
.58835 .71415 m .58599 .71498 L .58495 .7138 L F
.58835 .71415 m .58599 .71498 L .58495 .7138 L F
.751 .746 .847 r
.74415 .72122 m .74234 .72222 L .74557 .72249 L F
.556 .548 .8 r
.43911 .78046 m .43984 .77694 L .43804 .77776 L F
.43911 .78046 m .44124 .78018 L .43984 .77694 L F
.431 .189 .444 r
.37033 .6807 m .36848 .68113 L .37081 .67847 L F
.359 .05 .298 r
.37314 .67822 m .37033 .6807 L .37081 .67847 L F
.502 .37 .634 r
.46593 .76988 m .46585 .77214 L .46712 .76851 L F
0 0 0 r
.5153 .74743 m .5127 .74998 L .51258 .74766 L F
.5153 .74743 m .51418 .74915 L .5127 .74998 L F
.461 .459 .77 r
.51628 .74394 m .5153 .74743 L .51481 .74449 L F
.588 .435 .641 r
.51971 .74664 m .5197 .74911 L .51931 .74913 L F
.51823 .74841 m .51931 .74913 L .51753 .74924 L F
.51971 .74664 m .51931 .74913 L .51823 .74841 L F
.249 .003 .332 r
.51971 .74664 m .51823 .74841 L .51856 .74826 L F
.51823 .74841 m .51753 .74924 L .51856 .74826 L F
.461 .459 .77 r
.51628 .74394 m .51856 .74826 L .51765 .74802 L F
.51553 .74661 m .51765 .74802 L .5153 .74743 L F
.51628 .74394 m .51765 .74802 L .51553 .74661 L F
.692 .843 .955 r
.51753 .74924 m .5153 .74743 L .51856 .74826 L F
.51753 .74924 m .51418 .74915 L .5153 .74743 L F
.674 .774 .925 r
.42455 .65232 m .42583 .65376 L .42234 .65325 L F
.579 .738 .951 r
.42798 .65328 m .42583 .65376 L .42455 .65232 L F
.449 .225 .48 r
.32426 .62334 m .32647 .62027 L .32611 .62263 L F
.438 .207 .465 r
.32611 .62263 m .32647 .62027 L .32848 .61989 L F
.215 0 .156 r
.30782 .64465 m .30874 .64305 L .31046 .6423 L F
0 0 0 r
.38863 .66718 m .38691 .66808 L .38474 .66881 L F
.063 0 0 r
.38939 .66734 m .38863 .66718 L .39089 .66677 L F
.38939 .66734 m .38691 .66808 L .38863 .66718 L F
.592 .743 .948 r
.27886 .58983 m .27684 .5904 L .27534 .58893 L F
.487 .451 .744 r
.30745 .61242 m .30848 .60863 L .30716 .60929 L F
.30745 .61242 m .30922 .612 L .30848 .60863 L F
.502 .456 .737 r
.30825 .61517 m .30922 .612 L .30745 .61242 L F
.834 .71 .727 r
.59261 .67891 m .5915 .68124 L .59086 .67874 L F
0 0 .424 r
.59076 .67838 m .5915 .68124 L .59148 .68 L F
.59076 .67838 m .5915 .68124 L .59148 .68 L F
.73 .282 .187 r
.58868 .67853 m .59148 .68 L .58827 .67926 L F
.58908 .67781 m .59001 .67866 L .58868 .67853 L F
.59001 .67866 m .59148 .68 L .58868 .67853 L F
.834 .71 .727 r
.59278 .67854 m .59261 .67891 L .59076 .67838 L F
.59261 .67891 m .59086 .67874 L .59076 .67838 L F
.797 .714 .773 r
.63666 .51503 m .63765 .51821 L .63981 .51552 L F
.849 .699 .696 r
.60825 .68901 m .60953 .69216 L .60988 .68978 L F
.359 0 .043 r
.73325 .70809 m .73566 .70775 L .73629 .70648 L F
.276 0 .009 r
.73629 .70648 m .73705 .70697 L .73886 .70668 L F
.73629 .70648 m .73566 .70775 L .73705 .70697 L F
.842 .67 .669 r
.71802 .58391 m .71957 .58797 L .72033 .58502 L F
.488 .559 .854 r
.63508 .50748 m .63867 .50831 L .63684 .5061 L F
.393 .383 .729 r
.63764 .50892 m .63508 .50748 L .63684 .5061 L F
.373 0 0 r
.28474 .60301 m .28855 .60316 L .28681 .60279 L F
.26 0 0 r
.28855 .60316 m .29037 .60369 L .28681 .60279 L F
.443 0 0 r
.29017 .60343 m .29037 .60369 L .28855 .60316 L F
.637 .733 .918 r
.73777 .71355 m .73913 .71058 L .73704 .71182 L F
.73777 .71355 m .74018 .71215 L .73913 .71058 L F
.847 .386 .072 r
.3045 .75294 m .30597 .75538 L .30437 .75454 L F
.12 0 .013 r
.3045 .75294 m .30437 .75454 L .30599 .75238 L F
.563 .304 .481 r
.64436 .54253 m .64285 .54544 L .64049 .54567 L F
.566 .307 .483 r
.64559 .54318 m .64436 .54253 L .64596 .54259 L F
.64559 .54318 m .64285 .54544 L .64436 .54253 L F
.508 .851 .995 r
.47335 .76033 m .47126 .76066 L .47191 .76113 L F
.433 .065 .239 r
.58438 .67226 m .58773 .66978 L .58475 .6705 L F
.838 .503 .42 r
.33957 .70592 m .34293 .70874 L .34171 .70652 L F
.33957 .70592 m .33998 .70822 L .34293 .70874 L F
.681 .956 .949 r
.34056 .71053 m .34293 .70874 L .33998 .70822 L F
.429 .42 .747 r
.34293 .70874 m .34288 .70465 L .34171 .70652 L F
.34293 .70874 m .34451 .70851 L .34288 .70465 L F
.507 .674 .939 r
.44852 .7867 m .44998 .78512 L .44793 .78535 L F
.44852 .7867 m .45405 .78761 L .44998 .78512 L F
0 0 .212 r
.59849 .69769 m .5987 .69714 L .59855 .6946 L F
.263 .064 .412 r
.51628 .74196 m .51628 .74394 L .51481 .74449 L F
.038 0 0 r
.51506 .74287 m .51641 .74253 L .51709 .74115 L F
.07 0 .228 r
.51709 .74115 m .52054 .73774 L .51769 .73824 L F
.51709 .74115 m .51987 .74038 L .52054 .73774 L F
.651 .36 .465 r
.51837 .74314 m .51628 .74394 L .51628 .74196 L F
0 0 0 r
.51709 .74115 m .51641 .74253 L .51987 .74038 L F
.528 .389 .635 r
.31946 .71913 m .3209 .71647 L .31805 .71687 L F
.31946 .71913 m .32162 .71919 L .3209 .71647 L F
.555 .5 .749 r
.36988 .69099 m .36868 .6951 L .36801 .69148 L F
.36988 .69099 m .37077 .69475 L .36868 .6951 L F
.243 0 .297 r
.56366 .68097 m .56374 .68384 L .56533 .68235 L F
.571 .213 .323 r
.56047 .68195 m .56353 .68391 L .56366 .68097 L F
.56353 .68391 m .56374 .68384 L .56366 .68097 L F
.276 .401 .809 r
.56535 .68327 m .56533 .68235 L .56344 .68379 L F
.56353 .68391 m .56344 .68379 L .56306 .68408 L F
.56535 .68327 m .56344 .68379 L .56353 .68391 L F
0 .282 .775 r
.56194 .68213 m .56307 .68338 L .5608 .68213 L F
.56194 .68213 m .5608 .68213 L .56047 .68195 L F
.56317 .68344 m .56353 .68391 L .56047 .68195 L F
.756 .738 .835 r
.56194 .68213 m .56281 .68427 L .56344 .68379 L F
.56194 .68213 m .56344 .68379 L .56533 .68235 L F
0 .282 .775 r
.56194 .68213 m .56317 .68344 L .56307 .68338 L F
.72 .329 .309 r
.55824 .68319 m .56085 .68496 L .56072 .68239 L F
.551 .625 .879 r
.56085 .68496 m .56194 .68213 L .56072 .68239 L F
.56085 .68496 m .56281 .68427 L .56194 .68213 L F
0 .282 .775 r
.56317 .68344 m .56374 .68405 L .56353 .68391 L F
.276 .401 .809 r
.56535 .68327 m .56306 .68408 L .56281 .68427 L F
.243 0 .297 r
.56374 .68384 m .56374 .68405 L .56533 .68235 L F
.276 .401 .809 r
.56539 .68508 m .56535 .68327 L .56362 .68395 L F
.56316 .68438 m .56362 .68395 L .56281 .68427 L F
.571 .213 .323 r
.56353 .68391 m .56374 .68405 L .56374 .68384 L F
.767 .713 .802 r
.56533 .68235 m .56374 .68405 L .56194 .68213 L F
.042 .276 .77 r
.56281 .68427 m .56421 .68433 L .56194 .68213 L F
.728 .351 .336 r
.56194 .68213 m .56421 .68433 L .56047 .68362 L F
.202 .327 .769 r
.56354 .68159 m .56421 .68433 L .56194 .68213 L F
.56274 .68213 m .56194 .68213 L .56047 .68362 L F
.56354 .68159 m .56194 .68213 L .56274 .68213 L F
.276 .401 .809 r
.56539 .68508 m .56362 .68395 L .56316 .68438 L F
.243 0 .297 r
.56366 .68097 m .56533 .68235 L .56561 .68066 L F
.722 .685 .814 r
.73955 .6164 m .73633 .61699 L .73906 .61507 L F
.709 .839 .945 r
.7422 .61532 m .73955 .6164 L .73906 .61507 L F
.133 0 .112 r
.41731 .69727 m .41483 .69958 L .41564 .69819 L F
.763 .542 .597 r
.63526 .51802 m .63789 .52033 L .63765 .51821 L F
.247 .605 .953 r
.58938 .75555 m .58494 .75349 L .58762 .75622 L F
.58938 .75555 m .58942 .75476 L .58494 .75349 L F
.368 .721 .988 r
.58938 .75555 m .59002 .75456 L .58942 .75476 L F
.009 .234 .742 r
.58938 .75555 m .59121 .75743 L .59002 .75456 L F
.14 0 0 r
.44586 .74623 m .44717 .74634 L .44852 .74557 L F
.565 .036 0 r
.44717 .74634 m .45065 .74667 L .44852 .74557 L F
.557 .012 0 r
.44852 .74557 m .45065 .74667 L .45183 .74671 L F
.515 .059 .108 r
.35287 .65751 m .3544 .65593 L .35119 .65637 L F
.316 0 0 r
.35505 .65721 m .3544 .65593 L .35287 .65751 L F
.35505 .65721 m .35657 .65561 L .3544 .65593 L F
.764 .402 0 r
.71669 .59282 m .71792 .59558 L .71737 .59467 L F
.684 .608 .765 r
.71941 .59149 m .72014 .59547 L .71792 .59558 L F
.039 .262 .759 r
.71874 .59707 m .71737 .59467 L .71792 .59558 L F
.728 .429 .472 r
.72014 .59547 m .71874 .59707 L .71792 .59558 L F
.555 .433 .668 r
.43839 .76415 m .44047 .7638 L .44028 .76164 L F
.576 .439 .658 r
.43839 .76415 m .4409 .76617 L .44047 .7638 L F
.43839 .76415 m .43865 .76655 L .4409 .76617 L F
.361 .099 .376 r
.37795 .67272 m .37761 .67514 L .37588 .67539 L F
.49 .206 .41 r
.37976 .67462 m .37795 .67272 L .38001 .67232 L F
.37976 .67462 m .37761 .67514 L .37795 .67272 L F
.597 .494 .708 r
.3284 .70655 m .33056 .70779 L .33104 .70812 L F
.333 0 0 r
.33056 .70779 m .33407 .70847 L .33104 .70812 L F
.735 .628 .74 r
.49412 .75551 m .49769 .7561 L .49715 .7526 L F
.535 .16 .277 r
.49769 .7561 m .49421 .75758 L .49412 .75551 L F
.724 .505 0 r
.49715 .7526 m .49754 .75539 L .49769 .7561 L F
.294 0 .115 r
.49805 .75775 m .49769 .7561 L .49754 .75539 L F
.49805 .75775 m .49599 .75836 L .49769 .7561 L F
.433 .065 .239 r
.58438 .67226 m .58667 .67191 L .58773 .66978 L F
.243 0 0 r
.58667 .67191 m .59007 .67028 L .58773 .66978 L F
.5 .657 .93 r
.37977 .70023 m .37898 .70228 L .37741 .70074 L F
.37977 .70023 m .38098 .70223 L .37898 .70228 L F
.665 .293 0 r
.58299 .74994 m .58423 .7526 L .58274 .74953 L F
.343 .174 .502 r
.53938 .74654 m .53934 .74503 L .53667 .74375 L F
.53938 .74654 m .53958 .74727 L .53934 .74503 L F
.711 .214 .058 r
.46363 .77726 m .46589 .77783 L .46622 .77694 L F
.828 .365 .109 r
.55052 .70827 m .5487 .70778 L .54731 .70588 L F
.184 0 0 r
.29251 .63521 m .29211 .63422 L .29044 .63552 L F
.29251 .63521 m .29415 .63373 L .29211 .63422 L F
.842 .701 .708 r
.57816 .71579 m .58045 .7171 L .57917 .71379 L F
.825 .36 .105 r
.57816 .71579 m .57964 .71761 L .58045 .7171 L F
0 .217 .741 r
.58207 .71769 m .58266 .71913 L .58045 .7171 L F
.58207 .71769 m .58045 .7171 L .57964 .71761 L F
.502 .456 .737 r
.30825 .61517 m .31001 .61436 L .30922 .612 L F
.42 .158 .408 r
.30825 .61517 m .30964 .61659 L .31001 .61436 L F
.30825 .61517 m .30768 .61712 L .30964 .61659 L F
.22 .705 .929 r
.43013 .65282 m .43356 .65331 L .43147 .65347 L F
.499 .355 .616 r
.43792 .775 m .43984 .77694 L .4399 .77455 L F
.43792 .775 m .43804 .77776 L .43984 .77694 L F
.592 .334 .495 r
.64826 .54046 m .6506 .54239 L .64825 .54234 L F
.64826 .54046 m .65065 .54023 L .6506 .54239 L F
.513 .261 .471 r
.56637 .75856 m .56636 .76041 L .56404 .76068 L F
.516 .004 0 r
.54832 .73964 m .54662 .74068 L .54451 .73984 L F
.986 .872 .633 r
.54734 .73849 m .54832 .73964 L .55124 .73768 L F
.54734 .73849 m .54662 .74068 L .54832 .73964 L F
.096 .097 .568 r
.48869 .77995 m .4896 .77985 L .48893 .77755 L F
.068 0 .332 r
.75592 .60463 m .75473 .60343 L .75594 .60277 L F
.75592 .60463 m .75405 .606 L .75473 .60343 L F
.601 .931 .96 r
.51989 .73546 m .51867 .73647 L .51947 .73525 L F
.471 .12 .287 r
.51867 .73647 m .52054 .73774 L .51947 .73525 L F
.51867 .73647 m .51769 .73824 L .52054 .73774 L F
.611 .042 0 r
.33407 .70847 m .33731 .71006 L .33561 .71046 L F
.767 .772 .856 r
.51807 .79098 m .52151 .79146 L .5195 .79184 L F
.8 .718 .774 r
.51807 .79098 m .51948 .79496 L .52151 .79146 L F
.551 .4 .629 r
.51948 .79496 m .5223 .79423 L .52151 .79146 L F
0 .442 .805 r
.51948 .79496 m .52276 .79618 L .5223 .79423 L F
.576 .494 .725 r
.33784 .69817 m .33821 .7005 L .34035 .70008 L F
.519 .455 .724 r
.33821 .7005 m .34081 .70277 L .34035 .70008 L F
.662 .902 .98 r
.73507 .61577 m .73633 .61699 L .73404 .61752 L F
.698 .915 .969 r
.73906 .61507 m .73633 .61699 L .73507 .61577 L F
.309 .745 .968 r
.31178 .59529 m .3138 .5952 L .31529 .59581 L F
.275 .73 .955 r
.3138 .5952 m .31741 .59574 L .31529 .59581 L F
.933 .73 .606 r
.58822 .73027 m .5882 .73352 L .58974 .73333 L F
.644 .126 0 r
.5882 .73352 m .58919 .73462 L .58974 .73333 L F
.565 .108 .127 r
.58919 .73462 m .59223 .7335 L .58974 .73333 L F
.74 .871 .941 r
.54255 .75565 m .54014 .75703 L .53957 .75562 L F
.845 .512 .423 r
.3284 .70655 m .3297 .70692 L .32751 .70495 L F
.634 .584 .78 r
.32751 .70495 m .3297 .70692 L .32709 .70321 L F
.843 .658 .653 r
.60092 .711 m .6004 .71173 L .59863 .70863 L F
.86 .686 .665 r
.60092 .711 m .60015 .71368 L .6004 .71173 L F
.44 .518 .842 r
.30716 .60929 m .30848 .60863 L .30546 .60715 L F
.398 .65 .959 r
.32452 .59796 m .3208 .59619 L .32347 .59648 L F
.374 .61 .941 r
.32511 .59652 m .32452 .59796 L .32347 .59648 L F
.365 .6 .937 r
.32637 .59809 m .32452 .59796 L .32511 .59652 L F
0 0 .012 r
.66299 .5335 m .66336 .53177 L .66307 .5312 L F
.216 0 0 r
.46384 .78891 m .46445 .7894 L .46238 .7884 L F
.46384 .78891 m .46581 .78913 L .46445 .7894 L F
.656 .748 .918 r
.6606 .51841 m .65809 .51944 L .65689 .51768 L F
.218 .688 .94 r
.54114 .79384 m .54234 .79455 L .53966 .7944 L F
.79 .954 .923 r
.54114 .79384 m .53966 .7944 L .53879 .79381 L F
.447 0 .052 r
.53966 .7944 m .54234 .79455 L .53944 .7964 L F
.203 0 0 r
.53539 .79823 m .53757 .7972 L .53624 .79878 L F
.028 0 0 r
.53624 .79878 m .53757 .7972 L .53944 .7964 L F
.53624 .79878 m .53944 .7964 L .53861 .79869 L F
0 0 .294 r
.53948 .79612 m .53944 .7964 L .53879 .79381 L F
.715 .765 .267 r
.53861 .79869 m .53944 .7964 L .53948 .79612 L F
.79 .954 .923 r
.54114 .79384 m .54234 .79455 L .53944 .7964 L F
.715 .765 .267 r
.53861 .79869 m .53948 .79612 L .54082 .79819 L F
.692 .35 .391 r
.54012 .79803 m .53948 .79612 L .53614 .7971 L F
.54082 .79819 m .54012 .79712 L .54012 .79803 L F
.54012 .79712 m .53948 .79612 L .54012 .79803 L F
.79 .954 .923 r
.54013 .79422 m .53944 .7964 L .53966 .7944 L F
.54114 .79384 m .54013 .79536 L .54013 .79422 L F
.54013 .79536 m .53944 .7964 L .54013 .79422 L F
.516 .26 .465 r
.46548 .74452 m .46771 .74419 L .46811 .74207 L F
.521 .278 .488 r
.46771 .74419 m .47012 .74164 L .46811 .74207 L F
0 0 .344 r
.54252 .69953 m .54278 .6965 L .54172 .69766 L F
.989 .786 .538 r
.62885 .51565 m .62753 .51684 L .62786 .51446 L F
.62885 .51565 m .62862 .51789 L .62753 .51684 L F
.788 .722 .791 r
.32478 .70391 m .32145 .70498 L .32301 .70456 L F
.743 .376 .358 r
.32301 .70456 m .32751 .70495 L .32478 .70391 L F
.613 .34 .48 r
.55503 .75843 m .55727 .76046 L .5549 .76058 L F
.373 .149 .44 r
.59661 .68983 m .59737 .69136 L .59523 .6924 L F
.64 .088 0 r
.5447 .72409 m .54659 .7252 L .54782 .72519 L F
.487 0 0 r
.54659 .7252 m .55027 .72601 L .54782 .72519 L F
.516 .483 .758 r
.59253 .73804 m .59299 .73832 L .59138 .73782 L F
.674 .842 .964 r
.58755 .7387 m .59253 .73804 L .59138 .73782 L F
.522 .384 .634 r
.58898 .72028 m .58967 .72207 L .58739 .72247 L F
.746 .895 .501 r
.58967 .72207 m .58784 .72524 L .58739 .72247 L F
.283 .5 .89 r
.59401 .68983 m .59491 .68893 L .59478 .68886 L F
.59401 .68983 m .59737 .69136 L .59491 .68893 L F
.519 .444 .711 r
.59523 .6924 m .59737 .69136 L .59401 .68983 L F
.511 .236 .434 r
.41247 .68626 m .41468 .68592 L .41513 .684 L F
.555 .335 .536 r
.41468 .68592 m .4171 .68342 L .41513 .684 L F
.388 0 0 r
.4894 .76161 m .49032 .76236 L .4863 .76224 L F
.4894 .76161 m .49156 .76247 L .49032 .76236 L F
.531 .367 .604 r
.37033 .6807 m .36836 .68355 L .36848 .68113 L F
0 0 .357 r
.51413 .73999 m .51298 .73886 L .51286 .73819 L F
.667 .509 .661 r
.54949 .75852 m .54914 .76149 L .54872 .76092 L F
.653 .496 .659 r
.55233 .76106 m .54914 .76149 L .54949 .75852 L F
.522 .436 .7 r
.36878 .68565 m .36936 .68922 L .36739 .68959 L F
.525 .449 .713 r
.36936 .68922 m .36988 .69099 L .36739 .68959 L F
.502 .457 .739 r
.36739 .68959 m .36988 .69099 L .36801 .69148 L F
.406 0 0 r
.29017 .60343 m .29412 .60364 L .29037 .60369 L F
.834 .581 .556 r
.6144 .71894 m .61599 .72153 L .61769 .71962 L F
.456 .288 .564 r
.34412 .66191 m .34594 .66357 L .34613 .66127 L F
.34412 .66191 m .344 .66425 L .34594 .66357 L F
.682 .475 .6 r
.27102 .65645 m .27366 .65566 L .27282 .65556 L F
.27102 .65645 m .2737 .65653 L .27366 .65566 L F
.523 .898 .962 r
.27517 .65471 m .27366 .65566 L .27588 .65523 L F
.27517 .65471 m .27282 .65556 L .27366 .65566 L F
.38 .17 .465 r
.49628 .7278 m .49934 .72798 L .49838 .72512 L F
.428 .139 .369 r
.49628 .7278 m .49804 .72979 L .49934 .72798 L F
.49628 .7278 m .49578 .73071 L .49804 .72979 L F
.876 .89 .84 r
.6258 .5273 m .62392 .52953 L .62263 .52884 L F
.898 .719 .651 r
.62392 .52953 m .62173 .53072 L .62263 .52884 L F
.62392 .52953 m .6234 .53185 L .62173 .53072 L F
.359 .134 .43 r
.45887 .76845 m .45665 .76959 L .45902 .76652 L F
.462 .327 .611 r
.45887 .76845 m .45866 .7719 L .45665 .76959 L F
.18 .256 .706 r
.45665 .76959 m .45866 .7719 L .45758 .77135 L F
.512 .741 .978 r
.51807 .79098 m .51549 .79147 L .51579 .79151 L F
0 0 .532 r
.59382 .72178 m .59449 .72195 L .59398 .71861 L F
0 0 .039 r
.59455 .72366 m .59449 .72195 L .59382 .72178 L F
.893 .523 .332 r
.49865 .75407 m .49754 .75539 L .49715 .7526 L F
.114 0 0 r
.50051 .75407 m .49865 .75407 L .5014 .75386 L F
.50051 .75407 m .49754 .75539 L .49865 .75407 L F
.928 .72 .602 r
.60807 .69145 m .60953 .69216 L .60825 .68901 L F
.88 .609 .524 r
.60793 .69378 m .60953 .69216 L .60807 .69145 L F
.60793 .69378 m .60966 .69453 L .60953 .69216 L F
.491 .396 .675 r
.32751 .70495 m .32808 .70853 L .3284 .70655 L F
.476 .275 .527 r
.3484 .65831 m .34639 .65891 L .34613 .66127 L F
.221 0 0 r
.57533 .6806 m .57313 .68157 L .57154 .68174 L F
.321 .805 .766 r
.57751 .67982 m .57663 .67998 L .57533 .6806 L F
.308 .777 .659 r
.57663 .67998 m .57313 .68157 L .57533 .6806 L F
.876 .89 .84 r
.6258 .5273 m .62263 .52884 L .62467 .52638 L F
.454 .383 .688 r
.33957 .70592 m .34171 .70652 L .34081 .70277 L F
0 0 .205 r
.33999 .70722 m .33998 .70822 L .33957 .70592 L F
.33999 .70722 m .33957 .70592 L .33789 .70763 L F
.575 .059 0 r
.45448 .78762 m .45831 .78772 L .45689 .78759 L F
.167 .682 .892 r
.46042 .78802 m .45689 .78759 L .45831 .78772 L F
.727 .284 .2 r
.4935 .79349 m .49681 .79411 L .49564 .79562 L F
.64 .179 .142 r
.49564 .79562 m .49681 .79411 L .49921 .79589 L F
.576 .494 .725 r
.33784 .69817 m .34035 .70008 L .33997 .69761 L F
.673 .507 .652 r
.73383 .59 m .73592 .5873 L .73371 .5875 L F
.524 .362 .603 r
.33841 .6756 m .34054 .67499 L .34055 .67256 L F
.534 .41 .658 r
.33874 .67841 m .34054 .67499 L .33841 .6756 L F
.783 .756 .829 r
.65455 .51614 m .65178 .51673 L .65403 .51596 L F
.351 .41 .783 r
.65596 .51429 m .65455 .51614 L .65403 .51596 L F
.65596 .51429 m .65689 .51768 L .65455 .51614 L F
.595 .524 .745 r
.33747 .68375 m .34038 .68627 L .33947 .68307 L F
.884 .738 .695 r
.60922 .69688 m .61075 .69767 L .60966 .69453 L F
.874 .673 .627 r
.60922 .69688 m .61068 .7002 L .61075 .69767 L F
.041 .027 .512 r
.62008 .73281 m .62042 .73523 L .61913 .73629 L F
0 0 .088 r
.61913 .73629 m .6197 .73733 L .61854 .73866 L F
.61913 .73629 m .62042 .73523 L .6197 .73733 L F
.397 .191 .481 r
.5365 .79375 m .53491 .79429 L .53423 .79678 L F
.079 0 0 r
.30527 .64685 m .30352 .64787 L .30624 .64561 L F
.221 0 .183 r
.30782 .64465 m .30527 .64685 L .30624 .64561 L F
.375 0 0 r
.29412 .60364 m .2945 .60396 L .2923 .60373 L F
.072 .597 .873 r
.2923 .60373 m .2945 .60396 L .29416 .60383 L F
.076 0 0 r
.29135 .60368 m .29412 .60364 L .2923 .60373 L F
.072 .597 .873 r
.2923 .60373 m .29416 .60383 L .29287 .60334 L F
.076 0 0 r
.29037 .60369 m .29135 .60368 L .2923 .60373 L F
.375 0 0 r
.29412 .60364 m .29618 .60476 L .2945 .60396 L F
.753 .879 .937 r
.60403 .7573 m .60485 .75502 L .60233 .75701 L F
.60403 .7573 m .60631 .75573 L .60485 .75502 L F
.691 .683 .838 r
.7227 .59273 m .72353 .59558 L .72014 .59547 L F
.26 .175 .567 r
.72176 .59688 m .72014 .59547 L .72353 .59558 L F
.768 .728 .816 r
.72608 .59307 m .72353 .59558 L .7227 .59273 L F
.645 .907 .594 r
.72648 .59293 m .72586 .5936 L .72511 .59477 L F
0 0 0 r
.72511 .59477 m .72353 .59558 L .72461 .59554 L F
.72511 .59477 m .72176 .59688 L .72353 .59558 L F
.728 .429 .472 r
.72014 .59547 m .72096 .59782 L .71874 .59707 L F
.431 .012 .14 r
.72511 .59477 m .72284 .59573 L .72176 .59688 L F
.26 .175 .567 r
.72176 .59688 m .72093 .59775 L .72014 .59547 L F
.431 .012 .14 r
.72284 .59573 m .72027 .59683 L .72176 .59688 L F
.26 .175 .567 r
.72176 .59688 m .72096 .59782 L .72093 .59775 L F
0 0 0 r
.7202 .59911 m .72096 .59782 L .72176 .59688 L F
.728 .426 .467 r
.71874 .59707 m .72096 .59782 L .7202 .59911 L F
.248 .363 .785 r
.71937 .59652 m .7202 .59911 L .72176 .59688 L F
.377 0 0 r
.7196 .59655 m .72027 .59683 L .71959 .59655 L F
.72176 .59688 m .72027 .59683 L .7196 .59655 L F
.431 .012 .14 r
.72218 .59762 m .72215 .59764 L .72027 .59683 L F
.317 .199 .556 r
.72027 .59683 m .72215 .59764 L .72216 .59761 L F
.431 .012 .14 r
.72511 .59477 m .72218 .59762 L .72027 .59683 L F
.616 .562 .77 r
.7227 .59273 m .72014 .59547 L .71941 .59149 L F
.768 .728 .816 r
.72608 .59307 m .7227 .59273 L .72444 .59183 L F
.616 .562 .77 r
.7227 .59273 m .71941 .59149 L .72243 .59015 L F
.706 .528 .646 r
.72444 .59183 m .7227 .59273 L .72243 .59015 L F
.317 .199 .556 r
.72027 .59683 m .72216 .59761 L .72296 .59223 L F
.377 0 0 r
.71959 .59655 m .72027 .59683 L .71937 .59652 L F
.645 .907 .594 r
.72586 .5936 m .72215 .59764 L .72511 .59477 L F
0 0 0 r
.72511 .59477 m .72461 .59554 L .72528 .59552 L F
.091 .476 .894 r
.72276 .61825 m .72618 .62045 L .72579 .6177 L F
.424 .78 .996 r
.41763 .65117 m .41686 .65223 L .41534 .65109 L F
.41763 .65117 m .419 .65201 L .41686 .65223 L F
.505 .504 .789 r
.3728 .69437 m .37198 .69784 L .37077 .69475 L F
.3728 .69437 m .37389 .6976 L .37198 .69784 L F
.572 .566 .808 r
.37537 .70076 m .37198 .69784 L .37389 .6976 L F
.754 .738 .838 r
.66382 .51871 m .6606 .51841 L .66242 .5172 L F
.266 .505 .898 r
.66457 .51748 m .66382 .51871 L .66242 .5172 L F
.66457 .51748 m .66672 .51987 L .66382 .51871 L F
.743 .933 .95 r
.55235 .75153 m .55638 .75076 L .55311 .75057 L F
.791 .542 .561 r
.55476 .7474 m .5545 .75042 L .55143 .74907 L F
.743 .933 .95 r
.5534 .75066 m .55415 .75049 L .55432 .75051 L F
.55402 .75068 m .55432 .75051 L .55638 .75076 L F
.694 .762 .904 r
.55392 .75054 m .55235 .75153 L .55143 .74907 L F
.743 .933 .95 r
.55372 .75067 m .55432 .75051 L .55402 .75068 L F
.55385 .75059 m .55432 .75051 L .55372 .75067 L F
.55235 .75153 m .5534 .75066 L .55638 .75076 L F
.694 .762 .904 r
.55446 .75086 m .55235 .75153 L .55392 .75054 L F
.743 .933 .95 r
.5534 .75066 m .55385 .75059 L .55372 .75067 L F
.159 .699 .745 r
.55432 .75051 m .5583 .74975 L .55638 .75076 L F
.576 .352 .539 r
.5545 .75042 m .55464 .75039 L .55449 .75045 L F
.791 .542 .561 r
.5545 .75042 m .55415 .75049 L .55143 .74907 L F
.55415 .75049 m .55392 .75054 L .55389 .75053 L F
.55415 .75049 m .55389 .75053 L .55143 .74907 L F
.159 .699 .745 r
.55367 .75044 m .55505 .75023 L .55449 .75045 L F
.55415 .75049 m .55449 .75045 L .55432 .75051 L F
.55367 .75044 m .55449 .75045 L .55415 .75049 L F
.55505 .75023 m .5583 .74975 L .55432 .75051 L F
.576 .352 .539 r
.55449 .75045 m .55747 .74983 L .55446 .75086 L F
.55464 .75039 m .55747 .74983 L .55449 .75045 L F
.159 .699 .745 r
.55505 .75023 m .55747 .74983 L .5583 .74975 L F
.576 .352 .539 r
.55676 .74919 m .55747 .74983 L .5545 .75042 L F
.159 .699 .745 r
.55367 .75044 m .55747 .74983 L .55505 .75023 L F
.576 .352 .539 r
.55476 .7474 m .55676 .74919 L .55475 .75028 L F
.5545 .75032 m .55475 .75028 L .5545 .75042 L F
.55476 .7474 m .55475 .75028 L .5545 .75032 L F
.791 .542 .561 r
.5545 .75042 m .55446 .75086 L .55392 .75054 L F
.743 .933 .95 r
.5534 .75066 m .55367 .75044 L .55415 .75049 L F
.269 .691 .967 r
.28316 .58978 m .28232 .59057 L .28083 .58959 L F
.28316 .58978 m .28445 .59072 L .28232 .59057 L F
.355 0 0 r
.52334 .7632 m .52787 .76175 L .52686 .76185 L F
.628 .822 .975 r
.59453 .75782 m .59809 .75803 L .59777 .75724 L F
.513 .745 .979 r
.59809 .75803 m .5987 .75678 L .59777 .75724 L F
.59809 .75803 m .60017 .7577 L .5987 .75678 L F
.702 .788 .918 r
.73192 .62026 m .72852 .61992 L .7301 .61995 L F
.782 .7 .773 r
.73404 .61752 m .73192 .62026 L .7301 .61995 L F
.62 .819 .977 r
.55586 .73868 m .55378 .73944 L .55229 .73843 L F
.953 .631 .379 r
.55378 .73944 m .55285 .7409 L .55229 .73843 L F
.768 .487 .509 r
.62354 .54742 m .61998 .54525 L .62315 .5461 L F
.693 .298 .295 r
.62315 .5461 m .62574 .54811 L .62354 .54742 L F
.245 0 0 r
.38114 .71613 m .37758 .71814 L .37897 .71672 L F
.711 .214 .058 r
.46363 .77726 m .46586 .77898 L .46589 .77783 L F
.547 0 0 r
.46466 .77834 m .46586 .77898 L .46363 .77726 L F
.357 .767 .981 r
.46466 .77834 m .46526 .77842 L .46586 .77898 L F
.889 .515 .048 r
.46586 .77898 m .46652 .7796 L .46589 .77783 L F
.357 .767 .981 r
.46526 .77842 m .46809 .77881 L .46586 .77898 L F
.889 .515 .048 r
.46586 .77898 m .467 .78093 L .46652 .7796 L F
.395 .184 .471 r
.32212 .62631 m .32426 .62334 L .3238 .62558 L F
.474 .344 .623 r
.32384 .62762 m .32212 .62631 L .3238 .62558 L F
.32384 .62762 m .32198 .62826 L .32212 .62631 L F
.218 0 .086 r
.41355 .70157 m .41278 .70018 L .41483 .69958 L F
.41355 .70157 m .41167 .70225 L .41278 .70018 L F
.759 .665 .758 r
.67957 .51295 m .68049 .51577 L .67777 .51531 L F
.663 .469 .612 r
.68049 .51577 m .67741 .51784 L .67777 .51531 L F
.68049 .51577 m .68074 .51809 L .67741 .51784 L F
.65 .604 .789 r
.6828 .51542 m .68049 .51577 L .67957 .51295 L F
.667 .472 .612 r
.68331 .51749 m .68049 .51577 L .6828 .51542 L F
.68331 .51749 m .68074 .51809 L .68049 .51577 L F
.229 .707 .936 r
.25706 .58635 m .26064 .5869 L .2587 .58654 L F
.444 0 0 r
.71923 .58975 m .72246 .5899 L .72243 .59015 L F
.739 .214 0 r
.72246 .5899 m .72444 .59183 L .72243 .59015 L F
.688 .322 .347 r
.50229 .79453 m .50457 .79649 L .50102 .79654 L F
.395 .154 .427 r
.49838 .72512 m .50072 .72494 L .50092 .72192 L F
.514 .345 .589 r
.50092 .72192 m .50365 .72154 L .50338 .71994 L F
.396 .155 .427 r
.50092 .72192 m .50261 .72411 L .50365 .72154 L F
.50092 .72192 m .50072 .72494 L .50261 .72411 L F
.186 .447 .874 r
.29752 .60603 m .29805 .60483 L .29618 .60476 L F
.29752 .60603 m .29888 .60637 L .29805 .60483 L F
.386 .516 .866 r
.74573 .59339 m .74721 .59181 L .7453 .59169 L F
.74573 .59339 m .74878 .59467 L .74721 .59181 L F
.611 .042 0 r
.33407 .70847 m .33686 .71054 L .33731 .71006 L F
.806 .84 .376 r
.33731 .71006 m .33686 .71054 L .33789 .70763 L F
.419 .849 .945 r
.27102 .65645 m .26958 .65621 L .26724 .65676 L F
.593 .925 .964 r
.27148 .65534 m .27102 .65645 L .27282 .65556 L F
.27148 .65534 m .26958 .65621 L .27102 .65645 L F
.169 .515 .916 r
.44435 .783 m .44621 .78483 L .44793 .78535 L F
.076 0 0 r
.49758 .78925 m .49558 .78953 L .49409 .79023 L F
.944 .704 .544 r
.61748 .72439 m .619 .72248 L .61599 .72153 L F
.61748 .72439 m .61894 .72497 L .619 .72248 L F
.606 .433 .621 r
.46121 .76385 m .46111 .76682 L .45902 .76652 L F
.734 .54 .63 r
.46451 .7665 m .46121 .76385 L .46336 .76313 L F
.46451 .7665 m .46111 .76682 L .46121 .76385 L F
.435 .21 .471 r
.75833 .60926 m .75799 .61123 L .75597 .61146 L F
.493 .348 .612 r
.75838 .61378 m .75597 .61146 L .75799 .61123 L F
.75838 .61378 m .75637 .61437 L .75597 .61146 L F
.393 0 0 r
.51814 .709 m .52074 .71019 L .52202 .71048 L F
.439 0 0 r
.52074 .71019 m .52362 .71128 L .52202 .71048 L F
.508 .213 .4 r
.66127 .53446 m .6609 .53678 L .65852 .53716 L F
.465 .176 .389 r
.66308 .53595 m .66127 .53446 L .66299 .5335 L F
.66308 .53595 m .6609 .53678 L .66127 .53446 L F
.447 0 0 r
.71436 .58872 m .7131 .5879 L .71283 .58893 L F
.71436 .58872 m .71687 .58922 L .7131 .5879 L F
.605 .335 .482 r
.46111 .76682 m .45887 .76845 L .45902 .76652 L F
0 .411 .842 r
.5227 .76555 m .52334 .7632 L .52189 .76398 L F
.5227 .76555 m .52238 .76486 L .52334 .7632 L F
.612 .269 .364 r
.56068 .75836 m .55948 .76038 L .55727 .76046 L F
.68 .347 .404 r
.56255 .76012 m .55948 .76038 L .56068 .75836 L F
.397 0 0 r
.54457 .69698 m .54666 .69767 L .54741 .69763 L F
.697 .157 0 r
.5583 .74975 m .55476 .7474 L .55827 .74732 L F
.634 .962 .827 r
.54741 .69763 m .54666 .69767 L .54842 .69638 L F
.675 .127 0 r
.54741 .69763 m .54961 .69967 L .55102 .70024 L F
.169 .3 .755 r
.54842 .69638 m .54961 .69967 L .54741 .69763 L F
.912 .745 .662 r
.59737 .69136 m .59922 .69248 L .59855 .6946 L F
.501 .306 .547 r
.4549 .67434 m .45284 .67264 L .45473 .6718 L F
.4549 .67434 m .45257 .67503 L .45284 .67264 L F
.706 .466 .559 r
.52808 .725 m .52409 .72798 L .52385 .72496 L F
.724 .648 .773 r
.72974 .71697 m .72788 .71886 L .72634 .71754 L F
.72788 .71886 m .72722 .71953 L .72659 .71811 L F
.72788 .71886 m .72659 .71811 L .72634 .71754 L F
0 .091 .647 r
.72634 .71754 m .72722 .71953 L .72712 .71835 L F
.649 .156 .065 r
.72634 .71754 m .72712 .71835 L .72429 .7168 L F
0 .264 .674 r
.72454 .71692 m .72712 .71835 L .72563 .71742 L F
.72429 .7168 m .72518 .71729 L .72454 .71692 L F
.72518 .71729 m .72712 .71835 L .72454 .71692 L F
.236 .488 .893 r
.72722 .71953 m .72871 .7186 L .72712 .71835 L F
.21 .433 .858 r
.72722 .71953 m .73015 .72128 L .72871 .7186 L F
.922 .708 .595 r
.60704 .68831 m .60842 .68661 L .60696 .68594 L F
.60704 .68831 m .60825 .68901 L .60842 .68661 L F
.716 .286 .228 r
.51714 .70973 m .52074 .71019 L .51814 .709 L F
.649 .492 .656 r
.56333 .76282 m .56255 .76012 L .56404 .76068 L F
.523 .213 .383 r
.56636 .76041 m .56333 .76282 L .56404 .76068 L F
.495 .074 .17 r
.5687 .7041 m .56731 .70529 L .56898 .70495 L F
.961 .86 .695 r
.56807 .70259 m .56731 .70529 L .5687 .7041 L F
.137 .679 .829 r
.74186 .59161 m .74297 .5918 L .7453 .59169 L F
.559 .421 .649 r
.44385 .75027 m .44613 .75002 L .44586 .74623 L F
.565 .458 .69 r
.44385 .75027 m .44418 .75278 L .44613 .75002 L F
.436 .217 .482 r
.3238 .62558 m .32426 .62334 L .32611 .62263 L F
.853 .878 .857 r
.32281 .72269 m .32045 .72522 L .31898 .72448 L F
.671 .13 0 r
.32045 .72522 m .3204 .72578 L .31898 .72448 L F
.32045 .72522 m .3224 .72721 L .3204 .72578 L F
.875 .549 .431 r
.61068 .7002 m .61109 .7026 L .61379 .70309 L F
.883 .759 .72 r
.61109 .7026 m .61206 .70561 L .61379 .70309 L F
.224 0 0 r
.30399 .64896 m .30352 .64787 L .30527 .64685 L F
.30399 .64896 m .30193 .64943 L .30352 .64787 L F
.926 .568 .331 r
.63998 .50844 m .64159 .50937 L .64096 .50711 L F
.636 .226 .25 r
.52371 .79336 m .52151 .79146 L .5223 .79423 L F
.782 .7 .773 r
.73404 .61752 m .7301 .61995 L .73353 .61721 L F
.742 .993 .854 r
.73404 .61752 m .73353 .61721 L .73507 .61577 L F
.531 .61 .877 r
.33183 .72401 m .33246 .72156 L .33036 .7222 L F
.33183 .72401 m .33375 .72378 L .33246 .72156 L F
.553 0 0 r
.54058 .76443 m .54141 .76398 L .5438 .76536 L F
.08 .64 .73 r
.27892 .65444 m .27517 .65471 L .27588 .65523 L F
.805 .447 0 r
.59274 .68291 m .59148 .68 L .5915 .68124 L F
0 0 0 r
.39022 .64714 m .39009 .64732 L .38911 .64798 L F
.266 .517 .906 r
.30546 .60715 m .3064 .60614 L .30496 .60599 L F
.30546 .60715 m .30848 .60863 L .3064 .60614 L F
.47 .093 .243 r
.57855 .67513 m .58171 .67496 L .58228 .6729 L F
0 0 .08 r
.58228 .6729 m .58322 .67373 L .58438 .67226 L F
.58228 .6729 m .58171 .67496 L .58322 .67373 L F
.475 .538 .841 r
.37648 .69885 m .37537 .70076 L .37389 .6976 L F
.499 .568 .857 r
.37648 .69885 m .37741 .70074 L .37537 .70076 L F
.65 .421 .558 r
.36628 .72258 m .36577 .72497 L .36333 .72468 L F
.41 .198 .478 r
.3676 .72431 m .36628 .72258 L .36766 .72168 L F
.3676 .72431 m .36577 .72497 L .36628 .72258 L F
.419 .371 .698 r
.7409 .71502 m .74251 .71084 L .74018 .71215 L F
.7409 .71502 m .74287 .71407 L .74251 .71084 L F
.907 .739 .241 r
.74282 .71559 m .74287 .71407 L .7409 .71502 L F
.57 .792 .983 r
.72276 .61825 m .72579 .6177 L .72406 .6166 L F
.38 .684 .978 r
.29203 .59164 m .29147 .59286 L .28999 .59184 L F
.29203 .59164 m .29351 .5929 L .29147 .59286 L F
.868 .602 .534 r
.59912 .67247 m .59923 .67479 L .60174 .67524 L F
.882 .561 .436 r
.59923 .67479 m .60194 .67752 L .60174 .67524 L F
.251 0 .16 r
.26103 .61137 m .25977 .61378 L .25802 .61427 L F
.423 .094 .3 r
.26309 .61039 m .25977 .61378 L .26103 .61137 L F
.471 .422 .721 r
.43865 .76655 m .43918 .76969 L .44103 .76853 L F
.422 .373 .699 r
.43992 .7721 m .44103 .76853 L .43918 .76969 L F
.629 .271 .345 r
.50823 .79601 m .5079 .79448 L .51019 .79622 L F
.444 .234 .498 r
.48761 .75103 m .48958 .75221 L .48744 .75264 L F
.539 .313 .521 r
.43963 .68067 m .43739 .68314 L .43736 .68099 L F
.474 .283 .54 r
.75637 .61437 m .75636 .61706 L .75362 .61665 L F
.462 .095 .255 r
.75636 .61706 m .75341 .61871 L .75362 .61665 L F
.687 .169 0 r
.55183 .70176 m .55102 .70024 L .54961 .69967 L F
.55183 .70176 m .55339 .70292 L .55102 .70024 L F
.787 .776 .843 r
.47611 .76615 m .47254 .76616 L .47516 .76299 L F
.805 .711 .761 r
.47611 .76615 m .47373 .76933 L .47254 .76616 L F
.59 .406 .601 r
.47611 .76615 m .47627 .76924 L .47373 .76933 L F
.529 .541 .812 r
.47689 .76303 m .47611 .76615 L .47516 .76299 L F
.47689 .76303 m .47822 .76606 L .47611 .76615 L F
.282 .174 .549 r
.47767 .76787 m .47611 .76615 L .47822 .76606 L F
.47767 .76787 m .47627 .76924 L .47611 .76615 L F
.565 .412 .632 r
.3209 .71647 m .32162 .71919 L .32258 .71727 L F
0 0 0 r
.73511 .58876 m .73592 .5873 L .73383 .59 L F
.527 .052 .072 r
.73835 .58827 m .73592 .5873 L .73511 .58876 L F
.531 .095 .156 r
.73835 .58827 m .73869 .58704 L .73592 .5873 L F
.063 .035 .511 r
.4668 .76521 m .46775 .76276 L .46691 .76373 L F
0 0 .442 r
.62644 .52072 m .62751 .52409 L .62803 .52394 L F
.62802 .52389 m .62803 .52394 L .62804 .52393 L F
.62644 .52072 m .62803 .52394 L .62802 .52389 L F
.912 .807 .73 r
.62777 .52258 m .62973 .5227 L .62827 .52155 L F
0 0 .442 r
.62644 .52072 m .62804 .52393 L .62534 .51969 L F
.788 .496 .494 r
.62534 .51969 m .62804 .52393 L .62719 .52359 L F
.62314 .52143 m .62719 .52359 L .62269 .52178 L F
.62534 .51969 m .62719 .52359 L .62314 .52143 L F
.818 .678 .709 r
.62871 .52463 m .63232 .52278 L .62973 .5227 L F
.912 .807 .73 r
.62734 .52348 m .62871 .52463 L .62973 .5227 L F
.211 .683 .939 r
.62958 .52382 m .62887 .52448 L .62734 .52348 L F
.62887 .52448 m .62871 .52463 L .62795 .524 L F
.62887 .52448 m .62795 .524 L .62734 .52348 L F
.912 .807 .73 r
.62734 .52348 m .6279 .52329 L .62777 .52258 L F
.6279 .52329 m .62973 .5227 L .62777 .52258 L F
.894 .916 .83 r
.62644 .52072 m .62753 .51684 L .62862 .51789 L F
.62644 .52072 m .62534 .51969 L .62753 .51684 L F
.756 .275 .099 r
.4789 .76096 m .47992 .76171 L .47699 .7606 L F
.476 .4 .691 r
.58835 .71415 m .5892 .71722 L .59085 .71619 L F
.877 .442 .141 r
.53349 .75543 m .5319 .75393 L .5335 .7528 L F
.586 .412 .613 r
.53569 .75244 m .53349 .75543 L .5335 .7528 L F
.484 .086 .21 r
.5319 .75393 m .53569 .75244 L .5335 .7528 L F
.275 0 .084 r
.74126 .58663 m .73869 .58704 L .73835 .58827 L F
.427 .093 .294 r
.4859 .73602 m .48813 .73561 L .48886 .73321 L F
.06 0 0 r
.48886 .73321 m .49043 .73288 L .4908 .7323 L F
.314 0 .25 r
.48886 .73321 m .49009 .73489 L .49043 .73288 L F
.48886 .73321 m .48813 .73561 L .49009 .73489 L F
.179 .196 .64 r
.55368 .76673 m .55453 .76285 L .55197 .76357 L F
.55368 .76673 m .55528 .76577 L .55453 .76285 L F
.588 .607 .839 r
.55396 .76906 m .55475 .76707 L .55368 .76673 L F
.55396 .76906 m .55618 .76869 L .55528 .76577 L F
.613 .306 .427 r
.55472 .76859 m .55286 .77058 L .55283 .76846 L F
.55618 .76869 m .5547 .76953 L .55472 .76859 L F
.5547 .76953 m .55286 .77058 L .55472 .76859 L F
.588 .607 .839 r
.55475 .76707 m .55528 .76577 L .55478 .76607 L F
.55475 .76707 m .55478 .76607 L .55368 .76673 L F
.876 .709 .671 r
.61206 .70561 m .61322 .70864 L .61322 .70607 L F
.642 .238 .264 r
.39439 .66662 m .39282 .66833 L .39089 .66677 L F
.513 .086 .167 r
.39645 .66671 m .39282 .66833 L .39439 .66662 L F
0 .504 .742 r
.3993 .64891 m .40266 .64954 L .40075 .64922 L F
.40266 .64954 m .40274 .64956 L .40075 .64922 L F
.241 0 0 r
.39867 .64888 m .40075 .64922 L .40174 .64917 L F
.39733 .64875 m .40075 .64922 L .39867 .64888 L F
.762 .281 .098 r
.56135 .71313 m .55748 .71078 L .5587 .71167 L F
.456 .15 .357 r
.26558 .60892 m .26309 .61039 L .26342 .6092 L F
.663 .501 .655 r
.6004 .71173 m .59757 .71364 L .59627 .71137 L F
.6004 .71173 m .60015 .71368 L .59757 .71364 L F
.364 0 .114 r
.60015 .71368 m .5964 .71624 L .59757 .71364 L F
0 0 .423 r
.61969 .72687 m .61996 .72817 L .6192 .7258 L F
0 0 .428 r
.62075 .72903 m .62072 .73065 L .61996 .72817 L F
.819 .504 .456 r
.61799 .72684 m .62067 .72897 L .61969 .72687 L F
.62067 .72897 m .62075 .72903 L .61969 .72687 L F
0 0 .423 r
.61969 .72687 m .6192 .7258 L .61894 .72497 L F
.376 .835 .907 r
.72772 .5953 m .72922 .59516 L .72842 .59574 L F
.297 0 0 r
.72922 .59516 m .7309 .59607 L .72842 .59574 L F
.633 .804 .965 r
.72842 .59574 m .7309 .59607 L .72886 .59504 L F
.72842 .59574 m .72886 .59504 L .72852 .59581 L F
.72842 .59574 m .72852 .59581 L .72831 .59628 L F
.376 .835 .907 r
.72528 .59552 m .72772 .5953 L .72842 .59574 L F
.297 0 0 r
.72922 .59516 m .73163 .59514 L .7309 .59607 L F
.446 .138 .348 r
.44758 .67549 m .44697 .67741 L .44484 .67779 L F
.584 .3 .45 r
.4498 .67526 m .44697 .67741 L .44758 .67549 L F
.608 .346 .495 r
.47548 .74116 m .47804 .73874 L .47578 .73921 L F
.081 .624 .847 r
.4042 .65019 m .40622 .65033 L .40763 .6507 L F
.343 .786 .961 r
.40622 .65033 m .40977 .6505 L .40763 .6507 L F
.428 .136 .364 r
.52757 .73889 m .52704 .74088 L .52499 .74128 L F
.382 .094 .347 r
.52927 .7397 m .52757 .73889 L .52984 .73845 L F
.52927 .7397 m .52704 .74088 L .52757 .73889 L F
.468 .103 .262 r
.35287 .65751 m .35119 .65637 L .3505 .65797 L F
.745 .694 .802 r
.72144 .58669 m .72422 .58687 L .72095 .58909 L F
.257 0 0 r
.38872 .71309 m .38503 .71525 L .38686 .7136 L F
.311 0 .047 r
.36644 .65207 m .37008 .64969 L .36714 .65099 L F
.36644 .65207 m .36854 .65164 L .37008 .64969 L F
.276 0 .026 r
.37008 .64969 m .37143 .65017 L .37228 .6493 L F
.37008 .64969 m .36854 .65164 L .37143 .65017 L F
.701 .438 .524 r
.57172 .74697 m .57445 .74859 L .57333 .74972 L F
.993 .77 .399 r
.57445 .74859 m .57447 .74946 L .57394 .7491 L F
.701 .438 .524 r
.57172 .74697 m .57437 .74934 L .57445 .74859 L F
.57437 .74934 m .57487 .74978 L .57445 .74859 L F
0 .142 .651 r
.5733 .74799 m .57345 .74817 L .57172 .74697 L F
.993 .77 .399 r
.57394 .7491 m .57448 .75028 L .57333 .74972 L F
.57447 .74946 m .5742 .75093 L .57448 .75028 L F
.57445 .74859 m .57437 .74934 L .57447 .74946 L F
.57447 .74946 m .57448 .75028 L .57394 .7491 L F
.57437 .74934 m .5742 .75093 L .57447 .74946 L F
0 .142 .651 r
.57477 .74967 m .57465 .74959 L .57437 .74934 L F
.57431 .74927 m .57437 .74934 L .57172 .74697 L F
.402 .277 .595 r
.57445 .74859 m .57487 .74978 L .57666 .74872 L F
.616 .782 .961 r
.57666 .74872 m .57487 .74978 L .57465 .74953 L F
.394 .138 .403 r
.57666 .74872 m .57494 .74941 L .57445 .74859 L F
.993 .77 .399 r
.57445 .74859 m .57434 .7493 L .57437 .74934 L F
.394 .138 .403 r
.57533 .75005 m .57434 .7493 L .57445 .74859 L F
.616 .782 .961 r
.57666 .74872 m .57465 .74953 L .5733 .74799 L F
.394 .138 .403 r
.57666 .74872 m .57533 .75005 L .57494 .74941 L F
0 .142 .651 r
.57477 .74967 m .57437 .74934 L .57434 .7493 L F
.57477 .74967 m .57434 .7493 L .57441 .74935 L F
.993 .77 .399 r
.57437 .74934 m .57402 .75135 L .5742 .75093 L F
.57434 .7493 m .57402 .75135 L .57437 .74934 L F
0 .142 .651 r
.57477 .74967 m .57487 .74978 L .57465 .74959 L F
.095 .154 .634 r
.57402 .75135 m .57365 .75437 L .57375 .75388 L F
0 0 .271 r
.57378 .75092 m .57402 .75135 L .57336 .75001 L F
.095 .154 .634 r
.57402 .75135 m .57375 .75388 L .5742 .75167 L F
.57402 .75135 m .57494 .75391 L .57365 .75437 L F
0 0 .271 r
.57452 .75254 m .57402 .75135 L .57378 .75092 L F
.095 .154 .634 r
.57402 .75135 m .5742 .75167 L .57448 .75028 L F
.394 .138 .403 r
.57533 .75005 m .57402 .75135 L .57434 .7493 L F
0 .142 .651 r
.57345 .74817 m .57477 .74967 L .57431 .74927 L F
.849 .877 .861 r
.57419 .74968 m .57402 .75135 L .57666 .74872 L F
.57336 .75001 m .57402 .75135 L .57419 .74968 L F
0 .142 .651 r
.57441 .74935 m .57434 .7493 L .57431 .74927 L F
.57345 .74817 m .57431 .74927 L .57172 .74697 L F
.035 0 0 r
.56047 .68195 m .55824 .68319 L .56072 .68239 L F
0 .282 .775 r
.56194 .68213 m .56047 .68195 L .56072 .68239 L F
.203 0 0 r
.53539 .79823 m .53624 .79878 L .53423 .79678 L F
.29 .123 .473 r
.49838 .72512 m .50008 .7267 L .50072 .72494 L F
.49838 .72512 m .49934 .72798 L .50008 .7267 L F
.446 .485 .806 r
.4403 .65652 m .44298 .65793 L .44112 .65796 L F
.713 .741 .873 r
.59121 .75743 m .59264 .75895 L .59453 .75782 L F
.808 .79 .836 r
.72429 .7168 m .72167 .71642 L .72324 .7146 L F
.778 .361 .259 r
.72429 .7168 m .7231 .71795 L .72167 .71642 L F
.576 .595 .835 r
.72525 .7135 m .72429 .7168 L .72324 .7146 L F
.72525 .7135 m .72634 .71754 L .72429 .7168 L F
0 .264 .674 r
.72429 .7168 m .72563 .71742 L .7231 .71795 L F
.276 .707 .966 r
.30483 .59368 m .30834 .59447 L .30645 .59435 L F
.815 .685 .721 r
.61007 .70799 m .61322 .70864 L .61206 .70561 L F
.839 .613 .597 r
.61007 .70799 m .6132 .7111 L .61322 .70864 L F
.063 .551 .892 r
.58494 .75349 m .58744 .75369 L .58423 .7526 L F
.58494 .75349 m .58942 .75476 L .58744 .75369 L F
.422 .373 .699 r
.43992 .7721 m .44167 .77167 L .44103 .76853 L F
.413 .339 .664 r
.43992 .7721 m .44203 .77413 L .44167 .77167 L F
.519 .346 .586 r
.43992 .7721 m .4399 .77455 L .44203 .77413 L F
.353 .001 .221 r
.35923 .65357 m .35657 .65561 L .35882 .65546 L F
.517 .215 .394 r
.36099 .65513 m .35923 .65357 L .35882 .65546 L F
.36099 .65513 m .36144 .65335 L .35923 .65357 L F
.647 .187 .147 r
.58366 .67751 m .58186 .67783 L .58009 .6773 L F
.637 .171 .131 r
.58366 .67751 m .58551 .67829 L .58186 .67783 L F
.606 .462 .659 r
.33814 .68902 m .34074 .68899 L .34038 .68627 L F
.461 .336 .624 r
.33895 .69219 m .34074 .68899 L .33814 .68902 L F
.828 .729 .754 r
.67741 .51784 m .67574 .51822 L .67777 .51531 L F
.727 .603 .718 r
.67853 .52043 m .67574 .51822 L .67741 .51784 L F
.689 .555 .698 r
.68074 .51809 m .67853 .52043 L .67741 .51784 L F
.531 .198 .348 r
.46221 .74684 m .46484 .74665 L .46548 .74452 L F
.429 .103 .31 r
.46548 .74452 m .46685 .74613 L .46771 .74419 L F
.46548 .74452 m .46484 .74665 L .46685 .74613 L F
0 0 .503 r
.54679 .74321 m .54676 .74396 L .54644 .74421 L F
.196 0 0 r
.54679 .74321 m .5506 .74174 L .54676 .74396 L F
.54679 .74321 m .54875 .743 L .5506 .74174 L F
.49 .307 .56 r
.54949 .74185 m .54875 .743 L .54679 .74321 L F
.866 .793 .777 r
.54712 .74314 m .54875 .743 L .54949 .74185 L F
0 0 .351 r
.54644 .74421 m .54723 .74558 L .54679 .74321 L F
.54723 .74558 m .54726 .74564 L .54722 .74544 L F
.54723 .74558 m .54722 .74544 L .54679 .74321 L F
.959 .623 .312 r
.54679 .74321 m .54726 .74564 L .5457 .74391 L F
.866 .793 .777 r
.5457 .74391 m .54713 .74348 L .54712 .74314 L F
.54713 .74348 m .54875 .743 L .54712 .74314 L F
.24 .174 .578 r
.7105 .59401 m .70871 .59273 L .7112 .59233 L F
.7105 .59401 m .70871 .59521 L .70871 .59273 L F
.424 .131 .361 r
.50491 .71414 m .50684 .71371 L .50746 .71202 L F
.61 .315 .444 r
.50746 .71202 m .50888 .71297 L .50987 .71125 L F
.50746 .71202 m .50684 .71371 L .50888 .71297 L F
.811 .429 .331 r
.55527 .70209 m .55814 .70302 L .5565 .70053 L F
.823 .427 .3 r
.5565 .70053 m .55814 .70302 L .55988 .70309 L F
.431 .862 .932 r
.41349 .66457 m .41196 .66449 L .40987 .66505 L F
.471 .422 .721 r
.43865 .76655 m .44103 .76853 L .4409 .76617 L F
.72 .624 .75 r
.59863 .70863 m .6004 .71173 L .59627 .71137 L F
.908 .756 .681 r
.59937 .70269 m .59661 .70232 L .59778 .69896 L F
.819 .611 .622 r
.59937 .70269 m .59543 .70491 L .59661 .70232 L F
.59937 .70269 m .59752 .70526 L .59543 .70491 L F
.145 .559 .927 r
.75924 .60749 m .76015 .60842 L .75673 .60735 L F
.513 .508 .788 r
.75673 .60735 m .76015 .60842 L .75833 .60926 L F
.145 .559 .927 r
.75924 .60749 m .75673 .60735 L .75697 .60787 L F
.383 .434 .79 r
.44124 .78018 m .44228 .78305 L .44308 .78108 L F
.47 .534 .841 r
.44228 .78305 m .44435 .783 L .44308 .78108 L F
.522 0 0 r
.56999 .76091 m .56863 .76115 L .56636 .76041 L F
0 0 .37 r
.56999 .76091 m .57122 .76359 L .57085 .76237 L F
.853 .878 .857 r
.32281 .72269 m .31898 .72448 L .32124 .72218 L F
.806 .912 .912 r
.32281 .72269 m .32124 .72218 L .32309 .72122 L F
.087 0 0 r
.39748 .70916 m .39592 .71077 L .39452 .7107 L F
.078 0 0 r
.39592 .71077 m .39377 .71136 L .39452 .7107 L F
.039 0 0 r
.3949 .69797 m .39536 .69872 L .39695 .69744 L F
.3949 .69797 m .39376 .69914 L .39536 .69872 L F
.102 0 0 r
.3933 .69905 m .39671 .69837 L .39536 .69872 L F
.137 0 0 r
.39695 .69744 m .39536 .69872 L .39747 .69822 L F
.102 0 0 r
.39671 .69837 m .39747 .69822 L .39536 .69872 L F
.039 0 0 r
.39376 .69914 m .39342 .69949 L .39536 .69872 L F
.41 .17 .435 r
.32198 .62826 m .32184 .63077 L .31972 .63097 L F
.268 .059 .4 r
.32332 .62991 m .32198 .62826 L .32384 .62762 L F
.32332 .62991 m .32184 .63077 L .32198 .62826 L F
.243 0 0 r
.58667 .67191 m .58888 .67153 L .59007 .67028 L F
.663 .193 .127 r
.59007 .67028 m .58888 .67153 L .59227 .6719 L F
.605 .743 .942 r
.51579 .79151 m .51333 .79033 L .51443 .79074 L F
.969 .672 .406 r
.51592 .79372 m .51579 .79151 L .51443 .79074 L F
.518 .125 .235 r
.52914 .76274 m .52787 .76175 L .52559 .76439 L F
.63 .544 .739 r
.44418 .75278 m .44667 .75268 L .44613 .75002 L F
.56 .316 .502 r
.44408 .75507 m .44667 .75268 L .44418 .75278 L F
.461 .336 .624 r
.33895 .69219 m .34085 .69167 L .34074 .68899 L F
.484 .41 .697 r
.33895 .69219 m .34125 .69412 L .34085 .69167 L F
.456 .409 .716 r
.33895 .69219 m .3396 .69464 L .34125 .69412 L F
.506 .347 .6 r
.34055 .67256 m .34257 .67446 L .34249 .67202 L F
.34055 .67256 m .34054 .67499 L .34257 .67446 L F
.499 .744 .982 r
.74829 .58405 m .74714 .58551 L .7462 .58454 L F
.74829 .58405 m .75031 .58551 L .74714 .58551 L F
.37 .022 .239 r
.37688 .67677 m .37588 .67539 L .37761 .67514 L F
.37688 .67677 m .37483 .67726 L .37588 .67539 L F
.463 .485 .796 r
.33637 .71895 m .3374 .71605 L .3348 .71637 L F
.33637 .71895 m .33822 .7191 L .3374 .71605 L F
.651 .547 .723 r
.3369 .7197 m .33458 .7233 L .33835 .7221 L F
.841 .711 .181 r
.3369 .7197 m .33664 .72091 L .33666 .72073 L F
.474 .322 .595 r
.33375 .72378 m .3369 .7197 L .33246 .72156 L F
.33375 .72378 m .33458 .7233 L .3369 .7197 L F
.841 .711 .181 r
.3369 .7197 m .33666 .72073 L .33686 .71835 L F
.3369 .7197 m .33822 .7191 L .33707 .71901 L F
.3369 .7197 m .33707 .71901 L .33637 .71895 L F
0 0 0 r
.53569 .75244 m .53708 .75199 L .539 .74974 L F
.275 0 .011 r
.539 .74974 m .53708 .75199 L .53911 .7515 L F
.211 0 0 r
.52804 .76607 m .5268 .76649 L .52458 .76654 L F
.307 0 0 r
.52804 .76607 m .52913 .76658 L .5268 .76649 L F
.52804 .76607 m .53028 .76685 L .52913 .76658 L F
.223 0 .243 r
.3175 .63391 m .31686 .63601 L .31521 .63686 L F
.314 .084 .396 r
.31972 .63097 m .31933 .63354 L .3175 .63391 L F
.235 0 .248 r
.31855 .6352 m .3175 .63391 L .31933 .63354 L F
.31855 .6352 m .31686 .63601 L .3175 .63391 L F
.784 .484 0 r
.70214 .59212 m .70315 .59542 L .70267 .59421 L F
0 0 .55 r
.70404 .59681 m .70267 .59421 L .70315 .59542 L F
.34 .693 .982 r
.32148 .59526 m .3208 .59619 L .31938 .59544 L F
.32148 .59526 m .32347 .59648 L .3208 .59619 L F
.494 .227 .439 r
.54532 .75561 m .54769 .75492 L .54739 .75319 L F
.5 .365 .629 r
.54769 .75492 m .5493 .75191 L .54739 .75319 L F
.871 .65 .6 r
.59158 .72762 m .5926 .7284 L .59424 .72793 L F
.898 .813 .755 r
.59424 .72793 m .5926 .7284 L .59277 .72798 L F
.074 .472 .89 r
.59177 .72702 m .59245 .72816 L .59158 .72762 L F
.59245 .72816 m .5926 .7284 L .59158 .72762 L F
.801 .393 .278 r
.59311 .7278 m .59216 .72798 L .59158 .72762 L F
.59216 .72798 m .59199 .72801 L .59158 .72762 L F
.59424 .72793 m .59277 .72798 L .59311 .7278 L F
.59277 .72798 m .59199 .72801 L .59311 .7278 L F
.829 .58 .562 r
.58705 .72351 m .58779 .72486 L .58967 .72207 L F
0 0 .418 r
.58777 .72473 m .58779 .72486 L .58705 .72351 L F
.746 .895 .501 r
.58785 .72523 m .58779 .72486 L .58784 .72524 L F
.58912 .72301 m .58779 .72486 L .58785 .72523 L F
.77 .816 .34 r
.58779 .72486 m .58706 .72723 L .58784 .72524 L F
.617 .611 .822 r
.58779 .72486 m .58994 .72751 L .58706 .72723 L F
.074 .472 .89 r
.59137 .7268 m .58994 .72751 L .58779 .72486 L F
.724 .387 .407 r
.59043 .72689 m .59034 .72682 L .58843 .72585 L F
.59034 .72682 m .58779 .72486 L .58843 .72585 L F
0 0 .418 r
.58843 .72585 m .58779 .72486 L .58777 .72473 L F
.58779 .72486 m .58706 .72723 L .58843 .72585 L F
.58843 .72585 m .58706 .72723 L .58779 .72486 L F
.772 .359 .268 r
.58719 .72547 m .58843 .72585 L .58777 .72473 L F
.686 .718 .874 r
.58738 .72531 m .58843 .72585 L .58719 .72546 L F
.074 .472 .89 r
.59177 .72702 m .59149 .72709 L .59137 .7268 L F
.724 .387 .407 r
.59043 .72689 m .59177 .72702 L .58779 .72486 L F
.686 .718 .874 r
.59003 .72325 m .58843 .72585 L .58738 .72531 L F
.746 .895 .501 r
.58967 .72207 m .58852 .72378 L .58912 .72301 L F
.58852 .72378 m .58779 .72486 L .58912 .72301 L F
.772 .359 .268 r
.58719 .72546 m .58719 .72547 L .58705 .72351 L F
.58719 .72547 m .58777 .72473 L .58705 .72351 L F
.074 .472 .89 r
.59149 .72709 m .58994 .72751 L .59137 .7268 L F
.749 .625 .722 r
.59238 .72554 m .59118 .72637 L .59276 .72416 L F
.59118 .72637 m .59043 .72689 L .59108 .72613 L F
.59118 .72637 m .59108 .72613 L .59276 .72416 L F
.59276 .72416 m .59043 .72689 L .59226 .72419 L F
.963 .931 .707 r
.59455 .72366 m .59277 .72798 L .59193 .72717 L F
.59455 .72366 m .59193 .72717 L .59207 .72666 L F
.898 .813 .755 r
.59424 .72793 m .59277 .72798 L .59455 .72366 L F
.963 .931 .707 r
.59455 .72366 m .59177 .72702 L .59459 .72402 L F
.749 .625 .722 r
.59459 .72402 m .59238 .72554 L .59276 .72416 L F
.963 .931 .707 r
.59207 .72666 m .59193 .72717 L .59177 .72702 L F
.59277 .72798 m .5926 .7284 L .59245 .72816 L F
.59277 .72798 m .59245 .72816 L .59177 .72702 L F
.801 .393 .278 r
.59424 .72793 m .59347 .72944 L .59199 .72801 L F
.699 .806 .344 r
.59424 .72793 m .59311 .73044 L .59347 .72944 L F
.149 .422 .863 r
.59347 .72944 m .5942 .72844 L .5939 .72826 L F
.59347 .72944 m .5939 .72826 L .59177 .72702 L F
.699 .806 .344 r
.59311 .73044 m .59294 .73082 L .59347 .72944 L F
.769 .712 .799 r
.63409 .50188 m .63096 .50149 L .63321 .50043 L F
.259 .701 .96 r
.63321 .50043 m .63646 .50104 L .63409 .50188 L F
.875 .761 .733 r
.71687 .58922 m .71923 .58975 L .71957 .58797 L F
.759 .273 .081 r
.7182 .59079 m .71923 .58975 L .71687 .58922 L F
.31 .219 .588 r
.71957 .58797 m .71923 .58975 L .72093 .58901 L F
.444 0 0 r
.71923 .58975 m .72243 .59015 L .71941 .59149 L F
.601 .262 .367 r
.7182 .59079 m .72093 .58901 L .71923 .58975 L F
.535 .314 .527 r
.41971 .68098 m .42209 .6806 L .42232 .678 L F
.593 .464 .673 r
.42232 .678 m .42458 .67772 L .42417 .6749 L F
.477 .228 .456 r
.42209 .6806 m .42458 .67772 L .42232 .678 L F
.533 0 0 r
.50508 .75545 m .5014 .75386 L .50198 .75482 L F
.50508 .75545 m .50232 .75462 L .5014 .75386 L F
.468 .817 .998 r
.50617 .75436 m .50508 .75545 L .50742 .75268 L F
.50617 .75436 m .50232 .75462 L .50508 .75545 L F
.709 .839 .945 r
.7422 .61532 m .73906 .61507 L .74088 .61393 L F
.251 .76 .866 r
.32258 .71727 m .32592 .7168 L .32632 .71698 L F
0 0 .336 r
.32258 .71727 m .32398 .71746 L .32592 .7168 L F
.297 0 0 r
.32398 .71746 m .32554 .71663 L .32592 .7168 L F
.32554 .71663 m .32767 .71549 L .32592 .7168 L F
.251 .76 .866 r
.32632 .71698 m .32592 .7168 L .32713 .71692 L F
.723 .976 .923 r
.32713 .71692 m .32592 .7168 L .32767 .71549 L F
.38 0 .089 r
.32608 .71716 m .32713 .71655 L .32767 .71549 L F
.695 .8 .334 r
.32813 .7146 m .32713 .71692 L .32767 .71549 L F
.38 0 .089 r
.32713 .71655 m .32974 .71504 L .32767 .71549 L F
.695 .8 .334 r
.32848 .71379 m .32813 .7146 L .32767 .71549 L F
.968 .808 .629 r
.59913 .70609 m .59748 .70762 L .59752 .70526 L F
.59913 .70609 m .59863 .70863 L .59748 .70762 L F
.555 .374 .591 r
.53166 .76075 m .53397 .7575 L .53201 .75814 L F
.638 .334 .439 r
.45408 .7494 m .45746 .74715 L .45409 .74692 L F
.45408 .7494 m .45647 .74948 L .45746 .74715 L F
.657 .354 .448 r
.45746 .74715 m .45647 .74948 L .45967 .74924 L F
.618 .363 .509 r
.45746 .74715 m .45967 .74924 L .45988 .74707 L F
.1 0 0 r
.39795 .71004 m .39748 .70916 L .39958 .70873 L F
.39795 .71004 m .39592 .71077 L .39748 .70916 L F
.766 .693 .782 r
.47373 .76933 m .47029 .76911 L .47254 .76616 L F
.154 .684 .862 r
.47301 .76929 m .47248 .76907 L .47029 .76911 L F
.513 0 0 r
.47248 .76907 m .47328 .76996 L .47168 .76873 L F
.293 .733 .965 r
.47029 .76911 m .47248 .76907 L .47111 .76829 L F
.513 0 0 r
.47248 .76907 m .47168 .76873 L .47111 .76829 L F
.154 .684 .862 r
.47373 .76933 m .47248 .76907 L .47301 .76929 L F
.672 .23 .191 r
.47627 .76924 m .47248 .76907 L .47373 .76933 L F
.379 .753 .991 r
.55447 .70939 m .55386 .70873 L .55196 .70875 L F
.669 .119 0 r
.55748 .71078 m .55386 .70873 L .55447 .70939 L F
.005 0 .103 r
.49681 .78131 m .49791 .78186 L .49871 .78011 L F
.504 .299 .535 r
.75103 .60577 m .74867 .60602 L .74858 .60878 L F
.002 .559 .813 r
.32566 .70277 m .32709 .70321 L .32411 .70255 L F
.32411 .70255 m .32709 .70321 L .32566 .70277 L F
.655 .926 .974 r
.3275 .70182 m .32709 .70321 L .32566 .70277 L F
.3275 .70182 m .32709 .70321 L .32566 .70277 L F
.002 .559 .813 r
.32566 .70277 m .32709 .70321 L .32411 .70255 L F
.734 .256 .11 r
.55814 .70302 m .55868 .70407 L .55988 .70309 L F
0 0 .507 r
.56098 .70421 m .55988 .70309 L .55868 .70407 L F
.746 .344 .29 r
.55988 .70309 m .56192 .70537 L .56364 .70463 L F
0 0 .507 r
.56098 .70421 m .56192 .70537 L .55988 .70309 L F
0 0 0 r
.4908 .7323 m .49364 .73148 L .4913 .73185 L F
.328 .003 .254 r
.40969 .68844 m .41154 .68857 L .41247 .68626 L F
.427 .097 .301 r
.41247 .68626 m .4137 .68809 L .41468 .68592 L F
.41247 .68626 m .41154 .68857 L .4137 .68809 L F
.237 .726 .924 r
.26064 .5869 m .26267 .58682 L .2642 .58724 L F
.328 .765 .967 r
.26267 .58682 m .26633 .5872 L .2642 .58724 L F
.977 .895 .674 r
.62815 .51016 m .62658 .51144 L .62753 .50869 L F
.62815 .51016 m .6274 .51242 L .62658 .51144 L F
.76 .335 .243 r
.56192 .70537 m .56549 .70732 L .56364 .70463 L F
.605 .335 .482 r
.46111 .76682 m .46294 .76828 L .45887 .76845 L F
.601 .419 .608 r
.46294 .76828 m .45866 .7719 L .45887 .76845 L F
.46294 .76828 m .4616 .77311 L .45866 .7719 L F
.173 .012 .408 r
.46305 .76859 m .4616 .77311 L .46294 .76828 L F
.46327 .76926 m .46323 .76936 L .46305 .76859 L F
.46323 .76936 m .4616 .77311 L .46305 .76859 L F
.653 .296 .355 r
.46451 .7665 m .46324 .76877 L .46305 .76859 L F
.68 .28 .281 r
.46111 .76682 m .46305 .76859 L .46294 .76828 L F
.653 .296 .355 r
.46259 .76668 m .46305 .76859 L .46111 .76682 L F
.68 .28 .281 r
.46305 .76859 m .46324 .76877 L .46294 .76828 L F
.653 .296 .355 r
.46451 .7665 m .46305 .76859 L .46259 .76668 L F
.173 .012 .408 r
.46332 .76916 m .46327 .76926 L .46294 .76828 L F
.626 .573 .774 r
.4668 .76521 m .46451 .7665 L .46336 .76313 L F
.6 .238 .326 r
.46631 .76815 m .46451 .7665 L .4668 .76521 L F
.46631 .76815 m .46324 .76877 L .46451 .7665 L F
.631 .531 .722 r
.50338 .71994 m .50476 .71639 L .50358 .71689 L F
.693 .963 .941 r
.26535 .64504 m .26545 .64466 L .26685 .64376 L F
.642 .924 .975 r
.26488 .64494 m .26545 .64466 L .26535 .64504 L F
0 0 0 r
.50291 .73107 m .50201 .73264 L .50058 .73334 L F
0 0 .515 r
.50147 .7342 m .50058 .73334 L .50201 .73264 L F
.50147 .7342 m .50249 .73555 L .50058 .73334 L F
.773 .551 .597 r
.727 .58908 m .73036 .58708 L .72688 .58739 L F
.727 .58908 m .73035 .58963 L .73036 .58708 L F
.587 .341 .512 r
.65607 .5373 m .65616 .53928 L .65392 .5395 L F
.633 .377 .512 r
.65607 .5373 m .65858 .53936 L .65616 .53928 L F
.595 .388 .57 r
.65852 .53716 m .65858 .53936 L .65607 .5373 L F
.674 .401 .5 r
.47292 .78026 m .47686 .78084 L .47675 .78019 L F
.809 .424 .327 r
.47686 .78084 m .47823 .78277 L .47675 .78019 L F
.811 .425 .323 r
.47675 .78019 m .47823 .78277 L .4797 .78252 L F
.523 .315 .54 r
.4297 .68647 m .42956 .6888 L .4274 .68923 L F
.551 .337 .542 r
.43187 .68614 m .42956 .6888 L .4297 .68647 L F
.544 .832 .495 r
.7475 .62111 m .74621 .62255 L .74634 .62244 L F
.332 .493 .868 r
.44132 .65507 m .4403 .65652 L .43934 .65488 L F
.44132 .65507 m .44298 .65793 L .4403 .65652 L F
.59 .089 0 r
.56242 .71394 m .56343 .71527 L .56135 .71313 L F
.56242 .71394 m .56446 .71624 L .56343 .71527 L F
.763 .251 0 r
.56591 .71674 m .56446 .71624 L .56242 .71394 L F
.85 .836 .831 r
.58751 .70818 m .58822 .70507 L .58943 .70591 L F
.717 .567 .685 r
.58943 .70591 m .59004 .7088 L .58751 .70818 L F
.492 .827 .999 r
.59044 .70489 m .5925 .70564 L .58943 .70591 L F
.46 .777 .998 r
.58822 .70507 m .59044 .70489 L .58943 .70591 L F
.58822 .70507 m .59044 .70489 L .58943 .70591 L F
.66 .531 .695 r
.59242 .7064 m .58943 .70591 L .5925 .70564 L F
.59242 .7064 m .59004 .7088 L .58943 .70591 L F
.574 .5 .733 r
.33923 .68083 m .3408 .67807 L .33874 .67841 L F
.534 .41 .658 r
.33874 .67841 m .3408 .67807 L .34054 .67499 L F
.522 .676 .935 r
.33415 .59936 m .33347 .60139 L .33208 .59965 L F
.33415 .59936 m .33555 .60124 L .33347 .60139 L F
.332 .047 .321 r
.40969 .68844 m .41103 .69036 L .41154 .68857 L F
.40969 .68844 m .40912 .69106 L .41103 .69036 L F
.514 .526 .806 r
.3457 .72196 m .34786 .72398 L .34647 .72242 L F
.34786 .72398 m .34873 .72481 L .34647 .72242 L F
.375 .684 .978 r
.3461 .72199 m .34647 .72242 L .34635 .72199 L F
.295 0 0 r
.3457 .72196 m .34647 .72242 L .34379 .72197 L F
.375 .684 .978 r
.34379 .72197 m .34647 .72242 L .3461 .72199 L F
.473 .258 .506 r
.65958 .51243 m .65925 .51416 L .65697 .51515 L F
.65925 .51416 m .65919 .51448 L .65821 .51477 L F
.65925 .51416 m .65821 .51477 L .65697 .51515 L F
.65919 .51448 m .65917 .51457 L .6591 .51459 L F
.788 .555 .584 r
.65958 .51243 m .65917 .51457 L .65596 .51429 L F
.552 .33 .532 r
.66154 .51403 m .65917 .51457 L .65958 .51243 L F
.66154 .51403 m .65917 .51457 L .65958 .51243 L F
.514 .295 .52 r
.65967 .51396 m .65917 .51457 L .65958 .51243 L F
.788 .555 .584 r
.65958 .51243 m .65596 .51429 L .65967 .51396 L F
.03 0 .418 r
.65958 .51243 m .66083 .51089 L .66059 .51202 L F
.279 .337 .744 r
.66059 .51202 m .6608 .51246 L .65958 .51243 L F
.6608 .51246 m .66154 .51403 L .66096 .51356 L F
.6608 .51246 m .66096 .51356 L .65958 .51243 L F
.03 0 .418 r
.65958 .51243 m .65967 .51382 L .66033 .5115 L F
.65967 .51382 m .65967 .51396 L .66033 .5115 L F
.66033 .5115 m .65967 .51396 L .66083 .51089 L F
.658 .622 .802 r
.66055 .51067 m .6597 .51389 L .65707 .50805 L F
.66083 .51089 m .66065 .51137 L .66055 .51067 L F
.66065 .51137 m .6597 .51389 L .66055 .51067 L F
.6597 .51389 m .65967 .51396 L .65966 .51392 L F
.6597 .51389 m .65966 .51392 L .65707 .50805 L F
.768 .674 .759 r
.65707 .50805 m .65966 .51392 L .65471 .51092 L F
.65966 .51392 m .65967 .51396 L .65964 .51394 L F
.65966 .51392 m .65964 .51394 L .65471 .51092 L F
.473 .258 .506 r
.65919 .51448 m .6591 .51459 L .65697 .51515 L F
.605 .544 .759 r
.33997 .69761 m .34125 .69412 L .3396 .69464 L F
.468 .509 .817 r
.34188 .60584 m .3403 .60631 L .33901 .60315 L F
.413 .314 .633 r
.34188 .60584 m .34226 .60822 L .3403 .60631 L F
.476 .319 .588 r
.3403 .60631 m .34226 .60822 L .34036 .60906 L F
.116 0 0 r
.73622 .59375 m .73718 .59265 L .73948 .59198 L F
.517 .048 .08 r
.58908 .67781 m .58827 .67926 L .58551 .67829 L F
.677 .334 .386 r
.59076 .67838 m .59148 .68 L .58908 .67781 L F
.574 .868 .995 r
.40769 .66524 m .40568 .66476 L .40387 .66524 L F
.106 .651 .834 r
.40987 .66505 m .40568 .66476 L .40769 .66524 L F
.128 .561 .922 r
.27388 .58783 m .27311 .58825 L .27186 .58751 L F
.27388 .58783 m .27534 .58893 L .27311 .58825 L F
.597 .494 .708 r
.3284 .70655 m .32808 .70853 L .33056 .70779 L F
.529 .56 .831 r
.32808 .70853 m .33118 .71105 L .33056 .70779 L F
.208 .724 .877 r
.28439 .65416 m .28271 .65386 L .28069 .65409 L F
.338 .802 .931 r
.28648 .65383 m .28271 .65386 L .28439 .65416 L F
.55 .871 .994 r
.73511 .58876 m .73383 .59 L .73284 .58941 L F
.62 .467 .653 r
.44586 .74623 m .44844 .74947 L .44717 .74634 L F
.44586 .74623 m .44613 .75002 L .44844 .74947 L F
0 0 .227 r
.57466 .7557 m .57408 .75544 L .57467 .75541 L F
.743 .714 .182 r
.57458 .75503 m .57447 .75618 L .57469 .75513 L F
.921 .695 .578 r
.57494 .75391 m .57519 .75595 L .57365 .75437 L F
.743 .714 .182 r
.57471 .75462 m .57469 .75513 L .57494 .75391 L F
.57458 .75503 m .57469 .75513 L .57471 .75462 L F
0 0 .227 r
.57467 .75541 m .57408 .75544 L .57365 .75437 L F
.57519 .75595 m .57466 .7557 L .57467 .75541 L F
.57519 .75595 m .57382 .75795 L .57408 .75544 L F
.356 .097 .377 r
.32184 .63077 m .31933 .63354 L .31972 .63097 L F
.558 .814 .993 r
.65364 .5054 m .65228 .50694 L .65124 .50618 L F
.65364 .5054 m .65457 .50639 L .65228 .50694 L F
.959 .653 .233 r
.65457 .50639 m .65124 .50618 L .65228 .50694 L F
.48 .894 .797 r
.53483 .76601 m .53252 .76703 L .53287 .76697 L F
.324 0 0 r
.53028 .76685 m .53287 .76697 L .53107 .76767 L F
.48 .894 .797 r
.53252 .76703 m .53107 .76767 L .53287 .76697 L F
.087 0 0 r
.53325 .76691 m .53287 .76697 L .53028 .76685 L F
.53384 .76692 m .53287 .76697 L .53325 .76691 L F
.526 .91 .763 r
.53561 .76586 m .53483 .76601 L .53384 .76692 L F
0 0 0 r
.33193 .71861 m .33071 .71969 L .33292 .7175 L F
.63 .744 .93 r
.32904 .72081 m .33071 .71969 L .33193 .71861 L F
.32904 .72081 m .33246 .72156 L .33071 .71969 L F
.733 .738 .855 r
.34583 .71421 m .34399 .71662 L .34693 .71676 L F
.286 0 .156 r
.34428 .71903 m .34693 .71676 L .34399 .71662 L F
.34428 .71903 m .34596 .71876 L .34693 .71676 L F
.285 .467 .864 r
.34693 .71676 m .34807 .71583 L .34583 .71421 L F
.464 .091 .245 r
.34693 .71676 m .34861 .71803 L .34807 .71583 L F
.34693 .71676 m .34596 .71876 L .34861 .71803 L F
.08 .64 .73 r
.27892 .65444 m .27685 .65456 L .27517 .65471 L F
.437 .874 .894 r
.27889 .65385 m .27892 .65444 L .28069 .65409 L F
.27889 .65385 m .27685 .65456 L .27892 .65444 L F
.713 .378 .41 r
.72422 .58687 m .727 .58908 L .72688 .58739 L F
.391 0 0 r
.3821 .64849 m .38438 .64842 L .38716 .6463 L F
.297 0 0 r
.38438 .64842 m .39022 .64714 L .38716 .6463 L F
.919 .563 .342 r
.58839 .72136 m .58898 .72028 L .58827 .71937 L F
.58839 .72136 m .58967 .72207 L .58898 .72028 L F
.43 .352 .668 r
.5892 .71722 m .58898 .72028 L .59115 .71871 L F
.615 .433 .612 r
.58898 .72028 m .59244 .71993 L .59115 .71871 L F
.58898 .72028 m .58967 .72207 L .59244 .71993 L F
.59244 .71993 m .58967 .72207 L .58898 .72028 L F
.333 0 0 r
.33056 .70779 m .33403 .70875 L .33407 .70847 L F
.639 .087 0 r
.33403 .70875 m .33407 .70847 L .33368 .70818 L F
0 .46 .858 r
.33368 .70818 m .33408 .70876 L .33402 .70873 L F
.33367 .70817 m .33402 .70873 L .33143 .70724 L F
.33168 .7073 m .33143 .70724 L .3311 .70705 L F
.33367 .70817 m .33143 .70724 L .33168 .7073 L F
.218 .588 .946 r
.3311 .70705 m .33408 .70876 L .33056 .70779 L F
.514 .536 .816 r
.33289 .70652 m .33368 .70818 L .3311 .70705 L F
.333 .191 .534 r
.33203 .70741 m .333 .70934 L .33293 .70763 L F
.33204 .7074 m .33293 .70763 L .33289 .70652 L F
.33203 .70741 m .33293 .70763 L .33204 .7074 L F
.963 .691 .47 r
.333 .70934 m .33439 .70991 L .3336 .70813 L F
.33293 .70763 m .3336 .70813 L .33289 .70652 L F
.333 .70934 m .3336 .70813 L .33293 .70763 L F
0 .46 .858 r
.33368 .70818 m .33369 .70819 L .33367 .70817 L F
.33369 .70819 m .33402 .70873 L .33367 .70817 L F
.639 .087 0 r
.334 .70895 m .33403 .70875 L .33368 .70818 L F
.33439 .70991 m .33407 .70847 L .334 .70895 L F
.333 0 0 r
.33403 .70875 m .33408 .70876 L .33407 .70847 L F
.708 .32 0 r
.33407 .70847 m .33408 .70876 L .33368 .70818 L F
.639 .087 0 r
.33439 .70991 m .33686 .71054 L .33407 .70847 L F
.622 .175 .167 r
.48294 .793 m .48419 .79145 L .48628 .79296 L F
.935 .875 .752 r
.32721 .72104 m .32633 .72535 L .32819 .72267 L F
.32721 .72104 m .325 .72476 L .32633 .72535 L F
.31 .219 .588 r
.71957 .58797 m .72093 .58901 L .72144 .58669 L F
.64 .126 .007 r
.47559 .79062 m .47874 .79104 L .47704 .79139 L F
.675 .194 .101 r
.47874 .79104 m .47933 .79308 L .47704 .79139 L F
.47874 .79104 m .48081 .79261 L .47933 .79308 L F
.393 .014 .195 r
.27121 .60592 m .2698 .60824 L .26766 .60862 L F
.295 0 .138 r
.27171 .6076 m .27121 .60592 L .27331 .60569 L F
.27171 .6076 m .2698 .60824 L .27121 .60592 L F
.489 .29 .538 r
.50491 .71414 m .50476 .71639 L .50684 .71371 L F
.574 .5 .733 r
.33923 .68083 m .34149 .6805 L .3408 .67807 L F
.521 .377 .626 r
.33923 .68083 m .34134 .68263 L .34149 .6805 L F
.33923 .68083 m .33947 .68307 L .34134 .68263 L F
.572 .305 .473 r
.65392 .5395 m .6506 .54239 L .65065 .54023 L F
.634 .915 .98 r
.30192 .60639 m .30311 .60692 L .30496 .60599 L F
.591 .565 .793 r
.44594 .66094 m .4451 .6654 L .44423 .66111 L F
.44594 .66094 m .44783 .66506 L .4451 .6654 L F
.396 .424 .772 r
.73325 .70809 m .73414 .71159 L .73564 .70993 L F
.5 .584 .871 r
.73414 .71159 m .73704 .71182 L .73564 .70993 L F
.41 .777 .994 r
.30064 .59405 m .29692 .59369 L .29916 .59344 L F
.379 .748 .991 r
.30115 .59324 m .30064 .59405 L .29916 .59344 L F
.30115 .59324 m .30256 .59405 L .30064 .59405 L F
.518 .258 .459 r
.4293 .69079 m .4274 .68923 L .42956 .6888 L F
.4293 .69079 m .42705 .69119 L .4274 .68923 L F
.549 .305 .497 r
.64049 .54567 m .64043 .54769 L .63806 .54804 L F
.511 .242 .442 r
.64285 .54544 m .64043 .54769 L .64049 .54567 L F
0 0 0 r
.35199 .72573 m .35116 .72637 L .35609 .72568 L F
.839 .508 0 r
.35609 .72568 m .35524 .72467 L .35199 .72573 L F
.35609 .72568 m .35703 .72879 L .35524 .72467 L F
.653 .482 .64 r
.35772 .72496 m .35703 .72879 L .35609 .72568 L F
.881 .735 .695 r
.54119 .75239 m .54255 .75565 L .54137 .75464 L F
.74 .871 .941 r
.54255 .75565 m .53957 .75562 L .54137 .75464 L F
.632 .652 .852 r
.54338 .75207 m .54255 .75565 L .54127 .75256 L F
.54338 .75207 m .54127 .75256 L .5415 .75235 L F
.767 .584 .65 r
.54137 .75464 m .53933 .75262 L .54119 .75239 L F
.792 .489 .476 r
.54071 .74896 m .54274 .75117 L .54243 .74984 L F
.54071 .74896 m .54173 .75069 L .54274 .75117 L F
.566 .623 .868 r
.54243 .74984 m .54188 .75096 L .54071 .74896 L F
.54188 .75098 m .54167 .75141 L .54075 .74929 L F
.54167 .75141 m .54119 .75239 L .54104 .75135 L F
.54167 .75141 m .54104 .75135 L .54075 .74929 L F
.54167 .75141 m .54252 .75133 L .54119 .75239 L F
.54188 .75098 m .54248 .75131 L .54167 .75141 L F
.54248 .75131 m .54252 .75133 L .54167 .75141 L F
.263 0 0 r
.5422 .75146 m .54249 .7513 L .54205 .75123 L F
.54249 .7513 m .54274 .75117 L .54231 .75121 L F
.54249 .7513 m .54231 .75121 L .54205 .75123 L F
.566 .623 .868 r
.54188 .75096 m .54231 .75121 L .54188 .75098 L F
.54231 .75121 m .54248 .75131 L .54188 .75098 L F
.263 0 0 r
.54249 .7513 m .54263 .75129 L .54274 .75117 L F
0 0 0 r
.5428 .75112 m .54275 .75118 L .54285 .75108 L F
.54274 .75117 m .54267 .75124 L .5428 .75112 L F
.566 .623 .868 r
.54293 .75101 m .5415 .75235 L .54119 .75239 L F
.263 0 0 r
.5422 .75146 m .54244 .75149 L .54263 .75129 L F
.5422 .75146 m .54263 .75129 L .54249 .7513 L F
.632 .652 .852 r
.5415 .75235 m .54127 .75256 L .54119 .75239 L F
.767 .584 .65 r
.54137 .75464 m .53957 .75562 L .53933 .75262 L F
.704 .536 .658 r
.53933 .75262 m .53957 .75562 L .53575 .7551 L F
.263 0 0 r
.53881 .7533 m .54085 .75321 L .54244 .75149 L F
.53881 .7533 m .54244 .75149 L .5422 .75146 L F
.704 .536 .658 r
.53933 .75262 m .53575 .7551 L .53569 .75244 L F
.263 0 0 r
.53881 .7533 m .5422 .75146 L .53911 .7515 L F
.5422 .75146 m .54205 .75123 L .53911 .7515 L F
.566 .623 .868 r
.54188 .75096 m .54188 .75098 L .54071 .74896 L F
.54188 .75098 m .54075 .74929 L .54071 .74896 L F
.792 .489 .476 r
.54071 .74896 m .5401 .74992 L .54173 .75069 L F
.5401 .74992 m .53911 .7515 L .54231 .75121 L F
.5401 .74992 m .54231 .75121 L .54274 .75117 L F
.566 .623 .868 r
.54243 .74984 m .54293 .75101 L .54252 .75133 L F
.54243 .74984 m .54252 .75133 L .54188 .75096 L F
.54293 .75101 m .54338 .75207 L .5415 .75235 L F
0 0 0 r
.54274 .75117 m .54456 .74902 L .54243 .74984 L F
.54274 .75117 m .54286 .75108 L .54456 .74902 L F
.548 .565 .823 r
.54429 .74972 m .54293 .75101 L .54243 .74984 L F
0 0 0 r
.54286 .75108 m .54372 .75038 L .54456 .74902 L F
.548 .565 .823 r
.54456 .74902 m .54429 .74972 L .54396 .74974 L F
.54456 .74902 m .54396 .74974 L .54243 .74984 L F
.54429 .74972 m .54338 .75207 L .54293 .75101 L F
0 0 0 r
.54286 .75108 m .54085 .75321 L .54372 .75038 L F
.54285 .75108 m .54285 .75109 L .54286 .75108 L F
.54285 .75109 m .54085 .75321 L .54286 .75108 L F
.54275 .75118 m .54085 .75321 L .54285 .75108 L F
.54267 .75124 m .54085 .75321 L .5428 .75112 L F
.632 .652 .852 r
.54338 .75207 m .54532 .75561 L .54255 .75565 L F
.61 .312 .438 r
.54532 .75561 m .54475 .7575 L .54255 .75565 L F
.54532 .75561 m .54475 .7575 L .54255 .75565 L F
.579 .277 .42 r
.5127 .74998 m .51169 .75244 L .50958 .7523 L F
.731 .44 .487 r
.5127 .74998 m .51526 .7523 L .51418 .74915 L F
.5127 .74998 m .51169 .75244 L .51526 .7523 L F
.686 .755 .903 r
.52048 .72396 m .52183 .72524 L .52385 .72496 L F
.512 .237 .433 r
.29415 .63373 m .29633 .63343 L .29695 .63143 L F
.427 .156 .398 r
.29695 .63143 m .29833 .63287 L .29879 .63075 L F
.29695 .63143 m .29633 .63343 L .29833 .63287 L F
.375 .632 .954 r
.33208 .59965 m .33045 .59974 L .32831 .59772 L F
.609 .471 .668 r
.76015 .60842 m .75799 .61123 L .75833 .60926 L F
.737 .33 .279 r
.50742 .75268 m .51008 .75506 L .50617 .75436 L F
.535 .401 .645 r
.50958 .7523 m .51008 .75506 L .50742 .75268 L F
.667 .24 .223 r
.72372 .58848 m .72422 .58687 L .72144 .58669 L F
.744 .321 .247 r
.72372 .58848 m .727 .58908 L .72422 .58687 L F
.225 0 0 r
.2792 .60404 m .27765 .60549 L .2756 .60589 L F
.151 0 0 r
.28087 .60449 m .27765 .60549 L .2792 .60404 L F
.456 .537 .851 r
.42114 .66436 m .42254 .66707 L .42357 .66531 L F
.437 .395 .714 r
.42287 .66909 m .42357 .66531 L .42254 .66707 L F
.524 .386 .635 r
.4423 .75786 m .44408 .75507 L .44184 .75544 L F
0 0 .061 r
.59294 .73082 m .59308 .73103 L .59347 .72944 L F
.59294 .73082 m .59223 .7335 L .59308 .73103 L F
.63 .488 .671 r
.55453 .76285 m .55742 .76247 L .55866 .76325 L F
.968 .65 .276 r
.55866 .76325 m .55742 .76247 L .55727 .76046 L F
.526 .516 .788 r
.55948 .76038 m .55866 .76325 L .55727 .76046 L F
.55948 .76038 m .56068 .76306 L .55866 .76325 L F
.497 .298 .54 r
.56068 .76306 m .55855 .76605 L .55866 .76325 L F
.568 .162 .232 r
.47992 .76171 m .47689 .76303 L .47699 .7606 L F
.47992 .76171 m .4793 .7631 L .47689 .76303 L F
.719 .323 .299 r
.47992 .76171 m .48238 .76373 L .4793 .7631 L F
.191 0 0 r
.47992 .76171 m .48413 .76251 L .48238 .76373 L F
.344 .819 .891 r
.72974 .71697 m .72634 .71754 L .72963 .71678 L F
.504 .616 .896 r
.73209 .71583 m .72974 .71697 L .72963 .71678 L F
.73209 .71583 m .73172 .71695 L .72974 .71697 L F
.525 .318 .541 r
.28642 .63668 m .28622 .63902 L .28857 .63638 L F
.56 .276 .44 r
.64596 .54259 m .64799 .54363 L .64559 .54318 L F
.64596 .54259 m .64825 .54234 L .64799 .54363 L F
.863 .965 .637 r
.56085 .68496 m .55917 .68843 L .56182 .68621 L F
.56085 .68496 m .55869 .6885 L .55917 .68843 L F
.91 .631 .5 r
.60423 .68269 m .60696 .68594 L .60693 .68361 L F
.383 .06 .29 r
.34036 .60906 m .33763 .61123 L .33796 .60904 L F
.923 .532 .204 r
.56591 .71674 m .56539 .71793 L .56446 .71624 L F
.56591 .71674 m .56659 .71873 L .56539 .71793 L F
0 0 .344 r
.54252 .69953 m .54312 .69938 L .54278 .6965 L F
.879 .49 .295 r
.54519 .7028 m .54359 .70243 L .54252 .69953 L F
.968 .818 .64 r
.54359 .70243 m .54312 .69938 L .54252 .69953 L F
.573 .314 .486 r
.47054 .78249 m .47269 .78286 L .47292 .78026 L F
.674 .401 .5 r
.47292 .78026 m .47269 .78286 L .47686 .78084 L F
.89 .793 .747 r
.6234 .53185 m .62001 .53423 L .62173 .53072 L F
.6234 .53185 m .62262 .5338 L .62001 .53423 L F
.673 .802 .944 r
.38843 .82971 m .39194 .82999 L .39091 .82881 L F
.38843 .82971 m .39194 .82999 L .39091 .82881 L F
.287 .605 .953 r
.39091 .82881 m .39194 .82999 L .39268 .82904 L F
.39268 .82904 m .39194 .82999 L .39091 .82881 L F
0 0 0 r
.59863 .70863 m .59627 .71137 L .59757 .71013 L F
.338 .106 .408 r
.59508 .71297 m .59757 .71013 L .59627 .71137 L F
.669 .786 .936 r
.56085 .68496 m .56182 .68621 L .56539 .68508 L F
.658 .912 .979 r
.70816 .59947 m .70826 .59752 L .70931 .60012 L F
.34 .138 .454 r
.70826 .59752 m .70687 .59839 L .70834 .59585 L F
.658 .912 .979 r
.70551 .59797 m .70687 .59839 L .70826 .59752 L F
.70551 .59797 m .70826 .59752 L .70816 .59947 L F
.34 .138 .454 r
.70826 .59752 m .70834 .59585 L .70871 .59521 L F
.255 .064 .419 r
.71062 .59604 m .70871 .59521 L .7105 .59401 L F
.71062 .59604 m .70826 .59752 L .70871 .59521 L F
.577 .662 .896 r
.54521 .73403 m .54711 .73637 L .54901 .73561 L F
0 .129 .677 r
.54606 .73634 m .54734 .73849 L .54711 .73637 L F
.603 .661 .879 r
.42371 .6726 m .42474 .66993 L .42287 .66909 L F
.42371 .6726 m .42593 .67213 L .42474 .66993 L F
.67 .59 .758 r
.42417 .6749 m .42593 .67213 L .42371 .6726 L F
.224 0 .343 r
.344 .66425 m .34196 .66716 L .34383 .66663 L F
.458 .349 .641 r
.34196 .66716 m .34399 .66915 L .34383 .66663 L F
.34196 .66716 m .34221 .66959 L .34399 .66915 L F
.77 .328 .201 r
.50249 .73555 m .5056 .73658 L .50436 .73583 L F
.645 .579 .766 r
.71306 .60437 m .71133 .6063 L .71019 .60301 L F
.039 .204 .707 r
.71133 .6063 m .71217 .6055 L .71019 .60301 L F
.645 .579 .766 r
.71306 .60437 m .7141 .60536 L .71133 .6063 L F
0 .2 .726 r
.71133 .6063 m .71292 .60699 L .71217 .6055 L F
.71133 .6063 m .7137 .6085 L .71292 .60699 L F
.828 .762 .789 r
.73382 .72292 m .73667 .72229 L .7358 .72125 L F
.73382 .72292 m .73448 .72521 L .73667 .72229 L F
.65 .604 .789 r
.6828 .51542 m .67957 .51295 L .68185 .512 L F
.456 .42 .729 r
.68406 .51152 m .6828 .51542 L .68185 .512 L F
.68406 .51152 m .68462 .51548 L .6828 .51542 L F
0 .208 .731 r
.68429 .51603 m .6828 .51542 L .68462 .51548 L F
.68429 .51603 m .68487 .51715 L .6828 .51542 L F
.361 .316 .672 r
.6828 .51542 m .68487 .51715 L .68331 .51749 L F
.47 .369 .657 r
.44028 .76164 m .44224 .76332 L .44242 .76054 L F
.44028 .76164 m .44047 .7638 L .44224 .76332 L F
.73 .315 .261 r
.52362 .71128 m .52581 .71325 L .52711 .71208 L F
.707 .284 .24 r
.52581 .71325 m .52906 .71365 L .52711 .71208 L F
.662 .108 0 r
.52711 .71208 m .52906 .71365 L .53039 .7141 L F
.815 .858 .88 r
.61853 .53962 m .61569 .53963 L .61711 .53851 L F
.61853 .53962 m .61656 .54011 L .61569 .53963 L F
.788 .673 .737 r
.61853 .53962 m .61645 .54285 L .61656 .54011 L F
.878 .873 .827 r
.62063 .53639 m .61853 .53962 L .61711 .53851 L F
0 0 0 r
.62804 .52393 m .62751 .52409 L .62655 .52522 L F
.322 .57 .929 r
.43786 .6531 m .4368 .65407 L .43569 .65317 L F
.43786 .6531 m .43934 .65488 L .4368 .65407 L F
.302 .789 .737 r
.53689 .76526 m .53561 .76586 L .53804 .76432 L F
.53689 .76526 m .53483 .76601 L .53561 .76586 L F
.481 .74 .985 r
.2767 .64179 m .27613 .6434 L .27444 .64272 L F
.2767 .64179 m .27791 .6428 L .27613 .6434 L F
0 0 0 r
.28168 .64179 m .28271 .64152 L .28336 .64094 L F
.28168 .64179 m .28062 .64219 L .28271 .64152 L F
.809 .506 .477 r
.57144 .70884 m .57239 .71097 L .57392 .7107 L F
.691 .265 .232 r
.57239 .71097 m .57585 .7113 L .57392 .7107 L F
.921 .584 .126 r
.6274 .51242 m .62786 .51446 L .62658 .51144 L F
.6274 .51242 m .62786 .51446 L .62658 .51144 L F
.364 0 .114 r
.60015 .71368 m .59897 .71582 L .5964 .71624 L F
.953 .656 .433 r
.60015 .71368 m .60069 .71684 L .59897 .71582 L F
.936 .573 .293 r
.57039 .70807 m .57239 .71097 L .57144 .70884 L F
.637 .396 .536 r
.53264 .73618 m .53219 .73877 L .52984 .73845 L F
.592 .355 .525 r
.53623 .73799 m .53264 .73618 L .53515 .7357 L F
.53623 .73799 m .53219 .73877 L .53264 .73618 L F
.954 .708 .528 r
.35591 .73073 m .35545 .73297 L .35395 .72964 L F
.517 .806 .998 r
.35785 .73017 m .35591 .73073 L .35395 .72964 L F
.122 0 .311 r
.3568 .73156 m .35591 .73073 L .35785 .73017 L F
.3568 .73156 m .35545 .73297 L .35591 .73073 L F
.217 0 .001 r
.40516 .69233 m .40412 .69354 L .40714 .69169 L F
.923 .598 .408 r
.52906 .71365 m .52937 .71576 L .53039 .7141 L F
.919 .592 .406 r
.53039 .7141 m .52937 .71576 L .53118 .71623 L F
.686 .755 .903 r
.52048 .72396 m .52385 .72496 L .52358 .72379 L F
.629 .435 .601 r
.52178 .72766 m .52409 .72798 L .52385 .72496 L F
.52385 .72496 m .52409 .72798 L .52178 .72766 L F
.953 .947 .645 r
.52385 .72496 m .52265 .72459 L .52358 .72379 L F
0 0 .411 r
.52385 .72496 m .52409 .72798 L .52519 .72603 L F
.629 .435 .601 r
.52178 .72766 m .52409 .72798 L .52385 .72496 L F
0 0 0 r
.52048 .72396 m .51725 .72471 L .51885 .7256 L F
.574 .132 .162 r
.52179 .72402 m .52171 .72572 L .51916 .72436 L F
.52358 .72379 m .52276 .72463 L .52179 .72402 L F
.52276 .72463 m .52171 .72572 L .52179 .72402 L F
.725 .321 .282 r
.52519 .72603 m .52171 .72572 L .52276 .72463 L F
0 0 .411 r
.52385 .72496 m .52519 .72603 L .52311 .72483 L F
.52385 .72496 m .52307 .72483 L .52274 .72462 L F
.725 .321 .282 r
.52519 .72603 m .52276 .72463 L .52358 .72379 L F
0 0 .411 r
.52311 .72483 m .52519 .72603 L .52307 .72483 L F
.52274 .72462 m .52307 .72483 L .52265 .72459 L F
.884 .834 .792 r
.62001 .53423 m .62262 .5338 L .62063 .53639 L F
.514 .803 .998 r
.43056 .66424 m .43254 .66376 L .42909 .6634 L F
.049 .09 .584 r
.43056 .66424 m .43146 .66574 L .43254 .66376 L F
.045 .354 .828 r
.42545 .66383 m .4271 .66602 L .42475 .66427 L F
.731 .446 .496 r
.59004 .7088 m .58967 .71071 L .58751 .70818 L F
.199 0 .272 r
.59242 .7064 m .58967 .71071 L .59004 .7088 L F
.56 .155 .23 r
.48587 .7631 m .48238 .76373 L .48413 .76251 L F
.541 .288 .48 r
.4171 .68342 m .41939 .68315 L .41971 .68098 L F
.506 .251 .462 r
.41939 .68315 m .42209 .6806 L .41971 .68098 L F
0 .35 .736 r
.53456 .71823 m .53621 .71895 L .53577 .71885 L F
.555 0 0 r
.53331 .71763 m .53621 .71895 L .53456 .71823 L F
.53331 .71763 m .53496 .71864 L .53621 .71895 L F
.664 .194 .127 r
.53496 .71864 m .53671 .71907 L .53621 .71895 L F
.53671 .71907 m .53721 .7192 L .53621 .71895 L F
0 .35 .736 r
.53577 .71885 m .53621 .71895 L .53736 .71965 L F
0 .294 .728 r
.53721 .7192 m .53736 .71965 L .53621 .71895 L F
.53721 .7192 m .54009 .72117 L .53736 .71965 L F
.713 .261 .177 r
.62911 .54758 m .6325 .54822 L .63139 .54952 L F
.24 .753 .854 r
.63553 .54911 m .63139 .54952 L .6325 .54822 L F
.445 0 0 r
.636 .54809 m .63553 .54911 L .6325 .54822 L F
0 0 .445 r
.57382 .75795 m .57449 .76033 L .57413 .76032 L F
.698 .666 .118 r
.57375 .76259 m .57413 .76032 L .57449 .76033 L F
.466 .104 .266 r
.48082 .73801 m .48304 .73781 L .48363 .73635 L F
.453 .092 .261 r
.48304 .73781 m .4852 .7376 L .48363 .73635 L F
.448 .093 .271 r
.48363 .73635 m .4852 .7376 L .4859 .73602 L F
.442 0 0 r
.63806 .54804 m .63553 .54911 L .636 .54809 L F
.55 .511 .765 r
.34038 .68627 m .34134 .68263 L .33947 .68307 L F
.34038 .68627 m .34242 .68584 L .34134 .68263 L F
.511 .394 .656 r
.34038 .68627 m .34271 .68843 L .34242 .68584 L F
.34038 .68627 m .34074 .68899 L .34271 .68843 L F
.598 .666 .887 r
.32721 .72104 m .32819 .72267 L .33036 .7222 L F
.662 .428 .554 r
.52914 .76274 m .53166 .76075 L .52918 .76132 L F
.671 .735 .899 r
.42455 .65232 m .42234 .65325 L .42128 .6516 L F
.16 0 0 r
.38474 .66881 m .38433 .66931 L .38275 .6694 L F
.297 .003 .285 r
.38381 .67106 m .38275 .6694 L .38433 .66931 L F
.38381 .67106 m .38204 .67176 L .38275 .6694 L F
.04 .143 .646 r
.33118 .71105 m .33213 .71008 L .33056 .70779 L F
.52 .474 .745 r
.33085 .71312 m .33213 .71008 L .33118 .71105 L F
.633 .649 .848 r
.65403 .51596 m .65178 .51673 L .65022 .51404 L F
.749 .249 0 r
.57663 .73093 m .57565 .73038 L .57374 .72779 L F
.858 .417 .007 r
.57663 .73093 m .57758 .73277 L .57565 .73038 L F
.607 .615 .834 r
.72963 .71678 m .72634 .71754 L .72525 .7135 L F
.242 0 .005 r
.60712 .7527 m .61089 .75041 L .60983 .75187 L F
.301 0 .24 r
.61189 .74936 m .60983 .75187 L .61089 .75041 L F
.605 .544 .759 r
.33997 .69761 m .34221 .69734 L .34125 .69412 L F
.598 .482 .692 r
.33997 .69761 m .34035 .70008 L .34221 .69734 L F
.798 .435 .369 r
.51402 .79498 m .51709 .79818 L .51277 .79645 L F
.667 .117 0 r
.51402 .79498 m .51698 .79669 L .51709 .79818 L F
.652 .097 0 r
.5687 .71994 m .56741 .7194 L .56659 .71873 L F
.571 .041 0 r
.5703 .72193 m .56741 .7194 L .5687 .71994 L F
0 0 .35 r
.57374 .72779 m .57356 .72716 L .57245 .7247 L F
0 0 .519 r
.57374 .72779 m .57492 .72903 L .57356 .72716 L F
.57374 .72779 m .57565 .73038 L .57492 .72903 L F
.545 .842 .999 r
.72988 .61858 m .7301 .61995 L .72852 .61992 L F
.749 .967 .932 r
.73353 .61721 m .7301 .61995 L .72988 .61858 L F
0 0 0 r
.28996 .6532 m .28848 .65348 L .28648 .65383 L F
.138 .684 .739 r
.2921 .65299 m .28848 .65348 L .28996 .6532 L F
.85 .836 .831 r
.58751 .70818 m .5858 .70811 L .58822 .70507 L F
.802 .477 .439 r
.58967 .71071 m .5858 .70811 L .58751 .70818 L F
.629 .821 .974 r
.71069 .59118 m .7112 .59233 L .7125 .59072 L F
.506 .632 .908 r
.7112 .59233 m .71379 .59269 L .7125 .59072 L F
.552 .396 .624 r
.71069 .59118 m .7105 .59401 L .7112 .59233 L F
.397 .141 .405 r
.33084 .617 m .33328 .61443 L .33278 .61648 L F
.458 .209 .448 r
.33278 .61648 m .33328 .61443 L .3353 .61384 L F
.359 .709 .985 r
.4139 .65005 m .41309 .65105 L .41184 .65004 L F
.4139 .65005 m .41534 .65109 L .41309 .65105 L F
.546 .349 .565 r
.30304 .62512 m .30547 .62224 L .30362 .62304 L F
.342 .73 .985 r
.29692 .59369 m .29351 .5929 L .29536 .59258 L F
.398 .764 .993 r
.29776 .59265 m .29692 .59369 L .29536 .59258 L F
.29776 .59265 m .29916 .59344 L .29692 .59369 L F
.43 .352 .668 r
.5892 .71722 m .59115 .71871 L .59085 .71619 L F
.724 .359 .358 r
.57626 .67444 m .57855 .67513 L .57749 .67412 L F
.844 .976 .671 r
.67777 .51531 m .67574 .51822 L .6763 .51665 L F
.897 .941 .831 r
.67957 .51295 m .67777 .51531 L .67799 .51266 L F
.949 .956 .678 r
.67777 .51531 m .6763 .51665 L .67799 .51266 L F
.399 .422 .768 r
.4449 .65759 m .44423 .66111 L .44298 .65793 L F
.4449 .65759 m .44594 .66094 L .44423 .66111 L F
.828 .479 .396 r
.71669 .59282 m .71676 .59467 L .71379 .59269 L F
.71669 .59282 m .71737 .59467 L .71676 .59467 L F
0 0 0 r
.5046 .72945 m .50201 .73264 L .50291 .73107 L F
.478 .192 .401 r
.52629 .74305 m .52499 .74128 L .52704 .74088 L F
.52629 .74305 m .52452 .74345 L .52499 .74128 L F
.668 .633 .806 r
.53508 .74531 m .53938 .74654 L .53667 .74375 L F
.366 .295 .644 r
.53938 .74654 m .54071 .74896 L .53958 .74727 L F
.441 .138 .355 r
.41999 .69504 m .4194 .69682 L .41731 .69727 L F
.424 .123 .347 r
.42149 .6963 m .41999 .69504 L .42211 .69466 L F
.42149 .6963 m .4194 .69682 L .41999 .69504 L F
.575 .26 .398 r
.58253 .70309 m .58489 .70472 L .58248 .7047 L F
.58253 .70309 m .58489 .70472 L .58248 .7047 L F
.482 .297 .553 r
.7573 .59052 m .75724 .59416 L .75492 .59453 L F
.225 .428 .851 r
.75652 .58946 m .75905 .59101 L .7573 .59052 L F
.403 .237 .539 r
.75905 .59101 m .75724 .59416 L .7573 .59052 L F
.376 .446 .806 r
.75592 .60463 m .75697 .60787 L .75405 .606 L F
.563 .87 .995 r
.75592 .60463 m .75405 .606 L .75339 .60529 L F
.898 .941 .83 r
.74858 .60878 m .74661 .61138 L .74853 .60978 L F
.621 .331 .456 r
.74661 .61138 m .74905 .61322 L .74853 .60978 L F
.298 .433 .829 r
.74853 .60978 m .75154 .61067 L .74858 .60878 L F
.457 .22 .465 r
.74853 .60978 m .74905 .61322 L .75154 .61067 L F
.492 .01 .039 r
.5056 .73658 m .50853 .7375 L .50949 .73608 L F
.807 .592 .612 r
.50853 .7375 m .51037 .73491 L .50949 .73608 L F
.428 .191 .45 r
.29891 .6283 m .30086 .62778 L .30124 .62577 L F
.447 .268 .543 r
.29891 .6283 m .30067 .63014 L .30086 .62778 L F
.29891 .6283 m .29879 .63075 L .30067 .63014 L F
.298 .02 .312 r
.32848 .61989 m .33084 .617 L .33042 .61953 L F
.423 .168 .42 r
.33042 .61953 m .33084 .617 L .33278 .61648 L F
.72 .599 .721 r
.68331 .51749 m .68432 .52101 L .68081 .52066 L F
.648 .324 .409 r
.68432 .52101 m .68043 .52305 L .68081 .52066 L F
.68432 .52101 m .68164 .52375 L .68043 .52305 L F
.264 .308 .721 r
.68569 .51959 m .68432 .52101 L .68331 .51749 L F
.512 .821 .498 r
.68569 .51959 m .68164 .52375 L .68432 .52101 L F
0 .533 .803 r
.30834 .59447 m .31027 .59481 L .31178 .59529 L F
.297 .751 .956 r
.31027 .59481 m .3138 .5952 L .31178 .59529 L F
.413 0 .043 r
.37543 .71859 m .37181 .72028 L .37337 .71925 L F
.912 .745 .662 r
.59737 .69136 m .59855 .6946 L .59759 .69387 L F
.962 .694 .479 r
.59855 .6946 m .59725 .69626 L .59759 .69387 L F
.59855 .6946 m .5987 .69714 L .59725 .69626 L F
.443 .045 .188 r
.40681 .70498 m .40347 .70722 L .40512 .70588 L F
.695 .8 .334 r
.32848 .71379 m .32767 .71549 L .32806 .71519 L F
.331 0 .148 r
.32767 .71549 m .33085 .71312 L .32806 .71519 L F
.178 .713 .804 r
.36333 .72468 m .3639 .72451 L .36012 .72496 L F
.235 .693 .95 r
.36333 .72468 m .36577 .72497 L .36416 .72418 L F
0 .08 .618 r
.36416 .72418 m .3639 .72451 L .36333 .72468 L F
0 .25 .763 r
.5415 .72151 m .54097 .72219 L .54009 .72117 L F
.887 .577 .456 r
.59523 .68601 m .59274 .68291 L .59608 .68362 L F
.49 .796 .999 r
.73903 .72173 m .74234 .72222 L .74164 .72135 L F
.759 .921 .943 r
.74164 .72135 m .74234 .72222 L .74415 .72122 L F
.997 .808 .529 r
.48007 .7543 m .48114 .7556 L .48138 .7526 L F
.458 0 .026 r
.48272 .75368 m .48007 .7543 L .48138 .7526 L F
.564 .568 .816 r
.48188 .75294 m .48488 .755 L .48272 .75368 L F
.642 .78 .947 r
.48272 .75368 m .48488 .755 L .48725 .75465 L F
.48272 .75368 m .48725 .75465 L .48593 .75337 L F
.443 0 .021 r
.48593 .75337 m .48314 .75405 L .48272 .75368 L F
.48314 .75405 m .48254 .75419 L .48272 .75368 L F
.564 .568 .816 r
.48138 .7526 m .48188 .75294 L .48272 .75368 L F
.584 .86 .995 r
.27059 .64379 m .27111 .64244 L .27256 .64332 L F
.27059 .64379 m .26897 .64311 L .27111 .64244 L F
.608 .346 .495 r
.47548 .74116 m .47793 .74119 L .47804 .73874 L F
.497 .221 .425 r
.47793 .74119 m .48082 .73801 L .47804 .73874 L F
.727 .603 .718 r
.67853 .52043 m .6751 .52051 L .67574 .51822 L F
.707 .372 .407 r
.67933 .52247 m .6751 .52051 L .67853 .52043 L F
.689 .555 .698 r
.68074 .51809 m .68081 .52066 L .67853 .52043 L F
.681 .408 .502 r
.68081 .52066 m .67933 .52247 L .67853 .52043 L F
.373 0 0 r
.28474 .60301 m .28293 .60446 L .28087 .60449 L F
.224 0 0 r
.28681 .60279 m .28293 .60446 L .28474 .60301 L F
.69 .438 .536 r
.56561 .68066 m .56822 .68143 L .56876 .67815 L F
0 0 .15 r
.56876 .67815 m .56938 .67947 L .57073 .67734 L F
.56859 .67917 m .56822 .68143 L .56884 .68038 L F
.816 .474 .409 r
.56561 .68066 m .56843 .68249 L .56822 .68143 L F
.56561 .68066 m .56533 .68235 L .56843 .68249 L F
.468 .58 .884 r
.56843 .68249 m .56938 .67947 L .56822 .68143 L F
.275 0 0 r
.57154 .68174 m .56843 .68249 L .5692 .68247 L F
.57154 .68174 m .5709 .68229 L .56843 .68249 L F
.468 .58 .884 r
.56843 .68249 m .5709 .68229 L .56997 .68056 L F
.56907 .68045 m .56997 .68056 L .56938 .67947 L F
.56843 .68249 m .56997 .68056 L .56907 .68045 L F
.974 .739 .52 r
.57 .68053 m .5709 .68229 L .57047 .68133 L F
.56938 .67947 m .56997 .68056 L .57 .68053 L F
.56997 .68056 m .5709 .68229 L .57 .68053 L F
.451 .184 .416 r
.56949 .68155 m .56911 .68142 L .57029 .6806 L F
.793 .806 .862 r
.57063 .68052 m .57061 .68052 L .57061 .6805 L F
.451 .184 .416 r
.57062 .68052 m .57061 .68052 L .57063 .68052 L F
.974 .739 .52 r
.57 .68053 m .57056 .68052 L .57066 .68043 L F
.57 .68053 m .57066 .68043 L .5709 .67991 L F
.56938 .67947 m .57 .68053 L .57056 .68014 L F
.57046 .67928 m .57056 .68014 L .57225 .67898 L F
.56938 .67947 m .57056 .68014 L .57046 .67928 L F
.436 .063 .23 r
.56938 .67947 m .57294 .67629 L .57073 .67734 L F
.56938 .67947 m .57125 .67915 L .57294 .67629 L F
.57125 .67915 m .57225 .67898 L .57244 .67823 L F
.57125 .67915 m .57244 .67823 L .57294 .67629 L F
.86 .989 .84 r
.57092 .67897 m .57063 .68049 L .56952 .67973 L F
.57082 .67948 m .5702 .6802 L .57062 .68049 L F
0 0 .15 r
.56859 .67917 m .56884 .68038 L .56938 .67947 L F
.793 .806 .862 r
.57061 .6805 m .56638 .68158 L .56877 .67921 L F
.974 .739 .52 r
.57 .68053 m .57047 .68133 L .57109 .68052 L F
.451 .184 .416 r
.56906 .68146 m .5698 .68072 L .57029 .6806 L F
.86 .989 .84 r
.5702 .6802 m .56943 .6811 L .57062 .68049 L F
.57063 .68049 m .57063 .68052 L .57061 .6805 L F
.451 .184 .416 r
.57051 .68063 m .57029 .6806 L .57061 .68052 L F
.56915 .68194 m .57014 .68078 L .57051 .68063 L F
.57014 .68078 m .57029 .6806 L .57044 .68062 L F
.57014 .68078 m .57044 .68062 L .57051 .68063 L F
.86 .989 .84 r
.57062 .68049 m .56943 .6811 L .57062 .68052 L F
.57063 .68049 m .57062 .68052 L .57063 .68052 L F
.57101 .67848 m .57062 .68052 L .57063 .68049 L F
.974 .739 .52 r
.5709 .67991 m .57066 .68043 L .57225 .67898 L F
.57056 .68052 m .57109 .68052 L .57128 .68026 L F
.57056 .68052 m .57128 .68026 L .57225 .67898 L F
.86 .989 .84 r
.57063 .68049 m .57061 .6805 L .56877 .67921 L F
.793 .806 .862 r
.57061 .68052 m .56638 .68158 L .57061 .6805 L F
.451 .184 .416 r
.57051 .68063 m .57061 .68052 L .57062 .68052 L F
.778 .392 .325 r
.57294 .67629 m .57225 .67898 L .57518 .67891 L F
.764 .781 .867 r
.57047 .68133 m .57663 .67998 L .57518 .67891 L F
.75 .905 .946 r
.57225 .67898 m .57047 .68133 L .57518 .67891 L F
.451 .184 .416 r
.56915 .68194 m .56911 .68142 L .56949 .68155 L F
.53 .077 .122 r
.56943 .6811 m .56869 .68238 L .57063 .68052 L F
.425 .312 .622 r
.57226 .67824 m .57349 .68018 L .56943 .6811 L F
.57303 .67746 m .57309 .67779 L .57226 .67824 L F
.57309 .67779 m .57349 .68018 L .57226 .67824 L F
.86 .989 .84 r
.57101 .67848 m .57092 .67897 L .56877 .67921 L F
.57092 .67897 m .56952 .67973 L .56877 .67921 L F
.57101 .67848 m .57006 .68006 L .57082 .67948 L F
.57006 .68006 m .56943 .6811 L .57082 .67948 L F
.954 .748 .586 r
.57047 .68133 m .5709 .68229 L .57154 .68174 L F
.472 .072 .199 r
.57258 .68196 m .57186 .68235 L .56943 .6811 L F
.57186 .68235 m .57093 .68285 L .56995 .6817 L F
.57186 .68235 m .56995 .6817 L .56943 .6811 L F
.451 .184 .416 r
.56915 .68194 m .56906 .68146 L .56911 .68142 L F
.56906 .68146 m .56895 .68094 L .5698 .68072 L F
.56869 .68238 m .56638 .68158 L .56895 .68094 L F
.56869 .68238 m .56895 .68094 L .56915 .68194 L F
0 0 .15 r
.56876 .67815 m .56859 .67917 L .56938 .67947 L F
0 0 .525 r
.57871 .736 m .57905 .73537 L .57758 .73277 L F
0 .007 .583 r
.57871 .736 m .58034 .73833 L .57905 .73537 L F
.394 .226 .531 r
.344 .66425 m .34572 .66585 L .34594 .66357 L F
.344 .66425 m .34383 .66663 L .34572 .66585 L F
.289 .727 .965 r
.26822 .58686 m .27186 .58751 L .26974 .58755 L F
.784 .334 0 r
.54731 .70588 m .54657 .70538 L .54519 .7028 L F
0 0 .453 r
.54731 .70588 m .54803 .70676 L .54657 .70538 L F
.456 0 0 r
.55196 .70875 m .55046 .70851 L .5487 .70778 L F
.564 .01 0 r
.55046 .70851 m .54803 .70676 L .5487 .70778 L F
.852 .493 .372 r
.55042 .70884 m .54857 .70741 L .54803 .70676 L F
0 0 .453 r
.54743 .70605 m .5487 .70778 L .54803 .70676 L F
.852 .493 .372 r
.54857 .70741 m .5477 .70674 L .54803 .70676 L F
0 0 .453 r
.54731 .70588 m .54743 .70605 L .54803 .70676 L F
.67 .59 .758 r
.42417 .6749 m .42698 .6753 L .42593 .67213 L F
.503 .399 .67 r
.42417 .6749 m .42639 .67708 L .42698 .6753 L F
.42417 .6749 m .42458 .67772 L .42639 .67708 L F
.402 .168 .441 r
.30124 .62577 m .30086 .62778 L .30304 .62512 L F
.653 .187 .134 r
.57239 .71097 m .57474 .7126 L .57585 .7113 L F
.706 .252 .172 r
.57474 .7126 m .57804 .71325 L .57585 .7113 L F
.608 .054 0 r
.57585 .7113 m .57804 .71325 L .57917 .71379 L F
.354 .049 .301 r
.6072 .75262 m .60485 .75502 L .60631 .75573 L F
.464 .49 .8 r
.31438 .87101 m .3152 .87117 L .31452 .87135 L F
.356 .143 .446 r
.31452 .87135 m .3152 .87117 L .31429 .87271 L F
.524 .316 .54 r
.3353 .61384 m .33554 .61172 L .33763 .61123 L F
.791 .542 .561 r
.55476 .7474 m .55143 .74907 L .55168 .74752 L F
.697 .157 0 r
.5583 .74975 m .55747 .74983 L .55476 .7474 L F
.248 .62 .958 r
.2886 .59067 m .28823 .59161 L .28664 .5907 L F
.2886 .59067 m .28999 .59184 L .28823 .59161 L F
.874 .673 .627 r
.60922 .69688 m .60799 .69957 L .61068 .7002 L F
.866 .555 .459 r
.60799 .69957 m .60921 .70102 L .61068 .7002 L F
.856 .536 .444 r
.60921 .70102 m .61109 .7026 L .61068 .7002 L F
.774 .562 .613 r
.6132 .7111 m .61331 .71349 L .61659 .71371 L F
.775 .62 .687 r
.61331 .71349 m .61474 .71672 L .61659 .71371 L F
0 0 .284 r
.57129 .77158 m .57163 .77159 L .57187 .76907 L F
0 0 .141 r
.57163 .77159 m .57105 .77385 L .57129 .77158 L F
0 0 .284 r
.57187 .76907 m .57163 .77159 L .57129 .77158 L F
0 0 .141 r
.57163 .77159 m .57105 .77385 L .57129 .77158 L F
0 0 .362 r
.57804 .71325 m .57816 .71579 L .57917 .71379 L F
.518 .5 .776 r
.47342 .76258 m .47195 .76355 L .47126 .76066 L F
.536 .397 .638 r
.47516 .76299 m .47195 .76355 L .47342 .76258 L F
.47516 .76299 m .47254 .76616 L .47195 .76355 L F
.518 .403 .663 r
.75709 .59735 m .75492 .59453 L .75724 .59416 L F
.75709 .59735 m .75522 .59792 L .75492 .59453 L F
.884 .488 .272 r
.47029 .76911 m .4668 .76521 L .47003 .76661 L F
.603 .458 .658 r
.47254 .76616 m .47029 .76911 L .47003 .76661 L F
.931 .716 .59 r
.60704 .68831 m .60807 .69145 L .60825 .68901 L F
.486 .221 .438 r
.64506 .54676 m .64285 .54544 L .64559 .54318 L F
.483 .174 .364 r
.64799 .54363 m .64506 .54676 L .64559 .54318 L F
.578 .92 .963 r
.67957 .51295 m .68126 .5117 L .68185 .512 L F
.67957 .51295 m .67799 .51266 L .68126 .5117 L F
.584 .036 0 r
.70718 .59043 m .70961 .58932 L .70845 .59049 L F
.70718 .59043 m .71069 .59118 L .70961 .58932 L F
.651 .143 0 r
.70574 .5879 m .70813 .59042 L .70718 .59043 L F
.584 .036 0 r
.70718 .59043 m .70893 .59126 L .71069 .59118 L F
.651 .143 0 r
.70813 .59042 m .70893 .59126 L .70718 .59043 L F
.033 .603 .743 r
.70521 .59047 m .70718 .59043 L .70845 .59049 L F
.70403 .59046 m .70718 .59043 L .70521 .59047 L F
.855 .779 .776 r
.57109 .76493 m .56694 .7654 L .56888 .76187 L F
.368 0 0 r
.57109 .76493 m .56938 .7661 L .56694 .7654 L F
.238 .339 .765 r
.57122 .76359 m .57109 .76493 L .56888 .76187 L F
.57122 .76359 m .57246 .76448 L .57109 .76493 L F
.821 .758 .793 r
.61569 .53963 m .61645 .54285 L .6135 .54195 L F
.736 .43 .463 r
.61645 .54285 m .61317 .54429 L .6135 .54195 L F
.61645 .54285 m .61673 .54474 L .61317 .54429 L F
.916 .805 .722 r
.61656 .54011 m .61645 .54285 L .61569 .53963 L F
.712 .249 .151 r
.47823 .78277 m .48099 .78318 L .4797 .78252 L F
.646 .384 .509 r
.51084 .76915 m .50818 .77078 L .5077 .76899 L F
.51084 .76915 m .51059 .77111 L .50818 .77078 L F
.784 .578 .621 r
.5077 .76899 m .50975 .76998 L .51084 .76915 L F
.899 .912 .823 r
.51084 .76915 m .51316 .76626 L .51308 .76881 L F
.51084 .76915 m .512 .76572 L .51316 .76626 L F
.51084 .76915 m .50975 .76998 L .512 .76572 L F
.605 .393 .567 r
.51308 .76881 m .51059 .77111 L .51084 .76915 L F
.817 .561 .551 r
.59585 .67403 m .59912 .67247 L .5957 .6721 L F
.59585 .67403 m .59923 .67479 L .59912 .67247 L F
.786 .959 .924 r
.6485 .51529 m .64566 .51762 L .64752 .51662 L F
.312 .031 .317 r
.64566 .51762 m .6474 .51867 L .64752 .51662 L F
.075 0 .446 r
.64752 .51662 m .64953 .51571 L .6497 .51397 L F
.63 .497 .681 r
.6474 .51867 m .64953 .51571 L .64752 .51662 L F
.548 .27 .446 r
.44484 .67779 m .4442 .6803 L .44192 .68048 L F
.563 .319 .505 r
.44697 .67741 m .4442 .6803 L .44484 .67779 L F
0 0 .133 r
.66762 .52441 m .66734 .52332 L .66717 .52225 L F
.66762 .52441 m .6675 .5256 L .66736 .52357 L F
0 0 .222 r
.6678 .52503 m .66762 .52441 L .66706 .52334 L F
.6679 .52526 m .66824 .52655 L .66762 .52441 L F
.6679 .52526 m .66762 .52441 L .6678 .52503 L F
0 0 .133 r
.66762 .52441 m .66736 .52357 L .66734 .52332 L F
.692 .558 .698 r
.68331 .51749 m .68081 .52066 L .68074 .51809 L F
.536 0 0 r
.5014 .75386 m .50232 .75462 L .50051 .75407 L F
.496 .215 .417 r
.42705 .69119 m .42413 .69418 L .42488 .69162 L F
.62 .122 .049 r
.39282 .66833 m .38939 .66734 L .39089 .66677 L F
.359 .05 .298 r
.37314 .67822 m .37246 .68034 L .37033 .6807 L F
.376 .065 .305 r
.37486 .67923 m .37314 .67822 L .37483 .67726 L F
.37486 .67923 m .37246 .68034 L .37314 .67822 L F
.568 .806 .989 r
.59121 .75743 m .59453 .75782 L .59329 .75693 L F
.624 .826 .978 r
.59329 .75693 m .59453 .75782 L .59777 .75724 L F
.386 0 .166 r
.55496 .68552 m .55742 .6851 L .55824 .68319 L F
.72 .329 .309 r
.55824 .68319 m .55742 .6851 L .56085 .68496 L F
.579 .738 .951 r
.42798 .65328 m .42455 .65232 L .42669 .65207 L F
.278 .71 .967 r
.42669 .65207 m .43013 .65282 L .42798 .65328 L F
.524 .724 .965 r
.50275 .76452 m .50418 .76597 L .50245 .76477 L F
.904 .671 .575 r
.50418 .76597 m .50403 .76896 L .50245 .76477 L F
.691 .786 .923 r
.50669 .76478 m .50418 .76597 L .50275 .76452 L F
.616 .522 .724 r
.50669 .76478 m .50684 .76602 L .50418 .76597 L F
.721 .578 .694 r
.50684 .76602 m .50403 .76896 L .50418 .76597 L F
.584 .744 .952 r
.27648 .58756 m .27886 .58983 L .27534 .58893 L F
.368 .646 .963 r
.27648 .58756 m .27939 .58853 L .27886 .58983 L F
.472 .762 .994 r
.27939 .58853 m .28083 .58959 L .27886 .58983 L F
.587 .34 .508 r
.43554 .68351 m .43435 .68608 L .43187 .68614 L F
.497 .22 .424 r
.43739 .68314 m .43435 .68608 L .43554 .68351 L F
.167 .682 .892 r
.46042 .78802 m .45908 .78765 L .45689 .78759 L F
0 .504 .765 r
.46042 .78802 m .46238 .7884 L .45908 .78765 L F
.493 .494 .786 r
.50883 .7215 m .50806 .71889 L .51147 .71942 L F
.095 .189 .672 r
.51389 .73046 m .51503 .73299 L .51541 .73226 L F
.544 .548 .809 r
.31317 .86561 m .31544 .86578 L .31325 .86581 L F
.482 .121 .277 r
.31325 .86581 m .31544 .86578 L .31315 .86599 L F
.426 0 0 r
.31402 .87116 m .3152 .87117 L .31438 .87101 L F
.412 .233 .525 r
.30547 .62224 m .3074 .61934 L .30598 .62019 L F
.55 .436 .677 r
.44047 .7638 m .44303 .76575 L .44224 .76332 L F
.44047 .7638 m .4409 .76617 L .44303 .76575 L F
0 0 0 r
.52338 .7337 m .52145 .73467 L .52537 .73303 L F
.669 .461 .594 r
.55233 .76106 m .55197 .76357 L .54991 .76226 L F
.553 .356 .567 r
.55453 .76285 m .55233 .76106 L .5549 .76058 L F
.55453 .76285 m .55197 .76357 L .55233 .76106 L F
.39 0 .012 r
.35729 .65699 m .35657 .65561 L .35505 .65721 L F
.35729 .65699 m .35882 .65546 L .35657 .65561 L F
.635 .531 .719 r
.34035 .70008 m .34279 .69988 L .34221 .69734 L F
.537 .379 .614 r
.34081 .70277 m .34279 .69988 L .34035 .70008 L F
0 .322 .722 r
.25555 .58542 m .25449 .58507 L .2534 .58514 L F
.25555 .58542 m .25576 .58571 L .25449 .58507 L F
.251 .762 .773 r
.25151 .58627 m .25555 .58542 L .2534 .58514 L F
.458 .887 .855 r
.25555 .58542 m .25361 .58573 L .25529 .58509 L F
.25555 .58542 m .25529 .58509 L .25634 .58469 L F
0 .322 .722 r
.25555 .58542 m .25706 .58635 L .25576 .58571 L F
0 0 0 r
.33322 .71801 m .33292 .7175 L .3348 .71637 L F
.33322 .71801 m .33193 .71861 L .33292 .7175 L F
.531 .367 .604 r
.37033 .6807 m .37046 .68316 L .36836 .68355 L F
.549 .458 .704 r
.37046 .68316 m .36878 .68565 L .36836 .68355 L F
.782 .829 .889 r
.51318 .72845 m .515 .72548 L .51206 .72525 L F
.51318 .72845 m .51624 .7263 L .515 .72548 L F
.524 .386 .635 r
.4423 .75786 m .44436 .75743 L .44408 .75507 L F
.552 .412 .645 r
.44242 .76054 m .44436 .75743 L .4423 .75786 L F
.831 .864 .87 r
.54768 .76916 m .54717 .76869 L .54686 .77067 L F
.5 .475 .761 r
.54686 .77067 m .54797 .77005 L .54768 .76916 L F
.538 .565 .83 r
.54777 .76977 m .54797 .77005 L .54686 .77067 L F
.54978 .76904 m .5507 .77121 L .55001 .77111 L F
.54821 .76991 m .55001 .77111 L .54686 .77067 L F
.54978 .76904 m .55001 .77111 L .54821 .76991 L F
.575 .477 .706 r
.5507 .77121 m .54867 .77218 L .54686 .77067 L F
.5 .475 .761 r
.54686 .77067 m .54867 .77218 L .54797 .77005 L F
.538 .565 .83 r
.5494 .76815 m .54786 .76968 L .54717 .76869 L F
.54786 .76968 m .54686 .77067 L .54703 .76955 L F
.692 .536 .671 r
.54746 .76941 m .54739 .76961 L .5473 .76959 L F
.54768 .76916 m .54755 .76948 L .54746 .76941 L F
.603 .307 .439 r
.5479 .76984 m .54755 .76948 L .54768 .76916 L F
.54797 .77005 m .54777 .76977 L .5479 .76984 L F
.54777 .76977 m .54755 .76948 L .5479 .76984 L F
.692 .536 .671 r
.54716 .76953 m .54457 .77265 L .54475 .77121 L F
.54768 .76916 m .5473 .76959 L .54716 .76953 L F
.5473 .76959 m .54457 .77265 L .54716 .76953 L F
.538 .565 .83 r
.54749 .76962 m .5473 .76959 L .54706 .76939 L F
.831 .864 .87 r
.54768 .76916 m .54716 .76953 L .54717 .76869 L F
.538 .565 .83 r
.54716 .76953 m .54703 .76955 L .54704 .76948 L F
.54716 .76957 m .54703 .76955 L .54716 .76953 L F
.5473 .76959 m .54704 .76948 L .54706 .76939 L F
.831 .864 .87 r
.54716 .76953 m .54475 .77121 L .54717 .76869 L F
.538 .565 .83 r
.5473 .76959 m .54716 .76957 L .54716 .76953 L F
.54786 .76968 m .54749 .76962 L .54717 .76869 L F
.54749 .76962 m .54706 .76939 L .54717 .76869 L F
.692 .536 .671 r
.5473 .76959 m .54572 .77389 L .54457 .77265 L F
.54739 .76961 m .54572 .77389 L .5473 .76959 L F
.54755 .76948 m .54572 .77389 L .54746 .76941 L F
.603 .307 .439 r
.54867 .77218 m .54572 .77389 L .54755 .76948 L F
.54867 .77218 m .54755 .76948 L .54797 .77005 L F
.538 .565 .83 r
.5494 .76815 m .54978 .76904 L .54797 .77005 L F
.5494 .76815 m .54797 .77005 L .54777 .76977 L F
.768 .324 .197 r
.51277 .79645 m .51709 .79818 L .51593 .79837 L F
.878 .543 .412 r
.51709 .79818 m .51698 .79669 L .51593 .79837 L F
.759 .379 .336 r
.51698 .79669 m .51933 .79908 L .51593 .79837 L F
.638 .414 .562 r
.51698 .79669 m .51954 .7966 L .51933 .79908 L F
.983 .729 .467 r
.59863 .70863 m .59757 .71013 L .59748 .70762 L F
.259 .701 .96 r
.63321 .50043 m .63791 .50101 L .63646 .50104 L F
0 0 0 r
.63791 .50101 m .63839 .5007 L .63646 .50104 L F
.706 .7 .841 r
.52276 .79618 m .52653 .79638 L .52371 .79336 L F
.79 .505 .506 r
.52276 .79618 m .52368 .79813 L .52653 .79638 L F
.023 .415 .86 r
.34873 .72481 m .34912 .72409 L .34647 .72242 L F
.757 .282 .115 r
.35116 .72637 m .35058 .72689 L .34873 .72481 L F
0 .118 .67 r
.34873 .72481 m .35058 .72689 L .34912 .72409 L F
.865 .551 .453 r
.60198 .68044 m .60242 .68244 L .60374 .68072 L F
.788 .437 .393 r
.60374 .68072 m .60242 .68244 L .60423 .68269 L F
.521 .278 .488 r
.46771 .74419 m .46992 .74383 L .47012 .74164 L F
.525 .231 .411 r
.46992 .74383 m .47323 .74082 L .47012 .74164 L F
.612 .375 .533 r
.45967 .74924 m .46221 .74684 L .45988 .74707 L F
.814 .801 .308 r
.62015 .73192 m .62072 .73065 L .62075 .72903 L F
.62015 .73192 m .62008 .73281 L .62072 .73065 L F
.366 .038 .271 r
.50888 .71297 m .51223 .71059 L .50987 .71125 L F
.394 0 .157 r
.74367 .58485 m .74126 .58663 L .74283 .58543 L F
.631 .531 .722 r
.50338 .71994 m .50585 .72026 L .50476 .71639 L F
.758 .683 .78 r
.50365 .72154 m .50585 .72026 L .50338 .71994 L F
.681 .408 .502 r
.68081 .52066 m .68043 .52305 L .67933 .52247 L F
.896 .817 .762 r
.50603 .72418 m .50758 .72524 L .50883 .7215 L F
.759 .921 .943 r
.74164 .72135 m .74415 .72122 L .74391 .71855 L F
.809 .818 .858 r
.74391 .71855 m .74415 .72122 L .74641 .71875 L F
.348 0 0 r
.46445 .7894 m .46581 .78913 L .46916 .79007 L F
.505 .096 .199 r
.31308 .86574 m .31544 .86578 L .31317 .86561 L F
.839 .613 .597 r
.61007 .70799 m .60994 .71089 L .6132 .7111 L F
.76 .551 .615 r
.60977 .71328 m .6132 .7111 L .60994 .71089 L F
.60977 .71328 m .61331 .71349 L .6132 .7111 L F
.297 0 0 r
.38438 .64842 m .38658 .64846 L .39022 .64714 L F
.347 0 0 r
.39022 .64714 m .38658 .64846 L .39 .64812 L F
.91 .98 .719 r
.57841 .67711 m .57751 .67982 L .58009 .6773 L F
.57841 .67711 m .57663 .67998 L .57751 .67982 L F
.568 .038 0 r
.45087 .66637 m .45289 .66711 L .45419 .66685 L F
0 .228 .739 r
.45559 .66741 m .45626 .66911 L .45419 .66685 L F
.357 .345 .709 r
.45419 .66685 m .45626 .66911 L .45473 .6691 L F
0 .228 .739 r
.45559 .66741 m .45419 .66685 L .45289 .66711 L F
.897 .502 .261 r
.52238 .76486 m .52458 .76654 L .52332 .76749 L F
.38 0 0 r
.52458 .76654 m .52557 .7678 L .52332 .76749 L F
.52458 .76654 m .5268 .76649 L .52557 .7678 L F
.345 .13 .437 r
.5365 .79375 m .53423 .79678 L .53584 .79637 L F
.41 .313 .634 r
.53584 .79637 m .53423 .79678 L .53624 .79878 L F
.517 .32 .553 r
.53624 .79878 m .53423 .79678 L .53394 .79924 L F
.513 .086 .167 r
.39645 .66671 m .395 .66846 L .39282 .66833 L F
0 0 0 r
.39863 .66692 m .395 .66846 L .39645 .66671 L F
.553 .522 .775 r
.44124 .78018 m .44269 .77647 L .43984 .77694 L F
.44124 .78018 m .44346 .77977 L .44269 .77647 L F
.383 .434 .79 r
.44124 .78018 m .44308 .78108 L .44346 .77977 L F
.182 .668 .926 r
.59044 .70489 m .59188 .70518 L .5925 .70564 L F
0 .236 .752 r
.59188 .70518 m .59242 .7064 L .5925 .70564 L F
.59188 .70518 m .59352 .70698 L .59242 .7064 L F
.294 .022 .318 r
.59352 .70698 m .59112 .71016 L .59242 .7064 L F
.735 .517 .596 r
.59752 .70526 m .59352 .70698 L .59188 .70518 L F
.788 .308 .088 r
.59044 .70489 m .59352 .70698 L .59188 .70518 L F
.657 .82 .962 r
.59752 .70526 m .59188 .70518 L .59543 .70491 L F
.578 .853 .996 r
.59543 .70491 m .59188 .70518 L .59445 .70388 L F
0 0 .199 r
.59352 .70698 m .59445 .70388 L .59188 .70518 L F
.788 .308 .088 r
.5915 .70561 m .5921 .70681 L .59352 .70698 L F
.59044 .70489 m .5921 .70681 L .5915 .70561 L F
.199 0 .272 r
.59242 .7064 m .59208 .70736 L .59173 .70748 L F
.184 .117 .541 r
.5921 .70681 m .59112 .71016 L .59352 .70698 L F
.911 .878 .79 r
.5921 .70681 m .59112 .71016 L .59352 .70698 L F
0 0 .341 r
.59153 .70543 m .59294 .70851 L .5921 .70681 L F
.59294 .70851 m .59321 .7091 L .5921 .70681 L F
0 0 .199 r
.59434 .70422 m .59421 .70635 L .59445 .70388 L F
.59352 .70698 m .59421 .70635 L .59434 .70422 L F
.735 .517 .596 r
.59752 .70526 m .59748 .70762 L .59352 .70698 L F
.6 .094 .022 r
.59748 .70762 m .59575 .70786 L .59352 .70698 L F
.959 .622 .305 r
.59575 .70786 m .59421 .70635 L .59352 .70698 L F
.131 .519 .914 r
.59352 .70698 m .59575 .70786 L .59421 .70635 L F
.708 .559 .683 r
.5948 .70861 m .59412 .70795 L .59421 .70635 L F
.353 .813 .93 r
.59337 .70696 m .59421 .70635 L .5921 .70681 L F
.59352 .70698 m .59363 .70687 L .59337 .70696 L F
.59363 .70687 m .59421 .70635 L .59337 .70696 L F
.708 .559 .683 r
.59412 .70795 m .59153 .70543 L .59421 .70635 L F
.199 0 .272 r
.59173 .70748 m .59112 .71016 L .58967 .71071 L F
.59208 .70736 m .59112 .71016 L .59173 .70748 L F
.591 .779 .97 r
.73543 .62542 m .73841 .6258 L .73792 .62462 L F
.599 .73 .936 r
.73841 .6258 m .74015 .62422 L .73792 .62462 L F
.73841 .6258 m .74112 .6256 L .74015 .62422 L F
.264 .308 .721 r
.68569 .51959 m .68331 .51749 L .68487 .51715 L F
.535 .503 .767 r
.45626 .66911 m .45473 .6718 L .45473 .6691 L F
.871 .716 .688 r
.74594 .71593 m .74889 .7138 L .74683 .71238 L F
.74594 .71593 m .74833 .71564 L .74889 .7138 L F
.442 0 0 r
.63806 .54804 m .63729 .54919 L .63553 .54911 L F
.626 .229 .272 r
.64043 .54769 m .63729 .54919 L .63806 .54804 L F
.629 .724 .916 r
.38297 .70144 m .38098 .70223 L .37977 .70023 L F
.296 0 0 r
.29251 .63521 m .29633 .63343 L .29415 .63373 L F
.878 .81 .778 r
.63342 .51683 m .63526 .51802 L .63666 .51503 L F
.933 .753 .636 r
.63342 .51683 m .63451 .52008 L .63526 .51802 L F
.763 .542 .597 r
.63526 .51802 m .63451 .52008 L .63789 .52033 L F
.57 .554 .797 r
.37164 .69099 m .37077 .69475 L .36988 .69099 L F
.37164 .69099 m .3728 .69437 L .37077 .69475 L F
.656 .748 .918 r
.6606 .51841 m .65755 .51781 L .65929 .5176 L F
.65932 .51761 m .65929 .5176 L .65931 .5176 L F
.6606 .51841 m .65929 .5176 L .65932 .51761 L F
.124 0 .35 r
.65927 .5176 m .66019 .51477 L .66164 .5166 L F
.656 .748 .918 r
.65755 .51781 m .65766 .51765 L .65931 .5176 L F
.124 0 .35 r
.65756 .51831 m .65828 .51734 L .65927 .5176 L F
.65873 .51674 m .66019 .51477 L .65927 .51758 L F
.431 .617 .929 r
.65873 .51674 m .65931 .5176 L .65879 .5167 L F
.65689 .51768 m .65929 .5176 L .65835 .51615 L F
.65929 .5176 m .65931 .5176 L .65835 .51615 L F
.124 0 .35 r
.65828 .51734 m .65873 .51674 L .65927 .5176 L F
.65873 .51674 m .65927 .51758 L .65927 .5176 L F
.65756 .51831 m .66164 .5166 L .65931 .5176 L F
.65756 .51831 m .65901 .51827 L .6597 .51621 L F
.65873 .51674 m .6597 .51621 L .66019 .51477 L F
.65756 .51831 m .6597 .51621 L .65873 .51674 L F
.431 .617 .929 r
.65835 .51615 m .65873 .51674 L .65843 .51607 L F
.65873 .51674 m .65879 .5167 L .65843 .51607 L F
0 0 0 r
.65797 .51725 m .65753 .51885 L .65756 .51831 L F
.65843 .51607 m .6581 .51708 L .65797 .51725 L F
.6581 .51708 m .65753 .51885 L .65797 .51725 L F
.656 .748 .918 r
.65755 .51781 m .65689 .51768 L .65766 .51765 L F
.712 .922 .964 r
.6606 .51841 m .66164 .5166 L .66242 .5172 L F
.6606 .51841 m .65931 .5176 L .66164 .5166 L F
.289 0 0 r
.28681 .60279 m .29037 .60369 L .28866 .60337 L F
.007 .578 .769 r
.2923 .60373 m .28866 .60337 L .29037 .60369 L F
.751 .313 .212 r
.54925 .7469 m .54828 .74846 L .54772 .74679 L F
.54925 .7469 m .55143 .74907 L .54828 .74846 L F
.704 .351 .376 r
.55168 .74752 m .55143 .74907 L .54925 .7469 L F
.423 .094 .3 r
.26309 .61039 m .26176 .61336 L .25977 .61378 L F
.456 .15 .357 r
.26558 .60892 m .2643 .61051 L .26309 .61039 L F
.464 .136 .325 r
.2643 .61051 m .26176 .61336 L .26309 .61039 L F
0 0 0 r
.59449 .72195 m .59729 .71961 L .59398 .71861 L F
.59449 .72195 m .59662 .72089 L .59729 .71961 L F
.701 .8 .333 r
.59729 .71961 m .59801 .71773 L .5994 .7186 L F
.59729 .71961 m .59662 .72089 L .59801 .71773 L F
.508 .26 .474 r
.49348 .75275 m .49045 .75519 L .48898 .75446 L F
.49348 .75275 m .49265 .75489 L .49045 .75519 L F
.49045 .75519 m .49265 .75489 L .49348 .75275 L F
.549 .458 .704 r
.37046 .68316 m .37128 .68552 L .36878 .68565 L F
.436 .324 .627 r
.37128 .68552 m .36936 .68922 L .36878 .68565 L F
.848 .418 .207 r
.54519 .7028 m .54444 .70409 L .54359 .70243 L F
.839 .405 .201 r
.54519 .7028 m .54657 .70538 L .54444 .70409 L F
.935 .621 .42 r
.61748 .72439 m .61799 .72684 L .61894 .72497 L F
.894 .554 .397 r
.61894 .72497 m .61799 .72684 L .61969 .72687 L F
.956 .877 .716 r
.62872 .50408 m .62661 .50577 L .62777 .50319 L F
.62872 .50408 m .62781 .50657 L .62661 .50577 L F
.88 .914 .846 r
.62872 .50408 m .62998 .5005 L .63096 .50149 L F
.62872 .50408 m .62777 .50319 L .62998 .5005 L F
.789 .4 .317 r
.54451 .73984 m .54159 .7397 L .54317 .73798 L F
.54451 .73984 m .54441 .74076 L .54159 .7397 L F
.528 .162 .289 r
.54451 .73984 m .54662 .74068 L .54441 .74076 L F
.683 .567 .718 r
.74251 .71084 m .74379 .71296 L .74568 .711 L F
.71 .453 .535 r
.74379 .71296 m .74683 .71238 L .74568 .711 L F
.56 .316 .502 r
.44408 .75507 m .44648 .75481 L .44667 .75268 L F
.558 .45 .686 r
.44667 .75268 m .44844 .74947 L .44613 .75002 L F
.44667 .75268 m .44918 .7525 L .44844 .74947 L F
.419 .137 .376 r
.44648 .75481 m .44918 .7525 L .44667 .75268 L F
.508 .26 .474 r
.49348 .75275 m .48898 .75446 L .48958 .75221 L F
0 .074 .611 r
.72852 .61992 m .72994 .621 L .72988 .61858 L F
.72852 .61992 m .73081 .62227 L .72994 .621 L F
.921 .632 .477 r
.6751 .52051 m .67395 .52225 L .67373 .51981 L F
.88 .769 .736 r
.67574 .51822 m .6751 .52051 L .67373 .51981 L F
.76 .397 .366 r
.67586 .52237 m .67395 .52225 L .6751 .52051 L F
.707 .372 .407 r
.67933 .52247 m .67586 .52237 L .6751 .52051 L F
.397 .052 .259 r
.40222 .6942 m .40337 .69604 L .40412 .69354 L F
.40222 .6942 m .40127 .69651 L .40337 .69604 L F
.45 .588 .899 r
.75793 .58788 m .75652 .58946 L .75513 .58725 L F
.352 .437 .809 r
.75793 .58788 m .75905 .59101 L .75652 .58946 L F
.626 .573 .774 r
.4668 .76521 m .46336 .76313 L .4665 .76518 L F
.547 .37 .592 r
.46558 .76287 m .4665 .76518 L .46336 .76313 L F
0 0 0 r
.29531 .65225 m .29417 .6526 L .2921 .65299 L F
.054 0 0 r
.29708 .65191 m .29417 .6526 L .29531 .65225 L F
.87 .828 .804 r
.62001 .53423 m .62063 .53639 L .61873 .53645 L F
.878 .873 .827 r
.62063 .53639 m .61711 .53851 L .61873 .53645 L F
.535 .503 .767 r
.45626 .66911 m .45713 .67168 L .45473 .6718 L F
.566 .39 .601 r
.45713 .67168 m .4549 .67434 L .45473 .6718 L F
.627 .671 .873 r
.73104 .72332 m .73235 .721 L .73015 .72128 L F
.73104 .72332 m .73382 .72292 L .73235 .721 L F
.628 .188 .185 r
.73705 .70697 m .74071 .70752 L .73886 .70668 L F
.392 .16 .438 r
.31281 .63938 m .31232 .64162 L .31046 .6423 L F
.213 0 .233 r
.31521 .63686 m .31441 .63866 L .31281 .63938 L F
.354 .126 .423 r
.31408 .64079 m .31281 .63938 L .31441 .63866 L F
.31408 .64079 m .31232 .64162 L .31281 .63938 L F
.647 .875 .983 r
.51586 .76548 m .51316 .76626 L .512 .76572 L F
.54 .37 .599 r
.51316 .76626 m .51532 .76868 L .51308 .76881 L F
.539 .313 .521 r
.43963 .68067 m .43944 .6828 L .43739 .68314 L F
.536 .311 .52 r
.43963 .68067 m .44165 .68245 L .43944 .6828 L F
.57 .306 .476 r
.44192 .68048 m .44165 .68245 L .43963 .68067 L F
.357 0 0 r
.54892 .72624 m .5513 .72693 L .55226 .72689 L F
.56 .077 .067 r
.5513 .72693 m .55181 .72689 L .55226 .72689 L F
.55181 .72689 m .554 .72674 L .55226 .72689 L F
.384 0 0 r
.55268 .72688 m .55226 .72689 L .55358 .72721 L F
.55027 .72601 m .55226 .72689 L .55268 .72688 L F
0 .245 .754 r
.554 .72674 m .55358 .72721 L .55226 .72689 L F
.583 .017 0 r
.55358 .72721 m .55612 .72921 L .55759 .72988 L F
0 .245 .754 r
.554 .72674 m .55612 .72921 L .55358 .72721 L F
.476 .275 .527 r
.3484 .65831 m .34613 .66127 L .34829 .66075 L F
.5 .3 .54 r
.34829 .66075 m .34613 .66127 L .34594 .66357 L F
.215 0 .156 r
.30782 .64465 m .31046 .6423 L .30964 .64388 L F
.286 0 .225 r
.31046 .6423 m .31232 .64162 L .30964 .64388 L F
.613 .914 .98 r
.26331 .64455 m .26545 .64466 L .26488 .64494 L F
.366 .61 .943 r
.75288 .58701 m .75031 .58551 L .75218 .58548 L F
.436 .622 .93 r
.75431 .58555 m .75288 .58701 L .75218 .58548 L F
.428 .608 .923 r
.75431 .58555 m .75513 .58725 L .75288 .58701 L F
.687 .832 .398 r
.30657 .75406 m .30769 .75223 L .30599 .75238 L F
.30657 .75406 m .30597 .75538 L .30769 .75223 L F
.572 .305 .473 r
.65392 .5395 m .65326 .54232 L .6506 .54239 L F
.443 .139 .353 r
.65616 .53928 m .65326 .54232 L .65392 .5395 L F
.661 .585 .76 r
.42593 .67213 m .42698 .6753 L .42945 .67489 L F
.267 0 .304 r
.42698 .6753 m .42819 .67629 L .42945 .67489 L F
.42698 .6753 m .42639 .67708 L .42819 .67629 L F
.88 .769 .736 r
.67574 .51822 m .67373 .51981 L .6763 .51665 L F
.667 .137 0 r
.54319 .72406 m .54659 .7252 L .5447 .72409 L F
.806 .724 .774 r
.61109 .7026 m .60891 .70516 L .61206 .70561 L F
.887 .713 .661 r
.60891 .70516 m .61007 .70799 L .61206 .70561 L F
0 0 .228 r
.61854 .73866 m .6188 .74068 L .61842 .74052 L F
0 0 .251 r
.6197 .73733 m .6188 .74068 L .61854 .73866 L F
.632 .298 .386 r
.45257 .67503 m .45196 .67713 L .4498 .67526 L F
.431 .108 .316 r
.45409 .67666 m .45257 .67503 L .4549 .67434 L F
.45409 .67666 m .45196 .67713 L .45257 .67503 L F
.608 .259 .353 r
.52178 .72766 m .52439 .72937 L .52409 .72798 L F
.52178 .72766 m .52439 .72937 L .52409 .72798 L F
.366 .065 .316 r
.31631 .63808 m .31521 .63686 L .31686 .63601 L F
.31631 .63808 m .31441 .63866 L .31521 .63686 L F
.522 .402 .656 r
.34054 .67499 m .34278 .67766 L .34257 .67446 L F
.34054 .67499 m .3408 .67807 L .34278 .67766 L F
.324 0 0 r
.53028 .76685 m .53107 .76767 L .52913 .76658 L F
.584 .3 .45 r
.4498 .67526 m .44955 .6772 L .44697 .67741 L F
.598 .311 .453 r
.4498 .67526 m .45196 .67713 L .44955 .6772 L F
.59 .535 .761 r
.31315 .86599 m .31544 .86578 L .31308 .86574 L F
.486 .37 .647 r
.34221 .66959 m .34435 .67154 L .34399 .66915 L F
.34221 .66959 m .34249 .67202 L .34435 .67154 L F
.275 .73 .955 r
.3138 .5952 m .31597 .59515 L .31741 .59574 L F
.443 .792 .998 r
.31788 .59467 m .31741 .59574 L .31597 .59515 L F
.31788 .59467 m .31938 .59544 L .31741 .59574 L F
.523 .918 .837 r
.5583 .74975 m .55747 .74983 L .55944 .74875 L F
.5583 .74975 m .55747 .74983 L .55944 .74875 L F
.22 .705 .929 r
.43013 .65282 m .43226 .65283 L .43356 .65331 L F
.311 .758 .961 r
.4343 .65268 m .43356 .65331 L .43226 .65283 L F
.4343 .65268 m .43569 .65317 L .43356 .65331 L F
.877 .714 .676 r
.60793 .69378 m .60922 .69688 L .60966 .69453 L F
.668 .407 .516 r
.54991 .76226 m .54992 .76626 L .54603 .76582 L F
.541 .305 .507 r
.54991 .76226 m .55165 .76523 L .54992 .76626 L F
.734 .365 .352 r
.54991 .76226 m .55197 .76357 L .55165 .76523 L F
.635 .689 .883 r
.54555 .75187 m .54532 .75561 L .54338 .75207 L F
.54555 .75187 m .54769 .75492 L .54532 .75561 L F
0 0 0 r
.54769 .75492 m .54475 .7575 L .54532 .75561 L F
.532 .261 .451 r
.54769 .75492 m .54475 .7575 L .54532 .75561 L F
.563 .315 .498 r
.72372 .58848 m .72144 .58669 L .72093 .58901 L F
.758 .683 .78 r
.50365 .72154 m .50599 .72171 L .50585 .72026 L F
.981 .693 .33 r
.50509 .72167 m .50365 .72154 L .50261 .72411 L F
.042 0 .333 r
.50407 .72282 m .50474 .72166 L .50509 .72167 L F
.725 .659 .785 r
.50585 .72026 m .50599 .72171 L .50806 .71889 L F
.923 .796 .702 r
.50585 .72026 m .50599 .72171 L .50548 .7188 L F
.679 .444 .559 r
.50755 .72048 m .50509 .72167 L .50548 .7188 L F
0 0 .048 r
.50548 .7188 m .50509 .72167 L .50568 .72005 L F
.042 0 .333 r
.50474 .72166 m .50568 .72005 L .50509 .72167 L F
.981 .693 .33 r
.50509 .72167 m .50599 .72171 L .50549 .72167 L F
.50509 .72167 m .50549 .72167 L .50365 .72154 L F
.50509 .72167 m .50603 .72418 L .50599 .72171 L F
.896 .817 .762 r
.50603 .72418 m .50883 .7215 L .50599 .72171 L F
.99 .73 .374 r
.49791 .78186 m .49883 .78266 L .49871 .78011 L F
.409 .145 .399 r
.41675 .69861 m .41483 .69958 L .41731 .69727 L F
.309 0 .079 r
.41564 .7011 m .41483 .69958 L .41675 .69861 L F
.41564 .7011 m .41355 .70157 L .41483 .69958 L F
0 .192 .719 r
.51156 .72467 m .51169 .72432 L .50883 .7215 L F
.513 .434 .704 r
.50883 .7215 m .51169 .72432 L .51114 .72178 L F
.648 .766 .293 r
.51169 .72432 m .51324 .72087 L .51114 .72178 L F
.671 .891 .534 r
.51021 .72594 m .51192 .72365 L .51169 .72432 L F
.51192 .72365 m .51207 .72345 L .51169 .72432 L F
0 .192 .719 r
.51206 .72525 m .51169 .72432 L .51156 .72467 L F
.979 .873 .5 r
.51206 .72525 m .51172 .72689 L .51169 .72432 L F
0 0 0 r
.515 .72548 m .51172 .72689 L .51206 .72525 L F
.34252 .71701 m .34399 .71662 L .34293 .71622 L F
.914 .936 .808 r
.34487 .71323 m .34399 .71662 L .34583 .71421 L F
.467 0 0 r
.34056 .71053 m .34487 .71323 L .34417 .71466 L F
0 0 .308 r
.33999 .70722 m .34056 .71053 L .33998 .70822 L F
.914 .936 .808 r
.34487 .71323 m .34359 .7152 L .34399 .71662 L F
.85 .977 .674 r
.34313 .71484 m .34293 .71622 L .34487 .71323 L F
.249 0 0 r
.34528 .71432 m .34313 .71484 L .34487 .71323 L F
.467 0 0 r
.34089 .71074 m .34386 .71274 L .34487 .71323 L F
.34098 .71081 m .3451 .71358 L .34089 .71074 L F
.286 .39 .794 r
.34159 .70955 m .34385 .71183 L .34056 .71053 L F
.3432 .71092 m .34385 .71183 L .34159 .70955 L F
.467 0 0 r
.34056 .71053 m .34098 .71081 L .34089 .71074 L F
.286 .39 .794 r
.34385 .71183 m .34378 .71269 L .34056 .71053 L F
.781 .475 .469 r
.34541 .71124 m .34487 .71323 L .34834 .71347 L F
.766 .772 .858 r
.34487 .71323 m .34583 .71421 L .34834 .71347 L F
.249 0 0 r
.34528 .71432 m .34487 .71323 L .34535 .71191 L F
0 0 .047 r
.34487 .71323 m .3451 .71358 L .34535 .71191 L F
.702 .543 .669 r
.34535 .71191 m .3451 .71358 L .34197 .70919 L F
.606 .611 .831 r
.34232 .71191 m .34535 .71191 L .34395 .71117 L F
.34205 .71203 m .34252 .71201 L .34232 .71191 L F
.34252 .71201 m .34535 .71191 L .34232 .71191 L F
.467 0 0 r
.34386 .71274 m .3451 .71358 L .34493 .71332 L F
.34386 .71274 m .34493 .71332 L .34487 .71323 L F
0 0 .372 r
.34149 .71155 m .34205 .71203 L .34204 .71172 L F
.286 .39 .794 r
.34197 .70919 m .3432 .71092 L .34159 .70955 L F
0 0 .372 r
.34154 .71129 m .34204 .71172 L .34197 .70919 L F
.34149 .71155 m .34204 .71172 L .34154 .71129 L F
.565 .414 .636 r
.33848 .70979 m .34071 .71082 L .34023 .70839 L F
.33961 .70787 m .34023 .70839 L .33999 .70722 L F
.33848 .70979 m .34023 .70839 L .33961 .70787 L F
.286 .39 .794 r
.34385 .71183 m .3451 .71358 L .34378 .71269 L F
.914 .936 .808 r
.34359 .7152 m .34293 .71622 L .34349 .71643 L F
.34359 .7152 m .34349 .71643 L .34399 .71662 L F
.307 .589 .943 r
.7317 .62306 m .73353 .6223 L .73081 .62227 L F
.7317 .62306 m .73431 .62384 L .73353 .6223 L F
.478 .285 .54 r
.7586 .61615 m .75637 .61437 L .75838 .61378 L F
.7586 .61615 m .75636 .61706 L .75637 .61437 L F
.411 0 .131 r
.47321 .78261 m .47489 .78265 L .47686 .78084 L F
.095 0 0 r
.47489 .78265 m .47823 .78277 L .47686 .78084 L F
.477 0 0 r
.47328 .78191 m .47621 .78269 L .47489 .78265 L F
.095 0 0 r
.47489 .78265 m .47645 .78275 L .47823 .78277 L F
.477 0 0 r
.47621 .78269 m .47645 .78275 L .47489 .78265 L F
.411 0 .131 r
.47269 .78286 m .47489 .78265 L .47321 .78261 L F
.525 .231 .411 r
.46992 .74383 m .47218 .74363 L .47323 .74082 L F
.542 .212 .359 r
.47218 .74363 m .47548 .74116 L .47323 .74082 L F
.284 0 .122 r
.26766 .60862 m .2643 .61051 L .26558 .60892 L F
.765 .599 .672 r
.63981 .50385 m .63993 .50788 L .63684 .5061 L F
.415 .514 .851 r
.64026 .50214 m .63981 .50385 L .63839 .5007 L F
.129 .097 .55 r
.64181 .50485 m .63981 .50385 L .64026 .50214 L F
.562 .374 .584 r
.34829 .66075 m .3505 .65797 L .3484 .65831 L F
.538 0 0 r
.55612 .72921 m .55826 .73047 L .55759 .72988 L F
.169 .685 .891 r
.41763 .65117 m .42128 .6516 L .419 .65201 L F
.467 0 0 r
.49042 .79319 m .4935 .79349 L .4918 .79386 L F
.708 .302 .275 r
.4935 .79349 m .49212 .7954 L .4918 .79386 L F
.4935 .79349 m .49564 .79562 L .49212 .7954 L F
.797 .462 .421 r
.48173 .78522 m .48099 .78318 L .47823 .78277 L F
.507 .897 .95 r
.27517 .65471 m .27348 .65466 L .27282 .65556 L F
.498 .888 .958 r
.27348 .65466 m .27148 .65534 L .27282 .65556 L F
.061 .208 .704 r
.62753 .50869 m .62661 .50577 L .62781 .50657 L F
.781 .72 .796 r
.63373 .51462 m .63666 .51503 L .63549 .51213 L F
.878 .81 .778 r
.63342 .51683 m .63666 .51503 L .63373 .51462 L F
.759 .71 .806 r
.63549 .51213 m .63666 .51503 L .63944 .51317 L F
.555 .335 .536 r
.41468 .68592 m .41693 .68569 L .4171 .68342 L F
.412 .217 .503 r
.4171 .68342 m .41885 .68502 L .41939 .68315 L F
.4171 .68342 m .41693 .68569 L .41885 .68502 L F
.596 .873 .993 r
.5537 .69369 m .5508 .69375 L .55256 .69445 L F
.706 .286 .246 r
.48114 .7556 m .4849 .75701 L .48488 .755 L F
.64 .441 .598 r
.48488 .755 m .4849 .75701 L .48725 .75465 L F
.315 .135 .47 r
.32258 .71727 m .32162 .71919 L .32251 .71864 L F
.467 .41 .711 r
.32162 .71919 m .32309 .72122 L .32251 .71864 L F
.784 .878 .916 r
.63321 .50043 m .62998 .5005 L .63189 .49783 L F
.63321 .50043 m .63096 .50149 L .62998 .5005 L F
.599 .647 .87 r
.63411 .49687 m .63321 .50043 L .63189 .49783 L F
.63411 .49687 m .63791 .50101 L .63321 .50043 L F
.294 .707 .974 r
.28664 .5907 m .28445 .59072 L .28316 .58978 L F
0 0 .55 r
.70404 .59681 m .70439 .59663 L .70267 .59421 L F
0 .183 .689 r
.70404 .59681 m .70551 .59797 L .70439 .59663 L F
.755 .575 .652 r
.34081 .70277 m .34288 .70465 L .34275 .70234 L F
.34081 .70277 m .34171 .70652 L .34288 .70465 L F
.657 .634 .816 r
.34275 .70234 m .34288 .70465 L .34568 .70264 L F
.596 .513 .731 r
.34288 .70465 m .34575 .70433 L .34568 .70264 L F
.447 .43 .747 r
.34288 .70465 m .34587 .70763 L .34575 .70433 L F
.34288 .70465 m .34451 .70851 L .34587 .70763 L F
.445 .168 .398 r
.4194 .69682 m .41675 .69861 L .41731 .69727 L F
.576 .445 .665 r
.43984 .77694 m .44203 .77413 L .4399 .77455 L F
0 .214 .737 r
.55826 .73047 m .56065 .73261 L .56021 .73328 L F
0 .23 .748 r
.56196 .73388 m .56021 .73328 L .56065 .73261 L F
.676 .128 0 r
.56021 .73328 m .56248 .73539 L .56374 .73582 L F
0 .23 .748 r
.56196 .73388 m .56248 .73539 L .56021 .73328 L F
.406 .236 .535 r
.58443 .67891 m .58186 .67783 L .58551 .67829 L F
.276 .746 .942 r
.58827 .67926 m .58443 .67891 L .58551 .67829 L F
.089 .6 .889 r
.40075 .64922 m .40274 .64956 L .4042 .65019 L F
.072 .602 .867 r
.40274 .64956 m .40622 .65033 L .4042 .65019 L F
.393 .188 .479 r
.30768 .61712 m .3092 .61871 L .30964 .61659 L F
.30768 .61712 m .3074 .61934 L .3092 .61871 L F
0 0 .111 r
.52621 .73056 m .52537 .73303 L .52675 .7316 L F
.52621 .73056 m .52675 .7316 L .52439 .72937 L F
.476 .34 .617 r
.37246 .68034 m .37046 .68316 L .37033 .6807 L F
0 0 .336 r
.32258 .71727 m .32251 .71864 L .32398 .71746 L F
.221 0 .183 r
.30782 .64465 m .30682 .6471 L .30527 .64685 L F
.222 0 .094 r
.30527 .64685 m .30595 .64832 L .30399 .64896 L F
.30527 .64685 m .30682 .6471 L .30595 .64832 L F
.985 .707 .383 r
.58706 .72723 m .5873 .72959 L .58822 .73027 L F
.982 .774 .548 r
.58664 .73211 m .58822 .73027 L .5873 .72959 L F
.58664 .73211 m .5882 .73352 L .58822 .73027 L F
.572 .453 .678 r
.34085 .69167 m .34271 .68843 L .34074 .68899 L F
.706 .7 .841 r
.52276 .79618 m .52371 .79336 L .5223 .79423 L F
.718 .565 .68 r
.63451 .52008 m .63768 .5216 L .63789 .52033 L F
.25 .736 .925 r
.63768 .5216 m .64017 .52151 L .63789 .52033 L F
.608 .185 .213 r
.63789 .52033 m .64017 .52151 L .64136 .52048 L F
.436 .324 .627 r
.37128 .68552 m .37113 .68911 L .36936 .68922 L F
.436 .39 .708 r
.37113 .68911 m .36988 .69099 L .36936 .68922 L F
.733 .827 .923 r
.515 .72548 m .51885 .7256 L .51725 .72471 L F
.515 .72548 m .51624 .7263 L .51885 .7256 L F
.586 .412 .613 r
.53569 .75244 m .53575 .7551 L .53349 .75543 L F
.484 .086 .21 r
.5319 .75393 m .53464 .75482 L .53569 .75244 L F
.194 0 .084 r
.53569 .75244 m .53658 .75392 L .53708 .75199 L F
.53569 .75244 m .53464 .75482 L .53658 .75392 L F
.537 .379 .614 r
.34081 .70277 m .34275 .70234 L .34279 .69988 L F
.229 0 0 r
.45065 .74667 m .45409 .74692 L .45183 .74671 L F
.37 .37 .729 r
.30848 .60863 m .30922 .612 L .31065 .61046 L F
.393 .405 .754 r
.30922 .612 m .31151 .6136 L .31065 .61046 L F
.419 .405 .737 r
.30922 .612 m .31001 .61436 L .31151 .6136 L F
.446 .159 .383 r
.6428 .51985 m .64475 .51997 L .64566 .51762 L F
.312 .031 .317 r
.64566 .51762 m .64475 .51997 L .6474 .51867 L F
.052 0 .4 r
.53653 .7326 m .53626 .73517 L .53515 .7357 L F
.667 .588 .757 r
.53626 .73517 m .53623 .73799 L .53515 .7357 L F
.438 .207 .465 r
.32611 .62263 m .32848 .61989 L .32839 .62208 L F
.448 .239 .502 r
.32839 .62208 m .32848 .61989 L .33042 .61953 L F
.477 .228 .456 r
.42209 .6806 m .42424 .68019 L .42458 .67772 L F
.425 .183 .442 r
.42458 .67772 m .42602 .67959 L .42639 .67708 L F
.42458 .67772 m .42424 .68019 L .42602 .67959 L F
.523 .201 .362 r
.53614 .7971 m .5365 .79375 L .53584 .79637 L F
.53614 .7971 m .53879 .79381 L .5365 .79375 L F
.567 .262 .411 r
.36429 .65238 m .36144 .65335 L .36099 .65513 L F
.877 .442 .141 r
.53349 .75543 m .53256 .75555 L .5319 .75393 L F
.126 .418 .863 r
.53349 .75543 m .53464 .75482 L .53256 .75555 L F
.013 0 0 r
.53511 .75719 m .53616 .75706 L .53665 .75677 L F
.53397 .7575 m .53616 .75706 L .53511 .75719 L F
.338 .425 .804 r
.53616 .75706 m .53758 .75705 L .53752 .75688 L F
.681 .629 .791 r
.53957 .75562 m .53665 .75677 L .53575 .7551 L F
.338 .425 .804 r
.53616 .75706 m .53752 .75688 L .53658 .75392 L F
.582 .395 .594 r
.53575 .7551 m .53616 .75706 L .53349 .75543 L F
.126 .418 .863 r
.53349 .75543 m .53616 .75706 L .53464 .75482 L F
.736 .464 .517 r
.61998 .54525 m .61661 .54711 L .61673 .54474 L F
.61998 .54525 m .62023 .54729 L .61661 .54711 L F
.768 .487 .509 r
.62354 .54742 m .62023 .54729 L .61998 .54525 L F
.542 .336 .55 r
.6609 .53678 m .65858 .53936 L .65852 .53716 L F
.537 .766 .982 r
.68281 .51048 m .68406 .51152 L .68185 .512 L F
.712 .984 .891 r
.68185 .512 m .68126 .5117 L .68281 .51048 L F
.537 .766 .982 r
.68281 .51048 m .68406 .51152 L .68185 .512 L F
.436 .217 .482 r
.3238 .62558 m .32611 .62263 L .32597 .62496 L F
.501 .306 .547 r
.32611 .62263 m .32807 .62444 L .32597 .62496 L F
.32611 .62263 m .32839 .62208 L .32807 .62444 L F
.908 .605 .46 r
.57855 .67513 m .57841 .67711 L .58009 .6773 L F
0 0 .03 r
.58009 .6773 m .58171 .67496 L .57855 .67513 L F
.58009 .6773 m .5811 .6767 L .58171 .67496 L F
.772 .379 .311 r
.58009 .6773 m .58248 .68003 L .57908 .67922 L F
.687 .4 .482 r
.58186 .67783 m .58248 .68003 L .58009 .6773 L F
.772 .379 .311 r
.58009 .6773 m .57908 .67922 L .5811 .6767 L F
0 0 0 r
.5533 .68669 m .55102 .68911 L .55234 .6881 L F
0 0 .263 r
.55102 .68911 m .55202 .69041 L .55234 .6881 L F
.55102 .68911 m .55018 .69203 L .55202 .69041 L F
.746 .543 .62 r
.45076 .74903 m .45409 .74692 L .45065 .74667 L F
.45076 .74903 m .45408 .7494 L .45409 .74692 L F
.274 0 0 r
.39009 .64732 m .39374 .64855 L .39506 .64888 L F
.446 .029 .153 r
.64017 .52151 m .6428 .51985 L .64136 .52048 L F
.399 0 0 r
.37143 .65017 m .37456 .64982 L .37228 .6493 L F
.522 .379 .627 r
.30964 .61659 m .31151 .6136 L .31001 .61436 L F
.79 .505 .506 r
.52276 .79618 m .52182 .7987 L .52091 .79688 L F
.52276 .79618 m .52091 .79688 L .52368 .79813 L F
.63 .766 .944 r
.60017 .7577 m .60147 .75547 L .5987 .75678 L F
.60017 .7577 m .60233 .75701 L .60147 .75547 L F
0 0 .362 r
.57804 .71325 m .57843 .71527 L .57816 .71579 L F
0 .145 .69 r
.57843 .71527 m .57964 .71761 L .57816 .71579 L F
.433 .318 .622 r
.32602 .62749 m .3238 .62558 L .32597 .62496 L F
.32602 .62749 m .32384 .62762 L .3238 .62558 L F
.517 .081 .152 r
.49088 .78973 m .49222 .78813 L .48845 .78875 L F
.75 .364 .32 r
.49088 .78973 m .49409 .79023 L .49222 .78813 L F
.759 .71 .806 r
.63549 .51213 m .63944 .51317 L .63761 .51108 L F
.705 .719 .86 r
.63761 .51108 m .63944 .51317 L .64111 .51167 L F
.533 .387 .628 r
.44103 .76853 m .44303 .76575 L .4409 .76617 L F
.829 .58 .562 r
.58705 .72351 m .58967 .72207 L .58839 .72136 L F
.687 .832 .398 r
.30657 .75406 m .30599 .75238 L .30437 .75454 L F
.464 .726 .983 r
.47164 .78135 m .47054 .78249 L .46952 .78139 L F
.401 .625 .943 r
.47164 .78135 m .47269 .78286 L .47054 .78249 L F
.929 .562 .297 r
.45405 .78761 m .4521 .78754 L .44998 .78512 L F
.45405 .78761 m .45364 .78856 L .4521 .78754 L F
.487 .036 .105 r
.45448 .78762 m .45364 .78856 L .45405 .78761 L F
.523 .213 .383 r
.56636 .76041 m .56568 .76276 L .56333 .76282 L F
.58 .267 .403 r
.56888 .76187 m .56636 .76041 L .56863 .76115 L F
.56888 .76187 m .56568 .76276 L .56636 .76041 L F
.877 .714 .676 r
.60793 .69378 m .60666 .69658 L .60922 .69688 L F
.848 .638 .618 r
.60609 .69895 m .60922 .69688 L .60666 .69658 L F
.60609 .69895 m .60799 .69957 L .60922 .69688 L F
.45 .076 .236 r
.6506 .54239 m .64799 .54363 L .64825 .54234 L F
.795 .516 .516 r
.56578 .76582 m .56068 .76306 L .56333 .76282 L F
.56578 .76582 m .56071 .76549 L .56068 .76306 L F
.638 .247 .286 r
.56578 .76582 m .56072 .76795 L .56071 .76549 L F
.56578 .76582 m .56343 .76818 L .56072 .76795 L F
.215 .313 .749 r
.56568 .76276 m .56578 .76582 L .56333 .76282 L F
.56568 .76276 m .56694 .7654 L .56578 .76582 L F
.17 0 .013 r
.56694 .7654 m .56343 .76818 L .56578 .76582 L F
.636 .915 .98 r
.54422 .7936 m .54234 .79455 L .54114 .79384 L F
.54422 .7936 m .54234 .79455 L .54114 .79384 L F
.542 .853 .998 r
.36416 .72418 m .36577 .72497 L .3676 .72431 L F
.469 .331 .61 r
.3676 .72431 m .36778 .72687 L .36577 .72497 L F
.813 .438 .345 r
.52074 .71019 m .52251 .71291 L .52362 .71128 L F
.725 .323 .286 r
.52251 .71291 m .52581 .71325 L .52362 .71128 L F
.524 .796 .995 r
.36012 .72496 m .3639 .72451 L .36078 .72349 L F
.687 .96 .945 r
.36078 .72349 m .35879 .72476 L .36012 .72496 L F
.567 .262 .411 r
.36429 .65238 m .36099 .65513 L .36309 .65467 L F
.431 .051 .216 r
.36522 .65424 m .36429 .65238 L .36309 .65467 L F
.36522 .65424 m .36644 .65207 L .36429 .65238 L F
.884 .488 .272 r
.47029 .76911 m .46872 .76885 L .4668 .76521 L F
.293 .733 .965 r
.47029 .76911 m .47111 .76829 L .46872 .76885 L F
.551 .337 .542 r
.43187 .68614 m .43182 .68848 L .42956 .6888 L F
.481 .215 .433 r
.43435 .68608 m .43182 .68848 L .43187 .68614 L F
.325 .42 .805 r
.46112 .77343 m .4599 .77485 L .45866 .7719 L F
.333 .432 .813 r
.46112 .77343 m .46249 .7766 L .4599 .77485 L F
.493 .494 .786 r
.50883 .7215 m .51017 .71998 L .50806 .71889 L F
.50883 .7215 m .51114 .72178 L .51017 .71998 L F
.23 0 .187 r
.30864 .64621 m .30782 .64465 L .30964 .64388 L F
.30864 .64621 m .30682 .6471 L .30782 .64465 L F
.694 .963 .941 r
.26545 .64466 m .26544 .64365 L .26685 .64376 L F
.613 .914 .98 r
.26331 .64455 m .26544 .64365 L .26545 .64466 L F
.373 0 .153 r
.73163 .59514 m .73337 .59635 L .7309 .59607 L F
.73163 .59514 m .73402 .59463 L .73337 .59635 L F
.446 .029 .153 r
.64017 .52151 m .64249 .52151 L .6428 .51985 L F
.716 .436 .501 r
.64249 .52151 m .64475 .51997 L .6428 .51985 L F
0 0 0 r
.25918 .61564 m .25802 .61427 L .25977 .61378 L F
.25918 .61564 m .25748 .61639 L .25802 .61427 L F
.843 .825 .83 r
.5077 .76899 m .50626 .77129 L .50438 .77039 L F
.697 .193 .037 r
.50626 .77129 m .50502 .77172 L .50438 .77039 L F
.50626 .77129 m .50711 .77249 L .50502 .77172 L F
.686 .597 .751 r
.5077 .76899 m .50818 .77078 L .50626 .77129 L F
.509 .155 .303 r
.50818 .77078 m .50711 .77249 L .50626 .77129 L F
.501 .358 .618 r
.75709 .59735 m .75729 .59982 L .75522 .59792 L F
.317 .341 .727 r
.75729 .59982 m .75635 .60053 L .75522 .59792 L F
.229 .707 .936 r
.25706 .58635 m .25904 .58635 L .26064 .5869 L F
.263 .73 .945 r
.25904 .58635 m .26267 .58682 L .26064 .5869 L F
.608 .804 .975 r
.72673 .61608 m .72579 .6177 L .72406 .6166 L F
.72673 .61608 m .72579 .6177 L .72406 .6166 L F
.978 .721 .315 r
.66154 .51403 m .66164 .5166 L .66242 .5172 L F
.66154 .51403 m .66164 .5166 L .66242 .5172 L F
.328 .704 .982 r
.66164 .5166 m .66457 .51748 L .66242 .5172 L F
.49 .143 .304 r
.46771 .74419 m .46938 .74544 L .46992 .74383 L F
.46771 .74419 m .46685 .74613 L .46938 .74544 L F
.474 .818 .998 r
.30323 .59299 m .30256 .59405 L .30115 .59324 L F
.30323 .59299 m .30483 .59368 L .30256 .59405 L F
.43 .138 .366 r
.48587 .7631 m .4863 .76224 L .48813 .76249 L F
.364 0 0 r
.48813 .76249 m .4863 .76224 L .49032 .76236 L F
.672 .23 .191 r
.47627 .76924 m .47518 .77083 L .47248 .76907 L F
.617 .819 .411 r
.4768 .76834 m .47627 .76924 L .47767 .76787 L F
.4768 .76834 m .47518 .77083 L .47627 .76924 L F
.869 .797 .777 r
.74594 .71593 m .74641 .71875 L .74833 .71564 L F
.396 .424 .772 r
.73325 .70809 m .73564 .70993 L .73566 .70775 L F
.635 .804 .964 r
.7445 .61453 m .74088 .61393 L .74311 .61427 L F
.005 0 0 r
.74311 .61427 m .74685 .61395 L .7445 .61453 L F
.257 0 0 r
.38872 .71309 m .38721 .71476 L .38503 .71525 L F
.185 0 0 r
.39084 .71243 m .39037 .71322 L .38872 .71309 L F
.184 0 0 r
.39037 .71322 m .38721 .71476 L .38872 .71309 L F
.773 .632 .704 r
.54901 .73561 m .54734 .73849 L .55124 .73768 L F
0 .333 .812 r
.55124 .73768 m .55192 .73749 L .54901 .73561 L F
.55124 .73768 m .55229 .73843 L .55192 .73749 L F
0 0 0 r
.35199 .72573 m .35058 .72689 L .35116 .72637 L F
.436 .39 .708 r
.37113 .68911 m .37164 .69099 L .36988 .69099 L F
.456 0 0 r
.53118 .71623 m .53331 .71763 L .53456 .71823 L F
.511 .242 .442 r
.64285 .54544 m .64277 .5473 L .64043 .54769 L F
.486 .221 .438 r
.64506 .54676 m .64277 .5473 L .64285 .54544 L F
.403 0 0 r
.56504 .73669 m .56374 .73582 L .56248 .73539 L F
.882 .561 .436 r
.59923 .67479 m .59961 .67697 L .60194 .67752 L F
.913 .677 .568 r
.59968 .67933 m .60194 .67752 L .59961 .67697 L F
.59968 .67933 m .60198 .68044 L .60194 .67752 L F
.076 0 0 r
.49758 .78925 m .49409 .79023 L .4958 .78957 L F
.497 .22 .424 r
.43739 .68314 m .43652 .68586 L .43435 .68608 L F
.48 .203 .416 r
.43866 .68539 m .43739 .68314 L .43944 .6828 L F
.43866 .68539 m .43652 .68586 L .43739 .68314 L F
.55 0 0 r
.72946 .59029 m .73035 .58963 L .727 .58908 L F
.191 0 0 r
.73186 .59012 m .73035 .58963 L .72946 .59029 L F
.73186 .59012 m .73284 .58941 L .73035 .58963 L F
.462 .46 .77 r
.34451 .70851 m .3472 .71031 L .34587 .70763 L F
.519 .454 .723 r
.34451 .70851 m .34541 .71124 L .3472 .71031 L F
.702 .747 .887 r
.73543 .62542 m .73652 .62263 L .73431 .62384 L F
.73543 .62542 m .73792 .62462 L .73652 .62263 L F
.833 .456 .337 r
.56862 .74119 m .57116 .74319 L .57008 .74178 L F
.457 .098 .267 r
.4137 .68809 m .41693 .68569 L .41468 .68592 L F
.624 .826 .978 r
.59329 .75693 m .59777 .75724 L .59585 .7557 L F
.507 .685 .947 r
.59777 .75724 m .59755 .75432 L .59585 .7557 L F
.59777 .75724 m .5987 .75678 L .59755 .75432 L F
.382 .693 .981 r
.75218 .58548 m .75031 .58551 L .74829 .58405 L F
.311 0 0 r
.58322 .67373 m .58667 .67191 L .58438 .67226 L F
.532 .543 .812 r
.37488 .6946 m .37389 .6976 L .3728 .69437 L F
.37488 .6946 m .37643 .69753 L .37389 .6976 L F
.535 .522 .787 r
.37643 .69753 m .37648 .69885 L .37389 .6976 L F
.674 .346 .411 r
.58266 .71913 m .58475 .72117 L .58585 .71872 L F
.769 .455 .455 r
.58585 .71872 m .58839 .72136 L .58827 .71937 L F
.58585 .71872 m .58475 .72117 L .58839 .72136 L F
.458 .524 .838 r
.46809 .77881 m .467 .78093 L .46586 .77898 L F
.46809 .77881 m .46952 .78139 L .467 .78093 L F
.497 .221 .425 r
.47793 .74119 m .48013 .74076 L .48082 .73801 L F
.513 .234 .428 r
.48013 .74076 m .48304 .73781 L .48082 .73801 L F
.142 .551 .925 r
.52091 .79688 m .51954 .7966 L .51845 .79546 L F
.611 .459 .651 r
.52091 .79688 m .51933 .79908 L .51954 .7966 L F
.245 0 0 r
.38114 .71613 m .37962 .71764 L .37758 .71814 L F
.111 0 0 r
.38191 .71673 m .38114 .71613 L .38316 .71581 L F
.38191 .71673 m .37962 .71764 L .38114 .71613 L F
.847 .901 .874 r
.70403 .59046 m .70297 .58983 L .70384 .58816 L F
.70403 .59046 m .70214 .59212 L .70297 .58983 L F
.479 .549 .85 r
.70574 .5879 m .70403 .59046 L .70384 .58816 L F
.492 .567 .859 r
.70574 .5879 m .70718 .59043 L .70403 .59046 L F
.063 .035 .511 r
.4668 .76521 m .46808 .76549 L .46775 .76276 L F
.668 .44 .567 r
.4668 .76521 m .46872 .76885 L .46631 .76815 L F
.355 .001 .219 r
.53159 .73918 m .52984 .73845 L .53219 .73877 L F
.53159 .73918 m .52927 .7397 L .52984 .73845 L F
.291 .79 .834 r
.26724 .65676 m .26744 .65639 L .26565 .65678 L F
.26724 .65676 m .26958 .65621 L .26744 .65639 L F
0 0 0 r
.515 .72548 m .51376 .72622 L .51245 .72665 L F
.5128 .72642 m .51245 .72665 L .51172 .72689 L F
.515 .72548 m .51245 .72665 L .5128 .72642 L F
.674 .474 .607 r
.51376 .72622 m .5116 .72862 L .51172 .72689 L F
0 0 .224 r
.51172 .72689 m .51197 .72739 L .51169 .72432 L F
.973 .725 .501 r
.51194 .72698 m .51021 .72594 L .51169 .72432 L F
0 0 .018 r
.51172 .72689 m .5116 .72862 L .51197 .72739 L F
.973 .725 .501 r
.51197 .72739 m .51168 .72714 L .51194 .72698 L F
.51168 .72714 m .51021 .72594 L .51194 .72698 L F
.887 .577 .456 r
.59523 .68601 m .59332 .68566 L .59274 .68291 L F
.937 .788 .67 r
.59523 .68601 m .5931 .68747 L .59332 .68566 L F
.59523 .68601 m .59478 .68886 L .5931 .68747 L F
.366 .038 .271 r
.50888 .71297 m .51154 .71329 L .51223 .71059 L F
.238 0 .225 r
.51223 .71059 m .51323 .712 L .51452 .71042 L F
.51223 .71059 m .51154 .71329 L .51323 .712 L F
.552 .706 .942 r
.32717 .59619 m .32637 .59809 L .32511 .59652 L F
.32717 .59619 m .32831 .59772 L .32637 .59809 L F
.398 .523 .867 r
.71582 .60545 m .7141 .60536 L .71306 .60437 L F
.32 .518 .893 r
.33965 .60154 m .33901 .60315 L .33812 .60136 L F
.496 .72 .972 r
.34072 .60265 m .33901 .60315 L .33965 .60154 L F
.468 .509 .817 r
.34188 .60584 m .33901 .60315 L .34072 .60265 L F
.401 .115 .36 r
.55234 .6881 m .55496 .68552 L .5533 .68669 L F
.358 .792 .967 r
.38297 .70144 m .38555 .70118 L .38645 .70156 L F
.086 .634 .831 r
.38555 .70118 m .38855 .70146 L .38645 .70156 L F
.768 .775 .858 r
.35524 .72467 m .35703 .72879 L .35879 .72476 L F
.39 .518 .866 r
.45173 .66492 m .45087 .66637 L .44931 .66381 L F
.407 .541 .878 r
.45173 .66492 m .45289 .66711 L .45087 .66637 L F
.613 .224 .283 r
.50551 .79291 m .50676 .79087 L .50334 .7914 L F
.596 .198 .259 r
.50777 .79321 m .50676 .79087 L .50551 .79291 L F
.50777 .79321 m .50904 .79117 L .50676 .79087 L F
.77 .328 .201 r
.50249 .73555 m .50452 .7377 L .5056 .73658 L F
.485 0 0 r
.5056 .73658 m .50452 .7377 L .50853 .7375 L F
0 0 .267 r
.70267 .59421 m .70297 .58983 L .70214 .59212 L F
0 .216 .737 r
.48275 .75614 m .48114 .7556 L .48007 .7543 L F
.706 .286 .246 r
.48114 .7556 m .48338 .75775 L .4849 .75701 L F
0 .216 .737 r
.48275 .75614 m .48338 .75775 L .48114 .7556 L F
.646 .186 .146 r
.55386 .70873 m .55046 .70851 L .55196 .70875 L F
.662 .617 .794 r
.71285 .60212 m .71306 .60437 L .71019 .60301 L F
.505 .497 .781 r
.71513 .60214 m .71306 .60437 L .71285 .60212 L F
.398 .523 .867 r
.71582 .60545 m .71306 .60437 L .71513 .60214 L F
.383 .06 .29 r
.34036 .60906 m .33957 .61075 L .33763 .61123 L F
.331 .01 .262 r
.34163 .61023 m .34036 .60906 L .34226 .60822 L F
.34163 .61023 m .33957 .61075 L .34036 .60906 L F
.518 .5 .776 r
.47342 .76258 m .47126 .76066 L .47335 .76033 L F
.815 .596 .606 r
.34428 .71903 m .34131 .71878 L .34252 .71701 L F
.34428 .71903 m .34005 .72135 L .34131 .71878 L F
.34428 .71903 m .34252 .71701 L .3424 .72009 L F
.721 .644 .771 r
.50893 .76516 m .50975 .76998 L .5077 .76899 L F
.698 .628 .775 r
.512 .76572 m .50975 .76998 L .50893 .76516 L F
.275 0 .01 r
.49043 .73288 m .4928 .73181 L .4908 .7323 L F
0 0 0 r
.4908 .7323 m .4928 .73181 L .49364 .73148 L F
.692 .843 .955 r
.51753 .74924 m .51537 .74989 L .51418 .74915 L F
.944 .758 .621 r
.51537 .74989 m .51526 .7523 L .51418 .74915 L F
.711 .553 .673 r
.51817 .75213 m .51537 .74989 L .51753 .74924 L F
.51817 .75213 m .51526 .7523 L .51537 .74989 L F
.91 .631 .5 r
.60423 .68269 m .60456 .68522 L .60696 .68594 L F
.927 .679 .543 r
.60456 .68522 m .60704 .68831 L .60696 .68594 L F
.316 0 .013 r
.5875 .73685 m .58976 .73645 L .59089 .73483 L F
.997 .84 .497 r
.59089 .73483 m .58976 .73645 L .58977 .73633 L F
.565 .108 .127 r
.58919 .73462 m .59089 .73483 L .59175 .73367 L F
.255 0 0 r
.58919 .73462 m .58683 .73455 L .59089 .73483 L F
.316 0 .013 r
.5875 .73685 m .59089 .73483 L .58683 .73455 L F
.997 .84 .497 r
.59089 .73483 m .58977 .73633 L .59 .73408 L F
.565 .108 .127 r
.59175 .73367 m .59089 .73483 L .59223 .7335 L F
.583 .863 .537 r
.59223 .7335 m .59205 .73348 L .59308 .73103 L F
.59223 .7335 m .59089 .73483 L .59205 .73348 L F
0 0 0 r
.45558 .78749 m .45448 .78762 L .45689 .78759 L F
.45558 .78749 m .45364 .78856 L .45448 .78762 L F
0 .074 .625 r
.33056 .70779 m .33213 .71008 L .3311 .70705 L F
.715 .568 .688 r
.31429 .87271 m .3152 .87117 L .31402 .87116 L F
.398 .039 .234 r
.25099 .58606 m .2534 .58514 L .25154 .58502 L F
.737 .743 .856 r
.59115 .71871 m .59244 .71993 L .59398 .71861 L F
.095 .637 .848 r
.39708 .64879 m .40075 .64922 L .39733 .64875 L F
.466 .505 .815 r
.47977 .76558 m .47822 .76606 L .47689 .76303 L F
.471 .246 .49 r
.47977 .76558 m .47767 .76787 L .47822 .76606 L F
.518 .153 .286 r
.50684 .71371 m .50914 .71425 L .50888 .71297 L F
.369 .061 .305 r
.50888 .71297 m .50914 .71425 L .51154 .71329 L F
.142 .683 .827 r
.41573 .6645 m .41402 .66433 L .41196 .66449 L F
.221 .743 .816 r
.41777 .66393 m .41402 .66433 L .41573 .6645 L F
.707 .762 .896 r
.74018 .71215 m .74251 .71084 L .73913 .71058 L F
.929 .747 .636 r
.63998 .50844 m .64111 .51167 L .64159 .50937 L F
.775 .594 .654 r
.74071 .70752 m .74251 .71084 L .74324 .70737 L F
.343 .786 .961 r
.40622 .65033 m .40852 .65007 L .40977 .6505 L F
.194 .719 .854 r
.40852 .65007 m .41184 .65004 L .40977 .6505 L F
.476 .284 .539 r
.44436 .75743 m .44648 .75481 L .44408 .75507 L F
.745 .407 .412 r
.62354 .54742 m .62233 .54941 L .62023 .54729 L F
.647 .29 .353 r
.62354 .54742 m .62605 .54948 L .62233 .54941 L F
.665 .274 .294 r
.62574 .54811 m .62605 .54948 L .62354 .54742 L F
.931 .716 .59 r
.60704 .68831 m .60676 .69093 L .60807 .69145 L F
.942 .71 .559 r
.60676 .69093 m .60793 .69378 L .60807 .69145 L F
.639 .308 .395 r
.51117 .79307 m .51333 .79033 L .50904 .79117 L F
.527 .174 .312 r
.51443 .79074 m .51333 .79033 L .51117 .79307 L F
.552 .544 .799 r
.37881 .69841 m .37741 .70074 L .37648 .69885 L F
.37881 .69841 m .37977 .70023 L .37741 .70074 L F
.43 .857 .942 r
.28154 .6532 m .28069 .65409 L .28271 .65386 L F
.28154 .6532 m .27889 .65385 L .28069 .65409 L F
.437 .395 .714 r
.42287 .66909 m .42474 .66993 L .42357 .66531 L F
.137 0 0 r
.39695 .69744 m .39747 .69822 L .39913 .69707 L F
.8 .63 .67 r
.61111 .71614 m .61474 .71672 L .61331 .71349 L F
.826 .647 .661 r
.61111 .71614 m .6144 .71894 L .61474 .71672 L F
.647 .875 .983 r
.51586 .76548 m .512 .76572 L .51448 .76451 L F
0 .133 .654 r
.51679 .76474 m .51586 .76548 L .51448 .76451 L F
.51679 .76474 m .51655 .76639 L .51586 .76548 L F
.176 .712 .801 r
.27388 .58783 m .27648 .58756 L .27534 .58893 L F
.671 .735 .899 r
.42455 .65232 m .42128 .6516 L .42321 .65146 L F
.128 .647 .887 r
.42321 .65146 m .42669 .65207 L .42455 .65232 L F
.169 .515 .916 r
.44435 .783 m .44793 .78535 L .4466 .78235 L F
.549 .561 .819 r
.4466 .78235 m .44793 .78535 L .44998 .78512 L F
.852 .774 .775 r
.70931 .60012 m .71019 .60301 L .7087 .60191 L F
.668 .649 .822 r
.71153 .59927 m .71019 .60301 L .70931 .60012 L F
.71153 .59927 m .71285 .60212 L .71019 .60301 L F
.685 .185 0 r
.71019 .60301 m .71117 .60472 L .7087 .60191 L F
.71019 .60301 m .71217 .6055 L .71117 .60472 L F
.508 .744 .98 r
.29402 .59134 m .29351 .5929 L .29203 .59164 L F
.29402 .59134 m .29536 .59258 L .29351 .5929 L F
.333 .553 .914 r
.48835 .78298 m .48867 .78295 L .48952 .78268 L F
.48835 .78298 m .49094 .78472 L .48867 .78295 L F
.321 0 .022 r
.57294 .67629 m .57528 .67578 L .57626 .67444 L F
.984 .73 .341 r
.57764 .67604 m .57626 .67444 L .57528 .67578 L F
.57764 .67604 m .57855 .67513 L .57626 .67444 L F
.826 .647 .661 r
.61111 .71614 m .61115 .71865 L .6144 .71894 L F
.85 .594 .552 r
.61142 .72093 m .6144 .71894 L .61115 .71865 L F
.61142 .72093 m .61442 .72157 L .6144 .71894 L F
.834 .581 .556 r
.6144 .71894 m .61442 .72157 L .61599 .72153 L F
.487 0 0 r
.54659 .7252 m .54892 .72624 L .55027 .72601 L F
.504 0 0 r
.54892 .72624 m .55226 .72689 L .55027 .72601 L F
.137 .679 .829 r
.74186 .59161 m .7453 .59169 L .74421 .59114 L F
.128 .633 .902 r
.74421 .59114 m .7453 .59169 L .74721 .59181 L F
.634 .915 .98 r
.30192 .60639 m .30496 .60599 L .30352 .60507 L F
.215 .55 .931 r
.30496 .60599 m .30525 .60488 L .30352 .60507 L F
.30496 .60599 m .3064 .60614 L .30525 .60488 L F
.376 .608 .94 r
.32425 .59516 m .32347 .59648 L .32148 .59526 L F
.32425 .59516 m .32511 .59652 L .32347 .59648 L F
.48 .004 .047 r
.54058 .76443 m .53689 .76526 L .53804 .76432 L F
.595 .353 .52 r
.55742 .76247 m .5549 .76058 L .55727 .76046 L F
.55742 .76247 m .55453 .76285 L .5549 .76058 L F
.345 .437 .813 r
.30848 .60863 m .3096 .60713 L .3064 .60614 L F
.30848 .60863 m .30981 .60826 L .3096 .60713 L F
.328 .365 .748 r
.30848 .60863 m .31065 .61046 L .30981 .60826 L F
.835 .777 .797 r
.74594 .71593 m .74391 .71855 L .74641 .71875 L F
.713 .573 .695 r
.51971 .74664 m .51628 .74394 L .51837 .74314 L F
.692 .538 .673 r
.52197 .74391 m .51971 .74664 L .51837 .74314 L F
0 .36 .739 r
.49088 .78973 m .48845 .78875 L .48729 .78804 L F
.523 .445 .71 r
.34221 .69734 m .34358 .69379 L .34125 .69412 L F
.34221 .69734 m .34424 .69695 L .34358 .69379 L F
.529 .475 .741 r
.34221 .69734 m .34478 .6994 L .34424 .69695 L F
.55 .475 .724 r
.34221 .69734 m .34279 .69988 L .34478 .6994 L F
.475 .809 .999 r
.57648 .67527 m .57693 .67532 L .57764 .67604 L F
.984 .73 .341 r
.57764 .67604 m .57843 .67685 L .57855 .67513 L F
.475 .809 .999 r
.57693 .67532 m .57986 .67567 L .57764 .67604 L F
.984 .73 .341 r
.57764 .67604 m .57841 .67711 L .57843 .67685 L F
.677 .571 .728 r
.34275 .70234 m .34478 .6994 L .34279 .69988 L F
0 0 0 r
.51059 .77111 m .50711 .77249 L .50818 .77078 L F
.624 .418 .583 r
.4849 .75701 m .48729 .75784 L .48725 .75465 L F
.353 .206 .538 r
.48725 .75465 m .48875 .75669 L .48898 .75446 L F
.48725 .75465 m .48729 .75784 L .48875 .75669 L F
.106 .651 .834 r
.40987 .66505 m .4085 .66477 L .40568 .66476 L F
.625 .943 .953 r
.41048 .66394 m .40987 .66505 L .41196 .66449 L F
.41048 .66394 m .4085 .66477 L .40987 .66505 L F
.669 .786 .936 r
.56085 .68496 m .56539 .68508 L .56281 .68427 L F
.276 .401 .809 r
.56539 .68508 m .56632 .68532 L .56533 .68235 L F
0 0 0 r
.39988 .70928 m .39958 .70873 L .40143 .70786 L F
.39988 .70928 m .39795 .71004 L .39958 .70873 L F
.661 .585 .76 r
.42593 .67213 m .42945 .67489 L .42825 .67163 L F
.515 .388 .645 r
.42945 .67489 m .4312 .67194 L .42825 .67163 L F
.42945 .67489 m .43149 .67445 L .4312 .67194 L F
.421 .019 .167 r
.42819 .67629 m .43149 .67445 L .42945 .67489 L F
.439 .678 .965 r
.33611 .59965 m .33555 .60124 L .33415 .59936 L F
.33611 .59965 m .33812 .60136 L .33555 .60124 L F
.327 .093 .398 r
.50476 .71639 m .50651 .71577 L .50684 .71371 L F
0 0 .153 r
.50548 .7188 m .50651 .71577 L .50476 .71639 L F
0 0 .279 r
.50476 .71639 m .50585 .72026 L .50548 .7188 L F
.781 .475 .469 r
.34541 .71124 m .34834 .71347 L .3472 .71031 L F
.535 .553 .821 r
.51413 .73999 m .51291 .74275 L .51323 .74268 L F
.57 .62 .862 r
.49094 .78472 m .49177 .78192 L .48867 .78295 L F
.49094 .78472 m .493 .78439 L .49177 .78192 L F
.469 .785 .998 r
.73903 .72173 m .73824 .72084 L .7358 .72125 L F
.73903 .72173 m .73824 .72084 L .7358 .72125 L F
.489 .796 .999 r
.73903 .72173 m .74164 .72135 L .73824 .72084 L F
.73824 .72084 m .74164 .72135 L .73903 .72173 L F
.959 .653 .233 r
.65457 .50639 m .65364 .5054 L .65124 .50618 L F
.65457 .50639 m .6542 .50779 L .65364 .5054 L F
.653 .834 .969 r
.65327 .50655 m .6542 .50779 L .65285 .50653 L F
.959 .653 .233 r
.65457 .50639 m .6552 .50913 L .6542 .50779 L F
0 .339 .82 r
.65646 .50673 m .65707 .50805 L .65457 .50639 L F
.466 .379 .673 r
.65707 .50805 m .65522 .50924 L .65457 .50639 L F
.653 .834 .969 r
.65646 .50673 m .6542 .50779 L .65327 .50655 L F
.959 .653 .233 r
.6552 .50913 m .65522 .50924 L .6542 .50779 L F
0 .339 .82 r
.65646 .50673 m .65457 .50639 L .65364 .5054 L F
.578 .65 .885 r
.69016 .51594 m .69141 .51746 L .68872 .5174 L F
.305 .226 .599 r
.68872 .5174 m .68997 .51666 L .69016 .51594 L F
.522 .716 .961 r
.68997 .51666 m .69141 .51746 L .68872 .5174 L F
.276 .707 .966 r
.30483 .59368 m .30678 .59372 L .30834 .59447 L F
.201 .614 .948 r
.30872 .5937 m .30834 .59447 L .30678 .59372 L F
.30872 .5937 m .31027 .59481 L .30834 .59447 L F
.628 .673 .874 r
.42474 .66993 m .42593 .67213 L .42825 .67163 L F
.691 .834 .951 r
.36551 .72334 m .3676 .72431 L .36766 .72168 L F
.572 .21 .315 r
.36968 .72115 m .36551 .72334 L .36766 .72168 L F
.501 .241 .453 r
.43182 .68848 m .4293 .69079 L .42956 .6888 L F
.116 0 0 r
.73622 .59375 m .73948 .59198 L .73861 .59324 L F
.351 0 .046 r
.73948 .59198 m .74102 .59314 L .73861 .59324 L F
.73948 .59198 m .74186 .59161 L .74102 .59314 L F
.47 .858 .978 r
.53924 .7297 m .5374 .72931 L .53649 .73021 L F
.991 .733 .417 r
.53564 .73035 m .53649 .73021 L .5374 .72931 L F
.53573 .73034 m .53601 .73115 L .53649 .73021 L F
.53601 .73115 m .53653 .7326 L .5365 .73057 L F
.53601 .73115 m .5365 .73057 L .53649 .73021 L F
.733 .696 .815 r
.53315 .73234 m .53653 .7326 L .53564 .73035 L F
.749 .539 .61 r
.53302 .73493 m .53653 .7326 L .53315 .73234 L F
.677 .47 .598 r
.53567 .73155 m .53438 .73301 L .53488 .73151 L F
.991 .733 .417 r
.53572 .73056 m .53653 .7326 L .53573 .73034 L F
.722 .57 .682 r
.53653 .7326 m .53924 .7297 L .53649 .73021 L F
.53653 .7326 m .54191 .73367 L .53924 .7297 L F
.742 .632 .736 r
.53653 .7326 m .53753 .73546 L .54006 .73541 L F
.615 .37 .522 r
.5398 .73074 m .53938 .73378 L .53755 .73377 L F
.495 .223 .43 r
.5398 .73074 m .53909 .73172 L .53908 .7317 L F
.5398 .73074 m .53908 .7317 L .5374 .72931 L F
.677 .47 .598 r
.53909 .73172 m .53447 .73299 L .53468 .73274 L F
.53857 .73184 m .53468 .73274 L .5347 .73271 L F
.53909 .73172 m .53468 .73274 L .53857 .73184 L F
.615 .37 .522 r
.53857 .73184 m .53755 .73377 L .5364 .73376 L F
.5398 .73074 m .53907 .73172 L .53857 .73184 L F
.53907 .73172 m .53755 .73377 L .53857 .73184 L F
.5398 .73074 m .53857 .73184 L .53909 .73172 L F
.53857 .73184 m .5364 .73376 L .53909 .73172 L F
.677 .47 .598 r
.53909 .73172 m .5347 .73271 L .53567 .73155 L F
.53447 .73299 m .53438 .73301 L .53567 .73155 L F
.395 .197 .49 r
.5374 .72931 m .53909 .73172 L .53567 .73155 L F
.53571 .73079 m .53567 .73155 L .53488 .73151 L F
.5374 .72931 m .53567 .73155 L .53571 .73079 L F
.991 .733 .417 r
.53564 .73035 m .53572 .73056 L .53573 .73034 L F
0 0 .019 r
.63998 .50844 m .63993 .50788 L .64181 .50485 L F
.521 .466 .736 r
.3408 .67807 m .34149 .6805 L .34337 .6799 L F
.555 .421 .653 r
.34134 .68263 m .34337 .6799 L .34149 .6805 L F
.969 .672 .406 r
.51592 .79372 m .51443 .79074 L .5147 .79309 L F
.671 .229 .192 r
.51509 .7955 m .51592 .79372 L .5147 .79309 L F
.51509 .7955 m .51845 .79546 L .51592 .79372 L F
.502 .077 .165 r
.2756 .60589 m .27171 .6076 L .27331 .60569 L F
.328 .765 .967 r
.26267 .58682 m .26465 .58663 L .26633 .5872 L F
.271 .75 .931 r
.26465 .58663 m .26822 .58686 L .26633 .5872 L F
.406 .236 .535 r
.58443 .67891 m .58248 .68003 L .58186 .67783 L F
.555 .374 .591 r
.53166 .76075 m .53404 .76061 L .53397 .7575 L F
.479 .315 .58 r
.53397 .7575 m .536 .75996 L .53616 .75706 L F
.53397 .7575 m .53404 .76061 L .536 .75996 L F
.039 .262 .759 r
.71874 .59707 m .71937 .59652 L .71737 .59467 L F
.756 .565 .638 r
.7202 .59911 m .71937 .59652 L .71874 .59707 L F
.451 .854 .969 r
.59121 .75743 m .59234 .75643 L .59002 .75456 L F
.59121 .75743 m .59329 .75693 L .59234 .75643 L F
0 0 0 r
.37456 .64982 m .37672 .64954 L .37777 .64926 L F
.37777 .64926 m .37881 .64907 L .37996 .64885 L F
.37777 .64926 m .37672 .64954 L .37881 .64907 L F
.662 .428 .554 r
.52914 .76274 m .53168 .76311 L .53166 .76075 L F
.416 .235 .525 r
.53166 .76075 m .5335 .76253 L .53404 .76061 L F
.53166 .76075 m .53168 .76311 L .5335 .76253 L F
.538 .465 .721 r
.3408 .67807 m .34337 .6799 L .34278 .67766 L F
.633 .649 .848 r
.65403 .51596 m .65022 .51404 L .65346 .51499 L F
.674 .687 .855 r
.65596 .51429 m .65403 .51596 L .65346 .51499 L F
.552 .412 .645 r
.44242 .76054 m .44422 .76041 L .44436 .75743 L F
.471 .294 .558 r
.44224 .76332 m .44422 .76041 L .44242 .76054 L F
.506 .358 .615 r
.34249 .67202 m .34453 .67397 L .34435 .67154 L F
.34249 .67202 m .34257 .67446 L .34453 .67397 L F
.427 .223 .498 r
.38159 .674 m .38001 .67232 L .38204 .67176 L F
.38159 .674 m .37976 .67462 L .38001 .67232 L F
.612 .375 .533 r
.45967 .74924 m .46204 .74917 L .46221 .74684 L F
.538 .287 .483 r
.46204 .74917 m .46484 .74665 L .46221 .74684 L F
.607 .074 0 r
.59491 .68893 m .5931 .68747 L .59478 .68886 L F
.416 .087 .297 r
.40972 .703 m .40901 .70455 L .40681 .70498 L F
.302 0 .238 r
.41167 .70225 m .40901 .70455 L .40972 .703 L F
0 0 0 r
.50651 .71577 m .50914 .71425 L .50684 .71371 L F
.143 0 0 r
.38691 .66808 m .38433 .66931 L .38474 .66881 L F
0 0 .239 r
.57255 .74356 m .5724 .74616 L .57172 .74697 L F
0 .142 .651 r
.5733 .74799 m .57172 .74697 L .5724 .74616 L F
0 0 0 r
.33322 .71801 m .3348 .71637 L .3334 .71593 L F
.601 .622 .845 r
.3348 .71637 m .33567 .71293 L .3334 .71593 L F
.3348 .71637 m .3374 .71605 L .33567 .71293 L F
.388 .104 .356 r
.32332 .62991 m .32384 .62762 L .32602 .62749 L F
.962 .742 .558 r
.48151 .77128 m .48268 .77443 L .48128 .77402 L F
.672 .629 .798 r
.48493 .77259 m .48268 .77443 L .48151 .77128 L F
.025 .581 .819 r
.48268 .77443 m .48385 .77437 L .48128 .77402 L F
.48268 .77443 m .48512 .77474 L .48385 .77437 L F
.537 0 0 r
.50148 .79064 m .50334 .7914 L .50168 .79041 L F
.652 .327 .409 r
.51817 .75213 m .51751 .7544 L .51526 .7523 L F
.46 .348 .639 r
.5197 .74911 m .51817 .75213 L .51753 .74924 L F
.5197 .74911 m .52046 .75201 L .51817 .75213 L F
.454 .138 .34 r
.51974 .75396 m .51817 .75213 L .52046 .75201 L F
.51974 .75396 m .51751 .7544 L .51817 .75213 L F
.466 .219 .455 r
.66557 .52881 m .66426 .53176 L .66307 .5312 L F
.471 .225 .458 r
.66729 .53021 m .66426 .53176 L .66557 .52881 L F
.562 .402 .622 r
.6675 .5256 m .66807 .52827 L .66557 .52881 L F
.495 .219 .424 r
.66807 .52827 m .66729 .53021 L .66557 .52881 L F
.609 .471 .668 r
.76015 .60842 m .76044 .6109 L .75799 .61123 L F
.515 .329 .567 r
.76044 .6109 m .75838 .61378 L .75799 .61123 L F
.482 .803 1 r
.42114 .66436 m .41988 .66354 L .41777 .66393 L F
.178 .686 .903 r
.42305 .66397 m .41988 .66354 L .42114 .66436 L F
.456 .537 .851 r
.42114 .66436 m .42357 .66531 L .42305 .66397 L F
.761 .569 .638 r
.60977 .71328 m .61111 .71614 L .61331 .71349 L F
.598 .666 .887 r
.32721 .72104 m .33036 .7222 L .32904 .72081 L F
.63 .744 .93 r
.32904 .72081 m .33036 .7222 L .33246 .72156 L F
.603 .307 .439 r
.54867 .77218 m .54836 .7738 L .54572 .77389 L F
.631 .432 .595 r
.5507 .77121 m .54836 .7738 L .54867 .77218 L F
.145 .375 .829 r
.66426 .53176 m .66531 .53285 L .66307 .5312 L F
.56 .395 .615 r
.66307 .5312 m .66531 .53285 L .66299 .5335 L F
0 0 0 r
.5046 .72945 m .50329 .73199 L .50201 .73264 L F
.101 0 .04 r
.50607 .72948 m .50329 .73199 L .5046 .72945 L F
.936 .573 .293 r
.57039 .70807 m .57107 .71047 L .57239 .71097 L F
0 .246 .656 r
.57107 .71047 m .57474 .7126 L .57239 .71097 L F
.805 .447 0 r
.59274 .68291 m .5924 .68258 L .59148 .68 L F
.947 .615 .365 r
.59274 .68291 m .59189 .68493 L .5924 .68258 L F
.59274 .68291 m .59332 .68566 L .59189 .68493 L F
.468 .747 .99 r
.29888 .60637 m .29977 .60514 L .29805 .60483 L F
.29888 .60637 m .30192 .60639 L .29977 .60514 L F
.134 0 .175 r
.28857 .63638 m .28622 .63902 L .28799 .63783 L F
.284 0 .25 r
.29044 .63552 m .28857 .63638 L .28799 .63783 L F
.653 .754 .923 r
.74112 .6256 m .74344 .62486 L .74015 .62422 L F
.576 .445 .665 r
.43984 .77694 m .44269 .77647 L .44203 .77413 L F
0 0 0 r
.28336 .64094 m .28468 .64073 L .28622 .63902 L F
.28622 .63902 m .28652 .6398 L .28799 .63783 L F
.28622 .63902 m .28468 .64073 L .28652 .6398 L F
.622 .58 .787 r
.44931 .66381 m .44783 .66506 L .44594 .66094 L F
.383 .181 .478 r
.75792 .60196 m .75635 .60053 L .75729 .59982 L F
.75792 .60196 m .75594 .60277 L .75635 .60053 L F
0 0 0 r
.7475 .62111 m .7513 .61975 L .75157 .61953 L F
.72 .244 .118 r
.75341 .61871 m .75157 .61953 L .7513 .61975 L F
.783 .666 .734 r
.65967 .51396 m .65596 .51429 L .65471 .51092 L F
.571 .041 0 r
.5703 .72193 m .56947 .72145 L .56741 .7194 L F
.591 .158 0 r
.5703 .72193 m .57087 .7228 L .56947 .72145 L F
.5703 .72193 m .57159 .72385 L .57087 .7228 L F
.963 .712 .508 r
.74301 .71558 m .74391 .71855 L .74594 .71593 L F
.74263 .71553 m .74288 .71612 L .74301 .71558 L F
.74288 .71612 m .74391 .71855 L .74301 .71558 L F
0 0 .105 r
.74282 .71559 m .7418 .71959 L .74227 .71866 L F
.74273 .71674 m .74227 .71866 L .74264 .71793 L F
.74282 .71559 m .74227 .71866 L .74273 .71674 L F
.626 .87 .988 r
.74264 .71793 m .7418 .71959 L .74391 .71855 L F
.386 .168 .457 r
.7418 .71959 m .74164 .72135 L .74391 .71855 L F
.46 .251 .509 r
.5506 .74174 m .55245 .74315 L .55285 .7409 L F
.577 .904 .657 r
.5506 .74174 m .55164 .74052 L .55245 .74315 L F
.5506 .74174 m .54875 .743 L .55164 .74052 L F
.515 .368 .62 r
.74661 .61138 m .74685 .61395 L .74905 .61322 L F
.696 .617 .764 r
.71062 .59604 m .70931 .60012 L .70826 .59752 L F
0 0 .039 r
.59455 .72366 m .59459 .72402 L .59449 .72195 L F
.753 .628 .722 r
.56255 .76012 m .56068 .76306 L .55948 .76038 L F
.649 .492 .656 r
.56333 .76282 m .56068 .76306 L .56255 .76012 L F
.726 .316 .269 r
.629 .54974 m .62574 .54811 L .62911 .54758 L F
.567 .354 .55 r
.62911 .54758 m .63139 .54952 L .629 .54974 L F
.411 .058 .253 r
.4859 .73602 m .4852 .7376 L .48813 .73561 L F
.721 .578 .694 r
.50684 .76602 m .5077 .76899 L .50403 .76896 L F
.584 .498 .723 r
.50893 .76516 m .50684 .76602 L .50669 .76478 L F
.721 .644 .771 r
.50893 .76516 m .5077 .76899 L .50684 .76602 L F
.758 .301 .164 r
.71379 .59269 m .71676 .59467 L .71271 .59354 L F
.338 .802 .931 r
.28648 .65383 m .28447 .65348 L .28271 .65386 L F
.338 .803 .929 r
.28848 .65348 m .28447 .65348 L .28648 .65383 L F
.686 .319 .346 r
.51526 .7523 m .51383 .75433 L .51169 .75244 L F
.682 .314 .344 r
.51751 .7544 m .51383 .75433 L .51526 .7523 L F
.849 .592 .551 r
.58664 .73211 m .58919 .73462 L .5882 .73352 L F
.841 .711 .181 r
.3369 .7197 m .33686 .71835 L .33822 .7191 L F
.969 .77 .579 r
.3374 .71605 m .33822 .7191 L .33686 .71835 L F
.405 .277 .592 r
.34005 .72135 m .33822 .7191 L .34131 .71878 L F
.692 .685 .839 r
.33855 .71962 m .34059 .71827 L .34099 .71749 L F
.34059 .71827 m .34252 .71701 L .3412 .71742 L F
.34059 .71827 m .3412 .71742 L .34099 .71749 L F
.405 .277 .592 r
.34005 .72135 m .33835 .7221 L .33832 .72144 L F
.33916 .72026 m .33832 .72144 L .33822 .7191 L F
.34005 .72135 m .33832 .72144 L .33916 .72026 L F
.463 .117 .293 r
.40412 .69354 m .40641 .69322 L .40714 .69169 L F
.378 .034 .249 r
.40714 .69169 m .40846 .69264 L .40912 .69106 L F
.40714 .69169 m .40641 .69322 L .40846 .69264 L F
0 .01 .58 r
.57356 .72716 m .57159 .72385 L .57245 .7247 L F
0 0 0 r
.65917 .51457 m .65689 .51768 L .65596 .51429 L F
.65917 .51457 m .65843 .51607 L .65689 .51768 L F
.733 .523 .608 r
.74379 .71296 m .74594 .71593 L .74683 .71238 L F
.138 .684 .739 r
.2921 .65299 m .29038 .65312 L .28848 .65348 L F
0 0 0 r
.29225 .65303 m .2921 .65299 L .29417 .6526 L F
.29225 .65303 m .29038 .65312 L .2921 .65299 L F
.443 .139 .353 r
.65616 .53928 m .6555 .54176 L .65326 .54232 L F
.57 .256 .397 r
.65837 .54071 m .65616 .53928 L .65858 .53936 L F
.65837 .54071 m .6555 .54176 L .65616 .53928 L F
.372 .471 .832 r
.73325 .7153 m .73172 .71695 L .73209 .71583 L F
.377 .478 .836 r
.73325 .7153 m .73464 .71834 L .73172 .71695 L F
.427 .539 .868 r
.74721 .59181 m .74878 .59467 L .75033 .59322 L F
.314 .352 .741 r
.75033 .59322 m .74878 .59467 L .75113 .59654 L F
.409 .356 .687 r
.74878 .59467 m .74948 .59712 L .75113 .59654 L F
.565 .222 .346 r
.51169 .75244 m .51186 .75392 L .50958 .7523 L F
.376 .292 .633 r
.51186 .75392 m .51008 .75506 L .50958 .7523 L F
.565 .222 .346 r
.51169 .75244 m .51186 .75392 L .50958 .7523 L F
.546 .819 .997 r
.30437 .75454 m .30597 .75538 L .30657 .75406 L F
.506 .251 .462 r
.41939 .68315 m .42162 .68276 L .42209 .6806 L F
.447 .197 .441 r
.42209 .6806 m .42368 .68218 L .42424 .68019 L F
.42209 .6806 m .42162 .68276 L .42368 .68218 L F
.433 .301 .6 r
.34383 .66663 m .34578 .66885 L .34572 .66585 L F
.34383 .66663 m .34399 .66915 L .34578 .66885 L F
.7 .525 .648 r
.47699 .7606 m .47342 .76258 L .47335 .76033 L F
.47699 .7606 m .47689 .76303 L .47342 .76258 L F
0 0 0 r
.49364 .73148 m .4928 .73181 L .49578 .73071 L F
.66019 .51477 m .65917 .51457 L .66154 .51403 L F
.66019 .51477 m .65843 .51607 L .65917 .51457 L F
.887 .713 .661 r
.60891 .70516 m .60864 .7076 L .61007 .70799 L F
.895 .664 .582 r
.60859 .70988 m .61007 .70799 L .60864 .7076 L F
.60859 .70988 m .60994 .71089 L .61007 .70799 L F
.708 .5 .604 r
.54317 .73798 m .54006 .73541 L .54335 .73567 L F
.563 .39 .605 r
.54521 .73403 m .54606 .73634 L .54335 .73567 L F
.568 .372 .575 r
.54606 .73634 m .54317 .73798 L .54335 .73567 L F
0 0 .343 r
.66824 .52655 m .6675 .5256 L .66762 .52441 L F
.66824 .52655 m .66807 .52827 L .6675 .5256 L F
.731 .437 .482 r
.59227 .6719 m .59585 .67403 L .5957 .6721 L F
.534 .675 .928 r
.73652 .62263 m .73792 .62462 L .74015 .62422 L F
.909 .808 .735 r
.5987 .69714 m .59579 .6989 L .59725 .69626 L F
.5987 .69714 m .59778 .69896 L .59579 .6989 L F
.242 0 .005 r
.60712 .7527 m .60983 .75187 L .6072 .75262 L F
.772 .465 0 r
.57412 .75951 m .57449 .76033 L .57382 .75795 L F
.57412 .75951 m .57382 .75795 L .57519 .75595 L F
.691 .786 .923 r
.50669 .76478 m .50275 .76452 L .50517 .76259 L F
.608 .718 .923 r
.50734 .76233 m .50669 .76478 L .50517 .76259 L F
.50734 .76233 m .5077 .76396 L .50669 .76478 L F
.584 .498 .723 r
.50893 .76516 m .50669 .76478 L .5077 .76396 L F
.822 .536 .506 r
.61455 .72377 m .61599 .72153 L .61442 .72157 L F
.61455 .72377 m .61748 .72439 L .61599 .72153 L F
.413 0 .043 r
.37543 .71859 m .37399 .72022 L .37181 .72028 L F
.188 0 0 r
.37603 .71962 m .37543 .71859 L .37758 .71814 L F
.37603 .71962 m .37399 .72022 L .37543 .71859 L F
.524 .316 .54 r
.3353 .61384 m .33763 .61123 L .33735 .61327 L F
.455 .22 .468 r
.33763 .61123 m .33935 .61266 L .33735 .61327 L F
.33763 .61123 m .33957 .61075 L .33935 .61266 L F
0 0 0 r
.28336 .64094 m .28271 .64152 L .28468 .64073 L F
.839 .585 .555 r
.56783 .70732 m .56898 .70495 L .56731 .70529 L F
.56783 .70732 m .57039 .70807 L .56898 .70495 L F
.649 .81 .961 r
.32563 .71985 m .32309 .72122 L .32721 .72104 L F
.928 .549 .255 r
.32309 .72122 m .325 .72476 L .32721 .72104 L F
.46 .697 .969 r
.32721 .72104 m .32805 .7195 L .32563 .71985 L F
.32721 .72104 m .32904 .72081 L .32805 .7195 L F
.542 .212 .359 r
.47218 .74363 m .47448 .74357 L .47548 .74116 L F
.556 .226 .365 r
.47548 .74116 m .47747 .74266 L .47793 .74119 L F
.47548 .74116 m .47448 .74357 L .47747 .74266 L F
.458 .209 .448 r
.33278 .61648 m .3353 .61384 L .33483 .61626 L F
.411 .133 .378 r
.3353 .61384 m .33673 .61573 L .33483 .61626 L F
.3353 .61384 m .33735 .61327 L .33673 .61573 L F
.401 .162 .434 r
.29879 .63075 m .29833 .63287 L .30067 .63014 L F
0 0 .354 r
.52409 .72798 m .52525 .72803 L .52519 .72603 L F
.52409 .72798 m .52439 .72937 L .52525 .72803 L F
0 0 0 r
.39863 .66692 m .39675 .66788 L .395 .66846 L F
.792 .993 .761 r
.39933 .66521 m .39863 .66692 L .40063 .66588 L F
.39933 .66521 m .39675 .66788 L .39863 .66692 L F
.698 .915 .969 r
.73906 .61507 m .73507 .61577 L .73797 .61413 L F
.723 .907 .959 r
.74088 .61393 m .73906 .61507 L .73797 .61413 L F
.881 .72 .678 r
.62658 .51144 m .62786 .51446 L .62626 .51351 L F
.91 .589 .424 r
.62786 .51446 m .62646 .51589 L .62626 .51351 L F
.991 .794 .542 r
.62753 .51684 m .62646 .51589 L .62786 .51446 L F
.573 .3 .464 r
.56549 .70732 m .56783 .70732 L .56731 .70529 L F
.504 .299 .535 r
.75103 .60577 m .74858 .60878 L .75075 .60691 L F
.588 .542 .771 r
.75103 .60577 m .75259 .60171 L .75099 .60573 L F
.75103 .60577 m .75339 .60529 L .75259 .60171 L F
.688 .468 .583 r
.75075 .60691 m .75339 .60529 L .75103 .60577 L F
.572 .453 .678 r
.34085 .69167 m .343 .69135 L .34271 .68843 L F
.577 .475 .702 r
.34085 .69167 m .34125 .69412 L .343 .69135 L F
.609 .422 .603 r
.52207 .74633 m .51971 .74664 L .52197 .74391 L F
.627 .452 .625 r
.52452 .74345 m .52207 .74633 L .52197 .74391 L F
.36 0 .068 r
.35957 .65686 m .35882 .65546 L .35729 .65699 L F
.35957 .65686 m .36099 .65513 L .35882 .65546 L F
.496 .422 .703 r
.74858 .60878 m .75154 .61067 L .75075 .60691 L F
.267 .681 .968 r
.29618 .60476 m .29647 .60391 L .2945 .60396 L F
.29618 .60476 m .29805 .60483 L .29647 .60391 L F
.679 .444 .559 r
.50755 .72048 m .50548 .7188 L .50806 .71889 L F
.319 0 0 r
.51017 .71998 m .50755 .72048 L .50806 .71889 L F
.506 .879 .975 r
.40387 .66524 m .40541 .66424 L .40291 .66443 L F
.40387 .66524 m .40568 .66476 L .40541 .66424 L F
.637 .55 .74 r
.71069 .59118 m .71283 .58893 L .70961 .58932 L F
.843 .825 .83 r
.5077 .76899 m .50438 .77039 L .50403 .76896 L F
.756 .517 .572 r
.54003 .73803 m .53753 .73546 L .54006 .73541 L F
.919 .628 .475 r
.53753 .73546 m .53868 .73679 L .54006 .73541 L F
.717 .676 .809 r
.54191 .73367 m .54006 .73541 L .54226 .73458 L F
.708 .5 .604 r
.54317 .73798 m .54003 .73803 L .54006 .73541 L F
.387 0 0 r
.53868 .73679 m .54226 .73458 L .54006 .73541 L F
0 0 0 r
.61189 .74936 m .61493 .74678 L .61355 .74836 L F
.722 .942 .629 r
.61493 .74678 m .61721 .74399 L .61565 .74533 L F
.702 .897 .529 r
.61493 .74678 m .61565 .74533 L .61355 .74836 L F
.486 .197 .398 r
.4442 .6803 m .44165 .68245 L .44192 .68048 L F
.767 .675 .761 r
.44717 .74634 m .44844 .74947 L .45065 .74667 L F
.618 .458 .643 r
.45065 .74667 m .44844 .74947 L .45076 .74903 L F
.47 .393 .687 r
.44844 .74947 m .45102 .75195 L .45076 .74903 L F
.44844 .74947 m .44918 .7525 L .45102 .75195 L F
.524 .724 .965 r
.50275 .76452 m .50245 .76477 L .50072 .76556 L F
.781 .623 .684 r
.50245 .76477 m .50217 .76533 L .50072 .76556 L F
.50245 .76477 m .50403 .76896 L .50321 .76856 L F
.50245 .76477 m .50321 .76856 L .50217 .76533 L F
.807 .547 .545 r
.50217 .76533 m .50321 .76856 L .50283 .76523 L F
.50072 .76556 m .50321 .76856 L .50217 .76533 L F
.50072 .76556 m .50069 .76831 L .50321 .76856 L F
.781 .623 .684 r
.50217 .76533 m .50321 .76856 L .50069 .76831 L F
.50217 .76533 m .50069 .76831 L .50072 .76556 L F
.807 .547 .545 r
.50072 .76556 m .50283 .76523 L .50275 .76452 L F
.48 .344 .618 r
.54278 .6965 m .54666 .69767 L .54457 .69698 L F
.533 .387 .628 r
.44103 .76853 m .44316 .76819 L .44303 .76575 L F
.579 .48 .706 r
.44103 .76853 m .44386 .7712 L .44316 .76819 L F
.44103 .76853 m .44167 .77167 L .44386 .7712 L F
0 .142 .674 r
.57758 .73277 m .57752 .73204 L .57565 .73038 L F
0 0 .446 r
.57758 .73277 m .57856 .73404 L .57752 .73204 L F
.57758 .73277 m .57905 .73537 L .57856 .73404 L F
.301 0 .24 r
.61189 .74936 m .6117 .75138 L .60983 .75187 L F
0 0 .16 r
.61189 .74936 m .61355 .74836 L .6117 .75138 L F
.552 .391 .618 r
.46656 .66147 m .46914 .66119 L .46835 .65941 L F
.46835 .65941 m .46914 .66119 L .46656 .66147 L F
.461 .154 .359 r
.42413 .69418 m .42149 .6963 L .42211 .69466 L F
0 0 .364 r
.57231 .77 m .57163 .77159 L .57187 .76907 L F
.753 .563 .639 r
.55453 .76285 m .55165 .76523 L .55197 .76357 L F
0 0 0 r
.52048 .72396 m .51916 .72436 L .51725 .72471 L F
.155 0 0 r
.52358 .72379 m .51916 .72436 L .52048 .72396 L F
.455 .247 .506 r
.56071 .76549 m .55855 .76605 L .56068 .76306 L F
0 0 0 r
.72324 .7146 m .72167 .71642 L .72303 .71495 L F
.456 .387 .69 r
.72167 .71642 m .7231 .71795 L .72303 .71495 L F
.909 .821 .748 r
.59897 .71582 m .60069 .71684 L .5994 .7186 L F
.605 .393 .567 r
.51308 .76881 m .51329 .77088 L .51059 .77111 L F
.535 .342 .566 r
.51532 .76868 m .51329 .77088 L .51308 .76881 L F
0 0 .234 r
.4896 .77985 m .48952 .78268 L .49016 .78126 L F
.599 .052 0 r
.56741 .7194 m .56539 .71793 L .56659 .71873 L F
.029 .599 .76 r
.45908 .78765 m .45558 .78749 L .45689 .78759 L F
.602 .182 .218 r
.47161 .7908 m .47559 .79062 L .47367 .79091 L F
.732 .336 .3 r
.47559 .79062 m .47704 .79139 L .47367 .79091 L F
.543 .609 .869 r
.4449 .65759 m .44298 .65793 L .44132 .65507 L F
.49 .439 .727 r
.34242 .68584 m .34369 .6824 L .34134 .68263 L F
.34242 .68584 m .34425 .68536 L .34369 .6824 L F
.485 .374 .653 r
.34271 .68843 m .34425 .68536 L .34242 .68584 L F
0 .016 .523 r
.59308 .73103 m .59425 .73106 L .59347 .72944 L F
.005 0 0 r
.59308 .73103 m .59205 .73348 L .59425 .73106 L F
.626 .229 .272 r
.64043 .54769 m .63955 .54956 L .63729 .54919 L F
.406 .01 .172 r
.64277 .5473 m .63955 .54956 L .64043 .54769 L F
.985 .809 .584 r
.58274 .74953 m .58166 .74887 L .58334 .74673 L F
.962 .627 .28 r
.58173 .7436 m .58334 .74673 L .58225 .746 L F
.988 .822 .589 r
.58334 .74673 m .58166 .74887 L .58225 .746 L F
.664 .615 .79 r
.44308 .78108 m .44435 .783 L .4466 .78235 L F
.443 .045 .188 r
.40681 .70498 m .40567 .70705 L .40347 .70722 L F
.443 .071 .236 r
.40901 .70455 m .40567 .70705 L .40681 .70498 L F
0 0 .03 r
.61842 .74052 m .61801 .74266 L .61721 .74399 L F
.676 .925 .617 r
.61565 .74533 m .61721 .74399 L .61801 .74266 L F
.496 .215 .417 r
.42705 .69119 m .42633 .69384 L .42413 .69418 L F
.442 .143 .361 r
.4293 .69079 m .42633 .69384 L .42705 .69119 L F
.549 .494 .746 r
.74952 .60078 m .75099 .60573 L .75259 .60171 L F
.755 .709 .809 r
.73235 .721 m .73382 .72292 L .7358 .72125 L F
.226 0 0 r
.30012 .65025 m .29628 .65228 L .29708 .65191 L F
.30012 .65025 m .2984 .65183 L .29628 .65228 L F
.155 0 0 r
.30044 .65126 m .30012 .65025 L .30193 .64943 L F
.30044 .65126 m .2984 .65183 L .30012 .65025 L F
0 0 .03 r
.61842 .74052 m .6188 .74068 L .61801 .74266 L F
.177 .697 .879 r
.39374 .64855 m .39708 .64879 L .39506 .64888 L F
.054 0 0 r
.29708 .65191 m .29628 .65228 L .29417 .6526 L F
.778 .589 .643 r
.43146 .66574 m .42909 .6634 L .43254 .66376 L F
.521 .906 .942 r
.26685 .64376 m .26744 .64284 L .26897 .64311 L F
.26685 .64376 m .26544 .64365 L .26744 .64284 L F
.297 0 0 r
.48338 .75775 m .48729 .75784 L .4849 .75701 L F
.84 .987 .713 r
.57211 .76537 m .57375 .76259 L .57246 .76448 L F
.611 .54 .75 r
.48539 .76541 m .48238 .76373 L .48587 .7631 L F
.51 .301 .531 r
.48813 .76249 m .48539 .76541 L .48587 .7631 L F
.849 .832 .83 r
.62335 .52508 m .62263 .52884 L .62151 .52804 L F
.62335 .52508 m .62467 .52638 L .62263 .52884 L F
.933 .877 .757 r
.62263 .52884 m .62173 .53072 L .62151 .52804 L F
.42 .578 .903 r
.4404 .65329 m .43934 .65488 L .43786 .6531 L F
.4404 .65329 m .44132 .65507 L .43934 .65488 L F
.577 .662 .896 r
.54521 .73403 m .54901 .73561 L .5479 .73481 L F
0 .298 .771 r
.54901 .73561 m .54954 .73545 L .5479 .73481 L F
.54901 .73561 m .55192 .73749 L .54954 .73545 L F
0 0 .244 r
.55229 .73843 m .55244 .73808 L .55192 .73749 L F
.55229 .73843 m .55285 .7409 L .55244 .73808 L F
.224 0 0 r
.28681 .60279 m .28501 .60412 L .28293 .60446 L F
.034 0 0 r
.28713 .60343 m .28681 .60279 L .28866 .60337 L F
.28713 .60343 m .28501 .60412 L .28681 .60279 L F
.509 .005 0 r
.59737 .69136 m .5966 .69062 L .59491 .68893 L F
.995 .76 .409 r
.59654 .69323 m .59737 .69136 L .59759 .69387 L F
.59654 .69323 m .5966 .69062 L .59737 .69136 L F
.289 .727 .965 r
.26822 .58686 m .27038 .58674 L .27186 .58751 L F
.214 .606 .95 r
.27242 .58666 m .27186 .58751 L .27038 .58674 L F
.27242 .58666 m .27388 .58783 L .27186 .58751 L F
.706 .509 .619 r
.73564 .70993 m .73705 .70697 L .73566 .70775 L F
.73564 .70993 m .73913 .71058 L .73705 .70697 L F
.696 .505 .626 r
.73705 .70697 m .73913 .71058 L .74071 .70752 L F
.619 .53 .731 r
.34125 .69412 m .34358 .69379 L .343 .69135 L F
.81 .687 .729 r
.63106 .51965 m .62973 .5227 L .63232 .52278 L F
.818 .678 .709 r
.62871 .52463 m .63203 .5237 L .63232 .52278 L F
.765 .667 .755 r
.63106 .51965 m .63232 .52278 L .63451 .52008 L F
.471 .312 .582 r
.63232 .52278 m .63203 .5237 L .63365 .52402 L F
.668 .522 .677 r
.63232 .52278 m .63435 .52323 L .63451 .52008 L F
.662 .28 .312 r
.63365 .52402 m .63435 .52323 L .63232 .52278 L F
.297 .751 .956 r
.31027 .59481 m .31236 .59469 L .3138 .5952 L F
.337 .76 .975 r
.31236 .59469 m .31597 .59515 L .3138 .5952 L F
0 0 .52 r
.6657 .51869 m .66672 .51987 L .66457 .51748 L F
0 0 .333 r
.6657 .51869 m .66717 .52225 L .66672 .51987 L F
.813 .511 .478 r
.59585 .67403 m .59961 .67697 L .59923 .67479 L F
.445 .168 .398 r
.4194 .69682 m .41872 .69839 L .41675 .69861 L F
.483 .128 .288 r
.41872 .69839 m .41564 .7011 L .41675 .69861 L F
.349 0 0 r
.54414 .72438 m .54535 .72491 L .54659 .7252 L F
.67 .127 0 r
.54403 .72335 m .54678 .72554 L .54535 .72491 L F
.561 0 0 r
.54535 .72491 m .54755 .72616 L .54892 .72624 L F
.67 .127 0 r
.54678 .72554 m .54755 .72616 L .54535 .72491 L F
.349 0 0 r
.54319 .72406 m .54535 .72491 L .54414 .72438 L F
.561 0 0 r
.54535 .72491 m .54892 .72624 L .54659 .7252 L F
.353 .096 .378 r
.55818 .768 m .55618 .76869 L .55855 .76605 L F
.563 .349 .548 r
.56071 .76549 m .55818 .768 L .55855 .76605 L F
0 0 .483 r
.5319 .75393 m .53297 .75222 L .53464 .75482 L F
.5319 .75393 m .53256 .75555 L .53297 .75222 L F
.774 .716 .799 r
.55618 .76869 m .55283 .76846 L .55528 .76577 L F
.613 .306 .427 r
.55618 .76869 m .55472 .77124 L .55286 .77058 L F
.519 .202 .37 r
.55841 .77042 m .55618 .76869 L .55818 .768 L F
.55841 .77042 m .55472 .77124 L .55618 .76869 L F
0 .167 .702 r
.58425 .71993 m .58266 .71913 L .58207 .71769 L F
.58425 .71993 m .58475 .72117 L .58266 .71913 L F
.296 0 0 r
.29251 .63521 m .29468 .6349 L .29633 .63343 L F
.058 0 0 r
.29633 .63343 m .2966 .63425 L .29833 .63287 L F
.29633 .63343 m .29468 .6349 L .2966 .63425 L F
.761 .68 .773 r
.63106 .51965 m .63451 .52008 L .63342 .51683 L F
.718 .565 .68 r
.63451 .52008 m .63435 .52323 L .63768 .5216 L F
.278 .71 .967 r
.42669 .65207 m .42876 .6521 L .43013 .65282 L F
.274 .712 .964 r
.42876 .6521 m .43226 .65283 L .43013 .65282 L F
.531 .453 .713 r
.32251 .71864 m .32563 .71985 L .32398 .71746 L F
.32251 .71864 m .32309 .72122 L .32563 .71985 L F
.4 .082 .306 r
.37881 .67628 m .37761 .67514 L .37976 .67462 L F
.37881 .67628 m .37688 .67677 L .37761 .67514 L F
.489 .518 .814 r
.34351 .60442 m .34188 .60584 L .34072 .60265 L F
.448 .338 .637 r
.34399 .60745 m .34188 .60584 L .34351 .60442 L F
.34399 .60745 m .34226 .60822 L .34188 .60584 L F
.599 .826 .986 r
.27444 .64272 m .27256 .64332 L .27111 .64244 L F
.734 .453 .502 r
.50102 .79654 m .50457 .79649 L .50455 .79851 L F
.656 .391 .506 r
.50823 .79601 m .50455 .79851 L .50457 .79649 L F
.291 0 .041 r
.63768 .5216 m .63365 .52402 L .63688 .52289 L F
.63768 .5216 m .63435 .52323 L .63365 .52402 L F
.25 .736 .925 r
.63768 .5216 m .6389 .52116 L .6392 .52154 L F
0 0 0 r
.63768 .5216 m .63688 .52289 L .6389 .52116 L F
.683 .971 .778 r
.6389 .52116 m .63688 .52289 L .63577 .5233 L F
.6389 .52116 m .63577 .5233 L .63818 .52264 L F
.911 .827 .364 r
.63818 .52264 m .63859 .52077 L .6389 .52116 L F
.63859 .52077 m .63868 .52037 L .6389 .52116 L F
.25 .736 .925 r
.6392 .52154 m .6389 .52116 L .64017 .52151 L F
.885 .626 .543 r
.59118 .71337 m .58952 .71324 L .58967 .71071 L F
.079 .268 .755 r
.59142 .71234 m .59118 .71337 L .58967 .71071 L F
.03 .212 .718 r
.59118 .71337 m .59291 .71572 L .59142 .71234 L F
.7 .912 .968 r
.59142 .71234 m .58952 .71324 L .59118 .71337 L F
.52 .403 .66 r
.59085 .71619 m .59291 .71572 L .59118 .71337 L F
.03 .212 .718 r
.59118 .71337 m .59291 .71572 L .59142 .71234 L F
.15 0 .313 r
.59449 .72195 m .59459 .72402 L .59662 .72089 L F
.58 .004 0 r
.55527 .70209 m .55868 .70407 L .55814 .70302 L F
.695 .526 .655 r
.52927 .7397 m .52629 .74305 L .52704 .74088 L F
.713 .573 .695 r
.51971 .74664 m .51856 .74826 L .51628 .74394 L F
.423 .168 .42 r
.33042 .61953 m .33278 .61648 L .33235 .61892 L F
.405 .149 .408 r
.33235 .61892 m .33278 .61648 L .33483 .61626 L F
.927 .679 .543 r
.60456 .68522 m .60464 .68787 L .60704 .68831 L F
.911 .721 .634 r
.60464 .68787 m .60676 .69093 L .60704 .68831 L F
.007 .578 .769 r
.2923 .60373 m .29077 .60348 L .28866 .60337 L F
.072 .597 .873 r
.2923 .60373 m .29287 .60334 L .29077 .60348 L F
.546 .349 .565 r
.30304 .62512 m .3053 .62459 L .30547 .62224 L F
.412 .233 .525 r
.30547 .62224 m .30724 .62165 L .3074 .61934 L F
.473 .309 .578 r
.3053 .62459 m .30724 .62165 L .30547 .62224 L F
.83 .935 .563 r
.52334 .7632 m .52238 .76486 L .52208 .76466 L F
.525 0 0 r
.5243 .76433 m .52334 .7632 L .52208 .76466 L F
.5243 .76433 m .52559 .76439 L .52334 .7632 L F
.678 .456 .577 r
.45076 .74903 m .45379 .7512 L .45408 .7494 L F
.683 .402 .49 r
.45379 .7512 m .45647 .74948 L .45408 .7494 L F
.563 .319 .505 r
.44697 .67741 m .4465 .68009 L .4442 .6803 L F
.606 .358 .516 r
.44925 .67935 m .44697 .67741 L .44955 .6772 L F
.44925 .67935 m .4465 .68009 L .44697 .67741 L F
.75 .567 .648 r
.59085 .71619 m .59398 .71861 L .59291 .71572 L F
.59085 .71619 m .59115 .71871 L .59398 .71861 L F
.726 .682 .808 r
.59291 .71572 m .59398 .71861 L .5964 .71624 L F
.872 .842 .812 r
.62151 .52804 m .62173 .53072 L .62043 .52956 L F
.901 .783 .722 r
.62173 .53072 m .61874 .53266 L .62043 .52956 L F
.62173 .53072 m .62001 .53423 L .61874 .53266 L F
.37 .463 .825 r
.58423 .7526 m .58555 .75103 L .58274 .74953 L F
.389 .492 .843 r
.58423 .7526 m .58744 .75369 L .58555 .75103 L F
.343 .651 .969 r
.50403 .76896 m .50557 .7682 L .50321 .76856 L F
.724 .889 .498 r
.50438 .77039 m .50557 .7682 L .50403 .76896 L F
.834 .603 .589 r
.71737 .59467 m .71424 .59685 L .71676 .59467 L F
.71737 .59467 m .71707 .59721 L .71424 .59685 L F
.547 .341 .553 r
.71937 .59652 m .71707 .59721 L .71737 .59467 L F
.737 .625 .735 r
.66935 .49725 m .67037 .50065 L .66682 .50065 L F
.745 .507 .571 r
.67037 .50065 m .66651 .50196 L .66682 .50065 L F
.67037 .50065 m .67047 .50289 L .66651 .50196 L F
.631 .554 .75 r
.67225 .49803 m .67037 .50065 L .66935 .49725 L F
.67225 .49803 m .67304 .50047 L .67037 .50065 L F
.491 .232 .449 r
.67304 .50047 m .67047 .50289 L .67037 .50065 L F
.137 0 .202 r
.30304 .62512 m .30086 .62778 L .3024 .62699 L F
.458 .144 .346 r
.30304 .62512 m .3024 .62699 L .30454 .62649 L F
.459 .144 .343 r
.30304 .62512 m .30454 .62649 L .3053 .62459 L F
.464 .136 .325 r
.2643 .61051 m .2641 .61307 L .26176 .61336 L F
.284 0 .122 r
.26766 .60862 m .26642 .61058 L .2643 .61051 L F
.203 0 .271 r
.26569 .61208 m .2643 .61051 L .26642 .61058 L F
.26569 .61208 m .2641 .61307 L .2643 .61051 L F
.717 .676 .809 r
.54191 .73367 m .54226 .73458 L .54215 .73254 L F
.387 0 0 r
.53868 .73679 m .54099 .73662 L .54226 .73458 L F
.076 0 .28 r
.54226 .73458 m .54437 .73215 L .54215 .73254 L F
.54226 .73458 m .54394 .73528 L .54437 .73215 L F
.356 0 0 r
.54226 .73458 m .54366 .73617 L .54394 .73528 L F
.54226 .73458 m .54099 .73662 L .54366 .73617 L F
.42 .266 .565 r
.44203 .77413 m .44386 .7712 L .44167 .77167 L F
.265 .653 .966 r
.28316 .58978 m .28083 .58959 L .27939 .58853 L F
.45 .076 .236 r
.6506 .54239 m .65052 .54371 L .64799 .54363 L F
.412 .046 .231 r
.6506 .54239 m .65259 .54334 L .65052 .54371 L F
.439 0 .061 r
.65326 .54232 m .65259 .54334 L .6506 .54239 L F
.689 .453 .56 r
.34583 .71421 m .34807 .71583 L .34834 .71347 L F
.45 .473 .792 r
.34834 .71347 m .34898 .71003 L .3472 .71031 L F
.34834 .71347 m .34991 .71294 L .34898 .71003 L F
.501 .345 .601 r
.34807 .71583 m .34991 .71294 L .34834 .71347 L F
.629 .724 .916 r
.38297 .70144 m .37977 .70023 L .38188 .69937 L F
.566 .686 .921 r
.38373 .69911 m .38297 .70144 L .38188 .69937 L F
.38373 .69911 m .38555 .70118 L .38297 .70144 L F
.622 .464 .648 r
.52207 .74633 m .5197 .74911 L .51971 .74664 L F
.476 .34 .617 r
.37246 .68034 m .37221 .6828 L .37046 .68316 L F
.473 .33 .606 r
.37221 .6828 m .37247 .68505 L .37046 .68316 L F
.306 .313 .703 r
.37046 .68316 m .37247 .68505 L .37128 .68552 L F
.852 .752 .752 r
.56533 .68235 m .56632 .68532 L .56843 .68249 L F
.816 .974 .673 r
.65022 .51404 m .65111 .51189 L .65208 .51184 L F
.65022 .51404 m .6497 .51397 L .65111 .51189 L F
.606 .652 .869 r
.65208 .51184 m .65346 .51499 L .65022 .51404 L F
.394 0 0 r
.63127 .52477 m .63203 .5237 L .62871 .52463 L F
.422 0 0 r
.63365 .52402 m .63203 .5237 L .63127 .52477 L F
.726 .316 .269 r
.629 .54974 m .62605 .54948 L .62574 .54811 L F
.532 .261 .451 r
.54769 .75492 m .54703 .75733 L .54475 .7575 L F
.637 .192 .179 r
.54921 .7567 m .54769 .75492 L .5497 .75483 L F
.448 .184 .419 r
.54769 .75492 m .54703 .75733 L .54921 .7567 L F
.637 .192 .179 r
.54921 .7567 m .54727 .75673 L .54769 .75492 L F
.295 .468 .861 r
.54711 .75665 m .54687 .75687 L .54711 .75665 L F
.933 .612 .407 r
.54628 .75658 m .54613 .75675 L .54687 .75687 L F
.54628 .75658 m .54687 .75687 L .54691 .75655 L F
.637 .192 .179 r
.54691 .75655 m .54628 .75657 L .54649 .75633 L F
.54727 .75673 m .54649 .75633 L .54769 .75492 L F
.933 .612 .407 r
.54628 .75657 m .54691 .75655 L .54698 .75605 L F
.54628 .75658 m .54691 .75655 L .54628 .75657 L F
.637 .192 .179 r
.54727 .75673 m .54613 .75675 L .54628 .75657 L F
.54727 .75673 m .54628 .75657 L .54691 .75655 L F
.448 .184 .419 r
.54769 .75492 m .54921 .7567 L .5497 .75483 L F
.295 .468 .861 r
.54901 .75488 m .54711 .75665 L .54905 .7549 L F
.54711 .75665 m .54711 .75665 L .54905 .7549 L F
0 0 0 r
.54762 .75498 m .54628 .75657 L .54475 .7575 L F
.54769 .75492 m .54628 .75657 L .54762 .75498 L F
.493 .572 .864 r
.54852 .75178 m .54769 .75492 L .54555 .75187 L F
.5 .365 .629 r
.54769 .75492 m .5497 .75483 L .5493 .75191 L F
.493 .572 .864 r
.54852 .75178 m .5497 .75483 L .54769 .75492 L F
.295 .468 .861 r
.54724 .75417 m .54698 .75605 L .54901 .75488 L F
.54698 .75605 m .54687 .75687 L .54901 .75488 L F
0 0 0 r
.54648 .75633 m .54628 .75657 L .54628 .75657 L F
.54769 .75492 m .54649 .75633 L .54648 .75633 L F
.54649 .75633 m .54628 .75657 L .54648 .75633 L F
.933 .612 .407 r
.54437 .75564 m .54613 .75675 L .54628 .75658 L F
.54437 .75564 m .54628 .75658 L .54724 .75417 L F
.54628 .75658 m .54698 .75605 L .54724 .75417 L F
0 0 0 r
.54628 .75657 m .54613 .75675 L .54582 .75691 L F
.54628 .75657 m .54582 .75691 L .54475 .7575 L F
.583 .575 .81 r
.35395 .72964 m .3568 .73156 L .35785 .73017 L F
.241 0 .125 r
.35964 .72957 m .3568 .73156 L .35785 .73017 L F
.35964 .72957 m .3568 .73156 L .35785 .73017 L F
.354 .049 .301 r
.6072 .75262 m .60734 .75377 L .60485 .75502 L F
.618 .371 .521 r
.60983 .75187 m .60734 .75377 L .6072 .75262 L F
.762 .356 .283 r
.53612 .74062 m .53219 .73877 L .53623 .73799 L F
.53612 .74062 m .5326 .74055 L .53219 .73877 L F
.697 .524 .65 r
.53438 .74273 m .5326 .74055 L .53612 .74062 L F
.414 .291 .602 r
.53796 .73798 m .53612 .74062 L .53623 .73799 L F
.53796 .73798 m .53796 .74027 L .53612 .74062 L F
.553 .166 .262 r
.539 .7421 m .53612 .74062 L .53796 .74027 L F
.539 .7421 m .53438 .74273 L .53612 .74062 L F
0 .165 .693 r
.58144 .74117 m .58178 .74061 L .58034 .73833 L F
.741 .533 0 r
.58144 .74117 m .58173 .7436 L .58158 .74283 L F
.58144 .74117 m .58158 .74283 L .58178 .74061 L F
.893 .47 .136 r
.53219 .73877 m .5326 .74055 L .53159 .73918 L F
.529 0 0 r
.47012 .79024 m .47006 .79066 L .46916 .79007 L F
.47012 .79024 m .47161 .7908 L .47006 .79066 L F
.135 .005 .426 r
.30086 .62778 m .30188 .62906 L .3024 .62699 L F
.30086 .62778 m .30067 .63014 L .30188 .62906 L F
.359 .703 .984 r
.41633 .65015 m .41534 .65109 L .4139 .65005 L F
.41633 .65015 m .41763 .65117 L .41534 .65109 L F
.675 .288 .305 r
.50777 .79321 m .51117 .79307 L .50904 .79117 L F
.656 .391 .506 r
.50823 .79601 m .50687 .79913 L .50455 .79851 L F
.636 .297 .38 r
.50823 .79601 m .51006 .79726 L .50687 .79913 L F
.50823 .79601 m .51019 .79622 L .51006 .79726 L F
.548 0 0 r
.45908 .78765 m .46238 .7884 L .46058 .78828 L F
.532 0 0 r
.46445 .7894 m .46058 .78828 L .46238 .7884 L F
.718 .189 0 r
.63684 .5061 m .63998 .50844 L .63764 .50892 L F
.975 .773 .569 r
.58489 .70472 m .5858 .70811 L .5845 .7072 L F
.969 .663 .379 r
.5858 .70811 m .58483 .70952 L .5845 .7072 L F
.762 .679 .771 r
.58822 .70507 m .5858 .70811 L .58489 .70472 L F
.905 .534 .317 r
.5858 .70811 m .58647 .71037 L .58483 .70952 L F
.802 .477 .439 r
.58967 .71071 m .58647 .71037 L .5858 .70811 L F
.738 .82 .915 r
.62655 .52522 m .62467 .52638 L .62335 .52508 L F
.58 .644 .879 r
.73015 .72128 m .73133 .71775 L .72871 .7186 L F
.73015 .72128 m .73235 .721 L .73133 .71775 L F
.893 .493 .251 r
.50216 .79235 m .50334 .7914 L .50148 .79064 L F
.638 .125 .01 r
.50551 .79291 m .50334 .7914 L .50216 .79235 L F
.224 .497 .901 r
.72712 .71835 m .72789 .71737 L .72563 .71742 L F
.72712 .71835 m .72871 .7186 L .72789 .71737 L F
.541 .802 .993 r
.76165 .60704 m .76015 .60842 L .75924 .60749 L F
.536 .43 .681 r
.76015 .60842 m .76331 .61097 L .76119 .60869 L F
.76015 .60842 m .76119 .60869 L .76105 .60911 L F
.76015 .60842 m .76105 .60911 L .76044 .6109 L F
.367 .231 .56 r
.76253 .61224 m .76044 .6109 L .76105 .60911 L F
.76136 .60914 m .76105 .60911 L .76119 .60869 L F
.321 .414 .801 r
.76323 .61079 m .76331 .61097 L .76036 .60859 L F
.7604 .60861 m .76036 .60859 L .76015 .60842 L F
.76323 .61079 m .76036 .60859 L .7604 .60861 L F
.503 .424 .7 r
.76502 .60978 m .76331 .61097 L .76119 .60869 L F
.576 .565 .805 r
.76502 .60978 m .76331 .61097 L .76289 .60998 L F
.545 .331 .54 r
.76502 .60978 m .76308 .60996 L .76119 .60869 L F
.76413 .61066 m .76136 .60914 L .76119 .60869 L F
.576 .565 .805 r
.76502 .60978 m .76289 .60998 L .76165 .60704 L F
.545 .331 .54 r
.76502 .60978 m .76413 .61066 L .76308 .60996 L F
.321 .414 .801 r
.76258 .60924 m .76323 .61079 L .76105 .60911 L F
.545 .331 .54 r
.76413 .61066 m .76253 .61224 L .76136 .60914 L F
.367 .231 .56 r
.76253 .61224 m .76105 .60911 L .76136 .60914 L F
.321 .414 .801 r
.76165 .60704 m .76258 .60924 L .76015 .60842 L F
.76258 .60924 m .76105 .60911 L .76015 .60842 L F
.143 0 0 r
.38691 .66808 m .38636 .66879 L .38433 .66931 L F
.37 0 .014 r
.38939 .66734 m .38636 .66879 L .38691 .66808 L F
.479 .504 .806 r
.37363 .69108 m .3728 .69437 L .37164 .69099 L F
.37363 .69108 m .37488 .6946 L .3728 .69437 L F
.107 0 0 r
.32112 .72223 m .32309 .72122 L .32124 .72218 L F
.523 .354 .593 r
.32112 .72223 m .3204 .72578 L .32367 .7242 L F
.32112 .72223 m .32367 .7242 L .32167 .72292 L F
.107 0 0 r
.32112 .72223 m .32167 .72292 L .32309 .72122 L F
.902 .525 .307 r
.32167 .72292 m .32367 .7242 L .32309 .72122 L F
.928 .549 .255 r
.32309 .72122 m .32367 .7242 L .325 .72476 L F
.999 .797 .498 r
.5872 .71339 m .58967 .71071 L .58952 .71324 L F
.5872 .71339 m .58647 .71037 L .58967 .71071 L F
.079 .268 .755 r
.59142 .71234 m .58967 .71071 L .59112 .71016 L F
.375 .632 .954 r
.33208 .59965 m .32831 .59772 L .33095 .59832 L F
.52 .701 .952 r
.33415 .59936 m .33208 .59965 L .33095 .59832 L F
.292 0 0 r
.5268 .76649 m .52784 .76713 L .52557 .7678 L F
.5268 .76649 m .52913 .76658 L .52784 .76713 L F
.238 .339 .765 r
.57122 .76359 m .56888 .76187 L .57085 .76237 L F
.592 .116 .092 r
.47689 .76303 m .47516 .76299 L .47342 .76258 L F
.801 .611 .645 r
.52182 .7987 m .52519 .79905 L .52285 .80113 L F
.749 .522 .587 r
.52519 .79905 m .52604 .80098 L .52285 .80113 L F
.661 .55 .718 r
.52748 .79597 m .52747 .79923 L .52519 .79905 L F
.688 .518 .652 r
.52747 .79923 m .52604 .80098 L .52519 .79905 L F
.476 .284 .539 r
.44436 .75743 m .44639 .75707 L .44648 .75481 L F
.483 .355 .63 r
.44436 .75743 m .44649 .75977 L .44639 .75707 L F
.44436 .75743 m .44422 .76041 L .44649 .75977 L F
.401 .721 .989 r
.49156 .76247 m .4926 .7616 L .49032 .76236 L F
.49156 .76247 m .49377 .76253 L .4926 .7616 L F
.502 .21 .402 r
.41885 .68502 m .42162 .68276 L .41939 .68315 L F
.427 .398 .724 r
.68658 .51321 m .68462 .51548 L .68406 .51152 L F
0 0 0 r
.68658 .51321 m .68429 .51603 L .68462 .51548 L F
.528 .371 .612 r
.5479 .73481 m .54606 .73634 L .54521 .73403 L F
.973 .856 .663 r
.59778 .69896 m .59555 .70159 L .59579 .6989 L F
.59778 .69896 m .59661 .70232 L .59555 .70159 L F
.658 .645 .826 r
.73704 .71182 m .73913 .71058 L .73564 .70993 L F
0 0 0 r
.51059 .77111 m .50982 .77155 L .50711 .77249 L F
.51329 .77088 m .50982 .77155 L .51059 .77111 L F
.607 .615 .834 r
.72963 .71678 m .72525 .7135 L .7276 .71323 L F
.642 .644 .837 r
.73209 .71583 m .72963 .71678 L .7276 .71323 L F
.999 .825 .534 r
.49791 .78186 m .49753 .78436 L .49883 .78266 L F
.999 .797 .493 r
.6542 .50779 m .65522 .50924 L .65471 .51092 L F
.768 .674 .759 r
.65707 .50805 m .65471 .51092 L .65522 .50924 L F
.5 .3 .54 r
.34829 .66075 m .34594 .66357 L .34795 .66293 L F
.464 .255 .51 r
.34594 .66357 m .34795 .66537 L .34795 .66293 L F
.34594 .66357 m .34572 .66585 L .34795 .66537 L F
.531 .361 .596 r
.46775 .76276 m .4665 .76518 L .46558 .76287 L F
.74 .668 .78 r
.63761 .51108 m .64111 .51167 L .63998 .50844 L F
.397 .541 .882 r
.63577 .49636 m .63791 .50101 L .63411 .49687 L F
.894 .847 .79 r
.63986 .49902 m .64026 .50214 L .63839 .5007 L F
0 0 0 r
.63791 .50101 m .63907 .50028 L .63839 .5007 L F
.035 0 .401 r
.63839 .5007 m .63907 .50028 L .63986 .49902 L F
.397 .541 .882 r
.63577 .49636 m .63907 .50028 L .63791 .50101 L F
.854 .939 .878 r
.32124 .72218 m .31898 .72448 L .32112 .72223 L F
.553 .382 .604 r
.31898 .72448 m .3204 .72578 L .32112 .72223 L F
.721 .691 .82 r
.42357 .66531 m .4271 .66602 L .42545 .66383 L F
.467 .241 .486 r
.42474 .66993 m .4271 .66602 L .42357 .66531 L F
.42474 .66993 m .42708 .66911 L .4271 .66602 L F
.184 .441 .87 r
.4271 .66602 m .42771 .66463 L .42545 .66383 L F
.581 .33 .501 r
.4271 .66602 m .42919 .66688 L .42771 .66463 L F
.4271 .66602 m .42901 .66753 L .42919 .66688 L F
.4271 .66602 m .42708 .66911 L .42901 .66753 L F
.583 .575 .81 r
.35395 .72964 m .35545 .73297 L .3568 .73156 L F
.797 .496 .481 r
.7266 .59063 m .727 .58908 L .72372 .58848 L F
.55 .25 .412 r
.72946 .59029 m .727 .58908 L .7266 .59063 L F
.738 .243 .059 r
.59002 .75456 m .58744 .75369 L .58942 .75476 L F
.331 0 .148 r
.32767 .71549 m .32974 .71504 L .33085 .71312 L F
.52 .474 .745 r
.33085 .71312 m .33333 .71368 L .33213 .71008 L F
.365 0 .002 r
.32974 .71504 m .33333 .71368 L .33085 .71312 L F
0 0 .119 r
.62031 .7341 m .62008 .73281 L .62015 .73192 L F
.62031 .7341 m .62042 .73523 L .62008 .73281 L F
.423 .764 .996 r
.29053 .59075 m .28999 .59184 L .2886 .59067 L F
.29053 .59075 m .29203 .59164 L .28999 .59184 L F
.441 .363 .673 r
.74948 .59712 m .74952 .60078 L .7518 .59882 L F
.531 .513 .781 r
.74952 .60078 m .75259 .60171 L .7518 .59882 L F
.481 .215 .433 r
.43435 .68608 m .434 .68812 L .43182 .68848 L F
.407 .151 .41 r
.43598 .68745 m .43435 .68608 L .43652 .68586 L F
.43598 .68745 m .434 .68812 L .43435 .68608 L F
.643 .293 .363 r
.4616 .77311 m .46112 .77343 L .45866 .7719 L F
.796 .504 .495 r
.526 .71506 m .52906 .71365 L .52581 .71325 L F
.526 .71506 m .52937 .71576 L .52906 .71365 L F
.169 .685 .891 r
.41763 .65117 m .41964 .65117 L .42128 .6516 L F
.07 .626 .81 r
.41964 .65117 m .42321 .65146 L .42128 .6516 L F
.58 .609 .846 r
.73464 .71834 m .7358 .72125 L .73492 .71996 L F
.757 .704 .802 r
.73235 .721 m .7358 .72125 L .73464 .71834 L F
.441 .363 .673 r
.74948 .59712 m .7518 .59882 L .75113 .59654 L F
.743 .514 .583 r
.67933 .52247 m .67771 .52483 L .67586 .52237 L F
.738 .54 .625 r
.68043 .52305 m .67771 .52483 L .67933 .52247 L F
.907 .739 .241 r
.74282 .71559 m .74263 .71553 L .74287 .71407 L F
.683 .567 .718 r
.74251 .71084 m .74287 .71407 L .74379 .71296 L F
.774 .527 .562 r
.74263 .71553 m .74379 .71296 L .74287 .71407 L F
.095 .637 .848 r
.39708 .64879 m .3993 .64891 L .40075 .64922 L F
.327 .811 .871 r
.60485 .75502 m .60147 .75547 L .60233 .75701 L F
.169 0 0 r
.72303 .71495 m .72525 .7135 L .72324 .7146 L F
.252 .356 .777 r
.55091 .69835 m .54961 .69967 L .54842 .69638 L F
.219 .305 .739 r
.55091 .69835 m .55183 .70176 L .54961 .69967 L F
.956 .649 .225 r
.55742 .6851 m .55869 .6885 L .56085 .68496 L F
.735 .681 .798 r
.71479 .59981 m .71285 .60212 L .71153 .59927 L F
.505 .497 .781 r
.71513 .60214 m .71285 .60212 L .71479 .59981 L F
.765 .591 .662 r
.73913 .71058 m .74251 .71084 L .74071 .70752 L F
.542 .336 .55 r
.6609 .53678 m .66091 .53888 L .65858 .53936 L F
.555 .349 .556 r
.66308 .53595 m .66091 .53888 L .6609 .53678 L F
.677 .571 .728 r
.34275 .70234 m .34568 .70264 L .34478 .6994 L F
.562 .374 .584 r
.34829 .66075 m .3504 .66031 L .3505 .65797 L F
.549 .28 .46 r
.35236 .65962 m .3505 .65797 L .3504 .66031 L F
.35236 .65962 m .35287 .65751 L .3505 .65797 L F
.468 .648 .937 r
.25754 .5843 m .25706 .58635 L .25555 .58542 L F
.25754 .5843 m .25904 .58635 L .25706 .58635 L F
.674 .688 .856 r
.65596 .51429 m .65346 .51499 L .65208 .51184 L F
.237 .733 .913 r
.54084 .7295 m .5374 .72931 L .53924 .7297 L F
.59 .529 .755 r
.53924 .7297 m .54215 .73254 L .54084 .7295 L F
.53924 .7297 m .54191 .73367 L .54215 .73254 L F
.999 .797 .498 r
.5872 .71339 m .58633 .71325 L .58647 .71037 L F
.549 .926 .921 r
.58829 .7123 m .5872 .71339 L .58952 .71324 L F
.58829 .7123 m .58633 .71325 L .5872 .71339 L F
.493 .363 .632 r
.47083 .66009 m .46914 .66119 L .46835 .65941 L F
.46835 .65941 m .46914 .66119 L .47083 .66009 L F
.758 .709 .806 r
.3204 .72578 m .3224 .72721 L .325 .72476 L F
.599 .074 0 r
.47367 .79091 m .47704 .79139 L .47601 .79234 L F
.663 .151 .014 r
.47601 .79234 m .47704 .79139 L .47933 .79308 L F
.36 .41 .778 r
.50321 .76856 m .50415 .76407 L .50275 .76452 L F
.50321 .76856 m .50557 .7682 L .50415 .76407 L F
.779 .733 .81 r
.55165 .69597 m .54842 .69638 L .5508 .69375 L F
.252 .356 .777 r
.55091 .69835 m .54842 .69638 L .55165 .69597 L F
.085 .29 .773 r
.5508 .69375 m .55263 .69535 L .55165 .69597 L F
0 0 0 r
.55263 .69535 m .55091 .69835 L .55165 .69597 L F
.504 .368 .629 r
.5493 .75191 m .55151 .75398 L .55235 .75153 L F
.694 .762 .904 r
.55446 .75086 m .55367 .75044 L .55326 .75077 L F
.55401 .751 m .55326 .75077 L .55235 .75153 L F
.55446 .75086 m .55326 .75077 L .55401 .751 L F
.825 .555 .531 r
.55143 .74907 m .552 .75039 L .55081 .74948 L F
.552 .75039 m .5526 .75175 L .55137 .75019 L F
.552 .75039 m .55137 .75019 L .55081 .74948 L F
0 .072 .629 r
.55235 .75153 m .55323 .7518 L .55143 .74907 L F
.556 .416 .646 r
.55151 .75398 m .55323 .7518 L .55235 .75153 L F
.139 .655 .892 r
.29776 .59265 m .30115 .59324 L .29916 .59344 L F
.942 .71 .559 r
.60676 .69093 m .60662 .69357 L .60793 .69378 L F
.942 .812 .688 r
.60532 .69581 m .60793 .69378 L .60662 .69357 L F
.60532 .69581 m .60666 .69658 L .60793 .69378 L F
.555 .421 .653 r
.34134 .68263 m .34369 .6824 L .34337 .6799 L F
.07 0 0 r
.38855 .70146 m .39028 .70101 L .39151 .70022 L F
0 0 0 r
.39151 .70022 m .39028 .70101 L .39342 .69949 L F
.589 .377 .561 r
.37688 .67677 m .37486 .67923 L .37483 .67726 L F
.759 .606 .688 r
.48238 .76373 m .48348 .76607 L .47977 .76558 L F
.808 .637 .669 r
.48348 .76607 m .47959 .76729 L .47977 .76558 L F
.48348 .76607 m .48357 .76905 L .47959 .76729 L F
.611 .54 .75 r
.48539 .76541 m .48348 .76607 L .48238 .76373 L F
0 0 .066 r
.48539 .76541 m .48357 .76905 L .48348 .76607 L F
.51 .22 .409 r
.44152 .68392 m .43944 .6828 L .44165 .68245 L F
.44152 .68392 m .43866 .68539 L .43944 .6828 L F
.643 .153 .074 r
.55183 .70176 m .55527 .70209 L .55339 .70292 L F
.53 .781 .99 r
.42825 .67163 m .4312 .67194 L .43052 .67108 L F
.176 .14 .576 r
.4312 .67194 m .43274 .67271 L .43052 .67108 L F
.4312 .67194 m .43149 .67445 L .43274 .67271 L F
.331 0 .122 r
.2698 .60824 m .26642 .61058 L .26766 .60862 L F
.306 .627 .961 r
.44346 .77977 m .44393 .77616 L .44269 .77647 L F
.44346 .77977 m .44396 .7786 L .44393 .77616 L F
.44346 .77977 m .44453 .77935 L .44396 .7786 L F
.582 .656 .888 r
.44308 .78108 m .44453 .77935 L .44346 .77977 L F
.732 .644 .761 r
.71582 .60545 m .71584 .60889 L .7137 .6085 L F
.401 0 0 r
.7137 .6085 m .71584 .60889 L .71632 .60935 L F
.528 .455 .717 r
.71899 .60846 m .71584 .60889 L .71582 .60545 L F
.71908 .60872 m .71958 .61017 L .71591 .60891 L F
.708 .555 .679 r
.72463 .60769 m .71958 .61017 L .71899 .60846 L F
.782 .81 .875 r
.71857 .6091 m .71958 .61017 L .72463 .60769 L F
.71857 .6091 m .72062 .60863 L .72093 .60892 L F
.763 .541 .596 r
.725 .60656 m .72431 .60824 L .72443 .60732 L F
.72431 .60824 m .72411 .60874 L .72424 .60817 L F
.72431 .60824 m .72424 .60817 L .72443 .60732 L F
.782 .81 .875 r
.72062 .60863 m .72393 .60786 L .7221 .60853 L F
.72393 .60786 m .72463 .60769 L .72398 .60791 L F
.72393 .60786 m .72398 .60791 L .7221 .60853 L F
.72062 .60863 m .7221 .60853 L .72093 .60892 L F
.528 .455 .717 r
.71899 .60846 m .71908 .60872 L .71584 .60889 L F
.71908 .60872 m .71591 .60891 L .71584 .60889 L F
.2 .547 .93 r
.71584 .60889 m .71926 .61006 L .71857 .6091 L F
.71926 .61006 m .71958 .61017 L .71857 .6091 L F
.49 .734 .98 r
.71778 .608 m .71857 .6091 L .71782 .60796 L F
.2 .547 .93 r
.71584 .60889 m .71857 .6091 L .71632 .60935 L F
.49 .734 .98 r
.71632 .60935 m .71857 .6091 L .71778 .608 L F
.535 .298 .503 r
.34999 .66241 m .34829 .66075 L .34795 .66293 L F
.34999 .66241 m .3504 .66031 L .34829 .66075 L F
.455 .732 .986 r
.58706 .72723 m .58994 .72751 L .58843 .72585 L F
0 0 .246 r
.58843 .72585 m .5873 .72959 L .58706 .72723 L F
.082 0 0 r
.38459 .71584 m .38316 .71581 L .38503 .71525 L F
.38459 .71584 m .38191 .71673 L .38316 .71581 L F
.338 0 0 r
.47161 .7908 m .47305 .79182 L .47006 .79066 L F
.47161 .7908 m .47367 .79091 L .47305 .79182 L F
.908 .983 .749 r
.54457 .77265 m .5444 .77145 L .54475 .77121 L F
.54457 .77265 m .54289 .77377 L .5444 .77145 L F
.754 .419 .417 r
.54457 .77265 m .54205 .7758 L .54289 .77377 L F
.54457 .77265 m .54525 .77612 L .54205 .7758 L F
.847 .484 .366 r
.54572 .77389 m .54525 .77612 L .54457 .77265 L F
.8 .457 .407 r
.54441 .74076 m .54342 .7428 L .54159 .7397 L F
.785 .563 .599 r
.54662 .74068 m .54342 .7428 L .54441 .74076 L F
.466 .505 .815 r
.47977 .76558 m .47689 .76303 L .4793 .7631 L F
.418 .049 .228 r
.36522 .65424 m .36854 .65164 L .36644 .65207 L F
.646 .186 .146 r
.55386 .70873 m .55314 .70995 L .55046 .70851 L F
.701 .249 .176 r
.55386 .70873 m .55617 .71056 L .55314 .70995 L F
.669 .119 0 r
.55748 .71078 m .55617 .71056 L .55386 .70873 L F
.582 .157 .2 r
.56863 .76115 m .57085 .76237 L .56888 .76187 L F
.829 .799 .823 r
.63208 .51353 m .63373 .51462 L .63549 .51213 L F
.926 .714 .596 r
.63208 .51353 m .63342 .51683 L .63373 .51462 L F
.493 .293 .537 r
.32602 .62749 m .32597 .62496 L .32807 .62444 L F
.16 0 0 r
.52145 .73467 m .52409 .7345 L .52537 .73303 L F
.248 0 0 r
.52537 .73303 m .52643 .73381 L .52675 .7316 L F
.52537 .73303 m .52409 .7345 L .52643 .73381 L F
.495 .147 .305 r
.65858 .53936 m .6606 .54045 L .65837 .54071 L F
.477 .172 .37 r
.66091 .53888 m .6606 .54045 L .65858 .53936 L F
.351 .755 .983 r
.31788 .59467 m .32148 .59526 L .31938 .59544 L F
.316 .79 .921 r
.27685 .65456 m .27348 .65466 L .27517 .65471 L F
.233 .717 .93 r
.4343 .65268 m .43786 .6531 L .43569 .65317 L F
.471 .294 .558 r
.44224 .76332 m .44459 .76279 L .44422 .76041 L F
.477 .408 .701 r
.44303 .76575 m .44459 .76279 L .44224 .76332 L F
.399 0 0 r
.37143 .65017 m .37284 .6508 L .37456 .64982 L F
.014 0 0 r
.37284 .6508 m .37672 .64954 L .37456 .64982 L F
.447 .171 .4 r
.42149 .6963 m .41872 .69839 L .4194 .69682 L F
.074 .472 .89 r
.59177 .72702 m .59158 .72762 L .58994 .72751 L F
0 .25 .762 r
.59158 .72762 m .59177 .72702 L .58994 .72751 L F
.59158 .72762 m .59347 .72944 L .59177 .72702 L F
.908 .578 .408 r
.60045 .68145 m .60198 .68044 L .59968 .67933 L F
.60045 .68145 m .60242 .68244 L .60198 .68044 L F
.356 .097 .377 r
.32184 .63077 m .32116 .63279 L .31933 .63354 L F
.324 .067 .362 r
.32291 .63206 m .32184 .63077 L .32332 .62991 L F
.32291 .63206 m .32116 .63279 L .32184 .63077 L F
0 0 .153 r
.50548 .7188 m .5062 .71789 L .50651 .71577 L F
0 0 .048 r
.50548 .7188 m .50568 .72005 L .5062 .71789 L F
.513 .394 .654 r
.34257 .67446 m .34465 .67733 L .34453 .67397 L F
.34257 .67446 m .34278 .67766 L .34465 .67733 L F
.419 .137 .376 r
.44648 .75481 m .44854 .7544 L .44918 .7525 L F
.336 .06 .338 r
.44918 .7525 m .44854 .7544 L .45102 .75195 L F
.072 .602 .867 r
.40274 .64956 m .40475 .64981 L .40622 .65033 L F
.348 .781 .968 r
.40475 .64981 m .40852 .65007 L .40622 .65033 L F
.78 .612 .671 r
.71582 .59147 m .71687 .58922 L .71436 .58872 L F
.512 .303 .534 r
.7182 .59079 m .71687 .58922 L .71582 .59147 L F
.218 .713 .917 r
.58491 .70472 m .58705 .70467 L .58822 .70507 L F
.228 .729 .905 r
.58705 .70467 m .59044 .70489 L .58822 .70507 L F
.58705 .70467 m .58945 .70455 L .59044 .70489 L F
.121 0 0 r
.58594 .70592 m .58927 .70462 L .58705 .70467 L F
.58927 .70462 m .58945 .70455 L .58705 .70467 L F
.218 .713 .917 r
.58489 .70472 m .58705 .70467 L .58491 .70472 L F
.742 .98 .744 r
.54717 .76869 m .54475 .77121 L .54575 .76946 L F
.684 .887 .515 r
.54475 .77121 m .5444 .77145 L .54575 .76946 L F
.774 .527 .562 r
.74263 .71553 m .74594 .71593 L .74379 .71296 L F
0 0 0 r
.39206 .71234 m .39084 .71243 L .39377 .71136 L F
.39206 .71234 m .39037 .71322 L .39084 .71243 L F
.824 .746 .778 r
.57105 .77385 m .57042 .77133 L .57163 .77159 L F
0 0 .26 r
.57231 .77 m .57105 .77385 L .57163 .77159 L F
.747 .582 .671 r
.4793 .7631 m .48238 .76373 L .47977 .76558 L F
.906 .754 .681 r
.67283 .5162 m .67373 .51981 L .67145 .5184 L F
.979 .684 .371 r
.67373 .51981 m .67255 .52122 L .67145 .5184 L F
.67373 .51981 m .67395 .52225 L .67255 .52122 L F
.71 .644 .782 r
.6763 .51665 m .67373 .51981 L .67283 .5162 L F
.611 .449 .638 r
.6655 .53537 m .66299 .5335 L .66531 .53285 L F
.6655 .53537 m .66308 .53595 L .66299 .5335 L F
.636 .915 .98 r
.54422 .7936 m .54114 .79384 L .54226 .79259 L F
.54422 .7936 m .54114 .79384 L .54226 .79259 L F
.566 .39 .601 r
.45713 .67168 m .45726 .67416 L .4549 .67434 L F
.597 .324 .474 r
.45726 .67416 m .45409 .67666 L .4549 .67434 L F
.483 .174 .364 r
.64799 .54363 m .64743 .54635 L .64506 .54676 L F
.442 .122 .326 r
.65052 .54371 m .64743 .54635 L .64799 .54363 L F
.665 .471 .613 r
.61673 .54474 m .61448 .54682 L .61317 .54429 L F
.61673 .54474 m .61661 .54711 L .61448 .54682 L F
.225 0 0 r
.51323 .712 m .51714 .70973 L .51452 .71042 L F
.541 .2 .34 r
.45629 .75167 m .45967 .74924 L .45647 .74948 L F
.45629 .75167 m .45856 .75162 L .45967 .74924 L F
.633 .298 .385 r
.45967 .74924 m .45856 .75162 L .46174 .75113 L F
.595 .309 .453 r
.45967 .74924 m .46174 .75113 L .46204 .74917 L F
.778 .589 .643 r
.43146 .66574 m .42919 .66688 L .42909 .6634 L F
.514 .395 .656 r
.34575 .70433 m .34778 .70203 L .34568 .70264 L F
.34575 .70433 m .34891 .70525 L .34778 .70203 L F
.473 .36 .644 r
.34575 .70433 m .34828 .70677 L .34891 .70525 L F
.34575 .70433 m .34587 .70763 L .34828 .70677 L F
.408 .088 .307 r
.32055 .63474 m .31933 .63354 L .32116 .63279 L F
.32055 .63474 m .31855 .6352 L .31933 .63354 L F
.742 .22 0 r
.55748 .71078 m .55721 .71173 L .55617 .71056 L F
.55748 .71078 m .55965 .71295 L .55721 .71173 L F
.762 .281 .098 r
.56135 .71313 m .55965 .71295 L .55748 .71078 L F
.807 .592 .612 r
.50853 .7375 m .51286 .73801 L .51037 .73491 L F
.773 .42 .387 r
.50853 .7375 m .51041 .73959 L .51286 .73801 L F
.742 .544 .627 r
.51041 .73959 m .51286 .73819 L .51286 .73801 L F
.692 .429 .52 r
.51286 .73819 m .51037 .73491 L .51286 .73801 L F
.48 .344 .618 r
.54278 .6965 m .54499 .69839 L .54666 .69767 L F
0 0 0 r
.54666 .69767 m .54737 .69757 L .54842 .69638 L F
.54666 .69767 m .54499 .69839 L .54737 .69757 L F
.457 .098 .267 r
.4137 .68809 m .41589 .68783 L .41693 .68569 L F
.42 .062 .248 r
.41693 .68569 m .4184 .68673 L .41885 .68502 L F
.41693 .68569 m .41589 .68783 L .4184 .68673 L F
.432 .102 .304 r
.40337 .69604 m .40641 .69322 L .40412 .69354 L F
.176 .684 .902 r
.41402 .66433 m .41048 .66394 L .41196 .66449 L F
.37 0 .014 r
.38939 .66734 m .38806 .66862 L .38636 .66879 L F
.612 .18 .198 r
.38939 .66734 m .39174 .66885 L .38806 .66862 L F
.62 .122 .049 r
.39282 .66833 m .39174 .66885 L .38939 .66734 L F
.716 .286 .228 r
.51714 .70973 m .51898 .7105 L .52074 .71019 L F
.774 .394 .336 r
.51898 .7105 m .51925 .71195 L .52074 .71019 L F
.806 .438 .361 r
.51925 .71195 m .52251 .71291 L .52074 .71019 L F
.537 .921 .918 r
.26744 .65639 m .26958 .65621 L .27148 .65534 L F
0 .129 .677 r
.54606 .73634 m .54732 .73751 L .54734 .73849 L F
0 0 .045 r
.54759 .73946 m .54734 .73849 L .54732 .73751 L F
.54759 .73946 m .54662 .74068 L .54734 .73849 L F
.683 .402 .49 r
.45379 .7512 m .45629 .75167 L .45647 .74948 L F
.388 .019 .212 r
.46938 .74544 m .47218 .74363 L .46992 .74383 L F
.582 .656 .888 r
.44308 .78108 m .4466 .78235 L .44453 .77935 L F
.42 .266 .565 r
.44203 .77413 m .44381 .77368 L .44386 .7712 L F
.43 .297 .597 r
.44203 .77413 m .44393 .77616 L .44381 .77368 L F
.305 .275 .66 r
.44269 .77647 m .44393 .77616 L .44203 .77413 L F
.627 .654 .857 r
.42901 .66753 m .43313 .67113 L .43101 .66627 L F
.726 .296 .227 r
.43052 .67108 m .43313 .67113 L .42901 .66753 L F
.726 .233 .067 r
.43052 .67108 m .43274 .67271 L .43186 .67215 L F
.726 .296 .227 r
.43052 .67108 m .43186 .67215 L .43313 .67113 L F
.448 .549 .867 r
.43101 .66627 m .43313 .67113 L .43357 .6671 L F
0 0 0 r
.43313 .67113 m .43454 .67049 L .43357 .6671 L F
.43313 .67113 m .43186 .67215 L .43454 .67049 L F
.492 .593 .883 r
.58032 .7151 m .57964 .71761 L .57843 .71527 L F
.58032 .7151 m .58207 .71769 L .57964 .71761 L F
.403 .237 .539 r
.75905 .59101 m .75918 .59367 L .75724 .59416 L F
.39 .301 .634 r
.75946 .59597 m .75724 .59416 L .75918 .59367 L F
.75946 .59597 m .75709 .59735 L .75724 .59416 L F
.518 .125 .235 r
.52914 .76274 m .52559 .76439 L .52776 .76485 L F
.424 0 0 r
.52776 .76485 m .53089 .76412 L .52914 .76274 L F
.649 .323 .408 r
.53089 .76412 m .53168 .76311 L .52914 .76274 L F
.413 .233 .525 r
.3074 .61934 m .30724 .62165 L .3092 .61871 L F
.347 .25 .6 r
.37278 .68712 m .37128 .68552 L .37247 .68505 L F
.37278 .68712 m .37113 .68911 L .37128 .68552 L F
.667 .628 .8 r
.37836 .69664 m .37648 .69885 L .37643 .69753 L F
.614 .547 .755 r
.37836 .69664 m .37881 .69841 L .37648 .69885 L F
.277 0 .215 r
.30964 .64388 m .31232 .64162 L .31154 .64305 L F
.215 0 .179 r
.31154 .64305 m .31232 .64162 L .31408 .64079 L F
.359 .139 .437 r
.44639 .75707 m .44854 .7544 L .44648 .75481 L F
.797 .462 .421 r
.48173 .78522 m .47999 .784 L .481 .78282 L F
.47999 .784 m .47823 .78277 L .481 .78282 L F
.472 .012 .08 r
.47933 .78311 m .48157 .78214 L .481 .78282 L F
.48157 .78214 m .48261 .78169 L .481 .78282 L F
.144 0 0 r
.47933 .78311 m .47823 .78277 L .47645 .78275 L F
.47933 .78311 m .481 .78282 L .47823 .78277 L F
.363 .747 .988 r
.30323 .59299 m .30678 .59372 L .30483 .59368 L F
.308 .716 .977 r
.40568 .66476 m .40738 .66411 L .40541 .66424 L F
.40568 .66476 m .4085 .66477 L .40738 .66411 L F
.246 0 .104 r
.73337 .59635 m .73402 .59463 L .73622 .59375 L F
.789 .494 .489 r
.56786 .70974 m .57039 .70807 L .56783 .70732 L F
.56786 .70974 m .57107 .71047 L .57039 .70807 L F
.34 0 0 r
.39592 .71077 m .39206 .71234 L .39377 .71136 L F
.397 .67 .97 r
.54114 .79384 m .53879 .79381 L .53949 .79257 L F
.773 .524 .558 r
.53614 .7971 m .53948 .79612 L .53879 .79381 L F
.397 .67 .97 r
.54114 .79384 m .53879 .79381 L .53949 .79257 L F
.628 .673 .874 r
.42474 .66993 m .42825 .67163 L .42708 .66911 L F
.536 .493 .755 r
.42825 .67163 m .42901 .66753 L .42708 .66911 L F
.42825 .67163 m .43052 .67108 L .42901 .66753 L F
.477 .408 .701 r
.44303 .76575 m .44493 .76541 L .44459 .76279 L F
.539 .43 .678 r
.44316 .76819 m .44493 .76541 L .44303 .76575 L F
.695 .157 0 r
.56192 .70537 m .56346 .70392 L .56098 .70421 L F
.56192 .70537 m .56445 .70783 L .56174 .70606 L F
.76 .335 .243 r
.56192 .70537 m .56445 .70783 L .56549 .70732 L F
.695 .157 0 r
.56192 .70537 m .56174 .70606 L .56346 .70392 L F
.414 .788 .993 r
.47328 .78191 m .47269 .78286 L .47164 .78135 L F
.47328 .78191 m .47489 .78265 L .47269 .78286 L F
.864 .995 .77 r
.55701 .68932 m .5565 .69135 L .55869 .6885 L F
.678 .821 .952 r
.73353 .6223 m .73431 .62384 L .73652 .62263 L F
.584 .251 .372 r
.51006 .79726 m .51019 .79622 L .51248 .79794 L F
.595 .243 .342 r
.51019 .79622 m .51277 .79645 L .51248 .79794 L F
.857 .745 .739 r
.60688 .71306 m .60977 .71328 L .60994 .71089 L F
.807 .6 .622 r
.60627 .71546 m .60977 .71328 L .60688 .71306 L F
.60627 .71546 m .60955 .71584 L .60977 .71328 L F
.782 .577 .622 r
.60955 .71584 m .61111 .71614 L .60977 .71328 L F
0 0 .247 r
.66083 .51089 m .66154 .51403 L .66059 .51202 L F
.589 .658 .886 r
.4466 .78235 m .44704 .77918 L .44453 .77935 L F
.4466 .78235 m .44913 .78213 L .44704 .77918 L F
.549 .561 .819 r
.4466 .78235 m .44998 .78512 L .44913 .78213 L F
.502 .077 .165 r
.2756 .60589 m .2741 .60772 L .27171 .6076 L F
.221 0 0 r
.27617 .6071 m .2756 .60589 L .27765 .60549 L F
.27617 .6071 m .2741 .60772 L .2756 .60589 L F
.82 .75 .786 r
.60723 .7046 m .61109 .7026 L .60921 .70102 L F
.60723 .7046 m .60891 .70516 L .61109 .7026 L F
.522 .379 .627 r
.30964 .61659 m .31163 .61609 L .31151 .6136 L F
.46 .213 .452 r
.30964 .61659 m .3092 .61871 L .31163 .61609 L F
.515 .329 .567 r
.76044 .6109 m .76091 .61351 L .75838 .61378 L F
.352 .202 .533 r
.76031 .61518 m .75838 .61378 L .76091 .61351 L F
.76031 .61518 m .7586 .61615 L .75838 .61378 L F
.749 .616 .71 r
.66694 .49788 m .66682 .50065 L .6651 .50002 L F
.784 .507 .518 r
.66682 .50065 m .66651 .50196 L .6651 .50002 L F
.737 .625 .735 r
.66935 .49725 m .66682 .50065 L .66694 .49788 L F
.749 .967 .932 r
.73353 .61721 m .72988 .61858 L .73199 .61785 L F
.696 .977 .79 r
.73507 .61577 m .73353 .61721 L .73199 .61785 L F
.722 .626 .75 r
.52332 .76749 m .52208 .76466 L .52238 .76486 L F
.275 0 .084 r
.74126 .58663 m .73835 .58827 L .74061 .58788 L F
0 0 0 r
.74283 .58543 m .74126 .58663 L .74061 .58788 L F
.306 .066 .377 r
.31855 .6352 m .31631 .63808 L .31686 .63601 L F
.366 .101 .373 r
.50072 .72494 m .50008 .7267 L .50261 .72411 L F
.599 .052 0 r
.56741 .7194 m .56727 .71967 L .56539 .71793 L F
.6 .061 0 r
.56741 .7194 m .56812 .72045 L .56727 .71967 L F
.56741 .7194 m .56947 .72145 L .56812 .72045 L F
.513 .234 .428 r
.48013 .74076 m .48233 .74056 L .48304 .73781 L F
.557 .275 .443 r
.48304 .73781 m .48493 .73974 L .4852 .7376 L F
.48304 .73781 m .48233 .74056 L .48493 .73974 L F
.744 .29 .173 r
.56135 .71313 m .56029 .71449 L .55965 .71295 L F
.56135 .71313 m .56343 .71527 L .56029 .71449 L F
.311 0 0 r
.58322 .67373 m .58551 .67338 L .58667 .67191 L F
.421 0 .035 r
.58667 .67191 m .58747 .67318 L .58888 .67153 L F
.58667 .67191 m .58551 .67338 L .58747 .67318 L F
.103 0 0 r
.7462 .58454 m .74283 .58543 L .745 .58462 L F
.277 .781 .824 r
.74711 .58404 m .7462 .58454 L .745 .58462 L F
.74711 .58404 m .74829 .58405 L .7462 .58454 L F
.422 0 0 r
.48081 .79261 m .48294 .793 L .47933 .79308 L F
.572 .401 .611 r
.42602 .67959 m .42819 .67629 L .42639 .67708 L F
.678 .456 .577 r
.45076 .74903 m .45102 .75195 L .45379 .7512 L F
.772 .655 .733 r
.66581 .49467 m .66694 .49788 L .6638 .49742 L F
.825 .671 .692 r
.6651 .50002 m .6638 .49742 L .66694 .49788 L F
.714 .625 .757 r
.66935 .49725 m .66694 .49788 L .66581 .49467 L F
.692 .429 .52 r
.51286 .73819 m .51462 .73571 L .51037 .73491 L F
.485 .374 .653 r
.34271 .68843 m .34453 .68794 L .34425 .68536 L F
.405 .328 .656 r
.34271 .68843 m .34384 .68998 L .34453 .68794 L F
.34271 .68843 m .343 .69135 L .34384 .68998 L F
.532 .576 .845 r
.45408 .66455 m .45289 .66711 L .45173 .66492 L F
.45408 .66455 m .45559 .66741 L .45289 .66711 L F
.817 .506 .464 r
.5894 .67309 m .59227 .6719 L .58888 .67153 L F
.5894 .67309 m .59238 .6739 L .59227 .6719 L F
.731 .437 .482 r
.59227 .6719 m .59238 .6739 L .59585 .67403 L F
.618 .665 .873 r
.69332 .5164 m .69141 .51746 L .69016 .51594 L F
.638 .732 .916 r
.68997 .51666 m .69141 .51746 L .69332 .5164 L F
.535 .48 .741 r
.51679 .76474 m .51532 .76868 L .51655 .76639 L F
.598 .13 .114 r
.48628 .79296 m .49042 .79319 L .48848 .79341 L F
.762 .422 .409 r
.49042 .79319 m .4918 .79386 L .48848 .79341 L F
.768 .684 .77 r
.42545 .66383 m .4278 .66482 L .42909 .6634 L F
.688 .518 .652 r
.52747 .79923 m .52838 .80156 L .52604 .80098 L F
.481 .402 .69 r
.53002 .79848 m .52747 .79923 L .52748 .79597 L F
.624 .341 .468 r
.52838 .80156 m .53139 .80111 L .53048 .80343 L F
.541 .157 .263 r
.53063 .80309 m .53139 .80111 L .52838 .80156 L F
.239 .268 .69 r
.53063 .80309 m .52747 .79923 L .53002 .79848 L F
.53063 .80309 m .52838 .80156 L .52747 .79923 L F
.627 .708 .904 r
.5987 .75678 m .6002 .75379 L .59755 .75432 L F
.5987 .75678 m .60147 .75547 L .6002 .75379 L F
0 0 .267 r
.70267 .59421 m .70329 .59328 L .70297 .58983 L F
0 .108 .651 r
.70267 .59421 m .70439 .59663 L .70329 .59328 L F
.589 .556 .785 r
.45838 .66881 m .45713 .67168 L .45626 .66911 L F
.45838 .66881 m .45942 .67155 L .45713 .67168 L F
.605 .435 .626 r
.45942 .67155 m .45726 .67416 L .45713 .67168 L F
.367 .231 .56 r
.76253 .61224 m .76091 .61351 L .76044 .6109 L F
.527 .174 .312 r
.51443 .79074 m .51117 .79307 L .5147 .79309 L F
.462 .095 .255 r
.75636 .61706 m .75584 .61848 L .75341 .61871 L F
.592 .342 .507 r
.7586 .61615 m .75584 .61848 L .75636 .61706 L F
.387 .273 .6 r
.75953 .59824 m .75709 .59735 L .75946 .59597 L F
.75953 .59824 m .75729 .59982 L .75709 .59735 L F
.086 .634 .831 r
.38555 .70118 m .38752 .70124 L .38855 .70146 L F
.417 0 0 r
.38752 .70124 m .39028 .70101 L .38855 .70146 L F
.607 .074 0 r
.59491 .68893 m .59545 .6898 L .5931 .68747 L F
.608 .078 0 r
.59491 .68893 m .5966 .69062 L .59545 .6898 L F
.56 .194 .304 r
.54836 .7738 m .54525 .77612 L .54572 .77389 L F
.703 .817 .936 r
.28062 .64219 m .27791 .6428 L .2767 .64179 L F
.442 .592 .906 r
.7566 .58556 m .75513 .58725 L .75431 .58555 L F
.7566 .58556 m .75793 .58788 L .75513 .58725 L F
.275 0 .01 r
.49043 .73288 m .49262 .73248 L .4928 .73181 L F
.161 0 0 r
.4928 .73181 m .49457 .73173 L .49578 .73071 L F
.4928 .73181 m .49262 .73248 L .49457 .73173 L F
.929 .548 .233 r
.56539 .71793 m .56343 .71527 L .56446 .71624 L F
.567 .214 .329 r
.47747 .74266 m .47976 .74274 L .47793 .74119 L F
.502 .233 .44 r
.47793 .74119 m .47976 .74274 L .48013 .74076 L F
.263 .73 .945 r
.25904 .58635 m .26107 .58627 L .26267 .58682 L F
.353 .777 .974 r
.26107 .58627 m .26465 .58663 L .26267 .58682 L F
.601 .262 .367 r
.7182 .59079 m .72035 .59106 L .72093 .58901 L F
.57 .233 .357 r
.72093 .58901 m .72423 .58901 L .72372 .58848 L F
.72093 .58901 m .72035 .59106 L .72423 .58901 L F
.57 .272 .423 r
.72842 .59574 m .72511 .59477 L .72528 .59552 L F
.83 .606 .599 r
.71271 .59354 m .71676 .59467 L .71424 .59685 L F
.241 0 .171 r
.31048 .64544 m .30964 .64388 L .31154 .64305 L F
.31048 .64544 m .30864 .64621 L .30964 .64388 L F
.173 .012 .408 r
.46332 .76916 m .46294 .76828 L .46324 .76877 L F
.005 0 0 r
.74311 .61427 m .74636 .61407 L .74685 .61395 L F
.199 .719 .694 r
.74685 .61395 m .7482 .61355 L .74905 .61322 L F
.74685 .61395 m .74636 .61407 L .7482 .61355 L F
.551 .777 .982 r
.74015 .62422 m .74344 .62486 L .74233 .62377 L F
.816 .857 .878 r
.74233 .62377 m .74344 .62486 L .74621 .62255 L F
.161 0 0 r
.73741 .58864 m .73835 .58827 L .73511 .58876 L F
0 0 0 r
.74061 .58788 m .73835 .58827 L .73741 .58864 L F
.681 .427 .531 r
.62023 .54729 m .61655 .54956 L .61661 .54711 L F
.62023 .54729 m .62065 .54984 L .61655 .54956 L F
.68 .426 .531 r
.62233 .54941 m .62065 .54984 L .62023 .54729 L F
.714 .625 .757 r
.66935 .49725 m .66581 .49467 L .66831 .49387 L F
.609 .577 .793 r
.67144 .49482 m .66935 .49725 L .66831 .49387 L F
.622 .597 .804 r
.67144 .49482 m .67225 .49803 L .66935 .49725 L F
.76 .529 .582 r
.50911 .75646 m .50617 .75436 L .51008 .75506 L F
0 0 0 r
.51186 .75392 m .50911 .75646 L .51008 .75506 L F
.703 .817 .936 r
.28062 .64219 m .2767 .64179 L .27869 .64145 L F
.234 .74 .89 r
.27869 .64145 m .28271 .64152 L .28062 .64219 L F
.597 .522 .74 r
.34478 .6994 m .34568 .70264 L .34778 .70203 L F
.439 .221 .484 r
.31408 .64079 m .31441 .63866 L .31631 .63808 L F
.401 .115 .36 r
.55234 .6881 m .5542 .68815 L .55496 .68552 L F
.295 .021 .316 r
.55496 .68552 m .55702 .68596 L .55742 .6851 L F
.55496 .68552 m .5542 .68815 L .55702 .68596 L F
.448 .239 .502 r
.32839 .62208 m .33042 .61953 L .32985 .62135 L F
.313 .144 .485 r
.32807 .62444 m .32839 .62208 L .32985 .62135 L F
.589 .803 .981 r
.31794 .73555 m .3216 .73585 L .31998 .73487 L F
.31794 .73555 m .3216 .73585 L .31998 .73487 L F
.909 .821 .748 r
.59897 .71582 m .5994 .7186 L .59801 .71773 L F
.946 .662 .206 r
.53584 .79637 m .53624 .79878 L .53566 .79831 L F
.53584 .79637 m .53566 .79831 L .53614 .7971 L F
.725 .454 .517 r
.47919 .76808 m .47763 .76974 L .47904 .76815 L F
.796 .353 .194 r
.48357 .76905 m .48242 .77022 L .47969 .76739 L F
.48357 .76905 m .47969 .76739 L .47972 .76735 L F
.47972 .76735 m .47969 .76739 L .47959 .76729 L F
.205 .343 .783 r
.47959 .76729 m .48242 .77022 L .48117 .7671 L F
.725 .454 .517 r
.48117 .7671 m .47838 .76919 L .47919 .76808 L F
.47838 .76919 m .47763 .76974 L .47919 .76808 L F
0 0 .066 r
.48539 .76541 m .48415 .76866 L .48357 .76905 L F
.382 0 .156 r
.48415 .76866 m .48242 .77022 L .48357 .76905 L F
.664 .846 .97 r
.60574 .54413 m .60643 .54347 L .60767 .54474 L F
.89 .6 .489 r
.60767 .54474 m .60758 .54677 L .60574 .54413 L F
.268 .734 .947 r
.60643 .54347 m .61015 .54413 L .60767 .54474 L F
.671 .605 .773 r
.61015 .54413 m .61088 .54454 L .60767 .54474 L F
.748 .571 .655 r
.61088 .54454 m .60758 .54677 L .60767 .54474 L F
.425 .63 .94 r
.32905 .59612 m .32831 .59772 L .32717 .59619 L F
.32905 .59612 m .33095 .59832 L .32831 .59772 L F
.665 .55 .714 r
.49927 .76021 m .49599 .75836 L .49805 .75775 L F
.49927 .76021 m .49711 .76103 L .49599 .75836 L F
.733 .336 .298 r
.48848 .79341 m .4918 .79386 L .49212 .7954 L F
.651 .547 .723 r
.3369 .7197 m .33835 .7221 L .33664 .72091 L F
.622 .464 .648 r
.52207 .74633 m .52212 .74938 L .5197 .74911 L F
.416 .32 .638 r
.52214 .75117 m .5197 .74911 L .52212 .74938 L F
.52214 .75117 m .52046 .75201 L .5197 .74911 L F
.622 .58 .787 r
.44931 .66381 m .44594 .66094 L .44815 .66067 L F
.505 .495 .78 r
.45033 .66005 m .44931 .66381 L .44815 .66067 L F
.45033 .66005 m .45135 .66376 L .44931 .66381 L F
.506 .489 .772 r
.45135 .66376 m .45173 .66492 L .44931 .66381 L F
.459 .422 .73 r
.34399 .66915 m .34641 .67109 L .34578 .66885 L F
.537 .42 .668 r
.34435 .67154 m .34641 .67109 L .34399 .66915 L F
.544 .915 .947 r
.28961 .67909 m .28753 .67997 L .28886 .6801 L F
.28886 .6801 m .28753 .67997 L .28961 .67909 L F
.688 .287 .281 r
.5537 .69369 m .55263 .69535 L .5508 .69375 L F
0 0 0 r
.55528 .69301 m .55263 .69535 L .5537 .69369 L F
.548 .487 .739 r
.44713 .65691 m .44594 .66094 L .4449 .65759 L F
.44713 .65691 m .44815 .66067 L .44594 .66094 L F
.396 .385 .73 r
.68514 .50765 m .68406 .51152 L .68281 .51048 L F
.68514 .50765 m .68547 .51099 L .68406 .51152 L F
.401 .4 .743 r
.68547 .51099 m .68658 .51321 L .68406 .51152 L F
.501 .241 .453 r
.43182 .68848 m .43134 .69042 L .4293 .69079 L F
.411 .159 .419 r
.43333 .68971 m .43182 .68848 L .434 .68812 L F
.43333 .68971 m .43134 .69042 L .43182 .68848 L F
.515 .07 .13 r
.73186 .59012 m .73511 .58876 L .73284 .58941 L F
.797 .442 .386 r
.50004 .73744 m .50249 .73555 L .50147 .7342 L F
.50004 .73744 m .5043 .73793 L .50249 .73555 L F
.265 .322 .735 r
.5043 .73793 m .50452 .7377 L .50249 .73555 L F
.263 .525 .912 r
.7137 .6085 m .71499 .60748 L .71292 .60699 L F
.7137 .6085 m .71632 .60935 L .71499 .60748 L F
.544 .556 .817 r
.75924 .60749 m .75697 .60787 L .75592 .60463 L F
.723 .907 .959 r
.74088 .61393 m .73797 .61413 L .74004 .61289 L F
.333 .66 .972 r
.74225 .6131 m .74088 .61393 L .74004 .61289 L F
.74225 .6131 m .74311 .61427 L .74088 .61393 L F
.692 .315 .329 r
.51169 .75244 m .51383 .75433 L .51186 .75392 L F
.627 .452 .625 r
.52452 .74345 m .52467 .74613 L .52207 .74633 L F
.566 .405 .622 r
.52669 .74574 m .52452 .74345 L .52629 .74305 L F
.52669 .74574 m .52467 .74613 L .52452 .74345 L F
.538 .287 .483 r
.46204 .74917 m .46437 .74885 L .46484 .74665 L F
.518 .277 .488 r
.46437 .74885 m .46685 .74613 L .46484 .74665 L F
.221 .743 .816 r
.41777 .66393 m .41623 .66395 L .41402 .66433 L F
.256 .766 .838 r
.41988 .66354 m .41623 .66395 L .41777 .66393 L F
.504 .368 .629 r
.5493 .75191 m .5497 .75483 L .55151 .75398 L F
.453 .282 .558 r
.44422 .76041 m .44637 .76221 L .44649 .75977 L F
.44422 .76041 m .44459 .76279 L .44637 .76221 L F
.194 .719 .854 r
.40852 .65007 m .41059 .6499 L .41184 .65004 L F
.045 0 0 r
.41059 .6499 m .4139 .65005 L .41184 .65004 L F
.857 .685 .667 r
.60723 .7046 m .60864 .7076 L .60891 .70516 L F
.836 .999 .799 r
.61569 .53963 m .6135 .54195 L .61396 .54051 L F
.789 .857 .9 r
.61711 .53851 m .61569 .53963 L .61594 .53753 L F
.932 .961 .764 r
.61569 .53963 m .61396 .54051 L .61594 .53753 L F
.956 .649 .225 r
.55819 .68717 m .55792 .68785 L .55869 .6885 L F
.19 .045 .441 r
.55884 .68675 m .55772 .68833 L .55792 .68785 L F
.963 .933 .706 r
.55792 .68785 m .55701 .68932 L .55869 .6885 L F
.19 .045 .441 r
.55772 .68833 m .55701 .68932 L .55792 .68785 L F
.956 .649 .225 r
.55742 .6851 m .55792 .68785 L .55819 .68717 L F
0 0 .051 r
.57412 .75951 m .57375 .76259 L .57449 .76033 L F
.884 .547 .407 r
.58475 .72117 m .58705 .72351 L .58839 .72136 L F
.625 .783 .958 r
.65018 .50484 m .65124 .50618 L .65364 .5054 L F
.65018 .50484 m .65124 .50618 L .65364 .5054 L F
0 0 .105 r
.74282 .71559 m .74264 .71793 L .74263 .71553 L F
.672 .629 .798 r
.48398 .77223 m .48151 .77128 L .48376 .77195 L F
0 0 .282 r
.48151 .77128 m .4823 .7727 L .48376 .77195 L F
.839 .994 .75 r
.48376 .77195 m .4823 .7727 L .48334 .77142 L F
.48376 .77195 m .48334 .77142 L .48461 .76984 L F
.672 .629 .798 r
.48493 .77259 m .48398 .77223 L .48376 .77195 L F
.513 .811 .999 r
.48684 .77183 m .48493 .77259 L .48376 .77195 L F
.303 .06 .37 r
.49043 .73288 m .49192 .73406 L .49262 .73248 L F
.49043 .73288 m .49009 .73489 L .49192 .73406 L F
.475 0 0 r
.51593 .79837 m .51923 .79906 L .5187 .79938 L F
.56 .883 .612 r
.51825 .79965 m .5187 .79938 L .52025 .79794 L F
.593 .103 .06 r
.51593 .79837 m .5187 .79938 L .51755 .80026 L F
.56 .883 .612 r
.51755 .80026 m .5187 .79938 L .51825 .79965 L F
.475 0 0 r
.51923 .79906 m .51933 .79908 L .5187 .79938 L F
0 .046 .594 r
.51933 .79908 m .52025 .79794 L .5187 .79938 L F
.611 .459 .651 r
.52091 .79688 m .52182 .7987 L .51933 .79908 L F
.579 .346 .527 r
.51933 .79908 m .52182 .7987 L .52131 .80126 L F
0 .046 .594 r
.51933 .79908 m .5208 .80035 L .52025 .79794 L F
.51933 .79908 m .52131 .80126 L .5208 .80035 L F
.453 .017 .119 r
.48958 .75221 m .48855 .75367 L .48593 .75337 L F
.97 .899 .538 r
.48958 .75221 m .48898 .75446 L .48855 .75367 L F
.513 0 0 r
.47248 .76907 m .47518 .77083 L .47328 .76996 L F
.965 .851 .442 r
.54772 .74679 m .5468 .74803 L .54726 .74564 L F
.856 .434 .223 r
.54828 .74846 m .5468 .74803 L .54772 .74679 L F
.064 .62 .81 r
.54907 .79325 m .54978 .79344 L .54635 .79313 L F
.54635 .79313 m .54978 .79344 L .54907 .79325 L F
.427 0 .059 r
.39747 .69822 m .40127 .69651 L .39913 .69707 L F
.738 .54 .625 r
.68043 .52305 m .68171 .52535 L .67771 .52483 L F
.587 .879 .574 r
.68453 .5206 m .68164 .52375 L .68201 .52338 L F
.68453 .5206 m .68201 .52338 L .68569 .51959 L F
.041 .12 .62 r
.687 .51611 m .68569 .51959 L .68487 .51715 L F
.816 .954 .614 r
.687 .51611 m .68526 .51927 L .68569 .51959 L F
.68526 .51927 m .68453 .5206 L .68476 .52039 L F
.68526 .51927 m .68476 .52039 L .68569 .51959 L F
.497 .505 .795 r
.68592 .51742 m .68453 .5206 L .687 .51611 L F
.351 .4 .772 r
.688 .51847 m .68655 .52037 L .68597 .51765 L F
.68604 .51749 m .68597 .51765 L .68592 .51742 L F
.688 .51847 m .68597 .51765 L .68604 .51749 L F
.497 .505 .795 r
.68592 .51742 m .6862 .51875 L .68453 .5206 L F
.6862 .51875 m .68655 .52037 L .68453 .5206 L F
.724 .596 .712 r
.68587 .52431 m .6828 .52343 L .68393 .52141 L F
.529 .586 .856 r
.68655 .52037 m .68782 .52315 L .68393 .52141 L F
.648 .528 .703 r
.68782 .52315 m .68587 .52431 L .68393 .52141 L F
.25 .122 .503 r
.6828 .52343 m .68453 .5206 L .68393 .52141 L F
.6828 .52343 m .68164 .52375 L .68453 .5206 L F
.344 .456 .831 r
.68043 .52305 m .68164 .52375 L .6828 .52343 L F
.383 .391 .744 r
.6828 .52343 m .68171 .52535 L .68043 .52305 L F
.68 .896 .975 r
.59585 .7557 m .59234 .75643 L .59329 .75693 L F
.72 .362 .37 r
.49564 .79562 m .49921 .79589 L .49769 .79649 L F
.728 .365 .362 r
.49921 .79589 m .49957 .79798 L .49769 .79649 L F
.49921 .79589 m .5015 .79818 L .49957 .79798 L F
.49921 .79589 m .50102 .79654 L .5015 .79818 L F
.871 .83 .804 r
.62001 .53423 m .61873 .53645 L .61696 .53554 L F
.876 .827 .795 r
.61873 .53645 m .61711 .53851 L .61696 .53554 L F
.691 .834 .951 r
.36551 .72334 m .36416 .72418 L .3676 .72431 L F
.96 .706 .509 r
.3676 .72431 m .36773 .72613 L .36608 .72596 L F
.468 .33 .61 r
.36962 .7263 m .36778 .72687 L .3676 .72431 L F
.706 .298 .271 r
.36608 .72596 m .36962 .7263 L .3676 .72431 L F
.671 .126 0 r
.36608 .72596 m .36416 .72418 L .36551 .72334 L F
.36608 .72596 m .36277 .72423 L .36416 .72418 L F
0 0 0 r
.36837 .72357 m .36608 .72596 L .36551 .72334 L F
.36837 .72357 m .36738 .72542 L .36608 .72596 L F
.671 .126 0 r
.36608 .72596 m .36471 .72583 L .36277 .72423 L F
.54 .262 .443 r
.36738 .72542 m .36475 .72583 L .36608 .72596 L F
.36475 .72583 m .36471 .72583 L .36608 .72596 L F
.96 .706 .509 r
.36773 .72613 m .36778 .72687 L .36608 .72596 L F
.752 .336 .259 r
.59148 .68 m .59032 .68158 L .58827 .67926 L F
.909 .563 .376 r
.59148 .68 m .5924 .68258 L .59032 .68158 L F
.487 .24 .465 r
.34399 .60745 m .34163 .61023 L .34226 .60822 L F
.553 0 0 r
.54058 .76443 m .5438 .76536 L .54258 .76477 L F
.098 .604 .896 r
.5438 .76536 m .54465 .76505 L .54258 .76477 L F
.656 .369 .473 r
.54603 .76582 m .54606 .76711 L .5438 .76536 L F
.54606 .76711 m .54608 .76789 L .54534 .76707 L F
.54606 .76711 m .54534 .76707 L .5438 .76536 L F
.765 .457 .466 r
.5494 .76815 m .54603 .76582 L .54992 .76626 L F
.87 .726 .7 r
.54716 .76745 m .54749 .76777 L .54745 .76754 L F
.54716 .76745 m .54608 .76789 L .54749 .76777 L F
.765 .457 .466 r
.54716 .76745 m .54608 .76789 L .54606 .76711 L F
.54894 .76783 m .54754 .76748 L .54688 .76641 L F
.54938 .76813 m .54745 .76754 L .54894 .76783 L F
.54745 .76754 m .54606 .76711 L .54894 .76783 L F
.751 .676 .778 r
.55283 .76846 m .5507 .77121 L .5494 .76815 L F
.755 .661 .758 r
.55165 .76523 m .55283 .76846 L .5494 .76815 L F
.656 .517 .683 r
.55165 .76523 m .5494 .76815 L .54992 .76626 L F
.278 .285 .688 r
.55071 .76856 m .55119 .76871 L .55089 .76796 L F
.54749 .76777 m .54775 .76784 L .54759 .76757 L F
.54749 .76777 m .54759 .76757 L .54745 .76754 L F
.742 .98 .744 r
.54717 .76869 m .54575 .76946 L .54608 .76789 L F
.419 .027 .186 r
.54575 .76946 m .54714 .76812 L .54608 .76789 L F
.54714 .76812 m .54749 .76777 L .54608 .76789 L F
.555 .836 .997 r
.54841 .76839 m .54717 .76869 L .54659 .76827 L F
.54717 .76812 m .54659 .76827 L .54608 .76789 L F
.54841 .76839 m .54659 .76827 L .54717 .76812 L F
.5494 .76815 m .54841 .76839 L .54714 .76812 L F
.5494 .76815 m .54714 .76812 L .54765 .76801 L F
.765 .457 .466 r
.54788 .76768 m .54608 .76789 L .54716 .76745 L F
.5494 .76815 m .54762 .76801 L .54788 .76768 L F
.632 .793 .96 r
.54744 .76805 m .54803 .76791 L .54749 .76777 L F
.419 .027 .186 r
.54714 .76812 m .54744 .76805 L .54749 .76777 L F
.765 .457 .466 r
.54762 .76801 m .54608 .76789 L .54788 .76768 L F
.632 .793 .96 r
.55072 .76866 m .55119 .76871 L .5507 .76859 L F
0 0 .271 r
.5505 .76945 m .55072 .76866 L .55119 .76871 L F
.632 .793 .96 r
.55078 .76883 m .55119 .76871 L .55072 .76866 L F
.765 .457 .466 r
.5494 .76815 m .54606 .76711 L .54938 .76813 L F
.278 .285 .688 r
.54775 .76784 m .55119 .76871 L .54759 .76757 L F
.284 .288 .688 r
.54931 .76395 m .55119 .76871 L .55147 .766 L F
0 0 .271 r
.55072 .76866 m .55135 .76646 L .55119 .76871 L F
.55135 .76646 m .55147 .766 L .55119 .76871 L F
.55073 .76866 m .55122 .76929 L .55147 .76605 L F
.632 .793 .96 r
.55078 .76883 m .5505 .76945 L .55119 .76871 L F
0 0 .271 r
.5505 .76945 m .55078 .76883 L .55073 .76866 L F
.5505 .76945 m .55147 .76605 L .55135 .76646 L F
.632 .793 .96 r
.54711 .76991 m .5505 .76945 L .55078 .76883 L F
0 0 .271 r
.5505 .76945 m .55095 .76935 L .55078 .76883 L F
.55095 .76935 m .55122 .76929 L .55073 .76866 L F
.632 .793 .96 r
.54711 .76991 m .55078 .76883 L .54803 .76791 L F
.55078 .76883 m .5507 .76859 L .54803 .76791 L F
.54711 .76991 m .54803 .76791 L .54744 .76805 L F
.419 .027 .186 r
.54575 .76946 m .54711 .76991 L .54744 .76805 L F
.54575 .76946 m .54744 .76805 L .54714 .76812 L F
.555 .836 .997 r
.54765 .76801 m .54714 .76812 L .54608 .76789 L F
0 0 .271 r
.55135 .76646 m .55147 .76605 L .55147 .766 L F
.278 .285 .688 r
.54759 .76757 m .55071 .76856 L .54931 .76395 L F
.55071 .76856 m .55089 .76796 L .54931 .76395 L F
.765 .457 .466 r
.54688 .76641 m .54606 .76711 L .54603 .76582 L F
.54754 .76748 m .54606 .76711 L .54688 .76641 L F
.278 .285 .688 r
.54745 .76754 m .54931 .76395 L .54689 .76449 L F
.54759 .76757 m .54931 .76395 L .54745 .76754 L F
.87 .726 .7 r
.545 .76538 m .54608 .76789 L .54716 .76745 L F
.5449 .76554 m .54608 .76789 L .545 .76538 L F
0 .177 .711 r
.5438 .76536 m .54398 .76556 L .54428 .76532 L F
.5438 .76536 m .54428 .76532 L .5442 .76522 L F
.768 .432 .419 r
.54424 .76527 m .54151 .76724 L .54258 .76477 L F
.54454 .76536 m .54439 .76546 L .54424 .76527 L F
0 .177 .711 r
.54398 .76556 m .54608 .76789 L .54524 .76621 L F
.54449 .76555 m .54524 .76621 L .5449 .76554 L F
.54398 .76556 m .54524 .76621 L .54449 .76555 L F
.609 .194 .23 r
.54439 .76546 m .54355 .76884 L .54151 .76724 L F
.54454 .76536 m .54449 .76555 L .54439 .76546 L F
.54449 .76555 m .54355 .76884 L .54439 .76546 L F
.768 .432 .419 r
.54439 .76546 m .54151 .76724 L .54424 .76527 L F
0 .112 .584 r
.54438 .76521 m .5448 .76554 L .54454 .76536 L F
0 0 .004 r
.5448 .76554 m .54449 .76555 L .54454 .76536 L F
0 .177 .711 r
.54398 .76556 m .5449 .76554 L .54465 .76505 L F
0 .112 .584 r
.5436 .7645 m .54566 .76612 L .5448 .76554 L F
.5436 .7645 m .5448 .76554 L .54438 .76521 L F
.111 .608 .904 r
.54258 .76477 m .54465 .76505 L .5436 .7645 L F
.768 .432 .419 r
.54438 .76521 m .54258 .76477 L .5436 .7645 L F
.54454 .76536 m .54424 .76527 L .54438 .76521 L F
0 .177 .711 r
.5442 .76522 m .54424 .76527 L .54435 .76523 L F
.5442 .76522 m .54441 .76523 L .54432 .76517 L F
.768 .432 .419 r
.54424 .76527 m .54258 .76477 L .54438 .76521 L F
0 .177 .711 r
.54435 .76523 m .54428 .76532 L .54441 .76523 L F
.54424 .76527 m .54428 .76532 L .54435 .76523 L F
.54432 .76517 m .54441 .76523 L .54465 .76505 L F
0 0 .004 r
.54487 .76558 m .54418 .76665 L .54449 .76555 L F
.54487 .76558 m .54449 .76555 L .5448 .76554 L F
.54566 .76612 m .54355 .76884 L .54418 .76665 L F
.54566 .76612 m .54418 .76665 L .54487 .76558 L F
.87 .726 .7 r
.54465 .76505 m .5449 .76554 L .545 .76538 L F
.54686 .76716 m .54716 .76745 L .54739 .76719 L F
.54716 .76745 m .54745 .76754 L .54739 .76719 L F
.54465 .76505 m .54686 .76716 L .54689 .76449 L F
.54686 .76716 m .54739 .76719 L .54689 .76449 L F
.583 .73 .944 r
.51121 .76433 m .512 .76572 L .50893 .76516 L F
.708 .792 .917 r
.51448 .76451 m .512 .76572 L .51121 .76433 L F
0 0 .247 r
.66083 .51089 m .66148 .5132 L .66154 .51403 L F
.817 .987 .721 r
.66148 .5132 m .66019 .51477 L .66154 .51403 L F
.482 .106 .25 r
.49711 .76103 m .49602 .76245 L .49377 .76253 L F
.634 .35 .47 r
.49927 .76021 m .49602 .76245 L .49711 .76103 L F
.691 .762 .906 r
.55446 .75086 m .55747 .74983 L .55367 .75044 L F
.197 0 0 r
.24982 .5863 m .2534 .58514 L .25099 .58606 L F
.719 .796 .912 r
.34005 .72135 m .34379 .72197 L .3424 .72009 L F
.417 .655 .958 r
.34379 .72197 m .34439 .72027 L .3424 .72009 L F
.34379 .72197 m .34635 .72199 L .34439 .72027 L F
.535 .553 .821 r
.51413 .73999 m .51506 .74287 L .51291 .74275 L F
.481 .402 .69 r
.53002 .79848 m .52748 .79597 L .52943 .79685 L F
.791 .676 .737 r
.52591 .79788 m .52943 .79685 L .52748 .79597 L F
.593 .784 .972 r
.72203 .713 m .72525 .7135 L .7244 .71232 L F
.169 0 0 r
.72303 .71495 m .72462 .71469 L .72525 .7135 L F
.691 .253 .205 r
.72203 .713 m .72462 .71469 L .72525 .7135 L F
.254 .757 .887 r
.72764 .71304 m .72525 .7135 L .7244 .71232 L F
.72764 .71304 m .7276 .71323 L .72525 .7135 L F
.345 0 .025 r
.72462 .71469 m .7276 .71323 L .72525 .7135 L F
.72462 .71469 m .7276 .71323 L .72525 .7135 L F
.695 .67 .821 r
.48261 .78169 m .48173 .78522 L .481 .78282 L F
.48261 .78169 m .48372 .78414 L .48173 .78522 L F
.788 .496 .494 r
.62534 .51969 m .62269 .52178 L .6243 .51877 L F
0 0 0 r
.62804 .52393 m .62655 .52522 L .62335 .52508 L F
.893 .902 .826 r
.62534 .51969 m .62646 .51589 L .62753 .51684 L F
.62534 .51969 m .6243 .51877 L .62646 .51589 L F
.749 .539 .61 r
.53302 .73493 m .53626 .73517 L .53653 .7326 L F
.394 .118 .372 r
.32985 .62135 m .33042 .61953 L .33235 .61892 L F
.758 .709 .806 r
.3204 .72578 m .325 .72476 L .32367 .7242 L F
.406 .037 .222 r
.74186 .59161 m .74365 .59311 L .74102 .59314 L F
.74186 .59161 m .74421 .59114 L .74365 .59311 L F
.631 .432 .595 r
.5507 .77121 m .55037 .77433 L .54836 .7738 L F
.653 .532 .704 r
.55286 .77058 m .5507 .77121 L .55283 .76846 L F
.667 .485 .629 r
.55286 .77058 m .55037 .77433 L .5507 .77121 L F
.381 .752 .991 r
.36078 .72349 m .3639 .72451 L .36416 .72418 L F
.829 .799 .823 r
.63208 .51353 m .63549 .51213 L .6347 .51134 L F
.759 .849 .919 r
.63549 .51213 m .6363 .50995 L .6347 .51134 L F
.63549 .51213 m .63761 .51108 L .6363 .50995 L F
.558 .81 .992 r
.33664 .72091 m .33835 .7221 L .34005 .72135 L F
.327 .811 .871 r
.60485 .75502 m .60351 .75496 L .60147 .75547 L F
.246 0 0 r
.60734 .75377 m .60351 .75496 L .60485 .75502 L F
.714 .55 .665 r
.54317 .73798 m .54159 .7397 L .54003 .73803 L F
0 .072 .618 r
.44913 .78213 m .44998 .78512 L .45055 .78399 L F
.752 .233 0 r
.44998 .78512 m .4521 .78754 L .45076 .78705 L F
.44998 .78512 m .45076 .78705 L .45055 .78399 L F
.794 .563 .587 r
.60242 .68244 m .60456 .68522 L .60423 .68269 L F
.146 0 .211 r
.33953 .71354 m .3374 .71605 L .33882 .71523 L F
.774 .695 .775 r
.33567 .71293 m .3374 .71605 L .33953 .71354 L F
0 0 0 r
.3374 .71605 m .33744 .71711 L .33882 .71523 L F
.3374 .71605 m .33686 .71835 L .33744 .71711 L F
.599 .522 .74 r
.34424 .69695 m .34478 .6994 L .34642 .69648 L F
.593 .515 .736 r
.34478 .6994 m .34705 .69892 L .34642 .69648 L F
.597 .522 .74 r
.34478 .6994 m .34778 .70203 L .34705 .69892 L F
.333 .689 .98 r
.67208 .5104 m .6744 .51052 L .67551 .51169 L F
.546 .246 .41 r
.67551 .51169 m .67283 .51379 L .67208 .5104 L F
.67551 .51169 m .67517 .51339 L .67283 .51379 L F
.627 .848 .984 r
.67551 .51169 m .6766 .50955 L .67795 .51071 L F
.67551 .51169 m .6744 .51052 L .6766 .50955 L F
.674 .365 .442 r
.67799 .51266 m .67551 .51169 L .67795 .51071 L F
.67799 .51266 m .67517 .51339 L .67551 .51169 L F
.51 .219 .408 r
.45196 .67713 m .44925 .67935 L .44955 .6772 L F
.637 .55 .74 r
.71069 .59118 m .7125 .59072 L .71283 .58893 L F
.807 .344 .132 r
.71032 .59257 m .71069 .59118 L .70893 .59126 L F
.552 .396 .624 r
.71069 .59118 m .71271 .59354 L .7105 .59401 L F
.807 .344 .132 r
.71032 .59257 m .71271 .59354 L .71069 .59118 L F
.553 .648 .897 r
.62753 .51684 m .629 .51477 L .62646 .51589 L F
.62753 .51684 m .63017 .51622 L .629 .51477 L F
.664 .251 .252 r
.62646 .51589 m .63017 .51622 L .62753 .51684 L F
.699 .159 0 r
.55612 .72921 m .55816 .73112 L .55826 .73047 L F
.693 .15 0 r
.55816 .73112 m .56065 .73261 L .55826 .73047 L F
.309 0 .007 r
.49457 .73173 m .49804 .72979 L .49578 .73071 L F
.393 .677 .974 r
.29595 .59127 m .29536 .59258 L .29402 .59134 L F
.29595 .59127 m .29776 .59265 L .29536 .59258 L F
0 0 0 r
.5459 .75875 m .5475 .7577 L .54692 .75694 L F
0 0 .018 r
.54687 .75687 m .5469 .75691 L .54905 .7549 L F
.529 .861 .995 r
.54703 .75733 m .54669 .75711 L .54921 .7567 L F
.54669 .75711 m .54672 .75708 L .54921 .7567 L F
.54666 .75709 m .54715 .75673 L .54921 .7567 L F
0 0 .018 r
.5469 .75691 m .5475 .7577 L .54901 .75497 L F
.5469 .75691 m .54901 .75497 L .54905 .7549 L F
.529 .861 .995 r
.54669 .75711 m .54666 .75709 L .54672 .75708 L F
0 0 0 r
.54681 .75698 m .5469 .75691 L .54687 .75687 L F
.529 .861 .995 r
.54666 .75709 m .54613 .75675 L .54681 .75698 L F
.377 .78 .984 r
.54475 .7575 m .54613 .75675 L .54666 .75709 L F
.54611 .7574 m .54666 .75709 L .54703 .75733 L F
.54475 .7575 m .54666 .75709 L .54611 .7574 L F
.998 .8 .513 r
.54703 .75733 m .5459 .75875 L .54613 .75675 L F
0 0 0 r
.5459 .75875 m .54681 .75698 L .54613 .75675 L F
.54681 .75698 m .54687 .75687 L .54613 .75675 L F
.529 .861 .995 r
.54681 .75698 m .54613 .75675 L .54715 .75673 L F
0 0 0 r
.54679 .75702 m .54692 .75694 L .5469 .75691 L F
.54679 .75702 m .5469 .75691 L .54681 .75698 L F
.5459 .75875 m .54692 .75694 L .54679 .75702 L F
.50517 .76259 m .50275 .76452 L .50415 .76407 L F
.183 0 0 r
.402 .70878 m .40143 .70786 L .40347 .70722 L F
.402 .70878 m .39988 .70928 L .40143 .70786 L F
.594 .442 .645 r
.52482 .74892 m .52207 .74633 L .52467 .74613 L F
.52482 .74892 m .52212 .74938 L .52207 .74633 L F
.061 .208 .704 r
.62753 .50869 m .62901 .50814 L .62661 .50577 L F
.9 .792 .733 r
.62753 .50869 m .62658 .51144 L .62528 .51036 L F
.62753 .50869 m .62528 .51036 L .62901 .50814 L F
.583 .73 .944 r
.51121 .76433 m .50893 .76516 L .5077 .76396 L F
0 0 .282 r
.48151 .77128 m .48128 .77402 L .4823 .7727 L F
.573 .499 .734 r
.343 .69135 m .34358 .69379 L .34572 .69336 L F
.592 .492 .709 r
.34358 .69379 m .34642 .69648 L .34572 .69336 L F
.34358 .69379 m .34424 .69695 L .34642 .69648 L F
.572 .21 .315 r
.36968 .72115 m .36837 .72357 L .36551 .72334 L F
.574 .907 .978 r
.37261 .71957 m .37123 .7192 L .37098 .7203 L F
0 .018 .59 r
.37123 .7192 m .37142 .71969 L .37098 .7203 L F
.45 .883 .876 r
.37181 .72028 m .37098 .7203 L .37066 .72075 L F
.475 .895 .881 r
.37261 .71957 m .37098 .7203 L .37181 .72028 L F
0 .018 .59 r
.37142 .71969 m .37265 .72283 L .37098 .7203 L F
.45 .883 .876 r
.37066 .72075 m .37098 .7203 L .36968 .72115 L F
.041 0 .025 r
.37073 .72134 m .36968 .72115 L .37098 .7203 L F
.37073 .72134 m .36837 .72357 L .36968 .72115 L F
.757 .608 .693 r
.61317 .54429 m .61448 .54682 L .61117 .547 L F
.737 .498 .566 r
.61448 .54682 m .6112 .54922 L .61117 .547 L F
.61448 .54682 m .61513 .54993 L .6112 .54922 L F
.727 .491 .57 r
.61655 .54956 m .61448 .54682 L .61661 .54711 L F
.61655 .54956 m .61513 .54993 L .61448 .54682 L F
.027 .305 .796 r
.48512 .77474 m .4861 .77414 L .48385 .77437 L F
.531 .253 .438 r
.48758 .77412 m .48709 .77607 L .48512 .77474 L F
.027 .305 .796 r
.48512 .77474 m .48709 .77607 L .4861 .77414 L F
.812 .351 .134 r
.52025 .79794 m .52091 .79688 L .51845 .79546 L F
.576 .065 0 r
.52368 .79813 m .52091 .79688 L .52025 .79794 L F
.486 .197 .398 r
.4442 .6803 m .44387 .6821 L .44165 .68245 L F
.534 .236 .408 r
.4465 .68009 m .44387 .6821 L .4442 .6803 L F
.825 .671 .692 r
.6651 .50002 m .66343 .50024 L .6638 .49742 L F
.242 .711 .944 r
.66651 .50196 m .66343 .50024 L .6651 .50002 L F
.734 .453 .502 r
.50102 .79654 m .50455 .79851 L .5015 .79818 L F
.128 .647 .887 r
.42321 .65146 m .42527 .65159 L .42669 .65207 L F
.209 .699 .924 r
.42527 .65159 m .42876 .6521 L .42669 .65207 L F
.739 .48 .538 r
.52285 .80113 m .52604 .80098 L .52519 .80216 L F
.698 .392 .454 r
.52604 .80098 m .52733 .80402 L .52519 .80216 L F
.52604 .80098 m .52825 .80263 L .52733 .80402 L F
.52604 .80098 m .52838 .80156 L .52825 .80263 L F
.382 .693 .981 r
.75218 .58548 m .74829 .58405 L .75141 .58417 L F
.41 .648 .955 r
.75431 .58555 m .75218 .58548 L .75141 .58417 L F
.746 .629 .729 r
.59291 .71572 m .5964 .71624 L .59508 .71297 L F
.566 .686 .921 r
.5964 .71624 m .59897 .71582 L .59645 .71433 L F
.072 .228 .72 r
.59508 .71297 m .5964 .71624 L .59645 .71433 L F
.928 .954 .782 r
.5964 .71624 m .59441 .7175 L .59645 .71433 L F
.195 .347 .79 r
.59645 .71433 m .59801 .71773 L .5964 .71624 L F
.732 .362 .351 r
.5964 .71624 m .59801 .71773 L .59441 .7175 L F
.539 .271 .457 r
.41103 .69036 m .4137 .68809 L .41154 .68857 L F
.986 .847 .619 r
.6135 .54195 m .61262 .54187 L .61396 .54051 L F
.6135 .54195 m .61317 .54429 L .61262 .54187 L F
.338 .803 .929 r
.28848 .65348 m .28669 .65309 L .28447 .65348 L F
.16 .654 .917 r
.28848 .65348 m .28877 .65285 L .28669 .65309 L F
.28848 .65348 m .29038 .65312 L .28877 .65285 L F
.94 .811 .689 r
.34101 .71516 m .34252 .71701 L .34293 .71622 L F
.34101 .71516 m .34099 .71749 L .34252 .71701 L F
.692 .685 .839 r
.33855 .71962 m .3424 .72009 L .34252 .71701 L F
.402 .221 .518 r
.75792 .60196 m .75592 .60463 L .75594 .60277 L F
.829 .609 .604 r
.60609 .69895 m .60921 .70102 L .60799 .69957 L F
.797 .517 .514 r
.61116 .72325 m .61442 .72157 L .61142 .72093 L F
.61116 .72325 m .61455 .72377 L .61442 .72157 L F
.791 .385 .283 r
.56445 .70783 m .56451 .70897 L .56549 .70732 L F
.803 .557 .567 r
.56451 .70897 m .56783 .70732 L .56549 .70732 L F
.829 .609 .604 r
.60609 .69895 m .60579 .70103 L .60921 .70102 L F
.835 .694 .707 r
.60579 .70103 m .60723 .7046 L .60921 .70102 L F
.562 .571 .821 r
.76022 .58753 m .75905 .59101 L .75793 .58788 L F
.76022 .58753 m .76141 .59061 L .75905 .59101 L F
.513 .319 .555 r
.76141 .59061 m .75918 .59367 L .75905 .59101 L F
.491 .232 .449 r
.67304 .50047 m .67277 .50239 L .67047 .50289 L F
.564 .514 .758 r
.6752 .49967 m .67304 .50047 L .67225 .49803 L F
.568 .365 .566 r
.6752 .49967 m .67277 .50239 L .67304 .50047 L F
0 0 0 r
.6687 .52865 m .66807 .52827 L .66824 .52655 L F
.6687 .52865 m .66729 .53021 L .66807 .52827 L F
.786 .527 .545 r
.61464 .7263 m .61748 .72439 L .61455 .72377 L F
.61464 .7263 m .61799 .72684 L .61748 .72439 L F
.812 .513 .483 r
.67586 .52237 m .67412 .52407 L .67395 .52225 L F
.67586 .52237 m .67771 .52483 L .67412 .52407 L F
0 .25 .757 r
.50092 .78953 m .49958 .7891 L .49869 .78736 L F
.50092 .78953 m .50148 .79064 L .49958 .7891 L F
.816 .857 .878 r
.74233 .62377 m .74621 .62255 L .74461 .62259 L F
.793 .975 .908 r
.74461 .62259 m .74621 .62255 L .7475 .62111 L F
.545 .658 .91 r
.45751 .66726 m .45626 .66911 L .45559 .66741 L F
.45751 .66726 m .45838 .66881 L .45626 .66911 L F
.742 .804 .902 r
.29977 .60514 m .30192 .60639 L .30352 .60507 L F
.163 0 0 r
.51612 .72569 m .515 .72548 L .51725 .72471 L F
.51612 .72569 m .51376 .72622 L .515 .72548 L F
.581 .574 .81 r
.54215 .73254 m .54326 .72899 L .54084 .7295 L F
.54215 .73254 m .54437 .73215 L .54326 .72899 L F
.915 .582 .396 r
.49177 .78192 m .48952 .78268 L .48867 .78295 L F
.48 .894 .797 r
.53483 .76601 m .53385 .76655 L .53107 .76767 L F
.52 .392 .646 r
.53365 .77017 m .53107 .76767 L .53385 .76655 L F
.287 0 .278 r
.53593 .7672 m .53385 .76655 L .53483 .76601 L F
.599 .398 .581 r
.53593 .7672 m .53365 .77017 L .53385 .76655 L F
.751 .562 .641 r
.54159 .7397 m .53796 .73798 L .54003 .73803 L F
.771 .796 .873 r
.64397 .50033 m .64152 .50011 L .64351 .49951 L F
.7 .528 .652 r
.64397 .50033 m .64026 .50214 L .64152 .50011 L F
.64397 .50033 m .64442 .50277 L .64026 .50214 L F
.515 .515 .794 r
.64639 .49916 m .64397 .50033 L .64351 .49951 L F
.64639 .49916 m .64586 .49996 L .64397 .50033 L F
.581 .448 .665 r
.64676 .50218 m .64397 .50033 L .64586 .49996 L F
.64676 .50218 m .64442 .50277 L .64397 .50033 L F
.552 .149 .232 r
.46631 .76815 m .46554 .76902 L .46324 .76877 L F
.09 .571 .904 r
.46631 .76815 m .46796 .76863 L .46802 .76818 L F
.46796 .76863 m .46872 .76885 L .46802 .76818 L F
.414 .285 .594 r
.46877 .7666 m .46809 .76771 L .46802 .76818 L F
.328 0 .066 r
.46802 .76818 m .46697 .76952 L .46495 .7696 L F
.414 .285 .594 r
.46809 .76771 m .46697 .76952 L .46802 .76818 L F
.09 .571 .904 r
.46631 .76815 m .46802 .76818 L .46554 .76902 L F
.719 .298 .248 r
.629 .54974 m .62809 .5513 L .62605 .54948 L F
.461 .035 .144 r
.63139 .54952 m .62809 .5513 L .629 .54974 L F
.422 .142 .381 r
.53404 .76061 m .53563 .76194 L .536 .75996 L F
.53404 .76061 m .5335 .76253 L .53563 .76194 L F
.294 .374 .774 r
.52054 .73774 m .52183 .73723 L .51947 .73525 L F
.495 .203 .4 r
.52054 .73774 m .52154 .74004 L .52183 .73723 L F
.52054 .73774 m .51987 .74038 L .52154 .74004 L F
.968 .818 .64 r
.54359 .70243 m .54226 .70186 L .54312 .69938 L F
.898 .505 .266 r
.54444 .70409 m .54226 .70186 L .54359 .70243 L F
.142 .54 .922 r
.53721 .7192 m .54061 .7205 L .54009 .72117 L F
.13 .523 .915 r
.54061 .7205 m .5415 .72151 L .54009 .72117 L F
.68 .744 .9 r
.71387 .59825 m .71479 .59981 L .71153 .59927 L F
.817 .795 .832 r
.71707 .59721 m .71479 .59981 L .71387 .59825 L F
.612 .464 .656 r
.71707 .59721 m .71748 .60007 L .71479 .59981 L F
.613 .424 .602 r
.71479 .59981 m .71748 .60007 L .71513 .60214 L F
.784 .668 .736 r
.33567 .71293 m .33953 .71354 L .33933 .71102 L F
.294 .707 .974 r
.28664 .5907 m .28316 .58978 L .28499 .58998 L F
.229 .698 .943 r
.28499 .58998 m .2886 .59067 L .28664 .5907 L F
.518 .469 .741 r
.343 .69135 m .34501 .69099 L .34384 .68998 L F
.573 .499 .734 r
.343 .69135 m .34572 .69336 L .34501 .69099 L F
.945 .926 .756 r
.59661 .70232 m .59543 .70491 L .59445 .70388 L F
.178 .686 .903 r
.42305 .66397 m .42214 .66362 L .41988 .66354 L F
.113 .659 .829 r
.42545 .66383 m .42214 .66362 L .42305 .66397 L F
.721 .691 .82 r
.42357 .66531 m .42545 .66383 L .42305 .66397 L F
.674 .688 .856 r
.65596 .51429 m .65208 .51184 L .65471 .51092 L F
.477 .416 .71 r
.37363 .69108 m .37113 .68911 L .37278 .68712 L F
.37363 .69108 m .37164 .69099 L .37113 .68911 L F
.639 .168 0 r
.59757 .71013 m .59575 .70786 L .59748 .70762 L F
.425 .14 .374 r
.38636 .66879 m .38381 .67106 L .38433 .66931 L F
.871 .684 .647 r
.60939 .71819 m .61111 .71614 L .60955 .71584 L F
.60939 .71819 m .61115 .71865 L .61111 .71614 L F
.871 .83 .804 r
.62001 .53423 m .61696 .53554 L .61874 .53266 L F
.837 .855 .859 r
.6363 .50995 m .63761 .51108 L .63998 .50844 L F
.044 0 0 r
.29628 .65228 m .29225 .65303 L .29417 .6526 L F
.271 .75 .931 r
.26465 .58663 m .26685 .58638 L .26822 .58686 L F
.287 0 0 r
.26685 .58638 m .27038 .58674 L .26822 .58686 L F
.857 .745 .739 r
.60688 .71306 m .60994 .71089 L .60859 .70988 L F
0 0 0 r
.25918 .61564 m .25811 .61611 L .25748 .61639 L F
.205 0 .253 r
.25748 .61639 m .25811 .61611 L .25726 .61702 L F
.513 .449 .722 r
.34278 .67766 m .34528 .67942 L .34465 .67733 L F
.34278 .67766 m .34337 .6799 L .34528 .67942 L F
.421 .019 .167 r
.42819 .67629 m .43036 .6762 L .43149 .67445 L F
.561 .374 .585 r
.43036 .6762 m .43274 .67271 L .43149 .67445 L F
.041 .12 .62 r
.687 .51611 m .68487 .51715 L .68429 .51603 L F
.753 .563 .639 r
.55453 .76285 m .55528 .76577 L .55165 .76523 L F
.63 .488 .671 r
.55453 .76285 m .55528 .76577 L .55742 .76247 L F
.55453 .76285 m .55528 .76577 L .55742 .76247 L F
.656 .569 .745 r
.51017 .71998 m .51114 .72178 L .51324 .72087 L F
.953 .796 .649 r
.62658 .51144 m .62448 .51324 L .62528 .51036 L F
.62658 .51144 m .62626 .51351 L .62448 .51324 L F
.829 .509 .447 r
.33052 .71722 m .3334 .71593 L .33188 .71486 L F
.33052 .71722 m .33322 .71801 L .3334 .71593 L F
.678 .628 .793 r
.33333 .71368 m .3334 .71593 L .33567 .71293 L F
.973 .846 .657 r
.33188 .71486 m .3334 .71593 L .33333 .71368 L F
.33 0 .105 r
.36186 .65657 m .36099 .65513 L .35957 .65686 L F
.36186 .65657 m .36309 .65467 L .36099 .65513 L F
.565 .414 .636 r
.33848 .70979 m .33999 .70722 L .33789 .70763 L F
.28 0 .184 r
.38159 .674 m .37881 .67628 L .37976 .67462 L F
.471 .439 .741 r
.3472 .71031 m .34828 .70677 L .34587 .70763 L F
.194 .657 .941 r
.30872 .5937 m .31236 .59469 L .31027 .59481 L F
.695 .526 .655 r
.52927 .7397 m .52968 .74331 L .52629 .74305 L F
.552 .439 .679 r
.53159 .73918 m .52968 .74331 L .52927 .7397 L F
.471 .439 .741 r
.3472 .71031 m .34898 .71003 L .34828 .70677 L F
.458 .17 .387 r
.26176 .61336 m .25918 .61564 L .25977 .61378 L F
.717 .723 .854 r
.61262 .54187 m .61317 .54429 L .61088 .54454 L F
.713 .546 .661 r
.61088 .54454 m .61317 .54429 L .61117 .547 L F
.582 .869 .995 r
.40137 .66445 m .40063 .66588 L .40291 .66443 L F
.40137 .66445 m .39933 .66521 L .40063 .66588 L F
.919 .836 .747 r
.62827 .52155 m .63106 .51965 L .62992 .51869 L F
.62827 .52155 m .62973 .5227 L .63106 .51965 L F
.867 .887 .848 r
.62992 .51869 m .63106 .51965 L .63342 .51683 L F
.743 .477 .528 r
.50734 .76233 m .51121 .76433 L .5077 .76396 L F
0 0 0 r
.26744 .64284 m .27111 .64244 L .26897 .64311 L F
.442 .143 .361 r
.4293 .69079 m .42854 .69352 L .42633 .69384 L F
.411 .115 .35 r
.43041 .69303 m .4293 .69079 L .43134 .69042 L F
.43041 .69303 m .42854 .69352 L .4293 .69079 L F
.636 .201 .198 r
.48294 .793 m .48628 .79296 L .48523 .7947 L F
.637 .312 .404 r
.48628 .79296 m .48693 .79528 L .48523 .7947 L F
.48628 .79296 m .48886 .79498 L .48693 .79528 L F
.48628 .79296 m .48848 .79341 L .48886 .79498 L F
.224 0 .1 r
.5335 .76253 m .53168 .76311 L .53089 .76412 L F
.072 .348 .821 r
.5415 .72151 m .54403 .72335 L .54319 .72406 L F
.167 .51 .913 r
.54403 .72335 m .54535 .72491 L .54319 .72406 L F
0 0 0 r
.50755 .72048 m .50603 .72418 L .50509 .72167 L F
.50755 .72048 m .50686 .72234 L .50603 .72418 L F
.293 .354 .755 r
.50686 .72234 m .50642 .7267 L .50603 .72418 L F
.659 .603 .78 r
.37836 .69664 m .37643 .69753 L .37488 .6946 L F
0 .01 .58 r
.57356 .72716 m .57327 .72599 L .57159 .72385 L F
.594 .138 0 r
.57356 .72716 m .57404 .72791 L .57327 .72599 L F
.57356 .72716 m .57492 .72903 L .57404 .72791 L F
.918 .708 .603 r
.59759 .69387 m .59559 .6954 L .59654 .69323 L F
.59759 .69387 m .59725 .69626 L .59559 .6954 L F
.78 .612 .671 r
.71582 .59147 m .71436 .58872 L .7125 .59072 L F
.448 .295 .579 r
.7125 .59072 m .71535 .59219 L .71582 .59147 L F
.732 .401 .42 r
.71535 .59219 m .7182 .59079 L .71582 .59147 L F
.284 0 .25 r
.29044 .63552 m .28799 .63783 L .29003 .63741 L F
.444 .202 .452 r
.29044 .63552 m .29205 .63672 L .29251 .63521 L F
.29044 .63552 m .29003 .63741 L .29205 .63672 L F
.714 .545 0 r
.48875 .75669 m .48855 .75367 L .48898 .75446 L F
.43 .143 .374 r
.41167 .70225 m .41103 .70416 L .40901 .70455 L F
.418 .132 .369 r
.41317 .70359 m .41167 .70225 L .41355 .70157 L F
.41317 .70359 m .41103 .70416 L .41167 .70225 L F
.916 .662 .166 r
.58225 .746 m .58158 .74283 L .58173 .7436 L F
.49 .375 .649 r
.34337 .6799 m .34554 .68181 L .34528 .67942 L F
.34337 .6799 m .34369 .6824 L .34554 .68181 L F
.789 .857 .9 r
.61711 .53851 m .61594 .53753 L .61696 .53554 L F
.461 .154 .359 r
.42413 .69418 m .42365 .69591 L .42149 .6963 L F
.446 .126 .329 r
.42633 .69384 m .42365 .69591 L .42413 .69418 L F
.402 .046 .243 r
.48813 .73561 m .4852 .7376 L .48734 .73716 L F
.412 .099 .321 r
.48734 .73716 m .49009 .73489 L .48813 .73561 L F
.599 .826 .986 r
.27444 .64272 m .27111 .64244 L .27303 .64199 L F
.628 .858 .986 r
.2767 .64179 m .27444 .64272 L .27303 .64199 L F
.555 .349 .556 r
.66308 .53595 m .66344 .53855 L .66091 .53888 L F
.454 .279 .553 r
.66549 .53773 m .66308 .53595 L .6655 .53537 L F
.66549 .53773 m .66344 .53855 L .66308 .53595 L F
.217 0 0 r
.37962 .71764 m .37603 .71962 L .37758 .71814 L F
.688 .468 .583 r
.75075 .60691 m .75352 .60761 L .75339 .60529 L F
.611 .835 .985 r
.75339 .60529 m .75429 .60258 L .75259 .60171 L F
.75339 .60529 m .75531 .60352 L .75429 .60258 L F
.493 .336 .596 r
.75815 .60445 m .75592 .60463 L .75792 .60196 L F
.544 .556 .817 r
.75924 .60749 m .75592 .60463 L .75815 .60445 L F
.208 0 .344 r
.75531 .60626 m .75639 .60637 L .75614 .60361 L F
.75604 .60367 m .75614 .60361 L .75612 .6034 L F
.611 .835 .985 r
.75354 .60525 m .75592 .60463 L .75556 .60397 L F
.331 0 .059 r
.75531 .60626 m .75592 .60463 L .75339 .60529 L F
.611 .835 .985 r
.75354 .60525 m .75556 .60397 L .75531 .60352 L F
.969 .749 .314 r
.75531 .60352 m .75592 .60463 L .75531 .60626 L F
.208 0 .344 r
.75531 .60626 m .75614 .60361 L .75604 .60367 L F
.611 .835 .985 r
.75339 .60529 m .75354 .60525 L .75531 .60352 L F
.331 0 .059 r
.75531 .60626 m .75339 .60529 L .75352 .60761 L F
.637 .198 .19 r
.51329 .77088 m .51594 .77159 L .51375 .77176 L F
0 0 .435 r
.51329 .77088 m .51375 .77176 L .51414 .77195 L F
.51329 .77088 m .51414 .77195 L .51155 .77129 L F
0 .455 .751 r
.51155 .77129 m .51308 .77154 L .5125 .77135 L F
.51155 .77129 m .5125 .77135 L .51042 .77067 L F
0 0 0 r
.51128 .77127 m .51155 .77129 L .50982 .77155 L F
.51329 .77088 m .51155 .77129 L .51128 .77127 L F
.649 .506 .674 r
.51532 .76868 m .51594 .77159 L .51329 .77088 L F
.947 .898 .745 r
.70931 .60012 m .7087 .60191 L .70725 .60186 L F
.586 .016 0 r
.70725 .60186 m .7087 .60191 L .70867 .60284 L F
.723 .196 0 r
.70867 .60284 m .7087 .60191 L .71117 .60472 L F
.911 .721 .634 r
.60464 .68787 m .60424 .69002 L .60676 .69093 L F
.941 .667 .492 r
.60424 .69002 m .60662 .69357 L .60676 .69093 L F
.859 .517 .403 r
.50232 .75462 m .50215 .75617 L .50051 .75407 L F
.50232 .75462 m .50474 .7585 L .50215 .75617 L F
.594 .463 .672 r
.50623 .75688 m .50232 .75462 L .50617 .75436 L F
.50623 .75688 m .50474 .7585 L .50232 .75462 L F
.642 .586 .776 r
.38188 .69937 m .37977 .70023 L .37881 .69841 L F
.297 0 0 r
.48338 .75775 m .48567 .75825 L .48729 .75784 L F
.575 .174 .245 r
.48567 .75825 m .48875 .75669 L .48729 .75784 L F
.097 .339 .811 r
.57752 .73204 m .57492 .72903 L .57565 .73038 L F
.95 .691 .509 r
.60719 .7067 m .60864 .7076 L .60723 .7046 L F
.851 .697 .69 r
.60719 .7067 m .60859 .70988 L .60864 .7076 L F
.218 0 .279 r
.55234 .6881 m .55275 .68965 L .5542 .68815 L F
.55234 .6881 m .55202 .69041 L .55275 .68965 L F
.55 .317 .514 r
.38417 .67343 m .38204 .67176 L .38381 .67106 L F
.38417 .67343 m .38159 .674 L .38204 .67176 L F
.406 .01 .172 r
.64277 .5473 m .64182 .54917 L .63955 .54956 L F
.595 .279 .404 r
.64506 .54676 m .64182 .54917 L .64277 .5473 L F
.319 0 0 r
.51017 .71998 m .51001 .72041 L .50755 .72048 L F
.371 0 0 r
.51017 .71998 m .51268 .72032 L .51001 .72041 L F
.656 .569 .745 r
.51017 .71998 m .51324 .72087 L .51268 .72032 L F
.52 .729 .969 r
.32595 .59483 m .32511 .59652 L .32425 .59516 L F
.32595 .59483 m .32717 .59619 L .32511 .59652 L F
.424 .792 .994 r
.58994 .72751 m .59043 .72689 L .58843 .72585 L F
.58994 .72751 m .59177 .72702 L .59043 .72689 L F
.492 .182 .368 r
.35419 .65935 m .35287 .65751 L .35236 .65962 L F
.35419 .65935 m .35505 .65721 L .35287 .65751 L F
0 .345 .781 r
.58274 .74953 m .58419 .74992 L .58166 .74887 L F
.58274 .74953 m .58555 .75103 L .58419 .74992 L F
.49 .465 .757 r
.31151 .6136 m .31247 .61001 L .31065 .61046 L F
.31151 .6136 m .31332 .61321 L .31247 .61001 L F
.457 .329 .617 r
.31151 .6136 m .31163 .61609 L .31332 .61321 L F
.238 .577 .943 r
.33965 .60154 m .33812 .60136 L .33611 .59965 L F
.029 .599 .76 r
.45908 .78765 m .45791 .78755 L .45558 .78749 L F
.489 .241 .466 r
.45998 .78885 m .45908 .78765 L .46058 .78828 L F
.45998 .78885 m .45791 .78755 L .45908 .78765 L F
.725 .321 .282 r
.52519 .72603 m .52358 .72379 L .52265 .72459 L F
.825 .555 .531 r
.55143 .74907 m .55081 .74948 L .54828 .74846 L F
.13 .204 .673 r
.55143 .74907 m .55323 .7518 L .5526 .75175 L F
.756 .565 .638 r
.7202 .59911 m .71707 .59721 L .71937 .59652 L F
.7202 .59911 m .71748 .60007 L .71707 .59721 L F
0 0 0 r
.71975 .59944 m .71748 .60007 L .7202 .59911 L F
.248 .363 .785 r
.71937 .59652 m .72182 .59835 L .7202 .59911 L F
.5 .323 .573 r
.72182 .59835 m .71975 .59944 L .7202 .59911 L F
.414 .225 .514 r
.37486 .67923 m .37221 .6828 L .37246 .68034 L F
.471 .246 .49 r
.47977 .76558 m .47959 .76729 L .47767 .76787 L F
.374 0 .033 r
.47959 .76729 m .4768 .76834 L .47767 .76787 L F
0 0 .333 r
.6657 .51869 m .66669 .52084 L .66717 .52225 L F
.843 .525 0 r
.66706 .52334 m .66717 .52225 L .66669 .52084 L F
.66706 .52334 m .66762 .52441 L .66717 .52225 L F
.544 .411 .65 r
.34453 .67397 m .34641 .67109 L .34435 .67154 L F
.484 .214 .429 r
.42424 .68019 m .42578 .68175 L .42602 .67959 L F
.42424 .68019 m .42368 .68218 L .42578 .68175 L F
.338 .425 .804 r
.53616 .75706 m .53658 .75392 L .53464 .75482 L F
.532 .349 .578 r
.53616 .75706 m .53824 .75944 L .53758 .75705 L F
.53616 .75706 m .536 .75996 L .53824 .75944 L F
.594 .347 .512 r
.46174 .75113 m .46437 .74885 L .46204 .74917 L F
.717 .723 .854 r
.61262 .54187 m .61088 .54454 L .61015 .54413 L F
.748 .571 .655 r
.61088 .54454 m .61117 .547 L .60758 .54677 L F
0 0 0 r
.39356 .66821 m .39282 .66833 L .395 .66846 L F
.39356 .66821 m .39174 .66885 L .39282 .66833 L F
.458 0 .026 r
.48272 .75368 m .48254 .75419 L .48007 .7543 L F
.525 .359 .599 r
.49828 .76449 m .49602 .76245 L .50036 .76321 L F
.445 .051 .198 r
.49828 .76449 m .49872 .76422 L .49875 .7642 L F
.49828 .76449 m .50069 .76327 L .50171 .7624 L F
.525 .359 .599 r
.49828 .76449 m .50036 .76321 L .50069 .76327 L F
.445 .051 .198 r
.49828 .76449 m .49875 .7642 L .50007 .76337 L F
.69 .373 .435 r
.50171 .7624 m .50069 .76327 L .5006 .76307 L F
.50171 .7624 m .5006 .76307 L .49927 .76021 L F
.445 .051 .198 r
.5006 .76307 m .50171 .7624 L .50142 .76257 L F
.49872 .76422 m .50171 .7624 L .5006 .76307 L F
.49872 .76422 m .50142 .76257 L .50007 .76337 L F
.634 .35 .47 r
.49927 .76021 m .5006 .76307 L .49602 .76245 L F
.5006 .76307 m .50069 .76327 L .50036 .76321 L F
.5006 .76307 m .50036 .76321 L .49602 .76245 L F
.613 .637 .851 r
.50028 .75784 m .49927 .76021 L .49805 .75775 L F
.50028 .75784 m .50156 .75989 L .49927 .76021 L F
.69 .373 .435 r
.50171 .7624 m .49927 .76021 L .50156 .75989 L F
.373 .057 .296 r
.40912 .69106 m .41049 .69203 L .41103 .69036 L F
.40912 .69106 m .40846 .69264 L .41049 .69203 L F
.716 .436 .501 r
.64249 .52151 m .64582 .52177 L .64475 .51997 L F
.653 .418 .551 r
.64475 .51997 m .64808 .52162 L .6474 .51867 L F
.64475 .51997 m .64582 .52177 L .64808 .52162 L F
.604 .59 .81 r
.7231 .71795 m .72462 .71469 L .72303 .71495 L F
.7231 .71795 m .72563 .71742 L .72462 .71469 L F
.337 .37 .748 r
.71742 .60386 m .71582 .60545 L .71513 .60214 L F
.388 .451 .804 r
.71742 .60386 m .71899 .60846 L .71582 .60545 L F
.473 .309 .578 r
.3053 .62459 m .30725 .62403 L .30724 .62165 L F
.354 .044 .293 r
.3053 .62459 m .30454 .62649 L .30725 .62403 L F
.223 .287 .719 r
.34197 .70919 m .34056 .71053 L .33999 .70722 L F
.407 .18 .454 r
.33935 .61266 m .33957 .61075 L .34163 .61023 L F
.727 .985 .895 r
.60936 .54351 m .61262 .54187 L .61015 .54413 L F
0 0 0 r
.60815 .54499 m .60969 .54333 L .60936 .54351 L F
.727 .985 .895 r
.60936 .54351 m .61065 .54231 L .61262 .54187 L F
0 0 0 r
.60969 .54333 m .61065 .54231 L .60936 .54351 L F
.268 .734 .947 r
.6087 .54387 m .60936 .54351 L .61015 .54413 L F
.60643 .54347 m .60936 .54351 L .6087 .54387 L F
.751 .562 .641 r
.54159 .7397 m .53796 .74027 L .53796 .73798 L F
.708 .425 .494 r
.54159 .7397 m .54003 .74265 L .53796 .74027 L F
.722 .441 .501 r
.54159 .7397 m .54342 .7428 L .54003 .74265 L F
.798 .707 .764 r
.71283 .58893 m .7125 .59072 L .71436 .58872 L F
.515 .729 .97 r
.34146 .6016 m .34072 .60265 L .33965 .60154 L F
.489 .518 .814 r
.34351 .60442 m .34072 .60265 L .34146 .6016 L F
.599 .582 .805 r
.67359 .49625 m .67225 .49803 L .67144 .49482 L F
.564 .514 .758 r
.6752 .49967 m .67225 .49803 L .67359 .49625 L F
.544 0 0 r
.49088 .78973 m .49308 .79056 L .49409 .79023 L F
.512 0 0 r
.49409 .79023 m .49525 .79158 L .4958 .78957 L F
.49409 .79023 m .49308 .79056 L .49525 .79158 L F
.265 .389 .802 r
.46352 .7752 m .46249 .7766 L .46112 .77343 L F
.253 .371 .79 r
.46352 .7752 m .46466 .77834 L .46249 .7766 L F
.548 .565 .823 r
.54456 .74902 m .54555 .75187 L .54338 .75207 L F
.992 .792 .535 r
.55285 .7409 m .55164 .74052 L .55244 .73808 L F
.55285 .7409 m .55245 .74315 L .55164 .74052 L F
.667 .588 .757 r
.53626 .73517 m .53796 .73798 L .53623 .73799 L F
.637 .337 .445 r
.52838 .80156 m .53048 .80343 L .52825 .80263 L F
.525 .396 .647 r
.50094 .75622 m .49754 .75539 L .50051 .75407 L F
.50094 .75622 m .49805 .75775 L .49754 .75539 L F
.151 0 0 r
.28087 .60449 m .27955 .60515 L .27765 .60549 L F
.343 0 0 r
.28293 .60446 m .27955 .60515 L .28087 .60449 L F
.954 .748 .586 r
.57047 .68133 m .57154 .68174 L .57313 .68157 L F
.45 0 .049 r
.3424 .72009 m .34439 .72027 L .34596 .71876 L F
.695 .273 .24 r
.34439 .72027 m .34793 .72061 L .34596 .71876 L F
.58 .317 .482 r
.34596 .71876 m .34793 .72061 L .34861 .71803 L F
.51 .301 .531 r
.48813 .76249 m .48817 .7655 L .48539 .76541 L F
.607 .384 .552 r
.48816 .76771 m .48539 .76541 L .48817 .7655 L F
.48816 .76771 m .48415 .76866 L .48539 .76541 L F
.765 .649 .734 r
.5759 .71386 m .57766 .71287 L .57733 .71294 L F
.458 .344 .635 r
.5804 .71252 m .57733 .71294 L .57925 .71198 L F
.765 .649 .734 r
.57766 .71287 m .57925 .71198 L .57733 .71294 L F
.033 .582 .832 r
.5769 .71303 m .57733 .71294 L .57804 .71325 L F
.57474 .7126 m .57733 .71294 L .5769 .71303 L F
.458 .344 .635 r
.5804 .71252 m .57804 .71325 L .57733 .71294 L F
.5804 .71252 m .58032 .7151 L .57804 .71325 L F
.444 .344 .647 r
.57804 .71325 m .58032 .7151 L .57843 .71527 L F
.648 .766 .293 r
.51169 .72432 m .51207 .72345 L .51321 .72094 L F
.51321 .72093 m .51321 .72094 L .51324 .72087 L F
.51169 .72432 m .51321 .72094 L .51321 .72093 L F
.85 .422 .211 r
.51268 .72032 m .51207 .72345 L .51324 .72087 L F
.51268 .72032 m .51586 .72339 L .51207 .72345 L F
.107 0 0 r
.51207 .72345 m .51478 .72348 L .51586 .72339 L F
.667 .216 0 r
.51312 .72111 m .51478 .72348 L .51359 .72197 L F
.51268 .72032 m .51316 .72103 L .51312 .72111 L F
.51316 .72103 m .51478 .72348 L .51312 .72111 L F
.785 .563 .599 r
.54662 .74068 m .54679 .74321 L .54342 .7428 L F
.49 .307 .56 r
.54949 .74185 m .54662 .74068 L .54759 .73946 L F
.54949 .74185 m .54679 .74321 L .54662 .74068 L F
.339 0 .065 r
.6555 .54176 m .65259 .54334 L .65326 .54232 L F
.228 0 0 r
.37143 .65017 m .36854 .65164 L .37059 .65109 L F
.382 0 .071 r
.37059 .65109 m .37284 .6508 L .37143 .65017 L F
.414 .326 .646 r
.44386 .7712 m .44537 .76787 L .44316 .76819 L F
.44386 .7712 m .44546 .77083 L .44537 .76787 L F
.376 .227 .548 r
.44381 .77368 m .44546 .77083 L .44386 .7712 L F
.826 .646 .659 r
.66651 .50196 m .66821 .50568 L .6653 .50503 L F
.817 .552 .539 r
.66821 .50568 m .66521 .50665 L .6653 .50503 L F
.274 .286 .692 r
.66888 .50856 m .66937 .50833 L .66821 .50568 L F
.817 .552 .539 r
.66821 .50568 m .66937 .50833 L .6692 .50826 L F
.541 .35 .571 r
.67047 .50289 m .67058 .50518 L .66821 .50568 L F
.964 .849 .68 r
.66946 .50451 m .67058 .50518 L .66962 .50419 L F
.093 .159 .641 r
.66946 .50789 m .66922 .50831 L .66821 .50568 L F
.66922 .50831 m .66888 .50856 L .66859 .50732 L F
.6692 .50826 m .66859 .50732 L .66821 .50568 L F
.66922 .50831 m .66859 .50732 L .6692 .50826 L F
.958 .735 .559 r
.6692 .50826 m .6673 .50921 L .66521 .50665 L F
.188 .091 .505 r
.66888 .50856 m .6693 .51066 L .66937 .50833 L F
.346 .277 .635 r
.66923 .5083 m .6693 .51066 L .66888 .50856 L F
.958 .735 .559 r
.66937 .50833 m .66927 .50837 L .66923 .5083 L F
.66937 .50833 m .66923 .5083 L .66921 .50827 L F
.346 .277 .635 r
.66955 .50805 m .66946 .50894 L .66923 .5083 L F
.66926 .50838 m .6693 .51066 L .66923 .5083 L F
.958 .735 .559 r
.66926 .50838 m .6693 .51066 L .6673 .50921 L F
.66937 .50833 m .6693 .51066 L .66926 .50838 L F
.346 .277 .635 r
.66946 .50894 m .6693 .51066 L .66926 .50838 L F
.958 .735 .559 r
.66921 .50827 m .66923 .5083 L .6692 .50826 L F
.66927 .50837 m .6673 .50921 L .6692 .50826 L F
.817 .552 .539 r
.66821 .50568 m .6692 .50826 L .66521 .50665 L F
.093 .159 .641 r
.66955 .50805 m .66821 .50568 L .67058 .50518 L F
.964 .849 .68 r
.66831 .50676 m .66946 .50596 L .66946 .50451 L F
.66946 .50596 m .67058 .50518 L .66946 .50451 L F
.093 .159 .641 r
.66955 .50805 m .66946 .50812 L .66946 .50789 L F
.66946 .50812 m .66922 .50831 L .66946 .50789 L F
.725 .606 .725 r
.67047 .50289 m .66821 .50568 L .66651 .50196 L F
.945 .926 .756 r
.59661 .70232 m .59445 .70388 L .59555 .70159 L F
.48 .344 .618 r
.54278 .6965 m .54312 .69938 L .54499 .69839 L F
.539 .43 .678 r
.44316 .76819 m .44537 .76787 L .44493 .76541 L F
.623 .523 .72 r
.66729 .53021 m .66531 .53285 L .66426 .53176 L F
.555 .598 .852 r
.47028 .7786 m .46952 .78139 L .46809 .77881 L F
.47028 .7786 m .47164 .78135 L .46952 .78139 L F
0 0 0 r
.70297 .58983 m .70366 .58756 L .70384 .58816 L F
.451 .687 .967 r
.70457 .58664 m .70384 .58816 L .70366 .58756 L F
.70457 .58664 m .70574 .5879 L .70384 .58816 L F
.41 .132 .378 r
.33673 .61573 m .33735 .61327 L .33935 .61266 L F
.736 .652 .766 r
.55528 .76577 m .55283 .76846 L .55165 .76523 L F
.533 .344 .57 r
.67277 .50239 m .67058 .50518 L .67047 .50289 L F
.565 .608 .855 r
.63986 .49902 m .63907 .50028 L .63577 .49636 L F
.894 .847 .79 r
.63986 .49902 m .63796 .50183 L .64026 .50214 L F
.732 .399 .417 r
.63764 .50431 m .64026 .50214 L .63796 .50183 L F
.63764 .50431 m .64181 .50485 L .64026 .50214 L F
.073 .064 .541 r
.64026 .50214 m .64181 .49849 L .64152 .50011 L F
.719 .91 .961 r
.64351 .49951 m .64152 .50011 L .64181 .49849 L F
.073 .064 .541 r
.64026 .50214 m .64218 .50077 L .64181 .49849 L F
.374 .272 .609 r
.64459 .50354 m .64026 .50214 L .64442 .50277 L F
.64026 .50214 m .64459 .50354 L .64218 .50077 L F
.64026 .50214 m .64181 .50485 L .64459 .50354 L F
.64459 .50354 m .64181 .50485 L .64026 .50214 L F
.082 0 .201 r
.58171 .67496 m .5811 .6767 L .58322 .67373 L F
.839 .498 .409 r
.52438 .71517 m .52581 .71325 L .52251 .71291 L F
.52438 .71517 m .526 .71506 L .52581 .71325 L F
.297 0 .077 r
.28799 .63783 m .28857 .63927 L .29003 .63741 L F
.28799 .63783 m .28652 .6398 L .28857 .63927 L F
.738 .243 .059 r
.59002 .75456 m .58866 .75464 L .58744 .75369 L F
0 .222 .735 r
.59002 .75456 m .59234 .75643 L .59169 .75542 L F
.59002 .75456 m .59169 .75542 L .58866 .75464 L F
0 0 0 r
.57294 .67629 m .57485 .67594 L .57528 .67578 L F
.778 .392 .325 r
.57294 .67629 m .57518 .67891 L .57485 .67594 L F
.177 .697 .879 r
.39374 .64855 m .39579 .64852 L .39708 .64879 L F
.075 .625 .829 r
.39579 .64852 m .3993 .64891 L .39708 .64879 L F
.865 .419 .115 r
.56945 .74297 m .5724 .74616 L .57255 .74356 L F
.521 .608 .881 r
.64127 .51886 m .64017 .52151 L .6389 .52116 L F
.64127 .51886 m .64249 .52151 L .64017 .52151 L F
.56 .194 .304 r
.54836 .7738 m .5474 .77598 L .54525 .77612 L F
.667 .485 .629 r
.55286 .77058 m .5526 .77424 L .55037 .77433 L F
.457 .884 .805 r
.54963 .77396 m .54981 .77408 L .55156 .77319 L F
.156 0 .112 r
.54981 .77408 m .54836 .7738 L .55006 .77425 L F
.54981 .77408 m .5474 .77598 L .54836 .7738 L F
.457 .884 .805 r
.54767 .77476 m .54981 .77408 L .54963 .77396 L F
.156 0 .112 r
.54981 .77408 m .55006 .77425 L .55037 .77433 L F
.795 .771 .831 r
.73133 .71775 m .73235 .721 L .73464 .71834 L F
.413 .204 .484 r
.55472 .77124 m .5526 .77424 L .55286 .77058 L F
.898 .788 .731 r
.62777 .50319 m .62482 .50467 L .6262 .50194 L F
.62777 .50319 m .62661 .50577 L .62482 .50467 L F
.828 .791 .817 r
.62998 .5005 m .62777 .50319 L .6262 .50194 L F
.535 .48 .741 r
.51679 .76474 m .51757 .76808 L .51532 .76868 L F
.515 .408 .671 r
.51757 .76808 m .51772 .77067 L .51532 .76868 L F
.502 .408 .681 r
.51772 .77067 m .51594 .77159 L .51532 .76868 L F
.908 .638 .138 r
.62626 .51351 m .6259 .5147 L .62448 .51324 L F
.62626 .51351 m .62646 .51589 L .6259 .5147 L F
0 0 0 r
.62042 .73523 m .62 .73702 L .6197 .73733 L F
.837 .739 .217 r
.62031 .7341 m .62 .73702 L .62042 .73523 L F
.543 .609 .869 r
.4449 .65759 m .44132 .65507 L .44355 .65489 L F
.637 .66 .856 r
.44713 .65691 m .4449 .65759 L .44355 .65489 L F
.658 .622 .802 r
.66083 .51089 m .65707 .50805 L .65867 .50856 L F
.135 .471 .894 r
.66056 .50928 m .66083 .51089 L .65867 .50856 L F
.846 .73 .735 r
.66056 .50928 m .66148 .5132 L .66083 .51089 L F
.8 .674 .725 r
.63017 .51622 m .63342 .51683 L .63208 .51353 L F
.867 .887 .848 r
.62992 .51869 m .63342 .51683 L .63017 .51622 L F
.687 .422 .517 r
.68171 .52535 m .67862 .52675 L .67771 .52483 L F
.68171 .52535 m .68103 .52719 L .67862 .52675 L F
0 0 0 r
.6828 .52343 m .68103 .52719 L .68171 .52535 L F
.57763 .67863 m .57841 .67711 L .57764 .67604 L F
.57763 .67863 m .57663 .67998 L .57841 .67711 L F
.516 .391 .648 r
.51947 .73525 m .52183 .73723 L .52176 .73483 L F
.762 .691 .784 r
.34912 .72409 m .35058 .72689 L .35199 .72573 L F
.415 .191 .462 r
.35236 .65962 m .3504 .66031 L .34999 .66241 L F
.824 .53 .492 r
.60955 .72045 m .61115 .71865 L .60939 .71819 L F
.60955 .72045 m .61142 .72093 L .61115 .71865 L F
0 .215 .728 r
.58034 .73833 m .5803 .73705 L .57905 .73537 L F
0 .027 .599 r
.58178 .74061 m .5803 .73705 L .58034 .73833 L F
.642 .644 .837 r
.73209 .71583 m .7276 .71323 L .72999 .7132 L F
.439 .703 .978 r
.73169 .71374 m .73209 .71583 L .72999 .7132 L F
.73169 .71374 m .73325 .7153 L .73209 .71583 L F
.63 .744 .93 r
.32904 .72081 m .33193 .71861 L .33064 .72026 L F
.049 0 .041 r
.33322 .71801 m .33064 .72026 L .33193 .71861 L F
.829 .745 .771 r
.66581 .49467 m .66216 .49656 L .6645 .49333 L F
.66581 .49467 m .6638 .49742 L .66216 .49656 L F
.709 .729 .866 r
.66723 .49071 m .66581 .49467 L .6645 .49333 L F
.66723 .49071 m .66831 .49387 L .66581 .49467 L F
.863 .92 .526 r
.54828 .69654 m .54737 .69757 L .54818 .69606 L F
.878 .441 .077 r
.54818 .69606 m .54789 .69718 L .54802 .69531 L F
.54818 .69606 m .54802 .69531 L .54811 .69398 L F
.863 .92 .526 r
.54842 .69638 m .54828 .69654 L .54818 .69606 L F
.817 .795 .832 r
.71707 .59721 m .71387 .59825 L .71424 .59685 L F
.484 .884 .952 r
.71805 .59646 m .71707 .59721 L .71937 .59652 L F
.963 .712 .508 r
.74263 .71553 m .74264 .71793 L .74391 .71855 L F
0 0 .246 r
.58843 .72585 m .58823 .72848 L .5873 .72959 L F
.082 0 .307 r
.58855 .7309 m .5873 .72959 L .58823 .72848 L F
.58855 .7309 m .58664 .73211 L .5873 .72959 L F
.328 .704 .982 r
.66164 .5166 m .66381 .5167 L .66457 .51748 L F
0 .14 .653 r
.66381 .5167 m .6657 .51869 L .66457 .51748 L F
0 0 0 r
.70297 .58983 m .70304 .58974 L .70366 .58756 L F
0 0 .095 r
.70297 .58983 m .70329 .59328 L .70304 .58974 L F
.345 0 0 r
.46554 .76902 m .46332 .76916 L .46324 .76877 L F
.618 .371 .521 r
.60983 .75187 m .6096 .75438 L .60734 .75377 L F
.393 .182 .47 r
.6117 .75138 m .6096 .75438 L .60983 .75187 L F
.621 .41 .575 r
.49032 .76236 m .48817 .7655 L .48813 .76249 L F
0 0 .037 r
.29833 .63287 m .2998 .63176 L .30067 .63014 L F
.164 0 .272 r
.2998 .63176 m .30188 .62906 L .30067 .63014 L F
0 0 0 r
.29851 .63353 m .29833 .63287 L .2966 .63425 L F
.29851 .63353 m .2998 .63176 L .29833 .63287 L F
.762 .691 .784 r
.34912 .72409 m .35199 .72573 L .35125 .72575 L F
.704 .973 .757 r
.35365 .72346 m .35199 .72573 L .35524 .72467 L F
.35365 .72346 m .35125 .72575 L .35199 .72573 L F
.443 .071 .236 r
.40901 .70455 m .40793 .7068 L .40567 .70705 L F
.288 0 .16 r
.40992 .7061 m .40901 .70455 L .41103 .70416 L F
.40992 .7061 m .40793 .7068 L .40901 .70455 L F
0 0 0 r
.50651 .71577 m .50832 .71512 L .50914 .71425 L F
.366 .184 .497 r
.5062 .71789 m .50832 .71512 L .50651 .71577 L F
.871 .742 .717 r
.5931 .68747 m .59189 .68493 L .59332 .68566 L F
.564 .01 0 r
.55046 .70851 m .55042 .70884 L .54803 .70676 L F
.453 0 0 r
.55046 .70851 m .55314 .70995 L .55042 .70884 L F
.315 .451 .839 r
.48341 .78246 m .48372 .78414 L .48261 .78169 L F
.116 0 0 r
.30236 .65049 m .30193 .64943 L .30399 .64896 L F
.30236 .65049 m .30044 .65126 L .30193 .64943 L F
.274 .712 .964 r
.42876 .6521 m .43085 .65212 L .43226 .65283 L F
.34 .757 .978 r
.43085 .65212 m .4343 .65268 L .43226 .65283 L F
0 0 .302 r
.58489 .70472 m .58594 .70592 L .58705 .70467 L F
.58489 .70472 m .5845 .7072 L .58594 .70592 L F
.768 .324 .197 r
.51277 .79645 m .51486 .79785 L .51248 .79794 L F
.51277 .79645 m .51593 .79837 L .51486 .79785 L F
.75 .325 0 r
.59347 .72944 m .59356 .73019 L .5942 .72844 L F
.59347 .72944 m .59425 .73106 L .59356 .73019 L F
.209 .675 .942 r
.74421 .59114 m .74721 .59181 L .74638 .5913 L F
.223 .53 .921 r
.74721 .59181 m .74899 .59157 L .74638 .5913 L F
.74721 .59181 m .75033 .59322 L .74899 .59157 L F
.307 0 0 r
.33064 .72026 m .32805 .7195 L .32904 .72081 L F
.406 .673 .97 r
.38671 .70004 m .38555 .70118 L .38373 .69911 L F
.38671 .70004 m .38752 .70124 L .38555 .70118 L F
.509 .701 .956 r
.49377 .76253 m .49513 .7611 L .4926 .7616 L F
.49377 .76253 m .49602 .76245 L .49513 .7611 L F
.091 0 0 r
.53624 .79878 m .53782 .79899 L .53566 .79831 L F
.53624 .79878 m .53861 .79869 L .53782 .79899 L F
.947 .898 .745 r
.70931 .60012 m .70725 .60186 L .70674 .59927 L F
.696 .617 .764 r
.71062 .59604 m .71153 .59927 L .70931 .60012 L F
.16 0 0 r
.52145 .73467 m .52176 .73483 L .52409 .7345 L F
.784 .668 .736 r
.33567 .71293 m .33933 .71102 L .33848 .70979 L F
.665 .584 .754 r
.68997 .51666 m .69332 .5164 L .69016 .51594 L F
.502 .21 .402 r
.41885 .68502 m .42109 .68466 L .42162 .68276 L F
.581 .353 .535 r
.42109 .68466 m .42368 .68218 L .42162 .68276 L F
.586 .034 0 r
.47305 .79182 m .47367 .79091 L .47601 .79234 L F
.298 .699 .976 r
.29647 .60391 m .29805 .60483 L .29842 .60395 L F
.19 .578 .94 r
.29805 .60483 m .29977 .60514 L .29842 .60395 L F
.502 .773 .993 r
.34101 .71516 m .34293 .71622 L .34313 .71484 L F
.534 .675 .928 r
.73652 .62263 m .74015 .62422 L .73933 .62281 L F
.569 .736 .954 r
.73933 .62281 m .74015 .62422 L .74233 .62377 L F
.19 .679 .924 r
.3993 .64891 m .40134 .649 L .40274 .64956 L F
.243 .692 .955 r
.40134 .649 m .40475 .64981 L .40274 .64956 L F
.71 .645 .783 r
.67517 .51339 m .6763 .51665 L .67283 .5162 L F
.781 .682 .755 r
.67799 .51266 m .6763 .51665 L .67517 .51339 L F
.448 .295 .579 r
.7125 .59072 m .71271 .59354 L .71535 .59219 L F
.718 .827 .932 r
.4521 .78754 m .45364 .78856 L .45558 .78749 L F
.72 .244 .118 r
.75341 .61871 m .75329 .61998 L .75157 .61953 L F
.576 .201 .294 r
.75584 .61848 m .75329 .61998 L .75341 .61871 L F
.833 .456 .337 r
.56862 .74119 m .56945 .74297 L .57116 .74319 L F
.197 0 0 r
.24982 .5863 m .25151 .58627 L .2534 .58514 L F
.39 .715 .987 r
.73081 .62227 m .73253 .62128 L .72994 .621 L F
.73081 .62227 m .73353 .6223 L .73253 .62128 L F
.633 .595 .793 r
.38057 .69626 m .37881 .69841 L .37836 .69664 L F
.38057 .69626 m .38188 .69937 L .37881 .69841 L F
.805 .562 .571 r
.60939 .71819 m .60955 .71584 L .60627 .71546 L F
.349 .632 .959 r
.3064 .60614 m .30811 .60551 L .30525 .60488 L F
.3064 .60614 m .3096 .60713 L .30811 .60551 L F
.602 .514 .728 r
.75953 .59824 m .75792 .60196 L .75729 .59982 L F
.48 .004 .047 r
.54058 .76443 m .53943 .76532 L .53689 .76526 L F
.473 0 .041 r
.54258 .76477 m .53943 .76532 L .54058 .76443 L F
.251 0 0 r
.53139 .80111 m .53264 .80161 L .53048 .80343 L F
.53264 .80161 m .53139 .80111 L .53063 .80309 L F
.53264 .80161 m .5339 .80016 L .53139 .80111 L F
.53139 .80111 m .5339 .80016 L .53264 .80161 L F
.501 .345 .601 r
.34807 .71583 m .35017 .71534 L .34991 .71294 L F
.519 .406 .664 r
.34807 .71583 m .35029 .71782 L .35017 .71534 L F
.466 .403 .702 r
.34861 .71803 m .35029 .71782 L .34807 .71583 L F
.643 .153 .074 r
.55183 .70176 m .5542 .70326 L .55527 .70209 L F
.659 .173 .086 r
.5542 .70326 m .5576 .70379 L .55527 .70209 L F
.58 .004 0 r
.55527 .70209 m .5576 .70379 L .55868 .70407 L F
.989 .768 .51 r
.5317 .73382 m .53302 .73493 L .53315 .73234 L F
.714 .656 .791 r
.53488 .73151 m .53315 .73234 L .53564 .73035 L F
.133 0 0 r
.53438 .73301 m .53315 .73234 L .53488 .73151 L F
.53434 .73299 m .53209 .7337 L .53315 .73234 L F
.53438 .73301 m .53425 .73305 L .53434 .73299 L F
.53425 .73305 m .53209 .7337 L .53434 .73299 L F
.53209 .7337 m .5317 .73382 L .53198 .73353 L F
.818 .702 .737 r
.5317 .73382 m .53303 .7372 L .53302 .73493 L F
.5317 .73382 m .52972 .73676 L .53303 .7372 L F
.616 .493 .69 r
.52643 .73381 m .52972 .73676 L .52854 .73341 L F
.588 .787 .975 r
.52854 .73341 m .5317 .73382 L .53232 .73304 L F
.753 .606 .696 r
.52854 .73341 m .52972 .73676 L .5317 .73382 L F
.133 0 0 r
.53209 .7337 m .53198 .73353 L .53315 .73234 L F
.592 .793 .976 r
.53232 .73304 m .5317 .73382 L .53438 .73301 L F
.593 .173 .215 r
.53249 .73441 m .52908 .73516 L .53232 .73304 L F
.53254 .73484 m .53184 .7349 L .53249 .73441 L F
.53184 .7349 m .52908 .73516 L .53249 .73441 L F
.53255 .73453 m .53232 .73304 L .53264 .7327 L F
.53254 .73484 m .53249 .73441 L .53255 .73453 L F
.53249 .73441 m .53232 .73304 L .53255 .73453 L F
.751 .61 .702 r
.59508 .71297 m .59326 .7136 L .59142 .71234 L F
.953 .774 .32 r
.59645 .71433 m .5965 .71253 L .59508 .71297 L F
.338 .106 .408 r
.59508 .71297 m .5965 .71253 L .59757 .71013 L F
.527 .263 .458 r
.44387 .6821 m .44152 .68392 L .44165 .68245 L F
.474 .663 .945 r
.42919 .66688 m .42978 .66453 L .42771 .66463 L F
.42919 .66688 m .43101 .66627 L .42978 .66453 L F
.474 .664 .945 r
.42919 .66688 m .43101 .66627 L .42771 .66463 L F
.951 .795 .652 r
.60532 .69581 m .60609 .69895 L .60666 .69658 L F
.113 .663 .809 r
.29077 .60348 m .28713 .60343 L .28866 .60337 L F
.837 .855 .859 r
.6363 .50995 m .63998 .50844 L .63927 .50905 L F
.6363 .50995 m .63927 .50905 L .6384 .5095 L F
.206 .174 .6 r
.6363 .50995 m .63885 .5094 L .63781 .50637 L F
.6363 .50995 m .63781 .50637 L .63623 .50919 L F
.212 0 .081 r
.63786 .51091 m .6363 .50995 L .63623 .50919 L F
.63786 .51091 m .63587 .51162 L .6363 .50995 L F
.101 0 0 r
.63587 .51162 m .6347 .51134 L .6363 .50995 L F
.471 .235 .474 r
.63553 .51147 m .63587 .51162 L .63623 .50919 L F
.444 .276 .558 r
.63623 .50919 m .63587 .51162 L .63786 .51091 L F
.641 .428 .578 r
.63066 .50994 m .63553 .51147 L .63325 .507 L F
.562 .395 .613 r
.63325 .507 m .63623 .50919 L .63531 .50668 L F
.63325 .507 m .63553 .51147 L .63623 .50919 L F
.63325 .507 m .63553 .51147 L .63623 .50919 L F
.574 .443 .664 r
.63531 .50668 m .63623 .50919 L .63781 .50637 L F
.821 .79 .823 r
.63572 .50658 m .6362 .51144 L .63348 .5098 L F
.208 .312 .752 r
.63796 .50835 m .6362 .51144 L .63572 .50658 L F
.751 .988 .771 r
.63796 .50835 m .63555 .51069 L .63573 .5109 L F
.63685 .51031 m .63573 .5109 L .6362 .51144 L F
.63796 .50835 m .63573 .5109 L .63685 .51031 L F
.837 .855 .859 r
.6384 .5095 m .63927 .50905 L .63885 .5094 L F
0 0 .019 r
.63998 .50844 m .64181 .50485 L .64089 .50652 L F
.73 .894 .505 r
.63885 .5094 m .63998 .50844 L .64089 .50652 L F
.727 .333 0 r
.56803 .74034 m .56945 .74297 L .56862 .74119 L F
.774 .386 .32 r
.58248 .68003 m .58122 .68181 L .57908 .67922 L F
.319 0 .172 r
.58443 .67891 m .58122 .68181 L .58248 .68003 L F
.828 .791 .817 r
.62998 .5005 m .6262 .50194 L .62856 .49925 L F
.837 .822 .834 r
.63189 .49783 m .62998 .5005 L .62856 .49925 L F
.562 .867 .996 r
.28144 .68432 m .28098 .68561 L .28294 .68493 L F
.28144 .68432 m .28098 .68561 L .28294 .68493 L F
.337 .76 .975 r
.31236 .59469 m .31457 .59437 L .31597 .59515 L F
.319 .778 .948 r
.31457 .59437 m .31788 .59467 L .31597 .59515 L F
.23 0 .064 r
.48593 .75337 m .48275 .75614 L .48254 .75419 L F
.48593 .75337 m .48441 .75595 L .48275 .75614 L F
.71 .436 .509 r
.48855 .75367 m .48441 .75595 L .48593 .75337 L F
.269 .775 .835 r
.40371 .66396 m .40291 .66443 L .40541 .66424 L F
.40371 .66396 m .40137 .66445 L .40291 .66443 L F
.878 .522 .371 r
.64676 .50218 m .64528 .5031 L .64442 .50277 L F
0 0 .569 r
.64451 .50018 m .64501 .50184 L .64544 .5013 L F
.878 .522 .371 r
.64528 .5031 m .64459 .50354 L .64443 .50282 L F
.64528 .5031 m .64443 .50282 L .64442 .50277 L F
.64676 .50218 m .64558 .5037 L .64459 .50354 L F
.907 .759 .685 r
.64459 .50354 m .64558 .5037 L .64451 .50018 L F
.64459 .50354 m .64451 .50018 L .64218 .50077 L F
.459 .107 .28 r
.64561 .5015 m .6443 .50194 L .64451 .50018 L F
.561 .403 .624 r
.64181 .49849 m .64218 .50077 L .64451 .50018 L F
.913 .705 .206 r
.64451 .50018 m .6443 .50194 L .64414 .49985 L F
.048 .603 .82 r
.64181 .49849 m .64639 .49916 L .64351 .49951 L F
.64319 .49869 m .64431 .49862 L .64634 .49915 L F
.64319 .49869 m .64634 .49915 L .64636 .49916 L F
.032 .124 .629 r
.64431 .49862 m .64451 .50018 L .64514 .49857 L F
.82 .991 .737 r
.64451 .50018 m .64414 .49985 L .64509 .49855 L F
.679 .955 .95 r
.64639 .49916 m .64431 .49862 L .6476 .49725 L F
.032 .124 .629 r
.64431 .49862 m .64514 .49857 L .64522 .49838 L F
.82 .991 .737 r
.64514 .49857 m .64509 .49855 L .64522 .49838 L F
.64451 .50018 m .64509 .49855 L .64514 .49857 L F
.048 .603 .82 r
.64636 .49916 m .64634 .49915 L .64639 .49916 L F
.64181 .49849 m .64431 .49862 L .64319 .49869 L F
.561 .403 .624 r
.64181 .49849 m .64451 .50018 L .64431 .49862 L F
.671 .551 .71 r
.64118 .50199 m .6443 .50194 L .64414 .49985 L F
.794 .694 .754 r
.64124 .50426 m .6443 .50194 L .64118 .50199 L F
0 0 .392 r
.64118 .50199 m .64245 .50262 L .6443 .50194 L F
.671 .551 .71 r
.64118 .50199 m .6443 .50194 L .64414 .49985 L F
.366 .317 .671 r
.64414 .49985 m .6443 .50194 L .64579 .50089 L F
.229 0 0 r
.64245 .50262 m .64575 .50091 L .6443 .50194 L F
.64575 .50091 m .64579 .50089 L .64573 .50093 L F
.64575 .50091 m .64573 .50093 L .6443 .50194 L F
0 0 .569 r
.64544 .5013 m .64541 .50314 L .64561 .5015 L F
.64501 .50184 m .64541 .50314 L .64544 .5013 L F
.64541 .50314 m .64558 .5037 L .64559 .5032 L F
.64541 .50314 m .64559 .5032 L .64561 .5015 L F
.724 .889 .498 r
.50438 .77039 m .50424 .77009 L .50557 .7682 L F
.228 0 0 r
.50502 .77172 m .50424 .77009 L .50438 .77039 L F
.458 .175 .395 r
.34956 .66458 m .34795 .66293 L .34795 .66537 L F
.34956 .66458 m .34999 .66241 L .34795 .66293 L F
.139 .655 .892 r
.29776 .59265 m .29963 .59275 L .30115 .59324 L F
.234 .73 .913 r
.29963 .59275 m .30323 .59299 L .30115 .59324 L F
.436 .137 .358 r
.66266 .53999 m .66091 .53888 L .66344 .53855 L F
.66266 .53999 m .6606 .54045 L .66091 .53888 L F
.537 .921 .918 r
.26744 .65639 m .27148 .65534 L .26944 .65556 L F
.392 .851 .862 r
.26944 .65556 m .27148 .65534 L .27348 .65466 L F
.547 .414 .651 r
.72203 .713 m .72462 .71469 L .7244 .71232 L F
.737 .418 .441 r
.51001 .72041 m .50686 .72234 L .50755 .72048 L F
.543 .415 .656 r
.66729 .53021 m .66808 .53251 L .66531 .53285 L F
.418 .252 .548 r
.66808 .53251 m .6655 .53537 L .66531 .53285 L F
.764 .781 .867 r
.57047 .68133 m .57313 .68157 L .57663 .67998 L F
.491 .744 .984 r
.57518 .67891 m .57663 .67998 L .57763 .67863 L F
.425 .215 .489 r
.5479 .73481 m .54732 .73751 L .54606 .73634 L F
.662 .842 .969 r
.26386 .64268 m .26331 .64455 L .26178 .64353 L F
.26386 .64268 m .26544 .64365 L .26331 .64455 L F
.564 .38 .59 r
.71232 .59556 m .7105 .59401 L .71271 .59354 L F
.71232 .59556 m .71062 .59604 L .7105 .59401 L F
0 .087 .642 r
.59153 .70543 m .59044 .70489 L .58945 .70455 L F
.59153 .70543 m .5921 .70681 L .59044 .70489 L F
.51 .219 .408 r
.45196 .67713 m .45156 .679 L .44925 .67935 L F
.558 .306 .49 r
.45409 .67666 m .45156 .679 L .45196 .67713 L F
.783 .314 0 r
.55515 .72844 m .55612 .72921 L .554 .72674 L F
.637 .088 0 r
.55692 .73047 m .55612 .72921 L .55515 .72844 L F
.55692 .73047 m .55816 .73112 L .55612 .72921 L F
.519 .459 .729 r
.34369 .6824 m .34425 .68536 L .34619 .68493 L F
.529 .407 .657 r
.34425 .68536 m .34657 .68732 L .34619 .68493 L F
.34425 .68536 m .34453 .68794 L .34657 .68732 L F
.483 .128 .288 r
.41872 .69839 m .41791 .70085 L .41564 .7011 L F
.447 .171 .4 r
.42149 .6963 m .42147 .69809 L .41872 .69839 L F
.457 .126 .316 r
.42147 .69809 m .41791 .70085 L .41872 .69839 L F
.696 .977 .79 r
.73507 .61577 m .73199 .61785 L .73481 .61565 L F
.62 .943 .742 r
.73507 .61577 m .73658 .61417 L .73797 .61413 L F
.73507 .61577 m .73481 .61565 L .73658 .61417 L F
.494 .188 .376 r
.43866 .68539 m .43598 .68745 L .43652 .68586 L F
.477 .164 .357 r
.52482 .74892 m .52214 .75117 L .52212 .74938 L F
.414 .225 .514 r
.37486 .67923 m .37314 .68259 L .37221 .6828 L F
.468 .333 .614 r
.37314 .68259 m .37247 .68505 L .37221 .6828 L F
.904 .985 .748 r
.49934 .72798 m .49804 .72979 L .50008 .7267 L F
.936 .781 .663 r
.6638 .49742 m .66182 .49915 L .66216 .49656 L F
.6638 .49742 m .66343 .50024 L .66182 .49915 L F
0 .262 .727 r
.54803 .70676 m .54444 .70409 L .54657 .70538 L F
.46 .325 .61 r
.34572 .66585 m .34761 .66745 L .34795 .66537 L F
.34572 .66585 m .34578 .66885 L .34761 .66745 L F
.711 .839 .943 r
.33848 .70979 m .33686 .71054 L .33439 .70991 L F
.113 .659 .829 r
.42545 .66383 m .42458 .66358 L .42214 .66362 L F
0 .418 .805 r
.42545 .66383 m .42636 .66374 L .42458 .66358 L F
.42545 .66383 m .42771 .66463 L .42636 .66374 L F
.388 .019 .212 r
.46938 .74544 m .47173 .74499 L .47218 .74363 L F
.545 .164 .269 r
.47173 .74499 m .47404 .74504 L .47218 .74363 L F
.528 .174 .31 r
.47218 .74363 m .47404 .74504 L .47448 .74357 L F
.287 0 .278 r
.53593 .7672 m .53483 .76601 L .53689 .76526 L F
.781 .439 .408 r
.50215 .75617 m .50094 .75622 L .50051 .75407 L F
.802 .485 .452 r
.57246 .76448 m .57088 .76722 L .56938 .7661 L F
.198 0 .336 r
.57375 .76259 m .57322 .76483 L .57246 .76448 L F
.532 .218 .38 r
.57322 .76483 m .57088 .76722 L .57246 .76448 L F
.813 .511 .478 r
.59585 .67403 m .59765 .67673 L .59961 .67697 L F
.818 .536 .512 r
.59765 .67673 m .59782 .67898 L .59961 .67697 L F
.865 .613 .555 r
.59782 .67898 m .59968 .67933 L .59961 .67697 L F
.797 .496 .481 r
.7266 .59063 m .72372 .58848 L .72423 .58901 L F
.572 .4 .61 r
.52719 .74822 m .52467 .74613 L .52669 .74574 L F
.52719 .74822 m .52482 .74892 L .52467 .74613 L F
.399 .154 .422 r
.25918 .61564 m .25726 .61702 L .25811 .61611 L F
.25918 .61564 m .25681 .61844 L .25726 .61702 L F
.801 .611 .645 r
.52182 .7987 m .52285 .80113 L .52131 .80126 L F
.51 .509 .792 r
.31065 .61046 m .31143 .60673 L .30981 .60826 L F
.31065 .61046 m .31247 .61001 L .31143 .60673 L F
.331 0 .122 r
.2698 .60824 m .2684 .61022 L .26642 .61058 L F
.403 .005 .167 r
.27101 .60911 m .2698 .60824 L .27171 .6076 L F
.27101 .60911 m .2684 .61022 L .2698 .60824 L F
.651 .429 .569 r
.52968 .74331 m .52669 .74574 L .52629 .74305 L F
.711 .371 .4 r
.59238 .6739 m .5946 .6761 L .59585 .67403 L F
.82 .51 .466 r
.5946 .6761 m .59765 .67673 L .59585 .67403 L F
.104 0 .233 r
.50201 .73264 m .50329 .73199 L .50147 .7342 L F
.687 .897 .973 r
.50711 .77249 m .5085 .77083 L .50502 .77172 L F
.50711 .77249 m .50982 .77155 L .5085 .77083 L F
.435 .795 .996 r
.28447 .65348 m .28154 .6532 L .28271 .65386 L F
.471 .609 .906 r
.44226 .65322 m .44132 .65507 L .4404 .65329 L F
.52 .669 .93 r
.44226 .65322 m .44355 .65489 L .44132 .65507 L F
.418 .049 .228 r
.36522 .65424 m .36737 .65388 L .36854 .65164 L F
.485 .154 .33 r
.36737 .65388 m .37059 .65109 L .36854 .65164 L F
.832 .578 .555 r
.61117 .547 m .60919 .54845 L .60758 .54677 L F
.61117 .547 m .6112 .54922 L .60919 .54845 L F
.52 .701 .952 r
.33415 .59936 m .33095 .59832 L .33309 .59796 L F
.333 .595 .942 r
.33476 .59804 m .33415 .59936 L .33309 .59796 L F
.337 .6 .944 r
.33611 .59965 m .33415 .59936 L .33476 .59804 L F
.229 0 0 r
.41633 .65015 m .41964 .65117 L .41763 .65117 L F
.708 .792 .917 r
.51448 .76451 m .51121 .76433 L .51297 .76475 L F
0 .567 .783 r
.51499 .76443 m .51448 .76451 L .51297 .76475 L F
.51499 .76443 m .51679 .76474 L .51448 .76451 L F
.548 .38 .606 r
.46775 .76276 m .46808 .76549 L .4665 .76518 L F
.42 .807 .989 r
.46802 .76818 m .46872 .76885 L .47111 .76829 L F
.563 .349 .548 r
.56071 .76549 m .56072 .76795 L .55818 .768 L F
.723 .336 .317 r
.49212 .7954 m .49564 .79562 L .49429 .7974 L F
.714 .307 .273 r
.49564 .79562 m .49687 .79829 L .49429 .7974 L F
.49564 .79562 m .49769 .79649 L .49687 .79829 L F
.746 .364 .33 r
.5015 .79818 m .50455 .79851 L .50327 .80041 L F
.629 .196 .202 r
.50455 .79851 m .50709 .80038 L .50327 .80041 L F
.50455 .79851 m .50687 .79913 L .50709 .80038 L F
.597 .324 .474 r
.45726 .67416 m .45642 .67652 L .45409 .67666 L F
.605 .435 .626 r
.45942 .67155 m .4596 .67397 L .45726 .67416 L F
.571 .299 .464 r
.4593 .67579 m .45726 .67416 L .4596 .67397 L F
.4593 .67579 m .45642 .67652 L .45726 .67416 L F
.432 .102 .304 r
.40337 .69604 m .40551 .69563 L .40641 .69322 L F
.399 .071 .29 r
.40641 .69322 m .40759 .69512 L .40846 .69264 L F
.40641 .69322 m .40551 .69563 L .40759 .69512 L F
.34 0 0 r
.39592 .71077 m .39425 .71219 L .39206 .71234 L F
.094 0 0 r
.39638 .71154 m .39592 .71077 L .39795 .71004 L F
.39638 .71154 m .39425 .71219 L .39592 .71077 L F
.473 .785 .998 r
.29254 .59041 m .29203 .59164 L .29053 .59075 L F
.29254 .59041 m .29402 .59134 L .29203 .59164 L F
.242 .711 .944 r
.66651 .50196 m .66388 .50131 L .66343 .50024 L F
.66651 .50196 m .66602 .5014 L .66388 .50131 L F
.898 .739 .675 r
.66651 .50196 m .66369 .50423 L .66602 .5014 L F
.66651 .50196 m .6653 .50503 L .66369 .50423 L F
.959 .726 .542 r
.36778 .72687 m .3674 .7291 L .36608 .72596 L F
.411 .191 .467 r
.36962 .7263 m .3674 .7291 L .36778 .72687 L F
.824 .746 .778 r
.57105 .77385 m .56896 .7736 L .57042 .77133 L F
.423 0 0 r
.57105 .77385 m .57023 .77404 L .56896 .7736 L F
0 0 .26 r
.57231 .77 m .57222 .77301 L .57105 .77385 L F
.447 .874 .773 r
.57105 .77385 m .57222 .77301 L .57023 .77404 L F
.007 0 0 r
.50914 .71425 m .51012 .71434 L .51154 .71329 L F
.50914 .71425 m .50832 .71512 L .51012 .71434 L F
.8 .694 .748 r
.50517 .76259 m .50171 .7624 L .50391 .75959 L F
0 0 0 r
.50517 .76259 m .50415 .76407 L .50171 .7624 L F
.554 .514 .765 r
.50675 .75979 m .50517 .76259 L .50391 .75959 L F
.50675 .75979 m .50734 .76233 L .50517 .76259 L F
.503 .557 .844 r
.3096 .60713 m .30981 .60826 L .31143 .60673 L F
.098 0 0 r
.59142 .71234 m .58829 .7123 L .58952 .71324 L F
.316 .79 .921 r
.27685 .65456 m .27562 .65432 L .27348 .65466 L F
.66 .946 .958 r
.27745 .65328 m .27685 .65456 L .27889 .65385 L F
.27745 .65328 m .27562 .65432 L .27685 .65456 L F
.17 .37 .818 r
.44913 .78213 m .44995 .78085 L .44704 .77918 L F
.44913 .78213 m .44988 .78176 L .44995 .78085 L F
0 .072 .618 r
.44913 .78213 m .45055 .78399 L .44988 .78176 L F
.481 .419 .711 r
.34778 .70203 m .34911 .69847 L .34705 .69892 L F
.34778 .70203 m .3497 .70163 L .34911 .69847 L F
.478 .406 .697 r
.34778 .70203 m .35048 .70398 L .3497 .70163 L F
.522 .4 .655 r
.34778 .70203 m .34891 .70525 L .35048 .70398 L F
.014 0 0 r
.37284 .6508 m .3751 .65033 L .37672 .64954 L F
.443 0 .005 r
.3751 .65033 m .37881 .64907 L .37672 .64954 L F
0 .19 .721 r
.56196 .73388 m .56293 .73457 L .56248 .73539 L F
.061 .418 .865 r
.56293 .73457 m .56504 .73669 L .56248 .73539 L F
.271 .068 .41 r
.3092 .61871 m .30724 .62165 L .30879 .62097 L F
.324 .176 .52 r
.30724 .62165 m .30863 .62336 L .30879 .62097 L F
.294 .169 .534 r
.30724 .62165 m .30725 .62403 L .30863 .62336 L F
.814 .602 .615 r
.67283 .5162 m .66955 .51346 L .67283 .51379 L F
.67283 .5162 m .66943 .51591 L .66955 .51346 L F
.867 .421 .059 r
.67145 .5184 m .66943 .51591 L .67283 .5162 L F
.71 .645 .783 r
.67517 .51339 m .67283 .5162 L .67283 .51379 L F
.702 .725 .868 r
.67008 .49145 m .66831 .49387 L .66723 .49071 L F
.616 .599 .811 r
.67008 .49145 m .67088 .49336 L .66831 .49387 L F
.609 .577 .793 r
.67144 .49482 m .66831 .49387 L .67088 .49336 L F
.422 0 0 r
.63365 .52402 m .63127 .52477 L .63352 .52406 L F
0 0 0 r
.63577 .5233 m .63688 .52289 L .63365 .52402 L F
.226 .732 .671 r
.63577 .5233 m .63365 .52402 L .63352 .52406 L F
.663 .133 0 r
.52285 .80113 m .52391 .80299 L .52131 .80126 L F
.52285 .80113 m .52519 .80216 L .52391 .80299 L F
.395 .197 .49 r
.5374 .72931 m .53488 .73151 L .53564 .73035 L F
.867 .744 .726 r
.54114 .79384 m .54226 .79259 L .53949 .79257 L F
.54114 .79384 m .54226 .79259 L .53949 .79257 L F
.48 .737 .984 r
.55882 .78446 m .55988 .78295 L .5592 .78363 L F
.55882 .78446 m .56132 .78421 L .55988 .78295 L F
.241 0 0 r
.55882 .78446 m .56132 .78421 L .55943 .78555 L F
.55882 .78446 m .55943 .78555 L .5592 .78363 L F
.67 .601 .769 r
.46194 .6713 m .45942 .67155 L .45838 .66881 L F
.589 .423 .625 r
.46184 .6736 m .45942 .67155 L .46194 .6713 L F
.46184 .6736 m .4596 .67397 L .45942 .67155 L F
.642 .591 .782 r
.71232 .59556 m .71153 .59927 L .71062 .59604 L F
.71232 .59556 m .71387 .59825 L .71153 .59927 L F
.469 .328 .606 r
.48935 .77085 m .48758 .77412 L .48684 .77183 L F
.48935 .77085 m .48957 .77369 L .48758 .77412 L F
.399 .132 .389 r
.48957 .77369 m .48709 .77607 L .48758 .77412 L F
.583 .32 .483 r
.34861 .71803 m .35016 .71914 L .35029 .71782 L F
.34861 .71803 m .34793 .72061 L .35016 .71914 L F
.611 .644 .858 r
.55151 .75398 m .5497 .75483 L .54852 .75178 L F
.581 .371 .561 r
.54921 .7567 m .55151 .75398 L .5497 .75483 L F
.54921 .7567 m .55151 .75398 L .5497 .75483 L F
.519 .459 .729 r
.34369 .6824 m .34619 .68493 L .34554 .68181 L F
.297 0 0 r
.32398 .71746 m .32608 .71716 L .32767 .71549 L F
.589 .377 .561 r
.37688 .67677 m .37689 .67891 L .37486 .67923 L F
.398 .227 .53 r
.37809 .67788 m .37688 .67677 L .37881 .67628 L F
.37809 .67788 m .37689 .67891 L .37688 .67677 L F
.659 .603 .78 r
.37836 .69664 m .37488 .6946 L .37757 .69493 L F
.584 .711 .93 r
.37938 .69475 m .37836 .69664 L .37757 .69493 L F
.37938 .69475 m .38057 .69626 L .37836 .69664 L F
.491 .205 .406 r
.42323 .69719 m .42149 .6963 L .42365 .69591 L F
.42323 .69719 m .42147 .69809 L .42149 .6963 L F
.703 .3 .282 r
.67833 .51265 m .68126 .5117 L .67799 .51266 L F
.67833 .51265 m .68016 .51287 L .68126 .5117 L F
.328 0 .008 r
.68126 .5117 m .68232 .51232 L .68281 .51048 L F
.68126 .5117 m .68016 .51287 L .68232 .51232 L F
.471 .666 .948 r
.25958 .58454 m .25904 .58635 L .25754 .5843 L F
.25958 .58454 m .26107 .58627 L .25904 .58635 L F
.884 .547 .407 r
.58475 .72117 m .58521 .72318 L .58705 .72351 L F
.772 .359 .268 r
.58719 .72546 m .58705 .72351 L .58521 .72318 L F
.699 .568 .704 r
.56888 .76187 m .56694 .7654 L .56568 .76276 L F
.359 .139 .437 r
.44639 .75707 m .44814 .75677 L .44854 .7544 L F
.546 .395 .627 r
.44639 .75707 m .4487 .75931 L .44814 .75677 L F
.44639 .75707 m .44649 .75977 L .4487 .75931 L F
.91 .66 .547 r
.60009 .6839 m .60242 .68244 L .60045 .68145 L F
.60009 .6839 m .60248 .68499 L .60242 .68244 L F
.794 .563 .587 r
.60242 .68244 m .60248 .68499 L .60456 .68522 L F
.657 .24 .241 r
.62661 .50577 m .62453 .50731 L .62482 .50467 L F
.62661 .50577 m .62901 .50814 L .62453 .50731 L F
.493 .293 .537 r
.32602 .62749 m .32807 .62444 L .3274 .62649 L F
.313 .144 .485 r
.32807 .62444 m .32985 .62135 L .33011 .62373 L F
.386 .103 .356 r
.3274 .62649 m .32807 .62444 L .33011 .62373 L F
.518 .277 .488 r
.46437 .74885 m .46657 .7485 L .46685 .74613 L F
.523 .254 .448 r
.46657 .7485 m .46938 .74544 L .46685 .74613 L F
.351 .755 .983 r
.31788 .59467 m .32014 .59446 L .32148 .59526 L F
.383 .777 .987 r
.32216 .59425 m .32148 .59526 L .32014 .59446 L F
.32216 .59425 m .32425 .59516 L .32148 .59526 L F
0 0 0 r
.39028 .70101 m .39159 .70045 L .39342 .69949 L F
.555 .913 .719 r
.39342 .69949 m .3933 .69905 L .39536 .69872 L F
.39342 .69949 m .39159 .70045 L .3933 .69905 L F
.566 .226 .351 r
.72035 .59106 m .72296 .59223 L .72423 .58901 L F
.731 .4 .421 r
.72296 .59223 m .72648 .59293 L .72423 .58901 L F
.811 .416 .306 r
.72423 .58901 m .72648 .59293 L .7266 .59063 L F
.407 .151 .41 r
.48013 .74076 m .48182 .742 L .48233 .74056 L F
.48013 .74076 m .47976 .74274 L .48182 .742 L F
.515 .07 .13 r
.73186 .59012 m .73429 .59017 L .73511 .58876 L F
.506 .09 .185 r
.73429 .59017 m .73741 .58864 L .73511 .58876 L F
.809 .568 .575 r
.67771 .52483 m .67417 .52654 L .67412 .52407 L F
.67771 .52483 m .6781 .52761 L .67417 .52654 L F
.766 .539 .589 r
.67862 .52675 m .6781 .52761 L .67771 .52483 L F
.722 .269 .177 r
.526 .71506 m .52835 .71711 L .52937 .71576 L F
.789 .356 .223 r
.52835 .71711 m .53154 .71813 L .52937 .71576 L F
.765 .382 .328 r
.52937 .71576 m .53154 .71813 L .53331 .71763 L F
.529 .523 .793 r
.34647 .72242 m .34793 .72061 L .34635 .72199 L F
.34647 .72242 m .34912 .72409 L .34793 .72061 L F
.297 .362 .761 r
.52439 .72937 m .52675 .7316 L .52525 .72803 L F
.03 .566 .851 r
.27242 .58666 m .27588 .58755 L .27388 .58783 L F
.176 .712 .801 r
.27388 .58783 m .27588 .58755 L .27648 .58756 L F
.554 .551 .805 r
.37558 .69066 m .37488 .6946 L .37363 .69108 L F
.37558 .69066 m .37659 .69437 L .37488 .6946 L F
.549 .639 .892 r
.37659 .69437 m .37757 .69493 L .37488 .6946 L F
.703 .3 .282 r
.67833 .51265 m .67799 .51266 L .67795 .51071 L F
.723 .353 .349 r
.58888 .67153 m .58747 .67318 L .5894 .67309 L F
.577 .239 .361 r
.72648 .59293 m .72946 .59029 L .7266 .59063 L F
.679 .504 .642 r
.56072 .76795 m .55841 .77042 L .55818 .768 L F
.303 .736 .969 r
.74911 .58311 m .74829 .58405 L .74711 .58404 L F
.74911 .58311 m .75141 .58417 L .74829 .58405 L F
.544 .411 .65 r
.34453 .67397 m .34666 .67351 L .34641 .67109 L F
.479 .365 .646 r
.34453 .67397 m .34682 .67614 L .34666 .67351 L F
.34453 .67397 m .34465 .67733 L .34682 .67614 L F
.233 .717 .93 r
.4343 .65268 m .43662 .65259 L .43786 .6531 L F
.264 .692 .965 r
.43883 .65243 m .43786 .6531 L .43662 .65259 L F
.43883 .65243 m .4404 .65329 L .43786 .6531 L F
.649 .16 .077 r
.52913 .76658 m .53107 .76767 L .52784 .76713 L F
.742 .804 .902 r
.29977 .60514 m .30352 .60507 L .30219 .60502 L F
.384 .841 .902 r
.30404 .60448 m .30352 .60507 L .30525 .60488 L F
.30404 .60448 m .30219 .60502 L .30352 .60507 L F
.553 .011 0 r
.53154 .71813 m .53496 .71864 L .53331 .71763 L F
.599 .707 .92 r
.53464 .75482 m .53256 .75555 L .53297 .75222 L F
.467 .684 .96 r
.54802 .7923 m .54907 .79325 L .54635 .79313 L F
.54802 .7923 m .54907 .79325 L .54635 .79313 L F
.549 .458 .704 r
.75075 .60691 m .75214 .60856 L .75352 .60761 L F
.75075 .60691 m .75154 .61067 L .75214 .60856 L F
.733 .336 .298 r
.48848 .79341 m .49212 .7954 L .48886 .79498 L F
.17 0 .013 r
.56694 .7654 m .56537 .76756 L .56343 .76818 L F
0 0 0 r
.56714 .76612 m .56694 .7654 L .56938 .7661 L F
.56714 .76612 m .56537 .76756 L .56694 .7654 L F
.211 .683 .939 r
.62958 .52382 m .63127 .52477 L .62871 .52463 L F
.686 .29 0 r
.71217 .6055 m .71218 .60574 L .71117 .60472 L F
.71217 .6055 m .71292 .60699 L .71218 .60574 L F
.622 .896 .987 r
.51375 .77176 m .51594 .77159 L .51772 .77067 L F
.581 .207 .298 r
.51916 .72436 m .51612 .72569 L .51725 .72471 L F
.851 .672 .66 r
.55081 .74948 m .5468 .74803 L .54828 .74846 L F
.55081 .74948 m .54852 .75178 L .5468 .74803 L F
.611 .644 .858 r
.55151 .75398 m .55081 .74948 L .5526 .75175 L F
.55151 .75398 m .54852 .75178 L .55081 .74948 L F
.651 .429 .569 r
.52968 .74331 m .5297 .74563 L .52669 .74574 L F
.552 .439 .679 r
.53159 .73918 m .53201 .74296 L .52968 .74331 L F
.627 .469 .648 r
.53201 .74296 m .5297 .74563 L .52968 .74331 L F
.511 .268 .482 r
.4852 .7376 m .48665 .7394 L .48734 .73716 L F
.4852 .7376 m .48493 .73974 L .48665 .7394 L F
.981 .754 .52 r
.51486 .79785 m .51593 .79837 L .51469 .80063 L F
.593 .103 .06 r
.51558 .79901 m .51755 .80026 L .51469 .80063 L F
.577 .355 .542 r
.51469 .80063 m .51755 .80026 L .51687 .80296 L F
.737 .65 .763 r
.51888 .80106 m .51687 .80296 L .51755 .80026 L F
.422 0 0 r
.51852 .80087 m .51755 .80026 L .5158 .79941 L F
.51888 .80106 m .51755 .80026 L .51852 .80087 L F
.593 .103 .06 r
.51593 .79837 m .51755 .80026 L .51558 .79901 L F
.348 .781 .968 r
.40475 .64981 m .40724 .64955 L .40852 .65007 L F
.144 0 0 r
.40724 .64955 m .41059 .6499 L .40852 .65007 L F
.101 0 0 r
.38721 .71476 m .38645 .71529 L .38503 .71525 L F
.121 0 0 r
.38645 .71529 m .38459 .71584 L .38503 .71525 L F
.567 .276 .433 r
.50885 .80074 m .50687 .79913 L .51006 .79726 L F
.576 .343 .526 r
.51006 .79726 m .51242 .80016 L .50885 .80074 L F
.51006 .79726 m .51248 .79794 L .51242 .80016 L F
.74 .274 .143 r
.66343 .50024 m .66286 .50102 L .66182 .49915 L F
.66343 .50024 m .66388 .50131 L .66286 .50102 L F
0 0 .051 r
.57412 .75951 m .57394 .76198 L .57375 .76259 L F
.075 0 .279 r
.57401 .76457 m .57375 .76259 L .57394 .76198 L F
.57401 .76457 m .57322 .76483 L .57375 .76259 L F
.837 .368 .02 r
.65753 .51885 m .65836 .52047 L .65756 .51831 L F
.127 0 .397 r
.65756 .51831 m .65836 .52047 L .65901 .51827 L F
.246 0 .104 r
.73337 .59635 m .73622 .59375 L .73556 .59565 L F
.417 .068 .264 r
.73622 .59375 m .73786 .59537 L .73556 .59565 L F
.73622 .59375 m .73861 .59324 L .73786 .59537 L F
.925 .633 .155 r
.67395 .52225 m .67343 .52281 L .67255 .52122 L F
.67395 .52225 m .67412 .52407 L .67343 .52281 L F
.705 .454 .542 r
.53302 .73493 m .53631 .73673 L .53626 .73517 L F
.578 .292 .446 r
.53631 .73673 m .53868 .73679 L .53626 .73517 L F
.219 0 .277 r
.52214 .75117 m .51974 .75396 L .52046 .75201 L F
.14 0 0 r
.27955 .60515 m .27617 .6071 L .27765 .60549 L F
.372 .102 .369 r
.31163 .61609 m .3092 .61871 L .3111 .61805 L F
.431 .155 .392 r
.3111 .61805 m .31316 .61734 L .31163 .61609 L F
.603 .506 .718 r
.31163 .61609 m .31406 .61597 L .31332 .61321 L F
.506 .133 .266 r
.31163 .61609 m .31316 .61734 L .31406 .61597 L F
.234 .74 .89 r
.27869 .64145 m .2809 .64126 L .28271 .64152 L F
.545 .901 .972 r
.28271 .64152 m .28214 .64041 L .28468 .64073 L F
.28271 .64152 m .2809 .64126 L .28214 .64041 L F
.53 .679 .933 r
.33309 .59796 m .33095 .59832 L .32905 .59612 L F
.686 .162 0 r
.52391 .80299 m .52519 .80216 L .52733 .80402 L F
.751 .616 .709 r
.67208 .5104 m .67283 .51379 L .66955 .51346 L F
.225 0 0 r
.51323 .712 m .51576 .71134 L .51714 .70973 L F
.756 .381 .344 r
.51576 .71134 m .51898 .7105 L .51714 .70973 L F
.423 .811 .988 r
.50982 .77155 m .51042 .77067 L .5085 .77083 L F
.50982 .77155 m .51155 .77129 L .5109 .77093 L F
.50982 .77155 m .5109 .77093 L .51024 .77093 L F
.617 .204 .237 r
.51248 .77225 m .50726 .77242 L .50843 .77092 L F
.50875 .77092 m .50843 .77092 L .5085 .77083 L F
.51248 .77225 m .50843 .77092 L .50875 .77092 L F
.423 .811 .988 r
.51024 .77093 m .5109 .77093 L .51042 .77067 L F
.418 .252 .548 r
.66808 .53251 m .66802 .53482 L .6655 .53537 L F
.373 .128 .408 r
.66802 .53482 m .66549 .53773 L .6655 .53537 L F
.678 .821 .952 r
.73353 .6223 m .73652 .62263 L .73535 .62195 L F
.312 .704 .979 r
.73652 .62263 m .73813 .62195 L .73535 .62195 L F
.73652 .62263 m .73933 .62281 L .73813 .62195 L F
.309 0 .007 r
.49457 .73173 m .49672 .73136 L .49804 .72979 L F
.004 0 .157 r
.50008 .7267 m .49804 .72979 L .49955 .72823 L F
.451 .143 .35 r
.49672 .73136 m .49955 .72823 L .49804 .72979 L F
.25 0 .258 r
.50261 .72411 m .50008 .7267 L .50171 .72601 L F
0 0 0 r
.49955 .72823 m .50171 .72601 L .50008 .7267 L F
.451 0 0 r
.27588 .58755 m .27939 .58853 L .27648 .58756 L F
0 0 0 r
.50509 .72167 m .50261 .72411 L .50407 .72282 L F
.50171 .72601 m .50407 .72282 L .50261 .72411 L F
.534 .236 .408 r
.4465 .68009 m .44613 .68189 L .44387 .6821 L F
.5 .177 .35 r
.44925 .67935 m .44613 .68189 L .4465 .68009 L F
.07 .626 .81 r
.41964 .65117 m .42178 .65123 L .42321 .65146 L F
.018 .586 .781 r
.42321 .65146 m .42178 .65123 L .42527 .65159 L F
.706 .946 .957 r
.65471 .51092 m .65111 .51189 L .65379 .51 L F
.65471 .51092 m .65208 .51184 L .65111 .51189 L F
.999 .797 .494 r
.6542 .50779 m .65471 .51092 L .65379 .51 L F
.365 0 .002 r
.32974 .71504 m .33188 .71486 L .33333 .71368 L F
.659 .555 .726 r
.33213 .71008 m .33333 .71368 L .33567 .71293 L F
.321 .061 .355 r
.32055 .63474 m .32116 .63279 L .32291 .63206 L F
0 0 .399 r
.73426 .7173 m .73464 .71834 L .73325 .7153 L F
.795 .771 .831 r
.73133 .71775 m .73464 .71834 L .73426 .7173 L F
.731 .462 .521 r
.51509 .7955 m .5147 .79309 L .51117 .79307 L F
.478 .302 .563 r
.46332 .76916 m .46112 .77343 L .4616 .77311 L F
.52 .57 .846 r
.383 .69737 m .38188 .69937 L .38057 .69626 L F
.383 .69737 m .38373 .69911 L .38188 .69937 L F
.399 .391 .734 r
.75259 .60171 m .75372 .59832 L .7518 .59882 L F
.75259 .60171 m .75429 .60258 L .75372 .59832 L F
.57 .272 .423 r
.72842 .59574 m .72831 .59628 L .72511 .59477 L F
.645 .907 .594 r
.72648 .59293 m .72511 .59477 L .72831 .59628 L F
.363 .747 .988 r
.30323 .59299 m .30528 .5929 L .30678 .59372 L F
.33 .717 .982 r
.30725 .59282 m .30678 .59372 L .30528 .5929 L F
.30725 .59282 m .30872 .5937 L .30678 .59372 L F
.461 .597 .902 r
.34991 .71294 m .34974 .70955 L .34898 .71003 L F
.34991 .71294 m .35174 .71226 L .34974 .70955 L F
.653 .594 .777 r
.35017 .71534 m .35174 .71226 L .34991 .71294 L F
.76 .529 .582 r
.50911 .75646 m .50623 .75688 L .50617 .75436 L F
.427 0 .059 r
.39747 .69822 m .39965 .6982 L .40127 .69651 L F
.444 .029 .156 r
.39965 .6982 m .40337 .69604 L .40127 .69651 L F
.181 .492 .903 r
.65867 .50856 m .65707 .50805 L .65646 .50673 L F
.611 .532 .741 r
.34384 .68998 m .34657 .68732 L .34453 .68794 L F
.34384 .68998 m .34728 .69052 L .34657 .68732 L F
.626 .467 .647 r
.34501 .69099 m .34728 .69052 L .34384 .68998 L F
.098 .638 .85 r
.5576 .70379 m .56098 .70421 L .55868 .70407 L F
.348 0 0 r
.46445 .7894 m .46802 .7899 L .46698 .78958 L F
.298 0 0 r
.46698 .78958 m .46887 .79042 L .46567 .78917 L F
.19 .687 .917 r
.46445 .7894 m .46698 .78958 L .46556 .78912 L F
.298 0 0 r
.46698 .78958 m .46567 .78917 L .46556 .78912 L F
.348 0 0 r
.46802 .7899 m .46916 .79007 L .46698 .78958 L F
.647 .098 0 r
.46916 .79007 m .47006 .79066 L .46698 .78958 L F
.836 .694 .706 r
.60429 .70384 m .60723 .7046 L .60579 .70103 L F
.87 .616 .551 r
.60556 .70531 m .60723 .7046 L .60429 .70384 L F
.60556 .70531 m .60719 .7067 L .60723 .7046 L F
.929 .548 .233 r
.56539 .71793 m .56407 .71729 L .56343 .71527 L F
.686 .143 0 r
.56727 .71967 m .56407 .71729 L .56539 .71793 L F
.768 .775 .858 r
.35524 .72467 m .35879 .72476 L .35705 .72339 L F
.707 .802 .924 r
.35705 .72339 m .35879 .72476 L .36078 .72349 L F
.388 .104 .356 r
.32332 .62991 m .32602 .62749 L .32513 .62925 L F
.014 0 .093 r
.32513 .62925 m .32602 .62749 L .3274 .62649 L F
.276 .746 .942 r
.58827 .67926 m .58681 .67885 L .58443 .67891 L F
.823 .439 .327 r
.59032 .68158 m .58681 .67885 L .58827 .67926 L F
.471 .767 .995 r
.74465 .61294 m .74311 .61427 L .74225 .6131 L F
.74465 .61294 m .74636 .61407 L .74311 .61427 L F
.545 .484 .738 r
.34642 .69648 m .34705 .69892 L .34911 .69847 L F
.916 .711 .611 r
.58647 .71037 m .58633 .71325 L .58483 .70952 L F
.803 .557 .567 r
.56451 .70897 m .56786 .70974 L .56783 .70732 L F
.747 .391 .379 r
.51679 .79764 m .51845 .79546 L .51509 .7955 L F
.735 .375 .37 r
.51679 .79764 m .52025 .79794 L .51845 .79546 L F
.554 .193 .31 r
.45102 .75195 m .4526 .75347 L .45379 .7512 L F
.386 0 .017 r
.4526 .75347 m .45629 .75167 L .45379 .7512 L F
.625 .783 .958 r
.65018 .50484 m .65364 .5054 L .65133 .50378 L F
.65018 .50484 m .65364 .5054 L .65285 .50653 L F
.878 .46 .214 r
.65133 .50378 m .65364 .5054 L .65285 .50653 L F
.674 .289 .308 r
.47933 .79308 m .48294 .793 L .48155 .79499 L F
.62 .225 .273 r
.48155 .79499 m .48294 .793 L .48523 .7947 L F
.215 0 .179 r
.31154 .64305 m .31408 .64079 L .31342 .64234 L F
.284 0 .185 r
.3124 .64472 m .31154 .64305 L .31342 .64234 L F
.3124 .64472 m .31048 .64544 L .31154 .64305 L F
.563 .477 .715 r
.50094 .75622 m .50028 .75784 L .49805 .75775 L F
.97 .676 .411 r
.51197 .72739 m .5116 .72862 L .51021 .72594 L F
.409 .447 .789 r
.3311 .70705 m .33213 .71008 L .33203 .70741 L F
.334 .762 .972 r
.33213 .71008 m .333 .70934 L .33203 .70741 L F
.33213 .71008 m .33439 .70991 L .333 .70934 L F
.659 .555 .726 r
.33213 .71008 m .33567 .71293 L .33439 .70991 L F
.639 .168 0 r
.59757 .71013 m .59682 .70935 L .59575 .70786 L F
0 0 .025 r
.5965 .71253 m .59682 .70935 L .59757 .71013 L F
.439 .221 .484 r
.31408 .64079 m .31631 .63808 L .31595 .64017 L F
.333 .03 .293 r
.31595 .64017 m .31342 .64234 L .31408 .64079 L F
.296 0 .01 r
.53264 .80161 m .5339 .80016 L .53508 .80073 L F
.53264 .80161 m .5339 .80016 L .53508 .80073 L F
.228 0 0 r
.50502 .77172 m .50267 .77307 L .50424 .77009 L F
.50502 .77172 m .50508 .77269 L .50267 .77307 L F
.39 0 .09 r
.5085 .77083 m .50508 .77269 L .50502 .77172 L F
.246 0 0 r
.60734 .75377 m .60632 .75444 L .60351 .75496 L F
.113 .575 .916 r
.60734 .75377 m .60817 .75341 L .60632 .75444 L F
.60734 .75377 m .6096 .75438 L .60817 .75341 L F
.24 .753 .854 r
.63553 .54911 m .63372 .5492 L .63139 .54952 L F
.207 0 0 r
.63729 .54919 m .63372 .5492 L .63553 .54911 L F
.393 .64 .955 r
.48128 .77402 m .48385 .77437 L .4823 .7727 L F
.386 .161 .445 r
.32513 .62925 m .32291 .63206 L .32332 .62991 L F
.592 .342 .507 r
.7586 .61615 m .75834 .61821 L .75584 .61848 L F
.285 .082 .419 r
.76031 .61518 m .75834 .61821 L .7586 .61615 L F
.507 0 0 r
.46058 .78828 m .46338 .78957 L .45998 .78885 L F
.532 0 0 r
.46445 .7894 m .46338 .78957 L .46058 .78828 L F
.405 .149 .408 r
.33235 .61892 m .33483 .61626 L .33443 .61835 L F
.409 .167 .432 r
.33443 .61835 m .33483 .61626 L .33673 .61573 L F
.416 .111 .337 r
.43539 .68918 m .434 .68812 L .43598 .68745 L F
.43539 .68918 m .43333 .68971 L .434 .68812 L F
.852 .755 .756 r
.57231 .77 m .57042 .77133 L .57206 .76791 L F
.868 .766 .747 r
.57206 .76791 m .57145 .77111 L .57231 .77 L F
.44 .173 .411 r
.57145 .77111 m .57222 .77301 L .57231 .77 L F
.626 .931 .687 r
.71513 .60214 m .71748 .60007 L .71624 .60075 L F
.217 .357 .792 r
.71624 .60075 m .71742 .60386 L .71513 .60214 L F
0 0 0 r
.71624 .60075 m .71748 .60007 L .71975 .59944 L F
.236 0 0 r
.5243 .76433 m .52776 .76485 L .52559 .76439 L F
.851 .697 .69 r
.60719 .7067 m .60593 .70971 L .60859 .70988 L F
.851 .709 .705 r
.60859 .70988 m .60518 .71205 L .60688 .71306 L F
.60859 .70988 m .60593 .70971 L .60518 .71205 L F
.417 0 0 r
.38752 .70124 m .38984 .70151 L .39028 .70101 L F
0 0 0 r
.39028 .70101 m .38984 .70151 L .39159 .70045 L F
.963 .832 .666 r
.59579 .6989 m .59559 .6954 L .59725 .69626 L F
.855 .618 .58 r
.60261 .68713 m .60456 .68522 L .60248 .68499 L F
.60261 .68713 m .60464 .68787 L .60456 .68522 L F
.459 .008 .09 r
.74421 .59114 m .74594 .59261 L .74365 .59311 L F
.74421 .59114 m .74638 .5913 L .74594 .59261 L F
.345 0 .025 r
.72462 .71469 m .72687 .71446 L .7276 .71323 L F
.72462 .71469 m .72687 .71446 L .7276 .71323 L F
.578 .915 .692 r
.72908 .71176 m .7276 .71323 L .72764 .71304 L F
.299 0 .004 r
.7276 .71323 m .72929 .71364 L .72999 .7132 L F
.7276 .71323 m .72687 .71446 L .72929 .71364 L F
0 0 0 r
.7276 .71323 m .72687 .71446 L .72908 .71176 L F
.634 .218 .237 r
.49687 .79829 m .49769 .79649 L .49957 .79798 L F
.837 .822 .834 r
.63189 .49783 m .62856 .49925 L .63073 .49637 L F
.717 .74 .87 r
.63411 .49687 m .63189 .49783 L .63073 .49637 L F
.562 .66 .903 r
.32563 .71985 m .32608 .71716 L .32398 .71746 L F
.32563 .71985 m .32805 .7195 L .32608 .71716 L F
.681 .265 .25 r
.5116 .74286 m .51382 .74475 L .51506 .74287 L F
.272 0 0 r
.5116 .74286 m .51392 .74308 L .51506 .74287 L F
.656 .236 .235 r
.51506 .74287 m .51736 .74484 L .51641 .74253 L F
.51506 .74287 m .51382 .74475 L .51736 .74484 L F
.914 .905 .503 r
.75278 .61109 m .75089 .61193 L .75289 .6115 L F
.75214 .60856 m .75154 .61067 L .75089 .61193 L F
.75214 .60856 m .75089 .61193 L .75278 .61109 L F
.072 0 .083 r
.75154 .61067 m .74986 .61238 L .75089 .61193 L F
.74986 .61238 m .74905 .61322 L .75089 .61193 L F
.493 .88 .698 r
.75089 .61193 m .74905 .61322 L .7482 .61355 L F
.193 0 .194 r
.44854 .7544 m .44982 .75408 L .45102 .75195 L F
.539 .296 .495 r
.44854 .7544 m .45041 .75632 L .44982 .75408 L F
.44854 .7544 m .44814 .75677 L .45041 .75632 L F
.556 .48 .725 r
.34572 .69336 m .34642 .69648 L .34839 .69602 L F
.545 .484 .738 r
.34642 .69648 m .34911 .69847 L .34839 .69602 L F
.78 .661 .732 r
.67208 .5104 m .66955 .51346 L .6693 .51066 L F
.158 .664 .905 r
.67067 .50985 m .6744 .51052 L .67208 .5104 L F
.295 .383 .783 r
.67228 .50841 m .67229 .50845 L .67067 .50985 L F
.563 .887 .988 r
.66978 .51062 m .67067 .50985 L .67208 .5104 L F
.643 .138 .033 r
.67067 .50985 m .67307 .51139 L .6744 .51052 L F
.295 .383 .783 r
.67229 .50845 m .67307 .51139 L .67067 .50985 L F
.563 .887 .988 r
.6693 .51066 m .67067 .50985 L .66978 .51062 L F
.043 .04 .527 r
.55884 .68675 m .55792 .68785 L .55742 .6851 L F
0 0 0 r
.55702 .68596 m .5549 .68833 L .55566 .6876 L F
.55702 .68596 m .55566 .6876 L .5574 .68589 L F
.043 .04 .527 r
.55884 .68675 m .55758 .68529 L .55702 .68596 L F
.55758 .68529 m .55742 .6851 L .55702 .68596 L F
.48 .505 .807 r
.45624 .66416 m .45559 .66741 L .45408 .66455 L F
.45624 .66416 m .45751 .66726 L .45559 .66741 L F
.461 .035 .144 r
.63139 .54952 m .63037 .55123 L .62809 .5513 L F
.449 .067 .22 r
.63139 .54952 m .6327 .55118 L .63037 .55123 L F
.63139 .54952 m .63372 .5492 L .6327 .55118 L F
.256 .766 .838 r
.41988 .66354 m .41822 .66354 L .41623 .66395 L F
.126 .66 .861 r
.41988 .66354 m .42091 .66327 L .41822 .66354 L F
.41988 .66354 m .42214 .66362 L .42091 .66327 L F
.785 .682 .75 r
.33439 .70991 m .33567 .71293 L .33848 .70979 L F
.444 .481 .803 r
.33848 .70979 m .34149 .71155 L .34071 .71082 L F
.572 .482 .715 r
.34572 .69336 m .34728 .69052 L .34501 .69099 L F
.34572 .69336 m .34788 .693 L .34728 .69052 L F
.556 .48 .725 r
.34572 .69336 m .34839 .69602 L .34788 .693 L F
.527 .909 .944 r
.36526 .8447 m .36334 .84548 L .36457 .84562 L F
.36526 .8447 m .36334 .84548 L .36457 .84562 L F
0 0 .565 r
.57159 .72385 m .57206 .72374 L .57087 .7228 L F
.57159 .72385 m .57327 .72599 L .57206 .72374 L F
.446 .235 .498 r
.31814 .63747 m .31631 .63808 L .31855 .6352 L F
.444 .231 .494 r
.31595 .64017 m .31631 .63808 L .31814 .63747 L F
.303 .448 .841 r
.48441 .75595 m .48338 .75775 L .48275 .75614 L F
.48441 .75595 m .48567 .75825 L .48338 .75775 L F
.714 .424 .484 r
.53796 .74027 m .54003 .74265 L .539 .7421 L F
.353 .777 .974 r
.26107 .58627 m .2629 .58595 L .26465 .58663 L F
.373 .748 .99 r
.26516 .58559 m .26465 .58663 L .2629 .58595 L F
.26516 .58559 m .26685 .58638 L .26465 .58663 L F
.749 .555 .633 r
.61655 .54956 m .61498 .55169 L .61513 .54993 L F
.695 .481 .593 r
.61655 .54956 m .61647 .55219 L .61498 .55169 L F
.715 .498 .594 r
.62026 .5519 m .61655 .54956 L .62065 .54984 L F
.62026 .5519 m .61647 .55219 L .61655 .54956 L F
.191 .378 .819 r
.55037 .77433 m .55156 .77319 L .54981 .77408 L F
.591 .228 .321 r
.5526 .77424 m .55282 .77578 L .55037 .77433 L F
.191 .378 .819 r
.55037 .77433 m .55282 .77578 L .55156 .77319 L F
.587 .625 .857 r
.45386 .66392 m .45173 .66492 L .45135 .66376 L F
.45386 .66392 m .45408 .66455 L .45173 .66492 L F
.325 .03 .301 r
.30188 .62906 m .30454 .62649 L .3024 .62699 L F
.815 .602 .614 r
.67995 .50734 m .68168 .50892 L .68281 .50811 L F
.877 .978 .837 r
.68281 .50811 m .68168 .50892 L .68205 .50834 L F
.759 .319 .208 r
.68281 .50811 m .68205 .50834 L .67995 .50734 L F
.827 .86 .871 r
.68422 .50501 m .68205 .50834 L .68085 .5063 L F
.68205 .50834 m .68168 .50892 L .68149 .50832 L F
.68205 .50834 m .68149 .50832 L .68085 .5063 L F
.759 .319 .208 r
.68205 .50834 m .68169 .50845 L .68149 .50832 L F
.68205 .50834 m .68149 .50832 L .67995 .50734 L F
.306 .522 .9 r
.68149 .50832 m .68168 .50892 L .67995 .50734 L F
.759 .319 .208 r
.68169 .50845 m .68127 .50858 L .67995 .50734 L F
.306 .522 .9 r
.68085 .5063 m .68149 .50832 L .67995 .50734 L F
.877 .978 .837 r
.68281 .50811 m .68205 .50834 L .68422 .50501 L F
.759 .319 .208 r
.68281 .50811 m .68218 .50942 L .68127 .50858 L F
.979 .781 .365 r
.68281 .51048 m .68218 .50942 L .68281 .50811 L F
.877 .978 .837 r
.68281 .50811 m .68422 .50501 L .68514 .50765 L F
.562 .422 .648 r
.68514 .50765 m .68281 .51048 L .68281 .50811 L F
.265 .653 .966 r
.28316 .58978 m .27939 .58853 L .28123 .5883 L F
.331 .641 .965 r
.28386 .58878 m .28316 .58978 L .28123 .5883 L F
.28386 .58878 m .28499 .58998 L .28316 .58978 L F
.915 .582 .396 r
.49177 .78192 m .49016 .78126 L .48952 .78268 L F
0 0 0 r
.55271 .75238 m .5526 .75175 L .55323 .7518 L F
.55271 .75238 m .55151 .75398 L .5526 .75175 L F
.293 .354 .755 r
.50686 .72234 m .50781 .72622 L .50642 .7267 L F
.245 .206 .614 r
.50781 .72622 m .50805 .72827 L .50642 .7267 L F
.382 .215 .527 r
.50642 .7267 m .50805 .72827 L .50607 .72948 L F
.117 .346 .812 r
.33686 .71835 m .33855 .71962 L .33744 .71711 L F
.578 .357 .544 r
.33686 .71835 m .33664 .72091 L .33855 .71962 L F
.184 .117 .541 r
.5921 .70681 m .59321 .7091 L .59112 .71016 L F
0 0 .329 r
.59321 .7091 m .59142 .71234 L .59112 .71016 L F
.317 .033 .313 r
.50911 .75646 m .50822 .75942 L .50675 .75979 L F
.498 .302 .545 r
.51186 .75392 m .51159 .75661 L .50911 .75646 L F
.64 .335 .439 r
.51201 .75868 m .50911 .75646 L .51159 .75661 L F
.51201 .75868 m .50822 .75942 L .50911 .75646 L F
.467 .171 .379 r
.4184 .68673 m .42109 .68466 L .41885 .68502 L F
.926 .786 .686 r
.60532 .69581 m .60456 .69846 L .60609 .69895 L F
.968 .648 .29 r
.60456 .69846 m .60579 .70103 L .60609 .69895 L F
.204 0 .277 r
.30879 .62097 m .3111 .61805 L .3092 .61871 L F
.239 .756 .808 r
.26565 .65678 m .26539 .65625 L .26408 .65633 L F
.26565 .65678 m .26629 .65645 L .26539 .65625 L F
.26565 .65678 m .26744 .65639 L .26629 .65645 L F
.307 0 0 r
.37881 .64907 m .381 .64904 L .3821 .64849 L F
.291 0 0 r
.3821 .64849 m .381 .64904 L .38438 .64842 L F
.598 .519 .736 r
.45033 .66005 m .44815 .66067 L .44713 .65691 L F
.636 .647 .844 r
.50391 .75959 m .50156 .75989 L .50028 .75784 L F
.611 .421 .6 r
.50391 .75959 m .50171 .7624 L .50156 .75989 L F
.502 .2 .387 r
.45102 .75195 m .44982 .75408 L .4526 .75347 L F
0 0 0 r
.74061 .58788 m .73741 .58864 L .73987 .58918 L F
.518 .315 .544 r
.7428 .58758 m .74283 .58543 L .74061 .58788 L F
.415 0 .093 r
.73987 .58918 m .7428 .58758 L .74061 .58788 L F
.67 .601 .769 r
.46194 .6713 m .45838 .66881 L .46064 .66834 L F
.745 .684 .792 r
.4641 .66859 m .46194 .6713 L .46064 .66834 L F
.667 .566 .731 r
.4641 .66859 m .46459 .67135 L .46194 .6713 L F
.574 .302 .465 r
.46459 .67135 m .46184 .6736 L .46194 .6713 L F
0 .216 .737 r
.48275 .75614 m .48007 .7543 L .48254 .75419 L F
.539 .271 .457 r
.41103 .69036 m .4133 .69011 L .4137 .68809 L F
.471 .21 .436 r
.4137 .68809 m .41543 .68964 L .41589 .68783 L F
.4137 .68809 m .4133 .69011 L .41543 .68964 L F
.041 .279 .773 r
.36277 .72423 m .36471 .72583 L .36434 .72514 L F
.502 0 0 r
.36416 .72418 m .36277 .72423 L .36185 .72371 L F
.041 .279 .773 r
.36277 .72423 m .36434 .72514 L .36289 .7224 L F
.502 0 0 r
.36185 .72371 m .36277 .72423 L .36078 .72349 L F
0 0 0 r
.26744 .64284 m .26953 .64263 L .27111 .64244 L F
.638 .963 .898 r
.27111 .64244 m .27136 .64148 L .27303 .64199 L F
.27111 .64244 m .26953 .64263 L .27136 .64148 L F
.282 .714 .967 r
.5698 .70978 m .57107 .71047 L .56786 .70974 L F
0 .246 .656 r
.57107 .71047 m .57365 .71191 L .57474 .7126 L F
.602 .031 0 r
.5698 .70978 m .57365 .71191 L .57107 .71047 L F
.368 .699 .983 r
.66267 .5155 m .66164 .5166 L .66019 .51477 L F
.66267 .5155 m .66381 .5167 L .66164 .5166 L F
.849 .592 .551 r
.58664 .73211 m .58683 .73455 L .58919 .73462 L F
.999 .815 .514 r
.5924 .68258 m .59109 .68394 L .59032 .68158 L F
.5924 .68258 m .59189 .68493 L .59109 .68394 L F
.488 .272 .512 r
.31814 .63747 m .31855 .6352 L .32055 .63474 L F
.756 .381 .344 r
.51576 .71134 m .51925 .71195 L .51898 .7105 L F
.381 0 0 r
.39675 .66788 m .39356 .66821 L .395 .66846 L F
.478 .302 .563 r
.46332 .76916 m .46308 .77331 L .46112 .77343 L F
.345 0 0 r
.46554 .76902 m .46495 .7696 L .46332 .76916 L F
.494 .365 .633 r
.46495 .7696 m .46308 .77331 L .46332 .76916 L F
.335 0 0 r
.40567 .70705 m .402 .70878 L .40347 .70722 L F
.357 .767 .981 r
.46466 .77834 m .46666 .7781 L .46809 .77881 L F
.376 .758 .99 r
.46883 .77785 m .46809 .77881 L .46666 .7781 L F
.46883 .77785 m .47028 .7786 L .46809 .77881 L F
.871 .742 .717 r
.5931 .68747 m .59109 .68772 L .59189 .68493 L F
.735 .312 .246 r
.5931 .68747 m .59199 .68928 L .59109 .68772 L F
.5931 .68747 m .59545 .6898 L .59199 .68928 L F
.793 .975 .908 r
.74461 .62259 m .7475 .62111 L .74736 .62107 L F
.532 .891 .672 r
.74935 .61949 m .7475 .62111 L .75157 .61953 L F
.74935 .61949 m .74736 .62107 L .7475 .62111 L F
.534 .26 .446 r
.43333 .68971 m .43041 .69303 L .43134 .69042 L F
.098 0 0 r
.59142 .71234 m .59111 .71245 L .58829 .7123 L F
0 0 .329 r
.59321 .7091 m .59287 .71138 L .59142 .71234 L F
.402 .825 .655 r
.59287 .71138 m .59111 .71245 L .59142 .71234 L F
.926 .544 .159 r
.58032 .7151 m .58099 .71715 L .58207 .71769 L F
.787 .287 0 r
.58099 .71715 m .58425 .71993 L .58207 .71769 L F
.424 0 0 r
.52776 .76485 m .5302 .76499 L .53089 .76412 L F
.041 0 0 r
.53222 .76424 m .53089 .76412 L .5302 .76499 L F
.53222 .76424 m .5335 .76253 L .53089 .76412 L F
.725 .551 .655 r
.62233 .54941 m .62026 .5519 L .62065 .54984 L F
.708 .527 .641 r
.62233 .54941 m .62324 .5514 L .62026 .5519 L F
.602 .352 .51 r
.62605 .54948 m .62324 .5514 L .62233 .54941 L F
.718 .827 .932 r
.4521 .78754 m .45558 .78749 L .45423 .7871 L F
0 .187 .72 r
.45558 .78749 m .45637 .78738 L .45423 .7871 L F
.605 .34 .49 r
.45791 .78755 m .4577 .78956 L .45558 .78749 L F
0 .187 .72 r
.45558 .78749 m .4577 .78956 L .45637 .78738 L F
.394 .118 .372 r
.32985 .62135 m .33235 .61892 L .33178 .62085 L F
.418 .142 .385 r
.33178 .62085 m .33235 .61892 L .33443 .61835 L F
.427 .24 .522 r
.37621 .68097 m .37486 .67923 L .37689 .67891 L F
.37621 .68097 m .37314 .68259 L .37486 .67923 L F
0 .03 .598 r
.54437 .73215 m .54477 .73142 L .54326 .72899 L F
.19 0 .321 r
.54437 .73215 m .54579 .73353 L .54477 .73142 L F
.54437 .73215 m .54394 .73528 L .54579 .73353 L F
.959 .623 .312 r
.54679 .74321 m .5457 .74391 L .54342 .7428 L F
.044 0 0 r
.29628 .65228 m .29436 .6528 L .29225 .65303 L F
.215 .734 .727 r
.2984 .65183 m .29436 .6528 L .29628 .65228 L F
.574 .068 .015 r
.54084 .7295 m .5398 .73074 L .5374 .72931 L F
.605 .206 .26 r
.54326 .72899 m .5398 .73074 L .54084 .7295 L F
.554 .654 .902 r
.76022 .58753 m .75793 .58788 L .7566 .58556 L F
.819 .504 .456 r
.61799 .72684 m .61813 .72876 L .62075 .72903 L F
.977 .853 .651 r
.61896 .73083 m .62075 .72903 L .61813 .72876 L F
.61896 .73083 m .62015 .73192 L .62075 .72903 L F
.794 .484 .463 r
.61467 .72814 m .61799 .72684 L .61464 .7263 L F
.61467 .72814 m .61813 .72876 L .61799 .72684 L F
.817 .513 .476 r
.50004 .73744 m .50107 .73934 L .5043 .73793 L F
.169 0 0 r
.5043 .73793 m .50476 .73963 L .50452 .7377 L F
.5043 .73793 m .50331 .73896 L .50476 .73963 L F
.5043 .73793 m .50107 .73934 L .50331 .73896 L F
.987 .718 .356 r
.58425 .71993 m .58521 .72318 L .58475 .72117 L F
.941 .667 .492 r
.60424 .69002 m .60443 .69277 L .60662 .69357 L F
.903 .736 .664 r
.60385 .69467 m .60662 .69357 L .60443 .69277 L F
.60385 .69467 m .60532 .69581 L .60662 .69357 L F
.503 .425 .701 r
.44493 .76541 m .44637 .76221 L .44459 .76279 L F
.88 .858 .815 r
.62151 .52804 m .62043 .52956 L .61795 .52987 L F
.893 .799 .749 r
.62043 .52956 m .61732 .5315 L .61795 .52987 L F
.62043 .52956 m .61874 .53266 L .61732 .5315 L F
.376 .227 .548 r
.44381 .77368 m .44565 .77319 L .44546 .77083 L F
.453 .341 .636 r
.44393 .77616 m .44565 .77319 L .44381 .77368 L F
.695 .214 .103 r
.57365 .71191 m .57733 .71294 L .57474 .7126 L F
.786 .607 .658 r
.59801 .71773 m .59662 .72089 L .59441 .7175 L F
.761 .663 .754 r
.59897 .71582 m .59801 .71773 L .59645 .71433 L F
.602 .352 .51 r
.62605 .54948 m .62615 .55147 L .62324 .5514 L F
.611 .359 .51 r
.62605 .54948 m .62809 .5513 L .62615 .55147 L F
0 .027 .599 r
.58178 .74061 m .58185 .73932 L .5803 .73705 L F
0 0 0 r
.58158 .74283 m .58185 .73932 L .58178 .74061 L F
.988 .744 .469 r
.59545 .6898 m .5966 .69062 L .59654 .69323 L F
.427 .431 .761 r
.75033 .59322 m .75113 .59654 L .75301 .59518 L F
.413 .403 .74 r
.75113 .59654 m .75372 .59832 L .75301 .59518 L F
.465 .398 .698 r
.7518 .59882 m .75372 .59832 L .75113 .59654 L F
.429 .132 .357 r
.26176 .61336 m .26116 .61515 L .25918 .61564 L F
.382 .088 .337 r
.26176 .61336 m .26295 .6147 L .26116 .61515 L F
.445 .093 .273 r
.2641 .61307 m .26295 .6147 L .26176 .61336 L F
.929 .65 .49 r
.31449 .74874 m .31287 .75043 L .31335 .7488 L F
.914 .912 .803 r
.31449 .74874 m .31425 .74649 L .31527 .74812 L F
.31449 .74874 m .31335 .7488 L .31425 .74649 L F
.496 .214 .415 r
.31527 .74812 m .31287 .75043 L .31449 .74874 L F
.478 .511 .813 r
.60758 .54677 m .60643 .54347 L .60574 .54413 L F
0 0 .499 r
.60758 .54677 m .60736 .54544 L .60643 .54347 L F
.426 .5 .832 r
.60919 .54845 m .60736 .54544 L .60758 .54677 L F
.098 0 .197 r
.76253 .61224 m .76031 .61518 L .76091 .61351 L F
.83 .722 .745 r
.629 .51477 m .63017 .51622 L .63208 .51353 L F
.629 .51477 m .63208 .51353 L .63141 .51396 L F
0 0 0 r
.63354 .51238 m .63208 .51353 L .6347 .51134 L F
.621 .396 .554 r
.63354 .51238 m .63141 .51396 L .63208 .51353 L F
.507 .188 .361 r
.35661 .65886 m .35505 .65721 L .35419 .65935 L F
.35661 .65886 m .35729 .65699 L .35505 .65721 L F
.634 .343 .459 r
.51625 .75601 m .51383 .75433 L .51751 .7544 L F
.633 .338 .452 r
.51974 .75396 m .51625 .75601 L .51751 .7544 L F
.503 .425 .701 r
.44493 .76541 m .44682 .76502 L .44637 .76221 L F
.496 .397 .672 r
.44493 .76541 m .44728 .76746 L .44682 .76502 L F
.491 .396 .676 r
.44537 .76787 m .44728 .76746 L .44493 .76541 L F
.636 .238 .273 r
.52825 .80263 m .52934 .80552 L .52733 .80402 L F
.52825 .80263 m .53048 .80343 L .52934 .80552 L F
.444 .256 .53 r
.745 .58462 m .74283 .58543 L .7428 .58758 L F
.88 .858 .815 r
.62151 .52804 m .61795 .52987 L .61992 .52668 L F
.855 .792 .789 r
.62335 .52508 m .62151 .52804 L .61992 .52668 L F
.379 .247 .572 r
.75214 .60856 m .75531 .60626 L .75352 .60761 L F
.217 0 0 r
.37962 .71764 m .37799 .71922 L .37603 .71962 L F
.145 0 0 r
.38191 .71673 m .38096 .71784 L .37962 .71764 L F
.116 0 0 r
.38024 .71842 m .37962 .71764 L .38096 .71784 L F
.38024 .71842 m .37799 .71922 L .37962 .71764 L F
.594 .347 .512 r
.46174 .75113 m .4641 .75109 L .46437 .74885 L F
.513 .273 .488 r
.4641 .75109 m .46657 .7485 L .46437 .74885 L F
.427 .323 .633 r
.33999 .70722 m .34071 .71082 L .34197 .70919 L F
.523 .254 .448 r
.46657 .7485 m .46891 .74825 L .46938 .74544 L F
.459 .192 .42 r
.46891 .74825 m .47173 .74499 L .46938 .74544 L F
.549 .512 .767 r
.45249 .65958 m .45135 .66376 L .45033 .66005 L F
.45249 .65958 m .45386 .66392 L .45135 .66376 L F
.5 .177 .35 r
.44925 .67935 m .44839 .68166 L .44613 .68189 L F
.505 .188 .363 r
.45156 .679 m .44839 .68166 L .44925 .67935 L F
.637 .66 .856 r
.44713 .65691 m .44355 .65489 L .44565 .6542 L F
.632 .669 .868 r
.44956 .65635 m .44713 .65691 L .44565 .6542 L F
.598 .519 .736 r
.45033 .66005 m .44713 .65691 L .44956 .65635 L F
.456 .142 .343 r
.53708 .75199 m .53881 .7533 L .53911 .7515 L F
.53708 .75199 m .53658 .75392 L .53881 .7533 L F
.567 .606 .852 r
.34566 .60376 m .34351 .60442 L .34146 .6016 L F
.479 .391 .678 r
.34566 .60376 m .34399 .60745 L .34351 .60442 L F
.313 0 .045 r
.36388 .656 m .36309 .65467 L .36186 .65657 L F
.36388 .656 m .36522 .65424 L .36309 .65467 L F
.855 .792 .789 r
.62335 .52508 m .61992 .52668 L .62193 .52361 L F
.698 .659 .807 r
.62269 .52178 m .62335 .52508 L .62193 .52361 L F
.62269 .52178 m .62804 .52393 L .62335 .52508 L F
.274 .758 .661 r
.57528 .67578 m .57648 .67527 L .57764 .67604 L F
.57528 .67578 m .57485 .67594 L .57648 .67527 L F
.604 .714 .922 r
.72789 .71737 m .72871 .7186 L .73133 .71775 L F
.446 .126 .329 r
.42633 .69384 m .42581 .6955 L .42365 .69591 L F
.319 .012 .277 r
.42783 .6945 m .42633 .69384 L .42854 .69352 L F
.42783 .6945 m .42581 .6955 L .42633 .69384 L F
.991 .876 .609 r
.54312 .69938 m .54226 .70186 L .54157 .70048 L F
.037 0 0 r
.54312 .69938 m .54377 .69986 L .54499 .69839 L F
.54312 .69938 m .54157 .70048 L .54377 .69986 L F
.589 .544 .771 r
.76059 .60353 m .75924 .60749 L .75815 .60445 L F
.76059 .60353 m .76165 .60704 L .75924 .60749 L F
.475 .895 .881 r
.37261 .71957 m .37181 .72028 L .37399 .72022 L F
.333 0 .062 r
.65726 .54217 m .6555 .54176 L .65837 .54071 L F
0 0 0 r
.6606 .54045 m .65726 .54217 L .65837 .54071 L F
.767 .332 .219 r
.5894 .67309 m .59147 .67521 L .59238 .6739 L F
.762 .326 .216 r
.59147 .67521 m .5946 .6761 L .59238 .6739 L F
.052 0 .017 r
.54954 .73545 m .54732 .73751 L .5479 .73481 L F
.185 0 0 r
.71937 .59652 m .71805 .59646 L .71842 .59658 L F
.382 .399 .754 r
.71937 .59652 m .7206 .59307 L .71805 .59646 L F
.71937 .59652 m .72027 .59683 L .7206 .59307 L F
0 .155 .627 r
.72082 .59745 m .71937 .59652 L .71842 .59658 L F
.72082 .59745 m .72182 .59835 L .71937 .59652 L F
.846 .921 .882 r
.68908 .52415 m .68754 .52484 L .68782 .52315 L F
0 0 0 r
.68908 .52415 m .68767 .52492 L .68754 .52484 L F
.559 .758 .971 r
.68946 .52216 m .68908 .52415 L .68782 .52315 L F
.68946 .52216 m .69148 .52371 L .68908 .52415 L F
.659 .285 .325 r
.69148 .52371 m .68767 .52492 L .68908 .52415 L F
.591 .682 .904 r
.46064 .66834 m .45838 .66881 L .45751 .66726 L F
0 0 .098 r
.6197 .73733 m .61965 .73937 L .6188 .74068 L F
0 0 0 r
.61801 .74266 m .6188 .74068 L .61965 .73937 L F
.725 .605 .722 r
.46759 .67123 m .4641 .66859 L .46668 .66808 L F
.46759 .67123 m .46459 .67135 L .4641 .66859 L F
.327 0 .067 r
.46759 .67123 m .46425 .67336 L .46459 .67135 L F
.46759 .67123 m .46639 .67295 L .46425 .67336 L F
.451 .467 .785 r
.46907 .67035 m .46759 .67123 L .46668 .66808 L F
.589 .319 .476 r
.46907 .67035 m .46639 .67295 L .46759 .67123 L F
.734 .945 .951 r
.48935 .77085 m .48647 .77161 L .48816 .77019 L F
.48935 .77085 m .48684 .77183 L .48647 .77161 L F
.915 .582 .396 r
.49177 .78192 m .4911 .78381 L .49016 .78126 L F
.489 .345 .612 r
.49132 .77045 m .49152 .7729 L .48935 .77085 L F
.493 .346 .609 r
.49152 .7729 m .48957 .77369 L .48935 .77085 L F
.302 .401 .798 r
.49268 .77963 m .4939 .78247 L .49177 .78192 L F
.045 0 .071 r
.49242 .78301 m .4911 .78381 L .49177 .78192 L F
.386 0 .017 r
.4526 .75347 m .4549 .75322 L .45629 .75167 L F
.336 0 0 r
.4549 .75322 m .45789 .75269 L .45629 .75167 L F
.461 .015 .103 r
.45629 .75167 m .45789 .75269 L .45856 .75162 L F
.265 .389 .802 r
.46352 .7752 m .46112 .77343 L .46308 .77331 L F
.323 .73 .979 r
.2945 .60396 m .29491 .60312 L .29287 .60334 L F
.2945 .60396 m .29647 .60391 L .29491 .60312 L F
.595 .279 .404 r
.64506 .54676 m .64474 .54823 L .64182 .54917 L F
.426 .127 .353 r
.64726 .54772 m .64506 .54676 L .64743 .54635 L F
.64726 .54772 m .64474 .54823 L .64506 .54676 L F
.374 0 .033 r
.47959 .76729 m .47904 .76815 L .4768 .76834 L F
.205 .343 .783 r
.47959 .76729 m .48117 .7671 L .47904 .76815 L F
.477 .158 .345 r
.29412 .63641 m .29251 .63521 L .29205 .63672 L F
.29412 .63641 m .29468 .6349 L .29251 .63521 L F
.581 .207 .298 r
.51916 .72436 m .51954 .72571 L .51612 .72569 L F
.556 .193 .306 r
.51916 .72436 m .52171 .72572 L .51954 .72571 L F
.621 .41 .575 r
.49032 .76236 m .49036 .76501 L .48817 .7655 L F
.466 .885 .92 r
.49032 .76236 m .4926 .7616 L .49155 .76145 L F
.55 .354 .568 r
.4926 .7616 m .49032 .76236 L .49155 .76145 L F
.4926 .7616 m .49036 .76501 L .49032 .76236 L F
.141 0 .041 r
.30595 .64832 m .30682 .6471 L .30864 .64621 L F
0 0 .557 r
.66522 .51657 m .66584 .51826 L .66604 .51835 L F
0 0 .367 r
.66643 .51987 m .6657 .51869 L .66604 .51835 L F
0 0 .557 r
.66584 .51826 m .66643 .51987 L .66604 .51835 L F
0 .14 .653 r
.66584 .51826 m .66597 .51842 L .6657 .51869 L F
.978 .685 .316 r
.66584 .51826 m .66546 .51888 L .66643 .51987 L F
.66522 .51657 m .66573 .51812 L .66584 .51826 L F
0 .145 .667 r
.66522 .51657 m .66604 .51835 L .66573 .51812 L F
.66522 .51657 m .66573 .51812 L .66381 .5167 L F
.978 .685 .316 r
.66522 .51657 m .66533 .51763 L .66573 .51812 L F
0 .14 .653 r
.66483 .51777 m .66584 .51826 L .6657 .51869 L F
.978 .685 .316 r
.66533 .51763 m .66546 .51888 L .66584 .51826 L F
0 .14 .653 r
.66584 .51826 m .66604 .51835 L .66597 .51842 L F
.977 .795 .378 r
.66467 .51666 m .66465 .51674 L .66522 .51657 L F
0 .14 .653 r
.66381 .5167 m .66543 .51791 L .66483 .51777 L F
.977 .795 .378 r
.66465 .51674 m .66445 .51788 L .6649 .51711 L F
.66465 .51674 m .6649 .51711 L .66522 .51657 L F
0 .14 .653 r
.66543 .51791 m .66604 .51835 L .66559 .51814 L F
.66543 .51791 m .66559 .51814 L .66483 .51777 L F
0 0 .367 r
.66643 .51987 m .66669 .52084 L .6657 .51869 L F
.425 .14 .374 r
.38636 .66879 m .38583 .67063 L .38381 .67106 L F
.45 .135 .339 r
.38806 .66862 m .38583 .67063 L .38636 .66879 L F
.425 .31 .618 r
.33181 .62322 m .32985 .62135 L .33178 .62085 L F
.33181 .62322 m .33011 .62373 L .32985 .62135 L F
.732 .401 .42 r
.71535 .59219 m .71764 .59329 L .7182 .59079 L F
.619 .297 .403 r
.71764 .59329 m .72035 .59106 L .7182 .59079 L F
.209 .699 .924 r
.42527 .65159 m .42738 .65162 L .42876 .6521 L F
.327 .715 .982 r
.42965 .65125 m .42876 .6521 L .42738 .65162 L F
.42965 .65125 m .43085 .65212 L .42876 .6521 L F
.568 .365 .566 r
.6752 .49967 m .67537 .50205 L .67277 .50239 L F
.515 .419 .684 r
.67676 .49664 m .6752 .49967 L .67359 .49625 L F
.67676 .49664 m .6773 .49896 L .6752 .49967 L F
.464 .289 .557 r
.6773 .49896 m .67537 .50205 L .6752 .49967 L F
.291 0 0 r
.28097 .6057 m .27955 .60515 L .28293 .60446 L F
.163 0 0 r
.28293 .60446 m .28287 .60542 L .28097 .6057 L F
.28293 .60446 m .28501 .60412 L .28287 .60542 L F
.387 .096 .343 r
.67862 .52675 m .67786 .52921 L .6781 .52761 L F
.402 .109 .35 r
.68007 .52849 m .67862 .52675 L .68103 .52719 L F
.68007 .52849 m .67786 .52921 L .67862 .52675 L F
.435 .391 .711 r
.34465 .67733 m .34698 .67899 L .34682 .67614 L F
.34465 .67733 m .34528 .67942 L .34698 .67899 L F
.572 .401 .611 r
.42602 .67959 m .42858 .67919 L .42819 .67629 L F
.454 .317 .605 r
.42819 .67629 m .43038 .67853 L .43036 .6762 L F
.42819 .67629 m .42858 .67919 L .43038 .67853 L F
.335 .711 .983 r
.27786 .58757 m .27939 .58853 L .27588 .58755 L F
.42 .764 .996 r
.27993 .58745 m .27939 .58853 L .27786 .58757 L F
.27993 .58745 m .28123 .5883 L .27939 .58853 L F
.487 .24 .465 r
.34399 .60745 m .34373 .60949 L .34163 .61023 L F
.479 .391 .678 r
.34566 .60376 m .34582 .60696 L .34399 .60745 L F
.491 .282 .523 r
.34582 .60696 m .34373 .60949 L .34399 .60745 L F
0 .36 .739 r
.49088 .78973 m .48857 .78864 L .48965 .78935 L F
0 .198 .725 r
.49106 .79027 m .48965 .78935 L .48967 .78852 L F
.557 .008 0 r
.49179 .7912 m .49088 .78973 L .48965 .78935 L F
0 .198 .725 r
.49179 .7912 m .48965 .78935 L .49106 .79027 L F
0 .36 .739 r
.48857 .78864 m .48729 .78804 L .48965 .78935 L F
.557 .008 0 r
.49179 .7912 m .49308 .79056 L .49088 .78973 L F
.328 0 .066 r
.46802 .76818 m .46495 .7696 L .46554 .76902 L F
.291 0 .214 r
.49262 .73248 m .49192 .73406 L .49457 .73173 L F
.402 .402 .744 r
.48875 .78631 m .48965 .78935 L .48729 .78804 L F
.194 .657 .941 r
.30872 .5937 m .31083 .5939 L .31236 .59469 L F
.368 .756 .988 r
.31083 .5939 m .31457 .59437 L .31236 .59469 L F
.614 .401 .568 r
.53563 .76194 m .53824 .75944 L .536 .75996 L F
.413 .204 .484 r
.55472 .77124 m .55465 .77464 L .5526 .77424 L F
.491 .159 .332 r
.5552 .77527 m .5526 .77424 L .55465 .77464 L F
.5552 .77527 m .55282 .77578 L .5526 .77424 L F
.045 0 0 r
.41059 .6499 m .41274 .65001 L .4139 .65005 L F
.463 0 0 r
.41274 .65001 m .41633 .65015 L .4139 .65005 L F
0 0 .438 r
.66822 .5312 m .66729 .53021 L .6687 .52865 L F
.66822 .5312 m .66808 .53251 L .66729 .53021 L F
.655 .216 .195 r
.50709 .80038 m .50687 .79913 L .50885 .80074 L F
.307 0 0 r
.33064 .72026 m .32954 .72006 L .32805 .7195 L F
.985 .893 .64 r
.33052 .71722 m .33064 .72026 L .33322 .71801 L F
.33052 .71722 m .32954 .72006 L .33064 .72026 L F
.628 .858 .986 r
.2767 .64179 m .27303 .64199 L .27526 .64099 L F
.534 .8 .995 r
.27736 .64049 m .2767 .64179 L .27526 .64099 L F
.27736 .64049 m .27869 .64145 L .2767 .64179 L F
.527 .28 .484 r
.42578 .68175 m .42858 .67919 L .42602 .67959 L F
.733 .473 .534 r
.50476 .73963 m .50853 .7375 L .50452 .7377 L F
.50476 .73963 m .50892 .74029 L .50853 .7375 L F
.685 .438 .544 r
.50853 .7375 m .50892 .74029 L .51041 .73959 L F
.442 .122 .326 r
.65052 .54371 m .64967 .54583 L .64743 .54635 L F
.586 .315 .472 r
.65259 .54334 m .64967 .54583 L .65052 .54371 L F
.208 0 0 r
.29003 .63741 m .2906 .63863 L .29205 .63672 L F
.29003 .63741 m .28857 .63927 L .2906 .63863 L F
.561 .572 .822 r
.72563 .71742 m .72687 .71446 L .72462 .71469 L F
.72563 .71742 m .72789 .71737 L .72687 .71446 L F
.635 .262 0 r
.47101 .78009 m .47164 .78135 L .47028 .7786 L F
.456 .216 .46 r
.47083 .78201 m .47164 .78135 L .47101 .78009 L F
.47111 .78178 m .47328 .78191 L .47164 .78135 L F
.47132 .78199 m .47328 .78191 L .47111 .78178 L F
.47083 .78201 m .47213 .7835 L .47328 .78191 L F
.47201 .78267 m .47101 .78009 L .47161 .77989 L F
.47213 .7835 m .47179 .78245 L .47201 .78267 L F
.47179 .78245 m .47101 .78009 L .47201 .78267 L F
.47083 .78201 m .47132 .78199 L .47111 .78178 L F
.659 .825 .399 r
.57369 .76703 m .57145 .77111 L .57206 .76791 L F
.835 .652 .108 r
.57223 .76849 m .57225 .76935 L .57243 .76916 L F
.659 .825 .399 r
.57264 .76894 m .57243 .76916 L .57145 .77111 L F
0 0 .394 r
.57239 .77149 m .57145 .77111 L .57243 .76916 L F
.835 .652 .108 r
.57225 .76935 m .57229 .77103 L .57243 .76916 L F
.659 .825 .399 r
.57369 .76703 m .57243 .76916 L .57264 .76894 L F
0 0 .394 r
.57239 .77149 m .57222 .77301 L .57145 .77111 L F
.482 .746 .987 r
.3096 .60713 m .31068 .60551 L .30811 .60551 L F
.3096 .60713 m .31143 .60673 L .31068 .60551 L F
.967 .644 .285 r
.61923 .73303 m .62015 .73192 L .61896 .73083 L F
.61923 .73303 m .62031 .7341 L .62015 .73192 L F
0 .563 .763 r
.39579 .64852 m .39793 .6487 L .3993 .64891 L F
.375 .789 .979 r
.39793 .6487 m .40134 .649 L .3993 .64891 L F
.916 .662 .166 r
.58225 .746 m .58178 .74524 L .58158 .74283 L F
.814 .766 .255 r
.58225 .746 m .58184 .74725 L .58178 .74524 L F
.58225 .746 m .58166 .74887 L .58184 .74725 L F
.371 .148 .439 r
.76078 .59376 m .75918 .59367 L .76141 .59061 L F
.545 .561 .822 r
.76363 .59036 m .76141 .59061 L .76022 .58753 L F
.3 .086 .411 r
.76342 .59168 m .76141 .59061 L .76363 .59036 L F
.76342 .59168 m .76078 .59376 L .76141 .59061 L F
.563 .316 .5 r
.55841 .77042 m .55465 .77464 L .55472 .77124 L F
.872 .497 .33 r
.67654 .51176 m .67795 .51071 L .6766 .50955 L F
.67654 .51176 m .67833 .51265 L .67795 .51071 L F
.576 .428 .643 r
.33882 .71523 m .34101 .71516 L .3408 .71269 L F
.828 .487 .409 r
.33882 .71523 m .34099 .71749 L .34101 .71516 L F
.33882 .71523 m .33744 .71711 L .34099 .71749 L F
.229 .698 .943 r
.28499 .58998 m .28697 .59003 L .2886 .59067 L F
.265 .709 .96 r
.28697 .59003 m .29053 .59075 L .2886 .59067 L F
.287 .555 .927 r
.54954 .73545 m .55192 .73749 L .5525 .73633 L F
0 0 .495 r
.55192 .73749 m .55244 .73808 L .5525 .73633 L F
.162 .68 .888 r
.39 .64812 m .39221 .64819 L .39374 .64855 L F
.221 .718 .914 r
.39374 .64855 m .39221 .64819 L .39579 .64852 L F
.705 .454 .542 r
.53302 .73493 m .53303 .7372 L .53631 .73673 L F
.637 .587 .781 r
.67342 .49425 m .67144 .49482 L .67088 .49336 L F
.599 .582 .805 r
.67359 .49625 m .67144 .49482 L .67342 .49425 L F
.468 .333 .614 r
.37314 .68259 m .3744 .68496 L .37247 .68505 L F
.536 .402 .645 r
.37621 .68097 m .3744 .68496 L .37314 .68259 L F
0 .262 .727 r
.54803 .70676 m .54753 .70613 L .54444 .70409 L F
.801 .434 0 r
.54803 .70676 m .5477 .70674 L .54753 .70613 L F
.839 .994 .75 r
.48376 .77195 m .48461 .76984 L .48647 .77161 L F
.513 .811 .999 r
.48684 .77183 m .48376 .77195 L .48647 .77161 L F
.837 .612 .597 r
.61134 .72533 m .61455 .72377 L .61116 .72325 L F
.61134 .72533 m .61464 .7263 L .61455 .72377 L F
.664 .268 .284 r
.64249 .52151 m .64467 .52312 L .64582 .52177 L F
.143 0 0 r
.64582 .52177 m .64678 .52229 L .64808 .52162 L F
.64582 .52177 m .64467 .52312 L .64678 .52229 L F
.339 0 .065 r
.6555 .54176 m .65496 .54287 L .65259 .54334 L F
.333 0 .062 r
.65726 .54217 m .65496 .54287 L .6555 .54176 L F
.176 .684 .902 r
.41402 .66433 m .41297 .66393 L .41048 .66394 L F
.152 .69 .833 r
.41623 .66395 m .41297 .66393 L .41402 .66433 L F
.964 .849 .68 r
.66831 .50676 m .66955 .50805 L .67058 .50518 L F
.889 .909 .834 r
.66962 .50419 m .67058 .50518 L .67277 .50239 L F
.452 .357 .657 r
.76078 .59376 m .75946 .59597 L .75918 .59367 L F
.535 .471 .731 r
.34578 .66885 m .34844 .67064 L .34761 .66745 L F
.34578 .66885 m .34641 .67109 L .34844 .67064 L F
.78 .583 .633 r
.61513 .54993 m .61149 .55129 L .6112 .54922 L F
.61513 .54993 m .61498 .55169 L .61149 .55129 L F
.348 .019 .259 r
.49763 .78948 m .49869 .78736 L .4958 .78957 L F
.652 .334 .421 r
.49763 .78948 m .50092 .78953 L .49869 .78736 L F
0 0 0 r
.38159 .674 m .38059 .67557 L .37881 .67628 L F
.38417 .67343 m .38059 .67557 L .38159 .674 L F
.805 .436 .358 r
.51925 .71195 m .5212 .71468 L .52251 .71291 L F
.749 .361 .318 r
.5212 .71468 m .52438 .71517 L .52251 .71291 L F
.474 .417 .712 r
.3744 .68496 m .37481 .68688 L .37247 .68505 L F
.524 .414 .67 r
.37247 .68505 m .37481 .68688 L .37278 .68712 L F
.508 .385 .647 r
.34641 .67109 m .34874 .67304 L .34844 .67064 L F
.34641 .67109 m .34666 .67351 L .34874 .67304 L F
.569 .634 .877 r
.60147 .75547 m .60268 .75326 L .6002 .75379 L F
.60147 .75547 m .60351 .75496 L .60268 .75326 L F
.708 .555 .679 r
.72463 .60769 m .71899 .60846 L .7211 .60792 L F
.783 .707 .78 r
.72463 .60769 m .7211 .60792 L .72303 .60372 L F
.72463 .60769 m .72303 .60372 L .72443 .60732 L F
.632 .27 .339 r
.72443 .60732 m .72093 .60892 L .72463 .60769 L F
.116 .067 .52 r
.5845 .7072 m .58637 .70836 L .58594 .70592 L F
.5845 .7072 m .58483 .70952 L .58637 .70836 L F
.636 .788 .955 r
.63461 .49613 m .63411 .49687 L .63073 .49637 L F
.215 .658 .951 r
.63461 .49613 m .63577 .49636 L .63411 .49687 L F
.407 .373 .709 r
.6479 .49836 m .64586 .49996 L .64639 .49916 L F
.573 .5 .735 r
.64903 .50147 m .64586 .49996 L .6479 .49836 L F
.64903 .50147 m .64676 .50218 L .64586 .49996 L F
.702 .292 0 r
.5803 .73705 m .57856 .73404 L .57905 .73537 L F
.966 .789 .613 r
.6693 .51066 m .66955 .51346 L .66833 .51252 L F
.969 .66 .375 r
.66955 .51346 m .66862 .51472 L .66833 .51252 L F
.997 .789 .438 r
.66955 .51346 m .66943 .51591 L .66862 .51472 L F
0 0 0 r
.53782 .79899 m .53861 .79869 L .54082 .79819 L F
0 .506 .842 r
.55102 .72639 m .5513 .72693 L .54892 .72624 L F
.55102 .72639 m .54892 .72624 L .54755 .72616 L F
.571 .317 .492 r
.46184 .6736 m .4593 .67579 L .4596 .67397 L F
.441 .874 .906 r
.73199 .61785 m .73068 .6183 L .73058 .61793 L F
0 0 .401 r
.73058 .61793 m .73134 .61926 L .73049 .61757 L F
.772 .718 .802 r
.73031 .61414 m .73058 .61793 L .72801 .61662 L F
0 0 .401 r
.73058 .61793 m .73049 .61757 L .73034 .61727 L F
.441 .874 .906 r
.73068 .6183 m .72988 .61858 L .73058 .61793 L F
.047 0 .446 r
.72988 .61858 m .73134 .61926 L .73058 .61793 L F
.72988 .61858 m .72994 .621 L .73134 .61926 L F
.889 .909 .834 r
.66962 .50419 m .67277 .50239 L .6717 .5014 L F
.561 .756 .969 r
.67277 .50239 m .67397 .50063 L .6717 .5014 L F
.67277 .50239 m .67537 .50205 L .67397 .50063 L F
.412 .099 .321 r
.48734 .73716 m .48948 .7365 L .49009 .73489 L F
.408 .153 .413 r
.48948 .7365 m .49192 .73406 L .49009 .73489 L F
.301 .609 .954 r
.32595 .59483 m .32771 .59502 L .32717 .59619 L F
.381 .704 .985 r
.32771 .59502 m .32905 .59612 L .32717 .59619 L F
.538 .349 .572 r
.44649 .75977 m .44877 .76172 L .4487 .75931 L F
.44649 .75977 m .44637 .76221 L .44877 .76172 L F
.612 .872 .991 r
.26744 .64284 m .26544 .64365 L .26591 .64219 L F
.545 .807 .994 r
.26591 .64219 m .26544 .64365 L .26386 .64268 L F
.575 .174 .245 r
.48567 .75825 m .48761 .75881 L .48875 .75669 L F
.714 .545 0 r
.48875 .75669 m .4888 .75775 L .48855 .75367 L F
.693 .304 .306 r
.48875 .75669 m .48761 .75881 L .49105 .75891 L F
.48875 .75669 m .49105 .75891 L .4888 .75775 L F
.717 .884 .958 r
.40738 .66411 m .4085 .66477 L .41048 .66394 L F
.665 .124 0 r
.54061 .7205 m .54403 .72335 L .5415 .72151 L F
.574 .302 .465 r
.46459 .67135 m .46425 .67336 L .46184 .6736 L F
.135 0 .223 r
.68281 .51048 m .68445 .51109 L .68218 .50942 L F
.68281 .51048 m .68232 .51232 L .68445 .51109 L F
.963 .832 .666 r
.59579 .6989 m .59444 .69822 L .59559 .6954 L F
.92 .702 .592 r
.59579 .6989 m .59387 .70067 L .59444 .69822 L F
.59579 .6989 m .59555 .70159 L .59387 .70067 L F
.448 .426 .741 r
.68773 .5094 m .68547 .51099 L .68514 .50765 L F
.389 .363 .709 r
.68773 .5094 m .68658 .51321 L .68547 .51099 L F
.713 .357 0 r
.50216 .79235 m .50148 .79064 L .50092 .78953 L F
.755 .698 .797 r
.33664 .72091 m .34005 .72135 L .33855 .71962 L F
.692 .685 .839 r
.33855 .71962 m .34005 .72135 L .3424 .72009 L F
.511 .152 .293 r
.47404 .74504 m .47747 .74266 L .47448 .74357 L F
.485 .224 .443 r
.41532 .70314 m .41355 .70157 L .41564 .7011 L F
.41532 .70314 m .41317 .70359 L .41355 .70157 L F
.718 .39 .424 r
.51167 .79464 m .51117 .79307 L .50777 .79321 L F
.731 .462 .521 r
.51509 .7955 m .51117 .79307 L .51167 .79464 L F
.41 .648 .955 r
.75431 .58555 m .75141 .58417 L .75367 .58407 L F
.441 .624 .93 r
.75576 .58408 m .75431 .58555 L .75367 .58407 L F
.457 .65 .942 r
.7566 .58556 m .75431 .58555 L .75576 .58408 L F
.772 .268 0 r
.55965 .71295 m .55923 .71395 L .55721 .71173 L F
.866 .419 .057 r
.56029 .71449 m .55923 .71395 L .55965 .71295 L F
.379 .247 .572 r
.75214 .60856 m .75545 .6089 L .75531 .60626 L F
.379 .113 .38 r
.75214 .60856 m .75289 .6115 L .75545 .6089 L F
.609 .569 .784 r
.5468 .74803 m .54555 .75187 L .54456 .74902 L F
.5468 .74803 m .54852 .75178 L .54555 .75187 L F
.604 .427 .614 r
.52971 .74785 m .52669 .74574 L .5297 .74563 L F
.52971 .74785 m .52719 .74822 L .52669 .74574 L F
.899 .973 .814 r
.59089 .73483 m .59021 .73387 L .59205 .73348 L F
.59089 .73483 m .59 .73408 L .59021 .73387 L F
.271 0 0 r
.39037 .71322 m .38645 .71529 L .38721 .71476 L F
.39037 .71322 m .38877 .71485 L .38645 .71529 L F
0 0 0 r
.39064 .71394 m .39037 .71322 L .39206 .71234 L F
.39064 .71394 m .38877 .71485 L .39037 .71322 L F
.585 .125 .127 r
.63607 .55052 m .63372 .5492 L .63729 .54919 L F
.563 .075 .055 r
.63729 .54919 m .63848 .55083 L .63607 .55052 L F
.63729 .54919 m .63955 .54956 L .63848 .55083 L F
.571 .125 .153 r
.64972 .50338 m .64676 .50218 L .64903 .50147 L F
.64972 .50338 m .64558 .5037 L .64676 .50218 L F
.405 0 0 r
.46698 .78958 m .47006 .79066 L .46869 .79033 L F
.621 .095 0 r
.47305 .79182 m .46869 .79033 L .47006 .79066 L F
.354 .677 .977 r
.29823 .59152 m .29776 .59265 L .29595 .59127 L F
.29823 .59152 m .29963 .59275 L .29776 .59265 L F
.41 .132 .378 r
.33673 .61573 m .33935 .61266 L .33866 .61509 L F
.407 .18 .454 r
.33935 .61266 m .34163 .61023 L .34121 .61269 L F
.337 .046 .315 r
.33866 .61509 m .33935 .61266 L .34121 .61269 L F
.511 .152 .293 r
.47404 .74504 m .47633 .74492 L .47747 .74266 L F
.36 .002 .214 r
.47747 .74266 m .47845 .74438 L .47976 .74274 L F
.47747 .74266 m .47633 .74492 L .47845 .74438 L F
.498 .379 .648 r
.34528 .67942 m .34554 .68181 L .34745 .6813 L F
.431 .377 .697 r
.34528 .67942 m .34745 .6813 L .34698 .67899 L F
.602 .595 .816 r
.71963 .60345 m .71899 .60846 L .71742 .60386 L F
.71963 .60345 m .7211 .60792 L .71899 .60846 L F
.612 .597 .811 r
.6759 .49387 m .67359 .49625 L .67342 .49425 L F
.6759 .49387 m .67676 .49664 L .67359 .49625 L F
.251 .762 .773 r
.25216 .58613 m .25361 .58573 L .25555 .58542 L F
.212 0 0 r
.25244 .58641 m .25467 .58543 L .25361 .58573 L F
.25467 .58543 m .25634 .58469 L .25361 .58573 L F
.251 .762 .773 r
.25151 .58627 m .25361 .58573 L .25216 .58613 L F
.458 .887 .855 r
.25555 .58542 m .25634 .58469 L .25754 .5843 L F
.476 .879 .723 r
.73899 .61329 m .73797 .61413 L .73658 .61417 L F
.73899 .61329 m .74004 .61289 L .73797 .61413 L F
.898 .505 .266 r
.54444 .70409 m .5429 .70354 L .54226 .70186 L F
.676 .132 0 r
.54753 .70613 m .5429 .70354 L .54444 .70409 L F
.746 .63 .731 r
.49602 .76245 m .49374 .76528 L .4926 .7616 L F
.49602 .76245 m .4926 .7616 L .49484 .76351 L F
.593 .412 .606 r
.49602 .76245 m .4961 .76488 L .49374 .76528 L F
.123 .451 .884 r
.49513 .7611 m .49602 .76245 L .49684 .76163 L F
.503 .833 .538 r
.49602 .76245 m .49484 .76351 L .49684 .76163 L F
.525 .359 .599 r
.49828 .76449 m .4961 .76488 L .49602 .76245 L F
.959 .622 .305 r
.59575 .70786 m .5948 .70861 L .59421 .70635 L F
.786 .307 .09 r
.59575 .70786 m .59682 .70935 L .5948 .70861 L F
.406 0 0 r
.55617 .71056 m .55297 .71105 L .55314 .70995 L F
.55617 .71056 m .55543 .71134 L .55297 .71105 L F
.72 .203 0 r
.55721 .71173 m .55543 .71134 L .55617 .71056 L F
.122 0 .325 r
.38583 .67063 m .38417 .67343 L .38381 .67106 L F
.081 0 0 r
.30437 .6498 m .30399 .64896 L .30595 .64832 L F
.30437 .6498 m .30236 .65049 L .30399 .64896 L F
.681 .607 .766 r
.71424 .59685 m .71387 .59825 L .71232 .59556 L F
.743 .477 .528 r
.50734 .76233 m .50924 .76472 L .51121 .76433 L F
.423 0 0 r
.50924 .76472 m .51297 .76475 L .51121 .76433 L F
.636 .647 .844 r
.50391 .75959 m .50215 .75617 L .50474 .7585 L F
.004 0 .082 r
.50623 .75688 m .50391 .75959 L .50474 .7585 L F
.415 .191 .462 r
.35236 .65962 m .34999 .66241 L .35207 .66245 L F
.418 .141 .382 r
.35207 .66245 m .34999 .66241 L .34956 .66458 L F
.429 .441 .77 r
.58744 .75369 m .58788 .75073 L .58555 .75103 L F
.58744 .75369 m .58866 .75464 L .58788 .75073 L F
.34 .757 .978 r
.43085 .65212 m .43298 .652 L .4343 .65268 L F
.361 .72 .987 r
.43512 .65163 m .4343 .65268 L .43298 .652 L F
.43512 .65163 m .43662 .65259 L .4343 .65268 L F
.802 .63 .669 r
.49525 .79158 m .49763 .78948 L .4958 .78957 L F
.768 .596 .666 r
.5326 .74055 m .53201 .74296 L .53159 .73918 L F
.697 .524 .65 r
.53438 .74273 m .53201 .74296 L .5326 .74055 L F
.477 .164 .357 r
.52482 .74892 m .52417 .75135 L .52214 .75117 L F
.386 .082 .323 r
.52642 .75037 m .52482 .74892 L .52719 .74822 L F
.52642 .75037 m .52538 .75083 L .52482 .74892 L F
.463 .412 .716 r
.52642 .75037 m .5246 .75265 L .52448 .7523 L F
.52538 .75083 m .52448 .7523 L .52417 .75135 L F
.52642 .75037 m .52448 .7523 L .52538 .75083 L F
.451 .427 .741 r
.52553 .75066 m .52611 .75077 L .5265 .74897 L F
.5256 .75046 m .5265 .74897 L .52716 .74595 L F
.52553 .75066 m .5265 .74897 L .5256 .75046 L F
.657 .522 .688 r
.52838 .75012 m .52766 .75113 L .52642 .75037 L F
.52766 .75113 m .52648 .7528 L .52644 .75085 L F
.52766 .75113 m .52644 .75085 L .52642 .75037 L F
.451 .427 .741 r
.52611 .75077 m .52756 .75107 L .52753 .75067 L F
.463 .412 .716 r
.52642 .75037 m .52648 .7528 L .5246 .75265 L F
0 0 0 r
.52588 .75073 m .52683 .75081 L .52756 .75107 L F
.52553 .75066 m .52561 .75066 L .52588 .75073 L F
.52561 .75066 m .52683 .75081 L .52588 .75073 L F
.63 .28 .359 r
.52838 .75012 m .52719 .74822 L .52971 .74785 L F
.52838 .75012 m .52642 .75037 L .52719 .74822 L F
.451 .427 .741 r
.52611 .75077 m .52753 .75067 L .52716 .74595 L F
.386 .082 .323 r
.52538 .75083 m .52417 .75135 L .52429 .7509 L F
.52538 .75083 m .52429 .7509 L .52482 .74892 L F
.532 .563 .832 r
.49521 .78367 m .49617 .7813 L .4939 .78247 L F
.311 0 .249 r
.30725 .62403 m .30454 .62649 L .30645 .62581 L F
.402 .158 .426 r
.30645 .62581 m .30863 .62336 L .30725 .62403 L F
.865 .419 .115 r
.56945 .74297 m .57199 .74693 L .5724 .74616 L F
.862 .414 .046 r
.57199 .7471 m .5724 .74616 L .57199 .74693 L F
.57199 .7471 m .5733 .74799 L .5724 .74616 L F
.493 .371 .642 r
.6828 .52343 m .68387 .52644 L .68103 .52719 L F
.668 .405 .513 r
.68387 .52644 m .68007 .52849 L .68103 .52719 L F
.483 .379 .661 r
.44537 .76787 m .44762 .77012 L .44728 .76746 L F
.44537 .76787 m .44546 .77083 L .44762 .77012 L F
.934 .632 .446 r
.59617 .67821 m .59765 .67673 L .5946 .6761 L F
.59617 .67821 m .59782 .67898 L .59765 .67673 L F
.392 .851 .862 r
.26944 .65556 m .27348 .65466 L .27163 .65487 L F
.181 .715 .784 r
.27348 .65466 m .27375 .65444 L .27163 .65487 L F
.27348 .65466 m .27562 .65432 L .27375 .65444 L F
.602 .514 .728 r
.75953 .59824 m .76037 .60153 L .75792 .60196 L F
.575 .396 .601 r
.76037 .60153 m .75815 .60445 L .75792 .60196 L F
.472 .012 .08 r
.47933 .78311 m .48133 .78342 L .48261 .78169 L F
.409 .77 .995 r
.48356 .78062 m .48493 .7814 L .48261 .78169 L F
0 0 0 r
.48261 .78169 m .48133 .78342 L .48356 .78062 L F
.315 .451 .839 r
.48341 .78246 m .48261 .78169 L .48493 .7814 L F
.58 .875 .994 r
.28011 .65237 m .27889 .65385 L .28154 .6532 L F
.28011 .65237 m .27745 .65328 L .27889 .65385 L F
.222 0 0 r
.53563 .76194 m .5335 .76253 L .53222 .76424 L F
.477 0 0 r
.47328 .78191 m .47552 .78298 L .47645 .78275 L F
.366 .801 .963 r
.47552 .78298 m .47933 .78311 L .47645 .78275 L F
.527 .263 .458 r
.44387 .6821 m .44378 .68393 L .44152 .68392 L F
.531 .256 .443 r
.44613 .68189 m .44378 .68393 L .44387 .6821 L F
.659 .385 .493 r
.62509 .55411 m .62506 .55418 L .62248 .55365 L F
.616 .29 .396 r
.62353 .5539 m .6191 .55589 L .61971 .55475 L F
.62356 .55391 m .6191 .55589 L .62353 .5539 L F
.62348 .55383 m .61971 .55475 L .62063 .55303 L F
.62365 .55387 m .61971 .55475 L .62348 .55383 L F
.608 .336 .479 r
.62356 .55391 m .61917 .55835 L .6191 .55589 L F
.629 .221 .252 r
.62506 .55418 m .62497 .55461 L .62341 .55384 L F
.608 .336 .479 r
.62365 .55387 m .62361 .55391 L .62356 .55391 L F
.62361 .55391 m .61917 .55835 L .62356 .55391 L F
.629 .221 .252 r
.62341 .55384 m .62349 .55392 L .62248 .55365 L F
.608 .336 .479 r
.62365 .55387 m .62161 .5584 L .61917 .55835 L F
.465 .172 .384 r
.62486 .55518 m .62161 .5584 L .62363 .55392 L F
.629 .221 .252 r
.62497 .55461 m .62486 .55518 L .62368 .55398 L F
.465 .172 .384 r
.62486 .55518 m .62363 .55392 L .62365 .55387 L F
.629 .221 .252 r
.62368 .55398 m .62486 .55518 L .62341 .55384 L F
.62349 .55392 m .62486 .55518 L .62294 .55394 L F
.62349 .55392 m .62294 .55394 L .62248 .55365 L F
.616 .29 .396 r
.62365 .55387 m .62356 .55391 L .62353 .5539 L F
.62348 .55383 m .62063 .55303 L .62248 .55365 L F
.659 .385 .493 r
.62615 .55147 m .62539 .55336 L .62248 .55365 L F
.62539 .55336 m .62509 .55411 L .62348 .55383 L F
.62539 .55336 m .62348 .55383 L .62248 .55365 L F
.616 .29 .396 r
.62365 .55387 m .62348 .55383 L .62248 .55365 L F
.629 .305 .403 r
.62324 .5514 m .62248 .55365 L .62026 .5519 L F
.659 .385 .493 r
.62615 .55147 m .62248 .55365 L .62324 .5514 L F
.569 .736 .954 r
.73933 .62281 m .74233 .62377 L .7413 .62277 L F
.711 .864 .954 r
.7413 .62277 m .74233 .62377 L .74461 .62259 L F
.773 .645 .721 r
.4926 .7616 m .49374 .76528 L .49036 .76501 L F
.769 .665 .748 r
.49374 .76528 m .49166 .76798 L .49036 .76501 L F
.665 .512 .668 r
.49374 .76528 m .49412 .76812 L .49166 .76798 L F
.524 .369 .612 r
.4961 .76488 m .49412 .76812 L .49374 .76528 L F
.684 .727 .883 r
.58258 .71292 m .58633 .71325 L .58489 .71141 L F
.641 .712 .899 r
.58489 .71141 m .58633 .71325 L .58829 .7123 L F
.772 .421 .391 r
.50433 .79512 m .50551 .79291 L .50216 .79235 L F
.593 .216 .297 r
.50787 .79435 m .50551 .79291 L .50433 .79512 L F
.592 .22 .306 r
.50787 .79435 m .50777 .79321 L .50551 .79291 L F
.874 .545 .424 r
.56174 .70606 m .56451 .70897 L .56445 .70783 L F
.382 0 .156 r
.48415 .76866 m .48461 .76984 L .48242 .77022 L F
.77 .544 .591 r
.48816 .76771 m .48461 .76984 L .48415 .76866 L F
.576 .201 .294 r
.75584 .61848 m .75485 .62064 L .75329 .61998 L F
.717 .354 .359 r
.75848 .62062 m .75584 .61848 L .75834 .61821 L F
.75848 .62062 m .75485 .62064 L .75584 .61848 L F
.471 .37 .659 r
.34912 .72409 m .35016 .71914 L .34793 .72061 L F
.34912 .72409 m .35111 .72405 L .35016 .71914 L F
.47 .359 .646 r
.34912 .72409 m .35125 .72575 L .35111 .72405 L F
.494 .188 .376 r
.43866 .68539 m .43821 .68715 L .43598 .68745 L F
.463 .151 .351 r
.44152 .68392 m .43821 .68715 L .43866 .68539 L F
.399 .154 .422 r
.25918 .61564 m .25875 .61763 L .25681 .61844 L F
.482 .228 .451 r
.26087 .61706 m .25918 .61564 L .26116 .61515 L F
.26087 .61706 m .25875 .61763 L .25918 .61564 L F
.319 .778 .948 r
.31457 .59437 m .3164 .59415 L .31788 .59467 L F
.275 .75 .936 r
.3164 .59415 m .32014 .59446 L .31788 .59467 L F
0 0 .386 r
.64358 .51803 m .64249 .52151 L .64127 .51886 L F
.64358 .51803 m .64364 .52022 L .64249 .52151 L F
.247 .363 .785 r
.64364 .52022 m .64467 .52312 L .64249 .52151 L F
0 0 0 r
.34898 .71003 m .35033 .70691 L .34828 .70677 L F
.34898 .71003 m .34947 .70939 L .35033 .70691 L F
.241 .709 .944 r
.34974 .70955 m .34947 .70939 L .34898 .71003 L F
.805 .562 .571 r
.60939 .71819 m .60627 .71546 L .60689 .71725 L F
.962 .684 .462 r
.60794 .71936 m .60939 .71819 L .60689 .71725 L F
.60794 .71936 m .60955 .72045 L .60939 .71819 L F
.83 .394 .2 r
.71032 .59257 m .71198 .59512 L .71271 .59354 L F
.543 .923 .918 r
.71271 .59354 m .71416 .59224 L .71535 .59219 L F
.83 .606 .599 r
.71271 .59354 m .71424 .59685 L .71232 .59556 L F
0 0 0 r
.71271 .59354 m .71198 .59512 L .71416 .59224 L F
.844 .913 .881 r
.65038 .52109 m .65268 .52055 L .65277 .51828 L F
.65038 .52109 m .65277 .51828 L .65205 .51987 L F
.549 .394 .624 r
.64808 .52162 m .65205 .51987 L .6474 .51867 L F
.64808 .52162 m .65038 .52109 L .65205 .51987 L F
.825 .912 .898 r
.64678 .52229 m .65038 .52109 L .64808 .52162 L F
.392 .049 .259 r
.41049 .69203 m .4133 .69011 L .41103 .69036 L F
.57 .53 .771 r
.58855 .7309 m .58683 .73455 L .58664 .73211 L F
.142 0 0 r
.51375 .77176 m .51669 .77161 L .51414 .77195 L F
.51375 .77176 m .51772 .77067 L .51669 .77161 L F
.416 .081 .286 r
.27318 .60846 m .27101 .60911 L .27171 .6076 L F
.472 .01 .075 r
.2741 .60772 m .27318 .60846 L .27171 .6076 L F
.89 .574 .445 r
.59832 .68101 m .59968 .67933 L .59782 .67898 L F
.59832 .68101 m .60045 .68145 L .59968 .67933 L F
.871 .807 .784 r
.62453 .50731 m .62528 .51036 L .62374 .50927 L F
.915 .721 .626 r
.62528 .51036 m .62278 .51221 L .62374 .50927 L F
.62528 .51036 m .62448 .51324 L .62278 .51221 L F
.631 .665 .865 r
.62901 .50814 m .62528 .51036 L .62453 .50731 L F
.524 .759 .982 r
.44453 .77935 m .44704 .77918 L .44396 .7786 L F
0 0 .098 r
.6197 .73733 m .62 .73702 L .61965 .73937 L F
.581 .353 .535 r
.42109 .68466 m .42343 .68447 L .42368 .68218 L F
.536 .323 .538 r
.42343 .68447 m .42578 .68175 L .42368 .68218 L F
.856 .572 .038 r
.70674 .59927 m .70673 .6009 L .70598 .59866 L F
0 0 .495 r
.70666 .59972 m .70598 .59866 L .70673 .6009 L F
0 0 .524 r
.7054 .59777 m .70674 .59927 L .70598 .59866 L F
0 0 .495 r
.70651 .59732 m .70598 .59866 L .70666 .59972 L F
0 0 .524 r
.70439 .59663 m .7054 .59777 L .70598 .59866 L F
.856 .572 .038 r
.70674 .59927 m .70725 .60186 L .70673 .6009 L F
.25 0 .16 r
.66549 .53773 m .66266 .53999 L .66344 .53855 L F
.462 .538 .849 r
.37805 .69197 m .37757 .69493 L .37659 .69437 L F
.37805 .69197 m .37938 .69475 L .37757 .69493 L F
.745 .684 .792 r
.4641 .66859 m .46064 .66834 L .46286 .66769 L F
.651 .815 .962 r
.46668 .66808 m .4641 .66859 L .46286 .66769 L F
.46668 .66808 m .4641 .66859 L .46286 .66769 L F
.243 .692 .955 r
.40134 .649 m .40332 .64907 L .40475 .64981 L F
.328 .758 .972 r
.40332 .64907 m .40724 .64955 L .40475 .64981 L F
.558 .306 .49 r
.45409 .67666 m .45388 .67876 L .45156 .679 L F
.623 .374 .52 r
.45642 .67652 m .45388 .67876 L .45409 .67666 L F
.753 .658 .756 r
.49036 .76501 m .49166 .76798 L .48816 .76771 L F
.767 .552 .606 r
.49166 .76798 m .48816 .77019 L .48816 .76771 L F
.49166 .76798 m .49132 .77045 L .48816 .77019 L F
.518 .324 .557 r
.49343 .76992 m .49132 .77045 L .49166 .76798 L F
.638 .327 .428 r
.49412 .76812 m .49343 .76992 L .49166 .76798 L F
.527 .471 .736 r
.31332 .61321 m .31457 .60953 L .31247 .61001 L F
.31332 .61321 m .31529 .61267 L .31457 .60953 L F
.523 .453 .719 r
.31332 .61321 m .31589 .61519 L .31529 .61267 L F
.519 .453 .722 r
.31332 .61321 m .31406 .61597 L .31589 .61519 L F
.664 .251 .252 r
.62646 .51589 m .6288 .51763 L .63017 .51622 L F
.116 .024 .465 r
.63065 .51732 m .62992 .51869 L .63017 .51622 L F
.63065 .51732 m .63017 .51622 L .6288 .51763 L F
.409 .447 .789 r
.3311 .70705 m .33203 .70741 L .33289 .70652 L F
.928 .731 .616 r
.49617 .7813 m .49753 .78436 L .49791 .78186 L F
.577 .239 .361 r
.72648 .59293 m .72858 .59252 L .72946 .59029 L F
.609 .326 .462 r
.72858 .59252 m .73186 .59012 L .72946 .59029 L F
.901 .846 .78 r
.61874 .53266 m .61567 .53455 L .61732 .5315 L F
.61874 .53266 m .61696 .53554 L .61567 .53455 L F
.918 .67 .547 r
.66369 .50423 m .6653 .50503 L .66521 .50665 L F
.429 .068 .248 r
.41317 .70359 m .40992 .7061 L .41103 .70416 L F
.583 .306 .462 r
.51383 .75433 m .51159 .75661 L .51186 .75392 L F
.728 .75 .87 r
.34439 .72027 m .34635 .72199 L .34793 .72061 L F
.614 .279 .379 r
.53593 .7672 m .53689 .76526 L .53907 .76706 L F
.597 .287 .414 r
.53689 .76526 m .53943 .76532 L .53907 .76706 L F
.902 .8 .737 r
.68677 .52712 m .68512 .52662 L .68587 .52431 L F
.895 .508 .063 r
.68675 .5295 m .68512 .52662 L .68677 .52712 L F
0 0 0 r
.68767 .52492 m .68677 .52712 L .68754 .52484 L F
.327 .458 .84 r
.68807 .52547 m .68677 .52712 L .68587 .52431 L F
.879 .906 .844 r
.68807 .52547 m .68676 .52947 L .68677 .52712 L F
.68676 .52947 m .68675 .52947 L .68677 .52712 L F
.895 .508 .063 r
.68574 .52772 m .6857 .5284 L .68512 .52662 L F
.68675 .5295 m .6857 .5284 L .68574 .52772 L F
.879 .906 .844 r
.68676 .52947 m .68675 .5295 L .68675 .52947 L F
.68807 .52547 m .6857 .5284 L .68675 .5295 L F
.501 .348 .605 r
.6857 .5284 m .68813 .53002 L .68818 .53006 L F
.6857 .5284 m .68818 .53006 L .68752 .52979 L F
.957 .66 .229 r
.68688 .53177 m .6857 .5284 L .68675 .5295 L F
.501 .348 .605 r
.6857 .5284 m .68933 .53116 L .68675 .5295 L F
.957 .66 .229 r
.68688 .53177 m .68615 .53125 L .6857 .5284 L F
.507 .329 .573 r
.68675 .5295 m .68933 .53116 L .68688 .53177 L F
.501 .348 .605 r
.6857 .5284 m .68615 .53125 L .68813 .53002 L F
.619 .558 .764 r
.68903 .5266 m .68869 .5279 L .68716 .52688 L F
.68869 .5279 m .68813 .53002 L .68762 .52835 L F
.68869 .5279 m .68762 .52835 L .68716 .52688 L F
.229 0 .024 r
.68793 .52839 m .68716 .52688 L .68762 .52835 L F
.68793 .52839 m .68762 .52835 L .68813 .53002 L F
.68793 .52839 m .68561 .5298 L .68565 .52919 L F
.68753 .52839 m .68565 .52919 L .6857 .5284 L F
.68793 .52839 m .68565 .52919 L .68753 .52839 L F
.68561 .5298 m .68506 .53013 L .6857 .5284 L F
.501 .348 .605 r
.68752 .52979 m .68818 .53006 L .68933 .53116 L F
.722 .626 .75 r
.52332 .76749 m .51984 .76796 L .52208 .76466 L F
.658 .392 .506 r
.52332 .76749 m .51986 .77019 L .51984 .76796 L F
.52332 .76749 m .52356 .77022 L .51986 .77019 L F
.638 .377 .507 r
.52552 .76994 m .52332 .76749 L .52557 .7678 L F
.52552 .76994 m .52356 .77022 L .52332 .76749 L F
.863 .731 .716 r
.60518 .71205 m .60627 .71546 L .60688 .71306 L F
.608 .607 .825 r
.67244 .491 m .67088 .49336 L .67008 .49145 L F
.67244 .491 m .67342 .49425 L .67088 .49336 L F
.737 .418 .441 r
.51001 .72041 m .5097 .72224 L .50686 .72234 L F
.717 .474 .558 r
.51268 .72032 m .5097 .72224 L .51001 .72041 L F
.716 .464 .543 r
.6112 .54922 m .60766 .55132 L .60919 .54845 L F
.6112 .54922 m .61149 .55129 L .60766 .55132 L F
.039 .398 .854 r
.54929 .69838 m .55149 .70049 L .55091 .69835 L F
.54929 .69838 m .55113 .6992 L .55149 .70049 L F
.683 .406 0 r
.55149 .70049 m .55169 .70125 L .55152 .70062 L F
.55149 .70049 m .55152 .70062 L .55091 .69835 L F
.039 .398 .854 r
.55113 .6992 m .55164 .69942 L .55149 .70049 L F
.882 .461 .053 r
.5514 .70018 m .55149 .70049 L .55164 .69942 L F
.551 .70149 m .55149 .70049 L .5514 .70018 L F
.683 .406 0 r
.55149 .70049 m .55183 .70176 L .55169 .70125 L F
.858 .48 .331 r
.55149 .70049 m .5542 .70326 L .55183 .70176 L F
.525 .684 .939 r
.38148 .69451 m .38057 .69626 L .37938 .69475 L F
.391 .517 .865 r
.38148 .69451 m .383 .69737 L .38057 .69626 L F
.446 .228 .488 r
.35403 .66166 m .35236 .65962 L .35207 .66245 L F
.35403 .66166 m .35419 .65935 L .35236 .65962 L F
.717 .884 .958 r
.40738 .66411 m .41048 .66394 L .40942 .66339 L F
.293 .704 .974 r
.41048 .66394 m .41246 .6633 L .40942 .66339 L F
.41048 .66394 m .41297 .66393 L .41246 .6633 L F
.873 .867 .829 r
.5811 .6767 m .57908 .67922 L .57763 .67863 L F
.788 .378 .274 r
.57908 .67922 m .57794 .68086 L .57763 .67863 L F
.57908 .67922 m .58122 .68181 L .57794 .68086 L F
.001 .385 .844 r
.38671 .70004 m .38819 .70075 L .38752 .70124 L F
.178 .655 .93 r
.38752 .70124 m .38819 .70075 L .38984 .70151 L F
.438 .129 .342 r
.40759 .69512 m .41049 .69203 L .40846 .69264 L F
.251 0 0 r
.24882 .58721 m .25151 .58627 L .24982 .5863 L F
.501 .247 .461 r
.50147 .7342 m .501 .73703 L .50004 .73744 L F
.563 .436 .665 r
.50329 .73199 m .50354 .73452 L .50147 .7342 L F
.572 .31 .48 r
.50334 .7366 m .50147 .7342 L .50354 .73452 L F
.50334 .7366 m .501 .73703 L .50147 .7342 L F
.563 .436 .665 r
.50329 .73199 m .50354 .73452 L .50147 .7342 L F
.524 .776 .989 r
.57986 .67567 m .5811 .6767 L .57798 .67611 L F
.873 .867 .829 r
.5811 .6767 m .57763 .67863 L .57764 .67604 L F
.877 .85 .813 r
.58322 .67373 m .5811 .6767 L .57986 .67567 L F
.351 0 .128 r
.57907 .67719 m .5819 .67519 L .57986 .67567 L F
.5819 .67519 m .58202 .67511 L .57986 .67567 L F
.524 .776 .989 r
.57986 .67567 m .57798 .67611 L .57764 .67604 L F
.636 .647 .844 r
.50391 .75959 m .50028 .75784 L .50215 .75617 L F
.652 .515 .683 r
.50623 .75688 m .50675 .75979 L .50391 .75959 L F
.724 .367 .373 r
.5015 .79818 m .49978 .80019 L .49957 .79798 L F
.5015 .79818 m .50327 .80041 L .49978 .80019 L F
.783 .765 .837 r
.6638 .49033 m .6645 .49333 L .66128 .49312 L F
.802 .716 .77 r
.6645 .49333 m .66216 .49656 L .66128 .49312 L F
.722 .729 .855 r
.66723 .49071 m .6645 .49333 L .6638 .49033 L F
.877 .85 .813 r
.58322 .67373 m .57986 .67567 L .58202 .67511 L F
.234 0 0 r
.58322 .67373 m .58433 .67462 L .58551 .67338 L F
.58322 .67373 m .58202 .67511 L .58433 .67462 L F
.538 .464 .72 r
.37558 .69066 m .37278 .68712 L .37481 .68688 L F
.37558 .69066 m .37363 .69108 L .37278 .68712 L F
.606 .059 0 r
.47601 .79234 m .47933 .79308 L .47866 .79408 L F
.701 .176 0 r
.47933 .79308 m .47975 .79471 L .47866 .79408 L F
.47933 .79308 m .48155 .79499 L .47975 .79471 L F
.883 .584 .475 r
.60079 .68642 m .60248 .68499 L .60009 .6839 L F
.60079 .68642 m .60261 .68713 L .60248 .68499 L F
.49 .734 .98 r
.71632 .60935 m .71782 .60796 L .71499 .60748 L F
.791 .676 .737 r
.52591 .79788 m .53002 .79848 L .52943 .79685 L F
.781 .449 .426 r
.52968 .80058 m .53002 .79848 L .52591 .79788 L F
.477 .5 .803 r
.53179 .79796 m .53002 .79848 L .52943 .79685 L F
.623 .446 .622 r
.53264 .80161 m .53002 .79848 L .53179 .79796 L F
.53264 .80161 m .53063 .80309 L .53057 .80263 L F
.53264 .80161 m .53057 .80263 L .53002 .79848 L F
.71 .658 .797 r
.53264 .80161 m .53508 .80073 L .53447 .80071 L F
.53264 .80161 m .53447 .80071 L .53143 .80062 L F
.305 .027 .317 r
.53179 .79796 m .53002 .79848 L .52968 .80058 L F
.477 .5 .803 r
.52943 .79685 m .53002 .79848 L .53179 .79796 L F
.2 0 0 r
.32216 .59425 m .32595 .59483 L .32425 .59516 L F
.438 .473 .799 r
.37805 .69197 m .37659 .69437 L .37558 .69066 L F
.101 0 0 r
.63587 .51162 m .63354 .51238 L .6347 .51134 L F
.583 .306 .462 r
.51383 .75433 m .51403 .75646 L .51159 .75661 L F
.634 .343 .459 r
.51625 .75601 m .51403 .75646 L .51383 .75433 L F
.178 0 .064 r
.31406 .61597 m .31316 .61734 L .31589 .61519 L F
.74 .677 .789 r
.68094 .5156 m .68429 .51603 L .68232 .51232 L F
.529 .113 .195 r
.68099 .51769 m .68429 .51603 L .68094 .5156 L F
.68099 .51769 m .68346 .51777 L .68429 .51603 L F
0 0 0 r
.68658 .51321 m .68544 .51465 L .68429 .51603 L F
.295 .445 .841 r
.68429 .51603 m .68544 .51465 L .68232 .51232 L F
.222 0 .058 r
.68429 .51603 m .68346 .51777 L .687 .51611 L F
0 .455 .751 r
.51155 .77129 m .51414 .77195 L .51308 .77154 L F
.506 .09 .185 r
.73429 .59017 m .73683 .59008 L .73741 .58864 L F
.459 .045 .166 r
.73741 .58864 m .73683 .59008 L .73987 .58918 L F
.903 .741 .671 r
.59217 .72206 m .59226 .72419 L .59281 .71996 L F
.749 .625 .722 r
.59232 .72219 m .59226 .72419 L .59217 .72206 L F
.953 .792 .645 r
.59281 .71996 m .59226 .72419 L .59233 .72189 L F
.755 .671 .769 r
.5923 .72203 m .59217 .72206 L .59281 .71996 L F
.953 .792 .645 r
.59281 .71996 m .59233 .72189 L .59239 .71999 L F
.755 .671 .769 r
.59662 .72089 m .5923 .72203 L .59281 .71996 L F
.59662 .72089 m .59459 .72402 L .59232 .72219 L F
.5923 .72203 m .59232 .72219 L .59217 .72206 L F
.59662 .72089 m .59232 .72219 L .5923 .72203 L F
.953 .792 .645 r
.59199 .72002 m .59226 .72419 L .59132 .72007 L F
.59239 .71999 m .59232 .72219 L .59199 .72002 L F
.59232 .72219 m .59226 .72419 L .59199 .72002 L F
.749 .625 .722 r
.59459 .72402 m .59226 .72419 L .59232 .72219 L F
.59459 .72402 m .59177 .72702 L .59043 .72689 L F
0 0 .291 r
.3408 .71269 m .34205 .71203 L .34149 .71155 L F
.563 .587 .835 r
.34101 .71516 m .34205 .71203 L .3408 .71269 L F
.287 0 0 r
.26685 .58638 m .26866 .58675 L .27038 .58674 L F
.297 .781 .911 r
.26866 .58675 m .27242 .58666 L .27038 .58674 L F
.657 .272 .303 r
.62063 .55303 m .61647 .55219 L .62026 .5519 L F
.59 .325 .483 r
.62026 .5519 m .62248 .55365 L .62063 .55303 L F
.234 .73 .913 r
.29963 .59275 m .30169 .59263 L .30323 .59299 L F
.218 .72 .907 r
.30323 .59299 m .30169 .59263 L .30528 .5929 L F
.14 0 0 r
.27955 .60515 m .27803 .60661 L .27617 .6071 L F
.279 0 0 r
.28097 .6057 m .27803 .60661 L .27955 .60515 L F
.748 .431 .447 r
.48886 .79498 m .49212 .7954 L .49064 .79765 L F
.69 .358 .409 r
.49212 .7954 m .49429 .7974 L .49064 .79765 L F
.238 .577 .943 r
.33965 .60154 m .33611 .59965 L .33813 .59937 L F
.557 .73 .956 r
.34079 .5997 m .33965 .60154 L .33813 .59937 L F
.34079 .5997 m .34181 .60114 L .33965 .60154 L F
.515 .729 .97 r
.34146 .6016 m .33965 .60154 L .34181 .60114 L F
.48 .192 .398 r
.72462 .71469 m .72764 .71304 L .7244 .71232 L F
.986 .768 .523 r
.65285 .50653 m .6542 .50779 L .65379 .51 L F
.95 .956 .697 r
.57206 .76791 m .57027 .76961 L .57088 .76722 L F
.57206 .76791 m .57042 .77133 L .57027 .76961 L F
.659 .825 .399 r
.57369 .76703 m .57206 .76791 L .57088 .76722 L F
.438 .722 .985 r
.75157 .58229 m .75141 .58417 L .74911 .58311 L F
.75157 .58229 m .75367 .58407 L .75141 .58417 L F
.843 .779 .79 r
.49844 .74241 m .5003 .74301 L .49938 .7406 L F
.888 .597 .489 r
.49844 .74241 m .49886 .74494 L .5003 .74301 L F
.563 .631 .877 r
.49938 .7406 m .5003 .74301 L .50249 .74253 L F
.654 .277 .318 r
.5003 .74301 m .50245 .74493 L .50249 .74253 L F
.5003 .74301 m .49886 .74494 L .50245 .74493 L F
.915 .934 .807 r
.61262 .54187 m .61274 .53947 L .61396 .54051 L F
.61262 .54187 m .61065 .54231 L .61274 .53947 L F
.76 .86 .923 r
.65133 .50378 m .65018 .50484 L .64972 .50338 L F
0 .208 .645 r
.65018 .50484 m .65151 .50557 L .64972 .50338 L F
.65018 .50484 m .65285 .50653 L .65151 .50557 L F
.347 .1 .39 r
.37809 .67788 m .37621 .68097 L .37689 .67891 L F
.579 .343 .522 r
.25875 .61763 m .25602 .62042 L .25681 .61844 L F
.903 .767 .701 r
.66128 .49312 m .66216 .49656 L .66002 .49509 L F
.996 .813 .456 r
.66216 .49656 m .66103 .49761 L .66002 .49509 L F
.66216 .49656 m .66182 .49915 L .66103 .49761 L F
.443 0 .005 r
.3751 .65033 m .3773 .65041 L .37881 .64907 L F
.268 0 0 r
.3773 .65041 m .381 .64904 L .37881 .64907 L F
.514 .694 .95 r
.74899 .59157 m .75033 .59322 L .75247 .59282 L F
.427 .431 .761 r
.75033 .59322 m .75301 .59518 L .75247 .59282 L F
.56 .077 .067 r
.5513 .72693 m .55349 .72794 L .554 .72674 L F
.868 .442 .199 r
.554 .72674 m .55349 .72794 L .55515 .72844 L F
.253 0 0 r
.74225 .6131 m .74004 .61289 L .73899 .61329 L F
.826 .492 .423 r
.6781 .52761 m .67463 .5282 L .67417 .52654 L F
.6781 .52761 m .67786 .52921 L .67463 .5282 L F
.323 .783 .944 r
.40738 .66411 m .40371 .66396 L .40541 .66424 L F
.801 .587 .613 r
.6082 .7227 m .61142 .72093 L .60955 .72045 L F
.6082 .7227 m .61116 .72325 L .61142 .72093 L F
.581 .371 .561 r
.54921 .7567 m .55173 .75648 L .55151 .75398 L F
.54921 .7567 m .55173 .75648 L .55151 .75398 L F
.556 .416 .646 r
.55151 .75398 m .55424 .75402 L .55323 .7518 L F
.47 .291 .554 r
.55151 .75398 m .55369 .75593 L .55424 .75402 L F
.55369 .75593 m .55151 .75398 L .55271 .75238 L F
.55369 .75593 m .55173 .75648 L .55151 .75398 L F
.55151 .75398 m .55173 .75648 L .55369 .75593 L F
.874 .994 .792 r
.48356 .78062 m .48341 .78246 L .48493 .7814 L F
.48356 .78062 m .48133 .78342 L .48341 .78246 L F
.895 .476 .172 r
.48315 .7857 m .48341 .78246 L .48133 .78342 L F
.48315 .7857 m .48461 .78602 L .48341 .78246 L F
.389 .363 .709 r
.68773 .5094 m .68829 .51409 L .68658 .51321 L F
.039 .388 .849 r
.68829 .51409 m .68889 .51467 L .68658 .51321 L F
.892 .533 .358 r
.68692 .51523 m .68544 .51465 L .68658 .51321 L F
.643 .356 .468 r
.68889 .51467 m .68692 .51523 L .68658 .51321 L F
.68889 .51467 m .68692 .51523 L .68658 .51321 L F
.485 .154 .33 r
.36737 .65388 m .36958 .65361 L .37059 .65109 L F
.398 .071 .29 r
.37059 .65109 m .3717 .65309 L .37284 .6508 L F
.37059 .65109 m .36958 .65361 L .3717 .65309 L F
.742 .544 .627 r
.51041 .73959 m .51413 .73999 L .51286 .73819 L F
.436 .265 .549 r
.34828 .70677 m .35048 .70398 L .34891 .70525 L F
.6 .248 .344 r
.54258 .76477 m .53907 .76706 L .53943 .76532 L F
.54258 .76477 m .54151 .76724 L .53907 .76706 L F
.706 .591 .724 r
.51984 .76796 m .51757 .76808 L .51679 .76474 L F
.499 .28 .513 r
.51984 .76796 m .51772 .77067 L .51757 .76808 L F
.959 .762 .593 r
.60476 .71454 m .60627 .71546 L .60518 .71205 L F
.82 .433 .32 r
.60502 .71696 m .60627 .71546 L .60476 .71454 L F
.60502 .71696 m .60689 .71725 L .60627 .71546 L F
.633 .843 .451 r
.41415 .64399 m .41278 .6461 L .41356 .6448 L F
.673 .767 .921 r
.41506 .64556 m .41278 .6461 L .41415 .64399 L F
.576 .88 .993 r
.41356 .6448 m .41278 .6461 L .41506 .64556 L F
.332 .151 .479 r
.38059 .67557 m .37809 .67788 L .37881 .67628 L F
.463 .151 .351 r
.44152 .68392 m .44037 .68678 L .43821 .68715 L F
.54 .239 .406 r
.44378 .68393 m .44037 .68678 L .44152 .68392 L F
.976 .813 .615 r
.6693 .51066 m .66717 .51147 L .6673 .50921 L F
.6693 .51066 m .66833 .51252 L .66717 .51147 L F
.346 .277 .635 r
.66955 .50805 m .67067 .50985 L .6693 .51066 L F
.606 .462 .659 r
.52176 .73483 m .52372 .7364 L .52409 .7345 L F
.52176 .73483 m .52183 .73723 L .52372 .7364 L F
.627 .353 .484 r
.42584 .6967 m .42365 .69591 L .42581 .6955 L F
.42584 .6967 m .42323 .69719 L .42365 .69591 L F
.653 .594 .777 r
.35017 .71534 m .35266 .71513 L .35174 .71226 L F
.54 .354 .578 r
.35029 .71782 m .35266 .71513 L .35017 .71534 L F
.953 .774 .32 r
.59645 .71433 m .59596 .71389 L .5965 .71253 L F
0 0 .025 r
.5965 .71253 m .59666 .71182 L .59682 .70935 L F
.73 .777 .282 r
.59596 .71389 m .59666 .71182 L .5965 .71253 L F
.706 .591 .724 r
.51984 .76796 m .51791 .76592 L .51845 .76636 L F
.599 .362 .529 r
.5175 .76909 m .51906 .76686 L .51845 .76636 L F
.851 .825 .822 r
.52208 .76466 m .51984 .76796 L .51845 .76636 L F
.599 .362 .529 r
.51906 .76686 m .51991 .76563 L .51845 .76636 L F
.706 .591 .724 r
.51791 .76592 m .51679 .76474 L .51845 .76636 L F
.499 .28 .513 r
.51984 .76796 m .51986 .77019 L .51772 .77067 L F
.143 .634 .915 r
.29254 .59041 m .29595 .59127 L .29402 .59134 L F
.448 .102 .285 r
.48233 .74056 m .48405 .74161 L .48493 .73974 L F
.48233 .74056 m .48182 .742 L .48405 .74161 L F
.27 0 0 r
.45789 .75269 m .46174 .75113 L .45856 .75162 L F
.45789 .75269 m .46012 .75245 L .46174 .75113 L F
.599 .167 .193 r
.46012 .75245 m .4641 .75109 L .46174 .75113 L F
.83 .787 .811 r
.50215 .75617 m .50028 .75784 L .50094 .75622 L F
.664 .194 .127 r
.53496 .71864 m .53722 .7203 L .53721 .7192 L F
.634 .168 .128 r
.53721 .7192 m .53722 .7203 L .54061 .7205 L F
.393 .064 .283 r
.34163 .61023 m .34283 .61167 L .34121 .61269 L F
.34163 .61023 m .34373 .60949 L .34283 .61167 L F
0 .409 .702 r
.40782 .64934 m .40993 .64997 L .4092 .64983 L F
.446 0 0 r
.4092 .64983 m .4113 .65038 L .41274 .65001 L F
0 .409 .702 r
.40993 .64997 m .4113 .65038 L .4092 .64983 L F
.144 0 0 r
.4083 .64966 m .4092 .64983 L .41059 .6499 L F
.40724 .64955 m .4092 .64983 L .4083 .64966 L F
.039 0 0 r
.41059 .6499 m .4092 .64983 L .41274 .65001 L F
.556 .413 .642 r
.44565 .77319 m .44762 .77012 L .44546 .77083 L F
.366 .184 .497 r
.5062 .71789 m .50782 .71758 L .50832 .71512 L F
.304 .009 .289 r
.5062 .71789 m .5077 .71919 L .50782 .71758 L F
.5062 .71789 m .50568 .72005 L .5077 .71919 L F
.708 .284 .239 r
.5576 .70379 m .55988 .70586 L .56098 .70421 L F
.827 .438 .316 r
.56098 .70421 m .56174 .70606 L .56346 .70392 L F
.56098 .70421 m .55988 .70586 L .56174 .70606 L F
.129 .346 .809 r
.56803 .74034 m .57025 .74175 L .56945 .74297 L F
0 0 .43 r
.57046 .74434 m .56945 .74297 L .57025 .74175 L F
.881 .446 .108 r
.57031 .74397 m .57046 .74434 L .57038 .7436 L F
.57004 .74546 m .57046 .74434 L .57031 .74397 L F
0 0 .43 r
.57046 .74434 m .57199 .74693 L .57065 .74485 L F
.57046 .74434 m .57065 .74485 L .56945 .74297 L F
.911 .982 .751 r
.57042 .77133 m .56896 .7736 L .56854 .77251 L F
.093 .493 .9 r
.56854 .77251 m .57023 .77404 L .56896 .7736 L F
.84 .776 .791 r
.33744 .71711 m .33855 .71962 L .34099 .71749 L F
.489 .241 .466 r
.45998 .78885 m .4577 .78956 L .45791 .78755 L F
0 .253 .764 r
.30176 .82545 m .30216 .82579 L .30209 .82601 L F
.712 .804 .336 r
.30209 .82601 m .30216 .82579 L .30167 .82693 L F
.064 0 0 r
.39837 .71082 m .39795 .71004 L .39988 .70928 L F
.39837 .71082 m .39638 .71154 L .39795 .71004 L F
.765 .339 .238 r
.56343 .71527 m .56236 .71671 L .56029 .71449 L F
.901 .538 .342 r
.56407 .71729 m .56236 .71671 L .56343 .71527 L F
.432 .076 .259 r
.51012 .71434 m .51323 .712 L .51154 .71329 L F
.164 0 .272 r
.2998 .63176 m .30129 .63153 L .30188 .62906 L F
.129 0 .122 r
.30059 .63308 m .2998 .63176 L .29851 .63353 L F
.30059 .63308 m .30129 .63153 L .2998 .63176 L F
.94 .961 .737 r
.57042 .77133 m .56854 .77251 L .57027 .76961 L F
.651 .143 0 r
.70574 .5879 m .70798 .59055 L .70893 .59126 L F
.16 .488 .902 r
.70798 .59055 m .71032 .59257 L .70893 .59126 L F
.905 .929 .82 r
.50822 .75942 m .50734 .76233 L .50675 .75979 L F
.50822 .75942 m .50628 .76172 L .50734 .76233 L F
.969 .65 .317 r
.50628 .76172 m .5077 .76495 L .50734 .76233 L F
.743 .477 .528 r
.50734 .76233 m .5077 .76495 L .50924 .76472 L F
.67 .826 .958 r
.35705 .72339 m .36078 .72349 L .35986 .72243 L F
.054 .46 .882 r
.35986 .72243 m .36078 .72349 L .36113 .72279 L F
.097 .515 .907 r
.36078 .72349 m .36277 .72423 L .36113 .72279 L F
.553 .011 0 r
.53154 .71813 m .53393 .71942 L .53496 .71864 L F
.661 .139 0 r
.53393 .71942 m .53722 .7203 L .53496 .71864 L F
.867 .421 .059 r
.67145 .5184 m .67036 .51777 L .66943 .51591 L F
.891 .495 .057 r
.67145 .5184 m .67162 .52038 L .67036 .51777 L F
.67145 .5184 m .67255 .52122 L .67162 .52038 L F
.765 .462 .473 r
.61498 .55169 m .61313 .55371 L .61149 .55129 L F
.66 .318 .383 r
.61733 .55356 m .61498 .55169 L .61647 .55219 L F
.61733 .55356 m .61313 .55371 L .61498 .55169 L F
.185 .315 .764 r
.70329 .59328 m .70439 .59663 L .70567 .59514 L F
.112 .238 .716 r
.70439 .59663 m .70651 .59732 L .70567 .59514 L F
.70439 .59663 m .70598 .59866 L .70651 .59732 L F
.68 .896 .975 r
.59585 .7557 m .59394 .75553 L .59234 .75643 L F
.748 .887 .942 r
.597 .75384 m .59585 .7557 L .59755 .75432 L F
.597 .75384 m .59394 .75553 L .59585 .7557 L F
.533 .727 .963 r
.70766 .58653 m .70574 .5879 L .70457 .58664 L F
.326 .304 .681 r
.70766 .58653 m .70798 .59055 L .70574 .5879 L F
.923 .731 .625 r
.47518 .77083 m .47453 .77308 L .47328 .76996 L F
.819 .96 .631 r
.47525 .76969 m .47518 .77083 L .4768 .76834 L F
.923 .731 .625 r
.47328 .76996 m .47518 .77083 L .47525 .76969 L F
.47328 .76996 m .47453 .77308 L .47518 .77083 L F
.802 .412 .317 r
.52438 .71517 m .52486 .71676 L .526 .71506 L F
.71 .295 .258 r
.52486 .71676 m .52835 .71711 L .526 .71506 L F
.229 0 0 r
.41633 .65015 m .41828 .65077 L .41964 .65117 L F
.154 .672 .889 r
.41828 .65077 m .42178 .65123 L .41964 .65117 L F
.621 .713 .912 r
.44565 .6542 m .44355 .65489 L .44226 .65322 L F
.968 .648 .29 r
.60456 .69846 m .60479 .70028 L .60579 .70103 L F
.682 .314 .344 r
.60292 .70573 m .60429 .70384 L .60067 .70375 L F
.325 0 0 r
.60067 .70375 m .60429 .70384 L .6026 .70393 L F
.909 .92 .813 r
.60579 .70103 m .6026 .70393 L .60429 .70384 L F
.60579 .70103 m .60479 .70028 L .6026 .70393 L F
.246 .557 .933 r
.71292 .60699 m .71401 .60615 L .71218 .60574 L F
.248 .561 .935 r
.71292 .60699 m .71499 .60748 L .71401 .60615 L F
.543 .484 .739 r
.34619 .68493 m .34745 .6813 L .34554 .68181 L F
.34619 .68493 m .34811 .68452 L .34745 .6813 L F
.527 .414 .669 r
.34619 .68493 m .34856 .68695 L .34811 .68452 L F
.517 .415 .677 r
.34657 .68732 m .34856 .68695 L .34619 .68493 L F
.472 .323 .597 r
.34666 .67351 m .34861 .67546 L .34874 .67304 L F
.34666 .67351 m .34682 .67614 L .34861 .67546 L F
.674 .474 .607 r
.51376 .72622 m .51373 .72897 L .5116 .72862 L F
.601 .414 .601 r
.51612 .72569 m .51373 .72897 L .51376 .72622 L F
.425 .172 .424 r
.48665 .7394 m .48948 .7365 L .48734 .73716 L F
.766 .674 .761 r
.36608 .72596 m .3674 .7291 L .36962 .7263 L F
.19 .687 .917 r
.46445 .7894 m .46556 .78912 L .46338 .78957 L F
.904 .767 .701 r
.60432 .7089 m .60719 .7067 L .60556 .70531 L F
.60432 .7089 m .60593 .70971 L .60719 .7067 L F
.436 .265 .549 r
.34828 .70677 m .35033 .70691 L .35048 .70398 L F
.898 .842 .781 r
.61594 .53753 m .61567 .53455 L .61696 .53554 L F
.627 .469 .648 r
.53201 .74296 m .53204 .74547 L .5297 .74563 L F
.677 .476 .606 r
.53204 .74547 m .52971 .74785 L .5297 .74563 L F
.452 0 .044 r
.47904 .76815 m .47525 .76969 L .4768 .76834 L F
0 0 0 r
.6117 .75138 m .60817 .75341 L .6096 .75438 L F
.782 .599 .653 r
.6497 .51397 m .64587 .51509 L .64775 .5121 L F
.6497 .51397 m .64953 .51571 L .64587 .51509 L F
.768 .713 .801 r
.65111 .51189 m .6497 .51397 L .64775 .5121 L F
.453 .31 .595 r
.6497 .51397 m .64953 .51571 L .65153 .51496 L F
.6497 .51397 m .64953 .51571 L .65153 .51496 L F
.679 .504 .642 r
.56072 .76795 m .56069 .77043 L .55841 .77042 L F
.528 .38 .624 r
.56237 .76998 m .56069 .77043 L .56072 .76795 L F
.683 .401 .489 r
.56343 .76818 m .56237 .76998 L .56072 .76795 L F
.37 .447 .81 r
.53658 .75392 m .53748 .75676 L .53898 .75559 L F
.53748 .75676 m .53781 .75681 L .53898 .75559 L F
.372 .449 .811 r
.53758 .75705 m .53915 .75806 L .53898 .75559 L F
.53915 .75806 m .53945 .75784 L .53898 .75559 L F
.53955 .75832 m .53999 .75821 L .53898 .75559 L F
.37 .447 .81 r
.53658 .75392 m .53898 .75559 L .53881 .7533 L F
.719 .707 .837 r
.53976 .75761 m .54047 .75667 L .53898 .75559 L F
.54019 .75872 m .54055 .75774 L .53976 .75761 L F
.54055 .75774 m .5406 .75761 L .53976 .75761 L F
.54078 .75711 m .54138 .75544 L .54056 .75655 L F
.54047 .75667 m .54138 .75544 L .53998 .75553 L F
.5406 .75761 m .54321 .75806 L .54138 .75544 L F
.54019 .75872 m .54174 .75838 L .5406 .75761 L F
.54174 .75838 m .54321 .75806 L .5406 .75761 L F
.5406 .75761 m .54078 .75711 L .53999 .75731 L F
.715 .647 .78 r
.54102 .75781 m .54022 .75735 L .54029 .75722 L F
.54022 .75735 m .53987 .75715 L .53994 .75716 L F
.719 .707 .837 r
.54078 .75711 m .54056 .75655 L .53999 .75731 L F
.715 .647 .78 r
.54022 .75735 m .53994 .75716 L .54029 .75722 L F
.62 .46 .644 r
.53898 .75559 m .54016 .75552 L .53881 .7533 L F
.54016 .75552 m .54138 .75544 L .53948 .75386 L F
.54016 .75552 m .53948 .75386 L .53881 .7533 L F
0 0 .321 r
.54006 .75497 m .54113 .75776 L .5411 .7578 L F
.54076 .75699 m .5411 .7578 L .54106 .75784 L F
.54006 .75497 m .5411 .7578 L .54076 .75699 L F
.54105 .75782 m .54106 .75784 L .54106 .75784 L F
.54006 .75497 m .54106 .75784 L .54105 .75782 L F
.719 .707 .837 r
.5406 .75761 m .53999 .75731 L .53976 .75761 L F
.715 .647 .78 r
.54106 .75784 m .54094 .75777 L .54102 .75781 L F
.54094 .75777 m .53987 .75715 L .54102 .75781 L F
.372 .449 .811 r
.53915 .75806 m .53955 .75832 L .53945 .75784 L F
.37 .447 .81 r
.53748 .75676 m .53758 .75705 L .53781 .75681 L F
.535 .43 .682 r
.53758 .75705 m .53824 .75944 L .54019 .75872 L F
.715 .647 .78 r
.54094 .75777 m .53822 .75893 L .53623 .75503 L F
.54106 .75784 m .54099 .75787 L .54094 .75777 L F
.54099 .75787 m .53822 .75893 L .54094 .75777 L F
.719 .707 .837 r
.54047 .75667 m .53998 .75553 L .53898 .75559 L F
0 0 .321 r
.54073 .75691 m .54105 .75782 L .5403 .75722 L F
.54105 .75782 m .54106 .75784 L .54102 .75781 L F
.54105 .75782 m .54102 .75781 L .5403 .75722 L F
.54006 .75497 m .54073 .75691 L .53767 .7551 L F
.54073 .75691 m .5403 .75722 L .53767 .7551 L F
.372 .449 .811 r
.53955 .75832 m .54019 .75872 L .53999 .75821 L F
.543 .118 .184 r
.54028 .75814 m .53548 .76044 L .53822 .75893 L F
.54106 .75784 m .54057 .75807 L .54028 .75814 L F
.54057 .75807 m .53548 .76044 L .54028 .75814 L F
.715 .647 .78 r
.54029 .75722 m .53623 .75503 L .53767 .7551 L F
.53987 .75715 m .53623 .75503 L .54029 .75722 L F
.898 .842 .781 r
.61594 .53753 m .61387 .53758 L .61567 .53455 L F
.894 .831 .777 r
.61594 .53753 m .61274 .53947 L .61387 .53758 L F
.61594 .53753 m .61396 .54051 L .61274 .53947 L F
.453 .341 .636 r
.44393 .77616 m .44594 .77602 L .44565 .77319 L F
.628 .428 .593 r
.44393 .77616 m .44698 .77803 L .44594 .77602 L F
.44393 .77616 m .44396 .7786 L .44698 .77803 L F
.542 .018 0 r
.58578 .68141 m .58409 .68133 L .58331 .68112 L F
.319 0 .172 r
.58229 .68085 m .58331 .68112 L .58122 .68181 L F
.319 .804 .882 r
.58331 .68112 m .57996 .68147 L .58122 .68181 L F
.542 .018 0 r
.58409 .68133 m .58134 .6812 L .58331 .68112 L F
.319 0 .172 r
.58443 .67891 m .58331 .68112 L .58229 .68085 L F
.621 .255 .327 r
.58734 .68064 m .58443 .67891 L .58681 .67885 L F
.58734 .68064 m .58331 .68112 L .58443 .67891 L F
.569 .188 .281 r
.6327 .55118 m .63372 .5492 L .63607 .55052 L F
.63 .497 .681 r
.6474 .51867 m .65152 .51973 L .64953 .51571 L F
.65152 .51973 m .65179 .51945 L .64953 .51571 L F
.717 .525 .628 r
.64953 .51571 m .65277 .51828 L .65153 .51496 L F
.64953 .51571 m .65179 .51945 L .65277 .51828 L F
.65179 .51945 m .65205 .51987 L .65243 .51903 L F
.65179 .51945 m .65243 .51903 L .65277 .51828 L F
.844 .913 .881 r
.65087 .52006 m .64936 .5202 L .65206 .51759 L F
.65055 .52072 m .65014 .52054 L .65087 .52006 L F
.65014 .52054 m .64936 .5202 L .65087 .52006 L F
.65038 .52109 m .65028 .521 L .65055 .52072 L F
.65028 .521 m .64936 .5202 L .65055 .52072 L F
.63 .497 .681 r
.65152 .51973 m .65205 .51987 L .65179 .51945 L F
0 0 0 r
.6117 .75138 m .61006 .75251 L .60817 .75341 L F
.61267 .7501 m .61428 .7497 L .61277 .75022 L F
.758 .994 .811 r
.61006 .75251 m .61267 .7501 L .61083 .75088 L F
0 0 0 r
.61267 .7501 m .61277 .75022 L .61083 .75088 L F
.61256 .74997 m .61267 .7501 L .6117 .75138 L F
.61355 .74836 m .61267 .7501 L .61256 .74997 L F
.627 .928 .674 r
.6117 .75138 m .61267 .7501 L .61006 .75251 L F
.278 0 0 r
.63955 .54956 m .64092 .5505 L .63848 .55083 L F
.63955 .54956 m .64182 .54917 L .64092 .5505 L F
0 .266 .765 r
.5208 .80035 m .52131 .80126 L .52391 .80299 L F
.498 .587 .875 r
.46509 .7754 m .46466 .77834 L .46352 .7752 L F
.46509 .7754 m .46666 .7781 L .46466 .77834 L F
.356 .813 .933 r
.28468 .64073 m .28539 .64011 L .28652 .6398 L F
.28468 .64073 m .28214 .64041 L .28539 .64011 L F
.386 .103 .356 r
.3274 .62649 m .33011 .62373 L .32924 .62574 L F
.292 0 .278 r
.32924 .62574 m .33011 .62373 L .33181 .62322 L F
.686 .683 .841 r
.58149 .70936 m .58258 .71292 L .5804 .71252 L F
.657 .194 .142 r
.58258 .71292 m .58198 .71358 L .5804 .71252 L F
.797 .608 .645 r
.58149 .70936 m .58489 .71141 L .58258 .71292 L F
0 0 0 r
.58489 .71141 m .58198 .71358 L .58258 .71292 L F
.925 .653 .505 r
.60261 .68713 m .60424 .69002 L .60464 .68787 L F
.845 .706 .708 r
.6262 .50194 m .6235 .50125 L .62515 .49863 L F
.944 .852 .721 r
.6262 .50194 m .62382 .50348 L .6235 .50125 L F
.6262 .50194 m .62482 .50467 L .62382 .50348 L F
.732 .647 .765 r
.62856 .49925 m .6262 .50194 L .62515 .49863 L F
.507 .75 .983 r
.29977 .60514 m .30043 .60361 L .29842 .60395 L F
.29977 .60514 m .30219 .60502 L .30043 .60361 L F
.325 .03 .301 r
.30188 .62906 m .30373 .62875 L .30454 .62649 L F
.447 .174 .406 r
.30373 .62875 m .30645 .62581 L .30454 .62649 L F
.516 .151 .286 r
.73861 .59324 m .74119 .5945 L .73786 .59537 L F
.73861 .59324 m .74102 .59314 L .74119 .5945 L F
.366 .365 .726 r
.34657 .68732 m .34728 .69052 L .34861 .68919 L F
.427 .462 .793 r
.34728 .69052 m .34997 .69256 L .34861 .68919 L F
.543 .464 .716 r
.34788 .693 m .34997 .69256 L .34728 .69052 L F
.38 0 .089 r
.32608 .71716 m .3282 .71691 L .32974 .71504 L F
.849 .52 .43 r
.32974 .71504 m .33052 .71722 L .33188 .71486 L F
.32974 .71504 m .3282 .71691 L .33052 .71722 L F
0 0 0 r
.5542 .68815 m .55275 .68965 L .55702 .68596 L F
0 0 .271 r
.57452 .75254 m .57494 .75391 L .57402 .75135 L F
.572 .504 .74 r
.45177 .65595 m .45033 .66005 L .44956 .65635 L F
.45177 .65595 m .45249 .65958 L .45033 .66005 L F
.648 .775 .941 r
.28584 .6785 m .28753 .67997 L .28961 .67909 L F
.28584 .6785 m .28753 .67997 L .28961 .67909 L F
.245 0 .165 r
.26763 .61117 m .26642 .61058 L .2684 .61022 L F
.26763 .61117 m .26569 .61208 L .26642 .61058 L F
.725 .713 .839 r
.62331 .51578 m .6243 .51877 L .62325 .51678 L F
.826 .691 .715 r
.6243 .51877 m .62077 .52045 L .62325 .51678 L F
.6243 .51877 m .62269 .52178 L .62077 .52045 L F
.827 .766 .794 r
.62646 .51589 m .6243 .51877 L .62331 .51578 L F
.572 .778 .976 r
.73353 .6223 m .73465 .62061 L .73253 .62128 L F
.73353 .6223 m .73535 .62195 L .73465 .62061 L F
.391 .797 .982 r
.58555 .75103 m .58742 .75009 L .58419 .74992 L F
.58555 .75103 m .58788 .75073 L .58742 .75009 L F
.619 .297 .403 r
.71764 .59329 m .7206 .59307 L .72035 .59106 L F
.557 .253 .409 r
.72035 .59106 m .7206 .59307 L .72296 .59223 L F
.701 .27 .223 r
.46286 .66769 m .46516 .66955 L .46668 .66808 L F
.183 .714 .729 r
.46516 .66955 m .46762 .66904 L .46668 .66808 L F
.451 .467 .785 r
.46907 .67035 m .46668 .66808 L .46762 .66904 L F
.579 .589 .827 r
.67498 .49226 m .67342 .49425 L .67244 .491 L F
.571 .577 .82 r
.67498 .49226 m .6759 .49387 L .67342 .49425 L F
.454 .676 .96 r
.26127 .58451 m .26107 .58627 L .25958 .58454 L F
.26127 .58451 m .2629 .58595 L .26107 .58627 L F
.762 .487 .518 r
.51499 .76443 m .51845 .76636 L .51679 .76474 L F
.808 .628 .658 r
.52776 .76485 m .52954 .76678 L .5302 .76499 L F
.52776 .76485 m .52784 .76713 L .52954 .76678 L F
.52776 .76485 m .52784 .76713 L .52954 .76678 L F
.832 .377 .138 r
.5243 .76433 m .52694 .76641 L .52776 .76485 L F
.52694 .76641 m .52784 .76713 L .52782 .76657 L F
.52694 .76641 m .52782 .76657 L .52776 .76485 L F
.5243 .76433 m .52632 .76717 L .52784 .76713 L F
.619 .101 0 r
.52632 .76717 m .52954 .76678 L .52784 .76713 L F
.768 .559 .616 r
.53107 .76767 m .52949 .76996 L .52798 .76736 L F
.5284 .76722 m .52798 .76736 L .52784 .76713 L F
.53107 .76767 m .52798 .76736 L .5284 .76722 L F
.53107 .76767 m .53162 .77085 L .52949 .76996 L F
.52 .392 .646 r
.53365 .77017 m .53162 .77085 L .53107 .76767 L F
.076 0 .221 r
.53416 .76744 m .53194 .77056 L .53292 .7698 L F
.53416 .76744 m .53292 .7698 L .53375 .76751 L F
.702 .599 .738 r
.52908 .76791 m .53416 .76744 L .52969 .7668 L F
.52887 .7683 m .53375 .76751 L .52908 .76791 L F
.53375 .76751 m .53416 .76744 L .52908 .76791 L F
.354 .247 .592 r
.52954 .76678 m .53416 .76744 L .53222 .76424 L F
.483 .295 .548 r
.53222 .76424 m .53416 .76744 L .53435 .76584 L F
.076 0 .221 r
.53416 .76744 m .53375 .76751 L .53435 .76584 L F
.566 .36 .56 r
.53375 .76751 m .53662 .76565 L .53435 .76584 L F
.53292 .7698 m .53506 .7674 L .53375 .76751 L F
.53506 .7674 m .53662 .76565 L .53375 .76751 L F
.702 .599 .738 r
.52873 .76856 m .53416 .76744 L .52887 .7683 L F
.52951 .76686 m .52969 .7668 L .52954 .76678 L F
.52873 .76856 m .52969 .7668 L .52951 .76686 L F
.739 .553 .642 r
.52784 .76713 m .52552 .76994 L .52557 .7678 L F
.52784 .76713 m .52949 .76996 L .52552 .76994 L F
.619 .101 0 r
.52632 .76717 m .52873 .76856 L .5295 .76687 L F
.52921 .76682 m .5295 .76687 L .52954 .76678 L F
.52632 .76717 m .5295 .76687 L .52921 .76682 L F
.354 .247 .592 r
.52954 .76678 m .53222 .76424 L .5302 .76499 L F
.45 .135 .339 r
.38806 .66862 m .38805 .67028 L .38583 .67063 L F
.302 .027 .319 r
.39029 .66933 m .38806 .66862 L .39174 .66885 L F
.39029 .66933 m .38805 .67028 L .38806 .66862 L F
.905 .841 .385 r
.57447 .75618 m .57412 .75951 L .57519 .75595 L F
.57447 .75618 m .57384 .75852 L .57412 .75951 L F
0 0 .485 r
.57384 .75852 m .57394 .76198 L .57412 .75951 L F
.586 .639 .87 r
.31247 .61001 m .3129 .60663 L .31143 .60673 L F
.31247 .61001 m .31457 .60953 L .3129 .60663 L F
.827 .766 .794 r
.62646 .51589 m .62331 .51578 L .6259 .5147 L F
.71 .869 .957 r
.6259 .5147 m .62646 .51589 L .629 .51477 L F
0 .176 .656 r
.6266 .51568 m .62646 .51589 L .6259 .5147 L F
.6266 .51568 m .6288 .51763 L .62646 .51589 L F
0 .411 .785 r
.5942 .72844 m .59043 .72689 L .59177 .72702 L F
.498 0 0 r
.56451 .70897 m .56701 .70992 L .56786 .70974 L F
.499 0 0 r
.56701 .70992 m .5698 .70978 L .56786 .70974 L F
.52 0 0 r
.50171 .7624 m .5024 .76318 L .50007 .76337 L F
.50171 .7624 m .50415 .76407 L .5024 .76318 L F
.632 .723 .913 r
.53658 .75392 m .53464 .75482 L .53383 .75356 L F
.53658 .75392 m .53383 .75356 L .53433 .75286 L F
.53658 .75392 m .53464 .75482 L .53297 .75222 L F
.336 .312 .684 r
.5369 .75221 m .53481 .75461 L .53472 .75233 L F
.5357 .75097 m .53472 .75233 L .53463 .74986 L F
.5369 .75221 m .53472 .75233 L .5357 .75097 L F
.632 .723 .913 r
.53433 .75286 m .53383 .75356 L .53297 .75222 L F
.437 .153 .383 r
.50607 .72948 m .50542 .73153 L .50329 .73199 L F
0 0 0 r
.50805 .72827 m .50542 .73153 L .50607 .72948 L F
.246 0 0 r
.39356 .66821 m .39029 .66933 L .39174 .66885 L F
.467 .171 .379 r
.4184 .68673 m .42042 .68696 L .42109 .68466 L F
.425 .084 .282 r
.42042 .68696 m .42343 .68447 L .42109 .68466 L F
.761 .405 .38 r
.6673 .50921 m .66955 .50805 L .66831 .50676 L F
.6673 .50921 m .67067 .50985 L .66955 .50805 L F
.435 .795 .996 r
.28447 .65348 m .28327 .65289 L .28154 .6532 L F
.462 .813 .998 r
.28447 .65348 m .28552 .65249 L .28327 .65289 L F
.28447 .65348 m .28669 .65309 L .28552 .65249 L F
.444 .029 .156 r
.39965 .6982 m .40188 .69807 L .40337 .69604 L F
.315 0 .065 r
.40188 .69807 m .40551 .69563 L .40337 .69604 L F
.524 .369 .612 r
.4961 .76488 m .49627 .76769 L .49412 .76812 L F
.431 .12 .336 r
.49627 .76769 m .49343 .76992 L .49412 .76812 L F
.635 .475 .649 r
.53441 .74527 m .53201 .74296 L .53438 .74273 L F
.53441 .74527 m .53204 .74547 L .53201 .74296 L F
.03 .566 .851 r
.27242 .58666 m .27432 .58696 L .27588 .58755 L F
.454 .781 .998 r
.27432 .58696 m .27786 .58757 L .27588 .58755 L F
.383 .792 .981 r
.42458 .66358 m .42091 .66327 L .42214 .66362 L F
.29 0 .027 r
.51772 .77067 m .51854 .772 L .51669 .77161 L F
.51772 .77067 m .51986 .77019 L .51854 .772 L F
.974 .689 .421 r
.65269 .52372 m .65363 .52201 L .65268 .52055 L F
.65269 .52372 m .65391 .52437 L .65363 .52201 L F
.589 .741 .948 r
.65268 .52055 m .65363 .52201 L .65604 .52122 L F
.591 .461 .672 r
.65391 .52437 m .65604 .52122 L .65363 .52201 L F
.508 .734 .975 r
.33667 .59796 m .33611 .59965 L .33476 .59804 L F
.33667 .59796 m .33813 .59937 L .33611 .59965 L F
.163 .609 .935 r
.30525 .60488 m .30568 .60429 L .30404 .60448 L F
.30525 .60488 m .30811 .60551 L .30568 .60429 L F
.394 .703 .984 r
.44091 .6521 m .4404 .65329 L .43883 .65243 L F
.44091 .6521 m .44226 .65322 L .4404 .65329 L F
.709 .922 .965 r
.27303 .64199 m .27374 .64017 L .27526 .64099 L F
.27303 .64199 m .27136 .64148 L .27374 .64017 L F
.413 .263 .567 r
.68767 .52492 m .68782 .52315 L .68754 .52484 L F
.859 .804 .795 r
.5444 .77145 m .54289 .77377 L .54041 .773 L F
.906 .675 .578 r
.54289 .77377 m .54205 .7758 L .54041 .773 L F
.582 .507 .735 r
.43186 .67215 m .43274 .67271 L .43454 .67049 L F
.653 .428 .566 r
.539 .7421 m .53441 .74527 L .53438 .74273 L F
.194 0 0 r
.381 .64904 m .38317 .6489 L .38438 .64842 L F
.067 0 0 r
.38317 .6489 m .38658 .64846 L .38438 .64842 L F
.632 .669 .868 r
.44956 .65635 m .44565 .6542 L .44785 .65367 L F
.669 .699 .869 r
.45098 .65437 m .44956 .65635 L .44785 .65367 L F
.554 .536 .79 r
.45098 .65437 m .45177 .65595 L .44956 .65635 L F
.536 .416 .663 r
.34761 .66745 m .34956 .66458 L .34795 .66537 L F
0 .13 .625 r
.73169 .71374 m .73312 .71503 L .73325 .7153 L F
0 0 .326 r
.73312 .71503 m .73426 .7173 L .73325 .7153 L F
0 0 .261 r
.66885 .53322 m .66808 .53251 L .66822 .5312 L F
.66885 .53322 m .66802 .53482 L .66808 .53251 L F
.333 .03 .293 r
.31595 .64017 m .31535 .64265 L .31342 .64234 L F
.325 0 .203 r
.3144 .64409 m .31342 .64234 L .31535 .64265 L F
.3144 .64409 m .3124 .64472 L .31342 .64234 L F
.277 0 .235 r
.56537 .76756 m .56237 .76998 L .56343 .76818 L F
0 0 0 r
.6606 .54045 m .6599 .54097 L .65726 .54217 L F
.499 .098 .211 r
.66266 .53999 m .6599 .54097 L .6606 .54045 L F
.859 .804 .795 r
.5444 .77145 m .54041 .773 L .54191 .7719 L F
.876 .955 .854 r
.54575 .76946 m .5444 .77145 L .54191 .7719 L F
.366 .263 .604 r
.34839 .69602 m .34997 .69256 L .34788 .693 L F
.444 .231 .494 r
.31595 .64017 m .31814 .63747 L .31755 .63929 L F
.164 0 .229 r
.31688 .64167 m .31595 .64017 L .31755 .63929 L F
.31688 .64167 m .31535 .64265 L .31595 .64017 L F
.317 .199 .556 r
.72027 .59683 m .72296 .59223 L .7206 .59307 L F
0 0 .071 r
.69565 .51586 m .69689 .51191 L .69807 .51523 L F
.69565 .51586 m .6961 .51522 L .69689 .51191 L F
0 .173 .645 r
.69565 .51586 m .69597 .5159 L .6961 .51522 L F
.59 .397 .588 r
.69807 .51523 m .698 .5176 L .69565 .51586 L F
0 .173 .645 r
.69565 .51586 m .698 .5176 L .69597 .5159 L F
.604 .538 .754 r
.35016 .71914 m .35255 .71759 L .35029 .71782 L F
.35016 .71914 m .35328 .72016 L .35255 .71759 L F
.581 .444 .66 r
.35016 .71914 m .35365 .72346 L .35328 .72016 L F
.35016 .71914 m .35111 .72405 L .35365 .72346 L F
.657 .272 .303 r
.62063 .55303 m .61733 .55356 L .61647 .55219 L F
.451 .143 .35 r
.49672 .73136 m .49894 .73094 L .49955 .72823 L F
0 0 0 r
.49955 .72823 m .50084 .72791 L .50171 .72601 L F
0 0 .178 r
.49955 .72823 m .49894 .73094 L .50084 .72791 L F
.54 .354 .578 r
.35029 .71782 m .35255 .71759 L .35266 .71513 L F
.536 .245 .42 r
.41543 .68964 m .4184 .68673 L .41589 .68783 L F
.849 .877 .861 r
.57336 .75001 m .57666 .74872 L .5733 .74799 L F
.366 .263 .604 r
.34839 .69602 m .3503 .6951 L .34997 .69256 L F
.448 .454 .772 r
.34839 .69602 m .35102 .69797 L .3503 .6951 L F
.508 .453 .73 r
.34911 .69847 m .35102 .69797 L .34839 .69602 L F
0 .271 .773 r
.57492 .72903 m .57573 .72878 L .57404 .72791 L F
.57492 .72903 m .57754 .73103 L .57573 .72878 L F
.097 .339 .811 r
.57752 .73204 m .57754 .73103 L .57492 .72903 L F
.651 .507 .674 r
.49036 .76501 m .48816 .76771 L .48817 .7655 L F
.613 .438 .622 r
.5116 .74286 m .51413 .73999 L .51041 .73959 L F
.5116 .74286 m .51392 .74308 L .51413 .73999 L F
.679 .955 .95 r
.64639 .49916 m .6476 .49725 L .6479 .49836 L F
.599 .717 .927 r
.4926 .7616 m .49334 .75906 L .49155 .76145 L F
.4926 .7616 m .49513 .7611 L .49334 .75906 L F
.693 .273 .245 r
.49154 .76362 m .4926 .7616 L .49155 .76145 L F
.49154 .76362 m .49484 .76351 L .4926 .7616 L F
.706 .587 .72 r
.59441 .7175 m .59662 .72089 L .59281 .71996 L F
.797 .651 .7 r
.50825 .74242 m .5116 .74286 L .51041 .73959 L F
.541 .134 .22 r
.50805 .74469 m .5116 .74286 L .50825 .74242 L F
.50805 .74469 m .51043 .74465 L .5116 .74286 L F
.668 .278 .296 r
.5116 .74286 m .51043 .74465 L .51382 .74475 L F
.688 .272 .25 r
.5225 .79994 m .52368 .79813 L .52025 .79794 L F
.812 .603 .619 r
.5225 .79994 m .52591 .79788 L .52368 .79813 L F
.576 .579 .819 r
.68641 .50415 m .68514 .50765 L .68422 .50501 L F
.68641 .50415 m .68764 .507 L .68514 .50765 L F
.536 .411 .656 r
.68764 .507 m .68773 .5094 L .68514 .50765 L F
.633 .654 .852 r
.4559 .6629 m .45408 .66455 L .45386 .66392 L F
.568 .538 .781 r
.4559 .6629 m .45624 .66416 L .45408 .66455 L F
.346 .669 .975 r
.56218 .78323 m .56132 .78421 L .55988 .78295 L F
.563 .894 .641 r
.55943 .78555 m .56132 .78421 L .56218 .78323 L F
.751 .63 .726 r
.54875 .743 m .54726 .74564 L .54962 .74507 L F
.586 .213 .302 r
.54726 .74564 m .54938 .74596 L .54962 .74507 L F
.328 .398 .782 r
.54962 .74507 m .55137 .74494 L .54875 .743 L F
.248 0 .19 r
.54962 .74507 m .54938 .74596 L .55137 .74494 L F
.751 .63 .726 r
.54875 .743 m .54726 .74564 L .54962 .74507 L F
.519 .154 .287 r
.35881 .65848 m .35729 .65699 L .35661 .65886 L F
.35881 .65848 m .35957 .65686 L .35729 .65699 L F
.619 .319 .439 r
.54342 .7428 m .53994 .74529 L .54003 .74265 L F
.54342 .7428 m .54446 .74517 L .53994 .74529 L F
.5 .264 .488 r
.5457 .74391 m .54446 .74517 L .54342 .7428 L F
.564 .477 .714 r
.34911 .69847 m .35148 .70102 L .35102 .69797 L F
.34911 .69847 m .3497 .70163 L .35148 .70102 L F
.686 .683 .841 r
.58149 .70936 m .5804 .71252 L .57925 .71198 L F
0 0 .277 r
.58086 .71354 m .5804 .71252 L .58198 .71358 L F
.58086 .71354 m .58032 .7151 L .5804 .71252 L F
.717 .474 .558 r
.51268 .72032 m .51207 .72345 L .5097 .72224 L F
.667 .216 0 r
.51268 .72032 m .51359 .72197 L .51207 .72345 L F
.85 .422 .211 r
.51268 .72032 m .51478 .72348 L .51586 .72339 L F
.488 .249 .478 r
.30129 .63153 m .30373 .62875 L .30188 .62906 L F
.71 .863 .449 r
.62899 .51999 m .62827 .52155 L .62992 .51869 L F
0 0 0 r
.63003 .51857 m .62992 .51869 L .63065 .51732 L F
.63003 .51857 m .62899 .51999 L .62992 .51869 L F
.504 .56 .846 r
.38512 .69727 m .38373 .69911 L .383 .69737 L F
.493 .545 .838 r
.38512 .69727 m .38671 .70004 L .38373 .69911 L F
.335 0 0 r
.40567 .70705 m .40419 .70855 L .402 .70878 L F
.224 0 0 r
.40793 .7068 m .40419 .70855 L .40567 .70705 L F
.867 .618 .561 r
.7151 .5127 m .71217 .51226 L .71344 .51102 L F
.7151 .5127 m .71313 .5131 L .71217 .51226 L F
.733 .531 .619 r
.71483 .51454 m .71313 .5131 L .7151 .5127 L F
.82 .812 .843 r
.71717 .50998 m .7151 .5127 L .71344 .51102 L F
.561 .193 .3 r
.71728 .51435 m .71483 .51454 L .7151 .5127 L F
.552 .413 .646 r
.71717 .50998 m .71766 .51227 L .7151 .5127 L F
.493 .227 .439 r
.71766 .51227 m .71728 .51435 L .7151 .5127 L F
.605 .206 .26 r
.54326 .72899 m .54182 .73093 L .5398 .73074 L F
.765 .403 .37 r
.54326 .72899 m .54477 .73142 L .54182 .73093 L F
.574 .346 .532 r
.54921 .7567 m .55146 .75873 L .55173 .75648 L F
.54921 .7567 m .55146 .75873 L .55173 .75648 L F
.181 0 .318 r
.5367 .79828 m .53614 .7971 L .53566 .79831 L F
.692 .35 .391 r
.54082 .79819 m .53614 .7971 L .53814 .79811 L F
.434 .547 .871 r
.5367 .79828 m .53951 .79854 L .53814 .79811 L F
0 0 0 r
.53782 .79899 m .54082 .79819 L .53973 .79906 L F
.434 .547 .871 r
.5367 .79828 m .53973 .79906 L .53951 .79854 L F
.5367 .79828 m .53782 .79899 L .53973 .79906 L F
.896 .68 .601 r
.53844 .79847 m .53973 .79906 L .53823 .79909 L F
.692 .35 .391 r
.53934 .79849 m .53814 .79811 L .53892 .79851 L F
.53934 .79849 m .53892 .79851 L .53917 .79852 L F
.54082 .79819 m .53814 .79811 L .53934 .79849 L F
.434 .547 .871 r
.53814 .79811 m .53951 .79854 L .53928 .79798 L F
.383 .034 .245 r
.53814 .79811 m .53614 .7971 L .5367 .79828 L F
.434 .547 .871 r
.5367 .79828 m .53928 .79798 L .53891 .79706 L F
.896 .68 .601 r
.53891 .79706 m .53947 .79845 L .53889 .79846 L F
.383 .034 .245 r
.53901 .79855 m .53814 .79811 L .5367 .79828 L F
.53889 .79854 m .5367 .79828 L .53891 .79706 L F
.896 .68 .601 r
.53891 .79706 m .53889 .79846 L .53844 .79847 L F
.383 .034 .245 r
.53901 .79855 m .53889 .79854 L .53891 .79706 L F
.746 .793 .891 r
.5415 .79593 m .54282 .79747 L .53901 .79855 L F
.894 .961 .63 r
.54211 .79756 m .54211 .79758 L .54257 .79742 L F
.258 .763 .741 r
.54253 .79755 m .5416 .79791 L .53901 .79855 L F
.54279 .79748 m .5426 .79755 L .54253 .79755 L F
.5426 .79755 m .5416 .79791 L .54253 .79755 L F
0 0 0 r
.53973 .79906 m .54082 .79819 L .54282 .79747 L F
.461 0 0 r
.53973 .79906 m .5417 .79955 L .53823 .79909 L F
0 0 0 r
.53973 .79906 m .54282 .79747 L .5417 .79955 L F
.712 .304 .272 r
.53823 .79909 m .5417 .79955 L .5405 .80129 L F
.258 .763 .741 r
.5416 .79791 m .54082 .79819 L .53917 .79852 L F
.5416 .79791 m .53917 .79852 L .53901 .79855 L F
.896 .68 .601 r
.53947 .79845 m .53951 .79854 L .53917 .79852 L F
.53947 .79845 m .53917 .79852 L .53844 .79847 L F
.53951 .79854 m .53973 .79906 L .53844 .79847 L F
.692 .35 .391 r
.53917 .79852 m .53892 .79851 L .53901 .79855 L F
.746 .793 .891 r
.5415 .79593 m .53901 .79855 L .53891 .79706 L F
.595 .463 .671 r
.53823 .79909 m .54137 .79956 L .5415 .79593 L F
.378 .291 .63 r
.5415 .79593 m .54159 .79901 L .54211 .79756 L F
.866 .912 .508 r
.54159 .79901 m .5417 .79955 L .54205 .79787 L F
.595 .463 .671 r
.54137 .79956 m .54159 .79901 L .5415 .79593 L F
.859 .778 .771 r
.54211 .79756 m .54132 .79954 L .53948 .79923 L F
.866 .912 .508 r
.54211 .79758 m .54211 .79758 L .54211 .79756 L F
.54211 .79758 m .54211 .79758 L .54211 .79756 L F
.378 .291 .63 r
.54159 .79901 m .54161 .79959 L .54211 .79756 L F
.866 .912 .508 r
.54137 .79956 m .54139 .79956 L .54159 .79901 L F
.54139 .79956 m .5417 .79955 L .54159 .79901 L F
.54165 .79964 m .5417 .79955 L .54137 .79956 L F
.595 .463 .671 r
.54137 .79956 m .54161 .79959 L .54159 .79901 L F
.866 .912 .508 r
.5409 .80071 m .54205 .79787 L .54211 .79758 L F
.859 .778 .771 r
.54211 .79756 m .54161 .79959 L .54132 .79954 L F
.866 .912 .508 r
.5409 .80071 m .54165 .79964 L .54137 .79956 L F
0 .508 .732 r
.54132 .79954 m .54137 .79956 L .53823 .79909 L F
.866 .912 .508 r
.5405 .80129 m .5409 .80071 L .54211 .79758 L F
.859 .778 .771 r
.54126 .79953 m .54152 .80028 L .5405 .80129 L F
.866 .912 .508 r
.5405 .80129 m .54211 .79758 L .54211 .79758 L F
.859 .778 .771 r
.54211 .79756 m .54168 .79955 L .54126 .79953 L F
0 .508 .732 r
.54132 .79954 m .54161 .79959 L .54137 .79956 L F
.859 .778 .771 r
.54168 .79955 m .54152 .80028 L .54126 .79953 L F
0 .508 .732 r
.53948 .79923 m .5412 .79952 L .53823 .79909 L F
.5412 .79952 m .54132 .79954 L .54118 .79952 L F
.5412 .79952 m .54118 .79952 L .53823 .79909 L F
.258 .763 .741 r
.5428 .79748 m .5416 .79791 L .54279 .79748 L F
.894 .961 .63 r
.54211 .79758 m .5417 .79955 L .54253 .79752 L F
.54211 .79758 m .54253 .79752 L .54257 .79742 L F
.258 .763 .741 r
.54282 .79747 m .5428 .79748 L .54279 .79748 L F
.953 .792 .645 r
.59281 .71996 m .59132 .72007 L .59215 .71851 L F
.898 .89 .814 r
.59441 .7175 m .59281 .71996 L .59215 .71851 L F
.26 .666 .966 r
.30924 .59288 m .30872 .5937 L .30725 .59282 L F
.30924 .59288 m .31083 .5939 L .30872 .5937 L F
.55 .547 .804 r
.57518 .67891 m .57648 .67527 L .57485 .67594 L F
.57518 .67891 m .57763 .67863 L .57648 .67527 L F
.822 .501 .447 r
.61134 .72533 m .61467 .72814 L .61464 .7263 L F
.925 .934 .791 r
.59645 .71433 m .59349 .71681 L .59596 .71389 L F
.59645 .71433 m .59441 .7175 L .59349 .71681 L F
.189 .343 .788 r
.67995 .50734 m .68218 .50942 L .68085 .5063 L F
.632 .071 0 r
.30062 .82517 m .30176 .82545 L .30026 .82485 L F
.30062 .82517 m .30216 .82579 L .30176 .82545 L F
0 .15 .599 r
.55816 .73112 m .56196 .73388 L .56065 .73261 L F
.452 .357 .657 r
.76078 .59376 m .76141 .59563 L .75946 .59597 L F
.562 .425 .652 r
.76185 .59748 m .75946 .59597 L .76141 .59563 L F
.76185 .59748 m .75953 .59824 L .75946 .59597 L F
.331 .768 .967 r
.42178 .65123 m .42395 .65106 L .42527 .65159 L F
.361 .718 .987 r
.42606 .65061 m .42527 .65159 L .42395 .65106 L F
.42606 .65061 m .42738 .65162 L .42527 .65159 L F
.578 .901 .983 r
.39793 .83066 m .39825 .83145 L .39673 .83113 L F
.39793 .83066 m .39825 .83145 L .39673 .83113 L F
.505 .188 .363 r
.45156 .679 m .45051 .6814 L .44839 .68166 L F
.593 .278 .406 r
.45358 .68079 m .45156 .679 L .45388 .67876 L F
.45358 .68079 m .45051 .6814 L .45156 .679 L F
.808 .767 .815 r
.4861 .77414 m .48709 .77607 L .48957 .77369 L F
.4861 .77414 m .48957 .77369 L .48848 .77333 L F
.531 .903 .959 r
.48848 .77333 m .48957 .77369 L .49152 .7729 L F
.488 .272 .512 r
.31814 .63747 m .32055 .63474 L .32005 .63649 L F
.327 .085 .386 r
.32005 .63649 m .31755 .63929 L .31814 .63747 L F
0 0 0 r
.53157 .80271 m .53048 .80343 L .53264 .80161 L F
0 0 .455 r
.53171 .80519 m .53048 .80343 L .53157 .80271 L F
0 0 0 r
.52934 .80552 m .53048 .80343 L .53157 .80271 L F
.706 .515 .628 r
.52183 .73723 m .52503 .73971 L .52372 .7364 L F
.52183 .73723 m .52154 .74004 L .52503 .73971 L F
.838 .393 0 r
.66943 .51591 m .66915 .51667 L .66862 .51472 L F
.66943 .51591 m .67036 .51777 L .66915 .51667 L F
.487 .754 .989 r
.27945 .64001 m .27869 .64145 L .27736 .64049 L F
.27945 .64001 m .2809 .64126 L .27869 .64145 L F
0 0 .014 r
.61355 .74836 m .61565 .74533 L .61504 .74736 L F
0 0 0 r
.61355 .74836 m .61504 .74736 L .61267 .7501 L F
.397 .028 .216 r
.48405 .74161 m .48665 .7394 L .48493 .73974 L F
.845 .462 .322 r
.55297 .71105 m .55042 .70884 L .55314 .70995 L F
.459 .783 .998 r
.35048 .70398 m .35148 .70102 L .3497 .70163 L F
.702 .292 0 r
.5803 .73705 m .58003 .73689 L .57856 .73404 L F
0 .003 .551 r
.58185 .73932 m .58003 .73689 L .5803 .73705 L F
.462 .652 .942 r
.41415 .64399 m .41707 .64519 L .41506 .64556 L F
.368 .78 .98 r
.41506 .64556 m .41707 .64519 L .41356 .6448 L F
.627 .264 .334 r
.53303 .7372 m .53526 .739 L .53631 .73673 L F
.661 .351 .437 r
.53526 .739 m .53868 .73679 L .53631 .73673 L F
.53 .679 .933 r
.33309 .59796 m .32905 .59612 L .33117 .59606 L F
.322 .604 .949 r
.33476 .59804 m .33309 .59796 L .33117 .59606 L F
.215 .715 .91 r
.52139 .77846 m .52229 .77883 L .51884 .77852 L F
.52139 .77846 m .52229 .77883 L .51884 .77852 L F
.701 .489 .598 r
.51486 .79785 m .51242 .80016 L .51248 .79794 L F
.242 .745 .894 r
.45423 .7871 m .45076 .78705 L .4521 .78754 L F
.969 .714 .492 r
.5429 .70354 m .54157 .70048 L .54226 .70186 L F
.571 .317 .492 r
.46184 .6736 m .46177 .67557 L .4593 .67579 L F
.656 .387 .5 r
.46184 .6736 m .46417 .67591 L .46177 .67557 L F
.601 .392 .569 r
.46425 .67336 m .46417 .67591 L .46184 .6736 L F
.224 .493 .898 r
.58166 .74887 m .58265 .74787 L .58184 .74725 L F
.58166 .74887 m .58419 .74992 L .58265 .74787 L F
.366 .365 .726 r
.34657 .68732 m .34861 .68919 L .34856 .68695 L F
.331 0 0 r
.74638 .5913 m .74838 .59211 L .74594 .59261 L F
.74638 .5913 m .74899 .59157 L .74838 .59211 L F
.851 .825 .822 r
.52208 .76466 m .51845 .76636 L .52103 .76584 L F
.58 .165 .22 r
.52103 .76584 m .5243 .76433 L .52208 .76466 L F
.48 .192 .398 r
.72462 .71469 m .72687 .71446 L .72764 .71304 L F
.751 .831 .914 r
.35365 .72346 m .35524 .72467 L .35705 .72339 L F
.486 .198 .4 r
.43821 .68715 m .43539 .68918 L .43598 .68745 L F
.389 .145 .419 r
.32055 .63474 m .32291 .63206 L .32241 .63401 L F
.373 .114 .387 r
.32005 .63649 m .32055 .63474 L .32241 .63401 L F
.319 .08 .386 r
.32461 .63136 m .32291 .63206 L .32513 .62925 L F
.321 .084 .39 r
.32241 .63401 m .32291 .63206 L .32461 .63136 L F
.3 .347 .743 r
.58788 .75073 m .58866 .75464 L .59018 .75276 L F
.44 .551 .872 r
.58866 .75464 m .59169 .75542 L .59018 .75276 L F
.623 .374 .52 r
.45642 .67652 m .45634 .67875 L .45388 .67876 L F
.511 .239 .438 r
.4593 .67579 m .45634 .67875 L .45642 .67652 L F
.497 .883 .964 r
.63193 .52387 m .63127 .52477 L .62958 .52382 L F
.63193 .52387 m .63352 .52406 L .63127 .52477 L F
.653 .517 .685 r
.52372 .7364 m .52643 .73381 L .52409 .7345 L F
.453 .072 .225 r
.47845 .74438 m .48182 .742 L .47976 .74274 L F
0 0 0 r
.39791 .66683 m .39675 .66788 L .39933 .66521 L F
.27 0 .022 r
.40137 .66445 m .39791 .66683 L .39933 .66521 L F
.832 .764 .787 r
.63073 .49637 m .62785 .49766 L .62936 .49535 L F
.63073 .49637 m .62856 .49925 L .62785 .49766 L F
.612 .808 .975 r
.63461 .49613 m .63073 .49637 L .62936 .49535 L F
.57 .841 .996 r
.37261 .71957 m .37399 .72022 L .37603 .71962 L F
.686 .718 .874 r
.59003 .72325 m .59043 .72689 L .58843 .72585 L F
.362 0 .075 r
.59043 .72689 m .58823 .72848 L .58843 .72585 L F
.59043 .72689 m .5906 .7281 L .58823 .72848 L F
.856 .835 .824 r
.59226 .72419 m .59043 .72689 L .59003 .72325 L F
0 .411 .785 r
.5942 .72844 m .59311 .72773 L .59043 .72689 L F
.384 0 .072 r
.59043 .72689 m .59311 .72773 L .5906 .7281 L F
.214 0 0 r
.38459 .71584 m .38096 .71784 L .38191 .71673 L F
.334 .299 .67 r
.60736 .54544 m .60815 .54499 L .60643 .54347 L F
.586 .284 .424 r
.60815 .54499 m .60936 .54351 L .60643 .54347 L F
.334 .299 .67 r
.60736 .54544 m .60815 .54499 L .60643 .54347 L F
0 0 0 r
.50171 .72601 m .50313 .72508 L .50407 .72282 L F
.50171 .72601 m .50084 .72791 L .50313 .72508 L F
.513 .273 .488 r
.4641 .75109 m .46631 .75072 L .46657 .7485 L F
.491 .254 .483 r
.46657 .7485 m .46846 .75028 L .46891 .74825 L F
.46657 .7485 m .46631 .75072 L .46846 .75028 L F
.935 .689 .541 r
.67412 .52407 m .67251 .52609 L .67343 .52281 L F
.67412 .52407 m .67417 .52654 L .67251 .52609 L F
.681 .727 .884 r
.70021 .51422 m .70133 .51577 L .69807 .51523 L F
.614 .284 .388 r
.70133 .51577 m .698 .5176 L .69807 .51523 L F
.70133 .51577 m .70151 .51765 L .698 .5176 L F
.618 .702 .904 r
.70373 .51523 m .70133 .51577 L .70021 .51422 L F
.662 .319 .383 r
.7037 .51752 m .70151 .51765 L .70133 .51577 L F
.563 .376 .586 r
.70373 .51523 m .7037 .51752 L .70133 .51577 L F
.633 .338 .452 r
.51974 .75396 m .51983 .75592 L .51625 .75601 L F
.461 .247 .501 r
.52214 .75117 m .52175 .75352 L .51974 .75396 L F
.65 .351 .451 r
.51974 .75396 m .5219 .75602 L .51983 .75592 L F
.5 .362 .625 r
.52175 .75352 m .5219 .75602 L .51974 .75396 L F
.52175 .75352 m .5219 .75602 L .51974 .75396 L F
.343 .722 .985 r
.73813 .62195 m .73933 .62281 L .7413 .62277 L F
.491 .611 .899 r
.34372 .60091 m .34146 .6016 L .34181 .60114 L F
.34372 .60091 m .34566 .60376 L .34146 .6016 L F
.828 .759 .787 r
.63199 .50516 m .62988 .50711 L .63325 .507 L F
.641 .428 .578 r
.63066 .50994 m .63325 .507 L .62988 .50711 L F
.525 .559 .833 r
.63325 .507 m .63478 .50465 L .63199 .50516 L F
.63325 .507 m .63531 .50668 L .63478 .50465 L F
.401 .217 .513 r
.76048 .6176 m .75834 .61821 L .76031 .61518 L F
.509 .377 .637 r
.76048 .6176 m .75848 .62062 L .75834 .61821 L F
.14 0 0 r
.30044 .65126 m .29638 .65226 L .2984 .65183 L F
.30044 .65126 m .29843 .65202 L .29638 .65226 L F
.356 .79 .966 r
.29843 .65202 m .29744 .65197 L .29638 .65226 L F
.29744 .65197 m .29507 .65182 L .29638 .65226 L F
.215 .734 .727 r
.29461 .65274 m .29638 .65226 L .29436 .6528 L F
.2984 .65183 m .29638 .65226 L .29461 .65274 L F
.32 .708 .981 r
.28546 .5891 m .28499 .58998 L .28386 .58878 L F
.28546 .5891 m .28697 .59003 L .28499 .58998 L F
0 0 0 r
.58158 .74283 m .58167 .7418 L .58185 .73932 L F
0 .07 .594 r
.58178 .74524 m .58167 .7418 L .58158 .74283 L F
.415 0 .093 r
.73987 .58918 m .74223 .58901 L .7428 .58758 L F
.444 .256 .53 r
.745 .58462 m .7428 .58758 L .74514 .58728 L F
.39 .027 .223 r
.74223 .58901 m .74514 .58728 L .7428 .58758 L F
.653 .428 .566 r
.539 .7421 m .53913 .7453 L .53441 .74527 L F
.735 .493 .562 r
.53994 .74529 m .539 .7421 L .54003 .74265 L F
.53994 .74529 m .53913 .7453 L .539 .7421 L F
.898 .89 .814 r
.59441 .7175 m .59215 .71851 L .59349 .71681 L F
.27 .392 .803 r
.32805 .7195 m .3282 .71691 L .32608 .71716 L F
.32805 .7195 m .32954 .72006 L .3282 .71691 L F
.532 .218 .38 r
.57322 .76483 m .57369 .76703 L .57088 .76722 L F
.11 0 .39 r
.57401 .76457 m .57369 .76703 L .57322 .76483 L F
.342 .03 .284 r
.2966 .63425 m .29468 .6349 L .29412 .63641 L F
.988 .744 .469 r
.59545 .6898 m .59654 .69323 L .59531 .6924 L F
.951 .873 .724 r
.59654 .69323 m .59446 .69458 L .59531 .6924 L F
.59654 .69323 m .59559 .6954 L .59446 .69458 L F
.724 .596 .712 r
.68587 .52431 m .68387 .52644 L .6828 .52343 L F
.77 .554 .606 r
.64953 .51571 m .64632 .51809 L .64587 .51509 L F
.64953 .51571 m .65028 .51881 L .64632 .51809 L F
.372 .302 .649 r
.65206 .51759 m .64953 .51571 L .65153 .51496 L F
.65206 .51759 m .65028 .51881 L .64953 .51571 L F
.563 .316 .5 r
.55841 .77042 m .55752 .7735 L .55465 .77464 L F
.729 .484 .556 r
.56072 .77297 m .55841 .77042 L .56069 .77043 L F
.56072 .77297 m .55752 .7735 L .55841 .77042 L F
.848 .817 .818 r
.59205 .73348 m .59356 .73019 L .59425 .73106 L F
.806 .991 .879 r
.6389 .52116 m .6398 .5191 L .64127 .51886 L F
.6389 .52116 m .63868 .52037 L .6398 .5191 L F
.916 .912 .517 r
.65757 .51698 m .65753 .51885 L .65843 .51607 L F
.682 .665 .827 r
.65488 .51964 m .65753 .51885 L .65757 .51698 L F
.65488 .51964 m .65836 .52047 L .65753 .51885 L F
.065 .621 .813 r
.39221 .64819 m .39425 .64828 L .39579 .64852 L F
.251 0 0 r
.39425 .64828 m .39793 .6487 L .39579 .64852 L F
.696 .473 .581 r
.7309 .59607 m .72744 .59827 L .72886 .59504 L F
.7309 .59607 m .7298 .59768 L .72744 .59827 L F
.462 .091 .248 r
.73299 .59736 m .7298 .59768 L .7309 .59607 L F
.606 .152 .147 r
.7309 .59607 m .73337 .59635 L .73299 .59736 L F
.388 .333 .674 r
.55323 .7518 m .55424 .75402 L .55481 .75232 L F
.422 0 0 r
.55481 .75232 m .55271 .75238 L .55323 .7518 L F
.561 .565 .815 r
.67908 .4958 m .67676 .49664 L .6759 .49387 L F
.401 .344 .679 r
.67935 .49804 m .67676 .49664 L .67908 .4958 L F
.67935 .49804 m .6773 .49896 L .67676 .49664 L F
0 0 0 r
.38417 .67343 m .38212 .67498 L .38059 .67557 L F
.38384 .67411 m .38417 .67343 L .38529 .67282 L F
.38384 .67411 m .38212 .67498 L .38417 .67343 L F
.122 0 .325 r
.38583 .67063 m .38529 .67282 L .38417 .67343 L F
0 0 0 r
.51641 .74253 m .51824 .74169 L .51987 .74038 L F
.156 .665 .902 r
.51824 .74169 m .52173 .74221 L .51987 .74038 L F
.508 .235 .435 r
.51987 .74038 m .52173 .74221 L .52154 .74004 L F
.53 .22 .386 r
.64967 .54583 m .64726 .54772 L .64743 .54635 L F
0 .127 .641 r
.66136 .51323 m .662 .5139 L .66167 .51397 L F
.674 .127 0 r
.66167 .51397 m .66522 .51657 L .66267 .5155 L F
.66167 .51397 m .66467 .51666 L .66522 .51657 L F
0 .127 .641 r
.662 .5139 m .66467 .51666 L .6628 .51498 L F
.662 .5139 m .6628 .51498 L .66167 .51397 L F
0 .145 .667 r
.6634 .51581 m .66381 .5167 L .66267 .5155 L F
.66522 .51657 m .66404 .51668 L .6634 .51581 L F
.66404 .51668 m .66381 .5167 L .6634 .51581 L F
0 0 0 r
.28287 .60542 m .28501 .60412 L .28713 .60343 L F
.464 .765 .995 r
.7482 .61355 m .74636 .61407 L .74465 .61294 L F
.113 .663 .809 r
.29077 .60348 m .28924 .60336 L .28713 .60343 L F
.036 0 0 r
.29287 .60334 m .28924 .60336 L .29077 .60348 L F
.702 .725 .868 r
.67008 .49145 m .66723 .49071 L .66954 .49023 L F
.594 .606 .834 r
.67181 .4896 m .67008 .49145 L .66954 .49023 L F
.67181 .4896 m .67244 .491 L .67008 .49145 L F
.282 0 0 r
.36584 .65539 m .36522 .65424 L .36388 .656 L F
.36584 .65539 m .36737 .65388 L .36522 .65424 L F
.919 .698 .588 r
.33289 .70652 m .33439 .70991 L .33368 .70818 L F
.534 .26 .446 r
.43333 .68971 m .43286 .69274 L .43041 .69303 L F
.455 .192 .424 r
.43496 .69224 m .43333 .68971 L .43539 .68918 L F
.43496 .69224 m .43286 .69274 L .43333 .68971 L F
.121 0 0 r
.38658 .64846 m .38873 .6484 L .39 .64812 L F
.217 0 0 r
.38873 .6484 m .39221 .64819 L .39 .64812 L F
.322 .322 .704 r
.35266 .71513 m .35338 .71159 L .35174 .71226 L F
.35266 .71513 m .35424 .71445 L .35338 .71159 L F
.468 .296 .563 r
.35266 .71513 m .3544 .71701 L .35424 .71445 L F
.35266 .71513 m .35255 .71759 L .3544 .71701 L F
.445 .226 .486 r
.32513 .62925 m .3274 .62649 L .327 .62864 L F
.431 .185 .438 r
.327 .62864 m .32461 .63136 L .32513 .62925 L F
.563 .587 .835 r
.34101 .71516 m .34313 .71484 L .34205 .71203 L F
.525 .441 .703 r
.76329 .60287 m .76165 .60704 L .76059 .60353 L F
.76329 .60287 m .76387 .60659 L .76165 .60704 L F
.576 .565 .805 r
.76502 .60978 m .76165 .60704 L .76387 .60659 L F
.633 .601 .8 r
.72929 .71364 m .73169 .71374 L .72999 .7132 L F
.591 .682 .904 r
.46064 .66834 m .45751 .66726 L .45953 .6669 L F
.637 .736 .92 r
.46286 .66769 m .46064 .66834 L .45953 .6669 L F
.493 .88 .698 r
.75089 .61193 m .7482 .61355 L .74936 .61281 L F
0 0 0 r
.74936 .61281 m .75289 .6115 L .75089 .61193 L F
.409 .167 .432 r
.33443 .61835 m .33673 .61573 L .33603 .61752 L F
.336 .041 .308 r
.33603 .61752 m .33673 .61573 L .33866 .61509 L F
.711 .864 .954 r
.7413 .62277 m .74461 .62259 L .74345 .62172 L F
.736 .866 .941 r
.74461 .62259 m .74618 .61999 L .74345 .62172 L F
.74461 .62259 m .74736 .62107 L .74618 .61999 L F
.695 .703 .854 r
.62785 .49766 m .62856 .49925 L .62515 .49863 L F
.729 .321 .273 r
.51424 .79701 m .51509 .7955 L .51167 .79464 L F
.78 .383 .301 r
.51424 .79701 m .51679 .79764 L .51509 .7955 L F
.536 .245 .42 r
.41543 .68964 m .41771 .68942 L .4184 .68673 L F
.532 .269 .462 r
.41771 .68942 m .42042 .68696 L .4184 .68673 L F
.718 .39 .424 r
.51167 .79464 m .50777 .79321 L .50787 .79435 L F
.204 0 .277 r
.30879 .62097 m .31068 .62004 L .3111 .61805 L F
.248 .114 .494 r
.30879 .62097 m .31033 .62237 L .31068 .62004 L F
.30879 .62097 m .30863 .62336 L .31033 .62237 L F
0 0 .372 r
.34149 .71155 m .34197 .70919 L .34071 .71082 L F
.52 0 0 r
.49525 .79158 m .49308 .79056 L .49179 .7912 L F
.77 .544 .591 r
.48816 .76771 m .48816 .77019 L .48461 .76984 L F
.144 0 0 r
.57087 .7228 m .56812 .72045 L .56947 .72145 L F
.544 .391 .624 r
.49828 .76449 m .49627 .76769 L .4961 .76488 L F
.195 0 .273 r
.3111 .61805 m .31216 .6194 L .31316 .61734 L F
.3111 .61805 m .31068 .62004 L .31216 .6194 L F
.561 .374 .585 r
.43036 .6762 m .4326 .67605 L .43274 .67271 L F
.638 .587 .781 r
.43274 .67271 m .4355 .67344 L .43454 .67049 L F
.585 .394 .589 r
.43274 .67271 m .43475 .67523 L .4355 .67344 L F
.43274 .67271 m .4326 .67605 L .43475 .67523 L F
.586 .315 .472 r
.65259 .54334 m .65219 .54574 L .64967 .54583 L F
.443 .162 .391 r
.65496 .54287 m .65219 .54574 L .65259 .54334 L F
.432 .076 .259 r
.51012 .71434 m .51238 .71418 L .51323 .712 L F
.419 .081 .283 r
.51238 .71418 m .51576 .71134 L .51323 .712 L F
.882 .77 .734 r
.59555 .70159 m .59445 .70388 L .59387 .70067 L F
.214 0 0 r
.38459 .71584 m .38298 .71742 L .38096 .71784 L F
0 0 0 r
.38488 .71654 m .38459 .71584 L .38645 .71529 L F
.38488 .71654 m .38298 .71742 L .38459 .71584 L F
.439 .421 .742 r
.75372 .59832 m .75429 .60258 L .75652 .60009 L F
.849 .865 .853 r
.75531 .60352 m .75652 .60009 L .75429 .60258 L F
.415 .2 .476 r
.327 .62864 m .3274 .62649 L .32924 .62574 L F
.527 .28 .484 r
.42578 .68175 m .42808 .68141 L .42858 .67919 L F
.479 .236 .467 r
.42858 .67919 m .43016 .68092 L .43038 .67853 L F
.42858 .67919 m .42808 .68141 L .43016 .68092 L F
.181 .492 .903 r
.65867 .50856 m .65646 .50673 L .65772 .5072 L F
.006 .452 .867 r
.65982 .50842 m .65867 .50856 L .65772 .5072 L F
0 .344 .808 r
.65908 .50737 m .65982 .50842 L .65932 .50813 L F
.65908 .50737 m .65932 .50813 L .65772 .5072 L F
0 0 .477 r
.65896 .50641 m .65908 .50737 L .65894 .50702 L F
.65896 .50641 m .65894 .50702 L .65791 .50427 L F
.843 .618 .598 r
.66045 .50257 m .6603 .50486 L .65791 .50427 L F
0 .426 .791 r
.6603 .50486 m .66041 .50474 L .65791 .50427 L F
.87 .442 .024 r
.66045 .50257 m .66269 .50573 L .6603 .50486 L F
0 .426 .791 r
.66041 .50474 m .66045 .50469 L .66031 .50466 L F
.66041 .50474 m .66031 .50466 L .65791 .50427 L F
.231 .65 .958 r
.65791 .50427 m .66045 .50469 L .66026 .50367 L F
.149 .203 .663 r
.66026 .50367 m .65896 .50641 L .65791 .50427 L F
.99 .868 .617 r
.65897 .50541 m .65896 .50641 L .65993 .50437 L F
.65981 .50428 m .65993 .50437 L .66026 .50367 L F
.65897 .50541 m .65993 .50437 L .65981 .50428 L F
0 .344 .808 r
.65908 .50737 m .65772 .5072 L .65714 .50553 L F
.074 .254 .743 r
.65908 .50737 m .65714 .50553 L .65791 .50427 L F
.99 .868 .617 r
.65741 .50754 m .65896 .50641 L .65897 .50541 L F
.907 .877 .447 r
.65896 .50641 m .65886 .50671 L .65908 .50737 L F
.65886 .50671 m .65827 .5085 L .65908 .50737 L F
.919 .723 .231 r
.65909 .50749 m .65982 .50842 L .65908 .50737 L F
.006 .452 .867 r
.65982 .50842 m .66046 .50924 L .65867 .50856 L F
.919 .723 .231 r
.65937 .50959 m .65982 .50842 L .65909 .50749 L F
.006 .452 .867 r
.65982 .50842 m .66056 .50928 L .66046 .50924 L F
.768 .713 .801 r
.65111 .51189 m .64775 .5121 L .65042 .51029 L F
.77 .839 .904 r
.65379 .51 m .65111 .51189 L .65042 .51029 L F
.023 0 .243 r
.70366 .58756 m .70304 .58974 L .70457 .58664 L F
.55 .297 .485 r
.63737 .50605 m .63764 .50431 L .63539 .50464 L F
.63781 .50637 m .63764 .50431 L .63539 .50464 L F
.588 .564 .795 r
.63528 .50656 m .63708 .50341 L .63478 .50465 L F
.63531 .50668 m .63539 .50653 L .63528 .50656 L F
.63539 .50653 m .63708 .50341 L .63528 .50656 L F
.55 .297 .485 r
.63781 .50637 m .63778 .50595 L .63737 .50605 L F
.63778 .50595 m .63764 .50431 L .63737 .50605 L F
.603 .504 .714 r
.50542 .73153 m .50354 .73452 L .50329 .73199 L F
.015 0 0 r
.26569 .61208 m .26295 .6147 L .2641 .61307 L F
0 0 0 r
.48385 .77437 m .4845 .77446 L .4823 .7727 L F
.48385 .77437 m .4861 .77414 L .4845 .77446 L F
.965 .675 .257 r
.68016 .51287 m .68006 .5145 L .68094 .5156 L F
.974 .697 .291 r
.68006 .5145 m .68099 .51769 L .68094 .5156 L F
.658 .581 .757 r
.68016 .51287 m .68094 .5156 L .68232 .51232 L F
0 .15 .599 r
.55816 .73112 m .56095 .7331 L .56196 .73388 L F
.462 0 0 r
.56171 .73397 m .56196 .73388 L .56095 .7331 L F
.56171 .73397 m .56293 .73457 L .56196 .73388 L F
.911 .884 .46 r
.59189 .68493 m .5911 .68623 L .59109 .68394 L F
.59189 .68493 m .59109 .68772 L .5911 .68623 L F
.71 .436 .509 r
.48855 .75367 m .48793 .7562 L .48441 .75595 L F
.627 .355 .486 r
.48855 .75367 m .4888 .75775 L .48793 .7562 L F
0 0 0 r
.71624 .60075 m .71975 .59944 L .71994 .59984 L F
.566 0 0 r
.71975 .59944 m .72193 .60068 L .71994 .59984 L F
.5 .323 .573 r
.72182 .59835 m .72193 .60068 L .71975 .59944 L F
.418 .142 .385 r
.33178 .62085 m .33443 .61835 L .33378 .62031 L F
.244 0 .312 r
.33378 .62031 m .33443 .61835 L .33603 .61752 L F
.821 .657 .68 r
.62781 .51199 m .63244 .51305 L .63066 .50994 L F
.572 .645 .884 r
.62781 .51199 m .63141 .51396 L .63244 .51305 L F
.417 .489 .826 r
.63066 .50994 m .63244 .51305 L .63354 .51238 L F
.621 .396 .554 r
.63141 .51396 m .63354 .51238 L .63244 .51305 L F
.24 0 .023 r
.73299 .59736 m .73337 .59635 L .73556 .59565 L F
.973 .852 .661 r
.60348 .69745 m .60532 .69581 L .60385 .69467 L F
.60348 .69745 m .60456 .69846 L .60532 .69581 L F
.659 .285 .325 r
.69148 .52371 m .69103 .5252 L .68767 .52492 L F
.808 .8 .845 r
.69348 .52089 m .69148 .52371 L .68946 .52216 L F
.54 .418 .662 r
.69348 .52089 m .69383 .52357 L .69148 .52371 L F
.551 .236 .387 r
.69383 .52357 m .69103 .5252 L .69148 .52371 L F
.614 .401 .568 r
.53563 .76194 m .53791 .76184 L .53824 .75944 L F
.67 .532 .688 r
.53791 .76184 m .54019 .75872 L .53824 .75944 L F
.543 .379 .609 r
.51641 .74253 m .51904 .74306 L .51824 .74169 L F
.51641 .74253 m .51736 .74484 L .51904 .74306 L F
.216 0 .11 r
.50557 .7682 m .50424 .77009 L .50742 .76744 L F
.553 .531 .784 r
.50534 .76753 m .50557 .7682 L .50742 .76744 L F
.863 .951 .868 r
.50742 .76744 m .50374 .76945 L .50477 .76781 L F
.50742 .76744 m .50424 .77009 L .50374 .76945 L F
.283 0 0 r
.50477 .76781 m .50949 .76736 L .50742 .76744 L F
.50949 .76736 m .50975 .76733 L .50742 .76744 L F
.553 .531 .784 r
.50415 .76407 m .50534 .76753 L .50742 .76744 L F
.491 .273 .511 r
.52417 .75135 m .52175 .75352 L .52214 .75117 L F
.52417 .75135 m .52175 .75352 L .52214 .75117 L F
.612 .808 .975 r
.63461 .49613 m .62936 .49535 L .63166 .49279 L F
.199 .402 .836 r
.63401 .49247 m .63461 .49613 L .63166 .49279 L F
.63401 .49247 m .63575 .49589 L .63461 .49613 L F
.629 .657 .858 r
.63782 .49412 m .63575 .49589 L .63401 .49247 L F
.748 .921 .558 r
.63661 .49405 m .63585 .49516 L .63575 .49589 L F
.215 .658 .951 r
.63461 .49613 m .63575 .49589 L .63569 .49634 L F
.748 .921 .558 r
.63585 .49516 m .63402 .49778 L .63575 .49589 L F
.215 .658 .951 r
.63569 .49634 m .63575 .49589 L .63577 .49636 L F
.466 .399 .698 r
.44637 .76221 m .4487 .76419 L .44877 .76172 L F
.44637 .76221 m .44682 .76502 L .4487 .76419 L F
.475 .895 .889 r
.26629 .65645 m .26744 .65639 L .26944 .65556 L F
.647 .593 .78 r
.72789 .71737 m .72929 .71364 L .72687 .71446 L F
.72789 .71737 m .73028 .71672 L .72929 .71364 L F
.604 .714 .922 r
.72789 .71737 m .73133 .71775 L .73028 .71672 L F
.921 .668 .538 r
.66369 .50423 m .66521 .50665 L .66376 .50693 L F
0 .227 .659 r
.6673 .50921 m .66376 .50693 L .66521 .50665 L F
.052 0 .017 r
.54954 .73545 m .5492 .73666 L .54732 .73751 L F
.557 .117 .16 r
.5525 .73633 m .5492 .73666 L .54954 .73545 L F
.563 .204 .317 r
.54377 .69986 m .54737 .69757 L .54499 .69839 L F
.554 .654 .902 r
.76022 .58753 m .7566 .58556 L .75902 .58533 L F
.588 .671 .897 r
.76179 .58577 m .76022 .58753 L .75902 .58533 L F
.76179 .58577 m .76257 .58707 L .76022 .58753 L F
.545 .561 .822 r
.76363 .59036 m .76022 .58753 L .76257 .58707 L F
0 0 .027 r
.61504 .74736 m .61565 .74533 L .6171 .74444 L F
.903 .761 .266 r
.61668 .74565 m .6171 .74444 L .61684 .74372 L F
0 0 .019 r
.61504 .74736 m .6171 .74444 L .61662 .74632 L F
.903 .761 .266 r
.61662 .74632 m .6171 .74444 L .61668 .74565 L F
0 0 0 r
.61565 .74533 m .61755 .74317 L .6171 .74444 L F
.61755 .74317 m .61801 .74266 L .6171 .74444 L F
.781 .458 .441 r
.48693 .79528 m .48886 .79498 L .48722 .79723 L F
.762 .432 .428 r
.48886 .79498 m .49064 .79765 L .48722 .79723 L F
.76 .86 .923 r
.65133 .50378 m .64903 .50147 L .65128 .50111 L F
.65133 .50378 m .64972 .50338 L .64903 .50147 L F
.441 .581 .896 r
.65422 .50267 m .65133 .50378 L .65128 .50111 L F
.65422 .50267 m .65428 .50425 L .65133 .50378 L F
.903 .654 .552 r
.60009 .6839 m .60045 .68145 L .59832 .68101 L F
.632 .27 .339 r
.72443 .60732 m .72411 .60874 L .72093 .60892 L F
.518 .516 .793 r
.725 .60656 m .72443 .60732 L .72303 .60372 L F
.496 .346 .607 r
.6744 .51052 m .67654 .51176 L .6766 .50955 L F
.615 .103 .008 r
.6744 .51052 m .67307 .51139 L .67654 .51176 L F
.427 .557 .883 r
.43101 .66627 m .43194 .66415 L .42978 .66453 L F
.43101 .66627 m .43357 .6671 L .43194 .66415 L F
.447 .054 .199 r
.2906 .63863 m .29412 .63641 L .29205 .63672 L F
.701 .213 .084 r
.58747 .67318 m .59147 .67521 L .5894 .67309 L F
.546 .738 .964 r
.6548 .51533 m .65843 .51607 L .65579 .51449 L F
.916 .912 .517 r
.65757 .51698 m .65843 .51607 L .6548 .51533 L F
.196 .697 .911 r
.65739 .51414 m .66019 .51477 L .66148 .5132 L F
.6572 .51418 m .65751 .51424 L .65739 .51414 L F
.65751 .51424 m .66019 .51477 L .65739 .51414 L F
.57 .743 .958 r
.65579 .51449 m .65843 .51607 L .65883 .51542 L F
.196 .697 .911 r
.6572 .51418 m .65945 .51438 L .66019 .51477 L F
.6572 .51418 m .65945 .51438 L .66019 .51477 L F
.57 .743 .958 r
.65773 .51444 m .65883 .51542 L .65945 .51438 L F
.65579 .51449 m .65883 .51542 L .65773 .51444 L F
.751 .982 .91 r
.65945 .51438 m .65843 .51607 L .66019 .51477 L F
.866 .793 .777 r
.5457 .74391 m .54726 .74564 L .54875 .743 L F
.023 0 0 r
.54875 .743 m .55061 .74217 L .55164 .74052 L F
.39 .402 .752 r
.54875 .743 m .55137 .74494 L .55061 .74217 L F
.723 .221 .04 r
.52835 .71711 m .53047 .71907 L .53154 .71813 L F
.554 .015 0 r
.53154 .71813 m .53047 .71907 L .53393 .71942 L F
.526 .41 .664 r
.4487 .75931 m .45041 .75632 L .44814 .75677 L F
.457 .126 .316 r
.42147 .69809 m .42013 .70055 L .41791 .70085 L F
.333 .001 .244 r
.42214 .69986 m .42147 .69809 L .42323 .69719 L F
.42214 .69986 m .42013 .70055 L .42147 .69809 L F
.867 .827 .806 r
.67397 .50063 m .67537 .50205 L .6773 .49896 L F
.083 0 .38 r
.5492 .73666 m .54759 .73946 L .54732 .73751 L F
0 .048 .61 r
.57752 .73204 m .57856 .73404 L .57754 .73103 L F
.957 .838 .685 r
.58086 .71354 m .58099 .71715 L .58032 .7151 L F
.471 .58 .883 r
.72994 .621 m .73253 .62128 L .73134 .61926 L F
.531 .256 .443 r
.44613 .68189 m .44589 .68371 L .44378 .68393 L F
.457 .155 .364 r
.44839 .68166 m .44589 .68371 L .44613 .68189 L F
.943 .604 .352 r
.54687 .73979 m .54949 .74185 L .54759 .73946 L F
.54687 .73979 m .54668 .74084 L .54949 .74185 L F
0 0 .271 r
.54668 .74084 m .5457 .74391 L .54949 .74185 L F
.769 .69 .775 r
.72303 .60372 m .7211 .60792 L .71963 .60345 L F
.036 0 0 r
.59394 .75553 m .59169 .75542 L .59234 .75643 L F
.459 .192 .42 r
.46891 .74825 m .47109 .74782 L .47173 .74499 L F
.398 .138 .399 r
.47173 .74499 m .47308 .74715 L .47404 .74504 L F
.47173 .74499 m .47109 .74782 L .47308 .74715 L F
.547 .557 .817 r
.58489 .71141 m .58637 .70836 L .58483 .70952 L F
.957 .755 .59 r
.66388 .50131 m .663 .50537 L .66286 .50102 L F
.66388 .50131 m .66369 .50423 L .663 .50537 L F
.594 .429 .629 r
.66602 .5014 m .66369 .50423 L .66388 .50131 L F
.987 .718 .356 r
.58425 .71993 m .58441 .72285 L .58521 .72318 L F
.362 .797 .964 r
.58395 .72509 m .58521 .72318 L .58441 .72285 L F
.58395 .72509 m .58719 .72546 L .58521 .72318 L F
0 0 0 r
.61801 .74266 m .61965 .73937 L .6193 .74158 L F
.6171 .74444 m .61801 .74266 L .6193 .74158 L F
0 0 .141 r
.62903 .52213 m .62827 .52155 L .62899 .51999 L F
.62903 .52213 m .62734 .52348 L .62827 .52155 L F
.347 .1 .39 r
.37809 .67788 m .37797 .68082 L .37621 .68097 L F
.332 .151 .479 r
.38059 .67557 m .38034 .67796 L .37809 .67788 L F
.512 .316 .552 r
.38034 .67796 m .37797 .68082 L .37809 .67788 L F
.152 .69 .833 r
.41623 .66395 m .41491 .6638 L .41297 .66393 L F
.292 .785 .886 r
.41822 .66354 m .41491 .6638 L .41623 .66395 L F
.391 .783 .988 r
.26591 .64219 m .26953 .64263 L .26744 .64284 L F
.848 .658 .645 r
.54726 .74564 m .54427 .74751 L .5457 .74391 L F
.54726 .74564 m .5468 .74803 L .54427 .74751 L F
.503 0 0 r
.5457 .74391 m .54898 .74573 L .54726 .74564 L F
.54826 .74533 m .5483 .74556 L .54938 .74596 L F
.5457 .74391 m .5483 .74556 L .54826 .74533 L F
.037 0 0 r
.5483 .74556 m .54664 .74626 L .54834 .74589 L F
.503 0 0 r
.54898 .74573 m .54873 .74586 L .54726 .74564 L F
.426 .868 .892 r
.5483 .74556 m .55137 .74494 L .54938 .74596 L F
.037 0 0 r
.5483 .74556 m .54834 .74589 L .54974 .74559 L F
.426 .868 .892 r
.54924 .74533 m .54947 .74516 L .55037 .74506 L F
.5483 .74556 m .55037 .74506 L .55006 .74521 L F
0 0 .431 r
.55137 .74494 m .55238 .74138 L .55061 .74217 L F
.55137 .74494 m .55241 .74451 L .55238 .74138 L F
.28 .783 .825 r
.55137 .74494 m .54947 .74516 L .55241 .74451 L F
0 0 0 r
.54947 .74516 m .54974 .74559 L .55024 .74456 L F
.54947 .74516 m .55081 .74337 L .55241 .74451 L F
.54947 .74516 m .55024 .74456 L .55045 .74414 L F
.55081 .74337 m .55082 .74335 L .55084 .74336 L F
.592 .427 .628 r
.55085 .74331 m .55067 .74383 L .55063 .74376 L F
0 0 0 r
.55081 .74337 m .55062 .74377 L .55085 .74331 L F
.592 .427 .628 r
.55085 .74331 m .55063 .74376 L .54886 .7411 L F
0 0 0 r
.55062 .74377 m .55045 .74414 L .55085 .74331 L F
.54947 .74516 m .55045 .74414 L .55081 .74337 L F
.947 .678 .495 r
.54642 .74448 m .5483 .74556 L .5457 .74391 L F
.628 .434 .601 r
.55059 .74383 m .54642 .74448 L .54645 .7441 L F
.55067 .74383 m .55059 .74384 L .55059 .74383 L F
.55059 .74384 m .54642 .74448 L .55059 .74383 L F
.55019 .74347 m .54645 .7441 L .54668 .74084 L F
.55067 .74383 m .54645 .7441 L .55019 .74347 L F
0 0 0 r
.55081 .74337 m .55084 .74336 L .55241 .74451 L F
.55082 .74335 m .55085 .74331 L .55089 .74334 L F
.55082 .74335 m .55089 .74334 L .55241 .74451 L F
.628 .434 .601 r
.55041 .74343 m .54668 .74084 L .54886 .7411 L F
.55067 .74383 m .55019 .74347 L .55041 .74343 L F
.55019 .74347 m .54668 .74084 L .55041 .74343 L F
.635 .455 .622 r
.54974 .74559 m .54642 .74448 L .55059 .74384 L F
.54974 .74559 m .55059 .74384 L .55067 .74383 L F
0 0 0 r
.55024 .74456 m .54974 .74559 L .55024 .74456 L F
.426 .868 .892 r
.5483 .74556 m .54947 .74516 L .54924 .74533 L F
.55006 .74521 m .55037 .74506 L .55137 .74494 L F
.503 0 0 r
.54898 .74573 m .54938 .74596 L .54873 .74586 L F
.592 .539 .764 r
.4559 .6629 m .45386 .66392 L .45249 .65958 L F
.204 0 .11 r
.30773 .64754 m .30595 .64832 L .30864 .64621 L F
.275 0 .157 r
.30993 .64684 m .30864 .64621 L .31048 .64544 L F
.30993 .64684 m .30773 .64754 L .30864 .64621 L F
0 0 .185 r
.56128 .77133 m .56069 .77043 L .56237 .76998 L F
.56118 .77118 m .56072 .77297 L .56069 .77043 L F
.382 .075 .314 r
.55931 .77421 m .55752 .7735 L .56072 .77297 L F
0 0 .185 r
.56121 .77154 m .56072 .77297 L .56118 .77118 L F
.743 .939 .607 r
.56128 .77133 m .55931 .77421 L .56072 .77297 L F
.247 .054 .41 r
.56122 .7717 m .56121 .77423 L .55931 .77421 L F
.56161 .77119 m .56135 .7732 L .56122 .7717 L F
.56135 .7732 m .56121 .77423 L .56122 .7717 L F
0 0 .185 r
.56128 .77133 m .56121 .77154 L .56118 .77118 L F
0 .234 .734 r
.70673 .6009 m .70725 .60186 L .70867 .60284 L F
.884 .926 .845 r
.73199 .61785 m .73339 .61439 L .73481 .61565 L F
.73199 .61785 m .73058 .61793 L .73339 .61439 L F
0 0 .304 r
.60919 .54845 m .60908 .54765 L .60815 .54499 L F
.426 .5 .832 r
.60919 .54845 m .60815 .54499 L .60736 .54544 L F
.741 .993 .845 r
.60617 .55012 m .60919 .54845 L .60766 .55132 L F
.60617 .55012 m .60908 .54765 L .60919 .54845 L F
.752 .503 .555 r
.64089 .50652 m .64181 .50485 L .63764 .50431 L F
.653 .793 .949 r
.26034 .64231 m .26386 .64268 L .26178 .64353 L F
.834 .714 .732 r
.62077 .52045 m .62193 .52361 L .61894 .5234 L F
.832 .726 .748 r
.62193 .52361 m .61992 .52668 L .61894 .5234 L F
.806 .701 .75 r
.62269 .52178 m .62193 .52361 L .62077 .52045 L F
.312 .75 .967 r
.28327 .65289 m .28011 .65237 L .28154 .6532 L F
.536 .255 .436 r
.6272 .55373 m .62615 .55147 L .62809 .5513 L F
.6272 .55373 m .62506 .55418 L .62615 .55147 L F
.268 .699 .965 r
.29491 .60312 m .29647 .60391 L .29842 .60395 L F
.645 .489 .657 r
.76037 .60153 m .76059 .60353 L .75815 .60445 L F
.672 .558 .718 r
.76291 .60053 m .76037 .60153 L .75953 .59824 L F
.655 .512 .677 r
.76291 .60053 m .7631 .60241 L .76037 .60153 L F
.624 .474 .658 r
.76329 .60287 m .76037 .60153 L .7631 .60241 L F
.76329 .60287 m .76059 .60353 L .76037 .60153 L F
.567 .006 0 r
.54737 .69757 m .54929 .69838 L .55091 .69835 L F
.54737 .69757 m .54929 .69838 L .55091 .69835 L F
.881 .916 .845 r
.5519 .69502 m .55091 .69835 L .55263 .69535 L F
.5519 .69502 m .54929 .69838 L .55091 .69835 L F
.788 .993 .877 r
.55339 .69357 m .55263 .69535 L .55528 .69301 L F
.55339 .69357 m .5519 .69502 L .55263 .69535 L F
.774 .677 .757 r
.51021 .72594 m .5116 .72862 L .50805 .72827 L F
.747 .393 .383 r
.50805 .72827 m .5116 .72862 L .51038 .73141 L F
.642 .559 .746 r
.51149 .73144 m .51245 .73246 L .51035 .73293 L F
.733 .942 .952 r
.51355 .7305 m .51077 .7313 L .5116 .72862 L F
.51355 .7305 m .51239 .73027 L .51038 .73141 L F
.642 .559 .746 r
.51239 .73027 m .51243 .73162 L .51149 .73144 L F
.51243 .73162 m .51245 .73246 L .51149 .73144 L F
.733 .942 .952 r
.51077 .7313 m .51038 .73141 L .51046 .73124 L F
.51077 .7313 m .51046 .73124 L .5116 .72862 L F
.651 .285 .338 r
.51373 .72897 m .51355 .7305 L .5116 .72862 L F
.541 .515 .775 r
.45851 .66371 m .45751 .66726 L .45624 .66416 L F
.45851 .66371 m .45953 .6669 L .45751 .66726 L F
.505 .426 .7 r
.44728 .76746 m .4487 .76419 L .44682 .76502 L F
.526 .41 .664 r
.4487 .75931 m .45078 .75897 L .45041 .75632 L F
.423 .227 .508 r
.44877 .76172 m .45078 .75897 L .4487 .75931 L F
.695 .214 .103 r
.57365 .71191 m .5759 .71386 L .57733 .71294 L F
.476 .195 .407 r
.49192 .73406 m .49412 .7336 L .49457 .73173 L F
.227 0 .145 r
.49412 .7336 m .49672 .73136 L .49457 .73173 L F
.601 .414 .601 r
.51612 .72569 m .5161 .72883 L .51373 .72897 L F
.633 .44 .604 r
.52036 .72731 m .51612 .72569 L .51954 .72571 L F
.52036 .72731 m .5161 .72883 L .51612 .72569 L F
.392 .049 .259 r
.41049 .69203 m .4125 .69227 L .4133 .69011 L F
.463 .134 .323 r
.4125 .69227 m .41543 .68964 L .4133 .69011 L F
.677 .476 .606 r
.53204 .74547 m .53199 .74798 L .52971 .74785 L F
.702 .497 .607 r
.53734 .74764 m .53204 .74547 L .53441 .74527 L F
.53734 .74764 m .53199 .74798 L .53204 .74547 L F
.565 .608 .855 r
.63668 .49695 m .63577 .49636 L .63672 .49841 L F
.676 .977 .852 r
.63577 .49636 m .63575 .49589 L .63782 .49412 L F
.63577 .49636 m .63575 .49589 L .63782 .49412 L F
0 0 .417 r
.63575 .49589 m .63672 .49841 L .63577 .49636 L F
.738 .503 .572 r
.63315 .50023 m .63716 .50076 L .63672 .49841 L F
.63315 .50023 m .63672 .49841 L .63677 .49887 L F
.976 .682 .306 r
.63575 .49589 m .63673 .49877 L .63672 .49841 L F
.63673 .49877 m .63677 .49887 L .63672 .49841 L F
.565 .608 .855 r
.63986 .49902 m .63668 .49695 L .63672 .49841 L F
.917 .899 .794 r
.63716 .50076 m .63986 .49902 L .63672 .49841 L F
.63716 .50076 m .63796 .50183 L .63986 .49902 L F
.328 .627 .959 r
.28186 .58712 m .28123 .5883 L .27993 .58745 L F
.28186 .58712 m .28386 .58878 L .28123 .5883 L F
.751 .581 .666 r
.50892 .74029 m .50825 .74242 L .51041 .73959 L F
.463 0 0 r
.41274 .65001 m .41475 .65057 L .41633 .65015 L F
.468 0 0 r
.41633 .65015 m .41475 .65057 L .41828 .65077 L F
.375 .789 .979 r
.39793 .6487 m .39994 .64843 L .40134 .649 L F
.132 0 0 r
.39994 .64843 m .40332 .64907 L .40134 .649 L F
.456 .727 .984 r
.43155 .6507 m .43085 .65212 L .42965 .65125 L F
.43155 .6507 m .43298 .652 L .43085 .65212 L F
0 0 .48 r
.44988 .78176 m .45055 .78399 L .44995 .78085 L F
.672 .558 .718 r
.76291 .60053 m .75953 .59824 L .76185 .59748 L F
.667 .71 .88 r
.44396 .7786 m .44704 .77918 L .44698 .77803 L F
.324 .427 .813 r
.44698 .77803 m .44704 .77918 L .44825 .77791 L F
.368 .496 .857 r
.44704 .77918 m .44995 .78085 L .44825 .77791 L F
.464 .221 .459 r
.76502 .60978 m .76515 .61182 L .76253 .61224 L F
.577 .588 .827 r
.76622 .60614 m .76502 .60978 L .76387 .60659 L F
.76622 .60614 m .7674 .60927 L .76502 .60978 L F
.635 .347 .464 r
.76502 .60978 m .76753 .61176 L .76515 .61182 L F
.533 .378 .617 r
.7674 .60927 m .76753 .61176 L .76502 .60978 L F
.7674 .60927 m .76753 .61176 L .76502 .60978 L F
.973 .871 .485 r
.54456 .74902 m .54427 .74751 L .5468 .74803 L F
.54456 .74902 m .54372 .75038 L .54427 .74751 L F
.536 .416 .663 r
.34761 .66745 m .34972 .66763 L .34956 .66458 L F
.333 .33 .706 r
.34761 .66745 m .34994 .67033 L .34972 .66763 L F
.34761 .66745 m .34844 .67064 L .34994 .67033 L F
.929 .822 .718 r
.30167 .82693 m .30216 .82579 L .30062 .82517 L F
.858 .553 .47 r
.60292 .70573 m .60556 .70531 L .60429 .70384 L F
.784 .292 0 r
.59109 .68772 m .59117 .68888 L .5911 .68623 L F
.59109 .68772 m .59199 .68928 L .59117 .68888 L F
.71 .869 .957 r
.6259 .5147 m .629 .51477 L .62781 .51199 L F
.572 .645 .884 r
.62781 .51199 m .629 .51477 L .63141 .51396 L F
.9 .702 .625 r
.60292 .70573 m .60432 .7089 L .60556 .70531 L F
.477 .273 .524 r
.76253 .61224 m .7627 .61471 L .76031 .61518 L F
.555 .372 .588 r
.7627 .61471 m .76048 .6176 L .76031 .61518 L F
.548 .363 .582 r
.76515 .61182 m .7627 .61471 L .76253 .61224 L F
.474 .286 .545 r
.43036 .6762 m .43239 .67796 L .4326 .67605 L F
.43036 .6762 m .43038 .67853 L .43239 .67796 L F
.248 .325 .747 r
.62958 .52382 m .62734 .52348 L .62903 .52213 L F
0 .325 .72 r
.55233 .72722 m .5513 .72693 L .55102 .72639 L F
.087 .619 .865 r
.54898 .72595 m .55102 .72639 L .54755 .72616 L F
.17 .612 .938 r
.54898 .72595 m .55233 .72722 L .55102 .72639 L F
.54898 .72595 m .55119 .72637 L .55233 .72722 L F
.651 .189 0 r
.55138 .72659 m .55233 .72722 L .55119 .72637 L F
0 .325 .72 r
.55233 .72722 m .55327 .72784 L .5513 .72693 L F
.651 .189 0 r
.55316 .72866 m .55233 .72722 L .55138 .72659 L F
0 .325 .72 r
.55233 .72722 m .55349 .72794 L .55327 .72784 L F
.599 .167 .193 r
.46012 .75245 m .46273 .75275 L .4641 .75109 L F
.465 .054 .175 r
.46273 .75275 m .46631 .75072 L .4641 .75109 L F
.784 .339 .193 r
.55692 .73047 m .56095 .7331 L .55816 .73112 L F
.925 .653 .505 r
.60261 .68713 m .60269 .68946 L .60424 .69002 L F
.939 .666 .494 r
.60289 .69184 m .60424 .69002 L .60269 .68946 L F
.60289 .69184 m .60443 .69277 L .60424 .69002 L F
.381 0 0 r
.39675 .66788 m .39583 .66834 L .39356 .66821 L F
.538 .908 .731 r
.39791 .66683 m .39583 .66834 L .39675 .66788 L F
0 0 .083 r
.72908 .71176 m .72687 .71446 L .72764 .71304 L F
.347 .534 .896 r
.34705 .6036 m .34566 .60376 L .34372 .60091 L F
.438 .358 .669 r
.34785 .60605 m .34566 .60376 L .34705 .6036 L F
.34785 .60605 m .34582 .60696 L .34566 .60376 L F
.787 .842 .382 r
.59559 .6954 m .59469 .69708 L .59446 .69458 L F
.59559 .6954 m .59444 .69822 L .59469 .69708 L F
0 0 0 r
.54947 .69285 m .55089 .69204 L .55202 .69041 L F
.856 .835 .824 r
.59226 .72419 m .59003 .72325 L .59132 .72007 L F
.31 0 .1 r
.43011 .69391 m .42854 .69352 L .43041 .69303 L F
.43011 .69391 m .42783 .6945 L .42854 .69352 L F
.2 .187 .619 r
.52675 .7316 m .52766 .72795 L .52525 .72803 L F
.52675 .7316 m .52761 .7326 L .52766 .72795 L F
.51 .351 .601 r
.52643 .73381 m .52854 .73341 L .52675 .7316 L F
.71 .175 0 r
.52675 .7316 m .52854 .73341 L .52761 .7326 L F
.498 .12 .253 r
.49343 .76992 m .49031 .77192 L .49132 .77045 L F
.781 .287 .029 r
.55349 .72794 m .55692 .73047 L .55515 .72844 L F
.505 .336 .585 r
.33181 .62322 m .33178 .62085 L .33378 .62031 L F
.753 .696 .797 r
.593 .55121 m .59407 .55454 L .59105 .55324 L F
.593 .55121 m .59476 .5521 L .59407 .55454 L F
.828 .406 .237 r
.59105 .55324 m .59407 .55454 L .59263 .55566 L F
.564 .791 .984 r
.59407 .55454 m .59525 .55511 L .59263 .55566 L F
.539 .362 .589 r
.59642 .5515 m .59568 .55246 L .59476 .5521 L F
.59568 .55246 m .59407 .55454 L .59476 .5521 L F
.423 0 .058 r
.59336 .55155 m .59476 .5521 L .593 .55121 L F
.59488 .55299 m .59476 .5521 L .59336 .55155 L F
.539 .362 .589 r
.59642 .5515 m .59655 .55399 L .59407 .55454 L F
.564 .791 .984 r
.59407 .55454 m .59655 .55399 L .59488 .55299 L F
.59407 .55454 m .59488 .55299 L .59525 .55511 L F
.804 .518 .504 r
.6082 .7227 m .61134 .72533 L .61116 .72325 L F
.725 .745 .867 r
.48816 .77019 m .48647 .77161 L .48461 .76984 L F
.444 .791 .998 r
.46883 .77785 m .4712 .77766 L .47028 .7786 L F
0 0 .433 r
.4712 .77766 m .47101 .78009 L .47028 .7786 L F
.928 .805 .704 r
.6082 .7227 m .60955 .72045 L .60794 .71936 L F
.554 .381 .602 r
.50782 .71758 m .51012 .71434 L .50832 .71512 L F
.765 .649 .734 r
.5759 .71386 m .57805 .71118 L .57925 .71198 L F
.782 .594 .645 r
.57805 .71118 m .58149 .70936 L .57925 .71198 L F
.849 .865 .853 r
.75531 .60352 m .75612 .6034 L .75652 .60009 L F
.208 0 .344 r
.75531 .60626 m .75612 .6034 L .75531 .60352 L F
.307 .365 .759 r
.75652 .60009 m .75612 .6034 L .75891 .60196 L F
.307 .053 .355 r
.75612 .6034 m .75911 .60492 L .75891 .60196 L F
.75612 .6034 m .75639 .60637 L .75911 .60492 L F
.42 .807 .989 r
.46802 .76818 m .47111 .76829 L .47065 .76691 L F
.31 .405 .797 r
.47065 .76691 m .47111 .76829 L .47201 .76691 L F
.654 .869 .98 r
.47201 .76691 m .47111 .76829 L .47361 .76751 L F
.535 .403 .647 r
.44982 .75408 m .4525 .75589 L .4526 .75347 L F
.44982 .75408 m .45041 .75632 L .4525 .75589 L F
.791 .468 .442 r
.61467 .72814 m .61695 .73086 L .61813 .72876 L F
.814 .498 .455 r
.61813 .72876 m .61695 .73086 L .61896 .73083 L F
.507 .874 .982 r
.60351 .75496 m .60473 .754 L .60268 .75326 L F
.60351 .75496 m .60632 .75444 L .60473 .754 L F
.356 0 .097 r
.30773 .64754 m .30437 .6498 L .30595 .64832 L F
.75 .406 .401 r
.54525 .77612 m .54374 .77779 L .54205 .7758 L F
.467 .01 .081 r
.54525 .77612 m .54598 .77754 L .54374 .77779 L F
.54525 .77612 m .5474 .77598 L .54598 .77754 L F
.459 .783 .998 r
.35048 .70398 m .35049 .7029 L .35148 .70102 L F
.35048 .70398 m .35225 .70343 L .35049 .7029 L F
.439 .267 .549 r
.35048 .70398 m .35227 .70566 L .35225 .70343 L F
.35048 .70398 m .35033 .70691 L .35227 .70566 L F
.788 .678 .743 r
.65153 .51496 m .65277 .51828 L .6548 .51533 L F
.928 .605 .146 r
.65277 .51828 m .65153 .51496 L .6548 .51533 L F
.618 .948 .934 r
.65611 .51386 m .6548 .51533 L .65579 .51449 L F
.846 .73 .735 r
.66056 .50928 m .6572 .51418 L .66148 .5132 L F
0 0 0 r
.66016 .50997 m .6572 .51418 L .66056 .50928 L F
.65976 .51066 m .65958 .5108 L .66016 .50997 L F
.6579 .51321 m .6572 .51418 L .66016 .50997 L F
.919 .723 .231 r
.65937 .50959 m .65976 .51066 L .65982 .50842 L F
0 .128 .672 r
.65937 .50959 m .65999 .51048 L .65976 .51066 L F
.65999 .51048 m .6613 .51238 L .65976 .51066 L F
0 0 0 r
.65976 .51066 m .6579 .51321 L .65958 .5108 L F
0 0 .374 r
.65757 .51698 m .65665 .51501 L .65945 .51438 L F
.453 .791 .999 r
.65579 .51449 m .6564 .51448 L .65611 .51386 L F
.65703 .51446 m .65945 .51438 L .65732 .51405 L F
0 0 .374 r
.65665 .51501 m .65611 .51386 L .65732 .51405 L F
.65665 .51501 m .65732 .51405 L .65945 .51438 L F
.811 .675 .714 r
.65611 .51386 m .65757 .51698 L .6548 .51533 L F
.505 .254 .468 r
.4172 .70266 m .41564 .7011 L .41791 .70085 L F
.4172 .70266 m .41532 .70314 L .41564 .7011 L F
.701 .489 .598 r
.51486 .79785 m .51469 .80063 L .51242 .80016 L F
.815 .614 .632 r
.52525 .72803 m .52171 .72572 L .52519 .72603 L F
.48 .381 .666 r
.52519 .72603 m .52766 .72795 L .52525 .72803 L F
.52519 .72603 m .52766 .72795 L .52525 .72803 L F
.456 .197 .432 r
.74706 .58646 m .745 .58462 L .74514 .58728 L F
.74706 .58646 m .74711 .58404 L .745 .58462 L F
.116 0 0 r
.27617 .6071 m .27318 .60846 L .2741 .60772 L F
.733 .591 .698 r
.52972 .73676 m .53294 .73892 L .53303 .7372 L F
.567 .294 .461 r
.53294 .73892 m .53526 .739 L .53303 .7372 L F
.692 .666 .82 r
.76493 .58664 m .76363 .59036 L .76257 .58707 L F
.76493 .58664 m .76543 .58946 L .76363 .59036 L F
.238 0 .074 r
.76363 .59036 m .76515 .5913 L .76342 .59168 L F
.76363 .59036 m .76543 .58946 L .76515 .5913 L F
.042 0 .333 r
.50407 .72282 m .50535 .72221 L .50568 .72005 L F
0 0 .033 r
.50407 .72282 m .50313 .72508 L .50535 .72221 L F
.298 0 0 r
.46698 .78958 m .46869 .79033 L .46887 .79042 L F
.557 .646 .894 r
.6496 .49859 m .64903 .50147 L .6479 .49836 L F
.6496 .49859 m .65128 .50111 L .64903 .50147 L F
.328 .303 .679 r
.34844 .67064 m .35038 .67256 L .34994 .67033 L F
.418 .316 .632 r
.34844 .67064 m .34874 .67304 L .35038 .67256 L F
.482 .736 .983 r
.58489 .71141 m .58829 .7123 L .58753 .71116 L F
.76 .332 .235 r
.59111 .71245 m .58753 .71116 L .58829 .7123 L F
.69 .66 .815 r
.73028 .71672 m .73133 .71775 L .73426 .7173 L F
0 .563 .793 r
.2582 .58421 m .25754 .5843 L .25634 .58469 L F
.2582 .58421 m .25958 .58454 L .25754 .5843 L F
.901 .77 .707 r
.60518 .71205 m .60593 .70971 L .60432 .7089 L F
0 0 0 r
.67901 .4988 m .67636 .49957 L .6773 .49896 L F
.617 .669 .877 r
.67858 .49861 m .67636 .49957 L .67901 .4988 L F
.867 .827 .806 r
.67435 .50044 m .6773 .49896 L .67636 .49957 L F
0 0 0 r
.67901 .4988 m .6773 .49896 L .67935 .49804 L F
.617 .669 .877 r
.67503 .49701 m .67636 .49957 L .67858 .49861 L F
.867 .827 .806 r
.67397 .50063 m .67435 .50044 L .67636 .49957 L F
.175 .486 .9 r
.5367 .79828 m .53566 .79831 L .53782 .79899 L F
.471 .265 .517 r
.53782 .79899 m .53566 .79831 L .53508 .80073 L F
.57 .53 .771 r
.58855 .7309 m .59 .73408 L .58683 .73455 L F
.556 .417 .647 r
.59 .73408 m .5875 .73685 L .58683 .73455 L F
.536 .323 .538 r
.42343 .68447 m .42564 .68412 L .42578 .68175 L F
.499 .27 .498 r
.42564 .68412 m .42808 .68141 L .42578 .68175 L F
.603 .537 .753 r
.31425 .74649 m .31335 .7488 L .31527 .74812 L F
.496 .214 .415 r
.31287 .75043 m .31527 .74812 L .31335 .7488 L F
.391 .037 .24 r
.42427 .69939 m .42323 .69719 L .42584 .6967 L F
.42427 .69939 m .42214 .69986 L .42323 .69719 L F
.235 0 0 r
.64182 .54917 m .64474 .54823 L .64378 .54937 L F
.179 0 0 r
.64378 .54937 m .64474 .54823 L .64726 .54772 L F
.265 .709 .96 r
.28697 .59003 m .28899 .59005 L .29053 .59075 L F
.194 .7 .903 r
.28899 .59005 m .29254 .59041 L .29053 .59075 L F
.494 .365 .633 r
.46495 .7696 m .46484 .77273 L .46308 .77331 L F
.48 .329 .598 r
.46484 .77273 m .46509 .7754 L .46308 .77331 L F
.368 .313 .664 r
.46308 .77331 m .46509 .7754 L .46352 .7752 L F
.72 .696 .826 r
.6676 .48526 m .6691 .48793 L .6657 .48769 L F
.808 .51 .485 r
.66954 .49023 m .6657 .48769 L .6691 .48793 L F
.569 .704 .933 r
.6716 .4864 m .6691 .48793 L .6676 .48526 L F
.6716 .4864 m .67108 .48741 L .6691 .48793 L F
.569 .468 .699 r
.67181 .4896 m .6691 .48793 L .67108 .48741 L F
.67181 .4896 m .66954 .49023 L .6691 .48793 L F
.463 .222 .462 r
.26258 .61614 m .26116 .61515 L .26295 .6147 L F
.26258 .61614 m .26087 .61706 L .26116 .61515 L F
0 0 .176 r
.62482 .50467 m .62527 .50553 L .62382 .50348 L F
.62482 .50467 m .62453 .50731 L .62527 .50553 L F
.754 .665 .763 r
.4986 .7925 m .50216 .79235 L .50092 .78953 L F
.71 .405 .458 r
.50079 .79467 m .50216 .79235 L .4986 .7925 L F
.727 .425 .468 r
.50079 .79467 m .50433 .79512 L .50216 .79235 L F
0 0 0 r
.55202 .69041 m .55245 .69112 L .55275 .68965 L F
.55202 .69041 m .55089 .69204 L .55245 .69112 L F
.491 .282 .523 r
.34582 .60696 m .34573 .60889 L .34373 .60949 L F
.339 0 .194 r
.34373 .60949 m .34471 .61091 L .34283 .61167 L F
.34373 .60949 m .34573 .60889 L .34471 .61091 L F
.146 0 .046 r
.55164 .74052 m .55238 .74138 L .55244 .73808 L F
.55164 .74052 m .55061 .74217 L .55238 .74138 L F
.751 .819 .906 r
.73658 .61417 m .73481 .61565 L .73339 .61439 L F
.632 .869 .986 r
.597 .75384 m .59755 .75432 L .6002 .75379 L F
.792 .573 .604 r
.59445 .70388 m .59153 .70543 L .59219 .70347 L F
.886 .773 .731 r
.59234 .7035 m .59219 .70347 L .59274 .70255 L F
.678 .778 .302 r
.59153 .70543 m .59281 .70229 L .59219 .70347 L F
.59173 .70493 m .59185 .70454 L .59281 .70229 L F
.59153 .70543 m .59158 .70529 L .59173 .70493 L F
.59158 .70529 m .59185 .70454 L .59173 .70493 L F
.886 .773 .731 r
.59445 .70388 m .59234 .7035 L .59387 .70067 L F
.59234 .7035 m .59274 .70255 L .59387 .70067 L F
.792 .573 .604 r
.59445 .70388 m .59421 .70635 L .59153 .70543 L F
.51 .371 .628 r
.34785 .60605 m .34573 .60889 L .34582 .60696 L F
.371 .754 .989 r
.30019 .59183 m .29963 .59275 L .29823 .59152 L F
.30019 .59183 m .30169 .59263 L .29963 .59275 L F
.725 .298 .234 r
.51576 .71134 m .51804 .71351 L .51925 .71195 L F
.823 .43 .306 r
.51804 .71351 m .5212 .71468 L .51925 .71195 L F
0 .091 .598 r
.56293 .73457 m .56413 .73567 L .56504 .73669 L F
.036 0 0 r
.3925 .71314 m .39206 .71234 L .39425 .71219 L F
.3925 .71314 m .39064 .71394 L .39206 .71234 L F
.724 .414 .455 r
.62063 .55303 m .6191 .55589 L .61733 .55356 L F
.913 .697 .597 r
.70467 .50689 m .70607 .51007 L .70446 .50914 L F
.764 .566 .629 r
.70607 .51007 m .70252 .51174 L .70446 .50914 L F
.70607 .51007 m .7059 .51244 L .70252 .51174 L F
.746 .641 .744 r
.70782 .50755 m .70607 .51007 L .70467 .50689 L F
.608 .453 .646 r
.70949 .50803 m .70607 .51007 L .70782 .50755 L F
.573 .393 .6 r
.70949 .50803 m .7059 .51244 L .70607 .51007 L F
.825 .912 .898 r
.64678 .52229 m .64936 .5202 L .65038 .52109 L F
.844 .913 .881 r
.65038 .52109 m .65206 .51759 L .65268 .52055 L F
.653 .517 .685 r
.52372 .7364 m .52726 .73741 L .52643 .73381 L F
.602 .475 .679 r
.52503 .73971 m .52726 .73741 L .52372 .7364 L F
.64 .384 .516 r
.54818 .69606 m .54929 .69838 L .54737 .69757 L F
.878 .441 .077 r
.54818 .69606 m .54929 .69838 L .54789 .69718 L F
.369 .004 .208 r
.37284 .6508 m .37379 .6526 L .3751 .65033 L F
.37284 .6508 m .3717 .65309 L .37379 .6526 L F
.297 .781 .911 r
.26866 .58675 m .27074 .58644 L .27242 .58666 L F
.13 0 0 r
.27074 .58644 m .27432 .58696 L .27242 .58666 L F
.268 0 0 r
.3773 .65041 m .37947 .65021 L .381 .64904 L F
.273 0 0 r
.37947 .65021 m .38317 .6489 L .381 .64904 L F
.536 .261 .446 r
.70864 .51744 m .70956 .5174 L .71027 .5182 L F
.553 .291 .472 r
.70864 .51744 m .7072 .52027 L .70679 .5185 L F
.719 .48 .563 r
.71023 .51844 m .70864 .51744 L .71027 .5182 L F
.70899 .51794 m .70864 .51744 L .71023 .51844 L F
.71006 .51946 m .7072 .52027 L .70843 .51787 L F
.70899 .51794 m .70843 .51787 L .70864 .51744 L F
.71006 .51946 m .70843 .51787 L .70899 .51794 L F
.536 .261 .446 r
.70813 .51774 m .70679 .5185 L .70839 .51787 L F
.70813 .51774 m .70839 .51787 L .70956 .5174 L F
.70864 .51744 m .70813 .51774 L .70956 .5174 L F
.697 .652 .801 r
.7086 .51778 m .70839 .51787 L .70649 .51693 L F
.70839 .51787 m .70679 .5185 L .70663 .51766 L F
.70839 .51787 m .70663 .51766 L .70649 .51693 L F
.70956 .5174 m .7086 .51778 L .70606 .51467 L F
.7086 .51778 m .70649 .51693 L .70606 .51467 L F
.719 .48 .563 r
.71006 .51946 m .70899 .51794 L .71023 .51844 L F
.575 .674 .907 r
.71227 .51744 m .71027 .5182 L .70956 .5174 L F
.446 .176 .409 r
.7117 .51882 m .71027 .5182 L .71227 .51744 L F
.7117 .51882 m .71006 .51946 L .71027 .5182 L F
.443 .698 .974 r
.73465 .62061 m .73535 .62195 L .73813 .62195 L F
.511 .239 .438 r
.4593 .67579 m .45857 .67843 L .45634 .67875 L F
.569 .296 .463 r
.46177 .67557 m .45857 .67843 L .4593 .67579 L F
.547 .848 .998 r
.38984 .70151 m .39038 .7002 L .39159 .70045 L F
.38984 .70151 m .38819 .70075 L .39038 .7002 L F
0 0 0 r
.55636 .69181 m .55528 .69301 L .55701 .68932 L F
.19 .045 .441 r
.55884 .68675 m .55847 .68919 L .55701 .68932 L F
.366 .035 .264 r
.55849 .6912 m .55701 .68932 L .55847 .68919 L F
.55849 .6912 m .55636 .69181 L .55701 .68932 L F
.929 .822 .718 r
.30167 .82693 m .30062 .82517 L .3002 .82576 L F
.655 .631 .813 r
.70021 .51422 m .69807 .51523 L .69689 .51191 L F
.601 .566 .786 r
.43454 .67049 m .4355 .67344 L .43764 .67302 L F
.557 .291 .468 r
.43475 .67523 m .43764 .67302 L .4355 .67344 L F
.603 .504 .714 r
.50542 .73153 m .50599 .73424 L .50354 .73452 L F
.519 .266 .47 r
.5057 .73613 m .50334 .7366 L .50354 .73452 L F
.54 .257 .435 r
.50599 .73424 m .5057 .73613 L .50354 .73452 L F
.216 .727 .68 r
.27745 .65328 m .27375 .65444 L .27562 .65432 L F
.686 .635 .793 r
.71764 .59329 m .71805 .59646 L .7199 .594 L F
.71764 .59329 m .7199 .594 L .7206 .59307 L F
.732 .334 .296 r
.71628 .59287 m .71764 .59329 L .71535 .59219 L F
0 0 .498 r
.71807 .59418 m .71805 .59646 L .71764 .59329 L F
.732 .334 .296 r
.71807 .59418 m .71764 .59329 L .71628 .59287 L F
.185 .307 .756 r
.71937 .59472 m .71805 .59646 L .71807 .59418 L F
0 0 .365 r
.71842 .59658 m .71805 .59646 L .71937 .59472 L F
.82 .812 .843 r
.71717 .50998 m .71344 .51102 L .71656 .50971 L F
.182 .221 .667 r
.71851 .50839 m .71717 .50998 L .71656 .50971 L F
.71851 .50839 m .71891 .51146 L .71717 .50998 L F
.268 .225 .623 r
.71717 .50998 m .71891 .51146 L .71766 .51227 L F
.815 .614 .632 r
.52525 .72803 m .52149 .72823 L .52171 .72572 L F
.585 .088 .041 r
.52525 .72803 m .5241 .72978 L .52149 .72823 L F
.661 .284 .321 r
.52766 .72795 m .5241 .72978 L .52525 .72803 L F
.712 .451 .528 r
.5542 .70326 m .55845 .70578 L .5576 .70379 L F
.658 .321 .39 r
.55845 .70578 m .55988 .70586 L .5576 .70379 L F
.725 .362 .362 r
.67833 .51265 m .68006 .5145 L .68016 .51287 L F
0 0 0 r
.38805 .67028 m .38529 .67282 L .38583 .67063 L F
.423 0 .058 r
.59488 .55299 m .59642 .5515 L .59476 .5521 L F
.478 .301 .561 r
.59859 .55094 m .59655 .55399 L .59642 .5515 L F
.737 .506 .578 r
.59488 .55299 m .59859 .55094 L .59642 .5515 L F
.239 .645 .96 r
.31143 .60673 m .31163 .60577 L .31068 .60551 L F
.31143 .60673 m .3129 .60663 L .31163 .60577 L F
.48 .006 .051 r
.58433 .67462 m .58747 .67318 L .58551 .67338 L F
.613 .956 .849 r
.55636 .69181 m .55339 .69357 L .55528 .69301 L F
.921 .695 .578 r
.57494 .75391 m .57447 .75618 L .57519 .75595 L F
.743 .714 .182 r
.57458 .75503 m .57494 .75391 L .57452 .75254 L F
.632 .869 .986 r
.597 .75384 m .6002 .75379 L .59893 .75296 L F
.336 .773 .966 r
.60268 .75326 m .59893 .75296 L .6002 .75379 L F
.222 0 0 r
.53563 .76194 m .53222 .76424 L .53472 .76416 L F
.485 .051 .139 r
.53699 .76363 m .53563 .76194 L .53472 .76416 L F
.53699 .76363 m .53791 .76184 L .53563 .76194 L F
.609 .326 .462 r
.72858 .59252 m .73191 .59227 L .73186 .59012 L F
.614 .33 .462 r
.73191 .59227 m .73432 .59205 L .73186 .59012 L F
.613 .33 .465 r
.73186 .59012 m .73432 .59205 L .73429 .59017 L F
.722 .685 .814 r
.70681 .50415 m .70782 .50755 L .70467 .50689 L F
.505 .549 .835 r
.7098 .50566 m .70782 .50755 L .70681 .50415 L F
.492 .527 .821 r
.7098 .50566 m .70976 .50711 L .70782 .50755 L F
.38 .45 .807 r
.70976 .50711 m .70949 .50803 L .70782 .50755 L F
.268 .612 .956 r
.26733 .5855 m .26685 .58638 L .26516 .58559 L F
.26733 .5855 m .26866 .58675 L .26685 .58638 L F
0 0 .532 r
.65655 .5237 m .65753 .52694 L .65662 .52351 L F
.159 .302 .761 r
.65662 .52351 m .65753 .52694 L .65591 .52403 L F
.65591 .52403 m .65753 .52694 L .65662 .52351 L F
.776 .583 .638 r
.6259 .5147 m .62278 .51221 L .62448 .51324 L F
.523 .365 .608 r
.62781 .51199 m .6259 .5147 L .62448 .51324 L F
.981 .844 .453 r
.63708 .50341 m .63796 .50183 L .63716 .50076 L F
.63708 .50341 m .63764 .50431 L .63796 .50183 L F
.532 .43 .683 r
.34698 .67899 m .34861 .67546 L .34682 .67614 L F
.461 .671 .954 r
.3298 .59452 m .32905 .59612 L .32771 .59502 L F
.3298 .59452 m .33117 .59606 L .32905 .59612 L F
.725 .457 .521 r
.61149 .55129 m .61313 .55371 L .60956 .55292 L F
.708 .43 .502 r
.60766 .55132 m .61149 .55129 L .60956 .55292 L F
.876 .955 .854 r
.54575 .76946 m .54191 .7719 L .54462 .77076 L F
.42 0 .038 r
.54728 .77091 m .54575 .76946 L .54462 .77076 L F
.54728 .77091 m .54711 .76991 L .54575 .76946 L F
.928 .605 .146 r
.65244 .5174 m .65206 .51759 L .65153 .51496 L F
.007 .069 .579 r
.65206 .51759 m .65306 .51625 L .65162 .5178 L F
.86 .926 .539 r
.64952 .51932 m .65028 .51881 L .65206 .51759 L F
.724 .383 .402 r
.65028 .51881 m .64936 .5202 L .64596 .51986 L F
.86 .926 .539 r
.64933 .51945 m .64937 .51942 L .64952 .51932 L F
.64937 .51942 m .65028 .51881 L .64952 .51932 L F
.724 .383 .402 r
.65028 .51881 m .64596 .51986 L .64632 .51809 L F
.726 .725 .849 r
.64891 .51581 m .64972 .51918 L .65306 .51625 L F
.86 .926 .539 r
.64933 .51945 m .64936 .5202 L .65028 .51881 L F
.64933 .51945 m .64952 .51932 L .64985 .51971 L F
.64952 .51932 m .65206 .51759 L .64985 .51971 L F
.726 .725 .849 r
.64972 .51918 m .64985 .51971 L .65141 .51802 L F
.64972 .51918 m .65141 .51802 L .65306 .51625 L F
.007 .069 .579 r
.65206 .51759 m .65162 .5178 L .64985 .51971 L F
.928 .605 .146 r
.65277 .51828 m .65206 .51759 L .65244 .5174 L F
.859 .563 .486 r
.65488 .51964 m .65206 .51759 L .65277 .51828 L F
.59 .385 .571 r
.65277 .51828 m .65268 .52055 L .65488 .51964 L F
.946 .958 .722 r
.62515 .49863 m .62295 .4992 L .62414 .49827 L F
.62375 .50085 m .6235 .50125 L .62295 .4992 L F
0 0 .459 r
.62382 .50348 m .62295 .4992 L .6235 .50125 L F
.62382 .50348 m .62468 .5038 L .62295 .4992 L F
.833 .585 .564 r
.62468 .5038 m .62279 .49888 L .62295 .4992 L F
.62279 .49888 m .62278 .49886 L .62295 .4992 L F
.946 .958 .722 r
.62515 .49863 m .62375 .50085 L .62295 .4992 L F
.489 .879 .965 r
.62515 .49863 m .62636 .4976 L .62785 .49766 L F
.62515 .49863 m .62414 .49827 L .62636 .4976 L F
.619 .461 .645 r
.51403 .75646 m .51201 .75868 L .51159 .75661 L F
.316 .273 .651 r
.42737 .69613 m .42584 .6967 L .42581 .6955 L F
.309 0 .089 r
.42638 .6989 m .42584 .6967 L .42737 .69613 L F
.42638 .6989 m .42427 .69939 L .42584 .6967 L F
.424 .858 .746 r
.57023 .77404 m .57222 .77301 L .57052 .77356 L F
.848 .996 .761 r
.57052 .77356 m .57222 .77301 L .57239 .77149 L F
.845 .805 .315 r
.57239 .77149 m .57172 .77334 L .57089 .77358 L F
.424 .858 .746 r
.57023 .77404 m .57052 .77356 L .56886 .77268 L F
.5686 .77256 m .56886 .77268 L .56854 .77251 L F
.57023 .77404 m .56886 .77268 L .5686 .77256 L F
.482 0 .009 r
.56854 .77251 m .57052 .77356 L .5696 .77396 L F
.845 .805 .315 r
.57239 .77149 m .5696 .77396 L .57052 .77356 L F
.57032 .77333 m .57089 .77358 L .5696 .77396 L F
.57239 .77149 m .57089 .77358 L .57032 .77333 L F
.777 .363 0 r
.66182 .49915 m .66075 .49786 L .66103 .49761 L F
.66182 .49915 m .66286 .50102 L .66075 .49786 L F
0 0 0 r
.3689 .72441 m .36837 .72357 L .37054 .72332 L F
.3689 .72441 m .36738 .72542 L .36837 .72357 L F
.496 .268 .497 r
.37073 .72134 m .37054 .72332 L .36837 .72357 L F
.425 .084 .282 r
.42042 .68696 m .42254 .68663 L .42343 .68447 L F
.412 .072 .276 r
.42343 .68447 m .42465 .68609 L .42564 .68412 L F
.42343 .68447 m .42254 .68663 L .42465 .68609 L F
.751 .416 .416 r
.52154 .74004 m .52548 .7421 L .52503 .73971 L F
.602 .475 .679 r
.52503 .73971 m .52736 .7395 L .52726 .73741 L F
.384 .177 .471 r
.52548 .7421 m .52736 .7395 L .52503 .73971 L F
.876 .705 .666 r
.3552 .72279 m .35705 .72339 L .35564 .72012 L F
.751 .831 .914 r
.35365 .72346 m .35705 .72339 L .3552 .72279 L F
.659 .614 .792 r
.35564 .72012 m .35705 .72339 L .35986 .72243 L F
.79 .444 .401 r
.58681 .67885 m .58854 .68139 L .58734 .68064 L F
.823 .439 .327 r
.59032 .68158 m .58854 .68139 L .58681 .67885 L F
.849 .547 .476 r
.60236 .70036 m .60456 .69846 L .60348 .69745 L F
.60236 .70036 m .60479 .70028 L .60456 .69846 L F
.732 .37 .365 r
.50994 .79695 m .51167 .79464 L .50787 .79435 L F
.709 .34 .349 r
.50994 .79695 m .51424 .79701 L .51167 .79464 L F
.649 .358 .464 r
.5161 .72883 m .51355 .7305 L .51373 .72897 L F
.909 .761 .685 r
.66019 .51477 m .65757 .51698 L .65945 .51438 L F
.66019 .51477 m .65901 .51827 L .65757 .51698 L F
.275 .54 .919 r
.66167 .51397 m .66019 .51477 L .65945 .51438 L F
.66167 .51397 m .66267 .5155 L .66019 .51477 L F
.586 .034 0 r
.47305 .79182 m .47601 .79234 L .47473 .79286 L F
.47 0 0 r
.47473 .79286 m .47601 .79234 L .47535 .79347 L F
.614 .093 0 r
.47535 .79347 m .47601 .79234 L .47866 .79408 L F
.808 .51 .485 r
.66954 .49023 m .66596 .48973 L .6657 .48769 L F
.726 .808 .916 r
.66954 .49023 m .66723 .49071 L .66596 .48973 L F
.963 .716 .515 r
.66286 .50102 m .66045 .50257 L .66075 .49786 L F
.66286 .50102 m .663 .50537 L .66045 .50257 L F
.521 .132 .244 r
.74102 .59314 m .74319 .59433 L .74119 .5945 L F
.74102 .59314 m .74365 .59311 L .74319 .59433 L F
0 0 0 r
.55702 .68596 m .55275 .68965 L .5549 .68833 L F
.55275 .68965 m .55245 .69112 L .5549 .68833 L F
0 0 .267 r
.55988 .78295 m .5592 .78363 L .55943 .78555 L F
0 0 .485 r
.57384 .75852 m .57445 .76087 L .57394 .76198 L F
0 0 .385 r
.57445 .76087 m .57401 .76457 L .57394 .76198 L F
.774 .702 .783 r
.70606 .51467 m .70679 .5185 L .7037 .51752 L F
.745 .532 .607 r
.7072 .52027 m .7037 .51752 L .70679 .5185 L F
.438 .129 .342 r
.40759 .69512 m .40972 .69467 L .41049 .69203 L F
.429 .12 .338 r
.41049 .69203 m .41183 .69419 L .4125 .69227 L F
.41049 .69203 m .40972 .69467 L .41183 .69419 L F
.605 .569 .788 r
.76466 .59868 m .76291 .60053 L .76185 .59748 L F
.579 .491 .72 r
.76466 .59868 m .7631 .60241 L .76291 .60053 L F
.173 .496 .906 r
.34223 .60001 m .34181 .60114 L .34079 .5997 L F
.394 .746 .993 r
.34372 .60091 m .34181 .60114 L .34223 .60001 L F
.641 .921 .977 r
.60473 .754 m .60632 .75444 L .60817 .75341 L F
.316 .273 .651 r
.42737 .69613 m .42581 .6955 L .42783 .6945 L F
.988 .755 .369 r
.65638 .52796 m .65753 .52694 L .65662 .52351 L F
.963 .713 .273 r
.65691 .52355 m .65753 .52694 L .65662 .52351 L F
.65691 .52355 m .65753 .52694 L .65662 .52351 L F
.988 .755 .369 r
.65662 .52351 m .65753 .52694 L .65638 .52796 L F
.413 .28 .589 r
.37098 .7203 m .37265 .72283 L .37073 .72134 L F
.863 .514 .389 r
.59653 .68061 m .59782 .67898 L .59617 .67821 L F
.59653 .68061 m .59832 .68101 L .59782 .67898 L F
.156 0 0 r
.47328 .78191 m .4746 .78247 L .47552 .78298 L F
.47328 .78191 m .47213 .7835 L .4746 .78247 L F
.121 0 0 r
.58594 .70592 m .58821 .70546 L .58945 .70455 L F
.579 .069 .005 r
.58945 .70455 m .58821 .70546 L .59153 .70543 L F
.561 .336 .531 r
.50742 .76744 m .50924 .76472 L .5077 .76495 L F
.50742 .76744 m .50975 .76733 L .50924 .76472 L F
.515 .178 .335 r
.50975 .76733 m .51297 .76475 L .50924 .76472 L F
.598 .72 .929 r
.44437 .65269 m .44565 .6542 L .44226 .65322 L F
.605 .652 .87 r
.44687 .65178 m .44565 .6542 L .44437 .65269 L F
.44687 .65178 m .44785 .65367 L .44565 .6542 L F
.732 .736 .854 r
.43719 .6694 m .43454 .67049 L .43738 .67055 L F
.601 .566 .786 r
.43454 .67049 m .43764 .67302 L .43738 .67055 L F
.441 .525 .848 r
.43719 .6694 m .43738 .67055 L .43905 .6694 L F
.396 .282 .605 r
.43738 .67055 m .43961 .67217 L .43905 .6694 L F
.43738 .67055 m .43764 .67302 L .43961 .67217 L F
.572 .775 .975 r
.30043 .60361 m .30219 .60502 L .30404 .60448 L F
.244 0 0 r
.64092 .5505 m .64182 .54917 L .64378 .54937 L F
.685 .573 .724 r
.50476 .73963 m .50825 .74242 L .50892 .74029 L F
.797 .536 .544 r
.49016 .78126 m .48714 .78345 L .48947 .78138 L F
.49016 .78126 m .4911 .78381 L .48714 .78345 L F
0 0 0 r
.49268 .77963 m .49016 .78126 L .49149 .78064 L F
.325 .805 .752 r
.49149 .78064 m .49016 .78126 L .48947 .78138 L F
.686 .143 0 r
.56727 .71967 m .56599 .71916 L .56407 .71729 L F
.658 .107 0 r
.56727 .71967 m .56812 .72045 L .56599 .71916 L F
.589 .319 .476 r
.46907 .67035 m .46885 .67284 L .46639 .67295 L F
0 .246 .716 r
.46762 .66904 m .46973 .67046 L .46907 .67035 L F
.423 .181 .441 r
.47129 .67167 m .46907 .67035 L .46973 .67046 L F
.47129 .67167 m .46885 .67284 L .46907 .67035 L F
.527 .692 .944 r
.7581 .58381 m .7566 .58556 L .75576 .58408 L F
.7581 .58381 m .75902 .58533 L .7566 .58556 L F
.321 0 .189 r
.36079 .65784 m .35957 .65686 L .35881 .65848 L F
.379 0 .091 r
.36079 .65784 m .36186 .65657 L .35957 .65686 L F
.425 .172 .424 r
.48665 .7394 m .48908 .73943 L .48948 .7365 L F
.408 .153 .413 r
.48948 .7365 m .49164 .73645 L .49192 .73406 L F
.463 .204 .435 r
.48948 .7365 m .49116 .739 L .49164 .73645 L F
.48948 .7365 m .48908 .73943 L .49116 .739 L F
.828 .724 .75 r
.61894 .5234 m .61992 .52668 L .61821 .52556 L F
.868 .779 .761 r
.61992 .52668 m .61652 .52853 L .61821 .52556 L F
.61992 .52668 m .61795 .52987 L .61652 .52853 L F
.536 .402 .645 r
.37621 .68097 m .3765 .68478 L .3744 .68496 L F
.586 .523 .751 r
.3765 .68478 m .37481 .68688 L .3744 .68496 L F
.041 .279 .773 r
.36277 .72423 m .36289 .7224 L .36113 .72279 L F
.429 .068 .248 r
.41317 .70359 m .41212 .70576 L .40992 .7061 L F
.344 0 .204 r
.41419 .70516 m .41317 .70359 L .41532 .70314 L F
.41419 .70516 m .41212 .70576 L .41317 .70359 L F
.784 .46 .439 r
.52949 .76996 m .53162 .77085 L .53119 .77248 L F
.369 .062 .308 r
.53119 .77248 m .53162 .77085 L .53365 .77017 L F
.723 .196 0 r
.70867 .60284 m .71117 .60472 L .70987 .60381 L F
.508 .01 0 r
.71117 .60472 m .71152 .60508 L .70987 .60381 L F
.71117 .60472 m .71218 .60574 L .71152 .60508 L F
.69 .66 .815 r
.73028 .71672 m .73426 .7173 L .73312 .71503 L F
.532 .224 .391 r
.63137 .55256 m .62809 .5513 L .63037 .55123 L F
.63137 .55256 m .6272 .55373 L .62809 .5513 L F
.493 .265 .496 r
.37073 .72134 m .37265 .72283 L .37054 .72332 L F
.53 .334 .559 r
.46639 .6754 m .46425 .67336 L .46639 .67295 L F
.46639 .6754 m .46417 .67591 L .46425 .67336 L F
.501 .574 .861 r
.38347 .69435 m .383 .69737 L .38148 .69451 L F
.38347 .69435 m .38512 .69727 L .383 .69737 L F
.579 .343 .522 r
.25875 .61763 m .25825 .62039 L .25602 .62042 L F
.507 .28 .504 r
.26087 .61706 m .25825 .62039 L .25875 .61763 L F
.653 .834 .969 r
.65646 .50673 m .65285 .50653 L .65428 .50425 L F
.235 .487 .892 r
.65714 .50553 m .65646 .50673 L .65428 .50425 L F
.187 .424 .857 r
.65772 .5072 m .65646 .50673 L .65714 .50553 L F
.506 .444 .722 r
.37752 .69071 m .37558 .69066 L .37481 .68688 L F
.505 .455 .735 r
.37752 .69071 m .37805 .69197 L .37558 .69066 L F
.459 .818 .996 r
.30169 .59263 m .30374 .59225 L .30528 .5929 L F
.297 .739 .964 r
.30585 .59221 m .30528 .5929 L .30374 .59225 L F
.30585 .59221 m .30725 .59282 L .30528 .5929 L F
.516 .463 .736 r
.31457 .60953 m .31529 .61267 L .31681 .61173 L F
.422 .386 .714 r
.31529 .61267 m .31745 .61437 L .31681 .61173 L F
.31529 .61267 m .31589 .61519 L .31745 .61437 L F
.72 .307 .264 r
.55527 .73852 m .5525 .73633 L .55407 .7371 L F
.55527 .73852 m .55368 .73734 L .5525 .73633 L F
.304 .42 .815 r
.55368 .73734 m .55527 .73852 L .55407 .7371 L F
.55244 .73808 m .55527 .73852 L .55368 .73734 L F
.72 .307 .264 r
.55527 .73852 m .55503 .7385 L .55368 .73734 L F
.304 .42 .815 r
.55244 .73808 m .55368 .73734 L .5525 .73633 L F
.618 .45 .632 r
.55238 .74138 m .55527 .73852 L .55244 .73808 L F
.72 .307 .264 r
.55503 .7385 m .5511 .73807 L .5525 .73633 L F
.304 .42 .815 r
.55368 .73734 m .55407 .7371 L .5525 .73633 L F
.505 .426 .7 r
.44728 .76746 m .44922 .76709 L .4487 .76419 L F
.516 .401 .661 r
.44728 .76746 m .44973 .76961 L .44922 .76709 L F
.44728 .76746 m .44762 .77012 L .44973 .76961 L F
.591 .461 .672 r
.65391 .52437 m .65655 .5237 L .65604 .52122 L F
.045 0 0 r
.65512 .52458 m .65391 .52437 L .65269 .52372 L F
.65512 .52458 m .65655 .5237 L .65391 .52437 L F
.548 .638 .892 r
.34974 .70955 m .35174 .71226 L .35338 .71159 L F
.406 .728 .99 r
.42771 .66463 m .42848 .6635 L .42636 .66374 L F
.42771 .66463 m .42978 .66453 L .42848 .6635 L F
.546 .413 .65 r
.71994 .59984 m .71742 .60386 L .71624 .60075 L F
.71994 .59984 m .71963 .60345 L .71742 .60386 L F
.387 .137 .408 r
.49192 .73406 m .49356 .73579 L .49412 .7336 L F
.49192 .73406 m .49164 .73645 L .49356 .73579 L F
.876 .759 .73 r
.60432 .7089 m .60332 .71154 L .60518 .71205 L F
.975 .783 .58 r
.60362 .71356 m .60518 .71205 L .60332 .71154 L F
.60362 .71356 m .60476 .71454 L .60518 .71205 L F
.751 .416 .416 r
.52154 .74004 m .52173 .74221 L .52548 .7421 L F
.586 .523 .751 r
.3765 .68478 m .37701 .68654 L .37481 .68688 L F
.506 .444 .722 r
.37752 .69071 m .37481 .68688 L .37701 .68654 L F
.61 .575 .79 r
.35328 .72016 m .3544 .71701 L .35255 .71759 L F
.35328 .72016 m .35564 .72012 L .3544 .71701 L F
.655 .458 .605 r
.35328 .72016 m .3552 .72279 L .35564 .72012 L F
.35328 .72016 m .35365 .72346 L .3552 .72279 L F
.24 0 .149 r
.66549 .53773 m .66485 .53956 L .66266 .53999 L F
0 0 0 r
.66713 .53629 m .66549 .53773 L .66802 .53482 L F
.66576 .53832 m .66549 .53773 L .66713 .53629 L F
.66576 .53832 m .66485 .53956 L .66549 .53773 L F
.535 .369 .603 r
.7302 .6004 m .72744 .59827 L .7298 .59768 L F
.462 .091 .248 r
.73299 .59736 m .73253 .59804 L .7298 .59768 L F
.387 .162 .447 r
.73221 .59946 m .7298 .59768 L .73253 .59804 L F
.73221 .59946 m .7302 .6004 L .7298 .59768 L F
.719 .695 .826 r
.54019 .75872 m .54355 .75917 L .54321 .75806 L F
.777 .587 .642 r
.54195 .76149 m .54355 .75917 L .54019 .75872 L F
.54195 .76149 m .54368 .76163 L .54355 .75917 L F
.789 .734 .801 r
.54321 .75806 m .54355 .75917 L .54613 .75675 L F
.585 .391 .584 r
.54613 .75675 m .54355 .75917 L .5459 .75875 L F
.644 .508 .683 r
.54368 .76163 m .5459 .75875 L .54355 .75917 L F
.556 .413 .642 r
.44565 .77319 m .44757 .77289 L .44762 .77012 L F
.512 .384 .643 r
.44565 .77319 m .44766 .77536 L .44757 .77289 L F
.44565 .77319 m .44594 .77602 L .44766 .77536 L F
.529 .586 .856 r
.68655 .52037 m .68393 .52141 L .68453 .5206 L F
.452 0 .044 r
.47904 .76815 m .47763 .76974 L .47525 .76969 L F
.397 .028 .216 r
.48405 .74161 m .48619 .74128 L .48665 .7394 L F
.389 .022 .214 r
.48665 .7394 m .48822 .7409 L .48908 .73943 L F
.48665 .7394 m .48619 .74128 L .48822 .7409 L F
.77 .839 .904 r
.65379 .51 m .65042 .51029 L .6528 .50918 L F
.986 .768 .523 r
.65285 .50653 m .65379 .51 L .6528 .50918 L F
0 .292 .78 r
.56969 .74088 m .56803 .74034 L .56777 .73867 L F
.963 .907 .715 r
.57054 .74016 m .5705 .74093 L .56969 .74088 L F
.719 .539 0 r
.57038 .7436 m .57025 .74175 L .56969 .74088 L F
.57038 .7436 m .57046 .74434 L .57025 .74175 L F
.963 .907 .715 r
.5705 .74093 m .57038 .7436 L .56969 .74088 L F
0 .292 .78 r
.56969 .74088 m .57025 .74175 L .56878 .74081 L F
.56969 .74088 m .56878 .74081 L .56803 .74034 L F
.818 .427 .312 r
.59032 .68158 m .58912 .6832 L .58854 .68139 L F
.899 .55 .375 r
.59032 .68158 m .59109 .68394 L .58912 .6832 L F
.781 .76 .834 r
.5246 .75265 m .52175 .75352 L .52417 .75135 L F
.605 .443 .635 r
.52426 .75561 m .52175 .75352 L .5246 .75265 L F
.643 .382 .509 r
.52764 .75537 m .5246 .75265 L .52648 .7528 L F
.52764 .75537 m .52426 .75561 L .5246 .75265 L F
0 .35 .732 r
.55702 .68596 m .5574 .68589 L .55884 .68675 L F
.749 .991 .881 r
.54767 .77476 m .5474 .77598 L .54981 .77408 L F
.804 .939 .579 r
.54598 .77754 m .5474 .77598 L .54767 .77476 L F
.54 .239 .406 r
.44378 .68393 m .44265 .68665 L .44037 .68678 L F
.525 .226 .402 r
.44589 .68371 m .44265 .68665 L .44378 .68393 L F
0 0 0 r
.31316 .61734 m .31431 .61706 L .31589 .61519 L F
.474 .147 .332 r
.31431 .61706 m .31745 .61437 L .31589 .61519 L F
.796 .425 .356 r
.59147 .67521 m .59345 .67791 L .5946 .6761 L F
.764 .385 .336 r
.59345 .67791 m .59617 .67821 L .5946 .6761 L F
.648 .812 .379 r
.66885 .53322 m .66713 .53629 L .66802 .53482 L F
.144 0 0 r
.57087 .7228 m .56687 .72281 L .56812 .72045 L F
.353 0 0 r
.56908 .72292 m .57176 .7242 L .57031 .72364 L F
.56908 .72292 m .57031 .72364 L .56973 .72321 L F
.56908 .72292 m .56973 .72321 L .56778 .72176 L F
.144 0 0 r
.56882 .72281 m .56908 .72292 L .56687 .72281 L F
.57087 .7228 m .56908 .72292 L .56882 .72281 L F
.5 0 0 r
.57206 .72374 m .56908 .72292 L .57087 .7228 L F
.39 0 .09 r
.5085 .77083 m .50726 .77242 L .50508 .77269 L F
.617 .204 .237 r
.51248 .77225 m .5085 .77083 L .51042 .77067 L F
.515 .178 .335 r
.50975 .76733 m .51225 .7672 L .51297 .76475 L F
.667 .326 .386 r
.51297 .76475 m .51225 .7672 L .51516 .76684 L F
.574 .344 .53 r
.51297 .76475 m .51516 .76684 L .51499 .76443 L F
.408 .766 .995 r
.71857 .6091 m .7199 .60815 L .71782 .60796 L F
.71857 .6091 m .72093 .60892 L .7199 .60815 L F
.414 .285 .594 r
.46877 .7666 m .46802 .76818 L .47065 .76691 L F
.328 .758 .972 r
.40332 .64907 m .40582 .64885 L .40724 .64955 L F
0 .476 .77 r
.40582 .64885 m .4092 .64983 L .40724 .64955 L F
.741 .867 .939 r
.74618 .61999 m .74736 .62107 L .74935 .61949 L F
.102 0 0 r
.3939 .69893 m .39562 .69884 L .39747 .69822 L F
.313 .773 .948 r
.39457 .69866 m .39693 .69877 L .39562 .69884 L F
.228 0 0 r
.39562 .69884 m .39788 .69881 L .39965 .6982 L F
.313 .773 .948 r
.39693 .69877 m .39788 .69881 L .39562 .69884 L F
.102 0 0 r
.3933 .69905 m .39562 .69884 L .3939 .69893 L F
.228 0 0 r
.39562 .69884 m .39965 .6982 L .39747 .69822 L F
.214 0 0 r
.40045 .71034 m .39988 .70928 L .402 .70878 L F
.40045 .71034 m .39837 .71082 L .39988 .70928 L F
.067 0 0 r
.38317 .6489 m .38507 .64889 L .38658 .64846 L F
.507 0 0 r
.38507 .64889 m .38873 .6484 L .38658 .64846 L F
.78 .697 .772 r
.62988 .50711 m .62827 .50969 L .63066 .50994 L F
.821 .657 .68 r
.62781 .51199 m .63066 .50994 L .62827 .50969 L F
.417 .489 .826 r
.63066 .50994 m .63354 .51238 L .63553 .51147 L F
.789 .734 .801 r
.54321 .75806 m .54613 .75675 L .54437 .75564 L F
.393 .317 .652 r
.34811 .68452 m .34952 .68096 L .34745 .6813 L F
.34811 .68452 m .34992 .6837 L .34952 .68096 L F
.529 .416 .669 r
.34811 .68452 m .35058 .68647 L .34992 .6837 L F
.34811 .68452 m .34856 .68695 L .35058 .68647 L F
.534 .272 .464 r
.35608 .66125 m .35419 .65935 L .35403 .66166 L F
.35608 .66125 m .35661 .65886 L .35419 .65935 L F
.563 .631 .877 r
.49938 .7406 m .50249 .74253 L .50107 .73934 L F
.763 .677 .767 r
.50107 .73934 m .50249 .74253 L .50476 .73963 L F
.704 .587 .722 r
.50249 .74253 m .5051 .74259 L .50476 .73963 L F
.674 .441 .56 r
.50245 .74493 m .5051 .74259 L .50249 .74253 L F
.56 .883 .612 r
.51755 .80026 m .52025 .79794 L .51679 .79764 L F
.425 .332 .646 r
.52025 .79794 m .5208 .80035 L .5225 .79994 L F
.722 .729 .855 r
.66723 .49071 m .6638 .49033 L .66596 .48973 L F
.559 .26 .417 r
.45634 .67875 m .45358 .68079 L .45388 .67876 L F
.483 .725 .978 r
.60067 .70375 m .6026 .70393 L .60132 .70238 L F
.723 .238 .09 r
.60042 .70526 m .60292 .70573 L .60067 .70375 L F
.60042 .70526 m .60067 .70375 L .60132 .70238 L F
.616 .493 .69 r
.52643 .73381 m .52726 .73741 L .52972 .73676 L F
.562 .542 .79 r
.4535 .65584 m .45249 .65958 L .45177 .65595 L F
.4535 .65584 m .45464 .65924 L .45249 .65958 L F
.592 .539 .764 r
.4559 .6629 m .45249 .65958 L .45464 .65924 L F
.127 .157 .623 r
.70304 .58974 m .70329 .59328 L .70487 .59224 L F
.206 .318 .758 r
.70329 .59328 m .70567 .59514 L .70487 .59224 L F
.674 .441 .56 r
.50245 .74493 m .50488 .74497 L .5051 .74259 L F
.685 .573 .724 r
.50476 .73963 m .5051 .74259 L .50825 .74242 L F
.68 .447 .561 r
.5051 .74259 m .50805 .74469 L .50825 .74242 L F
.5051 .74259 m .50488 .74497 L .50805 .74469 L F
.865 .602 .537 r
.59835 .68806 m .60261 .68713 L .60079 .68642 L F
.59835 .68806 m .60269 .68946 L .60261 .68713 L F
.661 .351 .437 r
.53526 .739 m .53791 .73931 L .53868 .73679 L F
.76 .562 .63 r
.53791 .73931 m .54099 .73662 L .53868 .73679 L F
.847 .788 .794 r
.66097 .4899 m .66128 .49312 L .65901 .49236 L F
.941 .843 .719 r
.66128 .49312 m .65893 .49459 L .65901 .49236 L F
.66128 .49312 m .66002 .49509 L .65893 .49459 L F
.764 .731 .822 r
.6638 .49033 m .66128 .49312 L .66097 .4899 L F
.645 .592 .78 r
.73028 .71672 m .73312 .71503 L .72929 .71364 L F
.327 .085 .386 r
.32005 .63649 m .31957 .6394 L .31755 .63929 L F
.327 0 .238 r
.31881 .64106 m .31755 .63929 L .31957 .6394 L F
.31881 .64106 m .31688 .64167 L .31755 .63929 L F
.368 .686 .98 r
.75576 .58408 m .75367 .58407 L .75157 .58229 L F
.658 .204 .161 r
.76493 .58664 m .76748 .5885 L .76543 .58946 L F
0 0 .021 r
.76515 .5913 m .76543 .58946 L .76748 .5885 L F
.598 .806 .979 r
.42046 .65014 m .42178 .65123 L .41828 .65077 L F
.42046 .65014 m .42178 .65123 L .41828 .65077 L F
.439 .758 .995 r
.42253 .65007 m .42178 .65123 L .42046 .65014 L F
.42253 .65007 m .42395 .65106 L .42178 .65123 L F
.116 .024 .465 r
.63065 .51732 m .6288 .51763 L .63141 .51396 L F
.353 .189 .515 r
.63347 .51445 m .63065 .51732 L .63141 .51396 L F
.63347 .51445 m .63361 .51679 L .63065 .51732 L F
.154 0 0 r
.63361 .51679 m .63003 .51857 L .63065 .51732 L F
.251 .04 .386 r
.53913 .7453 m .53734 .74764 L .53441 .74527 L F
.848 .817 .818 r
.59205 .73348 m .59021 .73387 L .59356 .73019 L F
.828 .461 .36 r
.48461 .76984 m .48117 .7671 L .48242 .77022 L F
.478 .579 .878 r
.31457 .60953 m .31465 .60613 L .3129 .60663 L F
.31457 .60953 m .31632 .60905 L .31465 .60613 L F
.516 .463 .736 r
.31457 .60953 m .31681 .61173 L .31632 .60905 L F
.253 0 0 r
.74225 .6131 m .73899 .61329 L .74051 .61215 L F
.483 .712 .971 r
.74384 .61155 m .74225 .6131 L .74051 .61215 L F
.74384 .61155 m .74465 .61294 L .74225 .6131 L F
.844 .493 .389 r
.56236 .71671 m .55923 .71395 L .56029 .71449 L F
.968 .735 .3 r
.57277 .74921 m .5733 .74799 L .57199 .7471 L F
.57277 .74921 m .57336 .75001 L .5733 .74799 L F
.999 .844 .542 r
.61906 .73624 m .62031 .7341 L .61923 .73303 L F
.61906 .73624 m .62 .73702 L .62031 .7341 L F
.804 .409 .305 r
.55923 .71395 m .55543 .71134 L .55721 .71173 L F
.797 .608 .645 r
.58149 .70936 m .58107 .71333 L .58489 .71141 L F
.871 .927 .859 r
.58107 .71333 m .58198 .71358 L .58489 .71141 L F
.547 .557 .817 r
.58489 .71141 m .58753 .71116 L .58637 .70836 L F
.883 .657 .591 r
.59682 .70935 m .59666 .71182 L .5948 .70861 L F
.556 .834 .997 r
.27526 .64099 m .27588 .63958 L .27736 .64049 L F
.27526 .64099 m .27374 .64017 L .27588 .63958 L F
0 .001 .558 r
.45055 .78399 m .45157 .78367 L .44995 .78085 L F
.563 .611 .859 r
.45076 .78705 m .45157 .78367 L .45055 .78399 L F
.579 .491 .72 r
.76466 .59868 m .76496 .60187 L .7631 .60241 L F
.449 .185 .42 r
.76496 .60187 m .76329 .60287 L .7631 .60241 L F
.93 .731 .612 r
.47361 .76751 m .47328 .76996 L .47201 .76691 L F
.055 .613 .805 r
.47201 .76691 m .46877 .7666 L .47065 .76691 L F
.603 .066 0 r
.56407 .71729 m .56488 .71842 L .56236 .71671 L F
.56407 .71729 m .56599 .71916 L .56488 .71842 L F
.481 .445 .74 r
.35102 .69797 m .35148 .70102 L .35348 .70019 L F
.651 .812 .961 r
.35049 .7029 m .35348 .70019 L .35148 .70102 L F
.384 .841 .772 r
.28652 .6398 m .2872 .6393 L .28857 .63927 L F
.28652 .6398 m .28539 .64011 L .2872 .6393 L F
.532 .43 .683 r
.34698 .67899 m .34913 .67859 L .34861 .67546 L F
.543 .454 .704 r
.34698 .67899 m .34952 .68096 L .34913 .67859 L F
.34698 .67899 m .34745 .6813 L .34952 .68096 L F
.874 .466 .247 r
.67251 .52609 m .67417 .52654 L .67463 .5282 L F
.472 .445 .746 r
.75301 .59518 m .75372 .59832 L .75558 .59812 L F
.439 .421 .742 r
.75372 .59832 m .75652 .60009 L .75558 .59812 L F
.323 .783 .944 r
.40738 .66411 m .40581 .66371 L .40371 .66396 L F
.127 .676 .757 r
.40942 .66339 m .40581 .66371 L .40738 .66411 L F
.315 0 .065 r
.40188 .69807 m .40416 .69758 L .40551 .69563 L F
.25 0 .029 r
.40551 .69563 m .40629 .69692 L .40759 .69512 L F
.40551 .69563 m .40416 .69758 L .40629 .69692 L F
.831 .766 .791 r
.6643 .48632 m .6657 .48769 L .66293 .48743 L F
.553 .327 .526 r
.6657 .48769 m .6638 .49033 L .66293 .48743 L F
.6657 .48769 m .66596 .48973 L .6638 .49033 L F
.763 .765 .854 r
.6676 .48526 m .6657 .48769 L .6643 .48632 L F
.518 .516 .793 r
.725 .60656 m .72303 .60372 L .72553 .60354 L F
.763 .541 .596 r
.725 .60656 m .72594 .61158 L .72411 .60874 L F
.3 .189 .556 r
.72762 .60266 m .725 .60656 L .72553 .60354 L F
.72762 .60266 m .72783 .60526 L .725 .60656 L F
.375 .281 .62 r
.72802 .6077 m .725 .60656 L .72783 .60526 L F
.72802 .6077 m .72594 .61158 L .725 .60656 L F
.06 .252 .746 r
.67875 .51139 m .67833 .51265 L .67654 .51176 L F
.67875 .51139 m .68006 .5145 L .67833 .51265 L F
.747 .475 .519 r
.49687 .79829 m .49957 .79798 L .49978 .80019 L F
.992 .738 .417 r
.66369 .50423 m .66269 .50573 L .663 .50537 L F
.66373 .506 m .66376 .50693 L .66269 .50573 L F
.408 0 0 r
.66269 .50573 m .66408 .50662 L .6618 .5055 L F
.66269 .50573 m .6618 .5055 L .66144 .50532 L F
.992 .738 .417 r
.66369 .50423 m .66373 .506 L .66269 .50573 L F
.874 .545 .424 r
.56174 .70606 m .56299 .70903 L .56451 .70897 L F
.572 .023 0 r
.56299 .70903 m .56701 .70992 L .56451 .70897 L F
.266 0 .011 r
.26972 .6106 m .2684 .61022 L .27101 .60911 L F
.235 0 0 r
.27178 .61008 m .27101 .60911 L .27318 .60846 L F
.27178 .61008 m .26972 .6106 L .27101 .60911 L F
.499 0 0 r
.56701 .70992 m .56898 .71076 L .5698 .70978 L F
.679 .174 .036 r
.56898 .71076 m .57212 .71142 L .5698 .70978 L F
.602 .031 0 r
.5698 .70978 m .57212 .71142 L .57365 .71191 L F
.987 .716 .363 r
.57856 .73404 m .57762 .73319 L .57754 .73103 L F
0 .005 .574 r
.58003 .73689 m .57762 .73319 L .57856 .73404 L F
.768 .693 .78 r
.72303 .60372 m .71963 .60345 L .72193 .60068 L F
.777 .697 .776 r
.72521 .60109 m .72303 .60372 L .72193 .60068 L F
.657 .515 .678 r
.72521 .60109 m .72553 .60354 L .72303 .60372 L F
.143 .634 .915 r
.29254 .59041 m .29464 .59059 L .29595 .59127 L F
0 .473 .751 r
.29464 .59059 m .29823 .59152 L .29595 .59127 L F
.544 .409 .648 r
.7637 .59544 m .76078 .59376 L .76342 .59168 L F
.7637 .59544 m .76141 .59563 L .76078 .59376 L F
.337 .729 .983 r
.75157 .61953 m .75329 .61998 L .75201 .61922 L F
.094 .46 .887 r
.75329 .61998 m .75405 .61944 L .75201 .61922 L F
.75329 .61998 m .75485 .62064 L .75405 .61944 L F
.083 0 .38 r
.5492 .73666 m .54915 .73873 L .54759 .73946 L F
.51 .289 .515 r
.54915 .73873 m .54687 .73979 L .54759 .73946 L F
.54 .635 .894 r
.37982 .692 m .37938 .69475 L .37805 .69197 L F
.37982 .692 m .38148 .69451 L .37938 .69475 L F
.702 .457 .55 r
.53199 .74798 m .52838 .75012 L .52971 .74785 L F
.246 0 0 r
.39356 .66821 m .39212 .66914 L .39029 .66933 L F
.28 0 0 r
.39583 .66834 m .39212 .66914 L .39356 .66821 L F
.919 .609 .442 r
.51854 .772 m .51986 .77019 L .52003 .77229 L F
.704 .484 .587 r
.52356 .77022 m .52003 .77229 L .51986 .77019 L F
.436 .772 .997 r
.43749 .65151 m .43662 .65259 L .43512 .65163 L F
.43749 .65151 m .43883 .65243 L .43662 .65259 L F
.58 .442 .658 r
.35111 .72405 m .35125 .72575 L .35365 .72346 L F
.637 .736 .92 r
.46286 .66769 m .45953 .6669 L .46173 .66668 L F
.052 .311 .797 r
.46422 .66749 m .46286 .66769 L .46173 .66668 L F
.46422 .66749 m .46516 .66955 L .46286 .66769 L F
.726 .342 0 r
.57327 .72599 m .57282 .72559 L .57206 .72374 L F
0 .246 .757 r
.57404 .72791 m .57282 .72559 L .57327 .72599 L F
.904 .631 .129 r
.63781 .50637 m .63764 .50431 L .63708 .50341 L F
.752 .503 .555 r
.64089 .50652 m .63764 .50431 L .63781 .50637 L F
.107 .454 .885 r
.49334 .75906 m .49513 .7611 L .49684 .76163 L F
.499 .098 .211 r
.66266 .53999 m .66216 .54178 L .6599 .54097 L F
.451 .148 .36 r
.66485 .53956 m .66216 .54178 L .66266 .53999 L F
.933 .969 .735 r
.49938 .7406 m .49786 .74165 L .49844 .74241 L F
.812 .545 .535 r
.49548 .74432 m .49844 .74241 L .49786 .74165 L F
.49548 .74432 m .49886 .74494 L .49844 .74241 L F
.672 .525 .677 r
.64587 .51509 m .64818 .51513 L .64775 .5121 L F
0 0 0 r
.64775 .5121 m .64994 .51118 L .65042 .51029 L F
0 0 .49 r
.64775 .5121 m .64921 .51297 L .64994 .51118 L F
.64775 .5121 m .64818 .51513 L .64921 .51297 L F
.618 .702 .904 r
.70373 .51523 m .70021 .51422 L .70252 .51174 L F
.744 .647 .753 r
.7059 .51244 m .70373 .51523 L .70252 .51174 L F
.534 .355 .585 r
.70606 .51467 m .70373 .51523 L .7059 .51244 L F
.774 .702 .783 r
.70606 .51467 m .7037 .51752 L .70373 .51523 L F
.823 .882 .887 r
.5024 .76318 m .50415 .76407 L .50628 .76172 L F
.674 .603 .768 r
.50415 .76407 m .5077 .76495 L .50628 .76172 L F
.553 .531 .784 r
.50415 .76407 m .50742 .76744 L .5077 .76495 L F
.715 .43 .492 r
.52949 .76996 m .52768 .77244 L .52552 .76994 L F
.784 .46 .439 r
.52949 .76996 m .53119 .77248 L .52994 .77136 L F
.579 .484 .71 r
.52994 .77136 m .53194 .77056 L .53182 .77049 L F
.784 .46 .439 r
.52949 .76996 m .52994 .77136 L .52774 .77237 L F
.579 .484 .71 r
.52994 .77136 m .53182 .77049 L .52873 .76856 L F
.784 .46 .439 r
.52774 .77237 m .52994 .77136 L .52768 .77244 L F
0 0 0 r
.55424 .75402 m .55369 .75593 L .55481 .75232 L F
.67 .485 .625 r
.52171 .72572 m .52036 .72731 L .51954 .72571 L F
.871 .713 .684 r
.3282 .71691 m .32954 .72006 L .33052 .71722 L F
.391 0 0 r
.53722 .7203 m .53997 .72099 L .54061 .7205 L F
.574 .049 0 r
.54172 .72184 m .54061 .7205 L .53997 .72099 L F
.54172 .72184 m .54294 .72281 L .54061 .7205 L F
.665 .124 0 r
.54061 .7205 m .54294 .72281 L .54403 .72335 L F
.275 .75 .936 r
.3164 .59415 m .31848 .59404 L .32014 .59446 L F
.329 .777 .958 r
.31848 .59404 m .32216 .59425 L .32014 .59446 L F
.242 .745 .894 r
.45423 .7871 m .45307 .78685 L .45076 .78705 L F
.327 .665 .974 r
.45423 .7871 m .45512 .78613 L .45307 .78685 L F
.45423 .7871 m .45637 .78738 L .45512 .78613 L F
.729 .478 .548 r
.60766 .55132 m .60431 .55347 L .60617 .55012 L F
.60766 .55132 m .60771 .55362 L .60431 .55347 L F
.708 .43 .502 r
.60766 .55132 m .60956 .55292 L .60771 .55362 L F
.93 .622 .439 r
.57212 .71142 m .57239 .71364 L .57365 .71191 L F
.671 .257 .25 r
.57365 .71191 m .57291 .71293 L .57584 .7138 L F
.57291 .71293 m .57239 .71364 L .57328 .71368 L F
.57291 .71293 m .57328 .71368 L .57584 .7138 L F
.57584 .7138 m .57239 .71364 L .5759 .71386 L F
.843 .596 .565 r
.57423 .71567 m .5759 .71386 L .57328 .7137 L F
0 0 .317 r
.57328 .71368 m .57423 .71567 L .57239 .71364 L F
.843 .596 .565 r
.57423 .71567 m .57328 .7137 L .57239 .71364 L F
0 0 .317 r
.57302 .71316 m .57395 .71503 L .57413 .71544 L F
.57301 .71314 m .57302 .71314 L .57302 .71316 L F
.57302 .71314 m .57395 .71503 L .57302 .71316 L F
.57328 .71368 m .57413 .71544 L .57423 .71567 L F
.57301 .71314 m .57413 .71544 L .57328 .71368 L F
.57301 .71314 m .57328 .71368 L .57239 .71364 L F
.416 .638 .947 r
.33867 .5977 m .33813 .59937 L .33667 .59796 L F
.33867 .5977 m .34079 .5997 L .33813 .59937 L F
.812 .603 .619 r
.5225 .79994 m .52578 .80053 L .52591 .79788 L F
.781 .449 .426 r
.52968 .80058 m .52591 .79788 L .52578 .80053 L F
.439 .049 .202 r
.47308 .74715 m .47633 .74492 L .47404 .74504 L F
.48 .006 .051 r
.58433 .67462 m .58658 .67478 L .58747 .67318 L F
.695 .235 .155 r
.58658 .67478 m .5898 .67523 L .58747 .67318 L F
.701 .213 .084 r
.58747 .67318 m .5898 .67523 L .59147 .67521 L F
.402 .158 .426 r
.30645 .62581 m .3082 .62527 L .30863 .62336 L F
.452 .306 .591 r
.3082 .62527 m .31033 .62237 L .30863 .62336 L F
0 0 0 r
.48967 .78852 m .49169 .78516 L .49148 .78763 L F
.397 .174 .455 r
.4911 .78381 m .48875 .78631 L .48892 .78476 L F
.4911 .78381 m .49079 .78623 L .48875 .78631 L F
0 0 .362 r
.48967 .78852 m .48875 .78631 L .49079 .78623 L F
0 0 0 r
.48967 .78852 m .49079 .78623 L .49169 .78516 L F
.569 .53 .772 r
.48824 .78486 m .4896 .78847 L .49148 .78763 L F
.34 .807 .714 r
.48983 .78837 m .48967 .78852 L .49148 .78763 L F
0 0 .362 r
.48967 .78852 m .48965 .78935 L .48946 .78872 L F
0 .198 .725 r
.49179 .7912 m .48967 .78852 L .4885 .79095 L F
.569 .53 .772 r
.4896 .78847 m .48969 .78868 L .49148 .78763 L F
.34 .807 .714 r
.48989 .78831 m .48983 .78837 L .49148 .78763 L F
0 0 .362 r
.48967 .78852 m .48946 .78872 L .48875 .78631 L F
.732 .618 .731 r
.48702 .78943 m .4879 .78918 L .48824 .78486 L F
.34 .807 .714 r
.48923 .78863 m .48967 .78852 L .48982 .78838 L F
.89 .928 .545 r
.48915 .78886 m .48967 .78852 L .48923 .78863 L F
.732 .618 .731 r
.48914 .78884 m .48969 .78868 L .48923 .78863 L F
.524 .909 .939 r
.48905 .78867 m .48969 .78868 L .48914 .78884 L F
.732 .618 .731 r
.4879 .78918 m .48914 .78884 L .48923 .78863 L F
.524 .909 .939 r
.48905 .78867 m .48914 .78884 L .48702 .78943 L F
.89 .928 .545 r
.4885 .79095 m .48935 .78919 L .48915 .78886 L F
.48935 .78919 m .48967 .78852 L .48915 .78886 L F
.48881 .78965 m .48923 .78863 L .48905 .78867 L F
.4885 .79095 m .48923 .78863 L .48881 .78965 L F
.732 .618 .731 r
.48923 .78863 m .48969 .78868 L .4896 .78847 L F
.4879 .78918 m .4896 .78847 L .48824 .78486 L F
.34 .807 .714 r
.48905 .78867 m .48923 .78863 L .48989 .78831 L F
.48923 .78863 m .48982 .78838 L .48989 .78831 L F
.16 .488 .902 r
.70798 .59055 m .71057 .59157 L .71032 .59257 L F
.781 .303 0 r
.71091 .59439 m .71198 .59512 L .71032 .59257 L F
.71091 .59439 m .71032 .59257 L .71057 .59157 L F
.763 .677 .767 r
.50107 .73934 m .50476 .73963 L .50331 .73896 L F
.391 .788 .986 r
.28877 .65285 m .28552 .65249 L .28669 .65309 L F
.679 .793 .935 r
.7263 .59688 m .72744 .59827 L .72418 .59776 L F
.78 .685 .759 r
.72418 .59776 m .72744 .59827 L .72521 .60109 L F
.643 .483 .651 r
.72744 .59827 m .72608 .60225 L .72521 .60109 L F
.613 .565 .777 r
.72648 .59293 m .72831 .59628 L .72886 .59504 L F
.87 .836 .81 r
.72886 .59504 m .72744 .59827 L .7263 .59688 L F
.535 .369 .603 r
.7302 .6004 m .72608 .60225 L .72744 .59827 L F
.266 0 .011 r
.26972 .6106 m .26763 .61117 L .2684 .61022 L F
.808 .8 .845 r
.69348 .52089 m .68946 .52216 L .69248 .51996 L F
.811 .879 .895 r
.69598 .51843 m .69348 .52089 L .69248 .51996 L F
.666 .587 .757 r
.69598 .51843 m .69595 .52072 L .69348 .52089 L F
.489 .282 .526 r
.69595 .52072 m .69383 .52357 L .69348 .52089 L F
.531 .411 .661 r
.34861 .67546 m .35038 .67256 L .34874 .67304 L F
.271 0 .161 r
.49595 .76899 m .49343 .76992 L .49627 .76769 L F
0 0 0 r
.49857 .76736 m .49595 .76899 L .49627 .76769 L F
.544 .391 .624 r
.49828 .76449 m .49857 .76736 L .49627 .76769 L F
.622 .643 .85 r
.45637 .78738 m .4577 .78956 L .45998 .78885 L F
.486 .198 .4 r
.43821 .68715 m .43762 .689 L .43539 .68918 L F
.486 .2 .405 r
.44037 .68678 m .43762 .689 L .43821 .68715 L F
.784 .627 .686 r
.50686 .72234 m .51021 .72594 L .50781 .72622 L F
.677 .522 .668 r
.50781 .72622 m .51021 .72594 L .50805 .72827 L F
.447 .174 .406 r
.30373 .62875 m .30566 .62831 L .30645 .62581 L F
.49 .215 .424 r
.30645 .62581 m .308 .62717 L .3082 .62527 L F
.30645 .62581 m .30566 .62831 L .308 .62717 L F
.876 .592 .503 r
.68889 .51467 m .68729 .51589 L .68692 .51523 L F
.68889 .51467 m .68918 .51772 L .68774 .51665 L F
.68729 .51589 m .68774 .51665 L .687 .51611 L F
.68889 .51467 m .68774 .51665 L .68729 .51589 L F
.568 .506 .745 r
.68582 .51338 m .68844 .51582 L .68668 .51053 L F
.68544 .51465 m .6869 .51522 L .68582 .51338 L F
.6869 .51522 m .68844 .51582 L .68582 .51338 L F
.68844 .51582 m .68873 .51593 L .68868 .5158 L F
.68844 .51582 m .68868 .5158 L .68668 .51053 L F
.876 .592 .503 r
.68729 .51589 m .687 .51611 L .68698 .51591 L F
.68729 .51589 m .68698 .51591 L .68692 .51523 L F
.63 .626 .828 r
.69138 .51408 m .68889 .51467 L .68829 .51409 L F
.553 .35 .559 r
.69168 .51697 m .68889 .51467 L .69138 .51408 L F
.69168 .51697 m .68918 .51772 L .68889 .51467 L F
.807 .417 .316 r
.52391 .80299 m .52733 .80402 L .52599 .80534 L F
.648 .203 .181 r
.52599 .80534 m .52733 .80402 L .52934 .80552 L F
.283 .746 .949 r
.26408 .65633 m .26539 .65625 L .26307 .65601 L F
.853 .401 .113 r
.59018 .75276 m .58742 .75009 L .58788 .75073 L F
.859 .797 .789 r
.62325 .51678 m .62206 .51451 L .62331 .51578 L F
.62325 .51678 m .62001 .51733 L .62206 .51451 L F
.86 .783 .774 r
.62325 .51678 m .62077 .52045 L .62001 .51733 L F
.2 0 0 r
.32216 .59425 m .32415 .59464 L .32595 .59483 L F
.08 0 0 r
.32595 .59483 m .32415 .59464 L .32771 .59502 L F
.224 0 0 r
.40793 .7068 m .40636 .70816 L .40419 .70855 L F
.106 0 0 r
.40842 .70757 m .40793 .7068 L .40992 .7061 L F
.40842 .70757 m .40636 .70816 L .40793 .7068 L F
.217 0 0 r
.38873 .6484 m .39093 .64847 L .39221 .64819 L F
.519 .014 0 r
.39093 .64847 m .39425 .64828 L .39221 .64819 L F
.974 .666 .339 r
.66833 .51252 m .66862 .51472 L .66717 .51147 L F
.57 .841 .996 r
.37261 .71957 m .37603 .71962 L .37488 .71905 L F
.249 0 0 r
.37799 .71922 m .37488 .71905 L .37603 .71962 L F
.46 .467 .779 r
.68232 .51232 m .68544 .51465 L .68445 .51109 L F
.514 .694 .95 r
.74899 .59157 m .75247 .59282 L .75178 .59161 L F
.508 .698 .955 r
.75178 .59161 m .75247 .59282 L .75406 .59134 L F
.357 .436 .806 r
.75247 .59282 m .75529 .59465 L .75406 .59134 L F
.501 .425 .703 r
.75301 .59518 m .75529 .59465 L .75247 .59282 L F
.512 .765 .988 r
.28214 .64041 m .2809 .64126 L .27945 .64001 L F
.645 .41 .548 r
.53463 .74986 m .53199 .74798 L .53734 .74764 L F
.251 .04 .386 r
.53913 .7453 m .53769 .74777 L .53734 .74764 L F
.448 .092 .268 r
.53769 .74777 m .53463 .74986 L .53734 .74764 L F
.694 .3 .296 r
.75848 .62062 m .7568 .62258 L .75485 .62064 L F
.509 .377 .637 r
.76048 .6176 m .76075 .61996 L .75848 .62062 L F
.734 .498 .571 r
.76075 .61996 m .7568 .62258 L .75848 .62062 L F
.591 .587 .816 r
.67498 .49226 m .678 .49317 L .6759 .49387 L F
.561 .565 .815 r
.67908 .4958 m .6759 .49387 L .678 .49317 L F
.641 .48 .649 r
.64587 .51509 m .64632 .51809 L .64358 .51803 L F
0 0 0 r
.64358 .51803 m .64497 .51696 L .64587 .51509 L F
.271 0 .056 r
.64587 .51509 m .64746 .5162 L .64818 .51513 L F
.64587 .51509 m .64497 .51696 L .64746 .5162 L F
.594 .555 .78 r
.45851 .66371 m .45624 .66416 L .4559 .6629 L F
.454 .781 .998 r
.27432 .58696 m .27634 .58668 L .27786 .58757 L F
.374 .754 .99 r
.27836 .58661 m .27786 .58757 L .27634 .58668 L F
.27836 .58661 m .27993 .58745 L .27786 .58757 L F
.781 .685 .759 r
.72418 .59776 m .72521 .60109 L .72193 .60068 L F
.401 .116 .362 r
.72762 .60266 m .72608 .60225 L .7302 .6004 L F
.285 .362 .767 r
.72521 .60109 m .72608 .60225 L .72762 .60266 L F
.72521 .60109 m .72762 .60266 L .72553 .60354 L F
.513 .465 .741 r
.34997 .69256 m .35111 .68962 L .34861 .68919 L F
.34997 .69256 m .35185 .69206 L .35111 .68962 L F
.344 .248 .6 r
.34997 .69256 m .3517 .69441 L .35185 .69206 L F
.34997 .69256 m .3503 .6951 L .3517 .69441 L F
.368 .756 .988 r
.31083 .5939 m .31301 .59368 L .31457 .59437 L F
.415 .781 .995 r
.31506 .59349 m .31457 .59437 L .31301 .59368 L F
.31506 .59349 m .3164 .59415 L .31457 .59437 L F
.525 .895 .968 r
.63577 .5233 m .63352 .52406 L .63193 .52387 L F
.8 .538 .542 r
.59199 .68928 m .59545 .6898 L .59323 .69154 L F
.839 .61 .592 r
.59323 .69154 m .59545 .6898 L .59531 .6924 L F
.276 .206 .594 r
.37791 .68231 m .37621 .68097 L .37797 .68082 L F
.37791 .68231 m .3765 .68478 L .37621 .68097 L F
.519 .348 .588 r
.45041 .75632 m .45254 .75835 L .4525 .75589 L F
.433 .343 .655 r
.45041 .75632 m .45078 .75897 L .45254 .75835 L F
.66 .968 .908 r
.64127 .51886 m .64255 .51754 L .64358 .51803 L F
.64127 .51886 m .6398 .5191 L .64255 .51754 L F
.036 0 0 r
.59394 .75553 m .59343 .7555 L .59169 .75542 L F
.262 0 0 r
.597 .75384 m .59343 .7555 L .59394 .75553 L F
.52 .329 .562 r
.34197 .70919 m .34205 .71203 L .34395 .71117 L F
.702 .543 .669 r
.34535 .71191 m .34197 .70919 L .34395 .71117 L F
.382 .127 .398 r
.46891 .74825 m .47044 .74959 L .47109 .74782 L F
.46891 .74825 m .46846 .75028 L .47044 .74959 L F
.697 .652 .801 r
.70956 .5174 m .70606 .51467 L .70829 .51414 L F
.691 .697 .851 r
.71184 .51467 m .70956 .5174 L .70829 .51414 L F
.575 .674 .907 r
.71227 .51744 m .70956 .5174 L .71184 .51467 L F
.58 .165 .22 r
.52103 .76584 m .52308 .76627 L .5243 .76433 L F
.785 .408 .341 r
.52308 .76627 m .52632 .76717 L .5243 .76433 L F
.871 .775 .754 r
.61732 .5315 m .61485 .5315 L .61652 .52853 L F
.853 .737 .735 r
.61732 .5315 m .61395 .5334 L .61485 .5315 L F
.61732 .5315 m .61567 .53455 L .61395 .5334 L F
.874 .777 .751 r
.61795 .52987 m .61732 .5315 L .61652 .52853 L F
.53 .22 .386 r
.64967 .54583 m .64957 .54731 L .64726 .54772 L F
.543 .231 .388 r
.64967 .54583 m .65181 .54719 L .64957 .54731 L F
.555 .219 .354 r
.65219 .54574 m .65181 .54719 L .64967 .54583 L F
.305 .027 .317 r
.53179 .79796 m .52968 .80058 L .53143 .80062 L F
.775 .397 .338 r
.52152 .71602 m .52438 .71517 L .5212 .71468 L F
.52152 .71602 m .52486 .71676 L .52438 .71517 L F
.488 .864 .981 r
.64358 .51803 m .64255 .51754 L .64497 .51696 L F
.526 .246 .433 r
.64632 .51809 m .64364 .52022 L .64358 .51803 L F
.67 .127 0 r
.54403 .72335 m .54632 .72558 L .54755 .72616 L F
.087 .619 .865 r
.54898 .72595 m .54755 .72616 L .54632 .72558 L F
.977 .709 .455 r
.5436 .7645 m .54465 .76505 L .54368 .76163 L F
.587 .514 .74 r
.54368 .76163 m .54465 .76505 L .54689 .76449 L F
.64 .644 .839 r
.55156 .77319 m .55282 .77578 L .5552 .77527 L F
.787 .287 0 r
.58099 .71715 m .58276 .71935 L .58425 .71993 L F
.856 .644 .106 r
.58401 .7217 m .58425 .71993 L .58276 .71935 L F
.58401 .7217 m .58441 .72285 L .58425 .71993 L F
.348 0 0 r
.36806 .6552 m .36737 .65388 L .36584 .65539 L F
.36806 .6552 m .36958 .65361 L .36737 .65388 L F
.802 .63 .669 r
.49525 .79158 m .4986 .7925 L .49763 .78948 L F
.8 .452 .399 r
.49731 .79421 m .4986 .7925 L .49525 .79158 L F
.691 .57 .715 r
.49763 .78948 m .4986 .7925 L .50092 .78953 L F
.75 .385 .363 r
.49731 .79421 m .50079 .79467 L .4986 .7925 L F
.731 .469 0 r
.6679 .52526 m .6687 .52865 L .66824 .52655 L F
.424 .468 .801 r
.4535 .65584 m .45177 .65595 L .45098 .65437 L F
.298 .731 .969 r
.42606 .65061 m .42965 .65125 L .42738 .65162 L F
.425 .299 .604 r
.46697 .76952 m .46484 .77273 L .46495 .7696 L F
.734 .578 .68 r
.72296 .59223 m .72215 .59764 L .72648 .59293 L F
.567 .84 .996 r
.72317 .59689 m .72182 .59835 L .72082 .59745 L F
.72317 .59689 m .72418 .59776 L .72182 .59835 L F
.781 .685 .759 r
.72418 .59776 m .72193 .60068 L .72182 .59835 L F
.531 .903 .959 r
.48848 .77333 m .49152 .7729 L .49031 .77192 L F
1 .816 .492 r
.61965 .73937 m .62 .73702 L .61906 .73624 L F
.74 .467 .516 r
.62636 .4976 m .62936 .49535 L .62785 .49766 L F
.593 .75 .953 r
.44316 .65139 m .44226 .65322 L .44091 .6521 L F
.44316 .65139 m .44437 .65269 L .44226 .65322 L F
.595 .441 .642 r
.501 .73703 m .50107 .73934 L .50004 .73744 L F
.976 .676 .367 r
.32449 .85622 m .32458 .85801 L .32328 .85518 L F
.804 .606 .046 r
.32441 .85637 m .32458 .85801 L .32449 .85622 L F
.697 .642 .79 r
.32458 .85801 m .32441 .85637 L .32328 .85518 L F
.804 .606 .046 r
.3244 .85638 m .32458 .85801 L .32441 .85637 L F
.697 .642 .79 r
.32458 .85801 m .32524 .85725 L .32441 .85637 L F
.682 .181 0 r
.32441 .85637 m .32449 .85622 L .32328 .85518 L F
.697 .642 .79 r
.32524 .85725 m .32667 .85562 L .32328 .85518 L F
.682 .181 0 r
.3244 .85638 m .32441 .85637 L .32328 .85518 L F
.402 .02 .195 r
.50107 .73934 m .49786 .74165 L .49938 .7406 L F
.717 .577 .696 r
.31865 .74796 m .31425 .74649 L .31701 .74567 L F
.31865 .74796 m .31527 .74812 L .31425 .74649 L F
.38 .122 .391 r
.31786 .748 m .31527 .74812 L .31865 .74796 L F
.635 .191 0 r
.31701 .74567 m .31792 .74711 L .31865 .74796 L F
.939 .951 .632 r
.31792 .74711 m .31786 .748 L .31865 .74796 L F
.952 .934 .738 r
.62374 .50927 m .62288 .50824 L .62453 .50731 L F
.976 .834 .636 r
.62374 .50927 m .62169 .51143 L .62288 .50824 L F
.62374 .50927 m .62278 .51221 L .62169 .51143 L F
0 0 0 r
.31316 .61734 m .31216 .6194 L .31431 .61706 L F
.596 .644 .868 r
.67417 .48883 m .67244 .491 L .67181 .4896 L F
.67417 .48883 m .67471 .4908 L .67244 .491 L F
.579 .589 .827 r
.67498 .49226 m .67244 .491 L .67471 .4908 L F
.475 .895 .889 r
.26629 .65645 m .26944 .65556 L .26831 .6558 L F
.442 .871 .923 r
.26944 .65556 m .2701 .65482 L .26831 .6558 L F
.26944 .65556 m .27163 .65487 L .2701 .65482 L F
.485 .045 .126 r
.51201 .75868 m .51081 .76023 L .50822 .75942 L F
.835 .47 .365 r
.51201 .75868 m .5137 .76142 L .51081 .76023 L F
.685 .559 .706 r
.51403 .75646 m .51418 .75912 L .51201 .75868 L F
.7 .451 .543 r
.51418 .75912 m .5137 .76142 L .51201 .75868 L F
0 0 0 r
.53157 .80271 m .53264 .80161 L .53143 .80062 L F
.71 .658 .797 r
.53264 .80161 m .53508 .80073 L .53143 .80062 L F
.335 .714 .983 r
.30811 .60551 m .30874 .60441 L .30568 .60429 L F
.30811 .60551 m .31068 .60551 L .30874 .60441 L F
.573 .393 .6 r
.70949 .50803 m .70833 .51211 L .7059 .51244 L F
.526 .323 .548 r
.70833 .51211 m .70606 .51467 L .7059 .51244 L F
.851 .786 .787 r
.70377 .50371 m .70467 .50689 L .70311 .50591 L F
.817 .675 .707 r
.70446 .50914 m .70311 .50591 L .70467 .50689 L F
.752 .733 .835 r
.70681 .50415 m .70467 .50689 L .70377 .50371 L F
.774 .416 .378 r
.67786 .52921 m .67503 .53024 L .67463 .5282 L F
.67786 .52921 m .67767 .53076 L .67503 .53024 L F
.591 .35 .52 r
.68007 .52849 m .67767 .53076 L .67786 .52921 L F
.38 .45 .807 r
.70976 .50711 m .7107 .50997 L .70949 .50803 L F
.714 .498 .595 r
.7107 .50997 m .70833 .51211 L .70949 .50803 L F
.7107 .50997 m .71217 .51226 L .70833 .51211 L F
.595 .588 .814 r
.71309 .50866 m .7107 .50997 L .70976 .50711 L F
.635 .476 .65 r
.71344 .51102 m .7107 .50997 L .71309 .50866 L F
.71344 .51102 m .71217 .51226 L .7107 .50997 L F
.784 .627 .686 r
.50686 .72234 m .5097 .72224 L .51021 .72594 L F
.658 .539 .707 r
.5097 .72224 m .51207 .72345 L .51021 .72594 L F
.969 .714 .492 r
.5429 .70354 m .54158 .70287 L .54157 .70048 L F
.805 .4 .283 r
.54521 .70547 m .54158 .70287 L .5429 .70354 L F
.676 .132 0 r
.54753 .70613 m .54521 .70547 L .5429 .70354 L F
.27 0 .022 r
.40137 .66445 m .4 .66629 L .39791 .66683 L F
.188 0 0 r
.40198 .66565 m .40137 .66445 L .40371 .66396 L F
.40198 .66565 m .4 .66629 L .40137 .66445 L F
.638 .263 .317 r
.48155 .79499 m .48523 .7947 L .48378 .79681 L F
.716 .411 .461 r
.48523 .7947 m .48722 .79723 L .48378 .79681 L F
.48523 .7947 m .48693 .79528 L .48722 .79723 L F
.418 .141 .382 r
.35207 .66245 m .34956 .66458 L .35135 .6642 L F
.515 .399 .66 r
.34956 .66458 m .35189 .66658 L .35135 .6642 L F
.34956 .66458 m .34972 .66763 L .35189 .66658 L F
.036 0 0 r
.29207 .60334 m .29145 .60338 L .28924 .60336 L F
.319 .806 .796 r
.29062 .60343 m .29145 .60338 L .2935 .60272 L F
.122 0 0 r
.28924 .60336 m .29145 .60338 L .28961 .60368 L F
.319 .806 .796 r
.28961 .60368 m .29145 .60338 L .29062 .60343 L F
.036 0 0 r
.29287 .60334 m .29145 .60338 L .29207 .60334 L F
.318 .775 .95 r
.29287 .60334 m .2935 .60272 L .29145 .60338 L F
.29287 .60334 m .29491 .60312 L .2935 .60272 L F
.491 .44 .728 r
.69036 .51158 m .68829 .51409 L .68773 .5094 L F
.63 .626 .828 r
.69138 .51408 m .68829 .51409 L .69036 .51158 L F
.333 0 0 r
.46338 .78957 m .46176 .78938 L .45998 .78885 L F
.652 .265 .298 r
.46556 .78912 m .46176 .78938 L .46338 .78957 L F
.443 .162 .391 r
.65496 .54287 m .65481 .54522 L .65219 .54574 L F
.213 0 .337 r
.65644 .54384 m .65496 .54287 L .65726 .54217 L F
.65644 .54384 m .65481 .54522 L .65496 .54287 L F
.586 .357 .535 r
.35135 .6642 m .35403 .66166 L .35207 .66245 L F
.619 .081 0 r
.54504 .72473 m .54403 .72335 L .54294 .72281 L F
.54504 .72473 m .54632 .72558 L .54403 .72335 L F
.543 .693 .937 r
.46703 .7765 m .46666 .7781 L .46509 .7754 L F
.46703 .7765 m .46883 .77785 L .46666 .7781 L F
.821 .722 .756 r
.68688 .53177 m .68312 .53158 L .68615 .53125 L F
.68688 .53177 m .68463 .53444 L .68312 .53158 L F
.649 .459 .613 r
.68735 .5341 m .68463 .53444 L .68688 .53177 L F
.459 .296 .572 r
.68933 .53116 m .68735 .5341 L .68688 .53177 L F
.563 .053 0 r
.28877 .65285 m .29225 .65303 L .29092 .65261 L F
.28877 .65285 m .29038 .65312 L .29225 .65303 L F
.415 .812 .984 r
.29436 .6528 m .29092 .65261 L .29225 .65303 L F
0 0 0 r
.30236 .65049 m .29843 .65202 L .30044 .65126 L F
.56537 .76756 m .56386 .76888 L .56237 .76998 L F
.56386 .76888 m .56128 .77133 L .56237 .76998 L F
.702 .457 .55 r
.53199 .74798 m .53197 .75023 L .52838 .75012 L F
.645 .41 .548 r
.53463 .74986 m .53197 .75023 L .53199 .74798 L F
.724 .596 .712 r
.68587 .52431 m .68512 .52662 L .68387 .52644 L F
.67 .32 .371 r
.69103 .5252 m .68807 .52547 L .68767 .52492 L F
.413 .263 .567 r
.68767 .52492 m .68807 .52547 L .68782 .52315 L F
.57 .376 .579 r
.68782 .52315 m .68807 .52547 L .68587 .52431 L F
.705 .433 .509 r
.6857 .5284 m .68387 .52644 L .68512 .52662 L F
.585 .302 .454 r
.73432 .59205 m .73683 .59008 L .73429 .59017 L F
.373 .114 .387 r
.32005 .63649 m .32241 .63401 L .32174 .63604 L F
.395 .137 .401 r
.32174 .63604 m .31957 .6394 L .32005 .63649 L F
.635 .957 .926 r
.71535 .59219 m .71416 .59224 L .71661 .59106 L F
.395 .456 .805 r
.71661 .59106 m .71807 .59418 L .71535 .59219 L F
.635 .957 .926 r
.71535 .59219 m .71416 .59224 L .71661 .59106 L F
.54 .106 .165 r
.54014 .76273 m .53791 .76184 L .53699 .76363 L F
.67 .532 .688 r
.53791 .76184 m .54195 .76149 L .54019 .75872 L F
.54 .142 .236 r
.54014 .76273 m .54195 .76149 L .53791 .76184 L F
.487 .348 .618 r
.44757 .77289 m .44973 .76961 L .44762 .77012 L F
.785 .588 .635 r
.55988 .70586 m .56299 .70903 L .56174 .70606 L F
.074 0 .286 r
.71891 .51146 m .71728 .51435 L .71766 .51227 L F
0 0 0 r
.28287 .60542 m .28713 .60343 L .28455 .60496 L F
.122 0 0 r
.28924 .60336 m .28961 .60368 L .28829 .60391 L F
.306 .798 .861 r
.28961 .60368 m .28861 .60383 L .28829 .60391 L F
.138 0 0 r
.28713 .60343 m .28829 .60391 L .28493 .60473 L F
.306 .798 .861 r
.28861 .60383 m .28604 .60423 L .28829 .60391 L F
.138 0 0 r
.28493 .60473 m .28829 .60391 L .28455 .60496 L F
.28713 .60343 m .28924 .60336 L .28829 .60391 L F
.457 .155 .364 r
.44839 .68166 m .44802 .68337 L .44589 .68371 L F
.507 .199 .379 r
.44839 .68166 m .45035 .68313 L .44802 .68337 L F
.509 .199 .376 r
.45051 .6814 m .45035 .68313 L .44839 .68166 L F
.342 .746 .982 r
.6673 .50921 m .66965 .50911 L .67067 .50985 L F
.295 .383 .783 r
.67228 .50841 m .67067 .50985 L .66965 .50911 L F
.809 .365 0 r
.67255 .52122 m .67343 .52281 L .67162 .52038 L F
.661 .789 .942 r
.26243 .64152 m .26386 .64268 L .26034 .64231 L F
.57 .761 .968 r
.26591 .64219 m .26386 .64268 L .26243 .64152 L F
.321 .084 .39 r
.32241 .63401 m .32461 .63136 L .32402 .63331 L F
.381 .135 .411 r
.32241 .63401 m .32393 .63609 L .32174 .63604 L F
.32241 .63401 m .32402 .63331 L .32393 .63609 L F
.487 .216 .429 r
.43762 .689 m .43496 .69224 L .43539 .68918 L F
.693 .586 .731 r
.43357 .6671 m .43454 .67049 L .43719 .6694 L F
.618 .21 .248 r
.50327 .80041 m .50709 .80038 L .50581 .80219 L F
.689 .321 .344 r
.50709 .80038 m .50756 .80264 L .50581 .80219 L F
.50709 .80038 m .50885 .80074 L .50756 .80264 L F
.362 .797 .964 r
.58395 .72509 m .58629 .7248 L .58719 .72546 L F
.587 .922 .966 r
.58719 .72546 m .58818 .72388 L .59003 .72325 L F
.58719 .72546 m .58629 .7248 L .58818 .72388 L F
.317 .282 .661 r
.44698 .77803 m .44766 .77536 L .44594 .77602 L F
.44698 .77803 m .44825 .77791 L .44766 .77536 L F
.174 .199 .647 r
.70304 .58974 m .70366 .5861 L .70457 .58664 L F
.363 .784 .975 r
.70366 .5861 m .70766 .58653 L .70457 .58664 L F
.322 .388 .776 r
.687 .51611 m .68544 .51465 L .68692 .51523 L F
.553 .399 .627 r
.48793 .7562 m .48567 .75825 L .48441 .75595 L F
.48793 .7562 m .48761 .75881 L .48567 .75825 L F
.472 .445 .746 r
.75301 .59518 m .75558 .59812 L .75529 .59465 L F
.556 .417 .647 r
.59 .73408 m .58976 .73645 L .5875 .73685 L F
0 .266 .748 r
.60502 .71696 m .60794 .71936 L .60689 .71725 L F
.575 .584 .825 r
.50267 .77307 m .50374 .76945 L .50424 .77009 L F
.50267 .77307 m .50508 .77269 L .50374 .76945 L F
.143 0 0 r
.2481 .58756 m .25151 .58627 L .24882 .58721 L F
.2481 .58756 m .25044 .587 L .25151 .58627 L F
.037 0 0 r
.25151 .58627 m .25244 .58641 L .25361 .58573 L F
.03 0 0 r
.25044 .587 m .25244 .58641 L .25151 .58627 L F
.337 .646 .967 r
.71499 .60748 m .71699 .60677 L .71401 .60615 L F
.71499 .60748 m .71782 .60796 L .71699 .60677 L F
.606 .611 .831 r
.34205 .71203 m .34313 .71484 L .34528 .71432 L F
.539 .345 .565 r
.34313 .71484 m .34516 .71672 L .34528 .71432 L F
.34528 .71432 m .34516 .71672 L .34313 .71484 L F
0 .07 .594 r
.58178 .74524 m .58246 .74418 L .58167 .7418 L F
.099 .124 .599 r
.58184 .74725 m .58246 .74418 L .58178 .74524 L F
.321 .712 .981 r
.28749 .58914 m .28697 .59003 L .28546 .5891 L F
.28749 .58914 m .28899 .59005 L .28697 .59003 L F
.335 .049 .321 r
.32924 .62574 m .33181 .62322 L .33092 .6252 L F
.505 .336 .585 r
.33181 .62322 m .33378 .62031 L .33339 .62253 L F
.248 0 .272 r
.33092 .6252 m .33181 .62322 L .33339 .62253 L F
.554 .381 .602 r
.50782 .71758 m .51061 .71675 L .51012 .71434 L F
.569 .299 .466 r
.5077 .71919 m .51061 .71675 L .50782 .71758 L F
.431 .185 .438 r
.327 .62864 m .32641 .63056 L .32461 .63136 L F
.415 .2 .476 r
.327 .62864 m .32924 .62574 L .32888 .62767 L F
.398 .154 .424 r
.3282 .63041 m .327 .62864 L .32888 .62767 L F
.3282 .63041 m .32641 .63056 L .327 .62864 L F
.97 .932 .67 r
.66831 .50676 m .66962 .50419 L .66798 .50546 L F
.9 .976 .809 r
.6691 .50338 m .66962 .50419 L .6717 .5014 L F
.959 .947 .679 r
.66798 .50546 m .66962 .50419 L .6691 .50338 L F
.009 0 0 r
.38691 .71583 m .38645 .71529 L .38877 .71485 L F
.38691 .71583 m .38488 .71654 L .38645 .71529 L F
.453 .072 .225 r
.47845 .74438 m .48072 .74416 L .48182 .742 L F
.501 .146 .296 r
.48072 .74416 m .48405 .74161 L .48182 .742 L F
.264 .38 .794 r
.31425 .74649 m .31612 .74645 L .31701 .74567 L F
.31425 .74649 m .31527 .74812 L .31612 .74645 L F
.614 .484 .68 r
.52726 .73741 m .52949 .7391 L .52972 .73676 L F
.52726 .73741 m .52736 .7395 L .52949 .7391 L F
.99 .742 .372 r
.5429 .76247 m .54368 .76163 L .54195 .76149 L F
.422 .638 .946 r
.54199 .76078 m .5429 .76247 L .54104 .76025 L F
.99 .742 .372 r
.5429 .76247 m .54362 .7638 L .54368 .76163 L F
.587 .514 .74 r
.54368 .76163 m .54689 .76449 L .54682 .76193 L F
.422 .638 .946 r
.54495 .76245 m .5429 .76247 L .54199 .76078 L F
.99 .742 .372 r
.5429 .76247 m .5436 .7645 L .54362 .7638 L F
.644 .508 .683 r
.54368 .76163 m .54682 .76193 L .5459 .75875 L F
.251 0 0 r
.39425 .64828 m .39639 .64875 L .39793 .6487 L F
.268 0 0 r
.39639 .64875 m .39994 .64843 L .39793 .6487 L F
.604 .174 .198 r
.49064 .79765 m .49429 .7974 L .49314 .79955 L F
.712 .267 .193 r
.49429 .7974 m .49468 .79932 L .49314 .79955 L F
.49429 .7974 m .49669 .79951 L .49468 .79932 L F
.691 .297 .296 r
.49429 .7974 m .49687 .79829 L .49669 .79951 L F
.599 .59 .813 r
.64678 .52229 m .64467 .52312 L .64364 .52022 L F
.618 .517 .717 r
.34861 .68919 m .35058 .68647 L .34856 .68695 L F
.637 .522 .706 r
.51686 .75848 m .51403 .75646 L .51625 .75601 L F
.557 .318 .51 r
.51983 .75592 m .51686 .75848 L .51625 .75601 L F
.407 .741 .993 r
.31176 .59276 m .31083 .5939 L .30924 .59288 L F
.31176 .59276 m .31301 .59368 L .31083 .5939 L F
.772 .671 .752 r
.53705 .77251 m .53811 .77574 L .53467 .77567 L F
.257 .751 .909 r
.53467 .77567 m .53811 .77574 L .53578 .77542 L F
.701 .633 .777 r
.54041 .773 m .53811 .77574 L .53705 .77251 L F
.705 .623 .763 r
.53341 .77454 m .53705 .77251 L .53467 .77567 L F
.53341 .77454 m .53382 .77198 L .53705 .77251 L F
.728 .237 .074 r
.53578 .77542 m .53341 .77454 L .53413 .77511 L F
.257 .751 .909 r
.53467 .77567 m .53578 .77542 L .53413 .77511 L F
.728 .237 .074 r
.53578 .77542 m .53739 .77633 L .53341 .77454 L F
.705 .623 .763 r
.53341 .77454 m .53526 .77537 L .53585 .77296 L F
.097 .285 .765 r
.53811 .77574 m .53898 .77475 L .53578 .77542 L F
.53898 .77475 m .53913 .77459 L .53744 .77501 L F
.53898 .77475 m .53744 .77501 L .53578 .77542 L F
.625 .556 .756 r
.53913 .77459 m .53739 .77633 L .53578 .77542 L F
.705 .623 .763 r
.53526 .77537 m .53739 .77633 L .53683 .77511 L F
.53526 .77537 m .53683 .77511 L .53585 .77296 L F
.7 .631 .776 r
.54041 .773 m .54205 .7758 L .53811 .77574 L F
.648 .294 .357 r
.54205 .7758 m .54051 .77782 L .53811 .77574 L F
.097 .285 .765 r
.53811 .77574 m .54051 .77782 L .53913 .77459 L F
.342 .03 .284 r
.2966 .63425 m .29412 .63641 L .29598 .63564 L F
.127 0 .071 r
.29598 .63564 m .29851 .63353 L .2966 .63425 L F
.696 .669 .82 r
.65268 .52055 m .65604 .52122 L .65488 .51964 L F
.682 .665 .827 r
.65488 .51964 m .65604 .52122 L .65836 .52047 L F
.014 .065 .57 r
.65604 .52122 m .65755 .52188 L .65836 .52047 L F
.65604 .52122 m .65655 .5237 L .65755 .52188 L F
.671 .593 .759 r
.52173 .74221 m .52473 .74383 L .52548 .7421 L F
.384 .177 .471 r
.52548 .7421 m .52706 .74178 L .52736 .7395 L F
.547 .316 .517 r
.52473 .74383 m .52706 .74178 L .52548 .7421 L F
.496 .214 .415 r
.31287 .75043 m .31513 .75022 L .31527 .74812 L F
.31527 .74812 m .31513 .75022 L .31287 .75043 L F
.38 .122 .391 r
.31527 .74812 m .31786 .748 L .31612 .74645 L F
.31527 .74812 m .31513 .75022 L .31786 .748 L F
.31786 .748 m .31513 .75022 L .31527 .74812 L F
.694 .641 .792 r
.69004 .50677 m .68764 .507 L .68641 .50415 L F
.686 .528 .667 r
.69004 .50677 m .68773 .5094 L .68764 .507 L F
.668 .405 .513 r
.68387 .52644 m .68416 .52937 L .68007 .52849 L F
.705 .433 .509 r
.6857 .5284 m .68416 .52937 L .68387 .52644 L F
.7 .239 .156 r
.5654 .78116 m .56322 .78211 L .56306 .78135 L F
.178 0 0 r
.56306 .78135 m .56467 .78135 L .5654 .78116 L F
.388 .84 .752 r
.5654 .78116 m .56672 .78038 L .56467 .78135 L F
.378 .824 .698 r
.5654 .78116 m .56672 .78038 L .56322 .78211 L F
.751 .819 .906 r
.73658 .61417 m .73339 .61439 L .73578 .61192 L F
.632 .68 .877 r
.73899 .61329 m .73658 .61417 L .73578 .61192 L F
.067 .181 .675 r
.3503 .6951 m .35102 .69797 L .35171 .69667 L F
.237 .403 .826 r
.35102 .69797 m .35245 .69779 L .35171 .69667 L F
.481 .445 .74 r
.35102 .69797 m .35348 .70019 L .35245 .69779 L F
.871 .927 .859 r
.58107 .71333 m .58086 .71354 L .58198 .71358 L F
.864 .832 .814 r
.6026 .70393 m .60236 .70036 L .60132 .70238 L F
.6026 .70393 m .60479 .70028 L .60236 .70036 L F
.633 .334 .445 r
.50885 .80074 m .51242 .80016 L .51103 .80271 L F
.681 .305 .327 r
.51242 .80016 m .51481 .80206 L .51103 .80271 L F
.51242 .80016 m .51469 .80063 L .51481 .80206 L F
.882 .461 .053 r
.551 .70149 m .55263 .70314 L .55149 .70049 L F
.858 .48 .331 r
.55149 .70049 m .55263 .70314 L .5542 .70326 L F
.457 .096 .264 r
.73299 .59736 m .73556 .59565 L .73518 .59682 L F
.39 .036 .239 r
.73518 .59682 m .73556 .59565 L .73759 .59615 L F
.385 0 .075 r
.73556 .59565 m .73786 .59537 L .73759 .59615 L F
.529 .356 .59 r
.55729 .7745 m .55465 .77464 L .55752 .7735 L F
.55729 .7745 m .5552 .77527 L .55465 .77464 L F
.271 .377 .788 r
.38677 .69729 m .38671 .70004 L .38512 .69727 L F
.38677 .69729 m .38819 .70075 L .38671 .70004 L F
.682 .312 .339 r
.50885 .80074 m .51103 .80271 L .50756 .80264 L F
.827 .86 .871 r
.68422 .50501 m .68085 .5063 L .68316 .5034 L F
.65 .7 .883 r
.68641 .50415 m .68422 .50501 L .68316 .5034 L F
.468 .849 .984 r
.54374 .77779 m .54051 .77782 L .54205 .7758 L F
.343 .722 .985 r
.73813 .62195 m .7413 .62277 L .74041 .62163 L F
.699 .832 .947 r
.74041 .62163 m .7413 .62277 L .74345 .62172 L F
.637 .522 .706 r
.51686 .75848 m .51418 .75912 L .51403 .75646 L F
.423 .227 .508 r
.44877 .76172 m .45062 .76129 L .45078 .75897 L F
.522 .401 .656 r
.4487 .76419 m .45062 .76129 L .44877 .76172 L F
.542 .825 .998 r
.33729 .79742 m .33373 .79712 L .33525 .79795 L F
.33729 .79742 m .33373 .79712 L .33525 .79795 L F
.142 .649 .902 r
.41491 .6638 m .41246 .6633 L .41297 .66393 L F
.343 .415 .792 r
.57648 .67527 m .57907 .67719 L .57986 .67567 L F
.57648 .67527 m .57763 .67863 L .57907 .67719 L F
.54 .477 .734 r
.57794 .68086 m .57907 .67719 L .57763 .67863 L F
.74 .646 .756 r
.49617 .7813 m .49268 .77963 L .49495 .78068 L F
.528 .919 .816 r
.49242 .78301 m .49617 .7813 L .49495 .78068 L F
.616 .7 .905 r
.76387 .58428 m .76257 .58707 L .76179 .58577 L F
.76387 .58428 m .76493 .58664 L .76257 .58707 L F
.655 .631 .813 r
.70021 .51422 m .69689 .51191 L .69909 .51136 L F
.762 .714 .807 r
.70252 .51174 m .70021 .51422 L .69909 .51136 L F
.513 .729 .971 r
.64597 .52899 m .64887 .52899 L .64717 .52745 L F
.567 .252 .395 r
.64692 .53012 m .64887 .52899 L .64597 .52899 L F
.125 .168 .636 r
.64692 .53012 m .64597 .52899 L .64717 .52745 L F
.573 .817 .991 r
.64404 .5273 m .64597 .52899 L .64717 .52745 L F
.606 .56 .777 r
.458 .66206 m .4559 .6629 L .45464 .65924 L F
.594 .555 .78 r
.45851 .66371 m .4559 .6629 L .458 .66206 L F
.233 0 .115 r
.42013 .70055 m .4172 .70266 L .41791 .70085 L F
.686 .792 .93 r
.49776 .76284 m .49828 .76449 L .50007 .76337 L F
.071 .223 .716 r
.50019 .76506 m .49828 .76449 L .49776 .76284 L F
.50019 .76506 m .50018 .76646 L .49828 .76449 L F
.412 .295 .609 r
.50018 .76646 m .49857 .76736 L .49828 .76449 L F
.749 .601 .693 r
.51686 .75848 m .5137 .76142 L .51418 .75912 L F
0 0 0 r
.50805 .72827 m .50668 .73032 L .50542 .73153 L F
.736 .241 0 r
.50805 .72827 m .50888 .72997 L .50668 .73032 L F
.709 .742 .877 r
.50888 .72997 m .50817 .73359 L .50668 .73032 L F
.802 .515 .504 r
.50808 .73107 m .50902 .73076 L .50888 .72997 L F
.736 .241 0 r
.50875 .72921 m .51038 .73141 L .50888 .72997 L F
.709 .742 .877 r
.50888 .72997 m .51038 .73141 L .50817 .73359 L F
.264 .742 .934 r
.50888 .72997 m .51239 .73027 L .51038 .73141 L F
.50888 .72997 m .51239 .73027 L .51038 .73141 L F
.51086 .73014 m .51168 .72988 L .51239 .73027 L F
.50888 .72997 m .51168 .72988 L .51086 .73014 L F
.649 .358 .464 r
.5161 .72883 m .51589 .73079 L .51355 .7305 L F
.624 .329 .449 r
.51589 .73079 m .51239 .73027 L .51355 .7305 L F
.51589 .73079 m .51245 .73246 L .51239 .73027 L F
.642 .559 .746 r
.51239 .73027 m .51035 .73293 L .51038 .73141 L F
.264 .742 .934 r
.50888 .72997 m .51168 .72988 L .51239 .73027 L F
.504 .19 .367 r
.51168 .72988 m .51317 .73141 L .51284 .7295 L F
.51168 .72988 m .51284 .7295 L .51265 .7284 L F
.536 .692 .94 r
.51038 .73141 m .51168 .72988 L .50888 .72997 L F
.802 .515 .504 r
.50902 .73076 m .51168 .72988 L .50888 .72997 L F
.736 .241 0 r
.50805 .72827 m .50875 .72921 L .50888 .72997 L F
.819 .369 .166 r
.54753 .70613 m .5477 .70674 L .54521 .70547 L F
.704 .484 .587 r
.52356 .77022 m .52239 .77302 L .52003 .77229 L F
.616 .387 .546 r
.52538 .77239 m .52356 .77022 L .52552 .76994 L F
.52538 .77239 m .52239 .77302 L .52356 .77022 L F
.171 .688 .888 r
.74899 .59157 m .75056 .59121 L .74838 .59211 L F
.74899 .59157 m .75178 .59161 L .75056 .59121 L F
.669 .699 .869 r
.45098 .65437 m .44785 .65367 L .45004 .65299 L F
.384 .47 .825 r
.45218 .65274 m .45098 .65437 L .45004 .65299 L F
.45218 .65274 m .4535 .65584 L .45098 .65437 L F
.605 .443 .635 r
.52426 .75561 m .5219 .75602 L .52175 .75352 L F
.73 .606 .718 r
.33092 .6252 m .32888 .62767 L .32924 .62574 L F
.369 .109 .383 r
.4525 .75589 m .4549 .75322 L .4526 .75347 L F
.563 .204 .317 r
.54377 .69986 m .5463 .7 L .54737 .69757 L F
.097 .504 .904 r
.54789 .69718 m .54929 .69838 L .54737 .69757 L F
.986 .751 .496 r
.54737 .69757 m .54501 .69867 L .54789 .69718 L F
.54737 .69757 m .5463 .7 L .54501 .69867 L F
.56 .353 .556 r
.25825 .62039 m .25591 .6228 L .25602 .62042 L F
.675 .825 .391 r
.64818 .51513 m .64746 .5162 L .64921 .51297 L F
.718 .706 .838 r
.54138 .75544 m .54321 .75806 L .54437 .75564 L F
.383 .792 .981 r
.42458 .66358 m .42325 .66302 L .42091 .66327 L F
.209 .64 .951 r
.42458 .66358 m .425 .66286 L .42325 .66302 L F
.42458 .66358 m .42636 .66374 L .425 .66286 L F
.449 .185 .42 r
.76496 .60187 m .76507 .60223 L .76329 .60287 L F
.547 .456 .704 r
.76622 .60614 m .76329 .60287 L .76507 .60223 L F
.76622 .60614 m .76387 .60659 L .76329 .60287 L F
.784 .494 .498 r
.63781 .50637 m .63885 .5094 L .64089 .50652 L F
.361 .168 .479 r
.51061 .71675 m .51238 .71418 L .51012 .71434 L F
.597 .573 .798 r
.7637 .59544 m .76185 .59748 L .76141 .59563 L F
.7637 .59544 m .76466 .59868 L .76185 .59748 L F
.984 .706 .347 r
.66613 .52228 m .66669 .52084 L .66643 .51987 L F
.66613 .52228 m .66706 .52334 L .66669 .52084 L F
.9 .976 .809 r
.6691 .50338 m .6717 .5014 L .67067 .49986 L F
.653 .744 .917 r
.67067 .49986 m .6717 .5014 L .67397 .50063 L F
.569 .296 .463 r
.46177 .67557 m .46075 .67852 L .45857 .67843 L F
.575 .303 .466 r
.46372 .67734 m .46177 .67557 L .46417 .67591 L F
.46372 .67734 m .46075 .67852 L .46177 .67557 L F
.661 .385 .492 r
.4326 .67605 m .43524 .67771 L .43475 .67523 L F
.4326 .67605 m .43239 .67796 L .43524 .67771 L F
.7 .616 .759 r
.51736 .74484 m .5195 .74512 L .51904 .74306 L F
.711 .452 .531 r
.51736 .74484 m .5194 .74766 L .5195 .74512 L F
.616 .561 .77 r
.51904 .74306 m .5195 .74512 L .52217 .74469 L F
.625 .415 .577 r
.5194 .74766 m .52217 .74469 L .5195 .74512 L F
.659 .614 .792 r
.35564 .72012 m .35986 .72243 L .35795 .71963 L F
.332 .304 .677 r
.35986 .72243 m .36037 .71966 L .35795 .71963 L F
.35986 .72243 m .36113 .72279 L .36037 .71966 L F
.374 .778 .984 r
.26591 .64219 m .26796 .64196 L .26953 .64263 L F
.715 .928 .961 r
.27136 .64148 m .26953 .64263 L .26988 .64103 L F
.674 .894 .977 r
.26953 .64263 m .26796 .64196 L .26988 .64103 L F
.245 0 0 r
.26127 .58451 m .26516 .58559 L .2629 .58595 L F
.699 .336 .357 r
.51382 .74475 m .51599 .74691 L .51736 .74484 L F
.792 .454 .416 r
.51599 .74691 m .5194 .74766 L .51736 .74484 L F
.363 .484 .848 r
.50542 .73153 m .50817 .73359 L .50599 .73424 L F
.50542 .73153 m .50668 .73032 L .50817 .73359 L F
.928 .805 .704 r
.6082 .7227 m .60794 .71936 L .6065 .72243 L F
.884 .525 .361 r
.60731 .72459 m .6082 .7227 L .6065 .72243 L F
.60731 .72459 m .60971 .72552 L .6082 .7227 L F
.804 .518 .504 r
.6082 .7227 m .60971 .72552 L .61134 .72533 L F
.224 0 0 r
.58122 .68181 m .57996 .68147 L .57794 .68086 L F
.489 .282 .526 r
.69595 .52072 m .69607 .52294 L .69383 .52357 L F
.602 .444 .64 r
.698 .5176 m .69595 .52072 L .69598 .51843 L F
.698 .5176 m .69849 .5206 L .69595 .52072 L F
.508 .296 .528 r
.69828 .52233 m .69595 .52072 L .69849 .5206 L F
.69828 .52233 m .69607 .52294 L .69595 .52072 L F
.402 0 0 r
.48848 .77333 m .4845 .77446 L .4861 .77414 L F
.872 .789 .766 r
.62001 .51733 m .62077 .52045 L .61934 .51902 L F
.853 .743 .741 r
.62077 .52045 m .6173 .52228 L .61934 .51902 L F
.62077 .52045 m .61894 .5234 L .6173 .52228 L F
.559 .26 .417 r
.45634 .67875 m .45588 .68062 L .45358 .68079 L F
.485 .192 .393 r
.45634 .67875 m .45809 .68028 L .45588 .68062 L F
.493 .19 .382 r
.45857 .67843 m .45809 .68028 L .45634 .67875 L F
.216 .727 .68 r
.27745 .65328 m .27644 .65359 L .27375 .65444 L F
.35 .826 .81 r
.28011 .65237 m .27832 .65275 L .27745 .65328 L F
.363 .824 .738 r
.27832 .65275 m .27644 .65359 L .27745 .65328 L F
.877 .838 .803 r
.50483 .76082 m .50628 .76172 L .50822 .75942 L F
.50483 .76082 m .50822 .75942 L .50711 .76017 L F
.733 .413 .44 r
.51081 .76023 m .50711 .76017 L .50822 .75942 L F
.861 .424 .008 r
.67036 .51777 m .67034 .51917 L .66915 .51667 L F
.67036 .51777 m .67162 .52038 L .67034 .51917 L F
.39 .14 .41 r
.51796 .73008 m .5161 .72883 L .52036 .72731 L F
.51796 .73008 m .51589 .73079 L .5161 .72883 L F
.227 0 .145 r
.49412 .7336 m .49618 .73293 L .49672 .73136 L F
.195 0 0 r
.49618 .73293 m .49894 .73094 L .49672 .73136 L F
.647 .191 .155 r
.49978 .80019 m .50327 .80041 L .50192 .80183 L F
.634 .175 .145 r
.50192 .80183 m .50327 .80041 L .50581 .80219 L F
.829 .999 .786 r
.62453 .50731 m .62288 .50824 L .62527 .50553 L F
.498 .12 .253 r
.49343 .76992 m .49241 .77204 L .49031 .77192 L F
.595 .327 .48 r
.49595 .76899 m .49241 .77204 L .49343 .76992 L F
.174 .199 .647 r
.70304 .58974 m .70427 .58833 L .70366 .5861 L F
.151 .165 .619 r
.70304 .58974 m .70487 .59224 L .70427 .58833 L F
.694 .641 .792 r
.69004 .50677 m .68641 .50415 L .68886 .50346 L F
.612 .422 .601 r
.69004 .50677 m .69005 .50916 L .68773 .5094 L F
.642 .664 .857 r
.69261 .50627 m .69004 .50677 L .68886 .50346 L F
.681 .53 .674 r
.69261 .50627 m .69005 .50916 L .69004 .50677 L F
.465 .054 .175 r
.46273 .75275 m .46514 .75252 L .46631 .75072 L F
.374 0 .143 r
.46514 .75252 m .46846 .75028 L .46631 .75072 L F
.588 .564 .795 r
.63531 .50668 m .63781 .50637 L .63708 .50341 L F
0 0 0 r
.59444 .69822 m .59435 .69912 L .59469 .69708 L F
.59444 .69822 m .59387 .70067 L .59435 .69912 L F
.58 .429 .641 r
.50331 .73896 m .501 .73703 L .50334 .7366 L F
.50331 .73896 m .50107 .73934 L .501 .73703 L F
.337 .046 .315 r
.33866 .61509 m .34121 .61269 L .34029 .61412 L F
.051 0 .027 r
.34029 .61412 m .34121 .61269 L .34283 .61167 L F
.579 .01 0 r
.46869 .79033 m .47104 .79169 L .46924 .79144 L F
.46869 .79033 m .46924 .79144 L .46887 .79042 L F
.621 .095 0 r
.47305 .79182 m .47104 .79169 L .46869 .79033 L F
.765 .649 .734 r
.5759 .71386 m .58054 .71463 L .57805 .71118 L F
.772 .527 .564 r
.57585 .71624 m .58054 .71463 L .5759 .71386 L F
.57585 .71624 m .57968 .71671 L .58054 .71463 L F
.652 .619 .804 r
.57805 .71118 m .58054 .71463 L .58086 .71354 L F
.828 .859 .406 r
.58054 .71463 m .57968 .71671 L .58086 .71354 L F
.957 .838 .685 r
.58086 .71354 m .57968 .71671 L .58099 .71715 L F
.779 .275 0 r
.57968 .71671 m .58276 .71935 L .58099 .71715 L F
.599 .398 .581 r
.53593 .7672 m .53606 .76994 L .53365 .77017 L F
.609 .368 .526 r
.53907 .76706 m .53606 .76994 L .53593 .7672 L F
.463 .134 .323 r
.4125 .69227 m .41432 .69197 L .41543 .68964 L F
.542 .215 .364 r
.41543 .68964 m .41724 .69114 L .41771 .68942 L F
.41543 .68964 m .41432 .69197 L .41724 .69114 L F
.761 .99 .773 r
.63096 .50544 m .63199 .50516 L .63097 .50329 L F
.63096 .50544 m .62988 .50711 L .63199 .50516 L F
.625 .683 .885 r
.63199 .50516 m .63308 .50286 L .63097 .50329 L F
.63199 .50516 m .63478 .50465 L .63308 .50286 L F
.557 .291 .468 r
.43475 .67523 m .43743 .67533 L .43764 .67302 L F
.57 .302 .47 r
.43764 .67302 m .43969 .67496 L .43961 .67217 L F
.43764 .67302 m .43743 .67533 L .43969 .67496 L F
.271 .534 .916 r
.60268 .75326 m .6036 .7522 L .60356 .75288 L F
.336 .773 .966 r
.60268 .75326 m .60356 .75288 L .6035 .75288 L F
.243 .491 .893 r
.60268 .75326 m .60473 .754 L .6039 .75269 L F
.60268 .75326 m .6035 .75288 L .6035 .75283 L F
.60347 .75235 m .6035 .75278 L .6036 .7522 L F
.482 .734 .982 r
.6035 .75278 m .6036 .7522 L .60249 .75115 L F
.60356 .75288 m .6036 .7522 L .6035 .75278 L F
.243 .491 .893 r
.6035 .75278 m .6035 .75283 L .6036 .7522 L F
.60268 .75326 m .6035 .75283 L .60347 .75235 L F
.482 .734 .982 r
.60351 .75286 m .60249 .75115 L .60052 .75177 L F
.60356 .75288 m .6035 .75278 L .60351 .75286 L F
.6035 .75278 m .60249 .75115 L .60351 .75286 L F
.488 .785 .997 r
.59893 .75296 m .6035 .75288 L .60052 .75177 L F
.6035 .75288 m .60356 .75288 L .60351 .75286 L F
.6035 .75288 m .60351 .75286 L .60052 .75177 L F
.243 .491 .893 r
.6035 .75288 m .6039 .75269 L .60373 .75241 L F
.6035 .75288 m .60373 .75241 L .6036 .7522 L F
.336 .773 .966 r
.60268 .75326 m .6035 .75288 L .59893 .75296 L F
.973 .731 .509 r
.51499 .76443 m .51359 .76401 L .5137 .76142 L F
.749 .601 .693 r
.51686 .75848 m .51574 .76314 L .5137 .76142 L F
.595 .448 .651 r
.52124 .75854 m .51574 .76314 L .51686 .75848 L F
.526 .348 .583 r
.52124 .75854 m .5172 .76359 L .51574 .76314 L F
.532 .567 .836 r
.5172 .76359 m .5137 .76142 L .51574 .76314 L F
.5172 .76359 m .51499 .76443 L .5137 .76142 L F
.588 .173 .222 r
.5172 .76359 m .51359 .76401 L .51499 .76443 L F
.762 .487 .518 r
.51499 .76443 m .51516 .76684 L .51845 .76636 L F
.693 .586 .731 r
.43357 .6671 m .43719 .6694 L .4357 .66897 L F
.454 .465 .781 r
.43719 .6694 m .43799 .6661 L .4357 .66897 L F
.43719 .6694 m .43905 .6694 L .43799 .6661 L F
.125 0 0 r
.51669 .77161 m .51308 .77154 L .51414 .77195 L F
.865 .803 .788 r
.69598 .51843 m .69597 .5159 L .698 .5176 L F
.645 .474 .637 r
.70164 .51979 m .698 .5176 L .70151 .51765 L F
.70164 .51979 m .69849 .5206 L .698 .5176 L F
.252 0 .208 r
.26718 .61324 m .26566 .61451 L .26699 .61411 L F
.32 0 .251 r
.26699 .61411 m .26423 .6157 L .26258 .61614 L F
.252 0 .208 r
.26566 .61451 m .26423 .6157 L .26699 .61411 L F
.32 0 .251 r
.26699 .61411 m .26448 .61527 L .26566 .61451 L F
.252 0 .208 r
.26566 .61451 m .26617 .61561 L .26423 .6157 L F
.445 .173 .405 r
.26718 .61324 m .26699 .61411 L .26671 .61368 L F
.252 0 .208 r
.26718 .61324 m .26716 .61329 L .26695 .61346 L F
.26718 .61324 m .26695 .61346 L .26566 .61451 L F
.445 .173 .405 r
.26718 .61324 m .26671 .61368 L .26569 .61208 L F
.439 .171 .408 r
.26569 .61208 m .26671 .61368 L .26295 .6147 L F
.26671 .61368 m .26699 .61411 L .26606 .61425 L F
.252 0 .208 r
.26716 .61329 m .26606 .61425 L .26566 .61451 L F
.439 .171 .408 r
.26671 .61368 m .26606 .61425 L .26295 .6147 L F
.252 0 .208 r
.26716 .61329 m .26701 .61364 L .26606 .61425 L F
.32 0 .251 r
.26699 .61411 m .26278 .61537 L .26295 .6147 L F
.252 0 .208 r
.26701 .61364 m .26617 .61561 L .26566 .61451 L F
.32 0 .251 r
.26566 .61451 m .26258 .61614 L .26278 .61537 L F
.26448 .61527 m .26258 .61614 L .26566 .61451 L F
.445 .173 .405 r
.26718 .61324 m .26569 .61208 L .26763 .61117 L F
.43 .214 .483 r
.32675 .63221 m .32461 .63136 L .32641 .63056 L F
.32675 .63221 m .32402 .63331 L .32461 .63136 L F
.434 .031 .173 r
.43286 .69274 m .43011 .69391 L .43041 .69303 L F
.636 .418 .57 r
.50817 .73359 m .5057 .73613 L .50599 .73424 L F
.495 .271 .504 r
.52736 .7395 m .52981 .741 L .52949 .7391 L F
.52736 .7395 m .52706 .74178 L .52981 .741 L F
.852 .767 .768 r
.56638 .68158 m .56354 .68159 L .565 .67996 L F
.56638 .68158 m .56421 .68433 L .56354 .68159 L F
.807 .838 .874 r
.56877 .67921 m .56638 .68158 L .565 .67996 L F
.451 .184 .416 r
.56869 .68238 m .56623 .68337 L .56638 .68158 L F
.429 .817 .988 r
.4113 .65038 m .41475 .65057 L .41274 .65001 L F
.721 .336 .32 r
.51469 .80063 m .51687 .80296 L .51481 .80206 L F
.499 .27 .498 r
.42564 .68412 m .42778 .68365 L .42808 .68141 L F
.534 .32 .535 r
.42778 .68365 m .43016 .68092 L .42808 .68141 L F
.386 .547 .892 r
.56938 .7661 m .56983 .76481 L .56714 .76612 L F
.56938 .7661 m .57088 .76722 L .56983 .76481 L F
.684 .977 .818 r
.56628 .7662 m .56537 .76756 L .56714 .76612 L F
.654 .913 .602 r
.56628 .7662 m .56386 .76888 L .56537 .76756 L F
.709 .453 0 r
.65836 .52047 m .65757 .51698 L .65901 .51827 L F
.53 .077 .122 r
.56943 .6811 m .57093 .68285 L .56869 .68238 L F
.425 .312 .622 r
.57303 .67746 m .56943 .6811 L .57101 .67848 L F
.472 .072 .199 r
.57258 .68196 m .5701 .68129 L .57349 .68018 L F
.5701 .68129 m .57043 .68088 L .57349 .68018 L F
.56 .405 .628 r
.57529 .67727 m .57349 .68018 L .57303 .67746 L F
.137 0 .348 r
.57308 .67753 m .57304 .68067 L .57419 .67912 L F
.57303 .67746 m .57303 .67759 L .57308 .67753 L F
.57303 .67759 m .57304 .68067 L .57308 .67753 L F
.472 .072 .199 r
.5701 .68129 m .56943 .6811 L .57043 .68088 L F
.447 .054 .199 r
.2906 .63863 m .29272 .63848 L .29412 .63641 L F
.032 0 0 r
.29412 .63641 m .29454 .6374 L .29598 .63564 L F
.29412 .63641 m .29272 .63848 L .29454 .6374 L F
.366 .801 .963 r
.47552 .78298 m .47791 .78267 L .47933 .78311 L F
.167 0 0 r
.47975 .7833 m .47933 .78311 L .47791 .78267 L F
.47975 .7833 m .48133 .78342 L .47933 .78311 L F
.635 .668 .864 r
.43194 .66415 m .43357 .6671 L .43593 .66641 L F
.616 .56 .769 r
.43357 .6671 m .4357 .66897 L .43593 .66641 L F
.04 .169 .673 r
.56687 .72281 m .56599 .71916 L .56812 .72045 L F
.312 .75 .967 r
.28327 .65289 m .2817 .65226 L .28011 .65237 L F
.356 .788 .969 r
.28552 .65249 m .2817 .65226 L .28327 .65289 L F
.312 .011 .284 r
.33603 .61752 m .33866 .61509 L .3379 .61683 L F
.174 0 .21 r
.3379 .61683 m .33866 .61509 L .34029 .61412 L F
.513 .334 .575 r
.54037 .74672 m .53913 .7453 L .53994 .74529 L F
.694 .343 .377 r
.53994 .74529 m .54196 .74761 L .54037 .74672 L F
.734 .333 .291 r
.54427 .74751 m .53994 .74529 L .54446 .74517 L F
.54427 .74751 m .54196 .74761 L .53994 .74529 L F
.549 .342 .552 r
.43038 .67853 m .4324 .68054 L .43239 .67796 L F
.43038 .67853 m .43016 .68092 L .4324 .68054 L F
.692 .431 .524 r
.52552 .76994 m .52768 .77244 L .52538 .77239 L F
.798 .807 .858 r
.59356 .73019 m .59311 .72773 L .5942 .72844 L F
.6 .579 .802 r
.67717 .49036 m .67498 .49226 L .67471 .4908 L F
.67717 .49036 m .678 .49317 L .67498 .49226 L F
.551 .236 .387 r
.69383 .52357 m .69343 .52507 L .69103 .5252 L F
.408 .105 .336 r
.69607 .52294 m .69343 .52507 L .69383 .52357 L F
.293 0 .024 r
.65726 .54217 m .6599 .54097 L .66012 .54143 L F
.477 0 0 r
.6599 .54097 m .66216 .54178 L .66012 .54143 L F
.632 .488 .668 r
.72193 .60068 m .71963 .60345 L .71994 .59984 L F
.882 .545 .407 r
.55263 .70314 m .55296 .70509 L .5542 .70326 L F
.819 .453 .363 r
.55296 .70509 m .55596 .7058 L .5542 .70326 L F
.712 .451 .528 r
.5542 .70326 m .55596 .7058 L .55845 .70578 L F
.398 .172 .45 r
.33378 .62031 m .33603 .61752 L .33561 .61957 L F
.415 .204 .483 r
.33339 .62253 m .33378 .62031 L .33561 .61957 L F
0 .266 .765 r
.5208 .80035 m .52391 .80299 L .52022 .80233 L F
.5208 .80035 m .52022 .80233 L .5225 .79994 L F
.413 .637 .948 r
.26011 .58294 m .25958 .58454 L .2582 .58421 L F
.26011 .58294 m .26127 .58451 L .25958 .58454 L F
.606 .611 .831 r
.34205 .71203 m .34528 .71432 L .34535 .71191 L F
.419 .081 .283 r
.51238 .71418 m .51453 .71386 L .51576 .71134 L F
.664 .338 .411 r
.51576 .71134 m .51453 .71386 L .51804 .71351 L F
.45 .157 .376 r
.3124 .64472 m .30993 .64684 L .31048 .64544 L F
.346 .764 .978 r
.32712 .72806 m .32885 .72877 L .32516 .72832 L F
.422 .198 .467 r
.32712 .72806 m .32516 .72832 L .32885 .72877 L F
.906 .856 .781 r
.32712 .72806 m .32885 .72877 L .32847 .72677 L F
.32712 .72806 m .32885 .72877 L .32847 .72677 L F
0 0 .385 r
.57445 .76087 m .57474 .76358 L .57401 .76457 L F
0 0 0 r
.57392 .76557 m .57401 .76457 L .57474 .76358 L F
.57392 .76557 m .57369 .76703 L .57401 .76457 L F
.952 .8 .657 r
.60289 .69184 m .60225 .69435 L .60385 .69467 L F
.966 .743 .55 r
.6022 .69663 m .60385 .69467 L .60225 .69435 L F
.6022 .69663 m .60348 .69745 L .60385 .69467 L F
.891 .785 .738 r
.60289 .69184 m .60385 .69467 L .60443 .69277 L F
.162 0 0 r
.39638 .71154 m .3925 .71314 L .39425 .71219 L F
.51 .371 .628 r
.34785 .60605 m .34774 .60835 L .34573 .60889 L F
.332 0 .193 r
.34573 .60889 m .34677 .61029 L .34471 .61091 L F
.34573 .60889 m .34774 .60835 L .34677 .61029 L F
.337 .729 .983 r
.75157 .61953 m .75201 .61922 L .74935 .61949 L F
.501 .757 .987 r
.43375 .65044 m .43298 .652 L .43155 .6507 L F
.43375 .65044 m .43512 .65163 L .43298 .652 L F
.322 .604 .949 r
.33476 .59804 m .33117 .59606 L .3331 .59568 L F
.459 .608 .911 r
.33667 .59796 m .33476 .59804 L .3331 .59568 L F
.171 .193 .641 r
.5459 .75875 m .54763 .76111 L .5475 .7577 L F
.12 .175 .647 r
.5459 .75875 m .54682 .76193 L .54763 .76111 L F
.351 .107 .398 r
.74911 .58311 m .74711 .58404 L .74955 .58327 L F
.358 .122 .414 r
.74955 .58327 m .74711 .58404 L .74706 .58646 L F
.635 .589 .785 r
.3544 .71701 m .35564 .72012 L .35795 .71963 L F
.79 .478 .461 r
.60971 .72552 m .61006 .72757 L .61134 .72533 L F
.809 .503 .472 r
.61006 .72757 m .61342 .72823 L .61134 .72533 L F
.822 .501 .447 r
.61134 .72533 m .61342 .72823 L .61467 .72814 L F
.524 .491 .762 r
.46075 .6635 m .45953 .6669 L .45851 .66371 L F
.46075 .6635 m .46173 .66668 L .45953 .6669 L F
.855 .823 .345 r
.57027 .76961 m .57014 .76896 L .57088 .76722 L F
0 .135 .682 r
.57088 .76722 m .57113 .76649 L .56983 .76481 L F
.68 .77 .287 r
.57088 .76722 m .57014 .76896 L .57113 .76649 L F
.581 .2 .284 r
.71006 .51946 m .70979 .52062 L .7072 .52027 L F
.28 0 .197 r
.71173 .52069 m .71006 .51946 L .7117 .51882 L F
.71173 .52069 m .70979 .52062 L .71006 .51946 L F
.782 .696 .77 r
.66293 .48743 m .6638 .49033 L .66097 .4899 L F
.077 .635 .793 r
.29903 .75839 m .30264 .75852 L .30057 .7589 L F
.30264 .75852 m .29903 .75839 L .30057 .7589 L F
.261 .537 .92 r
.64869 .49719 m .6479 .49836 L .6476 .49725 L F
.64869 .49719 m .6496 .49859 L .6479 .49836 L F
.347 0 .124 r
.74365 .59311 m .74523 .59363 L .74319 .59433 L F
.74365 .59311 m .74594 .59261 L .74523 .59363 L F
.478 .301 .561 r
.59859 .55094 m .59863 .55324 L .59655 .55399 L F
.597 .801 .978 r
.59655 .55399 m .59863 .55324 L .59488 .55299 L F
.448 .492 .812 r
.68218 .50942 m .68324 .50617 L .68085 .5063 L F
.68218 .50942 m .68483 .51083 L .68324 .50617 L F
.676 .297 .321 r
.68218 .50942 m .68445 .51109 L .68483 .51083 L F
.693 .304 .306 r
.48761 .75881 m .49 .76074 L .49105 .75891 L F
.419 .655 .957 r
.49105 .75891 m .49201 .75767 L .4888 .75775 L F
.49105 .75891 m .49334 .75906 L .49201 .75767 L F
.848 .884 .865 r
.49 .76074 m .49334 .75906 L .49105 .75891 L F
.211 0 0 r
.27617 .6071 m .27526 .60806 L .27318 .60846 L F
.214 0 0 r
.27803 .60661 m .27526 .60806 L .27617 .6071 L F
.466 .376 .67 r
.52968 .80058 m .53157 .80271 L .53143 .80062 L F
.583 .2 .282 r
.64972 .50338 m .64564 .50539 L .64558 .5037 L F
.64972 .50338 m .64811 .50558 L .64564 .50539 L F
.696 .335 .359 r
.64972 .50338 m .65151 .50557 L .64811 .50558 L F
.487 .279 .523 r
.45078 .75897 m .45266 .76081 L .45254 .75835 L F
.45078 .75897 m .45062 .76129 L .45266 .76081 L F
.625 .23 .274 r
.62248 .55365 m .62486 .55518 L .62365 .55387 L F
.82 .531 .501 r
.61697 .733 m .61896 .73083 L .61695 .73086 L F
.61697 .733 m .61923 .73303 L .61896 .73083 L F
.051 .543 .886 r
.71218 .60574 m .71401 .60615 L .71152 .60508 L F
.633 .601 .8 r
.72929 .71364 m .73312 .71503 L .73169 .71374 L F
.319 .072 .373 r
.35033 .70691 m .34947 .70939 L .35227 .70566 L F
.93 .749 .635 r
.68006 .5145 m .67968 .5178 L .68099 .51769 L F
.871 .524 .391 r
.67968 .5178 m .67953 .51889 L .68099 .51769 L F
0 0 0 r
.68099 .51769 m .68283 .51731 L .68346 .51777 L F
.68099 .51769 m .67953 .51889 L .68283 .51731 L F
.903 .654 .552 r
.60009 .6839 m .59832 .68101 L .59856 .68332 L F
.926 .644 .488 r
.5986 .68548 m .60009 .6839 L .59856 .68332 L F
.5986 .68548 m .60079 .68642 L .60009 .6839 L F
.392 .166 .447 r
.33561 .61957 m .33603 .61752 L .3379 .61683 L F
.356 0 .097 r
.30773 .64754 m .30645 .64945 L .30437 .6498 L F
.223 0 .032 r
.30993 .64684 m .30645 .64945 L .30773 .64754 L F
.581 .76 .964 r
.51207 .72345 m .51478 .72348 L .51359 .72197 L F
0 0 .433 r
.4712 .77766 m .47161 .77989 L .47101 .78009 L F
.456 .216 .46 r
.47213 .7835 m .47083 .78201 L .47101 .78009 L F
.861 .78 .77 r
.61567 .53455 m .61214 .53641 L .61395 .5334 L F
.61567 .53455 m .61387 .53758 L .61214 .53641 L F
.672 .642 .812 r
.76974 .60881 m .7674 .60927 L .76622 .60614 L F
.65 .475 .634 r
.76974 .60881 m .76753 .61176 L .7674 .60927 L F
.928 .549 .166 r
.57277 .74921 m .57452 .75254 L .57336 .75001 L F
.536 .401 .645 r
.34994 .67033 m .35189 .66658 L .34972 .66763 L F
.754 .778 .873 r
.48714 .78345 m .4911 .78381 L .48892 .78476 L F
.73 .772 .887 r
.6259 .5147 m .62331 .51578 L .62206 .51451 L F
.565 .55 .797 r
.68122 .4947 m .67908 .4958 L .678 .49317 L F
.627 .505 .695 r
.68122 .4947 m .67935 .49804 L .67908 .4958 L F
.995 .753 .415 r
.65186 .52177 m .65269 .52372 L .65268 .52055 L F
0 0 .324 r
.65268 .52055 m .6527 .51982 L .65206 .51759 L F
.859 .563 .486 r
.65488 .51964 m .65325 .52067 L .65206 .51759 L F
.178 0 0 r
.65344 .52097 m .65268 .52055 L .65275 .51987 L F
.859 .563 .486 r
.65325 .52067 m .65308 .52077 L .65284 .52002 L F
.65325 .52067 m .65284 .52002 L .65206 .51759 L F
.178 0 0 r
.65275 .51987 m .65268 .52055 L .6527 .51982 L F
.955 .894 .729 r
.65446 .51708 m .65319 .52049 L .65488 .51964 L F
.65319 .52049 m .65308 .52077 L .65325 .52067 L F
.65319 .52049 m .65325 .52067 L .65488 .51964 L F
.178 0 0 r
.65402 .52128 m .65344 .52097 L .65325 .52067 L F
.007 .069 .579 r
.65206 .51759 m .65284 .52002 L .65306 .51625 L F
.178 0 0 r
.65311 .52028 m .65325 .52067 L .65284 .52002 L F
.65311 .52028 m .65284 .52002 L .65305 .52021 L F
.007 .069 .579 r
.65284 .52002 m .65308 .52025 L .65305 .52021 L F
.65284 .52002 m .65308 .52024 L .65306 .51625 L F
.178 0 0 r
.65305 .52021 m .65284 .52002 L .65275 .51987 L F
.422 .217 .495 r
.65305 .52021 m .65186 .52177 L .6527 .51982 L F
.178 0 0 r
.65402 .52128 m .65327 .52068 L .65311 .52028 L F
.65327 .52068 m .65325 .52067 L .65319 .52049 L F
.65327 .52068 m .65319 .52049 L .65311 .52028 L F
.904 .818 .752 r
.65306 .51625 m .65308 .52024 L .65446 .51708 L F
.007 .069 .579 r
.65284 .52002 m .65308 .52077 L .65308 .52025 L F
.178 0 0 r
.65402 .52128 m .65186 .52177 L .65268 .52055 L F
.422 .217 .495 r
.65308 .52025 m .65186 .52177 L .65305 .52021 L F
.904 .818 .752 r
.65308 .52024 m .65308 .52077 L .65319 .52049 L F
.65308 .52025 m .65308 .52077 L .65308 .52024 L F
.422 .217 .495 r
.65376 .52134 m .65233 .52167 L .65308 .52025 L F
.65233 .52167 m .65186 .52177 L .65308 .52025 L F
.65402 .52128 m .65376 .52134 L .65305 .52021 L F
.904 .818 .752 r
.65308 .52024 m .65308 .52025 L .65308 .52024 L F
.65308 .52024 m .65319 .52049 L .65446 .51708 L F
.007 .069 .579 r
.65305 .52021 m .65308 .52025 L .65308 .52024 L F
.273 0 0 r
.37947 .65021 m .38174 .65001 L .38317 .6489 L F
.078 0 0 r
.38174 .65001 m .38507 .64889 L .38317 .6489 L F
.667 .66 .834 r
.68946 .52216 m .68782 .52315 L .68655 .52037 L F
.658 .204 .161 r
.76493 .58664 m .76825 .58706 L .76748 .5885 L F
.313 0 0 r
.76743 .5871 m .76825 .58706 L .76493 .58664 L F
.415 .862 .884 r
.77035 .58615 m .76825 .58706 L .76743 .5871 L F
0 0 0 r
.76748 .5885 m .76825 .58706 L .77035 .58615 L F
.268 .699 .965 r
.29491 .60312 m .29842 .60395 L .29697 .60272 L F
.512 .749 .981 r
.29697 .60272 m .29842 .60395 L .30043 .60361 L F
.733 .531 .619 r
.71483 .51454 m .71217 .51226 L .71313 .5131 L F
.692 .442 .541 r
.61748 .55558 m .61313 .55371 L .61733 .55356 L F
.673 .411 .516 r
.61733 .55356 m .6191 .55589 L .61748 .55558 L F
.813 .618 .638 r
.52661 .8028 m .52968 .80058 L .52578 .80053 L F
.52661 .8028 m .53014 .80354 L .52968 .80058 L F
.466 .376 .67 r
.52968 .80058 m .53014 .80354 L .53157 .80271 L F
.194 .7 .903 r
.28899 .59005 m .29116 .59004 L .29254 .59041 L F
.075 .61 .86 r
.2932 .59012 m .29254 .59041 L .29116 .59004 L F
.2932 .59012 m .29464 .59059 L .29254 .59041 L F
.425 .299 .604 r
.46697 .76952 m .4664 .77291 L .46484 .77273 L F
.502 .377 .642 r
.4664 .77291 m .46509 .7754 L .46484 .77273 L F
0 0 0 r
.63102 .50776 m .62964 .50857 L .62922 .50875 L F
.62872 .50897 m .62922 .50875 L .62827 .50969 L F
.735 .709 .175 r
.62823 .5094 m .62827 .50969 L .62922 .50875 L F
0 0 0 r
.62964 .50857 m .62823 .5094 L .62922 .50875 L F
.62988 .50711 m .62922 .50875 L .62872 .50897 L F
.735 .709 .175 r
.62823 .5094 m .62781 .51199 L .62827 .50969 L F
.513 .334 .575 r
.54037 .74672 m .53769 .74777 L .53913 .7453 L F
.814 .675 .709 r
.47449 .7755 m .47199 .77556 L .47356 .7735 L F
.238 0 0 r
.47449 .7755 m .4712 .77766 L .47199 .77556 L F
.47449 .7755 m .47316 .77725 L .4712 .77766 L F
.521 .043 .061 r
.47356 .7735 m .47629 .77369 L .47449 .7755 L F
.074 0 0 r
.47496 .77646 m .47449 .7755 L .47701 .77573 L F
.47496 .77646 m .47316 .77725 L .47449 .7755 L F
.598 .532 .751 r
.47629 .77369 m .47701 .77573 L .47449 .7755 L F
.487 .528 .825 r
.47201 .76691 m .47328 .76996 L .47525 .76969 L F
.67 .485 .625 r
.52171 .72572 m .52149 .72823 L .52036 .72731 L F
.721 .385 .408 r
.51516 .76684 m .5175 .76909 L .51845 .76636 L F
.519 .726 .967 r
.51991 .76563 m .52103 .76584 L .51845 .76636 L F
.847 .729 .733 r
.68463 .53444 m .68138 .53367 L .68312 .53158 L F
.856 .547 .464 r
.68463 .53444 m .68355 .53623 L .68138 .53367 L F
.665 .303 .349 r
.68706 .53624 m .68355 .53623 L .68463 .53444 L F
.614 .344 .485 r
.68735 .5341 m .68706 .53624 L .68463 .53444 L F
.491 .44 .728 r
.69036 .51158 m .68773 .5094 L .69005 .50916 L F
.671 .133 0 r
.47975 .79471 m .48155 .79499 L .48378 .79681 L F
.249 .053 .406 r
.49242 .78301 m .49079 .78623 L .4911 .78381 L F
.905 .712 .63 r
.60362 .71356 m .60502 .71696 L .60476 .71454 L F
.132 0 0 r
.39994 .64843 m .40212 .64884 L .40332 .64907 L F
.499 0 0 r
.40212 .64884 m .40582 .64885 L .40332 .64907 L F
.257 .317 .734 r
.67249 .48595 m .67108 .48741 L .6716 .4864 L F
.379 .51 .864 r
.67249 .48595 m .67417 .48883 L .67108 .48741 L F
.527 .466 .731 r
.67108 .48741 m .67417 .48883 L .67181 .4896 L F
.457 .097 .265 r
.42564 .68412 m .42728 .68521 L .42778 .68365 L F
.42564 .68412 m .42465 .68609 L .42728 .68521 L F
.533 .214 .373 r
.63037 .55123 m .63263 .55249 L .63137 .55256 L F
.55 .188 .307 r
.6327 .55118 m .63263 .55249 L .63037 .55123 L F
.393 .198 .492 r
.54366 .73617 m .54579 .73353 L .54394 .73528 L F
.541 .494 .752 r
.43593 .66641 m .4357 .66897 L .43799 .6661 L F
.292 .785 .886 r
.41822 .66354 m .41705 .66342 L .41491 .6638 L F
.385 .827 .945 r
.42091 .66327 m .41705 .66342 L .41822 .66354 L F
.837 .545 .495 r
.61342 .72823 m .61359 .7303 L .61467 .72814 L F
.779 .471 .466 r
.61359 .7303 m .61695 .73086 L .61467 .72814 L F
.613 .565 .777 r
.72648 .59293 m .72886 .59504 L .72858 .59252 L F
.099 .124 .599 r
.58184 .74725 m .5833 .74604 L .58246 .74418 L F
.079 .09 .569 r
.58265 .74787 m .5833 .74604 L .58184 .74725 L F
.844 .642 .63 r
.59264 .71389 m .59224 .71412 L .59131 .71318 L F
0 0 .121 r
.59131 .71318 m .59134 .7143 L .59111 .71245 L F
.76 .332 .235 r
.59111 .71245 m .59134 .7143 L .58753 .71116 L F
.59134 .7143 m .59086 .71439 L .58753 .71116 L F
.844 .642 .63 r
.59224 .71412 m .59086 .71439 L .59131 .71318 L F
.59086 .71439 m .59039 .71449 L .59067 .71409 L F
.59086 .71439 m .59067 .71409 L .59131 .71318 L F
0 .123 .653 r
.58753 .71116 m .59085 .71438 L .58822 .71138 L F
.58783 .71096 m .58822 .71138 L .58785 .71095 L F
.58753 .71116 m .58822 .71138 L .58783 .71096 L F
.59085 .71438 m .59085 .71438 L .58785 .71095 L F
.59086 .71439 m .59066 .71409 L .58785 .71095 L F
.725 .608 .726 r
.58785 .71095 m .59066 .71409 L .59131 .71318 L F
.55 .338 .545 r
.5846 .71724 m .58661 .71506 L .58871 .71465 L F
.444 .288 .574 r
.58661 .71506 m .58757 .71494 L .58871 .71465 L F
.795 .52 .523 r
.58871 .71465 m .59015 .71429 L .58956 .71563 L F
.58871 .71465 m .58956 .71563 L .58952 .71568 L F
.844 .642 .63 r
.59264 .71389 m .59204 .71622 L .58953 .71569 L F
0 0 .121 r
.59131 .71318 m .59142 .71493 L .59134 .7143 L F
.844 .642 .63 r
.59134 .71464 m .58953 .71569 L .59134 .7143 L F
.76 .332 .235 r
.59134 .7143 m .59142 .71493 L .59086 .71439 L F
.725 .608 .726 r
.59066 .71409 m .59142 .71493 L .59131 .71318 L F
.795 .52 .523 r
.59041 .71369 m .59067 .71409 L .58953 .71569 L F
.844 .642 .63 r
.59134 .7143 m .58953 .71569 L .59039 .71449 L F
.795 .52 .523 r
.58871 .71465 m .59174 .71543 L .59166 .71503 L F
.59041 .71369 m .59131 .71318 L .59067 .71409 L F
.59041 .71369 m .59166 .71503 L .59131 .71318 L F
.58871 .71465 m .59041 .71369 L .59015 .71429 L F
0 .123 .653 r
.59085 .71438 m .59086 .71439 L .59085 .71438 L F
.59086 .71439 m .59142 .71493 L .59066 .71409 L F
.795 .52 .523 r
.58871 .71465 m .59166 .71503 L .59041 .71369 L F
.763 .533 .585 r
.58953 .71569 m .58602 .71781 L .58871 .71465 L F
0 0 .121 r
.59131 .71318 m .59111 .71245 L .59264 .71389 L F
.471 .345 .627 r
.59287 .71138 m .59264 .71389 L .59111 .71245 L F
.725 .608 .726 r
.58785 .71095 m .59131 .71318 L .59132 .71207 L F
.751 .639 .078 r
.59132 .71207 m .59131 .71318 L .59131 .71163 L F
0 0 .396 r
.59149 .71413 m .59131 .71163 L .59131 .71318 L F
.59174 .71543 m .59161 .71429 L .59149 .71413 L F
.59161 .71429 m .59131 .71163 L .59149 .71413 L F
.59161 .71429 m .59186 .71397 L .59131 .71163 L F
.844 .642 .63 r
.59224 .71412 m .59134 .71464 L .59134 .7143 L F
0 0 .396 r
.59174 .71543 m .59182 .71441 L .59161 .71429 L F
.59182 .71441 m .59186 .71403 L .59161 .71429 L F
.55 .769 .979 r
.59182 .71441 m .59174 .71543 L .58871 .71465 L F
.55 .338 .545 r
.58508 .71744 m .58871 .71465 L .58602 .71781 L F
.5846 .71724 m .5857 .71655 L .58508 .71744 L F
.5857 .71655 m .58871 .71465 L .58508 .71744 L F
.763 .533 .585 r
.58953 .71569 m .59053 .72041 L .58602 .71781 L F
.444 .288 .574 r
.58671 .7151 m .58757 .71722 L .58946 .71632 L F
.58661 .71506 m .58666 .71517 L .58671 .7151 L F
.58666 .71517 m .58757 .71722 L .58671 .7151 L F
.58757 .71494 m .59172 .71443 L .58871 .71465 L F
.59172 .71443 m .59171 .71442 L .58871 .71465 L F
.811 .434 .342 r
.59204 .71622 m .59196 .71627 L .58953 .71569 L F
.997 .823 .549 r
.59196 .71627 m .59053 .72041 L .58953 .71569 L F
.795 .52 .523 r
.58952 .71568 m .58956 .71563 L .58953 .71569 L F
.717 .377 .402 r
.59053 .72041 m .5861 .72054 L .58602 .71781 L F
.168 0 .071 r
.58675 .71833 m .58892 .71812 L .58946 .71632 L F
.795 .759 .244 r
.58946 .71632 m .58892 .71812 L .58894 .71798 L F
.444 .288 .574 r
.58661 .71506 m .58946 .71632 L .58996 .71471 L F
.58661 .71506 m .59188 .71451 L .59184 .71442 L F
.168 0 .071 r
.58675 .71833 m .58946 .71632 L .58757 .71722 L F
.795 .759 .244 r
.58946 .71632 m .58894 .71798 L .58969 .71419 L F
.444 .288 .574 r
.58996 .71471 m .58946 .71632 L .59188 .71451 L F
.55 .769 .979 r
.59203 .7144 m .59174 .71543 L .59182 .71441 L F
.444 .288 .574 r
.59184 .71442 m .59188 .71451 L .59203 .7144 L F
0 0 .396 r
.59183 .7144 m .59193 .71425 L .59186 .71397 L F
.59174 .71543 m .59188 .71451 L .59183 .7144 L F
.444 .288 .574 r
.59184 .71442 m .59203 .7144 L .59182 .71441 L F
.957 .92 .73 r
.59203 .7144 m .59188 .71451 L .59187 .71429 L F
0 0 .396 r
.59188 .71451 m .59193 .71425 L .59183 .7144 L F
.957 .92 .73 r
.59187 .71429 m .58946 .71632 L .59083 .71358 L F
.444 .288 .574 r
.59172 .71443 m .59184 .71442 L .59171 .71442 L F
.59184 .71442 m .59182 .71441 L .59171 .71442 L F
.957 .92 .73 r
.59188 .71451 m .58946 .71632 L .59187 .71429 L F
0 0 .396 r
.59186 .71403 m .59186 .71397 L .59185 .71398 L F
.59186 .71403 m .59185 .71398 L .59161 .71429 L F
.262 0 0 r
.597 .75384 m .5957 .75512 L .59343 .7555 L F
.084 0 0 r
.59893 .75296 m .5957 .75512 L .597 .75384 L F
.628 .282 .366 r
.50637 .79682 m .50787 .79435 L .50433 .79512 L F
.704 .372 .412 r
.50637 .79682 m .50994 .79695 L .50787 .79435 L F
.621 .396 .554 r
.63141 .51396 m .63347 .51445 L .63354 .51238 L F
.63354 .51238 m .63347 .51445 L .63141 .51396 L F
.471 .235 .474 r
.63553 .51147 m .63354 .51238 L .63587 .51162 L F
.536 .345 .569 r
.63587 .51162 m .63347 .51445 L .63354 .51238 L F
.63587 .51162 m .63347 .51445 L .63354 .51238 L F
.502 .222 .421 r
.35814 .66099 m .35661 .65886 L .35608 .66125 L F
.35814 .66099 m .35881 .65848 L .35661 .65886 L F
.319 0 .045 r
.37379 .6526 m .3773 .65041 L .3751 .65033 L F
.149 .631 .922 r
.26733 .5855 m .27074 .58644 L .26866 .58675 L F
.278 .495 .888 r
.6496 .49859 m .6522 .49977 L .65128 .50111 L F
.248 .453 .864 r
.6522 .49977 m .65422 .50267 L .65128 .50111 L F
.735 .961 .941 r
.39159 .70045 m .39245 .69862 L .3933 .69905 L F
.39159 .70045 m .39038 .7002 L .39245 .69862 L F
.397 .118 .368 r
.43011 .69391 m .42737 .69613 L .42783 .6945 L F
.49 .805 1 r
.30223 .59143 m .30169 .59263 L .30019 .59183 L F
.30223 .59143 m .30374 .59225 L .30169 .59263 L F
.488 .249 .478 r
.30129 .63153 m .30339 .63098 L .30373 .62875 L F
.448 .214 .466 r
.30373 .62875 m .30532 .63047 L .30566 .62831 L F
.30373 .62875 m .30339 .63098 L .30532 .63047 L F
.525 .226 .402 r
.44589 .68371 m .44492 .68644 L .44265 .68665 L F
.559 .26 .417 r
.44957 .68567 m .44492 .68644 L .44589 .68371 L F
.582 .329 .499 r
.45002 .68528 m .44957 .68567 L .44802 .68337 L F
.392 0 .13 r
.44957 .68567 m .44674 .68752 L .44445 .6879 L F
.511 .147 .284 r
.45002 .68528 m .44674 .68752 L .44957 .68567 L F
.44979 .68544 m .44893 .68747 L .44674 .68752 L F
.45002 .68528 m .44993 .68547 L .44979 .68544 L F
.44993 .68547 m .44893 .68747 L .44979 .68544 L F
.559 .26 .417 r
.44935 .68535 m .44589 .68371 L .44802 .68337 L F
.44957 .68567 m .44873 .68522 L .44935 .68535 L F
.44873 .68522 m .44589 .68371 L .44935 .68535 L F
.623 .662 .867 r
.45004 .65299 m .44785 .65367 L .44687 .65178 L F
.448 .092 .268 r
.53769 .74777 m .53672 .74979 L .53463 .74986 L F
.528 .241 .423 r
.54037 .74672 m .53672 .74979 L .53769 .74777 L F
.127 .676 .757 r
.40942 .66339 m .40792 .66346 L .40581 .66371 L F
.419 .836 .967 r
.41246 .6633 m .40792 .66346 L .40942 .66339 L F
.251 0 .044 r
.65872 .54309 m .65726 .54217 L .66012 .54143 L F
.65872 .54309 m .65644 .54384 L .65726 .54217 L F
.794 .678 .735 r
.53623 .75503 m .53822 .75893 L .53323 .75819 L F
.742 .328 .265 r
.53822 .75893 m .53548 .76044 L .53323 .75819 L F
.713 .303 .268 r
.52486 .71676 m .52699 .71877 L .52835 .71711 L F
.7 .286 .258 r
.52699 .71877 m .53047 .71907 L .52835 .71711 L F
.618 .517 .717 r
.34861 .68919 m .35111 .68962 L .35058 .68647 L F
.487 .348 .618 r
.44757 .77289 m .44989 .77244 L .44973 .76961 L F
.38 .257 .585 r
.44757 .77289 m .44949 .77439 L .44989 .77244 L F
.44757 .77289 m .44766 .77536 L .44949 .77439 L F
.21 .403 .834 r
.44995 .78085 m .45117 .78006 L .44825 .77791 L F
.689 .251 0 r
.44995 .78085 m .45157 .78367 L .45085 .7825 L F
.44995 .78085 m .45085 .7825 L .45117 .78006 L F
.507 .28 .504 r
.26087 .61706 m .26032 .62072 L .25825 .62039 L F
.389 .178 .467 r
.26248 .61917 m .26087 .61706 L .26258 .61614 L F
.26248 .61917 m .26032 .62072 L .26087 .61706 L F
.753 .422 .425 r
.41356 .6448 m .41707 .64519 L .41415 .64399 L F
.815 .671 .704 r
.55481 .75232 m .55369 .75593 L .55271 .75238 L F
.06 0 0 r
.55481 .75232 m .55472 .75241 L .55271 .75238 L F
0 0 0 r
.38805 .67028 m .38653 .67211 L .38529 .67282 L F
.38653 .67211 m .38384 .67411 L .38529 .67282 L F
.977 .728 .492 r
.63605 .49678 m .63491 .49813 L .63677 .49887 L F
.812 .868 .889 r
.63239 .4987 m .63677 .49887 L .63402 .49778 L F
.63365 .49875 m .63315 .50023 L .63677 .49887 L F
.63239 .4987 m .63275 .49942 L .63365 .49875 L F
.63275 .49942 m .63315 .50023 L .63365 .49875 L F
.766 .663 .749 r
.6317 .50001 m .63097 .50329 L .63315 .50023 L F
0 0 0 r
.63115 .50043 m .63112 .50046 L .6311 .50046 L F
.766 .663 .749 r
.62978 .49971 m .6311 .50042 L .6317 .50001 L F
0 0 0 r
.63115 .50043 m .6311 .50046 L .6311 .50042 L F
.766 .663 .749 r
.6311 .50042 m .63114 .50044 L .63115 .50043 L F
.6311 .50042 m .63115 .50043 L .6317 .50001 L F
.6311 .50048 m .63097 .50329 L .63168 .50008 L F
0 0 0 r
.63338 .50033 m .63142 .50136 L .6311 .50047 L F
.63112 .50046 m .6311 .50047 L .6311 .50046 L F
.63338 .50033 m .6311 .50047 L .63112 .50046 L F
.766 .663 .749 r
.63112 .50046 m .63168 .50008 L .6317 .50001 L F
.6311 .50048 m .63168 .50008 L .63112 .50046 L F
.29 .786 .762 r
.6311 .50047 m .63096 .50062 L .6311 .50046 L F
.8 .652 .699 r
.6311 .50046 m .63096 .50062 L .62978 .49971 L F
.766 .663 .749 r
.63025 .50114 m .63031 .5013 L .63096 .50062 L F
.63025 .50114 m .63096 .50062 L .63094 .5006 L F
.8 .652 .699 r
.6311 .50046 m .62978 .49971 L .6311 .50042 L F
.766 .663 .749 r
.62978 .49971 m .63025 .50114 L .63114 .50044 L F
.868 .712 .687 r
.62978 .49971 m .62787 .50233 L .63097 .50329 L F
.8 .652 .699 r
.63096 .50062 m .62963 .50211 L .62978 .49971 L F
.766 .663 .749 r
.63094 .5006 m .63096 .50062 L .6311 .50048 L F
.63031 .5013 m .63097 .50329 L .6311 .50048 L F
.29 .786 .762 r
.63142 .50136 m .62963 .50211 L .63096 .50062 L F
.63142 .50136 m .63096 .50062 L .6311 .50047 L F
.639 .788 .953 r
.62978 .49971 m .63315 .50023 L .63239 .4987 L F
.636 .818 .97 r
.63114 .49792 m .62978 .49971 L .63239 .4987 L F
.526 .784 .991 r
.63239 .4987 m .6344 .49858 L .63114 .49792 L F
0 0 0 r
.6344 .49858 m .63115 .50043 L .63114 .49792 L F
.63115 .50043 m .6311 .50042 L .63114 .49792 L F
.8 .652 .699 r
.6311 .50042 m .62978 .49971 L .63114 .49792 L F
0 0 0 r
.63213 .49988 m .63136 .50045 L .63112 .50046 L F
.63213 .49988 m .63112 .50046 L .63115 .50043 L F
.6344 .49858 m .63338 .50033 L .63136 .50045 L F
.6344 .49858 m .63136 .50045 L .63213 .49988 L F
.722 .514 .609 r
.63308 .50286 m .63716 .50076 L .63315 .50023 L F
.259 0 0 r
.63683 .49867 m .63338 .50033 L .6341 .49909 L F
.63453 .49859 m .6341 .49909 L .6344 .49858 L F
.63683 .49867 m .6341 .49909 L .63453 .49859 L F
.977 .728 .492 r
.63575 .49589 m .63402 .49778 L .63491 .49813 L F
.63575 .49589 m .63491 .49813 L .63605 .49678 L F
.04 .169 .673 r
.56687 .72281 m .56778 .72176 L .56599 .71916 L F
.396 .713 .986 r
.56687 .72281 m .56908 .72292 L .56778 .72176 L F
.99 .742 .372 r
.5429 .76247 m .54195 .76149 L .54014 .76273 L F
.184 .645 .939 r
.59169 .75542 m .59289 .75298 L .59018 .75276 L F
.707 .366 .397 r
.59289 .75298 m .59419 .75447 L .59259 .75379 L F
.59289 .75298 m .59259 .75379 L .59018 .75276 L F
.274 .58 .942 r
.59018 .75276 m .59259 .75379 L .59132 .75189 L F
.349 .323 .689 r
.59473 .75203 m .59419 .75447 L .59289 .75298 L F
.772 .66 .739 r
.59264 .75373 m .59473 .75203 L .59289 .75298 L F
.274 .58 .942 r
.59259 .75379 m .59319 .75357 L .59264 .75373 L F
.772 .66 .739 r
.59342 .75351 m .59473 .75203 L .59264 .75373 L F
.184 .645 .939 r
.59219 .75488 m .59228 .75479 L .59243 .75434 L F
.59227 .75466 m .59243 .75434 L .59289 .75298 L F
.59219 .75488 m .59243 .75434 L .59227 .75466 L F
.781 .752 .827 r
.59358 .75198 m .59319 .75357 L .59473 .75203 L F
.59132 .75189 m .59292 .75333 L .59358 .75198 L F
.59292 .75333 m .59319 .75357 L .59358 .75198 L F
.59319 .75357 m .59419 .75447 L .59473 .75203 L F
.772 .66 .739 r
.59228 .75479 m .59342 .75351 L .59319 .75357 L F
.59243 .75434 m .59319 .75357 L .59264 .75373 L F
.59228 .75479 m .59319 .75357 L .59243 .75434 L F
.274 .58 .942 r
.59259 .75379 m .59419 .75447 L .59319 .75357 L F
.59264 .75373 m .59319 .75357 L .59292 .75333 L F
.184 .645 .939 r
.59227 .75425 m .59259 .75379 L .59289 .75298 L F
.274 .58 .942 r
.59259 .75379 m .59292 .75333 L .59132 .75189 L F
.184 .645 .939 r
.59169 .75542 m .59219 .75488 L .59259 .75379 L F
.59169 .75542 m .59259 .75379 L .59227 .75425 L F
.59169 .75542 m .59343 .7555 L .59228 .75479 L F
.661 .833 .413 r
.59387 .70067 m .59219 .70347 L .59281 .70229 L F
.774 .877 .452 r
.59387 .70067 m .59281 .70229 L .59435 .69912 L F
.312 .281 .663 r
.52766 .72795 m .52761 .7326 L .52956 .73011 L F
.642 .478 .646 r
.52761 .7326 m .53232 .73304 L .52956 .73011 L F
.52761 .7326 m .52854 .73341 L .53232 .73304 L F
.524 .013 0 r
.37488 .71905 m .37123 .7192 L .37261 .71957 L F
.749 .973 .708 r
.65755 .52188 m .65655 .5237 L .65512 .52458 L F
.557 .318 .51 r
.51983 .75592 m .5197 .75813 L .51686 .75848 L F
.655 .396 .517 r
.5219 .75602 m .5197 .75813 L .51983 .75592 L F
0 0 .093 r
.57489 .7573 m .57447 .75618 L .57458 .75503 L F
.57489 .7573 m .57384 .75852 L .57447 .75618 L F
.76 .562 .63 r
.53791 .73931 m .54075 .73958 L .54099 .73662 L F
.689 .5 .625 r
.54099 .73662 m .54386 .73831 L .54366 .73617 L F
.54099 .73662 m .54075 .73958 L .54386 .73831 L F
.482 .458 .754 r
.3789 .68607 m .37701 .68654 L .3765 .68478 L F
.56 .455 .692 r
.37926 .68899 m .37701 .68654 L .3789 .68607 L F
.37926 .68899 m .37752 .69071 L .37701 .68654 L F
.852 .493 .372 r
.55042 .70884 m .54841 .70842 L .5477 .70674 L F
.805 .319 .036 r
.55193 .71146 m .54841 .70842 L .55042 .70884 L F
.845 .462 .322 r
.55297 .71105 m .55193 .71146 L .55042 .70884 L F
.772 .362 .273 r
.5158 .79941 m .51679 .79764 L .51424 .79701 L F
.957 .641 .387 r
.5158 .79941 m .51755 .80026 L .51679 .79764 L F
.782 .594 .645 r
.57805 .71118 m .58107 .71333 L .58149 .70936 L F
.427 0 0 r
.55543 .71134 m .55193 .71146 L .55297 .71105 L F
.526 .246 .433 r
.64632 .51809 m .64596 .51986 L .64364 .52022 L F
.441 .669 .959 r
.58419 .74992 m .58664 .74888 L .58265 .74787 L F
.58419 .74992 m .58742 .75009 L .58664 .74888 L F
.747 .475 .519 r
.49687 .79829 m .49978 .80019 L .49669 .79951 L F
.383 .134 .409 r
.72886 .59504 m .73191 .59227 L .72858 .59252 L F
.563 .479 .718 r
.76772 .5999 m .76496 .60187 L .76466 .59868 L F
.585 .478 .699 r
.76772 .5999 m .76507 .60223 L .76496 .60187 L F
.798 .807 .858 r
.59356 .73019 m .5908 .73033 L .59311 .72773 L F
.816 .751 .791 r
.59356 .73019 m .59021 .73387 L .5908 .73033 L F
.251 0 0 r
.38863 .67155 m .38805 .67028 L .39029 .66933 L F
.38863 .67155 m .38653 .67211 L .38805 .67028 L F
.766 .366 0 r
.57046 .74434 m .57199 .7471 L .57199 .74693 L F
.709 .453 0 r
.65836 .52047 m .65814 .51959 L .65757 .51698 L F
.924 .851 .409 r
.65755 .52188 m .65814 .51959 L .65836 .52047 L F
.532 .269 .462 r
.41771 .68942 m .42004 .68914 L .42042 .68696 L F
.442 .19 .435 r
.42042 .68696 m .42208 .68861 L .42254 .68663 L F
.42042 .68696 m .42004 .68914 L .42208 .68861 L F
.609 .368 .526 r
.53907 .76706 m .53886 .76999 L .53606 .76994 L F
.51 .285 .509 r
.54123 .76916 m .53907 .76706 L .54151 .76724 L F
.54123 .76916 m .53886 .76999 L .53907 .76706 L F
.92 .525 .169 r
.66002 .49509 m .6598 .49653 L .65893 .49459 L F
.66002 .49509 m .66103 .49761 L .6598 .49653 L F
.228 0 0 r
.36388 .656 m .36186 .65657 L .36079 .65784 L F
0 0 0 r
.65976 .51066 m .66056 .50928 L .65982 .50842 L F
.572 .775 .975 r
.30043 .60361 m .30404 .60448 L .30245 .60339 L F
.409 .742 .993 r
.30245 .60339 m .30404 .60448 L .30568 .60429 L F
.475 .462 .764 r
.53881 .7533 m .54138 .75544 L .54085 .75321 L F
.39 .451 .803 r
.51308 .77154 m .51248 .77225 L .51042 .77067 L F
.692 .611 .76 r
.49916 .76099 m .50351 .76207 L .50111 .75864 L F
.823 .882 .887 r
.50337 .76224 m .50628 .76172 L .50483 .76082 L F
.5024 .76318 m .50264 .76308 L .50337 .76224 L F
.692 .578 .723 r
.50483 .76082 m .50403 .7622 L .5024 .76318 L F
.692 .611 .76 r
.50351 .76207 m .50403 .7622 L .50372 .76182 L F
.50351 .76207 m .50372 .76182 L .50111 .75864 L F
.823 .882 .887 r
.50264 .76308 m .50628 .76172 L .50337 .76224 L F
.857 .782 .777 r
.61387 .53758 m .61274 .53947 L .61214 .53641 L F
.232 0 .105 r
.41618 .70437 m .41532 .70314 L .4172 .70266 L F
.41618 .70437 m .41419 .70516 L .41532 .70314 L F
.451 .822 .993 r
.41475 .65057 m .41692 .65017 L .41828 .65077 L F
.353 .806 .944 r
.41692 .65017 m .42046 .65014 L .41828 .65077 L F
.382 .075 .314 r
.55931 .77421 m .55729 .7745 L .55752 .7735 L F
.624 .657 .862 r
.73134 .61926 m .73253 .62128 L .73465 .62061 L F
.733 .591 .698 r
.52972 .73676 m .52949 .7391 L .53294 .73892 L F
.676 .351 .418 r
.52949 .7391 m .5318 .74134 L .53294 .73892 L F
.746 .534 .607 r
.5318 .74134 m .53526 .739 L .53294 .73892 L F
.763 .712 .805 r
.70252 .51174 m .69909 .51136 L .70146 .50872 L F
.8 .731 .787 r
.70446 .50914 m .70252 .51174 L .70146 .50872 L F
.098 0 0 r
.73069 .59563 m .72905 .59553 L .72786 .5958 L F
.73118 .5956 m .72905 .59553 L .73069 .59563 L F
.87 .836 .81 r
.72886 .59504 m .72825 .59548 L .72905 .59553 L F
.72825 .59548 m .7263 .59688 L .72905 .59553 L F
.383 .134 .409 r
.72886 .59504 m .73117 .59479 L .73191 .59227 L F
.304 0 .135 r
.73118 .5956 m .72886 .59504 L .72905 .59553 L F
.73118 .5956 m .73117 .59479 L .72886 .59504 L F
.779 .639 .707 r
.5948 .70861 m .59666 .71182 L .59287 .71138 L F
.782 .595 .646 r
.59287 .71138 m .59666 .71182 L .59596 .71389 L F
.483 .223 .444 r
.73683 .59008 m .73919 .59147 L .73987 .58918 L F
.288 0 .085 r
.73919 .59147 m .74223 .58901 L .73987 .58918 L F
.737 .506 .578 r
.59488 .55299 m .59863 .55324 L .59859 .55094 L F
.254 0 0 r
.27526 .60806 m .27178 .61008 L .27318 .60846 L F
.647 .743 .919 r
.51824 .74169 m .51904 .74306 L .52173 .74221 L F
.616 .561 .77 r
.51904 .74306 m .52217 .74469 L .52173 .74221 L F
.531 .411 .661 r
.34861 .67546 m .35056 .67499 L .35038 .67256 L F
.598 .475 .684 r
.34861 .67546 m .35127 .6781 L .35056 .67499 L F
.34861 .67546 m .34913 .67859 L .35127 .6781 L F
.806 .654 .694 r
.52391 .80299 m .52578 .80053 L .5225 .79994 L F
.807 .417 .316 r
.52391 .80299 m .52599 .80534 L .52356 .8055 L F
.465 .306 .581 r
.52391 .80299 m .52356 .8055 L .52462 .80428 L F
.52391 .80299 m .52462 .80428 L .52022 .80233 L F
.806 .654 .694 r
.52391 .80299 m .5225 .79994 L .52393 .80185 L F
.818 .416 .289 r
.52395 .80376 m .52393 .80185 L .52124 .80175 L F
.52485 .80443 m .52433 .80296 L .52395 .80376 L F
0 0 0 r
.52434 .80286 m .52448 .80264 L .52391 .80299 L F
.52448 .80264 m .52498 .80157 L .52441 .80232 L F
.52436 .80271 m .52441 .80232 L .52391 .80299 L F
.52448 .80264 m .52441 .80232 L .52436 .80271 L F
.852 .442 0 r
.52434 .80286 m .52393 .80185 L .52433 .80296 L F
.52434 .80286 m .52433 .80296 L .52485 .80443 L F
.818 .416 .289 r
.52433 .80296 m .52393 .80185 L .52395 .80376 L F
0 0 0 r
.52448 .80264 m .52578 .80053 L .52498 .80157 L F
.755 .437 .447 r
.52434 .80286 m .52661 .8028 L .52578 .80053 L F
.74 .467 .516 r
.62636 .4976 m .62939 .49819 L .62936 .49535 L F
.614 .517 .72 r
.62936 .49535 m .63451 .49648 L .63166 .49279 L F
0 0 .378 r
.62936 .49535 m .63071 .49598 L .63451 .49648 L F
.63071 .49598 m .63144 .49612 L .63451 .49648 L F
.254 .384 .802 r
.63166 .49279 m .63451 .49648 L .63375 .49348 L F
0 0 .378 r
.63071 .49598 m .63088 .49605 L .63144 .49612 L F
.737 .545 .633 r
.63088 .49605 m .63375 .49348 L .63451 .49648 L F
.697 .514 .637 r
.63375 .49348 m .63395 .49661 L .63661 .49405 L F
.63395 .49661 m .63402 .49778 L .63473 .49676 L F
.63395 .49661 m .63473 .49676 L .63661 .49405 L F
0 0 .378 r
.62936 .49535 m .62939 .49819 L .63088 .49605 L F
.258 .537 .921 r
.28434 .58756 m .28386 .58878 L .28186 .58712 L F
.28434 .58756 m .28546 .5891 L .28386 .58878 L F
.566 .345 .54 r
.49356 .73579 m .49618 .73293 L .49412 .7336 L F
.525 0 0 r
.53393 .71942 m .53641 .72072 L .53722 .7203 L F
.49 0 0 r
.53641 .72072 m .53997 .72099 L .53722 .7203 L F
.601 .455 .655 r
.5908 .73033 m .58823 .72848 L .5906 .7281 L F
.5908 .73033 m .58855 .7309 L .58823 .72848 L F
.491 .308 .56 r
.46844 .67475 m .46639 .67295 L .46885 .67284 L F
.46844 .67475 m .46639 .6754 L .46639 .67295 L F
.158 0 .258 r
.50535 .72221 m .5077 .71919 L .50568 .72005 L F
.282 .784 .807 r
.39788 .69881 m .40188 .69807 L .39965 .6982 L F
0 .246 .757 r
.57404 .72791 m .57457 .72751 L .57282 .72559 L F
0 .353 .818 r
.57404 .72791 m .57573 .72878 L .57457 .72751 L F
.785 .679 .747 r
.69689 .51191 m .69355 .5116 L .69579 .50879 L F
.746 .603 .699 r
.69689 .51191 m .69601 .51487 L .69355 .5116 L F
.69689 .51191 m .6961 .51522 L .69601 .51487 L F
.601 .579 .801 r
.69909 .51136 m .69689 .51191 L .69579 .50879 L F
.281 0 0 r
.26539 .65625 m .2625 .65608 L .26307 .65601 L F
.26539 .65625 m .26465 .65631 L .2625 .65608 L F
.26539 .65625 m .26629 .65645 L .26465 .65631 L F
.831 .767 .792 r
.61274 .53947 m .61004 .5392 L .61214 .53641 L F
.836 .754 .774 r
.61274 .53947 m .61065 .54231 L .61004 .5392 L F
.752 .235 0 r
.56171 .73397 m .56272 .73522 L .56293 .73457 L F
.736 .21 0 r
.56272 .73522 m .56413 .73567 L .56293 .73457 L F
.408 .144 .398 r
.59228 .55326 m .593 .55121 L .59105 .55324 L F
.653 .387 .505 r
.59228 .55326 m .59488 .55299 L .593 .55121 L F
.864 .755 .741 r
.61821 .52556 m .6173 .52228 L .61894 .5234 L F
.61821 .52556 m .61528 .52537 L .6173 .52228 L F
.867 .737 .718 r
.61821 .52556 m .61652 .52853 L .61528 .52537 L F
.698 .432 .518 r
.49886 .74494 m .50237 .74705 L .50245 .74493 L F
.711 .461 .546 r
.50237 .74705 m .50488 .74497 L .50245 .74493 L F
.464 .765 .995 r
.7482 .61355 m .74465 .61294 L .74672 .61286 L F
.575 .721 .942 r
.74996 .61189 m .7482 .61355 L .74672 .61286 L F
.74996 .61189 m .74936 .61281 L .7482 .61355 L F
.163 0 .151 r
.63102 .50776 m .62988 .50711 L .63096 .50544 L F
.63102 .50776 m .62922 .50875 L .62988 .50711 L F
.641 .921 .977 r
.60473 .754 m .60817 .75341 L .60722 .75312 L F
.613 .937 .956 r
.60817 .75341 m .61006 .75251 L .60928 .75211 L F
.614 .938 .955 r
.60722 .75312 m .60817 .75341 L .60928 .75211 L F
.555 .372 .588 r
.7627 .61471 m .76284 .61725 L .76048 .6176 L F
.625 .461 .641 r
.76324 .61963 m .76048 .6176 L .76284 .61725 L F
.76324 .61963 m .76075 .61996 L .76048 .6176 L F
.928 .734 .25 r
.65285 .50653 m .6523 .50698 L .65151 .50557 L F
.65285 .50653 m .6528 .50918 L .6523 .50698 L F
.64 .644 .839 r
.55156 .77319 m .5552 .77527 L .55354 .77302 L F
.63 .666 .866 r
.55354 .77302 m .5552 .77527 L .55729 .7745 L F
.28 0 0 r
.39583 .66834 m .39436 .66911 L .39212 .66914 L F
0 0 0 r
.39652 .66852 m .39583 .66834 L .39791 .66683 L F
.39652 .66852 m .39436 .66911 L .39583 .66834 L F
.811 .879 .895 r
.69598 .51843 m .69248 .51996 L .69398 .51859 L F
.865 .803 .788 r
.69598 .51843 m .69398 .51859 L .69597 .5159 L F
.718 .512 .61 r
.7037 .51752 m .70164 .51979 L .70151 .51765 L F
.7037 .51752 m .70393 .52036 L .70164 .51979 L F
.745 .532 .607 r
.7072 .52027 m .70393 .52036 L .7037 .51752 L F
.906 .5 .2 r
.54477 .73142 m .5442 .73268 L .54182 .73093 L F
.54477 .73142 m .54579 .73353 L .5442 .73268 L F
.573 .295 .456 r
.46639 .6754 m .46372 .67734 L .46417 .67591 L F
.564 .318 .501 r
.55943 .78555 m .56218 .78323 L .55988 .78295 L F
.336 0 0 r
.4549 .75322 m .45723 .75318 L .45789 .75269 L F
.128 0 0 r
.45789 .75269 m .45939 .75272 L .46012 .75245 L F
.45789 .75269 m .45723 .75318 L .45939 .75272 L F
.81 .471 .415 r
.59069 .7214 m .59215 .71851 L .59132 .72007 L F
.59069 .7214 m .59135 .72152 L .59215 .71851 L F
.927 .801 .334 r
.59215 .71851 m .59135 .72152 L .59196 .71627 L F
.853 .881 .858 r
.59349 .71681 m .59215 .71851 L .59196 .71627 L F
.548 .363 .582 r
.76515 .61182 m .76504 .61423 L .7627 .61471 L F
.528 .34 .569 r
.76504 .61423 m .76284 .61725 L .7627 .61471 L F
.543 .118 .184 r
.54106 .75784 m .53766 .76058 L .53548 .76044 L F
.533 .106 .176 r
.54104 .76025 m .54106 .75784 L .54113 .75776 L F
.54104 .76025 m .53766 .76058 L .54106 .75784 L F
.369 .062 .308 r
.53119 .77248 m .53365 .77017 L .53382 .77198 L F
.845 .682 .68 r
.53606 .76994 m .53382 .77198 L .53365 .77017 L F
.2 0 .228 r
.65352 .54609 m .65219 .54574 L .65481 .54522 L F
.65352 .54609 m .65181 .54719 L .65219 .54574 L F
.59 .37 .55 r
.61313 .55371 m .61113 .55632 L .60956 .55292 L F
.61313 .55371 m .6134 .55587 L .61113 .55632 L F
.692 .442 .541 r
.61748 .55558 m .6134 .55587 L .61313 .55371 L F
.439 .049 .202 r
.47308 .74715 m .47526 .7469 L .47633 .74492 L F
.725 .454 .517 r
.48117 .7671 m .48109 .76947 L .47763 .76974 L F
.419 .055 .238 r
.47526 .7469 m .47845 .74438 L .47633 .74492 L F
.607 .18 .205 r
.48109 .76947 m .48068 .77145 L .47763 .76974 L F
.906 .722 .22 r
.48109 .76947 m .4811 .77195 L .48102 .77186 L F
.48109 .76947 m .48102 .77186 L .48068 .77145 L F
.779 .641 .082 r
.48117 .7671 m .48113 .76782 L .48109 .76947 L F
.48113 .76782 m .48095 .77105 L .48109 .76947 L F
.799 .643 .088 r
.48095 .77105 m .4811 .77195 L .48109 .76947 L F
.828 .461 .36 r
.48461 .76984 m .48095 .77105 L .48117 .7671 L F
.56 .504 .749 r
.31681 .61173 m .31852 .60864 L .31632 .60905 L F
.31681 .61173 m .31912 .61159 L .31852 .60864 L F
.476 .339 .615 r
.31745 .61437 m .31912 .61159 L .31681 .61173 L F
.482 .458 .754 r
.3789 .68607 m .3765 .68478 L .37791 .68231 L F
.776 .583 .638 r
.6259 .5147 m .62206 .51451 L .62278 .51221 L F
0 0 0 r
.62781 .51199 m .62679 .51344 L .6259 .5147 L F
.815 .733 .206 r
.62679 .51344 m .6266 .51568 L .6259 .5147 L F
0 0 0 r
.62781 .51199 m .62679 .51344 L .6259 .5147 L F
0 0 .365 r
.71842 .59658 m .71937 .59472 L .72082 .59745 L F
.067 .181 .675 r
.3503 .6951 m .35171 .69667 L .3517 .69441 L F
.976 .918 .664 r
.36876 .72289 m .37054 .72332 L .37265 .72283 L F
.36876 .72289 m .3689 .72441 L .37054 .72332 L F
.565 .553 .8 r
.76646 .5965 m .76466 .59868 L .7637 .59544 L F
.531 .503 .77 r
.76646 .5965 m .76772 .5999 L .76466 .59868 L F
.713 .685 .821 r
.69355 .5116 m .69138 .51408 L .69036 .51158 L F
.678 .628 .792 r
.69355 .5116 m .69601 .51487 L .69138 .51408 L F
.424 .251 .541 r
.69377 .51615 m .69138 .51408 L .69601 .51487 L F
.69377 .51615 m .69168 .51697 L .69138 .51408 L F
.585 .302 .454 r
.73432 .59205 m .73683 .59194 L .73683 .59008 L F
.483 .223 .444 r
.73683 .59008 m .73683 .59194 L .73919 .59147 L F
.918 .529 .243 r
.6266 .51568 m .6281 .5189 L .6288 .51763 L F
0 0 0 r
.63141 .51396 m .6288 .51763 L .62987 .51626 L F
.6288 .51763 m .6281 .5189 L .62987 .51626 L F
.242 .716 .94 r
.27074 .58644 m .27277 .58642 L .27432 .58696 L F
.299 .761 .948 r
.27277 .58642 m .27634 .58668 L .27432 .58696 L F
.17 0 0 r
.38298 .71742 m .38024 .71842 L .38096 .71784 L F
.522 .401 .656 r
.4487 .76419 m .45081 .76398 L .45062 .76129 L F
.391 .345 .687 r
.4487 .76419 m .451 .76594 L .45081 .76398 L F
.4487 .76419 m .44922 .76709 L .451 .76594 L F
.718 .543 .652 r
.60956 .55292 m .6086 .55792 L .60771 .55362 L F
.60956 .55292 m .61113 .55632 L .6086 .55792 L F
.333 .152 .479 r
.38192 .67732 m .38059 .67557 L .38212 .67498 L F
.38192 .67732 m .38034 .67796 L .38059 .67557 L F
.741 .867 .939 r
.74618 .61999 m .74935 .61949 L .74852 .61876 L F
.473 .807 .999 r
.74935 .61949 m .75088 .61848 L .74852 .61876 L F
.74935 .61949 m .75201 .61922 L .75088 .61848 L F
.492 .4 .679 r
.4888 .75775 m .48761 .75881 L .48793 .7562 L F
.63 .495 .679 r
.43524 .67771 m .43743 .67533 L .43475 .67523 L F
.801 .424 .344 r
.59025 .67704 m .59147 .67521 L .5898 .67523 L F
.59025 .67704 m .59345 .67791 L .59147 .67521 L F
.33 0 0 r
.52149 .72823 m .51796 .73008 L .52036 .72731 L F
.817 .675 .707 r
.70446 .50914 m .70146 .50872 L .70311 .50591 L F
.52 .719 .963 r
.33183 .59433 m .33117 .59606 L .3298 .59452 L F
.33183 .59433 m .3331 .59568 L .33117 .59606 L F
.533 .782 .989 r
.27772 .63893 m .27736 .64049 L .27588 .63958 L F
.27772 .63893 m .27945 .64001 L .27736 .64049 L F
.137 0 0 r
.40248 .7097 m .402 .70878 L .40419 .70855 L F
.40248 .7097 m .40045 .71034 L .402 .70878 L F
.638 .263 .317 r
.62987 .51626 m .63347 .51445 L .63141 .51396 L F
.402 .02 .195 r
.50107 .73934 m .5 .74137 L .49786 .74165 L F
.562 .223 .352 r
.50331 .73896 m .5 .74137 L .50107 .73934 L F
.391 .788 .986 r
.28877 .65285 m .28742 .65227 L .28552 .65249 L F
.286 .749 .949 r
.29092 .65261 m .28742 .65227 L .28877 .65285 L F
.572 .023 0 r
.56299 .70903 m .56548 .71044 L .56701 .70992 L F
.475 0 0 r
.56548 .71044 m .56898 .71076 L .56701 .70992 L F
.507 0 0 r
.38507 .64889 m .38721 .64933 L .38873 .6484 L F
.435 0 0 r
.38721 .64933 m .39093 .64847 L .38873 .6484 L F
0 .165 .658 r
.70867 .60284 m .70811 .60214 L .70673 .6009 L F
.70867 .60284 m .70987 .60381 L .70811 .60214 L F
.763 .765 .854 r
.6676 .48526 m .6643 .48632 L .66703 .48438 L F
.451 .636 .935 r
.66887 .48393 m .6676 .48526 L .66703 .48438 L F
.66887 .48393 m .6716 .4864 L .6676 .48526 L F
.83 .998 .834 r
.59033 .7225 m .59069 .7214 L .59132 .72007 L F
.997 .823 .549 r
.59196 .71627 m .59142 .72094 L .59053 .72041 L F
.59142 .72094 m .59135 .72152 L .59116 .72126 L F
.59142 .72094 m .59116 .72126 L .59053 .72041 L F
.83 .998 .834 r
.59003 .72325 m .58818 .72388 L .59069 .7214 L F
.321 0 .027 r
.58956 .72305 m .58989 .72285 L .59069 .7214 L F
.83 .998 .834 r
.59003 .72325 m .59069 .7214 L .59033 .7225 L F
.321 0 .027 r
.58989 .72285 m .59295 .72099 L .59112 .72132 L F
.58989 .72285 m .59112 .72132 L .59069 .7214 L F
.656 .828 .966 r
.59053 .72041 m .59135 .72152 L .59069 .7214 L F
.28 .746 .946 r
.59295 .72099 m .59088 .72078 L .59069 .7214 L F
.656 .828 .966 r
.59053 .72041 m .59069 .7214 L .58953 .72065 L F
.28 .746 .946 r
.59088 .72078 m .58953 .72065 L .59069 .7214 L F
.496 .133 .281 r
.4823 .7727 m .47903 .77514 L .4811 .77195 L F
.4823 .7727 m .48131 .77482 L .47903 .77514 L F
.882 .892 .834 r
.48461 .76984 m .4823 .7727 L .4811 .77195 L F
.631 .274 .347 r
.4845 .77446 m .48131 .77482 L .4823 .7727 L F
.197 .678 .931 r
.30924 .59288 m .30725 .59282 L .30585 .59221 L F
.598 .564 .788 r
.71458 .51653 m .71227 .51744 L .71184 .51467 L F
.439 .216 .477 r
.71458 .51653 m .7117 .51882 L .71227 .51744 L F
.723 .319 .282 r
.48722 .79723 m .49064 .79765 L .48936 .79937 L F
.603 .175 .202 r
.48936 .79937 m .49064 .79765 L .49314 .79955 L F
.536 .091 .141 r
.55115 .79026 m .55486 .78935 L .55395 .7909 L F
.55486 .78935 m .55528 .78925 L .55395 .7909 L F
.167 .698 .687 r
.55423 .78951 m .55413 .78953 L .55115 .79026 L F
.563 .226 .355 r
.55395 .7909 m .55423 .78951 L .55115 .79026 L F
.646 .517 .692 r
.54994 .79123 m .55187 .79202 L .55115 .79026 L F
.526 .454 .717 r
.55395 .7909 m .55187 .79202 L .55115 .79026 L F
.458 0 0 r
.55097 .79102 m .55395 .7909 L .55115 .79026 L F
.641 .88 .985 r
.55395 .7909 m .55187 .79202 L .55097 .79102 L F
.587 .882 .992 r
.55333 .79017 m .55395 .7909 L .55097 .79102 L F
.691 .292 .286 r
.55097 .79102 m .55395 .7909 L .5529 .79303 L F
.992 .824 .451 r
.55297 .79257 m .55395 .7909 L .55333 .79017 L F
.5529 .79303 m .55395 .7909 L .55297 .79257 L F
.796 .817 .869 r
.55395 .7909 m .55446 .78945 L .55423 .78951 L F
.545 .769 .981 r
.55513 .78755 m .55681 .78875 L .55423 .78951 L F
.796 .817 .869 r
.55446 .78945 m .55513 .78755 L .55423 .78951 L F
.167 .698 .687 r
.55423 .78951 m .55528 .78925 L .55413 .78953 L F
.319 0 .006 r
.55395 .7909 m .55528 .78925 L .55752 .78889 L F
0 0 0 r
.55752 .78889 m .55528 .78925 L .55423 .78951 L F
.796 .634 .681 r
.59021 .73387 m .58855 .7309 L .5908 .73033 L F
.59021 .73387 m .59 .73408 L .58855 .7309 L F
.23 .487 .893 r
.65649 .50404 m .65428 .50425 L .65422 .50267 L F
.65649 .50404 m .65714 .50553 L .65428 .50425 L F
.635 .278 .348 r
.72411 .60874 m .72325 .60947 L .72093 .60892 L F
.24 .34 .765 r
.72411 .60874 m .72428 .61034 L .72325 .60947 L F
0 0 .249 r
.72654 .61113 m .72594 .61158 L .72802 .6077 L F
.24 .34 .765 r
.72411 .60874 m .72594 .61158 L .72654 .61113 L F
.72411 .60874 m .72654 .61113 L .72428 .61034 L F
.179 0 0 r
.64378 .54937 m .64726 .54772 L .64571 .54885 L F
.17 0 0 r
.64726 .54772 m .64778 .54825 L .64571 .54885 L F
.64726 .54772 m .64957 .54731 L .64778 .54825 L F
.668 .292 .324 r
.30004 .82515 m .30062 .82517 L .30026 .82485 L F
.863 .588 .52 r
.60105 .69127 m .60269 .68946 L .59835 .68806 L F
.60105 .69127 m .60289 .69184 L .60269 .68946 L F
.561 .702 .935 r
.76049 .58336 m .75902 .58533 L .7581 .58381 L F
.76049 .58336 m .76179 .58577 L .75902 .58533 L F
.496 .105 .229 r
.56421 .68433 m .56078 .68606 L .56047 .68362 L F
.56421 .68433 m .56345 .686 L .56078 .68606 L F
.341 0 .217 r
.56623 .68337 m .56345 .686 L .56421 .68433 L F
.882 .892 .834 r
.48461 .76984 m .4811 .77195 L .48095 .77105 L F
.235 .411 .833 r
.66376 .50693 m .66627 .5072 L .66269 .50573 L F
.66376 .50693 m .66689 .50884 L .66627 .5072 L F
0 .227 .659 r
.6673 .50921 m .66689 .50884 L .66376 .50693 L F
.824 .794 .823 r
.60916 .5414 m .60815 .54499 L .60793 .5444 L F
.60916 .5414 m .61065 .54231 L .60815 .54499 L F
.679 .363 0 r
.60815 .54499 m .60908 .54765 L .60793 .5444 L F
.60815 .54499 m .60908 .54765 L .60793 .5444 L F
0 0 .401 r
.73058 .61793 m .73034 .61727 L .72801 .61662 L F
.793 .733 .797 r
.73339 .61439 m .73058 .61793 L .73031 .61414 L F
.742 .54 .62 r
.71217 .51226 m .70829 .51414 L .70833 .51211 L F
.71217 .51226 m .71184 .51467 L .70829 .51414 L F
.733 .531 .619 r
.71483 .51454 m .71184 .51467 L .71217 .51226 L F
.907 .498 .132 r
.6666 .52431 m .66706 .52334 L .66613 .52228 L F
.6666 .52431 m .6679 .52526 L .66706 .52334 L F
.758 .419 .411 r
.49154 .76362 m .49353 .76623 L .49484 .76351 L F
.575 .469 .696 r
.49484 .76351 m .49776 .76284 L .49684 .76163 L F
.593 .298 .436 r
.49353 .76623 m .49776 .76284 L .49484 .76351 L F
.759 .333 .239 r
.47305 .79182 m .47473 .79286 L .47104 .79169 L F
0 0 0 r
.2872 .6393 m .2906 .63863 L .28857 .63927 L F
.655 .396 .517 r
.5219 .75602 m .52184 .75817 L .5197 .75813 L F
.65 .439 .584 r
.52426 .75561 m .52184 .75817 L .5219 .75602 L F
.065 .012 .48 r
.75531 .60626 m .75688 .60751 L .75639 .60637 L F
.75531 .60626 m .75545 .6089 L .75688 .60751 L F
0 .272 .774 r
.57754 .73103 m .57855 .73051 L .57573 .72878 L F
0 0 .392 r
.57848 .73229 m .57754 .73103 L .57762 .73319 L F
.57848 .73229 m .57855 .73051 L .57754 .73103 L F
.134 .131 .589 r
.54689 .76449 m .54763 .76111 L .54682 .76193 L F
.429 .323 .632 r
.59105 .55324 m .59263 .55566 L .59228 .55326 L F
.456 .216 .46 r
.47213 .7835 m .46993 .78382 L .47083 .78201 L F
.47083 .78201 m .46993 .78382 L .47213 .7835 L F
.595 .448 .651 r
.52124 .75854 m .51686 .75848 L .5197 .75813 L F
.562 .585 .834 r
.45552 .65596 m .45464 .65924 L .4535 .65584 L F
.45552 .65596 m .45687 .65893 L .45464 .65924 L F
.606 .56 .777 r
.458 .66206 m .45464 .65924 L .45687 .65893 L F
.672 .642 .812 r
.76974 .60881 m .76622 .60614 L .76871 .60567 L F
.65 .475 .634 r
.76974 .60881 m .77072 .61181 L .76753 .61176 L F
.7 .691 .838 r
.772 .60631 m .76974 .60881 L .76871 .60567 L F
.668 .637 .81 r
.772 .60631 m .77302 .60855 L .76974 .60881 L F
.569 .429 .651 r
.77329 .61046 m .76974 .60881 L .77302 .60855 L F
.77329 .61046 m .77072 .61181 L .76974 .60881 L F
.578 .752 .96 r
.67606 .48908 m .67471 .4908 L .67417 .48883 L F
.67606 .48908 m .67717 .49036 L .67471 .4908 L F
.691 .596 .744 r
.53463 .74986 m .53481 .75461 L .53297 .75222 L F
.744 .606 .704 r
.53481 .75461 m .53332 .75598 L .53297 .75222 L F
.561 .321 .51 r
.53623 .75503 m .53332 .75598 L .53481 .75461 L F
.398 .401 .746 r
.5369 .75221 m .53767 .7551 L .53481 .75461 L F
.213 .559 .935 r
.53481 .75461 m .53767 .7551 L .53623 .75503 L F
.222 .223 .648 r
.70946 .58834 m .70798 .59055 L .70766 .58653 L F
.399 .457 .805 r
.70946 .58834 m .71057 .59157 L .70798 .59055 L F
.529 .787 .992 r
.43978 .65104 m .43883 .65243 L .43749 .65151 L F
.43978 .65104 m .44091 .6521 L .43883 .65243 L F
.955 .894 .729 r
.65446 .51708 m .65488 .51964 L .65757 .51698 L F
.49 .219 .43 r
.76753 .61176 m .76504 .61423 L .76515 .61182 L F
.622 .643 .85 r
.45637 .78738 m .45998 .78885 L .45862 .78609 L F
.972 .658 .32 r
.45862 .78609 m .45998 .78885 L .45892 .78808 L F
.212 0 0 r
.45998 .78885 m .46042 .789 L .45892 .78808 L F
.45998 .78885 m .46176 .78938 L .46042 .789 L F
.126 0 .196 r
.5057 .73613 m .50331 .73896 L .50334 .7366 L F
.213 0 .345 r
.33855 .7 m .33653 .70312 L .33785 .70211 L F
.654 .966 .913 r
.33522 .70375 m .33584 .70361 L .33785 .70211 L F
.33584 .70361 m .33717 .70332 L .33785 .70211 L F
.213 0 .345 r
.33785 .70211 m .33653 .70312 L .33656 .70307 L F
.33785 .70211 m .33656 .70307 L .33855 .7 L F
.628 .958 .909 r
.33522 .70375 m .33717 .70332 L .33653 .70312 L F
.898 .652 .559 r
.33522 .70375 m .33708 .70569 L .33717 .70332 L F
.659 .969 .903 r
.33653 .70312 m .33717 .70332 L .33785 .70211 L F
.898 .652 .559 r
.33522 .70375 m .33708 .70569 L .33717 .70332 L F
.659 .969 .903 r
.33785 .70211 m .33717 .70332 L .33653 .70312 L F
.951 .817 .375 r
.66822 .5312 m .6687 .52865 L .66805 .52972 L F
0 0 .188 r
.66854 .52785 m .6687 .52865 L .6679 .52526 L F
.898 .846 .389 r
.66805 .52972 m .6687 .52865 L .66854 .52785 L F
.661 .789 .942 r
.26243 .64152 m .26034 .64231 L .26027 .6422 L F
.84 .499 .409 r
.69597 .5159 m .69601 .51487 L .6961 .51522 L F
.525 .895 .968 r
.63577 .5233 m .63193 .52387 L .6347 .52457 L F
.184 0 0 r
.63818 .52264 m .63577 .5233 L .6347 .52457 L F
.563 .611 .859 r
.45076 .78705 m .45307 .78685 L .45157 .78367 L F
.519 .014 0 r
.39093 .64847 m .39288 .64939 L .39425 .64828 L F
.07 0 0 r
.39288 .64939 m .39639 .64875 L .39425 .64828 L F
.429 .413 .739 r
.37982 .692 m .37752 .69071 L .37926 .68899 L F
.37982 .692 m .37805 .69197 L .37752 .69071 L F
.84 .499 .409 r
.69597 .5159 m .69377 .51615 L .69601 .51487 L F
.459 .296 .572 r
.68933 .53116 m .68947 .53346 L .68735 .5341 L F
.402 .162 .431 r
.68947 .53346 m .68706 .53624 L .68735 .5341 L F
.457 .179 .402 r
.30285 .63291 m .30129 .63153 L .30059 .63308 L F
.30285 .63291 m .30339 .63098 L .30129 .63153 L F
.711 .461 .546 r
.50237 .74705 m .50486 .7473 L .50488 .74497 L F
.606 .376 .542 r
.50488 .74497 m .50714 .74701 L .50805 .74469 L F
.50488 .74497 m .50486 .7473 L .50714 .74701 L F
.87 .442 .024 r
.66045 .50257 m .663 .50537 L .66269 .50573 L F
.392 .227 .535 r
.31033 .62237 m .31216 .6194 L .31068 .62004 L F
.746 .309 .212 r
.52819 .80429 m .53014 .80354 L .52661 .8028 L F
.456 .876 .761 r
.53157 .80271 m .53014 .80354 L .52819 .80429 L F
.512 .761 .986 r
.54044 .77232 m .54041 .773 L .53705 .77251 L F
.61 .843 .988 r
.54195 .77184 m .54041 .773 L .54044 .77232 L F
.456 .84 .616 r
.54191 .7719 m .54041 .773 L .54195 .77184 L F
.613 .064 0 r
.58395 .72509 m .58199 .72463 L .58176 .72555 L F
.58395 .72509 m .58199 .72463 L .58176 .72555 L F
.119 0 0 r
.40759 .69512 m .40819 .69614 L .40972 .69467 L F
.40759 .69512 m .40629 .69692 L .40819 .69614 L F
.415 .812 .984 r
.29436 .6528 m .29296 .65229 L .29092 .65261 L F
.475 .836 .994 r
.29638 .65226 m .29296 .65229 L .29436 .6528 L F
.707 .42 .488 r
.50714 .74701 m .51043 .74713 L .50805 .74469 L F
.637 .428 .583 r
.50805 .74469 m .51043 .74713 L .51043 .74465 L F
.311 .744 .97 r
.42253 .65007 m .42606 .65061 L .42395 .65106 L F
.55 .502 .755 r
.46023 .66162 m .45851 .66371 L .458 .66206 L F
.46023 .66162 m .46075 .6635 L .45851 .66371 L F
.663 .601 .775 r
.71656 .50971 m .71344 .51102 L .71309 .50866 L F
.555 .683 .924 r
.42978 .66453 m .43068 .66265 L .42848 .6635 L F
.42978 .66453 m .43194 .66415 L .43068 .66265 L F
.347 .534 .896 r
.34705 .6036 m .34372 .60091 L .34572 .60026 L F
.381 .469 .825 r
.34862 .60354 m .34705 .6036 L .34572 .60026 L F
.388 .324 .664 r
.34862 .60354 m .34908 .60539 L .34705 .6036 L F
.311 .317 .705 r
.34908 .60539 m .34785 .60605 L .34705 .6036 L F
0 .003 .551 r
.58185 .73932 m .58116 .73822 L .58003 .73689 L F
.822 .696 .158 r
.58185 .73932 m .58161 .74036 L .58116 .73822 L F
.58185 .73932 m .58167 .7418 L .58161 .74036 L F
.372 .838 .802 r
.56776 .76556 m .56714 .76612 L .56983 .76481 L F
.56776 .76556 m .56628 .7662 L .56714 .76612 L F
.867 .773 .755 r
.61004 .5392 m .61065 .54231 L .60916 .5414 L F
.699 .832 .947 r
.74041 .62163 m .74345 .62172 L .74317 .62016 L F
.749 .873 .937 r
.74317 .62016 m .74345 .62172 L .74618 .61999 L F
.7 .844 .951 r
.45512 .78613 m .45637 .78738 L .45862 .78609 L F
.927 .705 .581 r
.60273 .70808 m .60432 .7089 L .60292 .70573 L F
.91 .804 .731 r
.60157 .71065 m .60432 .7089 L .60273 .70808 L F
.60157 .71065 m .60332 .71154 L .60432 .7089 L F
.142 .607 .925 r
.72093 .60892 m .7218 .60855 L .7199 .60815 L F
.72093 .60892 m .72325 .60947 L .7218 .60855 L F
.399 .185 .468 r
.5511 .73807 m .5492 .73666 L .5525 .73633 L F
.551 .832 .998 r
.67654 .51176 m .67307 .51139 L .67539 .51066 L F
.454 .781 .998 r
.67539 .51066 m .67875 .51139 L .67654 .51176 L F
.591 .637 .865 r
.34974 .70955 m .35338 .71159 L .35214 .7085 L F
.787 .74 .81 r
.35214 .7085 m .35338 .71159 L .35534 .70865 L F
.568 .439 .665 r
.35338 .71159 m .35577 .71128 L .35534 .70865 L F
.716 .563 .681 r
.35338 .71159 m .35679 .71427 L .35577 .71128 L F
.35338 .71159 m .35424 .71445 L .35679 .71427 L F
.402 .367 .705 r
.44922 .76709 m .45151 .76913 L .451 .76594 L F
.457 .372 .672 r
.44973 .76961 m .45151 .76913 L .44922 .76709 L F
.635 .426 .582 r
.51043 .74465 m .51306 .74688 L .51382 .74475 L F
.667 .348 .423 r
.51306 .74688 m .51599 .74691 L .51382 .74475 L F
.816 .666 .696 r
.59531 .6924 m .59446 .69458 L .59323 .69154 L F
.227 .735 .685 r
.26629 .65645 m .2663 .65642 L .26465 .65631 L F
.26629 .65645 m .26831 .6558 L .2663 .65642 L F
.471 .24 .481 r
.55115 .79026 m .55012 .78954 L .54994 .79123 L F
.591 .271 .395 r
.45358 .68079 m .45035 .68313 L .45051 .6814 L F
.486 .2 .405 r
.44037 .68678 m .44021 .68898 L .43762 .689 L F
.507 .217 .408 r
.44223 .6883 m .44037 .68678 L .44265 .68665 L F
.44223 .6883 m .44021 .68898 L .44037 .68678 L F
.252 0 0 r
.58821 .70546 m .59112 .70576 L .59153 .70543 L F
.706 .876 .479 r
.59153 .70543 m .59112 .70576 L .59185 .70454 L F
.708 .559 .683 r
.5948 .70861 m .59321 .7091 L .59153 .70543 L F
.212 0 0 r
.3717 .65309 m .36958 .65361 L .36806 .6552 L F
1 .816 .492 r
.61965 .73937 m .61906 .73624 L .61872 .73843 L F
.157 .255 .716 r
.61872 .73843 m .6193 .74158 L .61965 .73937 L F
.443 .698 .974 r
.73465 .62061 m .73813 .62195 L .73697 .62004 L F
.572 .701 .929 r
.73813 .62195 m .73945 .61963 L .73697 .62004 L F
.73813 .62195 m .74041 .62163 L .73945 .61963 L F
.526 .323 .548 r
.70833 .51211 m .70829 .51414 L .70606 .51467 L F
.654 .683 .865 r
.26089 .63894 m .26027 .6422 L .25886 .63941 L F
.26089 .63894 m .26243 .64152 L .26027 .6422 L F
.646 .274 .325 r
.49149 .78064 m .49495 .78068 L .49268 .77963 L F
.807 .838 .874 r
.56877 .67921 m .565 .67996 L .56595 .68018 L F
.5 .907 .831 r
.56877 .67921 m .56981 .67828 L .57101 .67848 L F
.56877 .67921 m .56595 .68018 L .56981 .67828 L F
.661 .878 .979 r
.7263 .59688 m .72418 .59776 L .72317 .59689 L F
.553 .123 .179 r
.58734 .68064 m .58578 .68141 L .58331 .68112 L F
.896 .478 .111 r
.58854 .68139 m .58578 .68141 L .58734 .68064 L F
.369 .109 .383 r
.4525 .75589 m .4544 .75539 L .4549 .75322 L F
.417 .151 .4 r
.4549 .75322 m .45662 .75449 L .45723 .75318 L F
.4549 .75322 m .4544 .75539 L .45662 .75449 L F
.914 .699 .599 r
.5911 .68623 m .58912 .6832 L .59109 .68394 L F
.303 0 0 r
.63607 .55052 m .63263 .55249 L .6327 .55118 L F
.63607 .55052 m .63497 .55202 L .63263 .55249 L F
.457 0 0 r
.63607 .55052 m .63733 .55175 L .63497 .55202 L F
.63607 .55052 m .63848 .55083 L .63733 .55175 L F
.941 .76 .29 r
.6673 .50921 m .66717 .51147 L .66689 .50884 L F
0 0 .035 r
.66837 .50801 m .66743 .50891 L .66831 .50676 L F
.66837 .50801 m .66831 .50676 L .66798 .50546 L F
.959 .655 .233 r
.6675 .50665 m .66837 .50801 L .66798 .50546 L F
.557 0 0 r
.6675 .50665 m .66892 .50749 L .66837 .50801 L F
.66892 .50749 m .67043 .5084 L .66837 .50801 L F
0 0 .035 r
.66837 .50801 m .6673 .50921 L .66743 .50891 L F
.581 .939 .919 r
.6673 .50921 m .66689 .50884 L .66837 .50801 L F
.915 .745 .254 r
.6673 .50921 m .66837 .50801 L .66965 .50911 L F
.6673 .50921 m .66686 .51026 L .66837 .50801 L F
.6673 .50921 m .66717 .51147 L .66686 .51026 L F
.608 .19 .224 r
.69103 .5252 m .6906 .52719 L .68807 .52547 L F
.616 .197 .226 r
.69294 .5272 m .69103 .5252 L .69343 .52507 L F
.69294 .5272 m .6906 .52719 L .69103 .5252 L F
.687 .347 .394 r
.52981 .741 m .5318 .74134 L .52949 .7391 L F
.89 .987 .73 r
.47356 .7735 m .47199 .77556 L .47193 .7742 L F
.521 .043 .061 r
.47356 .7735 m .47593 .77476 L .47629 .77369 L F
0 .297 .755 r
.47414 .77346 m .47593 .77476 L .47356 .7735 L F
.47438 .77344 m .47485 .77384 L .47414 .77346 L F
.47485 .77384 m .47593 .77476 L .47414 .77346 L F
.966 .903 .707 r
.47593 .77476 m .47496 .77646 L .47701 .77573 L F
.354 .652 .968 r
.47606 .77354 m .47593 .77476 L .47438 .77344 L F
.309 .297 .683 r
.47606 .77354 m .47496 .77646 L .47593 .77476 L F
.47577 .77433 m .47684 .77581 L .47496 .77646 L F
.47606 .77354 m .47646 .7747 L .47577 .77433 L F
.546 .502 .757 r
.47903 .77514 m .47701 .77573 L .47629 .77369 L F
.966 .903 .707 r
.47593 .77476 m .47701 .77573 L .47903 .77514 L F
.309 .297 .683 r
.47646 .7747 m .47684 .77581 L .47577 .77433 L F
0 .297 .755 r
.47438 .77344 m .47356 .7735 L .47193 .7742 L F
0 0 0 r
.57027 .76961 m .56954 .77133 L .57014 .76896 L F
.57027 .76961 m .56854 .77251 L .56954 .77133 L F
0 0 .006 r
.54158 .70287 m .54377 .69986 L .54157 .70048 L F
.418 .44 .776 r
.38574 .69373 m .38512 .69727 L .38347 .69435 L F
.38574 .69373 m .38677 .69729 L .38512 .69727 L F
.506 .876 .979 r
.54689 .76449 m .54931 .76395 L .54825 .76347 L F
.134 .131 .589 r
.54689 .76449 m .54825 .76347 L .54763 .76111 L F
.812 .396 .256 r
.51804 .71351 m .52002 .71607 L .5212 .71468 L F
.792 .367 .24 r
.5212 .71468 m .52002 .71607 L .52152 .71602 L F
.988 .871 .627 r
.67343 .52281 m .67251 .52609 L .67172 .52435 L F
.651 .197 0 r
.67162 .52038 m .67343 .52281 L .673 .52239 L F
.899 .974 .674 r
.673 .52239 m .67343 .52281 L .67172 .52435 L F
.302 .198 .566 r
.5986 .68548 m .59835 .68806 L .60079 .68642 L F
.829 .466 0 r
.66862 .51472 m .66794 .51374 L .66717 .51147 L F
.929 .56 .291 r
.66862 .51472 m .66773 .51579 L .66794 .51374 L F
.66862 .51472 m .66915 .51667 L .66773 .51579 L F
.51 .607 .885 r
.38207 .69173 m .38148 .69451 L .37982 .692 L F
.38207 .69173 m .38347 .69435 L .38148 .69451 L F
0 0 0 r
.65042 .51029 m .64994 .51118 L .65109 .50955 L F
.64994 .51118 m .64921 .51297 L .65109 .50955 L F
0 0 .222 r
.64921 .51297 m .65063 .5095 L .65109 .50955 L F
.65063 .5095 m .65068 .50939 L .65109 .50955 L F
0 0 0 r
.65182 .50964 m .65109 .50955 L .6528 .50918 L F
.65042 .51029 m .65109 .50955 L .65182 .50964 L F
.845 .682 .68 r
.53606 .76994 m .53705 .77251 L .53382 .77198 L F
.606 .555 .771 r
.53886 .76999 m .53705 .77251 L .53606 .76994 L F
.53886 .76999 m .54044 .77232 L .53705 .77251 L F
.881 .591 .492 r
.59679 .68274 m .59832 .68101 L .59653 .68061 L F
.89 .607 .501 r
.59679 .68274 m .59856 .68332 L .59832 .68101 L F
.572 .821 .992 r
.34572 .60026 m .34372 .60091 L .34223 .60001 L F
.684 .783 .925 r
.44687 .65178 m .44437 .65269 L .44316 .65139 L F
.788 .541 .562 r
.49548 .74432 m .49897 .74711 L .49886 .74494 L F
.698 .432 .518 r
.49886 .74494 m .49897 .74711 L .50237 .74705 L F
.58 .254 .382 r
.6272 .55373 m .62486 .55518 L .62506 .55418 L F
.558 .626 .875 r
.76625 .58362 m .76493 .58664 L .76387 .58428 L F
.76625 .58362 m .76743 .5871 L .76493 .58664 L F
.896 .478 .111 r
.58854 .68139 m .58793 .68228 L .58578 .68141 L F
.58854 .68141 m .58912 .6832 L .58793 .68228 L F
.486 .769 .994 r
.58793 .68228 m .58912 .6832 L .59015 .68201 L F
.9 .877 .444 r
.59015 .68201 m .58745 .68297 L .58793 .68228 L F
.58745 .68297 m .58667 .68325 L .58793 .68228 L F
.896 .478 .111 r
.58854 .68139 m .58854 .68141 L .58793 .68228 L F
.772 .923 .936 r
.55884 .68675 m .55913 .68465 L .56047 .68362 L F
.55884 .68675 m .5574 .68589 L .55913 .68465 L F
.52 .381 .632 r
.56078 .68606 m .55884 .68675 L .56047 .68362 L F
.547 .378 .604 r
.56078 .68606 m .55847 .68919 L .55884 .68675 L F
.377 .77 .987 r
.31706 .59337 m .3164 .59415 L .31506 .59349 L F
.31706 .59337 m .31848 .59404 L .3164 .59415 L F
.207 0 0 r
.41056 .70707 m .40992 .7061 L .41212 .70576 L F
.41056 .70707 m .40842 .70757 L .40992 .7061 L F
.705 .56 .688 r
.5457 .74391 m .54427 .74751 L .54446 .74517 L F
0 0 .271 r
.54668 .74084 m .54642 .74448 L .5457 .74391 L F
.831 .461 .355 r
.34274 .72785 m .3451 .72803 L .34334 .72917 L F
.505 .872 .649 r
.34483 .72812 m .3451 .72803 L .34614 .72707 L F
.34334 .72917 m .3451 .72803 L .34466 .72818 L F
.22 0 0 r
.34498 .72813 m .3451 .72803 L .34484 .72812 L F
0 0 0 r
.34614 .72707 m .3451 .72803 L .34498 .72813 L F
.659 .809 .955 r
.34614 .72707 m .34498 .72813 L .34488 .72808 L F
.34614 .72707 m .34488 .72808 L .34256 .7267 L F
.505 .872 .649 r
.34466 .72818 m .34483 .72812 L .34614 .72707 L F
.22 0 0 r
.34484 .72812 m .3451 .72803 L .34274 .72785 L F
.575 .564 .804 r
.68023 .49134 m .678 .49317 L .67717 .49036 L F
.567 .549 .794 r
.68023 .49134 m .68122 .4947 L .678 .49317 L F
.585 .478 .699 r
.76772 .5999 m .76846 .60319 L .76507 .60223 L F
.595 .48 .692 r
.76846 .60319 m .76622 .60614 L .76507 .60223 L F
.752 .733 .835 r
.70681 .50415 m .70377 .50371 L .70597 .50329 L F
.71 .707 .845 r
.70931 .50354 m .70681 .50415 L .70597 .50329 L F
.505 .549 .835 r
.7098 .50566 m .70681 .50415 L .70931 .50354 L F
0 .147 .688 r
.75485 .62064 m .75638 .62144 L .75405 .61944 L F
.75485 .62064 m .7568 .62258 L .75638 .62144 L F
.642 .664 .857 r
.69261 .50627 m .68886 .50346 L .69126 .50281 L F
.681 .53 .674 r
.69261 .50627 m .69361 .50927 L .69005 .50916 L F
.611 .603 .819 r
.69502 .50567 m .69261 .50627 L .69126 .50281 L F
.687 .533 .672 r
.69579 .50879 m .69261 .50627 L .69502 .50567 L F
.69579 .50879 m .69361 .50927 L .69261 .50627 L F
.605 .501 .71 r
.34913 .67859 m .34952 .68096 L .35127 .6781 L F
.457 .096 .264 r
.73299 .59736 m .73518 .59682 L .73253 .59804 L F
.715 .928 .962 r
.27136 .64148 m .27204 .63972 L .27374 .64017 L F
.27136 .64148 m .26988 .64103 L .27204 .63972 L F
.024 .481 .877 r
.53341 .77454 m .53467 .77567 L .53413 .77511 L F
.49 .607 .896 r
.71185 .50553 m .70976 .50711 L .7098 .50566 L F
.71185 .50553 m .71309 .50866 L .70976 .50711 L F
.889 .538 .375 r
.64447 .50527 m .64558 .5037 L .64564 .50539 L F
.906 .913 .515 r
.64561 .5015 m .64558 .5037 L .64447 .50527 L F
.889 .538 .375 r
.64447 .50527 m .64558 .5037 L .64564 .50539 L F
.855 .429 .211 r
.54841 .70842 m .54521 .70547 L .5477 .70674 L F
.413 .831 .968 r
.27163 .65487 m .27224 .65409 L .2701 .65482 L F
.27163 .65487 m .27375 .65444 L .27224 .65409 L F
.249 0 0 r
.37799 .71922 m .3771 .71936 L .37488 .71905 L F
.397 .852 .812 r
.37901 .71856 m .37799 .71922 L .38024 .71842 L F
.37901 .71856 m .3771 .71936 L .37799 .71922 L F
.897 .724 .659 r
.62278 .51221 m .62055 .51321 L .62169 .51143 L F
.62278 .51221 m .62206 .51451 L .62055 .51321 L F
.685 .435 .538 r
.5519 .69502 m .54789 .69718 L .54929 .69838 L F
.622 .513 .709 r
.55389 .69597 m .55403 .6993 L .55282 .69936 L F
.55194 .69895 m .55282 .69936 L .55164 .69942 L F
.685 .435 .538 r
.5519 .69502 m .55216 .69911 L .54882 .69667 L F
.622 .513 .709 r
.55389 .69597 m .55282 .69936 L .55215 .69905 L F
.333 .173 .509 r
.55389 .69597 m .55216 .69911 L .55215 .69905 L F
.55389 .69597 m .55215 .69905 L .5519 .69502 L F
.622 .513 .709 r
.55389 .69597 m .55215 .69905 L .55194 .69895 L F
.685 .435 .538 r
.548 .69711 m .55216 .69911 L .54789 .69718 L F
.54882 .69667 m .55194 .69895 L .548 .69711 L F
.622 .513 .709 r
.55192 .69899 m .55191 .699 L .55216 .69911 L F
.685 .435 .538 r
.55194 .69895 m .55216 .69911 L .548 .69711 L F
.622 .513 .709 r
.55389 .69597 m .55194 .69895 L .55216 .69911 L F
.46 .239 .49 r
.55216 .69911 m .55164 .69942 L .54929 .69838 L F
.622 .513 .709 r
.55191 .699 m .55164 .69942 L .55216 .69911 L F
.46 .239 .49 r
.55216 .69911 m .54929 .69838 L .5483 .69753 L F
.55216 .69911 m .5483 .69753 L .54789 .69718 L F
.653 .744 .917 r
.67067 .49986 m .67397 .50063 L .6728 .49793 L F
.669 .722 .889 r
.6728 .49793 m .67397 .50063 L .67636 .49957 L F
0 0 0 r
.49857 .76736 m .49688 .76865 L .49595 .76899 L F
.572 .09 .072 r
.50022 .76862 m .49857 .76736 L .50018 .76646 L F
.50022 .76862 m .49688 .76865 L .49857 .76736 L F
.2 0 0 r
.40581 .66371 m .40198 .66565 L .40371 .66396 L F
.56 .353 .556 r
.25825 .62039 m .25836 .62261 L .25591 .6228 L F
.508 .315 .554 r
.26032 .62072 m .25836 .62261 L .25825 .62039 L F
.422 0 0 r
.7072 .52027 m .70394 .52147 L .70393 .52036 L F
.7072 .52027 m .7063 .52149 L .70394 .52147 L F
0 0 0 r
.70979 .52062 m .7063 .52149 L .7072 .52027 L F
.591 .727 .939 r
.68713 .50368 m .68641 .50415 L .68316 .5034 L F
.529 .758 .98 r
.68481 .50194 m .68713 .50368 L .68316 .5034 L F
.71 .617 .751 r
.68783 .49994 m .68713 .50368 L .68545 .50061 L F
0 0 .329 r
.68795 .5023 m .68713 .50368 L .68716 .50352 L F
.68795 .5023 m .68716 .50352 L .68783 .49994 L F
.71 .836 .942 r
.69126 .50281 m .68795 .5023 L .68783 .49994 L F
.686 .934 .634 r
.68877 .50109 m .68865 .50123 L .68795 .5023 L F
.95 .643 .418 r
.68545 .50061 m .68713 .50368 L .68481 .50194 L F
.586 .774 .969 r
.68481 .50194 m .68641 .50415 L .68795 .5023 L F
.787 .542 .565 r
.6842 .50303 m .68795 .5023 L .68481 .50194 L F
.621 .829 .98 r
.68795 .5023 m .68641 .50415 L .68713 .50368 L F
.594 .787 .972 r
.68886 .50346 m .68641 .50415 L .68795 .5023 L F
.787 .542 .565 r
.6842 .50303 m .68753 .50456 L .68776 .50331 L F
.68631 .50262 m .68776 .50331 L .68795 .5023 L F
.6842 .50303 m .68776 .50331 L .68631 .50262 L F
.597 .105 .057 r
.68795 .5023 m .68714 .50294 L .68481 .50194 L F
0 .352 .73 r
.68493 .50195 m .68714 .50294 L .68547 .50203 L F
.68481 .50194 m .68569 .50232 L .68493 .50195 L F
.68569 .50232 m .68714 .50294 L .68493 .50195 L F
.686 .934 .634 r
.68865 .50123 m .68714 .50294 L .68795 .5023 L F
.848 .884 .865 r
.49 .76074 m .49155 .76145 L .49334 .75906 L F
.957 .679 .468 r
.49154 .76362 m .49155 .76145 L .49 .76074 L F
.915 .636 .499 r
.35049 .7029 m .35227 .70566 L .35225 .70343 L F
.651 .812 .961 r
.35049 .7029 m .35225 .70343 L .35435 .70317 L F
.915 .636 .499 r
.35049 .7029 m .35227 .70566 L .35225 .70343 L F
.673 .499 .642 r
.35225 .70343 m .35411 .70529 L .35435 .70317 L F
.35225 .70343 m .35227 .70566 L .35411 .70529 L F
.586 .357 .535 r
.35135 .6642 m .35377 .66388 L .35403 .66166 L F
.468 .255 .506 r
.35403 .66166 m .35581 .66339 L .35608 .66125 L F
.35403 .66166 m .35377 .66388 L .35581 .66339 L F
.654 .544 .717 r
.35424 .71445 m .3567 .71677 L .35679 .71427 L F
.581 .574 .81 r
.35577 .71128 m .35679 .71427 L .3589 .71377 L F
.729 .555 .656 r
.35679 .71427 m .36015 .7168 L .3589 .71377 L F
.35679 .71427 m .3567 .71677 L .36015 .7168 L F
.739 .588 .688 r
.60431 .55347 m .60771 .55362 L .60601 .55635 L F
.698 .535 .662 r
.60771 .55362 m .6086 .55792 L .60601 .55635 L F
.763 .62 .7 r
.53297 .75222 m .53332 .75598 L .52973 .75581 L F
.777 .509 .53 r
.53332 .75598 m .52983 .75778 L .52973 .75581 L F
.53332 .75598 m .53323 .75819 L .52983 .75778 L F
.794 .678 .735 r
.53623 .75503 m .53323 .75819 L .53332 .75598 L F
.942 .759 .626 r
.59264 .71389 m .59349 .71681 L .59204 .71622 L F
.853 .881 .858 r
.59349 .71681 m .59196 .71627 L .59204 .71622 L F
.76 .675 .768 r
.59596 .71389 m .59349 .71681 L .59264 .71389 L F
.555 .44 .677 r
.34952 .68096 m .35173 .68054 L .35127 .6781 L F
.53 .414 .666 r
.34952 .68096 m .35189 .6831 L .35173 .68054 L F
.34952 .68096 m .34992 .6837 L .35189 .6831 L F
.654 .544 .717 r
.35424 .71445 m .3544 .71701 L .3567 .71677 L F
.635 .589 .785 r
.3544 .71701 m .35795 .71963 L .3567 .71677 L F
.452 .306 .591 r
.3082 .62527 m .3104 .62467 L .31033 .62237 L F
.447 .252 .521 r
.308 .62717 m .3104 .62467 L .3082 .62527 L F
.544 .641 .896 r
.74612 .6107 m .74465 .61294 L .74384 .61155 L F
.74612 .6107 m .74672 .61286 L .74465 .61294 L F
.422 .198 .467 r
.32516 .72832 m .32484 .73047 L .32712 .72806 L F
.32712 .72806 m .32484 .73047 L .32516 .72832 L F
.48 .334 .605 r
.45254 .75835 m .4544 .75539 L .4525 .75589 L F
.439 .216 .477 r
.71458 .51653 m .71468 .51931 L .7117 .51882 L F
.409 0 .146 r
.71468 .51931 m .71173 .52069 L .7117 .51882 L F
.675 .259 .248 r
.50333 .79633 m .50433 .79512 L .50079 .79467 L F
.667 .249 .242 r
.50637 .79682 m .50433 .79512 L .50333 .79633 L F
.394 .144 .413 r
.32393 .63609 m .32402 .63331 L .32675 .63221 L F
.763 .617 .698 r
.53297 .75222 m .52986 .7531 L .53197 .75023 L F
.763 .62 .7 r
.53297 .75222 m .52973 .75581 L .52986 .7531 L F
.691 .596 .744 r
.53463 .74986 m .53297 .75222 L .53197 .75023 L F
.73 .621 .737 r
.3567 .71677 m .35795 .71963 L .36015 .7168 L F
.68 .549 .699 r
.35795 .71963 m .36037 .71966 L .36015 .7168 L F
.236 .054 .419 r
.6398 .5191 m .63868 .52037 L .63818 .52264 L F
.501 .146 .296 r
.48072 .74416 m .48298 .744 L .48405 .74161 L F
.566 .261 .41 r
.48298 .744 m .48619 .74128 L .48405 .74161 L F
.591 .271 .395 r
.45358 .68079 m .45255 .68311 L .45035 .68313 L F
.607 .312 .443 r
.45588 .68062 m .45255 .68311 L .45358 .68079 L F
.599 .59 .813 r
.64678 .52229 m .64364 .52022 L .64596 .51986 L F
.789 .421 .36 r
.49669 .79951 m .49978 .80019 L .4985 .80207 L F
.077 .29 .775 r
.50057 .79951 m .49978 .80019 L .50192 .80183 L F
0 0 0 r
.4985 .80207 m .49978 .80019 L .50057 .79951 L F
.419 0 .13 r
.73786 .59537 m .74014 .59599 L .73759 .59615 L F
.73786 .59537 m .74119 .5945 L .74014 .59599 L F
.839 .787 .802 r
.66363 .48318 m .6643 .48632 L .66293 .48743 L F
.682 .691 .852 r
.66703 .48438 m .6643 .48632 L .66363 .48318 L F
.32 .75 .971 r
.27836 .58661 m .28186 .58712 L .27993 .58745 L F
.329 .777 .958 r
.31848 .59404 m .32063 .59383 L .32216 .59425 L F
.258 .7 .96 r
.32063 .59383 m .32415 .59464 L .32216 .59425 L F
.367 .123 .407 r
.25836 .62261 m .25591 .62523 L .25591 .6228 L F
.775 .375 .296 r
.52203 .7742 m .51854 .772 L .52003 .77229 L F
.689 .268 .242 r
.52003 .77229 m .52239 .77302 L .52203 .7742 L F
.881 .914 .513 r
.62823 .5094 m .62679 .51344 L .62781 .51199 L F
.712 .665 .803 r
.3244 .85638 m .32667 .85562 L .32458 .85801 L F
.385 .827 .945 r
.42091 .66327 m .41916 .66297 L .41705 .66342 L F
.401 .822 .968 r
.42325 .66302 m .41916 .66297 L .42091 .66327 L F
.667 .66 .834 r
.68946 .52216 m .68655 .52037 L .68917 .52113 L F
.785 .957 .925 r
.69248 .51996 m .68946 .52216 L .68917 .52113 L F
.597 .319 .466 r
.70164 .51979 m .69828 .52233 L .69849 .5206 L F
.719 .507 .602 r
.69355 .5116 m .69005 .50916 L .69361 .50927 L F
.69355 .5116 m .69036 .51158 L .69005 .50916 L F
.618 .733 .928 r
.76387 .58428 m .76179 .58577 L .76049 .58336 L F
.651 .812 .961 r
.35049 .7029 m .35435 .70317 L .35348 .70019 L F
.567 .516 .758 r
.35348 .70019 m .35435 .70317 L .35637 .70272 L F
.586 .441 .651 r
.35411 .70529 m .35637 .70272 L .35435 .70317 L F
.084 0 0 r
.59893 .75296 m .59906 .75376 L .5957 .75512 L F
0 0 0 r
.60052 .75177 m .59906 .75376 L .59893 .75296 L F
.652 .265 .298 r
.46556 .78912 m .46399 .79139 L .46176 .78938 L F
.23 0 0 r
.46887 .79042 m .46399 .79139 L .46556 .78912 L F
.57 .761 .968 r
.26591 .64219 m .26243 .64152 L .26505 .64087 L F
.5 .691 .953 r
.26668 .64063 m .26591 .64219 L .26505 .64087 L F
.26668 .64063 m .26796 .64196 L .26591 .64219 L F
.568 .542 .786 r
.45905 .65828 m .458 .66206 L .45687 .65893 L F
.45905 .65828 m .46023 .66162 L .458 .66206 L F
.935 .616 .41 r
.6015 .71232 m .60332 .71154 L .60157 .71065 L F
.6015 .71232 m .60362 .71356 L .60332 .71154 L F
.579 .666 .898 r
.47023 .77551 m .46883 .77785 L .46703 .7765 L F
.47023 .77551 m .4712 .77766 L .46883 .77785 L F
.657 .522 .688 r
.52838 .75012 m .52986 .7531 L .52648 .7528 L F
.718 .581 .7 r
.52986 .7531 m .52764 .75537 L .52648 .7528 L F
.781 .287 .029 r
.55349 .72794 m .55552 .73029 L .55692 .73047 L F
.6 .049 0 r
.55552 .73029 m .55897 .73297 L .55692 .73047 L F
.784 .339 .193 r
.55692 .73047 m .55897 .73297 L .56095 .7331 L F
.232 .028 .385 r
.26383 .61843 m .26258 .61614 L .26423 .6157 L F
.26383 .61843 m .26248 .61917 L .26258 .61614 L F
.804 .697 .747 r
.73128 .6139 m .73339 .61439 L .73031 .61414 L F
.771 .746 .83 r
.73578 .61192 m .73339 .61439 L .73128 .6139 L F
.752 .411 .406 r
.49379 .79384 m .49525 .79158 L .49179 .7912 L F
.787 .456 .428 r
.49379 .79384 m .49731 .79421 L .49525 .79158 L F
.33 0 0 r
.52149 .72823 m .52026 .72977 L .51796 .73008 L F
.582 .127 .138 r
.5241 .72978 m .52026 .72977 L .52149 .72823 L F
.49 .219 .43 r
.76753 .61176 m .76779 .61378 L .76504 .61423 L F
.67 .345 .415 r
.77009 .61366 m .76779 .61378 L .76753 .61176 L F
.634 .372 .504 r
.77072 .61181 m .77009 .61366 L .76753 .61176 L F
.625 .415 .577 r
.5194 .74766 m .52211 .74752 L .52217 .74469 L F
.671 .593 .759 r
.52173 .74221 m .52217 .74469 L .52473 .74383 L F
.583 .381 .572 r
.52217 .74469 m .52458 .74678 L .52473 .74383 L F
.52217 .74469 m .52211 .74752 L .52458 .74678 L F
.497 .192 .379 r
.41724 .69114 m .41942 .69081 L .41771 .68942 L F
.503 .191 .37 r
.41771 .68942 m .41942 .69081 L .42004 .68914 L F
.324 .217 .575 r
.34947 .60805 m .34785 .60605 L .34908 .60539 L F
.34947 .60805 m .34774 .60835 L .34785 .60605 L F
.733 .61 .72 r
.3002 .82576 m .30062 .82517 L .30004 .82515 L F
0 0 0 r
.30236 .65049 m .30019 .65145 L .29843 .65202 L F
.30437 .6498 m .30019 .65145 L .30236 .65049 L F
.657 .782 .94 r
.65057 .52793 m .64887 .52899 L .64717 .52745 L F
.435 .849 .682 r
.65057 .52793 m .64887 .52899 L .64692 .53012 L F
.491 .811 1 r
.29491 .60312 m .29546 .60191 L .2935 .60272 L F
.29491 .60312 m .29697 .60272 L .29546 .60191 L F
.368 .686 .98 r
.75576 .58408 m .75157 .58229 L .75497 .58276 L F
.466 .766 .995 r
.75719 .5829 m .75576 .58408 L .75497 .58276 L F
.75719 .5829 m .7581 .58381 L .75576 .58408 L F
.148 .676 .87 r
.70597 .50329 m .70831 .50324 L .70931 .50354 L F
.997 .812 .535 r
.70931 .50354 m .71051 .49938 L .71108 .5027 L F
.70931 .50354 m .70855 .50029 L .71051 .49938 L F
.70929 .50346 m .70831 .50324 L .70855 .50029 L F
.473 .47 .773 r
.7071 .49908 m .70831 .50324 L .70597 .50329 L F
.911 .72 .631 r
.70855 .50029 m .70831 .50324 L .7071 .49908 L F
.70855 .50029 m .70831 .50324 L .7071 .49908 L F
.677 .965 .932 r
.70948 .50161 m .70711 .50297 L .70831 .50324 L F
.70711 .50297 m .70694 .50307 L .70831 .50324 L F
.997 .812 .535 r
.70931 .50354 m .70831 .50324 L .70929 .50346 L F
.969 .648 .319 r
.70831 .50324 m .70931 .50354 L .71108 .5027 L F
.70831 .50324 m .7098 .50566 L .70931 .50354 L F
.686 .792 .93 r
.49776 .76284 m .50007 .76337 L .49916 .76099 L F
.7 .597 .737 r
.5024 .76318 m .49916 .76099 L .50007 .76337 L F
.449 .232 .491 r
.3282 .63041 m .32675 .63221 L .32641 .63056 L F
.54 0 0 r
.47104 .79169 m .47473 .79286 L .47535 .79347 L F
.551 .313 .507 r
.47044 .74959 m .47308 .74715 L .47109 .74782 L F
.395 .137 .401 r
.32174 .63604 m .3216 .63882 L .31957 .6394 L F
.231 .012 .362 r
.32312 .63775 m .32174 .63604 L .32393 .63609 L F
.32312 .63775 m .3216 .63882 L .32174 .63604 L F
.722 .238 0 r
.62382 .50348 m .62416 .50452 L .62468 .5038 L F
.62382 .50348 m .62527 .50553 L .62416 .50452 L F
.497 .505 .795 r
.68592 .51742 m .687 .51611 L .68491 .51709 L F
.68592 .51742 m .68491 .51709 L .68346 .51777 L F
.271 .414 .823 r
.68684 .51592 m .68781 .51805 L .68592 .51742 L F
.68781 .51805 m .688 .51847 L .68592 .51742 L F
.692 .973 .919 r
.68346 .51777 m .68458 .51605 L .68592 .51742 L F
.68346 .51777 m .68283 .51731 L .68458 .51605 L F
.804 .662 .706 r
.54869 .77255 m .55156 .77319 L .5505 .76945 L F
.457 .884 .805 r
.54767 .77476 m .55156 .77319 L .54869 .77255 L F
.593 .606 .835 r
.55156 .77319 m .55202 .76943 L .5505 .76945 L F
.55156 .77319 m .55354 .77302 L .55202 .76943 L F
.905 .538 .328 r
.59199 .68928 m .591 .69011 L .59117 .68888 L F
.59199 .68928 m .59323 .69154 L .591 .69011 L F
.696 .524 .65 r
.5948 .70861 m .59287 .71138 L .59321 .7091 L F
.514 .748 .98 r
.52994 .77136 m .53119 .77248 L .53382 .77198 L F
.866 .753 .736 r
.54728 .77091 m .5505 .76945 L .54711 .76991 L F
.569 .258 .401 r
.54075 .73958 m .54315 .74114 L .54386 .73831 L F
.581 .552 .787 r
.54386 .73831 m .54546 .73576 L .54366 .73617 L F
.54386 .73831 m .54687 .73979 L .54546 .73576 L F
.689 .374 .437 r
.54386 .73831 m .54668 .74084 L .54687 .73979 L F
.644 .589 .777 r
.54546 .73576 m .54687 .73979 L .54915 .73873 L F
.47 .892 .831 r
.54915 .73873 m .54731 .73958 L .54574 .7401 L F
.54731 .73958 m .54687 .73979 L .54641 .73991 L F
.54731 .73958 m .54641 .73991 L .54574 .7401 L F
.689 .374 .437 r
.54587 .74011 m .54315 .74114 L .54668 .74084 L F
.54386 .73831 m .54316 .74111 L .54587 .74011 L F
.54316 .74111 m .54315 .74114 L .54587 .74011 L F
.636 .418 .57 r
.50817 .73359 m .50799 .73614 L .5057 .73613 L F
.612 .571 .783 r
.50817 .73359 m .51038 .73141 L .51035 .73293 L F
.607 .393 .565 r
.51049 .73583 m .50817 .73359 L .51035 .73293 L F
.51049 .73583 m .50799 .73614 L .50817 .73359 L F
.363 .784 .975 r
.70366 .5861 m .70675 .58576 L .70766 .58653 L F
.134 .621 .916 r
.70675 .58576 m .7073 .58586 L .70766 .58653 L F
.222 .223 .648 r
.70946 .58834 m .70766 .58653 L .7073 .58586 L F
.393 .198 .492 r
.54366 .73617 m .54546 .73576 L .54579 .73353 L F
.61 .351 .5 r
.73191 .59227 m .73417 .5942 L .73432 .59205 L F
.73191 .59227 m .73117 .59479 L .73417 .5942 L F
.598 .564 .788 r
.71458 .51653 m .71184 .51467 L .71483 .51454 L F
.576 .379 .578 r
.71685 .516 m .71483 .51454 L .71728 .51435 L F
.71685 .516 m .71458 .51653 L .71483 .51454 L F
.591 .35 .52 r
.68007 .52849 m .67992 .5308 L .67767 .53076 L F
.667 .39 .492 r
.68416 .52937 m .68243 .53133 L .68007 .52849 L F
0 .091 .647 r
.68007 .52849 m .68243 .53133 L .68144 .52926 L F
.68007 .52849 m .68144 .52926 L .67992 .5308 L F
.825 .349 .049 r
.55233 .72722 m .55552 .73029 L .55349 .72794 L F
.485 0 0 r
.26331 .58515 m .26207 .58532 L .26349 .58518 L F
.26009 .58459 m .26207 .58532 L .26331 .58515 L F
.017 0 0 r
.26009 .58459 m .26019 .58558 L .26207 .58532 L F
.096 0 0 r
.26019 .58558 m .26031 .58556 L .26207 .58532 L F
.245 0 0 r
.26127 .58451 m .26349 .58518 L .26381 .58521 L F
.096 0 0 r
.26031 .58556 m .26422 .58494 L .26207 .58532 L F
.186 .718 .759 r
.26306 .58515 m .26349 .58518 L .26207 .58532 L F
.26422 .58494 m .26349 .58518 L .26306 .58515 L F
.245 0 0 r
.26381 .58521 m .26349 .58518 L .26516 .58559 L F
.464 .819 .997 r
.26349 .58518 m .26733 .5855 L .26516 .58559 L F
0 .068 .629 r
.58637 .70836 m .58753 .71116 L .58673 .70868 L F
0 0 .12 r
.5876 .70772 m .58727 .70928 L .58892 .70651 L F
0 .123 .653 r
.58753 .71116 m .58785 .71095 L .58683 .70887 L F
.58678 .70882 m .58683 .70887 L .58673 .70868 L F
.58753 .71116 m .58683 .70887 L .58678 .70882 L F
.197 .174 .604 r
.58673 .70868 m .58785 .71095 L .58844 .71106 L F
.58673 .70868 m .58844 .71106 L .58483 .70994 L F
.707 .188 0 r
.58669 .71051 m .58608 .7103 L .58483 .70994 L F
.566 .243 .38 r
.58483 .70994 m .5869 .71065 L .58676 .7105 L F
.58483 .70994 m .58699 .71057 L .5876 .70772 L F
.707 .188 0 r
.58608 .7103 m .58592 .71024 L .58483 .70994 L F
.148 .516 .915 r
.58675 .70966 m .58694 .71053 L .58483 .70994 L F
.707 .188 0 r
.58592 .71024 m .58443 .70972 L .58483 .70994 L F
.148 .516 .915 r
.58643 .71039 m .5869 .71065 L .58483 .70994 L F
.707 .188 0 r
.58693 .71056 m .58443 .70972 L .58669 .71051 L F
.58643 .71039 m .58597 .71116 L .58443 .70972 L F
.58676 .7105 m .58671 .71054 L .58643 .71039 L F
.58671 .71054 m .58597 .71116 L .58643 .71039 L F
.58844 .71106 m .58693 .71056 L .58669 .71051 L F
.58844 .71106 m .58733 .7111 L .58676 .7105 L F
.566 .243 .38 r
.58676 .7105 m .58697 .71067 L .58699 .71057 L F
.148 .516 .915 r
.58694 .71053 m .58697 .71067 L .5869 .71065 L F
.707 .188 0 r
.58733 .7111 m .58597 .71116 L .58676 .7105 L F
.566 .243 .38 r
.5869 .71065 m .58697 .71067 L .58676 .7105 L F
.148 .516 .915 r
.58694 .71053 m .5869 .71065 L .58643 .71039 L F
0 0 .12 r
.58727 .70928 m .58699 .71057 L .58751 .70951 L F
.58699 .71057 m .58697 .71067 L .58702 .71057 L F
.58699 .71057 m .58702 .71057 L .58751 .70951 L F
.58727 .70928 m .58751 .70951 L .58892 .70651 L F
.492 .4 .679 r
.4888 .75775 m .48977 .7583 L .48761 .75881 L F
.487 .382 .661 r
.48977 .7583 m .49 .76074 L .48761 .75881 L F
.591 .637 .865 r
.34974 .70955 m .35214 .7085 L .34947 .70939 L F
.562 .561 .81 r
.36015 .7168 m .36105 .71332 L .3589 .71377 L F
.36015 .7168 m .36227 .71641 L .36105 .71332 L F
.604 .519 .732 r
.36037 .71966 m .36227 .71641 L .36015 .7168 L F
.666 .694 .867 r
.63308 .50286 m .63478 .50465 L .63708 .50341 L F
.557 .23 .369 r
.54151 .76724 m .54355 .76884 L .54123 .76916 L F
.632 .68 .877 r
.73899 .61329 m .73578 .61192 L .73811 .61111 L F
.633 .73 .918 r
.74047 .61096 m .73899 .61329 L .73811 .61111 L F
.74047 .61096 m .74051 .61215 L .73899 .61329 L F
0 0 0 r
.64828 .52136 m .64678 .52229 L .64627 .52182 L F
.64828 .52136 m .64878 .52067 L .64678 .52229 L F
.64828 .52136 m .64936 .5202 L .64878 .52067 L F
.627 .154 .109 r
.64596 .51986 m .64936 .5202 L .64828 .52136 L F
.64596 .51986 m .64828 .52136 L .64627 .52182 L F
.615 .412 .584 r
.64367 .52246 m .6466 .52427 L .64627 .52182 L F
.351 .227 .568 r
.64627 .52182 m .64823 .524 L .64828 .52136 L F
.64627 .52182 m .6466 .52427 L .64823 .524 L F
.775 .521 .551 r
.64828 .52136 m .64704 .52205 L .64627 .52182 L F
.511 .488 .767 r
.64402 .51791 m .64655 .52227 L .64765 .52023 L F
.64655 .52227 m .64692 .52291 L .64701 .52256 L F
.64655 .52227 m .64701 .52256 L .64673 .52223 L F
.732 .575 .678 r
.64601 .52251 m .64692 .52291 L .64655 .52227 L F
.771 .437 .42 r
.64495 .52322 m .64692 .52291 L .64601 .52251 L F
.775 .521 .551 r
.64601 .52251 m .64495 .52322 L .64533 .52282 L F
.64704 .52205 m .64533 .52282 L .64627 .52182 L F
0 .196 .613 r
.64495 .52322 m .64367 .52246 L .64627 .52182 L F
.771 .437 .42 r
.64495 .52322 m .64601 .52251 L .64158 .52061 L F
.775 .521 .551 r
.64655 .52227 m .64495 .52322 L .64601 .52251 L F
.64673 .52223 m .64701 .52256 L .64495 .52322 L F
.64828 .52136 m .64823 .52397 L .64673 .52223 L F
.511 .488 .767 r
.64673 .52223 m .64701 .52256 L .64713 .52213 L F
.775 .521 .551 r
.64704 .52205 m .64673 .52223 L .64655 .52227 L F
.511 .488 .767 r
.64655 .52227 m .64713 .52213 L .64765 .52023 L F
.775 .521 .551 r
.64673 .52223 m .64495 .52322 L .64655 .52227 L F
.732 .575 .678 r
.64158 .52061 m .64601 .52251 L .64402 .51791 L F
.64601 .52251 m .64655 .52227 L .64402 .51791 L F
.842 .832 .838 r
.64765 .52023 m .64701 .52256 L .64495 .52322 L F
.64701 .52256 m .64692 .52291 L .64495 .52322 L F
.775 .521 .551 r
.64701 .52256 m .64823 .524 L .64495 .52322 L F
.64823 .52397 m .64823 .524 L .64673 .52223 L F
.724 .262 .152 r
.64775 .52211 m .64828 .52136 L .64765 .52023 L F
.64779 .52301 m .64828 .52136 L .64775 .52211 L F
.536 .401 .645 r
.34994 .67033 m .35201 .66991 L .35189 .66658 L F
.534 .446 .702 r
.34994 .67033 m .35241 .67212 L .35201 .66991 L F
.34994 .67033 m .35038 .67256 L .35241 .67212 L F
.837 .754 .772 r
.52159 .7494 m .52553 .75066 L .52458 .74678 L F
.7 .405 .474 r
.52159 .7494 m .52441 .75135 L .52553 .75066 L F
.451 .427 .741 r
.52553 .75066 m .52716 .74595 L .52458 .74678 L F
0 0 0 r
.52553 .75066 m .52441 .75135 L .52683 .75081 L F
.38894 .71509 m .38877 .71485 L .39064 .71394 L F
.38894 .71509 m .38691 .71583 L .38877 .71485 L F
.127 0 .071 r
.29598 .63564 m .29716 .63585 L .29851 .63353 L F
.138 0 0 r
.29598 .63564 m .29454 .6374 L .29716 .63585 L F
.635 .668 .864 r
.43194 .66415 m .43593 .66641 L .43425 .66329 L F
.546 .557 .817 r
.43593 .66641 m .43738 .6647 L .43425 .66329 L F
.43593 .66641 m .43799 .6661 L .43738 .6647 L F
.802 .313 .016 r
.56272 .73522 m .56608 .73818 L .56413 .73567 L F
.785 .285 0 r
.56413 .73567 m .56608 .73818 L .56777 .73867 L F
.722 .196 0 r
.56819 .74008 m .56777 .73867 L .56608 .73818 L F
.56819 .74008 m .56969 .74088 L .56777 .73867 L F
.661 .284 .321 r
.52766 .72795 m .52585 .72993 L .5241 .72978 L F
.69 .321 .345 r
.52956 .73011 m .52585 .72993 L .52766 .72795 L F
.662 .149 .011 r
.54196 .74761 m .54266 .74877 L .5426 .7486 L F
.995 .87 .577 r
.54427 .74751 m .54266 .74877 L .54196 .74761 L F
.54427 .74751 m .54372 .75038 L .54266 .74877 L F
.552 .14 .215 r
.58145 .72576 m .58319 .72522 L .58243 .72512 L F
.613 .064 0 r
.58292 .72485 m .58243 .72512 L .58199 .72463 L F
.58395 .72509 m .58243 .72512 L .58292 .72485 L F
.58395 .72509 m .58243 .72512 L .58199 .72463 L F
.831 .968 .648 r
.58326 .72295 m .58155 .72561 L .58243 .72512 L F
.58155 .72561 m .58145 .72576 L .58243 .72512 L F
.922 .878 .774 r
.58401 .7217 m .58243 .72512 L .58395 .72509 L F
.318 .798 .904 r
.58243 .72512 m .5851 .72462 L .58629 .7248 L F
.552 .14 .215 r
.58319 .72522 m .5851 .72462 L .58351 .72492 L F
.318 .798 .904 r
.58243 .72512 m .58629 .7248 L .58395 .72509 L F
.552 .14 .215 r
.58319 .72522 m .58351 .72492 L .58243 .72512 L F
.922 .878 .774 r
.58401 .7217 m .58396 .72449 L .58441 .72285 L F
.58396 .72449 m .58395 .72509 L .5841 .72436 L F
.58396 .72449 m .5841 .72436 L .58441 .72285 L F
.569 .299 .466 r
.5077 .71919 m .50998 .71921 L .51061 .71675 L F
.361 .168 .479 r
.51061 .71675 m .51228 .71642 L .51238 .71418 L F
.328 .078 .374 r
.51061 .71675 m .50998 .71921 L .51228 .71642 L F
.712 .545 .661 r
.53197 .75023 m .52986 .7531 L .52838 .75012 L F
0 .476 .77 r
.40582 .64885 m .40782 .64934 L .4092 .64983 L F
.283 0 0 r
.50477 .76781 m .50843 .76802 L .50975 .76733 L F
.577 .072 .018 r
.50843 .76802 m .51147 .76815 L .50975 .76733 L F
.426 0 .084 r
.50975 .76733 m .51147 .76815 L .51225 .7672 L F
.748 .921 .558 r
.63661 .49405 m .63575 .49589 L .63782 .49412 L F
.473 .44 .741 r
.35111 .68962 m .35185 .69206 L .35354 .69146 L F
.382 .207 .515 r
.35185 .69206 m .3517 .69441 L .35354 .69146 L F
.568 .263 .411 r
.53222 .76424 m .53435 .76584 L .53472 .76416 L F
.782 .595 .646 r
.59287 .71138 m .59596 .71389 L .59264 .71389 L F
.116 0 .289 r
.58637 .70836 m .58821 .70546 L .58594 .70592 L F
.491 .153 .322 r
.46075 .67852 m .45809 .68028 L .45857 .67843 L F
.455 .414 .722 r
.75529 .59465 m .75558 .59812 L .75772 .59638 L F
.388 .373 .721 r
.75558 .59812 m .75807 .59984 L .75772 .59638 L F
.75558 .59812 m .75652 .60009 L .75807 .59984 L F
.298 .731 .969 r
.42606 .65061 m .42849 .6506 L .42965 .65125 L F
.619 .889 .989 r
.42965 .65125 m .43039 .64978 L .43155 .6507 L F
.42965 .65125 m .42849 .6506 L .43039 .64978 L F
.474 .147 .332 r
.31431 .61706 m .31658 .61675 L .31745 .61437 L F
.476 .339 .615 r
.31745 .61437 m .31926 .61391 L .31912 .61159 L F
.534 .206 .357 r
.31745 .61437 m .31854 .61608 L .31926 .61391 L F
.31745 .61437 m .31658 .61675 L .31854 .61608 L F
.447 .377 .685 r
.44825 .77791 m .44949 .77439 L .44766 .77536 L F
.212 0 0 r
.25244 .58641 m .25447 .586 L .25634 .58469 L F
.309 0 0 r
.25634 .58469 m .25774 .58501 L .2582 .58421 L F
.25634 .58469 m .25447 .586 L .25774 .58501 L F
0 .473 .751 r
.29464 .59059 m .29664 .59104 L .29823 .59152 L F
0 .547 .81 r
.29664 .59104 m .30019 .59183 L .29823 .59152 L F
.008 0 0 r
.31688 .64167 m .3144 .64409 L .31535 .64265 L F
.434 .031 .173 r
.43286 .69274 m .43215 .69378 L .43011 .69391 L F
.292 0 .088 r
.43429 .69312 m .43286 .69274 L .43496 .69224 L F
.43429 .69312 m .43215 .69378 L .43286 .69274 L F
.084 0 0 r
.24661 .58834 m .25044 .587 L .2481 .58756 L F
.734 .498 .571 r
.76075 .61996 m .76097 .62228 L .7568 .62258 L F
.611 .407 .581 r
.76324 .61963 m .76097 .62228 L .76075 .61996 L F
.289 .09 .427 r
.54099 .73275 m .5398 .73074 L .54182 .73093 L F
.54099 .73275 m .53938 .73378 L .5398 .73074 L F
.156 .501 .909 r
.34223 .60001 m .34079 .5997 L .33867 .5977 L F
0 .176 .703 r
.50374 .76945 m .50508 .77269 L .50547 .77148 L F
.938 .621 .409 r
.50726 .77242 m .50547 .77148 L .50508 .77269 L F
.541 .456 .708 r
.35111 .68962 m .35267 .68603 L .35058 .68647 L F
.35111 .68962 m .35315 .6892 L .35267 .68603 L F
.473 .44 .741 r
.35111 .68962 m .35354 .69146 L .35315 .6892 L F
.399 .185 .468 r
.5511 .73807 m .54915 .73873 L .5492 .73666 L F
.253 0 .147 r
.68506 .53013 m .68416 .52937 L .6857 .5284 L F
0 0 0 r
.68716 .52688 m .6857 .5284 L .68807 .52547 L F
.229 0 .024 r
.68793 .52839 m .6857 .5284 L .68716 .52688 L F
.562 .507 .751 r
.35058 .68647 m .35189 .6831 L .34992 .6837 L F
.35058 .68647 m .35267 .68603 L .35189 .6831 L F
.233 0 .115 r
.42013 .70055 m .41897 .70268 L .4172 .70266 L F
.433 .094 .288 r
.42214 .69986 m .41897 .70268 L .42013 .70055 L F
.998 .829 .542 r
.67869 .51609 m .67968 .5178 L .68006 .5145 L F
.002 .211 .724 r
.68019 .5127 m .68006 .5145 L .67875 .51139 L F
.905 .941 .578 r
.68019 .5127 m .67869 .51609 L .68006 .5145 L F
.319 .804 .882 r
.58331 .68112 m .58134 .6812 L .57996 .68147 L F
.29 .748 .952 r
.32415 .59464 m .32623 .59452 L .32771 .59502 L F
.273 .764 .909 r
.32623 .59452 m .3298 .59452 L .32771 .59502 L F
.635 .654 .851 r
.77416 .60592 m .77302 .60855 L .772 .60631 L F
.77416 .60592 m .77536 .6087 L .77302 .60855 L F
.28 .12 .477 r
.77465 .61013 m .77302 .60855 L .77536 .6087 L F
.77465 .61013 m .77329 .61046 L .77302 .60855 L F
.487 .216 .429 r
.43762 .689 m .43711 .69189 L .43496 .69224 L F
.527 .252 .441 r
.43942 .68993 m .43762 .689 L .44021 .68898 L F
.43942 .68993 m .43711 .69189 L .43762 .689 L F
.915 .697 .594 r
.59446 .69458 m .59228 .69389 L .59323 .69154 L F
.936 .67 .196 r
.59446 .69458 m .59411 .69618 L .59228 .69389 L F
.59446 .69458 m .59469 .69708 L .59411 .69618 L F
.604 .519 .732 r
.36037 .71966 m .36201 .71991 L .36227 .71641 L F
.503 .376 .64 r
.36113 .72279 m .36201 .71991 L .36037 .71966 L F
.889 .604 .499 r
.59403 .67979 m .59617 .67821 L .59345 .67791 L F
.59403 .67979 m .59653 .68061 L .59617 .67821 L F
0 .266 .748 r
.60502 .71696 m .60703 .71826 L .60794 .71936 L F
.93 .904 .777 r
.60794 .71936 m .60511 .72172 L .6065 .72243 L F
.60794 .71936 m .60703 .71826 L .60511 .72172 L F
.829 .506 .442 r
.60701 .72679 m .60971 .72552 L .60731 .72459 L F
.60701 .72679 m .61006 .72757 L .60971 .72552 L F
.722 .514 .609 r
.63308 .50286 m .63708 .50341 L .63716 .50076 L F
.785 .588 .635 r
.55988 .70586 m .55977 .70882 L .56299 .70903 L F
.675 .232 .191 r
.55977 .70882 m .56209 .71064 L .56299 .70903 L F
.589 .137 .147 r
.56299 .70903 m .56209 .71064 L .56548 .71044 L F
.006 0 .086 r
.68316 .5034 m .68085 .5063 L .68285 .50493 L F
0 0 0 r
.68316 .5034 m .6842 .50303 L .68481 .50194 L F
.68316 .5034 m .68285 .50493 L .6842 .50303 L F
.39 .027 .223 r
.74223 .58901 m .74456 .58851 L .74514 .58728 L F
.465 .17 .379 r
.74456 .58851 m .74706 .58646 L .74514 .58728 L F
.402 0 0 r
.48848 .77333 m .48694 .77445 L .4845 .77446 L F
.947 .693 .52 r
.48685 .77186 m .48848 .77333 L .49031 .77192 L F
.48685 .77186 m .48694 .77445 L .48848 .77333 L F
.392 .731 .991 r
.28959 .58894 m .28899 .59005 L .28749 .58914 L F
.28959 .58894 m .29116 .59004 L .28899 .59005 L F
.482 0 .009 r
.56854 .77251 m .5696 .77396 L .56954 .77133 L F
.612 .438 .622 r
.61113 .55632 m .6134 .55587 L .61121 .55859 L F
.699 .506 .624 r
.6086 .55792 m .61113 .55632 L .61121 .55859 L F
.608 .629 .846 r
.31632 .60905 m .31675 .60541 L .31465 .60613 L F
.31632 .60905 m .31852 .60864 L .31675 .60541 L F
.268 0 0 r
.39639 .64875 m .39856 .6489 L .39994 .64843 L F
.242 0 0 r
.39856 .6489 m .40212 .64884 L .39994 .64843 L F
.479 .77 .995 r
.31163 .60577 m .3129 .60663 L .31465 .60613 L F
.467 .333 .614 r
.44973 .76961 m .45176 .77171 L .45151 .76913 L F
.44973 .76961 m .44989 .77244 L .45176 .77171 L F
.592 .243 .347 r
.52538 .77239 m .52203 .7742 L .52239 .77302 L F
.51 .229 .424 r
.47083 .67418 m .46885 .67284 L .47129 .67167 L F
.47083 .67418 m .46844 .67475 L .46885 .67284 L F
.438 .769 .997 r
.75178 .59161 m .75285 .59035 L .75056 .59121 L F
.75178 .59161 m .75406 .59134 L .75285 .59035 L F
.468 .221 .456 r
.26972 .6106 m .26718 .61324 L .26763 .61117 L F
.465 .128 .31 r
.29716 .63585 m .30059 .63308 L .29851 .63353 L F
.591 .491 .709 r
.35056 .67499 m .35241 .67212 L .35038 .67256 L F
.568 .506 .745 r
.68544 .51465 m .68668 .51053 L .68445 .51109 L F
.638 .172 .131 r
.68544 .51465 m .68799 .51623 L .68873 .51593 L F
.322 .388 .776 r
.687 .51611 m .68799 .51623 L .68544 .51465 L F
.73 .606 .718 r
.33092 .6252 m .33112 .6263 L .32888 .62767 L F
.391 .119 .376 r
.33112 .6263 m .3282 .63041 L .32888 .62767 L F
.33112 .6263 m .33047 .62987 L .3282 .63041 L F
0 .064 .586 r
.33116 .62557 m .33112 .6263 L .33092 .6252 L F
.479 .245 .482 r
.33116 .62557 m .33047 .62987 L .33112 .6263 L F
.607 .451 .645 r
.47343 .78628 m .47598 .78649 L .47552 .78298 L F
.397 .806 .98 r
.4746 .78247 m .47791 .78267 L .47552 .78298 L F
.54 .403 .644 r
.47552 .78298 m .47598 .78649 L .47809 .78548 L F
.574 .048 0 r
.47552 .78298 m .47696 .7846 L .47476 .78496 L F
.47552 .78298 m .47809 .78548 L .47696 .7846 L F
.716 .327 .31 r
.47696 .7846 m .47791 .78267 L .4746 .78247 L F
0 .094 .6 r
.47478 .78237 m .47609 .7837 L .4746 .78247 L F
.47609 .7837 m .47696 .7846 L .47581 .78356 L F
.47609 .7837 m .47581 .78356 L .4746 .78247 L F
0 0 0 r
.47476 .78496 m .47343 .78628 L .47531 .7833 L F
.47538 .78334 m .47531 .7833 L .47552 .78298 L F
.47476 .78496 m .47531 .7833 L .47538 .78334 L F
.514 .673 .936 r
.47476 .78496 m .47598 .78649 L .47343 .78628 L F
.183 .714 .729 r
.46516 .66955 m .46689 .66915 L .46762 .66904 L F
.624 .06 0 r
.46689 .66915 m .46973 .67046 L .46762 .66904 L F
.905 .958 .817 r
.66097 .4899 m .6586 .49118 L .65932 .48883 L F
.66097 .4899 m .65901 .49236 L .6586 .49118 L F
.842 .801 .812 r
.66293 .48743 m .66097 .4899 L .65932 .48883 L F
.561 .077 .065 r
.55543 .71134 m .55456 .7127 L .55193 .71146 L F
.824 .394 .217 r
.55543 .71134 m .55734 .71389 L .55456 .7127 L F
.804 .409 .305 r
.55923 .71395 m .55734 .71389 L .55543 .71134 L F
.592 .945 .808 r
.56047 .68362 m .56168 .68232 L .56354 .68159 L F
.557 .881 .609 r
.56047 .68362 m .55913 .68465 L .56168 .68232 L F
.547 .786 .987 r
.69057 .52974 m .68933 .53116 L .68813 .53002 L F
.121 .08 .534 r
.69057 .52974 m .68947 .53346 L .68933 .53116 L F
.635 .426 .582 r
.51043 .74465 m .51043 .74713 L .51306 .74688 L F
.833 .469 .364 r
.61006 .72757 m .61359 .7303 L .61342 .72823 L F
.319 0 .045 r
.37379 .6526 m .37591 .65219 L .3773 .65041 L F
.384 0 .082 r
.37591 .65219 m .37947 .65021 L .3773 .65041 L F
.351 0 .128 r
.57907 .67719 m .58037 .67759 L .58202 .67511 L F
.337 .812 .902 r
.58202 .67511 m .58289 .67457 L .58433 .67462 L F
0 0 0 r
.58073 .67704 m .58037 .67759 L .58082 .67704 L F
.58207 .67592 m .58037 .67759 L .5814 .67702 L F
.58289 .67457 m .58208 .67554 L .58207 .67592 L F
.58208 .67554 m .58037 .67759 L .58207 .67592 L F
.58202 .67511 m .58073 .67704 L .58289 .67457 L F
.58073 .67704 m .58082 .67704 L .58289 .67457 L F
.58289 .67457 m .58207 .67592 L .58197 .67615 L F
.58207 .67592 m .5814 .67702 L .58197 .67615 L F
.809 .632 .663 r
.58197 .67615 m .5814 .67702 L .57851 .67554 L F
0 0 .096 r
.58164 .67692 m .58197 .67615 L .57851 .67554 L F
.58202 .67709 m .58197 .67615 L .58164 .67692 L F
.456 .214 .457 r
.58197 .67615 m .5821 .67809 L .58448 .67751 L F
0 0 .096 r
.58214 .67714 m .5821 .67809 L .58197 .67615 L F
.58214 .67714 m .58204 .67657 L .58202 .67709 L F
.58204 .67657 m .58197 .67615 L .58202 .67709 L F
.168 .304 .76 r
.57907 .67719 m .58037 .67759 L .5814 .67702 L F
.57907 .67719 m .58109 .67704 L .57767 .67736 L F
.58109 .67704 m .5814 .67702 L .58116 .67704 L F
.54 .477 .734 r
.57794 .68086 m .57996 .68147 L .57907 .67719 L F
.618 .621 .831 r
.57996 .68147 m .58037 .67759 L .57907 .67719 L F
.168 .304 .76 r
.58109 .67704 m .58116 .67704 L .57767 .67736 L F
.195 0 0 r
.49618 .73293 m .49793 .73242 L .49894 .73094 L F
.331 .139 .462 r
.49894 .73094 m .50067 .72986 L .50084 .72791 L F
.404 .083 .304 r
.49793 .73242 m .50067 .72986 L .49894 .73094 L F
.283 0 .038 r
.41832 .70392 m .4172 .70266 L .41897 .70268 L F
.41832 .70392 m .41618 .70437 L .4172 .70266 L F
.555 .149 .227 r
.53754 .74124 m .54075 .73958 L .53791 .73931 L F
.53754 .74124 m .53986 .74134 L .54075 .73958 L F
.609 .205 .252 r
.54075 .73958 m .53986 .74134 L .54315 .74114 L F
.905 .712 .63 r
.60362 .71356 m .60317 .71666 L .60502 .71696 L F
.811 .44 .353 r
.6035 .71851 m .60502 .71696 L .60317 .71666 L F
.6035 .71851 m .60574 .71936 L .60502 .71696 L F
.527 .276 .478 r
.60574 .71936 m .60703 .71826 L .60502 .71696 L F
.374 0 .143 r
.46514 .75252 m .46731 .7521 L .46846 .75028 L F
.479 .149 .329 r
.46731 .7521 m .47044 .74959 L .46846 .75028 L F
.534 .32 .535 r
.42778 .68365 m .42999 .68329 L .43016 .68092 L F
.553 .34 .545 r
.42999 .68329 m .4324 .68054 L .43016 .68092 L F
.587 .415 .617 r
.65206 .51759 m .6527 .51982 L .64936 .5202 L F
.86 .936 .561 r
.64828 .52136 m .64936 .5202 L .64933 .51945 L F
.79 .624 .676 r
.64828 .52136 m .6527 .51982 L .64936 .5202 L F
0 0 0 r
.55347 .69385 m .5519 .69502 L .55339 .69357 L F
.333 .173 .509 r
.55389 .69597 m .5519 .69502 L .55347 .69385 L F
.142 .649 .902 r
.41491 .6638 m .41361 .66329 L .41246 .6633 L F
.42 .818 .983 r
.41705 .66342 m .41361 .66329 L .41491 .6638 L F
.693 .745 .891 r
.54138 .75544 m .54437 .75564 L .54305 .7533 L F
.538 0 0 r
.54724 .75417 m .54305 .7533 L .54437 .75564 L F
.914 .699 .599 r
.5911 .68623 m .58899 .68569 L .58912 .6832 L F
.975 .692 .424 r
.5911 .68623 m .58975 .68773 L .58899 .68569 L F
.5911 .68623 m .59117 .68888 L .58975 .68773 L F
.842 .801 .812 r
.66293 .48743 m .65932 .48883 L .6612 .48579 L F
.839 .787 .802 r
.66363 .48318 m .66293 .48743 L .6612 .48579 L F
.713 .678 .814 r
.65604 .5281 m .65857 .52731 L .65571 .52897 L F
.422 .356 .678 r
.65638 .52796 m .65607 .52801 L .65571 .52897 L F
.65607 .52801 m .65395 .52838 L .65571 .52897 L F
.713 .678 .814 r
.65511 .52839 m .65604 .5281 L .65571 .52897 L F
.143 0 0 r
.65511 .52839 m .65395 .52838 L .65638 .52796 L F
.166 .476 .895 r
.65571 .52897 m .65395 .52838 L .65511 .52839 L F
0 0 0 r
.60431 .55347 m .60547 .55169 L .60617 .55012 L F
.767 .767 .852 r
.60649 .54724 m .60617 .55012 L .60588 .54942 L F
.60649 .54724 m .60908 .54765 L .60617 .55012 L F
.904 .805 .328 r
.60547 .55169 m .60588 .54942 L .60617 .55012 L F
.758 .994 .811 r
.61006 .75251 m .61083 .75088 L .60928 .75211 L F
.502 .377 .642 r
.4664 .77291 m .46706 .77553 L .46509 .7754 L F
.475 .518 .822 r
.46706 .77553 m .46703 .7765 L .46509 .7754 L F
.627 .505 .695 r
.68122 .4947 m .68201 .49783 L .67935 .49804 L F
.197 .609 .947 r
.68199 .50017 m .67935 .49804 L .68201 .49783 L F
.68199 .50017 m .67901 .4988 L .67935 .49804 L F
.307 .305 .694 r
.5475 .7577 m .54763 .76111 L .54804 .76072 L F
.995 .767 .467 r
.54831 .76181 m .54931 .76395 L .54837 .76013 L F
.54829 .76235 m .54853 .76273 L .54831 .76181 L F
.54853 .76273 m .54931 .76395 L .54831 .76181 L F
.576 .557 .796 r
.54931 .76395 m .55225 .76391 L .54837 .76013 L F
.995 .767 .467 r
.54825 .76347 m .54848 .76357 L .54829 .76235 L F
.54848 .76357 m .54931 .76395 L .54829 .76235 L F
.54825 .76347 m .54837 .76013 L .55035 .76242 L F
.665 .144 0 r
.54837 .76013 m .55225 .76391 L .55035 .76242 L F
.497 .36 .625 r
.54804 .76072 m .55035 .76242 L .54934 .75951 L F
.54763 .76111 m .54821 .76139 L .54804 .76072 L F
.54821 .76139 m .55035 .76242 L .54804 .76072 L F
.307 .305 .694 r
.5476 .7578 m .54804 .76072 L .54934 .75951 L F
.5475 .7577 m .54804 .76072 L .5476 .7578 L F
.284 .288 .688 r
.54931 .76395 m .55147 .766 L .55225 .76391 L F
.577 .603 .842 r
.35245 .69779 m .35348 .70019 L .35533 .69968 L F
.567 .516 .758 r
.35348 .70019 m .35637 .70272 L .35533 .69968 L F
.248 0 .272 r
.33092 .6252 m .33339 .62253 L .33248 .62496 L F
0 .064 .586 r
.33116 .62557 m .33092 .6252 L .33248 .62496 L F
.71 .456 .539 r
.49872 .79666 m .50079 .79467 L .49731 .79421 L F
.49872 .79666 m .50094 .79697 L .50079 .79467 L F
.675 .259 .248 r
.50333 .79633 m .50079 .79467 L .50094 .79697 L F
.01 0 0 r
.64957 .54731 m .65132 .54729 L .64778 .54825 L F
.64957 .54731 m .65181 .54719 L .65132 .54729 L F
.874 .466 .247 r
.67251 .52609 m .67463 .5282 L .67357 .52758 L F
.878 .671 .62 r
.67503 .53024 m .67357 .52758 L .67463 .5282 L F
.14 .326 .789 r
.71853 .59266 m .71807 .59418 L .71661 .59106 L F
.683 .558 .707 r
.71661 .59106 m .71416 .59224 L .7161 .58919 L F
.14 .326 .789 r
.7193 .59329 m .71661 .59106 L .71916 .59102 L F
.753 .519 .576 r
.71529 .59296 m .71807 .59156 L .71619 .59092 L F
.71807 .59156 m .71916 .59102 L .71783 .59098 L F
.71807 .59156 m .71783 .59098 L .71619 .59092 L F
.14 .326 .789 r
.7193 .59329 m .71891 .59357 L .71853 .59266 L F
.71891 .59357 m .71807 .59418 L .71853 .59266 L F
.7193 .59329 m .71937 .59472 L .71807 .59418 L F
.739 .588 .688 r
.60431 .55347 m .60601 .55635 L .60456 .55531 L F
.679 .467 .591 r
.60601 .55635 m .60576 .55886 L .60456 .55531 L F
.60601 .55635 m .60747 .55842 L .60576 .55886 L F
.753 .478 .516 r
.60601 .55635 m .6086 .55792 L .60747 .55842 L F
.196 .538 .926 r
.687 .51611 m .68918 .51772 L .68799 .51623 L F
.304 .384 .779 r
.68918 .51772 m .69028 .51551 L .68799 .51623 L F
.522 .278 .487 r
.69168 .51697 m .69161 .51901 L .68918 .51772 L F
.304 .384 .779 r
.68918 .51772 m .69161 .51901 L .69028 .51551 L F
.781 .702 .777 r
.61528 .52537 m .61652 .52853 L .6149 .52705 L F
.842 .732 .743 r
.61652 .52853 m .61304 .53023 L .6149 .52705 L F
.61652 .52853 m .61485 .5315 L .61304 .53023 L F
.415 .204 .483 r
.33339 .62253 m .33561 .61957 L .33516 .62133 L F
.294 .042 .35 r
.33248 .62496 m .33339 .62253 L .33516 .62133 L F
.481 .523 .824 r
.68085 .5063 m .68324 .50617 L .68285 .50493 L F
.686 .531 .669 r
.69579 .50879 m .69355 .5116 L .69361 .50927 L F
0 0 0 r
.60401 .55435 m .60431 .55347 L .60456 .55531 L F
.60401 .55435 m .60547 .55169 L .60431 .55347 L F
.622 .202 .226 r
.31612 .74645 m .31792 .74711 L .31701 .74567 L F
.771 .315 .166 r
.55897 .73297 m .56171 .73397 L .56095 .7331 L F
.883 .642 .568 r
.5137 .76142 m .51115 .76309 L .51081 .76023 L F
.5137 .76142 m .51359 .76401 L .51115 .76309 L F
.448 .017 .127 r
.74119 .5945 m .74244 .59581 L .74014 .59599 L F
.74119 .5945 m .74319 .59433 L .74244 .59581 L F
.975 .69 .42 r
.55017 .75053 m .55271 .75238 L .5512 .75062 L F
.974 .682 .406 r
.55017 .75053 m .55132 .75418 L .55271 .75238 L F
.433 .569 .891 r
.55271 .75238 m .55314 .75017 L .5512 .75062 L F
.55271 .75238 m .55472 .75241 L .55314 .75017 L F
.517 .086 .159 r
.55132 .75418 m .55472 .75241 L .55271 .75238 L F
.289 0 0 r
.28097 .6057 m .28014 .60631 L .27803 .60661 L F
.303 0 0 r
.28287 .60542 m .28014 .60631 L .28097 .6057 L F
.321 0 .189 r
.36079 .65784 m .35881 .65848 L .36047 .65841 L F
.322 .059 .35 r
.36047 .65841 m .35881 .65848 L .35814 .66099 L F
.907 .952 .609 r
.57223 .76849 m .57369 .76703 L .57392 .76557 L F
.57223 .76849 m .57243 .76916 L .57369 .76703 L F
.077 .635 .793 r
.29903 .75839 m .30138 .75838 L .30264 .75852 L F
.30264 .75852 m .30138 .75838 L .29903 .75839 L F
.582 .93 .95 r
.30325 .75747 m .30138 .75838 L .30264 .75852 L F
.30325 .75747 m .30138 .75838 L .30264 .75852 L F
.479 0 0 r
.47201 .76691 m .47081 .76717 L .46877 .7666 L F
.487 .528 .825 r
.47201 .76691 m .47525 .76969 L .47396 .76719 L F
.556 .051 .01 r
.47396 .76719 m .47081 .76717 L .47201 .76691 L F
.636 .696 .889 r
.71524 .50772 m .71309 .50866 L .71185 .50553 L F
.622 .637 .844 r
.71524 .50772 m .71656 .50971 L .71309 .50866 L F
.773 .698 .781 r
.70377 .50371 m .70311 .50591 L .70016 .50541 L F
.791 .639 .693 r
.70311 .50591 m .70146 .50872 L .70016 .50541 L F
.623 .662 .867 r
.45004 .65299 m .44687 .65178 L .449 .65129 L F
.519 .702 .953 r
.45101 .65128 m .45004 .65299 L .449 .65129 L F
.45101 .65128 m .45218 .65274 L .45004 .65299 L F
.397 .118 .368 r
.43011 .69391 m .42928 .69707 L .42737 .69613 L F
.41 .053 .245 r
.42928 .69707 m .42638 .6989 L .42737 .69613 L F
.688 .211 .114 r
.47593 .77476 m .47903 .77514 L .47629 .77369 L F
.549 .357 .573 r
.49116 .739 m .49356 .73579 L .49164 .73645 L F
.318 .654 .971 r
.71782 .60796 m .71899 .60706 L .71699 .60677 L F
.71782 .60796 m .7199 .60815 L .71899 .60706 L F
.807 .547 .545 r
.55596 .7058 m .55749 .70782 L .55845 .70578 L F
.694 .502 .623 r
.55845 .70578 m .55749 .70782 L .55988 .70586 L F
.475 .314 .582 r
.35189 .66658 m .35377 .66388 L .35135 .6642 L F
.468 .849 .984 r
.54374 .77779 m .54324 .77722 L .54051 .77782 L F
.378 .792 .979 r
.54598 .77754 m .54324 .77722 L .54374 .77779 L F
.592 .023 0 r
.68807 .52547 m .68903 .5266 L .68716 .52688 L F
.68807 .52547 m .68829 .52562 L .68903 .5266 L F
.68829 .52562 m .69056 .52716 L .68903 .5266 L F
.619 .558 .764 r
.68903 .5266 m .69057 .52974 L .68813 .53002 L F
0 0 .384 r
.68903 .5266 m .68947 .52864 L .68995 .52782 L F
.592 .023 0 r
.69056 .52716 m .6906 .52719 L .68903 .5266 L F
.757 .618 .705 r
.6906 .52719 m .69057 .52974 L .68903 .5266 L F
0 0 .384 r
.68903 .5266 m .68995 .52782 L .69064 .5266 L F
.643 .712 .898 r
.68754 .52606 m .68903 .5266 L .68863 .52365 L F
.68716 .52688 m .68903 .5266 L .68754 .52606 L F
.336 .312 .684 r
.5369 .75221 m .53463 .74986 L .53672 .74979 L F
.214 0 0 r
.27803 .60661 m .27716 .60762 L .27526 .60806 L F
0 0 0 r
.28014 .60631 m .27716 .60762 L .27803 .60661 L F
.253 .765 .824 r
.2817 .65226 m .27832 .65275 L .28011 .65237 L F
.251 0 0 r
.74594 .59261 m .74749 .59344 L .74523 .59363 L F
.74594 .59261 m .74838 .59211 L .74749 .59344 L F
.413 .142 .39 r
.34029 .61412 m .34283 .61167 L .34232 .61357 L F
.358 .092 .368 r
.34232 .61357 m .34283 .61167 L .34471 .61091 L F
.619 .622 .832 r
.36289 .7224 m .36471 .72583 L .36738 .72542 L F
.54 .262 .443 r
.36471 .72583 m .36668 .72722 L .36738 .72542 L F
.36738 .72542 m .36668 .72722 L .36471 .72583 L F
.652 .619 .804 r
.57805 .71118 m .58086 .71354 L .58107 .71333 L F
.432 .358 .674 r
.7658 .59329 m .76342 .59168 L .76515 .5913 L F
.7658 .59329 m .7637 .59544 L .76342 .59168 L F
.798 .564 .584 r
.35227 .70566 m .35534 .70865 L .35411 .70529 L F
.35227 .70566 m .35214 .7085 L .35534 .70865 L F
.616 .539 .745 r
.35411 .70529 m .35534 .70865 L .35763 .70832 L F
.462 .078 .225 r
.35534 .70865 m .35648 .71066 L .35763 .70832 L F
0 0 .435 r
.35577 .71128 m .35648 .71066 L .35534 .70865 L F
0 .138 .61 r
.70987 .60381 m .70988 .60369 L .70811 .60214 L F
.70987 .60381 m .71152 .60508 L .70988 .60369 L F
.844 .493 .389 r
.56236 .71671 m .56067 .71684 L .55923 .71395 L F
.709 .234 .119 r
.56236 .71671 m .56092 .71783 L .56067 .71684 L F
.439 0 0 r
.56488 .71842 m .56092 .71783 L .56236 .71671 L F
.45 .157 .376 r
.3124 .64472 m .3116 .64643 L .30993 .64684 L F
.296 0 .237 r
.3144 .64409 m .3116 .64643 L .3124 .64472 L F
.162 0 0 r
.39638 .71154 m .39474 .71272 L .3925 .71314 L F
.275 0 0 r
.39837 .71082 m .39474 .71272 L .39638 .71154 L F
.547 .316 .517 r
.52473 .74383 m .52659 .74389 L .52706 .74178 L F
.437 .215 .477 r
.52706 .74178 m .52909 .74305 L .52981 .741 L F
.52706 .74178 m .52659 .74389 L .52909 .74305 L F
.653 .646 .83 r
.73134 .61926 m .73465 .62061 L .73391 .61871 L F
.588 .609 .84 r
.73391 .61871 m .73465 .62061 L .73697 .62004 L F
.65 .439 .584 r
.52426 .75561 m .52424 .75853 L .52184 .75817 L F
.644 .434 .583 r
.52739 .75771 m .52426 .75561 L .52764 .75537 L F
.52739 .75771 m .52424 .75853 L .52426 .75561 L F
.996 .852 .576 r
.65893 .49459 m .6586 .49118 L .65901 .49236 L F
.658 .58 .756 r
.69822 .50619 m .69579 .50879 L .69502 .50567 L F
.639 .55 .738 r
.69821 .5084 m .69579 .50879 L .69822 .50619 L F
.601 .579 .801 r
.69909 .51136 m .69579 .50879 L .69821 .5084 L F
.23 0 0 r
.46887 .79042 m .46636 .79132 L .46399 .79139 L F
.606 .094 .006 r
.46887 .79042 m .46924 .79144 L .46636 .79132 L F
.429 .817 .988 r
.4113 .65038 m .41342 .65001 L .41475 .65057 L F
.47 .83 .995 r
.41342 .65001 m .41692 .65017 L .41475 .65057 L F
.941 .812 .689 r
.47199 .77556 m .47023 .77551 L .47193 .7742 L F
.47199 .77556 m .4712 .77766 L .47023 .77551 L F
.654 .167 .081 r
.63361 .51679 m .63214 .51658 L .63003 .51857 L F
.63214 .51658 m .62987 .51626 L .63 .51804 L F
.63214 .51658 m .63 .51804 L .63003 .51857 L F
.528 .318 .538 r
.63601 .51416 m .63361 .51679 L .63347 .51445 L F
.654 .167 .081 r
.63264 .51665 m .63233 .51783 L .62987 .51626 L F
.63361 .51679 m .63233 .51783 L .63264 .51665 L F
.952 .61 .221 r
.63233 .51783 m .6332 .5206 L .63194 .51927 L F
.383 .332 .676 r
.63447 .51946 m .6332 .5206 L .63233 .51783 L F
.664 .195 .129 r
.63194 .51927 m .63447 .51946 L .63233 .51783 L F
.63233 .51783 m .63447 .51946 L .63194 .51927 L F
.63233 .51783 m .63194 .51927 L .632 .51912 L F
.599 .339 .494 r
.63504 .51539 m .63233 .51783 L .63361 .51679 L F
.63504 .51539 m .63493 .51772 L .63233 .51783 L F
.638 .263 .317 r
.62987 .51626 m .6328 .51715 L .63347 .51445 L F
.683 .859 .455 r
.6328 .51715 m .63233 .51783 L .63317 .51622 L F
.584 .287 .431 r
.63493 .51772 m .63447 .51946 L .63233 .51783 L F
.664 .195 .129 r
.63233 .51783 m .632 .51912 L .63317 .51622 L F
.979 .685 .37 r
.63347 .51445 m .6328 .51715 L .63361 .51679 L F
0 0 0 r
.63504 .51539 m .63361 .51679 L .63601 .51416 L F
.286 0 .211 r
.63442 .51502 m .6328 .51715 L .63504 .51539 L F
.63347 .51445 m .63311 .51592 L .63442 .51502 L F
.63311 .51592 m .6328 .51715 L .63442 .51502 L F
.536 .345 .569 r
.63587 .51162 m .63601 .51416 L .63347 .51445 L F
.286 0 .211 r
.63347 .51445 m .63504 .51539 L .63601 .51416 L F
.536 .345 .569 r
.63587 .51162 m .63601 .51416 L .63347 .51445 L F
.759 .348 .273 r
.52152 .71602 m .52359 .71831 L .52486 .71676 L F
.719 .297 .244 r
.52359 .71831 m .52699 .71877 L .52486 .71676 L F
.408 .105 .336 r
.69607 .52294 m .69589 .5244 L .69343 .52507 L F
.525 .252 .443 r
.69828 .52233 m .69589 .5244 L .69607 .52294 L F
.489 .181 .371 r
.73417 .5942 m .73683 .59194 L .73432 .59205 L F
.915 .636 .499 r
.35049 .7029 m .3505 .70514 L .35227 .70566 L F
.872 .827 .801 r
.35227 .70566 m .34947 .70939 L .3487 .70855 L F
.35227 .70566 m .3489 .70839 L .35053 .70756 L F
.3489 .70839 m .3487 .70855 L .35053 .70756 L F
.35227 .70566 m .35053 .70756 L .3505 .70514 L F
.928 .684 .549 r
.35053 .70756 m .35227 .70566 L .3505 .70514 L F
.35053 .70756 m .35214 .7085 L .35227 .70566 L F
.577 .729 .946 r
.3499 .70525 m .35205 .70679 L .35053 .70756 L F
.35205 .70679 m .35316 .70758 L .35053 .70756 L F
.915 .636 .499 r
.35049 .7029 m .3505 .70514 L .35227 .70566 L F
.781 .574 .619 r
.50999 .79934 m .51424 .79701 L .50994 .79695 L F
.50999 .79934 m .51488 .79993 L .51424 .79701 L F
.213 .201 .627 r
.51424 .79701 m .51488 .79993 L .5158 .79941 L F
.705 .52 .636 r
.55749 .70782 m .55977 .70882 L .55988 .70586 L F
.254 .384 .802 r
.63166 .49279 m .63375 .49348 L .63401 .49247 L F
.869 .496 .338 r
.55923 .71395 m .55796 .71527 L .55734 .71389 L F
.55923 .71395 m .56067 .71684 L .55796 .71527 L F
.392 .166 .447 r
.33561 .61957 m .3379 .61683 L .3378 .61873 L F
.422 .192 .458 r
.33516 .62133 m .33561 .61957 L .3378 .61873 L F
.201 .076 .476 r
.63003 .51857 m .62903 .52213 L .62899 .51999 L F
.445 .158 .382 r
.4324 .68054 m .43524 .67771 L .43239 .67796 L F
.52 .26 .461 r
.54085 .75321 m .54305 .7533 L .54372 .75038 L F
.805 .761 .247 r
.54372 .75038 m .54336 .75096 L .54266 .74877 L F
.54372 .75038 m .54305 .7533 L .54336 .75096 L F
.5 0 0 r
.57206 .72374 m .57176 .7242 L .56908 .72292 L F
.698 .789 .921 r
.70584 .50155 m .70597 .50329 L .7025 .50256 L F
.763 .745 .836 r
.70597 .50329 m .70377 .50371 L .7025 .50256 L F
.473 .47 .773 r
.7071 .49908 m .70597 .50329 L .70584 .50155 L F
.201 0 .125 r
.34677 .61029 m .34774 .60835 L .34947 .60805 L F
0 0 .343 r
.57046 .74434 m .57214 .74738 L .57199 .7471 L F
.721 .414 0 r
.57214 .74738 m .57277 .74921 L .57199 .7471 L F
.441 .122 .327 r
.42778 .68365 m .42951 .68472 L .42999 .68329 L F
.42778 .68365 m .42728 .68521 L .42951 .68472 L F
.597 .319 .466 r
.70164 .51979 m .70076 .52232 L .69828 .52233 L F
.632 .355 .48 r
.70394 .52147 m .70164 .51979 L .70393 .52036 L F
.70394 .52147 m .70076 .52232 L .70164 .51979 L F
.802 .315 0 r
.56599 .71916 m .56653 .72105 L .56488 .71842 L F
.56599 .71916 m .56778 .72176 L .56653 .72105 L F
.571 .433 .655 r
.71961 .5138 m .71728 .51435 L .71891 .51146 L F
.37 .06 .303 r
.71961 .5138 m .71685 .516 L .71728 .51435 L F
.746 .534 .607 r
.5318 .74134 m .53531 .74163 L .53526 .739 L F
.556 .382 .601 r
.53526 .739 m .53754 .74124 L .53791 .73931 L F
.53526 .739 m .53531 .74163 L .53754 .74124 L F
.493 .274 .51 r
.51238 .71418 m .51228 .71642 L .51453 .71386 L F
.45 .346 .645 r
.45062 .76129 m .45273 .76325 L .45266 .76081 L F
.45062 .76129 m .45081 .76398 L .45273 .76325 L F
.3 .483 .871 r
.65512 .52458 m .65269 .52372 L .65186 .52177 L F
.461 .466 .777 r
.45434 .65229 m .4535 .65584 L .45218 .65274 L F
.45434 .65229 m .45552 .65596 L .4535 .65584 L F
.156 .665 .902 r
.51824 .74169 m .52046 .74178 L .52173 .74221 L F
.647 .743 .919 r
.51824 .74169 m .52173 .74221 L .52046 .74178 L F
.622 .9 .986 r
.52173 .74221 m .52046 .74178 L .52284 .74098 L F
.576 .358 .547 r
.52284 .74098 m .52046 .74178 L .52173 .74221 L F
.479 .751 .989 r
.42636 .66374 m .42718 .66244 L .425 .66286 L F
.42636 .66374 m .42848 .6635 L .42718 .66244 L F
.945 .807 .677 r
.60236 .70036 m .60348 .69745 L .6022 .69663 L F
0 .211 .699 r
.56898 .71076 m .57239 .71364 L .57212 .71142 L F
0 .443 .836 r
.31068 .60551 m .31015 .60475 L .30874 .60441 L F
.31068 .60551 m .31163 .60577 L .31015 .60475 L F
.498 .156 .317 r
.73221 .59946 m .73518 .59682 L .73417 .59865 L F
.73221 .59946 m .73253 .59804 L .73518 .59682 L F
.39 .036 .239 r
.73518 .59682 m .73759 .59615 L .73708 .59685 L F
.211 0 .029 r
.73518 .59682 m .73708 .59685 L .73417 .59865 L F
.445 .158 .382 r
.4324 .68054 m .43451 .68009 L .43524 .67771 L F
.63 .495 .679 r
.43524 .67771 m .43766 .67767 L .43743 .67533 L F
.487 .151 .322 r
.43451 .68009 m .43766 .67767 L .43524 .67771 L F
.507 .249 .458 r
.30532 .63047 m .308 .62717 L .30566 .62831 L F
.356 .788 .969 r
.28552 .65249 m .28373 .65202 L .2817 .65226 L F
.461 .82 .996 r
.28742 .65227 m .28373 .65202 L .28552 .65249 L F
.477 .179 .382 r
.41183 .69419 m .41432 .69197 L .4125 .69227 L F
.353 .806 .944 r
.41692 .65017 m .41908 .64982 L .42046 .65014 L F
.303 .764 .949 r
.41908 .64982 m .42253 .65007 L .42046 .65014 L F
.149 .631 .922 r
.26733 .5855 m .26919 .58569 L .27074 .58644 L F
.375 .722 .989 r
.27121 .58536 m .27074 .58644 L .26919 .58569 L F
.27121 .58536 m .27277 .58642 L .27074 .58644 L F
.785 .957 .925 r
.69248 .51996 m .68917 .52113 L .69161 .51901 L F
.893 .924 .833 r
.69248 .51996 m .69377 .51615 L .69398 .51859 L F
.69248 .51996 m .69161 .51901 L .69377 .51615 L F
.647 .243 .264 r
.5442 .73268 m .54099 .73275 L .54182 .73093 L F
.293 .731 .966 r
.30415 .59152 m .30374 .59225 L .30223 .59143 L F
.30415 .59152 m .30585 .59221 L .30374 .59225 L F
.751 .255 .049 r
.48315 .7857 m .48133 .78342 L .47975 .7833 L F
.07 .472 .889 r
.72428 .61034 m .7218 .60855 L .72325 .60947 L F
.657 .685 .864 r
.26505 .64087 m .26243 .64152 L .26089 .63894 L F
.551 .343 .551 r
.52473 .74383 m .52716 .74595 L .52659 .74389 L F
.52473 .74383 m .52458 .74678 L .52716 .74595 L F
.63 .666 .866 r
.55354 .77302 m .55729 .7745 L .55644 .77401 L F
.325 .774 .958 r
.55644 .77401 m .55729 .7745 L .55931 .77421 L F
.705 .615 .754 r
.70146 .50872 m .69909 .51136 L .69821 .5084 L F
.512 .749 .981 r
.29697 .60272 m .30043 .60361 L .2991 .60215 L F
.519 .708 .957 r
.2991 .60215 m .30043 .60361 L .30112 .60186 L F
.515 .704 .956 r
.30043 .60361 m .30245 .60339 L .30112 .60186 L F
.941 .939 .763 r
.34516 .71672 m .34594 .71315 L .34544 .71548 L F
.565 .371 .577 r
.34768 .71602 m .34516 .71672 L .34544 .71548 L F
.574 .469 .697 r
.34724 .71614 m .34552 .71895 L .34516 .71672 L F
.34768 .71602 m .34746 .71631 L .34724 .71614 L F
.34746 .71631 m .34552 .71895 L .34724 .71614 L F
0 0 .137 r
.34993 .71664 m .34834 .71905 L .34768 .71602 L F
.344 0 0 r
.34709 .71587 m .34993 .71664 L .34768 .71602 L F
.34709 .71588 m .34993 .71664 L .34709 .71587 L F
.574 .469 .697 r
.34768 .71602 m .34834 .71905 L .34552 .71895 L F
.344 0 0 r
.34544 .71548 m .34993 .71664 L .34688 .71583 L F
.34688 .71583 m .34709 .71588 L .34709 .71587 L F
.82 .442 .338 r
.34594 .71315 m .34993 .71664 L .3469 .71586 L F
.34594 .71315 m .34784 .71685 L .34993 .71664 L F
0 0 .132 r
.34709 .71446 m .34669 .71417 L .34715 .7132 L F
0 0 .408 r
.34669 .71417 m .34773 .7166 L .34633 .71389 L F
.34773 .7166 m .34784 .71685 L .34768 .71654 L F
.969 .732 .524 r
.34669 .71417 m .34792 .7175 L .34784 .71685 L F
0 0 .132 r
.34704 .71561 m .34669 .71417 L .34709 .71446 L F
0 0 .408 r
.34669 .71417 m .34633 .71389 L .34594 .71315 L F
.34773 .7166 m .34768 .71654 L .34594 .71315 L F
.82 .442 .338 r
.34559 .71481 m .3469 .71586 L .34544 .71548 L F
.34594 .71315 m .3469 .71586 L .34559 .71481 L F
.58 .254 .382 r
.6272 .55373 m .62704 .55534 L .62486 .55518 L F
.622 .29 .388 r
.63014 .55501 m .6272 .55373 L .63137 .55256 L F
.63014 .55501 m .62704 .55534 L .6272 .55373 L F
.595 .48 .692 r
.76846 .60319 m .76871 .60567 L .76622 .60614 L F
.719 .318 .288 r
.53047 .71907 m .53262 .7212 L .53393 .71942 L F
.43 0 0 r
.53262 .7212 m .53641 .72072 L .53393 .71942 L F
.288 0 .085 r
.73919 .59147 m .74147 .5908 L .74223 .58901 L F
.35 0 .119 r
.74147 .5908 m .74456 .58851 L .74223 .58901 L F
.608 .579 .796 r
.39038 .7002 m .38819 .70075 L .38677 .69729 L F
.087 .646 .745 r
.39676 .69845 m .3989 .69828 L .39998 .69826 L F
.25 0 0 r
.3989 .69828 m .39914 .69831 L .39998 .69826 L F
.282 .784 .807 r
.39788 .69881 m .39998 .69826 L .40134 .69817 L F
.25 0 0 r
.39914 .69831 m .40245 .69867 L .39998 .69826 L F
.282 .784 .807 r
.40134 .69817 m .39998 .69826 L .40188 .69807 L F
.504 0 0 r
.39998 .69826 m .40416 .69758 L .40188 .69807 L F
0 0 .518 r
.67172 .52435 m .67251 .52609 L .67357 .52758 L F
.737 .467 .521 r
.61376 .73308 m .61695 .73086 L .61359 .7303 L F
.61376 .73308 m .61697 .733 L .61695 .73086 L F
.731 .723 .843 r
.64692 .53012 m .65057 .52793 L .64717 .52745 L F
.369 .495 .855 r
.77416 .60592 m .77744 .60795 L .77536 .6087 L F
.002 0 0 r
.77536 .6087 m .77744 .60795 L .77465 .61013 L F
.174 0 .21 r
.3379 .61683 m .34029 .61412 L .34001 .61637 L F
.442 .208 .462 r
.34001 .61637 m .34029 .61412 L .34232 .61357 L F
.338 .654 .97 r
.75201 .61922 m .75325 .61833 L .75088 .61848 L F
.75201 .61922 m .75405 .61944 L .75325 .61833 L F
.562 .223 .352 r
.50331 .73896 m .50235 .74151 L .5 .74137 L F
.126 0 .196 r
.5057 .73613 m .50482 .73831 L .50331 .73896 L F
.318 0 .246 r
.5047 .7393 m .50331 .73896 L .50482 .73831 L F
.5047 .7393 m .50235 .74151 L .50331 .73896 L F
.595 .16 .185 r
.5095 .7739 m .50726 .77242 L .51248 .77225 L F
.689 .398 .476 r
.51308 .77154 m .5095 .7739 L .51248 .77225 L F
.684 .783 .925 r
.44687 .65178 m .44316 .65139 L .44519 .65033 L F
.542 .775 .984 r
.44711 .65009 m .44687 .65178 L .44519 .65033 L F
.44711 .65009 m .449 .65129 L .44687 .65178 L F
.661 .878 .979 r
.7263 .59688 m .72317 .59689 L .7256 .5967 L F
.45 .876 .775 r
.72786 .5958 m .7263 .59688 L .7256 .5967 L F
.72786 .5958 m .72905 .59553 L .7263 .59688 L F
.559 .556 .806 r
.7658 .59329 m .76646 .5965 L .7637 .59544 L F
.779 .738 .815 r
.60063 .56017 m .60258 .55871 L .60336 .56183 L F
.891 .552 .4 r
.60063 .56017 m .60336 .56183 L .6021 .56321 L F
.792 .635 .687 r
.604 .55766 m .60336 .56183 L .60258 .55871 L F
.604 .55766 m .6057 .56123 L .60336 .56183 L F
.693 .396 .468 r
.6057 .56123 m .6021 .56321 L .60336 .56183 L F
.234 0 .303 r
.50084 .72791 m .50229 .72749 L .50313 .72508 L F
.341 .146 .465 r
.50084 .72791 m .5027 .72801 L .50229 .72749 L F
.50084 .72791 m .50067 .72986 L .5027 .72801 L F
.441 .274 .558 r
.63792 .51318 m .63587 .51162 L .63786 .51091 L F
.63792 .51318 m .63601 .51416 L .63587 .51162 L F
.63792 .51318 m .63587 .51162 L .63786 .51091 L F
.63792 .51318 m .63601 .51416 L .63587 .51162 L F
.582 .329 .499 r
.45002 .68528 m .44802 .68337 L .45035 .68313 L F
.427 .774 .997 r
.31359 .59265 m .31301 .59368 L .31176 .59276 L F
.31359 .59265 m .31506 .59349 L .31301 .59368 L F
.853 .633 .604 r
.60273 .70808 m .60292 .70573 L .60042 .70526 L F
.644 .666 .856 r
.54597 .76399 m .5436 .7645 L .5429 .76247 L F
.556 .302 .486 r
.54597 .76399 m .54566 .76612 L .5436 .7645 L F
.866 .753 .736 r
.54728 .77091 m .54869 .77255 L .5505 .76945 L F
.87 .435 .159 r
.55202 .76943 m .55122 .76929 L .5505 .76945 L F
.35 0 0 r
.26009 .58459 m .26127 .58451 L .26011 .58294 L F
.26009 .58459 m .26349 .58518 L .26127 .58451 L F
.586 .441 .651 r
.35411 .70529 m .35591 .70521 L .35637 .70272 L F
.616 .539 .745 r
.35411 .70529 m .35763 .70832 L .35591 .70521 L F
.091 .124 .603 r
.70651 .59732 m .70673 .6009 L .7079 .59899 L F
.207 .323 .762 r
.70673 .6009 m .70896 .6011 L .7079 .59899 L F
.70673 .6009 m .70811 .60214 L .70896 .6011 L F
.565 .694 .927 r
.6613 .51238 m .65945 .51438 L .6572 .51418 L F
.6613 .51238 m .66167 .51397 L .65945 .51438 L F
.401 .754 .994 r
.43624 .65062 m .43512 .65163 L .43375 .65044 L F
.43624 .65062 m .43749 .65151 L .43512 .65163 L F
.642 .689 .879 r
.76853 .58302 m .76743 .5871 L .76625 .58362 L F
.76853 .58302 m .77035 .58615 L .76743 .5871 L F
.414 .285 .594 r
.46877 .7666 m .46877 .76904 L .46697 .76952 L F
.238 .13 .523 r
.46839 .77134 m .46697 .76952 L .46877 .76904 L F
.46839 .77134 m .4664 .77291 L .46697 .76952 L F
.386 .447 .801 r
.75529 .59465 m .75592 .59116 L .75406 .59134 L F
.75529 .59465 m .75694 .59447 L .75592 .59116 L F
.455 .414 .722 r
.75529 .59465 m .75772 .59638 L .75694 .59447 L F
.834 .634 .632 r
.61682 .73571 m .61923 .73303 L .61697 .733 L F
.61682 .73571 m .61906 .73624 L .61923 .73303 L F
.959 .679 .462 r
.60511 .72172 m .60529 .72411 L .6065 .72243 L F
.839 .474 .364 r
.60529 .72411 m .60731 .72459 L .6065 .72243 L F
.681 .659 .822 r
.71851 .50839 m .71656 .50971 L .71524 .50772 L F
.388 .369 .717 r
.75652 .60009 m .75891 .60196 L .75807 .59984 L F
.831 .702 .722 r
.53232 .73304 m .52846 .73244 L .52956 .73011 L F
.83 .538 .495 r
.53232 .73304 m .52908 .73516 L .52846 .73244 L F
.592 .793 .976 r
.53232 .73304 m .53438 .73301 L .53264 .7327 L F
.369 .093 .357 r
.43109 .69644 m .43011 .69391 L .43215 .69378 L F
.43109 .69644 m .42928 .69707 L .43011 .69391 L F
.677 .47 .598 r
.53909 .73172 m .5364 .73376 L .53438 .73301 L F
.599 .479 .687 r
.59311 .72773 m .5908 .73033 L .5906 .7281 L F
.97 .933 .653 r
.62295 .4992 m .62278 .49886 L .62414 .49827 L F
.961 .944 .666 r
.62414 .49827 m .62374 .49696 L .62636 .4976 L F
.62414 .49827 m .62278 .49886 L .62374 .49696 L F
0 0 .311 r
.57439 .75942 m .57384 .75852 L .57489 .7573 L F
.57439 .75942 m .57445 .76087 L .57384 .75852 L F
.804 .538 .535 r
.6278 .50482 m .63097 .50329 L .62787 .50233 L F
.6278 .50482 m .63096 .50544 L .63097 .50329 L F
.602 .437 .63 r
.63315 .50023 m .63097 .50329 L .63308 .50286 L F
.985 .754 .508 r
.48371 .78861 m .48461 .78602 L .48315 .7857 L F
0 0 0 r
.48614 .78488 m .48714 .78345 L .48461 .78602 L F
.107 .454 .885 r
.49334 .75906 m .49684 .76163 L .49556 .75867 L F
.259 .39 .806 r
.49556 .75867 m .49684 .76163 L .49773 .76035 L F
.622 .481 .669 r
.49684 .76163 m .49916 .76099 L .49773 .76035 L F
.49684 .76163 m .49776 .76284 L .49916 .76099 L F
.749 .873 .937 r
.74317 .62016 m .74618 .61999 L .74512 .61891 L F
.715 .845 .944 r
.74512 .61891 m .74618 .61999 L .74852 .61876 L F
.962 .909 .718 r
.6528 .50918 m .65109 .50955 L .6523 .50698 L F
.475 .314 .582 r
.35189 .66658 m .35377 .66605 L .35377 .66388 L F
.532 .411 .661 r
.35201 .66991 m .35377 .66605 L .35189 .66658 L F
.771 .723 .807 r
.7346 .61034 m .73578 .61192 L .73299 .61154 L F
.771 .746 .83 r
.73578 .61192 m .73128 .6139 L .73299 .61154 L F
.673 .697 .864 r
.73718 .60881 m .73578 .61192 L .7346 .61034 L F
.73718 .60881 m .73811 .61111 L .73578 .61192 L F
.1 0 0 r
.66216 .54178 m .65872 .54309 L .66012 .54143 L F
.873 .601 .523 r
.55346 .70735 m .55596 .7058 L .55296 .70509 L F
.55346 .70735 m .55607 .70838 L .55596 .7058 L F
.807 .547 .545 r
.55596 .7058 m .55607 .70838 L .55749 .70782 L F
.513 .471 .747 r
.38084 .68582 m .37926 .68899 L .3789 .68607 L F
.38084 .68582 m .38096 .68876 L .37926 .68899 L F
.527 .393 .641 r
.38207 .69173 m .37926 .68899 L .38096 .68876 L F
.38207 .69173 m .37982 .692 L .37926 .68899 L F
.573 .295 .456 r
.46639 .6754 m .46604 .67732 L .46372 .67734 L F
.582 .303 .459 r
.46639 .6754 m .46838 .67716 L .46604 .67732 L F
.494 .315 .567 r
.46844 .67475 m .46838 .67716 L .46639 .6754 L F
.458 .482 .796 r
.46594 .66611 m .46516 .66955 L .46422 .66749 L F
.46594 .66611 m .46689 .66915 L .46516 .66955 L F
.415 .301 .615 r
.46689 .66915 m .46713 .67154 L .46516 .66955 L F
.46689 .66915 m .46713 .67154 L .46516 .66955 L F
.652 .617 .802 r
.68324 .50617 m .68483 .51083 L .68686 .51003 L F
.262 0 0 r
.68483 .51083 m .68668 .51053 L .68686 .51003 L F
.68483 .51083 m .68445 .51109 L .68668 .51053 L F
.201 .73 .784 r
.54191 .7719 m .54374 .77146 L .54462 .77076 L F
.54191 .7719 m .54195 .77184 L .54374 .77146 L F
.503 .376 .64 r
.36113 .72279 m .36289 .7224 L .36201 .71991 L F
.528 .34 .569 r
.76504 .61423 m .76535 .61705 L .76284 .61725 L F
.611 .495 .697 r
.76572 .61922 m .76284 .61725 L .76535 .61705 L F
.76572 .61922 m .76324 .61963 L .76284 .61725 L F
.83 .739 .764 r
.61395 .5334 m .61106 .53302 L .61304 .53023 L F
.837 .717 .731 r
.61395 .5334 m .61214 .53641 L .61106 .53302 L F
.828 .738 .765 r
.61485 .5315 m .61395 .5334 L .61304 .53023 L F
.591 .491 .709 r
.35056 .67499 m .35297 .67474 L .35241 .67212 L F
.478 .365 .647 r
.35127 .6781 m .35297 .67474 L .35056 .67499 L F
.301 0 0 r
.63848 .55083 m .63987 .55175 L .63733 .55175 L F
.63848 .55083 m .64092 .5505 L .63987 .55175 L F
.615 .45 .636 r
.76779 .61378 m .76535 .61705 L .76504 .61423 L F
.565 .694 .927 r
.6613 .51238 m .6572 .51418 L .65976 .51066 L F
.435 .785 .997 r
.54579 .73353 m .54661 .73281 L .5442 .73268 L F
.134 .264 .733 r
.54579 .73353 m .54777 .73541 L .54661 .73281 L F
.435 .785 .997 r
.54579 .73353 m .54661 .73281 L .5442 .73268 L F
.525 .313 .534 r
.54546 .73576 m .54777 .73541 L .54579 .73353 L F
.18 0 .265 r
.50313 .72508 m .50506 .72437 L .50535 .72221 L F
.388 .184 .478 r
.50229 .72749 m .50506 .72437 L .50313 .72508 L F
.62 .192 .209 r
.51598 .74897 m .5194 .74766 L .51599 .74691 L F
.51598 .74897 m .51822 .74927 L .5194 .74766 L F
.663 .243 .237 r
.5194 .74766 m .51822 .74927 L .52159 .7494 L F
.593 .298 .437 r
.5194 .74766 m .52159 .7494 L .52211 .74752 L F
.447 .377 .685 r
.44825 .77791 m .45023 .77777 L .44949 .77439 L F
.45 .432 .747 r
.44825 .77791 m .45117 .78006 L .45023 .77777 L F
.457 .239 .493 r
.3378 .61873 m .3379 .61683 L .34001 .61637 L F
.652 .711 .891 r
.73034 .61727 m .73134 .61926 L .73391 .61871 L F
.703 .627 .768 r
.32328 .85518 m .32667 .85562 L .3244 .85638 L F
.524 .013 0 r
.37488 .71905 m .37333 .71946 L .37123 .7192 L F
.413 0 0 r
.3771 .71936 m .37333 .71946 L .37488 .71905 L F
.908 .935 .565 r
.66947 .50091 m .67067 .49986 L .66957 .49923 L F
.66947 .50091 m .6691 .50338 L .67067 .49986 L F
.872 .95 .859 r
.67197 .49646 m .67067 .49986 L .6728 .49793 L F
.67197 .49646 m .66957 .49923 L .67067 .49986 L F
.374 .009 .211 r
.48908 .73943 m .48822 .7409 L .49116 .739 L F
.536 .709 .951 r
.49201 .75767 m .49334 .75906 L .49445 .75754 L F
.567 .754 .966 r
.49334 .75906 m .49556 .75867 L .49445 .75754 L F
.03 .59 .809 r
.28101 .63947 m .28539 .64011 L .28214 .64041 L F
.28101 .63947 m .28307 .63963 L .28539 .64011 L F
.371 .829 .92 r
.28307 .63963 m .2872 .6393 L .28539 .64011 L F
.677 .532 .681 r
.61695 .55804 m .6134 .55587 L .61748 .55558 L F
.666 .467 .606 r
.6191 .55589 m .61695 .55804 L .61748 .55558 L F
.133 0 0 r
.75151 .58267 m .74911 .58311 L .74955 .58327 L F
.75151 .58267 m .75157 .58229 L .74911 .58311 L F
.435 0 0 r
.38721 .64933 m .38937 .64954 L .39093 .64847 L F
.519 .013 0 r
.39093 .64847 m .38937 .64954 L .39288 .64939 L F
.342 0 0 r
.51147 .76815 m .51516 .76684 L .51225 .7672 L F
.51147 .76815 m .51428 .76817 L .51516 .76684 L F
.772 .297 .11 r
.51428 .76817 m .5175 .76909 L .51516 .76684 L F
.539 .263 .446 r
.69589 .5244 m .69294 .5272 L .69343 .52507 L F
.732 .339 .305 r
.48378 .79681 m .48722 .79723 L .4859 .79902 L F
.719 .322 .296 r
.48722 .79723 m .48936 .79937 L .4859 .79902 L F
.718 .581 .7 r
.52986 .7531 m .52973 .75581 L .52764 .75537 L F
.596 .898 .987 r
.27374 .64017 m .2743 .6389 L .27588 .63958 L F
.27374 .64017 m .27204 .63972 L .2743 .6389 L F
.044 0 .105 r
.61267 .7501 m .61504 .74736 L .61428 .7497 L F
.877 .833 .799 r
.62206 .51451 m .61876 .51633 L .62055 .51321 L F
.62206 .51451 m .62001 .51733 L .61876 .51633 L F
.699 .506 .624 r
.6086 .55792 m .61121 .55859 L .60747 .55842 L F
.512 .316 .552 r
.38034 .67796 m .38015 .68042 L .37797 .68082 L F
.423 .181 .441 r
.38015 .68042 m .37791 .68231 L .37797 .68082 L F
.785 .458 .435 r
.67767 .53076 m .67722 .53297 L .67503 .53024 L F
.301 .018 .305 r
.67932 .53175 m .67767 .53076 L .67992 .5308 L F
.67932 .53175 m .67722 .53297 L .67767 .53076 L F
.76 .657 .748 r
.77329 .61046 m .77009 .61366 L .77072 .61181 L F
.523 .26 .458 r
.42208 .68861 m .42465 .68609 L .42254 .68663 L F
.125 0 0 r
.51669 .77161 m .5152 .77166 L .51308 .77154 L F
.323 0 0 r
.51669 .77161 m .51854 .772 L .5152 .77166 L F
.631 .832 .978 r
.44316 .65139 m .44091 .6521 L .43978 .65104 L F
.498 .462 .747 r
.46267 .66317 m .46173 .66668 L .46075 .6635 L F
.46267 .66317 m .46422 .66749 L .46173 .66668 L F
.158 0 .258 r
.50535 .72221 m .50707 .72173 L .5077 .71919 L F
.348 .124 .426 r
.50506 .72437 m .50707 .72173 L .50535 .72221 L F
.397 .331 .666 r
.35127 .6781 m .35173 .68054 L .35334 .68009 L F
.478 .365 .647 r
.35127 .6781 m .35297 .67766 L .35297 .67474 L F
.469 .338 .619 r
.35127 .6781 m .35334 .68009 L .35297 .67766 L F
.836 .378 0 r
.57206 .72374 m .57282 .72559 L .57176 .7242 L F
.413 0 0 r
.46012 .75245 m .45939 .75272 L .46273 .75275 L F
.869 .921 .86 r
.75545 .6089 m .75191 .61064 L .75455 .60904 L F
.75545 .6089 m .75289 .6115 L .75191 .61064 L F
.59 .94 .783 r
.75688 .60751 m .75545 .6089 L .75455 .60904 L F
.513 0 0 r
.68799 .52167 m .68917 .52113 L .68655 .52037 L F
.68799 .52167 m .68655 .52037 L .688 .51847 L F
.304 0 .078 r
.36277 .65775 m .36388 .656 L .36079 .65784 L F
.237 0 .042 r
.36584 .65539 m .36388 .656 L .36277 .65775 L F
.362 .615 .947 r
.53438 .73301 m .53564 .73238 L .53264 .7327 L F
.53438 .73301 m .5364 .73376 L .53564 .73238 L F
.459 .608 .911 r
.33667 .59796 m .3331 .59568 L .33571 .5962 L F
.396 .559 .898 r
.33746 .59624 m .33667 .59796 L .33571 .5962 L F
.518 .704 .955 r
.33746 .59624 m .33867 .5977 L .33667 .59796 L F
.955 .611 .254 r
.66718 .52646 m .6679 .52526 L .6666 .52431 L F
.66718 .52646 m .66854 .52785 L .6679 .52526 L F
.189 0 0 r
.40636 .70816 m .40248 .7097 L .40419 .70855 L F
.467 .152 .348 r
.44265 .68665 m .44445 .6879 L .44223 .6883 L F
.49 .138 .296 r
.44492 .68644 m .44445 .6879 L .44265 .68665 L F
.286 .749 .949 r
.29092 .65261 m .28941 .65215 L .28742 .65227 L F
.403 .812 .978 r
.29296 .65229 m .28941 .65215 L .29092 .65261 L F
.595 .327 .48 r
.49595 .76899 m .49479 .77226 L .49241 .77204 L F
.881 .647 .579 r
.49608 .77128 m .49595 .76899 L .49688 .76865 L F
.49608 .77128 m .49479 .77226 L .49595 .76899 L F
.325 .805 .752 r
.49149 .78064 m .49131 .78267 L .49242 .78301 L F
0 0 0 r
.49169 .78516 m .49079 .78623 L .49242 .78301 L F
.49169 .78516 m .49242 .78301 L .49131 .78267 L F
.713 .623 .755 r
.49149 .78064 m .49242 .78301 L .49495 .78068 L F
.341 0 .217 r
.56623 .68337 m .56575 .68546 L .56345 .686 L F
0 0 .064 r
.56699 .68422 m .56623 .68337 L .56869 .68238 L F
.56699 .68422 m .56575 .68546 L .56623 .68337 L F
.528 .241 .423 r
.54037 .74672 m .53946 .74957 L .53672 .74979 L F
.553 .265 .433 r
.5426 .7486 m .54037 .74672 L .54196 .74761 L F
.5426 .7486 m .53946 .74957 L .54037 .74672 L F
.811 .675 .714 r
.65611 .51386 m .65446 .51708 L .65757 .51698 L F
0 0 .374 r
.65757 .51698 m .6572 .51602 L .65611 .51386 L F
.77 .496 0 r
.65757 .51698 m .6575 .51745 L .6572 .51602 L F
.65757 .51698 m .65814 .51959 L .6575 .51745 L F
.624 .329 .449 r
.51589 .73079 m .51553 .73309 L .51245 .73246 L F
.558 .339 .538 r
.51796 .73008 m .51553 .73309 L .51589 .73079 L F
.525 .496 .767 r
.54108 .75417 m .54138 .75544 L .54205 .75459 L F
.642 .634 .827 r
.54341 .75589 m .54006 .75497 L .5427 .75487 L F
.54344 .75519 m .5427 .75487 L .54345 .75484 L F
.54341 .75589 m .5427 .75487 L .54344 .75519 L F
.525 .496 .767 r
.54085 .75321 m .54108 .75417 L .54305 .7533 L F
.54108 .75417 m .54205 .75459 L .54305 .7533 L F
.126 0 0 r
.3771 .71936 m .37539 .72064 L .37316 .72111 L F
.06 .232 .728 r
.37316 .72111 m .37216 .72158 L .37123 .7192 L F
.37316 .72111 m .37123 .7192 L .37333 .71946 L F
.807 .747 .796 r
.37038 .71958 m .37308 .72092 L .37297 .71661 L F
.648 .27 .314 r
.37346 .72105 m .37373 .72085 L .37316 .72111 L F
.37506 .72071 m .37375 .72084 L .37346 .72105 L F
.37375 .72084 m .37373 .72085 L .37346 .72105 L F
.37539 .72064 m .37374 .72084 L .37373 .72085 L F
.37539 .72064 m .37373 .72085 L .37506 .72071 L F
.126 0 0 r
.3771 .71936 m .37316 .72111 L .37333 .71946 L F
.664 .624 .8 r
.37398 .72274 m .37379 .7211 L .37368 .72122 L F
.807 .747 .796 r
.37353 .72087 m .37368 .72122 L .37363 .72086 L F
.648 .27 .314 r
.37374 .72084 m .37363 .72086 L .37316 .72111 L F
.37363 .72086 m .37196 .72107 L .37302 .72111 L F
.37363 .72086 m .37302 .72111 L .37316 .72111 L F
.127 .238 .71 r
.37297 .71661 m .37363 .72086 L .3748 .71857 L F
.807 .747 .796 r
.37315 .72095 m .37368 .72122 L .37353 .72087 L F
.06 .232 .728 r
.37316 .72111 m .37265 .72283 L .37216 .72158 L F
.713 .934 .961 r
.37316 .72111 m .36876 .72289 L .37265 .72283 L F
.735 .914 .955 r
.36979 .72171 m .37316 .72111 L .37196 .72107 L F
.36979 .72171 m .36876 .72289 L .37316 .72111 L F
.681 .229 .172 r
.37196 .72107 m .37398 .72274 L .37368 .72122 L F
.648 .27 .314 r
.37364 .72086 m .37398 .72274 L .3721 .72118 L F
.37376 .72084 m .37378 .72099 L .37364 .72086 L F
.127 .238 .71 r
.37363 .72086 m .37368 .72122 L .37378 .72099 L F
.37363 .72086 m .37378 .72099 L .37363 .72086 L F
.648 .27 .314 r
.37378 .72099 m .37398 .72274 L .37364 .72086 L F
.37539 .72064 m .37398 .72274 L .37376 .72084 L F
.127 .238 .71 r
.37363 .72086 m .37378 .72099 L .37388 .72076 L F
.37363 .72086 m .37388 .72076 L .3748 .71857 L F
.648 .27 .314 r
.37353 .72087 m .37315 .72095 L .37196 .72107 L F
.681 .229 .172 r
.37196 .72107 m .37368 .72122 L .37315 .72095 L F
.648 .27 .314 r
.37315 .72095 m .3721 .72118 L .37196 .72107 L F
.681 .229 .172 r
.37196 .72107 m .37315 .72095 L .37038 .71958 L F
.807 .747 .796 r
.37308 .72092 m .37315 .72095 L .37353 .72087 L F
.648 .27 .314 r
.37376 .72084 m .3721 .72118 L .37353 .72087 L F
.664 .624 .8 r
.37398 .72274 m .37445 .72036 L .37379 .7211 L F
.37445 .72036 m .3748 .71857 L .37388 .72076 L F
.37445 .72036 m .37388 .72076 L .37368 .72122 L F
.807 .747 .796 r
.37308 .72092 m .37363 .72086 L .37297 .71661 L F
.5 .426 .705 r
.43905 .6694 m .4409 .66659 L .43799 .6661 L F
.43905 .6694 m .441 .66908 L .4409 .66659 L F
.587 .473 .69 r
.43905 .6694 m .44183 .67177 L .441 .66908 L F
.43905 .6694 m .43961 .67217 L .44183 .67177 L F
.976 .751 .531 r
.3487 .70855 m .34947 .70939 L .34829 .71069 L F
.654 .785 .944 r
.3487 .70855 m .34947 .70939 L .35214 .7085 L F
.59 .365 .543 r
.71369 .5976 m .71322 .59549 L .71178 .59487 L F
.7116 .5951 m .71178 .59487 L .71118 .59461 L F
.71369 .5976 m .71178 .59487 L .7116 .5951 L F
.713 .921 .579 r
.71416 .59224 m .71198 .59512 L .71297 .59335 L F
.71317 .5931 m .71297 .59335 L .71306 .5932 L F
.71416 .59224 m .71297 .59335 L .71317 .5931 L F
.685 .913 .973 r
.71306 .5932 m .71198 .59512 L .71091 .59439 L F
.769 .638 .715 r
.71423 .58974 m .71416 .59224 L .71057 .59157 L F
.713 .921 .579 r
.71416 .59224 m .71306 .5932 L .71057 .59157 L F
.697 .577 .716 r
.7161 .58919 m .71416 .59224 L .71423 .58974 L F
.723 .901 .959 r
.75191 .61064 m .75289 .6115 L .74936 .61281 L F
.65 .368 .479 r
.52973 .75581 m .52739 .75771 L .52764 .75537 L F
.52973 .75581 m .52983 .75778 L .52739 .75771 L F
.337 .519 .888 r
.67224 .48448 m .6716 .4864 L .66887 .48393 L F
.67224 .48448 m .67249 .48595 L .6716 .4864 L F
.547 .378 .604 r
.56078 .68606 m .56127 .68912 L .55847 .68919 L F
.417 .174 .436 r
.56046 .69046 m .55847 .68919 L .56127 .68912 L F
.56046 .69046 m .55849 .6912 L .55847 .68919 L F
.656 .36 .459 r
.5057 .73613 m .50787 .73828 L .50482 .73831 L F
.625 .365 .503 r
.50799 .73614 m .50787 .73828 L .5057 .73613 L F
.607 .312 .443 r
.45588 .68062 m .45501 .68334 L .45255 .68311 L F
.574 .28 .43 r
.458 .6824 m .45588 .68062 L .45809 .68028 L F
.458 .6824 m .45501 .68334 L .45588 .68062 L F
.522 .026 .02 r
.52538 .77239 m .52768 .77244 L .5257 .77341 L F
0 0 0 r
.5257 .77341 m .52768 .77244 L .52994 .77136 L F
.592 .243 .347 r
.52538 .77239 m .52427 .7744 L .52203 .7742 L F
.522 .026 .02 r
.52538 .77239 m .5257 .77341 L .52427 .7744 L F
0 .044 .599 r
.59228 .69389 m .591 .69011 L .59323 .69154 L F
0 0 .035 r
.61428 .7497 m .61504 .74736 L .61662 .74632 L F
.512 .765 .988 r
.28214 .64041 m .27945 .64001 L .28101 .63947 L F
.771 .747 .832 r
.48878 .76989 m .48685 .77186 L .49031 .77192 L F
.361 .697 .983 r
.49031 .77192 m .49137 .77097 L .48878 .76989 L F
.49031 .77192 m .49241 .77204 L .49137 .77097 L F
.409 .742 .993 r
.30245 .60339 m .30568 .60429 L .30437 .60315 L F
.395 .518 .864 r
.30874 .60441 m .31026 .60369 L .30957 .60445 L F
.30874 .60441 m .30882 .60443 L .31026 .60369 L F
.30882 .60443 m .30888 .60443 L .31026 .60369 L F
.319 .678 .977 r
.30437 .60315 m .30936 .6044 L .3054 .60197 L F
.30936 .6044 m .30957 .60445 L .30947 .60439 L F
.395 .518 .864 r
.30885 .60444 m .30947 .60438 L .31026 .60369 L F
.529 .764 .983 r
.30947 .60439 m .30957 .60445 L .31026 .60369 L F
.395 .518 .864 r
.30947 .60438 m .3102 .60432 L .31026 .60369 L F
.529 .764 .983 r
.3054 .60197 m .30947 .60439 L .31026 .60369 L F
.319 .678 .977 r
.30936 .6044 m .30947 .60439 L .3054 .60197 L F
.395 .518 .864 r
.30882 .60443 m .30885 .60444 L .30888 .60443 L F
0 .57 .735 r
.30903 .60443 m .30957 .60445 L .30936 .6044 L F
.395 .518 .864 r
.30885 .60444 m .31015 .60475 L .3102 .60432 L F
0 .57 .735 r
.30568 .60429 m .30903 .60443 L .30437 .60315 L F
.30903 .60443 m .30936 .6044 L .30437 .60315 L F
.30568 .60429 m .30874 .60441 L .30957 .60445 L F
.891 .857 .802 r
.69597 .5159 m .69398 .51859 L .69377 .51615 L F
.968 .721 .51 r
.66075 .49786 m .6598 .49653 L .66103 .49761 L F
.872 .812 .788 r
.61934 .51902 m .61876 .51633 L .62001 .51733 L F
.61934 .51902 m .61674 .51925 L .61876 .51633 L F
.873 .806 .78 r
.61934 .51902 m .6173 .52228 L .61674 .51925 L F
.236 .054 .419 r
.6398 .5191 m .63818 .52264 L .63987 .52133 L F
.232 0 .073 r
.6398 .5191 m .6421 .51884 L .64255 .51754 L F
.363 .09 .358 r
.6398 .5191 m .64158 .52061 L .6421 .51884 L F
.6398 .5191 m .63987 .52133 L .64158 .52061 L F
.989 .784 .535 r
.66504 .52127 m .66643 .51987 L .66546 .51888 L F
.66504 .52127 m .66613 .52228 L .66643 .51987 L F
0 0 .252 r
.56322 .78211 m .56218 .78323 L .56306 .78135 L F
.56322 .78211 m .56218 .78323 L .56306 .78135 L F
.507 .434 .71 r
.36227 .71641 m .36201 .71991 L .36499 .71896 L F
.366 .298 .648 r
.36201 .71991 m .365 .72073 L .36499 .71896 L F
.36201 .71991 m .36289 .7224 L .365 .72073 L F
.557 .555 .807 r
.68225 .49063 m .68122 .4947 L .68023 .49134 L F
.68225 .49063 m .68329 .49402 L .68122 .4947 L F
.701 .63 .774 r
.68329 .49402 m .68201 .49783 L .68122 .4947 L F
0 .437 .789 r
.71152 .60508 m .71401 .60615 L .7131 .60561 L F
.282 .62 .959 r
.71401 .60615 m .71534 .60542 L .7131 .60561 L F
.71401 .60615 m .71699 .60677 L .71534 .60542 L F
0 0 0 r
.55752 .78889 m .55423 .78951 L .55681 .78875 L F
.319 0 .006 r
.55395 .7909 m .55752 .78889 L .55681 .78875 L F
.555 .761 .973 r
.67854 .48882 m .67717 .49036 L .67606 .48908 L F
.67854 .48882 m .67931 .48976 L .67717 .49036 L F
.575 .564 .804 r
.68023 .49134 m .67717 .49036 L .67931 .48976 L F
.479 .245 .482 r
.33116 .62557 m .3326 .62956 L .33047 .62987 L F
.398 .209 .505 r
.3348 .62623 m .33116 .62557 L .33248 .62496 L F
.466 .284 .549 r
.3348 .62623 m .3326 .62956 L .33116 .62557 L F
.814 .671 .706 r
.68312 .53158 m .6802 .53305 L .68243 .53133 L F
.68312 .53158 m .68138 .53367 L .6802 .53305 L F
.57 .817 .991 r
.68506 .53013 m .68312 .53158 L .68243 .53133 L F
.68506 .53013 m .68615 .53125 L .68312 .53158 L F
.853 .401 .113 r
.59018 .75276 m .58876 .75239 L .58742 .75009 L F
.421 .837 .967 r
.59132 .75189 m .58876 .75239 L .59018 .75276 L F
.723 .901 .959 r
.75191 .61064 m .74936 .61281 L .74996 .61189 L F
.419 .055 .238 r
.47526 .7469 m .47745 .74653 L .47845 .74438 L F
.435 .071 .246 r
.47845 .74438 m .47965 .74616 L .48072 .74416 L F
.47845 .74438 m .47745 .74653 L .47965 .74616 L F
0 .07 .573 r
.46176 .78938 m .46289 .79025 L .46042 .789 L F
.46176 .78938 m .46399 .79139 L .46289 .79025 L F
.979 .72 .316 r
.67869 .51609 m .67953 .51889 L .67968 .5178 L F
.411 .232 .526 r
.38195 .67974 m .38034 .67796 L .38192 .67732 L F
.38195 .67974 m .38015 .68042 L .38034 .67796 L F
.976 .688 .298 r
.66794 .51374 m .66686 .51026 L .66717 .51147 L F
.367 .123 .407 r
.25836 .62261 m .25785 .62447 L .25591 .62523 L F
.378 .223 .542 r
.25785 .62447 m .25596 .6277 L .25591 .62523 L F
.525 .48 .748 r
.31852 .60864 m .31912 .61159 L .32131 .61064 L F
.385 .235 .552 r
.31926 .61391 m .32131 .61064 L .31912 .61159 L F
.416 .141 .386 r
.30532 .63047 m .30339 .63098 L .30285 .63291 L F
.591 .225 .317 r
.54687 .73979 m .54886 .7411 L .54668 .74084 L F
.51 .289 .515 r
.54915 .73873 m .54886 .7411 L .54687 .73979 L F
.973 .755 .548 r
.34552 .71895 m .34523 .72017 L .34516 .71672 L F
.975 .708 .461 r
.34523 .72017 m .34485 .72159 L .3436 .72056 L F
.82 .776 .269 r
.34552 .71895 m .34485 .72159 L .34523 .72017 L F
.669 .373 .463 r
.34764 .72127 m .34552 .71895 L .34834 .71905 L F
.34764 .72127 m .34485 .72159 L .34552 .71895 L F
.709 .546 .666 r
.76365 .622 m .76097 .62228 L .76324 .61963 L F
.467 .294 .562 r
.76572 .61922 m .76365 .622 L .76324 .61963 L F
.809 .734 .782 r
.70656 .50488 m .7098 .50566 L .70831 .50324 L F
.501 0 0 r
.70656 .50488 m .7099 .50631 L .7098 .50566 L F
.461 0 .043 r
.7099 .50631 m .71185 .50553 L .7098 .50566 L F
.041 .186 .689 r
.57941 .73551 m .57848 .73229 L .57762 .73319 L F
0 .005 .574 r
.58003 .73689 m .57941 .73551 L .57762 .73319 L F
.299 .761 .948 r
.27277 .58642 m .27488 .58624 L .27634 .58668 L F
.492 .81 1 r
.27488 .58624 m .27836 .58661 L .27634 .58668 L F
.223 0 .032 r
.30993 .64684 m .30838 .64883 L .30645 .64945 L F
.242 0 .045 r
.31047 .64812 m .30993 .64684 L .3116 .64643 L F
.31047 .64812 m .30838 .64883 L .30993 .64684 L F
.659 .722 .896 r
.60473 .754 m .60722 .75312 L .6036 .7522 L F
.307 .169 .524 r
.72109 .508 m .71891 .51146 L .71851 .50839 L F
.72109 .508 m .72122 .51023 L .71891 .51146 L F
.447 .359 .663 r
.7211 .51205 m .71891 .51146 L .72122 .51023 L F
.7211 .51205 m .71961 .5138 L .71891 .51146 L F
.182 0 0 r
.39856 .66788 m .39791 .66683 L .4 .66629 L F
.39856 .66788 m .39652 .66852 L .39791 .66683 L F
.769 .638 .715 r
.71423 .58974 m .71057 .59157 L .7128 .58839 L F
.712 .639 .775 r
.7161 .58919 m .71423 .58974 L .7128 .58839 L F
0 0 0 r
.52124 .80175 m .5225 .79994 L .52022 .80233 L F
.859 .517 .404 r
.52124 .80175 m .52393 .80185 L .5225 .79994 L F
.667 .357 .438 r
.52184 .75817 m .52124 .75854 L .5197 .75813 L F
0 .007 .582 r
.58167 .7418 m .58307 .74301 L .58161 .74036 L F
.58167 .7418 m .58335 .7441 L .58307 .74301 L F
.229 .233 .656 r
.58246 .74418 m .58335 .7441 L .58167 .7418 L F
.906 .856 .781 r
.32712 .72806 m .32847 .72677 L .32879 .72709 L F
.32712 .72806 m .32847 .72677 L .32879 .72709 L F
0 0 .263 r
.32929 .72486 m .32879 .72709 L .32847 .72677 L F
.724 .384 .403 r
.52599 .80534 m .52934 .80552 L .52832 .80799 L F
.542 .224 .377 r
.52934 .80552 m .53142 .80729 L .52832 .80799 L F
.52934 .80552 m .53171 .80519 L .53142 .80729 L F
0 0 0 r
.52934 .80552 m .53157 .80271 L .53171 .80519 L F
.448 .223 .479 r
.71689 .51847 m .71458 .51653 L .71685 .516 L F
.71689 .51847 m .71468 .51931 L .71458 .51653 L F
.899 .984 .787 r
.6193 .74158 m .61684 .74372 L .6171 .74444 L F
.106 0 0 r
.63191 .52405 m .63193 .52387 L .62958 .52382 L F
.236 0 0 r
.63191 .52405 m .6347 .52457 L .63193 .52387 L F
.683 .537 .681 r
.6134 .55587 m .61329 .55861 L .61121 .55859 L F
.677 .532 .681 r
.61695 .55804 m .61329 .55861 L .6134 .55587 L F
.148 0 0 r
.38298 .71742 m .37901 .71856 L .38024 .71842 L F
.36 .782 .975 r
.31911 .59328 m .31848 .59404 L .31706 .59337 L F
.31911 .59328 m .32063 .59383 L .31848 .59404 L F
.682 .76 .911 r
.73945 .61963 m .74041 .62163 L .74317 .62016 L F
.7 .844 .951 r
.45512 .78613 m .45862 .78609 L .45749 .78526 L F
.071 .031 .501 r
.45862 .78609 m .45892 .78808 L .4602 .78749 L F
.45862 .78609 m .4602 .78749 L .45749 .78526 L F
.178 .169 .609 r
.46842 .77389 m .4664 .77291 L .46839 .77134 L F
.46842 .77389 m .46706 .77553 L .4664 .77291 L F
.832 .839 .851 r
.48947 .78138 m .48714 .78345 L .48571 .78256 L F
.48947 .78138 m .48571 .78256 L .48806 .78189 L F
.619 .074 0 r
.48806 .78189 m .49131 .78267 L .48947 .78138 L F
.325 .805 .752 r
.49149 .78064 m .48947 .78138 L .49131 .78267 L F
0 0 .006 r
.54158 .70287 m .54308 .70011 L .54377 .69986 L F
.54158 .70287 m .54263 .70199 L .54308 .70011 L F
.805 .4 .283 r
.54521 .70547 m .54344 .70535 L .54158 .70287 L F
0 0 .545 r
.54158 .70287 m .54276 .70399 L .54263 .70199 L F
.54158 .70287 m .54344 .70535 L .54276 .70399 L F
.642 .754 .93 r
.56336 .78004 m .56467 .78135 L .56306 .78135 L F
0 0 .219 r
.56306 .78135 m .56322 .78211 L .56336 .78004 L F
.669 .722 .889 r
.6728 .49793 m .67636 .49957 L .67503 .49701 L F
.931 .667 .515 r
.551 .70149 m .55296 .70509 L .55263 .70314 L F
.788 .529 .545 r
.55644 .77401 m .55342 .77155 L .55354 .77302 L F
.55644 .77401 m .55518 .77409 L .55342 .77155 L F
.018 .234 .74 r
.55215 .76972 m .55354 .77302 L .55342 .77155 L F
.788 .529 .545 r
.55518 .77409 m .55307 .77423 L .55342 .77155 L F
.018 .234 .74 r
.55202 .76943 m .55215 .76972 L .55342 .77155 L F
0 0 0 r
.55097 .79102 m .55115 .79026 L .54994 .79123 L F
.084 .525 .904 r
.55097 .79102 m .55187 .79202 L .55052 .79147 L F
.535 .899 .969 r
.55333 .79017 m .55097 .79102 L .55161 .79004 L F
.691 .292 .286 r
.55097 .79102 m .5529 .79303 L .55041 .79344 L F
0 0 .004 r
.55142 .79057 m .55097 .79102 L .55041 .79344 L F
.55161 .79004 m .55097 .79102 L .55142 .79057 L F
.084 .525 .904 r
.55097 .79102 m .55052 .79147 L .54994 .79123 L F
.654 .391 .509 r
.59525 .55511 m .59228 .55326 L .59263 .55566 L F
.59525 .55511 m .59488 .55299 L .59228 .55326 L F
.48 .334 .605 r
.45254 .75835 m .45444 .75792 L .4544 .75539 L F
.474 .316 .585 r
.45254 .75835 m .45453 .76036 L .45444 .75792 L F
.457 .314 .598 r
.45266 .76081 m .45453 .76036 L .45254 .75835 L F
.773 .698 .781 r
.70377 .50371 m .70016 .50541 L .7025 .50256 L F
0 0 0 r
.70979 .52062 m .70864 .5211 L .7063 .52149 L F
.12 0 0 r
.71173 .52069 m .70864 .5211 L .70979 .52062 L F
.954 .803 .656 r
.60088 .6939 m .60289 .69184 L .60105 .69127 L F
.60088 .6939 m .60225 .69435 L .60289 .69184 L F
.685 .71 .867 r
.68668 .51053 m .69036 .51158 L .68895 .50897 L F
.442 .432 .753 r
.68668 .51053 m .6903 .51451 L .69036 .51158 L F
.522 .604 .876 r
.69036 .51158 m .69173 .509 L .68895 .50897 L F
.69036 .51158 m .6926 .51095 L .69173 .509 L F
.409 .156 .416 r
.69036 .51158 m .69267 .51327 L .6926 .51095 L F
.69036 .51158 m .6903 .51451 L .69267 .51327 L F
.604 .627 .847 r
.72317 .59689 m .72082 .59745 L .71937 .59472 L F
.951 .71 .539 r
.48571 .78256 m .48714 .78345 L .48614 .78488 L F
.392 .227 .535 r
.31033 .62237 m .31201 .62177 L .31216 .6194 L F
.393 .253 .569 r
.3104 .62467 m .31201 .62177 L .31033 .62237 L F
0 .044 .534 r
.54393 .72368 m .54294 .72281 L .54172 .72184 L F
.54393 .72368 m .54504 .72473 L .54294 .72281 L F
.665 .271 .288 r
.52302 .76848 m .52632 .76717 L .52308 .76627 L F
.52302 .76848 m .52553 .76878 L .52632 .76717 L F
.623 .224 .267 r
.52632 .76717 m .52553 .76878 L .52873 .76856 L F
.585 .437 .646 r
.43766 .67767 m .43969 .67496 L .43743 .67533 L F
.084 0 0 r
.24661 .58834 m .24853 .588 L .25044 .587 L F
.402 0 .021 r
.24853 .588 m .25244 .58641 L .25044 .587 L F
.148 0 0 r
.38298 .71742 m .38115 .71832 L .37901 .71856 L F
.384 0 .033 r
.38488 .71654 m .38115 .71832 L .38298 .71742 L F
.471 .559 .864 r
.45157 .78367 m .45307 .78685 L .45436 .78499 L F
.612 .757 .948 r
.45436 .78499 m .45307 .78685 L .45512 .78613 L F
.684 .388 .466 r
.61121 .55859 m .61359 .56092 L .6116 .56059 L F
.662 .393 .502 r
.61329 .55861 m .61359 .56092 L .61121 .55859 L F
.666 .376 .471 r
.61121 .55859 m .60776 .56062 L .60747 .55842 L F
.61121 .55859 m .6116 .56059 L .60776 .56062 L F
.629 .749 .934 r
.56336 .78004 m .56672 .78038 L .56467 .78135 L F
.542 .815 .997 r
.27992 .6387 m .27945 .64001 L .27772 .63893 L F
.27992 .6387 m .28101 .63947 L .27945 .64001 L F
.236 .385 .81 r
.47396 .76719 m .47525 .76969 L .47627 .76866 L F
.449 .732 .987 r
.47525 .76969 m .47763 .76974 L .47627 .76866 L F
0 0 0 r
.2872 .6393 m .28931 .63894 L .2906 .63863 L F
.177 .713 .77 r
.28931 .63894 m .29272 .63848 L .2906 .63863 L F
.712 .639 .775 r
.7161 .58919 m .7128 .58839 L .71337 .5881 L F
.71364 .58812 m .71337 .5881 L .71348 .58805 L F
.7161 .58919 m .71337 .5881 L .71364 .58812 L F
.609 .416 .595 r
.714 .58731 m .71453 .58819 L .71674 .58733 L F
.712 .639 .775 r
.7161 .58919 m .71348 .58805 L .71508 .58827 L F
.824 .619 .625 r
.71674 .58733 m .71838 .58871 L .7161 .58919 L F
.485 .391 .673 r
.71838 .58871 m .71661 .59106 L .7161 .58919 L F
.609 .416 .595 r
.71453 .58819 m .71619 .59092 L .71658 .58836 L F
.754 .886 .939 r
.71674 .58733 m .7161 .58919 L .71504 .58823 L F
.609 .416 .595 r
.71453 .58819 m .71504 .58823 L .71674 .58733 L F
.754 .886 .939 r
.71674 .58733 m .71504 .58823 L .71434 .58761 L F
.609 .416 .595 r
.71504 .58823 m .71658 .58836 L .71674 .58733 L F
.925 .96 .781 r
.7128 .58839 m .71057 .59157 L .71095 .58979 L F
.66 .432 .563 r
.71095 .58979 m .71619 .59092 L .71453 .58819 L F
.71348 .58805 m .71453 .58819 L .714 .58731 L F
0 0 0 r
.714 .58731 m .71434 .58761 L .71348 .58805 L F
.714 .58731 m .71348 .58805 L .7128 .58839 L F
.66 .432 .563 r
.71314 .588 m .71348 .58805 L .714 .58731 L F
.71095 .58979 m .71453 .58819 L .71314 .588 L F
.712 .639 .775 r
.71508 .58827 m .71348 .58805 L .71434 .58761 L F
.184 0 0 r
.63818 .52264 m .6347 .52457 L .63668 .52436 L F
0 0 0 r
.63987 .52133 m .63818 .52264 L .63668 .52436 L F
0 .093 .647 r
.58003 .73689 m .58116 .73822 L .57941 .73551 L F
.477 .061 .172 r
.40819 .69614 m .41183 .69419 L .40972 .69467 L F
.456 .876 .761 r
.53157 .80271 m .52819 .80429 L .53033 .80419 L F
.55 .408 .64 r
.53407 .80481 m .53157 .80271 L .53414 .80235 L F
.53407 .80481 m .53171 .80519 L .53157 .80271 L F
.243 0 0 r
.53414 .80235 m .53157 .80271 L .53033 .80419 L F
.581 .574 .81 r
.35577 .71128 m .3589 .71377 L .35648 .71066 L F
.588 .173 .222 r
.5172 .76359 m .51619 .76538 L .51359 .76401 L F
.526 .348 .583 r
.52124 .75854 m .51906 .76337 L .5172 .76359 L F
.432 .029 .172 r
.51906 .76337 m .51619 .76538 L .5172 .76359 L F
.576 .268 .409 r
.52356 .8055 m .52646 .80712 L .52253 .80706 L F
.52356 .8055 m .52599 .80534 L .52646 .80712 L F
0 0 0 r
.52462 .80428 m .52356 .8055 L .52253 .80706 L F
.611 .603 .819 r
.69502 .50567 m .69126 .50281 L .69415 .50275 L F
.59 .575 .805 r
.6969 .50322 m .69502 .50567 L .69415 .50275 L F
.629 .633 .835 r
.6969 .50322 m .69822 .50619 L .69502 .50567 L F
.848 .651 .636 r
.34516 .71672 m .34164 .7185 L .34419 .71627 L F
.34516 .71672 m .34523 .72017 L .34164 .7185 L F
.941 .939 .763 r
.34516 .71672 m .34419 .71627 L .34594 .71315 L F
.402 .031 .216 r
.45723 .75318 m .45893 .7539 L .45939 .75272 L F
.45723 .75318 m .45662 .75449 L .45893 .7539 L F
.213 0 .069 r
.50707 .72173 m .50998 .71921 L .5077 .71919 L F
.614 .613 .826 r
.45905 .65828 m .45687 .65893 L .45552 .65596 L F
.441 .634 .937 r
.33364 .59398 m .3331 .59568 L .33183 .59433 L F
.33364 .59398 m .33571 .5962 L .3331 .59568 L F
.492 .356 .624 r
.451 .76594 m .45273 .76325 L .45081 .76398 L F
.826 .758 .788 r
.43068 .66265 m .43418 .66123 L .43214 .66202 L F
.43068 .66265 m .43194 .66415 L .43418 .66123 L F
.654 .498 .66 r
.43418 .66123 m .43194 .66415 L .43425 .66329 L F
.092 .476 .894 r
.43418 .66123 m .43492 .66063 L .43214 .66202 L F
.43418 .66123 m .43593 .66182 L .43492 .66063 L F
.593 .586 .813 r
.43425 .66329 m .43593 .66182 L .43418 .66123 L F
.54 .106 .165 r
.54014 .76273 m .53699 .76363 L .53881 .76282 L F
.595 .719 .931 r
.54104 .76025 m .54014 .76273 L .53881 .76282 L F
.54104 .76025 m .5429 .76247 L .54014 .76273 L F
.666 .467 .606 r
.6191 .55589 m .61917 .55835 L .61695 .55804 L F
.872 .801 .777 r
.54789 .69718 m .54733 .69489 L .54811 .69398 L F
.54789 .69718 m .54557 .69659 L .54728 .69468 L F
0 0 .127 r
.54794 .69711 m .54781 .69477 L .54716 .69674 L F
.58 .395 .596 r
.54501 .69867 m .54557 .69659 L .54789 .69718 L F
0 0 .127 r
.54708 .69764 m .54716 .69674 L .54681 .6978 L F
.243 .176 .578 r
.54781 .69477 m .54785 .69758 L .5506 .69686 L F
.54785 .69758 m .54789 .70004 L .54989 .6977 L F
.54785 .69758 m .54989 .6977 L .5506 .69686 L F
0 0 .127 r
.54794 .69711 m .54789 .70004 L .54785 .69758 L F
.54794 .69711 m .54785 .69758 L .54781 .69477 L F
.54794 .69711 m .54716 .69674 L .54708 .69764 L F
.837 .73 .746 r
.54557 .69659 m .54681 .6978 L .54728 .69468 L F
.872 .801 .777 r
.54733 .69489 m .54728 .69468 L .54735 .69462 L F
0 0 .42 r
.54728 .69468 m .54681 .6978 L .54781 .69477 L F
.386 .201 .504 r
.54557 .69659 m .54794 .69711 L .54723 .69754 L F
.5465 .6975 m .54723 .69754 L .54681 .6978 L F
.54557 .69659 m .54723 .69754 L .5465 .6975 L F
.872 .801 .777 r
.54733 .69489 m .54735 .69462 L .54811 .69398 L F
.031 0 0 r
.54811 .69398 m .54944 .69397 L .55089 .69204 L F
.021 0 0 r
.54811 .69398 m .54728 .69468 L .54944 .69397 L F
.485 .391 .673 r
.71838 .58871 m .71916 .59102 L .71661 .59106 L F
.538 .28 .473 r
.53435 .76584 m .53699 .76363 L .53472 .76416 L F
.646 .747 .923 r
.74849 .61025 m .74672 .61286 L .74612 .6107 L F
.74849 .61025 m .74996 .61189 L .74672 .61286 L F
.899 .984 .787 r
.6193 .74158 m .61843 .74149 L .61684 .74372 L F
.157 .255 .716 r
.61872 .73843 m .62057 .7406 L .6193 .74158 L F
.493 .903 .9 r
.6193 .74158 m .62057 .7406 L .61843 .74149 L F
.253 0 .147 r
.68506 .53013 m .68243 .53133 L .68416 .52937 L F
.429 0 0 r
.55607 .70838 m .55543 .7093 L .55749 .70782 L F
.392 0 0 r
.55543 .7093 m .55977 .70882 L .55749 .70782 L F
.357 0 0 r
.54504 .72473 m .54898 .72595 L .54632 .72558 L F
.116 0 .289 r
.58637 .70836 m .5876 .70772 L .58821 .70546 L F
.566 .243 .38 r
.58483 .70994 m .58637 .70836 L .58673 .70868 L F
.58483 .70994 m .5876 .70772 L .58637 .70836 L F
.874 .806 .78 r
.6173 .52228 m .61444 .52233 L .61674 .51925 L F
.907 .833 .761 r
.6173 .52228 m .6142 .52426 L .61444 .52233 L F
.6173 .52228 m .61528 .52537 L .6142 .52426 L F
.234 0 0 r
.41419 .70516 m .41056 .70707 L .41212 .70576 L F
.582 .344 .52 r
.49201 .75767 m .48977 .7583 L .4888 .75775 L F
.626 .336 .457 r
.55636 .69181 m .55347 .69385 L .55339 .69357 L F
.694 .366 0 r
.55245 .69112 m .55347 .69385 L .55339 .69357 L F
.311 .744 .97 r
.42253 .65007 m .42466 .65 L .42606 .65061 L F
.194 0 0 r
.42466 .65 m .42849 .6506 L .42606 .65061 L F
.806 .792 .839 r
.73299 .61154 m .73128 .6139 L .73031 .61414 L F
.463 .32 .601 r
.5632 .68829 m .56078 .68606 L .56345 .686 L F
.5632 .68829 m .56127 .68912 L .56078 .68606 L F
.82 .363 0 r
.67034 .51917 m .67162 .52038 L .67129 .52088 L F
.797 .318 0 r
.67162 .52038 m .673 .52239 L .67129 .52088 L F
.64 .363 .483 r
.51481 .80206 m .51104 .80489 L .51103 .80271 L F
.51481 .80206 m .51349 .80496 L .51104 .80489 L F
.707 .262 .193 r
.51481 .80206 m .51652 .80402 L .51349 .80496 L F
.51481 .80206 m .51687 .80296 L .51652 .80402 L F
.479 .342 .616 r
.47316 .77725 m .47161 .77989 L .4712 .77766 L F
.779 .275 0 r
.57968 .71671 m .58148 .71891 L .58276 .71935 L F
0 .276 .78 r
.58148 .71891 m .58401 .7217 L .58276 .71935 L F
.212 0 0 r
.36982 .65418 m .36806 .6552 L .37015 .65466 L F
.181 0 0 r
.37015 .65466 m .36806 .6552 L .36668 .65664 L F
.37015 .65466 m .36668 .65664 L .36848 .65587 L F
.37015 .65466 m .36848 .65587 L .36867 .65339 L F
.239 0 0 r
.37078 .6556 m .37015 .65466 L .36867 .65339 L F
.37082 .65564 m .37015 .65466 L .37078 .6556 L F
.212 0 0 r
.3717 .65309 m .36982 .65418 L .37015 .65466 L F
.215 0 0 r
.37379 .6526 m .3717 .65309 L .37015 .65466 L F
.349 .594 .937 r
.28602 .58766 m .28546 .5891 L .28434 .58756 L F
.417 .671 .966 r
.28602 .58766 m .28749 .58914 L .28546 .5891 L F
0 0 0 r
.73031 .61414 m .72801 .61662 L .72926 .61574 L F
.297 .583 .941 r
.72801 .61662 m .73034 .61727 L .72926 .61574 L F
.507 .249 .458 r
.30532 .63047 m .3076 .63011 L .308 .62717 L F
.447 .252 .521 r
.308 .62717 m .31022 .62738 L .3104 .62467 L F
.358 .086 .358 r
.3076 .63011 m .31022 .62738 L .308 .62717 L F
.807 .696 .743 r
.60793 .5444 m .60908 .54765 L .60649 .54724 L F
.689 .367 .425 r
.56981 .67828 m .57303 .67746 L .57101 .67848 L F
.625 .452 .629 r
.51245 .73246 m .51049 .73583 L .51035 .73293 L F
.593 .94 .933 r
.26932 .65465 m .26831 .6558 L .2701 .65482 L F
.606 .952 .823 r
.2663 .65642 m .26831 .6558 L .26932 .65465 L F
.855 .429 .211 r
.54841 .70842 m .5468 .70806 L .54521 .70547 L F
.806 .352 .159 r
.54841 .70842 m .54776 .70986 L .5468 .70806 L F
.54841 .70842 m .55051 .7111 L .54776 .70986 L F
.805 .319 .036 r
.55193 .71146 m .55051 .7111 L .54841 .70842 L F
.465 .203 .432 r
.72762 .60266 m .7302 .6004 L .7299 .60234 L F
.36 .115 .4 r
.7299 .60234 m .7302 .6004 L .73221 .59946 L F
.569 .68 .914 r
.2584 .6388 m .26089 .63894 L .25886 .63941 L F
.796 .491 .473 r
.4885 .79095 m .49035 .79364 L .49179 .7912 L F
.733 .412 .436 r
.49035 .79364 m .49379 .79384 L .49179 .7912 L F
.46 .497 .81 r
.70487 .59224 m .70567 .59514 L .70734 .59341 L F
.394 .389 .736 r
.70567 .59514 m .70807 .59649 L .70734 .59341 L F
.70567 .59514 m .70651 .59732 L .70807 .59649 L F
.451 .148 .36 r
.66485 .53956 m .66447 .54123 L .66216 .54178 L F
0 0 .069 r
.66576 .53832 m .66447 .54123 L .66485 .53956 L F
.269 0 .046 r
.74244 .59581 m .74319 .59433 L .74523 .59363 L F
.805 .355 .17 r
.46924 .79144 m .47104 .79169 L .4702 .79312 L F
.622 .133 .07 r
.4702 .79312 m .47104 .79169 L .47366 .79332 L F
.54 0 0 r
.47104 .79169 m .47535 .79347 L .47366 .79332 L F
.419 .836 .967 r
.41246 .6633 m .4101 .66299 L .40792 .66346 L F
.064 .621 .808 r
.41361 .66329 m .4101 .66299 L .41246 .6633 L F
.301 .676 .975 r
.2625 .65608 m .26276 .65501 L .26087 .65636 L F
.2625 .65608 m .26465 .65631 L .26276 .65501 L F
.708 .6 .733 r
.70016 .50541 m .70146 .50872 L .69821 .5084 L F
.821 .563 .55 r
.59677 .68562 m .59856 .68332 L .59679 .68274 L F
.59677 .68562 m .5986 .68548 L .59856 .68332 L F
0 .455 .735 r
.2932 .59012 m .29664 .59104 L .29464 .59059 L F
.564 .57 .818 r
.67539 .51066 m .67307 .51139 L .67228 .50841 L F
.5 .469 .754 r
.38084 .68582 m .3789 .68607 L .37791 .68231 L F
.319 .476 .859 r
.67531 .48733 m .67417 .48883 L .67249 .48595 L F
.384 .57 .911 r
.67531 .48733 m .67606 .48908 L .67417 .48883 L F
.449 .151 .366 r
.35753 .66287 m .35608 .66125 L .35581 .66339 L F
.35753 .66287 m .35814 .66099 L .35608 .66125 L F
.447 .351 .654 r
.76936 .59731 m .76772 .5999 L .76646 .5965 L F
.76936 .59731 m .7695 .59966 L .76772 .5999 L F
.649 .594 .779 r
.7695 .59966 m .76846 .60319 L .76772 .5999 L F
.523 .44 .703 r
.46233 .66104 m .46075 .6635 L .46023 .66162 L F
.46233 .66104 m .46267 .66317 L .46075 .6635 L F
.552 .393 .619 r
.44949 .77439 m .45176 .77171 L .44989 .77244 L F
.234 0 0 r
.5776 .6832 m .57704 .68342 L .57427 .68316 L F
.57427 .68316 m .57704 .68342 L .5776 .6832 L F
.429 .848 .688 r
.57884 .68233 m .57704 .68342 L .5776 .6832 L F
.5776 .6832 m .57704 .68342 L .57884 .68233 L F
.234 0 0 r
.5776 .6832 m .57704 .68342 L .57427 .68316 L F
.542 .018 0 r
.58578 .68141 m .58445 .68236 L .58134 .6812 L F
.483 0 0 r
.58793 .68228 m .58445 .68236 L .58578 .68141 L F
.73 .645 .764 r
.77092 .60287 m .772 .60631 L .76871 .60567 L F
.582 .575 .81 r
.77308 .60273 m .772 .60631 L .77092 .60287 L F
.77308 .60273 m .77416 .60592 L .772 .60631 L F
.394 .086 .32 r
.42004 .68914 m .41942 .69081 L .42208 .68861 L F
.593 .298 .436 r
.49353 .76623 m .49613 .7665 L .49776 .76284 L F
.675 .386 .476 r
.49776 .76284 m .49613 .7665 L .50019 .76506 L F
.599 .362 .529 r
.5175 .76909 m .51992 .76904 L .51991 .76563 L F
.247 0 0 r
.51991 .76563 m .52308 .76627 L .52103 .76584 L F
.636 .392 .531 r
.51991 .76563 m .52302 .76848 L .52308 .76627 L F
.51991 .76563 m .51992 .76904 L .52302 .76848 L F
.574 .592 .833 r
.3589 .71377 m .35952 .71033 L .35648 .71066 L F
.3589 .71377 m .36105 .71332 L .35952 .71033 L F
.501 .902 .925 r
.27375 .65444 m .27443 .65359 L .27224 .65409 L F
.27375 .65444 m .27644 .65359 L .27443 .65359 L F
.2 0 0 r
.40581 .66371 m .40388 .66537 L .40198 .66565 L F
.455 .007 .096 r
.40792 .66346 m .40388 .66537 L .40581 .66371 L F
.499 0 0 r
.40212 .64884 m .40422 .64939 L .40582 .64885 L F
.476 0 0 r
.40582 .64885 m .40422 .64939 L .40782 .64934 L F
.49 .371 .644 r
.43961 .67217 m .44163 .67438 L .44183 .67177 L F
.43961 .67217 m .43969 .67496 L .44163 .67438 L F
.709 .452 .533 r
.50237 .74705 m .50464 .74956 L .50486 .7473 L F
.652 .43 .569 r
.50464 .74956 m .50714 .74701 L .50486 .7473 L F
.197 .609 .947 r
.68199 .50017 m .68079 .49906 L .67901 .4988 L F
.991 .737 .427 r
.68199 .50017 m .6809 .50139 L .68079 .49906 L F
.69 .566 .711 r
.68437 .49732 m .68199 .50017 L .68201 .49783 L F
.656 .176 .102 r
.68199 .50017 m .68481 .50194 L .6809 .50139 L F
.693 .572 .714 r
.68437 .49732 m .68545 .50061 L .68199 .50017 L F
.649 .248 .271 r
.68545 .50061 m .68481 .50194 L .68199 .50017 L F
.526 .902 .724 r
.54377 .69986 m .54308 .70011 L .54484 .69887 L F
.41 .731 .991 r
.54484 .69887 m .5463 .7 L .54377 .69986 L F
.254 0 0 r
.27526 .60806 m .27373 .60961 L .27178 .61008 L F
.098 0 0 r
.27608 .6085 m .27526 .60806 L .27716 .60762 L F
.27608 .6085 m .27373 .60961 L .27526 .60806 L F
.7 .597 .737 r
.5024 .76318 m .50403 .7622 L .49916 .76099 L F
0 0 0 r
.56354 .68159 m .5639 .68183 L .565 .67996 L F
.56354 .68159 m .56168 .68232 L .5639 .68183 L F
.723 .338 .321 r
.55089 .69204 m .55347 .69385 L .55245 .69112 L F
.359 0 .074 r
.54944 .69397 m .54781 .69477 L .54905 .69446 L F
.54944 .69397 m .54905 .69446 L .55217 .69367 L F
.723 .338 .321 r
.55095 .69208 m .54944 .69397 L .55347 .69385 L F
.55089 .69204 m .54944 .69397 L .55095 .69208 L F
.724 .325 .292 r
.55456 .7127 m .55051 .7111 L .55193 .71146 L F
.305 .495 .879 r
.65184 .49817 m .6496 .49859 L .64869 .49719 L F
.65184 .49817 m .6522 .49977 L .6496 .49859 L F
.478 .816 .999 r
.59343 .7555 m .5957 .75512 L .59228 .75479 L F
.726 .448 .505 r
.50756 .80264 m .51103 .80271 L .51104 .80489 L F
.542 .385 .617 r
.7299 .60234 m .72783 .60526 L .72762 .60266 L F
.508 .315 .554 r
.26032 .62072 m .25974 .62251 L .25836 .62261 L F
.311 .013 .287 r
.25974 .62251 m .25785 .62447 L .25836 .62261 L F
.708 .6 .733 r
.70016 .50541 m .69821 .5084 L .69822 .50619 L F
.695 .298 .291 r
.45939 .75272 m .46125 .75468 L .46273 .75275 L F
.914 .612 .459 r
.46273 .75275 m .46125 .75468 L .46242 .75445 L F
.66 .416 .54 r
.46242 .75445 m .46514 .75252 L .46273 .75275 L F
.491 .153 .322 r
.46075 .67852 m .46042 .67995 L .45809 .68028 L F
.553 .239 .389 r
.46372 .67734 m .46042 .67995 L .46075 .67852 L F
.737 .65 .763 r
.51888 .80106 m .52022 .80233 L .51687 .80296 L F
.635 .314 .411 r
.51687 .80296 m .52022 .80233 L .51881 .8048 L F
0 0 0 r
.52124 .80175 m .52022 .80233 L .51888 .80106 L F
.747 .448 .476 r
.52022 .80233 m .52462 .80428 L .51881 .8048 L F
0 .196 .613 r
.64495 .52322 m .6466 .52427 L .64367 .52246 L F
.566 .498 .738 r
.35189 .6831 m .35334 .68009 L .35173 .68054 L F
.197 .678 .931 r
.30924 .59288 m .30585 .59221 L .30776 .59189 L F
.382 .753 .991 r
.31014 .59187 m .30924 .59288 L .30776 .59189 L F
.31014 .59187 m .31176 .59276 L .30924 .59288 L F
.572 .821 .992 r
.34572 .60026 m .34223 .60001 L .34437 .59959 L F
.499 .852 .993 r
.34648 .5993 m .34572 .60026 L .34437 .59959 L F
.34648 .5993 m .34799 .59982 L .34572 .60026 L F
.381 .469 .825 r
.34862 .60354 m .34572 .60026 L .34799 .59982 L F
.701 .63 .774 r
.68329 .49402 m .68437 .49732 L .68201 .49783 L F
.605 .631 .85 r
.47023 .77551 m .46703 .7765 L .46706 .77553 L F
.589 .31 .461 r
.61695 .55804 m .61359 .56092 L .61329 .55861 L F
.703 .458 .551 r
.49897 .74711 m .50233 .74911 L .50237 .74705 L F
.699 .452 .547 r
.50233 .74911 m .50464 .74956 L .50237 .74705 L F
.843 .596 .565 r
.57423 .71567 m .57585 .71624 L .5759 .71386 L F
.596 .537 .759 r
.35533 .69968 m .35637 .70272 L .35867 .70218 L F
.613 .49 .689 r
.35591 .70521 m .35867 .70218 L .35637 .70272 L F
.606 .55 .765 r
.54123 .76916 m .54044 .77232 L .53886 .76999 L F
.54123 .76916 m .54195 .77184 L .54044 .77232 L F
.667 .357 .438 r
.52184 .75817 m .52153 .76057 L .52124 .75854 L F
.558 .261 .419 r
.5241 .75937 m .52184 .75817 L .52424 .75853 L F
.5241 .75937 m .52153 .76057 L .52184 .75817 L F
.258 .7 .96 r
.32063 .59383 m .32266 .5939 L .32415 .59464 L F
.392 .752 .993 r
.32468 .59361 m .32415 .59464 L .32266 .5939 L F
.32468 .59361 m .32623 .59452 L .32415 .59464 L F
.496 .578 .868 r
.58265 .74787 m .5843 .74588 L .5833 .74604 L F
.58265 .74787 m .58664 .74888 L .5843 .74588 L F
.938 .621 .409 r
.50726 .77242 m .50601 .7741 L .50547 .77148 L F
.598 .152 .162 r
.5095 .7739 m .50601 .7741 L .50726 .77242 L F
.996 .852 .576 r
.65893 .49459 m .65787 .49346 L .6586 .49118 L F
.807 .394 0 r
.65893 .49459 m .65847 .49425 L .65787 .49346 L F
.65893 .49459 m .6598 .49653 L .65847 .49425 L F
.76 .657 .748 r
.77329 .61046 m .77322 .61396 L .77009 .61366 L F
.766 .619 .696 r
.77322 .61396 m .77109 .61641 L .77009 .61366 L F
.701 .52 .639 r
.77322 .61396 m .77351 .61676 L .77109 .61641 L F
.722 .625 .749 r
.77562 .61108 m .77322 .61396 L .77329 .61046 L F
.522 .342 .578 r
.77562 .61108 m .77576 .61342 L .77322 .61396 L F
.49 .339 .603 r
.77576 .61342 m .77351 .61676 L .77322 .61396 L F
.518 .359 .605 r
.35377 .66605 m .35581 .66339 L .35377 .66388 L F
.79 .909 .923 r
.54345 .75484 m .54006 .75497 L .54196 .75388 L F
.375 .518 .872 r
.54305 .7533 m .54578 .75442 L .54345 .75484 L F
.639 .445 .605 r
.54578 .75442 m .54341 .75589 L .54345 .75484 L F
.949 .863 .72 r
.54305 .7533 m .54345 .75484 L .54196 .75388 L F
.676 .219 .159 r
.51245 .80123 m .51488 .79993 L .50999 .79934 L F
.358 .798 .639 r
.5158 .79941 m .51488 .79993 L .51245 .80123 L F
0 0 .415 r
.66805 .52972 m .66885 .53322 L .66822 .5312 L F
.71 .836 .942 r
.69126 .50281 m .68886 .50346 L .68795 .5023 L F
.264 0 .084 r
.64255 .51754 m .64402 .51791 L .64497 .51696 L F
.64255 .51754 m .6421 .51884 L .64402 .51791 L F
.561 .647 .892 r
.31852 .60864 m .31859 .60548 L .31675 .60541 L F
.31852 .60864 m .32059 .60818 L .31859 .60548 L F
.525 .48 .748 r
.31852 .60864 m .32131 .61064 L .32059 .60818 L F
.237 0 .206 r
.3204 .64043 m .31957 .6394 L .3216 .63882 L F
.3204 .64043 m .31881 .64106 L .31957 .6394 L F
.436 .227 .496 r
.49548 .74432 m .4952 .74668 L .4933 .74715 L F
.467 .314 .589 r
.4952 .74668 m .49521 .74931 L .4933 .74715 L F
.436 .227 .496 r
.49548 .74432 m .4952 .74668 L .4933 .74715 L F
.467 .314 .589 r
.4933 .74715 m .49521 .74931 L .4952 .74668 L F
.797 .383 .263 r
.54521 .70547 m .54418 .70696 L .54344 .70535 L F
.837 .438 .29 r
.54521 .70547 m .5468 .70806 L .54418 .70696 L F
.166 .298 .755 r
.5364 .73376 m .53736 .73199 L .53564 .73238 L F
.577 .232 .348 r
.53938 .73378 m .5383 .73517 L .5364 .73376 L F
.166 .298 .755 r
.5364 .73376 m .5383 .73517 L .53736 .73199 L F
.433 .191 .446 r
.49786 .74165 m .49743 .74388 L .49548 .74432 L F
.294 .071 .395 r
.4994 .74313 m .49786 .74165 L .5 .74137 L F
.4994 .74313 m .49743 .74388 L .49786 .74165 L F
.71 .182 0 r
.55897 .73297 m .56272 .73522 L .56171 .73397 L F
.957 .679 .468 r
.49154 .76362 m .49 .76074 L .4911 .7629 L F
.763 .267 0 r
.4921 .76525 m .49154 .76362 L .4911 .7629 L F
.4921 .76525 m .49353 .76623 L .49154 .76362 L F
.599 .33 .48 r
.76365 .622 m .76103 .62429 L .76097 .62228 L F
.76365 .622 m .76359 .62448 L .76103 .62429 L F
.467 .294 .562 r
.76572 .61922 m .76568 .62251 L .76365 .622 L F
0 0 0 r
.76568 .62251 m .76359 .62448 L .76365 .622 L F
.091 .124 .603 r
.70651 .59732 m .7079 .59899 L .70807 .59649 L F
.572 .914 .698 r
.65644 .54384 m .65352 .54609 L .65481 .54522 L F
.487 .151 .322 r
.43451 .68009 m .43659 .6798 L .43766 .67767 L F
.585 .437 .646 r
.43766 .67767 m .43995 .67742 L .43969 .67496 L F
.566 .233 .363 r
.43766 .67767 m .43952 .67923 L .43995 .67742 L F
.43766 .67767 m .43659 .6798 L .43952 .67923 L F
.619 .664 .872 r
.38574 .69373 m .38347 .69435 L .38207 .69173 L F
.542 .249 .42 r
.56872 .71211 m .5714 .713 L .56898 .71076 L F
0 0 .064 r
.57239 .71364 m .57311 .71122 L .57301 .71314 L F
.57311 .71122 m .57319 .71095 L .57317 .71115 L F
.57239 .71364 m .57288 .71351 L .57319 .71095 L F
.705 .581 .713 r
.5726 .71496 m .57395 .71503 L .57301 .71282 L F
0 0 .064 r
.57288 .71351 m .5729 .7135 L .57294 .7132 L F
.57288 .71351 m .57294 .7132 L .57319 .71095 L F
0 .211 .699 r
.56898 .71076 m .57271 .71337 L .57239 .71364 L F
.705 .581 .713 r
.57269 .71337 m .57301 .71282 L .57275 .71223 L F
.5726 .71496 m .57292 .71326 L .57269 .71337 L F
.992 .74 .43 r
.57319 .71095 m .57294 .7132 L .57275 .71223 L F
.57294 .7132 m .5729 .7135 L .57275 .71223 L F
.705 .581 .713 r
.57292 .71326 m .57294 .7132 L .57269 .71337 L F
.57294 .7132 m .57301 .71282 L .5729 .71301 L F
.57294 .7132 m .5729 .71301 L .57269 .71337 L F
.542 .249 .42 r
.5714 .713 m .57261 .71341 L .57171 .71267 L F
0 .211 .699 r
.57271 .71337 m .5729 .7135 L .57288 .71351 L F
.57271 .71337 m .57288 .71351 L .57239 .71364 L F
.542 .249 .42 r
.57261 .71341 m .5729 .7135 L .57271 .71337 L F
.57261 .71341 m .57271 .71337 L .57171 .71267 L F
.705 .581 .713 r
.57058 .71486 m .5726 .71496 L .57269 .71335 L F
.533 .286 .487 r
.57058 .71486 m .5729 .7135 L .57261 .71341 L F
.57058 .71486 m .57261 .71341 L .56872 .71211 L F
.705 .581 .713 r
.57058 .71486 m .57269 .71335 L .57269 .71335 L F
.57218 .71292 m .57269 .71335 L .57275 .71223 L F
.57058 .71486 m .57269 .71335 L .57218 .71292 L F
.542 .249 .42 r
.5714 .713 m .57171 .71267 L .56898 .71076 L F
0 0 .064 r
.57311 .71122 m .57317 .71115 L .57301 .71314 L F
.307 .498 .881 r
.57319 .71095 m .57565 .712 L .57301 .71314 L F
.041 0 .24 r
.57565 .712 m .57395 .71503 L .57301 .71314 L F
.77 .323 .188 r
.58658 .67478 m .59025 .67704 L .5898 .67523 L F
.572 .339 .523 r
.58977 .73888 m .59228 .74099 L .59213 .73845 L F
.58977 .73888 m .58959 .74169 L .59228 .74099 L F
.58977 .73888 m .59228 .74099 L .59213 .73845 L F
.58977 .73888 m .58959 .74169 L .59228 .74099 L F
0 0 .307 r
.66915 .51667 m .66969 .5178 L .66773 .51579 L F
.66915 .51667 m .66997 .5184 L .66969 .5178 L F
0 .24 .754 r
.66969 .5178 m .66678 .51467 L .66773 .51579 L F
.997 .791 .502 r
.66794 .51374 m .66773 .51579 L .66678 .51467 L F
0 .24 .754 r
.66969 .5178 m .66956 .51701 L .66678 .51467 L F
.898 .917 .522 r
.66869 .51902 m .66945 .51728 L .66969 .5178 L F
.66945 .51728 m .66956 .51701 L .66969 .5178 L F
0 0 .307 r
.66997 .5184 m .67034 .51917 L .66969 .5178 L F
.432 .842 .662 r
.65333 .54613 m .65181 .54719 L .65352 .54609 L F
.454 .871 .736 r
.65132 .54729 m .65181 .54719 L .65333 .54613 L F
.556 .837 .998 r
.29697 .60272 m .2991 .60215 L .29546 .60191 L F
.777 .788 .861 r
.67462 .50851 m .67228 .50841 L .67423 .50608 L F
.564 .57 .818 r
.67539 .51066 m .67228 .50841 L .67462 .50851 L F
.584 .653 .884 r
.67637 .50598 m .67462 .50851 L .67423 .50608 L F
.598 .386 .565 r
.67783 .50984 m .67462 .50851 L .67637 .50598 L F
.67783 .50984 m .67539 .51066 L .67462 .50851 L F
.803 .7 .751 r
.61106 .53302 m .61214 .53641 L .60905 .53607 L F
.799 .715 .771 r
.61214 .53641 m .61004 .5392 L .60905 .53607 L F
.71 .836 .942 r
.69126 .50281 m .68783 .49994 L .69008 .49942 L F
.632 .622 .822 r
.6924 .49879 m .69126 .50281 L .69008 .49942 L F
.6924 .49879 m .69415 .50275 L .69126 .50281 L F
.401 .822 .968 r
.42325 .66302 m .42147 .66258 L .41916 .66297 L F
.281 .754 .937 r
.425 .66286 m .42147 .66258 L .42325 .66302 L F
.817 .709 .746 r
.60823 .53811 m .60916 .5414 L .60659 .54103 L F
.60823 .53811 m .61004 .5392 L .60916 .5414 L F
.871 .714 .685 r
.60659 .54103 m .60916 .5414 L .60793 .5444 L F
.755 .42 0 r
.6015 .71232 m .60317 .71666 L .60362 .71356 L F
.72 .342 .333 r
.52485 .80443 m .52661 .8028 L .52434 .80286 L F
.52485 .80443 m .52819 .80429 L .52661 .8028 L F
.489 .181 .371 r
.73417 .5942 m .73624 .59385 L .73683 .59194 L F
.389 .064 .289 r
.73624 .59385 m .73919 .59147 L .73683 .59194 L F
.274 .209 .599 r
.47696 .7846 m .47598 .78649 L .47476 .78496 L F
.778 .598 .657 r
.47601 .78765 m .47809 .78548 L .47598 .78649 L F
.274 .209 .599 r
.47696 .7846 m .47601 .78765 L .47598 .78649 L F
.552 .521 .774 r
.35591 .70521 m .35763 .70832 L .35966 .70784 L F
.688 .316 .337 r
.35763 .70832 m .35952 .71033 L .35966 .70784 L F
.35763 .70832 m .35648 .71066 L .35952 .71033 L F
.803 .717 .769 r
.60905 .53607 m .61004 .5392 L .60823 .53811 L F
.566 .261 .41 r
.48298 .744 m .48549 .74413 L .48619 .74128 L F
.469 .177 .386 r
.48549 .74413 m .48822 .7409 L .48619 .74128 L F
.679 .86 .46 r
.3517 .69441 m .3523 .69318 L .35354 .69146 L F
.398 .701 .982 r
.3523 .69318 m .35355 .69401 L .3517 .69441 L F
.643 .631 .823 r
.35171 .69667 m .35355 .69401 L .3517 .69441 L F
.32 .732 .978 r
.57113 .76649 m .56843 .76574 L .56983 .76481 L F
.56843 .76574 m .56776 .76556 L .56804 .76546 L F
.57113 .76649 m .5704 .76578 L .56776 .76556 L F
.558 .579 .831 r
.57014 .76896 m .5704 .76578 L .57113 .76649 L F
.814 .999 .837 r
.57343 .76511 m .57309 .7654 L .57392 .76557 L F
.645 .234 .251 r
.57392 .76557 m .5704 .76578 L .57223 .76849 L F
.57392 .76557 m .57113 .76709 L .5704 .76578 L F
.814 .999 .837 r
.57309 .7654 m .57113 .76709 L .57243 .76638 L F
.57309 .7654 m .57243 .76638 L .57392 .76557 L F
.558 .579 .831 r
.57029 .76714 m .57139 .76791 L .5704 .76578 L F
.57139 .76791 m .57223 .76849 L .57161 .76758 L F
.57139 .76791 m .57161 .76758 L .5704 .76578 L F
.57014 .76896 m .57211 .76852 L .57029 .76714 L F
.57211 .76852 m .57223 .76849 L .57029 .76714 L F
.32 .732 .978 r
.56843 .76574 m .56804 .76546 L .56983 .76481 L F
.626 .336 .457 r
.55636 .69181 m .55591 .69405 L .55347 .69385 L F
.593 .371 .549 r
.55849 .6912 m .55591 .69405 L .55636 .69181 L F
.721 .616 .74 r
.50111 .75864 m .50403 .7622 L .50483 .76082 L F
.709 .297 .263 r
.57585 .71624 m .5781 .71808 L .57968 .71671 L F
.634 .139 0 r
.5804 .71787 m .57968 .71671 L .5781 .71808 L F
.5804 .71787 m .58148 .71891 L .57968 .71671 L F
.464 .819 .997 r
.26349 .58518 m .2656 .58477 L .26733 .5855 L F
.279 .701 .969 r
.2656 .58477 m .26919 .58569 L .26733 .5855 L F
.392 0 0 r
.55543 .7093 m .55875 .70957 L .55977 .70882 L F
.675 .147 0 r
.55875 .70957 m .56209 .71064 L .55977 .70882 L F
.706 .418 .484 r
.49669 .79951 m .4955 .80237 L .49468 .79932 L F
.49669 .79951 m .4985 .80207 L .4955 .80237 L F
.614 .093 0 r
.47535 .79347 m .47866 .79408 L .47678 .79395 L F
.785 .398 .324 r
.47866 .79408 m .47975 .79471 L .47678 .79395 L F
.336 0 .099 r
.39212 .66914 m .38863 .67155 L .39029 .66933 L F
.7 .575 .712 r
.68783 .49994 m .68545 .50061 L .68437 .49732 L F
.45 .584 .896 r
.54892 .77247 m .54767 .77476 L .54869 .77255 L F
.54881 .77272 m .54767 .77476 L .54892 .77247 L F
.54893 .77251 m .54767 .77476 L .54895 .77246 L F
.54893 .77251 m .54962 .77366 L .54767 .77476 L F
.829 .747 .773 r
.54904 .7727 m .54962 .77366 L .54915 .77269 L F
.45 .584 .896 r
.54896 .77246 m .54962 .77366 L .54893 .77251 L F
.829 .747 .773 r
.54884 .7727 m .54962 .77366 L .54904 .7727 L F
.874 .708 .672 r
.54581 .77596 m .54794 .77467 L .54676 .77365 L F
.54581 .77596 m .54676 .77365 L .54581 .77464 L F
.54794 .77467 m .5485 .77342 L .54581 .77284 L F
.744 .397 .395 r
.54598 .77754 m .54326 .77935 L .54324 .77722 L F
.349 .146 .457 r
.54195 .77184 m .54188 .77413 L .54374 .77146 L F
.704 .901 .537 r
.54374 .77146 m .54188 .77413 L .54238 .773 L F
.635 .525 .712 r
.54467 .77521 m .54238 .773 L .54461 .77239 L F
.54467 .77521 m .5426 .77585 L .54238 .773 L F
.647 .566 .75 r
.5426 .77585 m .54547 .77496 L .54461 .77239 L F
.635 .525 .712 r
.5449 .77543 m .54467 .77521 L .54461 .77239 L F
.647 .566 .75 r
.54467 .77521 m .54581 .77596 L .54547 .77496 L F
.5426 .77585 m .54469 .77592 L .54467 .77521 L F
.54469 .77592 m .54581 .77596 L .54467 .77521 L F
.635 .525 .712 r
.5449 .77543 m .5426 .77585 L .54467 .77521 L F
.65 .507 .675 r
.5426 .77585 m .54405 .77847 L .54581 .77596 L F
.893 .689 .621 r
.54461 .77239 m .54548 .77499 L .54581 .77284 L F
.54548 .77499 m .54581 .77596 L .54581 .77464 L F
.54548 .77499 m .54581 .77464 L .54581 .77284 L F
0 0 0 r
.54467 .77582 m .54518 .77529 L .54524 .77526 L F
.5448 .77574 m .54524 .77526 L .54779 .77401 L F
.54467 .77582 m .54524 .77526 L .5448 .77574 L F
.54376 .77736 m .54467 .77582 L .54779 .77401 L F
.54467 .77582 m .5449 .77543 L .54518 .77529 L F
.874 .708 .672 r
.54581 .77464 m .54676 .77365 L .54581 .77284 L F
.54794 .77467 m .54962 .77366 L .5485 .77342 L F
.45 .584 .896 r
.54895 .77246 m .54881 .77272 L .54892 .77247 L F
.54892 .77242 m .54869 .77255 L .54728 .77091 L F
.54895 .77246 m .54869 .77255 L .54892 .77242 L F
0 .167 .701 r
.5483 .77091 m .54892 .77242 L .54774 .77133 L F
.5483 .77091 m .54774 .77133 L .54728 .77091 L F
.86 .433 .205 r
.55122 .76929 m .5483 .77091 L .54818 .7687 L F
.428 .812 .573 r
.54867 .77063 m .5483 .77091 L .54991 .76971 L F
.54693 .77192 m .5483 .77091 L .54867 .77063 L F
.829 .747 .773 r
.54581 .77284 m .54904 .7727 L .54789 .77123 L F
.54904 .7727 m .54915 .77269 L .54892 .77242 L F
.54904 .7727 m .54892 .77242 L .54789 .77123 L F
.54789 .77123 m .54915 .77269 L .5483 .77091 L F
0 .167 .701 r
.5483 .77091 m .54896 .77246 L .54892 .77242 L F
.45 .584 .896 r
.54896 .77246 m .54893 .77251 L .54895 .77246 L F
.829 .747 .773 r
.54581 .77284 m .5485 .77342 L .54884 .7727 L F
.5485 .77342 m .54962 .77366 L .54884 .7727 L F
.45 .584 .896 r
.54896 .77246 m .54895 .77246 L .54892 .77242 L F
.355 .616 .949 r
.58742 .75009 m .58778 .74884 L .58664 .74888 L F
0 .057 .608 r
.58742 .75009 m .58876 .75239 L .58778 .74884 L F
.615 .807 .974 r
.67228 .50841 m .66965 .50911 L .66837 .50801 L F
.599 .561 .783 r
.46233 .66104 m .46023 .66162 L .45905 .65828 L F
.204 0 0 r
.70946 .58834 m .71205 .58849 L .7128 .58839 L F
.925 .96 .781 r
.7128 .58839 m .71095 .58979 L .71205 .58849 L F
0 0 0 r
.714 .58731 m .7128 .58839 L .71205 .58849 L F
.918 .954 .62 r
.66798 .50546 m .6691 .50338 L .66947 .50091 L F
.113 .656 .84 r
.39245 .69862 m .39562 .69884 L .3933 .69905 L F
.75 .516 .577 r
.76097 .62228 m .75739 .62482 L .7568 .62258 L F
.76097 .62228 m .76103 .62429 L .75739 .62482 L F
.846 .886 .868 r
.49773 .76035 m .49916 .76099 L .50111 .75864 L F
.909 .698 .196 r
.47897 .79802 m .47911 .79663 L .479 .79822 L F
.789 .412 .342 r
.47931 .79459 m .47911 .79663 L .47678 .79395 L F
0 .059 .608 r
.47678 .79395 m .47911 .79663 L .47847 .79521 L F
.909 .698 .196 r
.47847 .79521 m .47911 .79663 L .47897 .79802 L F
.789 .412 .342 r
.47975 .79471 m .47911 .79663 L .47931 .79459 L F
.708 .322 .315 r
.47975 .79471 m .48059 .79635 L .47911 .79663 L F
.671 .133 0 r
.47975 .79471 m .48378 .79681 L .48059 .79635 L F
.553 .239 .389 r
.46372 .67734 m .46267 .67971 L .46042 .67995 L F
.623 .312 .423 r
.46598 .67949 m .46372 .67734 L .46604 .67732 L F
.46598 .67949 m .46267 .67971 L .46372 .67734 L F
0 0 0 r
.30437 .6498 m .30204 .65102 L .30019 .65145 L F
.163 0 0 r
.30437 .65064 m .30437 .6498 L .30645 .64945 L F
.30437 .65064 m .30204 .65102 L .30437 .6498 L F
.928 .549 .166 r
.57277 .74921 m .57373 .75255 L .57452 .75254 L F
.191 .291 .737 r
.57373 .75255 m .57458 .75503 L .57452 .75254 L F
.681 .47 .593 r
.51049 .73583 m .50787 .73828 L .50799 .73614 L F
.589 .564 .794 r
.68665 .4967 m .68437 .49732 L .68329 .49402 L F
.7 .575 .712 r
.68783 .49994 m .68437 .49732 L .68665 .4967 L F
.947 .678 .495 r
.54642 .74448 m .54664 .74626 L .5483 .74556 L F
.037 0 0 r
.5483 .74556 m .54974 .74559 L .54947 .74516 L F
.532 .411 .661 r
.35201 .66991 m .35406 .66951 L .35377 .66605 L F
.52 .416 .676 r
.35241 .67212 m .35406 .66951 L .35201 .66991 L F
.385 .17 .46 r
.69377 .51615 m .69161 .51901 L .69168 .51697 L F
.657 .685 .864 r
.26505 .64087 m .26089 .63894 L .26291 .63834 L F
.451 .608 .914 r
.26485 .63812 m .26505 .64087 L .26291 .63834 L F
.26485 .63812 m .26668 .64063 L .26505 .64087 L F
.537 .918 .931 r
.27443 .65359 m .27644 .65359 L .27832 .65275 L F
.166 .577 .935 r
.53413 .77511 m .53739 .77633 L .53341 .77454 L F
.244 0 0 r
.64092 .5505 m .64378 .54937 L .64325 .54982 L F
0 0 0 r
.64531 .54887 m .64378 .54937 L .64571 .54885 L F
.64531 .54887 m .64325 .54982 L .64378 .54937 L F
.553 .34 .545 r
.42999 .68329 m .43225 .68297 L .4324 .68054 L F
.497 .293 .533 r
.4324 .68054 m .43437 .68241 L .43451 .68009 L F
.4324 .68054 m .43225 .68297 L .43437 .68241 L F
.377 .187 .492 r
.38384 .67411 m .38192 .67732 L .38212 .67498 L F
.697 .772 .91 r
.67783 .50984 m .67875 .51139 L .67539 .51066 L F
.6 .795 .974 r
.68013 .50956 m .67875 .51139 L .67783 .50984 L F
.68013 .50956 m .68108 .51076 L .67875 .51139 L F
.392 .149 .422 r
.68908 .53538 m .68706 .53624 L .68947 .53346 L F
.121 .08 .534 r
.69057 .52974 m .6909 .53206 L .68947 .53346 L F
.151 0 .326 r
.69054 .53358 m .68947 .53346 L .6909 .53206 L F
.69054 .53358 m .68908 .53538 L .68947 .53346 L F
.32 .75 .971 r
.27836 .58661 m .28052 .58646 L .28186 .58712 L F
.267 .637 .964 r
.28274 .58621 m .28186 .58712 L .28052 .58646 L F
.28274 .58621 m .28434 .58756 L .28186 .58712 L F
.788 .541 .562 r
.49548 .74432 m .4952 .74668 L .49897 .74711 L F
.531 .309 .522 r
.4976 .74624 m .49548 .74432 L .49743 .74388 L F
.4976 .74624 m .4952 .74668 L .49548 .74432 L F
0 0 0 r
.39095 .71428 m .39064 .71394 L .3925 .71314 L F
.39095 .71428 m .38894 .71509 L .39064 .71394 L F
.468 .221 .456 r
.26972 .6106 m .26909 .61291 L .26718 .61324 L F
.372 .098 .363 r
.27178 .61008 m .26909 .61291 L .26972 .6106 L F
.682 .691 .852 r
.66703 .48438 m .66363 .48318 L .66588 .48307 L F
.532 .791 .992 r
.66809 .48291 m .66703 .48438 L .66588 .48307 L F
.66809 .48291 m .66887 .48393 L .66703 .48438 L F
.475 .836 .994 r
.29638 .65226 m .29507 .65182 L .29296 .65229 L F
.657 .765 .929 r
.63883 .49055 m .63962 .49207 L .63646 .49143 L F
.92 .659 .526 r
.63782 .49412 m .63646 .49143 L .63962 .49207 L F
.723 .55 .656 r
.63962 .49207 m .64007 .49468 L .63782 .49412 L F
.507 .68 .944 r
.64097 .49035 m .63962 .49207 L .63883 .49055 L F
.431 .569 .892 r
.64097 .49035 m .64128 .4919 L .63962 .49207 L F
.599 .54 .76 r
.64128 .4919 m .64007 .49468 L .63962 .49207 L F
.76 .55 .612 r
.4952 .74668 m .49908 .7494 L .49897 .74711 L F
.703 .458 .551 r
.49897 .74711 m .49908 .7494 L .50233 .74911 L F
.522 .609 .881 r
.74047 .61096 m .73811 .61111 L .73718 .60881 L F
.837 .754 .772 r
.52159 .7494 m .52458 .74678 L .52211 .74752 L F
.671 .401 .503 r
.68598 .53802 m .68355 .53623 L .68706 .53624 L F
.437 .096 .289 r
.68817 .5374 m .68706 .53624 L .68908 .53538 L F
.68817 .5374 m .68598 .53802 L .68706 .53624 L F
.593 .586 .813 r
.43425 .66329 m .43738 .6647 L .43593 .66182 L F
.71 .567 .69 r
.60576 .55886 m .60747 .55842 L .6057 .56123 L F
.536 .348 .572 r
.60747 .55842 m .60776 .56062 L .6057 .56123 L F
.574 .562 .803 r
.68898 .49616 m .68783 .49994 L .68665 .4967 L F
.68898 .49616 m .69008 .49942 L .68783 .49994 L F
.106 0 0 r
.63191 .52405 m .62958 .52382 L .62903 .52213 L F
.644 .666 .856 r
.54597 .76399 m .5429 .76247 L .54495 .76245 L F
.338 .61 .949 r
.54712 .76261 m .54597 .76399 L .54495 .76245 L F
0 0 .215 r
.54712 .76261 m .54566 .76612 L .54597 .76399 L F
.402 .456 .801 r
.36227 .71641 m .36272 .71304 L .36105 .71332 L F
.36227 .71641 m .36407 .71642 L .36272 .71304 L F
.507 .434 .71 r
.36227 .71641 m .36499 .71896 L .36407 .71642 L F
.738 .36 .336 r
.53323 .75819 m .53189 .76013 L .52983 .75778 L F
.724 .343 .327 r
.53323 .75819 m .53548 .76044 L .53189 .76013 L F
.273 .764 .909 r
.32623 .59452 m .32838 .59428 L .3298 .59452 L F
.284 .765 .923 r
.32838 .59428 m .33183 .59433 L .3298 .59452 L F
.641 .891 .556 r
.58892 .70651 m .58812 .70729 L .58831 .70706 L F
0 0 .163 r
.58821 .70546 m .58892 .70651 L .58992 .70564 L F
.641 .891 .556 r
.58892 .70651 m .58831 .70706 L .58988 .7051 L F
0 0 .163 r
.58992 .70564 m .58892 .70651 L .59112 .70576 L F
.58821 .70546 m .5876 .70772 L .58892 .70651 L F
.373 0 0 r
.57573 .72878 m .5769 .72951 L .57457 .72751 L F
.57573 .72878 m .57855 .73051 L .5769 .72951 L F
.652 .617 .802 r
.68324 .50617 m .68686 .51003 L .68543 .50534 L F
.537 .554 .82 r
.68543 .50534 m .68686 .51003 L .68835 .50653 L F
.297 .026 .322 r
.68686 .51003 m .68895 .50897 L .68835 .50653 L F
.68686 .51003 m .68668 .51053 L .68895 .50897 L F
.525 .285 .493 r
.63164 .55393 m .63137 .55256 L .63263 .55249 L F
.63164 .55393 m .63014 .55501 L .63137 .55256 L F
.414 .119 .353 r
.26585 .61797 m .26423 .6157 L .26617 .61561 L F
.26585 .61797 m .26383 .61843 L .26423 .6157 L F
.886 .811 .769 r
.61528 .52537 m .6149 .52705 L .6123 .52725 L F
.89 .786 .739 r
.6149 .52705 m .61304 .53023 L .6123 .52725 L F
.868 .581 .5 r
.59417 .68214 m .59653 .68061 L .59403 .67979 L F
.59417 .68214 m .59679 .68274 L .59653 .68061 L F
.358 .122 .414 r
.74955 .58327 m .74706 .58646 L .74963 .58601 L F
.476 .304 .569 r
.74955 .58327 m .75182 .5852 L .75151 .58267 L F
.74955 .58327 m .74963 .58601 L .75182 .5852 L F
.557 .497 .744 r
.35267 .68603 m .35396 .68262 L .35189 .6831 L F
.35267 .68603 m .35475 .6856 L .35396 .68262 L F
.483 .415 .704 r
.35267 .68603 m .35528 .6886 L .35475 .6856 L F
.35267 .68603 m .35315 .6892 L .35528 .6886 L F
.405 0 0 r
.43039 .64978 m .43375 .65044 L .43155 .6507 L F
.652 .711 .891 r
.73034 .61727 m .73391 .61871 L .73263 .6167 L F
.576 .695 .923 r
.73391 .61871 m .73506 .61603 L .73263 .6167 L F
.73391 .61871 m .73642 .61826 L .73506 .61603 L F
.588 .609 .84 r
.73391 .61871 m .73697 .62004 L .73642 .61826 L F
.566 .345 .54 r
.49356 .73579 m .49578 .73572 L .49618 .73293 L F
.506 .32 .563 r
.49578 .73572 m .49793 .73242 L .49618 .73293 L F
.775 .656 .732 r
.72905 .61077 m .73031 .61414 L .72741 .61261 L F
0 0 0 r
.73031 .61414 m .72926 .61574 L .72741 .61261 L F
.806 .792 .839 r
.73299 .61154 m .73031 .61414 L .72905 .61077 L F
.706 .872 .96 r
.68813 .53002 m .68615 .53125 L .68506 .53013 L F
.68813 .53002 m .68506 .53013 L .68507 .53013 L F
.68813 .53002 m .68506 .53013 L .68793 .52839 L F
.199 0 0 r
.68809 .52874 m .68639 .53075 L .68866 .53 L F
.68793 .52839 m .68753 .529 L .68809 .52874 L F
.68753 .529 m .68639 .53075 L .68809 .52874 L F
.706 .872 .96 r
.68507 .53013 m .68506 .53013 L .68506 .53013 L F
.613 .49 .689 r
.35591 .70521 m .35913 .70555 L .35867 .70218 L F
.552 .521 .774 r
.35591 .70521 m .35966 .70784 L .35913 .70555 L F
0 0 .511 r
.57439 .75942 m .57474 .76358 L .57445 .76087 L F
.465 .17 .379 r
.74456 .58851 m .7469 .58807 L .74706 .58646 L F
.475 .172 .371 r
.7469 .58807 m .74963 .58601 L .74706 .58646 L F
.68 .758 .91 r
.26988 .64103 m .26796 .64196 L .26668 .64063 L F
.681 .659 .822 r
.71851 .50839 m .71524 .50772 L .71761 .50589 L F
.732 .727 .846 r
.72021 .50576 m .71851 .50839 L .71761 .50589 L F
.614 .565 .775 r
.72021 .50576 m .72109 .508 L .71851 .50839 L F
.639 .736 .918 r
.50304 .76589 m .50018 .76646 L .50019 .76506 L F
.777 .668 .743 r
.50304 .76589 m .50022 .76862 L .50018 .76646 L F
.649 .594 .779 r
.7695 .59966 m .77092 .60287 L .76846 .60319 L F
.64 .513 .692 r
.77092 .60287 m .76871 .60567 L .76846 .60319 L F
.721 .616 .74 r
.50111 .75864 m .50483 .76082 L .50323 .75871 L F
.596 .682 .902 r
.50323 .75871 m .50483 .76082 L .50711 .76017 L F
.775 .644 .717 r
.60456 .55531 m .60576 .55886 L .604 .55766 L F
.792 .635 .687 r
.604 .55766 m .60576 .55886 L .6057 .56123 L F
.551 .313 .507 r
.47044 .74959 m .47273 .74937 L .47308 .74715 L F
.479 .249 .487 r
.47308 .74715 m .47485 .74885 L .47526 .7469 L F
.47308 .74715 m .47273 .74937 L .47485 .74885 L F
.309 0 .035 r
.43711 .69189 m .43429 .69312 L .43496 .69224 L F
.619 .622 .832 r
.36289 .7224 m .36738 .72542 L .36575 .72365 L F
.608 .695 .905 r
.36575 .72365 m .36738 .72542 L .3689 .72441 L F
.176 0 .258 r
.3689 .72441 m .36668 .72722 L .36738 .72542 L F
.36738 .72542 m .36668 .72722 L .3689 .72441 L F
.751 .46 .489 r
.51881 .8048 m .52462 .80428 L .52253 .80706 L F
.582 .638 .872 r
.43799 .6661 m .43845 .66271 L .43738 .6647 L F
.43799 .6661 m .44017 .6656 L .43845 .66271 L F
.578 .587 .826 r
.43799 .6661 m .4409 .66659 L .44017 .6656 L F
.926 .878 .77 r
.6001 .70181 m .60132 .70238 L .60126 .69975 L F
.962 .826 .662 r
.60042 .70526 m .60132 .70238 L .6001 .70181 L F
.912 .87 .783 r
.60126 .69975 m .60132 .70238 L .60236 .70036 L F
.707 .476 .571 r
.50714 .74701 m .51031 .74943 L .51043 .74713 L F
.645 .42 .563 r
.51031 .74943 m .51306 .74688 L .51043 .74713 L F
.343 .728 .985 r
.62636 .4976 m .62929 .49779 L .62939 .49819 L F
.777 .995 .872 r
.62939 .49819 m .62929 .49779 L .63088 .49605 L F
.741 .688 .8 r
.70016 .50541 m .6969 .50322 L .6994 .50239 L F
.70016 .50541 m .69822 .50619 L .6969 .50322 L F
.8 .774 .829 r
.7025 .50256 m .70016 .50541 L .6994 .50239 L F
.712 .268 .195 r
.51652 .80402 m .51687 .80296 L .51881 .8048 L F
.384 0 .082 r
.37591 .65219 m .37811 .65194 L .37947 .65021 L F
.353 0 .038 r
.37811 .65194 m .38174 .65001 L .37947 .65021 L F
.433 .094 .288 r
.42214 .69986 m .42114 .70226 L .41897 .70268 L F
.508 .197 .375 r
.42427 .69939 m .42114 .70226 L .42214 .69986 L F
.477 .179 .382 r
.41183 .69419 m .41399 .69384 L .41432 .69197 L F
.478 .142 .317 r
.41399 .69384 m .41724 .69114 L .41432 .69197 L F
.99 .771 .509 r
.49571 .79504 m .49731 .79421 L .49379 .79384 L F
.49571 .79504 m .49705 .79684 L .49731 .79421 L F
.81 .581 .591 r
.49705 .79684 m .49872 .79666 L .49731 .79421 L F
.798 .416 .332 r
.59025 .67704 m .59219 .67942 L .59345 .67791 L F
.795 .412 .33 r
.59219 .67942 m .59403 .67979 L .59345 .67791 L F
.777 .668 .743 r
.50304 .76589 m .50374 .76945 L .50022 .76862 L F
.746 .32 .237 r
.50374 .76945 m .50257 .7709 L .50022 .76862 L F
.692 .613 .764 r
.50477 .76781 m .50374 .76945 L .50304 .76589 L F
.762 .34 .248 r
.50374 .76945 m .50547 .77148 L .50257 .7709 L F
0 0 .527 r
.35315 .6892 m .35449 .69051 L .35528 .6886 L F
.35315 .6892 m .35354 .69146 L .35449 .69051 L F
.538 0 0 r
.54724 .75417 m .54578 .75442 L .54305 .7533 L F
.488 0 0 r
.54724 .75417 m .54905 .7549 L .54578 .75442 L F
.334 .636 .963 r
.29144 .58868 m .29116 .59004 L .28959 .58894 L F
.29144 .58868 m .2932 .59012 L .29116 .59004 L F
.715 .845 .944 r
.74512 .61891 m .74852 .61876 L .74744 .61817 L F
.398 .797 .985 r
.74744 .61817 m .74852 .61876 L .75088 .61848 L F
.893 .808 .757 r
.6612 .48579 m .65793 .48774 L .66017 .48449 L F
.6612 .48579 m .65932 .48883 L .65793 .48774 L F
.815 .829 .86 r
.66363 .48318 m .6612 .48579 L .66017 .48449 L F
.968 .721 .51 r
.66075 .49786 m .65967 .5002 L .6598 .49653 L F
.988 .778 .53 r
.66075 .49786 m .65952 .50066 L .65967 .5002 L F
.66075 .49786 m .66045 .50257 L .65952 .50066 L F
.548 .102 .144 r
.51453 .71386 m .51678 .7151 L .51804 .71351 L F
.796 .406 .316 r
.51678 .7151 m .52002 .71607 L .51804 .71351 L F
.525 .797 .995 r
.76049 .58336 m .7581 .58381 L .75719 .5829 L F
.294 .042 .35 r
.33248 .62496 m .33516 .62133 L .33505 .62413 L F
.422 .192 .458 r
.33516 .62133 m .3378 .61873 L .33762 .6199 L F
.405 .16 .426 r
.33505 .62413 m .33516 .62133 L .33762 .6199 L F
.526 .15 .271 r
.5319 .74369 m .53531 .74163 L .5318 .74134 L F
.5319 .74369 m .53453 .74358 L .53531 .74163 L F
.442 .076 .247 r
.53453 .74358 m .53754 .74124 L .53531 .74163 L F
.577 .603 .842 r
.35245 .69779 m .35533 .69968 L .3547 .69719 L F
.586 .538 .768 r
.35533 .69968 m .35699 .69681 L .3547 .69719 L F
.35533 .69968 m .35796 .70015 L .35699 .69681 L F
.596 .537 .759 r
.35533 .69968 m .35867 .70218 L .35796 .70015 L F
.835 .624 .617 r
.61872 .73843 m .61906 .73624 L .61682 .73571 L F
.521 .1 .181 r
.49608 .77128 m .49707 .77346 L .49479 .77226 L F
.452 .202 .443 r
.50022 .76862 m .49608 .77128 L .49688 .76865 L F
.50022 .76862 m .49811 .77158 L .49608 .77128 L F
.563 .12 .155 r
.49908 .77319 m .49608 .77128 L .49811 .77158 L F
.49908 .77319 m .49707 .77346 L .49608 .77128 L F
.598 .634 .858 r
.76779 .59298 m .76646 .5965 L .7658 .59329 L F
.76779 .59298 m .76898 .59649 L .76646 .5965 L F
.617 .511 .711 r
.76898 .59649 m .76936 .59731 L .76646 .5965 L F
.853 .633 .604 r
.60273 .70808 m .60042 .70526 L .60013 .70762 L F
.924 .803 .709 r
.60017 .70977 m .60273 .70808 L .60013 .70762 L F
.60017 .70977 m .60157 .71065 L .60273 .70808 L F
0 .409 .702 r
.40782 .64934 m .40991 .64994 L .4113 .65038 L F
.407 .82 .974 r
.40991 .64994 m .41342 .65001 L .4113 .65038 L F
.456 .466 .78 r
.38754 .69388 m .38677 .69729 L .38574 .69373 L F
.38754 .69388 m .38856 .69737 L .38677 .69729 L F
.431 .537 .864 r
.38856 .69737 m .38949 .69847 L .38677 .69729 L F
.608 .579 .796 r
.39038 .7002 m .38677 .69729 L .38949 .69847 L F
.564 .405 .624 r
.47791 .78267 m .47809 .78548 L .47975 .7833 L F
.463 0 0 r
.75151 .58267 m .75497 .58276 L .75157 .58229 L F
.059 0 .097 r
.31216 .6194 m .3136 .61884 L .31431 .61706 L F
.272 .228 .624 r
.31216 .6194 m .31381 .6212 L .3136 .61884 L F
.421 .251 .543 r
.31201 .62177 m .31381 .6212 L .31216 .6194 L F
.597 .568 .792 r
.54051 .77782 m .54188 .77413 L .53913 .77459 L F
.54051 .77782 m .54324 .77722 L .54188 .77413 L F
.423 .181 .441 r
.38015 .68042 m .37971 .68237 L .37791 .68231 L F
.5 .469 .754 r
.38084 .68582 m .37791 .68231 L .37971 .68237 L F
.957 .775 .617 r
.32782 .72411 m .32879 .72709 L .32929 .72486 L F
.945 .807 .677 r
.60236 .70036 m .6022 .69663 L .60126 .69975 L F
.661 .601 .777 r
.35171 .69667 m .35245 .69779 L .3547 .69719 L F
0 .041 .596 r
.6522 .49977 m .65404 .5019 L .65422 .50267 L F
0 .261 .712 r
.65509 .50288 m .65422 .50267 L .65404 .5019 L F
.65509 .50288 m .65649 .50404 L .65422 .50267 L F
.729 .727 .848 r
.52153 .76057 m .51906 .76337 L .52124 .75854 L F
.589 .31 .461 r
.61695 .55804 m .61577 .56081 L .61359 .56092 L F
.638 .362 .484 r
.6192 .56006 m .61695 .55804 L .61917 .55835 L F
.6192 .56006 m .61577 .56081 L .61695 .55804 L F
0 0 .161 r
.59435 .69912 m .59411 .69618 L .59469 .69708 L F
.253 .765 .824 r
.2817 .65226 m .28023 .65235 L .27832 .65275 L F
.128 .677 .758 r
.28373 .65202 m .28023 .65235 L .2817 .65226 L F
.968 .693 .458 r
.77449 .61259 m .77562 .61108 L .77465 .61013 L F
.77449 .61259 m .77576 .61342 L .77562 .61108 L F
0 .272 .765 r
.77732 .61178 m .77888 .61352 L .77562 .61108 L F
0 .175 .65 r
.77562 .61108 m .77907 .61382 L .77576 .61342 L F
.77562 .61108 m .77888 .61352 L .77907 .61382 L F
0 .272 .765 r
.77732 .61178 m .77562 .61108 L .77576 .61342 L F
.42 .818 .983 r
.41705 .66342 m .41576 .66293 L .41361 .66329 L F
.3 .793 .87 r
.41705 .66342 m .41804 .66291 L .41576 .66293 L F
.41705 .66342 m .41916 .66297 L .41804 .66291 L F
.65 .781 .943 r
.7429 .6103 m .74051 .61215 L .74047 .61096 L F
.7429 .6103 m .74384 .61155 L .74051 .61215 L F
.667 .232 .206 r
.58289 .67457 m .58658 .67478 L .58433 .67462 L F
.465 .172 .384 r
.62486 .55518 m .62406 .55782 L .62161 .5584 L F
.598 .342 .5 r
.62486 .55518 m .62708 .5572 L .62406 .55782 L F
.62486 .55518 m .62704 .55534 L .62708 .5572 L F
.721 .414 0 r
.57214 .74738 m .57248 .74856 L .57277 .74921 L F
.915 .541 .113 r
.57282 .75175 m .57277 .74921 L .57248 .74856 L F
.57282 .75175 m .57373 .75255 L .57277 .74921 L F
0 0 0 r
.28014 .60631 m .27827 .60739 L .27716 .60762 L F
.286 0 0 r
.2817 .60665 m .27827 .60739 L .28014 .60631 L F
.303 0 0 r
.28287 .60542 m .2817 .60665 L .28014 .60631 L F
.921 .569 .122 r
.60088 .6939 m .6022 .69663 L .60225 .69435 L F
.865 .493 .343 r
.51359 .76401 m .51253 .7655 L .51115 .76309 L F
.591 .146 .161 r
.51619 .76538 m .51253 .7655 L .51359 .76401 L F
.292 0 .032 r
.565 .67996 m .56603 .68133 L .56595 .68018 L F
.565 .67996 m .5639 .68183 L .56603 .68133 L F
.385 .235 .552 r
.31926 .61391 m .32135 .61313 L .32131 .61064 L F
.484 .239 .467 r
.31926 .61391 m .32106 .61499 L .32135 .61313 L F
.31926 .61391 m .31854 .61608 L .32106 .61499 L F
.021 .026 .521 r
.64522 .49838 m .64701 .49932 L .64599 .49823 L F
.032 .124 .629 r
.64461 .49849 m .64522 .49838 L .6476 .49725 L F
.801 .999 .844 r
.6476 .49725 m .64522 .49838 L .64804 .49572 L F
.021 .026 .521 r
.64522 .49838 m .64599 .49823 L .64552 .49773 L F
.032 .124 .629 r
.64431 .49862 m .64522 .49838 L .64461 .49849 L F
.35 .579 .928 r
.64804 .49572 m .64869 .49719 L .6476 .49725 L F
.281 0 0 r
.28455 .60496 m .2817 .60665 L .28287 .60542 L F
.335 .145 .468 r
.262 .62131 m .26032 .62072 L .26248 .61917 L F
.262 .62131 m .25974 .62251 L .26032 .62072 L F
.526 .354 .591 r
.70366 .5861 m .7061 .58793 L .70675 .58576 L F
.432 .368 .686 r
.70427 .58833 m .7061 .58793 L .70366 .5861 L F
.051 .618 .751 r
.64811 .50558 m .65151 .50557 L .65039 .50553 L F
.817 .343 .08 r
.65039 .50553 m .65151 .50557 L .6523 .50698 L F
.304 0 .078 r
.36277 .65775 m .36079 .65784 L .36047 .65841 L F
.467 .159 .36 r
.53142 .80729 m .53171 .80519 L .53407 .80481 L F
.636 .696 .889 r
.71524 .50772 m .71185 .50553 L .71413 .50458 L F
.628 .626 .829 r
.71761 .50589 m .71524 .50772 L .71413 .50458 L F
.678 .697 .86 r
.39245 .69862 m .39038 .7002 L .38949 .69847 L F
.501 .453 .735 r
.35058 .60146 m .34862 .60354 L .34799 .59982 L F
.423 .347 .667 r
.35094 .6051 m .34862 .60354 L .35058 .60146 L F
.35094 .6051 m .34908 .60539 L .34862 .60354 L F
.465 .128 .31 r
.29716 .63585 m .29946 .63547 L .30059 .63308 L F
.415 .043 .222 r
.29946 .63547 m .30285 .63291 L .30059 .63308 L F
0 .014 .551 r
.68138 .53367 m .68142 .53355 L .6802 .53305 L F
.68138 .53367 m .68355 .53623 L .68142 .53355 L F
.414 .283 .591 r
.4544 .75539 m .45643 .75727 L .45662 .75449 L F
.4544 .75539 m .45444 .75792 L .45643 .75727 L F
.429 .101 .305 r
.26909 .61291 m .26617 .61561 L .26718 .61324 L F
.693 .396 .468 r
.6057 .56123 m .60562 .56304 L .6021 .56321 L F
.672 .477 .613 r
.60776 .56062 m .60562 .56304 L .6057 .56123 L F
.792 .644 .088 r
.57243 .76916 m .57229 .77103 L .57239 .77149 L F
.323 .727 .98 r
.29865 .59101 m .30019 .59183 L .29664 .59104 L F
.294 .749 .955 r
.29865 .59101 m .30223 .59143 L .30019 .59183 L F
.423 .073 .265 r
.31431 .61706 m .3136 .61884 L .31592 .61826 L F
.438 .067 .236 r
.31431 .61706 m .31592 .61826 L .31658 .61675 L F
.409 .142 .394 r
.31639 .6435 m .3144 .64409 L .31688 .64167 L F
.457 .208 .447 r
.31881 .64106 m .31639 .6435 L .31688 .64167 L F
.626 .468 .648 r
.68243 .53133 m .67992 .5308 L .68144 .52926 L F
.68243 .53133 m .6802 .53305 L .67992 .5308 L F
.52 .416 .676 r
.35241 .67212 m .35442 .67169 L .35406 .66951 L F
.523 .446 .71 r
.35241 .67212 m .35511 .67441 L .35442 .67169 L F
.35241 .67212 m .35297 .67474 L .35511 .67441 L F
.631 .832 .978 r
.44316 .65139 m .43978 .65104 L .44177 .65058 L F
.377 .83 .929 r
.44177 .65058 m .44519 .65033 L .44316 .65139 L F
0 .124 .583 r
.46973 .67046 m .47163 .67189 L .47129 .67167 L F
.466 .401 .7 r
.47163 .67189 m .47083 .67418 L .47129 .67167 L F
.37 .06 .303 r
.71961 .5138 m .7195 .51582 L .71685 .516 L F
.219 0 .274 r
.72127 .5148 m .71961 .5138 L .7211 .51205 L F
.72127 .5148 m .7195 .51582 L .71961 .5138 L F
.429 .296 .598 r
.43995 .67742 m .44163 .67438 L .43969 .67496 L F
.473 .086 .225 r
.48131 .77482 m .48111 .77587 L .47903 .77514 L F
.612 .224 .283 r
.4845 .77446 m .48112 .77586 L .48131 .77482 L F
.48112 .77586 m .48111 .77587 L .48111 .77585 L F
.48112 .77586 m .48111 .77585 L .48131 .77482 L F
.4845 .77446 m .48323 .77666 L .48115 .77589 L F
.48112 .77586 m .48115 .77589 L .48111 .77587 L F
.4845 .77446 m .48115 .77589 L .48112 .77586 L F
.431 .241 .521 r
.47955 .77433 m .48145 .77586 L .4811 .77195 L F
.48145 .77586 m .48152 .77586 L .4811 .77195 L F
.48037 .77513 m .48152 .77593 L .47955 .77433 L F
.481 .77576 m .48152 .77593 L .47945 .7745 L F
0 0 .29 r
.4811 .77195 m .48152 .77586 L .48189 .77315 L F
.452 .504 .822 r
.48152 .77586 m .48288 .77576 L .48189 .77315 L F
0 0 .29 r
.48152 .77586 m .48152 .77593 L .48189 .77315 L F
.452 .504 .822 r
.48115 .77589 m .48152 .77586 L .48189 .77315 L F
.48111 .77587 m .48115 .77589 L .48189 .77315 L F
.48115 .77589 m .48323 .77666 L .48288 .77576 L F
.431 .241 .521 r
.48145 .77586 m .48152 .77593 L .48152 .77586 L F
.47945 .7745 m .48037 .77513 L .47955 .77433 L F
.47903 .77514 m .481 .77576 L .47945 .7745 L F
.446 .2 .445 r
.48111 .77587 m .48152 .77593 L .47903 .77514 L F
.559 .69 .928 r
.25972 .63737 m .2584 .6388 L .25738 .63765 L F
.25972 .63737 m .26089 .63894 L .2584 .6388 L F
.815 .733 .206 r
.62679 .51344 m .62648 .51545 L .6266 .51568 L F
.857 .535 .44 r
.62528 .51802 m .6266 .51568 L .62648 .51545 L F
.62528 .51802 m .6281 .5189 L .6266 .51568 L F
.806 .849 .391 r
.62288 .50824 m .62169 .51143 L .62206 .50975 L F
0 0 .408 r
.62288 .50824 m .62416 .50452 L .62527 .50553 L F
.62288 .50824 m .62421 .5068 L .62416 .50452 L F
.213 0 0 r
.62288 .50824 m .62426 .50907 L .62421 .5068 L F
.62288 .50824 m .62206 .50975 L .62426 .50907 L F
.563 .218 .342 r
.42951 .68472 m .43186 .68484 L .42999 .68329 L F
.517 .234 .424 r
.42999 .68329 m .43186 .68484 L .43225 .68297 L F
.575 .423 .637 r
.52716 .74595 m .52909 .74305 L .52659 .74389 L F
.881 .446 .108 r
.57004 .74546 m .57214 .74738 L .57046 .74434 L F
.1 0 0 r
.66216 .54178 m .66107 .54261 L .65872 .54309 L F
.098 0 0 r
.66447 .54123 m .66107 .54261 L .66216 .54178 L F
.868 .712 .686 r
.62963 .50211 m .62787 .50233 L .62978 .49971 L F
.534 .309 .519 r
.25774 .58501 m .26011 .58294 L .2582 .58421 L F
.422 0 0 r
.51888 .80106 m .51552 .80187 L .51801 .80225 L F
.51888 .80106 m .5158 .79941 L .51552 .80187 L F
.474 0 .042 r
.52124 .80175 m .51888 .80106 L .51801 .80225 L F
.378 .223 .542 r
.25785 .62447 m .25793 .62631 L .25596 .6277 L F
.518 .41 .671 r
.25793 .62631 m .2561 .63021 L .25596 .6277 L F
.391 .272 .596 r
.58246 .74418 m .5843 .74588 L .58335 .7441 L F
.58246 .74418 m .5833 .74604 L .5843 .74588 L F
.479 .331 .602 r
.77783 .61468 m .77576 .61342 L .77907 .61382 L F
.586 .946 .867 r
.77907 .61382 m .77888 .61352 L .78054 .61246 L F
.519 .869 .62 r
.78054 .61246 m .77783 .61468 L .77907 .61382 L F
.406 .211 .501 r
.54767 .77476 m .54766 .77721 L .54598 .77754 L F
.614 .538 .745 r
.54962 .77366 m .54766 .77721 L .54767 .77476 L F
.893 .549 .389 r
.64564 .50539 m .64472 .50706 L .64447 .50527 L F
.298 0 0 r
.64811 .50558 m .64472 .50706 L .64564 .50539 L F
.744 .397 .395 r
.54598 .77754 m .54582 .77882 L .54326 .77935 L F
.592 .398 .588 r
.54766 .77721 m .54582 .77882 L .54598 .77754 L F
.657 .799 .349 r
.65567 .51461 m .65446 .51708 L .65606 .51395 L F
0 0 .484 r
.6575 .51745 m .65567 .51461 L .6572 .51602 L F
.6575 .51745 m .65729 .51689 L .65567 .51461 L F
0 0 .501 r
.65567 .51461 m .65662 .51561 L .65519 .51543 L F
.904 .818 .752 r
.65306 .51625 m .65446 .51708 L .65567 .51461 L F
0 0 .501 r
.65567 .51461 m .65519 .51543 L .65388 .51526 L F
.657 .799 .349 r
.65567 .51461 m .65606 .51395 L .65611 .51386 L F
.881 .453 .06 r
.65611 .51386 m .6572 .51602 L .65567 .51461 L F
.618 .621 .831 r
.57996 .68147 m .58134 .6812 L .58037 .67759 L F
.49 0 0 r
.53641 .72072 m .53831 .72128 L .53997 .72099 L F
.567 .023 0 r
.53831 .72128 m .54172 .72184 L .53997 .72099 L F
.525 .252 .443 r
.69828 .52233 m .69825 .52404 L .69589 .5244 L F
.536 .261 .445 r
.69828 .52233 m .70066 .52374 L .69825 .52404 L F
.568 .225 .348 r
.70076 .52232 m .70066 .52374 L .69828 .52233 L F
.878 .671 .62 r
.67503 .53024 m .67329 .53003 L .67357 .52758 L F
.833 .431 .285 r
.67503 .53024 m .67409 .53158 L .67329 .53003 L F
.67503 .53024 m .67722 .53297 L .67409 .53158 L F
.401 .549 .888 r
.31612 .74645 m .31786 .748 L .31792 .74711 L F
.735 .377 .373 r
.52699 .71877 m .52919 .72114 L .53047 .71907 L F
.697 .331 .35 r
.53047 .71907 m .52919 .72114 L .53262 .7212 L F
.625 .452 .629 r
.51245 .73246 m .51375 .73539 L .51049 .73583 L F
.656 .501 .662 r
.51553 .73309 m .51375 .73539 L .51245 .73246 L F
.75 .376 .345 r
.52599 .80534 m .52832 .80799 L .52646 .80712 L F
.975 .708 .461 r
.34523 .72017 m .3436 .72056 L .34164 .7185 L F
.79 .624 .676 r
.64828 .52136 m .65186 .52177 L .6527 .51982 L F
.618 .45 .632 r
.55238 .74138 m .55517 .74107 L .55527 .73852 L F
.566 .391 .604 r
.55238 .74138 m .55507 .74392 L .55517 .74107 L F
.55238 .74138 m .55241 .74451 L .55507 .74392 L F
.664 .96 .939 r
.32796 .72669 m .32712 .72806 L .32879 .72709 L F
.833 .469 .364 r
.61006 .72757 m .61043 .72969 L .61359 .7303 L F
.862 .618 .568 r
.61055 .73162 m .61359 .7303 L .61043 .72969 L F
.61055 .73162 m .61376 .73308 L .61359 .7303 L F
.947 .849 .713 r
.62777 .5212 m .62903 .52213 L .63003 .51857 L F
0 .327 .791 r
.62777 .5212 m .63191 .52405 L .62903 .52213 L F
.003 0 0 r
.74014 .59599 m .73708 .59685 L .73759 .59615 L F
.859 .808 .8 r
.62987 .51626 m .6281 .5189 L .63003 .51857 L F
.947 .849 .713 r
.62777 .5212 m .63003 .51857 L .6281 .5189 L F
.296 0 .237 r
.3144 .64409 m .31351 .6466 L .3116 .64643 L F
.198 0 .194 r
.31521 .64568 m .3144 .64409 L .31639 .6435 L F
.31521 .64568 m .31351 .6466 L .3144 .64409 L F
.566 .498 .738 r
.35189 .6831 m .35396 .68262 L .35334 .68009 L F
.97 .656 .287 r
.43351 .80595 m .43402 .80801 L .43261 .80433 L F
.581 .68 .908 r
.43478 .80408 m .43351 .80595 L .43261 .80433 L F
.43478 .80408 m .43571 .80555 L .43351 .80595 L F
.43351 .80595 m .43478 .80408 L .43261 .80433 L F
.43351 .80595 m .43571 .80555 L .43478 .80408 L F
.751 .321 .229 r
.72654 .61113 m .72605 .61241 L .72428 .61034 L F
0 0 .249 r
.72654 .61113 m .72802 .6077 L .72905 .61077 L F
.64 .451 .611 r
.72654 .61113 m .72741 .61261 L .72605 .61241 L F
.72654 .61113 m .72905 .61077 L .72741 .61261 L F
.26 .509 .902 r
.65791 .50427 m .65714 .50553 L .65649 .50404 L F
.386 .121 .385 r
.71902 .51765 m .71685 .516 L .7195 .51582 L F
.71902 .51765 m .71689 .51847 L .71685 .516 L F
.872 .704 .671 r
.62628 .50305 m .6278 .50482 L .62787 .50233 L F
.62628 .50305 m .62787 .50233 L .62963 .50211 L F
.62628 .50305 m .62963 .50211 L .62818 .50235 L F
.29 .786 .762 r
.63142 .50136 m .62818 .50235 L .62963 .50211 L F
.851 .539 .459 r
.68355 .53623 m .68084 .53732 L .68142 .53355 L F
.68355 .53623 m .68374 .53829 L .68084 .53732 L F
.671 .401 .503 r
.68598 .53802 m .68374 .53829 L .68355 .53623 L F
.442 .432 .753 r
.68668 .51053 m .68873 .51593 L .6903 .51451 L F
0 0 0 r
.68873 .51593 m .69028 .51551 L .6903 .51451 L F
.68873 .51593 m .68799 .51623 L .69028 .51551 L F
.61 .442 .629 r
.47081 .76717 m .46877 .76904 L .46877 .7666 L F
.461 .82 .996 r
.28742 .65227 m .28589 .65163 L .28373 .65202 L F
.335 .757 .976 r
.28742 .65227 m .28941 .65215 L .28589 .65163 L F
.776 .551 .594 r
.50638 .79905 m .50994 .79695 L .50637 .79682 L F
.50638 .79905 m .50999 .79934 L .50994 .79695 L F
.644 .589 .777 r
.54546 .73576 m .54915 .73873 L .54777 .73541 L F
.47 .892 .831 r
.54915 .73873 m .54574 .7401 L .54775 .73816 L F
.059 .254 .748 r
.54777 .73541 m .54915 .73873 L .54989 .73744 L F
.558 .884 .99 r
.54915 .73873 m .54775 .73816 L .54989 .73744 L F
.519 .841 .999 r
.5511 .73807 m .54915 .73873 L .54989 .73744 L F
.612 .378 .538 r
.55171 .74048 m .54915 .73873 L .5511 .73807 L F
.55171 .74048 m .54886 .7411 L .54915 .73873 L F
.652 .43 .569 r
.50464 .74956 m .50708 .74964 L .50714 .74701 L F
.707 .476 .571 r
.50714 .74701 m .50708 .74964 L .51031 .74943 L F
.565 .748 .963 r
.45309 .65096 m .45218 .65274 L .45101 .65128 L F
.45309 .65096 m .45434 .65229 L .45218 .65274 L F
.275 0 0 r
.39837 .71082 m .39687 .71236 L .39474 .71272 L F
.243 0 0 r
.39893 .71195 m .39837 .71082 L .40045 .71034 L F
.39893 .71195 m .39687 .71236 L .39837 .71082 L F
.757 .49 .528 r
.50581 .80219 m .50756 .80264 L .50745 .80492 L F
.726 .448 .505 r
.50756 .80264 m .51104 .80489 L .50745 .80492 L F
.556 .051 .01 r
.47396 .76719 m .4729 .76826 L .47081 .76717 L F
.643 .152 .071 r
.47396 .76719 m .47627 .76866 L .4729 .76826 L F
.5 .218 .418 r
.45255 .68311 m .45002 .68528 L .45035 .68313 L F
.687 .688 .846 r
.73106 .61006 m .73299 .61154 L .72905 .61077 L F
.764 .705 .796 r
.73362 .60744 m .73299 .61154 L .73106 .61006 L F
.73362 .60744 m .7346 .61034 L .73299 .61154 L F
.47 .83 .995 r
.41342 .65001 m .41559 .64956 L .41692 .65017 L F
.461 .821 .995 r
.41559 .64956 m .41908 .64982 L .41692 .65017 L F
.478 .142 .317 r
.41399 .69384 m .4163 .6936 L .41724 .69114 L F
.31 0 .242 r
.41724 .69114 m .41826 .69284 L .41942 .69081 L F
.41724 .69114 m .4163 .6936 L .41826 .69284 L F
.383 .289 .624 r
.35297 .67474 m .35489 .67653 L .35511 .67441 L F
.35297 .67474 m .35297 .67766 L .35489 .67653 L F
.744 .246 .045 r
.52002 .71607 m .52359 .71831 L .52152 .71602 L F
.814 .75 .793 r
.62636 .4976 m .62374 .49696 L .62507 .49469 L F
.335 .485 .86 r
.6273 .49558 m .62636 .4976 L .62507 .49469 L F
.968 .685 .441 r
.62676 .49674 m .62929 .49779 L .62636 .4976 L F
.62829 .49668 m .62929 .49779 L .62676 .49674 L F
.6273 .49558 m .62829 .49668 L .62676 .49674 L F
.6273 .49558 m .62753 .49786 L .62929 .49779 L F
.419 0 .096 r
.62903 .4978 m .63088 .49605 L .62929 .49779 L F
.62753 .49786 m .62952 .49679 L .62903 .4978 L F
.62952 .49679 m .63088 .49605 L .62903 .4978 L F
.479 .643 .929 r
.62909 .49487 m .62995 .49589 L .6273 .49558 L F
.419 0 .096 r
.62982 .49662 m .63056 .49659 L .63088 .49605 L F
.479 .643 .929 r
.62995 .49589 m .63088 .497 L .62965 .49651 L F
.62995 .49589 m .62965 .49651 L .6273 .49558 L F
.419 0 .096 r
.62753 .49786 m .63047 .49674 L .63056 .49659 L F
.62753 .49786 m .63056 .49659 L .62982 .49662 L F
.321 0 0 r
.63035 .49679 m .62753 .49786 L .6273 .49558 L F
.249 0 0 r
.63237 .49724 m .62992 .49768 L .63088 .497 L F
.39 0 .081 r
.6313 .49639 m .62992 .49768 L .63237 .49724 L F
.63088 .49605 m .63047 .49674 L .6313 .49639 L F
.321 0 0 r
.63088 .497 m .62834 .49765 L .63036 .49679 L F
.39 0 .081 r
.63047 .49674 m .62992 .49768 L .6313 .49639 L F
.321 0 0 r
.63036 .49679 m .62753 .49786 L .63035 .49679 L F
.62834 .49765 m .62753 .49786 L .63036 .49679 L F
.63022 .49717 m .62992 .49768 L .62753 .49786 L F
.63088 .497 m .62992 .49768 L .63022 .49717 L F
.419 0 .096 r
.62753 .49786 m .62992 .49768 L .63047 .49674 L F
.963 .638 .26 r
.62896 .49704 m .6295 .49837 L .62992 .49768 L F
.6295 .49837 m .62987 .49927 L .62992 .49768 L F
.715 .792 .912 r
.3523 .69318 m .35449 .69051 L .35354 .69146 L F
.557 .594 .846 r
.73642 .61826 m .73697 .62004 L .73848 .61783 L F
.573 .617 .858 r
.73697 .62004 m .73945 .61963 L .73848 .61783 L F
.643 .631 .823 r
.35171 .69667 m .3547 .69719 L .35355 .69401 L F
.976 .806 .608 r
.55225 .76391 m .55027 .76531 L .55035 .76242 L F
.55225 .76391 m .55147 .766 L .55027 .76531 L F
.302 .024 .313 r
.75639 .60637 m .7588 .60673 L .75911 .60492 L F
.75639 .60637 m .75688 .60751 L .7588 .60673 L F
.49 .18 .367 r
.43429 .69312 m .43109 .69644 L .43215 .69378 L F
.965 .747 .559 r
.70972 .59054 m .71057 .59157 L .70946 .58834 L F
.754 .504 .554 r
.70734 .59341 m .71057 .59157 L .70972 .59054 L F
.70734 .59341 m .71091 .59439 L .71057 .59157 L F
.311 .359 .751 r
.71057 .59157 m .71306 .5932 L .71095 .58979 L F
.321 .785 .939 r
.4811 .77195 m .48228 .77144 L .48068 .77145 L F
0 0 .29 r
.4811 .77195 m .48189 .77315 L .48228 .77144 L F
.733 .413 .44 r
.51081 .76023 m .50909 .76155 L .50711 .76017 L F
.782 .513 .53 r
.51081 .76023 m .50919 .76293 L .50909 .76155 L F
.51081 .76023 m .51115 .76309 L .50919 .76293 L F
.652 .578 .76 r
.76788 .61635 m .76572 .61922 L .76535 .61705 L F
.576 .474 .701 r
.76788 .61635 m .76827 .61931 L .76572 .61922 L F
.408 .247 .549 r
.76781 .62049 m .76572 .61922 L .76827 .61931 L F
.76781 .62049 m .76568 .62251 L .76572 .61922 L F
.801 .548 .555 r
.49705 .79684 m .49703 .79925 L .49872 .79666 L F
.712 .49 .585 r
.50057 .79951 m .49872 .79666 L .49703 .79925 L F
.50057 .79951 m .50094 .79697 L .49872 .79666 L F
.264 0 .017 r
.3124 .64765 m .3116 .64643 L .31351 .6466 L F
.3124 .64765 m .31047 .64812 L .3116 .64643 L F
.526 .774 .988 r
.34256 .7267 m .34498 .72813 L .34274 .72785 L F
.523 .26 .458 r
.42208 .68861 m .42437 .68834 L .42465 .68609 L F
.41 .165 .429 r
.42465 .68609 m .42632 .68766 L .42728 .68521 L F
.42465 .68609 m .42437 .68834 L .42632 .68766 L F
.715 .296 .25 r
.49556 .75867 m .49773 .76035 L .49443 .75997 L F
.617 .774 .956 r
.49445 .75754 m .49556 .75867 L .49758 .75778 L F
.448 .024 .141 r
.73417 .5942 m .73117 .59479 L .73118 .5956 L F
.271 .414 .823 r
.68684 .51592 m .68592 .51742 L .68458 .51605 L F
.651 .642 .828 r
.73718 .60881 m .7346 .61034 L .73362 .60744 L F
.322 .703 .981 r
.75285 .59035 m .75406 .59134 L .75592 .59116 L F
.393 .253 .569 r
.3104 .62467 m .31209 .62421 L .31201 .62177 L F
.328 .155 .488 r
.3104 .62467 m .31173 .62659 L .31209 .62421 L F
.3104 .62467 m .31022 .62738 L .31173 .62659 L F
.358 .092 .368 r
.34232 .61357 m .34471 .61091 L .34434 .61282 L F
.452 .2 .441 r
.34471 .61091 m .34583 .61093 L .34434 .61282 L F
.34471 .61091 m .34677 .61029 L .34583 .61093 L F
.62 .414 .58 r
.50057 .79951 m .50333 .79633 L .50094 .79697 L F
.392 0 .13 r
.44957 .68567 m .44445 .6879 L .44492 .68644 L F
.479 .149 .329 r
.46731 .7521 m .4696 .75189 L .47044 .74959 L F
.46 .116 .295 r
.4696 .75189 m .47273 .74937 L .47044 .74959 L F
.689 .398 .476 r
.51308 .77154 m .51203 .7743 L .5095 .7739 L F
.598 .302 .438 r
.51495 .77374 m .51308 .77154 L .5152 .77166 L F
.51495 .77374 m .51203 .7743 L .51308 .77154 L F
.654 .785 .944 r
.3487 .70855 m .35214 .7085 L .35053 .70756 L F
0 0 .017 r
.58912 .6832 m .58927 .68365 L .59015 .68201 L F
.58912 .6832 m .58899 .68569 L .58927 .68365 L F
.394 .144 .413 r
.32393 .63609 m .32675 .63221 L .32572 .63539 L F
.449 .232 .491 r
.3282 .63041 m .32835 .63283 L .32675 .63221 L F
.469 .19 .406 r
.32675 .63221 m .32785 .63478 L .32572 .63539 L F
.32675 .63221 m .32835 .63283 L .32785 .63478 L F
.538 .57 .835 r
.67931 .48976 m .68225 .49063 L .68023 .49134 L F
.361 .756 .986 r
.3156 .59261 m .31506 .59349 L .31359 .59265 L F
.3156 .59261 m .31706 .59337 L .31506 .59349 L F
.508 .09 .183 r
.5241 .75937 m .52424 .75853 L .52634 .75957 L F
.497 .122 .259 r
.52634 .75957 m .52424 .75853 L .52739 .75771 L F
.412 .196 .473 r
.33047 .62987 m .32835 .63283 L .3282 .63041 L F
.493 .351 .616 r
.45273 .76325 m .45453 .76036 L .45266 .76081 L F
.886 .811 .769 r
.61528 .52537 m .6123 .52725 L .6142 .52426 L F
.404 .083 .304 r
.49793 .73242 m .49998 .73219 L .50067 .72986 L F
.5 .259 .48 r
.49998 .73219 m .5027 .72801 L .50067 .72986 L F
.619 .48 .671 r
.49247 .76023 m .48977 .7583 L .49201 .75767 L F
.49247 .76023 m .49 .76074 L .48977 .7583 L F
.51 .702 .956 r
.30112 .60186 m .30245 .60339 L .30437 .60315 L F
.784 .627 .686 r
.77109 .61641 m .76788 .61635 L .77009 .61366 L F
.726 .581 .692 r
.77166 .61742 m .76788 .61635 L .77109 .61641 L F
.643 .384 .511 r
.77109 .61641 m .77372 .61824 L .77166 .61742 L F
.683 .345 .397 r
.77351 .61676 m .77372 .61824 L .77109 .61641 L F
.952 .605 .232 r
.6666 .52431 m .66613 .52228 L .66504 .52127 L F
.828 .501 .435 r
.60701 .72679 m .60871 .72943 L .61006 .72757 L F
.772 .423 .395 r
.60871 .72943 m .61043 .72969 L .61006 .72757 L F
.994 .864 .532 r
.6575 .51745 m .65814 .51959 L .65755 .52188 L F
.649 .727 .906 r
.6036 .7522 m .60722 .75312 L .60636 .7517 L F
.682 .862 .968 r
.60722 .75312 m .60815 .75122 L .60636 .7517 L F
.60722 .75312 m .60928 .75211 L .60815 .75122 L F
.825 .729 .759 r
.53618 .80014 m .53672 .80196 L .53414 .80235 L F
.754 .438 .45 r
.53414 .80235 m .53672 .80196 L .53608 .80452 L F
.588 .539 .767 r
.53823 .79909 m .53672 .80196 L .53618 .80014 L F
.53823 .79909 m .53859 .80145 L .53672 .80196 L F
.387 .037 .244 r
.53672 .80196 m .53799 .8036 L .53608 .80452 L F
.53672 .80196 m .53859 .80145 L .53799 .8036 L F
.69 .829 .95 r
.42718 .66244 m .42848 .6635 L .43068 .66265 L F
.774 .394 .336 r
.48059 .79635 m .48378 .79681 L .48242 .79855 L F
.732 .339 .305 r
.48378 .79681 m .4859 .79902 L .48242 .79855 L F
.969 .648 .319 r
.70831 .50324 m .71108 .5027 L .71039 .50274 L F
.508 .368 .626 r
.71251 .50041 m .71108 .5027 L .71051 .49938 L F
.71251 .50041 m .71356 .50261 L .71108 .5027 L F
.538 .096 .148 r
.71356 .50261 m .71039 .50274 L .71108 .5027 L F
.093 0 0 r
.74749 .59344 m .74838 .59211 L .75056 .59121 L F
.533 .329 .55 r
.53946 .74957 m .5369 .75221 L .53672 .74979 L F
.549 .357 .573 r
.49116 .739 m .49342 .73864 L .49356 .73579 L F
.467 .242 .487 r
.49342 .73864 m .49578 .73572 L .49356 .73579 L F
.759 .769 .861 r
.71051 .49938 m .70855 .50029 L .7071 .49908 L F
.698 .281 .251 r
.64007 .49468 m .63988 .49557 L .63782 .49412 L F
.599 .54 .76 r
.64128 .4919 m .64294 .49437 L .64007 .49468 L F
.504 .137 .276 r
.64294 .49437 m .63988 .49557 L .64007 .49468 L F
.605 .631 .85 r
.47023 .77551 m .46706 .77553 L .46842 .77389 L F
.35 0 .119 r
.74147 .5908 m .74384 .59029 L .74456 .58851 L F
.216 0 .067 r
.74456 .58851 m .74603 .58943 L .7469 .58807 L F
.74456 .58851 m .74384 .59029 L .74603 .58943 L F
0 0 0 r
.76748 .5885 m .77035 .58615 L .76984 .58842 L F
.583 .661 .891 r
.77218 .58511 m .77035 .58615 L .76853 .58302 L F
.54 .274 .46 r
.77352 .58634 m .77035 .58615 L .77218 .58511 L F
.77352 .58634 m .76984 .58842 L .77035 .58615 L F
.118 0 0 r
.55527 .73852 m .55171 .74048 L .5511 .73807 L F
.55527 .73852 m .55317 .74013 L .55171 .74048 L F
.014 .245 .75 r
.5558 .73938 m .55527 .73852 L .55517 .74107 L F
.453 .287 .565 r
.55745 .74048 m .55717 .74327 L .55904 .74254 L F
.475 .337 .613 r
.55795 .74122 m .55717 .74327 L .55904 .74254 L F
.664 .262 .273 r
.55527 .73852 m .55745 .74048 L .55698 .74044 L F
.55527 .73852 m .55698 .74044 L .55649 .74005 L F
.014 .245 .75 r
.55599 .73886 m .55745 .74048 L .55527 .73852 L F
.735 .535 .621 r
.55745 .74048 m .55717 .74327 L .55701 .74079 L F
.475 .337 .613 r
.55699 .74045 m .55717 .74327 L .55795 .74122 L F
.55626 .73986 m .55717 .74327 L .55699 .74045 L F
.465 .277 .54 r
.55517 .74107 m .55717 .74327 L .55626 .73986 L F
.55517 .74107 m .55507 .74392 L .55717 .74327 L F
.735 .535 .621 r
.55701 .74079 m .55717 .74327 L .55378 .74307 L F
.465 .277 .54 r
.55517 .74107 m .55626 .73986 L .5558 .73938 L F
.735 .535 .621 r
.55698 .74044 m .55378 .74307 L .55317 .74013 L F
.55745 .74048 m .55701 .74079 L .55698 .74044 L F
.55701 .74079 m .55378 .74307 L .55698 .74044 L F
.475 .337 .613 r
.55599 .73886 m .55626 .73986 L .55698 .74044 L F
.55694 .74 m .55698 .74044 L .55795 .74122 L F
.55599 .73886 m .55698 .74044 L .55694 .74 L F
.664 .262 .273 r
.55649 .74005 m .55698 .74044 L .55679 .74042 L F
.5558 .73938 m .55679 .74042 L .55644 .74039 L F
.55527 .73852 m .55679 .74042 L .5558 .73938 L F
.465 .277 .54 r
.5558 .73938 m .55626 .73986 L .55599 .73886 L F
.014 .245 .75 r
.55599 .73886 m .55527 .73852 L .5558 .73938 L F
.664 .262 .273 r
.55527 .73852 m .55644 .74039 L .55317 .74013 L F
.507 .818 1 r
.5152 .77166 m .51854 .772 L .51698 .77134 L F
.544 .055 0 r
.51854 .772 m .51961 .77109 L .51698 .77134 L F
.775 .375 .296 r
.52203 .7742 m .52094 .77468 L .51854 .772 L F
.544 .055 0 r
.51854 .772 m .51969 .77335 L .51961 .77109 L F
.587 .429 .635 r
.51969 .77335 m .51936 .77619 L .51745 .77618 L F
0 0 0 r
.51984 .77356 m .51969 .77335 L .51913 .77432 L F
.52082 .77252 m .51969 .77335 L .51984 .77356 L F
.544 .055 0 r
.51854 .772 m .51952 .7731 L .51969 .77335 L F
.51952 .7731 m .52094 .77468 L .51969 .77335 L F
.339 .338 .712 r
.52716 .74595 m .52756 .75107 L .5298 .74797 L F
.299 .003 .283 r
.52683 .75081 m .5298 .74797 L .52756 .75107 L F
.149 0 0 r
.56878 .68347 m .56869 .68238 L .57093 .68285 L F
.56878 .68347 m .56699 .68422 L .56869 .68238 L F
.875 .96 .622 r
.66576 .53832 m .66713 .53629 L .66585 .5374 L F
.931 .97 .736 r
.66718 .53408 m .66713 .53629 L .66885 .53322 L F
.94 .944 .61 r
.66585 .5374 m .66713 .53629 L .66718 .53408 L F
.897 .933 .831 r
.53913 .77459 m .54195 .77184 L .54019 .77154 L F
.589 .336 .501 r
.53913 .77459 m .54188 .77413 L .54195 .77184 L F
.427 .432 .762 r
.54374 .77146 m .54195 .77184 L .54123 .76916 L F
.293 .778 .911 r
.54019 .77154 m .54195 .77184 L .54374 .77146 L F
.165 0 0 r
.63987 .55175 m .64092 .5505 L .64325 .54982 L F
.504 0 0 r
.39998 .69826 m .40245 .69867 L .40416 .69758 L F
.468 .03 .122 r
.40245 .69867 m .40629 .69692 L .40416 .69758 L F
.455 .747 .991 r
.27321 .58504 m .27277 .58642 L .27121 .58536 L F
.27321 .58504 m .27488 .58624 L .27277 .58642 L F
.142 0 0 r
.57907 .67719 m .57767 .67736 L .57529 .67727 L F
.57907 .67719 m .57767 .67736 L .57529 .67727 L F
.477 0 0 r
.58037 .67759 m .57767 .67736 L .57907 .67719 L F
.679 .963 .937 r
.33785 .70211 m .33653 .70312 L .33522 .70375 L F
.446 .374 .683 r
.45151 .76913 m .45285 .76557 L .451 .76594 L F
.45151 .76913 m .45333 .7688 L .45285 .76557 L F
.447 .379 .688 r
.45151 .76913 m .45383 .77127 L .45333 .7688 L F
.515 .383 .638 r
.45151 .76913 m .45176 .77171 L .45383 .77127 L F
.759 .769 .861 r
.71051 .49938 m .7071 .49908 L .70926 .49794 L F
.701 .817 .937 r
.71282 .49769 m .71051 .49938 L .70926 .49794 L F
.592 .558 .786 r
.71282 .49769 m .71251 .50041 L .71051 .49938 L F
.497 .36 .625 r
.54763 .76111 m .54825 .76347 L .55035 .76242 L F
0 0 0 r
.51228 .71642 m .51346 .71578 L .51453 .71386 L F
.538 .134 .223 r
.51453 .71386 m .51346 .71578 L .51678 .7151 L F
.514 .748 .98 r
.52994 .77136 m .53382 .77198 L .53289 .77091 L F
0 .443 .856 r
.53382 .77198 m .53453 .77179 L .53289 .77091 L F
.53382 .77198 m .53585 .77296 L .53453 .77179 L F
.705 .623 .763 r
.53341 .77454 m .53585 .77296 L .53382 .77198 L F
.398 .209 .505 r
.3348 .62623 m .33248 .62496 L .33505 .62413 L F
.629 .657 .858 r
.63782 .49412 m .63401 .49247 L .63646 .49143 L F
.63782 .49412 m .63646 .49143 L .63661 .49405 L F
.92 .659 .526 r
.63782 .49412 m .63661 .49405 L .63646 .49143 L F
.237 .407 .829 r
.63782 .49412 m .63869 .49314 L .63661 .49405 L F
.63782 .49412 m .63988 .49557 L .63869 .49314 L F
0 .127 .641 r
.66136 .51323 m .66167 .51397 L .6613 .51238 L F
.432 .5 .829 r
.43593 .66182 m .43738 .6647 L .43845 .66271 L F
.772 .39 0 r
.591 .69011 m .58975 .68773 L .59117 .68888 L F
.296 .775 .923 r
.2743 .6389 m .27772 .63893 L .27588 .63958 L F
.845 .72 .726 r
.52714 .77182 m .52994 .77136 L .52873 .76856 L F
0 0 0 r
.5257 .77341 m .52994 .77136 L .52714 .77182 L F
.579 .484 .71 r
.52994 .77136 m .53289 .77091 L .53194 .77056 L F
.112 .659 .823 r
.29296 .65229 m .29154 .65211 L .28941 .65215 L F
.381 .829 .936 r
.29507 .65182 m .29366 .65162 L .29296 .65229 L F
.385 .834 .932 r
.29296 .65229 m .29366 .65162 L .29154 .65211 L F
.336 0 .099 r
.39212 .66914 m .39077 .67113 L .38863 .67155 L F
.201 0 .021 r
.39281 .67034 m .39212 .66914 L .39436 .66911 L F
.39281 .67034 m .39077 .67113 L .39212 .66914 L F
.278 .335 .742 r
.67143 .53046 m .66885 .53322 L .66805 .52972 L F
.869 .441 .022 r
.67078 .52799 m .6728 .53093 L .67151 .53056 L F
.278 .335 .742 r
.67147 .53047 m .67147 .53051 L .67143 .53046 L F
.67148 .5305 m .67147 .53051 L .67147 .53047 L F
.967 .801 .624 r
.66805 .52972 m .66854 .52785 L .66718 .52646 L F
.93 .688 .55 r
.67078 .52799 m .66976 .52871 L .66896 .52705 L F
.134 .463 .89 r
.67131 .53038 m .66805 .52972 L .66775 .5286 L F
.67136 .53041 m .67133 .5304 L .67131 .53038 L F
.67133 .5304 m .66805 .52972 L .67131 .53038 L F
.67081 .53018 m .66775 .5286 L .67046 .53003 L F
.67145 .53045 m .67139 .53044 L .67136 .53041 L F
.67147 .53047 m .66805 .52972 L .67145 .53045 L F
.93 .688 .55 r
.67089 .52993 m .67091 .53025 L .66976 .52871 L F
.134 .463 .89 r
.67139 .53044 m .66805 .52972 L .67136 .53041 L F
.489 .808 1 r
.66781 .53064 m .67144 .53048 L .67044 .53004 L F
.93 .688 .55 r
.67091 .53025 m .67092 .53038 L .67075 .53014 L F
.67091 .53025 m .67075 .53014 L .66976 .52871 L F
.489 .808 1 r
.67044 .53004 m .67086 .53021 L .67046 .53003 L F
.869 .441 .022 r
.67137 .53042 m .67151 .53056 L .67091 .53022 L F
.489 .808 1 r
.67086 .53021 m .6715 .53048 L .67081 .53018 L F
.67086 .53021 m .67081 .53018 L .67046 .53003 L F
.869 .441 .022 r
.67091 .53022 m .67113 .53034 L .67091 .53025 L F
.67078 .52799 m .67151 .53056 L .67083 .52893 L F
.134 .463 .89 r
.6715 .53048 m .67147 .53047 L .67145 .53045 L F
.489 .808 1 r
.67144 .53048 m .6715 .53048 L .67044 .53004 L F
.869 .441 .022 r
.67091 .53025 m .67151 .53056 L .67092 .53038 L F
.67113 .53034 m .67151 .53056 L .67091 .53025 L F
.134 .463 .89 r
.67145 .53045 m .67131 .53038 L .67091 .53022 L F
.869 .441 .022 r
.67089 .52993 m .67137 .53042 L .67091 .53022 L F
.134 .463 .89 r
.6715 .53048 m .67145 .53045 L .67081 .53018 L F
.67145 .53045 m .67091 .53022 L .67081 .53018 L F
.67131 .53038 m .66775 .5286 L .67081 .53018 L F
.206 .364 .801 r
.67046 .53003 m .66775 .5286 L .66896 .52705 L F
.967 .801 .624 r
.66805 .52972 m .66718 .52646 L .66775 .5286 L F
.002 .059 .569 r
.66896 .52705 m .66775 .5286 L .66718 .52646 L F
.206 .364 .801 r
.67046 .53003 m .67046 .53003 L .66583 .53033 L F
.67046 .53003 m .66896 .52705 L .6682 .52784 L F
.67046 .53003 m .6682 .52784 L .66583 .53033 L F
.278 .335 .742 r
.67147 .53051 m .66885 .53322 L .67143 .53046 L F
.429 .576 .898 r
.66899 .53177 m .66885 .53322 L .6715 .53048 L F
.278 .335 .742 r
.6715 .53048 m .67148 .5305 L .67147 .53047 L F
.489 .808 1 r
.66781 .53064 m .66899 .53177 L .6715 .53048 L F
.488 .849 .992 r
.66583 .53033 m .66781 .53064 L .67046 .53003 L F
.887 .477 .229 r
.66883 .52937 m .67075 .5303 L .67015 .53182 L F
.67075 .5303 m .67092 .53038 L .67089 .53044 L F
.67075 .5303 m .67089 .53044 L .67015 .53182 L F
.93 .688 .55 r
.66976 .52871 m .67007 .52917 L .66883 .52937 L F
.67007 .52917 m .67076 .53016 L .67054 .53007 L F
.67007 .52917 m .67054 .53007 L .66883 .52937 L F
.67076 .53016 m .67092 .53038 L .66892 .52942 L F
.67076 .53016 m .66892 .52942 L .66883 .52937 L F
.67078 .52799 m .67089 .52993 L .66976 .52871 L F
.66976 .52871 m .66883 .52937 L .66892 .52782 L F
.66976 .52871 m .66892 .52782 L .66896 .52705 L F
.869 .441 .022 r
.67083 .52893 m .67147 .53047 L .67089 .52993 L F
.67147 .53047 m .67151 .53056 L .67089 .52993 L F
.932 .57 .304 r
.67151 .53056 m .67198 .53234 L .67092 .53038 L F
.6728 .53093 m .6724 .53161 L .67151 .53056 L F
.6724 .53161 m .67198 .53234 L .67151 .53056 L F
.931 .97 .736 r
.66718 .53408 m .66885 .53322 L .66899 .53177 L F
.979 .685 .333 r
.66445 .51788 m .66546 .51888 L .66522 .51657 L F
0 0 .489 r
.58116 .73822 m .58121 .73796 L .57941 .73551 L F
0 .081 .637 r
.58161 .74036 m .58121 .73796 L .58116 .73822 L F
.215 .712 .915 r
.30415 .59152 m .30776 .59189 L .30585 .59221 L F
.692 .613 .764 r
.50477 .76781 m .50304 .76589 L .50476 .76642 L F
.505 .619 .899 r
.50706 .76567 m .50477 .76781 L .50476 .76642 L F
.50706 .76567 m .50843 .76802 L .50477 .76781 L F
.147 .664 .89 r
.6362 .51144 m .63364 .51064 L .63357 .50986 L F
.6362 .51144 m .63555 .51069 L .63364 .51064 L F
.204 .684 .933 r
.63555 .51069 m .63462 .51017 L .63364 .51064 L F
.587 .553 .783 r
.63004 .50923 m .63079 .51181 L .62783 .51234 L F
.248 0 .095 r
.63079 .51181 m .62813 .51326 L .62783 .51234 L F
.63079 .51181 m .63007 .51344 L .62813 .51326 L F
.702 .623 .765 r
.63364 .51064 m .63079 .51181 L .63004 .50923 L F
.764 .526 .574 r
.63364 .51064 m .63007 .51344 L .63079 .51181 L F
.63364 .51064 m .63336 .51417 L .63007 .51344 L F
0 0 0 r
.63372 .51148 m .63364 .51064 L .63406 .51044 L F
.63372 .51148 m .63406 .51044 L .63462 .51017 L F
.309 .341 .733 r
.63379 .50948 m .63376 .51136 L .63462 .51017 L F
.147 .664 .89 r
.63357 .50986 m .63364 .51064 L .63348 .5098 L F
.781 .644 .711 r
.63314 .50693 m .63348 .5098 L .63113 .50925 L F
.711 .243 .137 r
.63348 .5098 m .63364 .51064 L .63113 .50925 L F
.821 .79 .823 r
.63572 .50658 m .63348 .5098 L .63314 .50693 L F
.702 .623 .765 r
.63364 .51064 m .63004 .50923 L .63113 .50925 L F
.309 .341 .733 r
.63226 .50818 m .63363 .51109 L .63379 .50948 L F
.63363 .51109 m .63376 .51136 L .63379 .50948 L F
0 0 0 r
.63356 .51195 m .63336 .51417 L .6335 .51245 L F
.63358 .51162 m .6335 .51245 L .63364 .51064 L F
.63356 .51195 m .6335 .51245 L .63358 .51162 L F
.63349 .51305 m .63337 .51406 L .63356 .51195 L F
.63337 .51406 m .63336 .51417 L .63356 .51195 L F
.515 .169 .319 r
.63007 .51344 m .63357 .51185 L .62894 .51102 L F
0 0 0 r
.63356 .51195 m .63358 .51162 L .63363 .51176 L F
.515 .169 .319 r
.63357 .51185 m .6336 .51183 L .63357 .51183 L F
.63357 .51185 m .63357 .51183 L .62894 .51102 L F
.6336 .51183 m .63392 .51169 L .63367 .51166 L F
.6336 .51183 m .63367 .51166 L .62894 .51102 L F
.6336 .51183 m .63349 .51305 L .63392 .51169 L F
0 0 0 r
.63349 .51305 m .63356 .51195 L .63359 .51199 L F
.515 .169 .319 r
.63007 .51344 m .63349 .51305 L .6336 .51183 L F
0 0 0 r
.63349 .51305 m .63359 .51199 L .6338 .51226 L F
.63356 .51195 m .63363 .51176 L .6338 .51226 L F
.63358 .51162 m .63364 .51064 L .63372 .51143 L F
.63358 .51162 m .63372 .51143 L .6338 .51226 L F
.309 .341 .733 r
.63376 .51136 m .63392 .51169 L .63462 .51017 L F
.743 .555 .64 r
.62894 .51102 m .63367 .51166 L .63226 .50818 L F
.63367 .51166 m .63392 .51169 L .63376 .51136 L F
.63367 .51166 m .63376 .51136 L .63226 .50818 L F
0 0 0 r
.63392 .51169 m .63349 .51305 L .63462 .51017 L F
.6338 .51226 m .63372 .51148 L .63462 .51017 L F
.513 .557 .839 r
.36289 .7224 m .36575 .72365 L .365 .72073 L F
.729 .727 .848 r
.52153 .76057 m .51988 .76344 L .51906 .76337 L F
.606 .177 .202 r
.51988 .76344 m .51843 .76522 L .51906 .76337 L F
.51988 .76344 m .52066 .76542 L .51843 .76522 L F
.432 .233 .508 r
.5241 .75937 m .51988 .76344 L .52153 .76057 L F
.404 .075 .29 r
.524 .76297 m .51988 .76344 L .52322 .76377 L F
.6 .333 .484 r
.52313 .76734 m .52121 .76584 L .52322 .76377 L F
.52349 .76556 m .52322 .76377 L .524 .76297 L F
.52313 .76734 m .52322 .76377 L .52349 .76556 L F
.404 .075 .29 r
.524 .76297 m .52322 .76377 L .52394 .76384 L F
.524 .76297 m .52319 .76357 L .51988 .76344 L F
.432 .233 .508 r
.52276 .76066 m .52319 .76357 L .51988 .76344 L F
.52319 .76357 m .52322 .76377 L .51988 .76344 L F
.404 .075 .29 r
.52319 .76357 m .52066 .76542 L .51988 .76344 L F
.6 .333 .484 r
.52121 .76584 m .52066 .76542 L .524 .76297 L F
.432 .233 .508 r
.5241 .75937 m .52394 .76384 L .52322 .76377 L F
.5241 .75937 m .52322 .76377 L .52276 .76066 L F
.392 .065 .287 r
.63497 .55202 m .63164 .55393 L .63263 .55249 L F
0 0 .427 r
.34274 .72785 m .34334 .72917 L .34256 .7267 L F
.634 .462 .632 r
.46689 .66915 m .46974 .67109 L .46973 .67046 L F
.676 .158 0 r
.46974 .67109 m .47163 .67189 L .46973 .67046 L F
.638 .433 .588 r
.47103 .67674 m .46844 .67475 L .47083 .67418 L F
.47103 .67674 m .46838 .67716 L .46844 .67475 L F
.49 .339 .603 r
.77576 .61342 m .77612 .61614 L .77351 .61676 L F
.426 .168 .418 r
.77351 .61676 m .77612 .61614 L .77372 .61824 L F
.651 .597 .782 r
.53585 .77296 m .53739 .77633 L .53913 .77459 L F
.486 .108 .248 r
.47965 .74616 m .48298 .744 L .48072 .74416 L F
.34 .815 .893 r
.34836 .5994 m .34799 .59982 L .34648 .5993 L F
.34836 .5994 m .3501 .59934 L .34799 .59982 L F
.501 .453 .735 r
.35058 .60146 m .34799 .59982 L .3501 .59934 L F
.719 .473 .553 r
.52909 .74305 m .5318 .74134 L .52981 .741 L F
.303 .764 .949 r
.41908 .64982 m .42121 .64964 L .42253 .65007 L F
.316 .761 .962 r
.42121 .64964 m .42466 .65 L .42253 .65007 L F
.508 .467 .746 r
.38333 .68746 m .38096 .68876 L .38084 .68582 L F
.612 .524 .73 r
.38333 .68746 m .38207 .69173 L .38096 .68876 L F
.371 .829 .92 r
.28307 .63963 m .28525 .63905 L .2872 .6393 L F
.05 .617 .732 r
.28525 .63905 m .28931 .63894 L .2872 .6393 L F
.339 0 0 r
.3781 .72038 m .3771 .71936 L .37901 .71856 L F
.3781 .72038 m .37539 .72064 L .3771 .71936 L F
.189 0 0 r
.40636 .70816 m .40475 .70933 L .40248 .7097 L F
.247 0 0 r
.40842 .70757 m .40475 .70933 L .40636 .70816 L F
.268 .609 .955 r
.71152 .60508 m .71208 .60421 L .70988 .60369 L F
.213 .537 .925 r
.71152 .60508 m .7131 .60561 L .71208 .60421 L F
.233 .61 .954 r
.7199 .60815 m .72076 .60743 L .71899 .60706 L F
.7199 .60815 m .7218 .60855 L .72076 .60743 L F
.269 0 .046 r
.74244 .59581 m .74523 .59363 L .74408 .59521 L F
.18 0 0 r
.74523 .59363 m .74749 .59344 L .74408 .59521 L F
.846 .886 .868 r
.49773 .76035 m .50111 .75864 L .50063 .75726 L F
.44 .689 .97 r
.50111 .75864 m .50211 .7574 L .50063 .75726 L F
.50111 .75864 m .50323 .75871 L .50211 .7574 L F
0 0 .022 r
.51228 .71642 m .50998 .71921 L .51181 .7179 L F
0 0 0 r
.51228 .71642 m .51316 .71655 L .51346 .71578 L F
.51228 .71642 m .51181 .7179 L .51316 .71655 L F
.19 .317 .764 r
.75405 .61944 m .75612 .61957 L .75325 .61833 L F
.75405 .61944 m .75638 .62144 L .75612 .61957 L F
.78 .494 .503 r
.50581 .80219 m .5045 .80455 L .50433 .80224 L F
.50581 .80219 m .50745 .80492 L .5045 .80455 L F
.248 .187 .589 r
.50577 .8032 m .50433 .80224 L .50577 .80323 L F
.634 .175 .145 r
.50401 .80202 m .50581 .80219 L .50433 .80224 L F
.248 .187 .589 r
.50587 .801 m .50433 .80224 L .50577 .8032 L F
.634 .175 .145 r
.50192 .80183 m .50401 .80202 L .50433 .80224 L F
.758 .445 .455 r
.56548 .71044 m .56872 .71211 L .56898 .71076 L F
.457 .239 .493 r
.3378 .61873 m .34001 .61637 L .33961 .61827 L F
.469 .21 .438 r
.3378 .61873 m .3394 .62106 L .33762 .6199 L F
.3378 .61873 m .33961 .61827 L .3394 .62106 L F
.541 .301 .5 r
.46042 .67995 m .458 .6824 L .45809 .68028 L F
.326 .703 .981 r
.44969 .65032 m .449 .65129 L .44711 .65009 L F
.44969 .65032 m .45101 .65128 L .449 .65129 L F
.143 0 .355 r
.47316 .77725 m .47272 .77999 L .47161 .77989 L F
.084 .327 .804 r
.47272 .77999 m .47392 .78158 L .47161 .77989 L F
.652 .534 .707 r
.4746 .78247 m .47161 .77989 L .47392 .78158 L F
.4746 .78247 m .47213 .7835 L .47161 .77989 L F
.485 .143 .31 r
.62161 .5584 m .6192 .56006 L .61917 .55835 L F
.199 .311 .754 r
.70811 .60214 m .70988 .60369 L .70896 .6011 L F
.078 0 0 r
.38174 .65001 m .38374 .64956 L .38507 .64889 L F
.549 .074 .079 r
.38507 .64889 m .38374 .64956 L .38721 .64933 L F
.156 .501 .909 r
.34223 .60001 m .33867 .5977 L .34134 .59821 L F
.566 .734 .954 r
.34321 .59825 m .34223 .60001 L .34134 .59821 L F
.34321 .59825 m .34437 .59959 L .34223 .60001 L F
.722 .535 .636 r
.77009 .61366 m .76788 .61635 L .76779 .61378 L F
.07 0 0 r
.39288 .64939 m .39504 .64916 L .39639 .64875 L F
.285 0 0 r
.39639 .64875 m .39504 .64916 L .39856 .6489 L F
.613 .625 .838 r
.63932 .5306 m .64078 .52674 L .63813 .52981 L F
.63932 .5306 m .64172 .53023 L .64078 .52674 L F
.396 .823 .963 r
.64041 .52972 m .63932 .5306 L .63813 .52981 L F
.64041 .52972 m .64172 .53023 L .63932 .5306 L F
.812 .563 .563 r
.6278 .50482 m .63102 .50776 L .63096 .50544 L F
.479 .77 .995 r
.31163 .60577 m .31465 .60613 L .31395 .6053 L F
.648 .806 .959 r
.31465 .60613 m .31675 .60541 L .31395 .6053 L F
.442 .208 .462 r
.34001 .61637 m .34232 .61357 L .34181 .61578 L F
.465 .203 .43 r
.34232 .61357 m .34395 .61495 L .34181 .61578 L F
.34232 .61357 m .34434 .61282 L .34395 .61495 L F
.348 0 .18 r
.48822 .7409 m .49077 .74059 L .49116 .739 L F
.448 .059 .208 r
.49116 .739 m .49077 .74059 L .49296 .74 L F
.437 .074 .249 r
.49116 .739 m .49296 .74 L .49342 .73864 L F
.213 0 .069 r
.50707 .72173 m .50872 .72117 L .50998 .71921 L F
0 0 0 r
.50998 .71921 m .51076 .71875 L .51181 .7179 L F
.50998 .71921 m .50872 .72117 L .51076 .71875 L F
.89 .767 .72 r
.60193 .55657 m .60456 .55531 L .604 .55766 L F
.874 .949 .858 r
.60193 .55657 m .60401 .55435 L .60456 .55531 L F
.446 0 0 r
.47763 .76974 m .47871 .77062 L .47627 .76866 L F
.47763 .76974 m .48068 .77145 L .47871 .77062 L F
.658 .432 .565 r
.51306 .74688 m .51598 .74897 L .51599 .74691 L F
.492 .356 .624 r
.451 .76594 m .45285 .76557 L .45273 .76325 L F
.66 .416 .54 r
.46242 .75445 m .46491 .75491 L .46514 .75252 L F
.541 .321 .53 r
.46491 .75491 m .46731 .7521 L .46514 .75252 L F
.645 .42 .563 r
.51031 .74943 m .51285 .74947 L .51306 .74688 L F
.658 .432 .565 r
.51306 .74688 m .51285 .74947 L .51598 .74897 L F
.222 .416 .842 r
.45892 .78808 m .46042 .789 L .4602 .78749 L F
.594 .536 .759 r
.70487 .59224 m .7061 .58793 L .70427 .58833 L F
.856 .969 .649 r
.3473 .71062 m .34675 .71043 L .3487 .70855 L F
.494 .256 .483 r
.3487 .70855 m .34829 .71069 L .3473 .71062 L F
.937 .958 .656 r
.3487 .70855 m .3487 .7067 L .35053 .70756 L F
.3487 .70855 m .34675 .71043 L .3487 .7067 L F
.491 .254 .482 r
.35037 .71019 m .3487 .70855 L .35053 .70756 L F
.35037 .71019 m .34829 .71069 L .3487 .70855 L F
.631 .165 .13 r
.75382 .5842 m .75497 .58276 L .75151 .58267 L F
.404 0 0 r
.75719 .5829 m .75497 .58276 L .75382 .5842 L F
.348 0 0 r
.6603 .50486 m .66269 .50573 L .66144 .50532 L F
.939 .65 .465 r
.66431 .50828 m .66326 .5065 L .66408 .50662 L F
0 .386 .816 r
.66144 .50532 m .66408 .50662 L .66259 .50534 L F
.939 .65 .465 r
.66326 .5065 m .66259 .50534 L .66408 .50662 L F
.408 0 0 r
.66269 .50573 m .66527 .50679 L .66408 .50662 L F
.66527 .50679 m .66627 .5072 L .66408 .50662 L F
.513 .259 .467 r
.44223 .6883 m .43942 .68993 L .44021 .68898 L F
.629 .62 .823 r
.69579 .49969 m .69415 .50275 L .6924 .49879 L F
.598 .582 .806 r
.69662 .5021 m .69415 .50275 L .69579 .49969 L F
.59 .575 .805 r
.6969 .50322 m .69415 .50275 L .69662 .5021 L F
.89 .767 .72 r
.60193 .55657 m .604 .55766 L .60097 .55733 L F
.832 .749 .772 r
.60097 .55733 m .604 .55766 L .60258 .55871 L F
.493 .294 .539 r
.38195 .67974 m .37971 .68237 L .38015 .68042 L F
.237 0 .042 r
.36584 .65539 m .36277 .65775 L .36456 .65702 L F
.366 0 0 r
.36668 .65664 m .36584 .65539 L .36456 .65702 L F
.36668 .65664 m .36806 .6552 L .36584 .65539 L F
.385 .632 .952 r
.33938 .59629 m .33867 .5977 L .33746 .59624 L F
.33938 .59629 m .34134 .59821 L .33867 .5977 L F
.557 .829 .996 r
.43978 .65104 m .43749 .65151 L .43624 .65062 L F
.518 .359 .605 r
.35377 .66605 m .35584 .66565 L .35581 .66339 L F
.521 .399 .654 r
.35406 .66951 m .35584 .66565 L .35377 .66605 L F
.681 .47 .593 r
.51049 .73583 m .51046 .73837 L .50787 .73828 L F
.573 .352 .543 r
.51375 .73539 m .51046 .73837 L .51049 .73583 L F
.418 .323 .64 r
.35094 .6051 m .35111 .60713 L .34908 .60539 L F
.429 .323 .632 r
.35111 .60713 m .34947 .60805 L .34908 .60539 L F
.889 .689 .625 r
.61425 .73526 m .61697 .733 L .61376 .73308 L F
.61425 .73526 m .61682 .73571 L .61697 .733 L F
.134 0 .025 r
.48573 .77532 m .4845 .77446 L .48694 .77445 L F
.48573 .77532 m .48323 .77666 L .4845 .77446 L F
.614 .613 .826 r
.45905 .65828 m .45552 .65596 L .45773 .6554 L F
.636 .644 .841 r
.46132 .65763 m .45905 .65828 L .45773 .6554 L F
.599 .561 .783 r
.46233 .66104 m .45905 .65828 L .46132 .65763 L F
.566 .867 .562 r
.4877 .77084 m .48685 .77186 L .48878 .76989 L F
.186 .096 .514 r
.48849 .77368 m .48685 .77186 L .4877 .77084 L F
.48849 .77368 m .48694 .77445 L .48685 .77186 L F
.485 .824 .999 r
.31163 .60577 m .31242 .60466 L .31015 .60475 L F
.31163 .60577 m .31395 .6053 L .31242 .60466 L F
.784 .8 .866 r
.7025 .50256 m .6994 .50239 L .70119 .50129 L F
.699 .784 .917 r
.70584 .50155 m .7025 .50256 L .70119 .50129 L F
.959 .655 .233 r
.6675 .50665 m .66798 .50546 L .6675 .50437 L F
.918 .954 .62 r
.66798 .50546 m .66947 .50091 L .6675 .50437 L F
.507 .518 .802 r
.7695 .59966 m .77273 .60099 L .77092 .60287 L F
.54 .57 .834 r
.77273 .60099 m .77308 .60273 L .77092 .60287 L F
.719 .473 .553 r
.52909 .74305 m .5319 .74369 L .5318 .74134 L F
.049 .603 .822 r
.49241 .77204 m .493 .77186 L .49137 .77097 L F
.49241 .77204 m .49479 .77226 L .493 .77186 L F
.552 .393 .619 r
.44949 .77439 m .45173 .77422 L .45176 .77171 L F
.564 .454 .687 r
.44949 .77439 m .45232 .77688 L .45173 .77422 L F
.44949 .77439 m .45023 .77777 L .45232 .77688 L F
.451 .798 .998 r
.32431 .75406 m .32621 .75508 L .32401 .75532 L F
.966 .757 .57 r
.32621 .75508 m .32431 .75406 L .32401 .75532 L F
.311 .013 .287 r
.25974 .62251 m .25952 .62405 L .25785 .62447 L F
.446 .225 .483 r
.262 .62131 m .25952 .62405 L .25974 .62251 L F
.485 0 0 r
.47535 .79347 m .47678 .79395 L .47366 .79332 L F
.395 0 .14 r
.40198 .66565 m .39856 .66788 L .4 .66629 L F
.177 .713 .77 r
.28931 .63894 m .29155 .63856 L .29272 .63848 L F
.525 .918 .827 r
.29272 .63848 m .2934 .63769 L .29454 .6374 L F
.504 .91 .881 r
.29272 .63848 m .29155 .63856 L .2934 .63769 L F
0 0 .368 r
.62055 .51321 m .62206 .50975 L .62169 .51143 L F
.599 .534 .753 r
.3547 .69719 m .35609 .69348 L .35355 .69401 L F
.3547 .69719 m .35699 .69681 L .35609 .69348 L F
.665 .141 0 r
.55346 .70735 m .55543 .7093 L .55607 .70838 L F
.923 .88 .458 r
.6586 .49118 m .65844 .49015 L .65932 .48883 L F
.951 .617 .35 r
.65932 .48883 m .65844 .49015 L .65793 .48774 L F
.65932 .48883 m .65844 .49015 L .65793 .48774 L F
.607 .238 .317 r
.52983 .75778 m .52634 .75957 L .52739 .75771 L F
.86 .857 .837 r
.54501 .69867 m .5463 .7 L .54484 .69887 L F
.604 .627 .847 r
.72317 .59689 m .71937 .59472 L .72227 .59583 L F
.399 .779 .991 r
.72454 .59599 m .72317 .59689 L .72227 .59583 L F
.72454 .59599 m .7256 .5967 L .72317 .59689 L F
.815 .829 .86 r
.66363 .48318 m .66017 .48449 L .66258 .48287 L F
.382 .797 .977 r
.66258 .48287 m .66588 .48307 L .66363 .48318 L F
.537 .557 .823 r
.45085 .7825 m .45211 .77983 L .45117 .78006 L F
.45085 .7825 m .45364 .78266 L .45211 .77983 L F
.606 .514 .724 r
.45157 .78367 m .45364 .78266 L .45085 .7825 L F
.521 .374 .622 r
.35297 .67766 m .35538 .67966 L .35489 .67653 L F
.35297 .67766 m .35334 .68009 L .35538 .67966 L F
.424 .073 .264 r
.43942 .68993 m .43655 .69266 L .43711 .69189 L F
.43942 .68993 m .43879 .69236 L .43655 .69266 L F
.513 .259 .467 r
.44223 .6883 m .4421 .68978 L .43942 .68993 L F
.499 .156 .316 r
.4421 .68978 m .43879 .69236 L .43942 .68993 L F
.618 .733 .928 r
.76387 .58428 m .76049 .58336 L .7629 .58279 L F
.624 .74 .93 r
.76625 .58362 m .76387 .58428 L .7629 .58279 L F
.432 .029 .172 r
.51906 .76337 m .51843 .76522 L .51619 .76538 L F
.867 .924 .862 r
.61876 .51633 m .6202 .51316 L .62055 .51321 L F
0 0 .368 r
.62055 .51321 m .62203 .51192 L .62206 .50975 L F
.521 .905 .748 r
.62055 .51321 m .6202 .51316 L .62203 .51192 L F
.441 .18 .422 r
.54099 .73275 m .5383 .73517 L .53938 .73378 L F
.595 .463 .671 r
.53823 .79909 m .5415 .79593 L .53891 .79706 L F
.517 .086 .159 r
.55132 .75418 m .55359 .75415 L .55472 .75241 L F
.26 .475 .878 r
.55472 .75241 m .55577 .75131 L .55314 .75017 L F
0 0 0 r
.55472 .75241 m .55359 .75415 L .55577 .75131 L F
.558 .502 .749 r
.441 .66908 m .44183 .67177 L .44377 .67086 L F
.457 .29 .565 r
.44183 .67177 m .44382 .67347 L .44377 .67086 L F
.44183 .67177 m .44163 .67438 L .44382 .67347 L F
.07 .472 .889 r
.72428 .61034 m .72459 .60964 L .7218 .60855 L F
0 .105 .66 r
.72428 .61034 m .72605 .61241 L .72459 .60964 L F
.356 .79 .966 r
.29843 .65202 m .29715 .65157 L .29507 .65182 L F
.094 0 0 r
.30019 .65145 m .29715 .65157 L .29843 .65202 L F
.745 .243 0 r
.65558 .52942 m .65571 .52897 L .65511 .52839 L F
.65558 .52942 m .65571 .52897 L .65511 .52839 L F
.38 .844 .835 r
.65638 .52796 m .65857 .52731 L .65511 .52839 L F
.748 .799 .894 r
.65571 .52897 m .65857 .52731 L .65638 .52796 L F
.193 .684 .923 r
.31911 .59328 m .32266 .5939 L .32063 .59383 L F
.402 0 .021 r
.24853 .588 m .25075 .58788 L .25244 .58641 L F
.338 0 0 r
.25244 .58641 m .25391 .58687 L .25447 .586 L F
.25244 .58641 m .25075 .58788 L .25391 .58687 L F
.783 .479 0 r
.7568 .62258 m .75688 .62346 L .75638 .62144 L F
.7568 .62258 m .75739 .62482 L .75688 .62346 L F
.85 .472 .333 r
.55734 .71389 m .55614 .71537 L .55456 .7127 L F
.778 .369 .277 r
.55796 .71527 m .55614 .71537 L .55734 .71389 L F
.689 .367 .425 r
.56981 .67828 m .57304 .68067 L .57303 .67746 L F
0 0 0 r
.57529 .67727 m .57419 .67912 L .57349 .68018 L F
.137 0 .348 r
.57303 .67746 m .57419 .67912 L .57529 .67727 L F
.37 .598 .935 r
.33637 .59463 m .33571 .5962 L .33364 .59398 L F
.33637 .59463 m .33746 .59624 L .33571 .5962 L F
.416 .141 .386 r
.30532 .63047 m .30285 .63291 L .30459 .63205 L F
.419 .044 .219 r
.3066 .63153 m .30532 .63047 L .30459 .63205 L F
.3066 .63153 m .3076 .63011 L .30532 .63047 L F
.708 .277 .225 r
.65062 .52379 m .65186 .52177 L .64828 .52136 L F
.3 .483 .871 r
.65512 .52458 m .65186 .52177 L .65402 .52128 L F
.207 0 0 r
.65402 .52128 m .65186 .52177 L .65076 .52357 L F
.65402 .52128 m .65076 .52357 L .65093 .52356 L F
.767 .691 .778 r
.65402 .52128 m .65755 .52188 L .65512 .52458 L F
.751 .936 .946 r
.65506 .51932 m .6562 .52023 L .65402 .52128 L F
.207 0 0 r
.65093 .52356 m .65076 .52357 L .65062 .52379 L F
.65402 .52128 m .65062 .52379 L .65335 .52055 L F
.751 .936 .946 r
.65506 .51932 m .65402 .52128 L .65335 .52055 L F
.275 .024 .339 r
.65335 .52055 m .65152 .52355 L .65507 .52151 L F
.65152 .52355 m .6515 .52359 L .65156 .52355 L F
.65152 .52355 m .65156 .52355 L .65507 .52151 L F
.667 .782 .935 r
.45512 .78613 m .45749 .78526 L .45436 .78499 L F
.686 .824 .949 r
.67932 .53175 m .67722 .53297 L .6802 .53305 L F
.504 .732 .975 r
.67932 .53175 m .6802 .53305 L .68083 .53146 L F
.166 .336 .79 r
.6802 .53305 m .68142 .53355 L .68083 .53146 L F
.889 .465 .166 r
.59886 .68989 m .60105 .69127 L .59835 .68806 L F
.991 .746 .456 r
.59968 .69291 m .60105 .69127 L .59886 .68989 L F
.59968 .69291 m .60088 .6939 L .60105 .69127 L F
.665 .593 .764 r
.73184 .60846 m .72905 .61077 L .72802 .6077 L F
.73184 .60846 m .73106 .61006 L .72905 .61077 L F
.615 .45 .636 r
.76779 .61378 m .76788 .61635 L .76535 .61705 L F
.499 .271 .498 r
.34001 .61637 m .34142 .61767 L .33961 .61827 L F
.34001 .61637 m .34181 .61578 L .34142 .61767 L F
.621 .08 0 r
.67869 .51609 m .68283 .51731 L .67953 .51889 L F
.755 .42 0 r
.6015 .71232 m .60256 .71544 L .60317 .71666 L F
.952 .608 .311 r
.60229 .71795 m .60317 .71666 L .60256 .71544 L F
.60229 .71795 m .6035 .71851 L .60317 .71666 L F
.672 .79 .937 r
.74612 .6107 m .74384 .61155 L .7429 .6103 L F
.602 .422 .61 r
.49247 .76023 m .4911 .7629 L .49 .76074 L F
.398 .068 .285 r
.42728 .68521 m .42841 .68716 L .42951 .68472 L F
.42728 .68521 m .42632 .68766 L .42841 .68716 L F
.539 .263 .446 r
.69589 .5244 m .6955 .52694 L .69294 .5272 L F
.463 .172 .385 r
.69825 .52404 m .6955 .52694 L .69589 .5244 L F
.798 .737 .796 r
.61304 .53023 m .60998 .52994 L .6123 .52725 L F
.808 .704 .75 r
.61304 .53023 m .61106 .53302 L .60998 .52994 L F
.813 .692 .732 r
.60659 .54103 m .60793 .5444 L .60597 .54308 L F
.806 .695 .743 r
.60597 .54308 m .60793 .5444 L .60649 .54724 L F
.448 .024 .141 r
.73417 .5942 m .73118 .5956 L .73373 .59553 L F
.637 .299 .382 r
.73373 .59553 m .73624 .59385 L .73417 .5942 L F
.477 .061 .172 r
.40819 .69614 m .41046 .69608 L .41183 .69419 L F
.307 0 .068 r
.41183 .69419 m .41271 .69558 L .41399 .69384 L F
.41183 .69419 m .41046 .69608 L .41271 .69558 L F
.242 0 0 r
.39856 .6489 m .40069 .64909 L .40212 .64884 L F
.435 0 0 r
.40212 .64884 m .40069 .64909 L .40422 .64939 L F
.354 .137 .439 r
.56495 .68732 m .56345 .686 L .56575 .68546 L F
.56495 .68732 m .5632 .68829 L .56345 .686 L F
.189 .319 .766 r
.58037 .67759 m .58134 .6812 L .58196 .67823 L F
0 .438 .822 r
.58134 .6812 m .5817 .68084 L .58196 .67823 L F
.58134 .6812 m .58445 .68236 L .5817 .68084 L F
.617 .669 .877 r
.67503 .49701 m .67901 .4988 L .67697 .49695 L F
.376 .548 .897 r
.67901 .4988 m .6799 .49746 L .67697 .49695 L F
.67901 .4988 m .68079 .49906 L .6799 .49746 L F
.633 .372 .504 r
.64402 .51791 m .64746 .5162 L .64497 .51696 L F
.843 .395 0 r
.56067 .71684 m .56021 .71735 L .55796 .71527 L F
.56067 .71684 m .56092 .71783 L .56021 .71735 L F
.664 .307 .357 r
.45893 .7539 m .46125 .75468 L .45939 .75272 L F
.113 .656 .84 r
.39245 .69862 m .39457 .69866 L .39562 .69884 L F
.682 .76 .911 r
.73945 .61963 m .74317 .62016 L .74191 .61902 L F
.763 .83 .905 r
.74191 .61902 m .74317 .62016 L .74512 .61891 L F
.429 .296 .598 r
.43995 .67742 m .44175 .67679 L .44163 .67438 L F
.526 .32 .543 r
.43952 .67923 m .44175 .67679 L .43995 .67742 L F
.874 .483 .016 r
.60017 .70977 m .6015 .71232 L .60157 .71065 L F
.513 .055 .102 r
.5851 .72462 m .58818 .72388 L .58629 .7248 L F
.74 .642 .75 r
.64404 .5273 m .64717 .52745 L .6466 .52427 L F
.624 .56 .762 r
.64404 .5273 m .647 .52941 L .64717 .52745 L F
.578 .531 .766 r
.6466 .52427 m .64717 .52745 L .64942 .52687 L F
.166 .034 .444 r
.64717 .52745 m .64898 .52874 L .64942 .52687 L F
.64717 .52745 m .647 .52941 L .64898 .52874 L F
.719 .453 .522 r
.50638 .79905 m .50637 .79682 L .50333 .79633 L F
.856 .557 .482 r
.59705 .6875 m .5986 .68548 L .59677 .68562 L F
.302 .198 .566 r
.5986 .68548 m .59914 .68808 L .59835 .68806 L F
.856 .557 .482 r
.59705 .6875 m .59914 .68808 L .5986 .68548 L F
.567 .532 .776 r
.45773 .6554 m .45552 .65596 L .45434 .65229 L F
.653 .627 .811 r
.63375 .49348 m .63646 .49143 L .63401 .49247 L F
.591 .58 .809 r
.77618 .60388 m .77416 .60592 L .77308 .60273 L F
.534 .488 .752 r
.77618 .60388 m .77744 .60795 L .77416 .60592 L F
.976 .688 .298 r
.66794 .51374 m .66707 .51278 L .66686 .51026 L F
.997 .791 .502 r
.66794 .51374 m .66678 .51467 L .66707 .51278 L F
.668 .441 .567 r
.46838 .67716 m .46598 .67949 L .46604 .67732 L F
.562 .523 .769 r
.35796 .70015 m .35867 .70218 L .36073 .70162 L F
.561 .453 .688 r
.35867 .70218 m .36125 .70496 L .36073 .70162 L F
.35867 .70218 m .35913 .70555 L .36125 .70496 L F
0 .15 .674 r
.55299 .72866 m .55316 .72866 L .55193 .72808 L F
.825 .349 .049 r
.55233 .72722 m .55421 .72992 L .55552 .73029 L F
.651 .189 0 r
.55316 .72866 m .55421 .72992 L .55333 .72866 L F
0 .096 .606 r
.55672 .73113 m .55552 .73029 L .55421 .72992 L F
.656 .103 0 r
.55316 .72866 m .55672 .73113 L .55421 .72992 L F
.55537 .7302 m .55542 .73067 L .55672 .73113 L F
.55316 .72866 m .55542 .73067 L .55537 .7302 L F
.79 .292 0 r
.55549 .7314 m .55542 .73067 L .55474 .72962 L F
.55599 .7326 m .55542 .73067 L .55549 .7314 L F
0 .15 .674 r
.55474 .72962 m .55542 .73067 L .55316 .72866 L F
.55474 .72962 m .55316 .72866 L .55299 .72866 L F
.651 .189 0 r
.55316 .72866 m .55333 .72866 L .55233 .72722 L F
.962 .826 .662 r
.60042 .70526 m .6001 .70181 L .59938 .70481 L F
.923 .675 .545 r
.59864 .70699 m .60042 .70526 L .59938 .70481 L F
.59864 .70699 m .60013 .70762 L .60042 .70526 L F
.594 .536 .759 r
.70487 .59224 m .70833 .59181 L .7061 .58793 L F
.58 .436 .651 r
.70487 .59224 m .70734 .59341 L .70833 .59181 L F
.756 .636 .728 r
.64172 .53023 m .64495 .5303 L .64404 .5273 L F
.179 .704 .864 r
.64413 .53011 m .64495 .5303 L .64172 .53023 L F
.624 .56 .762 r
.64404 .5273 m .64495 .5303 L .647 .52941 L F
.566 .926 .942 r
.647 .52941 m .64495 .5303 L .64413 .53011 L F
.653 .627 .811 r
.63375 .49348 m .6354 .48999 L .63646 .49143 L F
.884 .794 .755 r
.63525 .48996 m .63646 .49143 L .6354 .48999 L F
.656 .75 .919 r
.63883 .49055 m .63646 .49143 L .63525 .48996 L F
.315 .657 .972 r
.28224 .63876 m .28101 .63947 L .27992 .6387 L F
.28224 .63876 m .28307 .63963 L .28101 .63947 L F
.234 0 0 r
.41419 .70516 m .41271 .70664 L .41056 .70707 L F
.09 0 0 r
.41478 .70592 m .41419 .70516 L .41618 .70437 L F
.41478 .70592 m .41271 .70664 L .41419 .70516 L F
.471 .885 .93 r
.26932 .65465 m .2701 .65482 L .27224 .65409 L F
.68 .758 .91 r
.26988 .64103 m .26668 .64063 L .26862 .64021 L F
.724 .864 .947 r
.27204 .63972 m .26988 .64103 L .26862 .64021 L F
.591 .621 .85 r
.68419 .49043 m .68329 .49402 L .68225 .49063 L F
.68419 .49043 m .68559 .4935 L .68329 .49402 L F
.589 .564 .794 r
.68665 .4967 m .68329 .49402 L .68559 .4935 L F
0 0 .518 r
.67172 .52435 m .67357 .52758 L .67192 .52674 L F
.974 .773 .572 r
.67357 .52758 m .67199 .52911 L .67192 .52674 L F
.67357 .52758 m .67329 .53003 L .67199 .52911 L F
.6 .949 .907 r
.54574 .7401 m .54315 .74114 L .5442 .73992 L F
.74 .553 .641 r
.54668 .74084 m .54315 .74114 L .54574 .7401 L F
.886 .988 .802 r
.54574 .7401 m .5466 .73695 L .54775 .73816 L F
.54574 .7401 m .5442 .73992 L .5466 .73695 L F
.215 0 0 r
.37379 .6526 m .37015 .65466 L .37232 .65428 L F
.291 0 0 r
.37442 .65385 m .37379 .6526 L .37232 .65428 L F
.37442 .65385 m .37591 .65219 L .37379 .6526 L F
.716 .768 .894 r
.75191 .61064 m .74996 .61189 L .74849 .61025 L F
0 0 .137 r
.34993 .71664 m .34935 .71808 L .34834 .71905 L F
.366 .172 .479 r
.34941 .71891 m .34764 .72127 L .34834 .71905 L F
.868 .903 .854 r
.34792 .7175 m .34558 .72029 L .34873 .71915 L F
.366 .172 .479 r
.34941 .71891 m .34834 .71905 L .34926 .7183 L F
.868 .903 .854 r
.34906 .71858 m .34873 .71915 L .34941 .71891 L F
0 0 .137 r
.34935 .71808 m .34919 .71835 L .34834 .71905 L F
.868 .903 .854 r
.34792 .7175 m .34873 .71915 L .34906 .71858 L F
0 0 .137 r
.34935 .71808 m .34926 .7183 L .34919 .71835 L F
.542 .385 .617 r
.7299 .60234 m .7302 .60481 L .72783 .60526 L F
.633 .564 .759 r
.7302 .60481 m .72802 .6077 L .72783 .60526 L F
.824 .782 .813 r
.64933 .51945 m .64985 .51971 L .64891 .51581 L F
.935 .677 .523 r
.54462 .77076 m .54587 .76871 L .54728 .77091 L F
.54462 .77076 m .54355 .76884 L .54587 .76871 L F
.54462 .77076 m .54374 .77146 L .54355 .76884 L F
.538 .28 .473 r
.53435 .76584 m .53662 .76565 L .53699 .76363 L F
.358 .123 .415 r
.53699 .76363 m .53662 .76565 L .53881 .76282 L F
.526 .054 .078 r
.75739 .62482 m .76103 .62429 L .7597 .62537 L F
.408 0 0 r
.76103 .62429 m .76079 .62515 L .7597 .62537 L F
.76103 .62429 m .76359 .62448 L .76079 .62515 L F
.385 .515 .866 r
.66627 .5072 m .66689 .50884 L .6675 .50665 L F
.639 .736 .918 r
.50304 .76589 m .50019 .76506 L .50151 .76469 L F
.463 .726 .982 r
.50375 .76463 m .50304 .76589 L .50151 .76469 L F
.251 .455 .865 r
.50375 .76463 m .50476 .76642 L .50304 .76589 L F
.693 .279 .256 r
.55931 .77421 m .55821 .77593 L .55644 .77401 L F
.247 .054 .41 r
.56161 .77119 m .55931 .77421 L .56128 .77133 L F
.195 0 0 r
.55931 .77421 m .56121 .77423 L .55821 .77593 L F
.807 .617 .645 r
.49314 .79955 m .49468 .79932 L .493 .80141 L F
.716 .483 .571 r
.49468 .79932 m .4955 .80237 L .493 .80141 L F
.741 .476 .53 r
.53254 .73484 m .53459 .73865 L .52948 .73736 L F
.858 .867 .846 r
.5367 .74043 m .53428 .73913 L .53537 .73828 L F
0 0 0 r
.53424 .73881 m .53135 .74037 L .52948 .73736 L F
.858 .867 .846 r
.53428 .73913 m .53419 .73908 L .53459 .73865 L F
.53419 .73908 m .53424 .73881 L .53459 .73865 L F
.53428 .73913 m .53459 .73865 L .53537 .73828 L F
0 0 0 r
.53477 .73898 m .53416 .73923 L .53424 .73881 L F
.53416 .73923 m .53135 .74037 L .53424 .73881 L F
.858 .867 .846 r
.53419 .73908 m .53395 .73895 L .53424 .73881 L F
.518 .392 .648 r
.5351 .73785 m .53459 .73865 L .53254 .73484 L F
.741 .476 .53 r
.53459 .73865 m .53424 .73881 L .52948 .73736 L F
.858 .867 .846 r
.53537 .73828 m .53395 .73895 L .5351 .73785 L F
.518 .392 .648 r
.5351 .73785 m .53477 .73898 L .53459 .73865 L F
.741 .476 .53 r
.53459 .73865 m .53477 .73898 L .53424 .73881 L F
0 0 0 r
.53416 .73923 m .53294 .73991 L .53135 .74037 L F
.858 .867 .846 r
.5367 .74043 m .53294 .73991 L .5343 .73914 L F
0 0 0 r
.53477 .73898 m .53294 .73991 L .53416 .73923 L F
.858 .867 .846 r
.5343 .73914 m .53294 .73991 L .53395 .73895 L F
.982 .846 .63 r
.53629 .73794 m .5367 .74043 L .5351 .73785 L F
.781 .312 .128 r
.5367 .74043 m .53505 .74214 L .53294 .73991 L F
.593 .412 .606 r
.5383 .73517 m .53864 .73797 L .53666 .73794 L F
.53656 .73757 m .53666 .73794 L .53629 .73794 L F
.5383 .73517 m .53666 .73794 L .53656 .73757 L F
.291 .735 .963 r
.53629 .73794 m .53738 .73733 L .53864 .73797 L F
0 0 .501 r
.53738 .73733 m .53805 .7412 L .53753 .7409 L F
.537 .73907 m .53753 .7409 L .5367 .74043 L F
.53738 .73733 m .53753 .7409 L .537 .73907 L F
0 0 0 r
.53629 .73794 m .53738 .73733 L .5383 .73517 L F
.337 .814 .886 r
.53629 .73794 m .5351 .73785 L .53738 .73733 L F
0 0 .501 r
.53738 .73733 m .5367 .74043 L .5351 .73785 L F
.442 .076 .247 r
.53453 .74358 m .53706 .74333 L .53754 .74124 L F
.663 .278 .306 r
.53754 .74124 m .53706 .74333 L .53973 .74315 L F
.612 .098 .003 r
.53819 .74242 m .5367 .74043 L .53805 .7412 L F
.672 .857 .97 r
.53973 .74315 m .53706 .74333 L .53819 .74242 L F
.53973 .74315 m .53706 .74333 L .53819 .74242 L F
.023 0 .132 r
.53706 .74333 m .53622 .74519 L .53819 .74242 L F
.437 .198 .452 r
.53453 .74358 m .53622 .74519 L .53706 .74333 L F
.799 .689 .744 r
.53819 .74242 m .53622 .74519 L .53505 .74214 L F
.518 .535 .813 r
.53622 .74519 m .53826 .74497 L .53756 .74311 L F
.53701 .7429 m .53756 .74311 L .53723 .74225 L F
.53622 .74519 m .53756 .74311 L .53701 .7429 L F
.612 .098 .003 r
.53819 .74242 m .53511 .74215 L .5367 .74043 L F
.53511 .74215 m .53505 .74214 L .53506 .74213 L F
.53511 .74215 m .53506 .74213 L .5367 .74043 L F
.602 .621 .843 r
.441 .66908 m .44175 .66592 L .4409 .66659 L F
.441 .66908 m .44317 .66858 L .44175 .66592 L F
.558 .502 .749 r
.441 .66908 m .44377 .67086 L .44317 .66858 L F
.492 .81 1 r
.27488 .58624 m .27687 .58581 L .27836 .58661 L F
.107 .631 .878 r
.27687 .58581 m .28052 .58646 L .27836 .58661 L F
.806 .695 .743 r
.60597 .54308 m .60649 .54724 L .60406 .54614 L F
.865 .669 .636 r
.60406 .54614 m .60649 .54724 L .60588 .54942 L F
.633 .564 .759 r
.7302 .60481 m .73184 .60846 L .72802 .6077 L F
.384 0 .033 r
.38488 .71654 m .38343 .71809 L .38115 .71832 L F
.355 0 .101 r
.38691 .71583 m .38343 .71809 L .38488 .71654 L F
.518 .41 .671 r
.25793 .62631 m .25807 .62986 L .2561 .63021 L F
.473 .339 .617 r
.25807 .62986 m .25624 .63115 L .2561 .63021 L F
.558 .339 .538 r
.51796 .73008 m .51801 .73281 L .51553 .73309 L F
.61 .412 .59 r
.52026 .72977 m .51801 .73281 L .51796 .73008 L F
.329 .787 .654 r
.56595 .68018 m .56854 .67887 L .56981 .67828 L F
0 0 0 r
.56595 .68018 m .56603 .68133 L .56854 .67887 L F
.5 .218 .418 r
.45255 .68311 m .45228 .68501 L .45002 .68528 L F
.504 .222 .42 r
.45255 .68311 m .45476 .6846 L .45228 .68501 L F
.567 .169 .247 r
.45501 .68334 m .45476 .6846 L .45255 .68311 L F
.6 .049 0 r
.55552 .73029 m .55776 .7323 L .55897 .73297 L F
0 .096 .606 r
.55672 .73113 m .55776 .7323 L .5561 .7308 L F
.748 .4 .394 r
.55542 .73067 m .55704 .7313 L .55672 .73113 L F
0 .401 .848 r
.55825 .73177 m .55776 .7323 L .55672 .73113 L F
.748 .4 .394 r
.55704 .7313 m .55825 .73177 L .55672 .73113 L F
0 .096 .606 r
.55672 .73113 m .5561 .7308 L .55552 .73029 L F
.464 .29 .559 r
.49445 .75754 m .49247 .76023 L .49201 .75767 L F
.319 .806 .796 r
.28961 .60368 m .2935 .60272 L .29165 .6035 L F
0 0 0 r
.29165 .6035 m .2935 .60272 L .29546 .60191 L F
.134 .575 .925 r
.26276 .65501 m .26465 .65631 L .2663 .65642 L F
.62 .414 .58 r
.50057 .79951 m .50587 .801 L .50333 .79633 L F
.719 .453 .522 r
.50638 .79905 m .50333 .79633 L .50587 .801 L F
.619 .664 .872 r
.38574 .69373 m .38207 .69173 L .38418 .69107 L F
.436 .506 .833 r
.38626 .69075 m .38574 .69373 L .38418 .69107 L F
.38626 .69075 m .38754 .69388 L .38574 .69373 L F
.407 0 0 r
.71916 .59503 m .71937 .59472 L .7193 .59329 L F
.71916 .59503 m .72227 .59583 L .71937 .59472 L F
.45 .608 .915 r
.68081 .48859 m .67931 .48976 L .67854 .48882 L F
.68081 .48859 m .68225 .49063 L .67931 .48976 L F
.427 .432 .762 r
.54374 .77146 m .54123 .76916 L .54355 .76884 L F
.629 .617 .819 r
.68285 .50493 m .68324 .50617 L .68543 .50534 L F
.608 .573 .789 r
.71554 .49877 m .71251 .50041 L .71282 .49769 L F
.605 .476 .679 r
.71554 .49877 m .71356 .50261 L .71251 .50041 L F
.577 .55 .788 r
.46338 .65732 m .46233 .66104 L .46132 .65763 L F
.46338 .65732 m .46455 .66063 L .46233 .66104 L F
.604 .497 .705 r
.46505 .66258 m .46233 .66104 L .46455 .66063 L F
.46505 .66258 m .46267 .66317 L .46233 .66104 L F
.522 .161 .296 r
.70394 .52147 m .70066 .52374 L .70076 .52232 L F
.70394 .52147 m .70313 .52368 L .70066 .52374 L F
.369 0 .119 r
.7063 .52149 m .70313 .52368 L .70394 .52147 L F
.814 .407 .278 r
.57423 .71567 m .575 .71767 L .57585 .71624 L F
.715 .283 .221 r
.575 .71767 m .5781 .71808 L .57585 .71624 L F
.772 .66 .739 r
.59228 .75479 m .5957 .75512 L .59473 .75203 L F
.643 .631 .823 r
.5957 .75512 m .5968 .75154 L .59473 .75203 L F
.5957 .75512 m .59906 .75376 L .5968 .75154 L F
.719 .603 .726 r
.56322 .78211 m .56672 .78038 L .56336 .78004 L F
.714 .741 .873 r
.67197 .49646 m .6728 .49793 L .67503 .49701 L F
.983 .716 .334 r
.32796 .72669 m .32879 .72709 L .32782 .72411 L F
.32782 .72411 m .32879 .72709 L .32796 .72669 L F
.32796 .72669 m .32879 .72709 L .32782 .72411 L F
.298 0 0 r
.64811 .50558 m .64724 .50672 L .64472 .50706 L F
.027 0 0 r
.64931 .5059 m .64811 .50558 L .65039 .50553 L F
.64931 .5059 m .64724 .50672 L .64811 .50558 L F
.835 .624 .617 r
.61872 .73843 m .61682 .73571 L .617 .73784 L F
.727 .358 .35 r
.61702 .74009 m .61872 .73843 L .617 .73784 L F
.61702 .74009 m .62057 .7406 L .61872 .73843 L F
.479 .651 .935 r
.26147 .63711 m .26089 .63894 L .25972 .63737 L F
.597 .777 .966 r
.26291 .63834 m .26089 .63894 L .26147 .63711 L F
.421 .408 .74 r
.36105 .71332 m .36182 .71025 L .35952 .71033 L F
.36105 .71332 m .36272 .71304 L .36182 .71025 L F
.897 .663 .577 r
.6054 .72648 m .60731 .72459 L .60529 .72411 L F
.6054 .72648 m .60701 .72679 L .60731 .72459 L F
.615 .807 .974 r
.67228 .50841 m .66837 .50801 L .67043 .5084 L F
.784 .991 .76 r
.67423 .50608 m .67228 .50841 L .6732 .50656 L F
.759 .975 .921 r
.6732 .50656 m .67228 .50841 L .67043 .5084 L F
0 .179 .707 r
.56052 .73373 m .55897 .73297 L .55776 .7323 L F
.71 .182 0 r
.55897 .73297 m .56123 .735 L .56272 .73522 L F
0 .179 .707 r
.56052 .73373 m .56123 .735 L .55897 .73297 L F
.455 .007 .096 r
.40792 .66346 m .40649 .66512 L .40388 .66537 L F
.597 .25 .352 r
.4101 .66299 m .40649 .66512 L .40792 .66346 L F
.659 .671 .85 r
.77124 .59394 m .76898 .59649 L .76779 .59298 L F
.56 .484 .726 r
.77163 .59599 m .76898 .59649 L .77124 .59394 L F
.77163 .59599 m .76936 .59731 L .76898 .59649 L F
.347 .218 .559 r
.45444 .75792 m .45638 .75966 L .45643 .75727 L F
.45444 .75792 m .45453 .76036 L .45638 .75966 L F
.827 .794 .821 r
.35293 .71624 m .34993 .71664 L .35097 .71463 L F
.35293 .71624 m .34993 .71664 L .35097 .71463 L F
.55 .745 .967 r
.35434 .7154 m .35293 .71624 L .35097 .71463 L F
.742 .393 .39 r
.35434 .7154 m .35097 .71463 L .35293 .71624 L F
.283 .097 .443 r
.25952 .62405 m .25793 .62631 L .25785 .62447 L F
.209 0 .126 r
.5632 .68829 m .56046 .69046 L .56127 .68912 L F
.693 .448 .549 r
.49917 .75188 m .50233 .74911 L .49908 .7494 L F
.49917 .75188 m .50163 .75217 L .50233 .74911 L F
.534 .296 .501 r
.50233 .74911 m .50375 .75169 L .50464 .74956 L F
.50233 .74911 m .50163 .75217 L .50375 .75169 L F
.778 .598 .657 r
.47601 .78765 m .47927 .7883 L .47809 .78548 L F
0 0 0 r
.47975 .7833 m .47809 .78548 L .47864 .78567 L F
.671 .665 .835 r
.47927 .7883 m .4797 .78587 L .47809 .78548 L F
.199 0 0 r
.47864 .78567 m .47809 .78548 L .4797 .78587 L F
.263 .76 .898 r
.40422 .64939 m .40634 .64913 L .40782 .64934 L F
.155 .648 .916 r
.40634 .64913 m .40991 .64994 L .40782 .64934 L F
.601 .521 .737 r
.46594 .66611 m .46422 .66749 L .46267 .66317 L F
.452 .213 .459 r
.47081 .76717 m .47129 .7693 L .46877 .76904 L F
.571 .426 .645 r
.47129 .7693 m .46839 .77134 L .46877 .76904 L F
0 0 0 r
.56492 .76807 m .56386 .76888 L .56628 .7662 L F
.554 .239 .388 r
.56776 .76556 m .56492 .76807 L .56628 .7662 L F
.051 0 0 r
.29546 .60191 m .2991 .60215 L .29767 .60206 L F
.245 .754 .87 r
.29767 .60206 m .2991 .60215 L .30112 .60186 L F
.824 .619 .625 r
.71674 .58733 m .71916 .59102 L .71838 .58871 L F
.473 .339 .617 r
.25807 .62986 m .25818 .6322 L .25624 .63115 L F
.439 .356 .666 r
.25624 .63115 m .25818 .6322 L .25646 .63285 L F
.532 .291 .495 r
.62708 .5572 m .62704 .55534 L .62941 .55682 L F
.595 .229 .319 r
.62941 .55682 m .62704 .55534 L .63014 .55501 L F
.515 .446 .717 r
.46827 .66538 m .46689 .66915 L .46594 .66611 L F
.46827 .66538 m .46895 .66874 L .46689 .66915 L F
.634 .462 .632 r
.46974 .67109 m .46689 .66915 L .46895 .66874 L F
.46974 .67109 m .46713 .67154 L .46689 .66915 L F
.46689 .66915 m .46713 .67154 L .46974 .67109 L F
.849 .423 0 r
.54257 .79742 m .54282 .79747 L .5415 .79593 L F
.904 .968 .655 r
.54257 .79742 m .5417 .79955 L .54282 .79747 L F
.862 .79 .779 r
.60905 .53607 m .60823 .53811 L .60562 .53783 L F
.875 .747 .717 r
.60562 .53783 m .60823 .53811 L .60659 .54103 L F
.561 .152 .224 r
.52203 .7742 m .52305 .7762 L .52094 .77468 L F
.52203 .7742 m .52427 .7744 L .52305 .7762 L F
.601 .521 .737 r
.46594 .66611 m .46267 .66317 L .46505 .66258 L F
.521 .512 .787 r
.72296 .50716 m .72109 .508 L .72021 .50576 L F
.405 .241 .543 r
.72296 .50716 m .72122 .51023 L .72109 .508 L F
.889 .778 .732 r
.67129 .52088 m .673 .52239 L .67172 .52435 L F
.593 .945 .812 r
.57258 .68196 m .57204 .68164 L .57093 .68285 L F
.775 .972 .687 r
.57419 .67912 m .57258 .68196 L .57349 .68018 L F
0 .244 .731 r
.57077 .67847 m .57265 .68029 L .56981 .67828 L F
.57265 .68029 m .57304 .68067 L .57215 .68001 L F
.57265 .68029 m .57215 .68001 L .56981 .67828 L F
.347 .078 .357 r
.57476 .68035 m .57367 .68087 L .57419 .67912 L F
.74 .749 .859 r
.57419 .67912 m .57304 .68067 L .57077 .67847 L F
.775 .972 .687 r
.57419 .67912 m .57204 .68164 L .57258 .68196 L F
.347 .078 .357 r
.57367 .68087 m .57204 .68164 L .57302 .6805 L F
.57367 .68087 m .57302 .6805 L .57419 .67912 L F
.846 .633 .614 r
.39513 .8442 m .39326 .84502 L .39483 .84295 L F
.922 .964 .782 r
.39279 .84508 m .39483 .84295 L .39326 .84502 L F
.424 .087 .289 r
.39505 .8439 m .39483 .84295 L .39279 .84508 L F
.696 .436 0 r
.39472 .84249 m .39513 .8442 L .39483 .84295 L F
.249 .294 .713 r
.39643 .84318 m .39513 .8442 L .39438 .84103 L F
.424 .087 .289 r
.39643 .84318 m .39483 .84295 L .39505 .8439 L F
.696 .436 0 r
.39438 .84103 m .39472 .84249 L .39483 .84295 L F
.846 .633 .614 r
.39513 .8442 m .39569 .84685 L .39326 .84502 L F
.321 .426 .813 r
.39643 .84318 m .39773 .84626 L .39513 .8442 L F
.546 .441 .686 r
.39773 .84626 m .39569 .84685 L .39513 .8442 L F
0 0 .323 r
.65558 .52942 m .65511 .52839 L .65575 .52887 L F
.162 0 0 r
.65511 .52839 m .65638 .52796 L .65575 .52887 L F
0 0 .423 r
.72741 .61261 m .72803 .61346 L .72605 .61241 L F
.72741 .61261 m .72926 .61574 L .72803 .61346 L F
.767 .446 .443 r
.54496 .73335 m .54099 .73275 L .5442 .73268 L F
.54496 .73335 m .54094 .7347 L .54099 .73275 L F
.572 .23 .35 r
.54496 .73335 m .54076 .73719 L .54094 .7347 L F
.54496 .73335 m .54307 .737 L .54076 .73719 L F
.149 .654 .905 r
.54661 .73281 m .54299 .73194 L .5442 .73268 L F
.54337 .73203 m .54472 .73205 L .54299 .73194 L F
.54661 .73281 m .54472 .73205 L .54337 .73203 L F
.455 .835 .988 r
.54851 .73136 m .54472 .73205 L .54661 .73281 L F
.575 .758 .965 r
.5468 .73077 m .54472 .73205 L .54851 .73136 L F
.405 .356 .691 r
.5468 .73077 m .54704 .73208 L .54472 .73205 L F
.331 .253 .616 r
.54777 .73541 m .54959 .73201 L .54661 .73281 L F
.455 .835 .988 r
.54851 .73136 m .54661 .73281 L .54959 .73201 L F
.405 .356 .691 r
.54704 .73208 m .54735 .73384 L .54472 .73205 L F
0 .004 .576 r
.54472 .73205 m .54496 .73335 L .5442 .73268 L F
.54472 .73205 m .54632 .73493 L .54496 .73335 L F
.679 .348 .407 r
.5466 .73695 m .54496 .73335 L .54632 .73493 L F
.5466 .73695 m .54307 .737 L .54496 .73335 L F
.931 .667 .515 r
.551 .70149 m .55148 .70493 L .55296 .70509 L F
.802 .34 .135 r
.55148 .70493 m .55225 .7062 L .55296 .70509 L F
.954 .605 .263 r
.55225 .7062 m .55346 .70735 L .55296 .70509 L F
.66 .432 .563 r
.71095 .58979 m .714 .58731 L .71205 .58849 L F
.242 0 0 r
.71674 .58733 m .71434 .58761 L .714 .58731 L F
.69 .829 .95 r
.42718 .66244 m .43068 .66265 L .42929 .66173 L F
.655 .854 .976 r
.42929 .66173 m .43068 .66265 L .43214 .66202 L F
.607 .238 .317 r
.52983 .75778 m .52851 .75991 L .52634 .75957 L F
.717 .366 .383 r
.52983 .75778 m .53189 .76013 L .52851 .75991 L F
.562 .738 .959 r
.72926 .61574 m .73034 .61727 L .73263 .6167 L F
.248 0 .163 r
.42208 .68861 m .41942 .69081 L .42131 .69007 L F
.383 .03 .237 r
.42208 .68861 m .4235 .68948 L .42437 .68834 L F
.42208 .68861 m .42131 .69007 L .4235 .68948 L F
.985 .704 .364 r
.64868 .53806 m .64966 .53878 L .64846 .53532 L F
.659 .608 .787 r
.64846 .53532 m .64966 .53878 L .65153 .53764 L F
.727 .922 .958 r
.65153 .53764 m .64966 .53878 L .64868 .53806 L F
0 0 0 r
.27827 .60739 m .27608 .6085 L .27716 .60762 L F
.438 0 .09 r
.25447 .586 m .25603 .58684 L .25774 .58501 L F
.534 .309 .519 r
.25774 .58501 m .26009 .58459 L .26011 .58294 L F
.352 0 .042 r
.25603 .58684 m .26009 .58459 L .25774 .58501 L F
.274 .449 .853 r
.4409 .66659 m .44175 .66592 L .44017 .6656 L F
.537 .918 .931 r
.27443 .65359 m .27832 .65275 L .27633 .6535 L F
0 0 0 r
.27832 .65275 m .27841 .65281 L .27633 .6535 L F
.27832 .65275 m .28023 .65235 L .27841 .65281 L F
.785 .755 .825 r
.60097 .55733 m .60063 .56017 L .59911 .55999 L F
.60097 .55733 m .60258 .55871 L .60063 .56017 L F
.85 .547 .476 r
.60063 .56017 m .59904 .56226 L .59911 .55999 L F
.60063 .56017 m .6021 .56321 L .59904 .56226 L F
.503 .69 .952 r
.28805 .58727 m .28749 .58914 L .28602 .58766 L F
.28805 .58727 m .28959 .58894 L .28749 .58914 L F
.24 0 0 r
.30838 .64883 m .30437 .65064 L .30645 .64945 L F
.388 .184 .478 r
.50229 .72749 m .50469 .72651 L .50506 .72437 L F
.588 .546 .775 r
.5027 .72801 m .50469 .72651 L .50229 .72749 L F
.415 .043 .222 r
.29946 .63547 m .30173 .63511 L .30285 .63291 L F
.232 0 .128 r
.30285 .63291 m .30363 .63433 L .30459 .63205 L F
.30285 .63291 m .30173 .63511 L .30363 .63433 L F
0 .455 .735 r
.2932 .59012 m .2951 .59058 L .29664 .59104 L F
.448 .799 .998 r
.2951 .59058 m .29865 .59101 L .29664 .59104 L F
0 0 0 r
.59281 .70229 m .5936 .70092 L .59435 .69912 L F
0 0 .161 r
.59435 .69912 m .59444 .69887 L .59411 .69618 L F
.664 .76 .275 r
.59435 .69912 m .5936 .70092 L .59444 .69887 L F
.482 0 0 r
.42333 .64948 m .42683 .65044 L .42466 .65 L F
.42333 .64948 m .42548 .65046 L .42683 .65044 L F
.376 .84 .879 r
.42683 .65044 m .42548 .65046 L .4258 .65037 L F
.194 0 0 r
.42466 .65 m .42683 .65044 L .4279 .65051 L F
.376 .84 .879 r
.42683 .65044 m .4258 .65037 L .42766 .64982 L F
.194 0 0 r
.4279 .65051 m .42683 .65044 L .42849 .6506 L F
.131 0 0 r
.42683 .65044 m .43039 .64978 L .42849 .6506 L F
.404 .069 .279 r
.63164 .55393 m .62941 .55682 L .63014 .55501 L F
.647 .729 .909 r
.68144 .52926 m .68243 .53133 L .68506 .53013 L F
.68506 .53013 m .68243 .53133 L .68144 .52926 L F
.322 .059 .35 r
.36047 .65841 m .35814 .66099 L .35982 .66 L F
.151 0 .233 r
.35982 .66 m .35814 .66099 L .35753 .66287 L F
.495 .376 .646 r
.77163 .59599 m .7695 .59966 L .76936 .59731 L F
.831 .439 .309 r
.68799 .52167 m .68863 .52365 L .68917 .52113 L F
.486 .265 .503 r
.6914 .521 m .69161 .51901 L .68917 .52113 L F
.274 0 .177 r
.68917 .52113 m .69059 .52254 L .6914 .521 L F
.68917 .52113 m .68863 .52365 L .69059 .52254 L F
.921 .569 .122 r
.60088 .6939 m .60131 .69575 L .6022 .69663 L F
.999 .842 .544 r
.6022 .69663 m .60087 .69805 L .60126 .69975 L F
.6022 .69663 m .60131 .69575 L .60087 .69805 L F
.795 .698 .758 r
.61106 .53302 m .60769 .53247 L .60998 .52994 L F
.808 .707 .754 r
.61106 .53302 m .60718 .53485 L .60769 .53247 L F
.61106 .53302 m .60905 .53607 L .60718 .53485 L F
.955 .824 .675 r
.67937 .51141 m .68108 .51076 L .68013 .50956 L F
.67937 .51141 m .68019 .5127 L .68108 .51076 L F
.427 .79 .996 r
.3268 .59348 m .32623 .59452 L .32468 .59361 L F
.3268 .59348 m .32838 .59428 L .32623 .59452 L F
.539 .504 .765 r
.75772 .59638 m .76 .59605 L .75694 .59447 L F
.484 .41 .698 r
.75772 .59638 m .7606 .5984 L .76 .59605 L F
.75772 .59638 m .75807 .59984 L .7606 .5984 L F
.671 .665 .835 r
.47927 .7883 m .48108 .78867 L .4797 .78587 L F
.707 .335 .342 r
.48095 .7901 m .48108 .78867 L .47927 .7883 L F
.731 .692 .813 r
.4797 .78587 m .48108 .78867 L .48315 .7857 L F
.58 .224 .33 r
.48095 .7901 m .48348 .79023 L .48108 .78867 L F
.985 .754 .508 r
.48371 .78861 m .48315 .7857 L .48108 .78867 L F
.567 .238 .371 r
.48108 .78867 m .48348 .79023 L .48371 .78861 L F
0 0 .132 r
.70694 .50307 m .70656 .50488 L .70831 .50324 L F
.677 .965 .932 r
.70948 .50161 m .70831 .50324 L .71039 .50274 L F
.186 .718 .759 r
.26422 .58494 m .2656 .58477 L .26349 .58518 L F
0 .044 .599 r
.59228 .69389 m .59262 .6931 L .591 .69011 L F
0 .215 .73 r
.59228 .69389 m .59411 .69618 L .59262 .6931 L F
.365 .418 .783 r
.76698 .58987 m .76779 .59298 L .76515 .5913 L F
.464 .407 .709 r
.76515 .5913 m .76779 .59298 L .7658 .59329 L F
.662 .653 .83 r
.76899 .58942 m .76779 .59298 L .76698 .58987 L F
.76899 .58942 m .77024 .59229 L .7689 .59267 L F
.76812 .592 m .7689 .59267 L .76779 .59298 L F
.76899 .58942 m .7689 .59267 L .76812 .592 L F
0 0 0 r
.76515 .5913 m .76748 .5885 L .76711 .5895 L F
.76515 .5913 m .76711 .5895 L .76671 .59008 L F
.823 .622 .63 r
.76331 .58946 m .76808 .59295 L .76756 .59151 L F
.76546 .5897 m .76756 .59151 L .76698 .58987 L F
.76331 .58946 m .76756 .59151 L .76546 .5897 L F
.76584 .59131 m .76465 .59424 L .76808 .59295 L F
.76331 .58946 m .7644 .59336 L .76584 .59131 L F
.7644 .59336 m .76465 .59424 L .76584 .59131 L F
0 0 0 r
.76671 .59008 m .76711 .5895 L .76698 .58987 L F
.469 .177 .386 r
.48549 .74413 m .48764 .74378 L .48822 .7409 L F
.512 .215 .399 r
.48822 .7409 m .48874 .74211 L .49077 .74059 L F
.48822 .7409 m .48764 .74378 L .48874 .74211 L F
.503 .235 .441 r
.47485 .74885 m .47745 .74653 L .47526 .7469 L F
.863 .634 .59 r
.51488 .77014 m .5175 .76909 L .51428 .76817 L F
.51488 .77014 m .51698 .77134 L .5175 .76909 L F
.556 .3 .483 r
.51698 .77134 m .51992 .76904 L .5175 .76909 L F
.445 .402 .717 r
.75807 .59984 m .76074 .60162 L .7606 .5984 L F
.75807 .59984 m .75891 .60196 L .76074 .60162 L F
.461 .187 .41 r
.36213 .65971 m .36047 .65841 L .35982 .66 L F
.36213 .65971 m .36277 .65775 L .36047 .65841 L F
.667 .232 .206 r
.58289 .67457 m .58542 .67627 L .58658 .67478 L F
.754 .341 .266 r
.58542 .67627 m .58862 .67703 L .58658 .67478 L F
.77 .323 .188 r
.58658 .67478 m .58862 .67703 L .59025 .67704 L F
.376 0 0 r
.41361 .66329 m .41233 .66347 L .4101 .66299 L F
.142 .685 .726 r
.41576 .66293 m .41233 .66347 L .41361 .66329 L F
.151 0 .199 r
.5549 .68833 m .55245 .69112 L .55452 .6905 L F
.786 .843 .385 r
.55347 .69385 m .55452 .6905 L .55268 .69174 L F
.55426 .69132 m .55372 .69231 L .55452 .6905 L F
.55347 .69385 m .55368 .69254 L .55426 .69132 L F
.55368 .69254 m .55372 .69231 L .55426 .69132 L F
.194 .722 .839 r
.55051 .69394 m .55217 .69367 L .55347 .69385 L F
.54944 .69397 m .55217 .69367 L .55051 .69394 L F
.47 .184 .396 r
.55249 .69507 m .55323 .69349 L .55217 .69367 L F
.741 .99 .884 r
.55347 .69385 m .55217 .69367 L .55372 .69231 L F
.47 .184 .396 r
.55323 .69349 m .5534 .69314 L .55217 .69367 L F
.5506 .69686 m .55249 .69507 L .55217 .69367 L F
.693 .528 .659 r
.55591 .69405 m .55389 .69597 L .55347 .69385 L F
.47 .184 .396 r
.55249 .69507 m .55542 .69227 L .5534 .69314 L F
0 0 .099 r
.55452 .6905 m .55372 .69231 L .55554 .68981 L F
.55452 .6905 m .55554 .68981 L .55584 .6894 L F
.786 .843 .385 r
.55268 .69174 m .55452 .6905 L .55245 .69112 L F
.984 .731 .468 r
.52273 .7434 m .52284 .74098 L .52046 .74178 L F
.576 .358 .547 r
.52284 .74098 m .52273 .7434 L .52046 .74178 L F
.508 .869 .636 r
.65333 .54613 m .65352 .54609 L .65644 .54384 L F
.595 .228 .317 r
.5 .74137 m .50188 .74336 L .4994 .74313 L F
.564 .23 .362 r
.50235 .74151 m .50188 .74336 L .5 .74137 L F
.375 .55 .898 r
.67385 .48451 m .67249 .48595 L .67224 .48448 L F
.328 .475 .855 r
.67385 .48451 m .67531 .48733 L .67249 .48595 L F
.36 .115 .4 r
.7299 .60234 m .73221 .59946 L .73231 .60199 L F
.573 .404 .614 r
.73417 .59865 m .73231 .60199 L .73221 .59946 L F
0 0 0 r
.4985 .80207 m .50174 .80153 L .50192 .80183 L F
.697 .382 .439 r
.4985 .80207 m .50192 .80183 L .50112 .80423 L F
.537 .712 .953 r
.50192 .80183 m .50433 .80224 L .50587 .801 L F
.741 .429 .454 r
.50192 .80183 m .5045 .80455 L .50112 .80423 L F
.691 .439 .537 r
.50192 .80183 m .50433 .80224 L .5045 .80455 L F
.771 .324 .189 r
.50307 .80368 m .50412 .80248 L .50174 .80153 L F
.50412 .80248 m .50433 .80224 L .50338 .80198 L F
.50412 .80248 m .50338 .80198 L .50174 .80153 L F
.537 .712 .953 r
.50112 .80045 m .50587 .801 L .50057 .79951 L F
.50192 .80183 m .50286 .80163 L .50112 .80045 L F
.50286 .80163 m .50587 .801 L .50112 .80045 L F
.542 .478 .734 r
.35796 .70015 m .35922 .69631 L .35699 .69681 L F
.35796 .70015 m .35978 .69981 L .35922 .69631 L F
.562 .523 .769 r
.35796 .70015 m .36073 .70162 L .35978 .69981 L F
.975 .681 .395 r
.55012 .75159 m .55132 .75418 L .55017 .75053 L F
.971 .675 .401 r
.5512 .75062 m .55012 .75159 L .55017 .75053 L F
.135 0 0 r
.55207 .75091 m .5512 .75062 L .55314 .75017 L F
.55207 .75091 m .55012 .75159 L .5512 .75062 L F
.377 .187 .492 r
.38384 .67411 m .38364 .67676 L .38192 .67732 L F
.409 .258 .564 r
.38367 .67911 m .38192 .67732 L .38364 .67676 L F
.38367 .67911 m .38195 .67974 L .38192 .67732 L F
.737 .297 .204 r
.47678 .79395 m .47732 .79664 L .47366 .79332 L F
0 .059 .608 r
.47678 .79395 m .47847 .79521 L .47732 .79664 L F
.612 .811 .977 r
.6036 .7522 m .60489 .75041 L .60249 .75115 L F
.6036 .7522 m .60636 .7517 L .60489 .75041 L F
0 0 .511 r
.57439 .75942 m .57528 .76225 L .57474 .76358 L F
.902 .984 .726 r
.57528 .76225 m .57392 .76557 L .57474 .76358 L F
.345 0 0 r
.76748 .5885 m .76899 .58942 L .76698 .58987 L F
.664 .667 .843 r
.77024 .59229 m .77124 .59394 L .76781 .59299 L F
.76782 .59298 m .76781 .59299 L .76779 .59298 L F
.77024 .59229 m .76781 .59299 L .76782 .59298 L F
.126 .083 .535 r
.76808 .59295 m .77008 .593 L .76904 .58958 L F
.76872 .59047 m .76904 .58958 L .76899 .58942 L F
.76808 .59295 m .76904 .58958 L .76872 .59047 L F
.709 .637 .775 r
.77008 .593 m .76906 .59013 L .76899 .58942 L F
.345 0 0 r
.76748 .5885 m .76889 .58846 L .76899 .58942 L F
.538 .813 .997 r
.76698 .58987 m .76899 .58942 L .76842 .58835 L F
.709 .637 .775 r
.76906 .59013 m .76842 .58835 L .76899 .58942 L F
.345 0 0 r
.76889 .58846 m .76984 .58842 L .76899 .58942 L F
.331 .205 .554 r
.31201 .62177 m .31358 .62351 L .31381 .6212 L F
.31201 .62177 m .31209 .62421 L .31358 .62351 L F
.501 .243 .456 r
.44445 .6879 m .4421 .68978 L .44223 .6883 L F
.773 .46 .457 r
.47778 .79023 m .47927 .7883 L .47601 .78765 L F
.707 .335 .342 r
.48095 .7901 m .47927 .7883 L .47778 .79023 L F
.508 .869 .636 r
.65333 .54613 m .65644 .54384 L .65539 .54487 L F
.357 0 .005 r
.65872 .54309 m .65539 .54487 L .65644 .54384 L F
.829 .565 .54 r
.52846 .73244 m .52585 .72993 L .52956 .73011 L F
.734 .606 .714 r
.60511 .72172 m .60703 .71826 L .60574 .71936 L F
0 0 .378 r
.58899 .68569 m .5896 .68615 L .58927 .68365 L F
.58899 .68569 m .58975 .68773 L .5896 .68615 L F
.594 .101 .053 r
.49137 .77097 m .4877 .77084 L .48878 .76989 L F
.899 .877 .804 r
.56161 .77119 m .56386 .76888 L .56287 .77075 L F
.56161 .77119 m .56128 .77133 L .56386 .76888 L F
.355 0 .132 r
.56482 .76939 m .56386 .76888 L .56492 .76807 L F
.56482 .76939 m .56287 .77075 L .56386 .76888 L F
0 0 0 r
.5549 .68833 m .55635 .68771 L .5574 .68589 L F
0 0 .148 r
.5549 .68833 m .55584 .6894 L .55635 .68771 L F
.5549 .68833 m .55452 .6905 L .55584 .6894 L F
.415 .294 .606 r
.32131 .61064 m .32279 .60759 L .32059 .60818 L F
.32131 .61064 m .3229 .61007 L .32279 .60759 L F
.324 .189 .538 r
.32131 .61064 m .32278 .61227 L .3229 .61007 L F
.32131 .61064 m .32135 .61313 L .32278 .61227 L F
.162 .063 .486 r
.45117 .78006 m .45232 .77688 L .45023 .77777 L F
.699 .784 .917 r
.70584 .50155 m .70119 .50129 L .70418 .49925 L F
.841 .814 .823 r
.7071 .49908 m .70584 .50155 L .70418 .49925 L F
.489 .333 .596 r
.45173 .77422 m .45383 .77127 L .45176 .77171 L F
.587 .875 .562 r
.56954 .77133 m .57223 .76849 L .57014 .76896 L F
.596 .566 .791 r
.68793 .4929 m .68665 .4967 L .68559 .4935 L F
.68793 .4929 m .68898 .49616 L .68665 .4967 L F
.64 .679 .871 r
.31859 .60548 m .32059 .60818 L .32279 .60759 L F
.497 .343 .602 r
.35581 .66339 m .35784 .66525 L .35753 .66287 L F
.35581 .66339 m .35584 .66565 L .35784 .66525 L F
.672 .477 .613 r
.60776 .56062 m .60793 .56323 L .60562 .56304 L F
.684 .448 .559 r
.60776 .56062 m .61065 .56208 L .60793 .56323 L F
.60776 .56062 m .6116 .56059 L .61065 .56208 L F
.167 0 .365 r
.47436 .7787 m .47316 .77725 L .47496 .77646 L F
.47436 .7787 m .47272 .77999 L .47316 .77725 L F
.889 .465 .166 r
.59886 .68989 m .59835 .68806 L .59914 .68808 L F
.279 0 .227 r
.32312 .63775 m .32393 .63609 L .32572 .63539 L F
.008 .577 .779 r
.34829 .71069 m .34675 .71043 L .3473 .71062 L F
0 .033 .563 r
.47478 .78237 m .4746 .78247 L .47392 .78158 L F
.608 .306 .432 r
.53754 .74124 m .53973 .74315 L .53986 .74134 L F
.372 .098 .363 r
.27178 .61008 m .27056 .61261 L .26909 .61291 L F
.115 0 .072 r
.27373 .60961 m .27056 .61261 L .27178 .61008 L F
.87 .435 .159 r
.55202 .76943 m .55208 .77118 L .55122 .76929 L F
.895 .473 .144 r
.55202 .76943 m .55342 .77155 L .55208 .77118 L F
.404 .069 .279 r
.63164 .55393 m .6317 .55624 L .62941 .55682 L F
.392 .065 .287 r
.63497 .55202 m .63417 .55444 L .63164 .55393 L F
.391 .128 .391 r
.63164 .55393 m .63407 .55592 L .6317 .55624 L F
.63164 .55393 m .63417 .55444 L .63407 .55592 L F
.369 .652 .966 r
.67081 .48295 m .66887 .48393 L .66809 .48291 L F
.67081 .48295 m .67224 .48448 L .66887 .48393 L F
.389 .064 .289 r
.73624 .59385 m .73853 .59349 L .73919 .59147 L F
.317 0 .216 r
.73853 .59349 m .74147 .5908 L .73919 .59147 L F
.403 .289 .608 r
.35966 .70784 m .36125 .70496 L .35913 .70555 L F
.298 .711 .974 r
.56819 .74008 m .57054 .74016 L .56969 .74088 L F
.414 .656 .959 r
.71899 .60706 m .71534 .60542 L .71699 .60677 L F
.692 .355 .401 r
.50375 .75169 m .50675 .75173 L .50464 .74956 L F
.64 .365 .486 r
.50464 .74956 m .50675 .75173 L .50708 .74964 L F
.403 .289 .608 r
.35966 .70784 m .36154 .70763 L .36125 .70496 L F
.632 .554 .748 r
.35952 .71033 m .36154 .70763 L .35966 .70784 L F
.498 .241 .455 r
.4729 .76826 m .47129 .7693 L .47081 .76717 L F
.872 .66 .613 r
.59677 .68562 m .59679 .68274 L .59417 .68214 L F
.742 .608 .709 r
.5426 .7486 m .54294 .75263 L .53899 .75191 L F
.933 .939 .778 r
.54305 .7533 m .54226 .75372 L .54245 .75342 L F
.54312 .75277 m .54283 .75305 L .54319 .75223 L F
.54283 .75305 m .54294 .75263 L .54319 .75223 L F
.22 .209 .633 r
.54336 .75096 m .54302 .75367 L .54294 .75263 L F
.54336 .75096 m .54294 .75263 L .5426 .7486 L F
.933 .939 .778 r
.54283 .75305 m .54245 .75342 L .54294 .75263 L F
.54305 .7533 m .54245 .75342 L .54312 .75277 L F
.702 .557 .687 r
.54196 .75388 m .53899 .75191 L .54245 .75342 L F
.54196 .75388 m .54245 .75342 L .54302 .75367 L F
.742 .608 .709 r
.54294 .75263 m .54302 .75367 L .54245 .75342 L F
.54294 .75263 m .54245 .75342 L .53899 .75191 L F
.933 .939 .778 r
.54319 .75223 m .54196 .75388 L .54336 .75096 L F
.54226 .75372 m .54196 .75388 L .54319 .75223 L F
.506 .274 .496 r
.43437 .68241 m .43659 .6798 L .43451 .68009 L F
.101 0 0 r
.39326 .71367 m .3925 .71314 L .39474 .71272 L F
.39326 .71367 m .39095 .71428 L .3925 .71314 L F
.568 .566 .812 r
.75592 .59116 m .75694 .59447 L .75888 .59279 L F
.533 .506 .772 r
.75694 .59447 m .76 .59605 L .75888 .59279 L F
.593 .371 .549 r
.55849 .6912 m .55687 .69454 L .55591 .69405 L F
.355 .117 .408 r
.56043 .69301 m .55849 .6912 L .56046 .69046 L F
.56043 .69301 m .55687 .69454 L .55849 .6912 L F
.521 .399 .654 r
.35406 .66951 m .35592 .66926 L .35584 .66565 L F
.547 .435 .677 r
.35406 .66951 m .3565 .67127 L .35592 .66926 L F
.35406 .66951 m .35442 .67169 L .3565 .67127 L F
.353 0 .038 r
.37811 .65194 m .38032 .65166 L .38174 .65001 L F
.299 0 .004 r
.38174 .65001 m .38332 .65039 L .38374 .64956 L F
.38174 .65001 m .38032 .65166 L .38332 .65039 L F
.39 .846 .785 r
.64735 .54799 m .64571 .54885 L .64778 .54825 L F
.64735 .54799 m .64531 .54887 L .64571 .54885 L F
.985 .742 .482 r
.6598 .49653 m .65761 .49774 L .65847 .49425 L F
.6598 .49653 m .65967 .5002 L .65761 .49774 L F
.281 .754 .937 r
.425 .66286 m .42358 .66243 L .42147 .66258 L F
.534 .885 .983 r
.42565 .66177 m .425 .66286 L .42718 .66244 L F
.42565 .66177 m .42358 .66243 L .425 .66286 L F
.726 .581 .692 r
.77166 .61742 m .76827 .61931 L .76788 .61635 L F
.41 .052 .244 r
.7707 .61894 m .76827 .61931 L .77166 .61742 L F
.279 .781 .787 r
.77372 .61824 m .7707 .61894 L .77166 .61742 L F
.546 .725 .957 r
.67747 .48719 m .67606 .48908 L .67531 .48733 L F
.67747 .48719 m .67854 .48882 L .67606 .48908 L F
.567 .548 .793 r
.38176 .68208 m .38084 .68582 L .37971 .68237 L F
.38176 .68208 m .38289 .68535 L .38084 .68582 L F
.508 .467 .746 r
.38333 .68746 m .38084 .68582 L .38289 .68535 L F
.851 .998 .783 r
.53436 .80107 m .53618 .80014 L .53414 .80235 L F
0 0 0 r
.53582 .80034 m .53618 .80014 L .53436 .80107 L F
.53582 .80034 m .53823 .79909 L .53618 .80014 L F
.981 .689 .347 r
.77482 .61477 m .77576 .61342 L .77449 .61259 L F
.77482 .61477 m .77612 .61614 L .77576 .61342 L F
.479 .331 .602 r
.77576 .61342 m .77783 .61468 L .77732 .61178 L F
.77576 .61342 m .77612 .61614 L .77783 .61468 L F
.77783 .61468 m .77612 .61614 L .77576 .61342 L F
.309 0 .035 r
.43711 .69189 m .43655 .69266 L .43429 .69312 L F
.293 .034 .339 r
.25646 .63285 m .25818 .6322 L .25599 .63451 L F
.578 .351 .535 r
.43186 .68484 m .43437 .68241 L .43225 .68297 L F
.36 .742 .988 r
.31359 .59265 m .31176 .59276 L .31014 .59187 L F
.75 .83 .37 r
.59185 .70454 m .59189 .70405 L .59281 .70229 L F
0 0 0 r
.59281 .70229 m .59189 .70405 L .5936 .70092 L F
.875 .612 .538 r
.49459 .7981 m .49705 .79684 L .49571 .79504 L F
.49459 .7981 m .49703 .79925 L .49705 .79684 L F
.751 .699 .802 r
.73362 .60744 m .73106 .61006 L .73184 .60846 L F
.435 .417 .741 r
.35396 .68262 m .35475 .6856 L .35642 .68515 L F
.424 .378 .703 r
.35475 .6856 m .35698 .68769 L .35642 .68515 L F
.486 .384 .664 r
.35475 .6856 m .35528 .6886 L .35698 .68769 L F
.162 .063 .486 r
.45117 .78006 m .45211 .77983 L .45232 .77688 L F
.785 .66 .724 r
.60511 .72172 m .60574 .71936 L .6035 .71851 L F
.751 .255 .049 r
.48315 .7857 m .48027 .78367 L .48236 .78295 L F
.48027 .78367 m .47975 .7833 L .48236 .78295 L F
.748 .585 .674 r
.48571 .78256 m .48236 .78295 L .48444 .78201 L F
.48571 .78256 m .48315 .7857 L .48236 .78295 L F
.163 0 0 r
.48388 .78243 m .48236 .78295 L .48113 .7845 L F
.48444 .78201 m .48236 .78295 L .48388 .78243 L F
.42 .074 .27 r
.48236 .78295 m .47975 .7833 L .47864 .78567 L F
.785 .66 .724 r
.60511 .72172 m .6035 .71851 L .60353 .72103 L F
.928 .653 .498 r
.60357 .72334 m .60511 .72172 L .60353 .72103 L F
.60357 .72334 m .60529 .72411 L .60511 .72172 L F
.334 .005 .25 r
.38653 .67211 m .38576 .6739 L .38384 .67411 L F
.309 0 .237 r
.3878 .67323 m .38653 .67211 L .38863 .67155 L F
.3878 .67323 m .38576 .6739 L .38653 .67211 L F
.475 .172 .371 r
.7469 .58807 m .74922 .58763 L .74963 .58601 L F
.36 .07 .329 r
.74963 .58601 m .74922 .58763 L .75182 .5852 L F
.802 .313 .016 r
.56272 .73522 m .56467 .7377 L .56608 .73818 L F
0 0 .455 r
.56385 .7366 m .56467 .7377 L .56272 .73522 L F
.56385 .7366 m .56272 .73522 L .56123 .735 L F
.707 .313 .3 r
.52762 .80494 m .52819 .80429 L .52485 .80443 L F
.371 0 .061 r
.53033 .80419 m .52819 .80429 L .52762 .80494 L F
.281 0 0 r
.28455 .60496 m .28357 .60624 L .2817 .60665 L F
.424 .859 .929 r
.28829 .60391 m .28604 .60423 L .28455 .60496 L F
0 0 0 r
.28604 .60423 m .28357 .60624 L .28455 .60496 L F
.766 .427 .412 r
.52359 .71831 m .5258 .72097 L .52699 .71877 L F
.727 .38 .391 r
.52699 .71877 m .5258 .72097 L .52919 .72114 L F
.63 .875 .987 r
.54971 .70104 m .551 .70149 L .55164 .69942 L F
.159 0 0 r
.55257 .70009 m .55164 .69942 L .55403 .6993 L F
.55257 .70009 m .54971 .70104 L .55164 .69942 L F
.456 .252 .513 r
.38571 .67617 m .38384 .67411 L .38576 .6739 L F
.38571 .67617 m .38364 .67676 L .38384 .67411 L F
.89 .928 .545 r
.4885 .79095 m .48905 .78867 L .4869 .79069 L F
.777 .49 .502 r
.48681 .79328 m .4885 .79095 L .4869 .79069 L F
.48681 .79328 m .49035 .79364 L .4885 .79095 L F
.549 .39 .618 r
.73231 .60199 m .7302 .60481 L .7299 .60234 L F
.763 .83 .905 r
.74191 .61902 m .74512 .61891 L .74417 .61811 L F
.588 .858 .994 r
.74417 .61811 m .74512 .61891 L .74744 .61817 L F
.529 .488 .755 r
.53823 .75237 m .53767 .7551 L .5369 .75221 L F
.553 .511 .763 r
.53823 .75237 m .54006 .75497 L .53767 .7551 L F
.862 .79 .779 r
.60905 .53607 m .60562 .53783 L .60718 .53485 L F
.598 .379 .555 r
.50022 .76862 m .50257 .7709 L .49811 .77158 L F
.726 .35 .338 r
.50859 .80128 m .50999 .79934 L .50638 .79905 L F
.655 .263 .29 r
.51245 .80123 m .50999 .79934 L .50859 .80128 L F
.485 .143 .31 r
.62161 .5584 m .6215 .5598 L .6192 .56006 L F
.456 .134 .33 r
.62406 .55782 m .6215 .5598 L .62161 .5584 L F
.111 0 0 r
.50787 .73828 m .5047 .7393 L .50482 .73831 L F
.618 .588 .798 r
.6924 .49879 m .69008 .49942 L .68898 .49616 L F
.439 0 0 r
.56488 .71842 m .56316 .71839 L .56092 .71783 L F
.747 .282 0 r
.56488 .71842 m .56557 .72015 L .56316 .71839 L F
.56488 .71842 m .56653 .72105 L .56557 .72015 L F
.508 .197 .375 r
.42427 .69939 m .42342 .70196 L .42114 .70226 L F
.473 .164 .36 r
.42601 .70062 m .42427 .69939 L .42638 .6989 L F
.42601 .70062 m .42342 .70196 L .42427 .69939 L F
.405 .16 .426 r
.33505 .62413 m .33762 .6199 L .33664 .62348 L F
.452 .182 .412 r
.33664 .62348 m .33762 .6199 L .3394 .62106 L F
.876 .572 .468 r
.617 .73784 m .61682 .73571 L .61425 .73526 L F
.428 .283 .58 r
.49777 .74837 m .4952 .74668 L .4976 .74624 L F
.76 .55 .612 r
.4952 .74668 m .49521 .74931 L .49908 .7494 L F
.428 .283 .58 r
.49777 .74837 m .49521 .74931 L .4952 .74668 L F
.784 .347 .212 r
.49521 .74931 m .49917 .75188 L .49908 .7494 L F
.222 .487 .894 r
.44017 .6656 m .44074 .66424 L .43845 .66271 L F
.44017 .6656 m .44175 .66592 L .44074 .66424 L F
.772 .39 0 r
.591 .69011 m .59114 .69118 L .58975 .68773 L F
.773 .335 0 r
.591 .69011 m .59262 .6931 L .59114 .69118 L F
.642 .227 .24 r
.6116 .56059 m .61395 .56201 L .61065 .56208 L F
.6116 .56059 m .61359 .56092 L .61395 .56201 L F
.511 0 0 r
.56467 .7377 m .56819 .74008 L .56608 .73818 L F
.493 .351 .616 r
.45273 .76325 m .45472 .76282 L .45453 .76036 L F
.542 .417 .66 r
.45285 .76557 m .45472 .76282 L .45273 .76325 L F
0 0 .132 r
.70694 .50307 m .70692 .50415 L .70656 .50488 L F
.126 .507 .909 r
.70692 .50415 m .7099 .50631 L .70656 .50488 L F
.783 .75 .822 r
.64181 .52764 m .64404 .5273 L .64273 .52406 L F
.756 .636 .728 r
.64172 .53023 m .64404 .5273 L .64181 .52764 L F
.812 .762 .807 r
.64273 .52406 m .64404 .5273 L .6466 .52427 L F
.845 .805 .315 r
.57239 .77149 m .57229 .77103 L .57172 .77334 L F
.656 .834 .969 r
.53453 .77179 m .53585 .77296 L .53795 .77198 L F
.651 .597 .782 r
.53585 .77296 m .53913 .77459 L .53795 .77198 L F
0 .201 .728 r
.5475 .7577 m .54588 .75462 L .54905 .7549 L F
.5475 .7577 m .54785 .75661 L .54578 .75442 L F
.589 .422 .623 r
.54649 .75925 m .54368 .75619 L .54714 .75665 L F
.54368 .75619 m .54341 .75589 L .54395 .756 L F
.54368 .75619 m .54395 .756 L .54714 .75665 L F
0 .201 .728 r
.54588 .75462 m .54578 .75442 L .54609 .75447 L F
.54588 .75462 m .54609 .75447 L .54905 .7549 L F
.722 .269 .174 r
.5475 .7577 m .54649 .75925 L .54785 .75661 L F
.5475 .7577 m .54934 .75951 L .54649 .75925 L F
.275 0 .101 r
.41942 .69081 m .4203 .69222 L .42131 .69007 L F
.41942 .69081 m .41826 .69284 L .4203 .69222 L F
.824 .782 .813 r
.64933 .51945 m .64891 .51581 L .6482 .51832 L F
.965 .924 .705 r
.64765 .52023 m .64933 .51945 L .6482 .51832 L F
.64765 .52023 m .64828 .52136 L .64933 .51945 L F
.619 .383 .537 r
.53564 .73238 m .53254 .73484 L .53264 .7327 L F
.642 .634 .827 r
.54341 .75589 m .54113 .75776 L .54006 .75497 L F
.567 .404 .62 r
.54341 .75589 m .54104 .76025 L .54113 .75776 L F
.339 .12 .428 r
.69054 .53358 m .68817 .5374 L .68908 .53538 L F
.557 .645 .893 r
.73642 .61826 m .73737 .61534 L .73506 .61603 L F
.73642 .61826 m .73848 .61783 L .73737 .61534 L F
.834 .747 .768 r
.61876 .51633 m .6151 .51801 L .61773 .51554 L F
.61876 .51633 m .61674 .51925 L .6151 .51801 L F
.867 .924 .862 r
.61876 .51633 m .61773 .51554 L .6202 .51316 L F
.591 .219 .306 r
.31658 .61675 m .31843 .61812 L .31854 .61608 L F
.31658 .61675 m .31592 .61826 L .31843 .61812 L F
0 .081 .637 r
.58161 .74036 m .58233 .73995 L .58121 .73796 L F
0 0 .557 r
.58161 .74036 m .58307 .74301 L .58233 .73995 L F
.596 .682 .902 r
.50569 .75963 m .50711 .76017 L .50582 .7598 L F
.588 .767 .964 r
.50703 .76298 m .50582 .7598 L .50711 .76017 L F
.658 .45 .592 r
.50909 .76155 m .50703 .76298 L .50711 .76017 L F
.196 .442 .868 r
.50582 .7598 m .5084 .76135 L .50692 .75874 L F
.50582 .7598 m .50692 .75874 L .50606 .76012 L F
.748 .523 .589 r
.50582 .7598 m .50577 .76228 L .50247 .76182 L F
.196 .442 .868 r
.50582 .7598 m .50509 .76166 L .50577 .76228 L F
.50582 .7598 m .50606 .76012 L .50509 .76166 L F
.596 .682 .902 r
.50323 .75871 m .50569 .75963 L .50582 .7598 L F
.417 .183 .45 r
.34434 .61282 m .34583 .61093 L .34618 .61322 L F
.441 .184 .426 r
.34583 .61093 m .34878 .60984 L .34871 .6113 L F
.34583 .61093 m .34677 .61029 L .34878 .60984 L F
.47 .218 .45 r
.34618 .61322 m .34583 .61093 L .34871 .6113 L F
.294 .749 .955 r
.29865 .59101 m .30075 .5909 L .30223 .59143 L F
.408 .767 .995 r
.30075 .5909 m .30415 .59152 L .30223 .59143 L F
.019 0 0 r
.28132 .65225 m .2822 .65216 L .28392 .65216 L F
0 0 0 r
.28273 .65211 m .2822 .65216 L .28023 .65235 L F
.084 .643 .728 r
.28023 .65235 m .2822 .65216 L .28047 .65227 L F
.019 0 0 r
.28047 .65227 m .2822 .65216 L .28132 .65225 L F
0 0 0 r
.28373 .65202 m .2822 .65216 L .28273 .65211 L F
.035 0 0 r
.28392 .65216 m .28373 .65202 L .28589 .65163 L F
.28392 .65216 m .2822 .65216 L .28373 .65202 L F
.676 .155 0 r
.56778 .72176 m .56758 .72294 L .56653 .72105 L F
.56778 .72176 m .57031 .72364 L .56758 .72294 L F
.606 .514 .724 r
.45157 .78367 m .45436 .78499 L .45364 .78266 L F
.617 .19 .207 r
.50745 .80492 m .51104 .80489 L .51013 .80653 L F
.958 .651 .404 r
.51013 .80653 m .51104 .80489 L .51107 .80646 L F
.653 .431 .569 r
.51104 .80489 m .51337 .80772 L .51107 .80646 L F
.51104 .80489 m .51349 .80496 L .51337 .80772 L F
.611 .907 .984 r
.61083 .75088 m .60815 .75122 L .60928 .75211 L F
.41 .069 .273 r
.55635 .68771 m .55913 .68465 L .5574 .68589 L F
.534 .764 .982 r
.67503 .49701 m .67559 .4964 L .67593 .49643 L F
.238 .399 .822 r
.67593 .49643 m .67637 .49555 L .67584 .49402 L F
.534 .764 .982 r
.67559 .4964 m .67637 .49555 L .67593 .49643 L F
.476 .67 .949 r
.67559 .4964 m .67697 .49695 L .67637 .49555 L F
.67503 .49701 m .67652 .49697 L .67559 .4964 L F
.67652 .49697 m .67697 .49695 L .67559 .4964 L F
.858 .873 .849 r
.67229 .49351 m .6722 .49431 L .67593 .49643 L F
.6722 .49431 m .67202 .49604 L .67559 .4964 L F
.6722 .49431 m .67559 .4964 L .67593 .49643 L F
.67202 .49604 m .67197 .49646 L .67593 .49643 L F
.542 .793 .991 r
.67503 .49701 m .67593 .49643 L .67197 .49646 L F
0 0 0 r
.32312 .63775 m .3204 .64043 L .3216 .63882 L F
.398 .797 .985 r
.74744 .61817 m .75088 .61848 L .74989 .61768 L F
.424 .761 .996 r
.75088 .61848 m .75228 .61746 L .74989 .61768 L F
.75088 .61848 m .75325 .61833 L .75228 .61746 L F
.124 0 .316 r
.26325 .62041 m .26248 .61917 L .26383 .61843 L F
.26325 .62041 m .262 .62131 L .26248 .61917 L F
.495 .376 .646 r
.77163 .59599 m .77252 .59876 L .7695 .59966 L F
.534 .504 .769 r
.77252 .59876 m .77273 .60099 L .7695 .59966 L F
.525 .797 .995 r
.76049 .58336 m .75719 .5829 L .7596 .58256 L F
.564 .833 .996 r
.76206 .58194 m .76049 .58336 L .7596 .58256 L F
.76206 .58194 m .7629 .58279 L .76049 .58336 L F
.856 .49 .356 r
.6123 .73434 m .61376 .73308 L .61055 .73162 L F
.842 .467 .341 r
.6123 .73434 m .61425 .73526 L .61376 .73308 L F
.559 .888 .988 r
.42147 .66258 m .41804 .66291 L .41916 .66297 L F
.535 .04 .026 r
.50577 .80323 m .50433 .80224 L .50307 .80368 L F
.748 .585 .674 r
.48571 .78256 m .48614 .78488 L .48315 .7857 L F
.479 .846 .99 r
.48806 .78189 m .48571 .78256 L .48444 .78201 L F
.513 .428 .697 r
.48614 .78488 m .48806 .78189 L .48571 .78256 L F
0 0 .363 r
.48661 .78409 m .48571 .78256 L .48806 .78189 L F
.48661 .78409 m .48614 .78488 L .48571 .78256 L F
.405 0 0 r
.43039 .64978 m .43054 .65021 L .43375 .65044 L F
.44 0 0 r
.43054 .65021 m .43624 .65062 L .43375 .65044 L F
.623 .539 .739 r
.4994 .74313 m .4976 .74624 L .49743 .74388 L F
0 0 .322 r
.54818 .7687 m .54728 .77091 L .54587 .76871 L F
.54818 .7687 m .5483 .77091 L .54728 .77091 L F
.663 .295 0 r
.54344 .70535 m .54418 .70696 L .54276 .70399 L F
.341 .529 .894 r
.43593 .66182 m .43699 .66044 L .43492 .66063 L F
.43593 .66182 m .43845 .66271 L .43699 .66044 L F
.778 .996 .862 r
.59112 .70576 m .59189 .70405 L .59185 .70454 L F
.59112 .70576 m .58892 .70651 L .59189 .70405 L F
.678 .697 .86 r
.39245 .69862 m .38949 .69847 L .39136 .69776 L F
.49 .692 .957 r
.39375 .69762 m .39245 .69862 L .39136 .69776 L F
.39375 .69762 m .39457 .69866 L .39245 .69862 L F
.621 .08 0 r
.67869 .51609 m .68103 .51761 L .68283 .51731 L F
.69 .98 .883 r
.68283 .51731 m .68413 .51562 L .68458 .51605 L F
.68283 .51731 m .68103 .51761 L .68413 .51562 L F
.712 .304 .272 r
.53823 .79909 m .5405 .80129 L .53859 .80145 L F
.211 0 .182 r
.53799 .8036 m .53859 .80145 L .5405 .80129 L F
.518 .299 .521 r
.45643 .75727 m .45893 .7539 L .45662 .75449 L F
.407 .82 .974 r
.40991 .64994 m .41206 .64956 L .41342 .65001 L F
.333 .794 .94 r
.41206 .64956 m .41559 .64956 L .41342 .65001 L F
.141 .03 .455 r
.62783 .51234 m .62679 .51344 L .62823 .5094 L F
.156 0 .393 r
.62813 .51326 m .62679 .51344 L .62783 .51234 L F
.62813 .51326 m .62648 .51545 L .62679 .51344 L F
.646 .341 .44 r
.50675 .75173 m .51031 .74943 L .50708 .74964 L F
.50675 .75173 m .51036 .75165 L .51031 .74943 L F
.682 .37 .439 r
.51036 .75165 m .51267 .75164 L .51031 .74943 L F
.638 .382 .515 r
.51031 .74943 m .51267 .75164 L .51285 .74947 L F
0 0 .096 r
.35648 .71066 m .35451 .71298 L .35382 .71087 L F
.429 .565 .889 r
.35382 .71087 m .35451 .71298 L .35491 .7109 L F
0 0 .096 r
.35648 .71066 m .35611 .71156 L .35451 .71298 L F
.35611 .71156 m .35583 .71226 L .35549 .71244 L F
.35611 .71156 m .35549 .71244 L .35451 .71298 L F
.872 .971 .657 r
.35583 .71226 m .35434 .7154 L .35451 .71298 L F
.55 .745 .967 r
.35434 .7154 m .35491 .7109 L .35451 .71298 L F
.35454 .7138 m .35097 .71463 L .35491 .7109 L F
.35434 .7154 m .35354 .71522 L .35454 .7138 L F
.35354 .71522 m .35097 .71463 L .35454 .7138 L F
.868 .563 .469 r
.6347 .52661 m .6347 .52457 L .63191 .52405 L F
.69 .433 .529 r
.6347 .52661 m .63668 .52436 L .6347 .52457 L F
.279 .701 .969 r
.2656 .58477 m .26764 .58487 L .26919 .58569 L F
.297 .742 .962 r
.26764 .58487 m .27121 .58536 L .26919 .58569 L F
.098 0 0 r
.66447 .54123 m .66339 .5421 L .66107 .54261 L F
0 0 0 r
.66541 .53967 m .66447 .54123 L .66576 .53832 L F
.692 .924 .601 r
.66541 .53967 m .66339 .5421 L .66447 .54123 L F
.284 .765 .923 r
.32838 .59428 m .33051 .59405 L .33183 .59433 L F
.268 .764 .899 r
.33051 .59405 m .33364 .59398 L .33183 .59433 L F
.414 .121 .356 r
.34677 .61029 m .34947 .60805 L .34878 .60984 L F
.202 0 .249 r
.34878 .60984 m .34947 .60805 L .35111 .60713 L F
.348 .081 .36 r
.31854 .61608 m .32027 .61744 L .32106 .61499 L F
.31854 .61608 m .31843 .61812 L .32027 .61744 L F
.591 .595 .824 r
.39136 .69776 m .38949 .69847 L .38856 .69737 L F
.198 .21 .646 r
.55378 .74307 m .55241 .74451 L .55085 .74331 L F
.419 .054 .235 r
.55241 .74451 m .5542 .74547 L .55507 .74392 L F
.198 .21 .646 r
.55378 .74307 m .5542 .74547 L .55241 .74451 L F
.759 .706 .802 r
.6562 .52023 m .65755 .52188 L .65402 .52128 L F
.994 .864 .532 r
.6575 .51745 m .65755 .52188 L .6562 .52023 L F
.46 .116 .295 r
.4696 .75189 m .47182 .75163 L .47273 .74937 L F
.317 0 .195 r
.47182 .75163 m .47485 .74885 L .47273 .74937 L F
.242 .643 .961 r
.28454 .58661 m .28434 .58756 L .28274 .58621 L F
.28454 .58661 m .28602 .58766 L .28434 .58756 L F
.108 0 0 r
.39494 .6698 m .39436 .66911 L .39652 .66852 L F
.39494 .6698 m .39281 .67034 L .39436 .66911 L F
.685 .55 .696 r
.54566 .76612 m .54587 .76871 L .54355 .76884 L F
.506 .32 .563 r
.49578 .73572 m .49802 .73535 L .49793 .73242 L F
.439 .256 .534 r
.49802 .73535 m .49998 .73219 L .49793 .73242 L F
.807 .319 .01 r
.39326 .84502 m .39569 .84685 L .39443 .8466 L F
.44 .862 .946 r
.39443 .8466 m .39569 .84685 L .39773 .84626 L F
.49 .18 .367 r
.43429 .69312 m .43329 .69627 L .43109 .69644 L F
.525 .213 .381 r
.43653 .69459 m .43429 .69312 L .43655 .69266 L F
.43653 .69459 m .43329 .69627 L .43429 .69312 L F
.657 .806 .955 r
.29401 .67671 m .29249 .67769 L .29053 .67639 L F
.29401 .67671 m .29249 .67769 L .29053 .67639 L F
.488 .757 .99 r
.51683 .77272 m .5152 .77166 L .51698 .77134 L F
.51683 .77272 m .51495 .77374 L .5152 .77166 L F
.732 .727 .846 r
.72021 .50576 m .71761 .50589 L .71976 .50486 L F
.506 .516 .801 r
.72211 .50412 m .72021 .50576 L .71976 .50486 L F
.72211 .50412 m .72296 .50716 L .72021 .50576 L F
.693 .773 .913 r
.31395 .6053 m .31675 .60541 L .31613 .60435 L F
.198 .669 .938 r
.31675 .60541 m .31772 .605 L .31613 .60435 L F
.31675 .60541 m .31859 .60548 L .31772 .605 L F
.574 .212 .316 r
.45201 .6866 m .45002 .68528 L .45228 .68501 L F
.45201 .6866 m .44893 .68747 L .45002 .68528 L F
.183 0 0 r
.46125 .75468 m .46491 .75491 L .46242 .75445 L F
.429 .101 .305 r
.26909 .61291 m .26828 .61526 L .26617 .61561 L F
.367 .051 .292 r
.27056 .61261 m .26828 .61526 L .26909 .61291 L F
.972 .663 .351 r
.54188 .77413 m .54324 .77722 L .54201 .77621 L F
.971 .658 .343 r
.54201 .77621 m .54324 .77722 L .54326 .77935 L F
.466 .401 .7 r
.47163 .67189 m .4727 .67394 L .47083 .67418 L F
.641 .573 .762 r
.4727 .67394 m .47103 .67674 L .47083 .67418 L F
.501 .519 .807 r
.6926 .51095 m .69379 .50701 L .69173 .509 L F
.6926 .51095 m .69518 .51049 L .69379 .50701 L F
.515 .254 .458 r
.6926 .51095 m .69495 .51233 L .69518 .51049 L F
.6926 .51095 m .69267 .51327 L .69495 .51233 L F
.608 .695 .905 r
.36575 .72365 m .3689 .72441 L .36752 .72337 L F
.647 .731 .91 r
.36752 .72337 m .3689 .72441 L .36876 .72289 L F
.416 .328 .649 r
.39643 .84318 m .39483 .84295 L .39438 .84103 L F
.211 0 0 r
.2464 .58853 m .24853 .588 L .24661 .58834 L F
.591 .64 .868 r
.25792 .63459 m .25738 .63765 L .25594 .63524 L F
.25792 .63459 m .25972 .63737 L .25738 .63765 L F
.384 .554 .898 r
.65002 .49565 m .64869 .49719 L .64804 .49572 L F
.65002 .49565 m .65184 .49817 L .64869 .49719 L F
.656 .501 .662 r
.51553 .73309 m .51578 .7353 L .51375 .73539 L F
.617 .496 .693 r
.51801 .73281 m .51578 .7353 L .51553 .73309 L F
.775 .648 .721 r
.7061 .58793 m .70946 .58834 L .7073 .58586 L F
.801 .608 .641 r
.7061 .58793 m .70972 .59054 L .70946 .58834 L F
.532 .476 .738 r
.35334 .68009 m .35396 .68262 L .35595 .68209 L F
.435 .417 .741 r
.35396 .68262 m .35642 .68515 L .35595 .68209 L F
.897 .933 .831 r
.53913 .77459 m .54019 .77154 L .53795 .77198 L F
.467 .159 .36 r
.53142 .80729 m .53407 .80481 L .53272 .80687 L F
.3 0 .047 r
.53272 .80687 m .53407 .80481 L .53608 .80452 L F
.754 .438 .45 r
.53414 .80235 m .53608 .80452 L .53407 .80481 L F
.535 .425 .676 r
.75911 .60492 m .76074 .60162 L .75891 .60196 L F
.74 .638 .746 r
.69028 .51551 m .69161 .51901 L .69377 .51615 L F
.394 .181 .468 r
.69377 .51615 m .69161 .51901 L .6931 .51905 L F
.395 .188 .478 r
.6931 .51905 m .69161 .51901 L .6914 .521 L F
.629 .617 .819 r
.68285 .50493 m .68543 .50534 L .6842 .50303 L F
.893 .829 .777 r
.65787 .49346 m .65844 .49015 L .6586 .49118 L F
.417 .183 .45 r
.34434 .61282 m .34618 .61322 L .34395 .61495 L F
0 .087 .643 r
.65346 .50048 m .6522 .49977 L .65184 .49817 L F
.65346 .50048 m .65404 .5019 L .6522 .49977 L F
.467 .242 .487 r
.49342 .73864 m .49561 .73806 L .49578 .73572 L F
.391 .179 .468 r
.49578 .73572 m .49746 .73727 L .49802 .73535 L F
.49578 .73572 m .49561 .73806 L .49746 .73727 L F
.727 .766 .884 r
.47193 .7742 m .47023 .77551 L .46842 .77389 L F
.111 0 0 r
.50787 .73828 m .50676 .73922 L .5047 .7393 L F
.203 .633 .949 r
.50808 .73984 m .50676 .73922 L .50787 .73828 L F
.827 .582 .568 r
.51046 .73837 m .50808 .73984 L .50787 .73828 L F
.522 .609 .881 r
.74047 .61096 m .73718 .60881 L .73963 .60815 L F
.619 .592 .801 r
.74171 .60705 m .74047 .61096 L .73963 .60815 L F
.74171 .60705 m .7429 .6103 L .74047 .61096 L F
.573 .352 .543 r
.51375 .73539 m .51319 .73772 L .51046 .73837 L F
.515 .24 .435 r
.51578 .7353 m .51319 .73772 L .51375 .73539 L F
.657 .405 .526 r
.52571 .73126 m .52259 .7348 L .52559 .73089 L F
.829 .565 .54 r
.52846 .73244 m .52578 .73231 L .52585 .73009 L F
.87 .563 .466 r
.52846 .73244 m .52668 .7343 L .52578 .73231 L F
.657 .405 .526 r
.52668 .7343 m .52559 .73089 L .52578 .73231 L F
.52668 .7343 m .52532 .73447 L .52571 .73126 L F
.52532 .73447 m .52259 .7348 L .52571 .73126 L F
.829 .565 .54 r
.52587 .72994 m .52585 .73009 L .52585 .72993 L F
.52846 .73244 m .52585 .73009 L .52587 .72994 L F
.87 .563 .466 r
.52846 .73244 m .52908 .73516 L .52668 .7343 L F
0 0 .215 r
.54712 .76261 m .54658 .76539 L .54566 .76612 L F
.284 .664 .971 r
.54658 .76539 m .54791 .76615 L .54566 .76612 L F
.571 .55 .792 r
.54791 .76615 m .54587 .76871 L .54566 .76612 L F
.003 0 0 r
.74014 .59599 m .7394 .59636 L .73708 .59685 L F
.165 0 0 r
.74014 .59599 m .74244 .59581 L .7394 .59636 L F
.565 .697 .93 r
.36575 .72365 m .36609 .72092 L .365 .72073 L F
.36575 .72365 m .36752 .72337 L .36609 .72092 L F
.46 0 0 r
.38374 .64956 m .38561 .65037 L .38721 .64933 L F
.234 0 0 r
.38561 .65037 m .38937 .64954 L .38721 .64933 L F
.812 .762 .807 r
.64273 .52406 m .6466 .52427 L .64495 .52322 L F
.578 .531 .766 r
.6466 .52427 m .64942 .52687 L .64823 .524 L F
.541 .301 .5 r
.46042 .67995 m .4603 .68215 L .458 .6824 L F
.661 .401 .516 r
.46042 .67995 m .46266 .68221 L .4603 .68215 L F
.607 .404 .581 r
.46267 .67971 m .46266 .68221 L .46042 .67995 L F
.69 .433 .529 r
.6347 .52661 m .63717 .52638 L .63668 .52436 L F
0 0 0 r
.63987 .52133 m .63668 .52436 L .64064 .52452 L F
.666 .537 .698 r
.63717 .52638 m .64064 .52452 L .63668 .52436 L F
.702 .599 .738 r
.52873 .76856 m .53194 .77056 L .53416 .76744 L F
.564 .017 0 r
.53194 .77056 m .53289 .77091 L .53453 .77179 L F
.53194 .77056 m .53453 .77179 L .53292 .7698 L F
.417 0 .123 r
.53973 .74315 m .54315 .74114 L .53986 .74134 L F
.53973 .74315 m .54221 .74288 L .54315 .74114 L F
0 0 0 r
.54315 .74114 m .54221 .74288 L .5442 .73992 L F
.461 .821 .995 r
.41559 .64956 m .41763 .64917 L .41908 .64982 L F
.257 .728 .943 r
.41763 .64917 m .42121 .64964 L .41908 .64982 L F
.369 .055 .297 r
.50343 .74227 m .50235 .74151 L .5047 .7393 L F
.227 0 .223 r
.50676 .73922 m .50343 .74227 L .5047 .7393 L F
.825 .372 .148 r
.58911 .67763 m .59025 .67704 L .58862 .67703 L F
.58911 .67763 m .59219 .67942 L .59025 .67704 L F
.618 .769 .953 r
.4553 .65037 m .45434 .65229 L .45309 .65096 L F
.497 .621 .904 r
.4553 .65037 m .45642 .65221 L .45434 .65229 L F
.567 .532 .776 r
.45773 .6554 m .45434 .65229 L .45642 .65221 L F
.646 .246 .272 r
.56209 .71064 m .56431 .71231 L .56548 .71044 L F
.849 .502 .396 r
.56548 .71044 m .56431 .71231 L .5659 .71214 L F
.758 .445 .455 r
.56548 .71044 m .5659 .71214 L .56872 .71211 L F
.539 .168 .284 r
.61395 .56201 m .61359 .56092 L .61591 .56213 L F
.538 .17 .29 r
.61359 .56092 m .61577 .56081 L .61591 .56213 L F
.654 .604 .786 r
.6994 .50239 m .6969 .50322 L .69662 .5021 L F
.457 .208 .447 r
.31881 .64106 m .31831 .64304 L .31639 .6435 L F
.392 .167 .45 r
.3204 .64043 m .31831 .64304 L .31881 .64106 L F
.486 .108 .248 r
.47965 .74616 m .48204 .74606 L .48298 .744 L F
.325 0 .025 r
.48204 .74606 m .48549 .74413 L .48298 .744 L F
.672 .218 .166 r
.4859 .79902 m .48936 .79937 L .48828 .80092 L F
.853 .454 .286 r
.48828 .80092 m .48936 .79937 L .49007 .80125 L F
.803 .613 .645 r
.49314 .79955 m .49007 .80125 L .48936 .79937 L F
.922 .795 .704 r
.64078 .52674 m .64172 .53023 L .64181 .52764 L F
.608 .588 .805 r
.64261 .5351 m .64332 .53111 L .64086 .53049 L F
.269 0 0 r
.6423 .53059 m .64413 .53011 L .64172 .53023 L F
.608 .588 .805 r
.64332 .53111 m .64341 .53058 L .6423 .53059 L F
.269 0 0 r
.64291 .53098 m .64347 .53058 L .6423 .53059 L F
.64347 .53058 m .64413 .53011 L .6423 .53059 L F
.608 .588 .805 r
.6423 .53059 m .64347 .53025 L .6419 .53039 L F
.64341 .53058 m .64347 .53025 L .6423 .53059 L F
.64332 .53111 m .6419 .53039 L .64086 .53049 L F
.34 0 .068 r
.64086 .53049 m .6419 .53039 L .64291 .53098 L F
.269 0 0 r
.64291 .53098 m .6423 .53059 L .64203 .53047 L F
.34 0 .068 r
.6419 .53039 m .64347 .53025 L .64291 .53098 L F
.269 0 0 r
.64291 .53098 m .64203 .53047 L .64041 .52972 L F
.6423 .53059 m .64172 .53023 L .64106 .52997 L F
.6423 .53059 m .64106 .52997 L .64041 .52972 L F
.801 .608 .641 r
.7061 .58793 m .70833 .59181 L .70972 .59054 L F
.915 .942 .807 r
.70833 .59181 m .70734 .59341 L .70972 .59054 L F
.636 .644 .841 r
.46132 .65763 m .45773 .6554 L .45985 .65483 L F
.541 .591 .854 r
.46204 .65456 m .46132 .65763 L .45985 .65483 L F
.46204 .65456 m .46338 .65732 L .46132 .65763 L F
.562 .669 .91 r
.26683 .63775 m .26668 .64063 L .26485 .63812 L F
.26683 .63775 m .26862 .64021 L .26668 .64063 L F
.557 .829 .996 r
.43978 .65104 m .43624 .65062 L .4381 .65022 L F
.488 .816 1 r
.4381 .65022 m .44177 .65058 L .43978 .65104 L F
.157 0 .318 r
.49247 .76023 m .49201 .76271 L .4911 .7629 L F
.464 .29 .559 r
.49445 .75754 m .49443 .75997 L .49247 .76023 L F
.597 .388 .569 r
.49443 .75997 m .49201 .76271 L .49247 .76023 L F
.082 0 0 r
.40077 .71127 m .40045 .71034 L .40248 .7097 L F
.40077 .71127 m .39893 .71195 L .40045 .71034 L F
.76 .715 .81 r
.34256 .7267 m .34334 .72917 L .34614 .72707 L F
.796 .817 .869 r
.55395 .7909 m .55681 .78875 L .55513 .78755 L F
.425 .174 .428 r
.3394 .62106 m .33961 .61827 L .34142 .61767 L F
.781 .47 .462 r
.49841 .80128 m .50057 .79951 L .49703 .79925 L F
0 0 0 r
.4985 .80207 m .50057 .79951 L .50174 .80153 L F
.781 .47 .462 r
.49841 .80128 m .50174 .80153 L .50057 .79951 L F
.559 .641 .889 r
.68895 .50897 m .69032 .5063 L .68835 .50653 L F
.68895 .50897 m .69173 .509 L .69032 .5063 L F
.358 .798 .639 r
.5158 .79941 m .51245 .80123 L .51552 .80187 L F
.341 .33 .702 r
.72122 .51023 m .72344 .51189 L .7211 .51205 L F
.304 .077 .395 r
.72344 .51189 m .72127 .5148 L .7211 .51205 L F
.854 .593 .544 r
.55342 .77155 m .55125 .773 L .55208 .77118 L F
.55342 .77155 m .55307 .77423 L .55125 .773 L F
.281 0 0 r
.28941 .65215 m .28785 .65207 L .28589 .65163 L F
.109 .66 .806 r
.29154 .65211 m .28785 .65207 L .28941 .65215 L F
.843 .618 .598 r
.66045 .50257 m .65791 .50427 L .65952 .50066 L F
.481 .415 .706 r
.35442 .67169 m .35682 .67374 L .3565 .67127 L F
.35442 .67169 m .35511 .67441 L .35682 .67374 L F
.224 0 0 r
.34764 .72127 m .34712 .72168 L .34485 .72159 L F
.691 .909 .564 r
.34941 .71891 m .34712 .72168 L .34764 .72127 L F
.668 .441 .567 r
.46838 .67716 m .4683 .67951 L .46598 .67949 L F
.666 .46 .597 r
.47103 .67674 m .4683 .67951 L .46838 .67716 L F
.736 .738 .853 r
.74514 .60913 m .74612 .6107 L .7429 .6103 L F
.596 .662 .884 r
.74785 .60851 m .74612 .6107 L .74514 .60913 L F
.74785 .60851 m .74849 .61025 L .74612 .6107 L F
.532 .476 .738 r
.35334 .68009 m .35595 .68209 L .35538 .67966 L F
.452 0 .086 r
.48315 .7857 m .48614 .78488 L .48442 .78702 L F
.653 .489 .649 r
.48371 .78861 m .48702 .78943 L .48614 .78488 L F
.608 .841 .465 r
.48442 .78702 m .48614 .78488 L .48661 .78409 L F
.513 .428 .697 r
.48614 .78488 m .48824 .78486 L .48806 .78189 L F
.732 .618 .731 r
.48702 .78943 m .48824 .78486 L .48614 .78488 L F
.873 .805 .78 r
.61674 .51925 m .6133 .52114 L .6151 .51801 L F
.61674 .51925 m .61444 .52233 L .6133 .52114 L F
.533 .329 .55 r
.53946 .74957 m .53899 .75191 L .5369 .75221 L F
.529 .488 .755 r
.53823 .75237 m .5369 .75221 L .53899 .75191 L F
.377 .83 .929 r
.44177 .65058 m .44377 .6501 L .44519 .65033 L F
.45 .868 .944 r
.44519 .65033 m .44594 .64949 L .44711 .65009 L F
.44519 .65033 m .44377 .6501 L .44594 .64949 L F
.296 .775 .923 r
.2743 .6389 m .27619 .63869 L .27772 .63893 L F
.408 .821 .974 r
.27619 .63869 m .27992 .6387 L .27772 .63893 L F
.812 .563 .563 r
.6278 .50482 m .62796 .50725 L .63102 .50776 L F
.829 .824 .844 r
.62775 .50858 m .63102 .50776 L .62796 .50725 L F
.62775 .50858 m .62823 .5094 L .63102 .50776 L F
.369 .145 .439 r
.63325 .5049 m .63102 .50776 L .63314 .50693 L F
.631 .93 .97 r
.63113 .50925 m .63314 .50693 L .63102 .50776 L F
.369 .145 .439 r
.63325 .5049 m .63102 .50776 L .63314 .50693 L F
.781 .644 .711 r
.63314 .50693 m .63113 .50925 L .63102 .50776 L F
.313 .773 .948 r
.39457 .69866 m .39676 .69845 L .39788 .69881 L F
.087 .646 .745 r
.39676 .69845 m .39998 .69826 L .39788 .69881 L F
.382 .563 .906 r
.58664 .74888 m .5859 .74636 L .5843 .74588 L F
.58664 .74888 m .58778 .74884 L .5859 .74636 L F
.41 .052 .244 r
.7707 .61894 m .76781 .62049 L .76827 .61931 L F
.577 .591 .831 r
.50888 .72997 m .50964 .72661 L .50811 .72878 L F
.50888 .72997 m .51168 .72988 L .50964 .72661 L F
.802 .515 .504 r
.50808 .73107 m .50888 .72997 L .50811 .72878 L F
0 .309 .767 r
.49613 .7665 m .49672 .76679 L .49673 .76679 L F
.49614 .7665 m .49673 .76679 L .50019 .76506 L F
.49613 .7665 m .49673 .76679 L .49614 .7665 L F
0 .306 .767 r
.49786 .76735 m .49724 .76721 L .49673 .76679 L F
0 .309 .767 r
.49672 .76679 m .49824 .76697 L .50019 .76506 L F
0 .306 .767 r
.49786 .76735 m .49673 .76679 L .49434 .76482 L F
.36 .622 .952 r
.49434 .76482 m .49673 .76679 L .49353 .76623 L F
.604 .457 .655 r
.49353 .76623 m .49724 .76721 L .49613 .7665 L F
.36 .622 .952 r
.49673 .76679 m .49724 .76721 L .4948 .76657 L F
.49673 .76679 m .4948 .76657 L .49353 .76623 L F
0 .309 .767 r
.49672 .76679 m .49786 .76735 L .49824 .76697 L F
.976 .922 .638 r
.50019 .76506 m .5001 .76231 L .50151 .76469 L F
.50019 .76506 m .49907 .7649 L .5001 .76231 L F
.958 .947 .681 r
.50019 .76506 m .49786 .76735 L .49907 .7649 L F
.73 .537 .631 r
.55147 .766 m .54791 .76615 L .55027 .76531 L F
.55147 .766 m .54818 .7687 L .54791 .76615 L F
.55147 .766 m .55122 .76929 L .54818 .7687 L F
0 .004 .576 r
.54472 .73205 m .5442 .73268 L .54299 .73194 L F
.803 .613 .645 r
.49314 .79955 m .493 .80141 L .49007 .80125 L F
.51 .175 .334 r
.63711 .553 m .63497 .55202 L .63733 .55175 L F
.63711 .553 m .63417 .55444 L .63497 .55202 L F
.515 .667 .931 r
.7131 .60561 m .71448 .60371 L .71208 .60421 L F
.7131 .60561 m .71534 .60542 L .71448 .60371 L F
.851 .394 .023 r
.67034 .51917 m .67001 .52006 L .66969 .5178 L F
.67034 .51917 m .67129 .52088 L .67001 .52006 L F
.571 .55 .792 r
.54791 .76615 m .54818 .7687 L .54587 .76871 L F
.468 .03 .122 r
.40245 .69867 m .40477 .69869 L .40629 .69692 L F
.4 .015 .188 r
.40477 .69869 m .40819 .69614 L .40629 .69692 L F
.41 .19 .467 r
.34142 .61767 m .34181 .61578 L .34395 .61495 L F
.401 0 0 r
.49479 .77226 m .49548 .77288 L .493 .77186 L F
.49479 .77226 m .49707 .77346 L .49548 .77288 L F
.43 0 0 r
.53262 .7212 m .53489 .72139 L .53641 .72072 L F
.573 .094 .079 r
.53641 .72072 m .53489 .72139 L .53831 .72128 L F
.682 .72 .878 r
.69028 .51551 m .69377 .51615 L .69254 .51453 L F
.602 .69 .904 r
.69254 .51453 m .69377 .51615 L .69502 .51441 L F
.47 .251 .498 r
.69377 .51615 m .69601 .51749 L .69502 .51441 L F
.69377 .51615 m .6931 .51905 L .69601 .51749 L F
.612 .524 .73 r
.38333 .68746 m .38418 .69107 L .38207 .69173 L F
.208 0 .104 r
.31707 .64489 m .31639 .6435 L .31831 .64304 L F
.31707 .64489 m .31521 .64568 L .31639 .6435 L F
.331 .253 .616 r
.54777 .73541 m .5493 .73495 L .54959 .73201 L F
.972 .695 .446 r
.54989 .73744 m .5493 .73495 L .54777 .73541 L F
.741 .438 .467 r
.51823 .75129 m .52159 .7494 L .51822 .74927 L F
.51823 .75129 m .52176 .7517 L .52159 .7494 L F
.7 .405 .474 r
.52159 .7494 m .52176 .7517 L .52441 .75135 L F
.59 .088 .03 r
.45436 .78499 m .45749 .78526 L .45635 .78685 L F
.72 .198 0 r
.45749 .78526 m .45823 .78711 L .45635 .78685 L F
.45749 .78526 m .4602 .78749 L .45823 .78711 L F
.165 0 0 r
.63987 .55175 m .64325 .54982 L .64202 .55114 L F
0 0 0 r
.64202 .55114 m .64325 .54982 L .64531 .54887 L F
.136 .466 .891 r
.64097 .49035 m .64471 .49312 L .64128 .4919 L F
.54 .518 .78 r
.64471 .49312 m .64294 .49437 L .64128 .4919 L F
.952 .605 .232 r
.6666 .52431 m .66504 .52127 L .66538 .5235 L F
.868 .523 .018 r
.66639 .52531 m .6666 .52431 L .66538 .5235 L F
.504 0 0 r
.66601 .52531 m .66639 .52531 L .66471 .52442 L F
.868 .523 .018 r
.66639 .52531 m .66718 .52646 L .66687 .52531 L F
.002 .059 .569 r
.66835 .52663 m .66718 .52646 L .66639 .52531 L F
.66896 .52705 m .66851 .5269 L .66835 .52663 L F
.66851 .5269 m .66718 .52646 L .66835 .52663 L F
.955 .734 .563 r
.66914 .52471 m .66793 .52594 L .6687 .52352 L F
.504 0 0 r
.66752 .52635 m .66896 .52705 L .66639 .52531 L F
.955 .734 .563 r
.66793 .52594 m .66752 .52635 L .66779 .52571 L F
.66793 .52594 m .66779 .52571 L .6687 .52352 L F
.504 0 0 r
.66752 .52635 m .66639 .52531 L .66601 .52531 L F
.868 .523 .018 r
.66639 .52531 m .66687 .52531 L .6666 .52431 L F
.575 .423 .637 r
.52716 .74595 m .52963 .74559 L .52909 .74305 L F
.339 .338 .712 r
.52716 .74595 m .5298 .74797 L .52963 .74559 L F
0 0 .483 r
.57282 .72559 m .57457 .72751 L .57361 .72645 L F
.509 0 0 r
.57457 .72751 m .57569 .7286 L .57361 .72645 L F
.57457 .72751 m .5769 .72951 L .57569 .7286 L F
.511 .375 .632 r
.44175 .67679 m .44382 .67347 L .44163 .67438 L F
.435 0 .11 r
.25391 .58687 m .25603 .58684 L .25447 .586 L F
.794 .694 .754 r
.64124 .50426 m .64447 .50527 L .6443 .50194 L F
.6443 .50194 m .64447 .50527 L .64124 .50426 L F
.6443 .50194 m .64447 .50527 L .64124 .50426 L F
.904 .558 .379 r
.64447 .50527 m .64279 .50575 L .64178 .50478 L F
0 .225 .746 r
.64124 .50426 m .64279 .50575 L .64215 .50495 L F
.515 .204 .378 r
.64215 .50495 m .64064 .50664 L .64124 .50426 L F
.307 0 .148 r
.64179 .50524 m .64176 .50529 L .6408 .50604 L F
.675 .412 .516 r
.64079 .50613 m .64064 .50664 L .64215 .50495 L F
.307 0 .148 r
.64176 .50529 m .64091 .50656 L .64079 .50613 L F
.64091 .50656 m .64076 .50645 L .64079 .50613 L F
.64176 .50529 m .64079 .50613 L .6408 .50604 L F
0 0 .016 r
.64124 .50426 m .64082 .50594 L .64088 .5058 L F
.307 0 .148 r
.64106 .50525 m .63796 .50835 L .63788 .50615 L F
.64215 .50495 m .6408 .50604 L .64106 .50525 L F
.6408 .50604 m .63796 .50835 L .64106 .50525 L F
0 0 .016 r
.64093 .50565 m .64088 .5058 L .64091 .50574 L F
.64124 .50426 m .64088 .5058 L .64093 .50565 L F
.675 .412 .516 r
.64106 .50525 m .64079 .50613 L .64215 .50495 L F
.307 0 .148 r
.64215 .50495 m .6418 .50543 L .64179 .50524 L F
.165 0 .009 r
.64064 .50664 m .64128 .50681 L .64074 .50644 L F
.871 .61 .54 r
.64313 .50839 m .64112 .508 L .64223 .50522 L F
.64112 .508 m .64008 .5078 L .64097 .50673 L F
.64112 .508 m .64097 .50673 L .64223 .50522 L F
.64223 .50522 m .64097 .50673 L .64215 .50495 L F
.165 0 .009 r
.64064 .50664 m .64008 .5078 L .64097 .50673 L F
.871 .61 .54 r
.64097 .50673 m .64008 .5078 L .64096 .50659 L F
.64097 .50673 m .64096 .50659 L .64215 .50495 L F
.165 0 .009 r
.64128 .50681 m .64215 .50705 L .64095 .50653 L F
.64096 .50659 m .64095 .50653 L .64074 .50644 L F
.64128 .50681 m .64095 .50653 L .64096 .50659 L F
.307 0 .148 r
.6418 .50543 m .64096 .50659 L .64179 .50524 L F
.64096 .50659 m .64008 .5078 L .64091 .50656 L F
.64096 .50659 m .64091 .50656 L .64179 .50524 L F
.904 .558 .379 r
.64447 .50527 m .64178 .50478 L .64176 .50442 L F
.165 0 .009 r
.6409 .50612 m .64215 .50705 L .64199 .50403 L F
.64074 .50644 m .64095 .50653 L .6409 .50612 L F
.64095 .50653 m .64215 .50705 L .6409 .50612 L F
.64097 .50673 m .64008 .5078 L .64215 .50705 L F
.307 0 .148 r
.64091 .50656 m .64071 .50686 L .64076 .50645 L F
.6408 .50604 m .64076 .50616 L .63796 .50835 L F
.675 .412 .516 r
.64028 .50657 m .64064 .50664 L .64079 .50613 L F
.259 0 .048 r
.63796 .50835 m .64064 .50664 L .64028 .50657 L F
.63796 .50835 m .64028 .50657 L .63788 .50615 L F
.63796 .50835 m .64008 .5078 L .64064 .50664 L F
.307 0 .148 r
.64028 .50657 m .64008 .5078 L .63834 .50825 L F
.64076 .50616 m .64073 .50623 L .64028 .50657 L F
.64073 .50623 m .64008 .5078 L .64028 .50657 L F
.64076 .50616 m .63834 .50825 L .63796 .50835 L F
.675 .412 .516 r
.63788 .50615 m .64028 .50657 L .64106 .50525 L F
.64028 .50657 m .64079 .50613 L .64106 .50525 L F
0 0 .016 r
.64146 .50397 m .64091 .50574 L .64245 .50262 L F
.64124 .50426 m .64091 .50574 L .64146 .50397 L F
.64082 .50594 m .64064 .50664 L .64077 .50634 L F
.904 .558 .379 r
.64176 .50442 m .64178 .50478 L .64124 .50426 L F
0 0 .016 r
.64082 .50594 m .64077 .50634 L .64245 .50262 L F
.307 0 .148 r
.64071 .50686 m .64008 .5078 L .6408 .50604 L F
.904 .558 .379 r
.64447 .50527 m .64472 .50706 L .64279 .50575 L F
.681 .607 .767 r
.64561 .5015 m .64447 .50527 L .6443 .50194 L F
.68 .624 .786 r
.73599 .60534 m .73718 .60881 L .73362 .60744 L F
.611 .582 .796 r
.73812 .60446 m .73718 .60881 L .73599 .60534 L F
.73812 .60446 m .73963 .60815 L .73718 .60881 L F
.781 .752 .827 r
.59132 .75189 m .59473 .75203 L .59374 .75311 L F
.208 0 .024 r
.596 .75206 m .59473 .75203 L .5968 .75154 L F
.596 .75206 m .59374 .75311 L .59473 .75203 L F
.34 .744 .982 r
.3156 .59261 m .31911 .59328 L .31706 .59337 L F
.461 0 .043 r
.7099 .50631 m .71227 .50724 L .71185 .50553 L F
.71227 .50724 m .71272 .50742 L .71262 .5072 L F
.71227 .50724 m .71262 .5072 L .71185 .50553 L F
.706 .594 .728 r
.70758 .50825 m .71074 .50898 L .71032 .50747 L F
0 .396 .84 r
.70979 .50553 m .7099 .50631 L .70692 .50415 L F
.706 .594 .728 r
.70799 .50775 m .71032 .50747 L .70979 .50553 L F
.70758 .50825 m .71032 .50747 L .70799 .50775 L F
.461 0 .043 r
.71272 .50742 m .71285 .50737 L .71185 .50553 L F
.06 0 .247 r
.71185 .50553 m .71292 .5075 L .71316 .50596 L F
.555 .501 .75 r
.70979 .50553 m .71241 .50722 L .71316 .50596 L F
0 .396 .84 r
.70979 .50553 m .71272 .50742 L .7099 .50631 L F
.555 .501 .75 r
.71217 .50763 m .71254 .50749 L .71316 .50596 L F
.135 0 .187 r
.71316 .50596 m .7126 .50734 L .71453 .50666 L F
.461 0 .043 r
.71272 .50742 m .71292 .5075 L .71285 .50737 L F
0 .396 .84 r
.7126 .50734 m .71292 .5075 L .71272 .50742 L F
.71269 .50736 m .71292 .5075 L .7126 .50734 L F
.135 0 .187 r
.7126 .50734 m .7124 .50784 L .71313 .50743 L F
.7126 .50734 m .71313 .50743 L .71453 .50666 L F
0 .396 .84 r
.70979 .50553 m .71269 .50736 L .7126 .50734 L F
.555 .501 .75 r
.70979 .50553 m .71217 .50763 L .71241 .50722 L F
.71217 .50763 m .7124 .50784 L .71254 .50749 L F
.721 .923 .96 r
.71413 .50458 m .71185 .50553 L .71316 .50369 L F
.06 0 .247 r
.71185 .50553 m .71316 .50596 L .71316 .50369 L F
.093 0 0 r
.74749 .59344 m .75056 .59121 L .74975 .59266 L F
.17 0 0 r
.74975 .59266 m .75056 .59121 L .75285 .59035 L F
.234 0 0 r
.48849 .77368 m .48573 .77532 L .48694 .77445 L F
.054 0 0 r
.38937 .64954 m .39159 .64952 L .39288 .64939 L F
.442 0 0 r
.39159 .64952 m .39504 .64916 L .39288 .64939 L F
.716 .768 .894 r
.75191 .61064 m .74849 .61025 L .75093 .60993 L F
.542 .922 .797 r
.75455 .60904 m .75191 .61064 L .75328 .60945 L F
.515 .837 .999 r
.75328 .60945 m .75191 .61064 L .75093 .60993 L F
.558 .544 .795 r
.38949 .69359 m .38856 .69737 L .38754 .69388 L F
.38949 .69359 m .39084 .69725 L .38856 .69737 L F
.591 .595 .824 r
.39136 .69776 m .38856 .69737 L .39084 .69725 L F
.836 .373 0 r
.67199 .52911 m .67329 .53003 L .67409 .53158 L F
.838 .626 .615 r
.62474 .52067 m .6281 .5189 L .62528 .51802 L F
.62474 .52067 m .62777 .5212 L .6281 .5189 L F
.05 .617 .732 r
.28525 .63905 m .28724 .63897 L .28931 .63894 L F
.219 .741 .821 r
.28724 .63897 m .29155 .63856 L .28931 .63894 L F
.504 .137 .276 r
.64294 .49437 m .64228 .49554 L .63988 .49557 L F
.549 .344 .555 r
.64471 .49312 m .64228 .49554 L .64294 .49437 L F
.625 .583 .786 r
.71673 .50391 m .71413 .50458 L .71356 .50261 L F
.628 .626 .829 r
.71761 .50589 m .71413 .50458 L .71673 .50391 L F
.209 0 0 r
.2934 .63769 m .29716 .63585 L .29454 .6374 L F
.2934 .63769 m .29551 .63728 L .29716 .63585 L F
.143 0 0 r
.29551 .63728 m .29867 .63639 L .29716 .63585 L F
.332 0 .012 r
.29716 .63585 m .29867 .63639 L .29946 .63547 L F
.81 .515 0 r
.5791 .73443 m .57895 .73438 L .57848 .73229 L F
0 .033 .579 r
.57895 .73438 m .57936 .73443 L .57867 .73428 L F
.97 .905 .552 r
.57716 .73397 m .57848 .73229 L .57895 .73438 L F
0 .033 .579 r
.57895 .73438 m .57867 .73428 L .57716 .73397 L F
.81 .515 0 r
.57941 .73551 m .57895 .73438 L .5791 .73443 L F
0 .06 .623 r
.57941 .73551 m .58076 .7364 L .57895 .73438 L F
.57941 .73551 m .58121 .73796 L .58076 .7364 L F
.5 .259 .48 r
.49998 .73219 m .50225 .73181 L .5027 .72801 L F
.588 .546 .775 r
.5027 .72801 m .50559 .72934 L .50469 .72651 L F
.17 0 0 r
.50225 .73181 m .50559 .72934 L .5027 .72801 L F
.541 .321 .53 r
.46491 .75491 m .46722 .75462 L .46731 .7521 L F
.474 .267 .518 r
.46731 .7521 m .46927 .75402 L .4696 .75189 L F
.46731 .7521 m .46722 .75462 L .46927 .75402 L F
.35 0 .215 r
.49342 .73864 m .49296 .74 L .49561 .73806 L F
.631 .431 .593 r
.55171 .74048 m .55085 .74331 L .54886 .7411 L F
.627 .161 .126 r
.49232 .79558 m .49379 .79384 L .49035 .79364 L F
.366 .743 .989 r
.49436 .79299 m .49623 .79396 L .49379 .79384 L F
.61 .14 .114 r
.49571 .79504 m .49379 .79384 L .49232 .79558 L F
.396 0 0 r
.49379 .79384 m .49623 .79396 L .49478 .79498 L F
.49379 .79384 m .49478 .79498 L .49436 .79299 L F
.631 .165 .13 r
.75382 .5842 m .75151 .58267 L .75182 .5852 L F
.51 .702 .956 r
.30112 .60186 m .30437 .60315 L .30295 .60211 L F
.319 .678 .977 r
.30437 .60315 m .3054 .60197 L .30295 .60211 L F
.357 0 0 r
.54504 .72473 m .54758 .7257 L .54898 .72595 L F
.263 0 0 r
.54758 .7257 m .55119 .72637 L .54898 .72595 L F
.409 0 .146 r
.71468 .51931 m .7141 .52036 L .71173 .52069 L F
.356 0 .21 r
.71689 .51847 m .7141 .52036 L .71468 .51931 L F
.824 .619 .625 r
.71674 .58733 m .71619 .59092 L .71916 .59102 L F
.753 .519 .576 r
.71529 .59296 m .7193 .59329 L .71916 .59102 L F
.905 .661 .559 r
.67722 .53297 m .6744 .53395 L .67409 .53158 L F
.67722 .53297 m .67665 .53479 L .6744 .53395 L F
.019 0 .205 r
.67835 .5336 m .67722 .53297 L .67932 .53175 L F
.67835 .5336 m .67665 .53479 L .67722 .53297 L F
.612 .543 .752 r
.35609 .69348 m .35699 .69681 L .35922 .69631 L F
.843 .459 .323 r
.5468 .70806 m .54593 .70961 L .54418 .70696 L F
.795 .395 .295 r
.54776 .70986 m .54593 .70961 L .5468 .70806 L F
.577 .072 .018 r
.50843 .76802 m .51113 .76876 L .51147 .76815 L F
.042 0 0 r
.51147 .76815 m .51253 .7655 L .51428 .76817 L F
.51147 .76815 m .51265 .76826 L .51253 .7655 L F
.51147 .76815 m .51113 .76876 L .51265 .76826 L F
.906 .788 .72 r
.67129 .52088 m .67172 .52435 L .67046 .52269 L F
.988 .719 .373 r
.67172 .52435 m .67092 .52569 L .67046 .52269 L F
.67172 .52435 m .67192 .52674 L .67092 .52569 L F
.427 .052 .223 r
.42114 .70226 m .41832 .70392 L .41897 .70268 L F
.738 .844 .4 r
.58326 .72295 m .58243 .72512 L .58401 .7217 L F
.573 .488 .72 r
.55494 .77671 m .55307 .77423 L .55644 .77401 L F
.594 .294 .43 r
.55821 .77593 m .55494 .77671 L .55644 .77401 L F
.907 .942 .818 r
.66837 .50801 m .66686 .51026 L .66612 .50924 L F
.98 .686 .346 r
.66686 .51026 m .66596 .51169 L .66612 .50924 L F
.66686 .51026 m .66707 .51278 L .66596 .51169 L F
.532 0 0 r
.4702 .79312 m .46636 .79132 L .46924 .79144 L F
.566 .926 .942 r
.647 .52941 m .64413 .53011 L .64636 .52959 L F
.232 .739 .687 r
.64898 .52874 m .647 .52941 L .64636 .52959 L F
.83 .7 .72 r
.52499 .77117 m .52873 .76856 L .52553 .76878 L F
.52499 .77117 m .52714 .77182 L .52873 .76856 L F
.717 .468 .548 r
.52585 .72993 m .52559 .73089 L .5241 .72978 L F
.52585 .72993 m .52578 .73231 L .52559 .73089 L F
.638 .266 .321 r
.62987 .51626 m .63233 .51783 L .6328 .51715 L F
.709 .493 .595 r
.52559 .73089 m .52026 .72977 L .5241 .72978 L F
.378 .755 .99 r
.55956 .78449 m .56099 .78534 L .55856 .78541 L F
.55956 .78449 m .56099 .78534 L .55856 .78541 L F
.984 .731 .468 r
.52273 .7434 m .5215 .74274 L .52284 .74098 L F
.52284 .74098 m .52273 .7434 L .52492 .74053 L F
.52284 .74098 m .5215 .74274 L .52273 .7434 L F
.476 .276 .528 r
.52492 .74053 m .52273 .7434 L .52284 .74098 L F
.992 .812 .563 r
.66504 .52127 m .66546 .51888 L .66445 .51788 L F
.41 .326 .65 r
.36499 .71896 m .36632 .7161 L .36407 .71642 L F
.36499 .71896 m .36661 .71848 L .36632 .7161 L F
.247 .027 .371 r
.365 .72073 m .36661 .71848 L .36499 .71896 L F
.74 .524 .601 r
.48824 .78486 m .49131 .78267 L .48806 .78189 L F
.48824 .78486 m .49169 .78516 L .49131 .78267 L F
.827 .582 .568 r
.51046 .73837 m .51022 .74079 L .50808 .73984 L F
.645 .416 .556 r
.51356 .73981 m .51046 .73837 L .51319 .73772 L F
.51356 .73981 m .51022 .74079 L .51046 .73837 L F
.628 .643 .847 r
.73945 .61963 m .74191 .61902 L .73848 .61783 L F
.177 .485 .899 r
.7218 .60855 m .72385 .60829 L .72076 .60743 L F
.7218 .60855 m .72459 .60964 L .72385 .60829 L F
.966 .757 .57 r
.32621 .75508 m .32352 .75851 L .32431 .75406 L F
.47 .775 .997 r
.3266 .75365 m .32621 .75508 L .32431 .75406 L F
.3266 .75365 m .32858 .75479 L .32621 .75508 L F
.781 .923 .549 r
.3266 .75365 m .32621 .75508 L .32858 .75479 L F
.3266 .75365 m .32352 .75851 L .32621 .75508 L F
.436 .363 .677 r
.35226 .60111 m .35058 .60146 L .3501 .59934 L F
0 .126 .618 r
.35083 .59972 m .3501 .59934 L .34836 .5994 L F
.35083 .59972 m .35226 .60111 L .3501 .59934 L F
.448 .677 .962 r
.34506 .59807 m .34437 .59959 L .34321 .59825 L F
.526 .767 .985 r
.34506 .59807 m .34648 .5993 L .34437 .59959 L F
0 0 0 r
.66541 .53967 m .66576 .53832 L .66585 .5374 L F
.655 .854 .976 r
.42929 .66173 m .43214 .66202 L .43084 .66128 L F
.663 .87 .977 r
.43084 .66128 m .43214 .66202 L .43492 .66063 L F
.36 .622 .952 r
.49434 .76482 m .49353 .76623 L .4921 .76525 L F
.779 .475 .474 r
.54326 .77935 m .54582 .77882 L .54478 .78174 L F
.592 .398 .588 r
.54766 .77721 m .54816 .77908 L .54582 .77882 L F
.582 .285 .43 r
.54582 .77882 m .5471 .78205 L .54478 .78174 L F
.54582 .77882 m .54816 .77908 L .5471 .78205 L F
.243 0 0 r
.53414 .80235 m .53033 .80419 L .53249 .80369 L F
.857 .994 .752 r
.53436 .80107 m .53414 .80235 L .53249 .80369 L F
.742 .608 .709 r
.5426 .7486 m .53899 .75191 L .53946 .74957 L F
.737 .545 .633 r
.63088 .49605 m .63402 .49778 L .63375 .49348 L F
.603 .034 0 r
.6385 .4916 m .63794 .49128 L .6353 .492 L F
.653 .627 .811 r
.63432 .49227 m .6353 .492 L .6354 .48999 L F
.656 .75 .919 r
.63883 .49055 m .63525 .48996 L .63742 .48832 L F
.877 .962 .629 r
.63525 .48996 m .63492 .48954 L .63642 .48669 L F
.308 .775 .939 r
.6354 .48999 m .63492 .48954 L .63525 .48996 L F
.947 .785 .328 r
.6354 .48999 m .6353 .492 L .63492 .48954 L F
.877 .962 .629 r
.63525 .48996 m .63642 .48669 L .63742 .48832 L F
.603 .034 0 r
.63794 .49128 m .63492 .48954 L .6353 .492 L F
.653 .627 .811 r
.63375 .49348 m .6353 .492 L .63432 .49227 L F
.63375 .49348 m .63661 .49405 L .6353 .492 L F
.564 .914 .965 r
.29565 .65078 m .29507 .65182 L .29715 .65157 L F
.29565 .65078 m .29366 .65162 L .29507 .65182 L F
.228 0 0 r
.74603 .58943 m .74922 .58763 L .7469 .58807 L F
.39 0 0 r
.53831 .72128 m .5406 .72191 L .54172 .72184 L F
.602 .03 0 r
.5406 .72191 m .54393 .72368 L .54172 .72184 L F
.637 .299 .382 r
.73373 .59553 m .73615 .5958 L .73624 .59385 L F
.567 .325 .508 r
.73615 .5958 m .73853 .59349 L .73624 .59385 L F
0 .384 .769 r
.50323 .75871 m .50314 .75838 L .50211 .7574 L F
.50323 .75871 m .50582 .7598 L .50314 .75838 L F
.65 .344 .439 r
.458 .6824 m .45476 .6846 L .45501 .68334 L F
.659 .608 .787 r
.64846 .53532 m .65153 .53764 L .65084 .53709 L F
.727 .922 .958 r
.65153 .53764 m .64868 .53806 L .65084 .53709 L F
.543 .604 .865 r
.67912 .50669 m .67783 .50984 L .67637 .50598 L F
.67912 .50669 m .68013 .50956 L .67783 .50984 L F
.624 .74 .93 r
.76625 .58362 m .7629 .58279 L .76529 .58212 L F
.614 .727 .926 r
.76767 .5815 m .76625 .58362 L .76529 .58212 L F
.76767 .5815 m .76853 .58302 L .76625 .58362 L F
.611 .341 .484 r
.63325 .5049 m .63314 .50693 L .63572 .50658 L F
.63572 .50658 m .63314 .50693 L .63325 .5049 L F
.604 .948 .801 r
.52527 .77323 m .52427 .7744 L .5257 .77341 L F
0 0 0 r
.52305 .7762 m .52427 .7744 L .52527 .77323 L F
.796 .654 .706 r
.60406 .54614 m .60588 .54942 L .60287 .54886 L F
.804 .587 .608 r
.60287 .54886 m .60588 .54942 L .60547 .55169 L F
.49 .811 1 r
.27524 .58495 m .27488 .58624 L .27321 .58504 L F
.27524 .58495 m .27687 .58581 L .27488 .58624 L F
.714 .603 .731 r
.73362 .60744 m .73184 .60846 L .7302 .60481 L F
.964 .8 .631 r
.59762 .55649 m .59848 .55755 L .59683 .55886 L F
.547 .785 .987 r
.5997 .55625 m .59848 .55755 L .59762 .55649 L F
.5997 .55625 m .60097 .55733 L .59848 .55755 L F
.615 .441 .623 r
.59848 .55755 m .59911 .55999 L .59683 .55886 L F
.59848 .55755 m .60097 .55733 L .59911 .55999 L F
.226 .42 .844 r
.4602 .78749 m .46042 .789 L .46289 .79025 L F
.724 .864 .947 r
.27204 .63972 m .26862 .64021 L .27091 .63938 L F
.299 .794 .857 r
.27091 .63938 m .2743 .6389 L .27204 .63972 L F
.56 .058 .019 r
.49758 .75778 m .49665 .75816 L .49647 .75811 L F
.49639 .75769 m .49647 .75811 L .49475 .75757 L F
.49758 .75778 m .49647 .75811 L .49639 .75769 L F
.606 .404 .581 r
.49445 .75754 m .49665 .75816 L .49758 .75778 L F
.927 .944 .788 r
.49889 .75435 m .49665 .75816 L .49758 .75778 L F
.79 .622 .673 r
.49622 .75846 m .49758 .75778 L .49665 .75816 L F
0 0 .129 r
.49778 .75621 m .49725 .75847 L .49654 .75846 L F
.49647 .75811 m .49622 .75846 L .49665 .75816 L F
.606 .404 .581 r
.49647 .75811 m .49443 .75997 L .49445 .75754 L F
.49665 .75816 m .49641 .75836 L .49647 .75811 L F
0 0 .129 r
.49647 .75811 m .49647 .75811 L .49622 .75846 L F
.49647 .75811 m .49638 .75846 L .49622 .75846 L F
.606 .404 .581 r
.49641 .75836 m .49443 .75997 L .49647 .75811 L F
.79 .622 .673 r
.49622 .75846 m .49773 .76035 L .49758 .75778 L F
0 0 .129 r
.49647 .75811 m .49654 .75846 L .49638 .75846 L F
.49778 .75621 m .49647 .75811 L .49665 .75816 L F
.49778 .75621 m .49654 .75846 L .49647 .75811 L F
.56 .058 .019 r
.49475 .75757 m .49665 .75816 L .49445 .75754 L F
.927 .944 .788 r
.49889 .75435 m .49758 .75778 L .50063 .75726 L F
.846 .886 .868 r
.49773 .76035 m .50063 .75726 L .49758 .75778 L F
.717 .449 .519 r
.4955 .80237 m .4985 .80207 L .49855 .80429 L F
.697 .382 .439 r
.4985 .80207 m .50112 .80423 L .49855 .80429 L F
.679 .356 .42 r
.6021 .56321 m .60562 .56304 L .60409 .56488 L F
.691 .371 .429 r
.60562 .56304 m .60792 .56519 L .60409 .56488 L F
.661 .381 .486 r
.60793 .56323 m .60792 .56519 L .60562 .56304 L F
.633 .309 .404 r
.68598 .53802 m .68395 .53979 L .68374 .53829 L F
.68598 .53802 m .68644 .54031 L .68395 .53979 L F
.393 .157 .432 r
.68847 .53926 m .68598 .53802 L .68817 .5374 L F
.68847 .53926 m .68644 .54031 L .68598 .53802 L F
.672 .336 0 r
.57395 .71503 m .575 .71767 L .57423 .71567 L F
.247 0 0 r
.40842 .70757 m .4069 .70895 L .40475 .70933 L F
.181 0 0 r
.40896 .70848 m .40842 .70757 L .41056 .70707 L F
.40896 .70848 m .4069 .70895 L .40842 .70757 L F
.761 .453 .465 r
.5659 .71214 m .56776 .715 L .56872 .71211 L F
.533 .286 .487 r
.57058 .71486 m .56872 .71211 L .56776 .715 L F
.492 .763 .991 r
.3436 .72056 m .34485 .72159 L .34558 .72029 L F
.37 .611 .943 r
.34485 .72159 m .34712 .72168 L .34558 .72029 L F
.614 .538 .745 r
.54962 .77366 m .55057 .7769 L .54766 .77721 L F
.591 .398 .588 r
.55057 .7769 m .54816 .77908 L .54766 .77721 L F
.763 .613 .692 r
.51652 .80402 m .51337 .80772 L .51349 .80496 L F
.593 .949 .863 r
.57204 .68164 m .56878 .68347 L .57093 .68285 L F
0 0 .051 r
.68795 .5023 m .68816 .50256 L .68877 .50109 L F
.68795 .5023 m .68753 .50456 L .68816 .50256 L F
.156 0 .034 r
.38094 .71869 m .37901 .71856 L .38115 .71832 L F
.38094 .71869 m .3781 .72038 L .37901 .71856 L F
0 0 .486 r
.58335 .7441 m .5843 .74588 L .58307 .74301 L F
.714 .603 .731 r
.73362 .60744 m .7302 .60481 L .73258 .60404 L F
.663 .594 .767 r
.73599 .60534 m .73362 .60744 L .73258 .60404 L F
0 0 0 r
.76568 .62251 m .76514 .62321 L .76359 .62448 L F
.76781 .62049 m .76514 .62321 L .76568 .62251 L F
.444 .254 .528 r
.35511 .67441 m .35675 .67596 L .35682 .67374 L F
.35511 .67441 m .35489 .67653 L .35675 .67596 L F
.737 .702 .818 r
.62628 .50305 m .62416 .50452 L .6278 .50482 L F
.756 .52 .575 r
.62421 .5068 m .6278 .50482 L .62416 .50452 L F
.62421 .5068 m .62796 .50725 L .6278 .50482 L F
.463 .172 .385 r
.69825 .52404 m .69786 .52641 L .6955 .52694 L F
.406 .076 .289 r
.70066 .52374 m .69786 .52641 L .69825 .52404 L F
.93 .797 .693 r
.65787 .49346 m .65847 .49425 L .65595 .49525 L F
.919 .587 .397 r
.65847 .49425 m .65601 .49505 L .65595 .49525 L F
.93 .797 .693 r
.65787 .49346 m .65733 .49396 L .65652 .49286 L F
.65733 .49396 m .65595 .49525 L .65633 .49366 L F
.65733 .49396 m .65633 .49366 L .65652 .49286 L F
.919 .587 .397 r
.65837 .49428 m .65761 .49774 L .65601 .49505 L F
.65847 .49425 m .65846 .4943 L .65837 .49428 L F
.65846 .4943 m .65761 .49774 L .65837 .49428 L F
.842 .797 .807 r
.61684 .74372 m .61702 .74009 L .61569 .74327 L F
.61684 .74372 m .61843 .74149 L .61702 .74009 L F
.938 .724 .588 r
.61485 .74543 m .61684 .74372 L .61569 .74327 L F
.61485 .74543 m .61662 .74632 L .61684 .74372 L F
.523 .301 .519 r
.69294 .5272 m .69057 .52974 L .6906 .52719 L F
.69294 .5272 m .69302 .52929 L .69057 .52974 L F
.45 .179 .41 r
.6955 .52694 m .69302 .52929 L .69294 .5272 L F
.358 .086 .358 r
.3076 .63011 m .30951 .62942 L .31022 .62738 L F
.022 0 .186 r
.31022 .62738 m .31088 .62826 L .31173 .62659 L F
.31022 .62738 m .30951 .62942 L .31088 .62826 L F
.579 .002 0 r
.54393 .72368 m .54758 .7257 L .54504 .72473 L F
.316 .761 .962 r
.42121 .64964 m .42333 .64948 L .42466 .65 L F
.778 .689 .766 r
.68388 .52676 m .68716 .52688 L .68565 .52593 L F
.68388 .52676 m .68793 .52839 L .68716 .52688 L F
.643 .712 .898 r
.68716 .52688 m .68863 .52365 L .68565 .52593 L F
.285 .096 .438 r
.68793 .52839 m .68903 .5266 L .68716 .52688 L F
.65 .634 .82 r
.71976 .50486 m .71761 .50589 L .71673 .50391 L F
.21 0 0 r
.39504 .64916 m .39713 .64922 L .39856 .6489 L F
.535 .036 .018 r
.39713 .64922 m .40069 .64909 L .39856 .6489 L F
.758 .256 .026 r
.51013 .80653 m .50626 .80371 L .50745 .80492 L F
.693 .528 .659 r
.55591 .69405 m .5562 .69634 L .55389 .69597 L F
.56 .439 .672 r
.55687 .69454 m .5562 .69634 L .55591 .69405 L F
.504 .735 .977 r
.60636 .7517 m .60736 .75001 L .60489 .75041 L F
.60636 .7517 m .60815 .75122 L .60736 .75001 L F
.596 .565 .79 r
.58778 .74884 m .58876 .75239 L .59132 .75189 L F
.619 .383 .537 r
.53564 .73238 m .53578 .73698 L .53254 .73484 L F
0 0 .19 r
.53617 .73371 m .53564 .73238 L .53736 .73199 L F
.53617 .73371 m .53578 .73698 L .53564 .73238 L F
.63 .875 .987 r
.54971 .70104 m .54836 .70137 L .551 .70149 L F
.962 .688 .469 r
.54987 .70407 m .551 .70149 L .54836 .70137 L F
.54987 .70407 m .55148 .70493 L .551 .70149 L F
.369 0 .119 r
.7063 .52149 m .70551 .52323 L .70313 .52368 L F
.413 .007 .157 r
.70864 .5211 m .70551 .52323 L .7063 .52149 L F
.476 0 0 r
.71118 .59461 m .71091 .59439 L .70734 .59341 L F
.252 0 .191 r
.71306 .5932 m .71091 .59439 L .71118 .59461 L F
.526 .624 .891 r
.63972 .48782 m .63883 .49055 L .63742 .48832 L F
.63972 .48782 m .64097 .49035 L .63883 .49055 L F
.518 .874 .635 r
.76359 .62448 m .76514 .62321 L .76504 .62315 L F
.573 .937 .914 r
.76079 .62515 m .76359 .62448 L .76504 .62315 L F
.762 .683 .775 r
.55029 .77715 m .55152 .7795 L .54849 .77912 L F
.54963 .77775 m .54849 .77912 L .54816 .77908 L F
.55029 .77715 m .54849 .77912 L .54963 .77775 L F
.55066 .77716 m .55152 .7795 L .55029 .77715 L F
.704 .281 .24 r
.54816 .77908 m .55152 .7795 L .55041 .78093 L F
.601 .542 .76 r
.55203 .77838 m .55152 .7795 L .55057 .7769 L F
.194 0 .272 r
.55015 .77712 m .55002 .77997 L .55147 .77858 L F
.55013 .77709 m .55013 .77715 L .55015 .77712 L F
.55013 .77715 m .55002 .77997 L .55015 .77712 L F
.694 .159 0 r
.54816 .77908 m .54901 .78072 L .5471 .78205 L F
.54816 .77908 m .55041 .78093 L .54901 .78072 L F
.699 .324 .334 r
.54583 .77883 m .55002 .77997 L .55013 .77715 L F
.54999 .77715 m .55013 .77715 L .55013 .77709 L F
.54583 .77883 m .55013 .77715 L .54999 .77715 L F
.762 .683 .775 r
.55057 .7769 m .55066 .77716 L .55029 .77715 L F
.601 .542 .76 r
.55203 .77838 m .55407 .77966 L .55152 .7795 L F
.516 .074 .138 r
.55152 .7795 m .55272 .78131 L .55041 .78093 L F
.55152 .7795 m .55407 .77966 L .55272 .78131 L F
.26 .372 .788 r
.5827 .71747 m .58148 .71891 L .5804 .71787 L F
.5827 .71747 m .584 .72102 L .58148 .71891 L F
0 .276 .78 r
.58148 .71891 m .584 .72102 L .58401 .7217 L F
.23 0 .033 r
.24549 .59012 m .24853 .588 L .2464 .58853 L F
0 0 .42 r
.54728 .69468 m .54781 .69477 L .54944 .69397 L F
.605 .586 .806 r
.69874 .50076 m .69662 .5021 L .69588 .49995 L F
.69874 .50076 m .69588 .49995 L .6962 .49984 L F
.69874 .50076 m .69579 .49969 L .69806 .49883 L F
.417 .379 .708 r
.69806 .49883 m .70052 .50062 L .69874 .50076 L F
.674 .262 .256 r
.69806 .49883 m .69731 .50056 L .70052 .50062 L F
.261 0 .082 r
.69952 .49989 m .69731 .50056 L .69788 .49923 L F
.69838 .49906 m .69788 .49923 L .69806 .49883 L F
.563 .352 .552 r
.70045 .49817 m .70052 .50062 L .69806 .49883 L F
.261 0 .082 r
.69952 .49989 m .69806 .49883 L .70052 .50062 L F
.69952 .49989 m .69788 .49923 L .69838 .49906 L F
.605 .586 .806 r
.6962 .49984 m .69588 .49995 L .69579 .49969 L F
.654 .604 .786 r
.6994 .50239 m .69662 .5021 L .69874 .50076 L F
.841 .814 .823 r
.7071 .49908 m .70418 .49925 L .70604 .4978 L F
.702 .821 .938 r
.70926 .49794 m .7071 .49908 L .70604 .4978 L F
.697 .812 .936 r
.64778 .54825 m .64988 .54591 L .64735 .54799 L F
.64778 .54825 m .65132 .54729 L .64988 .54591 L F
.803 .539 .539 r
.68395 .53979 m .68084 .53732 L .68374 .53829 L F
.475 .337 .613 r
.55599 .73886 m .55904 .74254 L .55745 .74048 L F
.344 .393 .769 r
.50063 .75726 m .50111 .75396 L .49889 .75435 L F
.50063 .75726 m .50211 .7574 L .50111 .75396 L F
.489 .333 .596 r
.45173 .77422 m .45399 .77373 L .45383 .77127 L F
.447 .379 .687 r
.45173 .77422 m .45419 .77618 L .45399 .77373 L F
.45173 .77422 m .45232 .77688 L .45419 .77618 L F
.515 .24 .435 r
.51578 .7353 m .51594 .73611 L .51319 .73772 L F
.617 .496 .693 r
.51801 .73281 m .51804 .73553 L .51578 .7353 L F
.576 .24 .363 r
.51804 .73553 m .51594 .73611 L .51578 .7353 L F
.92 .95 .798 r
.65793 .48774 m .6592 .48388 L .66017 .48449 L F
.74 .971 .929 r
.66017 .48449 m .661 .48256 L .66258 .48287 L F
.66017 .48449 m .6592 .48388 L .661 .48256 L F
.407 .19 .468 r
.67197 .49646 m .67157 .49852 L .66957 .49923 L F
.434 .221 .489 r
.67157 .49852 m .66947 .50091 L .66957 .49923 L F
.842 .752 .764 r
.34594 .71315 m .34419 .71627 L .34241 .71478 L F
.34594 .71315 m .34241 .71478 L .34446 .71384 L F
0 0 .408 r
.34669 .71417 m .34594 .71315 L .34446 .71384 L F
.702 .514 .631 r
.35449 .69051 m .35698 .68769 L .35528 .6886 L F
.648 .545 .725 r
.46827 .66538 m .46594 .66611 L .46505 .66258 L F
.215 .712 .915 r
.30415 .59152 m .30657 .59143 L .30776 .59189 L F
.221 .705 .93 r
.30845 .59135 m .30776 .59189 L .30657 .59143 L F
.30845 .59135 m .31014 .59187 L .30776 .59189 L F
.41 .069 .273 r
.55635 .68771 m .55848 .68728 L .55913 .68465 L F
.295 .029 .329 r
.55913 .68465 m .56085 .68476 L .56168 .68232 L F
.575 .322 .495 r
.55848 .68728 m .56085 .68476 L .55913 .68465 L F
.587 .603 .835 r
.36407 .71642 m .36482 .71287 L .36272 .71304 L F
.36407 .71642 m .36632 .7161 L .36482 .71287 L F
.836 .718 .735 r
.6048 .53985 m .60597 .54308 L .60283 .54278 L F
.6048 .53985 m .60659 .54103 L .60597 .54308 L F
.802 .665 .712 r
.60283 .54278 m .60597 .54308 L .60406 .54614 L F
.817 .343 .08 r
.65039 .50553 m .6523 .50698 L .65227 .50629 L F
.896 .96 .628 r
.65109 .50955 m .65227 .50629 L .6523 .50698 L F
.476 0 0 r
.71118 .59461 m .70734 .59341 L .70807 .59649 L F
.412 .271 .578 r
.70807 .59649 m .71034 .5979 L .71118 .59461 L F
.70807 .59649 m .7079 .59899 L .71034 .5979 L F
.826 .724 .752 r
.6048 .53985 m .60562 .53783 L .60659 .54103 L F
.493 .294 .539 r
.38195 .67974 m .38176 .68208 L .37971 .68237 L F
.738 .844 .4 r
.58326 .72295 m .58401 .7217 L .584 .72102 L F
.348 .124 .426 r
.50506 .72437 m .50679 .72365 L .50707 .72173 L F
.404 .237 .539 r
.50649 .72614 m .50506 .72437 L .50469 .72651 L F
.50649 .72614 m .50679 .72365 L .50506 .72437 L F
.556 .3 .483 r
.51698 .77134 m .51961 .77109 L .51992 .76904 L F
.635 .378 .511 r
.51961 .77109 m .52302 .76848 L .51992 .76904 L F
.781 .662 .732 r
.48348 .79023 m .48702 .78943 L .48371 .78861 L F
.492 .683 .951 r
.57643 .67552 m .57767 .67736 L .57529 .67727 L F
.535 .142 .244 r
.57767 .67736 m .57419 .67912 L .57529 .67727 L F
0 0 0 r
.57643 .67552 m .57419 .67912 L .57529 .67727 L F
.489 .373 .648 r
.35584 .66565 m .35808 .66772 L .35784 .66525 L F
.35584 .66565 m .35592 .66926 L .35808 .66772 L F
.664 .431 .557 r
.52963 .74559 m .5319 .74369 L .52909 .74305 L F
.283 .097 .443 r
.25952 .62405 m .25931 .62596 L .25793 .62631 L F
.542 .48 .736 r
.25931 .62596 m .25807 .62986 L .25793 .62631 L F
.471 .885 .93 r
.26932 .65465 m .27224 .65409 L .27074 .65377 L F
.437 .844 .971 r
.27224 .65409 m .27284 .65324 L .27074 .65377 L F
.27224 .65409 m .27443 .65359 L .27284 .65324 L F
0 .244 .731 r
.57077 .67847 m .56981 .67828 L .56854 .67887 L F
.578 .291 .444 r
.51267 .75164 m .51598 .74897 L .51285 .74947 L F
0 0 .483 r
.57282 .72559 m .57361 .72645 L .57176 .7242 L F
0 .508 .732 r
.53948 .79923 m .53823 .79909 L .53582 .80034 L F
.315 .559 .923 r
.29381 .58885 m .2932 .59012 L .29144 .58868 L F
.29381 .58885 m .2951 .59058 L .2932 .59012 L F
.615 .674 .883 r
.6842 .50303 m .68543 .50534 L .68753 .50456 L F
.537 .554 .82 r
.68543 .50534 m .68835 .50653 L .68753 .50456 L F
.909 .97 .667 r
.60126 .69975 m .59977 .7011 L .6001 .70181 L F
.978 .918 .646 r
.60087 .69805 m .59977 .7011 L .60126 .69975 L F
.624 .454 .633 r
.71306 .5932 m .71619 .59092 L .71095 .58979 L F
.907 .942 .818 r
.66837 .50801 m .66612 .50924 L .6675 .50665 L F
.478 .102 .247 r
.42841 .68716 m .43186 .68484 L .42951 .68472 L F
.406 .368 .703 r
.45453 .76036 m .45683 .76244 L .45638 .75966 L F
.523 .373 .619 r
.45472 .76282 m .45683 .76244 L .45453 .76036 L F
.653 .766 .932 r
.61843 .74149 m .62057 .7406 L .61702 .74009 L F
.746 .403 .401 r
.48059 .79635 m .479 .79822 L .47911 .79663 L F
.48059 .79635 m .48242 .79855 L .479 .79822 L F
.312 .795 .899 r
.35037 .71019 m .34675 .71043 L .34829 .71069 L F
.542 .417 .66 r
.45285 .76557 m .45503 .76523 L .45472 .76282 L F
.513 .408 .672 r
.45333 .7688 m .45503 .76523 L .45285 .76557 L F
.444 .819 .992 r
.5968 .75154 m .60052 .75177 L .59817 .75151 L F
.777 .638 .707 r
.5968 .75154 m .59906 .75376 L .60052 .75177 L F
.589 .381 .566 r
.60052 .75177 m .6006 .75456 L .59906 .75376 L F
.60052 .75177 m .6006 .75456 L .59906 .75376 L F
.709 .727 .864 r
.60249 .75115 m .59817 .75151 L .60052 .75177 L F
.784 .991 .76 r
.67423 .50608 m .6732 .50656 L .67302 .50411 L F
.596 .607 .834 r
.6761 .5041 m .67423 .50608 L .67302 .50411 L F
.6761 .5041 m .67637 .50598 L .67423 .50608 L F
.65 .344 .439 r
.458 .6824 m .45686 .68482 L .45476 .6846 L F
.622 .312 .425 r
.4601 .68435 m .458 .6824 L .4603 .68215 L F
.4601 .68435 m .45686 .68482 L .458 .6824 L F
.219 0 .089 r
.3066 .63153 m .30951 .62942 L .3076 .63011 L F
.776 .556 .602 r
.57361 .72645 m .57031 .72364 L .57176 .7242 L F
.241 .596 .95 r
.75739 .62482 m .75849 .62414 L .75688 .62346 L F
.75739 .62482 m .7597 .62537 L .75849 .62414 L F
.672 .897 .977 r
.31432 .60383 m .31395 .6053 L .31613 .60435 L F
.652 .879 .982 r
.31242 .60466 m .31395 .6053 L .31432 .60383 L F
.702 .667 .813 r
.44175 .66592 m .44317 .66858 L .4447 .66667 L F
.647 .584 .77 r
.44317 .66858 m .44584 .66825 L .4447 .66667 L F
.562 .423 .649 r
.44377 .67086 m .44584 .66825 L .44317 .66858 L F
.782 .365 .258 r
.51678 .7151 m .51881 .71751 L .52002 .71607 L F
.729 .294 .218 r
.51881 .71751 m .52193 .718 L .52002 .71607 L F
.744 .246 .045 r
.52002 .71607 m .52193 .718 L .52359 .71831 L F
.059 0 0 r
.41399 .69384 m .41457 .69473 L .4163 .6936 L F
.41399 .69384 m .41271 .69558 L .41457 .69473 L F
.215 .138 .549 r
.49201 .76271 m .4921 .76525 L .4911 .7629 L F
.462 .142 .336 r
.54308 .70011 m .54464 .70102 L .54484 .69887 L F
.54308 .70011 m .54263 .70199 L .54464 .70102 L F
.88 .784 .751 r
.6781 .51296 m .68019 .5127 L .67937 .51141 L F
.6781 .51296 m .67869 .51609 L .68019 .5127 L F
.897 .886 .813 r
.62507 .49469 m .62374 .49696 L .62264 .4959 L F
.95 .858 .715 r
.62374 .49696 m .62174 .49783 L .62264 .4959 L F
.62374 .49696 m .62278 .49886 L .62174 .49783 L F
.588 .52 .746 r
.46731 .66191 m .46505 .66258 L .46455 .66063 L F
.648 .545 .725 r
.46827 .66538 m .46505 .66258 L .46731 .66191 L F
.605 .607 .827 r
.6353 .492 m .63661 .49405 L .63869 .49314 L F
.616 .883 .99 r
.72786 .5958 m .7256 .5967 L .72454 .59599 L F
.794 .506 .5 r
.55133 .71242 m .54776 .70986 L .55051 .7111 L F
.724 .325 .292 r
.55456 .7127 m .55133 .71242 L .55051 .7111 L F
.519 .61 .883 r
.77479 .60099 m .77308 .60273 L .77273 .60099 L F
.77479 .60099 m .77618 .60388 L .77308 .60273 L F
.447 .251 .519 r
.69302 .52929 m .6909 .53206 L .69057 .52974 L F
.872 .66 .613 r
.59677 .68562 m .59417 .68214 L .59437 .6846 L F
.867 .515 .381 r
.59457 .68689 m .59677 .68562 L .59437 .6846 L F
.59457 .68689 m .59705 .6875 L .59677 .68562 L F
.664 .431 .557 r
.52963 .74559 m .53183 .74607 L .5319 .74369 L F
.533 .282 .48 r
.53183 .74607 m .53453 .74358 L .5319 .74369 L F
.505 .291 .522 r
.52664 .76257 m .5241 .75937 L .52634 .75957 L F
.452 .251 .516 r
.52664 .76257 m .5256 .76385 L .524 .76297 L F
.652 .456 .606 r
.5256 .76385 m .52313 .76734 L .524 .76297 L F
.452 .251 .516 r
.52664 .76257 m .524 .76297 L .52394 .76384 L F
.505 .291 .522 r
.52664 .76257 m .52394 .76384 L .5241 .75937 L F
.562 .423 .649 r
.44377 .67086 m .44632 .67117 L .44584 .66825 L F
.692 .568 .711 r
.44382 .67347 m .44632 .67117 L .44377 .67086 L F
.43 .615 .928 r
.34137 .59598 m .34134 .59821 L .33938 .59629 L F
.34137 .59598 m .34321 .59825 L .34134 .59821 L F
.64 .679 .871 r
.31859 .60548 m .32279 .60759 L .32101 .60518 L F
.458 .572 .881 r
.32279 .60759 m .32394 .60593 L .32101 .60518 L F
.32279 .60759 m .32449 .60736 L .32394 .60593 L F
.587 .493 .715 r
.3229 .61007 m .32449 .60736 L .32279 .60759 L F
.863 .806 .793 r
.34164 .7185 m .34241 .71478 L .34419 .71627 L F
.538 .096 .148 r
.71356 .50261 m .71316 .50369 L .71039 .50274 L F
.277 .577 .941 r
.71316 .50369 m .70948 .50161 L .71039 .50274 L F
.395 0 .14 r
.40198 .66565 m .40074 .6676 L .39856 .66788 L F
.562 .234 .369 r
.40388 .66537 m .40074 .6676 L .40198 .66565 L F
.419 .746 .994 r
.63988 .49557 m .6412 .49458 L .63869 .49314 L F
.63988 .49557 m .64228 .49554 L .6412 .49458 L F
.515 .307 .536 r
.64823 .524 m .65062 .52379 L .64828 .52136 L F
.724 .262 .152 r
.64779 .52301 m .65062 .52379 L .64828 .52136 L F
.585 .104 .079 r
.55314 .75017 m .55577 .75131 L .55207 .75091 L F
.775 .303 0 r
.57004 .74546 m .57248 .74856 L .57214 .74738 L F
.783 .75 .822 r
.64181 .52764 m .64273 .52406 L .64078 .52674 L F
.707 .478 .576 r
.49881 .76199 m .49443 .75997 L .49773 .76035 L F
.648 .311 .388 r
.49773 .76035 m .5001 .76231 L .49881 .76199 L F
0 .253 .765 r
.49937 .76087 m .49773 .76035 L .49622 .75846 L F
.49937 .76087 m .5001 .76231 L .49773 .76035 L F
.666 .46 .597 r
.47103 .67674 m .47101 .67989 L .4683 .67951 L F
.641 .573 .762 r
.4727 .67394 m .4741 .67649 L .47103 .67674 L F
.596 .403 .591 r
.47363 .67874 m .47103 .67674 L .4741 .67649 L F
.47363 .67874 m .47101 .67989 L .47103 .67674 L F
.606 .404 .581 r
.49445 .75754 m .49443 .75997 L .49665 .75816 L F
.274 .209 .599 r
.47696 .7846 m .47714 .78775 L .47601 .78765 L F
.257 .304 .72 r
.47714 .78775 m .47778 .79023 L .47601 .78765 L F
.461 .614 .915 r
.68419 .49043 m .68225 .49063 L .68081 .48859 L F
.61 .412 .59 r
.52026 .72977 m .52024 .7322 L .51801 .73281 L F
.709 .493 .595 r
.52559 .73089 m .52024 .7322 L .52026 .72977 L F
.183 0 0 r
.46125 .75468 m .46302 .75492 L .46491 .75491 L F
.603 .15 .149 r
.46302 .75492 m .46722 .75462 L .46491 .75491 L F
.96 .633 .349 r
.50547 .77148 m .50468 .77343 L .50257 .7709 L F
.50547 .77148 m .50601 .7741 L .50468 .77343 L F
.509 .385 .646 r
.51008 .72422 m .51076 .71875 L .50872 .72117 L F
.51008 .72422 m .51221 .72411 L .51076 .71875 L F
.674 .965 .932 r
.51316 .71655 m .51216 .71642 L .51181 .7179 L F
.51316 .71655 m .51216 .71642 L .51181 .7179 L F
.381 .351 .7 r
.51076 .71875 m .51316 .71655 L .51181 .7179 L F
.51076 .71875 m .51319 .72024 L .51316 .71655 L F
0 0 .512 r
.51076 .71875 m .51271 .72184 L .51319 .72024 L F
.51076 .71875 m .51207 .7236 L .51271 .72184 L F
.789 .955 .627 r
.51271 .72184 m .51214 .72247 L .51283 .72151 L F
.253 0 .105 r
.51319 .72024 m .51271 .72184 L .51537 .71996 L F
.789 .955 .627 r
.51271 .72184 m .51283 .72151 L .51284 .72149 L F
0 0 .512 r
.51207 .7236 m .51221 .72411 L .51271 .72184 L F
.754 .48 .518 r
.51115 .76309 m .50921 .76513 L .50919 .76293 L F
.51115 .76309 m .51253 .7655 L .50921 .76513 L F
.386 0 .088 r
.37671 .65365 m .37591 .65219 L .37442 .65385 L F
.37671 .65365 m .37811 .65194 L .37591 .65219 L F
0 0 .392 r
.64118 .50199 m .64124 .50426 L .64245 .50262 L F
.527 .345 .577 r
.65084 .53709 m .64868 .53806 L .64846 .53532 L F
.41 .053 .245 r
.42928 .69707 m .42847 .6985 L .42638 .6989 L F
.274 0 .167 r
.43109 .69644 m .42847 .6985 L .42928 .69707 L F
.316 .766 .957 r
.40069 .64909 m .40286 .64894 L .40422 .64939 L F
.288 0 0 r
.40286 .64894 m .40634 .64913 L .40422 .64939 L F
.775 .648 .721 r
.7061 .58793 m .7073 .58586 L .70675 .58576 L F
.461 .783 .998 r
.32117 .593 m .32266 .5939 L .31911 .59328 L F
.429 .793 .996 r
.32315 .5929 m .32266 .5939 L .32117 .593 L F
.32315 .5929 m .32468 .59361 L .32266 .5939 L F
.686 .564 .711 r
.5562 .69634 m .55403 .6993 L .55389 .69597 L F
0 0 0 r
.55527 .69804 m .55403 .6993 L .5562 .69634 L F
.56 .91 .701 r
.55527 .69804 m .55257 .70009 L .55403 .6993 L F
.44 .825 .988 r
.66408 .50662 m .66627 .5072 L .6675 .50665 L F
.868 .903 .854 r
.34792 .7175 m .34941 .71891 L .34926 .7183 L F
.865 .703 .679 r
.34558 .72029 m .34712 .72168 L .34941 .71891 L F
.778 .689 .766 r
.68388 .52676 m .68506 .53013 L .68793 .52839 L F
.647 .729 .909 r
.68144 .52926 m .68506 .53013 L .68461 .52885 L F
.68174 .52895 m .68461 .52885 L .68388 .52676 L F
.68144 .52926 m .68461 .52885 L .68174 .52895 L F
.6 .177 .212 r
.68405 .5298 m .68793 .52839 L .68506 .53013 L F
.68405 .5298 m .68639 .53075 L .6877 .52874 L F
.68688 .52877 m .6877 .52874 L .68793 .52839 L F
.68405 .5298 m .6877 .52874 L .68688 .52877 L F
.285 .096 .438 r
.68793 .52839 m .68947 .52864 L .68903 .5266 L F
.199 0 0 r
.68793 .52839 m .68866 .53 L .68947 .52864 L F
.332 .124 .44 r
.56296 .77326 m .56161 .77119 L .56287 .77075 L F
.56296 .77326 m .56121 .77423 L .56161 .77119 L F
.807 .501 .472 r
.60554 .72892 m .60701 .72679 L .6054 .72648 L F
.60554 .72892 m .60871 .72943 L .60701 .72679 L F
.772 .668 .748 r
.50679 .72365 m .50872 .72117 L .50707 .72173 L F
.492 .681 .95 r
.26355 .63663 m .26291 .63834 L .26147 .63711 L F
.26355 .63663 m .26485 .63812 L .26291 .63834 L F
.342 .46 .835 r
.64823 .524 m .64942 .52687 L .65117 .52589 L F
0 0 .052 r
.65117 .52589 m .64942 .52687 L .64898 .52874 L F
.54 .294 .49 r
.35522 .71817 m .35475 .7207 L .35282 .71864 L F
.35522 .71817 m .35475 .7207 L .35282 .71864 L F
.714 .299 .258 r
.49007 .80125 m .493 .80141 L .49199 .80287 L F
.757 .349 .279 r
.493 .80141 m .49332 .80394 L .49199 .80287 L F
.493 .80141 m .49511 .80373 L .49332 .80394 L F
.726 .365 .365 r
.493 .80141 m .4955 .80237 L .49511 .80373 L F
.383 .672 .973 r
.39251 .84042 m .39259 .84205 L .38993 .83986 L F
.469 0 0 r
.38993 .83986 m .39259 .84205 L .39174 .84139 L F
.907 .931 .556 r
.39238 .84014 m .39259 .84205 L .39251 .84042 L F
.895 .98 .698 r
.39174 .84139 m .39259 .84205 L .39238 .84014 L F
.577 .729 .946 r
.3499 .70525 m .35053 .70756 L .3487 .7067 L F
.63 .434 .599 r
.35263 .70967 m .35053 .70756 L .35316 .70758 L F
.35263 .70967 m .35037 .71019 L .35053 .70756 L F
.715 .792 .912 r
.3523 .69318 m .35609 .69348 L .35449 .69051 L F
.3523 .69318 m .35355 .69401 L .35609 .69348 L F
.391 .368 .714 r
.35609 .69348 m .35691 .69006 L .35449 .69051 L F
.35609 .69348 m .35783 .69326 L .35691 .69006 L F
.612 .543 .752 r
.35609 .69348 m .35922 .69631 L .35783 .69326 L F
.612 .633 .847 r
.68793 .4929 m .68559 .4935 L .68419 .49043 L F
.098 0 0 r
.73118 .5956 m .72786 .5958 L .73025 .5955 L F
.089 .646 .791 r
.73025 .5955 m .73373 .59553 L .73118 .5956 L F
.701 .817 .937 r
.71282 .49769 m .70926 .49794 L .71183 .49635 L F
.639 .725 .911 r
.71408 .49542 m .71282 .49769 L .71183 .49635 L F
.71408 .49542 m .71475 .49696 L .71282 .49769 L F
.608 .573 .789 r
.71554 .49877 m .71282 .49769 L .71475 .49696 L F
.661 .253 .26 r
.58197 .67615 m .58542 .67627 L .58289 .67457 L F
.987 .723 .424 r
.60244 .72012 m .6035 .71851 L .60229 .71795 L F
.60244 .72012 m .60353 .72103 L .6035 .71851 L F
.852 .67 .655 r
.6405 .53444 m .64261 .5351 L .64086 .53049 L F
.834 .45 .324 r
.6405 .53444 m .64174 .53672 L .64261 .5351 L F
.608 .588 .805 r
.64261 .5351 m .64507 .53488 L .64358 .53055 L F
.64261 .5351 m .64358 .53055 L .64341 .53059 L F
.452 .492 .81 r
.64385 .53052 m .64507 .53488 L .64678 .5326 L F
.64347 .53025 m .64358 .53055 L .64385 .53052 L F
.64358 .53055 m .64507 .53488 L .64385 .53052 L F
.608 .588 .805 r
.64341 .53059 m .64358 .53055 L .64347 .53025 L F
.989 .731 .432 r
.64385 .53052 m .64291 .53098 L .64347 .53025 L F
.64678 .5326 m .64291 .53098 L .64385 .53052 L F
.112 0 0 r
.64394 .53047 m .64413 .53011 L .64347 .53057 L F
.64516 .5302 m .6446 .53015 L .64394 .53047 L F
.6446 .53015 m .64413 .53011 L .64394 .53047 L F
.64593 .53027 m .64578 .53026 L .64291 .53098 L F
.64578 .53026 m .64516 .5302 L .6445 .53043 L F
.64578 .53026 m .6445 .53043 L .64291 .53098 L F
.64516 .5302 m .64347 .53057 L .64291 .53098 L F
0 0 0 r
.64261 .5351 m .64455 .53447 L .64442 .53493 L F
.64261 .5351 m .64174 .53672 L .64455 .53447 L F
.832 .651 .658 r
.63847 .53374 m .639 .53302 L .6392 .53242 L F
.639 .53302 m .64086 .53049 L .6392 .53242 L F
.63847 .53374 m .6405 .53444 L .64086 .53049 L F
.701 .285 0 r
.6392 .53242 m .6405 .53444 L .63847 .53374 L F
.63945 .5328 m .64174 .53672 L .6405 .53444 L F
.6392 .53242 m .63944 .53283 L .63945 .5328 L F
.63944 .53283 m .64174 .53672 L .63945 .5328 L F
0 0 0 r
.63847 .53374 m .63717 .53523 L .63939 .53306 L F
.6394 .53301 m .63939 .53306 L .63958 .53287 L F
.63847 .53374 m .63939 .53306 L .6394 .53301 L F
.705 .607 .745 r
.64455 .53447 m .64174 .53672 L .6392 .53242 L F
.64455 .53447 m .64095 .53309 L .64311 .53525 L F
.64095 .53309 m .6392 .53242 L .64311 .53525 L F
.67 .129 0 r
.64642 .53797 m .64311 .53525 L .6441 .53846 L F
.64642 .53797 m .6441 .53846 L .64411 .53849 L F
.64642 .53797 m .64515 .53733 L .64311 .53525 L F
.879 .903 .843 r
.64767 .53423 m .64642 .53797 L .64877 .53747 L F
.64767 .53423 m .64515 .53733 L .64642 .53797 L F
.452 0 0 r
.64515 .53733 m .64874 .53747 L .64642 .53797 L F
.64874 .53747 m .64877 .53747 L .64642 .53797 L F
.169 .262 .717 r
.64311 .53525 m .64515 .53733 L .64514 .53728 L F
0 0 0 r
.64311 .53525 m .64463 .53415 L .64455 .53447 L F
.64463 .53415 m .64678 .5326 L .64455 .53447 L F
.64442 .53493 m .64455 .53447 L .64507 .53488 L F
.764 .994 .871 r
.64678 .5326 m .64507 .53488 L .64455 .53447 L F
0 0 0 r
.64311 .53525 m .64592 .53305 L .64678 .5326 L F
.64311 .53525 m .6449 .53457 L .64592 .53305 L F
.36 .657 .969 r
.6446 .53426 m .6449 .53457 L .64311 .53525 L F
.6446 .53426 m .6446 .53426 L .6446 .53426 L F
.6446 .53426 m .6449 .53457 L .6446 .53426 L F
.169 .262 .717 r
.64311 .53525 m .64514 .53728 L .6446 .53426 L F
.055 .367 .836 r
.64219 .53352 m .64311 .53525 L .64013 .5331 L F
.64015 .53277 m .64013 .5331 L .6392 .53242 L F
.64219 .53352 m .64013 .5331 L .64015 .53277 L F
.073 0 0 r
.6392 .53242 m .64046 .53224 L .63958 .53287 L F
.055 .367 .836 r
.64219 .53352 m .64015 .53277 L .63958 .53287 L F
.64015 .53277 m .6392 .53242 L .63958 .53287 L F
0 0 0 r
.63847 .53374 m .63958 .53287 L .6392 .53242 L F
.855 .986 .711 r
.63958 .53287 m .63838 .53366 L .63887 .53299 L F
.073 0 0 r
.6392 .53242 m .63958 .53287 L .63956 .53256 L F
.34 0 .068 r
.64086 .53049 m .64291 .53098 L .6392 .53242 L F
.073 0 0 r
.6392 .53242 m .64291 .53098 L .64192 .53203 L F
.208 0 0 r
.64066 .53052 m .6394 .53012 L .63958 .53287 L F
.855 .986 .711 r
.63958 .53287 m .63887 .53299 L .64022 .53113 L F
.073 0 0 r
.64046 .53224 m .64192 .53203 L .63958 .53287 L F
.855 .986 .711 r
.6402 .53152 m .64022 .53113 L .64066 .53052 L F
.63958 .53287 m .64022 .53113 L .6402 .53152 L F
.788 .679 .743 r
.64311 .53525 m .64077 .53823 L .64411 .53849 L F
.65 .594 .778 r
.64219 .53352 m .64077 .53823 L .64311 .53525 L F
.467 .488 .796 r
.64515 .53733 m .644 .53832 L .64245 .53421 L F
.64273 .53422 m .64245 .53421 L .64219 .53352 L F
.64515 .53733 m .64245 .53421 L .64273 .53422 L F
.073 0 0 r
.6392 .53242 m .63956 .53256 L .63949 .53155 L F
.6392 .53242 m .63949 .53155 L .6394 .53012 L F
.519 .243 .436 r
.61395 .56201 m .61048 .56507 L .61065 .56208 L F
.632 .377 .514 r
.61065 .56208 m .60792 .56519 L .60793 .56323 L F
.61065 .56208 m .61048 .56507 L .60792 .56519 L F
.513 .055 .102 r
.5851 .72462 m .58699 .72569 L .58818 .72388 L F
0 0 0 r
.58956 .72305 m .58856 .7245 L .58944 .72395 L F
.795 .337 .154 r
.58956 .72305 m .58944 .72395 L .5892 .7237 L F
0 0 0 r
.58818 .72388 m .58956 .72305 L .59022 .72186 L F
.58818 .72388 m .58699 .72569 L .58956 .72305 L F
.58956 .72305 m .58699 .72569 L .58856 .7245 L F
.795 .337 .154 r
.58956 .72305 m .5892 .7237 L .5861 .72054 L F
0 0 0 r
.59022 .72186 m .58956 .72305 L .59069 .7214 L F
.583 .661 .891 r
.77218 .58511 m .76853 .58302 L .77109 .58273 L F
.607 .699 .909 r
.77351 .58237 m .77218 .58511 L .77109 .58273 L F
.77351 .58237 m .77469 .58455 L .77218 .58511 L F
.562 .497 .739 r
.77469 .58455 m .77352 .58634 L .77218 .58511 L F
.355 0 .101 r
.38691 .71583 m .38569 .71767 L .38343 .71809 L F
.106 0 0 r
.38748 .71692 m .38691 .71583 L .38894 .71509 L F
.38748 .71692 m .38569 .71767 L .38691 .71583 L F
.745 .385 .371 r
.6809 .50139 m .68481 .50194 L .6842 .50303 L F
.6809 .50139 m .68375 .5028 L .68102 .50389 L F
.68375 .5028 m .6842 .50303 L .68303 .50335 L F
.68375 .5028 m .68303 .50335 L .68102 .50389 L F
0 .352 .73 r
.68481 .50194 m .68352 .50324 L .6842 .50303 L F
.68454 .50221 m .68547 .50203 L .68352 .50324 L F
.68481 .50194 m .68489 .50195 L .68454 .50221 L F
.68489 .50195 m .68547 .50203 L .68454 .50221 L F
.506 .274 .496 r
.43437 .68241 m .43656 .68199 L .43659 .6798 L F
.472 .162 .358 r
.43656 .68199 m .43952 .67923 L .43659 .6798 L F
.788 .547 .572 r
.59208 .68218 m .59403 .67979 L .59219 .67942 L F
.59208 .68218 m .59417 .68214 L .59403 .67979 L F
.435 .229 .499 r
.31209 .62421 m .31364 .62595 L .31358 .62351 L F
.31209 .62421 m .31173 .62659 L .31364 .62595 L F
.575 .499 .732 r
.35226 .60111 m .35094 .6051 L .35058 .60146 L F
.121 0 0 r
.50257 .7709 m .49908 .77319 L .49811 .77158 L F
.5 .762 .989 r
.45178 .64986 m .45101 .65128 L .44969 .65032 L F
.45178 .64986 m .45309 .65096 L .45101 .65128 L F
.369 .055 .297 r
.50343 .74227 m .50188 .74336 L .50235 .74151 L F
.819 .761 .797 r
.54336 .75096 m .54196 .75388 L .54302 .75367 L F
.849 .423 0 r
.54257 .79742 m .5415 .79593 L .54273 .79603 L F
.894 .961 .63 r
.54211 .79756 m .54257 .79742 L .54273 .79603 L F
.382 .797 .977 r
.66258 .48287 m .66514 .48256 L .66588 .48307 L F
.465 .745 .99 r
.66696 .48182 m .66588 .48307 L .66514 .48256 L F
.66696 .48182 m .66809 .48291 L .66588 .48307 L F
.578 .291 .444 r
.51267 .75164 m .51533 .75159 L .51598 .74897 L F
.664 .373 .47 r
.51533 .75159 m .51823 .75129 L .51598 .74897 L F
.674 .371 .453 r
.51598 .74897 m .51823 .75129 L .51822 .74927 L F
.538 .531 .796 r
.36073 .70162 m .36163 .69832 L .35978 .69981 L F
.36073 .70162 m .36273 .70131 L .36163 .69832 L F
.567 .484 .72 r
.36125 .70496 m .36273 .70131 L .36073 .70162 L F
.658 .45 .592 r
.50909 .76155 m .50919 .76293 L .50703 .76298 L F
.59 .077 0 r
.53189 .76013 m .53548 .76044 L .53424 .76144 L F
.216 0 0 r
.53823 .76172 m .53424 .76144 L .53548 .76044 L F
.598 .274 .392 r
.53548 .76044 m .53766 .76058 L .53823 .76172 L F
.667 .532 .691 r
.64064 .52452 m .64158 .52061 L .63987 .52133 L F
.633 .372 .504 r
.64402 .51791 m .6482 .51832 L .64746 .5162 L F
.367 .186 .499 r
.64746 .5162 m .64891 .51581 L .64921 .51297 L F
.387 .239 .556 r
.64746 .5162 m .6482 .51832 L .64891 .51581 L F
.427 .254 .542 r
.38367 .67911 m .38176 .68208 L .38195 .67974 L F
.404 0 0 r
.75719 .5829 m .75382 .5842 L .75622 .58268 L F
.11 .662 .716 r
.75839 .5827 m .75719 .5829 L .75622 .58268 L F
.75839 .5827 m .7596 .58256 L .75719 .5829 L F
.77 .719 .804 r
.67702 .51381 m .67869 .51609 L .6781 .51296 L F
.81 .374 0 r
.67702 .51381 m .67949 .51845 L .67869 .51609 L F
0 .315 .804 r
.68108 .51676 m .68103 .51761 L .67869 .51609 L F
.68108 .51676 m .67869 .51609 L .67949 .51845 L F
0 0 0 r
.29165 .6035 m .29546 .60191 L .29376 .60328 L F
.31 0 0 r
.29767 .60206 m .29376 .60328 L .29546 .60191 L F
.578 .551 .788 r
.46675 .66015 m .46455 .66063 L .46338 .65732 L F
.588 .52 .746 r
.46731 .66191 m .46455 .66063 L .46675 .66015 L F
.793 .65 .704 r
.35952 .71033 m .35648 .71066 L .35632 .7099 L F
.811 .326 .03 r
.35632 .7099 m .35946 .71278 L .35952 .71033 L F
.632 .554 .748 r
.35952 .71033 m .36182 .71025 L .36154 .70763 L F
.941 .796 .672 r
.61444 .52233 m .61293 .52295 L .6133 .52114 L F
.61444 .52233 m .6142 .52426 L .61293 .52295 L F
.131 0 0 r
.42779 .65026 m .42902 .65029 L .43039 .64978 L F
.089 .619 .87 r
.42766 .64982 m .4302 .65032 L .42902 .65029 L F
.371 0 0 r
.42902 .65029 m .43118 .65051 L .43054 .65021 L F
.089 .619 .87 r
.4302 .65032 m .43118 .65051 L .42902 .65029 L F
.131 0 0 r
.42683 .65044 m .42902 .65029 L .42779 .65026 L F
.371 0 0 r
.42902 .65029 m .43054 .65021 L .43039 .64978 L F
0 0 .226 r
.54213 .77514 m .54188 .7742 L .54201 .77621 L F
.971 .658 .343 r
.54201 .77621 m .54326 .77935 L .54405 .77847 L F
0 0 .226 r
.54238 .773 m .54201 .77621 L .5426 .77585 L F
.722 .219 .035 r
.53903 .77502 m .54231 .77579 L .54256 .77734 L F
.049 .21 .71 r
.54201 .77621 m .54405 .77847 L .5426 .77585 L F
.722 .219 .035 r
.54231 .77579 m .5426 .77585 L .54258 .77679 L F
.54231 .77579 m .54258 .77679 L .54256 .77734 L F
0 0 .226 r
.54238 .773 m .54188 .77413 L .54188 .7742 L F
.54238 .773 m .54188 .7742 L .54213 .77514 L F
.301 0 .001 r
.41832 .70392 m .41478 .70592 L .41618 .70437 L F
.934 .891 .485 r
.6001 .70181 m .59905 .70326 L .59938 .70481 L F
.6001 .70181 m .59977 .7011 L .59905 .70326 L F
.688 .386 .459 r
.6192 .56006 m .61591 .56213 L .61577 .56081 L F
.6192 .56006 m .61813 .56236 L .61591 .56213 L F
.559 .267 .428 r
.6215 .5598 m .61813 .56236 L .6192 .56006 L F
.996 .784 .5 r
.63318 .49723 m .6344 .49858 L .63402 .49778 L F
.301 .789 .893 r
.63318 .49723 m .63699 .49693 L .6344 .49858 L F
.49 .357 .626 r
.63699 .49693 m .63683 .49867 L .6344 .49858 L F
.885 .596 .082 r
.52499 .77117 m .52527 .77323 L .5257 .77341 L F
.8 .744 .801 r
.52499 .77117 m .5257 .77341 L .52714 .77182 L F
.885 .596 .082 r
.52499 .77117 m .52527 .77323 L .5257 .77341 L F
.352 0 .042 r
.25603 .58684 m .25812 .58656 L .26009 .58459 L F
.017 0 0 r
.26009 .58459 m .25812 .58656 L .26019 .58558 L F
.36 0 .204 r
.4235 .68948 m .42632 .68766 L .42437 .68834 L F
.714 .475 .561 r
.52302 .76848 m .52499 .77117 L .52553 .76878 L F
.279 .781 .787 r
.77372 .61824 m .77296 .61829 L .7707 .61894 L F
.026 .018 .509 r
.77482 .61477 m .77372 .61824 L .77612 .61614 L F
.77482 .61477 m .77503 .61712 L .77372 .61824 L F
.523 .918 .828 r
.77503 .61712 m .77296 .61829 L .77372 .61824 L F
.618 .579 .789 r
.45985 .65483 m .45773 .6554 L .45642 .65221 L F
.326 0 0 r
.46399 .79139 m .46636 .79132 L .46631 .79226 L F
.46399 .79139 m .46631 .79226 L .46289 .79025 L F
.672 .556 .715 r
.73258 .60404 m .7302 .60481 L .73231 .60199 L F
.597 .091 .019 r
.76899 .58942 m .76984 .58842 L .77258 .59002 L F
.534 .263 .451 r
.77258 .59002 m .76984 .58842 L .77352 .58634 L F
.875 .808 .781 r
.6142 .52426 m .61086 .52605 L .61293 .52295 L F
.6142 .52426 m .6123 .52725 L .61086 .52605 L F
.597 .25 .352 r
.4101 .66299 m .40899 .66536 L .40649 .66512 L F
.32 0 .026 r
.41233 .66347 m .40899 .66536 L .4101 .66299 L F
.587 .433 .64 r
.55317 .74013 m .55085 .74331 L .55171 .74048 L F
.644 .434 .584 r
.46568 .68172 m .46267 .67971 L .46598 .67949 L F
.46568 .68172 m .46266 .68221 L .46267 .67971 L F
.412 .196 .473 r
.33047 .62987 m .33029 .63233 L .32835 .63283 L F
.328 .128 .45 r
.33192 .63139 m .33047 .62987 L .3326 .62956 L F
.33192 .63139 m .33029 .63233 L .33047 .62987 L F
.763 .409 .383 r
.6021 .56321 m .59914 .56452 L .59904 .56226 L F
.6021 .56321 m .60236 .56485 L .59914 .56452 L F
.679 .356 .42 r
.6021 .56321 m .60409 .56488 L .60236 .56485 L F
.441 .18 .422 r
.54099 .73275 m .5383 .73517 L .53736 .73199 L F
.54099 .73275 m .54094 .7347 L .5383 .73517 L F
.496 .343 .603 r
.54076 .73719 m .53864 .73797 L .5383 .73517 L F
.233 0 .089 r
.5383 .73517 m .53953 .73643 L .54076 .73719 L F
.5383 .73517 m .53738 .73733 L .53953 .73643 L F
.441 .18 .422 r
.54099 .73275 m .54094 .7347 L .5383 .73517 L F
.495 .344 .605 r
.54094 .7347 m .54076 .73719 L .5383 .73517 L F
.127 .557 .922 r
.65791 .50427 m .65649 .50404 L .65509 .50288 L F
.422 .638 .946 r
.54495 .76245 m .54388 .76184 L .54319 .76215 L F
.008 .576 .785 r
.54712 .76261 m .54495 .76245 L .54319 .76215 L F
.704 .52 .637 r
.54378 .76478 m .54712 .76261 L .54319 .76215 L F
.809 .72 .767 r
.53981 .76231 m .5413 .76519 L .54319 .76215 L F
.66 .516 .678 r
.54319 .76215 m .5413 .76519 L .54378 .76478 L F
.396 0 0 r
.54611 .76158 m .5423 .76255 L .54319 .76215 L F
.5423 .76255 m .54214 .76259 L .54319 .76215 L F
.422 .638 .946 r
.54388 .76184 m .54104 .76025 L .54319 .76215 L F
.731 .692 .813 r
.4797 .78587 m .48315 .7857 L .4821 .78734 L F
.452 0 .086 r
.48315 .7857 m .48442 .78702 L .4821 .78734 L F
.508 .141 .279 r
.36306 .85923 m .36277 .86033 L .36039 .86021 L F
.36306 .85923 m .36277 .86033 L .36039 .86021 L F
.91 .703 .609 r
.59864 .70699 m .60017 .70977 L .60013 .70762 L F
.635 .378 .511 r
.51961 .77109 m .52276 .77105 L .52302 .76848 L F
.747 .478 .523 r
.52276 .77105 m .52499 .77117 L .52302 .76848 L F
.696 .812 .937 r
.64988 .54591 m .65132 .54729 L .65333 .54613 L F
.605 .476 .679 r
.71554 .49877 m .71631 .50222 L .71356 .50261 L F
.625 .583 .786 r
.71673 .50391 m .71356 .50261 L .71631 .50222 L F
0 0 0 r
.73417 .59865 m .73708 .59685 L .7361 .59778 L F
.521 .828 1 r
.73708 .59685 m .7388 .59572 L .73615 .5958 L F
.73708 .59685 m .7394 .59636 L .7388 .59572 L F
.986 .708 .384 r
.7361 .59778 m .73708 .59685 L .73615 .5958 L F
.774 .692 .773 r
.53736 .73199 m .54099 .73275 L .53953 .72919 L F
.779 .435 0 r
.53953 .72919 m .54099 .73275 L .54044 .73181 L F
.985 .796 .57 r
.54094 .7347 m .54044 .73181 L .54099 .73275 L F
0 .434 .801 r
.65034 .51227 m .65149 .51243 L .6511 .51205 L F
0 0 .222 r
.64938 .51255 m .65034 .51227 L .65068 .50939 L F
.992 .753 .467 r
.65068 .50939 m .65034 .51227 L .64948 .51043 L F
0 .434 .801 r
.65034 .51227 m .6511 .51205 L .64948 .51043 L F
0 0 .222 r
.64921 .51297 m .65034 .51227 L .64938 .51255 L F
.328 .154 .486 r
.64921 .51297 m .65143 .51446 L .65034 .51227 L F
.64921 .51297 m .64891 .51581 L .65143 .51446 L F
.191 .291 .737 r
.57373 .75255 m .5749 .75432 L .57458 .75503 L F
0 .012 .531 r
.5749 .75432 m .57489 .7573 L .57458 .75503 L F
.784 .347 .212 r
.49521 .74931 m .49689 .75156 L .49835 .75177 L F
.49802 .75113 m .49835 .75177 L .49917 .75188 L F
.49521 .74931 m .49835 .75177 L .49802 .75113 L F
.871 .603 .531 r
.49689 .75156 m .49909 .75417 L .49917 .75188 L F
.609 .377 .539 r
.49917 .75188 m .49909 .75417 L .50111 .75396 L F
.681 .373 .447 r
.49917 .75188 m .50111 .75396 L .50163 .75217 L F
0 0 .521 r
.49882 .74972 m .49962 .75319 L .49936 .75368 L F
.49902 .75304 m .49936 .75368 L .49909 .75417 L F
.49882 .74972 m .49936 .75368 L .49902 .75304 L F
0 0 .529 r
.49639 .7505 m .49521 .74931 L .49777 .74837 L F
.49639 .7505 m .49648 .75101 L .49521 .74931 L F
.923 .685 .561 r
.49448 .74795 m .4948 .75052 L .49639 .7505 L F
.554 .115 .16 r
.4948 .75052 m .49633 .75021 L .49639 .7505 L F
.442 .097 .284 r
.49882 .74972 m .49639 .7505 L .49777 .74837 L F
.658 .616 .795 r
.49507 .74734 m .49639 .7505 L .49882 .74972 L F
.554 .115 .16 r
.49633 .75021 m .49882 .74972 L .49639 .7505 L F
0 0 .529 r
.49639 .7505 m .49689 .75156 L .49648 .75101 L F
.165 0 .36 r
.72285 .50894 m .72122 .51023 L .72296 .50716 L F
.388 .328 .668 r
.72285 .50894 m .72344 .51189 L .72122 .51023 L F
.628 .532 .727 r
.6903 .51451 m .69028 .51551 L .69254 .51453 L F
.513 .408 .672 r
.45333 .7688 m .45531 .76844 L .45503 .76523 L F
.506 .414 .685 r
.45383 .77127 m .45531 .76844 L .45333 .7688 L F
.22 .209 .633 r
.54336 .75096 m .5426 .7486 L .54266 .74877 L F
.394 .482 .831 r
.45211 .77983 m .45364 .78266 L .45513 .78145 L F
0 0 0 r
.45436 .78499 m .45513 .78145 L .45364 .78266 L F
.503 .235 .441 r
.47485 .74885 m .47709 .7485 L .47745 .74653 L F
.554 .302 .488 r
.47709 .7485 m .47965 .74616 L .47745 .74653 L F
.488 0 0 r
.58793 .68228 m .58667 .68325 L .58445 .68236 L F
0 0 .284 r
.58911 .67763 m .59015 .68201 L .59219 .67942 L F
.58911 .67763 m .59023 .68174 L .59015 .68201 L F
.24 .749 .873 r
.59015 .68201 m .59023 .68174 L .58793 .68228 L F
.542 .48 .736 r
.25931 .62596 m .26009 .62941 L .25807 .62986 L F
.571 .414 .63 r
.26039 .63173 m .25807 .62986 L .26009 .62941 L F
.26039 .63173 m .25818 .6322 L .25807 .62986 L F
.714 .575 .698 r
.51652 .80402 m .51881 .8048 L .51674 .80743 L F
.576 .386 .586 r
.51881 .8048 m .51916 .80758 L .51674 .80743 L F
.751 .46 .489 r
.51881 .8048 m .52107 .80718 L .51916 .80758 L F
.51881 .8048 m .52253 .80706 L .52107 .80718 L F
.543 .381 .611 r
.45232 .77688 m .4546 .77917 L .45419 .77618 L F
.45232 .77688 m .45211 .77983 L .4546 .77917 L F
.858 .873 .849 r
.67229 .49351 m .67055 .49602 L .67197 .49646 L F
.939 .712 .567 r
.67055 .49602 m .67157 .49852 L .67197 .49646 L F
.501 .243 .456 r
.44445 .6879 m .4442 .68985 L .4421 .68978 L F
.438 .147 .372 r
.44674 .68752 m .4442 .68985 L .44445 .6879 L F
.448 .321 .615 r
.32135 .61313 m .32262 .61409 L .32278 .61227 L F
.32135 .61313 m .32106 .61499 L .32262 .61409 L F
.461 .014 .1 r
.38332 .65039 m .38561 .65037 L .38374 .64956 L F
.942 .58 .205 r
.60028 .69496 m .60088 .6939 L .59968 .69291 L F
.60028 .69496 m .60131 .69575 L .60088 .6939 L F
.873 .861 .826 r
.60998 .52994 m .60666 .53166 L .60877 .52895 L F
.60998 .52994 m .60769 .53247 L .60666 .53166 L F
.86 .867 .843 r
.6123 .52725 m .60998 .52994 L .60877 .52895 L F
.351 .084 .361 r
.36456 .65702 m .36277 .65775 L .36213 .65971 L F
.298 0 .194 r
.32835 .63283 m .32925 .63389 L .32785 .63478 L F
.32835 .63283 m .33029 .63233 L .32925 .63389 L F
.897 .886 .813 r
.62507 .49469 m .62264 .4959 L .62407 .49312 L F
.431 .452 .781 r
.62646 .49222 m .62507 .49469 L .62407 .49312 L F
.62646 .49222 m .6273 .49558 L .62507 .49469 L F
.635 .455 .622 r
.54974 .74559 m .54664 .74626 L .54642 .74448 L F
.771 .68 .762 r
.47193 .7742 m .46842 .77389 L .47066 .77101 L F
.612 .598 .812 r
.47438 .77344 m .47193 .7742 L .47066 .77101 L F
.732 .575 .678 r
.64158 .52061 m .64402 .51791 L .6421 .51884 L F
.392 .786 .987 r
.32889 .59332 m .32838 .59428 L .3268 .59348 L F
.32889 .59332 m .33051 .59405 L .32838 .59428 L F
.763 .613 .692 r
.51652 .80402 m .51674 .80743 L .51337 .80772 L F
.56 .439 .672 r
.55687 .69454 m .55845 .69592 L .5562 .69634 L F
0 0 0 r
.55773 .69598 m .5562 .69634 L .55845 .69592 L F
.55773 .69598 m .55527 .69804 L .5562 .69634 L F
.75 .974 .925 r
.70119 .50129 m .6994 .50239 L .70052 .50062 L F
.414 .519 .856 r
.70052 .50062 m .6994 .50239 L .69874 .50076 L F
.084 .643 .728 r
.28023 .65235 m .28047 .65227 L .27841 .65281 L F
.981 .79 .38 r
.77465 .61013 m .77389 .61166 L .77449 .61259 L F
.655 .962 .773 r
.77465 .61013 m .77617 .60839 L .77383 .60919 L F
.77465 .61013 m .77552 .60945 L .77513 .60958 L F
.679 .231 .18 r
.77732 .61178 m .77465 .61013 L .77383 .60919 L F
.77732 .61178 m .7746 .60976 L .77607 .61116 L F
.7746 .60976 m .77383 .60919 L .77451 .60979 L F
.7746 .60976 m .77451 .60979 L .77607 .61116 L F
.655 .962 .773 r
.77587 .60906 m .77744 .60795 L .77617 .60839 L F
.77552 .60945 m .77744 .60795 L .77513 .60958 L F
.516 .478 .752 r
.77907 .60665 m .77744 .60795 L .77618 .60388 L F
.589 .937 .767 r
.77617 .60839 m .77744 .60795 L .77907 .60665 L F
.77617 .60839 m .77907 .60665 L .77855 .60828 L F
.371 .758 .988 r
.77617 .60839 m .77855 .60828 L .77641 .60787 L F
.77617 .60839 m .77641 .60787 L .77531 .60767 L F
.655 .962 .773 r
.77513 .60958 m .77587 .60906 L .77617 .60839 L F
.679 .231 .18 r
.77732 .61178 m .77389 .61166 L .77465 .61013 L F
.618 .588 .798 r
.6924 .49879 m .68898 .49616 L .69133 .49582 L F
.668 .616 .788 r
.69455 .4963 m .6924 .49879 L .69133 .49582 L F
.653 .594 .776 r
.69455 .4963 m .69579 .49969 L .6924 .49879 L F
.874 .483 .016 r
.60017 .70977 m .60108 .71231 L .6015 .71232 L F
.936 .565 .194 r
.60159 .71465 m .6015 .71232 L .60108 .71231 L F
.60159 .71465 m .60256 .71544 L .6015 .71232 L F
0 0 0 r
.45436 .78499 m .45469 .78423 L .45513 .78145 L F
0 .085 .644 r
.45436 .78499 m .45635 .78685 L .45469 .78423 L F
.339 .12 .428 r
.69054 .53358 m .69094 .53672 L .68817 .5374 L F
.399 .28 .601 r
.69303 .53145 m .69054 .53358 L .6909 .53206 L F
.69303 .53145 m .69337 .53396 L .69054 .53358 L F
.376 .145 .431 r
.69293 .53572 m .69054 .53358 L .69337 .53396 L F
.69293 .53572 m .69094 .53672 L .69054 .53358 L F
.499 .156 .316 r
.4421 .68978 m .44091 .69237 L .43879 .69236 L F
.414 .053 .24 r
.4442 .68985 m .44091 .69237 L .4421 .68978 L F
.535 .631 .893 r
.68863 .52365 m .68903 .5266 L .68954 .52479 L F
0 0 .384 r
.68903 .5266 m .69064 .5266 L .68954 .52479 L F
.471 .427 .727 r
.35922 .69631 m .35978 .69981 L .36163 .69832 L F
.618 .582 .791 r
.69024 .49225 m .68898 .49616 L .68793 .4929 L F
.69024 .49225 m .69133 .49582 L .68898 .49616 L F
.558 .443 .679 r
.52259 .7348 m .52024 .7322 L .52559 .73089 L F
.975 .754 .332 r
.56954 .77133 m .5696 .77396 L .56885 .77275 L F
.093 0 .446 r
.57284 .76662 m .57244 .76799 L .57113 .76709 L F
.587 .875 .562 r
.56954 .77133 m .56978 .77096 L .57223 .76849 L F
.56978 .77096 m .57001 .77063 L .57054 .77011 L F
.56978 .77096 m .57054 .77011 L .57223 .76849 L F
.92 .677 .554 r
.57001 .77063 m .57229 .77103 L .57223 .76849 L F
.093 0 .446 r
.57244 .76799 m .57194 .76968 L .57168 .76884 L F
.57244 .76799 m .57168 .76884 L .57113 .76709 L F
.803 .722 .775 r
.56885 .77275 m .57001 .77063 L .56954 .77133 L F
.368 .815 .948 r
.56769 .77091 m .57001 .77063 L .56954 .77133 L F
.141 .03 .455 r
.62783 .51234 m .62823 .5094 L .62775 .50858 L F
.616 .057 0 r
.55875 .70957 m .56125 .71128 L .56209 .71064 L F
.693 .165 0 r
.56125 .71128 m .56431 .71231 L .56209 .71064 L F
.245 .754 .87 r
.29767 .60206 m .30112 .60186 L .29991 .60217 L F
.303 0 0 r
.29991 .60217 m .30112 .60186 L .30295 .60211 L F
.488 .757 .99 r
.51683 .77272 m .51698 .77134 L .51488 .77014 L F
.562 .497 .739 r
.77469 .58455 m .77545 .58778 L .77352 .58634 L F
.775 .536 .574 r
.77545 .58778 m .77258 .59002 L .77352 .58634 L F
.142 .685 .726 r
.41576 .66293 m .41449 .6631 L .41233 .66347 L F
.303 0 0 r
.41804 .66291 m .41449 .6631 L .41576 .66293 L F
.863 .806 .793 r
.34164 .7185 m .34004 .71802 L .34241 .71478 L F
0 .018 .54 r
.34164 .7185 m .34183 .71856 L .34004 .71802 L F
.34164 .7185 m .3436 .72056 L .34183 .71856 L F
.363 .297 .648 r
.47105 .66825 m .46974 .67109 L .46895 .66874 L F
.47105 .66825 m .47138 .67064 L .46974 .67109 L F
0 0 .557 r
.47138 .67064 m .47163 .67189 L .46974 .67109 L F
.603 .431 .621 r
.53662 .76565 m .53901 .76555 L .53881 .76282 L F
.703 .62 .761 r
.54104 .76025 m .53881 .76282 L .53766 .76058 L F
.434 0 0 r
.54214 .76259 m .54068 .76246 L .53981 .76231 L F
.115 .456 .886 r
.53881 .76282 m .53981 .76231 L .53842 .76209 L F
.434 0 0 r
.54068 .76246 m .53841 .76224 L .53981 .76231 L F
.115 .456 .886 r
.53842 .76209 m .53981 .76231 L .53823 .76172 L F
.039 .286 .779 r
.53881 .76282 m .5413 .76519 L .53981 .76231 L F
.564 .402 .619 r
.53901 .76555 m .5413 .76519 L .53881 .76282 L F
.567 .484 .72 r
.36125 .70496 m .3636 .70459 L .36273 .70131 L F
.626 .45 .625 r
.36125 .70496 m .36383 .70701 L .3636 .70459 L F
.36125 .70496 m .36154 .70763 L .36383 .70701 L F
.115 0 .072 r
.27373 .60961 m .27259 .6119 L .27056 .61261 L F
.259 0 .146 r
.27445 .61129 m .27373 .60961 L .27608 .6085 L F
.27445 .61129 m .27259 .6119 L .27373 .60961 L F
.506 .094 .192 r
.70052 .50062 m .70418 .49925 L .70119 .50129 L F
.687 .336 .375 r
.52253 .80706 m .52646 .80712 L .52457 .80911 L F
.732 .282 .182 r
.52646 .80712 m .52691 .80926 L .52457 .80911 L F
.52646 .80712 m .52832 .80799 L .52691 .80926 L F
.689 .171 0 r
.56021 .71735 m .55614 .71537 L .55796 .71527 L F
.86 .614 .566 r
.59886 .68989 m .59914 .68808 L .59705 .6875 L F
.628 .532 .727 r
.6903 .51451 m .69254 .51453 L .69267 .51327 L F
.732 .648 .766 r
.55307 .77423 m .55203 .77838 L .55057 .7769 L F
.573 .488 .72 r
.55494 .77671 m .55203 .77838 L .55307 .77423 L F
.279 .519 .905 r
.55501 .7788 m .55203 .77838 L .55494 .77671 L F
.55501 .7788 m .55407 .77966 L .55203 .77838 L F
.987 .796 .561 r
.49778 .75621 m .49678 .75782 L .49725 .75847 L F
.49678 .75782 m .49608 .75897 L .49725 .75847 L F
0 .208 .722 r
.49725 .75847 m .49937 .76087 L .4985 .76021 L F
.49725 .75847 m .4985 .76021 L .49622 .75846 L F
.438 0 0 r
.65227 .50629 m .64931 .5059 L .65039 .50553 L F
.817 .59 .595 r
.68079 .49906 m .6809 .50139 L .67768 .50079 L F
.806 .494 .461 r
.67768 .50079 m .6809 .50139 L .68102 .50389 L F
.655 .602 .783 r
.68102 .50389 m .68178 .50156 L .68004 .50196 L F
.68178 .50156 m .68234 .49983 L .68065 .50139 L F
.68178 .50156 m .68065 .50139 L .68004 .50196 L F
.817 .59 .595 r
.68079 .49906 m .67768 .50079 L .67953 .50122 L F
.68079 .49906 m .67953 .50122 L .68073 .5014 L F
.124 0 .233 r
.68079 .49906 m .68073 .5015 L .68234 .49983 L F
.724 .768 .887 r
.67916 .49937 m .68027 .50123 L .68234 .49983 L F
.817 .59 .595 r
.68065 .50139 m .67953 .50122 L .68039 .50142 L F
.432 .619 .93 r
.67833 .50016 m .68039 .50142 L .67768 .50079 L F
.67916 .49937 m .67998 .50073 L .67833 .50016 L F
.67998 .50073 m .68039 .50142 L .67833 .50016 L F
.52 .642 .91 r
.67697 .49695 m .67887 .49496 L .67637 .49555 L F
.67697 .49695 m .6799 .49746 L .67887 .49496 L F
.781 .627 .689 r
.67724 .49609 m .67768 .50079 L .67442 .50038 L F
.432 .619 .93 r
.67916 .49937 m .67768 .50079 L .67724 .49609 L F
.67 .203 .136 r
.67442 .50038 m .67768 .50079 L .67665 .50164 L F
.665 .471 .613 r
.67714 .50122 m .67782 .50061 L .67773 .49995 L F
.294 .207 .584 r
.67724 .49609 m .67782 .50061 L .67916 .49937 L F
.395 .556 .896 r
.67768 .50079 m .67833 .50016 L .67782 .50061 L F
.67768 .50079 m .68004 .50196 L .67916 .49937 L F
.806 .494 .461 r
.67768 .50079 m .68102 .50389 L .68004 .50196 L F
.294 .207 .584 r
.67782 .50061 m .67793 .50146 L .67916 .49937 L F
.67 .28 .299 r
.67665 .50164 m .67793 .50146 L .67714 .50122 L F
.67665 .50164 m .67714 .50122 L .67442 .50038 L F
.395 .556 .896 r
.6773 .5011 m .6775 .50091 L .67694 .5014 L F
.6775 .50091 m .67782 .50061 L .67714 .50122 L F
.6775 .50091 m .67714 .50122 L .67694 .5014 L F
.67768 .50079 m .67782 .50061 L .6773 .5011 L F
.67694 .5014 m .67916 .49937 L .67665 .50164 L F
.67833 .50016 m .67916 .49937 L .67694 .5014 L F
.665 .471 .613 r
.67442 .50038 m .67714 .50122 L .67773 .49995 L F
.67714 .50122 m .67793 .50146 L .67782 .50061 L F
.67527 .49909 m .67773 .49995 L .67724 .49609 L F
.67442 .50038 m .67773 .49995 L .67527 .49909 L F
.724 .768 .887 r
.67988 .50149 m .68065 .50139 L .68234 .49983 L F
.67988 .50149 m .68004 .50196 L .68065 .50139 L F
.817 .59 .595 r
.68065 .50139 m .68039 .50142 L .68073 .5015 L F
.432 .619 .93 r
.67916 .49937 m .68073 .5015 L .68039 .50142 L F
.724 .768 .887 r
.67916 .49937 m .67988 .50149 L .68027 .50123 L F
.817 .59 .595 r
.68073 .5014 m .68065 .50139 L .68073 .5015 L F
.554 .65 .898 r
.6799 .49746 m .68079 .49906 L .68287 .49799 L F
.124 0 .233 r
.68079 .49906 m .68234 .49983 L .68287 .49799 L F
.571 .426 .645 r
.47129 .7693 m .47066 .77101 L .46839 .77134 L F
.56 .38 .595 r
.47066 .77101 m .46842 .77389 L .46839 .77134 L F
.642 .487 .657 r
.5368 .77104 m .53975 .77071 L .53895 .76821 L F
.53833 .76866 m .53895 .76821 L .53884 .76786 L F
.5368 .77104 m .53895 .76821 L .53833 .76866 L F
.566 .36 .56 r
.53292 .7698 m .53716 .76953 L .53662 .76565 L F
.642 .487 .657 r
.5368 .77104 m .53833 .76866 L .53809 .76947 L F
.53833 .76866 m .53884 .76786 L .53809 .76947 L F
.566 .36 .56 r
.53716 .76953 m .53809 .76947 L .5379 .76898 L F
.53716 .76953 m .5379 .76898 L .53662 .76565 L F
.539 .346 .567 r
.53662 .76565 m .53809 .76947 L .53884 .76786 L F
.586 .345 .518 r
.53662 .76565 m .53884 .76786 L .53901 .76555 L F
.902 .984 .726 r
.57528 .76225 m .57343 .76511 L .57392 .76557 L F
.815 .62 .639 r
.68477 .52031 m .688 .51847 L .68729 .51868 L F
.68477 .52031 m .68799 .52167 L .688 .51847 L F
.328 .451 .833 r
.68684 .51592 m .68959 .51723 L .688 .51847 L F
.5 .893 .736 r
.68959 .51723 m .68729 .51868 L .688 .51847 L F
.24 0 0 r
.30838 .64883 m .30641 .65029 L .30437 .65064 L F
.034 0 0 r
.30849 .64964 m .30838 .64883 L .31047 .64812 L F
.30849 .64964 m .30641 .65029 L .30838 .64883 L F
.896 .96 .628 r
.65109 .50955 m .65068 .50939 L .65227 .50629 L F
.248 .187 .589 r
.50587 .801 m .50577 .80323 L .50638 .79905 L F
.569 .379 .583 r
.50577 .80323 m .50859 .80128 L .50638 .79905 L F
.357 0 .005 r
.65872 .54309 m .65771 .54462 L .65539 .54487 L F
.361 0 .05 r
.66107 .54261 m .65771 .54462 L .65872 .54309 L F
.555 .112 .151 r
.71173 .52069 m .711 .52221 L .70864 .5211 L F
.398 0 .097 r
.7141 .52036 m .711 .52221 L .71173 .52069 L F
.518 .299 .521 r
.45643 .75727 m .45862 .75701 L .45893 .7539 L F
.474 .262 .511 r
.45893 .7539 m .46075 .75633 L .46125 .75468 L F
.45893 .7539 m .45862 .75701 L .46075 .75633 L F
.717 .449 .519 r
.4955 .80237 m .49855 .80429 L .49511 .80373 L F
.018 .588 .767 r
.26595 .58468 m .2656 .58477 L .26422 .58494 L F
.26595 .58468 m .26764 .58487 L .2656 .58477 L F
.652 .211 0 r
.65937 .50959 m .66067 .51163 L .6613 .51238 L F
.983 .723 .455 r
.66067 .51163 m .66136 .51323 L .6613 .51238 L F
0 0 .557 r
.47138 .67064 m .4727 .67394 L .47163 .67189 L F
.929 .658 .504 r
.6037 .72591 m .60529 .72411 L .60357 .72334 L F
.6037 .72591 m .6054 .72648 L .60529 .72411 L F
.094 0 0 r
.30019 .65145 m .29928 .65157 L .29715 .65157 L F
.393 0 .055 r
.30204 .65102 m .29928 .65157 L .30019 .65145 L F
.746 .395 .388 r
.47366 .79332 m .47198 .79539 L .4702 .79312 L F
.734 .305 .231 r
.47366 .79332 m .47443 .7956 L .47198 .79539 L F
.55 .411 .645 r
.47687 .79676 m .47758 .79793 L .47543 .79815 L F
.734 .305 .231 r
.47366 .79332 m .47732 .79664 L .47627 .79626 L F
.47403 .79443 m .47627 .79626 L .47443 .7956 L F
.47366 .79332 m .47627 .79626 L .47403 .79443 L F
.644 .656 .847 r
.47443 .7956 m .47732 .79664 L .47847 .79521 L F
.55 .411 .645 r
.47847 .79521 m .47773 .79746 L .47687 .79676 L F
.47773 .79746 m .47758 .79793 L .47687 .79676 L F
.772 .668 .748 r
.50679 .72365 m .51008 .72422 L .50872 .72117 L F
.737 .476 .535 r
.50649 .72614 m .51008 .72422 L .50679 .72365 L F
.50649 .72614 m .50964 .72661 L .51008 .72422 L F
.482 .24 .47 r
.51008 .72422 m .50964 .72661 L .51221 .72411 L F
.86 .867 .843 r
.6123 .52725 m .60877 .52895 L .61086 .52605 L F
.394 .826 .957 r
.42929 .66173 m .42565 .66177 L .42718 .66244 L F
.66 .291 .333 r
.51292 .80399 m .515 .80222 L .51245 .80123 L F
.502 .843 .565 r
.51467 .80247 m .515 .80222 L .51292 .80399 L F
.51663 .80076 m .515 .80222 L .51467 .80247 L F
.522 0 0 r
.515 .80222 m .51552 .80187 L .51547 .80186 L F
.515 .80222 m .51547 .80186 L .51245 .80123 L F
.598 .161 .183 r
.51337 .80772 m .51674 .80743 L .51543 .80918 L F
.588 .767 .964 r
.50703 .76298 m .5084 .76135 L .50582 .7598 L F
.50703 .76298 m .50919 .76293 L .5084 .76135 L F
.779 .341 .208 r
.50703 .76298 m .50921 .76513 L .50645 .76383 L F
.399 0 0 r
.50793 .76418 m .50703 .76298 L .50577 .76228 L F
.651 .418 .552 r
.50919 .76293 m .50921 .76513 L .50703 .76298 L F
.399 0 0 r
.50793 .76418 m .50919 .76293 L .50703 .76298 L F
.531 .867 .599 r
.51663 .80076 m .51552 .80187 L .515 .80222 L F
.62 .257 .333 r
.51833 .8034 m .51801 .80225 L .51552 .80187 L F
.267 .435 .843 r
.51663 .80076 m .51833 .8034 L .51552 .80187 L F
.358 0 0 r
.51674 .80743 m .51805 .80794 L .51543 .80918 L F
.51674 .80743 m .51916 .80758 L .51805 .80794 L F
.588 .858 .994 r
.74417 .61811 m .74744 .61817 L .7464 .6172 L F
.58 .757 .962 r
.74744 .61817 m .7492 .61645 L .7464 .6172 L F
.74744 .61817 m .74989 .61768 L .7492 .61645 L F
.306 .742 .968 r
.28224 .63876 m .28525 .63905 L .28307 .63963 L F
.73 .889 .953 r
.26087 .65636 m .26191 .65427 L .2593 .65583 L F
.26087 .65636 m .26276 .65501 L .26191 .65427 L F
.573 .404 .614 r
.73417 .59865 m .73475 .60157 L .73231 .60199 L F
.622 .587 .793 r
.7361 .59778 m .73475 .60157 L .73417 .59865 L F
.727 .332 .301 r
.55456 .7127 m .55316 .7144 L .55133 .71242 L F
.829 .473 .381 r
.55456 .7127 m .55614 .71537 L .55316 .7144 L F
.448 .799 .998 r
.2951 .59058 m .29714 .59026 L .29865 .59101 L F
.394 .766 .992 r
.29714 .59026 m .30075 .5909 L .29865 .59101 L F
.772 .425 .399 r
.52218 .72035 m .52359 .71831 L .52193 .718 L F
.52218 .72035 m .5258 .72097 L .52359 .71831 L F
.596 .255 .363 r
.62708 .5572 m .62382 .55935 L .62406 .55782 L F
.62708 .5572 m .62608 .5595 L .62382 .55935 L F
.564 .222 .348 r
.62936 .55846 m .62708 .5572 L .62941 .55682 L F
.62936 .55846 m .62608 .5595 L .62708 .5572 L F
.89 .775 .728 r
.60769 .53247 m .60718 .53485 L .60558 .53362 L F
.893 .773 .722 r
.60558 .53362 m .60718 .53485 L .60562 .53783 L F
.702 .557 .687 r
.54196 .75388 m .53823 .75237 L .53899 .75191 L F
.54196 .75388 m .54006 .75497 L .53823 .75237 L F
.519 .687 .943 r
.29004 .58691 m .28959 .58894 L .28805 .58727 L F
.29004 .58691 m .29144 .58868 L .28959 .58894 L F
.544 .29 .481 r
.32027 .61744 m .32262 .61409 L .32106 .61499 L F
.724 .985 .895 r
.68458 .51605 m .68593 .51421 L .68684 .51592 L F
.68458 .51605 m .68413 .51562 L .68593 .51421 L F
.472 .162 .358 r
.43656 .68199 m .43875 .68162 L .43952 .67923 L F
.526 .32 .543 r
.43952 .67923 m .44171 .67894 L .44175 .67679 L F
.523 .23 .41 r
.43875 .68162 m .44171 .67894 L .43952 .67923 L F
.571 .453 .679 r
.3136 .61884 m .31598 .62074 L .31592 .61826 L F
.3136 .61884 m .31381 .6212 L .31598 .62074 L F
.535 .425 .676 r
.75911 .60492 m .76155 .60423 L .76074 .60162 L F
.436 .162 .398 r
.7588 .60673 m .76155 .60423 L .75911 .60492 L F
.293 .778 .911 r
.54019 .77154 m .54374 .77146 L .54238 .773 L F
.25 .523 .913 r
.33637 .59463 m .33806 .59501 L .33746 .59624 L F
.36 .658 .97 r
.33806 .59501 m .33938 .59629 L .33746 .59624 L F
.611 .907 .984 r
.61083 .75088 m .6102 .75028 L .60815 .75122 L F
.732 .814 .915 r
.61083 .75088 m .61265 .74828 L .6102 .75028 L F
.61083 .75088 m .61428 .7497 L .61265 .74828 L F
.514 .327 .565 r
.47684 .77581 m .47436 .7787 L .47496 .77646 L F
.52 .72 .964 r
.39581 .69717 m .39457 .69866 L .39375 .69762 L F
.39581 .69717 m .39676 .69845 L .39457 .69866 L F
.541 .694 .938 r
.6798 .48668 m .67854 .48882 L .67747 .48719 L F
.6798 .48668 m .68081 .48859 L .67854 .48882 L F
.322 .703 .981 r
.75285 .59035 m .75592 .59116 L .75525 .59026 L F
.542 .674 .924 r
.75592 .59116 m .75759 .58952 L .75525 .59026 L F
.75592 .59116 m .75833 .59088 L .75759 .58952 L F
.568 .566 .812 r
.75592 .59116 m .75888 .59279 L .75833 .59088 L F
.054 0 0 r
.56219 .68937 m .56046 .69046 L .5632 .68829 L F
.353 .055 .313 r
.56495 .68732 m .56219 .68937 L .5632 .68829 L F
.507 .52 .804 r
.70988 .60369 m .71098 .60088 L .70896 .6011 L F
.70988 .60369 m .71208 .60421 L .71098 .60088 L F
.58 .395 .596 r
.54501 .69867 m .54484 .69887 L .54557 .69659 L F
.386 .201 .504 r
.54557 .69659 m .54484 .69887 L .54794 .69711 L F
.592 .069 0 r
.52565 .80607 m .52762 .80494 L .52485 .80443 L F
.583 .059 0 r
.52902 .80639 m .52762 .80494 L .52565 .80607 L F
.371 0 .061 r
.53033 .80419 m .52762 .80494 L .52902 .80639 L F
.59 .845 .993 r
.76529 .58212 m .7629 .58279 L .76206 .58194 L F
.945 .919 .756 r
.66718 .53408 m .66899 .53177 L .66781 .53064 L F
.317 0 .216 r
.73853 .59349 m .74106 .59267 L .74147 .5908 L F
.3 0 .138 r
.74106 .59267 m .74384 .59029 L .74147 .5908 L F
.484 .39 .674 r
.3565 .67127 m .35808 .66772 L .35592 .66926 L F
.652 .729 .905 r
.78054 .61246 m .77888 .61352 L .77732 .61178 L F
.469 .124 .298 r
.39077 .67113 m .3878 .67323 L .38863 .67155 L F
.511 .375 .632 r
.44175 .67679 m .44403 .67622 L .44382 .67347 L F
.49 .297 .545 r
.44171 .67894 m .44403 .67622 L .44175 .67679 L F
.13 0 0 r
.39687 .71236 m .39326 .71367 L .39474 .71272 L F
.905 .926 .543 r
.6254 .51661 m .62528 .51802 L .62632 .5158 L F
.926 .749 .644 r
.62377 .51817 m .62528 .51802 L .6254 .51661 L F
.635 .378 .512 r
.62756 .51581 m .62437 .5175 L .6254 .51661 L F
.412 .863 .855 r
.62434 .51752 m .62377 .51817 L .6254 .51661 L F
.635 .378 .512 r
.62437 .5175 m .62434 .51752 L .6254 .51661 L F
.905 .926 .543 r
.6254 .51661 m .62632 .5158 L .62648 .51545 L F
0 0 0 r
.62734 .51568 m .62648 .51545 L .62813 .51326 L F
.62734 .51568 m .6254 .51661 L .62648 .51545 L F
.507 .512 .796 r
.38486 .68523 m .38289 .68535 L .38176 .68208 L F
.563 .505 .748 r
.38486 .68523 m .38333 .68746 L .38289 .68535 L F
.824 .448 0 r
.59411 .69618 m .59349 .69552 L .59262 .6931 L F
.962 .674 .442 r
.59411 .69618 m .59284 .69786 L .59349 .69552 L F
.59411 .69618 m .59444 .69887 L .59284 .69786 L F
.623 .539 .739 r
.4994 .74313 m .49995 .746 L .4976 .74624 L F
.716 .495 .588 r
.49995 .746 m .49777 .74837 L .4976 .74624 L F
.107 .631 .878 r
.27687 .58581 m .279 .58592 L .28052 .58646 L F
.416 0 0 r
.279 .58592 m .28274 .58621 L .28052 .58646 L F
.642 .736 .917 r
.36609 .72092 m .36752 .72337 L .36979 .72171 L F
.647 .731 .91 r
.36752 .72337 m .36876 .72289 L .36979 .72171 L F
0 .426 .791 r
.6603 .50486 m .66144 .50532 L .66045 .50469 L F
.529 .564 .834 r
.38849 .69057 m .38754 .69388 L .38626 .69075 L F
.38849 .69057 m .38949 .69359 L .38754 .69388 L F
.541 .787 .989 r
.2881 .66974 m .28724 .67127 L .28579 .67011 L F
.2881 .66974 m .28931 .67083 L .28724 .67127 L F
.28724 .67127 m .2881 .66974 L .28579 .67011 L F
.28724 .67127 m .28931 .67083 L .2881 .66974 L F
.853 .399 .105 r
.55225 .7062 m .55524 .70931 L .55346 .70735 L F
.665 .141 0 r
.55346 .70735 m .55524 .70931 L .55543 .7093 L F
0 0 .079 r
.56699 .68422 m .56495 .68732 L .56575 .68546 L F
.146 .562 .928 r
.58785 .71095 m .59132 .71207 L .59052 .71102 L F
.58785 .71095 m .59052 .71102 L .58844 .71106 L F
.975 .853 .457 r
.57489 .7573 m .57393 .759 L .57439 .75942 L F
.795 .66 .108 r
.5749 .75432 m .57478 .75692 L .57489 .7573 L F
.828 .868 .423 r
.57478 .75692 m .57393 .759 L .57489 .7573 L F
.681 .291 .302 r
.52919 .72114 m .53146 .72315 L .53262 .7212 L F
.475 .049 .151 r
.53146 .72315 m .53489 .72139 L .53262 .7212 L F
.924 .937 .793 r
.6575 .51745 m .6562 .52023 L .65506 .51932 L F
.541 .469 .724 r
.38549 .6872 m .38418 .69107 L .38333 .68746 L F
.38549 .6872 m .38626 .69075 L .38418 .69107 L F
.6 .557 .778 r
.46925 .66135 m .46827 .66538 L .46731 .66191 L F
.46925 .66135 m .47057 .66503 L .46827 .66538 L F
.518 .415 .677 r
.47057 .66503 m .46895 .66874 L .46827 .66538 L F
.757 .415 .405 r
.48998 .7952 m .49035 .79364 L .48681 .79328 L F
.519 .185 .341 r
.49232 .79558 m .49035 .79364 L .48998 .7952 L F
.572 .456 .682 r
.77365 .59296 m .77163 .59599 L .77124 .59394 L F
.77365 .59296 m .7741 .59531 L .77163 .59599 L F
.611 .472 .667 r
.7741 .59531 m .77252 .59876 L .77163 .59599 L F
.741 .558 .646 r
.47627 .76866 m .47318 .7712 L .4729 .76826 L F
.47627 .76866 m .4765 .77309 L .47318 .7712 L F
.472 .351 .633 r
.47871 .77062 m .4765 .77309 L .47627 .76866 L F
0 0 0 r
.56043 .69301 m .55845 .69592 L .55687 .69454 L F
.47 .242 .485 r
.55041 .79344 m .55097 .79102 L .54837 .79355 L F
.54837 .79355 m .55097 .79102 L .55041 .79344 L F
.963 .907 .715 r
.57054 .74016 m .56931 .74296 L .57038 .7436 L F
.988 .758 .498 r
.56898 .74453 m .57038 .7436 L .56931 .74296 L F
.56898 .74453 m .57004 .74546 L .57038 .7436 L F
.578 .351 .535 r
.43186 .68484 m .43417 .68473 L .43437 .68241 L F
.514 .297 .522 r
.43417 .68473 m .43656 .68199 L .43437 .68241 L F
.339 0 0 r
.52691 .80926 m .52832 .80799 L .5305 .80798 L F
.384 0 .006 r
.52832 .80799 m .53142 .80729 L .5305 .80798 L F
.656 .834 .969 r
.53453 .77179 m .53795 .77198 L .5368 .77104 L F
.544 .819 .997 r
.53795 .77198 m .53975 .77071 L .5368 .77104 L F
.53899 .77178 m .54019 .77154 L .53975 .77071 L F
0 0 0 r
.54002 .77032 m .53975 .77071 L .53887 .77276 L F
.54075 .76879 m .53975 .77071 L .54002 .77032 L F
.544 .819 .997 r
.53795 .77198 m .53899 .77178 L .53975 .77071 L F
.736 .693 .809 r
.50626 .80371 m .50929 .80524 L .50859 .80128 L F
.758 .256 .026 r
.51013 .80653 m .50929 .80524 L .50626 .80371 L F
.225 .318 .75 r
.50859 .80128 m .50929 .80524 L .51081 .80311 L F
.042 .06 .552 r
.51081 .80311 m .50929 .80524 L .51013 .80653 L F
.116 0 .318 r
.56175 .69189 m .56046 .69046 L .56219 .68937 L F
.56175 .69189 m .56043 .69301 L .56046 .69046 L F
.741 .476 .53 r
.53254 .73484 m .52948 .73736 L .52908 .73516 L F
.518 .392 .648 r
.5351 .73785 m .53254 .73484 L .53578 .73698 L F
.366 .317 .671 r
.64414 .49985 m .64579 .50089 L .64522 .49838 L F
.17 0 0 r
.50225 .73181 m .50415 .73125 L .50559 .72934 L F
.586 .568 .8 r
.50559 .72934 m .50649 .72614 L .50469 .72651 L F
.50559 .72934 m .50811 .72878 L .50649 .72614 L F
.401 .045 .242 r
.50653 .73142 m .50559 .72934 L .50415 .73125 L F
.50653 .73142 m .50811 .72878 L .50559 .72934 L F
.544 .82 .997 r
.49851 .79335 m .49623 .79396 L .49436 .79299 L F
.025 0 0 r
.49478 .79498 m .49623 .79396 L .49851 .79335 L F
.647 .729 .909 r
.68506 .53013 m .68144 .52926 L .68405 .5298 L F
.155 .648 .916 r
.40634 .64913 m .40849 .6493 L .40991 .64994 L F
.247 0 0 r
.40849 .6493 m .41206 .64956 L .40991 .64994 L F
.489 .592 .883 r
.26147 .63711 m .25972 .63737 L .25792 .63459 L F
.562 .738 .959 r
.72926 .61574 m .73263 .6167 L .73174 .61537 L F
.624 .725 .919 r
.73263 .6167 m .734 .61442 L .73174 .61537 L F
.73263 .6167 m .73506 .61603 L .734 .61442 L F
.559 .888 .988 r
.42147 .66258 m .42007 .66216 L .41804 .66291 L F
.29 .757 .944 r
.42358 .66243 m .42007 .66216 L .42147 .66258 L F
.125 0 0 r
.7394 .59636 m .74244 .59581 L .742 .59611 L F
0 0 0 r
.74244 .59581 m .74408 .59521 L .74441 .59528 L F
.742 .59611 m .74244 .59581 L .74441 .59528 L F
.518 .415 .677 r
.47057 .66503 m .47105 .66825 L .46895 .66874 L F
.456 .134 .33 r
.62406 .55782 m .62382 .55935 L .6215 .5598 L F
0 0 0 r
.5305 .80798 m .53142 .80729 L .53272 .80687 L F
.813 .35 .126 r
.39326 .84502 m .39443 .8466 L .39279 .84508 L F
.659 .597 .774 r
.73475 .60157 m .73258 .60404 L .73231 .60199 L F
.73475 .60157 m .73599 .60534 L .73258 .60404 L F
.506 .414 .685 r
.45383 .77127 m .45581 .77082 L .45531 .76844 L F
.381 .209 .519 r
.45399 .77373 m .45581 .77082 L .45383 .77127 L F
.579 .303 .461 r
.4683 .67951 m .46568 .68172 L .46598 .67949 L F
.59 .94 .783 r
.75688 .60751 m .75455 .60904 L .75661 .60954 L F
.364 .141 .436 r
.75688 .60751 m .75661 .60954 L .7588 .60673 L F
.426 0 0 r
.75328 .60945 m .75661 .60954 L .75455 .60904 L F
.737 .743 .856 r
.74408 .60666 m .7429 .6103 L .74171 .60705 L F
.74408 .60666 m .74514 .60913 L .7429 .6103 L F
.92 .95 .798 r
.65793 .48774 m .65717 .48688 L .6592 .48388 L F
.802 .465 0 r
.65844 .49015 m .65717 .48688 L .65793 .48774 L F
.89 .775 .728 r
.60769 .53247 m .60558 .53362 L .60666 .53166 L F
.822 .674 .7 r
.60283 .54278 m .60406 .54614 L .60116 .54566 L F
.82 .684 .714 r
.60116 .54566 m .60406 .54614 L .60287 .54886 L F
.582 .552 .785 r
.50921 .76513 m .50843 .76802 L .50706 .76567 L F
.50921 .76513 m .51113 .76876 L .50843 .76802 L F
.826 .827 .849 r
.5997 .55625 m .60193 .55657 L .60097 .55733 L F
.934 .747 .626 r
.68142 .53355 m .68084 .53732 L .6794 .53669 L F
.68142 .53355 m .6794 .53669 L .682 .53441 L F
.271 .416 .825 r
.68142 .53355 m .68376 .53311 L .68083 .53146 L F
.124 0 .133 r
.68142 .53355 m .682 .53441 L .68376 .53311 L F
.647 .226 .231 r
.52094 .77468 m .52305 .7762 L .51936 .77619 L F
.982 .807 .593 r
.52094 .77468 m .51936 .77619 L .51969 .77335 L F
.42 0 0 r
.5095 .7739 m .5083 .77439 L .50601 .7741 L F
.7 .162 0 r
.51155 .77643 m .5083 .77439 L .5095 .7739 L F
.69 .401 .48 r
.51203 .7743 m .51155 .77643 L .5095 .7739 L F
.279 0 .227 r
.32312 .63775 m .32572 .63539 L .32511 .637 L F
.383 .074 .312 r
.32511 .637 m .32572 .63539 L .32785 .63478 L F
.234 0 0 r
.38561 .65037 m .38784 .6503 L .38937 .64954 L F
.243 0 0 r
.38784 .6503 m .39159 .64952 L .38937 .64954 L F
.976 .672 .343 r
.65827 .5085 m .65937 .50959 L .65908 .50737 L F
.34 0 .059 r
.62451 .52325 m .62777 .5212 L .62474 .52067 L F
.62451 .52325 m .62684 .52282 L .62777 .5212 L F
.522 0 0 r
.62975 .52278 m .62777 .5212 L .62684 .52282 L F
0 .327 .791 r
.63027 .52292 m .63181 .52373 L .63191 .52405 L F
.62777 .5212 m .63029 .52278 L .63027 .52292 L F
.63029 .52278 m .63181 .52373 L .63027 .52292 L F
.862 .738 .724 r
.6332 .5206 m .63116 .52189 L .63134 .52141 L F
.6332 .5206 m .63134 .52141 L .63194 .51927 L F
.522 0 0 r
.62975 .52278 m .63181 .52373 L .62777 .5212 L F
.862 .738 .724 r
.6332 .5206 m .63181 .52373 L .62975 .52278 L F
0 0 .359 r
.63134 .52141 m .6322 .52283 L .63153 .52088 L F
.863 .827 .352 r
.63194 .51927 m .63134 .52141 L .63134 .52031 L F
0 0 .359 r
.63134 .52141 m .63153 .52088 L .63134 .52031 L F
.862 .738 .724 r
.63116 .52189 m .63034 .52241 L .63134 .52141 L F
.63034 .52241 m .62975 .52278 L .63035 .52226 L F
.63034 .52241 m .63035 .52226 L .63134 .52141 L F
.561 .628 .876 r
.39212 .69483 m .39136 .69776 L .39084 .69725 L F
.39212 .69483 m .39375 .69762 L .39136 .69776 L F
.646 .52 .696 r
.52024 .7322 m .51804 .73553 L .51801 .73281 L F
.575 .499 .732 r
.35226 .60111 m .35303 .60451 L .35094 .6051 L F
.54 .414 .658 r
.35315 .60653 m .35094 .6051 L .35303 .60451 L F
.35315 .60653 m .35111 .60713 L .35094 .6051 L F
.293 0 .164 r
.55507 .74392 m .5542 .74547 L .55717 .74327 L F
.503 .236 .443 r
.42847 .6985 m .42601 .70062 L .42638 .6989 L F
.734 .346 .316 r
.51107 .80646 m .50998 .80952 L .51013 .80653 L F
.51107 .80646 m .51327 .80931 L .50998 .80952 L F
.51107 .80646 m .51337 .80772 L .51327 .80931 L F
.218 0 0 r
.28589 .65163 m .28607 .65184 L .28392 .65216 L F
.28589 .65163 m .28785 .65207 L .28607 .65184 L F
.626 .945 .948 r
.48905 .78867 m .48969 .78868 L .49148 .78763 L F
.739 .413 .43 r
.49602 .80185 m .49703 .79925 L .49459 .7981 L F
.49602 .80185 m .49841 .80128 L .49703 .79925 L F
.725 .319 .28 r
.48242 .79855 m .4859 .79902 L .48456 .80077 L F
.661 .24 .236 r
.48456 .80077 m .4859 .79902 L .48828 .80092 L F
.833 .567 .535 r
.60871 .72943 m .61055 .73162 L .61043 .72969 L F
.701 .425 .503 r
.56168 .68232 m .56546 .68406 L .5639 .68183 L F
.56168 .68232 m .56085 .68476 L .56546 .68406 L F
.799 .777 .272 r
.62278 .49886 m .62245 .4995 L .62174 .49783 L F
.62278 .49886 m .62162 .50321 L .62245 .4995 L F
.833 .585 .564 r
.62468 .5038 m .62162 .50321 L .62278 .49886 L F
0 0 .035 r
.61428 .7497 m .61662 .74632 L .61622 .74866 L F
.651 .794 .951 r
.61265 .74828 m .61428 .7497 L .61622 .74866 L F
.645 .844 .977 r
.62468 .5038 m .62416 .50452 L .62304 .50351 L F
.735 .503 .576 r
.62416 .50452 m .62083 .50646 L .62304 .50351 L F
.62416 .50452 m .62421 .5068 L .62083 .50646 L F
.541 .908 .726 r
.62628 .50305 m .62551 .50333 L .62416 .50452 L F
.645 .844 .977 r
.62468 .5038 m .62304 .50351 L .62162 .50321 L F
.837 .818 .831 r
.6242 .50394 m .62625 .50336 L .62725 .50175 L F
.141 0 0 r
.62818 .50235 m .62551 .50333 L .62628 .50305 L F
.62818 .50235 m .62787 .5029 L .62551 .50333 L F
.837 .818 .831 r
.62625 .50336 m .62787 .5029 L .62732 .50189 L F
.62625 .50336 m .62732 .50189 L .62725 .50175 L F
0 0 .384 r
.62544 .50447 m .62416 .50452 L .62551 .50333 L F
.62539 .50524 m .62503 .50503 L .62544 .50447 L F
.62503 .50503 m .62416 .50452 L .62544 .50447 L F
.62539 .50524 m .62421 .5068 L .62416 .50452 L F
.55 .516 .77 r
.75888 .59279 m .76 .59605 L .7623 .5956 L F
.43 .288 .586 r
.7606 .5984 m .7623 .5956 L .76 .59605 L F
.501 .296 .533 r
.25818 .6322 m .2559 .63499 L .25599 .63451 L F
.482 .43 .722 r
.7079 .59899 m .71098 .60088 L .71034 .5979 L F
.7079 .59899 m .70896 .6011 L .71098 .60088 L F
.36 .742 .988 r
.31359 .59265 m .31014 .59187 L .31201 .59202 L F
.28 .726 .961 r
.31405 .59196 m .31359 .59265 L .31201 .59202 L F
.31405 .59196 m .3156 .59261 L .31359 .59265 L F
.602 .621 .842 r
.35783 .69326 m .35922 .69631 L .36142 .69586 L F
.471 .427 .727 r
.35922 .69631 m .36163 .69832 L .36142 .69586 L F
.992 .812 .563 r
.66504 .52127 m .66445 .51788 L .66399 .52023 L F
.97 .655 .35 r
.66419 .52258 m .66504 .52127 L .66399 .52023 L F
.66419 .52258 m .66538 .5235 L .66504 .52127 L F
.446 .225 .483 r
.262 .62131 m .26151 .62354 L .25952 .62405 L F
.392 .161 .439 r
.26151 .62354 m .25931 .62596 L .25952 .62405 L F
.293 .009 .3 r
.69094 .53672 m .68847 .53926 L .68817 .5374 L F
.249 .012 .346 r
.51594 .73611 m .51356 .73981 L .51319 .73772 L F
.277 .093 .442 r
.33626 .6256 m .33505 .62413 L .33664 .62348 L F
.33626 .6256 m .3348 .62623 L .33505 .62413 L F
.86 .433 .205 r
.55122 .76929 m .54991 .76971 L .5483 .77091 L F
.55122 .76929 m .55208 .77118 L .54991 .76971 L F
.563 .505 .748 r
.38486 .68523 m .38549 .6872 L .38333 .68746 L F
.98 .706 .43 r
.67192 .52674 m .67078 .52799 L .67092 .52569 L F
.67192 .52674 m .67199 .52911 L .67078 .52799 L F
.651 .226 .223 r
.4797 .78587 m .4821 .78734 L .47924 .78723 L F
.887 .503 .303 r
.4797 .78587 m .47924 .78723 L .47864 .78567 L F
.674 .37 .451 r
.51978 .80397 m .52124 .80175 L .51801 .80225 L F
.737 .449 .493 r
.51978 .80397 m .52202 .80378 L .52124 .80175 L F
.818 .416 .289 r
.52485 .80443 m .52124 .80175 L .52202 .80378 L F
.312 .666 .974 r
.44827 .64926 m .44711 .65009 L .44594 .64949 L F
.44827 .64926 m .44969 .65032 L .44711 .65009 L F
.421 0 0 r
.53489 .72139 m .53727 .72211 L .53831 .72128 L F
.605 .101 .027 r
.53727 .72211 m .5406 .72191 L .53831 .72128 L F
.784 .697 .768 r
.77779 .5874 m .779 .59064 L .77579 .58985 L F
.75 .307 .2 r
.77579 .58985 m .779 .59064 L .77821 .59206 L F
.614 .639 .853 r
.78012 .58734 m .779 .59064 L .77779 .5874 L F
.78012 .58734 m .78183 .59009 L .779 .59064 L F
.683 .228 .165 r
.779 .59064 m .78213 .59267 L .77821 .59206 L F
.569 .391 .6 r
.78183 .59009 m .78213 .59267 L .779 .59064 L F
.333 .794 .94 r
.41206 .64956 m .41434 .64924 L .41559 .64956 L F
.105 .659 .784 r
.41434 .64924 m .41763 .64917 L .41559 .64956 L F
.477 0 0 r
.58037 .67759 m .57971 .67834 L .57767 .67736 L F
.21 .733 .842 r
.58196 .67823 m .57971 .67834 L .58037 .67759 L F
.948 .833 .697 r
.34792 .7175 m .34993 .71664 L .34784 .71685 L F
.34792 .7175 m .34926 .7183 L .34993 .71664 L F
.742 .393 .39 r
.35434 .7154 m .35312 .71682 L .35097 .71463 L F
.738 .621 .729 r
.35241 .71473 m .35312 .71682 L .35425 .71474 L F
.342 .207 .548 r
.34993 .71664 m .35191 .71622 L .35129 .71516 L F
.35055 .71545 m .35129 .71516 L .35097 .71463 L F
.34993 .71664 m .35129 .71516 L .35055 .71545 L F
.738 .621 .729 r
.3521 .71473 m .352 .71594 L .35241 .71473 L F
.237 .17 .575 r
.35097 .71463 m .35272 .71175 L .35491 .7109 L F
.35097 .71463 m .35131 .71516 L .35133 .71509 L F
.35097 .71463 m .35133 .71509 L .35236 .71262 L F
.732 .206 0 r
.35097 .71463 m .35312 .71682 L .35196 .71591 L F
.342 .207 .548 r
.34993 .71664 m .35197 .71621 L .35097 .71463 L F
0 0 .067 r
.34993 .71664 m .34926 .7183 L .35097 .71463 L F
.35097 .71463 m .34926 .7183 L .34993 .71664 L F
.342 .207 .548 r
.35191 .71622 m .35193 .71615 L .35097 .71463 L F
.732 .206 0 r
.35097 .71463 m .35045 .71472 L .35197 .71621 L F
.791 .296 0 r
.35097 .71463 m .35197 .71621 L .35045 .71472 L F
.732 .206 0 r
.35097 .71463 m .35196 .71591 L .35045 .71472 L F
.738 .621 .729 r
.35196 .71591 m .352 .71594 L .3521 .71473 L F
.237 .17 .575 r
.35131 .71516 m .35197 .71621 L .35223 .71466 L F
.35131 .71516 m .35223 .71466 L .35272 .71175 L F
.738 .621 .729 r
.35045 .71472 m .35196 .71591 L .3521 .71473 L F
.237 .17 .575 r
.35241 .71227 m .35236 .71262 L .35272 .71175 L F
.35097 .71463 m .35236 .71262 L .35241 .71227 L F
0 0 .055 r
.35272 .71175 m .35223 .71466 L .35242 .71422 L F
.738 .621 .729 r
.3522 .71473 m .35241 .71473 L .35223 .71466 L F
.3521 .71473 m .35241 .71456 L .35242 .71422 L F
0 0 .055 r
.35223 .71466 m .35197 .71621 L .35242 .71422 L F
.738 .621 .729 r
.35223 .71466 m .35241 .71473 L .35241 .71456 L F
.3521 .71473 m .3522 .71473 L .35223 .71466 L F
.35045 .71472 m .3521 .71473 L .35242 .71422 L F
.35241 .71473 m .35425 .71474 L .35317 .71443 L F
.35241 .71473 m .35317 .71443 L .35242 .71422 L F
.352 .71594 m .35312 .71682 L .35241 .71473 L F
.342 .207 .548 r
.35191 .71622 m .35197 .71621 L .35193 .71615 L F
.506 .534 .819 r
.44584 .66825 m .44761 .66776 L .4447 .66667 L F
.645 .554 .737 r
.44632 .67117 m .44761 .66776 L .44584 .66825 L F
.879 .718 .679 r
.39605 .84465 m .39773 .84626 L .39643 .84318 L F
.44 .862 .946 r
.39443 .8466 m .39773 .84626 L .39605 .84465 L F
.268 0 .206 r
.30459 .63205 m .30548 .63358 L .3066 .63153 L F
.30459 .63205 m .30363 .63433 L .30548 .63358 L F
0 0 .464 r
.57428 .7531 m .57373 .75255 L .57282 .75175 L F
.57428 .7531 m .5749 .75432 L .57373 .75255 L F
.665 .511 .666 r
.54266 .74877 m .5469 .7491 L .54664 .74626 L F
.618 .245 .313 r
.5469 .7491 m .54693 .75036 L .54266 .74877 L F
.665 .511 .666 r
.54266 .74877 m .5469 .7491 L .54664 .74626 L F
.618 .245 .313 r
.5469 .7491 m .54693 .75036 L .54266 .74877 L F
.202 .123 .538 r
.72452 .50354 m .72296 .50716 L .72211 .50412 L F
.72452 .50354 m .72474 .5058 L .72296 .50716 L F
.453 .35 .648 r
.72474 .5058 m .72285 .50894 L .72296 .50716 L F
.539 .171 .291 r
.63733 .55175 m .63839 .55238 L .63711 .553 L F
.63733 .55175 m .63987 .55175 L .63839 .55238 L F
.597 .568 .792 r
.71783 .49785 m .71554 .49877 L .71475 .49696 L F
.619 .485 .677 r
.71859 .50141 m .71554 .49877 L .71783 .49785 L F
.71859 .50141 m .71631 .50222 L .71554 .49877 L F
.557 .606 .858 r
.5769 .72951 m .57855 .73051 L .57848 .73229 L F
0 0 .35 r
.57848 .73229 m .57785 .73118 L .5769 .72951 L F
.97 .905 .552 r
.57716 .73397 m .57785 .73118 L .57848 .73229 L F
.569 .53 .772 r
.48824 .78486 m .49148 .78763 L .49169 .78516 L F
.781 .662 .732 r
.48348 .79023 m .4869 .79069 L .48702 .78943 L F
.981 .747 .51 r
.48553 .79261 m .4869 .79069 L .48348 .79023 L F
.48553 .79261 m .48681 .79328 L .4869 .79069 L F
.524 .909 .939 r
.48905 .78867 m .48702 .78943 L .4869 .79069 L F
.325 0 .025 r
.48204 .74606 m .48423 .74573 L .48549 .74413 L F
.273 0 0 r
.48423 .74573 m .48764 .74378 L .48549 .74413 L F
.523 .269 .472 r
.45476 .6846 m .45201 .6866 L .45228 .68501 L F
.726 .725 .849 r
.64891 .51581 m .65306 .51625 L .65162 .51624 L F
.491 .901 .817 r
.65388 .51526 m .65306 .51625 L .65567 .51461 L F
.58 .233 .346 r
.65143 .51446 m .65388 .51526 L .65307 .5133 L F
.65143 .51446 m .6515 .51516 L .652 .51465 L F
.246 .008 .342 r
.64891 .51581 m .65124 .51618 L .65143 .51446 L F
.65124 .51618 m .65162 .51624 L .65159 .51601 L F
.65124 .51618 m .65159 .51601 L .65143 .51446 L F
.58 .233 .346 r
.652 .51465 m .65159 .51601 L .65388 .51526 L F
.6515 .51516 m .65159 .51601 L .652 .51465 L F
.65159 .51601 m .6521 .51603 L .65388 .51526 L F
.491 .901 .817 r
.65388 .51526 m .6521 .51603 L .65306 .51625 L F
.582 .397 .597 r
.65307 .5133 m .65314 .51592 L .65066 .51603 L F
.549 .699 .939 r
.65144 .516 m .65162 .51599 L .65071 .51597 L F
.65162 .51599 m .6522 .51597 L .65167 .51597 L F
.65162 .51599 m .65167 .51597 L .65071 .51597 L F
.66 .913 .598 r
.65307 .5133 m .65081 .51587 L .65207 .51409 L F
.65081 .51587 m .65066 .51603 L .65071 .51597 L F
.65081 .51587 m .65071 .51597 L .65207 .51409 L F
.58 .233 .346 r
.65159 .51601 m .65162 .51624 L .6521 .51603 L F
.549 .699 .939 r
.65071 .51597 m .6522 .51597 L .65207 .51409 L F
.65066 .51603 m .65144 .516 L .65071 .51597 L F
.6522 .51597 m .65314 .51592 L .65291 .51553 L F
.6522 .51597 m .65291 .51553 L .65207 .51409 L F
.491 .901 .817 r
.6521 .51603 m .65162 .51624 L .65176 .51624 L F
.6521 .51603 m .65176 .51624 L .65306 .51625 L F
.576 .24 .363 r
.51804 .73553 m .5205 .736 L .51594 .73611 L F
.423 .163 .412 r
.51695 .73935 m .51594 .73611 L .51871 .73605 L F
.51955 .7369 m .51871 .73605 L .5205 .736 L F
.51695 .73935 m .51871 .73605 L .51955 .7369 L F
.443 .078 .249 r
.51757 .73925 m .51695 .73935 L .51955 .7369 L F
.51981 .73677 m .51955 .7369 L .5205 .736 L F
.51757 .73925 m .51955 .7369 L .51981 .73677 L F
.575 .236 .357 r
.51804 .73553 m .51981 .73677 L .5205 .736 L F
.51981 .73677 m .52023 .73707 L .5205 .736 L F
.554 .251 .409 r
.52039 .73649 m .52023 .73707 L .51981 .73677 L F
.443 .078 .249 r
.5193 .73897 m .51757 .73925 L .5205 .736 L F
.554 .251 .409 r
.52073 .73523 m .52039 .73649 L .51857 .73591 L F
.52039 .73649 m .51981 .73677 L .51857 .73591 L F
.51819 .73551 m .51857 .73591 L .51804 .73553 L F
.52073 .73523 m .51857 .73591 L .51819 .73551 L F
.621 .487 .678 r
.52024 .7322 m .52073 .73523 L .51804 .73553 L F
.558 .33 .526 r
.43879 .69236 m .43653 .69459 L .43655 .69266 L F
0 .386 .816 r
.66144 .50532 m .66259 .50534 L .66045 .50469 L F
.928 .619 .436 r
.63205 .53394 m .63249 .53652 L .63368 .53504 L F
.652 .583 .765 r
.63368 .53504 m .63549 .52979 L .63205 .53394 L F
.63368 .53504 m .63618 .53446 L .63549 .52979 L F
.787 .397 .317 r
.63368 .53504 m .63362 .53649 L .63618 .53446 L F
.63368 .53504 m .63249 .53652 L .63362 .53649 L F
.109 .494 .903 r
.75325 .61833 m .75519 .61832 L .75228 .61746 L F
.75325 .61833 m .75612 .61957 L .75519 .61832 L F
.719 .386 .415 r
.62912 .52969 m .62962 .53159 L .63002 .52968 L F
.538 .857 .997 r
.62912 .52969 m .63002 .52968 L .63244 .52937 L F
.273 0 .286 r
.63002 .52968 m .63162 .53014 L .63244 .52937 L F
.63002 .52968 m .62962 .53159 L .63162 .53014 L F
.565 .447 .677 r
.53292 .7698 m .5368 .77104 L .53809 .76947 L F
.53292 .7698 m .53453 .77179 L .5368 .77104 L F
.299 0 0 r
.31613 .60435 m .31585 .60434 L .31432 .60383 L F
.31613 .60435 m .31772 .605 L .31585 .60434 L F
.683 .698 .858 r
.7781 .60173 m .77618 .60388 L .77479 .60099 L F
.586 .544 .774 r
.7781 .60173 m .77875 .60453 L .77618 .60388 L F
.516 .478 .752 r
.77907 .60665 m .77618 .60388 L .77875 .60453 L F
.622 .682 .886 r
.73737 .61534 m .73848 .61783 L .74094 .61733 L F
.623 .646 .852 r
.73848 .61783 m .74191 .61902 L .74094 .61733 L F
.395 .188 .478 r
.6931 .51905 m .6914 .521 L .69344 .5202 L F
.332 0 .056 r
.6914 .521 m .69311 .52199 L .69344 .5202 L F
.6914 .521 m .69059 .52254 L .69311 .52199 L F
.414 .656 .959 r
.71899 .60706 m .71978 .60649 L .71534 .60542 L F
.369 .563 .911 r
.72026 .6058 m .71978 .60649 L .71899 .60706 L F
.364 .555 .906 r
.71899 .60706 m .72076 .60743 L .72026 .6058 L F
.452 .504 .822 r
.48111 .77587 m .48189 .77315 L .48152 .77593 L F
.252 0 .191 r
.71306 .5932 m .71118 .59461 L .71322 .59549 L F
.59 .365 .543 r
.71369 .5976 m .71118 .59461 L .71034 .5979 L F
.701 .62 .763 r
.69806 .49883 m .69579 .49969 L .69455 .4963 L F
.581 .505 .733 r
.71859 .50141 m .71673 .50391 L .71631 .50222 L F
.71859 .50141 m .71905 .50303 L .71673 .50391 L F
.623 .651 .858 r
.71905 .50303 m .71976 .50486 L .71673 .50391 L F
.227 0 .261 r
.31358 .62351 m .31598 .62074 L .31381 .6212 L F
.586 .731 .943 r
.35494 .70677 m .35316 .70758 L .3499 .70525 L F
.711 .633 .769 r
.35494 .70677 m .35263 .70967 L .35316 .70758 L F
.511 .488 .767 r
.64402 .51791 m .64765 .52023 L .6482 .51832 L F
.227 .355 .786 r
.31026 .60369 m .31015 .60475 L .31092 .60302 L F
.494 .675 .946 r
.31015 .60475 m .31242 .60466 L .31092 .60302 L F
.317 0 .195 r
.47182 .75163 m .47391 .75102 L .47485 .74885 L F
.358 0 .214 r
.47485 .74885 m .47592 .75056 L .47709 .7485 L F
.47485 .74885 m .47391 .75102 L .47592 .75056 L F
.772 .613 .683 r
.52176 .7517 m .52547 .75324 L .52441 .75135 L F
.52176 .7517 m .52167 .75423 L .52547 .75324 L F
.721 .403 .44 r
.52128 .75598 m .52547 .75324 L .52167 .75423 L F
.52128 .75598 m .524 .75637 L .52547 .75324 L F
.151 .054 .482 r
.52547 .75324 m .52683 .75081 L .52441 .75135 L F
.52547 .75324 m .52647 .7532 L .52683 .75081 L F
.575 .325 .499 r
.524 .75637 m .52647 .7532 L .52547 .75324 L F
.605 .607 .827 r
.6353 .492 m .63869 .49314 L .6385 .4916 L F
.215 0 .327 r
.50087 .78158 m .49961 .78193 L .50152 .77945 L F
.268 .764 .899 r
.33051 .59405 m .33284 .59377 L .33364 .59398 L F
.21 .603 .949 r
.33496 .59344 m .33364 .59398 L .33284 .59377 L F
.33496 .59344 m .33637 .59463 L .33364 .59398 L F
.554 .239 .388 r
.56776 .76556 m .56697 .76864 L .56492 .76807 L F
.002 0 0 r
.5704 .76578 m .56697 .76864 L .56776 .76556 L F
.939 .715 .572 r
.61622 .74866 m .61662 .74632 L .61485 .74543 L F
.587 .493 .715 r
.3229 .61007 m .32516 .60978 L .32449 .60736 L F
.42 .165 .418 r
.32278 .61227 m .32516 .60978 L .3229 .61007 L F
.238 .399 .822 r
.67593 .49643 m .67584 .49402 L .67229 .49351 L F
.365 0 .04 r
.39856 .66788 m .39494 .6698 L .39652 .66852 L F
.408 .821 .974 r
.27619 .63869 m .27858 .63825 L .27992 .6387 L F
.374 .71 .986 r
.28058 .63757 m .27992 .6387 L .27858 .63825 L F
.28058 .63757 m .28224 .63876 L .27992 .6387 L F
.297 .742 .962 r
.26764 .58487 m .26976 .58479 L .27121 .58536 L F
.388 .803 .977 r
.2717 .58462 m .27121 .58536 L .26976 .58479 L F
.2717 .58462 m .27321 .58504 L .27121 .58536 L F
.425 .174 .428 r
.3394 .62106 m .34142 .61767 L .34108 .62041 L F
.41 .19 .467 r
.34142 .61767 m .34395 .61495 L .34366 .61771 L F
.375 .104 .37 r
.34108 .62041 m .34142 .61767 L .34366 .61771 L F
.465 .162 .367 r
.48764 .74378 m .48991 .74342 L .48874 .74211 L F
.43 .118 .333 r
.48874 .74211 m .49296 .74 L .49077 .74059 L F
.48874 .74211 m .49202 .74272 L .49296 .74 L F
.431 .159 .399 r
.48874 .74211 m .48991 .74342 L .49202 .74272 L F
.299 .794 .857 r
.27091 .63938 m .27272 .63892 L .2743 .6389 L F
.279 .781 .849 r
.2743 .6389 m .27472 .63851 L .27619 .63869 L F
.2743 .6389 m .27272 .63892 L .27472 .63851 L F
.32 .019 .287 r
.74922 .58763 m .7511 .58696 L .75182 .5852 L F
.021 0 .018 r
.7511 .58696 m .75382 .5842 L .75182 .5852 L F
.669 .686 .857 r
.74191 .61902 m .74307 .61678 L .74094 .61733 L F
.74191 .61902 m .74417 .61811 L .74307 .61678 L F
.883 .62 .535 r
.59911 .55999 m .59904 .56226 L .59683 .55886 L F
.893 .829 .777 r
.65787 .49346 m .65652 .49286 L .65844 .49015 L F
.575 .682 .913 r
.75008 .60825 m .74849 .61025 L .74785 .60851 L F
.75008 .60825 m .75093 .60993 L .74849 .61025 L F
.613 .57 .782 r
.73812 .60446 m .73599 .60534 L .73475 .60157 L F
.349 .612 .948 r
.5084 .76135 m .50919 .76293 L .51026 .76146 L F
.604 .868 .529 r
.51026 .76146 m .50919 .76293 L .50793 .76418 L F
.988 .72 .397 r
.50919 .76293 m .50921 .76513 L .50793 .76418 L F
0 0 0 r
.51619 .76538 m .51428 .76817 L .51253 .7655 L F
.51619 .76538 m .51486 .76763 L .51428 .76817 L F
.627 .254 .317 r
.51864 .76747 m .51619 .76538 L .51843 .76522 L F
.51864 .76747 m .51486 .76763 L .51619 .76538 L F
.804 .587 .608 r
.60287 .54886 m .60547 .55169 L .60223 .5511 L F
.796 .688 .746 r
.60223 .5511 m .60547 .55169 L .60401 .55435 L F
.327 0 .076 r
.53105 .8057 m .53033 .80419 L .52902 .80639 L F
.53105 .8057 m .53249 .80369 L .53033 .80419 L F
.547 .508 .764 r
.50645 .76383 m .50476 .76642 L .50375 .76463 L F
.50645 .76383 m .50706 .76567 L .50476 .76642 L F
.214 0 0 r
.403 .71078 m .40248 .7097 L .40475 .70933 L F
.403 .71078 m .40077 .71127 L .40248 .7097 L F
.367 .051 .292 r
.27056 .61261 m .27024 .61474 L .26828 .61526 L F
.3 0 .274 r
.27208 .61398 m .27056 .61261 L .27259 .6119 L F
.27208 .61398 m .27024 .61474 L .27056 .61261 L F
.514 .387 .645 r
.45503 .76523 m .45683 .76244 L .45472 .76282 L F
.249 .012 .346 r
.51594 .73611 m .5151 .73992 L .51356 .73981 L F
.423 .163 .412 r
.51695 .73935 m .5151 .73992 L .51594 .73611 L F
.91 .703 .609 r
.59864 .70699 m .59839 .70963 L .60017 .70977 L F
.893 .516 .314 r
.59878 .7101 m .60017 .70977 L .59839 .70963 L F
.59878 .7101 m .60108 .71231 L .60017 .70977 L F
.645 .664 .854 r
.72211 .50412 m .71976 .50486 L .71905 .50303 L F
.741 .449 .486 r
.71916 .59503 m .7193 .59329 L .71529 .59296 L F
.44 0 .014 r
.2817 .60665 m .2798 .60806 L .27827 .60739 L F
0 0 0 r
.28286 .60668 m .2817 .60665 L .28357 .60624 L F
.28286 .60668 m .2798 .60806 L .2817 .60665 L F
.657 .692 .871 r
.69032 .5063 m .69173 .509 L .69379 .50701 L F
.872 .971 .657 r
.35583 .71226 m .35425 .71474 L .35434 .7154 L F
.876 .962 .629 r
.35425 .71474 m .35312 .71682 L .35434 .7154 L F
.912 .657 .538 r
.35312 .71682 m .35522 .71817 L .35434 .7154 L F
.77 .357 .267 r
.52341 .8058 m .52485 .80443 L .52202 .80378 L F
.592 .069 0 r
.52565 .80607 m .52485 .80443 L .52341 .8058 L F
.734 .335 .295 r
.49949 .80318 m .50174 .80153 L .49841 .80128 L F
.721 .316 .282 r
.50307 .80368 m .50174 .80153 L .49949 .80318 L F
.361 .79 .97 r
.33154 .83511 m .3301 .83463 L .32798 .83488 L F
.33154 .83511 m .3301 .83463 L .32798 .83488 L F
.702 .821 .938 r
.70926 .49794 m .70604 .4978 L .70868 .49583 L F
.713 .811 .926 r
.71183 .49635 m .70926 .49794 L .70868 .49583 L F
.556 .579 .832 r
.50247 .76182 m .50151 .76469 L .5001 .76231 L F
.50247 .76182 m .50375 .76463 L .50151 .76469 L F
.3 0 0 r
.30069 .63603 m .29946 .63547 L .29867 .63639 L F
.30069 .63603 m .30173 .63511 L .29946 .63547 L F
.166 .335 .789 r
.58307 .74301 m .5843 .74588 L .58537 .74493 L F
.236 .456 .87 r
.5843 .74588 m .5859 .74636 L .58537 .74493 L F
.649 .386 .507 r
.51495 .77374 m .51155 .77643 L .51203 .7743 L F
.439 .087 .27 r
.4203 .69222 m .4235 .68948 L .42131 .69007 L F
.65 .602 .788 r
.74171 .60705 m .73963 .60815 L .73812 .60446 L F
.826 .827 .849 r
.5997 .55625 m .60217 .55345 L .60193 .55657 L F
.848 .845 .841 r
.60217 .55345 m .60401 .55435 L .60193 .55657 L F
.452 .281 .557 r
.38571 .67617 m .38367 .67911 L .38364 .67676 L F
.652 .707 .887 r
.27091 .63938 m .26862 .64021 L .26683 .63775 L F
.484 .39 .674 r
.3565 .67127 m .35838 .67092 L .35808 .66772 L F
.484 .39 .673 r
.3565 .67127 m .35878 .67318 L .35838 .67092 L F
.506 .39 .654 r
.3565 .67127 m .35682 .67374 L .35878 .67318 L F
.876 .572 .468 r
.617 .73784 m .61425 .73526 L .61369 .73745 L F
.819 .583 .582 r
.61382 .73991 m .617 .73784 L .61369 .73745 L F
.61382 .73991 m .61702 .74009 L .617 .73784 L F
0 0 0 r
.36272 .71304 m .36441 .70998 L .36182 .71025 L F
.36272 .71304 m .36339 .71208 L .36441 .70998 L F
.391 .733 .991 r
.36272 .71304 m .36482 .71287 L .36339 .71208 L F
.499 .178 .354 r
.5298 .74797 m .53183 .74607 L .52963 .74559 L F
.23 0 .033 r
.24549 .59012 m .24801 .58894 L .24853 .588 L F
.446 .019 .133 r
.24801 .58894 m .25075 .58788 L .24853 .588 L F
.257 .728 .943 r
.41763 .64917 m .4199 .64912 L .42121 .64964 L F
.173 .689 .89 r
.4199 .64912 m .42333 .64948 L .42121 .64964 L F
.57 .263 .409 r
.50163 .75217 m .50361 .75371 L .50375 .75169 L F
.50163 .75217 m .50111 .75396 L .50361 .75371 L F
.15 0 .357 r
.26325 .62041 m .26151 .62354 L .262 .62131 L F
0 .309 .767 r
.49613 .7665 m .49724 .76721 L .49786 .76735 L F
.579 .303 .461 r
.4683 .67951 m .46808 .68149 L .46568 .68172 L F
.593 .314 .464 r
.4683 .67951 m .47046 .68139 L .46808 .68149 L F
.643 .295 .366 r
.47101 .67989 m .47046 .68139 L .4683 .67951 L F
.619 .624 .834 r
.67956 .50474 m .67637 .50598 L .6761 .5041 L F
.509 .322 .563 r
.67956 .50474 m .67912 .50669 L .67637 .50598 L F
.614 .513 .716 r
.36182 .71025 m .36383 .70701 L .36154 .70763 L F
.36182 .71025 m .36441 .70998 L .36383 .70701 L F
.408 .767 .995 r
.30075 .5909 m .30272 .59067 L .30415 .59152 L F
.334 .726 .983 r
.305 .59057 m .30415 .59152 L .30272 .59067 L F
.305 .59057 m .30657 .59143 L .30415 .59152 L F
.547 .364 .584 r
.35982 .66 m .35753 .66287 L .35976 .66241 L F
.49 .379 .655 r
.35753 .66287 m .35979 .66479 L .35976 .66241 L F
.35753 .66287 m .35784 .66525 L .35979 .66479 L F
.402 .185 .466 r
.26768 .61717 m .26617 .61561 L .26828 .61526 L F
.26768 .61717 m .26585 .61797 L .26617 .61561 L F
.796 .688 .746 r
.60223 .5511 m .60401 .55435 L .60217 .55345 L F
.47 .727 .982 r
.34706 .59777 m .34648 .5993 L .34506 .59807 L F
.34706 .59777 m .34836 .5994 L .34648 .5993 L F
0 0 0 r
.55272 .78131 m .55407 .77966 L .55501 .7788 L F
.529 .449 .71 r
.35489 .67653 m .35735 .6793 L .35675 .67596 L F
.35489 .67653 m .35538 .67966 L .35735 .6793 L F
.139 .612 .923 r
.56092 .71783 m .56316 .71839 L .56021 .71735 L F
.308 .015 .293 r
.32312 .63775 m .32191 .63996 L .3204 .64043 L F
.374 .085 .34 r
.32511 .637 m .32191 .63996 L .32312 .63775 L F
.702 .667 .813 r
.44175 .66592 m .4447 .66667 L .44423 .6658 L F
.45 .555 .871 r
.4447 .66667 m .44632 .66488 L .44423 .6658 L F
.4447 .66667 m .44761 .66776 L .44632 .66488 L F
.427 .052 .223 r
.42114 .70226 m .42059 .70355 L .41832 .70392 L F
.51 .157 .304 r
.42342 .70196 m .42059 .70355 L .42114 .70226 L F
.109 .66 .806 r
.29154 .65211 m .29007 .65199 L .28785 .65207 L F
.315 .8 .886 r
.29366 .65162 m .29007 .65199 L .29154 .65211 L F
.758 .521 .574 r
.50112 .80423 m .5045 .80455 L .50421 .80697 L F
.485 .279 .524 r
.50421 .80697 m .5045 .80455 L .50626 .80371 L F
.874 .708 .672 r
.54581 .77596 m .55013 .77709 L .54962 .77366 L F
.699 .324 .334 r
.54583 .77883 m .55013 .77709 L .54581 .77596 L F
.693 .586 .73 r
.55307 .77423 m .55057 .7769 L .55034 .77613 L F
.55084 .77386 m .55034 .77613 L .54962 .77366 L F
.55307 .77423 m .55034 .77613 L .55084 .77386 L F
.55307 .77423 m .54962 .77366 L .55125 .773 L F
.194 0 .272 r
.55013 .77709 m .55147 .77858 L .5511 .77678 L F
.861 .537 .018 r
.55138 .77835 m .5511 .77678 L .55147 .77858 L F
0 0 .366 r
.55014 .77705 m .5511 .77678 L .55075 .77483 L F
.55013 .77709 m .5511 .77678 L .55014 .77705 L F
.55013 .77709 m .55125 .773 L .54962 .77366 L F
.861 .537 .018 r
.54995 .77485 m .5511 .77678 L .55138 .77835 L F
0 0 .366 r
.55075 .77483 m .5511 .77678 L .55125 .773 L F
.55013 .77709 m .55013 .77709 L .55014 .77705 L F
.406 .076 .289 r
.70066 .52374 m .70016 .5259 L .69786 .52641 L F
.376 0 .165 r
.70313 .52368 m .70016 .5259 L .70066 .52374 L F
.655 .659 .842 r
.47481 .67372 m .4741 .67649 L .4727 .67394 L F
.47481 .67372 m .4764 .67696 L .4741 .67649 L F
.552 .337 .542 r
.47623 .67825 m .4741 .67649 L .4764 .67696 L F
.47623 .67825 m .47363 .67874 L .4741 .67649 L F
.75 .591 .679 r
.63469 .52953 m .63717 .52638 L .6347 .52661 L F
.63469 .52953 m .63813 .52981 L .63717 .52638 L F
.666 .537 .698 r
.63717 .52638 m .64078 .52674 L .64064 .52452 L F
.665 .541 .703 r
.63717 .52638 m .63813 .52981 L .64078 .52674 L F
.335 .538 .903 r
.5859 .74636 m .58778 .74884 L .58874 .74749 L F
.38 .601 .934 r
.58778 .74884 m .5894 .74869 L .58874 .74749 L F
.596 .565 .79 r
.58778 .74884 m .59132 .75189 L .5894 .74869 L F
.567 .404 .62 r
.54341 .75589 m .54331 .76002 L .54104 .76025 L F
.639 .445 .605 r
.54578 .75442 m .54714 .75665 L .54341 .75589 L F
.589 .422 .623 r
.54649 .75925 m .54331 .76002 L .54341 .75589 L F
.552 .489 .739 r
.35595 .68209 m .35735 .6793 L .35538 .67966 L F
.35595 .68209 m .35812 .68184 L .35735 .6793 L F
.383 .262 .589 r
.35642 .68515 m .35812 .68184 L .35595 .68209 L F
.647 .15 .056 r
.575 .71767 m .5784 .71969 L .5781 .71808 L F
.751 .383 .356 r
.5784 .71969 m .5804 .71787 L .5781 .71808 L F
.112 0 0 r
.64593 .53027 m .64636 .52959 L .64413 .53011 L F
.558 .691 .929 r
.77006 .5811 m .76853 .58302 L .76767 .5815 L F
.77006 .5811 m .77109 .58273 L .76853 .58302 L F
.538 .857 .997 r
.62912 .52969 m .63244 .52937 L .63126 .52622 L F
.741 .64 .748 r
.63126 .52622 m .63244 .52937 L .6347 .52661 L F
.286 0 0 r
.63162 .53014 m .63469 .52953 L .63244 .52937 L F
.62 .464 .648 r
.63244 .52937 m .63469 .52953 L .6347 .52661 L F
.392 .167 .45 r
.3204 .64043 m .31983 .64261 L .31831 .64304 L F
.149 0 0 r
.3191 .644 m .31831 .64304 L .31983 .64261 L F
.3191 .644 m .31707 .64489 L .31831 .64304 L F
.606 .952 .823 r
.2663 .65642 m .26932 .65465 L .26855 .65676 L F
.206 0 .305 r
.26855 .65676 m .26932 .65465 L .27074 .65377 L F
.76 .436 .437 r
.58975 .68773 m .5879 .68973 L .5896 .68615 L F
.58975 .68773 m .59114 .69118 L .5879 .68973 L F
.364 .34 .699 r
.54578 .75442 m .54785 .75661 L .54714 .75665 L F
.611 .644 .858 r
.47698 .67314 m .4764 .67696 L .47481 .67372 L F
.47698 .67314 m .47879 .67683 L .4764 .67696 L F
.622 .216 .253 r
.4764 .67696 m .47837 .67855 L .47623 .67825 L F
.563 .252 .399 r
.47879 .67683 m .47837 .67855 L .4764 .67696 L F
.996 .784 .5 r
.63302 .49715 m .63402 .49778 L .63088 .49605 L F
.63318 .49723 m .63318 .49724 L .63302 .49715 L F
.39 0 .081 r
.63088 .49605 m .63237 .49724 L .63318 .49723 L F
.243 .758 .825 r
.63237 .49724 m .63316 .49713 L .63318 .49723 L F
.63316 .49713 m .63568 .49678 L .63318 .49723 L F
.996 .784 .5 r
.63318 .49723 m .63327 .49729 L .63318 .49724 L F
.63327 .49729 m .63402 .49778 L .63302 .49715 L F
.592 .691 .911 r
.632 .4944 m .63125 .49614 L .62909 .49487 L F
.63125 .49614 m .63088 .497 L .62917 .49496 L F
.63125 .49614 m .62917 .49496 L .62909 .49487 L F
.763 .333 .228 r
.72132 .59739 m .72227 .59583 L .71916 .59503 L F
.473 .052 .158 r
.72395 .59736 m .72227 .59583 L .72132 .59739 L F
.72395 .59736 m .72454 .59599 L .72227 .59583 L F
.533 .282 .48 r
.53183 .74607 m .53417 .74573 L .53453 .74358 L F
.437 .198 .452 r
.53453 .74358 m .53417 .74573 L .53622 .74519 L F
0 .029 .582 r
.47478 .78237 m .47392 .78158 L .47272 .77999 L F
.17 0 0 r
.74975 .59266 m .75285 .59035 L .75185 .59179 L F
.173 0 0 r
.75285 .59035 m .75329 .59087 L .75185 .59179 L F
.75285 .59035 m .75525 .59026 L .75329 .59087 L F
.478 .102 .247 r
.42841 .68716 m .43069 .68697 L .43186 .68484 L F
.505 .13 .262 r
.43069 .68697 m .43417 .68473 L .43186 .68484 L F
.798 .664 .715 r
.54934 .75951 m .55035 .76242 L .54712 .76261 L F
.603 .134 .113 r
.55035 .76242 m .54947 .76323 L .54712 .76261 L F
.986 .76 .514 r
.55035 .76242 m .55027 .76531 L .54947 .76323 L F
.228 0 0 r
.74603 .58943 m .7484 .58888 L .74922 .58763 L F
.245 0 0 r
.7484 .58888 m .7511 .58696 L .74922 .58763 L F
.442 0 0 r
.39159 .64952 m .39353 .65018 L .39504 .64916 L F
.543 .073 .087 r
.39353 .65018 m .39713 .64922 L .39504 .64916 L F
.613 .684 .893 r
.74644 .60613 m .74514 .60913 L .74408 .60666 L F
.74644 .60613 m .74785 .60851 L .74514 .60913 L F
.545 .353 .571 r
.45638 .75966 m .45862 .75701 L .45643 .75727 L F
.833 .929 .895 r
.63504 .51539 m .6328 .51715 L .63336 .51417 L F
.545 .43 .673 r
.63504 .51539 m .63784 .51481 L .6365 .51414 L F
.447 .215 .469 r
.63667 .51488 m .63504 .51539 L .6365 .51414 L F
.562 .856 .997 r
.63557 .51528 m .63749 .51462 L .63784 .51481 L F
.63504 .51539 m .63667 .51488 L .63557 .51528 L F
.63667 .51488 m .63749 .51462 L .63557 .51528 L F
.369 .196 .512 r
.63894 .51576 m .63718 .51715 L .63667 .51488 L F
.63727 .51465 m .63667 .51488 L .6365 .51414 L F
.63894 .51576 m .63667 .51488 L .63727 .51465 L F
.447 .215 .469 r
.63718 .51715 m .63504 .51539 L .63667 .51488 L F
.443 .472 .794 r
.6365 .51414 m .63784 .51481 L .63924 .51395 L F
.573 .827 .993 r
.63784 .51481 m .63746 .5146 L .63924 .51395 L F
.369 .196 .512 r
.63883 .5141 m .6365 .51414 L .63924 .51395 L F
.63727 .51465 m .6365 .51414 L .63922 .51409 L F
.573 .827 .993 r
.63746 .5146 m .63578 .51366 L .63924 .51395 L F
.369 .196 .512 r
.63922 .51409 m .63883 .5141 L .63924 .51395 L F
.63894 .51576 m .63727 .51465 L .63922 .51409 L F
.562 .856 .997 r
.63504 .51539 m .63508 .51528 L .63749 .51462 L F
.63508 .51528 m .63578 .51366 L .63746 .5146 L F
.63508 .51528 m .63746 .5146 L .63749 .51462 L F
.63504 .51539 m .63336 .51417 L .63578 .51366 L F
.447 .215 .469 r
.63718 .51715 m .63493 .51772 L .63504 .51539 L F
.715 .322 .304 r
.52253 .80706 m .52119 .80893 L .52107 .80718 L F
.52253 .80706 m .52457 .80911 L .52119 .80893 L F
.709 .727 .864 r
.60249 .75115 m .60129 .74853 L .59817 .75151 L F
.588 .602 .833 r
.60249 .75115 m .60387 .74819 L .60129 .74853 L F
.60249 .75115 m .60489 .75041 L .60387 .74819 L F
.649 .499 .666 r
.54834 .74744 m .54664 .74626 L .54974 .74559 L F
.54834 .74744 m .5469 .7491 L .54664 .74626 L F
.669 .528 .684 r
.5469 .7491 m .54702 .74918 L .54834 .74744 L F
.54702 .74918 m .54957 .7507 L .54974 .74559 L F
.429 .341 .655 r
.55158 .74809 m .55013 .74869 L .54974 .74559 L F
.454 .349 .645 r
.54974 .74559 m .54973 .74583 L .55158 .74809 L F
.649 .499 .666 r
.55013 .74869 m .54988 .74851 L .54974 .74559 L F
.454 .349 .645 r
.54989 .74884 m .54957 .7507 L .54996 .75019 L F
.54989 .74863 m .54996 .75019 L .54997 .75018 L F
.54988 .74851 m .54988 .74863 L .54989 .74863 L F
.54988 .74863 m .54996 .75019 L .54989 .74863 L F
.54986 .74883 m .54957 .7507 L .54989 .74884 L F
.54964 .74862 m .54957 .7507 L .54988 .74872 L F
.54973 .74583 m .54996 .75019 L .54988 .74851 L F
.661 .38 .483 r
.55013 .74869 m .55008 .74886 L .54999 .74876 L F
.465 .187 .407 r
.55027 .74889 m .55008 .74886 L .55013 .74869 L F
.661 .38 .483 r
.55013 .74869 m .54999 .74876 L .54989 .74872 L F
.649 .499 .666 r
.55013 .74869 m .54989 .74872 L .54988 .74851 L F
.465 .187 .407 r
.55027 .74889 m .55013 .74869 L .55158 .74809 L F
.454 .349 .645 r
.54973 .74583 m .54991 .74911 L .55158 .74809 L F
.54991 .74911 m .54997 .75018 L .55158 .74809 L F
.036 0 .373 r
.55012 .75159 m .55122 .74896 L .54957 .7507 L F
.55122 .74896 m .55158 .74809 L .55089 .74898 L F
.55122 .74896 m .55089 .74898 L .54957 .7507 L F
.807 .516 .497 r
.54693 .75036 m .55012 .75159 L .54957 .7507 L F
.584 .01 0 r
.54693 .75036 m .54922 .75162 L .55012 .75159 L F
.036 0 .373 r
.55012 .75159 m .55149 .75077 L .55158 .74809 L F
.465 .187 .407 r
.55149 .75077 m .54922 .75162 L .55002 .74904 L F
.5502 .74903 m .55002 .74904 L .55008 .74886 L F
.55149 .75077 m .55002 .74904 L .5502 .74903 L F
.55149 .75077 m .55027 .74889 L .55158 .74809 L F
.807 .516 .497 r
.54693 .75036 m .54957 .7507 L .5469 .7491 L F
.661 .38 .483 r
.54999 .74876 m .54922 .75162 L .54693 .75036 L F
.55008 .74886 m .54922 .75162 L .54999 .74876 L F
.465 .187 .407 r
.55149 .75077 m .55008 .74886 L .55027 .74889 L F
.454 .349 .645 r
.54988 .74872 m .54986 .74883 L .54989 .74884 L F
.54973 .74583 m .54964 .74862 L .54988 .74872 L F
.661 .38 .483 r
.54989 .74872 m .54693 .75036 L .5469 .7491 L F
.54999 .74876 m .54693 .75036 L .54989 .74872 L F
.649 .499 .666 r
.54988 .74851 m .54834 .74744 L .54974 .74559 L F
.54988 .74851 m .5469 .7491 L .54834 .74744 L F
.54989 .74872 m .5469 .7491 L .54988 .74851 L F
.669 .528 .684 r
.5469 .7491 m .54834 .74744 L .54974 .74559 L F
.5469 .7491 m .54974 .74559 L .54664 .74626 L F
.44 0 0 r
.43054 .65021 m .43467 .65088 L .43624 .65062 L F
.042 0 0 r
.43467 .65088 m .4381 .65022 L .43624 .65062 L F
.439 .256 .534 r
.49802 .73535 m .49991 .73475 L .49998 .73219 L F
.365 .092 .36 r
.49802 .73535 m .49746 .73727 L .49991 .73475 L F
.501 .296 .533 r
.25818 .6322 m .25792 .63459 L .2559 .63499 L F
.544 .446 .694 r
.2559 .63499 m .25792 .63459 L .25594 .63524 L F
.603 .892 .593 r
.76781 .62049 m .76504 .62315 L .76514 .62321 L F
.775 .308 0 r
.5667 .71408 m .5659 .71214 L .56431 .71231 L F
.472 .792 .999 r
.56543 .71324 m .56568 .71321 L .5667 .71408 L F
.775 .308 0 r
.5667 .71408 m .56773 .71496 L .5659 .71214 L F
.472 .792 .999 r
.56568 .71321 m .56777 .71294 L .5667 .71408 L F
.775 .308 0 r
.5667 .71408 m .56776 .715 L .56773 .71496 L F
.358 .479 .845 r
.72459 .60964 m .72605 .61241 L .72762 .61126 L F
.72605 .61241 m .72803 .61346 L .72762 .61126 L F
.683 .859 .455 r
.6328 .51715 m .63317 .51622 L .63336 .51417 L F
.802 .515 .504 r
.50808 .73107 m .51083 .73185 L .51168 .72988 L F
.38 .495 .85 r
.50964 .72661 m .51168 .72988 L .51265 .7284 L F
.504 .19 .367 r
.51168 .72988 m .51083 .73185 L .51317 .73141 L F
.482 .54 .84 r
.4643 .6545 m .46338 .65732 L .46204 .65456 L F
.4643 .6545 m .46563 .65743 L .46338 .65732 L F
.578 .551 .788 r
.46675 .66015 m .46338 .65732 L .46563 .65743 L F
.512 .335 .578 r
.35976 .66241 m .36183 .66193 L .35982 .66 L F
.571 .333 .516 r
.36183 .66193 m .36213 .65971 L .35982 .66 L F
.463 .216 .454 r
.4696 .75189 m .47137 .75354 L .47182 .75163 L F
.4696 .75189 m .46927 .75402 L .47137 .75354 L F
.48 .25 .487 r
.26039 .63173 m .25792 .63459 L .25818 .6322 L F
.48 .408 .699 r
.49004 .77288 m .4877 .77084 L .49137 .77097 L F
.34 0 0 r
.493 .77186 m .49004 .77288 L .49137 .77097 L F
0 0 .07 r
.66873 .50334 m .6675 .50437 L .66947 .50091 L F
0 0 .362 r
.6688 .50468 m .6675 .50437 L .66873 .50334 L F
.6688 .50468 m .6675 .50665 L .6675 .50437 L F
.682 .813 .946 r
.62562 .5287 m .62912 .52969 L .62767 .52787 L F
.652 .346 .44 r
.62694 .53166 m .62912 .52969 L .62562 .5287 L F
.62694 .53166 m .62962 .53159 L .62912 .52969 L F
.87 .859 .827 r
.62767 .52787 m .62912 .52969 L .63126 .52622 L F
.738 .485 .548 r
.68083 .53146 m .67835 .5336 L .67932 .53175 L F
.572 .431 .651 r
.54331 .76002 m .54319 .76215 L .54104 .76025 L F
.317 .622 .958 r
.67385 .48451 m .67224 .48448 L .67081 .48295 L F
.701 .62 .763 r
.69806 .49883 m .69455 .4963 L .69686 .49563 L F
.642 .618 .811 r
.70045 .49817 m .69806 .49883 L .69686 .49563 L F
0 0 0 r
.64202 .55114 m .64531 .54887 L .64402 .55029 L F
.263 0 .155 r
.64402 .55029 m .64531 .54887 L .64735 .54799 L F
.42 .074 .27 r
.48236 .78295 m .47864 .78567 L .48113 .7845 L F
.624 .454 .633 r
.71306 .5932 m .71529 .59296 L .71619 .59092 L F
.614 .411 .584 r
.71322 .59549 m .71529 .59296 L .71306 .5932 L F
.748 .684 .79 r
.7006 .51221 m .70397 .5127 L .7029 .50946 L F
.425 .299 .605 r
.7006 .51221 m .70277 .51372 L .70397 .5127 L F
.671 .641 .812 r
.7029 .50946 m .70397 .5127 L .70667 .509 L F
.525 .275 .478 r
.70277 .51372 m .70667 .509 L .70397 .5127 L F
.624 .786 .959 r
.54989 .73744 m .54775 .73816 L .5466 .73695 L F
.45 .179 .41 r
.6955 .52694 m .69529 .52871 L .69302 .52929 L F
.461 .18 .401 r
.69786 .52641 m .69529 .52871 L .6955 .52694 L F
.4 .015 .188 r
.40477 .69869 m .40699 .69831 L .40819 .69614 L F
.364 0 .169 r
.40819 .69614 m .40914 .69784 L .41046 .69608 L F
.40819 .69614 m .40699 .69831 L .40914 .69784 L F
.202 0 .249 r
.34878 .60984 m .35111 .60713 L .35062 .60932 L F
.456 .231 .483 r
.34871 .6113 m .34878 .60984 L .35062 .60932 L F
.249 0 .323 r
.72127 .5148 m .71902 .51765 L .7195 .51582 L F
.451 .479 .797 r
.39212 .69483 m .39084 .69725 L .38949 .69359 L F
.468 .453 .759 r
.77479 .60099 m .77273 .60099 L .77252 .59876 L F
.532 .598 .865 r
.45771 .65 m .45642 .65221 L .4553 .65037 L F
.45771 .65 m .45841 .65206 L .45642 .65221 L F
.618 .579 .789 r
.45985 .65483 m .45642 .65221 L .45841 .65206 L F
.476 .25 .491 r
.35062 .60932 m .35111 .60713 L .35315 .60653 L F
.82 .684 .714 r
.60116 .54566 m .60287 .54886 L .60072 .54799 L F
.889 .674 .606 r
.60072 .54799 m .60287 .54886 L .60223 .5511 L F
.464 .466 .775 r
.68835 .50653 m .69032 .5063 L .68753 .50456 L F
.378 .291 .63 r
.5415 .79593 m .54211 .79756 L .54273 .79603 L F
.709 .685 .824 r
.77365 .59296 m .77124 .59394 L .77024 .59229 L F
0 .524 .782 r
.29928 .65157 m .29565 .65078 L .29715 .65157 L F
.454 .53 .846 r
.75638 .62144 m .75827 .61965 L .75612 .61957 L F
.039 .059 .552 r
.75638 .62144 m .75809 .62209 L .75827 .61965 L F
.75638 .62144 m .75688 .62346 L .75809 .62209 L F
.976 .675 .316 r
.65952 .50066 m .65761 .49774 L .65967 .5002 L F
.305 .048 .35 r
.26509 .61953 m .26383 .61843 L .26585 .61797 L F
.26509 .61953 m .26325 .62041 L .26383 .61843 L F
.95 .683 .496 r
.66296 .51701 m .66467 .51666 L .66136 .51323 L F
.66296 .51701 m .66445 .51788 L .66467 .51666 L F
.78 .539 .571 r
.62421 .5068 m .62775 .50858 L .62796 .50725 L F
.488 .816 1 r
.4381 .65022 m .44038 .64984 L .44177 .65058 L F
.523 .831 1 r
.44177 .65058 m .44269 .64933 L .44377 .6501 L F
.44177 .65058 m .44038 .64984 L .44269 .64933 L F
.254 .01 .337 r
.32191 .63996 m .31983 .64261 L .3204 .64043 L F
.239 0 0 r
.37082 .65564 m .37232 .65428 L .37015 .65466 L F
.255 .587 .947 r
.59132 .75189 m .59374 .75311 L .59396 .75141 L F
.643 .934 .968 r
.59396 .75141 m .59374 .75311 L .596 .75206 L F
.447 .251 .519 r
.69302 .52929 m .69303 .53145 L .6909 .53206 L F
.803 .314 0 r
.55078 .70536 m .55148 .70493 L .54987 .70407 L F
.55078 .70536 m .55225 .7062 L .55148 .70493 L F
.092 0 0 r
.41096 .70786 m .41056 .70707 L .41271 .70664 L F
.41096 .70786 m .40896 .70848 L .41056 .70707 L F
.548 .836 .998 r
.56187 .78401 m .56099 .78534 L .55956 .78449 L F
.55956 .78449 m .56099 .78534 L .56187 .78401 L F
0 .029 .582 r
.47478 .78237 m .47272 .77999 L .47436 .7787 L F
.601 .925 .967 r
.66258 .48287 m .66378 .48144 L .66514 .48256 L F
.66258 .48287 m .661 .48256 L .66378 .48144 L F
.413 .007 .157 r
.70864 .5211 m .70781 .52293 L .70551 .52323 L F
.553 .143 .219 r
.711 .52221 m .70781 .52293 L .70864 .5211 L F
.219 .741 .821 r
.28724 .63897 m .2893 .63864 L .29155 .63856 L F
.615 .944 .943 r
.29155 .63856 m .29107 .63757 L .2934 .63769 L F
.29155 .63856 m .2893 .63864 L .29107 .63757 L F
.134 .647 .895 r
.3176 .59276 m .31911 .59328 L .3156 .59261 L F
.348 .793 .957 r
.31981 .59259 m .31911 .59328 L .3176 .59276 L F
.31981 .59259 m .32117 .593 L .31911 .59328 L F
.632 .226 .256 r
.47778 .79023 m .47989 .79088 L .48095 .7901 L F
.164 0 0 r
.48174 .79032 m .48095 .7901 L .47989 .79088 L F
.48174 .79032 m .48348 .79023 L .48095 .7901 L F
.531 .774 .987 r
.31859 .60548 m .32 .60413 L .31772 .605 L F
.31859 .60548 m .32101 .60518 L .32 .60413 L F
.868 .563 .469 r
.6347 .52661 m .63191 .52405 L .63126 .52622 L F
.592 .469 .681 r
.54464 .70102 m .54794 .69711 L .54484 .69887 L F
.31 0 0 r
.29767 .60206 m .29603 .60318 L .29376 .60328 L F
.146 0 0 r
.29767 .60206 m .29796 .6024 L .29603 .60318 L F
.29767 .60206 m .29991 .60217 L .29796 .6024 L F
.673 .647 .816 r
.36482 .71287 m .36632 .7161 L .36852 .71521 L F
.549 .325 .528 r
.36632 .7161 m .36822 .71761 L .36852 .71521 L F
.433 .342 .653 r
.36632 .7161 m .36661 .71848 L .36822 .71761 L F
.549 .325 .528 r
.36632 .7161 m .36822 .71761 L .36852 .71521 L F
.856 .735 .729 r
.6151 .51801 m .61172 .51988 L .6138 .51685 L F
.6151 .51801 m .6133 .52114 L .61172 .51988 L F
.812 .854 .881 r
.61773 .51554 m .6151 .51801 L .6138 .51685 L F
.674 .628 .796 r
.69267 .51327 m .69254 .51453 L .69495 .51233 L F
.602 .69 .904 r
.69254 .51453 m .69502 .51441 L .69495 .51233 L F
.416 .767 .995 r
.28454 .58661 m .28805 .58727 L .28602 .58766 L F
.483 0 0 r
.38343 .71809 m .38094 .71869 L .38115 .71832 L F
.942 .674 .208 r
.5696 .77396 m .56978 .77625 L .56885 .77275 L F
.479 .287 .542 r
.57172 .77334 m .56978 .77625 L .5696 .77396 L F
.356 0 .21 r
.71689 .51847 m .71629 .51979 L .7141 .52036 L F
.271 0 .169 r
.71902 .51765 m .71629 .51979 L .71689 .51847 L F
.832 .498 .423 r
.51022 .74079 m .50977 .74282 L .50808 .73984 L F
.401 .024 .204 r
.51356 .73981 m .50977 .74282 L .51022 .74079 L F
.756 .694 .793 r
.64804 .49572 m .64522 .49838 L .64445 .49545 L F
.635 .552 .744 r
.64701 .49932 m .64632 .49882 L .64552 .49773 L F
0 0 .543 r
.64522 .49838 m .64552 .49773 L .64479 .49674 L F
.635 .552 .744 r
.64632 .49882 m .64327 .4966 L .64552 .49773 L F
0 0 .543 r
.64479 .49674 m .64552 .49773 L .64445 .49545 L F
.021 .026 .521 r
.64522 .49838 m .64579 .50089 L .64701 .49932 L F
.263 0 0 r
.54758 .7257 m .54955 .72617 L .55119 .72637 L F
.572 .007 0 r
.54955 .72617 m .55316 .72866 L .55119 .72637 L F
.936 .836 .721 r
.67001 .52006 m .67129 .52088 L .67046 .52269 L F
.411 0 0 r
.63469 .52953 m .6371 .53031 L .63813 .52981 L F
.124 0 0 r
.6394 .53012 m .63813 .52981 L .6371 .53031 L F
.6394 .53012 m .64041 .52972 L .63813 .52981 L F
.587 .553 .783 r
.63004 .50923 m .62783 .51234 L .62775 .50858 L F
.775 .856 .911 r
.53439 .80535 m .53591 .80284 L .53401 .80328 L F
.124 .211 .684 r
.53502 .80452 m .53439 .80535 L .53401 .80328 L F
.3 0 .047 r
.53381 .80611 m .53608 .80452 L .53439 .80535 L F
0 0 0 r
.53439 .80535 m .53608 .80452 L .53799 .8036 L F
.53439 .80535 m .53799 .8036 L .53835 .80356 L F
.775 .856 .911 r
.53439 .80535 m .53734 .80402 L .53591 .80284 L F
.53734 .80402 m .53835 .80356 L .53793 .80344 L F
.53734 .80402 m .53793 .80344 L .53591 .80284 L F
.611 .915 .652 r
.53799 .8036 m .5405 .80129 L .53903 .80237 L F
.53877 .80262 m .53903 .80237 L .53889 .80247 L F
.53799 .8036 m .53903 .80237 L .53877 .80262 L F
.124 .211 .684 r
.53602 .80575 m .53439 .80535 L .53502 .80452 L F
.3 0 .047 r
.53272 .80687 m .53381 .80611 L .53439 .80535 L F
.567 .526 .769 r
.75888 .59279 m .76105 .5904 L .75833 .59088 L F
.75888 .59279 m .76246 .59455 L .76105 .5904 L F
.55 .516 .77 r
.75888 .59279 m .7623 .5956 L .76246 .59455 L F
.821 .559 .543 r
.52948 .73736 m .52668 .7343 L .52908 .73516 L F
.94 .954 .753 r
.59938 .70481 m .59736 .70622 L .59864 .70699 L F
.59938 .70481 m .59905 .70326 L .59736 .70622 L F
.383 .262 .589 r
.35642 .68515 m .35833 .68428 L .35812 .68184 L F
.564 .527 .773 r
.35698 .68769 m .35833 .68428 L .35642 .68515 L F
.535 .142 .244 r
.57767 .67736 m .57787 .67895 L .57419 .67912 L F
.513 .702 .956 r
.57851 .67554 m .57767 .67736 L .57643 .67552 L F
.57851 .67554 m .5814 .67702 L .57767 .67736 L F
.465 .094 .25 r
.57971 .67834 m .57787 .67895 L .57767 .67736 L F
.58 .298 .454 r
.46266 .68221 m .4601 .68435 L .4603 .68215 L F
.569 .593 .838 r
.71534 .60542 m .71717 .60477 L .71448 .60371 L F
.71534 .60542 m .71978 .60649 L .71717 .60477 L F
.497 .302 .546 r
.49998 .73219 m .50206 .73422 L .50225 .73181 L F
.49998 .73219 m .49991 .73475 L .50206 .73422 L F
.552 .603 .858 r
.71644 .49472 m .71475 .49696 L .71408 .49542 L F
.71644 .49472 m .71783 .49785 L .71475 .49696 L F
.867 .468 .277 r
.6744 .53395 m .67665 .53479 L .67598 .5363 L F
.767 .636 .716 r
.67835 .5336 m .67598 .5363 L .67665 .53479 L F
.561 .434 .664 r
.45211 .77983 m .45513 .78145 L .4546 .77917 L F
.807 1 .831 r
.59838 .74889 m .5968 .75154 L .59817 .75151 L F
.59838 .74889 m .596 .75206 L .5968 .75154 L F
.562 .601 .85 r
.46128 .6526 m .45985 .65483 L .45841 .65206 L F
.46128 .6526 m .46204 .65456 L .45985 .65483 L F
.535 .036 .018 r
.39713 .64922 m .39921 .65023 L .40069 .64909 L F
.48 .015 .071 r
.39921 .65023 m .40286 .64894 L .40069 .64909 L F
.405 .068 .277 r
.49561 .73806 m .49296 .74 L .49482 .73946 L F
.573 .245 .375 r
.49561 .73806 m .49712 .73848 L .49746 .73727 L F
.49561 .73806 m .49482 .73946 L .49712 .73848 L F
.558 .443 .679 r
.52259 .7348 m .52073 .73523 L .52024 .7322 L F
.649 .386 .507 r
.51495 .77374 m .51524 .77623 L .51155 .77643 L F
.488 .757 .99 r
.51683 .77272 m .51722 .77363 L .51495 .77374 L F
.73 .544 .639 r
.51722 .77363 m .51524 .77623 L .51495 .77374 L F
.255 .587 .947 r
.59132 .75189 m .59396 .75141 L .5894 .74869 L F
.775 .536 .574 r
.77545 .58778 m .77579 .58985 L .77258 .59002 L F
.62 .582 .789 r
.77678 .58421 m .77545 .58778 L .77469 .58455 L F
.77678 .58421 m .77779 .5874 L .77545 .58778 L F
.588 .409 .607 r
.77779 .5874 m .77579 .58985 L .77545 .58778 L F
.092 0 0 r
.55524 .70931 m .55875 .70957 L .55543 .7093 L F
.621 .801 .372 r
.49778 .75621 m .49665 .75816 L .49889 .75435 L F
.753 .82 .905 r
.59817 .75151 m .60005 .74759 L .59838 .74889 L F
.59817 .75151 m .60129 .74853 L .60005 .74759 L F
.639 .449 .61 r
.59015 .68201 m .59208 .68218 L .59219 .67942 L F
.736 .385 .386 r
.68496 .52229 m .68799 .52167 L .68477 .52031 L F
.68496 .52229 m .68863 .52365 L .68799 .52167 L F
.312 .795 .899 r
.35037 .71019 m .34924 .70998 L .34675 .71043 L F
.166 .326 .781 r
.35037 .71019 m .35115 .70861 L .34924 .70998 L F
0 0 .096 r
.35648 .71066 m .35382 .71087 L .35503 .7104 L F
.35643 .71042 m .35503 .7104 L .35632 .7099 L F
.35648 .71066 m .35503 .7104 L .35643 .71042 L F
.715 .61 .738 r
.35632 .7099 m .35503 .7104 L .35263 .70967 L F
.35503 .7104 m .35382 .71087 L .35336 .7104 L F
.35503 .7104 m .35336 .7104 L .35263 .70967 L F
.603 .18 .213 r
.35491 .7109 m .35272 .71175 L .3507 .7104 L F
.35094 .7104 m .3507 .7104 L .35064 .71036 L F
.35491 .7109 m .3507 .7104 L .35094 .7104 L F
.35155 .71037 m .35064 .71036 L .35037 .71019 L F
.35491 .7109 m .35064 .71036 L .35155 .71037 L F
.35491 .7109 m .35263 .70967 L .35382 .71087 L F
.35491 .7109 m .35037 .71019 L .35263 .70967 L F
.166 .326 .781 r
.35037 .71019 m .35272 .71175 L .35115 .70861 L F
.225 .653 .956 r
.27753 .58505 m .27687 .58581 L .27524 .58495 L F
.27753 .58505 m .279 .58592 L .27687 .58581 L F
.487 .61 .899 r
.43699 .66044 m .43845 .66271 L .43973 .66136 L F
.356 .402 .772 r
.43845 .66271 m .44074 .66424 L .43973 .66136 L F
0 0 0 r
.7707 .61894 m .76953 .61964 L .76781 .62049 L F
.137 0 0 r
.77296 .61829 m .76953 .61964 L .7707 .61894 L F
.765 .704 .795 r
.53135 .74037 m .52713 .74011 L .52948 .73736 L F
.621 .138 .084 r
.53135 .74037 m .5296 .74163 L .52713 .74011 L F
.455 0 0 r
.53291 .74114 m .53135 .74037 L .53294 .73991 L F
.53291 .74114 m .5296 .74163 L .53135 .74037 L F
.789 .76 .827 r
.50037 .7766 m .50152 .77945 L .49855 .77872 L F
.844 .602 .572 r
.49855 .77872 m .50152 .77945 L .50087 .78158 L F
.436 .559 .881 r
.50062 .77632 m .50152 .77945 L .50037 .7766 L F
.998 .834 .549 r
.50087 .78158 m .50152 .77945 L .50062 .77632 L F
.502 .576 .863 r
.67668 .48533 m .67531 .48733 L .67385 .48451 L F
.67668 .48533 m .67747 .48719 L .67531 .48733 L F
.551 .837 .501 r
.47871 .77062 m .47606 .77354 L .4765 .77309 L F
.752 .662 .762 r
.47871 .77062 m .48152 .77593 L .47606 .77354 L F
.19 0 0 r
.48152 .77593 m .47684 .77581 L .47606 .77354 L F
.48152 .77593 m .47856 .77603 L .47684 .77581 L F
.619 .604 .813 r
.48189 .77315 m .48573 .77532 L .48426 .77335 L F
.563 .22 .345 r
.48426 .77335 m .48315 .77377 L .48189 .77315 L F
.506 .549 .834 r
.48189 .77315 m .48152 .77593 L .47941 .77194 L F
.811 .956 .91 r
.48148 .7744 m .48152 .77593 L .48183 .7736 L F
.48148 .7744 m .48183 .7736 L .48189 .77315 L F
.48148 .7744 m .47856 .77603 L .48152 .77593 L F
.619 .604 .813 r
.48189 .77315 m .48323 .77666 L .48573 .77532 L F
.654 .392 .51 r
.48385 .7751 m .48085 .77583 L .48148 .7744 L F
.48085 .77583 m .48053 .7759 L .48148 .7744 L F
.563 .22 .345 r
.48315 .77377 m .48148 .7744 L .48189 .77315 L F
.506 .549 .834 r
.48189 .77315 m .47941 .77194 L .47871 .77062 L F
.479 .846 .99 r
.48806 .78189 m .48444 .78201 L .48723 .78101 L F
.989 .815 .576 r
.48723 .78101 m .48661 .78409 L .48806 .78189 L F
.674 .37 .451 r
.51978 .80397 m .51801 .80225 L .51833 .8034 L F
.344 0 .208 r
.27827 .60739 m .27852 .60832 L .27608 .6085 L F
.222 0 .104 r
.27631 .6106 m .27608 .6085 L .27852 .60832 L F
.27631 .6106 m .27445 .61129 L .27608 .6085 L F
.513 .516 .797 r
.47363 .6702 m .4727 .67394 L .47138 .67064 L F
.47363 .6702 m .47481 .67372 L .4727 .67394 L F
.611 .824 .982 r
.32802 .7539 m .32858 .75479 L .3266 .75365 L F
.32802 .7539 m .32858 .75479 L .3266 .75365 L F
.576 .528 .764 r
.46925 .66135 m .46731 .66191 L .46675 .66015 L F
.199 .137 .558 r
.6931 .51905 m .69518 .51875 L .69601 .51749 L F
.6931 .51905 m .69344 .5202 L .69518 .51875 L F
.247 .027 .371 r
.365 .72073 m .36609 .72092 L .36661 .71848 L F
.282 0 0 r
.51218 .74251 m .51011 .74298 L .51443 .74179 L F
.51218 .74251 m .51011 .74298 L .51443 .74179 L F
.401 .024 .204 r
.51356 .73981 m .51233 .74221 L .50977 .74282 L F
.439 .061 .224 r
.51443 .74179 m .51218 .74251 L .51356 .73981 L F
.635 .455 .622 r
.51048 .74177 m .51399 .74179 L .51332 .73886 L F
.51399 .74179 m .51443 .74179 L .51439 .74169 L F
.51399 .74179 m .51439 .74169 L .51332 .73886 L F
.401 .024 .204 r
.51233 .74221 m .51218 .74251 L .51002 .74278 L F
.51233 .74221 m .51002 .74278 L .50977 .74282 L F
.439 .061 .224 r
.51443 .74179 m .51356 .73981 L .5151 .73992 L F
.616 .883 .99 r
.72786 .5958 m .72454 .59599 L .72702 .59568 L F
.166 .705 .793 r
.72928 .59549 m .72786 .5958 L .72702 .59568 L F
.72928 .59549 m .73025 .5955 L .72786 .5958 L F
.597 .388 .569 r
.49443 .75997 m .49438 .76237 L .49201 .76271 L F
.707 .478 .576 r
.49881 .76199 m .49438 .76237 L .49443 .75997 L F
.434 .221 .489 r
.67157 .49852 m .67151 .50075 L .66947 .50091 L F
.725 .555 .66 r
.67151 .50075 m .66873 .50334 L .66947 .50091 L F
.5 .461 .746 r
.68753 .50456 m .69032 .5063 L .68816 .50256 L F
.207 .714 .9 r
.27443 .65359 m .27633 .6535 L .27284 .65324 L F
.488 .011 .05 r
.28961 .60368 m .28613 .60603 L .28604 .60423 L F
.454 .096 .267 r
.28889 .60538 m .28728 .60634 L .28692 .60584 L F
.231 0 0 r
.2899 .60478 m .28613 .60603 L .28961 .60368 L F
.28999 .60512 m .28652 .60594 L .2899 .60478 L F
.28652 .60594 m .28613 .60603 L .2899 .60478 L F
.488 .011 .05 r
.28613 .60603 m .28609 .60602 L .28604 .60423 L F
.536 .882 .637 r
.28604 .60423 m .28438 .60536 L .28357 .60624 L F
.488 .011 .05 r
.28613 .60603 m .28609 .60605 L .28609 .60602 L F
.175 0 .053 r
.28604 .60423 m .28609 .60605 L .28664 .60545 L F
.597 .26 .369 r
.28664 .60545 m .28652 .60594 L .28438 .60536 L F
.28652 .60594 m .28627 .60694 L .28549 .60629 L F
.28652 .60594 m .28549 .60629 L .28438 .60536 L F
.454 .096 .267 r
.28728 .60634 m .28647 .60612 L .28664 .60545 L F
.28889 .60538 m .28836 .60673 L .28627 .60694 L F
.28911 .60524 m .28906 .60534 L .28889 .60538 L F
.28906 .60534 m .28836 .60673 L .28889 .60538 L F
.259 0 .165 r
.29034 .60588 m .28836 .60673 L .28906 .60534 L F
.231 0 0 r
.29 .60518 m .28919 .60536 L .28907 .60534 L F
.28907 .60534 m .28613 .60603 L .28889 .60538 L F
.28919 .60536 m .28613 .60603 L .28907 .60534 L F
.29 .60518 m .28609 .60605 L .28613 .60603 L F
.454 .096 .267 r
.28889 .60538 m .28692 .60584 L .28664 .60545 L F
.488 .142 .306 r
.28664 .60545 m .28609 .60605 L .2892 .60536 L F
.231 0 0 r
.29 .60516 m .28889 .60538 L .28999 .60512 L F
.29 .60518 m .28889 .60538 L .29 .60516 L F
.29 .60518 m .28961 .60368 L .29165 .6035 L F
.097 0 0 r
.29203 .60425 m .29 .60518 L .29165 .6035 L F
.361 0 .046 r
.28911 .60524 m .29 .60518 L .29203 .60425 L F
.259 0 .165 r
.29149 .60477 m .28911 .60524 L .29203 .60425 L F
.488 .142 .306 r
.28962 .60521 m .2892 .60536 L .29 .60518 L F
.28923 .6053 m .2892 .60536 L .28962 .60521 L F
.259 0 .165 r
.29034 .60588 m .28923 .6053 L .29149 .60477 L F
.28923 .6053 m .28911 .60524 L .29149 .60477 L F
.488 .142 .306 r
.28927 .60524 m .28923 .6053 L .28962 .60521 L F
.259 0 .165 r
.28923 .6053 m .28906 .60534 L .28911 .60524 L F
.2892 .60536 m .28906 .60534 L .28923 .6053 L F
.454 .096 .267 r
.28911 .60524 m .28889 .60538 L .28664 .60545 L F
.488 .142 .306 r
.28664 .60545 m .2892 .60536 L .28927 .60524 L F
.259 0 .165 r
.28939 .60539 m .2892 .60536 L .28923 .6053 L F
.29034 .60588 m .28906 .60534 L .28939 .60539 L F
.454 .096 .267 r
.28728 .60634 m .28627 .60694 L .28647 .60612 L F
0 0 0 r
.4163 .6936 m .41661 .69405 L .41826 .69284 L F
.4163 .6936 m .41457 .69473 L .41661 .69405 L F
.148 .516 .915 r
.58675 .70966 m .58483 .70994 L .58443 .70972 L F
.966 .76 .573 r
.5483 .77091 m .54962 .77366 L .54896 .77246 L F
.63 .68 .879 r
.55125 .773 m .54962 .77366 L .54896 .77246 L F
.55125 .773 m .54962 .77366 L .54896 .77246 L F
.608 .105 .031 r
.46636 .79132 m .46677 .79287 L .46631 .79226 L F
.46636 .79132 m .46863 .79273 L .46677 .79287 L F
.532 0 0 r
.4702 .79312 m .46863 .79273 L .46636 .79132 L F
.341 0 .012 r
.37979 .65255 m .37811 .65194 L .37671 .65365 L F
.37979 .65255 m .38032 .65166 L .37811 .65194 L F
.757 .609 .693 r
.55085 .74331 m .54974 .74559 L .55067 .74383 L F
.587 .433 .64 r
.55317 .74013 m .55378 .74307 L .55085 .74331 L F
.998 .811 .53 r
.66707 .51278 m .66588 .51344 L .66596 .51169 L F
.66707 .51278 m .66678 .51467 L .66588 .51344 L F
.423 .305 .613 r
.5888 .73137 m .58874 .73371 L .58964 .73213 L F
.498 .763 .99 r
.5888 .73137 m .58964 .73213 L .59139 .73095 L F
.606 .348 .5 r
.5863 .73656 m .58874 .73371 L .58902 .73461 L F
.399 .137 .396 r
.58888 .73654 m .59036 .73369 L .58943 .7337 L F
.58877 .73434 m .58897 .73397 L .58874 .73371 L F
.58897 .73397 m .58912 .73371 L .58874 .73371 L F
.59 .488 .706 r
.58874 .73371 m .59036 .73369 L .59139 .73095 L F
.423 .305 .613 r
.5888 .73137 m .58897 .73397 L .58874 .73371 L F
.58897 .73397 m .58902 .73461 L .58874 .73371 L F
.784 .578 .622 r
.58865 .73453 m .58877 .73434 L .58894 .73352 L F
.58877 .73434 m .58898 .73403 L .58897 .73397 L F
.58877 .73434 m .58897 .73397 L .58894 .73352 L F
.399 .137 .396 r
.58877 .73441 m .58943 .7337 L .58912 .73371 L F
.58877 .73441 m .58912 .73371 L .58877 .73434 L F
.784 .578 .622 r
.58865 .73453 m .58902 .73461 L .58898 .73403 L F
.399 .137 .396 r
.58888 .73654 m .58943 .7337 L .58877 .73441 L F
.776 .622 .689 r
.58865 .73453 m .5863 .73656 L .58776 .73551 L F
.58867 .73453 m .58776 .73551 L .58902 .73461 L F
.58865 .73453 m .58776 .73551 L .58867 .73453 L F
.606 .348 .5 r
.5863 .73656 m .58806 .73503 L .58874 .73371 L F
.58728 .73656 m .58877 .73434 L .58874 .73371 L F
.776 .622 .689 r
.58481 .73366 m .5863 .73656 L .58865 .73453 L F
.606 .348 .5 r
.5863 .73656 m .58728 .73656 L .58806 .73503 L F
.58728 .73656 m .58888 .73654 L .58877 .73434 L F
.784 .578 .622 r
.58827 .73444 m .58865 .73453 L .58894 .73352 L F
.58481 .73366 m .58827 .73444 L .5888 .73137 L F
.58827 .73444 m .58894 .73352 L .5888 .73137 L F
.59 .488 .706 r
.58874 .73371 m .589 .73344 L .58964 .73213 L F
.589 .73344 m .59139 .73095 L .59024 .73173 L F
.589 .73344 m .59024 .73173 L .58964 .73213 L F
.603 .892 .593 r
.76781 .62049 m .76751 .62062 L .76504 .62315 L F
.318 .78 .65 r
.76781 .62049 m .76953 .61964 L .76751 .62062 L F
.835 .53 .474 r
.64472 .50706 m .64313 .50839 L .64279 .50575 L F
.64472 .50706 m .64452 .50894 L .64313 .50839 L F
.557 .277 .446 r
.64472 .50706 m .64714 .5086 L .64452 .50894 L F
.546 .286 .473 r
.64724 .50672 m .64714 .5086 L .64472 .50706 L F
.536 .195 .337 r
.46075 .75633 m .46302 .75492 L .46125 .75468 L F
.627 .067 0 r
.58445 .68236 m .58337 .68225 L .5817 .68084 L F
.704 .205 .053 r
.58667 .68325 m .58337 .68225 L .58445 .68236 L F
.549 .344 .555 r
.64471 .49312 m .64445 .49545 L .64228 .49554 L F
.431 .752 .995 r
.64228 .49554 m .64445 .49545 L .6412 .49458 L F
.591 .321 .475 r
.52859 .76167 m .52634 .75957 L .52851 .75991 L F
.52859 .76167 m .52664 .76257 L .52634 .75957 L F
.903 .824 .759 r
.60425 .53685 m .6048 .53985 L .60222 .53979 L F
.60425 .53685 m .60562 .53783 L .6048 .53985 L F
.861 .805 .794 r
.60222 .53979 m .6048 .53985 L .60283 .54278 L F
0 0 0 r
.68305 .52794 m .68144 .52926 L .68388 .52676 L F
.467 .556 .863 r
.68305 .52794 m .68405 .5298 L .68144 .52926 L F
.976 .675 .316 r
.65952 .50066 m .65858 .50031 L .65761 .49774 L F
.963 .896 .712 r
.65952 .50066 m .65712 .5033 L .65858 .50031 L F
.65952 .50066 m .65791 .50427 L .65712 .5033 L F
.603 .15 .149 r
.46302 .75492 m .46568 .75611 L .46722 .75462 L F
.587 .229 .328 r
.46568 .75611 m .46927 .75402 L .46722 .75462 L F
.612 .633 .847 r
.68793 .4929 m .68419 .49043 L .68655 .49055 L F
.626 .734 .925 r
.68947 .48927 m .68793 .4929 L .68655 .49055 L F
.68947 .48927 m .69024 .49225 L .68793 .4929 L F
.455 .537 .852 r
.72803 .61346 m .72926 .61574 L .73069 .61381 L F
.562 .691 .927 r
.72926 .61574 m .73174 .61537 L .73069 .61381 L F
.644 .598 .787 r
.69326 .49323 m .69133 .49582 L .69024 .49225 L F
.663 .625 .801 r
.69326 .49323 m .69455 .4963 L .69133 .49582 L F
.66 .285 .324 r
.53189 .76013 m .52859 .76167 L .52851 .75991 L F
.53189 .76013 m .53096 .76231 L .52859 .76167 L F
.581 .202 .289 r
.53424 .76144 m .53096 .76231 L .53189 .76013 L F
.936 .675 .518 r
.59272 .68374 m .59417 .68214 L .59208 .68218 L F
.59272 .68374 m .59437 .6846 L .59417 .68214 L F
.889 .585 .079 r
.77389 .61166 m .77482 .61477 L .77449 .61259 L F
.414 .155 .409 r
.34395 .61495 m .34549 .61689 L .34366 .61771 L F
.34395 .61495 m .34618 .61322 L .34549 .61689 L F
.702 .514 .631 r
.35449 .69051 m .35691 .69006 L .35698 .68769 L F
.564 .527 .773 r
.35698 .68769 m .35913 .68718 L .35833 .68428 L F
.566 .4 .616 r
.35698 .68769 m .35891 .68951 L .35913 .68718 L F
.35698 .68769 m .35691 .69006 L .35891 .68951 L F
0 0 0 r
.5434 .70828 m .54361 .7068 L .54369 .70643 L F
.82 .443 0 r
.54376 .70608 m .54369 .70643 L .54276 .70399 L F
0 0 .441 r
.54276 .70399 m .54369 .70643 L .54381 .70537 L F
0 0 0 r
.54361 .7068 m .54381 .70537 L .54369 .70643 L F
.82 .443 0 r
.54418 .70696 m .54369 .70643 L .54376 .70608 L F
.861 .444 .233 r
.54418 .70696 m .5434 .70828 L .54369 .70643 L F
.54418 .70696 m .54593 .70961 L .5434 .70828 L F
.565 .2 .306 r
.51327 .80931 m .51337 .80772 L .51543 .80918 L F
.636 .105 0 r
.58542 .67627 m .58784 .67794 L .58862 .67703 L F
.619 .085 0 r
.58862 .67703 m .58784 .67794 L .58911 .67763 L F
.689 .456 .565 r
.56622 .77309 m .56287 .77075 L .56482 .76939 L F
.407 .429 .771 r
.56697 .76864 m .56482 .76939 L .56492 .76807 L F
.56697 .76864 m .56769 .77091 L .56482 .76939 L F
.668 .521 .676 r
.56769 .77091 m .56622 .77309 L .56482 .76939 L F
.44 .546 .868 r
.6385 .4916 m .63869 .49314 L .64025 .49136 L F
.351 .411 .784 r
.63869 .49314 m .6412 .49458 L .64025 .49136 L F
.882 .785 .749 r
.6785 .5087 m .68013 .50956 L .67912 .50669 L F
.856 .757 .753 r
.6785 .5087 m .67937 .51141 L .68013 .50956 L F
.559 .267 .428 r
.6215 .5598 m .62114 .56172 L .61813 .56236 L F
.537 .273 .461 r
.62382 .55935 m .62114 .56172 L .6215 .5598 L F
.872 .6 .523 r
.60609 .73125 m .60871 .72943 L .60554 .72892 L F
.60609 .73125 m .60876 .73178 L .60871 .72943 L F
.833 .567 .535 r
.60871 .72943 m .60876 .73178 L .61055 .73162 L F
.695 .792 .925 r
.48068 .77145 m .48228 .77144 L .47871 .77062 L F
.506 .549 .834 r
.48189 .77315 m .47871 .77062 L .48228 .77144 L F
.647 .3 .369 r
.48228 .77144 m .48426 .77335 L .48189 .77315 L F
.48228 .77144 m .48426 .77335 L .48189 .77315 L F
.84 .794 .807 r
.60013 .54239 m .60222 .53979 L .60283 .54278 L F
.864 .735 .719 r
.60013 .54239 m .60283 .54278 L .60116 .54566 L F
.507 .67 .937 r
.44175 .66592 m .44274 .66407 L .44074 .66424 L F
.44175 .66592 m .44423 .6658 L .44274 .66407 L F
.893 .773 .722 r
.60558 .53362 m .60562 .53783 L .60425 .53685 L F
.483 .307 .566 r
.38785 .67552 m .38576 .6739 L .3878 .67323 L F
.38785 .67552 m .38571 .67617 L .38576 .6739 L F
.692 .568 .711 r
.44382 .67347 m .44653 .67371 L .44632 .67117 L F
.654 .451 .597 r
.44403 .67622 m .44653 .67371 L .44382 .67347 L F
0 0 0 r
.31521 .64568 m .3124 .64765 L .31351 .6466 L F
0 .401 .848 r
.55825 .73177 m .56052 .73373 L .55776 .7323 L F
.115 0 0 r
.39095 .71428 m .39032 .71526 L .38894 .71509 L F
.088 0 0 r
.3894 .71612 m .38894 .71509 L .39032 .71526 L F
.3894 .71612 m .38748 .71692 L .38894 .71509 L F
.495 .288 .527 r
.69529 .52871 m .69303 .53145 L .69302 .52929 L F
.576 .357 .547 r
.53884 .76786 m .5413 .76519 L .53901 .76555 L F
.514 .387 .645 r
.45503 .76523 m .45713 .7649 L .45683 .76244 L F
.477 .364 .645 r
.45531 .76844 m .45713 .7649 L .45503 .76523 L F
.217 .49 .898 r
.64537 .49192 m .64626 .49331 L .64471 .49312 L F
.64541 .49185 m .64547 .49196 L .64537 .49192 L F
.64547 .49196 m .64626 .49331 L .64537 .49192 L F
0 0 .545 r
.64537 .49192 m .64536 .49244 L .64541 .49185 L F
.64471 .49312 m .64536 .49244 L .64537 .49192 L F
.369 .472 .834 r
.64112 .49017 m .64536 .49244 L .64097 .49035 L F
.64241 .48867 m .64475 .49166 L .64112 .49017 L F
.64475 .49166 m .64536 .49244 L .64112 .49017 L F
.136 .466 .891 r
.64097 .49035 m .64536 .49244 L .64471 .49312 L F
.738 .735 .849 r
.64626 .49331 m .64445 .49545 L .64471 .49312 L F
.722 .371 .382 r
.5258 .72097 m .5291 .7226 L .52919 .72114 L F
.656 .308 .372 r
.5291 .7226 m .53146 .72315 L .52919 .72114 L F
.409 .186 .461 r
.59532 .55972 m .59683 .55886 L .59762 .55649 L F
.964 .8 .631 r
.59762 .55649 m .59683 .55886 L .59532 .55972 L F
.472 .745 .988 r
.59809 .55522 m .5997 .55625 L .59762 .55649 L F
.721 .848 .413 r
.59652 .55826 m .59762 .55649 L .59683 .55886 L F
.59652 .55826 m .59809 .55522 L .59762 .55649 L F
.552 .14 .215 r
.58145 .72576 m .58619 .72597 L .5851 .72462 L F
.471 .13 .306 r
.5851 .72462 m .58619 .72597 L .58699 .72569 L F
.696 .812 .937 r
.64988 .54591 m .65333 .54613 L .65213 .54544 L F
.44 0 0 r
.65111 .54634 m .65213 .54544 L .65358 .54586 L F
.65294 .54618 m .65358 .54586 L .65432 .54607 L F
.65111 .54634 m .65358 .54586 L .65294 .54618 L F
.418 .837 .67 r
.65469 .54522 m .65429 .54549 L .65539 .54487 L F
.65429 .54549 m .65333 .54613 L .65481 .54522 L F
.65429 .54549 m .65481 .54522 L .65539 .54487 L F
.453 .803 .998 r
.65213 .54544 m .65333 .54613 L .65469 .54522 L F
.432 .568 .89 r
.64241 .48867 m .64097 .49035 L .63972 .48782 L F
.667 .532 .691 r
.64064 .52452 m .64273 .52406 L .64158 .52061 L F
.771 .437 .42 r
.64495 .52322 m .64158 .52061 L .64273 .52406 L F
.394 .826 .957 r
.42929 .66173 m .42788 .6613 L .42565 .66177 L F
.299 .787 .895 r
.43084 .66128 m .42788 .6613 L .42929 .66173 L F
.655 .11 0 r
.56316 .71839 m .56273 .71919 L .56021 .71735 L F
.645 .099 0 r
.56316 .71839 m .56557 .72015 L .56273 .71919 L F
.716 .495 .588 r
.49995 .746 m .49967 .74884 L .49777 .74837 L F
.581 .511 .741 r
.50265 .74534 m .49995 .746 L .4994 .74313 L F
.365 .124 .409 r
.50265 .74534 m .49967 .74884 L .49995 .746 L F
.01 .399 .851 r
.47481 .7824 m .47735 .78391 L .47696 .7846 L F
.47483 .7824 m .47735 .78391 L .47481 .7824 L F
.694 .263 .221 r
.47398 .78351 m .47735 .78391 L .47483 .7824 L F
.629 .407 .561 r
.47478 .78247 m .47398 .78351 L .47477 .78247 L F
.01 .399 .851 r
.47478 .78237 m .47483 .7824 L .47481 .7824 L F
.766 .511 .549 r
.47297 .78732 m .47324 .78451 L .46955 .78426 L F
.521 0 0 r
.46955 .78426 m .47324 .78451 L .47236 .78512 L F
0 0 0 r
.47461 .78261 m .47324 .78451 L .47398 .78351 L F
.753 .953 .641 r
.47236 .78512 m .47324 .78451 L .47478 .78237 L F
.47236 .78512 m .4745 .78277 L .47398 .78351 L F
.4745 .78277 m .47477 .78247 L .47398 .78351 L F
0 0 0 r
.47478 .78237 m .47461 .78261 L .47398 .78351 L F
.694 .263 .221 r
.47398 .78351 m .47483 .7824 L .47478 .78237 L F
.629 .407 .561 r
.47492 .78239 m .47398 .78351 L .47478 .78247 L F
.47661 .78141 m .47549 .78231 L .47492 .78239 L F
.47549 .78231 m .47398 .78351 L .47492 .78239 L F
.009 .398 .851 r
.47735 .78391 m .47864 .78567 L .47696 .7846 L F
.499 .32 .569 r
.47864 .78567 m .47714 .78775 L .47696 .7846 L F
.766 .661 .746 r
.69379 .50701 m .69718 .50934 L .69608 .50619 L F
.69379 .50701 m .69518 .51049 L .69718 .50934 L F
.704 .514 .629 r
.69518 .51049 m .69741 .51191 L .69718 .50934 L F
.677 .638 .803 r
.69608 .50619 m .69718 .50934 L .69947 .50696 L F
.642 .58 .769 r
.69718 .50934 m .7019 .50984 L .69947 .50696 L F
.716 .632 .763 r
.69741 .51191 m .7019 .50984 L .69718 .50934 L F
.773 .512 .541 r
.35648 .71066 m .35946 .71278 L .35583 .71226 L F
.943 .735 .592 r
.35648 .71066 m .35583 .71226 L .35632 .7099 L F
0 0 0 r
.54971 .70104 m .54969 .70121 L .54836 .70137 L F
.829 .438 .311 r
.54714 .70295 m .54987 .70407 L .54836 .70137 L F
.54714 .70295 m .54836 .70137 L .54969 .70121 L F
.438 .147 .372 r
.44674 .68752 m .44638 .68985 L .4442 .68985 L F
.518 .203 .374 r
.44893 .68747 m .44638 .68985 L .44674 .68752 L F
.924 .937 .793 r
.6575 .51745 m .65506 .51932 L .65729 .51689 L F
.795 .496 .482 r
.60907 .73399 m .61055 .73162 L .60876 .73178 L F
.60907 .73399 m .6123 .73434 L .61055 .73162 L F
.378 .319 .664 r
.7606 .5984 m .76074 .60162 L .76281 .60016 L F
.393 .346 .686 r
.76074 .60162 m .7631 .60316 L .76281 .60016 L F
.402 .344 .679 r
.76074 .60162 m .76155 .60423 L .7631 .60316 L F
.43 .288 .586 r
.7606 .5984 m .76245 .59798 L .7623 .5956 L F
.378 .319 .664 r
.7606 .5984 m .76281 .60016 L .76245 .59798 L F
.78 .539 .571 r
.62421 .5068 m .62426 .50907 L .62775 .50858 L F
.492 .107 .236 r
.62427 .51117 m .62775 .50858 L .62426 .50907 L F
.62427 .51117 m .62658 .51111 L .62775 .50858 L F
.595 .239 .335 r
.62658 .51111 m .63004 .50923 L .62775 .50858 L F
.514 .649 .918 r
.77678 .58421 m .77469 .58455 L .77351 .58237 L F
.987 .87 .632 r
.55988 .73292 m .56123 .735 L .56052 .73373 L F
.889 .586 .467 r
.55988 .73292 m .56385 .7366 L .56123 .735 L F
.458 .49 .804 r
.51265 .76826 m .50921 .76513 L .51253 .7655 L F
.569 .21 .32 r
.50361 .75371 m .50675 .75173 L .50375 .75169 L F
.50361 .75371 m .50701 .75354 L .50675 .75173 L F
.782 .369 .268 r
.50701 .75354 m .5093 .75427 L .50675 .75173 L F
.714 .418 .474 r
.50675 .75173 m .50998 .75339 L .51036 .75165 L F
.50675 .75173 m .5093 .75427 L .50998 .75339 L F
.663 .87 .977 r
.43084 .66128 m .43492 .66063 L .43368 .66028 L F
.747 .472 .514 r
.43699 .66044 m .43368 .66028 L .43492 .66063 L F
.002 0 0 r
.5704 .76578 m .5695 .76712 L .56697 .76864 L F
.706 .256 .18 r
.5704 .76578 m .57113 .76709 L .5695 .76712 L F
.554 .302 .488 r
.47709 .7485 m .47941 .74834 L .47965 .74616 L F
.483 .242 .472 r
.47965 .74616 m .48156 .74788 L .48204 .74606 L F
.47965 .74616 m .47941 .74834 L .48156 .74788 L F
.427 .254 .542 r
.38367 .67911 m .38356 .68178 L .38176 .68208 L F
.507 .512 .796 r
.38486 .68523 m .38176 .68208 L .38356 .68178 L F
.499 .178 .354 r
.5298 .74797 m .53179 .74767 L .53183 .74607 L F
.59 .31 .461 r
.53179 .74767 m .53417 .74573 L .53183 .74607 L F
.32 0 .026 r
.41233 .66347 m .41126 .66493 L .40899 .66536 L F
.238 0 0 r
.41339 .66434 m .41233 .66347 L .41449 .6631 L F
.41339 .66434 m .41126 .66493 L .41233 .66347 L F
.288 0 0 r
.40286 .64894 m .40489 .6494 L .40634 .64913 L F
.316 0 0 r
.40489 .6494 m .40849 .6493 L .40634 .64913 L F
.522 .362 .606 r
.35675 .67596 m .35878 .67318 L .35682 .67374 L F
.725 .237 .081 r
.49007 .80125 m .49024 .803 L .48828 .80092 L F
.49007 .80125 m .49199 .80287 L .49024 .803 L F
.539 .398 .638 r
.35784 .66525 m .36019 .66722 L .35979 .66479 L F
.35784 .66525 m .35808 .66772 L .36019 .66722 L F
.753 .41 .404 r
.49511 .80373 m .49855 .80429 L .49753 .80647 L F
.629 .271 .345 r
.49753 .80647 m .49855 .80429 L .49975 .80623 L F
.616 .268 .357 r
.49855 .80429 m .50112 .80423 L .49975 .80623 L F
.256 0 .061 r
.49982 .75566 m .49889 .75435 L .50111 .75396 L F
.49982 .75566 m .49778 .75621 L .49889 .75435 L F
.42 0 .092 r
.25075 .58788 m .25222 .58869 L .25391 .58687 L F
.182 0 0 r
.25222 .58869 m .25603 .58684 L .25391 .58687 L F
.836 .373 0 r
.67199 .52911 m .67409 .53158 L .6728 .53093 L F
.948 .608 .342 r
.6728 .53093 m .67409 .53158 L .6744 .53395 L F
.674 .435 .552 r
.47363 .67874 m .47046 .68139 L .47101 .67989 L F
.709 .685 .824 r
.77365 .59296 m .77024 .59229 L .77258 .59002 L F
.424 .254 .545 r
.77579 .58985 m .77365 .59296 L .77258 .59002 L F
.77579 .58985 m .77591 .59283 L .77365 .59296 L F
.521 .475 .746 r
.77591 .59283 m .7741 .59531 L .77365 .59296 L F
.835 .991 .735 r
.59203 .7144 m .59193 .71425 L .59174 .71543 L F
.697 .978 .905 r
.59257 .72059 m .59374 .7196 L .59295 .72099 L F
.191 0 .324 r
.59257 .72059 m .59374 .7196 L .59322 .72044 L F
.321 0 .027 r
.58956 .72305 m .59183 .72265 L .59295 .72099 L F
.191 0 .324 r
.59257 .72059 m .59322 .72044 L .59183 .72265 L F
.28 .746 .946 r
.59145 .72084 m .59257 .72059 L .58953 .72065 L F
.59295 .72099 m .59257 .72059 L .59145 .72084 L F
.64 .829 .418 r
.59183 .72265 m .59374 .7196 L .59295 .72099 L F
.519 .243 .436 r
.61395 .56201 m .61252 .56467 L .61048 .56507 L F
.635 .398 .541 r
.61591 .56213 m .61252 .56467 L .61395 .56201 L F
.591 .54 .766 r
.63549 .52979 m .63618 .53446 L .63847 .53374 L F
0 0 0 r
.63362 .53649 m .63847 .53374 L .63618 .53446 L F
.58 .298 .454 r
.46266 .68221 m .46244 .68415 L .4601 .68435 L F
.49 .157 .329 r
.46568 .68172 m .46244 .68415 L .46266 .68221 L F
.711 .633 .769 r
.35494 .70677 m .35632 .7099 L .35263 .70967 L F
.168 .26 .716 r
.35642 .70651 m .35632 .7099 L .35494 .70677 L F
.35642 .70651 m .3573 .70978 L .35632 .7099 L F
.413 .657 .96 r
.35469 .70969 m .35684 .71032 L .3556 .70858 L F
.35436 .71009 m .35543 .71019 L .35469 .70969 L F
.35543 .71019 m .35684 .71032 L .35469 .70969 L F
.811 .326 .03 r
.35632 .7099 m .35729 .71147 L .35946 .71278 L F
.35729 .71147 m .35767 .71208 L .35887 .71255 L F
.35729 .71147 m .35887 .71255 L .35946 .71278 L F
.35767 .71208 m .35775 .71221 L .35787 .71225 L F
.35767 .71208 m .35787 .71225 L .35946 .71278 L F
.466 .553 .861 r
.35583 .71226 m .35646 .71106 L .35436 .71009 L F
.35646 .71106 m .35684 .71032 L .35543 .71019 L F
.35646 .71106 m .35543 .71019 L .35436 .71009 L F
0 0 0 r
.35902 .70856 m .35831 .70913 L .3573 .70978 L F
.35831 .70913 m .35684 .71032 L .3573 .70978 L F
.153 .142 .592 r
.3573 .70978 m .35775 .71221 L .35654 .71026 L F
.3573 .70978 m .35654 .71026 L .35632 .7099 L F
.611 .243 .321 r
.57319 .71095 m .57275 .71223 L .57565 .712 L F
.669 .54 .698 r
.64064 .52452 m .64078 .52674 L .64273 .52406 L F
.589 .192 .258 r
.51316 .71655 m .51678 .7151 L .51346 .71578 L F
.51316 .71655 m .51537 .71708 L .51678 .7151 L F
.747 .382 .362 r
.51537 .71708 m .51881 .71751 L .51678 .7151 L F
.73 .649 .768 r
.77732 .61178 m .77783 .61468 L .78054 .61246 L F
.303 .753 .959 r
.32542 .59296 m .32468 .59361 L .32315 .5929 L F
.32542 .59296 m .3268 .59348 L .32468 .59361 L F
.344 .008 .243 r
.43043 .69797 m .42847 .6985 L .43109 .69644 L F
.379 .041 .26 r
.43246 .69739 m .43109 .69644 L .43329 .69627 L F
.43246 .69739 m .43043 .69797 L .43109 .69644 L F
.232 .01 .357 r
.53948 .73984 m .53864 .73797 L .54076 .73719 L F
.53948 .73984 m .53805 .7412 L .53864 .73797 L F
.134 .575 .925 r
.26276 .65501 m .2663 .65642 L .26482 .65645 L F
.266 0 0 r
.2663 .65642 m .26855 .65676 L .26482 .65645 L F
.353 .055 .313 r
.56495 .68732 m .56468 .68966 L .56219 .68937 L F
.4 .053 .258 r
.56389 .6914 m .56219 .68937 L .56468 .68966 L F
.56389 .6914 m .56175 .69189 L .56219 .68937 L F
.604 .608 .829 r
.46893 .65963 m .46675 .66015 L .46563 .65743 L F
.576 .528 .764 r
.46925 .66135 m .46675 .66015 L .46893 .65963 L F
.897 .805 .749 r
.56628 .74092 m .56773 .74011 L .56702 .73945 L F
.511 0 0 r
.56636 .73884 m .56702 .73945 L .56819 .74008 L F
.331 .712 .983 r
.56924 .73927 m .56819 .74008 L .56702 .73945 L F
.897 .805 .749 r
.56773 .74011 m .56924 .73927 L .56702 .73945 L F
.511 0 0 r
.56467 .7377 m .56702 .73945 L .56636 .73884 L F
.331 .712 .983 r
.56924 .73927 m .57054 .74016 L .56819 .74008 L F
.046 .352 .827 r
.65002 .49565 m .65223 .49711 L .65184 .49817 L F
0 .055 .617 r
.65223 .49711 m .65346 .50048 L .65184 .49817 L F
.826 .477 .395 r
.54326 .77935 m .54478 .78174 L .5439 .78169 L F
.54326 .77935 m .5439 .78169 L .54405 .77847 L F
.602 .047 0 r
.5083 .77439 m .50468 .77343 L .50601 .7741 L F
.2 0 .166 r
.31173 .62659 m .31269 .62784 L .31364 .62595 L F
.31173 .62659 m .31088 .62826 L .31269 .62784 L F
.86 .614 .566 r
.59886 .68989 m .59705 .6875 L .59701 .69012 L F
.902 .591 .448 r
.59752 .6926 m .59886 .68989 L .59701 .69012 L F
.59752 .6926 m .59968 .69291 L .59886 .68989 L F
.113 0 0 r
.30814 .63131 m .30951 .62942 L .3066 .63153 L F
0 0 0 r
.31088 .62826 m .30951 .62942 L .30814 .63131 L F
.429 .682 .969 r
.67089 .48218 m .66809 .48291 L .66696 .48182 L F
.67089 .48218 m .67081 .48295 L .66809 .48291 L F
1 .805 .497 r
.56385 .7366 m .56354 .73946 L .56467 .7377 L F
.667 .254 .253 r
.56467 .7377 m .56354 .73946 L .56702 .73945 L F
.631 .93 .97 r
.63113 .50925 m .63226 .50818 L .63314 .50693 L F
.252 0 0 r
.63226 .50818 m .63572 .50658 L .63314 .50693 L F
.738 .735 .849 r
.64626 .49331 m .64804 .49572 L .64445 .49545 L F
.465 .595 .898 r
.6497 .49401 m .64804 .49572 L .64626 .49331 L F
.6497 .49401 m .65002 .49565 L .64804 .49572 L F
.654 .451 .597 r
.44403 .67622 m .4465 .67613 L .44653 .67371 L F
.645 .533 .712 r
.44632 .67117 m .44653 .67371 L .44883 .6711 L F
.678 .583 .742 r
.44883 .6711 m .44653 .67371 L .44946 .67345 L F
.629 .41 .565 r
.4465 .67613 m .44946 .67345 L .44653 .67371 L F
.661 .524 .685 r
.4729 .76826 m .47066 .77101 L .47129 .7693 L F
.447 .239 .503 r
.51961 .77109 m .52142 .77245 L .52276 .77105 L F
.51961 .77109 m .51969 .77335 L .52142 .77245 L F
.502 .66 .932 r
.29586 .58863 m .2951 .59058 L .29381 .58885 L F
.538 .701 .945 r
.29586 .58863 m .29714 .59026 L .2951 .59058 L F
.54 .745 .971 r
.7394 .59636 m .74078 .59459 L .7388 .59572 L F
.7394 .59636 m .742 .59611 L .74078 .59459 L F
.644 .555 .74 r
.55207 .75091 m .55132 .75418 L .55012 .75159 L F
.55207 .75091 m .55359 .75415 L .55132 .75418 L F
.121 0 0 r
.50257 .7709 m .50117 .77287 L .49908 .77319 L F
.356 .771 .979 r
.50468 .77343 m .50117 .77287 L .50257 .7709 L F
.605 .805 .976 r
.4553 .65037 m .45309 .65096 L .45178 .64986 L F
.638 .377 .507 r
.50998 .75339 m .51267 .75164 L .51036 .75165 L F
.50998 .75339 m .51245 .75378 L .51267 .75164 L F
.547 .271 .448 r
.51245 .75378 m .51533 .75159 L .51267 .75164 L F
.992 .744 .445 r
.60254 .72262 m .60353 .72103 L .60244 .72012 L F
.60254 .72262 m .60357 .72334 L .60353 .72103 L F
.953 .75 .292 r
.5742 .75569 m .5749 .75432 L .57428 .7531 L F
.5742 .75569 m .57478 .75692 L .5749 .75432 L F
0 .19 .705 r
.67055 .49602 m .67194 .49788 L .67157 .49852 L F
0 0 .015 r
.67158 .49977 m .67157 .49852 L .67194 .49788 L F
.67158 .49977 m .67151 .50075 L .67157 .49852 L F
.449 .86 .96 r
.76126 .58157 m .7596 .58256 L .75839 .5827 L F
.76126 .58157 m .76206 .58194 L .7596 .58256 L F
.645 .554 .737 r
.44632 .67117 m .44883 .6711 L .44761 .66776 L F
.695 .572 .713 r
.4729 .76826 m .47318 .7712 L .47066 .77101 L F
.612 .598 .812 r
.47438 .77344 m .47066 .77101 L .47318 .7712 L F
.534 .759 .98 r
.75849 .62414 m .7597 .62537 L .76079 .62515 L F
.683 .531 .673 r
.31592 .61826 m .31598 .62074 L .31843 .61812 L F
.239 0 0 r
.6102 .75028 m .60736 .75001 L .60815 .75122 L F
.529 .345 .575 r
.36609 .72092 m .36822 .71761 L .36661 .71848 L F
.936 .836 .721 r
.67001 .52006 m .67046 .52269 L .67008 .52234 L F
.935 .635 .446 r
.67046 .52269 m .66914 .52471 L .67008 .52234 L F
.67046 .52269 m .67092 .52569 L .66914 .52471 L F
0 0 0 r
.5518 .70045 m .54971 .70104 L .55257 .70009 L F
.5518 .70045 m .54969 .70121 L .54971 .70104 L F
.362 0 0 r
.4765 .77309 m .47438 .77344 L .47318 .7712 L F
.4765 .77309 m .47606 .77354 L .47438 .77344 L F
.424 .087 .289 r
.39643 .84318 m .39279 .84508 L .39605 .84465 L F
.655 .514 .68 r
.39279 .84508 m .39443 .8466 L .39605 .84465 L F
.833 .719 .738 r
.54649 .75925 m .54934 .75951 L .54712 .76261 L F
.398 0 .097 r
.7141 .52036 m .71335 .52195 L .711 .52221 L F
.281 0 .052 r
.71629 .51979 m .71335 .52195 L .7141 .52036 L F
.789 .602 .648 r
.59532 .55972 m .59623 .56301 L .5936 .56194 L F
0 0 0 r
.59492 .56086 m .59532 .55972 L .5936 .56194 L F
.697 .593 .736 r
.59683 .55886 m .59623 .56301 L .59532 .55972 L F
.632 .947 .948 r
.59652 .55826 m .59532 .55972 L .59492 .56086 L F
.59652 .55826 m .59683 .55886 L .59532 .55972 L F
.653 .62 .804 r
.69686 .49563 m .69455 .4963 L .69326 .49323 L F
.922 .73 .627 r
.57172 .77334 m .57229 .77103 L .57001 .77063 L F
.59 .845 .993 r
.76529 .58212 m .76206 .58194 L .76432 .58096 L F
.603 .793 .972 r
.76767 .5815 m .76529 .58212 L .76432 .58096 L F
.902 .698 .618 r
.62206 .50975 m .61926 .50932 L .62083 .50646 L F
.899 .648 .551 r
.62206 .50975 m .62019 .5103 L .61926 .50932 L F
.573 .54 .78 r
.62426 .50907 m .62206 .50975 L .62083 .50646 L F
.62423 .50759 m .62083 .50646 L .62421 .5068 L F
.62426 .50907 m .62318 .50825 L .62423 .50759 L F
.62318 .50825 m .62083 .50646 L .62423 .50759 L F
.829 .981 .88 r
.62259 .50863 m .62019 .5103 L .62206 .50975 L F
.62316 .50744 m .62062 .50989 L .62259 .50863 L F
.62062 .50989 m .62019 .5103 L .62259 .50863 L F
.488 .29 .537 r
.62206 .50975 m .62203 .51192 L .62426 .50907 L F
.597 .695 .912 r
.62316 .50744 m .62206 .50975 L .62426 .50907 L F
.891 .626 .53 r
.62206 .50975 m .62203 .51192 L .62019 .5103 L F
.647 .18 .131 r
.54019 .77154 m .54238 .773 L .53887 .77276 L F
.842 .512 .429 r
.54776 .70986 m .54617 .71149 L .54593 .70961 L F
.54776 .70986 m .54936 .71263 L .54617 .71149 L F
.794 .506 .5 r
.55133 .71242 m .54936 .71263 L .54776 .70986 L F
.551 .524 .779 r
.36273 .70131 m .36376 .6978 L .36163 .69832 L F
.36273 .70131 m .3648 .70098 L .36376 .6978 L F
.601 .529 .746 r
.3636 .70459 m .3648 .70098 L .36273 .70131 L F
.364 .605 .941 r
.59262 .6931 m .59444 .69145 L .59114 .69118 L F
0 0 0 r
.59175 .6953 m .59262 .6931 L .59349 .69552 L F
.59175 .6953 m .59444 .69145 L .59262 .6931 L F
.468 .634 .927 r
.34506 .59807 m .34321 .59825 L .34137 .59598 L F
.215 .703 .927 r
.35946 .71278 m .35775 .71221 L .35583 .71226 L F
.206 .733 .819 r
.35775 .71221 m .36137 .71185 L .35946 .71278 L F
.591 .165 .203 r
.36137 .71185 m .35775 .71221 L .35946 .71278 L F
.297 .565 .931 r
.34893 .5977 m .34836 .5994 L .34706 .59777 L F
.34893 .5977 m .35083 .59972 L .34836 .5994 L F
.841 .824 .832 r
.6202 .51316 m .61636 .51427 L .61843 .51163 L F
.6202 .51316 m .61773 .51554 L .61636 .51427 L F
.695 .812 .938 r
.62203 .51192 m .6202 .51316 L .61843 .51163 L F
.458 .49 .804 r
.51265 .76826 m .51113 .76876 L .50921 .76513 L F
.227 0 .207 r
.51265 .76826 m .51113 .76876 L .51054 .77023 L F
.51265 .76826 m .51113 .76876 L .51054 .77023 L F
0 0 0 r
.56043 .69301 m .55952 .69476 L .55845 .69592 L F
.584 .943 .819 r
.55952 .69476 m .55773 .69598 L .55845 .69592 L F
.381 .209 .519 r
.45399 .77373 m .4557 .77324 L .45581 .77082 L F
.479 .359 .638 r
.45399 .77373 m .45612 .77569 L .4557 .77324 L F
.45399 .77373 m .45419 .77618 L .45612 .77569 L F
.541 .674 .925 r
.26567 .63616 m .26485 .63812 L .26355 .63663 L F
.26567 .63616 m .26683 .63775 L .26485 .63812 L F
.707 .254 0 r
.56758 .72294 m .56557 .72015 L .56653 .72105 L F
.894 .669 .59 r
.51265 .76826 m .51428 .76817 L .51486 .76763 L F
.51265 .76826 m .51488 .77014 L .51428 .76817 L F
0 .188 .719 r
.65346 .50048 m .65509 .50288 L .65404 .5019 L F
.227 .457 .873 r
.6883 .51469 m .68684 .51592 L .68593 .51421 L F
.6883 .51469 m .68959 .51723 L .68684 .51592 L F
.803 .539 .539 r
.68395 .53979 m .68093 .53935 L .68084 .53732 L F
.725 .287 .211 r
.68395 .53979 m .68271 .54109 L .68093 .53935 L F
.048 0 0 r
.68644 .54031 m .68271 .54109 L .68395 .53979 L F
.588 .55 .779 r
.47268 .66446 m .47057 .66503 L .46925 .66135 L F
.581 .46 .679 r
.47352 .66774 m .47057 .66503 L .47268 .66446 L F
.47352 .66774 m .47105 .66825 L .47057 .66503 L F
.534 .308 .518 r
.6317 .55624 m .62936 .55846 L .62941 .55682 L F
.29 .378 .781 r
.26276 .65501 m .26355 .65302 L .26191 .65427 L F
.26276 .65501 m .26482 .65645 L .26355 .65302 L F
.748 .523 .589 r
.50582 .7598 m .50247 .76182 L .50314 .75838 L F
.567 .325 .508 r
.73615 .5958 m .7388 .59572 L .73853 .59349 L F
.365 .185 .499 r
.73853 .59349 m .74078 .59459 L .74106 .59267 L F
.73853 .59349 m .7388 .59572 L .74078 .59459 L F
.461 .756 .993 r
.64495 .52322 m .64823 .524 L .64779 .52301 L F
.451 .749 .992 r
.64823 .524 m .65062 .52379 L .64779 .52301 L F
.342 .46 .835 r
.64823 .524 m .65117 .52589 L .65062 .52379 L F
.958 .739 .288 r
.57439 .75942 m .57393 .76143 L .57528 .76225 L F
.57439 .75942 m .57393 .759 L .57393 .76143 L F
.36 0 .204 r
.4235 .68948 m .42526 .68983 L .42632 .68766 L F
.379 .019 .222 r
.42526 .68983 m .42841 .68716 L .42632 .68766 L F
.856 .582 .047 r
.52489 .77238 m .52499 .77117 L .52276 .77105 L F
.52489 .77238 m .52527 .77323 L .52499 .77117 L F
.9 .877 .444 r
.59015 .68201 m .5893 .68343 L .58667 .68325 L F
.59015 .68201 m .58927 .68365 L .5893 .68343 L F
.612 .279 .382 r
.59015 .68201 m .59272 .68374 L .59208 .68218 L F
.483 0 0 r
.59139 .68309 m .59015 .68201 L .59023 .68174 L F
.59139 .68309 m .59272 .68374 L .59015 .68201 L F
.581 .511 .741 r
.50265 .74534 m .4994 .74313 L .50188 .74336 L F
.322 .785 .941 r
.33091 .59332 m .33051 .59405 L .32889 .59332 L F
.33091 .59332 m .33284 .59377 L .33051 .59405 L F
.889 .905 .832 r
.54352 .76762 m .54717 .76601 L .54658 .76539 L F
.555 .113 .155 r
.54549 .76885 m .54717 .76601 L .54352 .76762 L F
.414 0 0 r
.54803 .76649 m .54658 .76539 L .54717 .76601 L F
0 0 0 r
.54803 .76649 m .54717 .76601 L .54549 .76885 L F
.506 .227 .425 r
.52259 .7348 m .52023 .73707 L .52073 .73523 L F
.727 .72 .844 r
.48177 .67631 m .47879 .67683 L .48061 .67388 L F
.459 .157 .365 r
.48067 .67805 m .47879 .67683 L .48177 .67631 L F
.605 .604 .824 r
.48273 .67295 m .48177 .67631 L .48061 .67388 L F
.48273 .67295 m .48418 .67617 L .48177 .67631 L F
.97 .656 .291 r
.48273 .67295 m .48319 .67562 L .48418 .67617 L F
.169 0 0 r
.48414 .67502 m .48319 .67562 L .4843 .67454 L F
.48369 .67641 m .48319 .67562 L .48414 .67502 L F
0 0 0 r
.48319 .67562 m .48177 .67631 L .48213 .67629 L F
.48319 .67562 m .48213 .67629 L .48418 .67617 L F
.48319 .67562 m .48067 .67805 L .48177 .67631 L F
.66 .683 .861 r
.74307 .61678 m .74417 .61811 L .7464 .6172 L F
.785 .721 .792 r
.51054 .77023 m .51488 .77014 L .51265 .76826 L F
.564 .063 .022 r
.51054 .77023 m .51383 .77193 L .51488 .77014 L F
.51383 .77193 m .51439 .77194 L .51488 .77014 L F
.898 .527 .324 r
.51446 .77169 m .51683 .77272 L .51488 .77014 L F
.5149 .7721 m .51683 .77272 L .51446 .77169 L F
.51511 .77236 m .51683 .77272 L .51439 .77194 L F
.636 .508 .69 r
.51753 .77216 m .51533 .77249 L .51716 .76948 L F
.898 .527 .324 r
.51432 .77219 m .51528 .7725 L .51683 .77272 L F
.636 .508 .69 r
.51533 .77249 m .51528 .7725 L .5153 .77247 L F
.51533 .77249 m .5153 .77247 L .51716 .76948 L F
.898 .527 .324 r
.51439 .77194 m .5149 .7721 L .51446 .77169 L F
.51432 .77219 m .51511 .77236 L .51439 .77194 L F
.77 .688 .772 r
.51562 .77195 m .5153 .77247 L .51501 .77194 L F
.5153 .77247 m .51528 .7725 L .51525 .77244 L F
.5153 .77247 m .51525 .77244 L .51501 .77194 L F
.51716 .76948 m .51562 .77195 L .51368 .76917 L F
.51562 .77195 m .51501 .77194 L .51368 .76917 L F
.564 .063 .022 r
.51383 .77193 m .51432 .77219 L .51439 .77194 L F
.856 .757 .753 r
.6785 .5087 m .67674 .51158 L .67937 .51141 L F
.851 .788 .789 r
.67674 .51158 m .6781 .51296 L .67937 .51141 L F
0 0 .553 r
.47821 .78828 m .47778 .79023 L .47714 .78775 L F
.372 .608 .941 r
.47821 .78828 m .47989 .79088 L .47778 .79023 L F
.475 .049 .151 r
.53146 .72315 m .53379 .72312 L .53489 .72139 L F
.469 .043 .148 r
.53489 .72139 m .53379 .72312 L .53727 .72211 L F
.987 .816 .586 r
.65432 .53048 m .65558 .52942 L .65453 .52828 L F
.841 .882 .871 r
.65453 .52828 m .65558 .52942 L .65575 .52887 L F
.917 .97 .676 r
.65575 .52887 m .65558 .52942 L .65432 .53048 L F
.162 0 0 r
.3124 .64765 m .30849 .64964 L .31047 .64812 L F
.243 .176 .578 r
.54781 .69477 m .5506 .69686 L .55217 .69367 L F
.899 .791 .732 r
.3487 .7067 m .34527 .70881 L .3475 .70599 L F
.3487 .7067 m .34675 .71043 L .34527 .70881 L F
.547 .105 .152 r
.3475 .70599 m .3499 .70525 L .3487 .7067 L F
.303 0 0 r
.41804 .66291 m .41655 .66348 L .41449 .6631 L F
.333 0 0 r
.42007 .66216 m .41655 .66348 L .41804 .66291 L F
.483 .089 .216 r
.66339 .5421 m .66038 .54515 L .65998 .54428 L F
0 0 .366 r
.65998 .54428 m .66038 .54515 L .66049 .54483 L F
.361 0 .05 r
.66107 .54261 m .65998 .54428 L .65938 .54362 L F
.483 .089 .216 r
.66339 .5421 m .65998 .54428 L .66107 .54261 L F
0 0 .366 r
.65998 .54428 m .66049 .54483 L .66183 .5408 L F
.361 0 .05 r
.65938 .54362 m .65998 .54428 L .65771 .54462 L F
.775 .303 0 r
.57004 .74546 m .57165 .74799 L .57248 .74856 L F
.924 .663 .176 r
.57223 .74978 m .57248 .74856 L .57165 .74799 L F
.57223 .74978 m .57282 .75175 L .57248 .74856 L F
.7 .531 .656 r
.71322 .59549 m .71523 .59547 L .71529 .59296 L F
.741 .449 .486 r
.71916 .59503 m .71529 .59296 L .71523 .59547 L F
.722 .333 .313 r
.55133 .71242 m .54963 .71405 L .54936 .71263 L F
.722 .334 .314 r
.55133 .71242 m .55316 .7144 L .54963 .71405 L F
.579 .413 .62 r
.53953 .72919 m .54044 .73181 L .53736 .73199 L F
.756 .518 .572 r
.54044 .73181 m .53617 .73371 L .53736 .73199 L F
.926 .749 .644 r
.62377 .51817 m .62474 .52067 L .62528 .51802 L F
.351 .084 .361 r
.36456 .65702 m .36213 .65971 L .3643 .65932 L F
.488 .235 .457 r
.36629 .65873 m .36456 .65702 L .3643 .65932 L F
.36629 .65873 m .36668 .65664 L .36456 .65702 L F
.758 .521 .574 r
.50112 .80423 m .50421 .80697 L .49975 .80623 L F
.533 .34 .566 r
.49438 .76237 m .4921 .76525 L .49201 .76271 L F
.947 .676 .492 r
.60406 .72843 m .6054 .72648 L .6037 .72591 L F
.60406 .72843 m .60554 .72892 L .6054 .72648 L F
.573 .5 .735 r
.26202 .62889 m .26009 .62941 L .25931 .62596 L F
.484 .354 .627 r
.26202 .62889 m .26039 .63173 L .26009 .62941 L F
.425 .034 .19 r
.27827 .60739 m .2798 .60806 L .27852 .60832 L F
.225 .669 .953 r
.31055 .59122 m .31014 .59187 L .30845 .59135 L F
.31055 .59122 m .31201 .59202 L .31014 .59187 L F
.87 .859 .827 r
.62767 .52787 m .63126 .52622 L .63068 .52553 L F
.97 .927 .615 r
.63068 .52553 m .63126 .52622 L .63191 .52405 L F
.42 0 0 r
.73025 .5955 m .73278 .5959 L .73373 .59553 L F
.954 .721 .265 r
.73553 .59546 m .73373 .59553 L .73278 .5959 L F
.73553 .59546 m .73598 .59578 L .73373 .59553 L F
.678 .976 .826 r
.73521 .59522 m .73553 .59546 L .73409 .59586 L F
.73733 .59401 m .73553 .59546 L .73521 .59522 L F
.954 .721 .265 r
.73553 .59546 m .73615 .5958 L .73598 .59578 L F
.509 .732 .974 r
.74989 .61768 m .75149 .61623 L .7492 .61645 L F
.74989 .61768 m .75228 .61746 L .75149 .61623 L F
.414 .806 .987 r
.33056 .8788 m .33413 .87906 L .33203 .87937 L F
.33056 .8788 m .33413 .87906 L .33203 .87937 L F
.704 .514 .629 r
.69518 .51049 m .69495 .51233 L .69741 .51191 L F
.301 0 .001 r
.41832 .70392 m .41689 .70552 L .41478 .70592 L F
.251 0 0 r
.41901 .70501 m .41832 .70392 L .42059 .70355 L F
.41901 .70501 m .41689 .70552 L .41832 .70392 L F
.611 .472 .667 r
.7741 .59531 m .77541 .59839 L .77252 .59876 L F
.468 .453 .759 r
.77479 .60099 m .77252 .59876 L .77541 .59839 L F
.65 .602 .788 r
.74171 .60705 m .73812 .60446 L .7405 .60405 L F
.575 .596 .836 r
.74408 .60666 m .74171 .60705 L .7405 .60405 L F
.562 .234 .369 r
.40388 .66537 m .40301 .66766 L .40074 .6676 L F
.265 0 .052 r
.40649 .66512 m .40301 .66766 L .40388 .66537 L F
.899 .95 .828 r
.58804 .70841 m .58844 .71106 L .59052 .71102 L F
.58804 .70841 m .58597 .71116 L .58844 .71106 L F
.807 .673 .716 r
.6123 .73434 m .61369 .73745 L .61425 .73526 L F
.321 .018 .285 r
.49296 .74 m .49402 .74189 L .49482 .73946 L F
.49296 .74 m .49202 .74272 L .49402 .74189 L F
.601 .529 .746 r
.3636 .70459 m .36591 .70418 L .3648 .70098 L F
.59 .48 .696 r
.3636 .70459 m .36605 .70661 L .36591 .70418 L F
.3636 .70459 m .36383 .70701 L .36605 .70661 L F
.027 0 0 r
.63839 .55238 m .63987 .55175 L .64202 .55114 L F
.79 .586 .625 r
.51823 .75129 m .52167 .75423 L .52176 .7517 L F
.864 .665 .632 r
.68093 .53935 m .6794 .53669 L .68084 .53732 L F
.561 .527 .775 r
.78142 .60366 m .77875 .60453 L .7781 .60173 L F
.455 .325 .614 r
.78142 .60366 m .77907 .60665 L .77875 .60453 L F
.514 .236 .431 r
.51916 .80758 m .52119 .80893 L .51805 .80794 L F
.51916 .80758 m .52107 .80718 L .52119 .80893 L F
.368 0 .109 r
.56106 .68695 m .56546 .68406 L .56085 .68476 L F
.56106 .68695 m .56344 .68663 L .56546 .68406 L F
.524 .499 .771 r
.56546 .68406 m .56603 .68133 L .5639 .68183 L F
.56546 .68406 m .56714 .68426 L .56603 .68133 L F
.235 .03 .385 r
.56699 .68422 m .56698 .6868 L .56495 .68732 L F
.258 .047 .391 r
.56852 .68591 m .56698 .6868 L .56699 .68422 L F
.27 0 0 r
.56344 .68663 m .56714 .68426 L .56546 .68406 L F
.507 .812 1 r
.54072 .74195 m .53973 .74315 L .53819 .74242 L F
.49 .788 .998 r
.54072 .74195 m .54221 .74288 L .53973 .74315 L F
.497 .597 .884 r
.32394 .60593 m .32449 .60736 L .32583 .60562 L F
.442 .517 .84 r
.32449 .60736 m .32738 .60887 L .32583 .60562 L F
.57 .483 .717 r
.32449 .60736 m .32516 .60978 L .32738 .60887 L F
.626 .726 .919 r
.73506 .61603 m .73737 .61534 L .734 .61442 L F
.466 .284 .549 r
.3348 .62623 m .33457 .62901 L .3326 .62956 L F
.341 .01 .25 r
.3326 .62956 m .3338 .63058 L .33192 .63139 L F
.3326 .62956 m .33457 .62901 L .3338 .63058 L F
.641 .715 .901 r
.67887 .49496 m .6799 .49746 L .68248 .4961 L F
.554 .65 .898 r
.6799 .49746 m .68287 .49799 L .68248 .4961 L F
.084 .642 .778 r
.2678 .5847 m .26764 .58487 L .26595 .58468 L F
.2678 .5847 m .26976 .58479 L .26764 .58487 L F
.286 0 0 r
.63162 .53014 m .63372 .53026 L .63469 .52953 L F
.888 .99 .779 r
.63372 .53026 m .63205 .53394 L .63549 .52979 L F
.591 .54 .766 r
.63549 .52979 m .63847 .53374 L .6371 .53031 L F
.417 0 0 r
.6371 .53031 m .63372 .53026 L .63549 .52979 L F
.43 0 0 r
.63469 .52953 m .63372 .53026 L .6371 .53031 L F
.628 .389 .537 r
.4702 .79312 m .4696 .79552 L .46863 .79273 L F
.4702 .79312 m .47198 .79539 L .4696 .79552 L F
.622 .587 .793 r
.7361 .59778 m .73714 .60101 L .73475 .60157 L F
.613 .57 .782 r
.73812 .60446 m .73475 .60157 L .73714 .60101 L F
.577 .07 .012 r
.55524 .70931 m .55755 .71061 L .55875 .70957 L F
.32 0 0 r
.55755 .71061 m .56125 .71128 L .55875 .70957 L F
.477 .364 .645 r
.45531 .76844 m .4572 .76805 L .45713 .7649 L F
.385 .283 .615 r
.45581 .77082 m .4572 .76805 L .45531 .76844 L F
.73 .356 .342 r
.479 .79822 m .48242 .79855 L .48107 .80057 L F
.708 .329 .328 r
.48242 .79855 m .48456 .80077 L .48107 .80057 L F
.988 .817 .581 r
.60087 .69805 m .60131 .69575 L .60028 .69496 L F
0 0 0 r
.78182 .61057 m .78062 .61171 L .77993 .61182 L F
.652 .729 .905 r
.78054 .61246 m .77859 .61205 L .77993 .61182 L F
.73 .649 .768 r
.77732 .61178 m .78054 .61246 L .77993 .61182 L F
0 0 0 r
.78062 .61171 m .77891 .61332 L .77993 .61182 L F
.652 .729 .905 r
.77859 .61205 m .77732 .61178 L .77993 .61182 L F
.602 .621 .842 r
.35783 .69326 m .36142 .69586 L .36021 .69266 L F
.471 .435 .737 r
.36142 .69586 m .36243 .69222 L .36021 .69266 L F
.36142 .69586 m .36322 .69543 L .36243 .69222 L F
.548 .41 .645 r
.36142 .69586 m .36376 .6978 L .36322 .69543 L F
.36142 .69586 m .36163 .69832 L .36376 .6978 L F
.441 .758 .995 r
.39755 .69731 m .39676 .69845 L .39581 .69717 L F
.39755 .69731 m .3989 .69828 L .39676 .69845 L F
.812 .854 .881 r
.61773 .51554 m .6138 .51685 L .61636 .51427 L F
.583 .928 .953 r
.27619 .63869 m .27679 .63763 L .27858 .63825 L F
.27619 .63869 m .27472 .63851 L .27679 .63763 L F
.145 0 0 r
.45823 .78711 m .4602 .78749 L .46012 .78748 L F
.226 .42 .844 r
.4602 .78749 m .46289 .79025 L .46183 .78905 L F
.4602 .78749 m .46183 .78905 L .46012 .78748 L F
.925 .898 .782 r
.34004 .71802 m .34087 .71391 L .34241 .71478 L F
.26 .759 .895 r
.34087 .71391 m .34446 .71384 L .34241 .71478 L F
.338 .066 .346 r
.31843 .61812 m .31598 .62074 L .31781 .62008 L F
.31843 .61812 m .31598 .62074 L .31781 .62008 L F
.342 .07 .348 r
.31843 .61812 m .31781 .62008 L .32027 .61744 L F
.523 .23 .41 r
.43875 .68162 m .44103 .68134 L .44171 .67894 L F
.49 .297 .545 r
.44171 .67894 m .44391 .67862 L .44403 .67622 L F
.556 .261 .422 r
.44171 .67894 m .44368 .68046 L .44391 .67862 L F
.44171 .67894 m .44103 .68134 L .44368 .68046 L F
.673 .647 .816 r
.36482 .71287 m .36852 .71521 L .36718 .71213 L F
0 .184 .71 r
.36852 .71521 m .36911 .71409 L .36718 .71213 L F
0 .214 .731 r
.36852 .71521 m .37054 .71727 L .36911 .71409 L F
.559 .334 .53 r
.36852 .71521 m .36822 .71761 L .37054 .71727 L F
.989 .792 .547 r
.5936 .70092 m .59284 .69786 L .59444 .69887 L F
.47 .218 .45 r
.34618 .61322 m .34871 .6113 L .34786 .61455 L F
.471 .204 .427 r
.34549 .61689 m .34618 .61322 L .34786 .61455 L F
.13 0 0 r
.39687 .71236 m .3954 .71328 L .39326 .71367 L F
.117 0 0 r
.39762 .71284 m .39687 .71236 L .39893 .71195 L F
.39762 .71284 m .3954 .71328 L .39687 .71236 L F
.704 .69 .833 r
.48061 .67388 m .47879 .67683 L .47698 .67314 L F
.459 .157 .365 r
.48067 .67805 m .47837 .67855 L .47879 .67683 L F
.645 .664 .854 r
.72211 .50412 m .71905 .50303 L .72148 .50234 L F
.398 .556 .894 r
.72148 .50234 m .72382 .50272 L .72211 .50412 L F
.546 .854 .998 r
.72211 .50412 m .72382 .50272 L .72452 .50354 L F
.72211 .50412 m .72382 .50272 L .72452 .50354 L F
0 0 .501 r
.65567 .51461 m .65729 .51689 L .65662 .51561 L F
.622 .682 .886 r
.73737 .61534 m .74094 .61733 L .7397 .61469 L F
.646 .722 .903 r
.74094 .61733 m .74207 .61414 L .7397 .61469 L F
.74094 .61733 m .74307 .61678 L .74207 .61414 L F
.438 .655 .952 r
.29187 .58688 m .29144 .58868 L .29004 .58691 L F
.29187 .58688 m .29381 .58885 L .29144 .58868 L F
.544 .29 .481 r
.32027 .61744 m .32256 .61712 L .32262 .61409 L F
.438 .321 .623 r
.32262 .61409 m .32472 .6118 L .32278 .61227 L F
.32262 .61409 m .32501 .61437 L .32472 .6118 L F
.444 .212 .466 r
.32262 .61409 m .32455 .61656 L .32501 .61437 L F
.32262 .61409 m .32256 .61712 L .32455 .61656 L F
.319 0 .141 r
.3066 .63153 m .30751 .63305 L .30814 .63131 L F
.3066 .63153 m .30548 .63358 L .30751 .63305 L F
.3 0 .138 r
.74106 .59267 m .74326 .59202 L .74384 .59029 L F
.302 0 .139 r
.74384 .59029 m .74564 .59132 L .74603 .58943 L F
.74384 .59029 m .74326 .59202 L .74564 .59132 L F
.394 .766 .992 r
.29714 .59026 m .29926 .59007 L .30075 .5909 L F
.444 .748 .993 r
.30134 .58956 m .30075 .5909 L .29926 .59007 L F
.30134 .58956 m .30272 .59067 L .30075 .5909 L F
.55 .482 .732 r
.35507 .60392 m .35303 .60451 L .35226 .60111 L F
.498 .372 .64 r
.35511 .60601 m .35303 .60451 L .35507 .60392 L F
.35511 .60601 m .35315 .60653 L .35303 .60451 L F
.514 .297 .522 r
.43417 .68473 m .43636 .68432 L .43656 .68199 L F
.496 .282 .518 r
.43656 .68199 m .43849 .68381 L .43875 .68162 L F
.43656 .68199 m .43636 .68432 L .43849 .68381 L F
.535 .04 .026 r
.50577 .80323 m .50307 .80368 L .50626 .80371 L F
.485 .279 .524 r
.50421 .80697 m .50626 .80371 L .50642 .80654 L F
.812 .547 .538 r
.50642 .80654 m .50626 .80371 L .50307 .80368 L F
.716 .657 .79 r
.50577 .80323 m .50626 .80371 L .50859 .80128 L F
.832 .682 .697 r
.6107 .73672 m .61369 .73745 L .6123 .73434 L F
.797 .509 .501 r
.61083 .7396 m .61369 .73745 L .6107 .73672 L F
.61083 .7396 m .61382 .73991 L .61369 .73745 L F
.338 .788 .64 r
.74408 .59521 m .74749 .59344 L .74624 .59407 L F
0 0 0 r
.74749 .59344 m .74862 .59347 L .74624 .59407 L F
.74749 .59344 m .74975 .59266 L .74862 .59347 L F
.852 .822 .819 r
.67674 .51158 m .67702 .51381 L .6781 .51296 L F
.67674 .51158 m .67446 .51445 L .67702 .51381 L F
.887 .459 .136 r
.67725 .51622 m .67702 .51381 L .67446 .51445 L F
.67725 .51622 m .67949 .51845 L .67702 .51381 L F
.98 .715 .453 r
.62316 .50744 m .62421 .5068 L .62539 .50524 L F
.62316 .50744 m .62426 .50907 L .62421 .5068 L F
.519 .623 .895 r
.68208 .48605 m .68081 .48859 L .6798 .48668 L F
.68208 .48605 m .6836 .48859 L .68081 .48859 L F
.461 .614 .915 r
.68419 .49043 m .68081 .48859 L .6836 .48859 L F
.796 .319 0 r
.65931 .51049 m .65937 .50959 L .65827 .5085 L F
.65931 .51049 m .66067 .51163 L .65937 .50959 L F
.63 .099 0 r
.48553 .79261 m .48733 .79423 L .48681 .79328 L F
.757 .415 .405 r
.48998 .7952 m .48681 .79328 L .48733 .79423 L F
.521 .475 .746 r
.77591 .59283 m .77602 .5947 L .7741 .59531 L F
.683 .506 .641 r
.77704 .59807 m .7741 .59531 L .77602 .5947 L F
.77704 .59807 m .77541 .59839 L .7741 .59531 L F
.651 .582 .765 r
.68352 .50324 m .68102 .50389 L .6842 .50303 L F
.508 .502 .785 r
.50111 .75396 m .50211 .7574 L .50392 .75621 L F
0 0 .306 r
.50314 .75838 m .50392 .75621 L .50211 .7574 L F
.945 .919 .756 r
.66718 .53408 m .66781 .53064 L .66627 .53334 L F
.965 .938 .681 r
.6653 .53646 m .66718 .53408 L .66627 .53334 L F
.6653 .53646 m .66585 .5374 L .66718 .53408 L F
.972 .695 .446 r
.54989 .73744 m .54865 .73694 L .5493 .73495 L F
.405 .317 .644 r
.54959 .73201 m .5493 .73495 L .55164 .73396 L F
.619 .438 .615 r
.54865 .73694 m .55164 .73396 L .5493 .73495 L F
.469 .124 .298 r
.39077 .67113 m .3899 .67295 L .3878 .67323 L F
.363 .034 .266 r
.39281 .67034 m .3899 .67295 L .39077 .67113 L F
.379 0 0 r
.54658 .76539 m .55027 .76531 L .54791 .76615 L F
.678 .435 .546 r
.60792 .56519 m .6044 .56756 L .60409 .56488 L F
.60792 .56519 m .60797 .56738 L .6044 .56756 L F
.637 .401 .544 r
.61048 .56507 m .60797 .56738 L .60792 .56519 L F
0 0 0 r
.63398 .52122 m .63261 .52253 L .63447 .51946 L F
.488 .817 .515 r
.63398 .52122 m .63293 .52222 L .63261 .52253 L F
.884 .926 .539 r
.63191 .52405 m .63181 .52373 L .6332 .5206 L F
.488 .817 .515 r
.63293 .52222 m .6314 .52367 L .63261 .52253 L F
.884 .926 .539 r
.63191 .52405 m .63241 .52272 L .63261 .52253 L F
.63241 .52272 m .6332 .5206 L .63261 .52253 L F
.97 .927 .615 r
.63068 .52553 m .63191 .52405 L .63261 .52253 L F
.891 .669 .596 r
.59701 .69012 m .59705 .6875 L .59457 .68689 L F
.058 .618 .8 r
.42358 .66243 m .42224 .66223 L .42007 .66216 L F
.195 0 0 r
.42565 .66177 m .42224 .66223 L .42358 .66243 L F
.503 .236 .443 r
.42847 .6985 m .42804 .70033 L .42601 .70062 L F
.349 .071 .343 r
.43043 .69797 m .42804 .70033 L .42847 .6985 L F
.056 0 .341 r
.36441 .70998 m .36605 .70661 L .36383 .70701 L F
.884 .717 .67 r
.6133 .52114 m .61293 .52295 L .61172 .51988 L F
.452 .281 .557 r
.38571 .67617 m .38561 .67858 L .38367 .67911 L F
.453 .277 .551 r
.38561 .67858 m .38356 .68178 L .38367 .67911 L F
.583 .521 .752 r
.71208 .60421 m .71333 .60026 L .71098 .60088 L F
.71208 .60421 m .71448 .60371 L .71333 .60026 L F
.652 .707 .887 r
.27091 .63938 m .26683 .63775 L .26901 .63744 L F
.52 .7 .952 r
.27072 .63698 m .27091 .63938 L .26901 .63744 L F
.27072 .63698 m .27272 .63892 L .27091 .63938 L F
.474 .586 .886 r
.68564 .48852 m .68419 .49043 L .6836 .48859 L F
.494 .615 .9 r
.68564 .48852 m .68655 .49055 L .68419 .49043 L F
.843 .7 .705 r
.61371 .74213 m .61702 .74009 L .61382 .73991 L F
.61371 .74213 m .61569 .74327 L .61702 .74009 L F
.247 0 0 r
.40849 .6493 m .41062 .64969 L .41206 .64956 L F
.16 .7 .762 r
.41062 .64969 m .41434 .64924 L .41206 .64956 L F
.446 .019 .133 r
.24801 .58894 m .25011 .58886 L .25075 .58788 L F
.415 0 .116 r
.25011 .58886 m .25222 .58869 L .25075 .58788 L F
.056 0 .341 r
.36441 .70998 m .36591 .70938 L .36605 .70661 L F
0 0 .032 r
.36441 .70998 m .36339 .71208 L .36591 .70938 L F
.392 .161 .439 r
.26151 .62354 m .26096 .62584 L .25931 .62596 L F
.573 .5 .735 r
.26202 .62889 m .25931 .62596 L .26096 .62584 L F
.42 .165 .418 r
.32278 .61227 m .32472 .6118 L .32516 .60978 L F
.425 .169 .42 r
.32516 .60978 m .32472 .6118 L .32738 .60887 L F
.991 .846 .481 r
.66479 .53872 m .66541 .53967 L .66585 .5374 L F
.987 .856 .486 r
.6653 .53646 m .66479 .53872 L .66585 .5374 L F
.49 .157 .329 r
.46568 .68172 m .46472 .68387 L .46244 .68415 L F
.638 .35 .465 r
.46808 .68149 m .46472 .68387 L .46568 .68172 L F
.68 .609 .77 r
.3781 .72038 m .377 .72432 L .3762 .72164 L F
0 0 .383 r
.3774 .72347 m .377 .72432 L .3773 .72323 L F
.467 .476 .784 r
.377 .72432 m .3774 .72347 L .3762 .72164 L F
.79 .343 0 r
.3762 .72164 m .3774 .72347 L .3759 .72198 L F
.467 .476 .784 r
.377 .72432 m .37852 .72518 L .3774 .72347 L F
.348 .484 .854 r
.37752 .72376 m .37852 .72518 L .377 .72432 L F
.79 .343 0 r
.3774 .72347 m .37852 .72518 L .37752 .72376 L F
.348 .484 .854 r
.37805 .72318 m .37852 .72518 L .37752 .72376 L F
.79 .343 0 r
.37752 .72376 m .37852 .72518 L .37767 .72414 L F
0 0 .383 r
.37805 .72318 m .377 .72432 L .37807 .72208 L F
.79 .343 0 r
.3774 .72347 m .37767 .72414 L .3759 .72198 L F
0 0 .383 r
.37807 .72208 m .3774 .72347 L .3781 .72038 L F
.3774 .72347 m .3773 .72323 L .3781 .72038 L F
.632 .398 .545 r
.37852 .72518 m .37873 .72594 L .377 .72432 L F
.629 .41 .565 r
.4465 .67613 m .44915 .67622 L .44946 .67345 L F
.529 .489 .756 r
.44883 .6711 m .44946 .67345 L .45051 .67303 L F
.483 .283 .532 r
.44946 .67345 m .45115 .67551 L .45051 .67303 L F
.44946 .67345 m .44915 .67622 L .45115 .67551 L F
.643 .934 .968 r
.59396 .75141 m .596 .75206 L .5944 .75 L F
.761 .852 .918 r
.5944 .75 m .596 .75206 L .59838 .74889 L F
.267 0 0 r
.76434 .59502 m .76808 .59295 L .76465 .59424 L F
.76434 .59502 m .76656 .59472 L .76808 .59295 L F
.126 .083 .535 r
.76808 .59295 m .76899 .58942 L .76698 .58987 L F
.642 .502 .678 r
.76656 .59472 m .77008 .593 L .76808 .59295 L F
.163 0 0 r
.48444 .78201 m .48113 .7845 L .48411 .78411 L F
.572 .905 .978 r
.48723 .78101 m .48444 .78201 L .48443 .78135 L F
.773 .695 .152 r
.48443 .78135 m .48444 .78201 L .48411 .78411 L F
.796 .407 .319 r
.57031 .72364 m .56909 .72524 L .56758 .72294 L F
.988 .753 .492 r
.57031 .72364 m .57024 .72622 L .56909 .72524 L F
.57031 .72364 m .57024 .72622 L .56909 .72524 L F
.776 .556 .602 r
.57361 .72645 m .57024 .72622 L .57031 .72364 L F
.852 .872 .855 r
.68547 .50203 m .68714 .50294 L .68877 .50109 L F
.642 .618 .811 r
.70045 .49817 m .69686 .49563 L .6991 .49522 L F
.549 .517 .772 r
.70165 .49483 m .70045 .49817 L .6991 .49522 L F
.70165 .49483 m .70277 .49774 L .70045 .49817 L F
.498 .302 .545 r
.70277 .49774 m .70052 .50062 L .70045 .49817 L F
.508 .278 .5 r
.36183 .66193 m .3643 .65932 L .36213 .65971 L F
.227 0 .261 r
.31358 .62351 m .31523 .62284 L .31598 .62074 L F
.266 0 .28 r
.31598 .62074 m .31708 .62127 L .31781 .62008 L F
.31598 .62074 m .31523 .62284 L .31708 .62127 L F
.301 .764 .947 r
.57361 .72645 m .57233 .72604 L .57024 .72622 L F
0 .313 .782 r
.57569 .7286 m .57233 .72604 L .57361 .72645 L F
.514 .637 .909 r
.39394 .69486 m .39375 .69762 L .39212 .69483 L F
.39394 .69486 m .39581 .69717 L .39375 .69762 L F
.587 .575 .807 r
.73943 .6007 m .73812 .60446 L .73714 .60101 L F
.73943 .6007 m .7405 .60405 L .73812 .60446 L F
.716 .632 .763 r
.69741 .51191 m .7006 .51221 L .7019 .50984 L F
.72 .511 .606 r
.69741 .51191 m .70099 .51484 L .7006 .51221 L F
.712 .627 .761 r
.7019 .50984 m .7006 .51221 L .7029 .50946 L F
.425 .299 .605 r
.7006 .51221 m .70099 .51484 L .70277 .51372 L F
.632 .479 .657 r
.69502 .51441 m .69741 .51191 L .69495 .51233 L F
.69502 .51441 m .69909 .51496 L .69741 .51191 L F
.594 .471 .683 r
.69502 .51441 m .69819 .51697 L .69909 .51496 L F
.69502 .51441 m .69601 .51749 L .69819 .51697 L F
.552 .616 .869 r
.3436 .72056 m .34538 .71996 L .34183 .71856 L F
.3436 .72056 m .34558 .72029 L .34538 .71996 L F
.376 .84 .879 r
.42683 .65044 m .42766 .64982 L .42902 .65029 L F
.204 0 .274 r
.56635 .68872 m .56495 .68732 L .56698 .6868 L F
.56635 .68872 m .56468 .68966 L .56495 .68732 L F
.299 .787 .895 r
.43084 .66128 m .42998 .66093 L .42788 .6613 L F
.189 .72 .75 r
.43368 .66028 m .42998 .66093 L .43084 .66128 L F
.818 .718 .755 r
.68073 .52407 m .68388 .52676 L .68195 .52622 L F
.647 .655 .843 r
.68073 .52407 m .68195 .52622 L .68193 .52541 L F
.761 .776 .866 r
.68195 .52622 m .68292 .52615 L .68242 .52561 L F
.917 .622 .469 r
.68213 .52563 m .68292 .52615 L .68231 .52557 L F
.68193 .52541 m .68231 .52557 L .68073 .52407 L F
.852 .814 .811 r
.68193 .52541 m .68195 .52622 L .68242 .52561 L F
.917 .622 .469 r
.68213 .52563 m .68231 .52557 L .68193 .52541 L F
.68292 .52615 m .68388 .52676 L .68196 .52512 L F
.68292 .52615 m .68196 .52512 L .68073 .52407 L F
.852 .814 .811 r
.68187 .52271 m .68193 .52541 L .68496 .52229 L F
.68193 .52541 m .68242 .52561 L .68496 .52229 L F
.647 .655 .843 r
.68073 .52407 m .68193 .52541 L .68187 .52271 L F
.917 .622 .469 r
.68138 .52514 m .68213 .52563 L .68073 .52407 L F
.761 .776 .866 r
.68242 .52561 m .68565 .52593 L .68496 .52229 L F
.68292 .52615 m .68565 .52593 L .68242 .52561 L F
.68292 .52615 m .68388 .52676 L .68565 .52593 L F
.68195 .52622 m .68388 .52676 L .68292 .52615 L F
.917 .622 .469 r
.68305 .52794 m .68388 .52676 L .68138 .52514 L F
.414 .053 .24 r
.4442 .68985 m .4431 .69196 L .44091 .69237 L F
.4 .036 .226 r
.44638 .68985 m .4431 .69196 L .4442 .68985 L F
.656 .266 .294 r
.51081 .80311 m .51245 .80123 L .50859 .80128 L F
.66 .291 .333 r
.51292 .80399 m .51245 .80123 L .51081 .80311 L F
.536 .881 .636 r
.28438 .60536 m .28286 .60668 L .28357 .60624 L F
.134 .35 .811 r
.54472 .73205 m .54735 .73384 L .54632 .73493 L F
.506 .56 .845 r
.54735 .73384 m .5466 .73695 L .54632 .73493 L F
.265 .735 .943 r
.28785 .65207 m .28844 .65142 L .28607 .65184 L F
.28785 .65207 m .29007 .65199 L .28844 .65142 L F
.487 .725 .977 r
.35416 .60076 m .35226 .60111 L .35083 .59972 L F
.55 .482 .732 r
.35507 .60392 m .35226 .60111 L .35416 .60076 L F
.931 .55 .193 r
.66471 .52442 m .66538 .5235 L .66419 .52258 L F
.836 .373 .096 r
.66639 .52531 m .66538 .5235 L .66471 .52442 L F
.958 .773 .611 r
.60062 .71629 m .60256 .71544 L .60159 .71465 L F
.60062 .71629 m .60229 .71795 L .60256 .71544 L F
.747 .521 .588 r
.60409 .56488 m .60265 .56739 L .60236 .56485 L F
.60409 .56488 m .6044 .56756 L .60265 .56739 L F
.529 .461 .724 r
.38849 .69057 m .38626 .69075 L .38549 .6872 L F
.338 .788 .64 r
.74408 .59521 m .74624 .59407 L .74441 .59528 L F
0 .161 .699 r
.56898 .74453 m .57165 .74799 L .57004 .74546 L F
.61 .14 .114 r
.49571 .79504 m .49232 .79558 L .49478 .79498 L F
.876 .752 .722 r
.49239 .79804 m .49571 .79504 L .49478 .79498 L F
.49239 .79804 m .49459 .7981 L .49571 .79504 L F
.059 0 .222 r
.53436 .80107 m .53249 .80369 L .53401 .80328 L F
0 0 0 r
.53401 .80328 m .53249 .80369 L .53105 .8057 L F
0 .015 .566 r
.48419 .79058 m .48553 .79261 L .48348 .79023 L F
.48419 .79058 m .48348 .79023 L .48174 .79032 L F
.985 .783 .551 r
.5972 .70876 m .59864 .70699 L .59736 .70622 L F
.5972 .70876 m .59839 .70963 L .59864 .70699 L F
.252 0 0 r
.63226 .50818 m .63457 .50785 L .63572 .50658 L F
.208 .312 .752 r
.63796 .50835 m .63572 .50658 L .63788 .50615 L F
.78 .522 .546 r
.63457 .50785 m .63788 .50615 L .63572 .50658 L F
.792 .295 0 r
.55164 .73396 m .54851 .73136 L .54959 .73201 L F
.302 0 0 r
.3989 .69828 m .40085 .69868 L .40245 .69867 L F
.141 0 0 r
.40085 .69868 m .40477 .69869 L .40245 .69867 L F
.562 .192 .296 r
.45201 .6866 m .45097 .68893 L .44893 .68747 L F
.523 .269 .472 r
.45476 .6846 m .45449 .68656 L .45201 .6866 L F
.491 .128 .277 r
.45449 .68656 m .45097 .68893 L .45201 .6866 L F
.455 .274 .546 r
.33652 .6283 m .3348 .62623 L .33626 .6256 L F
.33652 .6283 m .33457 .62901 L .3348 .62623 L F
.717 .377 .402 r
.59053 .72041 m .58953 .72065 L .5861 .72054 L F
.398 .402 .747 r
.38715 .68684 m .38549 .6872 L .38486 .68523 L F
.529 .461 .724 r
.38849 .69057 m .38549 .6872 L .38715 .68684 L F
.808 .488 .448 r
.59623 .56301 m .59522 .56414 L .5936 .56194 L F
.697 .593 .736 r
.59683 .55886 m .59904 .56226 L .59623 .56301 L F
.345 0 0 r
.59623 .56301 m .59806 .56357 L .59522 .56414 L F
.59623 .56301 m .59904 .56226 L .59806 .56357 L F
.51 .157 .304 r
.42342 .70196 m .42282 .70343 L .42059 .70355 L F
.279 0 .2 r
.42472 .70268 m .42342 .70196 L .42601 .70062 L F
.42472 .70268 m .42282 .70343 L .42342 .70196 L F
.657 .605 .785 r
.68496 .52229 m .68565 .52593 L .68863 .52365 L F
.379 0 0 r
.54658 .76539 m .54953 .76576 L .55027 .76531 L F
.578 .61 .848 r
.54947 .76323 m .55027 .76531 L .55266 .76482 L F
.667 .35 .427 r
.54953 .76576 m .55266 .76482 L .55027 .76531 L F
.859 .778 .771 r
.54211 .79756 m .53948 .79923 L .54152 .80028 L F
.79 .586 .625 r
.51823 .75129 m .51814 .75388 L .52167 .75423 L F
.951 .623 .367 r
.52057 .75563 m .52167 .75423 L .51814 .75388 L F
.52057 .75563 m .52128 .75598 L .52167 .75423 L F
.499 .32 .569 r
.47864 .78567 m .47924 .78723 L .47714 .78775 L F
0 0 .553 r
.47821 .78828 m .47714 .78775 L .47924 .78723 L F
.303 0 0 r
.29991 .60217 m .30295 .60211 L .30139 .60192 L F
.154 .685 .86 r
.30295 .60211 m .30338 .60172 L .30139 .60192 L F
.30295 .60211 m .3054 .60197 L .30338 .60172 L F
.368 .516 .874 r
.78012 .58734 m .78363 .58915 L .78183 .59009 L F
0 0 .436 r
.78308 .59112 m .78183 .59009 L .78363 .58915 L F
.78308 .59112 m .78213 .59267 L .78183 .59009 L F
.505 .13 .262 r
.43069 .68697 m .43309 .68696 L .43417 .68473 L F
.375 .003 .198 r
.43417 .68473 m .43509 .68646 L .43636 .68432 L F
.43417 .68473 m .43309 .68696 L .43509 .68646 L F
.301 .789 .893 r
.63318 .49723 m .63568 .49678 L .63699 .49693 L F
.533 .394 .637 r
.63902 .4977 m .63683 .49867 L .63699 .49693 L F
.389 0 0 r
.63568 .49678 m .63902 .4977 L .63699 .49693 L F
0 .033 .579 r
.57895 .73438 m .58076 .7364 L .57936 .73443 L F
.727 .621 .739 r
.50811 .72878 m .50964 .72661 L .50649 .72614 L F
.796 .495 .479 r
.50653 .73142 m .50808 .73107 L .50811 .72878 L F
.613 .705 .91 r
.75833 .59088 m .75998 .58892 L .75759 .58952 L F
.75833 .59088 m .76105 .5904 L .75998 .58892 L F
.582 .321 .486 r
.45476 .6846 m .45675 .6864 L .45449 .68656 L F
.641 .304 .386 r
.45686 .68482 m .45675 .6864 L .45476 .6846 L F
.105 .659 .784 r
.41434 .64924 m .41637 .6491 L .41763 .64917 L F
.502 0 0 r
.41637 .6491 m .4199 .64912 L .41763 .64917 L F
.127 .557 .922 r
.65791 .50427 m .65509 .50288 L .65712 .5033 L F
.231 .65 .958 r
.65791 .50427 m .66026 .50367 L .65712 .5033 L F
.149 .203 .663 r
.66026 .50367 m .65791 .50427 L .65712 .5033 L F
.376 0 .165 r
.70313 .52368 m .70253 .52544 L .70016 .5259 L F
.331 0 .108 r
.70551 .52323 m .70253 .52544 L .70313 .52368 L F
.175 0 .053 r
.28604 .60423 m .28664 .60545 L .28438 .60536 L F
.528 .159 .284 r
.47592 .75056 m .47941 .74834 L .47709 .7485 L F
.529 .563 .834 r
.39103 .69143 m .38949 .69359 L .38849 .69057 L F
.464 .475 .784 r
.39103 .69143 m .39212 .69483 L .38949 .69359 L F
.485 .833 .997 r
.67451 .50347 m .6761 .5041 L .67302 .50411 L F
.685 .896 .973 r
.67735 .50293 m .6761 .5041 L .67451 .50347 L F
.619 .624 .834 r
.67956 .50474 m .6761 .5041 L .67735 .50293 L F
.605 .101 .027 r
.53727 .72211 m .53934 .72286 L .5406 .72191 L F
.659 .167 .072 r
.53934 .72286 m .54286 .72356 L .5406 .72191 L F
.602 .03 0 r
.5406 .72191 m .54286 .72356 L .54393 .72368 L F
.203 .633 .949 r
.50808 .73984 m .50882 .73957 L .50676 .73922 L F
.051 .18 .679 r
.50808 .73984 m .50977 .74282 L .50882 .73957 L F
.869 .441 .022 r
.67078 .52799 m .67199 .52911 L .6728 .53093 L F
.079 0 .05 r
.32925 .63389 m .33029 .63233 L .33192 .63139 L F
.273 0 0 r
.48423 .74573 m .48647 .74535 L .48764 .74378 L F
.037 0 0 r
.48764 .74378 m .48827 .74455 L .48991 .74342 L F
.48764 .74378 m .48647 .74535 L .48827 .74455 L F
.343 0 .215 r
.24456 .59201 m .24801 .58894 L .24549 .59012 L F
.688 .665 .823 r
.77258 .59002 m .77024 .59229 L .76899 .58942 L F
.243 0 0 r
.38784 .6503 m .39001 .65025 L .39159 .64952 L F
.428 0 0 r
.39159 .64952 m .39001 .65025 L .39353 .65018 L F
.277 .425 .831 r
.75809 .62209 m .75688 .62346 L .75849 .62414 L F
.339 0 0 r
.52691 .80926 m .5305 .80798 L .52902 .80639 L F
.651 .769 .936 r
.52902 .80639 m .5305 .80798 L .53272 .80687 L F
.405 .268 .58 r
.31358 .62351 m .31528 .62511 L .31523 .62284 L F
.31358 .62351 m .31364 .62595 L .31528 .62511 L F
.907 .736 .657 r
.58228 .72029 m .584 .72102 L .5827 .71747 L F
.975 .677 .3 r
.58228 .72029 m .58326 .72295 L .584 .72102 L F
.519 .341 .58 r
.58602 .71781 m .5861 .72054 L .584 .72102 L F
0 0 0 r
.58602 .71781 m .584 .72102 L .58538 .71963 L F
.517 .823 1 r
.584 .72102 m .5861 .72054 L .58538 .71963 L F
.674 .435 .552 r
.47363 .67874 m .47322 .68157 L .47046 .68139 L F
.499 .279 .511 r
.47549 .68076 m .47363 .67874 L .47623 .67825 L F
.47549 .68076 m .47322 .68157 L .47363 .67874 L F
.439 .087 .27 r
.4203 .69222 m .42251 .69188 L .4235 .68948 L F
.395 .045 .249 r
.4235 .68948 m .42464 .69142 L .42526 .68983 L F
.4235 .68948 m .42251 .69188 L .42464 .69142 L F
.917 .978 .754 r
.65844 .49015 m .65652 .49286 L .65684 .49089 L F
.802 .465 0 r
.65844 .49015 m .65798 .48945 L .65717 .48688 L F
.906 .984 .761 r
.65844 .49015 m .65684 .49089 L .65798 .48945 L F
.544 .82 .997 r
.49851 .79335 m .49436 .79299 L .497 .7901 L F
.025 0 0 r
.49478 .79498 m .49851 .79335 L .49713 .7953 L F
.563 .595 .843 r
.50052 .79277 m .49851 .79335 L .497 .7901 L F
.211 0 0 r
.49713 .7953 m .49851 .79335 L .50052 .79277 L F
0 0 0 r
.58602 .71781 m .58538 .71963 L .5846 .71724 L F
.428 .239 .52 r
.35979 .66479 m .36183 .66193 L .35976 .66241 L F
.455 .325 .614 r
.78142 .60366 m .78117 .60672 L .77907 .60665 L F
.8 .646 .691 r
.78117 .60672 m .77855 .60828 L .77907 .60665 L F
.925 .898 .782 r
.34004 .71802 m .33878 .7174 L .34087 .71391 L F
.713 .219 .068 r
.34183 .71856 m .33878 .7174 L .34004 .71802 L F
.669 .541 .699 r
.35691 .69006 m .36021 .69266 L .35891 .68951 L F
.35691 .69006 m .35783 .69326 L .36021 .69266 L F
.48 .25 .487 r
.26039 .63173 m .25992 .63442 L .25792 .63459 L F
.484 .354 .627 r
.26202 .62889 m .26226 .63126 L .26039 .63173 L F
.5 .291 .527 r
.26226 .63126 m .25992 .63442 L .26039 .63173 L F
.284 0 .011 r
.41046 .69608 m .4113 .69738 L .41271 .69558 L F
.41046 .69608 m .40914 .69784 L .4113 .69738 L F
.76 .66 .752 r
.61622 .74866 m .61485 .74543 L .61265 .74828 L F
.062 .072 .556 r
.55397 .78683 m .55333 .79017 L .55161 .79004 L F
.55397 .78683 m .55451 .79013 L .55333 .79017 L F
.67 .456 .586 r
.5529 .79303 m .55366 .7914 L .55333 .79017 L F
.992 .824 .451 r
.5529 .79303 m .55333 .79017 L .55366 .7914 L F
.67 .456 .586 r
.5529 .79303 m .55333 .79017 L .55451 .79013 L F
.547 .447 .692 r
.72084 .50087 m .71905 .50303 L .71859 .50141 L F
.72084 .50087 m .72148 .50234 L .71905 .50303 L F
.506 .094 .192 r
.70052 .50062 m .70323 .50062 L .70418 .49925 L F
.785 .742 .813 r
.70604 .4978 m .70418 .49925 L .70277 .49774 L F
0 .091 .572 r
.66678 .51467 m .66825 .51582 L .66588 .51344 L F
.66678 .51467 m .66956 .51701 L .66825 .51582 L F
.596 .735 .941 r
.75243 .60791 m .75093 .60993 L .75008 .60825 L F
.75243 .60791 m .75328 .60945 L .75093 .60993 L F
.575 .592 .833 r
.71883 .49413 m .71783 .49785 L .71644 .49472 L F
.71883 .49413 m .72015 .49726 L .71783 .49785 L F
.595 .522 .742 r
.72015 .49726 m .71859 .50141 L .71783 .49785 L F
.444 .156 .379 r
.32511 .637 m .32785 .63478 L .32709 .63652 L F
.13 0 .207 r
.32709 .63652 m .32785 .63478 L .32925 .63389 L F
.75 .804 .896 r
.70604 .4978 m .70277 .49774 L .70454 .49617 L F
.71 .794 .917 r
.70868 .49583 m .70604 .4978 L .70454 .49617 L F
.297 .391 .79 r
.38593 .68361 m .38486 .68523 L .38356 .68178 L F
.303 .399 .795 r
.38593 .68361 m .38715 .68684 L .38486 .68523 L F
.058 0 0 r
.64202 .55114 m .64402 .55029 L .6445 .55051 L F
.263 0 .155 r
.64402 .55029 m .64735 .54799 L .64683 .54797 L F
.64402 .55029 m .64683 .54797 L .6445 .55051 L F
.404 .36 .695 r
.54263 .70199 m .54276 .70399 L .54478 .70301 L F
0 0 .441 r
.54276 .70399 m .54381 .70537 L .54478 .70301 L F
0 0 .07 r
.69344 .5202 m .69311 .52199 L .69518 .51875 L F
.208 .67 .944 r
.31608 .59201 m .3156 .59261 L .31405 .59196 L F
.31608 .59201 m .3176 .59276 L .3156 .59261 L F
.12 .004 .435 r
.70875 .5023 m .70694 .50307 L .70948 .50161 L F
.70875 .5023 m .70692 .50415 L .70694 .50307 L F
.039 .248 .748 r
.51135 .72566 m .51335 .7278 L .51237 .7254 L F
.51135 .72566 m .51237 .7254 L .51181 .72405 L F
0 0 0 r
.51035 .72592 m .51135 .72566 L .51221 .72411 L F
.50964 .72661 m .51135 .72566 L .51035 .72592 L F
.817 .861 .411 r
.51221 .72411 m .51135 .72566 L .51271 .72184 L F
.543 .073 .087 r
.39353 .65018 m .3958 .6506 L .39713 .64922 L F
.536 .065 .083 r
.39713 .64922 m .3958 .6506 L .39921 .65023 L F
.595 .522 .742 r
.72015 .49726 m .72084 .50087 L .71859 .50141 L F
.72 .594 .714 r
.44761 .66776 m .45102 .67027 L .44985 .66729 L F
.44761 .66776 m .44883 .6711 L .45102 .67027 L F
.529 .489 .756 r
.44883 .6711 m .45051 .67303 L .45102 .67027 L F
.658 .615 .795 r
.44985 .66729 m .45102 .67027 L .45307 .66785 L F
.593 .518 .739 r
.45102 .67027 m .45427 .67209 L .45307 .66785 L F
.665 .511 .666 r
.45051 .67303 m .45427 .67209 L .45102 .67027 L F
.631 .93 .97 r
.63113 .50925 m .63004 .50923 L .63226 .50818 L F
.436 .162 .398 r
.7588 .60673 m .76097 .60637 L .76155 .60423 L F
.131 0 .267 r
.76155 .60423 m .76097 .60637 L .7631 .60316 L F
.705 .482 .582 r
.49655 .76475 m .49438 .76237 L .49881 .76199 L F
.746 .574 .662 r
.5001 .76231 m .49655 .76475 L .49881 .76199 L F
.557 0 0 r
.6675 .50665 m .6699 .50838 L .67043 .5084 L F
.941 .927 .565 r
.67043 .5084 m .67069 .5062 L .6732 .50656 L F
.67043 .5084 m .6699 .50838 L .67069 .5062 L F
.757 .513 .564 r
.60236 .56485 m .599 .56712 L .59914 .56452 L F
.60236 .56485 m .60265 .56739 L .599 .56712 L F
.416 0 0 r
.279 .58592 m .28089 .5864 L .28274 .58621 L F
.375 0 0 r
.28274 .58621 m .28089 .5864 L .28454 .58661 L F
.675 .393 .487 r
.51843 .76522 m .52064 .76756 L .51864 .76747 L F
.674 .393 .487 r
.52066 .76542 m .52064 .76756 L .51843 .76522 L F
.713 .811 .926 r
.71183 .49635 m .70868 .49583 L .71071 .49481 L F
.688 .731 .883 r
.71071 .49481 m .71408 .49542 L .71183 .49635 L F
.936 .592 .349 r
.66346 .51909 m .66445 .51788 L .66296 .51701 L F
.99 .851 .486 r
.66346 .51909 m .66399 .52023 L .66445 .51788 L F
.529 .764 .983 r
.3054 .60197 m .31026 .60369 L .3085 .60204 L F
.483 .774 .996 r
.3085 .60204 m .31026 .60369 L .31092 .60302 L F
.725 .665 .79 r
.50577 .76228 m .50375 .76463 L .50247 .76182 L F
.661 .565 .736 r
.50645 .76383 m .50375 .76463 L .50577 .76228 L F
.707 .188 0 r
.54286 .72356 m .54646 .72546 L .54393 .72368 L F
.579 .002 0 r
.54393 .72368 m .54646 .72546 L .54758 .7257 L F
.703 .583 .717 r
.55577 .75131 m .55359 .75415 L .55207 .75091 L F
.529 .631 .896 r
.77963 .5856 m .77779 .5874 L .77678 .58421 L F
.77963 .5856 m .78012 .58734 L .77779 .5874 L F
.569 .276 .431 r
.55821 .77593 m .55501 .7788 L .55494 .77671 L F
.133 0 0 r
.40489 .71031 m .40475 .70933 L .4069 .70895 L F
.40489 .71031 m .403 .71078 L .40475 .70933 L F
.452 .182 .412 r
.33664 .62348 m .3394 .62106 L .33877 .62302 L F
.447 .222 .478 r
.34108 .62041 m .33877 .62302 L .3394 .62106 L F
.607 .393 .565 r
.77821 .59206 m .77591 .59283 L .77579 .58985 L F
.546 .408 .645 r
.47352 .66774 m .47138 .67064 L .47105 .66825 L F
.932 .668 .19 r
.58233 .73995 m .58307 .74301 L .58249 .74193 L F
0 .223 .738 r
.58307 .74301 m .58428 .74335 L .58249 .74193 L F
.58307 .74301 m .58537 .74493 L .58428 .74335 L F
.56 .846 .997 r
.65453 .52828 m .65575 .52887 L .65702 .52763 L F
.917 .97 .676 r
.65575 .52887 m .65432 .53048 L .65695 .52992 L F
0 0 .395 r
.65702 .52763 m .65575 .52887 L .65695 .52992 L F
.456 .231 .483 r
.34871 .6113 m .35062 .60932 L .35022 .61113 L F
.462 .232 .477 r
.34871 .6113 m .34978 .61232 L .34786 .61455 L F
.34871 .6113 m .35022 .61113 L .34978 .61232 L F
.479 .643 .929 r
.62909 .49487 m .6273 .49558 L .62646 .49222 L F
.584 .374 .562 r
.44403 .67622 m .44618 .67823 L .4465 .67613 L F
.44403 .67622 m .44391 .67862 L .44618 .67823 L F
.077 0 0 r
.75567 .60957 m .75661 .60954 L .75328 .60945 L F
.6 .391 .57 r
.75661 .60954 m .75921 .61182 L .75899 .60922 L F
0 .071 .558 r
.75816 .61083 m .75921 .61182 L .75661 .60954 L F
.75816 .61083 m .75661 .60954 L .75567 .60957 L F
.618 .464 .651 r
.75661 .60954 m .75899 .60922 L .7588 .60673 L F
.536 .423 .672 r
.35838 .67092 m .36019 .66722 L .35808 .66772 L F
.966 .663 .396 r
.66969 .5178 m .67001 .52006 L .66869 .51902 L F
.255 0 .179 r
.63007 .51344 m .62734 .51568 L .62813 .51326 L F
.886 .811 .769 r
.68625 .50043 m .68877 .50109 L .68811 .49746 L F
.852 .872 .855 r
.68547 .50203 m .68877 .50109 L .68625 .50043 L F
.664 .671 .847 r
.68811 .49746 m .68877 .50109 L .6915 .50019 L F
.642 .571 .76 r
.68877 .50109 m .69257 .50172 L .6915 .50019 L F
.681 .608 .767 r
.68816 .50256 m .69257 .50172 L .68877 .50109 L F
.191 0 0 r
.63839 .55238 m .63588 .55482 L .63711 .553 L F
.63839 .55238 m .6391 .55307 L .63588 .55482 L F
.027 0 0 r
.63839 .55238 m .64202 .55114 L .64072 .55169 L F
.056 0 .129 r
.64072 .55169 m .6391 .55307 L .63839 .55238 L F
.547 0 0 r
.57546 .71861 m .5784 .71969 L .575 .71767 L F
0 .28 .783 r
.57825 .7188 m .5784 .71969 L .57573 .71871 L F
.547 0 0 r
.57546 .71861 m .575 .71767 L .57572 .71868 L F
0 .28 .783 r
.57572 .71868 m .57573 .71871 L .57546 .71861 L F
.547 0 0 r
.57546 .71861 m .57572 .71868 L .57575 .71872 L F
.742 .388 .38 r
.57241 .71705 m .57552 .7186 L .57395 .71503 L F
0 .28 .783 r
.57566 .71863 m .57572 .71868 L .57546 .71861 L F
.57571 .71864 m .57572 .71868 L .57566 .71863 L F
.57825 .7188 m .57573 .71871 L .57571 .71863 L F
0 0 .393 r
.57571 .71864 m .57575 .71872 L .57572 .71868 L F
.742 .388 .38 r
.57552 .7186 m .57575 .71872 L .57571 .71864 L F
0 0 .393 r
.57395 .71503 m .57571 .71864 L .575 .71767 L F
.57571 .71864 m .57572 .71868 L .575 .71767 L F
.742 .388 .38 r
.57552 .7186 m .57566 .71863 L .57395 .71503 L F
.57566 .71863 m .57571 .71864 L .57571 .71864 L F
.57566 .71863 m .57571 .71864 L .57395 .71503 L F
.52 .591 .866 r
.57546 .71861 m .57575 .71872 L .57241 .71705 L F
.194 .677 .929 r
.57352 .71783 m .57563 .71826 L .57547 .71859 L F
.57536 .71857 m .57547 .71859 L .57546 .71861 L F
.52 .591 .866 r
.57546 .71861 m .57241 .71705 L .57352 .71783 L F
.194 .677 .929 r
.57352 .71783 m .57547 .71859 L .57536 .71857 L F
.57563 .71826 m .57825 .7188 L .57571 .71863 L F
.57563 .71826 m .57571 .71863 L .57546 .71861 L F
0 .28 .783 r
.57571 .71863 m .57571 .71864 L .57566 .71863 L F
.365 0 .04 r
.39856 .66788 m .39713 .66957 L .39494 .6698 L F
.301 0 0 r
.40074 .6676 m .39713 .66957 L .39856 .66788 L F
.385 .283 .615 r
.45581 .77082 m .45739 .77049 L .4572 .76805 L F
.4 .346 .682 r
.45581 .77082 m .45801 .77289 L .45739 .77049 L F
.559 .353 .558 r
.45581 .77082 m .4557 .77324 L .45801 .77289 L F
.45581 .77082 m .4557 .77324 L .45801 .77289 L F
.489 .592 .883 r
.26147 .63711 m .25792 .63459 L .25992 .63442 L F
.588 .637 .867 r
.26195 .63395 m .26147 .63711 L .25992 .63442 L F
.26195 .63395 m .26355 .63663 L .26147 .63711 L F
0 .176 .705 r
.49639 .7505 m .49909 .75417 L .49689 .75156 L F
0 0 .521 r
.49882 .74972 m .49909 .75417 L .49639 .7505 L F
.256 0 .061 r
.49982 .75566 m .50111 .75396 L .49909 .75417 L F
0 0 .335 r
.49962 .75319 m .49982 .75566 L .49909 .75417 L F
.751 .383 .356 r
.5784 .71969 m .58034 .71953 L .5804 .71787 L F
.707 .54 .66 r
.58034 .71953 m .5827 .71747 L .5804 .71787 L F
.72 .511 .606 r
.69741 .51191 m .69909 .51496 L .70099 .51484 L F
.883 .802 .765 r
.6675 .50665 m .66431 .50828 L .66408 .50662 L F
.6675 .50665 m .66612 .50924 L .66431 .50828 L F
.092 .337 .81 r
.66983 .5071 m .6675 .50665 L .6688 .50468 L F
.66983 .5071 m .6699 .50838 L .6675 .50665 L F
.443 .078 .249 r
.5193 .73897 m .5205 .736 L .52023 .73707 L F
.746 .622 .722 r
.50921 .76513 m .50706 .76567 L .50645 .76383 L F
.856 .582 .047 r
.52489 .77238 m .52276 .77105 L .52142 .77245 L F
.48 .408 .699 r
.49004 .77288 m .48849 .77368 L .4877 .77084 L F
.37 .495 .854 r
.50964 .72661 m .51265 .7284 L .51135 .72566 L F
.011 0 0 r
.30363 .63433 m .30173 .63511 L .30069 .63603 L F
.24 0 0 r
.47751 .78623 m .47864 .78567 L .47735 .78391 L F
.47751 .78623 m .48206 .78615 L .47864 .78567 L F
.483 .309 .569 r
.47864 .78567 m .48206 .78615 L .48113 .7845 L F
.736 .588 .691 r
.55717 .74327 m .5542 .74547 L .55378 .74307 L F
.463 .309 .586 r
.55904 .74254 m .55912 .74509 L .55717 .74327 L F
.55717 .74327 m .55912 .74509 L .55904 .74254 L F
.444 .055 .205 r
.38332 .65039 m .38032 .65166 L .38196 .65261 L F
.511 .123 .241 r
.38426 .65254 m .38332 .65039 L .38196 .65261 L F
.38426 .65254 m .38561 .65037 L .38332 .65039 L F
.663 .121 0 r
.55614 .71537 m .55542 .71606 L .55316 .7144 L F
.679 .142 0 r
.55614 .71537 m .55856 .71738 L .55542 .71606 L F
.689 .171 0 r
.56021 .71735 m .55856 .71738 L .55614 .71537 L F
.7 .353 .385 r
.52341 .8058 m .52202 .80378 L .51978 .80397 L F
.385 .223 .536 r
.26317 .6228 m .26151 .62354 L .26325 .62041 L F
.41 .203 .485 r
.26317 .6228 m .26096 .62584 L .26151 .62354 L F
.483 0 0 r
.38343 .71809 m .38321 .7199 L .38094 .71869 L F
.081 0 0 r
.38416 .71906 m .38343 .71809 L .38445 .71902 L F
.108 0 0 r
.38758 .7192 m .38445 .71902 L .38748 .71692 L F
.53 .902 .96 r
.3894 .71612 m .3883 .71591 L .38748 .71692 L F
.519 .544 .821 r
.3883 .71591 m .38775 .71845 L .38748 .71692 L F
.38775 .71845 m .38758 .7192 L .38753 .718 L F
.38775 .71845 m .38753 .718 L .38748 .71692 L F
.3883 .71591 m .38961 .71908 L .38758 .7192 L F
.603 .113 .064 r
.38961 .71908 m .38495 .71913 L .38758 .7192 L F
.144 0 0 r
.38334 .71915 m .38416 .71906 L .38758 .7192 L F
.603 .113 .064 r
.38495 .71913 m .38334 .71915 L .38465 .71917 L F
.38495 .71913 m .38465 .71917 L .38758 .7192 L F
.081 0 0 r
.38416 .71906 m .38396 .71925 L .38343 .71809 L F
.38396 .71925 m .38328 .71932 L .38343 .71809 L F
.603 .113 .064 r
.38806 .7191 m .38702 .71977 L .38334 .71915 L F
.38961 .71908 m .38823 .71945 L .38806 .7191 L F
.38823 .71945 m .38702 .71977 L .38806 .7191 L F
.081 0 0 r
.38396 .71925 m .38321 .7199 L .38328 .71932 L F
.346 0 .081 r
.38569 .71767 m .38445 .71902 L .38343 .71809 L F
.764 .534 .584 r
.71369 .5976 m .71523 .59547 L .71322 .59549 L F
.075 0 0 r
.6476 .52948 m .64636 .52959 L .64593 .53027 L F
.232 .739 .687 r
.64898 .52874 m .64636 .52959 L .6476 .52948 L F
.875 .946 .587 r
.55208 .77118 m .55125 .773 L .55084 .77216 L F
.979 .767 .351 r
.55125 .773 m .54995 .77485 L .55084 .77216 L F
.55125 .773 m .5511 .77678 L .54995 .77485 L F
.233 .709 .938 r
.5466 .73695 m .54865 .73694 L .54989 .73744 L F
.771 .706 .791 r
.55266 .76482 m .55596 .76525 L .55459 .76251 L F
.759 .401 .377 r
.55266 .76482 m .55468 .76741 L .55596 .76525 L F
.207 .396 .829 r
.55596 .76525 m .55702 .76417 L .55459 .76251 L F
0 0 0 r
.55596 .76525 m .55468 .76741 L .55702 .76417 L F
.507 .711 .963 r
.34013 .59461 m .33938 .59629 L .33806 .59501 L F
.34013 .59461 m .34137 .59598 L .33938 .59629 L F
.975 .695 .432 r
.59904 .56226 m .59914 .56452 L .59806 .56357 L F
.52 .333 .567 r
.54649 .75925 m .54319 .76215 L .54331 .76002 L F
.042 0 0 r
.43467 .65088 m .43692 .65061 L .4381 .65022 L F
0 0 0 r
.4381 .65022 m .43909 .65001 L .44038 .64984 L F
.4381 .65022 m .43692 .65061 L .43909 .65001 L F
.496 .186 .37 r
.55821 .77593 m .56121 .77423 L .56125 .77584 L F
.275 .028 .345 r
.56125 .77584 m .56121 .77423 L .56296 .77326 L F
.56125 .77584 m .56121 .77423 L .56296 .77326 L F
.283 0 0 r
.2717 .58462 m .27524 .58495 L .27321 .58504 L F
.558 .33 .526 r
.43879 .69236 m .43826 .69483 L .43653 .69459 L F
.428 .16 .403 r
.44091 .69237 m .43826 .69483 L .43879 .69236 L F
.314 0 .131 r
.4272 .70197 m .42601 .70062 L .42804 .70033 L F
.4272 .70197 m .42472 .70268 L .42601 .70062 L F
.315 .8 .886 r
.29366 .65162 m .29219 .65156 L .29007 .65199 L F
0 0 0 r
.29565 .65078 m .29219 .65156 L .29366 .65162 L F
.338 .139 .457 r
.54785 .75661 m .54649 .75925 L .54714 .75665 L F
.864 .735 .719 r
.60013 .54239 m .60116 .54566 L .5997 .54474 L F
.941 .763 .632 r
.5997 .54474 m .60116 .54566 L .60072 .54799 L F
.482 .421 .712 r
.76246 .59455 m .7623 .5956 L .76434 .59502 L F
.552 .432 .67 r
.76245 .59798 m .76434 .59502 L .7623 .5956 L F
.466 .509 .819 r
.72076 .60743 m .72266 .60529 L .72026 .6058 L F
.72076 .60743 m .72385 .60829 L .72266 .60529 L F
.801 .318 0 r
.5769 .72951 m .57651 .73019 L .57569 .7286 L F
.5769 .72951 m .57785 .73118 L .57651 .73019 L F
.954 .721 .265 r
.73553 .59546 m .7361 .59778 L .73615 .5958 L F
.738 .485 .548 r
.68083 .53146 m .682 .53441 L .67835 .5336 L F
.5 .367 .63 r
.68083 .53146 m .682 .53441 L .68376 .53311 L F
.764 .534 .584 r
.71369 .5976 m .71578 .59783 L .71523 .59547 L F
.647 .364 .476 r
.71953 .59688 m .71523 .59547 L .71578 .59783 L F
.71953 .59688 m .71916 .59503 L .71523 .59547 L F
.853 .863 .848 r
.6717 .49344 m .67055 .49602 L .67229 .49351 L F
0 .154 .689 r
.67151 .49509 m .67055 .49602 L .6717 .49344 L F
.67151 .49509 m .67194 .49788 L .67055 .49602 L F
.73 .544 .639 r
.51722 .77363 m .51745 .77618 L .51524 .77623 L F
.587 .429 .635 r
.51969 .77335 m .51745 .77618 L .51722 .77363 L F
.321 0 0 r
.51913 .77432 m .51969 .77335 L .51722 .77363 L F
.51913 .77432 m .51722 .77363 L .51683 .77272 L F
.542 .449 .699 r
.45683 .76244 m .45858 .75937 L .45638 .75966 L F
.45683 .76244 m .45895 .76205 L .45858 .75937 L F
.499 .36 .623 r
.45713 .7649 m .45895 .76205 L .45683 .76244 L F
.881 .816 .781 r
.62083 .50646 m .61954 .50637 L .62 .50324 L F
.951 .784 .639 r
.62083 .50646 m .61851 .50823 L .61954 .50637 L F
.62083 .50646 m .61926 .50932 L .61851 .50823 L F
.802 .776 .83 r
.62304 .50351 m .62083 .50646 L .62 .50324 L F
0 0 .004 r
.55161 .79004 m .55041 .79344 L .5529 .79303 L F
.188 0 .167 r
.49482 .73946 m .49593 .74102 L .49712 .73848 L F
.166 0 .362 r
.49712 .73848 m .49923 .73648 L .49746 .73727 L F
.49712 .73848 m .49883 .73946 L .49923 .73648 L F
.413 .007 .155 r
.49593 .74102 m .49883 .73946 L .49712 .73848 L F
.64 .585 .777 r
.62646 .49222 m .62407 .49312 L .62285 .48956 L F
.624 .576 .78 r
.62285 .48956 m .62407 .49312 L .62414 .49292 L F
.866 .776 .76 r
.62407 .49312 m .62081 .49471 L .62414 .49292 L F
.62407 .49312 m .62264 .4959 L .62081 .49471 L F
.597 .481 .691 r
.45419 .77618 m .45682 .77871 L .45612 .77569 L F
.45419 .77618 m .4546 .77917 L .45682 .77871 L F
.473 .663 .945 r
.32101 .60518 m .32155 .60341 L .32 .60413 L F
.32101 .60518 m .32394 .60593 L .32155 .60341 L F
.584 .77 .968 r
.63836 .48661 m .63742 .48832 L .63642 .48669 L F
.63836 .48661 m .63972 .48782 L .63742 .48832 L F
.571 .273 .424 r
.63407 .55592 m .63711 .553 L .63588 .55482 L F
.63407 .55592 m .63417 .55444 L .63711 .553 L F
.579 .751 .959 r
.72385 .60829 m .72459 .60964 L .72617 .60788 L F
.405 .475 .819 r
.72459 .60964 m .72762 .61126 L .72617 .60788 L F
.832 .699 .716 r
.61293 .52295 m .60996 .52285 L .61172 .51988 L F
.827 .737 .766 r
.61293 .52295 m .61086 .52605 L .60996 .52285 L F
.985 .796 .57 r
.54094 .7347 m .53987 .73401 L .54044 .73181 L F
.982 .788 .567 r
.54076 .73719 m .53987 .73401 L .54094 .7347 L F
.662 .74 .908 r
.31092 .60302 m .31242 .60466 L .31432 .60383 L F
.174 0 0 r
.54646 .72546 m .54955 .72617 L .54758 .7257 L F
.508 .86 .607 r
.64735 .54799 m .64988 .54591 L .64876 .5467 L F
.561 .931 .803 r
.64876 .5467 m .64683 .54797 L .64735 .54799 L F
.404 .129 .379 r
.26828 .61526 m .27024 .61474 L .26768 .61717 L F
.798 .503 .488 r
.49975 .80623 m .50421 .80697 L .50438 .80912 L F
.803 .692 .743 r
.50642 .80654 m .50438 .80912 L .50421 .80697 L F
.434 .652 .951 r
.2823 .63679 m .28224 .63876 L .28058 .63757 L F
.2823 .63679 m .28398 .6386 L .28224 .63876 L F
.306 .742 .968 r
.28224 .63876 m .28398 .6386 L .28525 .63905 L F
.404 .36 .695 r
.54263 .70199 m .54478 .70301 L .54464 .70102 L F
.819 .516 .476 r
.51881 .71751 m .52218 .72035 L .52193 .718 L F
0 .524 .782 r
.29928 .65157 m .29745 .65108 L .29565 .65078 L F
.158 .697 .815 r
.29928 .65157 m .29969 .6513 L .29745 .65108 L F
.393 0 .055 r
.30204 .65102 m .30151 .65138 L .29928 .65157 L F
.158 .697 .815 r
.29928 .65157 m .30151 .65138 L .29969 .6513 L F
.377 .834 .914 r
.2934 .63769 m .29412 .63703 L .29551 .63728 L F
.2934 .63769 m .29107 .63757 L .29412 .63703 L F
.071 .393 .851 r
.46289 .79025 m .46361 .78954 L .46183 .78905 L F
.46289 .79025 m .46631 .79226 L .46361 .78954 L F
.259 0 0 r
.63683 .49867 m .63566 .49989 L .63338 .50033 L F
.494 .12 .258 r
.63902 .4977 m .63566 .49989 L .63683 .49867 L F
.545 .353 .571 r
.45638 .75966 m .45858 .75937 L .45862 .75701 L F
.173 .689 .89 r
.4199 .64912 m .42199 .64906 L .42333 .64948 L F
0 .382 .725 r
.42199 .64906 m .42548 .65046 L .42333 .64948 L F
.414 .137 .381 r
.47182 .75163 m .4734 .753 L .47391 .75102 L F
.47182 .75163 m .47137 .75354 L .4734 .753 L F
.454 .755 .994 r
.28612 .63817 m .28525 .63905 L .28398 .6386 L F
.28612 .63817 m .28724 .63897 L .28525 .63905 L F
.537 .629 .89 r
.74878 .60577 m .74785 .60851 L .74644 .60613 L F
.74878 .60577 m .75008 .60825 L .74785 .60851 L F
.814 .655 .685 r
.58145 .72576 m .58048 .72868 L .58273 .72889 L F
.452 0 0 r
.58048 .72868 m .58135 .72962 L .58273 .72889 L F
.413 .223 .511 r
.58273 .72889 m .58619 .72597 L .58145 .72576 L F
.58273 .72889 m .58492 .72883 L .58619 .72597 L F
.866 .457 .252 r
.58135 .72962 m .58489 .73114 L .58492 .72883 L F
.58135 .72962 m .58316 .73078 L .58489 .73114 L F
.798 .349 0 r
.58195 .72954 m .58294 .73145 L .58316 .73078 L F
.75 .778 .279 r
.5814 .72535 m .58048 .72868 L .58145 .72576 L F
.5814 .72535 m .58068 .72761 L .58048 .72868 L F
.866 .457 .252 r
.58135 .72962 m .58219 .72943 L .58273 .72889 L F
0 0 .447 r
.58068 .72761 m .58135 .72962 L .58048 .72868 L F
.686 .722 .877 r
.58054 .72809 m .58135 .72962 L .58068 .72761 L F
.58054 .72809 m .58316 .73078 L .58135 .72962 L F
.798 .349 0 r
.58054 .72809 m .58167 .72967 L .58195 .72954 L F
.58167 .72967 m .58294 .73145 L .58195 .72954 L F
.866 .457 .252 r
.58219 .72943 m .58492 .72883 L .58343 .72887 L F
.58219 .72943 m .58343 .72887 L .58273 .72889 L F
.45 .195 .435 r
.33877 .62302 m .33626 .6256 L .33664 .62348 L F
.372 .143 .431 r
.34978 .61232 m .35022 .61113 L .35103 .61101 L F
.35088 .61168 m .35103 .61101 L .35241 .6108 L F
.34978 .61232 m .35103 .61101 L .35088 .61168 L F
.476 .25 .491 r
.35114 .61053 m .35315 .60653 L .35141 .61115 L F
.35062 .60932 m .35165 .60819 L .35114 .61053 L F
.35165 .60819 m .35315 .60653 L .35114 .61053 L F
.732 .579 .683 r
.35511 .60601 m .35141 .61115 L .35315 .60653 L F
.374 .085 .34 r
.32511 .637 m .32448 .63961 L .32191 .63996 L F
.309 .03 .316 r
.32619 .63883 m .32511 .637 L .32709 .63652 L F
.32619 .63883 m .32448 .63961 L .32511 .637 L F
.534 .759 .98 r
.75849 .62414 m .76079 .62515 L .7591 .62417 L F
.683 .916 .973 r
.76079 .62515 m .76421 .62243 L .7591 .62417 L F
.76079 .62515 m .76504 .62315 L .76421 .62243 L F
.917 .639 .149 r
.59401 .68578 m .59437 .6846 L .59272 .68374 L F
.59401 .68578 m .59457 .68689 L .59437 .6846 L F
.802 .651 .696 r
.60072 .54799 m .60223 .5511 L .59977 .55061 L F
.809 .582 .594 r
.59977 .55061 m .60223 .5511 L .60217 .55345 L F
.483 0 0 r
.59131 .71163 m .59052 .71102 L .59132 .71207 L F
.116 0 0 r
.37274 .65496 m .37232 .65428 L .37082 .65564 L F
.37274 .65496 m .37442 .65385 L .37232 .65428 L F
.41 .09 .308 r
.55584 .6894 m .55848 .68728 L .55635 .68771 L F
.538 .481 .74 r
.35735 .6793 m .35812 .68184 L .36013 .68137 L F
.461 .319 .602 r
.35812 .68184 m .3602 .68363 L .36013 .68137 L F
.35812 .68184 m .35833 .68428 L .3602 .68363 L F
.638 .554 .744 r
.75899 .60922 m .76097 .60637 L .7588 .60673 L F
.732 .579 .683 r
.35511 .60601 m .35618 .60622 L .35141 .61115 L F
.389 .104 .354 r
.35141 .61115 m .35372 .60876 L .35442 .61053 L F
.35372 .60876 m .35618 .60622 L .35554 .60778 L F
.35372 .60876 m .35554 .60778 L .35442 .61053 L F
.473 .187 .397 r
.35442 .61053 m .35618 .60622 L .35737 .60751 L F
.65 .175 .111 r
.3573 .60683 m .35511 .60601 L .35718 .60569 L F
.35737 .60751 m .35678 .60711 L .3573 .60683 L F
.35737 .60751 m .35618 .60622 L .35511 .60601 L F
.35678 .60711 m .35511 .60601 L .3573 .60683 L F
.38 .167 .46 r
.35241 .6108 m .35062 .60932 L .35141 .61115 L F
.35241 .6108 m .35022 .61113 L .35062 .60932 L F
.624 .201 .218 r
.49604 .80291 m .49841 .80128 L .49602 .80185 L F
.717 .33 .316 r
.49949 .80318 m .49841 .80128 L .49604 .80291 L F
.608 .457 .65 r
.45858 .75937 m .46075 .75633 L .45862 .75701 L F
.937 .785 .667 r
.53196 .78758 m .53245 .79028 L .53111 .78904 L F
.53111 .78904 m .53245 .79028 L .53196 .78758 L F
.121 .67 .721 r
.29796 .6024 m .29991 .60217 L .30139 .60192 L F
.681 .608 .767 r
.68816 .50256 m .69288 .50374 L .69257 .50172 L F
.71 .545 .663 r
.68816 .50256 m .69032 .5063 L .69288 .50374 L F
.704 .52 .637 r
.54378 .76478 m .54658 .76539 L .54712 .76261 L F
.833 .719 .738 r
.54649 .75925 m .54712 .76261 L .54611 .76158 L F
.734 .221 0 r
.54947 .76323 m .54611 .76158 L .54712 .76261 L F
.582 .663 .893 r
.77248 .58045 m .77109 .58273 L .77006 .5811 L F
.77248 .58045 m .77351 .58237 L .77109 .58273 L F
.872 .694 .659 r
.62285 .48956 m .62414 .49292 L .61987 .49145 L F
.854 .737 .734 r
.62414 .49292 m .62081 .49471 L .61987 .49145 L F
.541 .294 .49 r
.77732 .61178 m .77482 .61477 L .77389 .61166 L F
.77732 .61178 m .77721 .61423 L .77482 .61477 L F
.509 .524 .807 r
.77855 .60828 m .77732 .61178 L .77607 .61116 L F
.77855 .60828 m .77993 .61182 L .77732 .61178 L F
.461 .23 .476 r
.77891 .61332 m .77732 .61178 L .77993 .61182 L F
.77891 .61332 m .77721 .61423 L .77732 .61178 L F
.759 .437 .441 r
.52218 .72035 m .52594 .72265 L .5258 .72097 L F
.722 .371 .382 r
.5258 .72097 m .52594 .72265 L .5291 .7226 L F
.254 .01 .337 r
.32191 .63996 m .32187 .64221 L .31983 .64261 L F
.191 0 .133 r
.31983 .64261 m .32103 .64361 L .3191 .644 L F
.31983 .64261 m .32187 .64221 L .32103 .64361 L F
.845 .567 .517 r
.49247 .80043 m .49459 .7981 L .49239 .79804 L F
.49247 .80043 m .49602 .80185 L .49459 .7981 L F
.569 .276 .431 r
.55821 .77593 m .55771 .77874 L .55501 .7788 L F
.623 .391 .545 r
.56125 .77584 m .55771 .77874 L .55821 .77593 L F
.6 .333 .484 r
.52313 .76734 m .52064 .76756 L .52066 .76542 L F
.447 .547 .865 r
.72762 .61126 m .72803 .61346 L .73069 .61381 L F
.653 .62 .804 r
.69686 .49563 m .69326 .49323 L .69563 .49266 L F
.553 .576 .831 r
.69796 .49205 m .69686 .49563 L .69563 .49266 L F
.69796 .49205 m .6991 .49522 L .69686 .49563 L F
.461 .18 .401 r
.69786 .52641 m .69765 .52813 L .69529 .52871 L F
.332 .076 .367 r
.69967 .52723 m .69786 .52641 L .70016 .5259 L F
.69967 .52723 m .69765 .52813 L .69786 .52641 L F
.021 0 .018 r
.7511 .58696 m .75324 .58595 L .75382 .5842 L F
.053 0 0 r
.75382 .5842 m .75576 .58378 L .75622 .58268 L F
.104 0 .046 r
.75382 .5842 m .75324 .58595 L .75576 .58378 L F
.656 .465 .614 r
.61252 .56467 m .6104 .56754 L .61048 .56507 L F
.637 .401 .544 r
.61048 .56507 m .6104 .56754 L .60797 .56738 L F
.837 .529 .467 r
.49332 .80394 m .49511 .80373 L .4937 .80604 L F
.749 .412 .413 r
.49511 .80373 m .49753 .80647 L .4937 .80604 L F
.803 .692 .743 r
.50642 .80654 m .5076 .80975 L .50438 .80912 L F
.799 .454 .403 r
.50438 .80912 m .5076 .80975 L .50612 .81098 L F
.755 .67 .767 r
.51013 .80653 m .5076 .80975 L .50642 .80654 L F
.807 .466 .412 r
.50612 .81098 m .5076 .80975 L .50799 .81195 L F
.648 .511 .683 r
.51013 .80653 m .50998 .80952 L .5076 .80975 L F
.751 .527 .592 r
.50998 .80952 m .50799 .81195 L .5076 .80975 L F
.733 .524 .609 r
.49908 .77319 m .49685 .77593 L .49707 .77346 L F
.49908 .77319 m .50037 .7766 L .49685 .77593 L F
.288 .281 .677 r
.50165 .77525 m .49908 .77319 L .50117 .77287 L F
.50165 .77525 m .50037 .7766 L .49908 .77319 L F
.99 .773 .388 r
.66612 .50924 m .66526 .51045 L .66431 .50828 L F
.66612 .50924 m .66596 .51169 L .66526 .51045 L F
.656 .37 .474 r
.71953 .59688 m .72132 .59739 L .71916 .59503 L F
.265 0 .052 r
.40649 .66512 m .40512 .66711 L .40301 .66766 L F
.154 0 0 r
.40839 .66631 m .40512 .66711 L .40649 .66512 L F
.552 .122 .176 r
.40899 .66536 m .40839 .66631 L .40649 .66512 L F
.645 .667 .857 r
.44632 .66488 m .44761 .66776 L .44985 .66729 L F
.453 .35 .648 r
.72474 .5058 m .72529 .50812 L .72285 .50894 L F
.058 .098 .588 r
.7246 .51015 m .72285 .50894 L .72529 .50812 L F
.7246 .51015 m .72344 .51189 L .72285 .50894 L F
.336 0 .002 r
.41478 .70592 m .41096 .70786 L .41271 .70664 L F
.867 .704 .677 r
.67302 .50411 m .6732 .50656 L .67069 .5062 L F
.704 .405 .467 r
.5093 .75427 m .509 .75598 L .50998 .75339 L F
.656 .366 .468 r
.509 .75598 m .51245 .75378 L .50998 .75339 L F
.477 .823 .998 r
.26482 .65645 m .26855 .65676 L .26695 .65602 L F
.885 .879 .823 r
.26695 .65602 m .26855 .65676 L .27074 .65377 L F
.771 .669 .751 r
.64931 .5059 m .64714 .5086 L .64724 .50672 L F
.463 .41 .714 r
.35675 .67596 m .35735 .6793 L .35928 .6779 L F
.501 .482 .768 r
.35735 .6793 m .36013 .68137 L .35928 .6779 L F
.586 .731 .943 r
.35494 .70677 m .3499 .70525 L .35328 .70599 L F
.314 .737 .974 r
.35328 .70599 m .35642 .70651 L .35494 .70677 L F
.778 .723 .801 r
.64988 .53374 m .65337 .5341 L .65203 .53134 L F
.735 .335 .291 r
.65226 .5361 m .65337 .5341 L .64988 .53374 L F
.499 .583 .871 r
.65203 .53134 m .65337 .5341 L .6545 .53341 L F
0 0 0 r
.6545 .53341 m .65337 .5341 L .65226 .5361 L F
.519 .607 .881 r
.45969 .64986 m .45841 .65206 L .45771 .65 L F
.45969 .64986 m .46128 .6526 L .45841 .65206 L F
.689 .456 .565 r
.56622 .77309 m .56296 .77326 L .56287 .77075 L F
.587 .538 .767 r
.4712 .65923 m .46925 .66135 L .46893 .65963 L F
.4712 .65923 m .47262 .66322 L .46925 .66135 L F
.588 .55 .779 r
.47268 .66446 m .46925 .66135 L .47262 .66322 L F
.557 .203 .323 r
.4601 .68435 m .45675 .6864 L .45686 .68482 L F
.442 .255 .53 r
.38785 .67552 m .38561 .67858 L .38571 .67617 L F
.604 .713 .921 r
.69141 .48947 m .69024 .49225 L .68947 .48927 L F
.69141 .48947 m .6927 .4919 L .69024 .49225 L F
.618 .619 .829 r
.6927 .4919 m .69326 .49323 L .69024 .49225 L F
.522 .362 .606 r
.35675 .67596 m .35884 .67561 L .35878 .67318 L F
.463 .41 .714 r
.35675 .67596 m .35928 .6779 L .35884 .67561 L F
.85 .53 .446 r
.3762 .72164 m .37398 .72274 L .37539 .72064 L F
.68 .609 .77 r
.3781 .72038 m .3762 .72164 L .37539 .72064 L F
.896 .842 .784 r
.60528 .53068 m .60558 .53362 L .60375 .53381 L F
.60528 .53068 m .60666 .53166 L .60558 .53362 L F
.943 .822 .695 r
.60375 .53381 m .60558 .53362 L .60425 .53685 L F
.444 .874 .915 r
.75525 .59026 m .75693 .58929 L .75329 .59087 L F
.75525 .59026 m .75759 .58952 L .75693 .58929 L F
.635 .398 .541 r
.61591 .56213 m .61602 .56451 L .61252 .56467 L F
.658 .416 .541 r
.61591 .56213 m .61838 .56423 L .61602 .56451 L F
.691 .402 .48 r
.61591 .56213 m .61813 .56236 L .61838 .56423 L F
.867 .852 .826 r
.60877 .52895 m .60666 .53166 L .60528 .53068 L F
.631 .817 .971 r
.76331 .58946 m .76698 .58987 L .76548 .58903 L F
.538 .813 .997 r
.76698 .58987 m .76842 .58835 L .76548 .58903 L F
.739 .618 .724 r
.77704 .59807 m .7781 .60173 L .77479 .60099 L F
.62 .535 .736 r
.77972 .59747 m .7781 .60173 L .77704 .59807 L F
.77972 .59747 m .78053 .60088 L .7781 .60173 L F
.561 .527 .775 r
.78142 .60366 m .7781 .60173 L .78053 .60088 L F
.886 .761 .719 r
.62264 .4959 m .62174 .49783 L .62081 .49471 L F
.48 .015 .071 r
.39921 .65023 m .40158 .6504 L .40286 .64894 L F
.119 0 0 r
.40158 .6504 m .40489 .6494 L .40286 .64894 L F
.085 .539 .905 r
.33663 .59397 m .33637 .59463 L .33496 .59344 L F
.33663 .59397 m .33806 .59501 L .33637 .59463 L F
.216 0 0 r
.53823 .76172 m .53642 .76173 L .53424 .76144 L F
.421 0 0 r
.53823 .76172 m .53981 .76231 L .53642 .76173 L F
.369 .8 .967 r
.44269 .64933 m .44594 .64949 L .44377 .6501 L F
.842 .832 .838 r
.64765 .52023 m .64495 .52322 L .64779 .52301 L F
.34 0 0 r
.493 .77186 m .49245 .77282 L .49004 .77288 L F
.551 .041 0 r
.493 .77186 m .49548 .77288 L .49245 .77282 L F
.518 .203 .374 r
.44893 .68747 m .44875 .68955 L .44638 .68985 L F
.531 .214 .376 r
.45097 .68893 m .44875 .68955 L .44893 .68747 L F
.769 .568 .627 r
.51474 .7536 m .51823 .75129 L .51533 .75159 L F
.51474 .7536 m .51814 .75388 L .51823 .75129 L F
.94 .965 .714 r
.50337 .74228 m .50188 .74336 L .50343 .74227 L F
.50337 .74228 m .50265 .74534 L .50188 .74336 L F
.806 .535 .529 r
.62923 .53592 m .63205 .53394 L .63157 .53316 L F
.62923 .53592 m .63249 .53652 L .63205 .53394 L F
.888 .99 .779 r
.63372 .53026 m .63157 .53316 L .63205 .53394 L F
.296 0 .088 r
.56878 .68347 m .56881 .68422 L .56699 .68422 L F
.258 .047 .391 r
.56852 .68591 m .56699 .68422 L .56881 .68422 L F
.2 0 0 r
.76579 .61221 m .76505 .61211 L .76248 .61151 L F
.76248 .61151 m .76505 .61211 L .76579 .61221 L F
.332 .814 .866 r
.76754 .6115 m .76579 .61221 L .76817 .61173 L F
.76754 .6115 m .76505 .61211 L .76579 .61221 L F
.76754 .6115 m .76579 .61221 L .76817 .61173 L F
.76754 .6115 m .76505 .61211 L .76579 .61221 L F
.429 .872 .859 r
.55012 .75159 m .54922 .75162 L .55149 .75077 L F
.596 .127 .111 r
.58489 .71474 m .58661 .71506 L .58871 .71465 L F
.885 .879 .823 r
.26695 .65602 m .27074 .65377 L .26923 .65402 L F
.28 .783 .802 r
.27284 .65324 m .26923 .65402 L .27074 .65377 L F
.333 .75 .978 r
.32173 .59221 m .32117 .593 L .31981 .59259 L F
.32173 .59221 m .32315 .5929 L .32117 .593 L F
.701 .591 .729 r
.69947 .50696 m .7019 .50984 L .7029 .50946 L F
.33 0 0 r
.7264 .59661 m .72454 .59599 L .72395 .59736 L F
.7264 .59661 m .72702 .59568 L .72454 .59599 L F
.671 .484 .624 r
.69032 .5063 m .6927 .50618 L .69288 .50374 L F
.646 .584 .77 r
.69257 .50172 m .69288 .50374 L .69491 .50076 L F
.556 .464 .705 r
.69491 .50076 m .69288 .50374 L .69535 .5029 L F
.74 .545 .63 r
.69288 .50374 m .69608 .50619 L .69535 .5029 L F
.69288 .50374 m .6927 .50618 L .69608 .50619 L F
.867 .704 .677 r
.67302 .50411 m .67069 .5062 L .6721 .50365 L F
.492 .8 .999 r
.67451 .50347 m .67302 .50411 L .6721 .50365 L F
.818 .733 .771 r
.60996 .52285 m .61086 .52605 L .60807 .52577 L F
.861 .817 .804 r
.61086 .52605 m .60733 .5278 L .60807 .52577 L F
.61086 .52605 m .60877 .52895 L .60733 .5278 L F
.533 .34 .566 r
.49438 .76237 m .49434 .76482 L .4921 .76525 L F
.456 .214 .457 r
.58197 .67615 m .58448 .67751 L .58542 .67627 L F
.642 .141 .043 r
.58448 .67751 m .58784 .67794 L .58542 .67627 L F
.745 .681 .789 r
.62331 .51975 m .62474 .52067 L .62377 .51817 L F
.749 .592 .682 r
.62101 .5231 m .62474 .52067 L .62331 .51975 L F
.62101 .5231 m .62451 .52325 L .62474 .52067 L F
.249 0 0 r
.63237 .49724 m .63088 .497 L .632 .4944 L F
.594 .637 .863 r
.60489 .75041 m .60604 .7481 L .60387 .74819 L F
.60489 .75041 m .60736 .75001 L .60604 .7481 L F
.982 .707 .423 r
.60255 .725 m .60357 .72334 L .60254 .72262 L F
.60255 .725 m .6037 .72591 L .60357 .72334 L F
.4 .804 .982 r
.28627 .6692 m .2881 .66974 L .28579 .67011 L F
.28627 .6692 m .2881 .66974 L .28579 .67011 L F
.399 .104 .344 r
.26768 .61717 m .26509 .61953 L .26585 .61797 L F
.536 .423 .672 r
.35838 .67092 m .36039 .67043 L .36019 .66722 L F
.45 .366 .67 r
.35838 .67092 m .36052 .6727 L .36039 .67043 L F
.35838 .67092 m .35878 .67318 L .36052 .6727 L F
.569 .305 .477 r
.62114 .56172 m .61838 .56423 L .61813 .56236 L F
.867 .852 .826 r
.60877 .52895 m .60528 .53068 L .60733 .5278 L F
.553 .596 .851 r
.46349 .65232 m .46204 .65456 L .46128 .6526 L F
.522 .555 .83 r
.46349 .65232 m .4643 .6545 L .46204 .65456 L F
.705 .482 .582 r
.49655 .76475 m .49434 .76482 L .49438 .76237 L F
.592 .469 .681 r
.54464 .70102 m .547 .70163 L .54794 .69711 L F
.614 .308 .427 r
.54478 .70301 m .547 .70163 L .54464 .70102 L F
.293 .037 .344 r
.32359 .64134 m .32191 .63996 L .32448 .63961 L F
.32359 .64134 m .32187 .64221 L .32191 .63996 L F
.416 .767 .995 r
.28454 .58661 m .28655 .58641 L .28805 .58727 L F
.469 .794 .999 r
.28655 .58641 m .29004 .58691 L .28805 .58727 L F
.308 .672 .975 r
.75612 .61957 m .75733 .61865 L .75519 .61832 L F
.75612 .61957 m .75827 .61965 L .75733 .61865 L F
.519 .497 .772 r
.76105 .5904 m .76246 .59455 L .76465 .59424 L F
.482 .421 .712 r
.76246 .59455 m .76434 .59502 L .76465 .59424 L F
.343 0 0 r
.7317 .59634 m .73025 .5955 L .72928 .59549 L F
.7317 .59634 m .73278 .5959 L .73025 .5955 L F
.576 .357 .547 r
.53884 .76786 m .54117 .76756 L .5413 .76519 L F
.591 .35 .52 r
.54117 .76756 m .54378 .76478 L .5413 .76519 L F
.473 .011 .075 r
.38196 .65261 m .38032 .65166 L .37979 .65255 L F
.557 .203 .323 r
.4601 .68435 m .459 .68646 L .45675 .6864 L F
.471 .093 .24 r
.46244 .68415 m .459 .68646 L .4601 .68435 L F
.701 .591 .729 r
.69947 .50696 m .7029 .50946 L .70174 .50611 L F
.667 .593 .763 r
.70174 .50611 m .7029 .50946 L .70534 .50868 L F
.671 .641 .812 r
.7029 .50946 m .70667 .509 L .70534 .50868 L F
.384 .002 .184 r
.43653 .69459 m .43522 .69695 L .43329 .69627 L F
.439 .031 .167 r
.43826 .69483 m .43522 .69695 L .43653 .69459 L F
.71 .671 .811 r
.71448 .60371 m .71717 .60477 L .71697 .60287 L F
.581 .575 .812 r
.71697 .60287 m .71717 .60477 L .71932 .60257 L F
.372 .567 .912 r
.71717 .60477 m .72026 .6058 L .71932 .60257 L F
.71717 .60477 m .71978 .60649 L .72026 .6058 L F
.245 0 0 r
.7484 .58888 m .75041 .58834 L .7511 .58696 L F
0 0 0 r
.7511 .58696 m .75041 .58834 L .75324 .58595 L F
.749 .317 .225 r
.64445 .49545 m .64327 .4966 L .6412 .49458 L F
.877 .509 .344 r
.64445 .49545 m .64552 .49773 L .64327 .4966 L F
.795 .337 .154 r
.58956 .72305 m .5861 .72054 L .58953 .72065 L F
.51 .271 .487 r
.59257 .72059 m .58956 .72305 L .58953 .72065 L F
.332 .146 .472 r
.45513 .78145 m .45682 .77871 L .4546 .77917 L F
.18 0 0 r
.39225 .71468 m .39095 .71428 L .39326 .71367 L F
.39225 .71468 m .39032 .71526 L .39095 .71428 L F
.957 .661 .433 r
.6011 .71902 m .60229 .71795 L .60062 .71629 L F
.6011 .71902 m .60244 .72012 L .60229 .71795 L F
.809 .72 .767 r
.53981 .76231 m .54319 .76215 L .54214 .76259 L F
.52 .333 .567 r
.54649 .75925 m .54611 .76158 L .54319 .76215 L F
.847 .495 .387 r
.48939 .79611 m .48998 .7952 L .48733 .79423 L F
.51 .139 .271 r
.49136 .79739 m .48998 .7952 L .48939 .79611 L F
.49136 .79739 m .49232 .79558 L .48998 .7952 L F
.383 .193 .495 r
.50225 .73181 m .50391 .73337 L .50415 .73125 L F
.50225 .73181 m .50206 .73422 L .50391 .73337 L F
0 .057 .621 r
.58121 .73796 m .58233 .73995 L .58076 .7364 L F
.048 0 0 r
.68644 .54031 m .68519 .54078 L .68271 .54109 L F
.361 0 0 r
.68847 .53926 m .68519 .54078 L .68644 .54031 L F
.746 .574 .662 r
.5001 .76231 m .49907 .7649 L .49655 .76475 L F
.416 0 0 r
.49937 .76087 m .50247 .76182 L .5001 .76231 L F
0 0 0 r
.52713 .74011 m .52835 .73921 L .52948 .73736 L F
.225 .368 .798 r
.52713 .74011 m .5296 .74163 L .52835 .73921 L F
.523 .87 .617 r
.53889 .80247 m .5405 .80129 L .54152 .80028 L F
.547 .271 .448 r
.51245 .75378 m .51474 .7536 L .51533 .75159 L F
.097 0 0 r
.29203 .60425 m .29165 .6035 L .29376 .60328 L F
.511 .821 1 r
.66378 .48144 m .66696 .48182 L .66514 .48256 L F
0 0 .207 r
.53835 .80356 m .53799 .8036 L .53889 .80247 L F
0 0 .237 r
.54794 .69711 m .54812 .69964 L .54789 .70004 L F
.771 .669 .751 r
.54812 .69964 m .5506 .69686 L .54789 .70004 L F
0 0 0 r
.75576 .58378 m .75839 .5827 L .75622 .58268 L F
.978 .719 .471 r
.68354 .52019 m .68477 .52031 L .68363 .51897 L F
.68354 .52019 m .68496 .52229 L .68477 .52031 L F
.764 .823 .899 r
.68363 .51897 m .68477 .52031 L .68729 .51868 L F
.846 .697 .697 r
.61371 .74213 m .61485 .74543 L .61569 .74327 L F
.537 .273 .461 r
.62382 .55935 m .62377 .56126 L .62114 .56172 L F
.534 .269 .461 r
.62382 .55935 m .62581 .56085 L .62377 .56126 L F
.591 .238 .34 r
.62608 .5595 m .62581 .56085 L .62382 .55935 L F
.187 0 .186 r
.49991 .73475 m .49746 .73727 L .49923 .73648 L F
.407 .083 .3 r
.49923 .73648 m .50206 .73422 L .49991 .73475 L F
.546 .408 .645 r
.47352 .66774 m .47363 .6702 L .47138 .67064 L F
.059 0 .222 r
.53436 .80107 m .53401 .80328 L .5343 .80082 L F
.386 .826 .949 r
.53582 .80034 m .53436 .80107 L .5343 .80082 L F
.64 .816 .391 r
.50524 .73913 m .50343 .74227 L .50676 .73922 L F
.50524 .73913 m .50337 .74228 L .50343 .74227 L F
.59 .31 .461 r
.53179 .74767 m .53381 .74793 L .53417 .74573 L F
.56 .283 .453 r
.53417 .74573 m .5362 .74761 L .53622 .74519 L F
.53417 .74573 m .53381 .74793 L .5362 .74761 L F
.344 .54 .902 r
.56618 .76686 m .56697 .76864 L .56492 .76807 L F
.56618 .76686 m .56697 .76864 L .56492 .76807 L F
.824 .701 .729 r
.47198 .79539 m .47323 .7985 L .47003 .79757 L F
.654 .11 0 r
.47003 .79757 m .47323 .7985 L .47223 .79872 L F
.571 .524 .764 r
.47443 .7956 m .47323 .7985 L .47198 .79539 L F
.47443 .7956 m .47543 .79815 L .47323 .7985 L F
.361 .809 .949 r
.47323 .7985 m .47409 .79783 L .47223 .79872 L F
.47323 .7985 m .47543 .79815 L .47409 .79783 L F
.54 .283 .474 r
.44618 .67823 m .44851 .67793 L .4465 .67613 L F
.598 .27 .385 r
.4465 .67613 m .44851 .67793 L .44915 .67622 L F
.853 .399 .105 r
.55225 .7062 m .55389 .70888 L .55524 .70931 L F
.716 .24 .117 r
.55389 .70888 m .55755 .71061 L .55524 .70931 L F
0 0 0 r
.3762 .72164 m .3759 .72198 L .37398 .72274 L F
.613 .574 .786 r
.68287 .49799 m .68454 .49498 L .68248 .4961 L F
.68287 .49799 m .68543 .49768 L .68454 .49498 L F
.563 .2 .31 r
.68287 .49799 m .68493 .49908 L .68543 .49768 L F
.68287 .49799 m .68234 .49983 L .68493 .49908 L F
.493 0 0 r
.56273 .71919 m .55856 .71738 L .56021 .71735 L F
.624 .709 .907 r
.74207 .61414 m .74307 .61678 L .74536 .61526 L F
.66 .683 .861 r
.74307 .61678 m .7464 .6172 L .74536 .61526 L F
.605 .805 .976 r
.4553 .65037 m .45178 .64986 L .45389 .64927 L F
.565 .735 .955 r
.45614 .64811 m .4553 .65037 L .45389 .64927 L F
.45614 .64811 m .45771 .65 L .4553 .65037 L F
.567 .72 .945 r
.48174 .79032 m .47989 .79088 L .47821 .78828 L F
.805 .718 .769 r
.56885 .77275 m .56978 .77625 L .57172 .77334 L F
.567 .783 .98 r
.45178 .64986 m .44969 .65032 L .44827 .64926 L F
.803 .722 .775 r
.57001 .77063 m .57172 .77334 L .56885 .77275 L F
.56885 .77275 m .57172 .77334 L .57001 .77063 L F
.834 .426 0 r
.57001 .77063 m .57115 .77298 L .57172 .77334 L F
0 0 .172 r
.57194 .76968 m .57198 .77118 L .57115 .77298 L F
.57198 .77118 m .572 .77175 L .57171 .77217 L F
.57198 .77118 m .57171 .77217 L .57115 .77298 L F
.483 .306 .564 r
.57113 .76709 m .57194 .76968 L .57001 .77063 L F
0 0 .172 r
.57194 .76968 m .57115 .77298 L .57001 .77063 L F
.976 .818 .622 r
.5708 .77103 m .57236 .76983 L .57217 .7676 L F
.093 0 .446 r
.57284 .76662 m .57276 .76952 L .57194 .76968 L F
.976 .818 .622 r
.57236 .76983 m .57276 .76952 L .57259 .76898 L F
.57236 .76983 m .57259 .76898 L .57217 .7676 L F
.652 .932 .662 r
.57115 .77298 m .572 .77175 L .5711 .77263 L F
.105 .632 .874 r
.57118 .77323 m .57115 .77298 L .56885 .77275 L F
.57172 .77334 m .57115 .77298 L .56885 .77275 L F
.51 .059 .115 r
.56885 .77275 m .57115 .77298 L .56917 .77454 L F
.652 .932 .662 r
.57115 .77298 m .5711 .77263 L .56917 .77454 L F
.105 .632 .874 r
.57172 .77334 m .57115 .77298 L .57118 .77323 L F
.393 0 .112 r
.69518 .51875 m .69819 .51697 L .69601 .51749 L F
.604 .608 .829 r
.46893 .65963 m .46563 .65743 L .46801 .65676 L F
.565 .509 .751 r
.46996 .65558 m .46893 .65963 L .46801 .65676 L F
.46996 .65558 m .4712 .65923 L .46893 .65963 L F
.569 .728 .949 r
.34675 .71043 m .34924 .70998 L .34527 .70881 L F
.277 .577 .941 r
.71316 .50369 m .71318 .5027 L .70948 .50161 L F
0 0 .156 r
.71316 .50596 m .71318 .5027 L .71316 .50369 L F
.137 0 0 r
.64988 .54591 m .65111 .54634 L .64876 .5467 L F
.64988 .54591 m .65213 .54544 L .65111 .54634 L F
.234 0 0 r
.48849 .77368 m .48691 .77534 L .48573 .77532 L F
.713 .488 .583 r
.49004 .77288 m .48691 .77534 L .48849 .77368 L F
.64 .757 .933 r
.7464 .6172 m .74785 .61472 L .74536 .61526 L F
.7464 .6172 m .7492 .61645 L .74785 .61472 L F
.293 0 0 r
.41661 .69405 m .4203 .69222 L .41826 .69284 L F
.988 .817 .581 r
.60087 .69805 m .60028 .69496 L .59975 .69735 L F
.892 .754 .252 r
.59975 .69735 m .59977 .7011 L .60087 .69805 L F
.535 .631 .893 r
.68863 .52365 m .68954 .52479 L .69059 .52254 L F
.474 .347 .627 r
.68954 .52479 m .69311 .52199 L .69059 .52254 L F
.68954 .52479 m .69335 .52472 L .69311 .52199 L F
.374 0 .125 r
.69267 .52591 m .68954 .52479 L .69064 .5266 L F
.69267 .52591 m .69335 .52472 L .68954 .52479 L F
.067 0 0 r
.36718 .71213 m .36339 .71208 L .36482 .71287 L F
.229 0 0 r
.64245 .50262 m .64476 .50215 L .64579 .50089 L F
.566 .821 .452 r
.64579 .50089 m .64476 .50215 L .64701 .49932 L F
.905 .874 .796 r
.65595 .49525 m .65684 .49089 L .65652 .49286 L F
.39 .105 .355 r
.48204 .74606 m .4835 .74734 L .48423 .74573 L F
.48204 .74606 m .48156 .74788 L .4835 .74734 L F
.318 0 .22 r
.71902 .51765 m .71867 .5196 L .71629 .51979 L F
.364 .133 .424 r
.72095 .51669 m .71902 .51765 L .72127 .5148 L F
.204 0 .189 r
.72069 .51852 m .71902 .51765 L .72095 .51669 L F
.72069 .51852 m .71867 .5196 L .71902 .51765 L F
.502 .527 .815 r
.47424 .78681 m .47421 .78742 L .47297 .78732 L F
.35 .153 .467 r
.47436 .78707 m .47424 .78681 L .47297 .78732 L F
.47424 .78681 m .47324 .78451 L .47297 .78732 L F
.502 .527 .815 r
.47426 .78648 m .47424 .78681 L .47297 .78732 L F
.47236 .78512 m .47426 .78648 L .47297 .78732 L F
.47426 .78648 m .47575 .78755 L .47421 .78742 L F
0 0 .475 r
.47398 .78351 m .47324 .78451 L .47424 .78681 L F
.47427 .78627 m .47424 .78681 L .47436 .78707 L F
.616 .521 .724 r
.47398 .78351 m .47575 .78755 L .47426 .78648 L F
0 0 .475 r
.47398 .78351 m .47424 .78681 L .47426 .78648 L F
.616 .521 .724 r
.47398 .78351 m .47426 .78648 L .47236 .78512 L F
0 0 .475 r
.47398 .78351 m .47426 .78648 L .47427 .78627 L F
.38 0 0 r
.27284 .65324 m .27633 .6535 L .2753 .65375 L F
.431 .869 .903 r
.27698 .65284 m .27633 .6535 L .27841 .65281 L F
.478 .894 .804 r
.2753 .65375 m .27633 .6535 L .27698 .65284 L F
.92 .953 .619 r
.58892 .70651 m .58675 .70966 L .58812 .70729 L F
.58892 .70651 m .58697 .71067 L .58675 .70966 L F
.641 .891 .556 r
.58892 .70651 m .58988 .7051 L .59189 .70405 L F
.818 .682 .715 r
.54991 .76971 m .55208 .77118 L .55205 .7694 L F
.875 .946 .587 r
.55208 .77118 m .55084 .77216 L .55205 .7694 L F
.886 .512 .327 r
.55078 .70536 m .55389 .70888 L .55225 .7062 L F
.033 0 0 r
.63014 .50213 m .62818 .50235 L .63142 .50136 L F
.63014 .50213 m .62787 .5029 L .62818 .50235 L F
.6 .542 .761 r
.35891 .68951 m .36021 .69266 L .36243 .69222 L F
.619 .624 .834 r
.67956 .50474 m .67609 .50459 L .67691 .50538 L F
.67956 .50474 m .67735 .50293 L .67609 .50459 L F
.698 .505 .623 r
.68107 .50576 m .67912 .50669 L .67956 .50474 L F
.722 .488 .572 r
.67691 .50538 m .68107 .50576 L .67956 .50474 L F
.596 .538 .76 r
.68102 .50389 m .68107 .50576 L .67956 .50474 L F
.68102 .50389 m .68107 .50576 L .67956 .50474 L F
.871 .61 .54 r
.64313 .50839 m .64215 .50495 L .64279 .50575 L F
.797 .7 .758 r
.35272 .71175 m .35583 .71226 L .35436 .71009 L F
.914 .698 .596 r
.35272 .71175 m .35425 .71474 L .35583 .71226 L F
.466 .553 .861 r
.35583 .71226 m .35775 .71221 L .35684 .71032 L F
.638 .35 .465 r
.46808 .68149 m .46706 .68415 L .46472 .68387 L F
.596 .306 .446 r
.47037 .68354 m .46808 .68149 L .47046 .68139 L F
.47037 .68354 m .46706 .68415 L .46808 .68149 L F
.575 .322 .495 r
.55848 .68728 m .56106 .68695 L .56085 .68476 L F
.642 .736 .917 r
.36609 .72092 m .36979 .72171 L .36824 .72049 L F
.664 .789 .941 r
.36824 .72049 m .36979 .72171 L .37196 .72107 L F
.299 .003 .283 r
.52683 .75081 m .5284 .75056 L .5298 .74797 L F
.564 .293 .464 r
.5284 .75056 m .53179 .74767 L .5298 .74797 L F
.188 0 .167 r
.49482 .73946 m .49402 .74189 L .49593 .74102 L F
.911 .962 .805 r
.72452 .50354 m .72596 .49974 L .72698 .50095 L F
.506 .275 .498 r
.72698 .50095 m .72687 .50301 L .72452 .50354 L F
.697 .875 .965 r
.72698 .50095 m .72865 .49898 L .72913 .5002 L F
.72698 .50095 m .72596 .49974 L .72865 .49898 L F
.554 .367 .583 r
.72913 .5002 m .72687 .50301 L .72698 .50095 L F
.182 0 0 r
.25222 .58869 m .25428 .58824 L .25603 .58684 L F
.045 0 0 r
.25603 .58684 m .25632 .58755 L .25812 .58656 L F
.25603 .58684 m .25428 .58824 L .25632 .58755 L F
.602 .047 0 r
.5083 .77439 m .50704 .77493 L .50468 .77343 L F
.709 .185 0 r
.5083 .77439 m .51 .77609 L .50704 .77493 L F
.7 .162 0 r
.51155 .77643 m .51 .77609 L .5083 .77439 L F
.661 .656 .834 r
.69608 .50619 m .69947 .50696 L .69921 .50584 L F
.694 .677 .83 r
.69921 .50584 m .69947 .50696 L .70174 .50611 L F
.185 0 .078 r
.50945 .80674 m .50866 .80664 L .50817 .80795 L F
.755 .67 .767 r
.51013 .80653 m .50773 .80654 L .50866 .80664 L F
.042 .06 .552 r
.51081 .80311 m .51013 .80653 L .51079 .80547 L F
.604 .95 .913 r
.51079 .80547 m .51013 .80653 L .50866 .80664 L F
.185 0 .078 r
.51079 .80547 m .50866 .80664 L .50945 .80674 L F
.755 .67 .767 r
.50773 .80654 m .50642 .80654 L .50866 .80664 L F
.457 .298 .576 r
.26509 .61953 m .26317 .6228 L .26325 .62041 L F
.442 .097 .284 r
.49882 .74972 m .49777 .74837 L .49967 .74884 L F
.587 .229 .328 r
.46568 .75611 m .46809 .75631 L .46927 .75402 L F
.449 .086 .256 r
.46927 .75402 m .47084 .75527 L .47137 .75354 L F
.46927 .75402 m .46809 .75631 L .47084 .75527 L F
.415 .429 .767 r
.35833 .68428 m .35913 .68718 L .36071 .68683 L F
.613 .569 .781 r
.35891 .68951 m .36071 .68683 L .35913 .68718 L F
.844 .602 .572 r
.49855 .77872 m .50087 .78158 L .50046 .78039 L F
.998 .834 .549 r
.50087 .78158 m .50062 .77632 L .50046 .78039 L F
.343 0 .215 r
.24456 .59201 m .24654 .59148 L .24801 .58894 L F
.279 0 .177 r
.24801 .58894 m .24849 .59076 L .25011 .58886 L F
.24801 .58894 m .24654 .59148 L .24849 .59076 L F
.453 .351 .649 r
.52647 .7532 m .5284 .75056 L .52683 .75081 L F
.737 .678 .793 r
.6927 .50618 m .69379 .50701 L .69608 .50619 L F
.663 .621 .797 r
.69535 .5029 m .69608 .50619 L .69921 .50584 L F
.809 .648 .682 r
.60907 .73399 m .6107 .73672 L .6123 .73434 L F
.408 .201 .484 r
.72325 .51384 m .72127 .5148 L .72344 .51189 L F
.07 0 .15 r
.72325 .51384 m .72095 .51669 L .72127 .5148 L F
.117 .264 .739 r
.63362 .53649 m .63663 .53824 L .63717 .53523 L F
.732 .697 .159 r
.63717 .53523 m .63663 .53824 L .63697 .53608 L F
0 0 0 r
.63717 .53523 m .63697 .53608 L .6371 .53586 L F
.63717 .53523 m .6371 .53586 L .63838 .53366 L F
.63727 .53441 m .63717 .53523 L .63847 .53374 L F
.63362 .53649 m .63717 .53523 L .63727 .53441 L F
.551 .587 .843 r
.6371 .53031 m .63847 .53374 L .6392 .53242 L F
.508 .502 .785 r
.50111 .75396 m .50392 .75621 L .50361 .75371 L F
.45 .733 .988 r
.48141 .65812 m .48297 .65918 L .48045 .65939 L F
.48141 .65812 m .48297 .65918 L .48045 .65939 L F
.607 .079 0 r
.70655 .50493 m .70979 .50553 L .70692 .50415 L F
0 0 0 r
.70849 .50314 m .70692 .50415 L .70875 .5023 L F
.70849 .50314 m .70655 .50493 L .70692 .50415 L F
.788 .677 .742 r
.65227 .50629 m .65068 .50939 L .64931 .5059 L F
.684 .746 .898 r
.73174 .61537 m .734 .61442 L .73069 .61381 L F
.506 .227 .425 r
.52259 .7348 m .52252 .7368 L .52023 .73707 L F
.441 .176 .415 r
.5247 .73607 m .52259 .7348 L .52668 .7343 L F
.5247 .73607 m .52252 .7368 L .52259 .7348 L F
.474 .496 .8 r
.6418 .52899 m .64041 .52972 L .6394 .53012 L F
.64201 .5289 m .6417 .52906 L .6418 .52899 L F
.6417 .52906 m .64041 .52972 L .6418 .52899 L F
.64231 .52874 m .64291 .53098 L .64041 .52972 L F
.788 .587 .628 r
.64256 .52744 m .64158 .52773 L .64386 .52526 L F
.546 .529 .787 r
.64567 .52501 m .64256 .52744 L .64386 .52526 L F
.64567 .52501 m .64686 .52672 L .64256 .52744 L F
.464 .513 .824 r
.64695 .52928 m .64465 .52831 L .64686 .52672 L F
.64489 .52749 m .64256 .52744 L .64503 .52702 L F
0 0 .203 r
.64489 .52749 m .64567 .52501 L .64386 .52526 L F
.645 .52773 m .64508 .52741 L .64489 .52749 L F
.64508 .52741 m .64567 .52501 L .64489 .52749 L F
.464 .513 .824 r
.64465 .52831 m .64378 .52795 L .64437 .52771 L F
.64465 .52831 m .64437 .52771 L .64482 .52773 L F
.616 .527 .731 r
.64256 .52744 m .64284 .53026 L .64243 .5291 L F
.64256 .52744 m .64243 .5291 L .64233 .52859 L F
.64256 .52744 m .64593 .53027 L .64291 .53098 L F
.788 .587 .628 r
.64256 .52744 m .64231 .52874 L .64158 .52773 L F
.464 .513 .824 r
.64301 .52763 m .64276 .5276 L .64256 .52744 L F
.64378 .52795 m .64256 .52744 L .64489 .52749 L F
.631 .572 .769 r
.64217 .52773 m .6442 .52773 L .64207 .5272 L F
.6442 .52773 m .645 .52773 L .64407 .52756 L F
.6442 .52773 m .64407 .52756 L .64207 .5272 L F
.464 .513 .824 r
.6447 .52838 m .64593 .53027 L .64276 .5276 L F
.64695 .52928 m .64605 .53015 L .6447 .52838 L F
.64605 .53015 m .64593 .53027 L .6447 .52838 L F
.6442 .52812 m .64276 .5276 L .64301 .52763 L F
.64413 .52815 m .64276 .5276 L .6442 .52812 L F
0 .003 .552 r
.64444 .52778 m .64324 .52857 L .64488 .52779 L F
.64158 .52773 m .64324 .52857 L .64444 .52778 L F
.616 .527 .731 r
.64233 .52859 m .64243 .5291 L .64231 .52874 L F
0 .003 .552 r
.6418 .52899 m .64211 .53075 L .64285 .52837 L F
.768 .951 .625 r
.64324 .52857 m .64205 .52948 L .64224 .52922 L F
0 .003 .552 r
.64158 .52773 m .64488 .52779 L .64429 .52774 L F
.64158 .52773 m .64498 .52774 L .64482 .52773 L F
.464 .513 .824 r
.64482 .52773 m .64437 .52771 L .64489 .52749 L F
.631 .572 .769 r
.64207 .5272 m .64483 .5277 L .64386 .52526 L F
.64483 .5277 m .64489 .52749 L .64386 .52526 L F
.768 .951 .625 r
.64324 .52857 m .64224 .52922 L .64445 .52624 L F
.313 .776 .643 r
.64502 .52772 m .64324 .52857 L .64526 .52759 L F
0 .003 .552 r
.64429 .52774 m .64488 .52779 L .64498 .52774 L F
.464 .513 .824 r
.64516 .52703 m .64517 .527 L .64686 .52672 L F
0 0 .203 r
.64508 .52741 m .64646 .52669 L .64567 .52501 L F
.645 .52773 m .64502 .52772 L .64508 .52741 L F
0 .003 .552 r
.64482 .52773 m .64498 .52774 L .645 .52773 L F
.631 .572 .769 r
.64483 .5277 m .645 .52773 L .64489 .52749 L F
.464 .513 .824 r
.64479 .52784 m .64503 .52702 L .64589 .52706 L F
.645 .52773 m .64589 .52706 L .64636 .52707 L F
.313 .776 .643 r
.645 .52773 m .645 .52773 L .64502 .52772 L F
.464 .513 .824 r
.64479 .52784 m .64589 .52706 L .645 .52773 L F
.313 .776 .643 r
.64502 .52772 m .64526 .52759 L .64646 .52669 L F
.645 .52773 m .64526 .52759 L .64502 .52772 L F
0 0 .203 r
.64502 .52772 m .64646 .52669 L .64508 .52741 L F
.464 .513 .824 r
.64636 .52707 m .64516 .52703 L .64686 .52672 L F
.64516 .52703 m .64503 .52702 L .64517 .527 L F
.313 .776 .643 r
.645 .52773 m .64498 .52774 L .645 .52773 L F
.464 .513 .824 r
.64465 .52831 m .64479 .52784 L .64636 .52707 L F
.313 .776 .643 r
.645 .52773 m .64488 .52779 L .64502 .52772 L F
.64498 .52774 m .64488 .52779 L .645 .52773 L F
.64488 .52779 m .64324 .52857 L .64502 .52772 L F
.464 .513 .824 r
.64695 .52928 m .64413 .52815 L .6442 .52812 L F
.631 .572 .769 r
.64158 .52773 m .64217 .52773 L .64207 .5272 L F
.616 .527 .731 r
.64284 .53026 m .64291 .53098 L .64272 .5303 L F
.64284 .53026 m .64272 .5303 L .64231 .52874 L F
0 .003 .552 r
.64285 .52837 m .64211 .53075 L .64324 .52857 L F
.809 .681 .723 r
.6394 .53012 m .64211 .53075 L .6418 .52899 L F
.7 .983 .839 r
.64324 .52857 m .64225 .53047 L .64066 .53052 L F
.64225 .53047 m .64211 .53075 L .64167 .53068 L F
.64225 .53047 m .64167 .53068 L .64066 .53052 L F
0 .003 .552 r
.64158 .52773 m .6418 .52899 L .64285 .52837 L F
.809 .681 .723 r
.6394 .53012 m .6418 .52899 L .64158 .52773 L F
.474 .496 .8 r
.64231 .52874 m .64201 .5289 L .6394 .53012 L F
.536 .195 .337 r
.46075 .75633 m .46347 .75631 L .46302 .75492 L F
.603 .233 .313 r
.46302 .75492 m .46347 .75631 L .46568 .75611 L F
.36 .536 .893 r
.5859 .74636 m .58732 .74486 L .58537 .74493 L F
.5859 .74636 m .58874 .74749 L .58732 .74486 L F
.657 .692 .871 r
.69032 .5063 m .69379 .50701 L .6927 .50618 L F
.592 .604 .834 r
.69563 .49266 m .69326 .49323 L .6927 .4919 L F
.381 .392 .747 r
.5936 .56194 m .59522 .56414 L .59492 .56086 L F
.7 .981 .891 r
.68413 .51562 m .68103 .51761 L .68108 .51676 L F
.641 .784 .95 r
.76673 .5802 m .76767 .5815 L .76432 .58096 L F
.558 .718 .947 r
.76908 .57973 m .76767 .5815 L .76673 .5802 L F
.76908 .57973 m .77006 .5811 L .76767 .5815 L F
.891 .669 .596 r
.59701 .69012 m .59457 .68689 L .59434 .68949 L F
.839 .504 .42 r
.59434 .68949 m .59686 .69178 L .59701 .69012 L F
.776 .41 .365 r
.59686 .69178 m .59752 .6926 L .59701 .69012 L F
.521 .562 .838 r
.46638 .65496 m .46563 .65743 L .4643 .6545 L F
.628 .676 .876 r
.46801 .65676 m .46563 .65743 L .46638 .65496 L F
.581 .634 .869 r
.67637 .49555 m .67812 .49348 L .67584 .49402 L F
.67637 .49555 m .67887 .49496 L .67812 .49348 L F
.269 0 .079 r
.742 .59611 m .74352 .59643 L .74148 .59672 L F
.742 .59611 m .74441 .59528 L .74352 .59643 L F
.754 .289 .143 r
.49967 .74884 m .50159 .75127 L .49882 .74972 L F
.365 .124 .409 r
.50265 .74534 m .50228 .74815 L .49967 .74884 L F
.873 .582 .493 r
.50081 .74734 m .50228 .74819 L .50265 .74534 L F
.42 .264 .562 r
.501 .74849 m .50159 .75127 L .49967 .74884 L F
.50208 .74903 m .50159 .75127 L .501 .74849 L F
.50229 .74819 m .50159 .75127 L .50228 .74815 L F
.534 .025 0 r
.50236 .74917 m .50346 .74887 L .5023 .7482 L F
.50236 .74914 m .5023 .7482 L .50229 .74819 L F
.50236 .74917 m .5023 .7482 L .50236 .74914 L F
.50355 .74979 m .50359 .74981 L .50359 .7498 L F
.412 .256 .557 r
.50359 .74981 m .50246 .75063 L .50262 .74931 L F
.50246 .75063 m .50159 .75127 L .50235 .74917 L F
.50236 .74917 m .50235 .74917 L .50236 .74914 L F
.50246 .75063 m .50235 .74917 L .50236 .74917 L F
.534 .025 0 r
.50236 .74917 m .50359 .7498 L .50236 .74917 L F
.873 .582 .493 r
.50229 .74819 m .50346 .74887 L .50228 .74815 L F
.412 .256 .557 r
.50246 .75063 m .50236 .74914 L .50277 .74802 L F
.42 .264 .562 r
.50236 .74914 m .50159 .75127 L .50229 .74819 L F
.534 .025 0 r
.50085 .7496 m .50355 .74979 L .50236 .74917 L F
.50355 .74979 m .50359 .7498 L .50236 .74917 L F
.50085 .7496 m .50359 .74981 L .50355 .74979 L F
.50236 .74917 m .50359 .7498 L .50346 .74887 L F
.412 .256 .557 r
.50359 .74981 m .50262 .74931 L .50277 .74802 L F
.42 .264 .562 r
.5024 .74902 m .50236 .74914 L .50229 .74819 L F
.50228 .74815 m .50208 .74903 L .501 .74849 L F
.534 .025 0 r
.50085 .7496 m .50236 .74917 L .50081 .74734 L F
.50236 .74917 m .50229 .74819 L .50081 .74734 L F
.42 .264 .562 r
.50277 .74802 m .5024 .74902 L .50228 .74815 L F
.873 .582 .493 r
.50228 .74815 m .50346 .74887 L .50265 .74534 L F
.50228 .74819 m .50229 .74819 L .50228 .74815 L F
.365 .124 .409 r
.50265 .74534 m .50277 .74802 L .50228 .74815 L F
.754 .289 .143 r
.49967 .74884 m .50159 .75127 L .49882 .74972 L F
.011 .192 .703 r
.51155 .77643 m .51285 .77594 L .51 .77609 L F
.612 .274 .374 r
.51524 .77623 m .51437 .77934 L .51155 .77643 L F
.011 .192 .703 r
.51155 .77643 m .51437 .77934 L .51394 .77837 L F
.993 .748 .443 r
.51745 .77618 m .51437 .77934 L .51524 .77623 L F
.51745 .77618 m .51632 .77765 L .51437 .77934 L F
.745 .61 .708 r
.51285 .77594 m .51437 .77934 L .51632 .77765 L F
.874 .906 .849 r
.51632 .77765 m .51395 .78067 L .51262 .77983 L F
.993 .747 .442 r
.51632 .77765 m .51656 .77998 L .51395 .78067 L F
.874 .906 .849 r
.51538 .77969 m .51262 .77983 L .51519 .7801 L F
.51632 .77765 m .51439 .77879 L .51538 .77969 L F
.51439 .77879 m .51262 .77983 L .51538 .77969 L F
.011 .192 .703 r
.51175 .77635 m .51394 .77837 L .51285 .77594 L F
.51155 .77643 m .51394 .77837 L .51175 .77635 L F
.665 .511 .666 r
.45051 .67303 m .45421 .67284 L .45427 .67209 L F
.564 .349 .547 r
.45051 .67303 m .45346 .67498 L .45421 .67284 L F
.45051 .67303 m .45115 .67551 L .45346 .67498 L F
.308 .056 .36 r
.69504 .53048 m .69303 .53145 L .69529 .52871 L F
.425 .275 .573 r
.69504 .53048 m .69505 .53286 L .69303 .53145 L F
.4 .281 .601 r
.69505 .53286 m .69337 .53396 L .69303 .53145 L F
.392 0 .009 r
.41655 .66348 m .41339 .66434 L .41449 .6631 L F
.766 .674 .761 r
.35917 .71741 m .36049 .72057 L .35694 .72023 L F
.493 0 0 r
.36049 .72057 m .35821 .72092 L .35694 .72023 L F
.19 .342 .787 r
.36176 .71792 m .36108 .71909 L .35992 .71655 L F
.691 .966 .935 r
.36176 .71792 m .36152 .71803 L .36108 .71909 L F
.04 .235 .736 r
.36108 .71909 m .36048 .72055 L .35917 .71741 L F
.543 .846 .53 r
.35917 .71741 m .35992 .71655 L .36108 .71909 L F
.691 .966 .935 r
.36152 .71803 m .35961 .71892 L .36108 .71909 L F
.04 .235 .736 r
.36108 .71909 m .36049 .72057 L .36048 .72055 L F
.707 .976 .919 r
.36108 .71909 m .35821 .72092 L .36049 .72057 L F
.143 0 0 r
.29551 .63728 m .29767 .63694 L .29867 .63639 L F
.037 0 0 r
.29767 .63694 m .30069 .63603 L .29867 .63639 L F
.791 .511 .513 r
.60581 .73349 m .60876 .73178 L .60609 .73125 L F
.60581 .73349 m .60907 .73399 L .60876 .73178 L F
.489 .219 .432 r
.69765 .52813 m .69504 .53048 L .69529 .52871 L F
.786 .865 .424 r
.58233 .72277 m .58145 .72576 L .58326 .72295 L F
.58233 .72277 m .5814 .72535 L .58145 .72576 L F
.771 .669 .751 r
.64931 .5059 m .65068 .50939 L .64714 .5086 L F
.702 .228 .123 r
.65068 .50939 m .64948 .51043 L .64714 .5086 L F
.529 .487 .753 r
.7384 .59734 m .73714 .60101 L .7361 .59778 L F
.7384 .59734 m .73943 .6007 L .73714 .60101 L F
.622 .799 .368 r
.68947 .52864 m .68866 .53 L .69064 .5266 L F
.388 0 .142 r
.43329 .69627 m .43522 .69695 L .43246 .69739 L F
.695 .554 .691 r
.77704 .59807 m .77479 .60099 L .77541 .59839 L F
.591 .11 .083 r
.62357 .52447 m .62451 .52325 L .62101 .5231 L F
.153 0 0 r
.62568 .52381 m .62451 .52325 L .62357 .52447 L F
.62568 .52381 m .62684 .52282 L .62451 .52325 L F
.475 .347 .626 r
.33675 .71748 m .33898 .72025 L .33878 .7174 L F
.33675 .71748 m .33898 .72025 L .33878 .7174 L F
0 .446 .763 r
.70948 .50161 m .71092 .50188 L .70875 .5023 L F
.70948 .50161 m .71318 .5027 L .71092 .50188 L F
.87 .589 .51 r
.59878 .7101 m .60159 .71465 L .60108 .71231 L F
.606 .928 .966 r
.76349 .58053 m .76206 .58194 L .76126 .58157 L F
.76349 .58053 m .76432 .58096 L .76206 .58194 L F
.505 .474 .756 r
.36591 .70418 m .36673 .70065 L .3648 .70098 L F
.36591 .70418 m .36722 .70462 L .36673 .70065 L F
.613 .531 .738 r
.36605 .70661 m .36722 .70462 L .36591 .70418 L F
.182 0 0 r
.30437 .65064 m .30151 .65138 L .30204 .65102 L F
.38 .267 .598 r
.51319 .72024 m .51537 .71708 L .51316 .71655 L F
.51319 .72024 m .51537 .71996 L .51537 .71708 L F
.137 0 0 r
.77296 .61829 m .77192 .61917 L .76953 .61964 L F
0 0 0 r
.77405 .61826 m .77296 .61829 L .77503 .61712 L F
.77405 .61826 m .77192 .61917 L .77296 .61829 L F
.772 .723 .807 r
.59926 .55293 m .5997 .55625 L .59809 .55522 L F
.59926 .55293 m .60217 .55345 L .5997 .55625 L F
.3 0 .179 r
.31521 .64568 m .31418 .64738 L .3124 .64765 L F
.14 0 .048 r
.31707 .64489 m .31418 .64738 L .31521 .64568 L F
.818 .682 .715 r
.54991 .76971 m .55205 .7694 L .55273 .76795 L F
.136 .204 .67 r
.55273 .76795 m .55205 .7694 L .5534 .76872 L F
0 0 0 r
.55205 .7694 m .55084 .77216 L .5534 .76872 L F
.317 .622 .958 r
.67385 .48451 m .67081 .48295 L .6731 .48298 L F
.382 .613 .941 r
.67493 .48316 m .67385 .48451 L .6731 .48298 L F
.67493 .48316 m .67668 .48533 L .67385 .48451 L F
.603 .034 0 r
.63743 .49098 m .63651 .49093 L .63492 .48954 L F
.711 .849 .42 r
.63642 .48669 m .63492 .48954 L .63576 .48768 L F
.133 .205 .673 r
.63492 .48954 m .63651 .49093 L .63576 .48768 L F
.55 .809 .994 r
.6332 .49057 m .63585 .48999 L .63651 .49093 L F
0 0 .048 r
.63585 .48999 m .63591 .49089 L .63651 .49093 L F
.535 .507 .772 r
.63602 .49268 m .6332 .49057 L .63651 .49093 L F
0 0 .048 r
.63591 .49089 m .63602 .49268 L .63651 .49093 L F
.603 .034 0 r
.6385 .4916 m .63651 .49093 L .63743 .49098 L F
.513 .823 1 r
.64025 .49136 m .63651 .49093 L .6385 .4916 L F
.775 .564 .614 r
.50509 .76166 m .50793 .76418 L .50577 .76228 L F
.018 0 .201 r
.63447 .51946 m .63261 .52253 L .6332 .5206 L F
.629 .603 .805 r
.47476 .66242 m .47268 .66446 L .47262 .66322 L F
.627 .6 .804 r
.47501 .66401 m .47268 .66446 L .47476 .66242 L F
.638 .505 .684 r
.47588 .66736 m .47268 .66446 L .47501 .66401 L F
.47588 .66736 m .47352 .66774 L .47268 .66446 L F
.852 .64 .615 r
.4821 .78734 m .47821 .78828 L .47924 .78723 L F
.4821 .78734 m .48174 .79032 L .47821 .78828 L F
.027 0 .382 r
.48327 .78858 m .4821 .78734 L .48442 .78702 L F
.48327 .78858 m .48174 .79032 L .4821 .78734 L F
.467 .488 .797 r
.26346 .6273 m .26202 .62889 L .26096 .62584 L F
.367 .296 .645 r
.26346 .6273 m .26226 .63126 L .26202 .62889 L F
.254 .607 .954 r
.65617 .50214 m .65509 .50288 L .65346 .50048 L F
.65617 .50214 m .65712 .5033 L .65509 .50288 L F
.75 .765 .865 r
.3759 .72198 m .37852 .72518 L .37805 .72318 L F
.751 .885 .477 r
.5936 .70092 m .59189 .70405 L .5924 .70261 L F
.782 .996 .792 r
.59189 .70405 m .58988 .7051 L .5924 .70261 L F
.096 0 0 r
.26019 .58558 m .26224 .58546 L .26422 .58494 L F
.225 .744 .754 r
.26224 .58546 m .26595 .58468 L .26422 .58494 L F
.909 .698 .196 r
.47847 .79521 m .479 .79822 L .47758 .79793 L F
.815 .37 .183 r
.48107 .80057 m .47758 .79793 L .479 .79822 L F
.961 .634 .343 r
.58869 .6805 m .58911 .67763 L .58784 .67794 L F
.58869 .6805 m .59023 .68174 L .58911 .67763 L F
.646 .561 .744 r
.77929 .59547 m .77704 .59807 L .77602 .5947 L F
.77929 .59547 m .77972 .59747 L .77704 .59807 L F
.407 .123 .367 r
.63718 .51715 m .63447 .51946 L .63493 .51772 L F
.907 .501 .194 r
.5972 .70876 m .59878 .7101 L .59839 .70963 L F
.871 .711 .681 r
.5439 .78169 m .54478 .78174 L .54382 .78263 L F
.51 .67 .935 r
.54478 .78174 m .54371 .7838 L .54382 .78263 L F
.54478 .78174 m .54564 .7798 L .54371 .7838 L F
.54478 .78174 m .5471 .78205 L .54564 .7798 L F
.771 .723 .809 r
.58726 .72835 m .58489 .73114 L .5888 .73137 L F
.784 .578 .622 r
.58481 .73366 m .5888 .73137 L .58489 .73114 L F
.541 .665 .917 r
.5888 .73137 m .58962 .72865 L .58726 .72835 L F
.5888 .73137 m .59139 .73095 L .58962 .72865 L F
.94 .965 .714 r
.50337 .74228 m .50179 .74519 L .50265 .74534 L F
.873 .582 .493 r
.50081 .74734 m .50265 .74534 L .50179 .74519 L F
.962 .629 .278 r
.50265 .74534 m .50346 .74887 L .50277 .74802 L F
.27 0 0 r
.56344 .68663 m .56555 .68622 L .56714 .68426 L F
.407 .414 .754 r
.56714 .68426 m .56734 .68111 L .56603 .68133 L F
.56714 .68426 m .56881 .68422 L .56734 .68111 L F
.673 .342 .405 r
.56555 .68622 m .56881 .68422 L .56714 .68426 L F
.407 .414 .754 r
.56714 .68426 m .56881 .68422 L .56734 .68111 L F
.954 .618 .222 r
.49685 .77593 m .49548 .77288 L .49707 .77346 L F
.299 0 .088 r
.5711 .68358 m .56878 .68347 L .57204 .68164 L F
.5711 .68358 m .56881 .68422 L .56878 .68347 L F
.654 .753 .922 r
.71299 .49435 m .71408 .49542 L .71071 .49481 L F
.634 .718 .908 r
.71583 .49374 m .71408 .49542 L .71299 .49435 L F
.71583 .49374 m .71644 .49472 L .71408 .49542 L F
.983 .723 .455 r
.66067 .51163 m .66063 .51332 L .66136 .51323 L F
.938 .57 .263 r
.66193 .51679 m .66136 .51323 L .66063 .51332 L F
.66193 .51679 m .66296 .51701 L .66136 .51323 L F
.588 .546 .776 r
.7223 .4969 m .72502 .50136 L .72084 .50087 L F
.72502 .50136 m .725 .5014 L .72084 .50087 L F
.72505 .5014 m .72499 .50152 L .72084 .50087 L F
.508 .201 .381 r
.72499 .50152 m .72148 .50234 L .72084 .50087 L F
.911 .962 .805 r
.72513 .50141 m .72552 .50036 L .72596 .49974 L F
.72424 .50321 m .72498 .50156 L .72513 .50141 L F
.725 .50153 m .72552 .50036 L .72513 .50141 L F
.493 .505 .798 r
.72576 .49828 m .72509 .50122 L .7223 .4969 L F
.72509 .50122 m .72505 .5014 L .72502 .50136 L F
.72509 .50122 m .72502 .50136 L .7223 .4969 L F
.899 .901 .818 r
.72596 .49974 m .72528 .50069 L .72522 .50096 L F
.911 .962 .805 r
.72505 .5014 m .72552 .50036 L .725 .50153 L F
.493 .505 .798 r
.72642 .49854 m .72586 .49972 L .72602 .49838 L F
.293 .274 .666 r
.72522 .50096 m .72603 .49952 L .72542 .50063 L F
.493 .505 .798 r
.72586 .49972 m .72505 .5014 L .72513 .50113 L F
.72586 .49972 m .72513 .50113 L .72602 .49838 L F
.508 .201 .381 r
.72495 .50158 m .72474 .50179 L .72488 .5016 L F
.72495 .50158 m .72148 .50234 L .72499 .50152 L F
.72488 .5016 m .72443 .50207 L .72401 .50179 L F
.72474 .50179 m .72382 .50272 L .72488 .5016 L F
.588 .546 .776 r
.72502 .50136 m .72505 .5014 L .725 .5014 L F
.911 .962 .805 r
.72424 .50321 m .72382 .50272 L .72552 .50036 L F
.899 .901 .818 r
.72451 .50214 m .72382 .50272 L .72446 .50223 L F
.72522 .50096 m .72382 .50272 L .72451 .50214 L F
.72528 .50069 m .72382 .50272 L .72522 .50096 L F
.493 .505 .798 r
.72602 .49838 m .72528 .50069 L .72576 .49828 L F
.72528 .50069 m .72505 .5014 L .72576 .49828 L F
.099 0 .351 r
.72642 .49854 m .72382 .50272 L .72455 .50206 L F
.72642 .49854 m .72455 .50206 L .72624 .49898 L F
.864 .46 .266 r
.72408 .49604 m .72642 .49854 L .7223 .4969 L F
.099 0 .351 r
.72642 .49854 m .72639 .49865 L .72382 .50272 L F
.293 .274 .666 r
.72453 .50209 m .72542 .50035 L .7262 .49904 L F
.72542 .50035 m .72626 .49888 L .7262 .49904 L F
.72561 .50012 m .7262 .49904 L .7262 .49905 L F
.72453 .50209 m .7262 .49904 L .72561 .50012 L F
.72446 .50223 m .72542 .50058 L .72522 .50096 L F
.72542 .50058 m .72603 .49952 L .72522 .50096 L F
.72542 .50058 m .7262 .49905 L .72603 .49952 L F
.72446 .50223 m .7262 .49905 L .72542 .50058 L F
.72542 .50063 m .7259 .49976 L .72579 .50001 L F
.7259 .49976 m .72603 .49952 L .72579 .50001 L F
.72579 .50001 m .72603 .49952 L .72596 .49974 L F
.493 .505 .798 r
.72642 .49854 m .72513 .50154 L .72505 .5014 L F
.911 .962 .805 r
.72498 .50156 m .72505 .5014 L .725 .50153 L F
.508 .201 .381 r
.72513 .50154 m .72382 .50272 L .72495 .50158 L F
.72513 .50154 m .72495 .50158 L .72499 .50152 L F
.588 .546 .776 r
.72505 .5014 m .72513 .50154 L .72499 .50152 L F
.099 0 .351 r
.72624 .49898 m .72455 .50206 L .72513 .50154 L F
.911 .962 .805 r
.72452 .50354 m .72424 .50321 L .72534 .50099 L F
.72452 .50354 m .72534 .50099 L .72569 .50044 L F
.65 .908 .981 r
.72865 .49898 m .72792 .49919 L .72649 .49821 L F
.72792 .49919 m .72596 .49974 L .72629 .4988 L F
.72792 .49919 m .72629 .4988 L .72649 .49821 L F
.936 .787 .67 r
.72422 .49829 m .72423 .4983 L .72642 .49854 L F
.293 .274 .666 r
.72601 .5004 m .72745 .50047 L .72695 .4993 L F
.72451 .50212 m .72603 .50127 L .72601 .5004 L F
.72603 .50127 m .72745 .50047 L .72601 .5004 L F
.099 0 .351 r
.72639 .49865 m .726 .49997 L .72539 .50039 L F
.936 .787 .67 r
.72629 .4988 m .726 .49997 L .72634 .49881 L F
.72596 .49872 m .72598 .49923 L .72629 .4988 L F
.293 .274 .666 r
.72598 .49923 m .72629 .4988 L .72626 .49888 L F
.936 .787 .67 r
.72598 .49923 m .726 .49997 L .72629 .4988 L F
.099 0 .351 r
.72639 .49865 m .72415 .50254 L .72382 .50272 L F
.293 .274 .666 r
.72542 .50035 m .72598 .49923 L .72626 .49888 L F
.936 .787 .67 r
.72423 .4983 m .72629 .4988 L .72642 .49854 L F
.72629 .4988 m .72634 .49881 L .72639 .49865 L F
.72629 .4988 m .72639 .49865 L .72642 .49854 L F
.293 .274 .666 r
.72451 .50212 m .72598 .49923 L .72453 .50209 L F
.72598 .49923 m .72649 .49821 L .72598 .49923 L F
.72598 .49923 m .72598 .49923 L .72453 .50209 L F
.72598 .49923 m .72649 .49821 L .72629 .4988 L F
.72539 .50039 m .72695 .4993 L .72649 .49821 L F
.911 .962 .805 r
.72569 .50044 m .72534 .50099 L .72596 .49974 L F
.293 .274 .666 r
.72451 .50212 m .72695 .4993 L .72539 .50039 L F
.72446 .50223 m .72451 .50212 L .72453 .50209 L F
.72446 .50223 m .72457 .50216 L .72451 .50212 L F
.72457 .50216 m .72745 .50047 L .72451 .50212 L F
.242 .754 .749 r
.72542 .50187 m .72446 .50218 L .72446 .50223 L F
.099 0 .351 r
.72433 .50223 m .72542 .50187 L .72415 .50254 L F
.72539 .50039 m .72542 .50162 L .72433 .50223 L F
.391 .826 .679 r
.72446 .50218 m .72583 .50137 L .72745 .50047 L F
.099 0 .351 r
.726 .49997 m .72542 .50187 L .72539 .50039 L F
.936 .787 .67 r
.72423 .4983 m .72535 .50164 L .726 .49997 L F
.72535 .50164 m .72552 .50156 L .726 .49997 L F
.72423 .4983 m .726 .49997 L .72596 .49872 L F
.608 .627 .844 r
.72688 .50009 m .72535 .50164 L .72422 .49829 L F
.72745 .50047 m .72583 .50137 L .72688 .50009 L F
.72583 .50137 m .72535 .50164 L .72688 .50009 L F
.391 .826 .679 r
.72583 .50137 m .72633 .50108 L .72745 .50047 L F
.72446 .50223 m .72577 .50144 L .72603 .50131 L F
.936 .787 .67 r
.72535 .50164 m .72542 .50187 L .72552 .50156 L F
.391 .826 .679 r
.72603 .50131 m .72577 .50144 L .72745 .50047 L F
.608 .627 .844 r
.72745 .50047 m .72542 .50187 L .72535 .50164 L F
.391 .826 .679 r
.72446 .50223 m .72446 .50218 L .72577 .50144 L F
.099 0 .351 r
.72542 .50162 m .72446 .50218 L .72433 .50223 L F
.391 .826 .679 r
.72446 .50218 m .72448 .50208 L .72633 .50108 L F
.099 0 .351 r
.72542 .50162 m .72542 .50187 L .72446 .50218 L F
.242 .754 .749 r
.72542 .50187 m .72448 .50208 L .72446 .50218 L F
.508 .201 .381 r
.72401 .50179 m .72382 .50272 L .72148 .50234 L F
.72443 .50207 m .72382 .50272 L .72401 .50179 L F
.425 .223 .5 r
.72687 .50301 m .72474 .5058 L .72452 .50354 L F
.693 .165 0 r
.56125 .71128 m .5627 .71212 L .56431 .71231 L F
.839 .416 .231 r
.5627 .71212 m .56305 .7134 L .56431 .71231 L F
.456 0 0 r
.56543 .71324 m .56431 .71231 L .56305 .7134 L F
.56543 .71324 m .5667 .71408 L .56431 .71231 L F
.239 0 0 r
.6102 .75028 m .60932 .75037 L .60736 .75001 L F
.788 .76 .827 r
.6102 .75028 m .60949 .74795 L .60932 .75037 L F
.6102 .75028 m .61265 .74828 L .60949 .74795 L F
.462 .735 .987 r
.29768 .58883 m .29714 .59026 L .29586 .58863 L F
.29768 .58883 m .29926 .59007 L .29714 .59026 L F
.695 .812 .938 r
.62203 .51192 m .61843 .51163 L .62019 .5103 L F
.489 .291 .538 r
.62426 .50907 m .62203 .51192 L .62427 .51117 L F
.486 0 0 r
.62019 .5103 m .62427 .51117 L .62203 .51192 L F
.499 .36 .623 r
.45713 .7649 m .45915 .76449 L .45895 .76205 L F
.501 .382 .65 r
.45713 .7649 m .45946 .76722 L .45915 .76449 L F
.45713 .7649 m .4572 .76805 L .45946 .76722 L F
.861 .75 .739 r
.62081 .49471 m .62174 .49783 L .61952 .49595 L F
.92 .598 .415 r
.62245 .4995 m .61952 .49595 L .62174 .49783 L F
.142 .644 .907 r
.305 .59057 m .30845 .59135 L .30657 .59143 L F
.586 .561 .793 r
.47698 .67314 m .47481 .67372 L .47363 .6702 L F
.751 .885 .477 r
.5936 .70092 m .5924 .70261 L .59258 .70031 L F
.989 .792 .547 r
.5936 .70092 m .59258 .70031 L .59284 .69786 L F
.922 .918 .794 r
.57261 .7641 m .57528 .76225 L .57393 .76143 L F
.57261 .7641 m .57343 .76511 L .57528 .76225 L F
.59 .649 .877 r
.67894 .48482 m .67747 .48719 L .67668 .48533 L F
.67894 .48482 m .6798 .48668 L .67747 .48719 L F
.082 0 0 r
.42282 .70343 m .41901 .70501 L .42059 .70355 L F
.741 .621 .726 r
.62356 .53124 m .62694 .53166 L .62562 .5287 L F
.754 .607 .694 r
.62346 .53373 m .62694 .53166 L .62356 .53124 L F
.62346 .53373 m .62673 .53411 L .62694 .53166 L F
.524 .404 .659 r
.62694 .53166 m .62848 .53245 L .62962 .53159 L F
.62694 .53166 m .62673 .53411 L .62848 .53245 L F
.432 .312 .616 r
.35878 .67318 m .36075 .67512 L .36052 .6727 L F
.46 .314 .595 r
.35884 .67561 m .36075 .67512 L .35878 .67318 L F
.7 .208 .073 r
.56718 .71626 m .56776 .715 L .5667 .71408 L F
.56718 .71626 m .57007 .71693 L .56776 .715 L F
.625 .311 .419 r
.56776 .715 m .57007 .71693 L .57058 .71486 L F
.993 .748 .443 r
.51745 .77618 m .51733 .77854 L .51632 .77765 L F
.797 .699 .757 r
.51477 .77493 m .51624 .77752 L .51913 .77432 L F
.51624 .77752 m .51632 .77765 L .51647 .77746 L F
.356 .177 .496 r
.51965 .77666 m .51745 .77618 L .51936 .77619 L F
.51923 .77677 m .51745 .77618 L .51965 .77666 L F
.51985 .77697 m .51733 .77854 L .51745 .77618 L F
.797 .699 .757 r
.51624 .77752 m .51647 .77746 L .51913 .77432 L F
.356 .177 .496 r
.51985 .77697 m .51923 .77677 L .51965 .77666 L F
.422 .443 .777 r
.5894 .74869 m .59128 .74709 L .58874 .74749 L F
.5894 .74869 m .59396 .75141 L .59128 .74709 L F
.318 .757 .966 r
.32758 .59269 m .3268 .59348 L .32542 .59296 L F
.32758 .59269 m .32889 .59332 L .3268 .59348 L F
.613 .531 .738 r
.36605 .70661 m .36856 .70646 L .36722 .70462 L F
.523 .264 .463 r
.36605 .70661 m .36794 .70885 L .36856 .70646 L F
.36605 .70661 m .36591 .70938 L .36794 .70885 L F
.754 .638 .732 r
.5351 .73785 m .53294 .73991 L .53477 .73898 L F
.652 .716 .895 r
.734 .61442 m .73737 .61534 L .73642 .61367 L F
.612 .696 .904 r
.73642 .61367 m .73737 .61534 L .7397 .61469 L F
.775 .972 .687 r
.664 .54072 m .66541 .53967 L .66479 .53872 L F
.664 .54072 m .66339 .5421 L .66541 .53967 L F
.8 .337 .137 r
.54963 .71405 m .54617 .71149 L .54936 .71263 L F
.741 .329 .27 r
.52029 .80552 m .51978 .80397 L .51833 .8034 L F
.7 .353 .385 r
.52341 .8058 m .51978 .80397 L .52029 .80552 L F
.314 .276 .655 r
.7246 .51015 m .72325 .51384 L .72344 .51189 L F
.749 .317 0 r
.51744 .80234 m .51833 .8034 L .51663 .80076 L F
.62 .102 0 r
.5191 .80455 m .51833 .8034 L .51744 .80234 L F
0 0 0 r
.51915 .80495 m .5191 .80455 L .51727 .80698 L F
.149 .554 .927 r
.52095 .80501 m .5191 .80455 L .52002 .80401 L F
0 0 0 r
.52002 .80401 m .5191 .80455 L .51915 .80495 L F
.62 .102 0 r
.5191 .80455 m .52029 .80552 L .51906 .80419 L F
.5191 .80455 m .51906 .80419 L .51833 .8034 L F
.751 .527 .592 r
.50998 .80952 m .50997 .81228 L .50799 .81195 L F
.622 .416 .581 r
.51327 .80931 m .50997 .81228 L .50998 .80952 L F
.747 .472 .514 r
.43699 .66044 m .43664 .66324 L .43368 .66028 L F
.29 .078 .408 r
.44008 .65961 m .43699 .66044 L .43973 .66136 L F
.483 .756 .99 r
.43973 .66136 m .44215 .66122 L .44031 .65989 L F
.29 .078 .408 r
.44008 .65961 m .43958 .66014 L .43699 .66044 L F
.43958 .66014 m .43664 .66324 L .43691 .66109 L F
.43958 .66014 m .43691 .66109 L .43699 .66044 L F
.751 .762 .862 r
.43442 .66019 m .43664 .66324 L .43924 .6605 L F
.43686 .65994 m .43924 .6605 L .44008 .65961 L F
.43442 .66019 m .43924 .6605 L .43686 .65994 L F
.43442 .66019 m .44008 .65961 L .43661 .65975 L F
.616 .806 .973 r
.43976 .65948 m .44209 .66118 L .44399 .66055 L F
.44209 .66118 m .44215 .66122 L .44219 .6612 L F
.44209 .66118 m .44219 .6612 L .44399 .66055 L F
.416 0 0 r
.43976 .65948 m .43661 .65975 L .44008 .65961 L F
.483 .756 .99 r
.43973 .66136 m .43976 .65948 L .44008 .65961 L F
.43975 .66008 m .44031 .65989 L .43976 .65948 L F
.43973 .66136 m .44031 .65989 L .43975 .66008 L F
.852 .73 .728 r
.59822 .54773 m .5997 .54474 L .60072 .54799 L F
.854 .715 .707 r
.59822 .54773 m .60072 .54799 L .59977 .55061 L F
.638 .554 .744 r
.75899 .60922 m .76204 .60907 L .76097 .60637 L F
.725 .485 .562 r
.75899 .60922 m .76248 .61151 L .76204 .60907 L F
.75899 .60922 m .75921 .61182 L .76248 .61151 L F
.434 .267 .554 r
.55372 .69231 m .55217 .69367 L .55542 .69227 L F
.901 .51 .269 r
.60406 .72843 m .6048 .7307 L .60554 .72892 L F
.925 .55 .281 r
.6048 .7307 m .60609 .73125 L .60554 .72892 L F
.568 .354 .55 r
.32431 .75406 m .32352 .75851 L .3266 .75365 L F
.474 .705 .97 r
.32394 .60593 m .322 .60323 L .32155 .60341 L F
.32394 .60593 m .32583 .60562 L .322 .60323 L F
.626 .719 .914 r
.44274 .66407 m .44423 .6658 L .44632 .66488 L F
.853 .863 .848 r
.6717 .49344 m .67229 .49351 L .67204 .49386 L F
0 0 0 r
.67396 .49212 m .67229 .49351 L .67584 .49402 L F
.67396 .49212 m .67204 .49386 L .67229 .49351 L F
.982 .788 .567 r
.54076 .73719 m .53953 .73643 L .53987 .73401 L F
.718 .445 .513 r
.54253 .73973 m .53948 .73984 L .54076 .73719 L F
.824 .445 .337 r
.5442 .73992 m .54076 .73719 L .54307 .737 L F
.5442 .73992 m .54253 .73973 L .54076 .73719 L F
.606 .853 .991 r
.31772 .605 m .31837 .60359 L .31585 .60434 L F
.31772 .605 m .32 .60413 L .31837 .60359 L F
.954 .615 .231 r
.54593 .70961 m .54518 .71054 L .5434 .70828 L F
.54593 .70961 m .54617 .71149 L .54518 .71054 L F
.863 .577 .502 r
.52668 .7343 m .52789 .73763 L .5247 .73607 L F
.821 .559 .543 r
.52948 .73736 m .52789 .73763 L .52668 .7343 L F
.843 .568 .523 r
.6326 .53881 m .63362 .53649 L .63249 .53652 L F
.6326 .53881 m .63684 .54201 L .63362 .53649 L F
.117 .264 .739 r
.63362 .53649 m .63684 .54201 L .63663 .53824 L F
.874 .85 .816 r
.5442 .73992 m .54221 .74288 L .54072 .74195 L F
.591 .35 .52 r
.54117 .76756 m .54352 .76762 L .54378 .76478 L F
.889 .905 .832 r
.54352 .76762 m .54658 .76539 L .54378 .76478 L F
.333 0 0 r
.42007 .66216 m .41855 .66345 L .41655 .66348 L F
.037 0 0 r
.42224 .66223 m .41855 .66345 L .42007 .66216 L F
.921 .828 .737 r
.56791 .74174 m .57054 .74016 L .56924 .73927 L F
.56791 .74174 m .56931 .74296 L .57054 .74016 L F
.162 0 0 r
.3124 .64765 m .31078 .64912 L .30849 .64964 L F
.307 0 0 r
.31279 .64883 m .3124 .64765 L .31418 .64738 L F
.31279 .64883 m .31078 .64912 L .3124 .64765 L F
.195 0 0 r
.42565 .66177 m .42457 .66216 L .42224 .66223 L F
.319 0 0 r
.42788 .6613 m .42457 .66216 L .42565 .66177 L F
.534 .308 .518 r
.6317 .55624 m .63143 .55811 L .62936 .55846 L F
.332 0 0 r
.6317 .55624 m .63316 .55734 L .63143 .55811 L F
.6317 .55624 m .63407 .55592 L .63316 .55734 L F
.778 .965 .661 r
.53565 .73644 m .53578 .73698 L .53617 .73371 L F
.53565 .73644 m .5351 .73785 L .53578 .73698 L F
.568 .333 .519 r
.54075 .76879 m .54117 .76756 L .53884 .76786 L F
.494 .4 .678 r
.53884 .76786 m .53975 .77071 L .54075 .76879 L F
.568 .333 .519 r
.54075 .76879 m .54117 .76756 L .53884 .76786 L F
.746 .936 .949 r
.2593 .65583 m .25985 .65401 L .2578 .6543 L F
.2593 .65583 m .26191 .65427 L .25985 .65401 L F
.561 .814 .993 r
.53738 .73733 m .5351 .73785 L .53565 .73644 L F
.38 .492 .847 r
.68543 .52823 m .68405 .5298 L .68305 .52794 L F
.68543 .52823 m .68639 .53075 L .68405 .5298 L F
.736 .463 .515 r
.51936 .77619 m .52305 .7762 L .52306 .77831 L F
.239 .012 .354 r
.52462 .77581 m .52305 .7762 L .52527 .77323 L F
.335 .305 .677 r
.52462 .77581 m .52525 .77811 L .52305 .7762 L F
.533 .3 .507 r
.52305 .7762 m .52525 .77811 L .52306 .77831 L F
.52305 .7762 m .52525 .77811 L .52306 .77831 L F
.575 .325 .499 r
.524 .75637 m .52656 .75618 L .52647 .7532 L F
.453 .351 .649 r
.52647 .7532 m .5287 .75334 L .5284 .75056 L F
.552 .307 .498 r
.52647 .7532 m .52883 .75518 L .5287 .75334 L F
.52647 .7532 m .52656 .75618 L .52883 .75518 L F
.174 0 .083 r
.31364 .62595 m .3143 .62722 L .31528 .62511 L F
.31364 .62595 m .31269 .62784 L .3143 .62722 L F
.159 0 0 r
.65771 .54462 m .65469 .54522 L .65539 .54487 L F
.147 .684 .841 r
.33091 .59332 m .33496 .59344 L .33284 .59377 L F
.664 .557 .724 r
.71098 .60088 m .71369 .5976 L .71034 .5979 L F
.71098 .60088 m .71333 .60026 L .71369 .5976 L F
.769 .959 .65 r
.664 .54072 m .66038 .54515 L .66339 .5421 L F
.905 .874 .796 r
.65595 .49525 m .65463 .49449 L .65684 .49089 L F
.777 .312 .139 r
.65601 .49505 m .65463 .49449 L .65595 .49525 L F
.281 0 .052 r
.71629 .51979 m .71567 .52132 L .71335 .52195 L F
.305 0 .061 r
.71791 .52071 m .71629 .51979 L .71867 .5196 L F
.71791 .52071 m .71567 .52132 L .71629 .51979 L F
.864 .665 .632 r
.68093 .53935 m .67931 .53951 L .6794 .53669 L F
.227 0 0 r
.68271 .54109 m .67931 .53951 L .68093 .53935 L F
.502 .465 .749 r
.3648 .70098 m .36589 .69741 L .36376 .6978 L F
.3648 .70098 m .36673 .70065 L .36589 .69741 L F
.613 .569 .781 r
.35891 .68951 m .3619 .6899 L .36071 .68683 L F
.6 .542 .761 r
.35891 .68951 m .36243 .69222 L .3619 .6899 L F
.457 .251 .511 r
.3899 .67295 m .38785 .67552 L .3878 .67323 L F
.379 .019 .222 r
.42526 .68983 m .42734 .6894 L .42841 .68716 L F
.442 .08 .254 r
.42841 .68716 m .43016 .68811 L .43069 .68697 L F
.42841 .68716 m .42734 .6894 L .43016 .68811 L F
.659 .625 .805 r
.69257 .50172 m .69337 .49754 L .6915 .50019 L F
.69257 .50172 m .69491 .50076 L .69337 .49754 L F
.423 0 0 r
.57233 .72604 m .56909 .72524 L .57024 .72622 L F
.036 .602 .78 r
.33056 .8788 m .33413 .87906 L .33268 .87888 L F
.33056 .8788 m .33413 .87906 L .33268 .87888 L F
.201 .722 .866 r
.33515 .87871 m .33413 .87906 L .33268 .87888 L F
.33515 .87871 m .33413 .87906 L .33268 .87888 L F
.429 .606 .921 r
.50676 .73922 m .50773 .73762 L .50524 .73913 L F
.50676 .73922 m .50882 .73957 L .5083 .73865 L F
.50676 .73922 m .5083 .73865 L .50717 .73853 L F
.786 .906 .508 r
.50629 .74066 m .5049 .74265 L .50527 .74194 L F
.341 0 .109 r
.50629 .74066 m .50524 .73913 L .50782 .73874 L F
0 0 0 r
.50451 .74038 m .50629 .74066 L .50456 .7401 L F
.50451 .74038 m .50482 .74041 L .50629 .74066 L F
.341 0 .109 r
.50629 .74066 m .50455 .74036 L .50467 .74014 L F
0 0 0 r
.50482 .74041 m .5059 .74049 L .50629 .74066 L F
.341 0 .109 r
.50629 .74066 m .50412 .74113 L .50446 .74052 L F
.50629 .74066 m .50446 .74052 L .50482 .74041 L F
0 0 0 r
.50482 .74041 m .5042 .74099 L .5059 .74049 L F
.50451 .74038 m .50443 .74053 L .50482 .74041 L F
.50443 .74053 m .5042 .74099 L .50482 .74041 L F
.341 0 .109 r
.50482 .74041 m .50446 .74052 L .50455 .74036 L F
.50629 .74066 m .50467 .74014 L .50524 .73913 L F
.429 .606 .921 r
.50717 .73853 m .5083 .73865 L .50773 .73762 L F
.707 .745 .882 r
.50872 .73861 m .50838 .73866 L .50773 .73762 L F
.50838 .73866 m .50524 .73913 L .50773 .73762 L F
.488 .64 .923 r
.50842 .73873 m .50882 .73957 L .5089 .73949 L F
.50835 .73874 m .50882 .73957 L .50842 .73873 L F
.533 .137 .237 r
.51028 .73827 m .50864 .73867 L .50872 .73861 L F
.359 .177 .493 r
.51044 .73765 m .50872 .73861 L .50773 .73762 L F
.51044 .73765 m .51028 .73827 L .50872 .73861 L F
.488 .64 .923 r
.50773 .73762 m .50838 .73866 L .51028 .73827 L F
.50838 .73866 m .5089 .73949 L .50975 .73873 L F
.341 0 .109 r
.50864 .73867 m .50838 .73866 L .50872 .73861 L F
.488 .64 .923 r
.50838 .73866 m .50975 .73873 L .51028 .73827 L F
.341 0 .109 r
.50862 .73869 m .50836 .73866 L .50838 .73866 L F
.50862 .73869 m .50838 .73866 L .50864 .73867 L F
.533 .137 .237 r
.51028 .73827 m .50629 .74066 L .50864 .73867 L F
.488 .64 .923 r
.50773 .73762 m .50835 .73874 L .50842 .73873 L F
0 0 0 r
.50456 .7401 m .50629 .74066 L .50512 .73743 L F
.5059 .74049 m .50412 .74113 L .50629 .74066 L F
.138 .269 .737 r
.50512 .73743 m .50629 .74066 L .50692 .73886 L F
.786 .906 .508 r
.50629 .74066 m .50527 .74194 L .50692 .73886 L F
.341 0 .109 r
.50629 .74066 m .50782 .73874 L .50836 .73866 L F
.50629 .74066 m .50836 .73866 L .50862 .73869 L F
.771 .366 .285 r
.50808 .73107 m .51207 .73412 L .51083 .73185 L F
.761 .309 0 r
.51083 .73185 m .51329 .73393 L .51317 .73141 L F
.51083 .73185 m .51207 .73412 L .51162 .73362 L F
.51083 .73185 m .51162 .73362 L .51329 .73393 L F
.828 .699 .721 r
.62304 .50351 m .62245 .4995 L .62162 .50321 L F
.62304 .50351 m .62 .50324 L .62245 .4995 L F
.319 .089 .399 r
.36848 .65587 m .36668 .65664 L .36629 .65873 L F
.685 .161 0 r
.59752 .6926 m .60028 .69496 L .59968 .69291 L F
.92 .67 .178 r
.66346 .51909 m .66419 .52258 L .66399 .52023 L F
.75 .936 .947 r
.63162 .53014 m .62962 .53159 L .63037 .52954 L F
.555 .547 .8 r
.62848 .53245 m .63037 .52954 L .62962 .53159 L F
.815 .679 .713 r
.60949 .74795 m .61265 .74828 L .61143 .74511 L F
.754 .651 .747 r
.61265 .74828 m .61485 .74543 L .61143 .74511 L F
.7 .981 .891 r
.68413 .51562 m .68108 .51676 L .68261 .51607 L F
0 0 0 r
.68413 .51562 m .68519 .51534 L .68593 .51421 L F
.68413 .51562 m .68261 .51607 L .68519 .51534 L F
.428 .239 .52 r
.35979 .66479 m .36165 .6644 L .36183 .66193 L F
.512 .431 .702 r
.36019 .66722 m .36165 .6644 L .35979 .66479 L F
.975 .677 .3 r
.58228 .72029 m .58238 .72244 L .58326 .72295 L F
.786 .865 .424 r
.58233 .72277 m .58326 .72295 L .58238 .72244 L F
.516 .261 .467 r
.43849 .68381 m .44103 .68134 L .43875 .68162 L F
.426 .188 .448 r
.65335 .52055 m .65062 .52379 L .6515 .52359 L F
.275 .024 .339 r
.65335 .52055 m .65507 .52151 L .65506 .51932 L F
.884 .662 .597 r
.49855 .77872 m .49685 .77593 L .50037 .7766 L F
.49855 .77872 m .4968 .77869 L .49685 .77593 L F
0 .153 .662 r
.49855 .77872 m .4988 .77858 L .4968 .77869 L F
.49855 .77872 m .50046 .78039 L .4988 .77858 L F
.761 .409 .389 r
.52948 .73736 m .52835 .73921 L .52789 .73763 L F
.337 .02 .271 r
.62795 .55999 m .62608 .5595 L .62936 .55846 L F
.22 0 0 r
.63121 .55867 m .62936 .55846 L .63143 .55811 L F
.63121 .55867 m .62795 .55999 L .62936 .55846 L F
.531 .698 .946 r
.2676 .63597 m .26683 .63775 L .26567 .63616 L F
.2676 .63597 m .26901 .63744 L .26683 .63775 L F
.724 .564 .673 r
.67691 .50538 m .67912 .50669 L .68107 .50576 L F
.651 .582 .765 r
.68102 .50389 m .68107 .50576 L .68352 .50324 L F
.68352 .50324 m .68107 .50576 L .68102 .50389 L F
.732 .607 .718 r
.5466 .73695 m .5442 .73992 L .54307 .737 L F
.506 .56 .845 r
.54735 .73384 m .54865 .73694 L .5466 .73695 L F
.546 .206 .342 r
.64452 .50894 m .64143 .51109 L .64313 .50839 L F
.64452 .50894 m .64392 .51107 L .64143 .51109 L F
.495 .158 .324 r
.64641 .51063 m .64452 .50894 L .64714 .5086 L F
.64641 .51063 m .64392 .51107 L .64452 .50894 L F
.607 .354 .507 r
.53887 .77276 m .53975 .77071 L .5368 .77104 L F
.323 0 .204 r
.69819 .51697 m .70099 .51484 L .69909 .51496 L F
.69819 .51697 m .70033 .51636 L .70099 .51484 L F
0 0 0 r
.70033 .51636 m .70277 .51372 L .70099 .51484 L F
.643 .467 .63 r
.62456 .53669 m .62673 .53411 L .62346 .53373 L F
.62456 .53669 m .62707 .53665 L .62673 .53411 L F
.507 .378 .64 r
.62673 .53411 m .62923 .53592 L .62848 .53245 L F
.515 .376 .63 r
.62673 .53411 m .62707 .53665 L .62923 .53592 L F
.099 0 .003 r
.57284 .76662 m .57113 .76709 L .57343 .76511 L F
.57284 .76662 m .57343 .76511 L .57261 .7641 L F
.856 .883 .45 r
.57372 .75872 m .57478 .75692 L .5742 .75569 L F
.57372 .75872 m .57393 .759 L .57478 .75692 L F
.067 0 0 r
.36718 .71213 m .3657 .71215 L .36339 .71208 L F
.001 .198 .712 r
.36718 .71213 m .36847 .71186 L .3657 .71215 L F
.36718 .71213 m .36911 .71409 L .36847 .71186 L F
.514 .649 .918 r
.77678 .58421 m .77351 .58237 L .77642 .58292 L F
.049 .441 .874 r
.77881 .58442 m .77678 .58421 L .77642 .58292 L F
.77881 .58442 m .77963 .5856 L .77678 .58421 L F
.692 .541 .677 r
.54901 .78072 m .55002 .77997 L .54583 .77883 L F
.798 .983 .896 r
.55147 .77858 m .55002 .77997 L .54901 .78072 L F
.513 .573 .853 r
.55041 .78093 m .55147 .77858 L .54901 .78072 L F
.55041 .78093 m .55272 .78131 L .55147 .77858 L F
.256 0 0 r
.40077 .71127 m .39762 .71284 L .39893 .71195 L F
.754 .652 .749 r
.61143 .74511 m .61485 .74543 L .61371 .74213 L F
.663 .768 .928 r
.77037 .60885 m .77383 .60919 L .77291 .60795 L F
.77037 .60885 m .77383 .60919 L .77291 .60795 L F
.621 .889 .988 r
.77383 .60919 m .77531 .60767 L .77291 .60795 L F
.77383 .60919 m .77617 .60839 L .77531 .60767 L F
.407 .519 .86 r
.77531 .60767 m .77383 .60919 L .77291 .60795 L F
.77531 .60767 m .77607 .61116 L .77383 .60919 L F
.892 .754 .252 r
.59975 .69735 m .59966 .70096 L .59977 .7011 L F
0 0 0 r
.59966 .70096 m .59905 .70326 L .59977 .7011 L F
.664 .671 .847 r
.68811 .49746 m .6915 .50019 L .69107 .49813 L F
.632 .62 .82 r
.69107 .49813 m .6915 .50019 L .69337 .49754 L F
.572 .905 .978 r
.48723 .78101 m .48443 .78135 L .4857 .77978 L F
0 0 0 r
.48888 .77883 m .48723 .78101 L .4857 .77978 L F
.48888 .77883 m .48753 .78097 L .48723 .78101 L F
.972 .788 .596 r
.48533 .78341 m .48661 .78409 L .48723 .78101 L F
.48533 .78341 m .48723 .78101 L .48753 .78097 L F
.667 .593 .763 r
.70174 .50611 m .70534 .50868 L .7041 .50586 L F
.57 .558 .801 r
.70534 .50868 m .70655 .50493 L .7041 .50586 L F
.70534 .50868 m .70758 .50825 L .70655 .50493 L F
.442 .453 .776 r
.70667 .509 m .70758 .50825 L .70534 .50868 L F
.724 .493 .576 r
.51805 .80794 m .51554 .81159 L .51543 .80918 L F
.51805 .80794 m .51842 .81043 L .51554 .81159 L F
.639 .387 .521 r
.51805 .80794 m .52114 .81105 L .51842 .81043 L F
.51805 .80794 m .52119 .80893 L .52114 .81105 L F
.34 .736 .983 r
.31055 .59122 m .31405 .59196 L .31201 .59202 L F
.363 .034 .266 r
.39281 .67034 m .39204 .67252 L .3899 .67295 L F
.521 .181 .332 r
.39433 .67209 m .39281 .67034 L .39494 .6698 L F
.39433 .67209 m .39204 .67252 L .39281 .67034 L F
.528 .159 .284 r
.47592 .75056 m .47832 .75055 L .47941 .74834 L F
.44 .07 .239 r
.47941 .74834 m .48136 .74913 L .48156 .74788 L F
.47941 .74834 m .47832 .75055 L .48136 .74913 L F
.872 .694 .659 r
.62285 .48956 m .61987 .49145 L .62158 .48839 L F
.713 .74 .873 r
.62417 .48603 m .62285 .48956 L .62158 .48839 L F
.62417 .48603 m .62569 .48851 L .62285 .48956 L F
.674 .567 .726 r
.62569 .48851 m .62627 .49075 L .62285 .48956 L F
.64 .585 .777 r
.62646 .49222 m .62285 .48956 L .62627 .49075 L F
.462 .833 .585 r
.54581 .77284 m .5483 .77091 L .54693 .77192 L F
.941 .904 .758 r
.62214 .51839 m .62331 .51975 L .62377 .51817 L F
.909 .888 .799 r
.6199 .52157 m .62331 .51975 L .62214 .51839 L F
.6199 .52157 m .62101 .5231 L .62331 .51975 L F
.575 .596 .836 r
.74408 .60666 m .7405 .60405 L .74279 .60378 L F
.601 .619 .842 r
.74644 .60613 m .74408 .60666 L .74279 .60378 L F
.645 .667 .857 r
.44632 .66488 m .44985 .66729 L .44841 .66395 L F
.687 .643 .801 r
.44841 .66395 m .44985 .66729 L .45184 .66457 L F
.661 .607 .784 r
.44985 .66729 m .45307 .66785 L .45184 .66457 L F
.397 .664 .967 r
.75149 .61623 m .75228 .61746 L .75364 .61629 L F
.34 .562 .919 r
.75228 .61746 m .75519 .61832 L .75364 .61629 L F
.141 0 0 r
.40085 .69868 m .40287 .69888 L .40477 .69869 L F
.025 0 0 r
.40287 .69888 m .40699 .69831 L .40477 .69869 L F
.253 .624 .959 r
.39962 .69741 m .3989 .69828 L .39755 .69731 L F
.39962 .69741 m .40085 .69868 L .3989 .69828 L F
.74 .749 .859 r
.57419 .67912 m .57077 .67847 L .57286 .67764 L F
.876 .856 .818 r
.57643 .67552 m .57419 .67912 L .57286 .67764 L F
.565 .172 .257 r
.57419 .67912 m .57649 .68048 L .57476 .68035 L F
.555 .189 .301 r
.57787 .67895 m .57649 .68048 L .57419 .67912 L F
.316 0 0 r
.40489 .6494 m .40706 .64968 L .40849 .6493 L F
.40849 .6493 m .40706 .64968 L .41062 .64969 L F
.414 0 0 r
.54803 .76649 m .54953 .76576 L .54658 .76539 L F
.23 .739 .885 r
.26999 .58433 m .26976 .58479 L .2678 .5847 L F
.26999 .58433 m .2717 .58462 L .26976 .58479 L F
.332 .146 .472 r
.45513 .78145 m .45667 .78172 L .45682 .77871 L F
.292 .297 .693 r
.45513 .78145 m .45711 .78368 L .45667 .78172 L F
.567 .349 .544 r
.45513 .78145 m .45469 .78423 L .45711 .78368 L F
.45513 .78145 m .45469 .78423 L .45711 .78368 L F
.914 .698 .596 r
.35272 .71175 m .35242 .71422 L .35425 .71474 L F
.674 .968 .925 r
.37704 .72009 m .3781 .72038 L .38094 .71869 L F
.892 .635 .544 r
.3759 .72198 m .3781 .72038 L .37704 .72009 L F
.3759 .72198 m .37805 .72318 L .3781 .72038 L F
.764 .823 .899 r
.68363 .51897 m .68729 .51868 L .68629 .5178 L F
.733 .938 .953 r
.68629 .5178 m .68729 .51868 L .68959 .51723 L F
.705 .741 .879 r
.76105 .5904 m .76331 .58946 L .75998 .58892 L F
.519 .497 .772 r
.76105 .5904 m .76465 .59424 L .76331 .58946 L F
0 0 0 r
.74862 .59347 m .74975 .59266 L .75185 .59179 L F
.63236 .5014 m .63142 .50136 L .63338 .50033 L F
.63236 .5014 m .63014 .50213 L .63142 .50136 L F
.71 .479 .574 r
.6044 .56756 m .60237 .56977 L .60265 .56739 L F
.6044 .56756 m .60542 .5687 L .60237 .56977 L F
.679 .437 .549 r
.6044 .56756 m .60783 .56936 L .60542 .5687 L F
.6044 .56756 m .60797 .56738 L .60783 .56936 L F
.874 .85 .816 r
.5442 .73992 m .54072 .74195 L .54253 .73973 L F
.363 .087 .354 r
.56603 .68133 m .56734 .68111 L .56854 .67887 L F
.225 0 .137 r
.56734 .68111 m .57077 .67847 L .56854 .67887 L F
0 0 .314 r
.62771 .4883 m .62646 .49222 L .62627 .49075 L F
.62771 .4883 m .62756 .49076 L .62646 .49222 L F
.261 .4 .814 r
.62756 .49076 m .62909 .49487 L .62646 .49222 L F
.525 .275 .478 r
.70389 .51237 m .70549 .51326 L .70667 .509 L F
.767 .518 .557 r
.70667 .509 m .70549 .51326 L .70792 .51325 L F
.594 .11 .076 r
.70549 .51326 m .70746 .51434 L .70792 .51325 L F
0 .212 .633 r
.70437 .51243 m .70744 .51433 L .70549 .51326 L F
.70744 .51433 m .70746 .51434 L .70549 .51326 L F
.525 .275 .478 r
.70277 .51372 m .70549 .51326 L .70389 .51237 L F
.442 .453 .776 r
.70667 .509 m .70859 .51145 L .70758 .50825 L F
.767 .518 .557 r
.70667 .509 m .70792 .51325 L .70859 .51145 L F
.429 .023 .165 r
.38426 .65254 m .38784 .6503 L .38561 .65037 L F
.992 .782 .404 r
.49359 .78968 m .49436 .79299 L .49354 .79326 L F
.787 .716 .785 r
.4937 .79341 m .4921 .79587 L .49003 .79202 L F
.953 .606 .236 r
.49354 .79326 m .49375 .79355 L .4937 .79341 L F
.49375 .79355 m .49478 .79498 L .4937 .79341 L F
.49385 .79345 m .49436 .79299 L .49478 .79498 L F
.413 .552 .885 r
.49384 .79343 m .49478 .79498 L .4958 .79377 L F
.4937 .79341 m .49478 .79498 L .49384 .79343 L F
.953 .606 .236 r
.49375 .79355 m .49385 .79345 L .49478 .79498 L F
0 0 .017 r
.49377 .79343 m .49375 .79355 L .4937 .79341 L F
.953 .606 .236 r
.49354 .79326 m .49382 .79316 L .49375 .79355 L F
.49377 .79343 m .49382 .79339 L .49375 .79355 L F
.49382 .79339 m .49436 .79299 L .49385 .79345 L F
.49382 .79339 m .49385 .79345 L .49375 .79355 L F
.49386 .79315 m .49436 .79299 L .49377 .79343 L F
.413 .552 .885 r
.4938 .79333 m .4958 .79377 L .4959 .79175 L F
.4937 .79341 m .49384 .79343 L .4938 .79333 L F
.49384 .79343 m .4958 .79377 L .4938 .79333 L F
0 0 0 r
.4959 .79175 m .49475 .79375 L .49377 .79343 L F
.4938 .79333 m .49377 .79343 L .4937 .79341 L F
.782 .74 .815 r
.497 .7901 m .49436 .79299 L .49359 .78968 L F
0 0 0 r
.4959 .79175 m .49377 .79343 L .4938 .79333 L F
.953 .606 .236 r
.49382 .79316 m .49386 .79315 L .49377 .79343 L F
0 0 .017 r
.49475 .79375 m .49411 .79461 L .49375 .79355 L F
.49475 .79375 m .49375 .79355 L .49377 .79343 L F
.687 .562 .709 r
.49232 .79558 m .49239 .79804 L .49478 .79498 L F
0 0 .017 r
.49411 .79461 m .49258 .79669 L .4937 .79341 L F
.656 .366 .468 r
.509 .75598 m .51226 .75634 L .51245 .75378 L F
.548 .275 .453 r
.51245 .75378 m .51464 .75582 L .51474 .7536 L F
.51245 .75378 m .51226 .75634 L .51464 .75582 L F
.688 .582 .731 r
.71333 .60026 m .71448 .60371 L .71697 .60287 L F
.522 .264 .465 r
.78213 .59267 m .77929 .59547 L .77821 .59206 L F
.78213 .59267 m .7811 .59484 L .77929 .59547 L F
0 0 .062 r
.78308 .59112 m .7811 .59484 L .78213 .59267 L F
.734 .221 0 r
.54947 .76323 m .54934 .76467 L .54611 .76158 L F
.578 .61 .848 r
.54947 .76323 m .55266 .76482 L .55172 .76255 L F
.094 0 0 r
.55028 .76378 m .54947 .76323 L .55172 .76255 L F
.55028 .76378 m .54934 .76467 L .54947 .76323 L F
.852 .814 .811 r
.68187 .52271 m .68496 .52229 L .68354 .52019 L F
.453 .277 .551 r
.38561 .67858 m .38566 .68121 L .38356 .68178 L F
.495 .399 .675 r
.38566 .68121 m .38593 .68361 L .38356 .68178 L F
.756 .518 .572 r
.54044 .73181 m .53987 .73401 L .53617 .73371 L F
.556 .426 .659 r
.34543 .70935 m .34446 .71384 L .3428 .71367 L F
.34543 .70935 m .34669 .71417 L .34446 .71384 L F
.537 .275 .465 r
.34543 .70935 m .3428 .71367 L .34607 .71264 L F
0 0 .457 r
.34543 .70935 m .34715 .7132 L .34669 .71417 L F
.369 .168 .471 r
.34607 .71264 m .34715 .7132 L .34543 .70935 L F
.725 .555 .66 r
.67151 .50075 m .6721 .50365 L .66873 .50334 L F
0 .049 .564 r
.67288 .50194 m .67151 .50075 L .67158 .49977 L F
.67288 .50194 m .6721 .50365 L .67151 .50075 L F
.694 .677 .83 r
.69921 .50584 m .70174 .50611 L .70128 .50486 L F
0 .41 .735 r
.7041 .50586 m .70128 .50486 L .70174 .50611 L F
.831 .398 0 r
.57223 .74978 m .57428 .7531 L .57282 .75175 L F
.99 .868 .617 r
.65741 .50754 m .65827 .5085 L .65896 .50641 L F
.63 .392 .538 r
.53294 .73991 m .53505 .74214 L .53291 .74114 L F
.349 .074 .347 r
.36379 .66133 m .3643 .65932 L .36183 .66193 L F
.396 .115 .365 r
.36629 .65873 m .3643 .65932 L .36379 .66133 L F
.926 .691 .564 r
.67092 .52569 m .66896 .52705 L .66914 .52471 L F
.67092 .52569 m .67078 .52799 L .66896 .52705 L F
.541 .499 .758 r
.35704 .60262 m .35507 .60392 L .35416 .60076 L F
.549 .441 .683 r
.35704 .60262 m .35511 .60601 L .35507 .60392 L F
.13 .369 .827 r
.65193 .49564 m .65002 .49565 L .6497 .49401 L F
.65193 .49564 m .65223 .49711 L .65002 .49565 L F
.535 .825 .487 r
.32738 .60887 m .32472 .6118 L .32586 .61052 L F
.322 .445 .83 r
.32583 .60562 m .32738 .60887 L .32798 .60752 L F
.164 0 .194 r
.32586 .61052 m .32798 .60752 L .32738 .60887 L F
.541 .765 .98 r
.31092 .60302 m .31432 .60383 L .313 .60254 L F
.129 .491 .903 r
.31432 .60383 m .31479 .6029 L .313 .60254 L F
.31432 .60383 m .31585 .60434 L .31479 .6029 L F
.754 .283 .127 r
.49199 .80287 m .49332 .80394 L .49024 .803 L F
.676 .509 .652 r
.71333 .60026 m .71578 .59783 L .71369 .5976 L F
.71333 .60026 m .71668 .60131 L .71578 .59783 L F
.591 .457 .666 r
.71578 .59783 m .71898 .60053 L .71953 .59688 L F
.71578 .59783 m .71668 .60131 L .71898 .60053 L F
.746 .582 .673 r
.49907 .7649 m .49786 .76735 L .49655 .76475 L F
.569 .305 .477 r
.62114 .56172 m .6208 .56391 L .61838 .56423 L F
.556 .324 .518 r
.62114 .56172 m .6234 .5638 L .6208 .56391 L F
.62114 .56172 m .62377 .56126 L .6234 .5638 L F
.864 .763 .75 r
.67608 .50777 m .6785 .5087 L .67912 .50669 L F
.817 .585 .029 r
.67608 .50777 m .67674 .51158 L .6785 .5087 L F
.16 .7 .762 r
.41062 .64969 m .4127 .64937 L .41434 .64924 L F
.102 0 0 r
.4127 .64937 m .41637 .6491 L .41434 .64924 L F
.588 .546 .776 r
.7223 .4969 m .72084 .50087 L .72015 .49726 L F
.709 .628 .766 r
.46863 .79273 m .4696 .79552 L .46687 .79516 L F
.698 .347 .379 r
.46687 .79516 m .4696 .79552 L .46831 .7977 L F
.632 .407 .558 r
.4696 .79552 m .47003 .79757 L .46831 .7977 L F
.4696 .79552 m .47198 .79539 L .47003 .79757 L F
.451 .878 .782 r
.52142 .77245 m .51969 .77335 L .52082 .77252 L F
.679 .183 .061 r
.51913 .77432 m .51969 .77335 L .51683 .77272 L F
.771 .705 .789 r
.34538 .71996 m .34558 .72029 L .34792 .7175 L F
.558 .543 .794 r
.74173 .60021 m .7405 .60405 L .73943 .6007 L F
.74173 .60021 m .74279 .60378 L .7405 .60405 L F
0 .029 .582 r
.47478 .78237 m .47436 .7787 L .47477 .78247 L F
.514 .327 .565 r
.47684 .77581 m .47651 .77833 L .47436 .7787 L F
.433 .347 .659 r
.47661 .78141 m .47436 .7787 L .47651 .77833 L F
.47661 .78141 m .47477 .78247 L .47436 .7787 L F
.552 .432 .67 r
.76245 .59798 m .76473 .59742 L .76434 .59502 L F
.483 .315 .577 r
.76281 .60016 m .76473 .59742 L .76245 .59798 L F
.367 0 0 r
.43118 .65051 m .43467 .65088 L .43054 .65021 L F
.659 .776 .935 r
.60129 .74853 m .60161 .74561 L .60005 .74759 L F
.60129 .74853 m .60387 .74819 L .60161 .74561 L F
.456 .07 .217 r
.41126 .66493 m .40839 .66631 L .40899 .66536 L F
.529 .345 .575 r
.36609 .72092 m .36824 .72049 L .36822 .71761 L F
.588 .391 .582 r
.36822 .71761 m .36824 .72049 L .37038 .71958 L F
.576 .392 .595 r
.36822 .71761 m .37038 .71958 L .37054 .71727 L F
0 0 0 r
.65717 .48688 m .65845 .48537 L .6592 .48388 L F
.66077 .48249 m .66004 .48408 L .66108 .48195 L F
.66077 .48249 m .66123 .48163 L .66172 .48067 L F
.584 .626 .86 r
.66406 .47998 m .66123 .48163 L .66172 .48067 L F
0 0 0 r
.66123 .48163 m .6614 .48132 L .66172 .48067 L F
.631 .785 .336 r
.66172 .48067 m .66121 .48165 L .66077 .48249 L F
.584 .626 .86 r
.66123 .48163 m .66121 .48165 L .66172 .48067 L F
.639 .961 .914 r
.66077 .48249 m .66121 .48165 L .66122 .48164 L F
.66077 .48249 m .66122 .48164 L .66378 .48144 L F
0 0 0 r
.66077 .48249 m .66108 .48195 L .6614 .48132 L F
.541 .905 .713 r
.66051 .48292 m .66077 .48249 L .661 .48256 L F
.6592 .48388 m .66077 .48249 L .66051 .48292 L F
0 0 0 r
.6592 .48388 m .65845 .48537 L .66077 .48249 L F
.21 .733 .842 r
.58196 .67823 m .5821 .67809 L .57971 .67834 L F
.647 .478 .641 r
.58193 .67982 m .57943 .68162 L .57971 .67834 L F
.23 .239 .662 r
.58188 .67959 m .58279 .68039 L .5821 .67809 L F
.5817 .68084 m .58279 .68039 L .58188 .67959 L F
.155 .463 .889 r
.58337 .68225 m .5844 .68004 L .58279 .68039 L F
.58337 .68225 m .58475 .68208 L .5844 .68004 L F
.507 0 0 r
.58475 .68208 m .58465 .68204 L .58279 .68039 L F
.23 .239 .662 r
.5817 .68084 m .58206 .67836 L .58196 .67823 L F
.263 .328 .743 r
.5817 .68084 m .58337 .68225 L .58279 .68039 L F
.647 .478 .641 r
.58185 .68074 m .57943 .68162 L .58193 .67982 L F
.522 .919 .864 r
.58104 .68045 m .57943 .68162 L .58279 .68039 L F
.507 0 0 r
.58465 .68204 m .58104 .68045 L .58279 .68039 L F
.647 .478 .641 r
.58279 .68039 m .58185 .68074 L .58193 .67982 L F
.23 .239 .662 r
.58206 .67836 m .5821 .67809 L .58208 .67811 L F
.58206 .67836 m .58208 .67811 L .58196 .67823 L F
.331 0 .108 r
.70551 .52323 m .7049 .52483 L .70253 .52544 L F
.274 0 0 r
.70781 .52293 m .7049 .52483 L .70551 .52323 L F
.705 .581 .713 r
.57058 .71486 m .57275 .71223 L .5729 .7135 L F
.535 .138 .235 r
.57007 .71693 m .57395 .71503 L .57058 .71486 L F
.097 .436 .876 r
.65062 .52379 m .65229 .52367 L .6515 .52359 L F
.704 .63 .771 r
.65315 .52482 m .65507 .52151 L .6515 .52359 L F
.65315 .52482 m .6515 .52359 L .65229 .52367 L F
.097 .436 .876 r
.65062 .52379 m .65315 .52482 L .65229 .52367 L F
.397 .355 .694 r
.65062 .52379 m .65117 .52589 L .65315 .52482 L F
.664 .41 .527 r
.47837 .67855 m .47549 .68076 L .47623 .67825 L F
.481 .669 .946 r
.75468 .60781 m .75328 .60945 L .75243 .60791 L F
.483 .672 .947 r
.75468 .60781 m .75567 .60957 L .75328 .60945 L F
.468 .634 .927 r
.34506 .59807 m .34137 .59598 L .34417 .59641 L F
.389 .569 .908 r
.34588 .59642 m .34506 .59807 L .34417 .59641 L F
.514 .721 .966 r
.34706 .59777 m .34506 .59807 L .34588 .59642 L F
.535 .314 .527 r
.60797 .56738 m .61037 .56898 L .60783 .56936 L F
.606 .261 .359 r
.6104 .56754 m .61037 .56898 L .60797 .56738 L F
.52 .419 .68 r
.44074 .66424 m .44331 .66261 L .43973 .66136 L F
.44074 .66424 m .44274 .66407 L .44331 .66261 L F
.601 .523 .739 r
.45307 .66785 m .45427 .67209 L .45598 .66941 L F
.427 .304 .61 r
.45421 .67284 m .45598 .66941 L .45427 .67209 L F
.656 .465 .614 r
.61252 .56467 m .61452 .56691 L .6104 .56754 L F
.702 .533 .656 r
.61602 .56451 m .61452 .56691 L .61252 .56467 L F
.744 .398 .396 r
.52119 .80893 m .52457 .80911 L .52347 .81151 L F
.516 .102 .193 r
.52457 .80911 m .52575 .81117 L .52347 .81151 L F
.52457 .80911 m .52691 .80926 L .52575 .81117 L F
.3 0 .228 r
.3338 .63058 m .33457 .62901 L .33652 .6283 L F
.471 .093 .24 r
.46244 .68415 m .46118 .68626 L .459 .68646 L F
.582 .211 .304 r
.46448 .68578 m .46244 .68415 L .46472 .68387 L F
.46448 .68578 m .46118 .68626 L .46244 .68415 L F
.535 .138 .235 r
.57007 .71693 m .57241 .71705 L .57395 .71503 L F
.709 .583 .711 r
.57275 .71223 m .57395 .71503 L .57565 .712 L F
.74 .42 .439 r
.52594 .72265 m .52797 .72507 L .5291 .7226 L F
.549 .211 .347 r
.5291 .7226 m .53062 .72477 L .53146 .72315 L F
.5291 .7226 m .52797 .72507 L .53062 .72477 L F
.438 .059 .22 r
.43636 .68432 m .43788 .68529 L .43849 .68381 L F
.43636 .68432 m .43509 .68646 L .43788 .68529 L F
0 0 .498 r
.65717 .48688 m .65832 .48743 L .65845 .48537 L F
.65732 .48734 m .65798 .48945 L .65832 .48743 L F
.917 .882 .784 r
.65798 .48945 m .65614 .48958 L .65832 .48743 L F
.804 .628 .664 r
.65758 .48788 m .65897 .48749 L .65832 .48743 L F
.65897 .48749 m .66078 .48698 L .65832 .48743 L F
0 0 .498 r
.65717 .48688 m .65732 .48734 L .65832 .48743 L F
.26 .759 .895 r
.34087 .71391 m .3428 .71367 L .34446 .71384 L F
.25 .359 .78 r
.58076 .7364 m .58233 .73995 L .58348 .73884 L F
.27 .23 .628 r
.58249 .74193 m .58348 .73884 L .58233 .73995 L F
.862 .738 .725 r
.48691 .77534 m .48888 .77883 L .48704 .77838 L F
0 0 0 r
.48888 .77883 m .4857 .77978 L .48704 .77838 L F
.575 .54 .779 r
.49028 .77541 m .48888 .77883 L .48691 .77534 L F
.49028 .77541 m .49112 .77853 L .48888 .77883 L F
.201 0 0 r
.48962 .78002 m .48888 .77883 L .49112 .77853 L F
.24 0 0 r
.49215 .77949 m .48962 .78002 L .49112 .77853 L F
.475 .841 .992 r
.49147 .77949 m .48962 .78002 L .49215 .77949 L F
.201 0 0 r
.48962 .78002 m .4878 .78054 L .48888 .77883 L F
.48962 .78002 m .48753 .78097 L .4878 .78054 L F
.765 .39 0 r
.48573 .77532 m .48704 .77838 L .48625 .77719 L F
.862 .738 .725 r
.48691 .77534 m .48704 .77838 L .48573 .77532 L F
.806 .797 .844 r
.48437 .77949 m .48435 .78129 L .48162 .7789 L F
.4857 .77978 m .48438 .78126 L .48437 .77949 L F
.48438 .78126 m .48435 .78129 L .48437 .77949 L F
.4857 .77978 m .4835 .7793 L .48499 .77987 L F
.4835 .7793 m .48162 .7789 L .48499 .77987 L F
.4857 .77978 m .48443 .78135 L .48435 .78129 L F
.602 .558 .778 r
.48499 .77987 m .48753 .78097 L .48748 .78082 L F
.48499 .77987 m .4868 .77856 L .4857 .77978 L F
.4868 .77856 m .48704 .77838 L .4857 .77978 L F
.48499 .77987 m .48625 .77719 L .48704 .77838 L F
.48499 .77987 m .48748 .78082 L .4865 .7779 L F
.48499 .77987 m .4865 .7779 L .48625 .77719 L F
.149 .24 .703 r
.48612 .77968 m .48499 .77987 L .48436 .77818 L F
.48436 .77713 m .48436 .77818 L .48354 .77594 L F
.48612 .77968 m .48436 .77818 L .48436 .77713 L F
.658 .591 .768 r
.48625 .77719 m .48753 .78097 L .48962 .78002 L F
.48625 .77719 m .48962 .78002 L .48846 .77946 L F
.475 .841 .992 r
.48846 .77946 m .48962 .78002 L .49147 .77949 L F
.707 .316 .305 r
.51474 .7536 m .51696 .75569 L .51814 .75388 L F
.655 .254 .273 r
.51814 .75388 m .51696 .75569 L .52057 .75563 L F
.398 .732 .991 r
.50786 .75297 m .5093 .75427 L .50701 .75354 L F
.821 .51 .464 r
.50701 .75354 m .509 .75598 L .5093 .75427 L F
.415 .429 .767 r
.35833 .68428 m .36071 .68683 L .3602 .68363 L F
0 0 0 r
.74603 .58943 m .74655 .59051 L .7484 .58888 L F
.74603 .58943 m .74564 .59132 L .74655 .59051 L F
.591 .854 .994 r
.27858 .63825 m .27906 .63673 L .28058 .63757 L F
.27858 .63825 m .27679 .63763 L .27906 .63673 L F
.337 .02 .271 r
.62795 .55999 m .62581 .56085 L .62608 .5595 L F
.707 .254 0 r
.56758 .72294 m .56724 .72283 L .56557 .72015 L F
.697 .237 0 r
.56758 .72294 m .56909 .72524 L .56724 .72283 L F
0 0 0 r
.64072 .55169 m .64202 .55114 L .6445 .55051 L F
.838 .666 .669 r
.62355 .53578 m .62456 .53669 L .62346 .53373 L F
.698 .608 .753 r
.62141 .53668 m .62456 .53669 L .62355 .53578 L F
.62141 .53668 m .62446 .53879 L .62456 .53669 L F
.382 .069 .305 r
.62446 .53879 m .62707 .53665 L .62456 .53669 L F
.529 .786 .991 r
.28815 .63772 m .28724 .63897 L .28612 .63817 L F
.28815 .63772 m .2893 .63864 L .28724 .63897 L F
.864 .763 .75 r
.67608 .50777 m .67691 .50538 L .67609 .50459 L F
.67608 .50777 m .67912 .50669 L .67691 .50538 L F
.445 .249 .52 r
.77721 .61423 m .77503 .61712 L .77482 .61477 L F
.462 0 0 r
.29187 .58688 m .29586 .58863 L .29381 .58885 L F
.906 .816 .748 r
.61172 .51988 m .60863 .52181 L .61075 .51892 L F
.61172 .51988 m .60996 .52285 L .60863 .52181 L F
.932 .92 .778 r
.61172 .51988 m .61266 .5158 L .6138 .51685 L F
.61172 .51988 m .61075 .51892 L .61266 .5158 L F
.13 .613 .916 r
.39013 .83939 m .39251 .84042 L .38993 .83986 L F
0 .216 .731 r
.38993 .83986 m .39174 .84139 L .39013 .83939 L F
.716 .738 .869 r
.77855 .60828 m .77607 .61116 L .77531 .60767 L F
.06 0 0 r
.40896 .70848 m .40489 .71031 L .4069 .70895 L F
.146 0 .183 r
.53196 .78758 m .53111 .78904 L .53339 .78674 L F
.53339 .78674 m .53111 .78904 L .53196 .78758 L F
.836 .508 0 r
.56791 .74174 m .56898 .74453 L .56931 .74296 L F
.435 .678 .966 r
.30298 .58897 m .30272 .59067 L .30134 .58956 L F
.30298 .58897 m .305 .59057 L .30272 .59067 L F
.145 .577 .929 r
.27945 .58533 m .279 .58592 L .27753 .58505 L F
.27945 .58533 m .28089 .5864 L .279 .58592 L F
.632 .475 .652 r
.47588 .66736 m .47363 .6702 L .47352 .66774 L F
.416 0 0 r
.49937 .76087 m .50082 .7616 L .50247 .76182 L F
.468 .881 .937 r
.50247 .76182 m .50334 .76027 L .50314 .75838 L F
.50247 .76182 m .50313 .76086 L .50334 .76027 L F
.50247 .76182 m .50082 .7616 L .50313 .76086 L F
.664 .789 .941 r
.36824 .72049 m .37196 .72107 L .37038 .71958 L F
0 0 0 r
.51265 .76826 m .51131 .76974 L .51054 .77023 L F
.043 .375 .842 r
.51131 .76974 m .51432 .77219 L .51054 .77023 L F
0 0 0 r
.51265 .76826 m .51131 .76974 L .51054 .77023 L F
.215 0 .226 r
.32027 .61744 m .31781 .62008 L .31967 .61925 L F
.595 .266 .383 r
.31967 .61925 m .32207 .61919 L .32027 .61744 L F
.538 .273 .462 r
.32027 .61744 m .32207 .61919 L .32256 .61712 L F
.809 .582 .594 r
.59977 .55061 m .60217 .55345 L .59926 .55293 L F
.663 .621 .797 r
.69535 .5029 m .69921 .50584 L .69695 .50282 L F
.545 .666 .916 r
.69695 .50282 m .69921 .50584 L .70128 .50486 L F
.349 .071 .343 r
.43043 .69797 m .43003 .70058 L .42804 .70033 L F
.31 .04 .332 r
.43189 .69962 m .43043 .69797 L .43246 .69739 L F
.43189 .69962 m .43003 .70058 L .43043 .69797 L F
.99 .727 .387 r
.67001 .52006 m .66911 .52134 L .66869 .51902 L F
.67001 .52006 m .67008 .52234 L .66911 .52134 L F
.786 .375 .27 r
.5861 .72054 m .58944 .72395 L .58486 .72201 L F
.996 .857 .528 r
.5861 .72054 m .58486 .72201 L .58538 .71963 L F
.234 0 0 r
.51486 .76763 m .51131 .76974 L .51265 .76826 L F
.81 .732 .778 r
.62234 .53 m .62562 .5287 L .62493 .52859 L F
.62234 .53 m .62356 .53124 L .62562 .5287 L F
.665 .972 .898 r
.62679 .52718 m .62562 .5287 L .62767 .52787 L F
.62679 .52718 m .62493 .52859 L .62562 .5287 L F
.053 .322 .805 r
.46817 .7939 m .46781 .79421 L .46853 .79434 L F
0 0 0 r
.46863 .79273 m .4671 .79483 L .46781 .79421 L F
.763 .375 .318 r
.46677 .79287 m .46863 .79273 L .46781 .79421 L F
.053 .322 .805 r
.46597 .79126 m .46781 .79421 L .46817 .7939 L F
0 0 0 r
.4671 .79483 m .46687 .79516 L .46781 .79421 L F
.006 .08 .591 r
.46781 .79421 m .46687 .79516 L .46831 .7977 L F
0 0 0 r
.31088 .62826 m .30814 .63131 L .3103 .63076 L F
.245 0 .296 r
.31269 .62784 m .31088 .62826 L .3103 .63076 L F
.78 .522 .546 r
.63457 .50785 m .63796 .50835 L .63788 .50615 L F
.609 .373 .534 r
.44851 .67793 m .45115 .67551 L .44915 .67622 L F
.427 .834 .974 r
.29007 .65199 m .29052 .65104 L .28844 .65142 L F
.29007 .65199 m .29219 .65156 L .29052 .65104 L F
0 .481 .85 r
.66045 .50469 m .66122 .50447 L .66026 .50367 L F
.66045 .50469 m .66259 .50534 L .66122 .50447 L F
.431 .044 .202 r
.43003 .70058 m .4272 .70197 L .42804 .70033 L F
.427 .304 .61 r
.45421 .67284 m .45589 .67252 L .45598 .66941 L F
.656 .469 .619 r
.45346 .67498 m .45589 .67252 L .45421 .67284 L F
.182 0 0 r
.30437 .65064 m .30355 .65109 L .30151 .65138 L F
.185 0 0 r
.30641 .65029 m .30355 .65109 L .30437 .65064 L F
.441 .695 .973 r
.67208 .48171 m .67081 .48295 L .67089 .48218 L F
.67208 .48171 m .6731 .48298 L .67081 .48295 L F
.659 .139 0 r
.54646 .72546 m .5488 .72726 L .54955 .72617 L F
.689 .176 .007 r
.5488 .72726 m .55193 .72808 L .54955 .72617 L F
.572 .007 0 r
.54955 .72617 m .55193 .72808 L .55316 .72866 L F
.561 .655 .899 r
.68947 .48927 m .68655 .49055 L .68564 .48852 L F
.528 .845 .999 r
.70052 .50062 m .69731 .50056 L .69952 .49989 L F
.854 .937 .878 r
.70199 .49753 m .69952 .49989 L .70052 .50062 L F
.70091 .4998 m .70052 .50062 L .70123 .49971 L F
.61 .073 0 r
.69952 .49989 m .70323 .50062 L .70052 .50062 L F
.70016 .50002 m .70216 .50156 L .70323 .50062 L F
.69952 .49989 m .69986 .50011 L .70016 .50002 L F
.69986 .50011 m .70216 .50156 L .70016 .50002 L F
.854 .937 .878 r
.70199 .49753 m .70091 .4998 L .70277 .49774 L F
.70091 .4998 m .70123 .49971 L .70277 .49774 L F
.528 .845 .999 r
.69952 .49989 m .69731 .50056 L .70052 .50062 L F
.595 .239 .335 r
.62658 .51111 m .62894 .51102 L .63004 .50923 L F
.743 .555 .64 r
.62894 .51102 m .63226 .50818 L .63004 .50923 L F
.517 .351 .595 r
.36165 .6644 m .36379 .66133 L .36183 .66193 L F
.301 0 0 r
.40074 .6676 m .39926 .66922 L .39713 .66957 L F
.511 .062 .12 r
.40299 .66868 m .40074 .6676 L .40301 .66766 L F
.40299 .66868 m .39926 .66922 L .40074 .6676 L F
.854 .715 .707 r
.59822 .54773 m .59977 .55061 L .5974 .54985 L F
.872 .652 .602 r
.5974 .54985 m .59977 .55061 L .59926 .55293 L F
.24 .752 .861 r
.30151 .65138 m .30172 .65095 L .29969 .6513 L F
.30151 .65138 m .30355 .65109 L .30172 .65095 L F
.707 .54 .66 r
.58034 .71953 m .58228 .72029 L .5827 .71747 L F
.586 .652 .882 r
.26407 .63359 m .26355 .63663 L .26195 .63395 L F
.26407 .63359 m .26567 .63616 L .26355 .63663 L F
.662 .572 .743 r
.77821 .59206 m .77602 .5947 L .77591 .59283 L F
.77821 .59206 m .77929 .59547 L .77602 .5947 L F
.602 .694 .908 r
.69366 .48876 m .6927 .4919 L .69141 .48947 L F
.69366 .48876 m .69511 .49147 L .6927 .4919 L F
.592 .604 .834 r
.69563 .49266 m .6927 .4919 L .69511 .49147 L F
0 0 0 r
.29565 .65078 m .29444 .65108 L .29219 .65156 L F
.023 .562 .846 r
.29565 .65078 m .29612 .65054 L .29444 .65108 L F
.29565 .65078 m .29745 .65108 L .29612 .65054 L F
.545 .584 .845 r
.35242 .71422 m .35197 .71621 L .35045 .71472 L F
.673 .647 .816 r
.78197 .59713 m .78053 .60088 L .77972 .59747 L F
.78197 .59713 m .78314 .60012 L .78053 .60088 L F
.44 .294 .585 r
.78314 .60012 m .78142 .60366 L .78053 .60088 L F
.73 .989 .874 r
.44038 .64984 m .44133 .64822 L .44269 .64933 L F
.44038 .64984 m .43909 .65001 L .44133 .64822 L F
.836 .879 .873 r
.61636 .51427 m .6138 .51685 L .61266 .5158 L F
.948 .608 .342 r
.6728 .53093 m .6744 .53395 L .67354 .53334 L F
.836 .486 .392 r
.6744 .53395 m .67338 .53554 L .67354 .53334 L F
.6744 .53395 m .67598 .5363 L .67338 .53554 L F
.615 .554 .763 r
.47476 .66242 m .47262 .66322 L .4712 .65923 L F
.67 .456 .586 r
.5529 .79303 m .55378 .79059 L .55161 .79004 L F
.5529 .79303 m .55451 .79013 L .55378 .79059 L F
.402 .296 .619 r
.4572 .76805 m .45945 .76945 L .45946 .76722 L F
.4572 .76805 m .45739 .77049 L .45945 .76945 L F
.345 0 0 r
.48827 .74455 m .49202 .74272 L .48991 .74342 L F
.492 .238 .458 r
.44368 .68046 m .44618 .67823 L .44391 .67862 L F
.696 .395 .462 r
.47046 .68139 m .47268 .68377 L .47037 .68354 L F
.668 .399 .505 r
.47322 .68157 m .47268 .68377 L .47046 .68139 L F
0 0 0 r
.34267 .71846 m .34183 .71856 L .34538 .71996 L F
.586 .189 .258 r
.3465 .71692 m .34267 .71846 L .34538 .71996 L F
.771 .705 .789 r
.34538 .71996 m .34792 .7175 L .3465 .71692 L F
.348 .584 .931 r
.64007 .48655 m .63972 .48782 L .63836 .48661 L F
.64007 .48655 m .64241 .48867 L .63972 .48782 L F
.943 .822 .695 r
.60375 .53381 m .60425 .53685 L .6028 .53569 L F
.865 .81 .793 r
.6028 .53569 m .60425 .53685 L .60222 .53979 L F
.512 .431 .702 r
.36019 .66722 m .36215 .66674 L .36165 .6644 L F
.467 .37 .662 r
.36019 .66722 m .36231 .67001 L .36215 .66674 L F
.36019 .66722 m .36039 .67043 L .36231 .67001 L F
.338 .667 .975 r
.52617 .77219 m .52527 .77323 L .52489 .77238 L F
.321 .084 .39 r
.52675 .77473 m .52527 .77323 L .52617 .77219 L F
.52675 .77473 m .52462 .77581 L .52527 .77323 L F
.667 .35 .427 r
.54953 .76576 m .5523 .76691 L .55266 .76482 L F
.793 .743 .807 r
.55172 .76255 m .55266 .76482 L .55459 .76251 L F
.725 .404 .437 r
.5523 .76691 m .55468 .76741 L .55266 .76482 L F
.381 0 0 r
.53792 .80024 m .53948 .79923 L .53582 .80034 L F
.535 .04 .027 r
.54152 .80028 m .53948 .79923 L .53792 .80024 L F
0 0 0 r
.50392 .75621 m .50701 .75354 L .50361 .75371 L F
.961 .655 .24 r
.62106 .52475 m .62101 .5231 L .6199 .52157 L F
.591 .11 .083 r
.62357 .52447 m .62101 .5231 L .62106 .52475 L F
.058 0 0 r
.38748 .71692 m .38445 .71902 L .38569 .71767 L F
.72 .389 .419 r
.48456 .80077 m .48828 .80092 L .48788 .80303 L F
0 .219 .732 r
.48828 .80092 m .48866 .80214 L .48788 .80303 L F
.48828 .80092 m .49024 .803 L .48898 .80012 L F
.48828 .80092 m .49024 .803 L .48898 .80012 L F
.48828 .80092 m .48898 .80012 L .48866 .80214 L F
.35 .788 .964 r
.28089 .5864 m .28294 .58615 L .28454 .58661 L F
.13 .667 .851 r
.28294 .58615 m .28655 .58641 L .28454 .58661 L F
.688 .582 .731 r
.71333 .60026 m .71697 .60287 L .71668 .60131 L F
.742 .586 .681 r
.62019 .53319 m .62356 .53124 L .62234 .53 L F
.62019 .53319 m .62346 .53373 L .62356 .53124 L F
.392 .568 .906 r
.50692 .75874 m .5084 .76135 L .51026 .76146 L F
.467 .312 .587 r
.45612 .77569 m .45801 .77289 L .4557 .77324 L F
.68 .475 .601 r
.60265 .56739 m .59858 .56985 L .599 .56712 L F
.60265 .56739 m .60237 .56977 L .59858 .56985 L F
.636 .605 .802 r
.71668 .60131 m .71697 .60287 L .71898 .60053 L F
.581 .575 .812 r
.71697 .60287 m .71932 .60257 L .71898 .60053 L F
.239 0 0 r
.37082 .65564 m .36867 .65339 L .36848 .65587 L F
.547 .105 .152 r
.3475 .70599 m .35023 .70619 L .3499 .70525 L F
.57 .119 .141 r
.3499 .70525 m .35023 .70619 L .35328 .70599 L F
.616 .582 .793 r
.45184 .66457 m .45307 .66785 L .45524 .66728 L F
.601 .523 .739 r
.45307 .66785 m .45598 .66941 L .45524 .66728 L F
.81 .768 .814 r
.7388 .59572 m .73553 .59546 L .73733 .59401 L F
.7388 .59572 m .7361 .59778 L .73553 .59546 L F
.537 .273 .462 r
.7388 .59572 m .7384 .59734 L .7361 .59778 L F
.627 .785 .957 r
.74078 .59459 m .7388 .59572 L .73733 .59401 L F
.726 .645 .768 r
.74078 .59459 m .7384 .59734 L .7388 .59572 L F
.52 .006 0 r
.37615 .65495 m .37442 .65385 L .37274 .65496 L F
.475 .081 .212 r
.37615 .65495 m .37671 .65365 L .37442 .65385 L F
.457 .427 .737 r
.62771 .4883 m .62627 .49075 L .62569 .48851 L F
.582 .724 .94 r
.27472 .63851 m .27272 .63892 L .27072 .63698 L F
0 0 0 r
.55359 .69986 m .55257 .70009 L .55527 .69804 L F
.55359 .69986 m .5518 .70045 L .55257 .70009 L F
.249 0 0 r
.41271 .69558 m .41333 .69687 L .41457 .69473 L F
.41271 .69558 m .4113 .69738 L .41333 .69687 L F
.385 .128 .395 r
.74106 .59267 m .74284 .59334 L .74326 .59202 L F
.74106 .59267 m .74078 .59459 L .74284 .59334 L F
.973 .757 .552 r
.59806 .56357 m .59914 .56452 L .599 .56712 L F
.608 .457 .65 r
.45858 .75937 m .46091 .75919 L .46075 .75633 L F
.56 .462 .7 r
.45858 .75937 m .46112 .76163 L .46091 .75919 L F
.45858 .75937 m .45895 .76205 L .46112 .76163 L F
.543 .853 .998 r
.75759 .58952 m .75998 .58892 L .75903 .58817 L F
.583 .942 .91 r
.75693 .58929 m .75759 .58952 L .75903 .58817 L F
.627 .561 .76 r
.70454 .49617 m .70277 .49774 L .70165 .49483 L F
.23 .381 .809 r
.70277 .49774 m .70409 .49661 L .70199 .49753 L F
.70277 .49774 m .70538 .49957 L .70409 .49661 L F
.506 .374 .634 r
.70277 .49774 m .70323 .50062 L .70538 .49957 L F
.651 .769 .936 r
.52902 .80639 m .53272 .80687 L .53105 .8057 L F
.737 .813 .911 r
.53105 .8057 m .53272 .80687 L .53439 .80535 L F
.442 .255 .53 r
.38785 .67552 m .38767 .67828 L .38561 .67858 L F
.549 .351 .565 r
.38784 .68067 m .38561 .67858 L .38767 .67828 L F
.38784 .68067 m .38566 .68121 L .38561 .67858 L F
.502 0 0 r
.41637 .6491 m .41844 .64973 L .4199 .64912 L F
.029 0 0 r
.41844 .64973 m .42199 .64906 L .4199 .64912 L F
.673 .481 .619 r
.57476 .68035 m .5711 .68358 L .57204 .68164 L F
.494 .456 .744 r
.45682 .77871 m .4581 .77529 L .45612 .77569 L F
.45682 .77871 m .45852 .77834 L .4581 .77529 L F
.409 .207 .492 r
.45682 .77871 m .45827 .78067 L .45852 .77834 L F
.45682 .77871 m .45667 .78172 L .45827 .78067 L F
.459 .87 .953 r
.29551 .63728 m .29601 .63643 L .29767 .63694 L F
.29551 .63728 m .29412 .63703 L .29601 .63643 L F
.369 .8 .967 r
.44269 .64933 m .44468 .64902 L .44594 .64949 L F
.556 .846 .998 r
.44468 .64902 m .44827 .64926 L .44594 .64949 L F
.162 .303 .761 r
.59284 .69786 m .59175 .6953 L .59349 .69552 L F
.428 .16 .403 r
.44091 .69237 m .4403 .69451 L .43826 .69483 L F
.48 .208 .423 r
.44243 .69382 m .44091 .69237 L .4431 .69196 L F
.44243 .69382 m .4403 .69451 L .44091 .69237 L F
.416 .183 .45 r
.31708 .62127 m .31967 .61925 L .31781 .62008 L F
.538 .882 .986 r
.32279 .7582 m .32217 .75929 L .32451 .75849 L F
.32279 .7582 m .32217 .75929 L .32451 .75849 L F
.13 0 .207 r
.32709 .63652 m .32925 .63389 L .3287 .63589 L F
.441 .146 .367 r
.3287 .63589 m .32619 .63883 L .32709 .63652 L F
.375 .104 .37 r
.34108 .62041 m .34366 .61771 L .34301 .61971 L F
.495 .274 .508 r
.34549 .61689 m .34301 .61971 L .34366 .61771 L F
.641 .715 .901 r
.67887 .49496 m .68248 .4961 L .68113 .49416 L F
.684 .691 .851 r
.68113 .49416 m .68248 .4961 L .68454 .49498 L F
.704 .69 .833 r
.48061 .67388 m .47698 .67314 L .47931 .67253 L F
.717 .782 .903 r
.48273 .67295 m .48061 .67388 L .47931 .67253 L F
.397 .005 .173 r
.52252 .7368 m .5193 .73897 L .52023 .73707 L F
.54 .606 .868 r
.60387 .74819 m .60518 .74502 L .60161 .74561 L F
.60387 .74819 m .60604 .7481 L .60518 .74502 L F
0 0 .306 r
.50314 .75838 m .50334 .76027 L .50392 .75621 L F
.649 .962 .786 r
.50165 .77525 m .50062 .77632 L .50037 .7766 L F
0 0 .052 r
.65079 .52639 m .64898 .52874 L .65073 .52677 L F
.733 .991 .847 r
.65073 .52677 m .64695 .52928 L .6498 .52694 L F
.482 0 0 r
.6498 .52694 m .65069 .52707 L .65073 .52677 L F
.65069 .52707 m .65308 .52743 L .65073 .52677 L F
0 0 .052 r
.65117 .52589 m .65079 .52639 L .65073 .52677 L F
.772 .99 .891 r
.65073 .52677 m .64898 .52874 L .6476 .52948 L F
0 0 0 r
.65315 .52482 m .65117 .52589 L .65073 .52677 L F
.563 .595 .843 r
.50052 .79277 m .497 .7901 L .49928 .78944 L F
.211 0 0 r
.49713 .7953 m .50052 .79277 L .49927 .79451 L F
.748 .642 .742 r
.50267 .78989 m .50052 .79277 L .49928 .78944 L F
.333 .104 .408 r
.50237 .79174 m .50052 .79277 L .50267 .78989 L F
0 0 0 r
.49927 .79451 m .50052 .79277 L .50237 .79174 L F
.333 .104 .408 r
.50237 .79174 m .50052 .79277 L .50267 .78989 L F
.812 .547 .538 r
.50642 .80654 m .50318 .80377 L .5052 .80536 L F
.517 .355 .6 r
.5052 .80536 m .50494 .80839 L .50656 .80643 L F
.331 .66 .972 r
.5073 .80554 m .50642 .80654 L .5052 .80536 L F
.517 .355 .6 r
.5052 .80536 m .50656 .80643 L .5073 .80554 L F
.812 .547 .538 r
.50318 .80377 m .50307 .80368 L .5052 .80536 L F
.343 .677 .978 r
.50866 .80664 m .50642 .80654 L .5073 .80554 L F
.34 .495 .867 r
.78128 .58598 m .78012 .58734 L .77963 .5856 L F
.354 .515 .879 r
.78128 .58598 m .78363 .58915 L .78012 .58734 L F
.47 .597 .897 r
.68564 .48852 m .6836 .48859 L .68208 .48605 L F
.655 .602 .783 r
.68102 .50389 m .68352 .50324 L .68234 .49983 L F
.374 .77 .987 r
.31815 .59185 m .3176 .59276 L .31608 .59201 L F
.31815 .59185 m .31981 .59259 L .3176 .59276 L F
.1 .135 .611 r
.32472 .6118 m .32623 .61345 L .32586 .61052 L F
.208 .154 .574 r
.32472 .6118 m .32501 .61437 L .32623 .61345 L F
.491 .128 .277 r
.45449 .68656 m .45321 .68871 L .45097 .68893 L F
.353 0 .105 r
.45675 .6864 m .45321 .68871 L .45449 .68656 L F
.593 .542 .767 r
.39038 .68988 m .38849 .69057 L .38715 .68684 L F
.529 .563 .834 r
.39103 .69143 m .38849 .69057 L .39038 .68988 L F
.552 .467 .712 r
.36322 .69543 m .36491 .69205 L .36243 .69222 L F
.36322 .69543 m .36532 .69504 L .36491 .69205 L F
.558 .477 .719 r
.36376 .6978 m .36532 .69504 L .36322 .69543 L F
.564 .293 .464 r
.5284 .75056 m .5307 .75033 L .53179 .74767 L F
.733 .553 .648 r
.5307 .75033 m .53381 .74793 L .53179 .74767 L F
0 0 0 r
.63756 .4974 m .63675 .49788 L .63748 .49762 L F
.63756 .4974 m .63912 .49701 L .64055 .49732 L F
.63756 .4974 m .63748 .49762 L .63912 .49701 L F
.313 0 0 r
.6376 .49731 m .63756 .4974 L .63902 .4977 L F
.63568 .49678 m .63756 .4974 L .6376 .49731 L F
.494 .12 .258 r
.63902 .4977 m .63819 .49962 L .63566 .49989 L F
.302 0 0 r
.29972 .63651 m .30363 .63433 L .30069 .63603 L F
.29972 .63651 m .30187 .63611 L .30363 .63433 L F
.319 0 .089 r
.30187 .63611 m .30548 .63358 L .30363 .63433 L F
.393 0 .112 r
.69518 .51875 m .69749 .51853 L .69819 .51697 L F
.221 0 .041 r
.69819 .51697 m .69951 .51774 L .70033 .51636 L F
.69819 .51697 m .69749 .51853 L .69951 .51774 L F
.584 .781 .973 r
.73069 .61381 m .734 .61442 L .7328 .61326 L F
.652 .744 .917 r
.734 .61442 m .7351 .61167 L .7328 .61326 L F
.734 .61442 m .73642 .61367 L .7351 .61167 L F
.835 .784 .803 r
.60062 .5386 m .60222 .53979 L .60013 .54239 L F
.865 .81 .793 r
.6028 .53569 m .60222 .53979 L .60062 .5386 L F
.443 .014 .127 r
.67674 .51158 m .67344 .5134 L .67446 .51445 L F
0 .261 .725 r
.676 .51508 m .67446 .51445 L .67344 .5134 L F
.676 .51508 m .67725 .51622 L .67446 .51445 L F
.484 .813 1 r
.43118 .65051 m .43333 .65011 L .43467 .65088 L F
.392 .779 .99 r
.43333 .65011 m .43692 .65061 L .43467 .65088 L F
.47 .289 .552 r
.47856 .77603 m .47651 .77833 L .47684 .77581 L F
.835 .784 .803 r
.60062 .5386 m .60013 .54239 L .59872 .54153 L F
.946 .769 .63 r
.59872 .54153 m .60013 .54239 L .5997 .54474 L F
.593 .107 .07 r
.66854 .49418 m .66885 .495 L .6717 .49344 L F
.825 .947 .902 r
.67106 .49172 m .6717 .49344 L .67204 .49386 L F
.67106 .49172 m .66854 .49418 L .6717 .49344 L F
.658 .193 .137 r
.6717 .49344 m .66885 .495 L .67151 .49509 L F
.739 .936 .952 r
.25985 .65401 m .26191 .65427 L .26355 .65302 L F
.5 .291 .527 r
.26226 .63126 m .26195 .63395 L .25992 .63442 L F
.367 .296 .645 r
.26346 .6273 m .26374 .63066 L .26226 .63126 L F
.524 .381 .628 r
.26374 .63066 m .26195 .63395 L .26226 .63126 L F
.226 0 .2 r
.33096 .6332 m .32925 .63389 L .33192 .63139 L F
.278 0 .23 r
.33096 .6332 m .33192 .63139 L .3338 .63058 L F
.487 .725 .977 r
.35416 .60076 m .35083 .59972 L .35286 .59955 L F
.45 .718 .982 r
.35487 .59939 m .35416 .60076 L .35286 .59955 L F
.429 .693 .975 r
.35612 .60054 m .35416 .60076 L .35487 .59939 L F
.541 .499 .758 r
.35704 .60262 m .35416 .60076 L .35612 .60054 L F
.969 .732 .524 r
.34669 .71417 m .3465 .71692 L .34792 .7175 L F
.519 .503 .778 r
.72127 .49387 m .72015 .49726 L .71883 .49413 L F
.72127 .49387 m .7223 .4969 L .72015 .49726 L F
.44 .294 .585 r
.78314 .60012 m .78398 .60349 L .78142 .60366 L F
.262 .162 .548 r
.78337 .60571 m .78142 .60366 L .78398 .60349 L F
.78337 .60571 m .78117 .60672 L .78142 .60366 L F
.632 .777 .95 r
.50226 .78817 m .50267 .78989 L .49928 .78944 L F
0 .187 .718 r
.50333 .78923 m .50267 .78989 L .50226 .78817 L F
0 0 .071 r
.50237 .79174 m .50267 .78989 L .50333 .78923 L F
.887 .822 .778 r
.62 .50324 m .61954 .50637 L .61711 .50442 L F
.983 .801 .581 r
.61954 .50637 m .61738 .50684 L .61711 .50442 L F
.61954 .50637 m .61851 .50823 L .61738 .50684 L F
.445 .608 .917 r
.62771 .4883 m .62569 .48851 L .62417 .48603 L F
.932 .57 .304 r
.6728 .53093 m .67354 .53334 L .67198 .53234 L F
.238 0 0 r
.51316 .71655 m .51537 .71708 L .51216 .71642 L F
.51216 .71642 m .51537 .71708 L .51316 .71655 L F
0 0 .009 r
.56175 .69189 m .55952 .69476 L .56043 .69301 L F
.953 .612 .321 r
.54235 .78282 m .5439 .78169 L .54371 .7838 L F
.871 .711 .681 r
.5439 .78169 m .54382 .78263 L .54371 .7838 L F
0 0 .328 r
.54405 .77847 m .5439 .78169 L .54477 .77997 L F
.703 .934 .622 r
.54477 .77997 m .5439 .78169 L .54235 .78282 L F
.957 .92 .73 r
.59203 .7144 m .59083 .71358 L .59193 .71425 L F
.95 .758 .609 r
.58413 .71202 m .58489 .71474 L .58357 .71375 L F
.58357 .71375 m .58489 .71474 L .58413 .71202 L F
.474 .573 .874 r
.7745 .58021 m .77351 .58237 L .77248 .58045 L F
.7745 .58021 m .77642 .58292 L .77351 .58237 L F
.876 .856 .818 r
.57643 .67552 m .57286 .67764 L .5753 .67654 L F
.09 0 0 r
.5753 .67654 m .57851 .67554 L .57643 .67552 L F
.781 .763 .837 r
.71071 .49481 m .70868 .49583 L .70758 .4944 L F
.787 .754 .824 r
.70758 .4944 m .70887 .49511 L .71071 .49481 L F
.751 .854 .926 r
.71071 .49481 m .71213 .49154 L .71299 .49435 L F
.71071 .49481 m .70887 .49511 L .71213 .49154 L F
.775 .637 .709 r
.56296 .77326 m .5634 .77617 L .56125 .77584 L F
.73 .527 .617 r
.56389 .77812 m .56125 .77584 L .5634 .77617 L F
.456 .234 .487 r
.56622 .77309 m .5634 .77617 L .56296 .77326 L F
.56622 .77309 m .56574 .77553 L .5634 .77617 L F
.618 .491 .685 r
.56574 .77553 m .56389 .77812 L .5634 .77617 L F
.907 .501 .194 r
.5972 .70876 m .59811 .71113 L .59878 .7101 L F
.902 .615 .491 r
.59741 .71343 m .59878 .7101 L .59811 .71113 L F
.59741 .71343 m .5991 .71406 L .59878 .7101 L F
.87 .589 .51 r
.59878 .7101 m .5991 .71406 L .60159 .71465 L F
.753 .953 .641 r
.47236 .78512 m .47478 .78237 L .47477 .78247 L F
.439 .031 .167 r
.43826 .69483 m .43728 .69673 L .43522 .69695 L F
.451 .082 .246 r
.4403 .69451 m .43728 .69673 L .43826 .69483 L F
.453 .803 .998 r
.65213 .54544 m .65469 .54522 L .65432 .54607 L F
.868 .824 .802 r
.66498 .5305 m .66627 .53334 L .66781 .53064 L F
.94 .793 .671 r
.66376 .53539 m .66627 .53334 L .66498 .5305 L F
.66376 .53539 m .6653 .53646 L .66627 .53334 L F
.45 .195 .435 r
.33877 .62302 m .33828 .6251 L .33626 .6256 L F
.447 .222 .478 r
.34108 .62041 m .34076 .62247 L .33877 .62302 L F
.425 .173 .426 r
.34076 .62247 m .33828 .6251 L .33877 .62302 L F
0 .306 .767 r
.49786 .76735 m .49434 .76482 L .49655 .76475 L F
.483 .306 .564 r
.57113 .76709 m .57001 .77063 L .5695 .76712 L F
.639 .556 .745 r
.7811 .59484 m .77972 .59747 L .77929 .59547 L F
.491 .379 .654 r
.7811 .59484 m .78197 .59713 L .77972 .59747 L F
.414 .433 .771 r
.35902 .70856 m .3573 .70978 L .35642 .70651 L F
.412 .863 .855 r
.62434 .51752 m .62214 .51839 L .62377 .51817 L F
.681 .412 .509 r
.51537 .71996 m .51881 .71751 L .51537 .71708 L F
.51537 .71996 m .51908 .72013 L .51881 .71751 L F
.819 .516 .476 r
.51881 .71751 m .51908 .72013 L .52218 .72035 L F
.62 .568 .775 r
.68543 .49768 m .68686 .49413 L .68454 .49498 L F
.68543 .49768 m .68811 .49746 L .68686 .49413 L F
.71 .553 .673 r
.68493 .49908 m .68811 .49746 L .68543 .49768 L F
.558 .477 .719 r
.36376 .6978 m .36589 .69741 L .36532 .69504 L F
.319 .121 .447 r
.45915 .76449 m .46112 .76163 L .45895 .76205 L F
.767 .636 .716 r
.67835 .5336 m .6794 .53669 L .67598 .5363 L F
.87 .67 .63 r
.6794 .53669 m .67644 .53793 L .67598 .5363 L F
.6794 .53669 m .67931 .53951 L .67644 .53793 L F
.715 .609 .737 r
.682 .53441 m .6794 .53669 L .67835 .5336 L F
.548 .525 .782 r
.50977 .74282 m .51048 .74177 L .50882 .73957 L F
.50977 .74282 m .51218 .74251 L .51048 .74177 L F
.39 .002 .176 r
.50977 .74282 m .51011 .74298 L .51218 .74251 L F
.51218 .74251 m .51011 .74298 L .50977 .74282 L F
0 0 .577 r
.65931 .51049 m .66063 .51332 L .66067 .51163 L F
.386 .139 .412 r
.27445 .61129 m .27208 .61398 L .27259 .6119 L F
.206 .733 .819 r
.35775 .71221 m .36027 .71186 L .36137 .71185 L F
.704 .655 .799 r
.36027 .71186 m .36053 .71183 L .36305 .71042 L F
.66 .966 .92 r
.36137 .71185 m .36053 .71183 L .36305 .71042 L F
.562 .65 .894 r
.36305 .71042 m .36339 .71208 L .36137 .71185 L F
.36305 .71042 m .36339 .71208 L .36137 .71185 L F
0 0 0 r
.36305 .71042 m .36063 .71256 L .36137 .71185 L F
.704 .655 .799 r
.36053 .71183 m .36159 .71171 L .36305 .71042 L F
.35941 .7102 m .36027 .71186 L .36305 .71042 L F
.66 .966 .92 r
.36053 .71183 m .36006 .71183 L .36305 .71042 L F
.206 .733 .819 r
.36027 .71186 m .36049 .71183 L .36053 .71183 L F
.36027 .71186 m .36053 .71183 L .36137 .71185 L F
.591 .165 .203 r
.36137 .71185 m .36063 .71256 L .35775 .71221 L F
.704 .655 .799 r
.36027 .71186 m .36063 .71256 L .36159 .71171 L F
.618 .616 .826 r
.35775 .71221 m .36063 .71256 L .36027 .71186 L F
.35775 .71221 m .36027 .71186 L .35941 .7102 L F
.206 .733 .819 r
.35775 .71221 m .36006 .71183 L .36049 .71183 L F
.41 .09 .308 r
.55584 .6894 m .55849 .68894 L .55848 .68728 L F
.699 .435 .521 r
.55849 .68894 m .56106 .68695 L .55848 .68728 L F
0 0 0 r
.55956 .78449 m .56003 .78439 L .56187 .78401 L F
.614 .308 .427 r
.54478 .70301 m .54714 .70295 L .547 .70163 L F
0 0 .237 r
.54794 .69711 m .547 .70163 L .54812 .69964 L F
.544 .257 .431 r
.547 .70163 m .54969 .70121 L .54812 .69964 L F
.547 .70163 m .54714 .70295 L .54969 .70121 L F
.984 .884 .648 r
.67151 .49509 m .67158 .49977 L .67194 .49788 L F
.493 .633 .915 r
.64774 .49164 m .64626 .49331 L .64541 .49185 L F
.64774 .49164 m .6497 .49401 L .64626 .49331 L F
.546 .643 .897 r
.46177 .64974 m .46128 .6526 L .45969 .64986 L F
.46177 .64974 m .46349 .65232 L .46128 .6526 L F
.835 .653 .656 r
.60907 .73399 m .60869 .7366 L .6107 .73672 L F
.829 .585 .57 r
.60869 .7366 m .60884 .73897 L .6107 .73672 L F
.823 .575 .564 r
.60884 .73897 m .61083 .7396 L .6107 .73672 L F
.607 .688 .9 r
.6412 .49458 m .64255 .4921 L .64025 .49136 L F
.6412 .49458 m .64181 .49458 L .64255 .4921 L F
.627 .376 .518 r
.6412 .49458 m .64327 .4966 L .64181 .49458 L F
0 .266 .751 r
.55887 .73209 m .56052 .73373 L .55825 .73177 L F
.55887 .73209 m .55988 .73292 L .56052 .73373 L F
.752 .243 0 r
.54714 .70295 m .55078 .70536 L .54987 .70407 L F
.443 .014 .127 r
.67674 .51158 m .67457 .51358 L .67344 .5134 L F
.817 .585 .029 r
.67608 .50777 m .67649 .51097 L .67674 .51158 L F
.872 .985 .707 r
.67649 .51097 m .67457 .51358 L .67674 .51158 L F
.571 .589 .833 r
.26482 .65645 m .26534 .65325 L .26355 .65302 L F
.26482 .65645 m .26695 .65602 L .26534 .65325 L F
.664 .41 .527 r
.47837 .67855 m .47841 .68075 L .47549 .68076 L F
.69 .531 .666 r
.48067 .67805 m .47841 .68075 L .47837 .67855 L F
.362 .136 .43 r
.33096 .6332 m .3287 .63589 L .32925 .63389 L F
.658 .36 .456 r
.51883 .72251 m .52218 .72035 L .51908 .72013 L F
.51883 .72251 m .52237 .72249 L .52218 .72035 L F
.759 .437 .441 r
.52218 .72035 m .52237 .72249 L .52594 .72265 L F
.466 0 0 r
.48691 .77534 m .48426 .77335 L .48573 .77532 L F
.765 .39 0 r
.48573 .77532 m .48625 .77719 L .48691 .77534 L F
.474 .45 .752 r
.36673 .70065 m .36722 .70462 L .36805 .70401 L F
.517 .499 .775 r
.36722 .70462 m .37037 .7058 L .36805 .70401 L F
.36722 .70462 m .36856 .70646 L .37037 .7058 L F
.809 .64 .673 r
.61036 .742 m .61382 .73991 L .61083 .7396 L F
.61036 .742 m .61371 .74213 L .61382 .73991 L F
.766 .467 .48 r
.50247 .80601 m .50307 .80368 L .49949 .80318 L F
.634 .334 .444 r
.50247 .80601 m .5052 .80536 L .50307 .80368 L F
.667 .746 .909 r
.54564 .7798 m .5471 .78205 L .54901 .78072 L F
0 0 0 r
.73409 .59586 m .73278 .5959 L .7317 .59634 L F
.73409 .59586 m .73553 .59546 L .73278 .5959 L F
.571 .428 .648 r
.46075 .75633 m .46312 .75876 L .46347 .75631 L F
.46075 .75633 m .46091 .75919 L .46312 .75876 L F
.428 .673 .965 r
.34202 .59456 m .34137 .59598 L .34013 .59461 L F
.34202 .59456 m .34417 .59641 L .34137 .59598 L F
.8 .695 .749 r
.49568 .78689 m .497 .7901 L .49359 .78968 L F
.672 .653 .823 r
.49802 .78643 m .497 .7901 L .49568 .78689 L F
.49802 .78643 m .49928 .78944 L .497 .7901 L F
.725 .547 .649 r
.66873 .50334 m .6721 .50365 L .67069 .5062 L F
.25 0 0 r
.67297 .5043 m .67451 .50347 L .6721 .50365 L F
.67297 .5043 m .6721 .50365 L .67288 .50194 L F
.865 .729 .711 r
.64313 .50839 m .64143 .51109 L .64008 .5078 L F
.41 .203 .485 r
.26317 .6228 m .26285 .62523 L .26096 .62584 L F
.513 .481 .758 r
.26285 .62523 m .26346 .6273 L .26096 .62584 L F
.326 0 0 r
.72944 .59592 m .72702 .59568 L .7264 .59661 L F
.72944 .59592 m .72928 .59549 L .72702 .59568 L F
.852 .988 .851 r
.76504 .62315 m .76679 .62018 L .76421 .62243 L F
.76504 .62315 m .76751 .62062 L .76679 .62018 L F
.51 .271 .487 r
.59257 .72059 m .59183 .72265 L .58956 .72305 L F
.605 .788 .969 r
.75998 .58892 m .76331 .58946 L .76235 .58829 L F
.627 .822 .975 r
.76331 .58946 m .76455 .58771 L .76235 .58829 L F
.76331 .58946 m .76548 .58903 L .76455 .58771 L F
.518 .667 .93 r
.7492 .61645 m .75003 .61427 L .74785 .61472 L F
.7492 .61645 m .75149 .61623 L .75003 .61427 L F
.711 .483 .578 r
.60237 .56977 m .60542 .5687 L .60493 .57216 L F
.595 .346 .509 r
.60783 .56936 m .60493 .57216 L .60542 .5687 L F
.622 .839 .983 r
.5215 .74274 m .51839 .74274 L .52019 .74186 L F
.5215 .74274 m .51839 .74274 L .52019 .74186 L F
.399 .169 .445 r
.34301 .61971 m .34076 .62247 L .34108 .62041 L F
.382 .564 .907 r
.39583 .69502 m .39581 .69717 L .39394 .69486 L F
.39583 .69502 m .39755 .69731 L .39581 .69717 L F
.336 0 .002 r
.41478 .70592 m .41332 .70754 L .41096 .70786 L F
.258 0 0 r
.4154 .7071 m .41478 .70592 L .41689 .70552 L F
.4154 .7071 m .41332 .70754 L .41478 .70592 L F
.534 .481 .744 r
.3619 .6899 m .36243 .69222 L .36384 .68972 L F
.594 .556 .782 r
.36243 .69222 m .36491 .69205 L .36384 .68972 L F
0 0 0 r
.77037 .60885 m .77197 .60689 L .77291 .60795 L F
.63 .876 .987 r
.7711 .60799 m .77037 .60885 L .77291 .60795 L F
0 0 0 r
.77037 .60885 m .77181 .60714 L .77197 .60689 L F
.63 .876 .987 r
.76948 .60802 m .7711 .60799 L .77197 .60689 L F
.7711 .60799 m .77291 .60795 L .77197 .60689 L F
0 0 0 r
.7711 .60799 m .76968 .6105 L .77181 .60714 L F
.77037 .60885 m .77032 .60896 L .7711 .60799 L F
.77032 .60896 m .76968 .6105 L .7711 .60799 L F
.63 .876 .987 r
.76948 .60802 m .77037 .60885 L .7711 .60799 L F
.189 .72 .75 r
.43368 .66028 m .43219 .66047 L .42998 .66093 L F
0 .184 .708 r
.43368 .66028 m .43442 .66019 L .43219 .66047 L F
.43368 .66028 m .43664 .66324 L .43442 .66019 L F
.759 .583 .659 r
.62019 .53319 m .62355 .53578 L .62346 .53373 L F
.926 .974 .721 r
.76948 .60802 m .76817 .61173 L .76968 .6105 L F
.76948 .60802 m .76754 .6115 L .76817 .61173 L F
.543 .923 .923 r
.76817 .61173 m .76754 .6115 L .76968 .6105 L F
.566 .543 .789 r
.47689 .66188 m .47501 .66401 L .47476 .66242 L F
.47689 .66188 m .47732 .66374 L .47501 .66401 L F
.538 .448 .701 r
.47732 .66374 m .47588 .66736 L .47501 .66401 L F
.566 .886 .99 r
.76575 .57959 m .76673 .5802 L .76432 .58096 L F
.582 .918 .969 r
.76575 .57959 m .76432 .58096 L .76349 .58053 L F
.28 .783 .802 r
.27284 .65324 m .27104 .65354 L .26923 .65402 L F
.244 0 0 r
.27284 .65324 m .27345 .65362 L .27104 .65354 L F
.27284 .65324 m .2753 .65375 L .27345 .65362 L F
.567 .783 .98 r
.45178 .64986 m .44827 .64926 L .45049 .64895 L F
.348 .78 .969 r
.45049 .64895 m .45389 .64927 L .45178 .64986 L F
.361 0 0 r
.60736 .75001 m .60932 .75037 L .60601 .75048 L F
.409 .191 .468 r
.55354 .74773 m .55149 .75077 L .55158 .74809 L F
.55354 .74773 m .55149 .75077 L .55158 .74809 L F
.946 .715 .248 r
.66588 .51344 m .66526 .51045 L .66596 .51169 L F
.793 .743 .807 r
.55172 .76255 m .55459 .76251 L .55351 .76131 L F
.437 .406 .727 r
.55459 .76251 m .5554 .76241 L .55351 .76131 L F
.55459 .76251 m .55702 .76417 L .5554 .76241 L F
.522 .145 .268 r
.49329 .77809 m .49685 .77593 L .4968 .77869 L F
.49329 .77809 m .49525 .77832 L .49685 .77593 L F
.954 .618 .222 r
.49685 .77593 m .49605 .7755 L .49548 .77288 L F
.992 .879 .597 r
.49685 .77593 m .49525 .77832 L .49605 .7755 L F
.357 .068 .331 r
.26768 .61717 m .27024 .61474 L .26959 .6166 L F
.322 .037 .315 r
.26959 .6166 m .27024 .61474 L .27208 .61398 L F
.239 0 0 r
.711 .52221 m .70877 .52302 L .70781 .52293 L F
.132 0 0 r
.71335 .52195 m .70877 .52302 L .711 .52221 L F
.475 .221 .448 r
.62787 .5029 m .62539 .50524 L .62551 .50333 L F
.61 .343 .488 r
.4765 .68311 m .47322 .68157 L .47549 .68076 L F
.4765 .68311 m .47268 .68377 L .47322 .68157 L F
.511 .821 1 r
.66378 .48144 m .66616 .48103 L .66696 .48182 L F
.351 .723 .986 r
.66624 .48027 m .66696 .48182 L .66616 .48103 L F
.66624 .48027 m .67089 .48218 L .66696 .48182 L F
.551 .413 .646 r
.3602 .68363 m .36199 .68072 L .36013 .68137 L F
.516 .492 .768 r
.35928 .6779 m .36013 .68137 L .36199 .68072 L F
.766 .511 .549 r
.47297 .78732 m .46955 .78426 L .47236 .78512 L F
.622 .416 .581 r
.51327 .80931 m .51337 .81184 L .50997 .81228 L F
.656 .45 .593 r
.51543 .80918 m .51337 .81184 L .51327 .80931 L F
.801 .361 .2 r
.49604 .80291 m .49602 .80185 L .49247 .80043 L F
.668 .521 .676 r
.56769 .77091 m .56885 .77275 L .56622 .77309 L F
.646 .559 .742 r
.5695 .76712 m .56769 .77091 L .56697 .76864 L F
.5695 .76712 m .57001 .77063 L .56769 .77091 L F
.64 .512 .691 r
.56769 .77091 m .57001 .77063 L .56885 .77275 L F
.297 .791 .872 r
.59522 .56414 m .59493 .56389 L .59492 .56086 L F
.59522 .56414 m .59806 .56357 L .59493 .56389 L F
.259 0 0 r
.24849 .59076 m .25222 .58869 L .25011 .58886 L F
.798 .674 .727 r
.48206 .78615 m .48411 .78411 L .48113 .7845 L F
.283 0 0 r
.2717 .58462 m .27395 .58509 L .27524 .58495 L F
.078 0 0 r
.27395 .58509 m .27753 .58505 L .27524 .58495 L F
0 0 .239 r
.65634 .51957 m .6558 .51884 L .65629 .52035 L F
0 0 0 r
.65729 .51689 m .65567 .51866 L .6558 .51884 L F
.848 .977 .677 r
.65729 .51689 m .6558 .51884 L .65655 .51642 L F
0 0 .239 r
.65655 .51642 m .6558 .51884 L .65634 .51957 L F
0 0 0 r
.65567 .51866 m .65506 .51932 L .6558 .51884 L F
.011 0 .245 r
.65506 .51932 m .65629 .52035 L .6558 .51884 L F
.65506 .51932 m .65507 .52151 L .65629 .52035 L F
.094 .651 .729 r
.75921 .61182 m .7617 .61156 L .76248 .61151 L F
.575 .522 .759 r
.76248 .61151 m .76397 .60793 L .76204 .60907 L F
.76248 .61151 m .76505 .61211 L .76397 .60793 L F
.323 .64 .965 r
.76384 .61074 m .76248 .61151 L .7617 .61156 L F
.76384 .61074 m .76505 .61211 L .76248 .61151 L F
.68 .754 .907 r
.63543 .48511 m .63642 .48669 L .6331 .48608 L F
.679 .209 .128 r
.63642 .48669 m .63576 .48768 L .6331 .48608 L F
.483 .546 .845 r
.63778 .48459 m .63642 .48669 L .63543 .48511 L F
.63778 .48459 m .63836 .48661 L .63642 .48669 L F
.061 0 0 r
.63576 .48768 m .63836 .48661 L .63642 .48669 L F
.63576 .48768 m .63836 .48661 L .63642 .48669 L F
.585 .536 .767 r
.43973 .66136 m .44331 .66261 L .44215 .66122 L F
.453 .476 .793 r
.39284 .69147 m .39212 .69483 L .39103 .69143 L F
.39284 .69147 m .39394 .69486 L .39212 .69483 L F
.412 .466 .807 r
.75849 .62414 m .76081 .62236 L .75809 .62209 L F
.75849 .62414 m .7591 .62417 L .76081 .62236 L F
.493 .12 .26 r
.2798 .60806 m .27631 .6106 L .27852 .60832 L F
.883 .991 .757 r
.67735 .50293 m .67501 .5051 L .67451 .50347 L F
.67735 .50293 m .67609 .50459 L .67501 .5051 L F
.67501 .5051 m .67609 .50459 L .67735 .50293 L F
.993 .752 .394 r
.51372 .73003 m .51335 .7278 L .51265 .7284 L F
0 0 .503 r
.51265 .7284 m .51317 .73141 L .51372 .73003 L F
0 0 0 r
.50392 .75621 m .50505 .75576 L .50701 .75354 L F
.283 .097 .443 r
.50392 .75621 m .50539 .75806 L .50505 .75576 L F
.50392 .75621 m .50334 .76027 L .50539 .75806 L F
.25 .762 .839 r
.50303 .75615 m .50505 .75576 L .50392 .75621 L F
.998 .789 .488 r
.50392 .75621 m .50334 .76027 L .50303 .75615 L F
.502 .384 .651 r
.35884 .67561 m .36106 .67751 L .36075 .67512 L F
.35884 .67561 m .35928 .6779 L .36106 .67751 L F
.007 0 0 r
.39421 .71386 m .39326 .71367 L .3954 .71328 L F
.39421 .71386 m .39225 .71468 L .39326 .71367 L F
.576 .532 .768 r
.54072 .74195 m .53819 .74242 L .53805 .7412 L F
.483 0 0 r
.59131 .71163 m .59075 .71121 L .59052 .71102 L F
.974 .668 .352 r
.59131 .71163 m .59083 .71358 L .59075 .71121 L F
.59131 .71163 m .59193 .71425 L .59083 .71358 L F
.753 .428 .434 r
.71316 .50596 m .71292 .5075 L .70979 .50553 L F
.135 0 .187 r
.71316 .50596 m .71453 .50666 L .71331 .50518 L F
.643 .615 .807 r
.71453 .50666 m .71346 .50579 L .71331 .50518 L F
0 0 .156 r
.71316 .50596 m .71331 .50518 L .71316 .50457 L F
.643 .615 .807 r
.71346 .50579 m .71126 .504 L .71331 .50518 L F
0 0 .156 r
.71316 .50457 m .71331 .50518 L .71318 .5027 L F
0 0 0 r
.27841 .65281 m .27937 .65263 L .27698 .65284 L F
.27841 .65281 m .28047 .65227 L .27937 .65263 L F
.627 .561 .76 r
.70454 .49617 m .70165 .49483 L .70489 .49495 L F
.675 .519 .667 r
.70165 .49483 m .705 .49594 L .70489 .49495 L F
.564 .621 .868 r
.70274 .49116 m .70497 .49587 L .70165 .49483 L F
.70497 .49587 m .705 .49594 L .70473 .49585 L F
.70497 .49587 m .70473 .49585 L .70165 .49483 L F
.589 .424 .626 r
.705 .49594 m .70758 .4944 L .70489 .49495 L F
.611 .459 .651 r
.70758 .4944 m .70504 .49588 L .70489 .49495 L F
.70504 .49588 m .70454 .49617 L .70463 .49584 L F
.70504 .49588 m .70497 .49587 L .70489 .49495 L F
.70497 .49587 m .70468 .49569 L .70489 .49495 L F
.515 .79 .995 r
.70739 .49358 m .70503 .49591 L .70274 .49116 L F
.71 .794 .917 r
.70868 .49583 m .70569 .49608 L .70758 .4944 L F
.70569 .49608 m .70528 .49599 L .70758 .4944 L F
.70507 .49613 m .70502 .49595 L .70758 .4944 L F
.589 .424 .626 r
.705 .49594 m .70506 .49593 L .70758 .4944 L F
.515 .79 .995 r
.70501 .49592 m .70506 .49593 L .705 .49594 L F
.71 .794 .917 r
.70506 .49593 m .70501 .4959 L .70758 .4944 L F
.70502 .49595 m .70501 .49592 L .70506 .49593 L F
.70501 .49592 m .70501 .4959 L .70506 .49593 L F
.589 .424 .626 r
.70506 .49593 m .70742 .49567 L .70758 .4944 L F
.515 .79 .995 r
.70739 .49358 m .70742 .49567 L .70506 .49593 L F
.70739 .49358 m .70506 .49593 L .70501 .49592 L F
.71 .794 .917 r
.70569 .49608 m .70507 .49613 L .70528 .49599 L F
.515 .79 .995 r
.70501 .49592 m .705 .49594 L .70501 .4959 L F
.71 .794 .917 r
.70507 .49613 m .70454 .49617 L .70501 .4959 L F
.515 .79 .995 r
.70501 .4959 m .705 .49594 L .70497 .49587 L F
.70503 .49591 m .70501 .49592 L .70501 .4959 L F
.70503 .49591 m .70497 .49587 L .70274 .49116 L F
.611 .459 .651 r
.70497 .49587 m .70463 .49584 L .70468 .49569 L F
0 0 0 r
.29603 .60318 m .29203 .60425 L .29376 .60328 L F
.172 0 .073 r
.56885 .77275 m .56574 .77553 L .56622 .77309 L F
.271 .708 .964 r
.32392 .59211 m .32315 .5929 L .32173 .59221 L F
.32392 .59211 m .32542 .59296 L .32315 .5929 L F
.751 .383 .356 r
.5784 .71969 m .57895 .72017 L .58034 .71953 L F
.592 .025 0 r
.57895 .72017 m .58228 .72029 L .58034 .71953 L F
.555 .639 .889 r
.75243 .60791 m .75008 .60825 L .74878 .60577 L F
.524 .492 .763 r
.76097 .60637 m .76204 .60907 L .76397 .60793 L F
.549 .441 .683 r
.35704 .60262 m .35718 .60569 L .35511 .60601 L F
.277 .335 .743 r
.64255 .4921 m .64181 .49458 L .64388 .49255 L F
.027 .176 .683 r
.64181 .49458 m .64377 .49427 L .64388 .49255 L F
.64181 .49458 m .64327 .4966 L .64377 .49427 L F
.213 0 .317 r
.69505 .53286 m .69293 .53572 L .69337 .53396 L F
.736 .463 .515 r
.51936 .77619 m .52306 .77831 L .51985 .77697 L F
.889 .586 .467 r
.55988 .73292 m .56202 .73659 L .56385 .7366 L F
.913 .698 .599 r
.56202 .73659 m .56354 .73946 L .56385 .7366 L F
.56202 .73659 m .56354 .73946 L .56385 .7366 L F
.404 .255 .563 r
.36052 .6727 m .36231 .67001 L .36039 .67043 L F
.435 .163 .401 r
.47391 .75102 m .4734 .753 L .47592 .75056 L F
.502 .843 .565 r
.51663 .80076 m .51292 .80399 L .51771 .80273 L F
.506 .334 .581 r
.51883 .80054 m .51663 .80076 L .51771 .80273 L F
.749 .317 0 r
.51744 .80234 m .51663 .80076 L .51883 .80054 L F
.627 .926 .973 r
.76751 .62062 m .76861 .6192 L .76679 .62018 L F
.76751 .62062 m .76953 .61964 L .76861 .6192 L F
.377 .015 .218 r
.70214 .52656 m .70016 .5259 L .70253 .52544 L F
.70214 .52656 m .69967 .52723 L .70016 .5259 L F
.457 .298 .576 r
.26509 .61953 m .26499 .62223 L .26317 .6228 L F
.484 .266 .506 r
.26486 .62479 m .26317 .6228 L .26499 .62223 L F
.26486 .62479 m .26285 .62523 L .26317 .6228 L F
.434 .823 .986 r
.69491 .50076 m .6972 .49981 L .69337 .49754 L F
.69491 .50076 m .69731 .50056 L .6972 .49981 L F
.659 .532 .698 r
.69491 .50076 m .69535 .5029 L .69731 .50056 L F
.82 .355 .112 r
.5879 .68973 m .58687 .69056 L .58667 .68962 L F
.477 .3 .561 r
.58949 .68643 m .59139 .68309 L .59018 .68329 L F
0 0 .52 r
.58927 .68365 m .5896 .68615 L .5893 .68343 L F
.477 .3 .561 r
.58939 .68478 m .59018 .68329 L .5893 .68343 L F
0 0 0 r
.58681 .68963 m .5896 .68615 L .5879 .68973 L F
.58708 .68913 m .5896 .68615 L .58681 .68963 L F
.58667 .68962 m .58949 .68643 L .5896 .68615 L F
.477 .3 .561 r
.58949 .68643 m .5893 .68343 L .5896 .68615 L F
.58949 .68643 m .59018 .68329 L .58939 .68478 L F
0 0 0 r
.58667 .68962 m .58708 .68913 L .58681 .68963 L F
.768 .278 .062 r
.5879 .68973 m .59025 .69194 L .58687 .69056 L F
.756 .365 .313 r
.59114 .69118 m .59025 .69194 L .5879 .68973 L F
.731 .877 .948 r
.68376 .53311 m .682 .53441 L .68279 .53224 L F
.68376 .53311 m .682 .53441 L .68279 .53224 L F
.8 .646 .691 r
.78117 .60672 m .78201 .60856 L .77855 .60828 L F
.342 .115 .417 r
.78182 .61057 m .77993 .61182 L .78201 .60856 L F
.797 .677 .733 r
.78201 .60856 m .77993 .61182 L .77855 .60828 L F
.54 .524 .786 r
.78428 .60825 m .78201 .60856 L .78117 .60672 L F
.4 .124 .374 r
.78428 .60825 m .78182 .61057 L .78201 .60856 L F
.859 .987 .845 r
.6494 .53303 m .64988 .53374 L .65203 .53134 L F
.945 .801 .671 r
.6494 .53303 m .65033 .53526 L .64988 .53374 L F
.735 .335 .291 r
.65226 .5361 m .64988 .53374 L .65033 .53526 L F
.841 .961 .626 r
.62245 .4995 m .62061 .50138 L .62078 .49931 L F
.567 .321 .502 r
.62078 .49931 m .62061 .50138 L .62092 .50114 L F
.92 .598 .415 r
.62245 .4995 m .62078 .49931 L .62061 .49727 L F
.841 .961 .626 r
.62245 .4995 m .62 .50324 L .62061 .50138 L F
.567 .321 .502 r
.62078 .49931 m .62092 .50114 L .6233 .49935 L F
.92 .598 .415 r
.62061 .49727 m .62078 .49931 L .61952 .49595 L F
.072 0 .082 r
.69094 .53672 m .69035 .53863 L .68847 .53926 L F
.248 0 .145 r
.69254 .53769 m .69094 .53672 L .69293 .53572 L F
.69254 .53769 m .69035 .53863 L .69094 .53672 L F
.488 .588 .881 r
.45825 .64735 m .45771 .65 L .45614 .64811 L F
.45825 .64735 m .45969 .64986 L .45771 .65 L F
.616 .487 .681 r
.70859 .51145 m .71074 .50898 L .70758 .50825 L F
.70859 .51145 m .71112 .51109 L .71074 .50898 L F
0 0 0 r
.70792 .51325 m .71112 .51109 L .70859 .51145 L F
.589 .072 0 r
.55316 .7144 m .55145 .7146 L .54963 .71405 L F
.69 .23 .154 r
.55542 .71606 m .55145 .7146 L .55316 .7144 L F
.706 .925 .596 r
.35917 .71741 m .35694 .72023 L .35748 .71905 L F
.041 .284 .777 r
.35694 .72023 m .35821 .72092 L .35748 .71905 L F
.296 0 0 r
.25632 .58755 m .26019 .58558 L .25812 .58656 L F
.563 .22 .345 r
.48426 .77335 m .48385 .7751 L .48148 .7744 L F
.421 .093 .301 r
.48426 .77335 m .48629 .77496 L .48385 .7751 L F
.466 0 0 r
.48691 .77534 m .48629 .77496 L .48426 .77335 L F
.516 .825 1 r
.67584 .49402 m .6767 .49231 L .67396 .49212 L F
.67584 .49402 m .67812 .49348 L .6767 .49231 L F
.361 0 0 r
.68847 .53926 m .68755 .54061 L .68519 .54078 L F
0 0 0 r
.68967 .53951 m .68847 .53926 L .69035 .53863 L F
.68967 .53951 m .68755 .54061 L .68847 .53926 L F
.936 .645 .464 r
.60254 .72797 m .6037 .72591 L .60255 .725 L F
.60254 .72797 m .60406 .72843 L .6037 .72591 L F
.55 .411 .645 r
.47847 .79521 m .47543 .79815 L .47443 .7956 L F
0 0 0 r
.47543 .79815 m .47628 .79817 L .47409 .79783 L F
.47543 .79815 m .47758 .79793 L .47628 .79817 L F
.497 .315 .563 r
.33828 .6251 m .33821 .62744 L .33626 .6256 L F
.432 .313 .617 r
.33821 .62744 m .33652 .6283 L .33626 .6256 L F
.467 .312 .587 r
.45612 .77569 m .4581 .77529 L .45801 .77289 L F
0 0 0 r
.64245 .50262 m .64064 .50664 L .64199 .50403 L F
.766 .644 .727 r
.35115 .70861 m .35436 .71009 L .35296 .70889 L F
.35115 .70861 m .35272 .71175 L .35436 .71009 L F
.413 .657 .96 r
.35436 .71009 m .3556 .70858 L .35296 .70889 L F
.759 .583 .659 r
.62019 .53319 m .62141 .53668 L .62355 .53578 L F
.864 .697 .673 r
.54238 .773 m .5426 .77585 L .53903 .77502 L F
.365 0 .028 r
.54256 .77734 m .5426 .77585 L .5449 .77543 L F
.647 .566 .75 r
.5426 .77585 m .54461 .77239 L .54238 .773 L F
.781 .716 .791 r
.60805 .7448 m .61143 .74511 L .61036 .742 L F
.796 .65 .701 r
.60949 .74795 m .61143 .74511 L .60805 .7448 L F
.799 .725 .782 r
.61143 .74511 m .61371 .74213 L .61036 .742 L F
.731 .701 .821 r
.46996 .65558 m .46801 .65676 L .46638 .65496 L F
.715 .669 .804 r
.70165 .49483 m .6991 .49522 L .69796 .49205 L F
.35 .14 .448 r
.55372 .69231 m .5561 .69149 L .55584 .6894 L F
.472 .41 .707 r
.55542 .69227 m .5561 .69149 L .55372 .69231 L F
.499 .583 .871 r
.65203 .53134 m .6545 .53341 L .65432 .53048 L F
0 0 0 r
.6545 .53341 m .65226 .5361 L .65447 .53513 L F
.069 .102 .588 r
.65432 .53048 m .6545 .53341 L .6557 .53177 L F
0 0 .081 r
.6557 .53177 m .6545 .53341 L .65447 .53513 L F
.737 .711 .826 r
.61559 .51134 m .61636 .51427 L .61521 .51267 L F
.836 .879 .873 r
.61636 .51427 m .61266 .5158 L .61521 .51267 L F
.794 .744 .806 r
.61843 .51163 m .61636 .51427 L .61559 .51134 L F
.452 .167 .388 r
.36856 .70646 m .37012 .70808 L .37037 .7058 L F
.36856 .70646 m .36794 .70885 L .37012 .70808 L F
.715 .669 .804 r
.70165 .49483 m .69796 .49205 L .70048 .49172 L F
.564 .621 .868 r
.70274 .49116 m .70165 .49483 L .70048 .49172 L F
.469 .794 .999 r
.28655 .58641 m .2886 .58609 L .29004 .58691 L F
.309 .703 .978 r
.29039 .58604 m .29004 .58691 L .2886 .58609 L F
.29039 .58604 m .29187 .58688 L .29004 .58691 L F
.425 .223 .5 r
.72687 .50301 m .72678 .50518 L .72474 .5058 L F
.371 .243 .574 r
.72678 .50518 m .72529 .50812 L .72474 .5058 L F
.549 .192 .315 r
.54283 .7684 m .54117 .76756 L .54075 .76879 L F
.54283 .7684 m .54352 .76762 L .54117 .76756 L F
.946 .692 .521 r
.60116 .72211 m .60244 .72012 L .6011 .71902 L F
.60116 .72211 m .60254 .72262 L .60244 .72012 L F
.868 .824 .802 r
.66498 .5305 m .66781 .53064 L .66583 .53033 L F
.399 .104 .344 r
.26768 .61717 m .26711 .619 L .26509 .61953 L F
.476 .221 .447 r
.26959 .6166 m .26711 .619 L .26768 .61717 L F
.667 .524 .68 r
.47602 .66982 m .47363 .6702 L .47588 .66736 L F
.586 .561 .793 r
.47698 .67314 m .47363 .6702 L .47602 .66982 L F
.628 .355 .485 r
.59373 .69431 m .59686 .69178 L .59444 .69145 L F
.639 .584 .777 r
.59025 .69194 m .59444 .69145 L .59175 .6953 L F
0 0 .486 r
.59455 .69074 m .59373 .69431 L .59444 .69145 L F
.59428 .69189 m .59491 .69311 L .59373 .69431 L F
.59455 .69074 m .59479 .6923 L .59428 .69189 L F
.59479 .6923 m .59491 .69311 L .59428 .69189 L F
.385 0 0 r
.59114 .69118 m .59367 .69139 L .59025 .69194 L F
.59367 .69139 m .59444 .69145 L .59383 .69152 L F
.59367 .69139 m .59383 .69152 L .59025 .69194 L F
.219 0 0 r
.53062 .72477 m .53379 .72312 L .53146 .72315 L F
.864 .697 .673 r
.54238 .773 m .53903 .77502 L .53887 .77276 L F
.532 .12 .205 r
.53424 .76144 m .53285 .76373 L .53096 .76231 L F
.546 .135 .213 r
.53529 .76348 m .53424 .76144 L .53642 .76173 L F
.53529 .76348 m .53285 .76373 L .53424 .76144 L F
.428 .812 .573 r
.54693 .77192 m .54991 .76971 L .54894 .7721 L F
.555 .83 .482 r
.5523 .76691 m .54991 .76971 L .55273 .76795 L F
.5523 .76691 m .54998 .76959 L .54991 .76971 L F
.725 .696 .823 r
.55145 .76946 m .54991 .76971 L .54998 .76959 L F
.55145 .76946 m .54894 .7721 L .54991 .76971 L F
.457 .251 .511 r
.3899 .67295 m .3899 .67508 L .38785 .67552 L F
.462 .271 .535 r
.38971 .67716 m .38785 .67552 L .3899 .67508 L F
.38971 .67716 m .38767 .67828 L .38785 .67552 L F
.725 .547 .649 r
.66873 .50334 m .67069 .5062 L .67109 .50454 L F
.66873 .50334 m .67109 .50454 L .6688 .50468 L F
.596 .121 .096 r
.56354 .73946 m .56628 .74092 L .56702 .73945 L F
.674 .409 .512 r
.61452 .56691 m .61037 .56898 L .6104 .56754 L F
.382 .069 .305 r
.62446 .53879 m .6265 .53826 L .62707 .53665 L F
.508 .247 .453 r
.6265 .53826 m .62923 .53592 L .62707 .53665 L F
0 0 0 r
.55773 .69598 m .55664 .69717 L .55527 .69804 L F
.29 .089 .426 r
.55664 .69717 m .55359 .69986 L .55527 .69804 L F
.646 .541 .721 r
.52699 .76882 m .52863 .76969 L .52627 .76969 L F
.652 .456 .606 r
.5256 .76385 m .5274 .76886 L .52313 .76734 L F
.5274 .76886 m .52729 .76885 L .52313 .76734 L F
.646 .541 .721 r
.52838 .76713 m .52856 .76897 L .5274 .76886 L F
.516 .383 .638 r
.52838 .76713 m .52742 .76889 L .5274 .76886 L F
.52838 .76713 m .5274 .76886 L .5256 .76385 L F
.684 .485 .611 r
.52627 .76969 m .52313 .76734 L .52729 .76885 L F
.52627 .76969 m .52729 .76885 L .52742 .76889 L F
.646 .541 .721 r
.52838 .76713 m .52752 .76865 L .52699 .76882 L F
.52752 .76865 m .5274 .76886 L .52729 .76885 L F
.52752 .76865 m .52729 .76885 L .52699 .76882 L F
.52856 .76897 m .52863 .76969 L .52699 .76882 L F
.652 .456 .606 r
.5274 .76886 m .52742 .76889 L .52729 .76885 L F
.341 .014 .257 r
.52859 .76167 m .5256 .76385 L .52664 .76257 L F
.52859 .76167 m .52835 .76308 L .5256 .76385 L F
.516 .383 .638 r
.52838 .76713 m .5256 .76385 L .52835 .76308 L F
.87 .597 .522 r
.62965 .53785 m .63249 .53652 L .62923 .53592 L F
.62965 .53785 m .6326 .53881 L .63249 .53652 L F
.272 0 0 r
.68519 .51534 m .6883 .51469 L .68593 .51421 L F
.27 .09 .443 r
.31528 .62511 m .31708 .62127 L .31523 .62284 L F
.877 .856 .817 r
.51329 .73393 m .51372 .73003 L .51317 .73141 L F
.082 0 0 r
.42282 .70343 m .42106 .70456 L .41901 .70501 L F
.075 0 0 r
.42345 .70396 m .42282 .70343 L .42472 .70268 L F
.42345 .70396 m .42106 .70456 L .42282 .70343 L F
.534 .49 .753 r
.3619 .6899 m .36299 .68627 L .36071 .68683 L F
.3619 .6899 m .36384 .68972 L .36299 .68627 L F
.409 .134 .382 r
.34786 .61455 m .34978 .61232 L .34946 .61587 L F
.389 .104 .354 r
.35141 .61115 m .35442 .61053 L .35241 .6108 L F
.372 .143 .431 r
.34978 .61232 m .35241 .6108 L .35219 .61346 L F
.442 .161 .389 r
.34946 .61587 m .34978 .61232 L .35219 .61346 L F
.592 .025 0 r
.57895 .72017 m .58238 .72244 L .58228 .72029 L F
.798 .503 .488 r
.49975 .80623 m .50438 .80912 L .50085 .8097 L F
.6 .224 .301 r
.50085 .8097 m .50438 .80912 L .50268 .81137 L F
.565 .809 .427 r
.50268 .81137 m .50438 .80912 L .50494 .80839 L F
.096 .323 .798 r
.50438 .80912 m .50612 .81098 L .50494 .80839 L F
.462 .833 .585 r
.54581 .77284 m .54693 .77192 L .54461 .77239 L F
.784 .684 .753 r
.59541 .56665 m .5966 .5699 L .59323 .56919 L F
.759 .351 .278 r
.5966 .5699 m .59553 .5713 L .59323 .56919 L F
.744 .664 .772 r
.59541 .56665 m .599 .56712 L .5966 .5699 L F
.744 .331 .268 r
.5966 .5699 m .59874 .57188 L .59553 .5713 L F
.681 .565 .718 r
.599 .56712 m .59858 .56985 L .5966 .5699 L F
.653 .386 .503 r
.59858 .56985 m .59874 .57188 L .5966 .5699 L F
.543 .846 .53 r
.35917 .71741 m .35748 .71905 L .35992 .71655 L F
.55 .338 .545 r
.5846 .71724 m .58757 .71722 L .58661 .71506 L F
.593 .722 .934 r
.28612 .63817 m .28398 .6386 L .2823 .63679 L F
.731 .27 0 r
.62019 .5103 m .61851 .50823 L .61926 .50932 L F
.62019 .5103 m .61931 .50954 L .61851 .50823 L F
.828 .976 .887 r
.62019 .5103 m .61843 .51163 L .61931 .50954 L F
.892 .974 .824 r
.62201 .50621 m .62019 .5103 L .62316 .50744 L F
.62201 .50621 m .61931 .50954 L .62019 .5103 L F
.486 0 0 r
.62019 .5103 m .6239 .51215 L .62427 .51117 L F
.663 .427 .551 r
.61931 .50954 m .6239 .51215 L .62019 .5103 L F
.624 .714 .911 r
.71883 .49413 m .71644 .49472 L .71583 .49374 L F
.407 .083 .3 r
.49923 .73648 m .50156 .73597 L .50206 .73422 L F
.518 .277 .489 r
.50156 .73597 m .50391 .73337 L .50206 .73422 L F
.4 .036 .226 r
.44638 .68985 m .44533 .69152 L .4431 .69196 L F
.662 .404 .519 r
.44875 .68955 m .44533 .69152 L .44638 .68985 L F
.538 .448 .701 r
.47732 .66374 m .4778 .66699 L .47588 .66736 L F
.551 .434 .674 r
.47801 .66925 m .47588 .66736 L .4778 .66699 L F
.47801 .66925 m .47602 .66982 L .47588 .66736 L F
.381 0 .026 r
.63621 .54371 m .63976 .54182 L .63816 .54068 L F
.63621 .54371 m .63875 .54341 L .63976 .54182 L F
.565 .599 .846 r
.63976 .54182 m .64077 .53823 L .63816 .54068 L F
.63976 .54182 m .64213 .54128 L .64077 .53823 L F
.018 0 0 r
.63976 .54182 m .64063 .54249 L .64213 .54128 L F
.63976 .54182 m .63875 .54341 L .64063 .54249 L F
.634 .549 .741 r
.47349 .65861 m .4712 .65923 L .46996 .65558 L F
.615 .554 .763 r
.47476 .66242 m .4712 .65923 L .47349 .65861 L F
.445 .249 .52 r
.77721 .61423 m .777 .61645 L .77503 .61712 L F
.114 0 0 r
.777 .61645 m .77405 .61826 L .77503 .61712 L F
.492 .307 .557 r
.7631 .60316 m .76097 .60637 L .76338 .60583 L F
.542 .485 .742 r
.76097 .60637 m .76397 .60793 L .76338 .60583 L F
.65 .095 0 r
.50863 .73211 m .50808 .73107 L .50653 .73142 L F
.50863 .73211 m .51207 .73412 L .50808 .73107 L F
.97 .859 .673 r
.59974 .71599 m .60159 .71465 L .5991 .71406 L F
.59974 .71599 m .60062 .71629 L .60159 .71465 L F
.552 .653 .902 r
.58076 .7364 m .58166 .73381 L .57936 .73443 L F
.58076 .7364 m .58304 .73617 L .58166 .73381 L F
.25 .359 .78 r
.58076 .7364 m .58348 .73884 L .58304 .73617 L F
.62 .875 .535 r
.69731 .50056 m .69535 .5029 L .6962 .50163 L F
.314 .613 .954 r
.69535 .5029 m .69695 .50282 L .6962 .50163 L F
.171 .663 .919 r
.63037 .52954 m .63372 .53026 L .63162 .53014 L F
.702 .533 .656 r
.61602 .56451 m .61597 .56701 L .61452 .56691 L F
.685 .518 .655 r
.61602 .56451 m .61838 .56423 L .61597 .56701 L F
.663 .311 .365 r
.64948 .51043 m .64641 .51063 L .64714 .5086 L F
.633 .221 0 r
.68297 .5279 m .68305 .52794 L .68073 .52407 L F
.41 .668 .967 r
.68401 .52622 m .68574 .52796 L .68305 .52794 L F
.68401 .52622 m .68305 .52794 L .68304 .52802 L F
.38 .492 .847 r
.68543 .52823 m .68305 .52794 L .68574 .52796 L F
.818 .792 .828 r
.68319 .52774 m .68543 .52823 L .68401 .52622 L F
.633 .221 0 r
.68304 .52802 m .68305 .52794 L .68297 .5279 L F
.818 .792 .828 r
.68342 .52863 m .68543 .52823 L .68282 .52766 L F
.41 .668 .967 r
.68401 .52622 m .68304 .52802 L .68304 .52802 L F
.818 .792 .828 r
.68282 .52766 m .68319 .52774 L .68401 .52622 L F
.633 .221 0 r
.68292 .52794 m .68073 .52407 L .67909 .52534 L F
.818 .792 .828 r
.68175 .52897 m .68342 .52863 L .68297 .5279 L F
.633 .221 0 r
.68304 .52802 m .68297 .5279 L .68292 .52794 L F
.68297 .5279 m .68073 .52407 L .68292 .52794 L F
.818 .792 .828 r
.68215 .52848 m .68297 .5279 L .68282 .52766 L F
.68175 .52897 m .68297 .5279 L .68215 .52848 L F
.633 .221 0 r
.68304 .52802 m .68304 .52802 L .68297 .5279 L F
.663 .281 .312 r
.53291 .74114 m .53217 .74258 L .5296 .74163 L F
.006 0 0 r
.53386 .74139 m .53291 .74114 L .53505 .74214 L F
.53386 .74139 m .53217 .74258 L .53291 .74114 L F
.401 .063 .273 r
.48423 .74573 m .4835 .74734 L .48647 .74535 L F
.738 .63 .739 r
.34527 .70881 m .34924 .70998 L .3475 .70599 L F
0 .145 .68 r
.3475 .70599 m .34924 .70998 L .34939 .70845 L F
.751 .938 .946 r
.34939 .70845 m .34924 .70998 L .35115 .70861 L F
.357 .398 .766 r
.48419 .79058 m .48174 .79032 L .48327 .78858 L F
.92 .676 .183 r
.59752 .70422 m .59774 .70533 L .59796 .70502 L F
.657 .821 .393 r
.5984 .70439 m .59796 .70502 L .59736 .70622 L F
0 0 .406 r
.59796 .70502 m .59815 .70745 L .5972 .70876 L F
.92 .676 .183 r
.59774 .70533 m .59815 .70745 L .59796 .70502 L F
.657 .821 .393 r
.59905 .70326 m .59796 .70502 L .5984 .70439 L F
0 0 0 r
.59966 .70096 m .59915 .70309 L .59905 .70326 L F
.607 .798 .375 r
.59915 .70309 m .59796 .70502 L .59905 .70326 L F
.874 .705 .669 r
.67501 .5051 m .67608 .50777 L .67609 .50459 L F
.019 0 0 r
.28047 .65227 m .28392 .65216 L .28266 .65168 L F
.426 .824 .982 r
.28392 .65216 m .28473 .65132 L .28266 .65168 L F
.28392 .65216 m .28607 .65184 L .28473 .65132 L F
.327 0 0 r
.53096 .76231 m .52835 .76308 L .52859 .76167 L F
.807 .718 .767 r
.55147 .77858 m .55501 .7788 L .5538 .77823 L F
.55147 .77858 m .55272 .78131 L .55501 .7788 L F
.095 .277 .759 r
.55501 .7788 m .55608 .77761 L .5538 .77823 L F
.566 .267 .42 r
.55501 .7788 m .55771 .77874 L .55722 .78057 L F
.095 .277 .759 r
.55501 .7788 m .55722 .78057 L .55608 .77761 L F
.733 .938 .953 r
.68629 .5178 m .68959 .51723 L .68853 .51841 L F
.439 .596 .91 r
.6912 .51567 m .68959 .51723 L .6883 .51469 L F
.291 .351 .753 r
.6912 .51567 m .69181 .51872 L .68959 .51723 L F
.638 .159 .098 r
.68959 .51723 m .69181 .51872 L .68853 .51841 L F
.713 .219 .068 r
.34183 .71856 m .34051 .71906 L .33878 .7174 L F
0 0 0 r
.34267 .71846 m .34051 .71906 L .34183 .71856 L F
.728 .773 .888 r
.48273 .67295 m .47931 .67253 L .48139 .67164 L F
.596 .736 .942 r
.48505 .67246 m .48273 .67295 L .48139 .67164 L F
.088 .062 .529 r
.4843 .67454 m .48273 .67295 L .48505 .67246 L F
.4843 .67454 m .48319 .67562 L .48273 .67295 L F
.037 0 0 r
.29767 .63694 m .29972 .63651 L .30069 .63603 L F
.847 .671 .133 r
.57393 .76143 m .57393 .759 L .57372 .75872 L F
.751 .652 .751 r
.62141 .53668 m .61908 .53936 L .6214 .53931 L F
.612 .406 .578 r
.61887 .54188 m .6214 .53931 L .61908 .53936 L F
.61887 .54188 m .62189 .54175 L .6214 .53931 L F
.698 .608 .753 r
.62141 .53668 m .6214 .53931 L .62446 .53879 L F
.319 .01 .275 r
.62189 .54175 m .62446 .53879 L .6214 .53931 L F
.704 .205 .053 r
.58667 .68325 m .58565 .68364 L .58337 .68225 L F
.342 0 0 r
.5893 .68343 m .58565 .68364 L .58667 .68325 L F
.293 0 0 r
.41661 .69405 m .41884 .6937 L .4203 .69222 L F
.517 .105 .198 r
.41884 .6937 m .42251 .69188 L .4203 .69222 L F
.299 .136 .485 r
.62975 .52278 m .63032 .52513 L .63134 .52141 L F
.533 .351 .58 r
.63092 .5249 m .62969 .52603 L .63068 .52553 L F
.299 .136 .485 r
.63032 .52513 m .63062 .52471 L .63134 .52141 L F
.437 .262 .544 r
.63134 .52141 m .63062 .52471 L .6314 .52367 L F
.533 .351 .58 r
.6312 .52418 m .63022 .52525 L .63092 .5249 L F
.6314 .52367 m .63013 .52535 L .6312 .52418 L F
.437 .262 .544 r
.63062 .52471 m .63043 .52558 L .6314 .52367 L F
.533 .351 .58 r
.63022 .52525 m .63013 .52535 L .63016 .52533 L F
.63022 .52525 m .63016 .52533 L .63092 .5249 L F
.6314 .52367 m .63005 .52539 L .63013 .52535 L F
.581 .306 .464 r
.62684 .52282 m .63013 .52535 L .62975 .52278 L F
.533 .351 .58 r
.63005 .52539 m .62914 .52653 L .63092 .5249 L F
.581 .306 .464 r
.63013 .52535 m .63043 .52558 L .63032 .52513 L F
.63013 .52535 m .63032 .52513 L .62975 .52278 L F
.299 .136 .485 r
.63032 .52513 m .63043 .52558 L .63062 .52471 L F
.533 .351 .58 r
.62969 .52603 m .62914 .52653 L .6295 .5263 L F
.62969 .52603 m .6295 .5263 L .63068 .52553 L F
.676 .176 .05 r
.62568 .52381 m .63 .52542 L .62684 .52282 L F
.533 .351 .58 r
.62914 .52653 m .63005 .52539 L .63043 .52558 L F
.676 .176 .05 r
.63005 .52539 m .63043 .52558 L .63013 .52535 L F
.533 .351 .58 r
.63005 .52539 m .6314 .52367 L .63043 .52558 L F
.792 .941 .589 r
.6314 .52367 m .63068 .52553 L .63261 .52253 L F
.533 .351 .58 r
.63005 .52539 m .63145 .526 L .6314 .52367 L F
.62914 .52653 m .63102 .5261 L .63005 .52539 L F
.676 .176 .05 r
.63017 .52548 m .63043 .52558 L .63005 .52539 L F
.533 .351 .58 r
.63102 .5261 m .63145 .526 L .63005 .52539 L F
.6314 .52367 m .63141 .52422 L .62914 .52653 L F
.645 .588 .776 r
.63017 .52548 m .62914 .52653 L .63043 .52558 L F
.533 .351 .58 r
.63141 .52422 m .63145 .526 L .62914 .52653 L F
.645 .588 .776 r
.62568 .52381 m .62914 .52653 L .63017 .52548 L F
.676 .176 .05 r
.63 .52542 m .63017 .52548 L .63005 .52539 L F
.63 .52542 m .63013 .52535 L .62684 .52282 L F
.308 .134 .474 r
.53582 .80034 m .5343 .80082 L .53401 .80328 L F
.639 .961 .914 r
.66077 .48249 m .66378 .48144 L .661 .48256 L F
.356 .771 .979 r
.50468 .77343 m .50343 .77281 L .50117 .77287 L F
.682 .138 0 r
.50704 .77493 m .50343 .77281 L .50468 .77343 L F
.848 .977 .677 r
.65729 .51689 m .65655 .51642 L .65662 .51561 L F
.833 .526 .47 r
.49024 .803 m .49332 .80394 L .4937 .80604 L F
.957 .772 .612 r
.65308 .52743 m .65453 .52828 L .65315 .52482 L F
.954 .78 .628 r
.65308 .52743 m .65432 .53048 L .65453 .52828 L F
.605 .572 .791 r
.65453 .52828 m .65586 .52432 L .65315 .52482 L F
.65453 .52828 m .65702 .52763 L .65586 .52432 L F
.636 .208 0 r
.65741 .50754 m .65931 .51049 L .65827 .5085 L F
.766 .652 .736 r
.51695 .73935 m .51443 .74179 L .5151 .73992 L F
.491 .42 .704 r
.76281 .60016 m .7631 .60316 L .76535 .60191 L F
.576 .44 .66 r
.76338 .60583 m .76535 .60191 L .7631 .60316 L F
.684 .614 .771 r
.61746 .53662 m .61888 .53706 L .61798 .5341 L F
.734 .562 .659 r
.61556 .53892 m .61888 .53706 L .61746 .53662 L F
.61556 .53892 m .61908 .53936 L .61888 .53706 L F
.667 .604 .775 r
.61798 .5341 m .61888 .53706 L .62141 .53668 L F
.652 .5 .665 r
.61888 .53706 m .61908 .53936 L .62141 .53668 L F
.484 .307 .564 r
.58443 .70972 m .58597 .71116 L .58675 .70966 L F
.445 .306 .598 r
.58443 .70972 m .58413 .71202 L .58597 .71116 L F
.58443 .70972 m .58413 .71202 L .58597 .71116 L F
.064 .255 .747 r
.78197 .59713 m .78398 .59909 L .78314 .60012 L F
.863 .635 .102 r
.78398 .59909 m .78451 .60256 L .78314 .60012 L F
.305 .21 .579 r
.78451 .60256 m .78398 .60349 L .78314 .60012 L F
.178 0 .258 r
.39204 .67252 m .3899 .67508 L .3899 .67295 L F
0 0 0 r
.74352 .59643 m .74441 .59528 L .74624 .59407 L F
.63 .262 .327 r
.51864 .76747 m .51716 .76948 L .51486 .76763 L F
.682 .341 .39 r
.52064 .76756 m .51716 .76948 L .51864 .76747 L F
.867 .813 .794 r
.61683 .53321 m .61746 .53662 L .61798 .5341 L F
.61683 .53321 m .6151 .53573 L .61746 .53662 L F
.898 .812 .754 r
.6151 .53573 m .61556 .53892 L .61746 .53662 L F
.367 0 .107 r
.43016 .68811 m .4324 .68772 L .43069 .68697 L F
.41 0 0 r
.43069 .68697 m .4324 .68772 L .43309 .68696 L F
.713 .488 .583 r
.49004 .77288 m .49028 .77541 L .48691 .77534 L F
.341 .106 .406 r
.49245 .77282 m .49028 .77541 L .49004 .77288 L F
.712 .21 .04 r
.56557 .72015 m .56439 .72041 L .56273 .71919 L F
.841 .38 .092 r
.56557 .72015 m .56515 .72132 L .56439 .72041 L F
.56557 .72015 m .56724 .72283 L .56515 .72132 L F
0 .161 .699 r
.56898 .74453 m .57169 .74739 L .57165 .74799 L F
.12 .521 .913 r
.57165 .74799 m .57169 .74739 L .57139 .74699 L F
0 0 .254 r
.57164 .74773 m .57165 .74799 L .57139 .74699 L F
.57164 .74773 m .57223 .74978 L .57165 .74799 L F
.142 .644 .907 r
.305 .59057 m .30687 .59074 L .30845 .59135 L F
.433 .743 .992 r
.30914 .59015 m .30845 .59135 L .30687 .59074 L F
.30914 .59015 m .31055 .59122 L .30845 .59135 L F
.539 .765 .981 r
.67763 .48342 m .67668 .48533 L .67493 .48316 L F
.67763 .48342 m .67894 .48482 L .67668 .48533 L F
.577 .407 .614 r
.71953 .59688 m .72135 .59991 L .72132 .59739 L F
.71953 .59688 m .71898 .60053 L .72135 .59991 L F
.516 .566 .845 r
.46547 .65216 m .4643 .6545 L .46349 .65232 L F
.46547 .65216 m .46638 .65496 L .4643 .6545 L F
.483 .774 .996 r
.3085 .60204 m .31092 .60302 L .30933 .60213 L F
.505 .813 1 r
.30933 .60213 m .31092 .60302 L .313 .60254 L F
.35 .275 .63 r
.45801 .77289 m .45945 .76945 L .45739 .77049 L F
.516 .261 .467 r
.43849 .68381 m .44072 .68348 L .44103 .68134 L F
.478 .18 .382 r
.44072 .68348 m .44368 .68046 L .44103 .68134 L F
.674 .968 .925 r
.37704 .72009 m .38094 .71869 L .37951 .71713 L F
.588 .901 .633 r
.38111 .71773 m .38075 .71807 L .38079 .7183 L F
0 .263 .702 r
.38084 .71857 m .38079 .7183 L .37951 .71713 L F
.75 .716 .821 r
.3748 .71857 m .37704 .72009 L .37951 .71713 L F
.3748 .71857 m .37951 .71713 L .37699 .7162 L F
.745 .535 .609 r
.38079 .7183 m .37699 .7162 L .37951 .71713 L F
.38079 .7183 m .37682 .71845 L .37699 .7162 L F
.672 .302 .337 r
.38079 .7183 m .37842 .72022 L .37682 .71845 L F
.588 .901 .633 r
.38075 .71807 m .37842 .72022 L .38079 .7183 L F
0 .263 .702 r
.38094 .71869 m .38079 .7183 L .38084 .71857 L F
.38094 .71869 m .38321 .7199 L .38079 .7183 L F
.883 .84 .798 r
.60996 .52285 m .60668 .52484 L .60863 .52181 L F
.60996 .52285 m .60807 .52577 L .60668 .52484 L F
.793 .608 .65 r
.57971 .67834 m .57649 .68048 L .57787 .67895 L F
.331 .007 .257 r
.47084 .75527 m .4734 .753 L .47137 .75354 L F
.399 .137 .396 r
.58888 .73654 m .59091 .73586 L .59036 .73369 L F
.104 0 .414 r
.59036 .73369 m .5919 .73353 L .59139 .73095 L F
.573 .475 .705 r
.59091 .73586 m .5919 .73353 L .59036 .73369 L F
.605 .469 .67 r
.76434 .59502 m .76717 .59684 L .76656 .59472 L F
.76434 .59502 m .76473 .59742 L .76717 .59684 L F
0 .474 .795 r
.63316 .54063 m .63684 .54201 L .6326 .53881 L F
0 0 0 r
.63684 .54201 m .63714 .53898 L .63663 .53824 L F
.63684 .54201 m .63816 .54068 L .63714 .53898 L F
.63684 .54201 m .6373 .54198 L .63816 .54068 L F
.906 .983 .733 r
.6362 .54365 m .63621 .54371 L .63816 .54068 L F
0 0 0 r
.6373 .54198 m .63731 .54198 L .63816 .54068 L F
0 .474 .795 r
.63316 .54063 m .6373 .54198 L .63684 .54201 L F
.906 .983 .733 r
.63701 .5418 m .6373 .54198 L .63816 .54068 L F
0 .474 .795 r
.6373 .54198 m .63731 .54198 L .6373 .54198 L F
.6373 .54198 m .6373 .54198 L .63684 .54201 L F
.906 .983 .733 r
.63614 .54265 m .6362 .54365 L .6373 .54198 L F
.63614 .54265 m .6373 .54198 L .6373 .54198 L F
.693 .224 .133 r
.6373 .54198 m .63614 .54265 L .63731 .54198 L F
.63316 .54063 m .63614 .54265 L .6373 .54198 L F
.906 .983 .733 r
.63614 .54265 m .6373 .54198 L .63701 .5418 L F
.929 .752 .641 r
.4988 .77858 m .50046 .78039 L .50062 .77632 L F
.4988 .77858 m .50062 .77632 L .49922 .77911 L F
.261 .227 .63 r
.50165 .77525 m .50307 .77652 L .50062 .77632 L F
.26 0 .165 r
.50307 .77652 m .49922 .77911 L .50062 .77632 L F
.491 .492 .785 r
.38801 .6832 m .38715 .68684 L .38593 .68361 L F
.38801 .6832 m .38934 .68694 L .38715 .68684 L F
.593 .542 .767 r
.39038 .68988 m .38715 .68684 L .38934 .68694 L F
.923 .595 .133 r
.65761 .49774 m .65858 .50031 L .65794 .49994 L F
0 0 .156 r
.65858 .50031 m .65725 .50304 L .65898 .50139 L F
.65725 .50304 m .65712 .5033 L .65741 .503 L F
.65725 .50304 m .65741 .503 L .65898 .50139 L F
.41 .451 .793 r
.65898 .50139 m .65712 .5033 L .66026 .50367 L F
0 .399 .839 r
.65576 .50063 m .65924 .50234 L .6597 .50307 L F
.903 .887 .806 r
.65916 .50242 m .6597 .50307 L .65924 .50234 L F
.244 .6 .951 r
.66019 .50365 m .65809 .50286 L .6597 .50307 L F
.65809 .50286 m .65854 .50276 L .6597 .50307 L F
.66026 .50367 m .65712 .5033 L .65617 .50214 L F
0 .399 .839 r
.65576 .50063 m .6597 .50307 L .65617 .50214 L F
.903 .887 .806 r
.65638 .50544 m .6597 .50307 L .65916 .50242 L F
.244 .6 .951 r
.66026 .50367 m .66019 .50365 L .65977 .50314 L F
.66026 .50367 m .65977 .50314 L .65978 .50315 L F
.877 .441 .074 r
.66122 .50447 m .66009 .50385 L .65978 .50315 L F
.66122 .50447 m .65898 .50139 L .66026 .50367 L F
.66079 .50388 m .65978 .50315 L .65898 .50139 L F
.66122 .50447 m .65978 .50315 L .66079 .50388 L F
.703 .323 0 r
.65931 .5024 m .66009 .50385 L .65933 .50249 L F
.65898 .50139 m .65978 .50315 L .65931 .5024 L F
.244 .6 .951 r
.65977 .50314 m .65977 .50314 L .6597 .50307 L F
.65978 .50315 m .65977 .50314 L .65977 .50314 L F
.784 .969 .67 r
.65752 .50682 m .66015 .5038 L .6597 .50307 L F
.703 .323 0 r
.65978 .50315 m .65978 .50315 L .65977 .50314 L F
.244 .6 .951 r
.65978 .50315 m .65978 .50315 L .65977 .50314 L F
.784 .969 .67 r
.66015 .5038 m .66026 .50367 L .65977 .50314 L F
.66015 .5038 m .65977 .50314 L .6597 .50307 L F
.703 .323 0 r
.65977 .50314 m .66009 .50385 L .65931 .5024 L F
.65978 .50315 m .66009 .50385 L .65977 .50314 L F
.244 .6 .951 r
.65809 .50286 m .65617 .50214 L .65854 .50276 L F
0 0 .156 r
.65858 .50031 m .65898 .50139 L .65794 .49994 L F
.549 .335 .541 r
.5846 .71724 m .58538 .71963 L .58757 .71722 L F
.518 .535 .813 r
.53622 .74519 m .53723 .74225 L .53505 .74214 L F
.606 .395 .57 r
.53622 .74519 m .53861 .74734 L .53826 .74497 L F
.53622 .74519 m .5362 .74761 L .53861 .74734 L F
0 0 0 r
.63316 .55734 m .63121 .55867 L .63143 .55811 L F
.592 .563 .79 r
.69746 .49101 m .69563 .49266 L .69511 .49147 L F
.69746 .49101 m .69796 .49205 L .69563 .49266 L F
.225 .744 .754 r
.26224 .58546 m .26432 .58494 L .26595 .58468 L F
.409 .839 .952 r
.26432 .58494 m .2678 .5847 L .26595 .58468 L F
.483 .315 .577 r
.76281 .60016 m .76483 .59965 L .76473 .59742 L F
.491 .42 .704 r
.76281 .60016 m .76535 .60191 L .76483 .59965 L F
.519 .878 .647 r
.63068 .52553 m .62914 .52653 L .62767 .52787 L F
.556 .885 .989 r
.62914 .52653 m .62679 .52718 L .62767 .52787 L F
.555 .547 .8 r
.62848 .53245 m .63157 .53316 L .63037 .52954 L F
.607 .444 .634 r
.62848 .53245 m .62923 .53592 L .63157 .53316 L F
.551 .587 .843 r
.6371 .53031 m .6392 .53242 L .6394 .53012 L F
.928 .808 .706 r
.60807 .52577 m .60733 .5278 L .60668 .52484 L F
.201 .656 .944 r
.39238 .84014 m .39251 .84042 L .39013 .83939 L F
.576 .532 .768 r
.54072 .74195 m .53805 .7412 L .53948 .73984 L F
.685 .161 0 r
.59752 .6926 m .59915 .69427 L .60028 .69496 L F
.915 .681 .182 r
.59915 .69427 m .59975 .69735 L .60028 .69496 L F
.735 .633 .746 r
.68811 .49746 m .69107 .49813 L .69016 .49617 L F
.626 .582 .785 r
.69016 .49617 m .69107 .49813 L .69337 .49754 L F
.489 .219 .432 r
.69765 .52813 m .69726 .52999 L .69504 .53048 L F
.368 .113 .391 r
.69939 .52898 m .69765 .52813 L .69967 .52723 L F
.69939 .52898 m .69726 .52999 L .69765 .52813 L F
.54 .524 .786 r
.78428 .60825 m .78117 .60672 L .78337 .60571 L F
.836 .508 0 r
.56791 .74174 m .56863 .74473 L .56898 .74453 L F
.706 .179 0 r
.56959 .74596 m .56898 .74453 L .56863 .74473 L F
.56959 .74596 m .57169 .74739 L .56898 .74453 L F
.601 .4 .581 r
.61838 .56423 m .61844 .56695 L .61597 .56701 L F
.615 .42 .595 r
.6208 .56391 m .61844 .56695 L .61838 .56423 L F
.726 .665 .789 r
.49184 .78716 m .49316 .78691 L .49154 .78688 L F
.804 .564 .576 r
.49316 .78691 m .49219 .78931 L .49154 .78688 L F
.49316 .78691 m .49359 .78968 L .49219 .78931 L F
.595 .664 .887 r
.49397 .78452 m .49316 .78691 L .49184 .78716 L F
.49397 .78452 m .49568 .78689 L .49316 .78691 L F
.619 .437 .614 r
.49568 .78689 m .49359 .78968 L .49316 .78691 L F
.637 .834 .976 r
.53953 .73643 m .53738 .73733 L .53565 .73644 L F
.07 0 .15 r
.72325 .51384 m .72297 .51579 L .72095 .51669 L F
.063 0 .134 r
.72297 .51579 m .72069 .51852 L .72095 .51669 L F
0 0 .51 r
.65317 .49903 m .65346 .50048 L .65223 .49711 L F
.15 .393 .842 r
.65576 .50063 m .65346 .50048 L .65317 .49903 L F
.65576 .50063 m .65617 .50214 L .65346 .50048 L F
0 0 .406 r
.59796 .70502 m .5972 .70876 L .59736 .70622 L F
.931 .585 .151 r
.66248 .51784 m .66296 .51701 L .66193 .51679 L F
.66248 .51784 m .66346 .51909 L .66296 .51701 L F
.628 .752 .937 r
.77245 .57917 m .77006 .5811 L .76908 .57973 L F
.77245 .57917 m .77248 .58045 L .77006 .5811 L F
.593 .515 .736 r
.47931 .67253 m .47698 .67314 L .47602 .66982 L F
.859 .987 .845 r
.6494 .53303 m .65203 .53134 L .65085 .53144 L F
0 0 0 r
.65203 .53134 m .65335 .53114 L .65085 .53144 L F
.65203 .53134 m .65432 .53048 L .65335 .53114 L F
.095 0 0 r
.55858 .6965 m .55773 .69598 L .55952 .69476 L F
.55858 .6965 m .55664 .69717 L .55773 .69598 L F
0 0 0 r
.62734 .51568 m .62756 .51581 L .6254 .51661 L F
.684 .5 .632 r
.59858 .56985 m .60232 .57219 L .59874 .57188 L F
.59858 .56985 m .60237 .56977 L .60232 .57219 L F
0 0 0 r
.63316 .55734 m .63407 .55592 L .63588 .55482 L F
.989 .731 .432 r
.64678 .5326 m .64593 .53027 L .64291 .53098 L F
0 0 0 r
.64291 .53098 m .64414 .53109 L .64192 .53203 L F
.64291 .53098 m .64593 .53027 L .64414 .53109 L F
.32 0 0 r
.53981 .76231 m .53841 .76224 L .53642 .76173 L F
.612 .696 .904 r
.73642 .61367 m .7397 .61469 L .73876 .61326 L F
.606 .718 .923 r
.73876 .61326 m .7397 .61469 L .74207 .61414 L F
.871 .857 .824 r
.61854 .53165 m .62019 .53319 L .62016 .53112 L F
.809 .846 .878 r
.61683 .53321 m .62019 .53319 L .61854 .53165 L F
.61683 .53321 m .61798 .5341 L .62019 .53319 L F
.667 .604 .775 r
.61798 .5341 m .62141 .53668 L .62019 .53319 L F
.742 .586 .681 r
.62019 .53319 m .62234 .53 L .62016 .53112 L F
.946 .76 .296 r
.59401 .68578 m .59434 .68949 L .59457 .68689 L F
.682 .341 .39 r
.52064 .76756 m .52016 .76972 L .51716 .76948 L F
.797 .593 .625 r
.52313 .76734 m .52016 .76972 L .52064 .76756 L F
.172 0 .073 r
.56885 .77275 m .56818 .77397 L .56574 .77553 L F
.51 .059 .115 r
.56885 .77275 m .56917 .77454 L .56818 .77397 L F
.744 .447 .48 r
.50799 .81195 m .50997 .81228 L .50977 .81437 L F
.532 .176 .308 r
.50997 .81228 m .51198 .81382 L .50977 .81437 L F
.50997 .81228 m .51337 .81184 L .51198 .81382 L F
.554 .367 .583 r
.72913 .5002 m .72931 .50258 L .72687 .50301 L F
.536 .313 .523 r
.72931 .50258 m .72678 .50518 L .72687 .50301 L F
0 .311 .792 r
.49171 .7864 m .49184 .78716 L .49154 .78688 L F
.776 .997 .817 r
.49397 .78452 m .49184 .78716 L .49171 .7864 L F
0 0 0 r
.65771 .54462 m .65432 .54607 L .65469 .54522 L F
.65771 .54462 m .65691 .54502 L .65432 .54607 L F
.461 .863 .688 r
.65937 .5434 m .65771 .54462 L .65998 .54428 L F
.65937 .5434 m .65691 .54502 L .65771 .54462 L F
.742 .778 .882 r
.56618 .76686 m .5695 .76712 L .56697 .76864 L F
.56618 .76686 m .5695 .76712 L .56697 .76864 L F
.668 .574 .74 r
.5695 .76712 m .57001 .77063 L .56697 .76864 L F
.234 0 0 r
.51486 .76763 m .51368 .76917 L .51131 .76974 L F
.669 .215 .165 r
.51486 .76763 m .51716 .76948 L .51368 .76917 L F
.658 .708 .885 r
.71431 .49051 m .71299 .49435 L .71213 .49154 L F
.71431 .49051 m .71583 .49374 L .71299 .49435 L F
.471 .826 .996 r
.76548 .58903 m .76704 .58776 L .76455 .58771 L F
.76548 .58903 m .76842 .58835 L .76704 .58776 L F
.63 .099 0 r
.48553 .79261 m .4879 .79489 L .48733 .79423 L F
.627 .097 0 r
.4879 .79489 m .48939 .79611 L .48733 .79423 L F
.314 .276 .655 r
.7246 .51015 m .72535 .51313 L .72325 .51384 L F
.027 0 .138 r
.72466 .51442 m .72325 .51384 L .72535 .51313 L F
.72466 .51442 m .72297 .51579 L .72325 .51384 L F
.597 .397 .582 r
.5561 .69149 m .55849 .68894 L .55584 .6894 L F
.821 .51 .464 r
.50701 .75354 m .50505 .75576 L .509 .75598 L F
.381 .044 .263 r
.50391 .73337 m .50653 .73142 L .50415 .73125 L F
.656 .45 .593 r
.51543 .80918 m .51554 .81159 L .51337 .81184 L F
.872 .489 .012 r
.52789 .73763 m .52679 .73644 L .5247 .73607 L F
.52789 .73763 m .52835 .73921 L .52679 .73644 L F
0 .101 .599 r
.46012 .78748 m .45988 .78716 L .45823 .78711 L F
.46012 .78748 m .46183 .78905 L .45988 .78716 L F
.742 .425 .447 r
.4879 .79489 m .49136 .79739 L .48939 .79611 L F
.14 0 .048 r
.31707 .64489 m .3158 .64711 L .31418 .64738 L F
.294 0 .131 r
.31786 .64645 m .31707 .64489 L .3191 .644 L F
.31786 .64645 m .3158 .64711 L .31707 .64489 L F
.658 .763 .927 r
.46883 .65383 m .46996 .65558 L .46638 .65496 L F
.69 .777 .917 r
.47247 .65442 m .46996 .65558 L .46883 .65383 L F
.663 .649 .826 r
.47247 .65442 m .47336 .65629 L .46996 .65558 L F
.634 .549 .741 r
.47349 .65861 m .46996 .65558 L .47336 .65629 L F
.564 .766 .973 r
.73108 .49828 m .72913 .5002 L .72865 .49898 L F
.73108 .49828 m .73196 .4997 L .72913 .5002 L F
.501 .328 .579 r
.73156 .50185 m .72913 .5002 L .73196 .4997 L F
.73156 .50185 m .72931 .50258 L .72913 .5002 L F
.732 .628 .743 r
.49949 .80318 m .49753 .80647 L .49975 .80623 L F
.875 .653 .598 r
.49975 .80623 m .50085 .8097 L .49721 .80849 L F
.49975 .80623 m .49721 .80849 L .49982 .8082 L F
.766 .467 .48 r
.50247 .80601 m .49949 .80318 L .49975 .80623 L F
.746 .527 .598 r
.49982 .8082 m .50247 .80601 L .49975 .80623 L F
.672 .507 .653 r
.58619 .72597 m .58726 .72835 L .58699 .72569 L F
.58619 .72597 m .58492 .72883 L .58726 .72835 L F
.636 .347 .463 r
.51474 .7536 m .51464 .75582 L .51696 .75569 L F
.798 .674 .727 r
.48206 .78615 m .48442 .78702 L .48411 .78411 L F
.824 .47 .386 r
.48327 .78858 m .48442 .78702 L .48206 .78615 L F
.576 .576 .815 r
.48442 .78702 m .48533 .78341 L .48411 .78411 L F
.608 .841 .465 r
.48442 .78702 m .48661 .78409 L .48671 .78663 L F
.576 .576 .815 r
.48442 .78702 m .48671 .78663 L .48533 .78341 L F
.5 .663 .935 r
.35286 .59955 m .35083 .59972 L .34893 .5977 L F
.319 .01 .275 r
.62189 .54175 m .62374 .54105 L .62446 .53879 L F
.471 .148 .337 r
.62446 .53879 m .6269 .53933 L .6265 .53826 L F
.62446 .53879 m .62374 .54105 L .6269 .53933 L F
.822 .483 0 r
.66471 .52442 m .66419 .52258 L .66362 .52165 L F
.942 .694 .224 r
.66362 .52165 m .66419 .52258 L .66346 .51909 L F
.822 .483 0 r
.66471 .52442 m .66419 .52258 L .66362 .52165 L F
.886 .987 .806 r
.58719 .56742 m .58994 .56653 L .58742 .56968 L F
.669 .521 .676 r
.58994 .56653 m .59071 .56967 L .58742 .56968 L F
.652 .507 .674 r
.58994 .56653 m .59323 .56919 L .59071 .56967 L F
.58994 .56653 m .59314 .56694 L .59323 .56919 L F
.015 0 0 r
.59087 .56659 m .58994 .56653 L .58719 .56742 L F
.619 .61 .819 r
.59245 .56637 m .59314 .56694 L .58994 .56653 L F
.015 0 0 r
.59087 .56659 m .59245 .56637 L .58994 .56653 L F
.607 .667 .882 r
.68134 .48425 m .6798 .48668 L .67894 .48482 L F
.68134 .48425 m .68208 .48605 L .6798 .48668 L F
.703 .762 .898 r
.58667 .5681 m .58742 .56968 L .58403 .56899 L F
.791 .631 .683 r
.58403 .56899 m .58742 .56968 L .58539 .57235 L F
.754 .576 .655 r
.58742 .56968 m .5881 .57197 L .58539 .57235 L F
.886 .987 .806 r
.58719 .56742 m .58742 .56968 L .58667 .5681 L F
.661 .449 .586 r
.58742 .56968 m .59048 .57166 L .5881 .57197 L F
.58742 .56968 m .59071 .56967 L .59048 .57166 L F
.97 .906 .554 r
.59975 .69735 m .59839 .69918 L .59966 .70096 L F
.98 .763 .35 r
.59839 .69918 m .59915 .70309 L .59966 .70096 L F
.492 .238 .458 r
.44368 .68046 m .4459 .68016 L .44618 .67823 L F
.559 .308 .492 r
.4459 .68016 m .44851 .67793 L .44618 .67823 L F
.024 0 0 r
.70742 .49567 m .70887 .49511 L .70758 .4944 L F
.70742 .49567 m .70957 .49541 L .70887 .49511 L F
0 0 .148 r
.70887 .49511 m .71094 .48995 L .71213 .49154 L F
.70887 .49511 m .70957 .49541 L .71094 .48995 L F
.903 .721 .646 r
.6062 .73626 m .60907 .73399 L .60581 .73349 L F
.6062 .73626 m .60869 .7366 L .60907 .73399 L F
.483 .808 1 r
.33869 .59384 m .33806 .59501 L .33663 .59397 L F
.33869 .59384 m .34013 .59461 L .33806 .59501 L F
.971 .688 .28 r
.52142 .77245 m .52271 .77004 L .52489 .77238 L F
.52142 .77245 m .52016 .76972 L .52271 .77004 L F
.52142 .77245 m .52082 .77252 L .52016 .76972 L F
.493 .12 .26 r
.2798 .60806 m .2785 .61047 L .27631 .6106 L F
.22 0 0 r
.28286 .60668 m .28227 .60771 L .2798 .60806 L F
.519 .23 .416 r
.28227 .60771 m .2785 .61047 L .2798 .60806 L F
.744 .439 .465 r
.48107 .80057 m .48456 .80077 L .48492 .80278 L F
.704 .411 .476 r
.48456 .80077 m .48788 .80303 L .48492 .80278 L F
.593 .515 .736 r
.47931 .67253 m .47602 .66982 L .47801 .66925 L F
.639 .635 .83 r
.36911 .71409 m .37054 .71727 L .37297 .71661 L F
.807 .747 .796 r
.37038 .71958 m .37297 .71661 L .37054 .71727 L F
.793 .608 .65 r
.57971 .67834 m .57943 .68162 L .57649 .68048 L F
.647 .478 .641 r
.58279 .68039 m .57971 .67834 L .5821 .67809 L F
.694 .592 .738 r
.68352 .50324 m .68493 .49908 L .68234 .49983 L F
.68352 .50324 m .68547 .50203 L .68493 .49908 L F
.339 0 0 r
.52724 .80895 m .52902 .80639 L .52851 .80772 L F
.52691 .80926 m .52714 .80895 L .52724 .80895 L F
.52714 .80895 m .52902 .80639 L .52724 .80895 L F
.758 .416 .406 r
.52851 .80772 m .52902 .80639 L .52565 .80607 L F
0 0 0 r
.52575 .81117 m .52691 .80926 L .52724 .80895 L F
.52768 .80876 m .52724 .80895 L .52851 .80772 L F
.52575 .81117 m .52724 .80895 L .52768 .80876 L F
.52575 .81117 m .52651 .81021 L .5275 .8106 L F
.52651 .81021 m .52851 .80772 L .528 .80918 L F
.52651 .81021 m .528 .80918 L .5275 .8106 L F
.758 .416 .406 r
.52851 .80772 m .52565 .80607 L .52806 .809 L F
.52851 .80772 m .52806 .809 L .52821 .80918 L F
0 0 0 r
.5275 .8106 m .52806 .809 L .52781 .8105 L F
.52806 .809 m .52851 .80772 L .52817 .80907 L F
0 .207 .729 r
.52816 .80907 m .52821 .80918 L .52806 .809 L F
0 0 0 r
.52806 .809 m .52817 .80907 L .52781 .8105 L F
0 .207 .729 r
.52809 .8089 m .52816 .80907 L .52798 .8089 L F
.52816 .80907 m .52806 .809 L .52798 .8089 L F
.562 .075 .056 r
.53105 .8057 m .53253 .80769 L .53039 .80843 L F
.37 .097 .363 r
.53039 .80843 m .52851 .80772 L .52821 .80918 L F
.758 .735 .831 r
.52818 .80905 m .52821 .80918 L .52816 .80907 L F
.38 .076 .318 r
.52781 .8105 m .52818 .80905 L .53039 .80843 L F
.37 .097 .363 r
.53039 .80843 m .52821 .80918 L .52871 .80868 L F
.758 .735 .831 r
.52871 .80868 m .52821 .80918 L .52818 .80905 L F
.38 .076 .318 r
.52818 .80905 m .52955 .80811 L .53039 .80843 L F
.37 .097 .363 r
.53039 .80843 m .52871 .80868 L .53106 .80635 L F
.38 .076 .318 r
.52871 .80868 m .52851 .80772 L .52955 .80811 L F
.52818 .80905 m .52825 .80875 L .52871 .80868 L F
.52825 .80875 m .52851 .80772 L .52871 .80868 L F
.758 .735 .831 r
.52872 .80868 m .52871 .80868 L .52818 .80905 L F
.53106 .80635 m .52872 .80868 L .52691 .80602 L F
.52872 .80868 m .52816 .80907 L .52691 .80602 L F
0 .207 .729 r
.52691 .80602 m .52798 .80864 L .52565 .80607 L F
.52798 .80864 m .52809 .8089 L .5279 .80867 L F
.52798 .80864 m .5279 .80867 L .52565 .80607 L F
.52809 .8089 m .52798 .8089 L .52565 .80607 L F
.445 .53 .851 r
.47472 .65478 m .47336 .65629 L .47247 .65442 L F
.589 .447 .655 r
.47597 .65805 m .47336 .65629 L .47472 .65478 L F
.47597 .65805 m .47349 .65861 L .47336 .65629 L F
.134 .561 .924 r
.27253 .58397 m .2717 .58462 L .26999 .58433 L F
.27253 .58397 m .27395 .58509 L .2717 .58462 L F
.056 0 .201 r
.77891 .61332 m .777 .61645 L .77721 .61423 L F
.816 .717 .755 r
.59798 .54352 m .59872 .54153 L .5997 .54474 L F
.835 .707 .723 r
.59798 .54352 m .5997 .54474 L .59822 .54773 L F
.562 0 0 r
.62427 .51117 m .62553 .5124 L .62658 .51111 L F
.62427 .51117 m .6239 .51215 L .62553 .5124 L F
.799 .734 .792 r
.61843 .51163 m .61559 .51134 L .61851 .50823 L F
.105 .141 .615 r
.61931 .50954 m .61843 .51163 L .61851 .50823 L F
.381 .825 .945 r
.51683 .77272 m .51528 .7725 L .51753 .77216 L F
.096 .364 .83 r
.51753 .77216 m .51913 .77432 L .51683 .77272 L F
.623 .391 .545 r
.56125 .77584 m .56101 .7784 L .55771 .77874 L F
.777 .528 .559 r
.56125 .77584 m .56355 .77875 L .56101 .7784 L F
.73 .527 .617 r
.56389 .77812 m .56355 .77875 L .56125 .77584 L F
.596 .534 .756 r
.72026 .6058 m .72173 .60208 L .71932 .60257 L F
.72026 .6058 m .72266 .60529 L .72173 .60208 L F
.973 .753 .545 r
.58294 .73145 m .58489 .73114 L .58316 .73078 L F
.58294 .73145 m .58481 .73366 L .58489 .73114 L F
.691 .595 .744 r
.58492 .72883 m .58489 .73114 L .58726 .72835 L F
.075 0 0 r
.6476 .52948 m .64593 .53027 L .64695 .52928 L F
.733 .991 .847 r
.65073 .52677 m .6476 .52948 L .64695 .52928 L F
.603 .616 .837 r
.50226 .78817 m .49928 .78944 L .49802 .78643 L F
.643 .823 .97 r
.55142 .7851 m .55397 .78683 L .55057 .78692 L F
.741 .622 .727 r
.55397 .78683 m .55161 .79004 L .55057 .78692 L F
.365 .711 .986 r
.55506 .78591 m .55397 .78683 L .55142 .7851 L F
.362 .705 .985 r
.55615 .78667 m .55397 .78683 L .55506 .78591 L F
.485 .369 .647 r
.55634 .7892 m .55397 .78683 L .55615 .78667 L F
.55634 .7892 m .55451 .79013 L .55397 .78683 L F
.628 .355 .485 r
.59373 .69431 m .59608 .69421 L .59686 .69178 L F
.721 .455 .523 r
.59366 .69579 m .59608 .69421 L .59373 .69431 L F
0 0 0 r
.59373 .69431 m .59491 .69311 L .59392 .69491 L F
.162 .303 .761 r
.59284 .69786 m .59366 .69579 L .59316 .69566 L F
.963 .68 .451 r
.59025 .69194 m .59175 .6953 L .5901 .69434 L F
.708 .377 .416 r
.59316 .69566 m .5901 .69434 L .59175 .6953 L F
0 0 0 r
.59373 .69431 m .59327 .69564 L .59366 .69579 L F
.708 .377 .416 r
.59366 .69579 m .59327 .69564 L .59316 .69566 L F
0 0 0 r
.59327 .69564 m .59284 .6969 L .59366 .69579 L F
.708 .377 .416 r
.59366 .69579 m .59329 .69564 L .59327 .69564 L F
.59329 .69564 m .5901 .69434 L .59316 .69566 L F
0 0 0 r
.59332 .6955 m .59392 .69491 L .59355 .6956 L F
.59327 .69564 m .59329 .69564 L .59284 .6969 L F
.162 .303 .761 r
.59227 .69652 m .59316 .69566 L .59175 .6953 L F
.59284 .69786 m .59316 .69566 L .59227 .69652 L F
.992 .796 .541 r
.59284 .69786 m .59178 .69763 L .59282 .69661 L F
.59326 .6968 m .59282 .69661 L .59366 .69579 L F
.59284 .69786 m .59282 .69661 L .59326 .6968 L F
0 0 0 r
.59178 .69763 m .59284 .6969 L .59366 .69579 L F
.783 .872 .439 r
.59058 .69764 m .59073 .6968 L .59125 .69608 L F
0 0 0 r
.59125 .69608 m .59073 .6968 L .59113 .69629 L F
.635 .093 0 r
.5901 .69434 m .59225 .69636 L .59109 .69584 L F
.59225 .69636 m .59284 .6969 L .59109 .69584 L F
.708 .377 .416 r
.59329 .69564 m .59284 .6969 L .5901 .69434 L F
0 0 0 r
.59373 .69431 m .59392 .69491 L .59332 .6955 L F
.635 .093 0 r
.59131 .69597 m .59284 .6969 L .59125 .69608 L F
.708 .377 .416 r
.59366 .69579 m .59284 .6969 L .59329 .69564 L F
0 0 0 r
.59329 .69564 m .59355 .6956 L .59284 .6969 L F
.59332 .6955 m .59355 .6956 L .59327 .69564 L F
.216 0 0 r
.59491 .69311 m .59125 .69608 L .59284 .6969 L F
.59491 .69311 m .5937 .69491 L .59125 .69608 L F
.715 .641 .774 r
.59125 .69608 m .5937 .69491 L .59226 .69182 L F
0 0 0 r
.59125 .69608 m .59268 .69432 L .5937 .69491 L F
.59125 .69608 m .59113 .69629 L .59268 .69432 L F
.635 .093 0 r
.59109 .69584 m .59131 .69597 L .59125 .69608 L F
.992 .796 .541 r
.59284 .69786 m .59258 .70031 L .59178 .69763 L F
.747 .666 .771 r
.45635 .78685 m .45823 .78711 L .45711 .78368 L F
.399 .454 .802 r
.45711 .78368 m .45823 .78711 L .45988 .78716 L F
.772 .923 .554 r
.69731 .50056 m .69818 .49843 L .69952 .49989 L F
.486 .862 .982 r
.6972 .49981 m .69731 .50056 L .69743 .49982 L F
.772 .923 .554 r
.69731 .50056 m .6962 .50163 L .69747 .49957 L F
.486 .862 .982 r
.6972 .49981 m .69743 .49982 L .69818 .49843 L F
.772 .923 .554 r
.69731 .50056 m .69743 .49982 L .69818 .49843 L F
.486 .862 .982 r
.69743 .49982 m .69952 .49989 L .69818 .49843 L F
.772 .923 .554 r
.69743 .49982 m .69747 .49957 L .69818 .49843 L F
.486 .862 .982 r
.69743 .49982 m .69731 .50056 L .69952 .49989 L F
.382 .461 .817 r
.72617 .60788 m .72762 .61126 L .72936 .61117 L F
.447 .547 .865 r
.72762 .61126 m .73069 .61381 L .72936 .61117 L F
.423 0 0 r
.57233 .72604 m .57109 .72597 L .56909 .72524 L F
0 .313 .782 r
.57569 .7286 m .5749 .7276 L .57233 .72604 L F
.734 .297 .211 r
.5749 .7276 m .57109 .72597 L .57233 .72604 L F
.993 .747 .442 r
.51632 .77765 m .51733 .77854 L .51656 .77998 L F
.652 .869 .981 r
.51632 .77765 m .51733 .77854 L .51985 .77697 L F
.993 .747 .442 r
.51656 .77998 m .51733 .77854 L .51632 .77765 L F
.381 .452 .809 r
.50882 .73957 m .51048 .74177 L .51028 .73827 L F
.47 .101 .255 r
.48148 .7744 m .48053 .7759 L .47856 .77603 L F
0 .104 .659 r
.57651 .73019 m .5749 .7276 L .57569 .7286 L F
.643 .919 .631 r
.36591 .70938 m .36396 .71148 L .36424 .71084 L F
0 .472 .832 r
.36621 .71127 m .3644 .71048 L .36424 .71084 L F
.839 .378 0 r
.36288 .70859 m .36424 .71084 L .36289 .70983 L F
0 .472 .832 r
.3644 .71048 m .36289 .70983 L .36424 .71084 L F
.643 .919 .631 r
.36396 .71148 m .36339 .71208 L .36424 .71084 L F
.435 .719 .985 r
.36339 .71208 m .3657 .71215 L .36424 .71084 L F
.421 .24 .528 r
.26711 .619 m .26499 .62223 L .26509 .61953 L F
.536 .275 .467 r
.62377 .56126 m .62463 .5632 L .6234 .5638 L F
.62377 .56126 m .62581 .56085 L .62463 .5632 L F
.766 .265 0 r
.59139 .68309 m .59401 .68578 L .59272 .68374 L F
.988 .719 .396 r
.49247 .80043 m .49239 .79804 L .49136 .79739 L F
.742 .425 .447 r
.4879 .79489 m .4921 .79587 L .49136 .79739 L F
0 0 0 r
.49136 .79739 m .4921 .79587 L .4937 .79341 L F
.996 .803 .529 r
.49136 .79739 m .49237 .79723 L .49232 .79558 L F
0 0 0 r
.49136 .79739 m .4937 .79341 L .49258 .79669 L F
.381 .843 .801 r
.49014 .79759 m .49136 .79739 L .49258 .79669 L F
.48855 .79817 m .49136 .79739 L .49014 .79759 L F
.996 .803 .529 r
.49136 .79739 m .49239 .79804 L .49237 .79723 L F
.688 .687 .844 r
.67812 .49348 m .67887 .49496 L .68113 .49416 L F
.25 .536 .921 r
.48631 .79212 m .48553 .79261 L .48419 .79058 L F
.171 .371 .819 r
.48631 .79212 m .4879 .79489 L .48553 .79261 L F
.037 0 0 r
.42224 .66223 m .42074 .66301 L .41855 .66345 L F
.024 0 0 r
.42457 .66216 m .42074 .66301 L .42224 .66223 L F
.808 .936 .572 r
.34087 .71391 m .33878 .7174 L .33929 .71575 L F
.415 .048 .231 r
.34147 .71589 m .34087 .71391 L .33929 .71575 L F
.34147 .71589 m .3428 .71367 L .34087 .71391 L F
.74 .753 .863 r
.68234 .49983 m .68073 .5015 L .67916 .49937 L F
.307 .484 .87 r
.40159 .69674 m .40085 .69868 L .39962 .69741 L F
.40159 .69674 m .40287 .69888 L .40085 .69868 L F
.929 .575 .144 r
.49154 .78688 m .49168 .78739 L .49111 .78851 L F
.49168 .78739 m .49219 .78931 L .49111 .78851 L F
.466 .167 .373 r
.49219 .78931 m .4896 .78925 L .49111 .78851 L F
.4896 .78925 m .4888 .78923 L .49111 .78851 L F
0 0 0 r
.49278 .78769 m .49111 .78851 L .49075 .7892 L F
.4933 .78731 m .49111 .78851 L .49278 .78769 L F
.466 .167 .373 r
.49219 .78931 m .49003 .79202 L .4888 .78923 L F
0 0 0 r
.49075 .7892 m .49111 .78851 L .48955 .7901 L F
.929 .575 .144 r
.49154 .78688 m .49111 .78851 L .49171 .7864 L F
.716 .635 .766 r
.44274 .66407 m .44632 .66488 L .44499 .66144 L F
.712 .633 .767 r
.44499 .66144 m .44632 .66488 L .44841 .66395 L F
.396 0 0 r
.54611 .76158 m .54471 .76293 L .54214 .76259 L F
.738 .234 .027 r
.54611 .76158 m .54653 .76342 L .54471 .76293 L F
.54611 .76158 m .54934 .76467 L .54653 .76342 L F
.429 .023 .165 r
.38426 .65254 m .38649 .6523 L .38784 .6503 L F
.506 .114 .232 r
.38649 .6523 m .39001 .65025 L .38784 .6503 L F
.842 .461 .331 r
.67961 .54052 m .67644 .53793 L .67931 .53951 L F
.227 0 0 r
.68271 .54109 m .67961 .54052 L .67931 .53951 L F
.25 0 .025 r
.24449 .59211 m .24654 .59148 L .24456 .59201 L F
.203 0 0 r
.30641 .65029 m .30536 .65105 L .30355 .65109 L F
.106 0 0 r
.30849 .64964 m .3079 .65021 L .30641 .65029 L F
.074 0 0 r
.3079 .65021 m .30536 .65105 L .30641 .65029 L F
0 0 .518 r
.48443 .78135 m .48499 .77987 L .48162 .7789 L F
.48443 .78135 m .48533 .78341 L .48499 .77987 L F
.773 .695 .152 r
.48443 .78135 m .48411 .78411 L .48533 .78341 L F
.747 .653 .756 r
.59806 .56357 m .599 .56712 L .59541 .56665 L F
.293 0 .161 r
.40448 .66815 m .40301 .66766 L .40512 .66711 L F
.40448 .66815 m .40299 .66868 L .40301 .66766 L F
.98 .701 .419 r
.55095 .78805 m .55161 .79004 L .55044 .78918 L F
.321 .569 .929 r
.55161 .79004 m .55326 .78905 L .55044 .78918 L F
.456 .876 .757 r
.55326 .78905 m .54972 .79078 L .55044 .78918 L F
.54972 .79078 m .54901 .79113 L .55044 .78918 L F
.98 .701 .419 r
.55057 .78692 m .55095 .78805 L .55044 .78918 L F
.321 .569 .929 r
.55161 .79004 m .55378 .79059 L .55326 .78905 L F
.532 .596 .864 r
.65695 .52992 m .65432 .53048 L .65308 .52743 L F
.069 .102 .588 r
.65432 .53048 m .6557 .53177 L .65695 .52992 L F
0 0 0 r
.65335 .53114 m .65432 .53048 L .65695 .52992 L F
.532 .802 .995 r
.29982 .58862 m .29926 .59007 L .29768 .58883 L F
.29982 .58862 m .30134 .58956 L .29926 .59007 L F
.025 0 0 r
.40287 .69888 m .40516 .69869 L .40699 .69831 L F
.119 0 0 r
.40516 .69869 m .40914 .69784 L .40699 .69831 L F
.496 .438 .721 r
.35775 .71221 m .36006 .71183 L .35941 .7102 L F
.519 .47 .742 r
.35902 .70856 m .35775 .71221 L .35941 .7102 L F
.989 .731 .432 r
.64678 .5326 m .64592 .53305 L .64593 .53027 L F
.44 .208 .465 r
.32501 .61437 m .32653 .61597 L .32623 .61345 L F
.32501 .61437 m .32455 .61656 L .32653 .61597 L F
.601 .619 .842 r
.74644 .60613 m .74279 .60378 L .74608 .60467 L F
.569 .626 .868 r
.74832 .60416 m .74644 .60613 L .74608 .60467 L F
.74832 .60416 m .74878 .60577 L .74644 .60613 L F
.675 .698 .863 r
.68113 .49416 m .68454 .49498 L .68344 .4935 L F
.659 .692 .869 r
.68344 .4935 m .68454 .49498 L .68686 .49413 L F
.574 .213 .318 r
.51554 .81159 m .51842 .81043 L .51724 .8132 L F
.548 .097 .133 r
.51842 .81043 m .5198 .81271 L .51724 .8132 L F
.51842 .81043 m .52114 .81105 L .5198 .81271 L F
.353 0 .105 r
.45675 .6864 m .45541 .68831 L .45321 .68871 L F
.43 0 .098 r
.459 .68646 m .45541 .68831 L .45675 .6864 L F
.318 .271 .647 r
.58726 .72835 m .58856 .7245 L .58699 .72569 L F
.598 .304 .441 r
.46472 .68387 m .46687 .68575 L .46448 .68578 L F
.627 .294 .388 r
.46706 .68415 m .46687 .68575 L .46472 .68387 L F
.975 .711 .468 r
.48533 .78341 m .48671 .78663 L .48661 .78409 L F
.426 .171 .422 r
.32256 .61712 m .32207 .61919 L .32455 .61656 L F
.569 .114 .133 r
.32155 .60341 m .31837 .60359 L .32 .60413 L F
.601 .58 .802 r
.72385 .60829 m .725 .6048 L .72266 .60529 L F
.72385 .60829 m .72617 .60788 L .725 .6048 L F
.484 .368 .646 r
.46091 .75919 m .46313 .76112 L .46312 .75876 L F
.46091 .75919 m .46112 .76163 L .46313 .76112 L F
.653 .916 .979 r
.63103 .49597 m .62992 .49768 L .63237 .49724 L F
.63103 .49597 m .62896 .49704 L .62992 .49768 L F
.571 .231 .353 r
.62992 .49768 m .62987 .49927 L .63218 .49902 L F
.546 .26 .432 r
.62992 .49768 m .63218 .49902 L .63237 .49724 L F
.478 .18 .382 r
.44072 .68348 m .44294 .68313 L .44368 .68046 L F
.443 .141 .356 r
.44294 .68313 m .4459 .68016 L .44368 .68046 L F
.686 .286 .283 r
.52128 .75598 m .52355 .75778 L .524 .75637 L F
.697 .422 .504 r
.52355 .75778 m .52656 .75618 L .524 .75637 L F
0 .096 .629 r
.57716 .73397 m .57651 .73019 L .57785 .73118 L F
.57716 .73397 m .5781 .73327 L .57651 .73019 L F
.207 .583 .943 r
.57716 .73397 m .57936 .73443 L .5781 .73327 L F
.647 .655 .843 r
.68073 .52407 m .68187 .52271 L .67909 .52534 L F
.4 .41 .755 r
.58537 .74493 m .58633 .74151 L .58428 .74335 L F
.58537 .74493 m .58732 .74486 L .58633 .74151 L F
.135 .648 .895 r
.32758 .59269 m .33091 .59332 L .32889 .59332 L F
.76 .694 .788 r
.44703 .66094 m .45065 .66148 L .44937 .65846 L F
.44703 .66094 m .44859 .66177 L .45065 .66148 L F
.713 .578 .702 r
.44841 .66395 m .45065 .66148 L .44859 .66177 L F
.44841 .66395 m .45184 .66457 L .45065 .66148 L F
.546 .57 .83 r
.45065 .66148 m .45166 .65765 L .44937 .65846 L F
.45065 .66148 m .45311 .66095 L .45166 .65765 L F
.556 .506 .755 r
.45184 .66457 m .45311 .66095 L .45065 .66148 L F
.725 .441 .497 r
.52237 .72481 m .52594 .72265 L .52237 .72249 L F
.52237 .72481 m .52418 .72516 L .52594 .72265 L F
.71 .422 .487 r
.52594 .72265 m .52418 .72516 L .52797 .72507 L F
.208 0 0 r
.64066 .53052 m .64211 .53075 L .6394 .53012 L F
.7 .353 .385 r
.52341 .8058 m .52029 .80552 L .52197 .8063 L F
.421 0 0 r
.52197 .8063 m .52565 .80607 L .52341 .8058 L F
.486 .733 .981 r
.76056 .61026 m .75921 .61182 L .75816 .61083 L F
.76056 .61026 m .7617 .61156 L .75921 .61182 L F
.831 .414 .249 r
.49721 .80849 m .50085 .8097 L .50004 .81124 L F
.538 .24 .41 r
.50268 .81137 m .50085 .8097 L .50114 .81227 L F
.50114 .81227 m .50085 .8097 L .50268 .81137 L F
.651 .195 .156 r
.50004 .81124 m .50085 .8097 L .50268 .81137 L F
.213 .527 .92 r
.45988 .78716 m .46183 .78905 L .46361 .78954 L F
.738 .863 .939 r
.53591 .80284 m .53835 .80356 L .53889 .80247 L F
.997 .77 .448 r
.75733 .61865 m .75827 .61965 L .75809 .62209 L F
.462 .186 .408 r
.39658 .67154 m .39494 .6698 L .39713 .66957 L F
.39658 .67154 m .39433 .67209 L .39494 .6698 L F
.711 .709 .846 r
.35583 .70568 m .35642 .70651 L .35328 .70599 L F
.309 .319 .708 r
.35831 .70571 m .35642 .70651 L .35583 .70568 L F
.35831 .70571 m .35848 .70785 L .35642 .70651 L F
0 .281 .778 r
.35848 .70785 m .35902 .70856 L .35642 .70651 L F
.972 .763 .335 r
.58869 .6805 m .5893 .68343 L .59023 .68174 L F
.572 .517 .756 r
.47689 .66188 m .47476 .66242 L .47349 .65861 L F
.309 .341 .733 r
.63226 .50818 m .63462 .51017 L .63457 .50785 L F
.653 .832 .969 r
.29107 .63757 m .2893 .63864 L .28815 .63772 L F
.274 0 0 r
.70781 .52293 m .70709 .52431 L .7049 .52483 L F
.256 0 0 r
.70877 .52302 m .70709 .52431 L .70781 .52293 L F
.946 .715 .248 r
.66588 .51344 m .66538 .51286 L .66526 .51045 L F
.734 .244 .076 r
.66588 .51344 m .66631 .51508 L .66538 .51286 L F
.66588 .51344 m .66825 .51582 L .66631 .51508 L F
.555 .501 .75 r
.70979 .50553 m .71074 .50898 L .7124 .50784 L F
0 0 .296 r
.71112 .51109 m .7124 .50784 L .71074 .50898 L F
.511 .177 .336 r
.3785 .65504 m .37671 .65365 L .37615 .65495 L F
.3785 .65504 m .37979 .65255 L .37671 .65365 L F
.256 0 0 r
.40077 .71127 m .39972 .71251 L .39762 .71284 L F
.232 0 0 r
.403 .71078 m .39972 .71251 L .40077 .71127 L F
.319 .121 .447 r
.45915 .76449 m .46087 .76412 L .46112 .76163 L F
.379 .323 .668 r
.45915 .76449 m .46127 .7666 L .46087 .76412 L F
.432 .33 .638 r
.45915 .76449 m .45946 .76722 L .46127 .7666 L F
.77 .638 .715 r
.61538 .54136 m .61887 .54188 L .61908 .53936 L F
.774 .618 .687 r
.61538 .54136 m .61691 .54418 L .61887 .54188 L F
.665 .458 .594 r
.61691 .54418 m .61944 .54433 L .61887 .54188 L F
.546 .383 .611 r
.61887 .54188 m .62178 .54369 L .62189 .54175 L F
.61887 .54188 m .61944 .54433 L .62178 .54369 L F
.556 .506 .755 r
.45184 .66457 m .45394 .66418 L .45311 .66095 L F
.616 .582 .793 r
.45184 .66457 m .45524 .66728 L .45394 .66418 L F
.735 .367 .355 r
.4937 .80604 m .49753 .80647 L .49721 .80849 L F
.92 .933 .799 r
.49648 .80569 m .49753 .80647 L .49949 .80318 L F
.424 .796 .994 r
.4937 .80604 m .49753 .80647 L .49648 .80569 L F
.98 .688 .329 r
.49648 .80569 m .49753 .80647 L .49721 .80849 L F
.939 .926 .563 r
.67069 .5062 m .66983 .5071 L .67109 .50454 L F
.67069 .5062 m .6699 .50838 L .66983 .5071 L F
.821 .721 .754 r
.61987 .49145 m .62081 .49471 L .61919 .49371 L F
.904 .747 .676 r
.61952 .49595 m .61919 .49371 L .62081 .49471 L F
0 .382 .725 r
.42199 .64906 m .42409 .64983 L .42538 .65042 L F
.529 0 0 r
.42062 .64946 m .42409 .64983 L .42199 .64906 L F
.38 .786 .983 r
.42062 .64946 m .42275 .64922 L .42409 .64983 L F
.42275 .64922 m .42279 .64922 L .42409 .64983 L F
0 .382 .725 r
.42538 .65042 m .42409 .64983 L .42548 .65046 L F
.555 .857 .997 r
.42766 .64982 m .42548 .65046 L .4263 .64915 L F
.561 .864 .996 r
.42548 .65046 m .42409 .64983 L .4263 .64915 L F
.598 .658 .88 r
.72936 .61117 m .73069 .61381 L .7328 .61326 L F
.659 .835 .967 r
.7591 .62417 m .76311 .62135 L .76081 .62236 L F
.7591 .62417 m .76421 .62243 L .76311 .62135 L F
.169 0 .228 r
.51094 .73671 m .51191 .73703 L .51329 .73393 L F
0 0 0 r
.51264 .73529 m .51094 .73671 L .51329 .73393 L F
.696 .303 .299 r
.51028 .73827 m .51332 .73886 L .51094 .73671 L F
0 .24 .756 r
.51094 .73671 m .51332 .73886 L .51191 .73703 L F
.44 .214 .472 r
.51264 .73529 m .51044 .73765 L .51094 .73671 L F
.197 0 0 r
.6347 .50087 m .63338 .50033 L .63566 .49989 L F
.6347 .50087 m .63236 .5014 L .63338 .50033 L F
.494 .412 .692 r
.45598 .66941 m .45747 .66676 L .45524 .66728 L F
.45598 .66941 m .45778 .66915 L .45747 .66676 L F
.458 .329 .617 r
.45598 .66941 m .45786 .67145 L .45778 .66915 L F
.45598 .66941 m .45589 .67252 L .45786 .67145 L F
.766 .652 .736 r
.51695 .73935 m .51839 .74274 L .51443 .74179 L F
.42 .754 .995 r
.51443 .74179 m .51839 .74274 L .51668 .74166 L F
.559 .548 .799 r
.52019 .74186 m .51839 .74274 L .51695 .73935 L F
.198 .712 .887 r
.52019 .74186 m .51668 .74166 L .51839 .74274 L F
.596 .149 .159 r
.55359 .69986 m .55323 .7018 L .5518 .70045 L F
.29 .089 .426 r
.55664 .69717 m .55629 .69958 L .55359 .69986 L F
.209 0 .08 r
.55629 .69958 m .55323 .7018 L .55359 .69986 L F
.47 .198 .419 r
.48136 .74913 m .4835 .74734 L .48156 .74788 L F
.711 .483 .578 r
.60237 .56977 m .60493 .57216 L .60232 .57219 L F
.992 .745 .441 r
.62754 .49289 m .62909 .49487 L .62756 .49076 L F
.782 .846 .9 r
.63106 .49175 m .62909 .49487 L .62754 .49289 L F
.592 .691 .911 r
.632 .4944 m .62909 .49487 L .63106 .49175 L F
.456 .07 .217 r
.41126 .66493 m .41052 .66625 L .40839 .66631 L F
.454 .112 .295 r
.41339 .66434 m .41052 .66625 L .41126 .66493 L F
.584 .633 .866 r
.58874 .74749 m .58971 .74436 L .58732 .74486 L F
.58874 .74749 m .59128 .74709 L .58971 .74436 L F
.319 0 0 r
.42788 .6613 m .42624 .66251 L .42457 .66216 L F
.186 0 0 r
.42857 .66203 m .42788 .6613 L .42998 .66093 L F
.42857 .66203 m .42624 .66251 L .42788 .6613 L F
.552 .4 .629 r
.74148 .59672 m .73943 .6007 L .7384 .59734 L F
.74148 .59672 m .74173 .60021 L .73943 .6007 L F
.516 .492 .768 r
.35928 .6779 m .36199 .68072 L .36106 .67751 L F
.583 .589 .825 r
.45394 .66418 m .45524 .66728 L .45747 .66676 L F
.617 .117 0 r
.4738 .78853 m .475 .78969 L .47297 .78732 L F
.4 .341 .675 r
.47297 .78732 m .47468 .78932 L .4745 .78767 L F
.47297 .78732 m .4745 .78767 L .47436 .78707 L F
.617 .117 0 r
.47543 .78771 m .47297 .78732 L .47575 .78755 L F
.613 .506 .708 r
.475 .78969 m .47585 .78773 L .4745 .78767 L F
.617 .117 0 r
.4752 .78782 m .4745 .78767 L .47543 .78771 L F
.4745 .78767 m .47297 .78732 L .47543 .78771 L F
0 0 .307 r
.47524 .78639 m .47575 .78755 L .47483 .78545 L F
.47564 .78729 m .47567 .78737 L .47524 .78639 L F
.47567 .78737 m .47575 .78755 L .47524 .78639 L F
.613 .506 .708 r
.47585 .78773 m .47704 .785 L .47539 .78673 L F
.47543 .78771 m .47539 .78673 L .4745 .78767 L F
.92 .923 .798 r
.4752 .78782 m .47543 .78771 L .4755 .78696 L F
.47543 .78771 m .47575 .78755 L .47564 .78729 L F
.613 .506 .708 r
.47564 .78729 m .47539 .78673 L .47543 .78771 L F
.92 .923 .798 r
.47543 .78771 m .47564 .78729 L .4755 .78696 L F
.613 .506 .708 r
.47583 .78773 m .47564 .78729 L .47543 .78771 L F
.47585 .78773 m .47539 .78673 L .47583 .78773 L F
0 0 .307 r
.47564 .78729 m .47483 .78545 L .47398 .78351 L F
.683 .239 .19 r
.47524 .78639 m .47398 .78351 L .47436 .78707 L F
.47704 .785 m .47398 .78351 L .47524 .78639 L F
0 0 .307 r
.47467 .78495 m .47564 .78729 L .47398 .78351 L F
.613 .506 .708 r
.4745 .78767 m .47539 .78673 L .47436 .78707 L F
.47539 .78673 m .47704 .785 L .47524 .78639 L F
.47539 .78673 m .47524 .78639 L .47436 .78707 L F
.617 .117 0 r
.4738 .78853 m .47297 .78732 L .4752 .78782 L F
.92 .923 .798 r
.4738 .78853 m .4752 .78782 L .47467 .78495 L F
.4752 .78782 m .4755 .78696 L .47467 .78495 L F
.4 .341 .675 r
.47468 .78932 m .475 .78969 L .47482 .78894 L F
.47468 .78932 m .47482 .78894 L .4745 .78767 L F
.674 .409 .512 r
.61452 .56691 m .61256 .56944 L .61037 .56898 L F
.626 .347 .475 r
.61582 .56842 m .61452 .56691 L .61597 .56701 L F
.61582 .56842 m .61256 .56944 L .61452 .56691 L F
.665 .408 .522 r
.52119 .80893 m .52347 .81151 L .52114 .81105 L F
.219 0 0 r
.70323 .50062 m .70425 .50119 L .70538 .49957 L F
.70323 .50062 m .70216 .50156 L .70425 .50119 L F
.752 .665 .765 r
.70655 .50493 m .70758 .50825 L .70979 .50553 L F
.77 .638 .715 r
.61538 .54136 m .61908 .53936 L .61556 .53892 L F
.627 .115 .012 r
.54803 .76649 m .5523 .76691 L .54953 .76576 L F
0 0 .062 r
.78308 .59112 m .78231 .59337 L .7811 .59484 L F
0 0 .401 r
.7811 .59484 m .78239 .59565 L .78197 .59713 L F
.7811 .59484 m .78231 .59337 L .78239 .59565 L F
.341 .105 .404 r
.58413 .71202 m .58357 .71375 L .58597 .71116 L F
.58413 .71202 m .58357 .71375 L .58597 .71116 L F
.595 .346 .509 r
.60783 .56936 m .60807 .57317 L .60493 .57216 L F
.538 .307 .512 r
.61037 .56898 m .60807 .57317 L .60783 .56936 L F
.56 .692 .928 r
.26968 .63546 m .26901 .63744 L .2676 .63597 L F
.26968 .63546 m .27072 .63698 L .26901 .63744 L F
.677 .44 .555 r
.50799 .81195 m .50742 .81338 L .50612 .81098 L F
.50799 .81195 m .50977 .81437 L .50742 .81338 L F
.51 .506 .788 r
.65034 .51227 m .65143 .51446 L .65307 .5133 L F
.27 .09 .443 r
.31528 .62511 m .3171 .62461 L .31708 .62127 L F
.416 .183 .45 r
.31708 .62127 m .31905 .62174 L .31967 .61925 L F
.359 .156 .463 r
.31708 .62127 m .31874 .62361 L .31905 .62174 L F
.31708 .62127 m .3171 .62461 L .31874 .62361 L F
.712 .633 .767 r
.44499 .66144 m .44841 .66395 L .44703 .66094 L F
.787 .677 .742 r
.44703 .66094 m .44841 .66395 L .44859 .66177 L F
.888 .529 .358 r
.51329 .73393 m .51264 .73529 L .51162 .73362 L F
.877 .856 .817 r
.51329 .73393 m .51162 .73362 L .51372 .73003 L F
.888 .529 .358 r
.51329 .73393 m .51264 .73529 L .51162 .73362 L F
.591 .309 .457 r
.51329 .73393 m .51191 .73703 L .51558 .73569 L F
.663 .248 .248 r
.51329 .73393 m .51558 .73569 L .51264 .73529 L F
.27 .23 .628 r
.58249 .74193 m .58358 .74208 L .58348 .73884 L F
.231 .338 .767 r
.58249 .74193 m .58428 .74335 L .58358 .74208 L F
.857 .458 .285 r
.67501 .5051 m .67451 .50347 L .67297 .5043 L F
.637 .834 .976 r
.53953 .73643 m .53565 .73644 L .53878 .73516 L F
0 0 .499 r
.53565 .73644 m .53726 .73736 L .53878 .73516 L F
.638 .176 .138 r
.53973 .734 m .53878 .73516 L .53617 .73371 L F
.928 .741 .628 r
.53406 .73536 m .53565 .73644 L .53617 .73371 L F
0 .366 .821 r
.53617 .73371 m .53878 .73516 L .53703 .73349 L F
.577 .46 .683 r
.53703 .73349 m .5383 .73538 L .53406 .73536 L F
0 .277 .752 r
.53878 .73516 m .53861 .73454 L .53703 .73349 L F
.844 .919 .524 r
.53867 .73476 m .53825 .73549 L .53861 .73454 L F
.53878 .73516 m .53782 .73634 L .53867 .73476 L F
.433 .407 .731 r
.53861 .73454 m .53863 .73587 L .5383 .73538 L F
.53861 .73454 m .5383 .73538 L .53703 .73349 L F
.577 .46 .683 r
.5383 .73538 m .5381 .73581 L .53406 .73536 L F
.844 .919 .524 r
.53825 .73549 m .53766 .73653 L .53861 .73454 L F
.653 .198 .159 r
.53726 .73736 m .53406 .73536 L .5381 .73581 L F
.844 .919 .524 r
.53782 .73634 m .53766 .73653 L .53867 .73476 L F
.53878 .73516 m .53768 .73676 L .53793 .7362 L F
.53768 .73676 m .53726 .73736 L .53793 .7362 L F
.653 .198 .159 r
.53726 .73736 m .5381 .73581 L .53863 .73587 L F
.577 .46 .683 r
.5383 .73538 m .53863 .73587 L .5381 .73581 L F
.844 .919 .524 r
.53793 .7362 m .53726 .73736 L .53766 .73653 L F
.638 .176 .138 r
.53987 .73401 m .53878 .73516 L .53973 .734 L F
.999 .819 .519 r
.53987 .73401 m .53953 .73643 L .53878 .73516 L F
.792 .295 0 r
.55164 .73396 m .54993 .73333 L .54851 .73136 L F
.619 .438 .615 r
.54865 .73694 m .55137 .73676 L .55164 .73396 L F
0 .096 .653 r
.55164 .73396 m .55176 .73293 L .54993 .73333 L F
.55164 .73396 m .55331 .73586 L .55176 .73293 L F
.448 .29 .574 r
.55164 .73396 m .55137 .73676 L .55331 .73586 L F
.261 0 0 r
.53379 .72312 m .53561 .7236 L .53727 .72211 L F
.291 0 0 r
.53561 .7236 m .53934 .72286 L .53727 .72211 L F
.317 0 .08 r
.24318 .59365 m .24654 .59148 L .24449 .59211 L F
0 0 0 r
.63648 .51858 m .63447 .51946 L .63718 .51715 L F
.63648 .51858 m .63718 .51715 L .63894 .51576 L F
.664 .681 .857 r
.51028 .73827 m .51048 .74177 L .51332 .73886 L F
.635 .455 .622 r
.51048 .74177 m .51218 .74251 L .51443 .74179 L F
.503 .2 .386 r
.61582 .56842 m .61597 .56701 L .61803 .56839 L F
.536 .174 .301 r
.61597 .56701 m .61844 .56695 L .61803 .56839 L F
.606 .709 .917 r
.69604 .48836 m .69511 .49147 L .69366 .48876 L F
.69604 .48836 m .69746 .49101 L .69511 .49147 L F
.222 .687 .944 r
.3125 .59128 m .31405 .59196 L .31055 .59122 L F
.276 .714 .964 r
.3125 .59128 m .31608 .59201 L .31405 .59196 L F
.262 .404 .818 r
.75663 .60766 m .75567 .60957 L .75468 .60781 L F
.75663 .60766 m .75816 .61083 L .75567 .60957 L F
.816 .751 .791 r
.60733 .5278 m .60441 .52762 L .60668 .52484 L F
.82 .738 .774 r
.60733 .5278 m .60528 .53068 L .60441 .52762 L F
.221 .295 .728 r
.49995 .75799 m .49937 .76087 L .49725 .75847 L F
.49995 .75799 m .50082 .7616 L .49937 .76087 L F
.461 0 0 r
.47003 .79757 m .47048 .79808 L .46831 .7977 L F
.47003 .79757 m .47223 .79872 L .47048 .79808 L F
.943 .745 .606 r
.6634 .53767 m .6653 .53646 L .66376 .53539 L F
.6634 .53767 m .66479 .53872 L .6653 .53646 L F
.973 .866 .671 r
.66911 .52134 m .67008 .52234 L .66914 .52471 L F
.225 0 .137 r
.56734 .68111 m .57035 .68017 L .57077 .67847 L F
.184 0 .068 r
.57035 .68017 m .57286 .67764 L .57077 .67847 L F
.733 .553 .648 r
.5307 .75033 m .53403 .75045 L .53381 .74793 L F
.612 .462 .655 r
.53381 .74793 m .53403 .75045 L .5362 .74761 L F
.629 .548 .744 r
.68493 .49908 m .68547 .50203 L .68625 .50043 L F
.581 .7 .924 r
.73642 .61367 m .73775 .61106 L .7351 .61167 L F
.73642 .61367 m .73876 .61326 L .73775 .61106 L F
.378 .045 .268 r
.30946 .63239 m .30814 .63131 L .30751 .63305 L F
.30946 .63239 m .3103 .63076 L .30814 .63131 L F
.699 .435 .521 r
.55849 .68894 m .5604 .689 L .56106 .68695 L F
.381 .123 .392 r
.56106 .68695 m .56273 .68815 L .56344 .68663 L F
.56106 .68695 m .5604 .689 L .56273 .68815 L F
.079 0 .066 r
.63571 .52014 m .63447 .51946 L .63648 .51858 L F
.63571 .52014 m .63398 .52122 L .63447 .51946 L F
.991 .731 .413 r
.63457 .50785 m .63555 .51069 L .63796 .50835 L F
.63457 .50785 m .63462 .51017 L .63555 .51069 L F
.42 .17 .427 r
.63796 .50835 m .63894 .51 L .63555 .51069 L F
0 0 .328 r
.54441 .77877 m .54477 .77997 L .54564 .7798 L F
.675 .29 .309 r
.54564 .7798 m .54583 .77883 L .54405 .77847 L F
.692 .541 .677 r
.54901 .78072 m .54583 .77883 L .54564 .7798 L F
.703 .934 .622 r
.54477 .77997 m .54371 .7838 L .54564 .7798 L F
.108 0 .088 r
.54503 .78087 m .54477 .77997 L .54702 .77866 L F
.703 .934 .622 r
.54477 .77997 m .54235 .78282 L .54371 .7838 L F
.108 0 .088 r
.54364 .78242 m .54477 .77997 L .54503 .78087 L F
0 0 .328 r
.54405 .77847 m .54477 .77997 L .54441 .77877 L F
.687 .556 .701 r
.54405 .77847 m .54583 .77883 L .54581 .77596 L F
.446 .292 .577 r
.69738 .53178 m .69504 .53048 L .69726 .52999 L F
.69738 .53178 m .69505 .53286 L .69504 .53048 L F
.35 .275 .63 r
.45801 .77289 m .4595 .77244 L .45945 .76945 L F
.415 .304 .619 r
.4581 .77529 m .4595 .77244 L .45801 .77289 L F
.29 .277 .672 r
.54993 .73333 m .54865 .73694 L .54735 .73384 L F
.54993 .73333 m .55058 .73574 L .54865 .73694 L F
.484 .063 .164 r
.54865 .73694 m .55045 .73792 L .55137 .73676 L F
.27 .238 .637 r
.55058 .73574 m .55045 .73792 L .54865 .73694 L F
.759 .973 .923 r
.62143 .52973 m .62016 .53112 L .62234 .53 L F
.914 .979 .763 r
.62343 .52662 m .62234 .53 L .62493 .52859 L F
.62343 .52662 m .62143 .52973 L .62234 .53 L F
.459 .622 .922 r
.49478 .79498 m .49713 .7953 L .4958 .79377 L F
.157 .27 .731 r
.56734 .68111 m .57007 .68256 L .57035 .68017 L F
.56734 .68111 m .56881 .68422 L .57007 .68256 L F
.573 .539 .779 r
.49329 .77809 m .49112 .77853 L .49028 .77541 L F
.24 0 0 r
.49215 .77949 m .49112 .77853 L .49329 .77809 L F
.657 .103 0 r
.51985 .77697 m .52306 .77831 L .52146 .7784 L F
.652 .869 .981 r
.51632 .77765 m .51985 .77697 L .51913 .77432 L F
.707 .558 .683 r
.51913 .77432 m .51632 .77765 L .51985 .77697 L F
.657 .103 0 r
.51985 .77697 m .52146 .7784 L .52138 .77837 L F
.331 .246 .606 r
.51985 .77697 m .52142 .77841 L .52114 .77721 L F
.327 .748 .975 r
.52051 .77802 m .51881 .77694 L .52114 .77721 L F
.51942 .77945 m .51892 .77739 L .52051 .77802 L F
.51892 .77739 m .51881 .77694 L .52051 .77802 L F
.657 .103 0 r
.52138 .77837 m .52146 .7784 L .52142 .77841 L F
.121 0 0 r
.52306 .77831 m .52342 .77881 L .52142 .77841 L F
.52306 .77831 m .52525 .77811 L .52342 .77881 L F
.489 .158 .331 r
.43522 .69695 m .43189 .69962 L .43246 .69739 L F
.509 .046 .089 r
.74655 .59051 m .75041 .58834 L .7484 .58888 L F
.471 .204 .427 r
.34549 .61689 m .34786 .61455 L .34749 .6165 L F
.409 .134 .382 r
.34786 .61455 m .34946 .61587 L .34749 .6165 L F
.511 0 0 r
.39001 .65025 m .39201 .65127 L .39353 .65018 L F
.492 0 0 r
.39201 .65127 m .3958 .6506 L .39353 .65018 L F
.632 .393 .538 r
.5881 .57197 m .58521 .57471 L .58539 .57235 L F
.5881 .57197 m .58841 .57443 L .58521 .57471 L F
.534 .266 .455 r
.5881 .57197 m .58969 .57435 L .58841 .57443 L F
.5881 .57197 m .59048 .57166 L .58969 .57435 L F
.365 0 .028 r
.54256 .77734 m .5449 .77543 L .54376 .77736 L F
.384 .363 .712 r
.54779 .77401 m .5449 .77543 L .54461 .77239 L F
.346 0 .023 r
.28419 .60724 m .28286 .60668 L .28438 .60536 L F
.28419 .60724 m .28227 .60771 L .28286 .60668 L F
.602 .42 .607 r
.76483 .59965 m .76717 .59684 L .76473 .59742 L F
.959 .919 .726 r
.54075 .76879 m .53887 .77276 L .53783 .77238 L F
.54075 .76879 m .53783 .77238 L .53989 .77127 L F
.566 .215 .333 r
.53989 .77127 m .54283 .7684 L .54075 .76879 L F
.431 .434 .761 r
.39038 .68988 m .39284 .69147 L .39103 .69143 L F
.556 .846 .998 r
.44468 .64902 m .44683 .6484 L .44827 .64926 L F
0 .506 .722 r
.44683 .6484 m .45049 .64895 L .44827 .64926 L F
.733 .629 .743 r
.68686 .49413 m .69016 .49617 L .68914 .49365 L F
.68686 .49413 m .68811 .49746 L .69016 .49617 L F
.63 .683 .881 r
.68914 .49365 m .69016 .49617 L .69249 .49495 L F
.626 .582 .785 r
.69016 .49617 m .69337 .49754 L .69249 .49495 L F
.793 .512 .511 r
.67644 .53793 m .67338 .53554 L .67598 .5363 L F
0 0 0 r
.74862 .59347 m .75185 .59179 L .75061 .59281 L F
.626 .959 .903 r
.75314 .59041 m .75185 .59179 L .75329 .59087 L F
.554 .87 .581 r
.75061 .59281 m .75185 .59179 L .75314 .59041 L F
.582 .724 .94 r
.27472 .63851 m .27072 .63698 L .27299 .63685 L F
.682 .775 .921 r
.27679 .63763 m .27472 .63851 L .27299 .63685 L F
.378 .013 .214 r
.43788 .68529 m .44072 .68348 L .43849 .68381 L F
.468 .208 .436 r
.3143 .62722 m .3171 .62461 L .31528 .62511 L F
.352 .734 .987 r
.27945 .58533 m .28294 .58615 L .28089 .5864 L F
.291 0 0 r
.53934 .72286 m .5422 .72366 L .54286 .72356 L F
.695 .153 0 r
.5422 .72366 m .54472 .72519 L .54286 .72356 L F
.707 .188 0 r
.54286 .72356 m .54472 .72519 L .54646 .72546 L F
.939 .65 .465 r
.66431 .50828 m .66285 .50761 L .66259 .50534 L F
.836 .372 0 r
.66526 .51045 m .66285 .50761 L .66431 .50828 L F
.796 .642 .69 r
.5974 .54985 m .59926 .55293 L .59617 .55249 L F
.789 .678 .742 r
.59617 .55249 m .59926 .55293 L .59809 .55522 L F
.609 .373 .534 r
.44851 .67793 m .45089 .67776 L .45115 .67551 L F
.615 .409 .579 r
.45089 .67776 m .45346 .67498 L .45115 .67551 L F
.558 .337 .536 r
.49883 .73946 m .50156 .73597 L .49923 .73648 L F
.32 0 0 r
.55755 .71061 m .55962 .7111 L .56125 .71128 L F
.725 .233 .072 r
.55962 .7111 m .5627 .71212 L .56125 .71128 L F
.284 .73 .961 r
.3054 .60197 m .3058 .60136 L .30338 .60172 L F
.3054 .60197 m .3085 .60204 L .3058 .60136 L F
.415 .301 .616 r
.34051 .71906 m .33898 .72025 L .33878 .7174 L F
.076 .242 .732 r
.33878 .7174 m .34051 .71906 L .33929 .71575 L F
.415 .301 .616 r
.34051 .71906 m .33898 .72025 L .33878 .7174 L F
.518 .508 .784 r
.39131 .68639 m .39038 .68988 L .38934 .68694 L F
.39131 .68639 m .39214 .68972 L .39038 .68988 L F
.513 .421 .688 r
.39214 .68972 m .39284 .69147 L .39038 .68988 L F
.457 .699 .971 r
.322 .60323 m .32583 .60562 L .3265 .60419 L F
.291 .499 .887 r
.32583 .60562 m .32748 .60568 L .3265 .60419 L F
.322 .445 .83 r
.32583 .60562 m .32798 .60752 L .32748 .60568 L F
.78 .672 .745 r
.26534 .65325 m .26923 .65402 L .26762 .653 L F
.26534 .65325 m .26695 .65602 L .26923 .65402 L F
.555 .824 .996 r
.26923 .65402 m .26954 .6524 L .26762 .653 L F
.26923 .65402 m .27104 .65354 L .26954 .6524 L F
.31 .082 .396 r
.47856 .77603 m .47823 .77864 L .47651 .77833 L F
.416 .282 .59 r
.47857 .77917 m .47651 .77833 L .47862 .77962 L F
.47857 .77917 m .47852 .77923 L .47651 .77833 L F
.193 .383 .823 r
.47845 .7792 m .47846 .77922 L .47651 .77833 L F
.47846 .77922 m .47862 .77962 L .47757 .77898 L F
.47846 .77922 m .47757 .77898 L .47651 .77833 L F
.406 .173 .445 r
.47834 .78279 m .47661 .78141 L .47852 .77923 L F
.642 .674 .865 r
.48079 .77788 m .47862 .77962 L .47823 .77864 L F
.406 .173 .445 r
.47857 .77925 m .47852 .77923 L .47857 .77917 L F
.47834 .78279 m .47852 .77923 L .47857 .77925 L F
.416 .282 .59 r
.47852 .77923 m .47661 .78141 L .47651 .77833 L F
.193 .383 .823 r
.47823 .77864 m .47845 .7792 L .47651 .77833 L F
.739 .936 .952 r
.25985 .65401 m .26355 .65302 L .26218 .65309 L F
.196 .632 .947 r
.26355 .65302 m .26402 .65234 L .26218 .65309 L F
.26355 .65302 m .26534 .65325 L .26402 .65234 L F
.595 .81 .982 r
.75998 .58892 m .7613 .58716 L .75903 .58817 L F
.75998 .58892 m .76235 .58829 L .7613 .58716 L F
.744 .579 .671 r
.54253 .73973 m .54072 .74195 L .53948 .73984 L F
.71 .553 .673 r
.68493 .49908 m .68625 .50043 L .68811 .49746 L F
.71 .594 .725 r
.58403 .56899 m .58166 .57204 L .58177 .56964 L F
.207 0 0 r
.58311 .57015 m .58177 .56964 L .58166 .57204 L F
.58311 .57015 m .58403 .56899 L .58177 .56964 L F
.813 .88 .895 r
.62201 .50621 m .62316 .50744 L .62539 .50524 L F
.557 .4 .625 r
.5287 .75334 m .5307 .75033 L .5284 .75056 L F
.614 .78 .961 r
.54812 .69964 m .54969 .70121 L .5518 .70045 L F
.726 .645 .768 r
.74078 .59459 m .74148 .59672 L .7384 .59734 L F
.506 .347 .599 r
.74352 .59643 m .74173 .60021 L .74148 .59672 L F
.816 .736 .776 r
.60441 .52762 m .60528 .53068 L .60341 .52962 L F
.841 .719 .729 r
.60341 .52962 m .60528 .53068 L .60375 .53381 L F
.575 .253 .386 r
.54381 .70537 m .54714 .70295 L .54478 .70301 L F
.771 .695 .779 r
.55351 .76131 m .5554 .76241 L .5558 .7586 L F
.382 .344 .692 r
.5558 .7586 m .5554 .76241 L .55806 .76065 L F
.937 .967 .723 r
.55702 .76417 m .55806 .76065 L .5554 .76241 L F
.243 .758 .825 r
.63237 .49724 m .63428 .49685 L .63568 .49678 L F
.453 0 0 r
.63428 .49685 m .63756 .4974 L .63568 .49678 L F
.351 .819 .911 r
.29219 .65156 m .29241 .65093 L .29052 .65104 L F
.29219 .65156 m .29444 .65108 L .29241 .65093 L F
.789 .678 .742 r
.59617 .55249 m .59809 .55522 L .59531 .55501 L F
.839 .708 .719 r
.59531 .55501 m .59809 .55522 L .59652 .55826 L F
.747 .666 .771 r
.45635 .78685 m .45711 .78368 L .45469 .78423 L F
.396 .115 .365 r
.36629 .65873 m .36379 .66133 L .36609 .66099 L F
.436 .23 .5 r
.36848 .65587 m .36629 .65873 L .36821 .6582 L F
.438 .234 .505 r
.36821 .6582 m .36629 .65873 L .36609 .66099 L F
.54 .483 .741 r
.36673 .70065 m .36803 .69702 L .36589 .69741 L F
.36673 .70065 m .36876 .7003 L .36803 .69702 L F
.474 .45 .752 r
.36673 .70065 m .36805 .70401 L .36876 .7003 L F
.599 .532 .75 r
.36071 .68683 m .36223 .6834 L .3602 .68363 L F
.36071 .68683 m .36299 .68627 L .36223 .6834 L F
.667 .117 0 r
.52273 .75766 m .52128 .75598 L .52057 .75563 L F
.52273 .75766 m .52355 .75778 L .52128 .75598 L F
.404 .255 .563 r
.36052 .6727 m .36234 .67236 L .36231 .67001 L F
.462 .354 .646 r
.36075 .67512 m .36234 .67236 L .36052 .6727 L F
.453 .404 .713 r
.36876 .7003 m .36805 .70401 L .37108 .70211 L F
.361 .368 .732 r
.37037 .7058 m .37108 .70211 L .36805 .70401 L F
.867 .747 .728 r
.56187 .78401 m .56003 .78439 L .56063 .78107 L F
.685 .265 .243 r
.5606 .78572 m .56003 .78439 L .56187 .78401 L F
.128 .086 .537 r
.56285 .78051 m .56187 .78401 L .56063 .78107 L F
.56285 .78051 m .5634 .7833 L .56187 .78401 L F
0 0 0 r
.56187 .78401 m .56216 .78499 L .5606 .78572 L F
.56187 .78401 m .5634 .7833 L .56216 .78499 L F
.546 .182 .3 r
.38077 .65483 m .37979 .65255 L .3785 .65504 L F
.38077 .65483 m .38196 .65261 L .37979 .65255 L F
.945 .801 .671 r
.6494 .53303 m .64862 .53516 L .65033 .53526 L F
.511 .912 .832 r
.64877 .53747 m .65033 .53526 L .64862 .53516 L F
.64877 .53747 m .65226 .5361 L .65033 .53526 L F
.537 .529 .794 r
.74487 .60165 m .74279 .60378 L .74173 .60021 L F
.586 .61 .842 r
.74487 .60165 m .74608 .60467 L .74279 .60378 L F
.412 .256 .557 r
.50359 .74981 m .50277 .74802 L .50346 .74887 L F
0 0 0 r
.50359 .74981 m .5058 .74919 L .50346 .74887 L F
.797 .576 .603 r
.5058 .74919 m .50359 .74981 L .50346 .74887 L F
0 0 .577 r
.65965 .51122 m .66137 .51295 L .66063 .51332 L F
.65999 .51129 m .66137 .51295 L .65965 .51122 L F
.651 .116 0 r
.65987 .51157 m .66137 .51295 L .65999 .51129 L F
0 0 .577 r
.65931 .51049 m .65999 .51129 L .65965 .51122 L F
.651 .116 0 r
.65987 .51157 m .65999 .51129 L .65931 .51049 L F
.949 .634 .4 r
.65868 .5114 m .65934 .51439 L .65987 .51157 L F
.98 .69 .386 r
.65987 .51157 m .65934 .51439 L .65871 .5122 L F
.65987 .51157 m .65871 .5122 L .65975 .51185 L F
.778 .67 .744 r
.6622 .51102 m .66039 .51204 L .65987 .51157 L F
.98 .69 .386 r
.65987 .51157 m .65975 .51185 L .66086 .51147 L F
.66054 .51141 m .66086 .51147 L .6622 .51102 L F
.65987 .51157 m .66086 .51147 L .66054 .51141 L F
.932 .554 .236 r
.66091 .51466 m .66193 .51679 L .66063 .51332 L F
.66091 .51466 m .66063 .51332 L .66137 .51295 L F
.508 .563 .847 r
.26616 .63292 m .26567 .63616 L .26407 .63359 L F
.26616 .63292 m .2676 .63597 L .26567 .63616 L F
.06 0 0 r
.40896 .70848 m .40743 .70971 L .40489 .71031 L F
.103 0 0 r
.41035 .70859 m .40896 .70848 L .41096 .70786 L F
.41035 .70859 m .40743 .70971 L .40896 .70848 L F
.454 .789 .999 r
.44346 .64821 m .44269 .64933 L .44133 .64822 L F
.44346 .64821 m .44468 .64902 L .44269 .64933 L F
.169 .461 .886 r
.59139 .73095 m .59205 .72988 L .58962 .72865 L F
0 0 .086 r
.5919 .73353 m .59205 .72988 L .59139 .73095 L F
.431 .678 .967 r
.34893 .5977 m .34706 .59777 L .34588 .59642 L F
0 0 .132 r
.34704 .71561 m .3465 .71692 L .34669 .71417 L F
.737 .813 .911 r
.53105 .8057 m .53439 .80535 L .53398 .80645 L F
.248 0 .06 r
.53398 .80645 m .53439 .80535 L .53602 .80575 L F
.191 .703 .893 r
.63578 .51366 m .63853 .51362 L .63924 .51395 L F
.327 0 0 r
.53096 .76231 m .52975 .76373 L .52835 .76308 L F
0 0 0 r
.53227 .76119 m .53096 .76231 L .53285 .76373 L F
.53227 .76119 m .52975 .76373 L .53096 .76231 L F
.811 .732 .777 r
.68041 .5187 m .68363 .51897 L .68261 .51607 L F
.863 .638 .596 r
.68065 .52119 m .68363 .51897 L .68041 .5187 L F
.68065 .52119 m .68354 .52019 L .68363 .51897 L F
.614 .626 .839 r
.68261 .51607 m .68363 .51897 L .68629 .5178 L F
.413 .764 .995 r
.4298 .64965 m .43118 .65051 L .42766 .64982 L F
.388 .78 .988 r
.4298 .64965 m .43333 .65011 L .43118 .65051 L F
.719 .618 .744 r
.60604 .7481 m .60949 .74795 L .60805 .7448 L F
.621 .237 .295 r
.60823 .74997 m .60949 .74795 L .60604 .7481 L F
.991 .788 .536 r
.60932 .75037 m .60949 .74795 L .60823 .74997 L F
.345 0 0 r
.48827 .74455 m .49055 .74429 L .49202 .74272 L F
.445 .058 .21 r
.49055 .74429 m .49402 .74189 L .49202 .74272 L F
.136 .664 .872 r
.30355 .65109 m .30393 .65067 L .30172 .65095 L F
.30355 .65109 m .30536 .65105 L .30393 .65067 L F
.329 .004 .253 r
.42526 .68983 m .42669 .69071 L .42734 .6894 L F
.42526 .68983 m .42464 .69142 L .42669 .69071 L F
.624 .709 .907 r
.74207 .61414 m .74536 .61526 L .74445 .61358 L F
.594 .725 .935 r
.74536 .61526 m .74682 .61318 L .74445 .61358 L F
.74536 .61526 m .74785 .61472 L .74682 .61318 L F
.371 .243 .574 r
.72678 .50518 m .72702 .50749 L .72529 .50812 L F
.24 0 .273 r
.72702 .50749 m .7246 .51015 L .72529 .50812 L F
.923 .595 .133 r
.65761 .49774 m .65794 .49994 L .65601 .49505 L F
0 0 .338 r
.65601 .49505 m .65794 .49994 L .65736 .49812 L F
.65601 .49505 m .65736 .49812 L .65667 .49693 L F
0 0 .396 r
.65667 .49693 m .65736 .49812 L .65718 .49778 L F
.777 .312 .139 r
.65601 .49505 m .65667 .49693 L .65539 .4948 L F
0 0 .396 r
.65667 .49693 m .65718 .49778 L .65573 .49513 L F
.777 .312 .139 r
.65539 .4948 m .65667 .49693 L .65463 .49449 L F
.316 .448 .836 r
.64541 .49185 m .64536 .49244 L .64241 .48867 L F
.78 .279 0 r
.64143 .51109 m .63796 .50835 L .64008 .5078 L F
.64143 .51109 m .63894 .51 L .63796 .50835 L F
.483 .231 .456 r
.63894 .51 m .64008 .5078 L .63796 .50835 L F
.604 .775 .962 r
.632 .48478 m .6331 .48608 L .62972 .48544 L F
.632 .48478 m .6331 .48608 L .62972 .48544 L F
.681 .806 .942 r
.63543 .48511 m .6331 .48608 L .632 .48478 L F
.516 0 0 r
.63576 .48768 m .632 .48478 L .6331 .48608 L F
.09 0 0 r
.5753 .67654 m .57754 .67617 L .57851 .67554 L F
0 .445 .859 r
.58038 .67575 m .58214 .67714 L .57851 .67554 L F
.58038 .67575 m .57851 .67554 L .57754 .67617 L F
0 0 0 r
.70033 .51636 m .70218 .51532 L .70277 .51372 L F
.524 .809 .998 r
.70277 .51372 m .70437 .51243 L .70549 .51326 L F
.246 0 .054 r
.70277 .51372 m .70442 .51452 L .70437 .51243 L F
.70277 .51372 m .70218 .51532 L .70442 .51452 L F
.716 .244 .128 r
.54472 .72519 m .5488 .72726 L .54646 .72546 L F
.612 .847 .988 r
.2823 .63679 m .28058 .63757 L .27906 .63673 L F
.479 .789 .999 r
.56012 .74385 m .56138 .74478 L .55912 .74509 L F
.56012 .74385 m .56138 .74478 L .55912 .74509 L F
.654 .43 .567 r
.72381 .5992 m .72132 .59739 L .72135 .59991 L F
.72381 .5992 m .72395 .59736 L .72132 .59739 L F
.013 .574 .808 r
.4968 .77869 m .49525 .77832 L .49329 .77809 L F
.589 .1 .061 r
.4988 .77858 m .49525 .77832 L .4968 .77869 L F
.516 .843 .998 r
.49245 .77282 m .49548 .77288 L .49439 .77219 L F
.96 .624 .279 r
.49548 .77288 m .49605 .7755 L .49439 .77219 L F
.603 .236 .32 r
.49995 .75799 m .49778 .75621 L .49982 .75566 L F
.896 .525 .326 r
.49608 .75897 m .49714 .75997 L .49725 .75847 L F
.079 0 0 r
.49714 .75997 m .49995 .75799 L .49725 .75847 L F
.603 .236 .32 r
.49995 .75799 m .49608 .75897 L .49778 .75621 L F
.723 .645 .771 r
.44331 .66261 m .44274 .66407 L .44499 .66144 L F
.412 .825 .973 r
.29601 .63643 m .29972 .63651 L .29767 .63694 L F
.984 .884 .648 r
.67151 .49509 m .67066 .49881 L .67158 .49977 L F
.83 .391 .193 r
.67069 .5014 m .67158 .49977 L .67066 .49881 L F
.67069 .5014 m .67288 .50194 L .67158 .49977 L F
.513 .823 1 r
.64025 .49136 m .63892 .49053 L .63651 .49093 L F
.245 .525 .915 r
.64025 .49136 m .6412 .49025 L .63892 .49053 L F
.64025 .49136 m .64255 .4921 L .6412 .49025 L F
.462 .872 .951 r
.31585 .60434 m .31747 .60314 L .31479 .6029 L F
.31585 .60434 m .31837 .60359 L .31747 .60314 L F
.598 .532 .752 r
.71898 .60053 m .71932 .60257 L .72173 .60208 L F
.92 .933 .799 r
.49648 .80569 m .49949 .80318 L .49604 .80291 L F
.831 .36 0 r
.54812 .71389 m .54518 .71054 L .54617 .71149 L F
.8 .337 .137 r
.54963 .71405 m .54812 .71389 L .54617 .71149 L F
.957 .842 .689 r
.66825 .51582 m .66956 .51701 L .66869 .51902 L F
.862 .436 .205 r
.64143 .51109 m .64022 .51198 L .63894 .51 L F
.123 0 0 r
.64392 .51107 m .64022 .51198 L .64143 .51109 L F
.761 .852 .918 r
.5944 .75 m .59838 .74889 L .59694 .74989 L F
.629 .949 .754 r
.59838 .74889 m .59825 .74845 L .59694 .74989 L F
.59838 .74889 m .60005 .74759 L .59825 .74845 L F
.337 0 0 r
.3958 .6506 m .39766 .6511 L .39921 .65023 L F
.094 0 0 r
.39766 .6511 m .40158 .6504 L .39921 .65023 L F
.81 .992 .874 r
.67947 .52361 m .67909 .52534 L .68187 .52271 L F
0 .253 .728 r
.68042 .52583 m .67909 .52534 L .67947 .52361 L F
.68042 .52583 m .68304 .52802 L .67909 .52534 L F
.747 .67 .775 r
.68042 .52583 m .68175 .52897 L .68274 .52777 L F
.68042 .52583 m .68274 .52777 L .68401 .52622 L F
0 .253 .728 r
.68042 .52583 m .68304 .52802 L .68304 .52802 L F
.3 0 .228 r
.3338 .63058 m .33652 .6283 L .33578 .63 L F
.217 0 .236 r
.33578 .63 m .33652 .6283 L .33821 .62744 L F
.707 .383 .425 r
.68279 .53224 m .68639 .53075 L .68543 .52823 L F
.68279 .53224 m .68581 .53216 L .68639 .53075 L F
0 0 .024 r
.68639 .53075 m .68731 .53121 L .68866 .53 L F
.68639 .53075 m .68581 .53216 L .68731 .53121 L F
.095 .615 .882 r
.29612 .65054 m .29745 .65108 L .29969 .6513 L F
0 0 0 r
.70792 .51325 m .70979 .51217 L .71112 .51109 L F
0 0 .296 r
.71112 .51109 m .71181 .51052 L .7124 .50784 L F
.71181 .51052 m .71248 .50873 L .7124 .50784 L F
.047 .615 .714 r
.71395 .50835 m .71279 .50843 L .71453 .50666 L F
.059 0 .32 r
.71364 .50715 m .71395 .50835 L .71453 .50666 L F
.7124 .50784 m .71285 .50799 L .71364 .50715 L F
.71285 .50799 m .71395 .50835 L .71364 .50715 L F
.755 .678 .775 r
.71273 .50824 m .71279 .50843 L .71266 .50837 L F
.059 0 .32 r
.71248 .50873 m .71258 .50989 L .71285 .50799 L F
.619 .053 0 r
.71044 .50743 m .71134 .5085 L .70888 .50676 L F
.71279 .50843 m .71134 .5085 L .71044 .50743 L F
0 0 .296 r
.71181 .51052 m .71258 .50989 L .71248 .50873 L F
.811 .807 .847 r
.71258 .50989 m .70877 .51121 L .71134 .5085 L F
.378 .001 .192 r
.71134 .5085 m .71069 .51005 L .71185 .5091 L F
.047 .615 .714 r
.71395 .50835 m .71134 .5085 L .7127 .50844 L F
.059 0 .32 r
.7124 .50784 m .71248 .50873 L .71285 .50799 L F
.755 .678 .775 r
.7127 .50815 m .71273 .50824 L .71262 .50836 L F
.71273 .50824 m .71266 .50837 L .71262 .50836 L F
.643 .615 .807 r
.71453 .50666 m .71279 .50843 L .71126 .504 L F
.047 .615 .714 r
.71395 .50835 m .7127 .50844 L .71279 .50843 L F
.059 0 .32 r
.71279 .50843 m .71258 .50989 L .71395 .50835 L F
.686 .813 .943 r
.71395 .50835 m .71258 .50989 L .71134 .5085 L F
.378 .001 .192 r
.71134 .5085 m .71185 .5091 L .71307 .5081 L F
.059 0 .32 r
.71285 .50799 m .71279 .50843 L .71395 .50835 L F
.755 .678 .775 r
.71126 .504 m .7127 .50815 L .70888 .50676 L F
.7127 .50815 m .7127 .50815 L .71269 .50815 L F
.7127 .50815 m .71269 .50815 L .70888 .50676 L F
.7127 .50815 m .71262 .50836 L .70888 .50676 L F
.449 .813 .548 r
.71112 .51109 m .70979 .51217 L .71258 .50989 L F
.595 .945 .917 r
.55781 .74661 m .55645 .7474 L .55681 .74778 L F
.345 .114 .414 r
.55781 .74661 m .55733 .74724 L .55645 .7474 L F
.301 .772 .935 r
.55681 .74778 m .55645 .7474 L .55462 .74775 L F
.327 0 .036 r
.55337 .74988 m .55681 .74778 L .55354 .74773 L F
.55337 .74988 m .55563 .74949 L .55681 .74778 L F
0 0 0 r
.55681 .74778 m .55563 .74949 L .55781 .74661 L F
.345 .114 .414 r
.55733 .74724 m .55563 .74949 L .55645 .7474 L F
.301 .772 .935 r
.55462 .74775 m .55645 .7474 L .55354 .74773 L F
.484 .746 .986 r
.77291 .60795 m .7748 .60634 L .77197 .60689 L F
.77291 .60795 m .77531 .60767 L .7748 .60634 L F
.77291 .60795 m .7748 .60634 L .77197 .60689 L F
.77291 .60795 m .77531 .60767 L .7748 .60634 L F
0 0 0 r
.64072 .55169 m .6445 .55051 L .6429 .55062 L F
.551 .841 .51 r
.64574 .54908 m .6445 .55051 L .64683 .54797 L F
.644 .965 .899 r
.64574 .54908 m .6429 .55062 L .6445 .55051 L F
.518 .241 .434 r
.44537 .69312 m .4431 .69196 L .44533 .69152 L F
.44537 .69312 m .44243 .69382 L .4431 .69196 L F
.517 .351 .595 r
.36165 .6644 m .36373 .66392 L .36379 .66133 L F
.509 .429 .702 r
.36165 .6644 m .36409 .66627 L .36373 .66392 L F
.36165 .6644 m .36215 .66674 L .36409 .66627 L F
.572 .517 .756 r
.47689 .66188 m .47349 .65861 L .47597 .65805 L F
.468 .196 .417 r
.59323 .56919 m .59048 .57166 L .59071 .56967 L F
0 .434 .801 r
.65034 .51227 m .65307 .5133 L .65149 .51243 L F
.831 .398 0 r
.57223 .74978 m .57345 .75245 L .57428 .7531 L F
.954 .655 .428 r
.57164 .74773 m .57345 .75245 L .57223 .74978 L F
.917 .882 .784 r
.65798 .48945 m .65684 .49089 L .65614 .48958 L F
.553 .806 .992 r
.7681 .57864 m .76673 .5802 L .76575 .57959 L F
.7681 .57864 m .76908 .57973 L .76673 .5802 L F
.021 0 .163 r
.56389 .77812 m .56285 .78051 L .56355 .77875 L F
.618 .491 .685 r
.56574 .77553 m .56585 .77846 L .56389 .77812 L F
.747 .57 .655 r
.56585 .77846 m .56285 .78051 L .56389 .77812 L F
0 0 .431 r
.55142 .7851 m .55057 .78692 L .55167 .78577 L F
0 0 .228 r
.55167 .78577 m .55057 .78692 L .55044 .78918 L F
.673 .342 .405 r
.56555 .68622 m .56852 .68591 L .56881 .68422 L F
0 0 0 r
.56881 .68422 m .569 .68437 L .57007 .68256 L F
.527 .21 .373 r
.57092 .68555 m .56852 .68591 L .56881 .68422 L F
0 0 0 r
.56881 .68422 m .56852 .68591 L .569 .68437 L F
.527 .21 .373 r
.57092 .68555 m .56881 .68422 L .5711 .68358 L F
.397 .005 .173 r
.52252 .7368 m .5215 .73872 L .5193 .73897 L F
.327 0 .137 r
.52377 .7382 m .52252 .7368 L .5247 .73607 L F
.52377 .7382 m .5215 .73872 L .52252 .7368 L F
.523 .211 .38 r
.37011 .65764 m .36848 .65587 L .36821 .6582 L F
.37011 .65764 m .37082 .65564 L .36848 .65587 L F
.687 .69 .847 r
.68108 .51676 m .67949 .51845 L .67725 .51622 L F
.835 .707 .723 r
.59798 .54352 m .59822 .54773 L .59633 .54661 L F
.873 .738 .709 r
.59633 .54661 m .59822 .54773 L .5974 .54985 L F
.743 .61 .711 r
.58304 .73617 m .5863 .73656 L .58481 .73366 L F
.647 .371 .486 r
.58348 .73884 m .5863 .73656 L .58304 .73617 L F
.58348 .73884 m .58607 .73903 L .5863 .73656 L F
.049 0 .322 r
.5863 .73656 m .58746 .73795 L .58885 .73846 L F
.5863 .73656 m .58607 .73903 L .58746 .73795 L F
.58 .257 .387 r
.5863 .73656 m .58885 .73846 L .58888 .73654 L F
0 0 0 r
.64742 .54767 m .64683 .54797 L .64876 .5467 L F
.64742 .54767 m .64574 .54908 L .64683 .54797 L F
.37 .714 .987 r
.47847 .79521 m .47989 .79564 L .47845 .79443 L F
.47847 .79521 m .47989 .79564 L .47845 .79443 L F
.506 .805 .999 r
.47989 .79564 m .48097 .7939 L .47845 .79443 L F
.513 .194 .364 r
.48206 .79694 m .48283 .79526 L .47989 .79564 L F
0 .241 .694 r
.48206 .79694 m .47989 .79564 L .47845 .79443 L F
.328 0 0 r
.48068 .7965 m .47923 .79785 L .48097 .79746 L F
.706 .552 .677 r
.48206 .79694 m .48444 .79401 L .48283 .79526 L F
.48206 .79694 m .48544 .79744 L .48444 .79401 L F
0 .132 .675 r
.48361 .79687 m .48206 .79694 L .48068 .7965 L F
.709 .423 .489 r
.48206 .79694 m .48658 .79788 L .48544 .79744 L F
.48206 .79694 m .4841 .79974 L .48658 .79788 L F
0 .132 .675 r
.48361 .79687 m .4841 .79974 L .48206 .79694 L F
.328 0 0 r
.48068 .7965 m .48097 .79746 L .48361 .79687 L F
0 .241 .694 r
.48206 .79694 m .48077 .79604 L .48068 .7965 L F
.537 .223 .383 r
.48296 .79566 m .48056 .79707 L .48068 .7965 L F
.48056 .79707 m .47923 .79785 L .48068 .7965 L F
0 .241 .694 r
.48077 .79604 m .48048 .79584 L .48068 .7965 L F
.48048 .79584 m .47869 .79459 L .48068 .7965 L F
.47869 .79459 m .47845 .79443 L .47858 .79454 L F
.47869 .79459 m .47858 .79454 L .48068 .7965 L F
.506 .805 .999 r
.48015 .79523 m .48283 .79526 L .48097 .7939 L F
.47989 .79564 m .48082 .79552 L .48015 .79523 L F
.48082 .79552 m .48283 .79526 L .48015 .79523 L F
.515 .735 .974 r
.6744 .48143 m .6731 .48298 L .67208 .48171 L F
.394 .552 .893 r
.6744 .48143 m .67493 .48316 L .6731 .48298 L F
.918 .961 .642 r
.50501 .81153 m .50612 .81098 L .50442 .81379 L F
.76 .555 .62 r
.50612 .81098 m .50742 .81338 L .50442 .81379 L F
.065 .3 .786 r
.50494 .80839 m .50612 .81098 L .50792 .81104 L F
.918 .961 .642 r
.50501 .81153 m .50612 .81098 L .50442 .81379 L F
.05 0 0 r
.50792 .81104 m .50612 .81098 L .50501 .81153 L F
.631 .37 .504 r
.3475 .70599 m .34939 .70845 L .35023 .70619 L F
.887 .822 .778 r
.62 .50324 m .61711 .50442 L .61854 .50235 L F
.679 .84 .961 r
.62061 .50138 m .62 .50324 L .61854 .50235 L F
.783 .698 .77 r
.56618 .76686 m .5695 .76712 L .56849 .76395 L F
.708 .289 .249 r
.5695 .76712 m .56846 .76892 L .56618 .76686 L F
.487 .522 .818 r
.56849 .76395 m .5695 .76712 L .57235 .76472 L F
0 0 0 r
.5695 .76712 m .56846 .76892 L .57235 .76472 L F
.708 .289 .249 r
.56618 .76686 m .56846 .76892 L .5695 .76712 L F
.56618 .76686 m .56846 .76892 L .5695 .76712 L F
.93 .742 .626 r
.61404 .53809 m .61538 .54136 L .61556 .53892 L F
.898 .812 .754 r
.6151 .53573 m .61404 .53809 L .61556 .53892 L F
.981 .705 .421 r
.60604 .7481 m .60601 .75048 L .60476 .74932 L F
.831 .777 .801 r
.60604 .7481 m .6063 .74413 L .60518 .74502 L F
.60604 .7481 m .60805 .7448 L .6063 .74413 L F
.668 .185 .095 r
.60476 .74932 m .60823 .74997 L .60604 .7481 L F
.147 .684 .841 r
.33091 .59332 m .33305 .59324 L .33496 .59344 L F
0 .459 .825 r
.33516 .5931 m .33496 .59344 L .33305 .59324 L F
.33516 .5931 m .33663 .59397 L .33496 .59344 L F
.797 .593 .625 r
.52313 .76734 m .52271 .77004 L .52016 .76972 L F
.684 .485 .611 r
.52627 .76969 m .52271 .77004 L .52313 .76734 L F
.13 .667 .851 r
.28294 .58615 m .28509 .58615 L .28655 .58641 L F
.03 .602 .723 r
.28509 .58615 m .2886 .58609 L .28655 .58641 L F
.078 0 0 r
.3158 .64711 m .31279 .64883 L .31418 .64738 L F
.551 .413 .646 r
.3602 .68363 m .36223 .6834 L .36199 .68072 L F
.079 .64 .739 r
.5893 .68343 m .58869 .68342 L .58565 .68364 L F
.972 .763 .335 r
.58869 .6805 m .58869 .68342 L .5893 .68343 L F
.476 0 0 r
.7317 .59634 m .72928 .59549 L .72944 .59592 L F
.48 .637 .924 r
.64377 .48691 m .64241 .48867 L .64007 .48655 L F
.358 .461 .829 r
.64377 .48691 m .64557 .49089 L .64241 .48867 L F
.316 .448 .836 r
.64541 .49185 m .64241 .48867 L .64557 .49089 L F
.211 .703 .921 r
.35296 .70889 m .34939 .70845 L .35115 .70861 L F
0 0 .385 r
.64245 .50262 m .64466 .49974 L .64476 .50215 L F
.64245 .50262 m .64313 .49955 L .64466 .49974 L F
.64245 .50262 m .64327 .5023 L .64296 .50033 L F
.763 .436 .434 r
.64321 .50196 m .64021 .50353 L .64287 .50143 L F
.64392 .50304 m .64327 .5023 L .64321 .50196 L F
.225 0 .15 r
.64327 .5023 m .64392 .50304 L .6434 .50226 L F
.64245 .50262 m .64392 .50304 L .64327 .5023 L F
.763 .436 .434 r
.64392 .50304 m .64339 .50311 L .64327 .5023 L F
.225 0 .15 r
.64245 .50262 m .64199 .50403 L .64392 .50304 L F
.763 .436 .434 r
.64339 .50311 m .64021 .50353 L .64321 .50196 L F
0 0 .385 r
.64296 .50033 m .6434 .50226 L .64313 .49955 L F
.64327 .5023 m .6434 .50226 L .64296 .50033 L F
.513 .449 .722 r
.36532 .69504 m .36665 .69131 L .36491 .69205 L F
.36532 .69504 m .36723 .69468 L .36665 .69131 L F
.518 .474 .748 r
.36532 .69504 m .36803 .69702 L .36723 .69468 L F
.551 .472 .72 r
.36589 .69741 m .36803 .69702 L .36532 .69504 L F
.553 .544 .798 r
.35811 .59991 m .35704 .60262 L .35612 .60054 L F
.35811 .59991 m .35915 .60193 L .35704 .60262 L F
.453 .366 .667 r
.35908 .60566 m .35704 .60262 L .35915 .60193 L F
.35908 .60566 m .35718 .60569 L .35704 .60262 L F
.392 .779 .99 r
.43333 .65011 m .43552 .64989 L .43692 .65061 L F
.476 .838 .993 r
.43552 .64989 m .43909 .65001 L .43692 .65061 L F
.462 0 0 r
.29187 .58688 m .29415 .5881 L .29586 .58863 L F
.181 .624 .941 r
.29619 .58791 m .29586 .58863 L .29415 .5881 L F
.29619 .58791 m .29768 .58883 L .29586 .58863 L F
.688 .687 .844 r
.67812 .49348 m .68113 .49416 L .68011 .49288 L F
.676 .737 .897 r
.68011 .49288 m .68113 .49416 L .68344 .4935 L F
.52 .517 .793 r
.36384 .68972 m .36491 .69205 L .36665 .69131 L F
.364 .607 .942 r
.34475 .5949 m .34417 .59641 L .34202 .59456 L F
.34475 .5949 m .34588 .59642 L .34417 .59641 L F
.55 .355 .569 r
.32528 .75052 m .32762 .75039 L .32782 .74771 L F
.32528 .75052 m .32762 .75039 L .32782 .74771 L F
.348 .78 .969 r
.45049 .64895 m .45253 .64872 L .45389 .64927 L F
.594 .896 .988 r
.45389 .64927 m .45464 .64792 L .45614 .64811 L F
.45389 .64927 m .45253 .64872 L .45464 .64792 L F
.259 0 0 r
.24849 .59076 m .25057 .59033 L .25222 .58869 L F
.223 0 0 r
.25057 .59033 m .25428 .58824 L .25222 .58869 L F
.316 .05 .343 r
.58812 .70729 m .58675 .70966 L .58804 .70841 L F
.055 0 .257 r
.58804 .70841 m .58988 .7051 L .58812 .70729 L F
.318 .271 .647 r
.58726 .72835 m .58889 .72733 L .58856 .7245 L F
.45 .543 .86 r
.58726 .72835 m .58962 .72865 L .58889 .72733 L F
.78 .828 .89 r
.67916 .49937 m .67793 .50146 L .67665 .50164 L F
.845 .597 .564 r
.60586 .73858 m .60869 .7366 L .6062 .73626 L F
.60586 .73858 m .60884 .73897 L .60869 .7366 L F
.524 .162 .295 r
.54549 .76885 m .54352 .76762 L .54283 .7684 L F
.856 .974 .663 r
.60107 .74466 m .60005 .74759 L .60161 .74561 L F
.60107 .74466 m .59966 .74734 L .60005 .74759 L F
.759 .989 .772 r
.60005 .74759 m .59966 .74734 L .59825 .74845 L F
.904 .911 .817 r
.59652 .55826 m .59492 .56086 L .59344 .56027 L F
.974 .708 .462 r
.59492 .56086 m .59493 .56389 L .59344 .56027 L F
.413 .834 .964 r
.76953 .61964 m .77102 .61879 L .76861 .6192 L F
.76953 .61964 m .77192 .61917 L .77102 .61879 L F
.532 .426 .679 r
.38801 .6832 m .38566 .68121 L .38784 .68067 L F
.38801 .6832 m .38593 .68361 L .38566 .68121 L F
0 0 0 r
.29603 .60318 m .29401 .60391 L .29203 .60425 L F
.128 0 0 r
.29796 .6024 m .29401 .60391 L .29603 .60318 L F
.119 0 0 r
.40158 .6504 m .40356 .65006 L .40489 .6494 L F
.442 0 0 r
.40489 .6494 m .40356 .65006 L .40706 .64968 L F
.886 .512 .327 r
.55078 .70536 m .55232 .70865 L .55389 .70888 L F
.622 .061 0 r
.55232 .70865 m .55291 .70935 L .55389 .70888 L F
.617 .05 0 r
.55291 .70935 m .55613 .71082 L .55389 .70888 L F
.716 .24 .117 r
.55389 .70888 m .55613 .71082 L .55755 .71061 L F
.505 .275 .499 r
.46112 .76163 m .46291 .76364 L .46313 .76112 L F
.46112 .76163 m .46087 .76412 L .46291 .76364 L F
.69 .531 .666 r
.48067 .67805 m .48092 .68074 L .47841 .68075 L F
.609 .909 .636 r
.48319 .67562 m .48145 .67698 L .48067 .67805 L F
.162 .424 .862 r
.48145 .67698 m .48353 .68002 L .48067 .67805 L F
.584 .453 .668 r
.48353 .68002 m .48092 .68074 L .48067 .67805 L F
.627 .404 .559 r
.47841 .68075 m .4765 .68311 L .47549 .68076 L F
.996 .77 .417 r
.57337 .75492 m .57428 .7531 L .57345 .75245 L F
.57337 .75492 m .5742 .75569 L .57428 .7531 L F
.465 .813 .998 r
.32173 .59221 m .31981 .59259 L .31815 .59185 L F
.516 .361 .61 r
.46347 .75631 m .46521 .75812 L .46568 .75611 L F
.491 .207 .41 r
.46568 .75611 m .46521 .75812 L .46747 .75754 L F
.568 .173 .253 r
.46568 .75611 m .46747 .75754 L .46809 .75631 L F
.887 .799 .758 r
.50539 .75806 m .509 .75598 L .50505 .75576 L F
.50539 .75806 m .50692 .75874 L .509 .75598 L F
.714 .526 .633 r
.50692 .75874 m .50908 .75848 L .509 .75598 L F
.673 .501 .644 r
.50908 .75848 m .51226 .75634 L .509 .75598 L F
.186 0 0 r
.41752 .70654 m .41689 .70552 L .41901 .70501 L F
.41752 .70654 m .4154 .7071 L .41689 .70552 L F
.516 .361 .61 r
.46347 .75631 m .46312 .75876 L .46521 .75812 L F
.915 .681 .182 r
.59915 .69427 m .59926 .69649 L .59975 .69735 L F
.97 .906 .554 r
.59975 .69735 m .59926 .69649 L .59839 .69918 L F
.602 .54 .757 r
.76397 .60793 m .76505 .61211 L .76754 .6115 L F
.599 .787 .971 r
.76754 .6115 m .76505 .61211 L .76384 .61074 L F
.4 .102 .34 r
.74564 .59132 m .74326 .59202 L .74284 .59334 L F
.741 .299 .203 r
.55145 .7146 m .54812 .71389 L .54963 .71405 L F
0 .051 .618 r
.56202 .73659 m .5641 .7392 L .56354 .73946 L F
.363 0 0 r
.56506 .74035 m .56628 .74092 L .56354 .73946 L F
.56506 .74035 m .56354 .73946 L .5641 .7392 L F
.132 0 0 r
.71335 .52195 m .71291 .52236 L .70877 .52302 L F
0 0 0 r
.71509 .52148 m .71335 .52195 L .71567 .52132 L F
.71509 .52148 m .71291 .52236 L .71335 .52195 L F
.946 .76 .296 r
.59401 .68578 m .59387 .68862 L .59434 .68949 L F
0 0 .42 r
.59387 .68862 m .59444 .69145 L .59434 .68949 L F
.839 .504 .42 r
.59434 .68949 m .59444 .69145 L .59686 .69178 L F
.732 .515 .598 r
.55962 .7111 m .56305 .7134 L .5627 .71212 L F
.92 .692 .576 r
.60116 .72211 m .60255 .725 L .60254 .72262 L F
.8 .673 .724 r
.49024 .803 m .49123 .80576 L .48888 .80578 L F
.732 .367 .359 r
.48888 .80578 m .49123 .80576 L .49037 .8081 L F
.833 .526 .47 r
.49024 .803 m .4937 .80604 L .49123 .80576 L F
.652 .413 .545 r
.49123 .80576 m .49357 .8084 L .49037 .8081 L F
.49123 .80576 m .4937 .80604 L .49357 .8084 L F
0 0 0 r
.5434 .70828 m .54356 .70774 L .54381 .70537 L F
0 .047 .612 r
.5434 .70828 m .54518 .71054 L .54356 .70774 L F
.508 .392 .656 r
.36231 .67001 m .36409 .66627 L .36215 .66674 L F
.395 .004 .173 r
.41457 .69473 m .41566 .69644 L .41661 .69405 L F
.41457 .69473 m .41333 .69687 L .41566 .69644 L F
.735 .237 .049 r
.55856 .71738 m .55766 .71827 L .55542 .71606 L F
.595 .063 0 r
.55856 .71738 m .56113 .7188 L .55766 .71827 L F
.493 0 0 r
.56273 .71919 m .56113 .7188 L .55856 .71738 L F
.406 0 0 r
.66121 .48165 m .66616 .48103 L .66378 .48144 L F
.474 .496 .8 r
.64231 .52874 m .6394 .53012 L .64158 .52773 L F
.662 .404 .519 r
.44875 .68955 m .44798 .69209 L .44533 .69152 L F
.408 .157 .418 r
.44996 .69147 m .44875 .68955 L .45097 .68893 L F
.44996 .69147 m .44798 .69209 L .44875 .68955 L F
.774 .737 .819 r
.39013 .83939 m .39174 .84139 L .39238 .84014 L F
.492 .392 .669 r
.39238 .84014 m .39365 .84197 L .39174 .84139 L F
.855 .704 .694 r
.49448 .74795 m .49639 .7505 L .49507 .74734 L F
.615 .42 .595 r
.6208 .56391 m .62142 .56544 L .61844 .56695 L F
.573 .279 .431 r
.6208 .56391 m .62343 .56589 L .62142 .56544 L F
.6208 .56391 m .6234 .5638 L .62343 .56589 L F
.544 .572 .834 r
.2578 .6543 m .25869 .65163 L .25725 .65289 L F
.2578 .6543 m .25985 .65401 L .25869 .65163 L F
.156 0 .192 r
.56635 .68872 m .56389 .6914 L .56468 .68966 L F
.68 .557 .708 r
.44215 .66122 m .44499 .66144 L .44399 .66055 L F
.44215 .66122 m .44331 .66261 L .44499 .66144 L F
.417 .048 .229 r
.39225 .71468 m .3894 .71612 L .39032 .71526 L F
.961 .773 .606 r
.63336 .51417 m .63183 .51518 L .63007 .51344 L F
.63336 .51417 m .63317 .51622 L .63183 .51518 L F
.708 .209 .052 r
.63349 .51305 m .63578 .51366 L .63336 .51417 L F
.729 .743 .863 r
.71762 .49102 m .71583 .49374 L .71431 .49051 L F
.624 .714 .911 r
.71883 .49413 m .71583 .49374 L .71762 .49102 L F
.197 0 0 r
.58214 .67714 m .58448 .67751 L .5821 .67809 L F
.406 .351 .683 r
.58279 .68039 m .5844 .68004 L .5821 .67809 L F
.58279 .68039 m .5844 .68004 L .5821 .67809 L F
.219 0 0 r
.53062 .72477 m .53282 .72433 L .53379 .72312 L F
.342 0 .033 r
.53282 .72433 m .53561 .7236 L .53379 .72312 L F
.441 .146 .367 r
.3287 .63589 m .32826 .63845 L .32619 .63883 L F
.362 .136 .43 r
.33096 .6332 m .33088 .63568 L .3287 .63589 L F
.408 .118 .358 r
.33042 .63787 m .3287 .63589 L .33088 .63568 L F
.33042 .63787 m .32826 .63845 L .3287 .63589 L F
.405 .825 .968 r
.28607 .65184 m .28672 .651 L .28473 .65132 L F
.28607 .65184 m .28844 .65142 L .28672 .651 L F
.512 .853 .995 r
.49678 .78581 m .49568 .78689 L .49397 .78452 L F
.49678 .78581 m .49802 .78643 L .49568 .78689 L F
.717 .457 .532 r
.59608 .69421 m .59752 .6926 L .59686 .69178 L F
0 0 0 r
.75576 .58378 m .75799 .58304 L .75839 .5827 L F
.75839 .5827 m .76028 .58215 L .76126 .58157 L F
.75839 .5827 m .75799 .58304 L .76028 .58215 L F
.319 0 .089 r
.30187 .63611 m .30404 .63564 L .30548 .63358 L F
.224 0 .033 r
.30548 .63358 m .30611 .63492 L .30751 .63305 L F
.30548 .63358 m .30404 .63564 L .30611 .63492 L F
.665 .328 .393 r
.46995 .68559 m .46706 .68415 L .47037 .68354 L F
.46995 .68559 m .46687 .68575 L .46706 .68415 L F
.372 .342 .696 r
.45852 .77834 m .45983 .77497 L .4581 .77529 L F
.45852 .77834 m .46052 .77765 L .45983 .77497 L F
.396 .238 .546 r
.45827 .78067 m .46052 .77765 L .45852 .77834 L F
.278 0 .23 r
.33096 .6332 m .3338 .63058 L .33301 .63225 L F
.404 .111 .351 r
.33301 .63225 m .3338 .63058 L .33578 .63 L F
.701 .64 .785 r
.59267 .56581 m .59314 .56694 L .59245 .56637 L F
.59267 .56581 m .59294 .56589 L .59284 .56598 L F
.668 .636 .809 r
.59284 .56598 m .59267 .56581 L .59245 .56637 L F
.701 .64 .785 r
.59267 .56581 m .59284 .56598 L .59277 .56605 L F
.797 .737 .797 r
.59493 .56389 m .59541 .56665 L .59267 .56581 L F
.668 .636 .809 r
.59493 .56389 m .59267 .56581 L .59284 .56598 L F
.59493 .56389 m .59284 .56598 L .59125 .5662 L F
.59284 .56598 m .59245 .56637 L .59242 .56636 L F
.59284 .56598 m .59242 .56636 L .59125 .5662 L F
.701 .64 .785 r
.59277 .56605 m .59541 .56665 L .59314 .56694 L F
.59294 .56589 m .59541 .56665 L .59277 .56605 L F
.69 .537 .674 r
.59314 .56694 m .59541 .56665 L .59323 .56919 L F
.61 .938 .952 r
.27345 .65362 m .2753 .65375 L .27698 .65284 L F
.257 .512 .905 r
.64774 .49164 m .65035 .49266 L .6497 .49401 L F
.11 .324 .796 r
.65035 .49266 m .65193 .49564 L .6497 .49401 L F
.495 .274 .508 r
.34549 .61689 m .34512 .61915 L .34301 .61971 L F
.364 .16 .464 r
.34694 .61835 m .34549 .61689 L .34749 .6165 L F
.34694 .61835 m .34512 .61915 L .34549 .61689 L F
.371 0 .07 r
.55234 .7631 m .55172 .76255 L .55351 .76131 L F
.55234 .7631 m .55028 .76378 L .55172 .76255 L F
.958 .779 .619 r
.60581 .73349 m .60609 .73125 L .6048 .7307 L F
.77 .901 .933 r
.35328 .70599 m .35406 .70344 L .35583 .70568 L F
.369 .599 .936 r
.35585 .70315 m .35583 .70568 L .35406 .70344 L F
.763 .671 .761 r
.35959 .70349 m .35848 .70785 L .35831 .70571 L F
.812 .723 .766 r
.3571 .70714 m .35848 .70785 L .3589 .70618 L F
.35822 .7055 m .3589 .70618 L .35959 .70349 L F
.3571 .70714 m .3589 .70618 L .35822 .7055 L F
.369 .599 .936 r
.35585 .70316 m .35831 .70571 L .35583 .70568 L F
.35585 .70315 m .35596 .70327 L .35585 .70316 L F
.35596 .70327 m .35831 .70571 L .35585 .70316 L F
.886 .882 .824 r
.61521 .51267 m .61454 .51045 L .61559 .51134 L F
.61521 .51267 m .6125 .51306 L .61454 .51045 L F
.947 .892 .743 r
.61266 .5158 m .6125 .51306 L .61521 .51267 L F
0 0 0 r
.27937 .65263 m .28047 .65227 L .28266 .65168 L F
.752 .243 0 r
.54714 .70295 m .54947 .7052 L .55078 .70536 L F
.816 .955 .907 r
.55078 .70536 m .54947 .7052 L .55091 .7045 L F
.815 .497 .453 r
.54939 .70773 m .55078 .70536 L .54947 .7052 L F
.54939 .70773 m .55232 .70865 L .55078 .70536 L F
.822 .381 .188 r
.67015 .53182 m .67092 .53038 L .67198 .53234 L F
.574 .223 .336 r
.51337 .81184 m .5143 .81408 L .51198 .81382 L F
.51337 .81184 m .51554 .81159 L .5143 .81408 L F
.69 .671 .827 r
.72059 .4912 m .71883 .49413 L .71762 .49102 L F
.631 .593 .793 r
.72059 .4912 m .72127 .49387 L .71883 .49413 L F
.593 .722 .934 r
.28612 .63817 m .2823 .63679 L .28455 .63711 L F
.523 .798 .996 r
.2867 .63666 m .28612 .63817 L .28455 .63711 L F
.2867 .63666 m .28815 .63772 L .28612 .63817 L F
.056 0 .201 r
.77891 .61332 m .77897 .61539 L .777 .61645 L F
0 0 0 r
.78182 .61057 m .78071 .61212 L .77891 .61332 L F
0 0 .187 r
.78071 .61212 m .77897 .61539 L .77891 .61332 L F
0 0 0 r
.49927 .79451 m .50237 .79174 L .5018 .79233 L F
0 0 .071 r
.50237 .79174 m .50333 .78923 L .50389 .79153 L F
.665 .146 0 r
.5036 .79372 m .50237 .79174 L .50389 .79153 L F
.5036 .79372 m .5018 .79233 L .50237 .79174 L F
0 .28 .783 r
.57825 .7188 m .57895 .72017 L .5784 .71969 L F
.227 0 0 r
.68271 .54109 m .68184 .54101 L .67961 .54052 L F
.219 .74 .844 r
.68519 .54078 m .68184 .54101 L .68271 .54109 L F
.695 .786 .921 r
.55991 .77894 m .55986 .77892 L .55722 .78057 L F
.75 .585 .67 r
.56062 .77844 m .56002 .77881 L .55771 .77874 L F
.695 .786 .921 r
.55991 .77894 m .56047 .77878 L .55986 .77892 L F
.75 .585 .67 r
.56101 .7784 m .56028 .77882 L .56002 .77881 L F
.56101 .7784 m .56002 .77881 L .56062 .77844 L F
.56101 .7784 m .56073 .77879 L .56028 .77882 L F
.56073 .77879 m .56071 .77882 L .56035 .77882 L F
.56073 .77879 m .56035 .77882 L .56028 .77882 L F
.695 .786 .921 r
.56032 .77882 m .56051 .77878 L .56047 .77878 L F
.56035 .77882 m .56051 .77878 L .56032 .77882 L F
.75 .585 .67 r
.56101 .7784 m .56097 .77869 L .56071 .77882 L F
.695 .786 .921 r
.55906 .77864 m .56112 .77862 L .55608 .77761 L F
.747 .752 .857 r
.55608 .77761 m .56033 .77846 L .55814 .77702 L F
.56033 .77846 m .56112 .77862 L .56045 .77826 L F
.56033 .77846 m .56045 .77826 L .55814 .77702 L F
.589 .752 .956 r
.55814 .77702 m .56112 .77862 L .56172 .77732 L F
.282 .167 .541 r
.56035 .77882 m .56172 .77732 L .56112 .77862 L F
.695 .786 .921 r
.56051 .77878 m .56112 .77862 L .55906 .77864 L F
.282 .167 .541 r
.56001 .77885 m .56172 .77732 L .56035 .77882 L F
.601 .32 .463 r
.56355 .77875 m .56319 .77904 L .56101 .7784 L F
.56319 .77904 m .56063 .78107 L .56095 .77882 L F
.56319 .77904 m .56095 .77882 L .56101 .7784 L F
.282 .167 .541 r
.5602 .77868 m .56155 .77915 L .56172 .77732 L F
.695 .786 .921 r
.55986 .77892 m .56047 .77878 L .55906 .77864 L F
.282 .167 .541 r
.56001 .77885 m .56009 .77886 L .5602 .77868 L F
.695 .786 .921 r
.55991 .77894 m .56035 .77882 L .56032 .77882 L F
.75 .585 .67 r
.56097 .77869 m .5587 .78079 L .5597 .77933 L F
.282 .167 .541 r
.56009 .77886 m .56155 .77915 L .5602 .77868 L F
.75 .585 .67 r
.56028 .77882 m .56026 .77883 L .55752 .77945 L F
.282 .167 .541 r
.55991 .77894 m .55995 .7789 L .56035 .77882 L F
.55995 .7789 m .56026 .77883 L .56035 .77882 L F
.75 .585 .67 r
.56026 .77883 m .55999 .77898 L .55995 .7789 L F
.282 .167 .541 r
.55995 .7789 m .56 .77895 L .56001 .77885 L F
.55991 .77894 m .55997 .77895 L .55995 .7789 L F
.55997 .77895 m .56 .77895 L .55995 .7789 L F
.75 .585 .67 r
.55995 .7789 m .55722 .78057 L .55751 .77948 L F
.029 0 .12 r
.5597 .77933 m .55991 .77894 L .55722 .78057 L F
.75 .585 .67 r
.56028 .77882 m .56071 .77882 L .55956 .7794 L F
.56097 .77869 m .56063 .78107 L .55975 .78094 L F
.56097 .77869 m .55975 .78094 L .55991 .77967 L F
.601 .32 .463 r
.56355 .77875 m .56285 .78051 L .56063 .78107 L F
.317 0 .231 r
.56 .77895 m .56087 .78194 L .56155 .77915 L F
.55991 .77894 m .55994 .77901 L .55997 .77895 L F
.75 .585 .67 r
.55997 .77895 m .55722 .78057 L .55995 .7789 L F
.55998 .77895 m .55997 .77896 L .55997 .77895 L F
.55997 .77896 m .55722 .78057 L .55997 .77895 L F
.55999 .77898 m .55993 .77902 L .55998 .77895 L F
.317 0 .231 r
.55997 .77895 m .55994 .77901 L .56 .77895 L F
.55991 .77894 m .55986 .77911 L .55994 .77901 L F
.75 .585 .67 r
.55993 .77902 m .55722 .78057 L .55998 .77895 L F
.317 0 .231 r
.55994 .77901 m .55994 .77901 L .55997 .77895 L F
.55994 .77901 m .56087 .78194 L .56 .77895 L F
.75 .585 .67 r
.55966 .7793 m .55956 .7794 L .55948 .77944 L F
.56028 .77882 m .55956 .7794 L .55966 .7793 L F
.029 0 .12 r
.5597 .77933 m .55987 .77907 L .55991 .77894 L F
.75 .585 .67 r
.55993 .77902 m .55948 .77944 L .55722 .78057 L F
.56028 .77882 m .55948 .77944 L .55993 .77902 L F
.55991 .77967 m .55975 .78094 L .5587 .78079 L F
.879 .759 .726 r
.56063 .78107 m .56003 .78439 L .55783 .78272 L F
.56063 .78107 m .55783 .78272 L .55722 .78057 L F
.317 0 .231 r
.55994 .77901 m .55886 .78258 L .56087 .78194 L F
.55994 .77901 m .55993 .77902 L .55994 .77901 L F
.55993 .77902 m .55886 .78258 L .55994 .77901 L F
.55986 .77911 m .55886 .78258 L .55994 .77901 L F
.75 .585 .67 r
.56026 .77883 m .55751 .77948 L .55752 .77945 L F
.56028 .77882 m .55752 .77945 L .55771 .77874 L F
.282 .167 .541 r
.55995 .7789 m .56001 .77885 L .56026 .77883 L F
.56 .77895 m .56155 .77915 L .56001 .77885 L F
.75 .585 .67 r
.5597 .77933 m .5587 .78079 L .55722 .78057 L F
.029 0 .12 r
.55783 .78272 m .55886 .78258 L .55987 .77907 L F
.55783 .78272 m .55987 .77907 L .5597 .77933 L F
.55783 .78272 m .5597 .77933 L .55722 .78057 L F
.695 .786 .921 r
.55986 .77892 m .55608 .77761 L .55722 .78057 L F
.188 0 .272 r
.56852 .68591 m .56635 .68872 L .56698 .6868 L F
.598 .532 .752 r
.71898 .60053 m .72173 .60208 L .72135 .59991 L F
.375 .049 .28 r
.32562 .64075 m .32448 .63961 L .32619 .63883 L F
.32562 .64075 m .32359 .64134 L .32448 .63961 L F
.591 .589 .819 r
.69249 .49495 m .69337 .49754 L .69499 .49503 L F
.495 .463 .751 r
.69337 .49754 m .6972 .49981 L .69499 .49503 L F
.384 .363 .712 r
.54779 .77401 m .54461 .77239 L .54693 .77192 L F
.976 .672 .353 r
.53783 .77238 m .53887 .77276 L .53903 .77502 L F
.53783 .77238 m .53887 .77276 L .53903 .77502 L F
0 0 0 r
.39623 .71303 m .3954 .71328 L .39762 .71284 L F
.39623 .71303 m .39421 .71386 L .3954 .71328 L F
.196 0 .291 r
.35023 .70619 m .35193 .70521 L .35328 .70599 L F
.77 .901 .933 r
.35328 .70599 m .35193 .70521 L .35406 .70344 L F
.717 .211 .028 r
.57943 .68162 m .57835 .6818 L .57649 .68048 L F
.91 .554 .351 r
.57943 .68162 m .58017 .68353 L .57835 .6818 L F
.522 .919 .864 r
.58104 .68045 m .57835 .6818 L .57943 .68162 L F
.489 .564 .859 r
.46397 .64924 m .46349 .65232 L .46177 .64974 L F
.46397 .64924 m .46547 .65216 L .46349 .65232 L F
.385 .122 .387 r
.34015 .62453 m .33828 .6251 L .34076 .62247 L F
.386 .143 .418 r
.34076 .62247 m .34227 .62379 L .34015 .62453 L F
.34076 .62247 m .34263 .62178 L .34227 .62379 L F
.399 .169 .445 r
.34301 .61971 m .34263 .62178 L .34076 .62247 L F
.81 .642 .673 r
.60884 .73897 m .61036 .742 L .61083 .7396 L F
.574 .531 .77 r
.26486 .62479 m .26346 .6273 L .26285 .62523 L F
.512 .396 .658 r
.26433 .62649 m .26374 .63066 L .26346 .6273 L F
.26422 .62729 m .26596 .63057 L .26374 .63066 L F
.26433 .62649 m .26457 .6271 L .26422 .62729 L F
.26457 .6271 m .26596 .63057 L .26422 .62729 L F
.545 .407 .644 r
.26456 .62691 m .26518 .62669 L .26433 .62649 L F
.576 .481 .71 r
.26616 .62999 m .26596 .63057 L .26457 .6271 L F
.26463 .62705 m .26457 .6271 L .26433 .62649 L F
.26616 .62999 m .26457 .6271 L .26463 .62705 L F
.574 .531 .77 r
.26547 .62627 m .26559 .62655 L .26541 .62661 L F
.463 .528 .839 r
.2657 .62682 m .26524 .62648 L .26433 .62649 L F
.574 .531 .77 r
.26524 .62648 m .26541 .62661 L .2649 .62679 L F
.26547 .62627 m .26541 .62661 L .26524 .62648 L F
.545 .407 .644 r
.26456 .62691 m .2657 .62682 L .26518 .62669 L F
.26346 .6273 m .26463 .62705 L .26456 .62691 L F
.26463 .62705 m .2657 .62682 L .26456 .62691 L F
.574 .531 .77 r
.26559 .62655 m .2657 .62682 L .26469 .62704 L F
.26559 .62655 m .26469 .62704 L .26463 .62705 L F
.2649 .62679 m .26463 .62705 L .26346 .6273 L F
.26559 .62655 m .26463 .62705 L .2649 .62679 L F
.576 .481 .71 r
.26737 .62647 m .26616 .62999 L .26463 .62705 L F
.26497 .62673 m .26463 .62705 L .26449 .62678 L F
.444 .404 .719 r
.26681 .62432 m .26737 .62647 L .2657 .62682 L F
.463 .528 .839 r
.2657 .62682 m .26737 .62647 L .26524 .62648 L F
.576 .481 .71 r
.26737 .62647 m .26463 .62705 L .26497 .62673 L F
.26506 .62648 m .26449 .62678 L .26433 .62649 L F
.444 .404 .719 r
.26609 .62594 m .2657 .62682 L .26547 .62627 L F
.576 .481 .71 r
.26737 .62647 m .26449 .62678 L .26506 .62648 L F
.444 .404 .719 r
.26681 .62432 m .26609 .62594 L .26486 .62479 L F
.26609 .62594 m .26547 .62627 L .26486 .62479 L F
.545 .407 .644 r
.26346 .6273 m .26456 .62691 L .26433 .62649 L F
.574 .531 .77 r
.26486 .62479 m .26547 .62627 L .26346 .6273 L F
.26547 .62627 m .2649 .62679 L .26346 .6273 L F
.524 .381 .628 r
.26374 .63066 m .26407 .63359 L .26195 .63395 L F
.563 .443 .674 r
.35908 .60566 m .35737 .60751 L .35718 .60569 L F
.374 .58 .922 r
.75364 .61629 m .75519 .61832 L .75733 .61865 L F
.841 .719 .729 r
.60341 .52962 m .60375 .53381 L .60247 .53288 L F
.927 .851 .748 r
.60247 .53288 m .60375 .53381 L .6028 .53569 L F
.575 .253 .386 r
.54381 .70537 m .54701 .70705 L .54714 .70295 L F
.157 .318 .776 r
.54812 .70204 m .54947 .7052 L .54714 .70295 L F
0 0 .205 r
.54714 .70295 m .54701 .70705 L .54812 .70204 L F
.871 .814 .791 r
.58304 .73617 m .58481 .73366 L .58294 .73145 L F
.516 .107 .204 r
.53854 .763 m .53642 .76173 L .53841 .76224 L F
.53854 .763 m .53529 .76348 L .53642 .76173 L F
.899 .509 .274 r
.60315 .72958 m .60406 .72843 L .60254 .72797 L F
.60315 .72958 m .6048 .7307 L .60406 .72843 L F
.573 .501 .736 r
.47905 .66117 m .47732 .66374 L .47689 .66188 L F
.47905 .66117 m .47975 .66365 L .47732 .66374 L F
.406 .353 .686 r
.47949 .66595 m .47732 .66374 L .47975 .66365 L F
.47949 .66595 m .4778 .66699 L .47732 .66374 L F
.438 .281 .569 r
.45945 .76945 m .46127 .7666 L .45946 .76722 L F
.637 .899 .985 r
.47048 .79808 m .47223 .79872 L .47409 .79783 L F
.139 0 0 r
.40706 .64968 m .40922 .6498 L .41062 .64969 L F
.11 .662 .721 r
.40922 .6498 m .4127 .64937 L .41062 .64969 L F
.656 .469 .619 r
.45346 .67498 m .45616 .67499 L .45589 .67252 L F
.571 .456 .683 r
.45616 .67499 m .45786 .67145 L .45589 .67252 L F
.481 .241 .473 r
.34512 .61915 m .34263 .62178 L .34301 .61971 L F
.675 .489 .626 r
.5307 .75033 m .53358 .75252 L .53403 .75045 L F
.471 .191 .406 r
.53358 .75252 m .53637 .75019 L .53403 .75045 L F
.578 .417 .627 r
.53403 .75045 m .53637 .75019 L .5362 .74761 L F
.829 .996 .848 r
.59125 .5662 m .59245 .56637 L .59087 .56659 L F
.131 .633 .906 r
.6667 .48046 m .67208 .48171 L .67089 .48218 L F
.66676 .48039 m .67208 .48171 L .6667 .48046 L F
.045 0 .451 r
.67208 .48171 m .67371 .48016 L .6744 .48143 L F
.67208 .48171 m .67288 .48158 L .67371 .48016 L F
.131 .633 .906 r
.66624 .48027 m .67288 .48158 L .67208 .48171 L F
.481 .843 .992 r
.67007 .47927 m .66881 .47927 L .67151 .47892 L F
.67007 .47927 m .67133 .47896 L .66881 .47927 L F
.443 .727 .986 r
.67133 .47896 m .67108 .47902 L .67081 .47909 L F
.481 .843 .992 r
.67227 .47927 m .67084 .47927 L .67151 .47892 L F
.443 .727 .986 r
.67108 .47902 m .66929 .48087 L .66678 .48037 L F
.66707 .48005 m .66678 .48037 L .66624 .48027 L F
.67108 .47902 m .66678 .48037 L .66707 .48005 L F
.67108 .47902 m .66624 .48027 L .66701 .48001 L F
0 0 0 r
.66636 .48084 m .66548 .48208 L .66731 .47991 L F
.6663 .48091 m .66627 .48095 L .66636 .48084 L F
.66627 .48095 m .66548 .48208 L .66636 .48084 L F
.481 .843 .992 r
.67084 .47927 m .67007 .47927 L .67108 .47902 L F
.67084 .47927 m .67108 .47902 L .67151 .47892 L F
.443 .727 .986 r
.67133 .47896 m .67084 .47927 L .67108 .47902 L F
.481 .843 .992 r
.67084 .47927 m .67133 .47896 L .67007 .47927 L F
.67227 .47927 m .67133 .47896 L .67084 .47927 L F
.443 .727 .986 r
.67133 .47896 m .66929 .48087 L .67084 .47927 L F
.67133 .47896 m .67288 .48158 L .66929 .48087 L F
.67133 .47896 m .67081 .47909 L .66731 .47991 L F
.67108 .47902 m .66701 .48001 L .66731 .47991 L F
.481 .843 .992 r
.67151 .47892 m .66881 .47927 L .67101 .47868 L F
0 0 0 r
.66616 .48103 m .66613 .48109 L .6663 .48091 L F
.66613 .48109 m .66548 .48208 L .6663 .48091 L F
.131 .633 .906 r
.66624 .48027 m .66676 .48039 L .6667 .48046 L F
.869 .839 .372 r
.57315 .76087 m .57261 .7641 L .57393 .76143 L F
.847 .671 .133 r
.57393 .76143 m .57372 .75872 L .57315 .76087 L F
.102 0 0 r
.4127 .64937 m .41491 .64934 L .41637 .6491 L F
.456 0 0 r
.41491 .64934 m .41844 .64973 L .41637 .6491 L F
.48 .265 .51 r
.36373 .66392 m .36609 .66099 L .36379 .66133 L F
.797 .737 .797 r
.59493 .56389 m .59806 .56357 L .59541 .56665 L F
.631 .638 .839 r
.46883 .65383 m .46638 .65496 L .46547 .65216 L F
.933 .664 .505 r
.71318 .5027 m .71126 .504 L .71092 .50188 L F
.71318 .5027 m .71331 .50518 L .71126 .504 L F
.681 .674 .836 r
.49003 .79202 m .4921 .79587 L .4879 .79489 L F
.951 .713 .543 r
.67198 .53234 m .67354 .53334 L .67338 .53554 L F
.904 .747 .676 r
.61952 .49595 m .61788 .49643 L .61919 .49371 L F
.813 .559 .555 r
.61952 .49595 m .61745 .49862 L .61788 .49643 L F
.61952 .49595 m .62078 .49931 L .61745 .49862 L F
.758 .717 .813 r
.59178 .69763 m .59258 .70031 L .58924 .69995 L F
.982 .745 .504 r
.59258 .70031 m .59127 .70166 L .58924 .69995 L F
.59258 .70031 m .5924 .70261 L .59127 .70166 L F
.154 0 0 r
.40839 .66631 m .40707 .66686 L .40512 .66711 L F
.27 0 0 r
.41052 .66625 m .40707 .66686 L .40839 .66631 L F
.4 .132 .387 r
.62463 .5632 m .62581 .56085 L .62795 .55999 L F
.779 .282 0 r
.47758 .79793 m .4781 .79969 L .47628 .79817 L F
.47758 .79793 m .47934 .80031 L .4781 .79969 L F
.815 .37 .183 r
.48107 .80057 m .47934 .80031 L .47758 .79793 L F
0 0 0 r
.70033 .51636 m .69951 .51774 L .70218 .51532 L F
.642 .475 .642 r
.72381 .5992 m .7264 .59661 L .72395 .59736 L F
.65 .093 0 r
.56439 .72041 m .56113 .7188 L .56273 .71919 L F
.844 .637 .623 r
.61538 .54136 m .61392 .54367 L .61691 .54418 L F
.767 .573 .636 r
.61392 .54367 m .61557 .54594 L .61691 .54418 L F
.696 .373 .426 r
.61557 .54594 m .61908 .54627 L .61691 .54418 L F
.654 .385 .5 r
.61691 .54418 m .61908 .54627 L .61944 .54433 L F
.381 .044 .263 r
.50391 .73337 m .50628 .73252 L .50653 .73142 L F
.467 .118 .29 r
.50628 .73252 m .50863 .73211 L .50653 .73142 L F
.364 .111 .391 r
.27391 .61337 m .27208 .61398 L .27445 .61129 L F
.463 .233 .478 r
.27631 .6106 m .27391 .61337 L .27445 .61129 L F
.596 .736 .942 r
.48505 .67246 m .48139 .67164 L .48368 .66934 L F
.536 .594 .859 r
.48637 .67138 m .48505 .67246 L .48368 .66934 L F
.313 0 .211 r
.48623 .67379 m .48505 .67246 L .48637 .67138 L F
.48623 .67379 m .4843 .67454 L .48505 .67246 L F
0 .41 .735 r
.7041 .50586 m .70312 .50538 L .70128 .50486 L F
.836 .997 .835 r
.70553 .50318 m .7041 .50586 L .70655 .50493 L F
.455 .508 .823 r
.70128 .50486 m .70373 .50535 L .70216 .50156 L F
.836 .997 .835 r
.7042 .50471 m .70359 .50561 L .7041 .50586 L F
.702 .635 .779 r
.70216 .50156 m .70385 .50511 L .70553 .50318 L F
.836 .997 .835 r
.70423 .50437 m .70385 .50511 L .7042 .50471 L F
.70385 .50511 m .70359 .50561 L .7042 .50471 L F
.70553 .50318 m .70423 .50437 L .7041 .50586 L F
.702 .635 .779 r
.70385 .50511 m .70399 .5054 L .70553 .50318 L F
.455 .508 .823 r
.70373 .50535 m .70399 .5054 L .70385 .50511 L F
.70373 .50535 m .70385 .50511 L .70216 .50156 L F
.836 .997 .835 r
.70423 .50437 m .70312 .50538 L .70359 .50561 L F
.296 0 0 r
.25632 .58755 m .25844 .58721 L .26019 .58558 L F
.353 0 0 r
.25844 .58721 m .26224 .58546 L .26019 .58558 L F
.978 .709 .448 r
.59997 .71854 m .60062 .71629 L .59974 .71599 L F
.59997 .71854 m .6011 .71902 L .60062 .71629 L F
.514 .414 .679 r
.63409 .4937 m .63237 .49724 L .632 .4944 L F
.63409 .4937 m .63428 .49685 L .63237 .49724 L F
.991 .8 .552 r
.632 .4944 m .63103 .49597 L .63237 .49724 L F
.509 .76 .986 r
.63237 .49724 m .63352 .49545 L .63103 .49597 L F
.63237 .49724 m .63428 .49685 L .63352 .49545 L F
.432 .165 .407 r
.63237 .49724 m .63218 .49902 L .63428 .49685 L F
.322 .669 .975 r
.30554 .5896 m .305 .59057 L .30298 .58897 L F
.30554 .5896 m .30687 .59074 L .305 .59057 L F
.474 .13 .302 r
.7049 .52483 m .70214 .52656 L .70253 .52544 L F
.056 .46 .882 r
.52095 .80501 m .52029 .80552 L .5191 .80455 L F
.52095 .80501 m .52197 .8063 L .52029 .80552 L F
.043 .549 .878 r
.50704 .77493 m .51 .77609 L .50951 .77553 L F
.279 .739 .952 r
.50951 .77553 m .51 .77609 L .51285 .77594 L F
.747 .537 .611 r
.59874 .57188 m .60232 .57219 L .60236 .57459 L F
.642 .433 .584 r
.60493 .57216 m .60236 .57459 L .60232 .57219 L F
.897 .847 .786 r
.68187 .52271 m .68354 .52019 L .68065 .52119 L F
.557 .4 .625 r
.5287 .75334 m .53094 .75327 L .5307 .75033 L F
.36 .116 .403 r
.52883 .75518 m .53094 .75327 L .5287 .75334 L F
.826 .392 .208 r
.48107 .80057 m .48007 .80173 L .47934 .80031 L F
.906 .522 .282 r
.48107 .80057 m .48134 .80231 L .48007 .80173 L F
.744 .439 .465 r
.48107 .80057 m .48492 .80278 L .48134 .80231 L F
.529 .308 .524 r
.54851 .73136 m .54735 .73384 L .5468 .73077 L F
.54851 .73136 m .54993 .73333 L .54735 .73384 L F
.27 .698 .966 r
.53505 .74214 m .53723 .74225 L .53386 .74139 L F
.683 .239 .19 r
.47704 .785 m .47735 .78391 L .47398 .78351 L F
.94 .574 .265 r
.47751 .78623 m .47735 .78391 L .47704 .785 L F
.682 .43 .535 r
.5131 .80601 m .51081 .80311 L .51079 .80547 L F
.5131 .80601 m .51292 .80399 L .51081 .80311 L F
.639 .635 .83 r
.36911 .71409 m .37297 .71661 L .37148 .71367 L F
.388 .478 .83 r
.37297 .71661 m .37334 .71341 L .37148 .71367 L F
.37297 .71661 m .37462 .71642 L .37334 .71341 L F
.127 .238 .71 r
.37297 .71661 m .3748 .71857 L .37462 .71642 L F
.961 .655 .24 r
.62106 .52475 m .6199 .52157 L .6206 .5249 L F
.792 .482 .464 r
.6206 .5249 m .61992 .52649 L .62106 .52475 L F
.657 .299 .355 r
.61992 .52649 m .62343 .52662 L .62106 .52475 L F
.576 .342 .525 r
.62106 .52475 m .62343 .52662 L .62357 .52447 L F
.322 .037 .315 r
.26959 .6166 m .27208 .61398 L .27169 .61612 L F
.485 .246 .477 r
.27377 .61564 m .27208 .61398 L .27391 .61337 L F
.27377 .61564 m .27169 .61612 L .27208 .61398 L F
.69 .777 .917 r
.47247 .65442 m .46883 .65383 L .47098 .65302 L F
.372 .59 .929 r
.47334 .65275 m .47247 .65442 L .47098 .65302 L F
.47334 .65275 m .47472 .65478 L .47247 .65442 L F
.627 .404 .559 r
.47841 .68075 m .47823 .6831 L .4765 .68311 L F
.687 .462 .574 r
.48092 .68074 m .47823 .6831 L .47841 .68075 L F
.288 0 .254 r
.47592 .75056 m .4734 .753 L .47546 .75224 L F
.503 .167 .331 r
.47592 .75056 m .47546 .75224 L .47775 .75187 L F
.526 .152 .275 r
.47592 .75056 m .47775 .75187 L .47832 .75055 L F
.189 .547 .93 r
.78128 .58598 m .77963 .5856 L .77881 .58442 L F
.437 .266 .55 r
.33997 .62668 m .33828 .6251 L .34015 .62453 L F
.33997 .62668 m .33821 .62744 L .33828 .6251 L F
0 0 0 r
.70792 .51325 m .70746 .51434 L .70979 .51217 L F
.155 .463 .889 r
.58337 .68225 m .58565 .68364 L .58475 .68208 L F
.359 0 .087 r
.41655 .66348 m .41274 .66592 L .41339 .66434 L F
.41655 .66348 m .41499 .66552 L .41274 .66592 L F
.438 .02 .147 r
.41855 .66345 m .41499 .66552 L .41655 .66348 L F
.813 .711 .752 r
.59439 .54944 m .59633 .54661 L .5974 .54985 L F
.822 .674 .7 r
.59439 .54944 m .5974 .54985 L .59617 .55249 L F
.71 .594 .725 r
.58403 .56899 m .58539 .57235 L .58166 .57204 L F
.736 .569 .666 r
.58539 .57235 m .58191 .57446 L .58166 .57204 L F
.58539 .57235 m .58521 .57471 L .58191 .57446 L F
.491 .71 .967 r
.77415 .57895 m .77248 .58045 L .77245 .57917 L F
.77415 .57895 m .7745 .58021 L .77248 .58045 L F
.47 .597 .897 r
.68564 .48852 m .68208 .48605 L .68422 .48556 L F
.619 .674 .881 r
.68627 .48518 m .68564 .48852 L .68422 .48556 L F
.68627 .48518 m .68804 .48789 L .68564 .48852 L F
.561 .655 .899 r
.68947 .48927 m .68564 .48852 L .68804 .48789 L F
0 0 0 r
.55378 .79059 m .55451 .79013 L .55634 .7892 L F
.507 .245 .453 r
.48079 .77788 m .47856 .77603 L .48053 .7759 L F
.48079 .77788 m .47823 .77864 L .47856 .77603 L F
.43 0 .098 r
.459 .68646 m .45762 .68819 L .45541 .68831 L F
.508 .072 .147 r
.46091 .68759 m .459 .68646 L .46118 .68626 L F
.46091 .68759 m .45762 .68819 L .459 .68646 L F
.895 .802 .75 r
.62158 .48839 m .61843 .49036 L .62068 .48755 L F
.62158 .48839 m .61987 .49145 L .61843 .49036 L F
.823 .94 .903 r
.62417 .48603 m .62158 .48839 L .62068 .48755 L F
.919 .935 .8 r
.69518 .51875 m .69311 .52199 L .69271 .52047 L F
.156 .352 .807 r
.69311 .52199 m .69433 .52071 L .69271 .52047 L F
.69311 .52199 m .69566 .52393 L .69433 .52071 L F
.508 .372 .631 r
.69311 .52199 m .69335 .52472 L .69566 .52393 L F
.726 .305 .247 r
.58448 .67751 m .58674 .67955 L .58784 .67794 L F
.899 .546 .368 r
.58674 .67955 m .58869 .6805 L .58784 .67794 L F
.897 .805 .749 r
.56628 .74092 m .56791 .74174 L .56924 .73927 L F
.688 .649 .806 r
.55273 .76795 m .55468 .76741 L .5523 .76691 L F
.566 .284 .447 r
.5534 .76872 m .55468 .76741 L .55273 .76795 L F
.434 0 0 r
.54214 .76259 m .54095 .76311 L .53841 .76224 L F
.27 0 0 r
.54471 .76293 m .54095 .76311 L .54214 .76259 L F
.392 .568 .906 r
.50692 .75874 m .51026 .76146 L .50908 .75848 L F
.604 .868 .529 r
.51026 .76146 m .50793 .76418 L .50989 .76375 L F
.535 .512 .777 r
.50908 .75848 m .51026 .76146 L .51238 .76059 L F
.411 .215 .502 r
.51238 .76059 m .51026 .76146 L .50989 .76375 L F
.439 .627 .933 r
.75003 .61427 m .75149 .61623 L .75364 .61629 L F
.343 .677 .978 r
.50866 .80664 m .50494 .80839 L .50817 .80795 L F
.50866 .80664 m .5073 .80554 L .50494 .80839 L F
.431 .218 .487 r
.56102 .69339 m .55952 .69476 L .56175 .69189 L F
.338 0 .116 r
.5609 .69601 m .55952 .69476 L .56102 .69339 L F
.5609 .69601 m .55858 .6965 L .55952 .69476 L F
.859 .747 .738 r
.60805 .7448 m .60698 .74167 L .6063 .74413 L F
.777 .709 .787 r
.60805 .7448 m .61036 .742 L .60698 .74167 L F
.917 .68 .564 r
.5296 .74163 m .52839 .74159 L .52835 .73921 L F
.527 .089 .15 r
.53217 .74258 m .52839 .74159 L .5296 .74163 L F
.517 .105 .198 r
.41884 .6937 m .4212 .69383 L .42251 .69188 L F
.389 0 .156 r
.4212 .69383 m .42464 .69142 L .42251 .69188 L F
0 .118 .637 r
.59075 .71121 m .58804 .70841 L .59052 .71102 L F
.606 .464 .663 r
.56574 .77553 m .56827 .77794 L .56585 .77846 L F
.56574 .77553 m .56818 .77397 L .56827 .77794 L F
.76 .291 .13 r
.55746 .73324 m .55909 .73435 L .55889 .73225 L F
.55876 .73218 m .55889 .73225 L .55887 .73209 L F
.55746 .73324 m .55889 .73225 L .55876 .73218 L F
.92 .568 .35 r
.55909 .73435 m .55988 .73292 L .55908 .73226 L F
.55889 .73225 m .55908 .73226 L .55887 .73209 L F
.55909 .73435 m .55908 .73226 L .55889 .73225 L F
.748 .4 .394 r
.55542 .73067 m .55799 .73218 L .55854 .73208 L F
.76 .291 .13 r
.55746 .73324 m .55876 .73218 L .55949 .73306 L F
.748 .4 .394 r
.55799 .73218 m .55949 .73306 L .55869 .73223 L F
.55799 .73218 m .55869 .73223 L .55854 .73208 L F
.76 .291 .13 r
.55876 .73218 m .55887 .73209 L .55949 .73306 L F
.748 .4 .394 r
.55661 .73114 m .55854 .73208 L .55825 .73177 L F
.55542 .73067 m .55854 .73208 L .55661 .73114 L F
.708 .256 .175 r
.55825 .73177 m .55949 .73306 L .55887 .73209 L F
.474 .493 .797 r
.47949 .66595 m .47989 .6679 L .4778 .66699 L F
.553 .448 .688 r
.47989 .6679 m .47801 .66925 L .4778 .66699 L F
.829 .704 .726 r
.59531 .55501 m .59652 .55826 L .59401 .5579 L F
.904 .911 .817 r
.59652 .55826 m .59344 .56027 L .59401 .5579 L F
0 0 .366 r
.65998 .54428 m .66183 .5408 L .65937 .5434 L F
.356 0 .057 r
.4324 .68772 m .43509 .68646 L .43309 .68696 L F
.609 .789 .967 r
.73973 .59337 m .74078 .59459 L .73733 .59401 L F
.714 .829 .936 r
.74284 .59334 m .74078 .59459 L .73973 .59337 L F
.451 .082 .246 r
.4403 .69451 m .43949 .69649 L .43728 .69673 L F
.44 .092 .276 r
.44243 .69382 m .43949 .69649 L .4403 .69451 L F
0 0 .485 r
.59836 .70979 m .5972 .70876 L .59815 .70745 L F
.59836 .70979 m .59811 .71113 L .5972 .70876 L F
0 0 0 r
.62881 .54002 m .62793 .54165 L .63013 .53914 L F
.9 .515 .076 r
.63222 .53961 m .6326 .53881 L .63025 .53805 L F
.63222 .53961 m .63025 .53805 L .63023 .53825 L F
.63023 .53825 m .63025 .53805 L .62965 .53785 L F
.068 0 .263 r
.62965 .53785 m .63102 .53812 L .63222 .53961 L F
0 0 0 r
.63016 .53886 m .63013 .53914 L .63102 .53812 L F
.62881 .54002 m .63013 .53914 L .63016 .53886 L F
.9 .515 .076 r
.63222 .53961 m .63316 .54063 L .6326 .53881 L F
.704 .63 .771 r
.65315 .52482 m .65586 .52432 L .65507 .52151 L F
.985 .709 .395 r
.65586 .52432 m .65702 .52763 L .65505 .52419 L F
.986 .741 .479 r
.65505 .52419 m .65702 .52763 L .65578 .52714 L F
.986 .739 .473 r
.65505 .52419 m .65702 .52763 L .65695 .52992 L F
.985 .709 .395 r
.65586 .52432 m .65702 .52763 L .65505 .52419 L F
.837 .818 .831 r
.6242 .50394 m .62539 .50524 L .62787 .5029 L F
.286 0 .106 r
.62787 .5029 m .63014 .50213 L .62725 .50175 L F
.62787 .5029 m .62971 .50333 L .63014 .50213 L F
.63014 .50213 m .62971 .50333 L .62787 .5029 L F
.93 .952 .778 r
.65684 .49089 m .65438 .493 L .65614 .48958 L F
.65684 .49089 m .65463 .49449 L .65438 .493 L F
.375 .274 .61 r
.72378 .49386 m .7223 .4969 L .72127 .49387 L F
.72378 .49386 m .72408 .49604 L .7223 .4969 L F
.659 .692 .869 r
.68344 .4935 m .68686 .49413 L .68685 .49301 L F
.576 .673 .905 r
.68686 .49413 m .68845 .49202 L .68685 .49301 L F
.68686 .49413 m .68914 .49365 L .68845 .49202 L F
.572 .5 .735 r
.52675 .77473 m .52525 .77811 L .52462 .77581 L F
.973 .751 .542 r
.49359 .78968 m .49234 .791 L .49219 .78931 L F
.787 .716 .785 r
.4937 .79341 m .49003 .79202 L .49234 .791 L F
.4937 .79341 m .49234 .791 L .49354 .79326 L F
.973 .751 .542 r
.49359 .78968 m .49354 .79326 L .49234 .791 L F
.024 0 0 r
.42457 .66216 m .42296 .6627 L .42074 .66301 L F
.352 .813 .927 r
.42624 .66251 m .42296 .6627 L .42457 .66216 L F
.503 .47 .753 r
.36299 .68627 m .36384 .68972 L .36567 .68832 L F
.528 .516 .786 r
.36384 .68972 m .36665 .69131 L .36567 .68832 L F
.363 .762 .985 r
.32758 .59269 m .32542 .59296 L .32392 .59211 L F
.555 .639 .889 r
.75243 .60791 m .74878 .60577 L .75106 .60553 L F
.508 .616 .894 r
.75468 .60781 m .75243 .60791 L .75106 .60553 L F
.148 .671 .881 r
.68011 .49288 m .6767 .49231 L .67812 .49348 L F
.699 .719 .864 r
.44399 .66055 m .44499 .66144 L .44703 .66094 L F
.559 .548 .799 r
.52019 .74186 m .51695 .73935 L .5193 .73897 L F
.845 .678 .676 r
.58166 .57204 m .57985 .57449 L .57877 .57334 L F
.77 .565 .621 r
.58166 .57204 m .58191 .57446 L .57985 .57449 L F
.792 .51 .51 r
.58191 .57446 m .58005 .57667 L .57985 .57449 L F
.968 .921 .588 r
.58037 .57525 m .5807 .57347 L .58067 .57311 L F
.845 .678 .676 r
.58166 .57204 m .58063 .5725 L .58067 .57311 L F
.968 .921 .588 r
.5807 .57347 m .58095 .57213 L .58067 .57311 L F
.845 .678 .676 r
.58063 .5725 m .57877 .57334 L .58067 .57311 L F
.207 0 0 r
.58311 .57015 m .58166 .57204 L .58157 .57148 L F
.827 .909 .505 r
.58157 .57148 m .58166 .57204 L .58067 .57311 L F
.153 0 .109 r
.32103 .64361 m .32187 .64221 L .32359 .64134 L F
.303 0 0 r
.4272 .70197 m .42345 .70396 L .42472 .70268 L F
0 0 0 r
.5059 .74049 m .50402 .74142 L .50412 .74113 L F
.50412 .74113 m .50337 .74228 L .50421 .74087 L F
.384 .674 .973 r
.50321 .74109 m .50239 .74136 L .50412 .74113 L F
.50239 .74136 m .50337 .74228 L .50355 .74201 L F
.50239 .74136 m .50355 .74201 L .50412 .74113 L F
.815 .703 .741 r
.50017 .74252 m .50337 .74228 L .50236 .74133 L F
0 0 0 r
.50185 .74155 m .50236 .74133 L .50234 .74134 L F
.50054 .74203 m .50234 .74134 L .50093 .74054 L F
.815 .703 .741 r
.50082 .74201 m .50185 .74155 L .501 .74186 L F
0 0 0 r
.50083 .742 m .50185 .74155 L .501 .74186 L F
.50185 .74155 m .50234 .74134 L .50054 .74203 L F
.815 .703 .741 r
.50017 .74252 m .50236 .74133 L .50082 .74201 L F
.384 .674 .973 r
.50236 .74133 m .50239 .74136 L .50321 .74109 L F
.063 0 0 r
.5027 .74207 m .50242 .74162 L .50412 .74113 L F
0 0 0 r
.50297 .74125 m .50321 .74109 L .50236 .74133 L F
.50234 .74134 m .50431 .74078 L .50451 .74038 L F
.50234 .74134 m .50451 .74038 L .50093 .74054 L F
.384 .674 .973 r
.50204 .74104 m .50236 .74133 L .50321 .74109 L F
.063 0 0 r
.50242 .74162 m .50204 .74104 L .50321 .74109 L F
.50242 .74162 m .50321 .74109 L .50412 .74113 L F
0 0 0 r
.50084 .742 m .50297 .74125 L .50236 .74133 L F
.50297 .74125 m .50431 .74078 L .50321 .74109 L F
.076 0 0 r
.50019 .74255 m .50017 .74252 L .501 .74186 L F
0 0 0 r
.5005 .74215 m .50099 .74198 L .50084 .742 L F
.50099 .74198 m .50431 .74078 L .50084 .742 L F
.815 .703 .741 r
.50017 .74252 m .50179 .74519 L .50337 .74228 L F
.076 0 0 r
.5006 .74318 m .50019 .74255 L .50087 .742 L F
.815 .703 .741 r
.501 .74186 m .50236 .74133 L .50204 .74104 L F
0 0 0 r
.5005 .74215 m .50236 .74133 L .50185 .74155 L F
.076 0 0 r
.50147 .74189 m .50087 .742 L .50204 .74104 L F
.5006 .74318 m .50087 .742 L .50147 .74189 L F
.50019 .74255 m .501 .74186 L .50204 .74104 L F
0 0 0 r
.5005 .74215 m .50083 .742 L .50054 .74203 L F
.50083 .742 m .501 .74186 L .50054 .74203 L F
.815 .703 .741 r
.50185 .74155 m .50236 .74133 L .501 .74186 L F
0 0 0 r
.5005 .74215 m .5042 .74099 L .50431 .74078 L F
.50093 .74054 m .50451 .74038 L .50127 .73923 L F
.50402 .74142 m .5027 .74207 L .50412 .74113 L F
.50412 .74113 m .50421 .74087 L .50524 .73913 L F
.641 .253 .293 r
.50442 .81379 m .50742 .81338 L .50623 .81532 L F
.666 .184 .096 r
.50742 .81338 m .5082 .81537 L .50623 .81532 L F
.50742 .81338 m .50977 .81437 L .5082 .81537 L F
.341 .106 .406 r
.49245 .77282 m .49205 .77502 L .49028 .77541 L F
.573 .539 .779 r
.49329 .77809 m .49028 .77541 L .49205 .77502 L F
.559 .308 .492 r
.4459 .68016 m .4483 .68 L .44851 .67793 L F
.642 .38 .507 r
.4483 .68 m .4508 .68007 L .44851 .67793 L F
.612 .385 .548 r
.44851 .67793 m .4508 .68007 L .45089 .67776 L F
0 .051 .608 r
.46631 .79226 m .46597 .79126 L .46361 .78954 L F
.46631 .79226 m .46677 .79287 L .46597 .79126 L F
.344 .124 .43 r
.69484 .5343 m .69293 .53572 L .69505 .53286 L F
.145 0 .16 r
.69437 .53661 m .69293 .53572 L .69484 .5343 L F
.69437 .53661 m .69254 .53769 L .69293 .53572 L F
.845 .903 .877 r
.5324 .80243 m .53401 .80328 L .53105 .8057 L F
.308 .134 .474 r
.53582 .80034 m .53401 .80328 L .53591 .80284 L F
.457 .81 .997 r
.53591 .80284 m .53401 .80328 L .5324 .80243 L F
.124 .211 .684 r
.53602 .80575 m .53401 .80328 L .53591 .80284 L F
.678 .57 .727 r
.48139 .67164 m .47931 .67253 L .47801 .66925 L F
.567 .215 .332 r
.5143 .81408 m .51554 .81159 L .51724 .8132 L F
0 .036 .598 r
.65463 .49449 m .65573 .49513 L .65438 .493 L F
.65463 .49449 m .65667 .49693 L .65573 .49513 L F
.871 .814 .791 r
.58304 .73617 m .58294 .73145 L .58166 .73381 L F
.775 .564 .614 r
.50509 .76166 m .50454 .76396 L .50793 .76418 L F
.742 .406 .413 r
.50454 .76396 m .50645 .76647 L .50793 .76418 L F
.52 .18 .332 r
.50645 .76647 m .50989 .76375 L .50793 .76418 L F
.991 .84 .593 r
.47751 .78623 m .47965 .78901 L .48206 .78615 L F
.061 0 0 r
.48206 .78615 m .48165 .78796 L .48327 .78858 L F
.48206 .78615 m .47965 .78901 L .48165 .78796 L F
.468 .196 .417 r
.59323 .56919 m .59348 .57034 L .59048 .57166 L F
.744 .373 .35 r
.59323 .56919 m .59553 .5713 L .59348 .57034 L F
0 0 0 r
.63316 .55734 m .63588 .55482 L .63571 .55521 L F
.63588 .55482 m .6391 .55307 L .63759 .55399 L F
.63759 .55399 m .63571 .55521 L .63588 .55482 L F
.351 .095 .378 r
.33301 .63225 m .33088 .63568 L .33096 .6332 L F
0 .086 .628 r
.56909 .72524 m .56958 .72529 L .56724 .72283 L F
.845 .382 .061 r
.57109 .72597 m .56958 .72529 L .56909 .72524 L F
.956 .935 .726 r
.56777 .71294 m .56718 .71626 L .5667 .71408 L F
.421 .24 .528 r
.26711 .619 m .26686 .62169 L .26499 .62223 L F
.486 .32 .581 r
.26686 .62169 m .26486 .62479 L .26499 .62223 L F
.928 .741 .628 r
.53406 .73536 m .53617 .73371 L .53609 .73367 L F
0 .366 .821 r
.53617 .73371 m .53703 .73349 L .53609 .73367 L F
.978 .685 .312 r
.66259 .50534 m .66184 .50651 L .66122 .50447 L F
.66259 .50534 m .66285 .50761 L .66184 .50651 L F
.029 0 0 r
.41844 .64973 m .42062 .64946 L .42199 .64906 L F
.583 .935 .937 r
.76277 .58023 m .76126 .58157 L .76028 .58215 L F
.76277 .58023 m .76349 .58053 L .76126 .58157 L F
.72 .783 .296 r
.51271 .72184 m .51135 .72566 L .51181 .72405 L F
.606 .382 .551 r
.5108 .72796 m .51335 .7278 L .51135 .72566 L F
.973 .866 .671 r
.66911 .52134 m .66914 .52471 L .6687 .52352 L F
.955 .734 .563 r
.66914 .52471 m .66896 .52705 L .66752 .52635 L F
.2 0 .137 r
.56389 .6914 m .56102 .69339 L .56175 .69189 L F
.608 .856 .991 r
.69432 .51786 m .69518 .51875 L .69181 .51872 L F
.919 .935 .8 r
.69518 .51875 m .69271 .52047 L .69181 .51872 L F
.451 .775 .998 r
.69432 .51786 m .69749 .51853 L .69518 .51875 L F
.732 .286 .192 r
.3641 .70885 m .36591 .70938 L .36288 .70859 L F
.643 .919 .631 r
.36591 .70938 m .36424 .71084 L .36288 .70859 L F
.64 .727 .911 r
.36794 .70885 m .36591 .70938 L .3641 .70885 L F
.693 .306 0 r
.65244 .49776 m .65223 .49711 L .65193 .49564 L F
.65244 .49776 m .65317 .49903 L .65223 .49711 L F
.833 .782 .803 r
.59903 .53739 m .60062 .5386 L .59782 .5384 L F
.843 .753 .764 r
.59782 .5384 m .60062 .5386 L .59872 .54153 L F
.854 .815 .81 r
.60141 .53449 m .60062 .5386 L .59903 .53739 L F
.60141 .53449 m .6028 .53569 L .60062 .5386 L F
.863 .843 .823 r
.50522 .75969 m .50509 .76166 L .50692 .75874 L F
.50313 .76086 m .50692 .75874 L .50539 .75806 L F
.085 0 .452 r
.50678 .75929 m .50543 .7581 L .50647 .75693 L F
.50543 .7581 m .50539 .75806 L .50545 .75801 L F
.50543 .7581 m .50545 .75801 L .50647 .75693 L F
.863 .843 .823 r
.50313 .76086 m .50497 .76161 L .50522 .75969 L F
.50497 .76161 m .50509 .76166 L .50522 .75969 L F
.979 .804 .596 r
.50365 .76215 m .50509 .76166 L .50313 .76086 L F
.50365 .76215 m .50454 .76396 L .50509 .76166 L F
.606 .718 .923 r
.73876 .61326 m .74207 .61414 L .74106 .61275 L F
.61 .672 .885 r
.74207 .61414 m .74388 .61224 L .74106 .61275 L F
.74207 .61414 m .74445 .61358 L .74388 .61224 L F
.508 .247 .453 r
.6265 .53826 m .62965 .53785 L .62923 .53592 L F
.569 .429 .65 r
.38999 .68026 m .38767 .67828 L .38971 .67716 L F
.38999 .68026 m .38784 .68067 L .38767 .67828 L F
.615 .942 .744 r
.64414 .53109 m .64593 .53027 L .64695 .52928 L F
.336 .18 .516 r
.64593 .53027 m .64797 .53168 L .64695 .52928 L F
.64593 .53027 m .64592 .53305 L .64797 .53168 L F
.442 .115 .316 r
.45201 .69093 m .45097 .68893 L .45321 .68871 L F
.45201 .69093 m .44996 .69147 L .45097 .68893 L F
.512 .384 .643 r
.36199 .68072 m .36434 .68277 L .36411 .68028 L F
.36199 .68072 m .36223 .6834 L .36434 .68277 L F
.564 .517 .761 r
.36106 .67751 m .36199 .68072 L .36411 .68028 L F
.265 .529 .914 r
.78128 .58598 m .78432 .58791 L .78363 .58915 L F
0 0 0 r
.78363 .58915 m .78432 .58791 L .78308 .59112 L F
.551 .397 .625 r
.5362 .74761 m .53862 .74976 L .53861 .74734 L F
.5362 .74761 m .53637 .75019 L .53862 .74976 L F
0 .231 .75 r
.77687 .58228 m .77642 .58292 L .7745 .58021 L F
0 .346 .822 r
.77687 .58228 m .77881 .58442 L .77642 .58292 L F
.577 .679 .91 r
.25725 .65289 m .25869 .65163 L .25637 .6517 L F
.687 .462 .574 r
.48092 .68074 m .48069 .68324 L .47823 .6831 L F
.635 .416 .567 r
.48394 .68206 m .48092 .68074 L .48353 .68002 L F
.48394 .68206 m .48069 .68324 L .48092 .68074 L F
.478 0 0 r
.55755 .71061 m .55613 .71082 L .55962 .7111 L F
.169 0 0 r
.48369 .67641 m .48145 .67698 L .48319 .67562 L F
.438 .844 .972 r
.60601 .75048 m .60932 .75037 L .60823 .74997 L F
.697 .422 .504 r
.52355 .75778 m .52617 .75827 L .52656 .75618 L F
.352 .112 .404 r
.52656 .75618 m .52814 .75728 L .52883 .75518 L F
.52656 .75618 m .52617 .75827 L .52814 .75728 L F
.541 .537 .799 r
.69981 .48984 m .69796 .49205 L .69746 .49101 L F
.611 .643 .857 r
.69981 .48984 m .70048 .49172 L .69796 .49205 L F
.927 .851 .748 r
.60247 .53288 m .6028 .53569 L .60141 .53449 L F
.657 .241 .243 r
.62553 .5124 m .6287 .51266 L .62658 .51111 L F
.497 0 0 r
.62658 .51111 m .63007 .51344 L .62894 .51102 L F
.62658 .51111 m .6287 .51266 L .63007 .51344 L F
.506 .334 .581 r
.51883 .80054 m .51771 .80273 L .51744 .80234 L F
.561 .632 .88 r
.7468 .60135 m .74608 .60467 L .74487 .60165 L F
.7468 .60135 m .74832 .60416 L .74608 .60467 L F
.682 .775 .921 r
.27679 .63763 m .27299 .63685 L .27545 .63653 L F
.6 .83 .987 r
.27906 .63673 m .27679 .63763 L .27545 .63653 L F
.409 .191 .468 r
.55354 .74773 m .55337 .74988 L .55149 .75077 L F
.55354 .74773 m .55337 .74988 L .55149 .75077 L F
.515 .286 .505 r
.55645 .7474 m .55337 .74988 L .55354 .74773 L F
.552 .494 .744 r
.57672 .68395 m .57617 .68533 L .57512 .68561 L F
.673 .481 .619 r
.57476 .68035 m .57538 .68541 L .57434 .68496 L F
.376 .269 .604 r
.57672 .68395 m .57538 .68541 L .57476 .68035 L F
.658 .794 .947 r
.57434 .68496 m .57098 .68487 L .5711 .68358 L F
.57538 .68541 m .57493 .68536 L .57434 .68496 L F
.57493 .68536 m .57098 .68487 L .57434 .68496 L F
.552 .494 .744 r
.57493 .68536 m .57435 .68582 L .57538 .68541 L F
.57493 .68536 m .57512 .68561 L .57487 .68541 L F
.57672 .68395 m .57493 .68536 L .57538 .68541 L F
.57672 .68395 m .5752 .68553 L .57493 .68536 L F
.658 .794 .947 r
.57538 .68541 m .57435 .68582 L .57503 .68542 L F
.552 .494 .744 r
.5752 .68553 m .57512 .68561 L .57493 .68536 L F
.658 .794 .947 r
.57538 .68541 m .57092 .68555 L .57098 .68487 L F
.552 .494 .744 r
.57487 .68541 m .57495 .68547 L .57435 .68582 L F
.658 .794 .947 r
.57503 .68542 m .57435 .68582 L .57092 .68555 L F
.552 .494 .744 r
.57495 .68547 m .57512 .68561 L .57435 .68582 L F
.673 .481 .619 r
.57185 .68292 m .57434 .68496 L .5711 .68358 L F
.57476 .68035 m .57434 .68496 L .57185 .68292 L F
.376 .269 .604 r
.57672 .68395 m .57476 .68035 L .57649 .68048 L F
.24 0 .234 r
.72931 .50258 m .72864 .50457 L .72678 .50518 L F
.385 .066 .297 r
.73134 .50374 m .72931 .50258 L .73156 .50185 L F
.73134 .50374 m .72864 .50457 L .72931 .50258 L F
0 .141 .645 r
.58033 .72099 m .57895 .72017 L .57825 .7188 L F
.592 .025 0 r
.57895 .72017 m .5811 .72193 L .58238 .72244 L F
0 .141 .645 r
.58033 .72099 m .5811 .72193 L .57895 .72017 L F
.061 0 0 r
.63576 .48768 m .63791 .48718 L .63836 .48661 L F
.63576 .48768 m .63791 .48718 L .63836 .48661 L F
.605 .626 .846 r
.6402 .48407 m .63836 .48661 L .63778 .48459 L F
.57 .577 .821 r
.6402 .48407 m .64007 .48655 L .63836 .48661 L F
.059 0 0 r
.55137 .73676 m .55045 .73792 L .55331 .73586 L F
.474 .536 .84 r
.39824 .69429 m .39755 .69731 L .39583 .69502 L F
.39824 .69429 m .39962 .69741 L .39755 .69731 L F
.158 0 .271 r
.34051 .71906 m .33834 .72208 L .33898 .72025 L F
.34051 .71906 m .33834 .72208 L .33898 .72025 L F
.385 .162 .448 r
.62178 .54369 m .62374 .54105 L .62189 .54175 L F
.4 .124 .374 r
.78428 .60825 m .78373 .60946 L .78182 .61057 L F
.593 .621 .849 r
.7855 .60495 m .78428 .60825 L .78337 .60571 L F
.7855 .60495 m .78677 .60779 L .78428 .60825 L F
.848 .998 .785 r
.78677 .60779 m .78373 .60946 L .78428 .60825 L F
.963 .908 .715 r
.63317 .51622 m .63112 .51754 L .63183 .51518 L F
.63317 .51622 m .63194 .51927 L .63112 .51754 L F
.392 .058 .275 r
.31905 .62174 m .32207 .61919 L .31967 .61925 L F
.93 .742 .626 r
.61404 .53809 m .61354 .54045 L .61538 .54136 L F
.923 .765 .667 r
.61354 .54045 m .61392 .54367 L .61538 .54136 L F
.462 .354 .646 r
.36075 .67512 m .3626 .6747 L .36234 .67236 L F
.525 .415 .671 r
.36075 .67512 m .36309 .67707 L .3626 .6747 L F
.36075 .67512 m .36106 .67751 L .36309 .67707 L F
.581 .759 .963 r
.35811 .59991 m .35612 .60054 L .35487 .59939 L F
.774 .827 .894 r
.3556 .70858 m .35684 .71032 L .35902 .70856 L F
0 0 .558 r
.46677 .79287 m .46781 .79421 L .46597 .79126 L F
.201 .656 .944 r
.39238 .84014 m .39013 .83939 L .39253 .83929 L F
.774 .737 .819 r
.39013 .83939 m .39238 .84014 L .39253 .83929 L F
.678 .57 .727 r
.48139 .67164 m .47801 .66925 L .47989 .6679 L F
.539 .652 .908 r
.64699 .48984 m .64541 .49185 L .64557 .49089 L F
.539 .653 .909 r
.64699 .48984 m .64774 .49164 L .64541 .49185 L F
.245 .639 .961 r
.30914 .59015 m .31104 .59037 L .31055 .59122 L F
.292 .694 .974 r
.31104 .59037 m .3125 .59128 L .31055 .59122 L F
.769 .355 .266 r
.56718 .71626 m .56886 .7185 L .57007 .71693 L F
.448 0 .059 r
.57007 .71693 m .57126 .71813 L .57241 .71705 L F
.57007 .71693 m .56886 .7185 L .57126 .71813 L F
.66 .738 .908 r
.62343 .52662 m .62493 .52859 L .62679 .52718 L F
.291 0 0 r
.53561 .7236 m .53812 .72358 L .53934 .72286 L F
.502 0 0 r
.53812 .72358 m .5422 .72366 L .53934 .72286 L F
.121 .67 .721 r
.29796 .6024 m .30139 .60192 L .30005 .60192 L F
.133 0 0 r
.30338 .60172 m .30005 .60192 L .30139 .60192 L F
.38 .777 .986 r
.3657 .71215 m .36621 .71127 L .36424 .71084 L F
.3657 .71215 m .36847 .71186 L .36621 .71127 L F
.813 .88 .895 r
.62201 .50621 m .62539 .50524 L .6242 .50394 L F
.963 .634 .27 r
.6676 .51802 m .66869 .51902 L .66911 .52134 L F
.957 .842 .689 r
.66825 .51582 m .66869 .51902 L .6676 .51802 L F
.55 .223 .366 r
.47268 .68377 m .46995 .68559 L .47037 .68354 L F
.47268 .68377 m .47252 .68546 L .46995 .68559 L F
.673 .329 .382 r
.47268 .68377 m .47477 .68577 L .47252 .68546 L F
.611 .344 .489 r
.4765 .68311 m .47477 .68577 L .47268 .68377 L F
.516 .335 .574 r
.46312 .75876 m .46518 .7605 L .46521 .75812 L F
.46312 .75876 m .46313 .76112 L .46518 .7605 L F
.496 .6 .887 r
.46022 .64731 m .45969 .64986 L .45825 .64735 L F
.46022 .64731 m .46177 .64974 L .45969 .64986 L F
.506 .114 .232 r
.38649 .6523 m .38884 .65226 L .39001 .65025 L F
.494 .102 .226 r
.39001 .65025 m .38884 .65226 L .39201 .65127 L F
.361 .368 .732 r
.37037 .7058 m .37194 .70573 L .37108 .70211 L F
.336 .125 .438 r
.37037 .7058 m .37012 .70808 L .37194 .70573 L F
.37037 .7058 m .37012 .70808 L .37194 .70573 L F
.61 .543 .755 r
.72173 .60208 m .72266 .60529 L .725 .6048 L F
.789 .955 .627 r
.51271 .72184 m .51284 .72149 L .51537 .71996 L F
.635 .333 .441 r
.51284 .72149 m .51588 .72179 L .51537 .71996 L F
.833 .702 .719 r
.51588 .72179 m .51908 .72013 L .51537 .71996 L F
.714 .179 0 r
.78266 .59862 m .78398 .59909 L .78197 .59713 L F
.78266 .59862 m .78197 .59713 L .78239 .59565 L F
.436 .11 .314 r
.61844 .56695 m .62035 .56812 L .61803 .56839 L F
.61844 .56695 m .62142 .56544 L .62035 .56812 L F
.476 .221 .447 r
.26959 .6166 m .26909 .61869 L .26711 .619 L F
.455 .202 .439 r
.27114 .61812 m .26959 .6166 L .27169 .61612 L F
.27114 .61812 m .26909 .61869 L .26959 .6166 L F
.114 0 0 r
.777 .61645 m .77637 .61736 L .77405 .61826 L F
0 0 0 r
.77897 .61539 m .77637 .61736 L .777 .61645 L F
.676 .737 .897 r
.68011 .49288 m .68344 .4935 L .68189 .49101 L F
.632 .749 .932 r
.68189 .49101 m .68344 .4935 L .68685 .49301 L F
.572 .521 .759 r
.72617 .60788 m .72764 .60461 L .725 .6048 L F
.72617 .60788 m .72851 .60752 L .72764 .60461 L F
.382 .461 .817 r
.72617 .60788 m .72936 .61117 L .72851 .60752 L F
.602 .42 .607 r
.76483 .59965 m .76731 .59937 L .76717 .59684 L F
.545 .423 .664 r
.76717 .59684 m .76928 .59402 L .76656 .59472 L F
.76717 .59684 m .76967 .59644 L .76928 .59402 L F
.626 .494 .682 r
.76731 .59937 m .76967 .59644 L .76717 .59684 L F
.078 0 0 r
.27395 .58509 m .27574 .58515 L .27753 .58505 L F
.242 0 0 r
.27753 .58505 m .27574 .58515 L .27945 .58533 L F
.466 .876 .948 r
.48807 .77464 m .48629 .77496 L .48691 .77534 L F
0 0 .014 r
.48691 .77534 m .48625 .77719 L .48807 .77464 L F
.463 .482 .793 r
.39548 .6929 m .39394 .69486 L .39284 .69147 L F
.468 .49 .798 r
.39548 .6929 m .39583 .69502 L .39394 .69486 L F
.581 .075 .016 r
.63566 .49989 m .63795 .50122 L .6347 .50087 L F
.537 .217 .374 r
.63819 .49962 m .63795 .50122 L .63566 .49989 L F
.57 .646 .886 r
.68422 .48556 m .68208 .48605 L .68134 .48425 L F
.675 .489 .626 r
.5307 .75033 m .53094 .75327 L .53358 .75252 L F
.633 .339 .455 r
.51577 .80584 m .51771 .80273 L .51292 .80399 L F
.864 .641 .599 r
.51744 .80234 m .51771 .80273 L .51577 .80584 L F
.874 .705 .669 r
.67501 .5051 m .67437 .50734 L .67608 .50777 L F
.981 .718 .455 r
.67507 .50958 m .67608 .50777 L .67437 .50734 L F
.67507 .50958 m .67649 .51097 L .67608 .50777 L F
.21 0 0 r
.58667 .5681 m .58403 .56899 L .58311 .57015 L F
.869 .839 .372 r
.57315 .76087 m .57243 .76337 L .57261 .7641 L F
0 0 .172 r
.57243 .76337 m .57284 .76662 L .57261 .7641 L F
.615 .409 .579 r
.45089 .67776 m .45325 .67766 L .45346 .67498 L F
.658 .446 .586 r
.45346 .67498 m .45636 .67733 L .45616 .67499 L F
.45346 .67498 m .45325 .67766 L .45636 .67733 L F
.502 .354 .612 r
.63627 .54601 m .63416 .54685 L .6339 .54424 L F
.63627 .54601 m .63416 .54685 L .6339 .54424 L F
.986 .714 .358 r
.66262 .52061 m .66346 .51909 L .66248 .51784 L F
.66262 .52061 m .66362 .52165 L .66346 .51909 L F
.897 .847 .786 r
.68187 .52271 m .68065 .52119 L .67947 .52361 L F
.341 .107 .406 r
.69738 .53178 m .69484 .5343 L .69505 .53286 L F
.92 .568 .35 r
.55909 .73435 m .56202 .73659 L .55988 .73292 L F
.504 .002 0 r
.52417 .80707 m .52565 .80607 L .52197 .8063 L F
0 .207 .729 r
.52691 .80602 m .52565 .80607 L .52417 .80707 L F
.41 .315 .637 r
.45711 .78368 m .45827 .78067 L .45667 .78172 L F
.178 0 .258 r
.39204 .67252 m .39144 .67439 L .3899 .67508 L F
.465 .336 .62 r
.39144 .67439 m .38971 .67716 L .3899 .67508 L F
.747 .57 .655 r
.56585 .77846 m .56646 .78082 L .56285 .78051 L F
.54 .443 .693 r
.56817 .77885 m .56585 .77846 L .56827 .77794 L F
.56817 .77885 m .56646 .78082 L .56585 .77846 L F
.542 .393 .629 r
.26616 .63292 m .26374 .63066 L .26596 .63057 L F
.26616 .63292 m .26407 .63359 L .26374 .63066 L F
.836 .74 .759 r
.59688 .54045 m .59798 .54352 L .59523 .54337 L F
.59688 .54045 m .59872 .54153 L .59798 .54352 L F
.871 .731 .705 r
.59523 .54337 m .59798 .54352 L .59633 .54661 L F
.908 .77 .697 r
.60581 .73349 m .6048 .7307 L .6042 .73311 L F
.907 .599 .452 r
.60451 .73534 m .60581 .73349 L .6042 .73311 L F
.891 .573 .44 r
.60451 .73534 m .6062 .73626 L .60581 .73349 L F
.817 .632 .652 r
.64466 .49974 m .64313 .49955 L .64327 .4966 L F
.635 .552 .744 r
.64701 .49932 m .64466 .49974 L .64327 .4966 L F
.614 .453 .64 r
.64701 .49932 m .64476 .50215 L .64466 .49974 L F
.741 .299 .203 r
.55145 .7146 m .55037 .71596 L .54812 .71389 L F
.689 .234 .167 r
.55145 .7146 m .5538 .71652 L .55037 .71596 L F
.69 .23 .154 r
.55542 .71606 m .5538 .71652 L .55145 .7146 L F
.253 0 .154 r
.31978 .64569 m .3191 .644 L .32103 .64361 L F
.31978 .64569 m .31786 .64645 L .3191 .644 L F
.767 .668 .754 r
.63037 .52954 m .63157 .53316 L .63372 .53026 L F
.642 .433 .584 r
.60493 .57216 m .60471 .57454 L .60236 .57459 L F
.591 .396 .586 r
.60807 .57317 m .60471 .57454 L .60493 .57216 L F
.41 .315 .637 r
.45711 .78368 m .45874 .78386 L .45827 .78067 L F
.399 .454 .802 r
.45711 .78368 m .45988 .78716 L .45874 .78386 L F
0 .352 .797 r
.29273 .58685 m .29187 .58688 L .29039 .58604 L F
.29273 .58685 m .29415 .5881 L .29187 .58688 L F
.415 .304 .619 r
.4581 .77529 m .45983 .77497 L .4595 .77244 L F
.505 .813 1 r
.30933 .60213 m .313 .60254 L .31141 .60173 L F
.539 .83 .999 r
.31141 .60173 m .313 .60254 L .31361 .6012 L F
.294 .547 .92 r
.31361 .6012 m .313 .60254 L .31479 .6029 L F
.331 .007 .257 r
.47084 .75527 m .4727 .75538 L .4734 .753 L F
.204 0 .207 r
.4734 .753 m .47443 .75447 L .47546 .75224 L F
.4734 .753 m .4727 .75538 L .47443 .75447 L F
.507 0 0 r
.58475 .68208 m .58279 .68039 L .5844 .68004 L F
.708 .184 0 r
.48254 .76591 m .48387 .76663 L .48232 .76492 L F
.48254 .76591 m .48232 .76492 L .48171 .76425 L F
.442 0 .029 r
.48114 .76706 m .48269 .76661 L .48254 .76591 L F
.603 .383 .555 r
.48171 .76425 m .48387 .76663 L .48418 .76399 L F
.584 .401 .6 r
.48387 .76663 m .48652 .76343 L .48418 .76399 L F
.48387 .76663 m .4865 .76653 L .48652 .76343 L F
.023 .183 .692 r
.48522 .76588 m .48387 .76663 L .48254 .76591 L F
.442 0 .029 r
.48269 .76661 m .48522 .76588 L .48254 .76591 L F
.708 .184 0 r
.48254 .76591 m .48171 .76425 L .48418 .76399 L F
.572 .884 .991 r
.72865 .49898 m .73073 .49706 L .73108 .49828 L F
.72865 .49898 m .72649 .49821 L .73073 .49706 L F
.319 .16 .502 r
.52627 .76969 m .52489 .77238 L .52271 .77004 L F
.52627 .76969 m .52617 .77219 L .52489 .77238 L F
.845 .903 .877 r
.5324 .80243 m .53105 .8057 L .53011 .80285 L F
.048 .226 .725 r
.53011 .80285 m .53105 .8057 L .53211 .80486 L F
.562 .075 .056 r
.53105 .8057 m .53398 .80645 L .53253 .80769 L F
0 0 0 r
.53211 .80486 m .53105 .8057 L .53106 .80635 L F
.673 .501 .644 r
.50908 .75848 m .51242 .7589 L .51226 .75634 L F
.614 .456 .644 r
.51226 .75634 m .51457 .75833 L .51464 .75582 L F
.51226 .75634 m .51242 .7589 L .51457 .75833 L F
.485 .069 .176 r
.38295 .65444 m .38196 .65261 L .38077 .65483 L F
.38295 .65444 m .38426 .65254 L .38196 .65261 L F
.164 0 .194 r
.32586 .61052 m .3273 .61013 L .32798 .60752 L F
.362 .386 .751 r
.32798 .60752 m .32903 .60474 L .32748 .60568 L F
.32798 .60752 m .32995 .60733 L .32903 .60474 L F
.456 .115 .298 r
.32798 .60752 m .32953 .60949 L .32995 .60733 L F
.32798 .60752 m .3273 .61013 L .32953 .60949 L F
.632 .496 .678 r
.65073 .52677 m .65308 .52743 L .65315 .52482 L F
.833 .702 .719 r
.51588 .72179 m .51883 .72251 L .51908 .72013 L F
.902 .635 .524 r
.5167 .72383 m .51883 .72251 L .51588 .72179 L F
.5167 .72383 m .51879 .72479 L .51883 .72251 L F
.705 .488 .593 r
.51879 .72479 m .52237 .72249 L .51883 .72251 L F
.557 .333 .532 r
.4937 .80604 m .49587 .80811 L .49357 .8084 L F
.735 .367 .355 r
.4937 .80604 m .49721 .80849 L .49587 .80811 L F
.324 .519 .892 r
.70785 .49185 m .70742 .49567 L .70739 .49358 L F
.70781 .49223 m .70957 .49541 L .70742 .49567 L F
.70821 .4926 m .70957 .49541 L .70781 .49223 L F
.941 .815 .692 r
.70814 .49168 m .70957 .49541 L .70785 .49185 L F
.71094 .48995 m .70998 .49378 L .70814 .49168 L F
.70998 .49378 m .70957 .49541 L .70814 .49168 L F
.71094 .48995 m .70814 .49168 L .7096 .489 L F
.70814 .49168 m .70785 .49185 L .70804 .49154 L F
.70814 .49168 m .70804 .49154 L .7096 .489 L F
.798 .605 .641 r
.7096 .489 m .70785 .49185 L .70656 .48843 L F
.746 .333 .267 r
.70888 .48998 m .7096 .489 L .70656 .48843 L F
.498 .508 .797 r
.70798 .48468 m .70888 .48998 L .70656 .48843 L F
.772 .699 .782 r
.71145 .48507 m .70888 .48998 L .70798 .48468 L F
.659 .789 .944 r
.70738 .49057 m .71003 .49132 L .70896 .48978 L F
.46 .489 .802 r
.70771 .49147 m .7042 .48899 L .70656 .48843 L F
.70785 .49185 m .7075 .49157 L .70771 .49147 L F
.7075 .49157 m .7042 .48899 L .70771 .49147 L F
.659 .789 .944 r
.70754 .491 m .70848 .49112 L .70723 .49064 L F
.70848 .49112 m .71003 .49132 L .70872 .491 L F
.70848 .49112 m .70872 .491 L .70723 .49064 L F
.70723 .49064 m .70747 .4907 L .70738 .49057 L F
.70747 .4907 m .71003 .49132 L .70738 .49057 L F
.70674 .49089 m .70754 .491 L .70723 .49064 L F
.175 0 .008 r
.70844 .49667 m .71068 .49487 L .70778 .49402 L F
.71068 .49487 m .71115 .49449 L .71011 .49434 L F
.71068 .49487 m .71011 .49434 L .70778 .49402 L F
.324 .519 .892 r
.70785 .49185 m .70821 .4926 L .70781 .49223 L F
.652 .63 .816 r
.49003 .79202 m .4879 .79489 L .48631 .79212 L F
.545 .666 .916 r
.69695 .50282 m .70128 .50486 L .69928 .50267 L F
.455 .508 .823 r
.70128 .50486 m .70216 .50156 L .69928 .50267 L F
.259 0 0 r
.70128 .50486 m .70312 .50538 L .70399 .5054 L F
.793 .636 .688 r
.60698 .74167 m .61036 .742 L .60884 .73897 L F
.699 .719 .864 r
.44399 .66055 m .44703 .66094 L .44634 .6599 L F
.733 .799 .905 r
.44634 .6599 m .44703 .66094 L .44937 .65846 L F
.506 .463 .743 r
.76338 .60583 m .76397 .60793 L .76612 .60762 L F
.602 .54 .757 r
.76397 .60793 m .76754 .6115 L .76612 .60762 L F
.56 .903 .674 r
.63759 .55399 m .6391 .55307 L .64072 .55169 L F
.387 .146 .422 r
.49439 .77219 m .49205 .77502 L .49245 .77282 L F
.773 .61 .678 r
.62972 .48544 m .62635 .48481 L .62866 .48418 L F
.62972 .48544 m .62806 .48732 L .62635 .48481 L F
.914 .958 .803 r
.62972 .48544 m .62771 .4883 L .62806 .48732 L F
.642 .855 .472 r
.62861 .48681 m .62771 .4883 L .62972 .48544 L F
.356 .757 .984 r
.62866 .48418 m .632 .48478 L .62972 .48544 L F
.62866 .48418 m .63088 .48404 L .632 .48478 L F
0 0 0 r
.63088 .48404 m .62972 .48544 L .632 .48478 L F
.63088 .48404 m .62861 .48681 L .62972 .48544 L F
.64213 .54128 m .64411 .53849 L .64077 .53823 L F
.64213 .54128 m .64312 .5399 L .64411 .53849 L F
.633 .911 .618 r
.64213 .54128 m .64063 .54249 L .64312 .5399 L F
.586 .94 .923 r
.75314 .59041 m .75329 .59087 L .75693 .58929 L F
.007 0 0 r
.78375 .61014 m .78182 .61057 L .78373 .60946 L F
.78375 .61014 m .78071 .61212 L .78182 .61057 L F
.055 0 .259 r
.57276 .76952 m .572 .77175 L .57194 .76968 L F
.508 .392 .656 r
.36231 .67001 m .36418 .66976 L .36409 .66627 L F
.496 .329 .583 r
.36234 .67236 m .36418 .66976 L .36231 .67001 L F
.725 .509 .598 r
.34147 .71589 m .34607 .71264 L .3428 .71367 L F
.864 .641 .599 r
.51744 .80234 m .51577 .80584 L .5191 .80455 L F
.611 .454 .644 r
.5558 .7586 m .55681 .76132 L .55351 .76131 L F
.63 .384 .527 r
.55681 .76132 m .55234 .7631 L .55351 .76131 L F
0 .353 .826 r
.35137 .70585 m .35146 .7059 L .35233 .70572 L F
.35146 .7059 m .35389 .7073 L .35285 .70625 L F
.35146 .7059 m .35285 .70625 L .35233 .70572 L F
.196 0 .291 r
.35023 .70619 m .34939 .70845 L .3514 .70589 L F
.35095 .70577 m .3514 .70589 L .35193 .70521 L F
.35023 .70619 m .3514 .70589 L .35095 .70577 L F
.445 .608 .917 r
.62771 .4883 m .62635 .48481 L .62806 .48732 L F
.62771 .4883 m .62417 .48603 L .62635 .48481 L F
.507 .32 .562 r
.6298 .49015 m .62771 .4883 L .62861 .48681 L F
.6298 .49015 m .62756 .49076 L .62771 .4883 L F
.727 .829 .928 r
.70553 .50318 m .70655 .50493 L .70849 .50314 L F
.917 .939 .804 r
.5538 .76648 m .55468 .76741 L .5534 .76872 L F
.903 .942 .824 r
.55702 .76417 m .55468 .76741 L .5538 .76648 L F
.681 .806 .942 r
.63543 .48511 m .632 .48478 L .63421 .48414 L F
.59 .795 .978 r
.63647 .48332 m .63543 .48511 L .63421 .48414 L F
.63647 .48332 m .63778 .48459 L .63543 .48511 L F
.863 .827 .352 r
.63194 .51927 m .63134 .52031 L .63112 .51754 L F
.898 .779 .721 r
.66183 .5408 m .66479 .53872 L .6634 .53767 L F
.66183 .5408 m .664 .54072 L .66479 .53872 L F
.108 0 0 r
.38758 .7192 m .38416 .71906 L .38445 .71902 L F
0 0 0 r
.63004 .51348 m .62734 .51568 L .63007 .51344 L F
.62901 .51483 m .62801 .51534 L .63004 .51348 L F
.62801 .51534 m .62734 .51568 L .63004 .51348 L F
.62901 .51483 m .62756 .51581 L .62734 .51568 L F
.821 .639 .657 r
.62351 .51491 m .62751 .5158 L .62553 .5124 L F
.62751 .5158 m .62756 .51581 L .62754 .51578 L F
.62751 .5158 m .62754 .51578 L .62553 .5124 L F
0 0 0 r
.62901 .51483 m .63007 .51344 L .6287 .51266 L F
0 .175 .711 r
.63007 .51344 m .63148 .51391 L .63349 .51305 L F
.63007 .51344 m .63183 .51518 L .63148 .51391 L F
.868 .791 .773 r
.61919 .49371 m .61843 .49036 L .61987 .49145 L F
.61919 .49371 m .61666 .49301 L .61843 .49036 L F
.937 .799 .683 r
.61919 .49371 m .61649 .49538 L .61666 .49301 L F
.61919 .49371 m .61788 .49643 L .61649 .49538 L F
.478 .364 .645 r
.72864 .50457 m .72702 .50749 L .72678 .50518 L F
.492 0 0 r
.39201 .65127 m .39422 .65162 L .3958 .6506 L F
.347 0 0 r
.3958 .6506 m .39422 .65162 L .39766 .6511 L F
.367 .017 .233 r
.4835 .74734 m .48484 .74747 L .48647 .74535 L F
.242 0 .141 r
.48647 .74535 m .48759 .74649 L .48827 .74455 L F
.48647 .74535 m .48484 .74747 L .48759 .74649 L F
.539 .279 .469 r
.61944 .54433 m .62181 .54578 L .62178 .54369 L F
.61944 .54433 m .61908 .54627 L .62181 .54578 L F
.695 .181 .003 r
.69604 .48836 m .69981 .48984 L .69746 .49101 L F
.589 .423 .625 r
.50159 .75127 m .49962 .75319 L .49882 .74972 L F
.50159 .75127 m .50202 .75297 L .49962 .75319 L F
.592 .438 .642 r
.50202 .75297 m .49982 .75566 L .49962 .75319 L F
.569 .114 .133 r
.32155 .60341 m .31977 .60455 L .31837 .60359 L F
0 0 0 r
.32259 .60291 m .32155 .60341 L .322 .60323 L F
.32259 .60291 m .31977 .60455 L .32155 .60341 L F
.79 .577 .612 r
.59128 .74709 m .5944 .75 L .59314 .74753 L F
.59128 .74709 m .59396 .75141 L .5944 .75 L F
.515 .281 .497 r
.59423 .75107 m .5945 .75283 L .5944 .75 L F
.5944 .75 m .5945 .75283 L .59423 .75107 L F
.428 .58 .901 r
.5944 .75 m .59558 .7484 L .59314 .74753 L F
.5944 .75 m .59694 .74989 L .59558 .7484 L F
.447 .311 .603 r
.59694 .74989 m .59667 .75212 L .5944 .75 L F
.551 .308 .5 r
.5945 .75283 m .59667 .75212 L .5944 .75 L F
.447 .311 .603 r
.5944 .75 m .59667 .75212 L .59694 .74989 L F
.551 .308 .5 r
.5945 .75283 m .59667 .75212 L .5944 .75 L F
.407 .186 .463 r
.5944 .75 m .59396 .75141 L .59423 .75107 L F
.561 .409 .631 r
.76535 .60191 m .76731 .59937 L .76483 .59965 L F
.47 .184 .396 r
.5506 .69686 m .55275 .6965 L .55542 .69227 L F
.472 .41 .707 r
.55542 .69227 m .5577 .69461 L .5561 .69149 L F
.257 0 0 r
.55275 .6965 m .5577 .69461 L .55542 .69227 L F
.717 .457 .532 r
.59608 .69421 m .59915 .69427 L .59752 .6926 L F
.9 .718 .212 r
.59025 .69194 m .58981 .69317 L .58687 .69056 L F
.59025 .69194 m .5901 .69434 L .58981 .69317 L F
.574 .783 .978 r
.68014 .4829 m .67894 .48482 L .67763 .48342 L F
.68014 .4829 m .68134 .48425 L .67894 .48482 L F
.379 .703 .984 r
.34075 .5935 m .34013 .59461 L .33869 .59384 L F
.34075 .5935 m .34202 .59456 L .34013 .59461 L F
.44 .747 .993 r
.51443 .74179 m .5155 .74062 L .51332 .73886 L F
.51443 .74179 m .51668 .74166 L .5155 .74062 L F
.119 0 0 r
.40516 .69869 m .40735 .69851 L .40914 .69784 L F
.253 .747 .665 r
.40914 .69784 m .40928 .69778 L .4113 .69738 L F
.40914 .69784 m .40735 .69851 L .40928 .69778 L F
.518 .277 .489 r
.50156 .73597 m .50284 .73581 L .50391 .73337 L F
.43 .167 .412 r
.50284 .73581 m .50628 .73252 L .50391 .73337 L F
.69 .347 .391 r
.58888 .73654 m .59072 .73798 L .59091 .73586 L F
.58888 .73654 m .58885 .73846 L .59072 .73798 L F
0 .118 .637 r
.59075 .71121 m .59022 .71038 L .58993 .71036 L F
.794 .554 0 r
.59083 .71358 m .59022 .71038 L .59075 .71121 L F
.59083 .71358 m .59055 .71273 L .59022 .71038 L F
.938 .857 .427 r
.59055 .71273 m .59059 .7104 L .59022 .71038 L F
.59059 .7104 m .59061 .70942 L .59022 .71038 L F
0 .118 .637 r
.58993 .71036 m .59022 .71038 L .58804 .70841 L F
.144 .663 .886 r
.4263 .64915 m .4298 .64965 L .42766 .64982 L F
.786 .694 .762 r
.48898 .80012 m .49247 .80043 L .49136 .79739 L F
.759 .41 .392 r
.49203 .80251 m .49247 .80043 L .48898 .80012 L F
.734 .384 .387 r
.49203 .80251 m .49447 .803 L .49247 .80043 L F
.801 .361 .2 r
.49604 .80291 m .49247 .80043 L .49447 .803 L F
.598 .658 .88 r
.72936 .61117 m .7328 .61326 L .73212 .61073 L F
.692 .723 .873 r
.73212 .61073 m .7328 .61326 L .7351 .61167 L F
.717 .636 .766 r
.49507 .74734 m .4997 .74786 L .49749 .74482 L F
.658 .616 .795 r
.49507 .74734 m .49882 .74972 L .4997 .74786 L F
.632 .61 .81 r
.49749 .74482 m .4997 .74786 L .50081 .74734 L F
.463 .276 .541 r
.49882 .74972 m .50081 .74734 L .4997 .74786 L F
.638 .587 .781 r
.48368 .66934 m .48139 .67164 L .47989 .6679 L F
.51 .204 .383 r
.39888 .67117 m .39713 .66957 L .39926 .66922 L F
.39888 .67117 m .39658 .67154 L .39713 .66957 L F
.359 .247 .587 r
.58411 .5761 m .58191 .57446 L .58521 .57471 L F
.487 .87 .975 r
.58798 .57568 m .58411 .5761 L .58521 .57471 L F
.517 .106 .2 r
.58521 .57471 m .58841 .57443 L .58798 .57568 L F
.359 .663 .972 r
.51162 .73362 m .51207 .73412 L .50863 .73211 L F
.843 .753 .764 r
.59782 .5384 m .59872 .54153 L .59688 .54045 L F
0 0 .241 r
.733 .50027 m .73196 .4997 L .73108 .49828 L F
.733 .50027 m .73156 .50185 L .73196 .4997 L F
.576 .44 .66 r
.76338 .60583 m .7659 .60523 L .76535 .60191 L F
.506 .463 .743 r
.76338 .60583 m .76612 .60762 L .7659 .60523 L F
.481 .331 .6 r
.55149 .75077 m .55357 .75244 L .55337 .74988 L F
.74 .682 .794 r
.49749 .74482 m .50179 .74519 L .50017 .74252 L F
.632 .61 .81 r
.49749 .74482 m .50081 .74734 L .50179 .74519 L F
.848 .659 .647 r
.64327 .4966 m .64055 .49732 L .64305 .49613 L F
.64327 .4966 m .64218 .49928 L .64055 .49732 L F
.64327 .4966 m .64313 .49955 L .64218 .49928 L F
.857 .926 .537 r
.64327 .4966 m .64305 .49613 L .64377 .49427 L F
.835 .719 .737 r
.49024 .803 m .48788 .80303 L .48866 .80214 L F
.49024 .803 m .48662 .8059 L .48788 .80303 L F
.49024 .803 m .48888 .80578 L .48662 .8059 L F
.759 .41 .392 r
.49203 .80251 m .48898 .80012 L .49024 .803 L F
.385 .719 .988 r
.49203 .80251 m .49024 .803 L .48866 .80214 L F
.686 .5 .629 r
.59348 .57034 m .58969 .57435 L .59048 .57166 L F
.535 .512 .777 r
.50908 .75848 m .51238 .76059 L .51242 .7589 L F
.565 .563 .81 r
.53723 .74225 m .53826 .74497 L .53962 .74264 L F
.53 .416 .669 r
.53826 .74497 m .54078 .74683 L .53962 .74264 L F
.53826 .74497 m .53861 .74734 L .54078 .74683 L F
.542 .32 .528 r
.6269 .53933 m .62965 .53785 L .6265 .53826 L F
.626 .533 .729 r
.47905 .66117 m .47689 .66188 L .47597 .65805 L F
.863 .429 .011 r
.56628 .74092 m .56863 .74473 L .56791 .74174 L F
0 0 0 r
.58233 .72277 m .58068 .72761 L .5814 .72535 L F
.961 .715 .52 r
.5995 .72145 m .6011 .71902 L .59997 .71854 L F
.5995 .72145 m .60116 .72211 L .6011 .71902 L F
.5 .663 .935 r
.35286 .59955 m .34893 .5977 L .35189 .59808 L F
.492 .657 .934 r
.35487 .59939 m .35286 .59955 L .35189 .59808 L F
.26 .655 .966 r
.27104 .65354 m .27287 .65271 L .26954 .6524 L F
.27104 .65354 m .27345 .65362 L .27287 .65271 L F
.629 .407 .561 r
.47661 .78141 m .4759 .78311 L .47398 .78351 L F
.406 .173 .445 r
.47834 .78279 m .4759 .78311 L .47661 .78141 L F
.809 .678 .719 r
.55028 .76378 m .5523 .76691 L .54803 .76649 L F
.91 .925 .813 r
.55023 .76753 m .54998 .76959 L .5523 .76691 L F
.323 .473 .855 r
.5538 .76648 m .5523 .76691 L .55028 .76378 L F
0 0 0 r
.55023 .76753 m .5523 .76691 L .5538 .76648 L F
.997 .77 .448 r
.75733 .61865 m .75809 .62209 L .75964 .62072 L F
.437 .609 .92 r
.75809 .62209 m .76081 .62236 L .75964 .62072 L F
0 0 0 r
.74352 .59643 m .74624 .59407 L .74571 .59586 L F
.556 .886 .628 r
.74862 .59347 m .74571 .59586 L .74624 .59407 L F
.917 .892 .791 r
.61075 .51892 m .61161 .51489 L .61266 .5158 L F
.947 .892 .743 r
.61266 .5158 m .61161 .51489 L .6125 .51306 L F
.457 .218 .463 r
.69929 .53083 m .69726 .52999 L .69939 .52898 L F
.69929 .53083 m .69738 .53178 L .69726 .52999 L F
.454 .112 .295 r
.41339 .66434 m .41274 .66592 L .41052 .66625 L F
.875 .725 .692 r
.66315 .52415 m .66471 .52442 L .66362 .52165 L F
.871 .579 .492 r
.66315 .52415 m .66401 .52663 L .66471 .52442 L F
.618 .303 .415 r
.66401 .52663 m .66752 .52635 L .66471 .52442 L F
.317 0 .08 r
.24318 .59365 m .24516 .59334 L .24654 .59148 L F
.22 0 .02 r
.24654 .59148 m .24711 .59272 L .24849 .59076 L F
.24654 .59148 m .24516 .59334 L .24711 .59272 L F
.65 .097 0 r
.5811 .72193 m .58233 .72277 L .58238 .72244 L F
.664 .624 .8 r
.37398 .72274 m .3759 .72198 L .3748 .71857 L F
.506 .347 .599 r
.74352 .59643 m .74408 .59979 L .74173 .60021 L F
.542 .527 .788 r
.74408 .59979 m .74487 .60165 L .74173 .60021 L F
.554 .115 .16 r
.4948 .75052 m .49732 .75167 L .49882 .74972 L F
.463 .276 .541 r
.49882 .74972 m .50085 .7496 L .50081 .74734 L F
.599 .243 .337 r
.49732 .75167 m .50085 .7496 L .49882 .74972 L F
.408 .203 .487 r
.35406 .61273 m .35241 .6108 L .35442 .61053 L F
.35406 .61273 m .35219 .61346 L .35241 .6108 L F
.708 .209 .052 r
.63349 .51305 m .63474 .51453 L .63578 .51366 L F
.544 .083 .11 r
.63474 .51453 m .63853 .51362 L .63578 .51366 L F
.88 .89 .835 r
.61559 .51134 m .61738 .50684 L .61851 .50823 L F
.61559 .51134 m .61454 .51045 L .61738 .50684 L F
.74 .55 .637 r
.5029 .80882 m .5052 .80536 L .50247 .80601 L F
.5029 .80882 m .50494 .80839 L .5052 .80536 L F
.502 .469 .753 r
.36223 .6834 m .36299 .68627 L .36489 .68586 L F
.503 .47 .753 r
.36299 .68627 m .36567 .68832 L .36489 .68586 L F
.909 .798 .726 r
.66498 .5305 m .66583 .53033 L .6646 .52904 L F
.814 .809 .846 r
.6646 .52904 m .66583 .53033 L .66896 .52705 L F
.397 .179 .461 r
.26909 .61869 m .26686 .62169 L .26711 .619 L F
.544 .469 .721 r
.74571 .59586 m .74408 .59979 L .74352 .59643 L F
.184 0 .068 r
.57035 .68017 m .57209 .67956 L .57286 .67764 L F
.096 0 .033 r
.57286 .67764 m .57375 .6787 L .5753 .67654 L F
.57286 .67764 m .57209 .67956 L .57375 .6787 L F
.2 0 .137 r
.56389 .6914 m .5632 .69342 L .56102 .69339 L F
0 0 0 r
.5632 .69342 m .5609 .69601 L .56102 .69339 L F
.554 .631 .882 r
.75061 .60376 m .74878 .60577 L .74832 .60416 L F
.75061 .60376 m .75106 .60553 L .74878 .60577 L F
.485 .834 .561 r
.75576 .58378 m .75324 .58595 L .75475 .5846 L F
.238 .743 .689 r
.75658 .58347 m .75576 .58378 L .75475 .5846 L F
.75658 .58347 m .75799 .58304 L .75576 .58378 L F
.021 0 0 r
.75041 .58834 m .7526 .58748 L .75324 .58595 L F
0 0 0 r
.75324 .58595 m .7526 .58748 L .75475 .5846 L F
.346 0 .144 r
.46809 .75631 m .46967 .75698 L .47084 .75527 L F
.46809 .75631 m .46747 .75754 L .46967 .75698 L F
.705 .488 .593 r
.51879 .72479 m .52237 .72481 L .52237 .72249 L F
.232 0 0 r
.403 .71078 m .40181 .71208 L .39972 .71251 L F
.197 0 0 r
.40395 .71154 m .403 .71078 L .40489 .71031 L F
.40395 .71154 m .40181 .71208 L .403 .71078 L F
.576 .635 .873 r
.27191 .63473 m .27072 .63698 L .26968 .63546 L F
.27191 .63473 m .27299 .63685 L .27072 .63698 L F
.594 .531 .753 r
.45311 .66095 m .45394 .66418 L .4562 .66373 L F
.583 .589 .825 r
.45394 .66418 m .45747 .66676 L .4562 .66373 L F
.572 .5 .735 r
.52675 .77473 m .52747 .77803 L .52525 .77811 L F
0 0 0 r
.52747 .77803 m .52342 .77881 L .52525 .77811 L F
.794 .68 .738 r
.53591 .80284 m .53889 .80247 L .53792 .80024 L F
.726 .65 .773 r
.53889 .80247 m .54152 .80028 L .53792 .80024 L F
.598 .801 .978 r
.76235 .58829 m .76328 .58662 L .7613 .58716 L F
.76235 .58829 m .76455 .58771 L .76328 .58662 L F
.123 0 0 r
.64392 .51107 m .6425 .51175 L .64022 .51198 L F
.553 .001 0 r
.64392 .51107 m .64611 .51229 L .6425 .51175 L F
.52 .214 .389 r
.64641 .51063 m .64611 .51229 L .64392 .51107 L F
.959 .653 .404 r
.49508 .8051 m .49604 .80291 L .49447 .803 L F
.49508 .8051 m .49648 .80569 L .49604 .80291 L F
.558 .834 .997 r
.30183 .58823 m .30134 .58956 L .29982 .58862 L F
.30183 .58823 m .30298 .58897 L .30134 .58956 L F
.509 .046 .089 r
.74655 .59051 m .75141 .59031 L .75041 .58834 L F
.445 .016 .13 r
.75041 .58834 m .75286 .58979 L .7526 .58748 L F
.75041 .58834 m .75141 .59031 L .75286 .58979 L F
.217 0 0 r
.31078 .64912 m .3079 .65021 L .30849 .64964 L F
.623 .708 .906 r
.73876 .61326 m .73992 .61024 L .73775 .61106 L F
.73876 .61326 m .74106 .61275 L .73992 .61024 L F
.324 .044 .324 r
.32207 .61919 m .32387 .61853 L .32455 .61656 L F
.188 0 .152 r
.32387 .61853 m .32653 .61597 L .32455 .61656 L F
.071 0 0 r
.72069 .51852 m .71791 .52071 L .71867 .5196 L F
.735 .746 .86 r
.36293 .70617 m .3641 .70885 L .36288 .70859 L F
.631 .692 .888 r
.36761 .70777 m .3641 .70885 L .36293 .70617 L F
.64 .727 .911 r
.36794 .70885 m .3641 .70885 L .36761 .70777 L F
.378 .013 .214 r
.43788 .68529 m .43981 .68562 L .44072 .68348 L F
.257 0 .158 r
.44072 .68348 m .44182 .68482 L .44294 .68313 L F
.44072 .68348 m .43981 .68562 L .44182 .68482 L F
.986 .73 .349 r
.61936 .52356 m .6206 .5249 L .62 .52207 L F
.908 .708 .621 r
.61679 .52608 m .6206 .5249 L .61936 .52356 L F
.039 0 0 r
.62116 .52255 m .61912 .52413 L .61936 .52356 L F
.61912 .52413 m .61866 .52448 L .61936 .52356 L F
.986 .73 .349 r
.61936 .52356 m .62 .52207 L .6199 .52157 L F
.908 .708 .621 r
.61679 .52608 m .61835 .52659 L .6206 .5249 L F
.792 .482 .464 r
.6206 .5249 m .61835 .52659 L .61992 .52649 L F
.642 .227 .241 r
.51696 .75569 m .51917 .75748 L .52057 .75563 L F
.7 .296 .28 r
.51917 .75748 m .52273 .75766 L .52057 .75563 L F
.65 .616 .802 r
.4562 .66373 m .45747 .66676 L .45988 .66641 L F
.605 .469 .669 r
.45778 .66915 m .45988 .66641 L .45747 .66676 L F
.615 .944 .943 r
.34536 .72517 m .34438 .72492 L .34602 .72402 L F
.34536 .72517 m .34438 .72492 L .34602 .72402 L F
.443 .141 .356 r
.44294 .68313 m .44509 .68269 L .4459 .68016 L F
.463 .133 .32 r
.44509 .68269 m .4483 .68 L .4459 .68016 L F
.545 .279 .462 r
.28438 .60536 m .28627 .60694 L .28419 .60724 L F
.117 0 0 r
.43084 .66145 m .42998 .66093 L .43219 .66047 L F
.43084 .66145 m .42857 .66203 L .42998 .66093 L F
.758 .551 .616 r
.59874 .57188 m .59514 .57379 L .59553 .5713 L F
.59874 .57188 m .59863 .57428 L .59514 .57379 L F
.713 .512 .616 r
.59874 .57188 m .60122 .57493 L .59863 .57428 L F
.747 .537 .611 r
.59874 .57188 m .60236 .57459 L .60122 .57493 L F
.566 .215 .333 r
.53989 .77127 m .54219 .7714 L .54283 .7684 L F
.512 .159 .306 r
.54219 .7714 m .54549 .76885 L .54283 .7684 L F
.762 .529 .58 r
.58856 .7245 m .58486 .72201 L .58944 .72395 L F
.651 .116 0 r
.65987 .51157 m .65931 .51049 L .65987 .51152 L F
.636 .208 0 r
.65741 .50754 m .65987 .51152 L .65931 .51049 L F
.427 .153 .393 r
.70214 .52656 m .69939 .52898 L .69967 .52723 L F
.47 .534 .841 r
.47649 .65472 m .47597 .65805 L .47472 .65478 L F
.47649 .65472 m .47786 .6579 L .47597 .65805 L F
.626 .533 .729 r
.47905 .66117 m .47597 .65805 L .47786 .6579 L F
.419 .855 .931 r
.29241 .65093 m .29444 .65108 L .29612 .65054 L F
.861 .537 .018 r
.54995 .77485 m .55147 .77858 L .55282 .77688 L F
.563 .743 .961 r
.55147 .77858 m .5538 .77823 L .55282 .77688 L F
.466 .167 .373 r
.49219 .78931 m .49234 .791 L .49003 .79202 L F
.417 .347 .671 r
.55806 .76065 m .55681 .76132 L .5558 .7586 L F
.903 .942 .824 r
.55702 .76417 m .5538 .76648 L .55632 .76378 L F
.937 .967 .723 r
.55702 .76417 m .55632 .76378 L .55806 .76065 L F
0 0 0 r
.58757 .71722 m .58538 .71963 L .58675 .71833 L F
.40707 .66686 m .40448 .66815 L .40512 .66711 L F
.564 .517 .761 r
.36106 .67751 m .36411 .68028 L .36309 .67707 L F
.606 .333 .477 r
.39433 .67209 m .39144 .67439 L .39204 .67252 L F
.272 .459 .861 r
.58971 .74436 m .59128 .74709 L .59209 .74581 L F
.316 .518 .894 r
.59209 .74581 m .59128 .74709 L .59314 .74753 L F
.36 .116 .403 r
.52883 .75518 m .53056 .75538 L .53094 .75327 L F
.352 .019 .253 r
.52883 .75518 m .52814 .75728 L .53056 .75538 L F
.256 0 0 r
.70877 .52302 m .70968 .52375 L .70709 .52431 L F
.569 .937 .823 r
.71104 .52243 m .71102 .52245 L .71147 .52246 L F
.126 0 .159 r
.71147 .52246 m .70877 .52302 L .71215 .52248 L F
.71147 .52246 m .70968 .52375 L .70877 .52302 L F
.569 .937 .823 r
.71102 .52245 m .70968 .52375 L .71147 .52246 L F
.126 0 .159 r
.71147 .52246 m .71215 .52248 L .71291 .52236 L F
.598 .561 .784 r
.39017 .68275 m .38934 .68694 L .38801 .6832 L F
.39017 .68275 m .39131 .68639 L .38934 .68694 L F
.332 .031 .296 r
.37274 .65496 m .37082 .65564 L .37011 .65764 L F
.553 .363 .578 r
.49605 .7755 m .49329 .77809 L .49205 .77502 L F
.49605 .7755 m .49525 .77832 L .49329 .77809 L F
.705 .344 .361 r
.49525 .77832 m .49215 .77949 L .49329 .77809 L F
.37 .782 .98 r
.49678 .78581 m .50025 .78622 L .49802 .78643 L F
.603 .616 .837 r
.50226 .78817 m .49802 .78643 L .50025 .78622 L F
.822 .674 .7 r
.59439 .54944 m .59617 .55249 L .59385 .55177 L F
.829 .67 .685 r
.59617 .55249 m .59531 .55501 L .59385 .55177 L F
.245 0 .296 r
.31269 .62784 m .3103 .63076 L .31208 .62995 L F
.279 .029 .345 r
.31269 .62784 m .31381 .62913 L .3143 .62722 L F
.31269 .62784 m .31208 .62995 L .31381 .62913 L F
.632 .555 .75 r
.72277 .49113 m .72127 .49387 L .72059 .4912 L F
.72277 .49113 m .72378 .49386 L .72127 .49387 L F
.584 .338 .509 r
.61037 .56898 m .61266 .57099 L .61082 .57173 L F
.662 .31 .366 r
.61256 .56944 m .61266 .57099 L .61037 .56898 L F
.538 .307 .512 r
.61037 .56898 m .61082 .57173 L .60807 .57317 L F
.455 .128 .322 r
.62035 .56812 m .62142 .56544 L .62343 .56589 L F
.642 .502 .678 r
.76656 .59472 m .76928 .59402 L .77008 .593 L F
.453 0 0 r
.63428 .49685 m .63675 .49788 L .63756 .4974 L F
.679 .648 .812 r
.64055 .49732 m .63819 .49962 L .63756 .4974 L F
.643 .662 .854 r
.36847 .71186 m .36911 .71409 L .37148 .71367 L F
.57 .626 .868 r
.52679 .73644 m .52835 .73921 L .53044 .73868 L F
.507 .348 .6 r
.52835 .73921 m .52839 .74159 L .53044 .73868 L F
0 0 0 r
.64411 .53849 m .64515 .53733 L .64642 .53797 L F
.64411 .53849 m .64312 .5399 L .64515 .53733 L F
.677 .634 .799 r
.63409 .4937 m .632 .4944 L .63106 .49175 L F
.834 .845 .855 r
.69818 .49843 m .69952 .49989 L .70199 .49753 L F
.619 .119 .041 r
.69851 .50099 m .69952 .49989 L .69818 .49843 L F
.69851 .50099 m .70216 .50156 L .69952 .49989 L F
.094 0 0 r
.39766 .6511 m .39979 .65094 L .40158 .6504 L F
.327 0 0 r
.39979 .65094 m .40356 .65006 L .40158 .6504 L F
.198 .712 .887 r
.52019 .74186 m .51918 .74157 L .51668 .74166 L F
.014 .158 .67 r
.52084 .7402 m .52019 .74186 L .5193 .73897 L F
.736 .972 .929 r
.52084 .7402 m .51918 .74157 L .52019 .74186 L F
.644 .507 .682 r
.72173 .60208 m .72381 .5992 L .72135 .59991 L F
.72173 .60208 m .72496 .60284 L .72381 .5992 L F
.61 .543 .755 r
.72173 .60208 m .725 .6048 L .72496 .60284 L F
.718 .495 .587 r
.48492 .80278 m .48788 .80303 L .48662 .8059 L F
.633 .339 .455 r
.51577 .80584 m .51292 .80399 L .5131 .80601 L F
.614 .357 .505 r
.71092 .50188 m .70849 .50314 L .70875 .5023 L F
.61 .132 .094 r
.56285 .78051 m .56646 .78082 L .56458 .78203 L F
.733 .973 .723 r
.56458 .78203 m .56646 .78082 L .56817 .77885 L F
.627 .689 .889 r
.4958 .79377 m .49713 .7953 L .49927 .79451 L F
.298 .569 .933 r
.67344 .5134 m .67457 .51358 L .67381 .51213 L F
.918 .884 .785 r
.67381 .51213 m .67457 .51358 L .67649 .51097 L F
.925 .604 .415 r
.67381 .51213 m .676 .51508 L .67344 .5134 L F
.552 .803 .992 r
.57617 .68533 m .57785 .68627 L .57435 .68582 L F
.797 .576 .603 r
.5058 .74919 m .50768 .75036 L .50359 .74981 L F
.726 .555 .659 r
.50768 .75036 m .50261 .75272 L .50359 .74981 L F
.50768 .75036 m .50786 .75297 L .50261 .75272 L F
.562 .824 .995 r
.50886 .74903 m .50768 .75036 L .5058 .74919 L F
.50886 .74903 m .51012 .74999 L .50768 .75036 L F
.629 .481 .662 r
.51012 .74999 m .50786 .75297 L .50768 .75036 L F
.72 .783 .296 r
.51271 .72184 m .51181 .72405 L .51214 .72247 L F
.342 .036 .293 r
.6234 .5638 m .62517 .56484 L .62343 .56589 L F
.6234 .5638 m .62463 .5632 L .62517 .56484 L F
.305 .794 .886 r
.65111 .54634 m .65432 .54607 L .65347 .54589 L F
.734 .848 .934 r
.65432 .54607 m .656 .54329 L .65347 .54589 L F
.65432 .54607 m .65691 .54502 L .656 .54329 L F
.47 .198 .419 r
.48136 .74913 m .48386 .74838 L .4835 .74734 L F
.272 .006 .315 r
.48386 .74838 m .48484 .74747 L .4835 .74734 L F
.549 .396 .626 r
.38999 .68026 m .38801 .6832 L .38784 .68067 L F
.887 .829 .784 r
.66183 .5408 m .66038 .54515 L .664 .54072 L F
.718 .554 .666 r
.35941 .7102 m .36006 .71183 L .36305 .71042 L F
.759 .973 .923 r
.62143 .52973 m .61854 .53165 L .62016 .53112 L F
0 0 0 r
.63648 .51858 m .63894 .51576 L .63807 .51729 L F
.315 .293 .675 r
.64022 .51198 m .63894 .51576 L .63853 .51362 L F
.64022 .51198 m .64103 .51534 L .63894 .51576 L F
.31 0 .156 r
.64103 .51534 m .63807 .51729 L .63894 .51576 L F
.653 .832 .969 r
.29107 .63757 m .28815 .63772 L .28993 .63714 L F
.544 .87 .994 r
.29107 .63757 m .29192 .6364 L .29412 .63703 L F
.29107 .63757 m .28993 .63714 L .29192 .6364 L F
.382 .479 .835 r
.70409 .49661 m .70538 .49957 L .70678 .49782 L F
.709 .61 .745 r
.70425 .50119 m .70678 .49782 L .70538 .49957 L F
.352 .734 .987 r
.27945 .58533 m .28141 .58525 L .28294 .58615 L F
.386 .725 .989 r
.28336 .58498 m .28294 .58615 L .28141 .58525 L F
.28336 .58498 m .28509 .58615 L .28294 .58615 L F
.597 .428 .624 r
.50261 .75272 m .50159 .75127 L .50359 .74981 L F
.50261 .75272 m .50202 .75297 L .50159 .75127 L F
.771 .669 .751 r
.54812 .69964 m .5518 .70045 L .5506 .69686 L F
.095 .239 .723 r
.5506 .69686 m .5518 .70045 L .55258 .69877 L F
.995 .765 .41 r
.55323 .7018 m .55258 .69877 L .5518 .70045 L F
.735 .849 .934 r
.55378 .79059 m .55634 .7892 L .55326 .78905 L F
.777 .667 .743 r
.4959 .79175 m .50032 .79308 L .49806 .78917 L F
.806 .577 .592 r
.49927 .79451 m .50032 .79308 L .4959 .79175 L F
.518 .56 .837 r
.49806 .78917 m .50032 .79308 L .5018 .79233 L F
.098 0 .071 r
.5018 .79233 m .50032 .79308 L .49927 .79451 L F
.605 .469 .669 r
.45778 .66915 m .46008 .66887 L .45988 .66641 L F
.561 .376 .588 r
.45786 .67145 m .46008 .66887 L .45778 .66915 L F
.823 .94 .903 r
.62417 .48603 m .62068 .48755 L .62353 .4852 L F
.789 .937 .927 r
.62417 .48603 m .62505 .48387 L .62635 .48481 L F
.62417 .48603 m .62353 .4852 L .62505 .48387 L F
.491 .49 .783 r
.39401 .68765 m .39214 .68972 L .39131 .68639 L F
.45 .387 .695 r
.39458 .69143 m .39214 .68972 L .39401 .68765 L F
.39458 .69143 m .39284 .69147 L .39214 .68972 L F
.321 0 0 r
.41332 .70754 m .41035 .70859 L .41096 .70786 L F
.746 .527 .598 r
.49982 .8082 m .5029 .80882 L .50247 .80601 L F
.574 .822 .992 r
.77114 .57777 m .76908 .57973 L .7681 .57864 L F
.77114 .57777 m .77245 .57917 L .76908 .57973 L F
.779 .278 0 r
.55909 .73435 m .5616 .73718 L .56202 .73659 L F
.753 .237 0 r
.5616 .73718 m .5641 .7392 L .56202 .73659 L F
.51 0 0 r
.5488 .72726 m .55063 .72801 L .55193 .72808 L F
.439 0 0 r
.55063 .72801 m .55474 .72962 L .55193 .72808 L F
.412 .825 .973 r
.29601 .63643 m .29805 .63604 L .29972 .63651 L F
.327 .791 .938 r
.29805 .63604 m .30187 .63611 L .29972 .63651 L F
.878 .789 .759 r
.38203 .72563 m .37912 .72725 L .38178 .72269 L F
.77 .491 .513 r
.38203 .72563 m .38304 .72769 L .37936 .7272 L F
.548 .552 .81 r
.37936 .7272 m .38152 .72699 L .38147 .72685 L F
.77 .491 .513 r
.38203 .72563 m .37936 .7272 L .37913 .72724 L F
.804 .679 .726 r
.38178 .72269 m .37912 .72725 L .37792 .72433 L F
.548 .552 .81 r
.37936 .7272 m .38147 .72685 L .38021 .72364 L F
.77 .491 .513 r
.37913 .72724 m .37936 .7272 L .37912 .72725 L F
.354 .391 .761 r
.38395 .72406 m .38203 .72563 L .38178 .72269 L F
.881 .882 .83 r
.38395 .72406 m .38304 .72769 L .38203 .72563 L F
.746 .369 .338 r
.48662 .8059 m .48888 .80578 L .49037 .8081 L F
.665 .883 .519 r
.5022 .7742 m .50165 .77525 L .50343 .77281 L F
0 .183 .71 r
.5022 .7742 m .50307 .77652 L .50165 .77525 L F
.123 .385 .84 r
.66091 .51466 m .66137 .51295 L .65987 .51157 L F
.783 .959 .925 r
.6622 .51102 m .66031 .51166 L .66173 .51014 L F
.92 .55 .302 r
.65749 .50827 m .65868 .5114 L .65987 .51157 L F
0 0 .26 r
.65803 .50963 m .65868 .5114 L .65749 .50827 L F
.824 .532 0 r
.65803 .50963 m .65866 .51195 L .65868 .5114 L F
.783 .959 .925 r
.65877 .51218 m .65871 .5122 L .65877 .51216 L F
.97 .697 .456 r
.65871 .5122 m .65934 .51439 L .65771 .51181 L F
.929 .738 .624 r
.65771 .51181 m .65934 .51439 L .65878 .51236 L F
0 .14 .683 r
.65771 .51181 m .6587 .51233 L .65871 .5122 L F
.929 .738 .624 r
.65771 .51181 m .65878 .51236 L .65803 .50963 L F
0 .14 .683 r
.65771 .51181 m .65869 .51287 L .6587 .51233 L F
.824 .532 0 r
.6588 .51223 m .65934 .51439 L .65891 .51247 L F
.65878 .51236 m .65934 .51439 L .6588 .51223 L F
0 .14 .683 r
.65869 .51287 m .65925 .51347 L .65878 .51237 L F
.65869 .51287 m .65878 .51237 L .65871 .5122 L F
.783 .959 .925 r
.66031 .51166 m .65877 .51218 L .66023 .51116 L F
.65877 .51218 m .65877 .51216 L .66023 .51116 L F
.66031 .51166 m .66023 .51116 L .66173 .51014 L F
.737 .276 0 r
.65749 .50827 m .65987 .51152 L .65741 .50754 L F
.92 .55 .302 r
.65749 .50827 m .65987 .51157 L .65987 .51152 L F
.14 .027 .452 r
.65871 .5122 m .66082 .50891 L .66173 .51014 L F
.65875 .51213 m .66059 .51142 L .66082 .50891 L F
.65871 .5122 m .65876 .51218 L .65875 .51213 L F
.65876 .51218 m .66059 .51142 L .65875 .51213 L F
.123 .385 .84 r
.66072 .51412 m .65987 .51157 L .66037 .51202 L F
.019 0 .141 r
.65876 .51218 m .65925 .51347 L .66059 .51142 L F
.65871 .5122 m .65878 .51237 L .65876 .51218 L F
.824 .532 0 r
.65877 .51226 m .65878 .51236 L .65879 .51231 L F
.65878 .51236 m .65878 .51236 L .65877 .51226 L F
.65876 .51214 m .65879 .51231 L .6588 .51223 L F
.019 0 .141 r
.65878 .51237 m .65925 .51347 L .65876 .51218 L F
.824 .532 0 r
.65866 .51195 m .65878 .51236 L .65877 .51226 L F
.65866 .51195 m .65879 .51231 L .65876 .51214 L F
.65866 .51195 m .65891 .51247 L .65868 .5114 L F
.123 .385 .84 r
.66091 .51466 m .66072 .51412 L .66039 .51204 L F
.66072 .51412 m .66037 .51202 L .66039 .51204 L F
0 0 .259 r
.66182 .51618 m .66091 .51466 L .66039 .51204 L F
0 0 .368 r
.66248 .51784 m .66193 .51679 L .66091 .51466 L F
.66248 .51784 m .66102 .51488 L .6612 .5168 L F
.66102 .51488 m .66091 .51466 L .6612 .5168 L F
.945 .668 .483 r
.6612 .5168 m .66262 .52061 L .66248 .51784 L F
.911 .663 .551 r
.6609 .51942 m .66262 .52061 L .6612 .5168 L F
0 0 .214 r
.66131 .51796 m .6612 .5168 L .66182 .51618 L F
.6609 .51942 m .6612 .5168 L .66131 .51796 L F
0 0 .259 r
.66182 .51618 m .6612 .5168 L .66091 .51466 L F
.638 .529 .714 r
.52838 .76713 m .52627 .76969 L .52742 .76889 L F
.575 .365 .559 r
.52627 .76969 m .52849 .77178 L .52617 .77219 L F
.624 .359 .497 r
.52863 .76969 m .52849 .77178 L .52627 .76969 L F
.56 .73 .954 r
.64876 .5467 m .65111 .54634 L .64984 .54506 L F
.706 .946 .654 r
.64984 .54506 m .64742 .54767 L .64876 .5467 L F
.56 .73 .954 r
.64876 .5467 m .65111 .54634 L .64984 .54506 L F
.741 .75 .86 r
.35748 .71905 m .35821 .72092 L .36108 .71909 L F
.794 .68 .738 r
.53591 .80284 m .53792 .80024 L .53582 .80034 L F
.841 .71 .719 r
.60698 .74167 m .60884 .73897 L .60586 .73858 L F
.276 .714 .964 r
.3125 .59128 m .31452 .59125 L .31608 .59201 L F
.383 .761 .991 r
.31648 .59099 m .31608 .59201 L .31452 .59125 L F
.31648 .59099 m .31815 .59185 L .31608 .59201 L F
.216 0 .176 r
.30946 .63239 m .31208 .62995 L .3103 .63076 L F
.933 .582 .335 r
.59823 .71504 m .5991 .71406 L .59741 .71343 L F
.59823 .71504 m .59974 .71599 L .5991 .71406 L F
.758 .59 .668 r
.67639 .51861 m .68108 .51676 L .67725 .51622 L F
.67639 .51861 m .68041 .5187 L .68108 .51676 L F
.619 .439 .617 r
.68108 .51676 m .68041 .5187 L .68261 .51607 L F
.48 .265 .51 r
.36373 .66392 m .36579 .66343 L .36609 .66099 L F
.438 .234 .505 r
.36821 .6582 m .36609 .66099 L .36818 .66053 L F
.445 .211 .464 r
.36579 .66343 m .36818 .66053 L .36609 .66099 L F
.388 .78 .988 r
.4298 .64965 m .43196 .64943 L .43333 .65011 L F
.451 .796 .998 r
.43196 .64943 m .43552 .64989 L .43333 .65011 L F
.596 .435 .634 r
.58675 .70966 m .58597 .71116 L .58804 .70841 L F
.574 .715 .938 r
.74682 .61318 m .74785 .61472 L .75003 .61427 L F
.392 .058 .275 r
.31905 .62174 m .32138 .6212 L .32207 .61919 L F
.318 0 .244 r
.32207 .61919 m .32321 .62046 L .32387 .61853 L F
.32207 .61919 m .32138 .6212 L .32321 .62046 L F
.21 0 0 r
.58667 .5681 m .58311 .57015 L .58517 .57001 L F
.158 .53 .921 r
.58667 .5681 m .58707 .567 L .58719 .56742 L F
.706 .879 .485 r
.58517 .57001 m .58707 .567 L .58667 .5681 L F
.814 .348 .117 r
.58667 .68962 m .5854 .69012 L .58617 .68908 L F
.58667 .68962 m .58687 .69056 L .5854 .69012 L F
.723 .989 .849 r
.58667 .68962 m .58783 .68773 L .58949 .68643 L F
.58667 .68962 m .58617 .68908 L .58783 .68773 L F
.609 .653 .868 r
.67106 .49172 m .67204 .49386 L .67396 .49212 L F
.56 .055 .011 r
.52114 .81105 m .52183 .81261 L .5198 .81271 L F
.52114 .81105 m .52347 .81151 L .52183 .81261 L F
.5 .127 .263 r
.47821 .78828 m .47743 .78946 L .475 .78969 L F
.47821 .78828 m .47743 .78946 L .475 .78969 L F
.991 .84 .593 r
.47751 .78623 m .47821 .78828 L .47965 .78901 L F
.47751 .78623 m .47743 .78946 L .47821 .78828 L F
.354 0 .173 r
.47821 .78828 m .47743 .78946 L .47965 .78901 L F
.099 .064 .526 r
.56827 .77794 m .56818 .77397 L .56917 .77454 L F
.418 .041 .214 r
.42669 .69071 m .43016 .68811 L .42734 .6894 L F
.42669 .69071 m .4289 .69038 L .43016 .68811 L F
.367 0 .107 r
.43016 .68811 m .43185 .68853 L .4324 .68772 L F
.452 .107 .289 r
.4289 .69038 m .43185 .68853 L .43016 .68811 L F
.538 .282 .476 r
.4508 .68007 m .45325 .67766 L .45089 .67776 L F
.834 .845 .855 r
.69818 .49843 m .70199 .49753 L .70046 .49576 L F
.667 .155 .014 r
.70409 .49661 m .70046 .49576 L .70199 .49753 L F
.759 .417 .405 r
.48492 .80278 m .48344 .80482 L .48134 .80231 L F
.718 .495 .587 r
.48492 .80278 m .48662 .8059 L .48344 .80482 L F
.675 .409 .512 r
.57835 .6818 m .57672 .68395 L .57649 .68048 L F
.79 .292 0 r
.55599 .7326 m .55746 .73324 L .55542 .73067 L F
.748 .4 .394 r
.55542 .73067 m .55746 .73324 L .55949 .73306 L F
.077 .608 .867 r
.3085 .60204 m .30781 .60161 L .3058 .60136 L F
.3085 .60204 m .30933 .60213 L .30781 .60161 L F
.509 .207 .389 r
.56273 .68815 m .56555 .68622 L .56344 .68663 L F
.571 .456 .683 r
.45616 .67499 m .45875 .67512 L .45786 .67145 L F
.687 .57 .718 r
.45636 .67733 m .45875 .67512 L .45616 .67499 L F
.612 .847 .988 r
.2823 .63679 m .27906 .63673 L .28102 .63591 L F
.403 .628 .945 r
.28309 .63536 m .2823 .63679 L .28102 .63591 L F
.28309 .63536 m .28455 .63711 L .2823 .63679 L F
.924 .927 .793 r
.60863 .52181 m .60966 .518 L .61075 .51892 L F
.917 .892 .791 r
.61075 .51892 m .60966 .518 L .61161 .51489 L F
.48 .429 .723 r
.36876 .7003 m .36998 .69656 L .36803 .69702 L F
.36876 .7003 m .37036 .69986 L .36998 .69656 L F
.473 .403 .698 r
.36876 .7003 m .37108 .70211 L .37036 .69986 L F
.011 .585 .751 r
.44346 .64821 m .44683 .6484 L .44468 .64902 L F
0 .416 .799 r
.55766 .71827 m .5538 .71652 L .55542 .71606 L F
.586 .189 .258 r
.34599 .71712 m .34523 .71881 L .34267 .71846 L F
.623 .366 .507 r
.34267 .71846 m .34468 .72085 L .34523 .71881 L F
.953 .849 .425 r
.34521 .7176 m .34489 .71958 L .34523 .71881 L F
.34489 .71958 m .34468 .72085 L .34523 .71881 L F
.586 .189 .258 r
.3465 .71692 m .34523 .71881 L .34599 .71712 L F
.725 .509 .598 r
.34147 .71589 m .34642 .71654 L .34607 .71264 L F
.1 .052 .51 r
.34607 .71264 m .34642 .71654 L .34704 .71561 L F
0 .158 .687 r
.34147 .71589 m .34334 .71768 L .34642 .71654 L F
.981 .898 .56 r
.34521 .7176 m .3465 .71692 L .34704 .71561 L F
.34521 .7176 m .34523 .71881 L .3465 .71692 L F
.725 .974 .925 r
.58486 .72201 m .58675 .71833 L .58538 .71963 L F
.303 0 .076 r
.47084 .75527 m .46967 .75698 L .4727 .75538 L F
.792 .51 .51 r
.58191 .57446 m .58261 .57719 L .58005 .57667 L F
.359 .247 .587 r
.58411 .5761 m .58261 .57719 L .58191 .57446 L F
.206 0 .1 r
.49507 .74734 m .49429 .74946 L .49448 .74795 L F
0 0 0 r
.49758 .74577 m .49574 .74666 L .49612 .74626 L F
.4965 .74585 m .49612 .74626 L .49507 .74734 L F
.904 .656 .149 r
.49448 .74795 m .4948 .75052 L .49429 .74946 L F
0 0 0 r
.49612 .74626 m .49429 .74946 L .49507 .74734 L F
.93 .971 .734 r
.49437 .74732 m .49429 .74946 L .49612 .74626 L F
0 0 0 r
.49574 .74666 m .49437 .74732 L .49612 .74626 L F
.49749 .74482 m .49612 .74626 L .4965 .74585 L F
.905 .866 .791 r
.60324 .52669 m .60341 .52962 L .6014 .52928 L F
.60324 .52669 m .60441 .52762 L .60341 .52962 L F
.927 .749 .641 r
.6014 .52928 m .60341 .52962 L .60247 .53288 L F
.502 .469 .753 r
.36223 .6834 m .36489 .68586 L .36434 .68277 L F
.568 .314 .491 r
.44533 .69152 m .44723 .69321 L .44537 .69312 L F
.649 .288 .345 r
.44798 .69209 m .44723 .69321 L .44533 .69152 L F
.659 .403 .521 r
.47833 .68503 m .4765 .68311 L .47823 .6831 L F
.47833 .68503 m .47477 .68577 L .4765 .68311 L F
.621 .798 .967 r
.76384 .61074 m .7617 .61156 L .76056 .61026 L F
.389 .748 .992 r
.26402 .65234 m .26534 .65325 L .26762 .653 L F
.415 .039 .213 r
.47775 .75187 m .48136 .74913 L .47832 .75055 L F
.47775 .75187 m .47988 .75153 L .48136 .74913 L F
.272 0 .128 r
.48136 .74913 m .48212 .75086 L .48386 .74838 L F
.48136 .74913 m .47988 .75153 L .48212 .75086 L F
.489 .158 .331 r
.43522 .69695 m .43416 .69942 L .43189 .69962 L F
.207 0 .191 r
.43591 .69856 m .43522 .69695 L .43728 .69673 L F
.43591 .69856 m .43416 .69942 L .43522 .69695 L F
.635 .428 .584 r
.55849 .68894 m .56055 .6911 L .5604 .689 L F
.433 .229 .501 r
.5604 .689 m .56055 .6911 L .56273 .68815 L F
.224 0 .048 r
.69566 .52393 m .69335 .52472 L .69267 .52591 L F
.08 .072 .547 r
.52975 .76373 m .52966 .76538 L .52835 .76308 L F
.144 .097 .541 r
.52966 .76538 m .52838 .76713 L .52837 .76518 L F
.135 0 0 r
.52836 .76543 m .53055 .76552 L .52966 .76538 L F
.688 .571 .718 r
.53337 .76626 m .53071 .76664 L .53285 .76373 L F
0 0 0 r
.53285 .76373 m .53071 .76664 L .53185 .76558 L F
.392 .636 .953 r
.53185 .76558 m .53071 .76664 L .52966 .76538 L F
.135 0 0 r
.53055 .76552 m .53185 .76558 L .52966 .76538 L F
.144 .097 .541 r
.52966 .76538 m .52837 .76518 L .52835 .76308 L F
.982 .855 .474 r
.57316 .75737 m .5742 .75569 L .57337 .75492 L F
.57316 .75737 m .57372 .75872 L .5742 .75569 L F
0 0 0 r
.5252 .73718 m .5247 .73607 L .52679 .73644 L F
.5252 .73718 m .52377 .7382 L .5247 .73607 L F
.561 .409 .631 r
.76535 .60191 m .76776 .60137 L .76731 .59937 L F
.602 .458 .659 r
.76535 .60191 m .76834 .60469 L .76776 .60137 L F
.76535 .60191 m .7659 .60523 L .76834 .60469 L F
.907 .88 .797 r
.60863 .52181 m .60555 .52386 L .60775 .52098 L F
.60863 .52181 m .60668 .52484 L .60555 .52386 L F
.924 .927 .793 r
.60863 .52181 m .60775 .52098 L .60966 .518 L F
.714 .881 .958 r
.48097 .7939 m .48283 .79526 L .48444 .79401 L F
.337 .346 .723 r
.35941 .7102 m .36006 .71183 L .35902 .70856 L F
.042 0 0 r
.5082 .81537 m .50977 .81437 L .51198 .81382 L F
.586 .94 .923 r
.75314 .59041 m .75693 .58929 L .75607 .58859 L F
.67 .92 .975 r
.75607 .58859 m .75693 .58929 L .75903 .58817 L F
.782 .622 .681 r
.65315 .52482 m .6498 .52694 L .65229 .52367 L F
.65315 .52482 m .65308 .52743 L .6498 .52694 L F
.562 .555 .803 r
.65457 .52363 m .65315 .52482 L .65229 .52367 L F
.65457 .52363 m .65308 .52743 L .65315 .52482 L F
.616 .806 .973 r
.43976 .65948 m .44399 .66055 L .44214 .65904 L F
.626 .822 .976 r
.44214 .65904 m .44399 .66055 L .44634 .6599 L F
.525 .397 .648 r
.36373 .66392 m .36604 .66584 L .36579 .66343 L F
.499 .398 .671 r
.36373 .66392 m .36409 .66627 L .36604 .66584 L F
.607 .354 .507 r
.52839 .74159 m .52813 .74397 L .52589 .7418 L F
.52839 .74159 m .52813 .74397 L .52589 .7418 L F
.648 .7 .884 r
.69031 .48746 m .68947 .48927 L .68804 .48789 L F
.69031 .48746 m .69141 .48947 L .68947 .48927 L F
.435 .231 .503 r
.55845 .7886 m .55865 .78627 L .5606 .78572 L F
.315 .133 .468 r
.56033 .78553 m .55865 .78627 L .55845 .7886 L F
.56041 .78539 m .56029 .78545 L .56033 .78553 L F
.56029 .78545 m .55865 .78627 L .56033 .78553 L F
.826 .35 0 r
.56022 .78531 m .56003 .78439 L .5606 .78572 L F
.55783 .78272 m .55964 .7841 L .56022 .78531 L F
.55964 .7841 m .56003 .78439 L .56022 .78531 L F
.683 .782 .925 r
.68739 .52667 m .68574 .52796 L .68401 .52622 L F
0 0 0 r
.68739 .52667 m .68543 .52823 L .68574 .52796 L F
.521 .671 .931 r
.69695 .50282 m .69851 .50099 L .6962 .50163 L F
.69695 .50282 m .69928 .50267 L .69851 .50099 L F
.693 .334 .362 r
.60122 .57493 m .60236 .57459 L .6013 .57657 L F
.533 .158 .277 r
.60236 .57459 m .60489 .57581 L .6013 .57657 L F
.54 .128 .208 r
.60471 .57454 m .60489 .57581 L .60236 .57459 L F
.406 0 0 r
.66121 .48165 m .66548 .48208 L .66616 .48103 L F
0 0 0 r
.66616 .48103 m .66731 .47991 L .66624 .48027 L F
.445 .058 .21 r
.49055 .74429 m .49292 .74403 L .49402 .74189 L F
.381 0 .178 r
.49402 .74189 m .49523 .7436 L .49593 .74102 L F
.49402 .74189 m .49292 .74403 L .49523 .7436 L F
.597 .397 .582 r
.5561 .69149 m .55858 .69146 L .55849 .68894 L F
.635 .428 .584 r
.55849 .68894 m .55858 .69146 L .56055 .6911 L F
.836 .372 0 r
.66526 .51045 m .66413 .5098 L .66285 .50761 L F
.954 .706 .523 r
.66526 .51045 m .66363 .51193 L .66413 .5098 L F
.66526 .51045 m .66538 .51286 L .66363 .51193 L F
.677 .393 .483 r
.61582 .56842 m .61266 .57099 L .61256 .56944 L F
.61582 .56842 m .6151 .57101 L .61266 .57099 L F
.611 .327 .461 r
.61826 .5707 m .61582 .56842 L .61803 .56839 L F
.61826 .5707 m .6151 .57101 L .61582 .56842 L F
0 0 0 r
.56743 .76566 m .56618 .76686 L .56849 .76395 L F
.725 .245 .104 r
.56618 .7685 m .56846 .76892 L .56618 .76686 L F
.56619 .76937 m .56722 .76917 L .56618 .7685 L F
.56722 .76917 m .56846 .76892 L .56618 .7685 L F
.693 .448 .549 r
.56491 .77135 m .56846 .76892 L .56619 .76937 L F
.56491 .77135 m .56978 .77215 L .56846 .76892 L F
.622 .479 .666 r
.56733 .76924 m .56849 .77139 L .56491 .77135 L F
.56834 .76836 m .56842 .76994 L .56733 .76924 L F
.56842 .76994 m .56849 .77139 L .56733 .76924 L F
.725 .245 .104 r
.56619 .76937 m .56618 .76686 L .56743 .76566 L F
.213 .527 .92 r
.45988 .78716 m .46361 .78954 L .46298 .78879 L F
0 .261 .758 r
.46361 .78954 m .46551 .79046 L .46298 .78879 L F
.46361 .78954 m .46597 .79126 L .46551 .79046 L F
.654 .392 .51 r
.48385 .7751 m .48354 .77594 L .48053 .7759 L F
.567 .449 .678 r
.48629 .77496 m .48354 .77594 L .48385 .7751 L F
.92 .692 .576 r
.60116 .72211 m .60049 .72454 L .60255 .725 L F
.893 .664 .585 r
.60016 .72675 m .60255 .725 L .60049 .72454 L F
.60016 .72675 m .60254 .72797 L .60255 .725 L F
.609 .451 .643 r
.53862 .74976 m .54078 .74683 L .53861 .74734 L F
.558 .337 .536 r
.49883 .73946 m .50127 .73923 L .50156 .73597 L F
.818 .647 .671 r
.50127 .73923 m .50284 .73581 L .50156 .73597 L F
.599 .787 .971 r
.76754 .6115 m .76384 .61074 L .76638 .61063 L F
.775 .669 .746 r
.76612 .60762 m .76754 .6115 L .76948 .60802 L F
.644 .882 .985 r
.76968 .6105 m .76754 .6115 L .76638 .61063 L F
.473 .187 .397 r
.35442 .61053 m .35737 .60751 L .3575 .60841 L F
.563 .443 .674 r
.35908 .60566 m .35925 .60743 L .35737 .60751 L F
.605 .413 .595 r
.35925 .60743 m .3575 .60841 L .35737 .60751 L F
0 0 .144 r
.78451 .60256 m .78337 .60571 L .78398 .60349 L F
0 .214 .711 r
.31837 .60359 m .31915 .60368 L .31747 .60314 L F
.31837 .60359 m .31977 .60455 L .31915 .60368 L F
.632 .693 .888 r
.69366 .48876 m .69141 .48947 L .69031 .48746 L F
.223 0 0 r
.25057 .59033 m .25264 .58985 L .25428 .58824 L F
.33 0 .063 r
.25264 .58985 m .25632 .58755 L .25428 .58824 L F
.681 .823 .951 r
.656 .54329 m .65691 .54502 L .65937 .5434 L F
.642 .475 .642 r
.72381 .5992 m .7268 .60003 L .7264 .59661 L F
.539 .401 .641 r
.7264 .59661 m .72917 .59835 L .72944 .59592 L F
.7264 .59661 m .7268 .60003 L .72917 .59835 L F
.647 .509 .681 r
.72381 .5992 m .72718 .60213 L .7268 .60003 L F
.72381 .5992 m .72496 .60284 L .72718 .60213 L F
.426 .479 .811 r
.45874 .78386 m .45988 .78716 L .46147 .78524 L F
.498 .585 .873 r
.45988 .78716 m .46298 .78879 L .46147 .78524 L F
0 .224 .742 r
.36761 .70777 m .36827 .70781 L .36794 .70885 L F
.57 .899 .983 r
.36794 .70885 m .36827 .70781 L .37012 .70808 L F
.509 .282 .504 r
.36794 .70885 m .3698 .71035 L .37012 .70808 L F
.501 .858 .99 r
.29412 .63703 m .294 .63587 L .29601 .63643 L F
.29412 .63703 m .29192 .6364 L .294 .63587 L F
.431 .678 .967 r
.34893 .5977 m .34588 .59642 L .34778 .59645 L F
.461 .684 .962 r
.34969 .59604 m .34893 .5977 L .34778 .59645 L F
.34969 .59604 m .35189 .59808 L .34893 .5977 L F
.476 .838 .993 r
.43552 .64989 m .43776 .64942 L .43909 .65001 L F
.7 .984 .842 r
.44133 .64822 m .43909 .65001 L .43989 .64863 L F
.595 .886 .991 r
.43909 .65001 m .43776 .64942 L .43989 .64863 L F
.806 .656 .696 r
.50303 .75615 m .50334 .76027 L .49995 .75799 L F
.61 .565 .779 r
.50313 .76086 m .49995 .75799 L .50334 .76027 L F
.54 .454 .707 r
.50539 .75806 m .50334 .76027 L .50303 .75615 L F
.569 .372 .575 r
.50539 .75806 m .50313 .76086 L .50334 .76027 L F
.863 .843 .823 r
.50313 .76086 m .50539 .75806 L .50334 .76027 L F
0 .506 .722 r
.44683 .6484 m .44907 .64871 L .45049 .64895 L F
.438 .86 .948 r
.45049 .64895 m .45121 .64813 L .45253 .64872 L F
.45049 .64895 m .44907 .64871 L .45121 .64813 L F
.63 .683 .881 r
.68914 .49365 m .69249 .49495 L .69143 .49357 L F
.525 .696 .947 r
.69249 .49495 m .69413 .49317 L .69143 .49357 L F
.69249 .49495 m .69499 .49503 L .69413 .49317 L F
.442 .791 .998 r
.6688 .50468 m .67109 .50454 L .66996 .50377 L F
.604 .461 .66 r
.67109 .50454 m .66983 .5071 L .6688 .50468 L F
.117 0 0 r
.68519 .54078 m .68422 .54099 L .68184 .54101 L F
.004 0 0 r
.68755 .54061 m .68422 .54099 L .68519 .54078 L F
.61 .938 .952 r
.27345 .65362 m .27698 .65284 L .27547 .65321 L F
0 0 0 r
.27698 .65284 m .27707 .65286 L .27547 .65321 L F
.27698 .65284 m .27937 .65263 L .27707 .65286 L F
.52 .074 .13 r
.56849 .76395 m .57235 .76472 L .56743 .76566 L F
.448 .283 .563 r
.36821 .6582 m .37008 .65975 L .37011 .65764 L F
.36821 .6582 m .36818 .66053 L .37008 .65975 L F
.838 .94 .891 r
.76421 .62243 m .76627 .61892 L .76311 .62135 L F
.76421 .62243 m .76679 .62018 L .76627 .61892 L F
.506 .018 .031 r
.40356 .65006 m .40546 .65105 L .40706 .64968 L F
.349 0 0 r
.40546 .65105 m .40922 .6498 L .40706 .64968 L F
.828 .593 .584 r
.55651 .71291 m .55962 .7111 L .55613 .71082 L F
.55651 .71291 m .55967 .71354 L .55962 .7111 L F
.732 .515 .598 r
.55962 .7111 m .55967 .71354 L .56305 .7134 L F
.775 .669 .746 r
.7662 .60763 m .76948 .60802 L .76856 .60777 L F
.986 .708 .364 r
.76948 .60802 m .76873 .60981 L .76856 .60777 L F
.76948 .60802 m .76968 .6105 L .76873 .60981 L F
.834 .927 .894 r
.76873 .60981 m .77014 .60787 L .76856 .60777 L F
.77014 .60787 m .77107 .60659 L .76856 .60777 L F
.775 .669 .746 r
.76612 .60762 m .7662 .60763 L .76856 .60777 L F
.621 .931 .967 r
.77107 .60659 m .76948 .60802 L .77197 .60689 L F
.77107 .60659 m .76948 .60802 L .77197 .60689 L F
.578 .915 .97 r
.77102 .61879 m .77192 .61917 L .77405 .61826 L F
.03 .602 .723 r
.28509 .58615 m .287 .58609 L .2886 .58609 L F
.362 0 0 r
.287 .58609 m .29039 .58604 L .2886 .58609 L F
.585 .606 .839 r
.26968 .63546 m .2676 .63597 L .26616 .63292 L F
0 0 0 r
.27937 .65263 m .28266 .65168 L .28109 .65162 L F
.258 .766 .858 r
.28266 .65168 m .28325 .65127 L .28109 .65162 L F
.28266 .65168 m .28473 .65132 L .28325 .65127 L F
.712 .447 .523 r
.52418 .72516 m .52799 .72723 L .52797 .72507 L F
.662 .438 .569 r
.52799 .72723 m .53062 .72477 L .52797 .72507 L F
.208 .733 .758 r
.47398 .78351 m .47396 .78342 L .47493 .78221 L F
0 0 .307 r
.47483 .78323 m .47398 .78351 L .47493 .78221 L F
.208 .733 .758 r
.47398 .78351 m .4759 .78311 L .47455 .78332 L F
0 0 .307 r
.47467 .78495 m .47398 .78351 L .47483 .78323 L F
.208 .733 .758 r
.47398 .78351 m .47455 .78332 L .47396 .78342 L F
.527 .639 .904 r
.45311 .66095 m .45252 .65725 L .45166 .65765 L F
.45311 .66095 m .45501 .66039 L .45252 .65725 L F
.594 .531 .753 r
.45311 .66095 m .4562 .66373 L .45501 .66039 L F
.61 .574 .789 r
.63651 .49093 m .63791 .48718 L .63576 .48768 L F
.63651 .49093 m .63892 .49053 L .63791 .48718 L F
.219 0 0 r
.41974 .70599 m .41901 .70501 L .42106 .70456 L F
.41974 .70599 m .41752 .70654 L .41901 .70501 L F
.774 .827 .894 r
.3556 .70858 m .35902 .70856 L .3571 .70714 L F
.691 .761 .905 r
.3571 .70714 m .35902 .70856 L .35848 .70785 L F
.432 .224 .495 r
.62357 .52447 m .62343 .52662 L .62568 .52381 L F
.305 .793 .886 r
.65662 .51561 m .65314 .51592 L .65388 .51526 L F
.65662 .51561 m .65545 .51548 L .65314 .51592 L F
.786 .293 .037 r
.65655 .51642 m .65545 .51548 L .65662 .51561 L F
.148 .671 .881 r
.68011 .49288 m .67926 .49244 L .6767 .49231 L F
.779 .997 .86 r
.68069 .49096 m .68011 .49288 L .68189 .49101 L F
.68069 .49096 m .67926 .49244 L .68011 .49288 L F
0 0 .172 r
.57243 .76337 m .57281 .76567 L .57284 .76662 L F
.931 .739 .258 r
.57217 .7676 m .57284 .76662 L .57281 .76567 L F
.57217 .7676 m .57276 .76952 L .57284 .76662 L F
.055 0 .257 r
.58804 .70841 m .58999 .70684 L .58988 .7051 L F
.37 .349 .705 r
.59022 .71038 m .58999 .70684 L .58804 .70841 L F
.511 .912 .832 r
.64877 .53747 m .64965 .53669 L .65226 .5361 L F
.722 .989 .858 r
.65226 .5361 m .65348 .53427 L .65447 .53513 L F
.65226 .5361 m .64965 .53669 L .65348 .53427 L F
.471 .191 .406 r
.53358 .75252 m .53621 .75204 L .53637 .75019 L F
.597 .296 .429 r
.53621 .75204 m .5385 .75207 L .53637 .75019 L F
.524 .31 .53 r
.53637 .75019 m .5385 .75207 L .53862 .74976 L F
.989 .747 .47 r
.65507 .52151 m .65586 .52432 L .65457 .52363 L F
.963 .631 .305 r
.65457 .52363 m .65586 .52432 L .65505 .52419 L F
0 .122 .665 r
.51198 .78325 m .51074 .78543 L .51098 .78331 L F
.51198 .78325 m .51244 .78254 L .51074 .78543 L F
.149 0 .346 r
.51244 .78254 m .51127 .78316 L .51074 .78543 L F
.51127 .78316 m .51098 .78331 L .51092 .78387 L F
.51127 .78316 m .51092 .78387 L .51074 .78543 L F
.929 .882 .768 r
.51243 .78083 m .51395 .78067 L .51198 .78325 L F
.51262 .77983 m .51286 .77998 L .51243 .78083 L F
.51286 .77998 m .51395 .78067 L .51243 .78083 L F
.74 .547 .632 r
.51395 .78067 m .51398 .78382 L .51198 .78325 L F
.651 .497 .662 r
.51656 .77998 m .51398 .78382 L .51395 .78067 L F
.593 .395 .583 r
.51242 .7589 m .51238 .76059 L .51457 .75833 L F
.663 .304 .352 r
.50333 .78923 m .50226 .78817 L .50003 .78818 L F
.724 .663 .789 r
.50003 .78818 m .50226 .78817 L .50025 .78622 L F
.762 .654 .743 r
.49439 .77219 m .49605 .7755 L .49205 .77502 L F
.876 .874 .831 r
.60668 .52484 m .60324 .52669 L .60555 .52386 L F
.60668 .52484 m .60441 .52762 L .60324 .52669 L F
.763 .668 .757 r
.50268 .81137 m .50442 .81379 L .50114 .81227 L F
.829 .521 .468 r
.50114 .81227 m .50442 .81379 L .50294 .81466 L F
.918 .961 .642 r
.50501 .81153 m .50442 .81379 L .50268 .81137 L F
.655 .241 .246 r
.50294 .81466 m .50442 .81379 L .50623 .81532 L F
.828 .51 .45 r
.67338 .53554 m .67158 .53715 L .67221 .53486 L F
.86 .871 .846 r
.67158 .53715 m .67197 .53592 L .67221 .53486 L F
.951 .713 .543 r
.67251 .53354 m .67338 .53554 L .67221 .53486 L F
.86 .871 .846 r
.67197 .53592 m .67281 .53329 L .67221 .53486 L F
.951 .713 .543 r
.67198 .53234 m .67251 .53354 L .67221 .53486 L F
.828 .51 .45 r
.67338 .53554 m .67533 .53833 L .67158 .53715 L F
.793 .512 .511 r
.67644 .53793 m .67533 .53833 L .67338 .53554 L F
.44 .092 .276 r
.44243 .69382 m .4417 .69614 L .43949 .69649 L F
.414 .067 .266 r
.44388 .6957 m .44243 .69382 L .44537 .69312 L F
.44388 .6957 m .4417 .69614 L .44243 .69382 L F
.662 .329 .398 r
.64948 .51043 m .64611 .51229 L .64641 .51063 L F
.64948 .51043 m .64875 .51257 L .64611 .51229 L F
.672 .339 .401 r
.65149 .51243 m .64875 .51257 L .64948 .51043 L F
.483 .231 .456 r
.63894 .51 m .63999 .50993 L .64008 .5078 L F
.536 .341 .564 r
.63999 .50993 m .64215 .50705 L .64008 .5078 L F
.431 .044 .202 r
.43003 .70058 m .42922 .70179 L .4272 .70197 L F
.108 0 .007 r
.43189 .69962 m .42922 .70179 L .43003 .70058 L F
.637 .899 .985 r
.47048 .79808 m .47409 .79783 L .47372 .79907 L F
.557 .172 .267 r
.47409 .79783 m .47586 .80087 L .47372 .79907 L F
.47409 .79783 m .47628 .79817 L .47586 .80087 L F
.532 .115 .196 r
.46448 .68578 m .46347 .68757 L .46118 .68626 L F
.663 .312 .367 r
.46687 .68575 m .46347 .68757 L .46448 .68578 L F
.71 .951 .668 r
.36364 .71636 m .36108 .71909 L .36176 .71792 L F
.601 .393 .571 r
.36364 .71636 m .36348 .71919 L .36108 .71909 L F
.927 .684 .549 r
.36176 .71792 m .36348 .71919 L .36364 .71636 L F
.38 .812 .962 r
.28672 .651 m .28844 .65142 L .29052 .65104 L F
.465 .813 .998 r
.32173 .59221 m .31815 .59185 L .32031 .5916 L F
.236 .714 .936 r
.32392 .59211 m .32173 .59221 L .32031 .5916 L F
.705 .601 .737 r
.50202 .75297 m .50303 .75615 L .49982 .75566 L F
.806 .656 .696 r
.50303 .75615 m .49995 .75799 L .49982 .75566 L F
.545 .491 .746 r
.50261 .75272 m .50303 .75615 L .50202 .75297 L F
.50261 .75272 m .50505 .75576 L .50303 .75615 L F
.54 .454 .707 r
.50539 .75806 m .50303 .75615 L .50505 .75576 L F
.135 .648 .895 r
.32758 .59269 m .32954 .59283 L .33091 .59332 L F
.285 .745 .952 r
.32954 .59283 m .33305 .59324 L .33091 .59332 L F
0 .023 .556 r
.46781 .79421 m .46831 .7977 L .46913 .79669 L F
.31 .598 .947 r
.46831 .7977 m .47048 .79808 L .46913 .79669 L F
.214 .739 .791 r
.39972 .71251 m .39623 .71303 L .39762 .71284 L F
.503 .12 .246 r
.43456 .68742 m .43788 .68529 L .43509 .68646 L F
.43456 .68742 m .43685 .6874 L .43788 .68529 L F
.454 .103 .28 r
.43685 .6874 m .43981 .68562 L .43788 .68529 L F
.804 .701 .751 r
.3748 .71857 m .3759 .72198 L .37704 .72009 L F
.555 .879 .607 r
.58924 .69995 m .59036 .69874 L .59178 .69763 L F
.183 .322 .771 r
.58924 .69995 m .59127 .70166 L .59036 .69874 L F
.128 0 0 r
.29796 .6024 m .29624 .6035 L .29401 .60391 L F
.386 0 0 r
.30005 .60192 m .29624 .6035 L .29796 .6024 L F
.132 0 0 r
.58565 .68364 m .58869 .68342 L .58702 .684 L F
.58565 .68364 m .58702 .684 L .58475 .68208 L F
.417 .048 .229 r
.39225 .71468 m .39146 .71589 L .3894 .71612 L F
.222 0 .106 r
.39421 .71386 m .39146 .71589 L .39225 .71468 L F
.388 .207 .511 r
.58841 .57443 m .58949 .57616 L .58798 .57568 L F
.58841 .57443 m .58969 .57435 L .58949 .57616 L F
0 .146 .689 r
.7363 .59459 m .73698 .59527 L .73655 .59444 L F
.782 .787 .857 r
.7386 .59228 m .7363 .59459 L .73538 .59221 L F
0 .146 .689 r
.7363 .59459 m .73655 .59444 L .73538 .59221 L F
.678 .976 .826 r
.73733 .59401 m .73605 .59474 L .7363 .59459 L F
.73605 .59474 m .73409 .59586 L .7363 .59459 L F
.606 .798 .973 r
.7386 .59228 m .73733 .59401 L .7363 .59459 L F
.7386 .59228 m .73973 .59337 L .73733 .59401 L F
.516 .144 .273 r
.46118 .68626 m .46347 .68757 L .46091 .68759 L F
.614 .626 .839 r
.68261 .51607 m .68629 .5178 L .68519 .51534 L F
.735 .746 .86 r
.36293 .70617 m .36288 .70859 L .36102 .70773 L F
.839 .378 0 r
.36288 .70859 m .36289 .70983 L .36102 .70773 L F
.714 .829 .936 r
.74284 .59334 m .73973 .59337 L .74197 .59275 L F
.798 .957 .917 r
.74564 .59132 m .74284 .59334 L .74197 .59275 L F
.689 .404 .485 r
.53278 .73844 m .53565 .73644 L .53406 .73536 L F
.53278 .73844 m .53645 .73925 L .53565 .73644 L F
0 0 .499 r
.53565 .73644 m .53645 .73925 L .53726 .73736 L F
.842 .461 .331 r
.67961 .54052 m .67849 .54091 L .67644 .53793 L F
.022 0 0 r
.68093 .5407 m .67961 .54052 L .68184 .54101 L F
.68093 .5407 m .67849 .54091 L .67961 .54052 L F
.848 .998 .785 r
.78677 .60779 m .78539 .6084 L .78373 .60946 L F
0 0 0 r
.78539 .6084 m .78375 .61014 L .78373 .60946 L F
.50359 .74981 m .50599 .74939 L .5058 .74919 L F
.067 0 0 r
.5058 .74919 m .50599 .74939 L .50886 .74903 L F
.561 .856 .997 r
.57936 .73443 m .58042 .73317 L .5781 .73327 L F
.57936 .73443 m .58166 .73381 L .58042 .73317 L F
.185 0 .078 r
.51079 .80547 m .50817 .80795 L .50949 .80771 L F
.625 .295 .391 r
.51312 .80824 m .51079 .80547 L .50949 .80771 L F
.51312 .80824 m .5131 .80601 L .51079 .80547 L F
.898 .652 .558 r
.65388 .51526 m .65314 .51592 L .65307 .5133 L F
.366 .191 .508 r
.64313 .49955 m .64287 .50143 L .64218 .49928 L F
.64313 .49955 m .6434 .50226 L .64287 .50143 L F
.917 .534 .268 r
.65307 .5133 m .65207 .51409 L .65149 .51243 L F
.561 .483 .725 r
.68629 .5178 m .68718 .51508 L .68519 .51534 L F
.68629 .5178 m .68853 .51841 L .68718 .51508 L F
.874 .705 .669 r
.67297 .5043 m .67437 .50734 L .67501 .5051 L F
0 0 .038 r
.58988 .7051 m .59127 .70166 L .5924 .70261 L F
.58988 .7051 m .59024 .70488 L .59127 .70166 L F
.169 .051 .465 r
.58999 .70684 m .59024 .70488 L .58988 .7051 L F
.711 .187 0 r
.66331 .52717 m .66401 .52663 L .66029 .52544 L F
.814 .809 .846 r
.6646 .52904 m .66702 .52794 L .66603 .52773 L F
.684 .603 .76 r
.66401 .52663 m .6646 .52904 L .66752 .52635 L F
.66401 .52663 m .6646 .52904 L .66752 .52635 L F
.132 .224 .694 r
.66599 .52865 m .6646 .52904 L .66401 .52663 L F
.839 .429 .264 r
.6655 .52791 m .66724 .52869 L .66653 .52946 L F
.132 .224 .694 r
.6661 .52876 m .66607 .52877 L .66599 .52865 L F
.66607 .52877 m .6646 .52904 L .66599 .52865 L F
.711 .187 0 r
.6656 .52869 m .66029 .52544 L .66007 .5279 L F
.6661 .52876 m .66547 .5284 L .6656 .52869 L F
.66547 .5284 m .66029 .52544 L .6656 .52869 L F
.676 .309 0 r
.66467 .52678 m .66511 .52763 L .66552 .52851 L F
.711 .187 0 r
.66599 .52865 m .66485 .52749 L .66582 .5286 L F
.676 .309 0 r
.66511 .52763 m .66518 .52777 L .66539 .52822 L F
.711 .187 0 r
.66531 .52801 m .66485 .52749 L .66547 .5284 L F
.676 .309 0 r
.66511 .52763 m .66539 .52822 L .66552 .52851 L F
.909 .798 .726 r
.66498 .5305 m .66464 .52919 L .66433 .52948 L F
.66464 .52919 m .6646 .52904 L .66433 .52948 L F
.899 .774 .714 r
.66224 .53446 m .66498 .5305 L .66433 .52948 L F
.88 .783 .75 r
.66146 .53136 m .66224 .53446 L .66433 .52948 L F
0 0 0 r
.66433 .52948 m .66606 .52878 L .66363 .53014 L F
.66433 .52948 m .66363 .53014 L .66146 .53136 L F
.839 .429 .264 r
.66607 .52877 m .66653 .52946 L .66584 .52897 L F
0 0 0 r
.66606 .52878 m .6661 .52876 L .66605 .52879 L F
.66606 .52878 m .66605 .52879 L .66146 .53136 L F
.839 .429 .264 r
.66584 .52897 m .66653 .52946 L .66613 .5299 L F
.6655 .52791 m .66607 .52877 L .66584 .52897 L F
0 0 0 r
.66433 .52948 m .6646 .52904 L .6661 .52876 L F
.693 .599 .746 r
.66146 .53136 m .6661 .52876 L .66007 .5279 L F
.676 .309 0 r
.66579 .52916 m .66552 .52851 L .66613 .5299 L F
.66467 .52678 m .66552 .52851 L .66579 .52916 L F
.711 .187 0 r
.66547 .5284 m .66485 .52749 L .66331 .52717 L F
.66582 .5286 m .66531 .52801 L .66547 .5284 L F
.6661 .52876 m .66599 .52865 L .66582 .5286 L F
.839 .429 .264 r
.66518 .52777 m .6655 .52791 L .66571 .52857 L F
.66552 .52851 m .66571 .52857 L .66613 .5299 L F
.66518 .52777 m .66571 .52857 L .66552 .52851 L F
.711 .187 0 r
.66485 .52749 m .66401 .52663 L .66331 .52717 L F
.814 .809 .846 r
.66603 .52773 m .66896 .52705 L .66752 .52635 L F
.66702 .52794 m .66896 .52705 L .66603 .52773 L F
.93 .683 .543 r
.66896 .52705 m .66724 .52869 L .66752 .52635 L F
.66896 .52705 m .66883 .52937 L .66724 .52869 L F
.818 .698 .732 r
.68175 .52897 m .68279 .53224 L .68543 .52823 L F
.712 .761 .891 r
.68401 .52622 m .68543 .52823 L .68739 .52667 L F
.353 .08 .353 r
.51457 .75833 m .51696 .75569 L .51464 .75582 L F
.351 .813 .717 r
.71726 .5205 m .71567 .52132 L .71791 .52071 L F
.71726 .5205 m .71509 .52148 L .71567 .52132 L F
.543 .917 .941 r
.76575 .57959 m .76349 .58053 L .76277 .58023 L F
.518 .475 .748 r
.36723 .69468 m .36803 .69702 L .36998 .69656 L F
.635 .319 .419 r
.48354 .77594 m .48079 .77788 L .48053 .7759 L F
.527 .089 .15 r
.53217 .74258 m .52813 .74397 L .52839 .74159 L F
.53217 .74258 m .53073 .7442 L .52813 .74397 L F
.179 0 0 r
.53307 .74343 m .53217 .74258 L .53386 .74139 L F
.53307 .74343 m .53073 .7442 L .53217 .74258 L F
.547 .54 .799 r
.64265 .48358 m .64007 .48655 L .6402 .48407 L F
.64265 .48358 m .64377 .48691 L .64007 .48655 L F
.709 .637 .775 r
.77008 .593 m .7701 .58907 L .76842 .58835 L F
.281 0 0 r
.76704 .58776 m .76842 .58835 L .7701 .58907 L F
.438 .281 .569 r
.45945 .76945 m .46129 .76901 L .46127 .7666 L F
.459 .362 .658 r
.45945 .76945 m .46172 .77155 L .46129 .76901 L F
.45945 .76945 m .4595 .77244 L .46172 .77155 L F
.918 .884 .785 r
.67381 .51213 m .67649 .51097 L .67507 .50958 L F
.503 .844 .997 r
.48491 .76272 m .48418 .76399 L .48652 .76343 L F
.652 .874 .508 r
.48491 .76272 m .48254 .76591 L .48418 .76399 L F
.917 .939 .804 r
.5538 .76648 m .5534 .76872 L .55145 .76946 L F
.907 .882 .798 r
.5534 .76872 m .55084 .77216 L .55145 .76946 L F
.579 .86 .996 r
.69064 .5266 m .68739 .52667 L .69153 .52575 L F
.927 .963 .773 r
.69064 .5266 m .68845 .52866 L .68739 .52667 L F
.548 .87 .994 r
.69153 .52575 m .68739 .52667 L .68882 .52528 L F
.355 .305 .663 r
.68739 .52667 m .68896 .52729 L .68882 .52528 L F
.927 .963 .773 r
.69064 .5266 m .68868 .52995 L .68886 .52828 L F
.355 .305 .663 r
.68896 .52729 m .69017 .52777 L .68911 .52583 L F
.68896 .52729 m .68911 .52583 L .68882 .52528 L F
.927 .963 .773 r
.68886 .52828 m .68866 .53 L .68845 .52866 L F
.68868 .52995 m .68866 .53 L .68886 .52828 L F
.962 .931 .609 r
.68845 .52866 m .68866 .53 L .68731 .53121 L F
.404 .111 .351 r
.33301 .63225 m .33578 .63 L .33468 .63169 L F
.391 .137 .404 r
.33578 .63 m .33821 .62744 L .33765 .62921 L F
.405 .131 .382 r
.33765 .62921 m .33468 .63169 L .33578 .63 L F
.567 .321 .502 r
.62078 .49931 m .62061 .50138 L .6233 .49935 L F
0 0 .147 r
.62061 .50138 m .62099 .50083 L .62078 .49931 L F
.697 .209 .084 r
.62078 .49931 m .62099 .50083 L .61745 .49862 L F
.581 .424 .633 r
.623 .49637 m .6233 .49935 L .62078 .49931 L F
.62078 .49931 m .6233 .49935 L .623 .49637 L F
.906 .888 .466 r
.67639 .51861 m .67725 .51622 L .67641 .51741 L F
.97 .661 .366 r
.67641 .51741 m .67725 .51622 L .676 .51508 L F
.075 .475 .891 r
.52417 .80707 m .52197 .8063 L .52095 .80501 L F
.617 .837 .449 r
.62098 .5199 m .6199 .52157 L .62214 .51839 L F
.166 0 .142 r
.62116 .52255 m .6199 .52157 L .62098 .5199 L F
.62116 .52255 m .61936 .52356 L .6199 .52157 L F
.637 .523 .708 r
.58348 .73884 m .58358 .74208 L .58633 .74151 L F
.64 .537 .722 r
.58358 .74208 m .58428 .74335 L .58633 .74151 L F
.352 .101 .387 r
.33765 .62921 m .33821 .62744 L .33997 .62668 L F
.562 .555 .803 r
.65457 .52363 m .65578 .52714 L .65308 .52743 L F
.532 .596 .864 r
.65695 .52992 m .65308 .52743 L .65578 .52714 L F
.797 .699 .757 r
.51477 .77493 m .51913 .77432 L .51685 .77484 L F
.723 .655 .782 r
.52082 .77252 m .51913 .77432 L .51753 .77216 L F
.818 .424 .305 r
.51913 .77432 m .51881 .77694 L .51685 .77484 L F
.309 .305 .693 r
.51985 .77697 m .52114 .77721 L .51913 .77432 L F
.818 .424 .305 r
.51913 .77432 m .52114 .77721 L .51881 .77694 L F
.491 .132 .285 r
.45484 .69034 m .45321 .68871 L .45541 .68831 L F
.45484 .69034 m .45201 .69093 L .45321 .68871 L F
.312 .331 .719 r
.5561 .69149 m .55811 .69375 L .55858 .69146 L F
.5561 .69149 m .5577 .69461 L .55811 .69375 L F
.11 .662 .721 r
.40922 .6498 m .41145 .6495 L .4127 .64937 L F
.18 .713 .826 r
.41145 .6495 m .41491 .64934 L .4127 .64937 L F
.488 .64 .923 r
.50773 .73762 m .51028 .73827 L .51044 .73765 L F
.65 .093 0 r
.56439 .72041 m .56357 .72074 L .56113 .7188 L F
.711 .174 0 r
.56515 .72132 m .56357 .72074 L .56439 .72041 L F
.356 0 .057 r
.4324 .68772 m .43456 .68742 L .43509 .68646 L F
0 0 0 r
.30751 .63305 m .30788 .63387 L .30946 .63239 L F
.30751 .63305 m .30611 .63492 L .30788 .63387 L F
.617 .837 .449 r
.62098 .5199 m .62214 .51839 L .62101 .51766 L F
.848 .918 .88 r
.62351 .51491 m .62214 .51839 L .62434 .51752 L F
.62351 .51491 m .62101 .51766 L .62214 .51839 L F
.421 0 0 r
.65412 .49977 m .65317 .49903 L .65244 .49776 L F
.65412 .49977 m .65576 .50063 L .65317 .49903 L F
.309 .024 .308 r
.34433 .62114 m .34263 .62178 L .34512 .61915 L F
.435 .192 .446 r
.34694 .61835 m .34433 .62114 L .34512 .61915 L F
.351 .095 .378 r
.33301 .63225 m .33268 .63508 L .33088 .63568 L F
.357 .1 .38 r
.33453 .63435 m .33301 .63225 L .33468 .63169 L F
.33453 .63435 m .33268 .63508 L .33301 .63225 L F
.688 .874 .968 r
.76627 .61892 m .76679 .62018 L .76861 .6192 L F
.637 .523 .708 r
.58348 .73884 m .58633 .74151 L .58607 .73903 L F
.632 .749 .932 r
.68189 .49101 m .68685 .49301 L .68451 .49035 L F
.567 .703 .933 r
.68451 .49035 m .68685 .49301 L .68845 .49202 L F
.39 .112 .367 r
.34946 .61587 m .34694 .61835 L .34749 .6165 L F
.459 .411 .717 r
.36665 .69131 m .36723 .69468 L .36907 .69342 L F
.518 .475 .748 r
.36723 .69468 m .36998 .69656 L .36907 .69342 L F
.509 .036 .067 r
.53841 .76224 m .54095 .76311 L .53854 .763 L F
0 0 .501 r
.50569 .76519 m .50454 .76396 L .50365 .76215 L F
.223 .232 .658 r
.5053 .76304 m .50569 .76519 L .50365 .76215 L F
.683 .555 .703 r
.50768 .76254 m .50569 .76519 L .5053 .76304 L F
.592 .885 .991 r
.50713 .76338 m .50569 .76519 L .50727 .76308 L F
.50713 .76338 m .50727 .76308 L .50768 .76254 L F
.148 .666 .889 r
.50893 .7637 m .5071 .76345 L .50713 .76338 L F
0 0 .501 r
.50569 .76519 m .50617 .7661 L .50454 .76396 L F
.371 .15 .444 r
.50541 .76045 m .50365 .76215 L .50313 .76086 L F
.50541 .76045 m .5053 .76304 L .50365 .76215 L F
.616 .347 .487 r
.50768 .76254 m .5053 .76304 L .50541 .76045 L F
.577 .576 .816 r
.50292 .76151 m .50417 .76466 L .50713 .76338 L F
.148 .666 .889 r
.5071 .76345 m .50524 .7632 L .50713 .76338 L F
.592 .885 .991 r
.50713 .76338 m .50517 .76423 L .50569 .76519 L F
.50517 .76423 m .50417 .76466 L .50569 .76519 L F
0 0 .501 r
.50569 .76519 m .50645 .76647 L .50617 .7661 L F
.677 .634 .799 r
.63409 .4937 m .63106 .49175 L .6332 .49057 L F
.535 .507 .772 r
.63602 .49268 m .63409 .4937 L .6332 .49057 L F
.36 0 .133 r
.63103 .49597 m .63387 .49445 L .6297 .49248 L F
.979 .762 .347 r
.63387 .49438 m .63388 .49443 L .63409 .4937 L F
.63388 .49443 m .63428 .49685 L .6341 .4938 L F
.63388 .49443 m .6341 .4938 L .63409 .4937 L F
.36 0 .133 r
.63387 .49445 m .63352 .49545 L .63458 .49406 L F
.63103 .49597 m .63352 .49545 L .63387 .49445 L F
.63387 .49445 m .63458 .49406 L .63429 .49397 L F
.63387 .49445 m .63384 .49382 L .6297 .49248 L F
.979 .762 .347 r
.63386 .4944 m .63387 .49444 L .63387 .49438 L F
.63387 .49444 m .63428 .49685 L .63387 .49438 L F
.63352 .49545 m .63392 .49619 L .63386 .4944 L F
.63392 .49619 m .63428 .49685 L .63386 .4944 L F
.735 .563 .659 r
.63384 .49382 m .63429 .49397 L .63378 .49203 L F
.63429 .49397 m .63458 .49406 L .63447 .49379 L F
.979 .762 .347 r
.63447 .49379 m .63409 .4937 L .6351 .49317 L F
.63387 .49438 m .63401 .49395 L .63447 .49379 L F
.63401 .49395 m .63409 .4937 L .63447 .49379 L F
.63429 .49397 m .6351 .49317 L .63514 .49314 L F
.36 0 .133 r
.63387 .49445 m .63429 .49397 L .63387 .49438 L F
.979 .762 .347 r
.63387 .49438 m .63514 .49314 L .63602 .49268 L F
.399 .382 .725 r
.6332 .49057 m .63447 .49379 L .63603 .49273 L F
.63447 .49379 m .63458 .49406 L .63514 .49355 L F
0 0 0 r
.63458 .49406 m .63352 .49545 L .63514 .49355 L F
.979 .762 .347 r
.63352 .49545 m .63387 .49438 L .6356 .49301 L F
.63352 .49545 m .6356 .49301 L .63602 .49268 L F
.63352 .49545 m .63602 .49268 L .63603 .49273 L F
0 0 0 r
.63514 .49355 m .63352 .49545 L .63603 .49273 L F
.399 .382 .725 r
.63447 .49379 m .63514 .49355 L .63603 .49273 L F
.979 .762 .347 r
.63387 .49438 m .6351 .49317 L .63429 .49397 L F
.735 .563 .659 r
.63429 .49397 m .63447 .49379 L .63378 .49203 L F
.36 0 .133 r
.63387 .49438 m .63429 .49397 L .63384 .49382 L F
.735 .563 .659 r
.6297 .49248 m .6332 .49057 L .63106 .49175 L F
.6297 .49248 m .63384 .49382 L .6332 .49057 L F
.63384 .49382 m .63378 .49203 L .6332 .49057 L F
.211 .703 .921 r
.35296 .70889 m .35173 .70842 L .34939 .70845 L F
.501 .742 .981 r
.35296 .70889 m .35389 .7073 L .35173 .70842 L F
.35296 .70889 m .3556 .70858 L .35389 .7073 L F
.282 0 0 r
.68392 .53268 m .68581 .53216 L .68279 .53224 L F
.439 .872 .789 r
.68731 .53121 m .68581 .53216 L .68392 .53268 L F
.332 .756 .975 r
.2867 .63666 m .28993 .63714 L .28815 .63772 L F
.684 .643 .803 r
.25985 .65401 m .26218 .65309 L .25869 .65163 L F
.474 .13 .302 r
.7049 .52483 m .70452 .52621 L .70214 .52656 L F
.359 .029 .262 r
.70639 .52556 m .7049 .52483 L .70709 .52431 L F
.70639 .52556 m .70452 .52621 L .7049 .52483 L F
.561 .64 .886 r
.68853 .48513 m .68804 .48789 L .68627 .48518 L F
.68853 .48513 m .69031 .48746 L .68804 .48789 L F
.804 .857 .889 r
.64797 .53168 m .6494 .53303 L .65085 .53144 L F
.981 .869 .65 r
.64767 .53423 m .6494 .53303 L .64797 .53168 L F
.64767 .53423 m .64862 .53516 L .6494 .53303 L F
.519 .32 .55 r
.48141 .65812 m .47786 .6579 L .48005 .6572 L F
.48141 .65812 m .47905 .66117 L .47786 .6579 L F
.48141 .65812 m .48101 .6609 L .47905 .66117 L F
.618 .836 .984 r
.48227 .65671 m .48141 .65812 L .48005 .6572 L F
.511 .441 .714 r
.48227 .65671 m .48101 .6609 L .48141 .65812 L F
.766 .265 0 r
.59139 .68309 m .59311 .68539 L .59401 .68578 L F
0 0 .353 r
.59311 .68539 m .59387 .68862 L .59401 .68578 L F
.52 .18 .332 r
.50645 .76647 m .50968 .76618 L .50989 .76375 L F
0 0 .059 r
.50989 .76375 m .51146 .76302 L .51238 .76059 L F
.109 0 .243 r
.50989 .76375 m .5111 .76559 L .51146 .76302 L F
.50989 .76375 m .50968 .76618 L .5111 .76559 L F
.541 .481 .738 r
.48175 .66294 m .47975 .66365 L .47905 .66117 L F
.668 .554 .717 r
.48175 .66294 m .47949 .66595 L .47975 .66365 L F
.254 .753 .897 r
.39146 .71589 m .3883 .71591 L .3894 .71612 L F
.606 .333 .477 r
.39433 .67209 m .39395 .67432 L .39144 .67439 L F
.397 .149 .417 r
.39586 .67373 m .39433 .67209 L .39658 .67154 L F
.39586 .67373 m .39395 .67432 L .39433 .67209 L F
.41 .446 .787 r
.50658 .75451 m .50261 .75272 L .50786 .75297 L F
.581 .122 .128 r
.50983 .75437 m .50786 .75297 L .51012 .75248 L F
.50983 .75437 m .50658 .75451 L .50786 .75297 L F
.521 .339 .575 r
.51012 .75248 m .50786 .75297 L .51012 .74999 L F
.353 0 0 r
.25844 .58721 m .2606 .58702 L .26224 .58546 L F
.304 0 0 r
.2606 .58702 m .26432 .58494 L .26224 .58546 L F
.265 0 .2 r
.41661 .69405 m .41756 .69566 L .41884 .6937 L F
.41661 .69405 m .41566 .69644 L .41756 .69566 L F
.373 .097 .359 r
.32757 .64003 m .32619 .63883 L .32826 .63845 L F
.32757 .64003 m .32562 .64075 L .32619 .63883 L F
.756 .436 .442 r
.67644 .53793 m .67516 .54004 L .67533 .53833 L F
.784 .471 .458 r
.67644 .53793 m .67849 .54091 L .67516 .54004 L F
.603 .681 .896 r
.70195 .48944 m .70048 .49172 L .69981 .48984 L F
.70195 .48944 m .70274 .49116 L .70048 .49172 L F
.679 .648 .812 r
.64055 .49732 m .64218 .49928 L .63819 .49962 L F
.723 .386 .408 r
.64287 .50143 m .63819 .49962 L .64218 .49928 L F
.64287 .50143 m .63795 .50122 L .63819 .49962 L F
.373 .447 .809 r
.3605 .60155 m .35915 .60193 L .35811 .59991 L F
.477 .361 .643 r
.36082 .60503 m .35915 .60193 L .3605 .60155 L F
.36082 .60503 m .35908 .60566 L .35915 .60193 L F
.488 .142 .306 r
.28664 .60545 m .29 .60518 L .28911 .60524 L F
.743 .491 .548 r
.67729 .52072 m .68041 .5187 L .67741 .51863 L F
.67729 .52072 m .68065 .52119 L .68041 .5187 L F
.81 .669 .707 r
.67713 .52306 m .68065 .52119 L .67729 .52072 L F
0 0 .146 r
.67718 .52284 m .67729 .52072 L .67789 .51931 L F
.67713 .52306 m .67729 .52072 L .67718 .52284 L F
.743 .491 .548 r
.67729 .52072 m .67741 .51863 L .67639 .51861 L F
.838 .766 .783 r
.49806 .78917 m .50003 .78818 L .50025 .78622 L F
.518 .56 .837 r
.49806 .78917 m .5018 .79233 L .50003 .78818 L F
.368 .352 .71 r
.50003 .78818 m .5031 .79027 L .50333 .78923 L F
.50003 .78818 m .5018 .79233 L .5031 .79027 L F
.65 .616 .802 r
.4562 .66373 m .45988 .66641 L .4585 .6632 L F
.727 .681 .805 r
.4585 .6632 m .45988 .66641 L .46161 .66352 L F
.592 .504 .724 r
.46161 .66352 m .45988 .66641 L .46224 .66598 L F
.585 .456 .671 r
.46008 .66887 m .46224 .66598 L .45988 .66641 L F
.955 .744 .578 r
.55506 .78591 m .55634 .7892 L .55615 .78667 L F
.649 .413 .548 r
.55845 .7886 m .55615 .78667 L .55634 .7892 L F
.55845 .7886 m .55865 .78627 L .55615 .78667 L F
.55615 .78667 m .55845 .7886 L .55634 .7892 L F
.55615 .78667 m .55865 .78627 L .55845 .7886 L F
0 0 0 r
.65335 .53114 m .65641 .5301 L .65546 .53171 L F
.65335 .53114 m .65412 .53135 L .65473 .53104 L F
.65412 .53135 m .6557 .53177 L .65473 .53104 L F
.65546 .53171 m .65695 .52992 L .6557 .53177 L F
.65641 .5301 m .65695 .52992 L .65546 .53171 L F
.966 .889 .701 r
.65447 .53513 m .65473 .53104 L .6557 .53177 L F
.629 .596 .797 r
.65557 .53273 m .65653 .53012 L .65473 .53104 L F
.65653 .53012 m .65662 .52985 L .65473 .53104 L F
.966 .889 .701 r
.65459 .53316 m .65348 .53427 L .65473 .53104 L F
.65447 .53513 m .65378 .53453 L .65459 .53316 L F
.65378 .53453 m .65348 .53427 L .65459 .53316 L F
.986 .739 .473 r
.65505 .52419 m .65695 .52992 L .65578 .52714 L F
.014 .158 .67 r
.52084 .7402 m .5193 .73897 L .5215 .73872 L F
.376 .445 .804 r
.55145 .76946 m .54998 .76959 L .55023 .76753 L F
.595 .631 .857 r
.25637 .6517 m .25699 .64868 L .25518 .64931 L F
.25637 .6517 m .25869 .65163 L .25699 .64868 L F
.835 .672 .68 r
.59385 .55177 m .59531 .55501 L .59254 .5547 L F
.843 .722 .73 r
.59531 .55501 m .59177 .55684 L .59254 .5547 L F
.59531 .55501 m .59401 .5579 L .59177 .55684 L F
.463 .482 .793 r
.39548 .6929 m .39284 .69147 L .39458 .69143 L F
.841 .763 .252 r
.57609 .72696 m .57609 .72713 L .57642 .7265 L F
0 .104 .659 r
.57631 .72987 m .57623 .72894 L .5749 .7276 L F
.605 .059 0 r
.5749 .7276 m .57636 .72907 L .57601 .72905 L F
0 .104 .659 r
.57651 .73019 m .5774 .73011 L .57623 .72894 L F
.605 .059 0 r
.57636 .72907 m .5774 .73011 L .57601 .72905 L F
.912 .86 .418 r
.57609 .72696 m .57557 .72904 L .57601 .72905 L F
.671 .253 .243 r
.57601 .72905 m .57514 .73077 L .57242 .72885 L F
.912 .86 .418 r
.57557 .72904 m .57514 .73077 L .57601 .72905 L F
.841 .763 .252 r
.57609 .72713 m .57601 .72905 L .57616 .72809 L F
.57609 .72713 m .57616 .72809 L .57642 .7265 L F
0 .104 .659 r
.57651 .73019 m .57623 .72894 L .57631 .72987 L F
.818 .389 0 r
.57651 .73019 m .5781 .73327 L .57708 .7321 L F
.57651 .73019 m .57708 .7321 L .5774 .73011 L F
.49 .012 .048 r
.57126 .71813 m .57352 .71783 L .57241 .71705 L F
.589 .518 .742 r
.72936 .61117 m .73089 .60704 L .72851 .60752 L F
.72936 .61117 m .73212 .61073 L .73089 .60704 L F
.272 0 0 r
.68519 .51534 m .68718 .51508 L .6883 .51469 L F
0 0 .478 r
.50448 .7908 m .50389 .79153 L .50333 .78923 L F
0 0 0 r
.5036 .79372 m .50389 .79153 L .50448 .7908 L F
.091 .532 .908 r
.27289 .58425 m .27414 .58436 L .27395 .58509 L F
.158 0 0 r
.27248 .58445 m .27521 .58446 L .27414 .58436 L F
.092 .635 .844 r
.27495 .58446 m .2762 .58446 L .27779 .58479 L F
.27414 .58436 m .2762 .58446 L .27495 .58446 L F
.242 0 0 r
.27456 .58461 m .27799 .58445 L .2762 .58446 L F
.113 .649 .858 r
.27674 .58452 m .27816 .58445 L .27992 .58487 L F
.2762 .58446 m .27816 .58445 L .27674 .58452 L F
.325 .81 .869 r
.27672 .58475 m .27914 .5844 L .27816 .58445 L F
.27 .761 .91 r
.27816 .58445 m .28031 .58422 L .28211 .58455 L F
.325 .81 .869 r
.27914 .5844 m .28031 .58422 L .27816 .58445 L F
.242 0 0 r
.27799 .58445 m .27816 .58445 L .2762 .58446 L F
.158 0 0 r
.27521 .58446 m .2762 .58446 L .27414 .58436 L F
.091 .532 .908 r
.27253 .58397 m .27414 .58436 L .27289 .58425 L F
.228 .677 .952 r
.27395 .58509 m .27414 .58436 L .27574 .58515 L F
.541 .481 .738 r
.48175 .66294 m .47905 .66117 L .48101 .6609 L F
.588 .203 .281 r
.41052 .66625 m .40932 .66829 L .40707 .66686 L F
.369 0 .139 r
.41274 .66592 m .40932 .66829 L .41052 .66625 L F
.527 .511 .782 r
.36665 .69131 m .36751 .68787 L .36567 .68832 L F
.36665 .69131 m .36863 .69095 L .36751 .68787 L F
.459 .411 .717 r
.36665 .69131 m .36907 .69342 L .36863 .69095 L F
.927 .972 .748 r
.47493 .78221 m .47396 .78342 L .47393 .7816 L F
0 0 0 r
.47476 .78314 m .47834 .78279 L .47743 .7822 L F
.47396 .78342 m .47537 .7832 L .47493 .78328 L F
.47396 .78342 m .47493 .78328 L .47476 .78314 L F
.47493 .78328 m .4759 .78311 L .47834 .78279 L F
.47537 .7832 m .4759 .78311 L .47493 .78328 L F
.47493 .78328 m .47834 .78279 L .47476 .78314 L F
.603 .774 .962 r
.47393 .7816 m .47396 .78342 L .47476 .78314 L F
.982 .736 .335 r
.47393 .7816 m .47441 .78248 L .47493 .78221 L F
.47415 .78261 m .47455 .78295 L .47493 .78221 L F
.47433 .78339 m .47483 .7833 L .47493 .78221 L F
.603 .774 .962 r
.47393 .7816 m .47476 .78314 L .47743 .7822 L F
.982 .736 .335 r
.47393 .7816 m .47415 .78261 L .47441 .78248 L F
.47415 .78261 m .47433 .78339 L .47455 .78295 L F
.47433 .78339 m .47467 .78495 L .47483 .7833 L F
.557 .262 .423 r
.53056 .75538 m .53358 .75252 L .53094 .75327 L F
.667 .575 .742 r
.72496 .60284 m .725 .6048 L .72718 .60213 L F
.643 .54 .723 r
.725 .6048 m .72764 .60461 L .72718 .60213 L F
.4 .132 .387 r
.62463 .5632 m .62795 .55999 L .62759 .56212 L F
.023 0 0 r
.63121 .55867 m .63075 .55908 L .62795 .55999 L F
.312 0 .145 r
.62795 .55999 m .62947 .56123 L .62759 .56212 L F
.62795 .55999 m .63075 .55908 L .62947 .56123 L F
.61 .132 .094 r
.56285 .78051 m .56458 .78203 L .5634 .7833 L F
.561 .904 .976 r
.45614 .64811 m .45722 .6471 L .45825 .64735 L F
.45614 .64811 m .45464 .64792 L .45722 .6471 L F
.658 .287 .33 r
.68718 .51508 m .6912 .51567 L .6883 .51469 L F
.631 .638 .839 r
.46883 .65383 m .46547 .65216 L .46742 .65198 L F
.641 .723 .908 r
.47098 .65302 m .46883 .65383 L .46742 .65198 L F
.587 .197 .27 r
.40299 .66868 m .40126 .67059 L .39926 .66922 L F
.445 .071 .234 r
.40448 .66815 m .40126 .67059 L .40299 .66868 L F
.818 .647 .671 r
.50127 .73923 m .50451 .74038 L .50284 .73581 L F
.098 .221 .704 r
.50284 .73581 m .50451 .74038 L .50512 .73743 L F
0 .544 .767 r
.30554 .5896 m .30914 .59015 L .30687 .59074 L F
.391 0 .076 r
.38515 .65403 m .38426 .65254 L .38295 .65444 L F
.38515 .65403 m .38649 .6523 L .38426 .65254 L F
.51 .394 .657 r
.36409 .66627 m .36643 .66822 L .36604 .66584 L F
.36409 .66627 m .36418 .66976 L .36643 .66822 L F
.555 .786 .985 r
.60601 .75048 m .60823 .74997 L .60476 .74932 L F
.333 .755 .976 r
.33716 .5932 m .33663 .59397 L .33516 .5931 L F
.33716 .5932 m .33869 .59384 L .33663 .59397 L F
.767 .644 .727 r
.62822 .49886 m .62987 .49927 L .62896 .49704 L F
.847 .64 .623 r
.62822 .49886 m .63014 .50213 L .62987 .49927 L F
.562 .468 .705 r
.62987 .49927 m .63236 .5014 L .63218 .49902 L F
.62987 .49927 m .63014 .50213 L .63236 .5014 L F
.537 .362 .591 r
.77008 .593 m .76928 .59402 L .77158 .5916 L F
.645 .519 .695 r
.76928 .59402 m .77197 .59381 L .77158 .5916 L F
.45 .23 .488 r
.76967 .59644 m .77197 .59381 L .76928 .59402 L F
.826 .943 .901 r
.55091 .7045 m .54947 .7052 L .55107 .70315 L F
.046 0 0 r
.55334 .70395 m .55047 .706 L .55091 .7045 L F
.05 0 .174 r
.55038 .70642 m .55003 .70599 L .55006 .70599 L F
.95 .757 .297 r
.54947 .7052 m .54893 .70798 L .54939 .70773 L F
.54893 .70798 m .54888 .70819 L .54893 .70815 L F
.54893 .70798 m .54893 .70815 L .54939 .70773 L F
.317 0 0 r
.55091 .7045 m .55003 .70599 L .54947 .7052 L F
.05 0 .174 r
.55006 .70599 m .55003 .70599 L .54947 .7052 L F
.95 .757 .297 r
.54947 .7052 m .54888 .70819 L .54939 .70773 L F
.05 0 .174 r
.55036 .70646 m .54888 .70819 L .54947 .7052 L F
.55038 .70642 m .55036 .70646 L .55003 .70599 L F
.55038 .70642 m .55006 .70599 L .5497 .70654 L F
.046 0 0 r
.55006 .70599 m .5497 .70654 L .55003 .70599 L F
.545 .413 .652 r
.54848 .70675 m .54888 .70819 L .55038 .70642 L F
.046 0 0 r
.5497 .70654 m .54969 .70655 L .5497 .70654 L F
.5497 .70654 m .5497 .70654 L .55003 .70599 L F
.545 .413 .652 r
.54784 .70446 m .54848 .70675 L .5497 .70654 L F
.54972 .70653 m .5497 .70654 L .55038 .70642 L F
.05 0 .174 r
.55038 .70642 m .5497 .70654 L .54969 .70655 L F
.435 .098 .294 r
.55038 .70642 m .54969 .70655 L .54972 .70653 L F
.55038 .70642 m .54972 .70653 L .55047 .706 L F
.545 .413 .652 r
.5502 .70628 m .54972 .70653 L .55038 .70642 L F
.54784 .70446 m .5497 .70654 L .5502 .70628 L F
.317 0 0 r
.55003 .70599 m .54969 .70655 L .54947 .7052 L F
.05 0 .174 r
.55006 .70599 m .54947 .7052 L .54969 .70655 L F
.545 .413 .652 r
.54886 .70525 m .5502 .70628 L .54885 .70461 L F
.5502 .70628 m .55038 .70642 L .55025 .70626 L F
.046 0 0 r
.55047 .706 m .54979 .70648 L .55006 .70599 L F
.545 .413 .652 r
.5502 .70628 m .55025 .70626 L .54885 .70461 L F
.046 0 0 r
.54979 .70648 m .54969 .70655 L .54971 .70652 L F
.54979 .70648 m .54971 .70652 L .55006 .70599 L F
.435 .098 .294 r
.55038 .70642 m .55047 .706 L .55334 .70395 L F
.545 .413 .652 r
.54885 .70461 m .55038 .70642 L .54986 .70477 L F
.54784 .70446 m .54886 .70525 L .54885 .70461 L F
.046 0 0 r
.55047 .706 m .55003 .70599 L .55091 .7045 L F
.314 .483 .866 r
.55107 .70315 m .55334 .70395 L .55091 .7045 L F
.825 .361 0 r
.66285 .50761 m .66282 .50879 L .66184 .50651 L F
.66285 .50761 m .66413 .5098 L .66282 .50879 L F
.732 .882 .95 r
.62635 .48481 m .62796 .4821 L .62866 .48418 L F
.62635 .48481 m .62505 .48387 L .62796 .4821 L F
.868 .8 .782 r
.58922 .68352 m .58949 .68643 L .58857 .68541 L F
.58922 .68352 m .59139 .68309 L .58949 .68643 L F
.99 .879 .617 r
.58783 .68773 m .58857 .68541 L .58949 .68643 L F
.727 .754 .873 r
.68853 .51841 m .69181 .51872 L .69044 .51728 L F
.38 .297 .636 r
.69181 .51872 m .69433 .52071 L .69432 .51786 L F
.69181 .51872 m .69271 .52047 L .69433 .52071 L F
.886 .756 .713 r
.69044 .51728 m .69181 .51872 L .6912 .51567 L F
.807 .347 .141 r
.59126 .68498 m .59139 .68309 L .58922 .68352 L F
.59126 .68498 m .59311 .68539 L .59139 .68309 L F
.798 .957 .917 r
.74564 .59132 m .74197 .59275 L .74418 .59196 L F
0 0 .14 r
.74655 .59051 m .74564 .59132 L .74673 .58972 L F
.695 .974 .775 r
.74673 .58972 m .74564 .59132 L .74418 .59196 L F
.626 .494 .682 r
.76731 .59937 m .7705 .59953 L .76967 .59644 L F
.65 .495 .66 r
.76776 .60137 m .7705 .59953 L .76731 .59937 L F
.318 .666 .974 r
.57139 .74699 m .57169 .74739 L .56959 .74596 L F
.702 .27 .22 r
.50343 .77281 m .50554 .77455 L .5022 .7742 L F
.682 .138 0 r
.50704 .77493 m .50554 .77455 L .50343 .77281 L F
.643 .416 .56 r
.47823 .6831 m .4805 .6854 L .47833 .68503 L F
.679 .412 .511 r
.48069 .68324 m .4805 .6854 L .47823 .6831 L F
.47 .616 .912 r
.67636 .48129 m .67493 .48316 L .6744 .48143 L F
.67636 .48129 m .67763 .48342 L .67493 .48316 L F
.847 .64 .623 r
.62822 .49886 m .62725 .50175 L .63014 .50213 L F
.691 .463 .572 r
.63236 .5014 m .62971 .50333 L .63014 .50213 L F
0 0 0 r
.63014 .50213 m .63124 .50197 L .63236 .5014 L F
.63014 .50213 m .62898 .50274 L .63124 .50197 L F
.396 .238 .546 r
.45827 .78067 m .46047 .78003 L .46052 .77765 L F
.344 .269 .626 r
.45827 .78067 m .46065 .78192 L .46047 .78003 L F
.45827 .78067 m .45874 .78386 L .46065 .78192 L F
.516 0 0 r
.63576 .48768 m .63464 .48696 L .632 .48478 L F
.704 .933 .964 r
.63684 .48565 m .63576 .48768 L .63791 .48718 L F
.63684 .48565 m .63464 .48696 L .63576 .48768 L F
.589 .1 .061 r
.4988 .77858 m .49773 .77959 L .49525 .77832 L F
.609 .123 .075 r
.49922 .77911 m .49773 .77959 L .4988 .77858 L F
.1 .052 .51 r
.34607 .71264 m .34704 .71561 L .34715 .7132 L F
.578 .654 .888 r
.74388 .61224 m .74445 .61358 L .74682 .61318 L F
.513 .23 .423 r
.63316 .55734 m .63075 .55908 L .63121 .55867 L F
.557 .262 .423 r
.53056 .75538 m .53316 .75525 L .53358 .75252 L F
.429 .152 .39 r
.53358 .75252 m .53515 .75458 L .53621 .75204 L F
.53358 .75252 m .53316 .75525 L .53515 .75458 L F
.652 .617 .802 r
.48253 .66623 m .47989 .6679 L .47949 .66595 L F
.639 .587 .78 r
.48253 .66623 m .48368 .66934 L .47989 .6679 L F
.599 .188 .235 r
.73145 .59773 m .72944 .59592 L .72917 .59835 L F
.73145 .59773 m .7317 .59634 L .72944 .59592 L F
.98 .763 .35 r
.59839 .69918 m .59831 .70137 L .59915 .70309 L F
.979 .902 .568 r
.59831 .70137 m .59796 .70502 L .59915 .70309 L F
.609 .062 0 r
.56724 .72283 m .56737 .72338 L .56515 .72132 L F
.636 .109 0 r
.56724 .72283 m .56958 .72529 L .56737 .72338 L F
.481 .55 .85 r
.48369 .67641 m .48353 .68002 L .48145 .67698 L F
.48369 .67641 m .4852 .67946 L .48353 .68002 L F
.599 .562 .784 r
.4852 .67946 m .48394 .68206 L .48353 .68002 L F
.358 .119 .409 r
.34227 .62379 m .34263 .62178 L .34433 .62114 L F
.341 .107 .406 r
.69738 .53178 m .69731 .53438 L .69484 .5343 L F
.299 0 .212 r
.69622 .53579 m .69484 .5343 L .69731 .53438 L F
.69622 .53579 m .69437 .53661 L .69484 .5343 L F
.095 0 0 r
.52347 .81151 m .5242 .81194 L .52183 .81261 L F
.52347 .81151 m .52575 .81117 L .5242 .81194 L F
.675 .606 .771 r
.53071 .76664 m .52863 .76969 L .52838 .76713 L F
.53071 .76664 m .53132 .76967 L .52863 .76969 L F
.758 .561 .63 r
.53132 .76967 m .52849 .77178 L .52863 .76969 L F
.526 .423 .68 r
.45983 .77497 m .46172 .77155 L .4595 .77244 L F
0 0 0 r
.50017 .74252 m .49855 .74394 L .49749 .74482 L F
.49855 .74394 m .49612 .74626 L .49749 .74482 L F
.749 .506 .564 r
.59612 .69652 m .59915 .69427 L .59608 .69421 L F
.59612 .69652 m .59926 .69649 L .59915 .69427 L F
.359 .663 .972 r
.51162 .73362 m .50863 .73211 L .51089 .73212 L F
.9 .897 .816 r
.51372 .73003 m .51162 .73362 L .51089 .73212 L F
0 0 .468 r
.51089 .73212 m .51264 .73529 L .51162 .73362 L F
.51089 .73212 m .51264 .73529 L .51162 .73362 L F
.276 .003 .306 r
.62517 .56484 m .62463 .5632 L .62759 .56212 L F
.389 0 .156 r
.4212 .69383 m .42346 .69344 L .42464 .69142 L F
.284 0 .1 r
.42464 .69142 m .42551 .69283 L .42669 .69071 L F
.42464 .69142 m .42346 .69344 L .42551 .69283 L F
.353 .08 .353 r
.51457 .75833 m .51652 .75754 L .51696 .75569 L F
.568 .274 .428 r
.51652 .75754 m .51917 .75748 L .51696 .75569 L F
.438 .02 .147 r
.41855 .66345 m .4173 .66531 L .41499 .66552 L F
.246 0 .037 r
.41934 .66473 m .41855 .66345 L .42074 .66301 L F
.41934 .66473 m .4173 .66531 L .41855 .66345 L F
.393 .221 .525 r
.46313 .76112 m .46456 .76314 L .46518 .7605 L F
.46313 .76112 m .46291 .76364 L .46456 .76314 L F
.784 .969 .67 r
.65752 .50682 m .65741 .50754 L .66026 .50367 L F
.737 .276 0 r
.65749 .50827 m .65741 .50754 L .65752 .50682 L F
.779 .689 .764 r
.59298 .54618 m .59523 .54337 L .59633 .54661 L F
.785 .667 .734 r
.59298 .54618 m .59633 .54661 L .59439 .54944 L F
.928 .729 .612 r
.51368 .76917 m .51528 .7725 L .51432 .77219 L F
.789 .548 .573 r
.51287 .77399 m .51477 .77493 L .51528 .7725 L F
.891 .823 .773 r
.51432 .77219 m .51287 .77399 L .51528 .7725 L F
.17 .685 .891 r
.41491 .64934 m .41711 .64935 L .41844 .64973 L F
.335 .788 .95 r
.41711 .64935 m .42062 .64946 L .41844 .64973 L F
.465 .336 .62 r
.39144 .67439 m .39161 .6767 L .38971 .67716 L F
.511 .405 .67 r
.39197 .67971 m .38971 .67716 L .39161 .6767 L F
.39197 .67971 m .38999 .68026 L .38971 .67716 L F
.443 .763 .996 r
.29831 .58763 m .29768 .58883 L .29619 .58791 L F
.29831 .58763 m .29982 .58862 L .29768 .58883 L F
.845 .382 .061 r
.57109 .72597 m .57023 .72648 L .56958 .72529 L F
.605 .059 0 r
.5749 .7276 m .57601 .72905 L .57402 .72872 L F
.734 .297 .211 r
.5749 .7276 m .57433 .72846 L .57109 .72597 L F
.862 .45 .246 r
.57433 .72846 m .57242 .72885 L .57023 .72648 L F
.91 .547 .332 r
.5749 .7276 m .57368 .72867 L .57433 .72846 L F
.862 .45 .246 r
.57433 .72846 m .57368 .72867 L .57242 .72885 L F
.605 .059 0 r
.57398 .72841 m .57402 .72872 L .57368 .72867 L F
.5749 .7276 m .57402 .72872 L .57398 .72841 L F
.698 .162 0 r
.57109 .72597 m .57395 .72817 L .57023 .72648 L F
.57395 .72817 m .57433 .72846 L .57396 .72828 L F
.57395 .72817 m .57396 .72828 L .57023 .72648 L F
.557 .816 .994 r
.69267 .52591 m .69064 .5266 L .69153 .52575 L F
.496 .329 .583 r
.36234 .67236 m .36414 .67195 L .36418 .66976 L F
.507 .383 .646 r
.3626 .6747 m .36414 .67195 L .36234 .67236 L F
.522 .492 .764 r
.72277 .49113 m .72625 .49247 L .72378 .49386 L F
.512 .408 .674 r
.72625 .49247 m .72408 .49604 L .72378 .49386 L F
.709 .637 .775 r
.77008 .593 m .77158 .5916 L .7701 .58907 L F
.52 .006 0 r
.37615 .65495 m .37274 .65496 L .37491 .65481 L F
.356 0 0 r
.3763 .65602 m .37615 .65495 L .37491 .65481 L F
.3763 .65602 m .3785 .65504 L .37615 .65495 L F
0 0 0 r
.56635 .68872 m .56557 .68965 L .56389 .6914 L F
.637 .489 .665 r
.56055 .6911 m .56415 .69119 L .56273 .68815 L F
.237 0 .151 r
.56512 .69266 m .56389 .6914 L .56507 .69024 L F
.637 .489 .665 r
.56415 .69119 m .56417 .69119 L .56417 .69118 L F
.56415 .69119 m .56417 .69118 L .56273 .68815 L F
0 0 0 r
.56557 .68965 m .56507 .69024 L .56459 .69071 L F
.56557 .68965 m .56459 .69071 L .56389 .6914 L F
.237 0 .151 r
.56512 .69266 m .5632 .69342 L .56389 .6914 L F
.549 .396 .626 r
.38999 .68026 m .39017 .68275 L .38801 .6832 L F
.906 .983 .733 r
.63614 .54265 m .63816 .54068 L .63731 .54198 L F
.766 .735 .824 r
.63714 .53898 m .63816 .54068 L .64077 .53823 L F
.71 .627 .762 r
.66726 .49237 m .66885 .495 L .66854 .49418 L F
.797 .836 .881 r
.66726 .49237 m .66854 .49418 L .67106 .49172 L F
.197 0 0 r
.58214 .67714 m .58308 .67735 L .5831 .67729 L F
.038 .487 .884 r
.58193 .67629 m .58308 .67735 L .58214 .67714 L F
.582 .05 0 r
.58301 .67749 m .58308 .67735 L .58193 .67629 L F
.58368 .67823 m .58308 .67735 L .58301 .67749 L F
.197 0 0 r
.5831 .67729 m .58308 .67735 L .58448 .67751 L F
.74 .239 .034 r
.58308 .67735 m .58674 .67955 L .58448 .67751 L F
.424 .154 .399 r
.63218 .49902 m .63497 .49852 L .63428 .49685 L F
.499 .19 .374 r
.63428 .49685 m .63497 .49852 L .63675 .49788 L F
.721 .71 .84 r
.53386 .74139 m .53723 .74225 L .53645 .73925 L F
.551 .653 .903 r
.53723 .74225 m .53921 .74037 L .53645 .73925 L F
.53723 .74225 m .53873 .7422 L .53921 .74037 L F
.565 .563 .81 r
.53723 .74225 m .53962 .74264 L .53873 .7422 L F
.058 .231 .727 r
.50886 .74903 m .51012 .75248 L .51012 .74999 L F
.643 .662 .854 r
.36847 .71186 m .37148 .71367 L .3698 .71035 L F
.438 .457 .782 r
.37148 .71367 m .37215 .71012 L .3698 .71035 L F
.37148 .71367 m .37334 .71341 L .37215 .71012 L F
.806 .68 .725 r
.59344 .56027 m .59493 .56389 L .59268 .56248 L F
.668 .636 .809 r
.59493 .56389 m .59125 .5662 L .59268 .56248 L F
.443 .309 .603 r
.46127 .7666 m .46291 .76364 L .46087 .76412 L F
.409 .839 .952 r
.26446 .58493 m .26644 .58447 L .2678 .5847 L F
.444 .848 .971 r
.26644 .58447 m .26999 .58433 L .2678 .5847 L F
.26644 .58447 m .26854 .58396 L .26999 .58433 L F
.362 0 .098 r
.2648 .58635 m .26851 .58398 L .26644 .58447 L F
.26851 .58398 m .26854 .58396 L .26644 .58447 L F
.409 .839 .952 r
.26432 .58494 m .26644 .58447 L .26446 .58493 L F
.39 .822 .96 r
.30933 .60213 m .30995 .60138 L .30781 .60161 L F
.30933 .60213 m .31141 .60173 L .30995 .60138 L F
.591 .396 .586 r
.60807 .57317 m .60817 .57437 L .60471 .57454 L F
.565 .29 .458 r
.60471 .57454 m .60713 .57637 L .60489 .57581 L F
.60471 .57454 m .60817 .57437 L .60713 .57637 L F
.89 .858 .803 r
.6139 .53472 m .61683 .53321 L .6155 .53174 L F
.6139 .53472 m .6151 .53573 L .61683 .53321 L F
.77 .777 .859 r
.6155 .53174 m .61683 .53321 L .61854 .53165 L F
.644 .277 .333 r
.46995 .68559 m .46904 .68756 L .46687 .68575 L F
.648 .339 .434 r
.47252 .68546 m .46904 .68756 L .46995 .68559 L F
.755 .608 .695 r
.50268 .81137 m .50494 .80839 L .5029 .80882 L F
.065 .3 .786 r
.50494 .80839 m .50792 .81104 L .50817 .80795 L F
.585 .376 .564 r
.50268 .81137 m .50494 .80839 L .50501 .81153 L F
.50501 .81153 m .50494 .80839 L .50268 .81137 L F
.55 .401 .632 r
.62525 .49652 m .623 .49637 L .62516 .49568 L F
.6255 .49876 m .62441 .49771 L .62525 .49652 L F
.62441 .49771 m .623 .49637 L .62525 .49652 L F
.6255 .49876 m .6233 .49935 L .623 .49637 L F
0 0 .393 r
.62401 .49706 m .6233 .49935 L .623 .49637 L F
.35 0 0 r
.62198 .49991 m .62322 .49939 L .62401 .49706 L F
.62322 .49939 m .6233 .49935 L .62334 .49921 L F
.62322 .49939 m .62334 .49921 L .62401 .49706 L F
0 0 .393 r
.62401 .49706 m .623 .49637 L .62516 .49568 L F
.138 0 .175 r
.72702 .50749 m .72669 .5091 L .7246 .51015 L F
.422 .381 .708 r
.72669 .5091 m .72715 .51193 L .7246 .51015 L F
.467 .375 .668 r
.72715 .51193 m .72535 .51313 L .7246 .51015 L F
.794 .778 .274 r
.57317 .75996 m .57372 .75872 L .57316 .75737 L F
.57317 .75996 m .57315 .76087 L .57372 .75872 L F
.993 .845 .588 r
.54951 .78854 m .55044 .78918 L .54901 .79113 L F
0 0 .228 r
.55167 .78577 m .55044 .78918 L .54951 .78854 L F
.486 .32 .581 r
.26686 .62169 m .26681 .62432 L .26486 .62479 L F
.592 .754 .956 r
.639 .48248 m .63778 .48459 L .63647 .48332 L F
.639 .48248 m .6402 .48407 L .63778 .48459 L F
.734 .431 .467 r
.51181 .72405 m .51284 .72149 L .51214 .72247 L F
.51181 .72405 m .51598 .72515 L .51284 .72149 L F
.629 .43 .594 r
.51284 .72149 m .5167 .72383 L .51588 .72179 L F
.51284 .72149 m .51598 .72515 L .5167 .72383 L F
.899 .774 .714 r
.66224 .53446 m .66376 .53539 L .66498 .5305 L F
.545 .542 .802 r
.32623 .61345 m .3273 .61013 L .32586 .61052 L F
.32623 .61345 m .32815 .61303 L .3273 .61013 L F
.568 .46 .691 r
.32653 .61597 m .32815 .61303 L .32623 .61345 L F
0 0 .526 r
.64388 .49255 m .6412 .49025 L .64255 .4921 L F
.729 .346 .325 r
.50951 .77553 m .50554 .77455 L .50704 .77493 L F
.442 .651 .948 r
.34673 .59488 m .34588 .59642 L .34475 .5949 L F
.421 .624 .937 r
.34673 .59488 m .34778 .59645 L .34588 .59642 L F
.892 .655 .573 r
.57877 .57334 m .57985 .57449 L .57775 .57388 L F
.851 .454 .291 r
.57854 .57516 m .57985 .57449 L .57775 .57388 L F
0 0 .243 r
.57985 .57449 m .58005 .57667 L .58037 .57525 L F
.57985 .57449 m .58037 .57525 L .57854 .57516 L F
.851 .454 .291 r
.57775 .57388 m .57985 .57449 L .57854 .57516 L F
.923 .596 .404 r
.57877 .57334 m .57985 .57449 L .57854 .57516 L F
.695 .153 0 r
.5422 .72366 m .54341 .72476 L .54472 .72519 L F
.523 0 0 r
.54596 .72645 m .54472 .72519 L .54341 .72476 L F
.54596 .72645 m .54731 .7274 L .54472 .72519 L F
.716 .244 .128 r
.54472 .72519 m .54731 .7274 L .5488 .72726 L F
.463 .233 .478 r
.27631 .6106 m .27592 .61287 L .27391 .61337 L F
.447 .219 .473 r
.27788 .61225 m .27631 .6106 L .2785 .61047 L F
.27788 .61225 m .27592 .61287 L .27631 .6106 L F
.741 .75 .86 r
.35748 .71905 m .36108 .71909 L .35961 .71892 L F
.48 .719 .975 r
.36108 .71909 m .36348 .71919 L .36176 .71792 L F
.787 .679 .746 r
.53783 .77238 m .53903 .77502 L .53595 .77486 L F
.75 .512 .571 r
.53903 .77502 m .53553 .77727 L .53595 .77486 L F
.53903 .77502 m .53913 .77726 L .53553 .77727 L F
.722 .219 .035 r
.53903 .77502 m .54256 .77734 L .53913 .77726 L F
.825 .709 .737 r
.55326 .78905 m .55634 .7892 L .55506 .78591 L F
.099 .064 .526 r
.56827 .77794 m .56917 .77454 L .56969 .77695 L F
0 0 0 r
.56969 .77695 m .56817 .77885 L .56827 .77794 L F
.515 .635 .907 r
.68845 .49202 m .68914 .49365 L .69058 .49176 L F
.509 .627 .903 r
.68914 .49365 m .69143 .49357 L .69058 .49176 L F
.613 .506 .708 r
.475 .78969 m .47743 .78946 L .47704 .785 L F
.156 0 0 r
.47622 .79009 m .47743 .78946 L .475 .78969 L F
.47622 .79009 m .475 .78969 L .4738 .78853 L F
.745 .61 .708 r
.51288 .77593 m .51612 .77755 L .51477 .77493 L F
.51612 .77755 m .51632 .77765 L .51477 .77493 L F
.51286 .77595 m .51632 .77765 L .51288 .77593 L F
.687 .703 .86 r
.51136 .77436 m .51285 .77594 L .51288 .77593 L F
.51382 .77478 m .51288 .77593 L .51477 .77493 L F
.51136 .77436 m .51288 .77593 L .51382 .77478 L F
.773 .579 .637 r
.5146 .77303 m .51477 .77493 L .51287 .77399 L F
.961 .718 .524 r
.51477 .77493 m .51432 .77407 L .5146 .77303 L F
.008 0 .211 r
.51432 .77407 m .51429 .77421 L .51461 .77369 L F
.733 .62 .733 r
.51136 .77436 m .51477 .77493 L .51287 .77399 L F
.961 .718 .524 r
.51477 .77493 m .51354 .77702 L .51432 .77407 L F
.008 0 .211 r
.51429 .77421 m .51354 .77702 L .51455 .77388 L F
.51429 .77421 m .51455 .77388 L .51461 .77369 L F
.51461 .77369 m .51354 .77702 L .51464 .77471 L F
.5146 .77303 m .51432 .77407 L .51461 .77369 L F
.745 .61 .708 r
.51285 .77594 m .51286 .77595 L .51288 .77593 L F
.993 .747 .442 r
.51656 .77998 m .51632 .77765 L .51835 .7799 L F
.715 .187 0 r
.51705 .77924 m .51632 .77765 L .51519 .7801 L F
.51705 .77924 m .51835 .7799 L .51632 .77765 L F
.638 .603 .798 r
.58732 .74486 m .58869 .74148 L .58633 .74151 L F
.58732 .74486 m .58971 .74436 L .58869 .74148 L F
.453 .183 .413 r
.27323 .6176 m .27169 .61612 L .27377 .61564 L F
.27323 .6176 m .27114 .61812 L .27169 .61612 L F
.61 .743 .939 r
.53071 .76664 m .52838 .76713 L .52966 .76538 L F
.408 .291 .608 r
.36411 .68028 m .36602 .68222 L .36591 .67973 L F
.36411 .68028 m .36434 .68277 L .36602 .68222 L F
.494 .482 .773 r
.36309 .67707 m .36411 .68028 L .36591 .67973 L F
.482 .535 .835 r
.64699 .48984 m .64557 .49089 L .64377 .48691 L F
0 0 0 r
.66077 .48249 m .65845 .48537 L .66004 .48408 L F
.516 .489 .765 r
.65832 .48743 m .66078 .48698 L .66056 .48613 L F
.65883 .48643 m .66056 .48613 L .66004 .48408 L F
.65832 .48743 m .66056 .48613 L .65883 .48643 L F
.686 .598 .752 r
.66004 .48408 m .66078 .48698 L .66277 .48597 L F
.487 .741 .984 r
.66182 .48514 m .66162 .48595 L .66009 .48536 L F
.66162 .48595 m .66155 .48625 L .66117 .48603 L F
.66162 .48595 m .66117 .48603 L .66009 .48536 L F
.516 .489 .765 r
.65836 .48684 m .66004 .48408 L .65845 .48537 L F
.65883 .48643 m .66004 .48408 L .65836 .48684 L F
.487 .741 .984 r
.66066 .48488 m .66009 .48536 L .65851 .4844 L F
.66182 .48514 m .66009 .48536 L .66066 .48488 L F
.516 .489 .765 r
.65832 .48743 m .65883 .48643 L .65836 .48684 L F
.758 .555 .622 r
.59863 .57428 m .59681 .5768 L .59514 .57379 L F
.628 .324 .435 r
.60122 .57493 m .59681 .5768 L .59863 .57428 L F
.696 .625 .774 r
.48609 .78774 m .48631 .79212 L .48419 .79058 L F
.622 .568 .772 r
.4888 .78923 m .48631 .79212 L .48609 .78774 L F
.654 .616 .799 r
.4888 .78923 m .49003 .79202 L .48631 .79212 L F
.596 .337 .494 r
.48394 .68206 m .4805 .6854 L .48069 .68324 L F
.625 .214 .245 r
.55967 .71354 m .56196 .71523 L .56305 .7134 L F
.61 .248 .329 r
.56196 .71523 m .56543 .71324 L .56305 .7134 L F
0 .09 .585 r
.77608 .58147 m .7745 .58021 L .77415 .57895 L F
.77608 .58147 m .77687 .58228 L .7745 .58021 L F
.478 .364 .645 r
.72864 .50457 m .72904 .50692 L .72702 .50749 L F
.368 .025 .245 r
.72804 .50825 m .72702 .50749 L .72904 .50692 L F
.72804 .50825 m .72669 .5091 L .72702 .50749 L F
0 .023 .556 r
.46781 .79421 m .46913 .79669 L .46853 .79434 L F
.712 .46 .543 r
.54894 .7721 m .54779 .77401 L .54693 .77192 L F
.727 .289 .211 r
.69672 .51997 m .69749 .51853 L .69432 .51786 L F
.171 0 0 r
.69951 .51774 m .69749 .51853 L .69672 .51997 L F
.637 .534 .72 r
.48499 .77987 m .48533 .78341 L .48753 .78097 L F
.433 .235 .51 r
.34227 .62379 m .33997 .62668 L .34015 .62453 L F
0 .157 .696 r
.46147 .78524 m .46298 .78879 L .46347 .78747 L F
0 .282 .783 r
.46298 .78879 m .46551 .79046 L .46347 .78747 L F
.9 .957 .825 r
.56558 .68792 m .56635 .68872 L .56852 .68591 L F
.997 .855 .538 r
.56558 .68792 m .56507 .69024 L .56635 .68872 L F
.783 .608 .663 r
.48354 .77594 m .48162 .7789 L .48079 .77788 L F
.48354 .77594 m .48499 .77987 L .48162 .7789 L F
.567 .449 .678 r
.48629 .77496 m .48625 .77719 L .48354 .77594 L F
.149 .24 .703 r
.48612 .77968 m .48354 .77594 L .48625 .77719 L F
.133 0 0 r
.30338 .60172 m .3023 .60193 L .30005 .60192 L F
.301 .794 .778 r
.30428 .60129 m .30338 .60172 L .3058 .60136 L F
.30428 .60129 m .3023 .60193 L .30338 .60172 L F
.662 .717 .889 r
.47857 .77917 m .47862 .77962 L .48079 .77788 L F
.43 .167 .412 r
.50284 .73581 m .50572 .7356 L .50628 .73252 L F
.313 0 .264 r
.50572 .7356 m .50863 .73211 L .50628 .73252 L F
0 0 .359 r
.63134 .52141 m .6314 .52367 L .6322 .52283 L F
.443 .032 .162 r
.63621 .54371 m .63688 .54465 L .63875 .54341 L F
.933 .587 .154 r
.63614 .54265 m .63688 .54465 L .63621 .54371 L F
.848 .998 .785 r
.78677 .60779 m .78625 .60726 L .78539 .6084 L F
.826 .472 0 r
.7855 .60495 m .78625 .60726 L .78677 .60779 L F
.491 .532 .827 r
.46608 .64881 m .46547 .65216 L .46397 .64924 L F
.46608 .64881 m .46742 .65198 L .46547 .65216 L F
.887 .637 .556 r
.62636 .4923 m .62754 .49289 L .62756 .49076 L F
.62636 .4923 m .62756 .49076 L .6298 .49015 L F
.61 .565 .779 r
.50313 .76086 m .50082 .7616 L .49995 .75799 L F
.458 .45 .762 r
.58962 .72865 m .59076 .72843 L .58889 .72733 L F
.58962 .72865 m .59205 .72988 L .59076 .72843 L F
.095 .615 .882 r
.29612 .65054 m .29969 .6513 L .29848 .65041 L F
.476 .791 .999 r
.29848 .65041 m .29969 .6513 L .30172 .65095 L F
.561 .376 .588 r
.45786 .67145 m .46053 .67103 L .46008 .66887 L F
.637 .497 .676 r
.45786 .67145 m .46093 .6743 L .46053 .67103 L F
.45786 .67145 m .45875 .67512 L .46093 .6743 L F
.356 .164 .477 r
.53044 .73868 m .52839 .74159 L .53039 .7408 L F
.607 .46 .656 r
.52813 .74397 m .53039 .7408 L .52839 .74159 L F
.69 .671 .827 r
.72059 .4912 m .71762 .49102 L .72004 .49051 L F
.601 .798 .975 r
.72221 .49 m .72059 .4912 L .72004 .49051 L F
.72221 .49 m .72277 .49113 L .72059 .4912 L F
.936 .872 .749 r
.61287 .53706 m .6151 .53573 L .6139 .53472 L F
.61287 .53706 m .61404 .53809 L .6151 .53573 L F
0 0 0 r
.59178 .69763 m .59036 .69874 L .59284 .6969 L F
.863 .635 .102 r
.78398 .59909 m .78416 .60144 L .78451 .60256 L F
.597 .747 .949 r
.78544 .60369 m .78451 .60256 L .78416 .60144 L F
.78529 .60351 m .7843 .60465 L .78451 .60256 L F
.7843 .60465 m .78337 .60571 L .78351 .60531 L F
.7843 .60465 m .78351 .60531 L .78451 .60256 L F
.78544 .60369 m .7855 .60495 L .7843 .60465 L F
.78544 .60369 m .78337 .60571 L .78529 .60351 L F
.78544 .60369 m .7843 .60465 L .78226 .60415 L F
.671 .72 .886 r
.78226 .60415 m .7843 .60465 L .78337 .60571 L F
.7843 .60465 m .7855 .60495 L .78337 .60571 L F
.686 .5 .629 r
.59348 .57034 m .59319 .57396 L .58969 .57435 L F
.706 .517 .631 r
.59553 .5713 m .59319 .57396 L .59348 .57034 L F
.254 0 .099 r
.44996 .69147 m .44723 .69321 L .44798 .69209 L F
.538 .282 .476 r
.4508 .68007 m .45306 .67985 L .45325 .67766 L F
.656 .383 .495 r
.45325 .67766 m .45617 .67905 L .45636 .67733 L F
.45325 .67766 m .45306 .67985 L .45617 .67905 L F
.637 .715 .904 r
.73992 .61024 m .74106 .61275 L .74388 .61224 L F
.776 .997 .817 r
.49397 .78452 m .49171 .7864 L .49323 .78576 L F
.658 .265 .289 r
.49323 .78576 m .49678 .78581 L .49397 .78452 L F
.726 .457 .521 r
.52237 .72481 m .52439 .72721 L .52418 .72516 L F
.712 .447 .523 r
.52418 .72516 m .52439 .72721 L .52799 .72723 L F
.609 .919 .976 r
.30393 .65067 m .30536 .65105 L .3079 .65021 L F
.9 .957 .825 r
.56558 .68792 m .56852 .68591 L .56555 .68622 L F
.698 .157 0 r
.56852 .68591 m .57051 .6878 L .56875 .68693 L F
.584 .361 .543 r
.57092 .68555 m .57051 .6878 L .56852 .68591 L F
.698 .157 0 r
.56852 .68591 m .56875 .68693 L .569 .68437 L F
.303 0 0 r
.4272 .70197 m .42563 .70368 L .42345 .70396 L F
.379 0 .045 r
.42922 .70179 m .42563 .70368 L .4272 .70197 L F
0 0 .249 r
.78432 .58791 m .78455 .58971 L .78308 .59112 L F
0 0 .048 r
.78308 .59112 m .78297 .59273 L .78231 .59337 L F
.78308 .59112 m .78455 .58971 L .78297 .59273 L F
.798 .68 .734 r
.6063 .74413 m .60377 .74122 L .60357 .74377 L F
.6063 .74413 m .60698 .74167 L .60377 .74122 L F
.84 .771 .786 r
.60357 .74377 m .60518 .74502 L .6063 .74413 L F
.729 .743 .863 r
.71762 .49102 m .71431 .49051 L .71673 .48961 L F
.612 .74 .936 r
.72004 .49051 m .71762 .49102 L .71673 .48961 L F
.533 .259 .446 r
.62372 .54302 m .6269 .53933 L .62374 .54105 L F
.62372 .54302 m .62632 .54263 L .6269 .53933 L F
.542 .32 .528 r
.6269 .53933 m .62881 .54002 L .62965 .53785 L F
.274 .038 .363 r
.6269 .53933 m .62793 .54165 L .62881 .54002 L F
.6269 .53933 m .62632 .54263 L .62793 .54165 L F
.956 .935 .726 r
.56777 .71294 m .56639 .71566 L .56718 .71626 L F
.797 .339 .154 r
.56623 .71734 m .56718 .71626 L .56639 .71566 L F
.56623 .71734 m .56886 .7185 L .56718 .71626 L F
.456 .876 .757 r
.55326 .78905 m .55071 .79048 L .54901 .79113 L F
.679 .199 .104 r
.54901 .79113 m .55071 .79048 L .55315 .79486 L F
.2 0 .151 r
.55361 .78969 m .55071 .79048 L .55326 .78905 L F
.55304 .79032 m .55071 .79048 L .55361 .78969 L F
.241 .036 .389 r
.55359 .79219 m .55071 .79048 L .55391 .79027 L F
.55315 .79486 m .5518 .79243 L .55359 .79219 L F
.5518 .79243 m .55071 .79048 L .55359 .79219 L F
.2 0 .151 r
.55391 .79027 m .55071 .79048 L .55326 .78905 L F
.568 .485 .721 r
.55091 .78702 m .55391 .79027 L .55294 .78866 L F
.2 0 .151 r
.55391 .79027 m .55304 .79032 L .55361 .78969 L F
.568 .485 .721 r
.55091 .78702 m .55228 .79143 L .55391 .79027 L F
.574 .547 .786 r
.55536 .78637 m .55391 .79027 L .5538 .78925 L F
.55536 .78637 m .55662 .79018 L .55391 .79027 L F
.356 .133 .432 r
.55391 .79027 m .55228 .79143 L .55315 .79486 L F
.804 .664 .114 r
.5538 .78925 m .55391 .79027 L .55381 .79253 L F
.312 0 0 r
.55391 .79027 m .55463 .79094 L .55381 .79253 L F
.55391 .79027 m .55553 .79022 L .55463 .79094 L F
.55553 .79022 m .55662 .79018 L .55463 .79094 L F
.804 .664 .114 r
.55419 .79129 m .55463 .79094 L .55439 .79235 L F
.5538 .78925 m .5538 .79216 L .55463 .79094 L F
.5538 .78925 m .55463 .79094 L .55419 .79129 L F
.5538 .79216 m .55381 .79253 L .55401 .79213 L F
.5538 .79216 m .55401 .79213 L .55463 .79094 L F
.996 .852 .575 r
.54951 .78854 m .54901 .79113 L .54808 .79013 L F
.783 .608 .663 r
.54808 .79013 m .5521 .79137 L .55091 .78702 L F
.5521 .79137 m .55228 .79143 L .55222 .79124 L F
.5521 .79137 m .55222 .79124 L .55091 .78702 L F
.459 .298 .575 r
.46521 .75812 m .46718 .7595 L .46747 .75754 L F
.46521 .75812 m .46518 .7605 L .46718 .7595 L F
.628 .324 .435 r
.60122 .57493 m .59901 .57667 L .59681 .5768 L F
.693 .334 .362 r
.60122 .57493 m .6013 .57657 L .59901 .57667 L F
.522 .34 .576 r
.27592 .61287 m .27377 .61564 L .27391 .61337 L F
.736 .599 .705 r
.52016 .76972 m .52082 .77252 L .51753 .77216 L F
.369 .728 .989 r
.52186 .77173 m .52082 .77252 L .51932 .77153 L F
.776 .563 .611 r
.57435 .68582 m .57051 .6878 L .57092 .68555 L F
.57435 .68582 m .57411 .68843 L .57051 .6878 L F
.497 .318 .568 r
.57617 .68533 m .57411 .68843 L .57435 .68582 L F
.871 .677 .637 r
.59401 .5579 m .59344 .56027 L .59177 .55684 L F
.236 0 .012 r
.5753 .67654 m .57667 .67714 L .57754 .67617 L F
.5753 .67654 m .57375 .6787 L .57667 .67714 L F
.317 .013 .282 r
.32288 .64313 m .32103 .64361 L .32359 .64134 L F
.342 .02 .266 r
.32562 .64075 m .32288 .64313 L .32359 .64134 L F
.759 .709 .805 r
.4632 .67156 m .46093 .6743 L .46443 .67468 L F
.532 .393 .637 r
.46093 .6743 m .46315 .67636 L .46443 .67468 L F
.604 .557 .775 r
.46443 .67468 m .46532 .67081 L .4632 .67156 L F
.46443 .67468 m .46677 .67439 L .46532 .67081 L F
.557 .139 .203 r
.46443 .67468 m .46315 .67636 L .4663 .67616 L F
.501 .167 .333 r
.46443 .67468 m .4663 .67616 L .46677 .67439 L F
.141 0 .021 r
.3216 .64492 m .32103 .64361 L .32288 .64313 L F
.3216 .64492 m .31978 .64569 L .32103 .64361 L F
.59 .412 .608 r
.55858 .6965 m .55629 .69958 L .55664 .69717 L F
.542 .854 .998 r
.632 .48478 m .63088 .48404 L .63421 .48414 L F
.526 .361 .599 r
.632 .48478 m .63421 .48414 L .63088 .48404 L F
.632 .48478 m .63464 .48696 L .63421 .48414 L F
.965 .824 .654 r
.66173 .52217 m .66362 .52165 L .66262 .52061 L F
.66173 .52217 m .66315 .52415 L .66362 .52165 L F
.597 .536 .757 r
.72851 .60752 m .73027 .60527 L .72764 .60461 L F
.72851 .60752 m .73089 .60704 L .73027 .60527 L F
.168 0 0 r
.52273 .75766 m .52617 .75827 L .52355 .75778 L F
.683 .492 .621 r
.51879 .72479 m .52219 .72702 L .52237 .72481 L F
.679 .457 .577 r
.52219 .72702 m .52439 .72721 L .52237 .72481 L F
.385 .162 .448 r
.62178 .54369 m .62372 .54302 L .62374 .54105 L F
.41 .446 .787 r
.50658 .75451 m .50505 .75576 L .50261 .75272 L F
.692 .264 .227 r
.63188 .54215 m .63316 .54063 L .63222 .53961 L F
.63188 .54215 m .63614 .54265 L .63316 .54063 L F
.36 .811 .944 r
.42279 .64922 m .4263 .64915 L .42409 .64983 L F
.581 .759 .963 r
.35811 .59991 m .35487 .59939 L .35703 .59901 L F
.387 .448 .802 r
.35923 .59813 m .35811 .59991 L .35703 .59901 L F
.35923 .59813 m .3605 .60155 L .35811 .59991 L F
.556 .886 .628 r
.74862 .59347 m .74805 .59383 L .74571 .59586 L F
0 0 0 r
.75061 .59281 m .74805 .59383 L .74862 .59347 L F
.374 .58 .922 r
.75364 .61629 m .75733 .61865 L .75593 .61576 L F
.056 .28 .771 r
.75593 .61576 m .75733 .61865 L .75802 .61741 L F
.064 .29 .778 r
.75733 .61865 m .75964 .62072 L .75802 .61741 L F
.93 .883 .765 r
.58081 .72426 m .58079 .72446 L .58233 .72277 L F
.58053 .72475 m .58068 .72761 L .58206 .72355 L F
.58053 .72475 m .58206 .72355 L .58233 .72277 L F
.58052 .72455 m .58053 .72475 L .58079 .72446 L F
.58052 .72455 m .58079 .72446 L .58081 .72426 L F
.58052 .72455 m .58233 .72277 L .58157 .72535 L F
.442 .829 .986 r
.58486 .72201 m .5811 .72193 L .58448 .72146 L F
.744 .515 .583 r
.58486 .72201 m .58233 .72277 L .5811 .72193 L F
.58486 .72201 m .58496 .72459 L .58233 .72277 L F
.307 0 0 r
.58496 .72459 m .58157 .72535 L .58233 .72277 L F
.529 .815 .998 r
.58448 .72146 m .5811 .72193 L .58033 .72099 L F
.575 .591 .832 r
.58157 .72535 m .58298 .72131 L .58106 .72108 L F
.58091 .72302 m .58106 .72108 L .58033 .72099 L F
.58157 .72535 m .58106 .72108 L .58091 .72302 L F
.93 .883 .765 r
.57947 .72557 m .58002 .72649 L .58052 .72455 L F
.58002 .72649 m .58068 .72761 L .58052 .72455 L F
.231 .349 .778 r
.58045 .72481 m .57947 .72557 L .58157 .72535 L F
.5781 .72368 m .57947 .72557 L .58045 .72481 L F
.93 .883 .765 r
.57947 .72557 m .58052 .72455 L .58157 .72535 L F
.702 .638 .783 r
.5781 .72368 m .58045 .72481 L .58044 .72449 L F
.57859 .72309 m .58044 .72449 L .58033 .72099 L F
.5781 .72368 m .58044 .72449 L .57859 .72309 L F
.58045 .72481 m .58157 .72535 L .58091 .72302 L F
.58045 .72481 m .58091 .72302 L .58033 .72099 L F
.915 .744 .655 r
.57947 .72557 m .58054 .72809 L .58068 .72761 L F
.411 .219 .507 r
.62178 .54369 m .62181 .54578 L .62372 .54302 L F
.59 .658 .885 r
.27403 .63432 m .27299 .63685 L .27191 .63473 L F
.27403 .63432 m .27545 .63653 L .27299 .63685 L F
.63 .384 .527 r
.55681 .76132 m .55632 .76378 L .55234 .7631 L F
.266 .059 .401 r
.55806 .76065 m .55632 .76378 L .55681 .76132 L F
.585 .456 .671 r
.46008 .66887 m .4625 .66952 L .46224 .66598 L F
.044 0 0 r
.46053 .67103 m .4625 .66952 L .46008 .66887 L F
.384 .264 .591 r
.733 .50027 m .73134 .50374 L .73156 .50185 L F
.56 .903 .674 r
.63759 .55399 m .64072 .55169 L .63972 .55316 L F
0 0 0 r
.6429 .55062 m .64248 .55098 L .64072 .55169 L F
.64248 .55098 m .63972 .55316 L .64072 .55169 L F
.688 .217 .13 r
.63148 .51391 m .63474 .51453 L .63349 .51305 L F
.874 .835 .805 r
.61711 .50442 m .61731 .50149 L .61854 .50235 L F
.661 .241 .237 r
.61731 .50149 m .62061 .50138 L .61854 .50235 L F
.244 .545 .927 r
.72657 .49147 m .72277 .49113 L .72221 .49 L F
.72657 .49147 m .72625 .49247 L .72277 .49113 L F
.928 .729 .612 r
.51368 .76917 m .51432 .77219 L .51131 .76974 L F
.793 .513 .512 r
.48162 .7789 m .48499 .77987 L .48359 .78252 L F
.04 0 .083 r
.48359 .78252 m .48499 .77987 L .48612 .77968 L F
.736 .599 .705 r
.52016 .76972 m .51753 .77216 L .51716 .76948 L F
.098 .221 .704 r
.50284 .73581 m .50512 .73743 L .50572 .7356 L F
.795 .69 .749 r
.60377 .74122 m .60698 .74167 L .60586 .73858 L F
.385 .702 .984 r
.76328 .58662 m .76455 .58771 L .76704 .58776 L F
.596 .337 .494 r
.48394 .68206 m .48302 .68528 L .4805 .6854 L F
.599 .562 .784 r
.4852 .67946 m .4862 .6828 L .48394 .68206 L F
.651 .391 .513 r
.48637 .68484 m .48394 .68206 L .4862 .6828 L F
.48637 .68484 m .48302 .68528 L .48394 .68206 L F
.988 .812 .578 r
.61287 .53706 m .61354 .54045 L .61404 .53809 L F
.573 .424 .641 r
.76612 .60762 m .76834 .60469 L .7659 .60523 L F
.638 .461 .627 r
.51238 .76059 m .51527 .7612 L .51457 .75833 L F
0 0 .47 r
.51457 .75833 m .51581 .76001 L .51652 .75754 L F
.51457 .75833 m .51487 .75955 L .51581 .76001 L F
.562 .253 .402 r
.51897 .75887 m .51652 .75754 L .51581 .76001 L F
.471 .062 .182 r
.51581 .76001 m .51763 .76116 L .51897 .75887 L F
.772 .363 .277 r
.51437 .7588 m .51649 .76033 L .51581 .76001 L F
.51649 .76033 m .51763 .76116 L .51581 .76001 L F
0 0 .47 r
.51487 .75955 m .51527 .7612 L .51581 .76001 L F
.189 .547 .93 r
.78128 .58598 m .77881 .58442 L .78046 .58513 L F
0 .423 .811 r
.78424 .58682 m .78128 .58598 L .78046 .58513 L F
.78424 .58682 m .78513 .58757 L .78128 .58598 L F
.265 .529 .914 r
.78128 .58598 m .78513 .58757 L .78432 .58791 L F
.692 .723 .873 r
.73212 .61073 m .7351 .61167 L .73437 .60982 L F
.599 .648 .87 r
.7351 .61167 m .73668 .60936 L .73437 .60982 L F
.7351 .61167 m .73775 .61106 L .73668 .60936 L F
.794 .671 .728 r
.59298 .54618 m .59439 .54944 L .59133 .54879 L F
.834 .682 .695 r
.59439 .54944 m .5909 .55118 L .59133 .54879 L F
.59439 .54944 m .59385 .55177 L .5909 .55118 L F
.954 .623 .352 r
.66232 .49796 m .66361 .49829 L .66319 .49557 L F
.655 .939 .965 r
.66304 .49761 m .66361 .49829 L .66232 .49796 L F
.902 .605 .107 r
.66361 .49829 m .66411 .49889 L .66319 .49557 L F
.66319 .49557 m .66415 .49905 L .66361 .49829 L F
.66319 .49557 m .66361 .49829 L .66556 .49501 L F
0 0 0 r
.66556 .49501 m .66361 .49829 L .66478 .49675 L F
.655 .939 .965 r
.66478 .49675 m .66361 .49829 L .66304 .49761 L F
.902 .605 .107 r
.66361 .49829 m .66415 .49905 L .66411 .49889 L F
.53 .247 .43 r
.40126 .67059 m .39888 .67117 L .39926 .66922 L F
.496 .277 .511 r
.34129 .84215 m .34306 .84403 L .34336 .84161 L F
.34336 .84161 m .34306 .84403 L .34129 .84215 L F
.328 .506 .881 r
.65034 .49138 m .64774 .49164 L .64699 .48984 L F
.65034 .49138 m .65035 .49266 L .64774 .49164 L F
.508 .616 .894 r
.75468 .60781 m .75106 .60553 L .75341 .60549 L F
.487 .634 .919 r
.75634 .60611 m .75468 .60781 L .75341 .60549 L F
.75634 .60611 m .75663 .60766 L .75468 .60781 L F
.489 .493 .788 r
.39289 .68403 m .39131 .68639 L .39017 .68275 L F
.487 .491 .787 r
.39289 .68403 m .39401 .68765 L .39131 .68639 L F
.919 .739 .642 r
.66174 .53707 m .66376 .53539 L .66224 .53446 L F
.66174 .53707 m .6634 .53767 L .66376 .53539 L F
.554 .542 .795 r
.58633 .74151 m .58746 .73795 L .58607 .73903 L F
.413 .007 .155 r
.49593 .74102 m .49856 .74075 L .49883 .73946 L F
.853 .784 .784 r
.49856 .74075 m .50127 .73923 L .49883 .73946 L F
.536 .594 .859 r
.48637 .67138 m .48368 .66934 L .48602 .6688 L F
.53 .406 .656 r
.4886 .66812 m .48637 .67138 L .48602 .6688 L F
.4886 .66812 m .48934 .67178 L .48637 .67138 L F
.661 .36 .451 r
.48961 .67372 m .48637 .67138 L .48934 .67178 L F
.48961 .67372 m .48623 .67379 L .48637 .67138 L F
.58 .572 .808 r
.33929 .71575 m .34051 .71906 L .34267 .71846 L F
0 0 0 r
.64592 .53305 m .6449 .53457 L .64797 .53168 L F
.563 .375 .585 r
.67109 .50454 m .67288 .50194 L .67069 .5014 L F
.67109 .50454 m .67297 .5043 L .67288 .50194 L F
0 0 .42 r
.59387 .68862 m .59455 .69074 L .59444 .69145 L F
.976 .764 .552 r
.61745 .49862 m .61649 .49538 L .61788 .49643 L F
.463 .133 .32 r
.44509 .68269 m .44725 .68235 L .4483 .68 L F
.62 .294 .396 r
.4483 .68 m .4502 .68162 L .4508 .68007 L F
.4483 .68 m .44725 .68235 L .4502 .68162 L F
.662 .438 .569 r
.52799 .72723 m .53051 .72739 L .53062 .72477 L F
.494 .3 .545 r
.53062 .72477 m .53266 .72693 L .53282 .72433 L F
.53062 .72477 m .53051 .72739 L .53266 .72693 L F
.883 .901 .837 r
.48898 .80012 m .49136 .79739 L .48855 .79817 L F
.462 .249 .503 r
.54381 .70537 m .54581 .70702 L .54701 .70705 L F
.54381 .70537 m .54356 .70774 L .54581 .70702 L F
.598 .574 .798 r
.45501 .66039 m .4562 .66373 L .4585 .6632 L F
.956 .741 .571 r
.59919 .7239 m .60116 .72211 L .5995 .72145 L F
.59919 .7239 m .60049 .72454 L .60116 .72211 L F
.758 .561 .63 r
.53132 .76967 m .53192 .77214 L .52849 .77178 L F
.53 .507 .776 r
.53376 .76855 m .53132 .76967 L .53071 .76664 L F
.619 .475 .664 r
.53444 .77154 m .53132 .76967 L .53376 .76855 L F
.53444 .77154 m .53192 .77214 L .53132 .76967 L F
.422 .816 .985 r
.27574 .58515 m .27779 .58479 L .27945 .58533 L F
.112 .647 .861 r
.27779 .58479 m .28141 .58525 L .27945 .58533 L F
.654 .94 .685 r
.63958 .53287 m .63717 .53523 L .63838 .53366 L F
.57 .646 .886 r
.68422 .48556 m .68134 .48425 L .68375 .48386 L F
.41 .544 .879 r
.68561 .48391 m .68422 .48556 L .68375 .48386 L F
.518 .708 .957 r
.68561 .48391 m .68627 .48518 L .68422 .48556 L F
.773 .654 .732 r
.5167 .72383 m .51877 .7273 L .51879 .72479 L F
.683 .492 .621 r
.51879 .72479 m .51877 .7273 L .52219 .72702 L F
.706 .576 .707 r
.51191 .73703 m .51332 .73886 L .51558 .73569 L F
.458 .27 .536 r
.51253 .73731 m .51028 .73827 L .51044 .73765 L F
.44 .214 .472 r
.51264 .73529 m .51253 .73731 L .51044 .73765 L F
.91 .954 .617 r
.59083 .71358 m .58969 .71419 L .59055 .71273 L F
.59083 .71358 m .58946 .71632 L .58969 .71419 L F
0 .134 .68 r
.65794 .49994 m .65898 .50139 L .65736 .49812 L F
.721 .455 .523 r
.59366 .69579 m .59612 .69652 L .59608 .69421 L F
.782 .846 .9 r
.63106 .49175 m .62754 .49289 L .6297 .49248 L F
.439 .627 .933 r
.75003 .61427 m .75364 .61629 L .75266 .61388 L F
.589 .649 .878 r
.75266 .61388 m .75364 .61629 L .75593 .61576 L F
.506 .737 .977 r
.40443 .69767 m .40287 .69888 L .40159 .69674 L F
.40443 .69767 m .40516 .69869 L .40287 .69888 L F
0 .02 .593 r
.58674 .67955 m .58869 .68342 L .58869 .6805 L F
.593 .659 .884 r
.3265 .60419 m .32748 .60568 L .32903 .60474 L F
.963 .634 .27 r
.6676 .51802 m .66911 .52134 L .66787 .52039 L F
.992 .846 .486 r
.66807 .52267 m .66911 .52134 L .6687 .52352 L F
.974 .682 .404 r
.66787 .52039 m .66911 .52134 L .66807 .52267 L F
.66787 .52039 m .66911 .52134 L .66807 .52267 L F
.725 .696 .823 r
.55145 .76946 m .55084 .77216 L .54894 .7721 L F
.755 .51 .562 r
.55084 .77216 m .549 .77449 L .54894 .7721 L F
.55084 .77216 m .54995 .77485 L .549 .77449 L F
.457 .81 .997 r
.53591 .80284 m .5324 .80243 L .53483 .80369 L F
.521 .358 .601 r
.53806 .80244 m .53602 .80575 L .53591 .80284 L F
.107 0 0 r
.53806 .80244 m .53591 .80284 L .53483 .80369 L F
0 0 0 r
.40707 .66686 m .40572 .66773 L .40448 .66815 L F
.608 .085 0 r
.40707 .66686 m .40932 .66829 L .40572 .66773 L F
.584 .413 .616 r
.63218 .49902 m .6347 .50087 L .63497 .49852 L F
.63218 .49902 m .63236 .5014 L .6347 .50087 L F
.443 .309 .603 r
.46127 .7666 m .46309 .76613 L .46291 .76364 L F
.48 .333 .604 r
.46129 .76901 m .46309 .76613 L .46127 .7666 L F
.415 .086 .297 r
.35442 .61053 m .3575 .60841 L .35576 .6119 L F
.605 .413 .595 r
.35925 .60743 m .35912 .60783 L .3575 .60841 L F
.42 .059 .243 r
.3575 .60841 m .35779 .61129 L .35576 .6119 L F
.3575 .60841 m .35912 .60783 L .35779 .61129 L F
.663 .312 .367 r
.46687 .68575 m .4654 .68791 L .46347 .68757 L F
.637 .281 .351 r
.46904 .68756 m .4654 .68791 L .46687 .68575 L F
.319 .799 .739 r
.44133 .64822 m .44208 .64779 L .44346 .64821 L F
.44133 .64822 m .43989 .64863 L .44208 .64779 L F
.447 .357 .66 r
.36078 .60678 m .35908 .60566 L .36082 .60503 L F
.36078 .60678 m .35925 .60743 L .35908 .60566 L F
0 0 .34 r
.67387 .50615 m .6738 .5061 L .67297 .5043 L F
.852 .412 0 r
.67262 .50504 m .67387 .50615 L .67297 .5043 L F
.5 0 0 r
.67262 .50504 m .67394 .5062 L .67387 .50615 L F
.67394 .5062 m .67599 .508 L .67387 .50615 L F
0 0 .34 r
.67387 .50615 m .67437 .50734 L .6738 .5061 L F
0 .014 .52 r
.67599 .508 m .67437 .50734 L .67387 .50615 L F
.67599 .508 m .67507 .50958 L .67437 .50734 L F
.604 .673 .889 r
.25869 .65163 m .26218 .65309 L .26094 .65094 L F
.435 .582 .901 r
.26094 .65094 m .26218 .65309 L .26258 .6508 L F
.58 .724 .942 r
.26258 .6508 m .26218 .65309 L .26402 .65234 L F
.525 .308 .527 r
.53211 .80486 m .5324 .80243 L .53011 .80285 L F
.264 .769 .757 r
.4113 .69738 m .41164 .69708 L .41333 .69687 L F
.4113 .69738 m .40928 .69778 L .41164 .69708 L F
.7 .291 .268 r
.55058 .73574 m .55331 .73586 L .55045 .73792 L F
.55058 .73574 m .55168 .7376 L .55331 .73586 L F
.851 .468 0 r
.55331 .73586 m .55275 .73552 L .55176 .73293 L F
.935 .951 .626 r
.55331 .73586 m .55168 .7376 L .55275 .73552 L F
.725 .974 .925 r
.58538 .72099 m .58513 .71997 L .58675 .71833 L F
.822 .792 .824 r
.58892 .71812 m .58571 .72032 L .58617 .71939 L F
.837 .926 .891 r
.58568 .71941 m .58892 .71812 L .58675 .71833 L F
.58531 .71979 m .58617 .71939 L .58568 .71941 L F
.58617 .71939 m .58892 .71812 L .58568 .71941 L F
.185 .047 .448 r
.58571 .72032 m .58736 .71973 L .58726 .71934 L F
.822 .792 .824 r
.58892 .71812 m .58617 .71939 L .58688 .71794 L F
.837 .926 .891 r
.58513 .71997 m .58892 .71812 L .58531 .71979 L F
.58633 .71938 m .58571 .72032 L .58892 .71812 L F
.58513 .71997 m .58571 .72032 L .58633 .71938 L F
.185 .047 .448 r
.58617 .71939 m .58633 .71938 L .58688 .71794 L F
.58633 .71938 m .58726 .71934 L .587 .71838 L F
.58633 .71938 m .587 .71838 L .58688 .71794 L F
.58571 .72032 m .58726 .71934 L .58617 .71939 L F
.987 .798 .562 r
.58513 .71997 m .58494 .72017 L .58571 .72032 L F
.342 .808 .923 r
.58497 .72017 m .58736 .71973 L .58571 .72032 L F
.967 .728 .524 r
.5849 .71755 m .58513 .71997 L .58448 .72146 L F
.342 .808 .923 r
.58494 .72017 m .58497 .72016 L .58497 .72017 L F
.58497 .72016 m .58736 .71973 L .58497 .72017 L F
.725 .974 .925 r
.58486 .72201 m .58507 .72038 L .58538 .72099 L F
.58507 .72038 m .58513 .71997 L .58538 .72099 L F
.58486 .72201 m .58448 .72146 L .58513 .71997 L F
.762 .529 .58 r
.58856 .7245 m .58496 .72459 L .58486 .72201 L F
.882 .656 .591 r
.66631 .51508 m .66363 .51193 L .66538 .51286 L F
.031 0 0 r
.53253 .80769 m .53398 .80645 L .53602 .80575 L F
.626 .822 .976 r
.44214 .65904 m .44634 .6599 L .44502 .65844 L F
.066 0 0 r
.44841 .65769 m .44502 .65844 L .44634 .6599 L F
.733 .799 .905 r
.44634 .6599 m .44937 .65846 L .44841 .65769 L F
.361 .703 .985 r
.31301 .59015 m .3125 .59128 L .31104 .59037 L F
.31301 .59015 m .31452 .59125 L .3125 .59128 L F
.726 .626 .746 r
.62516 .49568 m .62896 .49704 L .62754 .49289 L F
.835 .592 .571 r
.62516 .49568 m .62822 .49886 L .62896 .49704 L F
.601 .556 .775 r
.62754 .49289 m .62896 .49704 L .63103 .49597 L F
.614 .357 .505 r
.71092 .50188 m .71126 .504 L .70849 .50314 L F
.815 .593 .601 r
.54653 .76342 m .54934 .76467 L .55028 .76378 L F
.854 .991 .734 r
.55028 .76378 m .54775 .76593 L .54653 .76342 L F
.55028 .76378 m .54803 .76649 L .54775 .76593 L F
.323 .473 .855 r
.5538 .76648 m .55028 .76378 L .55234 .7631 L F
.535 .637 .898 r
.74902 .60108 m .74832 .60416 L .7468 .60135 L F
.74902 .60108 m .75061 .60376 L .74832 .60416 L F
.531 .737 .97 r
.68266 .48241 m .68134 .48425 L .68014 .4829 L F
.68266 .48241 m .68375 .48386 L .68134 .48425 L F
.715 .59 .714 r
.51558 .73569 m .51332 .73886 L .51264 .73529 L F
.844 .5 .403 r
.5155 .74062 m .51253 .73731 L .51332 .73886 L F
0 0 0 r
.52747 .77803 m .52635 .77829 L .52342 .77881 L F
.645 .548 .73 r
.52988 .7751 m .52747 .77803 L .52675 .77473 L F
0 0 .543 r
.52747 .77803 m .52868 .7788 L .52635 .77829 L F
.682 .296 .308 r
.53048 .77897 m .52822 .77935 L .52747 .77803 L F
0 0 .543 r
.52747 .77803 m .52822 .77935 L .52868 .7788 L F
.689 .613 .766 r
.52997 .7772 m .52747 .77803 L .52988 .7751 L F
.682 .296 .308 r
.53048 .77897 m .52747 .77803 L .52997 .7772 L F
.831 .36 0 r
.54812 .71389 m .54679 .71315 L .54518 .71054 L F
.921 .528 .208 r
.54812 .71389 m .54735 .715 L .54679 .71315 L F
.745 .253 .068 r
.54812 .71389 m .55037 .71596 L .54735 .715 L F
.625 .46 .638 r
.55234 .7631 m .55632 .76378 L .5538 .76648 L F
0 .171 .709 r
.54518 .71054 m .5456 .70956 L .54356 .70774 L F
.758 .293 0 r
.54518 .71054 m .54679 .71315 L .5457 .71212 L F
.54518 .71054 m .5457 .71212 L .5456 .70956 L F
0 0 .048 r
.63585 .48999 m .63603 .49273 L .63602 .49268 L F
.399 .382 .725 r
.6332 .49057 m .63603 .49273 L .63585 .48999 L F
.362 .705 .985 r
.77415 .57895 m .77245 .57917 L .77114 .57777 L F
.835 .592 .571 r
.62516 .49568 m .6255 .49876 L .62822 .49886 L F
.976 .819 .622 r
.62613 .50071 m .62822 .49886 L .6255 .49876 L F
.62613 .50071 m .62725 .50175 L .62822 .49886 L F
.394 .465 .815 r
.47552 .65186 m .47472 .65478 L .47334 .65275 L F
.47552 .65186 m .47649 .65472 L .47472 .65478 L F
.354 0 .054 r
.43949 .69649 m .43591 .69856 L .43728 .69673 L F
.963 .67 .426 r
.59823 .71504 m .59997 .71854 L .59974 .71599 L F
.784 .558 .594 r
.54992 .75198 m .55357 .75244 L .55337 .74988 L F
.54992 .75198 m .55337 .74988 L .55344 .75174 L F
.515 .286 .505 r
.55645 .7474 m .55563 .74949 L .55337 .74988 L F
.81 .996 .769 r
.55357 .75244 m .55344 .75174 L .55337 .74988 L F
.519 .23 .416 r
.28227 .60771 m .28089 .61032 L .2785 .61047 L F
.257 0 .257 r
.28269 .60943 m .28227 .60771 L .28419 .60724 L F
.28269 .60943 m .28089 .61032 L .28227 .60771 L F
.649 .8 .955 r
.77158 .5916 m .77414 .58968 L .7701 .58907 L F
.77158 .5916 m .77326 .59097 L .77414 .58968 L F
.564 .42 .643 r
.77158 .5916 m .77416 .5931 L .77326 .59097 L F
.526 .437 .697 r
.77158 .5916 m .77197 .59381 L .77416 .5931 L F
.447 .289 .573 r
.36418 .66976 m .3664 .67068 L .36643 .66822 L F
.36418 .66976 m .36414 .67195 L .3664 .67068 L F
.592 .757 .957 r
.55282 .77688 m .5538 .77823 L .55608 .77761 L F
.08 0 .129 r
.51238 .76059 m .51146 .76302 L .51361 .76098 L F
.858 .968 .645 r
.51361 .76098 m .51251 .7619 L .51307 .76097 L F
.08 0 .129 r
.51238 .76059 m .51361 .76098 L .51425 .76098 L F
.858 .968 .645 r
.51361 .76098 m .51307 .76097 L .51437 .7588 L F
.08 0 .129 r
.51425 .76098 m .51361 .76098 L .51527 .7612 L F
.473 .33 .605 r
.39197 .67971 m .39017 .68275 L .38999 .68026 L F
.5 .262 .485 r
.31874 .62361 m .32138 .6212 L .31905 .62174 L F
.389 0 0 r
.51918 .74157 m .5155 .74062 L .51668 .74166 L F
.989 .747 .47 r
.65507 .52151 m .65457 .52363 L .65629 .52035 L F
.397 .179 .461 r
.26909 .61869 m .26864 .62112 L .26686 .62169 L F
.488 .322 .581 r
.26883 .62379 m .26686 .62169 L .26864 .62112 L F
.26883 .62379 m .26681 .62432 L .26686 .62169 L F
.6 .83 .987 r
.27906 .63673 m .27545 .63653 L .27755 .63577 L F
.639 .841 .978 r
.28102 .63591 m .27906 .63673 L .27755 .63577 L F
.76 .6 .679 r
.59514 .57379 m .59319 .57396 L .59553 .5713 L F
.726 .318 .274 r
.54939 .70773 m .55291 .70935 L .55232 .70865 L F
.144 .663 .886 r
.4263 .64915 m .42846 .64923 L .4298 .64965 L F
.191 .707 .884 r
.42846 .64923 m .43196 .64943 L .4298 .64965 L F
.076 0 0 r
.5006 .74318 m .49855 .74394 L .50017 .74252 L F
.781 .548 .584 r
.49357 .8084 m .49018 .81022 L .49037 .8081 L F
.49357 .8084 m .49367 .81078 L .49018 .81022 L F
.416 .813 .984 r
.49448 .80761 m .49587 .80811 L .49357 .8084 L F
.571 .384 .589 r
.49357 .8084 m .49587 .80811 L .49367 .81078 L F
.733 .973 .723 r
.56458 .78203 m .56817 .77885 L .56759 .7802 L F
0 0 0 r
.56969 .77695 m .56759 .7802 L .56817 .77885 L F
.456 .406 .714 r
.74628 .59913 m .74487 .60165 L .74408 .59979 L F
.74628 .59913 m .7468 .60135 L .74487 .60165 L F
.095 .239 .723 r
.5506 .69686 m .55258 .69877 L .55275 .6965 L F
.45 .23 .488 r
.76967 .59644 m .77185 .59592 L .77197 .59381 L F
.663 .588 .761 r
.7705 .59953 m .77185 .59592 L .76967 .59644 L F
.737 .64 .751 r
.62343 .52662 m .62679 .52718 L .62568 .52381 L F
.645 .588 .776 r
.62568 .52381 m .62679 .52718 L .62914 .52653 L F
.615 .942 .744 r
.64414 .53109 m .64695 .52928 L .64797 .53168 L F
.707 .609 .745 r
.6498 .52694 m .64695 .52928 L .64686 .52672 L F
.682 .65 .812 r
.48658 .79788 m .48898 .80012 L .48736 .7974 L F
.991 .853 .604 r
.48744 .80224 m .48898 .80012 L .48658 .79788 L F
.48744 .80224 m .48866 .80214 L .48898 .80012 L F
.883 .901 .837 r
.48898 .80012 m .48855 .79817 L .48736 .7974 L F
.553 .081 .09 r
.495 .75123 m .49732 .75167 L .4948 .75052 L F
.142 0 0 r
.44294 .68313 m .44365 .68416 L .44509 .68269 L F
.44294 .68313 m .44182 .68482 L .44365 .68416 L F
.771 .674 .756 r
.49587 .80811 m .4971 .81102 L .49367 .81078 L F
.723 .35 .342 r
.49367 .81078 m .4971 .81102 L .49591 .81305 L F
.827 .697 .72 r
.49721 .80849 m .4971 .81102 L .49587 .80811 L F
.831 .414 .249 r
.49721 .80849 m .50004 .81124 L .4971 .81102 L F
.589 .25 .362 r
.4971 .81102 m .50004 .81124 L .50008 .81219 L F
0 .457 .86 r
.4971 .81102 m .50008 .81219 L .49804 .81084 L F
.4971 .81102 m .49804 .81084 L .49591 .81305 L F
.651 .497 .662 r
.51656 .77998 m .51728 .7831 L .51398 .78382 L F
.628 .568 .768 r
.51835 .7799 m .51728 .7831 L .51656 .77998 L F
.674 .606 .772 r
.48602 .6688 m .48368 .66934 L .48253 .66623 L F
.491 .268 .502 r
.27114 .61812 m .26864 .62112 L .26909 .61869 L F
.691 .223 .136 r
.52273 .75766 m .5248 .75937 L .52617 .75827 L F
.433 .029 .171 r
.5248 .75937 m .52814 .75728 L .52617 .75827 L F
.007 .172 .686 r
.68403 .53134 m .68279 .53224 L .68175 .52897 L F
0 .12 .642 r
.68392 .53268 m .68279 .53224 L .68403 .53134 L F
.348 0 .142 r
.48759 .74649 m .49055 .74429 L .48827 .74455 L F
.601 .607 .83 r
.40159 .69674 m .39962 .69741 L .39824 .69429 L F
.103 0 0 r
.69254 .53769 m .68967 .53951 L .69035 .53863 L F
.327 0 0 r
.39979 .65094 m .40206 .65097 L .40356 .65006 L F
.505 0 0 r
.40356 .65006 m .40206 .65097 L .40546 .65105 L F
.563 .375 .585 r
.67109 .50454 m .67069 .5014 L .66996 .50377 L F
.531 0 0 r
.66996 .50377 m .67297 .5043 L .67109 .50454 L F
.595 .647 .872 r
.46397 .64924 m .46177 .64974 L .46022 .64731 L F
.453 .799 .998 r
.30394 .66547 m .30582 .66641 L .30185 .66585 L F
.30185 .66585 m .30582 .66641 L .30394 .66547 L F
.584 .851 .995 r
.30613 .6649 m .30582 .66641 L .30394 .66547 L F
.30394 .66547 m .30582 .66641 L .30613 .6649 L F
.872 .58 .49 r
.66029 .52544 m .66315 .52415 L .66173 .52217 L F
.66029 .52544 m .66401 .52663 L .66315 .52415 L F
.651 .195 .156 r
.50004 .81124 m .5029 .80882 L .49982 .8082 L F
.50004 .81124 m .50268 .81137 L .5029 .80882 L F
.696 .625 .774 r
.48609 .78774 m .48419 .79058 L .48327 .78858 L F
.923 .765 .667 r
.61354 .54045 m .61254 .54322 L .61392 .54367 L F
.93 .726 .605 r
.61254 .54322 m .6137 .54634 L .61392 .54367 L F
.767 .573 .636 r
.61392 .54367 m .6137 .54634 L .61557 .54594 L F
.806 .577 .592 r
.49927 .79451 m .4959 .79175 L .4958 .79377 L F
.591 .58 .809 r
.39824 .69429 m .39583 .69502 L .39548 .6929 L F
.705 .344 .361 r
.49525 .77832 m .49419 .78015 L .49215 .77949 L F
.583 .205 .291 r
.49525 .77832 m .49773 .77959 L .49419 .78015 L F
.221 .594 .948 r
.30424 .58839 m .30298 .58897 L .30183 .58823 L F
.30424 .58839 m .30554 .5896 L .30298 .58897 L F
.726 .423 .466 r
.58885 .73846 m .59091 .74076 L .59072 .73798 L F
.47 .312 .584 r
.59072 .73798 m .59323 .73543 L .59091 .73586 L F
.59072 .73798 m .59348 .73809 L .59323 .73543 L F
.462 .226 .47 r
.59072 .73798 m .59091 .74076 L .59348 .73809 L F
.871 .728 .701 r
.6042 .73311 m .6048 .7307 L .60315 .72958 L F
.316 0 .089 r
.24711 .59272 m .25057 .59033 L .24849 .59076 L F
.304 0 0 r
.48165 .78796 m .48509 .78643 L .48327 .78858 L F
.636 .538 .727 r
.48609 .78774 m .48327 .78858 L .48509 .78643 L F
.508 .892 .96 r
.45825 .64735 m .45934 .64633 L .46022 .64731 L F
.45825 .64735 m .45722 .6471 L .45934 .64633 L F
.703 .342 .36 r
.58856 .7245 m .58803 .72695 L .58496 .72459 L F
.575 .542 .781 r
.58889 .72733 m .58982 .72479 L .58856 .7245 L F
.58889 .72733 m .59076 .72843 L .58982 .72479 L F
.127 0 .191 r
.58975 .72579 m .58856 .7245 L .58982 .72479 L F
.58975 .72579 m .58803 .72695 L .58856 .7245 L F
.383 .777 .987 r
.38304 .72769 m .38152 .72699 L .37936 .7272 L F
.881 .882 .83 r
.38395 .72406 m .38152 .72699 L .38304 .72769 L F
.573 .475 .705 r
.59091 .73586 m .59323 .73543 L .5919 .73353 L F
.888 .84 .792 r
.59677 .53755 m .59903 .53739 L .59782 .5384 L F
.59677 .53755 m .59867 .53444 L .59903 .53739 L F
.836 .808 .824 r
.59867 .53444 m .60141 .53449 L .59903 .53739 L F
0 0 .285 r
.57756 .68409 m .57672 .68395 L .57835 .6818 L F
.106 0 0 r
.58104 .68045 m .57969 .68209 L .57835 .6818 L F
.354 .025 .262 r
.57969 .68209 m .57756 .68409 L .57835 .6818 L F
.277 0 .088 r
.40743 .70971 m .40663 .7105 L .40489 .71031 L F
.287 0 0 r
.40663 .7105 m .40395 .71154 L .40489 .71031 L F
.327 .791 .938 r
.29805 .63604 m .29977 .6356 L .30187 .63611 L F
.579 .912 .974 r
.30187 .63611 m .30129 .63473 L .30404 .63564 L F
.30187 .63611 m .29977 .6356 L .30129 .63473 L F
.716 .365 .383 r
.64287 .50143 m .64021 .50353 L .63795 .50122 L F
.763 .436 .434 r
.64392 .50304 m .64287 .50143 L .6434 .50226 L F
.555 .404 .631 r
.64199 .50403 m .64453 .50635 L .64392 .50304 L F
.64199 .50403 m .64215 .50705 L .64453 .50635 L F
.533 .137 .237 r
.51028 .73827 m .5087 .74058 L .50629 .74066 L F
.453 .051 .187 r
.51219 .73944 m .51028 .73827 L .51253 .73731 L F
.51219 .73944 m .5087 .74058 L .51028 .73827 L F
.687 .57 .718 r
.45636 .67733 m .45907 .67743 L .45875 .67512 L F
.656 .411 .537 r
.45617 .67905 m .45866 .67955 L .45636 .67733 L F
.673 .408 .512 r
.45636 .67733 m .45866 .67955 L .45907 .67743 L F
.609 .919 .976 r
.30393 .65067 m .3079 .65021 L .30593 .65051 L F
0 0 0 r
.3079 .65021 m .30802 .65028 L .30593 .65051 L F
.3079 .65021 m .30998 .64974 L .30802 .65028 L F
.217 0 0 r
.31078 .64912 m .30998 .64974 L .3079 .65021 L F
.718 .565 .681 r
.61557 .54594 m .61694 .54883 L .61908 .54627 L F
.647 .463 .621 r
.61694 .54883 m .61947 .54899 L .61908 .54627 L F
.542 .389 .624 r
.61908 .54627 m .62168 .54832 L .62181 .54578 L F
.61908 .54627 m .61947 .54899 L .62168 .54832 L F
.554 .542 .795 r
.58633 .74151 m .58869 .74148 L .58746 .73795 L F
.555 .446 .685 r
.72718 .60213 m .72917 .59835 L .7268 .60003 L F
.427 .153 .393 r
.70214 .52656 m .70195 .52905 L .69939 .52898 L F
.205 0 .141 r
.70452 .52621 m .70195 .52905 L .70214 .52656 L F
.426 .54 .869 r
.75252 .60381 m .75106 .60553 L .75061 .60376 L F
.496 .646 .924 r
.75252 .60381 m .75341 .60549 L .75106 .60553 L F
.507 .383 .646 r
.3626 .6747 m .36462 .67433 L .36414 .67195 L F
.567 .502 .741 r
.36309 .67707 m .36462 .67433 L .3626 .6747 L F
.606 .656 .873 r
.76005 .60875 m .75816 .61083 L .75663 .60766 L F
.76005 .60875 m .76056 .61026 L .75816 .61083 L F
.993 .752 .394 r
.51372 .73003 m .51303 .72963 L .51335 .7278 L F
.9 .897 .816 r
.51372 .73003 m .51089 .73212 L .51303 .72963 L F
.804 .857 .889 r
.64797 .53168 m .65085 .53144 L .64966 .53067 L F
.526 .757 .981 r
.65085 .53144 m .65215 .53 L .64966 .53067 L F
.65085 .53144 m .65335 .53114 L .65215 .53 L F
.606 .367 .529 r
.3698 .71035 m .37215 .71012 L .37012 .70808 L F
.3698 .71035 m .37215 .71012 L .37012 .70808 L F
.591 .02 0 r
.36827 .70781 m .37215 .71012 L .37012 .70808 L F
.682 .576 .73 r
.37012 .70808 m .37274 .70833 L .37194 .70573 L F
.67 .358 .438 r
.37012 .70808 m .37215 .71012 L .37274 .70833 L F
.779 .67 .744 r
.49678 .78581 m .49806 .78917 L .50025 .78622 L F
.038 .487 .884 r
.58193 .67629 m .58214 .67714 L .58038 .67575 L F
.641 .563 .752 r
.52849 .77178 m .52675 .77473 L .52617 .77219 L F
.52849 .77178 m .52988 .7751 L .52675 .77473 L F
.3 .784 .714 r
.76028 .58215 m .75799 .58304 L .75658 .58347 L F
.379 .678 .976 r
.3429 .59341 m .34202 .59456 L .34075 .5935 L F
.3429 .59341 m .34475 .5949 L .34202 .59456 L F
.685 .215 .13 r
.51198 .78325 m .51398 .78382 L .51378 .7852 L F
.735 .441 .483 r
.51728 .7831 m .51432 .78487 L .51398 .78382 L F
.51728 .7831 m .51621 .78551 L .51378 .7852 L F
.57 .564 .807 r
.51244 .78254 m .51466 .78485 L .51485 .78207 L F
.51466 .78485 m .51473 .78492 L .51473 .78484 L F
.51466 .78485 m .51473 .78484 L .51485 .78207 L F
.735 .441 .483 r
.51432 .78487 m .51378 .7852 L .51382 .78491 L F
.51432 .78487 m .51382 .78491 L .51398 .78382 L F
.662 .717 .889 r
.47857 .77917 m .48079 .77788 L .48162 .7789 L F
.643 .44 .593 r
.48162 .7789 m .47834 .78279 L .47857 .77917 L F
.704 .775 .907 r
.60161 .74561 m .60518 .74502 L .60357 .74377 L F
.67 .92 .975 r
.75607 .58859 m .75903 .58817 L .75814 .58743 L F
.659 .9 .981 r
.75814 .58743 m .75903 .58817 L .7613 .58716 L F
.766 .735 .824 r
.63714 .53898 m .64077 .53823 L .64023 .53846 L F
.65 .594 .778 r
.64219 .53352 m .644 .53832 L .64077 .53823 L F
.822 .554 .534 r
.644 .53832 m .64312 .5399 L .64243 .53837 L F
.644 .53832 m .64243 .53837 L .64206 .53754 L F
.916 .892 .791 r
.64206 .53754 m .63915 .53761 L .64023 .53846 L F
.881 .675 .619 r
.64206 .53754 m .64102 .53842 L .63915 .53761 L F
.64102 .53842 m .63817 .54081 L .63884 .53862 L F
.822 .554 .534 r
.64095 .53843 m .64023 .53846 L .64026 .53845 L F
.64078 .53844 m .64023 .53846 L .64095 .53843 L F
0 .159 .611 r
.64023 .53846 m .63697 .53608 L .63714 .53898 L F
.881 .675 .619 r
.64102 .53842 m .63884 .53862 L .63915 .53761 L F
.64102 .53842 m .6398 .54174 L .63817 .54081 L F
.822 .554 .534 r
.64324 .5383 m .64142 .53839 L .64077 .53823 L F
.64142 .53839 m .64026 .53845 L .64036 .53841 L F
.64142 .53839 m .64036 .53841 L .64077 .53823 L F
.866 .948 .866 r
.64312 .5399 m .6398 .54174 L .64161 .53839 L F
.64243 .53837 m .64161 .53839 L .64206 .53754 L F
.64312 .5399 m .64161 .53839 L .64243 .53837 L F
.822 .554 .534 r
.64084 .53843 m .64026 .53845 L .64324 .5383 L F
.881 .675 .619 r
.64206 .53754 m .64161 .53839 L .64102 .53842 L F
.64161 .53839 m .6398 .54174 L .64102 .53842 L F
.822 .554 .534 r
.644 .53832 m .64084 .53843 L .64324 .5383 L F
.644 .53832 m .64078 .53844 L .64095 .53843 L F
.638 .524 .708 r
.68718 .51508 m .69044 .51728 L .6912 .51567 L F
.68718 .51508 m .68853 .51841 L .69044 .51728 L F
.784 .735 .808 r
.61789 .52901 m .6155 .53174 L .61854 .53165 L F
.749 .715 .82 r
.61789 .52901 m .61854 .53165 L .62143 .52973 L F
.53 .487 .753 r
.36489 .68586 m .36567 .68832 L .36751 .68787 L F
.49 .853 .989 r
.62084 .50843 m .61931 .50954 L .62201 .50621 L F
.62084 .50843 m .61865 .50888 L .61931 .50954 L F
.222 .297 .73 r
.62084 .50843 m .61931 .50954 L .61865 .50888 L F
.663 .427 .551 r
.61931 .50954 m .62221 .51334 L .6239 .51215 L F
.222 .297 .73 r
.62084 .50843 m .62221 .51334 L .61931 .50954 L F
.809 .639 .671 r
.59385 .55177 m .59055 .55347 L .5909 .55118 L F
.59385 .55177 m .59254 .5547 L .59055 .55347 L F
.805 .751 .803 r
.35193 .70521 m .34939 .70845 L .35137 .70585 L F
.501 .321 .569 r
.34939 .70845 m .35173 .70842 L .35137 .70585 L F
.507 .307 .543 r
.77185 .59592 m .77416 .5931 L .77197 .59381 L F
.925 .852 .751 r
.59558 .53938 m .59688 .54045 L .59523 .54337 L F
.917 .874 .779 r
.59677 .53755 m .59688 .54045 L .59558 .53938 L F
.59677 .53755 m .59782 .5384 L .59688 .54045 L F
.616 .691 .897 r
.69499 .49503 m .69624 .49201 L .69413 .49317 L F
.69499 .49503 m .69737 .49443 L .69624 .49201 L F
.607 .576 .794 r
.69499 .49503 m .69816 .49609 L .69737 .49443 L F
.554 .494 .742 r
.69499 .49503 m .69818 .49843 L .69816 .49609 L F
.69499 .49503 m .6972 .49981 L .69818 .49843 L F
.101 .652 .811 r
.68184 .54101 m .68333 .54074 L .68093 .5407 L F
.68184 .54101 m .68422 .54099 L .68333 .54074 L F
.704 .775 .907 r
.60161 .74561 m .60357 .74377 L .60107 .74466 L F
.492 .657 .934 r
.35487 .59939 m .35189 .59808 L .35405 .59794 L F
.27 .511 .901 r
.35552 .59802 m .35487 .59939 L .35405 .59794 L F
.508 .793 .997 r
.35552 .59802 m .35703 .59901 L .35487 .59939 L F
.158 0 0 r
.43442 .66019 m .43084 .66145 L .43219 .66047 L F
.599 .532 .751 r
.72764 .60461 m .72951 .60171 L .72718 .60213 L F
.72764 .60461 m .73027 .60527 L .72951 .60171 L F
.879 .903 .843 r
.64767 .53423 m .64877 .53747 L .64862 .53516 L F
.576 .481 .71 r
.26737 .62647 m .26896 .63066 L .26596 .63057 L F
.575 .438 .657 r
.26896 .63066 m .26616 .63292 L .26596 .63057 L F
.716 .29 0 r
.62035 .50385 m .62109 .50505 L .62201 .50621 L F
.49 .853 .989 r
.62084 .50843 m .62201 .50621 L .62109 .50505 L F
.735 .529 .613 r
.62363 .50322 m .62201 .50621 L .6242 .50394 L F
.62363 .50322 m .62035 .50385 L .62201 .50621 L F
.381 0 .115 r
.4324 .68772 m .43185 .68853 L .43456 .68742 L F
.211 .025 .396 r
.36044 .60934 m .35925 .60743 L .36078 .60678 L F
.36044 .60934 m .35912 .60783 L .35925 .60743 L F
.258 .1 .467 r
.7013 .53048 m .69939 .52898 L .70195 .52905 L F
.7013 .53048 m .69929 .53083 L .69939 .52898 L F
.874 .835 .805 r
.61711 .50442 m .6154 .50403 L .61731 .50149 L F
.916 .661 .537 r
.61711 .50442 m .61738 .50684 L .6154 .50403 L F
.807 .46 .4 r
.60038 .72962 m .60254 .72797 L .60016 .72675 L F
.60038 .72962 m .60315 .72958 L .60254 .72797 L F
.728 .346 .327 r
.54812 .70204 m .55107 .70315 L .54947 .7052 L F
.805 .32 0 r
.56959 .74596 m .57164 .74773 L .57139 .74699 L F
.56959 .74596 m .57138 .74857 L .57164 .74773 L F
.953 .666 .222 r
.57137 .75105 m .57164 .74773 L .57138 .74857 L F
.57137 .75105 m .57214 .75204 L .57164 .74773 L F
.954 .655 .428 r
.57164 .74773 m .57214 .75204 L .57345 .75245 L F
.468 .208 .436 r
.3143 .62722 m .31633 .62668 L .3171 .62461 L F
.589 .409 .606 r
.31633 .62668 m .31874 .62361 L .3171 .62461 L F
.712 .46 .543 r
.54894 .7721 m .549 .77449 L .54779 .77401 L F
.384 0 .027 r
.31279 .64883 m .30998 .64974 L .31078 .64912 L F
.321 0 0 r
.41332 .70754 m .41176 .7091 L .41035 .70859 L F
.264 0 0 r
.4139 .7087 m .41332 .70754 L .4154 .7071 L F
.4139 .7087 m .41176 .7091 L .41332 .70754 L F
.709 .61 .745 r
.70425 .50119 m .70747 .50251 L .70678 .49782 L F
.727 .829 .928 r
.70746 .50253 m .70849 .50314 L .70834 .50223 L F
.70553 .50318 m .70712 .50316 L .70746 .50253 L F
.70712 .50316 m .70849 .50314 L .70746 .50253 L F
.709 .61 .745 r
.70747 .50251 m .70785 .50267 L .70779 .50241 L F
.70747 .50251 m .70779 .50241 L .70678 .49782 L F
.304 .334 .728 r
.70678 .49782 m .70772 .50208 L .70905 .49964 L F
.70772 .50208 m .70779 .50241 L .70822 .50146 L F
.70772 .50208 m .70822 .50146 L .70905 .49964 L F
.479 .549 .85 r
.70849 .50314 m .71021 .50176 L .70839 .50126 L F
.70822 .50146 m .70839 .50126 L .70818 .5012 L F
.70849 .50314 m .70839 .50126 L .70822 .50146 L F
.595 .666 .888 r
.70818 .5012 m .70747 .50251 L .70425 .50119 L F
.727 .829 .928 r
.70562 .50311 m .70747 .50251 L .70818 .5012 L F
.70747 .50251 m .70779 .50241 L .70818 .5012 L F
.70779 .50241 m .70834 .50223 L .70822 .50146 L F
.70779 .50241 m .70822 .50146 L .70818 .5012 L F
.70553 .50318 m .70834 .50223 L .70562 .50311 L F
.304 .334 .728 r
.70779 .50241 m .70785 .50267 L .70844 .50118 L F
.70839 .50109 m .70844 .50118 L .70905 .49964 L F
.70779 .50241 m .70844 .50118 L .70839 .50109 L F
.617 .492 .687 r
.70882 .50197 m .70732 .50544 L .70818 .5012 L F
.479 .549 .85 r
.70849 .50314 m .71126 .504 L .71021 .50176 L F
.617 .492 .687 r
.71052 .50402 m .70994 .50427 L .70882 .50197 L F
.70994 .50427 m .70732 .50544 L .70882 .50197 L F
.51 .58 .862 r
.70922 .49978 m .70818 .5012 L .70839 .50126 L F
.70922 .49978 m .70839 .50126 L .71021 .50176 L F
.304 .334 .728 r
.70905 .49964 m .70846 .50114 L .70922 .49978 L F
.70846 .50114 m .70831 .5015 L .70922 .49978 L F
.70831 .5015 m .70785 .50267 L .70838 .50156 L F
.70831 .5015 m .70838 .50156 L .70922 .49978 L F
.51 .58 .862 r
.70922 .49978 m .70785 .50267 L .70818 .5012 L F
.937 .964 .742 r
.70855 .50099 m .7082 .49896 L .70922 .49978 L F
.617 .492 .687 r
.70882 .50197 m .70818 .5012 L .70998 .50302 L F
.595 .666 .888 r
.70818 .5012 m .70785 .50267 L .70747 .50251 L F
.70818 .5012 m .70425 .50119 L .70553 .50318 L F
.997 .77 .441 r
.70436 .50414 m .70553 .50318 L .70399 .5054 L F
.70466 .50312 m .70538 .50317 L .70454 .50397 L F
.70538 .50317 m .70553 .50318 L .70436 .50414 L F
.702 .635 .779 r
.70216 .50156 m .70553 .50318 L .70425 .50119 L F
.997 .77 .441 r
.70538 .50317 m .70551 .5063 L .70553 .50318 L F
.70466 .50312 m .70501 .50445 L .70538 .50317 L F
.70501 .50445 m .70551 .5063 L .70538 .50317 L F
.9 .909 .821 r
.70312 .50538 m .70218 .50557 L .70399 .5054 L F
.664 .179 .089 r
.70312 .50538 m .70551 .5063 L .70218 .50557 L F
.48 .853 .625 r
.70551 .5063 m .70247 .50857 L .70218 .50557 L F
.685 .655 .814 r
.70732 .50544 m .70551 .5063 L .70513 .50488 L F
.70732 .50544 m .70513 .50488 L .7053 .50457 L F
.70732 .50544 m .70501 .50445 L .70538 .50433 L F
.70596 .50426 m .70549 .50432 L .70587 .50418 L F
.70549 .50432 m .70547 .5043 L .70587 .50418 L F
.70732 .50544 m .70563 .50397 L .70818 .5012 L F
.70563 .50397 m .70466 .50312 L .70603 .50238 L F
.70563 .50397 m .70603 .50238 L .70818 .5012 L F
.70732 .50544 m .70538 .50433 L .70596 .50426 L F
.711 .761 .892 r
.70551 .5063 m .70888 .50676 L .70732 .50544 L F
.70551 .5063 m .70888 .50676 L .70732 .50544 L F
.485 .007 .044 r
.70732 .50544 m .70577 .50624 L .70551 .5063 L F
.48 .853 .625 r
.70551 .5063 m .70485 .5067 L .70247 .50857 L F
.70485 .5067 m .70451 .5069 L .70373 .50754 L F
.70485 .5067 m .70373 .50754 L .70247 .50857 L F
.781 .691 .765 r
.70247 .50857 m .7 .50855 L .70218 .50557 L F
.196 0 0 r
.70247 .50857 m .70284 .50881 L .7 .50855 L F
.553 .375 .594 r
.7 .50855 m .70214 .50874 L .70218 .50557 L F
0 0 0 r
.70451 .5069 m .70284 .50881 L .70247 .50857 L F
.553 .375 .594 r
.70214 .50874 m .70284 .50881 L .70274 .50829 L F
.70214 .50874 m .70274 .50829 L .70218 .50557 L F
.485 .007 .044 r
.70577 .50624 m .70451 .5069 L .70515 .50652 L F
.70577 .50624 m .70515 .50652 L .70551 .5063 L F
.979 .688 .32 r
.7064 .50597 m .70684 .50473 L .70554 .50431 L F
.485 .007 .044 r
.70549 .50639 m .70694 .50702 L .70451 .5069 L F
.70732 .50544 m .70694 .50702 L .70549 .50639 L F
0 .311 .802 r
.70888 .50676 m .70928 .50704 L .70999 .50677 L F
.70928 .50704 m .71134 .5085 L .70999 .50677 L F
.59 .561 .789 r
.71134 .5085 m .71228 .50489 L .70999 .50677 L F
0 0 0 r
.71183 .50592 m .71099 .50637 L .70999 .50677 L F
.71099 .50637 m .70841 .50778 L .70999 .50677 L F
.59 .083 .016 r
.70999 .50677 m .70841 .50778 L .70694 .50702 L F
.998 .788 .443 r
.70813 .50754 m .70694 .50702 L .70841 .50778 L F
.979 .688 .32 r
.70694 .50702 m .70554 .50431 L .70552 .50441 L F
.685 .655 .814 r
.70549 .50432 m .70538 .50433 L .70547 .5043 L F
.979 .688 .32 r
.70694 .50702 m .70545 .50428 L .70543 .50433 L F
.806 .765 .816 r
.71126 .504 m .70888 .50676 L .70732 .50544 L F
0 .311 .802 r
.70888 .50676 m .70999 .50677 L .70732 .50544 L F
.627 .139 .076 r
.70999 .50677 m .70694 .50702 L .70732 .50544 L F
.979 .688 .32 r
.70694 .50702 m .70689 .50575 L .7064 .50597 L F
.70689 .50575 m .70684 .50473 L .7064 .50597 L F
.74 .56 .65 r
.70466 .50312 m .70716 .50349 L .70818 .5012 L F
.606 .037 0 r
.70327 .50208 m .70716 .50349 L .70466 .50312 L F
.70327 .50208 m .70588 .50354 L .70676 .50351 L F
.70327 .50208 m .70676 .50351 L .70702 .50344 L F
.353 .487 .855 r
.7046 .50036 m .70563 .50322 L .70327 .50208 L F
.007 .36 .832 r
.70432 .50267 m .70533 .50307 L .70424 .50255 L F
.70568 .50343 m .70579 .50325 L .70432 .50267 L F
.7054 .50427 m .70545 .50428 L .70541 .50424 L F
.979 .688 .32 r
.70543 .50433 m .7054 .50427 L .70538 .50433 L F
.70543 .50433 m .70545 .50428 L .7054 .50427 L F
.368 .254 .59 r
.70502 .50442 m .70502 .50445 L .7054 .50427 L F
.70502 .50445 m .70538 .50433 L .7054 .50427 L F
.685 .655 .814 r
.70587 .50418 m .70549 .5043 L .70466 .50312 L F
.007 .36 .832 r
.7054 .50427 m .70541 .50424 L .70535 .50419 L F
.997 .77 .441 r
.70449 .50371 m .70454 .50397 L .70436 .50414 L F
.70466 .50312 m .70454 .50397 L .70449 .50371 L F
.70466 .50312 m .70399 .5054 L .70218 .50557 L F
.723 .684 .812 r
.70466 .50312 m .70218 .50557 L .7054 .50427 L F
.685 .655 .814 r
.70549 .5043 m .70501 .50445 L .70484 .50379 L F
.70549 .5043 m .70484 .50379 L .70466 .50312 L F
.007 .36 .832 r
.70535 .50419 m .70543 .50419 L .70526 .50406 L F
.70541 .50424 m .70543 .50419 L .70535 .50419 L F
.70526 .50406 m .70568 .50343 L .70432 .50267 L F
.606 .037 0 r
.70327 .50208 m .70575 .50355 L .70588 .50354 L F
.353 .487 .855 r
.70563 .50322 m .70575 .50355 L .70327 .50208 L F
.007 .36 .832 r
.70424 .50255 m .70579 .50325 L .70422 .50253 L F
.70533 .50307 m .70579 .50325 L .70424 .50255 L F
.606 .037 0 r
.70702 .50344 m .70676 .50351 L .70716 .50349 L F
.007 .36 .832 r
.70541 .50424 m .70616 .5045 L .70578 .50329 L F
.70545 .50428 m .70684 .50473 L .70541 .50424 L F
.979 .688 .32 r
.70694 .50702 m .70569 .50578 L .70577 .50376 L F
.937 .964 .742 r
.70586 .50354 m .70575 .50355 L .70582 .50343 L F
.979 .688 .32 r
.70593 .50372 m .70577 .50376 L .70579 .50325 L F
.70694 .50702 m .70577 .50376 L .70593 .50372 L F
.849 .779 .783 r
.70582 .50343 m .70561 .50315 L .70489 .50115 L F
.70491 .50113 m .70489 .50115 L .7046 .50036 L F
.70582 .50343 m .70489 .50115 L .70491 .50113 L F
.353 .487 .855 r
.7046 .50036 m .70327 .50208 L .70228 .50139 L F
.077 .523 .901 r
.70521 .50294 m .7037 .50193 L .70228 .50139 L F
.655 .749 .919 r
.69851 .50099 m .69928 .50267 L .70216 .50156 L F
.281 .73 .96 r
.69998 .50152 m .70228 .50139 L .70327 .50208 L F
.70228 .50139 m .70228 .50139 L .70228 .50139 L F
.70228 .50139 m .70228 .50139 L .70327 .50208 L F
0 0 0 r
.69818 .49843 m .6962 .50163 L .69753 .49978 L F
.592 .779 .969 r
.6962 .50163 m .69851 .50099 L .69753 .49978 L F
.98 .687 .335 r
.69753 .49978 m .69851 .50099 L .69818 .49843 L F
.701 .604 .745 r
.69627 .49977 m .69419 .50178 L .69445 .49932 L F
.69627 .49977 m .69712 .50097 L .69419 .50178 L F
.64 .646 .841 r
.69849 .49953 m .69712 .50097 L .69627 .49977 L F
.69849 .49953 m .69998 .50152 L .69712 .50097 L F
.429 .672 .964 r
.69995 .50044 m .69998 .50152 L .69849 .49953 L F
.70059 .50084 m .70226 .50139 L .69998 .50152 L F
.727 .372 .377 r
.70112 .50116 m .70207 .50136 L .70187 .50126 L F
.70059 .50084 m .70187 .50126 L .69849 .49953 L F
.70112 .50116 m .70187 .50126 L .70059 .50084 L F
.429 .672 .964 r
.70116 .5002 m .70228 .50139 L .70226 .50139 L F
.219 .535 .924 r
.69849 .49953 m .70187 .50126 L .70116 .5002 L F
.429 .672 .964 r
.70116 .5002 m .70226 .50139 L .70187 .50126 L F
.219 .535 .924 r
.70187 .50126 m .70207 .50136 L .70116 .5002 L F
.429 .672 .964 r
.70116 .5002 m .70187 .50126 L .70059 .50084 L F
.7007 .50071 m .69998 .50152 L .69994 .4999 L F
.727 .372 .377 r
.69545 .49997 m .70112 .50116 L .69849 .49953 L F
.429 .672 .964 r
.69994 .4999 m .69995 .50044 L .69849 .49953 L F
.70116 .5002 m .7007 .50071 L .69994 .4999 L F
.521 .205 .372 r
.69567 .50058 m .7012 .50126 L .69545 .49997 L F
.7012 .50126 m .70207 .50136 L .70112 .50116 L F
.7012 .50126 m .70112 .50116 L .69545 .49997 L F
.281 .73 .96 r
.69998 .50152 m .70228 .50139 L .70327 .50208 L F
.575 .315 .485 r
.69712 .50097 m .69433 .50389 L .69419 .50178 L F
.69712 .50097 m .69675 .50364 L .69433 .50389 L F
.461 .077 .224 r
.69998 .50152 m .69675 .50364 L .69712 .50097 L F
.69998 .50152 m .69926 .50326 L .69675 .50364 L F
.524 .137 .251 r
.70248 .5027 m .69998 .50152 L .70228 .50139 L F
.70248 .5027 m .69926 .50326 L .69949 .50269 L F
.70146 .50222 m .69949 .50269 L .69998 .50152 L F
.70248 .5027 m .69949 .50269 L .70146 .50222 L F
.521 .205 .372 r
.69665 .50336 m .70207 .50137 L .69567 .50058 L F
.69675 .50364 m .69832 .50296 L .69665 .50336 L F
.69832 .50296 m .70207 .50137 L .69665 .50336 L F
.70207 .50137 m .70207 .50136 L .69567 .50058 L F
.077 .523 .901 r
.70579 .50325 m .70228 .50139 L .70327 .50208 L F
.655 .377 .487 r
.70228 .50139 m .7037 .50193 L .70248 .5027 L F
.077 .523 .901 r
.70579 .50325 m .70562 .50265 L .7037 .50193 L F
.70579 .50325 m .7037 .50193 L .70521 .50294 L F
.849 .779 .783 r
.7082 .49896 m .70585 .50337 L .7046 .50036 L F
.70585 .50337 m .70578 .50333 L .7046 .50036 L F
.007 .36 .832 r
.70438 .50322 m .70422 .50253 L .70327 .50208 L F
.7054 .50427 m .70422 .50253 L .70438 .50322 L F
.655 .377 .487 r
.7037 .50193 m .70562 .50265 L .70252 .5027 L F
.7037 .50193 m .70252 .5027 L .70248 .5027 L F
.849 .779 .783 r
.70585 .50337 m .70582 .50343 L .70578 .50333 L F
.007 .36 .832 r
.70543 .50419 m .70576 .50334 L .70526 .50406 L F
.70576 .50334 m .70579 .50325 L .70574 .50333 L F
.70576 .50334 m .70574 .50333 L .70526 .50406 L F
.849 .779 .783 r
.70582 .50343 m .70575 .50355 L .70563 .50322 L F
.70576 .50334 m .70563 .50322 L .70561 .50315 L F
.70582 .50343 m .70563 .50322 L .70576 .50334 L F
.007 .36 .832 r
.70582 .50343 m .70684 .50473 L .70578 .50329 L F
.70616 .5045 m .7068 .50472 L .70582 .50343 L F
.7068 .50472 m .70684 .50473 L .70582 .50343 L F
.70578 .50329 m .70684 .50473 L .70579 .50325 L F
.937 .964 .742 r
.70716 .50349 m .70586 .50354 L .7082 .49896 L F
.70586 .50354 m .70582 .50343 L .7082 .49896 L F
.979 .688 .32 r
.70694 .50702 m .70579 .50325 L .70684 .50473 L F
.70694 .50702 m .70543 .50433 L .70451 .5069 L F
0 0 .005 r
.70818 .5012 m .70922 .49978 L .70952 .50219 L F
.70818 .5012 m .70716 .50349 L .70922 .49978 L F
.937 .964 .742 r
.70716 .50349 m .70816 .49912 L .70855 .50099 L F
.593 .719 .932 r
.70579 .50325 m .70684 .50473 L .70824 .50284 L F
.52 .245 .437 r
.70579 .50325 m .70824 .50284 L .70684 .50473 L F
.526 .24 .423 r
.70579 .50325 m .7057 .50556 L .70808 .50472 L F
.7057 .50556 m .70569 .50578 L .70593 .50567 L F
.7057 .50556 m .70593 .50567 L .70808 .50472 L F
.998 .788 .443 r
.70597 .50569 m .70694 .50702 L .70813 .50754 L F
.368 .278 .621 r
.70593 .50567 m .70584 .50558 L .70808 .50472 L F
.998 .788 .443 r
.70584 .50558 m .70589 .50566 L .70593 .50567 L F
.368 .278 .621 r
.70569 .50578 m .70584 .50558 L .70593 .50567 L F
.998 .788 .443 r
.70584 .50558 m .70593 .50567 L .70597 .50569 L F
.70589 .50566 m .70694 .50702 L .70597 .50569 L F
.979 .688 .32 r
.70552 .50441 m .70554 .50431 L .70545 .50428 L F
.70543 .50433 m .70538 .50433 L .70451 .5069 L F
.685 .655 .814 r
.7053 .50457 m .70513 .50488 L .70501 .50445 L F
.368 .254 .59 r
.70502 .50445 m .70451 .5069 L .70538 .50433 L F
.70335 .5051 m .70437 .50668 L .70502 .50442 L F
.70437 .50668 m .70451 .5069 L .70502 .50442 L F
.70218 .50557 m .7026 .50581 L .70335 .5051 L F
.7026 .50581 m .70451 .5069 L .70335 .5051 L F
.937 .964 .742 r
.70816 .49912 m .7082 .49896 L .70855 .50099 L F
.617 .492 .687 r
.70998 .50302 m .7087 .50173 L .70952 .50219 L F
.7087 .50173 m .70818 .5012 L .70867 .50156 L F
.7087 .50173 m .70867 .50156 L .70952 .50219 L F
.71052 .50402 m .70882 .50197 L .70998 .50302 L F
.363 .762 .985 r
.32758 .59269 m .32392 .59211 L .32603 .59209 L F
.126 .644 .888 r
.328 .59232 m .32758 .59269 L .32603 .59209 L F
.328 .59232 m .32954 .59283 L .32758 .59269 L F
.696 .716 .194 r
.59836 .70979 m .59741 .71343 L .59811 .71113 L F
.766 .261 .002 r
.49097 .80478 m .48866 .80214 L .48744 .80224 L F
.385 .719 .988 r
.49203 .80251 m .48866 .80214 L .49097 .80478 L F
.188 0 .152 r
.32387 .61853 m .32566 .61798 L .32653 .61597 L F
.568 .46 .691 r
.32653 .61597 m .32871 .61557 L .32815 .61303 L F
.272 0 .107 r
.32566 .61798 m .32871 .61557 L .32653 .61597 L F
.847 .448 .287 r
.48344 .80482 m .48007 .80173 L .48134 .80231 L F
.959 .793 .633 r
.49448 .80761 m .49648 .80569 L .49508 .8051 L F
.49448 .80761 m .49587 .80811 L .49648 .80569 L F
.98 .688 .329 r
.49648 .80569 m .49721 .80849 L .49587 .80811 L F
.445 .211 .464 r
.36579 .66343 m .36774 .66291 L .36818 .66053 L F
.435 .218 .483 r
.36774 .66291 m .37008 .65975 L .36818 .66053 L F
.632 .693 .888 r
.69366 .48876 m .69031 .48746 L .69267 .48686 L F
.579 .705 .928 r
.69492 .48647 m .69366 .48876 L .69267 .48686 L F
.69492 .48647 m .69604 .48836 L .69366 .48876 L F
.972 .778 .584 r
.30676 .67174 m .30482 .67245 L .30568 .6704 L F
.321 .599 .946 r
.30735 .67049 m .30676 .67174 L .30568 .6704 L F
.712 .985 .822 r
.30735 .67049 m .30482 .67245 L .30676 .67174 L F
.976 .678 .375 r
.77107 .60659 m .77197 .60689 L .77078 .60449 L F
.551 .583 .84 r
.77078 .60449 m .77197 .60689 L .7748 .60634 L F
.372 .814 .952 r
.7748 .60634 m .77197 .60689 L .77107 .60659 L F
.724 .253 .13 r
.55651 .71291 m .5586 .71477 L .55967 .71354 L F
.647 .158 .076 r
.5586 .71477 m .56196 .71523 L .55967 .71354 L F
.541 .548 .811 r
.63892 .49053 m .64 .48691 L .63791 .48718 L F
.63892 .49053 m .6412 .49025 L .64 .48691 L F
.875 .446 .172 r
.50114 .81227 m .50294 .81466 L .50152 .81504 L F
.2 0 0 r
.5015 .81346 m .50268 .81137 L .50114 .81227 L F
.392 0 0 r
.50369 .81252 m .50268 .81137 L .5015 .81346 L F
.50369 .81252 m .50501 .81153 L .50268 .81137 L F
.772 .693 .775 r
.50004 .81124 m .50268 .81137 L .50114 .81227 L F
.567 .502 .741 r
.36309 .67707 m .36543 .67688 L .36462 .67433 L F
.494 .482 .773 r
.36309 .67707 m .36591 .67973 L .36543 .67688 L F
.582 .584 .819 r
.65111 .54634 m .65226 .5426 L .64984 .54506 L F
.65111 .54634 m .65347 .54589 L .65226 .5426 L F
.561 .245 .389 r
.51518 .80758 m .5131 .80601 L .51312 .80824 L F
.56 .246 .392 r
.51518 .80758 m .51577 .80584 L .5131 .80601 L F
0 0 .343 r
.67198 .53234 m .67221 .53486 L .67281 .53329 L F
.67198 .53234 m .67281 .53329 L .67015 .53182 L F
.747 .596 .689 r
.6137 .54634 m .61694 .54883 L .61557 .54594 L F
.84 .378 0 r
.47934 .80031 m .48007 .80173 L .4781 .79969 L F
.615 .957 .876 r
.71286 .5215 m .71291 .52236 L .71509 .52148 L F
.71286 .5215 m .71147 .52246 L .71291 .52236 L F
.574 .715 .938 r
.74682 .61318 m .75003 .61427 L .74917 .61275 L F
.554 .713 .946 r
.75003 .61427 m .75153 .61246 L .74917 .61275 L F
.75003 .61427 m .75266 .61388 L .75153 .61246 L F
.617 .05 0 r
.55291 .70935 m .55465 .71043 L .55613 .71082 L F
.952 .605 .228 r
.55556 .71207 m .55613 .71082 L .55465 .71043 L F
.55556 .71207 m .55651 .71291 L .55613 .71082 L F
.555 .446 .685 r
.72718 .60213 m .72951 .60171 L .72917 .59835 L F
.404 0 0 r
.49703 .74257 m .5005 .74215 L .49856 .74075 L F
.49703 .74257 m .4997 .74327 L .5005 .74215 L F
.853 .784 .784 r
.49856 .74075 m .5005 .74215 L .50127 .73923 L F
.063 0 0 r
.5027 .74207 m .5006 .74318 L .50149 .74186 L F
0 0 0 r
.5005 .74215 m .50052 .74215 L .5042 .74099 L F
.063 0 0 r
.50239 .74159 m .50149 .74186 L .50204 .74104 L F
.5027 .74207 m .50149 .74186 L .50239 .74159 L F
0 0 0 r
.50052 .74215 m .50135 .74217 L .50375 .74118 L F
.50052 .74215 m .50375 .74118 L .5042 .74099 L F
.5005 .74215 m .4997 .74327 L .50135 .74217 L F
.107 .661 .732 r
.49767 .80842 m .49982 .8082 L .49721 .80849 L F
.415 .086 .297 r
.35442 .61053 m .35576 .6119 L .35406 .61273 L F
.334 .644 .966 r
.31479 .6029 m .31521 .60181 L .31361 .6012 L F
.31479 .6029 m .31747 .60314 L .31521 .60181 L F
.419 .855 .931 r
.29241 .65093 m .29612 .65054 L .29447 .65031 L F
.145 .683 .838 r
.29447 .65031 m .29612 .65054 L .29848 .65041 L F
.57 .626 .868 r
.52679 .73644 m .53044 .73868 L .52937 .73633 L F
.61 .681 .892 r
.53044 .73868 m .53108 .73571 L .52937 .73633 L F
.53044 .73868 m .53278 .73844 L .53108 .73571 L F
.78 .647 .715 r
.53039 .7408 m .53278 .73844 L .53044 .73868 L F
.279 .739 .952 r
.50951 .77553 m .51285 .77594 L .51136 .77436 L F
.27 0 0 r
.28336 .58498 m .287 .58609 L .28509 .58615 L F
.641 .097 0 r
.67516 .54004 m .67158 .53715 L .67533 .53833 L F
.006 0 .261 r
.78513 .58757 m .78455 .58971 L .78432 .58791 L F
.011 .585 .751 r
.44346 .64821 m .44558 .64828 L .44683 .6484 L F
.477 .806 1 r
.44558 .64828 m .44907 .64871 L .44683 .6484 L F
.65 .495 .66 r
.76776 .60137 m .77073 .60187 L .7705 .59953 L F
.654 .517 .684 r
.76834 .60469 m .77073 .60187 L .76776 .60137 L F
.667 .155 .014 r
.70409 .49661 m .70317 .49741 L .70046 .49576 L F
.664 .904 .57 r
.70538 .49465 m .70409 .49661 L .70678 .49782 L F
.70538 .49465 m .70317 .49741 L .70409 .49661 L F
.194 .677 .929 r
.57352 .71783 m .57689 .7181 L .57825 .7188 L F
.118 .647 .872 r
.57689 .7181 m .58069 .7187 L .57825 .7188 L F
0 .141 .645 r
.58033 .72099 m .57825 .7188 L .58069 .7187 L F
.592 .558 .786 r
.37462 .71642 m .37563 .71281 L .37334 .71341 L F
.37462 .71642 m .37699 .7162 L .37563 .71281 L F
.584 .454 .67 r
.37462 .71642 m .3748 .71857 L .37699 .7162 L F
.345 .694 .982 r
.322 .60323 m .32502 .60299 L .32259 .60291 L F
.322 .60323 m .3265 .60419 L .32502 .60299 L F
.503 .663 .934 r
.3519 .59553 m .35189 .59808 L .34969 .59604 L F
.3519 .59553 m .35405 .59794 L .35189 .59808 L F
.544 .083 .11 r
.63474 .51453 m .63745 .5149 L .63853 .51362 L F
0 0 0 r
.63853 .51362 m .63938 .51385 L .64022 .51198 L F
.63853 .51362 m .63745 .5149 L .63938 .51385 L F
.272 .006 .315 r
.48386 .74838 m .48479 .74952 L .48484 .74747 L F
.428 .03 .18 r
.48386 .74838 m .48212 .75086 L .48479 .74952 L F
.929 .882 .768 r
.51262 .77983 m .51198 .78325 L .51098 .78331 L F
0 .122 .665 r
.51198 .78325 m .51378 .7852 L .51244 .78254 L F
.573 .424 .641 r
.76612 .60762 m .76856 .60777 L .76834 .60469 L F
.122 0 0 r
.24261 .5951 m .24516 .59334 L .24318 .59365 L F
.509 .207 .389 r
.56273 .68815 m .56558 .68792 L .56555 .68622 L F
.406 .046 .237 r
.35779 .61129 m .35912 .60783 L .36044 .60934 L F
.688 .874 .968 r
.76627 .61892 m .76861 .6192 L .76764 .61789 L F
.557 .763 .974 r
.76861 .6192 m .77003 .61746 L .76764 .61789 L F
.76861 .6192 m .77102 .61879 L .77003 .61746 L F
.797 .458 .414 r
.57775 .57388 m .57877 .57334 L .57854 .57516 L F
.352 .069 .336 r
.58067 .57311 m .57877 .57334 L .57854 .57516 L F
.976 .92 .622 r
.65438 .493 m .65492 .48878 L .65614 .48958 L F
.586 .872 .994 r
.65614 .48958 m .65758 .48788 L .65832 .48743 L F
.65614 .48958 m .65492 .48878 L .65758 .48788 L F
.357 .011 .233 r
.47546 .75224 m .4765 .75388 L .47775 .75187 L F
.47546 .75224 m .47443 .75447 L .4765 .75388 L F
.405 .131 .382 r
.33765 .62921 m .33721 .63201 L .33468 .63169 L F
.398 .068 .285 r
.33468 .63169 m .33639 .63367 L .33453 .63435 L F
.33468 .63169 m .33721 .63201 L .33639 .63367 L F
.468 .057 .176 r
.51727 .80698 m .5191 .80455 L .51577 .80584 L F
.809 .684 .726 r
.49522 .78885 m .49806 .78917 L .49678 .78581 L F
.802 .711 .763 r
.4959 .79175 m .49806 .78917 L .49522 .78885 L F
.332 .031 .296 r
.37274 .65496 m .37011 .65764 L .37201 .65702 L F
.488 .152 .324 r
.37424 .65649 m .37274 .65496 L .37201 .65702 L F
.37424 .65649 m .37491 .65481 L .37274 .65496 L F
.655 .547 .721 r
.45875 .67512 m .45907 .67743 L .46093 .6743 L F
.528 .39 .637 r
.46093 .6743 m .45907 .67743 L .46116 .67688 L F
.514 .284 .503 r
.45866 .67955 m .46116 .67688 L .45907 .67743 L F
.668 .554 .717 r
.48175 .66294 m .48253 .66623 L .47949 .66595 L F
.516 .388 .645 r
.63894 .51 m .64022 .51198 L .63999 .50993 L F
.869 .826 .804 r
.60098 .53177 m .60247 .53288 L .60141 .53449 L F
.836 .808 .823 r
.59867 .53444 m .60098 .53177 L .60141 .53449 L F
.598 .229 .314 r
.62725 .50175 m .62363 .50322 L .6242 .50394 L F
.749 .594 .685 r
.55811 .69375 m .56055 .6911 L .55858 .69146 L F
0 0 .53 r
.67641 .51741 m .67729 .52072 L .67639 .51861 L F
.601 .448 .647 r
.53218 .7747 m .52997 .7772 L .52988 .7751 L F
.53218 .7747 m .53199 .77724 L .52997 .7772 L F
.559 .425 .655 r
.53199 .77724 m .53048 .77897 L .52997 .7772 L F
.524 .487 .758 r
.36489 .68586 m .36602 .68222 L .36434 .68277 L F
.36489 .68586 m .3669 .68545 L .36602 .68222 L F
.53 .487 .753 r
.36489 .68586 m .36751 .68787 L .3669 .68545 L F
.546 .457 .705 r
.51335 .7278 m .51598 .72515 L .51181 .72405 L F
.51335 .7278 m .51548 .72744 L .51598 .72515 L F
.443 .147 .367 r
.51303 .72963 m .51548 .72744 L .51335 .7278 L F
.814 .417 .3 r
.48344 .80482 m .48662 .8059 L .4872 .8079 L F
.746 .369 .338 r
.48662 .8059 m .49037 .8081 L .4872 .8079 L F
.332 .058 .339 r
.49171 .7864 m .4933 .78731 L .49323 .78576 L F
.49171 .7864 m .49111 .78851 L .4933 .78731 L F
.804 .679 .726 r
.38178 .72269 m .37792 .72433 L .38021 .72364 L F
.644 .161 .089 r
.38021 .72364 m .38395 .72406 L .38178 .72269 L F
.886 .894 .831 r
.58042 .73317 m .58166 .73381 L .58294 .73145 L F
.312 0 .026 r
.73329 .59722 m .7317 .59634 L .73145 .59773 L F
.73329 .59722 m .73409 .59586 L .7317 .59634 L F
.451 .796 .998 r
.43196 .64943 m .43414 .64911 L .43552 .64989 L F
.461 .816 .997 r
.43414 .64911 m .43776 .64942 L .43552 .64989 L F
.842 .589 .557 r
.35661 .72746 m .35696 .73013 L .3539 .72993 L F
.35661 .72746 m .3539 .72993 L .35535 .72928 L F
.973 .684 .415 r
.35661 .72746 m .35696 .73013 L .35535 .72928 L F
.791 .593 .633 r
.38079 .7183 m .38321 .7199 L .38416 .71906 L F
.465 0 0 r
.38079 .7183 m .38416 .71906 L .38258 .71897 L F
.277 0 0 r
.38258 .71897 m .38416 .71906 L .38334 .71915 L F
.292 0 .165 r
.44601 .69498 m .44537 .69312 L .44723 .69321 L F
.44601 .69498 m .44388 .6957 L .44537 .69312 L F
.257 0 0 r
.55275 .6965 m .55504 .69614 L .5577 .69461 L F
0 0 0 r
.5577 .69461 m .55761 .69516 L .55811 .69375 L F
.5577 .69461 m .55504 .69614 L .55761 .69516 L F
.871 .728 .701 r
.6042 .73311 m .60315 .72958 L .602 .73261 L F
.839 .549 .498 r
.60158 .73501 m .6042 .73311 L .602 .73261 L F
.60158 .73501 m .60451 .73534 L .6042 .73311 L F
.621 .798 .967 r
.76384 .61074 m .76056 .61026 L .76291 .60973 L F
.436 .751 .994 r
.7654 .6097 m .76384 .61074 L .76291 .60973 L F
.7654 .6097 m .76638 .61063 L .76384 .61074 L F
.599 .633 .856 r
.25699 .64868 m .25869 .65163 L .26094 .65094 L F
.544 .469 .721 r
.74571 .59586 m .74628 .59913 L .74408 .59979 L F
.578 .915 .97 r
.77102 .61879 m .77405 .61826 L .77359 .61809 L F
.609 .916 .978 r
.77405 .61826 m .77561 .6168 L .77359 .61809 L F
.77405 .61826 m .77637 .61736 L .77561 .6168 L F
.327 .418 .802 r
.53921 .74037 m .53873 .7422 L .54076 .7403 L F
.785 .618 .673 r
.54076 .7403 m .54335 .73749 L .54056 .73772 L F
0 0 .134 r
.5408 .73803 m .54076 .7403 L .54056 .73772 L F
.951 .934 .597 r
.5408 .73803 m .54071 .73828 L .54076 .7403 L F
.447 .62 .925 r
.53873 .7422 m .5408 .74232 L .54076 .7403 L F
.463 .669 .953 r
.53962 .74264 m .54177 .74238 L .53873 .7422 L F
.483 .571 .868 r
.53645 .73925 m .53921 .74037 L .53726 .73736 L F
.153 .665 .898 r
.53921 .74037 m .53793 .73979 L .53726 .73736 L F
.53921 .74037 m .54076 .7403 L .53793 .73979 L F
.794 .471 .442 r
.54076 .7403 m .53915 .74259 L .53793 .73979 L F
.951 .934 .597 r
.54071 .73828 m .53915 .74259 L .54076 .7403 L F
.447 .62 .925 r
.5408 .74232 m .54177 .74238 L .54076 .7403 L F
.704 .681 .825 r
.71431 .49051 m .71213 .49154 L .71094 .48995 L F
.864 .46 .266 r
.72408 .49604 m .72422 .49829 L .72642 .49854 L F
.512 .408 .674 r
.72625 .49247 m .72615 .49617 L .72408 .49604 L F
.27 .003 .311 r
.72525 .49722 m .72408 .49604 L .72615 .49617 L F
.72525 .49722 m .72422 .49829 L .72408 .49604 L F
.869 .714 .688 r
.66825 .51582 m .66523 .51716 L .66631 .51508 L F
.66825 .51582 m .6676 .51802 L .66523 .51716 L F
.552 .156 .245 r
.3698 .71035 m .36621 .71127 L .36847 .71186 L F
.927 .749 .641 r
.6014 .52928 m .60247 .53288 L .60098 .53177 L F
.182 0 .368 r
.6987 .53299 m .69738 .53178 L .69929 .53083 L F
.6987 .53299 m .69731 .53438 L .69738 .53178 L F
0 0 0 r
.72167 .5187 m .71953 .51963 L .72069 .51852 L F
.72167 .5187 m .72025 .51915 L .71953 .51963 L F
.72069 .51852 m .71953 .51963 L .71811 .52056 L F
.72025 .51915 m .71878 .51963 L .71953 .51963 L F
.71811 .52056 m .71953 .51963 L .71791 .52071 L F
.486 .897 .914 r
.71953 .51963 m .71726 .5205 L .71791 .52071 L F
.644 .882 .985 r
.76968 .6105 m .76638 .61063 L .76873 .60981 L F
.72 .543 .65 r
.59514 .57379 m .59324 .57655 L .59319 .57396 L F
.59514 .57379 m .59681 .5768 L .59324 .57655 L F
.567 .508 .748 r
.37194 .70573 m .37274 .70833 L .37481 .70764 L F
.619 .399 .561 r
.37215 .71012 m .37481 .70764 L .37274 .70833 L F
.004 0 0 r
.68755 .54061 m .68575 .54099 L .68422 .54099 L F
.199 0 0 r
.68754 .54122 m .68755 .54061 L .68967 .53951 L F
.68754 .54122 m .68575 .54099 L .68755 .54061 L F
.379 .059 .291 r
.4508 .68007 m .45226 .681 L .45306 .67985 L F
.4508 .68007 m .4502 .68162 L .45226 .681 L F
.714 .881 .958 r
.48097 .7939 m .48444 .79401 L .48301 .7941 L F
.651 .584 .767 r
.48544 .79744 m .48648 .79389 L .48444 .79401 L F
.366 0 .104 r
.48444 .79401 m .48512 .79585 L .48301 .7941 L F
.48444 .79401 m .48648 .79389 L .48512 .79585 L F
.475 .467 .769 r
.45874 .78386 m .46147 .78524 L .46065 .78192 L F
0 0 .061 r
.39146 .71589 m .38961 .71908 L .3883 .71591 L F
.406 .093 .319 r
.39286 .71796 m .39069 .71844 L .39146 .71589 L F
.505 .011 .017 r
.39286 .71796 m .39131 .71829 L .39069 .71844 L F
0 0 .061 r
.39146 .71589 m .39069 .71844 L .38987 .71863 L F
.076 0 0 r
.39069 .71844 m .38621 .71885 L .38702 .71977 L F
.3867 .7188 m .38909 .71877 L .38621 .71885 L F
.39069 .71844 m .38909 .71877 L .3867 .7188 L F
0 0 .061 r
.38987 .71863 m .39069 .71844 L .38961 .71908 L F
.388 .847 .805 r
.39069 .71844 m .38702 .71977 L .38961 .71908 L F
.505 .011 .017 r
.39131 .71829 m .38909 .71877 L .39069 .71844 L F
.39286 .71796 m .3911 .71925 L .38909 .71877 L F
.443 .531 .853 r
.38909 .71877 m .3911 .71925 L .39084 .71875 L F
.38909 .71877 m .39084 .71875 L .3895 .71619 L F
.655 .723 .899 r
.64989 .52559 m .6498 .52694 L .64686 .52672 L F
.894 .917 .831 r
.65229 .52367 m .6498 .52694 L .64989 .52559 L F
.5 .813 1 r
.65314 .51592 m .65405 .51463 L .65207 .51409 L F
.65314 .51592 m .65545 .51548 L .65405 .51463 L F
.387 .748 .992 r
.31904 .59072 m .31815 .59185 L .31648 .59099 L F
.31904 .59072 m .32031 .5916 L .31815 .59185 L F
.526 .423 .68 r
.45983 .77497 m .46179 .77454 L .46172 .77155 L F
.516 .385 .641 r
.45983 .77497 m .46218 .77699 L .46179 .77454 L F
.436 .384 .702 r
.45983 .77497 m .46052 .77765 L .46218 .77699 L F
.495 .244 .463 r
.3761 .65823 m .3785 .65524 L .3763 .65602 L F
.021 0 0 r
.37836 .65529 m .3785 .65504 L .3763 .65602 L F
.495 .244 .463 r
.3785 .65524 m .37885 .65481 L .3763 .65602 L F
.021 0 0 r
.37832 .65536 m .37836 .65529 L .3763 .65602 L F
.495 .244 .463 r
.3761 .65823 m .37869 .65804 L .37883 .65526 L F
.3761 .65823 m .37883 .65526 L .37882 .65526 L F
.3761 .65823 m .37883 .65525 L .37847 .65528 L F
.021 0 0 r
.37837 .65527 m .38077 .65483 L .3785 .65504 L F
.37836 .65529 m .37852 .65526 L .37837 .65527 L F
.37852 .65526 m .38077 .65483 L .37837 .65527 L F
.37879 .65526 m .38077 .65483 L .37836 .65529 L F
.604 .333 .479 r
.37885 .65481 m .37915 .65522 L .38087 .65437 L F
.098 0 0 r
.37883 .65526 m .38077 .65483 L .37879 .65526 L F
.38111 .65554 m .38104 .6554 L .37883 .65526 L F
.38104 .6554 m .38077 .65483 L .37883 .65526 L F
.604 .333 .479 r
.37919 .65528 m .37869 .65804 L .38092 .6577 L F
.37885 .65481 m .37883 .65526 L .37919 .65528 L F
.37883 .65526 m .37869 .65804 L .37919 .65528 L F
.37915 .65522 m .37919 .65528 L .37934 .6552 L F
.37915 .65522 m .37934 .6552 L .38087 .65437 L F
.37919 .65528 m .38092 .6577 L .38089 .65553 L F
.37919 .65528 m .38089 .65553 L .38087 .65437 L F
.098 0 0 r
.38116 .65565 m .38295 .65444 L .38077 .65483 L F
.065 0 0 r
.38342 .65497 m .38295 .65444 L .38116 .65565 L F
.569 .391 .601 r
.38089 .65553 m .38342 .65497 L .38087 .65437 L F
.38092 .6577 m .38276 .65569 L .38089 .65553 L F
.098 0 0 r
.38089 .65553 m .38111 .65554 L .3808 .65552 L F
.38111 .65555 m .38111 .65554 L .38089 .65553 L F
.569 .391 .601 r
.38276 .65569 m .38342 .65497 L .38089 .65553 L F
.098 0 0 r
.38112 .65556 m .38111 .65555 L .38089 .65553 L F
.38116 .65565 m .38112 .65556 L .37832 .65536 L F
.38112 .65556 m .3808 .65552 L .37832 .65536 L F
.38111 .65554 m .37879 .65526 L .37832 .65536 L F
.495 .244 .463 r
.37882 .65526 m .37883 .65526 L .37883 .65525 L F
.37847 .65528 m .37883 .65525 L .37885 .65481 L F
.021 0 0 r
.37832 .65536 m .37879 .65526 L .37836 .65529 L F
.585 .789 .977 r
.74197 .59275 m .73973 .59337 L .7386 .59228 L F
.585 .606 .839 r
.26968 .63546 m .26616 .63292 L .26828 .63228 L F
.641 .617 .81 r
.27191 .63473 m .26968 .63546 L .26828 .63228 L F
.609 .218 .277 r
.47586 .80087 m .47628 .79817 L .4781 .79969 L F
.113 0 .01 r
.28459 .60842 m .28419 .60724 L .28627 .60694 L F
.28459 .60842 m .28269 .60943 L .28419 .60724 L F
.227 0 0 r
.29239 .60537 m .29203 .60425 L .29401 .60391 L F
.29239 .60537 m .29034 .60588 L .29203 .60425 L F
0 0 0 r
.72297 .51579 m .72227 .51762 L .72069 .51852 L F
.72167 .5187 m .72069 .51852 L .72227 .51762 L F
.954 .623 .352 r
.66232 .49796 m .66319 .49557 L .66191 .4941 L F
.574 .789 .981 r
.66319 .49557 m .66452 .49359 L .66191 .4941 L F
.66319 .49557 m .66556 .49501 L .66452 .49359 L F
.543 .917 .941 r
.76575 .57959 m .76277 .58023 L .76511 .5791 L F
.653 .864 .979 r
.76724 .57763 m .76575 .57959 L .76511 .5791 L F
.76724 .57763 m .7681 .57864 L .76575 .57959 L F
.042 0 0 r
.5082 .81537 m .51198 .81382 L .51066 .8143 L F
.155 0 0 r
.51198 .81382 m .51337 .81418 L .51066 .8143 L F
.51198 .81382 m .5143 .81408 L .51337 .81418 L F
.445 .071 .234 r
.40448 .66815 m .40347 .67039 L .40126 .67059 L F
.601 .427 .618 r
.40572 .66773 m .40347 .67039 L .40448 .66815 L F
.875 .446 .172 r
.50114 .81227 m .50152 .81504 L .50008 .81219 L F
.2 0 0 r
.5015 .81346 m .50114 .81227 L .50008 .81219 L F
.909 .532 .296 r
.50004 .81124 m .50114 .81227 L .50008 .81219 L F
.807 .785 .283 r
.67082 .4972 m .67066 .49881 L .67151 .49509 L F
0 0 .066 r
.67069 .5014 m .67066 .49881 L .67082 .4972 L F
.635 .378 .512 r
.62434 .51752 m .62756 .51581 L .62351 .51491 L F
.62434 .51752 m .62685 .51774 L .62756 .51581 L F
.62756 .51581 m .62685 .51774 L .62434 .51752 L F
.51 .525 .807 r
.62553 .5124 m .62756 .51581 L .62901 .51483 L F
.531 .271 .466 r
.62891 .51718 m .62756 .51581 L .62901 .51483 L F
.62891 .51718 m .62685 .51774 L .62756 .51581 L F
.62891 .51718 m .62756 .51581 L .62901 .51483 L F
.62891 .51718 m .62685 .51774 L .62756 .51581 L F
.958 .635 .235 r
.57214 .75204 m .57337 .75492 L .57345 .75245 L F
.807 .785 .283 r
.67082 .4972 m .67151 .49509 L .66885 .495 L F
.579 .341 .519 r
.31381 .62913 m .31633 .62668 L .3143 .62722 L F
.349 0 0 r
.40546 .65105 m .40777 .65095 L .40922 .6498 L F
0 0 0 r
.40922 .6498 m .40981 .65018 L .41145 .6495 L F
.40922 .6498 m .40777 .65095 L .40981 .65018 L F
0 0 .275 r
.50045 .80998 m .50004 .81124 L .49982 .8082 L F
.50045 .80998 m .49982 .8082 L .49767 .80842 L F
.008 0 0 r
.72715 .51193 m .72466 .51442 L .72535 .51313 L F
.474 .359 .642 r
.36579 .66343 m .36797 .66546 L .36774 .66291 L F
.36579 .66343 m .36604 .66584 L .36797 .66546 L F
.609 .451 .643 r
.53862 .74976 m .54119 .74962 L .54078 .74683 L F
.555 .313 .503 r
.5385 .75207 m .54119 .74962 L .53862 .74976 L F
.931 .841 .734 r
.6606 .53978 m .6634 .53767 L .66174 .53707 L F
.6606 .53978 m .66183 .5408 L .6634 .53767 L F
.578 .461 .683 r
.55176 .73293 m .55058 .73574 L .54993 .73333 L F
.655 .723 .899 r
.64989 .52559 m .64686 .52672 L .64567 .52501 L F
.497 .848 .994 r
.294 .63587 m .29805 .63604 L .29601 .63643 L F
.442 .161 .389 r
.34946 .61587 m .35219 .61346 L .35153 .61535 L F
.328 .047 .325 r
.35153 .61535 m .35219 .61346 L .35406 .61273 L F
.562 .667 .908 r
.28506 .63466 m .28455 .63711 L .28309 .63536 L F
.28506 .63466 m .2867 .63666 L .28455 .63711 L F
.394 .768 .992 r
.29472 .58713 m .29415 .5881 L .29273 .58685 L F
.29472 .58713 m .29619 .58791 L .29415 .5881 L F
.631 .692 .888 r
.36761 .70777 m .36293 .70617 L .36531 .70457 L F
0 .196 .719 r
.3681 .70661 m .36761 .70777 L .36531 .70457 L F
.3681 .70661 m .36827 .70781 L .36761 .70777 L F
.068 0 .263 r
.62965 .53785 m .62881 .54002 L .63102 .53812 L F
.605 .432 .622 r
.60807 .57317 m .61042 .57391 L .60817 .57437 L F
.60807 .57317 m .61082 .57173 L .61042 .57391 L F
0 .353 .826 r
.35137 .70585 m .35246 .70408 L .35193 .70521 L F
.35137 .70585 m .35233 .70572 L .35246 .70408 L F
.502 .322 .569 r
.35137 .70585 m .35173 .70842 L .35389 .7073 L F
.388 .112 .368 r
.72466 .51442 m .72227 .51762 L .72297 .51579 L F
.355 .305 .663 r
.68739 .52667 m .68845 .52866 L .69017 .52777 L F
.33 0 .063 r
.25264 .58985 m .25475 .58947 L .25632 .58755 L F
.351 0 .075 r
.25475 .58947 m .25844 .58721 L .25632 .58755 L F
.411 .15 .404 r
.35748 .71905 m .35961 .71892 L .35992 .71655 L F
.595 .306 .448 r
.35992 .71655 m .35961 .71892 L .36176 .71792 L F
.026 0 .059 r
.64567 .52501 m .64752 .52475 L .64989 .52559 L F
.64567 .52501 m .64646 .52669 L .64752 .52475 L F
.747 .596 .689 r
.6137 .54634 m .61344 .54872 L .61694 .54883 L F
.597 .277 .397 r
.61354 .55105 m .61694 .54883 L .61344 .54872 L F
.61354 .55105 m .61594 .55102 L .61694 .54883 L F
.199 0 0 r
.61594 .55102 m .61901 .55006 L .61694 .54883 L F
.556 .123 .173 r
.61694 .54883 m .61901 .55006 L .61947 .54899 L F
.588 .943 .915 r
.27707 .65286 m .27937 .65263 L .28109 .65162 L F
.218 .394 .824 r
.65035 .49266 m .65285 .49428 L .65193 .49564 L F
.898 .84 .381 r
.65285 .49428 m .65244 .49776 L .65193 .49564 L F
.755 .618 .708 r
.53192 .77214 m .52988 .7751 L .52849 .77178 L F
.721 .57 .685 r
.53192 .77214 m .53218 .7747 L .52988 .7751 L F
.697 .599 .742 r
.53444 .77154 m .53218 .7747 L .53192 .77214 L F
.883 .481 .257 r
.66883 .52937 m .66868 .53132 L .66724 .52869 L F
.66883 .52937 m .67015 .53182 L .66868 .53132 L F
.894 .917 .831 r
.65229 .52367 m .64989 .52559 L .65093 .5252 L F
.373 0 .012 r
.65457 .52363 m .65229 .52367 L .65093 .5252 L F
.674 .606 .772 r
.48602 .6688 m .48253 .66623 L .48491 .66516 L F
.654 .589 .77 r
.48815 .66667 m .48602 .6688 L .48491 .66516 L F
.684 .64 .8 r
.4886 .66812 m .48602 .6688 L .48815 .66667 L F
.206 0 .166 r
.31129 .63152 m .31208 .62995 L .30946 .63239 L F
.169 0 .146 r
.31381 .62913 m .31208 .62995 L .31129 .63152 L F
.101 .642 .849 r
.33157 .59291 m .33305 .59324 L .32954 .59283 L F
.252 .741 .92 r
.33369 .59274 m .33305 .59324 L .33157 .59291 L F
.33369 .59274 m .33516 .5931 L .33305 .59324 L F
.611 .586 .801 r
.58971 .74436 m .59091 .74076 L .58869 .74148 L F
.58971 .74436 m .5919 .74385 L .59091 .74076 L F
.575 .43 .647 r
.58971 .74436 m .59209 .74581 L .5919 .74385 L F
.663 .969 .8 r
.35406 .70344 m .35193 .70521 L .35246 .70408 L F
.599 .243 .337 r
.49732 .75167 m .49961 .75205 L .50085 .7496 L F
.622 .268 .349 r
.50085 .7496 m .49961 .75205 L .50336 .7513 L F
.641 .238 .264 r
.50085 .7496 m .50336 .7513 L .50359 .74981 L F
.602 .332 .48 r
.50336 .7513 m .50599 .74939 L .50359 .74981 L F
.797 .836 .881 r
.66726 .49237 m .67106 .49172 L .66984 .4899 L F
.587 .731 .943 r
.66984 .4899 m .67106 .49172 L .67185 .49022 L F
.609 .653 .868 r
.67106 .49172 m .67396 .49212 L .67185 .49022 L F
.346 .324 .692 r
.5031 .79027 m .5018 .79233 L .5036 .79372 L F
.912 .943 .586 r
.62636 .4923 m .62516 .49568 L .62754 .49289 L F
.62636 .4923 m .62487 .49496 L .62516 .49568 L F
.918 .913 .521 r
.62487 .49496 m .62401 .49706 L .62516 .49568 L F
.658 .598 .776 r
.48898 .68239 m .4862 .6828 L .4852 .67946 L F
.732 .534 .624 r
.48898 .68239 m .48637 .68484 L .4862 .6828 L F
.494 .439 .725 r
.36998 .69656 m .37036 .69986 L .37238 .6987 L F
.572 .509 .746 r
.37108 .70211 m .37238 .6987 L .37036 .69986 L F
.976 .818 .622 r
.5708 .77103 m .572 .77175 L .57276 .76952 L F
.79 .617 .666 r
.61789 .52901 m .62143 .52973 L .61992 .52649 L F
.708 .584 .714 r
.61992 .52649 m .62143 .52973 L .62343 .52662 L F
.865 .691 .665 r
.60586 .73858 m .6062 .73626 L .60451 .73534 L F
0 0 0 r
.3158 .64711 m .31415 .64863 L .31279 .64883 L F
.281 0 0 r
.31786 .64645 m .31415 .64863 L .3158 .64711 L F
.68 .91 .974 r
.45253 .64872 m .45338 .6471 L .45464 .64792 L F
.45253 .64872 m .45121 .64813 L .45338 .6471 L F
.635 .093 0 r
.5901 .69434 m .59125 .69608 L .58981 .69317 L F
.604 .428 .616 r
.62035 .56812 m .61826 .5707 L .61803 .56839 L F
.386 0 0 r
.30005 .60192 m .29839 .60338 L .29624 .6035 L F
.011 0 0 r
.30038 .60261 m .30005 .60192 L .3023 .60193 L F
.30038 .60261 m .29839 .60338 L .30005 .60192 L F
.611 .286 .395 r
.71698 .50597 m .72028 .50442 L .71922 .50319 L F
.71698 .50597 m .71982 .50598 L .72028 .50442 L F
.557 .813 .993 r
.72028 .50442 m .72151 .50286 L .71922 .50319 L F
.72028 .50442 m .72261 .50383 L .72151 .50286 L F
.117 0 0 r
.71982 .50598 m .72261 .50383 L .72028 .50442 L F
.73 .674 .795 r
.4585 .6632 m .46161 .66352 L .46062 .6606 L F
.608 .603 .821 r
.46062 .6606 m .46161 .66352 L .46388 .663 L F
.575 .445 .665 r
.46161 .66352 m .4642 .66548 L .46388 .663 L F
.511 .452 .726 r
.46224 .66598 m .4642 .66548 L .46161 .66352 L F
.308 .027 .313 r
.39395 .67432 m .39161 .6767 L .39144 .67439 L F
.234 .75 .847 r
.28325 .65127 m .28473 .65132 L .28672 .651 L F
.728 .875 .95 r
.44841 .65769 m .44937 .65846 L .45166 .65765 L F
.374 .061 .3 r
.32387 .61853 m .32524 .6199 L .32566 .61798 L F
.32387 .61853 m .32321 .62046 L .32524 .6199 L F
.622 .621 .829 r
.48005 .6572 m .47786 .6579 L .47649 .65472 L F
.226 .002 .35 r
.33196 .63686 m .33088 .63568 L .33268 .63508 L F
.33196 .63686 m .33042 .63787 L .33088 .63568 L F
.728 .875 .95 r
.44841 .65769 m .45166 .65765 L .45036 .65671 L F
.281 .67 .971 r
.45252 .65725 m .45036 .65671 L .45166 .65765 L F
.514 .402 .664 r
.46224 .66598 m .46465 .66784 L .4642 .66548 L F
.46224 .66598 m .4625 .66952 L .46465 .66784 L F
.35 0 0 r
.62198 .49991 m .6255 .49876 L .6233 .49935 L F
.433 .009 .133 r
.50448 .7908 m .50333 .78923 L .5031 .79027 L F
.499 0 0 r
.54731 .7274 m .55063 .72801 L .5488 .72726 L F
.509 .132 .261 r
.5146 .77303 m .51464 .77471 L .51287 .77399 L F
.531 .468 .73 r
.37194 .70573 m .37323 .70168 L .37108 .70211 L F
.37194 .70573 m .37397 .70526 L .37323 .70168 L F
.567 .508 .748 r
.37194 .70573 m .37481 .70764 L .37397 .70526 L F
.663 .588 .761 r
.7705 .59953 m .77276 .59938 L .77185 .59592 L F
.657 .5 .659 r
.7705 .59953 m .77073 .60187 L .77276 .59938 L F
.061 0 0 r
.41884 .6937 m .41951 .69467 L .4212 .69383 L F
.41884 .6937 m .41756 .69566 L .41951 .69467 L F
.348 .304 .667 r
.47704 .785 m .47743 .78946 L .47751 .78623 L F
.234 .239 .66 r
.47751 .78623 m .47832 .7857 L .47704 .785 L F
.678 .208 .129 r
.56113 .7188 m .5598 .71931 L .55766 .71827 L F
.48 0 0 r
.56357 .72074 m .5598 .71931 L .56113 .7188 L F
.792 .581 .616 r
.63183 .51518 m .62901 .51483 L .63148 .51391 L F
.63183 .51518 m .62891 .51718 L .62901 .51483 L F
.63183 .51518 m .63112 .51754 L .62891 .51718 L F
0 0 0 r
.52766 .73609 m .52679 .73644 L .52937 .73633 L F
.52764 .7361 m .5252 .73718 L .52679 .73644 L F
.52766 .73609 m .52755 .73614 L .52764 .7361 L F
.52755 .73614 m .5252 .73718 L .52764 .7361 L F
.087 0 .4 r
.5267 .73412 m .5252 .73718 L .52766 .73609 L F
.5267 .73412 m .52666 .73638 L .5252 .73718 L F
.593 .492 .709 r
.52324 .73627 m .52475 .7374 L .52666 .73638 L F
.21 0 0 r
.52436 .73939 m .52377 .7382 L .5252 .73718 L F
.409 .046 .234 r
.52664 .73883 m .5252 .73718 L .52666 .73638 L F
.52664 .73883 m .52436 .73939 L .5252 .73718 L F
.593 .492 .709 r
.52475 .7374 m .52664 .73883 L .52666 .73654 L F
.52475 .7374 m .52666 .73654 L .52666 .73638 L F
.268 .084 .437 r
.57035 .68017 m .57144 .68155 L .57209 .67956 L F
.57035 .68017 m .57007 .68256 L .57144 .68155 L F
.802 .711 .763 r
.4959 .79175 m .49522 .78885 L .49403 .79131 L F
.85 .525 .437 r
.49403 .79131 m .49475 .79375 L .4959 .79175 L F
.648 .339 .434 r
.47252 .68546 m .4712 .68811 L .46904 .68756 L F
.666 .359 .444 r
.47472 .68749 m .47252 .68546 L .47477 .68577 L F
.47472 .68749 m .4712 .68811 L .47252 .68546 L F
.597 .747 .949 r
.78544 .60369 m .78226 .60415 L .78337 .60571 L F
.704 .579 .712 r
.53962 .74264 m .54078 .74683 L .54329 .744 L F
.585 .406 .605 r
.54078 .74683 m .5433 .7466 L .54329 .744 L F
.502 .376 .641 r
.54078 .74683 m .54318 .74908 L .5433 .7466 L F
.54078 .74683 m .54119 .74962 L .54318 .74908 L F
.546 .561 .821 r
.25518 .64931 m .25699 .64868 L .25495 .6488 L F
.352 .101 .387 r
.33765 .62921 m .33997 .62668 L .33962 .62864 L F
.376 .108 .373 r
.33912 .63138 m .33765 .62921 L .33962 .62864 L F
.33912 .63138 m .33721 .63201 L .33765 .62921 L F
.837 .486 0 r
.66122 .50447 m .66113 .50536 L .66009 .50385 L F
.66122 .50447 m .66184 .50651 L .66113 .50536 L F
.362 0 0 r
.287 .58609 m .28904 .58646 L .29039 .58604 L F
.463 0 0 r
.29039 .58604 m .28904 .58646 L .29273 .58685 L F
.194 .717 .86 r
.26854 .58396 m .27253 .58397 L .26999 .58433 L F
.523 .2 .361 r
.4575 .68982 m .45541 .68831 L .45762 .68819 L F
.4575 .68982 m .45484 .69034 L .45541 .68831 L F
.693 .842 .416 r
.60024 .746 m .59966 .74734 L .60107 .74466 L F
.743 .984 .763 r
.59825 .74845 m .59966 .74734 L .60024 .746 L F
.24 0 0 r
.42345 .70396 m .41974 .70599 L .42106 .70456 L F
.641 .723 .908 r
.47098 .65302 m .46742 .65198 L .46963 .65151 L F
.536 .639 .899 r
.47188 .65086 m .47098 .65302 L .46963 .65151 L F
.47188 .65086 m .47334 .65275 L .47098 .65302 L F
.809 .735 .783 r
.35959 .70349 m .35831 .70571 L .35585 .70315 L F
.78 .647 .715 r
.53039 .7408 m .53386 .74139 L .53278 .73844 L F
.379 0 0 r
.53386 .74139 m .53219 .74129 L .53039 .7408 L F
.656 .583 .762 r
.53278 .73844 m .53386 .74139 L .53645 .73925 L F
.881 .534 .387 r
.53219 .74129 m .53307 .74343 L .53386 .74139 L F
0 0 0 r
.47965 .78901 m .47743 .78946 L .47622 .79009 L F
.61 .248 .329 r
.56196 .71523 m .564 .71551 L .56543 .71324 L F
.806 .487 .45 r
.56543 .71324 m .56639 .71566 L .56777 .71294 L F
.56543 .71324 m .564 .71551 L .56639 .71566 L F
.494 .533 .826 r
.59314 .74753 m .59501 .74597 L .59209 .74581 L F
.59314 .74753 m .59558 .7484 L .59501 .74597 L F
.489 .077 .184 r
.38821 .65336 m .38884 .65226 L .38649 .6523 L F
.499 .063 .143 r
.38821 .65336 m .38649 .6523 L .38515 .65403 L F
0 .399 .81 r
.77954 .58434 m .77881 .58442 L .77687 .58228 L F
.77954 .58434 m .78046 .58513 L .77881 .58442 L F
.008 .064 .571 r
.50647 .75693 m .50505 .75576 L .50658 .75451 L F
.50647 .75693 m .50539 .75806 L .50505 .75576 L F
.131 0 .005 r
.39421 .71386 m .39318 .71552 L .39146 .71589 L F
.527 .211 .375 r
.39623 .71303 m .39318 .71552 L .39421 .71386 L F
.477 .347 .623 r
.48097 .7939 m .48068 .7965 L .47845 .79443 L F
.503 .178 .349 r
.48484 .74747 m .48755 .7491 L .48759 .74649 L F
.48484 .74747 m .48479 .74952 L .48755 .7491 L F
.79 .617 .666 r
.61789 .52901 m .61992 .52649 L .61835 .52659 L F
.759 .464 .485 r
.53048 .77897 m .52971 .78225 L .52822 .77935 L F
.559 .425 .655 r
.53199 .77724 m .53323 .77912 L .53048 .77897 L F
.534 .222 .384 r
.53048 .77897 m .53195 .78189 L .52971 .78225 L F
.53048 .77897 m .53323 .77912 L .53195 .78189 L F
0 0 .491 r
.65736 .49812 m .65898 .50139 L .65869 .50021 L F
.703 .323 0 r
.65898 .50139 m .65933 .50249 L .65869 .50021 L F
.501 .228 .431 r
.43189 .69962 m .43139 .70152 L .42922 .70179 L F
.439 .17 .408 r
.43314 .70102 m .43139 .70152 L .43189 .69962 L F
.495 .174 .351 r
.43416 .69942 m .43314 .70102 L .43189 .69962 L F
.696 .716 .194 r
.59836 .70979 m .59741 .71337 L .59741 .71343 L F
.817 .46 0 r
.59741 .71337 m .59823 .71504 L .59741 .71343 L F
.361 0 .196 r
.70968 .52375 m .70639 .52556 L .70709 .52431 L F
.976 .686 .402 r
.53497 .77072 m .53619 .77174 L .53444 .77154 L F
.53497 .77072 m .53501 .77118 L .53619 .77174 L F
.749 .622 .718 r
.53718 .77222 m .53444 .77154 L .53619 .77174 L F
.53783 .77238 m .53595 .77486 L .53444 .77154 L F
.976 .686 .402 r
.53501 .77118 m .5352 .77313 L .53619 .77174 L F
.749 .622 .718 r
.53783 .77238 m .53718 .77222 L .53619 .77174 L F
.666 .877 .977 r
.53989 .77127 m .53783 .77238 L .53619 .77174 L F
.51 .525 .807 r
.62553 .5124 m .62901 .51483 L .6287 .51266 L F
.515 .317 .549 r
.63148 .51391 m .62901 .51483 L .6287 .51266 L F
.304 0 0 r
.2606 .58702 m .2627 .58667 L .26432 .58494 L F
.332 0 .039 r
.2627 .58667 m .26644 .58447 L .26432 .58494 L F
.689 .723 .876 r
.76081 .62236 m .76311 .62135 L .75964 .62072 L F
.277 .111 .467 r
.50949 .80771 m .50817 .80795 L .50792 .81104 L F
.214 .739 .791 r
.39972 .71251 m .39838 .71261 L .39623 .71303 L F
0 0 0 r
.40181 .71208 m .39838 .71261 L .39972 .71251 L F
.18 .713 .826 r
.41145 .6495 m .41358 .64927 L .41491 .64934 L F
.112 0 0 r
.41358 .64927 m .41711 .64935 L .41491 .64934 L F
.424 .473 .807 r
.7042 .48899 m .70274 .49116 L .70195 .48944 L F
.7042 .48899 m .70739 .49358 L .70274 .49116 L F
.65 .353 .455 r
.47833 .68503 m .47472 .68749 L .47477 .68577 L F
.47833 .68503 m .477 .68777 L .47472 .68749 L F
.602 .301 .43 r
.48041 .68702 m .47833 .68503 L .4805 .6854 L F
.48041 .68702 m .477 .68777 L .47833 .68503 L F
.463 .669 .953 r
.53962 .74264 m .54329 .744 L .54177 .74238 L F
.575 .438 .657 r
.26896 .63066 m .26828 .63228 L .26616 .63292 L F
.387 .033 .237 r
.6948 .52526 m .69566 .52393 L .69267 .52591 L F
.377 .503 .859 r
.69433 .52071 m .69566 .52393 L .6971 .52232 L F
.239 .081 .455 r
.6948 .52526 m .6971 .52232 L .69566 .52393 L F
.569 .372 .575 r
.50539 .75806 m .50541 .76045 L .50313 .76086 L F
.085 0 .452 r
.50678 .75929 m .50541 .76045 L .50539 .75806 L F
.303 .006 .283 r
.27968 .61156 m .2785 .61047 L .28089 .61032 L F
.27968 .61156 m .27788 .61225 L .2785 .61047 L F
.369 0 .139 r
.41274 .66592 m .41148 .66793 L .40932 .66829 L F
.289 0 .094 r
.4136 .66731 m .41274 .66592 L .41499 .66552 L F
.4136 .66731 m .41148 .66793 L .41274 .66592 L F
.637 .715 .904 r
.73992 .61024 m .74388 .61224 L .74243 .60972 L F
.602 .671 .889 r
.74388 .61224 m .74477 .60889 L .74243 .60972 L F
.74388 .61224 m .74619 .6116 L .74477 .60889 L F
.578 .654 .888 r
.74388 .61224 m .74682 .61318 L .74619 .6116 L F
.454 .806 .998 r
.68364 .49823 m .6867 .49789 L .68664 .49861 L F
.568 .028 0 r
.68597 .4994 m .68364 .49823 L .68664 .49861 L F
.815 .882 .452 r
.68664 .49861 m .6867 .49789 L .68597 .4994 L F
.485 .679 .951 r
.54177 .74238 m .54329 .744 L .54443 .74269 L F
.175 .209 .658 r
.54329 .744 m .54507 .74605 L .54443 .74269 L F
.401 .26 .572 r
.5433 .7466 m .54507 .74605 L .54329 .744 L F
.695 .181 .003 r
.69604 .48836 m .69888 .49037 L .69981 .48984 L F
.897 .967 .65 r
.69981 .48984 m .70042 .48679 L .70195 .48944 L F
.69981 .48984 m .69888 .49037 L .70042 .48679 L F
.079 0 0 r
.49714 .75997 m .49873 .75968 L .49995 .75799 L F
.517 .09 .169 r
.49995 .75799 m .49873 .75968 L .49608 .75897 L F
.511 .441 .714 r
.48227 .65671 m .48344 .66127 L .48101 .6609 L F
.471 .523 .83 r
.48344 .66127 m .48398 .66241 L .48101 .6609 L F
.573 .491 .724 r
.48398 .66241 m .48175 .66294 L .48101 .6609 L F
.749 .594 .685 r
.55811 .69375 m .5612 .69403 L .56055 .6911 L F
.35 .11 .402 r
.5612 .69403 m .56417 .69119 L .56055 .6911 L F
.487 .178 .369 r
.39888 .67117 m .39586 .67373 L .39658 .67154 L F
.384 .786 .984 r
.48652 .76343 m .48833 .76311 L .48491 .76272 L F
.508 .34 .588 r
.48652 .76343 m .48863 .76584 L .48833 .76311 L F
.48652 .76343 m .4865 .76653 L .48863 .76584 L F
.794 .524 .53 r
.58261 .57719 m .58189 .57896 L .58005 .57667 L F
.08 0 .18 r
.58411 .5761 m .58189 .57896 L .58261 .57719 L F
.53 .507 .776 r
.53376 .76855 m .53071 .76664 L .53337 .76626 L F
.38 .812 .962 r
.28672 .651 m .29052 .65104 L .28887 .65058 L F
.249 .731 .93 r
.28887 .65058 m .29052 .65104 L .29241 .65093 L F
0 0 .106 r
.57357 .76205 m .57315 .76087 L .57317 .75996 L F
.57357 .76205 m .57243 .76337 L .57315 .76087 L F
0 0 .353 r
.59311 .68539 m .59379 .68754 L .59387 .68862 L F
.997 .766 .44 r
.59379 .68754 m .59455 .69074 L .59387 .68862 L F
.367 .215 .539 r
.46052 .77765 m .46047 .78003 L .46218 .77699 L F
.325 .14 .469 r
.73134 .50374 m .72904 .50692 L .72864 .50457 L F
0 0 .086 r
.5919 .73353 m .59203 .73232 L .59205 .72988 L F
.104 .276 .755 r
.5919 .73353 m .59323 .73543 L .59203 .73232 L F
.697 .599 .742 r
.53444 .77154 m .53595 .77486 L .53218 .7747 L F
.669 .473 .611 r
.53595 .77486 m .53199 .77724 L .53218 .7747 L F
.791 .654 .71 r
.59177 .55684 m .59344 .56027 L .58983 .56002 L F
.791 .662 .722 r
.58983 .56002 m .59344 .56027 L .59268 .56248 L F
.055 .367 .836 r
.64219 .53352 m .63958 .53287 L .64192 .53203 L F
0 .544 .767 r
.30554 .5896 m .30747 .58983 L .30914 .59015 L F
0 .549 .77 r
.30747 .58983 m .31104 .59037 L .30914 .59015 L F
.717 .386 .417 r
.49922 .77911 m .49763 .78165 L .49773 .77959 L F
.49922 .77911 m .50161 .78177 L .49763 .78165 L F
.588 .396 .588 r
.50307 .77652 m .50255 .78146 L .49922 .77911 L F
.675 .614 .779 r
.50255 .78146 m .50161 .78177 L .49922 .77911 L F
.353 0 0 r
.48387 .76663 m .48553 .76739 L .4865 .76653 L F
.768 .662 .746 r
.48545 .76585 m .48578 .76406 L .48667 .76512 L F
.023 .183 .692 r
.48522 .76588 m .48543 .76689 L .48387 .76663 L F
.48543 .76689 m .48542 .76734 L .48387 .76663 L F
.833 .771 .794 r
.48863 .76584 m .48522 .76588 L .48667 .76512 L F
.049 0 0 r
.4865 .76653 m .48553 .76739 L .48863 .76584 L F
.833 .771 .794 r
.48863 .76584 m .48553 .76739 L .48522 .76588 L F
.768 .662 .746 r
.48348 .76704 m .48568 .76572 L .48522 .76588 L F
.48568 .76572 m .48667 .76512 L .48544 .76576 L F
.48568 .76572 m .48544 .76576 L .48522 .76588 L F
.162 .295 .753 r
.4871 .76543 m .48698 .76729 L .48804 .76642 L F
.48578 .76406 m .48634 .76558 L .4871 .76543 L F
.48634 .76558 m .48698 .76729 L .4871 .76543 L F
.442 0 .029 r
.48114 .76706 m .48348 .76704 L .48522 .76588 L F
.768 .662 .746 r
.48348 .76704 m .48547 .76445 L .48545 .76585 L F
.48547 .76445 m .48578 .76406 L .48545 .76585 L F
.023 .183 .692 r
.48543 .76689 m .48553 .76739 L .48542 .76734 L F
.433 .235 .51 r
.34227 .62379 m .34193 .62604 L .33997 .62668 L F
.443 .221 .481 r
.34193 .62604 m .33962 .62864 L .33997 .62668 L F
.513 .23 .423 r
.63316 .55734 m .63186 .55854 L .63075 .55908 L F
0 0 0 r
.63571 .55521 m .63476 .55653 L .63316 .55734 L F
0 0 .014 r
.63316 .55734 m .63411 .55788 L .63186 .55854 L F
.63316 .55734 m .63476 .55653 L .63411 .55788 L F
.695 .546 .68 r
.58969 .57435 m .59324 .57655 L .58949 .57616 L F
.58969 .57435 m .59319 .57396 L .59324 .57655 L F
.253 .168 .562 r
.46291 .76364 m .46474 .76516 L .46456 .76314 L F
.46291 .76364 m .46309 .76613 L .46474 .76516 L F
.71 .362 .385 r
.54471 .76293 m .54319 .7654 L .54095 .76311 L F
.737 .459 .508 r
.54653 .76342 m .54319 .7654 L .54471 .76293 L F
.431 0 0 r
.63912 .49701 m .64305 .49613 L .64055 .49732 L F
.988 .812 .578 r
.61287 .53706 m .61232 .53979 L .61354 .54045 L F
.975 .849 .653 r
.6115 .54043 m .61354 .54045 L .61232 .53979 L F
.6115 .54043 m .61254 .54322 L .61354 .54045 L F
.125 0 0 r
.30946 .63239 m .30987 .63328 L .31129 .63152 L F
.30946 .63239 m .30788 .63387 L .30987 .63328 L F
.512 .159 .306 r
.54219 .7714 m .54462 .77126 L .54549 .76885 L F
0 0 0 r
.54709 .76803 m .54803 .76649 L .54549 .76885 L F
.579 .423 .634 r
.54462 .77126 m .54709 .76803 L .54549 .76885 L F
0 0 0 r
.63875 .54341 m .63688 .54465 L .64063 .54249 L F
.313 0 .264 r
.50572 .7356 m .50761 .73477 L .50863 .73211 L F
.521 .196 .357 r
.50761 .73477 m .51089 .73212 L .50863 .73211 L F
.612 .366 .52 r
.69433 .52071 m .69672 .51997 L .69432 .51786 L F
.891 .466 .15 r
.5664 .74347 m .56628 .74092 L .56506 .74035 L F
.5664 .74347 m .56812 .74462 L .56628 .74092 L F
.863 .429 .011 r
.56628 .74092 m .56812 .74462 L .56863 .74473 L F
.773 .654 .732 r
.5167 .72383 m .51548 .72744 L .51877 .7273 L F
.829 .583 .567 r
.51542 .72921 m .51877 .7273 L .51548 .72744 L F
.51542 .72921 m .51903 .72995 L .51877 .7273 L F
.575 .396 .601 r
.51877 .7273 m .52107 .72938 L .52219 .72702 L F
.51877 .7273 m .51903 .72995 L .52107 .72938 L F
.058 .231 .727 r
.50886 .74903 m .51092 .75138 L .51012 .75248 L F
.603 .323 .466 r
.51012 .75248 m .51222 .75448 L .50983 .75437 L F
.078 .261 .749 r
.51092 .75138 m .51222 .75448 L .51012 .75248 L F
.628 .568 .768 r
.51835 .7799 m .51897 .78236 L .51728 .7831 L F
.132 0 .176 r
.51819 .784 m .51728 .7831 L .51897 .78236 L F
.51819 .784 m .51621 .78551 L .51728 .7831 L F
.301 .062 .375 r
.46456 .76314 m .46718 .7595 L .46518 .7605 L F
.468 .212 .443 r
.34946 .61587 m .349 .61788 L .34694 .61835 L F
.43 .178 .429 r
.351 .6172 m .34946 .61587 L .35153 .61535 L F
.351 .6172 m .349 .61788 L .34946 .61587 L F
.406 .093 .319 r
.39286 .71796 m .39146 .71589 L .39318 .71552 L F
.427 .75 .994 r
.25495 .6488 m .25521 .64766 L .25339 .64801 L F
.25495 .6488 m .25699 .64868 L .25521 .64766 L F
.745 .59 .683 r
.77073 .60187 m .77408 .60466 L .77332 .6018 L F
.77073 .60187 m .77078 .60449 L .77408 .60466 L F
.551 .583 .84 r
.77078 .60449 m .7748 .60634 L .77408 .60466 L F
.613 .477 .672 r
.77408 .60466 m .776 .60191 L .77332 .6018 L F
.77408 .60466 m .77656 .60432 L .776 .60191 L F
.581 .353 .535 r
.77408 .60466 m .7748 .60634 L .77656 .60432 L F
.76 .58 .654 r
.59839 .69918 m .59926 .69649 L .59612 .69652 L F
.894 .983 .713 r
.61843 .49036 m .61666 .49301 L .61684 .49134 L F
.847 .995 .835 r
.61843 .49036 m .61896 .4882 L .62068 .48755 L F
.61843 .49036 m .61802 .48974 L .61896 .4882 L F
.926 .972 .701 r
.61843 .49036 m .61684 .49134 L .61802 .48974 L F
.804 .628 .664 r
.65758 .48788 m .66098 .48953 L .66078 .48698 L F
.609 .274 .376 r
.66063 .48663 m .65987 .48893 L .65758 .48788 L F
.66155 .48625 m .66145 .48641 L .66063 .48663 L F
.745 .85 .928 r
.66284 .48603 m .66078 .48698 L .66411 .48722 L F
.702 .237 .143 r
.66078 .48698 m .66304 .48858 L .66411 .48722 L F
.517 .411 .673 r
.66078 .48698 m .66098 .48953 L .66304 .48858 L F
.609 .274 .376 r
.66145 .48641 m .65987 .48893 L .66063 .48663 L F
.745 .85 .928 r
.66277 .48597 m .66241 .48615 L .66284 .48603 L F
.66241 .48615 m .66155 .48659 L .66284 .48603 L F
.66155 .48659 m .66154 .48663 L .66284 .48603 L F
.686 .598 .752 r
.66004 .48408 m .66277 .48597 L .66182 .48514 L F
.325 0 .199 r
.66214 .48796 m .66158 .48634 L .66182 .48514 L F
.66158 .48634 m .66155 .48625 L .66162 .48594 L F
.66158 .48634 m .66162 .48594 L .66182 .48514 L F
.745 .85 .928 r
.66155 .48659 m .66078 .48698 L .66154 .48663 L F
.648 .822 .967 r
.66277 .48597 m .66411 .48722 L .66655 .48639 L F
.624 .143 .092 r
.66411 .48722 m .66304 .48858 L .66651 .48886 L F
.639 .616 .81 r
.66411 .48722 m .66713 .48661 L .66655 .48639 L F
.541 .261 .439 r
.66411 .48722 m .66651 .48886 L .66713 .48661 L F
.442 .453 .775 r
.58687 .69056 m .58783 .68773 L .5854 .69012 L F
.58687 .69056 m .58833 .69139 L .58783 .68773 L F
.507 .437 .712 r
.58687 .69056 m .58981 .69317 L .58833 .69139 L F
.137 .103 .553 r
.77414 .58968 m .77326 .59097 L .77487 .59002 L F
.313 .288 .67 r
.77326 .59097 m .77599 .59164 L .77487 .59002 L F
.77326 .59097 m .77416 .5931 L .77599 .59164 L F
.281 0 0 r
.76704 .58776 m .7701 .58907 L .77159 .58854 L F
.309 .673 .975 r
.7701 .58907 m .77304 .58843 L .77159 .58854 L F
.7701 .58907 m .77414 .58968 L .77304 .58843 L F
.601 .556 .775 r
.62754 .49289 m .63103 .49597 L .6297 .49248 L F
.916 .878 .451 r
.54775 .76593 m .54803 .76649 L .54709 .76803 L F
.374 .05 .281 r
.33042 .63787 m .32757 .64003 L .32826 .63845 L F
.654 .517 .684 r
.76834 .60469 m .77078 .60449 L .77073 .60187 L F
.608 .451 .643 r
.76834 .60469 m .77107 .60659 L .77078 .60449 L F
.76834 .60469 m .76856 .60777 L .77107 .60659 L F
.451 .152 .367 r
.46747 .75754 m .46972 .75827 L .46967 .75698 L F
.554 .435 .671 r
.46718 .7595 m .46972 .75827 L .46747 .75754 L F
0 0 .061 r
.63807 .51729 m .63571 .52014 L .63648 .51858 L F
.473 .33 .605 r
.39197 .67971 m .3921 .68235 L .39017 .68275 L F
.489 .493 .788 r
.39289 .68403 m .39017 .68275 L .3921 .68235 L F
0 0 0 r
.36293 .70617 m .36102 .70773 L .36257 .70654 L F
.324 .3 .678 r
.36102 .70773 m .36289 .70983 L .36257 .70654 L F
.77 .522 .56 r
.78114 .6009 m .78398 .59909 L .78266 .59862 L F
.78114 .6009 m .78416 .60144 L .78398 .59909 L F
.976 .92 .622 r
.65438 .493 m .65371 .4923 L .65492 .48878 L F
.756 .344 .269 r
.65438 .493 m .65285 .49428 L .65371 .4923 L F
.65438 .493 m .65573 .49513 L .65285 .49428 L F
.799 .618 .058 r
.78239 .59565 m .78231 .59337 L .78222 .59477 L F
0 0 0 r
.78222 .59477 m .78231 .59337 L .78297 .59273 L F
0 .02 .593 r
.58674 .67955 m .58839 .68191 L .58869 .68342 L F
.924 .971 .764 r
.58869 .68342 m .58839 .68191 L .58702 .684 L F
.208 0 0 r
.31279 .64883 m .3114 .64995 L .30998 .64974 L F
.227 0 0 r
.31415 .64863 m .3114 .64995 L .31279 .64883 L F
.66 .549 .718 r
.48491 .66516 m .48253 .66623 L .48175 .66294 L F
.791 .662 .722 r
.58983 .56002 m .59268 .56248 L .58949 .562 L F
.805 .656 .698 r
.59268 .56248 m .59125 .5662 L .58949 .562 L F
.384 0 0 r
.33914 .72968 m .33844 .73014 L .33586 .72973 L F
.33586 .72973 m .33844 .73014 L .33914 .72968 L F
.447 .83 .6 r
.34009 .72892 m .33844 .73014 L .33914 .72968 L F
.34009 .72892 m .33844 .73014 L .33914 .72968 L F
.691 .463 .572 r
.63236 .5014 m .63239 .50374 L .62971 .50333 L F
.547 .337 .547 r
.6347 .50087 m .63239 .50374 L .63236 .5014 L F
.087 0 0 r
.63124 .50197 m .6347 .50087 L .63236 .5014 L F
.857 .767 .762 r
.59137 .54508 m .59298 .54618 L .59133 .54879 L F
.833 .781 .803 r
.5936 .54221 m .59298 .54618 L .59137 .54508 L F
.5936 .54221 m .59523 .54337 L .59298 .54618 L F
.128 0 0 r
.63759 .55399 m .63476 .55653 L .63571 .55521 L F
.976 .764 .552 r
.61745 .49862 m .61624 .49769 L .61649 .49538 L F
.705 .256 .182 r
.61745 .49862 m .61626 .49998 L .61624 .49769 L F
.61745 .49862 m .62099 .50083 L .61626 .49998 L F
.955 .862 .709 r
.6687 .52352 m .66638 .52567 L .66807 .52267 L F
.6687 .52352 m .66752 .52635 L .66638 .52567 L F
0 0 0 r
.5242 .81194 m .52575 .81117 L .52781 .8105 L F
.701 .632 .777 r
.73212 .61073 m .73333 .60645 L .73089 .60704 L F
.73212 .61073 m .73437 .60982 L .73333 .60645 L F
.809 .735 .783 r
.35959 .70349 m .35585 .70315 L .35651 .70479 L F
.892 .862 .804 r
.35651 .70479 m .3571 .70714 L .35959 .70349 L F
.222 0 0 r
.55761 .69516 m .5612 .69403 L .55811 .69375 L F
.55761 .69516 m .55939 .69505 L .5612 .69403 L F
.35 .11 .402 r
.5612 .69403 m .5632 .69342 L .56417 .69119 L F
.419 0 .027 r
.55939 .69505 m .5632 .69342 L .5612 .69403 L F
.358 .351 .715 r
.56273 .68815 m .56507 .69024 L .56558 .68792 L F
.56273 .68815 m .56417 .69119 L .56507 .69024 L F
.612 .74 .936 r
.72004 .49051 m .71673 .48961 L .71902 .48918 L F
.59 .754 .956 r
.72175 .48858 m .72004 .49051 L .71902 .48918 L F
.72175 .48858 m .72221 .49 L .72004 .49051 L F
.661 .241 .237 r
.61731 .50149 m .62041 .5032 L .62061 .50138 L F
.612 .942 .748 r
.62198 .49991 m .62099 .50083 L .62061 .50138 L F
0 0 .064 r
.62061 .50138 m .62041 .5032 L .62198 .49991 L F
.979 .902 .568 r
.59831 .70137 m .59752 .70422 L .59796 .70502 L F
.533 .188 .328 r
.53913 .77726 m .53542 .77975 L .53553 .77727 L F
.53913 .77726 m .53786 .7797 L .53542 .77975 L F
.703 .285 .249 r
.53913 .77726 m .53973 .77957 L .53786 .7797 L F
.53913 .77726 m .54151 .77917 L .53973 .77957 L F
.655 .338 .424 r
.53913 .77726 m .54256 .77734 L .54151 .77917 L F
.651 .584 .767 r
.48544 .79744 m .48736 .7974 L .48648 .79389 L F
.651 .579 .76 r
.48544 .79744 m .48658 .79788 L .48736 .7974 L F
.304 0 0 r
.48165 .78796 m .48397 .78764 L .48509 .78643 L F
.269 .4 .811 r
.48509 .78643 m .48754 .78783 L .48609 .78774 L F
.454 0 0 r
.48509 .78643 m .48635 .78736 L .48754 .78783 L F
.48509 .78643 m .48397 .78764 L .48635 .78736 L F
.669 .473 .611 r
.53595 .77486 m .53553 .77727 L .53199 .77724 L F
.66 .549 .718 r
.48491 .66516 m .48175 .66294 L .48398 .66241 L F
.734 .624 .736 r
.46532 .67081 m .46677 .67439 L .46895 .6713 L F
.548 .376 .6 r
.46895 .6713 m .46677 .67439 L .46893 .67395 L F
.68 .45 .567 r
.4663 .67616 m .46893 .67395 L .46677 .67439 L F
.822 .554 .534 r
.644 .53832 m .64206 .53754 L .64023 .53846 L F
0 0 0 r
.64515 .53733 m .64312 .5399 L .644 .53832 L F
.925 .852 .751 r
.59558 .53938 m .59523 .54337 L .5936 .54221 L F
.701 .463 .561 r
.52439 .72721 m .52768 .72916 L .52799 .72723 L F
.589 .335 .5 r
.52768 .72916 m .52989 .7292 L .52799 .72723 L F
.642 .331 .429 r
.52799 .72723 m .52989 .7292 L .53051 .72739 L F
.473 .44 .74 r
.36998 .69656 m .37105 .69294 L .36907 .69342 L F
.36998 .69656 m .37178 .69617 L .37105 .69294 L F
.494 .439 .725 r
.36998 .69656 m .37238 .6987 L .37178 .69617 L F
.341 0 .029 r
.42296 .6627 m .41934 .66473 L .42074 .66301 L F
.171 0 0 r
.69951 .51774 m .69672 .51997 L .69888 .51916 L F
0 0 0 r
.70218 .51532 m .69951 .51774 L .70152 .51681 L F
.70152 .51681 m .69951 .51774 L .69888 .51916 L F
.553 .75 .969 r
.64162 .48206 m .6402 .48407 L .639 .48248 L F
.64162 .48206 m .64265 .48358 L .6402 .48407 L F
.527 .523 .795 r
.57341 .69041 m .57051 .6878 L .57411 .68843 L F
.863 .984 .7 r
.5752 .68573 m .57411 .68843 L .57617 .68533 L F
0 0 0 r
.5752 .68573 m .57341 .69041 L .57411 .68843 L F
.721 .988 .823 r
.62353 .4852 m .62068 .48755 L .62177 .48586 L F
.719 .984 .792 r
.62068 .48755 m .61896 .4882 L .62177 .48586 L F
.951 .656 .44 r
.6676 .51802 m .66636 .51924 L .66523 .51716 L F
.6676 .51802 m .66787 .52039 L .66636 .51924 L F
0 0 0 r
.63238 .52318 m .6314 .52367 L .63398 .52122 L F
.63238 .52318 m .63398 .52122 L .63571 .52014 L F
.332 .756 .975 r
.2867 .63666 m .28852 .63653 L .28993 .63714 L F
.565 .865 .996 r
.28993 .63714 m .29074 .63577 L .29192 .6364 L F
.28993 .63714 m .28852 .63653 L .29074 .63577 L F
.534 .422 .672 r
.36462 .67433 m .3664 .67068 L .36414 .67195 L F
.643 .44 .593 r
.48162 .7789 m .48027 .78266 L .47834 .78279 L F
.793 .513 .512 r
.48162 .7789 m .48359 .78252 L .48027 .78266 L F
.695 .692 .843 r
.71368 .48982 m .71431 .49051 L .71094 .48995 L F
.681 .688 .851 r
.71673 .48961 m .71431 .49051 L .71368 .48982 L F
.584 .673 .901 r
.74682 .61318 m .74887 .61127 L .74619 .6116 L F
.74682 .61318 m .74917 .61275 L .74887 .61127 L F
.609 .676 .888 r
.6919 .48508 m .69031 .48746 L .68853 .48513 L F
.6919 .48508 m .69267 .48686 L .69031 .48746 L F
.335 .788 .95 r
.41711 .64935 m .41927 .64907 L .42062 .64946 L F
.143 0 0 r
.41927 .64907 m .42279 .64922 L .42062 .64946 L F
.82 .688 .719 r
.61219 .54534 m .6137 .54634 L .61254 .54322 L F
.918 .706 .6 r
.61219 .54534 m .61344 .54872 L .6137 .54634 L F
.723 .596 .713 r
.77073 .60187 m .77332 .6018 L .77276 .59938 L F
.671 .633 .804 r
.77332 .6018 m .77486 .59924 L .77276 .59938 L F
.77332 .6018 m .776 .60191 L .77486 .59924 L F
.426 .808 .991 r
.33933 .59288 m .33869 .59384 L .33716 .5932 L F
.33933 .59288 m .34075 .5935 L .33869 .59384 L F
.389 .056 .275 r
.52377 .7382 m .52084 .7402 L .5215 .73872 L F
.727 .492 .571 r
.53227 .76119 m .53198 .7639 L .52975 .76373 L F
.621 .617 .825 r
.53039 .75748 m .53227 .76119 L .53434 .75997 L F
.53039 .75748 m .53227 .76119 L .53434 .75997 L F
.974 .741 .522 r
.53145 .7611 m .53227 .76119 L .53434 .75997 L F
.53145 .7611 m .53198 .7639 L .53227 .76119 L F
.53227 .76119 m .53145 .7611 L .53434 .75997 L F
.53227 .76119 m .53198 .7639 L .53145 .7611 L F
.557 .473 .715 r
.53227 .76119 m .53285 .76373 L .53434 .75997 L F
.313 0 .174 r
.54767 .75237 m .54448 .75539 L .54552 .75469 L F
.615 .443 .626 r
.54552 .75469 m .54782 .75507 L .54767 .75237 L F
.313 0 .174 r
.54767 .75237 m .54752 .75319 L .54448 .75539 L F
.459 .84 .612 r
.54552 .75469 m .54448 .75539 L .54492 .75508 L F
.734 .299 .218 r
.54492 .75508 m .54782 .75507 L .54552 .75469 L F
.313 0 .174 r
.54492 .75508 m .54596 .75574 L .54448 .75539 L F
.837 .402 0 r
.54414 .75558 m .54448 .75539 L .543 .75376 L F
.459 .84 .612 r
.54473 .7552 m .54448 .75539 L .54414 .75558 L F
.54492 .75508 m .54448 .75539 L .54473 .7552 L F
.734 .299 .218 r
.54473 .7552 m .54543 .7554 L .54492 .75508 L F
.225 .255 .683 r
.54448 .75539 m .54596 .75574 L .54473 .7552 L F
.734 .299 .218 r
.54414 .75558 m .54525 .75543 L .54473 .7552 L F
.54525 .75543 m .54543 .7554 L .54473 .7552 L F
.54543 .7554 m .54782 .75507 L .54492 .75508 L F
.54543 .7554 m .54686 .75663 L .54782 .75507 L F
.313 0 .174 r
.54752 .75319 m .54647 .75491 L .54628 .7545 L F
.54752 .75319 m .54543 .7554 L .54549 .75467 L F
.551 .396 .624 r
.54782 .75507 m .55022 .75498 L .54992 .75198 L F
0 0 0 r
.54782 .75507 m .54872 .75427 L .55022 .75498 L F
.54782 .75507 m .54686 .75663 L .54872 .75427 L F
0 0 .336 r
.54852 .75453 m .54846 .75443 L .54872 .75427 L F
.54686 .75663 m .54673 .75546 L .54852 .75453 L F
.254 0 .159 r
.54872 .75427 m .54699 .75597 L .54713 .75525 L F
.551 .396 .624 r
.54782 .75507 m .54992 .75198 L .54767 .75237 L F
.254 0 .159 r
.54872 .75427 m .54713 .75525 L .54767 .75237 L F
.313 0 .174 r
.54752 .75319 m .54713 .75525 L .54675 .75444 L F
.54713 .75525 m .5469 .75537 L .54675 .75444 L F
.54675 .75445 m .54699 .75597 L .54596 .75574 L F
0 0 .336 r
.54673 .75546 m .54621 .75089 L .54852 .75453 L F
.54673 .75546 m .54689 .75548 L .54621 .75089 L F
.225 .255 .683 r
.54448 .75539 m .54654 .75304 L .54579 .75218 L F
.54448 .75539 m .54624 .75108 L .54586 .7518 L F
.547 .32 .522 r
.54276 .75136 m .54501 .75245 L .54571 .75209 L F
.54402 .75016 m .54571 .75209 L .54556 .74869 L F
.54276 .75136 m .54571 .75209 L .54402 .75016 L F
0 0 .357 r
.54556 .74869 m .54571 .75209 L .54586 .7518 L F
.54556 .74869 m .54586 .7518 L .54587 .75179 L F
.54556 .74869 m .54591 .75223 L .54652 .74997 L F
.418 .289 .596 r
.54276 .75136 m .54621 .75089 L .54501 .75245 L F
.225 .255 .683 r
.54501 .75245 m .54621 .75089 L .54393 .75292 L F
.547 .32 .522 r
.54501 .75245 m .54571 .75213 L .54571 .75209 L F
.225 .255 .683 r
.54571 .75213 m .54621 .75089 L .54501 .75245 L F
.54574 .75212 m .54586 .7518 L .54571 .75213 L F
.54586 .7518 m .54621 .75089 L .54571 .75213 L F
0 0 .357 r
.54587 .75179 m .54586 .7518 L .54587 .75179 L F
.225 .255 .683 r
.54448 .75539 m .54574 .75212 L .54485 .75265 L F
.547 .32 .522 r
.54501 .75245 m .54574 .7528 L .54571 .75213 L F
.225 .255 .683 r
.54586 .7518 m .54624 .75108 L .54621 .75089 L F
0 0 .357 r
.54587 .75179 m .54574 .7528 L .54591 .75223 L F
.54571 .75209 m .54574 .7528 L .54587 .75179 L F
.418 .289 .596 r
.54501 .75245 m .54621 .75089 L .54574 .7528 L F
.225 .255 .683 r
.54354 .75435 m .54485 .75265 L .543 .75376 L F
.54448 .75539 m .54485 .75265 L .54354 .75435 L F
.54574 .75212 m .54393 .75292 L .543 .75376 L F
.54448 .75539 m .54664 .7537 L .54654 .75304 L F
.54579 .75218 m .54654 .75304 L .54624 .75108 L F
0 0 .357 r
.54652 .74997 m .54591 .75223 L .54656 .75003 L F
0 0 .336 r
.54846 .75443 m .54625 .75096 L .54872 .75427 L F
.54625 .75096 m .54621 .75089 L .54625 .75095 L F
.54625 .75096 m .54625 .75095 L .54872 .75427 L F
.313 0 .174 r
.54713 .75525 m .54699 .75597 L .5469 .75537 L F
.225 .255 .683 r
.54663 .75371 m .54699 .75597 L .54664 .7537 L F
.313 0 .174 r
.54628 .7545 m .54596 .75574 L .54543 .7554 L F
.54647 .75491 m .54596 .75574 L .54628 .7545 L F
.54549 .75467 m .54543 .7554 L .54492 .75508 L F
.225 .255 .683 r
.54492 .75505 m .54697 .75596 L .54663 .75371 L F
.54697 .75596 m .54699 .75597 L .54663 .75371 L F
.826 .687 .71 r
.54621 .75089 m .54699 .75597 L .54872 .75427 L F
.254 0 .159 r
.54872 .75427 m .54767 .75237 L .54992 .75198 L F
.892 .811 .762 r
.54667 .75228 m .54833 .75314 L .54975 .75012 L F
.54646 .75243 m .5467 .75252 L .54667 .75228 L F
.5467 .75252 m .54833 .75314 L .54667 .75228 L F
0 0 .336 r
.54689 .75548 m .547 .7555 L .54621 .75089 L F
.547 .7555 m .54712 .75551 L .54688 .75432 L F
.547 .7555 m .54688 .75432 L .54621 .75089 L F
.54686 .75663 m .547 .75603 L .54673 .75546 L F
.547 .75603 m .54712 .75551 L .54673 .75546 L F
.734 .299 .218 r
.54525 .75543 m .54542 .75555 L .54543 .7554 L F
.54542 .75555 m .54686 .75663 L .54543 .7554 L F
.54414 .75558 m .54603 .75631 L .54525 .75543 L F
.54603 .75631 m .54686 .75663 L .54525 .75543 L F
.225 .255 .683 r
.54473 .7552 m .54519 .75536 L .54492 .75505 L F
.54519 .75536 m .54699 .75597 L .54492 .75505 L F
.54596 .75574 m .54699 .75597 L .54473 .7552 L F
.877 .858 .819 r
.61454 .51045 m .6125 .51035 L .61337 .50925 L F
.61454 .51045 m .6125 .51306 L .6125 .51035 L F
.87 .864 .831 r
.61738 .50684 m .61454 .51045 L .61337 .50925 L F
.459 .302 .58 r
.37011 .65764 m .37194 .65903 L .37201 .65702 L F
.37011 .65764 m .37008 .65975 L .37194 .65903 L F
.422 .848 .952 r
.31141 .60173 m .3119 .60104 L .30995 .60138 L F
.31141 .60173 m .31361 .6012 L .3119 .60104 L F
.8 .391 .274 r
.56737 .72338 m .56357 .72074 L .56515 .72132 L F
.538 .532 .796 r
.62977 .48069 m .62866 .48418 L .62796 .4821 L F
.62977 .48069 m .63088 .48404 L .62866 .48418 L F
.649 .687 .872 r
.45252 .65725 m .45501 .66039 L .45741 .66009 L F
.598 .574 .798 r
.45501 .66039 m .4585 .6632 L .45741 .66009 L F
.4 .425 .771 r
.58982 .72479 m .59076 .72843 L .59154 .72694 L F
.993 .807 .553 r
.59205 .72988 m .59154 .72694 L .59076 .72843 L F
.81 .669 .707 r
.67713 .52306 m .67947 .52361 L .68065 .52119 L F
.489 .307 .56 r
.53529 .76348 m .53337 .76626 L .53285 .76373 L F
.53529 .76348 m .53543 .76596 L .53337 .76626 L F
.215 .014 .378 r
.53543 .76596 m .53376 .76855 L .53337 .76626 L F
.123 .622 .905 r
.55392 .78531 m .55506 .78591 L .55142 .7851 L F
.55392 .78531 m .55142 .7851 L .55167 .78577 L F
.631 .646 .847 r
.69816 .49609 m .69997 .49393 L .69737 .49443 L F
.69816 .49609 m .70046 .49576 L .69997 .49393 L F
.615 .469 .66 r
.69816 .49609 m .69818 .49843 L .70046 .49576 L F
.429 .487 .818 r
.63663 .53824 m .63714 .53898 L .63697 .53608 L F
.471 .343 .625 r
.55176 .73293 m .55275 .73552 L .55058 .73574 L F
.439 .207 .463 r
.55275 .73552 m .55168 .7376 L .55058 .73574 L F
.352 .813 .927 r
.42624 .66251 m .42514 .66228 L .42296 .6627 L F
.059 .624 .712 r
.42857 .66203 m .42514 .66228 L .42624 .66251 L F
.522 .34 .576 r
.27592 .61287 m .27581 .61519 L .27377 .61564 L F
.454 .179 .406 r
.27534 .6171 m .27377 .61564 L .27581 .61519 L F
.27534 .6171 m .27323 .6176 L .27377 .61564 L F
.483 .881 .955 r
.48766 .77418 m .48629 .77496 L .48807 .77464 L F
.734 .587 .691 r
.48629 .77496 m .48625 .77719 L .48807 .77464 L F
.963 .631 .305 r
.65457 .52363 m .65505 .52419 L .65578 .52714 L F
.429 0 .089 r
.57667 .67714 m .58038 .67575 L .57754 .67617 L F
.651 .543 .718 r
.46053 .67103 m .46093 .6743 L .4632 .67156 L F
.532 .393 .637 r
.46093 .6743 m .46116 .67688 L .46315 .67636 L F
.713 .473 .56 r
.52107 .72938 m .52439 .72721 L .52219 .72702 L F
.572 .509 .746 r
.37108 .70211 m .37323 .70168 L .37238 .6987 L F
.627 .938 .96 r
.51581 .76001 m .51527 .7612 L .51361 .76098 L F
.819 .828 .856 r
.35651 .70479 m .35389 .7073 L .3571 .70714 L F
.83 .803 .826 r
.35389 .7073 m .3556 .70858 L .3571 .70714 L F
.562 .42 .646 r
.58869 .74148 m .58885 .73846 L .58746 .73795 L F
.58869 .74148 m .59091 .74076 L .58885 .73846 L F
.596 .535 .757 r
.73027 .60527 m .73089 .60704 L .73333 .60645 L F
.588 .584 .815 r
.49029 .66602 m .4886 .66812 L .48815 .66667 L F
.49029 .66602 m .4909 .6677 L .4886 .66812 L F
.643 .515 .693 r
.4909 .6677 m .48934 .67178 L .4886 .66812 L F
.792 .669 .728 r
.6239 .51215 m .6245 .50865 L .62553 .5124 L F
.821 .639 .657 r
.62351 .51491 m .62553 .5124 L .6239 .51215 L F
.951 .804 .663 r
.62234 .51402 m .62351 .51491 L .6239 .51215 L F
.62234 .51402 m .6239 .51215 L .62553 .5124 L F
.62234 .51402 m .62553 .5124 L .62432 .51241 L F
0 0 .148 r
.62723 .50866 m .62553 .5124 L .6245 .50865 L F
.62723 .50866 m .6269 .51069 L .62553 .5124 L F
.641 .966 .841 r
.6269 .51069 m .62432 .51241 L .62553 .5124 L F
.963 .67 .426 r
.59823 .71504 m .59848 .71808 L .59997 .71854 L F
.985 .774 .537 r
.59838 .72045 m .59997 .71854 L .59848 .71808 L F
.59838 .72045 m .5995 .72145 L .59997 .71854 L F
0 0 0 r
.75061 .59281 m .75064 .59307 L .74805 .59383 L F
0 0 .194 r
.75286 .58979 m .75061 .59281 L .75314 .59041 L F
.75286 .58979 m .75219 .59176 L .75061 .59281 L F
0 0 0 r
.75061 .59281 m .75219 .59176 L .75064 .59307 L F
.379 0 .045 r
.42922 .70179 m .42782 .70345 L .42563 .70368 L F
.354 0 .032 r
.43139 .70152 m .42782 .70345 L .42922 .70179 L F
.716 .671 .804 r
.46532 .67081 m .46895 .6713 L .46757 .66826 L F
.557 .558 .81 r
.46895 .6713 m .46986 .66772 L .46757 .66826 L F
.46895 .6713 m .47108 .67094 L .46986 .66772 L F
.628 .493 .679 r
.46893 .67395 m .47108 .67094 L .46895 .6713 L F
.845 .573 .526 r
.48451 .80112 m .48658 .79788 L .4841 .79974 L F
.48451 .80112 m .48744 .80224 L .48658 .79788 L F
.253 0 .275 r
.49593 .74102 m .49703 .74257 L .49856 .74075 L F
.49593 .74102 m .49523 .7436 L .49703 .74257 L F
.48 .333 .604 r
.46129 .76901 m .46326 .76861 L .46309 .76613 L F
.466 .351 .638 r
.46172 .77155 m .46326 .76861 L .46129 .76901 L F
.839 .682 .688 r
.60373 .73793 m .60586 .73858 L .60451 .73534 L F
.817 .726 .765 r
.60377 .74122 m .60586 .73858 L .60373 .73793 L F
.552 .496 .746 r
.36863 .69095 m .36985 .68797 L .36751 .68787 L F
.36863 .69095 m .37073 .69055 L .36985 .68797 L F
.506 .393 .659 r
.36907 .69342 m .37073 .69055 L .36863 .69095 L F
.72 .533 .637 r
.59324 .57655 m .59681 .5768 L .59671 .57915 L F
.557 .396 .619 r
.59681 .5768 m .59902 .57873 L .59671 .57915 L F
.647 .381 .502 r
.59901 .57667 m .59902 .57873 L .59681 .5768 L F
.746 .445 .473 r
.49508 .8051 m .49447 .803 L .49203 .80251 L F
.914 .831 .75 r
.6125 .51306 m .61034 .51378 L .6125 .51035 L F
.6125 .51306 m .61161 .51489 L .61034 .51378 L F
.536 .341 .564 r
.63999 .50993 m .64238 .5094 L .64215 .50705 L F
.532 .338 .563 r
.64215 .50705 m .64418 .50856 L .64453 .50635 L F
.64215 .50705 m .64238 .5094 L .64418 .50856 L F
.622 .568 .772 r
.4888 .78923 m .48609 .78774 L .48754 .78783 L F
.561 .519 .765 r
.77276 .59938 m .77416 .59536 L .77185 .59592 L F
.77276 .59938 m .77486 .59924 L .77416 .59536 L F
.204 .061 .453 r
.51262 .77983 m .51098 .78331 L .51244 .78254 L F
.388 .69 .979 r
.6322 .52283 m .6314 .52367 L .63238 .52318 L F
0 .462 .796 r
.47048 .79808 m .4723 .7984 L .46913 .79669 L F
.47048 .79808 m .47372 .79907 L .4723 .7984 L F
.859 .572 .501 r
.67236 .50378 m .67396 .5059 L .67262 .50504 L F
.5 0 0 r
.67262 .50504 m .67478 .50699 L .67599 .508 L F
.859 .572 .501 r
.67396 .5059 m .67478 .50699 L .67262 .50504 L F
.531 0 0 r
.67091 .50394 m .67262 .50504 L .67297 .5043 L F
.66996 .50377 m .67262 .50504 L .67091 .50394 L F
.523 .8 .996 r
.30025 .58721 m .29982 .58862 L .29831 .58763 L F
.30025 .58721 m .30183 .58823 L .29982 .58862 L F
0 0 0 r
.64427 .54965 m .6429 .55062 L .64574 .54908 L F
.64427 .54965 m .64248 .55098 L .6429 .55062 L F
.917 .615 .456 r
.53285 .76373 m .53185 .76558 L .53198 .7639 L F
.744 .765 .869 r
.656 .54329 m .65937 .5434 L .65765 .5425 L F
.798 .748 .806 r
.65765 .5425 m .65937 .5434 L .66183 .5408 L F
.807 .926 .547 r
.55294 .78866 m .55506 .78591 L .55392 .78531 L F
.55294 .78866 m .55326 .78905 L .55506 .78591 L F
.863 .984 .7 r
.5752 .68573 m .57617 .68533 L .57562 .68521 L F
0 0 .285 r
.57756 .68409 m .57617 .68533 L .57672 .68395 L F
.544 .928 .84 r
.57756 .68409 m .57562 .68521 L .57617 .68533 L F
.389 .748 .992 r
.26402 .65234 m .26762 .653 L .26597 .6517 L F
.642 .844 .977 r
.26762 .653 m .26819 .65139 L .26597 .6517 L F
.26762 .653 m .26954 .6524 L .26819 .65139 L F
.487 .793 .999 r
.3265 .60419 m .32697 .60279 L .32502 .60299 L F
.3265 .60419 m .32844 .60379 L .32697 .60279 L F
.593 .659 .884 r
.3265 .60419 m .32903 .60474 L .32844 .60379 L F
.35 0 .129 r
.55022 .75498 m .55357 .75244 L .54992 .75198 L F
.5 .562 .85 r
.55469 .75606 m .55666 .75577 L .55326 .75468 L F
0 .18 .689 r
.55268 .75443 m .55469 .75606 L .55359 .755 L F
.5 .562 .85 r
.55469 .75606 m .55326 .75468 L .55297 .75459 L F
0 .18 .689 r
.55359 .755 m .55469 .75606 L .5539 .75519 L F
.35 0 .129 r
.55173 .75384 m .55268 .75443 L .55357 .75244 L F
0 .18 .689 r
.55268 .75443 m .5539 .75519 L .55331 .75453 L F
0 0 0 r
.553 .75448 m .55268 .75443 L .55297 .75459 L F
.55357 .75244 m .55268 .75443 L .553 .75448 L F
0 .18 .689 r
.55268 .75443 m .55265 .75414 L .55098 .75331 L F
.812 .521 .497 r
.55144 .753 m .55243 .75403 L .55098 .75331 L F
0 .18 .689 r
.55268 .75443 m .55302 .75449 L .55265 .75414 L F
.812 .521 .497 r
.55298 .75445 m .55297 .75459 L .55144 .753 L F
0 .18 .689 r
.55265 .75414 m .55264 .75406 L .55098 .75331 L F
.812 .521 .497 r
.55243 .75403 m .55297 .75459 L .55098 .75331 L F
.289 0 .069 r
.55098 .75331 m .54992 .75198 L .55344 .75174 L F
.812 .521 .497 r
.55322 .75182 m .55098 .75331 L .55344 .75174 L F
.55322 .75182 m .55298 .75445 L .55144 .753 L F
0 .18 .689 r
.55302 .75449 m .55307 .7545 L .55265 .75414 L F
.547 .531 .789 r
.553 .75443 m .5557 .75257 L .55332 .7531 L F
.55297 .75459 m .55307 .75451 L .553 .75443 L F
.55307 .75451 m .5557 .75257 L .553 .75443 L F
0 .18 .689 r
.55307 .7545 m .55331 .75453 L .55287 .75427 L F
.511 .625 .901 r
.55264 .75406 m .553 .75443 L .55305 .75424 L F
0 .18 .689 r
.553 .75443 m .55287 .75427 L .55283 .75425 L F
.55307 .7545 m .55287 .75427 L .553 .75443 L F
.55307 .7545 m .55283 .75425 L .55265 .75414 L F
.511 .625 .901 r
.55098 .75331 m .55297 .75459 L .553 .75443 L F
.55098 .75331 m .553 .75443 L .55264 .75406 L F
.55264 .75406 m .55305 .75424 L .55185 .75323 L F
0 .18 .689 r
.55264 .75406 m .55331 .75453 L .55262 .75377 L F
.55265 .75414 m .55283 .75425 L .55264 .75406 L F
.55283 .75425 m .55331 .75453 L .55264 .75406 L F
0 0 0 r
.55357 .75244 m .55297 .75459 L .55322 .75182 L F
.511 .625 .901 r
.55185 .75323 m .55305 .75424 L .55332 .7531 L F
.55098 .75331 m .55264 .75406 L .55185 .75323 L F
0 .18 .689 r
.55264 .75406 m .55262 .75377 L .55098 .75331 L F
.35 0 .129 r
.55022 .75498 m .55268 .75443 L .55173 .75384 L F
.81 .996 .769 r
.55357 .75244 m .55322 .75182 L .55344 .75174 L F
.213 0 0 r
.63075 .55908 m .6324 .55926 L .62947 .56123 L F
.63075 .55908 m .63186 .55854 L .6324 .55926 L F
.435 .192 .446 r
.34694 .61835 m .34638 .62042 L .34433 .62114 L F
.432 .189 .444 r
.34835 .6195 m .34694 .61835 L .349 .61788 L F
.34835 .6195 m .34638 .62042 L .34694 .61835 L F
.524 .177 .321 r
.42551 .69283 m .4289 .69038 L .42669 .69071 L F
.614 .759 .948 r
.27583 .63427 m .27545 .63653 L .27403 .63432 L F
.27583 .63427 m .27755 .63577 L .27545 .63653 L F
.548 .552 .81 r
.37936 .7272 m .37792 .72433 L .37912 .72725 L F
.58 .572 .808 r
.33929 .71575 m .34267 .71846 L .34147 .71589 L F
.703 .644 .788 r
.7526 .58748 m .75314 .59041 L .75607 .58859 L F
.422 .041 .209 r
.40926 .70966 m .40743 .70971 L .41035 .70859 L F
.32 0 0 r
.41176 .7091 m .40926 .70966 L .41035 .70859 L F
.689 .403 .484 r
.51685 .77484 m .51354 .77702 L .51477 .77493 L F
.61 .574 .789 r
.39695 .69091 m .39548 .6929 L .39458 .69143 L F
.39695 .69091 m .39824 .69429 L .39548 .6929 L F
.464 .289 .558 r
.64414 .53109 m .64219 .53352 L .64192 .53203 L F
.166 0 0 r
.3058 .60136 m .30781 .60161 L .30428 .60129 L F
.519 .428 .692 r
.36643 .66822 m .36797 .66546 L .36604 .66584 L F
.044 0 0 r
.46053 .67103 m .46185 .67067 L .4625 .66952 L F
.651 .543 .718 r
.46053 .67103 m .4632 .67156 L .46185 .67067 L F
.882 .656 .591 r
.66631 .51508 m .66344 .51424 L .66363 .51193 L F
.909 .695 .6 r
.66631 .51508 m .66354 .51637 L .66344 .51424 L F
.66631 .51508 m .66523 .51716 L .66354 .51637 L F
.36 .811 .944 r
.42279 .64922 m .42501 .64884 L .4263 .64915 L F
.315 .759 .963 r
.42501 .64884 m .42846 .64923 L .4263 .64915 L F
.559 .551 .802 r
.3273 .61013 m .32815 .61303 L .33016 .61178 L F
.392 .342 .682 r
.32815 .61303 m .33015 .61456 L .33016 .61178 L F
.32815 .61303 m .32871 .61557 L .33015 .61456 L F
.538 .878 .989 r
.29954 .83021 m .29794 .82976 L .29754 .83088 L F
.29754 .83088 m .29794 .82976 L .29954 .83021 L F
.092 .635 .844 r
.27414 .58436 m .27779 .58479 L .27574 .58515 L F
.826 .35 0 r
.55783 .78272 m .5606 .78572 L .56041 .78539 L F
.315 .133 .468 r
.56041 .78539 m .55845 .7886 L .55829 .7875 L F
.658 .226 .21 r
.55982 .7873 m .55988 .7884 L .55968 .78829 L F
0 0 .075 r
.55845 .7886 m .55992 .78663 L .55982 .7873 L F
.736 .915 .954 r
.55829 .7875 m .55845 .7886 L .55982 .7873 L F
.658 .226 .21 r
.55982 .7873 m .55968 .78829 L .55829 .7875 L F
0 0 .075 r
.55992 .78663 m .5606 .78572 L .55982 .7873 L F
.548 .703 .942 r
.67396 .49212 m .67563 .4913 L .67185 .49022 L F
.67396 .49212 m .6767 .49231 L .67563 .4913 L F
.61 .406 .58 r
.60817 .57437 m .61016 .57549 L .60713 .57637 L F
.60817 .57437 m .61042 .57391 L .61016 .57549 L F
.358 .119 .409 r
.34227 .62379 m .34433 .62114 L .34436 .62317 L F
.444 .243 .512 r
.34569 .62233 m .34433 .62114 L .34638 .62042 L F
.34569 .62233 m .34436 .62317 L .34433 .62114 L F
.502 0 0 r
.53812 .72358 m .54035 .72403 L .5422 .72366 L F
.746 .318 .233 r
.54035 .72403 m .54341 .72476 L .5422 .72366 L F
.772 .665 .746 r
.6154 .50403 m .61738 .50684 L .61529 .50604 L F
.87 .864 .831 r
.61738 .50684 m .61337 .50925 L .61529 .50604 L F
.672 .584 .748 r
.45741 .66009 m .4585 .6632 L .46062 .6606 L F
.799 .639 .684 r
.54376 .77736 m .54151 .77917 L .54256 .77734 L F
.582 .283 .426 r
.48669 .67589 m .4843 .67454 L .48623 .67379 L F
.48669 .67589 m .48369 .67641 L .4843 .67454 L F
.776 .269 0 r
.49804 .81084 m .49587 .80811 L .49448 .80761 L F
.627 .344 .469 r
.49804 .81084 m .49767 .80842 L .49587 .80811 L F
.237 0 .038 r
.70442 .51452 m .70218 .51532 L .70152 .51681 L F
.455 .37 .67 r
.26883 .62379 m .26737 .62647 L .26681 .62432 L F
.755 .827 .908 r
.46185 .67067 m .46465 .66784 L .4625 .66952 L F
0 0 0 r
.56216 .78499 m .5634 .7833 L .56458 .78203 L F
.529 .306 .52 r
.34336 .84161 m .34527 .84388 L .34559 .84121 L F
.34336 .84161 m .34306 .84403 L .34527 .84388 L F
.34527 .84388 m .34336 .84161 L .34559 .84121 L F
.34527 .84388 m .34306 .84403 L .34336 .84161 L F
.34336 .84161 m .34306 .84403 L .34527 .84388 L F
.918 .706 .6 r
.61219 .54534 m .61251 .54902 L .61344 .54872 L F
.938 .633 .436 r
.61251 .54902 m .61354 .55105 L .61344 .54872 L F
.652 .479 .638 r
.61266 .57099 m .61042 .57391 L .61082 .57173 L F
.582 .45 .666 r
.64022 .51198 m .64238 .5094 L .63999 .50993 L F
.886 .894 .831 r
.58042 .73317 m .58294 .73145 L .58314 .73234 L F
.798 .349 0 r
.58054 .72809 m .58314 .73234 L .58294 .73145 L F
.887 .637 .556 r
.62636 .4923 m .6298 .49015 L .62894 .48979 L F
.54 .845 .999 r
.63103 .48884 m .6321 .48959 L .63339 .48826 L F
.63103 .48884 m .6321 .48959 L .63339 .48826 L F
.189 0 .03 r
.63143 .48872 m .6311 .48886 L .63103 .48884 L F
.529 .84 .999 r
.63103 .48884 m .63101 .48886 L .62906 .48808 L F
.63101 .48886 m .6298 .49015 L .62932 .48881 L F
.63101 .48886 m .62932 .48881 L .62906 .48808 L F
.583 .925 .959 r
.63103 .48884 m .62894 .48979 L .6298 .49015 L F
.189 0 .03 r
.6311 .48886 m .62796 .49133 L .62894 .48979 L F
.63143 .48872 m .63123 .48887 L .6311 .48886 L F
.63123 .48887 m .62796 .49133 L .6311 .48886 L F
.6311 .48886 m .62894 .48979 L .63103 .48884 L F
.529 .84 .999 r
.63103 .48884 m .62906 .48808 L .62861 .48681 L F
.63103 .48884 m .6321 .48959 L .6298 .49015 L F
.583 .925 .959 r
.63103 .48884 m .6298 .49015 L .6321 .48959 L F
.464 .168 .377 r
.53854 .763 m .53543 .76596 L .53529 .76348 L F
.079 .598 .88 r
.67516 .54004 m .67849 .54091 L .67719 .54029 L F
.193 .679 .927 r
.67719 .54029 m .67849 .54091 L .68093 .5407 L F
0 0 .12 r
.50045 .80998 m .50004 .81124 L .50008 .81219 L F
.21 0 0 r
.63421 .48414 m .63658 .48407 L .63647 .48332 L F
.527 .361 .599 r
.63421 .48414 m .63684 .48565 L .63658 .48407 L F
.63421 .48414 m .63464 .48696 L .63684 .48565 L F
.476 .791 .999 r
.29848 .65041 m .30172 .65095 L .30016 .65061 L F
.425 .797 .994 r
.30172 .65095 m .30236 .64997 L .30016 .65061 L F
.30172 .65095 m .30393 .65067 L .30236 .64997 L F
.806 .842 .878 r
.59694 .74989 m .59706 .74797 L .59558 .7484 L F
.59694 .74989 m .59825 .74845 L .59706 .74797 L F
.554 0 0 r
.50152 .81504 m .50294 .81466 L .50497 .81586 L F
.655 .241 .246 r
.50294 .81466 m .50623 .81532 L .50497 .81586 L F
.771 .467 .472 r
.49018 .81022 m .49367 .81078 L .49208 .81317 L F
.69 .364 .418 r
.49367 .81078 m .49591 .81305 L .49208 .81317 L F
.455 .128 .322 r
.62035 .56812 m .62343 .56589 L .62276 .56761 L F
.185 0 .228 r
.62276 .56761 m .62343 .56589 L .62517 .56484 L F
.661 .206 .161 r
.53406 .73536 m .53108 .73571 L .53278 .73844 L F
.596 .121 .098 r
.5538 .71652 m .55069 .71732 L .55037 .71596 L F
.5538 .71652 m .55284 .71792 L .55069 .71732 L F
0 .416 .799 r
.55766 .71827 m .55668 .71759 L .5538 .71652 L F
.113 .666 .753 r
.55668 .71759 m .55284 .71792 L .5538 .71652 L F
.89 .724 .67 r
.67994 .52819 m .68175 .52897 L .68042 .52583 L F
.767 .261 0 r
.68108 .52962 m .68175 .52897 L .67994 .52819 L F
.704 .174 0 r
.68403 .53134 m .68175 .52897 L .68108 .52962 L F
.659 .9 .981 r
.75814 .58743 m .7613 .58716 L .76029 .58622 L F
.619 .794 .966 r
.7613 .58716 m .76239 .5854 L .76029 .58622 L F
.7613 .58716 m .76328 .58662 L .76239 .5854 L F
.566 .268 .422 r
.53621 .75204 m .53756 .75428 L .5385 .75207 L F
.53621 .75204 m .53515 .75458 L .53756 .75428 L F
.342 .02 .266 r
.32562 .64075 m .32485 .64257 L .32288 .64313 L F
.291 0 .227 r
.32757 .64003 m .32485 .64257 L .32562 .64075 L F
.954 .898 .731 r
.61649 .49538 m .61684 .49134 L .61666 .49301 L F
.623 .341 .469 r
.61901 .55006 m .62168 .54832 L .61947 .54899 L F
.588 .573 .804 r
.73437 .60982 m .73566 .6061 L .73333 .60645 L F
.73437 .60982 m .73668 .60936 L .73566 .6061 L F
.798 .648 .697 r
.59254 .5547 m .59177 .55684 L .59055 .55347 L F
.639 .841 .978 r
.28102 .63591 m .27755 .63577 L .27953 .63494 L F
.568 .781 .979 r
.2816 .63419 m .28102 .63591 L .27953 .63494 L F
.2816 .63419 m .28309 .63536 L .28102 .63591 L F
.569 .512 .752 r
.72951 .60171 m .73027 .60527 L .73245 .60342 L F
.596 .535 .757 r
.73027 .60527 m .73333 .60645 L .73245 .60342 L F
.721 .201 0 r
.55798 .73466 m .55746 .73324 L .55599 .7326 L F
.55798 .73466 m .55915 .73533 L .55746 .73324 L F
.76 .291 .13 r
.55746 .73324 m .55915 .73533 L .55909 .73435 L F
.854 .624 .589 r
.49608 .75897 m .49465 .75974 L .49714 .75997 L F
.856 .64 .61 r
.49465 .75974 m .49606 .76283 L .49714 .75997 L F
.724 .669 .795 r
.49606 .76283 m .49873 .75968 L .49714 .75997 L F
0 0 0 r
.36293 .70617 m .3634 .70391 L .36531 .70457 L F
.36293 .70617 m .36326 .70644 L .3634 .70391 L F
.36293 .70617 m .36257 .70654 L .36326 .70644 L F
.465 .2 .426 r
.35214 .7353 m .3541 .73509 L .35491 .73314 L F
.74 .56 .65 r
.58949 .57616 m .59324 .57655 L .59108 .57871 L F
.702 .501 .613 r
.59108 .57871 m .59324 .57655 L .59324 .57933 L F
.72 .533 .637 r
.59324 .57655 m .59671 .57915 L .59324 .57933 L F
.402 .481 .826 r
.77486 .59924 m .776 .60191 L .77788 .60058 L F
.636 .642 .839 r
.77656 .60432 m .77788 .60058 L .776 .60191 L F
.058 0 .105 r
.6324 .55926 m .63186 .55854 L .63411 .55788 L F
.658 .598 .776 r
.48898 .68239 m .4852 .67946 L .48709 .67947 L F
.732 .534 .624 r
.48898 .68239 m .48879 .6854 L .48637 .68484 L F
.465 .598 .901 r
.48889 .67895 m .48898 .68239 L .48709 .67947 L F
.48889 .67895 m .49062 .68193 L .48898 .68239 L F
.604 .423 .61 r
.49184 .68483 m .48898 .68239 L .49062 .68193 L F
.49184 .68483 m .48879 .6854 L .48898 .68239 L F
.589 .752 .956 r
.55814 .77702 m .56219 .77529 L .56076 .77383 L F
.55814 .77702 m .56172 .77732 L .56219 .77529 L F
.716 .621 .75 r
.56076 .77383 m .56219 .77529 L .56416 .77454 L F
.693 .55 .687 r
.56219 .77529 m .56172 .77732 L .56416 .77454 L F
.031 0 0 r
.53253 .80769 m .53602 .80575 L .53483 .80369 L F
.554 .781 .983 r
.53602 .80575 m .53681 .80399 L .53483 .80369 L F
.521 .358 .601 r
.53806 .80244 m .53826 .80522 L .53602 .80575 L F
.554 .781 .983 r
.53602 .80575 m .53826 .80522 L .53681 .80399 L F
.457 .243 .498 r
.34436 .62317 m .34193 .62604 L .34227 .62379 L F
.455 .37 .67 r
.26883 .62379 m .26913 .62617 L .26737 .62647 L F
.636 .514 .697 r
.27037 .62955 m .26737 .62647 L .26913 .62617 L F
.27037 .62955 m .26896 .63066 L .26737 .62647 L F
.354 0 .054 r
.43949 .69649 m .43812 .69826 L .43591 .69856 L F
.409 0 .121 r
.4417 .69614 m .43812 .69826 L .43949 .69649 L F
.364 .162 .468 r
.27788 .61225 m .27581 .61519 L .27592 .61287 L F
.153 .451 .881 r
.73073 .49706 m .73156 .4972 L .73108 .49828 L F
0 .21 .729 r
.73156 .4972 m .733 .50027 L .73108 .49828 L F
.587 .507 .732 r
.39695 .69091 m .39458 .69143 L .39401 .68765 L F
.548 .552 .81 r
.37936 .7272 m .37794 .72645 L .37792 .72433 L F
.37936 .7272 m .38021 .72364 L .37794 .72645 L F
.434 .825 .985 r
.27345 .65362 m .27373 .65279 L .27287 .65271 L F
.27345 .65362 m .27547 .65321 L .27373 .65279 L F
.798 .748 .806 r
.65765 .5425 m .66183 .5408 L .6606 .53978 L F
.857 .767 .762 r
.59137 .54508 m .59133 .54879 L .58947 .54802 L F
.888 .695 .636 r
.59133 .54879 m .5909 .55118 L .58947 .54802 L F
.747 .67 .775 r
.68401 .52622 m .68304 .52802 L .68042 .52583 L F
.468 .057 .176 r
.51727 .80698 m .51577 .80584 L .51518 .80758 L F
.136 0 .011 r
.47775 .75187 m .47839 .75297 L .47988 .75153 L F
.47775 .75187 m .4765 .75388 L .47839 .75297 L F
0 .212 .633 r
.70437 .51243 m .70657 .51375 L .70746 .51434 L F
.53 .334 .559 r
.70437 .51243 m .70442 .51452 L .70657 .51375 L F
.567 .215 .332 r
.5143 .81408 m .51724 .8132 L .5168 .81394 L F
.224 0 0 r
.51724 .8132 m .51881 .8134 L .5168 .81394 L F
.51724 .8132 m .5198 .81271 L .51881 .8134 L F
.557 .816 .994 r
.69267 .52591 m .69153 .52575 L .69226 .52555 L F
.387 .033 .237 r
.6948 .52526 m .69267 .52591 L .69226 .52555 L F
.161 .632 .93 r
.40443 .69767 m .40735 .69851 L .40516 .69869 L F
.774 .877 .922 r
.71413 .50429 m .71453 .50666 L .71719 .50444 L F
.154 0 0 r
.7137 .50795 m .71453 .50666 L .71413 .50429 L F
.7137 .50795 m .71659 .50747 L .71453 .50666 L F
.679 .646 .809 r
.71719 .50444 m .71453 .50666 L .71698 .50597 L F
.428 .039 .197 r
.71453 .50666 m .71659 .50747 L .71698 .50597 L F
.729 .346 .325 r
.50951 .77553 m .50782 .77688 L .50554 .77455 L F
.546 .105 .153 r
.51211 .77661 m .50951 .77553 L .51136 .77436 L F
.51211 .77661 m .50782 .77688 L .50951 .77553 L F
.912 .928 .81 r
.70746 .51434 m .7075 .51193 L .70979 .51217 L F
.70746 .51434 m .70657 .51375 L .7075 .51193 L F
.573 .941 .856 r
.77897 .61539 m .77561 .6168 L .77637 .61736 L F
.551 .33 .533 r
.53211 .80486 m .53483 .80369 L .5324 .80243 L F
.785 .992 .882 r
.34704 .71561 m .34642 .71654 L .34334 .71768 L F
.569 .928 .764 r
.64726 .54765 m .64574 .54908 L .64742 .54767 L F
.64726 .54765 m .64427 .54965 L .64574 .54908 L F
.307 0 0 r
.58496 .72459 m .58422 .72571 L .58157 .72535 L F
.716 .207 .019 r
.58496 .72459 m .58797 .72689 L .58422 .72571 L F
.58797 .72689 m .58791 .72691 L .58422 .72571 L F
.682 .978 .876 r
.58803 .72695 m .58571 .72762 L .58422 .72571 L F
.631 .962 .884 r
.58636 .72728 m .58842 .72638 L .58801 .72644 L F
.58654 .72724 m .58975 .72579 L .58636 .72728 L F
.682 .978 .876 r
.58803 .72695 m .5864 .7277 L .58571 .72762 L F
.631 .962 .884 r
.58571 .72762 m .5864 .7277 L .58975 .72579 L F
.777 .276 0 r
.58801 .72644 m .58546 .72494 L .58571 .72762 L F
.58801 .72644 m .58731 .72716 L .58687 .72663 L F
.58801 .72644 m .58687 .72663 L .58546 .72494 L F
.631 .962 .884 r
.58842 .72638 m .58975 .72579 L .58801 .72644 L F
.58571 .72762 m .58654 .72724 L .58636 .72728 L F
.716 .207 .019 r
.58797 .72689 m .58803 .72695 L .58791 .72691 L F
.427 .87 .876 r
.55608 .77761 m .55814 .77702 L .55751 .77678 L F
.816 .992 .743 r
.55751 .77678 m .55814 .77702 L .56076 .77383 L F
.419 .661 .96 r
.63791 .48718 m .63894 .48569 L .63684 .48565 L F
.456 .712 .978 r
.63791 .48718 m .64 .48691 L .63894 .48569 L F
.576 .773 .972 r
.67905 .48159 m .67763 .48342 L .67636 .48129 L F
.67905 .48159 m .68014 .4829 L .67763 .48342 L F
.679 .478 .606 r
.53553 .77727 m .53323 .77912 L .53199 .77724 L F
0 .158 .687 r
.34147 .71589 m .34267 .71846 L .34334 .71768 L F
0 .181 .705 r
.34267 .71846 m .34468 .72085 L .34334 .71768 L F
.918 .903 .794 r
.58702 .684 m .58922 .68352 L .58857 .68541 L F
.58702 .684 m .58839 .68191 L .58922 .68352 L F
.509 0 0 r
.58969 .68419 m .58922 .68352 L .58839 .68191 L F
.58969 .68419 m .59126 .68498 L .58922 .68352 L F
.547 .498 .753 r
.32903 .60474 m .32995 .60733 L .33187 .60662 L F
.487 .268 .507 r
.32953 .60949 m .33187 .60662 L .32995 .60733 L F
.571 .663 .9 r
.69143 .49357 m .69282 .49133 L .69058 .49176 L F
.69143 .49357 m .69413 .49317 L .69282 .49133 L F
.713 .473 .56 r
.52107 .72938 m .52441 .72954 L .52439 .72721 L F
.701 .463 .561 r
.52439 .72721 m .52441 .72954 L .52768 .72916 L F
.888 .833 .786 r
.61161 .51489 m .60835 .51684 L .61034 .51378 L F
.61161 .51489 m .60966 .518 L .60835 .51684 L F
.716 .621 .75 r
.56076 .77383 m .56416 .77454 L .56306 .77247 L F
.566 .37 .574 r
.56172 .77732 m .56431 .77725 L .56416 .77454 L F
.46 .441 .751 r
.56416 .77454 m .56491 .77135 L .56306 .77247 L F
.56416 .77454 m .56709 .77309 L .56491 .77135 L F
.121 .039 .481 r
.56416 .77454 m .56589 .77607 L .56671 .77402 L F
.56651 .77338 m .56671 .77402 L .56709 .77309 L F
.56416 .77454 m .56671 .77402 L .56651 .77338 L F
.56589 .77607 m .566 .77584 L .56709 .77309 L F
.56416 .77454 m .56431 .77725 L .56591 .77608 L F
.186 0 0 r
.56591 .77608 m .56888 .77373 L .56709 .77309 L F
.662 .25 .252 r
.56668 .77425 m .56691 .77464 L .56368 .77545 L F
.186 0 0 r
.56591 .77608 m .56753 .77572 L .56888 .77373 L F
.662 .25 .252 r
.56691 .77464 m .56753 .77572 L .56724 .77569 L F
.56691 .77464 m .56724 .77569 L .56368 .77545 L F
.776 .613 .678 r
.56709 .77309 m .5674 .77298 L .56491 .77135 L F
.5674 .77298 m .56978 .77215 L .56801 .77186 L F
.5674 .77298 m .56801 .77186 L .56491 .77135 L F
.56709 .77309 m .56888 .77373 L .56978 .77215 L F
0 0 0 r
.56871 .77242 m .56674 .7742 L .56849 .77139 L F
.56674 .7742 m .56668 .77425 L .5669 .7739 L F
.56674 .7742 m .5669 .7739 L .56849 .77139 L F
.783 .612 .668 r
.56813 .7715 m .56668 .77425 L .56371 .77289 L F
.56849 .77139 m .56712 .77356 L .56813 .7715 L F
.56712 .77356 m .56668 .77425 L .56813 .7715 L F
.121 .039 .481 r
.56589 .77607 m .56591 .77608 L .566 .77584 L F
.422 .111 .331 r
.52814 .75728 m .5306 .75637 L .53056 .75538 L F
.518 .181 .335 r
.5306 .75637 m .53283 .75655 L .53056 .75538 L F
.524 .171 .311 r
.53283 .75655 m .53316 .75525 L .53056 .75538 L F
.661 .206 .161 r
.53406 .73536 m .53358 .73714 L .53108 .73571 L F
.577 .46 .683 r
.53703 .73349 m .53406 .73536 L .53609 .73367 L F
.653 .198 .159 r
.53726 .73736 m .53358 .73714 L .53406 .73536 L F
.254 0 .26 r
.55982 .7873 m .5606 .78572 L .56216 .78499 L F
.601 .607 .83 r
.40159 .69674 m .39824 .69429 L .40017 .69384 L F
.478 .543 .845 r
.4031 .69507 m .40159 .69674 L .40017 .69384 L F
.464 .521 .831 r
.4031 .69507 m .40443 .69767 L .40159 .69674 L F
.447 .004 .102 r
.45306 .67985 m .4549 .68091 L .45617 .67905 L F
.673 .276 .286 r
.4549 .68091 m .45866 .67955 L .45617 .67905 L F
.236 .714 .936 r
.32392 .59211 m .32031 .5916 L .32251 .59141 L F
.319 .733 .977 r
.32449 .59135 m .32392 .59211 L .32251 .59141 L F
.32449 .59135 m .32603 .59209 L .32392 .59211 L F
.66 .213 .179 r
.52146 .75918 m .52273 .75766 L .51917 .75748 L F
.684 .242 .196 r
.52146 .75918 m .5248 .75937 L .52273 .75766 L F
.638 .397 .537 r
.6013 .57657 m .59902 .57873 L .59901 .57667 L F
.389 .049 .264 r
.45061 .6922 m .44723 .69321 L .44996 .69147 L F
.549 .062 .051 r
.44996 .69147 m .45177 .69264 L .45061 .6922 L F
.465 .162 .366 r
.45201 .69093 m .45177 .69264 L .44996 .69147 L F
.817 .928 .907 r
.58311 .57015 m .58157 .57148 L .58136 .5696 L F
.656 .107 0 r
.58157 .57148 m .58095 .57213 L .58136 .5696 L F
.555 .276 .446 r
.58067 .57311 m .58315 .57277 L .58157 .57148 L F
.656 .107 0 r
.58157 .57148 m .58315 .57277 L .58095 .57213 L F
.348 0 .142 r
.48759 .74649 m .48978 .74609 L .49055 .74429 L F
.471 .082 .221 r
.48978 .74609 m .49292 .74403 L .49055 .74429 L F
.308 .027 .313 r
.39395 .67432 m .39335 .67629 L .39161 .6767 L F
.388 .329 .67 r
.39369 .67861 m .39161 .6767 L .39335 .67629 L F
.39369 .67861 m .39197 .67971 L .39161 .6767 L F
.589 .649 .878 r
.75266 .61388 m .75593 .61576 L .75645 .61469 L F
.276 .292 .696 r
.75645 .61469 m .75593 .61576 L .75757 .61425 L F
.288 .31 .711 r
.75757 .61425 m .75593 .61576 L .75802 .61741 L F
.205 0 .141 r
.70452 .52621 m .70392 .52824 L .70195 .52905 L F
.114 0 .109 r
.70579 .52693 m .70452 .52621 L .70639 .52556 L F
.70579 .52693 m .70392 .52824 L .70452 .52621 L F
.472 .215 .443 r
.39586 .67373 m .39335 .67629 L .39395 .67432 L F
.319 .11 .431 r
.62181 .54578 m .6236 .54523 L .62372 .54302 L F
.544 .43 .673 r
.62168 .54832 m .6236 .54523 L .62181 .54578 L F
.751 .28 .126 r
.54818 .70885 m .54939 .70773 L .54888 .70819 L F
.54818 .70885 m .55155 .70993 L .54939 .70773 L F
.726 .318 .274 r
.54939 .70773 m .55155 .70993 L .55291 .70935 L F
.704 .983 .821 r
.62505 .48387 m .62353 .4852 L .62177 .48586 L F
.214 0 0 r
.28836 .60673 m .28459 .60842 L .28627 .60694 L F
.158 0 0 r
.43442 .66019 m .43288 .66121 L .43084 .66145 L F
.355 0 0 r
.43661 .65975 m .43288 .66121 L .43442 .66019 L F
.244 0 0 r
.48855 .79817 m .49258 .79669 L .49106 .79819 L F
.48855 .79817 m .49106 .79819 L .48822 .79645 L F
.195 0 0 r
.49106 .79819 m .48964 .79819 L .48822 .79645 L F
.03 .152 .658 r
.48663 .7945 m .48736 .7974 L .48822 .79645 L F
.147 .339 .799 r
.48736 .7974 m .48855 .79817 L .48822 .79645 L F
.195 0 0 r
.48964 .79819 m .48534 .79819 L .48822 .79645 L F
.03 .152 .658 r
.48648 .79389 m .48663 .7945 L .48822 .79645 L F
.186 0 .185 r
.7013 .53048 m .6987 .53299 L .69929 .53083 L F
.567 .703 .933 r
.68451 .49035 m .68845 .49202 L .68692 .48996 L F
.51 .654 .924 r
.68845 .49202 m .689 .48969 L .68692 .48996 L F
.68845 .49202 m .69058 .49176 L .689 .48969 L F
.776 .931 .934 r
.31915 .60368 m .31977 .60455 L .32259 .60291 L F
.342 0 .033 r
.53282 .72433 m .53484 .72415 L .53561 .7236 L F
.34 .167 .495 r
.53282 .72433 m .53449 .72594 L .53484 .72415 L F
.53282 .72433 m .53266 .72693 L .53449 .72594 L F
.503 .743 .981 r
.34837 .59491 m .34778 .59645 L .34673 .59488 L F
.34837 .59491 m .34969 .59604 L .34778 .59645 L F
.817 .726 .765 r
.60377 .74122 m .60373 .73793 L .60236 .74059 L F
.986 .796 .566 r
.60244 .74303 m .60377 .74122 L .60236 .74059 L F
.60244 .74303 m .60357 .74377 L .60377 .74122 L F
.932 .74 .621 r
.35281 .73205 m .3541 .73509 L .35491 .73314 L F
.89 .807 .76 r
.35281 .73205 m .35491 .73314 L .35553 .7302 L F
.771 .685 .768 r
.35553 .7302 m .35491 .73314 L .35696 .73013 L F
.963 .908 .545 r
.35553 .7302 m .3541 .73509 L .35491 .73314 L F
.595 .647 .872 r
.46397 .64924 m .46022 .64731 L .46267 .64745 L F
.566 .584 .83 r
.46518 .64597 m .46397 .64924 L .46267 .64745 L F
.46518 .64597 m .46608 .64881 L .46397 .64924 L F
.229 0 0 r
.41164 .69708 m .41566 .69644 L .41333 .69687 L F
.362 0 0 r
.64392 .50304 m .6427 .50408 L .64021 .50353 L F
.505 .558 .844 r
.64554 .50327 m .6434 .50226 L .64392 .50304 L F
.64554 .50327 m .64702 .50273 L .6434 .50226 L F
.528 .517 .787 r
.6434 .50226 m .64702 .50273 L .64392 .50304 L F
.539 .41 .653 r
.64392 .50304 m .64666 .50566 L .64554 .50327 L F
.64392 .50304 m .64453 .50635 L .64666 .50566 L F
.308 .797 .764 r
.64554 .50327 m .64669 .50283 L .64702 .50273 L F
.64669 .50283 m .64792 .50235 L .64702 .50273 L F
.449 0 0 r
.64702 .50273 m .6427 .50408 L .64285 .50395 L F
.64702 .50273 m .64285 .50395 L .64392 .50304 L F
.642 .667 .859 r
.73775 .61106 m .73992 .61024 L .73668 .60936 L F
.419 .113 .337 r
.53051 .72739 m .52989 .7292 L .53266 .72693 L F
0 0 .178 r
.53509 .76816 m .53444 .77154 L .53376 .76855 L F
.53446 .77142 m .53497 .77072 L .53444 .77154 L F
.53502 .76852 m .53497 .77072 L .53446 .77142 L F
0 0 .382 r
.53624 .76958 m .53497 .77072 L .53509 .76816 L F
.534 .918 .791 r
.53541 .77011 m .53497 .77072 L .53624 .76958 L F
.53443 .77073 m .53497 .77072 L .53541 .77011 L F
.786 .537 .561 r
.53175 .77271 m .53491 .77309 L .53497 .77072 L F
.53491 .77309 m .5352 .77313 L .53497 .77072 L F
0 0 .178 r
.53509 .76816 m .53497 .77072 L .53502 .76852 L F
.417 .758 .995 r
.5781 .73327 m .57918 .73228 L .57708 .7321 L F
.5781 .73327 m .58042 .73317 L .57918 .73228 L F
.499 0 0 r
.54731 .7274 m .54962 .72848 L .55063 .72801 L F
.529 0 0 r
.54962 .72848 m .55301 .72919 L .55063 .72801 L F
.439 0 0 r
.55063 .72801 m .55301 .72919 L .55474 .72962 L F
.59 .412 .608 r
.55858 .6965 m .5587 .69929 L .55629 .69958 L F
.496 .34 .598 r
.56087 .69866 m .55858 .6965 L .5609 .69601 L F
.56087 .69866 m .5587 .69929 L .55858 .6965 L F
.363 .075 .334 r
.50554 .77455 m .50307 .77652 L .5022 .7742 L F
.50554 .77455 m .50402 .77701 L .50307 .77652 L F
.121 .002 .431 r
.50443 .77866 m .50307 .77652 L .50402 .77701 L F
.50443 .77866 m .50255 .78146 L .50307 .77652 L F
.641 .617 .81 r
.27191 .63473 m .26828 .63228 L .27062 .63152 L F
.561 .546 .795 r
.27277 .63096 m .27191 .63473 L .27062 .63152 L F
.27277 .63096 m .27403 .63432 L .27191 .63473 L F
.456 .033 .147 r
.56296 .77888 m .56172 .77732 L .56155 .77915 L F
.56296 .77888 m .56431 .77725 L .56172 .77732 L F
.679 .444 .559 r
.63847 .50273 m .6347 .50087 L .63795 .50122 L F
.724 .362 .364 r
.63795 .50122 m .64021 .50353 L .63847 .50273 L F
.152 0 0 r
.71137 .49042 m .71094 .48995 L .7096 .489 L F
.71137 .49042 m .71368 .48982 L .71094 .48995 L F
.873 .665 .618 r
.57202 .69086 m .5702 .6906 L .57051 .6878 L F
.529 .909 .753 r
.57227 .69145 m .57306 .69136 L .57202 .69086 L F
.619 .387 .543 r
.57263 .69141 m .57055 .69288 L .57037 .69167 L F
.57306 .69136 m .57236 .69179 L .57263 .69141 L F
.57236 .69179 m .57055 .69288 L .57263 .69141 L F
.529 .909 .753 r
.57227 .69145 m .57202 .69086 L .57263 .69124 L F
.619 .387 .543 r
.57263 .69124 m .57037 .69167 L .5702 .6906 L F
.57306 .69136 m .57227 .69145 L .57263 .69124 L F
.57227 .69145 m .57037 .69167 L .57263 .69124 L F
.529 .909 .753 r
.57237 .69169 m .57306 .69136 L .57227 .69145 L F
.57237 .69169 m .57227 .69145 L .5727 .69129 L F
.57227 .69145 m .57263 .69124 L .5727 .69129 L F
.619 .387 .543 r
.57306 .69136 m .57272 .69127 L .57276 .69122 L F
.529 .909 .753 r
.5727 .69129 m .57202 .69086 L .57341 .69041 L F
.67 .874 .495 r
.57361 .68993 m .57237 .69169 L .57283 .69113 L F
.5735 .6902 m .57283 .69113 L .57341 .69041 L F
.527 .523 .795 r
.57341 .69041 m .57202 .69086 L .57051 .6878 L F
.67 .874 .495 r
.57361 .68993 m .57283 .69113 L .5735 .6902 L F
.619 .387 .543 r
.57263 .69124 m .5702 .6906 L .57202 .69086 L F
.572 .373 .573 r
.48625 .77719 m .48846 .77946 L .48612 .77968 L F
.468 .091 .24 r
.45061 .6922 m .44601 .69498 L .44723 .69321 L F
.541 .442 .691 r
.72951 .60171 m .73145 .59773 L .72917 .59835 L F
.652 .479 .638 r
.61266 .57099 m .61266 .57341 L .61042 .57391 L F
.656 .45 .594 r
.6151 .57101 m .61266 .57341 L .61266 .57099 L F
.592 .757 .957 r
.55282 .77688 m .55608 .77761 L .55462 .77858 L F
0 0 0 r
.55462 .77858 m .55608 .77761 L .55751 .77678 L F
.365 .695 .983 r
.46551 .79046 m .46597 .79126 L .46691 .79028 L F
.144 .348 .807 r
.46597 .79126 m .46873 .79344 L .46691 .79028 L F
.053 .322 .805 r
.46597 .79126 m .46853 .79434 L .46873 .79344 L F
.746 .445 .473 r
.49508 .8051 m .49203 .80251 L .49097 .80478 L F
.576 .558 .797 r
.48576 .66193 m .48491 .66516 L .48398 .66241 L F
.48576 .66193 m .48725 .66481 L .48491 .66516 L F
.654 .589 .77 r
.48815 .66667 m .48491 .66516 L .48725 .66481 L F
.086 .08 .553 r
.46853 .79434 m .47047 .79543 L .46873 .79344 L F
.46853 .79434 m .46913 .79669 L .47047 .79543 L F
.491 .268 .502 r
.27114 .61812 m .27075 .62075 L .26864 .62112 L F
.468 .248 .495 r
.27302 .62003 m .27114 .61812 L .27323 .6176 L F
.27302 .62003 m .27075 .62075 L .27114 .61812 L F
.628 .292 .382 r
.4805 .6854 m .48264 .68725 L .48041 .68702 L F
.587 .306 .458 r
.48302 .68528 m .48264 .68725 L .4805 .6854 L F
.807 .409 0 r
.55506 .7313 m .55474 .72962 L .55301 .72919 L F
.55506 .7313 m .55599 .7326 L .55474 .72962 L F
.316 0 .089 r
.24711 .59272 m .2492 .59223 L .25057 .59033 L F
.247 0 .018 r
.2492 .59223 m .25264 .58985 L .25057 .59033 L F
.933 .555 .224 r
.78497 .60613 m .7855 .60495 L .78544 .60369 L F
.78497 .60613 m .78625 .60726 L .7855 .60495 L F
.507 .29 .519 r
.55275 .6965 m .55258 .69877 L .55504 .69614 L F
.578 .627 .864 r
.69737 .49443 m .69862 .49128 L .69624 .49201 L F
.69737 .49443 m .69997 .49393 L .69862 .49128 L F
0 0 0 r
.55023 .76753 m .5538 .76648 L .55145 .76946 L F
.139 .661 .883 r
.44208 .64779 m .44558 .64828 L .44346 .64821 L F
.562 .253 .402 r
.51897 .75887 m .51917 .75748 L .51652 .75754 L F
.577 .195 .28 r
.46091 .68759 m .45979 .68961 L .45762 .68819 L F
.655 .346 .437 r
.46347 .68757 m .45979 .68961 L .46091 .68759 L F
.416 0 0 r
.43976 .65948 m .43892 .66002 L .43661 .65975 L F
.013 0 0 r
.44129 .65942 m .43976 .65948 L .44214 .65904 L F
.44129 .65942 m .43892 .66002 L .43976 .65948 L F
.112 .647 .861 r
.27779 .58479 m .27992 .58487 L .28141 .58525 L F
.387 .81 .971 r
.27992 .58487 m .28336 .58498 L .28141 .58525 L F
.773 .997 .819 r
.71565 .48732 m .71368 .48982 L .71137 .49042 L F
.681 .688 .851 r
.71673 .48961 m .71368 .48982 L .71565 .48732 L F
.46 .245 .499 r
.54356 .70774 m .5456 .70956 L .54581 .70702 L F
.941 .746 .61 r
.59203 .73232 m .59323 .73543 L .59173 .73529 L F
.154 .36 .815 r
.59348 .73809 m .59173 .73529 L .59323 .73543 L F
.223 .359 .791 r
.64364 .48368 m .64377 .48691 L .64265 .48358 L F
.64364 .48368 m .64494 .48546 L .64377 .48691 L F
.19 .31 .757 r
.64494 .48546 m .64606 .48872 L .64377 .48691 L F
.482 .535 .835 r
.64699 .48984 m .64377 .48691 L .64606 .48872 L F
.885 .803 .762 r
.61464 .52885 m .61382 .5311 L .6155 .53174 L F
.952 .919 .741 r
.61308 .5338 m .6155 .53174 L .61382 .5311 L F
.61308 .5338 m .6139 .53472 L .6155 .53174 L F
.799 .762 .819 r
.61464 .52885 m .6155 .53174 L .61789 .52901 L F
.466 .504 .813 r
.32903 .60474 m .33093 .6035 L .32844 .60379 L F
.32903 .60474 m .33187 .60662 L .33093 .6035 L F
.656 .45 .594 r
.6151 .57101 m .61514 .57341 L .61266 .57341 L F
.623 .407 .568 r
.61826 .5707 m .61514 .57341 L .6151 .57101 L F
0 0 .295 r
.54812 .70204 m .54701 .70705 L .54784 .70446 L F
.536 .298 .501 r
.54784 .70446 m .54986 .70477 L .54812 .70204 L F
.728 .346 .327 r
.54812 .70204 m .54986 .70477 L .55107 .70315 L F
.512 .107 .208 r
.51287 .77399 m .51464 .77471 L .51136 .77436 L F
.516 .102 .195 r
.44365 .68416 m .44725 .68235 L .44509 .68269 L F
.506 .393 .659 r
.36907 .69342 m .37105 .69294 L .37073 .69055 L F
.776 .931 .934 r
.31915 .60368 m .32259 .60291 L .32132 .60218 L F
.181 .667 .925 r
.32132 .60218 m .32259 .60291 L .32502 .60299 L F
.782 .329 .171 r
.50537 .81342 m .50501 .81153 L .50369 .81252 L F
.05 0 0 r
.50792 .81104 m .50501 .81153 L .50537 .81342 L F
.003 0 0 r
.68422 .54099 m .68575 .54099 L .68558 .54102 L F
.68422 .54099 m .68558 .54102 L .68333 .54074 L F
.387 .667 .97 r
.67371 .48016 m .67546 .48018 L .6744 .48143 L F
.404 .692 .978 r
.67546 .48018 m .67636 .48129 L .6744 .48143 L F
.954 .949 .716 r
.49426 .78807 m .49678 .78581 L .49323 .78576 L F
.49426 .78807 m .49522 .78885 L .49678 .78581 L F
.242 .491 .893 r
.52903 .80508 m .52842 .80579 L .52764 .80401 L F
.758 .735 .831 r
.53106 .80635 m .52814 .80612 L .52842 .80579 L F
.766 .838 .907 r
.53211 .80486 m .53106 .80635 L .52842 .80579 L F
.53211 .80486 m .52842 .80579 L .53129 .80684 L F
.242 .491 .893 r
.53129 .80684 m .52842 .80579 L .52903 .80508 L F
.758 .735 .831 r
.52814 .80612 m .52691 .80602 L .52842 .80579 L F
.474 .426 .724 r
.36543 .67688 m .36591 .67973 L .36774 .67936 L F
.595 .486 .7 r
.36602 .68222 m .36774 .67936 L .36591 .67973 L F
.464 .168 .377 r
.53854 .763 m .53751 .76564 L .53543 .76596 L F
.626 .332 .451 r
.54073 .76515 m .53854 .763 L .54095 .76311 L F
.54073 .76515 m .53751 .76564 L .53854 .763 L F
.296 0 0 r
.3114 .64995 m .30802 .65028 L .30998 .64974 L F
.604 .711 .919 r
.76228 .6082 m .76056 .61026 L .76005 .60875 L F
.76228 .6082 m .76291 .60973 L .76056 .61026 L F
.191 .707 .884 r
.42944 .64929 m .43058 .64914 L .43196 .64943 L F
.015 0 0 r
.42922 .64981 m .43181 .64898 L .43058 .64914 L F
.432 .835 .977 r
.43058 .64914 m .43277 .64867 L .43414 .64911 L F
.015 0 0 r
.43181 .64898 m .43277 .64867 L .43058 .64914 L F
.191 .707 .884 r
.42846 .64923 m .43058 .64914 L .42944 .64929 L F
.432 .835 .977 r
.43058 .64914 m .43414 .64911 L .43196 .64943 L F
.584 .184 .249 r
.58104 .68045 m .58329 .68177 L .57969 .68209 L F
.512 .327 .567 r
.584 .68052 m .58298 .68208 L .58329 .68177 L F
.433 0 .072 r
.58329 .68177 m .58238 .68304 L .57973 .68349 L F
.58238 .68304 m .58218 .68332 L .58129 .68338 L F
.58238 .68304 m .58129 .68338 L .57973 .68349 L F
.354 .025 .262 r
.57969 .68209 m .57973 .68349 L .57756 .68409 L F
.414 .208 .489 r
.57938 .68489 m .57756 .68409 L .57973 .68349 L F
.771 .65 .728 r
.57523 .68336 m .5795 .68394 L .57762 .68086 L F
.493 .182 .368 r
.58083 .68341 m .57938 .68489 L .57973 .68349 L F
.58218 .68332 m .57996 .68456 L .58083 .68341 L F
.57996 .68456 m .57938 .68489 L .58083 .68341 L F
.46 .244 .498 r
.57756 .68409 m .5752 .68573 L .57562 .68521 L F
.57756 .68409 m .57746 .68734 L .5752 .68573 L F
.414 .208 .489 r
.57938 .68489 m .57746 .68734 L .57756 .68409 L F
.092 0 .343 r
.57938 .68489 m .5776 .68888 L .57746 .68734 L F
.57938 .68489 m .57924 .68562 L .5776 .68888 L F
.57924 .68562 m .57876 .68819 L .57819 .68853 L F
.57924 .68562 m .57819 .68853 L .5776 .68888 L F
.603 .408 .59 r
.58132 .68504 m .57876 .68819 L .57924 .68562 L F
.57963 .68491 m .57924 .68562 L .57938 .68489 L F
.87 .738 .713 r
.57947 .6852 m .57952 .68514 L .57963 .68491 L F
.603 .408 .59 r
.58132 .68504 m .57924 .68562 L .57943 .68527 L F
.58132 .68504 m .57943 .68527 L .57973 .68492 L F
.493 .182 .368 r
.58147 .68378 m .58006 .68494 L .57973 .68492 L F
.57977 .68467 m .57975 .68478 L .57938 .68489 L F
.713 .977 .763 r
.57943 .68527 m .58077 .68366 L .58024 .68404 L F
.493 .182 .368 r
.57975 .68478 m .57973 .68492 L .57963 .68491 L F
.57975 .68478 m .57963 .68491 L .57938 .68489 L F
.87 .738 .713 r
.57978 .68411 m .57941 .68515 L .58024 .68404 L F
.57941 .68515 m .57935 .68533 L .57964 .68491 L F
.57941 .68515 m .57964 .68491 L .58024 .68404 L F
.493 .182 .368 r
.58218 .68332 m .57973 .68492 L .57975 .68478 L F
.57996 .68456 m .57975 .68478 L .57977 .68467 L F
.58218 .68332 m .57975 .68478 L .57996 .68456 L F
.87 .738 .713 r
.57963 .68491 m .57952 .68514 L .57975 .68478 L F
.57964 .68491 m .57975 .68478 L .58024 .68404 L F
.57963 .68491 m .57975 .68478 L .57964 .68491 L F
.713 .977 .763 r
.57971 .68501 m .58323 .68192 L .58077 .68366 L F
.57966 .68527 m .58323 .68192 L .57971 .68501 L F
.57907 .68583 m .58077 .68366 L .57943 .68527 L F
.603 .408 .59 r
.57973 .68492 m .57943 .68527 L .57963 .68491 L F
.713 .977 .763 r
.57966 .68527 m .5794 .68478 L .58323 .68192 L F
.57907 .68583 m .57966 .68527 L .57971 .68501 L F
.57907 .68583 m .5791 .68574 L .57966 .68527 L F
.87 .738 .713 r
.57901 .68582 m .57947 .6852 L .57963 .68491 L F
.57901 .68582 m .57907 .68583 L .57952 .68514 L F
.713 .977 .763 r
.5791 .68574 m .5794 .68478 L .57966 .68527 L F
.493 .182 .368 r
.58218 .68332 m .58132 .68504 L .58006 .68494 L F
.58218 .68332 m .58006 .68494 L .58147 .68378 L F
.87 .738 .713 r
.57534 .68485 m .57901 .68582 L .57935 .68533 L F
.57534 .68485 m .57935 .68533 L .57978 .68411 L F
.771 .65 .728 r
.5795 .68394 m .58024 .68404 L .58002 .68377 L F
.433 0 .072 r
.58329 .68177 m .57973 .68349 L .57969 .68209 L F
.771 .65 .728 r
.5795 .68394 m .58002 .68377 L .57762 .68086 L F
.512 .327 .567 r
.58298 .68208 m .58218 .68332 L .58329 .68177 L F
.507 0 0 r
.58352 .68154 m .58329 .68177 L .58104 .68045 L F
.58475 .68208 m .58329 .68177 L .58352 .68154 L F
.459 .046 .168 r
.39201 .65127 m .38821 .65336 L .39051 .65329 L F
.39201 .65127 m .38884 .65226 L .38821 .65336 L F
.566 .128 .168 r
.3928 .65326 m .39201 .65127 L .39051 .65329 L F
.3928 .65326 m .39422 .65162 L .39201 .65127 L F
.452 0 0 r
.64515 .53733 m .64745 .53811 L .64877 .53747 L F
0 0 .295 r
.64996 .53593 m .64965 .53669 L .64877 .53747 L F
.657 .953 .728 r
.64877 .53747 m .64745 .53811 L .64996 .53593 L F
.764 .254 0 r
.59475 .6979 m .59366 .69579 L .59284 .6969 L F
.59475 .6979 m .59608 .69839 L .59366 .69579 L F
.717 .367 .384 r
.59366 .69579 m .59608 .69839 L .59612 .69652 L F
.929 .545 .215 r
.67903 .52492 m .67947 .52361 L .67713 .52306 L F
.67903 .52492 m .68042 .52583 L .67947 .52361 L F
.389 0 0 r
.51918 .74157 m .51779 .74148 L .5155 .74062 L F
.41 0 .038 r
.52084 .7402 m .51779 .74148 L .51918 .74157 L F
.439 .382 .697 r
.48669 .67589 m .4852 .67946 L .48369 .67641 L F
.48669 .67589 m .48709 .67947 L .4852 .67946 L F
.445 .381 .692 r
.36286 .60338 m .36082 .60503 L .3605 .60155 L F
.44 .324 .625 r
.36329 .60609 m .36082 .60503 L .36286 .60338 L F
.36329 .60609 m .36078 .60678 L .36082 .60503 L F
.333 .621 .956 r
.75834 .60688 m .75663 .60766 L .75634 .60611 L F
.75834 .60688 m .76005 .60875 L .75663 .60766 L F
.325 .14 .469 r
.73134 .50374 m .73175 .50574 L .72904 .50692 L F
.611 .566 .779 r
.73175 .50574 m .72804 .50825 L .72904 .50692 L F
0 .125 .652 r
.67789 .51931 m .67729 .52072 L .67641 .51741 L F
.272 0 .107 r
.32566 .61798 m .32751 .61755 L .32871 .61557 L F
.308 0 .127 r
.32871 .61557 m .32949 .61701 L .33015 .61456 L F
.32871 .61557 m .32751 .61755 L .32949 .61701 L F
.588 .612 .844 r
.4682 .64863 m .46742 .65198 L .46608 .64881 L F
.4682 .64863 m .46963 .65151 L .46742 .65198 L F
.669 .738 .902 r
.75964 .62072 m .76311 .62135 L .76193 .61988 L F
.781 .813 .878 r
.76311 .62135 m .76481 .61749 L .76193 .61988 L F
.76311 .62135 m .76627 .61892 L .76481 .61749 L F
.804 .596 .621 r
.49037 .8081 m .48695 .80931 L .4872 .8079 L F
.49037 .8081 m .49018 .81022 L .48695 .80931 L F
.778 .745 .823 r
.58828 .56517 m .59087 .56659 L .58719 .56742 L F
.58828 .56517 m .59125 .5662 L .59087 .56659 L F
.35 .008 .236 r
.43185 .68853 m .43314 .68951 L .43456 .68742 L F
.242 0 .049 r
.43456 .68742 m .43535 .68877 L .43685 .6874 L F
.43456 .68742 m .43314 .68951 L .43535 .68877 L F
.47 .849 .624 r
.55629 .69958 m .55453 .70071 L .55323 .7018 L F
.651 .149 .04 r
.5582 .70121 m .55453 .70071 L .55629 .69958 L F
.534 .232 .402 r
.5587 .69929 m .5582 .70121 L .55629 .69958 L F
.555 .313 .503 r
.5385 .75207 m .54089 .75182 L .54119 .74962 L F
.399 .162 .435 r
.54089 .75182 m .54318 .74908 L .54119 .74962 L F
.199 0 0 r
.48955 .7901 m .4888 .78923 L .48754 .78783 L F
.48955 .7901 m .49111 .78851 L .4888 .78923 L F
.169 .051 .465 r
.58999 .70684 m .59117 .70621 L .59026 .70491 L F
.59023 .70499 m .59026 .70491 L .59024 .70488 L F
.58999 .70684 m .59026 .70491 L .59023 .70499 L F
.348 .096 .383 r
.59024 .70488 m .59026 .70491 L .59032 .70573 L F
.59026 .70491 m .59117 .70621 L .59032 .70573 L F
0 0 .321 r
.59163 .70206 m .59032 .70573 L .59258 .70313 L F
.59127 .70166 m .59075 .70389 L .59163 .70206 L F
.59075 .70389 m .59032 .70573 L .59163 .70206 L F
.013 0 .332 r
.59024 .70488 m .59032 .70573 L .59127 .70166 L F
.286 .396 .8 r
.59127 .70166 m .59321 .70111 L .59036 .69874 L F
0 0 .321 r
.59127 .70166 m .59258 .70313 L .59321 .70111 L F
.107 0 0 r
.53806 .80244 m .53483 .80369 L .53681 .80399 L F
0 0 .377 r
.53908 .80389 m .53826 .80522 L .53806 .80244 L F
.53908 .80389 m .53806 .80244 L .53681 .80399 L F
.037 .211 .715 r
.36116 .60018 m .3605 .60155 L .35923 .59813 L F
.385 .651 .962 r
.36207 .60131 m .3605 .60155 L .36116 .60018 L F
.445 .381 .692 r
.36286 .60338 m .3605 .60155 L .36207 .60131 L F
.916 .967 .79 r
.6014 .52928 m .60135 .52756 L .60324 .52669 L F
.887 .925 .842 r
.60555 .52386 m .60324 .52669 L .60335 .52439 L F
.932 .95 .775 r
.60324 .52669 m .60135 .52756 L .60335 .52439 L F
.894 .795 .744 r
.70979 .51217 m .7075 .51193 L .70877 .51121 L F
.811 .807 .847 r
.71258 .50989 m .70979 .51217 L .70877 .51121 L F
.509 .806 .999 r
.71223 .49542 m .71453 .49496 L .71115 .49449 L F
.71223 .49542 m .71453 .49496 L .71115 .49449 L F
.89 .846 .795 r
.60966 .518 m .60641 .51984 L .60835 .51684 L F
.60966 .518 m .60775 .52098 L .60641 .51984 L F
.856 .64 .609 r
.66752 .52635 m .66518 .52777 L .66638 .52567 L F
.66752 .52635 m .66724 .52869 L .66518 .52777 L F
.925 .604 .415 r
.67381 .51213 m .67441 .51452 L .676 .51508 L F
0 0 .48 r
.67734 .51578 m .67641 .51741 L .676 .51508 L F
.67734 .51578 m .676 .51508 L .67441 .51452 L F
.607 .567 .783 r
.37563 .71281 m .37699 .7162 L .37906 .71563 L F
.19 .068 .473 r
.37699 .7162 m .37768 .71798 L .37906 .71563 L F
.37699 .7162 m .37682 .71845 L .37768 .71798 L F
.3 .784 .714 r
.76028 .58215 m .75658 .58347 L .75962 .5815 L F
.807 .907 .91 r
.76179 .57908 m .76028 .58215 L .75962 .5815 L F
.76179 .57908 m .76277 .58023 L .76028 .58215 L F
.656 .177 0 r
.56895 .74537 m .56863 .74473 L .56812 .74462 L F
.56895 .74537 m .56959 .74596 L .56863 .74473 L F
.946 .747 .604 r
.66413 .5098 m .6622 .51102 L .66282 .50879 L F
.66413 .5098 m .66363 .51193 L .6622 .51102 L F
.883 .615 .529 r
.29063 .70631 m .28995 .70779 L .29 .70597 L F
0 .37 .761 r
.29 .70597 m .2921 .70683 L .29063 .70631 L F
.309 0 .249 r
.2921 .70683 m .28995 .70779 L .29063 .70631 L F
.548 .255 .421 r
.50645 .76647 m .50904 .76793 L .50968 .76618 L F
.822 .383 .193 r
.50569 .76519 m .50904 .76793 L .50645 .76647 L F
.2 0 .151 r
.55391 .79027 m .55326 .78905 L .55294 .78866 L F
.235 .302 .729 r
.65082 .51322 m .65149 .51243 L .65207 .51409 L F
.65082 .51322 m .64875 .51257 L .65149 .51243 L F
.223 0 0 r
.416 .70824 m .4154 .7071 L .41752 .70654 L F
.416 .70824 m .4139 .7087 L .4154 .7071 L F
.564 .822 .994 r
.77114 .57777 m .7681 .57864 L .76724 .57763 L F
.525 .728 .967 r
.68788 .48359 m .68627 .48518 L .68561 .48391 L F
.68788 .48359 m .68853 .48513 L .68627 .48518 L F
.193 .716 .865 r
.30129 .63473 m .30611 .63492 L .30404 .63564 L F
.793 .299 0 r
.55783 .78272 m .55854 .78345 L .5583 .78442 L F
.55854 .78345 m .56041 .78539 L .5583 .78442 L F
.936 .895 .764 r
.5583 .78442 m .55829 .7875 L .55694 .78798 L F
.682 .762 .272 r
.5583 .78442 m .55694 .78798 L .55743 .78662 L F
0 0 0 r
.55811 .78517 m .5583 .78442 L .55743 .78662 L F
.55886 .78357 m .5583 .78442 L .55811 .78517 L F
.793 .299 0 r
.55783 .78272 m .5583 .78442 L .55886 .78258 L F
.598 .229 .314 r
.62725 .50175 m .62399 .50354 L .62363 .50322 L F
.881 .88 .828 r
.62613 .50071 m .62395 .50344 L .62725 .50175 L F
.472 .298 .563 r
.6235 .50458 m .62549 .50499 L .6234 .50561 L F
.62363 .50322 m .62407 .50364 L .6235 .50458 L F
.62407 .50364 m .62549 .50499 L .6235 .50458 L F
.598 .229 .314 r
.62399 .50354 m .62377 .50366 L .62392 .50348 L F
.62379 .50336 m .62377 .50366 L .62363 .50322 L F
0 .166 .705 r
.62384 .50328 m .62399 .50354 L .62363 .50322 L F
.782 .689 .762 r
.62381 .50319 m .62395 .50344 L .62491 .50223 L F
0 0 .37 r
.62363 .50322 m .6238 .50317 L .62397 .49974 L F
0 .166 .705 r
.6238 .50317 m .62363 .50322 L .62371 .50294 L F
.62384 .50328 m .62363 .50322 L .6238 .50317 L F
0 0 .37 r
.62363 .50322 m .62377 .50366 L .6238 .50317 L F
.782 .689 .762 r
.6238 .5032 m .62384 .50328 L .62381 .50319 L F
.62384 .50328 m .62395 .50344 L .62381 .50319 L F
.881 .88 .828 r
.62395 .50344 m .62399 .50354 L .62725 .50175 L F
0 .166 .705 r
.62497 .50358 m .62384 .50328 L .62395 .50202 L F
.782 .689 .762 r
.62397 .49974 m .6238 .50314 L .62491 .50223 L F
.6238 .50314 m .6238 .5032 L .62382 .50318 L F
.6238 .50314 m .62382 .50318 L .62491 .50223 L F
0 0 .37 r
.62363 .50322 m .62397 .49974 L .62198 .49991 L F
.62363 .50322 m .62198 .49991 L .62254 .5005 L F
.62371 .50294 m .62254 .5005 L .62395 .50202 L F
.62363 .50322 m .62254 .5005 L .62371 .50294 L F
0 .166 .705 r
.62384 .50328 m .62371 .50294 L .62395 .50202 L F
.62388 .50329 m .62395 .50344 L .62384 .50328 L F
.62395 .50344 m .62399 .50354 L .62384 .50328 L F
.782 .689 .762 r
.6238 .5032 m .62377 .50366 L .62395 .50344 L F
.62589 .50061 m .62491 .50223 L .62613 .50071 L F
.62397 .49974 m .62491 .50223 L .62589 .50061 L F
.881 .88 .828 r
.62395 .50344 m .62377 .50366 L .62399 .50354 L F
0 .166 .705 r
.62497 .50358 m .62544 .50485 L .62399 .50354 L F
.62497 .50358 m .62399 .50354 L .62388 .50329 L F
.62544 .50485 m .62549 .50499 L .62363 .50322 L F
.404 .437 .781 r
.3957 .68758 m .39401 .68765 L .39289 .68403 L F
.587 .507 .732 r
.39695 .69091 m .39401 .68765 L .3957 .68758 L F
.535 .821 .998 r
.28355 .71788 m .28436 .71874 L .28078 .71844 L F
.499 .097 .21 r
.28436 .71874 m .28059 .72081 L .28078 .71844 L F
.28436 .71874 m .28282 .72092 L .28059 .72081 L F
.285 0 .078 r
.28493 .72035 m .28282 .72092 L .28436 .71874 L F
.28493 .72035 m .28436 .71874 L .28355 .71788 L F
.32 .426 .813 r
.69725 .48624 m .69604 .48836 L .69492 .48647 L F
.69725 .48624 m .69888 .49037 L .69604 .48836 L F
.481 .661 .941 r
.65335 .53114 m .65217 .52781 L .65215 .53 L F
.65335 .53114 m .65473 .53104 L .65217 .52781 L F
.755 .827 .908 r
.46185 .67067 m .46532 .67081 L .46465 .66784 L F
.46185 .67067 m .4632 .67156 L .46532 .67081 L F
.696 .638 .787 r
.46465 .66784 m .46532 .67081 L .46757 .66826 L F
.607 .46 .656 r
.52813 .74397 m .53073 .7442 L .53039 .7408 L F
.736 .601 .707 r
.58702 .684 m .58839 .68191 L .5851 .68117 L F
.01 .265 .767 r
.58475 .68208 m .58702 .684 L .58647 .68319 L F
.825 .73 .76 r
.58636 .68381 m .58839 .68191 L .58702 .684 L F
.616 .381 .538 r
.58675 .68345 m .58969 .68419 L .58839 .68191 L F
.58636 .68381 m .58722 .68391 L .58675 .68345 L F
.58722 .68391 m .58969 .68419 L .58675 .68345 L F
.01 .265 .767 r
.5849 .68168 m .58647 .68319 L .5851 .68117 L F
.58475 .68208 m .58647 .68319 L .5849 .68168 L F
.589 .914 .975 r
.5851 .68117 m .58329 .68177 L .58475 .68208 L F
.556 .469 .712 r
.39369 .67861 m .3921 .68235 L .39197 .67971 L F
0 0 0 r
.59022 .71038 m .59117 .70621 L .58999 .70684 L F
.59022 .71038 m .59061 .70942 L .59117 .70621 L F
.616 .573 .782 r
.504 .78428 m .5024 .78568 L .50296 .78506 L F
.504 .78428 m .50478 .78563 L .5024 .78568 L F
.439 0 .027 r
.5024 .78568 m .50478 .78563 L .50472 .78725 L F
.541 .623 .883 r
.50458 .79031 m .50521 .78833 L .50405 .78703 L F
.916 .615 .458 r
.50477 .78733 m .50837 .78841 L .50693 .7904 L F
.541 .623 .883 r
.50521 .78833 m .50547 .7875 L .50473 .78726 L F
.50521 .78833 m .50473 .78726 L .50405 .78703 L F
.916 .615 .458 r
.50472 .78727 m .50474 .78727 L .50477 .78733 L F
.50474 .78727 m .50837 .78841 L .50477 .78733 L F
.439 0 .027 r
.50467 .78724 m .50472 .78725 L .50472 .78727 L F
.5024 .78568 m .50472 .78725 L .50467 .78724 L F
.916 .615 .458 r
.50472 .78727 m .50693 .7904 L .50458 .79031 L F
.541 .623 .883 r
.50527 .78815 m .50584 .78774 L .50547 .7875 L F
0 .144 .685 r
.50417 .78659 m .5024 .78568 L .50467 .78724 L F
.50296 .78506 m .50276 .78528 L .50417 .78659 L F
.50276 .78528 m .5024 .78568 L .50417 .78659 L F
.541 .623 .883 r
.50405 .78703 m .50467 .78724 L .50396 .7865 L F
.50458 .79031 m .50396 .7865 L .50472 .78727 L F
.50474 .78726 m .50469 .78699 L .50396 .7865 L F
.50467 .78724 m .50474 .78726 L .50458 .78711 L F
.50467 .78724 m .50458 .78711 L .50396 .7865 L F
0 .144 .685 r
.50451 .78701 m .50467 .78724 L .50472 .78727 L F
.50296 .78506 m .50467 .78724 L .50451 .78701 L F
.493 .357 .623 r
.50296 .78506 m .50472 .78727 L .50396 .7865 L F
.622 .159 .134 r
.50396 .7865 m .50432 .78674 L .50432 .78674 L F
.50396 .7865 m .50432 .78674 L .50408 .7872 L F
.50432 .78674 m .50469 .78699 L .50461 .78701 L F
.50432 .78674 m .50461 .78701 L .50408 .7872 L F
.50408 .7872 m .50584 .78774 L .50432 .7887 L F
.912 .764 .684 r
.50542 .78674 m .50837 .78841 L .50474 .78727 L F
.50474 .78725 m .50474 .78727 L .50472 .78727 L F
.541 .623 .883 r
.50474 .78726 m .50547 .7875 L .50469 .78699 L F
.622 .159 .134 r
.50469 .78699 m .50584 .78774 L .50408 .7872 L F
.912 .764 .684 r
.50774 .78491 m .50792 .78589 L .50542 .78674 L F
.50792 .78589 m .50837 .78841 L .50542 .78674 L F
.50774 .78491 m .50474 .78727 L .50474 .78725 L F
.759 .525 .579 r
.50782 .7864 m .50653 .78725 L .50584 .78774 L F
.50653 .78725 m .50432 .7887 L .50584 .78774 L F
.541 .623 .883 r
.50458 .79031 m .50584 .78774 L .50527 .78815 L F
.745 .275 .133 r
.52342 .77881 m .52114 .77721 L .52142 .77841 L F
.636 .275 .341 r
.52114 .77721 m .52271 .77933 L .51942 .77945 L F
.745 .275 .133 r
.52342 .77881 m .52271 .77933 L .52114 .77721 L F
.835 .668 .674 r
.58949 .562 m .59125 .5662 L .58828 .56517 L F
.649 .687 .872 r
.45252 .65725 m .45741 .66009 L .45481 .65841 L F
.292 .679 .974 r
.46077 .66027 m .45481 .65841 L .45741 .66009 L F
.661 .609 .785 r
.45741 .66009 m .46062 .6606 L .46077 .66027 L F
.057 .623 .727 r
.5143 .81408 m .51414 .81403 L .51337 .81418 L F
.5143 .81408 m .5168 .81394 L .51414 .81403 L F
.696 .517 .641 r
.51464 .77471 m .51211 .77661 L .51136 .77436 L F
.584 .914 .973 r
.3575 .59783 m .35703 .59901 L .35552 .59802 L F
.3575 .59783 m .35923 .59813 L .35703 .59901 L F
.594 .583 .81 r
.39896 .69056 m .39824 .69429 L .39695 .69091 L F
.39896 .69056 m .40017 .69384 L .39824 .69429 L F
.79 .645 .701 r
.59055 .55347 m .59177 .55684 L .58843 .55644 L F
.789 .65 .709 r
.59177 .55684 m .58983 .56002 L .58843 .55644 L F
.344 .63 .959 r
.68561 .48391 m .68375 .48386 L .68266 .48241 L F
.056 0 0 r
.50623 .81532 m .50722 .81541 L .50497 .81586 L F
.50623 .81532 m .5082 .81537 L .50722 .81541 L F
.816 .992 .743 r
.55751 .77678 m .56076 .77383 L .55921 .77319 L F
.568 .906 .976 r
.55921 .77319 m .56076 .77383 L .56306 .77247 L F
.588 .901 .633 r
.38111 .71773 m .38079 .7183 L .38258 .71897 L F
.766 .55 .606 r
.64618 .51415 m .6425 .51175 L .64611 .51229 L F
.774 .626 .696 r
.64875 .51257 m .64618 .51415 L .64611 .51229 L F
.07 0 0 r
.69254 .53769 m .69166 .53916 L .68967 .53951 L F
0 0 0 r
.69341 .53785 m .69254 .53769 L .69437 .53661 L F
.69341 .53785 m .69166 .53916 L .69254 .53769 L F
.16 .247 .705 r
.52029 .78208 m .51897 .78236 L .51835 .7799 L F
0 0 0 r
.51819 .784 m .51897 .78236 L .52029 .78208 L F
.855 .913 .871 r
.56917 .77454 m .5708 .77103 L .56888 .77373 L F
.56917 .77454 m .572 .77175 L .5708 .77103 L F
.765 .494 0 r
.56969 .77695 m .56917 .77454 L .56888 .77373 L F
.993 .807 .553 r
.59205 .72988 m .591 .72908 L .59154 .72694 L F
.835 .53 0 r
.59203 .73232 m .591 .72908 L .59205 .72988 L F
.591 .728 .939 r
.26258 .6508 m .26402 .65234 L .26597 .6517 L F
.519 .428 .692 r
.36643 .66822 m .3684 .66777 L .36797 .66546 L F
.534 .377 .614 r
.3664 .67068 m .3684 .66777 L .36643 .66822 L F
.427 .667 .962 r
.34543 .59339 m .34475 .5949 L .3429 .59341 L F
.34543 .59339 m .34673 .59488 L .34475 .5949 L F
0 0 0 r
.54376 .77736 m .54779 .77401 L .54786 .77802 L F
.669 .474 .612 r
.54913 .7768 m .5491 .77939 L .54702 .77866 L F
.54913 .7768 m .54702 .77866 L .54786 .77802 L F
.713 .456 .535 r
.54779 .77401 m .54913 .7768 L .54786 .77802 L F
.54779 .77401 m .549 .77449 L .54913 .7768 L F
.589 .409 .606 r
.31633 .62668 m .31885 .62662 L .31874 .62361 L F
.5 .262 .485 r
.31874 .62361 m .32086 .62322 L .32138 .6212 L F
.481 .303 .563 r
.31885 .62662 m .32086 .62322 L .31874 .62361 L F
.865 .726 .706 r
.35281 .73205 m .3541 .73509 L .35553 .7302 L F
.718 .26 .162 r
.35696 .73013 m .35511 .73051 L .3539 .72993 L F
.914 .891 .793 r
.35535 .72928 m .35511 .73051 L .35696 .73013 L F
.49 .435 .723 r
.59344 .74257 m .59091 .74076 L .5919 .74385 L F
.593 .587 .815 r
.59209 .74581 m .59344 .74257 L .5919 .74385 L F
.518 .268 .476 r
.62372 .54302 m .6236 .54523 L .62584 .54456 L F
.533 .261 .449 r
.62372 .54302 m .62584 .54456 L .62632 .54263 L F
.377 0 .01 r
.45226 .681 m .4549 .68091 L .45306 .67985 L F
.511 .298 .527 r
.32086 .62322 m .32321 .62046 L .32138 .6212 L F
.886 .884 .825 r
.60775 .52098 m .60442 .5228 L .60641 .51984 L F
.60775 .52098 m .60555 .52386 L .60442 .5228 L F
0 0 .526 r
.64388 .49255 m .64345 .4898 L .6412 .49025 L F
.64388 .49255 m .64415 .49173 L .64345 .4898 L F
0 0 .019 r
.64377 .49427 m .64415 .49173 L .64388 .49255 L F
.887 .925 .842 r
.60555 .52386 m .60335 .52439 L .60442 .5228 L F
.76 .58 .654 r
.59839 .69918 m .59612 .69652 L .59608 .69839 L F
.381 0 0 r
.39422 .65162 m .39641 .65171 L .39766 .6511 L F
.456 0 .059 r
.39641 .65171 m .39979 .65094 L .39766 .6511 L F
.582 .05 0 r
.58368 .67823 m .58484 .67907 L .58308 .67735 L F
.74 .239 .034 r
.58308 .67735 m .58484 .67907 L .58674 .67955 L F
.925 .675 .54 r
.5961 .70087 m .59839 .69918 L .59608 .69839 L F
.5961 .70087 m .59831 .70137 L .59839 .69918 L F
.952 .765 .613 r
.60016 .72675 m .60049 .72454 L .59919 .7239 L F
.296 .701 .975 r
.33007 .59201 m .32954 .59283 L .328 .59232 L F
.33007 .59201 m .33157 .59291 L .32954 .59283 L F
.416 .083 .291 r
.3763 .65602 m .37491 .65481 L .37424 .65649 L F
.385 .702 .984 r
.76328 .58662 m .76704 .58776 L .76618 .5867 L F
.384 .666 .97 r
.76704 .58776 m .76846 .58657 L .76618 .5867 L F
.76704 .58776 m .77159 .58854 L .76846 .58657 L F
.607 .559 .775 r
.36751 .68787 m .36911 .68514 L .3669 .68545 L F
.36751 .68787 m .36985 .68797 L .36911 .68514 L F
.496 .351 .614 r
.57035 .77063 m .56978 .77215 L .5708 .77103 L F
.56846 .76892 m .56965 .77183 L .57035 .77063 L F
.56965 .77183 m .56978 .77215 L .57035 .77063 L F
.56908 .76949 m .57035 .77063 L .56932 .77015 L F
.57035 .77063 m .5708 .77103 L .56932 .77015 L F
.916 .943 .805 r
.57217 .7676 m .56932 .77015 L .5708 .77103 L F
0 0 0 r
.56957 .7708 m .56932 .77015 L .57042 .76918 L F
.56871 .77242 m .56932 .77015 L .56957 .7708 L F
.496 .351 .614 r
.56846 .76892 m .56908 .76949 L .56932 .77015 L F
0 0 0 r
.57235 .76472 m .56846 .76892 L .57019 .7686 L F
.57235 .76472 m .57019 .7686 L .57111 .7675 L F
.57235 .76472 m .57111 .7675 L .56743 .76566 L F
.916 .943 .805 r
.57133 .76734 m .57116 .76746 L .56983 .76941 L F
.56981 .76947 m .56983 .76941 L .56932 .77015 L F
.57133 .76734 m .56983 .76941 L .56981 .76947 L F
.259 .254 .663 r
.57019 .76811 m .56834 .76836 L .56743 .76566 L F
.57065 .76851 m .57009 .76848 L .57019 .76811 L F
.57009 .76848 m .56834 .76836 L .57019 .76811 L F
.916 .943 .805 r
.57126 .76731 m .57118 .76741 L .56932 .77015 L F
0 0 0 r
.57111 .7675 m .57019 .7686 L .57059 .76853 L F
.916 .943 .805 r
.57205 .76771 m .57133 .76734 L .56932 .77015 L F
0 0 0 r
.57097 .76781 m .57059 .76853 L .57065 .76851 L F
.56932 .77015 m .57118 .76741 L .57059 .76853 L F
.496 .351 .614 r
.57059 .76853 m .56932 .77015 L .57065 .76851 L F
0 0 0 r
.56932 .77015 m .57059 .76853 L .57008 .76948 L F
.496 .351 .614 r
.56846 .76892 m .56932 .77015 L .57059 .76853 L F
0 0 0 r
.57111 .7675 m .57059 .76853 L .57097 .76781 L F
.57008 .76948 m .57125 .7673 L .57042 .76918 L F
.57111 .7675 m .57097 .76781 L .57019 .76811 L F
.57097 .76781 m .57065 .76851 L .57063 .76849 L F
.57097 .76781 m .57081 .76812 L .57008 .76948 L F
.57097 .76781 m .57063 .76849 L .57019 .76811 L F
.916 .943 .805 r
.57126 .76731 m .57125 .7673 L .57118 .76741 L F
0 0 0 r
.57118 .76741 m .57125 .7673 L .57081 .76812 L F
.57118 .76741 m .57081 .76812 L .57097 .76781 L F
.57111 .7675 m .57019 .76811 L .56743 .76566 L F
.916 .943 .805 r
.57133 .76734 m .57126 .76731 L .57116 .76746 L F
.57217 .7676 m .57212 .76759 L .57205 .76771 L F
.57212 .76759 m .57126 .76731 L .57205 .76771 L F
.495 .458 .745 r
.36462 .67433 m .36543 .67688 L .36721 .67621 L F
.474 .426 .724 r
.36543 .67688 m .36774 .67936 L .36721 .67621 L F
.594 .627 .854 r
.49029 .66602 m .48815 .66667 L .48725 .66481 L F
.862 .687 .665 r
.602 .73261 m .60315 .72958 L .60038 .72962 L F
.433 .029 .171 r
.5248 .75937 m .527 .75927 L .52814 .75728 L F
.364 0 .169 r
.527 .75927 m .5306 .75637 L .52814 .75728 L F
.537 .387 .624 r
.27075 .62075 m .26883 .62379 L .26864 .62112 L F
.549 .36 .577 r
.41512 .83866 m .41739 .83863 L .4174 .83585 L F
.41512 .83866 m .41739 .83863 L .4174 .83585 L F
.487 .87 .975 r
.58798 .57568 m .58653 .57541 L .58411 .5761 L F
.81 .542 .533 r
.58798 .57568 m .58606 .57793 L .58653 .57541 L F
.58798 .57568 m .58828 .57889 L .58606 .57793 L F
.806 .574 .586 r
.58949 .57616 m .58828 .57889 L .58798 .57568 L F
.737 .67 .784 r
.65226 .5426 m .65347 .54589 L .656 .54329 L F
0 0 0 r
.49608 .75897 m .49502 .75966 L .49465 .75974 L F
.444 0 0 r
.49873 .75968 m .49502 .75966 L .49608 .75897 L F
.075 .475 .891 r
.52417 .80707 m .52095 .80501 L .52318 .80728 L F
.658 .732 .904 r
.5254 .80436 m .52417 .80707 L .52318 .80728 L F
.5254 .80436 m .52691 .80602 L .52417 .80707 L F
.939 .965 .722 r
.59963 .53064 m .6014 .52928 L .60098 .53177 L F
.59963 .53064 m .60135 .52756 L .6014 .52928 L F
.958 .635 .235 r
.57214 .75204 m .57248 .75417 L .57337 .75492 L F
.999 .796 .457 r
.57233 .75661 m .57337 .75492 L .57248 .75417 L F
.57233 .75661 m .57316 .75737 L .57337 .75492 L F
.577 .93 .945 r
.71644 .52016 m .71509 .52148 L .71726 .5205 L F
.71644 .52016 m .71286 .5215 L .71509 .52148 L F
.602 .785 .968 r
.77003 .61746 m .77102 .61879 L .77359 .61809 L F
.57 .681 .915 r
.71835 .48782 m .71673 .48961 L .71565 .48732 L F
.71835 .48782 m .71902 .48918 L .71673 .48961 L F
.552 .156 .245 r
.3698 .71035 m .36848 .71217 L .36621 .71127 L F
0 0 0 r
.37066 .70957 m .3698 .71035 L .37215 .71012 L F
.37066 .70957 m .36848 .71217 L .3698 .71035 L F
.936 .895 .764 r
.5583 .78442 m .56041 .78539 L .55829 .7875 L F
.431 .266 .555 r
.4174 .83585 m .41836 .83586 L .41952 .83551 L F
.4174 .83585 m .41739 .83863 L .41836 .83586 L F
.41836 .83586 m .4174 .83585 L .41952 .83551 L F
.41836 .83586 m .41739 .83863 L .4174 .83585 L F
.84 .932 .889 r
.57655 .57988 m .57641 .58109 L .57501 .58104 L F
.566 .485 .723 r
.57832 .57831 m .57641 .58109 L .57655 .57988 L F
.57832 .57831 m .57966 .58139 L .57641 .58109 L F
.195 0 .101 r
.57544 .5811 m .57793 .58027 L .5783 .57843 L F
.57774 .57888 m .5783 .57843 L .57832 .57831 L F
.57544 .5811 m .5783 .57843 L .57774 .57888 L F
.84 .932 .889 r
.57567 .58052 m .57501 .58104 L .57494 .58104 L F
.57655 .57988 m .57501 .58104 L .57567 .58052 L F
.847 .441 .27 r
.57494 .58104 m .57641 .58109 L .5764 .58308 L F
.573 .37 .567 r
.57641 .58109 m .57908 .58398 L .5764 .58308 L F
.57641 .58109 m .57966 .58139 L .57908 .58398 L F
.469 .762 .994 r
.31499 .58993 m .31452 .59125 L .31301 .59015 L F
.31499 .58993 m .31648 .59099 L .31452 .59125 L F
.579 .341 .519 r
.31381 .62913 m .31614 .62895 L .31633 .62668 L F
.467 .246 .495 r
.31633 .62668 m .31817 .6284 L .31885 .62662 L F
.31633 .62668 m .31614 .62895 L .31817 .6284 L F
.648 .858 .979 r
.45722 .6471 m .45464 .64792 L .45338 .6471 L F
.247 0 .041 r
.32485 .64257 m .3216 .64492 L .32288 .64313 L F
.774 .626 .696 r
.64875 .51257 m .64958 .51503 L .64618 .51415 L F
.235 .302 .729 r
.65082 .51322 m .64958 .51503 L .64875 .51257 L F
.493 .903 .815 r
.64887 .51399 m .64861 .51438 L .65082 .51322 L F
.21 .669 .945 r
.64838 .51472 m .64861 .51438 L .64618 .51415 L F
.227 0 0 r
.64618 .51415 m .64861 .51438 L .64708 .5147 L F
.493 .903 .815 r
.64708 .5147 m .64861 .51438 L .64887 .51399 L F
.21 .669 .945 r
.64958 .51503 m .64861 .51438 L .64838 .51472 L F
.681 .919 .973 r
.65082 .51322 m .64861 .51438 L .64958 .51503 L F
.817 .958 .905 r
.72448 .50208 m .72261 .50383 L .72542 .50187 L F
.654 .963 .925 r
.72745 .50047 m .72448 .50208 L .72542 .50187 L F
.895 .754 .698 r
.61679 .52608 m .61789 .52901 L .61835 .52659 L F
.332 .067 .354 r
.46967 .75698 m .47116 .75708 L .4727 .75538 L F
.332 0 .092 r
.4727 .75538 m .47393 .75647 L .47443 .75447 L F
.4727 .75538 m .47116 .75708 L .47393 .75647 L F
.637 .847 .456 r
.55107 .70315 m .55323 .7018 L .55334 .70395 L F
.55107 .70315 m .5524 .70109 L .55323 .7018 L F
.55107 .70315 m .54986 .70477 L .5524 .70109 L F
.45 .48 .798 r
.58371 .56665 m .58311 .57015 L .58136 .5696 L F
.58371 .56665 m .58517 .57001 L .58311 .57015 L F
.838 .382 .127 r
.55915 .73533 m .5616 .73718 L .55909 .73435 L F
.765 .527 .573 r
.58005 .57667 m .57832 .57831 L .58037 .57525 L F
.58005 .57667 m .58189 .57896 L .57832 .57831 L F
.628 .372 .512 r
.50554 .77455 m .50782 .77688 L .50402 .77701 L F
.466 .351 .638 r
.46172 .77155 m .46363 .77113 L .46326 .76861 L F
.384 .31 .649 r
.46172 .77155 m .46386 .77364 L .46363 .77113 L F
.46172 .77155 m .46179 .77454 L .46386 .77364 L F
.622 .621 .829 r
.48005 .6572 m .47649 .65472 L .47882 .65424 L F
.735 .683 .8 r
.48265 .65472 m .48005 .6572 L .47882 .65424 L F
.618 .836 .984 r
.48227 .65671 m .48005 .6572 L .48265 .65472 L F
.249 .737 .923 r
.69226 .52555 m .69153 .52575 L .68882 .52528 L F
.662 .588 .762 r
.37215 .71012 m .37334 .71341 L .37563 .71281 L F
.452 .107 .289 r
.4289 .69038 m .4311 .69006 L .43185 .68853 L F
.35 .008 .236 r
.43185 .68853 m .4311 .69006 L .43314 .68951 L F
.71 .627 .762 r
.66726 .49237 m .66556 .49501 L .66885 .495 L F
.225 0 0 r
.66556 .49501 m .66785 .49522 L .66885 .495 L F
0 0 .486 r
.66882 .49491 m .66885 .495 L .66785 .49522 L F
.66882 .49491 m .67082 .4972 L .66885 .495 L F
.534 .422 .672 r
.36462 .67433 m .36669 .67386 L .3664 .67068 L F
.542 .454 .705 r
.36462 .67433 m .36721 .67621 L .36669 .67386 L F
.582 .45 .666 r
.64022 .51198 m .6425 .51175 L .64238 .5094 L F
.064 0 .361 r
.6425 .51175 m .64103 .51534 L .64022 .51198 L F
.792 .576 .608 r
.63938 .51385 m .6425 .51175 L .64022 .51198 L F
.541 .442 .691 r
.72951 .60171 m .73185 .60128 L .73145 .59773 L F
.569 .512 .752 r
.72951 .60171 m .73245 .60342 L .73185 .60128 L F
.806 .574 .586 r
.58949 .57616 m .59108 .57871 L .58828 .57889 L F
.571 .422 .64 r
.58471 .6882 m .5854 .69012 L .58783 .68773 L F
.558 .415 .643 r
.58617 .68908 m .5854 .69012 L .58471 .6882 L F
.568 .41 .627 r
.58783 .68773 m .58617 .68908 L .58471 .6882 L F
.408 .335 .663 r
.46326 .76861 m .46474 .76516 L .46309 .76613 L F
.526 .265 .462 r
.61266 .57341 m .61016 .57549 L .61042 .57391 L F
.461 .816 .997 r
.43414 .64911 m .43637 .64873 L .43776 .64942 L F
.533 .847 .998 r
.43776 .64942 m .43861 .64817 L .43989 .64863 L F
.43776 .64942 m .43637 .64873 L .43861 .64817 L F
.575 .141 .179 r
.35246 .70408 m .35585 .70315 L .35406 .70344 L F
.373 0 .083 r
.73575 .59692 m .73409 .59586 L .73329 .59722 L F
.73575 .59692 m .73698 .59527 L .73409 .59586 L F
.539 .266 .45 r
.73409 .59586 m .73698 .59527 L .7363 .59459 L F
.412 .569 .9 r
.75252 .60381 m .75061 .60376 L .74902 .60108 L F
.608 .603 .821 r
.46062 .6606 m .46388 .663 L .46292 .65988 L F
.561 .509 .754 r
.46388 .663 m .46522 .65936 L .46292 .65988 L F
.46388 .663 m .46604 .66254 L .46522 .65936 L F
.534 .411 .659 r
.4642 .66548 m .46604 .66254 L .46388 .663 L F
.771 .466 .47 r
.51253 .73731 m .51381 .74081 L .51219 .73944 L F
.844 .5 .403 r
.5155 .74062 m .51381 .74081 L .51253 .73731 L F
.308 .627 .961 r
.75548 .60492 m .75341 .60549 L .75252 .60381 L F
.75548 .60492 m .75634 .60611 L .75341 .60549 L F
.624 .493 .682 r
.27037 .62955 m .26828 .63228 L .26896 .63066 L F
.634 .507 .69 r
.27037 .62955 m .27062 .63152 L .26828 .63228 L F
.351 0 .075 r
.25475 .58947 m .25688 .58913 L .25844 .58721 L F
.175 0 0 r
.25688 .58913 m .2606 .58702 L .25844 .58721 L F
.676 .747 .905 r
.68189 .49101 m .68372 .4887 L .68069 .49096 L F
.68189 .49101 m .68451 .49035 L .68372 .4887 L F
.5 .682 .948 r
.46147 .64566 m .46022 .64731 L .45934 .64633 L F
.46147 .64566 m .46267 .64745 L .46022 .64731 L F
.675 .322 .368 r
.59659 .58021 m .59324 .57933 L .59671 .57915 L F
.55 .282 .463 r
.59902 .57873 m .59659 .58021 L .59671 .57915 L F
0 .447 .864 r
.64843 .48983 m .64699 .48984 L .64606 .48872 L F
.64843 .48983 m .65034 .49138 L .64699 .48984 L F
.327 0 0 r
.41951 .69467 m .42346 .69344 L .4212 .69383 L F
.55 .224 .367 r
.45762 .68819 m .45979 .68961 L .4575 .68982 L F
.393 .645 .958 r
.26954 .6524 m .26993 .65076 L .26819 .65139 L F
.26954 .6524 m .27287 .65271 L .26993 .65076 L F
.478 .22 .443 r
.7748 .60634 m .77674 .60563 L .77656 .60432 L F
.636 .642 .839 r
.77656 .60432 m .77891 .60415 L .77788 .60058 L F
.625 .321 .435 r
.77674 .60563 m .77919 .60633 L .77656 .60432 L F
.6 .334 .485 r
.77656 .60432 m .77919 .60633 L .77891 .60415 L F
.514 .284 .503 r
.45866 .67955 m .46087 .67913 L .46116 .67688 L F
.549 .342 .553 r
.46087 .67913 m .46315 .67636 L .46116 .67688 L F
.539 .402 .642 r
.54318 .74908 m .54507 .74605 L .5433 .7466 L F
.862 .774 .763 r
.66054 .53377 m .66224 .53446 L .66146 .53136 L F
.846 .663 .654 r
.65908 .5363 m .66224 .53446 L .66054 .53377 L F
.65908 .5363 m .66174 .53707 L .66224 .53446 L F
.765 .5 .532 r
.54995 .77485 m .54913 .7768 L .549 .77449 L F
.54995 .77485 m .55282 .77688 L .54913 .7768 L F
.487 .178 .369 r
.39888 .67117 m .39802 .67335 L .39586 .67373 L F
.546 .238 .396 r
.40081 .67244 m .39888 .67117 L .40126 .67059 L F
.40081 .67244 m .39802 .67335 L .39888 .67117 L F
.753 .597 .683 r
.75286 .58979 m .74876 .58867 L .75224 .5892 L F
.142 0 0 r
.75009 .58892 m .75224 .5892 L .74876 .58867 L F
.858 .904 .865 r
.75233 .58713 m .75224 .5892 L .75009 .58892 L F
0 0 0 r
.75475 .5846 m .7526 .58748 L .75383 .58592 L F
.858 .904 .865 r
.75383 .58592 m .75309 .58745 L .75233 .58713 L F
.75309 .58745 m .75224 .5892 L .75233 .58713 L F
.703 .644 .788 r
.75368 .58769 m .75607 .58859 L .75399 .58776 L F
.7526 .58748 m .75496 .58823 L .75368 .58769 L F
.75496 .58823 m .75607 .58859 L .75368 .58769 L F
.709 .883 .962 r
.75399 .58776 m .75607 .58859 L .75814 .58743 L F
.92 .923 .798 r
.4738 .78853 m .47467 .78495 L .47476 .78739 L F
.181 .365 .811 r
.47622 .79009 m .4738 .78853 L .47476 .78739 L F
.507 .307 .543 r
.77185 .59592 m .77416 .59536 L .77416 .5931 L F
.619 .399 .561 r
.37215 .71012 m .37449 .71003 L .37481 .70764 L F
.596 .544 .767 r
.37397 .70526 m .37481 .70764 L .37686 .70717 L F
.739 .509 .581 r
.37481 .70764 m .37796 .71008 L .37686 .70717 L F
.37481 .70764 m .37449 .71003 L .37796 .71008 L F
.799 .639 .684 r
.54376 .77736 m .54477 .77997 L .54151 .77917 L F
.798 .463 .421 r
.54151 .77917 m .54477 .77997 L .54364 .78242 L F
.53 .499 .766 r
.54702 .77866 m .54477 .77997 L .54376 .77736 L F
.349 .09 .373 r
.36044 .60934 m .36078 .60678 L .36329 .60609 L F
.791 .607 .652 r
.63112 .51754 m .63134 .52031 L .62891 .51718 L F
.743 .984 .763 r
.59825 .74845 m .60024 .746 L .59706 .74797 L F
.995 .765 .41 r
.55323 .7018 m .5524 .70109 L .55258 .69877 L F
.435 .098 .294 r
.55038 .70642 m .55334 .70395 L .55254 .70587 L F
.453 .828 .991 r
.55644 .70359 m .55471 .70315 L .55334 .70395 L F
.598 .418 .609 r
.55471 .70315 m .55254 .70587 L .55334 .70395 L F
.55254 .70587 m .55408 .70395 L .55248 .70349 L F
.55408 .70395 m .55471 .70315 L .55413 .70324 L F
.166 .125 .564 r
.55429 .70091 m .55334 .70395 L .55323 .7018 L F
.55425 .70147 m .55334 .70395 L .55429 .70091 L F
.55453 .70071 m .55471 .70315 L .55334 .70395 L F
.598 .418 .609 r
.55408 .70395 m .55413 .70324 L .55248 .70349 L F
.166 .125 .564 r
.55453 .70071 m .55425 .70147 L .55429 .70091 L F
.497 .848 .994 r
.294 .63587 m .2965 .63538 L .29805 .63604 L F
.403 .715 .987 r
.29882 .63476 m .29805 .63604 L .2965 .63538 L F
.29882 .63476 m .29977 .6356 L .29805 .63604 L F
.706 .57 .7 r
.56087 .78194 m .56296 .77888 L .56155 .77915 L F
.679 .478 .606 r
.53553 .77727 m .53542 .77975 L .53323 .77912 L F
.978 .913 .662 r
.62636 .4923 m .62488 .49574 L .62487 .49496 L F
0 0 0 r
.62894 .48979 m .62796 .49133 L .62636 .4923 L F
0 0 .087 r
.62765 .49258 m .62636 .4923 L .62796 .49133 L F
.62765 .49258 m .62488 .49574 L .62636 .4923 L F
.734 .211 0 r
.5598 .71931 m .55668 .71759 L .55766 .71827 L F
.806 .765 .816 r
.71126 .504 m .70732 .50544 L .71052 .50402 L F
.411 .509 .848 r
.71021 .50176 m .71126 .504 L .7124 .50285 L F
.55 .293 .478 r
.71052 .50402 m .7124 .50285 L .71126 .504 L F
.585 .789 .977 r
.74197 .59275 m .7386 .59228 L .74018 .59173 L F
.657 .772 .934 r
.74359 .59002 m .74197 .59275 L .74018 .59173 L F
.74359 .59002 m .74418 .59196 L .74197 .59275 L F
.722 .469 0 r
.66726 .49237 m .66452 .49359 L .66556 .49501 L F
0 0 0 r
.66556 .49501 m .66743 .49344 L .66785 .49522 L F
.66556 .49501 m .66478 .49675 L .66743 .49344 L F
.599 .633 .856 r
.25699 .64868 m .26094 .65094 L .25956 .64805 L F
.445 .52 .841 r
.25956 .64805 m .26094 .65094 L .26258 .6508 L F
.611 .286 .395 r
.71698 .50597 m .71922 .50319 L .71719 .50444 L F
.283 0 0 r
.71659 .50747 m .71982 .50598 L .71698 .50597 L F
.541 .582 .844 r
.70046 .49576 m .70206 .49365 L .69997 .49393 L F
.70046 .49576 m .70294 .49542 L .70206 .49365 L F
.53 .428 .684 r
.70046 .49576 m .70317 .49741 L .70294 .49542 L F
.435 .218 .483 r
.36774 .66291 m .36973 .66263 L .37008 .65975 L F
.462 .24 .49 r
.37008 .65975 m .3719 .66188 L .37194 .65903 L F
.37008 .65975 m .36973 .66263 L .3719 .66188 L F
.537 0 0 r
.65517 .50126 m .65576 .50063 L .65412 .49977 L F
.65517 .50126 m .65924 .50234 L .65576 .50063 L F
.974 .725 .499 r
.54141 .78184 m .54235 .78282 L .54198 .78556 L F
.798 .463 .421 r
.54151 .77917 m .54235 .78282 L .54141 .78184 L F
.54151 .77917 m .54364 .78242 L .54235 .78282 L F
.011 0 .308 r
.54198 .78556 m .54235 .78282 L .54364 .78242 L F
.443 .147 .367 r
.51303 .72963 m .51542 .72921 L .51548 .72744 L F
.937 .855 .735 r
.51598 .72515 m .51548 .72744 L .5167 .72383 L F
.377 .136 .417 r
.56512 .69266 m .56417 .69119 L .56507 .69024 L F
.56512 .69266 m .5632 .69342 L .56417 .69119 L F
.165 0 .299 r
.69017 .52777 m .68845 .52866 L .68731 .53121 L F
.431 0 0 r
.63912 .49701 m .64164 .49718 L .64305 .49613 L F
.919 .969 .672 r
.64305 .49613 m .64392 .49406 L .64377 .49427 L F
.64305 .49613 m .64261 .49453 L .64392 .49406 L F
.64305 .49613 m .64164 .49718 L .64261 .49453 L F
.918 .975 .77 r
.62234 .51402 m .62101 .51766 L .62351 .51491 L F
.62234 .51402 m .62059 .51679 L .62101 .51766 L F
.982 .718 .328 r
.62028 .51871 m .62101 .51766 L .62059 .51679 L F
.748 .59 .68 r
.61938 .5183 m .61952 .51836 L .62028 .51871 L F
.982 .718 .328 r
.62028 .51871 m .62098 .5199 L .62099 .51903 L F
.666 .796 .944 r
.62348 .51957 m .62098 .5199 L .62028 .51871 L F
.748 .59 .68 r
.61952 .51836 m .62272 .51983 L .62028 .51871 L F
.982 .718 .328 r
.62028 .51871 m .62099 .51903 L .62101 .51766 L F
.772 .555 .605 r
.62685 .51774 m .62348 .51957 L .62481 .51863 L F
.62685 .51774 m .62687 .52048 L .62348 .51957 L F
.326 .792 .679 r
.62685 .51774 m .62837 .51698 L .62891 .51718 L F
.62685 .51774 m .62481 .51863 L .62837 .51698 L F
.74 .602 .704 r
.62891 .51718 m .62687 .52048 L .62685 .51774 L F
.005 0 .233 r
.49578 .79023 m .49403 .79131 L .49522 .78885 L F
.49578 .79023 m .49522 .78885 L .49426 .78807 L F
0 0 .275 r
.50045 .80998 m .49767 .80842 L .49804 .81084 L F
.208 .639 .951 r
.30596 .58887 m .30554 .5896 L .30424 .58839 L F
.30596 .58887 m .30747 .58983 L .30554 .5896 L F
.944 .589 .293 r
.6828 .49842 m .68364 .49823 L .68258 .49831 L F
.455 .806 .998 r
.68556 .49703 m .68364 .49823 L .6828 .49842 L F
.68556 .49703 m .6867 .49789 L .68364 .49823 L F
.502 0 0 r
.68258 .49831 m .68364 .49823 L .68597 .4994 L F
.922 .567 .342 r
.59232 .6868 m .59311 .68539 L .59126 .68498 L F
.59232 .6868 m .59379 .68754 L .59311 .68539 L F
.773 .689 .77 r
.48489 .6542 m .48265 .65472 L .48427 .65227 L F
.711 .592 .721 r
.48573 .65528 m .48265 .65472 L .48489 .6542 L F
.4 .461 .808 r
.48427 .65227 m .48673 .65356 L .48489 .6542 L F
.41 .439 .78 r
.48673 .65356 m .48573 .65528 L .48489 .6542 L F
.087 0 0 r
.63124 .50197 m .63336 .50165 L .6347 .50087 L F
.547 .337 .547 r
.6347 .50087 m .63467 .50337 L .63239 .50374 L F
.517 .437 .704 r
.63497 .49852 m .6347 .50087 L .63619 .50009 L F
0 0 0 r
.6347 .50087 m .63595 .5007 L .63619 .50009 L F
.679 .444 .559 r
.63847 .50273 m .63467 .50337 L .6347 .50087 L F
0 0 0 r
.6347 .50087 m .63336 .50165 L .63595 .5007 L F
.6347 .50087 m .63336 .50165 L .63619 .50009 L F
.409 .316 .638 r
.77416 .59536 m .77599 .59164 L .77416 .5931 L F
0 0 0 r
.41145 .6495 m .41213 .64955 L .41358 .64927 L F
.41145 .6495 m .40981 .65018 L .41213 .64955 L F
.053 0 .422 r
.78063 .61166 m .77897 .61539 L .78071 .61212 L F
.657 .972 .869 r
.78063 .61166 m .78071 .61212 L .78375 .61014 L F
.833 .454 .335 r
.62397 .49974 m .62613 .50071 L .6255 .49876 L F
.292 .077 .406 r
.626 .50052 m .62397 .49974 L .62601 .49783 L F
.62599 .5008 m .62397 .49974 L .626 .50052 L F
.35 0 0 r
.62329 .49948 m .62397 .49974 L .6255 .49876 L F
.62198 .49991 m .62397 .49974 L .62329 .49948 L F
.074 0 0 r
.29464 .60448 m .29401 .60391 L .29624 .6035 L F
.29464 .60448 m .29239 .60537 L .29401 .60391 L F
.812 .722 .766 r
.61679 .52608 m .61464 .52885 L .61789 .52901 L F
.615 .429 .607 r
.58484 .67907 m .5851 .68117 L .58674 .67955 L F
.737 .386 .386 r
.5851 .68117 m .58839 .68191 L .58674 .67955 L F
.503 .681 .946 r
.75266 .61388 m .75399 .61237 L .75153 .61246 L F
.75266 .61388 m .75645 .61469 L .75399 .61237 L F
.547 .415 .653 r
.53039 .7408 m .53307 .74343 L .53219 .74129 L F
.53039 .7408 m .53073 .7442 L .53307 .74343 L F
.252 .535 .92 r
.35552 .59802 m .35405 .59794 L .3519 .59553 L F
.346 .267 .623 r
.46179 .77454 m .46356 .77622 L .46386 .77364 L F
.46179 .77454 m .46218 .77699 L .46356 .77622 L F
.643 .153 0 r
.65545 .51548 m .65528 .51558 L .65405 .51463 L F
.65545 .51548 m .65642 .51672 L .65528 .51558 L F
.786 .293 .037 r
.65655 .51642 m .65642 .51672 L .65545 .51548 L F
0 0 0 r
.67503 .50975 m .67507 .50958 L .67599 .508 L F
.67503 .50975 m .67381 .51213 L .67507 .50958 L F
.898 .84 .381 r
.65285 .49428 m .65217 .4969 L .65244 .49776 L F
.936 .562 .246 r
.65217 .4969 m .65412 .49977 L .65244 .49776 L F
.648 .822 .967 r
.66277 .48597 m .66655 .48639 L .6644 .48449 L F
.577 .693 .921 r
.66655 .48639 m .66729 .48264 L .6644 .48449 L F
.66655 .48639 m .6688 .4858 L .66729 .48264 L F
.591 .697 .916 r
.66713 .48661 m .6688 .4858 L .66655 .48639 L F
.514 .36 .61 r
.57237 .72134 m .57352 .71783 L .57126 .71813 L F
.57237 .72134 m .57455 .72079 L .57352 .71783 L F
.552 .353 .564 r
.57455 .72079 m .57689 .7181 L .57352 .71783 L F
.194 .717 .86 r
.26854 .58396 m .27056 .5838 L .27253 .58397 L F
.263 0 0 r
.27056 .5838 m .27414 .58436 L .27253 .58397 L F
0 .087 .621 r
.52822 .77935 m .52971 .78225 L .52868 .7788 L F
.99 .87 .616 r
.61254 .54322 m .61115 .54441 L .61219 .54534 L F
.993 .755 .394 r
.61125 .5468 m .61219 .54534 L .61115 .54441 L F
.61125 .5468 m .61251 .54902 L .61219 .54534 L F
.079 0 0 r
.30428 .60129 m .30038 .60261 L .3023 .60193 L F
.589 .812 .985 r
.48258 .67545 m .48145 .67698 L .48369 .67641 L F
.695 .976 .785 r
.48258 .67545 m .47895 .67848 L .48145 .67698 L F
.5 .049 .112 r
.48145 .67698 m .48311 .67818 L .48369 .67641 L F
.48145 .67698 m .47895 .67848 L .48311 .67818 L F
.85 .695 .69 r
.60373 .73793 m .60451 .73534 L .60158 .73501 L F
.477 .806 1 r
.44558 .64828 m .44776 .64792 L .44907 .64871 L F
.474 .829 .996 r
.44776 .64792 m .45121 .64813 L .44907 .64871 L F
.561 .57 .82 r
.6412 .49025 m .64253 .48688 L .64 .48691 L F
.6412 .49025 m .64345 .4898 L .64253 .48688 L F
.754 .699 .8 r
.49429 .74946 m .49163 .75222 L .495 .75123 L F
.541 .166 .28 r
.49163 .75222 m .49369 .75366 L .495 .75123 L F
.535 .135 .229 r
.49369 .75366 m .49732 .75167 L .495 .75123 L F
.785 .534 0 r
.57266 .76551 m .57281 .76567 L .57243 .76337 L F
.57266 .76551 m .57243 .76337 L .57357 .76205 L F
.685 .514 .649 r
.62922 .50558 m .62898 .50274 L .62971 .50333 L F
.618 .369 .517 r
.63207 .50523 m .62971 .50333 L .63239 .50374 L F
.63207 .50523 m .62922 .50558 L .62971 .50333 L F
.281 0 0 r
.31786 .64645 m .31632 .64823 L .31415 .64863 L F
.16 0 0 r
.31832 .64754 m .31786 .64645 L .31978 .64569 L F
.31832 .64754 m .31632 .64823 L .31786 .64645 L F
.337 .702 .983 r
.65003 .52426 m .64989 .52559 L .64752 .52475 L F
.65003 .52426 m .65093 .5252 L .64989 .52559 L F
0 0 0 r
.69166 .53916 m .68754 .54122 L .68967 .53951 L F
.081 0 .313 r
.46047 .78003 m .46155 .77985 L .46218 .77699 L F
.147 .229 .693 r
.46047 .78003 m .46228 .78181 L .46155 .77985 L F
.438 .268 .553 r
.46065 .78192 m .46228 .78181 L .46047 .78003 L F
.063 0 0 r
.24221 .59554 m .24423 .59464 L .24261 .5951 L F
.122 0 0 r
.24261 .5951 m .24423 .59464 L .24516 .59334 L F
.591 .697 .916 r
.66713 .48661 m .66932 .48675 L .6688 .4858 L F
.778 .587 .641 r
.66651 .48886 m .66932 .48675 L .66713 .48661 L F
.487 .074 .182 r
.4173 .66531 m .4136 .66731 L .41499 .66552 L F
.361 .322 .68 r
.58833 .69139 m .59006 .68717 L .58783 .68773 L F
.58833 .69139 m .59048 .68968 L .59006 .68717 L F
.001 .008 .509 r
.58981 .69317 m .59048 .68968 L .58833 .69139 L F
.99 .839 .597 r
.6115 .54043 m .61115 .54441 L .61254 .54322 L F
0 .133 .667 r
.65034 .49138 m .65081 .49135 L .65035 .49266 L F
.55 .358 .574 r
.65371 .4923 m .65285 .49428 L .65035 .49266 L F
.919 .524 .156 r
.65081 .49135 m .65285 .49428 L .65035 .49266 L F
.573 .941 .856 r
.77897 .61539 m .77838 .61528 L .77561 .6168 L F
.053 0 .422 r
.78063 .61166 m .78057 .61417 L .77897 .61539 L F
.521 .918 .86 r
.77897 .61539 m .78057 .61417 L .77838 .61528 L F
.571 .851 .996 r
.7654 .6097 m .76873 .60981 L .76638 .61063 L F
.332 0 .039 r
.2627 .58667 m .2648 .58635 L .26644 .58447 L F
.547 .676 .923 r
.6767 .49231 m .67785 .48936 L .67563 .4913 L F
.6767 .49231 m .67926 .49244 L .67785 .48936 L F
.954 .823 .675 r
.6154 .50403 m .61529 .50604 L .61372 .50467 L F
.985 .88 .642 r
.61337 .50925 m .61372 .50467 L .61529 .50604 L F
.972 .698 .454 r
.5702 .6906 m .56875 .68693 L .57051 .6878 L F
.386 .023 .221 r
.24423 .59464 m .24711 .59272 L .24516 .59334 L F
.823 .346 0 r
.58982 .72479 m .59154 .72694 L .58975 .72579 L F
.179 0 .142 r
.43591 .69856 m .43314 .70102 L .43416 .69942 L F
.24 0 0 r
.42345 .70396 m .422 .70553 L .41974 .70599 L F
.299 0 0 r
.42563 .70368 m .422 .70553 L .42345 .70396 L F
.085 .356 .825 r
.72689 .4914 m .72625 .49247 L .72657 .49147 L F
.186 .494 .904 r
.72689 .4914 m .72748 .49263 L .72625 .49247 L F
.496 .395 .67 r
.7289 .49396 m .72625 .49247 L .72748 .49263 L F
.7289 .49396 m .72615 .49617 L .72625 .49247 L F
.616 .347 .487 r
.50768 .76254 m .50541 .76045 L .50678 .75929 L F
.218 .683 .944 r
.33575 .59252 m .33516 .5931 L .33369 .59274 L F
.33575 .59252 m .33716 .5932 L .33516 .5931 L F
.797 .595 .629 r
.47834 .78279 m .47832 .7857 L .47467 .78495 L F
.372 0 0 r
.47467 .78495 m .47832 .7857 L .47657 .78558 L F
.797 .595 .629 r
.47834 .78279 m .47467 .78495 L .47657 .78558 L F
.994 .858 .589 r
.47743 .7822 m .47834 .78279 L .47657 .78558 L F
.592 .427 .627 r
.48047 .78498 m .47834 .78279 L .48027 .78266 L F
.48047 .78498 m .47832 .7857 L .47834 .78279 L F
.808 .331 0 r
.4781 .79969 m .48007 .80173 L .47963 .80218 L F
.849 .448 .282 r
.48007 .80173 m .47986 .8041 L .47963 .80218 L F
.48007 .80173 m .48176 .80467 L .47986 .8041 L F
.847 .448 .287 r
.48344 .80482 m .48176 .80467 L .48007 .80173 L F
.583 .479 .701 r
.36797 .66546 m .36973 .66263 L .36774 .66291 L F
.69 .642 .797 r
.46077 .66027 m .46062 .6606 L .46292 .65988 L F
.722 .904 .959 r
.60107 .74466 m .60357 .74377 L .60244 .74303 L F
.641 .385 .515 r
.53756 .75428 m .54089 .75182 L .5385 .75207 L F
.235 0 0 r
.28109 .65162 m .28148 .65266 L .27965 .65243 L F
0 .556 .794 r
.27965 .65243 m .28148 .65266 L .28043 .65247 L F
.588 .943 .915 r
.27866 .65237 m .28109 .65162 L .27965 .65243 L F
0 .556 .794 r
.27965 .65243 m .28043 .65247 L .27818 .65205 L F
.588 .943 .915 r
.27707 .65286 m .27866 .65237 L .27965 .65243 L F
.235 0 0 r
.28109 .65162 m .28325 .65127 L .28148 .65266 L F
.777 .746 .825 r
.52369 .77086 m .526 .77308 L .526 .76797 L F
.45 .475 .794 r
.526 .76797 m .526 .77308 L .5287 .76979 L F
.525 .453 .717 r
.52712 .77332 m .5287 .76979 L .526 .77308 L F
.577 .543 .781 r
.52369 .77086 m .52712 .77332 L .526 .77308 L F
.677 .866 .971 r
.76511 .5791 m .76277 .58023 L .76179 .57908 L F
.737 .459 .508 r
.54653 .76342 m .54775 .76593 L .54319 .7654 L F
.604 .428 .616 r
.62035 .56812 m .6206 .57041 L .61826 .5707 L F
.572 .392 .599 r
.62276 .56761 m .6206 .57041 L .62035 .56812 L F
.595 .308 .451 r
.51485 .78207 m .51262 .77983 L .51244 .78254 L F
.51485 .78207 m .51519 .7801 L .51262 .77983 L F
.443 .398 .713 r
.74823 .59756 m .74628 .59913 L .74571 .59586 L F
.497 .457 .743 r
.74823 .59756 m .7468 .60135 L .74628 .59913 L F
.454 .103 .28 r
.43685 .6874 m .43909 .6871 L .43981 .68562 L F
.488 .21 .418 r
.43909 .6871 m .44182 .68482 L .43981 .68562 L F
.527 .211 .375 r
.39623 .71303 m .39405 .71552 L .39318 .71552 L F
.235 0 .136 r
.39717 .71432 m .39623 .71303 L .39838 .71261 L F
.39717 .71432 m .39405 .71552 L .39623 .71303 L F
.954 .949 .716 r
.49426 .78807 m .49323 .78576 L .4933 .78731 L F
.943 .852 .723 r
.61172 .53603 m .6139 .53472 L .61308 .5338 L F
.61172 .53603 m .61287 .53706 L .6139 .53472 L F
.462 .261 .52 r
.29 .70597 m .28995 .70779 L .2921 .70683 L F
.509 .562 .845 r
.59706 .74797 m .59501 .74597 L .59558 .7484 L F
.438 .782 .998 r
.29672 .58681 m .29619 .58791 L .29472 .58713 L F
.29672 .58681 m .29831 .58763 L .29619 .58791 L F
.997 .766 .44 r
.59379 .68754 m .59367 .6899 L .59455 .69074 L F
.971 .666 .281 r
.59367 .6899 m .59491 .69311 L .59455 .69074 L F
.909 .846 .769 r
.65629 .52035 m .65337 .5225 L .65531 .51937 L F
.65629 .52035 m .65457 .52363 L .65337 .5225 L F
.978 .827 .626 r
.65655 .51642 m .65629 .52035 L .65531 .51937 L F
.495 .657 .932 r
.28694 .63451 m .2867 .63666 L .28506 .63466 L F
.28694 .63451 m .28852 .63653 L .2867 .63666 L F
.891 .561 .418 r
.56895 .74537 m .57138 .74857 L .56959 .74596 L F
.578 .509 .741 r
.3669 .68545 m .36826 .68176 L .36602 .68222 L F
.3669 .68545 m .36911 .68514 L .36826 .68176 L F
0 0 .147 r
.59752 .70422 m .59797 .70646 L .59815 .70745 L F
.702 .506 0 r
.59797 .70646 m .59836 .70979 L .59815 .70745 L F
.117 0 0 r
.71982 .50598 m .72244 .50492 L .72261 .50383 L F
.914 .523 .122 r
.72261 .50383 m .72244 .50492 L .72151 .50286 L F
0 0 0 r
.40181 .71208 m .40055 .71229 L .39838 .71261 L F
.178 0 0 r
.40395 .71154 m .40055 .71229 L .40181 .71208 L F
.437 .225 .492 r
.38021 .72364 m .37792 .72433 L .37794 .72645 L F
.817 .46 0 r
.59741 .71337 m .59773 .71452 L .59823 .71504 L F
.997 .772 .432 r
.59773 .71452 m .59848 .71808 L .59823 .71504 L F
.118 .647 .872 r
.57689 .7181 m .57927 .71821 L .58069 .7187 L F
.561 .906 .974 r
.58069 .7187 m .58133 .71747 L .58267 .71801 L F
.58069 .7187 m .57927 .71821 L .58133 .71747 L F
.529 .815 .998 r
.58448 .72146 m .58069 .7187 L .58267 .71801 L F
.58448 .72146 m .58033 .72099 L .58069 .7187 L F
.673 .276 .286 r
.4549 .68091 m .45739 .68132 L .45866 .67955 L F
.484 .064 .166 r
.45866 .67955 m .46048 .68068 L .46087 .67913 L F
.45866 .67955 m .45739 .68132 L .46048 .68068 L F
.366 0 0 r
.53484 .72415 m .53812 .72358 L .53561 .7236 L F
0 0 0 r
.74571 .59586 m .74805 .59383 L .74755 .59449 L F
.498 .388 .659 r
.74755 .59449 m .74823 .59756 L .74571 .59586 L F
.53 .499 .766 r
.54702 .77866 m .54376 .77736 L .54786 .77802 L F
.623 .407 .568 r
.61826 .5707 m .61846 .57298 L .61514 .57341 L F
.641 .42 .568 r
.62068 .57281 m .61826 .5707 L .6206 .57041 L F
.62068 .57281 m .61846 .57298 L .61826 .5707 L F
.718 .881 .482 r
.64914 .54453 m .64742 .54767 L .64984 .54506 L F
.875 .993 .799 r
.6514 .54168 m .64984 .54506 L .65226 .5426 L F
.6514 .54168 m .64914 .54453 L .64984 .54506 L F
.757 .476 .507 r
.51524 .73159 m .51903 .72995 L .51542 .72921 L F
.51524 .73159 m .51873 .732 L .51903 .72995 L F
.672 .465 .597 r
.51873 .732 m .52107 .72938 L .51903 .72995 L F
.846 .44 .269 r
.55556 .71207 m .5586 .71477 L .55651 .71291 L F
0 0 0 r
.55091 .78702 m .55167 .78577 L .54951 .78854 L F
.7 .324 .332 r
.55294 .78866 m .55167 .78577 L .55091 .78702 L F
.463 .216 .453 r
.55294 .78866 m .55392 .78531 L .55167 .78577 L F
.742 .344 .296 r
.55155 .70993 m .55465 .71043 L .55291 .70935 L F
.638 .397 .537 r
.6013 .57657 m .60088 .5788 L .59902 .57873 L F
.66 .446 .582 r
.6013 .57657 m .60478 .57835 L .60088 .5788 L F
.6013 .57657 m .60489 .57581 L .60478 .57835 L F
.362 .705 .985 r
.77415 .57895 m .77114 .57777 L .77286 .57829 L F
0 0 .458 r
.77458 .57975 m .77415 .57895 L .77286 .57829 L F
0 .148 .658 r
.77447 .5793 m .77286 .57829 L .77151 .5779 L F
0 0 .458 r
.77529 .58035 m .77505 .58006 L .77458 .57975 L F
.77505 .58006 m .77415 .57895 L .77458 .57975 L F
0 .148 .658 r
.77447 .5793 m .77529 .58035 L .77286 .57829 L F
0 .37 .794 r
.77354 .57846 m .77447 .5793 L .77243 .57833 L F
.77195 .57802 m .77243 .57833 L .77151 .5779 L F
.77354 .57846 m .77243 .57833 L .77195 .57802 L F
0 0 .458 r
.77529 .58035 m .77608 .58147 L .77415 .57895 L F
.497 .457 .743 r
.74823 .59756 m .74902 .60108 L .7468 .60135 L F
.911 .731 .646 r
.36531 .70457 m .3634 .70391 L .36434 .70157 L F
.833 .837 .849 r
.36604 .701 m .36531 .70457 L .36434 .70157 L F
.36604 .701 m .3634 .70391 L .36531 .70457 L F
.629 .065 0 r
.36583 .70581 m .36531 .70457 L .3634 .70391 L F
.36583 .70581 m .3681 .70661 L .36531 .70457 L F
.234 .75 .847 r
.28325 .65127 m .28672 .651 L .28525 .65058 L F
.402 .828 .963 r
.28672 .651 m .28733 .65024 L .28525 .65058 L F
.28672 .651 m .28887 .65058 L .28733 .65024 L F
0 .014 .529 r
.4957 .7923 m .49403 .79131 L .49578 .79023 L F
.4957 .7923 m .49475 .79375 L .49403 .79131 L F
.666 .877 .977 r
.53989 .77127 m .53619 .77174 L .53886 .77394 L F
.575 .244 .371 r
.54266 .77303 m .53989 .77127 L .53886 .77394 L F
.54266 .77303 m .54219 .7714 L .53989 .77127 L F
.804 .671 .717 r
.5909 .55118 m .59055 .55347 L .58714 .55314 L F
.804 .667 .711 r
.59055 .55347 m .58843 .55644 L .58714 .55314 L F
.082 0 0 r
.74805 .59383 m .75023 .59335 L .74755 .59449 L F
.74805 .59383 m .75064 .59307 L .75023 .59335 L F
.27 .003 .311 r
.72525 .49722 m .72615 .49617 L .72649 .49821 L F
.628 .499 .685 r
.73073 .49706 m .72615 .49617 L .7289 .49396 L F
.73073 .49706 m .72649 .49821 L .72615 .49617 L F
.745 .297 .188 r
.5202 .80663 m .52095 .80501 L .52002 .80401 L F
.5202 .80663 m .52318 .80728 L .52095 .80501 L F
.672 .373 .459 r
.54095 .76311 m .54319 .7654 L .54073 .76515 L F
.197 0 .038 r
.28269 .60943 m .27968 .61156 L .28089 .61032 L F
.722 .904 .959 r
.60107 .74466 m .60244 .74303 L .60024 .746 L F
.824 .677 .7 r
.5909 .55118 m .58762 .55076 L .58947 .54802 L F
.804 .671 .717 r
.5909 .55118 m .58714 .55314 L .58762 .55076 L F
.332 .067 .354 r
.46967 .75698 m .46972 .75827 L .47116 .75708 L F
.68 .45 .567 r
.4663 .67616 m .46886 .6763 L .46893 .67395 L F
.628 .493 .679 r
.46893 .67395 m .4714 .67378 L .47108 .67094 L F
.622 .41 .573 r
.46886 .6763 m .4714 .67378 L .46893 .67395 L F
.798 .54 .548 r
.58828 .57889 m .59108 .57871 L .58967 .58091 L F
.659 .363 .459 r
.59108 .57871 m .59341 .58088 L .58967 .58091 L F
.704 .344 .363 r
.59324 .57933 m .59341 .58088 L .59108 .57871 L F
.552 .62 .874 r
.74619 .6116 m .74718 .6084 L .74477 .60889 L F
.74619 .6116 m .74887 .61127 L .74718 .6084 L F
.526 .265 .462 r
.61266 .57341 m .61261 .57536 L .61016 .57549 L F
.558 .291 .467 r
.61266 .57341 m .615 .57515 L .61261 .57536 L F
.606 .262 .36 r
.61514 .57341 m .615 .57515 L .61266 .57341 L F
.643 .515 .693 r
.4909 .6677 m .4916 .67135 L .48934 .67178 L F
.638 .495 .672 r
.4916 .67135 m .48961 .67372 L .48934 .67178 L F
.215 .014 .378 r
.53543 .76596 m .53509 .76816 L .53376 .76855 L F
.328 .047 .325 r
.35153 .61535 m .35406 .61273 L .35345 .61465 L F
.261 0 .314 r
.35345 .61465 m .35406 .61273 L .35576 .6119 L F
.391 .614 .94 r
.72175 .48858 m .72298 .48842 L .72221 .49 L F
.336 .547 .909 r
.72298 .48842 m .72657 .49147 L .72221 .49 L F
.603 .375 .542 r
.62099 .50083 m .61731 .50149 L .61626 .49998 L F
.902 .903 .816 r
.61731 .50149 m .61647 .50023 L .61626 .49998 L F
.61731 .50149 m .6154 .50403 L .61647 .50023 L F
.603 .375 .542 r
.62099 .50083 m .62041 .5032 L .61731 .50149 L F
.312 .615 .955 r
.63102 .53812 m .63283 .53849 L .63222 .53961 L F
0 0 .062 r
.63253 .54051 m .63222 .53961 L .63283 .53849 L F
.63253 .54051 m .63188 .54215 L .63222 .53961 L F
.704 .983 .821 r
.62505 .48387 m .62177 .48586 L .62477 .48391 L F
.409 .829 .653 r
.62505 .48387 m .62654 .48288 L .62796 .4821 L F
.422 .847 .699 r
.62505 .48387 m .62477 .48391 L .62654 .48288 L F
.292 .679 .974 r
.46077 .66027 m .45968 .65855 L .45481 .65841 L F
.87 .975 .849 r
.46031 .65795 m .46077 .66027 L .46203 .65871 L F
.46031 .65795 m .45968 .65855 L .46077 .66027 L F
.69 .642 .797 r
.46077 .66027 m .46292 .65988 L .46203 .65871 L F
.571 .426 .645 r
.33657 .72891 m .33844 .73014 L .33586 .72973 L F
.33586 .72973 m .33844 .73014 L .33657 .72891 L F
.483 .613 .904 r
.76328 .58662 m .76529 .58509 L .76239 .5854 L F
.76328 .58662 m .76618 .5867 L .76529 .58509 L F
.521 .196 .357 r
.50761 .73477 m .50993 .73468 L .51089 .73212 L F
.46 .255 .514 r
.51089 .73212 m .51347 .73215 L .51303 .72963 L F
.603 .278 .392 r
.51089 .73212 m .51352 .73394 L .51347 .73215 L F
.51089 .73212 m .50993 .73468 L .51352 .73394 L F
.873 .441 .169 r
.57023 .72648 m .56737 .72338 L .56958 .72529 L F
.746 .52 .588 r
.65825 .49532 m .66074 .49311 L .65994 .49199 L F
.65808 .49566 m .65827 .49547 L .65825 .49532 L F
.65827 .49547 m .66074 .49311 L .65825 .49532 L F
.24 .41 .831 r
.65736 .49812 m .65844 .49652 L .65573 .49513 L F
.65844 .49652 m .65895 .49576 L .6583 .49563 L F
.65844 .49652 m .6583 .49563 L .65573 .49513 L F
0 0 .462 r
.65736 .49812 m .65815 .49896 L .65895 .49576 L F
.65736 .49812 m .65839 .49975 L .65815 .49896 L F
.871 .508 .016 r
.65815 .49896 m .65799 .49988 L .65791 .49823 L F
.65815 .49896 m .65791 .49823 L .65789 .49776 L F
0 0 .462 r
.65839 .49975 m .65869 .50021 L .65815 .49896 L F
.815 .629 .651 r
.57642 .7265 m .5802 .72811 L .5781 .72368 L F
.915 .744 .655 r
.58033 .72761 m .58009 .72853 L .58054 .72809 L F
.815 .629 .651 r
.5802 .72811 m .58046 .72822 L .58027 .72786 L F
.5802 .72811 m .58027 .72786 L .5781 .72368 L F
.786 .527 .544 r
.57601 .72905 m .58015 .72828 L .57642 .7265 L F
.58015 .72828 m .58046 .72822 L .5802 .72811 L F
.58015 .72828 m .5802 .72811 L .57642 .7265 L F
.915 .744 .655 r
.58005 .7284 m .57933 .72927 L .58008 .72854 L F
.58008 .72852 m .58008 .72854 L .58009 .72853 L F
.786 .527 .544 r
.58015 .72828 m .57933 .72927 L .58046 .72822 L F
.57601 .72905 m .57933 .72927 L .58015 .72828 L F
.231 .349 .778 r
.5781 .72368 m .58027 .72786 L .57947 .72557 L F
.915 .744 .655 r
.57947 .72557 m .58027 .72786 L .58033 .72761 L F
.231 .349 .778 r
.58027 .72786 m .58046 .72822 L .57947 .72557 L F
.915 .744 .655 r
.57947 .72557 m .58009 .72853 L .58027 .72786 L F
.57947 .72557 m .57933 .72927 L .58005 .7284 L F
.57947 .72557 m .58008 .72854 L .58008 .72852 L F
.885 .453 .114 r
.58163 .73129 m .58054 .72809 L .57933 .72927 L F
.58163 .73129 m .58314 .73234 L .58054 .72809 L F
.954 .898 .731 r
.61649 .49538 m .61562 .49467 L .61684 .49134 L F
.997 .794 .51 r
.61649 .49538 m .61624 .49769 L .61562 .49467 L F
.877 .831 .797 r
.64797 .53168 m .6449 .53457 L .6446 .53426 L F
.64797 .53168 m .6446 .53426 L .64759 .53384 L F
.64797 .53168 m .64759 .53384 L .64414 .53109 L F
.693 .971 .925 r
.64797 .53168 m .64966 .53067 L .64892 .53043 L F
0 0 .364 r
.64884 .53273 m .64797 .53168 L .64892 .53043 L F
.64884 .53273 m .64767 .53423 L .64797 .53168 L F
.842 .433 0 r
.66184 .50651 m .66179 .50757 L .66113 .50536 L F
.66184 .50651 m .66282 .50879 L .66179 .50757 L F
.166 .102 .534 r
.64666 .50566 m .64761 .50316 L .64605 .50325 L F
.64562 .50345 m .64605 .50325 L .64554 .50327 L F
.64666 .50566 m .64605 .50325 L .64562 .50345 L F
.64761 .50316 m .6467 .50282 L .64554 .50327 L F
.775 .54 .579 r
.64792 .50235 m .64501 .50422 L .64683 .50287 L F
.64792 .50235 m .64683 .50287 L .64702 .50273 L F
.449 0 0 r
.64671 .50283 m .64501 .50422 L .6427 .50408 L F
.64702 .50273 m .64683 .50287 L .64671 .50283 L F
.64683 .50287 m .64501 .50422 L .64671 .50283 L F
.166 .102 .534 r
.64761 .50316 m .64792 .50235 L .6467 .50282 L F
.726 .633 .755 r
.77891 .60415 m .78226 .60415 L .78114 .6009 L F
.447 .228 .487 r
.77891 .60415 m .78145 .60515 L .78226 .60415 L F
.601 .439 .634 r
.78226 .60415 m .78416 .60144 L .78114 .6009 L F
.78226 .60415 m .78544 .60369 L .78416 .60144 L F
.331 0 0 r
.78145 .60515 m .78544 .60369 L .78226 .60415 L F
.89 .499 .28 r
.66868 .53132 m .67015 .53182 L .6694 .53281 L F
.611 .128 .084 r
.67015 .53182 m .67281 .53329 L .6694 .53281 L F
.689 .403 .484 r
.51685 .77484 m .51828 .77732 L .51354 .77702 L F
.733 .415 .443 r
.51685 .77484 m .51881 .77694 L .51828 .77732 L F
.543 .393 .628 r
.64414 .53109 m .6446 .53426 L .64219 .53352 L F
.467 .488 .796 r
.64515 .53733 m .64219 .53352 L .6446 .53426 L F
.059 .624 .712 r
.42857 .66203 m .42734 .66212 L .42514 .66228 L F
.063 0 0 r
.43084 .66145 m .42734 .66212 L .42857 .66203 L F
.559 .551 .802 r
.3273 .61013 m .33016 .61178 L .32953 .60949 L F
.341 0 .029 r
.42296 .6627 m .42157 .66439 L .41934 .66473 L F
.463 .057 .183 r
.42514 .66228 m .42157 .66439 L .42296 .6627 L F
.327 .748 .975 r
.51942 .77945 m .51835 .7799 L .51705 .77924 L F
.171 .25 .704 r
.51942 .77945 m .52029 .78208 L .51835 .7799 L F
.609 .285 .395 r
.55282 .77688 m .5491 .77939 L .54913 .7768 L F
.55282 .77688 m .55202 .77962 L .5491 .77939 L F
.591 .267 .388 r
.55282 .77688 m .55462 .77858 L .55202 .77962 L F
.593 .587 .815 r
.59209 .74581 m .59501 .74597 L .59344 .74257 L F
.578 .513 .746 r
.37397 .70526 m .37529 .70128 L .37323 .70168 L F
.37397 .70526 m .37641 .7049 L .37529 .70128 L F
.596 .544 .767 r
.37397 .70526 m .37686 .70717 L .37641 .7049 L F
.617 .818 .977 r
.25521 .64766 m .25699 .64868 L .25956 .64805 L F
.752 .378 .344 r
.48648 .79389 m .48822 .79645 L .48512 .79585 L F
.378 .787 .981 r
.30781 .60161 m .30626 .60102 L .30428 .60129 L F
.263 .738 .938 r
.30995 .60138 m .30626 .60102 L .30781 .60161 L F
.128 0 0 r
.63759 .55399 m .63691 .55558 L .63476 .55653 L F
0 0 0 r
.63846 .55431 m .63759 .55399 L .63972 .55316 L F
.63846 .55431 m .63691 .55558 L .63759 .55399 L F
.875 .474 .267 r
.48344 .80482 m .483 .80672 L .48176 .80467 L F
.48344 .80482 m .48581 .80827 L .483 .80672 L F
.814 .417 .3 r
.48344 .80482 m .4872 .8079 L .48581 .80827 L F
.614 .604 .817 r
.47882 .65424 m .47649 .65472 L .47552 .65186 L F
.112 0 0 r
.41358 .64927 m .41542 .64944 L .41711 .64935 L F
.091 0 0 r
.41542 .64944 m .41927 .64907 L .41711 .64935 L F
.361 .074 .336 r
.72684 .51346 m .72466 .51442 L .72715 .51193 L F
.535 .462 .72 r
.72955 .51116 m .72715 .51193 L .72669 .5091 L F
.414 .136 .38 r
.72955 .51116 m .72684 .51346 L .72715 .51193 L F
.842 .651 .644 r
.5695 .72039 m .57237 .72134 L .57126 .71813 L F
.775 .311 .142 r
.5695 .72039 m .5712 .72236 L .57237 .72134 L F
.676 .328 .376 r
.5712 .72236 m .57455 .72079 L .57237 .72134 L F
.6 .288 .412 r
.50532 .75149 m .50886 .74903 L .50599 .74939 L F
.50532 .75149 m .50786 .75158 L .50886 .74903 L F
.677 .368 .444 r
.50886 .74903 m .50786 .75158 L .51092 .75138 L F
.431 .252 .537 r
.30568 .6704 m .30735 .67049 L .30749 .6681 L F
.415 .122 .356 r
.30568 .6704 m .30482 .67245 L .30735 .67049 L F
.431 .252 .537 r
.30568 .6704 m .30735 .67049 L .30749 .6681 L F
.078 0 .164 r
.57007 .68256 m .569 .68437 L .57144 .68155 L F
.641 .097 0 r
.67516 .54004 m .6745 .53992 L .67158 .53715 L F
.345 .584 .932 r
.67516 .54004 m .67639 .53866 L .6745 .53992 L F
.67516 .54004 m .67719 .54029 L .67639 .53866 L F
.313 0 0 r
.58157 .72535 m .58422 .72571 L .58493 .72516 L F
.7 .651 .797 r
.58298 .72131 m .58493 .72516 L .58571 .72208 L F
.575 .591 .832 r
.58374 .72523 m .58493 .72516 L .58447 .72425 L F
0 0 .23 r
.58422 .72571 m .58571 .72208 L .58493 .72516 L F
.58422 .72571 m .58484 .72532 L .58566 .72267 L F
.58484 .72532 m .58555 .72389 L .58566 .72267 L F
.58524 .72322 m .58566 .72267 L .58571 .72208 L F
.58422 .72571 m .58566 .72267 L .58524 .72322 L F
.575 .591 .832 r
.58374 .72523 m .58447 .72425 L .58298 .72131 L F
.967 .728 .524 r
.5849 .71755 m .58448 .72146 L .58283 .71831 L F
.58313 .71792 m .58283 .71831 L .58267 .71801 L F
.5849 .71755 m .58283 .71831 L .58313 .71792 L F
.459 .258 .519 r
.58487 .71518 m .5849 .71755 L .58267 .71801 L F
.486 .819 .999 r
.58487 .71518 m .58597 .71403 L .58714 .71477 L F
.738 .478 .536 r
.5849 .71755 m .58299 .71851 L .58354 .71752 L F
.5849 .71755 m .58354 .71752 L .58487 .71518 L F
.705 .553 .679 r
.58714 .71477 m .5849 .71755 L .58487 .71518 L F
0 0 0 r
.58389 .7169 m .58354 .71752 L .58522 .71516 L F
.743 .488 .544 r
.58354 .71752 m .5849 .71755 L .58313 .71792 L F
.58133 .71747 m .5849 .71755 L .58136 .71748 L F
.58355 .71752 m .58299 .71851 L .5849 .71755 L F
0 0 0 r
.58354 .71752 m .58299 .71851 L .58355 .71752 L F
.743 .488 .544 r
.58136 .71748 m .58354 .71752 L .58267 .71801 L F
.58354 .71752 m .58313 .71792 L .58267 .71801 L F
.58133 .71747 m .58299 .71851 L .58355 .71752 L F
0 0 0 r
.58355 .71752 m .58299 .71851 L .58381 .71727 L F
.58354 .71752 m .58381 .71727 L .58522 .71516 L F
.58487 .71518 m .58389 .7169 L .58597 .71403 L F
.58389 .7169 m .58522 .71516 L .58597 .71403 L F
.7 .651 .797 r
.58298 .72131 m .58571 .72208 L .58494 .72017 L F
0 0 .407 r
.58571 .72208 m .58614 .72271 L .58494 .72017 L F
0 0 .239 r
.58571 .72208 m .58546 .72494 L .58614 .72271 L F
.561 .424 .652 r
.58494 .72017 m .58614 .72271 L .58736 .71973 L F
.983 .825 .609 r
.58613 .7227 m .58364 .72337 L .58551 .72114 L F
.58614 .72271 m .58612 .72272 L .58613 .7227 L F
.58612 .72272 m .58364 .72337 L .58613 .7227 L F
0 0 .23 r
.58484 .72532 m .58546 .72494 L .58555 .72389 L F
.575 .591 .832 r
.58157 .72535 m .58374 .72523 L .58298 .72131 L F
0 0 0 r
.62891 .51718 m .63148 .51391 L .62901 .51483 L F
.736 .226 0 r
.56387 .73961 m .5641 .7392 L .5616 .73718 L F
.56387 .73961 m .56506 .74035 L .5641 .7392 L F
.783 .608 .663 r
.54808 .79013 m .55091 .78702 L .54951 .78854 L F
.57 .577 .822 r
.48576 .66193 m .48398 .66241 L .48344 .66127 L F
.763 .898 .937 r
.67371 .48016 m .67288 .48158 L .67133 .47896 L F
.429 .09 .287 r
.63467 .50337 m .63207 .50523 L .63239 .50374 L F
.373 0 .012 r
.65457 .52363 m .65093 .5252 L .65337 .5225 L F
.756 .809 .895 r
.76481 .61749 m .76627 .61892 L .76764 .61789 L F
.499 0 0 r
.54035 .72403 m .54268 .72518 L .54341 .72476 L F
0 .169 .599 r
.54481 .72566 m .54596 .72645 L .54341 .72476 L F
.54481 .72566 m .54341 .72476 L .54268 .72518 L F
.717 .184 0 r
.55069 .71732 m .54735 .715 L .55037 .71596 L F
.818 .696 .73 r
.49757 .68505 m .49382 .68453 L .49637 .68186 L F
.774 .566 .617 r
.49757 .68505 m .49408 .68731 L .49382 .68453 L F
.49757 .68505 m .49762 .68788 L .49408 .68731 L F
.696 .637 .786 r
.49978 .68465 m .49757 .68505 L .49637 .68186 L F
.49933 .68446 m .49637 .68186 L .49673 .68334 L F
.49978 .68465 m .49684 .68225 L .49933 .68446 L F
.49684 .68225 m .49637 .68186 L .49933 .68446 L F
.718 .52 .621 r
.50145 .68717 m .49757 .68505 L .49947 .68458 L F
.113 .356 .821 r
.50074 .68338 m .49978 .68465 L .49673 .68334 L F
.413 .85 .935 r
.50132 .68413 m .50003 .68445 L .49978 .68465 L F
.50003 .68445 m .49757 .68505 L .49978 .68465 L F
.113 .356 .821 r
.50074 .68338 m .50084 .6838 L .49978 .68465 L F
.197 0 .104 r
.49978 .68465 m .50022 .6847 L .50132 .68413 L F
.718 .52 .621 r
.50141 .68626 m .50022 .6847 L .50132 .68413 L F
.197 0 .104 r
.50022 .6847 m .50106 .68479 L .50132 .68413 L F
.718 .52 .621 r
.50022 .6847 m .50003 .68445 L .50132 .68413 L F
.113 .356 .821 r
.50003 .68445 m .50022 .6847 L .49978 .68465 L F
.718 .52 .621 r
.50142 .68631 m .49947 .68458 L .50003 .68445 L F
.50142 .68631 m .50003 .68445 L .50141 .68626 L F
.113 .356 .821 r
.50084 .6838 m .50106 .68479 L .50022 .6847 L F
.50084 .6838 m .50022 .6847 L .50003 .68445 L F
.718 .52 .621 r
.50145 .68717 m .49947 .68458 L .50142 .68631 L F
.50145 .68717 m .49762 .68788 L .49757 .68505 L F
.434 0 0 r
.78117 .58586 m .78046 .58513 L .77954 .58434 L F
.78117 .58586 m .78424 .58682 L .78046 .58513 L F
.945 .712 .244 r
.78199 .5971 m .78239 .59565 L .78222 .59477 L F
.78199 .5971 m .78266 .59862 L .78239 .59565 L F
0 0 0 r
.47965 .78901 m .47622 .79009 L .47889 .79086 L F
.629 .256 .317 r
.47889 .79086 m .48173 .79046 L .47965 .78901 L F
.479 .342 .616 r
.47965 .78901 m .48173 .79046 L .48165 .78796 L F
.978 .827 .626 r
.65655 .51642 m .65531 .51937 L .65642 .51672 L F
.823 .407 .254 r
.56623 .71734 m .56802 .71994 L .56886 .7185 L F
.883 .494 .292 r
.56886 .7185 m .56802 .71994 L .5695 .72039 L F
.842 .651 .644 r
.5695 .72039 m .57126 .71813 L .56886 .7185 L F
0 0 .048 r
.63647 .48332 m .6375 .48182 L .639 .48248 L F
.63647 .48332 m .63658 .48407 L .6375 .48182 L F
.551 .642 .894 r
.69492 .48647 m .69267 .48686 L .6919 .48508 L F
.202 .311 .753 r
.75399 .58776 m .7526 .58748 L .75383 .58592 L F
.667 .722 .89 r
.75964 .62072 m .76082 .61687 L .75802 .61741 L F
.75964 .62072 m .76193 .61988 L .76082 .61687 L F
.737 .67 .784 r
.65226 .5426 m .656 .54329 L .65434 .54188 L F
.741 .745 .856 r
.65434 .54188 m .656 .54329 L .65765 .5425 L F
.422 .041 .209 r
.40926 .70966 m .40663 .7105 L .40743 .70971 L F
.584 .558 .791 r
.27119 .6257 m .27037 .62955 L .26913 .62617 L F
.27119 .6257 m .27228 .62901 L .27037 .62955 L F
.559 .453 .691 r
.27228 .62901 m .27062 .63152 L .27037 .62955 L F
.145 .683 .838 r
.29447 .65031 m .29848 .65041 L .2967 .64993 L F
.008 .566 .813 r
.2967 .64993 m .29848 .65041 L .30016 .65061 L F
.601 .255 .356 r
.44725 .68235 m .44932 .68402 L .4502 .68162 L F
.508 .205 .388 r
.44932 .68402 m .45226 .681 L .4502 .68162 L F
.249 .731 .93 r
.28887 .65058 m .29241 .65093 L .29097 .65036 L F
.528 .858 .996 r
.29097 .65036 m .29241 .65093 L .29447 .65031 L F
.784 .648 .711 r
.58843 .55644 m .58983 .56002 L .58666 .55931 L F
.786 .641 .701 r
.58666 .55931 m .58983 .56002 L .58949 .562 L F
0 0 0 r
.52781 .8105 m .53039 .80843 L .52915 .80997 L F
.118 0 0 r
.52915 .80997 m .53039 .80843 L .53253 .80769 L F
.535 .462 .72 r
.72955 .51116 m .72669 .5091 L .72804 .50825 L F
.6 .395 .576 r
.60489 .57581 m .60697 .57819 L .60478 .57835 L F
.694 .398 .469 r
.60713 .57637 m .60697 .57819 L .60489 .57581 L F
.443 .221 .481 r
.34193 .62604 m .34128 .62783 L .33962 .62864 L F
.365 .086 .35 r
.33962 .62864 m .341 .63063 L .33912 .63138 L F
.33962 .62864 m .34128 .62783 L .341 .63063 L F
.517 .437 .704 r
.63497 .49852 m .63619 .50009 L .63675 .49788 L F
.379 .118 .388 r
.351 .6172 m .35153 .61535 L .35345 .61465 L F
.771 .492 .511 r
.63188 .54215 m .6368 .54526 L .63614 .54265 L F
.933 .587 .154 r
.63614 .54265 m .6368 .54526 L .63688 .54465 L F
.903 .887 .806 r
.65638 .50544 m .65752 .50682 L .6597 .50307 L F
.796 .461 0 r
.65638 .50544 m .65749 .50827 L .65752 .50682 L F
.534 .411 .659 r
.4642 .66548 m .46634 .66501 L .46604 .66254 L F
.698 .634 .782 r
.46465 .66784 m .46634 .66501 L .4642 .66548 L F
.611 .566 .779 r
.73175 .50574 m .73187 .50868 L .72804 .50825 L F
.62 .422 .592 r
.73187 .50868 m .72955 .51116 L .72804 .50825 L F
.666 .38 .477 r
.48637 .68699 m .48302 .68528 L .48637 .68484 L F
.48637 .68699 m .48264 .68725 L .48302 .68528 L F
0 .412 .793 r
.31361 .6012 m .31423 .60086 L .3119 .60104 L F
.31361 .6012 m .31521 .60181 L .31423 .60086 L F
.31 0 .156 r
.64103 .51534 m .64028 .51659 L .63807 .51729 L F
.064 0 .361 r
.6425 .51175 m .64194 .51487 L .64103 .51534 L F
0 0 0 r
.64194 .51487 m .64028 .51659 L .64103 .51534 L F
.887 .609 .511 r
.66787 .52039 m .66652 .52156 L .66636 .51924 L F
.66787 .52039 m .66807 .52267 L .66652 .52156 L F
.25 .677 .963 r
.30247 .58744 m .30183 .58823 L .30025 .58721 L F
.30247 .58744 m .30424 .58839 L .30183 .58823 L F
.364 .162 .468 r
.27788 .61225 m .27756 .61459 L .27581 .61519 L F
.492 .277 .514 r
.27756 .61459 m .27534 .6171 L .27581 .61519 L F
.447 .572 .887 r
.74887 .61127 m .74917 .61275 L .75068 .61105 L F
.537 .713 .954 r
.74917 .61275 m .75153 .61246 L .75068 .61105 L F
.359 0 0 r
.69226 .52555 m .69469 .5257 L .6948 .52526 L F
.239 .081 .455 r
.6948 .52526 m .69689 .52473 L .6971 .52232 L F
0 0 0 r
.6948 .52526 m .69469 .5257 L .69689 .52473 L F
.74 .602 .704 r
.62891 .51718 m .63134 .52031 L .62687 .52048 L F
.64 .249 .287 r
.62687 .52048 m .63134 .52031 L .62905 .52218 L F
.812 .503 .467 r
.63134 .52031 m .6322 .52283 L .62905 .52218 L F
.931 .937 .781 r
.6154 .50403 m .61372 .50467 L .61647 .50023 L F
.641 .681 .872 r
.47552 .65186 m .47334 .65275 L .47188 .65086 L F
.756 .319 .214 r
.48695 .80931 m .49018 .81022 L .48929 .81103 L F
.702 .252 0 r
.49018 .81022 m .49083 .81156 L .48929 .81103 L F
.49083 .81156 m .49054 .81179 L .48929 .81103 L F
0 .171 .633 r
.48695 .80931 m .48929 .81103 L .49049 .81184 L F
.48695 .80931 m .49049 .81184 L .4855 .80947 L F
.53 .049 .06 r
.49049 .81184 m .48929 .81103 L .49111 .81214 L F
.656 .125 0 r
.4855 .80947 m .49049 .81184 L .48743 .81158 L F
.959 .682 .467 r
.48751 .81055 m .49048 .81184 L .48937 .80894 L F
.49048 .81184 m .49049 .81184 L .49049 .81184 L F
.49048 .81184 m .49049 .81184 L .48937 .80894 L F
.702 .252 0 r
.49083 .81156 m .49111 .81214 L .49054 .81179 L F
.53 .049 .06 r
.48989 .8103 m .49142 .80957 L .48937 .80894 L F
.49049 .81184 m .49066 .81141 L .48989 .8103 L F
.702 .252 0 r
.49018 .81022 m .49208 .81317 L .49135 .8124 L F
.53 .049 .06 r
.49066 .81141 m .49142 .80957 L .48989 .8103 L F
.702 .252 0 r
.49096 .81184 m .49135 .8124 L .49111 .81214 L F
.49018 .81022 m .49135 .8124 L .49096 .81184 L F
.884 .494 .289 r
.67158 .53715 m .67065 .53852 L .6701 .53677 L F
.86 .871 .846 r
.67158 .53715 m .6701 .53677 L .67281 .53329 L F
.744 .298 .192 r
.67158 .53715 m .6745 .53992 L .67065 .53852 L F
.542 .232 .392 r
.45484 .69034 m .45177 .69264 L .45201 .69093 L F
.307 .007 .283 r
.33453 .63435 m .33196 .63686 L .33268 .63508 L F
.766 .741 .83 r
.48838 .75132 m .49163 .75222 L .49038 .7497 L F
.733 .479 .545 r
.48838 .75132 m .49178 .75383 L .49163 .75222 L F
.779 .746 .823 r
.49038 .7497 m .49163 .75222 L .49429 .74946 L F
.537 .169 .291 r
.49178 .75383 m .49369 .75366 L .49163 .75222 L F
.067 0 .052 r
.63688 .54465 m .6368 .54526 L .63785 .54465 L F
.074 0 .214 r
.63688 .54465 m .63868 .54285 L .63924 .54329 L F
.63688 .54465 m .63785 .54465 L .6398 .54174 L F
.981 .882 .658 r
.63785 .54465 m .63686 .54397 L .63765 .54206 L F
.63804 .54236 m .63765 .54206 L .63817 .54081 L F
.63785 .54465 m .63765 .54206 L .63804 .54236 L F
.074 0 .214 r
.63924 .54329 m .6398 .54174 L .64063 .54249 L F
.63868 .54285 m .6398 .54174 L .63924 .54329 L F
.711 .592 .721 r
.48573 .65528 m .48227 .65671 L .48265 .65472 L F
.548 .394 .625 r
.48573 .65528 m .48344 .66127 L .48227 .65671 L F
.662 .588 .762 r
.37215 .71012 m .37563 .71281 L .37449 .71003 L F
.745 .646 .751 r
.37449 .71003 m .37563 .71281 L .37796 .71008 L F
.594 .424 .621 r
.37563 .71281 m .37827 .71253 L .37796 .71008 L F
.607 .567 .783 r
.37563 .71281 m .37906 .71563 L .37827 .71253 L F
.568 .527 .77 r
.73333 .60645 m .73518 .60432 L .73245 .60342 L F
.73333 .60645 m .73566 .6061 L .73518 .60432 L F
.62 .501 .696 r
.51932 .77153 m .52135 .76894 L .51819 .76822 L F
.51932 .77153 m .51819 .76822 L .519 .7701 L F
.51932 .77153 m .52186 .77173 L .52135 .76894 L F
.812 .468 .405 r
.519 .7701 m .52186 .77173 L .51932 .77153 L F
.555 .549 .803 r
.37323 .70168 m .37415 .69811 L .37238 .6987 L F
.37323 .70168 m .37529 .70128 L .37415 .69811 L F
.483 .844 .992 r
.7748 .60634 m .77107 .60659 L .77339 .60597 L F
.615 .886 .99 r
.77339 .60597 m .77674 .60563 L .7748 .60634 L F
.733 .433 .473 r
.48879 .6854 m .48832 .68727 L .48637 .68484 L F
.627 .328 .443 r
.49212 .68674 m .48879 .6854 L .49184 .68483 L F
.49212 .68674 m .48832 .68727 L .48879 .6854 L F
.586 .541 .772 r
.49253 .66538 m .4909 .6677 L .49029 .66602 L F
.49253 .66538 m .4932 .66726 L .4909 .6677 L F
.629 .506 .694 r
.49389 .67069 m .4909 .6677 L .4932 .66726 L F
.49389 .67069 m .4916 .67135 L .4909 .6677 L F
.548 .394 .625 r
.48573 .65528 m .48597 .66084 L .48344 .66127 L F
.41 .439 .78 r
.48673 .65356 m .48675 .65578 L .48573 .65528 L F
.552 .397 .625 r
.48811 .65958 m .48573 .65528 L .48675 .65578 L F
.48811 .65958 m .48597 .66084 L .48573 .65528 L F
0 0 0 r
.5242 .81194 m .52689 .81087 L .52633 .81135 L F
.612 .955 .896 r
.52633 .81135 m .52734 .81022 L .52588 .81174 L F
0 0 0 r
.5232 .81251 m .52633 .81135 L .52544 .8122 L F
.612 .955 .896 r
.52633 .81135 m .52588 .81174 L .52544 .8122 L F
0 0 0 r
.52689 .81087 m .52781 .8105 L .52633 .81135 L F
.52633 .81135 m .52781 .8105 L .52915 .80997 L F
.537 .436 .687 r
.34009 .72892 m .33844 .73014 L .33657 .72891 L F
.34009 .72892 m .33844 .73014 L .33657 .72891 L F
.249 .246 .659 r
.46147 .78524 m .46228 .78181 L .46065 .78192 L F
.46147 .78524 m .4626 .7857 L .46228 .78181 L F
.215 .269 .703 r
.46147 .78524 m .46347 .78747 L .4626 .7857 L F
.675 .322 .368 r
.59659 .58021 m .59341 .58088 L .59324 .57933 L F
.559 .627 .876 r
.70317 .48651 m .70195 .48944 L .70042 .48679 L F
.70317 .48651 m .7042 .48899 L .70195 .48944 L F
.133 0 .211 r
.64418 .50856 m .64666 .50566 L .64453 .50635 L F
.938 .633 .436 r
.61251 .54902 m .61302 .55221 L .61354 .55105 L F
.918 .546 .298 r
.61302 .55221 m .61313 .55269 L .61354 .55105 L F
.494 .103 .228 r
.61313 .55269 m .61594 .55102 L .61354 .55105 L F
.952 .765 .613 r
.60016 .72675 m .59919 .7239 L .59861 .72622 L F
.857 .592 .538 r
.59864 .72864 m .60016 .72675 L .59861 .72622 L F
.59864 .72864 m .60038 .72962 L .60016 .72675 L F
0 .301 .796 r
.7788 .58286 m .77687 .58228 L .77608 .58147 L F
.7788 .58286 m .77954 .58434 L .77687 .58228 L F
.608 .627 .844 r
.72745 .50047 m .72525 .49722 L .72649 .49821 L F
.354 0 .032 r
.43139 .70152 m .43002 .70318 L .42782 .70345 L F
.295 0 .029 r
.43314 .70102 m .43002 .70318 L .43139 .70152 L F
.942 .739 .6 r
.78314 .58881 m .78513 .58757 L .78424 .58682 L F
.78314 .58881 m .78455 .58971 L .78513 .58757 L F
.336 .356 .734 r
.77416 .59536 m .77486 .59924 L .77658 .59721 L F
.969 .663 .274 r
.77788 .60058 m .77658 .59721 L .77486 .59924 L F
.169 0 .146 r
.31381 .62913 m .31129 .63152 L .31322 .63075 L F
.501 .125 .26 r
.31517 .6302 m .31381 .62913 L .31322 .63075 L F
.31517 .6302 m .31614 .62895 L .31381 .62913 L F
.289 0 .069 r
.55098 .75331 m .54872 .75427 L .54992 .75198 L F
.301 .062 .375 r
.46456 .76314 m .46669 .76242 L .46718 .7595 L F
.554 .435 .671 r
.46718 .7595 m .46941 .75936 L .46972 .75827 L F
.452 .19 .424 r
.46718 .7595 m .46881 .76191 L .46941 .75936 L F
.46718 .7595 m .46669 .76242 L .46881 .76191 L F
.677 .451 .57 r
.58189 .57896 m .57966 .58139 L .57832 .57831 L F
.58189 .57896 m .58189 .58126 L .57966 .58139 L F
.474 .275 .53 r
.58411 .5761 m .5841 .57843 L .58189 .57896 L F
.763 .687 .778 r
.5841 .57843 m .58189 .58126 L .58189 .57896 L F
.246 0 0 r
.53632 .75971 m .53145 .7611 L .53434 .75997 L F
.53632 .75971 m .53145 .7611 L .53434 .75997 L F
.299 .059 .373 r
.57209 .67956 m .57484 .67886 L .57375 .6787 L F
.57209 .67956 m .57144 .68155 L .57484 .67886 L F
.653 .205 .174 r
.53323 .77912 m .53416 .78112 L .53195 .78189 L F
.53323 .77912 m .53542 .77975 L .53416 .78112 L F
.591 .02 0 r
.36923 .70838 m .37066 .70957 L .37215 .71012 L F
.599 .889 .99 r
.37215 .71012 m .37066 .70957 L .37293 .70883 L F
.903 .71 .631 r
.37293 .70883 m .37066 .70957 L .37215 .71012 L F
.37293 .70883 m .37201 .71069 L .37066 .70957 L F
.37201 .71069 m .3718 .71111 L .37066 .70957 L F
.591 .02 0 r
.36827 .70781 m .37066 .70957 L .36923 .70838 L F
.653 .42 .554 r
.48359 .78252 m .48047 .78498 L .48027 .78266 L F
.092 0 0 r
.48961 .67372 m .48669 .67589 L .48623 .67379 L F
.618 .355 .497 r
.52441 .73209 m .52768 .72916 L .52441 .72954 L F
.52441 .73209 m .52678 .73257 L .52768 .72916 L F
.56 .299 .477 r
.52768 .72916 m .52965 .73153 L .52989 .7292 L F
.52768 .72916 m .52678 .73257 L .52965 .73153 L F
.572 .731 .95 r
.68451 .49035 m .68584 .4884 L .68372 .4887 L F
.68451 .49035 m .68692 .48996 L .68584 .4884 L F
.596 .759 .956 r
.46203 .65871 m .46292 .65988 L .46522 .65936 L F
.399 0 .018 r
.3928 .65326 m .39641 .65171 L .39422 .65162 L F
0 .226 .739 r
.67361 .51405 m .67374 .51314 L .6727 .51428 L F
.846 .53 0 r
.67374 .51314 m .67441 .51452 L .67385 .51229 L F
0 .361 .746 r
.67607 .51501 m .67441 .51452 L .67374 .51314 L F
0 .226 .739 r
.6752 .51364 m .67607 .51501 L .67374 .51314 L F
.6752 .51364 m .67374 .51314 L .67361 .51405 L F
.846 .53 0 r
.67374 .51314 m .67385 .51229 L .67381 .51213 L F
0 0 0 r
.67503 .50975 m .67374 .51314 L .67381 .51213 L F
.524 .177 .321 r
.42551 .69283 m .42778 .69281 L .4289 .69038 L F
.39 .044 .254 r
.4289 .69038 m .43002 .69228 L .4311 .69006 L F
.4289 .69038 m .42778 .69281 L .43002 .69228 L F
.866 .948 .866 r
.64312 .5399 m .64063 .54249 L .6398 .54174 L F
.786 .641 .701 r
.58666 .55931 m .58949 .562 L .58617 .56159 L F
.805 .631 .666 r
.58617 .56159 m .58949 .562 L .58828 .56517 L F
0 .472 .832 r
.36621 .71127 m .36543 .71062 L .36289 .70983 L F
0 .429 .843 r
.36621 .71127 m .36666 .71088 L .36543 .71062 L F
.36621 .71127 m .36848 .71217 L .36666 .71088 L F
.416 .839 .678 r
.44317 .6583 m .44214 .65904 L .44502 .65844 L F
.44317 .6583 m .44129 .65942 L .44214 .65904 L F
.281 .278 .678 r
.70678 .49782 m .70778 .49402 L .70538 .49465 L F
.70678 .49782 m .70844 .49667 L .70778 .49402 L F
.311 .335 .725 r
.70678 .49782 m .70922 .49978 L .70844 .49667 L F
.848 .445 .275 r
.564 .71551 m .56623 .71734 L .56639 .71566 L F
.35 .737 .986 r
.34146 .59259 m .34075 .5935 L .33933 .59288 L F
.34146 .59259 m .3429 .59341 L .34075 .5935 L F
.602 .332 .48 r
.50336 .7513 m .50532 .75149 L .50599 .74939 L F
.778 .587 .641 r
.66651 .48886 m .66984 .4899 L .66932 .48675 L F
.57 .667 .904 r
.66932 .48675 m .6712 .48528 L .6688 .4858 L F
.66932 .48675 m .67102 .48651 L .6712 .48528 L F
.117 .126 .591 r
.66932 .48675 m .67107 .488 L .67102 .48651 L F
.66932 .48675 m .66984 .4899 L .67107 .488 L F
.353 .022 .258 r
.33042 .63787 m .32955 .63951 L .32757 .64003 L F
.38 .123 .394 r
.33196 .63686 m .32955 .63951 L .33042 .63787 L F
.06 0 0 r
.31129 .63152 m .31181 .63239 L .31322 .63075 L F
.31129 .63152 m .30987 .63328 L .31181 .63239 L F
.614 .357 .504 r
.51303 .72963 m .51524 .73159 L .51542 .72921 L F
.51303 .72963 m .51347 .73215 L .51524 .73159 L F
.741 .745 .856 r
.65434 .54188 m .65765 .5425 L .65669 .54282 L F
.891 .903 .829 r
.6589 .53843 m .65765 .5425 L .6606 .53978 L F
.6589 .53843 m .65669 .54282 L .65765 .5425 L F
0 0 0 r
.75475 .5846 m .75637 .58339 L .75658 .58347 L F
.75475 .5846 m .75383 .58592 L .75637 .58339 L F
.573 .31 .48 r
.53283 .75655 m .53515 .75458 L .53316 .75525 L F
.893 .725 .666 r
.58046 .72822 m .57933 .72927 L .57947 .72557 L F
.463 .251 .506 r
.63088 .48404 m .63085 .48632 L .62861 .48681 L F
.497 .354 .617 r
.63085 .48632 m .63103 .48884 L .62861 .48681 L F
.735 .683 .8 r
.48265 .65472 m .47882 .65424 L .48082 .65339 L F
.804 .735 .788 r
.48427 .65227 m .48265 .65472 L .48082 .65339 L F
.283 0 0 r
.71659 .50747 m .71911 .50705 L .71982 .50598 L F
.005 0 0 r
.71982 .50598 m .71911 .50705 L .72244 .50492 L F
.143 0 0 r
.41927 .64907 m .42107 .64931 L .42279 .64922 L F
.354 0 0 r
.42107 .64931 m .42501 .64884 L .42279 .64922 L F
0 0 .066 r
.67069 .5014 m .67082 .4972 L .66882 .50041 L F
.828 .699 .722 r
.66882 .50041 m .66996 .50377 L .67069 .5014 L F
.468 .849 .984 r
.29954 .83021 m .30009 .82926 L .29794 .82976 L F
.29794 .82976 m .30009 .82926 L .29954 .83021 L F
.961 .652 .242 r
.61154 .54918 m .61251 .54902 L .61125 .5468 L F
.61154 .54918 m .61302 .55221 L .61251 .54902 L F
.457 .243 .498 r
.34436 .62317 m .34391 .62515 L .34193 .62604 L F
.379 .135 .413 r
.34391 .62515 m .34128 .62783 L .34193 .62604 L F
.559 .453 .691 r
.27228 .62901 m .27277 .63096 L .27062 .63152 L F
.358 .069 .331 r
.351 .6172 m .34835 .6195 L .349 .61788 L F
.636 .075 0 r
.54596 .72645 m .54962 .72848 L .54731 .7274 L F
.98 .846 .638 r
.52975 .76373 m .52836 .76543 L .52966 .76538 L F
.444 .787 .998 r
.30954 .58954 m .31104 .59037 L .30747 .58983 L F
.412 .757 .995 r
.31161 .58928 m .31104 .59037 L .30954 .58954 L F
.31161 .58928 m .31301 .59015 L .31104 .59037 L F
.722 .469 0 r
.66726 .49237 m .66743 .49344 L .66452 .49359 L F
.66726 .49237 m .66785 .49522 L .66743 .49344 L F
.813 .994 .865 r
.6679 .48977 m .66726 .49237 L .66984 .4899 L F
.6679 .48977 m .66984 .4899 L .66651 .48886 L F
.251 0 0 r
.664 .48866 m .66526 .48891 L .66651 .48886 L F
.66304 .48858 m .66526 .48891 L .664 .48866 L F
0 .284 .764 r
.66452 .48701 m .66738 .48934 L .66526 .48891 L F
.583 .215 .309 r
.66526 .48891 m .6679 .48977 L .66651 .48886 L F
0 .284 .764 r
.66738 .48934 m .66793 .48979 L .66526 .48891 L F
.722 .469 0 r
.66786 .49008 m .66726 .49237 L .6679 .48977 L F
.843 .852 .394 r
.66825 .49005 m .66743 .49344 L .6679 .48977 L F
.583 .215 .309 r
.66526 .48891 m .66825 .49005 L .6679 .48977 L F
0 .284 .764 r
.66793 .48979 m .66825 .49005 L .6679 .48991 L F
.66793 .48979 m .6679 .48991 L .66526 .48891 L F
.722 .469 0 r
.66743 .49344 m .66726 .4924 L .66786 .49008 L F
.66726 .4924 m .66726 .49237 L .66786 .49008 L F
.66743 .49344 m .66785 .49522 L .66726 .49237 L F
.595 .486 .7 r
.36602 .68222 m .36826 .68176 L .36774 .67936 L F
.693 .433 .526 r
.48637 .68484 m .48832 .68727 L .48637 .68699 L F
.794 .735 .797 r
.77788 .60058 m .77891 .60415 L .78114 .6009 L F
.447 .228 .487 r
.77891 .60415 m .77919 .60633 L .78145 .60515 L F
.834 .927 .894 r
.76873 .60981 m .77061 .60666 L .77107 .60659 L F
.521 .822 1 r
.77339 .60597 m .77107 .60659 L .77242 .60513 L F
.583 .918 .696 r
.77242 .60513 m .77107 .60659 L .77061 .60666 L F
.778 .745 .823 r
.58828 .56517 m .58719 .56742 L .58707 .567 L F
.081 0 .418 r
.37796 .71008 m .37951 .70689 L .37686 .70717 L F
.37796 .71008 m .37902 .70951 L .37951 .70689 L F
0 0 .395 r
.37796 .71008 m .37859 .71086 L .37902 .70951 L F
.37796 .71008 m .37904 .71201 L .37859 .71086 L F
0 0 .444 r
.37827 .71253 m .37904 .71201 L .37796 .71008 L F
.645 .665 .855 r
.73668 .60936 m .73992 .61024 L .73952 .60899 L F
.616 .691 .897 r
.73992 .61024 m .74141 .60825 L .73952 .60899 L F
.73992 .61024 m .74243 .60972 L .74141 .60825 L F
.598 .354 .518 r
.61261 .57536 m .60952 .5781 L .61016 .57549 L F
.626 .344 .47 r
.60713 .57637 m .61016 .57549 L .60952 .5781 L F
.639 .419 .568 r
.49111 .67613 m .48832 .67763 L .48812 .67553 L F
0 0 .437 r
.48812 .67553 m .48832 .67763 L .4885 .67565 L F
.092 0 0 r
.48961 .67372 m .48812 .67553 L .48744 .67534 L F
.639 .419 .568 r
.49111 .67613 m .48812 .67553 L .48961 .67372 L F
0 0 .437 r
.48812 .67553 m .4885 .67565 L .48882 .67189 L F
.092 0 0 r
.48744 .67534 m .48812 .67553 L .48669 .67589 L F
.684 .562 .711 r
.4916 .67135 m .49364 .67379 L .48961 .67372 L F
.604 .213 .275 r
.49364 .67379 m .49111 .67613 L .48961 .67372 L F
.504 0 0 r
.63148 .51391 m .63341 .51461 L .63474 .51453 L F
.502 0 0 r
.63402 .51548 m .63474 .51453 L .63341 .51461 L F
.63402 .51548 m .63745 .5149 L .63474 .51453 L F
.842 .636 .625 r
.60993 .53882 m .61287 .53706 L .61172 .53603 L F
.60993 .53882 m .61232 .53979 L .61287 .53706 L F
.113 .649 .858 r
.2762 .58446 m .27992 .58487 L .27779 .58479 L F
.613 .624 .838 r
.50561 .78176 m .50478 .78563 L .504 .78428 L F
.50561 .78176 m .50774 .78491 L .50478 .78563 L F
.912 .764 .684 r
.50774 .78491 m .50472 .78727 L .50478 .78563 L F
.237 0 .038 r
.70442 .51452 m .70152 .51681 L .70409 .51666 L F
.202 0 .218 r
.70442 .51452 m .70598 .51558 L .70657 .51375 L F
.70442 .51452 m .70409 .51666 L .70598 .51558 L F
.85 .695 .69 r
.60373 .73793 m .60158 .73501 L .60118 .73743 L F
.847 .713 .715 r
.60236 .74059 m .60373 .73793 L .60118 .73743 L F
.56 .933 .821 r
.70968 .52375 m .70801 .52417 L .70639 .52556 L F
0 0 0 r
.70801 .52417 m .70579 .52693 L .70639 .52556 L F
.792 .669 .728 r
.6239 .51215 m .62221 .51334 L .6245 .50865 L F
.707 .238 .134 r
.5155 .74062 m .51421 .74195 L .51381 .74081 L F
.541 .038 .011 r
.51779 .74148 m .51421 .74195 L .5155 .74062 L F
.288 .266 .66 r
.37682 .71845 m .37842 .72022 L .37768 .71798 L F
.375 .348 .701 r
.37073 .69055 m .37172 .68693 L .36985 .68797 L F
.37073 .69055 m .3724 .69013 L .37172 .68693 L F
.38 .369 .721 r
.37073 .69055 m .3729 .69255 L .3724 .69013 L F
.487 .379 .657 r
.37105 .69294 m .3729 .69255 L .37073 .69055 L F
.569 .937 .823 r
.71104 .52243 m .70801 .52417 L .70968 .52375 L F
.403 .786 .991 r
.32103 .59073 m .32031 .5916 L .31904 .59072 L F
.32103 .59073 m .32251 .59141 L .32031 .5916 L F
.907 .519 .096 r
.54679 .71315 m .54735 .715 L .5457 .71212 L F
.647 .769 .937 r
.27953 .63494 m .27755 .63577 L .27583 .63427 L F
.872 .726 .697 r
.66148 .51994 m .66262 .52061 L .6609 .51942 L F
.66148 .51994 m .66173 .52217 L .66262 .52061 L F
.384 .264 .591 r
.733 .50027 m .73346 .50282 L .73134 .50374 L F
.325 .14 .469 r
.73346 .50282 m .73175 .50574 L .73134 .50374 L F
.764 .448 .451 r
.48833 .76311 m .48667 .76512 L .48491 .76272 L F
.473 .343 .622 r
.48833 .76311 m .48863 .76584 L .49051 .76517 L F
.668 .32 .375 r
.48833 .76311 m .49051 .76517 L .48667 .76512 L F
.679 .627 .79 r
.46986 .66772 m .47108 .67094 L .47334 .67015 L F
.662 .566 .737 r
.47108 .67094 m .47604 .67061 L .47334 .67015 L F
.614 .483 .679 r
.47108 .67094 m .47423 .67318 L .47604 .67061 L F
.47108 .67094 m .4714 .67378 L .47423 .67318 L F
.623 .341 .469 r
.61901 .55006 m .62138 .55025 L .62168 .54832 L F
.544 .43 .673 r
.62168 .54832 m .6241 .54781 L .6236 .54523 L F
.468 .205 .431 r
.62168 .54832 m .62138 .55025 L .6241 .54781 L F
.436 .337 .644 r
.64238 .5094 m .64414 .51091 L .64418 .50856 L F
.64238 .5094 m .6425 .51175 L .64414 .51091 L F
.087 0 0 r
.47988 .75153 m .48133 .75155 L .48212 .75086 L F
.089 0 0 r
.47988 .75153 m .47839 .75297 L .48133 .75155 L F
.648 .858 .979 r
.45722 .6471 m .45338 .6471 L .45573 .646 L F
.599 .831 .988 r
.45934 .64633 m .45722 .6471 L .45573 .646 L F
0 0 0 r
.63238 .52318 m .63571 .52014 L .63502 .52171 L F
.362 0 .142 r
.63749 .51956 m .63983 .51903 L .63964 .52018 L F
.63749 .51956 m .63964 .52018 L .63887 .51981 L F
.109 0 .186 r
.63807 .51729 m .63749 .51956 L .63635 .51936 L F
.461 .156 .361 r
.64028 .51659 m .63749 .51956 L .63807 .51729 L F
.64028 .51659 m .63983 .51903 L .63749 .51956 L F
.362 0 .142 r
.63749 .51956 m .63887 .51981 L .63706 .51891 L F
.109 0 .186 r
.63635 .51936 m .63749 .51956 L .63571 .52014 L F
.34 .794 .947 r
.63571 .52014 m .63749 .51956 L .63726 .51921 L F
.802 .476 .437 r
.63706 .51891 m .63964 .52018 L .6381 .52017 L F
0 .06 .596 r
.6368 .51843 m .6381 .52017 L .63695 .51853 L F
.799 .992 .878 r
.63681 .51895 m .63689 .519 L .63693 .51893 L F
.6369 .51887 m .63693 .51893 L .63711 .51868 L F
.63681 .51895 m .63693 .51893 L .6369 .51887 L F
.697 .209 .083 r
.63507 .51886 m .6368 .51871 L .63595 .51787 L F
0 0 .29 r
.63711 .51868 m .63706 .51891 L .63595 .51787 L F
.697 .209 .083 r
.6368 .51871 m .63711 .51868 L .63595 .51787 L F
0 .06 .596 r
.6366 .5183 m .63687 .51877 L .6368 .51843 L F
.34 .794 .947 r
.63698 .51898 m .63726 .51921 L .63706 .51891 L F
.802 .476 .437 r
.63706 .51891 m .6381 .52017 L .63699 .51898 L F
.874 .992 .811 r
.63507 .51886 m .63439 .5212 L .63694 .51883 L F
.63696 .51869 m .63694 .51883 L .63711 .51868 L F
.6368 .51871 m .63694 .51883 L .63696 .51869 L F
.802 .476 .437 r
.63694 .51881 m .63693 .51892 L .63595 .51787 L F
.874 .992 .811 r
.63688 .51883 m .63694 .51883 L .6368 .51871 L F
0 .06 .596 r
.6369 .51887 m .63697 .51896 L .6366 .5183 L F
.63692 .5189 m .63693 .51892 L .6369 .51887 L F
.63697 .51896 m .6381 .52017 L .63746 .51931 L F
0 0 .29 r
.63711 .51868 m .63693 .51893 L .63706 .51891 L F
.63693 .51893 m .63697 .51895 L .63706 .51891 L F
.802 .476 .437 r
.63706 .51891 m .63699 .51898 L .63697 .51895 L F
.63706 .51891 m .63697 .51895 L .63693 .51892 L F
.63696 .51892 m .63693 .51892 L .63694 .51886 L F
.63696 .51892 m .63694 .51886 L .63694 .51881 L F
.63706 .51891 m .63696 .51892 L .63694 .51881 L F
0 .06 .596 r
.63697 .51896 m .63746 .51931 L .6368 .51843 L F
.63697 .51896 m .63746 .51931 L .63697 .51896 L F
0 0 .29 r
.63693 .51893 m .6369 .51898 L .63697 .51895 L F
.34 .794 .947 r
.63693 .51903 m .63701 .51907 L .63698 .51898 L F
.63571 .52014 m .63726 .51921 L .63693 .51903 L F
.63548 .52066 m .63706 .51891 L .63502 .52171 L F
0 0 .29 r
.6369 .51898 m .63502 .52171 L .63706 .51891 L F
0 .06 .596 r
.63693 .51892 m .63697 .51896 L .6369 .51887 L F
.874 .992 .811 r
.63507 .51886 m .63688 .51883 L .6368 .51871 L F
.34 .794 .947 r
.63571 .52014 m .63706 .51891 L .63548 .52066 L F
0 .06 .596 r
.63687 .51877 m .63697 .51896 L .63693 .51884 L F
.63687 .51877 m .63693 .51884 L .6368 .51843 L F
.63595 .51787 m .63692 .5189 L .6366 .5183 L F
.34 .794 .947 r
.63701 .51907 m .63726 .51921 L .63698 .51898 L F
.799 .992 .878 r
.63439 .5212 m .63502 .52171 L .63689 .519 L F
.63439 .5212 m .63689 .519 L .63681 .51895 L F
.014 .421 .861 r
.6431 .48291 m .64265 .48358 L .64162 .48206 L F
.6431 .48291 m .64364 .48368 L .64265 .48358 L F
.986 .872 .515 r
.67928 .52727 m .68042 .52583 L .67903 .52492 L F
.67928 .52727 m .67994 .52819 L .68042 .52583 L F
.874 .67 .623 r
.6767 .53281 m .67984 .53437 L .67833 .53227 L F
0 .017 .561 r
.6767 .53281 m .67899 .53569 L .67984 .53437 L F
.032 .32 .806 r
.67833 .53227 m .67984 .53437 L .68005 .53322 L F
.761 .266 0 r
.67731 .5344 m .67871 .53556 L .6767 .53281 L F
.143 .067 .504 r
.6792 .53536 m .68005 .53322 L .67984 .53437 L F
.67899 .53569 m .67911 .53539 L .6792 .53536 L F
.67911 .53539 m .68005 .53322 L .6792 .53536 L F
.67899 .53569 m .68061 .53511 L .68005 .53322 L F
.008 0 .101 r
.67899 .53569 m .67971 .53625 L .68061 .53511 L F
.813 .784 .283 r
.67648 .53145 m .6766 .53213 L .67688 .53083 L F
.67648 .53145 m .67688 .53083 L .67716 .52949 L F
.901 .816 .755 r
.6767 .53281 m .67868 .5306 L .67716 .52949 L F
.6767 .53281 m .67716 .52949 L .6766 .53213 L F
.874 .67 .623 r
.6767 .53281 m .67833 .53227 L .67868 .5306 L F
.521 .727 .967 r
.67771 .52971 m .67861 .53123 L .67648 .53145 L F
0 0 .085 r
.67771 .52971 m .67648 .53145 L .67861 .53123 L F
.67771 .52971 m .67614 .53199 L .67648 .53145 L F
0 0 .227 r
.67648 .53145 m .67676 .53245 L .6766 .53213 L F
.67676 .53245 m .67731 .5344 L .6768 .53278 L F
.67676 .53245 m .6768 .53278 L .6766 .53213 L F
0 .017 .561 r
.6767 .53281 m .67683 .53296 L .67683 .53297 L F
.761 .266 0 r
.67731 .5344 m .6767 .53281 L .6766 .53213 L F
.721 .617 .741 r
.67412 .53404 m .67731 .5344 L .67648 .53145 L F
0 0 .085 r
.67614 .53199 m .67568 .53264 L .67648 .53145 L F
.032 .32 .806 r
.67833 .53227 m .68005 .53322 L .67868 .5306 L F
0 0 .532 r
.67868 .5306 m .68005 .53322 L .68013 .53188 L F
.793 .439 .387 r
.68005 .53322 m .67801 .5341 L .68013 .53188 L F
0 .017 .561 r
.67683 .53297 m .67838 .53482 L .67852 .5351 L F
.67838 .53482 m .67934 .53596 L .67852 .5351 L F
.67683 .53296 m .67934 .53596 L .67683 .53297 L F
.761 .266 0 r
.67871 .53556 m .67893 .53547 L .6767 .53281 L F
.793 .439 .387 r
.67801 .5341 m .67731 .5344 L .6779 .53388 L F
.67801 .5341 m .6779 .53388 L .68013 .53188 L F
0 .017 .561 r
.67852 .5351 m .67934 .53596 L .67899 .53569 L F
.67934 .53596 m .67964 .53633 L .67899 .53569 L F
.42 .032 .194 r
.67964 .53633 m .67871 .53751 L .67899 .53569 L F
.008 0 .101 r
.67899 .53569 m .67932 .53623 L .67934 .53596 L F
.947 .744 .596 r
.67938 .53611 m .67871 .53751 L .67964 .53633 L F
.008 0 .101 r
.67932 .53623 m .6795 .53651 L .67938 .53611 L F
.67932 .53623 m .67938 .53611 L .67934 .53596 L F
.67899 .53569 m .67871 .53751 L .6795 .53651 L F
.947 .744 .596 r
.67731 .5344 m .67871 .53751 L .67938 .53611 L F
.761 .266 0 r
.67871 .53556 m .67938 .53611 L .67893 .53547 L F
.67938 .53611 m .67964 .53633 L .67934 .53596 L F
.67938 .53611 m .67934 .53596 L .67893 .53547 L F
.008 0 .101 r
.67934 .53596 m .6795 .53651 L .67971 .53625 L F
0 0 .12 r
.50045 .80998 m .50008 .81219 L .49804 .81084 L F
.316 .226 .592 r
.5015 .81346 m .50008 .81219 L .50152 .81504 L F
.724 .669 .795 r
.49606 .76283 m .50018 .76306 L .49873 .75968 L F
.711 .477 .569 r
.49756 .76515 m .50018 .76306 L .49606 .76283 L F
.49756 .76515 m .49996 .76572 L .50018 .76306 L F
.235 .215 .631 r
.50018 .76306 m .50183 .76175 L .49873 .75968 L F
.50018 .76306 m .50157 .76251 L .50183 .76175 L F
.216 .164 .581 r
.50018 .76306 m .5018 .76502 L .50157 .76251 L F
.382 .198 .503 r
.50018 .76306 m .49996 .76572 L .5018 .76502 L F
.552 .497 .748 r
.39436 .68191 m .39289 .68403 L .3921 .68235 L F
.39436 .68191 m .39473 .68387 L .39289 .68403 L F
.404 .437 .781 r
.3957 .68758 m .39289 .68403 L .39473 .68387 L F
.55 .531 .787 r
.39785 .68705 m .39695 .69091 L .3957 .68758 L F
.39785 .68705 m .39896 .69056 L .39695 .69091 L F
.388 .112 .368 r
.72466 .51442 m .72458 .51682 L .72227 .51762 L F
.31 .053 .353 r
.72653 .5157 m .72466 .51442 L .72684 .51346 L F
.72653 .5157 m .72458 .51682 L .72466 .51442 L F
.345 .407 .783 r
.63256 .48289 m .63088 .48404 L .62977 .48069 L F
0 0 .309 r
.63187 .48457 m .63088 .48404 L .63256 .48289 L F
.63187 .48457 m .63085 .48632 L .63088 .48404 L F
.429 0 .089 r
.57667 .67714 m .5788 .67781 L .58038 .67575 L F
.652 .273 .314 r
.5788 .67781 m .58193 .67629 L .58038 .67575 L F
.397 .108 .353 r
.56087 .69866 m .5582 .70121 L .5587 .69929 L F
.352 .069 .336 r
.58067 .57311 m .57854 .57516 L .58037 .57525 L F
.59 .382 .567 r
.58067 .57311 m .58248 .57509 L .58315 .57277 L F
.58067 .57311 m .58248 .57509 L .58315 .57277 L F
.277 .111 .467 r
.50949 .80771 m .50792 .81104 L .50936 .8095 L F
.587 .885 .589 r
.50936 .8095 m .50792 .81104 L .50537 .81342 L F
.427 .861 .929 r
.64966 .53067 m .65126 .52975 L .64892 .53043 L F
.732 .405 .426 r
.65089 .52937 m .65126 .52975 L .65094 .52928 L F
.427 .861 .929 r
.64966 .53067 m .65164 .53014 L .65126 .52975 L F
.711 .618 .751 r
.65126 .52975 m .64884 .53273 L .64892 .53043 L F
.732 .405 .426 r
.64951 .53165 m .65126 .52975 L .65089 .52937 L F
.427 .861 .929 r
.65164 .53014 m .65215 .53 L .65126 .52975 L F
.601 .287 .41 r
.52146 .75918 m .51917 .75748 L .51897 .75887 L F
.88 .494 .302 r
.66724 .52869 m .66868 .53132 L .66613 .5299 L F
.541 .487 .745 r
.58783 .68773 m .58702 .684 L .58857 .68541 L F
.056 .62 .778 r
.53034 .73619 m .52937 .73633 L .53108 .73571 L F
.53034 .73619 m .52766 .73609 L .52937 .73633 L F
.409 0 .121 r
.4417 .69614 m .44036 .69804 L .43812 .69826 L F
.447 .054 .201 r
.44388 .6957 m .44036 .69804 L .4417 .69614 L F
.29 0 .091 r
.53058 .76477 m .52975 .76373 L .53198 .7639 L F
.974 .687 .416 r
.53198 .7639 m .53185 .76558 L .53058 .76477 L F
.383 .142 .42 r
.34835 .6195 m .34569 .62233 L .34638 .62042 L F
.539 .729 .962 r
.6901 .48308 m .68853 .48513 L .68788 .48359 L F
.6901 .48308 m .6919 .48508 L .68853 .48513 L F
.647 .634 .823 r
.73668 .60936 m .73806 .60558 L .73566 .6061 L F
.73668 .60936 m .73952 .60899 L .73806 .60558 L F
.436 .257 .539 r
.46474 .76516 m .46669 .76242 L .46456 .76314 L F
.876 .716 .68 r
.6589 .53843 m .66174 .53707 L .65908 .5363 L F
.6589 .53843 m .6606 .53978 L .66174 .53707 L F
.556 .469 .712 r
.39369 .67861 m .39436 .68191 L .3921 .68235 L F
.763 .687 .778 r
.5841 .57843 m .58533 .58168 L .58189 .58126 L F
.706 .284 .242 r
.58189 .58126 m .58533 .58168 L .5841 .58309 L F
.511 .304 .536 r
.58411 .5761 m .58653 .57541 L .5841 .57843 L F
.58411 .5761 m .58653 .57541 L .5841 .57843 L F
.555 .519 .77 r
.58606 .57793 m .58533 .58168 L .5841 .57843 L F
.58606 .57793 m .58764 .58105 L .58533 .58168 L F
.736 .506 .581 r
.58764 .58105 m .5841 .58309 L .58533 .58168 L F
.876 .82 .789 r
.59726 .5334 m .59867 .53444 L .59677 .53755 L F
.851 .839 .833 r
.59963 .53064 m .59867 .53444 L .59726 .5334 L F
.59963 .53064 m .60098 .53177 L .59867 .53444 L F
.295 .77 .932 r
.29074 .63577 m .294 .63587 L .29192 .6364 L F
.416 .399 .732 r
.37238 .6987 m .37415 .69811 L .37178 .69617 L F
.068 .52 .898 r
.31747 .60314 m .3176 .60253 L .31521 .60181 L F
.31747 .60314 m .31915 .60368 L .3176 .60253 L F
.376 .758 .99 r
.30393 .65067 m .30449 .64973 L .30236 .64997 L F
.30393 .65067 m .30593 .65051 L .30449 .64973 L F
.687 .465 .58 r
.50966 .75592 m .50658 .75451 L .50983 .75437 L F
0 0 0 r
.51222 .75448 m .50966 .75592 L .50983 .75437 L F
.563 .364 .569 r
.28059 .72081 m .28355 .71788 L .28078 .71844 L F
0 0 0 r
.52377 .7382 m .52198 .74015 L .52084 .7402 L F
.21 0 0 r
.52436 .73939 m .52198 .74015 L .52377 .7382 L F
.471 .082 .221 r
.48978 .74609 m .492 .74608 L .49292 .74403 L F
.338 0 .161 r
.49292 .74403 m .494 .7456 L .49523 .7436 L F
.49292 .74403 m .492 .74608 L .494 .7456 L F
.161 .632 .93 r
.40443 .69767 m .40613 .69782 L .40735 .69851 L F
.595 .862 .993 r
.40735 .69851 m .40815 .69712 L .40928 .69778 L F
.40735 .69851 m .40613 .69782 L .40815 .69712 L F
.366 0 0 r
.53484 .72415 m .53714 .7241 L .53812 .72358 L F
.58 .117 .119 r
.53812 .72358 m .53714 .7241 L .54035 .72403 L F
.293 .379 .781 r
.67129 .50195 m .66996 .50377 L .66882 .50041 L F
.33 .431 .814 r
.67129 .50195 m .67262 .50504 L .66996 .50377 L F
.487 .48 .775 r
.36911 .68514 m .36985 .68797 L .37172 .68693 L F
.665 .391 .496 r
.61846 .57298 m .615 .57515 L .61514 .57341 L F
.403 .188 .469 r
.34569 .62233 m .34391 .62515 L .34436 .62317 L F
.066 0 0 r
.44841 .65769 m .4468 .65828 L .44502 .65844 L F
0 0 0 r
.44797 .65793 m .44841 .65769 L .45036 .65671 L F
.44797 .65793 m .4468 .65828 L .44841 .65769 L F
.447 .236 .498 r
.37194 .65903 m .37424 .65649 L .37201 .65702 L F
.206 .287 .727 r
.37827 .71253 m .37906 .71563 L .37997 .71424 L F
.624 .544 .744 r
.37768 .71798 m .37997 .71424 L .37906 .71563 L F
.782 .787 .857 r
.7386 .59228 m .73682 .59224 L .73767 .59165 L F
.573 .899 .983 r
.7392 .59109 m .7386 .59228 L .73767 .59165 L F
.568 .899 .983 r
.7392 .59109 m .73767 .59165 L .73929 .59026 L F
.02 0 .38 r
.7391 .59065 m .73767 .59165 L .73749 .59394 L F
.73929 .59026 m .73767 .59165 L .7391 .59065 L F
.782 .787 .857 r
.73682 .59224 m .73538 .59221 L .73767 .59165 L F
.573 .899 .983 r
.7392 .59109 m .74018 .59173 L .7386 .59228 L F
.465 .782 .998 r
.32844 .60379 m .32897 .6025 L .32697 .60279 L F
.32844 .60379 m .33093 .6035 L .32897 .6025 L F
0 0 0 r
.64666 .53566 m .64515 .53733 L .64767 .53423 L F
.364 .412 .778 r
.64666 .53566 m .64745 .53811 L .64515 .53733 L F
.515 .234 .426 r
.40301 .67208 m .40126 .67059 L .40347 .67039 L F
.40301 .67208 m .40081 .67244 L .40126 .67059 L F
.772 .671 .751 r
.38021 .72364 m .38152 .72699 L .38395 .72406 L F
.698 .634 .782 r
.46465 .66784 m .46757 .66826 L .46634 .66501 L F
.618 .591 .801 r
.46634 .66501 m .46757 .66826 L .46986 .66772 L F
.823 .837 .859 r
.71624 .50293 m .71719 .50444 L .71922 .50319 L F
.71624 .50293 m .71413 .50429 L .71719 .50444 L F
.57 .364 .563 r
.50512 .73743 m .50761 .73477 L .50572 .7356 L F
.876 .82 .789 r
.59726 .5334 m .59677 .53755 L .59563 .53644 L F
.903 .87 .795 r
.59563 .53644 m .59677 .53755 L .59558 .53938 L F
.495 .251 .473 r
.53751 .76564 m .53509 .76816 L .53543 .76596 L F
.657 .972 .869 r
.78063 .61166 m .78375 .61014 L .78297 .60911 L F
.872 .924 .857 r
.78297 .60911 m .78375 .61014 L .78539 .6084 L F
.931 .933 .781 r
.78114 .6009 m .78266 .59862 L .78199 .5971 L F
.625 .801 .967 r
.28506 .63466 m .28309 .63536 L .2816 .63419 L F
.441 .006 .115 r
.46904 .68756 m .46536 .68944 L .4654 .68791 L F
.46904 .68756 m .46768 .68931 L .46536 .68944 L F
.6 .181 .218 r
.47106 .68914 m .46904 .68756 L .4712 .68811 L F
.47106 .68914 m .46768 .68931 L .46904 .68756 L F
.626 .344 .47 r
.60713 .57637 m .60952 .5781 L .60697 .57819 L F
.897 .866 .801 r
.78497 .60613 m .78539 .6084 L .78625 .60726 L F
.78497 .60613 m .78297 .60911 L .78539 .6084 L F
.315 .759 .963 r
.42501 .64884 m .42689 .64868 L .42846 .64923 L F
.571 .039 0 r
.42689 .64868 m .43058 .64914 L .42846 .64923 L F
.214 0 0 r
.28836 .60673 m .28671 .60806 L .28459 .60842 L F
.393 0 .109 r
.29034 .60588 m .28671 .60806 L .28836 .60673 L F
0 0 0 r
.62891 .51718 m .63029 .51584 L .63148 .51391 L F
.558 .934 .848 r
.62891 .51718 m .62837 .51698 L .63029 .51584 L F
.951 .725 .561 r
.66363 .51193 m .66344 .51424 L .6622 .51102 L F
.555 .78 .983 r
.68129 .48127 m .68014 .4829 L .67905 .48159 L F
.68129 .48127 m .68266 .48241 L .68014 .4829 L F
.254 0 .26 r
.55982 .7873 m .56216 .78499 L .56205 .78749 L F
.298 0 .214 r
.55982 .7873 m .56205 .78749 L .55988 .7884 L F
.229 0 0 r
.41164 .69708 m .41387 .69708 L .41566 .69644 L F
.217 0 0 r
.41387 .69708 m .41756 .69566 L .41566 .69644 L F
.913 .932 .809 r
.58838 .54709 m .59137 .54508 L .58947 .54802 L F
.58838 .54709 m .59043 .54416 L .59137 .54508 L F
.896 .933 .832 r
.59043 .54416 m .5936 .54221 L .59137 .54508 L F
0 0 0 r
.5752 .68573 m .57361 .68993 L .57341 .69041 L F
.57 .577 .822 r
.48576 .66193 m .48344 .66127 L .48597 .66084 L F
.516 .102 .195 r
.44365 .68416 m .44582 .68422 L .44725 .68235 L F
.631 .233 .272 r
.44725 .68235 m .44582 .68422 L .44932 .68402 L F
.04 0 .083 r
.48359 .78252 m .48612 .77968 L .48607 .78217 L F
.65 .438 .582 r
.48846 .77946 m .48607 .78217 L .48612 .77968 L F
.584 .626 .86 r
.66406 .47998 m .66548 .48208 L .66121 .48165 L F
.326 .13 .455 r
.27941 .6138 m .27788 .61225 L .27968 .61156 L F
.27941 .6138 m .27756 .61459 L .27788 .61225 L F
.323 0 0 r
.43535 .68877 m .43909 .6871 L .43685 .6874 L F
.785 .992 .882 r
.34704 .71561 m .34334 .71768 L .34521 .7176 L F
.776 .706 .786 r
.6245 .50865 m .62084 .50843 L .6234 .50561 L F
.785 .66 .725 r
.6245 .50865 m .62221 .51334 L .62084 .50843 L F
.75 .693 .797 r
.62662 .50597 m .6245 .50865 L .6234 .50561 L F
.577 .442 .66 r
.62662 .50597 m .62723 .50866 L .6245 .50865 L F
.653 .42 .554 r
.48359 .78252 m .48359 .78528 L .48047 .78498 L F
.533 .353 .583 r
.48607 .78217 m .48359 .78528 L .48359 .78252 L F
.587 .245 .356 r
.49215 .77949 m .48842 .78191 L .48846 .77946 L F
.49215 .77949 m .49059 .78194 L .48842 .78191 L F
.696 .372 .424 r
.4942 .78191 m .49059 .78194 L .49215 .77949 L F
.708 .371 .404 r
.49419 .78015 m .4942 .78191 L .49215 .77949 L F
.718 .881 .482 r
.64914 .54453 m .64726 .54765 L .64742 .54767 L F
0 .036 .577 r
.36016 .59879 m .35923 .59813 L .3575 .59783 L F
.36016 .59879 m .36116 .60018 L .35923 .59813 L F
.291 .113 .458 r
.65473 .53104 m .65348 .53427 L .65557 .53273 L F
.631 .581 .78 r
.65217 .52781 m .65662 .52985 L .65565 .52638 L F
.65217 .52781 m .65428 .52694 L .65352 .52741 L F
.65428 .52694 m .65565 .52638 L .65352 .52741 L F
.384 .61 .939 r
.65217 .52781 m .65441 .53063 L .6533 .52833 L F
.956 .947 .709 r
.65126 .52975 m .65215 .53 L .65217 .52781 L F
.65126 .52975 m .65217 .52781 L .65352 .52741 L F
.88 .962 .63 r
.65301 .52772 m .65126 .52975 L .65308 .52787 L F
.65247 .52661 m .65174 .5285 L .65301 .52772 L F
.65174 .5285 m .65126 .52975 L .65301 .52772 L F
.65267 .52608 m .65247 .52661 L .65352 .52741 L F
.65247 .52661 m .65308 .52787 L .65352 .52741 L F
.384 .61 .939 r
.6533 .52833 m .65473 .53104 L .65662 .52985 L F
.65441 .53063 m .65473 .53104 L .6533 .52833 L F
.436 .77 .997 r
.27547 .65321 m .27542 .65184 L .27373 .65279 L F
.27547 .65321 m .27707 .65286 L .27542 .65184 L F
0 0 0 r
.52342 .77881 m .525 .77864 L .52271 .77933 L F
.52342 .77881 m .52635 .77829 L .525 .77864 L F
.134 0 .207 r
.63619 .50009 m .63912 .49701 L .63675 .49788 L F
.586 .571 .804 r
.63938 .51385 m .63807 .51729 L .63745 .5149 L F
.63938 .51385 m .64028 .51659 L .63807 .51729 L F
.63938 .51385 m .63807 .51729 L .63745 .5149 L F
.63938 .51385 m .64028 .51659 L .63807 .51729 L F
.655 .346 .437 r
.46347 .68757 m .46195 .69003 L .45979 .68961 L F
.638 .326 .426 r
.46536 .68944 m .46347 .68757 L .4654 .68791 L F
.46536 .68944 m .46195 .69003 L .46347 .68757 L F
.804 .735 .788 r
.48427 .65227 m .48082 .65339 L .48334 .6511 L F
.482 .44 .734 r
.48555 .64939 m .48427 .65227 L .48334 .6511 L F
.48555 .64939 m .48673 .65356 L .48427 .65227 L F
.291 0 .227 r
.32757 .64003 m .32662 .6425 L .32485 .64257 L F
.291 0 .226 r
.32855 .6417 m .32757 .64003 L .32955 .63951 L F
.32855 .6417 m .32662 .6425 L .32757 .64003 L F
.371 .445 .807 r
.40137 .69197 m .40017 .69384 L .39896 .69056 L F
.45 .549 .866 r
.40137 .69197 m .4031 .69507 L .40017 .69384 L F
.375 .625 .95 r
.75399 .61237 m .75645 .61469 L .75757 .61425 L F
.077 .163 .652 r
.67789 .51931 m .67641 .51741 L .67734 .51578 L F
.355 0 0 r
.43661 .65975 m .43518 .66111 L .43288 .66121 L F
.234 0 0 r
.43892 .66002 m .43518 .66111 L .43661 .65975 L F
.908 .708 .621 r
.61679 .52608 m .61936 .52356 L .61866 .52448 L F
.292 .079 .409 r
.46218 .77699 m .46377 .77828 L .46356 .77622 L F
.46218 .77699 m .46155 .77985 L .46377 .77828 L F
0 0 .146 r
.67713 .52306 m .67789 .51931 L .67844 .52148 L F
0 .129 .67 r
.67841 .52366 m .67713 .52306 L .67844 .52148 L F
0 0 0 r
.6789 .52356 m .67841 .52366 L .67971 .52225 L F
0 .129 .67 r
.67841 .52366 m .67903 .52492 L .67786 .52378 L F
.973 .687 .423 r
.678 .52614 m .67903 .52492 L .67841 .52366 L F
0 0 0 r
.67773 .52545 m .67841 .52366 L .6789 .52356 L F
0 .129 .67 r
.67841 .52366 m .67786 .52378 L .67713 .52306 L F
.537 .387 .624 r
.27075 .62075 m .27078 .62333 L .26883 .62379 L F
.544 .429 .673 r
.27078 .62333 m .26913 .62617 L .26883 .62379 L F
.991 .751 .382 r
.59838 .72045 m .59919 .7239 L .5995 .72145 L F
.727 .716 .84 r
.53832 .7443 m .53487 .74549 L .53387 .74474 L F
.383 .061 .29 r
.53307 .74343 m .53285 .74532 L .53073 .7442 L F
.53307 .74343 m .53284 .74534 L .53073 .7442 L F
.952 .707 .249 r
.5324 .74362 m .53251 .74404 L .53307 .74343 L F
.383 .061 .29 r
.53285 .74532 m .53282 .74533 L .53073 .7442 L F
.083 0 .022 r
.53273 .74495 m .53241 .74773 L .53136 .74461 L F
.383 .061 .29 r
.53285 .74532 m .53284 .74534 L .53282 .74533 L F
.952 .707 .249 r
.53255 .74399 m .53284 .74534 L .53307 .74343 L F
.53269 .74476 m .53284 .74534 L .53255 .74399 L F
.53251 .74404 m .53269 .74476 L .53255 .74399 L F
.734 .716 .834 r
.53251 .74404 m .53487 .74549 L .53284 .74534 L F
.336 0 0 r
.53251 .74404 m .53307 .74343 L .53141 .74457 L F
.734 .716 .834 r
.5324 .74362 m .53278 .74391 L .53251 .74404 L F
.53278 .74391 m .53487 .74549 L .53251 .74404 L F
.336 0 0 r
.53239 .74417 m .53251 .74404 L .53136 .74461 L F
.53251 .74404 m .53141 .74457 L .53136 .74461 L F
.083 0 .022 r
.53487 .74549 m .53136 .74461 L .53284 .74534 L F
.53487 .74549 m .53312 .74708 L .53273 .74495 L F
.53312 .74708 m .53241 .74773 L .53273 .74495 L F
.727 .716 .84 r
.53527 .74395 m .53387 .74474 L .53278 .74391 L F
.336 0 0 r
.53309 .74377 m .53307 .74343 L .53251 .74404 L F
.53309 .74377 m .5324 .74362 L .53307 .74343 L F
.727 .716 .84 r
.53309 .74377 m .53278 .74391 L .5324 .74362 L F
.336 0 0 r
.53309 .74387 m .5324 .74362 L .53309 .74377 L F
.727 .716 .84 r
.5332 .74371 m .53309 .74377 L .5324 .74362 L F
.53527 .74395 m .53278 .74391 L .5332 .74371 L F
.336 0 0 r
.53309 .74387 m .53309 .74377 L .53239 .74417 L F
.53309 .74377 m .53251 .74404 L .53239 .74417 L F
.727 .716 .84 r
.53832 .7443 m .53387 .74474 L .53527 .74395 L F
.538 .727 .961 r
.76228 .6082 m .76005 .60875 L .75834 .60688 L F
.641 .735 .916 r
.54076 .7403 m .54177 .74238 L .5437 .74128 L F
.485 .679 .951 r
.54177 .74238 m .54443 .74269 L .5437 .74128 L F
.505 .3 .535 r
.46843 .64581 m .46518 .64597 L .46677 .64481 L F
.46843 .64581 m .46608 .64881 L .46518 .64597 L F
.46843 .64581 m .4682 .64863 L .46608 .64881 L F
.582 .679 .907 r
.46971 .64383 m .46843 .64581 L .46677 .64481 L F
.46971 .64383 m .47063 .64536 L .46843 .64581 L F
.529 .32 .54 r
.47064 .64801 m .46843 .64581 L .47063 .64536 L F
.47064 .64801 m .4682 .64863 L .46843 .64581 L F
.677 .612 .776 r
.5049 .78282 m .504 .78428 L .50161 .78177 L F
.616 .573 .782 r
.504 .78428 m .50296 .78506 L .50161 .78177 L F
0 0 0 r
.50561 .78176 m .504 .78428 L .5049 .78282 L F
.716 .498 .593 r
.52123 .73206 m .52441 .72954 L .52107 .72938 L F
.52123 .73206 m .52441 .73209 L .52441 .72954 L F
.522 .66 .923 r
.76449 .60798 m .76291 .60973 L .76228 .6082 L F
.516 .65 .918 r
.76449 .60798 m .7654 .6097 L .76291 .60973 L F
.713 .273 .204 r
.55155 .70993 m .55364 .71181 L .55465 .71043 L F
.826 .422 .282 r
.55465 .71043 m .55364 .71181 L .55556 .71207 L F
.625 .539 .737 r
.49389 .67069 m .49364 .67379 L .4916 .67135 L F
.27 0 0 r
.28336 .58498 m .28552 .58571 L .287 .58609 L F
0 .512 .767 r
.28552 .58571 m .28904 .58646 L .287 .58609 L F
0 .301 .795 r
.3698 .70809 m .36827 .70781 L .3681 .70661 L F
.3698 .70809 m .37066 .70957 L .36827 .70781 L F
.605 .24 .325 r
.50145 .68717 m .49971 .68942 L .49762 .68788 L F
.339 .723 .984 r
.50242 .68644 m .50145 .68717 L .50132 .68413 L F
.50242 .68644 m .50339 .68729 L .50145 .68717 L F
.824 .658 .677 r
.50339 .68729 m .49971 .68942 L .50145 .68717 L F
.534 .377 .614 r
.3664 .67068 m .36846 .67042 L .3684 .66777 L F
.496 .373 .643 r
.36669 .67386 m .36846 .67042 L .3664 .67068 L F
.916 .903 .797 r
.59265 .5413 m .59558 .53938 L .5936 .54221 L F
.59265 .5413 m .59452 .53843 L .59558 .53938 L F
.903 .87 .795 r
.59563 .53644 m .59558 .53938 L .59452 .53843 L F
.408 .335 .663 r
.46326 .76861 m .46492 .76813 L .46474 .76516 L F
.397 .301 .628 r
.46326 .76861 m .46525 .77065 L .46492 .76813 L F
.394 .3 .63 r
.46363 .77113 m .46525 .77065 L .46326 .76861 L F
.458 .738 .988 r
.53681 .80399 m .53826 .80522 L .53908 .80389 L F
.515 .471 .746 r
.37178 .69617 m .3729 .69255 L .37105 .69294 L F
.37178 .69617 m .37364 .69564 L .3729 .69255 L F
.495 .401 .678 r
.37178 .69617 m .37415 .69811 L .37364 .69564 L F
.244 .651 .962 r
.32653 .59132 m .32603 .59209 L .32449 .59135 L F
.32653 .59132 m .328 .59232 L .32603 .59209 L F
.896 .933 .832 r
.59043 .54416 m .59265 .5413 L .5936 .54221 L F
.629 .817 .972 r
.58042 .73317 m .58163 .73129 L .57918 .73228 L F
.58042 .73317 m .58314 .73234 L .58163 .73129 L F
.744 .645 .751 r
.56237 .78456 m .56125 .78261 L .56138 .78335 L F
.56125 .78261 m .56112 .78239 L .56122 .78275 L F
.56125 .78261 m .56122 .78275 L .56138 .78335 L F
.368 .079 .337 r
.56087 .78194 m .5583 .78442 L .56138 .78335 L F
.56087 .78194 m .55886 .78258 L .5583 .78442 L F
.479 .874 .964 r
.56076 .7834 m .5583 .78442 L .55886 .78357 L F
.832 .676 .689 r
.56069 .78352 m .56138 .78335 L .56102 .78307 L F
.479 .874 .964 r
.56138 .78335 m .56026 .78374 L .56053 .78356 L F
.832 .676 .689 r
.55918 .7856 m .56138 .78335 L .56069 .78352 L F
.479 .874 .964 r
.56138 .78335 m .56053 .78356 L .56076 .7834 L F
.56026 .78374 m .5583 .78442 L .56076 .7834 L F
.744 .645 .751 r
.56242 .78453 m .56107 .78228 L .56237 .78456 L F
.56107 .78228 m .56087 .78194 L .56108 .7823 L F
.56107 .78228 m .56108 .7823 L .56237 .78456 L F
.56112 .78239 m .56115 .78271 L .56138 .78335 L F
.626 .874 .528 r
.56257 .78446 m .56458 .78203 L .56432 .7822 L F
.56216 .78499 m .5626 .78444 L .56257 .78446 L F
.5626 .78444 m .56458 .78203 L .56257 .78446 L F
.56216 .78499 m .56432 .7822 L .56261 .78485 L F
.744 .645 .751 r
.56261 .78485 m .56178 .78135 L .56087 .78194 L F
.56261 .78485 m .56432 .7822 L .56178 .78135 L F
.716 .612 .739 r
.56432 .7822 m .56296 .77888 L .56178 .78135 L F
0 0 0 r
.56117 .78292 m .56178 .78135 L .56305 .78064 L F
.56115 .78278 m .56178 .78135 L .56117 .78292 L F
.56278 .78055 m .56178 .78135 L .56115 .78278 L F
.56212 .78186 m .56102 .78307 L .56138 .78335 L F
.56129 .78278 m .56305 .78064 L .56212 .78186 L F
.56278 .78055 m .56102 .78307 L .56212 .78186 L F
.56117 .78292 m .56129 .78278 L .56181 .78227 L F
.56129 .78278 m .56212 .78186 L .56181 .78227 L F
.56278 .78055 m .56212 .78186 L .56183 .78201 L F
.56278 .78055 m .56115 .78278 L .56116 .78287 L F
.744 .645 .751 r
.56112 .78239 m .56087 .78194 L .56115 .78271 L F
.36 .013 .235 r
.56102 .78307 m .56178 .78135 L .56087 .78194 L F
0 0 0 r
.56278 .78055 m .56183 .78201 L .55886 .78357 L F
.716 .612 .739 r
.56432 .7822 m .5664 .77935 L .56296 .77888 L F
0 0 0 r
.56137 .78283 m .56388 .78017 L .56284 .78183 L F
.56102 .78307 m .56181 .78227 L .56137 .78283 L F
.56181 .78227 m .56187 .78236 L .56168 .78243 L F
.56211 .78189 m .56187 .78236 L .56181 .78227 L F
.56181 .78227 m .56388 .78017 L .56137 .78283 L F
.56212 .78186 m .56211 .78189 L .56181 .78227 L F
.56212 .78186 m .56168 .78243 L .55886 .78357 L F
.56181 .78227 m .56305 .78064 L .56388 .78017 L F
.56102 .78307 m .56115 .78278 L .56117 .78292 L F
.56187 .78236 m .56138 .78335 L .56076 .7834 L F
.56099 .78319 m .56102 .78307 L .56118 .78296 L F
.56091 .78326 m .56102 .78307 L .56099 .78319 L F
.56076 .7834 m .56102 .78307 L .56088 .78333 L F
.56116 .78287 m .56115 .78278 L .56102 .78307 L F
.56187 .78236 m .56076 .7834 L .55886 .78357 L F
.56088 .78333 m .56091 .78326 L .56099 .78319 L F
.832 .676 .689 r
.55918 .7856 m .56013 .78429 L .56001 .78438 L F
.56013 .78429 m .56102 .78307 L .56001 .78438 L F
.549 0 0 r
.55987 .78448 m .56001 .78438 L .56044 .78479 L F
0 0 0 r
.55886 .78357 m .55743 .78662 L .55918 .7856 L F
.832 .676 .689 r
.55918 .7856 m .56001 .78438 L .55886 .78357 L F
.549 0 0 r
.55791 .78342 m .56001 .78438 L .55987 .78448 L F
0 0 0 r
.56001 .78438 m .56076 .7834 L .56088 .78333 L F
.56108 .78341 m .56118 .78296 L .56284 .78183 L F
.56001 .78438 m .56118 .78296 L .56108 .78341 L F
.744 .645 .751 r
.56261 .78485 m .56242 .78453 L .56237 .78456 L F
.785 .908 .925 r
.56458 .78203 m .5664 .77935 L .56432 .7822 L F
.56458 .78203 m .56759 .7802 L .5664 .77935 L F
.41 0 .038 r
.52084 .7402 m .5191 .7419 L .51779 .74148 L F
0 0 0 r
.52198 .74015 m .5191 .7419 L .52084 .7402 L F
.78 .788 .859 r
.76481 .61749 m .76764 .61789 L .76594 .61568 L F
.575 .715 .937 r
.76594 .61568 m .76764 .61789 L .77003 .61746 L F
.922 .889 .782 r
.53129 .80684 m .53483 .80369 L .53211 .80486 L F
.247 0 .018 r
.2492 .59223 m .25122 .59168 L .25264 .58985 L F
.213 0 0 r
.25264 .58985 m .25315 .59109 L .25475 .58947 L F
.25264 .58985 m .25122 .59168 L .25315 .59109 L F
.487 .268 .507 r
.32953 .60949 m .33165 .60902 L .33187 .60662 L F
.588 .583 .814 r
.33093 .6035 m .33187 .60662 L .33403 .60602 L F
.597 .362 .53 r
.33187 .60662 m .33419 .60857 L .33403 .60602 L F
.33187 .60662 m .33165 .60902 L .33419 .60857 L F
.696 .361 .405 r
.49763 .78165 m .49419 .78015 L .49773 .77959 L F
.766 .55 .606 r
.64618 .51415 m .64194 .51487 L .6425 .51175 L F
.212 0 0 r
.64618 .51415 m .64493 .5149 L .64194 .51487 L F
.227 0 0 r
.64618 .51415 m .64708 .5147 L .64493 .5149 L F
.431 .186 .439 r
.59091 .74076 m .59332 .74044 L .59348 .73809 L F
.49 .435 .723 r
.59344 .74257 m .59332 .74044 L .59091 .74076 L F
0 0 .166 r
.56205 .78749 m .56216 .78499 L .56261 .78485 L F
.709 .883 .962 r
.75399 .58776 m .75814 .58743 L .75744 .58717 L F
.557 .934 .846 r
.75971 .5861 m .75814 .58743 L .76029 .58622 L F
.568 .932 .929 r
.75971 .5861 m .75744 .58717 L .75814 .58743 L F
.667 .48 .623 r
.64759 .53384 m .6446 .53426 L .64414 .53109 L F
.29 0 .091 r
.53058 .76477 m .52836 .76543 L .52975 .76373 L F
.232 .19 .603 r
.59117 .70621 m .59258 .70313 L .59032 .70573 L F
.685 .514 .649 r
.62922 .50558 m .62662 .50597 L .62898 .50274 L F
0 0 0 r
.62662 .50597 m .62807 .50478 L .62898 .50274 L F
.62898 .50274 m .62997 .50338 L .63124 .50197 L F
.62898 .50274 m .62807 .50478 L .62997 .50338 L F
.946 .717 .251 r
.57267 .75905 m .57316 .75737 L .57233 .75661 L F
.57267 .75905 m .57317 .75996 L .57316 .75737 L F
.154 .36 .815 r
.59348 .73809 m .59443 .73688 L .59173 .73529 L F
.199 .427 .856 r
.59348 .73809 m .59511 .73829 L .59443 .73688 L F
.294 .077 .405 r
.59348 .73809 m .59332 .74044 L .59511 .73829 L F
.96 .66 .237 r
.57137 .75105 m .57248 .75417 L .57214 .75204 L F
.321 .056 .346 r
.27534 .6171 m .27302 .62003 L .27323 .6176 L F
.494 .345 .608 r
.40796 .66993 m .40572 .66773 L .40932 .66829 L F
0 0 0 r
.40976 .66882 m .40932 .66829 L .41148 .66793 L F
.40976 .66882 m .40796 .66993 L .40932 .66829 L F
.585 .323 .486 r
.51174 .80967 m .50949 .80771 L .50936 .8095 L F
.663 .291 .33 r
.51174 .80967 m .51312 .80824 L .50949 .80771 L F
.364 0 .169 r
.527 .75927 m .52919 .75875 L .5306 .75637 L F
.35 0 .161 r
.5306 .75637 m .53173 .75797 L .53283 .75655 L F
.5306 .75637 m .52919 .75875 L .53173 .75797 L F
0 .155 .685 r
.591 .72908 m .58975 .72579 L .59154 .72694 L F
.961 .856 .692 r
.57688 .72051 m .5764 .72299 L .5781 .72368 L F
.815 .629 .651 r
.57642 .7265 m .5781 .72368 L .5764 .72299 L F
.751 .718 .821 r
.57688 .72051 m .5781 .72368 L .58033 .72099 L F
.714 .62 .751 r
.56296 .77888 m .56591 .77608 L .56431 .77725 L F
.734 .211 0 r
.5598 .71931 m .55869 .71977 L .55668 .71759 L F
.517 0 0 r
.5598 .71931 m .56192 .72043 L .55869 .71977 L F
.48 0 0 r
.56357 .72074 m .56192 .72043 L .5598 .71931 L F
.485 .581 .876 r
.38258 .71897 m .38353 .71676 L .38111 .71773 L F
.38258 .71897 m .38422 .7187 L .38353 .71676 L F
.277 0 0 r
.38258 .71897 m .38334 .71915 L .38422 .7187 L F
.46 .389 .69 r
.4889 .66234 m .48725 .66481 L .48576 .66193 L F
.4889 .66234 m .48918 .66483 L .48725 .66481 L F
.594 .627 .854 r
.49029 .66602 m .48725 .66481 L .48918 .66483 L F
.239 0 .217 r
.24151 .59758 m .24423 .59464 L .24221 .59554 L F
.451 .785 .998 r
.65207 .51409 m .65313 .51294 L .65082 .51322 L F
.295 .55 .922 r
.65207 .51409 m .65405 .51463 L .65313 .51294 L F
1 .82 .507 r
.59173 .73529 m .59083 .73399 L .59203 .73232 L F
.835 .53 0 r
.59203 .73232 m .59164 .73178 L .591 .72908 L F
.945 .909 .528 r
.59083 .73399 m .59164 .73178 L .59203 .73232 L F
.807 .857 .886 r
.74673 .58972 m .74418 .59196 L .74359 .59002 L F
.641 .639 .833 r
.47188 .65086 m .46963 .65151 L .4682 .64863 L F
.309 .758 .959 r
.28904 .58646 m .29112 .58632 L .29273 .58685 L F
.192 .626 .946 r
.29314 .58614 m .29273 .58685 L .29112 .58632 L F
.29314 .58614 m .29472 .58713 L .29273 .58685 L F
.283 .278 .676 r
.5031 .79027 m .5036 .79372 L .50448 .7908 L F
.885 .485 .042 r
.53307 .74343 m .5324 .74362 L .53219 .74129 L F
.53307 .74343 m .5324 .74362 L .53219 .74129 L F
.288 .359 .762 r
.64884 .53273 m .64996 .53593 L .64767 .53423 L F
.664 .248 .247 r
.64767 .53423 m .64996 .53593 L .64666 .53566 L F
0 0 0 r
.5082 .81537 m .51066 .8143 L .50949 .81524 L F
.166 0 0 r
.50949 .81524 m .51066 .8143 L .51337 .81418 L F
0 0 0 r
.5082 .81537 m .50949 .81524 L .50722 .81541 L F
.449 .475 .794 r
.27457 .63078 m .27403 .63432 L .27277 .63096 L F
.27457 .63078 m .27583 .63427 L .27403 .63432 L F
.263 .019 .344 r
.62632 .54263 m .62584 .54456 L .62793 .54165 L F
.765 .675 .763 r
.51074 .78543 m .50837 .78841 L .50774 .78491 L F
0 0 0 r
.50693 .7904 m .50837 .78841 L .50999 .78745 L F
.51114 .78809 m .50999 .78745 L .50941 .78695 L F
.676 .518 .663 r
.51161 .78856 m .51334 .78986 L .51026 .79013 L F
.51241 .78764 m .51328 .78973 L .51161 .78856 L F
.51328 .78973 m .51334 .78986 L .51161 .78856 L F
0 0 0 r
.51208 .78871 m .51241 .78764 L .51161 .78856 L F
.51208 .78871 m .51161 .78856 L .51026 .79013 L F
.51208 .78871 m .51028 .78763 L .51114 .78809 L F
.51028 .78763 m .50999 .78745 L .51019 .78756 L F
.51028 .78763 m .51019 .78756 L .51114 .78809 L F
.115 0 .202 r
.50999 .78745 m .50837 .78841 L .50939 .78712 L F
.50999 .78745 m .50939 .78712 L .51074 .78543 L F
.537 .108 .173 r
.47472 .68749 m .47338 .68923 L .4712 .68811 L F
.676 .268 .265 r
.47689 .68937 m .47338 .68923 L .47472 .68749 L F
.637 .295 .375 r
.477 .68777 m .47689 .68937 L .47472 .68749 L F
.39 .141 .412 r
.62759 .56212 m .62701 .56407 L .62517 .56484 L F
.098 0 .272 r
.629 .56307 m .62759 .56212 L .62947 .56123 L F
.629 .56307 m .62701 .56407 L .62759 .56212 L F
.788 .607 .656 r
.49113 .80714 m .49508 .8051 L .49097 .80478 L F
.49113 .80714 m .49448 .80761 L .49508 .8051 L F
.956 .832 .68 r
.59622 .70346 m .59831 .70137 L .5961 .70087 L F
.59622 .70346 m .59752 .70422 L .59831 .70137 L F
.303 .438 .832 r
.46913 .79669 m .4723 .7984 L .47047 .79543 L F
.982 .713 .328 r
.54808 .79013 m .54901 .79113 L .54899 .79405 L F
.679 .199 .104 r
.54901 .79113 m .55315 .79486 L .54899 .79405 L F
.511 .298 .527 r
.32086 .62322 m .32294 .62285 L .32321 .62046 L F
.567 .391 .603 r
.32294 .62285 m .32524 .6199 L .32321 .62046 L F
.372 0 0 r
.53542 .77975 m .5365 .78095 L .53416 .78112 L F
.53542 .77975 m .53786 .7797 L .5365 .78095 L F
.053 .283 .774 r
.73538 .59221 m .73698 .59527 L .73749 .59394 L F
.73 .888 .492 r
.73749 .59394 m .73698 .59527 L .73575 .59692 L F
0 0 0 r
.5632 .69342 m .56223 .69513 L .5609 .69601 L F
.546 .296 .489 r
.55939 .69505 m .56097 .69662 L .56144 .69585 L F
.512 .332 .574 r
.56287 .69808 m .56087 .69866 L .5609 .69601 L F
.546 .296 .489 r
.56097 .69662 m .5613 .69695 L .56141 .6961 L F
.671 .209 .148 r
.56513 .69504 m .56221 .69517 L .5632 .69342 L F
.56513 .69504 m .56221 .69517 L .5632 .69342 L F
.83 .774 .8 r
.56513 .69504 m .56229 .69566 L .56403 .69453 L F
.512 .332 .574 r
.56229 .69566 m .5609 .69601 L .56217 .69519 L F
.83 .774 .8 r
.56229 .69566 m .56144 .69585 L .56231 .69561 L F
.512 .332 .574 r
.56287 .69808 m .56174 .6969 L .56229 .69566 L F
.83 .774 .8 r
.56513 .69504 m .56287 .69808 L .56229 .69566 L F
.512 .332 .574 r
.56287 .69808 m .56217 .69519 L .56221 .69517 L F
.83 .774 .8 r
.56229 .69566 m .56287 .69808 L .56144 .69585 L F
.806 .769 .819 r
.56144 .69585 m .56287 .69808 L .56231 .69561 L F
.56144 .69585 m .56231 .69561 L .56221 .69517 L F
.83 .774 .8 r
.56231 .69561 m .56144 .69585 L .56243 .69535 L F
.56229 .69566 m .56243 .69535 L .56403 .69453 L F
.512 .332 .574 r
.56174 .6969 m .5609 .69601 L .56229 .69566 L F
.546 .296 .489 r
.56097 .69662 m .56141 .6961 L .56144 .69585 L F
0 0 0 r
.56223 .69513 m .56221 .69517 L .56219 .69518 L F
.56223 .69513 m .56219 .69518 L .5609 .69601 L F
.445 0 .056 r
.5198 .81271 m .52183 .81261 L .51881 .8134 L F
.877 .473 .255 r
.47657 .78558 m .47832 .7857 L .479 .78755 L F
.789 .608 .656 r
.48047 .78498 m .479 .78755 L .47832 .7857 L F
.616 .248 .321 r
.48097 .7939 m .48296 .79566 L .48068 .7965 L F
.48097 .7939 m .48301 .7941 L .48296 .79566 L F
.583 .479 .701 r
.36797 .66546 m .37015 .66495 L .36973 .66263 L F
.517 .427 .692 r
.36797 .66546 m .37039 .66739 L .37015 .66495 L F
.36797 .66546 m .3684 .66777 L .37039 .66739 L F
.481 .303 .563 r
.31885 .62662 m .32083 .62605 L .32086 .62322 L F
.323 .022 .29 r
.31885 .62662 m .32009 .62769 L .32083 .62605 L F
.31885 .62662 m .31817 .6284 L .32009 .62769 L F
0 0 .019 r
.64377 .49427 m .64392 .49406 L .64415 .49173 L F
.625 .539 .737 r
.49389 .67069 m .49533 .67381 L .49364 .67379 L F
.555 .152 .232 r
.49501 .67502 m .49364 .67379 L .49533 .67381 L F
.49501 .67502 m .49111 .67613 L .49364 .67379 L F
.566 .479 .716 r
.37686 .70717 m .37865 .70416 L .37641 .7049 L F
.37686 .70717 m .37951 .70689 L .37865 .70416 L F
.362 .111 .393 r
.62276 .56761 m .62517 .56484 L .62469 .56684 L F
.263 0 .293 r
.62701 .56407 m .62469 .56684 L .62517 .56484 L F
.503 .178 .349 r
.53449 .72594 m .53714 .7241 L .53484 .72415 L F
.862 .687 .665 r
.602 .73261 m .60038 .72962 L .59986 .73198 L F
.874 .655 .602 r
.59989 .73424 m .602 .73261 L .59986 .73198 L F
.59989 .73424 m .60158 .73501 L .602 .73261 L F
0 .278 .747 r
.77414 .58968 m .77401 .58908 L .77304 .58843 L F
.77414 .58968 m .77487 .59002 L .77401 .58908 L F
.257 0 .163 r
.53266 .72693 m .52989 .7292 L .53297 .72786 L F
.245 0 .166 r
.53266 .72693 m .53341 .72745 L .53449 .72594 L F
.53266 .72693 m .53297 .72786 L .53341 .72745 L F
.91 .897 .803 r
.5664 .77935 m .56969 .77695 L .56893 .77651 L F
.5664 .77935 m .56759 .7802 L .56969 .77695 L F
.765 .494 0 r
.56969 .77695 m .56888 .77373 L .56893 .77651 L F
.691 .711 .864 r
.69282 .49133 m .69413 .49317 L .69624 .49201 L F
.792 .576 .608 r
.63938 .51385 m .64194 .51487 L .6425 .51175 L F
0 0 .258 r
.6425 .51175 m .64347 .51242 L .64414 .51091 L F
.64249 .51177 m .64194 .51487 L .64284 .51343 L F
.738 .659 .772 r
.63938 .51385 m .64028 .51659 L .64194 .51487 L F
0 0 .258 r
.64249 .51177 m .64284 .51343 L .64347 .51242 L F
.698 .83 .946 r
.64347 .51242 m .64194 .51487 L .64184 .5135 L F
.325 .119 .439 r
.64465 .51423 m .64194 .51487 L .64493 .5149 L F
.64465 .51423 m .64244 .51594 L .64194 .51487 L F
.518 .529 .806 r
.64244 .51594 m .63938 .51385 L .64184 .5135 L F
.609 .178 .198 r
.64184 .5135 m .64068 .51482 L .64306 .51447 L F
.64292 .51378 m .64306 .51447 L .64465 .51423 L F
.64184 .5135 m .64306 .51447 L .64292 .51378 L F
0 0 .258 r
.6425 .51175 m .64249 .51177 L .64347 .51242 L F
.456 0 .059 r
.39641 .65171 m .39836 .65243 L .39979 .65094 L F
.46 0 .067 r
.39836 .65243 m .40206 .65097 L .39979 .65094 L F
.672 .465 .597 r
.51873 .732 m .52123 .73206 L .52107 .72938 L F
.653 .523 .693 r
.55405 .73861 m .55597 .74068 L .55313 .74038 L F
.652 .393 .515 r
.55313 .74038 m .55546 .74279 L .55597 .74068 L F
.653 .523 .693 r
.55313 .74038 m .55597 .74068 L .55405 .73861 L F
.652 .393 .515 r
.55597 .74068 m .55546 .74279 L .55313 .74038 L F
.653 .523 .693 r
.55313 .74038 m .55597 .74068 L .55405 .73861 L F
.581 .901 .984 r
.43989 .64863 m .44071 .64737 L .44208 .64779 L F
.579 .899 .985 r
.43989 .64863 m .43861 .64817 L .44071 .64737 L F
.091 0 .2 r
.50968 .76618 m .50904 .76793 L .5111 .76559 L F
.572 .392 .599 r
.62276 .56761 m .62296 .56996 L .6206 .57041 L F
.386 .255 .578 r
.62466 .56917 m .62276 .56761 L .62469 .56684 L F
.62466 .56917 m .62296 .56996 L .62276 .56761 L F
.001 .008 .509 r
.59 .69217 m .59082 .69186 L .59048 .68968 L F
.244 0 .009 r
.59082 .69186 m .59367 .6899 L .59048 .68968 L F
.59082 .69186 m .59226 .69182 L .59367 .6899 L F
.215 .66 .951 r
.59011 .69104 m .59161 .69158 L .59082 .69186 L F
.59161 .69158 m .59226 .69182 L .59082 .69186 L F
.001 .008 .509 r
.58981 .69317 m .59082 .69186 L .59 .69217 L F
.016 .03 .528 r
.58981 .69317 m .59125 .69608 L .59082 .69186 L F
.375 .119 .393 r
.55504 .69614 m .55258 .69877 L .55463 .69816 L F
.453 .257 .522 r
.5524 .70109 m .55463 .69816 L .55258 .69877 L F
.779 .746 .823 r
.49038 .7497 m .49429 .74946 L .4927 .74874 L F
.787 .9 .922 r
.4927 .74874 m .49429 .74946 L .49437 .74732 L F
0 0 0 r
.49855 .74394 m .49758 .74577 L .49612 .74626 L F
.622 .41 .573 r
.46886 .6763 m .47134 .67615 L .4714 .67378 L F
.561 .36 .566 r
.4714 .67378 m .47366 .67544 L .47423 .67318 L F
.4714 .67378 m .47134 .67615 L .47366 .67544 L F
.576 .405 .612 r
.62296 .56996 m .62068 .57281 L .6206 .57041 L F
.738 .636 .746 r
.58714 .55314 m .58843 .55644 L .5848 .55601 L F
.745 .595 .689 r
.5848 .55601 m .58843 .55644 L .58666 .55931 L F
.648 .257 .29 r
.48581 .80827 m .4872 .8079 L .4855 .80947 L F
.937 .728 .594 r
.4872 .8079 m .48695 .80931 L .4855 .80947 L F
.225 0 .18 r
.70392 .52824 m .7013 .53048 L .70195 .52905 L F
.193 .716 .865 r
.30129 .63473 m .30309 .63461 L .30611 .63492 L F
.505 .885 .968 r
.30611 .63492 m .30671 .63393 L .30788 .63387 L F
.30611 .63492 m .30309 .63461 L .30671 .63393 L F
.473 .205 .426 r
.55504 .69614 m .5568 .69771 L .55761 .69516 L F
.55504 .69614 m .55463 .69816 L .5568 .69771 L F
.491 .409 .69 r
.33016 .61178 m .33165 .60902 L .32953 .60949 L F
.697 .932 .966 r
.58969 .71419 m .58892 .71369 L .59055 .71273 L F
.938 .857 .427 r
.59055 .71273 m .59017 .71237 L .59061 .70942 L F
.83 .994 .753 r
.58892 .71369 m .59017 .71237 L .59055 .71273 L F
.307 .779 .932 r
.43277 .64867 m .43637 .64873 L .43414 .64911 L F
.321 .809 .848 r
.51414 .81403 m .5168 .81394 L .51881 .8134 L F
0 0 0 r
.47419 .64581 m .47267 .64675 L .47341 .64641 L F
.698 .777 .913 r
.46518 .64597 m .46267 .64745 L .46147 .64566 L F
.822 .656 .677 r
.50481 .68916 m .50289 .69022 L .50339 .68729 L F
.712 .428 .494 r
.50481 .68916 m .50315 .69239 L .50289 .69022 L F
.573 .119 0 r
.50339 .68729 m .50518 .68967 L .50481 .68916 L F
.563 .384 .597 r
.50518 .68967 m .50315 .69239 L .50481 .68916 L F
.116 0 0 r
.68495 .53097 m .68403 .53134 L .68314 .52983 L F
.628 .956 .922 r
.68684 .53083 m .68392 .53268 L .68403 .53134 L F
.116 0 0 r
.68588 .53156 m .68684 .53083 L .68403 .53134 L F
.68588 .53156 m .68479 .53143 L .68495 .53097 L F
.68479 .53143 m .68403 .53134 L .68495 .53097 L F
.628 .956 .922 r
.68684 .53083 m .68731 .53121 L .68443 .53246 L F
.68447 .53233 m .68443 .53246 L .68392 .53268 L F
.68684 .53083 m .68443 .53246 L .68447 .53233 L F
.165 0 .299 r
.69017 .52777 m .68731 .53121 L .6888 .52969 L F
.62 .952 .924 r
.6888 .52969 m .68731 .53121 L .68684 .53083 L F
.535 .135 .229 r
.49369 .75366 m .49604 .75368 L .49732 .75167 L F
.562 .155 .228 r
.49604 .75368 m .49961 .75205 L .49732 .75167 L F
.472 .215 .443 r
.39586 .67373 m .39547 .67585 L .39335 .67629 L F
.541 .276 .463 r
.39786 .67549 m .39586 .67373 L .39802 .67335 L F
.39786 .67549 m .39547 .67585 L .39586 .67373 L F
.462 .242 .493 r
.32524 .6199 m .32751 .61755 L .32566 .61798 L F
.474 .278 .534 r
.32083 .62605 m .32294 .62285 L .32086 .62322 L F
.491 .409 .69 r
.33016 .61178 m .332 .61141 L .33165 .60902 L F
.397 .262 .578 r
.33015 .61456 m .332 .61141 L .33016 .61178 L F
.419 0 .027 r
.55939 .69505 m .56221 .69517 L .5632 .69342 L F
.671 .209 .148 r
.56513 .69504 m .5632 .69342 L .56512 .69266 L F
.56513 .69504 m .5632 .69342 L .56512 .69266 L F
.302 .261 .645 r
.50458 .79031 m .5031 .79027 L .50448 .7908 L F
.581 .526 .758 r
.73245 .60342 m .73413 .60079 L .73185 .60128 L F
.73245 .60342 m .73518 .60432 L .73413 .60079 L F
.738 .779 .886 r
.67785 .48936 m .67926 .49244 L .68069 .49096 L F
.696 .361 .405 r
.49763 .78165 m .4942 .78191 L .49419 .78015 L F
.97 .849 .666 r
.62466 .49648 m .62487 .49496 L .62488 .49574 L F
.149 .054 .483 r
.62765 .49258 m .62466 .49648 L .62488 .49574 L F
.387 .81 .971 r
.27992 .58487 m .28211 .58455 L .28336 .58498 L F
.015 .479 .873 r
.28402 .58457 m .28336 .58498 L .28211 .58455 L F
.28402 .58457 m .28552 .58571 L .28336 .58498 L F
.586 .722 .938 r
.52764 .80401 m .52691 .80602 L .5254 .80436 L F
.52764 .80401 m .52842 .80579 L .52691 .80602 L F
.785 .874 .442 r
.59036 .69874 m .59125 .69608 L .59284 .6969 L F
.178 .318 .769 r
.5937 .69491 m .59284 .6969 L .59125 .69608 L F
.5937 .69491 m .59475 .6979 L .59284 .6969 L F
.661 .842 .969 r
.77788 .60058 m .78114 .6009 L .77996 .5998 L F
.931 .933 .781 r
.78114 .6009 m .78199 .5971 L .77996 .5998 L F
.377 .503 .859 r
.69433 .52071 m .6971 .52232 L .69672 .51997 L F
.635 .578 .773 r
.6275 .52121 m .62348 .51957 L .62687 .52048 L F
.671 .184 .086 r
.62687 .52048 m .62905 .52218 L .6275 .52121 L F
.713 .277 .213 r
.50941 .78695 m .51074 .78543 L .50774 .78491 L F
.999 .843 .528 r
.50999 .78745 m .51074 .78543 L .50941 .78695 L F
.494 .103 .228 r
.61313 .55269 m .61566 .55239 L .61594 .55102 L F
.199 0 0 r
.61594 .55102 m .61832 .55057 L .61901 .55006 L F
.366 0 .195 r
.61594 .55102 m .61566 .55239 L .61832 .55057 L F
.233 0 0 r
.41814 .70773 m .41752 .70654 L .41974 .70599 L F
.41814 .70773 m .416 .70824 L .41752 .70654 L F
.63 .101 0 r
.71021 .50176 m .7124 .50285 L .70952 .50219 L F
.997 .768 .452 r
.71021 .50176 m .70952 .50219 L .70922 .49978 L F
0 0 .358 r
.66523 .51716 m .66636 .51924 L .66594 .51839 L F
.66523 .51716 m .66594 .51839 L .66354 .51637 L F
0 0 0 r
.49925 .74472 m .49855 .74394 L .5006 .74318 L F
.49925 .74472 m .49758 .74577 L .49855 .74394 L F
.735 .654 .769 r
.51819 .76822 m .52135 .76894 L .5203 .76576 L F
.608 .581 .798 r
.5203 .76576 m .52135 .76894 L .52368 .76832 L F
.571 .467 .697 r
.52135 .76894 m .52369 .77086 L .52368 .76832 L F
.52135 .76894 m .52186 .77173 L .52369 .77086 L F
.992 .746 .389 r
.3634 .70391 m .36249 .70497 L .36251 .70513 L F
.898 .896 .48 r
.3634 .70391 m .36251 .70513 L .36434 .70157 L F
.094 0 .079 r
.36434 .70157 m .3634 .70391 L .36604 .701 L F
.36434 .70157 m .36503 .70274 L .3634 .70391 L F
.992 .746 .389 r
.3634 .70391 m .36331 .70559 L .36262 .70506 L F
.554 .316 .508 r
.36249 .70497 m .3626 .70505 L .36251 .70513 L F
.094 0 .079 r
.36269 .70479 m .36251 .70513 L .3626 .70505 L F
.992 .746 .389 r
.36272 .70469 m .36257 .70513 L .36249 .70497 L F
.284 .331 .735 r
.36503 .70274 m .36583 .70581 L .3634 .70391 L F
.094 0 .079 r
.36269 .70479 m .3626 .70505 L .36503 .70274 L F
.554 .316 .508 r
.36249 .70497 m .36503 .70274 L .3626 .70505 L F
.992 .746 .389 r
.36262 .70506 m .36326 .70644 L .36257 .70513 L F
.36331 .70559 m .36326 .70644 L .36262 .70506 L F
.3634 .70391 m .36257 .70513 L .36272 .70469 L F
.094 0 .079 r
.36434 .70157 m .36269 .70479 L .36503 .70274 L F
.972 .698 .454 r
.5702 .6906 m .5684 .68979 L .56875 .68693 L F
.765 .488 .515 r
.5702 .6906 m .56712 .69224 L .56824 .68971 L F
.012 0 .304 r
.56835 .69026 m .56876 .69142 L .56907 .68911 L F
.56712 .69224 m .5682 .6917 L .56835 .69026 L F
.5682 .6917 m .56876 .69142 L .56835 .69026 L F
.972 .698 .454 r
.5684 .68979 m .56824 .68971 L .56862 .68763 L F
.5684 .68979 m .56862 .68763 L .56875 .68693 L F
.765 .488 .515 r
.5702 .6906 m .57055 .69288 L .56712 .69224 L F
.752 .316 .217 r
.5352 .77313 m .53886 .77394 L .53619 .77174 L F
.667 .586 .755 r
.7075 .51193 m .70951 .51251 L .70877 .51121 L F
0 0 0 r
.70877 .51121 m .71069 .51005 L .71134 .5085 L F
.411 .398 .734 r
.70951 .51251 m .71069 .51005 L .70877 .51121 L F
.065 0 0 r
.38342 .65497 m .38515 .65403 L .38295 .65444 L F
.571 .851 .996 r
.7654 .6097 m .76778 .60902 L .76873 .60981 L F
.834 .927 .894 r
.76873 .60981 m .76778 .60902 L .77061 .60666 L F
.935 .882 .758 r
.58947 .54802 m .58719 .54986 L .58838 .54709 L F
.58947 .54802 m .58762 .55076 L .58719 .54986 L F
.909 .946 .594 r
.55275 .73552 m .55146 .7372 L .55168 .7376 L F
.55275 .73552 m .55146 .7372 L .55168 .7376 L F
.019 0 0 r
.55303 .73646 m .55146 .7372 L .55275 .73552 L F
.175 0 0 r
.25688 .58913 m .25891 .58859 L .2606 .58702 L F
.365 0 .032 r
.25891 .58859 m .2627 .58667 L .2606 .58702 L F
.561 .795 .987 r
.35051 .59457 m .34969 .59604 L .34837 .59491 L F
.35051 .59457 m .3519 .59553 L .34969 .59604 L F
.591 .728 .939 r
.26258 .6508 m .26597 .6517 L .2646 .65039 L F
.556 .716 .947 r
.26597 .6517 m .26673 .64985 L .2646 .65039 L F
.26597 .6517 m .26819 .65139 L .26673 .64985 L F
.512 .498 .777 r
.55771 .73996 m .55597 .74068 L .55405 .73861 L F
.55405 .73861 m .55597 .74068 L .55771 .73996 L F
.751 .595 .683 r
.4974 .67364 m .49389 .67069 L .49621 .67015 L F
.4974 .67364 m .49533 .67381 L .49389 .67069 L F
.274 .49 .885 r
.49511 .67627 m .49533 .67381 L .4974 .67364 L F
.61 .409 .585 r
.4974 .67364 m .49746 .6761 L .49511 .67627 L F
.594 .594 .822 r
.49839 .66977 m .4974 .67364 L .49621 .67015 L F
.49839 .66977 m .50052 .6737 L .4974 .67364 L F
.357 .049 .297 r
.50052 .6737 m .49746 .6761 L .4974 .67364 L F
.838 .382 .127 r
.55915 .73533 m .56018 .73692 L .5616 .73718 L F
.764 .257 0 r
.56018 .73692 m .56387 .73961 L .5616 .73718 L F
.959 .947 .688 r
.67868 .5306 m .67994 .52819 L .67928 .52727 L F
.501 .286 .519 r
.68108 .52962 m .67994 .52819 L .67868 .5306 L F
.418 .732 .99 r
.48369 .67641 m .48467 .67523 L .48258 .67545 L F
0 0 .057 r
.48369 .67641 m .48446 .67641 L .48467 .67523 L F
.48369 .67641 m .48311 .67818 L .48446 .67641 L F
.215 .703 .925 r
.44208 .64779 m .44422 .6478 L .44558 .64828 L F
.199 .716 .879 r
.44422 .6478 m .44776 .64792 L .44558 .64828 L F
.61 .453 .644 r
.54581 .70702 m .54784 .70446 L .54701 .70705 L F
.54581 .70702 m .54888 .70819 L .54784 .70446 L F
.571 .338 .523 r
.54581 .70702 m .54818 .70885 L .54888 .70819 L F
.54581 .70702 m .5456 .70956 L .54818 .70885 L F
.55 .282 .463 r
.59902 .57873 m .59917 .58014 L .59659 .58021 L F
.589 .31 .461 r
.59902 .57873 m .60135 .5805 L .59917 .58014 L F
.615 .296 .406 r
.60088 .5788 m .60135 .5805 L .59902 .57873 L F
.327 0 0 r
.41951 .69467 m .42181 .69459 L .42346 .69344 L F
.407 0 .046 r
.42181 .69459 m .42551 .69283 L .42346 .69344 L F
.419 0 .118 r
.47963 .80218 m .4841 .79974 L .48361 .79687 L F
.47963 .80218 m .48264 .80142 L .4841 .79974 L F
.712 .335 .333 r
.4841 .79974 m .48264 .80142 L .48451 .80112 L F
.553 .744 .966 r
.69058 .49176 m .69177 .48999 L .689 .48969 L F
.69058 .49176 m .69282 .49133 L .69177 .48999 L F
.544 .429 .673 r
.27078 .62333 m .27119 .6257 L .26913 .62617 L F
.644 .764 .936 r
.49253 .66538 m .49029 .66602 L .48918 .66483 L F
.785 .874 .442 r
.59036 .69874 m .59058 .69764 L .59125 .69608 L F
.791 .892 .477 r
.59036 .69874 m .58922 .70037 L .59058 .69764 L F
.72 .194 0 r
.59036 .69874 m .59141 .70072 L .58922 .70037 L F
.59036 .69874 m .59321 .70111 L .59141 .70072 L F
.487 .074 .182 r
.4173 .66531 m .41587 .66737 L .4136 .66731 L F
.5 .088 .19 r
.41859 .66649 m .4173 .66531 L .41934 .66473 L F
.41859 .66649 m .41587 .66737 L .4173 .66531 L F
.26 .77 .807 r
.71953 .51963 m .71644 .52016 L .71726 .5205 L F
.549 .593 .851 r
.69997 .49393 m .70095 .49078 L .69862 .49128 L F
.69997 .49393 m .70206 .49365 L .70095 .49078 L F
.575 .141 .179 r
.35246 .70408 m .35497 .70362 L .35585 .70315 L F
.835 .563 .526 r
.35497 .70362 m .35651 .70479 L .35585 .70315 L F
.679 .627 .79 r
.46986 .66772 m .47334 .67015 L .4721 .66721 L F
.622 .64 .847 r
.4721 .66721 m .47334 .67015 L .47519 .66833 L F
.647 .602 .79 r
.47334 .67015 m .47503 .66983 L .47519 .66833 L F
.47334 .67015 m .47604 .67061 L .47503 .66983 L F
.587 .731 .943 r
.66984 .4899 m .67185 .49022 L .67212 .4892 L F
.586 .679 .905 r
.67185 .49022 m .67431 .48871 L .67212 .4892 L F
.67185 .49022 m .67563 .4913 L .67431 .48871 L F
.951 .599 .246 r
.49458 .76187 m .49606 .76283 L .49465 .75974 L F
.61 .859 .503 r
.49445 .76461 m .49606 .76283 L .49458 .76187 L F
0 0 .331 r
.49553 .76313 m .49458 .76187 L .49529 .76075 L F
.49557 .76363 m .49539 .76331 L .49553 .76313 L F
.49539 .76331 m .49458 .76187 L .49553 .76313 L F
.49507 .76274 m .49445 .76461 L .49458 .76187 L F
0 0 .333 r
.49497 .76315 m .49511 .76212 L .49253 .76063 L F
.49511 .76212 m .49529 .76075 L .4952 .76075 L F
.951 .599 .246 r
.49458 .76187 m .49465 .75974 L .49279 .75969 L F
.095 .648 .81 r
.49465 .75974 m .49502 .75966 L .49279 .75969 L F
.498 .263 .488 r
.49502 .75966 m .49458 .76187 L .49279 .75969 L F
0 0 .17 r
.49529 .76075 m .49458 .76187 L .49502 .75966 L F
0 0 .333 r
.49511 .76212 m .4952 .76075 L .49253 .76063 L F
0 0 .331 r
.49539 .76331 m .495 .76386 L .49507 .76274 L F
.495 .76386 m .49445 .76461 L .49507 .76274 L F
.61 .859 .503 r
.49445 .76461 m .49405 .76517 L .49606 .76283 L F
0 0 .331 r
.49557 .76363 m .49445 .76461 L .49539 .76331 L F
.61 .859 .503 r
.49445 .76461 m .49388 .76537 L .49405 .76517 L F
.49388 .76537 m .49382 .76544 L .49383 .76542 L F
.49388 .76537 m .49383 .76542 L .49606 .76283 L F
.825 .527 .485 r
.49606 .76283 m .49382 .76544 L .49756 .76515 L F
.531 .211 .37 r
.54442 .77297 m .54219 .7714 L .54266 .77303 L F
.54442 .77297 m .54462 .77126 L .54219 .7714 L F
.291 .131 .485 r
.48759 .74649 m .48902 .74798 L .48978 .74609 L F
.48759 .74649 m .48755 .7491 L .48902 .74798 L F
.575 .467 .693 r
.73145 .59773 m .73413 .60079 L .73329 .59722 L F
.73145 .59773 m .73185 .60128 L .73413 .60079 L F
.788 .555 .584 r
.56743 .76566 m .56834 .76836 L .56619 .76937 L F
0 0 .458 r
.66009 .50385 m .66113 .50536 L .65933 .50249 L F
.777 .591 .648 r
.6246 .52266 m .62098 .5199 L .62348 .51957 L F
.6246 .52266 m .62116 .52255 L .62098 .5199 L F
.028 .598 .752 r
.6246 .52266 m .62361 .52259 L .62116 .52255 L F
.635 .578 .773 r
.6275 .52121 m .6246 .52266 L .62348 .51957 L F
.233 0 0 r
.6275 .52121 m .62361 .52259 L .6246 .52266 L F
.614 .789 .965 r
.67107 .488 m .66984 .4899 L .67212 .4892 L F
.399 .162 .435 r
.54089 .75182 m .54276 .75136 L .54318 .74908 L F
.539 .402 .642 r
.54318 .74908 m .54556 .74869 L .54507 .74605 L F
.491 .243 .465 r
.54318 .74908 m .54276 .75136 L .54556 .74869 L F
.602 .785 .968 r
.77003 .61746 m .77359 .61809 L .77245 .61697 L F
.738 .896 .95 r
.77359 .61809 m .77474 .61587 L .77245 .61697 L F
.77359 .61809 m .77561 .6168 L .77474 .61587 L F
.801 .758 .814 r
.71731 .50028 m .71624 .50293 L .71922 .50319 L F
.541 .737 .966 r
.71922 .50319 m .72079 .50146 L .71731 .50028 L F
.71922 .50319 m .72151 .50286 L .72079 .50146 L F
.549 .342 .553 r
.46087 .67913 m .4632 .67875 L .46315 .67636 L F
.307 0 .172 r
.4632 .67875 m .4663 .67616 L .46315 .67636 L F
.134 0 .207 r
.63619 .50009 m .63851 .49933 L .63912 .49701 L F
.445 .064 .222 r
.63595 .5007 m .63851 .49933 L .63619 .50009 L F
.087 0 .32 r
.62198 .49991 m .62041 .5032 L .62099 .50083 L F
.988 .831 .599 r
.57281 .76567 m .57125 .7673 L .57217 .7676 L F
.72 .924 .584 r
.57266 .76551 m .57125 .7673 L .57281 .76567 L F
.87 .917 .858 r
.65359 .53891 m .65226 .5426 L .65434 .54188 L F
.65359 .53891 m .6514 .54168 L .65226 .5426 L F
.555 .662 .908 r
.67431 .48871 m .67563 .4913 L .67785 .48936 L F
.641 .385 .515 r
.53756 .75428 m .54088 .75434 L .54089 .75182 L F
.456 .316 .602 r
.54089 .75182 m .543 .75376 L .54276 .75136 L F
.551 .313 .508 r
.54089 .75182 m .54088 .75434 L .543 .75376 L F
.542 .232 .392 r
.45484 .69034 m .45406 .69251 L .45177 .69264 L F
.394 .09 .326 r
.4562 .69191 m .45484 .69034 L .4575 .68982 L F
.4562 .69191 m .45406 .69251 L .45484 .69034 L F
.32 0 0 r
.40206 .65097 m .40424 .65127 L .40546 .65105 L F
.191 0 0 r
.40424 .65127 m .40777 .65095 L .40546 .65105 L F
.667 .305 .35 r
.59659 .58021 m .59569 .58274 L .59341 .58088 L F
.651 .351 .45 r
.59917 .58014 m .59569 .58274 L .59659 .58021 L F
0 0 0 r
.6987 .53299 m .69622 .53579 L .69731 .53438 L F
.432 .763 .996 r
.31734 .5898 m .31648 .59099 L .31499 .58993 L F
.31734 .5898 m .31904 .59072 L .31648 .59099 L F
.645 .419 .561 r
.51498 .80985 m .51312 .80824 L .51174 .80967 L F
.51498 .80985 m .51518 .80758 L .51312 .80824 L F
.17 0 .255 r
.569 .68437 m .57087 .68389 L .57144 .68155 L F
.155 .054 .478 r
.569 .68437 m .57091 .68589 L .57087 .68389 L F
.569 .68437 m .56875 .68693 L .57091 .68589 L F
.617 .818 .977 r
.25521 .64766 m .25956 .64805 L .25827 .64641 L F
.435 .69 .972 r
.25956 .64805 m .25946 .64633 L .25827 .64641 L F
.25956 .64805 m .26122 .64777 L .25946 .64633 L F
.445 .52 .841 r
.25956 .64805 m .26258 .6508 L .26122 .64777 L F
.438 .308 .605 r
.27287 .62222 m .27075 .62075 L .27302 .62003 L F
.27287 .62222 m .27078 .62333 L .27075 .62075 L F
.474 .829 .996 r
.44776 .64792 m .44992 .64749 L .45121 .64813 L F
.783 .921 .929 r
.45121 .64813 m .45194 .64575 L .45338 .6471 L F
.45121 .64813 m .44992 .64749 L .45194 .64575 L F
.423 .724 .988 r
.64 .48691 m .64123 .48581 L .63894 .48569 L F
.64 .48691 m .64253 .48688 L .64123 .48581 L F
.898 .731 .666 r
.60061 .73985 m .60236 .74059 L .60118 .73743 L F
.603 .399 .578 r
.59993 .74322 m .60236 .74059 L .60061 .73985 L F
.59993 .74322 m .60244 .74303 L .60236 .74059 L F
.371 0 0 r
.71835 .48782 m .72175 .48858 L .71902 .48918 L F
.404 .768 .994 r
.33215 .59187 m .33157 .59291 L .33007 .59201 L F
.33215 .59187 m .33369 .59274 L .33157 .59291 L F
.738 .761 .871 r
.76082 .61687 m .76193 .61988 L .76481 .61749 L F
.344 .09 .378 r
.51705 .77924 m .51519 .7801 L .51485 .78207 L F
.536 .396 .637 r
.36846 .67042 m .37039 .66739 L .3684 .66777 L F
.743 .617 .718 r
.64066 .53052 m .63838 .53366 L .64155 .53203 L F
0 0 0 r
.63838 .53366 m .63875 .5342 L .64155 .53203 L F
.005 .242 .749 r
.64066 .53052 m .64155 .53203 L .64177 .53037 L F
.862 .99 .726 r
.64155 .53203 m .63875 .5342 L .64177 .53037 L F
.85 .916 .877 r
.65348 .53427 m .64996 .53593 L .65222 .53401 L F
.65348 .53427 m .64965 .53669 L .64996 .53593 L F
.54 .205 .348 r
.65222 .53401 m .65557 .53273 L .65348 .53427 L F
.909 .772 .698 r
.61562 .49467 m .61624 .49769 L .61446 .49657 L F
.826 .558 .533 r
.61624 .49769 m .61413 .4994 L .61446 .49657 L F
.61624 .49769 m .61626 .49998 L .61413 .4994 L F
.287 0 0 r
.40663 .7105 m .40612 .71118 L .40395 .71154 L F
.382 0 .098 r
.40926 .70966 m .40612 .71118 L .40663 .7105 L F
.916 .791 .708 r
.6591 .5246 m .66173 .52217 L .66148 .51994 L F
.6591 .5246 m .66029 .52544 L .66173 .52217 L F
.508 .5 .783 r
.46604 .66254 m .467 .65919 L .46522 .65936 L F
.46604 .66254 m .46801 .66205 L .467 .65919 L F
.527 .431 .689 r
.46634 .66501 m .46801 .66205 L .46604 .66254 L F
.31 .799 .876 r
.54522 .78792 m .54582 .78804 L .54283 .78842 L F
.586 .159 .198 r
.54283 .78842 m .54582 .78804 L .54461 .78982 L F
.996 .851 .517 r
.54461 .78982 m .54582 .78804 L .54522 .78792 L F
.496 .373 .643 r
.36669 .67386 m .36849 .67342 L .36846 .67042 L F
.466 .381 .676 r
.36721 .67621 m .36849 .67342 L .36669 .67386 L F
.677 .866 .971 r
.76511 .5791 m .76179 .57908 L .76398 .57812 L F
.747 .92 .949 r
.76724 .57763 m .76511 .5791 L .76623 .57688 L F
.705 .869 .959 r
.76623 .57688 m .76511 .5791 L .76398 .57812 L F
.481 .279 .529 r
.51727 .80698 m .51518 .80758 L .51498 .80985 L F
0 0 0 r
.63697 .53608 m .63798 .53539 L .63838 .53366 L F
.08 .3 .782 r
.63697 .53608 m .63915 .53761 L .63798 .53539 L F
0 .159 .611 r
.64023 .53846 m .63915 .53761 L .63697 .53608 L F
.429 .475 .805 r
.40497 .69477 m .40443 .69767 L .4031 .69507 L F
.40497 .69477 m .40613 .69782 L .40443 .69767 L F
.195 0 .101 r
.57544 .5811 m .57832 .57831 L .57655 .57988 L F
0 0 0 r
.57832 .57831 m .5796 .57709 L .58037 .57525 L F
.57832 .57831 m .57793 .58027 L .5796 .57709 L F
.879 .712 .671 r
.54151 .77917 m .54141 .78184 L .53973 .77957 L F
.646 .273 .324 r
.47586 .80087 m .4781 .79969 L .47648 .80105 L F
.722 .38 .4 r
.4781 .79969 m .47963 .80218 L .47648 .80105 L F
.509 .562 .845 r
.59706 .74797 m .59688 .74547 L .59501 .74597 L F
.737 .923 .954 r
.59706 .74797 m .59919 .74532 L .59688 .74547 L F
.59706 .74797 m .60024 .746 L .59919 .74532 L F
.979 .689 .394 r
.66094 .49601 m .66191 .4941 L .66074 .49311 L F
.66094 .49601 m .66232 .49796 L .66191 .4941 L F
.427 .793 .995 r
.66452 .49359 m .66074 .49311 L .66191 .4941 L F
.789 .457 0 r
.63238 .52318 m .63264 .52447 L .6322 .52283 L F
.185 0 .236 r
.63502 .52171 m .63264 .52447 L .63238 .52318 L F
.202 .701 .914 r
.50768 .76254 m .51124 .76272 L .51146 .76302 L F
.954 .684 .486 r
.51146 .76302 m .50987 .76475 L .50768 .76254 L F
.51146 .76302 m .5111 .76559 L .50987 .76475 L F
.572 .939 .899 r
.51146 .76302 m .51124 .76272 L .51251 .7619 L F
.541 .862 .573 r
.51361 .76098 m .51146 .76302 L .51251 .7619 L F
0 0 0 r
.45139 .65643 m .45036 .65671 L .45222 .65687 L F
.281 .67 .971 r
.45252 .65725 m .45222 .65687 L .45036 .65671 L F
0 0 0 r
.45139 .65643 m .44797 .65793 L .45036 .65671 L F
.079 0 0 r
.30428 .60129 m .30251 .60222 L .30038 .60261 L F
.102 0 0 r
.30626 .60102 m .30251 .60222 L .30428 .60129 L F
.773 .775 .271 r
.59836 .70979 m .59773 .71159 L .59741 .71337 L F
.702 .506 0 r
.59797 .70646 m .5983 .70925 L .59836 .70979 L F
.821 .788 .288 r
.5983 .70925 m .59773 .71159 L .59836 .70979 L F
.829 .416 0 r
.56532 .74203 m .56506 .74035 L .56387 .73961 L F
.56532 .74203 m .5664 .74347 L .56506 .74035 L F
.18 .121 .549 r
.69672 .51997 m .6988 .52085 L .69888 .51916 L F
.69672 .51997 m .6971 .52232 L .6988 .52085 L F
.307 0 .172 r
.4632 .67875 m .46521 .67831 L .4663 .67616 L F
.78 .519 .542 r
.46521 .67831 m .46886 .6763 L .4663 .67616 L F
.938 .693 .54 r
.59232 .6868 m .59367 .6899 L .59379 .68754 L F
.5 .468 .753 r
.48907 .65313 m .48675 .65578 L .48673 .65356 L F
.48907 .65313 m .49025 .65713 L .48675 .65578 L F
.629 .443 .613 r
.49026 .65854 m .48675 .65578 L .49025 .65713 L F
.49026 .65854 m .48811 .65958 L .48675 .65578 L F
.623 .116 .023 r
.5586 .71477 m .561 .7166 L .56196 .71523 L F
.014 .578 .794 r
.561 .7166 m .56455 .71715 L .56196 .71523 L F
.627 .322 .433 r
.56196 .71523 m .56455 .71715 L .564 .71551 L F
.046 .33 .812 r
.49032 .68067 m .49062 .68193 L .48889 .67895 L F
.833 .556 .518 r
.49032 .68067 m .49295 .68366 L .49062 .68193 L F
.336 .368 .746 r
.49295 .68366 m .49184 .68483 L .49062 .68193 L F
.368 .254 .59 r
.70218 .50557 m .70284 .50881 L .70451 .5069 L F
.163 0 0 r
.77575 .60595 m .77674 .60563 L .77339 .60597 L F
.104 .564 .913 r
.77831 .60552 m .77674 .60563 L .77575 .60595 L F
.77831 .60552 m .77919 .60633 L .77674 .60563 L F
.513 .044 .079 r
.49762 .68788 m .49398 .68922 L .49408 .68731 L F
.49621 .6884 m .49716 .68928 L .49398 .68922 L F
.653 .433 .572 r
.49716 .68928 m .49638 .69171 L .49398 .68922 L F
.783 .573 .615 r
.49961 .69203 m .49638 .69171 L .49716 .68928 L F
.791 .579 .615 r
.49511 .68822 m .49804 .6901 L .49716 .68928 L F
.783 .573 .615 r
.49961 .69203 m .49716 .68928 L .49971 .68942 L F
.791 .579 .615 r
.49804 .6901 m .49836 .6903 L .49716 .68928 L F
.513 .044 .079 r
.49762 .68788 m .49716 .68928 L .49621 .6884 L F
.645 .174 .12 r
.49971 .68942 m .49716 .68928 L .49762 .68788 L F
.33 .615 .953 r
.45252 .65725 m .45481 .65841 L .45476 .6571 L F
0 .476 .789 r
.45968 .65855 m .45476 .6571 L .45481 .65841 L F
.35 0 .042 r
.56306 .77247 m .56491 .77135 L .56371 .77289 L F
.622 .479 .666 r
.56834 .76836 m .56491 .77135 L .56619 .76937 L F
.783 .612 .668 r
.56849 .77139 m .56371 .77289 L .56491 .77135 L F
.71 .364 .389 r
.49763 .78165 m .50161 .78177 L .49973 .78273 L F
.675 .614 .779 r
.50255 .78146 m .5049 .78282 L .50161 .78177 L F
.89 .536 .369 r
.50161 .78177 m .50142 .78484 L .49973 .78273 L F
.50161 .78177 m .50296 .78506 L .50142 .78484 L F
.725 .209 0 r
.47372 .79907 m .4741 .80028 L .4723 .7984 L F
.47372 .79907 m .47532 .801 L .4741 .80028 L F
.682 .361 .426 r
.47372 .79907 m .47586 .80087 L .47532 .801 L F
.366 .603 .939 r
.34738 .5934 m .34673 .59488 L .34543 .59339 L F
.34738 .5934 m .34837 .59491 L .34673 .59488 L F
.025 0 0 r
.28148 .65266 m .28325 .65127 L .28525 .65058 L F
.409 .316 .638 r
.77416 .59536 m .7761 .59461 L .77599 .59164 L F
.425 .356 .676 r
.77416 .59536 m .77658 .59721 L .7761 .59461 L F
.812 .468 .405 r
.519 .7701 m .52213 .77279 L .52186 .77173 L F
.78 .642 .709 r
.52213 .77279 m .52369 .77086 L .52186 .77173 L F
.606 .236 .315 r
.49961 .75205 m .50164 .75364 L .50336 .7513 L F
.751 .416 .416 r
.50164 .75364 m .50523 .75426 L .50336 .7513 L F
.848 .396 .125 r
.50336 .7513 m .50658 .75451 L .50532 .75149 L F
.50336 .7513 m .50523 .75426 L .50658 .75451 L F
.536 .127 .214 r
.63847 .50273 m .6369 .50456 L .63467 .50337 L F
.199 0 0 r
.64021 .50353 m .6369 .50456 L .63847 .50273 L F
.51 .465 .742 r
.36826 .68176 m .36911 .68514 L .37098 .6845 L F
.514 .478 .754 r
.36911 .68514 m .37172 .68693 L .37098 .6845 L F
.984 .71 .412 r
.5938 .69233 m .59491 .69311 L .59367 .6899 L F
.989 .745 .468 r
.5938 .69233 m .5937 .69491 L .59491 .69311 L F
.673 .295 .323 r
.50851 .74262 m .5049 .74265 L .50629 .74066 L F
.604 .325 .468 r
.5087 .74058 m .50851 .74262 L .50629 .74066 L F
.309 0 0 r
.52635 .77829 m .52723 .77882 L .525 .77864 L F
.52635 .77829 m .52868 .7788 L .52723 .77882 L F
.362 0 .098 r
.2648 .58635 m .26694 .58605 L .26854 .58396 L F
.259 0 0 r
.26694 .58605 m .27056 .5838 L .26854 .58396 L F
.05 0 0 r
.29673 .60396 m .29624 .6035 L .29839 .60338 L F
.29673 .60396 m .29464 .60448 L .29624 .6035 L F
.706 .417 .484 r
.50782 .77688 m .50443 .77866 L .50402 .77701 L F
.521 .47 .741 r
.36774 .67936 m .36905 .67576 L .36721 .67621 L F
.36774 .67936 m .36995 .67906 L .36905 .67576 L F
.57 .503 .74 r
.36826 .68176 m .36995 .67906 L .36774 .67936 L F
.379 .135 .413 r
.34391 .62515 m .34364 .62806 L .34128 .62783 L F
.374 .077 .327 r
.34128 .62783 m .34289 .62992 L .341 .63063 L F
.34128 .62783 m .34364 .62806 L .34289 .62992 L F
.762 .349 .267 r
.50164 .75364 m .50586 .7545 L .50523 .75426 L F
.968 .723 .512 r
.50523 .75426 m .50657 .75478 L .50658 .75451 L F
.50658 .75451 m .50647 .75693 L .50549 .75482 L F
.762 .349 .267 r
.50164 .75364 m .50407 .75606 L .50586 .7545 L F
.968 .723 .512 r
.50598 .7544 m .50549 .75482 L .50523 .75426 L F
.50658 .75451 m .50549 .75482 L .50598 .7544 L F
.50523 .75426 m .50647 .75693 L .50657 .75478 L F
.762 .349 .267 r
.50586 .7545 m .50407 .75607 L .50652 .75464 L F
.50407 .75606 m .50407 .75607 L .50586 .7545 L F
.50586 .7545 m .50652 .75464 L .50523 .75426 L F
0 0 .097 r
.50658 .75451 m .50786 .75158 L .50532 .75149 L F
.50658 .75451 m .50737 .75383 L .50786 .75158 L F
.968 .723 .512 r
.50658 .75451 m .50523 .75426 L .50737 .75383 L F
.687 .465 .58 r
.50966 .75592 m .50647 .75693 L .50658 .75451 L F
.614 .604 .817 r
.47882 .65424 m .47552 .65186 L .47764 .65067 L F
.654 .582 .762 r
.48082 .65339 m .47882 .65424 L .47764 .65067 L F
.963 .644 .361 r
.59648 .70541 m .59752 .70422 L .59622 .70346 L F
.59648 .70541 m .59797 .70646 L .59752 .70422 L F
.832 .417 .255 r
.56536 .7232 m .56192 .72043 L .56357 .72074 L F
.8 .391 .274 r
.56737 .72338 m .56536 .7232 L .56357 .72074 L F
.841 .509 .425 r
.48451 .80112 m .48631 .80432 L .48744 .80224 L F
.73 .368 .365 r
.48744 .80224 m .48631 .80432 L .48822 .80414 L F
.766 .261 .002 r
.49097 .80478 m .48744 .80224 L .48822 .80414 L F
.735 .529 .613 r
.62363 .50322 m .6234 .50561 L .62035 .50385 L F
.133 0 .211 r
.64418 .50856 m .64637 .50759 L .64666 .50566 L F
.058 0 .422 r
.64418 .50856 m .64562 .50943 L .64637 .50759 L F
.64418 .50856 m .64414 .51091 L .64562 .50943 L F
.274 .262 .663 r
.36257 .70654 m .36289 .70983 L .3644 .70814 L F
.412 .467 .807 r
.36289 .70983 m .36543 .71062 L .3644 .70814 L F
.753 .687 .788 r
.35233 .70572 m .35389 .7073 L .35651 .70479 L F
.468 .091 .24 r
.45061 .6922 m .44823 .69481 L .44601 .69498 L F
.526 .151 .272 r
.45177 .69264 m .44823 .69481 L .45061 .6922 L F
.468 .624 .919 r
.50561 .78176 m .5049 .78282 L .50255 .78146 L F
.96 .922 .578 r
.65492 .48878 m .65335 .49082 L .65384 .48819 L F
.65492 .48878 m .65371 .4923 L .65335 .49082 L F
.899 .927 .827 r
.65492 .48878 m .6562 .48525 L .65758 .48788 L F
.65492 .48878 m .65384 .48819 L .6562 .48525 L F
.745 .562 .646 r
.51378 .7852 m .51621 .78551 L .51473 .78492 L F
.644 .653 .845 r
.51473 .78492 m .51621 .78551 L .51819 .784 L F
.39 .661 .967 r
.67772 .48018 m .67636 .48129 L .67546 .48018 L F
.67772 .48018 m .67905 .48159 L .67636 .48129 L F
.295 0 .115 r
.31517 .6302 m .31817 .6284 L .31614 .62895 L F
.309 0 .224 r
.47393 .75647 m .4765 .75388 L .47443 .75447 L F
.393 .824 .959 r
.25339 .64801 m .25521 .64766 L .25232 .64778 L F
.247 0 .041 r
.32485 .64257 m .32362 .64433 L .3216 .64492 L F
.254 0 .048 r
.32662 .6425 m .32362 .64433 L .32485 .64257 L F
.395 0 0 r
.41213 .64955 m .41542 .64944 L .41358 .64927 L F
.625 .921 .976 r
.74359 .59002 m .74018 .59173 L .7392 .59109 L F
.834 .563 .529 r
.48866 .8069 m .49097 .80478 L .48822 .80414 L F
.48866 .8069 m .49113 .80714 L .49097 .80478 L F
.98 .871 .656 r
.68597 .4994 m .6867 .49789 L .68556 .49703 L F
.108 0 0 r
.40055 .71229 m .39717 .71432 L .39838 .71261 L F
.535 .324 .541 r
.52965 .73153 m .53297 .72786 L .52989 .7292 L F
.627 .279 .36 r
.46048 .68068 m .46296 .68097 L .46087 .67913 L F
.536 .304 .51 r
.46087 .67913 m .46296 .68097 L .4632 .67875 L F
.439 .294 .586 r
.39547 .67585 m .39369 .67861 L .39335 .67629 L F
.386 .023 .221 r
.24423 .59464 m .2463 .59422 L .24711 .59272 L F
.369 .004 .207 r
.2463 .59422 m .2492 .59223 L .24711 .59272 L F
.155 0 0 r
.62654 .48288 m .62977 .48069 L .62796 .4821 L F
.68 .788 .931 r
.65851 .4844 m .66155 .48625 L .6562 .48525 L F
.609 .274 .376 r
.66155 .48625 m .65758 .48788 L .6562 .48525 L F
.325 0 .199 r
.66214 .48796 m .65987 .48893 L .66155 .48625 L F
.555 .583 .838 r
.73806 .60558 m .73952 .60899 L .74141 .60825 L F
.655 .549 .722 r
.59688 .74547 m .59344 .74257 L .59501 .74597 L F
.644 .347 .452 r
.48041 .68702 m .47689 .68937 L .477 .68777 L F
.66 .285 .323 r
.48301 .7941 m .48512 .79585 L .48296 .79566 L F
.447 .236 .498 r
.37194 .65903 m .37388 .65874 L .37424 .65649 L F
.511 .323 .562 r
.3719 .66188 m .37388 .65874 L .37194 .65903 L F
.403 .188 .469 r
.34569 .62233 m .34601 .6253 L .34391 .62515 L F
.383 .142 .42 r
.34835 .6195 m .34819 .62227 L .34569 .62233 L F
.429 .205 .471 r
.34787 .62468 m .34569 .62233 L .34819 .62227 L F
.34787 .62468 m .34601 .6253 L .34569 .62233 L F
.696 .486 .599 r
.69017 .52777 m .69226 .52555 L .68882 .52528 L F
.69017 .52777 m .69217 .5279 L .69226 .52555 L F
0 0 .374 r
.69226 .52555 m .69348 .52637 L .69469 .5257 L F
.615 .743 .937 r
.69284 .52678 m .69217 .5279 L .69283 .52678 L F
0 0 .354 r
.69348 .52637 m .69217 .5279 L .69284 .52678 L F
0 0 .374 r
.69283 .52678 m .69217 .5279 L .69298 .52695 L F
.69224 .52613 m .69217 .5279 L .69283 .52678 L F
.615 .743 .937 r
.69283 .52678 m .69217 .5279 L .69017 .52777 L F
.69283 .52678 m .69017 .52777 L .6888 .52969 L F
.69284 .52678 m .69283 .52678 L .69283 .52678 L F
.69283 .52678 m .69017 .52777 L .69283 .52678 L F
0 0 .374 r
.69226 .52555 m .69224 .52613 L .69348 .52637 L F
.393 .831 .695 r
.69348 .52637 m .69284 .52678 L .69283 .52678 L F
.69348 .52637 m .69283 .52678 L .68999 .52809 L F
0 0 .374 r
.69224 .52613 m .69283 .52678 L .69348 .52637 L F
.69283 .52678 m .69298 .52695 L .69348 .52637 L F
.543 .812 .996 r
.6234 .50561 m .62549 .50499 L .62662 .50597 L F
.477 .78 .997 r
.62549 .50499 m .62807 .50478 L .62662 .50597 L F
.451 .36 .661 r
.62904 .50777 m .62662 .50597 L .62922 .50558 L F
.62904 .50777 m .62723 .50866 L .62662 .50597 L F
.896 .969 .823 r
.6125 .51035 m .61152 .50989 L .61337 .50925 L F
.935 .963 .753 r
.61034 .51378 m .61152 .50989 L .6125 .51035 L F
.695 .672 .824 r
.53914 .78517 m .54028 .78133 L .54141 .78184 L F
.974 .725 .499 r
.54141 .78184 m .54198 .78556 L .53914 .78517 L F
.903 .498 .101 r
.53973 .77957 m .54141 .78184 L .54028 .78133 L F
0 .312 .684 r
.65758 .48788 m .65987 .48893 L .66098 .48953 L F
.619 .921 .975 r
.66098 .48953 m .66214 .48796 L .66304 .48858 L F
.66098 .48953 m .65987 .48893 L .66214 .48796 L F
.541 .487 .745 r
.58783 .68773 m .58873 .68611 L .58702 .684 L F
.58783 .68773 m .59006 .68717 L .58873 .68611 L F
.949 .836 .697 r
.65528 .51558 m .65642 .51672 L .65531 .51937 L F
.722 .598 .717 r
.49382 .68453 m .49184 .68483 L .49295 .68366 L F
.49382 .68453 m .49212 .68674 L .49184 .68483 L F
.259 0 .014 r
.32046 .64699 m .31978 .64569 L .3216 .64492 L F
.32046 .64699 m .31832 .64754 L .31978 .64569 L F
.466 .381 .676 r
.36721 .67621 m .36905 .67576 L .36849 .67342 L F
.664 .522 .681 r
.5428 .7349 m .54056 .73772 L .54335 .73749 L F
0 0 .083 r
.5428 .7349 m .54205 .73712 L .54056 .73772 L F
0 0 .134 r
.5408 .73803 m .54056 .73772 L .54205 .73712 L F
.901 .884 .807 r
.64152 .52988 m .6387 .53132 L .64083 .52847 L F
.005 .242 .749 r
.64066 .53052 m .64177 .53037 L .64205 .52948 L F
.901 .884 .807 r
.64177 .53037 m .64026 .53083 L .64152 .52988 L F
.64026 .53083 m .6387 .53132 L .64152 .52988 L F
0 0 0 r
.64066 .53052 m .64203 .52949 L .64324 .52857 L F
.64203 .52949 m .64205 .52948 L .64207 .52947 L F
.64203 .52949 m .64207 .52947 L .64324 .52857 L F
.553 .136 .205 r
.53687 .72567 m .54035 .72403 L .53714 .7241 L F
.53687 .72567 m .53922 .72576 L .54035 .72403 L F
.565 .149 .212 r
.54035 .72403 m .53922 .72576 L .54268 .72518 L F
.116 0 .075 r
.49382 .68453 m .49547 .68392 L .49637 .68186 L F
.118 0 .075 r
.49637 .68186 m .49725 .68302 L .49673 .68334 L F
.49637 .68186 m .49547 .68392 L .49725 .68302 L F
.491 .785 .997 r
.64023 .48104 m .639 .48248 L .6375 .48182 L F
.64023 .48104 m .64162 .48206 L .639 .48248 L F
0 0 0 r
.69622 .53579 m .69341 .53785 L .69437 .53661 L F
.429 .09 .287 r
.63467 .50337 m .63455 .50466 L .63207 .50523 L F
.52 .164 .303 r
.63467 .50337 m .6369 .50456 L .63455 .50466 L F
.3 0 0 r
.57368 .72867 m .57601 .72905 L .57242 .72885 L F
.985 .88 .642 r
.61337 .50925 m .6126 .50828 L .61372 .50467 L F
.937 .918 .77 r
.61337 .50925 m .61152 .50989 L .6126 .50828 L F
.466 .566 .873 r
.6712 .48528 m .67102 .48651 L .67267 .48406 L F
0 0 .132 r
.67102 .48651 m .67107 .488 L .67267 .48406 L F
.606 .707 .915 r
.29074 .63577 m .28852 .63653 L .28694 .63451 L F
.178 0 0 r
.40395 .71154 m .40271 .71211 L .40055 .71229 L F
.49 .042 .111 r
.40612 .71118 m .40271 .71211 L .40395 .71154 L F
.665 .391 .496 r
.61846 .57298 m .6176 .57516 L .615 .57515 L F
.553 .274 .446 r
.6204 .57382 m .61846 .57298 L .62068 .57281 L F
.6204 .57382 m .6176 .57516 L .61846 .57298 L F
.079 .638 .709 r
.28887 .65058 m .28948 .65051 L .28733 .65024 L F
.28887 .65058 m .29097 .65036 L .28948 .65051 L F
.331 0 0 r
.78145 .60515 m .78406 .60499 L .78535 .60373 L F
.414 .771 .995 r
.78296 .60422 m .78406 .60499 L .78145 .60515 L F
.502 0 0 r
.78296 .60422 m .78342 .60561 L .78406 .60499 L F
.78342 .60561 m .78406 .60755 L .78406 .60499 L F
.331 0 0 r
.78535 .60373 m .78406 .60499 L .78544 .60369 L F
.996 .794 .516 r
.78406 .60499 m .78497 .60613 L .78544 .60369 L F
.451 .742 .99 r
.38334 .71915 m .38621 .71885 L .38422 .7187 L F
.38334 .71915 m .38702 .71977 L .38621 .71885 L F
.745 .562 .646 r
.51378 .7852 m .51473 .78492 L .51244 .78254 L F
.64 .624 .818 r
.51485 .78207 m .51473 .78492 L .51819 .784 L F
.33 .615 .953 r
.45252 .65725 m .45476 .6571 L .45222 .65687 L F
.387 .433 .787 r
.27354 .62718 m .27228 .62901 L .27119 .6257 L F
.351 .384 .756 r
.27354 .62718 m .27457 .63078 L .27228 .62901 L F
.454 .386 .691 r
.27457 .63078 m .27277 .63096 L .27228 .62901 L F
.538 .101 .157 r
.4712 .68811 m .47338 .68923 L .47106 .68914 L F
.868 .713 .688 r
.34334 .71768 m .34468 .72085 L .34521 .7176 L F
.776 .744 .824 r
.54899 .79405 m .55023 .79617 L .54719 .79618 L F
.723 .358 .358 r
.54719 .79618 m .55023 .79617 L .54993 .79861 L F
.259 .475 .878 r
.55078 .79592 m .55023 .79617 L .54972 .7953 L F
.55043 .79556 m .54972 .7953 L .54899 .79405 L F
.55078 .79592 m .54972 .7953 L .55043 .79556 L F
0 0 .186 r
.54993 .79861 m .55023 .79617 L .55167 .79552 L F
0 0 0 r
.55097 .79764 m .54993 .79861 L .55167 .79552 L F
.536 .162 .279 r
.5502 .79842 m .55044 .79556 L .54719 .79618 L F
.55044 .79556 m .55044 .79555 L .55043 .79556 L F
.55044 .79556 m .55043 .79556 L .54719 .79618 L F
.697 .616 .762 r
.54719 .79618 m .55043 .79556 L .54899 .79405 L F
.55043 .79556 m .55044 .79555 L .54899 .79405 L F
.255 .475 .879 r
.54899 .79405 m .55044 .79555 L .55167 .79552 L F
.259 .475 .878 r
.55167 .79552 m .55078 .79592 L .54899 .79405 L F
.619 .858 .495 r
.61568 .52737 m .61464 .52885 L .61679 .52608 L F
.012 0 0 r
.6178 .52639 m .61679 .52608 L .61866 .52448 L F
.6178 .52639 m .61568 .52737 L .61679 .52608 L F
.206 .287 .727 r
.37827 .71253 m .37997 .71424 L .37904 .71201 L F
.778 .624 .69 r
.58617 .56159 m .58828 .56517 L .58469 .56477 L F
.775 .643 .715 r
.58469 .56477 m .58828 .56517 L .58707 .567 L F
.677 .658 .824 r
.65434 .54188 m .65669 .54282 L .65574 .53811 L F
.753 .708 .809 r
.65574 .53811 m .65669 .54282 L .6589 .53843 L F
.476 .779 .997 r
.33789 .59187 m .33716 .5932 L .33575 .59252 L F
.33789 .59187 m .33933 .59288 L .33716 .5932 L F
.673 .662 .831 r
.48811 .65958 m .48576 .66193 L .48597 .66084 L F
.605 .548 .764 r
.48811 .65958 m .4889 .66234 L .48576 .66193 L F
.807 .857 .886 r
.74673 .58972 m .74359 .59002 L .74585 .589 L F
.671 .91 .977 r
.74876 .58867 m .74673 .58972 L .74585 .589 L F
.687 .626 .783 r
.74876 .58867 m .74655 .59051 L .74673 .58972 L F
0 0 0 r
.51222 .75448 m .51091 .75593 L .50966 .75592 L F
.127 .294 .765 r
.51316 .75335 m .51222 .75448 L .51092 .75138 L F
.686 .481 .604 r
.51316 .75335 m .51091 .75593 L .51222 .75448 L F
.62 .529 .73 r
.49621 .67015 m .49389 .67069 L .4932 .66726 L F
.274 .49 .885 r
.49511 .67627 m .49501 .67502 L .49533 .67381 L F
.49511 .67627 m .49605 .67502 L .49501 .67502 L F
.491 .265 .498 r
.49746 .6761 m .49518 .67883 L .49511 .67627 L F
.55 .551 .808 r
.49518 .67883 m .49605 .67502 L .49511 .67627 L F
.748 .595 .687 r
.5848 .55601 m .58666 .55931 L .58282 .55884 L F
.749 .581 .667 r
.58282 .55884 m .58666 .55931 L .58617 .56159 L F
.873 .441 .169 r
.57023 .72648 m .5688 .72596 L .56737 .72338 L F
.776 .296 .092 r
.57023 .72648 m .5697 .72755 L .5688 .72596 L F
.57023 .72648 m .57242 .72885 L .5697 .72755 L F
.362 .402 .768 r
.48829 .78452 m .48754 .78783 L .48635 .78736 L F
.48829 .78452 m .48906 .78761 L .48754 .78783 L F
.348 .293 .654 r
.48906 .78761 m .48955 .7901 L .48754 .78783 L F
.561 .816 .993 r
.48667 .76512 m .48863 .76584 L .49051 .76517 L F
.448 .283 .564 r
.48863 .76584 m .49051 .76773 L .49051 .76517 L F
.48863 .76584 m .49051 .76773 L .49051 .76517 L F
.771 .492 .511 r
.63188 .54215 m .63437 .54542 L .6368 .54526 L F
0 0 .463 r
.6328 .54321 m .63188 .54215 L .63253 .54051 L F
.6328 .54321 m .63437 .54542 L .63188 .54215 L F
.725 .987 .886 r
.66277 .48597 m .66408 .484 L .66182 .48514 L F
.552 .368 .585 r
.66452 .48701 m .66214 .48796 L .66189 .48576 L F
.66229 .48547 m .66189 .48576 L .66182 .48514 L F
.725 .987 .886 r
.66277 .48597 m .6644 .48449 L .66415 .4841 L F
.66277 .48597 m .66415 .4841 L .6639 .48428 L F
.552 .368 .585 r
.66452 .48701 m .66189 .48576 L .66229 .48547 L F
.725 .987 .886 r
.6639 .48428 m .66415 .4841 L .66408 .484 L F
.397 .262 .578 r
.33015 .61456 m .33203 .61416 L .332 .61141 L F
.475 .18 .384 r
.33015 .61456 m .33176 .61642 L .33203 .61416 L F
.33015 .61456 m .32949 .61701 L .33176 .61642 L F
.063 0 0 r
.43084 .66145 m .42949 .66188 L .42734 .66212 L F
.032 0 0 r
.43288 .66121 m .42949 .66188 L .43084 .66145 L F
.557 .799 .989 r
.55098 .75331 m .55022 .75498 L .54872 .75427 L F
.55098 .75331 m .55268 .75443 L .55022 .75498 L F
.32 .41 .798 r
.64253 .48688 m .64345 .4898 L .64374 .48831 L F
0 0 .38 r
.64345 .4898 m .64359 .48932 L .64374 .48831 L F
.64345 .4898 m .64415 .49173 L .64359 .48932 L F
.28 0 .136 r
.57544 .5811 m .57655 .57988 L .57494 .58104 L F
.584 .606 .84 r
.6688 .4858 m .66988 .48234 L .66729 .48264 L F
.6688 .4858 m .6712 .48528 L .66988 .48234 L F
.481 .316 .58 r
.75023 .59335 m .74823 .59756 L .74755 .59449 L F
.608 .627 .844 r
.72745 .50047 m .72422 .49829 L .72525 .49722 L F
.78 .519 .542 r
.46521 .67831 m .46872 .67859 L .46886 .6763 L F
.628 .387 .533 r
.46886 .6763 m .47093 .67796 L .47134 .67615 L F
.46886 .6763 m .46872 .67859 L .47093 .67796 L F
.468 .624 .919 r
.50561 .78176 m .50255 .78146 L .50443 .77866 L F
.463 .057 .183 r
.42514 .66228 m .42405 .66426 L .42157 .66439 L F
.083 0 0 r
.42584 .66335 m .42514 .66228 L .42734 .66212 L F
.42584 .66335 m .42405 .66426 L .42514 .66228 L F
.415 .539 .873 r
.46347 .78747 m .46551 .79046 L .46691 .79028 L F
.526 .431 .69 r
.54335 .73749 m .5452 .73714 L .5428 .7349 L F
.362 .809 .949 r
.5452 .73714 m .54205 .73712 L .5438 .73583 L F
.5452 .73714 m .544 .7367 L .54205 .73712 L F
.163 0 0 r
.544 .7367 m .54082 .73802 L .54205 .73712 L F
.54082 .73802 m .5408 .73803 L .54205 .73712 L F
.362 .809 .949 r
.5438 .73583 m .54205 .73712 L .5428 .7349 L F
.686 .646 .805 r
.47413 .64859 m .47552 .65186 L .47188 .65086 L F
.704 .655 .798 r
.47764 .65067 m .47552 .65186 L .47413 .64859 L F
0 0 .038 r
.61684 .49134 m .61896 .4882 L .61802 .48974 L F
.369 .105 .377 r
.63121 .5067 m .62904 .50777 L .62922 .50558 L F
.641 .904 .983 r
.63026 .50606 m .62904 .50777 L .63121 .5067 L F
0 0 0 r
.63053 .50589 m .62947 .50723 L .63026 .50606 L F
.62947 .50723 m .62904 .50777 L .62952 .5071 L F
.62947 .50723 m .62952 .5071 L .63026 .50606 L F
.369 .105 .377 r
.63121 .5067 m .62997 .506 L .63207 .50523 L F
.62997 .506 m .62922 .50558 L .63019 .50546 L F
.62997 .506 m .63019 .50546 L .63207 .50523 L F
.295 0 .029 r
.43314 .70102 m .43221 .70271 L .43002 .70318 L F
.279 0 .249 r
.43591 .69856 m .43489 .70107 L .43314 .70102 L F
.475 .117 .278 r
.43489 .70107 m .43221 .70271 L .43314 .70102 L F
.463 .778 .998 r
.30805 .58858 m .30747 .58983 L .30596 .58887 L F
.30805 .58858 m .30954 .58954 L .30747 .58983 L F
.488 .21 .418 r
.43909 .6871 m .44126 .68673 L .44182 .68482 L F
.348 .082 .36 r
.44182 .68482 m .44126 .68673 L .44365 .68416 L F
.947 .942 .614 r
.61358 .52993 m .61382 .5311 L .61464 .52885 L F
0 0 0 r
.61349 .53246 m .61382 .5311 L .61358 .52993 L F
.61349 .53246 m .61308 .5338 L .61382 .5311 L F
.439 .295 .588 r
.47423 .67318 m .47503 .66983 L .47604 .67061 L F
.97 .849 .666 r
.62466 .49648 m .62401 .49706 L .62487 .49496 L F
.17 .11 .542 r
.62601 .49783 m .62401 .49706 L .62466 .49648 L F
.149 .054 .483 r
.62765 .49258 m .62771 .49491 L .62466 .49648 L F
.246 .07 .434 r
.62771 .49491 m .62601 .49783 L .62466 .49648 L F
.274 .262 .663 r
.36257 .70654 m .3644 .70814 L .36326 .70644 L F
.341 .232 .582 r
.46363 .77113 m .46534 .77312 L .46525 .77065 L F
.46363 .77113 m .46386 .77364 L .46534 .77312 L F
.705 .43 .505 r
.60478 .57835 m .60135 .5805 L .60088 .5788 L F
.602 .194 .242 r
.63148 .51391 m .63402 .51548 L .63341 .51461 L F
.63148 .51391 m .63029 .51584 L .63402 .51548 L F
.51 .465 .742 r
.36826 .68176 m .37098 .6845 L .37049 .68137 L F
.57 .503 .74 r
.36826 .68176 m .37049 .68137 L .36995 .67906 L F
.993 .742 .419 r
.59895 .74047 m .5996 .74441 L .59993 .74322 L F
.729 .588 .699 r
.5969 .74318 m .5996 .74441 L .59895 .74047 L F
.995 .76 .411 r
.5996 .74441 m .59919 .74532 L .59993 .74322 L F
.603 .399 .578 r
.59993 .74322 m .60061 .73985 L .59895 .74047 L F
.613 .451 .638 r
.60024 .746 m .59993 .74322 L .59919 .74532 L F
.60024 .746 m .60244 .74303 L .59993 .74322 L F
.459 .739 .988 r
.65285 .49428 m .65573 .49513 L .65495 .49406 L F
.242 0 0 r
.65573 .49513 m .65846 .49566 L .65808 .49566 L F
.746 .52 .588 r
.65808 .49566 m .66094 .49601 L .66092 .4957 L F
.242 0 0 r
.65846 .49566 m .65852 .49568 L .65808 .49566 L F
.746 .52 .588 r
.65808 .49566 m .66092 .4957 L .66074 .49311 L F
.533 .789 .991 r
.65985 .49495 m .66069 .49577 L .65808 .49566 L F
.66069 .49577 m .66094 .49601 L .65808 .49566 L F
.242 0 0 r
.65852 .49568 m .65895 .49576 L .65808 .49566 L F
.65573 .49513 m .65808 .49566 L .65495 .49406 L F
.907 .942 .819 r
.60835 .51684 m .6096 .51309 L .61034 .51378 L F
.935 .963 .753 r
.61034 .51378 m .6096 .51309 L .61152 .50989 L F
.162 .172 .622 r
.48834 .67779 m .48709 .67947 L .48669 .67589 L F
.458 .587 .895 r
.48834 .67779 m .48889 .67895 L .48709 .67947 L F
.149 .515 .915 r
.75743 .60553 m .75634 .60611 L .75548 .60492 L F
.132 .48 .898 r
.75743 .60553 m .75834 .60688 L .75634 .60611 L F
.856 .767 .763 r
.65791 .53312 m .66054 .53377 L .66146 .53136 L F
.869 .74 .719 r
.65791 .53312 m .65908 .5363 L .66054 .53377 L F
.373 .779 .983 r
.29672 .58681 m .30025 .58721 L .29831 .58763 L F
.644 .347 .452 r
.48041 .68702 m .47927 .68967 L .47689 .68937 L F
.658 .362 .459 r
.48261 .68915 m .48041 .68702 L .48264 .68725 L F
.48261 .68915 m .47927 .68967 L .48041 .68702 L F
.877 .798 .769 r
.58319 .55476 m .5848 .55601 L .58282 .55884 L F
.834 .799 .818 r
.58437 .55308 m .5848 .55601 L .58319 .55476 L F
.58437 .55308 m .58714 .55314 L .5848 .55601 L F
.721 .672 .802 r
.5774 .73011 m .57708 .7321 L .57601 .72905 L F
.463 .518 .829 r
.57601 .72905 m .57708 .7321 L .57862 .73041 L F
.48 .545 .846 r
.57708 .7321 m .57918 .73228 L .57862 .73041 L F
.533 .077 .115 r
.61901 .55006 m .61832 .55057 L .62138 .55025 L F
.502 0 0 r
.63402 .51548 m .63775 .51618 L .63745 .5149 L F
.094 0 .024 r
.63745 .5149 m .6387 .51548 L .63938 .51385 L F
.63745 .5149 m .63775 .51618 L .6387 .51548 L F
.363 .141 .438 r
.39478 .71687 m .39318 .71552 L .39405 .71552 L F
.39478 .71687 m .39286 .71796 L .39318 .71552 L F
.156 0 0 r
.51881 .8134 m .52183 .81261 L .5211 .81311 L F
0 0 0 r
.52183 .81261 m .5242 .81194 L .5232 .81251 L F
.5211 .81311 m .52183 .81261 L .5232 .81251 L F
.431 .007 .132 r
.48133 .75155 m .48479 .74952 L .48212 .75086 L F
.48133 .75155 m .48364 .75131 L .48479 .74952 L F
.532 .111 .188 r
.48479 .74952 m .48364 .75131 L .48737 .74982 L F
.588 .421 .623 r
.48479 .74952 m .48737 .74982 L .48755 .7491 L F
.667 .586 .755 r
.7075 .51193 m .70657 .51375 L .70951 .51251 L F
.093 0 .024 r
.70657 .51375 m .70803 .51435 L .70951 .51251 L F
.70657 .51375 m .70598 .51558 L .70803 .51435 L F
.461 .373 .67 r
.6236 .54523 m .62562 .5458 L .62584 .54456 L F
.6236 .54523 m .6241 .54781 L .62562 .5458 L F
.155 0 0 r
.62654 .48288 m .62877 .48214 L .62977 .48069 L F
.345 .407 .783 r
.63256 .48289 m .62977 .48069 L .63234 .48044 L F
.049 0 0 r
.62977 .48069 m .6309 .4812 L .63234 .48044 L F
.62977 .48069 m .62877 .48214 L .6309 .4812 L F
.799 .57 .59 r
.49591 .81305 m .49238 .81465 L .49208 .81317 L F
.49591 .81305 m .4959 .81569 L .49238 .81465 L F
.508 .333 .578 r
.49801 .81517 m .4959 .81569 L .49591 .81305 L F
.648 .108 0 r
.49801 .81517 m .49591 .81305 L .49634 .81388 L F
.003 0 .061 r
.49634 .81388 m .49591 .81305 L .49804 .81084 L F
.344 .63 .959 r
.68561 .48391 m .68266 .48241 L .68475 .48249 L F
.513 .698 .953 r
.68788 .48359 m .68561 .48391 L .68475 .48249 L F
.564 .822 .994 r
.77114 .57777 m .76724 .57763 L .77002 .57715 L F
0 .491 .828 r
.77002 .57715 m .77286 .57829 L .77114 .57777 L F
.299 0 0 r
.42563 .70368 m .42415 .70512 L .422 .70553 L F
.197 0 0 r
.42782 .70345 m .42415 .70512 L .42563 .70368 L F
.648 .554 .736 r
.37529 .70128 m .37641 .7049 L .37865 .70416 L F
.901 .7 .622 r
.65821 .52147 m .66148 .51994 L .6609 .51942 L F
.921 .78 .688 r
.6591 .5246 m .66148 .51994 L .65821 .52147 L F
0 0 0 r
.64248 .55098 m .6415 .55234 L .63972 .55316 L F
.63972 .55316 m .6415 .55234 L .63846 .55431 L F
.705 .43 .505 r
.60478 .57835 m .60529 .5798 L .60135 .5805 L F
.617 .404 .571 r
.60697 .57819 m .60529 .5798 L .60478 .57835 L F
.389 .504 .855 r
.36328 .59977 m .36207 .60131 L .36116 .60018 L F
.36328 .59977 m .36487 .60289 L .36207 .60131 L F
.56 .477 .718 r
.36207 .60131 m .36487 .60289 L .36286 .60338 L F
.505 .226 .423 r
.58189 .58126 m .57908 .58398 L .57966 .58139 L F
.557 .581 .833 r
.26122 .64777 m .26258 .6508 L .2646 .65039 L F
.719 .191 0 r
.56703 .74485 m .56812 .74462 L .5664 .74347 L F
.56703 .74485 m .56895 .74537 L .56812 .74462 L F
.719 .297 .244 r
.49333 .80928 m .49448 .80761 L .49113 .80714 L F
.834 .448 .321 r
.49517 .80947 m .49448 .80761 L .49333 .80928 L F
.776 .269 0 r
.49804 .81084 m .49448 .80761 L .49517 .80947 L F
.596 .759 .956 r
.46203 .65871 m .46522 .65936 L .4637 .65826 L F
.399 .707 .985 r
.467 .65919 m .4637 .65826 L .46522 .65936 L F
.922 .889 .782 r
.53129 .80684 m .53253 .80769 L .53483 .80369 L F
.338 .102 .402 r
.55597 .74068 m .55546 .74279 L .55771 .73996 L F
.55597 .74068 m .55546 .74279 L .55771 .73996 L F
.162 .172 .622 r
.48834 .67779 m .48669 .67589 L .48812 .67553 L F
.88 .815 .78 r
.78297 .59273 m .78314 .58881 L .78181 .59181 L F
.78297 .59273 m .78455 .58971 L .78314 .58881 L F
.988 .858 .621 r
.78222 .59477 m .78297 .59273 L .78181 .59181 L F
.439 .295 .588 r
.47423 .67318 m .476 .67267 L .47503 .66983 L F
.295 .357 .757 r
.47503 .66983 m .4776 .66962 L .47519 .66833 L F
.49 .323 .582 r
.47503 .66983 m .47792 .67189 L .4776 .66962 L F
.47503 .66983 m .476 .67267 L .47792 .67189 L F
.312 0 .238 r
.33639 .63367 m .33721 .63201 L .33912 .63138 L F
.74 .964 .685 r
.64427 .54965 m .6415 .55234 L .64248 .55098 L F
.477 .157 .345 r
.43851 .70042 m .43591 .69856 L .43812 .69826 L F
.43851 .70042 m .43489 .70107 L .43591 .69856 L F
.824 .658 .677 r
.50339 .68729 m .50289 .69022 L .49971 .68942 L F
.876 .438 .125 r
.50242 .68644 m .50518 .68967 L .50339 .68729 L F
0 0 0 r
.63838 .53366 m .63798 .53539 L .63875 .5342 L F
.65 .152 .054 r
.55829 .7875 m .55783 .78918 L .55694 .78798 L F
.55829 .7875 m .55988 .7884 L .55783 .78918 L F
.771 .956 .639 r
.49309 .79527 m .49258 .79669 L .49475 .79375 L F
.771 .953 .631 r
.49106 .79819 m .49258 .79669 L .49309 .79527 L F
.091 0 0 r
.41542 .64944 m .41755 .64941 L .41927 .64907 L F
.479 0 0 r
.41755 .64941 m .42107 .64931 L .41927 .64907 L F
.922 .873 .771 r
.66807 .52267 m .66532 .52455 L .66652 .52156 L F
.66807 .52267 m .66638 .52567 L .66532 .52455 L F
.263 .738 .938 r
.30995 .60138 m .30827 .60093 L .30626 .60102 L F
.102 0 0 r
.3119 .60104 m .30827 .60093 L .30995 .60138 L F
.399 0 .018 r
.3928 .65326 m .39507 .65314 L .39641 .65171 L F
.456 0 .056 r
.39641 .65171 m .39507 .65314 L .39836 .65243 L F
.599 .035 0 r
.53108 .73571 m .53358 .73714 L .53034 .73619 L F
.62 .422 .592 r
.73187 .50868 m .73204 .51101 L .72955 .51116 L F
.557 .523 .773 r
.7339 .50805 m .73187 .50868 L .73175 .50574 L F
.463 .304 .58 r
.73393 .5098 m .73187 .50868 L .7339 .50805 L F
.73393 .5098 m .73204 .51101 L .73187 .50868 L F
.818 .913 .515 r
.66172 .48067 m .66004 .48408 L .66071 .48186 L F
.487 .741 .984 r
.66182 .48514 m .66071 .48186 L .66004 .48408 L F
0 0 0 r
.75064 .59307 m .75166 .5933 L .75023 .59335 L F
.75095 .5928 m .75219 .59176 L .75166 .5933 L F
0 0 .056 r
.7534 .59042 m .75219 .59176 L .75286 .58979 L F
0 0 0 r
.75166 .5933 m .75219 .59176 L .7534 .59042 L F
.908 .889 .801 r
.75073 .59226 m .75166 .5933 L .7534 .59042 L F
.521 0 0 r
.75224 .59371 m .75166 .5933 L .75073 .59226 L F
.445 .429 .747 r
.75166 .5933 m .75448 .595 L .75273 .59732 L F
.521 0 0 r
.75325 .59468 m .75448 .595 L .75166 .5933 L F
.75325 .59468 m .75166 .5933 L .75224 .59371 L F
0 0 0 r
.75064 .59307 m .75095 .5928 L .75166 .5933 L F
.577 .502 .734 r
.39785 .68705 m .3957 .68758 L .39473 .68387 L F
.351 0 0 r
.27056 .5838 m .27248 .58445 L .27414 .58436 L F
.633 .629 .829 r
.70206 .49365 m .70294 .49542 L .70538 .49465 L F
.593 .475 .688 r
.70294 .49542 m .70317 .49741 L .70538 .49465 L F
.504 .746 .982 r
.49457 .80056 m .49338 .80188 L .49217 .80077 L F
.49217 .80077 m .49338 .80188 L .49457 .80056 L F
.573 .31 .48 r
.53283 .75655 m .53503 .75669 L .53515 .75458 L F
.747 .564 .647 r
.53503 .75669 m .53756 .75428 L .53515 .75458 L F
.508 .205 .388 r
.44932 .68402 m .4516 .68375 L .45226 .681 L F
.377 0 .01 r
.45226 .681 m .45405 .68126 L .4549 .68091 L F
.499 .227 .433 r
.4516 .68375 m .45405 .68126 L .45226 .681 L F
.548 .497 .751 r
.49473 .66484 m .4932 .66726 L .49253 .66538 L F
.49473 .66484 m .49537 .66689 L .4932 .66726 L F
.62 .529 .73 r
.49621 .67015 m .4932 .66726 L .49537 .66689 L F
.674 .752 .909 r
.74243 .60972 m .74376 .60761 L .74141 .60825 L F
.74243 .60972 m .74477 .60889 L .74376 .60761 L F
.017 .244 .749 r
.73293 .4989 m .733 .50027 L .73156 .4972 L F
0 0 .326 r
.73365 .50084 m .733 .50027 L .73293 .4989 L F
.73365 .50084 m .73346 .50282 L .733 .50027 L F
.805 .566 .576 r
.60993 .53882 m .6115 .54043 L .61232 .53979 L F
.552 .353 .564 r
.57455 .72079 m .57688 .72051 L .57689 .7181 L F
.463 .518 .829 r
.57601 .72905 m .57862 .73041 L .57933 .72927 L F
.523 .329 .56 r
.57689 .7181 m .57688 .72051 L .57927 .71821 L F
.707 .273 .218 r
.57862 .73041 m .58163 .73129 L .57933 .72927 L F
.528 .858 .996 r
.29097 .65036 m .29447 .65031 L .29303 .6502 L F
.396 .819 .969 r
.29447 .65031 m .29511 .64954 L .29303 .6502 L F
.29447 .65031 m .2967 .64993 L .29511 .64954 L F
.806 .741 .792 r
.5371 .78766 m .53876 .78725 L .53914 .78517 L F
.76 .664 .757 r
.53993 .78724 m .54011 .78774 L .53858 .7877 L F
.53876 .78741 m .53858 .7877 L .5371 .78766 L F
.53993 .78724 m .53858 .7877 L .53876 .78741 L F
0 0 .156 r
.53887 .78724 m .53876 .78725 L .53876 .78741 L F
.586 .173 .226 r
.53876 .78741 m .53876 .78725 L .5371 .78766 L F
.76 .664 .757 r
.53914 .78517 m .53993 .78724 L .53884 .7874 L F
0 0 .465 r
.53914 .78517 m .53876 .78725 L .53887 .78724 L F
.76 .664 .757 r
.53914 .78517 m .53884 .7874 L .5371 .78766 L F
.745 .657 .763 r
.53914 .78517 m .54198 .78556 L .54011 .78774 L F
0 0 .465 r
.53914 .78517 m .53887 .78724 L .54027 .78709 L F
.749 .49 .539 r
.5371 .78766 m .54011 .78774 L .53976 .78987 L F
.5371 .78766 m .53976 .78987 L .53697 .79012 L F
0 0 .156 r
.54027 .78709 m .53887 .78724 L .5387 .7897 L F
.53887 .78724 m .53876 .78741 L .5387 .7897 L F
.586 .173 .226 r
.5387 .7897 m .53876 .78741 L .5371 .78766 L F
.565 .318 .501 r
.53976 .78987 m .54011 .78774 L .54217 .78946 L F
.683 .561 .711 r
.54198 .78556 m .54283 .78842 L .54011 .78774 L F
.676 .257 .243 r
.54011 .78774 m .54283 .78842 L .54217 .78946 L F
.197 0 .038 r
.28269 .60943 m .28139 .61117 L .27968 .61156 L F
.312 0 .113 r
.28346 .61063 m .28269 .60943 L .28459 .60842 L F
.28346 .61063 m .28139 .61117 L .28269 .60943 L F
.647 .769 .937 r
.27953 .63494 m .27583 .63427 L .27796 .63376 L F
.625 .802 .967 r
.2816 .63419 m .27953 .63494 L .27796 .63376 L F
.74 .988 .792 r
.76115 .58472 m .76029 .58622 L .76239 .5854 L F
.76115 .58472 m .75971 .5861 L .76029 .58622 L F
.789 .608 .656 r
.48047 .78498 m .48165 .78796 L .479 .78755 L F
.617 .496 .693 r
.48359 .78528 m .48165 .78796 L .48047 .78498 L F
.776 .713 .793 r
.51545 .76728 m .51819 .76822 L .51694 .76582 L F
.847 .549 .484 r
.51545 .76728 m .519 .7701 L .51819 .76822 L F
.77 .711 .797 r
.51694 .76582 m .51819 .76822 L .5203 .76576 L F
.696 .517 .641 r
.51464 .77471 m .51354 .77702 L .51211 .77661 L F
.753 .687 .788 r
.35233 .70572 m .35651 .70479 L .35497 .70362 L F
.423 .079 .274 r
.43002 .69228 m .43314 .68951 L .4311 .69006 L F
.801 .815 .333 r
.59741 .71337 m .59687 .71425 L .59773 .71452 L F
.59741 .71337 m .59773 .71159 L .59687 .71425 L F
.618 .591 .801 r
.46634 .66501 m .46986 .66772 L .46836 .6646 L F
.602 .614 .835 r
.46836 .6646 m .46986 .66772 L .4721 .66721 L F
.485 .763 .992 r
.68692 .48996 m .68784 .48861 L .68584 .4884 L F
.68692 .48996 m .689 .48969 L .68784 .48861 L F
.429 .213 .482 r
.53542 .78466 m .53346 .7852 L .53317 .78748 L F
.53542 .78466 m .53346 .7852 L .53317 .78748 L F
.778 .67 .744 r
.6622 .51102 m .66344 .51424 L .66039 .51204 L F
.87 .479 .294 r
.66344 .51424 m .66247 .51553 L .66039 .51204 L F
.986 .716 .415 r
.66344 .51424 m .66354 .51637 L .66247 .51553 L F
.25 .359 .78 r
.59173 .73529 m .59313 .73362 L .59083 .73399 L F
.59173 .73529 m .59443 .73688 L .59313 .73362 L F
.412 .569 .9 r
.75252 .60381 m .74902 .60108 L .75239 .60219 L F
.268 .411 .822 r
.75239 .60219 m .75383 .60244 L .75252 .60381 L F
.332 .515 .886 r
.75383 .60244 m .75548 .60492 L .75252 .60381 L F
.505 .226 .423 r
.58189 .58126 m .58182 .58346 L .57908 .58398 L F
.646 .34 .438 r
.5841 .58309 m .58182 .58346 L .58189 .58126 L F
.785 .617 .672 r
.58828 .57889 m .58764 .58105 L .58606 .57793 L F
.798 .54 .548 r
.58828 .57889 m .58967 .58091 L .58764 .58105 L F
.546 .926 .811 r
.58975 .72579 m .5864 .7277 L .58803 .72695 L F
.427 .174 .425 r
.34555 .6275 m .34391 .62515 L .34601 .6253 L F
.34555 .6275 m .34364 .62806 L .34391 .62515 L F
.762 .668 .759 r
.4791 .76486 m .48254 .76591 L .48028 .76338 L F
.744 .292 .177 r
.4791 .76486 m .48114 .76706 L .48254 .76591 L F
.769 .669 .752 r
.48028 .76338 m .48254 .76591 L .48491 .76272 L F
.225 .368 .798 r
.73033 .49426 m .73073 .49706 L .7289 .49396 L F
.73033 .49426 m .73156 .4972 L .73073 .49706 L F
.358 .069 .331 r
.351 .6172 m .35039 .61957 L .34835 .6195 L F
.398 .154 .424 r
.35004 .62161 m .34835 .6195 L .35039 .61957 L F
.35004 .62161 m .34819 .62227 L .34835 .6195 L F
.863 .452 .247 r
.56737 .72338 m .56741 .72591 L .56536 .7232 L F
.56737 .72338 m .5688 .72596 L .56741 .72591 L F
.848 .445 .275 r
.564 .71551 m .56455 .71715 L .56623 .71734 L F
.787 .291 .013 r
.56455 .71715 m .56802 .71994 L .56623 .71734 L F
.769 .669 .752 r
.48028 .76338 m .48491 .76272 L .48355 .76374 L F
.62 .16 0 r
.48491 .76272 m .48578 .76406 L .48355 .76374 L F
.48491 .76272 m .48667 .76512 L .48578 .76406 L F
.438 .644 .945 r
.63684 .48565 m .6375 .48182 L .63658 .48407 L F
.63684 .48565 m .63842 .48421 L .6375 .48182 L F
.63684 .48565 m .63894 .48569 L .63842 .48421 L F
.642 .888 .548 r
.61568 .52737 m .61358 .52993 L .61464 .52885 L F
.166 .102 .534 r
.64666 .50566 m .64817 .50462 L .64792 .50235 L F
0 0 .155 r
.64666 .50566 m .64637 .50759 L .64817 .50462 L F
.199 0 0 r
.64021 .50353 m .63929 .50432 L .6369 .50456 L F
.132 0 0 r
.6427 .50408 m .63929 .50432 L .64021 .50353 L F
.92 .747 .651 r
.54775 .76593 m .54548 .76852 L .54319 .7654 L F
.54775 .76593 m .54709 .76803 L .54548 .76852 L F
.763 .302 0 r
.67554 .51453 m .67607 .51501 L .6752 .51364 L F
.67616 .51618 m .67607 .51501 L .67554 .51453 L F
0 .361 .746 r
.67607 .51501 m .67734 .51578 L .67654 .51543 L F
.67607 .51501 m .67654 .51543 L .67441 .51452 L F
.12 .641 .884 r
.32103 .59073 m .32449 .59135 L .32251 .59141 L F
.619 .793 .359 r
.584 .68052 m .58484 .67907 L .58368 .67823 L F
.584 .68052 m .58329 .68177 L .58484 .67907 L F
.615 .429 .607 r
.58484 .67907 m .58329 .68177 L .5851 .68117 L F
.856 .767 .763 r
.65791 .53312 m .66146 .53136 L .65988 .52996 L F
.693 .599 .746 r
.66146 .53136 m .66007 .5279 L .65988 .52996 L F
.676 .328 .376 r
.5712 .72236 m .57343 .72288 L .57455 .72079 L F
.773 .588 .649 r
.57343 .72288 m .57688 .72051 L .57455 .72079 L F
.922 .957 .789 r
.66837 .49924 m .66882 .50041 L .67082 .4972 L F
.62 .086 0 r
.66803 .50127 m .66882 .50041 L .66837 .49924 L F
.66803 .50127 m .67129 .50195 L .66882 .50041 L F
.991 .751 .382 r
.59838 .72045 m .59848 .72333 L .59919 .7239 L F
.986 .896 .635 r
.59919 .7239 m .59765 .72556 L .59861 .72622 L F
.59919 .7239 m .59848 .72333 L .59765 .72556 L F
.305 .209 .579 r
.54507 .74605 m .54658 .74259 L .54443 .74269 L F
.54507 .74605 m .54683 .74535 L .54658 .74259 L F
.016 0 .404 r
.54556 .74869 m .54683 .74535 L .54507 .74605 L F
.889 .524 .346 r
.483 .80672 m .48581 .80827 L .4855 .80947 L F
.841 .78 .793 r
.58437 .55308 m .58719 .54986 L .58714 .55314 L F
.969 .875 .686 r
.58719 .54986 m .58762 .55076 L .58714 .55314 L F
.687 .626 .783 r
.74876 .58867 m .75141 .59031 L .74655 .59051 L F
.656 .338 .423 r
.57144 .68155 m .57411 .68372 L .57484 .67886 L F
.57144 .68155 m .57087 .68389 L .57411 .68372 L F
.012 0 0 r
.66172 .48067 m .66298 .48083 L .66406 .47998 L F
.66172 .48067 m .66071 .48186 L .66298 .48083 L F
.574 .472 .701 r
.39663 .68144 m .39473 .68387 L .39436 .68191 L F
.39663 .68144 m .3972 .68354 L .39473 .68387 L F
.577 .502 .734 r
.39785 .68705 m .39473 .68387 L .3972 .68354 L F
.527 .431 .689 r
.46634 .66501 m .46836 .6646 L .46801 .66205 L F
.775 .643 .715 r
.58469 .56477 m .58707 .567 L .58371 .56665 L F
.761 .641 .729 r
.58371 .56665 m .58707 .567 L .58517 .57001 L F
.382 0 .098 r
.40926 .70966 m .40835 .71089 L .40612 .71118 L F
.285 0 .039 r
.41039 .71043 m .40926 .70966 L .41176 .7091 L F
.41039 .71043 m .40835 .71089 L .40926 .70966 L F
.959 .947 .688 r
.67868 .5306 m .67928 .52727 L .67716 .52949 L F
0 0 .532 r
.67868 .5306 m .68013 .53188 L .68108 .52962 L F
.948 .958 .711 r
.60641 .51984 m .60743 .51604 L .60835 .51684 L F
.907 .942 .819 r
.60835 .51684 m .60743 .51604 L .6096 .51309 L F
.684 .644 .804 r
.70042 .48679 m .69888 .49037 L .69725 .48624 L F
.354 0 0 r
.42107 .64931 m .42345 .64951 L .42501 .64884 L F
.414 0 0 r
.42345 .64951 m .42689 .64868 L .42501 .64884 L F
.522 .301 .521 r
.37424 .65649 m .3761 .65823 L .3763 .65602 L F
.37424 .65649 m .37388 .65874 L .3761 .65823 L F
.641 .639 .833 r
.47188 .65086 m .4682 .64863 L .47064 .64801 L F
.713 .695 .831 r
.47413 .64859 m .47188 .65086 L .47064 .64801 L F
.459 0 0 r
.62028 .51871 m .62272 .51983 L .62348 .51957 L F
.351 0 0 r
.62272 .51983 m .62481 .51863 L .62348 .51957 L F
.683 .778 .923 r
.28376 .63325 m .28506 .63466 L .2816 .63419 L F
.518 .713 .96 r
.28582 .63294 m .28506 .63466 L .28376 .63325 L F
.451 .635 .934 r
.28582 .63294 m .28694 .63451 L .28506 .63466 L F
.592 .542 .768 r
.73518 .60432 m .73566 .6061 L .73806 .60558 L F
.64 .928 .659 r
.75658 .58347 m .75827 .5815 L .75962 .5815 L F
.75658 .58347 m .75637 .58339 L .75827 .5815 L F
.368 .175 .482 r
.46941 .75936 m .47116 .75708 L .46972 .75827 L F
.46941 .75936 m .47126 .75934 L .47116 .75708 L F
.51 .211 .395 r
.46941 .75936 m .47101 .76153 L .47126 .75934 L F
.46941 .75936 m .46881 .76191 L .47101 .76153 L F
.295 .77 .932 r
.29074 .63577 m .29272 .63554 L .294 .63587 L F
.41 .837 .957 r
.29272 .63554 m .2965 .63538 L .294 .63587 L F
.491 .713 .969 r
.75153 .61246 m .75299 .61101 L .75068 .61105 L F
.75153 .61246 m .75399 .61237 L .75299 .61101 L F
.758 .707 .805 r
.57688 .72051 m .58033 .72099 L .57927 .71821 L F
.444 .526 .847 r
.57927 .71821 m .58033 .72099 L .58209 .71982 L F
.467 .576 .881 r
.58033 .72099 m .58298 .72131 L .58209 .71982 L F
.164 0 .276 r
.56978 .77215 m .56888 .77373 L .5708 .77103 L F
.93 .902 .776 r
.51828 .77732 m .51881 .77694 L .51705 .77924 L F
.327 .748 .975 r
.51942 .77945 m .51705 .77924 L .51881 .77694 L F
.78 .642 .709 r
.52213 .77279 m .52502 .77391 L .52369 .77086 L F
.775 .333 .2 r
.52213 .77279 m .5232 .77389 L .52502 .77391 L F
.577 .543 .781 r
.52369 .77086 m .52502 .77391 L .52712 .77332 L F
.649 .305 .376 r
.5232 .77389 m .52712 .77332 L .52502 .77391 L F
.745 .355 .313 r
.479 .78755 m .48165 .78796 L .48082 .78981 L F
.617 .496 .693 r
.48359 .78528 m .48397 .78764 L .48165 .78796 L F
.605 .441 .633 r
.48397 .78764 m .48173 .79046 L .48165 .78796 L F
.996 .761 .43 r
.48165 .78796 m .48173 .79046 L .48082 .78981 L F
.605 .441 .633 r
.48397 .78764 m .48173 .79046 L .48165 .78796 L F
.996 .761 .43 r
.48165 .78796 m .48173 .79046 L .48082 .78981 L F
.25 .31 .73 r
.57494 .58104 m .5764 .58308 L .57544 .5811 L F
.768 .951 .625 r
.64324 .52857 m .64445 .52624 L .64526 .52759 L F
.118 0 0 r
.52915 .80997 m .53253 .80769 L .53129 .80684 L F
.193 0 0 r
.31322 .63075 m .31388 .63178 L .31517 .6302 L F
.31322 .63075 m .31181 .63239 L .31388 .63178 L F
.753 .597 .683 r
.75286 .58979 m .75141 .59031 L .74876 .58867 L F
.622 .649 .856 r
.75392 .58846 m .75286 .58979 L .75224 .5892 L F
0 0 .056 r
.7534 .59042 m .75286 .58979 L .75392 .58846 L F
.632 .594 .793 r
.37415 .69811 m .37529 .70128 L .37744 .7006 L F
.648 .554 .736 r
.37529 .70128 m .37865 .70416 L .37744 .7006 L F
.701 .277 .238 r
.52146 .75918 m .52497 .76223 L .5248 .75937 L F
.408 .055 .252 r
.5248 .75937 m .5257 .76159 L .527 .75927 L F
.5248 .75937 m .52497 .76223 L .5257 .76159 L F
.181 .667 .925 r
.32132 .60218 m .32502 .60299 L .32364 .60208 L F
.42 .754 .995 r
.32502 .60299 m .32568 .60186 L .32364 .60208 L F
.32502 .60299 m .32697 .60279 L .32568 .60186 L F
.65 .438 .582 r
.48846 .77946 m .48842 .78191 L .48607 .78217 L F
.796 .461 0 r
.65638 .50544 m .65735 .50877 L .65749 .50827 L F
0 0 .26 r
.65803 .50963 m .65749 .50827 L .65735 .50877 L F
.583 .208 .297 r
.38694 .65553 m .38821 .65336 L .38515 .65403 L F
.453 .017 .119 r
.3891 .65506 m .38821 .65336 L .38694 .65553 L F
.3891 .65506 m .39051 .65329 L .38821 .65336 L F
.676 .723 .885 r
.69282 .49133 m .69624 .49201 L .69509 .49064 L F
.649 .715 .896 r
.69509 .49064 m .69624 .49201 L .69862 .49128 L F
0 .47 .827 r
.31423 .60086 m .31521 .60181 L .3176 .60253 L F
.922 .641 .492 r
.62035 .50385 m .61978 .50503 L .62109 .50505 L F
.938 .771 .648 r
.62109 .50505 m .62084 .50843 L .61978 .50503 L F
.234 0 0 r
.43892 .66002 m .43742 .66094 L .43518 .66111 L F
0 0 0 r
.43944 .66037 m .43892 .66002 L .44129 .65942 L F
.43944 .66037 m .43742 .66094 L .43892 .66002 L F
.677 .658 .824 r
.65434 .54188 m .65574 .53811 L .65359 .53891 L F
.242 0 .087 r
.72458 .51682 m .72167 .5187 L .72227 .51762 L F
.379 .118 .388 r
.351 .6172 m .35345 .61465 L .35298 .6165 L F
.351 .106 .396 r
.35546 .61387 m .35345 .61465 L .35576 .6119 L F
.354 .113 .403 r
.35298 .6165 m .35345 .61465 L .35546 .61387 L F
.848 .744 .748 r
.53861 .73454 m .53726 .73736 L .53863 .73587 L F
.677 .528 .675 r
.4957 .7923 m .49309 .79527 L .49475 .79375 L F
.763 .621 .703 r
.51524 .73159 m .5171 .73266 L .51873 .732 L F
.726 .525 .618 r
.5171 .73266 m .51882 .73454 L .51873 .732 L F
.594 .368 .543 r
.51882 .73454 m .52123 .73206 L .51873 .732 L F
.532 .548 .817 r
.54443 .74269 m .54658 .74259 L .5437 .74128 L F
.264 .614 .957 r
.76846 .58657 m .77159 .58854 L .77304 .58843 L F
.551 .434 .673 r
.36487 .60289 m .36329 .60609 L .36286 .60338 L F
.434 .316 .619 r
.37015 .66495 m .3719 .66188 L .36973 .66263 L F
.561 .067 0 r
.66743 .49344 m .66882 .49491 L .66785 .49522 L F
.645 .203 .187 r
.63437 .54542 m .63411 .54639 L .6368 .54526 L F
.792 .995 .868 r
.6368 .54526 m .63686 .54397 L .63785 .54465 L F
.6368 .54526 m .63411 .54639 L .63686 .54397 L F
.402 .108 .348 r
.35243 .619 m .351 .6172 L .35298 .6165 L F
.35243 .619 m .35039 .61957 L .351 .6172 L F
.727 .832 .93 r
.3176 .60253 m .31915 .60368 L .32132 .60218 L F
.551 .642 .894 r
.69492 .48647 m .6919 .48508 L .69417 .48469 L F
.55 .639 .892 r
.69642 .48438 m .69492 .48647 L .69417 .48469 L F
.524 .602 .874 r
.69642 .48438 m .69725 .48624 L .69492 .48647 L F
.857 .447 .256 r
.54359 .80039 m .54491 .79939 L .54454 .80059 L F
.605 .485 .689 r
.54491 .79939 m .54733 .79903 L .54719 .79618 L F
0 0 0 r
.54719 .79618 m .54491 .79939 L .54642 .79831 L F
.54642 .79831 m .54491 .79939 L .54359 .80039 L F
.548 .284 .466 r
.54497 .79944 m .5471 .80113 L .54454 .80059 L F
.54491 .79939 m .54733 .79903 L .5471 .80113 L F
.625 .66 .863 r
.54454 .80059 m .5471 .80113 L .5458 .7992 L F
.54454 .80059 m .5458 .7992 L .54414 .80165 L F
.54454 .80059 m .54414 .80165 L .54328 .80293 L F
.548 .284 .466 r
.54491 .79939 m .54497 .79944 L .54454 .80059 L F
.22 0 0 r
.57667 .67714 m .57375 .6787 L .57679 .67781 L F
.419 0 0 r
.57679 .67781 m .5788 .67781 L .57667 .67714 L F
.239 0 .04 r
.62308 .5723 m .6204 .57382 L .62068 .57281 L F
.54 .356 .581 r
.62296 .56996 m .62308 .5723 L .62068 .57281 L F
.008 .566 .813 r
.2967 .64993 m .30016 .65061 L .29872 .65 L F
.531 .867 .993 r
.30016 .65061 m .30081 .64946 L .29872 .65 L F
.30016 .65061 m .30236 .64997 L .30081 .64946 L F
.536 .723 .959 r
.69213 .48244 m .6919 .48508 L .6901 .48308 L F
.69213 .48244 m .69417 .48469 L .6919 .48508 L F
.396 .144 .41 r
.35546 .61387 m .35576 .6119 L .35779 .61129 L F
.166 0 .292 r
.56875 .68693 m .56824 .68971 L .56907 .68911 L F
.29 .004 .295 r
.56875 .68693 m .57103 .68826 L .57091 .68589 L F
.56875 .68693 m .56907 .68911 L .57103 .68826 L F
.527 .564 .836 r
.65285 .49428 m .65335 .49082 L .65371 .4923 L F
.439 .294 .586 r
.39547 .67585 m .39552 .67818 L .39369 .67861 L F
.622 .514 .71 r
.39663 .68144 m .39369 .67861 L .39552 .67818 L F
.39663 .68144 m .39436 .68191 L .39369 .67861 L F
.61 .635 .851 r
.35535 .72928 m .3539 .72993 L .35405 .72807 L F
.557 .587 .84 r
.3539 .72993 m .35511 .73051 L .35405 .72807 L F
.682 .521 .661 r
.3539 .72993 m .35281 .73205 L .35511 .73051 L F
.732 .241 .074 r
.54818 .70885 m .55048 .71095 L .55155 .70993 L F
.723 .23 .067 r
.55048 .71095 m .55364 .71181 L .55155 .70993 L F
0 0 0 r
.4933 .78731 m .48955 .7901 L .4914 .78987 L F
.808 .564 .571 r
.4914 .78987 m .49426 .78807 L .4933 .78731 L F
.785 .618 .673 r
.54076 .7403 m .5437 .74128 L .54335 .73749 L F
.433 .355 .669 r
.54335 .73749 m .54551 .7389 L .5452 .73714 L F
.54335 .73749 m .5437 .74128 L .54551 .7389 L F
.44 .177 .416 r
.33453 .63435 m .33398 .63639 L .33196 .63686 L F
.367 .11 .387 r
.33639 .63367 m .33398 .63639 L .33453 .63435 L F
.448 .566 .881 r
.74718 .6084 m .74887 .61127 L .75068 .61105 L F
.766 .534 .582 r
.54027 .78709 m .54056 .78703 L .54229 .78447 L F
.011 0 .308 r
.54198 .78556 m .54349 .7827 L .54229 .78447 L F
.31 .799 .876 r
.54522 .78792 m .54283 .78842 L .54198 .78556 L F
.516 0 0 r
.543 .7865 m .54522 .78792 L .54198 .78556 L F
.543 .7865 m .54198 .78556 L .54229 .78447 L F
.766 .534 .582 r
.54056 .78703 m .543 .7865 L .54229 .78447 L F
.011 0 .308 r
.54349 .7827 m .54364 .78242 L .54229 .78447 L F
.602 .339 .49 r
.49399 .76795 m .49756 .76515 L .49382 .76544 L F
.49399 .76795 m .49653 .76795 L .49756 .76515 L F
.469 .09 .238 r
.49653 .76795 m .49996 .76572 L .49756 .76515 L F
.688 .974 .782 r
.54417 .78288 m .54566 .78053 L .54458 .78292 L F
.108 0 .088 r
.54364 .78242 m .54644 .77931 L .54566 .78053 L F
.695 .672 .824 r
.53914 .78517 m .54234 .78435 L .54028 .78133 L F
0 0 .465 r
.53914 .78517 m .54027 .78709 L .54234 .78435 L F
.734 .297 0 r
.54028 .78133 m .54234 .78435 L .54229 .78447 L F
.54028 .78133 m .54229 .78447 L .54364 .78242 L F
.54028 .78133 m .54364 .78242 L .54243 .78271 L F
.688 .974 .782 r
.54243 .78271 m .54364 .78242 L .54566 .78053 L F
.54243 .78271 m .54566 .78053 L .54417 .78288 L F
.108 0 .088 r
.54644 .77931 m .54702 .77866 L .54566 .78053 L F
.623 .111 .009 r
.54702 .77866 m .54858 .78066 L .54566 .78053 L F
.54702 .77866 m .5491 .77939 L .54858 .78066 L F
.929 .972 .738 r
.66638 .52567 m .66518 .52777 L .66467 .52678 L F
.573 .514 .751 r
.52971 .78225 m .53176 .7788 L .52868 .7788 L F
.52971 .78225 m .53195 .78189 L .53176 .7788 L F
.447 .054 .201 r
.44388 .6957 m .44257 .69778 L .44036 .69804 L F
.533 .216 .376 r
.44601 .69498 m .44257 .69778 L .44388 .6957 L F
.776 .652 .726 r
.57842 .56917 m .58069 .57307 L .57682 .57231 L F
.968 .921 .588 r
.58037 .57525 m .58013 .57497 L .58092 .57227 L F
.776 .652 .726 r
.58069 .57307 m .58072 .57312 L .58067 .57311 L F
.58069 .57307 m .58067 .57311 L .57682 .57231 L F
.772 .539 .582 r
.58067 .57311 m .57619 .5743 L .57682 .57231 L F
.58072 .57312 m .58067 .57314 L .58067 .57311 L F
.58067 .57314 m .57619 .5743 L .58067 .57311 L F
.58072 .57312 m .57992 .57474 L .57619 .5743 L F
.968 .921 .588 r
.58069 .57307 m .58088 .57237 L .58092 .57227 L F
.762 .648 .736 r
.58095 .57213 m .58072 .57312 L .58069 .57307 L F
.58095 .57213 m .58069 .57307 L .57842 .56917 L F
.968 .921 .588 r
.58067 .57311 m .57992 .57474 L .58088 .57237 L F
.58067 .57311 m .58088 .57237 L .58069 .57307 L F
.58013 .57497 m .57998 .5748 L .58067 .57311 L F
.57998 .5748 m .57992 .57474 L .58067 .57311 L F
.58092 .57227 m .57992 .57474 L .58095 .57213 L F
.973 .816 .4 r
.58037 .57525 m .5796 .57709 L .57992 .57474 L F
.5 .821 1 r
.40928 .69778 m .41039 .69663 L .41164 .69708 L F
.40928 .69778 m .40815 .69712 L .41039 .69663 L F
.371 .265 .601 r
.27287 .62222 m .27119 .6257 L .27078 .62333 L F
.57 .364 .563 r
.50512 .73743 m .50768 .73744 L .50761 .73477 L F
.472 .288 .55 r
.50761 .73477 m .50973 .73689 L .50993 .73468 L F
.50761 .73477 m .50768 .73744 L .50973 .73689 L F
.586 .159 .198 r
.54283 .78842 m .54461 .78982 L .54217 .78946 L F
.377 0 0 r
.54962 .72848 m .55169 .72912 L .55301 .72919 L F
.718 .187 0 r
.55169 .72912 m .55506 .7313 L .55301 .72919 L F
.563 .364 .569 r
.28059 .72081 m .28282 .72092 L .28355 .71788 L F
0 .051 .579 r
.66882 .49491 m .67035 .4965 L .67082 .4972 L F
.922 .957 .789 r
.66837 .49924 m .67082 .4972 L .67035 .4965 L F
.323 0 0 r
.43535 .68877 m .43756 .68859 L .43909 .6871 L F
.602 .219 .289 r
.43756 .68859 m .44126 .68673 L .43909 .6871 L F
.418 0 0 r
.50152 .81504 m .50497 .81586 L .50362 .81578 L F
.315 .8 .888 r
.50362 .81578 m .50497 .81586 L .50722 .81541 L F
.997 .772 .432 r
.59773 .71452 m .5976 .71743 L .59848 .71808 L F
.718 .446 0 r
.5976 .71743 m .59838 .72045 L .59848 .71808 L F
.667 .313 .364 r
.45946 .69154 m .4575 .68982 L .45979 .68961 L F
.45946 .69154 m .4562 .69191 L .4575 .68982 L F
.653 .417 .549 r
.52123 .73206 m .52441 .73406 L .52441 .73209 L F
.656 .352 .446 r
.52441 .73406 m .5267 .73412 L .52441 .73209 L F
.618 .364 .511 r
.52441 .73209 m .5267 .73412 L .52678 .73257 L F
0 .33 .761 r
.64843 .48983 m .65081 .49135 L .65034 .49138 L F
.276 .504 .895 r
.72689 .4914 m .7289 .49396 L .72748 .49263 L F
.579 .716 .937 r
.72279 .49665 m .72422 .49829 L .72036 .49715 L F
.72036 .49715 m .72422 .49829 L .72279 .49665 L F
.801 .781 .834 r
.72525 .49722 m .72422 .49829 L .72279 .49665 L F
.72525 .49722 m .72422 .49829 L .72279 .49665 L F
.579 .716 .937 r
.72279 .49665 m .72422 .49829 L .72036 .49715 L F
.489 .165 .344 r
.51219 .73944 m .50851 .74262 L .5087 .74058 L F
.51219 .73944 m .51079 .74238 L .50851 .74262 L F
.658 .345 .431 r
.51421 .74195 m .51219 .73944 L .51381 .74081 L F
.51421 .74195 m .51079 .74238 L .51219 .73944 L F
.808 .673 .714 r
.59986 .73198 m .60038 .72962 L .59864 .72864 L F
.749 .581 .667 r
.58282 .55884 m .58617 .56159 L .5825 .56132 L F
.728 .564 .668 r
.5825 .56132 m .58617 .56159 L .58469 .56477 L F
.6 .659 .879 r
.70555 .48579 m .7042 .48899 L .70317 .48651 L F
.70555 .48579 m .70656 .48843 L .7042 .48899 L F
.46 .489 .802 r
.70785 .49185 m .70739 .49358 L .7042 .48899 L F
.598 .354 .518 r
.61261 .57536 m .6129 .57774 L .60952 .5781 L F
.647 .389 .514 r
.61505 .57756 m .61261 .57536 L .615 .57515 L F
.61505 .57756 m .6129 .57774 L .61261 .57536 L F
.929 .972 .738 r
.66638 .52567 m .66467 .52678 L .66532 .52455 L F
.658 .123 0 r
.5559 .73309 m .55599 .7326 L .55506 .7313 L F
.5559 .73309 m .55798 .73466 L .55599 .7326 L F
.599 .831 .988 r
.45934 .64633 m .45573 .646 L .45792 .6452 L F
.585 .809 .985 r
.46147 .64566 m .45934 .64633 L .45792 .6452 L F
.948 .753 .29 r
.6622 .51102 m .66179 .50757 L .66282 .50879 L F
.352 .403 .775 r
.40014 .68897 m .39896 .69056 L .39785 .68705 L F
.382 .445 .801 r
.40014 .68897 m .40137 .69197 L .39896 .69056 L F
.309 0 .067 r
.4059 .67065 m .40301 .67208 L .40347 .67039 L F
.601 .427 .618 r
.40572 .66773 m .4059 .67065 L .40347 .67039 L F
.414 .136 .38 r
.72955 .51116 m .72903 .51356 L .72684 .51346 L F
.412 .098 .319 r
.72885 .51507 m .72684 .51346 L .72903 .51356 L F
.72885 .51507 m .72653 .5157 L .72684 .51346 L F
.653 .494 .656 r
.5841 .57843 m .58653 .57541 L .58606 .57793 L F
.654 .582 .762 r
.48082 .65339 m .47764 .65067 L .47968 .65037 L F
.706 .638 .778 r
.48334 .6511 m .48082 .65339 L .47968 .65037 L F
.557 .929 .796 r
.71286 .5215 m .71298 .52113 L .71147 .52246 L F
.553 .925 .781 r
.71298 .52113 m .71104 .52243 L .71147 .52246 L F
.742 .666 .775 r
.49126 .66195 m .49253 .66538 L .48918 .66483 L F
.587 .58 .813 r
.49473 .66484 m .49253 .66538 L .49126 .66195 L F
.562 .155 .228 r
.49604 .75368 m .4986 .75377 L .49961 .75205 L F
.623 .221 .262 r
.49961 .75205 m .4986 .75377 L .50164 .75364 L F
.642 .163 .1 r
.5365 .78095 m .53786 .7797 L .54028 .78133 L F
.556 .296 .477 r
.53786 .7797 m .53973 .77957 L .54028 .78133 L F
.494 .345 .608 r
.40796 .66993 m .4059 .67065 L .40572 .66773 L F
.46 0 .067 r
.39836 .65243 m .40059 .65254 L .40206 .65097 L F
.356 0 0 r
.40059 .65254 m .40424 .65127 L .40206 .65097 L F
.723 .94 .956 r
.77561 .6168 m .77706 .6147 L .77474 .61587 L F
.77561 .6168 m .77838 .61528 L .77706 .6147 L F
.087 .346 .818 r
.50872 .78431 m .50774 .78491 L .50561 .78176 L F
0 .138 .658 r
.50872 .78431 m .50941 .78695 L .50774 .78491 L F
.252 0 .24 r
.53714 .76727 m .53509 .76816 L .53751 .76564 L F
.51 .168 .322 r
.53751 .76564 m .53953 .767 L .53714 .76727 L F
.538 .143 .241 r
.54073 .76515 m .53953 .767 L .53751 .76564 L F
.592 .446 .652 r
.47366 .67544 m .476 .67267 L .47423 .67318 L F
.273 0 .211 r
.62092 .52364 m .61866 .52448 L .62116 .52255 L F
.559 .244 .392 r
.62092 .52364 m .6178 .52639 L .61866 .52448 L F
.704 .655 .798 r
.47764 .65067 m .47413 .64859 L .47629 .64769 L F
.599 .55 .771 r
.47845 .64661 m .47764 .65067 L .47629 .64769 L F
.47845 .64661 m .47968 .65037 L .47764 .65067 L F
.804 .324 0 r
.55902 .73617 m .55915 .73533 L .55798 .73466 L F
.55902 .73617 m .56018 .73692 L .55915 .73533 L F
.393 0 .109 r
.29034 .60588 m .28886 .60784 L .28671 .60806 L F
.111 0 0 r
.29083 .60698 m .29034 .60588 L .29239 .60537 L F
.29083 .60698 m .28886 .60784 L .29034 .60588 L F
.302 0 .148 r
.73204 .51101 m .72903 .51356 L .72955 .51116 L F
.472 .18 .387 r
.57484 .67886 m .57679 .67781 L .57375 .6787 L F
.667 .829 .961 r
.45573 .646 m .45338 .6471 L .45194 .64575 L F
.144 .109 .556 r
.56932 .77015 m .56834 .76836 L .57065 .76851 L F
.56932 .77015 m .56849 .77139 L .56834 .76836 L F
.503 .178 .349 r
.53449 .72594 m .53687 .72567 L .53714 .7241 L F
.738 .779 .886 r
.67785 .48936 m .68069 .49096 L .68024 .48831 L F
.761 .718 .812 r
.68024 .48831 m .68069 .49096 L .68372 .4887 L F
.493 .297 .542 r
.28355 .71788 m .28282 .72092 L .28493 .72035 L F
.262 0 .084 r
.49523 .7436 m .49595 .74495 L .49703 .74257 L F
.49523 .7436 m .494 .7456 L .49595 .74495 L F
.763 .898 .937 r
.67371 .48016 m .67133 .47896 L .67227 .47927 L F
.287 .699 .972 r
.67227 .47927 m .67546 .48018 L .67371 .48016 L F
.042 0 .306 r
.62466 .56917 m .62308 .5723 L .62296 .56996 L F
.434 .316 .619 r
.37015 .66495 m .37202 .66455 L .3719 .66188 L F
.452 .386 .693 r
.37015 .66495 m .37245 .66688 L .37202 .66455 L F
.518 .385 .639 r
.37015 .66495 m .37039 .66739 L .37245 .66688 L F
.778 .294 .075 r
.57 .72236 m .5695 .72039 L .56802 .71994 L F
.57 .72236 m .5712 .72236 L .5695 .72039 L F
0 .486 .739 r
.28552 .58571 m .28752 .58609 L .28904 .58646 L F
.39 .802 .979 r
.28752 .58609 m .29112 .58632 L .28904 .58646 L F
.842 .687 .691 r
.59681 .73137 m .59986 .73198 L .59864 .72864 L F
.811 .553 .548 r
.59666 .73393 m .59986 .73198 L .59681 .73137 L F
.59666 .73393 m .59989 .73424 L .59986 .73198 L F
.156 .693 .835 r
.4468 .65828 m .44317 .6583 L .44502 .65844 L F
.624 .544 .744 r
.37768 .71798 m .38111 .71773 L .37997 .71424 L F
.615 .459 .646 r
.37768 .71798 m .37842 .72022 L .38111 .71773 L F
.921 .966 .783 r
.60641 .51984 m .60442 .5228 L .60459 .52065 L F
.948 .958 .711 r
.60641 .51984 m .60585 .51916 L .60743 .51604 L F
.905 .978 .795 r
.60641 .51984 m .60459 .52065 L .60585 .51916 L F
.549 .51 .765 r
.75038 .59731 m .74902 .60108 L .74823 .59756 L F
.75038 .59731 m .75132 .60063 L .74902 .60108 L F
.553 .543 .797 r
.75132 .60063 m .75239 .60219 L .74902 .60108 L F
.868 .465 .265 r
.6322 .52283 m .63075 .52337 L .62905 .52218 L F
.6322 .52283 m .63264 .52447 L .63075 .52337 L F
.019 0 .35 r
.46601 .79157 m .46695 .79171 L .46545 .79206 L F
.959 .631 .343 r
.46691 .79028 m .4678 .79183 L .46695 .79171 L F
.019 0 .35 r
.46835 .78955 m .46691 .79028 L .46695 .79171 L F
.46835 .78955 m .46695 .79171 L .46601 .79157 L F
.959 .631 .343 r
.4678 .79183 m .46873 .79344 L .46695 .79171 L F
.603 .1 0 r
.46695 .79171 m .46873 .79344 L .47047 .79543 L F
.251 0 .177 r
.40081 .67244 m .39786 .67549 L .39802 .67335 L F
.753 .687 .788 r
.35233 .70572 m .35497 .70362 L .35246 .70408 L F
.775 .668 .745 r
.39717 .71432 m .39478 .71687 L .39405 .71552 L F
.227 0 0 r
.31415 .64863 m .31314 .64955 L .3114 .64995 L F
.273 0 0 r
.31632 .64823 m .31314 .64955 L .31415 .64863 L F
.231 0 .163 r
.63476 .55653 m .63691 .55558 L .63411 .55788 L F
.235 0 0 r
.25315 .59109 m .25688 .58913 L .25475 .58947 L F
.59 .561 .789 r
.71134 .5085 m .7137 .50795 L .71228 .50489 L F
0 0 0 r
.49038 .7497 m .48934 .7507 L .48838 .75132 L F
.681 .254 0 r
.4892 .75299 m .48999 .75402 L .489 .75235 L F
.4892 .75299 m .489 .75235 L .48838 .75132 L F
.733 .479 .545 r
.48838 .75132 m .48999 .75402 L .49178 .75383 L F
.001 0 .155 r
.49021 .75185 m .48924 .7531 L .4892 .75299 L F
.861 .671 .645 r
.48672 .75537 m .48999 .75402 L .4892 .75299 L F
.001 0 .155 r
.48924 .7531 m .48841 .75415 L .4892 .75299 L F
.681 .254 0 r
.4892 .75299 m .48838 .75132 L .48934 .7507 L F
.465 .617 .915 r
.47156 .64361 m .47063 .64536 L .46971 .64383 L F
.607 .389 .559 r
.47267 .64675 m .47063 .64536 L .47156 .64361 L F
.47267 .64675 m .47064 .64801 L .47063 .64536 L F
.594 .15 .167 r
.71137 .49042 m .7096 .489 L .70888 .48998 L F
.469 .09 .238 r
.49653 .76795 m .49868 .76791 L .49996 .76572 L F
.665 .303 .349 r
.49996 .76572 m .49868 .76791 L .50193 .76762 L F
.436 .322 .626 r
.49996 .76572 m .50193 .76762 L .5018 .76502 L F
.49996 .76572 m .50193 .76762 L .5018 .76502 L F
.252 .535 .92 r
.35552 .59802 m .3519 .59553 L .35363 .59533 L F
.455 .581 .891 r
.35655 .59617 m .35552 .59802 L .35363 .59533 L F
.498 .636 .916 r
.35655 .59617 m .3575 .59783 L .35552 .59802 L F
.772 .699 .782 r
.6234 .50561 m .62084 .50843 L .61978 .50503 L F
.689 .421 .512 r
.48637 .68699 m .48261 .68915 L .48264 .68725 L F
.48637 .68699 m .48497 .68976 L .48261 .68915 L F
.663 .391 .498 r
.48862 .68926 m .48637 .68699 L .48832 .68727 L F
.48862 .68926 m .48497 .68976 L .48637 .68699 L F
.96 .884 .493 r
.62041 .5032 m .61978 .50503 L .62035 .50385 L F
.776 .443 .424 r
.62035 .50385 m .6234 .50561 L .61978 .50503 L F
.96 .884 .493 r
.62041 .5032 m .61978 .50503 L .62035 .50385 L F
.46 .627 .925 r
.68363 .48088 m .68266 .48241 L .68129 .48127 L F
.68363 .48088 m .68475 .48249 L .68266 .48241 L F
.571 .394 .604 r
.58569 .6928 m .58585 .69543 L .58345 .69563 L F
.05 0 .141 r
.58345 .69563 m .58531 .69513 L .58569 .6928 L F
.88 .786 .753 r
.58343 .69376 m .58433 .69516 L .58528 .69517 L F
.58549 .69486 m .58528 .69517 L .58609 .69519 L F
.58343 .69376 m .58528 .69517 L .58549 .69486 L F
.05 0 .141 r
.58531 .69513 m .58543 .69509 L .58545 .69492 L F
.58531 .69513 m .58545 .69492 L .58569 .6928 L F
.347 .816 .909 r
.58585 .69543 m .58543 .69509 L .58345 .69563 L F
.414 .773 .995 r
.31371 .58915 m .31301 .59015 L .31161 .58928 L F
.31371 .58915 m .31499 .58993 L .31301 .59015 L F
.351 0 0 r
.62272 .51983 m .62472 .51999 L .62481 .51863 L F
0 0 0 r
.62481 .51863 m .62769 .51771 L .62837 .51698 L F
.606 .37 .533 r
.62472 .51999 m .62769 .51771 L .62481 .51863 L F
.622 .649 .856 r
.75392 .58846 m .75224 .5892 L .75383 .58592 L F
.666 .45 .583 r
.59006 .68717 m .59126 .68498 L .58969 .68419 L F
.59006 .68717 m .59232 .6868 L .59126 .68498 L F
.313 .775 .944 r
.30593 .65051 m .30645 .64991 L .30449 .64973 L F
.30593 .65051 m .30802 .65028 L .30645 .64991 L F
.239 0 .217 r
.24151 .59758 m .24321 .59699 L .24423 .59464 L F
.379 .045 .267 r
.24321 .59699 m .2463 .59422 L .24423 .59464 L F
.77 .711 .797 r
.51694 .76582 m .5203 .76576 L .51916 .76547 L F
.169 .707 .774 r
.52267 .76507 m .51916 .76547 L .5203 .76576 L F
.608 .581 .798 r
.5203 .76576 m .52368 .76832 L .52267 .76507 L F
.536 .396 .637 r
.36846 .67042 m .37064 .6699 L .37039 .66739 L F
.499 .359 .621 r
.36849 .67342 m .37064 .6699 L .36846 .67042 L F
.41 .747 .994 r
.34364 .59233 m .3429 .59341 L .34146 .59259 L F
.34364 .59233 m .34543 .59339 L .3429 .59341 L F
.856 .7 .688 r
.60118 .73743 m .60158 .73501 L .59989 .73424 L F
.799 .535 .539 r
.59401 .70077 m .59608 .69839 L .59475 .6979 L F
.59401 .70077 m .5961 .70087 L .59608 .69839 L F
0 0 0 r
.62138 .55025 m .62319 .54938 L .6241 .54781 L F
.172 0 0 r
.62562 .5458 m .62466 .54758 L .62763 .54578 L F
0 0 0 r
.6241 .54781 m .62466 .54758 L .62538 .54625 L F
.6241 .54781 m .62538 .54625 L .62535 .54616 L F
.62386 .54711 m .62763 .54578 L .62466 .54758 L F
.62548 .54654 m .62566 .54665 L .62763 .54578 L F
.62386 .54711 m .62552 .54669 L .62548 .54654 L F
.62552 .54669 m .62566 .54665 L .62548 .54654 L F
.62535 .54616 m .62538 .54625 L .62562 .5458 L F
.6241 .54781 m .62319 .54938 L .62466 .54758 L F
.543 .537 .798 r
.75802 .61741 m .7597 .61443 L .75757 .61425 L F
.75802 .61741 m .76082 .61687 L .7597 .61443 L F
.547 .753 .973 r
.33222 .60446 m .3335 .6025 L .3313 .60356 L F
.588 .583 .814 r
.33093 .6035 m .33276 .60499 L .33222 .60446 L F
.571 0 0 r
.33093 .6035 m .33222 .60446 L .33047 .60396 L F
.547 .753 .973 r
.33222 .60446 m .3313 .60356 L .33047 .60396 L F
.588 .583 .814 r
.33276 .60499 m .33403 .60602 L .33222 .60446 L F
.499 .637 .916 r
.33403 .60602 m .33508 .6041 L .33222 .60446 L F
.33403 .60602 m .33578 .60561 L .33508 .6041 L F
.382 .238 .559 r
.33419 .60857 m .33578 .60561 L .33403 .60602 L F
.372 0 .104 r
.63455 .50466 m .63121 .5067 L .63207 .50523 L F
.138 .269 .737 r
.50512 .73743 m .50692 .73886 L .50768 .73744 L F
.518 .529 .806 r
.64244 .51594 m .64028 .51659 L .63938 .51385 L F
.546 .23 .384 r
.64285 .51819 m .64028 .51659 L .64244 .51594 L F
.64285 .51819 m .63983 .51903 L .64028 .51659 L F
.339 .723 .984 r
.50242 .68644 m .50132 .68413 L .50106 .68479 L F
.848 .718 .719 r
.58969 .71419 m .58892 .71812 L .58688 .71794 L F
.697 .932 .966 r
.58969 .71419 m .58714 .71477 L .58892 .71369 L F
.848 .718 .719 r
.58969 .71419 m .58688 .71794 L .58714 .71477 L F
.622 .259 .334 r
.51211 .77661 m .51008 .77862 L .50782 .77688 L F
.696 .358 .4 r
.51456 .7783 m .51211 .77661 L .51354 .77702 L F
.51456 .7783 m .51008 .77862 L .51211 .77661 L F
.66 .643 .822 r
.35405 .72807 m .35511 .73051 L .35535 .72928 L F
.571 0 0 r
.33093 .6035 m .33047 .60396 L .32897 .6025 L F
.831 .41 0 r
.66868 .53132 m .66834 .53185 L .66613 .5299 L F
.66868 .53132 m .6694 .53281 L .66834 .53185 L F
.491 .541 .836 r
.4035 .6916 m .4031 .69507 L .40137 .69197 L F
.4035 .6916 m .40497 .69477 L .4031 .69507 L F
.793 .745 .809 r
.48461 .6449 m .48566 .64811 L .48204 .64775 L F
.761 .674 .767 r
.48555 .64939 m .48204 .64775 L .48566 .64811 L F
.604 .552 .769 r
.48819 .6463 m .48566 .64811 L .48461 .6449 L F
.48819 .6463 m .48812 .64765 L .48566 .64811 L F
.665 .567 .734 r
.48812 .64765 m .48555 .64939 L .48566 .64811 L F
0 0 .214 r
.6609 .51942 m .66182 .51618 L .6609 .51678 L F
.901 .7 .622 r
.65821 .52147 m .6609 .51942 L .6609 .51678 L F
.9 .679 .593 r
.59605 .72852 m .59861 .72622 L .59765 .72556 L F
.59605 .72852 m .59864 .72864 L .59861 .72622 L F
.447 0 0 r
.49873 .75968 m .49709 .76009 L .49502 .75966 L F
.613 .045 0 r
.49873 .75968 m .49943 .76093 L .49709 .76009 L F
.49873 .75968 m .50124 .76135 L .49943 .76093 L F
.048 .596 .835 r
.50142 .76123 m .49824 .76066 L .49943 .76093 L F
.14 .67 .865 r
.49943 .76093 m .49529 .76075 L .49709 .76009 L F
.048 .596 .835 r
.49824 .76066 m .49813 .76064 L .49943 .76093 L F
.613 .045 0 r
.50124 .76135 m .50183 .76175 L .49943 .76093 L F
.427 .795 .995 r
.44071 .64737 m .44422 .6478 L .44208 .64779 L F
.575 .522 .758 r
.73413 .60079 m .73518 .60432 L .73711 .60241 L F
.592 .542 .768 r
.73518 .60432 m .73806 .60558 L .73711 .60241 L F
.38 .123 .394 r
.33196 .63686 m .33146 .63892 L .32955 .63951 L F
.426 .164 .411 r
.33351 .63835 m .33196 .63686 L .33398 .63639 L F
.33351 .63835 m .33146 .63892 L .33196 .63686 L F
.858 .968 .645 r
.51361 .76098 m .51437 .7588 L .51581 .76001 L F
.575 .715 .937 r
.76594 .61568 m .77003 .61746 L .7692 .61579 L F
.594 .684 .904 r
.77003 .61746 m .77149 .61536 L .7692 .61579 L F
.77003 .61746 m .77245 .61697 L .77149 .61536 L F
.311 .084 .398 r
.62904 .50777 m .6269 .51069 L .62723 .50866 L F
.757 .461 .484 r
.50289 .69022 m .49961 .69203 L .49971 .68942 L F
.50289 .69022 m .50315 .69239 L .49961 .69203 L F
.571 .039 0 r
.42689 .64868 m .42922 .64981 L .43058 .64914 L F
.623 .245 .306 r
.51763 .76116 m .52146 .75918 L .51897 .75887 L F
.27 .761 .91 r
.27816 .58445 m .28211 .58455 L .27992 .58487 L F
.63 .92 .646 r
.55926 .69982 m .5582 .70121 L .56087 .69866 L F
.593 .092 .034 r
.56087 .69866 m .563 .70008 L .55926 .69982 L F
.472 .237 .476 r
.56287 .69808 m .563 .70008 L .56087 .69866 L F
.321 .056 .346 r
.27534 .6171 m .27471 .61944 L .27302 .62003 L F
.492 .277 .514 r
.27756 .61459 m .27735 .61686 L .27534 .6171 L F
.348 .038 .291 r
.27735 .61686 m .27471 .61944 L .27534 .6171 L F
.563 .841 .997 r
.53058 .76477 m .53185 .76558 L .52836 .76543 L F
.553 .613 .867 r
.66715 .48011 m .66548 .48208 L .66457 .48074 L F
.66624 .48007 m .66457 .48074 L .66406 .47998 L F
.66715 .48011 m .66457 .48074 L .66624 .48007 L F
.414 .863 .864 r
.66298 .48083 m .66624 .48007 L .66406 .47998 L F
.66433 .4805 m .6651 .48004 L .66643 .48 L F
.66298 .48083 m .66643 .48 L .66624 .48007 L F
.66624 .48007 m .66659 .47999 L .66406 .47998 L F
.66624 .48007 m .66643 .48 L .66659 .47999 L F
.669 .645 .817 r
.66881 .47927 m .66731 .47991 L .66659 .47999 L F
.553 .613 .867 r
.66731 .47991 m .66658 .47993 L .66659 .47999 L F
.66658 .47993 m .66406 .47998 L .66659 .47999 L F
.66731 .47991 m .66715 .48011 L .66626 .48007 L F
.66658 .47993 m .66626 .48007 L .66406 .47998 L F
.459 .887 .874 r
.66659 .47999 m .66643 .48 L .66658 .47993 L F
.553 .613 .867 r
.66731 .47991 m .66626 .48007 L .66658 .47993 L F
.459 .887 .874 r
.66658 .47993 m .6651 .48004 L .66651 .47953 L F
.66643 .48 m .6651 .48004 L .66658 .47993 L F
.66659 .47999 m .66651 .47953 L .66783 .47905 L F
.037 0 .471 r
.6651 .48004 m .66659 .47901 L .66783 .47905 L F
.6651 .48004 m .66577 .48214 L .66655 .47918 L F
.6651 .48004 m .66655 .47918 L .66659 .47901 L F
.414 .863 .864 r
.66298 .48083 m .6651 .48004 L .66433 .4805 L F
.685 .331 .369 r
.54319 .7654 m .53953 .767 L .54073 .76515 L F
.851 .739 .74 r
.58282 .55884 m .57934 .56074 L .58112 .55775 L F
.58282 .55884 m .58104 .56133 L .57934 .56074 L F
.795 .65 .702 r
.58282 .55884 m .5825 .56132 L .58104 .56133 L F
.877 .798 .769 r
.58319 .55476 m .58282 .55884 L .58112 .55775 L F
.594 .368 .543 r
.51882 .73454 m .52116 .7343 L .52123 .73206 L F
.653 .417 .549 r
.52123 .73206 m .52116 .7343 L .52441 .73406 L F
.391 .076 .307 r
.63912 .49701 m .64077 .49855 L .64164 .49718 L F
.63912 .49701 m .63851 .49933 L .64077 .49855 L F
.931 .774 .665 r
.6591 .5246 m .66007 .5279 L .66029 .52544 L F
.765 .684 .774 r
.70778 .49402 m .71115 .49449 L .71003 .49132 L F
.175 0 .008 r
.70844 .49667 m .71052 .49604 L .71115 .49449 L F
.265 .268 .675 r
.71115 .49449 m .71217 .49061 L .71003 .49132 L F
.71115 .49449 m .7128 .49357 L .71217 .49061 L F
.106 0 0 r
.71115 .49449 m .71247 .49511 L .7128 .49357 L F
.71115 .49449 m .71052 .49604 L .71247 .49511 L F
.915 .98 .75 r
.60335 .52439 m .60273 .52382 L .60442 .5228 L F
.934 .967 .741 r
.60442 .5228 m .60273 .52382 L .60459 .52065 L F
.444 .278 .56 r
.27941 .6138 m .27735 .61686 L .27756 .61459 L F
.486 .316 .576 r
.51008 .77862 m .50967 .78107 L .50782 .77688 L F
.509 .336 .583 r
.51008 .77862 m .5091 .77994 L .50967 .78107 L F
.5091 .77994 m .50799 .78145 L .50967 .78107 L F
.501 .327 .577 r
.51008 .78111 m .50968 .78117 L .51008 .77862 L F
.50962 .78105 m .50799 .78145 L .5091 .77994 L F
.535 .784 .989 r
.50962 .78105 m .50561 .78176 L .50443 .77866 L F
.50967 .78107 m .50946 .78111 L .50962 .78105 L F
.50946 .78111 m .50561 .78176 L .50962 .78105 L F
.501 .327 .577 r
.50968 .78117 m .50896 .78129 L .50962 .78105 L F
.50896 .78129 m .50799 .78145 L .50962 .78105 L F
.706 .417 .484 r
.5091 .77994 m .50967 .78107 L .50962 .78105 L F
.501 .327 .577 r
.50968 .78117 m .5091 .77994 L .51008 .77862 L F
.706 .417 .484 r
.50763 .77698 m .5091 .77994 L .50443 .77866 L F
.5091 .77994 m .50962 .78105 L .50443 .77866 L F
.50782 .77688 m .50967 .78107 L .50763 .77698 L F
.217 0 0 r
.41387 .69708 m .41595 .69685 L .41756 .69566 L F
.322 0 .045 r
.41595 .69685 m .41951 .69467 L .41756 .69566 L F
.511 .349 .598 r
.588 .69477 m .58585 .69543 L .58569 .6928 L F
.925 .598 .404 r
.58343 .69376 m .58555 .6949 L .58543 .69509 L F
.58555 .6949 m .58609 .69519 L .58543 .69509 L F
.622 .926 .972 r
.58543 .69509 m .588 .69477 L .58645 .69345 L F
.58543 .69509 m .58645 .69345 L .58569 .6928 L F
.76 .635 .722 r
.55898 .70372 m .55644 .70359 L .5582 .70121 L F
.728 .404 .431 r
.55898 .70372 m .55836 .70594 L .55644 .70359 L F
.396 .414 .761 r
.5582 .70121 m .561 .70339 L .55898 .70372 L F
.286 0 .277 r
.561 .70339 m .55836 .70594 L .55898 .70372 L F
.161 0 0 r
.4136 .66731 m .40976 .66882 L .41148 .66793 L F
.191 0 0 r
.40424 .65127 m .40599 .65151 L .40777 .65095 L F
.523 .064 .106 r
.40599 .65151 m .40981 .65018 L .40777 .65095 L F
.359 .08 .348 r
.50966 .75592 m .50678 .75929 L .50647 .75693 L F
.50966 .75592 m .50866 .75901 L .50678 .75929 L F
.475 .188 .398 r
.51136 .7585 m .50966 .75592 L .51091 .75593 L F
.51136 .7585 m .50866 .75901 L .50955 .75627 L F
.738 .625 .734 r
.51437 .7588 m .51251 .7619 L .51107 .76011 L F
.51437 .7588 m .51107 .76011 L .51136 .7585 L F
.532 .587 .855 r
.51251 .7619 m .51136 .7585 L .51107 .76011 L F
.51251 .7619 m .50866 .75901 L .50992 .75877 L F
.861 .622 .576 r
.51251 .7619 m .51109 .76018 L .51107 .76011 L F
.532 .587 .855 r
.51251 .7619 m .50992 .75877 L .51136 .7585 L F
.51251 .7619 m .51124 .76272 L .50866 .75901 L F
.861 .622 .576 r
.51251 .7619 m .51212 .76422 L .51109 .76018 L F
.786 .502 .507 r
.5097 .75784 m .51242 .7598 L .51136 .7585 L F
.51242 .7598 m .51285 .76011 L .51136 .7585 L F
.475 .188 .398 r
.51136 .7585 m .50955 .75627 L .50966 .75592 L F
0 .155 .685 r
.591 .72908 m .59178 .7282 L .58975 .72579 L F
.457 .501 .816 r
.59164 .73178 m .59178 .7282 L .591 .72908 L F
.236 0 0 r
.422 .70553 m .41814 .70773 L .41974 .70599 L F
.717 .184 0 r
.55069 .71732 m .54953 .71706 L .54735 .715 L F
.227 0 0 r
.55069 .71732 m .55284 .71792 L .54953 .71706 L F
.678 .316 .354 r
.49763 .78165 m .49636 .78398 L .4942 .78191 L F
.048 0 0 r
.49973 .78273 m .49636 .78398 L .49763 .78165 L F
.89 .534 .053 r
.49111 .81214 m .49208 .81317 L .49238 .81465 L F
.436 .816 .991 r
.76876 .57664 m .76724 .57763 L .76623 .57688 L F
.76876 .57664 m .77002 .57715 L .76724 .57763 L F
.444 .496 .818 r
.67719 .54029 m .67871 .53751 L .67639 .53866 L F
.193 .679 .927 r
.67719 .54029 m .68093 .5407 L .67985 .54064 L F
.444 .496 .818 r
.67719 .54029 m .67985 .54064 L .67871 .53751 L F
.867 .926 .863 r
.65337 .5225 m .65093 .5252 L .65003 .52426 L F
.083 .517 .903 r
.30453 .58769 m .30424 .58839 L .30247 .58744 L F
.30453 .58769 m .30596 .58887 L .30424 .58839 L F
.113 .666 .753 r
.55668 .71759 m .55529 .71767 L .55284 .71792 L F
.694 .288 .273 r
.55668 .71759 m .55507 .71942 L .55529 .71767 L F
.55668 .71759 m .55869 .71977 L .55507 .71942 L F
.358 .738 .987 r
.77468 .60514 m .77339 .60597 L .77242 .60513 L F
.77468 .60514 m .77575 .60595 L .77339 .60597 L F
.585 .797 .98 r
.63203 .48691 m .63085 .48632 L .63187 .48457 L F
.63203 .48691 m .63103 .48884 L .63085 .48632 L F
.613 .547 .757 r
.52267 .76507 m .52368 .76832 L .526 .76797 L F
.604 .485 .691 r
.52368 .76832 m .52369 .77086 L .526 .76797 L F
.618 .286 .385 r
.54442 .77297 m .54678 .77309 L .54462 .77126 L F
.579 .423 .634 r
.54462 .77126 m .5473 .77076 L .54709 .76803 L F
.543 .309 .51 r
.54462 .77126 m .54678 .77309 L .5473 .77076 L F
.672 .514 .663 r
.47093 .67796 m .47366 .67544 L .47134 .67615 L F
.85 .987 .855 r
.52723 .77882 m .52868 .7788 L .53089 .77622 L F
.573 .447 .67 r
.52868 .7788 m .53176 .7788 L .53089 .77622 L F
.736 .506 .581 r
.58764 .58105 m .58772 .58347 L .5841 .58309 L F
.691 .483 .601 r
.58764 .58105 m .58971 .58342 L .58772 .58347 L F
.58764 .58105 m .58967 .58091 L .58971 .58342 L F
0 0 .038 r
.5752 .68573 m .5744 .68898 L .57361 .68993 L F
.67 .355 .432 r
.5776 .68888 m .5752 .68573 L .57746 .68734 L F
.5776 .68888 m .5744 .68898 L .5752 .68573 L F
.773 .997 .819 r
.71565 .48732 m .71137 .49042 L .71456 .48547 L F
.608 .653 .869 r
.71699 .48483 m .71565 .48732 L .71456 .48547 L F
.71699 .48483 m .71835 .48782 L .71565 .48732 L F
.359 0 .041 r
.62361 .52259 m .62092 .52364 L .62116 .52255 L F
.337 .454 .832 r
.5457 .71212 m .54735 .715 L .54854 .71385 L F
.268 .341 .753 r
.54735 .715 m .54953 .71706 L .54854 .71385 L F
.517 .565 .843 r
.76618 .5867 m .76808 .58493 L .76529 .58509 L F
.76618 .5867 m .76846 .58657 L .76808 .58493 L F
.214 0 .149 r
.33038 .64091 m .32955 .63951 L .33146 .63892 L F
.33038 .64091 m .32855 .6417 L .32955 .63951 L F
.652 .273 .314 r
.5788 .67781 m .58076 .6782 L .58193 .67629 L F
.719 .352 .353 r
.58193 .67629 m .58076 .6782 L .58368 .67823 L F
.927 .694 .566 r
.64415 .49173 m .64235 .49254 L .64359 .48932 L F
.64415 .49173 m .64392 .49406 L .64235 .49254 L F
.912 .875 .786 r
.65531 .51937 m .65224 .52149 L .65381 .5184 L F
.65531 .51937 m .65337 .5225 L .65224 .52149 L F
.949 .836 .697 r
.65528 .51558 m .65531 .51937 L .65381 .5184 L F
.674 .378 .463 r
.49192 .68842 m .48832 .68727 L .49212 .68674 L F
.49192 .68842 m .48862 .68926 L .48832 .68727 L F
.562 .519 .765 r
.37744 .7006 m .37865 .70416 L .38057 .70367 L F
.431 .397 .72 r
.37865 .70416 m .38096 .70614 L .38057 .70367 L F
.37865 .70416 m .37951 .70689 L .38096 .70614 L F
.654 .424 .558 r
.59341 .58088 m .58971 .58342 L .58967 .58091 L F
.565 .535 .78 r
.5437 .74128 m .54658 .74259 L .54551 .7389 L F
.356 .652 .967 r
.27287 .65271 m .273 .65158 L .26993 .65076 L F
.27287 .65271 m .27373 .65279 L .273 .65158 L F
.847 .549 .484 r
.51545 .76728 m .51654 .77064 L .519 .7701 L F
.896 .513 .297 r
.51837 .77283 m .519 .7701 L .51654 .77064 L F
.51837 .77283 m .52001 .77328 L .519 .7701 L F
.812 .468 .405 r
.519 .7701 m .52001 .77328 L .52213 .77279 L F
.97 .711 .487 r
.56753 .77572 m .56893 .77651 L .56888 .77373 L F
.22 .722 .905 r
.4637 .65826 m .46031 .65795 L .46203 .65871 L F
.473 .784 .998 r
.32859 .59107 m .328 .59232 L .32653 .59132 L F
.32859 .59107 m .33007 .59201 L .328 .59232 L F
.759 .624 .711 r
.51524 .73159 m .51352 .73394 L .5171 .73266 L F
.676 .397 .491 r
.50993 .73468 m .5152 .73603 L .51352 .73394 L F
.50993 .73468 m .50973 .73689 L .5152 .73603 L F
.576 .181 .255 r
.50973 .73689 m .50982 .73695 L .5152 .73603 L F
.50982 .73695 m .51204 .73844 L .51484 .7363 L F
.50982 .73695 m .51484 .7363 L .5152 .73603 L F
.846 .609 .58 r
.51204 .73844 m .51508 .73659 L .5152 .73603 L F
.768 .445 .439 r
.5152 .73603 m .51508 .73659 L .51352 .73394 L F
.68 .422 .525 r
.51352 .73394 m .5149 .73629 L .5171 .73266 L F
.5149 .73629 m .51508 .73659 L .51526 .73625 L F
.5149 .73629 m .51526 .73625 L .5171 .73266 L F
.763 .521 .569 r
.51508 .73659 m .51876 .7369 L .5171 .73266 L F
.762 .521 .569 r
.5171 .73266 m .51876 .7369 L .51882 .73454 L F
.881 .756 .719 r
.65839 .52679 m .66007 .5279 L .6591 .5246 L F
.919 .703 .593 r
.65988 .52996 m .66007 .5279 L .65839 .52679 L F
.648 .135 .01 r
.38694 .65553 m .38515 .65403 L .38342 .65497 L F
.722 .598 .717 r
.49382 .68453 m .49408 .68731 L .49212 .68674 L F
.661 .354 .441 r
.49408 .68731 m .49192 .68842 L .49212 .68674 L F
.49408 .68731 m .49398 .68922 L .49192 .68842 L F
.422 .208 .48 r
.28139 .61117 m .27941 .6138 L .27968 .61156 L F
.74 .58 .677 r
.48635 .78736 m .48359 .78528 L .48593 .78495 L F
.48635 .78736 m .48397 .78764 L .48359 .78528 L F
.65 .657 .843 r
.48829 .78452 m .48635 .78736 L .48593 .78495 L F
.263 0 .293 r
.62701 .56407 m .62715 .566 L .62469 .56684 L F
.107 0 .276 r
.62843 .56507 m .62701 .56407 L .629 .56307 L F
.62843 .56507 m .62715 .566 L .62701 .56407 L F
.62 .732 .927 r
.76688 .60749 m .7654 .6097 L .76449 .60798 L F
.76688 .60749 m .76778 .60902 L .7654 .6097 L F
.636 .892 .986 r
.68556 .49703 m .6828 .49842 L .68258 .49831 L F
.502 0 0 r
.68258 .49831 m .68597 .4994 L .68556 .49703 L F
.765 .573 .638 r
.5825 .56132 m .58071 .56406 L .58104 .56133 L F
.5825 .56132 m .58469 .56477 L .58071 .56406 L F
.517 .318 .549 r
.73767 .59165 m .73538 .59221 L .73749 .59394 L F
.003 0 .061 r
.49634 .81388 m .49804 .81084 L .49517 .80947 L F
.491 .265 .498 r
.49746 .6761 m .49734 .6785 L .49518 .67883 L F
.357 .049 .297 r
.50052 .6737 m .49961 .67556 L .49746 .6761 L F
.431 .217 .486 r
.49961 .67556 m .49734 .6785 L .49746 .6761 L F
.26 .77 .807 r
.71953 .51963 m .71878 .51963 L .71644 .52016 L F
.199 0 0 r
.4139 .7087 m .41039 .71043 L .41176 .7091 L F
.985 .706 .355 r
.61154 .54918 m .61262 .55299 L .61302 .55221 L F
.918 .546 .298 r
.61302 .55221 m .61262 .55299 L .61313 .55269 L F
.705 .542 .665 r
.51354 .77702 m .51705 .77924 L .51456 .7783 L F
.51354 .77702 m .51828 .77732 L .51705 .77924 L F
.59 .803 .981 r
.30129 .63473 m .29977 .6356 L .29882 .63476 L F
.796 .458 .416 r
.55384 .71408 m .55556 .71207 L .55364 .71181 L F
.256 .763 .745 r
.55667 .7179 m .561 .7166 L .5586 .71477 L F
.442 .464 .786 r
.55865 .71295 m .55955 .71698 L .55873 .71724 L F
.915 .971 .674 r
.55783 .71529 m .55667 .7179 L .5586 .71477 L F
.442 .464 .786 r
.55745 .71596 m .55873 .71724 L .55667 .7179 L F
.796 .458 .416 r
.55465 .71314 m .55783 .71529 L .55556 .71207 L F
.55633 .71483 m .55783 .71529 L .55465 .71314 L F
.846 .44 .269 r
.55556 .71207 m .55783 .71529 L .5586 .71477 L F
.92 .927 .799 r
.55621 .71501 m .55721 .71518 L .55384 .71408 L F
.55721 .71518 m .55783 .71529 L .55633 .71483 L F
.55721 .71518 m .55633 .71483 L .55384 .71408 L F
.442 .464 .786 r
.55768 .71537 m .55873 .71724 L .55745 .71596 L F
.55865 .71295 m .5587 .71577 L .55768 .71537 L F
.5587 .71577 m .55873 .71724 L .55768 .71537 L F
.796 .458 .416 r
.55384 .71408 m .55633 .71483 L .55465 .71314 L F
.474 .278 .534 r
.32083 .62605 m .32282 .6254 L .32294 .62285 L F
.567 .391 .603 r
.32294 .62285 m .32522 .62257 L .32524 .6199 L F
.479 .282 .535 r
.32294 .62285 m .32486 .62488 L .32522 .62257 L F
.32294 .62285 m .32282 .6254 L .32486 .62488 L F
0 0 .376 r
.57696 .72535 m .57642 .7265 L .5764 .72299 L F
.841 .763 .252 r
.57609 .72696 m .57642 .7265 L .57696 .72535 L F
.206 0 0 r
.30038 .60261 m .29673 .60396 L .29839 .60338 L F
.698 .777 .913 r
.46518 .64597 m .46147 .64566 L .46365 .64498 L F
.799 .847 .887 r
.46677 .64481 m .46518 .64597 L .46365 .64498 L F
.025 .405 .856 r
.71134 .50343 m .71052 .50402 L .70952 .50219 L F
.55 .293 .478 r
.71052 .50402 m .71228 .50489 L .7124 .50285 L F
.025 .405 .856 r
.71134 .50343 m .71228 .50489 L .71052 .50402 L F
.857 .979 .859 r
.76179 .57908 m .75962 .5815 L .75999 .5796 L F
.861 .981 .853 r
.75999 .5796 m .75962 .5815 L .75827 .5815 L F
.025 .405 .856 r
.71134 .50343 m .70952 .50219 L .7124 .50285 L F
.865 .99 .73 r
.71367 .49965 m .7124 .50285 L .71483 .50005 L F
.71367 .49965 m .71232 .5017 L .7124 .50285 L F
.886 .943 .578 r
.71232 .5017 m .71134 .50343 L .7124 .50285 L F
.654 .665 .848 r
.7124 .50285 m .71624 .50293 L .71483 .50005 L F
.725 .44 .496 r
.7124 .50285 m .71413 .50429 L .71624 .50293 L F
.7124 .50285 m .71228 .50489 L .71413 .50429 L F
.206 .732 .819 r
.61832 .55057 m .62135 .55018 L .62138 .55025 L F
.366 .833 .79 r
.62135 .55018 m .62319 .54938 L .62138 .55025 L F
.606 .821 .983 r
.68253 .48759 m .68024 .48831 L .68372 .4887 L F
.503 .715 .966 r
.68372 .4887 m .68495 .48706 L .68253 .48759 L F
.68372 .4887 m .68584 .4884 L .68495 .48706 L F
.764 .57 .636 r
.47393 .7816 m .47657 .78558 L .47467 .78495 L F
.536 .35 .575 r
.47467 .78495 m .47657 .78558 L .47476 .78739 L F
.569 .721 .945 r
.26673 .64985 m .26819 .65139 L .26993 .65076 L F
.713 .619 .751 r
.67281 .53329 m .6701 .53677 L .6694 .53281 L F
.266 .3 .711 r
.6694 .53281 m .6701 .53677 L .67178 .53732 L F
.462 .85 .98 r
.66888 .53806 m .67065 .53852 L .67034 .53802 L F
.768 .43 0 r
.67032 .538 m .67065 .53852 L .67034 .5381 L F
.6701 .53677 m .67065 .53852 L .67034 .53802 L F
.6701 .53677 m .67034 .53802 L .67032 .53798 L F
.6701 .53677 m .67032 .53798 L .67178 .53732 L F
.67032 .53798 m .67072 .53789 L .67178 .53732 L F
.462 .85 .98 r
.67034 .53802 m .67079 .53801 L .67008 .53739 L F
.67079 .53801 m .67296 .53795 L .67049 .53747 L F
.67079 .53801 m .67049 .53747 L .67008 .53739 L F
.66888 .53806 m .67034 .53802 L .67008 .53739 L F
.768 .43 0 r
.67032 .53798 m .67034 .53802 L .67032 .538 L F
.782 .895 .924 r
.6687 .53666 m .66888 .53806 L .67036 .53723 L F
.933 .784 .673 r
.67022 .53699 m .67025 .53719 L .6687 .53666 L F
.835 .41 0 r
.6694 .53281 m .67178 .53732 L .66941 .53434 L F
.749 .578 .664 r
.66779 .53391 m .66926 .53481 L .66911 .53383 L F
.933 .784 .673 r
.67178 .53732 m .67022 .53699 L .66941 .53434 L F
.67022 .53699 m .6687 .53666 L .66921 .53497 L F
.67022 .53699 m .66921 .53497 L .66941 .53434 L F
.67178 .53732 m .67072 .53789 L .67022 .53699 L F
.462 .85 .98 r
.67035 .53723 m .67165 .5377 L .6718 .53642 L F
.67008 .53739 m .67046 .53746 L .67035 .53723 L F
.67046 .53746 m .67165 .5377 L .67035 .53723 L F
.749 .578 .664 r
.66926 .53481 m .66992 .53521 L .66941 .53434 L F
.66926 .53481 m .66941 .53434 L .66911 .53383 L F
.66779 .53391 m .6687 .53666 L .66992 .53521 L F
.933 .784 .673 r
.66941 .53434 m .6687 .53666 L .66926 .53415 L F
.835 .41 0 r
.66927 .53409 m .66941 .53434 L .66926 .53415 L F
.6694 .53281 m .66941 .53434 L .66927 .53409 L F
.749 .578 .664 r
.66911 .53383 m .66992 .53521 L .6712 .53369 L F
.782 .895 .924 r
.6687 .53666 m .67036 .53723 L .6718 .53642 L F
.933 .784 .673 r
.67025 .53719 m .67034 .5381 L .6687 .53666 L F
.768 .43 0 r
.67032 .53798 m .67034 .5381 L .67072 .53789 L F
.933 .784 .673 r
.67072 .53789 m .67034 .5381 L .67022 .53699 L F
.462 .85 .98 r
.67165 .5377 m .67296 .53795 L .67261 .53749 L F
.67165 .5377 m .67261 .53749 L .6718 .53642 L F
.67034 .53802 m .67065 .53852 L .67296 .53795 L F
.716 .394 .431 r
.50468 .76746 m .50569 .76519 L .50417 .76466 L F
.50468 .76746 m .50736 .76762 L .50569 .76519 L F
.822 .383 .193 r
.50569 .76519 m .50736 .76762 L .50904 .76793 L F
.86 .546 .455 r
.48176 .80467 m .47867 .80496 L .47986 .8041 L F
.48176 .80467 m .48039 .80671 L .47867 .80496 L F
.771 .422 .395 r
.483 .80672 m .48039 .80671 L .48176 .80467 L F
.997 .768 .45 r
.66636 .51924 m .6652 .51952 L .66594 .51839 L F
.66636 .51924 m .66652 .52156 L .6652 .51952 L F
.458 0 .062 r
.53173 .75797 m .53503 .75669 L .53283 .75655 L F
.411 .398 .734 r
.70951 .51251 m .71155 .51308 L .71069 .51005 L F
.645 .965 .905 r
.70803 .51435 m .71155 .51308 L .70951 .51251 L F
.594 .383 .564 r
.50593 .81518 m .50654 .81257 L .50626 .81256 L F
0 0 0 r
.50775 .8111 m .50936 .8095 L .50537 .81342 L F
.50866 .81021 m .50537 .81342 L .50654 .81257 L F
.782 .329 .171 r
.50537 .81342 m .50369 .81252 L .50654 .81257 L F
.594 .383 .564 r
.50488 .81393 m .50626 .81256 L .50369 .81252 L F
.50593 .81518 m .50626 .81256 L .50488 .81393 L F
0 0 0 r
.50866 .81021 m .50883 .81003 L .50775 .8111 L F
.50883 .81003 m .50936 .8095 L .50775 .8111 L F
.585 .323 .486 r
.51174 .80967 m .50936 .8095 L .51052 .80903 L F
0 0 0 r
.51052 .80903 m .50936 .8095 L .50866 .81021 L F
.475 .422 .718 r
.46228 .78181 m .4626 .7857 L .4651 .78436 L F
.434 .363 .677 r
.46347 .78747 m .4651 .78436 L .4626 .7857 L F
0 0 .382 r
.53624 .76958 m .53509 .76816 L .53714 .76727 L F
0 0 .409 r
.65145 .49211 m .65156 .49422 L .6516 .49335 L F
.65156 .49422 m .65163 .49563 L .6516 .49335 L F
.919 .524 .156 r
.65164 .49255 m .6516 .49335 L .65285 .49428 L F
.65081 .49135 m .6516 .49335 L .65164 .49255 L F
.99 .869 .523 r
.65163 .49563 m .65285 .49428 L .6516 .49335 L F
.65163 .49563 m .65217 .4969 L .65285 .49428 L F
.527 .564 .836 r
.65285 .49428 m .65495 .49406 L .65335 .49082 L F
.464 .841 .988 r
.67212 .4892 m .67296 .48816 L .67107 .488 L F
.67212 .4892 m .67431 .48871 L .67296 .48816 L F
.321 .809 .848 r
.51414 .81403 m .51881 .8134 L .5166 .81398 L F
0 0 0 r
.51881 .8134 m .51755 .81387 L .5166 .81398 L F
.51881 .8134 m .5211 .81311 L .51755 .81387 L F
.307 .779 .932 r
.43277 .64867 m .43531 .64835 L .43637 .64873 L F
.517 0 0 r
.43531 .64835 m .43861 .64817 L .43637 .64873 L F
.96 .66 .237 r
.57137 .75105 m .57172 .75344 L .57248 .75417 L F
.911 .673 .171 r
.57172 .75344 m .57233 .75661 L .57248 .75417 L F
.44 .421 .741 r
.3729 .69255 m .37364 .69564 L .3754 .69495 L F
.5 .441 .722 r
.37415 .69811 m .3754 .69495 L .37364 .69564 L F
.276 .504 .895 r
.72689 .4914 m .72984 .49255 L .7289 .49396 L F
.232 .444 .861 r
.72984 .49255 m .73033 .49426 L .7289 .49396 L F
.365 0 .032 r
.25891 .58859 m .26112 .58837 L .2627 .58667 L F
.163 0 0 r
.2627 .58667 m .26313 .58774 L .2648 .58635 L F
.2627 .58667 m .26112 .58837 L .26313 .58774 L F
.427 .745 .993 r
.35281 .59457 m .3519 .59553 L .35051 .59457 L F
.35281 .59457 m .35363 .59533 L .3519 .59553 L F
.52 .558 .834 r
.50189 .67262 m .50052 .6737 L .49839 .66977 L F
.404 .095 .324 r
.50052 .6737 m .5017 .67474 L .50189 .67262 L F
.50052 .6737 m .49961 .67556 L .5017 .67474 L F
.481 .316 .58 r
.75023 .59335 m .75038 .59731 L .74823 .59756 L F
.497 .464 .75 r
.75166 .5933 m .75038 .59731 L .75023 .59335 L F
.921 .975 .757 r
.60135 .52756 m .60273 .52382 L .60335 .52439 L F
.251 0 .177 r
.40081 .67244 m .39965 .67493 L .39786 .67549 L F
.393 .044 .249 r
.40183 .67445 m .40081 .67244 L .40301 .67208 L F
.40183 .67445 m .39965 .67493 L .40081 .67244 L F
.293 .38 .781 r
.64729 .48721 m .64606 .48872 L .64494 .48546 L F
.347 .459 .833 r
.64729 .48721 m .64843 .48983 L .64606 .48872 L F
0 0 0 r
.62947 .56123 m .6324 .55926 L .63144 .56044 L F
.06 0 .121 r
.62947 .56123 m .63063 .56205 L .629 .56307 L F
.62947 .56123 m .63144 .56044 L .63063 .56205 L F
.839 .729 .742 r
.65791 .53312 m .65616 .53593 L .65908 .5363 L F
.776 .572 .624 r
.65574 .53811 m .65908 .5363 L .65616 .53593 L F
.65574 .53811 m .6589 .53843 L .65908 .5363 L F
.494 .268 .5 r
.47116 .75708 m .47358 .75877 L .47393 .75647 L F
.47116 .75708 m .47126 .75934 L .47358 .75877 L F
.349 .09 .373 r
.36044 .60934 m .36329 .60609 L .36372 .60672 L F
.551 .434 .673 r
.36487 .60289 m .36522 .60577 L .36329 .60609 L F
.543 .396 .631 r
.36522 .60577 m .36372 .60672 L .36329 .60609 L F
.386 .821 .957 r
.27707 .65286 m .27818 .65205 L .27542 .65184 L F
.27707 .65286 m .27965 .65243 L .27818 .65205 L F
.747 .564 .647 r
.53503 .75669 m .53858 .75705 L .53756 .75428 L F
.629 .503 .69 r
.53756 .75428 m .54086 .75657 L .54088 .75434 L F
.53756 .75428 m .53858 .75705 L .54086 .75657 L F
.277 .035 .356 r
.62793 .54165 m .62584 .54456 L .62772 .54319 L F
.629 .475 .655 r
.62793 .54165 m .63206 .54151 L .63102 .53812 L F
.175 0 0 r
.62772 .54319 m .63206 .54151 L .62793 .54165 L F
.457 .16 .373 r
.32009 .62769 m .32282 .6254 L .32083 .62605 L F
.556 .512 .762 r
.49709 .66663 m .49621 .67015 L .49537 .66689 L F
.49709 .66663 m .49839 .66977 L .49621 .67015 L F
.511 .341 .587 r
.332 .61141 m .33419 .60857 L .33165 .60902 L F
.586 .845 .489 r
.50135 .74217 m .5006 .74318 L .5027 .74207 L F
.50135 .74217 m .49925 .74472 L .5006 .74318 L F
.576 .723 .942 r
.76239 .5854 m .764 .58318 L .76115 .58472 L F
.76239 .5854 m .76529 .58509 L .764 .58318 L F
.829 .69 .71 r
.59807 .73723 m .60118 .73743 L .59989 .73424 L F
.831 .657 .667 r
.60061 .73985 m .60118 .73743 L .59807 .73723 L F
.371 .265 .601 r
.27287 .62222 m .27279 .62535 L .27119 .6257 L F
.41 .432 .772 r
.27279 .62535 m .27354 .62718 L .27119 .6257 L F
.462 .242 .493 r
.32524 .6199 m .32721 .61941 L .32751 .61755 L F
.508 .348 .599 r
.32522 .62257 m .32721 .61941 L .32524 .6199 L F
.617 .404 .571 r
.60697 .57819 m .60707 .58055 L .60529 .5798 L F
.622 .388 .541 r
.60952 .5781 m .60707 .58055 L .60697 .57819 L F
.199 .716 .879 r
.44422 .6478 m .44644 .64767 L .44776 .64792 L F
.325 .8 .914 r
.44644 .64767 m .44992 .64749 L .44776 .64792 L F
.06 0 0 r
.49131 .75009 m .49038 .7497 L .4927 .74874 L F
.49131 .75009 m .48934 .7507 L .49038 .7497 L F
.467 .698 .968 r
.49295 .68366 m .49547 .68392 L .49382 .68453 L F
.526 .151 .272 r
.45177 .69264 m .45042 .69493 L .44823 .69481 L F
.568 .196 .296 r
.45374 .69376 m .45177 .69264 L .45406 .69251 L F
.45374 .69376 m .45042 .69493 L .45177 .69264 L F
.233 0 0 r
.6275 .52121 m .62605 .52269 L .62361 .52259 L F
.555 .031 0 r
.62905 .52218 m .62605 .52269 L .6275 .52121 L F
.854 .57 .507 r
.58702 .684 m .58873 .68611 L .58636 .68381 L F
.614 .127 .074 r
.53726 .73736 m .53744 .73886 L .53358 .73714 L F
.213 .539 .926 r
.53793 .73979 m .53744 .73886 L .53726 .73736 L F
.407 0 .046 r
.42181 .69459 m .42408 .69447 L .42551 .69283 L F
.356 0 0 r
.42408 .69447 m .42778 .69281 L .42551 .69283 L F
.463 .211 .446 r
.50346 .67615 m .5009 .67888 L .50328 .67829 L F
.50328 .67829 m .5009 .67888 L .50346 .67615 L F
.658 .811 .957 r
.49961 .67556 m .50346 .67615 L .5017 .67474 L F
.463 .211 .446 r
.50346 .67615 m .50328 .67829 L .5017 .67474 L F
.519 .762 .985 r
.5017 .67474 m .50568 .67558 L .50346 .67615 L F
.409 .167 .433 r
.50346 .67615 m .50328 .67829 L .50568 .67558 L F
.891 .561 .418 r
.56895 .74537 m .56983 .74845 L .57138 .74857 L F
.747 .33 0 r
.56983 .74845 m .57137 .75105 L .57138 .74857 L F
.577 .595 .834 r
.58873 .68611 m .58969 .68419 L .58636 .68381 L F
.666 .45 .583 r
.59006 .68717 m .58969 .68419 L .58873 .68611 L F
.068 .048 .524 r
.50652 .75464 m .50737 .75383 L .50523 .75426 L F
.50652 .75464 m .50802 .75539 L .50737 .75383 L F
.443 0 .026 r
.50407 .75607 m .50802 .75539 L .50652 .75464 L F
.533 .353 .583 r
.48607 .78217 m .48593 .78495 L .48359 .78528 L F
.529 .909 .753 r
.57237 .69169 m .57055 .69288 L .57306 .69136 L F
0 0 0 r
.78297 .60911 m .78194 .61045 L .78063 .61166 L F
.78063 .61166 m .77965 .61322 L .78057 .61417 L F
.78063 .61166 m .78194 .61045 L .77965 .61322 L F
.926 .566 .139 r
.56871 .7473 m .56895 .74537 L .56703 .74485 L F
.56871 .7473 m .56983 .74845 L .56895 .74537 L F
.497 .618 .902 r
.38422 .7187 m .38545 .71676 L .38353 .71676 L F
.38422 .7187 m .38621 .71885 L .38545 .71676 L F
.685 .331 .369 r
.54319 .7654 m .54186 .76751 L .53953 .767 L F
.772 .439 .423 r
.54319 .7654 m .54548 .76852 L .54186 .76751 L F
.947 .957 .677 r
.61446 .49657 m .61407 .49573 L .61562 .49467 L F
.784 .837 .374 r
.61684 .49134 m .61562 .49467 L .61611 .4927 L F
.864 .984 .7 r
.61562 .49467 m .61407 .49573 L .61611 .4927 L F
.754 .646 .741 r
.50259 .64779 m .49922 .64512 L .50276 .64556 L F
.50259 .64779 m .50053 .64798 L .49922 .64512 L F
.744 .554 .638 r
.50259 .64779 m .50044 .65045 L .50053 .64798 L F
.783 .614 .67 r
.50259 .64779 m .50326 .65077 L .50044 .65045 L F
.518 .336 .574 r
.50544 .64498 m .50259 .64779 L .50276 .64556 L F
.50544 .64498 m .50521 .64715 L .50259 .64779 L F
.556 .466 .709 r
.50521 .64715 m .50326 .65077 L .50259 .64779 L F
0 0 0 r
.70152 .51681 m .69888 .51916 L .70131 .51894 L F
.489 .132 .287 r
.70308 .51793 m .70152 .51681 L .70131 .51894 L F
.70308 .51793 m .70409 .51666 L .70152 .51681 L F
.586 .173 .226 r
.5387 .7897 m .5371 .78766 L .53697 .79012 L F
.408 .86 .867 r
.30788 .63387 m .30835 .63334 L .30987 .63328 L F
.30788 .63387 m .30671 .63393 L .30835 .63334 L F
.769 .679 .763 r
.47456 .77338 m .47232 .77621 L .47576 .77651 L F
.707 .3 .274 r
.47232 .77621 m .47448 .77828 L .47576 .77651 L F
.265 .38 .793 r
.47456 .77338 m .47576 .77651 L .47712 .77555 L F
.593 .387 .571 r
.47448 .77828 m .47712 .77555 L .47576 .77651 L F
.371 0 0 r
.71835 .48782 m .72164 .48889 L .72175 .48858 L F
.391 .615 .94 r
.72293 .48714 m .72298 .48842 L .72175 .48858 L F
.72293 .48714 m .72175 .48858 L .72164 .48889 L F
.776 .389 .323 r
.55315 .79486 m .55228 .79143 L .54808 .79013 L F
.654 .424 .558 r
.59341 .58088 m .59323 .58318 L .58971 .58342 L F
.569 .351 .544 r
.59341 .58088 m .59569 .58274 L .59323 .58318 L F
.276 .111 .468 r
.6971 .52232 m .69836 .52332 L .6988 .52085 L F
.6971 .52232 m .69689 .52473 L .69836 .52332 L F
.594 .782 .97 r
.48028 .76338 m .48355 .76374 L .483 .76209 L F
.222 .347 .779 r
.48355 .76374 m .4844 .76145 L .483 .76209 L F
.48355 .76374 m .48578 .76406 L .4844 .76145 L F
.985 .722 .344 r
.57267 .75905 m .57357 .76205 L .57317 .75996 L F
.464 0 0 r
.77151 .5779 m .77286 .57829 L .77002 .57715 L F
.799 .847 .887 r
.46677 .64481 m .46365 .64498 L .46584 .64427 L F
.682 .957 .948 r
.46677 .64481 m .46792 .64305 L .46971 .64383 L F
.46677 .64481 m .46584 .64427 L .46792 .64305 L F
.211 .087 .485 r
.37951 .70689 m .38071 .70844 L .38096 .70614 L F
.37951 .70689 m .37902 .70951 L .38071 .70844 L F
.975 .688 .296 r
.59723 .70788 m .59797 .70646 L .59648 .70541 L F
.59723 .70788 m .5983 .70925 L .59797 .70646 L F
.67 .797 .943 r
.69177 .48999 m .69282 .49133 L .69509 .49064 L F
.15 .218 .68 r
.72151 .50286 m .72367 .50316 L .72079 .50146 L F
.72151 .50286 m .72324 .50442 L .72367 .50316 L F
.129 .216 .686 r
.72244 .50492 m .72324 .50442 L .72151 .50286 L F
0 0 0 r
.51843 .80623 m .52002 .80401 L .51727 .80698 L F
.904 .613 .481 r
.5202 .80663 m .52002 .80401 L .51843 .80623 L F
.567 .782 .98 r
.74477 .60889 m .74766 .60771 L .74376 .60761 L F
.74477 .60889 m .74718 .6084 L .74766 .60771 L F
.907 .531 .091 r
.47553 .78977 m .47622 .79009 L .4756 .78894 L F
.709 .61 .744 r
.4761 .78861 m .47549 .79019 L .47553 .78977 L F
.702 .338 .356 r
.47468 .79231 m .47622 .79009 L .47553 .78977 L F
.709 .61 .744 r
.47549 .79019 m .47468 .79231 L .47553 .78977 L F
.907 .531 .091 r
.47553 .78977 m .4756 .78894 L .47476 .78739 L F
.702 .338 .356 r
.47468 .79231 m .47818 .79218 L .47622 .79009 L F
.682 .344 .396 r
.47818 .79218 m .47889 .79086 L .47622 .79009 L F
.623 .624 .831 r
.50866 .75901 m .50768 .76254 L .50678 .75929 L F
.50866 .75901 m .51124 .76272 L .50768 .76254 L F
0 .019 .532 r
.50768 .76254 m .50987 .76475 L .50893 .7637 L F
.50768 .76254 m .50893 .7637 L .50713 .76338 L F
0 0 0 r
.63144 .56044 m .6324 .55926 L .63411 .55788 L F
.406 .046 .237 r
.35779 .61129 m .36044 .60934 L .36003 .61094 L F
.432 .165 .407 r
.36044 .60934 m .36223 .61064 L .36003 .61094 L F
.36044 .60934 m .36372 .60672 L .36223 .61064 L F
.651 .351 .45 r
.59917 .58014 m .59786 .58284 L .59569 .58274 L F
.673 .417 .526 r
.60135 .5805 m .59786 .58284 L .59917 .58014 L F
.052 0 .469 r
.25389 .64906 m .25322 .65024 L .25232 .64778 L F
.25453 .64959 m .25232 .64778 L .25521 .64766 L F
.742 .696 .808 r
.25117 .64716 m .25505 .64787 L .2526 .6437 L F
.601 .069 0 r
.25211 .64857 m .25505 .64787 L .25117 .64716 L F
.953 .899 .735 r
.25332 .64582 m .25371 .64629 L .25211 .64857 L F
.25371 .64629 m .25505 .64787 L .25383 .64816 L F
.25371 .64629 m .25383 .64816 L .25211 .64857 L F
.052 0 .469 r
.25453 .64959 m .25394 .64988 L .25389 .64906 L F
.25394 .64988 m .25322 .65024 L .25389 .64906 L F
.25453 .64959 m .25328 .65069 L .25322 .65024 L F
0 0 .322 r
.25322 .65024 m .25328 .65069 L .25326 .65075 L F
.296 0 0 r
.3114 .64995 m .31024 .65038 L .30802 .65028 L F
0 0 0 r
.31314 .64955 m .31024 .65038 L .3114 .64995 L F
.69622 .53579 m .6965 .53603 L .69341 .53785 L F
.6987 .53299 m .69796 .53451 L .69622 .53579 L F
.69796 .53451 m .6965 .53603 L .69622 .53579 L F
.25827 .64641 m .25642 .6473 L .25521 .64766 L F
.25551 .64867 m .25521 .64766 L .25642 .6473 L F
.25551 .64867 m .25453 .64959 L .25521 .64766 L F
.547 .357 .574 r
.5524 .70109 m .54986 .70477 L .55248 .70349 L F
.453 .257 .522 r
.5524 .70109 m .55453 .70071 L .55463 .69816 L F
.576 .436 .654 r
.55248 .70349 m .55453 .70071 L .5524 .70109 L F
.753 .637 .733 r
.59048 .68968 m .59367 .6899 L .59232 .6868 L F
.951 .677 .483 r
.59226 .69182 m .5938 .69233 L .59367 .6899 L F
0 0 0 r
.69689 .52473 m .69469 .5257 L .69348 .52637 L F
.637 .126 .015 r
.54858 .78066 m .5491 .77939 L .55122 .78105 L F
.585 .205 .288 r
.5491 .77939 m .55202 .77962 L .55122 .78105 L F
.002 .31 .801 r
.65405 .51463 m .65551 .51459 L .65313 .51294 L F
.65405 .51463 m .65528 .51558 L .65551 .51459 L F
.488 0 0 r
.51418 .81031 m .51498 .80985 L .51174 .80967 L F
.481 .279 .529 r
.51727 .80698 m .51498 .80985 L .51641 .80963 L F
0 0 0 r
.51641 .80963 m .51498 .80985 L .51418 .81031 L F
.976 .752 .537 r
.59096 .70853 m .5893 .70996 L .59146 .70794 L F
0 0 0 r
.59096 .70853 m .59197 .70746 L .59297 .70601 L F
.976 .752 .537 r
.59096 .70853 m .59146 .70794 L .59197 .70746 L F
0 0 .05 r
.59117 .70621 m .59072 .70883 L .59096 .70853 L F
.59072 .70883 m .59061 .70942 L .59096 .70853 L F
.232 .19 .603 r
.59117 .70621 m .59297 .70601 L .59258 .70313 L F
.177 0 .263 r
.59117 .70621 m .59096 .70853 L .59297 .70601 L F
.367 .754 .988 r
.29314 .58614 m .29672 .58681 L .29472 .58713 L F
.738 .761 .871 r
.76082 .61687 m .76481 .61749 L .76382 .61695 L F
.848 .899 .872 r
.76481 .61749 m .76594 .61568 L .76487 .61517 L F
.888 .924 .84 r
.76382 .61695 m .76481 .61749 L .76487 .61517 L F
.22 0 .313 r
.62562 .5458 m .62772 .54319 L .62584 .54456 L F
.671 .663 .834 r
.70095 .49078 m .70206 .49365 L .70452 .4919 L F
.633 .629 .829 r
.70206 .49365 m .70538 .49465 L .70452 .4919 L F
.867 .926 .863 r
.65337 .5225 m .65003 .52426 L .65224 .52149 L F
.671 .903 .977 r
.78145 .60515 m .77919 .60633 L .77831 .60552 L F
0 0 0 r
.62234 .51402 m .62144 .51555 L .62059 .51679 L F
.907 .972 .801 r
.62144 .51555 m .62028 .51871 L .62059 .51679 L F
.538 .727 .961 r
.76228 .6082 m .75834 .60688 L .76324 .60727 L F
.488 .722 .975 r
.76252 .60699 m .76228 .6082 L .76324 .60727 L F
.76252 .60699 m .76449 .60798 L .76228 .6082 L F
.76267 .60625 m .76252 .60699 L .76324 .60727 L F
.521 .748 .979 r
.76267 .60625 m .76324 .60727 L .76275 .60698 L F
.488 .722 .975 r
.76267 .60625 m .76275 .60698 L .76252 .60699 L F
.521 .748 .979 r
.76267 .60625 m .76275 .60698 L .76012 .60545 L F
.488 .722 .975 r
.76267 .60625 m .76342 .60697 L .76275 .60698 L F
.76342 .60697 m .76449 .60798 L .76252 .60699 L F
.471 .733 .984 r
.75963 .60585 m .76252 .60699 L .75834 .60688 L F
.76252 .60699 m .76324 .60727 L .76032 .60704 L F
.76252 .60699 m .76032 .60704 L .75834 .60688 L F
.76012 .60545 m .76324 .60727 L .75963 .60585 L F
.044 0 0 r
.63124 .50197 m .63235 .50244 L .63336 .50165 L F
0 0 .374 r
.63026 .50606 m .63137 .50456 L .63135 .50351 L F
.044 0 0 r
.63124 .50197 m .63013 .5032 L .63235 .50244 L F
.63013 .5032 m .62997 .50338 L .63031 .50325 L F
.63013 .5032 m .63031 .50325 L .63235 .50244 L F
.387 .837 .925 r
.62901 .50282 m .63235 .50244 L .62997 .50338 L F
.62901 .50282 m .63132 .50226 L .63235 .50244 L F
0 0 .374 r
.631 .50342 m .63135 .50351 L .63132 .50226 L F
.63026 .50606 m .63135 .50351 L .631 .50342 L F
0 0 0 r
.56871 .77242 m .56849 .77139 L .56932 .77015 L F
.671 .91 .977 r
.74876 .58867 m .74585 .589 L .74784 .58802 L F
.142 0 0 r
.75009 .58892 m .74876 .58867 L .74784 .58802 L F
.738 .437 0 r
.65869 .50021 m .65883 .50107 L .65815 .49896 L F
.65869 .50021 m .65933 .50249 L .65883 .50107 L F
.55 .551 .808 r
.49518 .67883 m .49734 .6785 L .49605 .67502 L F
.565 .136 .185 r
.4793 .79124 m .47996 .79071 L .47889 .79086 L F
.686 .18 0 r
.479 .78755 m .48076 .78973 L .47868 .78772 L F
.48076 .78973 m .48082 .78981 L .48074 .78973 L F
.48076 .78973 m .48074 .78973 L .47868 .78772 L F
.565 .136 .185 r
.4804 .79225 m .47889 .79086 L .47818 .79218 L F
.632 .923 .655 r
.48056 .78975 m .47934 .79105 L .4782 .79211 L F
.296 .55 .922 r
.47868 .78772 m .48082 .78981 L .48136 .78867 L F
.632 .923 .655 r
.48096 .78935 m .48058 .78975 L .48056 .78975 L F
.48058 .78975 m .47934 .79105 L .48056 .78975 L F
.726 .4 .427 r
.47672 .79472 m .47818 .79218 L .47468 .79231 L F
.632 .923 .655 r
.47799 .79228 m .4782 .79211 L .47754 .79272 L F
.48096 .78935 m .4782 .79211 L .47799 .79228 L F
.565 .136 .185 r
.4804 .79225 m .48173 .79046 L .47996 .79071 L F
.4804 .79225 m .47996 .79071 L .4793 .79124 L F
.535 .256 .439 r
.48164 .79476 m .47818 .79218 L .47672 .79472 L F
.48164 .79476 m .4804 .79225 L .47818 .79218 L F
.589 .166 .207 r
.47772 .7939 m .47934 .79105 L .48034 .79157 L F
.999 .823 .532 r
.48058 .79124 m .48173 .79046 L .4804 .79225 L F
.48082 .78981 m .48134 .79018 L .48058 .79124 L F
.444 .353 .658 r
.48106 .78953 m .47934 .79105 L .48096 .78935 L F
.999 .823 .532 r
.48134 .79018 m .48173 .79046 L .48058 .79124 L F
0 0 .048 r
.48191 .79009 m .48155 .79061 L .48261 .79188 L F
.48155 .79061 m .48169 .79204 L .48261 .79188 L F
.444 .353 .658 r
.48154 .79047 m .48106 .78953 L .48136 .78867 L F
0 0 .048 r
.48136 .78867 m .48116 .7891 L .48106 .78953 L F
.48116 .7891 m .48082 .78981 L .48094 .79004 L F
.444 .353 .658 r
.48106 .78953 m .48096 .78935 L .48136 .78867 L F
0 0 .048 r
.48136 .78867 m .48106 .78953 L .48094 .79004 L F
.444 .353 .658 r
.48154 .79047 m .48063 .79138 L .48106 .78953 L F
0 0 .048 r
.48136 .78867 m .48063 .79138 L .48191 .79009 L F
.48063 .79138 m .4804 .79225 L .48191 .79009 L F
.48155 .79061 m .4804 .79225 L .48169 .79204 L F
.444 .353 .658 r
.48205 .79236 m .48056 .79169 L .48063 .79138 L F
.48274 .79282 m .48185 .79236 L .48205 .79236 L F
.332 0 .044 r
.48191 .79228 m .48169 .79204 L .4804 .79225 L F
.48232 .79228 m .482 .79216 L .48191 .79228 L F
.482 .79216 m .48169 .79204 L .48191 .79228 L F
.48047 .79237 m .48232 .79228 L .4804 .79225 L F
.589 .166 .207 r
.48123 .79314 m .48185 .79236 L .48274 .79282 L F
.332 0 .044 r
.48128 .79368 m .48227 .79235 L .48116 .79236 L F
.48128 .79368 m .48116 .79236 L .48047 .79237 L F
.48133 .79382 m .4804 .79225 L .48164 .79476 L F
.48128 .79368 m .48108 .79334 L .48133 .79382 L F
.48108 .79334 m .4804 .79225 L .48133 .79382 L F
.48227 .79235 m .48232 .79228 L .48047 .79237 L F
.589 .166 .207 r
.4809 .79302 m .48056 .79169 L .48185 .79236 L F
.48052 .7933 m .48054 .79235 L .4809 .79302 L F
.48054 .79235 m .48056 .79169 L .4809 .79302 L F
.47772 .7939 m .48123 .79314 L .48128 .79368 L F
.48123 .79314 m .48274 .79282 L .48128 .79368 L F
.48052 .7933 m .48185 .79236 L .48123 .79314 L F
.444 .353 .658 r
.48185 .79236 m .48056 .79169 L .48205 .79236 L F
.332 0 .044 r
.48232 .79228 m .48261 .79188 L .48169 .79204 L F
.444 .353 .658 r
.48274 .79282 m .4825 .79235 L .48259 .79239 L F
.775 .558 .605 r
.48227 .79235 m .48325 .79223 L .48261 .79188 L F
.48325 .79223 m .48348 .79206 L .48261 .79188 L F
.235 .344 .772 r
.48136 .78867 m .48261 .79188 L .48348 .79206 L F
.48362 .79175 m .48348 .79206 L .48391 .79215 L F
.48136 .78867 m .48348 .79206 L .48362 .79175 L F
.48136 .78867 m .48391 .79215 L .48428 .78872 L F
.378 .258 .588 r
.48428 .78872 m .48394 .79186 L .48615 .79084 L F
.48394 .79186 m .48391 .79215 L .48615 .79084 L F
.48428 .78872 m .48615 .79084 L .4862 .78812 L F
.452 .296 .577 r
.4862 .78812 m .48615 .79084 L .4882 .79024 L F
.542 .724 .958 r
.4877 .79013 m .48615 .79084 L .48456 .78948 L F
.4882 .79024 m .48615 .79084 L .4877 .79013 L F
.562 .467 .704 r
.48439 .79079 m .48316 .7923 L .48136 .78867 L F
.48316 .7923 m .48274 .79282 L .48259 .79239 L F
.48316 .7923 m .48259 .79239 L .48136 .78867 L F
.81 .999 .794 r
.48128 .79368 m .48274 .79282 L .48316 .7923 L F
.775 .558 .605 r
.48128 .79368 m .48358 .79235 L .48284 .79235 L F
.81 .999 .794 r
.48128 .79368 m .48316 .7923 L .48363 .79172 L F
.48381 .79133 m .48363 .79172 L .48439 .79079 L F
.775 .558 .605 r
.48358 .79235 m .48391 .79215 L .48227 .79235 L F
.81 .999 .794 r
.48128 .79368 m .48363 .79172 L .48381 .79133 L F
.444 .353 .658 r
.48274 .79282 m .48205 .79236 L .4825 .79235 L F
.775 .558 .605 r
.48219 .79246 m .48284 .79235 L .48227 .79235 L F
.48128 .79368 m .48284 .79235 L .48219 .79246 L F
.48325 .79223 m .48391 .79215 L .48348 .79206 L F
.444 .353 .658 r
.4825 .79235 m .48063 .79138 L .48154 .79047 L F
.48205 .79236 m .48063 .79138 L .4825 .79235 L F
.48259 .79239 m .48154 .79047 L .48136 .78867 L F
.4825 .79235 m .48154 .79047 L .48259 .79239 L F
0 0 .048 r
.48094 .79004 m .48082 .78981 L .48058 .79124 L F
.444 .353 .658 r
.48056 .79169 m .47934 .79105 L .48106 .78953 L F
0 0 .048 r
.48056 .79164 m .48058 .79124 L .4804 .79225 L F
.48136 .78867 m .48058 .79124 L .48056 .79164 L F
.589 .166 .207 r
.47881 .79366 m .48034 .79157 L .48056 .79169 L F
.47881 .79366 m .48056 .79169 L .48052 .7933 L F
.47772 .7939 m .48034 .79157 L .47881 .79366 L F
.345 0 .222 r
.42157 .66439 m .41859 .66649 L .41934 .66473 L F
.413 .772 .995 r
.33575 .59252 m .33369 .59274 L .33215 .59187 L F
.436 .257 .539 r
.46474 .76516 m .46652 .7649 L .46669 .76242 L F
.153 .136 .585 r
.46474 .76516 m .4663 .76715 L .46652 .7649 L F
.46474 .76516 m .46492 .76813 L .4663 .76715 L F
.424 .209 .481 r
.4632 .67875 m .46296 .68097 L .46521 .67831 L F
.936 .562 .246 r
.65217 .4969 m .65288 .49908 L .65412 .49977 L F
0 .19 .692 r
.65288 .49908 m .65517 .50126 L .65412 .49977 L F
.906 .611 .475 r
.50736 .76762 m .50759 .76985 L .50904 .76793 L F
.72 .343 .335 r
.50759 .76985 m .51111 .7702 L .50904 .76793 L F
.646 .556 .738 r
.50904 .76793 m .51176 .76844 L .5111 .76559 L F
.663 .355 .44 r
.50904 .76793 m .51111 .7702 L .51176 .76844 L F
.216 .018 .382 r
.62715 .566 m .62466 .56917 L .62469 .56684 L F
.44 .287 .576 r
.63456 .48201 m .63234 .48044 L .63467 .47977 L F
.63456 .48201 m .63256 .48289 L .63234 .48044 L F
.019 0 0 r
.6309 .4812 m .63467 .47977 L .63234 .48044 L F
.492 .818 1 r
.36797 .70539 m .3681 .70661 L .36583 .70581 L F
0 .17 .707 r
.36797 .70539 m .3698 .70809 L .3681 .70661 L F
.409 .324 .649 r
.46356 .77622 m .46534 .77312 L .46386 .77364 L F
.919 .696 .584 r
.55644 .70359 m .55453 .70071 L .5582 .70121 L F
.241 .391 .814 r
.55926 .69982 m .561 .70339 L .5582 .70121 L F
.541 .038 .011 r
.51779 .74148 m .51646 .74228 L .51421 .74195 L F
.398 0 0 r
.5191 .7419 m .51646 .74228 L .51779 .74148 L F
.649 .499 .667 r
.62401 .49706 m .62397 .49974 L .62198 .49991 L F
.602 .316 .455 r
.62397 .49974 m .62395 .50202 L .62198 .49991 L F
.697 .94 .644 r
.54888 .70819 m .54818 .70885 L .55038 .70642 L F
.534 .474 .735 r
.46228 .78181 m .46377 .77828 L .46155 .77985 L F
.747 .961 .938 r
.56513 .69504 m .56712 .69224 L .56512 .69266 L F
.622 .457 .638 r
.56712 .69224 m .56513 .69504 L .56512 .69266 L F
0 0 0 r
.70042 .53186 m .6987 .53299 L .7013 .53048 L F
.70042 .53186 m .69796 .53451 L .6987 .53299 L F
.538 .386 .622 r
.48868 .65056 m .48673 .65356 L .48555 .64939 L F
.48868 .65056 m .48907 .65313 L .48673 .65356 L F
.511 .341 .587 r
.332 .61141 m .3341 .61092 L .33419 .60857 L F
.551 .398 .627 r
.33203 .61416 m .3341 .61092 L .332 .61141 L F
.494 .858 .988 r
.6913 .49923 m .69445 .49932 L .69183 .49994 L F
.698 .194 .037 r
.69183 .49994 m .69092 .50085 L .6913 .49923 L F
.69183 .49994 m .69419 .50178 L .69092 .50085 L F
.549 .362 .579 r
.69445 .49932 m .69419 .50178 L .69183 .49994 L F
.521 .439 .704 r
.73413 .60079 m .73575 .59692 L .73329 .59722 L F
.73413 .60079 m .73667 .60043 L .73575 .59692 L F
.575 .522 .758 r
.73413 .60079 m .73711 .60241 L .73667 .60043 L F
.102 0 0 r
.3119 .60104 m .31028 .6011 L .30827 .60093 L F
.072 .635 .755 r
.3119 .60104 m .31239 .60091 L .31028 .6011 L F
.3119 .60104 m .31423 .60086 L .31239 .60091 L F
.17 .11 .542 r
.62601 .49783 m .62397 .49974 L .62401 .49706 L F
.764 .534 .585 r
.50326 .65077 m .50042 .65294 L .50044 .65045 L F
.50326 .65077 m .50377 .65315 L .50042 .65294 L F
.556 .466 .709 r
.50521 .64715 m .50561 .65058 L .50326 .65077 L F
.669 .557 .719 r
.50561 .65058 m .50377 .65315 L .50326 .65077 L F
0 0 0 r
.64414 .51091 m .64347 .51242 L .64562 .50943 L F
.901 .982 .793 r
.59865 .52974 m .60135 .52756 L .59963 .53064 L F
.59865 .52974 m .60084 .5268 L .60135 .52756 L F
.921 .975 .757 r
.60135 .52756 m .60084 .5268 L .60273 .52382 L F
.543 .032 0 r
.54548 .76852 m .54709 .76803 L .54582 .76898 L F
.21 .147 .564 r
.54709 .76803 m .5473 .77076 L .54896 .77013 L F
.672 .124 0 r
.54709 .76803 m .54769 .76935 L .54582 .76898 L F
.54709 .76803 m .54896 .77013 L .54769 .76935 L F
.259 0 0 r
.26694 .58605 m .26903 .58557 L .27056 .5838 L F
.013 0 0 r
.26903 .58557 m .27248 .58445 L .27056 .5838 L F
0 0 .038 r
.61684 .49134 m .61852 .49004 L .61896 .4882 L F
0 0 0 r
.61684 .49134 m .61611 .4927 L .61852 .49004 L F
.761 .674 .767 r
.48555 .64939 m .48334 .6511 L .48204 .64775 L F
.665 .567 .734 r
.48812 .64765 m .48868 .65056 L .48555 .64939 L F
.252 .435 .848 r
.77849 .5812 m .77608 .58147 L .77529 .58035 L F
.77849 .5812 m .7788 .58286 L .77608 .58147 L F
.025 0 0 r
.28148 .65266 m .28525 .65058 L .28362 .6526 L F
.416 .01 .158 r
.28733 .65024 m .28362 .6526 L .28525 .65058 L F
.978 .839 .636 r
.6652 .51952 m .66652 .52156 L .66532 .52455 L F
.36 .66 .971 r
.45222 .65687 m .4533 .65562 L .45139 .65643 L F
.45222 .65687 m .45476 .6571 L .4533 .65562 L F
.751 .632 .729 r
.58469 .56477 m .58027 .56624 L .58071 .56406 L F
.58469 .56477 m .58371 .56665 L .58027 .56624 L F
.016 0 .404 r
.54556 .74869 m .54688 .74773 L .54683 .74535 L F
0 0 .357 r
.54556 .74869 m .54656 .75003 L .54688 .74773 L F
.635 .374 .505 r
.50786 .75158 m .51088 .75345 L .51092 .75138 L F
.636 .312 .406 r
.51092 .75138 m .51088 .75345 L .51316 .75335 L F
.751 .631 .728 r
.58027 .56624 m .58371 .56665 L .58136 .5696 L F
.683 .882 .972 r
.77838 .61528 m .77965 .61322 L .77706 .6147 L F
.77838 .61528 m .78057 .61417 L .77965 .61322 L F
.409 .324 .649 r
.46356 .77622 m .46582 .77577 L .46534 .77312 L F
.403 .214 .508 r
.46377 .77828 m .46582 .77577 L .46356 .77622 L F
.154 0 0 r
.7137 .50795 m .71623 .50776 L .71659 .50747 L F
0 0 0 r
.71659 .50747 m .71843 .50685 L .71911 .50705 L F
.71659 .50747 m .71623 .50776 L .71843 .50685 L F
.676 .507 .65 r
.51347 .73215 m .51352 .73394 L .51524 .73159 L F
0 0 .024 r
.51843 .80623 m .51727 .80698 L .51641 .80963 L F
.661 .787 .326 r
.25326 .65075 m .25328 .65069 L .25318 .65091 L F
.71 .451 .531 r
.57055 .69288 m .56757 .69484 L .56712 .69224 L F
.57055 .69288 m .57083 .69498 L .56757 .69484 L F
0 0 .339 r
.5716 .69225 m .57055 .69288 L .57237 .69169 L F
.5716 .69225 m .57083 .69498 L .57055 .69288 L F
.665 .511 .665 r
.59344 .74257 m .59596 .74014 L .59332 .74044 L F
.59344 .74257 m .5969 .74318 L .59596 .74014 L F
.655 .549 .722 r
.59688 .74547 m .5969 .74318 L .59344 .74257 L F
.266 .512 .903 r
.71949 .48689 m .71835 .48782 L .71699 .48483 L F
.556 .379 .597 r
.72051 .48994 m .72333 .48935 L .72331 .48925 L F
.075 .314 .795 r
.72656 .4898 m .72657 .49147 L .72298 .48842 L F
.658 .172 .086 r
.72333 .48935 m .72656 .4898 L .72298 .48842 L F
.556 .379 .597 r
.72167 .4886 m .72331 .48925 L .72293 .48714 L F
.72051 .48994 m .72331 .48925 L .72167 .4886 L F
.266 .512 .903 r
.71879 .48746 m .72164 .48889 L .71835 .48782 L F
.71949 .48689 m .72107 .48836 L .71879 .48746 L F
.72107 .48836 m .72164 .48889 L .71879 .48746 L F
.951 .945 .732 r
.59556 .53428 m .59726 .5334 L .59563 .53644 L F
.914 .914 .804 r
.59672 .53275 m .59963 .53064 L .59726 .5334 L F
.913 .98 .764 r
.59556 .53428 m .59672 .53275 L .59726 .5334 L F
.599 .348 .508 r
.48902 .74798 m .492 .74608 L .48978 .74609 L F
.613 .528 .735 r
.3724 .69013 m .3729 .69255 L .37458 .68974 L F
.593 .503 .722 r
.3729 .69255 m .37532 .69227 L .37458 .68974 L F
.44 .421 .741 r
.3729 .69255 m .3754 .69495 L .37532 .69227 L F
.648 .574 .758 r
.49126 .66195 m .4889 .66234 L .48811 .65958 L F
.64 .521 .703 r
.49126 .66195 m .48918 .66483 L .4889 .66234 L F
.039 .11 .611 r
.63102 .53812 m .63253 .54051 L .63283 .53849 L F
.63102 .53812 m .63206 .54151 L .63253 .54051 L F
.558 .845 .998 r
.61334 .53447 m .61308 .5338 L .61349 .53246 L F
.61334 .53447 m .61172 .53603 L .61308 .5338 L F
.169 .707 .774 r
.52267 .76507 m .52155 .76511 L .51916 .76547 L F
.302 .793 .877 r
.52526 .7646 m .52357 .76457 L .52267 .76507 L F
.318 .807 .831 r
.52267 .76507 m .52357 .76457 L .52155 .76511 L F
.613 .547 .757 r
.52267 .76507 m .526 .76797 L .52526 .7646 L F
.499 .359 .621 r
.36849 .67342 m .37059 .67361 L .37064 .6699 L F
.57 .449 .675 r
.36849 .67342 m .37125 .6753 L .37059 .67361 L F
.36849 .67342 m .36905 .67576 L .37125 .6753 L F
.374 .19 .499 r
.27471 .61944 m .27287 .62222 L .27302 .62003 L F
.723 .358 .358 r
.54719 .79618 m .54993 .79861 L .54733 .79903 L F
.536 .162 .279 r
.5502 .79842 m .54719 .79618 L .54642 .79831 L F
0 0 0 r
.62177 .48586 m .62349 .48509 L .62477 .48391 L F
.237 0 .021 r
.62349 .48509 m .62654 .48288 L .62477 .48391 L F
.735 .681 .797 r
.59332 .74044 m .59596 .74014 L .59511 .73829 L F
.645 .644 .835 r
.59596 .74014 m .59737 .73925 L .59511 .73829 L F
.59596 .74014 m .59895 .74047 L .59737 .73925 L F
.729 .588 .699 r
.5969 .74318 m .59895 .74047 L .59596 .74014 L F
.764 .57 .636 r
.47393 .7816 m .47743 .7822 L .47657 .78558 L F
.243 0 .204 r
.57659 .58163 m .57544 .5811 L .5764 .58308 L F
.57659 .58163 m .57793 .58027 L .57544 .5811 L F
.53 .302 .513 r
.32751 .61755 m .32934 .61898 L .32949 .61701 L F
.32751 .61755 m .32721 .61941 L .32934 .61898 L F
.717 .261 0 r
.77487 .59002 m .77599 .59164 L .77401 .58908 L F
.751 .901 .511 r
.73265 .50403 m .73175 .50574 L .73346 .50282 L F
.557 .523 .773 r
.7339 .50805 m .73175 .50574 L .73265 .50403 L F
.969 .663 .274 r
.77788 .60058 m .77705 .59991 L .77658 .59721 L F
.652 .863 .98 r
.77788 .60058 m .77996 .5998 L .77925 .59872 L F
.69 .921 .97 r
.77925 .59872 m .77705 .59991 L .77788 .60058 L F
.969 .749 .549 r
.78199 .5971 m .78222 .59477 L .78103 .59367 L F
.988 .858 .621 r
.78222 .59477 m .78181 .59181 L .78103 .59367 L F
.822 .595 .596 r
.61647 .50023 m .61413 .4994 L .61626 .49998 L F
.369 .004 .207 r
.2463 .59422 m .24831 .59377 L .2492 .59223 L F
.316 0 .177 r
.2492 .59223 m .25028 .59318 L .25122 .59168 L F
.2492 .59223 m .24831 .59377 L .25028 .59318 L F
0 0 0 r
.61896 .4882 m .62093 .48739 L .62177 .48586 L F
.175 0 0 r
.62177 .48586 m .62305 .48663 L .62349 .48509 L F
.62177 .48586 m .62093 .48739 L .62305 .48663 L F
0 0 0 r
.5232 .81251 m .5242 .81194 L .52633 .81135 L F
.035 0 0 r
.626 .51229 m .62383 .51321 L .62432 .51241 L F
.396 0 0 r
.626 .51229 m .62475 .51273 L .62383 .51321 L F
0 0 0 r
.62383 .51321 m .62244 .51393 L .62432 .51241 L F
.396 0 0 r
.62475 .51273 m .62227 .5136 L .62383 .51321 L F
0 0 0 r
.62383 .51321 m .62234 .51402 L .62244 .51393 L F
.62383 .51321 m .62144 .51555 L .62234 .51402 L F
0 .073 .586 r
.78049 .58502 m .77954 .58434 L .7788 .58286 L F
.78049 .58502 m .78117 .58586 L .77954 .58434 L F
.61 .417 .596 r
.48829 .78452 m .48607 .78217 L .48842 .78191 L F
.48829 .78452 m .48593 .78495 L .48607 .78217 L F
.594 .615 .842 r
.27643 .63077 m .27583 .63427 L .27457 .63078 L F
.27643 .63077 m .27796 .63376 L .27583 .63427 L F
.108 0 0 r
.40055 .71229 m .39906 .7138 L .39717 .71432 L F
.541 .131 .212 r
.40271 .71211 m .39906 .7138 L .40055 .71229 L F
.779 .336 .197 r
.51456 .7783 m .51705 .77924 L .51543 .77938 L F
.697 .54 .67 r
.51485 .78207 m .5183 .78204 L .51705 .77924 L F
.64 .624 .818 r
.51485 .78207 m .51819 .784 L .5183 .78204 L F
.737 .537 .623 r
.51686 .78106 m .51782 .78336 L .51228 .78324 L F
.805 .346 .145 r
.51705 .77924 m .51731 .78131 L .51543 .77938 L F
.51731 .78131 m .51723 .78126 L .51543 .77938 L F
.461 .352 .644 r
.51543 .77938 m .51723 .78126 L .51717 .78092 L F
.737 .537 .623 r
.51717 .78092 m .51726 .78128 L .51723 .78126 L F
.805 .346 .145 r
.51731 .78131 m .51732 .78136 L .51728 .78131 L F
.737 .537 .623 r
.51726 .78128 m .51782 .78336 L .51686 .78106 L F
.805 .346 .145 r
.51726 .78128 m .51728 .78131 L .51723 .78126 L F
.51731 .78131 m .51728 .78131 L .51726 .78128 L F
0 0 .466 r
.51801 .7831 m .51782 .78336 L .51726 .78128 L F
.51728 .78131 m .51726 .78128 L .51717 .78092 L F
.461 .352 .644 r
.51723 .78126 m .51728 .78131 L .51717 .78092 L F
.51728 .78131 m .51732 .78136 L .51717 .78092 L F
.142 .241 .707 r
.51705 .77924 m .5183 .78204 L .51895 .78166 L F
.851 .441 .257 r
.51732 .78136 m .51895 .78166 L .51801 .7831 L F
0 0 .466 r
.51801 .7831 m .51717 .78092 L .51732 .78136 L F
.51745 .78166 m .51728 .78131 L .51717 .78092 L F
.51801 .7831 m .51726 .78128 L .51745 .78166 L F
.737 .537 .623 r
.51717 .78092 m .51723 .78126 L .51686 .78106 L F
.805 .346 .145 r
.51705 .77924 m .51895 .78166 L .51732 .78136 L F
.576 .327 .502 r
.45979 .68961 m .46178 .69132 L .45946 .69154 L F
.647 .3 .369 r
.46195 .69003 m .46178 .69132 L .45979 .68961 L F
.568 .906 .976 r
.55921 .77319 m .56306 .77247 L .56153 .77295 L F
.35 0 .042 r
.56306 .77247 m .56371 .77289 L .56153 .77295 L F
.197 0 0 r
.42782 .70345 m .42649 .70462 L .42415 .70512 L F
.252 0 0 r
.43002 .70318 m .42649 .70462 L .42782 .70345 L F
.702 .645 .79 r
.48204 .64775 m .48334 .6511 L .47968 .65037 L F
.789 .409 .336 r
.52201 .80912 m .52318 .80728 L .5202 .80663 L F
.291 0 .052 r
.52535 .80674 m .52318 .80728 L .52201 .80912 L F
.658 .732 .904 r
.5254 .80436 m .52318 .80728 L .52535 .80674 L F
.831 .61 .604 r
.57908 .58398 m .57859 .58647 L .5764 .58308 L F
.57908 .58398 m .57948 .58593 L .57859 .58647 L F
.62 .507 .703 r
.58182 .58346 m .57948 .58593 L .57908 .58398 L F
.822 .595 .596 r
.61647 .50023 m .6138 .50202 L .61413 .4994 L F
.98 .914 .627 r
.61372 .50467 m .6138 .50202 L .61647 .50023 L F
.309 0 .224 r
.47393 .75647 m .4757 .75619 L .4765 .75388 L F
.31 0 .224 r
.4765 .75388 m .47765 .75559 L .47839 .75297 L F
.4765 .75388 m .4757 .75619 L .47765 .75559 L F
.709 .441 .517 r
.60135 .5805 m .60529 .5798 L .6037 .58299 L F
.636 .357 .478 r
.60707 .58055 m .6037 .58299 L .60529 .5798 L F
.493 .353 .619 r
.37064 .6699 m .37245 .66688 L .37039 .66739 L F
.632 .594 .793 r
.37415 .69811 m .37744 .7006 L .3761 .69769 L F
.576 .559 .798 r
.37744 .7006 m .37871 .69717 L .3761 .69769 L F
.37744 .7006 m .38041 .70067 L .37871 .69717 L F
.562 .519 .765 r
.37744 .7006 m .38057 .70367 L .38041 .70067 L F
.948 .753 .29 r
.6622 .51102 m .66173 .51014 L .66179 .50757 L F
.557 .551 .803 r
.37172 .68693 m .37237 .68319 L .37098 .6845 L F
.37172 .68693 m .3738 .68648 L .37237 .68319 L F
.609 .508 .714 r
.37172 .68693 m .37458 .68974 L .3738 .68648 L F
.37172 .68693 m .3724 .69013 L .37458 .68974 L F
.511 .268 .481 r
.5568 .69771 m .55939 .69505 L .55761 .69516 L F
.961 .856 .692 r
.57688 .72051 m .57566 .7232 L .5764 .72299 L F
0 0 .376 r
.57696 .72535 m .5764 .72299 L .57566 .7232 L F
.658 .967 .8 r
.61832 .55057 m .61566 .55239 L .61709 .55097 L F
.257 0 0 r
.61709 .55097 m .62135 .55018 L .61832 .55057 L F
.135 .111 .565 r
.46492 .76813 m .46659 .76941 L .4663 .76715 L F
.46492 .76813 m .46525 .77065 L .46659 .76941 L F
.732 .365 .356 r
.61262 .55299 m .61566 .55239 L .61313 .55269 L F
.102 0 0 r
.30626 .60102 m .30464 .60187 L .30251 .60222 L F
0 0 0 r
.30827 .60093 m .30464 .60187 L .30626 .60102 L F
.70301 .52929 m .70344 .52865 L .70392 .52824 L F
.70569 .5266 m .70301 .52929 L .70392 .52824 L F
.678 .947 .684 r
.7042 .52761 m .70301 .52929 L .70443 .52786 L F
.7042 .52761 m .70443 .52786 L .70569 .5266 L F
.832 .838 .37 r
.70405 .52744 m .7042 .52761 L .70457 .5254 L F
.131 0 .255 r
.70354 .52946 m .70211 .53061 L .7042 .52761 L F
.832 .838 .37 r
.70354 .52946 m .7042 .52761 L .70405 .52744 L F
0 0 0 r
.70259 .52992 m .70301 .52929 L .7042 .52761 L F
.70211 .53061 m .70301 .52929 L .70259 .52992 L F
.70301 .52929 m .7013 .53048 L .70344 .52865 L F
.70042 .53186 m .7013 .53048 L .70301 .52929 L F
.81 .764 .81 r
.36666 .71088 m .36848 .71217 L .37066 .70957 L F
.575 .396 .602 r
.39786 .67549 m .39552 .67818 L .39547 .67585 L F
.301 .148 .499 r
.48755 .7491 m .48737 .74982 L .48902 .74798 L F
.437 .421 .744 r
.52175 .78151 m .51942 .77945 L .52271 .77933 L F
.392 .104 .351 r
.52465 .7802 m .52271 .77933 L .525 .77864 L F
.52465 .7802 m .52175 .78151 L .52271 .77933 L F
.427 .793 .995 r
.66452 .49359 m .66341 .49282 L .66074 .49311 L F
.396 .776 .991 r
.66452 .49359 m .66743 .49344 L .66341 .49282 L F
.877 .473 .255 r
.47657 .78558 m .479 .78755 L .47748 .7867 L F
.686 .18 0 r
.479 .78755 m .47868 .78772 L .47748 .7867 L F
0 0 .549 r
.65933 .50249 m .66113 .50536 L .66052 .50408 L F
.928 .602 .144 r
.66179 .50757 m .66052 .50408 L .66113 .50536 L F
.677 .632 .797 r
.70452 .4919 m .70538 .49465 L .70778 .49402 L F
.295 0 .115 r
.31517 .6302 m .31696 .63045 L .31817 .6284 L F
.261 0 .097 r
.31817 .6284 m .31887 .62983 L .32009 .62769 L F
.31817 .6284 m .31696 .63045 L .31887 .62983 L F
.504 .404 .675 r
.54986 .70477 m .55254 .70587 L .55248 .70349 L F
.54986 .70477 m .55038 .70642 L .55254 .70587 L F
.586 .368 .551 r
.51876 .7369 m .52116 .7343 L .51882 .73454 L F
.55 .335 .541 r
.55463 .69816 m .55695 .70012 L .5568 .69771 L F
.55463 .69816 m .55453 .70071 L .55695 .70012 L F
.302 0 .148 r
.73204 .51101 m .73188 .51268 L .72903 .51356 L F
.836 .953 .606 r
.73393 .5098 m .73188 .51268 L .73204 .51101 L F
.446 0 0 r
.49238 .81465 m .4959 .81569 L .49463 .81561 L F
.329 .811 .877 r
.49463 .81561 m .4959 .81569 L .49801 .81517 L F
.534 .474 .735 r
.46228 .78181 m .46446 .78152 L .46377 .77828 L F
.475 .422 .718 r
.46228 .78181 m .4651 .78436 L .46446 .78152 L F
0 0 .476 r
.5456 .70956 m .54681 .71066 L .54818 .70885 L F
.5456 .70956 m .5457 .71212 L .54681 .71066 L F
0 0 0 r
.29097 .65036 m .29303 .6502 L .28948 .65051 L F
0 0 .493 r
.64253 .48688 m .64193 .48603 L .64123 .48581 L F
.64253 .48688 m .64374 .48831 L .64193 .48603 L F
.649 .715 .896 r
.69509 .49064 m .69862 .49128 L .69798 .48982 L F
.565 .755 .967 r
.69862 .49128 m .7002 .48942 L .69798 .48982 L F
.69862 .49128 m .70095 .49078 L .7002 .48942 L F
.008 0 0 r
.75744 .58717 m .75392 .58846 L .75399 .58776 L F
.453 .333 .626 r
.25453 .64959 m .25318 .65091 L .25328 .65069 L F
.746 .648 .752 r
.5183 .78204 m .51819 .784 L .52029 .78208 L F
.622 .441 .616 r
.52029 .78208 m .52055 .78475 L .51819 .784 L F
.52029 .78208 m .52055 .78475 L .51819 .784 L F
.518 .29 .509 r
.52755 .80614 m .5254 .80436 L .52535 .80674 L F
.52755 .80614 m .52764 .80401 L .5254 .80436 L F
.7 .269 .223 r
.52086 .77478 m .52213 .77279 L .52001 .77328 L F
.52086 .77478 m .5232 .77389 L .52213 .77279 L F
.713 .229 .095 r
.66354 .51637 m .66277 .51779 L .66247 .51553 L F
.66354 .51637 m .66594 .51839 L .66277 .51779 L F
.691 .819 .944 r
.76293 .57688 m .76179 .57908 L .75999 .5796 L F
.76293 .57688 m .76398 .57812 L .76179 .57908 L F
.815 .664 .696 r
.58136 .5696 m .57842 .56917 L .58027 .56624 L F
.762 .648 .736 r
.58095 .57213 m .57842 .56917 L .58136 .5696 L F
.919 .696 .584 r
.55644 .70359 m .55471 .70315 L .55453 .70071 L F
.268 0 0 r
.55836 .70594 m .55471 .70315 L .55644 .70359 L F
.437 .421 .744 r
.52175 .78151 m .52029 .78208 L .51942 .77945 L F
.722 .5 .589 r
.52175 .78151 m .51895 .78166 L .52029 .78208 L F
.391 .806 .976 r
.51895 .78166 m .5183 .78204 L .52029 .78208 L F
.815 .486 .432 r
.49142 .80957 m .49113 .80714 L .48866 .8069 L F
.616 .34 .475 r
.49142 .80957 m .49333 .80928 L .49113 .80714 L F
.49 .042 .111 r
.40612 .71118 m .40514 .71225 L .40271 .71211 L F
.29 0 0 r
.40835 .71089 m .40514 .71225 L .40612 .71118 L F
.5 .441 .722 r
.37415 .69811 m .3761 .69769 L .3754 .69495 L F
.643 .436 .587 r
.6129 .57774 m .6095 .58042 L .60952 .5781 L F
.622 .388 .541 r
.60952 .5781 m .6095 .58042 L .60707 .58055 L F
.543 .396 .631 r
.36522 .60577 m .36505 .60708 L .36372 .60672 L F
.568 .226 .349 r
.36372 .60672 m .36424 .60979 L .36223 .61064 L F
.36372 .60672 m .36505 .60708 L .36424 .60979 L F
.41 .837 .957 r
.29272 .63554 m .29481 .63507 L .2965 .63538 L F
.325 .803 .903 r
.29481 .63507 m .29882 .63476 L .2965 .63538 L F
.765 .715 .805 r
.71483 .50005 m .71624 .50293 L .71731 .50028 L F
.375 .625 .95 r
.75399 .61237 m .75757 .61425 L .75697 .61284 L F
.412 .572 .902 r
.75697 .61284 m .75757 .61425 L .7597 .61443 L F
.738 .675 .789 r
.50136 .64415 m .50276 .64556 L .49922 .64512 L F
.694 .67 .822 r
.50544 .64498 m .50276 .64556 L .50136 .64415 L F
.39 .336 .677 r
.39785 .67783 m .39663 .68144 L .39552 .67818 L F
.39785 .67783 m .39825 .68117 L .39663 .68144 L F
.398 .381 .724 r
.39825 .68117 m .39896 .68328 L .39663 .68144 L F
.432 .382 .702 r
.39663 .68144 m .39896 .68328 L .3972 .68354 L F
.453 .333 .626 r
.25453 .64959 m .25257 .65285 L .25318 .65091 L F
0 0 0 r
.70569 .5266 m .70392 .52824 L .70579 .52693 L F
.632 .872 .519 r
.30008 .84793 m .3016 .84624 L .29937 .84906 L F
.539 .354 .578 r
.3016 .84624 m .30156 .84885 L .29937 .84906 L F
.446 .773 .997 r
.29937 .84906 m .30156 .84885 L .30008 .84793 L F
.735 .327 .276 r
.48512 .79585 m .48822 .79645 L .48534 .79819 L F
.418 .289 .596 r
.54276 .75136 m .543 .75376 L .54621 .75089 L F
.368 0 0 r
.42949 .66188 m .42584 .66335 L .42734 .66212 L F
.756 .646 .74 r
.49922 .64512 m .50053 .64798 L .49753 .64778 L F
.764 .572 .637 r
.50053 .64798 m .49705 .65021 L .49753 .64778 L F
.50053 .64798 m .50044 .65045 L .49705 .65021 L F
.449 .2 .443 r
.5471 .80113 m .54733 .79903 L .54993 .79861 L F
.466 .218 .453 r
.24074 .59958 m .24321 .59699 L .24151 .59758 L F
.362 .327 .685 r
.37049 .68137 m .37098 .6845 L .37237 .68319 L F
.375 .371 .727 r
.36995 .67906 m .37049 .68137 L .372 .68086 L F
.36 .327 .686 r
.37049 .68137 m .37237 .68319 L .372 .68086 L F
0 0 0 r
.55462 .77858 m .55751 .77678 L .55587 .77799 L F
.816 .992 .743 r
.55751 .77678 m .55841 .77488 L .55867 .77517 L F
.55841 .77488 m .55921 .77319 L .55867 .77517 L F
0 0 .389 r
.55812 .77286 m .55867 .77517 L .55921 .77319 L F
.55812 .77286 m .55892 .77548 L .55867 .77517 L F
.55892 .77548 m .55896 .7756 L .55867 .77517 L F
.724 .958 .676 r
.55587 .77799 m .55751 .77678 L .55867 .77517 L F
.373 .779 .983 r
.29672 .58681 m .29899 .58663 L .30025 .58721 L F
.279 .647 .967 r
.30129 .58641 m .30025 .58721 L .29899 .58663 L F
.30129 .58641 m .30247 .58744 L .30025 .58721 L F
.736 .657 .771 r
.47783 .76214 m .47543 .76517 L .4791 .76486 L F
.644 .418 .56 r
.47543 .76517 m .47828 .76733 L .4791 .76486 L F
.761 .667 .759 r
.47783 .76214 m .4791 .76486 L .48028 .76338 L F
.626 .332 .45 r
.4791 .76486 m .47828 .76733 L .48114 .76706 L F
.625 .802 .967 r
.2816 .63419 m .27796 .63376 L .28009 .63299 L F
.641 .917 .979 r
.28376 .63325 m .2816 .63419 L .28217 .63281 L F
.463 .731 .985 r
.28217 .63281 m .2816 .63419 L .28009 .63299 L F
.28217 .63281 m .2816 .63419 L .28009 .63299 L F
.628 .158 .119 r
.53745 .7579 m .53858 .75705 L .53503 .75669 L F
.549 .722 .954 r
.53982 .75779 m .53858 .75705 L .53745 .7579 L F
.53982 .75779 m .54086 .75657 L .53858 .75705 L F
.602 .893 .989 r
.55988 .7884 m .5609 .78682 L .55783 .78918 L F
.55988 .7884 m .56205 .78749 L .5609 .78682 L F
.898 .782 .724 r
.59681 .73137 m .59864 .72864 L .59605 .72852 L F
.545 .516 .774 r
.39896 .68328 m .39785 .68705 L .3972 .68354 L F
.39896 .68328 m .39987 .68658 L .39785 .68705 L F
.522 .416 .675 r
.39987 .68658 m .40014 .68897 L .39785 .68705 L F
.224 .223 .647 r
.61072 .53518 m .60993 .53882 L .61172 .53603 L F
.558 .845 .998 r
.61334 .53447 m .61072 .53518 L .61172 .53603 L F
.496 .111 .24 r
.55202 .77962 m .55462 .77858 L .55365 .78088 L F
0 0 0 r
.55365 .78088 m .55462 .77858 L .55587 .77799 L F
.807 .487 .449 r
.5387 .77582 m .53886 .77394 L .5352 .77313 L F
.741 .553 .64 r
.5387 .77582 m .54266 .77303 L .53886 .77394 L F
.873 .688 .649 r
.58104 .56133 m .58071 .56406 L .57934 .56074 L F
.513 .254 .46 r
.53341 .72745 m .53687 .72567 L .53449 .72594 L F
.602 .614 .835 r
.46836 .6646 m .4721 .66721 L .47084 .66569 L F
.573 .736 .953 r
.47084 .66569 m .4721 .66721 L .4744 .66673 L F
.622 .64 .847 r
.4721 .66721 m .47519 .66833 L .4744 .66673 L F
0 .12 .605 r
.55268 .75443 m .55469 .75606 L .55297 .75459 L F
.606 .707 .915 r
.29074 .63577 m .28694 .63451 L .28989 .63493 L F
.444 .772 .997 r
.29155 .63484 m .29074 .63577 L .28989 .63493 L F
.29155 .63484 m .29272 .63554 L .29074 .63577 L F
.026 0 0 r
.48364 .75131 m .4861 .75072 L .48737 .74982 L F
.663 .935 .661 r
.48737 .74982 m .48692 .74976 L .48902 .74798 L F
.697 .938 .637 r
.48737 .74982 m .4861 .75072 L .48692 .74976 L F
.914 .914 .804 r
.59672 .53275 m .59865 .52974 L .59963 .53064 L F
.563 .782 .981 r
.273 .65158 m .27373 .65279 L .27542 .65184 L F
.42 0 .008 r
.39127 .65471 m .39051 .65329 L .3891 .65506 L F
.39127 .65471 m .3928 .65326 L .39051 .65329 L F
.604 .579 .799 r
.40815 .69712 m .40613 .69782 L .40497 .69477 L F
.643 .958 .93 r
.66408 .484 m .6644 .48449 L .66729 .48264 L F
.234 0 .228 r
.55167 .79552 m .55044 .79555 L .5502 .79842 L F
.454 .147 .354 r
.44019 .69969 m .43812 .69826 L .44036 .69804 L F
.44019 .69969 m .43851 .70042 L .43812 .69826 L F
.981 .882 .658 r
.63785 .54465 m .63817 .54081 L .6398 .54174 L F
.62 .907 .984 r
.66304 .48858 m .66214 .48796 L .66452 .48701 L F
.46 .634 .93 r
.66452 .48701 m .66526 .48891 L .66304 .48858 L F
.761 .667 .759 r
.47783 .76214 m .48028 .76338 L .48004 .76176 L F
.594 .782 .97 r
.48028 .76338 m .483 .76209 L .48004 .76176 L F
.545 .72 .954 r
.6712 .48528 m .67264 .48347 L .66988 .48234 L F
.6712 .48528 m .67267 .48406 L .67264 .48347 L F
.74 .964 .685 r
.64427 .54965 m .64384 .54966 L .6415 .55234 L F
.76 .965 .673 r
.64508 .54803 m .64427 .54965 L .64726 .54765 L F
.64508 .54803 m .64384 .54966 L .64427 .54965 L F
0 0 0 r
.37902 .70951 m .37859 .71086 L .38071 .70844 L F
.46 .771 .997 r
.34146 .59259 m .33933 .59288 L .33789 .59187 L F
.635 .374 .505 r
.50786 .75158 m .50737 .75383 L .51088 .75345 L F
.081 0 .11 r
.61896 .4882 m .61852 .49004 L .62093 .48739 L F
.966 .719 .513 r
.30008 .84793 m .30156 .84885 L .3016 .84624 L F
.419 0 0 r
.47519 .66833 m .47629 .66911 L .4744 .66673 L F
.47519 .66833 m .4776 .66962 L .47629 .66911 L F
.893 .471 .15 r
.48526 .80467 m .48451 .80112 L .48264 .80142 L F
.48501 .80345 m .48631 .80432 L .48451 .80112 L F
.613 .417 .593 r
.48734 .80013 m .48341 .80187 L .48392 .79975 L F
.48341 .80187 m .48316 .80198 L .48325 .80171 L F
.48341 .80187 m .48325 .80171 L .48392 .79975 L F
.893 .471 .15 r
.48526 .80467 m .48599 .80443 L .48501 .80345 L F
.48599 .80443 m .48631 .80432 L .48501 .80345 L F
.422 0 0 r
.68217 .53115 m .68108 .52962 L .68013 .53188 L F
.704 .174 0 r
.68403 .53134 m .68108 .52962 L .68314 .52983 L F
.422 0 0 r
.68217 .53115 m .68314 .52983 L .68108 .52962 L F
.482 .754 .99 r
.31006 .58809 m .30954 .58954 L .30805 .58858 L F
.31006 .58809 m .31161 .58928 L .30954 .58954 L F
.836 .732 .75 r
.47667 .67804 m .47895 .67848 L .47892 .67523 L F
.47667 .67804 m .47867 .67852 L .47895 .67848 L F
.924 .678 .548 r
.47867 .67852 m .47865 .68031 L .47895 .67848 L F
.775 .728 .809 r
.47892 .67523 m .47895 .67848 L .48258 .67545 L F
.523 .309 .531 r
.47895 .67848 m .48106 .67834 L .48311 .67818 L F
.47895 .67848 m .47865 .68031 L .48106 .67834 L F
.903 .71 .631 r
.37293 .70883 m .37418 .71211 L .3718 .71111 L F
.001 .183 .698 r
.37484 .71089 m .37418 .71211 L .37293 .70883 L F
.471 .787 .999 r
.3718 .71111 m .37418 .71211 L .37484 .71089 L F
.983 .905 .589 r
.61372 .50467 m .61221 .50594 L .61294 .5041 L F
.61372 .50467 m .6126 .50828 L .61221 .50594 L F
.98 .914 .627 r
.61372 .50467 m .61294 .5041 L .6138 .50202 L F
.713 .695 .831 r
.47413 .64859 m .47064 .64801 L .47267 .64675 L F
.678 .635 .8 r
.47629 .64769 m .47413 .64859 L .47267 .64675 L F
.773 .588 .649 r
.57343 .72288 m .57566 .7232 L .57688 .72051 L F
0 0 0 r
.50693 .7904 m .50999 .78745 L .51026 .79013 L F
.51208 .78871 m .51026 .79013 L .50999 .78745 L F
0 0 .154 r
.73365 .50084 m .73265 .50403 L .73346 .50282 L F
.46 .701 .971 r
.25946 .64633 m .26122 .64777 L .26182 .6464 L F
.198 .386 .824 r
.26122 .64777 m .26324 .64899 L .26182 .6464 L F
.557 .581 .833 r
.26122 .64777 m .2646 .65039 L .26324 .64899 L F
.209 .309 .748 r
.467 .65919 m .46801 .66205 L .46864 .66084 L F
0 0 .385 r
.46801 .66205 m .46845 .66293 L .46864 .66084 L F
.46801 .66205 m .46836 .6646 L .46845 .66293 L F
.992 .736 .408 r
.6328 .54321 m .63411 .54639 L .63437 .54542 L F
.292 .708 .973 r
.2967 .64993 m .29723 .64918 L .29511 .64954 L F
.2967 .64993 m .29872 .65 L .29723 .64918 L F
.048 0 0 r
.49973 .78273 m .49892 .78345 L .49636 .78398 L F
.787 .289 0 r
.49973 .78273 m .50142 .78484 L .49892 .78345 L F
.951 .686 .498 r
.65926 .51468 m .66182 .51618 L .66039 .51204 L F
.85 .841 .835 r
.6609 .51678 m .66182 .51618 L .65926 .51468 L F
.81 .764 .81 r
.36666 .71088 m .37066 .70957 L .3698 .70809 L F
.66 .785 .941 r
.37293 .70883 m .37066 .70957 L .3698 .70809 L F
.37293 .70883 m .36989 .70618 L .37239 .70665 L F
.37293 .70883 m .3698 .70809 L .36989 .70618 L F
.802 .994 .87 r
.37418 .70653 m .37293 .70883 L .37239 .70665 L F
.37418 .70653 m .3713 .70927 L .37293 .70883 L F
.038 .102 .602 r
.37137 .70976 m .37131 .70935 L .3698 .70809 L F
.802 .994 .87 r
.3713 .70927 m .37101 .70955 L .37132 .70943 L F
0 .275 .776 r
.3698 .70809 m .37131 .70935 L .37001 .70738 L F
.705 .265 .203 r
.372 .70993 m .37293 .70883 L .37132 .70943 L F
.038 .102 .602 r
.37137 .70976 m .372 .70993 L .37132 .70943 L F
.705 .265 .203 r
.372 .70993 m .37132 .70943 L .37101 .70955 L F
.802 .994 .87 r
.37131 .70935 m .37132 .70943 L .37133 .70943 L F
.038 .102 .602 r
.37132 .70943 m .372 .70993 L .37131 .70935 L F
.79 .815 .872 r
.37001 .70738 m .37101 .70955 L .3713 .70928 L F
.37001 .70738 m .3713 .70928 L .37418 .70653 L F
0 .275 .776 r
.3713 .70928 m .372 .70993 L .37123 .70894 L F
.802 .994 .87 r
.37131 .70935 m .37133 .70943 L .37293 .70883 L F
0 .275 .776 r
.37131 .70935 m .3714 .70942 L .3713 .70928 L F
.3714 .70942 m .372 .70993 L .3713 .70928 L F
.37131 .70935 m .37123 .70894 L .37001 .70738 L F
.802 .994 .87 r
.3713 .70927 m .37131 .70935 L .37293 .70883 L F
.038 .102 .602 r
.37066 .70957 m .37137 .70976 L .3698 .70809 L F
.37066 .70957 m .3718 .71111 L .372 .70993 L F
.993 .816 .563 r
.5609 .78682 m .56261 .78485 L .56138 .78335 L F
.5609 .78682 m .56205 .78749 L .56261 .78485 L F
.667 .59 .76 r
.48204 .64775 m .47968 .65037 L .47845 .64661 L F
.434 .363 .677 r
.46347 .78747 m .46521 .78734 L .4651 .78436 L F
.415 .539 .873 r
.46347 .78747 m .46691 .79028 L .46521 .78734 L F
.605 .36 .519 r
.6176 .57516 m .61505 .57756 L .615 .57515 L F
.555 .583 .838 r
.73806 .60558 m .74141 .60825 L .74041 .60514 L F
.632 .63 .83 r
.74141 .60825 m .74278 .60463 L .74041 .60514 L F
.74141 .60825 m .74376 .60761 L .74278 .60463 L F
.766 .534 .582 r
.54027 .78709 m .54229 .78447 L .54234 .78435 L F
.876 .98 .838 r
.65586 .50425 m .65924 .50234 L .65517 .50126 L F
.65586 .50425 m .65638 .50544 L .65924 .50234 L F
.492 .155 .322 r
.28594 .61011 m .28459 .60842 L .28671 .60806 L F
.28594 .61011 m .28346 .61063 L .28459 .60842 L F
.105 0 0 r
.37832 .65536 m .3763 .65602 L .37885 .65481 L F
.519 .233 .42 r
.50351 .81394 m .5015 .81346 L .50152 .81504 L F
.50351 .81394 m .50369 .81252 L .5015 .81346 L F
0 0 0 r
.78406 .60755 m .78367 .60806 L .78497 .60613 L F
.994 .752 .43 r
.78406 .60499 m .78406 .60755 L .78497 .60613 L F
.502 0 0 r
.78296 .60422 m .78645 .60698 L .78406 .60755 L F
.579 .901 .983 r
.78645 .60698 m .78433 .60721 L .78406 .60755 L F
.78433 .60721 m .78336 .60731 L .78406 .60755 L F
0 0 0 r
.78406 .60755 m .78297 .60911 L .78367 .60806 L F
.579 .785 .977 r
.2646 .65039 m .26512 .64863 L .26324 .64899 L F
.2646 .65039 m .26673 .64985 L .26512 .64863 L F
.421 .725 .988 r
.31968 .58958 m .31904 .59072 L .31734 .5898 L F
.31968 .58958 m .32103 .59073 L .31904 .59072 L F
.284 0 0 r
.70019 .51996 m .69888 .51916 L .6988 .52085 L F
.70019 .51996 m .70131 .51894 L .69888 .51916 L F
.676 .2 .114 r
.50135 .74217 m .5059 .74049 L .5042 .74099 L F
.631 .413 .567 r
.5267 .73412 m .52965 .73153 L .52678 .73257 L F
.59 .539 .765 r
.49015 .647 m .48868 .65056 L .48812 .64765 L F
.49015 .647 m .49113 .65046 L .48868 .65056 L F
.583 .417 .622 r
.49113 .65046 m .48907 .65313 L .48868 .65056 L F
.718 .446 0 r
.5976 .71743 m .59805 .71932 L .59838 .72045 L F
.956 .902 .524 r
.59838 .72045 m .59707 .7226 L .59848 .72333 L F
.59838 .72045 m .59805 .71932 L .59707 .7226 L F
.831 .657 .667 r
.60061 .73985 m .59737 .73925 L .59895 .74047 L F
.60061 .73985 m .59807 .73723 L .59737 .73925 L F
.607 .525 .736 r
.36905 .67576 m .36995 .67906 L .37178 .67838 L F
.375 .371 .727 r
.36995 .67906 m .372 .68086 L .37178 .67838 L F
.11 0 .034 r
.32222 .64609 m .3216 .64492 L .32362 .64433 L F
.32222 .64609 m .32046 .64699 L .3216 .64492 L F
.524 .768 .986 r
.68029 .48011 m .67905 .48159 L .67772 .48018 L F
.68029 .48011 m .68129 .48127 L .67905 .48159 L F
.158 0 0 r
.27248 .58445 m .27456 .58461 L .2762 .58446 L F
.917 .936 .803 r
.59349 .5374 m .59563 .53644 L .59452 .53843 L F
.59349 .5374 m .59556 .53428 L .59563 .53644 L F
0 0 .434 r
.6431 .48291 m .64494 .48546 L .64364 .48368 L F
.753 .637 .733 r
.59048 .68968 m .59232 .6868 L .59006 .68717 L F
.962 .746 .567 r
.67026 .51039 m .67014 .51309 L .6714 .51368 L F
.684 .142 0 r
.6714 .51368 m .67014 .51309 L .66998 .51344 L F
.59 .564 .793 r
.6714 .51368 m .6726 .5098 L .67026 .51039 L F
.6714 .51368 m .67374 .51314 L .6726 .5098 L F
.65 .164 .084 r
.66998 .51344 m .67374 .51314 L .6714 .51368 L F
.084 .176 .663 r
.71069 .51005 m .71241 .51111 L .71307 .5081 L F
.314 0 0 r
.71307 .5081 m .71623 .50776 L .7137 .50795 L F
.71307 .5081 m .7153 .50898 L .71623 .50776 L F
.268 0 .179 r
.71307 .5081 m .71241 .51111 L .7153 .50898 L F
.292 .077 .406 r
.62599 .5008 m .62395 .50202 L .62397 .49974 L F
.3 0 0 r
.46536 .68944 m .46178 .69132 L .46195 .69003 L F
.46536 .68944 m .46408 .69095 L .46178 .69132 L F
.375 0 .006 r
.46768 .68931 m .46408 .69095 L .46536 .68944 L F
.276 0 0 r
.31599 .63134 m .31517 .6302 L .31388 .63178 L F
.31599 .63134 m .31696 .63045 L .31517 .6302 L F
.805 .566 .576 r
.60993 .53882 m .60997 .54116 L .6115 .54043 L F
.976 .824 .627 r
.61001 .54344 m .6115 .54043 L .60997 .54116 L F
.799 .912 .517 r
.61145 .53795 m .60997 .54116 L .60993 .53882 L F
.61128 .53832 m .61011 .54009 L .60997 .54116 L F
.61145 .53795 m .61011 .54009 L .61128 .53832 L F
.617 .752 .942 r
.60766 .54107 m .60929 .54132 L .61011 .54009 L F
.536 .745 .972 r
.61117 .54161 m .61024 .54126 L .61011 .54009 L F
.61024 .54126 m .60997 .54116 L .61003 .54069 L F
.61024 .54126 m .61003 .54069 L .61011 .54009 L F
.617 .752 .942 r
.60929 .54132 m .61117 .54161 L .61011 .54009 L F
.976 .824 .627 r
.61001 .54344 m .61115 .54441 L .6112 .54381 L F
.61061 .54224 m .6112 .54381 L .6115 .54043 L F
.61001 .54344 m .6112 .54381 L .61061 .54224 L F
.575 .359 .55 r
.48842 .78191 m .49064 .78407 L .48829 .78452 L F
.619 .355 .496 r
.49059 .78194 m .49064 .78407 L .48842 .78191 L F
.353 .595 .937 r
.34911 .59352 m .34837 .59491 L .34738 .5934 L F
.504 .779 .994 r
.34911 .59352 m .35051 .59457 L .34837 .59491 L F
.844 .817 .823 r
.50572 .79642 m .50596 .79691 L .50399 .79813 L F
.705 .476 .574 r
.50596 .79691 m .50607 .79916 L .50399 .79813 L F
.305 .526 .903 r
.50789 .79667 m .50596 .79691 L .50572 .79642 L F
.642 .196 .177 r
.50596 .79691 m .5087 .79866 L .50607 .79916 L F
.547 .416 .654 r
.50574 .79644 m .50607 .79916 L .5087 .79866 L F
.50572 .79642 m .50572 .79643 L .50574 .79644 L F
.50572 .79643 m .50607 .79916 L .50574 .79644 L F
.305 .526 .903 r
.50672 .79681 m .50874 .79812 L .50596 .79691 L F
.50789 .79667 m .50833 .79742 L .50672 .79681 L F
.50833 .79742 m .50874 .79812 L .50672 .79681 L F
.642 .196 .177 r
.50596 .79691 m .50874 .79812 L .5087 .79866 L F
.75 .233 0 r
.54481 .72566 m .54829 .72821 L .54596 .72645 L F
.636 .075 0 r
.54596 .72645 m .54829 .72821 L .54962 .72848 L F
.727 .832 .93 r
.3176 .60253 m .32132 .60218 L .31966 .60213 L F
.376 .773 .986 r
.32132 .60218 m .32166 .60133 L .31966 .60213 L F
.32132 .60218 m .32364 .60208 L .32166 .60133 L F
.778 .704 .782 r
.67478 .50699 m .67503 .50975 L .67599 .508 L F
.532 .806 .996 r
.67478 .50699 m .67825 .50746 L .67599 .508 L F
.67478 .50699 m .67825 .50746 L .67599 .508 L F
.468 .807 .999 r
.77599 .59164 m .77704 .59033 L .77401 .58908 L F
.77599 .59164 m .77792 .59115 L .77704 .59033 L F
.527 .408 .661 r
.77599 .59164 m .77818 .59356 L .77792 .59115 L F
.77599 .59164 m .7761 .59461 L .77818 .59356 L F
.782 .674 .744 r
.46521 .67831 m .46649 .6809 L .46872 .67859 L F
.719 .568 .683 r
.46649 .6809 m .46911 .68165 L .46872 .67859 L F
.647 .516 .69 r
.46872 .67859 m .47202 .68067 L .47093 .67796 L F
.46872 .67859 m .46911 .68165 L .47202 .68067 L F
.575 .407 .617 r
.46652 .7649 m .46881 .76191 L .46669 .76242 L F
0 0 .17 r
.49529 .76075 m .49502 .75966 L .49709 .76009 L F
.243 0 .204 r
.57659 .58163 m .5764 .58308 L .57572 .582 L F
.846 .399 0 r
.5764 .58308 m .57647 .5845 L .57572 .582 L F
.5764 .58308 m .57859 .58647 L .57647 .5845 L F
.224 .223 .647 r
.61072 .53518 m .61145 .53795 L .60993 .53882 L F
.223 .378 .809 r
.61227 .54305 m .61115 .54441 L .61001 .54344 L F
.61227 .54305 m .61364 .54644 L .61115 .54441 L F
.578 .404 .61 r
.61115 .54441 m .61364 .54644 L .61125 .5468 L F
.58 .524 .756 r
.73806 .60558 m .7399 .60313 L .73711 .60241 L F
.73806 .60558 m .74041 .60514 L .7399 .60313 L F
.75 .503 .559 r
.48783 .75653 m .49178 .75383 L .48999 .75402 L F
.48783 .75653 m .49036 .7564 L .49178 .75383 L F
.537 .236 .405 r
.49036 .7564 m .49369 .75366 L .49178 .75383 L F
.847 .64 .622 r
.51387 .76491 m .51545 .76728 L .51694 .76582 L F
.51387 .76491 m .51378 .76801 L .51545 .76728 L F
.82 .536 .507 r
.51334 .76978 m .51545 .76728 L .51378 .76801 L F
.51334 .76978 m .51654 .77064 L .51545 .76728 L F
.382 .238 .559 r
.33419 .60857 m .33585 .60801 L .33578 .60561 L F
.483 .357 .632 r
.3341 .61092 m .33585 .60801 L .33419 .60857 L F
.919 .703 .593 r
.65988 .52996 m .65839 .52679 L .65662 .52985 L F
.825 .692 .716 r
.65662 .52985 m .65791 .53312 L .65988 .52996 L F
.508 .841 .998 r
.29794 .82976 m .30009 .82926 L .29852 .82864 L F
.29794 .82976 m .30009 .82926 L .29852 .82864 L F
.988 .757 .496 r
.49267 .76968 m .49399 .76795 L .49051 .76773 L F
.278 0 0 r
.49051 .76773 m .49399 .76795 L .49264 .76809 L F
.988 .757 .496 r
.49313 .76908 m .49387 .7707 L .49399 .76795 L F
.968 .883 .695 r
.49264 .76809 m .49399 .76795 L .49382 .76544 L F
.289 .152 .515 r
.49399 .76795 m .49541 .76854 L .49653 .76795 L F
.49399 .76795 m .49387 .7707 L .49541 .76854 L F
.721 .468 .544 r
.49541 .76854 m .49289 .76813 L .49497 .76667 L F
.49289 .76813 m .49264 .76809 L .49285 .76796 L F
.49289 .76813 m .49285 .76796 L .49497 .76667 L F
.988 .757 .496 r
.49267 .76968 m .49343 .77032 L .49313 .76908 L F
.49343 .77032 m .49387 .7707 L .49313 .76908 L F
0 .135 .657 r
.73265 .50403 m .73455 .50655 L .7339 .50805 L F
.985 .705 .376 r
.73343 .5027 m .73455 .50655 L .73265 .50403 L F
.73343 .5027 m .7343 .50656 L .73455 .50655 L F
.7343 .50656 m .73462 .50797 L .73455 .50655 L F
0 0 .12 r
.73422 .50653 m .73421 .50656 L .73455 .50655 L F
0 0 .154 r
.73343 .50153 m .73343 .5027 L .73265 .50403 L F
.73365 .50084 m .73343 .5027 L .73343 .50153 L F
.98 .706 .316 r
.73288 .50218 m .73343 .504 L .73343 .5027 L F
.73343 .504 m .73418 .50649 L .73343 .5027 L F
0 0 .365 r
.73462 .50797 m .73422 .50653 L .73426 .50654 L F
.98 .706 .316 r
.73426 .50654 m .73462 .50797 L .7343 .50656 L F
0 0 .12 r
.7343 .50656 m .7345 .50666 L .73455 .50655 L F
.73421 .50656 m .7345 .50666 L .7343 .50656 L F
0 0 .365 r
.73462 .50797 m .73426 .50654 L .73455 .50655 L F
.98 .706 .316 r
.73423 .50652 m .73462 .50797 L .73426 .50654 L F
.73422 .50651 m .73423 .50658 L .73423 .50652 L F
.73423 .50658 m .73462 .50797 L .73423 .50652 L F
.953 .937 .607 r
.73213 .51083 m .73224 .51132 L .73422 .50653 L F
.73213 .51083 m .73422 .50653 L .73423 .50658 L F
0 0 0 r
.7362 .50614 m .73462 .50797 L .73467 .50701 L F
0 0 .365 r
.73462 .50797 m .7348 .50786 L .73465 .50752 L F
.73462 .50797 m .73465 .50752 L .73423 .50658 L F
.953 .937 .607 r
.7343 .50842 m .73428 .50769 L .7348 .50786 L F
0 0 .365 r
.73462 .50797 m .73423 .50658 L .73422 .50653 L F
0 0 .12 r
.73421 .50656 m .7339 .50805 L .7345 .50666 L F
.98 .706 .316 r
.73418 .50649 m .73462 .50797 L .73422 .50651 L F
0 0 .12 r
.73422 .50653 m .73393 .5098 L .7339 .50805 L F
.944 .935 .59 r
.73422 .50653 m .73224 .51132 L .73393 .5098 L F
.953 .937 .607 r
.73213 .51083 m .73423 .50658 L .7343 .50842 L F
.98 .706 .316 r
.73288 .50218 m .73378 .50752 L .73418 .50773 L F
.73424 .50669 m .73418 .50773 L .73462 .50797 L F
.73288 .50218 m .73418 .50773 L .73424 .50669 L F
.953 .937 .607 r
.73428 .50769 m .73424 .50669 L .73465 .50752 L F
.73424 .50669 m .73423 .50658 L .73424 .5066 L F
.73424 .50669 m .73424 .5066 L .73465 .50752 L F
0 0 0 r
.73465 .50752 m .73462 .50797 L .73418 .50773 L F
.953 .937 .607 r
.73428 .50769 m .73465 .50752 L .7348 .50786 L F
0 0 0 r
.73467 .50701 m .73465 .50752 L .73378 .50752 L F
.73465 .50752 m .73418 .50773 L .73378 .50752 L F
.98 .706 .316 r
.73418 .50649 m .7343 .50656 L .73343 .5027 L F
.2 .603 .947 r
.28402 .58457 m .28598 .58493 L .28552 .58571 L F
.205 .609 .949 r
.28598 .58493 m .28752 .58609 L .28552 .58571 L F
.603 .45 .646 r
.54088 .75434 m .54086 .75657 L .543 .75376 L F
.585 .797 .98 r
.63203 .48691 m .63339 .48826 L .63103 .48884 L F
.153 0 0 r
.63339 .48826 m .63143 .48872 L .63103 .48884 L F
.973 .687 .423 r
.678 .52614 m .67928 .52727 L .67903 .52492 L F
.794 .417 .341 r
.55507 .71942 m .55387 .72116 L .55212 .71881 L F
.886 .455 .104 r
.55387 .72116 m .55272 .71939 L .55212 .71881 L F
.615 .067 0 r
.55284 .71792 m .55212 .71881 L .55059 .71733 L F
.606 .056 0 r
.55284 .71792 m .55507 .71942 L .55212 .71881 L F
.886 .455 .104 r
.55272 .71939 m .5514 .71737 L .55212 .71881 L F
.615 .067 0 r
.55059 .71733 m .55212 .71881 L .54953 .71706 L F
.542 .247 .416 r
.55529 .71767 m .55507 .71942 L .55284 .71792 L F
.288 .683 .973 r
.689 .48969 m .69073 .48899 L .68784 .48861 L F
.689 .48969 m .69177 .48999 L .69073 .48899 L F
.309 0 .067 r
.4059 .67065 m .40484 .67221 L .40301 .67208 L F
.195 0 .003 r
.40683 .6716 m .4059 .67065 L .40796 .66993 L F
.40683 .6716 m .40484 .67221 L .4059 .67065 L F
.28 0 .089 r
.63938 .51385 m .64068 .51482 L .64184 .5135 L F
.63938 .51385 m .6387 .51548 L .64068 .51482 L F
.2 .351 .792 r
.73205 .49549 m .73156 .4972 L .73033 .49426 L F
.844 .577 .035 r
.73205 .49549 m .73293 .4989 L .73156 .4972 L F
.526 .582 .854 r
.36679 .60243 m .36487 .60289 L .36328 .59977 L F
.572 .485 .718 r
.36679 .60243 m .36522 .60577 L .36487 .60289 L F
.511 .323 .562 r
.3719 .66188 m .37404 .66134 L .37388 .65874 L F
.477 .297 .558 r
.37388 .65874 m .37595 .66018 L .3761 .65823 L F
.37388 .65874 m .37404 .66134 L .37595 .66018 L F
.384 .786 .984 r
.30236 .64997 m .30293 .64911 L .30081 .64946 L F
.30236 .64997 m .30449 .64973 L .30293 .64911 L F
.689 .411 .496 r
.49404 .78391 m .49059 .78194 L .4942 .78191 L F
.635 .33 .437 r
.4942 .78191 m .49636 .78398 L .49404 .78391 L F
.649 .305 .376 r
.5232 .77389 m .52612 .7759 L .52712 .77332 L F
.525 .453 .717 r
.52712 .77332 m .52942 .773 L .5287 .76979 L F
.613 .34 .48 r
.52612 .7759 m .52942 .773 L .52712 .77332 L F
.501 .07 .152 r
.71843 .50685 m .72244 .50492 L .71911 .50705 L F
.71843 .50685 m .721 .50671 L .72244 .50492 L F
.334 0 .045 r
.72244 .50492 m .72285 .50606 L .72324 .50442 L F
.72244 .50492 m .721 .50671 L .72285 .50606 L F
.85 .987 .855 r
.52723 .77882 m .53089 .77622 L .52952 .77879 L F
0 0 .414 r
.53089 .77622 m .53176 .7788 L .53183 .77848 L F
.698 .383 .439 r
.52952 .77879 m .53089 .77622 L .53183 .77848 L F
.288 .451 .849 r
.5457 .71212 m .54854 .71385 L .54681 .71066 L F
.269 0 .285 r
.44365 .68416 m .44126 .68673 L .44321 .68586 L F
.532 .218 .381 r
.44321 .68586 m .44562 .68572 L .44365 .68416 L F
.556 .207 .332 r
.44365 .68416 m .44562 .68572 L .44582 .68422 L F
.075 .314 .795 r
.72656 .4898 m .72689 .4914 L .72657 .49147 L F
.646 .273 .324 r
.47586 .80087 m .47648 .80105 L .47532 .801 L F
.648 .574 .758 r
.49126 .66195 m .48811 .65958 L .49026 .65854 L F
.835 .41 0 r
.6694 .53281 m .66926 .53415 L .66834 .53185 L F
.855 .617 .578 r
.47667 .67804 m .4786 .68059 L .47867 .67852 L F
.924 .678 .548 r
.47867 .67852 m .4786 .68059 L .47865 .68031 L F
.672 .514 .663 r
.47093 .67796 m .47464 .67821 L .47366 .67544 L F
.592 .446 .652 r
.47366 .67544 m .47673 .67583 L .476 .67267 L F
.615 .506 .707 r
.47464 .67821 m .47673 .67583 L .47366 .67544 L F
.008 0 0 r
.75731 .58722 m .75648 .58796 L .75392 .58846 L F
.202 0 .134 r
.75392 .58846 m .75648 .58796 L .7534 .59042 L F
.66 .897 .556 r
.75533 .58897 m .75648 .58796 L .75763 .5862 L F
0 0 0 r
.7534 .59042 m .75648 .58796 L .75488 .58952 L F
.66 .897 .556 r
.75488 .58952 m .75648 .58796 L .75533 .58897 L F
.008 0 0 r
.75744 .58717 m .75648 .58796 L .75731 .58722 L F
.717 .6 .725 r
.59688 .74547 m .5996 .74441 L .5969 .74318 L F
.383 0 .124 r
.59688 .74547 m .59919 .74532 L .5996 .74441 L F
.59688 .74547 m .59919 .74532 L .5996 .74441 L F
.806 .484 .443 r
.66039 .51204 m .66247 .51553 L .65926 .51468 L F
.67 .797 .943 r
.69177 .48999 m .69509 .49064 L .694 .48933 L F
.599 .793 .973 r
.69509 .49064 m .69619 .48899 L .694 .48933 L F
.69509 .49064 m .69798 .48982 L .69619 .48899 L F
.139 .382 .835 r
.6425 .48107 m .64162 .48206 L .64023 .48104 L F
.6425 .48107 m .6431 .48291 L .64162 .48206 L F
.579 .473 .698 r
.4971 .66422 m .49537 .66689 L .49473 .66484 L F
.4971 .66422 m .49709 .66663 L .49537 .66689 L F
.529 0 0 r
.54829 .72821 m .55169 .72912 L .54962 .72848 L F
.312 0 .238 r
.33639 .63367 m .33912 .63138 L .33834 .63294 L F
.274 0 .211 r
.33834 .63294 m .33912 .63138 L .341 .63063 L F
.423 .079 .274 r
.43002 .69228 m .4322 .69187 L .43314 .68951 L F
.456 .141 .342 r
.4322 .69187 m .43535 .68877 L .43314 .68951 L F
.734 .64 .754 r
.64996 .53593 m .64745 .53811 L .64666 .53566 L F
.623 .465 .647 r
.56259 .76232 m .56249 .76531 L .56034 .76514 L F
.016 0 0 r
.56232 .76617 m .56249 .76531 L .56109 .76727 L F
.471 0 0 r
.56232 .76617 m .56249 .76531 L .56034 .76514 L F
.623 .465 .647 r
.56034 .76514 m .56249 .76531 L .56259 .76232 L F
.471 0 0 r
.56232 .76617 m .56249 .76531 L .56034 .76514 L F
.561 .067 0 r
.66743 .49344 m .66906 .49528 L .66882 .49491 L F
.551 .043 0 r
.66906 .49528 m .67035 .4965 L .66882 .49491 L F
.656 .659 .84 r
.57918 .73228 m .58163 .73129 L .57862 .73041 L F
.282 0 0 r
.68093 .5407 m .6823 .54104 L .67985 .54064 L F
.68093 .5407 m .68333 .54074 L .6823 .54104 L F
.594 .826 .442 r
.78406 .60755 m .78194 .61045 L .78297 .60911 L F
.847 .64 .622 r
.51387 .76491 m .51694 .76582 L .51502 .76543 L F
.46 0 0 r
.51916 .76547 m .51502 .76543 L .51694 .76582 L F
.574 .523 .761 r
.50448 .7908 m .50693 .7904 L .50458 .79031 L F
.805 .657 .699 r
.71228 .50489 m .7137 .50795 L .71413 .50429 L F
.556 .497 .744 r
.5111 .76559 m .51176 .76844 L .51378 .76801 L F
.447 .138 .347 r
.51176 .76844 m .51334 .76978 L .51378 .76801 L F
.51176 .76844 m .51111 .7702 L .51334 .76978 L F
.607 .525 .736 r
.36905 .67576 m .37178 .67838 L .37125 .6753 L F
.12 .641 .884 r
.32103 .59073 m .32294 .59085 L .32449 .59135 L F
.228 .713 .93 r
.32294 .59085 m .32653 .59132 L .32449 .59135 L F
.842 .487 0 r
.65625 .50633 m .65638 .50544 L .65586 .50425 L F
.65625 .50633 m .65735 .50877 L .65638 .50544 L F
.694 .67 .822 r
.50544 .64498 m .50136 .64415 L .50356 .6419 L F
.361 .504 .866 r
.50624 .6431 m .50544 .64498 L .50356 .6419 L F
.4 .383 .725 r
.50624 .6431 m .50521 .64715 L .50544 .64498 L F
0 0 .566 r
.67236 .50378 m .67262 .50504 L .67129 .50195 L F
.7 .37 .415 r
.57859 .58647 m .57948 .58593 L .57861 .58833 L F
.62 .507 .703 r
.58182 .58346 m .58194 .58596 L .57948 .58593 L F
.668 .382 .477 r
.58194 .58596 m .57861 .58833 L .57948 .58593 L F
.463 .235 .481 r
.526 .76797 m .52836 .76543 L .52526 .7646 L F
.526 .76797 m .52804 .76789 L .52836 .76543 L F
.45 .475 .794 r
.526 .76797 m .5287 .76979 L .52804 .76789 L F
.586 .933 .756 r
.71499 .51948 m .71286 .5215 L .71644 .52016 L F
.71499 .51948 m .71298 .52113 L .71286 .5215 L F
.414 0 0 r
.42345 .64951 m .42572 .64966 L .42689 .64868 L F
.583 .079 .023 r
.42689 .64868 m .42572 .64966 L .42922 .64981 L F
.14 0 .402 r
.5744 .68898 m .57237 .69169 L .57361 .68993 L F
.335 0 .06 r
.29464 .60448 m .29083 .60698 L .29239 .60537 L F
.696 .746 .89 r
.66478 .49675 m .66232 .49796 L .66094 .49601 L F
.623 .245 .306 r
.51763 .76116 m .52011 .76136 L .52146 .75918 L F
.692 .152 0 r
.52235 .7609 m .52146 .75918 L .52011 .76136 L F
.52235 .7609 m .52497 .76223 L .52146 .75918 L F
.239 0 .04 r
.62308 .5723 m .62227 .57398 L .6204 .57382 L F
.042 0 .306 r
.62466 .56917 m .62488 .57116 L .62308 .5723 L F
0 0 0 r
.62387 .57285 m .62308 .5723 L .62488 .57116 L F
.62387 .57285 m .62227 .57398 L .62308 .5723 L F
0 0 .024 r
.59775 .71629 m .5976 .71743 L .59773 .71452 L F
.59775 .71629 m .59773 .71452 L .59687 .71425 L F
.605 .36 .519 r
.6176 .57516 m .6178 .57736 L .61505 .57756 L F
.355 .068 .331 r
.6204 .57382 m .6178 .57736 L .6176 .57516 L F
.461 0 .028 r
.43288 .66121 m .43179 .66199 L .42949 .66188 L F
.394 0 0 r
.43383 .66256 m .43288 .66121 L .43518 .66111 L F
.43383 .66256 m .43179 .66199 L .43288 .66121 L F
.622 .426 .596 r
.47202 .68067 m .47464 .67821 L .47093 .67796 L F
.448 .684 .966 r
.75399 .61237 m .75533 .61097 L .75299 .61101 L F
.75399 .61237 m .75697 .61284 L .75533 .61097 L F
.518 .723 .966 r
.64646 .52669 m .64526 .52759 L .64445 .52624 L F
.598 .333 .487 r
.53976 .78987 m .53664 .79271 L .53697 .79012 L F
.53976 .78987 m .53928 .7928 L .53664 .79271 L F
.796 .634 .681 r
.54179 .78962 m .5435 .78974 L .543 .7865 L F
.5435 .78974 m .54461 .78982 L .54427 .78913 L F
.5435 .78974 m .54427 .78913 L .543 .7865 L F
.385 .147 .425 r
.54149 .79132 m .53976 .78987 L .54217 .78946 L F
.54123 .79205 m .541 .79171 L .54149 .79132 L F
.541 .79171 m .53976 .78987 L .54149 .79132 L F
.54123 .79205 m .53928 .7928 L .53976 .78987 L F
.786 .689 .757 r
.48116 .67238 m .47892 .67523 L .48258 .67545 L F
.481 .353 .629 r
.48258 .67545 m .48467 .67265 L .48116 .67238 L F
.48258 .67545 m .48467 .67523 L .48467 .67265 L F
.475 .124 .291 r
.5257 .76159 m .52919 .75875 L .527 .75927 L F
.984 .905 .633 r
.58095 .57213 m .57992 .57474 L .58072 .57312 L F
.252 .439 .851 r
.46521 .78734 m .46691 .79028 L .46835 .78955 L F
.354 .113 .403 r
.35298 .6165 m .35546 .61387 L .35478 .61611 L F
.49 .225 .44 r
.35478 .61611 m .35243 .619 L .35298 .6165 L F
.602 .219 .289 r
.43756 .68859 m .44007 .68878 L .44126 .68673 L F
.574 .298 .46 r
.44007 .68878 m .44321 .68586 L .44126 .68673 L F
.724 .771 .89 r
.50509 .65893 m .50158 .65854 L .50395 .65797 L F
.639 .34 .449 r
.50509 .65893 m .50163 .66081 L .50158 .65854 L F
.50509 .65893 m .50577 .66115 L .50163 .66081 L F
.389 .33 .67 r
.50617 .65534 m .50509 .65893 L .50395 .65797 L F
.50617 .65534 m .50698 .65981 L .50509 .65893 L F
.648 .346 .445 r
.50731 .66089 m .50509 .65893 L .50698 .65981 L F
.50731 .66089 m .50577 .66115 L .50509 .65893 L F
.599 .534 .753 r
.53176 .7788 m .53195 .78189 L .53416 .78112 L F
.073 .47 .889 r
.46836 .6646 m .46885 .66398 L .46845 .66293 L F
.46836 .6646 m .47084 .66569 L .46885 .66398 L F
.846 .427 .24 r
.50296 .78506 m .50207 .78642 L .50142 .78484 L F
.826 .399 .226 r
.50396 .7865 m .50207 .78642 L .50296 .78506 L F
.705 .553 .679 r
.58714 .71477 m .58688 .71794 L .5849 .71755 L F
.577 .859 .996 r
.58714 .71477 m .58815 .71336 L .58892 .71369 L F
.58714 .71477 m .58597 .71403 L .58815 .71336 L F
.776 .389 .323 r
.55315 .79486 m .54808 .79013 L .54899 .79405 L F
.514 .29 .512 r
.48022 .75892 m .47783 .76214 L .47885 .75979 L F
.48022 .75892 m .48004 .76176 L .47783 .76214 L F
.48022 .75892 m .47783 .76214 L .47885 .75979 L F
.48022 .75892 m .48004 .76176 L .47783 .76214 L F
.612 .466 .659 r
.48022 .75892 m .48292 .75928 L .48243 .7563 L F
0 0 0 r
.48243 .7563 m .48135 .7584 L .48022 .75892 L F
.688 .487 .61 r
.48004 .76176 m .48292 .75928 L .48022 .75892 L F
0 0 .033 r
.48036 .76022 m .48022 .75892 L .48135 .7584 L F
.48036 .76022 m .48004 .76176 L .48022 .75892 L F
.531 .389 .632 r
.37202 .66455 m .37404 .66134 L .3719 .66188 L F
.414 .722 .988 r
.52526 .7646 m .52836 .76543 L .52722 .76431 L F
.585 .808 .984 r
.52722 .76431 m .52836 .76543 L .53058 .76477 L F
0 0 .171 r
.52836 .76543 m .52722 .76431 L .53058 .76477 L F
.52836 .76543 m .52804 .76789 L .52886 .76689 L F
.52836 .76543 m .52886 .76689 L .52722 .76431 L F
.487 .876 .967 r
.5461 .73612 m .5452 .73714 L .5478 .73713 L F
.5461 .73612 m .544 .7367 L .5452 .73714 L F
.521 .292 .508 r
.54551 .7389 m .5478 .73713 L .5452 .73714 L F
.356 0 0 r
.40059 .65254 m .40286 .65247 L .40424 .65127 L F
.384 0 .025 r
.40286 .65247 m .40599 .65151 L .40424 .65127 L F
.07 .057 .534 r
.71134 .50343 m .70999 .50677 L .71228 .50489 L F
.71134 .50343 m .71183 .50592 L .70999 .50677 L F
.513 .698 .953 r
.68788 .48359 m .68475 .48249 L .68721 .48188 L F
.558 .698 .933 r
.68936 .48164 m .68788 .48359 L .68721 .48188 L F
.68936 .48164 m .6901 .48308 L .68788 .48359 L F
.918 .906 .796 r
.64622 .5465 m .64726 .54765 L .64914 .54453 L F
.911 .908 .805 r
.64622 .5465 m .64508 .54803 L .64726 .54765 L F
.466 .29 .558 r
.55038 .70642 m .55241 .70864 L .55254 .70587 L F
.55038 .70642 m .55241 .70864 L .55254 .70587 L F
.485 .35 .622 r
.56487 .76438 m .56249 .76531 L .56259 .76232 L F
.56259 .76232 m .56249 .76531 L .56487 .76438 L F
.772 .665 .745 r
.50074 .68338 m .50242 .68644 L .50106 .68479 L F
.219 .197 .62 r
.50183 .76175 m .50157 .76251 L .50292 .76151 L F
.627 .605 .808 r
.5018 .76502 m .50292 .76151 L .50157 .76251 L F
.407 .184 .46 r
.37885 .65481 m .38116 .65565 L .37832 .65536 L F
.37885 .65481 m .38087 .65437 L .38116 .65565 L F
.652 .56 .738 r
.37997 .71424 m .38111 .71773 L .38353 .71676 L F
.677 .632 .797 r
.70452 .4919 m .70778 .49402 L .70674 .49089 L F
.761 .678 .771 r
.70674 .49089 m .70778 .49402 L .71003 .49132 L F
.498 .508 .797 r
.70798 .48468 m .70656 .48843 L .70555 .48579 L F
.165 .005 .404 r
.59475 .6979 m .59401 .70077 L .59321 .70111 L F
.59475 .6979 m .59401 .70077 L .59321 .70111 L F
.407 .822 .973 r
.59321 .70111 m .59401 .70077 L .59141 .70072 L F
.086 0 .217 r
.59258 .70313 m .59401 .70077 L .59321 .70111 L F
.736 .36 0 r
.64359 .48932 m .64193 .48603 L .64374 .48831 L F
.315 .8 .888 r
.50362 .81578 m .50634 .8155 L .50593 .81518 L F
.309 0 0 r
.50593 .81518 m .50688 .81611 L .50536 .81473 L F
.577 .512 .745 r
.50351 .81394 m .50593 .81518 L .50469 .81412 L F
.309 0 0 r
.50593 .81518 m .50536 .81473 L .50469 .81412 L F
.315 .8 .888 r
.50634 .8155 m .50722 .81541 L .50593 .81518 L F
.134 .68 .801 r
.50722 .81541 m .5083 .81517 L .50593 .81518 L F
.50722 .81541 m .50949 .81524 L .5083 .81517 L F
.699 .634 .78 r
.48999 .64472 m .48812 .64765 L .48819 .6463 L F
.506 .384 .648 r
.49015 .647 m .48812 .64765 L .48999 .64472 L F
.355 .068 .331 r
.6204 .57382 m .61985 .57667 L .6178 .57736 L F
.236 0 .291 r
.6216 .5758 m .6204 .57382 L .62227 .57398 L F
.6216 .5758 m .61985 .57667 L .6204 .57382 L F
.587 .58 .813 r
.49473 .66484 m .49126 .66195 L .49363 .66145 L F
.647 .585 .772 r
.4971 .66422 m .49473 .66484 L .49363 .66145 L F
0 0 .425 r
.67821 .51752 m .67789 .51931 L .67734 .51578 L F
0 0 .405 r
.67894 .5203 m .67789 .51931 L .67821 .51752 L F
.67894 .5203 m .67844 .52148 L .67789 .51931 L F
.918 .906 .796 r
.64622 .5465 m .64914 .54453 L .64827 .54384 L F
.924 .946 .791 r
.65034 .54062 m .64914 .54453 L .6514 .54168 L F
.65034 .54062 m .64827 .54384 L .64914 .54453 L F
.849 .779 .783 r
.7082 .49896 m .7046 .50036 L .7067 .49989 L F
.449 .839 .625 r
.70714 .49959 m .7082 .49896 L .7067 .49989 L F
.988 .718 .379 r
.70844 .49667 m .70891 .49853 L .7082 .49896 L F
.23 0 .278 r
.71052 .49604 m .7082 .49896 L .71016 .49756 L F
.449 .839 .625 r
.71016 .49756 m .7082 .49896 L .70714 .49959 L F
.988 .718 .379 r
.70891 .49853 m .70922 .49978 L .7082 .49896 L F
.233 0 0 r
.64164 .49718 m .64096 .49514 L .64261 .49453 L F
.64164 .49718 m .6428 .49666 L .64096 .49514 L F
.64164 .49718 m .64306 .49782 L .6428 .49666 L F
.64164 .49718 m .64077 .49855 L .64306 .49782 L F
.667 .829 .961 r
.45573 .646 m .45194 .64575 L .45438 .64522 L F
.525 .858 .995 r
.45438 .64522 m .45792 .6452 L .45573 .646 L F
.347 .816 .909 r
.58585 .69543 m .58433 .69516 L .58543 .69509 L F
.281 .776 .89 r
.58609 .69519 m .58585 .69543 L .588 .69477 L F
.58609 .69519 m .58433 .69516 L .58585 .69543 L F
.584 .705 .926 r
.67065 .53852 m .6745 .53992 L .67296 .53795 L F
.68 .743 .899 r
.67296 .53795 m .6745 .53992 L .67639 .53866 L F
.542 .374 .602 r
.65064 .52264 m .64752 .52475 L .6467 .52295 L F
.639 .584 .776 r
.64859 .51918 m .6467 .52295 L .64619 .52156 L F
.64859 .51918 m .65064 .52264 L .6467 .52295 L F
.728 .426 .468 r
.64752 .52475 m .64619 .52156 L .6467 .52295 L F
.64752 .52475 m .64376 .52516 L .64619 .52156 L F
.64752 .52475 m .64646 .52669 L .64376 .52516 L F
.542 .374 .602 r
.65064 .52264 m .65003 .52426 L .64752 .52475 L F
.713 .616 .748 r
.65222 .53401 m .64996 .53593 L .64884 .53273 L F
.585 .375 .562 r
.53297 .72786 m .53438 .73078 L .53341 .72745 L F
.513 .254 .46 r
.53341 .72745 m .53662 .72816 L .53687 .72567 L F
.604 .459 .658 r
.53438 .73078 m .53662 .72816 L .53341 .72745 L F
.636 .541 .729 r
.49363 .66145 m .49126 .66195 L .49026 .65854 L F
.411 .8 .989 r
.32697 .60279 m .32737 .6019 L .32568 .60186 L F
.32697 .60279 m .32897 .6025 L .32737 .6019 L F
.978 .698 .423 r
.4742 .76674 m .47552 .76756 L .47543 .76517 L F
.731 .946 .634 r
.47626 .7635 m .47543 .76517 L .47783 .76214 L F
.693 .873 .479 r
.47626 .7635 m .4742 .76674 L .47543 .76517 L F
.644 .418 .56 r
.47543 .76517 m .47552 .76756 L .47828 .76733 L F
.85 .841 .835 r
.6609 .51678 m .65926 .51468 L .65954 .51528 L F
.902 .766 .702 r
.65672 .52027 m .6609 .51678 L .65965 .5154 L F
.65672 .52027 m .65821 .52147 L .6609 .51678 L F
.799 .446 .39 r
.65972 .51537 m .66247 .51553 L .66082 .51702 L F
.65926 .51468 m .66047 .515 L .65972 .51537 L F
.66047 .515 m .66247 .51553 L .65972 .51537 L F
.902 .766 .702 r
.65672 .52027 m .65965 .5154 L .6594 .51552 L F
.693 .424 .512 r
.65551 .51459 m .6595 .5153 L .65948 .51527 L F
.738 .614 .72 r
.65551 .51459 m .65926 .51468 L .65771 .51181 L F
.693 .424 .512 r
.65551 .51459 m .65948 .51527 L .65926 .51468 L F
.849 .388 .067 r
.65926 .51468 m .65972 .51537 L .65949 .51531 L F
.693 .424 .512 r
.65948 .51527 m .65954 .51528 L .65926 .51468 L F
.849 .388 .067 r
.65926 .51468 m .65949 .51531 L .65924 .51524 L F
.812 .725 .769 r
.65565 .51699 m .65672 .52027 L .65924 .5158 L F
.65924 .51541 m .65924 .5158 L .65954 .51528 L F
.65565 .51699 m .65924 .5158 L .65924 .51541 L F
0 .14 .683 r
.65771 .51181 m .65926 .51468 L .65925 .51347 L F
.849 .388 .067 r
.65925 .51403 m .65922 .51596 L .65925 .51347 L F
.65926 .51453 m .65925 .51492 L .65925 .51403 L F
.65925 .51492 m .65922 .51596 L .65925 .51403 L F
.65926 .51468 m .65925 .51492 L .65926 .51453 L F
.65925 .51492 m .65922 .51596 L .65926 .51453 L F
.693 .424 .512 r
.65551 .51459 m .65565 .51699 L .65924 .51541 L F
.65925 .51525 m .65924 .51541 L .6595 .5153 L F
.65551 .51459 m .65924 .51541 L .65925 .51525 L F
.65948 .51527 m .6595 .5153 L .65954 .51528 L F
.849 .388 .067 r
.65924 .51524 m .66006 .51616 L .65922 .51596 L F
.66006 .51616 m .66082 .51702 L .66046 .51678 L F
.66006 .51616 m .66046 .51678 L .65922 .51596 L F
.902 .766 .702 r
.6594 .51552 m .65965 .5154 L .65959 .51533 L F
.6594 .51552 m .65959 .51533 L .65952 .51532 L F
.849 .388 .067 r
.65972 .51537 m .66082 .51702 L .65924 .51524 L F
.902 .766 .702 r
.65952 .51532 m .65959 .51533 L .65954 .51528 L F
.715 .196 0 r
.4741 .80028 m .47532 .801 L .47704 .80317 L F
.649 .296 .36 r
.47532 .801 m .47648 .80105 L .47704 .80317 L F
.235 0 0 r
.25315 .59109 m .25523 .59066 L .25688 .58913 L F
.35 0 .051 r
.25523 .59066 m .25891 .58859 L .25688 .58913 L F
.72 .698 .829 r
.49806 .64181 m .49576 .64202 L .49791 .63951 L F
.77 .594 .661 r
.49806 .64181 m .4958 .64466 L .49576 .64202 L F
.49806 .64181 m .49922 .64512 L .4958 .64466 L F
.64 .574 .765 r
.50016 .6391 m .49806 .64181 L .49791 .63951 L F
.50016 .6391 m .50126 .64237 L .49806 .64181 L F
.698 .557 .692 r
.50136 .64415 m .49806 .64181 L .50126 .64237 L F
.50136 .64415 m .49922 .64512 L .49806 .64181 L F
.786 .537 .561 r
.53175 .77271 m .53497 .77072 L .53443 .77073 L F
.553 .493 .742 r
.50152 .81504 m .50362 .81578 L .50351 .81394 L F
.9 .66 .566 r
.54461 .78982 m .54522 .78792 L .543 .7865 L F
.591 .57 .799 r
.54658 .74259 m .5475 .73882 L .54551 .7389 L F
.54658 .74259 m .54879 .7423 L .5475 .73882 L F
.505 .327 .573 r
.54683 .74535 m .54879 .7423 L .54658 .74259 L F
.585 .809 .985 r
.46147 .64566 m .45792 .6452 L .46005 .64463 L F
.607 .82 .982 r
.46365 .64498 m .46147 .64566 L .46005 .64463 L F
.673 .477 .612 r
.58971 .58342 m .58766 .58612 L .58772 .58347 L F
.58971 .58342 m .59036 .5855 L .58766 .58612 L F
.643 .385 .513 r
.58971 .58342 m .59287 .58527 L .59036 .5855 L F
.58971 .58342 m .59323 .58318 L .59287 .58527 L F
0 .253 .656 r
.64123 .48581 m .63842 .48421 L .63894 .48569 L F
.738 .43 .46 r
.46649 .6809 m .46866 .68352 L .46911 .68165 L F
.582 .309 .468 r
.46866 .68352 m .47202 .68067 L .46911 .68165 L F
.409 .787 .992 r
.41039 .69663 m .41387 .69708 L .41164 .69708 L F
.911 .891 .797 r
.59349 .5374 m .59452 .53843 L .59265 .5413 L F
.822 .665 .688 r
.58027 .56624 m .57756 .56359 L .58071 .56406 L F
.58027 .56624 m .57698 .56586 L .57756 .56359 L F
.821 .673 .699 r
.58027 .56624 m .57842 .56917 L .57698 .56586 L F
.697 .429 .515 r
.49192 .68842 m .49057 .6917 L .48862 .68926 L F
.609 .334 .475 r
.49373 .69145 m .49192 .68842 L .49398 .68922 L F
.49373 .69145 m .49057 .6917 L .49192 .68842 L F
.052 0 0 r
.6269 .51069 m .626 .51229 L .62432 .51241 L F
.708 .415 .479 r
.4549 .68091 m .45405 .68126 L .45739 .68132 L F
.666 .159 0 r
.50469 .81412 m .50369 .81252 L .50351 .81394 L F
.50469 .81412 m .50593 .81518 L .50369 .81252 L F
.541 .623 .883 r
.50458 .79031 m .50693 .7904 L .50584 .78774 L F
.14 0 .402 r
.5744 .68898 m .57427 .69133 L .57237 .69169 L F
.532 .106 .176 r
.57427 .69133 m .5716 .69225 L .57237 .69169 L F
.867 .657 .615 r
.47963 .80218 m .47704 .80317 L .47648 .80105 L F
.369 .621 .949 r
.36186 .59879 m .36116 .60018 L .36016 .59879 L F
.514 .793 .996 r
.36328 .59977 m .36116 .60018 L .36186 .59879 L F
.675 .965 .932 r
.64704 .51414 m .64708 .5147 L .6493 .51307 L F
.493 .903 .815 r
.64708 .5147 m .64746 .51455 L .64738 .51448 L F
.505 .005 0 r
.64704 .51414 m .6497 .51681 L .64708 .5147 L F
.474 .441 .74 r
.6497 .51681 m .64806 .51732 L .64708 .5147 L F
.699 .658 .807 r
.64859 .51918 m .64522 .51816 L .64806 .51732 L F
.659 .544 .713 r
.64806 .51732 m .64522 .51816 L .64708 .5147 L F
.619 .225 .275 r
.64768 .51772 m .64921 .51632 L .64728 .51554 L F
.678 .632 .796 r
.64768 .51772 m .64888 .516 L .64921 .51632 L F
.64888 .516 m .64967 .51486 L .64921 .51632 L F
.505 .005 0 r
.64953 .51663 m .64921 .51632 L .6497 .51681 L F
.64713 .51423 m .64921 .51632 L .64953 .51663 L F
.64704 .51414 m .64712 .51421 L .64713 .51423 L F
.64712 .51421 m .64921 .51632 L .64713 .51423 L F
.493 .903 .815 r
.64738 .51448 m .65082 .51322 L .6493 .51307 L F
.64746 .51455 m .65082 .51322 L .64738 .51448 L F
.405 .857 .88 r
.6523 .51216 m .65082 .51322 L .65313 .51294 L F
.6523 .51216 m .6493 .51307 L .65082 .51322 L F
.374 .013 .217 r
.62998 .49197 m .62796 .49133 L .63143 .48872 L F
.153 0 0 r
.63339 .48826 m .63272 .48905 L .63143 .48872 L F
.722 .563 .674 r
.63272 .48905 m .62998 .49197 L .63143 .48872 L F
.359 0 .041 r
.62361 .52259 m .62313 .52341 L .62092 .52364 L F
.272 0 0 r
.62605 .52269 m .62313 .52341 L .62361 .52259 L F
.199 0 0 r
.4139 .7087 m .41265 .70994 L .41039 .71043 L F
.368 0 .037 r
.416 .70824 m .41265 .70994 L .4139 .7087 L F
.54 .205 .348 r
.65222 .53401 m .65484 .53502 L .65557 .53273 L F
.629 .596 .797 r
.65557 .53273 m .65791 .53312 L .65662 .52985 L F
.888 .807 .764 r
.65484 .53502 m .65791 .53312 L .65557 .53273 L F
.011 0 0 r
.44165 .65984 m .44129 .65942 L .44317 .6583 L F
.44165 .65984 m .43944 .66037 L .44129 .65942 L F
.549 .864 .573 r
.75787 .58658 m .75744 .58717 L .75971 .5861 L F
.75787 .58658 m .75648 .58796 L .75744 .58717 L F
.724 .429 .478 r
.45405 .68126 m .45718 .68339 L .45739 .68132 L F
.564 .264 .418 r
.45718 .68339 m .46048 .68068 L .45739 .68132 L F
.92 .927 .799 r
.55621 .71501 m .55667 .7179 L .55783 .71529 L F
.442 .464 .786 r
.55865 .71295 m .55667 .7179 L .55621 .71501 L F
.256 .763 .745 r
.55667 .7179 m .55955 .71698 L .561 .7166 L F
.815 .67 .702 r
.59807 .73723 m .59989 .73424 L .59666 .73393 L F
.633 .553 .747 r
.49233 .65608 m .49026 .65854 L .49025 .65713 L F
.622 .537 .738 r
.49233 .65608 m .49264 .65826 L .49026 .65854 L F
.636 .541 .729 r
.49363 .66145 m .49026 .65854 L .49264 .65826 L F
.64 .491 .665 r
.56513 .69504 m .56555 .69798 L .56287 .69808 L F
.764 .588 .659 r
.56555 .69798 m .563 .70008 L .56287 .69808 L F
.663 .463 .604 r
.48106 .67834 m .48446 .67641 L .48311 .67818 L F
.885 .984 .816 r
.58472 .5511 m .58719 .54986 L .58437 .55308 L F
.95 .914 .744 r
.58838 .54709 m .58719 .54986 L .58644 .5481 L F
.941 .915 .762 r
.58644 .5481 m .58719 .54986 L .58472 .5511 L F
.487 .228 .446 r
.4562 .69191 m .45374 .69376 L .45406 .69251 L F
.741 .553 .64 r
.5387 .77582 m .54299 .77637 L .54266 .77303 L F
.389 .294 .626 r
.54266 .77303 m .54465 .77493 L .54442 .77297 L F
.54266 .77303 m .54299 .77637 L .54465 .77493 L F
.533 .216 .376 r
.44601 .69498 m .44492 .69766 L .44257 .69778 L F
.554 .237 .385 r
.44742 .69661 m .44601 .69498 L .44823 .69481 L F
.44742 .69661 m .44492 .69766 L .44601 .69498 L F
.714 .313 .287 r
.63355 .50635 m .63268 .50815 L .63256 .50804 L F
.372 0 .104 r
.63453 .50467 m .63355 .50635 L .63121 .5067 L F
.437 .81 .993 r
.63355 .50635 m .63026 .50606 L .63121 .5067 L F
0 0 0 r
.62995 .50697 m .62777 .51144 L .6286 .50949 L F
.63053 .50589 m .62984 .50728 L .62995 .50697 L F
.62984 .50728 m .62777 .51144 L .62995 .50697 L F
.714 .313 .287 r
.63355 .50635 m .63256 .50804 L .63028 .50608 L F
.63028 .50606 m .63028 .50608 L .63026 .50606 L F
.63355 .50635 m .63028 .50608 L .63028 .50606 L F
.372 0 .104 r
.63455 .50466 m .63355 .50635 L .63453 .50467 L F
.316 0 0 r
.6369 .50456 m .63355 .50635 L .63455 .50466 L F
.908 .715 .629 r
.64392 .49406 m .64084 .49272 L .64235 .49254 L F
.857 .745 .738 r
.64261 .49453 m .64084 .49272 L .64392 .49406 L F
.746 .66 .765 r
.46521 .67831 m .46296 .68097 L .46649 .6809 L F
.668 .294 .328 r
.46296 .68097 m .46514 .68286 L .46649 .6809 L F
.772 .424 .396 r
.46514 .68286 m .46866 .68352 L .46649 .6809 L F
.545 .248 .414 r
.40484 .67221 m .40183 .67445 L .40301 .67208 L F
.496 .111 .24 r
.55202 .77962 m .55365 .78088 L .55122 .78105 L F
.335 .508 .88 r
.64596 .48386 m .64494 .48546 L .6431 .48291 L F
.236 .373 .799 r
.64596 .48386 m .64729 .48721 L .64494 .48546 L F
.444 .526 .847 r
.57927 .71821 m .58209 .71982 L .58133 .71747 L F
.544 .667 .917 r
.69534 .48159 m .69417 .48469 L .69213 .48244 L F
.69534 .48159 m .69642 .48438 L .69417 .48469 L F
.396 .673 .971 r
.34588 .59203 m .34543 .59339 L .34364 .59233 L F
.34588 .59203 m .34738 .5934 L .34543 .59339 L F
.595 .793 .975 r
.509 .65267 m .50958 .65327 L .50603 .65294 L F
.675 .49 .627 r
.50807 .65355 m .50603 .65294 L .50958 .65327 L F
.554 .776 .981 r
.51147 .65192 m .50958 .65327 L .509 .65267 L F
.51147 .65192 m .51181 .65281 L .50958 .65327 L F
.655 .44 .58 r
.51181 .65281 m .50807 .65355 L .50958 .65327 L F
.25 .734 .929 r
.28031 .58422 m .28402 .58457 L .28211 .58455 L F
.535 .784 .989 r
.50967 .78107 m .50799 .78145 L .50561 .78176 L F
.087 .346 .818 r
.50872 .78431 m .50561 .78176 L .50799 .78145 L F
.788 .977 .695 r
.39323 .71661 m .39286 .71796 L .39478 .71687 L F
.39323 .71661 m .3911 .71925 L .39286 .71796 L F
.535 .324 .541 r
.52965 .73153 m .53193 .73111 L .53297 .72786 L F
.585 .375 .562 r
.53297 .72786 m .53193 .73111 L .53438 .73078 L F
.543 .36 .583 r
.51212 .76422 m .5111 .76559 L .51387 .76491 L F
.51212 .76422 m .50987 .76475 L .5111 .76559 L F
.556 .497 .744 r
.5111 .76559 m .51378 .76801 L .51387 .76491 L F
.508 .348 .599 r
.32522 .62257 m .32726 .62218 L .32721 .61941 L F
.439 .2 .453 r
.32522 .62257 m .32689 .62428 L .32726 .62218 L F
.32522 .62257 m .32486 .62488 L .32689 .62428 L F
.39 .802 .979 r
.28752 .58609 m .28955 .58579 L .29112 .58632 L F
.307 .761 .955 r
.29173 .58566 m .29112 .58632 L .28955 .58579 L F
.29173 .58566 m .29314 .58614 L .29112 .58632 L F
.379 .045 .267 r
.24321 .59699 m .24524 .5965 L .2463 .59422 L F
.357 .023 .255 r
.2463 .59422 m .24731 .59586 L .24831 .59377 L F
.2463 .59422 m .24524 .5965 L .24731 .59586 L F
.747 .961 .938 r
.56513 .69504 m .56604 .69309 L .56712 .69224 L F
.622 .457 .638 r
.56712 .69224 m .56757 .69484 L .56513 .69504 L F
.012 0 .304 r
.56712 .69224 m .56907 .68911 L .56824 .68971 L F
0 0 0 r
.56712 .69224 m .56604 .69309 L .56876 .69142 L F
.586 .184 .246 r
.44562 .68572 m .44932 .68402 L .44582 .68422 L F
.44562 .68572 m .44803 .68593 L .44932 .68402 L F
.5 .114 .239 r
.44803 .68593 m .4516 .68375 L .44932 .68402 L F
.703 .525 .645 r
.58772 .58347 m .58591 .5856 L .5841 .58309 L F
.58772 .58347 m .58766 .58612 L .58591 .5856 L F
0 0 .466 r
.58975 .72579 m .59071 .72689 L .58801 .72644 L F
.619 .783 .96 r
.59071 .72689 m .5914 .72448 L .58994 .72593 L F
0 0 .466 r
.58975 .72579 m .59124 .72756 L .59071 .72689 L F
.619 .783 .96 r
.59071 .72689 m .58994 .72593 L .58949 .72638 L F
0 0 .466 r
.59124 .72756 m .59178 .7282 L .59071 .72689 L F
.92 .968 .781 r
.58775 .54652 m .59043 .54416 L .58838 .54709 L F
.58775 .54652 m .58978 .54343 L .59043 .54416 L F
.919 .927 .8 r
.58978 .54343 m .59265 .5413 L .59043 .54416 L F
.479 .25 .488 r
.5473 .77076 m .54894 .77262 L .54896 .77013 L F
.5473 .77076 m .54678 .77309 L .54894 .77262 L F
.695 .8 .93 r
.77245 .61697 m .77385 .61463 L .77149 .61536 L F
.77245 .61697 m .77474 .61587 L .77385 .61463 L F
.564 .264 .418 r
.45718 .68339 m .45945 .68338 L .46048 .68068 L F
.649 .352 .454 r
.46048 .68068 m .46276 .68264 L .46296 .68097 L F
.46048 .68068 m .45945 .68338 L .46276 .68264 L F
.374 .064 .306 r
.50768 .73744 m .50692 .73886 L .50973 .73689 L F
.987 .827 .6 r
.61446 .49657 m .61307 .49794 L .61407 .49573 L F
.61446 .49657 m .61413 .4994 L .61307 .49794 L F
.367 .11 .387 r
.33639 .63367 m .33582 .63583 L .33398 .63639 L F
.354 .089 .366 r
.33834 .63294 m .33582 .63583 L .33639 .63367 L F
.458 0 .062 r
.53173 .75797 m .53378 .75822 L .53503 .75669 L F
.521 0 0 r
.53604 .75786 m .53503 .75669 L .53378 .75822 L F
.53604 .75786 m .53745 .7579 L .53503 .75669 L F
.471 .733 .984 r
.76012 .60545 m .75834 .60688 L .75743 .60553 L F
.639 .727 .911 r
.49446 .64085 m .49576 .64202 L .49229 .6415 L F
.682 .484 .611 r
.49576 .64202 m .49225 .64423 L .49229 .6415 L F
.49576 .64202 m .4958 .64466 L .49225 .64423 L F
.748 .745 .849 r
.49791 .63951 m .49576 .64202 L .49446 .64085 L F
.506 0 0 r
.51261 .81112 m .51174 .80967 L .51052 .80903 L F
.51261 .81112 m .51418 .81031 L .51174 .80967 L F
.493 .353 .619 r
.37064 .6699 m .37262 .66945 L .37245 .66688 L F
.445 .315 .609 r
.37064 .6699 m .3727 .67179 L .37262 .66945 L F
.37064 .6699 m .37059 .67361 L .3727 .67179 L F
.671 .329 .385 r
.49703 .74257 m .49925 .74472 L .4997 .74327 L F
.49703 .74257 m .49595 .74495 L .49925 .74472 L F
.679 .152 0 r
.56104 .73843 m .56018 .73692 L .55902 .73617 L F
.56104 .73843 m .56224 .73916 L .56018 .73692 L F
.764 .257 0 r
.56018 .73692 m .56224 .73916 L .56387 .73961 L F
.346 .297 .66 r
.46534 .77312 m .46659 .76941 L .46525 .77065 L F
.027 0 0 r
.724 .51757 m .72167 .5187 L .72458 .51682 L F
.23 0 .112 r
.72653 .5157 m .724 .51757 L .72458 .51682 L F
.762 .339 .246 r
.56192 .72043 m .56083 .72196 L .55869 .71977 L F
.823 .421 .288 r
.56192 .72043 m .56364 .723 L .56083 .72196 L F
.832 .417 .255 r
.56536 .7232 m .56364 .723 L .56192 .72043 L F
.911 .673 .171 r
.57172 .75344 m .5719 .75589 L .57233 .75661 L F
.878 .607 .084 r
.57233 .75661 m .5719 .75589 L .57267 .75905 L F
.332 .116 .428 r
.52081 .68395 m .51925 .68594 L .51919 .684 L F
.606 .13 .098 r
.47689 .68937 m .47545 .69067 L .47338 .68923 L F
.609 .129 .09 r
.47901 .691 m .47545 .69067 L .47689 .68937 L F
.593 .17 .21 r
.47927 .68967 m .47901 .691 L .47689 .68937 L F
.587 .779 .971 r
.76594 .61568 m .76792 .61429 L .76487 .61517 L F
.76594 .61568 m .7692 .61579 L .76792 .61429 L F
.808 .564 .571 r
.4914 .78987 m .49578 .79023 L .49426 .78807 L F
.509 .488 .769 r
.49426 .78807 m .4977 .78972 L .49578 .79023 L F
.49426 .78807 m .4977 .78972 L .49578 .79023 L F
0 .575 .746 r
.30802 .65028 m .3085 .65023 L .30645 .64991 L F
.30802 .65028 m .31024 .65038 L .3085 .65023 L F
.784 .669 .736 r
.78314 .58881 m .78424 .58682 L .78117 .58586 L F
.607 .389 .559 r
.47267 .64675 m .47156 .64361 L .47341 .64641 L F
.662 .672 .849 r
.47511 .64471 m .47341 .64641 L .47156 .64361 L F
.673 .641 .81 r
.47511 .64471 m .47267 .64675 L .47341 .64641 L F
.895 .938 .833 r
.77925 .59872 m .77996 .5998 L .78199 .5971 L F
.732 .365 .356 r
.61262 .55299 m .61602 .55489 L .61566 .55239 L F
.517 .402 .661 r
.61602 .55489 m .61709 .55097 L .61566 .55239 L F
.161 0 0 r
.4136 .66731 m .41194 .66843 L .40976 .66882 L F
.026 0 0 r
.4145 .66763 m .4136 .66731 L .41587 .66737 L F
.4145 .66763 m .41194 .66843 L .4136 .66731 L F
.81 .811 .852 r
.77061 .60666 m .76778 .60902 L .76688 .60749 L F
.322 .314 .695 r
.75352 .59888 m .75239 .60219 L .75132 .60063 L F
.75352 .59888 m .75383 .60244 L .75239 .60219 L F
.517 .41 .671 r
.77658 .59721 m .77818 .59356 L .7761 .59461 L F
.86 .89 .856 r
.65034 .54062 m .6514 .54168 L .65359 .53891 L F
.04 .085 .581 r
.38041 .70067 m .38057 .70367 L .38163 .70242 L F
.23 .375 .803 r
.38057 .70367 m .38307 .7057 L .38163 .70242 L F
.534 .401 .647 r
.38096 .70614 m .38307 .7057 L .38057 .70367 L F
.362 .748 .988 r
.31578 .58898 m .31499 .58993 L .31371 .58915 L F
.31578 .58898 m .31734 .5898 L .31499 .58993 L F
.356 .133 .432 r
.55391 .79027 m .55315 .79486 L .55381 .79253 L F
.241 .036 .389 r
.55315 .79486 m .55391 .79027 L .55381 .79253 L F
.594 .15 .167 r
.71137 .49042 m .70888 .48998 L .71145 .48507 L F
.517 .719 .964 r
.70896 .48978 m .71003 .49132 L .71139 .48971 L F
.819 .679 .709 r
.71145 .48507 m .71456 .48547 L .71137 .49042 L F
.567 .797 .986 r
.71003 .49132 m .71217 .49061 L .71139 .48971 L F
.651 .632 .818 r
.59511 .73829 m .59737 .73925 L .59621 .73638 L F
.727 .671 .795 r
.59621 .73638 m .59737 .73925 L .59807 .73723 L F
.899 .982 .797 r
.58775 .54652 m .58838 .54709 L .58644 .5481 L F
0 0 0 r
.6897 .53959 m .68754 .54122 L .69166 .53916 L F
.556 .931 .821 r
.69341 .53785 m .6897 .53959 L .69166 .53916 L F
.747 .961 .938 r
.56513 .69504 m .56403 .69453 L .56604 .69309 L F
.519 .349 .59 r
.56757 .69484 m .56555 .69798 L .56513 .69504 L F
.42 .704 .981 r
.28783 .63337 m .28694 .63451 L .28582 .63294 L F
.28783 .63337 m .28989 .63493 L .28694 .63451 L F
.824 .577 .565 r
.49316 .81179 m .49517 .80947 L .49333 .80928 L F
.49316 .81179 m .49634 .81388 L .49517 .80947 L F
.861 .671 .645 r
.48672 .75537 m .48783 .75653 L .48999 .75402 L F
.919 .927 .8 r
.58978 .54343 m .59172 .54046 L .59265 .5413 L F
.911 .891 .797 r
.59349 .5374 m .59265 .5413 L .59172 .54046 L F
.06 .582 .873 r
.67227 .47927 m .67447 .47966 L .67546 .48018 L F
.384 .705 .985 r
.67676 .47914 m .67546 .48018 L .67447 .47966 L F
.67676 .47914 m .67772 .48018 L .67546 .48018 L F
.335 .756 .976 r
.47156 .64361 m .46971 .64383 L .46792 .64305 L F
.838 .43 .27 r
.56536 .7232 m .56434 .72469 L .56364 .723 L F
.801 .38 .246 r
.56536 .7232 m .56741 .72591 L .56434 .72469 L F
0 0 .505 r
.37904 .71201 m .37997 .71424 L .37859 .71086 L F
.664 .662 .838 r
.37859 .71086 m .37997 .71424 L .38195 .71184 L F
.599 .563 .786 r
.37997 .71424 m .38229 .7141 L .38195 .71184 L F
.652 .56 .738 r
.37997 .71424 m .38353 .71676 L .38229 .7141 L F
.684 .644 .804 r
.70042 .48679 m .69725 .48624 L .69967 .48564 L F
.651 .767 .934 r
.70203 .48503 m .70042 .48679 L .69967 .48564 L F
.70203 .48503 m .70317 .48651 L .70042 .48679 L F
.922 .668 .536 r
.48834 .67779 m .49032 .68067 L .48889 .67895 L F
.48834 .67779 m .48805 .68034 L .49032 .68067 L F
.92 .654 .518 r
.48805 .68034 m .48979 .6833 L .49032 .68067 L F
.833 .556 .518 r
.49032 .68067 m .48979 .6833 L .49295 .68366 L F
.356 0 0 r
.42408 .69447 m .42635 .69428 L .42778 .69281 L F
.343 0 .027 r
.42635 .69428 m .43002 .69228 L .42778 .69281 L F
.918 .656 .526 r
.48671 .80597 m .48822 .80414 L .48631 .80432 L F
.48671 .80597 m .48866 .8069 L .48822 .80414 L F
.822 .47 0 r
.65209 .49763 m .65217 .4969 L .65163 .49563 L F
.65209 .49763 m .65288 .49908 L .65217 .4969 L F
.517 0 0 r
.43531 .64835 m .43689 .64908 L .43861 .64817 L F
.669 .96 .744 r
.43861 .64817 m .43897 .64732 L .44071 .64737 L F
.43861 .64817 m .43689 .64908 L .43897 .64732 L F
.791 .756 .821 r
.71379 .48288 m .71456 .48547 L .71145 .48507 L F
.605 .594 .813 r
.7158 .48162 m .71456 .48547 L .71379 .48288 L F
.7158 .48162 m .71699 .48483 L .71456 .48547 L F
.967 .728 .524 r
.5849 .71755 m .58494 .72017 L .58513 .71997 L F
.697 .344 .373 r
.58688 .71794 m .58736 .71973 L .5849 .71755 L F
.55 .385 .61 r
.5849 .71755 m .58736 .71973 L .58494 .72017 L F
.396 .144 .41 r
.35546 .61387 m .35779 .61129 L .35746 .61338 L F
.54 .268 .451 r
.35779 .61129 m .35954 .61284 L .35746 .61338 L F
.35779 .61129 m .36003 .61094 L .35954 .61284 L F
.958 .732 .555 r
.51387 .76491 m .51212 .76422 L .51251 .7619 L F
.733 .518 .601 r
.51529 .76652 m .51387 .76491 L .51502 .76543 L F
.51529 .76652 m .51212 .76422 L .51387 .76491 L F
.788 .656 .717 r
.57934 .56074 m .58071 .56406 L .57756 .56359 L F
.907 .972 .801 r
.62144 .51555 m .61938 .5183 L .62028 .51871 L F
.825 .876 .882 r
.67718 .48892 m .68024 .48831 L .67699 .4889 L F
.67718 .48892 m .67785 .48936 L .68024 .48831 L F
.572 .865 .996 r
.68168 .48682 m .68024 .48831 L .68253 .48759 L F
.609 .933 .96 r
.68168 .48682 m .67699 .4889 L .68024 .48831 L F
.714 .62 .751 r
.56296 .77888 m .5664 .77935 L .56591 .77608 L F
.866 .88 .845 r
.5664 .77935 m .56753 .77572 L .56591 .77608 L F
.5664 .77935 m .56893 .77651 L .56753 .77572 L F
.654 .508 .673 r
.47456 .77338 m .47527 .77657 L .47232 .77621 L F
.643 .33 .426 r
.47527 .77657 m .47448 .77828 L .47232 .77621 L F
.555 .862 .558 r
.47476 .78739 m .47657 .78558 L .47567 .78634 L F
.14 .125 .579 r
.4761 .78861 m .47476 .78739 L .47567 .78634 L F
.4761 .78861 m .47553 .78977 L .47476 .78739 L F
.643 .092 0 r
.54907 .71021 m .54818 .70885 L .54681 .71066 L F
.54907 .71021 m .55048 .71095 L .54818 .70885 L F
.572 .485 .718 r
.36679 .60243 m .36777 .60558 L .36522 .60577 L F
.505 .303 .54 r
.36777 .60558 m .36505 .60708 L .36522 .60577 L F
.22 0 .313 r
.62562 .5458 m .62763 .54578 L .62772 .54319 L F
.631 .413 .567 r
.5267 .73412 m .52905 .7345 L .52965 .73153 L F
.564 .361 .564 r
.52905 .7345 m .53193 .73111 L .52965 .73153 L F
.399 .707 .985 r
.467 .65919 m .46754 .659 L .4637 .65826 L F
.972 .881 .502 r
.46864 .66084 m .46891 .65806 L .467 .65919 L F
.193 .01 .389 r
.46891 .65806 m .46754 .659 L .467 .65919 L F
.769 .655 .736 r
.49753 .64778 m .49362 .64755 L .4958 .64466 L F
.716 .52 .623 r
.49753 .64778 m .49328 .64963 L .49362 .64755 L F
.49753 .64778 m .49705 .65021 L .49328 .64963 L F
.76 .652 .742 r
.49922 .64512 m .49753 .64778 L .4958 .64466 L F
.563 .716 .944 r
.7692 .61579 m .77039 .61338 L .76792 .61429 L F
.7692 .61579 m .77149 .61536 L .77039 .61338 L F
.451 .211 .458 r
.33582 .63583 m .33351 .63835 L .33398 .63639 L F
.673 .641 .81 r
.47511 .64471 m .47629 .64769 L .47267 .64675 L F
.744 .677 .787 r
.4784 .64507 m .47629 .64769 L .47511 .64471 L F
.724 .646 .771 r
.47845 .64661 m .47629 .64769 L .4784 .64507 L F
.625 .921 .976 r
.74359 .59002 m .7392 .59109 L .74282 .58928 L F
.717 .889 .959 r
.74483 .58811 m .74359 .59002 L .74282 .58928 L F
.74483 .58811 m .74585 .589 L .74359 .59002 L F
.015 0 0 r
.42937 .64976 m .4314 .64934 L .43277 .64867 L F
.384 .809 .97 r
.43005 .64882 m .43341 .64893 L .4314 .64934 L F
0 0 0 r
.43258 .64904 m .43358 .64894 L .43531 .64835 L F
.4314 .64934 m .43358 .64894 L .43258 .64904 L F
.4314 .64934 m .43531 .64835 L .43277 .64867 L F
.147 0 0 r
.43213 .64849 m .43461 .64882 L .43358 .64894 L F
.513 0 0 r
.43531 .64835 m .43358 .64894 L .43689 .64908 L F
.147 0 0 r
.43461 .64882 m .43592 .649 L .43358 .64894 L F
.384 .809 .97 r
.43341 .64893 m .43358 .64894 L .4314 .64934 L F
.015 0 0 r
.42922 .64981 m .4314 .64934 L .42937 .64976 L F
.723 .518 .613 r
.50044 .65045 m .49685 .65249 L .49705 .65021 L F
.50044 .65045 m .50042 .65294 L .49685 .65249 L F
0 0 0 r
.49383 .74798 m .4927 .74874 L .49437 .74732 L F
.49383 .74798 m .49131 .75009 L .4927 .74874 L F
.406 .554 .89 r
.36543 .71062 m .36572 .70857 L .3644 .70814 L F
.36543 .71062 m .36666 .71088 L .36572 .70857 L F
.346 .788 .624 r
.3143 .6489 m .31314 .64955 L .31632 .64823 L F
.239 .741 .68 r
.3143 .6489 m .31632 .64823 L .31832 .64754 L F
.608 .65 .866 r
.69877 .48385 m .69725 .48624 L .69642 .48438 L F
.69877 .48385 m .69967 .48564 L .69725 .48624 L F
.586 .368 .551 r
.51876 .7369 m .52123 .73672 L .52116 .7343 L F
.598 .377 .552 r
.52116 .7343 m .52324 .73627 L .52441 .73406 L F
.52116 .7343 m .52123 .73672 L .52324 .73627 L F
.784 .669 .736 r
.78314 .58881 m .78117 .58586 L .78077 .58863 L F
.891 .742 .69 r
.78077 .58863 m .78181 .59181 L .78314 .58881 L F
.549 .722 .954 r
.53982 .75779 m .5385 .75941 L .54086 .75657 L F
.626 .458 .635 r
.5385 .75941 m .54102 .75944 L .54086 .75657 L F
.494 .308 .557 r
.543 .75376 m .54086 .75657 L .54346 .75587 L F
.54 .403 .643 r
.54102 .75944 m .54346 .75587 L .54086 .75657 L F
.35 0 0 r
.53358 .73714 m .53243 .73708 L .53034 .73619 L F
.34 0 0 r
.53358 .73714 m .53398 .73747 L .53243 .73708 L F
.53358 .73714 m .53744 .73886 L .53398 .73747 L F
.537 .236 .405 r
.49036 .7564 m .49289 .75608 L .49369 .75366 L F
.572 .271 .42 r
.49369 .75366 m .49591 .75544 L .49604 .75368 L F
.49369 .75366 m .49289 .75608 L .49591 .75544 L F
.523 .064 .106 r
.40599 .65151 m .40838 .65173 L .40981 .65018 L F
.368 0 .077 r
.40838 .65173 m .41213 .64955 L .40981 .65018 L F
.678 .51 .652 r
.50399 .79813 m .50607 .79916 L .50572 .79642 L F
.547 .416 .654 r
.50572 .79642 m .5087 .79866 L .50789 .79667 L F
0 0 0 r
.6888 .52969 m .68684 .53083 L .68588 .53156 L F
.73 .613 .727 r
.4926 .67224 m .49111 .67613 L .49501 .67502 L F
.299 .097 .43 r
.49501 .67502 m .49712 .67348 L .4926 .67224 L F
.49501 .67502 m .49605 .67502 L .49712 .67348 L F
.711 .618 .751 r
.65126 .52975 m .65222 .53401 L .64884 .53273 L F
0 .001 .559 r
.65227 .53178 m .65222 .53401 L .65126 .52975 L F
.464 0 0 r
.6513 .5345 m .65222 .53401 L .65227 .53178 L F
.6513 .5345 m .65484 .53502 L .65222 .53401 L F
.651 .632 .818 r
.59511 .73829 m .59621 .73638 L .59443 .73688 L F
0 0 0 r
.72167 .5187 m .7212 .51903 L .71878 .51963 L F
.72366 .51834 m .72167 .5187 L .724 .51757 L F
.72366 .51834 m .7212 .51903 L .72167 .5187 L F
.411 .81 .984 r
.55921 .77319 m .56043 .77245 L .55812 .77286 L F
.55921 .77319 m .56153 .77295 L .56043 .77245 L F
.838 .385 .138 r
.56224 .73916 m .56532 .74203 L .56387 .73961 L F
.615 .699 .905 r
.68571 .47969 m .68475 .48249 L .68363 .48088 L F
.68571 .47969 m .68721 .48188 L .68475 .48249 L F
.457 .501 .816 r
.59164 .73178 m .59416 .732 L .59178 .7282 L F
.492 .303 .552 r
.59313 .73362 m .59164 .73178 L .59083 .73399 L F
.59313 .73362 m .59416 .732 L .59164 .73178 L F
.452 .452 .767 r
.27643 .63077 m .27457 .63078 L .27354 .62718 L F
.136 0 0 r
.32977 .74818 m .33154 .7483 L .33223 .74824 L F
.06 0 0 r
.33223 .74824 m .33019 .74819 L .32977 .74818 L F
.678 .463 .587 r
.32963 .74699 m .33081 .7478 L .32977 .74818 L F
.33081 .7478 m .33019 .74819 L .32977 .74818 L F
.33146 .74825 m .33154 .7483 L .32977 .74818 L F
.06 0 0 r
.33019 .74819 m .32987 .74819 L .32977 .74818 L F
.599 .494 .706 r
.32963 .74699 m .33081 .7478 L .33237 .7461 L F
.831 .92 .895 r
.33232 .74684 m .33081 .7478 L .33223 .74824 L F
.33237 .7461 m .33019 .74819 L .33232 .74684 L F
.599 .494 .706 r
.33081 .7478 m .33154 .7483 L .33237 .7461 L F
.831 .92 .895 r
.33081 .7478 m .33019 .74819 L .33045 .7482 L F
.33081 .7478 m .33045 .7482 L .33223 .74824 L F
.33237 .7461 m .32987 .74819 L .33019 .74819 L F
.678 .463 .587 r
.33081 .7478 m .33146 .74825 L .33019 .74819 L F
.94 .951 .631 r
.33237 .7461 m .33154 .7483 L .33223 .74824 L F
.427 .795 .995 r
.44071 .64737 m .44287 .64708 L .44422 .6478 L F
.392 .771 .991 r
.44287 .64708 m .44644 .64767 L .44422 .6478 L F
.257 0 0 r
.61709 .55097 m .61993 .5509 L .62135 .55018 L F
.052 0 0 r
.61993 .5509 m .62319 .54938 L .62135 .55018 L F
.988 .718 .379 r
.70844 .49667 m .7082 .49896 L .71052 .49604 L F
.348 .038 .291 r
.27735 .61686 m .27661 .61892 L .27471 .61944 L F
.444 .278 .56 r
.27941 .6138 m .2793 .61643 L .27735 .61686 L F
.291 0 .265 r
.2784 .61824 m .27735 .61686 L .2793 .61643 L F
.2784 .61824 m .27661 .61892 L .27735 .61686 L F
.639 .569 .76 r
.50356 .6419 m .50136 .64415 L .50126 .64237 L F
.686 .462 .577 r
.50377 .65315 m .50017 .65534 L .50042 .65294 L F
.50377 .65315 m .50378 .65571 L .50017 .65534 L F
.669 .557 .719 r
.50561 .65058 m .50603 .65294 L .50377 .65315 L F
.707 .514 .625 r
.50603 .65294 m .50378 .65571 L .50377 .65315 L F
.536 .868 .993 r
.48309 .75525 m .48243 .7563 L .48518 .75567 L F
0 0 .529 r
.48333 .75512 m .48243 .7563 L .48309 .75525 L F
.487 .312 .568 r
.48292 .75928 m .48518 .75567 L .48243 .7563 L F
.438 .595 .909 r
.48518 .75567 m .48672 .75537 L .48309 .75525 L F
.256 .745 .92 r
.48309 .75525 m .48672 .75537 L .48333 .75512 L F
0 0 0 r
.48333 .75512 m .48135 .7584 L .48243 .7563 L F
.662 .25 .252 r
.56668 .77425 m .56368 .77545 L .56371 .77289 L F
0 0 .465 r
.56736 .77434 m .56668 .77425 L .56871 .77242 L F
0 0 0 r
.56736 .77434 m .5677 .77402 L .56762 .77413 L F
.571 .072 .03 r
.56368 .77545 m .56753 .77572 L .56574 .77654 L F
0 0 .465 r
.56736 .77434 m .56753 .77572 L .56694 .7747 L F
.894 .985 .798 r
.56574 .77654 m .56753 .77572 L .56736 .77434 L F
0 0 0 r
.56736 .77434 m .56762 .77413 L .56595 .77634 L F
0 0 .465 r
.56736 .77434 m .56694 .7747 L .56668 .77425 L F
.734 .629 .742 r
.49113 .65046 m .49102 .6542 L .48907 .65313 L F
.631 .549 .744 r
.49233 .65608 m .48907 .65313 L .49102 .6542 L F
.666 .572 .739 r
.49465 .65309 m .49102 .6542 L .49113 .65046 L F
.633 .468 .641 r
.49465 .65309 m .49233 .65608 L .49102 .6542 L F
.513 .546 .827 r
.38621 .71885 m .38783 .7162 L .38545 .71676 L F
.38621 .71885 m .38909 .71877 L .38783 .7162 L F
.551 .398 .627 r
.33203 .61416 m .33425 .61369 L .3341 .61092 L F
.489 .271 .51 r
.33203 .61416 m .33407 .61585 L .33425 .61369 L F
.33203 .61416 m .33176 .61642 L .33407 .61585 L F
.747 .33 0 r
.56983 .74845 m .57068 .75019 L .57137 .75105 L F
.946 .651 .202 r
.57068 .75019 m .57172 .75344 L .57137 .75105 L F
.907 .928 .549 r
.65384 .48819 m .65505 .48402 L .6562 .48525 L F
.673 .836 .962 r
.65851 .4844 m .6562 .48525 L .65505 .48402 L F
0 .33 .761 r
.64843 .48983 m .65069 .49097 L .65081 .49135 L F
0 0 .281 r
.65069 .49097 m .6516 .49335 L .65081 .49135 L F
.549 .722 .954 r
.53982 .75779 m .54102 .75944 L .5385 .75941 L F
.607 .338 .484 r
.5385 .75941 m .54075 .76147 L .54102 .75944 L F
.5385 .75941 m .54075 .76147 L .54102 .75944 L F
.985 .722 .344 r
.57267 .75905 m .57281 .76145 L .57357 .76205 L F
.985 .904 .608 r
.57214 .76369 m .57357 .76205 L .57281 .76145 L F
.57214 .76369 m .57266 .76551 L .57357 .76205 L F
.046 0 0 r
.2648 .58635 m .26511 .58707 L .26694 .58605 L F
.2648 .58635 m .26313 .58774 L .26511 .58707 L F
.81 .811 .852 r
.77061 .60666 m .76688 .60749 L .76829 .60717 L F
.681 .977 .818 r
.77159 .60554 m .77061 .60666 L .76829 .60717 L F
.77202 .60547 m .77061 .60666 L .77159 .60554 L F
.77242 .60513 m .76829 .60717 L .77111 .60558 L F
.353 0 0 r
.77061 .60594 m .77407 .60643 L .7712 .60561 L F
.77104 .60563 m .7712 .60561 L .77111 .60558 L F
.77061 .60594 m .7712 .60561 L .77104 .60563 L F
.681 .977 .818 r
.77242 .60513 m .77202 .60547 L .77159 .60554 L F
.195 .724 .829 r
.52722 .76431 m .52357 .76457 L .52526 .7646 L F
.49 .472 .765 r
.75352 .59888 m .75132 .60063 L .75038 .59731 L F
.337 .801 .932 r
.71878 .51963 m .71499 .51948 L .71644 .52016 L F
.704 .824 .939 r
.76623 .57688 m .76398 .57812 L .76293 .57688 L F
.441 .19 .436 r
.35746 .61338 m .35478 .61611 L .35546 .61387 L F
.514 .507 .786 r
.49117 .7862 m .48906 .78761 L .48829 .78452 L F
.466 .387 .684 r
.49117 .7862 m .48955 .7901 L .48906 .78761 L F
.38 .541 .89 r
.35834 .59612 m .3575 .59783 L .35655 .59617 L F
.35834 .59612 m .36016 .59879 L .3575 .59783 L F
.575 .396 .602 r
.39786 .67549 m .39785 .67783 L .39552 .67818 L F
.683 .68 .841 r
.58209 .71982 m .58298 .72131 L .58494 .72017 L F
.609 .696 .905 r
.47456 .77338 m .47714 .77316 L .47594 .77078 L F
.117 .092 .55 r
.47594 .77078 m .47594 .77266 L .47456 .77338 L F
.265 .38 .793 r
.47456 .77338 m .47712 .77555 L .47714 .77316 L F
0 0 .335 r
.47532 .77468 m .47456 .77338 L .47594 .77266 L F
.47532 .77468 m .47527 .77657 L .47456 .77338 L F
.383 .754 .991 r
.33058 .59102 m .33007 .59201 L .32859 .59107 L F
.33058 .59102 m .33215 .59187 L .33007 .59201 L F
.555 .031 0 r
.62905 .52218 m .62801 .52309 L .62605 .52269 L F
.669 .166 .041 r
.63075 .52337 m .62801 .52309 L .62905 .52218 L F
.673 .417 .526 r
.60135 .5805 m .60159 .58269 L .59786 .58284 L F
.709 .441 .517 r
.60135 .5805 m .6037 .58299 L .60159 .58269 L F
.89 .709 .652 r
.49106 .79819 m .49217 .80077 L .49015 .80057 L F
.844 .482 .366 r
.49217 .80077 m .49091 .80292 L .49015 .80057 L F
.573 .533 .772 r
.49369 .7975 m .49217 .80077 L .49106 .79819 L F
.49369 .7975 m .49457 .80056 L .49217 .80077 L F
.913 .585 .41 r
.49217 .80077 m .49253 .80283 L .49091 .80292 L F
.504 .746 .982 r
.49217 .80077 m .49475 .80378 L .49253 .80283 L F
.49217 .80077 m .49457 .80056 L .49475 .80378 L F
.684 .504 .637 r
.476 .67267 m .47892 .67523 L .47792 .67189 L F
.476 .67267 m .47673 .67583 L .47892 .67523 L F
.689 .411 .496 r
.49404 .78391 m .49064 .78407 L .49059 .78194 L F
0 0 .007 r
.59061 .70942 m .59017 .71237 L .59057 .7108 L F
.832 .995 .755 r
.59057 .7108 m .59017 .71237 L .58892 .71369 L F
.953 .943 .727 r
.65528 .51558 m .65311 .51728 L .65551 .51459 L F
.65528 .51558 m .65381 .5184 L .65311 .51728 L F
.236 0 0 r
.422 .70553 m .42019 .70727 L .41814 .70773 L F
.308 0 0 r
.4233 .70614 m .422 .70553 L .42415 .70512 L F
.4233 .70614 m .42019 .70727 L .422 .70553 L F
.631 .549 .744 r
.49233 .65608 m .49025 .65713 L .48907 .65313 L F
.775 .668 .745 r
.39717 .71432 m .39824 .7175 L .39478 .71687 L F
.606 .073 0 r
.39824 .7175 m .3966 .71772 L .39478 .71687 L F
.911 .914 .808 r
.39906 .7138 m .39824 .7175 L .39717 .71432 L F
.39906 .7138 m .3966 .71772 L .39824 .7175 L F
.898 .494 .08 r
.47047 .79543 m .4723 .7984 L .47143 .79828 L F
.747 .23 0 r
.4723 .7984 m .47251 .79994 L .47143 .79828 L F
.4723 .7984 m .4741 .80028 L .47251 .79994 L F
.175 0 0 r
.62772 .54319 m .63005 .54311 L .63206 .54151 L F
.707 .46 .548 r
.63032 .54289 m .63253 .54051 L .63206 .54151 L F
.63059 .54254 m .63253 .54051 L .63032 .54289 L F
.63005 .54311 m .63059 .54254 L .63032 .54289 L F
.63005 .54311 m .6328 .54321 L .63253 .54051 L F
.666 .572 .739 r
.63542 .54264 m .6328 .54321 L .63205 .54065 L F
.63233 .54028 m .63205 .54065 L .63182 .5399 L F
.63542 .54264 m .63205 .54065 L .63233 .54028 L F
.539 .72 .957 r
.76529 .58509 m .76659 .58304 L .764 .58318 L F
.76529 .58509 m .76808 .58493 L .76659 .58304 L F
.389 .667 .97 r
.67431 .48871 m .67594 .48772 L .67296 .48816 L F
.67431 .48871 m .67718 .48892 L .67594 .48772 L F
.555 .662 .908 r
.67431 .48871 m .67785 .48936 L .67718 .48892 L F
.776 .471 .47 r
.48982 .68513 m .49295 .68366 L .48979 .6833 L F
.48982 .68513 m .4945 .68569 L .49295 .68366 L F
0 .181 .713 r
.4945 .68569 m .49502 .68583 L .49295 .68366 L F
.609 .324 .46 r
.49295 .68366 m .49502 .68583 L .49547 .68392 L F
.511 .268 .481 r
.5568 .69771 m .55918 .69741 L .55939 .69505 L F
.546 .296 .489 r
.55939 .69505 m .55918 .69741 L .5613 .69695 L F
.806 .769 .819 r
.56144 .69585 m .56221 .69517 L .55939 .69505 L F
.445 .82 .992 r
.77762 .60488 m .77575 .60595 L .77468 .60514 L F
.77762 .60488 m .77831 .60552 L .77575 .60595 L F
.598 .035 0 r
.5688 .72596 m .56827 .72653 L .56741 .72591 L F
.1 .549 .912 r
.5697 .72755 m .56827 .72653 L .5688 .72596 L F
.703 .74 .88 r
.72027 .49112 m .71925 .49384 L .72189 .49292 L F
.933 .555 .221 r
.72027 .49112 m .72189 .49292 L .71925 .49384 L F
.788 .656 .717 r
.48707 .6723 m .48467 .67523 L .48812 .67553 L F
.695 .48 .591 r
.48446 .67641 m .48812 .67553 L .48467 .67523 L F
.48446 .67641 m .48834 .67779 L .48812 .67553 L F
0 0 .437 r
.48812 .67553 m .48882 .67189 L .48707 .6723 L F
.929 .963 .769 r
.58052 .55702 m .58319 .55476 L .58112 .55775 L F
.58052 .55702 m .58242 .55399 L .58319 .55476 L F
.885 .984 .817 r
.58242 .55399 m .58437 .55308 L .58319 .55476 L F
.938 .751 .623 r
.59477 .70273 m .5961 .70087 L .59401 .70077 L F
.59477 .70273 m .59622 .70346 L .5961 .70087 L F
.65 .608 .793 r
.48075 .64445 m .47845 .64661 L .4784 .64507 L F
.48075 .64445 m .48204 .64775 L .47845 .64661 L F
.604 .544 .76 r
.73711 .60241 m .73895 .59973 L .73667 .60043 L F
.73711 .60241 m .7399 .60313 L .73895 .59973 L F
.206 0 0 r
.30038 .60261 m .29857 .60379 L .29673 .60396 L F
.059 0 0 r
.30103 .60307 m .30038 .60261 L .30251 .60222 L F
.30103 .60307 m .29857 .60379 L .30038 .60261 L F
.636 .357 .478 r
.60707 .58055 m .60711 .58238 L .6037 .58299 L F
.623 .346 .478 r
.60707 .58055 m .60941 .58256 L .60711 .58238 L F
.612 .35 .496 r
.6095 .58042 m .60941 .58256 L .60707 .58055 L F
.325 .8 .914 r
.44644 .64767 m .44881 .64726 L .44992 .64749 L F
.695 .98 .818 r
.45194 .64575 m .44992 .64749 L .45075 .64611 L F
.655 .955 .944 r
.44992 .64749 m .44881 .64726 L .45075 .64611 L F
.784 .769 .839 r
.49229 .6415 m .4887 .6416 L .49113 .63881 L F
.801 .679 .73 r
.49229 .6415 m .48999 .64472 L .4887 .6416 L F
.727 .571 .679 r
.49225 .64423 m .48999 .64472 L .49229 .6415 L F
.631 .63 .831 r
.4933 .63802 m .49229 .6415 L .49113 .63881 L F
.4933 .63802 m .49446 .64085 L .49229 .6415 L F
.468 .446 .751 r
.3738 .68648 m .37458 .68974 L .37638 .68852 L F
.476 .463 .764 r
.37458 .68974 m .3773 .69169 L .37638 .68852 L F
.523 .46 .727 r
.37458 .68974 m .37532 .69227 L .3773 .69169 L F
0 0 0 r
.31314 .64955 m .31246 .64991 L .31024 .65038 L F
.346 .788 .624 r
.3143 .6489 m .31246 .64991 L .31314 .64955 L F
.537 .182 .314 r
.51456 .7783 m .51008 .78111 L .51008 .77862 L F
.51456 .7783 m .5124 .78095 L .51008 .78111 L F
.559 .347 .549 r
.51456 .7783 m .51543 .77938 L .51717 .78092 L F
.51456 .7783 m .51717 .78092 L .5124 .78095 L F
.604 .188 .227 r
.47106 .68914 m .4698 .69087 L .46768 .68931 L F
.444 0 .062 r
.47338 .68923 m .4698 .69087 L .47106 .68914 L F
.969 .749 .549 r
.78199 .5971 m .78103 .59367 L .78082 .59653 L F
.895 .938 .833 r
.77925 .59872 m .78199 .5971 L .78082 .59653 L F
.576 .436 .654 r
.55248 .70349 m .55471 .70315 L .55453 .70071 L F
.744 .606 .704 r
.48648 .64204 m .48819 .6463 L .48461 .6449 L F
.661 .565 .737 r
.48999 .64472 m .48819 .6463 L .48648 .64204 L F
.457 .16 .373 r
.32009 .62769 m .32218 .62727 L .32282 .6254 L F
.252 0 .28 r
.32282 .6254 m .32402 .62632 L .32486 .62488 L F
.32282 .6254 m .32218 .62727 L .32402 .62632 L F
.889 .524 .346 r
.483 .80672 m .4855 .80947 L .48419 .81015 L F
.599 .117 .082 r
.48419 .81015 m .4855 .80947 L .48493 .81104 L F
.656 .125 0 r
.4855 .80947 m .48743 .81158 L .48493 .81104 L F
.867 .657 .615 r
.47963 .80218 m .47986 .8041 L .47704 .80317 L F
.88 .953 .85 r
.47997 .8001 m .47963 .80218 L .48262 .79818 L F
.47971 .80029 m .47971 .80038 L .47997 .8001 L F
.47971 .80038 m .47963 .80218 L .47997 .8001 L F
.47971 .80029 m .48262 .79818 L .48208 .79821 L F
.47971 .80029 m .48361 .79687 L .48065 .79753 L F
.47932 .7983 m .48065 .79753 L .47923 .79785 L F
.47971 .80029 m .48065 .79753 L .47932 .7983 L F
.48208 .79821 m .48262 .79818 L .48361 .79687 L F
.647 .25 .279 r
.48248 .79648 m .48424 .79832 L .48155 .79809 L F
.48296 .79566 m .48316 .79609 L .48248 .79648 L F
.48316 .79609 m .48424 .79832 L .48248 .79648 L F
.523 .3 .517 r
.48424 .79832 m .48392 .79975 L .48174 .79823 L F
.48184 .79812 m .48174 .79823 L .48155 .79809 L F
.48424 .79832 m .48174 .79823 L .48184 .79812 L F
.7 .773 .908 r
.48232 .79871 m .47963 .80218 L .47971 .80029 L F
.48233 .79871 m .47963 .80218 L .48232 .79871 L F
.631 .087 0 r
.48174 .79823 m .48248 .79875 L .48143 .79824 L F
0 0 .473 r
.48316 .80198 m .48234 .79872 L .48392 .79975 L F
.631 .087 0 r
.48248 .79875 m .48392 .79975 L .48233 .79871 L F
0 0 .473 r
.48234 .79872 m .48234 .79869 L .48392 .79975 L F
.631 .087 0 r
.48233 .79871 m .48392 .79975 L .4821 .79865 L F
.48248 .79875 m .4821 .79865 L .48143 .79824 L F
.7 .773 .908 r
.48233 .79871 m .48264 .80142 L .47963 .80218 L F
.48234 .79869 m .48234 .79871 L .48233 .79871 L F
.48234 .79871 m .48264 .80142 L .48233 .79871 L F
.48234 .79869 m .48233 .79871 L .48232 .79871 L F
0 0 .473 r
.48316 .80198 m .48264 .80142 L .48234 .79871 L F
.48234 .79872 m .48234 .79871 L .48234 .79869 L F
.48316 .80198 m .48234 .79871 L .48234 .79872 L F
.631 .087 0 r
.48216 .79868 m .48241 .79884 L .48121 .79854 L F
.48241 .79884 m .48392 .79975 L .48259 .79916 L F
.48203 .79874 m .48175 .79878 L .48121 .79854 L F
.65 .968 .891 r
.48095 .79889 m .48234 .79869 L .48232 .79871 L F
.48095 .79889 m .48232 .79871 L .47971 .80029 L F
.631 .087 0 r
.48241 .79884 m .48259 .79916 L .48175 .79878 L F
.48241 .79884 m .48175 .79878 L .48203 .79874 L F
.48121 .79854 m .48392 .79975 L .48095 .79889 L F
.48143 .79824 m .48216 .79868 L .48121 .79854 L F
.48155 .79809 m .48174 .79823 L .48143 .79824 L F
.671 .516 .667 r
.48264 .80142 m .47986 .8041 L .47963 .80218 L F
.213 0 .012 r
.59297 .70601 m .59622 .70346 L .59477 .70273 L F
.59297 .70601 m .59509 .70532 L .59622 .70346 L F
.399 .401 .746 r
.59358 .70607 m .59509 .70532 L .59284 .70626 L F
.02 .327 .812 r
.59509 .70532 m .59723 .70788 L .59648 .70541 L F
.59509 .70532 m .5978 .70738 L .59723 .70788 L F
.399 .401 .746 r
.59715 .70515 m .5978 .70738 L .59509 .70532 L F
.59715 .70515 m .59509 .70532 L .59358 .70607 L F
.933 .618 .42 r
.59509 .70532 m .59648 .70541 L .59638 .70467 L F
.59509 .70532 m .59638 .70467 L .59622 .70346 L F
.998 .795 .503 r
.61413 .4994 m .61282 .50085 L .61307 .49794 L F
.61413 .4994 m .6138 .50202 L .61282 .50085 L F
.775 .54 .579 r
.64792 .50235 m .64817 .50462 L .64501 .50422 L F
.636 .915 .98 r
.28376 .63325 m .28441 .63179 L .28582 .63294 L F
.28376 .63325 m .28217 .63281 L .28441 .63179 L F
.537 .223 .383 r
.48296 .79566 m .48155 .79809 L .47923 .79785 L F
.647 .25 .279 r
.48296 .79566 m .48512 .79585 L .48424 .79832 L F
.942 .922 .761 r
.58112 .55775 m .57839 .56003 L .58052 .55702 L F
.58112 .55775 m .57934 .56074 L .57839 .56003 L F
.706 .57 .7 r
.56087 .78194 m .56178 .78135 L .56296 .77888 L F
.954 .703 .52 r
.59226 .69182 m .5937 .69491 L .5938 .69233 L F
.185 0 .113 r
.63411 .55788 m .63691 .55558 L .63594 .5569 L F
0 0 0 r
.63594 .5569 m .63691 .55558 L .63846 .55431 L F
.345 0 .222 r
.42157 .66439 m .42042 .66688 L .41859 .66649 L F
.486 .133 .292 r
.42365 .66533 m .42157 .66439 L .42405 .66426 L F
.42365 .66533 m .42042 .66688 L .42157 .66439 L F
.468 .647 .936 r
.74766 .60771 m .74718 .6084 L .74901 .60707 L F
.366 .44 .805 r
.74718 .6084 m .7499 .60979 L .74901 .60707 L F
.448 .566 .881 r
.74718 .6084 m .75068 .61105 L .7499 .60979 L F
.215 .298 .734 r
.58422 .72571 m .58571 .72762 L .58546 .72494 L F
.745 .868 .937 r
.78073 .60409 m .78145 .60515 L .77831 .60552 L F
.414 .771 .995 r
.78296 .60422 m .78145 .60515 L .78073 .60409 L F
.671 .275 .288 r
.48424 .79832 m .48512 .79585 L .48534 .79819 L F
.622 .426 .596 r
.47202 .68067 m .47435 .6806 L .47464 .67821 L F
.615 .506 .707 r
.47464 .67821 m .47667 .67804 L .47673 .67583 L F
.591 .394 .584 r
.47435 .6806 m .47667 .67804 L .47464 .67821 L F
.264 0 0 r
.30835 .63334 m .31181 .63239 L .30987 .63328 L F
.505 .303 .54 r
.36777 .60558 m .36723 .60719 L .36505 .60708 L F
.473 .135 .311 r
.36505 .60708 m .36642 .60947 L .36424 .60979 L F
.36505 .60708 m .36723 .60719 L .36642 .60947 L F
.765 .715 .805 r
.71483 .50005 m .71731 .50028 L .71692 .49916 L F
.427 0 0 r
.72079 .50146 m .71692 .49916 L .71731 .50028 L F
.848 .452 0 r
.2526 .6437 m .25505 .64787 L .25332 .64582 L F
.518 .808 .998 r
.69328 .51016 m .69225 .50925 L .69085 .51062 L F
.69328 .51016 m .69225 .50925 L .69085 .51062 L F
.847 .772 .265 r
.65384 .48819 m .65335 .49082 L .65342 .48917 L F
.907 .928 .549 r
.65384 .48819 m .65375 .48725 L .65505 .48402 L F
.854 .77 .264 r
.65384 .48819 m .65342 .48917 L .65375 .48725 L F
.503 .372 .636 r
.39965 .67493 m .39785 .67783 L .39786 .67549 L F
.63 .475 .654 r
.4914 .78987 m .49466 .79083 L .49578 .79023 L F
.42 .21 .486 r
.4977 .78972 m .4957 .7923 L .49578 .79023 L F
.413 0 .01 r
.49466 .79083 m .4977 .78972 L .49578 .79023 L F
.298 .017 .306 r
.63456 .48201 m .63187 .48457 L .63256 .48289 L F
.699 .209 .079 r
.54346 .75587 m .54686 .75663 L .54414 .75558 L F
.633 .481 .658 r
.54346 .75587 m .54535 .75873 L .54686 .75663 L F
.67 .333 .394 r
.54686 .75663 m .54535 .75873 L .5489 .75848 L F
0 .241 .756 r
.54686 .75663 m .5489 .75848 L .54712 .75551 L F
.499 .227 .433 r
.4516 .68375 m .45374 .68341 L .45405 .68126 L F
.724 .429 .478 r
.45405 .68126 m .45374 .68341 L .45718 .68339 L F
.299 .604 .952 r
.35411 .59423 m .35363 .59533 L .35281 .59457 L F
.35411 .59423 m .35655 .59617 L .35363 .59533 L F
.7 .269 .223 r
.52086 .77478 m .52416 .77534 L .5232 .77389 L F
.672 .264 .263 r
.52416 .77534 m .52612 .7759 L .5232 .77389 L F
.569 .721 .945 r
.26673 .64985 m .26993 .65076 L .26873 .64952 L F
.432 .604 .919 r
.26993 .65076 m .27079 .64916 L .26873 .64952 L F
.26993 .65076 m .273 .65158 L .27079 .64916 L F
.522 .388 .64 r
.37532 .69227 m .37759 .69424 L .3773 .69169 L F
.37532 .69227 m .3754 .69495 L .37759 .69424 L F
.255 .763 .756 r
.51755 .81387 m .5211 .81311 L .5232 .81251 L F
.579 .341 .519 r
.59569 .58274 m .59287 .58527 L .59323 .58318 L F
.22 .722 .905 r
.4637 .65826 m .46283 .65789 L .46031 .65795 L F
.609 .641 .857 r
.4637 .65826 m .46474 .65496 L .46283 .65789 L F
.4637 .65826 m .46754 .659 L .46474 .65496 L F
.701 .588 .725 r
.50065 .66692 m .49839 .66977 L .49709 .66663 L F
.608 .456 .65 r
.50065 .66692 m .50113 .67008 L .49839 .66977 L F
.38 .174 .471 r
.50289 .66889 m .50255 .66924 L .50113 .67008 L F
.52 .558 .834 r
.50189 .67262 m .49976 .67089 L .50113 .67008 L F
.38 .174 .471 r
.50255 .66924 m .50068 .6711 L .50113 .67008 L F
.52 .558 .834 r
.49976 .67089 m .49839 .66977 L .50113 .67008 L F
.014 .578 .794 r
.561 .7166 m .56302 .71685 L .56455 .71715 L F
.781 .278 0 r
.56511 .71905 m .56455 .71715 L .56302 .71685 L F
.56511 .71905 m .56653 .71952 L .56455 .71715 L F
.787 .291 .013 r
.56455 .71715 m .56653 .71952 L .56802 .71994 L F
.236 .726 .922 r
.33915 .75377 m .3379 .75335 L .33557 .75344 L F
.33915 .75377 m .3379 .75335 L .33557 .75344 L F
.312 .61 .953 r
.7499 .60979 m .75068 .61105 L .75198 .61009 L F
.374 .728 .989 r
.75198 .61009 m .75068 .61105 L .75299 .61101 L F
.037 0 0 r
.70598 .51558 m .70409 .51666 L .70308 .51793 L F
0 0 0 r
.62904 .50777 m .6286 .50949 L .6269 .51069 L F
.047 0 0 r
.62777 .51144 m .6269 .51069 L .6286 .50949 L F
.62777 .51144 m .626 .51229 L .6269 .51069 L F
0 0 0 r
.69689 .52473 m .69348 .52637 L .69565 .52558 L F
.57 .892 .628 r
.69836 .52332 m .69689 .52473 L .69565 .52558 L F
.377 .559 .905 r
.33508 .6041 m .33578 .60561 L .33685 .60424 L F
.446 .287 .572 r
.33578 .60561 m .33773 .60737 L .33685 .60424 L F
.33578 .60561 m .33585 .60801 L .33773 .60737 L F
.695 .355 .396 r
.48261 .68915 m .47901 .691 L .47927 .68967 L F
.48261 .68915 m .48134 .69145 L .47901 .691 L F
.619 .268 .353 r
.48488 .69083 m .48134 .69145 L .48261 .68915 L F
.653 .221 .208 r
.48497 .68976 m .48488 .69083 L .48261 .68915 L F
0 0 0 r
.63144 .56044 m .63411 .55788 L .63302 .5592 L F
.63594 .5569 m .63302 .5592 L .63411 .55788 L F
.885 .984 .817 r
.58242 .55399 m .58472 .5511 L .58437 .55308 L F
.322 0 .045 r
.41595 .69685 m .41809 .69648 L .41951 .69467 L F
.253 0 0 r
.41809 .69648 m .42181 .69459 L .41951 .69467 L F
.917 .978 .762 r
.55116 .73618 m .55146 .7372 L .55303 .73646 L F
.966 .843 .43 r
.55289 .73663 m .55116 .73618 L .55303 .73646 L F
.499 .83 .999 r
.55103 .73643 m .5478 .73713 L .55146 .7372 L F
.713 .469 .555 r
.5478 .73713 m .55114 .73875 L .55146 .7372 L F
.917 .978 .762 r
.55116 .73618 m .55094 .73628 L .55146 .7372 L F
.267 .028 .354 r
.55146 .7372 m .55114 .73875 L .55303 .73646 L F
.966 .843 .43 r
.55114 .73875 m .55116 .73645 L .55289 .73663 L F
.55116 .73645 m .55116 .73618 L .55289 .73663 L F
.499 .83 .999 r
.55056 .73638 m .5478 .73713 L .55103 .73643 L F
.227 0 0 r
.55076 .73633 m .5461 .73612 L .5478 .73713 L F
.798 .307 .022 r
.55112 .73637 m .54992 .73623 L .55116 .73618 L F
.227 0 0 r
.55094 .73628 m .55038 .73626 L .55076 .73633 L F
.55038 .73626 m .5461 .73612 L .55076 .73633 L F
.798 .307 .022 r
.55064 .73831 m .54992 .73623 L .55076 .73633 L F
.55111 .73639 m .55076 .73633 L .55112 .73637 L F
.499 .83 .999 r
.55098 .73635 m .55056 .73638 L .55103 .73643 L F
.55076 .73633 m .55056 .73638 L .55098 .73635 L F
.798 .307 .022 r
.55064 .73831 m .55076 .73633 L .55111 .73639 L F
.55064 .73831 m .54811 .7363 L .54992 .73623 L F
.499 .83 .999 r
.55094 .73628 m .55076 .73633 L .55098 .73635 L F
.374 .19 .499 r
.27471 .61944 m .27454 .62161 L .27287 .62222 L F
.412 .298 .613 r
.27447 .6238 m .27287 .62222 L .27454 .62161 L F
.27447 .6238 m .27279 .62535 L .27287 .62222 L F
.943 .922 .557 r
.61152 .50989 m .61221 .50594 L .6126 .50828 L F
.705 .265 .203 r
.372 .70993 m .37484 .71089 L .37293 .70883 L F
.714 .921 .578 r
.57124 .76694 m .57266 .76551 L .57214 .76369 L F
.57124 .76694 m .57125 .7673 L .57266 .76551 L F
.509 .328 .57 r
.32726 .62218 m .32934 .61898 L .32721 .61941 L F
.868 .658 .128 r
.59723 .70788 m .59773 .71159 L .5983 .70925 L F
.626 .229 0 r
.66052 .50408 m .65883 .50107 L .65933 .50249 L F
.699 .209 .079 r
.54346 .75587 m .54414 .75558 L .543 .75376 L F
.559 .53 .779 r
.40235 .68837 m .40137 .69197 L .40014 .68897 L F
.40235 .68837 m .4035 .6916 L .40137 .69197 L F
.643 .436 .587 r
.6129 .57774 m .61277 .57987 L .6095 .58042 L F
.634 .409 .559 r
.61505 .57756 m .61277 .57987 L .6129 .57774 L F
.587 .75 .955 r
.7047 .48449 m .70317 .48651 L .70203 .48503 L F
.7047 .48449 m .70555 .48579 L .70317 .48651 L F
.374 .747 .99 r
.56388 .78017 m .56178 .78135 L .56278 .78055 L F
.852 .751 .751 r
.65733 .5238 m .6591 .5246 L .65821 .52147 L F
.839 .705 .716 r
.65565 .52638 m .6591 .5246 L .65733 .5238 L F
.65565 .52638 m .65839 .52679 L .6591 .5246 L F
.671 .663 .834 r
.70095 .49078 m .70452 .4919 L .70311 .49068 L F
.05 .614 .783 r
.70674 .49089 m .70311 .49068 L .70452 .4919 L F
.576 .597 .837 r
.59533 .6949 m .59475 .6979 L .5937 .69491 L F
.59533 .6949 m .59649 .69705 L .59475 .6979 L F
.21 0 .357 r
.59649 .69705 m .59401 .70077 L .59475 .6979 L F
.25 .716 .947 r
.50183 .76175 m .50292 .76151 L .49943 .76093 L F
.254 0 .048 r
.32662 .6425 m .32564 .64374 L .32362 .64433 L F
.147 0 0 r
.32855 .6417 m .32564 .64374 L .32662 .6425 L F
.558 .072 .057 r
.50851 .74262 m .50701 .74379 L .5049 .74265 L F
0 0 0 r
.51079 .74238 m .50701 .74379 L .50851 .74262 L F
.197 .308 .752 r
.52144 .78441 m .52262 .78686 L .52055 .78475 L F
0 0 0 r
.47865 .76219 m .47783 .76214 L .48004 .76176 L F
.47865 .76219 m .47626 .7635 L .47783 .76214 L F
.776 .295 .09 r
.47567 .78634 m .47657 .78558 L .47748 .7867 L F
.472 .18 .387 r
.57484 .67886 m .57521 .68026 L .57679 .67781 L F
.064 0 .458 r
.57411 .68372 m .57521 .68026 L .57484 .67886 L F
.489 .51 .806 r
.40569 .69126 m .40497 .69477 L .4035 .6916 L F
.40569 .69126 m .40684 .69455 L .40497 .69477 L F
.604 .579 .799 r
.40815 .69712 m .40497 .69477 L .40684 .69455 L F
.448 0 0 r
.4468 .65828 m .44528 .65867 L .44317 .6583 L F
.394 0 0 r
.44797 .65793 m .44528 .65867 L .4468 .65828 L F
0 .099 .568 r
.56653 .71952 m .57 .72236 L .56802 .71994 L F
0 .384 .758 r
.57242 .72885 m .57194 .72838 L .5697 .72755 L F
.484 0 0 r
.57242 .72885 m .57514 .73077 L .57354 .72986 L F
.57242 .72885 m .57354 .72986 L .57194 .72838 L F
.216 .018 .382 r
.62715 .566 m .62678 .5683 L .62466 .56917 L F
.19 0 .323 r
.62678 .5683 m .62488 .57116 L .62466 .56917 L F
.723 .587 .703 r
.5841 .58309 m .58194 .58596 L .58182 .58346 L F
.711 .57 .694 r
.5841 .58309 m .58591 .5856 L .58194 .58596 L F
.404 .393 .733 r
.37125 .6753 m .37178 .67838 L .37366 .67741 L F
.32 .208 .566 r
.37178 .67838 m .37364 .67951 L .37366 .67741 L F
.37178 .67838 m .372 .68086 L .37364 .67951 L F
.265 0 .13 r
.33235 .64025 m .33146 .63892 L .33351 .63835 L F
.33235 .64025 m .33038 .64091 L .33146 .63892 L F
.599 .534 .753 r
.53176 .7788 m .53416 .78112 L .53285 .78138 L F
.53176 .7788 m .53285 .78138 L .53183 .77848 L F
.367 .754 .988 r
.29314 .58614 m .2953 .58602 L .29672 .58681 L F
.397 .773 .992 r
.2953 .58602 m .29899 .58663 L .29672 .58681 L F
.414 0 0 r
.68333 .54074 m .68558 .54102 L .6823 .54104 L F
.719 .933 .959 r
.62997 .50338 m .62807 .50478 L .62866 .50353 L F
.62941 .50305 m .62866 .50353 L .62901 .50282 L F
.62997 .50338 m .62866 .50353 L .62941 .50305 L F
.621 .554 .758 r
.62599 .5008 m .62876 .50347 L .62497 .50358 L F
.62876 .50347 m .629 .5037 L .62875 .50369 L F
.62876 .50347 m .62875 .50369 L .62866 .50353 L F
.528 .747 .976 r
.62875 .50369 m .62549 .50499 L .62497 .50358 L F
.629 .5037 m .62868 .50382 L .62875 .50369 L F
.62868 .50382 m .62549 .50499 L .62875 .50369 L F
.292 .467 .861 r
.62901 .50282 m .629 .5037 L .62599 .5008 L F
.238 .358 .784 r
.62866 .50353 m .62875 .50368 L .62901 .50282 L F
.528 .747 .976 r
.62868 .50382 m .62807 .50478 L .62549 .50499 L F
.629 .5037 m .62807 .50478 L .62868 .50382 L F
.238 .358 .784 r
.62875 .50368 m .62876 .50369 L .62909 .50304 L F
.163 .36 .811 r
.62939 .50401 m .62807 .50478 L .629 .5037 L F
.238 .358 .784 r
.62908 .50419 m .63026 .50606 L .62945 .50397 L F
.62807 .50478 m .62995 .50588 L .62866 .50353 L F
.62995 .50588 m .63026 .50606 L .62866 .50353 L F
0 0 .374 r
.63026 .50606 m .63132 .50226 L .62957 .50268 L F
.62945 .50397 m .62957 .50268 L .62901 .50282 L F
.63026 .50606 m .62957 .50268 L .62945 .50397 L F
.163 .36 .811 r
.62944 .50405 m .62807 .50478 L .62939 .50401 L F
.63017 .50463 m .62939 .50468 L .62944 .50405 L F
.62939 .50468 m .62807 .50478 L .62944 .50405 L F
.238 .358 .784 r
.62876 .50369 m .62908 .50419 L .62912 .50312 L F
.62912 .50318 m .62945 .50397 L .62912 .50312 L F
.62939 .50401 m .62945 .50397 L .62912 .50318 L F
0 .181 .698 r
.62901 .50282 m .63017 .50463 L .62939 .50401 L F
.62901 .50282 m .62939 .50401 L .629 .5037 L F
.238 .358 .784 r
.62908 .50419 m .62939 .50401 L .62912 .50318 L F
.62876 .50369 m .62912 .50312 L .62909 .50304 L F
.62875 .50368 m .62909 .50304 L .62901 .50282 L F
.621 .554 .758 r
.62866 .50353 m .62875 .50369 L .62843 .50368 L F
.62876 .50347 m .62843 .50368 L .62497 .50358 L F
.575 .754 .962 r
.68495 .48706 m .68584 .4884 L .68731 .48656 L F
.451 .568 .882 r
.68584 .4884 m .68784 .48861 L .68731 .48656 L F
.517 .41 .671 r
.77658 .59721 m .77985 .59703 L .77818 .59356 L F
.544 .382 .611 r
.77658 .59721 m .77925 .59872 L .77985 .59703 L F
.77658 .59721 m .77705 .59991 L .77925 .59872 L F
.387 .485 .837 r
.65335 .49082 m .65495 .49406 L .65637 .49216 L F
.402 .506 .85 r
.65495 .49406 m .65808 .49566 L .65637 .49216 L F
.781 .704 .779 r
.49854 .68633 m .49716 .68928 L .49971 .68942 L F
.61 .113 .047 r
.49716 .68928 m .49836 .6903 L .49971 .68942 L F
.634 .627 .826 r
.49854 .68633 m .49971 .68942 L .50288 .68805 L F
.606 .288 .404 r
.49836 .6903 m .50288 .68805 L .49971 .68942 L F
.491 .857 .988 r
.69273 .49894 m .69445 .49932 L .6913 .49923 L F
.341 0 0 r
.69545 .49997 m .69445 .49932 L .69273 .49894 L F
.69545 .49997 m .69627 .49977 L .69445 .49932 L F
.888 .807 .764 r
.65484 .53502 m .65616 .53593 L .65791 .53312 L F
.687 .221 .14 r
.5049 .74265 m .50135 .74217 L .5027 .74207 L F
.395 0 0 r
.41213 .64955 m .41422 .64986 L .41542 .64944 L F
.192 0 0 r
.41542 .64944 m .41422 .64986 L .41755 .64941 L F
.627 .605 .808 r
.5018 .76502 m .50417 .76466 L .50292 .76151 L F
.606 .454 .649 r
.5018 .76502 m .50193 .76762 L .50417 .76466 L F
.626 .631 .835 r
.28009 .63299 m .27796 .63376 L .27643 .63077 L F
.29 .025 .327 r
.62772 .54319 m .62763 .54578 L .63005 .54311 L F
.119 0 0 r
.56487 .76438 m .56249 .76531 L .56232 .76617 L F
.56487 .76438 m .56249 .76531 L .56232 .76617 L F
.3 .709 .975 r
.66341 .49282 m .65994 .49199 L .66074 .49311 L F
.304 .499 .883 r
.75743 .60553 m .75548 .60492 L .75383 .60244 L F
.557 .593 .845 r
.76808 .58493 m .76846 .58657 L .7704 .58471 L F
.452 .421 .733 r
.76846 .58657 m .77132 .58769 L .7704 .58471 L F
.264 .614 .957 r
.76846 .58657 m .77304 .58843 L .77132 .58769 L F
.559 .244 .392 r
.62092 .52364 m .62028 .52626 L .6178 .52639 L F
.487 .18 .371 r
.62313 .52341 m .62028 .52626 L .62092 .52364 L F
.982 .697 .336 r
.63268 .50815 m .63137 .50456 L .63026 .50606 L F
0 0 0 r
.63053 .50589 m .6286 .50949 L .62904 .50777 L F
0 0 .312 r
.51338 .78983 m .51334 .78986 L .51241 .78764 L F
.844 .379 .037 r
.51338 .78983 m .51241 .78764 L .51208 .78871 L F
0 .285 .669 r
.7715 .57781 m .77002 .57715 L .76876 .57664 L F
.7715 .57781 m .77151 .5779 L .77002 .57715 L F
.354 .128 .426 r
.47358 .75877 m .4757 .75619 L .47393 .75647 L F
.252 0 0 r
.43002 .70318 m .42866 .70435 L .42649 .70462 L F
.246 0 0 r
.43221 .70271 m .42866 .70435 L .43002 .70318 L F
.957 .653 .416 r
.56532 .74203 m .56703 .74485 L .5664 .74347 L F
.531 .389 .632 r
.37202 .66455 m .37412 .66403 L .37404 .66134 L F
.513 .428 .697 r
.37202 .66455 m .37444 .66644 L .37412 .66403 L F
.37202 .66455 m .37245 .66688 L .37444 .66644 L F
.237 0 .021 r
.62349 .48509 m .62562 .48438 L .62654 .48288 L F
.34 0 .074 r
.62654 .48288 m .6285 .48345 L .62877 .48214 L F
.62654 .48288 m .62562 .48438 L .6285 .48345 L F
.715 .325 .309 r
.50315 .69239 m .50188 .6941 L .49961 .69203 L F
.168 0 0 r
.50415 .69335 m .50315 .69239 L .5058 .69206 L F
.50415 .69335 m .50188 .6941 L .50315 .69239 L F
.563 .384 .597 r
.50518 .68967 m .5058 .69206 L .50315 .69239 L F
.703 .624 .766 r
.49574 .65875 m .49647 .66193 L .49363 .66145 L F
.647 .585 .772 r
.4971 .66422 m .49363 .66145 L .49647 .66193 L F
.613 .546 .755 r
.49811 .65817 m .49647 .66193 L .49574 .65875 L F
.49811 .65817 m .49942 .66159 L .49647 .66193 L F
.61 .511 .717 r
.49942 .66159 m .4971 .66422 L .49647 .66193 L F
.307 .734 .972 r
.34351 .75055 m .34736 .75126 L .34499 .751 L F
0 0 0 r
.62837 .51698 m .62919 .51687 L .63029 .51584 L F
.62837 .51698 m .62769 .51771 L .62919 .51687 L F
.655 .353 .448 r
.49541 .76854 m .49868 .76791 L .49653 .76795 L F
.204 .666 .943 r
.30453 .58769 m .30805 .58858 L .30596 .58887 L F
.791 .535 .55 r
.4786 .68059 m .47976 .68398 L .47865 .68031 L F
.694 .482 .595 r
.47865 .68031 m .48343 .68335 L .48106 .67834 L F
.47865 .68031 m .47976 .68398 L .48343 .68335 L F
.424 0 .076 r
.39356 .65479 m .3928 .65326 L .39127 .65471 L F
.39356 .65479 m .39507 .65314 L .3928 .65326 L F
.884 .823 .782 r
.57647 .5845 m .57859 .58647 L .57643 .58881 L F
.7 .37 .415 r
.57859 .58647 m .57861 .58833 L .57643 .58881 L F
.578 .394 .595 r
.32934 .61898 m .33176 .61642 L .32949 .61701 L F
.477 .427 .723 r
.38353 .71676 m .38516 .71493 L .38229 .7141 L F
.38353 .71676 m .38545 .71676 L .38516 .71493 L F
.177 0 0 r
.47839 .75297 m .48011 .753 L .48133 .75155 L F
.426 0 .081 r
.48011 .753 m .48364 .75131 L .48133 .75155 L F
.753 .468 .499 r
.57347 .72518 m .57566 .7232 L .57343 .72288 L F
.57347 .72518 m .57696 .72535 L .57566 .7232 L F
.541 .131 .212 r
.40271 .71211 m .40136 .71394 L .39906 .7138 L F
.491 .076 .179 r
.4045 .71299 m .40136 .71394 L .40271 .71211 L F
.496 .054 .128 r
.40514 .71225 m .4045 .71299 L .40271 .71211 L F
.876 .438 .125 r
.50242 .68644 m .50383 .68917 L .50518 .68967 L F
0 0 .422 r
.50383 .68917 m .5058 .69206 L .50518 .68967 L F
.386 0 .039 r
.63235 .50244 m .63595 .5007 L .63336 .50165 L F
.416 .01 .158 r
.28733 .65024 m .2859 .65232 L .28362 .6526 L F
.451 0 0 r
.28733 .65024 m .28792 .65161 L .2859 .65232 L F
.28733 .65024 m .28948 .65051 L .28792 .65161 L F
.679 .421 .525 r
.52324 .73627 m .5267 .73412 L .52441 .73406 L F
.858 .658 .631 r
.64459 .52246 m .64294 .52324 L .64207 .52031 L F
.899 .842 .78 r
.64588 .52186 m .64376 .52516 L .64337 .52424 L F
.64467 .52234 m .64337 .52424 L .64294 .52324 L F
.64619 .52156 m .64337 .52424 L .64467 .52234 L F
.858 .658 .631 r
.64511 .52291 m .64294 .52324 L .64459 .52246 L F
.899 .842 .78 r
.64619 .52156 m .64604 .52178 L .64588 .52186 L F
.64604 .52178 m .64376 .52516 L .64588 .52186 L F
.806 .682 .729 r
.64522 .51816 m .64514 .52167 L .64207 .52031 L F
.899 .842 .78 r
.64619 .52156 m .64467 .52234 L .64511 .52291 L F
.806 .682 .729 r
.64467 .52234 m .64511 .52291 L .64459 .52246 L F
.899 .842 .78 r
.64467 .52234 m .64294 .52324 L .64511 .52291 L F
.806 .682 .729 r
.64514 .52167 m .64511 .52291 L .64467 .52234 L F
.64514 .52167 m .64459 .52246 L .64207 .52031 L F
.908 .768 .694 r
.64619 .52156 m .64511 .52291 L .64522 .51816 L F
.699 .658 .807 r
.64859 .51918 m .64619 .52156 L .64522 .51816 L F
.793 .439 .387 r
.68005 .53322 m .68061 .53511 L .67731 .5344 L F
.89 .534 .053 r
.49111 .81214 m .49238 .81465 L .49101 .81458 L F
.479 0 0 r
.49238 .81465 m .49463 .81561 L .49101 .81458 L F
.735 .503 .578 r
.58591 .5856 m .58221 .58782 L .58194 .58596 L F
.58591 .5856 m .58428 .58838 L .58221 .58782 L F
.616 .359 .505 r
.58777 .58767 m .58591 .5856 L .58766 .58612 L F
.58777 .58767 m .58428 .58838 L .58591 .5856 L F
.522 .345 .582 r
.61364 .54644 m .61154 .54918 L .61125 .5468 L F
.483 .357 .632 r
.3341 .61092 m .33613 .61041 L .33585 .60801 L F
.448 .306 .595 r
.33425 .61369 m .33613 .61041 L .3341 .61092 L F
.547 .753 .973 r
.33222 .60446 m .33508 .6041 L .3335 .6025 L F
.707 .514 .625 r
.50603 .65294 m .50617 .65534 L .50378 .65571 L F
.664 .629 .804 r
.50759 .64885 m .50603 .65294 L .50561 .65058 L F
.50759 .64885 m .509 .65267 L .50603 .65294 L F
.675 .49 .627 r
.50807 .65355 m .50617 .65534 L .50603 .65294 L F
.866 .668 .632 r
.63267 .52686 m .63075 .52337 L .63264 .52447 L F
.799 .729 .787 r
.63075 .52337 m .63264 .52447 L .63502 .52171 L F
.251 .392 .81 r
.63075 .52337 m .63267 .52686 L .63264 .52447 L F
.718 .704 .835 r
.485 .64045 m .48648 .64204 L .48295 .64143 L F
.756 .623 .712 r
.48648 .64204 m .48461 .6449 L .48295 .64143 L F
.581 .591 .828 r
.48788 .63895 m .48648 .64204 L .485 .64045 L F
.48788 .63895 m .4887 .6416 L .48648 .64204 L F
.661 .565 .737 r
.48999 .64472 m .48648 .64204 L .4887 .6416 L F
.741 .655 .764 r
.48461 .6449 m .48204 .64775 L .48075 .64445 L F
.613 .622 .836 r
.74376 .60761 m .74531 .60398 L .74278 .60463 L F
.74376 .60761 m .74766 .60771 L .74531 .60398 L F
.582 .309 .468 r
.46866 .68352 m .47121 .68373 L .47202 .68067 L F
.445 .126 .329 r
.47121 .68373 m .47435 .6806 L .47202 .68067 L F
.844 .577 .035 r
.73205 .49549 m .73253 .49832 L .73293 .4989 L F
.852 .496 0 r
.73253 .49832 m .73365 .50084 L .73293 .4989 L F
.413 .772 .995 r
.33575 .59252 m .33215 .59187 L .33421 .59168 L F
.556 .839 .998 r
.33789 .59187 m .33575 .59252 L .33421 .59168 L F
.285 .757 .938 r
.67034 .5381 m .67065 .53852 L .66888 .53806 L F
.599 .348 .508 r
.48902 .74798 m .4915 .74965 L .492 .74608 L F
.526 .283 .49 r
.492 .74608 m .49383 .74798 L .494 .7456 L F
.492 .74608 m .4915 .74965 L .49383 .74798 L F
.186 0 0 r
.68558 .54102 m .68575 .54099 L .68754 .54122 L F
.875 .746 .717 r
.65381 .5184 m .65111 .5185 L .65311 .51728 L F
.65381 .5184 m .65224 .52149 L .65111 .5185 L F
.325 .803 .903 r
.29481 .63507 m .29687 .63467 L .29882 .63476 L F
.469 .878 .947 r
.29882 .63476 m .29901 .63399 L .30005 .63419 L F
.29882 .63476 m .29687 .63467 L .29901 .63399 L F
.59 .803 .981 r
.30129 .63473 m .29882 .63476 L .30005 .63419 L F
.533 .271 .464 r
.53687 .72567 m .53662 .72816 L .53892 .72747 L F
.597 .253 .357 r
.53687 .72567 m .53892 .72747 L .53922 .72576 L F
.813 .784 .283 r
.67648 .53145 m .67716 .52949 L .67614 .52851 L F
.839 .843 .848 r
.67716 .52949 m .678 .52614 L .67614 .52851 L F
.67716 .52949 m .67928 .52727 L .678 .52614 L F
.669 .912 .977 r
.74784 .58802 m .74585 .589 L .74707 .58726 L F
.633 .86 .985 r
.74707 .58726 m .74585 .589 L .74483 .58811 L F
.291 0 .052 r
.52535 .80674 m .52201 .80912 L .52272 .80901 L F
.17 0 0 r
.52755 .80614 m .52535 .80674 L .52272 .80901 L F
.104 .284 .762 r
.52411 .81099 m .52201 .80912 L .52286 .80899 L F
.17 0 0 r
.52293 .80904 m .52346 .8094 L .52629 .80904 L F
.52293 .80904 m .52629 .80904 L .52647 .80898 L F
.52647 .80898 m .52629 .80904 L .52636 .80903 L F
.745 .77 .873 r
.52675 .80892 m .52633 .80935 L .5262 .80918 L F
.678 .643 .808 r
.52346 .8094 m .52516 .81021 L .52603 .80935 L F
.52346 .8094 m .52411 .81099 L .52516 .81021 L F
.104 .284 .762 r
.52347 .80942 m .52286 .80899 L .52346 .8094 L F
.52411 .81099 m .52354 .81008 L .52347 .80942 L F
.52354 .81008 m .52286 .80899 L .52347 .80942 L F
.745 .77 .873 r
.52675 .80892 m .5262 .80918 L .52636 .80903 L F
.17 0 0 r
.52656 .80897 m .52636 .80903 L .5268 .80897 L F
.52647 .80898 m .52636 .80903 L .52656 .80897 L F
.52755 .80614 m .52293 .80904 L .5268 .80897 L F
.52755 .80614 m .52272 .80901 L .52293 .80904 L F
.678 .643 .808 r
.52314 .80806 m .52649 .80889 L .52516 .80777 L F
.745 .77 .873 r
.52675 .80892 m .52658 .80897 L .52516 .80777 L F
.678 .643 .808 r
.52649 .80889 m .5268 .80897 L .52516 .80777 L F
.745 .77 .873 r
.52658 .80897 m .52635 .80903 L .52516 .80777 L F
.678 .643 .808 r
.52614 .80881 m .52635 .80903 L .5268 .80897 L F
.5229 .808 m .52635 .80903 L .52614 .80881 L F
.5229 .808 m .52346 .8094 L .52635 .80903 L F
.52346 .8094 m .5262 .80918 L .52629 .80904 L F
.17 0 0 r
.52346 .8094 m .52347 .8094 L .5268 .80897 L F
.66 .748 .915 r
.52516 .80777 m .52635 .80903 L .52347 .8094 L F
.745 .77 .873 r
.52635 .80903 m .52613 .80909 L .52516 .80777 L F
.66 .748 .915 r
.52516 .80777 m .5268 .80897 L .52635 .80903 L F
.702 .17 0 r
.52411 .81099 m .52201 .80912 L .52113 .80942 L F
.796 .844 .888 r
.52411 .81099 m .52544 .8122 L .52734 .81022 L F
.687 .285 .28 r
.5219 .80953 m .52609 .80936 L .52606 .80942 L F
.796 .844 .888 r
.52411 .81099 m .52734 .81022 L .52694 .80929 L F
.52411 .81099 m .52555 .81013 L .52624 .80939 L F
.52555 .81013 m .52694 .80929 L .5263 .80938 L F
.52555 .81013 m .5263 .80938 L .52624 .80939 L F
.528 .111 .194 r
.52939 .80788 m .52838 .80692 L .5268 .80897 L F
.52838 .80692 m .52755 .80614 L .52685 .80879 L F
.52838 .80692 m .52685 .80879 L .5268 .80897 L F
.766 .753 .841 r
.52675 .80893 m .52939 .80788 L .5268 .80897 L F
0 0 0 r
.52675 .80894 m .52668 .80901 L .52699 .80868 L F
.52668 .80901 m .52673 .80894 L .52735 .80831 L F
.766 .753 .841 r
.5278 .80784 m .52939 .80788 L .52675 .80893 L F
.5278 .80784 m .52939 .80788 L .52675 .80893 L F
0 0 0 r
.52699 .80868 m .52735 .80831 L .52776 .80789 L F
.52668 .80901 m .52735 .80831 L .52699 .80868 L F
.766 .753 .841 r
.52675 .80893 m .52939 .80788 L .5268 .80897 L F
.52516 .80777 m .5278 .80784 L .52735 .80831 L F
.745 .77 .873 r
.52735 .80831 m .52675 .80892 L .52516 .80777 L F
.766 .753 .841 r
.52516 .80777 m .5278 .80784 L .52675 .80893 L F
.745 .77 .873 r
.52776 .80789 m .52735 .80831 L .52516 .80777 L F
.766 .753 .841 r
.52516 .80777 m .52735 .80831 L .52675 .80893 L F
0 0 0 r
.52748 .80822 m .52675 .80894 L .52776 .80789 L F
.52675 .80894 m .52699 .80868 L .52776 .80789 L F
.687 .285 .28 r
.52609 .80936 m .52633 .80935 L .52629 .8094 L F
.776 .778 .855 r
.5262 .80918 m .52633 .80935 L .52609 .80936 L F
.678 .643 .808 r
.52636 .80903 m .52516 .81021 L .52645 .80924 L F
.5267 .80898 m .52645 .80924 L .5268 .80897 L F
0 0 0 r
.52668 .809 m .52633 .80935 L .52673 .80894 L F
.52665 .80903 m .52633 .80935 L .52668 .809 L F
.678 .643 .808 r
.52636 .80903 m .52645 .80924 L .5267 .80898 L F
0 0 0 r
.52668 .80901 m .52665 .80903 L .52668 .809 L F
.5252 .81086 m .5263 .80938 L .52748 .80822 L F
.5263 .80938 m .52633 .80935 L .52748 .80822 L F
.687 .285 .28 r
.52279 .80989 m .52606 .80942 L .5252 .81086 L F
.5219 .80953 m .52606 .80942 L .52279 .80989 L F
.796 .844 .888 r
.52624 .80939 m .52694 .80929 L .5268 .80897 L F
.678 .643 .808 r
.52346 .8094 m .52603 .80935 L .52549 .80924 L F
.104 .284 .762 r
.52346 .8094 m .52286 .80899 L .52327 .80892 L F
.17 0 0 r
.52293 .80904 m .52204 .80959 L .52347 .8094 L F
.66 .748 .915 r
.52341 .8088 m .52347 .8094 L .52204 .80959 L F
.52516 .80777 m .52347 .8094 L .52341 .8088 L F
.17 0 0 r
.52293 .80904 m .52272 .80901 L .52204 .80959 L F
.776 .778 .855 r
.52516 .80777 m .52613 .80909 L .5219 .80953 L F
.52613 .80909 m .5252 .8094 L .5219 .80953 L F
.745 .77 .873 r
.52776 .80789 m .52516 .80777 L .52739 .80746 L F
.321 0 0 r
.5219 .80953 m .5252 .81086 L .52314 .81015 L F
.346 0 .072 r
.52738 .80746 m .52516 .80777 L .52314 .81015 L F
.52739 .80746 m .52516 .80777 L .52738 .80746 L F
.678 .643 .808 r
.5229 .808 m .52314 .80806 L .52516 .80777 L F
.687 .285 .28 r
.52609 .80936 m .52629 .8094 L .5252 .81086 L F
.678 .643 .808 r
.52549 .80924 m .52603 .80935 L .5262 .80918 L F
.52629 .80904 m .5262 .80918 L .52636 .80903 L F
.776 .778 .855 r
.52613 .80909 m .5262 .80918 L .5252 .8094 L F
.5262 .80918 m .52609 .80936 L .5252 .8094 L F
.745 .77 .873 r
.52636 .80903 m .5262 .80918 L .52613 .80909 L F
.104 .284 .762 r
.52327 .80892 m .52272 .80901 L .5229 .808 L F
.52272 .80901 m .52201 .80912 L .52215 .80894 L F
.52272 .80901 m .52215 .80894 L .5229 .808 L F
.291 0 .052 r
.52272 .80901 m .52201 .80912 L .52204 .80959 L F
0 0 0 r
.70308 .51793 m .70131 .51894 L .70019 .51996 L F
.701 .588 .725 r
.49957 .66402 m .49709 .66663 L .4971 .66422 L F
.49957 .66402 m .50065 .66692 L .49709 .66663 L F
.248 0 0 r
.25946 .64633 m .25642 .6473 L .25827 .64641 L F
.572 .616 .858 r
.41039 .69663 m .40815 .69712 L .40684 .69455 L F
.799 .729 .787 r
.63075 .52337 m .63502 .52171 L .63439 .5212 L F
.766 .669 .756 r
.49605 .67502 m .49734 .6785 L .49961 .67556 L F
.64 .574 .765 r
.50356 .6419 m .50126 .64237 L .50016 .6391 L F
.29 0 0 r
.40835 .71089 m .4073 .71193 L .40514 .71225 L F
.361 0 .072 r
.41039 .71043 m .4073 .71193 L .40835 .71089 L F
.685 .626 .783 r
.49957 .66402 m .4971 .66422 L .49942 .66159 L F
.314 0 .256 r
.47839 .75297 m .47961 .75486 L .48011 .753 L F
.47839 .75297 m .47765 .75559 L .47961 .75486 L F
.4 .383 .725 r
.50624 .6431 m .50692 .64689 L .50521 .64715 L F
.466 .4 .699 r
.50759 .64885 m .50521 .64715 L .50692 .64689 L F
.50759 .64885 m .50561 .65058 L .50521 .64715 L F
.718 .544 .653 r
.49225 .64423 m .49015 .647 L .48999 .64472 L F
.49225 .64423 m .49362 .64755 L .49015 .647 L F
.68 .526 .669 r
.4958 .64466 m .49362 .64755 L .49225 .64423 L F
.548 .159 .257 r
.53892 .72747 m .54268 .72518 L .53922 .72576 L F
.53892 .72747 m .5414 .72743 L .54268 .72518 L F
.459 .033 .143 r
.5414 .72743 m .54481 .72566 L .54268 .72518 L F
.579 .742 .954 r
.76412 .60545 m .76449 .60798 L .76267 .60625 L F
.76412 .60545 m .76688 .60749 L .76449 .60798 L F
.958 .828 .672 r
.59765 .72556 m .59848 .72333 L .59707 .7226 L F
.663 .463 .604 r
.48106 .67834 m .48568 .68084 L .48446 .67641 L F
.648 .455 .608 r
.48446 .67641 m .48805 .68034 L .48834 .67779 L F
.48446 .67641 m .48568 .68084 L .48805 .68034 L F
0 0 0 r
.30827 .60093 m .30676 .60136 L .30464 .60187 L F
.07 0 0 r
.31028 .6011 m .30676 .60136 L .30827 .60093 L F
.684 .569 .72 r
.64465 .51423 m .64285 .51819 L .64244 .51594 L F
.662 .564 .734 r
.49574 .65875 m .49363 .66145 L .49264 .65826 L F
.676 .2 .114 r
.50135 .74217 m .5049 .74265 L .5059 .74049 L F
.471 .747 .989 r
.30283 .63392 m .30129 .63473 L .30005 .63419 L F
.30283 .63392 m .30309 .63461 L .30129 .63473 L F
.609 .322 .457 r
.46276 .68264 m .46514 .68286 L .46296 .68097 L F
.293 0 .15 r
.25122 .59168 m .25028 .59318 L .25315 .59109 L F
.836 .953 .606 r
.73393 .5098 m .73224 .51132 L .73188 .51268 L F
.839 .701 .711 r
.65565 .52638 m .65662 .52985 L .65839 .52679 L F
.668 .382 .477 r
.58194 .58596 m .58221 .58782 L .57861 .58833 L F
.487 .741 .984 r
.66182 .48514 m .65851 .4844 L .66071 .48186 L F
.552 .368 .585 r
.66452 .48701 m .66182 .48514 L .66408 .484 L F
.634 .409 .559 r
.61505 .57756 m .61508 .57982 L .61277 .57987 L F
.589 .357 .532 r
.6178 .57736 m .61508 .57982 L .61505 .57756 L F
.856 .544 .459 r
.483 .80672 m .48096 .80848 L .48039 .80671 L F
.483 .80672 m .48419 .81015 L .48096 .80848 L F
.724 .952 .659 r
.70786 .52411 m .70579 .52693 L .70801 .52417 L F
.70786 .52411 m .70569 .5266 L .70579 .52693 L F
.368 0 0 r
.42949 .66188 m .42816 .66313 L .42584 .66335 L F
.503 .035 .077 r
.43179 .66199 m .42816 .66313 L .42949 .66188 L F
.775 .559 .606 r
.51499 .73927 m .51876 .7369 L .51508 .73659 L F
.51499 .73927 m .51911 .74015 L .51876 .7369 L F
.684 .493 .621 r
.51876 .7369 m .52013 .73982 L .52123 .73672 L F
.51876 .7369 m .51911 .74015 L .52013 .73982 L F
.421 .283 .587 r
.56993 .69673 m .56757 .69484 L .57083 .69498 L F
.772 .836 .375 r
.5716 .69225 m .56993 .69673 L .57083 .69498 L F
.196 .326 .77 r
.36326 .70644 m .36479 .70578 L .36249 .70497 L F
.36326 .70644 m .36572 .70857 L .36479 .70578 L F
.145 .314 .777 r
.3644 .70814 m .36572 .70857 L .36326 .70644 L F
0 0 .473 r
.48316 .80198 m .48526 .80467 L .48264 .80142 L F
.609 .196 .234 r
.45946 .69154 m .45831 .69329 L .4562 .69191 L F
.408 0 .095 r
.46178 .69132 m .45831 .69329 L .45946 .69154 L F
.019 0 0 r
.6309 .4812 m .6332 .48065 L .63467 .47977 L F
0 0 .188 r
.63552 .47791 m .63513 .4789 L .63467 .47977 L F
.769 .972 .691 r
.63467 .47977 m .6332 .48065 L .63552 .47791 L F
.586 .516 .743 r
.63513 .4789 m .63456 .48201 L .63467 .47977 L F
.959 .854 .439 r
.54179 .78962 m .54123 .79205 L .54217 .78946 L F
.356 0 0 r
.41859 .66649 m .41811 .6672 L .41587 .66737 L F
.398 0 .105 r
.42042 .66688 m .41811 .6672 L .41859 .66649 L F
.454 .306 .59 r
.50242 .66402 m .50065 .66692 L .49957 .66402 L F
.50242 .66402 m .50284 .66638 L .50065 .66692 L F
.477 .382 .669 r
.50284 .66638 m .50289 .66889 L .50065 .66692 L F
.503 .383 .648 r
.50289 .66889 m .50113 .67008 L .50065 .66692 L F
.75 .705 .81 r
.49605 .67502 m .49961 .67556 L .49833 .67227 L F
.643 .649 .841 r
.49833 .67227 m .49961 .67556 L .5017 .67474 L F
.73 .888 .492 r
.73749 .59394 m .73575 .59692 L .73839 .59633 L F
.631 .509 .695 r
.73575 .59692 m .73895 .59973 L .73839 .59633 L F
.73575 .59692 m .73667 .60043 L .73895 .59973 L F
.898 .782 .724 r
.59681 .73137 m .59605 .72852 L .59532 .73074 L F
.924 .701 .583 r
.59532 .73074 m .59666 .73393 L .59681 .73137 L F
.75 .813 .902 r
.65242 .53778 m .65574 .53811 L .65484 .53502 L F
.65242 .53778 m .65359 .53891 L .65574 .53811 L F
.9 .799 .739 r
.65484 .53502 m .65574 .53811 L .65616 .53593 L F
.593 .392 .578 r
.5568 .69771 m .55926 .69982 L .55918 .69741 L F
.5568 .69771 m .55695 .70012 L .55926 .69982 L F
.809 .723 .77 r
.50068 .6711 m .49833 .67227 L .50189 .67262 L F
.643 .649 .841 r
.49833 .67227 m .5017 .67474 L .50189 .67262 L F
.199 .504 .908 r
.72806 .49058 m .72689 .4914 L .72656 .4898 L F
.658 .172 .086 r
.72333 .48935 m .72715 .49061 L .72656 .4898 L F
.34 .418 .796 r
.72811 .48817 m .7292 .49117 L .72656 .4898 L F
.099 .049 .507 r
.72656 .4898 m .72715 .49061 L .72811 .48817 L F
.739 .76 .87 r
.72702 .48817 m .72715 .49061 L .72294 .48817 L F
.72811 .48817 m .72759 .48949 L .72702 .48817 L F
.72759 .48949 m .72715 .49061 L .72702 .48817 L F
.199 .504 .908 r
.7292 .49117 m .72835 .49126 L .72806 .49058 L F
.72835 .49126 m .72689 .4914 L .72806 .49058 L F
.7292 .49117 m .72984 .49255 L .72689 .4914 L F
.896 .661 .576 r
.47986 .8041 m .47684 .80492 L .47704 .80317 L F
.47986 .8041 m .47867 .80496 L .47684 .80492 L F
.938 .709 .566 r
.63915 .53761 m .63746 .53743 L .63798 .53539 L F
.63915 .53761 m .63746 .53743 L .63798 .53539 L F
.93 .822 .718 r
.63915 .53761 m .63817 .54081 L .63746 .53743 L F
.612 .955 .896 r
.52633 .81135 m .52915 .80997 L .52734 .81022 L F
.596 .355 .521 r
.52755 .80614 m .52985 .80629 L .52764 .80401 L F
.331 0 .134 r
.53026 .8073 m .52985 .80629 L .52939 .80788 L F
.242 .491 .893 r
.53129 .80684 m .5295 .80544 L .52985 .80629 L F
0 0 0 r
.53044 .80838 m .52997 .80877 L .53129 .80684 L F
.946 .787 .653 r
.53044 .80838 m .53129 .80684 L .52985 .80629 L F
.205 .329 .77 r
.53132 .80766 m .53044 .80838 L .52985 .80629 L F
.53235 .80861 m .53044 .80838 L .53132 .80766 L F
0 0 0 r
.53044 .80838 m .52915 .80997 L .52997 .80877 L F
.205 .329 .77 r
.53235 .80861 m .52985 .80629 L .53242 .80586 L F
.331 0 .134 r
.53242 .80586 m .52985 .80629 L .53026 .8073 L F
.242 .491 .893 r
.5295 .80544 m .52764 .80401 L .52985 .80629 L F
.687 .978 .812 r
.68999 .52809 m .69284 .52678 L .6888 .52969 L F
.375 0 .006 r
.46768 .68931 m .46638 .69085 L .46408 .69095 L F
.617 .168 .162 r
.4698 .69087 m .46638 .69085 L .46768 .68931 L F
.749 .633 .731 r
.37145 .7037 m .37239 .70665 L .36989 .70618 L F
.421 .435 .769 r
.37428 .70558 m .37239 .70665 L .37145 .7037 L F
.802 .994 .87 r
.37418 .70653 m .37239 .70665 L .37428 .70558 L F
.86 .89 .856 r
.65034 .54062 m .65359 .53891 L .65242 .53778 L F
.187 .087 .501 r
.53697 .79012 m .53815 .7916 L .5387 .7897 L F
.53697 .79012 m .53664 .79271 L .53815 .7916 L F
.764 .588 .659 r
.56555 .69798 m .56598 .70049 L .563 .70008 L F
.519 .349 .59 r
.56757 .69484 m .56808 .69765 L .56555 .69798 L F
.204 .196 .627 r
.56738 .69924 m .56555 .69798 L .56808 .69765 L F
.56738 .69924 m .56598 .70049 L .56555 .69798 L F
.394 0 0 r
.44797 .65793 m .44835 .65937 L .44528 .65867 L F
.057 0 0 r
.45139 .65643 m .45018 .65757 L .44797 .65793 L F
.675 .386 .476 r
.45018 .65757 m .44835 .65937 L .44797 .65793 L F
.761 .666 .758 r
.66341 .49282 m .66478 .49675 L .66094 .49601 L F
.766 .669 .755 r
.66743 .49344 m .66478 .49675 L .66341 .49282 L F
.571 .133 .17 r
.50693 .7904 m .51026 .79013 L .50921 .79086 L F
.935 .737 .611 r
.51026 .79013 m .51035 .79285 L .50921 .79086 L F
.589 .399 .592 r
.51334 .78986 m .51035 .79285 L .51026 .79013 L F
.804 .99 .882 r
.52734 .81022 m .52915 .80997 L .53044 .80838 L F
.375 .772 .986 r
.32166 .60133 m .32364 .60208 L .32568 .60186 L F
.565 .238 .374 r
.58766 .58612 m .59001 .58759 L .58777 .58767 L F
.57 .233 .358 r
.59036 .5855 m .59001 .58759 L .58766 .58612 L F
.715 .641 .774 r
.59125 .69608 m .59226 .69182 L .59082 .69186 L F
0 .19 .692 r
.65288 .49908 m .65582 .50124 L .65517 .50126 L F
.83 .515 0 r
.6553 .50298 m .65517 .50126 L .65582 .50124 L F
.6553 .50298 m .65586 .50425 L .65517 .50126 L F
.466 .112 .282 r
.44257 .69778 m .44019 .69969 L .44036 .69804 L F
0 .47 .827 r
.31423 .60086 m .3176 .60253 L .31615 .60113 L F
.537 .752 .975 r
.31615 .60113 m .3176 .60253 L .31966 .60213 L F
.855 .617 .578 r
.47667 .67804 m .47661 .68046 L .4786 .68059 L F
.811 .545 .536 r
.47656 .6829 m .4786 .68059 L .47661 .68046 L F
.47656 .6829 m .47976 .68398 L .4786 .68059 L F
.545 0 0 r
.77304 .58843 m .77401 .58908 L .77132 .58769 L F
.958 .621 .251 r
.66467 .52678 m .66613 .5299 L .6651 .52889 L F
0 .116 .627 r
.66613 .5299 m .66747 .53087 L .6651 .52889 L F
.66613 .5299 m .66834 .53185 L .66747 .53087 L F
.545 .509 .767 r
.3738 .68648 m .37526 .68318 L .37237 .68319 L F
.3738 .68648 m .37585 .68606 L .37526 .68318 L F
.468 .446 .751 r
.3738 .68648 m .37638 .68852 L .37585 .68606 L F
.896 .503 .27 r
.66753 .49199 m .66675 .49336 L .66675 .49336 L F
.843 .852 .394 r
.66798 .49119 m .66753 .49199 L .66743 .49344 L F
0 .117 .666 r
.66753 .49199 m .66906 .49528 L .66743 .49344 L F
.896 .503 .27 r
.66753 .49199 m .66675 .49336 L .66841 .49389 L F
.843 .852 .394 r
.66825 .49005 m .66753 .49199 L .66798 .49119 L F
.653 .633 .818 r
.76082 .61687 m .76251 .61373 L .7597 .61443 L F
.76082 .61687 m .76382 .61695 L .76251 .61373 L F
.491 .35 .617 r
.37262 .66945 m .37444 .66644 L .37245 .66688 L F
.729 .708 .831 r
.47716 .64341 m .4784 .64507 L .47511 .64471 L F
.643 .68 .87 r
.48075 .64445 m .4784 .64507 L .47716 .64341 L F
.038 .537 .878 r
.31968 .58958 m .32294 .59085 L .32103 .59073 L F
.644 .401 .536 r
.57521 .68026 m .5788 .67781 L .57679 .67781 L F
0 0 .007 r
.59061 .70942 m .59057 .7108 L .59096 .70853 L F
.713 .405 .455 r
.48862 .68926 m .48488 .69083 L .48497 .68976 L F
.48862 .68926 m .4869 .6917 L .48488 .69083 L F
.732 .429 .468 r
.49057 .6917 m .4869 .6917 L .48862 .68926 L F
.744 .626 .728 r
.49467 .65549 m .49233 .65608 L .49465 .65309 L F
.672 .522 .672 r
.49467 .65549 m .49264 .65826 L .49233 .65608 L F
.49467 .65549 m .49574 .65875 L .49264 .65826 L F
.657 .541 .711 r
.49685 .65249 m .49467 .65549 L .49465 .65309 L F
.49685 .65249 m .49811 .65568 L .49467 .65549 L F
.632 .499 .683 r
.49811 .65817 m .49467 .65549 L .49811 .65568 L F
.49811 .65817 m .49574 .65875 L .49467 .65549 L F
.575 .391 .595 r
.47101 .76153 m .47358 .75877 L .47126 .75934 L F
.648 .108 0 r
.49801 .81517 m .49634 .81388 L .49695 .81477 L F
.329 .811 .877 r
.49463 .81561 m .49801 .81517 L .49695 .81477 L F
.491 .508 .802 r
.38041 .70067 m .38065 .69687 L .37871 .69717 L F
.38041 .70067 m .38242 .70047 L .38065 .69687 L F
.04 .085 .581 r
.38041 .70067 m .38163 .70242 L .38242 .70047 L F
.459 .887 .874 r
.66659 .47999 m .66783 .47905 L .66881 .47927 L F
.497 .464 .75 r
.75166 .5933 m .75273 .59732 L .75038 .59731 L F
.497 .47 .758 r
.75273 .59732 m .75352 .59888 L .75038 .59731 L F
.373 0 0 r
.57 .72236 m .57343 .72288 L .5712 .72236 L F
.13 .678 .766 r
.28948 .65051 m .29303 .6502 L .29201 .65022 L F
.567 .856 .997 r
.29359 .64885 m .29303 .6502 L .29511 .64954 L F
.725 .989 .872 r
.29201 .65022 m .29303 .6502 L .29359 .64885 L F
.694 .602 .75 r
.49328 .64963 m .49113 .65046 L .49015 .647 L F
.666 .572 .739 r
.49465 .65309 m .49113 .65046 L .49328 .64963 L F
.679 .421 .525 r
.52324 .73627 m .52666 .73638 L .5267 .73412 L F
.731 .418 .45 r
.5267 .73412 m .53034 .73619 L .52905 .7345 L F
.5267 .73412 m .52766 .73609 L .53034 .73619 L F
.166 0 0 r
.50949 .81524 m .51337 .81418 L .51166 .81465 L F
0 0 0 r
.51166 .81465 m .51337 .81418 L .51414 .81403 L F
.466 .387 .684 r
.49117 .7862 m .4914 .78987 L .48955 .7901 L F
.461 .362 .656 r
.4914 .78987 m .49184 .79213 L .48955 .7901 L F
.4914 .78987 m .49184 .79213 L .48955 .7901 L F
.733 .412 .437 r
.51856 .80917 m .5202 .80663 L .51843 .80623 L F
.51856 .80917 m .52201 .80912 L .5202 .80663 L F
.536 .745 .972 r
.61117 .54161 m .61001 .54344 L .60997 .54116 L F
.336 .61 .949 r
.70095 .49078 m .70218 .48969 L .7002 .48942 L F
.402 .723 .989 r
.70095 .49078 m .70311 .49068 L .70218 .48969 L F
.521 .292 .508 r
.54551 .7389 m .5475 .73882 L .5478 .73713 L F
.832 .995 .755 r
.59057 .7108 m .58892 .71369 L .58815 .71336 L F
.548 .218 .362 r
.53953 .767 m .53624 .76958 L .53714 .76727 L F
.05 .168 .668 r
.61296 .55053 m .61262 .55299 L .61154 .54918 L F
.93 .966 .676 r
.61296 .55053 m .61149 .55373 L .61262 .55299 L F
.85 .449 .282 r
.61149 .55373 m .61299 .55463 L .61262 .55299 L F
.732 .365 .356 r
.61262 .55299 m .61299 .55463 L .61602 .55489 L F
.55 .279 .457 r
.59036 .5855 m .59233 .58755 L .59001 .58759 L F
.59036 .5855 m .59287 .58527 L .59233 .58755 L F
.703 .74 .88 r
.72027 .49112 m .72189 .49292 L .72051 .48994 L F
.984 .706 .345 r
.71949 .49089 m .71996 .49356 L .72079 .4931 L F
.797 .96 .637 r
.72079 .4931 m .71996 .49356 L .71997 .49356 L F
.933 .555 .221 r
.72027 .49112 m .72079 .4931 L .72163 .49263 L F
.534 .554 .822 r
.72189 .49292 m .72333 .48935 L .72051 .48994 L F
.984 .706 .345 r
.71949 .49089 m .72079 .4931 L .72027 .49112 L F
.797 .96 .637 r
.72079 .4931 m .71997 .49356 L .72198 .49065 L F
.933 .555 .221 r
.72163 .49263 m .72079 .4931 L .72189 .49292 L F
.534 .554 .822 r
.72189 .49292 m .72439 .49257 L .72333 .48935 L F
.365 .831 .778 r
.72189 .49292 m .72334 .49208 L .72439 .49257 L F
.72189 .49292 m .72079 .4931 L .72334 .49208 L F
.422 .208 .48 r
.28139 .61117 m .28111 .61313 L .27941 .6138 L F
.54 .382 .616 r
.28111 .61313 m .2793 .61643 L .27941 .6138 L F
.555 .773 .979 r
.29367 .63423 m .29272 .63554 L .29155 .63484 L F
.29367 .63423 m .29481 .63507 L .29272 .63554 L F
.435 .201 .459 r
.38071 .70844 m .38307 .7057 L .38096 .70614 L F
.561 .227 .359 r
.525 .77864 m .52724 .78012 L .52465 .7802 L F
.525 .77864 m .52723 .77882 L .52724 .78012 L F
.87 .718 .198 r
.66991 .51172 m .67014 .51309 L .67026 .51039 L F
.66991 .51172 m .67026 .51039 L .6726 .5098 L F
.784 .585 .63 r
.55048 .71095 m .55384 .71408 L .55364 .71181 L F
.772 .665 .745 r
.50074 .68338 m .49854 .68633 L .50242 .68644 L F
.634 .627 .826 r
.49854 .68633 m .50288 .68805 L .50242 .68644 L F
.652 .394 .517 r
.50288 .68805 m .50383 .68917 L .50242 .68644 L F
.573 .736 .953 r
.47084 .66569 m .4744 .66673 L .47311 .664 L F
.395 .318 .652 r
.4744 .66673 m .47567 .66381 L .47311 .664 L F
.4744 .66673 m .47592 .66642 L .47567 .66381 L F
.386 .281 .612 r
.4744 .66673 m .47629 .66911 L .47592 .66642 L F
.418 .181 .446 r
.34555 .6275 m .34601 .6253 L .34787 .62468 L F
.501 .755 .987 r
.26512 .64863 m .26673 .64985 L .26873 .64952 L F
.858 .904 .865 r
.75383 .58592 m .75009 .58892 L .75297 .58514 L F
.826 .942 .901 r
.75383 .58592 m .75567 .5828 L .75637 .58339 L F
.75383 .58592 m .75297 .58514 L .75567 .5828 L F
.907 .972 .8 r
.6096 .51309 m .61103 .50951 L .61152 .50989 L F
.943 .922 .557 r
.61152 .50989 m .61103 .50951 L .61221 .50594 L F
.493 .696 .959 r
.75697 .61284 m .75777 .6107 L .75533 .61097 L F
.75697 .61284 m .75895 .61261 L .75777 .6107 L F
.412 .572 .902 r
.75697 .61284 m .7597 .61443 L .75895 .61261 L F
0 0 .25 r
.47532 .77468 m .47448 .77828 L .47527 .77657 L F
.473 .434 .734 r
.27447 .6238 m .27354 .62718 L .27279 .62535 L F
.27447 .6238 m .27539 .62697 L .27354 .62718 L F
.452 .452 .767 r
.27643 .63077 m .27354 .62718 L .27539 .62697 L F
.584 .396 .593 r
.28346 .61063 m .28111 .61313 L .28139 .61117 L F
.988 .757 .496 r
.49267 .76968 m .49051 .76773 L .49264 .76809 L F
.662 .971 .898 r
.70943 .52255 m .70801 .52417 L .71104 .52243 L F
.602 .906 .634 r
.70943 .52255 m .70786 .52411 L .70801 .52417 L F
.575 .407 .617 r
.46652 .7649 m .46882 .7647 L .46881 .76191 L F
.493 .26 .489 r
.46652 .7649 m .46846 .76672 L .46882 .7647 L F
.46652 .7649 m .4663 .76715 L .46846 .76672 L F
.738 .419 .442 r
.49398 .68922 m .49638 .69171 L .49373 .69145 L F
.853 .566 .502 r
.58137 .67984 m .58368 .67823 L .58076 .6782 L F
.58137 .67984 m .584 .68052 L .58368 .67823 L F
.866 .792 .776 r
.63746 .53743 m .63817 .54081 L .63555 .54009 L F
.936 .793 .677 r
.63817 .54081 m .63542 .54264 L .63555 .54009 L F
.63817 .54081 m .63686 .54397 L .63542 .54264 L F
.656 .212 .184 r
.54099 .77738 m .54299 .77637 L .5387 .77582 L F
.622 .951 .779 r
.54465 .77493 m .54299 .77637 L .54099 .77738 L F
.815 .67 .702 r
.59807 .73723 m .59666 .73393 L .59621 .73638 L F
.746 .528 .599 r
.57992 .57474 m .57582 .57662 L .57619 .5743 L F
.57992 .57474 m .5796 .57709 L .57582 .57662 L F
.558 .358 .566 r
.37595 .66018 m .37869 .65804 L .3761 .65823 L F
.893 .819 .768 r
.57934 .56074 m .57613 .56271 L .57839 .56003 L F
.57934 .56074 m .57756 .56359 L .57613 .56271 L F
.351 0 .112 r
.57091 .68589 m .57411 .68372 L .57087 .68389 L F
.57091 .68589 m .57326 .68548 L .57411 .68372 L F
.064 0 .458 r
.57411 .68372 m .57523 .68336 L .57521 .68026 L F
.302 .002 .278 r
.57326 .68548 m .57523 .68336 L .57411 .68372 L F
.335 0 .06 r
.29464 .60448 m .2929 .60663 L .29083 .60698 L F
.203 0 0 r
.29496 .60597 m .29464 .60448 L .29673 .60396 L F
.29496 .60597 m .2929 .60663 L .29464 .60448 L F
.819 .889 .894 r
.49541 .76854 m .49387 .7707 L .49267 .76968 L F
.421 .283 .587 r
.56993 .69673 m .56808 .69765 L .56757 .69484 L F
.749 .241 0 r
.5559 .73309 m .55902 .73617 L .55798 .73466 L F
.666 .542 .704 r
.50163 .66081 m .49957 .66402 L .49942 .66159 L F
.50163 .66081 m .50242 .66402 L .49957 .66402 L F
.744 .633 .737 r
.50568 .67558 m .50328 .67829 L .5017 .67474 L F
.5017 .67474 m .50328 .67829 L .50568 .67558 L F
.35 0 .163 r
.31887 .62983 m .32218 .62727 L .32009 .62769 L F
.384 .199 .503 r
.27622 .62097 m .27471 .61944 L .27661 .61892 L F
.27622 .62097 m .27454 .62161 L .27471 .61944 L F
.573 .802 .986 r
.68235 .47962 m .68129 .48127 L .68029 .48011 L F
.68235 .47962 m .68363 .48088 L .68129 .48127 L F
.726 .655 .779 r
.4834 .66969 m .48707 .6723 L .48577 .66897 L F
.4834 .66969 m .48467 .67265 L .48707 .6723 L F
.71 .539 .655 r
.48467 .67265 m .48467 .67523 L .48707 .6723 L F
.695 .636 .787 r
.48577 .66897 m .48707 .6723 L .48921 .66951 L F
.589 .486 .704 r
.48921 .66951 m .48707 .6723 L .48882 .67189 L F
.46 0 0 r
.51916 .76547 m .51811 .76646 L .51502 .76543 L F
.703 .319 .318 r
.52155 .76511 m .51811 .76646 L .51916 .76547 L F
.969 .647 .307 r
.63203 .48691 m .63272 .48905 L .63339 .48826 L F
.737 .704 .82 r
.494 .7456 m .49437 .74732 L .49758 .74577 L F
.494 .7456 m .49758 .74577 L .49595 .74495 L F
.639 .851 .464 r
.49437 .74732 m .49595 .74495 L .49603 .74722 L F
.49437 .74732 m .49383 .74798 L .49595 .74495 L F
.046 0 0 r
.49603 .74722 m .49383 .74798 L .49437 .74732 L F
.661 .514 .674 r
.48106 .67834 m .48582 .68316 L .48568 .68084 L F
.48106 .67834 m .48343 .68335 L .48582 .68316 L F
.439 .255 .533 r
.55471 .70315 m .55695 .70012 L .55453 .70071 L F
.427 .123 .344 r
.2879 .60957 m .28671 .60806 L .28886 .60784 L F
.2879 .60957 m .28594 .61011 L .28671 .60806 L F
.75 .62 .716 r
.48295 .64143 m .48461 .6449 L .48075 .64445 L F
0 0 0 r
.61568 .52737 m .61491 .52869 L .61358 .52993 L F
.267 .321 .733 r
.61491 .52869 m .61583 .5318 L .61358 .52993 L F
.493 .325 .582 r
.61358 .52993 m .61583 .5318 L .61349 .53246 L F
.978 .839 .636 r
.6652 .51952 m .66532 .52455 L .66397 .52355 L F
.954 .802 .654 r
.66532 .52455 m .66467 .52678 L .66397 .52355 L F
.515 .521 .8 r
.4007 .68305 m .39987 .68658 L .39896 .68328 L F
.4007 .68305 m .40186 .68637 L .39987 .68658 L F
.585 .506 .732 r
.40186 .68637 m .40014 .68897 L .39987 .68658 L F
.795 .663 .717 r
.57698 .56586 m .57842 .56917 L .57508 .56871 L F
.79 .671 .732 r
.57842 .56917 m .57431 .57109 L .57508 .56871 L F
.57842 .56917 m .57682 .57231 L .57431 .57109 L F
.54 .829 .999 r
.29872 .65 m .30081 .64946 L .29723 .64918 L F
.152 0 .326 r
.58597 .71403 m .58299 .71851 L .58473 .71719 L F
.58571 .71612 m .58473 .71719 L .58567 .71649 L F
.58597 .71403 m .58473 .71719 L .58571 .71612 L F
.634 .731 .918 r
.58209 .71982 m .58258 .71954 L .58133 .71747 L F
.58258 .71954 m .5842 .71862 L .58364 .71839 L F
.422 .355 .677 r
.5842 .71862 m .58567 .71649 L .58299 .71851 L F
.251 .523 .913 r
.58133 .71747 m .5842 .71862 L .58299 .71851 L F
.634 .731 .918 r
.58258 .71954 m .58364 .71839 L .58133 .71747 L F
.781 .431 .393 r
.66803 .50127 m .67014 .50384 L .67129 .50195 L F
.819 .481 .416 r
.67014 .50384 m .67236 .50378 L .67129 .50195 L F
.65 .164 .084 r
.66998 .51344 m .6727 .51428 L .67374 .51314 L F
.781 .67 .741 r
.6726 .5098 m .67374 .51314 L .67503 .50975 L F
.444 0 .062 r
.47338 .68923 m .47206 .6908 L .4698 .69087 L F
.598 .153 .163 r
.47545 .69067 m .47206 .6908 L .47338 .68923 L F
.65 .406 .536 r
.61277 .57987 m .60941 .58256 L .6095 .58042 L F
.627 .318 .428 r
.54624 .77481 m .54442 .77297 L .54465 .77493 L F
.54624 .77481 m .54678 .77309 L .54442 .77297 L F
.257 .405 .82 r
.64994 .48871 m .64843 .48983 L .64729 .48721 L F
.64994 .48871 m .65069 .49097 L .64843 .48983 L F
.272 .291 .698 r
.46377 .77828 m .46446 .78152 L .46594 .78056 L F
.294 .336 .735 r
.46446 .78152 m .46669 .78363 L .46594 .78056 L F
.422 .357 .679 r
.46446 .78152 m .4651 .78436 L .46669 .78363 L F
.516 .455 .726 r
.37125 .6753 m .3727 .67179 L .37059 .67361 L F
.37125 .6753 m .3732 .67486 L .3727 .67179 L F
.404 .393 .733 r
.37125 .6753 m .37366 .67741 L .3732 .67486 L F
.529 0 0 r
.54829 .72821 m .5509 .72957 L .55169 .72912 L F
.712 .177 0 r
.5509 .72957 m .55363 .73098 L .55169 .72912 L F
.718 .187 0 r
.55169 .72912 m .55363 .73098 L .55506 .7313 L F
.511 .329 .57 r
.35004 .62161 m .34787 .62468 L .34819 .62227 L F
.688 .487 .61 r
.48004 .76176 m .483 .76209 L .48292 .75928 L F
.487 .312 .568 r
.48292 .75928 m .48498 .75878 L .48518 .75567 L F
.468 .315 .59 r
.48292 .75928 m .4844 .76145 L .48498 .75878 L F
.48292 .75928 m .483 .76209 L .4844 .76145 L F
0 .173 .709 r
.72984 .49255 m .73205 .49549 L .73033 .49426 L F
.864 .415 .052 r
.5694 .74947 m .56983 .74845 L .56871 .7473 L F
.5694 .74947 m .57068 .75019 L .56983 .74845 L F
.78 .286 0 r
.67821 .51752 m .67734 .51578 L .67607 .51501 L F
.475 .117 .278 r
.43489 .70107 m .43442 .70253 L .43221 .70271 L F
.45 .096 .273 r
.43851 .70042 m .43442 .70253 L .43489 .70107 L F
.376 .751 .99 r
.31198 .58827 m .31161 .58928 L .31006 .58809 L F
.31198 .58827 m .31371 .58915 L .31161 .58928 L F
.505 .327 .573 r
.54683 .74535 m .54931 .74511 L .54879 .7423 L F
.088 0 .13 r
.54688 .74773 m .54931 .74511 L .54683 .74535 L F
.684 .344 .393 r
.5365 .78095 m .53285 .78138 L .53416 .78112 L F
.488 .266 .503 r
.35243 .619 m .35004 .62161 L .35039 .61957 L F
.591 .529 .753 r
.74041 .60514 m .74213 .60266 L .7399 .60313 L F
.74041 .60514 m .74278 .60463 L .74213 .60266 L F
.425 .734 .991 r
.35111 .59327 m .35051 .59457 L .34911 .59352 L F
.35111 .59327 m .35281 .59457 L .35051 .59457 L F
.43 .14 .37 r
.73188 .51268 m .72885 .51507 L .72903 .51356 L F
.647 .32 .405 r
.49591 .75544 m .49826 .7557 L .49604 .75368 L F
.621 .329 .452 r
.49604 .75368 m .49826 .7557 L .4986 .75377 L F
.682 .795 .934 r
.77385 .61463 m .77474 .61587 L .77706 .6147 L F
.928 .602 .144 r
.66179 .50757 m .66099 .50652 L .66052 .50408 L F
.997 .774 .432 r
.66179 .50757 m .66082 .50891 L .66099 .50652 L F
.66179 .50757 m .66173 .51014 L .66082 .50891 L F
.47 .054 .167 r
.48902 .74798 m .49199 .74908 L .4915 .74965 L F
.48902 .74798 m .48692 .74976 L .49199 .74908 L F
.073 .204 .696 r
.54854 .71385 m .54953 .71706 L .55049 .71605 L F
.15 .33 .79 r
.54953 .71706 m .55212 .71881 L .55049 .71605 L F
.708 .581 .711 r
.49705 .65021 m .49465 .65309 L .49328 .64963 L F
.667 .521 .676 r
.49685 .65249 m .49465 .65309 L .49705 .65021 L F
.672 .944 .962 r
.73976 .58971 m .7392 .59109 L .73929 .59026 L F
.73976 .58971 m .74282 .58928 L .7392 .59109 L F
.673 .836 .962 r
.65851 .4844 m .65505 .48402 L .65751 .48329 L F
.423 0 .048 r
.65751 .48329 m .66071 .48186 L .65851 .4844 L F
0 0 0 r
.66976 .49789 m .66837 .49924 L .67035 .4965 L F
.011 0 .337 r
.66976 .49789 m .66803 .50127 L .66837 .49924 L F
.423 0 .004 r
.39836 .65243 m .39507 .65314 L .39677 .65396 L F
.443 0 .021 r
.39909 .65399 m .39836 .65243 L .39677 .65396 L F
.39909 .65399 m .40059 .65254 L .39836 .65243 L F
.852 .412 0 r
.5549 .73224 m .55506 .7313 L .55363 .73098 L F
.5549 .73224 m .5559 .73309 L .55506 .7313 L F
.757 .804 .322 r
.57042 .76918 m .57125 .7673 L .57124 .76694 L F
.66 .543 .711 r
.3754 .69495 m .37871 .69717 L .37759 .69424 L F
.3754 .69495 m .3761 .69769 L .37871 .69717 L F
.589 .399 .592 r
.51334 .78986 m .51326 .79288 L .51035 .79285 L F
.342 0 0 r
.51035 .79285 m .51326 .79288 L .51212 .79353 L F
0 0 .408 r
.5095 .79137 m .51035 .79285 L .50968 .7916 L F
.972 .742 .315 r
.50968 .7916 m .51035 .79285 L .51026 .79509 L F
.342 0 0 r
.51035 .79285 m .51212 .79353 L .51026 .79509 L F
.972 .742 .315 r
.50968 .7916 m .51026 .79509 L .51212 .79353 L F
.50968 .7916 m .51212 .79353 L .51208 .79339 L F
.505 0 0 r
.50997 .79197 m .50968 .7916 L .51208 .79339 L F
.5083 .79084 m .50968 .7916 L .50997 .79197 L F
0 0 .408 r
.50921 .79086 m .5095 .79137 L .50968 .7916 L F
.563 .385 .597 r
.53664 .79271 m .53677 .79515 L .53439 .79553 L F
.893 .817 .765 r
.53677 .79515 m .53484 .79812 L .53439 .79553 L F
.53677 .79515 m .53548 .79882 L .53484 .79812 L F
.372 .244 .575 r
.53843 .7973 m .53548 .79882 L .53677 .79515 L F
.462 .116 .293 r
.53661 .79725 m .53439 .79553 L .53484 .79812 L F
.53661 .79725 m .53677 .79515 L .53439 .79553 L F
.563 .385 .597 r
.53664 .79271 m .53677 .79515 L .53439 .79553 L F
.81 .99 .879 r
.5114 .69555 m .51229 .69423 L .5124 .69486 L F
.501 .816 1 r
.51229 .69423 m .51338 .69365 L .5124 .69486 L F
.352 .336 .701 r
.51338 .69365 m .5114 .69555 L .5124 .69486 L F
.525 .858 .995 r
.45438 .64522 m .45669 .64462 L .45792 .6452 L F
.535 .863 .995 r
.45792 .6452 m .45873 .64403 L .46005 .64463 L F
.45792 .6452 m .45669 .64462 L .45873 .64403 L F
.317 .39 .779 r
.45476 .6571 m .45552 .65459 L .4533 .65562 L F
.45476 .6571 m .45839 .65794 L .45552 .65459 L F
0 .476 .789 r
.45968 .65855 m .45839 .65794 L .45476 .6571 L F
.083 0 .022 r
.53487 .74549 m .53413 .74748 L .53241 .74773 L F
.052 0 .01 r
.53585 .74639 m .53487 .74549 L .53784 .74599 L F
.53585 .74639 m .53413 .74748 L .53487 .74549 L F
.358 0 .078 r
.53832 .7443 m .53784 .74599 L .53487 .74549 L F
.588 .467 .682 r
.50931 .65884 m .50617 .65534 L .50807 .65355 L F
.655 .44 .58 r
.51181 .65281 m .50921 .65518 L .50807 .65355 L F
.151 0 .07 r
.51282 .65387 m .50921 .65518 L .51181 .65281 L F
.588 .504 .726 r
.51282 .65387 m .51087 .65731 L .50921 .65518 L F
.4 .305 .632 r
.51087 .65731 m .50807 .65355 L .50921 .65518 L F
.51087 .65731 m .50931 .65884 L .50807 .65355 L F
.386 .09 .334 r
.34289 .62992 m .34364 .62806 L .34555 .6275 L F
.622 .159 .134 r
.50396 .7865 m .50432 .7887 L .50207 .78642 L F
.7 .643 .789 r
.48116 .67238 m .48467 .67265 L .4834 .66969 L F
.475 .124 .291 r
.5257 .76159 m .52826 .76128 L .52919 .75875 L F
.464 .132 .318 r
.52826 .76128 m .53173 .75797 L .52919 .75875 L F
.316 0 0 r
.6369 .50456 m .6359 .50598 L .63355 .50635 L F
.094 0 0 r
.63806 .50512 m .6369 .50456 L .63929 .50432 L F
.63806 .50512 m .6359 .50598 L .6369 .50456 L F
.603 .1 0 r
.46695 .79171 m .47047 .79543 L .46777 .79296 L F
.676 .157 0 r
.46777 .79296 m .47047 .79543 L .46956 .79491 L F
.895 .492 .071 r
.46956 .79491 m .47047 .79543 L .47143 .79828 L F
.415 0 0 r
.66729 .48264 m .66988 .48234 L .66885 .48334 L F
0 .32 .665 r
.66988 .48234 m .67128 .48289 L .66885 .48334 L F
.66988 .48234 m .67264 .48347 L .67128 .48289 L F
0 0 .146 r
.67841 .52366 m .67844 .52148 L .67894 .5203 L F
.255 0 .005 r
.32431 .64555 m .32362 .64433 L .32564 .64374 L F
.32431 .64555 m .32222 .64609 L .32362 .64433 L F
.577 .512 .745 r
.50351 .81394 m .50362 .81578 L .50593 .81518 L F
.435 .661 .956 r
.54183 .75776 m .54102 .75944 L .53982 .75779 L F
.54 .403 .643 r
.54102 .75944 m .54333 .7592 L .54346 .75587 L F
.499 .244 .459 r
.54333 .7592 m .54102 .75944 L .54183 .75776 L F
.54333 .7592 m .54075 .76147 L .54102 .75944 L F
.54102 .75944 m .54075 .76147 L .54333 .7592 L F
.728 .645 .766 r
.5475 .73882 m .54879 .7423 L .55114 .73875 L F
.546 .405 .64 r
.54879 .7423 m .55152 .74239 L .55114 .73875 L F
.309 .198 .56 r
.54879 .7423 m .55064 .74409 L .55152 .74239 L F
.54879 .7423 m .54931 .74511 L .55064 .74409 L F
.425 .646 .95 r
.28999 .63291 m .28989 .63493 L .28783 .63337 L F
.28999 .63291 m .29155 .63484 L .28989 .63493 L F
.88 .962 .63 r
.65267 .52608 m .65094 .52928 L .65126 .52975 L F
.732 .405 .426 r
.64951 .53165 m .65227 .53178 L .65126 .52975 L F
.934 .965 .678 r
.60743 .51604 m .60585 .51916 L .60598 .51704 L F
.908 .983 .76 r
.60743 .51604 m .60892 .5124 L .6096 .51309 L F
.60743 .51604 m .60681 .51569 L .60892 .5124 L F
.959 .945 .662 r
.60743 .51604 m .60598 .51704 L .60681 .51569 L F
.649 .467 .624 r
.46881 .76191 m .47302 .76259 L .47101 .76153 L F
.46881 .76191 m .46882 .7647 L .47302 .76259 L F
.213 .539 .926 r
.53793 .73979 m .5382 .73884 L .53744 .73886 L F
0 0 .508 r
.53793 .73979 m .53915 .74259 L .5382 .73884 L F
.536 .356 .584 r
.53793 .73979 m .53915 .74259 L .53704 .7424 L F
.694 .602 .75 r
.49328 .64963 m .49015 .647 L .49362 .64755 L F
.409 .787 .992 r
.41039 .69663 m .41264 .69641 L .41387 .69708 L F
0 .499 .705 r
.41264 .69641 m .41595 .69685 L .41387 .69708 L F
.941 .602 .355 r
.48778 .80868 m .48866 .8069 L .48671 .80597 L F
.48778 .80868 m .48937 .80894 L .48866 .8069 L F
.815 .486 .432 r
.49142 .80957 m .48866 .8069 L .48937 .80894 L F
.514 .6 .877 r
.46474 .65496 m .46754 .659 L .46891 .65806 L F
.713 .469 .555 r
.5478 .73713 m .5475 .73882 L .55114 .73875 L F
.46 .771 .997 r
.34146 .59259 m .33789 .59187 L .33979 .59168 L F
.389 .79 .985 r
.34206 .59162 m .34146 .59259 L .33979 .59168 L F
.34206 .59162 m .34364 .59233 L .34146 .59259 L F
.49 .05 .128 r
.43742 .66094 m .43383 .66256 L .43518 .66111 L F
.284 .153 .521 r
.51457 .79189 m .51334 .78986 L .51338 .78983 L F
.51457 .79189 m .51326 .79288 L .51334 .78986 L F
.709 .586 .715 r
.50395 .65797 m .50017 .65534 L .50378 .65571 L F
.50395 .65797 m .50158 .65854 L .50017 .65534 L F
.729 .635 .754 r
.50617 .65534 m .50395 .65797 L .50378 .65571 L F
.773 .614 .682 r
.50017 .65534 m .50158 .65854 L .49811 .65817 L F
.759 .622 .707 r
.50163 .66081 m .49811 .65817 L .50158 .65854 L F
.304 .185 .548 r
.67267 .48406 m .67107 .488 L .67326 .4861 L F
.447 .413 .727 r
.67107 .488 m .67296 .48816 L .67326 .4861 L F
.828 .977 .886 r
.75827 .5815 m .75637 .58339 L .75729 .58105 L F
.835 .984 .872 r
.75729 .58105 m .75637 .58339 L .75567 .5828 L F
.778 .704 .782 r
.67478 .50699 m .6726 .5098 L .67503 .50975 L F
.921 .673 .546 r
.54359 .80039 m .54454 .80059 L .54328 .80293 L F
.907 .972 .8 r
.6096 .51309 m .60892 .5124 L .61103 .50951 L F
.645 .965 .905 r
.70803 .51435 m .7112 .51271 L .71088 .51332 L F
.084 .176 .663 r
.71069 .51005 m .71155 .51308 L .71241 .51111 L F
0 0 0 r
.70978 .51403 m .7112 .51271 L .70888 .51392 L F
.70978 .51403 m .70888 .51392 L .70803 .51435 L F
.684 .918 .594 r
.71153 .51209 m .7112 .51271 L .70978 .51403 L F
.71241 .51111 m .7112 .51271 L .71153 .51209 L F
.645 .965 .905 r
.71088 .51332 m .7112 .51271 L .71155 .51308 L F
.803 .999 .799 r
.71155 .51308 m .7112 .51271 L .71241 .51111 L F
.684 .918 .594 r
.71241 .51111 m .70978 .51403 L .71252 .51355 L F
.414 .011 .163 r
.71278 .51582 m .71252 .51355 L .70978 .51403 L F
0 .217 .739 r
.71092 .51417 m .70978 .51403 L .70873 .5122 L F
.71278 .51582 m .70978 .51403 L .71092 .51417 L F
.432 .821 .987 r
.56153 .77295 m .56371 .77289 L .56043 .77245 L F
.985 .706 .351 r
.56371 .77289 m .56266 .77456 L .56043 .77245 L F
.56371 .77289 m .56368 .77545 L .56266 .77456 L F
.485 .176 .367 r
.36003 .61094 m .3616 .61241 L .35954 .61284 L F
.36003 .61094 m .36223 .61064 L .3616 .61241 L F
.634 .731 .918 r
.58209 .71982 m .58494 .72017 L .5842 .71862 L F
.518 .807 .998 r
.58494 .72017 m .58736 .71973 L .58587 .71884 L F
.317 .534 .905 r
.5842 .71862 m .58494 .72017 L .58587 .71884 L F
.374 .013 .217 r
.62998 .49197 m .62765 .49258 L .62796 .49133 L F
.146 .645 .91 r
.30449 .64973 m .30645 .64991 L .30293 .64911 L F
.866 .668 .632 r
.63267 .52686 m .62994 .52645 L .63075 .52337 L F
.908 .826 .754 r
.63267 .52686 m .62941 .52864 L .62994 .52645 L F
.63267 .52686 m .63054 .52973 L .62941 .52864 L F
.656 .436 .573 r
.63267 .52686 m .63352 .52953 L .63054 .52973 L F
.251 .392 .81 r
.63075 .52337 m .6344 .52726 L .63267 .52686 L F
0 .205 .723 r
.63328 .52677 m .63267 .52686 L .6344 .52726 L F
.63328 .52677 m .63503 .52863 L .63267 .52686 L F
.351 .261 .612 r
.63503 .52863 m .63352 .52953 L .63267 .52686 L F
.496 .165 .336 r
.56738 .69924 m .56531 .70048 L .5654 .70046 L F
.037 0 .401 r
.56377 .7014 m .563 .70008 L .5654 .70046 L F
.496 .165 .336 r
.56531 .70048 m .56377 .7014 L .5654 .70046 L F
.157 0 0 r
.56551 .70042 m .5654 .70046 L .563 .70008 L F
.56598 .70049 m .5654 .70046 L .56551 .70042 L F
.592 .948 .863 r
.56738 .69924 m .5654 .70046 L .56598 .70049 L F
0 0 .222 r
.58922 .70037 m .59073 .6968 L .59058 .69764 L F
.45 .855 .967 r
.6375 .48182 m .6371 .48139 L .63456 .48201 L F
.807 .44 0 r
.6375 .48182 m .63842 .48421 L .6371 .48139 L F
.677 .969 .924 r
.6375 .48182 m .63915 .47997 L .64023 .48104 L F
.6375 .48182 m .6371 .48139 L .63915 .47997 L F
.05 .614 .783 r
.70674 .49089 m .70523 .4907 L .70311 .49068 L F
0 0 0 r
.70896 .48978 m .70523 .4907 L .70674 .49089 L F
.301 0 .132 r
.6178 .52639 m .61491 .52869 L .61568 .52737 L F
.779 .772 .847 r
.36572 .70857 m .36666 .71088 L .3698 .70809 L F
.607 .82 .982 r
.46365 .64498 m .46005 .64463 L .46235 .64422 L F
.593 .859 .994 r
.46584 .64427 m .46365 .64498 L .46235 .64422 L F
.756 .981 .736 r
.49106 .79819 m .48976 .79874 L .49003 .79845 L F
.195 0 0 r
.49106 .79819 m .49019 .79841 L .48534 .79819 L F
.682 .662 .824 r
.48534 .79819 m .49019 .79841 L .48835 .79548 L F
.756 .981 .736 r
.49106 .79819 m .49019 .79841 L .49138 .79698 L F
.682 .662 .824 r
.49019 .79841 m .4904 .79841 L .4903 .79827 L F
.49019 .79841 m .4903 .79827 L .48835 .79548 L F
.659 .654 .834 r
.48835 .79548 m .4903 .79827 L .4914 .79691 L F
.756 .981 .736 r
.49138 .79698 m .49111 .79727 L .4914 .79691 L F
.659 .654 .834 r
.4903 .79827 m .4904 .79841 L .4914 .79691 L F
.756 .981 .736 r
.49111 .79727 m .49003 .79845 L .4914 .79691 L F
.49019 .79841 m .49003 .79845 L .49138 .79698 L F
.195 0 0 r
.49106 .79819 m .4904 .79841 L .49019 .79841 L F
.883 .7 .65 r
.49106 .79819 m .48734 .80013 L .48976 .79874 L F
.49106 .79819 m .49015 .80057 L .48734 .80013 L F
.767 .957 .644 r
.49106 .79819 m .4904 .79841 L .4914 .79691 L F
.771 .953 .631 r
.49106 .79819 m .49309 .79527 L .49369 .7975 L F
.207 .181 .608 r
.51002 .78345 m .50799 .78145 L .51008 .78111 L F
.51002 .78345 m .50872 .78431 L .50799 .78145 L F
.689 .603 .754 r
.65224 .52149 m .65064 .52264 L .64859 .51918 L F
.597 .432 .628 r
.65224 .52149 m .65003 .52426 L .65064 .52264 L F
0 0 0 r
.67047 .49688 m .67035 .4965 L .66906 .49528 L F
.67047 .49688 m .66976 .49789 L .67035 .4965 L F
.488 0 0 r
.633 .51642 m .63246 .51582 L .63188 .51554 L F
.63358 .51688 m .63246 .51582 L .633 .51642 L F
.198 0 0 r
.63231 .51565 m .63246 .51582 L .63402 .51548 L F
.63029 .51584 m .63246 .51582 L .63231 .51565 L F
.798 .338 .147 r
.63475 .51755 m .63402 .51548 L .63246 .51582 L F
.63475 .51755 m .63595 .51787 L .63402 .51548 L F
.628 .375 .516 r
.63402 .51548 m .63595 .51787 L .63775 .51618 L F
.732 .618 .732 r
.47792 .67189 m .48116 .67238 L .48006 .66949 L F
.734 .609 .718 r
.47792 .67189 m .47892 .67523 L .48116 .67238 L F
.66 .581 .756 r
.48006 .66949 m .48116 .67238 L .4834 .66969 L F
.548 .165 .268 r
.53664 .79271 m .53928 .7928 L .53768 .79482 L F
0 0 .441 r
.53664 .79271 m .53768 .79482 L .53815 .7916 L F
.53664 .79271 m .53677 .79515 L .53768 .79482 L F
.548 .165 .268 r
.53664 .79271 m .53768 .79482 L .53677 .79515 L F
.971 .667 .284 r
.53786 .80077 m .53908 .80389 L .53826 .80357 L F
.688 .681 .838 r
.54015 .80023 m .53908 .80389 L .53786 .80077 L F
.54015 .80023 m .54204 .80307 L .53908 .80389 L F
.195 0 0 r
.53908 .80389 m .53972 .80476 L .53826 .80357 L F
.53908 .80389 m .54204 .80307 L .53972 .80476 L F
.822 .629 .641 r
.57682 .57231 m .57619 .5743 L .57431 .57109 L F
.804 .567 .579 r
.47594 .77078 m .47898 .77263 L .47905 .77019 L F
.809 .582 .594 r
.47599 .76983 m .47594 .77078 L .47905 .77019 L F
.751 .239 0 r
.47599 .76983 m .47898 .77263 L .47905 .77019 L F
.522 .648 .913 r
.47714 .77316 m .47898 .77263 L .47747 .77171 L F
.47664 .77215 m .47747 .77171 L .47594 .77078 L F
.47714 .77316 m .47747 .77171 L .47664 .77215 L F
.757 .615 .701 r
.47898 .77263 m .47594 .77266 L .47594 .77078 L F
.751 .239 0 r
.47599 .76983 m .47768 .77193 L .47898 .77263 L F
.75 .578 .662 r
.47768 .77193 m .47905 .77019 L .47898 .77263 L F
.47814 .77134 m .48044 .76961 L .47905 .77019 L F
.47768 .77193 m .4788 .77099 L .47814 .77134 L F
.4788 .77099 m .48044 .76961 L .47814 .77134 L F
.429 .261 .551 r
.47712 .77555 m .47898 .77263 L .47714 .77316 L F
.719 .572 .688 r
.50042 .65294 m .49811 .65568 L .49685 .65249 L F
.738 .6 .704 r
.50017 .65534 m .49811 .65568 L .50042 .65294 L F
.68 .743 .899 r
.67296 .53795 m .67639 .53866 L .67547 .53719 L F
.666 .749 .912 r
.67547 .53719 m .67639 .53866 L .67871 .53751 L F
.438 .595 .909 r
.48518 .75567 m .48783 .75653 L .48672 .75537 L F
.573 .384 .587 r
.48518 .75567 m .48709 .75752 L .48783 .75653 L F
.48518 .75567 m .48498 .75878 L .48709 .75752 L F
.332 0 .011 r
.4984 .76962 m .50193 .76762 L .49868 .76791 L F
.4984 .76962 m .50062 .76932 L .50193 .76762 L F
.863 .501 .362 r
.50193 .76762 m .50062 .76932 L .50242 .7697 L F
.666 .536 .696 r
.50193 .76762 m .50468 .76746 L .50417 .76466 L F
0 0 0 r
.50242 .7697 m .50468 .76746 L .50193 .76762 L F
.721 .981 .771 r
.76088 .58434 m .75971 .5861 L .76115 .58472 L F
.728 .99 .856 r
.75787 .58658 m .75971 .5861 L .76088 .58434 L F
.61 .136 .103 r
.68588 .53156 m .68314 .52983 L .68217 .53115 L F
.374 .813 .956 r
.6823 .54104 m .68558 .54102 L .68459 .54063 L F
.455 .793 .999 r
.68558 .54102 m .6871 .53988 L .68459 .54063 L F
.68558 .54102 m .68814 .54075 L .6871 .53988 L F
.186 0 0 r
.68558 .54102 m .68754 .54122 L .68814 .54075 L F
.588 .802 .981 r
.67962 .50566 m .67825 .50746 L .68072 .50695 L F
.67962 .50566 m .67825 .50746 L .68072 .50695 L F
.346 .297 .66 r
.46534 .77312 m .4669 .77322 L .46659 .76941 L F
.344 .314 .681 r
.46534 .77312 m .46742 .77516 L .4669 .77322 L F
.407 .322 .648 r
.46534 .77312 m .46582 .77577 L .46742 .77516 L F
.479 0 0 r
.41755 .64941 m .41994 .64976 L .42107 .64931 L F
.413 0 0 r
.42107 .64931 m .41994 .64976 L .42345 .64951 L F
.739 .482 .54 r
.50468 .76746 m .50759 .76985 L .50736 .76762 L F
.403 .214 .508 r
.46377 .77828 m .46569 .77803 L .46582 .77577 L F
.272 .291 .698 r
.46377 .77828 m .46594 .78056 L .46569 .77803 L F
0 0 0 r
.64817 .50462 m .64637 .50759 L .64776 .50564 L F
0 0 .194 r
.64562 .50943 m .64776 .50564 L .64637 .50759 L F
.722 .5 .589 r
.52175 .78151 m .52 .78313 L .51895 .78166 L F
.52153 .78355 m .52144 .78441 L .52089 .78392 L F
.177 .035 .438 r
.52365 .78278 m .52144 .78441 L .52175 .78151 L F
.472 .499 .804 r
.52 .78313 m .52144 .78441 L .52046 .78411 L F
.448 .515 .835 r
.52046 .78411 m .52144 .78441 L .52365 .78278 L F
0 0 0 r
.52073 .78452 m .52049 .78416 L .52365 .78278 L F
.52049 .78416 m .52046 .78411 L .52085 .78394 L F
.52049 .78416 m .52085 .78394 L .52365 .78278 L F
.722 .5 .589 r
.52175 .78151 m .52153 .78355 L .52 .78313 L F
.52153 .78355 m .52089 .78392 L .52 .78313 L F
.177 .035 .438 r
.52365 .78278 m .52175 .78151 L .52465 .7802 L F
.456 .141 .342 r
.4322 .69187 m .43436 .69149 L .43535 .68877 L F
.479 .16 .348 r
.43436 .69149 m .43756 .68859 L .43535 .68877 L F
.271 .382 .793 r
.67871 .53751 m .67985 .54064 L .67985 .53879 L F
.257 .668 .966 r
.67985 .54064 m .68121 .54011 L .67985 .53879 L F
.67985 .54064 m .6823 .54104 L .68121 .54011 L F
.901 .893 .812 r
.53016 .74762 m .52903 .74818 L .52886 .74651 L F
.668 .611 .782 r
.53136 .74461 m .53016 .74762 L .52886 .74651 L F
.53136 .74461 m .53241 .74773 L .53016 .74762 L F
.323 0 0 r
.53241 .74773 m .52903 .74818 L .53016 .74762 L F
.609 .178 .198 r
.64184 .5135 m .64465 .51423 L .64347 .51242 L F
.943 .594 .19 r
.47971 .80029 m .47923 .79785 L .47836 .79743 L F
.085 .616 .867 r
.47923 .79785 m .48155 .79809 L .47836 .79743 L F
.493 .167 .342 r
.45042 .69493 m .44742 .69661 L .44823 .69481 L F
.026 0 0 r
.5191 .7419 m .51764 .74224 L .51646 .74228 L F
.706 .651 .793 r
.51911 .74015 m .5191 .7419 L .52198 .74015 L F
.252 .269 .684 r
.51911 .74015 m .52091 .7413 L .5191 .7419 L F
.24 .75 .727 r
.52091 .7413 m .51764 .74224 L .5191 .7419 L F
.591 .394 .584 r
.47435 .6806 m .47661 .68046 L .47667 .67804 L F
.708 .584 .715 r
.47673 .67583 m .47667 .67804 L .47892 .67523 L F
.514 .507 .786 r
.49117 .7862 m .48829 .78452 L .49064 .78407 L F
.549 .578 .836 r
.50973 .64868 m .509 .65267 L .50759 .64885 L F
.50973 .64868 m .51147 .65192 L .509 .65267 L F
.602 .487 .695 r
.38229 .7141 m .38424 .71103 L .38195 .71184 L F
.38229 .7141 m .38516 .71493 L .38424 .71103 L F
.655 .969 .898 r
.70943 .52255 m .71104 .52243 L .71298 .52113 L F
.91 .505 .179 r
.48671 .80597 m .48631 .80432 L .48526 .80467 L F
.663 .837 .966 r
.49595 .74495 m .49758 .74577 L .49925 .74472 L F
.519 .379 .631 r
.37404 .66134 m .3762 .66328 L .37595 .66018 L F
.37404 .66134 m .37412 .66403 L .3762 .66328 L F
.687 .221 .14 r
.5049 .74265 m .50373 .74406 L .50135 .74217 L F
.676 .2 .114 r
.50413 .74362 m .50439 .74376 L .5049 .74265 L F
.683 .235 .18 r
.50413 .74362 m .50373 .74406 L .50439 .74376 L F
.50135 .74217 m .50373 .74406 L .50413 .74362 L F
.05 0 0 r
.50598 .74313 m .5042 .74356 L .50499 .74269 L F
.50598 .74313 m .5049 .74265 L .50701 .74379 L F
0 0 0 r
.50456 .74347 m .50598 .74313 L .50596 .74117 L F
.50439 .74376 m .50598 .74313 L .50456 .74347 L F
.05 0 0 r
.50598 .74313 m .50413 .74362 L .5042 .74356 L F
0 0 0 r
.50439 .74376 m .50373 .74406 L .50598 .74313 L F
.05 0 0 r
.50598 .74313 m .50382 .74402 L .50413 .74362 L F
.50499 .74269 m .50413 .74362 L .5049 .74265 L F
.50382 .74402 m .50373 .74406 L .5049 .74265 L F
.676 .2 .114 r
.50135 .74217 m .50413 .74362 L .5049 .74265 L F
0 0 0 r
.5049 .74265 m .50596 .74117 L .50692 .73886 L F
.5049 .74265 m .50439 .74376 L .50596 .74117 L F
.441 .19 .436 r
.35746 .61338 m .35762 .6143 L .35478 .61611 L F
.453 .197 .435 r
.35943 .61448 m .35746 .61338 L .35954 .61284 L F
.35943 .61448 m .35762 .6143 L .35746 .61338 L F
0 0 0 r
.40844 .67075 m .40796 .66993 L .40976 .66882 L F
.40844 .67075 m .40683 .6716 L .40796 .66993 L F
.339 .494 .866 r
.50584 .78774 m .50693 .7904 L .50813 .78877 L F
.437 .632 .937 r
.50693 .7904 m .50921 .79086 L .50813 .78877 L F
0 .146 .623 r
.57 .72236 m .57347 .72518 L .57343 .72288 L F
0 0 0 r
.50713 .81206 m .50866 .81021 L .50654 .81257 L F
0 0 .106 r
.50713 .81206 m .50654 .81257 L .50593 .81518 L F
.459 .79 .999 r
.28795 .58488 m .28752 .58609 L .28598 .58493 L F
.28795 .58488 m .28955 .58579 L .28752 .58609 L F
.646 .157 .075 r
.53471 .77461 m .5352 .77313 L .53175 .77271 L F
.94 .575 .199 r
.53563 .77507 m .5352 .77313 L .53471 .77461 L F
.807 .487 .449 r
.5387 .77582 m .5352 .77313 L .53563 .77507 L F
0 0 .346 r
.59775 .71629 m .59805 .71932 L .5976 .71743 L F
.773 .614 .682 r
.50017 .65534 m .49811 .65817 L .49811 .65568 L F
.5 .114 .239 r
.44803 .68593 m .45029 .68595 L .4516 .68375 L F
.498 .112 .238 r
.4516 .68375 m .45346 .68495 L .45374 .68341 L F
.4516 .68375 m .45029 .68595 L .45346 .68495 L F
.081 0 0 r
.64501 .50422 m .64434 .50438 L .64166 .5043 L F
.779 .465 .456 r
.64434 .50438 m .64431 .50438 L .64166 .5043 L F
.64431 .50438 m .64074 .50419 L .64166 .5043 L F
.132 0 0 r
.64018 .50426 m .64166 .5043 L .63929 .50432 L F
.6427 .50408 m .64166 .5043 L .64018 .50426 L F
.226 0 0 r
.64501 .50422 m .64166 .5043 L .6427 .50408 L F
.852 .433 .231 r
.64376 .52516 m .64281 .52549 L .64294 .52324 L F
.64376 .52516 m .64445 .52624 L .64281 .52549 L F
.518 .723 .966 r
.64646 .52669 m .64445 .52624 L .64376 .52516 L F
.715 .592 .717 r
.78103 .59367 m .77792 .59115 L .77818 .59356 L F
.78103 .59367 m .78181 .59181 L .77792 .59115 L F
.722 .5 .588 r
.77985 .59703 m .78103 .59367 L .77818 .59356 L F
.77985 .59703 m .78082 .59653 L .78103 .59367 L F
.724 .419 .463 r
.54582 .76898 m .54186 .76751 L .54548 .76852 L F
.37 .835 .89 r
.5083 .81517 m .50949 .81524 L .51166 .81465 L F
.847 .777 .783 r
.37145 .7037 m .36878 .70354 L .37028 .70244 L F
.37145 .7037 m .36797 .70539 L .36878 .70354 L F
.37145 .7037 m .36989 .70618 L .36797 .70539 L F
.748 .239 0 r
.37028 .70244 m .37252 .70358 L .37145 .7037 L F
.421 .435 .769 r
.37428 .70558 m .37145 .7037 L .37252 .70358 L F
.453 .333 .626 r
.25453 .64959 m .25433 .65267 L .25257 .65285 L F
0 .452 .829 r
.25334 .65417 m .25257 .65285 L .25433 .65267 L F
.25334 .65417 m .25292 .65446 L .25257 .65285 L F
.759 .622 .707 r
.50163 .66081 m .49942 .66159 L .49811 .65817 L F
.553 .373 .591 r
.50577 .66115 m .50242 .66402 L .50163 .66081 L F
.237 .636 .959 r
.67344 .47867 m .67227 .47927 L .67101 .47868 L F
.67344 .47867 m .67447 .47966 L .67227 .47927 L F
.067 0 0 r
.71623 .50776 m .71764 .50815 L .71843 .50685 L F
.71623 .50776 m .7153 .50898 L .71764 .50815 L F
.35 0 .051 r
.25523 .59066 m .25742 .59034 L .25891 .58859 L F
.102 0 0 r
.25742 .59034 m .26112 .58837 L .25891 .58859 L F
.518 .859 .994 r
.69177 .48999 m .69309 .48865 L .69073 .48899 L F
.69177 .48999 m .694 .48933 L .69309 .48865 L F
.743 .525 .599 r
.50802 .75539 m .51088 .75345 L .50737 .75383 L F
.831 .373 .127 r
.46695 .79171 m .46759 .7943 L .46545 .79206 L F
.46695 .79171 m .46777 .79296 L .46759 .7943 L F
.682 .777 .923 r
.49906 .6377 m .50016 .6391 L .4967 .63866 L F
.721 .745 .871 r
.50016 .6391 m .49791 .63951 L .4967 .63866 L F
.433 .66 .956 r
.49906 .6377 m .50112 .6377 L .50016 .6391 L F
.595 .876 .993 r
.50016 .6391 m .50112 .6377 L .50244 .63837 L F
.50016 .6391 m .50112 .6377 L .50244 .63837 L F
.64 .574 .765 r
.50356 .6419 m .50016 .6391 L .50244 .63837 L F
0 .452 .829 r
.25334 .65417 m .25468 .65506 L .25292 .65446 L F
.452 .397 .705 r
.25292 .65446 m .25468 .65506 L .25314 .65562 L F
.48 .802 1 r
.32294 .59085 m .32504 .59048 L .32653 .59132 L F
.351 .755 .983 r
.32504 .59048 m .32859 .59107 L .32653 .59132 L F
0 .07 .6 r
.32897 .6025 m .32973 .60289 L .32737 .6019 L F
.32897 .6025 m .33047 .60396 L .32973 .60289 L F
.415 .124 .36 r
.33834 .63294 m .341 .63063 L .34041 .63251 L F
.512 .275 .493 r
.34289 .62992 m .34041 .63251 L .341 .63063 L F
.91 .982 .738 r
.60459 .52065 m .60598 .51704 L .60585 .51916 L F
.896 .688 .614 r
.36989 .70618 m .3698 .70809 L .36797 .70539 L F
.505 .816 1 r
.49725 .68302 m .50074 .68338 L .49673 .68334 L F
.758 .657 .75 r
.49502 .68583 m .49725 .68302 L .49547 .68392 L F
.596 .539 .761 r
.73895 .59973 m .7399 .60313 L .74213 .60266 L F
.727 .716 .84 r
.53832 .7443 m .5324 .74362 L .53704 .7424 L F
.537 .58 .845 r
.53915 .74259 m .53832 .7443 L .53704 .7424 L F
.53915 .74259 m .54021 .74399 L .53832 .7443 L F
.76 .47 .494 r
.54021 .74399 m .53784 .74599 L .53832 .7443 L F
.694 .645 .796 r
.77792 .59115 m .78181 .59181 L .78077 .58863 L F
.585 .506 .732 r
.40186 .68637 m .40235 .68837 L .40014 .68897 L F
.369 0 0 r
.54858 .78066 m .5467 .78119 L .54566 .78053 L F
.193 0 .295 r
.54566 .78053 m .54669 .78281 L .54458 .78292 L F
.54566 .78053 m .5467 .78119 L .54669 .78281 L F
.721 .669 .798 r
.76251 .61373 m .76382 .61695 L .76487 .61517 L F
.449 .2 .443 r
.5471 .80113 m .54993 .79861 L .54874 .80014 L F
.564 .633 .878 r
.5458 .7992 m .5471 .80113 L .54874 .80014 L F
.354 .826 .881 r
.71692 .49916 m .71367 .49965 L .71483 .50005 L F
.085 0 0 r
.44528 .65867 m .44165 .65984 L .44317 .6583 L F
.157 0 .056 r
.25314 .65562 m .25468 .65506 L .25279 .6562 L F
.16 .683 .877 r
.71728 .51299 m .71981 .51303 L .7193 .51271 L F
.194 0 0 r
.71833 .51346 m .71981 .51303 L .71728 .51299 L F
.71833 .51346 m .71728 .51299 L .7193 .51271 L F
.785 .619 .674 r
.47993 .66681 m .4776 .66962 L .48006 .66949 L F
.47993 .66681 m .4776 .66962 L .48006 .66949 L F
0 0 .234 r
.48092 .66553 m .47993 .66681 L .48217 .66633 L F
.662 .568 .739 r
.48006 .66949 m .48217 .66633 L .47993 .66681 L F
0 0 .234 r
.48092 .66553 m .48006 .66949 L .47993 .66681 L F
.512 .041 .073 r
.77111 .60558 m .77468 .60514 L .77242 .60513 L F
.254 0 0 r
.42649 .70462 m .4233 .70614 L .42415 .70512 L F
.466 .218 .453 r
.24074 .59958 m .2428 .59907 L .24321 .59699 L F
.421 .165 .417 r
.2428 .59907 m .24524 .5965 L .24321 .59699 L F
.315 0 0 r
.43897 .64732 m .44287 .64708 L .44071 .64737 L F
.709 .671 .811 r
.4967 .63866 m .49446 .64085 L .4933 .63802 L F
.748 .745 .849 r
.49791 .63951 m .49446 .64085 L .4967 .63866 L F
.591 .237 .337 r
.49826 .7557 m .50164 .75364 L .4986 .75377 L F
.49826 .7557 m .50062 .75571 L .50164 .75364 L F
.721 .381 .402 r
.50062 .75571 m .50407 .75607 L .50164 .75364 L F
.49 .225 .44 r
.35478 .61611 m .3546 .61863 L .35243 .619 L F
.442 .189 .434 r
.35762 .6143 m .3546 .61863 L .35478 .61611 L F
.824 .663 .684 r
.53425 .80047 m .53749 .80408 L .53231 .80313 L F
.806 .46 .401 r
.53231 .80313 m .53749 .80408 L .53583 .80541 L F
.204 .461 .881 r
.53826 .80357 m .53749 .80408 L .53425 .80047 L F
0 0 0 r
.53583 .80541 m .53749 .80408 L .53826 .80357 L F
.606 .616 .834 r
.7597 .61443 m .76157 .61218 L .75895 .61261 L F
.7597 .61443 m .76251 .61373 L .76157 .61218 L F
.524 .657 .92 r
.50896 .79684 m .50874 .79812 L .50789 .79667 L F
0 0 0 r
.5087 .79866 m .50874 .79812 L .50896 .79684 L F
.28 .65 .968 r
.30304 .58653 m .30247 .58744 L .30129 .58641 L F
.30304 .58653 m .30453 .58769 L .30247 .58744 L F
.622 .926 .972 r
.58543 .69509 m .58609 .69519 L .588 .69477 L F
0 0 .222 r
.58922 .70037 m .59034 .69916 L .59073 .6968 L F
.402 .667 .968 r
.58922 .70037 m .59141 .70072 L .59034 .69916 L F
.7 .827 .943 r
.76589 .57556 m .76623 .57688 L .76293 .57688 L F
.276 .762 .917 r
.76765 .57636 m .76623 .57688 L .76589 .57556 L F
.76765 .57636 m .76876 .57664 L .76623 .57688 L F
0 .37 .794 r
.77354 .57846 m .77151 .5779 L .7715 .57781 L F
.294 0 0 r
.5365 .78095 m .54028 .78133 L .53849 .78132 L F
.612 .066 0 r
.53849 .78132 m .54028 .78133 L .54243 .78271 L F
.72 .987 .879 r
.50973 .73689 m .50692 .73886 L .50833 .73785 L F
.437 .016 .139 r
.50692 .73886 m .50822 .74075 L .50833 .73785 L F
.50692 .73886 m .50596 .74117 L .50822 .74075 L F
.543 .59 .852 r
.5287 .76979 m .53006 .76792 L .52804 .76789 L F
.5287 .76979 m .53076 .76942 L .53006 .76792 L F
.605 .539 .754 r
.52942 .773 m .53076 .76942 L .5287 .76979 L F
.503 .372 .636 r
.39965 .67493 m .39988 .67742 L .39785 .67783 L F
.434 .369 .685 r
.40011 .67949 m .39785 .67783 L .39988 .67742 L F
.40011 .67949 m .39825 .68117 L .39785 .67783 L F
.518 .669 .931 r
.69798 .48982 m .69883 .48745 L .69619 .48899 L F
.69798 .48982 m .7002 .48942 L .69883 .48745 L F
.556 .931 .821 r
.69341 .53785 m .69289 .53777 L .6897 .53959 L F
.556 .929 .804 r
.69341 .53785 m .6965 .53603 L .69487 .53653 L F
.559 .933 .82 r
.69487 .53653 m .69289 .53777 L .69341 .53785 L F
.622 .434 .607 r
.59258 .70313 m .59477 .70273 L .59401 .70077 L F
0 0 .322 r
.59401 .70077 m .59437 .70136 L .59141 .70072 L F
.181 0 .117 r
.59676 .69945 m .59477 .70273 L .59401 .70077 L F
0 0 .322 r
.59401 .70077 m .59477 .70273 L .59437 .70136 L F
.21 0 .357 r
.59649 .69705 m .59676 .69945 L .59401 .70077 L F
.272 0 .182 r
.24831 .59377 m .24913 .59525 L .25028 .59318 L F
.24831 .59377 m .24731 .59586 L .24913 .59525 L F
.018 .568 .829 r
.36674 .70288 m .36878 .70354 L .36503 .70274 L F
.758 .64 .73 r
.36878 .70354 m .36583 .70581 L .36503 .70274 L F
.492 .818 1 r
.36797 .70539 m .36583 .70581 L .36878 .70354 L F
.661 .916 .977 r
.36674 .70288 m .36878 .70354 L .37028 .70244 L F
.356 .637 .96 r
.51147 .65192 m .51252 .65151 L .51181 .65281 L F
.151 0 .07 r
.51282 .65387 m .51181 .65281 L .51252 .65151 L F
.526 .582 .854 r
.36679 .60243 m .36328 .59977 L .36543 .5992 L F
.54 .558 .822 r
.36884 .60203 m .36679 .60243 L .36543 .5992 L F
.629 .565 .764 r
.36884 .60203 m .36777 .60558 L .36679 .60243 L F
.284 .784 .852 r
.31024 .65038 m .31065 .64986 L .3085 .65023 L F
.31024 .65038 m .31246 .64991 L .31065 .64986 L F
.868 .466 .005 r
.4742 .76674 m .47599 .76983 L .47552 .76756 L F
.794 .489 .473 r
.47552 .76756 m .47905 .77019 L .47828 .76733 L F
.47552 .76756 m .47599 .76983 L .47905 .77019 L F
.479 0 0 r
.41811 .6672 m .4145 .66763 L .41587 .66737 L F
.445 .126 .329 r
.47121 .68373 m .47346 .68329 L .47435 .6806 L F
.754 .528 .588 r
.47346 .68329 m .47661 .68046 L .47435 .6806 L F
.273 .52 .907 r
.6438 .48139 m .6431 .48291 L .6425 .48107 L F
.6438 .48139 m .64596 .48386 L .6431 .48291 L F
0 0 0 r
.51052 .80903 m .50866 .81021 L .50713 .81206 L F
.915 .794 .317 r
.78071 .58549 m .78117 .58586 L .78049 .58502 L F
.78071 .58549 m .78077 .58863 L .78117 .58586 L F
.509 .102 .204 r
.45374 .69376 m .45249 .69614 L .45042 .69493 L F
.487 .228 .446 r
.4562 .69191 m .45606 .69323 L .45374 .69376 L F
.482 .075 .191 r
.45475 .69591 m .45374 .69376 L .45606 .69323 L F
.45475 .69591 m .45249 .69614 L .45374 .69376 L F
.569 .815 .991 r
.36186 .59879 m .36543 .5992 L .36328 .59977 L F
.451 .877 .774 r
.45194 .64575 m .45286 .64499 L .45438 .64522 L F
.45194 .64575 m .45075 .64611 L .45286 .64499 L F
.281 0 0 r
.51421 .74195 m .51258 .74268 L .51079 .74238 L F
.102 0 0 r
.5158 .74202 m .51421 .74195 L .51646 .74228 L F
.5158 .74202 m .51258 .74268 L .51421 .74195 L F
.73 .613 .727 r
.4926 .67224 m .48832 .67763 L .49111 .67613 L F
.268 0 0 r
.55836 .70594 m .5549 .70558 L .55471 .70315 L F
.55836 .70594 m .55882 .70624 L .5549 .70558 L F
.599 .499 .713 r
.5549 .70558 m .55803 .70611 L .55679 .70291 L F
.55803 .70611 m .55882 .70624 L .55848 .70567 L F
.55803 .70611 m .55848 .70567 L .55679 .70291 L F
0 0 .204 r
.55942 .70472 m .55836 .70594 L .561 .70339 L F
.55929 .70484 m .55918 .70497 L .55942 .70472 L F
.55918 .70497 m .55836 .70594 L .55942 .70472 L F
.55929 .70484 m .55882 .70624 L .55836 .70594 L F
.927 .784 .683 r
.57756 .56359 m .57698 .56586 L .57613 .56271 L F
.871 .555 .449 r
.48982 .68513 m .49366 .68854 L .4945 .68569 L F
.275 .143 .513 r
.49366 .68854 m .49502 .68583 L .4945 .68569 L F
.564 .361 .564 r
.52905 .7345 m .53185 .73385 L .53193 .73111 L F
.578 .373 .566 r
.53193 .73111 m .53436 .73327 L .53438 .73078 L F
.53193 .73111 m .53185 .73385 L .53436 .73327 L F
.368 0 .037 r
.416 .70824 m .4148 .70976 L .41265 .70994 L F
.329 0 .053 r
.41814 .70773 m .4148 .70976 L .416 .70824 L F
.529 .517 .787 r
.50451 .63833 m .50356 .6419 L .50244 .63837 L F
.50451 .63833 m .5053 .64167 L .50356 .6419 L F
.522 .451 .717 r
.5053 .64167 m .50624 .6431 L .50356 .6419 L F
.632 .615 .815 r
.56263 .70246 m .561 .70339 L .55926 .69982 L F
.582 .234 .344 r
.56263 .70246 m .55929 .70484 L .561 .70339 L F
.69 .914 .971 r
.68384 .48592 m .68253 .48759 L .68495 .48706 L F
.68384 .48592 m .68168 .48682 L .68253 .48759 L F
.553 .373 .591 r
.50577 .66115 m .50531 .66385 L .50242 .66402 L F
.639 .431 .584 r
.50518 .66604 m .50242 .66402 L .50531 .66385 L F
.50518 .66604 m .50284 .66638 L .50242 .66402 L F
.784 .71 .782 r
.60661 .54529 m .60806 .54837 L .60887 .54247 L F
.60806 .54837 m .60835 .54897 L .60838 .5485 L F
.60806 .54837 m .60838 .5485 L .60839 .54843 L F
.60806 .54837 m .60839 .54843 L .60887 .54247 L F
.643 .511 .687 r
.60842 .54845 m .60915 .54868 L .61154 .54918 L F
.655 .652 .835 r
.61059 .54751 m .60867 .54817 L .60923 .54676 L F
.665 .761 .922 r
.60872 .54811 m .60867 .54817 L .61059 .54751 L F
.424 .392 .719 r
.60887 .54247 m .60839 .54843 L .60999 .54477 L F
.61045 .54355 m .60999 .54477 L .6105 .54359 L F
.60887 .54247 m .60999 .54477 L .61045 .54355 L F
.60839 .54843 m .60841 .54844 L .6105 .54359 L F
.60838 .5485 m .60867 .54817 L .6105 .54359 L F
.655 .652 .835 r
.61059 .54751 m .60923 .54676 L .60872 .54811 L F
.665 .761 .922 r
.60867 .54817 m .61154 .54918 L .61059 .54751 L F
.60809 .54837 m .60843 .54845 L .60867 .54817 L F
.60843 .54845 m .61154 .54918 L .60867 .54817 L F
.424 .392 .719 r
.6105 .54359 m .60867 .54817 L .61137 .54418 L F
.655 .652 .835 r
.61059 .54751 m .60889 .54862 L .6086 .54819 L F
.424 .392 .719 r
.60839 .54843 m .60838 .5485 L .60841 .54844 L F
.643 .511 .687 r
.60807 .54837 m .60853 .54851 L .60842 .54845 L F
.784 .71 .782 r
.60806 .54837 m .60839 .54843 L .60806 .54837 L F
.655 .652 .835 r
.6086 .54819 m .60806 .54837 L .60661 .54529 L F
.424 .392 .719 r
.60838 .5485 m .60835 .54897 L .60866 .54819 L F
.60866 .54818 m .60866 .54819 L .60867 .54817 L F
.60838 .5485 m .60866 .54819 L .60866 .54818 L F
.643 .511 .687 r
.60797 .54835 m .60887 .55219 L .60955 .55043 L F
.60885 .54868 m .60955 .55043 L .61005 .54913 L F
.655 .652 .835 r
.60889 .54862 m .60835 .54897 L .60806 .54837 L F
.689 .741 .891 r
.60861 .54855 m .60835 .54897 L .60889 .54862 L F
.643 .511 .687 r
.60797 .54835 m .60955 .55043 L .60885 .54868 L F
.655 .652 .835 r
.60889 .54862 m .60807 .54837 L .6086 .54819 L F
.60807 .54837 m .60806 .54837 L .6086 .54819 L F
.665 .761 .922 r
.60802 .54836 m .60807 .54837 L .60798 .54834 L F
.60807 .54837 m .61154 .54918 L .60809 .54837 L F
.60807 .54837 m .60809 .54837 L .60798 .54834 L F
.643 .511 .687 r
.60854 .54852 m .61005 .54913 L .61064 .54915 L F
.60802 .54836 m .60882 .54866 L .60854 .54852 L F
.60882 .54866 m .61005 .54913 L .60854 .54852 L F
.424 .392 .719 r
.60867 .54817 m .60853 .54851 L .60935 .54738 L F
.60853 .54851 m .60835 .54897 L .60861 .54855 L F
.60853 .54851 m .60861 .54855 L .60935 .54738 L F
.60867 .54817 m .60935 .54738 L .61137 .54418 L F
.655 .652 .835 r
.60872 .54811 m .60661 .54529 L .60797 .54835 L F
.60923 .54676 m .6086 .54819 L .60661 .54529 L F
.60867 .54817 m .6086 .54819 L .60923 .54676 L F
.60923 .54676 m .60661 .54529 L .60872 .54811 L F
.689 .741 .891 r
.61137 .54418 m .60861 .54855 L .61059 .54751 L F
.60861 .54855 m .60889 .54862 L .61059 .54751 L F
.643 .511 .687 r
.60915 .54868 m .61064 .54915 L .61119 .54916 L F
.60915 .54868 m .61119 .54916 L .61154 .54918 L F
.60853 .54851 m .61064 .54915 L .60842 .54845 L F
.665 .761 .922 r
.60798 .54834 m .60809 .54837 L .60867 .54817 L F
.60798 .54834 m .60867 .54817 L .60872 .54811 L F
.643 .511 .687 r
.60802 .54836 m .61064 .54915 L .60807 .54837 L F
.60797 .54835 m .60798 .54835 L .60802 .54836 L F
.60798 .54835 m .61005 .54913 L .60802 .54836 L F
.665 .761 .922 r
.60797 .54835 m .60802 .54836 L .60798 .54834 L F
.422 .627 .938 r
.61059 .54751 m .61154 .54918 L .61247 .54729 L F
.562 .56 .809 r
.61005 .54913 m .61247 .54729 L .61154 .54918 L F
.522 .345 .582 r
.61364 .54644 m .61381 .54882 L .61154 .54918 L F
.05 .168 .668 r
.61296 .55053 m .61154 .54918 L .61381 .54882 L F
.337 .801 .932 r
.71878 .51963 m .71739 .51917 L .71499 .51948 L F
.091 .649 .757 r
.7212 .51903 m .71739 .51917 L .71878 .51963 L F
0 0 0 r
.6888 .52969 m .68588 .53156 L .68792 .53107 L F
.68999 .52809 m .6888 .52969 L .68792 .53107 L F
.842 .766 .777 r
.48295 .64143 m .47989 .64183 L .48152 .64048 L F
.48295 .64143 m .48075 .64445 L .47989 .64183 L F
.735 .864 .941 r
.485 .64045 m .48295 .64143 L .48152 .64048 L F
.588 .467 .682 r
.50931 .65884 m .50698 .65981 L .50617 .65534 L F
0 .082 .642 r
.65145 .49211 m .6516 .49335 L .65069 .49097 L F
.579 .341 .519 r
.59569 .58274 m .59562 .58502 L .59287 .58527 L F
.679 .423 .528 r
.59569 .58274 m .59781 .5851 L .59562 .58502 L F
.666 .423 .544 r
.59786 .58284 m .59781 .5851 L .59569 .58274 L F
.02 0 .38 r
.73929 .59026 m .73749 .59394 L .7397 .59259 L F
.386 .441 .795 r
.73749 .59394 m .74059 .59587 L .7397 .59259 L F
.492 .428 .713 r
.73839 .59633 m .74059 .59587 L .73749 .59394 L F
0 0 0 r
.64817 .50462 m .64776 .50564 L .64501 .50422 L F
.613 .34 .48 r
.52612 .7759 m .52894 .77567 L .52942 .773 L F
.605 .539 .754 r
.52942 .773 m .53175 .77271 L .53076 .76942 L F
.558 .29 .466 r
.52942 .773 m .53157 .77373 L .53175 .77271 L F
.52942 .773 m .52894 .77567 L .53157 .77373 L F
.282 .39 .796 r
.71845 .48345 m .71699 .48483 L .7158 .48162 L F
.59 .036 0 r
.71804 .48594 m .71949 .48689 L .71942 .48683 L F
.71804 .48594 m .71942 .48683 L .71699 .48483 L F
.71804 .48594 m .71699 .48483 L .71845 .48345 L F
.772 .983 .905 r
.71845 .48345 m .716 .48463 L .71804 .48594 L F
.716 .48463 m .71487 .48517 L .71804 .48594 L F
.841 .671 .671 r
.65551 .51459 m .6523 .51216 L .65313 .51294 L F
.77 .349 .249 r
.53563 .77507 m .53758 .77718 L .5387 .77582 L F
.496 0 0 r
.53758 .77718 m .54099 .77738 L .5387 .77582 L F
.427 0 0 r
.72079 .50146 m .71954 .50081 L .71958 .50074 L F
.107 .411 .861 r
.72079 .50146 m .72272 .50146 L .71954 .50081 L F
.206 0 0 r
.72272 .50146 m .71949 .5009 L .71954 .50081 L F
.71949 .5009 m .71879 .50078 L .71954 .50081 L F
.427 0 0 r
.71958 .50074 m .71954 .50081 L .71692 .49916 L F
.107 .411 .861 r
.72079 .50146 m .72367 .50316 L .72272 .50146 L F
.548 .692 .934 r
.69213 .48244 m .6901 .48308 L .68936 .48164 L F
.501 .614 .896 r
.68865 .47988 m .68721 .48188 L .68571 .47969 L F
.68865 .47988 m .68936 .48164 L .68721 .48188 L F
.778 .991 .886 r
.77792 .59115 m .77859 .58941 L .77704 .59033 L F
.77792 .59115 m .78077 .58863 L .77859 .58941 L F
.083 .594 .887 r
.55238 .7696 m .55502 .77025 L .55378 .76953 L F
.835 .365 .055 r
.55326 .77182 m .55238 .7696 L .55136 .7704 L F
.803 .679 .728 r
.54896 .77013 m .54894 .77262 L .54769 .76935 L F
.749 .654 .755 r
.54894 .77262 m .55136 .7704 L .54769 .76935 L F
.658 .946 .7 r
.5498 .77135 m .55136 .7704 L .54894 .77262 L F
0 0 0 r
.55166 .7705 m .55136 .7704 L .5498 .77135 L F
.835 .365 .055 r
.55294 .77099 m .55505 .77284 L .55253 .76979 L F
.719 .489 .578 r
.55238 .7696 m .55505 .77284 L .55502 .77025 L F
.835 .365 .055 r
.55294 .77099 m .55253 .76979 L .55247 .76984 L F
.55423 .77237 m .55505 .77284 L .55294 .77099 L F
.55326 .77182 m .55136 .7704 L .55378 .76953 L F
0 0 0 r
.55378 .76953 m .55212 .77013 L .55166 .7705 L F
.55212 .77013 m .55136 .7704 L .55166 .7705 L F
.835 .365 .055 r
.55247 .76984 m .55253 .76979 L .55238 .7696 L F
.55326 .77182 m .55423 .77237 L .55294 .77099 L F
.545 .529 .788 r
.55006 .76667 m .55076 .76868 L .55378 .76953 L F
.55076 .76868 m .55136 .7704 L .55212 .77013 L F
.083 .594 .887 r
.55238 .7696 m .55378 .76953 L .55136 .7704 L F
.545 .529 .788 r
.55076 .76868 m .55212 .77013 L .55378 .76953 L F
.957 .653 .416 r
.56532 .74203 m .56571 .74441 L .56703 .74485 L F
.79 .3 0 r
.56757 .74661 m .56703 .74485 L .56571 .74441 L F
.56757 .74661 m .56871 .7473 L .56703 .74485 L F
.868 .658 .128 r
.59723 .70788 m .5973 .71032 L .59773 .71159 L F
0 0 .345 r
.5973 .71032 m .59687 .71425 L .59773 .71159 L F
.724 .612 .732 r
.59443 .73688 m .59621 .73638 L .59666 .73393 L F
.629 .661 .862 r
.70203 .48503 m .69967 .48564 L .69877 .48385 L F
.65 .406 .536 r
.61277 .57987 m .61281 .58189 L .60941 .58256 L F
.589 .331 .494 r
.61508 .57982 m .61281 .58189 L .61277 .57987 L F
.724 .958 .676 r
.55587 .77799 m .55867 .77517 L .55896 .7756 L F
.323 0 0 r
.53241 .74773 m .53136 .74849 L .52903 .74818 L F
0 0 0 r
.53413 .74748 m .53136 .74849 L .53241 .74773 L F
.591 .027 0 r
.51334 .76978 m .51536 .77136 L .51654 .77064 L F
0 .032 .593 r
.51778 .77154 m .51837 .77283 L .51654 .77064 L F
.51778 .77154 m .51654 .77064 L .51536 .77136 L F
.852 .717 .713 r
.5942 .72759 m .59765 .72556 L .59615 .72457 L F
.5942 .72759 m .59605 .72852 L .59765 .72556 L F
.958 .828 .672 r
.59765 .72556 m .59707 .7226 L .59615 .72457 L F
.397 .333 .668 r
.4651 .78436 m .46521 .78734 L .46737 .78612 L F
.458 .462 .775 r
.46521 .78734 m .46835 .78955 L .46737 .78612 L F
.598 .418 .609 r
.55254 .70587 m .5549 .70558 L .55471 .70315 L F
.55471 .70315 m .5549 .70558 L .55254 .70587 L F
.439 .255 .533 r
.55471 .70315 m .55679 .70291 L .55695 .70012 L F
.599 .499 .713 r
.5549 .70558 m .55679 .70291 L .55471 .70315 L F
.448 .306 .595 r
.33425 .61369 m .33621 .61319 L .33613 .61041 L F
.272 .025 .346 r
.33407 .61585 m .33621 .61319 L .33425 .61369 L F
.831 .688 .705 r
.55694 .78798 m .55662 .79018 L .55536 .78637 L F
.112 0 0 r
.51496 .81093 m .51418 .81031 L .51261 .81112 L F
.51496 .81093 m .51641 .80963 L .51418 .81031 L F
.441 .408 .726 r
.4007 .68305 m .39825 .68117 L .40011 .67949 L F
.4007 .68305 m .39896 .68328 L .39825 .68117 L F
.397 .333 .668 r
.4651 .78436 m .46737 .78612 L .46669 .78363 L F
.81 .99 .879 r
.5114 .69555 m .50889 .69691 L .51229 .69423 L F
.554 .26 .422 r
.5114 .69555 m .50889 .69939 L .50889 .69691 L F
.5114 .69555 m .51127 .69938 L .50889 .69939 L F
.352 .336 .701 r
.51338 .69365 m .51419 .69627 L .5114 .69555 L F
.503 .259 .478 r
.51419 .69627 m .51127 .69938 L .5114 .69555 L F
.689 .603 .754 r
.65224 .52149 m .64859 .51918 L .65111 .5185 L F
.884 .823 .782 r
.57647 .5845 m .57643 .58881 L .57473 .58753 L F
.181 0 0 r
.57643 .58881 m .57518 .58974 L .57473 .58753 L F
.57643 .58881 m .57707 .58944 L .57518 .58974 L F
.57643 .58881 m .57861 .58833 L .57707 .58944 L F
0 0 .251 r
.57157 .75284 m .57172 .75344 L .57068 .75019 L F
.945 .694 .228 r
.57133 .75522 m .57172 .75344 L .57157 .75284 L F
.57133 .75522 m .5719 .75589 L .57172 .75344 L F
.239 .741 .68 r
.3143 .6489 m .31832 .64754 L .31643 .64864 L F
.42 0 .035 r
.32046 .64699 m .31643 .64864 L .31832 .64754 L F
.541 .273 .458 r
.4562 .69191 m .45831 .69329 L .45606 .69323 L F
.857 .745 .738 r
.64261 .49453 m .64096 .49514 L .64084 .49272 L F
.354 .826 .881 r
.71692 .49916 m .71599 .4991 L .71583 .49933 L F
.577 0 0 r
.71692 .49916 m .71706 .49994 L .71599 .4991 L F
0 .227 .747 r
.71706 .49994 m .7162 .4988 L .71599 .4991 L F
.7162 .4988 m .71503 .49725 L .71599 .4991 L F
.354 .826 .881 r
.71583 .49933 m .71599 .4991 L .71367 .49965 L F
.577 0 0 r
.71692 .49916 m .71954 .50081 L .71706 .49994 L F
.427 .127 .351 r
.54894 .77262 m .54678 .77309 L .54624 .77481 L F
.509 .328 .57 r
.32726 .62218 m .32942 .62185 L .32934 .61898 L F
.313 .078 .388 r
.32726 .62218 m .32867 .62345 L .32942 .62185 L F
.32726 .62218 m .32689 .62428 L .32867 .62345 L F
0 .024 .584 r
.51001 .78608 m .50941 .78695 L .50872 .78431 L F
.04 .33 .812 r
.51208 .78871 m .50941 .78695 L .51001 .78608 L F
.877 .832 .799 r
.49511 .68822 m .49716 .68928 L .49854 .68633 L F
.589 .357 .532 r
.6178 .57736 m .61769 .57966 L .61508 .57982 L F
.401 .204 .495 r
.61962 .57881 m .6178 .57736 L .61985 .57667 L F
.61962 .57881 m .61769 .57966 L .6178 .57736 L F
.765 .725 .815 r
.72069 .51031 m .71981 .51303 L .72303 .51291 L F
.555 .867 .995 r
.72303 .51291 m .71981 .51303 L .72231 .5122 L F
.596 .109 0 r
.72303 .51291 m .72231 .5122 L .72069 .51031 L F
0 .439 .858 r
.39478 .71687 m .39527 .71641 L .39323 .71661 L F
.39478 .71687 m .3966 .71772 L .39527 .71641 L F
.608 .669 .883 r
.69749 .48105 m .69642 .48438 L .69534 .48159 L F
.69749 .48105 m .69877 .48385 L .69642 .48438 L F
.343 .754 .98 r
.29373 .58531 m .29314 .58614 L .29173 .58566 L F
.29373 .58531 m .2953 .58602 L .29314 .58614 L F
0 0 0 r
.54874 .80014 m .54993 .79861 L .55097 .79764 L F
.644 .401 .536 r
.57521 .68026 m .57762 .68086 L .5788 .67781 L F
.59 .344 .512 r
.5788 .67781 m .58137 .67984 L .58076 .6782 L F
.5788 .67781 m .57762 .68086 L .58137 .67984 L F
.742 .696 .808 r
.25117 .64716 m .25164 .644 L .25031 .64546 L F
.25117 .64716 m .2526 .6437 L .25164 .644 L F
.601 .069 0 r
.25211 .64857 m .25117 .64716 L .25021 .6469 L F
.723 .811 .92 r
.54833 .75314 m .54872 .75427 L .55098 .75331 L F
.55098 .75331 m .54872 .75427 L .54833 .75314 L F
.578 .394 .595 r
.32934 .61898 m .33188 .6188 L .33176 .61642 L F
.527 .341 .572 r
.32934 .61898 m .33162 .62131 L .33188 .6188 L F
.32934 .61898 m .32942 .62185 L .33162 .62131 L F
.719 .596 .718 r
.48882 .67189 m .48832 .67763 L .4926 .67224 L F
.41 .739 .992 r
.33622 .75233 m .3379 .75335 L .33557 .75344 L F
.33622 .75233 m .3379 .75335 L .33557 .75344 L F
.253 0 0 r
.41809 .69648 m .4203 .69607 L .42181 .69459 L F
.2 0 0 r
.4203 .69607 m .42408 .69447 L .42181 .69459 L F
.036 .568 .857 r
.69092 .50085 m .69419 .50178 L .69374 .50137 L F
.625 .574 .777 r
.69433 .50389 m .69374 .50137 L .69419 .50178 L F
.45 .834 .986 r
.55378 .76953 m .55502 .77025 L .5569 .76972 L F
.094 .005 .453 r
.55502 .77025 m .55711 .7727 L .5569 .76972 L F
.55502 .77025 m .55505 .77284 L .55712 .77282 L F
.745 .763 .867 r
.55685 .77338 m .55688 .77392 L .55742 .77256 L F
.094 .005 .453 r
.55715 .77275 m .5572 .77272 L .55719 .77262 L F
.745 .763 .867 r
.55715 .77275 m .55742 .77256 L .55831 .77033 L F
.55685 .77338 m .55742 .77256 L .55715 .77275 L F
.094 .005 .453 r
.55711 .7727 m .55715 .77275 L .55719 .77262 L F
.55715 .77275 m .55721 .77282 L .5572 .77272 L F
.55715 .77275 m .55712 .77282 L .55721 .77282 L F
.55502 .77025 m .55712 .77282 L .55715 .77275 L F
.745 .763 .867 r
.55831 .77033 m .55688 .77392 L .56011 .77074 L F
.094 .005 .453 r
.55711 .7727 m .55719 .77262 L .5569 .76972 L F
.859 .667 .643 r
.5564 .77399 m .55709 .77544 L .55688 .77392 L F
.09 0 .328 r
.55614 .77374 m .55505 .77284 L .55466 .775 L F
.55658 .77336 m .55616 .77321 L .55614 .77374 L F
.55616 .77321 m .55505 .77284 L .55614 .77374 L F
.55692 .77306 m .55669 .77299 L .55658 .77336 L F
.55698 .77302 m .55695 .77302 L .55692 .77306 L F
.55695 .77302 m .55669 .77299 L .55692 .77306 L F
.859 .667 .643 r
.55569 .77409 m .5564 .77399 L .55682 .77298 L F
.5564 .77399 m .55688 .77392 L .55684 .77322 L F
.5564 .77399 m .55684 .77322 L .55682 .77298 L F
.09 0 .328 r
.55669 .77299 m .55505 .77284 L .55658 .77336 L F
.55721 .77282 m .55712 .77282 L .55698 .77302 L F
.55712 .77282 m .55505 .77284 L .55698 .77302 L F
.932 .687 .546 r
.55466 .775 m .55505 .77284 L .55326 .77182 L F
.44 .471 .795 r
.55702 .77277 m .55466 .775 L .55326 .77182 L F
.745 .763 .867 r
.55684 .77322 m .55712 .77282 L .55717 .77271 L F
.732 .322 .272 r
.55378 .76953 m .5569 .76972 L .55719 .77262 L F
.55711 .77263 m .55719 .77262 L .5572 .77272 L F
.55378 .76953 m .55719 .77262 L .55711 .77263 L F
.859 .667 .643 r
.55569 .77409 m .55682 .77298 L .55681 .77267 L F
.732 .322 .272 r
.55702 .77264 m .5572 .77272 L .55709 .7727 L F
.55378 .76953 m .55711 .77263 L .55702 .77264 L F
.55711 .77263 m .5572 .77272 L .55702 .77264 L F
.859 .667 .643 r
.55403 .77432 m .55569 .77409 L .55599 .77277 L F
.732 .322 .272 r
.55378 .76953 m .55709 .7727 L .55326 .77182 L F
.745 .763 .867 r
.55684 .77322 m .55717 .77271 L .5571 .7727 L F
.732 .322 .272 r
.55709 .7727 m .55721 .77282 L .55702 .77277 L F
.55709 .7727 m .55702 .77277 L .55326 .77182 L F
.44 .471 .795 r
.55698 .77302 m .55466 .775 L .55702 .77277 L F
.745 .763 .867 r
.55698 .77281 m .55684 .77322 L .55699 .77291 L F
.55665 .76995 m .55682 .77297 L .55698 .77281 L F
.55682 .77297 m .55684 .77322 L .55698 .77281 L F
.859 .667 .643 r
.55488 .7729 m .55599 .77277 L .55665 .76995 L F
.55403 .77432 m .55599 .77277 L .55488 .7729 L F
.55599 .77277 m .55681 .77267 L .55665 .76995 L F
.55569 .77409 m .55681 .77267 L .55599 .77277 L F
.745 .763 .867 r
.5571 .7727 m .55717 .77271 L .55831 .77033 L F
.732 .322 .272 r
.55709 .7727 m .5572 .77272 L .55721 .77282 L F
.44 .471 .795 r
.55721 .77282 m .55698 .77302 L .55702 .77277 L F
.745 .763 .867 r
.55746 .77013 m .55699 .77291 L .55831 .77033 L F
.55665 .76995 m .55699 .77291 L .55746 .77013 L F
.862 .533 .428 r
.55605 .77596 m .55609 .77507 L .55403 .77432 L F
.55599 .77599 m .55605 .77596 L .55532 .77536 L F
.55527 .77538 m .55532 .77536 L .55403 .77432 L F
.55599 .77599 m .55532 .77536 L .55527 .77538 L F
.55599 .77599 m .55403 .77432 L .55539 .77515 L F
.871 .983 .839 r
.55294 .77625 m .55539 .77515 L .5534 .77499 L F
.55237 .7778 m .55502 .77547 L .55294 .77625 L F
.55502 .77547 m .55539 .77515 L .55294 .77625 L F
.862 .533 .428 r
.55605 .77596 m .55709 .77544 L .55609 .77507 L F
.859 .667 .643 r
.55403 .77432 m .55609 .77507 L .5564 .77399 L F
.55609 .77507 m .55709 .77544 L .5564 .77399 L F
.745 .763 .867 r
.55684 .77322 m .55685 .77338 L .55712 .77282 L F
.615 .694 .9 r
.47371 .64303 m .47511 .64471 L .47156 .64361 L F
.737 .731 .846 r
.47716 .64341 m .47511 .64471 L .47371 .64303 L F
.899 .629 .121 r
.5719 .75589 m .57222 .75839 L .57267 .75905 L F
1 .799 .483 r
.57222 .75839 m .57281 .76145 L .57267 .75905 L F
.354 .089 .366 r
.33834 .63294 m .33774 .63537 L .33582 .63583 L F
.435 .16 .396 r
.33996 .63474 m .33834 .63294 L .34041 .63251 L F
.33996 .63474 m .33774 .63537 L .33834 .63294 L F
.431 .252 .536 r
.33585 .60801 m .33752 .60989 L .33773 .60737 L F
.311 .233 .604 r
.33613 .61041 m .33752 .60989 L .33585 .60801 L F
0 .253 .656 r
.64123 .48581 m .64054 .48534 L .63842 .48421 L F
0 .34 .713 r
.64123 .48581 m .64193 .48603 L .64054 .48534 L F
.75 .65 .751 r
.59443 .73688 m .59666 .73393 L .59313 .73362 L F
.968 .883 .695 r
.49264 .76809 m .49382 .76544 L .49445 .76461 L F
0 .165 .65 r
.65414 .49978 m .65288 .49908 L .65209 .49763 L F
.65414 .49978 m .65582 .50124 L .65288 .49908 L F
.504 .242 .45 r
.50833 .73785 m .51204 .73844 L .50973 .73689 L F
.744 .526 .599 r
.50822 .74075 m .51204 .73844 L .50833 .73785 L F
.368 0 .077 r
.40838 .65173 m .41061 .65144 L .41213 .64955 L F
.33 0 0 r
.41061 .65144 m .41422 .64986 L .41213 .64955 L F
.861 .622 .576 r
.51251 .7619 m .51212 .76422 L .51107 .76011 L F
.732 .618 .732 r
.47792 .67189 m .48006 .66949 L .4776 .66962 L F
.343 0 .027 r
.42635 .69428 m .42865 .69393 L .43002 .69228 L F
.32 0 .022 r
.42865 .69393 m .4322 .69187 L .43002 .69228 L F
.594 .635 .862 r
.75024 .58629 m .74784 .58802 L .74707 .58726 L F
.75024 .58629 m .75009 .58892 L .74784 .58802 L F
.719 .403 .443 r
.48783 .75653 m .49026 .75834 L .49036 .7564 L F
.691 .473 .587 r
.49026 .75834 m .49289 .75608 L .49036 .7564 L F
.742 .347 .304 r
.49961 .69203 m .49648 .69322 L .49638 .69171 L F
.49961 .69203 m .49988 .69368 L .49648 .69322 L F
.714 .327 .314 r
.49961 .69203 m .50188 .6941 L .49988 .69368 L F
.474 .853 .984 r
.30283 .63392 m .30671 .63393 L .30309 .63461 L F
.30283 .63392 m .30509 .63343 L .30671 .63393 L F
.541 .014 0 r
.30509 .63343 m .30835 .63334 L .30671 .63393 L F
.753 .509 .562 r
.64285 .51819 m .63964 .52018 L .63983 .51903 L F
.719 .597 .719 r
.48882 .67189 m .4926 .67224 L .49182 .6701 L F
.67 .635 .806 r
.4926 .67224 m .49417 .66764 L .49182 .6701 L F
.4926 .67224 m .49496 .67234 L .49417 .66764 L F
.683 .547 .694 r
.4926 .67224 m .49712 .67348 L .49496 .67234 L F
.633 .964 .868 r
.55463 .79094 m .55662 .79018 L .55783 .78918 L F
.629 .565 .764 r
.36884 .60203 m .36985 .6047 L .36777 .60558 L F
.53 .328 .552 r
.36985 .6047 m .36723 .60719 L .36777 .60558 L F
.753 .963 .935 r
.64235 .49254 m .64084 .49272 L .64135 .49185 L F
.951 .943 .736 r
.64235 .49254 m .64307 .4885 L .64359 .48932 L F
.64235 .49254 m .64135 .49185 L .64307 .4885 L F
.23 0 .112 r
.72653 .5157 m .72593 .51758 L .724 .51757 L F
.28 0 .129 r
.72827 .51668 m .72653 .5157 L .72885 .51507 L F
.72827 .51668 m .72593 .51758 L .72653 .5157 L F
.07 .625 .813 r
.48006 .66949 m .47629 .66911 L .4776 .66962 L F
.48006 .66949 m .4801 .66922 L .47629 .66911 L F
0 0 .234 r
.48092 .66553 m .48087 .66795 L .48006 .66949 L F
.647 .827 .409 r
.48087 .66795 m .4801 .66922 L .48006 .66949 L F
.662 .568 .739 r
.48006 .66949 m .4834 .66969 L .48217 .66633 L F
.592 .22 .304 r
.25551 .64867 m .25946 .64633 L .25752 .64782 L F
.25551 .64867 m .25642 .6473 L .25946 .64633 L F
.058 .619 .797 r
.26182 .6464 m .26029 .64619 L .25946 .64633 L F
0 0 0 r
.25946 .64633 m .26029 .64619 L .25752 .64782 L F
.352 .628 .956 r
.52804 .76789 m .53006 .76792 L .52886 .76689 L F
.487 .321 .581 r
.24078 .60206 m .2428 .59907 L .24074 .59958 L F
.645 .465 .626 r
.55241 .70864 m .5549 .70558 L .55254 .70587 L F
.55241 .70864 m .55528 .70851 L .5549 .70558 L F
.161 .046 .463 r
.55254 .70587 m .55404 .70763 L .5549 .70558 L F
.55254 .70587 m .55241 .70864 L .55404 .70763 L F
.408 0 .095 r
.46178 .69132 m .46049 .69321 L .45831 .69329 L F
.463 .062 .193 r
.46408 .69095 m .46049 .69321 L .46178 .69132 L F
.876 .479 .275 r
.51895 .78166 m .52 .78313 L .51801 .7831 L F
.486 0 0 r
.28148 .65266 m .28025 .6528 L .27818 .65205 L F
.431 .873 .848 r
.2823 .65199 m .28148 .65266 L .28362 .6526 L F
.2823 .65199 m .28025 .6528 L .28148 .65266 L F
.392 .771 .991 r
.44355 .64719 m .44507 .64688 L .44644 .64767 L F
.004 0 0 r
.44346 .64735 m .44665 .64656 L .44507 .64688 L F
.488 .811 1 r
.44726 .64641 m .44644 .64767 L .44507 .64688 L F
.004 0 0 r
.44665 .64656 m .44726 .64641 L .44507 .64688 L F
.392 .771 .991 r
.44287 .64708 m .44507 .64688 L .44355 .64719 L F
.488 .811 1 r
.44726 .64641 m .44881 .64726 L .44644 .64767 L F
.535 .683 .933 r
.76808 .58493 m .76952 .58308 L .76659 .58304 L F
.76808 .58493 m .7704 .58471 L .76952 .58308 L F
.617 .745 .937 r
.77149 .61536 m .77287 .61275 L .77039 .61338 L F
.77149 .61536 m .77385 .61463 L .77287 .61275 L F
.426 0 .081 r
.48011 .753 m .48262 .75299 L .48364 .75131 L F
0 0 0 r
.48364 .75131 m .48424 .75193 L .4861 .75072 L F
.48364 .75131 m .48262 .75299 L .48424 .75193 L F
.902 .686 .6 r
.48743 .81158 m .49049 .81184 L .48654 .81404 L F
0 .513 .78 r
.48493 .81104 m .48671 .81142 L .48511 .81095 L F
.48671 .81142 m .48743 .81158 L .48692 .81144 L F
.48671 .81142 m .48692 .81144 L .48511 .81095 L F
.87 .643 .593 r
.48743 .81158 m .48341 .8126 L .48511 .81095 L F
.48743 .81158 m .48654 .81404 L .48341 .8126 L F
.76 .878 .932 r
.48511 .81095 m .48743 .81158 L .48751 .81055 L F
.939 .829 .71 r
.48654 .81404 m .49049 .81184 L .48751 .81055 L F
.016 0 .357 r
.48802 .8127 m .48654 .81404 L .48726 .81147 L F
.48774 .81151 m .48726 .81147 L .48751 .81055 L F
.48802 .8127 m .48726 .81147 L .48774 .81151 L F
.53 .049 .06 r
.49049 .81184 m .49111 .81214 L .49142 .80957 L F
0 .371 .756 r
.77132 .58769 m .77401 .58908 L .77346 .58863 L F
.268 .49 .887 r
.77401 .58908 m .7761 .58876 L .77346 .58863 L F
.77401 .58908 m .77704 .59033 L .7761 .58876 L F
.394 0 0 r
.26511 .58707 m .26903 .58557 L .26694 .58605 L F
.681 .975 .806 r
.76331 .58242 m .76115 .58472 L .764 .58318 L F
.76331 .58242 m .76088 .58434 L .76115 .58472 L F
.411 .842 .95 r
.51112 .66048 m .50731 .66089 L .51041 .66036 L F
.613 .362 .512 r
.51112 .66048 m .50731 .66363 L .50731 .66089 L F
.51112 .66048 m .51168 .66338 L .50731 .66363 L F
.427 .85 .953 r
.51041 .66036 m .5118 .6598 L .51112 .66048 L F
.608 .358 .513 r
.51265 .66308 m .51112 .66048 L .5118 .6598 L F
.51265 .66308 m .51168 .66338 L .51112 .66048 L F
.539 .314 .522 r
.42584 .66335 m .42365 .66533 L .42405 .66426 L F
0 .165 .698 r
.49543 .80008 m .49457 .80056 L .49369 .7975 L F
.49543 .80008 m .49498 .80091 L .49457 .80056 L F
.301 .179 .542 r
.49556 .8014 m .49475 .80378 L .49457 .80056 L F
0 .165 .698 r
.49543 .80008 m .49369 .7975 L .49508 .79789 L F
.576 .407 .615 r
.49791 .79476 m .49611 .79962 L .49508 .79789 L F
.453 .279 .553 r
.50026 .79657 m .49611 .79962 L .49791 .79476 L F
.761 .663 .753 r
.50026 .79657 m .49749 .79948 L .49611 .79962 L F
.454 .215 .461 r
.49749 .79948 m .49508 .79789 L .49611 .79962 L F
.49749 .79948 m .49543 .80008 L .49508 .79789 L F
.981 .779 .559 r
.49427 .7987 m .4939 .80161 L .49543 .80008 L F
.37 .648 .964 r
.49427 .7987 m .49543 .80008 L .49621 .79882 L F
.657 .901 .57 r
.49543 .80008 m .4939 .80161 L .49595 .79913 L F
.49543 .80008 m .49595 .79913 L .49621 .79882 L F
0 .165 .698 r
.49543 .80008 m .49556 .8014 L .49498 .80091 L F
.424 .794 .994 r
.64549 .5147 m .64708 .5147 L .64493 .5149 L F
.673 .562 .721 r
.64708 .5147 m .64465 .51423 L .64704 .51414 L F
.424 .794 .994 r
.64704 .51414 m .64708 .5147 L .64549 .5147 L F
.673 .562 .721 r
.64708 .5147 m .64672 .51538 L .64549 .5147 L F
.64708 .5147 m .64549 .5147 L .64465 .51423 L F
.424 .794 .994 r
.64549 .5147 m .64493 .5149 L .64465 .51423 L F
.673 .562 .721 r
.64672 .51538 m .64522 .51816 L .64465 .51423 L F
.424 .794 .994 r
.64704 .51414 m .64549 .5147 L .64465 .51423 L F
.603 .566 .786 r
.37237 .68319 m .37364 .67951 L .372 .68086 L F
.502 .157 .315 r
.50777 .77281 m .51111 .7702 L .50759 .76985 L F
.50777 .77281 m .51026 .77263 L .51111 .7702 L F
.499 .155 .314 r
.51111 .7702 m .51304 .77144 L .51334 .76978 L F
.51111 .7702 m .51026 .77263 L .51304 .77144 L F
0 .05 .612 r
.5026 .76925 m .50266 .7696 L .50242 .7697 L F
.739 .482 .54 r
.50468 .76746 m .50246 .76968 L .50759 .76985 L F
0 .051 .613 r
.5031 .77191 m .50228 .76987 L .50242 .7697 L F
.739 .482 .54 r
.50246 .76968 m .50228 .76987 L .50252 .76987 L F
.50246 .76968 m .50252 .76987 L .50759 .76985 L F
0 .05 .612 r
.50246 .76968 m .5031 .77191 L .50242 .7697 L F
.821 .43 .311 r
.50252 .76987 m .50568 .77228 L .50759 .76985 L F
.50228 .76987 m .50259 .77009 L .50252 .76987 L F
.50259 .77009 m .50568 .77228 L .50252 .76987 L F
.50259 .77009 m .50369 .77214 L .50568 .77228 L F
0 .05 .612 r
.5029 .77087 m .50293 .77104 L .50267 .77027 L F
.821 .43 .311 r
.50228 .76987 m .50291 .77088 L .50259 .77009 L F
0 .05 .612 r
.5029 .77087 m .50369 .77214 L .5031 .77191 L F
.821 .43 .311 r
.5029 .77087 m .50369 .77214 L .50259 .77009 L F
0 0 0 r
.50242 .7697 m .50246 .76968 L .50468 .76746 L F
0 .05 .612 r
.5026 .76925 m .50369 .77214 L .5029 .77087 L F
.821 .43 .311 r
.50291 .77088 m .50369 .77214 L .5029 .77087 L F
0 .05 .612 r
.50266 .7696 m .5029 .77087 L .50252 .76987 L F
.5029 .77087 m .50267 .77027 L .50252 .76987 L F
.50247 .76968 m .50252 .76987 L .50246 .76968 L F
.50266 .7696 m .50252 .76987 L .50247 .76968 L F
.50293 .77104 m .5031 .77191 L .50246 .76968 L F
0 0 0 r
.50242 .7697 m .50228 .76987 L .50246 .76968 L F
.234 0 .228 r
.55167 .79552 m .5502 .79842 L .55097 .79764 L F
.265 .64 .964 r
.34779 .5924 m .34738 .5934 L .34588 .59203 L F
.34779 .5924 m .34911 .59352 L .34738 .5934 L F
.491 .35 .617 r
.37262 .66945 m .3746 .66899 L .37444 .66644 L F
.442 .286 .572 r
.37262 .66945 m .37455 .67116 L .3746 .66899 L F
.37262 .66945 m .3727 .67179 L .37455 .67116 L F
.626 .631 .835 r
.28009 .63299 m .27643 .63077 L .27844 .63033 L F
.521 .636 .904 r
.28107 .63101 m .28009 .63299 L .27844 .63033 L F
.28107 .63101 m .28217 .63281 L .28009 .63299 L F
.445 .064 .222 r
.63595 .5007 m .63804 .50061 L .63851 .49933 L F
.59 .32 .475 r
.63804 .50061 m .64077 .49855 L .63851 .49933 L F
.701 .747 .887 r
.46885 .66398 m .47084 .66569 L .47311 .664 L F
.366 0 0 r
.30464 .60187 m .30103 .60307 L .30251 .60222 L F
.574 .298 .46 r
.44007 .68878 m .44258 .68866 L .44321 .68586 L F
.467 .166 .371 r
.44258 .68866 m .44562 .68572 L .44321 .68586 L F
.51 .513 .795 r
.37871 .69717 m .37957 .69383 L .37759 .69424 L F
.37871 .69717 m .38065 .69687 L .37957 .69383 L F
0 0 0 r
.63594 .5569 m .63597 .5573 L .63302 .5592 L F
.63594 .5569 m .63846 .55431 L .63765 .55582 L F
.63765 .55582 m .63597 .5573 L .63594 .5569 L F
.422 .228 .51 r
.33188 .6188 m .33407 .61585 L .33176 .61642 L F
.739 .992 .823 r
.69487 .53653 m .6965 .53603 L .69796 .53451 L F
.403 0 .012 r
.53309 .74387 m .53704 .7424 L .5324 .74362 L F
.53309 .74387 m .53578 .74392 L .53704 .7424 L F
.38 0 0 r
.53704 .7424 m .53831 .74361 L .53915 .74259 L F
.53704 .7424 m .53578 .74392 L .53831 .74361 L F
.533 .58 .848 r
.26182 .6464 m .26324 .64899 L .26512 .64863 L F
.08 0 .244 r
.47905 .77019 m .48114 .76706 L .47828 .76733 L F
.47905 .77019 m .48044 .76961 L .48114 .76706 L F
.661 .263 .279 r
.45374 .68341 m .45588 .68525 L .45718 .68339 L F
.558 .166 .254 r
.45588 .68525 m .45945 .68338 L .45718 .68339 L F
.993 .856 .509 r
.61294 .5041 m .61282 .50085 L .6138 .50202 L F
.783 .656 .723 r
.57435 .57942 m .57572 .582 L .57413 .5818 L F
.57435 .57942 m .57659 .58163 L .57572 .582 L F
.798 .459 .413 r
.57572 .582 m .57387 .58416 L .57413 .5818 L F
.57572 .582 m .57647 .5845 L .57387 .58416 L F
.415 0 .07 r
.39677 .65396 m .39507 .65314 L .39356 .65479 L F
.668 .169 .053 r
.38517 .65653 m .38694 .65553 L .38342 .65497 L F
.529 .811 .998 r
.38731 .65409 m .38694 .65553 L .38517 .65653 L F
.38731 .65409 m .3891 .65506 L .38694 .65553 L F
.846 .609 .58 r
.51204 .73844 m .51499 .73927 L .51508 .73659 L F
.156 0 .374 r
.53034 .73619 m .53185 .73385 L .52905 .7345 L F
.744 .831 .918 r
.75024 .58629 m .74707 .58726 L .74621 .58604 L F
.75024 .58629 m .74621 .58604 L .74639 .58606 L F
.792 .805 .863 r
.75201 .5864 m .75009 .58892 L .75024 .58629 L F
.744 .831 .918 r
.75024 .58629 m .74639 .58606 L .75074 .58656 L F
.792 .805 .863 r
.75297 .58514 m .75201 .5864 L .75024 .58629 L F
.702 .248 .172 r
.51136 .7585 m .51285 .76011 L .51437 .7588 L F
.781 .357 .243 r
.51285 .76011 m .51654 .76145 L .51437 .7588 L F
.772 .363 .277 r
.51437 .7588 m .51654 .76145 L .51763 .76116 L F
.563 .782 .981 r
.273 .65158 m .27542 .65184 L .27423 .65175 L F
.117 .657 .847 r
.27818 .65205 m .27423 .65175 L .27542 .65184 L F
.796 .889 .912 r
.63875 .5342 m .63798 .53539 L .63644 .53411 L F
.898 .659 .568 r
.63798 .53539 m .63566 .53629 L .63644 .53411 L F
.63798 .53539 m .63746 .53743 L .63566 .53629 L F
.643 .958 .93 r
.66408 .484 m .66729 .48264 L .66647 .48359 L F
.415 0 0 r
.66729 .48264 m .66885 .48334 L .66647 .48359 L F
.603 .566 .786 r
.37237 .68319 m .37526 .68318 L .37364 .67951 L F
.912 .785 .707 r
.66397 .52355 m .66467 .52678 L .66323 .52575 L F
.938 .583 .315 r
.66323 .52575 m .66467 .52678 L .66379 .52811 L F
.955 .619 .333 r
.66467 .52678 m .6651 .52889 L .66379 .52811 L F
.1 .549 .912 r
.5697 .72755 m .57004 .72703 L .56827 .72653 L F
.007 .428 .861 r
.5697 .72755 m .57194 .72838 L .57004 .72703 L F
.318 .358 .745 r
.29933 .86808 m .29943 .86804 L .29929 .86794 L F
0 0 0 r
.29933 .86808 m .29943 .86804 L .29928 .86815 L F
.509 .454 .731 r
.65895 .49576 m .65815 .49896 L .65808 .49566 L F
.882 .719 .204 r
.65808 .49566 m .65815 .49896 L .65789 .49776 L F
.871 .508 .016 r
.65815 .49896 m .65883 .50107 L .65799 .49988 L F
.86 .431 .195 r
.51837 .77283 m .51919 .77452 L .52001 .77328 L F
.823 .375 .168 r
.52001 .77328 m .51919 .77452 L .52086 .77478 L F
.538 .581 .846 r
.61574 .54565 m .61364 .54644 L .61227 .54305 L F
.537 .356 .583 r
.61567 .54809 m .61364 .54644 L .61574 .54565 L F
.61567 .54809 m .61381 .54882 L .61364 .54644 L F
.743 .525 .599 r
.50802 .75539 m .51091 .75593 L .51088 .75345 L F
.686 .481 .604 r
.51091 .75593 m .51316 .75335 L .51088 .75345 L F
.92 .965 .787 r
.60273 .52382 m .60404 .52011 L .60459 .52065 L F
.91 .982 .738 r
.60459 .52065 m .60404 .52011 L .60598 .51704 L F
.66 .517 .679 r
.52123 .73672 m .52436 .73939 L .52324 .73627 L F
.52123 .73672 m .52013 .73982 L .52436 .73939 L F
.837 .666 .124 r
.66998 .51344 m .67014 .51309 L .66991 .51172 L F
.547 .531 .789 r
.55297 .75459 m .5543 .75501 L .55415 .75371 L F
.208 0 .019 r
.55138 .75868 m .55445 .75625 L .55262 .75377 L F
.55445 .75625 m .55469 .75606 L .55439 .75573 L F
.55445 .75625 m .55439 .75573 L .55262 .75377 L F
.547 .531 .789 r
.55573 .75501 m .55666 .75577 L .55626 .75444 L F
.5543 .75501 m .55666 .75577 L .55415 .75371 L F
0 0 0 r
.55482 .75604 m .55618 .75485 L .55666 .75577 L F
.55469 .75606 m .55618 .75485 L .55482 .75604 L F
.547 .531 .789 r
.55573 .75501 m .55626 .75444 L .5557 .75257 L F
.847 .545 .011 r
.5557 .75257 m .55627 .75446 L .55618 .75485 L F
.55627 .75446 m .55666 .75577 L .55618 .75485 L F
.506 .3 .535 r
.55456 .75735 m .55604 .75546 L .55618 .75485 L F
.55604 .75546 m .55725 .75391 L .55618 .75485 L F
.55725 .75391 m .55726 .75391 L .55618 .75485 L F
0 0 0 r
.5549 .75589 m .5535 .75815 L .55618 .75485 L F
.55469 .75606 m .55461 .7562 L .5549 .75589 L F
.55461 .7562 m .5535 .75815 L .5549 .75589 L F
.547 .531 .789 r
.55415 .75371 m .55573 .75501 L .5557 .75257 L F
.751 .643 .74 r
.59313 .73362 m .59666 .73393 L .59532 .73074 L F
.643 .68 .87 r
.48075 .64445 m .47716 .64341 L .47989 .64183 L F
.599 .299 .431 r
.29925 .86805 m .29943 .86804 L .29929 .86794 L F
.208 0 .019 r
.55138 .75868 m .5535 .75815 L .55469 .75606 L F
.992 .736 .408 r
.6328 .54321 m .63312 .54555 L .63411 .54639 L F
.888 .924 .84 r
.63411 .54639 m .63542 .54264 L .63686 .54397 L F
.63411 .54639 m .63312 .54555 L .63542 .54264 L F
.941 .809 .686 r
.63167 .5352 m .63173 .53256 L .62989 .53276 L F
.729 .591 .701 r
.63054 .52973 m .62989 .53276 L .63173 .53256 L F
.828 .703 .726 r
.63173 .53256 m .63096 .53126 L .63054 .52973 L F
.529 .395 .643 r
.63096 .53126 m .62989 .53276 L .63054 .52973 L F
.828 .703 .726 r
.63173 .53256 m .63068 .53236 L .63096 .53126 L F
.529 .395 .643 r
.63102 .53146 m .63087 .53163 L .63096 .53126 L F
.63087 .53163 m .62989 .53276 L .63096 .53126 L F
.828 .703 .726 r
.63096 .53126 m .62791 .53182 L .62941 .52864 L F
.529 .395 .643 r
.63065 .5324 m .62989 .53276 L .63175 .53061 L F
.828 .703 .726 r
.63068 .53236 m .62791 .53182 L .63096 .53126 L F
.63096 .53126 m .62941 .52864 L .63054 .52973 L F
.529 .395 .643 r
.63175 .53061 m .63102 .53146 L .63054 .52973 L F
.63281 .53138 m .63065 .5324 L .63175 .53061 L F
.541 .575 .838 r
.63052 .53302 m .63065 .5338 L .62989 .53276 L F
.941 .809 .686 r
.63167 .5352 m .63124 .53341 L .63173 .53256 L F
.741 .512 .582 r
.63054 .53293 m .63036 .53492 L .62649 .53416 L F
.63173 .53256 m .63122 .53344 L .63054 .53293 L F
.541 .575 .838 r
.63081 .53314 m .63052 .53302 L .63059 .53297 L F
.63115 .53335 m .63167 .5352 L .63065 .5338 L F
.63121 .5333 m .63124 .53341 L .63115 .53335 L F
.63124 .53341 m .63167 .5352 L .63115 .53335 L F
.63121 .5333 m .63065 .5338 L .63052 .53302 L F
.741 .512 .582 r
.63122 .53344 m .63036 .53492 L .63053 .53296 L F
.63081 .53314 m .63053 .53296 L .63054 .53293 L F
.63122 .53344 m .63053 .53296 L .63081 .53314 L F
.541 .575 .838 r
.63348 .53423 m .63081 .53314 L .63281 .53138 L F
.63081 .53314 m .63059 .53297 L .63281 .53138 L F
.63052 .53302 m .62989 .53276 L .63065 .5324 L F
.741 .512 .582 r
.63173 .53256 m .63054 .53293 L .63066 .53235 L F
.541 .575 .838 r
.63052 .53302 m .63065 .5324 L .63281 .53138 L F
.741 .512 .582 r
.63066 .53235 m .6305 .53294 L .6304 .53231 L F
.63054 .53293 m .6305 .53294 L .63066 .53235 L F
.63047 .5327 m .62649 .53416 L .6304 .53231 L F
.6305 .53294 m .63028 .53301 L .63047 .5327 L F
.63028 .53301 m .62649 .53416 L .63047 .5327 L F
.6304 .53231 m .62649 .53416 L .62791 .53182 L F
.541 .575 .838 r
.63348 .53423 m .63167 .5352 L .63121 .5333 L F
.941 .809 .686 r
.63167 .5352 m .63036 .53492 L .63124 .53341 L F
.886 .487 .261 r
.63167 .5352 m .63067 .53638 L .63036 .53492 L F
.746 .499 .558 r
.63348 .53423 m .63067 .53638 L .63167 .5352 L F
.407 .197 .479 r
.49131 .75009 m .4892 .75299 L .48934 .7507 L F
.901 .884 .807 r
.64177 .53037 m .64083 .52847 L .64205 .52948 L F
.905 .868 .792 r
.64177 .53037 m .63875 .5342 L .6387 .53132 L F
0 0 0 r
.51079 .74238 m .50902 .74309 L .50701 .74379 L F
.479 .886 .752 r
.51208 .74134 m .51079 .74238 L .51258 .74268 L F
.51208 .74134 m .50902 .74309 L .51079 .74238 L F
.255 .763 .756 r
.51755 .81387 m .5232 .81251 L .52212 .81214 L F
.519 .76 .984 r
.5232 .81251 m .52411 .81099 L .52212 .81214 L F
.5232 .81251 m .52544 .8122 L .52411 .81099 L F
.776 .708 .789 r
.54359 .80039 m .54204 .80307 L .54015 .80023 L F
.069 0 0 r
.53972 .80476 m .54204 .80307 L .54328 .80293 L F
.242 .063 .428 r
.54328 .80293 m .54204 .80307 L .54359 .80039 L F
0 0 0 r
.63029 .51584 m .63188 .51554 L .63246 .51582 L F
.63029 .51584 m .62919 .51687 L .63188 .51554 L F
.739 .215 0 r
.49695 .81477 m .49634 .81388 L .49316 .81179 L F
.669 .645 .817 r
.66881 .47927 m .67133 .47896 L .66731 .47991 L F
0 0 .21 r
.46864 .66084 m .46845 .66293 L .46893 .66187 L F
0 0 .379 r
.46845 .66293 m .46885 .66398 L .46893 .66187 L F
.503 .035 .077 r
.43179 .66199 m .43045 .66335 L .42816 .66313 L F
.397 0 .004 r
.43383 .66256 m .43045 .66335 L .43179 .66199 L F
.707 .652 .793 r
.48921 .66951 m .49182 .6701 L .4916 .66784 L F
.719 .597 .719 r
.48882 .67189 m .49182 .6701 L .48921 .66951 L F
.585 .56 .793 r
.4916 .66784 m .49182 .6701 L .49417 .66764 L F
.694 .463 .569 r
.60159 .58269 m .59781 .5851 L .59786 .58284 L F
.28 0 0 r
.40679 .71237 m .40514 .71225 L .4073 .71193 L F
.40679 .71237 m .4045 .71299 L .40514 .71225 L F
.612 .623 .838 r
.65111 .5185 m .64859 .51918 L .64806 .51732 L F
.499 .718 .97 r
.28948 .65051 m .28982 .64856 L .28792 .65161 L F
.28948 .65051 m .29201 .65022 L .28982 .64856 L F
.713 .337 .336 r
.55869 .71977 m .55737 .72162 L .55507 .71942 L F
.733 .363 .349 r
.55869 .71977 m .56083 .72196 L .55737 .72162 L F
.292 .592 .946 r
.77661 .57939 m .77529 .58035 L .77447 .5793 L F
.77661 .57939 m .77849 .5812 L .77529 .58035 L F
.668 .495 .641 r
.49111 .81214 m .49333 .80928 L .49142 .80957 L F
.374 .769 .987 r
.33267 .591 m .33215 .59187 L .33058 .59102 L F
.33267 .591 m .33421 .59168 L .33215 .59187 L F
.867 .974 .854 r
.75827 .5815 m .75945 .57874 L .75999 .5796 L F
.75827 .5815 m .75729 .58105 L .75945 .57874 L F
.737 .222 0 r
.50987 .76475 m .5103 .76658 L .50893 .7637 L F
.50987 .76475 m .51203 .76682 L .5103 .76658 L F
.543 .36 .583 r
.51212 .76422 m .51203 .76682 L .50987 .76475 L F
.466 .676 .956 r
.5949 .69346 m .5937 .69491 L .59268 .69432 L F
.5949 .69346 m .59533 .6949 L .5937 .69491 L F
.163 .36 .811 r
.63017 .50463 m .63026 .50606 L .62807 .50478 L F
.579 .29 .441 r
.38087 .65437 m .38342 .65497 L .38116 .65565 L F
.214 .403 .833 r
.77985 .58161 m .7788 .58286 L .77849 .5812 L F
.089 .212 .698 r
.78049 .58502 m .7788 .58286 L .77985 .58161 L F
.053 .299 .787 r
.54854 .71385 m .54932 .71287 L .54681 .71066 L F
.784 .585 .63 r
.55048 .71095 m .54929 .71399 L .55384 .71408 L F
0 .171 .694 r
.54854 .71385 m .55019 .71571 L .54895 .71333 L F
.784 .585 .63 r
.54929 .71399 m .54928 .71402 L .54931 .71402 L F
.54929 .71399 m .54931 .71402 L .55384 .71408 L F
.413 0 .113 r
.55049 .71605 m .55384 .71408 L .54931 .71402 L F
0 .171 .694 r
.55019 .71571 m .55049 .71605 L .54931 .71402 L F
.413 0 .113 r
.55049 .71605 m .54931 .71402 L .54928 .71402 L F
0 .171 .694 r
.54931 .71402 m .55049 .71605 L .54895 .71333 L F
.54895 .71333 m .54929 .71394 L .54932 .71287 L F
.924 .907 .51 r
.54932 .71287 m .54928 .71402 L .54929 .71399 L F
.54932 .71287 m .54929 .71399 L .55048 .71095 L F
0 .171 .694 r
.54929 .71394 m .55049 .71605 L .54932 .71287 L F
.42 .686 .973 r
.71217 .49061 m .71421 .48972 L .71139 .48971 L F
.71217 .49061 m .71422 .49034 L .71421 .48972 L F
.566 .53 .774 r
.7128 .49357 m .71422 .49034 L .71217 .49061 L F
.76 .383 .341 r
.49475 .80378 m .49091 .80292 L .49253 .80283 L F
.745 .88 .942 r
.77957 .60312 m .78073 .60409 L .77831 .60552 L F
.814 .972 .9 r
.77957 .60312 m .77831 .60552 L .77762 .60488 L F
.466 .112 .282 r
.44257 .69778 m .44206 .69946 L .44019 .69969 L F
.463 .11 .281 r
.44257 .69778 m .44449 .69915 L .44206 .69946 L F
.486 .096 .226 r
.44492 .69766 m .44449 .69915 L .44257 .69778 L F
.809 .73 .776 r
.57613 .56271 m .57698 .56586 L .57389 .56539 L F
.844 .737 .746 r
.57698 .56586 m .57336 .56766 L .57389 .56539 L F
.57698 .56586 m .57508 .56871 L .57336 .56766 L F
.206 0 0 r
.724 .51757 m .72593 .51758 L .72366 .51834 L F
.966 .843 .43 r
.55114 .73875 m .55064 .73831 L .55116 .73618 L F
0 0 .447 r
.55114 .73875 m .55152 .73916 L .55064 .73831 L F
.55114 .73875 m .55316 .74154 L .55152 .73916 L F
.425 .316 .627 r
.55114 .73875 m .55152 .74239 L .55316 .74154 L F
.818 1 .805 r
.48036 .76022 m .47865 .76219 L .48004 .76176 L F
.692 .544 .68 r
.47868 .78772 m .47567 .78634 L .47748 .7867 L F
.626 .229 0 r
.66052 .50408 m .66081 .50464 L .65883 .50107 L F
.872 .568 .049 r
.66052 .50408 m .66099 .50652 L .66001 .50414 L F
.66052 .50408 m .66001 .50414 L .66081 .50464 L F
.838 .508 .43 r
.66082 .51702 m .66247 .51553 L .66277 .51779 L F
.735 .864 .941 r
.485 .64045 m .48152 .64048 L .48475 .63598 L F
.682 .757 .908 r
.48741 .63851 m .48499 .64035 L .48475 .63598 L F
.48788 .63895 m .48475 .63598 L .48621 .63764 L F
.75 .844 .922 r
.48909 .63723 m .48621 .63764 L .48831 .63664 L F
.48964 .63765 m .48855 .63765 L .48909 .63723 L F
.48855 .63765 m .48621 .63764 L .48909 .63723 L F
.682 .757 .908 r
.48788 .63895 m .485 .64045 L .48499 .64035 L F
.48788 .63895 m .48499 .64035 L .48741 .63851 L F
.744 .506 .569 r
.53548 .79882 m .53425 .80047 L .53484 .79812 L F
.53548 .79882 m .53786 .80077 L .53425 .80047 L F
.608 .632 .849 r
.53843 .7973 m .53786 .80077 L .53548 .79882 L F
.548 .218 .362 r
.53953 .767 m .53864 .76933 L .53624 .76958 L F
.714 .392 .431 r
.53953 .767 m .54197 .76952 L .53864 .76933 L F
.695 .397 .466 r
.54186 .76751 m .54197 .76952 L .53953 .767 L F
0 0 0 r
.64307 .4885 m .64233 .48948 L .6431 .48901 L F
.736 .36 0 r
.64359 .48932 m .64307 .4885 L .64305 .48824 L F
0 0 0 r
.64307 .4885 m .6431 .48901 L .64519 .48771 L F
.736 .36 0 r
.64305 .48824 m .64307 .4885 L .64193 .48603 L F
.487 .709 .969 r
.67918 .47867 m .67772 .48018 L .67676 .47914 L F
.67918 .47867 m .68029 .48011 L .67772 .48018 L F
.706 .651 .793 r
.51911 .74015 m .52198 .74015 L .52013 .73982 L F
.664 .672 .848 r
.52013 .73982 m .52198 .74015 L .52436 .73939 L F
.648 .832 .971 r
.68571 .47969 m .68363 .48088 L .68235 .47962 L F
.651 .553 .73 r
.29928 .86815 m .29943 .86804 L .29925 .86805 L F
.213 0 .012 r
.59297 .70601 m .59477 .70273 L .59258 .70313 L F
.395 .411 .759 r
.49496 .67234 m .49652 .66843 L .49417 .66764 L F
.49496 .67234 m .4965 .66935 L .49652 .66843 L F
.49496 .67234 m .49688 .6718 L .4965 .66935 L F
.428 .595 .914 r
.49496 .67234 m .49712 .67348 L .49688 .6718 L F
.647 .293 .357 r
.4925 .78599 m .49064 .78407 L .49404 .78391 L F
.376 .815 .665 r
.49636 .78398 m .4925 .78599 L .49404 .78391 L F
.558 .503 .75 r
.73895 .59973 m .74059 .59587 L .73839 .59633 L F
.73895 .59973 m .74133 .59936 L .74059 .59587 L F
.596 .539 .761 r
.73895 .59973 m .74213 .60266 L .74133 .59936 L F
.397 .773 .992 r
.2953 .58602 m .29739 .58578 L .29899 .58663 L F
.402 .772 .993 r
.29739 .58578 m .30129 .58641 L .29899 .58663 L F
.632 .615 .815 r
.56263 .70246 m .55926 .69982 L .563 .70008 L F
.037 0 .401 r
.56377 .7014 m .56263 .70246 L .563 .70008 L F
.463 .294 .565 r
.49712 .67348 m .49605 .67502 L .49833 .67227 L F
.686 .481 .604 r
.51091 .75593 m .51314 .75583 L .51316 .75335 L F
.51316 .75335 m .51314 .75583 L .51091 .75593 L F
.382 .237 .557 r
.51316 .75335 m .51509 .75528 L .51513 .75274 L F
.51316 .75335 m .51314 .75583 L .51509 .75528 L F
.51316 .75335 m .51509 .75528 L .51513 .75274 L F
.51316 .75335 m .51314 .75583 L .51509 .75528 L F
.779 .772 .847 r
.36572 .70857 m .3698 .70809 L .36787 .70794 L F
0 .275 .776 r
.3698 .70809 m .37001 .70738 L .36787 .70794 L F
.3 0 .153 r
.32486 .62488 m .32402 .62632 L .32689 .62428 L F
.783 .998 .818 r
.6329 .48229 m .63187 .48457 L .63456 .48201 L F
.459 .25 .508 r
.63426 .48625 m .63187 .48457 L .6329 .48229 L F
.63426 .48625 m .63203 .48691 L .63187 .48457 L F
.714 .478 .566 r
.61554 .54055 m .61227 .54305 L .6141 .54016 L F
.61554 .54055 m .61509 .54321 L .61227 .54305 L F
.643 .658 .849 r
.61675 .5381 m .61554 .54055 L .6141 .54016 L F
.61675 .5381 m .61818 .54077 L .61554 .54055 L F
0 0 0 r
.61818 .54077 m .61509 .54321 L .61554 .54055 L F
.556 .521 .772 r
.40482 .68773 m .4035 .6916 L .40235 .68837 L F
.40482 .68773 m .40569 .69126 L .4035 .6916 L F
.013 0 0 r
.26903 .58557 m .27108 .58509 L .27248 .58445 L F
.372 0 0 r
.27248 .58445 m .27108 .58509 L .27456 .58461 L F
.459 .778 .998 r
.31801 .5886 m .31734 .5898 L .31578 .58898 L F
.31801 .5886 m .31968 .58958 L .31734 .5898 L F
.866 .436 .187 r
.50142 .78484 m .50053 .78597 L .49892 .78345 L F
.50142 .78484 m .50207 .78642 L .50053 .78597 L F
.793 .63 .68 r
.54179 .78962 m .543 .7865 L .54027 .78709 L F
.422 .503 .837 r
.74766 .60771 m .74749 .60376 L .74531 .60398 L F
.74766 .60771 m .74901 .60707 L .74749 .60376 L F
.451 .211 .458 r
.33582 .63583 m .33556 .63799 L .33351 .63835 L F
.413 .193 .468 r
.33774 .63537 m .33556 .63799 L .33582 .63583 L F
.122 .57 .921 r
.28621 .63227 m .28582 .63294 L .28441 .63179 L F
.28621 .63227 m .28783 .63337 L .28582 .63294 L F
.156 0 .374 r
.53034 .73619 m .53159 .73585 L .53185 .73385 L F
.256 .308 .725 r
.53034 .73619 m .53243 .73708 L .53159 .73585 L F
.783 .871 .913 r
.49949 .66991 m .49833 .67227 L .50068 .6711 L F
.818 .917 .905 r
.49949 .66991 m .50068 .6711 L .50289 .66889 L F
.754 .736 .836 r
.71009 .48365 m .71145 .48507 L .70798 .48468 L F
.784 .739 .812 r
.71379 .48288 m .71145 .48507 L .71009 .48365 L F
.282 0 .128 r
.32761 .64324 m .32564 .64374 L .32855 .6417 L F
.427 .116 .333 r
.33038 .64091 m .32761 .64324 L .32855 .6417 L F
.34 .163 .49 r
.46582 .77577 m .46569 .77803 L .46742 .77516 L F
.694 .463 .569 r
.60159 .58269 m .60144 .58484 L .59781 .5851 L F
.628 .406 .561 r
.60159 .58269 m .60372 .58487 L .60144 .58484 L F
.7 .397 .46 r
.6037 .58299 m .60372 .58487 L .60159 .58269 L F
0 0 0 r
.70308 .51793 m .70019 .51996 L .70322 .51771 L F
.815 .972 .899 r
.70337 .51588 m .70598 .51558 L .70308 .51793 L F
.70337 .51588 m .70308 .51793 L .70322 .51771 L F
.776 .549 .591 r
.51499 .73927 m .51706 .74035 L .51911 .74015 L F
.562 .083 .077 r
.51706 .74035 m .52091 .7413 L .51911 .74015 L F
.293 .496 .884 r
.65335 .49082 m .65571 .49045 L .65342 .48917 L F
.65335 .49082 m .65637 .49216 L .65571 .49045 L F
.487 .18 .371 r
.62313 .52341 m .62275 .5258 L .62028 .52626 L F
.387 .071 .302 r
.62605 .52269 m .62275 .5258 L .62313 .52341 L F
.959 .682 .467 r
.48751 .81055 m .48937 .80894 L .48778 .80868 L F
.926 .965 .772 r
.60273 .52382 m .60036 .52565 L .60205 .52307 L F
.60273 .52382 m .60084 .5268 L .60036 .52565 L F
.92 .965 .787 r
.60273 .52382 m .60205 .52307 L .60404 .52011 L F
.256 .188 .585 r
.51646 .74228 m .51706 .74035 L .5158 .74202 L F
.51646 .74228 m .51764 .74224 L .51706 .74035 L F
.88 .884 .832 r
.66341 .49282 m .66094 .49601 L .65985 .49495 L F
.517 .726 .968 r
.49792 .76635 m .49868 .76791 L .49497 .76667 L F
.655 .353 .448 r
.49868 .76791 m .49541 .76854 L .49497 .76667 L F
.49868 .76791 m .4984 .76962 L .49541 .76854 L F
.49541 .76854 m .4984 .76962 L .49868 .76791 L F
.501 .775 .993 r
.50116 .76855 m .49868 .76791 L .49792 .76635 L F
.50116 .76855 m .4984 .76962 L .49868 .76791 L F
.621 .554 .758 r
.62599 .5008 m .62497 .50358 L .62395 .50202 L F
.07 .299 .784 r
.59533 .6949 m .59719 .69687 L .59649 .69705 L F
0 0 .315 r
.59719 .69687 m .59676 .69945 L .59649 .69705 L F
.478 0 0 r
.46514 .68286 m .46756 .68371 L .46866 .68352 L F
.241 0 0 r
.46756 .68371 m .47121 .68373 L .46866 .68352 L F
.246 0 0 r
.43221 .70271 m .43079 .704 L .42866 .70435 L F
.178 0 0 r
.43442 .70253 m .43079 .704 L .43221 .70271 L F
.385 .646 .96 r
.35722 .59471 m .35655 .59617 L .35411 .59423 L F
.35722 .59471 m .35834 .59612 L .35655 .59617 L F
.789 .637 .692 r
.57582 .57662 m .57793 .58027 L .57435 .57942 L F
.783 .656 .723 r
.57435 .57942 m .57793 .58027 L .57659 .58163 L F
.738 .622 .729 r
.5796 .57709 m .57793 .58027 L .57582 .57662 L F
.274 0 .053 r
.4533 .65562 m .45018 .65757 L .45139 .65643 L F
.639 .084 0 r
.57347 .72518 m .57609 .72696 L .57696 .72535 L F
.972 .881 .502 r
.46864 .66084 m .46817 .66008 L .46891 .65806 L F
0 0 .21 r
.46864 .66084 m .46893 .66187 L .46817 .66008 L F
.57 .892 .628 r
.69836 .52332 m .69565 .52558 L .69674 .52414 L F
0 0 0 r
.69836 .52332 m .70019 .51996 L .6988 .52085 L F
.69836 .52332 m .6987 .52327 L .70019 .51996 L F
.69674 .52414 m .6987 .52327 L .69836 .52332 L F
.627 .335 .455 r
.6037 .58299 m .60618 .58473 L .60372 .58487 L F
.6037 .58299 m .60711 .58238 L .60618 .58473 L F
.335 .756 .976 r
.47156 .64361 m .46792 .64305 L .47028 .64231 L F
.583 .825 .99 r
.47229 .64201 m .47156 .64361 L .47028 .64231 L F
.47229 .64201 m .47371 .64303 L .47156 .64361 L F
0 0 .328 r
.52 .78313 m .52046 .78411 L .52073 .78452 L F
.498 .477 .765 r
.52046 .78411 m .52262 .78686 L .52144 .78441 L F
.827 .526 .481 r
.52046 .78411 m .52262 .78686 L .52272 .78902 L F
.498 .477 .765 r
.52144 .78441 m .52262 .78686 L .52046 .78411 L F
.827 .526 .481 r
.52046 .78411 m .52262 .78686 L .52272 .78902 L F
.389 .315 .652 r
.37412 .66403 m .37611 .66571 L .3762 .66328 L F
.37412 .66403 m .37444 .66644 L .37611 .66571 L F
.192 .481 .896 r
.27079 .64916 m .273 .65158 L .27423 .65175 L F
.677 .528 .675 r
.4957 .7923 m .49572 .7955 L .49309 .79527 L F
.413 0 .01 r
.49466 .79083 m .49641 .79112 L .4977 .78972 L F
0 .276 .716 r
.4952 .79006 m .49643 .79084 L .49641 .79112 L F
.49643 .79084 m .49671 .79101 L .49641 .79112 L F
.645 .878 .523 r
.49641 .79112 m .4957 .7923 L .4964 .79139 L F
.49641 .79112 m .4964 .79139 L .4977 .78972 L F
.19 .432 .862 r
.49641 .79112 m .49703 .79254 L .4957 .7923 L F
.536 .413 .66 r
.49791 .79476 m .4957 .7923 L .49703 .79254 L F
.49791 .79476 m .49572 .7955 L .4957 .7923 L F
0 0 .422 r
.50383 .68917 m .50542 .69146 L .5058 .69206 L F
.907 .973 .677 r
.50542 .69146 m .50415 .69335 L .5058 .69206 L F
.242 0 0 r
.27456 .58461 m .27672 .58475 L .27816 .58445 L F
.727 .372 .377 r
.69545 .49997 m .69849 .49953 L .69627 .49977 L F
.833 .662 .67 r
.66277 .51779 m .66594 .51839 L .6652 .51952 L F
.559 .302 .483 r
.6285 .48345 m .6309 .4812 L .62877 .48214 L F
.264 0 0 r
.30835 .63334 m .3111 .63301 L .31181 .63239 L F
0 0 0 r
.31182 .63239 m .31281 .63216 L .31388 .63178 L F
.255 .732 .936 r
.30899 .63222 m .31183 .6319 L .31228 .63205 L F
.168 0 0 r
.31082 .63233 m .31351 .63199 L .31281 .63216 L F
.31085 .63232 m .31351 .63199 L .31082 .63233 L F
.31078 .63233 m .31085 .63232 L .31082 .63233 L F
.077 0 0 r
.31281 .63216 m .31494 .63181 L .31599 .63134 L F
.168 0 0 r
.31351 .63199 m .31494 .63181 L .31281 .63216 L F
0 0 0 r
.31181 .63239 m .31281 .63216 L .31182 .63239 L F
.168 0 0 r
.31109 .63229 m .31301 .63231 L .31494 .63181 L F
0 0 0 r
.31181 .63239 m .3111 .63301 L .31281 .63216 L F
.614 .954 .813 r
.3111 .63301 m .31078 .63233 L .31281 .63216 L F
.168 0 0 r
.31078 .63233 m .31301 .63231 L .31109 .63229 L F
.337 0 0 r
.31301 .63231 m .31713 .63156 L .31494 .63181 L F
.31301 .63231 m .31534 .63239 L .31713 .63156 L F
.21 .703 .921 r
.31183 .6319 m .31487 .63233 L .31301 .63231 L F
.31487 .63233 m .31534 .63239 L .31301 .63231 L F
.255 .732 .936 r
.31114 .63227 m .31228 .63205 L .31301 .63231 L F
.30899 .63222 m .31228 .63205 L .31114 .63227 L F
0 0 0 r
.63846 .55431 m .6407 .55285 L .64024 .5535 L F
.6407 .55285 m .6415 .55234 L .64024 .5535 L F
.896 .955 .613 r
.64024 .5535 m .6415 .55234 L .64221 .54959 L F
.948 .92 .749 r
.64024 .5535 m .64221 .54959 L .64099 .54923 L F
.64024 .5535 m .64099 .54923 L .64145 .55167 L F
.606 .815 .41 r
.6398 .55411 m .64024 .5535 L .64145 .55167 L F
0 0 0 r
.63765 .55582 m .64024 .5535 L .63925 .55492 L F
.606 .815 .41 r
.63925 .55492 m .64024 .5535 L .6398 .55411 L F
.876 .956 .854 r
.6415 .55234 m .64384 .54966 L .64221 .54959 L F
.736 .684 .801 r
.49113 .63881 m .4887 .6416 L .48788 .63895 L F
.771 .663 .744 r
.49725 .68302 m .49854 .68633 L .50074 .68338 L F
.423 0 .048 r
.65751 .48329 m .65977 .48336 L .66071 .48186 L F
.625 .925 .973 r
.66071 .48186 m .662 .48033 L .66298 .48083 L F
.547 .369 .592 r
.65977 .48336 m .662 .48033 L .66071 .48186 L F
.546 .889 .984 r
.59071 .72689 m .58731 .72716 L .58801 .72644 L F
.87 .718 .198 r
.66991 .51172 m .6726 .5098 L .6714 .50876 L F
.96 .848 .687 r
.67192 .50646 m .6726 .5098 L .67478 .50699 L F
.67192 .50646 m .6714 .50876 L .6726 .5098 L F
.566 .53 .774 r
.7128 .49357 m .71528 .49279 L .71422 .49034 L F
.381 .074 .314 r
.7128 .49357 m .71247 .49511 L .71528 .49279 L F
.25 .734 .929 r
.28031 .58422 m .2824 .58413 L .28402 .58457 L F
.114 .589 .914 r
.28444 .58404 m .28402 .58457 L .2824 .58413 L F
.28444 .58404 m .28598 .58493 L .28402 .58457 L F
.774 .618 .686 r
.61248 .55697 m .61602 .55489 L .61299 .55463 L F
.61248 .55697 m .61593 .55741 L .61602 .55489 L F
.517 .402 .661 r
.61602 .55489 m .61799 .55443 L .61709 .55097 L F
.526 .408 .662 r
.61602 .55489 m .6181 .55662 L .61799 .55443 L F
.61602 .55489 m .61593 .55741 L .6181 .55662 L F
.421 .524 .857 r
.36032 .59587 m .36016 .59879 L .35834 .59612 L F
.36032 .59587 m .36186 .59879 L .36016 .59879 L F
.664 .662 .838 r
.37859 .71086 m .38195 .71184 L .38037 .7109 L F
.725 .643 .766 r
.38037 .7109 m .38195 .71184 L .38424 .71103 L F
.38037 .7109 m .38424 .71103 L .38264 .70817 L F
.457 .588 .896 r
.38424 .71103 m .38433 .70917 L .38264 .70817 L F
.38424 .71103 m .3862 .71086 L .38433 .70917 L F
.585 .476 .696 r
.38424 .71103 m .38675 .71442 L .3862 .71086 L F
.38424 .71103 m .38516 .71493 L .38675 .71442 L F
.452 .224 .475 r
.61583 .5318 m .61334 .53447 L .61349 .53246 L F
0 0 0 r
.47754 .79272 m .47934 .79105 L .47772 .7939 L F
.297 0 .119 r
.33439 .63968 m .33351 .63835 L .33556 .63799 L F
.33439 .63968 m .33235 .64025 L .33351 .63835 L F
.721 .669 .798 r
.76251 .61373 m .76487 .61517 L .76467 .61273 L F
.655 .6 .781 r
.76487 .61517 m .76792 .61429 L .76467 .61273 L F
.633 .481 .658 r
.54346 .75587 m .54333 .7592 L .54535 .75873 L F
.763 .615 .695 r
.57431 .57109 m .57619 .5743 L .57254 .5739 L F
.765 .584 .653 r
.57254 .5739 m .57619 .5743 L .57582 .57662 L F
.876 .678 .633 r
.63075 .52337 m .62792 .52543 L .62801 .52309 L F
.63075 .52337 m .62994 .52645 L .62792 .52543 L F
.518 .91 .786 r
.63439 .5212 m .63259 .52185 L .63075 .52337 L F
0 .208 .733 r
.63217 .52364 m .63075 .52337 L .63259 .52185 L F
.641 .582 .773 r
.63465 .52719 m .63503 .52863 L .63328 .52677 L F
.63734 .52801 m .63568 .52845 L .63465 .52719 L F
.63568 .52845 m .63503 .52863 L .63465 .52719 L F
0 .208 .733 r
.63166 .52354 m .6344 .52726 L .63075 .52337 L F
.63217 .52364 m .63347 .52575 L .63166 .52354 L F
.63347 .52575 m .6344 .52726 L .63166 .52354 L F
.587 .247 .36 r
.52724 .78012 m .52723 .77882 L .52954 .78041 L F
.583 .251 .372 r
.52723 .77882 m .52952 .77879 L .52954 .78041 L F
.644 .414 .556 r
.59562 .58502 m .59233 .58755 L .59287 .58527 L F
.348 .804 .941 r
.29901 .63399 m .30283 .63392 L .30005 .63419 L F
.882 .984 .706 r
.59713 .53082 m .59865 .52974 L .59672 .53275 L F
.882 .979 .684 r
.59521 .53388 m .59672 .53275 L .59556 .53428 L F
.59521 .53388 m .59713 .53082 L .59672 .53275 L F
.725 .818 .923 r
.65267 .52608 m .65352 .52741 L .65565 .52638 L F
.467 .423 .725 r
.3773 .69169 m .37846 .6881 L .37638 .68852 L F
.3773 .69169 m .37908 .69124 L .37846 .6881 L F
.506 .418 .69 r
.37759 .69424 m .37908 .69124 L .3773 .69169 L F
.723 .811 .92 r
.54833 .75314 m .55098 .75331 L .54975 .75012 L F
.55098 .75331 m .54833 .75314 L .5503 .7541 L F
.522 .454 .721 r
.55098 .75331 m .55225 .75046 L .54975 .75012 L F
.55098 .75331 m .55332 .7531 L .55225 .75046 L F
.624 .182 .178 r
.5503 .7541 m .55262 .75377 L .55098 .75331 L F
.439 .116 .319 r
.55262 .75377 m .55332 .7531 L .55098 .75331 L F
.753 .509 .562 r
.64285 .51819 m .64207 .52031 L .63964 .52018 L F
.684 .569 .72 r
.64465 .51423 m .64522 .51816 L .64285 .51819 L F
.806 .682 .729 r
.64522 .51816 m .64207 .52031 L .64285 .51819 L F
.907 .965 .809 r
.59865 .52974 m .59878 .52754 L .60084 .5268 L F
.904 .968 .811 r
.60084 .5268 m .59878 .52754 L .60036 .52565 L F
.668 .495 .641 r
.49111 .81214 m .49316 .81179 L .49333 .80928 L F
.288 .012 .309 r
.55679 .70291 m .55926 .69982 L .55695 .70012 L F
.5 .205 .397 r
.51502 .76543 m .51811 .76646 L .51529 .76652 L F
.111 .012 .451 r
.72285 .50606 m .72367 .50316 L .72324 .50442 L F
.806 .526 .515 r
.53183 .77848 m .52954 .78041 L .52952 .77879 L F
.53183 .77848 m .53285 .78138 L .52954 .78041 L F
.762 .639 .724 r
.60328 .55428 m .60669 .55471 L .60566 .55143 L F
.766 .618 .696 r
.60457 .55749 m .60669 .55471 L .60328 .55428 L F
.735 .573 .673 r
.60457 .55749 m .60706 .55737 L .60669 .55471 L F
.625 .561 .762 r
.60566 .55143 m .60669 .55471 L .6091 .55418 L F
.632 .514 .701 r
.60706 .55737 m .6091 .55418 L .60669 .55471 L F
.571 .254 .392 r
.60941 .58256 m .60618 .58473 L .60711 .58238 L F
.768 .662 .746 r
.48348 .76704 m .48698 .76729 L .48578 .76406 L F
.703 .305 .289 r
.48348 .76704 m .48582 .76904 L .48698 .76729 L F
.469 .246 .492 r
.48582 .76904 m .48804 .76642 L .48698 .76729 L F
.535 .329 .547 r
.49572 .7955 m .49369 .7975 L .49309 .79527 L F
.382 .76 .991 r
.5383 .75694 m .53745 .7579 L .53604 .75786 L F
.5383 .75694 m .53982 .75779 L .53745 .7579 L F
.103 .519 .909 r
.76829 .60717 m .76688 .60749 L .76412 .60545 L F
.737 .731 .846 r
.47716 .64341 m .47371 .64303 L .47585 .64227 L F
.697 .796 .927 r
.47989 .64183 m .47716 .64341 L .47585 .64227 L F
.54 .382 .616 r
.28111 .61313 m .28109 .6162 L .2793 .61643 L F
.337 .002 .241 r
.28035 .61767 m .2793 .61643 L .28109 .6162 L F
.28035 .61767 m .2784 .61824 L .2793 .61643 L F
.162 0 .36 r
.62843 .56507 m .62678 .5683 L .62715 .566 L F
.204 .666 .943 r
.30453 .58769 m .30657 .58783 L .30805 .58858 L F
.465 .82 .997 r
.30657 .58783 m .31006 .58809 L .30805 .58858 L F
.828 .87 .876 r
.76188 .57577 m .75999 .5796 L .75945 .57874 L F
.76188 .57577 m .76293 .57688 L .75999 .5796 L F
.893 .882 .815 r
.64445 .52624 m .64083 .52847 L .64281 .52549 L F
.64445 .52624 m .64205 .52948 L .64083 .52847 L F
.44 .173 .412 r
.46882 .7647 m .47065 .76613 L .47302 .76259 L F
.46882 .7647 m .46846 .76672 L .47065 .76613 L F
.361 0 .072 r
.41039 .71043 m .40957 .71159 L .4073 .71193 L F
.144 0 0 r
.41155 .7108 m .41039 .71043 L .41265 .70994 L F
.41155 .7108 m .40957 .71159 L .41039 .71043 L F
.939 .964 .691 r
.59713 .53082 m .59878 .52754 L .59865 .52974 L F
.918 .933 .803 r
.51925 .68594 m .52019 .68287 L .52081 .68395 L F
.51925 .68594 m .51834 .68565 L .52019 .68287 L F
.669 .553 .714 r
.52081 .68395 m .52143 .68656 L .51925 .68594 L F
.37 0 0 r
.52143 .68656 m .51834 .68565 L .51925 .68594 L F
.686 .652 .81 r
.48577 .66897 m .48921 .66951 L .48762 .66621 L F
.712 .663 .8 r
.48762 .66621 m .48921 .66951 L .4916 .66784 L F
.589 .331 .494 r
.61508 .57982 m .61497 .58163 L .61281 .58189 L F
.512 .222 .41 r
.61769 .57966 m .61497 .58163 L .61508 .57982 L F
.381 0 0 r
.41422 .64986 m .41645 .64996 L .41755 .64941 L F
.023 0 0 r
.41645 .64996 m .41994 .64976 L .41755 .64941 L F
.3 .709 .975 r
.66341 .49282 m .66217 .49204 L .65994 .49199 L F
.88 .884 .832 r
.66341 .49282 m .65985 .49495 L .66217 .49204 L F
.871 .555 .449 r
.48982 .68513 m .49149 .68869 L .49366 .68854 L F
.835 .463 .351 r
.49149 .68869 m .49153 .69022 L .49366 .68854 L F
.275 .143 .513 r
.49366 .68854 m .49511 .68822 L .49502 .68583 L F
.792 .581 .615 r
.49153 .69022 m .49511 .68822 L .49366 .68854 L F
0 0 0 r
.63846 .55431 m .64024 .5535 L .63765 .55582 L F
.865 .775 .76 r
.65672 .52027 m .65733 .5238 L .65821 .52147 L F
.65672 .52027 m .6546 .52373 L .65733 .5238 L F
.865 .773 .758 r
.6546 .52373 m .65565 .52638 L .65733 .5238 L F
.376 .73 .99 r
.75198 .61009 m .75299 .61101 L .75533 .61097 L F
.38 .556 .902 r
.33508 .6041 m .33575 .60158 L .3335 .6025 L F
.33508 .6041 m .33685 .60424 L .33575 .60158 L F
.626 .554 .753 r
.25022 .64418 m .25095 .64174 L .24898 .64133 L F
.25037 .64415 m .2526 .6437 L .25193 .6429 L F
.25022 .64418 m .25164 .644 L .2526 .6437 L F
.829 .443 0 r
.2526 .6437 m .25248 .64474 L .2521 .64269 L F
.2526 .6437 m .25332 .64582 L .25248 .64474 L F
.118 0 .237 r
.2522 .64269 m .25248 .64474 L .25347 .64263 L F
.2521 .64269 m .25211 .64276 L .2522 .64269 L F
.25211 .64276 m .25248 .64474 L .2522 .64269 L F
.626 .554 .753 r
.25022 .64418 m .25037 .64415 L .25095 .64174 L F
.25037 .64415 m .25193 .6429 L .25095 .64174 L F
.612 .458 .649 r
.25031 .64546 m .25164 .644 L .25022 .64418 L F
.593 .652 .878 r
.3718 .71111 m .37484 .71089 L .372 .70993 L F
.575 .391 .595 r
.47101 .76153 m .47342 .76126 L .47358 .75877 L F
.534 .522 .788 r
.47302 .76259 m .47342 .76126 L .47101 .76153 L F
.477 .538 .84 r
.68784 .48861 m .68956 .48611 L .68731 .48656 L F
.68784 .48861 m .69073 .48899 L .68956 .48611 L F
.556 .839 .998 r
.33789 .59187 m .33421 .59168 L .33646 .59126 L F
.336 .758 .975 r
.33874 .59105 m .33789 .59187 L .33646 .59126 L F
.33874 .59105 m .33979 .59168 L .33789 .59187 L F
.758 .657 .75 r
.49502 .68583 m .49854 .68633 L .49725 .68302 L F
.877 .832 .799 r
.49511 .68822 m .49854 .68633 L .49502 .68583 L F
.565 .565 .812 r
.27699 .62669 m .27643 .63077 L .27539 .62697 L F
.27699 .62669 m .27844 .63033 L .27643 .63077 L F
.486 .803 1 r
.29511 .64954 m .2957 .64833 L .29359 .64885 L F
.29511 .64954 m .29723 .64918 L .2957 .64833 L F
.683 .795 .934 r
.70798 .48468 m .70555 .48579 L .7047 .48449 L F
.75 .233 0 r
.54481 .72566 m .54694 .72789 L .54829 .72821 L F
.703 .224 .109 r
.54694 .72789 m .5509 .72957 L .54829 .72821 L F
.298 .274 .663 r
.4925 .78599 m .49117 .7862 L .49064 .78407 L F
.762 .521 .569 r
.48049 .68539 m .48343 .68335 L .47976 .68398 L F
.48049 .68539 m .48354 .6857 L .48343 .68335 L F
.716 .534 .641 r
.48354 .6857 m .48582 .68316 L .48343 .68335 L F
.31 .774 .943 r
.42572 .64966 m .42788 .64942 L .42922 .64981 L F
.485 .866 .978 r
.42922 .64981 m .43005 .64882 L .4314 .64934 L F
.42922 .64981 m .42788 .64942 L .43005 .64882 L F
.703 .319 .318 r
.52155 .76511 m .52046 .76667 L .51811 .76646 L F
.453 .038 .16 r
.52349 .76584 m .52155 .76511 L .52357 .76457 L F
.52349 .76584 m .52046 .76667 L .52155 .76511 L F
.724 .419 .463 r
.54582 .76898 m .54197 .76952 L .54186 .76751 L F
.554 .415 .646 r
.56043 .77245 m .55896 .7756 L .55812 .77286 L F
.888 .603 .499 r
.67033 .50567 m .67236 .50378 L .67014 .50384 L F
.67033 .50567 m .67192 .50646 L .67236 .50378 L F
.859 .572 .501 r
.67236 .50378 m .67192 .50646 L .67478 .50699 L F
.609 .73 .931 r
.70873 .5122 m .70807 .51342 L .70687 .5128 L F
.70807 .51342 m .70743 .5146 L .70727 .51406 L F
.70807 .51342 m .70727 .51406 L .70687 .5128 L F
.621 .953 .924 r
.70803 .51435 m .70598 .51558 L .70525 .51567 L F
.7061 .51499 m .70525 .51567 L .70337 .51588 L F
.70803 .51435 m .70525 .51567 L .7061 .51499 L F
.784 .739 .812 r
.71379 .48288 m .71009 .48365 L .71277 .48169 L F
.749 .838 .919 r
.71478 .48032 m .71379 .48288 L .71277 .48169 L F
.71478 .48032 m .7158 .48162 L .71379 .48288 L F
.659 .634 .814 r
.67296 .53795 m .67412 .53404 L .6718 .53642 L F
.67296 .53795 m .67547 .53719 L .67412 .53404 L F
0 0 .418 r
.32977 .74818 m .32987 .74819 L .32963 .74699 L F
.521 .296 .514 r
.33237 .7461 m .32987 .74819 L .32963 .74699 L F
.32963 .74699 m .32987 .74819 L .33237 .7461 L F
.723 .532 .632 r
.50731 .66363 m .50577 .66115 L .50731 .66089 L F
.655 .556 .731 r
.51041 .66036 m .50731 .66089 L .50698 .65981 L F
.748 .239 0 r
.37028 .70244 m .37229 .70465 L .37252 .70358 L F
.803 .314 .014 r
.37229 .70465 m .37428 .70558 L .37252 .70358 L F
.536 .745 .972 r
.61117 .54161 m .61227 .54305 L .61001 .54344 L F
.463 .294 .565 r
.49712 .67348 m .49833 .67227 L .49688 .6718 L F
.299 0 .157 r
.25315 .59109 m .25028 .59318 L .25221 .59259 L F
.244 0 .047 r
.25221 .59259 m .25523 .59066 L .25315 .59109 L F
.607 .753 .948 r
.61183 .53336 m .61072 .53518 L .61334 .53447 L F
.798 .628 .671 r
.61183 .53336 m .61371 .53671 L .61072 .53518 L F
.499 .4 .674 r
.61371 .53671 m .61145 .53795 L .61072 .53518 L F
.572 .616 .858 r
.41039 .69663 m .40684 .69455 L .40894 .69561 L F
.5 .747 .983 r
.41128 .69532 m .41039 .69663 L .40894 .69561 L F
.41128 .69532 m .41264 .69641 L .41039 .69663 L F
.993 .857 .594 r
.45897 .65734 m .45968 .65855 L .46031 .65795 L F
.343 .761 .978 r
.46031 .65795 m .46283 .65789 L .45897 .65734 L F
.46031 .65795 m .46283 .65789 L .45897 .65734 L F
.612 .346 .49 r
.48044 .76961 m .48348 .76704 L .48114 .76706 L F
.237 .753 .832 r
.66647 .48359 m .66571 .48353 L .66408 .484 L F
0 0 .401 r
.66487 .48541 m .66408 .484 L .66571 .48353 L F
.66487 .48541 m .66452 .48701 L .66408 .484 L F
.459 .033 .143 r
.5414 .72743 m .54367 .72737 L .54481 .72566 L F
.733 .34 .307 r
.54367 .72737 m .54694 .72789 L .54481 .72566 L F
.717 .597 .721 r
.48217 .66633 m .48577 .66897 L .48439 .66569 L F
.48217 .66633 m .4834 .66969 L .48577 .66897 L F
.655 .608 .789 r
.48439 .66569 m .48577 .66897 L .48762 .66621 L F
.424 .617 .931 r
.67267 .48406 m .67464 .48348 L .67264 .48347 L F
.264 .133 .507 r
.67326 .4861 m .67464 .48348 L .67267 .48406 L F
.15 0 0 r
.41994 .64976 m .42227 .64977 L .42345 .64951 L F
.271 .768 .893 r
.42227 .64977 m .42572 .64966 L .42345 .64951 L F
0 0 .328 r
.52 .78313 m .52073 .78452 L .51801 .7831 L F
.655 .556 .731 r
.51041 .66036 m .50698 .65981 L .50931 .65884 L F
.586 .516 .743 r
.63513 .4789 m .6371 .48139 L .63456 .48201 L F
.747 .6 .693 r
.63555 .4802 m .63456 .48201 L .6371 .48139 L F
.63555 .4802 m .6329 .48229 L .63456 .48201 L F
.823 .445 .339 r
.56434 .72469 m .56083 .72196 L .56364 .723 L F
.817 .766 .805 r
.25334 .65417 m .25279 .6562 L .25468 .65506 L F
.25334 .65417 m .25125 .6571 L .25279 .6562 L F
.715 .829 .936 r
.74378 .58688 m .74282 .58928 L .73976 .58971 L F
.74378 .58688 m .74483 .58811 L .74282 .58928 L F
.584 .396 .593 r
.28346 .61063 m .28326 .61282 L .28111 .61313 L F
.39 .262 .583 r
.28313 .61518 m .28111 .61313 L .28326 .61282 L F
.28313 .61518 m .28109 .6162 L .28111 .61313 L F
.606 .288 .404 r
.49836 .6903 m .50086 .69097 L .50288 .68805 L F
.703 .411 .477 r
.50086 .69097 m .50383 .68917 L .50288 .68805 L F
.53 .328 .552 r
.36985 .6047 m .36945 .60664 L .36723 .60719 L F
.4 .044 .241 r
.36723 .60719 m .36852 .60886 L .36642 .60947 L F
.36723 .60719 m .36945 .60664 L .36852 .60886 L F
.342 .125 .433 r
.55926 .69982 m .5613 .69695 L .55918 .69741 L F
.537 .752 .975 r
.31615 .60113 m .31966 .60213 L .31808 .60089 L F
.635 .802 .963 r
.31808 .60089 m .31966 .60213 L .32166 .60133 L F
.467 .228 .468 r
.28594 .61011 m .28326 .61282 L .28346 .61063 L F
.554 .761 .974 r
.29578 .63364 m .29481 .63507 L .29367 .63423 L F
.29578 .63364 m .29687 .63467 L .29481 .63507 L F
.572 .481 .713 r
.27622 .62097 m .27447 .6238 L .27454 .62161 L F
.162 0 .005 r
.53768 .79482 m .53928 .7928 L .54123 .79205 L F
.684 .515 .651 r
.61248 .55697 m .61587 .55844 L .61593 .55741 L F
.279 0 .199 r
.61587 .55844 m .6181 .55662 L .61593 .55741 L F
.184 0 .146 r
.5613 .69695 m .56403 .69453 L .56144 .69585 L F
.728 .796 .906 r
.37859 .71086 m .37484 .71089 L .37713 .70901 L F
.693 .828 .948 r
.37703 .70918 m .37484 .71089 L .37859 .71086 L F
0 0 0 r
.37698 .70922 m .37484 .71089 L .37685 .70939 L F
.37713 .70901 m .37484 .71089 L .37698 .70922 L F
.693 .828 .948 r
.37695 .7091 m .37484 .71089 L .37703 .70918 L F
.126 .473 .895 r
.37713 .70901 m .3792 .71009 L .37859 .71086 L F
.678 .233 .187 r
.37699 .7092 m .3792 .71009 L .37713 .70901 L F
.189 .561 .935 r
.37859 .71086 m .3792 .71009 L .37707 .70923 L F
.678 .233 .187 r
.37685 .70939 m .3792 .71009 L .37699 .7092 L F
.189 .561 .935 r
.37707 .70923 m .3792 .71009 L .37695 .7091 L F
.685 .553 .699 r
.37859 .71086 m .38037 .7109 L .38071 .70844 L F
.804 .99 .882 r
.52734 .81022 m .53044 .80838 L .53019 .80936 L F
.252 0 .069 r
.53019 .80936 m .53044 .80838 L .53235 .80861 L F
.08 .236 .725 r
.40768 .69331 m .40684 .69455 L .40569 .69126 L F
.216 .429 .854 r
.40768 .69331 m .40894 .69561 L .40684 .69455 L F
.452 .294 .576 r
.40183 .67445 m .39988 .67742 L .39965 .67493 L F
.552 .363 .579 r
.4997 .74327 m .49925 .74472 L .50135 .74217 L F
.69 .642 .798 r
.72293 .48714 m .72164 .48889 L .71949 .48689 L F
.354 .128 .426 r
.47358 .75877 m .47534 .75826 L .4757 .75619 L F
.562 .443 .675 r
.47342 .76126 m .47534 .75826 L .47358 .75877 L F
.859 .494 .357 r
.48039 .80671 m .47684 .80492 L .47867 .80496 L F
.48039 .80671 m .47896 .80843 L .47684 .80492 L F
.809 .419 .315 r
.48096 .80848 m .47896 .80843 L .48039 .80671 L F
.35 0 .163 r
.31887 .62983 m .32098 .62935 L .32218 .62727 L F
.429 .115 .329 r
.32098 .62935 m .32402 .62632 L .32218 .62727 L F
.723 .532 .632 r
.50731 .66363 m .50531 .66385 L .50577 .66115 L F
0 0 0 r
.61818 .54077 m .61655 .54217 L .61509 .54321 L F
.802 .722 .776 r
.62036 .53766 m .61818 .54077 L .61675 .5381 L F
.466 .272 .533 r
.62033 .54003 m .61818 .54077 L .62036 .53766 L F
.804 .962 .641 r
.61889 .5389 m .61818 .54077 L .62033 .54003 L F
.61889 .5389 m .61655 .54217 L .61818 .54077 L F
.689 .839 .955 r
.6784 .48662 m .67699 .4889 L .68168 .48682 L F
.541 .639 .896 r
.67718 .48892 m .67699 .4889 L .6784 .48662 L F
.977 .713 .307 r
.7067 .50859 m .70569 .50578 L .70694 .50702 L F
.998 .788 .443 r
.70584 .50558 m .7067 .50859 L .70694 .50702 L F
.842 .892 .875 r
.64402 .54717 m .64384 .54966 L .64508 .54803 L F
.907 .937 .818 r
.64221 .54959 m .64384 .54966 L .64402 .54717 L F
.224 0 .149 r
.29083 .60698 m .2879 .60957 L .28886 .60784 L F
.791 .549 .571 r
.67962 .50566 m .68285 .50407 L .68072 .50695 L F
.496 .319 .571 r
.68285 .50407 m .68294 .5064 L .68072 .50695 L F
.545 .781 .986 r
.68072 .50695 m .68294 .5064 L .67962 .50566 L F
0 0 0 r
.64074 .50419 m .63929 .50432 L .64166 .5043 L F
.64074 .50419 m .63806 .50512 L .63929 .50432 L F
.873 .879 .836 r
.52886 .74651 m .52903 .74818 L .52787 .74685 L F
.369 .496 .856 r
.52903 .74818 m .53026 .74664 L .52787 .74685 L F
.52903 .74818 m .53136 .74849 L .53026 .74664 L F
.66 .408 .528 r
.57907 .69037 m .5744 .68898 L .5776 .68888 L F
.404 .396 .737 r
.57876 .68819 m .57907 .69037 L .5776 .68888 L F
.682 .795 .934 r
.77385 .61463 m .77706 .6147 L .77657 .61321 L F
.745 .832 .918 r
.77706 .6147 m .77965 .61322 L .77657 .61321 L F
.362 .345 .706 r
.75567 .60073 m .75383 .60244 L .75352 .59888 L F
.456 .498 .814 r
.75567 .60073 m .75679 .60376 L .75383 .60244 L F
.304 .499 .883 r
.75743 .60553 m .75383 .60244 L .75679 .60376 L F
.679 .298 .317 r
.53843 .7973 m .53677 .79515 L .53661 .79725 L F
.464 .132 .318 r
.52826 .76128 m .53053 .76085 L .53173 .75797 L F
.481 .137 .305 r
.53053 .76085 m .53378 .75822 L .53173 .75797 L F
.421 0 .062 r
.40142 .65406 m .40059 .65254 L .39909 .65399 L F
.40142 .65406 m .40286 .65247 L .40059 .65254 L F
.592 .529 .753 r
.74213 .60266 m .74278 .60463 L .74531 .60398 L F
.435 .201 .459 r
.38071 .70844 m .38264 .70817 L .38307 .7057 L F
.556 .726 .954 r
.38307 .7057 m .3831 .70269 L .38163 .70242 L F
.38307 .7057 m .38541 .70548 L .3831 .70269 L F
.411 .119 .356 r
.38264 .70817 m .38541 .70548 L .38307 .7057 L F
.483 .802 1 r
.68121 .54011 m .6823 .54104 L .68459 .54063 L F
.011 0 .337 r
.66976 .49789 m .66948 .50032 L .66803 .50127 L F
.806 .42 .324 r
.66688 .50262 m .67014 .50384 L .66803 .50127 L F
.66688 .50262 m .66803 .50127 L .66948 .50032 L F
.593 .492 .709 r
.52324 .73627 m .52436 .73939 L .52664 .73883 L F
.566 .565 .811 r
.37585 .68606 m .37672 .68243 L .37526 .68318 L F
.37585 .68606 m .37796 .68563 L .37672 .68243 L F
.534 .439 .694 r
.37638 .68852 m .37796 .68563 L .37585 .68606 L F
.421 .732 .99 r
.35411 .59423 m .35281 .59457 L .35111 .59327 L F
.981 .712 .443 r
.55122 .78105 m .55077 .78393 L .54858 .78066 L F
.55122 .78105 m .55169 .78339 L .55077 .78393 L F
0 .047 .567 r
.55294 .78311 m .55122 .78105 L .55365 .78088 L F
.55294 .78311 m .55169 .78339 L .55122 .78105 L F
.535 .329 .547 r
.49572 .7955 m .49508 .79789 L .49369 .7975 L F
.069 .278 .767 r
.6371 .48139 m .63842 .48421 L .63908 .48297 L F
.107 .33 .801 r
.63842 .48421 m .64054 .48534 L .63908 .48297 L F
0 0 .317 r
.54621 .75089 m .54656 .75003 L .54574 .7528 L F
.376 .815 .665 r
.49636 .78398 m .49391 .78524 L .4925 .78599 L F
.556 .214 .343 r
.49892 .78345 m .49391 .78524 L .49636 .78398 L F
.576 .373 .569 r
.69092 .50085 m .69273 .49894 L .6913 .49923 L F
.972 .716 .488 r
.64641 .48226 m .64784 .48599 L .64596 .48386 L F
0 .136 .676 r
.64596 .48386 m .64784 .48599 L .64693 .48631 L F
.972 .716 .488 r
.64641 .48226 m .64669 .48549 L .64784 .48599 L F
.225 .457 .873 r
.64859 .48573 m .64784 .48599 L .64669 .48549 L F
.65027 .48595 m .64784 .48599 L .64859 .48573 L F
0 .136 .676 r
.64693 .48631 m .64784 .48599 L .64729 .48721 L F
.09 .387 .846 r
.64784 .48599 m .64994 .48871 L .64729 .48721 L F
.462 .879 .935 r
.66881 .47927 m .66986 .47838 L .67101 .47868 L F
.66881 .47927 m .66783 .47905 L .66986 .47838 L F
.528 .111 .194 r
.52939 .80788 m .52985 .80629 L .52755 .80614 L F
.87 .738 .713 r
.57534 .68485 m .58024 .68404 L .57523 .68336 L F
.512 .327 .567 r
.584 .68052 m .58439 .68278 L .58218 .68332 L F
.648 .626 .814 r
.57762 .68086 m .58024 .68404 L .58323 .68192 L F
.49 .05 .128 r
.43742 .66094 m .43597 .66267 L .43383 .66256 L F
.565 .133 .179 r
.43876 .66197 m .43742 .66094 L .43944 .66037 L F
.43876 .66197 m .43597 .66267 L .43742 .66094 L F
.296 .014 .303 r
.71247 .49511 m .71052 .49604 L .71016 .49756 L F
.751 .618 .711 r
.49101 .81458 m .49463 .81561 L .49316 .81179 L F
.739 .215 0 r
.49695 .81477 m .49316 .81179 L .49463 .81561 L F
.037 .602 .784 r
.29723 .64918 m .30081 .64946 L .29927 .64926 L F
.179 .714 .777 r
.30081 .64946 m .30149 .64922 L .29927 .64926 L F
.30081 .64946 m .30293 .64911 L .30149 .64922 L F
.993 .857 .594 r
.45897 .65734 m .45839 .65794 L .45968 .65855 L F
.593 .859 .994 r
.46584 .64427 m .46235 .64422 L .46452 .64349 L F
.717 .918 .962 r
.46792 .64305 m .46584 .64427 L .46663 .64242 L F
.688 .887 .971 r
.46584 .64427 m .46452 .64349 L .46663 .64242 L F
.783 .449 .422 r
.49015 .80057 m .48748 .8025 L .48734 .80013 L F
.49015 .80057 m .49091 .80292 L .48748 .8025 L F
.468 .022 .105 r
.45945 .68338 m .46151 .68431 L .46276 .68264 L F
.498 .04 .096 r
.46151 .68431 m .46514 .68286 L .46276 .68264 L F
.175 .7 .867 r
.54238 .80013 m .54359 .80039 L .54015 .80023 L F
.597 .937 .75 r
.54453 .79927 m .54359 .80039 L .54238 .80013 L F
.54453 .79927 m .54642 .79831 L .54359 .80039 L F
.063 .605 .849 r
.50112 .6377 m .50451 .63833 L .50244 .63837 L F
.418 .181 .446 r
.34555 .6275 m .34787 .62468 L .34753 .62692 L F
.511 .329 .57 r
.35004 .62161 m .35007 .62416 L .34787 .62468 L F
.478 .243 .478 r
.34787 .62468 m .3497 .62646 L .34753 .62692 L F
.34787 .62468 m .35007 .62416 L .3497 .62646 L F
.048 .564 .874 r
.63915 .47997 m .6425 .48107 L .64023 .48104 L F
.559 .308 .493 r
.56907 .68911 m .57136 .69088 L .57103 .68826 L F
.56907 .68911 m .56876 .69142 L .57136 .69088 L F
.442 .189 .434 r
.35762 .6143 m .35669 .61809 L .3546 .61863 L F
.425 .173 .427 r
.35863 .61749 m .35762 .6143 L .35943 .61448 L F
.35863 .61749 m .35669 .61809 L .35762 .6143 L F
.541 .639 .896 r
.67718 .48892 m .6784 .48662 L .67594 .48772 L F
.534 .522 .788 r
.47302 .76259 m .47526 .76485 L .47342 .76126 L F
.15 .663 .896 r
.47065 .76613 m .47526 .76485 L .47302 .76259 L F
.424 .816 .987 r
.45873 .64403 m .46235 .64422 L .46005 .64463 L F
.959 .944 .699 r
.58736 .71973 m .58614 .72271 L .58551 .72114 L F
.983 .825 .609 r
.58614 .72271 m .58546 .72494 L .58364 .72337 L F
.285 .783 .863 r
.45286 .64499 m .45669 .64462 L .45438 .64522 L F
.806 .365 .194 r
.47851 .68457 m .47976 .68398 L .47656 .6829 L F
.47851 .68457 m .48049 .68539 L .47976 .68398 L F
.558 .358 .566 r
.37595 .66018 m .3784 .66033 L .37869 .65804 L F
.555 .404 .631 r
.37595 .66018 m .37829 .66286 L .3784 .66033 L F
.37595 .66018 m .3762 .66328 L .37829 .66286 L F
0 0 0 r
.64347 .51242 m .64465 .5117 L .64562 .50943 L F
.376 .658 .968 r
.64465 .5117 m .64465 .51423 L .64347 .51242 L F
.648 .273 .32 r
.52722 .76431 m .52578 .76644 L .52357 .76457 L F
.741 .386 .38 r
.52722 .76431 m .52886 .76689 L .52578 .76644 L F
.375 .772 .986 r
.32166 .60133 m .32568 .60186 L .32466 .60089 L F
.327 .691 .98 r
.32466 .60089 m .32568 .60186 L .32737 .6019 L F
.802 .722 .776 r
.62036 .53766 m .61889 .5389 L .62033 .54003 L F
.62036 .53766 m .61675 .5381 L .61889 .5389 L F
.488 .29 .537 r
.62036 .53766 m .62033 .54003 L .62256 .53715 L F
.62256 .53715 m .62033 .54003 L .62036 .53766 L F
.687 .431 .53 r
.48709 .75752 m .49026 .75834 L .48783 .75653 L F
.529 .395 .643 r
.63281 .53138 m .63054 .52973 L .63352 .52953 L F
.683 .702 .861 r
.49513 .63556 m .4967 .63866 L .4933 .63802 L F
.164 .391 .837 r
.49744 .63729 m .4967 .63866 L .49513 .63556 L F
.605 .922 .972 r
.49906 .6377 m .4967 .63866 L .49744 .63729 L F
.456 .313 .597 r
.33613 .61041 m .33806 .61238 L .33752 .60989 L F
.33613 .61041 m .33621 .61319 L .33806 .61238 L F
.81 .719 .764 r
.57127 .57062 m .57336 .56766 L .57431 .57109 L F
.818 .693 .727 r
.57127 .57062 m .57431 .57109 L .57254 .5739 L F
.844 .737 .745 r
.57336 .56766 m .57508 .56871 L .57431 .57109 L F
.725 .643 .766 r
.38037 .7109 m .38264 .70817 L .38071 .70844 L F
.501 .755 .987 r
.26512 .64863 m .26873 .64952 L .26773 .64819 L F
.004 .537 .846 r
.27079 .64916 m .26773 .64819 L .26873 .64952 L F
.648 .626 .814 r
.57762 .68086 m .58323 .68192 L .58137 .67984 L F
.67 .173 0 r
.58323 .68192 m .58311 .68201 L .58137 .67984 L F
.96 .634 .346 r
.58311 .68201 m .584 .68052 L .58137 .67984 L F
.58311 .68201 m .58439 .68278 L .584 .68052 L F
.746 .235 0 r
.50921 .79086 m .5083 .79084 L .50813 .78877 L F
.50921 .79086 m .50968 .7916 L .5083 .79084 L F
.721 .468 .544 r
.49541 .76854 m .49267 .76968 L .49264 .76809 L F
.484 .196 .4 r
.62305 .48663 m .62562 .48438 L .62349 .48509 L F
.754 .528 .588 r
.47346 .68329 m .47656 .6829 L .47661 .68046 L F
.413 0 .113 r
.55049 .71605 m .55286 .71589 L .55384 .71408 L F
0 0 0 r
.55384 .71408 m .55481 .71416 L .55621 .71501 L F
.55384 .71408 m .55286 .71589 L .55481 .71416 L F
.848 .722 .725 r
.59532 .73074 m .59605 .72852 L .5942 .72759 L F
.554 .316 .508 r
.36249 .70497 m .36479 .70578 L .36503 .70274 L F
.515 .283 .501 r
.36503 .70274 m .36642 .70426 L .36674 .70288 L F
.36503 .70274 m .36479 .70578 L .36642 .70426 L F
.655 .969 .898 r
.70943 .52255 m .71298 .52113 L .71244 .52089 L F
.679 .973 .909 r
.71424 .51949 m .71298 .52113 L .71499 .51948 L F
.682 .979 .86 r
.71424 .51949 m .71244 .52089 L .71298 .52113 L F
.61 .472 .669 r
.61799 .55443 m .61993 .5509 L .61709 .55097 L F
.614 .525 .73 r
.38516 .71493 m .38545 .71676 L .38783 .7162 L F
.307 .01 .287 r
.3616 .61241 m .36223 .61064 L .36424 .60979 L F
.498 .236 .447 r
.58567 .71649 m .58815 .71336 L .58597 .71403 L F
.673 .498 .641 r
.60456 .55987 m .60706 .55737 L .60457 .55749 L F
.60456 .55987 m .60799 .55976 L .60706 .55737 L F
.632 .514 .701 r
.60706 .55737 m .61031 .55764 L .6091 .55418 L F
.724 .523 .619 r
.60706 .55737 m .61033 .55975 L .61031 .55764 L F
.60706 .55737 m .60799 .55976 L .61033 .55975 L F
.903 .81 .335 r
.67773 .52545 m .67817 .52509 L .67841 .52366 L F
0 0 0 r
.67773 .52545 m .67971 .52225 L .67895 .52442 L F
.461 .819 .549 r
.67734 .52576 m .67773 .52545 L .67895 .52442 L F
.67657 .52641 m .67773 .52545 L .67734 .52576 L F
.903 .81 .335 r
.67773 .52545 m .678 .52614 L .67817 .52509 L F
0 0 .146 r
.67841 .52366 m .67894 .5203 L .67971 .52225 L F
.736 .434 .469 r
.58221 .58782 m .58428 .58838 L .58427 .59035 L F
.637 .378 .509 r
.58777 .58767 m .58427 .59035 L .58428 .58838 L F
.038 .537 .878 r
.31968 .58958 m .32145 .58999 L .32294 .59085 L F
.457 .811 .997 r
.32354 .58977 m .32294 .59085 L .32145 .58999 L F
.32354 .58977 m .32504 .59048 L .32294 .59085 L F
.396 .331 .667 r
.37444 .66644 m .37651 .66839 L .37611 .66571 L F
.473 .337 .615 r
.37444 .66644 m .3746 .66899 L .37651 .66839 L F
.375 0 0 r
.59437 .70136 m .59034 .69916 L .59141 .70072 L F
.786 .701 .77 r
.65637 .49216 m .65808 .49566 L .65994 .49199 L F
.882 .719 .204 r
.65808 .49566 m .65789 .49776 L .65985 .49495 L F
.386 0 .039 r
.63235 .50244 m .63471 .50232 L .63595 .5007 L F
.565 .173 .257 r
.63471 .50232 m .63804 .50061 L .63595 .5007 L F
.604 .459 .658 r
.53438 .73078 m .53652 .73054 L .53662 .72816 L F
.599 .391 .571 r
.53436 .73327 m .53652 .73054 L .53438 .73078 L F
.759 .723 .819 r
.47565 .66294 m .47311 .664 L .47567 .66381 L F
.532 .54 .808 r
.47565 .66294 m .47567 .66381 L .47725 .66299 L F
.381 .308 .649 r
.47567 .66381 m .47758 .66545 L .47725 .66299 L F
.47567 .66381 m .47592 .66642 L .47758 .66545 L F
.281 .182 .56 r
.58311 .68201 m .58218 .68332 L .58439 .68278 L F
.58311 .68201 m .58132 .68504 L .58218 .68332 L F
.27 0 0 r
.41194 .66843 m .40844 .67075 L .40976 .66882 L F
.204 .461 .881 r
.53826 .80357 m .53425 .80047 L .53786 .80077 L F
.608 .632 .849 r
.53843 .7973 m .54015 .80023 L .53786 .80077 L F
.421 .399 .729 r
.5226 .68228 m .52081 .68395 L .52019 .68287 L F
.5226 .68228 m .52252 .68468 L .52081 .68395 L F
.428 .395 .72 r
.52252 .68468 m .52143 .68656 L .52081 .68395 L F
.493 .167 .342 r
.45042 .69493 m .4506 .69711 L .44742 .69661 L F
.47 .151 .342 r
.45249 .69614 m .4506 .69711 L .45042 .69493 L F
.582 .234 .344 r
.56263 .70246 m .56211 .70488 L .55929 .70484 L F
.518 .321 .553 r
.56377 .7014 m .56211 .70488 L .56263 .70246 L F
.576 .407 .615 r
.49791 .79476 m .49508 .79789 L .49572 .7955 L F
.37 0 0 r
.52143 .68656 m .51802 .6878 L .51834 .68565 L F
.52143 .68656 m .52032 .68781 L .51802 .6878 L F
.444 .156 .38 r
.52252 .68468 m .52032 .68781 L .52143 .68656 L F
.976 .752 .537 r
.59096 .70853 m .59057 .7108 L .5893 .70996 L F
.794 .966 .657 r
.31018 .66639 m .3081 .66925 L .30854 .66781 L F
.465 .27 .531 r
.31018 .66639 m .31044 .66904 L .3081 .66925 L F
.909 .652 .536 r
.31044 .66904 m .30854 .66781 L .3081 .66925 L F
.66 .408 .528 r
.57907 .69037 m .57427 .69133 L .5744 .68898 L F
0 .024 .584 r
.51001 .78608 m .50872 .78431 L .51002 .78345 L F
.593 .387 .571 r
.47448 .77828 m .47703 .77847 L .47712 .77555 L F
.429 .261 .551 r
.47712 .77555 m .4793 .77508 L .47898 .77263 L F
.438 .261 .543 r
.47712 .77555 m .47891 .77754 L .4793 .77508 L F
.47712 .77555 m .47703 .77847 L .47891 .77754 L F
.504 .618 .898 r
.76012 .60545 m .75743 .60553 L .75679 .60376 L F
0 .451 .781 r
.64776 .50564 m .64434 .50438 L .64501 .50422 L F
.357 .132 .43 r
.64068 .51482 m .64313 .51566 L .64465 .51423 L F
.376 .658 .968 r
.64465 .5117 m .64704 .51414 L .64465 .51423 L F
.503 0 0 r
.64465 .51423 m .64728 .51554 L .64704 .51414 L F
.64465 .51423 m .64313 .51566 L .64728 .51554 L F
.597 .747 .949 r
.75895 .61261 m .76047 .61012 L .75777 .6107 L F
.75895 .61261 m .76157 .61218 L .76047 .61012 L F
.659 .528 .693 r
.49497 .76667 m .49264 .76809 L .49445 .76461 L F
.443 .531 .853 r
.38909 .71877 m .3895 .71619 L .38783 .7162 L F
.181 0 .117 r
.59676 .69945 m .59437 .70136 L .59477 .70273 L F
.26 .027 .358 r
.62843 .56507 m .629 .56307 L .63063 .56205 L F
.489 .872 .673 r
.51212 .79353 m .51326 .79288 L .51457 .79189 L F
.169 0 0 r
.56232 .76617 m .56379 .76614 L .56487 .76438 L F
.71 .62 .754 r
.48582 .68316 m .48979 .6833 L .48805 .68034 L F
.698 .518 .641 r
.48582 .68316 m .48982 .68513 L .48979 .6833 L F
.933 .788 .678 r
.57354 .72986 m .57514 .73077 L .57609 .72696 L F
.57354 .72986 m .57609 .72696 L .57597 .72737 L F
.639 .084 0 r
.57347 .72518 m .57597 .72737 L .57609 .72696 L F
.613 .252 .334 r
.58221 .58782 m .5808 .58974 L .57861 .58833 L F
.756 .431 .435 r
.58221 .58782 m .58427 .59035 L .5808 .58974 L F
.322 .36 .745 r
.24815 .63566 m .24881 .63522 L .24784 .63461 L F
.445 .86 .706 r
.24775 .63585 m .24881 .63522 L .24815 .63566 L F
.085 0 0 r
.44528 .65867 m .44389 .65946 L .44165 .65984 L F
.358 0 0 r
.44835 .65937 m .44389 .65946 L .44528 .65867 L F
0 0 .194 r
.64562 .50943 m .64722 .50798 L .64776 .50564 L F
0 0 0 r
.64562 .50943 m .64465 .5117 L .64722 .50798 L F
.875 .994 .78 r
.59087 .53952 m .59349 .5374 L .59172 .54046 L F
.59087 .53952 m .59299 .53679 L .59349 .5374 L F
.824 .985 .709 r
.59299 .53679 m .59556 .53428 L .59349 .5374 L F
.517 .132 .25 r
.52787 .74685 m .53136 .74461 L .52886 .74651 L F
.52787 .74685 m .53026 .74664 L .53136 .74461 L F
.752 .532 .598 r
.53026 .74664 m .53309 .74387 L .53136 .74461 L F
.488 .266 .503 r
.35243 .619 m .35213 .62121 L .35004 .62161 L F
.441 .275 .558 r
.35195 .62354 m .35004 .62161 L .35213 .62121 L F
.35195 .62354 m .35007 .62416 L .35004 .62161 L F
.465 .246 .496 r
.35419 .62081 m .35243 .619 L .3546 .61863 L F
.35419 .62081 m .35213 .62121 L .35243 .619 L F
0 0 .106 r
.50713 .81206 m .50593 .81518 L .50469 .81412 L F
.309 0 0 r
.50593 .81518 m .5083 .81517 L .50688 .81611 L F
.558 .533 .783 r
.74133 .59936 m .74213 .60266 L .7448 .60114 L F
.592 .529 .753 r
.74213 .60266 m .74531 .60398 L .7448 .60114 L F
.626 .285 .374 r
.45346 .68495 m .45588 .68525 L .45374 .68341 L F
.386 .09 .334 r
.34289 .62992 m .34555 .6275 L .34495 .62937 L F
.399 .113 .358 r
.34495 .62937 m .34555 .6275 L .34753 .62692 L F
.722 .608 .73 r
.59178 .7282 m .59416 .732 L .59532 .73074 L F
.647 .493 .661 r
.59532 .73074 m .59416 .732 L .59313 .73362 L F
.982 .804 .588 r
.4741 .80028 m .47231 .80254 L .47251 .79994 L F
.4741 .80028 m .47357 .80317 L .47231 .80254 L F
.715 .196 0 r
.4741 .80028 m .47704 .80317 L .47357 .80317 L F
.67 .502 .649 r
.49101 .81458 m .49316 .81179 L .49111 .81214 L F
.824 .985 .709 r
.59299 .53679 m .59521 .53388 L .59556 .53428 L F
.749 .241 0 r
.5559 .73309 m .55782 .73548 L .55902 .73617 L F
.485 0 0 r
.55782 .73548 m .56104 .73843 L .55902 .73617 L F
.666 .749 .912 r
.67547 .53719 m .67871 .53751 L .67777 .53886 L F
.786 .704 .774 r
.68061 .53511 m .67871 .53751 L .67731 .5344 L F
.868 .995 .782 r
.67929 .53537 m .67871 .53751 L .68061 .53511 L F
.635 .48 .655 r
.67871 .53751 m .68144 .53764 L .68061 .53511 L F
.55 .708 .944 r
.67929 .53537 m .68144 .53764 L .67871 .53751 L F
.831 .426 .276 r
.67871 .53751 m .67985 .53879 L .67777 .53886 L F
.614 .525 .73 r
.38516 .71493 m .38783 .7162 L .38675 .71442 L F
.985 .727 .455 r
.48087 .66312 m .48217 .66633 L .48439 .66569 L F
.48087 .66312 m .48092 .66553 L .48217 .66633 L F
.696 .754 .896 r
.76417 .57382 m .76293 .57688 L .76188 .57577 L F
.76417 .57382 m .76589 .57556 L .76293 .57688 L F
.368 0 .158 r
.32761 .64324 m .32431 .64555 L .32564 .64374 L F
.959 .944 .699 r
.58736 .71973 m .58551 .72114 L .58587 .71884 L F
.26 0 0 r
.29857 .60379 m .29496 .60597 L .29673 .60396 L F
.388 .069 .298 r
.56954 .69868 m .56808 .69765 L .56993 .69673 L F
.56954 .69868 m .56738 .69924 L .56808 .69765 L F
.534 .439 .694 r
.37638 .68852 m .37846 .6881 L .37796 .68563 L F
.487 .321 .581 r
.24078 .60206 m .24277 .60147 L .2428 .59907 L F
.464 .312 .59 r
.24087 .60456 m .24277 .60147 L .24078 .60206 L F
.038 0 .107 r
.63063 .56205 m .63144 .56044 L .63302 .5592 L F
.714 .604 .731 r
.53076 .76942 m .53175 .77271 L .53443 .77073 L F
.568 .317 .495 r
.53157 .77373 m .53471 .77461 L .53175 .77271 L F
.771 .65 .728 r
.57523 .68336 m .57762 .68086 L .57521 .68026 L F
.877 .981 .833 r
.61829 .51741 m .61659 .52091 L .61938 .5183 L F
.61829 .51741 m .61589 .5203 L .61659 .52091 L F
.253 .764 .777 r
.6162 .52225 m .61846 .52168 L .61659 .52091 L F
.628 .481 .664 r
.61659 .52091 m .61907 .52111 L .61938 .5183 L F
.474 0 0 r
.61659 .52091 m .61846 .52168 L .61907 .52111 L F
.722 .608 .73 r
.59178 .7282 m .59532 .73074 L .5942 .72759 L F
.316 .67 .975 r
.70311 .49068 m .70455 .48988 L .70218 .48969 L F
.70311 .49068 m .70523 .4907 L .70455 .48988 L F
.709 .61 .744 r
.4761 .78861 m .47754 .79272 L .47468 .79231 L F
.525 0 0 r
.47468 .79231 m .47555 .79374 L .47672 .79472 L F
.47468 .79231 m .47754 .79272 L .47555 .79374 L F
.632 .923 .655 r
.48096 .78935 m .47754 .79272 L .4761 .78861 L F
0 0 0 r
.47754 .79272 m .47772 .7939 L .47555 .79374 L F
.572 .543 .784 r
.40392 .6867 m .40235 .68837 L .40186 .68637 L F
.40392 .6867 m .40482 .68773 L .40235 .68837 L F
.805 .34 .124 r
.46777 .79296 m .46956 .79491 L .46759 .7943 L F
.662 .509 .666 r
.4844 .76145 m .48709 .75752 L .48498 .75878 L F
.923 .944 .596 r
.7193 .51271 m .71981 .51303 L .72069 .51031 L F
.243 .748 .697 r
.72231 .5122 m .71981 .51303 L .71833 .51346 L F
.895 .938 .834 r
.71179 .50009 m .71232 .5017 L .71367 .49965 L F
.954 .84 .693 r
.71069 .5018 m .71232 .5017 L .71179 .50009 L F
.71069 .5018 m .71134 .50343 L .71232 .5017 L F
.595 .529 .751 r
.37111 .60142 m .36985 .6047 L .36884 .60203 L F
.37111 .60142 m .37198 .6041 L .36985 .6047 L F
.491 .237 .457 r
.36985 .6047 m .37144 .607 L .36945 .60664 L F
.36985 .6047 m .37198 .6041 L .37144 .607 L F
.61 .558 .772 r
.50789 .79667 m .5087 .79866 L .50896 .79684 L F
.016 .571 .82 r
.31198 .58827 m .31578 .58898 L .31371 .58915 L F
.102 0 0 r
.25742 .59034 m .25941 .58977 L .26112 .58837 L F
.193 0 0 r
.25941 .58977 m .26313 .58774 L .26112 .58837 L F
.878 .816 .784 r
.33366 .74528 m .33154 .7483 L .33237 .7461 L F
.428 .832 .635 r
.33366 .74528 m .33237 .7461 L .33512 .74429 L F
.33512 .74429 m .33237 .7461 L .33366 .74528 L F
.434 .315 .618 r
.55702 .70731 m .55528 .70851 L .5549 .70558 L F
.55729 .70753 m .55675 .7078 L .55702 .70731 L F
.55675 .7078 m .55528 .70851 L .55702 .70731 L F
.641 .252 .292 r
.5549 .70558 m .55404 .70763 L .55729 .70753 L F
.531 .473 .736 r
.55679 .70291 m .55929 .70484 L .55806 .70384 L F
.55679 .70291 m .55882 .70624 L .55929 .70484 L F
.887 .819 .775 r
.55867 .70434 m .55584 .70671 L .55806 .70384 L F
.55929 .70484 m .558 .70554 L .55867 .70434 L F
.558 .70554 m .55584 .70671 L .55867 .70434 L F
.837 .372 .084 r
.56177 .74026 m .56224 .73916 L .56104 .73843 L F
.56177 .74026 m .56414 .742 L .56224 .73916 L F
.838 .385 .138 r
.56224 .73916 m .56414 .742 L .56532 .74203 L F
.748 .59 .68 r
.61938 .5183 m .61907 .52111 L .62272 .51983 L F
.12 0 0 r
.61907 .52111 m .62081 .52101 L .62272 .51983 L F
.196 0 0 r
.62272 .51983 m .62397 .52028 L .62472 .51999 L F
.62272 .51983 m .62081 .52101 L .62397 .52028 L F
.506 .418 .69 r
.37759 .69424 m .37957 .69383 L .37908 .69124 L F
.41 .176 .445 r
.4757 .75619 m .47534 .75826 L .47765 .75559 L F
.523 .342 .578 r
.2784 .61824 m .27622 .62097 L .27661 .61892 L F
.736 .912 .954 r
.6871 .53988 m .68814 .54075 L .6897 .53959 L F
0 0 0 r
.6897 .53959 m .68814 .54075 L .68754 .54122 L F
.833 .662 .67 r
.66277 .51779 m .6652 .51952 L .66249 .5202 L F
.832 .679 .693 r
.6652 .51952 m .66397 .52355 L .66249 .5202 L F
.716 .534 .641 r
.48354 .6857 m .48577 .68573 L .48582 .68316 L F
.679 .574 .73 r
.48568 .68084 m .48582 .68316 L .48805 .68034 L F
.698 .518 .641 r
.48582 .68316 m .48577 .68573 L .48982 .68513 L F
.479 .16 .348 r
.43436 .69149 m .43659 .69122 L .43756 .68859 L F
.581 .261 .392 r
.43756 .68859 m .43967 .69015 L .44007 .68878 L F
.43756 .68859 m .43659 .69122 L .43967 .69015 L F
0 0 .51 r
.68061 .53511 m .68144 .53764 L .68151 .53675 L F
.802 .32 .065 r
.68061 .53511 m .68151 .53675 L .67929 .53537 L F
.052 0 0 r
.61993 .5509 m .62233 .55021 L .62319 .54938 L F
.353 .212 .547 r
.62233 .55021 m .62466 .54758 L .62319 .54938 L F
.269 .178 .564 r
.256 .65176 m .25453 .64959 L .25551 .64867 L F
.256 .65176 m .25433 .65267 L .25453 .64959 L F
.913 .893 .478 r
.61221 .50594 m .61198 .50541 L .61294 .5041 L F
.993 .856 .509 r
.61294 .5041 m .61232 .50311 L .61282 .50085 L F
.991 .826 .449 r
.61294 .5041 m .61198 .50541 L .61232 .50311 L F
.028 .045 .54 r
.49256 .78914 m .49117 .7862 L .4925 .78599 L F
.993 .744 .409 r
.49186 .7879 m .49256 .78914 L .4925 .78599 L F
.168 .456 .883 r
.49332 .78885 m .49256 .78914 L .49186 .7879 L F
.4952 .79006 m .49256 .78914 L .49332 .78885 L F
.028 .045 .54 r
.49256 .78914 m .4914 .78987 L .49138 .7896 L F
.49256 .78914 m .49138 .7896 L .49117 .7862 L F
.37 .835 .89 r
.5083 .81517 m .51166 .81465 L .51057 .8148 L F
0 0 0 r
.51166 .81465 m .51414 .81403 L .51395 .81413 L F
.211 .735 .755 r
.51057 .8148 m .51166 .81465 L .51395 .81413 L F
0 0 0 r
.51052 .80903 m .50713 .81206 L .50986 .81171 L F
.633 .317 .418 r
.51261 .81112 m .51052 .80903 L .50986 .81171 L F
.998 .811 .523 r
.55077 .78393 m .55169 .78339 L .54982 .78602 L F
0 0 0 r
.54982 .78602 m .55169 .78339 L .55294 .78311 L F
.684 .344 .393 r
.5365 .78095 m .53527 .78348 L .53285 .78138 L F
.576 .231 .347 r
.5365 .78095 m .53878 .78296 L .53527 .78348 L F
.5365 .78095 m .53849 .78132 L .53878 .78296 L F
.374 .805 .965 r
.34415 .5915 m .34364 .59233 L .34206 .59162 L F
.34415 .5915 m .34588 .59203 L .34364 .59233 L F
.159 .698 .744 r
.71139 .48971 m .70792 .49021 L .70896 .48978 L F
.492 .783 .997 r
.71043 .48978 m .71037 .48977 L .70792 .49021 L F
0 0 0 r
.70896 .48978 m .70792 .49021 L .70529 .49068 L F
.492 .783 .997 r
.71037 .48977 m .70705 .48929 L .70792 .49021 L F
0 0 0 r
.70529 .49068 m .70792 .49021 L .70523 .4907 L F
.308 .684 .977 r
.78296 .60422 m .78073 .60409 L .77957 .60312 L F
.876 .826 .795 r
.64685 .54252 m .65034 .54062 L .64863 .53948 L F
.64685 .54252 m .64827 .54384 L .65034 .54062 L F
.828 .763 .791 r
.64863 .53948 m .65034 .54062 L .65242 .53778 L F
.627 .662 .864 r
.70117 .48319 m .70203 .48503 L .69877 .48385 L F
.59 .625 .855 r
.70325 .48271 m .70203 .48503 L .70117 .48319 L F
.70325 .48271 m .7047 .48449 L .70203 .48503 L F
.509 .304 .537 r
.4663 .76715 m .46822 .76929 L .46846 .76672 L F
.382 .285 .62 r
.46659 .76941 m .46822 .76929 L .4663 .76715 L F
.481 .422 .714 r
.3732 .67486 m .37455 .67116 L .3727 .67179 L F
.3732 .67486 m .37504 .6744 L .37455 .67116 L F
.466 .368 .66 r
.3732 .67486 m .37544 .67682 L .37504 .6744 L F
.457 .367 .667 r
.3732 .67486 m .37366 .67741 L .37544 .67682 L F
0 0 .204 r
.31064 .66751 m .31044 .66904 L .31018 .66639 L F
.31064 .66751 m .31018 .66639 L .30854 .66781 L F
0 0 .117 r
.32977 .74818 m .32852 .75034 L .32987 .74819 L F
.791 .743 .809 r
.6546 .52373 m .65267 .52608 L .65565 .52638 L F
.917 .969 .671 r
.55536 .78637 m .5538 .78925 L .55285 .78894 L F
.687 .304 .317 r
.55743 .78884 m .55536 .78637 L .55285 .78894 L F
.544 .3 .496 r
.55743 .78884 m .55743 .78662 L .55536 .78637 L F
0 0 0 r
.59297 .70601 m .59284 .70626 L .59509 .70532 L F
.59297 .70601 m .59197 .70746 L .59284 .70626 L F
0 0 .345 r
.5973 .71032 m .59765 .71325 L .59687 .71425 L F
.14 .27 .738 r
.59765 .71325 m .59775 .71629 L .59687 .71425 L F
.508 .49 .772 r
.40288 .68258 m .40186 .68637 L .4007 .68305 L F
.40288 .68258 m .40392 .6867 L .40186 .68637 L F
.256 0 0 r
.30293 .64911 m .30645 .64991 L .30505 .64968 L F
.088 .599 .888 r
.30645 .64991 m .30664 .64946 L .30505 .64968 L F
.30645 .64991 m .3085 .65023 L .30664 .64946 L F
.802 .673 .722 r
.6021 .551 m .60566 .55143 L .60545 .54931 L F
.797 .695 .753 r
.60328 .55428 m .60566 .55143 L .6021 .551 L F
.737 .626 .736 r
.60545 .54931 m .60566 .55143 L .60797 .54835 L F
.667 .526 .683 r
.60566 .55143 m .60887 .55219 L .60797 .54835 L F
.625 .561 .762 r
.60566 .55143 m .6091 .55418 L .60887 .55219 L F
.808 .707 .754 r
.6513 .5345 m .64952 .53751 L .65242 .53778 L F
.828 .763 .791 r
.64863 .53948 m .65242 .53778 L .64952 .53751 L F
.76 .683 .777 r
.6513 .5345 m .65242 .53778 L .65484 .53502 L F
.568 .54 .784 r
.24881 .63522 m .24654 .63231 L .24784 .63461 L F
.553 .64 .89 r
.49557 .76363 m .49497 .76667 L .49445 .76461 L F
.393 .755 .993 r
.28991 .58467 m .28955 .58579 L .28795 .58488 L F
.28991 .58467 m .29173 .58566 L .28955 .58579 L F
.326 .059 .347 r
.54328 .80293 m .5458 .7992 L .54496 .80183 L F
.125 .541 .919 r
.5458 .7992 m .54598 .80086 L .54496 .80183 L F
.564 .633 .878 r
.5458 .7992 m .54874 .80014 L .54909 .80026 L F
.412 .741 .993 r
.54735 .79732 m .55013 .7984 L .54642 .79831 L F
.55013 .7984 m .5502 .79842 L .55013 .79842 L F
.55013 .7984 m .55013 .79842 L .54642 .79831 L F
0 0 .073 r
.55191 .79644 m .55097 .79764 L .55261 .79433 L F
.687 .876 .969 r
.54906 .79672 m .55097 .79764 L .55191 .79644 L F
.74 .982 .911 r
.55017 .79751 m .55097 .79764 L .55191 .79644 L F
.702 .781 .913 r
.55097 .79764 m .5502 .79842 L .54735 .79732 L F
.74 .982 .911 r
.5488 .79835 m .55015 .79791 L .55017 .79751 L F
.55015 .79791 m .55097 .79764 L .55017 .79751 L F
0 0 0 r
.54874 .80014 m .55097 .79764 L .5488 .79835 L F
.125 .541 .919 r
.5458 .7992 m .54909 .80026 L .54742 .79874 L F
.5458 .7992 m .54742 .79874 L .54598 .80086 L F
.301 0 .132 r
.6178 .52639 m .61678 .52831 L .61491 .52869 L F
.427 .01 .143 r
.62028 .52626 m .61678 .52831 L .6178 .52639 L F
.629 .185 .177 r
.49057 .6917 m .48921 .69328 L .4869 .6917 L F
.747 .333 .264 r
.49057 .6917 m .49299 .6941 L .48921 .69328 L F
.623 .38 .529 r
.49373 .69145 m .49299 .6941 L .49057 .6917 L F
.799 .485 .459 r
.54535 .75873 m .54633 .76043 L .5489 .75848 L F
.75 .525 .59 r
.54633 .76043 m .54919 .76116 L .5489 .75848 L F
.753 .704 .805 r
.54712 .75551 m .5489 .75848 L .55226 .75456 L F
.593 .459 .668 r
.5489 .75848 m .55138 .75868 L .55226 .75456 L F
.335 .077 .366 r
.54919 .76116 m .55138 .75868 L .5489 .75848 L F
.177 .286 .738 r
.5441 .75718 m .54333 .7592 L .54183 .75776 L F
.575 .318 .489 r
.54333 .7592 m .54559 .76129 L .54535 .75873 L F
.177 .286 .738 r
.5441 .75718 m .54559 .76129 L .54333 .7592 L F
.765 .584 .653 r
.57254 .5739 m .57582 .57662 L .57205 .57641 L F
.74 .574 .668 r
.57205 .57641 m .57582 .57662 L .57435 .57942 L F
.73 .53 .621 r
.50568 .77228 m .50777 .77281 L .50759 .76985 L F
.604 .174 .198 r
.54582 .76898 m .54385 .77151 L .54197 .76952 L F
.408 0 .073 r
.54668 .76986 m .54582 .76898 L .54769 .76935 L F
.54668 .76986 m .54385 .77151 L .54582 .76898 L F
.164 0 0 r
.51856 .80917 m .51641 .80963 L .51496 .81093 L F
0 0 .024 r
.51843 .80623 m .51641 .80963 L .51856 .80917 L F
.856 .811 .805 r
.64466 .54529 m .64827 .54384 L .64685 .54252 L F
.64466 .54529 m .64622 .5465 L .64827 .54384 L F
.572 .041 0 r
.55507 .71942 m .55623 .72077 L .55387 .72116 L F
.55507 .71942 m .55737 .72162 L .55623 .72077 L F
.691 .473 .587 r
.49026 .75834 m .49244 .75825 L .49289 .75608 L F
.689 .511 .641 r
.49244 .75825 m .49591 .75544 L .49289 .75608 L F
.597 .562 .786 r
.38065 .69687 m .38242 .70047 L .38411 .69946 L F
.161 0 .228 r
.38163 .70242 m .38411 .69946 L .38242 .70047 L F
.916 .883 .786 r
.77859 .58941 m .78077 .58863 L .78071 .58549 L F
.791 .549 .571 r
.67962 .50566 m .68294 .5064 L .68285 .50407 L F
.779 .539 .573 r
.68285 .50407 m .68633 .50682 L .68542 .50531 L F
.68285 .50407 m .68294 .5064 L .68633 .50682 L F
.58 .383 .58 r
.68542 .50531 m .68294 .5064 L .68285 .50407 L F
.68542 .50531 m .68294 .5064 L .68285 .50407 L F
.694 .731 .218 r
.59805 .71932 m .59748 .72113 L .59707 .7226 L F
0 0 .158 r
.59775 .71629 m .59811 .71901 L .59805 .71932 L F
.705 .736 .222 r
.59805 .71932 m .59811 .71901 L .59748 .72113 L F
.528 0 0 r
.56741 .72591 m .56681 .72597 L .56434 .72469 L F
.56741 .72591 m .56827 .72653 L .56681 .72597 L F
.541 .014 0 r
.30509 .63343 m .3069 .63425 L .30835 .63334 L F
0 0 0 r
.3069 .63425 m .3111 .63301 L .30835 .63334 L F
.254 0 0 r
.42649 .70462 m .42539 .70569 L .4233 .70614 L F
.292 0 0 r
.42866 .70435 m .42539 .70569 L .42649 .70462 L F
.63 .475 .654 r
.49466 .79083 m .4914 .78987 L .49256 .78914 L F
.49466 .79083 m .49184 .79213 L .4914 .78987 L F
.4914 .78987 m .49184 .79213 L .49466 .79083 L F
.615 .672 .882 r
.53076 .76942 m .53443 .77073 L .53253 .76799 L F
0 .494 .852 r
.53624 .76958 m .53253 .76799 L .53443 .77073 L F
.545 .248 .414 r
.40484 .67221 m .40422 .67418 L .40183 .67445 L F
.357 .072 .336 r
.40616 .67357 m .40484 .67221 L .40683 .6716 L F
.40616 .67357 m .40422 .67418 L .40484 .67221 L F
.088 0 .13 r
.54688 .74773 m .54834 .74699 L .54931 .74511 L F
.977 .726 .489 r
.54975 .75012 m .54688 .74773 L .54656 .75003 L F
.54975 .75012 m .54834 .74699 L .54688 .74773 L F
.479 0 0 r
.41811 .6672 m .41644 .66808 L .4145 .66763 L F
.358 0 0 r
.42006 .6677 m .41644 .66808 L .41811 .6672 L F
.398 0 .105 r
.42042 .66688 m .42006 .6677 L .41811 .6672 L F
0 .499 .705 r
.41264 .69641 m .41467 .69668 L .41595 .69685 L F
.008 0 0 r
.41467 .69668 m .41809 .69648 L .41595 .69685 L F
.668 .115 0 r
.48096 .80848 m .48419 .81015 L .48493 .81104 L F
.48 .808 1 r
.36394 .59839 m .36543 .5992 L .36186 .59879 L F
.356 .75 .986 r
.36601 .59825 m .36543 .5992 L .36394 .59839 L F
.36601 .59825 m .36734 .59904 L .36543 .5992 L F
.54 .558 .822 r
.36884 .60203 m .36543 .5992 L .36734 .59904 L F
.533 .797 .994 r
.6757 .47812 m .67447 .47966 L .67344 .47867 L F
.6757 .47812 m .67676 .47914 L .67447 .47966 L F
.318 0 .212 r
.63775 .51618 m .63834 .51695 L .6387 .51548 L F
.63775 .51618 m .63595 .51787 L .63834 .51695 L F
.956 .653 .226 r
.56488 .7432 m .56532 .74203 L .56414 .742 L F
.56488 .7432 m .56571 .74441 L .56532 .74203 L F
.662 .276 .303 r
.561 .7166 m .55955 .71698 L .56302 .71685 L F
.727 .25 .114 r
.71843 .50685 m .71764 .50815 L .72055 .50868 L F
.985 .833 .444 r
.72055 .50868 m .721 .50671 L .71843 .50685 L F
.793 .63 .68 r
.54179 .78962 m .54027 .78709 L .54006 .78885 L F
.946 .752 .611 r
.54058 .78908 m .54123 .79205 L .54179 .78962 L F
.54046 .78903 m .5405 .78919 L .54058 .78908 L F
.5405 .78919 m .54123 .79205 L .54058 .78908 L F
.54025 .78937 m .54123 .79205 L .54046 .78903 L F
.691 .647 .801 r
.53815 .7916 m .54123 .79205 L .54038 .78972 L F
.53815 .7916 m .54038 .78972 L .5397 .79007 L F
.53815 .7916 m .54029 .78948 L .53907 .79032 L F
.124 0 .109 r
.53907 .79032 m .53862 .79028 L .5387 .7904 L F
.691 .647 .801 r
.53815 .7916 m .53895 .79046 L .53849 .79042 L F
.53895 .79046 m .53901 .79036 L .5387 .7904 L F
.53895 .79046 m .5387 .7904 L .53849 .79042 L F
.218 0 .048 r
.5386 .79064 m .53861 .79038 L .53879 .79054 L F
.53861 .79038 m .53862 .79028 L .5387 .7904 L F
.53861 .79038 m .5387 .7904 L .53879 .79054 L F
.124 0 .109 r
.53901 .79036 m .5387 .7904 L .53879 .79054 L F
.53907 .79032 m .5387 .7904 L .53901 .79036 L F
.691 .647 .801 r
.53849 .79042 m .54006 .78885 L .5387 .7897 L F
.53901 .79036 m .54006 .78885 L .5387 .7904 L F
.53901 .79036 m .53907 .79032 L .53902 .79035 L F
.124 0 .109 r
.53966 .79037 m .53907 .79032 L .53919 .79115 L F
.53907 .79032 m .53879 .79054 L .53919 .79115 L F
.691 .647 .801 r
.53902 .79035 m .54029 .78948 L .54006 .78885 L F
.124 0 .04 r
.53884 .79047 m .53862 .79028 L .53907 .79032 L F
.5386 .79064 m .53862 .79028 L .53884 .79047 L F
0 0 .183 r
.53947 .79156 m .5387 .7904 L .53872 .79037 L F
.124 0 .04 r
.5386 .79064 m .53907 .79032 L .53966 .79037 L F
0 0 .183 r
.53957 .79111 m .53872 .79037 L .54006 .78885 L F
.124 0 .109 r
.53966 .79037 m .53919 .79115 L .53947 .79156 L F
0 0 .183 r
.53947 .79156 m .53872 .79037 L .53957 .79111 L F
.5387 .7904 m .53862 .79028 L .54006 .78885 L F
.691 .647 .801 r
.5387 .7904 m .54006 .78885 L .53849 .79042 L F
.53815 .7916 m .53907 .79032 L .53901 .79036 L F
.72 .514 .611 r
.53768 .79482 m .54123 .79205 L .53815 .7916 L F
.218 0 .048 r
.53845 .79278 m .5386 .79064 L .53947 .79156 L F
.5386 .79064 m .53879 .79054 L .53947 .79156 L F
.691 .647 .801 r
.5397 .79007 m .54038 .78972 L .54029 .78948 L F
.124 0 .04 r
.53851 .79198 m .5386 .79064 L .53966 .79037 L F
.53845 .79278 m .53851 .79198 L .53938 .7915 L F
.124 0 .109 r
.5412 .7905 m .53966 .79037 L .53947 .79156 L F
.124 0 .04 r
.53942 .79148 m .53966 .79037 L .5412 .7905 L F
.53851 .79198 m .53894 .79137 L .53942 .79148 L F
.53894 .79137 m .53966 .79037 L .53942 .79148 L F
.408 .829 .656 r
.5401 .79107 m .53954 .79151 L .53743 .78893 L F
.53954 .79151 m .53947 .79156 L .5394 .79147 L F
.53954 .79151 m .5394 .79147 L .53743 .78893 L F
.956 .78 .624 r
.53743 .78893 m .5394 .79147 L .53845 .79278 L F
.5394 .79147 m .53947 .79156 L .53845 .79278 L F
.408 .829 .656 r
.53954 .79151 m .5412 .7905 L .53947 .79156 L F
.124 0 .04 r
.53925 .79168 m .53938 .7915 L .5412 .7905 L F
.408 .829 .656 r
.5401 .79107 m .5412 .7905 L .53954 .79151 L F
.124 0 .04 r
.53845 .79278 m .53925 .79168 L .5412 .7905 L F
.946 .752 .611 r
.54006 .78885 m .54025 .78937 L .54046 .78903 L F
.67 .132 0 r
.50403 .76258 m .50077 .76107 L .50142 .76123 L F
.048 .596 .835 r
.50142 .76123 m .50032 .76086 L .49813 .76064 L F
.67 .132 0 r
.50077 .76107 m .50032 .76086 L .50142 .76123 L F
0 .513 .739 r
.50192 .76135 m .50142 .76123 L .49943 .76093 L F
.50292 .76151 m .50142 .76123 L .50192 .76135 L F
.331 0 0 r
.50524 .7632 m .50142 .76123 L .50292 .76151 L F
.577 .576 .816 r
.50292 .76151 m .50713 .76338 L .50524 .7632 L F
.559 .918 .737 r
.54735 .79732 m .54642 .79831 L .54453 .79927 L F
.757 .707 .805 r
.60436 .54786 m .60797 .54835 L .60661 .54529 L F
.60436 .54786 m .60545 .54931 L .60797 .54835 L F
.81 .719 .765 r
.77985 .59703 m .77925 .59872 L .78082 .59653 L F
.712 .663 .8 r
.48762 .66621 m .4916 .66784 L .49001 .66609 L F
.566 .667 .906 r
.4916 .66784 m .49229 .66555 L .49001 .66609 L F
.4916 .66784 m .49417 .66764 L .49229 .66555 L F
.091 .649 .757 r
.7212 .51903 m .7199 .519 L .71739 .51917 L F
0 0 0 r
.72366 .51834 m .7199 .519 L .7212 .51903 L F
.371 .266 .604 r
.27681 .62408 m .27539 .62697 L .27447 .6238 L F
.27681 .62408 m .27699 .62669 L .27539 .62697 L F
.572 .481 .713 r
.27622 .62097 m .27681 .62408 L .27447 .6238 L F
.625 .741 .931 r
.29367 .63423 m .29155 .63484 L .28999 .63291 L F
.451 .79 .998 r
.54907 .71021 m .55137 .70996 L .55048 .71095 L F
.924 .907 .51 r
.54932 .71287 m .55048 .71095 L .55137 .70996 L F
.913 .637 .143 r
.57128 .75757 m .5719 .75589 L .57133 .75522 L F
.57128 .75757 m .57222 .75839 L .5719 .75589 L F
.754 .705 .805 r
.64096 .49514 m .63694 .49587 L .6394 .49304 L F
.494 .037 .097 r
.64096 .49514 m .6397 .49677 L .63694 .49587 L F
.818 .716 .753 r
.64084 .49272 m .64096 .49514 L .6394 .49304 L F
.852 .655 .636 r
.6428 .49666 m .6397 .49677 L .64096 .49514 L F
.808 1 .808 r
.62227 .5136 m .62144 .51555 L .62383 .51321 L F
.558 .166 .254 r
.45588 .68525 m .45849 .68538 L .45945 .68338 L F
.458 .065 .207 r
.45945 .68338 m .45849 .68538 L .46151 .68431 L F
.663 .359 .449 r
.51008 .78111 m .51228 .78324 L .51002 .78345 L F
.6 .369 .538 r
.51008 .78111 m .5124 .78095 L .51228 .78324 L F
.112 0 0 r
.31887 .62983 m .31696 .63045 L .31599 .63134 L F
0 0 0 r
.61307 .49794 m .61359 .49732 L .61407 .49573 L F
.61407 .49573 m .61548 .49445 L .61611 .4927 L F
.069 0 .064 r
.61407 .49573 m .61522 .49642 L .61548 .49445 L F
.61407 .49573 m .61359 .49732 L .61522 .49642 L F
.256 0 .277 r
.62093 .48739 m .61852 .49004 L .62042 .48902 L F
.303 .014 .298 r
.62093 .48739 m .62247 .48797 L .62305 .48663 L F
.62093 .48739 m .62042 .48902 L .62247 .48797 L F
.869 .808 .787 r
.64466 .54529 m .64508 .54803 L .64622 .5465 L F
.783 .871 .913 r
.49949 .66991 m .49688 .6718 L .49833 .67227 L F
.588 .698 .918 r
.68495 .48706 m .68678 .48563 L .68384 .48592 L F
.68495 .48706 m .68731 .48656 L .68678 .48563 L F
.791 .629 .681 r
.60131 .55713 m .60457 .55749 L .60328 .55428 L F
.789 .643 .7 r
.60456 .55987 m .60457 .55749 L .60131 .55713 L F
.896 .879 .81 r
.39527 .71641 m .3966 .71772 L .39906 .7138 L F
.329 0 .105 r
.45831 .69329 m .45475 .69591 L .45606 .69323 L F
.195 0 0 r
.56092 .71693 m .56221 .71728 L .56302 .71685 L F
.332 .544 .909 r
.56027 .71563 m .56249 .71735 L .56221 .71728 L F
.694 .16 0 r
.56367 .71827 m .56302 .71685 L .56221 .71728 L F
.332 .544 .909 r
.56249 .71735 m .56367 .71827 L .56221 .71728 L F
.195 0 0 r
.55955 .71698 m .56221 .71728 L .56092 .71693 L F
.694 .16 0 r
.56367 .71827 m .56511 .71905 L .56302 .71685 L F
.719 .32 .29 r
.52086 .77478 m .52276 .7767 L .52416 .77534 L F
.635 .157 .101 r
.52481 .77721 m .52416 .77534 L .52276 .7767 L F
.52481 .77721 m .52612 .7759 L .52416 .77534 L F
.991 .874 .612 r
.57281 .76145 m .5712 .76326 L .57214 .76369 L F
.57281 .76145 m .57192 .76089 L .5712 .76326 L F
1 .799 .483 r
.57222 .75839 m .57192 .76089 L .57281 .76145 L F
.662 .53 .692 r
.50518 .66604 m .50289 .66889 L .50284 .66638 L F
.574 .237 .361 r
.52724 .78012 m .52365 .78278 L .52465 .7802 L F
.2 0 0 r
.4203 .69607 m .42253 .69572 L .42408 .69447 L F
.494 .031 .083 r
.42253 .69572 m .42635 .69428 L .42408 .69447 L F
.067 0 .127 r
.49648 .69322 m .49489 .69071 L .49638 .69171 L F
.351 .755 .983 r
.32504 .59048 m .32715 .59035 L .32859 .59107 L F
.38 .723 .989 r
.3292 .59002 m .32859 .59107 L .32715 .59035 L F
.3292 .59002 m .33058 .59102 L .32859 .59107 L F
.708 .766 .898 r
.68542 .50531 m .68294 .5064 L .68633 .50682 L F
.623 .728 .922 r
.68884 .50621 m .68633 .50682 L .68542 .50531 L F
.702 .243 .158 r
.68884 .50621 m .68542 .50531 L .68633 .50682 L F
.708 .766 .898 r
.68633 .50682 m .68294 .5064 L .68542 .50531 L F
.68633 .50682 m .68294 .5064 L .68542 .50531 L F
.494 .261 .49 r
.3616 .61241 m .35943 .61448 L .35954 .61284 L F
0 0 .25 r
.47532 .77468 m .47522 .77766 L .47448 .77828 L F
.248 .7 .954 r
.47522 .77766 m .47703 .77847 L .47448 .77828 L F
.579 .321 .489 r
.60469 .56231 m .60799 .55976 L .60456 .55987 L F
.789 .643 .7 r
.60456 .55987 m .60131 .55713 L .60105 .55936 L F
.728 .507 .591 r
.60137 .56204 m .60456 .55987 L .60105 .55936 L F
.60137 .56204 m .60469 .56231 L .60456 .55987 L F
.76 .47 .494 r
.54021 .74399 m .53933 .74672 L .53784 .74599 L F
.695 .158 0 r
.53915 .74259 m .54281 .74462 L .54021 .74399 L F
.381 0 .092 r
.54281 .74462 m .53933 .74672 L .54021 .74399 L F
.604 .059 0 r
.47836 .79743 m .48155 .79809 L .48037 .79839 L F
.631 .087 0 r
.48155 .79809 m .48095 .79889 L .48037 .79839 L F
.938 .568 .197 r
.57019 .75105 m .57068 .75019 L .5694 .74947 L F
.57019 .75105 m .57157 .75284 L .57068 .75019 L F
.46 .073 .217 r
.44677 .6987 m .44492 .69766 L .44742 .69661 L F
.54 .195 .332 r
.4506 .69711 m .44677 .6987 L .44742 .69661 L F
.637 .197 .189 r
.57861 .58833 m .5808 .58974 L .57707 .58944 L F
.56 .008 0 r
.71751 .4892 m .72027 .49112 L .72051 .48994 L F
.71751 .4892 m .71901 .49047 L .72027 .49112 L F
.865 .67 .638 r
.71751 .4892 m .72051 .48994 L .71949 .48689 L F
.826 .657 .673 r
.71804 .48594 m .71751 .4892 L .71949 .48689 L F
.56 .008 0 r
.71901 .49047 m .71949 .49089 L .71971 .49095 L F
.063 .297 .784 r
.71898 .4896 m .71949 .49089 L .71751 .4892 L F
.71898 .4896 m .71751 .4892 L .71565 .48952 L F
.71898 .4896 m .71565 .48952 L .71611 .4903 L F
.566 .757 .968 r
.71779 .4882 m .71898 .4896 L .71805 .48982 L F
.71704 .48914 m .71805 .48982 L .71611 .4903 L F
.71779 .4882 m .71805 .48982 L .71704 .48914 L F
.56 .008 0 r
.71901 .49047 m .71971 .49095 L .72027 .49112 L F
.697 .593 .735 r
.63503 .52863 m .63281 .53138 L .63352 .52953 L F
.594 .39 .574 r
.37869 .65804 m .38054 .65982 L .38092 .6577 L F
.37869 .65804 m .3784 .66033 L .38054 .65982 L F
.8 .701 .755 r
.47985 .77514 m .47957 .77485 L .48044 .77412 L F
.685 .614 .77 r
.47975 .77242 m .47986 .77515 L .48149 .77251 L F
.8 .701 .755 r
.48297 .7755 m .47988 .77565 L .4793 .77508 L F
.685 .614 .77 r
.47986 .77515 m .47988 .77565 L .48004 .77534 L F
.8 .701 .755 r
.48297 .7755 m .47985 .77514 L .48044 .77412 L F
.819 .594 .598 r
.48044 .77412 m .48107 .77528 L .48297 .7755 L F
.169 .144 .584 r
.48297 .7755 m .48107 .77528 L .47988 .77565 L F
.791 .594 .635 r
.47975 .775 m .48107 .77528 L .48044 .77412 L F
.685 .614 .77 r
.47986 .77515 m .48004 .77534 L .48007 .77528 L F
.47986 .77515 m .48007 .77528 L .47988 .77512 L F
.797 .701 .759 r
.4793 .77508 m .47988 .77565 L .47986 .7751 L F
.8 .701 .755 r
.47985 .77514 m .4793 .77508 L .47957 .77485 L F
.791 .594 .635 r
.47968 .77509 m .47986 .7751 L .47975 .775 L F
.4793 .77508 m .47953 .77528 L .48044 .77412 L F
.797 .701 .759 r
.4793 .77508 m .47986 .7751 L .47975 .77242 L F
.791 .594 .635 r
.47953 .77528 m .48007 .77528 L .47986 .7751 L F
.47953 .77528 m .47986 .7751 L .47968 .77509 L F
.48007 .77528 m .48107 .77528 L .47975 .775 L F
.685 .614 .77 r
.47988 .77512 m .48007 .77528 L .48149 .77251 L F
.169 .144 .584 r
.48107 .77528 m .48012 .77518 L .48007 .77528 L F
.48107 .77528 m .48007 .77528 L .47988 .77565 L F
.791 .594 .635 r
.47953 .77528 m .48247 .77788 L .48107 .77528 L F
.819 .594 .598 r
.48107 .77528 m .48247 .77788 L .48297 .7755 L F
.169 .144 .584 r
.48297 .7755 m .48149 .77251 L .48012 .77518 L F
.48297 .7755 m .48379 .77203 L .48149 .77251 L F
.48297 .7755 m .48387 .77527 L .48379 .77203 L F
.194 .239 .682 r
.48297 .7755 m .48478 .77746 L .48387 .77527 L F
.51 .294 .523 r
.48297 .7755 m .48247 .77788 L .48478 .77746 L F
.991 .734 .398 r
.72439 .49257 m .72334 .49208 L .72333 .48935 L F
.15 .663 .896 r
.47065 .76613 m .4742 .76674 L .47526 .76485 L F
.525 .518 .79 r
.47342 .76126 m .47526 .76485 L .47626 .7635 L F
0 0 0 r
.47526 .76485 m .4742 .76674 L .47626 .7635 L F
.042 0 .084 r
.61611 .4927 m .61789 .4919 L .61852 .49004 L F
.244 0 .118 r
.61611 .4927 m .61761 .49367 L .61789 .4919 L F
.61611 .4927 m .61548 .49445 L .61761 .49367 L F
.794 .495 .483 r
.51499 .73927 m .5158 .74202 L .51706 .74035 L F
.608 .392 .563 r
.51706 .74035 m .51764 .74224 L .52091 .7413 L F
.315 0 0 r
.43897 .64732 m .44117 .64779 L .44287 .64708 L F
.007 0 0 r
.44287 .64708 m .44346 .64735 L .44507 .64688 L F
.44287 .64708 m .44117 .64779 L .44346 .64735 L F
.702 .589 .726 r
.71949 .48689 m .72051 .48994 L .72293 .48714 L F
.628 .682 .881 r
.69982 .48041 m .69877 .48385 L .69749 .48105 L F
.69982 .48041 m .70117 .48319 L .69877 .48385 L F
.452 .119 .309 r
.24913 .59525 m .25221 .59259 L .25028 .59318 L F
.641 .301 .38 r
.60941 .58256 m .61178 .58435 L .60971 .58435 L F
.616 .32 .445 r
.61281 .58189 m .61178 .58435 L .60941 .58256 L F
.571 .254 .392 r
.60941 .58256 m .60971 .58435 L .60618 .58473 L F
.421 .165 .417 r
.2428 .59907 m .24475 .59854 L .24524 .5965 L F
.574 .362 .555 r
.24475 .59854 m .24731 .59586 L .24524 .5965 L F
.255 .189 .587 r
.47592 .66642 m .4775 .66693 L .47758 .66545 L F
.47592 .66642 m .47629 .66911 L .4775 .66693 L F
.202 .286 .727 r
.50663 .64032 m .5053 .64167 L .50451 .63833 L F
.336 .431 .811 r
.50663 .64032 m .50624 .6431 L .5053 .64167 L F
.592 .772 .966 r
.71724 .47969 m .7158 .48162 L .71478 .48032 L F
.71724 .47969 m .71818 .48102 L .7158 .48162 L F
.282 .39 .796 r
.71845 .48345 m .7158 .48162 L .71818 .48102 L F
.422 .228 .51 r
.33188 .6188 m .33378 .6182 L .33407 .61585 L F
.446 .239 .504 r
.33188 .6188 m .33351 .62063 L .33378 .6182 L F
.33188 .6188 m .33162 .62131 L .33351 .62063 L F
.796 .889 .912 r
.63875 .5342 m .63644 .53411 L .6387 .53132 L F
.58 .939 .916 r
.31065 .64986 m .31246 .64991 L .3143 .6489 L F
.33 0 0 r
.41061 .65144 m .41286 .65122 L .41422 .64986 L F
.199 0 0 r
.41286 .65122 m .41645 .64996 L .41422 .64986 L F
.112 .1 .563 r
.75448 .595 m .75352 .59888 L .75273 .59732 L F
.454 .498 .815 r
.74901 .60707 m .7499 .60979 L .75198 .61009 L F
.787 .287 0 r
.5564 .73485 m .5559 .73309 L .5549 .73224 L F
.5564 .73485 m .55782 .73548 L .5559 .73309 L F
.329 0 .053 r
.41814 .70773 m .41694 .70942 L .4148 .70976 L F
.27 0 .019 r
.41909 .70888 m .41814 .70773 L .42019 .70727 L F
.41909 .70888 m .41694 .70942 L .41814 .70773 L F
.536 .868 .993 r
.69309 .48865 m .694 .48933 L .69619 .48899 L F
.357 0 0 r
.7715 .57781 m .76876 .57664 L .76765 .57636 L F
.971 .902 .694 r
.58998 .54138 m .59172 .54046 L .58978 .54343 L F
.58998 .54138 m .59087 .53952 L .59172 .54046 L F
.508 .469 .748 r
.50692 .64689 m .50973 .64868 L .50759 .64885 L F
.67 .456 .586 r
.36968 .72507 m .36964 .7279 L .36732 .72671 L F
0 0 0 r
.36968 .72507 m .36732 .72671 L .36685 .72708 L F
.36968 .72507 m .36685 .72708 L .36807 .72461 L F
.68 .156 0 r
.36807 .72461 m .37014 .72492 L .36968 .72507 L F
.35 .2 .532 r
.37014 .72492 m .36964 .7279 L .36968 .72507 L F
.512 .041 .073 r
.77111 .60558 m .77407 .60643 L .77468 .60514 L F
.292 0 0 r
.77468 .60514 m .77662 .60582 L .77762 .60488 L F
.77468 .60514 m .77407 .60643 L .77662 .60582 L F
.622 .951 .779 r
.54465 .77493 m .54099 .77738 L .54293 .77709 L F
0 0 0 r
.54293 .77709 m .54624 .77481 L .54465 .77493 L F
.45 .096 .273 r
.43851 .70042 m .43664 .70224 L .43442 .70253 L F
.499 .178 .354 r
.44019 .69969 m .43664 .70224 L .43851 .70042 L F
.769 .987 .753 r
.55439 .79235 m .55229 .79402 L .55324 .78908 L F
0 0 0 r
.55299 .79078 m .55324 .78908 L .55321 .78923 L F
.918 .567 .115 r
.55285 .78894 m .55324 .78907 L .55315 .78962 L F
.55285 .78894 m .55315 .78962 L .55324 .78908 L F
.55315 .78962 m .5538 .78925 L .55439 .79235 L F
.55315 .78962 m .55439 .79235 L .55324 .78908 L F
0 0 0 r
.5529 .7912 m .55321 .78923 L .55229 .79402 L F
.55296 .7909 m .55315 .78962 L .5529 .7912 L F
.55315 .78962 m .55321 .78923 L .5529 .7912 L F
.55299 .79078 m .55321 .78923 L .55296 .7909 L F
.918 .567 .115 r
.55324 .78907 m .5538 .78925 L .55315 .78962 L F
.553 .64 .89 r
.49557 .76363 m .49792 .76635 L .49497 .76667 L F
.467 .166 .371 r
.44258 .68866 m .44482 .68838 L .44562 .68572 L F
.361 0 .149 r
.44482 .68838 m .44803 .68593 L .44562 .68572 L F
.954 .943 .63 r
.65505 .48402 m .65375 .48725 L .65341 .48536 L F
0 0 0 r
.65505 .48402 m .65652 .4836 L .65751 .48329 L F
.65505 .48402 m .65341 .48536 L .65652 .4836 L F
.83 .607 .601 r
.49244 .75825 m .49529 .76075 L .49571 .75987 L F
.49244 .75825 m .49253 .76063 L .49529 .76075 L F
0 0 .333 r
.49497 .76315 m .49557 .76363 L .49529 .76075 L F
.402 .329 .661 r
.49529 .76075 m .49839 .75854 L .49571 .75987 L F
.49529 .76075 m .49813 .76064 L .49839 .75854 L F
.14 .67 .865 r
.49943 .76093 m .49813 .76064 L .49529 .76075 L F
.302 0 .188 r
.61852 .49004 m .62015 .49116 L .62042 .48902 L F
.61852 .49004 m .61789 .4919 L .62015 .49116 L F
.799 .728 .786 r
.59159 .68877 m .59226 .69182 L .59011 .69104 L F
.874 .588 .5 r
.59226 .69182 m .59088 .69375 L .59011 .69104 L F
.59226 .69182 m .59268 .69432 L .59088 .69375 L F
.25 .347 .768 r
.59159 .68877 m .59359 .69032 L .59226 .69182 L F
.535 .356 .586 r
.59226 .69182 m .5949 .69346 L .59268 .69432 L F
.286 .402 .806 r
.59359 .69032 m .5949 .69346 L .59226 .69182 L F
.729 .394 .412 r
.50802 .75539 m .5097 .75784 L .51091 .75593 L F
.694 .538 .671 r
.51091 .75593 m .51136 .7585 L .51314 .75583 L F
.886 .829 .785 r
.5097 .75784 m .51314 .75583 L .51091 .75593 L F
0 0 0 r
.6141 .54016 m .61227 .54305 L .61355 .54128 L F
.463 .835 .592 r
.61675 .5381 m .6141 .54016 L .61609 .53857 L F
.716 .554 .669 r
.61355 .54128 m .61609 .53857 L .6141 .54016 L F
.763 .764 .854 r
.76251 .61373 m .76467 .61273 L .76341 .60998 L F
.623 .704 .904 r
.76467 .61273 m .76584 .60947 L .76341 .60998 L F
.76467 .61273 m .76717 .61233 L .76584 .60947 L F
.63 .61 .812 r
.76467 .61273 m .76792 .61429 L .76717 .61233 L F
.745 .748 .854 r
.4933 .63802 m .48964 .63765 L .49185 .63554 L F
.746 .748 .854 r
.4933 .63802 m .49113 .63881 L .48964 .63765 L F
.703 .731 .873 r
.49513 .63556 m .4933 .63802 L .49185 .63554 L F
.736 .684 .801 r
.49113 .63881 m .48788 .63895 L .48964 .63765 L F
.82 .658 .11 r
.70579 .50325 m .70569 .50578 L .70562 .50265 L F
.826 .994 .75 r
.7072 .50026 m .70579 .50325 L .70824 .50284 L F
.7072 .50026 m .70562 .50265 L .70579 .50325 L F
.52 .245 .437 r
.70579 .50325 m .70808 .50472 L .70824 .50284 L F
.703 .853 .954 r
.65888 .49095 m .65637 .49216 L .65994 .49199 L F
.419 .677 .969 r
.66124 .49071 m .65994 .49199 L .65888 .49095 L F
.66124 .49071 m .66217 .49204 L .65994 .49199 L F
.476 .737 .984 r
.764 .58318 m .76579 .5818 L .76331 .58242 L F
.764 .58318 m .76659 .58304 L .76579 .5818 L F
.393 .831 .695 r
.69348 .52637 m .68999 .52809 L .69252 .52509 L F
.609 .788 .967 r
.69565 .52558 m .69348 .52637 L .69252 .52509 L F
.922 .957 .791 r
.58776 .54429 m .58978 .54343 L .58775 .54652 L F
.919 .974 .695 r
.58644 .5481 m .58776 .54429 L .58775 .54652 L F
.512 .275 .493 r
.34289 .62992 m .34259 .63211 L .34041 .63251 L F
.405 .183 .462 r
.34448 .6315 m .34289 .62992 L .34495 .62937 L F
.34448 .6315 m .34259 .63211 L .34289 .62992 L F
.391 .176 .463 r
.57103 .68826 m .57326 .68548 L .57091 .68589 L F
0 0 .409 r
.65145 .49211 m .65219 .49453 L .65163 .49563 L F
0 .054 .584 r
.65219 .49453 m .65209 .49763 L .65163 .49563 L F
.899 .977 .809 r
.58776 .54429 m .58998 .54138 L .58978 .54343 L F
.763 .764 .854 r
.76251 .61373 m .76341 .60998 L .76157 .61218 L F
.42 .217 .496 r
.53652 .73054 m .53892 .72747 L .53662 .72816 L F
.637 .378 .509 r
.58777 .58767 m .58776 .5895 L .58427 .59035 L F
.615 .373 .526 r
.59001 .58759 m .58776 .5895 L .58777 .58767 L F
0 .099 .568 r
.56653 .71952 m .56889 .72142 L .57 .72236 L F
.772 .304 .13 r
.56511 .71905 m .56889 .72142 L .56653 .71952 L F
.575 .372 .568 r
.69092 .50085 m .69374 .50137 L .69273 .49894 L F
.576 .373 .568 r
.69273 .49894 m .69374 .50137 L .69545 .49997 L F
.539 .535 .799 r
.50791 .64341 m .50692 .64689 L .50624 .6431 L F
.50791 .64341 m .50898 .64644 L .50692 .64689 L F
.527 .465 .731 r
.50898 .64644 m .50973 .64868 L .50692 .64689 L F
.704 .631 .773 r
.62096 .51703 m .62241 .51901 L .62004 .51819 L F
.374 .742 .99 r
.62135 .5165 m .61938 .5183 L .62144 .51555 L F
.561 .369 .578 r
.62507 .51523 m .62158 .51676 L .62305 .51361 L F
.62158 .51676 m .62096 .51703 L .62123 .51659 L F
.62158 .51676 m .62123 .51659 L .62305 .51361 L F
.383 .665 .97 r
.61653 .51607 m .61829 .51741 L .62118 .51656 L F
0 0 0 r
.62227 .5136 m .62142 .51629 L .62144 .51555 L F
.62142 .51629 m .62135 .51651 L .62135 .51647 L F
.62142 .51629 m .62135 .51647 L .62144 .51555 L F
.835 .497 .414 r
.61929 .51457 m .62113 .51631 L .62227 .5136 L F
.881 .819 .783 r
.62135 .5163 m .62123 .51659 L .62124 .5163 L F
.835 .497 .414 r
.62113 .51631 m .62135 .51651 L .62142 .51629 L F
.62113 .51631 m .62142 .51629 L .62227 .5136 L F
.881 .819 .783 r
.62213 .51437 m .62135 .5163 L .62128 .51507 L F
.62135 .5163 m .62124 .5163 L .62128 .51507 L F
.62305 .51361 m .62142 .51628 L .62213 .51437 L F
.62142 .51628 m .62123 .51659 L .62213 .51437 L F
.383 .665 .97 r
.62102 .51648 m .62118 .51656 L .6212 .51655 L F
.62102 .51648 m .6212 .51655 L .62114 .51649 L F
.374 .742 .99 r
.62132 .51654 m .61938 .5183 L .62135 .5165 L F
.62127 .51659 m .61829 .51741 L .61938 .5183 L F
.62135 .51651 m .62134 .51652 L .62135 .5165 L F
.62135 .51651 m .6212 .51655 L .62127 .51659 L F
.6212 .51655 m .61829 .51741 L .62127 .51659 L F
.881 .819 .783 r
.62123 .51659 m .62096 .51703 L .62105 .51648 L F
.383 .665 .97 r
.61653 .51607 m .62114 .51649 L .61929 .51457 L F
.881 .819 .783 r
.62123 .51659 m .62106 .51641 L .62128 .51507 L F
.383 .665 .97 r
.62114 .51649 m .62135 .51651 L .62113 .51631 L F
.62114 .51649 m .62113 .51631 L .61929 .51457 L F
.881 .819 .783 r
.62114 .51649 m .62105 .51648 L .62106 .51641 L F
.6212 .51655 m .62114 .51652 L .62114 .51649 L F
.62114 .51652 m .62105 .51648 L .62114 .51649 L F
.62123 .51659 m .62105 .51648 L .6212 .51655 L F
.383 .665 .97 r
.62114 .51649 m .6212 .51655 L .62135 .51651 L F
.61653 .51607 m .62118 .51656 L .62102 .51648 L F
.704 .631 .773 r
.62092 .51705 m .62004 .51819 L .61893 .5178 L F
.62096 .51703 m .62004 .51819 L .62092 .51705 L F
.612 .623 .838 r
.65111 .5185 m .64806 .51732 L .6497 .51681 L F
.182 0 .155 r
.61371 .53671 m .61011 .54009 L .61145 .53795 L F
.385 .399 .751 r
.51087 .65731 m .51041 .66036 L .50931 .65884 L F
.51087 .65731 m .5118 .6598 L .51041 .66036 L F
0 0 .052 r
.54931 .74511 m .54834 .74699 L .55064 .74409 L F
.112 .1 .563 r
.75448 .595 m .75492 .59724 L .75352 .59888 L F
.271 .334 .744 r
.75492 .59724 m .75567 .60073 L .75352 .59888 L F
.445 0 0 r
.51763 .76116 m .51654 .76145 L .52011 .76136 L F
.818 .917 .905 r
.49949 .66991 m .50289 .66889 L .50134 .66842 L F
.318 .634 .964 r
.50289 .66889 m .50376 .66765 L .50134 .66842 L F
.581 .417 .624 r
.50518 .66604 m .50564 .66926 L .50289 .66889 L F
.395 0 0 r
.50564 .66926 m .50655 .66949 L .50289 .66889 L F
.478 .345 .62 r
.50733 .66825 m .50564 .66926 L .50518 .66604 L F
.455 .299 .58 r
.50655 .66949 m .50733 .66825 L .50564 .66926 L F
.318 .634 .964 r
.50289 .66889 m .50655 .66949 L .50376 .66765 L F
0 .173 .709 r
.72984 .49255 m .73176 .49436 L .73205 .49549 L F
.927 .636 .16 r
.73175 .497 m .73205 .49549 L .73176 .49436 L F
.73175 .497 m .73253 .49832 L .73205 .49549 L F
.989 .728 .374 r
.47205 .65988 m .47565 .66294 L .47437 .6611 L F
.47205 .65988 m .47311 .664 L .47565 .66294 L F
.529 .551 .822 r
.47565 .66294 m .47636 .65946 L .47437 .6611 L F
.47565 .66294 m .47725 .66299 L .47636 .65946 L F
.819 .351 0 r
.65663 .50854 m .65735 .50877 L .65625 .50633 L F
.65663 .50854 m .65803 .50963 L .65735 .50877 L F
.734 .599 .706 r
.50731 .66363 m .50518 .66604 L .50531 .66385 L F
.521 .298 .516 r
.50731 .66363 m .50725 .66583 L .50518 .66604 L F
.658 .45 .592 r
.51168 .66338 m .50725 .66583 L .50731 .66363 L F
.584 .293 .44 r
.61497 .58163 m .61178 .58435 L .61281 .58189 L F
.162 0 .164 r
.55152 .74239 m .55064 .74409 L .55316 .74154 L F
.523 .267 .469 r
.53159 .73585 m .53436 .73327 L .53185 .73385 L F
.802 .673 .722 r
.6021 .551 m .60545 .54931 L .60436 .54786 L F
.288 .012 .309 r
.55679 .70291 m .55904 .7022 L .55926 .69982 L F
.342 .125 .433 r
.55926 .69982 m .56109 .69925 L .5613 .69695 L F
.065 0 .248 r
.55926 .69982 m .56039 .70104 L .56109 .69925 L F
.55926 .69982 m .55904 .7022 L .56039 .70104 L F
.024 0 .373 r
.53484 .79812 m .53558 .79977 L .53661 .79725 L F
.53484 .79812 m .53425 .80047 L .53558 .79977 L F
.615 .672 .882 r
.53076 .76942 m .53253 .76799 L .53006 .76792 L F
.653 .216 0 r
.5949 .69346 m .59719 .69687 L .59533 .6949 L F
.305 .67 .975 r
.305 .58669 m .30453 .58769 L .30304 .58653 L F
.305 .58669 m .30657 .58783 L .30453 .58769 L F
.457 .486 .801 r
.37364 .67951 m .37526 .68318 L .37672 .68243 L F
.621 .884 .989 r
.28412 .65109 m .28362 .6526 L .2859 .65232 L F
.28412 .65109 m .2823 .65199 L .28362 .6526 L F
.537 .907 .957 r
.26221 .64539 m .26182 .6464 L .26416 .64585 L F
.26221 .64539 m .26029 .64619 L .26182 .6464 L F
.533 .58 .848 r
.26182 .6464 m .26512 .64863 L .26416 .64585 L F
.695 .356 .398 r
.47357 .80317 m .47704 .80317 L .47575 .80571 L F
.895 .612 .5 r
.47575 .80571 m .47704 .80317 L .47684 .80492 L F
.769 .671 .755 r
.57127 .57062 m .57254 .5739 L .56908 .57346 L F
.779 .62 .683 r
.56908 .57346 m .57254 .5739 L .57099 .57671 L F
.812 .664 .699 r
.57254 .5739 m .57205 .57641 L .57099 .57671 L F
.32 0 .022 r
.42865 .69393 m .43087 .69358 L .4322 .69187 L F
.255 0 0 r
.43087 .69358 m .43436 .69149 L .4322 .69187 L F
.886 .829 .785 r
.5097 .75784 m .51136 .7585 L .51314 .75583 L F
.842 .892 .875 r
.64402 .54717 m .64508 .54803 L .64466 .54529 L F
.366 0 0 r
.30464 .60187 m .30299 .60313 L .30103 .60307 L F
.206 0 0 r
.30676 .60136 m .30299 .60313 L .30464 .60187 L F
.394 0 0 r
.26511 .58707 m .26736 .58704 L .26903 .58557 L F
.143 0 0 r
.26736 .58704 m .27108 .58509 L .26903 .58557 L F
.558 .285 .457 r
.63834 .51695 m .64068 .51482 L .6387 .51548 L F
.241 0 0 r
.52113 .80942 m .52201 .80912 L .51856 .80917 L F
0 0 0 r
.52204 .80959 m .52201 .80912 L .5229 .808 L F
.505 .801 .999 r
.55241 .70864 m .55528 .70851 L .55404 .70763 L F
.731 .507 .587 r
.6071 .56154 m .61033 .55975 L .60799 .55976 L F
.6071 .56154 m .61035 .56226 L .61033 .55975 L F
.736 .642 .756 r
.61031 .55764 m .61033 .55975 L .61248 .55697 L F
.604 .455 .653 r
.61033 .55975 m .6127 .55944 L .61248 .55697 L F
.587 .39 .581 r
.61035 .56226 m .6127 .55944 L .61033 .55975 L F
.439 .161 .393 r
.61381 .54882 m .61296 .55053 L .61567 .54809 L F
.42 0 .035 r
.32046 .64699 m .31873 .64863 L .31643 .64864 L F
.105 0 0 r
.32076 .64796 m .32046 .64699 L .32222 .64609 L F
.32076 .64796 m .31873 .64863 L .32046 .64699 L F
.497 .544 .835 r
.67412 .53404 m .67547 .53719 L .67754 .53679 L F
.666 .749 .912 r
.67547 .53719 m .67777 .53886 L .67754 .53679 L F
.889 .76 .713 r
.65663 .50854 m .65771 .51181 L .65803 .50963 L F
.46 .073 .217 r
.44677 .6987 m .44449 .69915 L .44492 .69766 L F
.584 .584 .819 r
.76717 .61233 m .76792 .61429 L .76974 .61157 L F
.621 .635 .843 r
.76974 .61157 m .76792 .61429 L .77039 .61338 L F
.536 .868 .993 r
.69309 .48865 m .69619 .48899 L .69449 .48774 L F
.643 .854 .98 r
.69449 .48774 m .69619 .48899 L .69883 .48745 L F
.963 .649 .375 r
.47898 .77263 m .47573 .77445 L .47594 .77266 L F
.47573 .77445 m .47532 .77468 L .4754 .77441 L F
.47898 .77263 m .47768 .77193 L .47532 .77468 L F
.47898 .77263 m .4793 .77508 L .47768 .77193 L F
.797 .701 .759 r
.47918 .77485 m .47975 .77242 L .47768 .77193 L F
.4793 .77508 m .47933 .77486 L .47918 .77485 L F
.47933 .77486 m .47975 .77242 L .47918 .77485 L F
.963 .649 .375 r
.47573 .77445 m .4754 .77441 L .47594 .77266 L F
.843 .716 .723 r
.60328 .55428 m .6021 .551 L .60225 .55351 L F
.846 .714 .717 r
.60131 .55713 m .60328 .55428 L .60225 .55351 L F
.488 0 0 r
.63358 .51688 m .63475 .51755 L .63246 .51582 L F
.801 .737 .793 r
.77657 .61321 m .77965 .61322 L .7784 .61216 L F
.868 .865 .833 r
.77965 .61322 m .78078 .60935 L .7784 .61216 L F
.77965 .61322 m .78194 .61045 L .78078 .60935 L F
.452 .294 .576 r
.40183 .67445 m .40181 .67691 L .39988 .67742 L F
.516 .372 .624 r
.40208 .67907 m .39988 .67742 L .40181 .67691 L F
.40208 .67907 m .40011 .67949 L .39988 .67742 L F
.43 .14 .37 r
.73188 .51268 m .73113 .51441 L .72885 .51507 L F
.77 .833 .369 r
.73224 .51132 m .73113 .51441 L .73188 .51268 L F
.678 .776 .925 r
.77287 .61275 m .77385 .61463 L .77657 .61321 L F
.244 .437 .852 r
.53744 .73886 m .53635 .73585 L .53398 .73747 L F
.53744 .73886 m .5382 .73884 L .53635 .73585 L F
.641 .737 .918 r
.36984 .59959 m .36884 .60203 L .36734 .59904 L F
.36984 .59959 m .37111 .60142 L .36884 .60203 L F
.467 .297 .567 r
.24277 .60147 m .24475 .59854 L .2428 .59907 L F
.59 .32 .475 r
.63804 .50061 m .64048 .50049 L .64077 .49855 L F
.59 .375 .557 r
.64048 .50049 m .64306 .49782 L .64077 .49855 L F
.535 0 0 r
.57121 .7236 m .57 .72236 L .56889 .72142 L F
0 .146 .623 r
.57 .72236 m .57292 .7246 L .57347 .72518 L F
.535 0 0 r
.57121 .7236 m .57292 .7246 L .57 .72236 L F
.384 0 .025 r
.40286 .65247 m .40515 .65227 L .40599 .65151 L F
.535 .092 .143 r
.40599 .65151 m .40515 .65227 L .40838 .65173 L F
.422 .355 .677 r
.5842 .71862 m .58587 .71884 L .58567 .71649 L F
.807 .655 .694 r
.61149 .55373 m .61248 .55697 L .61299 .55463 L F
.569 .351 .544 r
.57347 .72518 m .57411 .72852 L .57597 .72737 L F
.896 .879 .81 r
.39527 .71641 m .39906 .7138 L .39767 .71308 L F
.127 .657 .87 r
.39906 .7138 m .39964 .71347 L .39767 .71308 L F
.39906 .7138 m .40136 .71394 L .39964 .71347 L F
.733 .518 .601 r
.51529 .76652 m .51203 .76682 L .51212 .76422 L F
.645 .554 .737 r
.60887 .55219 m .6091 .55418 L .61149 .55373 L F
.713 .557 .676 r
.6091 .55418 m .61248 .55697 L .61149 .55373 L F
.6091 .55418 m .61031 .55764 L .61248 .55697 L F
.785 .753 .824 r
.25095 .64174 m .2526 .6437 L .2521 .64269 L F
.647 .273 .321 r
.52357 .76457 m .52578 .76644 L .52349 .76584 L F
.778 .335 .198 r
.53612 .77741 m .53563 .77507 L .53471 .77461 L F
.53612 .77741 m .53758 .77718 L .53563 .77507 L F
.756 .993 .873 r
.78406 .60755 m .78078 .60935 L .78194 .61045 L F
0 0 .168 r
.61307 .49794 m .61339 .49952 L .61359 .49732 L F
.61307 .49794 m .61282 .50085 L .61339 .49952 L F
.573 .445 .667 r
.48578 .76406 m .48802 .76134 L .4844 .76145 L F
.48578 .76406 m .48815 .76385 L .48802 .76134 L F
.162 .295 .753 r
.48578 .76406 m .48804 .76642 L .48815 .76385 L F
.779 .487 .492 r
.51208 .74134 m .51499 .73927 L .51204 .73844 L F
.51208 .74134 m .5158 .74202 L .51499 .73927 L F
.423 .61 .927 r
.37001 .70738 m .372 .70993 L .37101 .70955 L F
.829 .809 .831 r
.54022 .73664 m .5382 .73884 L .5408 .73803 L F
.82 .698 .731 r
.5382 .73884 m .53915 .74259 L .5408 .73803 L F
.755 .777 .871 r
.54022 .73664 m .5408 .73803 L .544 .7367 L F
.427 .127 .351 r
.54894 .77262 m .54624 .77481 L .54742 .77348 L F
.661 .954 .728 r
.5498 .77135 m .54894 .77262 L .54742 .77348 L F
0 0 0 r
.256 .65176 m .25334 .65417 L .25433 .65267 L F
.023 0 0 r
.41645 .64996 m .4187 .64993 L .41994 .64976 L F
.464 0 0 r
.4187 .64993 m .42227 .64977 L .41994 .64976 L F
.65 .738 .914 r
.59178 .7282 m .5934 .7265 L .59071 .72689 L F
.59178 .7282 m .5942 .72759 L .5934 .7265 L F
.514 .6 .877 r
.46474 .65496 m .46891 .65806 L .46699 .65436 L F
.646 .603 .792 r
.46699 .65436 m .46891 .65806 L .47103 .65767 L F
.716 .444 .513 r
.46891 .65806 m .47205 .65988 L .47103 .65767 L F
.46891 .65806 m .46817 .66008 L .47205 .65988 L F
.754 .647 .743 r
.54769 .76935 m .55136 .7704 L .55006 .76667 L F
.257 0 0 r
.29373 .58531 m .29739 .58578 L .2953 .58602 L F
.778 .306 0 r
.65883 .50107 m .65915 .50249 L .65799 .49988 L F
.65883 .50107 m .66081 .50464 L .65915 .50249 L F
.755 .777 .871 r
.54022 .73664 m .544 .7367 L .54249 .73624 L F
.353 0 .138 r
.5461 .73612 m .54536 .73682 L .544 .7367 L F
.566 .217 .335 r
.54863 .73727 m .54889 .73778 L .54545 .73683 L F
.109 0 0 r
.54625 .73694 m .54532 .73686 L .54674 .73699 L F
.544 .7367 m .54532 .73686 L .54625 .73694 L F
.544 .7367 m .54625 .73694 L .54537 .73682 L F
.566 .217 .335 r
.54545 .73683 m .54565 .73689 L .54532 .73686 L F
.54565 .73689 m .54889 .73778 L .54532 .73686 L F
.54811 .7363 m .54863 .73727 L .54545 .73683 L F
.109 0 0 r
.54537 .73682 m .54674 .73699 L .54605 .73688 L F
.54625 .73694 m .54674 .73699 L .54537 .73682 L F
.24 .581 .944 r
.54582 .73684 m .5482 .73675 L .54674 .73699 L F
.109 0 0 r
.54605 .73688 m .54674 .73699 L .54611 .73688 L F
.24 .581 .944 r
.54532 .73686 m .54582 .73684 L .54674 .73699 L F
.353 0 .138 r
.54536 .73682 m .54532 .73686 L .544 .7367 L F
.109 0 0 r
.544 .7367 m .54611 .73688 L .54249 .73624 L F
.695 .158 0 r
.53915 .74259 m .54222 .74486 L .54281 .74462 L F
.381 0 .092 r
.54281 .74462 m .5416 .74673 L .53933 .74672 L F
.422 .844 .685 r
.54281 .74462 m .54222 .74486 L .54428 .74366 L F
.312 0 .058 r
.54428 .74539 m .54281 .74462 L .54428 .74366 L F
.54428 .74539 m .5416 .74673 L .54281 .74462 L F
.857 .993 .747 r
.67614 .52851 m .678 .52614 L .67773 .52545 L F
.097 0 .015 r
.73015 .51571 m .72885 .51507 L .73113 .51441 L F
.73015 .51571 m .72827 .51668 L .72885 .51507 L F
.638 .144 .062 r
.48672 .75537 m .48569 .75587 L .48333 .75512 L F
.404 .161 .429 r
.48841 .75415 m .48672 .75537 L .4892 .75299 L F
.056 0 0 r
.48826 .75525 m .48672 .75537 L .48841 .75415 L F
.48826 .75525 m .48569 .75587 L .48672 .75537 L F
.852 .496 0 r
.73253 .49832 m .733 .49994 L .73365 .50084 L F
.978 .774 .357 r
.733 .49994 m .73343 .5027 L .73365 .50084 L F
.756 .993 .873 r
.78406 .60755 m .78336 .60731 L .78078 .60935 L F
.766 .578 .644 r
.64951 .53165 m .6513 .5345 L .65227 .53178 L F
.609 .723 .926 r
.67296 .48816 m .67472 .4859 L .67326 .4861 L F
.67296 .48816 m .67594 .48772 L .67472 .4859 L F
0 0 0 r
.53308 .80241 m .53425 .80047 L .53231 .80313 L F
.53558 .79977 m .53425 .80047 L .53308 .80241 L F
.716 .363 .378 r
.662 .48033 m .6651 .48004 L .66298 .48083 L F
.023 .005 .494 r
.50889 .69691 m .50988 .69329 L .51229 .69423 L F
.501 .816 1 r
.50988 .69329 m .51338 .69365 L .51229 .69423 L F
.857 .61 .565 r
.57524 .68729 m .57907 .68583 L .57534 .68485 L F
.57524 .68729 m .57876 .68819 L .57907 .68583 L F
0 0 .178 r
.57907 .68583 m .57994 .68659 L .5794 .68478 L F
.57907 .68583 m .57876 .68819 L .57994 .68659 L F
.184 0 .146 r
.5613 .69695 m .56311 .69652 L .56403 .69453 L F
.418 .246 .539 r
.56109 .69925 m .56311 .69652 L .5613 .69695 L F
.895 .938 .834 r
.71179 .50009 m .71367 .49965 L .71249 .49768 L F
.638 .789 .954 r
.71367 .49965 m .71503 .49725 L .71249 .49768 L F
.71367 .49965 m .71599 .4991 L .71503 .49725 L F
.662 .509 .666 r
.4844 .76145 m .48802 .76134 L .48709 .75752 L F
.671 .515 .664 r
.48709 .75752 m .48802 .76134 L .49026 .75834 L F
.703 .881 .964 r
.45075 .64611 m .44881 .64726 L .44726 .64641 L F
.536 .243 .417 r
.32867 .62345 m .33162 .62131 L .32942 .62185 L F
.701 .747 .887 r
.46885 .66398 m .47311 .664 L .47039 .66372 L F
.989 .728 .374 r
.47205 .65988 m .47232 .66335 L .47311 .664 L F
.594 .876 .993 r
.47232 .66335 m .47039 .66372 L .47311 .664 L F
.625 .574 .777 r
.69433 .50389 m .69545 .49997 L .69374 .50137 L F
.69433 .50389 m .69675 .50364 L .69545 .49997 L F
.739 .992 .823 r
.69487 .53653 m .69796 .53451 L .69691 .53553 L F
.396 .85 .79 r
.70118 .53248 m .69963 .53335 L .70107 .5321 L F
.70118 .53248 m .70095 .53257 L .69963 .53335 L F
0 0 0 r
.69963 .53335 m .69832 .53413 L .70042 .53186 L F
.70211 .53061 m .69963 .53335 L .70042 .53186 L F
.70107 .5321 m .69963 .53335 L .70211 .53061 L F
.396 .85 .79 r
.70095 .53257 m .6983 .53362 L .69963 .53335 L F
0 0 0 r
.69963 .53335 m .69796 .53451 L .69832 .53413 L F
.69963 .53335 m .69691 .53553 L .69796 .53451 L F
.506 .802 .999 r
.38983 .65374 m .3891 .65506 L .38731 .65409 L F
.26 0 0 r
.38974 .65612 m .39127 .65471 L .3891 .65506 L F
.38974 .65612 m .3891 .65506 L .38983 .65374 L F
.45 .166 .39 r
.51304 .77144 m .51536 .77136 L .51334 .76978 L F
.823 .778 .81 r
.58543 .69509 m .58433 .69516 L .58343 .69376 L F
0 0 .156 r
.54027 .78709 m .5387 .7897 L .54006 .78885 L F
.958 .682 .471 r
.54621 .75089 m .54712 .75551 L .54585 .75467 L F
.892 .811 .762 r
.54646 .75243 m .54975 .75012 L .54656 .75003 L F
.977 .726 .489 r
.54975 .75012 m .54841 .75033 L .54834 .74699 L F
.428 .871 .83 r
.55058 .74939 m .54975 .75012 L .55225 .75046 L F
.55058 .74939 m .54841 .75033 L .54975 .75012 L F
0 0 0 r
.70211 .53061 m .70042 .53186 L .70301 .52929 L F
.463 .062 .193 r
.46408 .69095 m .46276 .69308 L .46049 .69321 L F
.618 .288 .39 r
.46638 .69085 m .46276 .69308 L .46408 .69095 L F
.637 .083 0 r
.6651 .52889 m .66573 .52993 L .66379 .52811 L F
.6651 .52889 m .66747 .53087 L .66573 .52993 L F
.528 .69 .942 r
.7704 .58471 m .7731 .5829 L .76952 .58308 L F
.7704 .58471 m .77285 .58432 L .7731 .5829 L F
.529 .467 .73 r
.77132 .58769 m .77285 .58432 L .7704 .58471 L F
.467 .228 .468 r
.28594 .61011 m .28548 .6129 L .28326 .61282 L F
.425 .192 .455 r
.28751 .61228 m .28594 .61011 L .2879 .60957 L F
.28751 .61228 m .28548 .6129 L .28594 .61011 L F
.512 .222 .41 r
.61769 .57966 m .61733 .58153 L .61497 .58163 L F
.481 .194 .401 r
.61967 .58094 m .61769 .57966 L .61962 .57881 L F
.61967 .58094 m .61733 .58153 L .61769 .57966 L F
.451 0 .033 r
.48488 .69083 m .4838 .69156 L .48134 .69145 L F
.658 .201 .155 r
.4869 .6917 m .4838 .69156 L .48488 .69083 L F
.737 .607 .037 r
.65342 .48917 m .65341 .48536 L .65375 .48725 L F
.712 .718 .854 r
.65311 .51728 m .65111 .5185 L .6497 .51681 L F
0 0 .537 r
.54909 .80026 m .54874 .80014 L .5488 .79835 L F
.258 .045 .387 r
.28464 .61428 m .28326 .61282 L .28548 .6129 L F
.28464 .61428 m .28313 .61518 L .28326 .61282 L F
.653 .859 .978 r
.47431 .64132 m .47371 .64303 L .47229 .64201 L F
.47431 .64132 m .47585 .64227 L .47371 .64303 L F
.496 .212 .413 r
.56311 .69652 m .56604 .69309 L .56403 .69453 L F
.612 .346 .49 r
.48044 .76961 m .48338 .76964 L .48348 .76704 L F
.623 .355 .491 r
.48348 .76704 m .48338 .76964 L .48582 .76904 L F
.808 .332 0 r
.63555 .4802 m .6371 .48139 L .6357 .47963 L F
.63555 .4802 m .6357 .47963 L .63513 .4789 L F
.747 .6 .693 r
.63555 .4802 m .63675 .48318 L .6329 .48229 L F
0 0 0 r
.63555 .4802 m .63454 .48145 L .63533 .48101 L F
.606 .255 .349 r
.6371 .48139 m .63675 .48318 L .63555 .4802 L F
0 0 0 r
.63555 .4802 m .63533 .48101 L .63674 .48023 L F
.808 .332 0 r
.63555 .4802 m .63513 .4789 L .63552 .47791 L F
.711 .214 .057 r
.67777 .53886 m .67985 .53879 L .68121 .54011 L F
.644 .414 .556 r
.59562 .58502 m .59559 .58731 L .59233 .58755 L F
.625 .363 .501 r
.59781 .5851 m .59559 .58731 L .59562 .58502 L F
.543 .439 .686 r
.37364 .67951 m .37544 .67682 L .37366 .67741 L F
.699 .366 .409 r
.66834 .53185 m .66926 .53415 L .66779 .53391 L F
.544 .747 .97 r
.66747 .53087 m .66834 .53185 L .67024 .53029 L F
.686 .353 .406 r
.66834 .53185 m .6712 .53369 L .67024 .53029 L F
.66834 .53185 m .66779 .53391 L .6712 .53369 L F
.07 0 0 r
.31028 .6011 m .30886 .6013 L .30676 .60136 L F
0 0 0 r
.31239 .60091 m .30886 .6013 L .31028 .6011 L F
.09 0 0 r
.52712 .77613 m .52612 .7759 L .52481 .77721 L F
.52712 .77613 m .5287 .77594 L .52612 .7759 L F
.384 0 0 r
.52612 .7759 m .5287 .77594 L .52894 .77567 L F
.649 .805 .958 r
.74707 .58726 m .74483 .58811 L .74378 .58688 L F
.529 .467 .73 r
.77132 .58769 m .77346 .58863 L .77285 .58432 L F
.613 .566 .778 r
.63549 .49014 m .63679 .49375 L .63686 .49222 L F
.868 .721 .698 r
.63688 .49296 m .63686 .49222 L .63679 .49375 L F
.478 .486 .788 r
.63619 .49042 m .63638 .49148 L .63549 .49014 L F
.754 .577 .656 r
.63686 .49222 m .63656 .49175 L .63549 .49014 L F
.478 .486 .788 r
.63638 .49148 m .63643 .49175 L .63549 .49014 L F
.63643 .49175 m .63626 .49176 L .63549 .49014 L F
.63626 .49176 m .63607 .49176 L .63585 .49116 L F
.63626 .49176 m .63585 .49116 L .63549 .49014 L F
.754 .577 .656 r
.63626 .49176 m .63413 .49219 L .63272 .48905 L F
.63686 .49222 m .63657 .49222 L .63626 .49176 L F
.478 .486 .788 r
.63618 .49176 m .63679 .49375 L .63607 .49176 L F
.63643 .49175 m .63649 .49212 L .63618 .49176 L F
.63649 .49212 m .63679 .49375 L .63618 .49176 L F
0 .239 .726 r
.63457 .49518 m .63413 .49219 L .63657 .49222 L F
.63673 .4924 m .63657 .49222 L .63686 .49222 L F
.754 .577 .656 r
.63686 .49222 m .63626 .49176 L .63656 .49175 L F
.478 .486 .788 r
.63688 .49296 m .63679 .49375 L .63619 .49042 L F
0 .239 .726 r
.63457 .49518 m .63657 .49222 L .63673 .4924 L F
.754 .577 .656 r
.63657 .49222 m .63413 .49219 L .63626 .49176 L F
.63656 .49175 m .63454 .48868 L .63549 .49014 L F
.63656 .49175 m .63272 .48905 L .63454 .48868 L F
.63626 .49176 m .63272 .48905 L .63656 .49175 L F
.868 .721 .698 r
.63694 .49587 m .63457 .49518 L .63673 .4924 L F
.63688 .49296 m .63673 .4924 L .63686 .49222 L F
.61 .482 .681 r
.6394 .49304 m .63723 .49363 L .63834 .49129 L F
.63723 .49363 m .63679 .49375 L .637 .49341 L F
.63723 .49363 m .637 .49341 L .63834 .49129 L F
.868 .721 .698 r
.63689 .4933 m .63673 .4924 L .63688 .49296 L F
.478 .486 .788 r
.63834 .49129 m .63679 .49375 L .63713 .4908 L F
.868 .721 .698 r
.63689 .4933 m .63688 .49296 L .63684 .49326 L F
.61 .482 .681 r
.6394 .49304 m .63694 .49587 L .63679 .49375 L F
.868 .721 .698 r
.63694 .49587 m .6368 .49362 L .63679 .49375 L F
.63694 .49587 m .63678 .49319 L .63689 .4933 L F
.63678 .49319 m .63673 .4924 L .63689 .4933 L F
.478 .486 .788 r
.63713 .4908 m .63688 .49296 L .63619 .49042 L F
.661 .916 .977 r
.36674 .70288 m .37028 .70244 L .36892 .69944 L F
.968 .707 .484 r
.36892 .69944 m .36881 .70198 L .37028 .70244 L F
.706 .303 .282 r
.36902 .7037 m .37028 .70244 L .36881 .70198 L F
.36902 .7037 m .37229 .70465 L .37028 .70244 L F
.596 .227 .311 r
.43967 .69015 m .44205 .69042 L .44007 .68878 L F
.557 .245 .395 r
.44007 .68878 m .44205 .69042 L .44258 .68866 L F
.674 .392 .487 r
.59781 .5851 m .60144 .58484 L .60014 .5872 L F
.637 .362 .485 r
.60372 .58487 m .60014 .5872 L .60144 .58484 L F
.433 .013 .141 r
.40957 .71159 m .40679 .71237 L .4073 .71193 L F
.659 .702 .878 r
.28441 .63179 m .28217 .63281 L .28107 .63101 L F
.799 .485 .459 r
.54535 .75873 m .54559 .76129 L .54633 .76043 L F
.816 .748 .787 r
.36642 .70426 m .36797 .70539 L .36674 .70288 L F
.616 .604 .816 r
.36479 .70578 m .36797 .70539 L .36642 .70426 L F
.36479 .70578 m .36787 .70794 L .36797 .70539 L F
.493 .59 .88 r
.36674 .70288 m .36797 .70539 L .36902 .7037 L F
.518 .329 .563 r
.36797 .70539 m .37001 .70738 L .36902 .7037 L F
.36797 .70539 m .36787 .70794 L .37001 .70738 L F
.689 .511 .641 r
.49244 .75825 m .49571 .75987 L .49591 .75544 L F
.357 .128 .424 r
.49571 .75987 m .49826 .7557 L .49591 .75544 L F
.227 0 0 r
.55094 .73628 m .54811 .7363 L .5461 .73612 L F
.528 0 0 r
.55116 .73618 m .54811 .7363 L .55094 .73628 L F
.771 .577 .636 r
.57205 .57641 m .57057 .57904 L .57099 .57671 L F
.57205 .57641 m .57435 .57942 L .57057 .57904 L F
.487 .21 .419 r
.34224 .63398 m .34041 .63251 L .34259 .63211 L F
.34224 .63398 m .33996 .63474 L .34041 .63251 L F
.443 0 .026 r
.50407 .75607 m .5064 .75681 L .50802 .75539 L F
.624 .072 0 r
.5064 .75681 m .5097 .75784 L .50802 .75539 L F
0 .183 .716 r
.7292 .49117 m .73176 .49436 L .72984 .49255 L F
.178 0 0 r
.43442 .70253 m .43307 .7036 L .43079 .704 L F
.281 0 0 r
.43664 .70224 m .43307 .7036 L .43442 .70253 L F
.478 .345 .62 r
.50733 .66825 m .50518 .66604 L .50725 .66583 L F
.469 0 0 r
.25043 .6471 m .25021 .6469 L .24857 .6468 L F
.25043 .6471 m .25211 .64857 L .25021 .6469 L F
.186 .402 .84 r
.54854 .7517 m .5503 .7541 L .54833 .75314 L F
.662 .866 .977 r
.54854 .7517 m .54833 .75314 L .54646 .75243 L F
.195 .686 .923 r
.67264 .48347 m .67464 .48348 L .67128 .48289 L F
.075 0 .018 r
.28313 .61518 m .28035 .61767 L .28109 .6162 L F
.857 .993 .747 r
.67614 .52851 m .67773 .52545 L .67612 .52809 L F
.521 .727 .967 r
.67771 .52971 m .67614 .52851 L .67612 .52809 L F
.67771 .52971 m .67648 .53145 L .67614 .52851 L F
.177 .578 .938 r
.24898 .64133 m .24938 .64039 L .24739 .64061 L F
.24898 .64133 m .25095 .64174 L .24938 .64039 L F
.579 .321 .489 r
.60469 .56231 m .6071 .56154 L .60799 .55976 L F
.901 .935 .826 r
.58472 .5511 m .58598 .54744 L .58644 .5481 L F
.919 .974 .695 r
.58644 .5481 m .58598 .54744 L .58776 .54429 L F
.536 0 0 r
.278 .65266 m .27499 .65151 L .27609 .65178 L F
.184 .691 .904 r
.27609 .65178 m .27451 .65133 L .27423 .65175 L F
.536 0 0 r
.27499 .65151 m .27451 .65133 L .27609 .65178 L F
.117 .657 .847 r
.27669 .65193 m .27609 .65178 L .27423 .65175 L F
.27818 .65205 m .27609 .65178 L .27669 .65193 L F
.43 0 0 r
.28025 .6528 m .27609 .65178 L .27818 .65205 L F
.868 .466 .005 r
.4742 .76674 m .47527 .7693 L .47599 .76983 L F
.814 .595 .606 r
.47527 .7693 m .47768 .77193 L .47599 .76983 L F
.787 .664 .727 r
.63746 .53743 m .63345 .53923 L .63566 .53629 L F
.63746 .53743 m .63555 .54009 L .63345 .53923 L F
.569 .391 .601 r
.38092 .6577 m .38318 .65727 L .38342 .65497 L F
.438 .22 .484 r
.38092 .6577 m .38252 .65915 L .38318 .65727 L F
.38092 .6577 m .38054 .65982 L .38252 .65915 L F
.272 .025 .346 r
.33407 .61585 m .33562 .61524 L .33621 .61319 L F
.423 .23 .511 r
.33407 .61585 m .33568 .61752 L .33562 .61524 L F
.33407 .61585 m .33378 .6182 L .33568 .61752 L F
.703 .411 .477 r
.50086 .69097 m .50534 .69142 L .50383 .68917 L F
.798 .317 0 r
.50534 .69142 m .50542 .69146 L .50383 .68917 L F
.45 .517 .835 r
.7002 .48942 m .70189 .48793 L .69883 .48745 L F
.7002 .48942 m .70218 .48969 L .70189 .48793 L F
.586 .654 .883 r
.26512 .64863 m .26574 .64576 L .26416 .64585 L F
.26512 .64863 m .26773 .64819 L .26574 .64576 L F
.985 .727 .455 r
.48087 .66312 m .48439 .66569 L .48306 .66265 L F
.728 .676 .799 r
.48306 .66265 m .48439 .66569 L .48661 .66306 L F
.667 .58 .748 r
.48439 .66569 m .48762 .66621 L .48661 .66306 L F
.585 .88 .993 r
.47028 .64231 m .46792 .64305 L .46663 .64242 L F
.683 .795 .934 r
.70798 .48468 m .7047 .48449 L .70679 .48313 L F
.767 .824 .897 r
.70943 .48189 m .70798 .48468 L .70679 .48313 L F
.70943 .48189 m .71009 .48365 L .70798 .48468 L F
0 .05 .612 r
.5026 .76925 m .50242 .7697 L .50062 .76932 L F
.241 0 0 r
.46756 .68371 m .46892 .68424 L .47121 .68373 L F
.374 0 0 r
.46892 .68424 m .47346 .68329 L .47121 .68373 L F
.03 .528 .875 r
.31801 .5886 m .32145 .58999 L .31968 .58958 L F
.292 .41 .81 r
.51129 .64841 m .51147 .65192 L .50973 .64868 L F
.51129 .64841 m .51252 .65151 L .51147 .65192 L F
0 .162 .626 r
.54047 .74341 m .54222 .74486 L .53915 .74259 L F
.54047 .74341 m .53915 .74259 L .53831 .74361 L F
.724 .958 .676 r
.55587 .77799 m .55896 .7756 L .55821 .77777 L F
.775 .874 .445 r
.55925 .77434 m .55896 .7756 L .56043 .77245 L F
0 .074 .631 r
.55925 .77434 m .56037 .77739 L .55896 .7756 L F
.499 .264 .49 r
.55896 .7756 m .56037 .77739 L .55821 .77777 L F
.386 .787 .985 r
.31423 .60086 m .31615 .60113 L .31467 .6005 L F
.388 .791 .984 r
.31615 .60113 m .3167 .60028 L .31467 .6005 L F
.31615 .60113 m .31808 .60089 L .3167 .60028 L F
.662 .51 .667 r
.55587 .77799 m .55641 .78144 L .55365 .78088 L F
.453 .791 .999 r
.55587 .77799 m .55821 .77777 L .55678 .77697 L F
.55587 .77799 m .55821 .77777 L .55678 .77697 L F
.582 .46 .679 r
.55587 .77799 m .55816 .78078 L .55641 .78144 L F
.55587 .77799 m .55821 .77777 L .55816 .78078 L F
.325 .123 .444 r
.62145 .57789 m .61985 .57667 L .6216 .5758 L F
.62145 .57789 m .61962 .57881 L .61985 .57667 L F
.413 .254 .554 r
.62984 .49399 m .62765 .49258 L .62998 .49197 L F
.62984 .49399 m .62771 .49491 L .62765 .49258 L F
.645 .554 .737 r
.60887 .55219 m .61149 .55373 L .61005 .54913 L F
.618 .413 .581 r
.48577 .68573 m .48835 .68809 L .48982 .68513 L F
.765 .524 .569 r
.48835 .68809 m .49149 .68869 L .48982 .68513 L F
.065 0 0 r
.27108 .58509 m .27314 .58494 L .27456 .58461 L F
.27 0 0 r
.27314 .58494 m .27672 .58475 L .27456 .58461 L F
.498 .04 .096 r
.46151 .68431 m .4637 .68445 L .46514 .68286 L F
.198 0 0 r
.46514 .68286 m .4658 .68392 L .46756 .68371 L F
.46514 .68286 m .4637 .68445 L .4658 .68392 L F
.967 .915 .704 r
.66487 .48541 m .66729 .48875 L .66452 .48701 L F
0 .284 .764 r
.66452 .48701 m .66729 .48875 L .66825 .49005 L F
.692 .544 .68 r
.47868 .78772 m .4761 .78861 L .47567 .78634 L F
.47868 .78772 m .48096 .78935 L .4761 .78861 L F
.64 .858 .982 r
.66825 .49005 m .66729 .48875 L .66905 .48813 L F
.897 .94 .831 r
.66905 .48813 m .66753 .49199 L .66825 .49005 L F
.91 .505 .179 r
.48671 .80597 m .48553 .8049 L .4857 .80519 L F
.868 .472 .004 r
.48681 .80768 m .48671 .80597 L .4857 .80519 L F
.503 .827 1 r
.48645 .80637 m .4857 .80519 L .48706 .80522 L F
.48618 .80686 m .48681 .80768 L .4857 .80519 L F
.48618 .80686 m .4857 .80519 L .48645 .80637 L F
.91 .505 .179 r
.48553 .8049 m .48526 .80467 L .4857 .80519 L F
.868 .472 .004 r
.48681 .80768 m .48778 .80868 L .48671 .80597 L F
.562 .443 .675 r
.47342 .76126 m .47586 .76092 L .47534 .75826 L F
.525 .518 .79 r
.47342 .76126 m .47626 .7635 L .47586 .76092 L F
0 .083 .622 r
.33773 .60737 m .33839 .60634 L .33685 .60424 L F
.168 .038 .447 r
.33773 .60737 m .33912 .60815 L .33839 .60634 L F
.33773 .60737 m .33752 .60989 L .33912 .60815 L F
.211 0 0 r
.24608 .637 m .24881 .63522 L .24775 .63585 L F
.472 0 0 r
.51414 .81403 m .51647 .81455 L .51395 .81413 L F
.51414 .81403 m .5166 .81398 L .51647 .81455 L F
.325 .81 .869 r
.27672 .58475 m .27876 .58425 L .28031 .58422 L F
.049 .616 .729 r
.28031 .58422 m .27876 .58425 L .2824 .58413 L F
.494 .29 .532 r
.49595 .74495 m .49383 .74798 L .49603 .74722 L F
.446 .254 .525 r
.49595 .74495 m .49603 .74722 L .49801 .7465 L F
.49595 .74495 m .49603 .74722 L .49801 .7465 L F
.604 .467 .668 r
.37455 .67116 m .37651 .66839 L .3746 .66899 L F
.276 .711 .966 r
.50049 .63717 m .49906 .6377 L .49744 .63729 L F
.50049 .63717 m .50112 .6377 L .49906 .6377 L F
.943 .594 .19 r
.47971 .80029 m .47836 .79743 L .47775 .80008 L F
.65 .968 .891 r
.48095 .79889 m .47971 .80029 L .47775 .80008 L F
.599 .391 .571 r
.53436 .73327 m .53665 .73298 L .53652 .73054 L F
.42 .217 .496 r
.53652 .73054 m .53842 .73025 L .53892 .72747 L F
.504 .319 .563 r
.53652 .73054 m .5384 .73245 L .53842 .73025 L F
.53652 .73054 m .53665 .73298 L .5384 .73245 L F
.762 .496 .531 r
.56368 .77545 m .56037 .77739 L .56266 .77456 L F
.56368 .77545 m .56387 .77771 L .56037 .77739 L F
.571 .072 .03 r
.56368 .77545 m .56574 .77654 L .56387 .77771 L F
.742 .811 .907 r
.71277 .48169 m .71009 .48365 L .70943 .48189 L F
.76 .383 .341 r
.49475 .80378 m .49322 .80544 L .49091 .80292 L F
.267 .11 .474 r
.49722 .80168 m .49544 .80473 L .49535 .80454 L F
0 0 .132 r
.49548 .80419 m .49475 .80378 L .49556 .8014 L F
.49547 .80422 m .49475 .80378 L .49548 .80419 L F
.174 0 0 r
.49544 .80473 m .49475 .80378 L .49547 .80422 L F
.49544 .80473 m .49547 .80422 L .49548 .80423 L F
0 0 .132 r
.49548 .80415 m .49556 .8014 L .49543 .80008 L F
.267 .11 .474 r
.49643 .80166 m .49547 .80422 L .49558 .80165 L F
0 0 .132 r
.49548 .80423 m .49548 .80419 L .49548 .80415 L F
.49548 .80419 m .49556 .8014 L .49548 .80415 L F
.267 .11 .474 r
.49535 .80394 m .49535 .80454 L .4939 .80161 L F
.49722 .80168 m .49535 .80454 L .49643 .80166 L F
0 0 .132 r
.49548 .80423 m .49547 .80422 L .49548 .80419 L F
.938 .663 .493 r
.4939 .80161 m .49548 .80423 L .49548 .80415 L F
.4939 .80161 m .49548 .80415 L .49543 .80008 L F
.267 .11 .474 r
.49536 .80164 m .49535 .80394 L .4939 .80161 L F
.49558 .80165 m .49544 .80339 L .49536 .80164 L F
.49544 .80339 m .49535 .80454 L .49536 .80164 L F
.49547 .80422 m .49535 .80454 L .49558 .80165 L F
.174 0 0 r
.49544 .80473 m .49322 .80544 L .49475 .80378 L F
.271 .768 .893 r
.42227 .64977 m .42459 .64948 L .42572 .64966 L F
.237 0 0 r
.42459 .64948 m .42788 .64942 L .42572 .64966 L F
.625 .363 .501 r
.59781 .5851 m .59799 .58716 L .59559 .58731 L F
.674 .392 .487 r
.59781 .5851 m .60014 .5872 L .59799 .58716 L F
.661 .829 .964 r
.5052 .62663 m .50219 .62681 L .50458 .62592 L F
.50458 .62592 m .50219 .62681 L .5052 .62663 L F
.438 .72 .985 r
.5052 .62663 m .50668 .62577 L .50458 .62592 L F
.50458 .62592 m .50668 .62577 L .5052 .62663 L F
.684 .515 .651 r
.61248 .55697 m .6127 .55944 L .61587 .55844 L F
.53 .632 .896 r
.69089 .47959 m .68936 .48164 L .68865 .47988 L F
.539 .644 .902 r
.69089 .47959 m .69159 .48127 L .68936 .48164 L F
.548 .692 .934 r
.69213 .48244 m .68936 .48164 L .69159 .48127 L F
.289 0 .116 r
.5287 .77594 m .53157 .77373 L .52894 .77567 L F
.5287 .77594 m .53067 .77533 L .53157 .77373 L F
.655 .365 .466 r
.53067 .77533 m .53471 .77461 L .53157 .77373 L F
.792 .558 .584 r
.48222 .68794 m .48577 .68573 L .48354 .6857 L F
.48222 .68794 m .4857 .68845 L .48577 .68573 L F
.618 .413 .581 r
.48577 .68573 m .4857 .68845 L .48835 .68809 L F
.47 .83 .994 r
.33477 .59045 m .33421 .59168 L .33267 .591 L F
.33477 .59045 m .33646 .59126 L .33421 .59168 L F
.626 .147 .097 r
.55365 .78088 m .55598 .78348 L .55294 .78311 L F
.55365 .78088 m .55676 .78259 L .55598 .78348 L F
.628 .198 .206 r
.55365 .78088 m .55641 .78144 L .55676 .78259 L F
.539 .314 .522 r
.42584 .66335 m .42567 .66562 L .42365 .66533 L F
.586 .354 .531 r
.42584 .66335 m .42803 .66537 L .42567 .66562 L F
.59 .353 .526 r
.42816 .66313 m .42803 .66537 L .42584 .66335 L F
0 0 .317 r
.54621 .75089 m .54646 .75243 L .54656 .75003 L F
.958 .682 .471 r
.54621 .75089 m .54585 .75467 L .54646 .75243 L F
.799 .625 .666 r
.5257 .76159 m .52497 .76223 L .52235 .7609 L F
.74 .309 .226 r
.52235 .7609 m .52453 .7631 L .5257 .76159 L F
.467 0 .051 r
.5257 .76159 m .52985 .76251 L .52826 .76128 L F
.5257 .76159 m .52453 .7631 L .52985 .76251 L F
.918 .582 .389 r
.57923 .72495 m .57778 .72614 L .57807 .72498 L F
.474 .124 .293 r
.58053 .72398 m .57807 .72498 L .57923 .72495 L F
.017 0 0 r
.58082 .7248 m .57923 .72495 L .58053 .72398 L F
.58082 .7248 m .57778 .72614 L .57923 .72495 L F
.686 .31 .328 r
.51654 .76145 m .51879 .76338 L .52011 .76136 L F
.662 .28 .312 r
.52011 .76136 m .52342 .76322 L .52235 .7609 L F
.52011 .76136 m .51879 .76338 L .52342 .76322 L F
.633 .716 .907 r
.69413 .48044 m .69213 .48244 L .69159 .48127 L F
.69413 .48044 m .69534 .48159 L .69213 .48244 L F
.384 .54 .887 r
.48136 .78867 m .48096 .78935 L .47868 .78772 L F
.908 .889 .801 r
.75073 .59226 m .7534 .59042 L .75325 .58974 L F
0 0 0 r
.7534 .59042 m .75488 .58952 L .75325 .58974 L F
.336 .431 .811 r
.50663 .64032 m .50791 .64341 L .50624 .6431 L F
0 0 .484 r
.3862 .71086 m .38675 .71442 L .38681 .71301 L F
.86 .409 .1 r
.3895 .71619 m .38675 .71442 L .38783 .7162 L F
.3895 .71619 m .38681 .71301 L .38675 .71442 L F
.499 .178 .354 r
.44019 .69969 m .43889 .70207 L .43664 .70224 L F
.475 .148 .333 r
.44206 .69946 m .43889 .70207 L .44019 .69969 L F
.252 .064 .421 r
.46569 .77803 m .46714 .77777 L .46742 .77516 L F
.311 .305 .691 r
.46569 .77803 m .46773 .78009 L .46714 .77777 L F
.431 .324 .632 r
.46594 .78056 m .46773 .78009 L .46569 .77803 L F
.668 .973 .891 r
.55463 .79094 m .55783 .78918 L .55743 .78884 L F
.752 .707 .809 r
.55783 .78918 m .55918 .7856 L .55743 .78662 L F
.55783 .78918 m .5609 .78682 L .55918 .7856 L F
.833 .541 0 r
.6553 .50298 m .65625 .50633 L .65586 .50425 L F
0 0 0 r
.49199 .74908 m .49383 .74798 L .4915 .74965 L F
.553 .201 .325 r
.42365 .66533 m .42006 .6677 L .42042 .66688 L F
.42365 .66533 m .42221 .66789 L .42006 .6677 L F
.369 .012 .221 r
.42438 .66737 m .42365 .66533 L .42567 .66562 L F
.42438 .66737 m .42221 .66789 L .42365 .66533 L F
.744 .526 .598 r
.57435 .57942 m .57021 .58146 L .57057 .57904 L F
.57435 .57942 m .57413 .5818 L .57021 .58146 L F
.75 .844 .922 r
.48964 .63765 m .48788 .63895 L .48621 .63764 L F
.985 .833 .444 r
.72055 .50868 m .72069 .51031 L .721 .50671 L F
.721 .50671 m .72309 .50624 L .72285 .50606 L F
.721 .50671 m .72069 .51031 L .72055 .50868 L F
.721 .50671 m .72055 .50868 L .72368 .50611 L F
.819 .997 .849 r
.72167 .50701 m .72058 .50752 L .72281 .50531 L F
.72055 .50868 m .72057 .50761 L .72167 .50701 L F
.72057 .50761 m .72058 .50752 L .72167 .50701 L F
.985 .833 .444 r
.72309 .50624 m .72368 .50611 L .72337 .50609 L F
.72309 .50624 m .72337 .50609 L .72285 .50606 L F
.562 .56 .809 r
.61005 .54913 m .61296 .55053 L .61247 .54729 L F
.637 .522 .707 r
.61005 .54913 m .61149 .55373 L .61296 .55053 L F
.403 .341 .673 r
.46659 .76941 m .46888 .77159 L .46822 .76929 L F
.46659 .76941 m .4669 .77322 L .46888 .77159 L F
.417 0 .066 r
.4045 .71299 m .40378 .71393 L .40136 .71394 L F
.184 0 0 r
.40679 .71237 m .40582 .7133 L .4045 .71299 L F
.177 0 0 r
.40582 .7133 m .40378 .71393 L .4045 .71299 L F
.077 0 0 r
.31281 .63216 m .31599 .63134 L .31388 .63178 L F
.464 .312 .59 r
.24087 .60456 m .24285 .60403 L .24277 .60147 L F
.432 .237 .514 r
.24065 .60689 m .24285 .60403 L .24087 .60456 L F
.885 .695 .64 r
.66249 .5202 m .66397 .52355 L .66229 .52248 L F
.938 .82 .703 r
.66397 .52355 m .66147 .52514 L .66229 .52248 L F
.66397 .52355 m .66323 .52575 L .66147 .52514 L F
.787 .301 .063 r
.5509 .72957 m .55301 .73201 L .55363 .73098 L F
.738 .235 .033 r
.55363 .73098 m .55301 .73201 L .5549 .73224 L F
.27 .324 .735 r
.40741 .69208 m .40569 .69126 L .40482 .68773 L F
.33 .296 .669 r
.40768 .69331 m .40569 .69126 L .40741 .69208 L F
.478 .676 .952 r
.68151 .53675 m .68144 .53764 L .67929 .53537 L F
.71 .354 .371 r
.36732 .72671 m .36667 .72895 L .36685 .72708 L F
.36732 .72671 m .36964 .7279 L .36667 .72895 L F
.533 .516 .783 r
.38065 .69687 m .38179 .69332 L .37957 .69383 L F
.38065 .69687 m .38264 .69641 L .38179 .69332 L F
.597 .562 .786 r
.38065 .69687 m .38411 .69946 L .38264 .69641 L F
.139 0 .221 r
.62387 .57285 m .6216 .5758 L .62227 .57398 L F
.497 .316 .566 r
.3762 .66328 m .37811 .66519 L .37829 .66286 L F
.3762 .66328 m .37611 .66571 L .37811 .66519 L F
.324 0 .181 r
.32689 .62428 m .32402 .62632 L .32607 .62574 L F
.142 0 .079 r
.32867 .62345 m .32689 .62428 L .32607 .62574 L F
.623 .38 .529 r
.49648 .69322 m .49373 .69145 L .49489 .69071 L F
.49648 .69322 m .49299 .6941 L .49373 .69145 L F
.834 .979 .684 r
.59707 .7226 m .59748 .72113 L .5954 .72409 L F
0 0 0 r
.59748 .72113 m .59668 .72332 L .5954 .72409 L F
.408 .856 .905 r
.5954 .72409 m .59668 .72332 L .59441 .72386 L F
.793 .831 .881 r
.5914 .72448 m .5934 .7265 L .5954 .72409 L F
.5914 .72448 m .5954 .72409 L .59145 .72457 L F
.408 .856 .905 r
.5954 .72409 m .59441 .72386 L .59145 .72457 L F
.834 .979 .684 r
.59629 .72428 m .5954 .72409 L .59615 .72457 L F
.59707 .7226 m .5954 .72409 L .59629 .72428 L F
.616 .604 .816 r
.36479 .70578 m .36572 .70857 L .36787 .70794 L F
.576 .757 .964 r
.68171 .47811 m .68029 .48011 L .67918 .47867 L F
.68171 .47811 m .68235 .47962 L .68029 .48011 L F
.544 .849 .998 r
.25908 .65424 m .2606 .65494 L .25713 .6549 L F
.25713 .6549 m .2606 .65494 L .25908 .65424 L F
.456 .812 .997 r
.2606 .65494 m .26274 .65459 L .25908 .65424 L F
.25908 .65424 m .26274 .65459 L .2606 .65494 L F
.319 0 .105 r
.6351 .50752 m .63355 .50635 L .6359 .50598 L F
.6351 .50752 m .63268 .50815 L .63355 .50635 L F
.832 .713 .734 r
.56232 .76617 m .56109 .76727 L .55985 .76705 L F
.185 0 .071 r
.56232 .76617 m .56109 .76727 L .56159 .76707 L F
.734 .444 .488 r
.56159 .76707 m .56144 .76896 L .56232 .76617 L F
.381 .147 .43 r
.56144 .76896 m .56109 .76727 L .56159 .76707 L F
.734 .444 .488 r
.56073 .76811 m .56144 .76896 L .56159 .76707 L F
.215 0 .277 r
.56232 .76617 m .56144 .76896 L .56379 .76614 L F
.381 .147 .43 r
.56144 .76896 m .56159 .76707 L .56379 .76614 L F
.185 0 .071 r
.56232 .76617 m .56159 .76707 L .56379 .76614 L F
.804 .424 .336 r
.55985 .76705 m .56109 .76727 L .56144 .76896 L F
.734 .444 .488 r
.55985 .76705 m .56073 .76811 L .56232 .76617 L F
.832 .676 .689 r
.55918 .7856 m .5609 .78682 L .56138 .78335 L F
0 0 0 r
.54293 .77709 m .54445 .77621 L .54624 .77481 L F
.605 .912 .648 r
.54624 .77481 m .54445 .77621 L .54742 .77348 L F
.506 .24 .446 r
.33621 .61319 m .33784 .61476 L .33806 .61238 L F
.33621 .61319 m .33562 .61524 L .33784 .61476 L F
.12 0 0 r
.61907 .52111 m .61846 .52168 L .62081 .52101 L F
.968 .795 .616 r
.62994 .52645 m .62815 .52764 L .62792 .52543 L F
.62994 .52645 m .62941 .52864 L .62815 .52764 L F
.846 .662 .652 r
.36667 .72895 m .36964 .7279 L .37014 .72492 L F
.36667 .72895 m .37014 .72492 L .37 .72628 L F
.68 .156 0 r
.36807 .72461 m .37 .72628 L .37014 .72492 L F
.902 .981 .792 r
.57962 .55627 m .58242 .55399 L .58052 .55702 L F
.57962 .55627 m .58178 .55333 L .58242 .55399 L F
.919 .929 .8 r
.58178 .55333 m .58472 .5511 L .58242 .55399 L F
.112 0 0 r
.46283 .65789 m .46063 .65758 L .45897 .65734 L F
.761 .758 .85 r
.46345 .65428 m .46283 .65789 L .46474 .65496 L F
.46345 .65428 m .46063 .65758 L .46283 .65789 L F
.748 .445 .47 r
.48049 .68539 m .48222 .68794 L .48354 .6857 L F
0 0 0 r
.63694 .49587 m .63372 .4972 L .63457 .49518 L F
.63694 .49587 m .63587 .49659 L .63372 .4972 L F
.151 0 0 r
.63723 .49632 m .63694 .49587 L .63943 .49668 L F
.936 .94 .772 r
.63623 .49303 m .63592 .4961 L .63723 .49632 L F
.151 0 0 r
.63723 .49632 m .63587 .49659 L .63694 .49587 L F
.936 .94 .772 r
.63592 .4961 m .63587 .49659 L .63723 .49632 L F
.151 0 0 r
.63723 .49632 m .63943 .49668 L .6397 .49677 L F
.403 .396 .738 r
.74059 .59587 m .74133 .59936 L .74312 .59743 L F
.573 .661 .897 r
.74133 .59936 m .74356 .59896 L .74312 .59743 L F
.558 .533 .783 r
.74133 .59936 m .7448 .60114 L .74356 .59896 L F
.378 .362 .715 r
.46669 .78363 m .46773 .78009 L .46594 .78056 L F
.46669 .78363 m .46819 .78317 L .46773 .78009 L F
.332 .226 .58 r
.46669 .78363 m .46831 .78578 L .46819 .78317 L F
.173 .179 .625 r
.46669 .78363 m .46737 .78612 L .46831 .78578 L F
.465 .82 .997 r
.30657 .58783 m .30857 .58745 L .31006 .58809 L F
.199 .666 .94 r
.30857 .58745 m .31198 .58827 L .31006 .58809 L F
.406 .05 .244 r
.36852 .60886 m .36945 .60664 L .37144 .607 L F
.635 .802 .963 r
.31808 .60089 m .32166 .60133 L .32008 .60014 L F
.501 .813 1 r
.32166 .60133 m .3224 .59996 L .32008 .60014 L F
.32166 .60133 m .32466 .60089 L .3224 .59996 L F
.411 .119 .356 r
.38264 .70817 m .38459 .70827 L .38541 .70548 L F
.569 .732 .952 r
.3831 .70269 m .38541 .70548 L .38743 .70492 L F
.475 .177 .381 r
.38541 .70548 m .38696 .70747 L .38743 .70492 L F
.38541 .70548 m .38459 .70827 L .38696 .70747 L F
.339 .494 .866 r
.50584 .78774 m .50813 .78877 L .50782 .7864 L F
.818 .716 .753 r
.64084 .49272 m .6394 .49304 L .64135 .49185 L F
.609 .129 .09 r
.47901 .691 m .47755 .69125 L .47545 .69067 L F
.627 .157 .119 r
.48134 .69145 m .47755 .69125 L .47901 .691 L F
.861 .934 .871 r
.55377 .7476 m .55225 .75046 L .55422 .7474 L F
.55377 .7476 m .55058 .74939 L .55225 .75046 L F
.582 .52 .751 r
.55225 .75046 m .55548 .75174 L .55422 .7474 L F
.645 .519 .695 r
.55225 .75046 m .5557 .75257 L .55548 .75174 L F
.55225 .75046 m .55332 .7531 L .5557 .75257 L F
.975 .67 .34 r
.55058 .74939 m .55203 .7522 L .55225 .75046 L F
.108 0 .234 r
.37685 .70939 m .37484 .71089 L .37695 .7091 L F
.023 .005 .494 r
.50889 .69691 m .51024 .69592 L .50988 .69329 L F
.98 .73 .48 r
.50858 .69731 m .50889 .69939 L .50761 .69853 L F
.50889 .69691 m .50889 .6973 L .50858 .69731 L F
.50889 .6973 m .50889 .69939 L .50858 .69731 L F
.237 0 0 r
.50511 .69693 m .50791 .69732 L .50605 .69696 L F
.50791 .69732 m .50896 .69747 L .50809 .69732 L F
.50791 .69732 m .50809 .69732 L .50605 .69696 L F
.50511 .69693 m .50861 .69742 L .50605 .69696 L F
.50861 .69742 m .50896 .69747 L .50861 .6974 L F
.50861 .69742 m .50861 .6974 L .50605 .69696 L F
.98 .73 .48 r
.50889 .69691 m .50858 .69731 L .51024 .69592 L F
.50858 .69731 m .50761 .69853 L .50864 .69751 L F
.50858 .69731 m .50864 .69751 L .51024 .69592 L F
.8 .486 .457 r
.54858 .78066 m .54669 .78281 L .5467 .78119 L F
.54858 .78066 m .55077 .78393 L .54669 .78281 L F
.929 .883 .466 r
.5978 .70738 m .5973 .71032 L .59723 .70788 L F
.348 .804 .941 r
.29901 .63399 m .30125 .63361 L .30283 .63392 L F
.199 .725 .835 r
.30125 .63361 m .30509 .63343 L .30283 .63392 L F
.111 .012 .451 r
.72285 .50606 m .72368 .50611 L .72367 .50316 L F
.422 .76 .996 r
.35061 .59252 m .34911 .59352 L .34779 .5924 L F
.35061 .59252 m .35111 .59327 L .34911 .59352 L F
.977 .713 .307 r
.7067 .50859 m .70597 .50825 L .70569 .50578 L F
.987 .76 .368 r
.70584 .50558 m .70597 .50825 L .7067 .50859 L F
.723 .989 .834 r
.75763 .5862 m .75648 .58796 L .75787 .58658 L F
.264 .195 .588 r
.46742 .77516 m .46888 .77159 L .4669 .77322 L F
.737 .537 .623 r
.51717 .78092 m .51228 .78324 L .5124 .78095 L F
.244 0 .047 r
.25221 .59259 m .25401 .59237 L .25523 .59066 L F
.229 0 0 r
.25401 .59237 m .25742 .59034 L .25523 .59066 L F
.483 .802 1 r
.2957 .64833 m .29723 .64918 L .29779 .64797 L F
.387 .695 .981 r
.29723 .64918 m .29927 .64926 L .29779 .64797 L F
.933 .679 .53 r
.37229 .70465 m .37418 .70653 L .37428 .70558 L F
.509 .285 .51 r
.37418 .70653 m .37566 .70741 L .37428 .70558 L F
.597 .874 .993 r
.46558 .65352 m .46474 .65496 L .46699 .65436 L F
.594 .87 .993 r
.46558 .65352 m .46345 .65428 L .46474 .65496 L F
.61 .472 .669 r
.61799 .55443 m .62019 .55381 L .61993 .5509 L F
.549 .432 .672 r
.61799 .55443 m .62018 .55595 L .62019 .55381 L F
.61799 .55443 m .6181 .55662 L .62018 .55595 L F
0 0 0 r
.49021 .75185 m .4892 .75299 L .49131 .75009 L F
.419 .262 .56 r
.38342 .65497 m .38318 .65727 L .38517 .65653 L F
.909 .755 .679 r
.64294 .52324 m .64281 .52549 L .64029 .52487 L F
.899 .785 .727 r
.64281 .52549 m .64083 .52847 L .64029 .52487 L F
0 0 0 r
.49383 .74798 m .49246 .74914 L .49131 .75009 L F
.49199 .74908 m .49246 .74914 L .49383 .74798 L F
.521 .539 .815 r
.27965 .62813 m .27844 .63033 L .27699 .62669 L F
.535 .557 .824 r
.27965 .62813 m .28107 .63101 L .27844 .63033 L F
.538 .581 .846 r
.61574 .54565 m .61227 .54305 L .61509 .54321 L F
.593 .606 .834 r
.61655 .54217 m .61574 .54565 L .61509 .54321 L F
0 .119 .665 r
.64994 .48871 m .65145 .49211 L .65069 .49097 L F
.303 0 0 r
.4148 .70976 m .41155 .7108 L .41265 .70994 L F
.768 .327 .203 r
.58546 .72494 m .58406 .72625 L .58364 .72337 L F
.58546 .72494 m .58731 .72716 L .58406 .72625 L F
.019 0 .35 r
.46835 .78955 m .46545 .79206 L .46642 .79189 L F
0 .134 .654 r
.46737 .78612 m .46835 .78955 L .46911 .78842 L F
.613 .861 .506 r
.46911 .78842 m .46835 .78955 L .46642 .79189 L F
.609 .783 .964 r
.29901 .63399 m .29687 .63467 L .29578 .63364 L F
.872 .796 .773 r
.5934 .7265 m .59615 .72457 L .5954 .72409 L F
.5934 .7265 m .5942 .72759 L .59615 .72457 L F
.644 .282 0 r
.66841 .49389 m .66906 .49528 L .66753 .49199 L F
0 0 .517 r
.66991 .49607 m .66906 .49528 L .66841 .49389 L F
.66991 .49607 m .67047 .49688 L .66906 .49528 L F
0 0 .49 r
.50369 .77214 m .50408 .77447 L .5031 .77191 L F
0 .051 .613 r
.5031 .77191 m .50369 .77214 L .50228 .76987 L F
0 0 .49 r
.50369 .77214 m .50408 .77447 L .5031 .77191 L F
.706 .307 .288 r
.56043 .77245 m .56247 .77439 L .56104 .77446 L F
.56247 .77439 m .56266 .77456 L .5621 .77453 L F
.56247 .77439 m .5621 .77453 L .56104 .77446 L F
.775 .663 .74 r
.55925 .77434 m .56266 .77456 L .56125 .77493 L F
.2 .342 .783 r
.56115 .77455 m .56143 .77479 L .56318 .77339 L F
.852 .396 .027 r
.56143 .77479 m .56176 .77393 L .56318 .77339 L F
.2 .342 .783 r
.56115 .77455 m .56125 .77493 L .56143 .77479 L F
.852 .396 .027 r
.56125 .77493 m .5613 .77484 L .56143 .77479 L F
.5613 .77484 m .56176 .77393 L .56143 .77479 L F
.2 .342 .783 r
.56011 .77074 m .56115 .77455 L .56318 .77339 L F
.706 .307 .288 r
.55983 .77342 m .56104 .77446 L .55925 .77434 L F
.56043 .77245 m .56104 .77446 L .55983 .77342 L F
.884 .886 .829 r
.57613 .56271 m .57287 .56463 L .5751 .56183 L F
.57613 .56271 m .57389 .56539 L .57287 .56463 L F
.904 .922 .82 r
.57613 .56271 m .5772 .55905 L .57839 .56003 L F
.57613 .56271 m .5751 .56183 L .5772 .55905 L F
.429 .667 .961 r
.54072 .75639 m .53982 .75779 L .5383 .75694 L F
.54072 .75639 m .54183 .75776 L .53982 .75779 L F
.847 .653 .639 r
.64207 .52031 m .64021 .5225 L .63964 .52018 L F
.64207 .52031 m .64294 .52324 L .64021 .5225 L F
.909 .755 .679 r
.64294 .52324 m .64029 .52487 L .64021 .5225 L F
.792 .805 .863 r
.75297 .58514 m .75024 .58629 L .75234 .58465 L F
.825 .949 .901 r
.75567 .5828 m .75297 .58514 L .75256 .58256 L F
.941 .963 .705 r
.75256 .58256 m .75297 .58514 L .75234 .58465 L F
.878 .982 .832 r
.7061 .5244 m .70569 .5266 L .70786 .52411 L F
.903 .979 .7 r
.7042 .52761 m .70569 .5266 L .7061 .5244 L F
.099 0 0 r
.51647 .81455 m .5166 .81398 L .51755 .81387 L F
.361 0 .149 r
.44482 .68838 m .4471 .68793 L .44803 .68593 L F
.261 0 .104 r
.44803 .68593 m .44915 .68726 L .44962 .68657 L F
.44803 .68593 m .4471 .68793 L .44915 .68726 L F
.367 0 0 r
.44803 .68593 m .44962 .68657 L .45029 .68595 L F
.801 .422 .338 r
.51919 .77452 m .52276 .7767 L .52086 .77478 L F
.687 .88 .97 r
.32973 .60289 m .33047 .60396 L .3335 .6025 L F
.427 .116 .333 r
.33038 .64091 m .32963 .64273 L .32761 .64324 L F
.263 0 .207 r
.33235 .64025 m .32963 .64273 L .33038 .64091 L F
.62 .785 .961 r
.6687 .53666 m .66888 .53806 L .67034 .5381 L F
.461 .026 .125 r
.40142 .65406 m .40515 .65227 L .40286 .65247 L F
.521 .748 .979 r
.76267 .60625 m .76012 .60545 L .76247 .60461 L F
.569 .586 .831 r
.76477 .60369 m .76267 .60625 L .76247 .60461 L F
.76477 .60369 m .76412 .60545 L .76267 .60625 L F
.559 .302 .483 r
.6285 .48345 m .63074 .48322 L .6309 .4812 L F
.416 .184 .452 r
.6309 .4812 m .6329 .48229 L .6332 .48065 L F
.6309 .4812 m .63074 .48322 L .6329 .48229 L F
.697 .209 .083 r
.63507 .51886 m .63595 .51787 L .63475 .51755 L F
0 .06 .596 r
.63595 .51787 m .63695 .51853 L .63834 .51695 L F
.763 .302 0 r
.67616 .51618 m .677 .51675 L .67607 .51501 L F
.78 .286 0 r
.67821 .51752 m .67607 .51501 L .677 .51675 L F
.593 .949 .884 r
.66783 .48229 m .66647 .48359 L .66885 .48334 L F
.66783 .48229 m .66571 .48353 L .66647 .48359 L F
0 0 0 r
.77061 .60594 m .77061 .60586 L .76829 .60717 L F
.77061 .60594 m .76829 .60717 L .76806 .60396 L F
.346 0 0 r
.77061 .606 m .77061 .60594 L .76949 .60546 L F
.77419 .60771 m .77061 .60594 L .77061 .606 L F
0 0 0 r
.77061 .60594 m .77111 .60558 L .77061 .60586 L F
.922 .713 .221 r
.77061 .60594 m .77111 .60558 L .77058 .60345 L F
.774 .994 .875 r
.7061 .5244 m .70786 .52411 L .70943 .52255 L F
.896 .885 .814 r
.58052 .55702 m .5772 .55905 L .57962 .55627 L F
.58052 .55702 m .57839 .56003 L .5772 .55905 L F
.432 .598 .914 r
.41362 .69503 m .41264 .69641 L .41128 .69532 L F
.41362 .69503 m .41467 .69668 L .41264 .69641 L F
.288 .451 .849 r
.76712 .57437 m .76589 .57556 L .76417 .57382 L F
.76712 .57437 m .76765 .57636 L .76589 .57556 L F
.697 .796 .927 r
.47989 .64183 m .47585 .64227 L .47834 .64072 L F
.794 .822 .873 r
.48152 .64048 m .47989 .64183 L .47834 .64072 L F
0 .054 .6 r
.55865 .71295 m .56027 .71563 L .55955 .71698 L F
.258 .543 .924 r
.56027 .71563 m .56221 .71728 L .55955 .71698 L F
.661 .308 .365 r
.51529 .76652 m .51394 .76891 L .51203 .76682 L F
.738 .543 .63 r
.51811 .76646 m .51394 .76891 L .51529 .76652 L F
.692 .29 .281 r
.48134 .69145 m .47997 .69333 L .47755 .69125 L F
.488 .059 .15 r
.48349 .6927 m .48134 .69145 L .4838 .69156 L F
.48349 .6927 m .47997 .69333 L .48134 .69145 L F
.498 .236 .447 r
.58567 .71649 m .58786 .7157 L .58815 .71336 L F
0 0 0 r
.58815 .71336 m .58965 .71247 L .59057 .7108 L F
.316 .201 .56 r
.58786 .7157 m .58965 .71247 L .58815 .71336 L F
.543 .446 .694 r
.24623 .62968 m .24819 .62651 L .24552 .62682 L F
.24623 .62968 m .24822 .6293 L .24819 .62651 L F
.531 .397 .643 r
.2464 .63196 m .24822 .6293 L .24623 .62968 L F
0 0 .136 r
.49246 .74914 m .49021 .75185 L .49131 .75009 L F
.657 .725 .899 r
.70824 .50284 m .71134 .50343 L .71069 .5018 L F
.958 .637 .234 r
.7108 .50421 m .71134 .50343 L .70824 .50284 L F
.7108 .50421 m .71183 .50592 L .71134 .50343 L F
.34 0 .057 r
.48424 .75193 m .48692 .74976 L .4861 .75072 L F
.542 .086 .12 r
.50039 .75742 m .50407 .75607 L .50062 .75571 L F
.50039 .75742 m .50279 .75765 L .50407 .75607 L F
.446 0 .06 r
.50407 .75607 m .50279 .75765 L .5064 .75681 L F
.531 .473 .736 r
.55679 .70291 m .55806 .70384 L .55904 .7022 L F
.453 .347 .643 r
.46545 .79206 m .46759 .7943 L .46642 .79189 L F
.742 .819 .911 r
.76047 .61012 m .76157 .61218 L .76341 .60998 L F
.427 .01 .143 r
.62028 .52626 m .6196 .52809 L .61678 .52831 L F
.123 0 .033 r
.62152 .52709 m .62028 .52626 L .62275 .5258 L F
.62152 .52709 m .6196 .52809 L .62028 .52626 L F
.874 .992 .811 r
.63507 .51886 m .63259 .52185 L .63439 .5212 L F
.634 .127 0 r
.47357 .80317 m .47453 .80464 L .47231 .80254 L F
.47357 .80317 m .47575 .80571 L .47453 .80464 L F
.109 0 0 r
.47346 .68329 m .47556 .68321 L .47656 .6829 L F
.659 .106 0 r
.47795 .6848 m .47656 .6829 L .47556 .68321 L F
.47795 .6848 m .47851 .68457 L .47656 .6829 L F
.736 .912 .954 r
.6871 .53988 m .6897 .53959 L .68903 .53869 L F
.709 .965 .939 r
.6897 .53959 m .6911 .53752 L .68903 .53869 L F
.6897 .53959 m .69289 .53777 L .6911 .53752 L F
.609 .73 .931 r
.70873 .5122 m .70972 .51391 L .70743 .5146 L F
0 0 0 r
.70978 .51403 m .70803 .51435 L .70743 .5146 L F
.609 .73 .931 r
.70972 .51391 m .70978 .51403 L .70743 .5146 L F
.621 .953 .924 r
.70803 .51435 m .70557 .51516 L .70743 .5146 L F
.70557 .51516 m .70337 .51588 L .70743 .5146 L F
.723 .774 .893 r
.28982 .64856 m .29201 .65022 L .29359 .64885 L F
.584 .293 .44 r
.61497 .58163 m .61421 .5842 L .61178 .58435 L F
.609 .318 .449 r
.61701 .58368 m .61497 .58163 L .61733 .58153 L F
.61701 .58368 m .61421 .5842 L .61497 .58163 L F
.749 .612 .707 r
.47205 .65988 m .47437 .6611 L .47396 .65762 L F
.467 .406 .705 r
.47396 .65762 m .47437 .6611 L .47636 .65946 L F
.812 .768 .812 r
.61183 .53336 m .61334 .53447 L .61583 .5318 L F
.709 .839 .945 r
.63915 .47997 m .6371 .48139 L .63555 .4802 L F
.606 .255 .349 r
.6371 .48139 m .63908 .48297 L .63675 .48318 L F
.402 .772 .993 r
.29739 .58578 m .29957 .58553 L .30129 .58641 L F
.216 0 0 r
.29957 .58553 m .30304 .58653 L .30129 .58641 L F
.919 .929 .8 r
.58178 .55333 m .58378 .55037 L .58472 .5511 L F
.901 .935 .826 r
.58472 .5511 m .58378 .55037 L .58598 .54744 L F
.545 .383 .613 r
.54681 .71066 m .54932 .71287 L .54907 .71021 L F
.893 .864 .42 r
.57116 .76553 m .57214 .76369 L .5712 .76326 L F
.57116 .76553 m .57124 .76694 L .57214 .76369 L F
.777 .377 .295 r
.52954 .78041 m .53285 .78138 L .53164 .78284 L F
.722 .304 .254 r
.53285 .78138 m .53527 .78348 L .53164 .78284 L F
.605 .813 .407 r
.62582 .56973 m .62488 .57116 L .62678 .5683 L F
0 0 0 r
.62582 .56973 m .62387 .57285 L .62488 .57116 L F
.658 .201 .155 r
.4869 .6917 m .48561 .69306 L .4838 .69156 L F
.633 .17 .136 r
.48921 .69328 m .48561 .69306 L .4869 .6917 L F
.994 .788 .418 r
.66099 .50652 m .66012 .50803 L .66001 .50414 L F
.66099 .50652 m .66082 .50891 L .66012 .50803 L F
.484 .196 .4 r
.62305 .48663 m .62542 .48618 L .62562 .48438 L F
.402 .129 .381 r
.62562 .48438 m .62762 .48536 L .6285 .48345 L F
.62562 .48438 m .62542 .48618 L .62762 .48536 L F
.529 .594 .863 r
.54238 .80013 m .54015 .80023 L .53843 .7973 L F
.285 .783 .863 r
.45286 .64499 m .45496 .64458 L .45669 .64462 L F
.54 .918 .933 r
.45669 .64462 m .45769 .64355 L .45873 .64403 L F
.45669 .64462 m .45496 .64458 L .45769 .64355 L F
.746 .499 .558 r
.63348 .53423 m .63421 .53703 L .63067 .53638 L F
.595 .468 .677 r
.63576 .53157 m .63348 .53423 L .63281 .53138 L F
.63576 .53157 m .63644 .53411 L .63348 .53423 L F
.695 .469 .576 r
.63566 .53629 m .63348 .53423 L .63644 .53411 L F
.63566 .53629 m .63421 .53703 L .63348 .53423 L F
.357 .128 .424 r
.49571 .75987 m .49839 .75854 L .49826 .7557 L F
.547 .267 .443 r
.49826 .7557 m .49839 .75854 L .50039 .75742 L F
.594 .246 .349 r
.49826 .7557 m .50039 .75742 L .50062 .75571 L F
.557 .478 .721 r
.40288 .68258 m .4007 .68305 L .40011 .67949 L F
.817 .608 .62 r
.63555 .54009 m .63542 .54264 L .63345 .53923 L F
.643 .139 .035 r
.55528 .70851 m .55718 .70999 L .55338 .7094 L F
.416 .278 .584 r
.55729 .70753 m .55718 .70999 L .55528 .70851 L F
.775 .471 .472 r
.64501 .53346 m .64771 .53166 L .64635 .53067 L F
.843 .759 .77 r
.64775 .53626 m .6513 .5345 L .65064 .53398 L F
.64897 .53404 m .65064 .53398 L .6495 .53308 L F
.64775 .53626 m .65064 .53398 L .64897 .53404 L F
.775 .471 .472 r
.64501 .53346 m .64737 .53409 L .64771 .53166 L F
.64737 .53409 m .6488 .53447 L .64863 .53405 L F
.64737 .53409 m .64863 .53405 L .64771 .53166 L F
.67 .669 .84 r
.64771 .53166 m .64893 .52786 L .64635 .53067 L F
.64771 .53166 m .64951 .53165 L .64893 .52786 L F
.648 .41 .544 r
.64771 .53166 m .6488 .53447 L .6495 .53308 L F
.877 .587 .493 r
.6495 .53308 m .64951 .53165 L .64771 .53166 L F
.387 .071 .302 r
.62605 .52269 m .62479 .52519 L .62275 .5258 L F
.769 .488 .509 r
.62792 .52543 m .62605 .52269 L .62801 .52309 L F
.62792 .52543 m .62479 .52519 L .62605 .52269 L F
.649 .799 .955 r
.61355 .54128 m .61227 .54305 L .61117 .54161 L F
.591 .829 .45 r
.61227 .54305 m .61137 .54418 L .61355 .54128 L F
.583 .374 .563 r
.61137 .54418 m .61355 .54128 L .61227 .54305 L F
.689 .741 .891 r
.61137 .54418 m .61059 .54751 L .61247 .54729 L F
.854 .754 .752 r
.6712 .53369 m .6687 .53666 L .6718 .53642 L F
.731 .681 .802 r
.6712 .53369 m .6718 .53642 L .67412 .53404 L F
.507 .559 .844 r
.74531 .60398 m .74621 .60064 L .7448 .60114 L F
.74531 .60398 m .74749 .60376 L .74621 .60064 L F
.87 .74 .716 r
.60105 .55936 m .59982 .55613 L .59818 .55927 L F
.871 .736 .711 r
.59899 .56223 m .60105 .55936 L .59818 .55927 L F
.772 .583 .643 r
.60137 .56204 m .60105 .55936 L .59899 .56223 L F
.837 .728 .743 r
.60105 .55936 m .60131 .55713 L .59982 .55613 L F
.274 0 .053 r
.4533 .65562 m .45245 .65702 L .45018 .65757 L F
0 0 0 r
.45398 .65603 m .4533 .65562 L .45552 .65459 L F
.45398 .65603 m .45245 .65702 L .4533 .65562 L F
.462 .406 .709 r
.46885 .66398 m .47038 .66174 L .46893 .66187 L F
.46885 .66398 m .47039 .66372 L .47038 .66174 L F
.354 .718 .986 r
.28642 .58387 m .28598 .58493 L .28444 .58404 L F
.28642 .58387 m .28795 .58488 L .28598 .58493 L F
.413 .193 .468 r
.33774 .63537 m .3372 .63787 L .33556 .63799 L F
.267 0 .074 r
.33642 .6391 m .33556 .63799 L .3372 .63787 L F
.33642 .6391 m .33439 .63968 L .33556 .63799 L F
.424 .816 .987 r
.45873 .64403 m .461 .64367 L .46235 .64422 L F
.503 .852 .994 r
.46235 .64422 m .46324 .64313 L .46452 .64349 L F
.46235 .64422 m .461 .64367 L .46324 .64313 L F
.299 0 .233 r
.53842 .73025 m .5414 .72743 L .53892 .72747 L F
.962 .833 .669 r
.57287 .56463 m .57389 .56539 L .57336 .56766 L F
.602 .54 .758 r
.48762 .66621 m .48906 .66255 L .48661 .66306 L F
.48762 .66621 m .49001 .66609 L .48906 .66255 L F
.889 .76 .713 r
.65663 .50854 m .65531 .5112 L .65771 .51181 L F
.857 .994 .753 r
.65511 .51407 m .65771 .51181 L .65531 .5112 L F
.65511 .51407 m .65551 .51459 L .65771 .51181 L F
.483 .319 .582 r
.40385 .67645 m .40183 .67445 L .40422 .67418 L F
.40385 .67645 m .40181 .67691 L .40183 .67445 L F
.615 .373 .526 r
.59001 .58759 m .59024 .58975 L .58776 .5895 L F
.7 .465 .565 r
.59233 .58755 m .59024 .58975 L .59001 .58759 L F
.648 .832 .971 r
.68571 .47969 m .68235 .47962 L .68492 .47846 L F
.516 .681 .94 r
.68713 .47781 m .68571 .47969 L .68492 .47846 L F
.68713 .47781 m .68865 .47988 L .68571 .47969 L F
.299 .728 .97 r
.6723 .4779 m .67101 .47868 L .66986 .47838 L F
.6723 .4779 m .67344 .47867 L .67101 .47868 L F
.396 .406 .753 r
.37356 .60311 m .37198 .6041 L .37111 .60142 L F
.142 0 .328 r
.37144 .607 m .37198 .6041 L .37356 .60311 L F
.668 .973 .891 r
.55463 .79094 m .55743 .78884 L .55439 .79235 L F
.498 .824 1 r
.47396 .65762 m .47379 .65681 L .47103 .65767 L F
.708 .55 .672 r
.47103 .65767 m .47205 .65988 L .47396 .65762 L F
.023 .329 .813 r
.47396 .65762 m .47502 .65716 L .47379 .65681 L F
.47396 .65762 m .47636 .65946 L .47502 .65716 L F
.46 .356 .65 r
.50369 .77214 m .50777 .77281 L .50568 .77228 L F
.50369 .77214 m .50518 .77282 L .50777 .77281 L F
.614 .122 .06 r
.50518 .77282 m .50951 .77374 L .50777 .77281 L F
.401 0 .049 r
.50777 .77281 m .50951 .77374 L .51026 .77263 L F
.753 .704 .805 r
.54712 .75551 m .55226 .75456 L .54978 .75748 L F
.918 .974 .694 r
.55133 .75478 m .55226 .75456 L .55262 .75377 L F
.55133 .75478 m .54978 .75748 L .55226 .75456 L F
.208 0 .019 r
.55138 .75868 m .55262 .75377 L .55226 .75456 L F
.69 .541 .678 r
.48802 .76134 m .4902 .76131 L .49026 .75834 L F
.645 .503 .675 r
.49026 .75834 m .49253 .76063 L .49244 .75825 L F
.49026 .75834 m .4902 .76131 L .49253 .76063 L F
.78 .937 .583 r
.60892 .5124 m .60681 .51569 L .60779 .51353 L F
0 0 .223 r
.60598 .51704 m .60779 .51353 L .60681 .51569 L F
.224 0 .149 r
.29083 .60698 m .28978 .60908 L .2879 .60957 L F
.343 0 .174 r
.2929 .60663 m .28978 .60908 L .29083 .60698 L F
.245 0 .167 r
.71528 .49279 m .71247 .49511 L .71471 .4943 L F
.562 .443 .675 r
.71471 .4943 m .7164 .49153 L .71528 .49279 L F
.503 .495 .781 r
.71422 .49034 m .71528 .49279 L .7164 .49153 L F
.593 .606 .834 r
.61655 .54217 m .61806 .54514 L .61574 .54565 L F
.683 .616 .774 r
.61806 .54514 m .61567 .54809 L .61574 .54565 L F
.241 0 0 r
.61712 .54629 m .61574 .54565 L .61806 .54514 L F
.61712 .54629 m .61471 .54683 L .61574 .54565 L F
.61712 .54629 m .61574 .54565 L .61806 .54514 L F
.61712 .54629 m .61471 .54683 L .61574 .54565 L F
.428 .481 .813 r
.37672 .68243 m .37796 .68563 L .37962 .68533 L F
.551 .513 .767 r
.37846 .6881 m .37962 .68533 L .37796 .68563 L F
.161 0 .228 r
.38163 .70242 m .3831 .70269 L .38411 .69946 L F
0 .41 .689 r
.30293 .64911 m .30155 .64871 L .30149 .64922 L F
.30293 .64911 m .30505 .64968 L .30155 .64871 L F
.812 .768 .812 r
.61183 .53336 m .61583 .5318 L .61474 .53111 L F
.449 .053 .195 r
.61861 .52898 m .61758 .52973 L .61651 .52946 L F
.112 .213 .691 r
.61651 .52946 m .61583 .5318 L .61503 .5291 L F
.799 .943 .92 r
.61651 .52946 m .61474 .53111 L .61583 .5318 L F
.449 .053 .195 r
.61758 .52973 m .61563 .53115 L .61651 .52946 L F
.112 .213 .691 r
.61651 .52946 m .61503 .5291 L .61491 .52869 L F
.528 .788 .992 r
.28832 .63186 m .28783 .63337 L .28621 .63227 L F
.28832 .63186 m .28999 .63291 L .28783 .63337 L F
.646 .603 .792 r
.46699 .65436 m .47103 .65767 L .46944 .65391 L F
.529 .631 .896 r
.47103 .65767 m .47123 .654 L .46944 .65391 L F
.47103 .65767 m .47379 .65681 L .47123 .654 L F
.74 .318 .247 r
.50207 .78642 m .50073 .78806 L .50053 .78597 L F
.50207 .78642 m .50432 .7887 L .50073 .78806 L F
.501 .775 .993 r
.50116 .76855 m .50062 .76932 L .4984 .76962 L F
.607 .571 .788 r
.24552 .62682 m .24681 .62389 L .2452 .626 L F
.24552 .62682 m .24819 .62651 L .24681 .62389 L F
.779 .62 .683 r
.56908 .57346 m .57099 .57671 L .56854 .57591 L F
.778 .594 .65 r
.57099 .57671 m .57057 .57904 L .56854 .57591 L F
.557 .478 .721 r
.40288 .68258 m .40011 .67949 L .40208 .67907 L F
.568 .54 .784 r
.24881 .63522 m .2488 .63187 L .24654 .63231 L F
.24881 .63522 m .24984 .63499 L .2488 .63187 L F
.211 0 0 r
.24608 .637 m .24984 .63499 L .24881 .63522 L F
.766 .338 0 r
.51313 .78971 m .51323 .7897 L .51208 .78871 L F
.129 .323 .79 r
.51314 .78881 m .51313 .78971 L .51208 .78871 L F
.711 .19 0 r
.51291 .78972 m .51313 .78971 L .51314 .78881 L F
.5128 .79019 m .51313 .78971 L .51291 .78972 L F
.766 .338 0 r
.51313 .78971 m .51338 .78983 L .51323 .7897 L F
.51313 .78971 m .51457 .79189 L .51338 .78983 L F
.919 .572 .119 r
.66323 .52575 m .66288 .52687 L .66147 .52514 L F
.66323 .52575 m .66379 .52811 L .66288 .52687 L F
.414 .313 .631 r
.63426 .48625 m .63272 .48905 L .63203 .48691 L F
.85 .788 .79 r
.63328 .52677 m .6344 .52726 L .63217 .52364 L F
.279 0 .199 r
.61587 .55844 m .61753 .55871 L .6181 .55662 L F
.123 0 .03 r
.61753 .55871 m .62018 .55595 L .6181 .55662 L F
.73 .337 .307 r
.53849 .78132 m .54055 .78331 L .53878 .78296 L F
.612 .066 0 r
.53849 .78132 m .54243 .78271 L .54055 .78331 L F
.376 .73 .99 r
.75198 .61009 m .75533 .61097 L .75423 .61027 L F
.438 .776 .997 r
.75533 .61097 m .75631 .60981 L .75423 .61027 L F
.75533 .61097 m .75777 .6107 L .75631 .60981 L F
.302 0 0 r
.4233 .70614 m .42187 .70762 L .42019 .70727 L F
.218 0 0 r
.42464 .70655 m .4233 .70614 L .42539 .70569 L F
.42464 .70655 m .42187 .70762 L .4233 .70614 L F
.001 0 .155 r
.49021 .75185 m .48991 .75422 L .48841 .75415 L F
.001 0 .151 r
.48991 .75422 m .48826 .75525 L .48841 .75415 L F
.285 .727 .963 r
.34206 .59162 m .33979 .59168 L .33874 .59105 L F
.625 .892 .988 r
.50458 .62592 m .50219 .62681 L .50305 .6254 L F
.50305 .6254 m .50219 .62681 L .50458 .62592 L F
.50458 .62592 m .50219 .62681 L .50305 .6254 L F
.759 .532 .588 r
.37963 .70533 m .37566 .70741 L .37804 .70428 L F
.37963 .70533 m .37906 .70763 L .37566 .70741 L F
.702 .71 .183 r
.37934 .70642 m .37963 .70533 L .37804 .70428 L F
.37934 .70642 m .37906 .70763 L .37963 .70533 L F
.516 .402 .662 r
.61993 .5509 m .6216 .5523 L .62233 .55021 L F
.61993 .5509 m .62019 .55381 L .6216 .5523 L F
.004 .537 .846 r
.27079 .64916 m .26983 .64862 L .26773 .64819 L F
.797 .967 .913 r
.26983 .64862 m .26853 .64958 L .27079 .64916 L F
.762 .962 .933 r
.27153 .64731 m .27079 .64916 L .27297 .64855 L F
.27153 .64731 m .26983 .64862 L .27079 .64916 L F
.797 .967 .913 r
.26983 .64862 m .26853 .64958 L .27079 .64916 L F
.192 .481 .896 r
.27079 .64916 m .27423 .65175 L .27297 .64855 L F
.327 .691 .98 r
.32466 .60089 m .32737 .6019 L .32587 .60087 L F
0 .367 .756 r
.32737 .6019 m .32843 .60208 L .32587 .60087 L F
.32737 .6019 m .32973 .60289 L .32843 .60208 L F
.27 0 0 r
.41194 .66843 m .4106 .67029 L .40844 .67075 L F
.475 .032 .115 r
.41291 .67005 m .41194 .66843 L .4145 .66763 L F
.41291 .67005 m .4106 .67029 L .41194 .66843 L F
.579 .099 .08 r
.4698 .69087 m .46963 .69236 L .46638 .69085 L F
.575 .149 .195 r
.47206 .6908 m .46963 .69236 L .4698 .69087 L F
.752 .532 .598 r
.53026 .74664 m .53413 .74748 L .53309 .74387 L F
.485 .374 .653 r
.53309 .74387 m .53585 .74639 L .53578 .74392 L F
.53309 .74387 m .53413 .74748 L .53585 .74639 L F
.113 0 .324 r
.62802 .56675 m .62678 .5683 L .62843 .56507 L F
0 0 0 r
.62737 .56816 m .62678 .5683 L .62802 .56675 L F
.62737 .56816 m .62582 .56973 L .62678 .5683 L F
.923 .944 .596 r
.7193 .51271 m .72069 .51031 L .72055 .50868 L F
.538 .062 0 r
.72069 .51031 m .72127 .511 L .72055 .50868 L F
.72069 .51031 m .72231 .5122 L .72127 .511 L F
.543 .439 .686 r
.37364 .67951 m .37577 .6792 L .37544 .67682 L F
.457 .486 .801 r
.37364 .67951 m .37672 .68243 L .37577 .6792 L F
.649 .14 .02 r
.53253 .76799 m .52886 .76689 L .53006 .76792 L F
.397 .172 .452 r
.3497 .62646 m .35007 .62416 L .35195 .62354 L F
.606 .37 .533 r
.62472 .51999 m .62732 .52012 L .62769 .51771 L F
0 0 .243 r
.62769 .51771 m .62833 .51825 L .62919 .51687 L F
.62769 .51771 m .62732 .52012 L .62833 .51825 L F
0 .495 .767 r
.34415 .5915 m .34779 .5924 L .34588 .59203 L F
.625 .741 .931 r
.29367 .63423 m .28999 .63291 L .29204 .63214 L F
.576 .713 .936 r
.29578 .63364 m .29367 .63423 L .29204 .63214 L F
.399 .654 .961 r
.35722 .59471 m .35906 .59473 L .35834 .59612 L F
.467 .736 .986 r
.35906 .59473 m .36032 .59587 L .35834 .59612 L F
.708 .718 .857 r
.70584 .50558 m .70841 .50778 L .71183 .50592 L F
0 0 0 r
.72366 .51834 m .72233 .51864 L .7199 .519 L F
.72593 .51758 m .72233 .51864 L .72366 .51834 L F
.048 .564 .874 r
.63915 .47997 m .64117 .48036 L .6425 .48107 L F
.116 .471 .894 r
.64335 .48034 m .6425 .48107 L .64117 .48036 L F
.64335 .48034 m .6438 .48139 L .6425 .48107 L F
.519 .508 .783 r
.47629 .66911 m .4801 .66922 L .4775 .66693 L F
.638 .712 .901 r
.76584 .60947 m .76717 .61233 L .7687 .60979 L F
.584 .584 .819 r
.76717 .61233 m .76974 .61157 L .7687 .60979 L F
.159 .698 .744 r
.71139 .48971 m .71043 .48978 L .70792 .49021 L F
.102 0 0 r
.71421 .48972 m .71043 .48978 L .71139 .48971 L F
.4 .773 .993 r
.32354 .58977 m .32715 .59035 L .32504 .59048 L F
.841 .671 .671 r
.65551 .51459 m .65191 .51454 L .6523 .51216 L F
.758 .365 .308 r
.65551 .51459 m .65401 .51573 L .65191 .51454 L F
.889 .583 .461 r
.65401 .51573 m .65551 .51459 L .65311 .51728 L F
.65401 .51573 m .65565 .51699 L .65551 .51459 L F
.876 .988 .721 r
.65511 .51407 m .65401 .51573 L .65551 .51459 L F
.889 .583 .461 r
.65401 .51573 m .65565 .51699 L .65551 .51459 L F
.842 .654 .647 r
.54832 .7631 m .5501 .76425 L .54919 .76116 L F
.864 .675 .645 r
.54832 .7631 m .55006 .76667 L .5501 .76425 L F
.694 .573 .714 r
.54919 .76116 m .5501 .76425 L .55254 .76395 L F
.58 .389 .587 r
.55006 .76667 m .55254 .76395 L .5501 .76425 L F
.683 .462 .58 r
.62745 .53468 m .62649 .53416 L .62755 .53437 L F
.641 .825 .408 r
.62791 .53182 m .62649 .53416 L .6276 .53218 L F
.683 .462 .58 r
.63067 .53638 m .62699 .53655 L .62649 .53416 L F
.842 .801 .309 r
.62699 .53655 m .6276 .53218 L .62649 .53416 L F
.6271 .53578 m .62695 .53533 L .6276 .53218 L F
.62699 .53655 m .62698 .53615 L .6271 .53578 L F
.62698 .53615 m .62695 .53533 L .6271 .53578 L F
.683 .462 .58 r
.63067 .53638 m .62745 .53468 L .63036 .53492 L F
.62745 .53468 m .62755 .53437 L .63036 .53492 L F
.41 .169 .435 r
.35614 .6202 m .3546 .61863 L .35669 .61809 L F
.35614 .6202 m .35419 .62081 L .3546 .61863 L F
.246 .07 .434 r
.62771 .49491 m .62747 .49704 L .62601 .49783 L F
.158 .116 .557 r
.6266 .50014 m .62601 .49783 L .62747 .49704 L F
.6266 .50014 m .62599 .5008 L .62601 .49783 L F
.196 .357 .799 r
.38264 .69641 m .38411 .69946 L .38472 .69832 L F
.229 .4 .825 r
.38411 .69946 m .38565 .69978 L .38472 .69832 L F
.817 .515 .478 r
.38411 .69946 m .3854 .70176 L .38565 .69978 L F
.38411 .69946 m .3831 .70269 L .3854 .70176 L F
.56 .643 .889 r
.36255 .59605 m .36186 .59879 L .36032 .59587 L F
.36255 .59605 m .36394 .59839 L .36186 .59879 L F
.98 .883 .661 r
.6021 .551 m .60028 .55206 L .60225 .55351 L F
.917 .884 .786 r
.59982 .55613 m .60225 .55351 L .60028 .55206 L F
.846 .714 .717 r
.60131 .55713 m .60225 .55351 L .59982 .55613 L F
.483 .802 1 r
.68121 .54011 m .68459 .54063 L .68347 .53942 L F
.574 .841 .995 r
.68459 .54063 m .68587 .53903 L .68347 .53942 L F
.68459 .54063 m .6871 .53988 L .68587 .53903 L F
.791 .579 .615 r
.49511 .68822 m .49489 .69071 L .49836 .6903 L F
.067 0 .127 r
.49648 .69322 m .49836 .6903 L .49489 .69071 L F
.789 .52 .53 r
.49988 .69368 m .49832 .69619 L .49648 .69322 L F
.067 0 .127 r
.49648 .69322 m .49695 .69348 L .49836 .6903 L F
.607 .29 .406 r
.49836 .6903 m .49695 .69348 L .501 .69245 L F
.606 .29 .409 r
.49836 .6903 m .501 .69245 L .50086 .69097 L F
.877 .587 .493 r
.6495 .53308 m .6513 .5345 L .64951 .53165 L F
.834 .779 .8 r
.64893 .52786 m .64951 .53165 L .65094 .52928 L F
0 0 0 r
.43421 .64884 m .43799 .64828 L .43592 .649 L F
.509 .006 0 r
.43643 .64857 m .43811 .64827 L .43799 .64828 L F
.349 0 0 r
.43897 .64732 m .43799 .64828 L .44117 .64779 L F
.165 .703 .752 r
.43799 .64828 m .44019 .6479 L .44117 .64779 L F
.509 .006 0 r
.43811 .64827 m .44019 .6479 L .43799 .64828 L F
0 0 0 r
.43783 .64829 m .43799 .64828 L .43897 .64732 L F
.43689 .64908 m .43799 .64828 L .43783 .64829 L F
.705 .726 .867 r
.65191 .51454 m .65311 .51728 L .6497 .51681 L F
.889 .583 .461 r
.65401 .51573 m .65311 .51728 L .65191 .51454 L F
.931 .917 .535 r
.61221 .50594 m .61116 .5072 L .61198 .50541 L F
.61221 .50594 m .61103 .50951 L .61116 .5072 L F
.565 .173 .257 r
.63471 .50232 m .63708 .50245 L .63804 .50061 L F
.541 .148 .245 r
.63804 .50061 m .63959 .50083 L .64048 .50049 L F
.63804 .50061 m .63708 .50245 L .63959 .50083 L F
.264 .195 .588 r
.46742 .77516 m .46844 .77503 L .46888 .77159 L F
.469 .244 .488 r
.46742 .77516 m .46923 .77728 L .46844 .77503 L F
.46742 .77516 m .46714 .77777 L .46923 .77728 L F
.481 .137 .305 r
.53053 .76085 m .53289 .76065 L .53378 .75822 L F
.497 .17 .343 r
.53289 .76065 m .53604 .75786 L .53378 .75822 L F
.063 .605 .849 r
.50112 .6377 m .5032 .63793 L .50451 .63833 L F
0 .183 .717 r
.50592 .63879 m .50663 .64032 L .50451 .63833 L F
.50592 .63879 m .50451 .63833 L .5032 .63793 L F
.574 .237 .361 r
.52724 .78012 m .526 .78278 L .52365 .78278 L F
.621 .301 .407 r
.52954 .78041 m .526 .78278 L .52724 .78012 L F
.637 .362 .485 r
.60372 .58487 m .60384 .58685 L .60014 .5872 L F
.702 .462 .558 r
.60618 .58473 m .60384 .58685 L .60372 .58487 L F
.335 .077 .366 r
.54919 .76116 m .55099 .76064 L .55138 .75868 L F
.357 .095 .373 r
.55138 .75868 m .55099 .76064 L .5535 .75815 L F
.34 0 .057 r
.48424 .75193 m .48646 .75158 L .48692 .74976 L F
.237 0 .032 r
.48692 .74976 m .48861 .75089 L .49199 .74908 L F
.48692 .74976 m .48646 .75158 L .48861 .75089 L F
.842 .654 .647 r
.54832 .7631 m .54919 .76116 L .54633 .76043 L F
.694 .573 .714 r
.54919 .76116 m .55254 .76395 L .55177 .76231 L F
.54993 .76095 m .55177 .76231 L .55099 .76064 L F
.404 .659 .963 r
.55113 .76092 m .55136 .76221 L .55099 .76064 L F
.55254 .76395 m .55136 .76221 L .55113 .76092 L F
.58 .389 .587 r
.55006 .76667 m .55291 .76664 L .55254 .76395 L F
.404 .659 .963 r
.55254 .76395 m .55416 .76407 L .55136 .76221 L F
.331 .215 .567 r
.55254 .76395 m .55458 .76517 L .55416 .76407 L F
.55254 .76395 m .55291 .76664 L .55458 .76517 L F
.762 .504 .544 r
.55374 .76408 m .55179 .7646 L .55136 .76221 L F
.55179 .7646 m .54981 .76512 L .55136 .76221 L F
.584 .026 0 r
.55136 .76221 m .55414 .76406 L .55374 .76408 L F
.55414 .76406 m .55416 .76407 L .55416 .76407 L F
.55414 .76406 m .55416 .76407 L .55374 .76408 L F
.694 .573 .714 r
.54919 .76116 m .55177 .76231 L .54993 .76095 L F
.22 .317 .752 r
.49912 .7944 m .49791 .79476 L .49703 .79254 L F
.453 .279 .553 r
.50026 .79657 m .49791 .79476 L .49912 .7944 L F
.221 .525 .918 r
.77661 .57939 m .77985 .58161 L .77849 .5812 L F
.571 .495 .73 r
.37846 .6881 m .37908 .69124 L .38126 .69079 L F
.528 .415 .668 r
.37957 .69383 m .38126 .69079 L .37908 .69124 L F
0 0 .16 r
.53708 .76798 m .53624 .76958 L .53724 .76621 L F
0 .494 .852 r
.53624 .76958 m .5365 .7694 L .53253 .76799 L F
.762 .522 .57 r
.53864 .76933 m .53611 .77123 L .53624 .76958 L F
.929 .883 .767 r
.53611 .77123 m .53708 .76798 L .53624 .76958 L F
0 0 0 r
.53708 .76798 m .5365 .7694 L .53624 .76958 L F
.523 .267 .469 r
.53159 .73585 m .5335 .73552 L .53436 .73327 L F
.665 .458 .595 r
.5335 .73552 m .53665 .73298 L .53436 .73327 L F
.388 .171 .458 r
.33938 .63701 m .33774 .63537 L .33996 .63474 L F
.33938 .63701 m .3372 .63787 L .33774 .63537 L F
.459 .253 .511 r
.37829 .66286 m .38054 .65982 L .3784 .66033 L F
.27 .519 .907 r
.64641 .48226 m .64596 .48386 L .6438 .48139 L F
0 .24 .755 r
.72367 .50316 m .72377 .50214 L .72272 .50146 L F
.843 .663 .122 r
.72367 .50316 m .72335 .50333 L .72377 .50214 L F
.72367 .50316 m .72368 .50611 L .72335 .50333 L F
.785 .753 .824 r
.25095 .64174 m .2521 .64269 L .25347 .64263 L F
.747 .464 .504 r
.50185 .69628 m .49988 .69368 L .50188 .6941 L F
.416 .202 .478 r
.50415 .69335 m .50185 .69628 L .50188 .6941 L F
.794 .822 .873 r
.48152 .64048 m .47834 .64072 L .48021 .63946 L F
.798 .862 .897 r
.48475 .63598 m .48152 .64048 L .48021 .63946 L F
.8 .727 .783 r
.61247 .54729 m .61567 .54809 L .61471 .54683 L F
.61247 .54729 m .61296 .55053 L .61567 .54809 L F
.303 .425 .82 r
.61567 .54809 m .61712 .54629 L .61471 .54683 L F
.683 .616 .774 r
.61806 .54514 m .61918 .54877 L .61567 .54809 L F
.238 0 0 r
.61918 .54877 m .61848 .54881 L .61567 .54809 L F
.303 .425 .82 r
.61567 .54809 m .61848 .54881 L .61712 .54629 L F
.895 .492 .071 r
.46956 .79491 m .47143 .79828 L .46888 .7973 L F
.834 .366 0 r
.47143 .79828 m .47126 .79924 L .46888 .7973 L F
.47143 .79828 m .47251 .79994 L .47126 .79924 L F
.086 .224 .711 r
.7397 .59259 m .74059 .59587 L .74162 .59466 L F
.199 .399 .834 r
.74059 .59587 m .74312 .59743 L .74162 .59466 L F
.972 .682 .418 r
.59057 .7108 m .58965 .71247 L .5893 .70996 L F
.79 .453 .418 r
.54055 .78331 m .54243 .78271 L .54097 .78524 L F
.35 0 .169 r
.54097 .78524 m .54243 .78271 L .54458 .78292 L F
.302 .002 .278 r
.57326 .68548 m .57534 .68485 L .57523 .68336 L F
.693 .869 .965 r
.47834 .64072 m .47585 .64227 L .47431 .64132 L F
0 0 0 r
.44165 .65984 m .43876 .66197 L .43944 .66037 L F
.547 0 0 r
.55925 .72197 m .55937 .72273 L .55861 .72226 L F
.285 0 0 r
.55954 .72184 m .55925 .72197 L .55737 .72162 L F
.547 0 0 r
.55925 .72197 m .55623 .72077 L .55737 .72162 L F
.55925 .72197 m .55861 .72226 L .55623 .72077 L F
.285 0 0 r
.56083 .72196 m .55925 .72197 L .55954 .72184 L F
0 .133 .614 r
.56262 .7248 m .55925 .72197 L .56083 .72196 L F
.823 .445 .339 r
.56434 .72469 m .56262 .7248 L .56083 .72196 L F
.26 .027 .358 r
.62843 .56507 m .63063 .56205 L .63031 .56402 L F
0 0 .197 r
.63031 .56402 m .62802 .56675 L .62843 .56507 L F
.587 .39 .581 r
.61035 .56226 m .61313 .56206 L .6127 .55944 L F
.409 .269 .577 r
.6127 .55944 m .61492 .56112 L .61587 .55844 L F
.6127 .55944 m .61313 .56206 L .61492 .56112 L F
.523 .342 .578 r
.2784 .61824 m .27837 .62049 L .27622 .62097 L F
.525 .433 .694 r
.27837 .62049 m .27681 .62408 L .27622 .62097 L F
.864 .991 .733 r
.61103 .50951 m .60892 .5124 L .60946 .51044 L F
.94 .965 .707 r
.61103 .50951 m .60946 .51044 L .61116 .5072 L F
.496 0 0 r
.53758 .77718 m .53962 .77777 L .54099 .77738 L F
.679 .183 .061 r
.54099 .77738 m .54185 .77947 L .54293 .77709 L F
.54099 .77738 m .53962 .77777 L .54185 .77947 L F
.512 .397 .659 r
.48802 .76134 m .49021 .76338 L .4902 .76131 L F
.48802 .76134 m .48815 .76385 L .49021 .76338 L F
.117 .58 .918 r
.4952 .79006 m .49466 .79083 L .49256 .78914 L F
.4952 .79006 m .49641 .79112 L .49466 .79083 L F
.599 .427 .621 r
.62256 .53715 m .62496 .53697 L .62482 .53432 L F
.62256 .53715 m .62496 .53697 L .62482 .53432 L F
.422 .625 .938 r
.37191 .59978 m .37111 .60142 L .36984 .59959 L F
.237 .397 .82 r
.37191 .59978 m .37356 .60311 L .37111 .60142 L F
.986 .716 .419 r
.55816 .78078 m .55676 .78259 L .55641 .78144 L F
.293 .31 .707 r
.33685 .60424 m .33751 .6005 L .33575 .60158 L F
.33685 .60424 m .33803 .60362 L .33751 .6005 L F
.237 .186 .595 r
.33685 .60424 m .33839 .60634 L .33803 .60362 L F
.755 .24 0 r
.56617 .74593 m .56571 .74441 L .56488 .7432 L F
.56617 .74593 m .56757 .74661 L .56571 .74441 L F
.283 .107 .457 r
.35343 .62272 m .35213 .62121 L .35419 .62081 L F
.35343 .62272 m .35195 .62354 L .35213 .62121 L F
.623 .728 .922 r
.68884 .50621 m .68542 .50531 L .68774 .50471 L F
.702 .243 .158 r
.68884 .50621 m .68852 .50659 L .68845 .50656 L F
.68873 .50618 m .68845 .50656 L .68594 .50545 L F
.68884 .50621 m .68845 .50656 L .68873 .50618 L F
.992 .739 .412 r
.68845 .50656 m .68772 .50755 L .68855 .50682 L F
.702 .243 .158 r
.68852 .50659 m .68772 .50755 L .68594 .50545 L F
.992 .739 .412 r
.68774 .50471 m .68772 .50755 L .68845 .50656 L F
.499 .704 .962 r
.69008 .50452 m .68884 .50621 L .68774 .50471 L F
.992 .739 .412 r
.68774 .50471 m .68845 .50656 L .69008 .50452 L F
.68845 .50656 m .68855 .50682 L .68852 .50659 L F
.993 .844 .487 r
.68855 .50682 m .68772 .50755 L .68852 .50659 L F
.68855 .50682 m .68852 .50659 L .68884 .50621 L F
.992 .739 .412 r
.68852 .50659 m .68855 .50682 L .68866 .50665 L F
.993 .844 .487 r
.68855 .50682 m .68884 .50621 L .69008 .50452 L F
.992 .739 .412 r
.68845 .50656 m .68866 .50665 L .69008 .50452 L F
.702 .243 .158 r
.68594 .50545 m .68772 .50755 L .68542 .50531 L F
0 0 .5 r
.27423 .65175 m .27451 .65133 L .27297 .64855 L F
.708 .55 .672 r
.60467 .56462 m .6071 .56154 L .60469 .56231 L F
.73 .524 .614 r
.60467 .56462 m .60469 .56231 L .60137 .56204 L F
.226 0 0 r
.40136 .71394 m .40191 .71467 L .39964 .71347 L F
.40136 .71394 m .40378 .71393 L .40191 .71467 L F
.5 .036 .083 r
.40515 .65227 m .40694 .65329 L .40838 .65173 L F
.542 .139 .227 r
.40694 .65329 m .41061 .65144 L .40838 .65173 L F
.848 .949 .593 r
.60892 .5124 m .60779 .51353 L .60946 .51044 L F
.613 .676 .887 r
.70229 .47984 m .70117 .48319 L .69982 .48041 L F
.70229 .47984 m .70325 .48271 L .70117 .48319 L F
.595 .303 .443 r
.48011 .753 m .4816 .75398 L .48262 .75299 L F
.48011 .753 m .47961 .75486 L .4816 .75398 L F
.264 .133 .507 r
.67326 .4861 m .67472 .4859 L .67464 .48348 L F
.774 .69 .771 r
.3895 .71619 m .3911 .71925 L .39323 .71661 L F
.818 .655 .679 r
.66277 .51779 m .66249 .5202 L .66082 .51702 L F
.33 0 .021 r
.5083 .81517 m .50956 .81631 L .50688 .81611 L F
.5083 .81517 m .51057 .8148 L .50956 .81631 L F
.399 .113 .358 r
.34495 .62937 m .34753 .62692 L .34696 .62881 L F
.443 .162 .391 r
.34696 .62881 m .34753 .62692 L .3497 .62646 L F
.919 .927 .8 r
.60436 .54786 m .60117 .55021 L .6021 .551 L F
.60436 .54786 m .60319 .54715 L .60117 .55021 L F
.914 .929 .807 r
.60525 .54429 m .60436 .54786 L .60661 .54529 L F
.60525 .54429 m .60319 .54715 L .60436 .54786 L F
.494 .031 .083 r
.42253 .69572 m .42487 .69583 L .42635 .69428 L F
.303 0 0 r
.42487 .69583 m .42865 .69393 L .42635 .69428 L F
.306 .347 .741 r
.3862 .71086 m .38696 .70747 L .38433 .70917 L F
.3862 .71086 m .3882 .71102 L .38696 .70747 L F
.501 .491 .777 r
.38681 .71301 m .3882 .71102 L .3862 .71086 L F
.429 .115 .329 r
.32098 .62935 m .32308 .62891 L .32402 .62632 L F
.453 .156 .371 r
.32308 .62891 m .32607 .62574 L .32402 .62632 L F
.193 0 0 r
.25941 .58977 m .26147 .58927 L .26313 .58774 L F
.316 0 .037 r
.26147 .58927 m .26511 .58707 L .26313 .58774 L F
.296 .014 .303 r
.71247 .49511 m .71016 .49756 L .71249 .49768 L F
.56 .412 .637 r
.71249 .49768 m .71471 .4943 L .71247 .49511 L F
.556 .214 .343 r
.49892 .78345 m .49677 .78614 L .49391 .78524 L F
.72 .42 .469 r
.50053 .78597 m .49677 .78614 L .49892 .78345 L F
.523 0 0 r
.61609 .53857 m .61889 .5389 L .61675 .5381 L F
.621 .444 .622 r
.62482 .53432 m .62699 .53655 L .62649 .53416 L F
.62482 .53432 m .62496 .53697 L .62699 .53655 L F
.62699 .53655 m .62482 .53432 L .62649 .53416 L F
.62699 .53655 m .62496 .53697 L .62482 .53432 L F
.62482 .53432 m .62496 .53697 L .62699 .53655 L F
.082 .544 .904 r
.56827 .72653 m .56863 .72604 L .56681 .72597 L F
.56827 .72653 m .57004 .72703 L .56863 .72604 L F
.069 0 0 r
.53972 .80476 m .54328 .80293 L .5428 .80358 L F
0 0 0 r
.5428 .80358 m .54328 .80293 L .54496 .80183 L F
.946 .827 .695 r
.57198 .56653 m .57287 .56463 L .57336 .56766 L F
.889 .859 .806 r
.57198 .56653 m .57336 .56766 L .57127 .57062 L F
.14 .27 .738 r
.59765 .71325 m .59893 .71527 L .59775 .71629 L F
.942 .939 .599 r
.59893 .71527 m .59811 .71901 L .59775 .71629 L F
.011 .585 .744 r
.43358 .64894 m .43592 .649 L .43689 .64908 L F
.446 .877 .908 r
.43689 .64908 m .43592 .649 L .43799 .64828 L F
0 0 0 r
.53583 .80541 m .53826 .80357 L .53802 .80598 L F
.404 .248 .553 r
.53972 .80476 m .53802 .80598 L .53826 .80357 L F
.133 0 .18 r
.61587 .55844 m .61664 .55997 L .61753 .55871 L F
.61587 .55844 m .61492 .56112 L .61664 .55997 L F
.685 .281 .273 r
.75256 .58256 m .75729 .58105 L .75567 .5828 L F
.647 .249 .275 r
.47545 .69067 m .47423 .6925 L .47206 .6908 L F
.686 .295 .3 r
.47775 .69272 m .47545 .69067 L .47755 .69125 L F
.47775 .69272 m .47423 .6925 L .47545 .69067 L F
.229 .382 .81 r
.74749 .60376 m .74901 .60707 L .7501 .60559 L F
.242 .401 .822 r
.74901 .60707 m .75153 .60869 L .7501 .60559 L F
.454 .498 .815 r
.74901 .60707 m .75198 .61009 L .75153 .60869 L F
.521 .205 .372 r
.69675 .50364 m .69926 .50326 L .70207 .50136 L F
.359 0 .007 r
.69926 .50326 m .69921 .50419 L .69675 .50364 L F
.69926 .50326 m .69921 .50419 L .69675 .50364 L F
.712 .723 .859 r
.2452 .626 m .24557 .62296 L .24367 .62447 L F
.2452 .626 m .24586 .6227 L .24557 .62296 L F
.2452 .626 m .24681 .62389 L .24586 .6227 L F
.211 .735 .755 r
.51057 .8148 m .51395 .81413 L .51271 .81424 L F
0 .548 .805 r
.51395 .81413 m .51514 .81411 L .51271 .81424 L F
.611 .952 .809 r
.51492 .81395 m .51514 .81411 L .51711 .81275 L F
0 .548 .805 r
.51395 .81413 m .51552 .81439 L .51514 .81411 L F
.246 0 0 r
.50956 .81631 m .51057 .8148 L .51271 .81424 L F
.50956 .81631 m .51271 .81424 L .51122 .81401 L F
.675 .944 .961 r
.51514 .81411 m .51815 .81344 L .51711 .81275 L F
.752 .908 .945 r
.51755 .81387 m .52212 .81214 L .52085 .81132 L F
.51755 .81387 m .52085 .81132 L .51815 .81344 L F
0 0 0 r
.51815 .81344 m .51929 .81257 L .51711 .81275 L F
.22 0 0 r
.5159 .81361 m .51711 .81275 L .51929 .81257 L F
.664 .824 .96 r
.5159 .81361 m .51884 .81267 L .51844 .81244 L F
.611 .952 .809 r
.5155 .81379 m .51711 .81275 L .5159 .81361 L F
.355 .333 .697 r
.51652 .81055 m .51496 .81093 L .51711 .81275 L F
.165 .695 .855 r
.51171 .81402 m .51271 .81424 L .51403 .81417 L F
.51171 .81402 m .51403 .81417 L .51435 .81409 L F
.51435 .81409 m .51403 .81417 L .51514 .81411 L F
.51122 .81401 m .51138 .81403 L .51171 .81402 L F
.51138 .81403 m .51271 .81424 L .51171 .81402 L F
.51122 .81401 m .51514 .81411 L .51354 .81473 L F
.51275 .81456 m .51354 .81473 L .51338 .81479 L F
.51122 .81401 m .51354 .81473 L .51275 .81456 L F
.631 .298 .389 r
.51711 .81275 m .51496 .81093 L .51297 .81438 L F
.537 .451 .705 r
.51652 .81055 m .51711 .81275 L .51929 .81257 L F
.631 .298 .389 r
.51711 .81275 m .51297 .81438 L .5163 .81088 L F
.531 .602 .869 r
.51929 .81257 m .51711 .81275 L .5163 .81088 L F
.664 .824 .96 r
.5159 .81361 m .51844 .81244 L .51696 .81158 L F
.611 .952 .809 r
.51546 .81381 m .5155 .81379 L .5159 .81361 L F
.51338 .81479 m .51514 .81411 L .51492 .81395 L F
.51338 .81479 m .51492 .81395 L .51546 .81381 L F
.51492 .81395 m .51711 .81275 L .51546 .81381 L F
.5 .155 .313 r
.51293 .81397 m .51496 .81093 L .51261 .81112 L F
.51297 .81438 m .51321 .81396 L .51293 .81397 L F
.51321 .81396 m .51496 .81093 L .51293 .81397 L F
0 .548 .805 r
.51552 .81439 m .51647 .81455 L .51514 .81411 L F
.646 .66 .849 r
.47725 .66299 m .47839 .65909 L .47636 .65946 L F
.684 .471 .591 r
.47758 .66545 m .48087 .66312 L .47725 .66299 L F
.689 .426 .519 r
.48087 .66312 m .47969 .66331 L .47725 .66299 L F
.646 .66 .849 r
.47725 .66299 m .47969 .66331 L .47839 .65909 L F
.7 .465 .565 r
.59233 .58755 m .59223 .58996 L .59024 .58975 L F
.639 .409 .554 r
.59559 .58731 m .59223 .58996 L .59233 .58755 L F
.506 .47 .751 r
.6204 .54462 m .61918 .54877 L .61806 .54514 L F
.62025 .54511 m .62261 .54949 L .61918 .54877 L F
.62107 .54609 m .62261 .54949 L .62025 .54511 L F
.686 .242 .19 r
.62261 .54949 m .61848 .54881 L .61918 .54877 L F
.353 .212 .547 r
.62233 .55021 m .62386 .54711 L .62466 .54758 L F
.62233 .55021 m .62393 .5497 L .62386 .54711 L F
.713 .571 .694 r
.62386 .54711 m .62261 .54949 L .6204 .54462 L F
.686 .242 .19 r
.62261 .54949 m .62037 .54973 L .61848 .54881 L F
.739 .512 .586 r
.62386 .54711 m .62037 .54973 L .62261 .54949 L F
.62265 .54802 m .62393 .5497 L .62037 .54973 L F
.62386 .54711 m .62393 .54956 L .62265 .54802 L F
.62393 .54956 m .62393 .5497 L .62265 .54802 L F
.506 .47 .751 r
.6204 .54462 m .62107 .54609 L .62025 .54511 L F
.424 .508 .841 r
.63686 .48811 m .63549 .49014 L .63454 .48868 L F
.63686 .48811 m .63834 .49129 L .63549 .49014 L F
.864 .675 .645 r
.54832 .7631 m .54718 .7662 L .55006 .76667 L F
.919 .714 .22 r
.54718 .7662 m .54769 .76935 L .55006 .76667 L F
.545 .529 .788 r
.55006 .76667 m .55378 .76953 L .55291 .76664 L F
.939 .573 .263 r
.56813 .74877 m .56871 .7473 L .56757 .74661 L F
.56813 .74877 m .5694 .74947 L .56871 .7473 L F
.64 .101 0 r
.48095 .79889 m .48392 .79975 L .48234 .79869 L F
.496 .212 .413 r
.56311 .69652 m .56552 .69624 L .56604 .69309 L F
.404 .077 .293 r
.56604 .69309 m .56811 .69316 L .56876 .69142 L F
.538 .249 .424 r
.56604 .69309 m .56837 .69553 L .56811 .69316 L F
.56604 .69309 m .56552 .69624 L .56837 .69553 L F
.277 .111 .468 r
.46846 .76672 m .47021 .7684 L .47065 .76613 L F
.46846 .76672 m .46822 .76929 L .47021 .7684 L F
.392 0 0 r
.47522 .77766 m .47891 .77754 L .47703 .77847 L F
.898 .719 .652 r
.46759 .7943 m .46956 .79491 L .46888 .7973 L F
.525 .433 .694 r
.27837 .62049 m .27874 .62364 L .27681 .62408 L F
.519 .378 .629 r
.27906 .62626 m .27681 .62408 L .27874 .62364 L F
.27906 .62626 m .27699 .62669 L .27681 .62408 L F
.722 .563 .674 r
.63272 .48905 m .63413 .49219 L .62998 .49197 L F
.414 .313 .631 r
.63426 .48625 m .63454 .48868 L .63272 .48905 L F
.307 .01 .287 r
.3616 .61241 m .36424 .60979 L .36393 .61193 L F
.523 .27 .472 r
.36424 .60979 m .36601 .6114 L .36393 .61193 L F
.36424 .60979 m .36642 .60947 L .36601 .6114 L F
.199 0 0 r
.41286 .65122 m .4151 .65093 L .41645 .64996 L F
.299 0 0 r
.4151 .65093 m .4187 .64993 L .41645 .64996 L F
.319 .742 .974 r
.30664 .64946 m .3085 .65023 L .31065 .64986 L F
0 .054 .584 r
.65219 .49453 m .65294 .49637 L .65209 .49763 L F
.069 .229 .722 r
.65294 .49637 m .65414 .49978 L .65209 .49763 L F
.796 .992 .758 r
.63005 .54311 m .62763 .54578 L .62839 .54397 L F
.793 .999 .815 r
.62763 .54578 m .62566 .54665 L .62839 .54397 L F
.759 .525 .579 r
.50782 .7864 m .50813 .78877 L .50432 .7887 L F
.523 .358 .599 r
.51001 .78608 m .50813 .78877 L .50782 .7864 L F
0 0 .375 r
.59073 .6968 m .59088 .69375 L .59268 .69432 L F
.555 .392 .615 r
.5918 .69789 m .59374 .6976 L .59134 .69554 L F
0 .113 .587 r
.59374 .6976 m .59178 .69598 L .59134 .69554 L F
0 0 .375 r
.59073 .6968 m .59134 .69554 L .59082 .69501 L F
0 .113 .587 r
.59178 .69598 m .59027 .69474 L .59134 .69554 L F
0 0 .375 r
.59082 .69501 m .59134 .69554 L .59088 .69375 L F
.112 .096 .558 r
.59034 .69916 m .59134 .69554 L .59073 .6968 L F
.716 .601 .727 r
.63182 .5399 m .6328 .54321 L .63005 .54311 L F
.652 .511 .678 r
.63542 .54264 m .63312 .54555 L .6328 .54321 L F
.551 .513 .767 r
.37846 .6881 m .38058 .68763 L .37962 .68533 L F
.571 .495 .73 r
.37846 .6881 m .38126 .69079 L .38058 .68763 L F
.908 .765 .692 r
.65517 .51924 m .65672 .52027 L .65565 .51699 L F
.846 .744 .751 r
.65334 .52198 m .65672 .52027 L .65517 .51924 L F
.65334 .52198 m .6546 .52373 L .65672 .52027 L F
.467 .297 .567 r
.24277 .60147 m .24467 .60094 L .24475 .59854 L F
.426 .283 .582 r
.24277 .60147 m .24461 .60331 L .24467 .60094 L F
.24277 .60147 m .24285 .60403 L .24461 .60331 L F
.566 .217 .335 r
.54811 .7363 m .54532 .73686 L .5461 .73612 L F
.292 .467 .861 r
.62901 .50282 m .62599 .5008 L .6266 .50014 L F
.752 .459 .486 r
.4902 .76131 m .49497 .76315 L .49253 .76063 L F
.4902 .76131 m .49021 .76338 L .49497 .76315 L F
.456 .335 .626 r
.49021 .76338 m .49238 .76546 L .49497 .76315 L F
.338 0 .013 r
.49497 .76315 m .4947 .76508 L .49557 .76363 L F
.49497 .76315 m .49238 .76546 L .4947 .76508 L F
0 0 0 r
.3069 .63425 m .30901 .63378 L .3111 .63301 L F
.614 .954 .813 r
.3111 .63301 m .30901 .63378 L .31078 .63233 L F
.421 .732 .99 r
.35411 .59423 m .35111 .59327 L .3533 .59303 L F
.388 .641 .956 r
.35615 .59327 m .35411 .59423 L .3533 .59303 L F
.35615 .59327 m .35722 .59471 L .35411 .59423 L F
.364 .508 .868 r
.71422 .49034 m .71611 .4903 L .71421 .48972 L F
.71422 .49034 m .7164 .49153 L .71611 .4903 L F
.292 0 0 r
.42866 .70435 m .42709 .70606 L .42539 .70569 L F
.23 0 0 r
.43079 .704 m .42709 .70606 L .42866 .70435 L F
0 0 0 r
.75024 .58629 m .75161 .58368 L .75234 .58465 L F
.75024 .58629 m .75074 .58656 L .75161 .58368 L F
0 .411 .765 r
.71069 .5018 m .7072 .50026 L .70824 .50284 L F
.958 .637 .234 r
.7108 .50421 m .70824 .50284 L .70808 .50472 L F
.815 .705 .743 r
.57387 .58416 m .57647 .5845 L .57473 .58753 L F
.684 .471 .591 r
.47758 .66545 m .48092 .66553 L .48087 .66312 L F
.742 .74 .849 r
.48183 .65948 m .48087 .66312 L .48306 .66265 L F
.48183 .65948 m .47969 .66331 L .48087 .66312 L F
.734 .681 .798 r
.56037 .77739 m .56278 .78055 L .55816 .78078 L F
.737 .602 .707 r
.55816 .78078 m .56278 .78055 L .55886 .78357 L F
.35 .525 .888 r
.56388 .78017 m .56278 .78055 L .56037 .77739 L F
.755 .644 .738 r
.54719 .76892 m .54549 .77008 L .54668 .76986 L F
.919 .714 .22 r
.54718 .7662 m .54728 .76896 L .54766 .76917 L F
0 0 .328 r
.54783 .76774 m .54728 .76905 L .54718 .7662 L F
.755 .644 .738 r
.54783 .76774 m .54684 .76873 L .54719 .76892 L F
.54684 .76873 m .54549 .77008 L .54719 .76892 L F
.919 .714 .22 r
.54766 .76917 m .54728 .76905 L .54769 .76935 L F
.54728 .76896 m .54728 .76905 L .54766 .76917 L F
.727 .987 .802 r
.54728 .76905 m .54668 .76986 L .54769 .76935 L F
.861 .867 .42 r
.57019 .76895 m .57124 .76694 L .57116 .76553 L F
.57019 .76895 m .57042 .76918 L .57124 .76694 L F
.008 0 0 r
.41467 .69668 m .41692 .69659 L .41809 .69648 L F
.071 0 0 r
.41692 .69659 m .4203 .69607 L .41809 .69648 L F
.279 .42 .825 r
.77943 .58047 m .78254 .58255 L .78125 .58389 L F
.589 .936 .763 r
.78125 .58389 m .78254 .58255 L .78237 .58267 L F
.089 .212 .698 r
.78044 .58476 m .77985 .58161 L .78125 .58389 L F
0 0 .521 r
.77943 .58047 m .78125 .58389 L .77985 .58161 L F
.589 .936 .763 r
.78125 .58389 m .78237 .58267 L .77977 .58455 L F
.089 .212 .698 r
.78049 .58502 m .78044 .58476 L .78125 .58389 L F
0 0 .31 r
.78071 .58549 m .78049 .58502 L .78125 .58389 L F
.591 .486 .702 r
.24654 .63231 m .24822 .6293 L .2464 .63196 L F
.24654 .63231 m .2488 .63187 L .24822 .6293 L F
.701 .398 .46 r
.57907 .69037 m .57403 .69265 L .57427 .69133 L F
.57907 .69037 m .57658 .6932 L .57403 .69265 L F
.404 .396 .737 r
.57876 .68819 m .5799 .69085 L .57907 .69037 L F
.332 0 .164 r
.57878 .69259 m .57907 .69037 L .5799 .69085 L F
.57878 .69259 m .57658 .6932 L .57907 .69037 L F
.843 .759 .77 r
.64775 .53626 m .64952 .53751 L .6513 .5345 L F
.792 .723 .788 r
.49229 .66555 m .49417 .66764 L .49609 .66543 L F
.623 .46 .641 r
.49417 .66764 m .49652 .66843 L .49609 .66543 L F
.54 .228 .387 r
.46893 .66187 m .47205 .65988 L .46817 .66008 L F
.46893 .66187 m .47038 .66174 L .47205 .65988 L F
.789 .569 .603 r
.47038 .66174 m .47232 .66335 L .47205 .65988 L F
.398 0 0 r
.71954 .50081 m .71879 .50078 L .71706 .49994 L F
.449 .839 .625 r
.71016 .49756 m .7067 .49989 L .7096 .49809 L F
.88 .549 .419 r
.7096 .49809 m .71249 .49768 L .71016 .49756 L F
.613 .635 .848 r
.50701 .74379 m .50822 .74075 L .50598 .74313 L F
.50701 .74379 m .50902 .74309 L .50822 .74075 L F
.26 0 0 r
.29857 .60379 m .2971 .60552 L .29496 .60597 L F
.377 0 .097 r
.30103 .60307 m .2971 .60552 L .29857 .60379 L F
.133 0 .196 r
.63302 .5592 m .63278 .5613 L .63063 .56205 L F
.115 0 .151 r
.63063 .56205 m .63198 .56295 L .63031 .56402 L F
.63063 .56205 m .63278 .5613 L .63198 .56295 L F
.791 .594 .635 r
.4793 .77508 m .47891 .77754 L .48247 .77788 L F
.605 .429 .618 r
.4802 .78073 m .48271 .7805 L .48247 .77788 L F
0 0 0 r
.48125 .77961 m .4802 .78073 L .48247 .77788 L F
.48125 .77961 m .48247 .77788 L .47891 .77754 L F
.511 .361 .613 r
.48247 .77788 m .48473 .77999 L .48478 .77746 L F
.48247 .77788 m .48271 .7805 L .48473 .77999 L F
.703 .787 .916 r
.52734 .81022 m .52939 .80788 L .5268 .80897 L F
.52734 .81022 m .53019 .80936 L .52939 .80788 L F
.801 .475 .437 r
.66701 .50484 m .67014 .50384 L .66688 .50262 L F
.66701 .50484 m .67033 .50567 L .67014 .50384 L F
.761 .992 .879 r
.73976 .58971 m .73929 .59026 L .7401 .58856 L F
.948 .642 .201 r
.73929 .59026 m .73889 .59171 L .7401 .58856 L F
.73929 .59026 m .7397 .59259 L .73889 .59171 L F
.61 .083 0 r
.56434 .72469 m .56355 .72541 L .56262 .7248 L F
0 .499 .728 r
.56681 .72597 m .56355 .72541 L .56434 .72469 L F
0 0 .316 r
.51778 .77154 m .51919 .77452 L .51837 .77283 L F
.774 .69 .771 r
.3895 .71619 m .39323 .71661 L .39206 .71613 L F
.477 .692 .962 r
.39323 .71661 m .39398 .71504 L .39206 .71613 L F
.39323 .71661 m .39527 .71641 L .39398 .71504 L F
.707 .475 .571 r
.54163 .77153 m .53864 .76933 L .54197 .76952 L F
.628 .081 0 r
.54197 .76952 m .54308 .77103 L .54163 .77153 L F
.54197 .76952 m .54385 .77151 L .54308 .77103 L F
.747 .464 .504 r
.50185 .69628 m .49832 .69619 L .49988 .69368 L F
.821 .828 .854 r
.77657 .61321 m .7784 .61216 L .77769 .6093 L F
.793 .813 .868 r
.77769 .6093 m .7784 .61216 L .78078 .60935 L F
.737 .607 .037 r
.65341 .48839 m .65337 .48823 L .65341 .48536 L F
.534 .316 .531 r
.65071 .48743 m .65341 .48536 L .65337 .48823 L F
.65335 .4854 m .6535 .48471 L .65341 .48536 L F
.65071 .48743 m .6535 .48471 L .65335 .4854 L F
.795 .861 .416 r
.6535 .48471 m .65288 .48555 L .65377 .48341 L F
.6535 .48471 m .65377 .48341 L .65419 .48239 L F
.534 .316 .531 r
.65071 .48743 m .6522 .48769 L .6535 .48471 L F
.795 .861 .416 r
.6535 .48471 m .65272 .48649 L .65288 .48555 L F
.65272 .48649 m .6522 .48769 L .65243 .48697 L F
.65272 .48649 m .65243 .48697 L .65288 .48555 L F
.335 .502 .875 r
.65371 .4874 m .65525 .48875 L .65493 .48698 L F
.76 .321 .209 r
.6531 .48765 m .6548 .4886 L .65456 .48853 L F
.6531 .48765 m .6548 .4886 L .6531 .48765 L F
.65299 .48754 m .6548 .4886 L .65294 .48756 L F
.335 .502 .875 r
.6522 .48769 m .65274 .48788 L .65314 .48763 L F
.65294 .48749 m .65314 .48763 L .65361 .48732 L F
.6522 .48769 m .65314 .48763 L .65294 .48749 L F
.76 .321 .209 r
.65301 .4876 m .65456 .48853 L .6543 .48844 L F
.335 .502 .875 r
.65243 .48697 m .65361 .48732 L .65288 .48555 L F
.6522 .48769 m .65294 .48749 L .65243 .48697 L F
.65294 .48749 m .65361 .48732 L .65243 .48697 L F
.76 .321 .209 r
.65301 .4876 m .6543 .48844 L .65062 .48712 L F
.389 .584 .919 r
.65027 .48595 m .6522 .48769 L .65071 .48743 L F
.76 .321 .209 r
.65027 .48595 m .65301 .4876 L .65062 .48712 L F
0 .337 .809 r
.65337 .48823 m .65488 .48864 L .65333 .48809 L F
.737 .607 .037 r
.65342 .48917 m .65337 .48823 L .65341 .48839 L F
0 .375 .834 r
.65342 .48917 m .65571 .49045 L .65337 .48823 L F
.593 .019 0 r
.65763 .49048 m .65337 .48823 L .65571 .49045 L F
.65763 .49048 m .65669 .4904 L .65451 .48898 L F
.65456 .48886 m .65451 .48898 L .65337 .48823 L F
.65763 .49048 m .65451 .48898 L .65456 .48886 L F
0 0 0 r
.65437 .48932 m .65302 .49174 L .65223 .49285 L F
0 .337 .809 r
.65337 .48823 m .65562 .4897 L .65525 .48875 L F
.65562 .4897 m .65669 .4904 L .65525 .48875 L F
.76 .321 .209 r
.65314 .48763 m .65429 .48841 L .6548 .4886 L F
.483 .506 .805 r
.6548 .4886 m .65479 .48861 L .65466 .48856 L F
.65479 .48861 m .65169 .49069 L .65466 .48856 L F
.65466 .48856 m .65169 .49069 L .65071 .48743 L F
.76 .321 .209 r
.65429 .48841 m .65473 .48872 L .65479 .48861 L F
.65429 .48841 m .65479 .48861 L .6548 .4886 L F
0 .337 .809 r
.65488 .48864 m .65525 .48875 L .65436 .48844 L F
.65488 .48864 m .65436 .48844 L .65333 .48809 L F
.65488 .48864 m .65436 .48844 L .65488 .48864 L F
.335 .502 .875 r
.65274 .48788 m .65525 .48875 L .65361 .48732 L F
.804 .34 0 r
.65525 .48875 m .65492 .48926 L .65492 .48789 L F
.65525 .48875 m .65492 .48789 L .65493 .48698 L F
0 0 0 r
.6548 .4886 m .65429 .48951 L .65437 .48932 L F
.65429 .48951 m .65302 .49174 L .65437 .48932 L F
.76 .321 .209 r
.65423 .48839 m .65452 .48909 L .65473 .48872 L F
.65311 .48766 m .65358 .48813 L .65423 .48839 L F
0 .337 .809 r
.65333 .48809 m .65525 .48875 L .65332 .48808 L F
0 0 0 r
.6548 .4886 m .65223 .49285 L .65169 .49069 L F
.76 .321 .209 r
.65358 .48813 m .65452 .48909 L .65423 .48839 L F
0 .337 .809 r
.65337 .48823 m .65332 .48808 L .6522 .48769 L F
.05 .573 .869 r
.65071 .48743 m .6522 .48769 L .65337 .48823 L F
.76 .321 .209 r
.65062 .48712 m .65456 .48853 L .65071 .48743 L F
.65232 .48715 m .65404 .48996 L .65452 .48909 L F
.65232 .48715 m .65452 .48909 L .65311 .48766 L F
.65294 .48756 m .6531 .48765 L .6531 .48765 L F
.65232 .48715 m .65473 .48872 L .65314 .48763 L F
.781 .348 0 r
.65669 .4904 m .65634 .49058 L .65525 .48875 L F
.804 .34 0 r
.65525 .48875 m .65634 .49058 L .65492 .48926 L F
.623 .885 .557 r
.65492 .48926 m .65753 .48607 L .65493 .48698 L F
.65753 .48607 m .65783 .4857 L .65493 .48698 L F
.335 .502 .875 r
.65361 .48732 m .65371 .4874 L .65493 .48698 L F
.76 .321 .209 r
.65027 .48595 m .65299 .48754 L .65294 .48756 L F
.335 .502 .875 r
.65361 .48732 m .65493 .48698 L .65481 .4869 L F
.65361 .48732 m .65481 .4869 L .65288 .48555 L F
.76 .321 .209 r
.65027 .48595 m .65195 .48774 L .65232 .48715 L F
.65195 .48774 m .65404 .48996 L .65232 .48715 L F
.603 .408 .59 r
.58132 .68504 m .58218 .69021 L .57876 .68819 L F
.281 .182 .56 r
.58311 .68201 m .58345 .68432 L .58132 .68504 L F
.449 .303 .59 r
.58504 .68658 m .58132 .68504 L .58345 .68432 L F
.58504 .68658 m .58218 .69021 L .58132 .68504 L F
0 0 0 r
.6344 .55831 m .63597 .5573 L .63476 .55828 L F
.495 .84 .567 r
.63476 .55828 m .63597 .5573 L .63765 .55582 L F
.63476 .55828 m .63765 .55582 L .63653 .55685 L F
.624 .955 .793 r
.63601 .55683 m .63476 .55828 L .63653 .55685 L F
0 0 0 r
.63507 .55825 m .63476 .55828 L .63601 .55683 L F
.63391 .55997 m .63476 .55828 L .63507 .55825 L F
.63302 .5592 m .6344 .55831 L .63476 .55828 L F
0 0 .033 r
.63302 .5592 m .63391 .55997 L .63278 .5613 L F
.63302 .5592 m .63476 .55828 L .63391 .55997 L F
.663 .445 .579 r
.5794 .68478 m .58311 .68201 L .58323 .68192 L F
.887 .786 .744 r
.56908 .57346 m .56585 .57559 L .56773 .57249 L F
.56908 .57346 m .56725 .57568 L .56585 .57559 L F
.829 .679 .697 r
.56908 .57346 m .56854 .57591 L .56725 .57568 L F
.885 .886 .827 r
.57004 .56965 m .56908 .57346 L .56773 .57249 L F
.57004 .56965 m .57127 .57062 L .56908 .57346 L F
.391 .176 .463 r
.57103 .68826 m .57295 .68768 L .57326 .68548 L F
.422 .294 .6 r
.57136 .69088 m .57295 .68768 L .57103 .68826 L F
.254 0 0 r
.42187 .70762 m .41909 .70888 L .42019 .70727 L F
.15 .663 .896 r
.47065 .76613 m .47284 .76628 L .4742 .76674 L F
0 0 .527 r
.47556 .76823 m .47527 .7693 L .4742 .76674 L F
.47556 .76823 m .4742 .76674 L .47284 .76628 L F
.558 .285 .457 r
.63834 .51695 m .6407 .51674 L .64068 .51482 L F
.357 .132 .43 r
.64068 .51482 m .6407 .51674 L .64313 .51566 L F
.471 .466 .77 r
.40536 .68427 m .40392 .6867 L .40288 .68258 L F
.321 .337 .722 r
.40536 .68427 m .40482 .68773 L .40392 .6867 L F
.783 .423 .376 r
.63964 .52018 m .63845 .52185 L .6381 .52017 L F
.897 .592 .46 r
.64021 .5225 m .63845 .52185 L .63964 .52018 L F
.934 .585 .342 r
.68019 .48539 m .68168 .48682 L .6786 .48357 L F
.689 .839 .955 r
.6784 .48662 m .68168 .48682 L .68019 .48539 L F
.713 .704 .841 r
.6786 .48357 m .68168 .48682 L .68384 .48592 L F
.889 .859 .806 r
.57198 .56653 m .57127 .57062 L .57004 .56965 L F
.703 .719 .862 r
.48306 .66265 m .48661 .66306 L .48558 .66025 L F
.616 .669 .878 r
.48558 .66025 m .48661 .66306 L .48906 .66255 L F
.552 .621 .875 r
.68731 .48656 m .68892 .48512 L .68678 .48563 L F
.68731 .48656 m .68956 .48611 L .68892 .48512 L F
.79 .815 .872 r
.37001 .70738 m .37418 .70653 L .37229 .70465 L F
.368 .55 .901 r
.38264 .70817 m .38433 .70917 L .38459 .70827 L F
.709 .785 .911 r
.7046 .50036 m .70228 .50139 L .70116 .5002 L F
.945 .589 .288 r
.47718 .79698 m .47836 .79743 L .47725 .79559 L F
.979 .844 .638 r
.47651 .79927 m .47836 .79743 L .47718 .79698 L F
.555 .458 .699 r
.47836 .79743 m .48164 .79476 L .47672 .79472 L F
.361 0 0 r
.47836 .79743 m .48037 .79839 L .47718 .79698 L F
0 0 .169 r
.47713 .79803 m .47718 .79698 L .47829 .7957 L F
.47651 .79927 m .47718 .79698 L .47713 .79803 L F
.945 .589 .288 r
.47718 .79698 m .47725 .79559 L .47672 .79472 L F
.979 .844 .638 r
.47651 .79927 m .47775 .80008 L .47836 .79743 L F
.555 .458 .699 r
.47836 .79743 m .48037 .79839 L .48164 .79476 L F
.652 .321 .399 r
.56811 .69316 m .56978 .69354 L .56876 .69142 L F
.634 .313 .411 r
.56876 .69142 m .5716 .69225 L .57136 .69088 L F
.56876 .69142 m .56978 .69354 L .5716 .69225 L F
.851 .773 .774 r
.64893 .52786 m .65094 .52928 L .65267 .52608 L F
0 0 0 r
.52019 .68287 m .51834 .68565 L .51921 .68439 L F
.508 .12 .239 r
.51921 .68439 m .5226 .68228 L .52019 .68287 L F
.658 .45 .592 r
.51168 .66338 m .51125 .66577 L .50725 .66583 L F
.631 .425 .585 r
.5127 .66546 m .51168 .66338 L .51265 .66308 L F
.5127 .66546 m .51125 .66577 L .51168 .66338 L F
.164 0 0 r
.51856 .80917 m .51496 .81093 L .51652 .81055 L F
.514 .156 .298 r
.51929 .81213 m .51856 .80917 L .51652 .81055 L F
.51929 .81213 m .52113 .80942 L .51856 .80917 L F
.339 0 0 r
.31494 .63181 m .31887 .62983 L .31599 .63134 L F
.31494 .63181 m .31713 .63156 L .31887 .62983 L F
.288 0 0 r
.31887 .62983 m .32011 .63033 L .32098 .62935 L F
.31887 .62983 m .31713 .63156 L .32011 .63033 L F
.112 .213 .691 r
.61651 .52946 m .61491 .52869 L .61678 .52831 L F
.246 .713 .946 r
.28991 .58467 m .29373 .58531 L .29173 .58566 L F
0 .119 .665 r
.64994 .48871 m .65169 .49069 L .65145 .49211 L F
0 0 .372 r
.65223 .49285 m .65145 .49211 L .65169 .49069 L F
.65223 .49285 m .65219 .49453 L .65145 .49211 L F
.01 .199 .711 r
.54928 .71402 m .55049 .71605 L .54932 .71287 L F
.329 0 .105 r
.45831 .69329 m .45694 .69544 L .45475 .69591 L F
.541 .17 .286 r
.46049 .69321 m .45694 .69544 L .45831 .69329 L F
.597 .396 .579 r
.4802 .78073 m .48234 .78312 L .48271 .7805 L F
0 .095 .644 r
.48183 .78199 m .4802 .78073 L .48125 .77961 L F
.48183 .78199 m .48234 .78312 L .4802 .78073 L F
0 0 .106 r
.50713 .81206 m .50469 .81412 L .50697 .81367 L F
.377 0 .076 r
.50874 .81285 m .50713 .81206 L .50697 .81367 L F
.50874 .81285 m .50986 .81171 L .50713 .81206 L F
.146 .494 .905 r
.71907 .48029 m .71818 .48102 L .71724 .47969 L F
.372 .421 .783 r
.71907 .48029 m .71845 .48345 L .71818 .48102 L F
.581 .868 .995 r
.46742 .65309 m .46699 .65436 L .46944 .65391 L F
.46742 .65309 m .46558 .65352 L .46699 .65436 L F
.4 .037 .23 r
.70207 .50136 m .69926 .50326 L .70186 .50166 L F
.70207 .50136 m .70186 .50166 L .70116 .5002 L F
.526 .539 .812 r
.51802 .6878 m .51921 .68439 L .51834 .68565 L F
.793 .715 .778 r
.49458 .66261 m .49229 .66555 L .49609 .66543 L F
.394 .366 .709 r
.49609 .66543 m .49703 .66216 L .49458 .66261 L F
.49609 .66543 m .49774 .66546 L .49703 .66216 L F
.361 .275 .622 r
.49609 .66543 m .498 .66772 L .49774 .66546 L F
.49609 .66543 m .49652 .66843 L .498 .66772 L F
.532 .106 .176 r
.57427 .69133 m .57403 .69265 L .5716 .69225 L F
.422 .215 .492 r
.42991 .66444 m .42816 .66313 L .43045 .66335 L F
.42991 .66444 m .42803 .66537 L .42816 .66313 L F
.934 .963 .754 r
.63182 .5399 m .63005 .54311 L .63008 .54088 L F
.943 .961 .715 r
.63005 .54311 m .62839 .54397 L .63008 .54088 L F
.386 .787 .985 r
.31423 .60086 m .31467 .6005 L .31239 .60091 L F
.497 .544 .835 r
.67412 .53404 m .67754 .53679 L .67731 .5344 L F
.457 .209 .449 r
.67731 .5344 m .67966 .53382 L .68013 .53188 L F
.487 .355 .626 r
.67731 .5344 m .67929 .53537 L .67966 .53382 L F
.67731 .5344 m .67754 .53679 L .67929 .53537 L F
.396 0 0 r
.626 .51229 m .62433 .51352 L .62227 .5136 L F
.771 .373 .301 r
.626 .51229 m .62647 .51395 L .62433 .51352 L F
.348 .125 .428 r
.62777 .51144 m .62647 .51395 L .626 .51229 L F
.62777 .51144 m .62647 .51395 L .626 .51229 L F
.444 .156 .38 r
.52252 .68468 m .5226 .68735 L .52032 .68781 L F
.279 .165 .54 r
.52463 .68187 m .52252 .68468 L .5226 .68228 L F
.52463 .68187 m .52473 .68432 L .52252 .68468 L F
.271 .033 .358 r
.52429 .68653 m .52252 .68468 L .52473 .68432 L F
.52429 .68653 m .5226 .68735 L .52252 .68468 L F
.762 .766 .857 r
.70582 .4804 m .7047 .48449 L .70325 .48271 L F
.70582 .4804 m .70679 .48313 L .7047 .48449 L F
.427 .197 .461 r
.47534 .75826 m .47709 .75848 L .47765 .75559 L F
.395 .4 .747 r
.47534 .75826 m .47766 .76012 L .47709 .75848 L F
.501 .402 .674 r
.47534 .75826 m .47586 .76092 L .47766 .76012 L F
.738 .691 .806 r
.64889 .52551 m .65267 .52608 L .65128 .52301 L F
.851 .773 .774 r
.64893 .52786 m .65267 .52608 L .64889 .52551 L F
.768 .705 .792 r
.65128 .52301 m .65267 .52608 L .6546 .52373 L F
.857 .753 .747 r
.64775 .53626 m .64863 .53948 L .64952 .53751 L F
.58 .939 .916 r
.31065 .64986 m .3143 .6489 L .31215 .64969 L F
.077 0 0 r
.3143 .6489 m .31485 .64928 L .31215 .64969 L F
.3143 .6489 m .31643 .64864 L .31485 .64928 L F
0 .25 .761 r
.49883 .79335 m .49703 .79254 L .49641 .79112 L F
.49883 .79335 m .49912 .7944 L .49703 .79254 L F
.321 .337 .722 r
.40536 .68427 m .40634 .68794 L .40482 .68773 L F
.27 .324 .735 r
.40741 .69208 m .40482 .68773 L .40634 .68794 L F
.711 .741 .875 r
.64135 .49185 m .6394 .49304 L .63834 .49129 L F
.302 .011 .293 r
.44258 .68866 m .44402 .6896 L .44482 .68838 L F
.44258 .68866 m .44205 .69042 L .44402 .6896 L F
.978 .774 .357 r
.733 .49994 m .73288 .50218 L .73343 .5027 L F
.589 .805 .982 r
.28412 .65109 m .2859 .65232 L .28792 .65161 L F
.676 .958 .946 r
.6911 .53752 m .69289 .53777 L .69487 .53653 L F
.765 .725 .816 r
.61589 .5203 m .61328 .52329 L .6162 .52225 L F
.415 .068 .266 r
.61324 .52504 m .6162 .52225 L .61328 .52329 L F
.61324 .52504 m .61557 .52452 L .6162 .52225 L F
.253 .764 .777 r
.6162 .52225 m .61783 .52172 L .61846 .52168 L F
.037 0 .127 r
.6162 .52225 m .61557 .52452 L .61783 .52172 L F
.852 .655 .636 r
.6428 .49666 m .64306 .49782 L .6397 .49677 L F
.56 .472 .713 r
.6428 .49666 m .64591 .49745 L .64306 .49782 L F
.64306 .49782 m .64591 .49745 L .6428 .49666 L F
0 .041 .591 r
.51203 .76682 m .51394 .76891 L .51309 .76753 L F
.51203 .76682 m .51309 .76753 L .5103 .76658 L F
.648 .572 .756 r
.47586 .76092 m .47626 .7635 L .47865 .76219 L F
.653 .216 0 r
.5949 .69346 m .59641 .69589 L .59719 .69687 L F
.855 .771 .265 r
.59667 .69777 m .59719 .69687 L .59641 .69589 L F
.59667 .69777 m .59676 .69945 L .59719 .69687 L F
.974 .805 .386 r
.5715 .75785 m .57222 .75839 L .57128 .75757 L F
.5715 .75785 m .57192 .76089 L .57222 .75839 L F
.58 .457 .677 r
.53048 .80084 m .52865 .80294 L .52879 .80201 L F
.69 .623 .775 r
.5297 .80174 m .53231 .80313 L .52865 .80294 L F
.53048 .80084 m .53064 .80105 L .5297 .80174 L F
.53064 .80105 m .53231 .80313 L .5297 .80174 L F
.653 .299 .36 r
.52865 .80294 m .53231 .80313 L .53167 .80558 L F
.806 .46 .401 r
.53231 .80313 m .53583 .80541 L .53242 .80586 L F
.207 .424 .853 r
.53308 .80241 m .53231 .80313 L .53048 .80084 L F
.993 .742 .399 r
.53231 .80313 m .53242 .80586 L .53167 .80558 L F
0 0 .007 r
.53167 .80558 m .53231 .80313 L .53308 .80241 L F
.993 .742 .399 r
.53231 .80313 m .53167 .80558 L .53308 .80241 L F
.544 .358 .579 r
.53167 .80558 m .53308 .80241 L .52927 .80206 L F
.52899 .80226 m .52927 .80206 L .52879 .80201 L F
.53167 .80558 m .52927 .80206 L .52899 .80226 L F
.449 .337 .635 r
.52879 .80201 m .52865 .80294 L .53167 .80558 L F
.543 .392 .626 r
.52879 .80201 m .53308 .80241 L .53048 .80084 L F
.452 .119 .309 r
.24913 .59525 m .25133 .59485 L .25221 .59259 L F
.38 .074 .316 r
.25133 .59485 m .25401 .59237 L .25221 .59259 L F
.491 .486 .779 r
.75804 .60024 m .75679 .60376 L .75567 .60073 L F
.75804 .60024 m .75898 .60369 L .75679 .60376 L F
.504 .618 .898 r
.76012 .60545 m .75679 .60376 L .75898 .60369 L F
0 0 .366 r
.73175 .497 m .733 .49994 L .73253 .49832 L F
.983 .747 .344 r
.54743 .76032 m .54832 .7631 L .54633 .76043 L F
.54757 .76049 m .54832 .7631 L .54743 .76032 L F
.54757 .76049 m .54752 .76277 L .54832 .7631 L F
.54752 .76032 m .54752 .76277 L .54757 .76049 L F
.913 .893 .478 r
.54694 .76523 m .54832 .7631 L .54752 .76277 L F
.414 .854 .924 r
.55136 .76221 m .54752 .76277 L .54832 .7631 L F
.615 .29 .396 r
.54922 .76252 m .54749 .76458 L .54752 .76277 L F
.54749 .76458 m .54694 .76523 L .54752 .76277 L F
.55136 .76221 m .54983 .76326 L .54922 .76252 L F
.913 .893 .478 r
.54694 .76523 m .54718 .7662 L .54728 .76593 L F
.54694 .76523 m .54728 .76593 L .54832 .7631 L F
.719 .474 .554 r
.54447 .76569 m .54694 .76523 L .54752 .76277 L F
.645 .959 .929 r
.5467 .76476 m .54694 .76523 L .54643 .76491 L F
0 0 .192 r
.54752 .76277 m .54694 .76523 L .54825 .76385 L F
.645 .959 .929 r
.54825 .76385 m .54694 .76523 L .5467 .76476 L F
.615 .29 .396 r
.54983 .76326 m .54694 .76523 L .54922 .76252 L F
.983 .747 .344 r
.54752 .76032 m .54757 .76049 L .54743 .76032 L F
.799 .877 .904 r
.49185 .63554 m .48964 .63765 L .48831 .63664 L F
.703 .881 .964 r
.45075 .64611 m .44726 .64641 L .44953 .6458 L F
.53 .922 .864 r
.45075 .64611 m .45169 .64515 L .45286 .64499 L F
.485 .877 .965 r
.45075 .64611 m .44953 .6458 L .45169 .64515 L F
.995 .77 .48 r
.57031 .75438 m .57157 .75284 L .57019 .75105 L F
.57031 .75438 m .57133 .75522 L .57157 .75284 L F
.841 .686 .691 r
.71764 .50815 m .7193 .51271 L .72055 .50868 L F
.966 .717 .509 r
.71762 .51096 m .7193 .51271 L .71764 .50815 L F
.243 .748 .697 r
.72231 .5122 m .71833 .51346 L .72127 .511 L F
.574 .362 .555 r
.24475 .59854 m .24705 .59824 L .24731 .59586 L F
.508 .335 .582 r
.24705 .59824 m .24913 .59525 L .24731 .59586 L F
.528 .415 .668 r
.37957 .69383 m .38179 .69332 L .38126 .69079 L F
.72 .442 .504 r
.48006 .68732 m .48049 .68539 L .47851 .68457 L F
.48006 .68732 m .48222 .68794 L .48049 .68539 L F
.833 .541 0 r
.6553 .50298 m .6558 .50536 L .65603 .50556 L F
.128 .094 .547 r
.65776 .50246 m .6558 .50536 L .6553 .50298 L F
.743 .977 .729 r
.65776 .50246 m .6554 .50502 L .6558 .50536 L F
.6554 .50502 m .65405 .50648 L .6558 .50536 L F
.833 .541 0 r
.65603 .50556 m .6558 .50536 L .65625 .50633 L F
.857 .579 .046 r
.6558 .50536 m .65663 .50854 L .65625 .50633 L F
.67 .502 .65 r
.47709 .75848 m .47961 .75486 L .47765 .75559 L F
.711 .699 .836 r
.47839 .65909 m .47969 .66331 L .48183 .65948 L F
.959 .718 .27 r
.51457 .79189 m .51208 .79339 L .51212 .79353 L F
.51457 .79189 m .51422 .79476 L .51208 .79339 L F
.51457 .79189 m .51465 .79428 L .51422 .79476 L F
0 .171 .707 r
.51458 .79127 m .51457 .79189 L .51313 .78971 L F
0 0 .272 r
.51523 .79332 m .51457 .79189 L .51458 .79127 L F
.51523 .79332 m .51465 .79428 L .51457 .79189 L F
.422 .237 .523 r
.28035 .61767 m .27837 .62049 L .2784 .61824 L F
.602 .378 .549 r
.6079 .56477 m .61035 .56226 L .6071 .56154 L F
.6079 .56477 m .61039 .56452 L .61035 .56226 L F
.447 .174 .405 r
.61039 .56452 m .61313 .56206 L .61035 .56226 L F
.143 0 0 r
.26736 .58704 m .26937 .58653 L .27108 .58509 L F
.252 0 0 r
.27108 .58509 m .27269 .5853 L .27314 .58494 L F
.27108 .58509 m .26937 .58653 L .27269 .5853 L F
.779 .698 .774 r
.58884 .68712 m .59011 .69104 L .58854 .69035 L F
.58884 .68712 m .59159 .68877 L .59011 .69104 L F
.885 .571 .451 r
.59011 .69104 m .58826 .69252 L .58854 .69035 L F
.59011 .69104 m .59088 .69375 L .58826 .69252 L F
.368 0 .158 r
.32761 .64324 m .32643 .64511 L .32431 .64555 L F
.218 0 .072 r
.32841 .64435 m .32761 .64324 L .32963 .64273 L F
.32841 .64435 m .32643 .64511 L .32761 .64324 L F
.407 .839 .95 r
.65652 .4836 m .65977 .48336 L .65751 .48329 L F
.495 .437 .721 r
.51408 .6593 m .51265 .66308 L .5118 .6598 L F
.51408 .6593 m .51454 .66253 L .51265 .66308 L F
.433 .266 .554 r
.51454 .66253 m .5127 .66546 L .51265 .66308 L F
.266 0 0 r
.51228 .78324 m .51782 .78336 L .51766 .78358 L F
.661 .333 .408 r
.51801 .7831 m .51766 .78358 L .51782 .78336 L F
.624 .182 .178 r
.5503 .7541 m .55133 .75478 L .55262 .75377 L F
.698 .758 .899 r
.65571 .49045 m .65637 .49216 L .65888 .49095 L F
.655 .704 .882 r
.7761 .58876 m .77704 .59033 L .77859 .58941 L F
.59 .375 .557 r
.64048 .50049 m .64328 .5005 L .64306 .49782 L F
.522 .139 .257 r
.64048 .50049 m .64188 .50114 L .64328 .5005 L F
.696 .256 0 r
.6397 .49677 m .64218 .50074 L .64061 .49852 L F
.397 .234 .54 r
.64306 .49782 m .64328 .5005 L .64517 .49932 L F
0 0 .06 r
.64326 .50038 m .64354 .49992 L .64517 .49932 L F
.64354 .49992 m .6445 .49928 L .64517 .49932 L F
.162 0 .241 r
.64474 .49907 m .64257 .50057 L .64306 .49782 L F
.397 .234 .54 r
.64306 .49782 m .64517 .49932 L .64591 .49745 L F
.708 .986 .853 r
.64517 .49932 m .6445 .49928 L .6462 .49781 L F
.162 0 .241 r
.64478 .49909 m .6445 .49928 L .64474 .49907 L F
.6445 .49928 m .64257 .50057 L .64474 .49907 L F
.64497 .49895 m .64306 .49782 L .64591 .49745 L F
.64484 .49914 m .64474 .49907 L .64497 .49895 L F
.64474 .49907 m .64306 .49782 L .64497 .49895 L F
0 0 .042 r
.64701 .49608 m .64517 .49932 L .64591 .49745 L F
0 0 0 r
.64631 .49765 m .64701 .49608 L .64517 .49932 L F
.708 .986 .853 r
.6445 .49928 m .64438 .49927 L .64474 .49907 L F
.845 .502 .403 r
.64306 .49782 m .64257 .50057 L .6397 .49677 L F
.64257 .50057 m .64254 .50058 L .6397 .49677 L F
.696 .256 0 r
.64218 .50074 m .64212 .5007 L .64061 .49852 L F
.845 .502 .403 r
.6425 .50053 m .64218 .50074 L .6397 .49677 L F
0 0 .06 r
.64188 .50114 m .64249 .50059 L .64326 .50038 L F
.845 .502 .403 r
.64257 .50061 m .64247 .50064 L .6425 .50053 L F
.64247 .50064 m .64218 .50074 L .6425 .50053 L F
0 0 .06 r
.64188 .50114 m .64232 .50128 L .64237 .50105 L F
.64227 .50079 m .64237 .50105 L .64249 .50059 L F
.538 .924 .828 r
.64241 .5009 m .64188 .50114 L .64237 .50087 L F
0 0 .06 r
.64188 .50114 m .64237 .50105 L .64227 .50079 L F
.696 .256 0 r
.64218 .50074 m .64237 .50105 L .64212 .5007 L F
.64237 .50105 m .64246 .50119 L .64238 .50108 L F
.64237 .50105 m .64238 .50108 L .64212 .5007 L F
.845 .502 .403 r
.64257 .50061 m .64246 .50119 L .64218 .50074 L F
.664 .663 .839 r
.64207 .50063 m .64236 .50104 L .64249 .50093 L F
0 0 .06 r
.64249 .50059 m .64312 .50002 L .64354 .49992 L F
.64312 .50002 m .64369 .49968 L .64354 .49992 L F
.64257 .50057 m .64354 .49992 L .64326 .50038 L F
.162 0 .241 r
.64484 .49914 m .64257 .50057 L .64478 .49909 L F
.538 .924 .828 r
.64241 .5009 m .64237 .50087 L .64326 .50038 L F
.664 .663 .839 r
.64312 .50002 m .64249 .50093 L .64439 .49927 L F
0 0 .06 r
.64249 .50059 m .64354 .49992 L .64257 .50057 L F
.538 .924 .828 r
.64328 .5005 m .64241 .5009 L .64326 .50038 L F
.64328 .5005 m .64326 .50038 L .64371 .50023 L F
.162 0 .241 r
.64484 .49914 m .64246 .50119 L .64257 .50057 L F
.845 .502 .403 r
.64257 .50057 m .64257 .50061 L .64254 .50058 L F
0 0 .06 r
.64249 .50059 m .64247 .50096 L .64312 .50002 L F
.664 .663 .839 r
.64207 .50063 m .64249 .50093 L .64312 .50002 L F
.64061 .49852 m .64207 .50063 L .64458 .49911 L F
.64207 .50063 m .64439 .49927 L .64458 .49911 L F
0 0 .06 r
.64312 .50002 m .64396 .49924 L .64369 .49968 L F
.64312 .50002 m .64245 .50133 L .64396 .49924 L F
.664 .663 .839 r
.64249 .50093 m .64246 .50119 L .64458 .49911 L F
0 0 .06 r
.64236 .50113 m .64247 .50096 L .64249 .50059 L F
.664 .663 .839 r
.64236 .50104 m .64238 .50108 L .64249 .50093 L F
.64238 .50108 m .64246 .50119 L .64249 .50093 L F
0 0 .06 r
.64232 .50128 m .64245 .50133 L .64247 .50096 L F
.64232 .50128 m .64247 .50096 L .64236 .50113 L F
.64247 .50096 m .64245 .50133 L .64312 .50002 L F
.664 .663 .839 r
.64458 .49911 m .64246 .50119 L .64484 .49914 L F
.708 .986 .853 r
.64567 .49826 m .64588 .49807 L .6462 .49781 L F
0 0 0 r
.64631 .49765 m .64484 .49914 L .64497 .49895 L F
.64631 .49765 m .64497 .49895 L .64591 .49745 L F
.708 .986 .853 r
.64474 .49907 m .64458 .49911 L .64588 .49807 L F
.64474 .49907 m .64588 .49807 L .64567 .49826 L F
.616 .256 .336 r
.64396 .49924 m .64061 .49852 L .64458 .49911 L F
.708 .986 .853 r
.64438 .49927 m .64396 .49924 L .64474 .49907 L F
.616 .256 .336 r
.64396 .49924 m .64458 .49911 L .64484 .49914 L F
.708 .986 .853 r
.64474 .49907 m .64396 .49924 L .64474 .49907 L F
.64458 .49911 m .64396 .49924 L .64573 .49811 L F
.64458 .49911 m .64573 .49811 L .6462 .49781 L F
.6462 .49781 m .64396 .49924 L .64631 .49765 L F
0 0 .06 r
.64354 .49992 m .64396 .49924 L .6445 .49928 L F
.538 .924 .828 r
.64371 .50023 m .64326 .50038 L .64517 .49932 L F
.802 .905 .913 r
.55865 .71295 m .55621 .71501 L .55481 .71416 L F
.651 .742 .916 r
.67472 .4859 m .67594 .48772 L .6784 .48662 L F
.53 .791 .993 r
.67805 .47766 m .67676 .47914 L .6757 .47812 L F
.67805 .47766 m .67918 .47867 L .67676 .47914 L F
.494 .261 .49 r
.3616 .61241 m .36162 .61414 L .35943 .61448 L F
.476 .21 .431 r
.36162 .61414 m .35863 .61749 L .35943 .61448 L F
.255 0 0 r
.43087 .69358 m .43301 .69314 L .43436 .69149 L F
.262 0 0 r
.43436 .69149 m .43524 .69262 L .43659 .69122 L F
.43436 .69149 m .43301 .69314 L .43524 .69262 L F
.42 .214 .492 r
.6715 .49935 m .66976 .49789 L .67047 .49688 L F
.6715 .49935 m .66948 .50032 L .66976 .49789 L F
.702 .462 .558 r
.60618 .58473 m .60624 .5873 L .60384 .58685 L F
.622 .402 .563 r
.60618 .58473 m .60952 .58662 L .60624 .5873 L F
.60618 .58473 m .60971 .58435 L .60952 .58662 L F
.715 .537 .647 r
.59884 .5646 m .60137 .56204 L .59899 .56223 L F
.59884 .5646 m .60236 .56515 L .60137 .56204 L F
.73 .524 .614 r
.60467 .56462 m .60137 .56204 L .60236 .56515 L F
0 0 .197 r
.48234 .75739 m .48135 .7584 L .48333 .75512 L F
.67 .502 .65 r
.47989 .75917 m .48037 .75878 L .47961 .75486 L F
.968 .824 .648 r
.47948 .75938 m .4799 .75916 L .48037 .75878 L F
.48038 .75875 m .48037 .75878 L .4806 .7586 L F
.47948 .75938 m .48037 .75878 L .48038 .75875 L F
0 0 .4 r
.47961 .75486 m .48037 .75878 L .48062 .7564 L F
.968 .824 .648 r
.4799 .75916 m .48135 .7584 L .4806 .7586 L F
.4799 .75916 m .48036 .76022 L .48135 .7584 L F
.67 .502 .65 r
.47989 .75917 m .4799 .75917 L .4799 .75916 L F
.968 .824 .648 r
.47948 .75938 m .47978 .75966 L .4799 .75916 L F
.47978 .75966 m .48036 .76022 L .4799 .75916 L F
.67 .502 .65 r
.4799 .75916 m .48047 .75931 L .48037 .75878 L F
.4799 .75917 m .48047 .75931 L .4799 .75916 L F
.968 .824 .648 r
.48055 .75883 m .4806 .7586 L .48251 .75801 L F
.48038 .75875 m .4806 .7586 L .48054 .7589 L F
.4806 .7586 m .48135 .7584 L .48234 .75739 L F
.4806 .7586 m .48234 .75739 L .48242 .75768 L F
.4806 .7586 m .48242 .75768 L .48251 .75801 L F
.703 .903 .967 r
.48049 .75885 m .48251 .75801 L .48062 .7564 L F
.48047 .75931 m .48251 .75801 L .48049 .75885 L F
.968 .824 .648 r
.48054 .7589 m .48055 .75883 L .48251 .75801 L F
0 0 .4 r
.48037 .75878 m .48049 .75885 L .48038 .75875 L F
.968 .824 .648 r
.47948 .75938 m .48038 .75875 L .48054 .7589 L F
0 0 .4 r
.48037 .75878 m .48047 .75931 L .48049 .75885 L F
.48038 .75875 m .48049 .75885 L .48051 .75846 L F
.48037 .75878 m .48051 .75846 L .48062 .7564 L F
.67 .502 .65 r
.47709 .75848 m .47961 .7591 L .47961 .75486 L F
.47961 .7591 m .47989 .75917 L .47987 .75896 L F
.47961 .7591 m .47987 .75896 L .47961 .75486 L F
.246 .627 .959 r
.72294 .48817 m .72333 .48935 L .72272 .4885 L F
.72294 .48817 m .72715 .49061 L .72333 .48935 L F
.973 .706 .466 r
.72333 .48935 m .72198 .49065 L .72272 .4885 L F
.72333 .48935 m .72334 .49208 L .72198 .49065 L F
.359 0 .205 r
.6285 .48345 m .62989 .48468 L .63074 .48322 L F
.6285 .48345 m .62762 .48536 L .62989 .48468 L F
.698 .362 .403 r
.53242 .80586 m .53583 .80541 L .53416 .8076 L F
.55 .011 0 r
.53583 .80541 m .53605 .80663 L .53416 .8076 L F
.53583 .80541 m .53802 .80598 L .53605 .80663 L F
.475 .247 .487 r
.36185 .61277 m .3616 .61241 L .36393 .61193 L F
.36185 .61277 m .36162 .61414 L .3616 .61241 L F
.585 .88 .993 r
.47028 .64231 m .46663 .64242 L .46866 .64142 L F
.524 .702 .951 r
.47122 .64012 m .47028 .64231 L .46866 .64142 L F
.47122 .64012 m .47229 .64201 L .47028 .64231 L F
.496 .165 .336 r
.56738 .69924 m .56757 .70098 L .56377 .7014 L F
.6 .345 .503 r
.56954 .69868 m .56757 .70098 L .56738 .69924 L F
.403 .149 .411 r
.28952 .61155 m .2879 .60957 L .28978 .60908 L F
.28952 .61155 m .28751 .61228 L .2879 .60957 L F
.281 .68 .972 r
.77661 .57939 m .77447 .5793 L .77354 .57846 L F
.384 .727 .99 r
.33115 .58993 m .33058 .59102 L .3292 .59002 L F
.33115 .58993 m .33267 .591 L .33058 .59102 L F
0 .134 .654 r
.46737 .78612 m .46911 .78842 L .46831 .78578 L F
.887 .767 .724 r
.64775 .53626 m .64622 .53946 L .64863 .53948 L F
.864 .754 .739 r
.64541 .5413 m .64863 .53948 L .64622 .53946 L F
.64541 .5413 m .64685 .54252 L .64863 .53948 L F
.944 .66 .471 r
.66082 .51702 m .66249 .5202 L .66107 .51844 L F
.894 .704 .637 r
.66249 .5202 m .65991 .52141 L .66107 .51844 L F
.66249 .5202 m .66229 .52248 L .65991 .52141 L F
.08 0 .36 r
.62018 .55595 m .6216 .5523 L .62019 .55381 L F
.79 .931 .565 r
.36892 .69944 m .36714 .70161 L .3674 .69857 L F
.36892 .69944 m .36674 .70288 L .36714 .70161 L F
.931 .667 .515 r
.36714 .70161 m .36892 .69944 L .3674 .69857 L F
.36714 .70161 m .36881 .70198 L .36892 .69944 L F
.642 .34 .445 r
.58427 .59035 m .58061 .59222 L .5808 .58974 L F
.58427 .59035 m .58444 .5921 L .58061 .59222 L F
.635 .372 .503 r
.58427 .59035 m .58652 .59238 L .58444 .5921 L F
.58427 .59035 m .58776 .5895 L .58652 .59238 L F
.664 .799 .947 r
.74621 .58604 m .74707 .58726 L .74378 .58688 L F
.578 .594 .833 r
.69073 .48899 m .69184 .48548 L .68956 .48611 L F
.69073 .48899 m .69309 .48865 L .69184 .48548 L F
.437 .179 .423 r
.3465 .63089 m .34495 .62937 L .34696 .62881 L F
.3465 .63089 m .34448 .6315 L .34495 .62937 L F
.82 .452 .361 r
.45552 .65459 m .45589 .65489 L .45755 .65479 L F
.45589 .65489 m .45897 .65734 L .45755 .65479 L F
.658 .721 .895 r
.45897 .65734 m .46023 .65456 L .45755 .65479 L F
.186 .717 .746 r
.46023 .65456 m .45972 .65465 L .45755 .65479 L F
.45972 .65465 m .45632 .65526 L .45755 .65479 L F
.087 0 0 r
.45632 .65526 m .45552 .65459 L .45755 .65479 L F
.82 .452 .361 r
.45552 .65459 m .45839 .65794 L .45897 .65734 L F
.087 0 0 r
.45632 .65526 m .45398 .65603 L .45552 .65459 L F
.337 .735 .983 r
.62602 .5192 m .62472 .51999 L .62397 .52028 L F
.62602 .5192 m .62732 .52012 L .62472 .51999 L F
0 0 .521 r
.48316 .80198 m .4857 .80519 L .48526 .80467 L F
.613 .417 .593 r
.48734 .80013 m .48748 .8025 L .48316 .80198 L F
.263 .062 .408 r
.48748 .8025 m .4857 .80519 L .48316 .80198 L F
.308 .684 .977 r
.78296 .60422 m .77957 .60312 L .78241 .60084 L F
.279 .291 .694 r
.7838 .60079 m .78296 .60422 L .78241 .60084 L F
.7838 .60079 m .78469 .60279 L .78296 .60422 L F
.502 0 0 r
.7862 .60678 m .78564 .60644 L .78645 .60698 L F
.78296 .60422 m .78528 .60614 L .7862 .60678 L F
.78528 .60614 m .78564 .60644 L .7862 .60678 L F
.641 .807 .963 r
.78336 .60731 m .78439 .60552 L .78249 .60636 L F
.321 .364 .751 r
.78469 .60279 m .78564 .60644 L .78296 .60422 L F
.641 .807 .963 r
.78439 .60552 m .78459 .60519 L .78421 .6054 L F
.78439 .60552 m .78421 .6054 L .78249 .60636 L F
.288 0 .104 r
.62247 .48797 m .62542 .48618 L .62305 .48663 L F
0 0 0 r
.61282 .50085 m .61298 .50152 L .61339 .49952 L F
.61282 .50085 m .61232 .50311 L .61298 .50152 L F
.383 .125 .393 r
.38252 .65915 m .38517 .65653 L .38318 .65727 L F
.206 0 0 r
.30676 .60136 m .30514 .60273 L .30299 .60313 L F
.586 .175 .229 r
.30886 .6013 m .30514 .60273 L .30676 .60136 L F
.244 0 0 r
.39262 .65528 m .39127 .65471 L .39007 .65581 L F
.39262 .65528 m .39007 .65581 L .39103 .65574 L F
.28 0 0 r
.39262 .65528 m .39356 .65479 L .39127 .65471 L F
0 0 0 r
.39677 .65396 m .39262 .65528 L .39518 .65522 L F
.39677 .65396 m .39356 .65479 L .39262 .65528 L F
.604 .522 .735 r
.39427 .65287 m .39262 .65528 L .39205 .65334 L F
.244 0 0 r
.39262 .65528 m .38974 .65612 L .392 .65582 L F
.604 .522 .735 r
.39427 .65287 m .39518 .65522 L .39262 .65528 L F
.446 .28 .561 r
.39205 .65334 m .392 .65567 L .39398 .65517 L F
.392 .65567 m .392 .65582 L .39257 .65563 L F
.392 .65567 m .39257 .65563 L .39398 .65517 L F
.244 0 0 r
.39103 .65574 m .39007 .65581 L .38974 .65612 L F
0 .087 .646 r
.55049 .71605 m .55212 .71881 L .5514 .71737 L F
.98 .883 .661 r
.6021 .551 m .60117 .55021 L .60028 .55206 L F
.586 .644 .875 r
.40986 .69284 m .40894 .69561 L .40768 .69331 L F
.40986 .69284 m .41128 .69532 L .40894 .69561 L F
.376 0 0 r
.40857 .71249 m .40582 .7133 L .40679 .71237 L F
.433 .013 .141 r
.40957 .71159 m .40857 .71249 L .40679 .71237 L F
.475 .148 .333 r
.44206 .69946 m .44109 .70184 L .43889 .70207 L F
.594 .268 .387 r
.44351 .70051 m .44206 .69946 L .44449 .69915 L F
.44351 .70051 m .44109 .70184 L .44206 .69946 L F
.453 .779 .998 r
.67861 .53123 m .68013 .53188 L .67648 .53145 L F
.67861 .53123 m .68013 .53188 L .67648 .53145 L F
.654 .572 .751 r
.68165 .52817 m .68013 .53188 L .67861 .53123 L F
.68165 .52817 m .68217 .53115 L .68013 .53188 L F
.939 .954 .644 r
.62941 .52864 m .62795 .52995 L .62815 .52764 L F
.62941 .52864 m .62791 .53182 L .62795 .52995 L F
.449 .106 .291 r
.568 .69751 m .56989 .69727 L .5705 .6954 L F
0 0 0 r
.57003 .69725 m .56993 .69673 L .5705 .6954 L F
.449 .106 .291 r
.56989 .69727 m .57003 .69725 L .5705 .6954 L F
0 0 0 r
.5705 .6954 m .56993 .69673 L .57108 .69365 L F
.5705 .6954 m .57108 .69365 L .5716 .69225 L F
.57003 .69725 m .56954 .69868 L .56993 .69673 L F
.261 .604 .953 r
.36803 .59799 m .36734 .59904 L .36601 .59825 L F
.36803 .59799 m .36984 .59959 L .36734 .59904 L F
.659 .702 .878 r
.28441 .63179 m .28107 .63101 L .28299 .63045 L F
.053 .47 .885 r
.28299 .63045 m .28476 .63109 L .28441 .63179 L F
.097 .525 .909 r
.28476 .63109 m .28621 .63227 L .28441 .63179 L F
.569 .421 .641 r
.48804 .76642 m .49021 .76338 L .48815 .76385 L F
.847 .722 .726 r
.57263 .58692 m .57387 .58416 L .57473 .58753 L F
.79 .505 .505 r
.57473 .58753 m .57233 .58918 L .57263 .58692 L F
.57473 .58753 m .57518 .58974 L .57233 .58918 L F
.671 .275 .288 r
.48424 .79832 m .48534 .79819 L .48672 .79636 L F
.682 .662 .824 r
.48534 .79819 m .48835 .79548 L .48672 .79636 L F
.169 .685 .892 r
.26416 .64585 m .26574 .64576 L .26221 .64539 L F
.609 .788 .967 r
.69565 .52558 m .69252 .52509 L .6949 .52497 L F
.781 .956 .927 r
.69674 .52414 m .69565 .52558 L .6949 .52497 L F
.936 .634 .172 r
.63182 .5399 m .63421 .53703 L .63345 .53923 L F
.63182 .5399 m .63067 .53638 L .63421 .53703 L F
.63182 .5399 m .63112 .53896 L .63067 .53638 L F
.958 .927 .726 r
.63182 .5399 m .63008 .54088 L .63112 .53896 L F
.666 .572 .739 r
.63542 .54264 m .63182 .5399 L .63345 .53923 L F
.851 .717 .714 r
.62914 .51457 m .62647 .51395 L .62777 .51144 L F
.832 .581 .56 r
.62914 .51457 m .62638 .51624 L .62647 .51395 L F
.62914 .51457 m .62919 .51687 L .62638 .51624 L F
.38 .473 .83 r
.63059 .51289 m .62914 .51457 L .62777 .51144 L F
.484 .304 .561 r
.63188 .51554 m .62914 .51457 L .63059 .51289 L F
.63188 .51554 m .62919 .51687 L .62914 .51457 L F
.697 .593 .735 r
.63503 .52863 m .63576 .53157 L .63281 .53138 L F
.708 .55 .672 r
.60467 .56462 m .6079 .56477 L .6071 .56154 L F
.653 .413 .543 r
.59024 .58975 m .58652 .59238 L .58776 .5895 L F
.598 .029 0 r
.51545 .76141 m .51654 .76145 L .51285 .76011 L F
.661 .107 0 r
.51721 .76285 m .51654 .76145 L .51545 .76141 L F
.51721 .76285 m .51879 .76338 L .51654 .76145 L F
.599 .143 .141 r
.63413 .49219 m .63316 .49367 L .62998 .49197 L F
0 .239 .726 r
.63457 .49518 m .63316 .49367 L .63413 .49219 L F
.621 .68 .884 r
.77039 .61338 m .77201 .61106 L .76974 .61157 L F
.77039 .61338 m .77287 .61275 L .77201 .61106 L F
.847 .982 .694 r
.65985 .49495 m .65789 .49776 L .65826 .49582 L F
0 0 .116 r
.65799 .49988 m .65826 .49582 L .65789 .49776 L F
.463 .409 .712 r
.37455 .67116 m .37504 .6744 L .37692 .67323 L F
.527 .451 .713 r
.37544 .67682 m .37692 .67323 L .37504 .6744 L F
.766 .689 .777 r
.53635 .73585 m .5382 .73884 L .54022 .73664 L F
.016 .571 .82 r
.31198 .58827 m .31429 .58855 L .31578 .58898 L F
.105 0 0 r
.31429 .58855 m .31801 .5886 L .31578 .58898 L F
.536 .243 .417 r
.32867 .62345 m .33097 .62321 L .33162 .62131 L F
.474 .218 .445 r
.33097 .62321 m .33351 .62063 L .33162 .62131 L F
.725 .882 .482 r
.69225 .50925 m .69135 .51037 L .69237 .50874 L F
.695 .953 .687 r
.69225 .50925 m .69237 .50874 L .69348 .50746 L F
.607 .837 .456 r
.69348 .50746 m .69135 .51037 L .69225 .50925 L F
.773 .265 0 r
.48096 .80848 m .48144 .81022 L .47896 .80843 L F
.48096 .80848 m .48265 .8107 L .48144 .81022 L F
.668 .115 0 r
.48096 .80848 m .48493 .81104 L .48265 .8107 L F
.43 0 0 r
.28025 .6528 m .278 .65266 L .27609 .65178 L F
.117 .666 .705 r
.2823 .65199 m .278 .65266 L .28025 .6528 L F
.847 .982 .694 r
.65985 .49495 m .65826 .49582 L .658 .49428 L F
.811 .801 .842 r
.65985 .49495 m .66124 .49071 L .66217 .49204 L F
.65985 .49495 m .658 .49428 L .66124 .49071 L F
.299 0 .233 r
.53842 .73025 m .54051 .73004 L .5414 .72743 L F
.299 0 .111 r
.54051 .73004 m .54367 .72737 L .5414 .72743 L F
.182 0 .253 r
.40844 .67075 m .40616 .67357 L .40683 .6716 L F
.621 .163 .142 r
.67053 .5137 m .6702 .51354 L .67005 .51222 L F
.67106 .51538 m .67185 .51424 L .6702 .51354 L F
.67106 .51538 m .6702 .51354 L .67053 .5137 L F
.837 .666 .124 r
.67004 .51346 m .6702 .51354 L .6727 .51428 L F
.66998 .51344 m .6702 .51354 L .67004 .51346 L F
.66998 .51344 m .66991 .51172 L .6702 .51354 L F
.803 .598 .625 r
.56854 .57591 m .56679 .57846 L .56725 .57568 L F
.56854 .57591 m .57057 .57904 L .56679 .57846 L F
.829 .928 .898 r
.51562 .69076 m .51572 .68868 L .51802 .6878 L F
.592 .395 .583 r
.51802 .6878 m .51829 .69049 L .51562 .69076 L F
.526 .539 .812 r
.51802 .6878 m .52032 .68781 L .51921 .68439 L F
.257 .018 .347 r
.52032 .68781 m .51829 .69049 L .51802 .6878 L F
.709 .379 .417 r
.51572 .68868 m .52032 .68781 L .51802 .6878 L F
.567 .737 .956 r
.76659 .58304 m .76781 .58097 L .76579 .5818 L F
.76659 .58304 m .76952 .58308 L .76781 .58097 L F
.579 .901 .983 r
.78645 .60698 m .78564 .60644 L .78336 .60731 L F
.573 .898 .984 r
.78794 .6056 m .78564 .60644 L .78645 .60698 L F
.78794 .6056 m .78564 .60644 L .78645 .60698 L F
.618 .644 .854 r
.76132 .60291 m .76012 .60545 L .75898 .60369 L F
.76132 .60291 m .76247 .60461 L .76012 .60545 L F
.148 .666 .889 r
.50893 .7637 m .50733 .76329 L .50524 .7632 L F
.874 .439 .055 r
.50893 .7637 m .50889 .76556 L .50733 .76329 L F
.50893 .7637 m .5103 .76658 L .50889 .76556 L F
.211 0 0 r
.24608 .637 m .24815 .63655 L .24984 .63499 L F
.943 .961 .694 r
.24984 .63499 m .25078 .63144 L .2488 .63187 L F
.24984 .63499 m .24893 .6344 L .25078 .63144 L F
.958 .946 .659 r
.24984 .63499 m .24815 .63655 L .24893 .6344 L F
.711 .613 .745 r
.53243 .73708 m .5335 .73552 L .53159 .73585 L F
.435 .308 .608 r
.57326 .68548 m .57524 .68729 L .57534 .68485 L F
.54 .304 .506 r
.57326 .68548 m .57295 .68768 L .57524 .68729 L F
.57326 .68548 m .57295 .68768 L .57524 .68729 L F
.816 .63 .65 r
.57057 .57904 m .56691 .58101 L .56679 .57846 L F
.57057 .57904 m .57021 .58146 L .56691 .58101 L F
.583 .792 .979 r
.6712 .53369 m .67412 .53404 L .67349 .53273 L F
.867 .92 .862 r
.67349 .53273 m .67436 .53378 L .67648 .53145 L F
.67349 .53273 m .67648 .53145 L .67568 .53264 L F
.463 .762 .995 r
.67349 .53273 m .67568 .53264 L .67295 .5321 L F
.545 .567 .827 r
.67024 .53029 m .6712 .53369 L .67349 .53273 L F
.67024 .53029 m .67349 .53273 L .6716 .53183 L F
.463 .762 .995 r
.67349 .53273 m .67295 .5321 L .6716 .53183 L F
.867 .92 .862 r
.67349 .53273 m .67412 .53404 L .67436 .53378 L F
.859 .849 .832 r
.60525 .54429 m .60661 .54529 L .60887 .54247 L F
0 .08 .632 r
.64193 .48603 m .64261 .48641 L .64054 .48534 L F
.64193 .48603 m .64307 .4885 L .64261 .48641 L F
.095 0 0 r
.41155 .7108 m .40857 .71249 L .40957 .71159 L F
.568 .579 .824 r
.55821 .77777 m .55925 .77434 L .55678 .77697 L F
.55821 .77777 m .56037 .77739 L .55925 .77434 L F
.205 0 0 r
.5576 .7793 m .55821 .77777 L .55678 .77697 L F
.734 .681 .798 r
.56037 .77739 m .55816 .78078 L .55821 .77777 L F
.205 0 0 r
.5576 .7793 m .56037 .77739 L .55821 .77777 L F
.655 .577 .756 r
.63734 .52801 m .63576 .53157 L .63503 .52863 L F
.63734 .52801 m .6387 .53132 L .63576 .53157 L F
.648 .5 .669 r
.6387 .53132 m .63644 .53411 L .63576 .53157 L F
.885 .473 .223 r
.47684 .80492 m .47737 .80782 L .47575 .80571 L F
.47684 .80492 m .47896 .80843 L .47737 .80782 L F
.68 .47 .596 r
.57413 .5818 m .57 .58404 L .57021 .58146 L F
.57413 .5818 m .57387 .58416 L .57 .58404 L F
.263 0 .282 r
.34448 .6315 m .34224 .63398 L .34259 .63211 L F
.792 .581 .615 r
.49153 .69022 m .49489 .69071 L .49511 .68822 L F
.838 .521 0 r
.67852 .5195 m .67821 .51752 L .677 .51675 L F
.537 .03 0 r
.67772 .5203 m .67854 .52036 L .67852 .5195 L F
.751 .4 0 r
.67852 .5195 m .67971 .52225 L .67894 .5203 L F
.196 .371 .812 r
.68059 .52052 m .67971 .52225 L .67852 .5195 L F
.537 .03 0 r
.67854 .52036 m .68059 .52052 L .67852 .5195 L F
.838 .521 0 r
.67852 .5195 m .67894 .5203 L .6785 .51863 L F
.67852 .5195 m .6785 .51863 L .67821 .51752 L F
.469 .494 .802 r
.55548 .75174 m .5557 .75257 L .55699 .75113 L F
.847 .545 .011 r
.5557 .75257 m .55618 .75485 L .55699 .75113 L F
.658 .721 .895 r
.45897 .65734 m .46063 .65758 L .46023 .65456 L F
.79 .813 .87 r
.46023 .65456 m .46063 .65758 L .46345 .65428 L F
.75 .578 .662 r
.47768 .77193 m .47975 .77242 L .48044 .76961 L F
.692 .565 .707 r
.47975 .77242 m .48338 .76964 L .48044 .76961 L F
.777 .699 .777 r
.58999 .68693 m .59159 .68877 L .58884 .68712 L F
0 .139 .618 r
.5926 .6894 m .59159 .68877 L .58999 .68693 L F
.5926 .6894 m .59359 .69032 L .59159 .68877 L F
.716 .363 .378 r
.662 .48033 m .66577 .48214 L .6651 .48004 L F
.663 .678 .853 r
.70798 .47953 m .70679 .48313 L .70582 .4804 L F
.70798 .47953 m .70943 .48189 L .70679 .48313 L F
.604 .467 .668 r
.37455 .67116 m .37691 .67113 L .37651 .66839 L F
.463 .409 .712 r
.37455 .67116 m .37692 .67323 L .37691 .67113 L F
.129 .11 .566 r
.73213 .51083 m .73113 .51441 L .73224 .51132 L F
.73213 .51083 m .73265 .51301 L .73113 .51441 L F
0 0 0 r
.73265 .51301 m .73015 .51571 L .73113 .51441 L F
.709 .839 .945 r
.63915 .47997 m .63552 .47791 L .63828 .47925 L F
.63915 .47997 m .63555 .4802 L .63552 .47791 L F
0 0 0 r
.6375 .4789 m .63674 .48023 L .63797 .47916 L F
.406 .245 .548 r
.63706 .47866 m .6375 .4789 L .63828 .47925 L F
.368 .837 .852 r
.6375 .4789 m .64035 .47803 L .63828 .47925 L F
0 0 0 r
.6375 .4789 m .63797 .47916 L .63914 .47814 L F
.406 .245 .548 r
.63552 .47791 m .6375 .4789 L .63706 .47866 L F
.407 .554 .89 r
.64035 .47803 m .63915 .47997 L .63828 .47925 L F
0 0 0 r
.62984 .49399 m .62747 .49704 L .62771 .49491 L F
.281 0 0 r
.43664 .70224 m .43518 .70349 L .43307 .7036 L F
.301 0 0 r
.43889 .70207 m .43518 .70349 L .43664 .70224 L F
.292 0 .283 r
.62042 .48902 m .62215 .49026 L .62247 .48797 L F
.62042 .48902 m .62015 .49116 L .62215 .49026 L F
.817 .766 .805 r
.25334 .65417 m .25343 .65615 L .25125 .6571 L F
.813 .999 .839 r
.25346 .65716 m .25125 .6571 L .25343 .65615 L F
0 0 .503 r
.25334 .65417 m .25419 .65594 L .25343 .65615 L F
0 0 .085 r
.25419 .65594 m .25346 .65716 L .25343 .65615 L F
.451 .481 .799 r
.51075 .64483 m .50898 .64644 L .50791 .64341 L F
.369 .36 .718 r
.51075 .64483 m .50973 .64868 L .50898 .64644 L F
0 0 0 r
.77957 .60312 m .77762 .60488 L .77662 .60582 L F
.457 .225 .474 r
.24467 .60094 m .24705 .59824 L .24475 .59854 L F
.693 .35 .39 r
.70248 .5027 m .69921 .50419 L .69926 .50326 L F
0 0 0 r
.69921 .50419 m .70186 .50166 L .69926 .50326 L F
.69921 .50419 m .70052 .50326 L .70186 .50166 L F
.454 .59 .899 r
.70186 .50166 m .70437 .50077 L .70116 .5002 L F
.799 .574 .597 r
.70052 .50326 m .70437 .50077 L .70186 .50166 L F
.622 .384 .536 r
.51125 .66577 m .50733 .66825 L .50725 .66583 L F
.917 .85 .762 r
.70019 .51996 m .69736 .52203 L .6996 .51982 L F
.70019 .51996 m .6987 .52327 L .69736 .52203 L F
.797 .811 .863 r
.70159 .51629 m .70019 .51996 L .6996 .51982 L F
.70159 .51629 m .70322 .51771 L .70019 .51996 L F
.758 .374 .327 r
.49091 .80292 m .48951 .80483 L .48748 .8025 L F
.763 .381 .33 r
.49091 .80292 m .49322 .80544 L .48951 .80483 L F
.546 .889 .984 r
.59071 .72689 m .58949 .72638 L .58731 .72716 L F
.619 .783 .96 r
.59071 .72689 m .5934 .7265 L .5914 .72448 L F
.617 .744 .937 r
.52939 .80788 m .53019 .80936 L .53235 .80861 L F
.502 .33 .58 r
.33351 .62063 m .33568 .61752 L .33378 .6182 L F
.882 .861 .815 r
.69736 .52203 m .6987 .52327 L .69674 .52414 L F
.422 .398 .727 r
.33752 .60989 m .33991 .61177 L .33912 .60815 L F
.484 .397 .681 r
.33752 .60989 m .33806 .61238 L .33991 .61177 L F
.181 .187 .629 r
.63017 .50463 m .63053 .50589 L .63026 .50606 L F
.713 .704 .841 r
.6786 .48357 m .68074 .48453 L .67998 .48393 L F
.44 .704 .978 r
.6786 .48357 m .68086 .48284 L .67904 .48297 L F
.67923 .48336 m .68185 .48443 L .68086 .48284 L F
.6786 .48357 m .67998 .48393 L .67923 .48336 L F
.67998 .48393 m .68185 .48443 L .67923 .48336 L F
.813 .787 .828 r
.67904 .48297 m .68019 .48539 L .6786 .48357 L F
.67922 .48336 m .67707 .48519 L .68019 .48539 L F
.6792 .48332 m .67919 .48333 L .67922 .48336 L F
.67919 .48333 m .67707 .48519 L .67922 .48336 L F
.67904 .48297 m .67892 .4831 L .6792 .48332 L F
.67892 .4831 m .67707 .48519 L .6792 .48332 L F
.713 .704 .841 r
.67998 .48393 m .68384 .48592 L .68185 .48443 L F
.68074 .48453 m .68384 .48592 L .67998 .48393 L F
.621 .763 .947 r
.68185 .48443 m .68384 .48592 L .68678 .48563 L F
.678 .776 .925 r
.77287 .61275 m .77657 .61321 L .77529 .61195 L F
.821 .828 .854 r
.77657 .61321 m .77769 .6093 L .77529 .61195 L F
.268 0 0 r
.44962 .68657 m .45346 .68495 L .45029 .68595 L F
.44962 .68657 m .45222 .68615 L .45346 .68495 L F
.555 .076 .074 r
.45222 .68615 m .45588 .68525 L .45346 .68495 L F
.681 .764 .914 r
.51208 .74134 m .51258 .74268 L .5158 .74202 L F
.742 .811 .907 r
.71277 .48169 m .70943 .48189 L .71142 .48002 L F
.743 .754 .861 r
.71478 .48032 m .71277 .48169 L .71142 .48002 L F
.797 .96 .637 r
.72079 .4931 m .72198 .49065 L .72334 .49208 L F
.717 .986 .885 r
.49798 .67011 m .49688 .6718 L .49949 .66991 L F
.138 .214 .68 r
.4965 .66935 m .49688 .6718 L .49798 .67011 L F
.909 .652 .536 r
.31044 .66904 m .309 .6708 L .30854 .66781 L F
0 0 0 r
.3105 .6699 m .31044 .66904 L .31064 .66751 L F
.3105 .6699 m .309 .6708 L .31044 .66904 L F
.335 .323 .698 r
.77285 .58432 m .77346 .58863 L .77497 .58587 L F
.575 .62 .86 r
.77346 .58863 m .7761 .58876 L .77497 .58587 L F
.766 .689 .777 r
.53635 .73585 m .54022 .73664 L .53882 .73619 L F
.435 0 0 r
.54249 .73624 m .53882 .73619 L .54022 .73664 L F
.815 .963 .904 r
.73134 .50898 m .73215 .50976 L .73594 .50637 L F
.981 .91 .6 r
.73596 .50627 m .73593 .50635 L .7359 .50632 L F
.69 .608 .759 r
.73853 .5081 m .73601 .50631 L .73949 .50666 L F
.73601 .50631 m .73596 .50627 L .73606 .50628 L F
.73601 .50631 m .73606 .50628 L .73949 .50666 L F
.743 .647 .754 r
.73844 .50344 m .73949 .50666 L .73609 .50628 L F
0 0 0 r
.73619 .50616 m .73604 .50633 L .73608 .50628 L F
.73618 .50617 m .73604 .50633 L .73619 .50616 L F
.743 .647 .754 r
.73688 .50522 m .73609 .50628 L .73596 .50627 L F
.73844 .50344 m .73609 .50628 L .73688 .50522 L F
0 0 0 r
.7362 .50614 m .73618 .50617 L .73619 .50616 L F
.815 .963 .904 r
.7359 .50632 m .73593 .50636 L .7362 .50614 L F
0 0 0 r
.73608 .50628 m .7348 .50786 L .73462 .50797 L F
.73604 .50633 m .7348 .50786 L .73608 .50628 L F
.864 .992 .827 r
.73215 .50976 m .7348 .50786 L .73613 .50623 L F
.73599 .50633 m .73613 .50623 L .7362 .50614 L F
.73215 .50976 m .73613 .50623 L .73599 .50633 L F
.867 .691 .662 r
.73705 .50924 m .73489 .50908 L .73591 .50638 L F
.815 .963 .904 r
.73134 .50898 m .73594 .50637 L .7359 .50632 L F
.945 .702 .539 r
.7312 .50388 m .73378 .50752 L .73288 .50218 L F
.522 .623 .893 r
.73604 .50607 m .73378 .50752 L .7312 .50388 L F
.73604 .50611 m .73378 .50752 L .73604 .50607 L F
.73613 .50618 m .73378 .50752 L .73608 .50609 L F
.815 .963 .904 r
.73134 .50898 m .7359 .50632 L .73449 .50539 L F
.522 .623 .893 r
.73608 .50609 m .73604 .50611 L .73604 .50607 L F
.7362 .50614 m .73613 .50618 L .73608 .50609 L F
.956 .932 .728 r
.73596 .50627 m .73601 .50606 L .73609 .50611 L F
.522 .623 .893 r
.73608 .50609 m .73604 .50607 L .73601 .50606 L F
.956 .932 .728 r
.73601 .50606 m .73603 .50598 L .73608 .50609 L F
.73601 .50606 m .73608 .50609 L .73609 .50611 L F
.522 .623 .893 r
.7362 .50614 m .73608 .50609 L .73594 .50602 L F
.956 .932 .728 r
.73596 .50627 m .73597 .50392 L .73603 .50598 L F
.522 .623 .893 r
.73608 .50609 m .73601 .50606 L .73594 .50602 L F
.815 .963 .904 r
.7359 .50632 m .7362 .50614 L .73589 .506 L F
.956 .932 .728 r
.73596 .50627 m .7359 .50618 L .73596 .50603 L F
.815 .963 .904 r
.73587 .50629 m .73589 .506 L .73449 .50539 L F
.7359 .50618 m .73589 .506 L .73587 .50629 L F
.956 .932 .728 r
.7359 .50618 m .73571 .50593 L .73594 .50602 L F
.7359 .50618 m .73594 .50602 L .73596 .50603 L F
.815 .963 .904 r
.7359 .50632 m .7359 .50618 L .73587 .50629 L F
.981 .91 .6 r
.7359 .50632 m .73456 .5075 L .73511 .50568 L F
.73533 .50577 m .73511 .50568 L .73514 .50558 L F
.7359 .50632 m .73511 .50568 L .73533 .50577 L F
.522 .623 .893 r
.73589 .506 m .7312 .50388 L .73449 .50539 L F
.73594 .50602 m .73591 .50601 L .73589 .506 L F
.73591 .50601 m .7312 .50388 L .73589 .506 L F
.73604 .50607 m .7312 .50388 L .73594 .50602 L F
.956 .932 .728 r
.73596 .50603 m .73523 .50527 L .73597 .50392 L F
.73571 .50593 m .73523 .50527 L .73596 .50603 L F
.73603 .50598 m .73597 .50392 L .73716 .50174 L F
.73609 .50611 m .73716 .50174 L .73844 .50344 L F
.73603 .50598 m .73716 .50174 L .73609 .50611 L F
.981 .91 .6 r
.73596 .50627 m .7359 .50632 L .73523 .50527 L F
.7359 .50632 m .73514 .50558 L .73523 .50527 L F
.867 .691 .662 r
.73593 .50637 m .73591 .50638 L .73593 .50635 L F
.73705 .50924 m .73591 .50638 L .73593 .50637 L F
.73598 .50633 m .73593 .50635 L .73596 .50627 L F
.815 .963 .904 r
.73593 .50636 m .73594 .50637 L .73599 .50633 L F
.73593 .50636 m .73599 .50633 L .73595 .50634 L F
.867 .691 .662 r
.73705 .50924 m .73593 .50635 L .73598 .50633 L F
.69 .608 .759 r
.73853 .5081 m .73705 .50924 L .73598 .50633 L F
.73601 .50631 m .73598 .50633 L .73596 .50627 L F
.815 .963 .904 r
.73601 .50631 m .73599 .50633 L .73602 .5063 L F
.73598 .50633 m .73599 .50633 L .73601 .50631 L F
.69 .608 .759 r
.73853 .5081 m .73598 .50633 L .73601 .50631 L F
.815 .963 .904 r
.73595 .50634 m .73598 .50633 L .73601 .50631 L F
.73593 .50636 m .73602 .5063 L .7362 .50614 L F
.981 .91 .6 r
.7359 .50632 m .73579 .5067 L .73456 .5075 L F
.73593 .50635 m .73579 .5067 L .7359 .50632 L F
.73579 .5067 m .73489 .50908 L .73472 .50828 L F
.73579 .5067 m .73472 .50828 L .73456 .5075 L F
.522 0 0 r
.57524 .68729 m .57815 .68888 L .57876 .68819 L F
.631 .406 .557 r
.57815 .68888 m .57994 .68659 L .57876 .68819 L F
.502 .816 1 r
.58218 .69021 m .5799 .69085 L .57876 .68819 L F
.564 .451 .684 r
.37611 .66571 m .37871 .66793 L .37811 .66519 L F
.37611 .66571 m .37651 .66839 L .37871 .66793 L F
.768 .705 .792 r
.65128 .52301 m .6546 .52373 L .65334 .52198 L F
.069 0 0 r
.32431 .64555 m .32076 .64796 L .32222 .64609 L F
.459 .253 .511 r
.37829 .66286 m .38031 .66234 L .38054 .65982 L F
.408 .196 .477 r
.38031 .66234 m .38252 .65915 L .38054 .65982 L F
.199 .725 .835 r
.30125 .63361 m .30323 .63336 L .30509 .63343 L F
0 .374 .796 r
.30531 .63307 m .30509 .63343 L .30323 .63336 L F
.30531 .63307 m .3069 .63425 L .30509 .63343 L F
.65 .846 .975 r
.38459 .70827 m .38433 .70917 L .38696 .70747 L F
0 0 0 r
.4925 .78599 m .49269 .78589 L .4926 .78603 L F
.49186 .7879 m .4925 .78599 L .49258 .78602 L F
.4925 .78599 m .4926 .78603 L .49259 .78604 L F
.49258 .78602 m .4925 .78599 L .49264 .78586 L F
.4925 .78599 m .49259 .78604 L .49264 .78586 L F
.906 .598 .107 r
.49237 .78565 m .49264 .78586 L .49259 .78604 L F
.49151 .78405 m .4924 .78548 L .49237 .78565 L F
.4924 .78548 m .49264 .78586 L .49237 .78565 L F
.224 0 0 r
.49147 .78829 m .49218 .78681 L .49024 .78728 L F
0 0 0 r
.49186 .7879 m .49258 .78602 L .49352 .78739 L F
.49269 .78589 m .4927 .78596 L .49261 .78601 L F
.49258 .78602 m .49264 .78586 L .4927 .78596 L F
.49258 .78602 m .4927 .78596 L .49352 .78739 L F
.49261 .78601 m .4927 .78597 L .49259 .78604 L F
.4927 .78596 m .4927 .78597 L .49261 .78601 L F
.638 .132 .029 r
.49259 .78604 m .49278 .78611 L .49352 .78739 L F
.632 .222 0 r
.49352 .78739 m .4927 .78596 L .49271 .78598 L F
.638 .132 .029 r
.49278 .78611 m .49757 .7878 L .49352 .78739 L F
.632 .222 0 r
.49352 .78739 m .49271 .78598 L .49272 .78606 L F
0 0 .456 r
.49272 .78606 m .49259 .78604 L .49352 .78739 L F
.49151 .78405 m .49237 .78565 L .49248 .78577 L F
.89 .844 .793 r
.49024 .78728 m .49248 .78577 L .49151 .78405 L F
.49248 .78577 m .49254 .78573 L .49151 .78405 L F
0 0 0 r
.49269 .78589 m .49391 .78524 L .4927 .78597 L F
.49342 .78586 m .49277 .78557 L .49262 .78588 L F
.49291 .78649 m .49262 .78588 L .49147 .78829 L F
.632 .222 0 r
.49272 .78606 m .49268 .78596 L .49259 .78581 L F
.49272 .78606 m .49259 .78581 L .49266 .78596 L F
.4927 .78596 m .49264 .78586 L .49272 .78606 L F
.638 .132 .029 r
.49259 .78604 m .49391 .78524 L .49757 .7878 L F
0 0 0 r
.49342 .78586 m .49262 .78588 L .49291 .78649 L F
.632 .222 0 r
.49266 .78596 m .49259 .78581 L .49151 .78405 L F
.49268 .78596 m .49264 .78586 L .49151 .78405 L F
.89 .844 .793 r
.49254 .78573 m .49277 .78557 L .49151 .78405 L F
0 0 .456 r
.49151 .78405 m .49248 .78577 L .49272 .78606 L F
.49237 .78565 m .49259 .78604 L .49272 .78606 L F
.224 0 0 r
.49218 .78681 m .4926 .78592 L .49234 .78586 L F
.4926 .78592 m .49277 .78557 L .49248 .78577 L F
.4926 .78592 m .49248 .78577 L .49234 .78586 L F
.49218 .78681 m .49234 .78586 L .49024 .78728 L F
.55 .277 .455 r
.49391 .78524 m .49677 .78614 L .49757 .7878 L F
0 0 0 r
.61589 .5203 m .61489 .52217 L .61328 .52329 L F
.58 .513 .745 r
.61489 .52217 m .61324 .52504 L .61328 .52329 L F
.876 .735 .703 r
.71487 .48517 m .71565 .48952 L .71804 .48594 L F
.826 .657 .673 r
.71804 .48594 m .71565 .48952 L .71751 .4892 L F
.452 .25 .513 r
.37811 .66519 m .38031 .66234 L .37829 .66286 L F
.62 .285 .382 r
.54712 .75551 m .5441 .75718 L .54585 .75467 L F
.54712 .75551 m .54645 .75753 L .5441 .75718 L F
.659 .325 .396 r
.54712 .75551 m .54978 .75748 L .54645 .75753 L F
.464 0 0 r
.4187 .64993 m .4207 .65039 L .42227 .64977 L F
.418 0 0 r
.4207 .65039 m .42459 .64948 L .42227 .64977 L F
.618 .288 .39 r
.46638 .69085 m .46512 .69327 L .46276 .69308 L F
.569 .236 .364 r
.46963 .69236 m .46512 .69327 L .46638 .69085 L F
.613 .861 .506 r
.46911 .78842 m .46642 .79189 L .46855 .79065 L F
.391 .317 .653 r
.46642 .79189 m .46928 .79409 L .46855 .79065 L F
.46642 .79189 m .46759 .7943 L .46928 .79409 L F
.639 .409 .554 r
.59559 .58731 m .59543 .58951 L .59223 .58996 L F
.573 .316 .488 r
.59799 .58716 m .59543 .58951 L .59559 .58731 L F
.802 .737 .791 r
.63566 .53629 m .63345 .53923 L .63421 .53703 L F
.27 0 0 r
.27314 .58494 m .27481 .5853 L .27672 .58475 L F
.127 0 0 r
.27481 .5853 m .27876 .58425 L .27672 .58475 L F
.221 0 0 r
.31239 .60091 m .31115 .6013 L .30886 .6013 L F
.076 0 0 r
.31467 .6005 m .31115 .6013 L .31239 .60091 L F
.583 .046 0 r
.54367 .72737 m .546 .72872 L .54694 .72789 L F
.699 .188 .015 r
.546 .72872 m .5493 .72979 L .54694 .72789 L F
.703 .224 .109 r
.54694 .72789 m .5493 .72979 L .5509 .72957 L F
.986 .716 .419 r
.55816 .78078 m .55886 .78357 L .55791 .78342 L F
.549 0 0 r
.55791 .78342 m .55886 .78357 L .56001 .78438 L F
.182 .713 .839 r
.32008 .60014 m .3167 .60028 L .31808 .60089 L F
.489 .299 .549 r
.68542 .50531 m .68772 .50755 L .68774 .50471 L F
.5 .805 .999 r
.30709 .58654 m .30657 .58783 L .305 .58669 L F
.30709 .58654 m .30857 .58745 L .30657 .58783 L F
.707 .835 .943 r
.50867 .80634 m .50879 .80641 L .50857 .80637 L F
.839 .533 .47 r
.50463 .80561 m .50879 .80641 L .50792 .80771 L F
.947 .71 .547 r
.50879 .80641 m .50867 .80634 L .50792 .80771 L F
.611 .19 .218 r
.50867 .80634 m .51057 .80761 L .50792 .80771 L F
.947 .71 .547 r
.50879 .80641 m .50921 .80537 L .50867 .80634 L F
.229 .684 .951 r
.50911 .80626 m .50921 .80537 L .50879 .80641 L F
.611 .19 .218 r
.50921 .80537 m .50962 .80605 L .50911 .80621 L F
.229 .684 .951 r
.5114 .80517 m .51155 .80571 L .50921 .80537 L F
.611 .19 .218 r
.50921 .80537 m .51155 .80571 L .51131 .80618 L F
.50969 .80616 m .51131 .80618 L .51057 .80761 L F
.50921 .80537 m .51131 .80618 L .50969 .80616 L F
.229 .684 .951 r
.5114 .80517 m .50921 .80537 L .50911 .80626 L F
.611 .799 .972 r
.5114 .80517 m .50933 .80616 L .50711 .80458 L F
.611 .19 .218 r
.50921 .80537 m .50911 .80621 L .50871 .80633 L F
.50868 .80633 m .50871 .80633 L .50867 .80634 L F
.50921 .80537 m .50871 .80633 L .50868 .80633 L F
.611 .799 .972 r
.50933 .80616 m .50911 .80626 L .50855 .80615 L F
.50911 .80626 m .50879 .80641 L .50871 .80633 L F
.50911 .80626 m .50871 .80633 L .50855 .80615 L F
.50933 .80616 m .50855 .80615 L .50711 .80458 L F
.611 .19 .218 r
.50962 .80605 m .51057 .80761 L .50867 .80634 L F
.707 .835 .943 r
.50635 .80489 m .50867 .80634 L .50463 .80561 L F
.50867 .80634 m .50857 .80637 L .50463 .80561 L F
.50711 .80458 m .50879 .80641 L .50635 .80489 L F
.322 .809 .851 r
.71659 .51888 m .71499 .51948 L .71739 .51917 L F
.71659 .51888 m .71424 .51949 L .71499 .51948 L F
.848 .997 .768 r
.6497 .51681 m .65122 .51377 L .65191 .51454 L F
.6497 .51681 m .64921 .51632 L .65122 .51377 L F
.336 .76 .974 r
.33874 .59105 m .33646 .59126 L .33477 .59045 L F
.603 .405 .586 r
.51788 .75242 m .51509 .75528 L .51513 .75274 L F
.51788 .75242 m .51802 .75486 L .51509 .75528 L F
.088 .03 .49 r
.51513 .75274 m .51636 .7543 L .51788 .75242 L F
.51513 .75274 m .51509 .75528 L .51636 .7543 L F
.374 0 0 r
.46892 .68424 m .47154 .68425 L .47346 .68329 L F
.192 0 0 r
.47346 .68329 m .47394 .68378 L .47556 .68321 L F
.47346 .68329 m .47154 .68425 L .47394 .68378 L F
.846 .719 .723 r
.67033 .50567 m .6714 .50876 L .67192 .50646 L F
.369 .36 .718 r
.51075 .64483 m .51129 .64841 L .50973 .64868 L F
.877 .949 .595 r
.6701 .50994 m .66991 .51172 L .6714 .50876 L F
.758 .44 0 r
.67033 .50567 m .67081 .50745 L .6714 .50876 L F
.973 .906 .561 r
.67081 .50745 m .6701 .50994 L .6714 .50876 L F
.609 .09 0 r
.52985 .76251 m .53016 .76267 L .52826 .76128 L F
.501 .215 .412 r
.52826 .76128 m .53016 .76267 L .53053 .76085 L F
.987 .771 .378 r
.66684 .49098 m .66675 .49336 L .66753 .49199 L F
.897 .94 .831 r
.66905 .48813 m .66684 .49098 L .66753 .49199 L F
.987 .771 .378 r
.66684 .49098 m .66675 .49336 L .66753 .49199 L F
.519 .317 .545 r
.40616 .67357 m .40385 .67645 L .40422 .67418 L F
.454 .612 .916 r
.75153 .60869 m .75198 .61009 L .75341 .60844 L F
.457 .615 .918 r
.75198 .61009 m .75423 .61027 L .75341 .60844 L F
.61 .136 .103 r
.68588 .53156 m .68217 .53115 L .68459 .53043 L F
.629 .845 .982 r
.68687 .53008 m .68588 .53156 L .68459 .53043 L F
.68687 .53008 m .68792 .53107 L .68588 .53156 L F
0 0 .241 r
.6702 .51354 m .66991 .51172 L .6701 .50994 L F
.548 .281 .462 r
.62998 .49197 m .63316 .49367 L .62984 .49399 L F
.543 .423 .667 r
.55985 .76705 m .55923 .7694 L .56144 .76896 L F
.55985 .76705 m .55923 .7694 L .56144 .76896 L F
.859 .849 .832 r
.60525 .54429 m .60887 .54247 L .60766 .54107 L F
.617 .752 .942 r
.60766 .54107 m .60887 .54247 L .61117 .54161 L F
.518 .374 .625 r
.60887 .54247 m .61137 .54418 L .61117 .54161 L F
.723 .774 .893 r
.28982 .64856 m .29359 .64885 L .29176 .64997 L F
.102 0 0 r
.29359 .64885 m .2937 .6497 L .29176 .64997 L F
.29359 .64885 m .2957 .64833 L .2937 .6497 L F
0 0 .136 r
.49246 .74914 m .49177 .75108 L .49021 .75185 L F
0 0 .133 r
.49177 .75108 m .48991 .75422 L .49021 .75185 L F
.029 0 .032 r
.55064 .74409 m .55233 .74351 L .55316 .74154 L F
.763 .376 .321 r
.55535 .74095 m .55152 .73916 L .55316 .74154 L F
.653 .269 .305 r
.55316 .74154 m .55233 .74351 L .55532 .74336 L F
.509 .32 .56 r
.55316 .74154 m .55532 .74336 L .55535 .74095 L F
.685 .281 .273 r
.75256 .58256 m .75481 .58396 L .75729 .58105 L F
.898 .949 .829 r
.75256 .58256 m .75234 .58465 L .75161 .58368 L F
.639 .46 .625 r
.75161 .58368 m .75461 .58474 L .75256 .58256 L F
.685 .281 .273 r
.75481 .58396 m .7553 .58426 L .75539 .58412 L F
.75481 .58396 m .75539 .58412 L .75729 .58105 L F
.416 .452 .79 r
.75554 .583 m .75536 .58398 L .75256 .58256 L F
.75536 .58398 m .7553 .58426 L .7552 .58419 L F
.75536 .58398 m .7552 .58419 L .75256 .58256 L F
.75557 .58314 m .75256 .58256 L .75461 .58474 L F
.75554 .583 m .75256 .58256 L .75557 .58314 L F
.75558 .58316 m .7553 .58426 L .75554 .583 L F
.7556 .58316 m .7553 .58426 L .75562 .58302 L F
.458 .591 .898 r
.75445 .58212 m .75461 .58474 L .75161 .58368 L F
.708 .792 .917 r
.75513 .58264 m .75461 .58474 L .75445 .58212 L F
.192 0 .005 r
.75729 .58105 m .75545 .58402 L .75919 .58111 L F
.75545 .58402 m .7553 .58426 L .7557 .58394 L F
.75545 .58402 m .7557 .58394 L .75919 .58111 L F
.511 .647 .918 r
.7561 .58381 m .75827 .58305 L .75585 .58346 L F
.75682 .58486 m .75824 .5831 L .7561 .58381 L F
.75824 .5831 m .75827 .58305 L .7561 .58381 L F
.899 .95 .828 r
.75671 .58312 m .7553 .58426 L .75559 .5832 L F
.745 .99 .796 r
.75568 .58355 m .75585 .58346 L .75572 .58319 L F
.75559 .5832 m .75572 .58319 L .75547 .58272 L F
.75568 .58355 m .75572 .58319 L .75559 .5832 L F
.899 .95 .828 r
.75919 .58111 m .75576 .58303 L .75578 .58294 L F
.75671 .58312 m .75559 .5832 L .75564 .58302 L F
.75919 .58111 m .75578 .58294 L .75791 .58185 L F
.75919 .58111 m .75671 .58312 L .75576 .58303 L F
.591 .569 .798 r
.75585 .58346 m .75791 .58185 L .75596 .58285 L F
.899 .95 .828 r
.75578 .58294 m .75564 .58302 L .75791 .58185 L F
.591 .569 .798 r
.75596 .58285 m .75791 .58185 L .75619 .5815 L F
.75572 .58319 m .75619 .5815 L .75468 .58119 L F
.75585 .58346 m .75619 .5815 L .75572 .58319 L F
.899 .95 .828 r
.75578 .58294 m .75576 .58303 L .75564 .58302 L F
.416 .452 .79 r
.75562 .58302 m .75558 .58316 L .75554 .583 L F
.75564 .58302 m .75554 .583 L .75557 .58314 L F
.745 .99 .796 r
.75568 .58355 m .75547 .58272 L .75468 .58119 L F
.708 .792 .917 r
.75564 .58302 m .75557 .58314 L .75513 .58264 L F
.75557 .58314 m .75461 .58474 L .75513 .58264 L F
.745 .99 .796 r
.75392 .58441 m .75564 .58356 L .75538 .58292 L F
.75513 .58264 m .75538 .58292 L .75468 .58119 L F
.75564 .58356 m .75561 .58338 L .75468 .58119 L F
.708 .792 .917 r
.75564 .58302 m .75513 .58264 L .75468 .58119 L F
.75513 .58264 m .75445 .58212 L .75468 .58119 L F
.745 .99 .796 r
.75451 .58192 m .75513 .58264 L .75468 .58119 L F
.75392 .58441 m .75538 .58292 L .75451 .58192 L F
.75564 .58356 m .75568 .58355 L .75561 .58338 L F
.75392 .58441 m .75384 .5852 L .75544 .58382 L F
.75549 .58375 m .75544 .58382 L .75554 .58373 L F
.75392 .58441 m .75544 .58382 L .75549 .58375 L F
.75568 .58355 m .75554 .58373 L .75585 .58346 L F
.75392 .58441 m .75554 .58373 L .75568 .58355 L F
.416 .452 .79 r
.75564 .58302 m .7556 .58316 L .75562 .58302 L F
.844 .839 .841 r
.75585 .58346 m .75554 .58373 L .75682 .58486 L F
.75554 .58373 m .75384 .5852 L .7554 .58502 L F
.75554 .58373 m .7554 .58502 L .75682 .58486 L F
.458 .591 .898 r
.75445 .58212 m .75236 .58327 L .74984 .58218 L F
.75236 .58327 m .75161 .58368 L .75051 .58275 L F
.75236 .58327 m .75051 .58275 L .74984 .58218 L F
.22 0 .254 r
.75729 .58105 m .75919 .58111 L .75945 .57874 L F
.762 .522 .57 r
.53864 .76933 m .53857 .77197 L .53611 .77123 L F
.707 .475 .571 r
.54163 .77153 m .53857 .77197 L .53864 .76933 L F
.461 .026 .125 r
.40142 .65406 m .40479 .65318 L .40515 .65227 L F
.492 .055 .137 r
.40479 .65318 m .40694 .65329 L .40515 .65227 L F
.734 .625 .737 r
.60257 .56757 m .60236 .56515 L .60012 .56783 L F
.673 .498 .64 r
.60011 .57024 m .60257 .56757 L .60012 .56783 L F
.60011 .57024 m .60328 .57054 L .60257 .56757 L F
.622 .474 .66 r
.60257 .56757 m .60467 .56462 L .60236 .56515 L F
.60257 .56757 m .60553 .56762 L .60467 .56462 L F
.622 .481 .669 r
.60556 .57008 m .60257 .56757 L .60328 .57054 L F
.60556 .57008 m .60553 .56762 L .60257 .56757 L F
.157 .652 .915 r
.51127 .69938 m .50761 .69853 L .50889 .69939 L F
.72 .902 .96 r
.52085 .81132 m .52212 .81214 L .52411 .81099 L F
.669 .812 .951 r
.68492 .47846 m .68235 .47962 L .68171 .47811 L F
.119 .669 .787 r
.27876 .58425 m .28082 .5841 L .2824 .58413 L F
.027 .599 .72 r
.28082 .5841 m .28444 .58404 L .2824 .58413 L F
.432 .237 .514 r
.24065 .60689 m .24258 .60612 L .24285 .60403 L F
.438 .313 .613 r
.24089 .60948 m .24258 .60612 L .24065 .60689 L F
0 0 0 r
.52902 .77631 m .5287 .77594 L .52712 .77613 L F
.52902 .77631 m .53067 .77533 L .5287 .77594 L F
.627 .593 .795 r
.511 .67118 m .50857 .67158 L .50733 .66825 L F
.107 .28 .758 r
.50857 .67158 m .50939 .67007 L .50761 .66976 L F
.975 .704 .454 r
.511 .67118 m .51071 .67331 L .50857 .67158 L F
.107 .28 .758 r
.50857 .67158 m .51071 .67331 L .50939 .67007 L F
.589 .87 .994 r
.48095 .79889 m .47775 .80008 L .47651 .79927 L F
.662 .315 .374 r
.47755 .69125 m .47997 .69333 L .47775 .69272 L F
.665 .458 .595 r
.5335 .73552 m .53635 .73585 L .53665 .73298 L F
.257 .11 .481 r
.53665 .73298 m .53849 .73453 L .5384 .73245 L F
.53665 .73298 m .53635 .73585 L .53849 .73453 L F
.378 0 0 r
.43876 .66197 m .43866 .66274 L .43597 .66267 L F
0 0 0 r
.44165 .65984 m .44031 .66143 L .43876 .66197 L F
.44031 .66143 m .43866 .66274 L .43876 .66197 L F
.986 .716 .419 r
.55816 .78078 m .55791 .78342 L .55676 .78259 L F
.694 .237 .162 r
.48222 .68794 m .48441 .68983 L .4857 .68845 L F
.782 .353 .231 r
.48441 .68983 m .4867 .69038 L .4857 .68845 L F
.757 .512 .563 r
.4867 .69038 m .48835 .68809 L .4857 .68845 L F
.774 .994 .875 r
.7061 .5244 m .70943 .52255 L .70895 .52228 L F
.744 .993 .831 r
.71065 .52066 m .70943 .52255 L .71244 .52089 L F
.71065 .52066 m .70895 .52228 L .70943 .52255 L F
.782 .943 .597 r
.60404 .52011 m .60205 .52307 L .60278 .5213 L F
.661 .846 .441 r
.60598 .51704 m .60404 .52011 L .605 .51838 L F
.711 .922 .584 r
.60404 .52011 m .60278 .5213 L .605 .51838 L F
.162 .695 .85 r
.63235 .50244 m .63132 .50226 L .63471 .50232 L F
.593 .873 .993 r
.63806 .50512 m .63713 .50447 L .6359 .50598 L F
0 0 0 r
.63713 .50447 m .6351 .50752 L .6359 .50598 L F
.16 0 0 r
.63959 .50083 m .64188 .50114 L .64048 .50049 L F
0 0 .223 r
.60598 .51704 m .60739 .51567 L .60779 .51353 L F
0 0 0 r
.60598 .51704 m .605 .51838 L .60739 .51567 L F
.49 .284 .526 r
.54834 .74699 m .54985 .74802 L .55064 .74409 L F
0 0 .064 r
.55064 .74409 m .55108 .74508 L .55233 .74351 L F
.55064 .74409 m .54985 .74802 L .55108 .74508 L F
.537 .787 .99 r
.70523 .4907 m .70705 .48929 L .70455 .48988 L F
.70523 .4907 m .70792 .49021 L .70705 .48929 L F
.503 .339 .591 r
.54834 .74699 m .55058 .74939 L .54985 .74802 L F
.54834 .74699 m .54841 .75033 L .55058 .74939 L F
.433 .493 .821 r
.26773 .64819 m .26791 .64514 L .26574 .64576 L F
.26773 .64819 m .26983 .64862 L .26791 .64514 L F
.798 .307 .022 r
.55064 .73831 m .54889 .73778 L .54811 .7363 L F
.833 .403 .214 r
.55152 .73916 m .54889 .73778 L .55064 .73831 L F
.675 .386 .476 r
.45018 .65757 m .44976 .65957 L .44835 .65937 L F
.285 .037 .351 r
.45135 .65859 m .45018 .65757 L .45245 .65702 L F
.45135 .65859 m .44976 .65957 L .45018 .65757 L F
.595 .115 0 r
.49557 .76363 m .4973 .76579 L .49792 .76635 L F
.654 .104 0 r
.49816 .76777 m .49792 .76635 L .4973 .76579 L F
.49816 .76777 m .50116 .76855 L .49792 .76635 L F
.257 0 0 r
.29373 .58531 m .2957 .58575 L .29739 .58578 L F
.258 .763 .874 r
.2957 .58575 m .29957 .58553 L .29739 .58578 L F
.648 .572 .756 r
.47586 .76092 m .47865 .76219 L .47766 .76012 L F
.692 .454 .557 r
.48835 .68809 m .49153 .69022 L .49149 .68869 L F
.215 .689 .938 r
.4658 .68392 m .46892 .68424 L .46756 .68371 L F
0 0 0 r
.48569 .75587 m .48234 .75739 L .48333 .75512 L F
.112 .372 .833 r
.51314 .78881 m .51208 .78871 L .51001 .78608 L F
.823 .811 .839 r
.70337 .51588 m .70322 .51771 L .70159 .51629 L F
.388 .343 .686 r
.52342 .76322 m .52453 .7631 L .52235 .7609 L F
.575 .149 .195 r
.47206 .6908 m .47068 .69257 L .46963 .69236 L F
.654 .24 .248 r
.47423 .6925 m .47068 .69257 L .47206 .6908 L F
.556 .46 .701 r
.40385 .67645 m .40208 .67907 L .40181 .67691 L F
.344 .418 .794 r
.7448 .60114 m .74621 .60064 L .74356 .59896 L F
.726 .713 .838 r
.55416 .76407 m .55794 .76373 L .55676 .76132 L F
.599 .2 .257 r
.55696 .76559 m .55794 .76373 L .55416 .76407 L F
.272 .454 .858 r
.55676 .76132 m .55794 .76373 L .55919 .76266 L F
0 0 0 r
.55919 .76266 m .55794 .76373 L .55696 .76559 L F
.435 0 0 r
.67185 .51424 m .6727 .51428 L .6702 .51354 L F
.274 .779 .799 r
.67408 .51376 m .6727 .51428 L .67185 .51424 L F
.67408 .51376 m .6752 .51364 L .6727 .51428 L F
.866 .449 .004 r
.63507 .51886 m .63475 .51755 L .63358 .51688 L F
.611 .546 .757 r
.48906 .66255 m .49001 .66609 L .49229 .66555 L F
.895 .983 .713 r
.60205 .52307 m .60036 .52565 L .60048 .52412 L F
.803 .984 .716 r
.60205 .52307 m .60048 .52412 L .60278 .5213 L F
0 0 .385 r
.25649 .65056 m .25551 .64867 L .25752 .64782 L F
.25649 .65056 m .256 .65176 L .25551 .64867 L F
.763 .663 .753 r
.48338 .76964 m .48149 .77251 L .48379 .77203 L F
.511 .366 .621 r
.48379 .77203 m .48582 .76904 L .48338 .76964 L F
.48379 .77203 m .48613 .77193 L .48582 .76904 L F
0 0 .354 r
.48379 .77203 m .48469 .7736 L .48613 .77193 L F
.48379 .77203 m .48387 .77527 L .48469 .7736 L F
.993 .828 .576 r
.66059 .51142 m .66012 .50803 L .66082 .50891 L F
.628 .476 .657 r
.57194 .72838 m .57411 .72852 L .57004 .72703 L F
.57194 .72838 m .57354 .72986 L .57411 .72852 L F
.975 .74 .517 r
.54932 .71287 m .55049 .71605 L .54908 .71538 L F
0 .182 .701 r
.55123 .71492 m .55049 .71605 L .54932 .71287 L F
.468 .827 .995 r
.54908 .71538 m .55049 .71605 L .55123 .71492 L F
0 .087 .646 r
.55049 .71605 m .5514 .71737 L .55286 .71589 L F
.798 .964 .914 r
.64135 .49185 m .64233 .48948 L .64307 .4885 L F
.321 .449 .835 r
.64307 .4885 m .64519 .48771 L .64261 .48641 L F
.237 0 0 r
.42459 .64948 m .42645 .64979 L .42788 .64942 L F
.055 0 0 r
.42645 .64979 m .43005 .64882 L .42788 .64942 L F
.582 .559 .794 r
.63708 .50245 m .64074 .50419 L .63959 .50083 L F
.16 0 0 r
.63959 .50083 m .64245 .50133 L .64188 .50114 L F
.582 .559 .794 r
.63857 .50316 m .63806 .50512 L .64074 .50419 L F
.63708 .50245 m .6375 .50361 L .63857 .50316 L F
.6375 .50361 m .63806 .50512 L .63857 .50316 L F
.31 0 .254 r
.63959 .50083 m .63941 .5028 L .64245 .50133 L F
.63941 .5028 m .63933 .50378 L .64197 .5017 L F
.63941 .5028 m .64197 .5017 L .64245 .50133 L F
.676 .79 .935 r
.6965 .47979 m .69534 .48159 L .69413 .48044 L F
.6965 .47979 m .69749 .48105 L .69534 .48159 L F
.782 .958 .925 r
.74297 .58622 m .73976 .58971 L .7401 .58856 L F
.74297 .58622 m .74378 .58688 L .73976 .58971 L F
.946 .594 .204 r
.47718 .79698 m .47672 .79472 L .47555 .79374 L F
.298 .749 .958 r
.50305 .6254 m .50668 .62577 L .50458 .62592 L F
.50305 .6254 m .50668 .62577 L .50458 .62592 L F
.668 .654 .827 r
.48183 .65948 m .48306 .66265 L .48558 .66025 L F
.716 .846 .944 r
.4977 .63488 m .49426 .63495 L .49638 .63399 L F
.4977 .63488 m .49513 .63556 L .49426 .63495 L F
.657 .665 .847 r
.4984 .63436 m .4977 .63488 L .49638 .63399 L F
.4984 .63436 m .49744 .63729 L .4977 .63488 L F
.798 .628 .671 r
.61183 .53336 m .6102 .53639 L .61371 .53671 L F
.784 .711 .783 r
.6102 .53639 m .61011 .54009 L .61371 .53671 L F
.51 .543 .826 r
.28299 .63045 m .28107 .63101 L .27965 .62813 L F
.229 0 0 r
.25401 .59237 m .25601 .59189 L .25742 .59034 L F
.221 0 0 r
.25601 .59189 m .25941 .58977 L .25742 .59034 L F
.641 .825 .408 r
.62791 .53182 m .6276 .53218 L .62795 .52995 L F
.675 .965 .932 r
.64704 .51414 m .6493 .51307 L .64901 .51264 L F
.645 .837 .974 r
.64901 .51264 m .6493 .51307 L .6523 .51216 L F
.609 .783 .964 r
.29901 .63399 m .29578 .63364 L .29787 .63321 L F
.118 0 0 r
.29787 .63321 m .30125 .63361 L .29901 .63399 L F
.007 .034 .537 r
.51338 .69365 m .51391 .6906 L .51562 .69076 L F
.642 .479 .646 r
.51562 .69076 m .51597 .6936 L .51338 .69365 L F
.829 .928 .898 r
.51562 .69076 m .51391 .6906 L .51572 .68868 L F
.512 .385 .644 r
.51812 .69303 m .51562 .69076 L .51829 .69049 L F
.51812 .69303 m .51597 .6936 L .51562 .69076 L F
.046 0 .387 r
.75945 .57874 m .76139 .57505 L .76188 .57577 L F
.75945 .57874 m .7612 .57736 L .76139 .57505 L F
.145 0 .234 r
.75945 .57874 m .76114 .57956 L .7612 .57736 L F
.75945 .57874 m .75919 .58111 L .76114 .57956 L F
.549 .5 .753 r
.55464 .74768 m .55548 .75174 L .55732 .74943 L F
.55422 .7474 m .55732 .74943 L .55659 .74706 L F
.427 .394 .719 r
.55659 .74706 m .55732 .74943 L .55894 .74864 L F
.243 0 .001 r
.5571 .74802 m .55521 .74921 L .55649 .7472 L F
.55664 .74716 m .55649 .7472 L .55659 .74706 L F
.5571 .74802 m .55649 .7472 L .55664 .74716 L F
.549 .5 .753 r
.55422 .7474 m .55432 .74776 L .55464 .74768 L F
.55432 .74776 m .55548 .75174 L .55464 .74768 L F
.469 .494 .802 r
.55548 .75174 m .55699 .75113 L .55732 .74943 L F
0 0 0 r
.66311 .48927 m .66366 .48922 L .66411 .4887 L F
.967 .915 .704 r
.66487 .48541 m .66411 .4887 L .66729 .48875 L F
.66487 .48541 m .66311 .48927 L .66411 .4887 L F
.979 .819 .614 r
.66571 .48994 m .66411 .4887 L .66366 .48922 L F
.66571 .48994 m .66729 .48875 L .66411 .4887 L F
.419 .157 .408 r
.3629 .61655 m .36162 .61414 L .36185 .61277 L F
.49 .227 .442 r
.36601 .6114 m .36185 .61277 L .36393 .61193 L F
.36601 .6114 m .36578 .61271 L .36185 .61277 L F
.333 .124 .439 r
.36464 .61558 m .36185 .61277 L .36578 .61271 L F
.36464 .61558 m .3629 .61655 L .36185 .61277 L F
.491 .232 .449 r
.36393 .61193 m .36578 .61271 L .36185 .61277 L F
0 0 .469 r
.48478 .77746 m .48469 .7736 L .48387 .77527 L F
0 .513 .78 r
.48493 .81104 m .48511 .81095 L .48265 .8107 L F
.75 .993 .81 r
.75846 .58483 m .75787 .58658 L .76088 .58434 L F
.75846 .58483 m .75763 .5862 L .75787 .58658 L F
.738 .682 .797 r
.64029 .52487 m .64083 .52847 L .63734 .52801 L F
.756 .626 .716 r
.64083 .52847 m .6387 .53132 L .63734 .52801 L F
.286 .417 .819 r
.74356 .59896 m .74482 .59779 L .74312 .59743 L F
.74356 .59896 m .74621 .60064 L .74482 .59779 L F
.772 .99 .888 r
.76334 .57342 m .76188 .57577 L .76139 .57505 L F
.76334 .57342 m .76417 .57382 L .76188 .57577 L F
.561 .664 .906 r
.66747 .53087 m .66846 .52782 L .66573 .52993 L F
.66747 .53087 m .67024 .53029 L .66846 .52782 L F
0 0 .057 r
.62145 .57789 m .61967 .58094 L .61962 .57881 L F
.055 0 0 r
.62368 .52634 m .62275 .5258 L .62479 .52519 L F
.62368 .52634 m .62152 .52709 L .62275 .5258 L F
.709 .785 .911 r
.7046 .50036 m .70116 .5002 L .70437 .50077 L F
.781 .967 .666 r
.7072 .50026 m .7046 .50036 L .7067 .49989 L F
.7072 .50026 m .70437 .50077 L .7046 .50036 L F
.553 .533 .787 r
.27906 .62626 m .27965 .62813 L .27699 .62669 L F
.558 .896 .982 r
.45873 .64403 m .45965 .64276 L .461 .64367 L F
.45873 .64403 m .45769 .64355 L .45965 .64276 L F
.532 .803 .995 r
.66885 .48334 m .67019 .48191 L .66783 .48229 L F
.66885 .48334 m .67128 .48289 L .67019 .48191 L F
.649 .14 .02 r
.53253 .76799 m .53153 .76856 L .52886 .76689 L F
.606 .085 0 r
.53253 .76799 m .5365 .7694 L .53153 .76856 L F
.172 0 .358 r
.58587 .71884 m .58786 .7157 L .58567 .71649 L F
.327 0 0 r
.4148 .70976 m .41324 .71113 L .41155 .7108 L F
.229 0 0 r
.4155 .71066 m .4148 .70976 L .41694 .70942 L F
.4155 .71066 m .41324 .71113 L .4148 .70976 L F
.384 .809 .97 r
.43005 .64882 m .43213 .64849 L .43358 .64894 L F
.742 .648 .757 r
.48672 .79636 m .48392 .79975 L .48424 .79832 L F
.819 .997 .849 r
.72055 .50868 m .72281 .50531 L .72368 .50611 L F
.906 .522 .09 r
.72055 .50868 m .72028 .51002 L .72058 .50752 L F
.72055 .50868 m .72127 .511 L .72028 .51002 L F
.455 .033 .149 r
.42803 .66537 m .42438 .66737 L .42567 .66562 L F
.35 .525 .888 r
.56388 .78017 m .56037 .77739 L .56387 .77771 L F
0 0 0 r
.56387 .77771 m .56456 .77832 L .56388 .78017 L F
.56387 .77771 m .56574 .77654 L .56456 .77832 L F
.612 .261 .351 r
.50951 .77374 m .51304 .77144 L .51026 .77263 L F
.50951 .77374 m .51195 .77396 L .51304 .77144 L F
.509 .189 .36 r
.51195 .77396 m .51536 .77136 L .51304 .77144 L F
.687 .88 .97 r
.32973 .60289 m .3335 .6025 L .33165 .60306 L F
.334 .809 .747 r
.33165 .60306 m .3335 .6025 L .33575 .60158 L F
.569 .335 .522 r
.60553 .56762 m .6079 .56477 L .60467 .56462 L F
.60553 .56762 m .60772 .56699 L .6079 .56477 L F
.501 .279 .508 r
.6079 .56477 m .60973 .56626 L .61039 .56452 L F
.6079 .56477 m .60772 .56699 L .60973 .56626 L F
.732 .77 .883 r
.76477 .60369 m .76806 .60396 L .76412 .60545 L F
.103 .519 .909 r
.76829 .60717 m .76412 .60545 L .76806 .60396 L F
0 0 0 r
.62582 .56973 m .62503 .57148 L .62387 .57285 L F
.62737 .56816 m .62604 .56984 L .62582 .56973 L F
.62604 .56984 m .62503 .57148 L .62582 .56973 L F
.721 .37 0 r
.66147 .52514 m .65991 .52141 L .66229 .52248 L F
.588 .944 .815 r
.53605 .80663 m .53802 .80598 L .53972 .80476 L F
.652 .21 .188 r
.4838 .69156 m .48561 .69306 L .48349 .6927 L F
.228 .682 .951 r
.3224 .59996 m .32466 .60089 L .32587 .60087 L F
.614 .741 .936 r
.50448 .8121 m .50469 .81412 L .50336 .81325 L F
.50448 .8121 m .50697 .81367 L .50469 .81412 L F
.584 .036 0 r
.50336 .81325 m .50469 .81412 L .50688 .81611 L F
.703 .731 .873 r
.49513 .63556 m .49185 .63554 L .49426 .63495 L F
.712 .66 .796 r
.53026 .74664 m .53136 .74849 L .53413 .74748 L F
.779 .996 .864 r
.7627 .58036 m .76169 .58265 L .76464 .58029 L F
0 0 0 r
.7627 .58036 m .76253 .58086 L .76169 .58265 L F
.736 .991 .859 r
.76169 .58265 m .76091 .58432 L .76331 .58242 L F
.227 .746 .759 r
.76169 .58265 m .76331 .58242 L .76579 .5818 L F
.76169 .58265 m .76579 .5818 L .76464 .58029 L F
0 0 0 r
.76253 .58086 m .76139 .5842 L .76169 .58265 L F
.736 .991 .859 r
.76169 .58265 m .76088 .58434 L .76091 .58432 L F
.76169 .58265 m .75846 .58483 L .76088 .58434 L F
.635 .927 .973 r
.46452 .64349 m .46543 .64206 L .46663 .64242 L F
.46452 .64349 m .46324 .64313 L .46543 .64206 L F
.881 .79 .755 r
.60915 .53899 m .61011 .54009 L .6102 .53639 L F
.617 .752 .942 r
.60766 .54107 m .61011 .54009 L .60915 .53899 L F
.502 .816 1 r
.58218 .69021 m .58218 .69042 L .5799 .69085 L F
.412 0 .139 r
.58218 .69042 m .57878 .69259 L .5799 .69085 L F
.351 .746 .985 r
.29927 .64926 m .29955 .6483 L .29779 .64797 L F
.29927 .64926 m .30149 .64922 L .29955 .6483 L F
.641 .407 .548 r
.69237 .50874 m .69135 .51037 L .68855 .50682 L F
.542 .485 .742 r
.69348 .50746 m .69237 .50874 L .68855 .50682 L F
.559 .392 .612 r
.68855 .50682 m .69135 .51037 L .69348 .50746 L F
.428 .481 .813 r
.37672 .68243 m .37962 .68533 L .37883 .68199 L F
.566 .511 .753 r
.37577 .6792 m .37672 .68243 L .37883 .68199 L F
.24 .581 .944 r
.54532 .73686 m .546 .73703 L .5482 .73675 L F
.188 0 0 r
.54365 .73679 m .54249 .73624 L .54674 .73699 L F
.134 .679 .817 r
.5482 .73675 m .54365 .73679 L .54646 .73697 L F
.5482 .73675 m .54646 .73697 L .54674 .73699 L F
.24 .581 .944 r
.546 .73703 m .54889 .73778 L .5482 .73675 L F
.621 .301 .407 r
.52954 .78041 m .52874 .78307 L .526 .78278 L F
.716 .398 .438 r
.52954 .78041 m .53164 .78284 L .52874 .78307 L F
.35 0 .148 r
.43247 .66371 m .43045 .66335 L .43383 .66256 L F
.384 0 0 r
.43597 .66267 m .43247 .66371 L .43383 .66256 L F
.431 .387 .709 r
.50972 .69867 m .50975 .69856 L .51024 .69592 L F
0 0 0 r
.51024 .69592 m .51338 .69365 L .51071 .69337 L F
.51024 .69592 m .51129 .69564 L .51338 .69365 L F
.011 .019 .517 r
.51095 .69207 m .51129 .69564 L .51024 .69592 L F
.431 .387 .709 r
.50975 .69856 m .51084 .69448 L .51024 .69592 L F
0 0 0 r
.51024 .69592 m .51071 .69337 L .50988 .69329 L F
.229 .385 .812 r
.51241 .68646 m .51215 .68804 L .51077 .68701 L F
.529 0 0 r
.51215 .68804 m .51312 .68897 L .51077 .68701 L F
.625 .504 .694 r
.51077 .68701 m .51312 .68897 L .51252 .68642 L F
.51077 .68701 m .51252 .68642 L .51229 .68543 L F
.487 .413 .699 r
.51229 .68543 m .51257 .68664 L .51537 .68638 L F
.229 .385 .812 r
.5124 .68651 m .51436 .6899 L .51215 .68804 L F
.51317 .68711 m .51436 .6899 L .5124 .68651 L F
.532 .576 .844 r
.51537 .68638 m .51436 .6899 L .51317 .68711 L F
.487 .413 .699 r
.51257 .68664 m .5141 .68785 L .51537 .68638 L F
.532 .576 .844 r
.51537 .68638 m .51317 .68711 L .51254 .68564 L F
.487 .413 .699 r
.51317 .68711 m .51312 .68897 L .5141 .68785 L F
.51257 .68664 m .51272 .68726 L .51317 .68711 L F
.51272 .68726 m .51312 .68897 L .51317 .68711 L F
.229 .385 .812 r
.51254 .68564 m .51317 .68711 L .5124 .68651 L F
.51254 .68564 m .51241 .68646 L .51077 .68701 L F
.529 0 0 r
.51215 .68804 m .51436 .6899 L .51312 .68897 L F
.007 .034 .537 r
.51338 .69365 m .51451 .69269 L .51391 .6906 L F
.297 .09 .42 r
.51597 .6936 m .51419 .69627 L .51338 .69365 L F
0 0 0 r
.51338 .69365 m .51129 .69564 L .51451 .69269 L F
.953 .933 .735 r
.50534 .69142 m .50415 .69335 L .50542 .69146 L F
.83 .864 .871 r
.54742 .79874 m .54909 .80026 L .5488 .79835 L F
.517 .405 .666 r
.37651 .66839 m .37888 .67061 L .37871 .66793 L F
.37651 .66839 m .37691 .67113 L .37888 .67061 L F
.637 .824 .972 r
.58551 .72114 m .58651 .71979 L .58587 .71885 L F
.58551 .72114 m .58267 .72099 L .58651 .71979 L F
.286 .778 .895 r
.58114 .72018 m .58651 .71979 L .58267 .72099 L F
.58561 .71985 m .5847 .71963 L .58651 .71979 L F
.58114 .72018 m .5847 .71963 L .58561 .71985 L F
.447 .807 .996 r
.5835 .71881 m .5847 .71963 L .58255 .71997 L F
.5835 .71881 m .58255 .71997 L .58114 .72018 L F
0 0 .279 r
.58404 .71769 m .58394 .71829 L .5835 .71881 L F
.974 .732 .511 r
.5835 .71881 m .58386 .71943 L .5847 .71963 L F
.661 .497 .652 r
.58364 .72337 m .58267 .72099 L .58551 .72114 L F
.974 .732 .511 r
.5835 .71881 m .58341 .72147 L .58436 .72029 L F
0 0 .279 r
.58394 .71829 m .58341 .72147 L .5835 .71881 L F
.974 .732 .511 r
.58386 .71943 m .58436 .72029 L .5847 .71963 L F
.567 0 0 r
.5847 .71963 m .5868 .72021 L .58651 .71979 L F
.5868 .72021 m .58731 .72036 L .58651 .71979 L F
.637 .824 .972 r
.58587 .71885 m .58651 .71979 L .58587 .71884 L F
.172 0 .358 r
.58587 .71884 m .58759 .7182 L .58786 .7157 L F
.448 .193 .434 r
.58651 .71979 m .58759 .7182 L .58587 .71884 L F
.708 .718 .857 r
.70584 .50558 m .71183 .50592 L .7108 .50421 L F
.495 .655 .931 r
.7108 .50421 m .71183 .50592 L .71321 .50424 L F
.7108 .50421 m .71183 .50592 L .71321 .50424 L F
.03 .528 .875 r
.31801 .5886 m .31995 .5891 L .32145 .58999 L F
.434 .768 .997 r
.32204 .58883 m .32145 .58999 L .31995 .5891 L F
.32204 .58883 m .32354 .58977 L .32145 .58999 L F
.936 .821 .706 r
.64297 .54594 m .64466 .54529 L .64335 .54427 L F
.64297 .54594 m .64402 .54717 L .64466 .54529 L F
.864 .846 .824 r
.64335 .54427 m .64466 .54529 L .64685 .54252 L F
.393 .665 .968 r
.50207 .63642 m .50112 .6377 L .50049 .63717 L F
.50207 .63642 m .5032 .63793 L .50112 .6377 L F
.569 .732 .952 r
.3831 .70269 m .38743 .70492 L .3854 .70176 L F
.553 .523 .776 r
.3854 .70176 m .38743 .70492 L .38949 .70439 L F
.38 .127 .4 r
.38743 .70492 m .38871 .70656 L .38949 .70439 L F
.38743 .70492 m .38696 .70747 L .38871 .70656 L F
.769 .613 .686 r
.59673 .56746 m .60012 .56783 L .59884 .5646 L F
.769 .616 .69 r
.60011 .57024 m .60012 .56783 L .59673 .56746 L F
.707 .584 .715 r
.60012 .56783 m .60236 .56515 L .59884 .5646 L F
0 0 .5 r
.24819 .62651 m .24822 .6293 L .24939 .62782 L F
.489 .418 .703 r
.2488 .63187 m .25078 .63144 L .24822 .6293 L F
.739 .241 .05 r
.24822 .6293 m .25078 .63144 L .24932 .63103 L F
.24822 .6293 m .24932 .63103 L .24939 .62782 L F
0 0 0 r
.5428 .80358 m .54496 .80183 L .54494 .80284 L F
0 0 .033 r
.54494 .80284 m .54496 .80183 L .54598 .80086 L F
.744 .526 .599 r
.50822 .74075 m .51208 .74134 L .51204 .73844 L F
.614 .663 .874 r
.6369 .52499 m .63328 .52677 L .63217 .52364 L F
.641 .582 .773 r
.63734 .52801 m .63328 .52677 L .6369 .52499 L F
.605 .539 .753 r
.68459 .53043 m .68217 .53115 L .68165 .52817 L F
.499 .516 .806 r
.70218 .48969 m .70386 .48733 L .70189 .48793 L F
.70218 .48969 m .7044 .4899 L .70386 .48733 L F
.475 .562 .864 r
.70218 .48969 m .70455 .48988 L .7044 .4899 L F
0 0 0 r
.62492 .53893 m .62699 .53655 L .62496 .53697 L F
.591 .343 .509 r
.62699 .53655 m .62492 .53893 L .62496 .53697 L F
.557 .517 .766 r
.3854 .70176 m .38759 .69917 L .38565 .69978 L F
.3854 .70176 m .38882 .70134 L .38759 .69917 L F
.553 .523 .776 r
.3854 .70176 m .38949 .70439 L .38882 .70134 L F
.898 .719 .652 r
.46759 .7943 m .46888 .7973 L .46985 .79625 L F
.139 .319 .783 r
.46888 .7973 m .47126 .79924 L .46985 .79625 L F
.38 .543 .891 r
.7731 .5829 m .77285 .58432 L .77411 .58386 L F
.335 .323 .698 r
.77285 .58432 m .77497 .58587 L .77411 .58386 L F
.421 .476 .812 r
.24681 .62389 m .24819 .62651 L .24931 .6257 L F
0 0 .5 r
.24819 .62651 m .24939 .62782 L .24931 .6257 L F
.527 .451 .713 r
.37544 .67682 m .37749 .67638 L .37692 .67323 L F
.601 .524 .74 r
.37577 .6792 m .37749 .67638 L .37544 .67682 L F
.772 .333 .208 r
.5493 .72979 m .55301 .73201 L .5509 .72957 L F
.774 .318 0 r
.55542 .73391 m .5549 .73224 L .55301 .73201 L F
.55542 .73391 m .5564 .73485 L .5549 .73224 L F
0 0 0 r
.6488 .53447 m .64775 .53626 L .6495 .53308 L F
.956 .678 .236 r
.67754 .53679 m .67777 .53886 L .67715 .53712 L F
.465 .122 .299 r
.67715 .53712 m .67929 .53537 L .67754 .53679 L F
.557 .393 .614 r
.54907 .71021 m .54932 .71287 L .55137 .70996 L F
.887 .819 .775 r
.55929 .70484 m .55729 .70753 L .55584 .70671 L F
.622 .418 .584 r
.55954 .70724 m .55729 .70753 L .55929 .70484 L F
.501 .24 .45 r
.56211 .70488 m .55954 .70724 L .55929 .70484 L F
.57 0 0 r
.64901 .51264 m .64465 .5117 L .64704 .51414 L F
.608 .318 .451 r
.64728 .51554 m .64921 .51632 L .64704 .51414 L F
.69 .476 .592 r
.4775 .66693 m .48092 .66553 L .47758 .66545 L F
.59 .519 .743 r
.51408 .6593 m .5118 .6598 L .51087 .65731 L F
.643 .38 .505 r
.52046 .76667 m .51776 .76899 L .51811 .76646 L F
.52046 .76667 m .52026 .76877 L .51776 .76899 L F
.458 .136 .331 r
.52349 .76584 m .52026 .76877 L .52046 .76667 L F
.517 .681 .94 r
.69089 .47959 m .68865 .47988 L .68713 .47781 L F
.3 .731 .97 r
.63834 .49129 m .64054 .49121 L .64135 .49185 L F
.798 .964 .914 r
.64135 .49185 m .64054 .49121 L .64233 .48948 L F
0 0 .197 r
.63031 .56402 m .62977 .56587 L .62802 .56675 L F
0 0 0 r
.62977 .56587 m .62737 .56816 L .62802 .56675 L F
.551 .358 .572 r
.6332 .48065 m .63555 .4802 L .63552 .47791 L F
0 0 0 r
.6329 .48229 m .63555 .4802 L .6332 .48065 L F
.406 .245 .548 r
.63552 .47791 m .63555 .4802 L .6375 .4789 L F
.387 .413 .766 r
.38264 .69641 m .38334 .69281 L .38179 .69332 L F
.38264 .69641 m .38423 .69608 L .38334 .69281 L F
.385 .403 .756 r
.38264 .69641 m .38472 .69832 L .38423 .69608 L F
.908 .637 .516 r
.66082 .51702 m .65886 .51883 L .65922 .51596 L F
.66082 .51702 m .66107 .51844 L .65886 .51883 L F
0 0 0 r
.71241 .51111 m .71423 .51005 L .7153 .50898 L F
.28 .023 .334 r
.71241 .51111 m .71446 .51235 L .71423 .51005 L F
.71241 .51111 m .71252 .51355 L .71446 .51235 L F
.975 .704 .454 r
.511 .67118 m .51209 .67414 L .51071 .67331 L F
.51071 .67331 m .51209 .67414 L .511 .67118 L F
0 0 .221 r
.36685 .72708 m .36772 .72702 L .36807 .72461 L F
0 0 .28 r
.36685 .72708 m .36667 .72895 L .36772 .72702 L F
.518 .916 .886 r
.66783 .47905 m .6688 .47796 L .66986 .47838 L F
.66783 .47905 m .66659 .47901 L .6688 .47796 L F
.664 .717 .888 r
.69413 .48044 m .69159 .48127 L .69089 .47959 L F
.864 .846 .824 r
.64335 .54427 m .64685 .54252 L .64541 .5413 L F
.418 .246 .539 r
.56109 .69925 m .56319 .69917 L .56311 .69652 L F
.278 0 .152 r
.56109 .69925 m .56238 .70046 L .56319 .69917 L F
.56109 .69925 m .56039 .70104 L .56238 .70046 L F
.422 .241 .528 r
.33784 .61476 m .33991 .61177 L .33806 .61238 L F
.724 .402 .433 r
.53012 .7678 m .52578 .76644 L .52886 .76689 L F
.348 .407 .781 r
.52886 .76689 m .53153 .76856 L .53012 .7678 L F
.742 .648 .757 r
.48672 .79636 m .48734 .80013 L .48392 .79975 L F
.767 .944 .938 r
.48836 .79805 m .48722 .79937 L .48672 .79636 L F
.706 .264 .199 r
.48836 .79805 m .48462 .79661 L .48724 .79863 L F
.604 .436 .627 r
.48881 .79753 m .48836 .79805 L .48724 .79863 L F
.659 .654 .834 r
.48835 .79548 m .4914 .79691 L .49048 .79635 L F
.604 .436 .627 r
.49048 .79635 m .48836 .79805 L .48881 .79753 L F
.767 .944 .938 r
.48836 .79805 m .48734 .80013 L .48722 .79937 L F
.48836 .79805 m .48976 .79874 L .48734 .80013 L F
.371 .495 .854 r
.25095 .64174 m .25166 .63946 L .24938 .64039 L F
.25095 .64174 m .25347 .64263 L .25166 .63946 L F
.501 .491 .777 r
.38681 .71301 m .39036 .71447 L .3882 .71102 L F
.86 .409 .1 r
.3895 .71619 m .38843 .71599 L .38681 .71301 L F
.619 .362 .507 r
.38681 .71301 m .38843 .71599 L .39036 .71447 L F
0 .451 .781 r
.64776 .50564 m .64613 .50493 L .64434 .50438 L F
.949 .722 .561 r
.64776 .50564 m .64722 .50798 L .64613 .50493 L F
.924 .656 .513 r
.51636 .7543 m .51802 .75486 L .51788 .75242 L F
.683 .719 .876 r
.70582 .4804 m .70325 .48271 L .70229 .47984 L F
.458 .136 .331 r
.52349 .76584 m .52238 .76847 L .52026 .76877 L F
.666 .349 .428 r
.52599 .76822 m .52349 .76584 L .52578 .76644 L F
.52599 .76822 m .52238 .76847 L .52349 .76584 L F
.508 .12 .239 r
.51921 .68439 m .52151 .68449 L .5226 .68228 L F
.67 .29 .318 r
.5226 .68228 m .52473 .68432 L .52463 .68187 L F
.5226 .68228 m .52151 .68449 L .52473 .68432 L F
.343 0 .174 r
.2929 .60663 m .29178 .6087 L .28978 .60908 L F
.323 0 .175 r
.29496 .60597 m .29178 .6087 L .2929 .60663 L F
0 0 0 r
.56736 .77434 m .56871 .77242 L .5677 .77402 L F
.894 .966 .644 r
.56871 .77242 m .57042 .76918 L .56912 .77044 L F
.845 .883 .451 r
.56871 .77242 m .56912 .77044 L .5677 .77402 L F
.289 0 0 r
.42709 .70606 m .42464 .70655 L .42539 .70569 L F
.234 .744 .878 r
.63988 .51653 m .6407 .51674 L .63834 .51695 L F
.63988 .51653 m .63834 .51695 L .63695 .51853 L F
.588 .504 .726 r
.51282 .65387 m .51457 .65801 L .51087 .65731 L F
.59 .519 .743 r
.51408 .6593 m .51087 .65731 L .51457 .65801 L F
0 0 0 r
.55378 .76953 m .5498 .77135 L .55214 .76863 L F
.915 .706 .606 r
.55291 .76664 m .55378 .76953 L .55214 .76863 L F
.692 .149 0 r
.55853 .73701 m .55782 .73548 L .5564 .73485 L F
.55853 .73701 m .56026 .73773 L .55782 .73548 L F
.485 0 0 r
.55782 .73548 m .56026 .73773 L .56104 .73843 L F
.192 0 .267 r
.62387 .57285 m .62386 .57497 L .6216 .5758 L F
0 0 .204 r
.62491 .57349 m .62387 .57285 L .62503 .57148 L F
.62491 .57349 m .62386 .57497 L .62387 .57285 L F
.326 .537 .905 r
.4155 .6952 m .41467 .69668 L .41362 .69503 L F
.476 .725 .98 r
.4155 .6952 m .41692 .69659 L .41467 .69668 L F
.474 0 0 r
.53612 .77741 m .53962 .77777 L .53758 .77718 L F
.818 .951 .607 r
.59878 .52754 m .60048 .52412 L .60036 .52565 L F
.518 .321 .553 r
.56377 .7014 m .56432 .70477 L .56211 .70488 L F
.703 .448 .534 r
.56744 .70425 m .56377 .7014 L .56757 .70098 L F
.56744 .70425 m .56432 .70477 L .56377 .7014 L F
.979 .706 .436 r
.67464 .48348 m .67358 .48433 L .67128 .48289 L F
.67464 .48348 m .67472 .4859 L .67358 .48433 L F
.785 .647 .71 r
.59884 .5646 m .5975 .56167 L .59601 .56447 L F
.59884 .5646 m .59899 .56223 L .5975 .56167 L F
.85 .741 .743 r
.59673 .56746 m .59884 .5646 L .59601 .56447 L F
.407 .554 .89 r
.64035 .47803 m .64117 .48036 L .63915 .47997 L F
.837 .707 .72 r
.55865 .71295 m .55556 .71323 L .55718 .70999 L F
.802 .905 .913 r
.55865 .71295 m .55481 .71416 L .55556 .71323 L F
0 0 .149 r
.55963 .70962 m .55865 .71295 L .55718 .70999 L F
.55963 .70962 m .55938 .71195 L .55865 .71295 L F
.654 .223 0 r
.55946 .71448 m .55865 .71295 L .55938 .71195 L F
.55946 .71448 m .56025 .7156 L .56008 .71532 L F
.55946 .71448 m .56008 .71532 L .55865 .71295 L F
.532 .343 .571 r
.55859 .71325 m .55827 .71365 L .55946 .71448 L F
.402 .686 .976 r
.55878 .71358 m .55946 .71448 L .55827 .71365 L F
.532 .343 .571 r
.56053 .7108 m .55946 .71448 L .55938 .71195 L F
.56053 .7108 m .55859 .71325 L .55946 .71448 L F
.402 .686 .976 r
.56063 .71331 m .55946 .71448 L .55878 .71358 L F
.654 .223 0 r
.55946 .71448 m .56027 .71563 L .56025 .7156 L F
.711 .613 .745 r
.53243 .73708 m .53398 .73747 L .5335 .73552 L F
.652 .575 .756 r
.5335 .73552 m .53398 .73747 L .53635 .73585 L F
.852 .946 .88 r
.4914 .79691 m .48976 .79874 L .48836 .79805 L F
.319 .657 .972 r
.27153 .64731 m .27297 .64855 L .27339 .64743 L F
0 0 .569 r
.27297 .64855 m .27451 .65133 L .27339 .64743 L F
.602 .61 .832 r
.6204 .54462 m .61806 .54514 L .61655 .54217 L F
.263 0 .207 r
.33235 .64025 m .33138 .64271 L .32963 .64273 L F
.295 0 .222 r
.33332 .64196 m .33235 .64025 L .33439 .63968 L F
.33332 .64196 m .33138 .64271 L .33235 .64025 L F
.654 .907 .981 r
.36714 .70161 m .36674 .70288 L .36881 .70198 L F
.493 .59 .88 r
.36674 .70288 m .36902 .7037 L .36881 .70198 L F
.123 0 .03 r
.61753 .55871 m .61948 .55774 L .62018 .55595 L F
.08 0 .36 r
.62018 .55595 m .62192 .55508 L .6216 .5523 L F
0 0 0 r
.62018 .55595 m .61948 .55774 L .62192 .55508 L F
.717 .561 .677 r
.51228 .78324 m .51001 .78608 L .51002 .78345 L F
.628 .437 .605 r
.51228 .78324 m .51233 .7857 L .51001 .78608 L F
.266 0 0 r
.51228 .78324 m .51766 .78358 L .51233 .7857 L F
.905 .7 .616 r
.56026 .73773 m .56177 .74026 L .56104 .73843 L F
.356 .216 .55 r
.33562 .61524 m .33728 .6168 L .33784 .61476 L F
.33562 .61524 m .33568 .61752 L .33728 .6168 L F
.674 .253 .238 r
.37906 .70763 m .37765 .70907 L .37566 .70741 L F
.821 .955 .615 r
.37934 .70642 m .37765 .70907 L .37906 .70763 L F
.954 .697 .508 r
.37765 .70907 m .3792 .71009 L .37906 .70763 L F
.536 .461 .718 r
.40421 .67871 m .40288 .68258 L .40208 .67907 L F
.40421 .67871 m .40501 .68208 L .40288 .68258 L F
.535 .459 .716 r
.40501 .68208 m .40536 .68427 L .40288 .68258 L F
.996 .768 .425 r
.48751 .81055 m .48778 .80868 L .48681 .80768 L F
.634 .078 0 r
.62815 .52764 m .62479 .52519 L .62792 .52543 L F
.465 .257 .512 r
.61904 .58307 m .61733 .58153 L .61967 .58094 L F
.61904 .58307 m .61701 .58368 L .61733 .58153 L F
.871 .736 .711 r
.59899 .56223 m .59818 .55927 L .5975 .56167 L F
.573 .316 .488 r
.59799 .58716 m .598 .58923 L .59543 .58951 L F
.683 .414 .509 r
.60014 .5872 m .598 .58923 L .59799 .58716 L F
.422 .294 .6 r
.57136 .69088 m .57335 .69028 L .57295 .68768 L F
.544 .492 .748 r
.5716 .69225 m .57335 .69028 L .57136 .69088 L F
.769 .616 .69 r
.60011 .57024 m .59673 .56746 L .59658 .56979 L F
.639 .42 .57 r
.59765 .57275 m .60011 .57024 L .59658 .56979 L F
.59765 .57275 m .60014 .57259 L .60011 .57024 L F
.671 .437 .559 r
.60304 .57236 m .60011 .57024 L .60014 .57259 L F
.60304 .57236 m .60328 .57054 L .60011 .57024 L F
0 0 0 r
.77957 .60312 m .77662 .60582 L .77882 .60526 L F
.77957 .60312 m .77882 .60526 L .77917 .60333 L F
.522 .873 .629 r
.78241 .60084 m .77957 .60312 L .77917 .60333 L F
.652 .138 .007 r
.49299 .6941 m .49142 .69489 L .48921 .69328 L F
.667 .158 .022 r
.49299 .6941 m .49494 .69577 L .49142 .69489 L F
.566 .252 .396 r
.49648 .69322 m .49494 .69577 L .49299 .6941 L F
0 0 0 r
.50116 .76855 m .50132 .76854 L .50062 .76932 L F
.33 .735 .981 r
.50132 .76854 m .5026 .76925 L .50062 .76932 L F
.682 .208 .12 r
.71423 .51005 m .71762 .51096 L .7153 .50898 L F
.476 .306 .571 r
.7153 .50898 m .71762 .51096 L .71764 .50815 L F
.453 .28 .555 r
.24258 .60612 m .24461 .60331 L .24285 .60403 L F
.337 .761 .975 r
.48136 .78867 m .48428 .78872 L .48209 .78784 L F
.562 .467 .704 r
.48439 .79079 m .48136 .78867 L .48209 .78784 L F
.771 .265 0 r
.56177 .74026 m .56488 .7432 L .56414 .742 L F
.276 .14 .508 r
.4965 .66935 m .498 .66772 L .49652 .66843 L F
.923 .799 .705 r
.78136 .59804 m .78241 .60084 L .78055 .59888 L F
.522 .873 .629 r
.78241 .60084 m .77917 .60333 L .78109 .60242 L F
.78241 .60084 m .78109 .60242 L .78055 .59888 L F
.346 .333 .702 r
.7831 .59845 m .78241 .60084 L .78136 .59804 L F
.7831 .59845 m .7838 .60079 L .78241 .60084 L F
.199 .666 .94 r
.30857 .58745 m .31101 .58761 L .31198 .58827 L F
.155 .628 .927 r
.31281 .58777 m .31198 .58827 L .31101 .58761 L F
.31281 .58777 m .31429 .58855 L .31198 .58827 L F
.733 .681 .8 r
.47766 .76012 m .47865 .76219 L .48036 .76022 L F
.558 .923 .942 r
.51242 .80462 m .51155 .80571 L .5114 .80517 L F
0 0 0 r
.51057 .80761 m .51155 .80571 L .51242 .80462 L F
.711 .214 .057 r
.67777 .53886 m .68121 .54011 L .68011 .53903 L F
.599 .82 .984 r
.68011 .53903 m .68121 .54011 L .68347 .53942 L F
.602 .266 .374 r
.41644 .66808 m .41291 .67005 L .4145 .66763 L F
.516 .109 .208 r
.39779 .65591 m .39677 .65396 L .39518 .65522 L F
.39779 .65591 m .39909 .65399 L .39677 .65396 L F
.201 .455 .877 r
.64784 .48599 m .65071 .48743 L .64994 .48871 L F
0 .153 .674 r
.65071 .48743 m .65169 .49069 L .64994 .48871 L F
.806 .698 .746 r
.56691 .58101 m .57021 .58146 L .56807 .58393 L F
.759 .62 .706 r
.57021 .58146 m .57 .58404 L .56807 .58393 L F
.603 .828 .986 r
.71478 .48032 m .71142 .48002 L .71373 .47924 L F
.559 .834 .997 r
.71613 .47879 m .71478 .48032 L .71373 .47924 L F
.71613 .47879 m .71724 .47969 L .71478 .48032 L F
.565 .367 .571 r
.48271 .7805 m .48503 .78254 L .48473 .77999 L F
.48271 .7805 m .48234 .78312 L .48503 .78254 L F
.466 .75 .991 r
.35195 .59185 m .35111 .59327 L .35061 .59252 L F
.35195 .59185 m .3533 .59303 L .35111 .59327 L F
.791 .339 0 r
.55374 .76408 m .55416 .76407 L .55458 .76517 L F
0 0 0 r
.55676 .76132 m .55589 .76284 L .55416 .76407 L F
.428 .175 .427 r
.55589 .76284 m .55374 .76408 L .55416 .76407 L F
.599 .2 .257 r
.55696 .76559 m .55416 .76407 L .55458 .76517 L F
.375 0 0 r
.59437 .70136 m .59396 .7012 L .59034 .69916 L F
0 0 .38 r
.59437 .70136 m .59566 .70058 L .59396 .7012 L F
.181 0 .117 r
.59676 .69945 m .59507 .70192 L .59437 .70136 L F
0 0 .38 r
.59437 .70136 m .59507 .70192 L .59566 .70058 L F
.499 .708 .964 r
.76952 .58308 m .77036 .58091 L .76781 .58097 L F
.76952 .58308 m .7731 .5829 L .77036 .58091 L F
.841 .932 .889 r
.64832 .52441 m .64889 .52551 L .65128 .52301 L F
.957 .725 .273 r
.64832 .52441 m .64893 .52786 L .64889 .52551 L F
.692 .565 .707 r
.47975 .77242 m .48149 .77251 L .48338 .76964 L F
.941 .775 .311 r
.47251 .79994 m .47188 .80242 L .47126 .79924 L F
.47251 .79994 m .47231 .80254 L .47188 .80242 L F
.75 .521 .584 r
.57 .58404 m .56802 .5867 L .56807 .58393 L F
.57 .58404 m .57263 .58692 L .56802 .5867 L F
.684 .522 .661 r
.57 .58404 m .57387 .58416 L .57263 .58692 L F
.331 0 0 r
.50524 .7632 m .50403 .76258 L .50142 .76123 L F
.897 .895 .817 r
.68999 .52809 m .68792 .53107 L .68687 .53008 L F
.022 0 .187 r
.62386 .57497 m .62145 .57789 L .6216 .5758 L F
.794 .631 .68 r
.501 .69245 m .50534 .69142 L .50086 .69097 L F
.501 .69245 m .50415 .69335 L .50534 .69142 L F
.786 .953 .623 r
.56912 .77044 m .57042 .76918 L .57019 .76895 L F
.556 .46 .701 r
.40385 .67645 m .40421 .67871 L .40208 .67907 L F
.142 0 .079 r
.32867 .62345 m .32607 .62574 L .32813 .62526 L F
.43 .163 .406 r
.32867 .62345 m .33027 .62454 L .33097 .62321 L F
.32867 .62345 m .32813 .62526 L .33027 .62454 L F
.929 .883 .466 r
.5978 .70738 m .59739 .70738 L .5973 .71032 L F
.999 .839 .514 r
.59739 .70738 m .59765 .71325 L .5973 .71032 L F
.458 .326 .612 r
.53585 .74639 m .53615 .7491 L .53413 .74748 L F
.53585 .74639 m .53615 .7491 L .53413 .74748 L F
.529 .594 .863 r
.54238 .80013 m .53843 .7973 L .5394 .79947 L F
.17 0 0 r
.54229 .80013 m .54238 .80013 L .5394 .79947 L F
.595 .913 .978 r
.54453 .79927 m .54238 .80013 L .54329 .79887 L F
.603 .859 .51 r
.54329 .79887 m .54238 .80013 L .54229 .80013 L F
.319 0 0 r
.48861 .75089 m .49246 .74914 L .49199 .74908 L F
.621 .763 .947 r
.68185 .48443 m .68678 .48563 L .68505 .48347 L F
.582 .766 .966 r
.68678 .48563 m .68648 .48292 L .68505 .48347 L F
.68678 .48563 m .68892 .48512 L .68648 .48292 L F
.41 .371 .705 r
.38126 .69079 m .38241 .68707 L .38058 .68763 L F
.38126 .69079 m .38296 .69029 L .38241 .68707 L F
.39 .308 .642 r
.38126 .69079 m .38334 .69281 L .38296 .69029 L F
.364 .305 .657 r
.38179 .69332 m .38334 .69281 L .38126 .69079 L F
.608 .348 .498 r
.61178 .58435 m .60952 .58662 L .60971 .58435 L F
.668 .254 .25 r
.50813 .78877 m .50661 .79059 L .50432 .7887 L F
.921 .619 .455 r
.5083 .79084 m .50661 .79059 L .50813 .78877 L F
0 0 0 r
.48569 .75587 m .48414 .75685 L .48234 .75739 L F
.38 0 0 r
.48826 .75525 m .48414 .75685 L .48569 .75587 L F
.933 .914 .776 r
.61107 .53251 m .6102 .53639 L .61183 .53336 L F
.626 .915 .98 r
.61327 .53144 m .61183 .53336 L .61474 .53111 L F
.61327 .53144 m .61107 .53251 L .61183 .53336 L F
.617 .759 .946 r
.5441 .75718 m .54183 .75776 L .54072 .75639 L F
.383 .805 .616 r
.5488 .79835 m .55099 .797 L .55158 .79663 L F
.55099 .797 m .55191 .79644 L .5517 .79656 L F
.55099 .797 m .5517 .79656 L .55158 .79663 L F
.702 .781 .913 r
.55041 .79737 m .54735 .79732 L .54906 .79672 L F
.55097 .79764 m .5501 .79756 L .55041 .79737 L F
.5501 .79756 m .54735 .79732 L .55041 .79737 L F
.734 .563 .661 r
.5808 .58974 m .57858 .59247 L .57707 .58944 L F
.72 .544 .65 r
.58061 .59222 m .57858 .59247 L .5808 .58974 L F
.927 .544 .166 r
.6381 .52017 m .63724 .52077 L .63695 .51853 L F
.6381 .52017 m .63845 .52185 L .63724 .52077 L F
.497 .17 .343 r
.53289 .76065 m .53523 .76039 L .53604 .75786 L F
.421 .1 .313 r
.53604 .75786 m .53778 .75964 L .5383 .75694 L F
.53604 .75786 m .53523 .76039 L .53778 .75964 L F
.377 0 .097 r
.30103 .60307 m .29922 .60523 L .2971 .60552 L F
.268 0 .024 r
.30141 .60466 m .30103 .60307 L .30299 .60313 L F
.30141 .60466 m .29922 .60523 L .30103 .60307 L F
.598 .822 .985 r
.69893 .47943 m .69749 .48105 L .6965 .47979 L F
.69893 .47943 m .69982 .48041 L .69749 .48105 L F
.451 .205 .448 r
.36601 .6114 m .36642 .60947 L .36852 .60886 L F
0 0 .169 r
.5384 .73245 m .54051 .73004 L .53842 .73025 L F
.35 0 .148 r
.43247 .66371 m .42991 .66444 L .43045 .66335 L F
.303 0 0 r
.42487 .69583 m .42712 .69555 L .42865 .69393 L F
.267 0 0 r
.42712 .69555 m .43087 .69358 L .42865 .69393 L F
.751 .959 .938 r
.71065 .52066 m .71244 .52089 L .71424 .51949 L F
.895 .706 .639 r
.56725 .57568 m .56679 .57846 L .56585 .57559 L F
.112 .096 .558 r
.59034 .69916 m .5918 .69789 L .59134 .69554 L F
.301 .419 .815 r
.59034 .69916 m .59396 .7012 L .5918 .69789 L F
.622 .384 .536 r
.51125 .66577 m .50945 .66831 L .50733 .66825 L F
.716 .506 .604 r
.51322 .6679 m .51125 .66577 L .5127 .66546 L F
.51322 .6679 m .50945 .66831 L .51125 .66577 L F
.698 .758 .899 r
.65571 .49045 m .65888 .49095 L .65763 .49048 L F
.306 .768 .946 r
.66124 .49071 m .65763 .49048 L .65888 .49095 L F
0 0 0 r
.72593 .51758 m .72473 .51816 L .72233 .51864 L F
.249 0 0 r
.72746 .51795 m .72593 .51758 L .72827 .51668 L F
.72746 .51795 m .72473 .51816 L .72593 .51758 L F
.966 .712 .499 r
.498 .66772 m .49949 .66991 L .50134 .66842 L F
.498 .66772 m .49798 .67011 L .49949 .66991 L F
0 0 0 r
.69149 .52669 m .69252 .52509 L .68999 .52809 L F
.445 .733 .988 r
.69376 .52384 m .6949 .52497 L .69252 .52509 L F
.69376 .52384 m .6949 .52497 L .69252 .52509 L F
0 0 0 r
.69376 .52384 m .69252 .52509 L .69149 .52669 L F
.897 .895 .817 r
.68999 .52809 m .68687 .53008 L .68951 .52794 L F
.577 .939 .812 r
.69149 .52669 m .68999 .52809 L .68951 .52794 L F
.245 0 .12 r
.28668 .61347 m .28548 .6129 L .28751 .61228 L F
.28668 .61347 m .28464 .61428 L .28548 .6129 L F
.778 .672 .746 r
.54834 .78529 m .54683 .78764 L .54735 .78603 L F
.8 .482 .451 r
.54853 .7847 m .55077 .78393 L .54982 .78602 L F
.54669 .78281 m .54895 .78343 L .54853 .7847 L F
.54895 .78343 m .55077 .78393 L .54853 .7847 L F
.54669 .78281 m .54982 .78602 L .5495 .78444 L F
.778 .672 .746 r
.5495 .78444 m .54806 .78617 L .54834 .78529 L F
.54806 .78617 m .54683 .78764 L .54834 .78529 L F
.555 .076 .074 r
.45222 .68615 m .45446 .68664 L .45588 .68525 L F
.579 .105 .092 r
.45588 .68525 m .45446 .68664 L .45768 .68659 L F
.548 .139 .219 r
.45588 .68525 m .45768 .68659 L .45849 .68538 L F
.726 .777 .893 r
.7674 .60244 m .76806 .60396 L .76477 .60369 L F
.556 .827 .996 r
.76963 .60253 m .76806 .60396 L .7674 .60244 L F
.76963 .60253 m .77058 .60345 L .76806 .60396 L F
.633 .821 .972 r
.29204 .63214 m .28999 .63291 L .28832 .63186 L F
.908 .95 .815 r
.64099 .54923 m .64402 .54717 L .64297 .54594 L F
.64099 .54923 m .64221 .54959 L .64402 .54717 L F
.69 .476 .592 r
.4775 .66693 m .48087 .66795 L .48092 .66553 L F
.601 .524 .74 r
.37577 .6792 m .37812 .67958 L .37749 .67638 L F
.566 .511 .753 r
.37577 .6792 m .37883 .68199 L .37812 .67958 L F
.327 0 .009 r
.44389 .65946 m .44031 .66143 L .44165 .65984 L F
.387 0 .075 r
.55659 .74706 m .55377 .7476 L .55422 .7474 L F
0 0 0 r
.6216 .5523 m .62393 .5497 L .62233 .55021 L F
.6216 .5523 m .62286 .55144 L .62393 .5497 L F
0 0 .341 r
.6216 .5523 m .62192 .55508 L .62286 .55144 L F
.799 .877 .904 r
.49185 .63554 m .48831 .63664 L .4906 .63539 L F
.605 .937 .952 r
.49185 .63554 m .49287 .63435 L .49426 .63495 L F
.49185 .63554 m .4906 .63539 L .49287 .63435 L F
.695 .596 .741 r
.47038 .66174 m .47039 .66372 L .47232 .66335 L F
.562 .443 .675 r
.71471 .4943 m .71611 .4903 L .7164 .49153 L F
.403 .595 .923 r
.76884 .57474 m .76765 .57636 L .76712 .57437 L F
.76884 .57474 m .77213 .57746 L .76765 .57636 L F
.357 0 0 r
.7715 .57781 m .76765 .57636 L .77213 .57746 L F
.438 .313 .613 r
.24089 .60948 m .24285 .60881 L .24258 .60612 L F
.494 .441 .727 r
.2429 .6118 m .24089 .60948 L .24133 .61188 L F
.2429 .6118 m .24285 .60881 L .24089 .60948 L F
.097 0 0 r
.63074 .48322 m .63273 .48276 L .6329 .48229 L F
.63074 .48322 m .62989 .48468 L .63273 .48276 L F
.262 .77 .78 r
.61846 .52168 m .62011 .52111 L .62081 .52101 L F
.61846 .52168 m .61783 .52172 L .62011 .52111 L F
.703 .686 .832 r
.50822 .74075 m .50902 .74309 L .51208 .74134 L F
.542 .139 .227 r
.40694 .65329 m .40932 .65343 L .41061 .65144 L F
.4 0 .129 r
.40932 .65343 m .41286 .65122 L .41061 .65144 L F
.683 .414 .509 r
.60014 .5872 m .60022 .5894 L .598 .58923 L F
.655 .402 .524 r
.60384 .58685 m .60022 .5894 L .60014 .5872 L F
.509 .833 .999 r
.51509 .75528 m .51802 .75486 L .51636 .7543 L F
.802 .844 .882 r
.57004 .72703 m .57121 .7236 L .56863 .72604 L F
.57004 .72703 m .57292 .7246 L .57121 .7236 L F
.682 .58 .735 r
.57004 .72703 m .57411 .72852 L .57292 .7246 L F
.942 .939 .599 r
.59893 .71527 m .59795 .71721 L .59811 .71901 L F
.9 .819 .348 r
.59811 .71901 m .59737 .72108 L .59748 .72113 L F
.59811 .71901 m .59795 .71721 L .59737 .72108 L F
.427 .571 .895 r
.36482 .59653 m .36394 .59839 L .36255 .59605 L F
.482 .637 .924 r
.36482 .59653 m .36601 .59825 L .36394 .59839 L F
.352 .773 .976 r
.30155 .64871 m .30505 .64968 L .30664 .64946 L F
0 .176 .705 r
.7397 .59259 m .74128 .59306 L .73889 .59171 L F
.7397 .59259 m .74162 .59466 L .74128 .59306 L F
.422 .237 .523 r
.28035 .61767 m .28016 .62012 L .27837 .62049 L F
.458 .384 .686 r
.28061 .62255 m .27837 .62049 L .28016 .62012 L F
.28061 .62255 m .27874 .62364 L .27837 .62049 L F
0 0 0 r
.5514 .71737 m .55182 .71707 L .55286 .71589 L F
.886 .455 .104 r
.55387 .72116 m .55266 .72055 L .5514 .71737 L F
0 0 .409 r
.5514 .71737 m .55266 .72055 L .55182 .71707 L F
.608 .348 .498 r
.61178 .58435 m .61177 .58641 L .60952 .58662 L F
.621 .373 .52 r
.61421 .5842 m .61177 .58641 L .61178 .58435 L F
.896 .735 .674 r
.57508 .59213 m .57632 .59531 L .57439 .59453 L F
.787 .63 .687 r
.57138 .59383 m .574 .59536 L .57288 .59722 L F
.726 .42 .461 r
.57632 .59531 m .57353 .59687 L .57448 .59457 L F
.57353 .59687 m .57288 .59722 L .574 .59536 L F
.57353 .59687 m .574 .59536 L .57448 .59457 L F
.83 .659 .67 r
.57248 .59151 m .57411 .59503 L .57138 .59383 L F
.8 .652 .699 r
.57435 .59556 m .57439 .59453 L .5741 .59506 L F
.83 .659 .67 r
.5741 .59506 m .57435 .59556 L .574 .59536 L F
.787 .63 .687 r
.574 .59536 m .57435 .59556 L .57288 .59722 L F
.726 .42 .461 r
.57448 .59457 m .57288 .59722 L .57439 .59453 L F
.8 .652 .699 r
.57435 .59556 m .5741 .59506 L .57288 .59722 L F
.83 .659 .67 r
.57411 .59503 m .57435 .59556 L .5741 .59506 L F
.57411 .59503 m .574 .59536 L .57138 .59383 L F
.726 .42 .461 r
.57632 .59531 m .57628 .59731 L .57288 .59722 L F
.735 .668 .785 r
.57508 .59213 m .57858 .59247 L .57632 .59531 L F
.665 .564 .731 r
.57632 .59531 m .57858 .59247 L .57846 .59544 L F
.676 .394 .487 r
.57846 .59544 m .57628 .59731 L .57632 .59531 L F
.655 .704 .882 r
.7761 .58876 m .77859 .58941 L .77855 .58687 L F
0 0 0 r
.78071 .58549 m .77855 .58687 L .77859 .58941 L F
.695 .476 .585 r
.53558 .79977 m .53843 .7973 L .53661 .79725 L F
.53558 .79977 m .5394 .79947 L .53843 .7973 L F
.787 .394 0 r
.53807 .79701 m .5394 .79947 L .53843 .7973 L F
.616 .669 .878 r
.48558 .66025 m .48906 .66255 L .48807 .65945 L F
.465 .471 .78 r
.48807 .65945 m .48906 .66255 L .4912 .66074 L F
.346 .273 .63 r
.48906 .66255 m .49046 .66277 L .4912 .66074 L F
.611 .546 .757 r
.48906 .66255 m .49229 .66555 L .49046 .66277 L F
.734 .207 0 r
.56466 .71977 m .56511 .71905 L .56367 .71827 L F
.56466 .71977 m .568 .72193 L .56511 .71905 L F
.772 .304 .13 r
.56511 .71905 m .568 .72193 L .56889 .72142 L F
.247 0 0 r
.43659 .69122 m .43842 .69155 L .43967 .69015 L F
.648 .224 .225 r
.43842 .69155 m .44205 .69042 L .43967 .69015 L F
.937 .893 .761 r
.59982 .55613 m .59703 .55812 L .59818 .55927 L F
.59982 .55613 m .59872 .55521 L .59703 .55812 L F
.917 .884 .786 r
.59982 .55613 m .60028 .55206 L .59872 .55521 L F
0 0 .062 r
.61232 .50311 m .61268 .50366 L .61298 .50152 L F
.61232 .50311 m .61198 .50541 L .61268 .50366 L F
.724 .842 .937 r
.54428 .74366 m .54222 .74486 L .54047 .74341 L F
.244 .7 .952 r
.50524 .7632 m .50733 .76329 L .50403 .76258 L F
.675 .944 .961 r
.51514 .81411 m .51647 .81455 L .51815 .81344 L F
.099 0 0 r
.51647 .81455 m .51755 .81387 L .51815 .81344 L F
.813 .999 .839 r
.25346 .65716 m .25116 .65952 L .25125 .6571 L F
.408 .758 .995 r
.28823 .58371 m .28795 .58488 L .28642 .58387 L F
.28823 .58371 m .28991 .58467 L .28795 .58488 L F
.576 .713 .936 r
.29578 .63364 m .29204 .63214 L .29402 .63133 L F
.529 .677 .932 r
.29563 .63112 m .29578 .63364 L .29402 .63133 L F
.29563 .63112 m .29787 .63321 L .29578 .63364 L F
0 .411 .765 r
.71069 .5018 m .70955 .50114 L .7072 .50026 L F
.864 .965 .863 r
.71113 .50048 m .71069 .5018 L .71179 .50009 L F
.71113 .50048 m .70955 .50114 L .71069 .5018 L F
.819 .932 .557 r
.59566 .70058 m .59676 .69945 L .59667 .69777 L F
.59566 .70058 m .59507 .70192 L .59676 .69945 L F
.503 .259 .478 r
.51419 .69627 m .51366 .69903 L .51127 .69938 L F
.297 .09 .42 r
.51597 .6936 m .51574 .69572 L .51419 .69627 L F
.393 .162 .441 r
.5156 .69807 m .51419 .69627 L .51574 .69572 L F
.5156 .69807 m .51366 .69903 L .51419 .69627 L F
.693 .35 .39 r
.70248 .5027 m .70165 .50492 L .69921 .50419 L F
.411 .07 .274 r
.70402 .50431 m .70248 .5027 L .70562 .50265 L F
.70402 .50431 m .70165 .50492 L .70248 .5027 L F
.216 0 0 r
.29957 .58553 m .30144 .58609 L .30304 .58653 L F
.228 .66 .956 r
.30351 .5858 m .30304 .58653 L .30144 .58609 L F
.30351 .5858 m .305 .58669 L .30304 .58653 L F
.59 .229 .325 r
.51122 .81401 m .51261 .81112 L .50986 .81171 L F
.5 .155 .313 r
.51297 .81438 m .51261 .81112 L .51122 .81401 L F
.682 .966 .933 r
.68829 .5383 m .6871 .53988 L .68903 .53869 L F
.605 .853 .991 r
.68587 .53903 m .6871 .53988 L .68829 .5383 L F
.564 .646 .89 r
.75659 .59765 m .75567 .60073 L .75492 .59724 L F
.75659 .59765 m .75804 .60024 L .75567 .60073 L F
.256 .009 .333 r
.34105 .63614 m .33996 .63474 L .34224 .63398 L F
.34105 .63614 m .33938 .63701 L .33996 .63474 L F
.446 .181 .417 r
.35823 .61964 m .35669 .61809 L .35863 .61749 L F
.35823 .61964 m .35614 .6202 L .35669 .61809 L F
.653 .413 .543 r
.59024 .58975 m .5906 .59189 L .58652 .59238 L F
.677 .429 .54 r
.59024 .58975 m .59225 .5921 L .5906 .59189 L F
.696 .429 .516 r
.59223 .58996 m .59225 .5921 L .59024 .58975 L F
.505 .845 .996 r
.6757 .47812 m .67344 .47867 L .6723 .4779 L F
.913 .53 .273 r
.56873 .75112 m .5694 .74947 L .56813 .74877 L F
.56873 .75112 m .57019 .75105 L .5694 .74947 L F
.826 .924 .9 r
.62833 .51825 m .62732 .52012 L .62602 .5192 L F
.4 .773 .993 r
.32354 .58977 m .32563 .58956 L .32715 .59035 L F
.441 .811 .994 r
.32781 .58935 m .32715 .59035 L .32563 .58956 L F
.32781 .58935 m .3292 .59002 L .32715 .59035 L F
.676 .958 .946 r
.6911 .53752 m .69487 .53653 L .69427 .53624 L F
.654 .893 .982 r
.69608 .53479 m .69487 .53653 L .69691 .53553 L F
.719 .987 .877 r
.69608 .53479 m .69427 .53624 L .69487 .53653 L F
.276 .14 .508 r
.4965 .66935 m .49798 .67011 L .498 .66772 L F
.793 .813 .868 r
.77769 .6093 m .78078 .60935 L .77978 .60822 L F
.812 .938 .911 r
.78078 .60935 m .78249 .60636 L .77978 .60822 L F
.78078 .60935 m .78336 .60731 L .78249 .60636 L F
.772 .983 .905 r
.71845 .48345 m .71759 .48308 L .71487 .48517 L F
.372 .421 .783 r
.71907 .48029 m .72001 .48151 L .71845 .48345 L F
.723 .974 .926 r
.71845 .48345 m .72001 .48151 L .71759 .48308 L F
.316 0 .037 r
.26147 .58927 m .26362 .58888 L .26511 .58707 L F
.219 0 0 r
.26511 .58707 m .26561 .58832 L .26736 .58704 L F
.26511 .58707 m .26362 .58888 L .26561 .58832 L F
.163 0 .178 r
.57778 .72614 m .57597 .72737 L .57807 .72498 L F
.57778 .72614 m .57597 .72737 L .57807 .72498 L F
.474 .124 .293 r
.58022 .72411 m .58082 .7248 L .57807 .72498 L F
.58053 .72398 m .58082 .7248 L .58022 .72411 L F
.664 .111 0 r
.58082 .7248 m .58276 .72654 L .58198 .72613 L F
.47 .115 .281 r
.57807 .72498 m .57778 .72614 L .58082 .7248 L F
.664 .111 0 r
.58082 .7248 m .58198 .72613 L .57934 .72472 L F
.511 .707 .959 r
.57807 .72498 m .58082 .7248 L .57931 .72303 L F
.47 .115 .281 r
.57807 .72498 m .58082 .7248 L .57931 .72303 L F
0 0 .202 r
.62747 .49704 m .62716 .49966 L .6266 .50014 L F
0 .142 .66 r
.62716 .49966 m .62801 .50161 L .6266 .50014 L F
.292 .467 .861 r
.62901 .50282 m .6266 .50014 L .62801 .50161 L F
.071 0 0 r
.41692 .69659 m .41931 .69638 L .4203 .69607 L F
.176 .708 .722 r
.41931 .69638 m .42253 .69572 L .4203 .69607 L F
.732 .977 .739 r
.47644 .78099 m .47553 .78267 L .47755 .78049 L F
.662 .597 .772 r
.47553 .78267 m .47825 .78216 L .47755 .78049 L F
.187 .347 .793 r
.47644 .78099 m .4769 .78228 L .47553 .78267 L F
.961 .937 .707 r
.478 .7826 m .47788 .78597 L .47707 .78581 L F
.478 .7826 m .47707 .78581 L .47705 .78555 L F
.478 .7826 m .47788 .78597 L .47698 .78579 L F
.698 .618 .764 r
.47553 .78267 m .47698 .78579 L .478 .7826 L F
.47553 .78267 m .478 .7826 L .47825 .78216 L F
.187 .347 .793 r
.4769 .78228 m .47779 .78479 L .47698 .78403 L F
.4769 .78228 m .47698 .78403 L .47553 .78267 L F
.961 .937 .707 r
.47705 .78555 m .47707 .78581 L .47698 .78579 L F
.901 .648 .547 r
.64021 .5225 m .64029 .52487 L .63845 .52185 L F
.395 .637 .953 r
.36114 .59447 m .36032 .59587 L .35906 .59473 L F
.36114 .59447 m .36255 .59605 L .36032 .59587 L F
.576 .48 .709 r
.48164 .79476 m .48037 .79839 L .4847 .79662 L F
.662 .572 .743 r
.48095 .79889 m .4847 .79662 L .48037 .79839 L F
.522 .471 .741 r
.24142 .61224 m .2429 .6118 L .24133 .61188 L F
.527 .435 .694 r
.24178 .6149 m .2429 .6118 L .24142 .61224 L F
.773 .975 .7 r
.6166 .5186 m .61589 .5203 L .61829 .51741 L F
.609 .27 .371 r
.61783 .52172 m .61589 .5203 L .6166 .5186 L F
.61783 .52172 m .61489 .52217 L .61589 .5203 L F
.793 .817 .871 r
.47795 .6848 m .47697 .68718 L .47851 .68457 L F
.792 .569 .598 r
.47851 .68457 m .47697 .68718 L .48006 .68732 L F
.476 .863 .663 r
.47967 .68358 m .47851 .68457 L .47795 .6848 L F
.47967 .68358 m .47851 .68457 L .47795 .6848 L F
0 0 .31 r
.78071 .58549 m .78125 .58389 L .78044 .58568 L F
0 0 0 r
.78071 .58549 m .78044 .58568 L .77855 .58687 L F
.646 .662 .852 r
.54423 .77405 m .54445 .77621 L .54293 .77709 L F
.593 .507 .727 r
.54185 .77947 m .5444 .7789 L .54364 .77688 L F
.878 .525 .031 r
.54364 .77688 m .5444 .7789 L .54366 .77724 L F
.646 .662 .852 r
.54359 .77554 m .54293 .77709 L .54364 .77688 L F
.878 .525 .031 r
.54364 .77688 m .54366 .77724 L .54301 .77582 L F
.646 .662 .852 r
.54423 .77405 m .54359 .77554 L .54364 .77688 L F
.593 .507 .727 r
.54185 .77947 m .54364 .77688 L .54293 .77709 L F
.117 .666 .705 r
.2823 .65199 m .27994 .65235 L .278 .65266 L F
.65 .965 .911 r
.28238 .65105 m .2823 .65199 L .28412 .65109 L F
.28238 .65105 m .27994 .65235 L .2823 .65199 L F
.449 .593 .903 r
.24263 .61784 m .24284 .6177 L .24253 .61769 L F
.523 .387 .637 r
.2427 .62034 m .24284 .6177 L .24263 .61784 L F
.648 .602 .789 r
.53784 .74599 m .53831 .74361 L .53585 .74639 L F
.53784 .74599 m .53933 .74672 L .53831 .74361 L F
.833 .784 .806 r
.53831 .74361 m .53585 .74639 L .53784 .74599 L F
.815 .954 .615 r
.59653 .53037 m .59878 .52754 L .59713 .53082 L F
.59653 .53037 m .59858 .52718 L .59878 .52754 L F
.818 .951 .607 r
.59878 .52754 m .59858 .52718 L .60048 .52412 L F
.262 .39 .804 r
.51377 .65022 m .51252 .65151 L .51129 .64841 L F
.529 .527 .797 r
.51377 .65022 m .51282 .65387 L .51252 .65151 L F
.964 .719 .518 r
.47387 .77674 m .47532 .77468 L .47392 .77412 L F
.47387 .77674 m .47522 .77766 L .47532 .77468 L F
.934 .829 .717 r
.47491 .77205 m .47532 .77468 L .47768 .77193 L F
.47491 .77205 m .47392 .77412 L .47532 .77468 L F
.453 .156 .371 r
.32308 .62891 m .32521 .62847 L .32607 .62574 L F
.439 .141 .361 r
.32521 .62847 m .32813 .62526 L .32607 .62574 L F
.757 .512 .563 r
.4867 .69038 m .48809 .69061 L .48835 .68809 L F
.692 .454 .557 r
.48835 .68809 m .48809 .69061 L .49153 .69022 L F
.641 .395 .531 r
.59543 .58951 m .59225 .5921 L .59223 .58996 L F
.748 .399 0 r
.59443 .6926 m .5949 .69346 L .59359 .69032 L F
.806 .328 0 r
.59497 .69472 m .5949 .69346 L .59443 .6926 L F
.59497 .69472 m .59641 .69589 L .5949 .69346 L F
.519 .847 .998 r
.75777 .6107 m .75943 .60951 L .75631 .60981 L F
.75777 .6107 m .76047 .61012 L .75943 .60951 L F
.23 0 0 r
.43079 .704 m .42917 .70565 L .42709 .70606 L F
.3 0 0 r
.43307 .7036 m .42917 .70565 L .43079 .704 L F
.19 .336 .782 r
.50886 .64209 m .50791 .64341 L .50663 .64032 L F
.302 .495 .88 r
.50886 .64209 m .51075 .64483 L .50791 .64341 L F
.601 .898 .987 r
.74621 .58604 m .74378 .58688 L .74297 .58622 L F
.121 0 0 r
.33938 .63701 m .33642 .6391 L .3372 .63787 L F
.552 .4 .628 r
.63675 .48318 m .63426 .48625 L .6329 .48229 L F
.63675 .48318 m .63655 .4857 L .63426 .48625 L F
.555 .414 .644 r
.63655 .4857 m .63454 .48868 L .63426 .48625 L F
.469 .246 .492 r
.48582 .76904 m .4879 .76867 L .48804 .76642 L F
.569 .421 .641 r
.48804 .76642 m .49037 .76614 L .49021 .76338 L F
.515 .271 .483 r
.4879 .76867 m .49037 .76614 L .48804 .76642 L F
.053 0 .207 r
.55458 .76517 m .55291 .76664 L .55214 .76863 L F
.889 .755 .708 r
.65501 .50774 m .65663 .50854 L .6558 .50536 L F
.775 .606 .669 r
.65142 .51035 m .65663 .50854 L .65501 .50774 L F
.65142 .51035 m .65531 .5112 L .65663 .50854 L F
.746 .673 .78 r
.65414 .49978 m .6553 .50298 L .65582 .50124 L F
.767 .366 0 r
.65799 .49988 m .65816 .50093 L .65822 .49909 L F
.65823 .49852 m .65822 .49909 L .65825 .49842 L F
.65799 .49988 m .65822 .49909 L .65823 .49852 L F
.974 .742 .525 r
.6583 .50501 m .65786 .50392 L .65776 .50246 L F
.128 .094 .547 r
.65776 .50246 m .6553 .50298 L .65765 .501 L F
0 0 0 r
.65668 .50434 m .65405 .50648 L .65668 .50363 L F
.65668 .50434 m .65668 .50363 L .65776 .50246 L F
.975 .775 .353 r
.65729 .50811 m .65672 .50706 L .65668 .50434 L F
0 0 .122 r
.65668 .50434 m .65672 .50706 L .6569 .50562 L F
.65668 .50434 m .6569 .50562 L .65669 .50491 L F
.979 .889 .666 r
.6558 .50536 m .65405 .50648 L .65501 .50774 L F
.801 .978 .902 r
.6541 .50683 m .65501 .50774 L .65405 .50648 L F
0 0 0 r
.65668 .50434 m .6532 .50741 L .65405 .50648 L F
.767 .366 0 r
.65799 .49988 m .65833 .50065 L .65816 .50093 L F
.65833 .50065 m .65915 .50249 L .65816 .50093 L F
.128 .094 .547 r
.65776 .50246 m .65821 .50052 L .65821 .50065 L F
.944 .944 .752 r
.65776 .50246 m .65813 .50099 L .65816 .50093 L F
.128 .094 .547 r
.65776 .50246 m .65821 .50065 L .65821 .50081 L F
.944 .944 .752 r
.65776 .50246 m .65812 .501 L .65813 .50099 L F
.128 .094 .547 r
.65821 .50081 m .65821 .50052 L .65831 .50044 L F
.322 .738 .977 r
.65825 .50048 m .65776 .50246 L .65831 .50044 L F
0 0 .072 r
.65818 .50075 m .65845 .49746 L .65817 .50081 L F
.689 .33 .361 r
.65388 .49835 m .65824 .50041 L .65414 .49978 L F
.65824 .50041 m .65824 .50043 L .65414 .49978 L F
.404 .471 .816 r
.65823 .50043 m .6553 .50298 L .65414 .49978 L F
.65831 .50044 m .65822 .50052 L .65823 .50043 L F
.65822 .50052 m .6553 .50298 L .65823 .50043 L F
.689 .33 .361 r
.65388 .49835 m .65612 .5018 L .65824 .50049 L F
.65824 .50048 m .65824 .50049 L .65825 .50048 L F
.65388 .49835 m .65824 .50049 L .65824 .50048 L F
0 0 .072 r
.65816 .50093 m .6582 .50075 L .65823 .50027 L F
.65823 .50011 m .65823 .50027 L .65845 .49746 L F
.65816 .50093 m .65823 .50027 L .65823 .50011 L F
.6582 .50075 m .65838 .49975 L .65841 .49875 L F
.6582 .50075 m .65841 .49875 L .65845 .49746 L F
.689 .33 .361 r
.65824 .50041 m .65831 .50044 L .65824 .50043 L F
.65824 .50041 m .65825 .50048 L .65831 .50044 L F
.65388 .49835 m .65825 .50048 L .65824 .50041 L F
0 0 .072 r
.65821 .49952 m .65845 .49746 L .65825 .49842 L F
.65817 .50081 m .65823 .50007 L .65821 .49952 L F
.65823 .50007 m .65845 .49746 L .65821 .49952 L F
.65816 .50093 m .65818 .50075 L .65817 .50081 L F
.128 .094 .547 r
.65776 .50246 m .65765 .501 L .65821 .50052 L F
.322 .738 .977 r
.65652 .50196 m .65776 .50246 L .65825 .5005 L F
.65652 .50196 m .65825 .5005 L .65825 .50048 L F
.65612 .5018 m .65652 .50196 L .65825 .50048 L F
.944 .944 .752 r
.65776 .50246 m .65808 .50108 L .65812 .501 L F
.65808 .50108 m .65838 .49975 L .65816 .50093 L F
.322 .738 .977 r
.65689 .50211 m .65701 .50181 L .65776 .50246 L F
.65612 .5018 m .65701 .50181 L .65689 .50211 L F
0 0 0 r
.65668 .50434 m .65776 .50246 L .65701 .50181 L F
.974 .742 .525 r
.6583 .50501 m .65668 .50434 L .65701 .50181 L F
.968 .925 .603 r
.65668 .50434 m .65727 .50119 L .65701 .50181 L F
.694 .877 .487 r
.65701 .50181 m .65728 .50112 L .65838 .49975 L F
.968 .925 .603 r
.65727 .50119 m .65728 .50112 L .65701 .50181 L F
.741 .672 .122 r
.65689 .50235 m .65701 .50181 L .65692 .50215 L F
.968 .925 .603 r
.65699 .5027 m .65683 .50251 L .65723 .50136 L F
.741 .672 .122 r
.65688 .5024 m .65689 .50233 L .65689 .50235 L F
.65689 .50233 m .65701 .50181 L .65689 .50235 L F
.968 .925 .603 r
.65723 .50136 m .65674 .50239 L .65728 .50112 L F
.793 .338 .163 r
.6534 .5008 m .65578 .50167 L .65388 .49835 L F
.65578 .50167 m .65612 .5018 L .65388 .49835 L F
0 0 .494 r
.65388 .49835 m .65414 .49978 L .65326 .49727 L F
.65388 .49835 m .65326 .49727 L .65294 .49637 L F
.637 .097 0 r
.6534 .5008 m .65701 .50181 L .65612 .5018 L F
.6534 .5008 m .65692 .50215 L .65701 .50181 L F
.968 .925 .603 r
.65683 .50251 m .65674 .50239 L .65723 .50136 L F
.741 .672 .122 r
.65689 .50233 m .65668 .50434 L .65701 .50181 L F
.968 .925 .603 r
.65668 .50434 m .65673 .5026 L .65686 .50266 L F
.741 .672 .122 r
.65688 .5024 m .65668 .50434 L .65689 .50233 L F
.968 .925 .603 r
.65668 .50434 m .65686 .50266 L .65699 .5027 L F
.65673 .5026 m .65674 .50239 L .65699 .5027 L F
.827 1 .814 r
.65673 .5026 m .65262 .50701 L .6532 .50741 L F
.65688 .5024 m .6567 .50259 L .65673 .5026 L F
.6567 .50259 m .65262 .50701 L .65673 .5026 L F
.65688 .5024 m .65673 .5026 L .65668 .50434 L F
.65673 .5026 m .6532 .50741 L .65668 .50434 L F
.852 .991 .845 r
.65455 .50307 m .65262 .50701 L .6567 .50259 L F
.968 .925 .603 r
.65673 .50263 m .65667 .50255 L .65674 .50239 L F
.852 .991 .845 r
.65661 .50248 m .6567 .50259 L .65688 .5024 L F
.65455 .50307 m .6567 .50259 L .65661 .50248 L F
.968 .925 .603 r
.65668 .50434 m .65626 .5035 L .65667 .50255 L F
.65668 .50434 m .65667 .50255 L .65673 .50263 L F
0 0 .122 r
.65668 .50434 m .65669 .50491 L .65626 .5035 L F
.974 .742 .525 r
.65786 .50392 m .65701 .50181 L .65776 .50246 L F
.992 .882 .6 r
.5712 .76326 m .57192 .76089 L .57042 .76252 L F
.994 .868 .594 r
.57042 .76252 m .57192 .76089 L .5715 .75785 L F
.57 .273 .424 r
.36807 .72461 m .36772 .72702 L .37 .72628 L F
.447 .174 .405 r
.61039 .56452 m .61263 .56393 L .61313 .56206 L F
.268 .014 .332 r
.61313 .56206 m .61263 .56393 L .61492 .56112 L F
.643 .854 .98 r
.69449 .48774 m .69883 .48745 L .69773 .48616 L F
.517 .691 .947 r
.69883 .48745 m .70009 .48568 L .69773 .48616 L F
.69883 .48745 m .70189 .48793 L .70009 .48568 L F
.966 .645 .345 r
.67953 .52392 m .68165 .52817 L .67971 .52683 L F
.873 .877 .836 r
.68165 .52817 m .67861 .53123 L .67771 .52971 L F
.68165 .52817 m .67771 .52971 L .6801 .52918 L F
.68165 .52817 m .6801 .52918 L .67971 .52683 L F
.528 .542 .813 r
.68353 .52725 m .68165 .52817 L .67953 .52392 L F
.605 .539 .753 r
.68459 .53043 m .68165 .52817 L .68353 .52725 L F
.476 .486 .789 r
.53933 .74672 m .54047 .74341 L .53831 .74361 L F
.53933 .74672 m .5416 .74673 L .54047 .74341 L F
.453 .162 .379 r
.5416 .74673 m .53966 .74848 L .53933 .74672 L F
.953 .637 .392 r
.66527 .50334 m .66688 .50262 L .66581 .50168 L F
.66527 .50334 m .66701 .50484 L .66688 .50262 L F
.834 .927 .894 r
.66581 .50168 m .66688 .50262 L .66948 .50032 L F
.195 0 0 r
.33048 .64365 m .32963 .64273 L .33138 .64271 L F
.33048 .64365 m .32841 .64435 L .32963 .64273 L F
0 .063 .626 r
.49489 .69071 m .49695 .69348 L .49648 .69322 L F
.787 .52 .532 r
.49832 .69619 m .49494 .69577 L .49648 .69322 L F
.346 .041 .298 r
.28313 .61518 m .28221 .61717 L .28035 .61767 L F
.454 .222 .471 r
.28464 .61428 m .28221 .61717 L .28313 .61518 L F
.397 .172 .452 r
.3497 .62646 m .35195 .62354 L .35143 .6256 L F
.215 0 .338 r
.35143 .6256 m .35195 .62354 L .35343 .62272 L F
.358 .05 .299 r
.349 .62826 m .34696 .62881 L .3497 .62646 L F
.231 0 .237 r
.349 .62826 m .3497 .62646 L .35143 .6256 L F
.208 .224 .657 r
.46822 .76929 m .47035 .77036 L .47021 .7684 L F
.46822 .76929 m .46888 .77159 L .47035 .77036 L F
.331 0 .134 r
.53242 .80586 m .52939 .80788 L .53101 .80811 L F
.493 .373 .645 r
.53416 .8076 m .53235 .80861 L .53235 .80854 L F
.53416 .8076 m .53235 .80854 L .53242 .80586 L F
.628 .902 .985 r
.53603 .80664 m .53416 .8076 L .53605 .80663 L F
.667 .13 0 r
.53242 .80586 m .53416 .8076 L .5331 .80705 L F
.53242 .80586 m .53416 .8076 L .5331 .80705 L F
.628 .902 .985 r
.5331 .80705 m .53416 .8076 L .53603 .80664 L F
.667 .13 0 r
.53242 .80586 m .5331 .80705 L .53101 .80811 L F
.996 .864 .574 r
.53167 .80558 m .53242 .80586 L .53101 .80811 L F
.667 .13 0 r
.53242 .80586 m .5331 .80705 L .53167 .80558 L F
.16 0 .359 r
.58053 .72398 m .58267 .72099 L .58284 .72361 L F
.688 .195 .071 r
.58406 .72625 m .58166 .7247 L .58284 .72361 L F
.58166 .7247 m .58053 .72398 L .58172 .72379 L F
.58166 .7247 m .58172 .72379 L .58284 .72361 L F
.58406 .72625 m .58082 .7248 L .58053 .72398 L F
.16 0 .359 r
.58053 .72398 m .58082 .7248 L .58267 .72099 L F
.889 .812 .766 r
.58189 .72146 m .58082 .7248 L .57931 .72303 L F
.58267 .72099 m .5818 .72279 L .58189 .72146 L F
.5818 .72279 m .58082 .7248 L .58189 .72146 L F
.555 .46 .702 r
.28061 .62255 m .27906 .62626 L .27874 .62364 L F
.871 .96 .858 r
.57121 .7236 m .57029 .72303 L .56916 .72428 L F
.828 .391 0 r
.56675 .72076 m .568 .72193 L .56466 .71977 L F
.56675 .72076 m .56885 .72417 L .568 .72193 L F
.56885 .72417 m .56919 .72472 L .569 .72429 L F
.56885 .72417 m .569 .72429 L .568 .72193 L F
.871 .96 .858 r
.57022 .72424 m .56916 .72428 L .56909 .72436 L F
.56952 .72469 m .56909 .72436 L .5678 .7258 L F
.57022 .72424 m .56909 .72436 L .56952 .72469 L F
.57121 .7236 m .56916 .72428 L .57022 .72424 L F
.831 .395 .198 r
.568 .72193 m .569 .72429 L .56889 .72142 L F
.871 .96 .858 r
.57121 .7236 m .5678 .7258 L .56863 .72604 L F
.382 .147 .428 r
.57029 .72303 m .56992 .72567 L .5678 .7258 L F
.831 .395 .198 r
.569 .72429 m .56919 .72472 L .56915 .72428 L F
.569 .72429 m .56915 .72428 L .56889 .72142 L F
.212 0 .255 r
.56889 .72142 m .57029 .72303 L .57121 .7236 L F
.56889 .72142 m .56919 .72472 L .57029 .72303 L F
.754 .379 .345 r
.49153 .69022 m .4935 .69262 L .49489 .69071 L F
.802 .444 .379 r
.4935 .69262 m .49695 .69348 L .49489 .69071 L F
.814 .595 .606 r
.47527 .7693 m .47491 .77205 L .47768 .77193 L F
.392 0 0 r
.47522 .77766 m .47799 .778 L .47891 .77754 L F
.073 .294 .779 r
.4801 .77725 m .48125 .77961 L .47891 .77754 L F
.48043 .77717 m .48065 .77782 L .4801 .77725 L F
.48065 .77782 m .48125 .77961 L .4801 .77725 L F
0 0 .335 r
.48201 .78083 m .48178 .78047 L .48194 .77922 L F
.48178 .78047 m .48125 .77961 L .48194 .77922 L F
0 0 .174 r
.48267 .77656 m .48194 .77922 L .48125 .77961 L F
.632 .437 .6 r
.48195 .77919 m .48194 .77922 L .48195 .77919 L F
.48053 .78074 m .48194 .77922 L .48195 .77919 L F
.48154 .77876 m .48195 .77919 L .48267 .77656 L F
.48053 .78074 m .48195 .77919 L .48154 .77876 L F
.073 .294 .779 r
.48043 .77717 m .47891 .77754 L .47799 .778 L F
.628 .849 .468 r
.51422 .79476 m .51465 .79428 L .51523 .79332 L F
.473 .88 .948 r
.39062 .71524 m .3895 .71619 L .39206 .71613 L F
.39062 .71524 m .38843 .71599 L .3895 .71619 L F
.433 .266 .554 r
.51454 .66253 m .51458 .6649 L .5127 .66546 L F
.461 .369 .665 r
.51458 .6649 m .51322 .6679 L .5127 .66546 L F
.567 .64 .883 r
.76974 .61157 m .77201 .61106 L .7687 .60979 L F
0 .258 .764 r
.64054 .48534 m .64157 .48511 L .63908 .48297 L F
.047 .452 .878 r
.64054 .48534 m .64261 .48641 L .64157 .48511 L F
.538 .477 .736 r
.24681 .62389 m .24862 .62307 L .24586 .6227 L F
.24681 .62389 m .24931 .6257 L .24862 .62307 L F
.702 .17 0 r
.52275 .81027 m .52113 .80942 L .5219 .80953 L F
.079 0 .017 r
.5219 .80953 m .52113 .80942 L .51929 .81213 L F
.5219 .80953 m .51929 .81213 L .52145 .80915 L F
.5219 .80953 m .52145 .80915 L .522 .8084 L F
.702 .17 0 r
.52411 .81099 m .52275 .81027 L .5219 .80953 L F
.72 .902 .96 r
.52085 .81132 m .52411 .81099 L .5219 .80953 L F
.456 .529 .843 r
.74621 .60064 m .74749 .60376 L .74912 .60211 L F
.37 .391 .752 r
.74749 .60376 m .7501 .60559 L .74912 .60211 L F
.279 .759 .928 r
.7199 .519 m .71659 .51888 L .71739 .51917 L F
0 0 0 r
.5705 .6954 m .5716 .69225 L .56978 .69354 L F
.544 .492 .748 r
.5716 .69225 m .57403 .69265 L .57335 .69028 L F
.118 0 0 r
.32011 .63033 m .32308 .62891 L .32098 .62935 L F
.85 .742 .744 r
.25332 .64582 m .25043 .6471 L .25248 .64474 L F
.25332 .64582 m .25211 .64857 L .25043 .6471 L F
.47 .306 .576 r
.37691 .67113 m .37883 .67262 L .37888 .67061 L F
.37691 .67113 m .37692 .67323 L .37883 .67262 L F
0 0 0 r
.40191 .71467 m .40378 .71393 L .40582 .7133 L F
.455 .299 .58 r
.50655 .66949 m .50733 .66825 L .50376 .66765 L F
.50655 .66949 m .50761 .66976 L .50733 .66825 L F
.50655 .66949 m .50761 .66976 L .50733 .66825 L F
.886 .991 .783 r
.59441 .53312 m .59713 .53082 L .59521 .53388 L F
.59441 .53312 m .59653 .53037 L .59713 .53082 L F
0 0 0 r
.47021 .7684 m .47284 .76628 L .47065 .76613 L F
.175 .709 .742 r
.45169 .64515 m .45496 .64458 L .45286 .64499 L F
.86 .802 .792 r
.39461 .7147 m .39527 .71641 L .39767 .71308 L F
.39398 .71504 m .39466 .71577 L .39461 .7147 L F
.39466 .71577 m .39527 .71641 L .39461 .7147 L F
.39398 .71504 m .39767 .71308 L .39511 .71476 L F
.652 .645 .83 r
.39445 .71123 m .39511 .71476 L .39501 .71099 L F
.39271 .71196 m .39458 .71415 L .39445 .71123 L F
.39458 .71415 m .39511 .71476 L .39445 .71123 L F
.223 0 0 r
.39767 .71308 m .39753 .71322 L .39511 .71476 L F
.39767 .71308 m .39964 .71347 L .39753 .71322 L F
.591 .343 .509 r
.62699 .53655 m .62737 .53865 L .62492 .53893 L F
0 0 0 r
.62492 .53893 m .62632 .5375 L .62699 .53655 L F
.851 .822 .342 r
.62699 .53655 m .62632 .5375 L .62695 .53533 L F
.726 .495 .577 r
.63067 .53638 m .62737 .53865 L .62699 .53655 L F
0 0 .4 r
.47961 .75486 m .48062 .7564 L .4816 .75398 L F
.745 .862 .934 r
.48424 .75193 m .4816 .75398 L .48408 .75263 L F
.338 0 .085 r
.4816 .75398 m .48283 .75597 L .48408 .75263 L F
.4816 .75398 m .48062 .7564 L .48283 .75597 L F
.03 0 .022 r
.48262 .75299 m .4816 .75398 L .48424 .75193 L F
.919 .94 .584 r
.5896 .54091 m .59087 .53952 L .58998 .54138 L F
.871 .995 .775 r
.59121 .53771 m .59299 .53679 L .59087 .53952 L F
.867 .944 .58 r
.5896 .54091 m .59121 .53771 L .59087 .53952 L F
.47 .336 .617 r
.48582 .76904 m .48804 .77125 L .4879 .76867 L F
.48582 .76904 m .48613 .77193 L .48804 .77125 L F
.457 .225 .474 r
.24467 .60094 m .24667 .60044 L .24705 .59824 L F
.508 .335 .582 r
.24705 .59824 m .2491 .59774 L .24913 .59525 L F
.433 .204 .466 r
.24705 .59824 m .2486 .59985 L .2491 .59774 L F
.24705 .59824 m .24667 .60044 L .2486 .59985 L F
.738 .543 .63 r
.51811 .76646 m .51776 .76899 L .51394 .76891 L F
.496 .307 .553 r
.55203 .7522 m .5503 .7541 L .54854 .7517 L F
.55203 .7522 m .55133 .75478 L .5503 .7541 L F
.381 .324 .669 r
.24284 .6177 m .24178 .6149 L .24253 .61769 L F
.653 .505 .669 r
.57411 .72852 m .57354 .72986 L .57597 .72737 L F
0 .239 .726 r
.63457 .49518 m .63498 .49477 L .63316 .49367 L F
.935 .943 .773 r
.63587 .49659 m .63457 .49518 L .63372 .4972 L F
.936 .94 .772 r
.63623 .49303 m .63535 .49554 L .63587 .49659 L F
.544 .377 .605 r
.63587 .49659 m .63373 .49993 L .63372 .4972 L F
0 0 .26 r
.63372 .4972 m .63411 .49763 L .63587 .49659 L F
.935 .943 .773 r
.6349 .49553 m .63497 .49477 L .63457 .49518 L F
.63587 .49659 m .63535 .49554 L .6349 .49553 L F
.63535 .49554 m .63497 .49477 L .6349 .49553 L F
0 0 .066 r
.63612 .49405 m .63549 .49555 L .63623 .49303 L F
0 0 .26 r
.63485 .49719 m .63464 .49747 L .63587 .49659 L F
.63464 .49747 m .63465 .49747 L .63587 .49659 L F
.936 .94 .772 r
.63549 .49583 m .635 .49722 L .63587 .49659 L F
.63535 .49554 m .635 .49722 L .63549 .49583 L F
.63535 .49554 m .63468 .49745 L .635 .49722 L F
.63468 .49745 m .6346 .49768 L .63587 .49659 L F
.935 .943 .773 r
.63517 .49517 m .63498 .49477 L .63497 .49477 L F
.63587 .49659 m .63518 .49519 L .63517 .49517 L F
.63518 .49519 m .63498 .49477 L .63517 .49517 L F
0 0 0 r
.63644 .49627 m .63625 .49642 L .63612 .49405 L F
0 0 .26 r
.63464 .49747 m .63462 .49749 L .63465 .49747 L F
0 0 .066 r
.63536 .49554 m .6346 .49768 L .63535 .49554 L F
.935 .943 .773 r
.63536 .49554 m .6346 .49768 L .63498 .49477 L F
.63587 .49659 m .6346 .49768 L .63536 .49554 L F
0 0 .066 r
.63549 .49555 m .6346 .49768 L .63536 .49554 L F
0 0 0 r
.63625 .49642 m .63492 .49743 L .63556 .49563 L F
.63625 .49642 m .63556 .49563 L .63612 .49405 L F
.63492 .49743 m .6346 .49768 L .63469 .49747 L F
.63492 .49743 m .63469 .49747 L .63612 .49405 L F
0 0 .26 r
.63411 .49763 m .63443 .49754 L .63485 .49719 L F
.63443 .49754 m .63462 .49749 L .63485 .49719 L F
.63372 .4972 m .63373 .49993 L .63427 .49866 L F
.63421 .49773 m .63427 .49866 L .63452 .49806 L F
.63372 .4972 m .63427 .49866 L .63421 .49773 L F
.357 0 0 r
.63418 .49733 m .63245 .49782 L .63203 .49554 L F
.63443 .49754 m .6342 .49757 L .63418 .49733 L F
.6342 .49757 m .63245 .49782 L .63418 .49733 L F
.6346 .49768 m .63423 .4977 L .63443 .49754 L F
0 0 .26 r
.63411 .49763 m .63424 .49777 L .63462 .49749 L F
.357 0 0 r
.63423 .4977 m .63245 .49782 L .63443 .49754 L F
0 0 .066 r
.63549 .49555 m .63535 .49554 L .63623 .49303 L F
.544 .6 .86 r
.63498 .49477 m .63463 .49749 L .63203 .49554 L F
.63463 .49749 m .6346 .49768 L .63443 .49754 L F
.63463 .49749 m .63443 .49754 L .63203 .49554 L F
0 0 0 r
.63492 .49743 m .63452 .49806 L .6346 .49768 L F
0 0 .26 r
.63511 .49713 m .63452 .49806 L .63587 .49659 L F
.544 .377 .605 r
.63587 .49659 m .63597 .49941 L .63373 .49993 L F
.587 .378 .564 r
.63723 .49632 m .63597 .49941 L .63587 .49659 L F
.984 .733 .468 r
.63587 .49659 m .63597 .49941 L .63452 .49806 L F
0 0 0 r
.63587 .49659 m .63452 .49806 L .63644 .49627 L F
.63644 .49627 m .63452 .49806 L .63492 .49743 L F
0 0 .26 r
.63424 .49777 m .63452 .49806 L .63511 .49713 L F
.144 0 0 r
.31643 .64864 m .31664 .64906 L .31485 .64928 L F
.31643 .64864 m .31873 .64863 L .31664 .64906 L F
.576 .537 .775 r
.54752 .76032 m .54559 .76129 L .5441 .75718 L F
.102 0 0 r
.71421 .48972 m .71291 .48986 L .71043 .48978 L F
.869 .995 .794 r
.71456 .48797 m .71421 .48972 L .71565 .48952 L F
.71456 .48797 m .71291 .48986 L .71421 .48972 L F
.576 .488 .718 r
.71421 .48972 m .71611 .4903 L .71565 .48952 L F
.624 .072 0 r
.5064 .75681 m .50798 .75767 L .5097 .75784 L F
.824 .399 .23 r
.50798 .75767 m .50877 .75919 L .5097 .75784 L F
.916 .544 .302 r
.50877 .75919 m .51074 .7604 L .5097 .75784 L F
.786 .502 .507 r
.5097 .75784 m .51074 .7604 L .51285 .76011 L F
.112 .372 .833 r
.51314 .78881 m .51001 .78608 L .51233 .7857 L F
.808 .796 .84 r
.67707 .48519 m .6784 .48662 L .68019 .48539 L F
.586 .175 .229 r
.30886 .6013 m .30761 .60307 L .30514 .60273 L F
.107 0 0 r
.31115 .6013 m .30761 .60307 L .30886 .6013 L F
.124 .33 .797 r
.66379 .52811 m .66504 .52706 L .66288 .52687 L F
.66379 .52811 m .66573 .52993 L .66504 .52706 L F
.495 .482 .772 r
.38058 .68763 m .38241 .68707 L .37962 .68533 L F
.88 .549 .419 r
.7096 .49809 m .71179 .50009 L .71249 .49768 L F
.56 .412 .637 r
.71249 .49768 m .71503 .49725 L .71471 .4943 L F
.975 .761 .551 r
.74955 .59134 m .75073 .59226 L .74968 .58923 L F
.755 .687 .785 r
.75073 .59226 m .75325 .58974 L .74968 .58923 L F
.681 .772 .92 r
.74968 .58923 m .75325 .58974 L .75178 .58876 L F
.499 .366 .631 r
.75307 .5894 m .75073 .59226 L .74955 .59134 L F
.311 .651 .97 r
.75178 .58876 m .75325 .58974 L .75488 .58952 L F
.499 .366 .631 r
.75307 .5894 m .75325 .59468 L .75073 .59226 L F
0 0 .469 r
.48478 .77746 m .48543 .77684 L .48469 .7736 L F
0 .172 .708 r
.48478 .77746 m .48687 .77995 L .48543 .77684 L F
.61 .425 .606 r
.48473 .77999 m .48687 .77995 L .48478 .77746 L F
.606 .612 .831 r
.41217 .69223 m .41128 .69532 L .40986 .69284 L F
.41217 .69223 m .41362 .69503 L .41128 .69532 L F
0 .297 .793 r
.75325 .59468 m .75492 .59724 L .75448 .595 L F
.299 0 .111 r
.54051 .73004 m .54226 .72969 L .54367 .72737 L F
.576 .186 .267 r
.54367 .72737 m .54226 .72969 L .546 .72872 L F
.914 .757 .672 r
.65991 .52141 m .65886 .51883 L .66107 .51844 L F
.362 .071 .33 r
.35614 .6202 m .35343 .62272 L .35419 .62081 L F
.769 .987 .753 r
.55439 .79235 m .55261 .79433 L .55229 .79402 L F
.687 .876 .969 r
.54906 .79672 m .55191 .79644 L .55158 .79663 L F
.909 .856 .411 r
.55229 .79402 m .55261 .79433 L .55158 .79663 L F
.377 0 .035 r
.55261 .79433 m .55367 .79577 L .55191 .79644 L F
.55261 .79433 m .55515 .79413 L .55367 .79577 L F
.56 .411 .636 r
.55439 .79235 m .55515 .79413 L .55261 .79433 L F
.742 .819 .911 r
.76047 .61012 m .76341 .60998 L .76268 .60991 L F
.603 .135 .115 r
.76584 .60947 m .76268 .60991 L .76341 .60998 L F
.111 .569 .916 r
.2448 .63128 m .24497 .63132 L .24559 .63179 L F
.894 .896 .822 r
.24559 .63179 m .24497 .63132 L .24478 .63157 L F
.439 .853 .689 r
.55377 .7476 m .55208 .74836 L .55058 .74939 L F
0 0 .506 r
.55377 .7476 m .55413 .74752 L .55208 .74836 L F
.387 0 .075 r
.55659 .74706 m .55521 .74921 L .55377 .7476 L F
0 0 .506 r
.55377 .7476 m .55521 .74921 L .55413 .74752 L F
.633 .242 .285 r
.42006 .6677 m .4186 .6698 L .41644 .66808 L F
.639 .249 .289 r
.42184 .66953 m .42006 .6677 L .42221 .66789 L F
.42184 .66953 m .4186 .6698 L .42006 .6677 L F
.359 .348 .711 r
.46773 .78009 m .46819 .78317 L .47008 .78233 L F
.196 .122 .541 r
.46819 .78317 m .46998 .78458 L .47008 .78233 L F
.46819 .78317 m .46831 .78578 L .46998 .78458 L F
.285 .727 .963 r
.34206 .59162 m .33874 .59105 L .34074 .5911 L F
.15 .688 .836 r
.34265 .59136 m .34206 .59162 L .34074 .5911 L F
.34265 .59136 m .34415 .5915 L .34206 .59162 L F
.899 .956 .827 r
.59303 .53456 m .59521 .53388 L .59299 .53679 L F
.937 .963 .744 r
.59121 .53771 m .59303 .53456 L .59299 .53679 L F
.182 0 0 r
.43659 .69122 m .43723 .6921 L .43842 .69155 L F
.43659 .69122 m .43524 .69262 L .43723 .6921 L F
.979 .904 .665 r
.72368 .50611 m .72281 .50531 L .72335 .50333 L F
.38 0 0 r
.48826 .75525 m .48642 .75689 L .48414 .75685 L F
0 0 0 r
.48864 .75604 m .48826 .75525 L .48991 .75422 L F
.48864 .75604 m .48642 .75689 L .48826 .75525 L F
.898 .813 .756 r
.64498 .5294 m .64635 .53067 L .64568 .52743 L F
.872 .718 .688 r
.64315 .53253 m .64635 .53067 L .64498 .5294 L F
.64315 .53253 m .64501 .53346 L .64635 .53067 L F
.771 .742 .826 r
.64568 .52743 m .64635 .53067 L .64893 .52786 L F
.303 0 0 r
.27269 .5853 m .27481 .5853 L .27314 .58494 L F
.926 .539 .213 r
.56982 .75564 m .57133 .75522 L .57031 .75438 L F
.56982 .75564 m .57128 .75757 L .57133 .75522 L F
.594 .336 .495 r
.60513 .57184 m .60328 .57054 L .60304 .57236 L F
.60513 .57184 m .60556 .57008 L .60328 .57054 L F
.488 .306 .56 r
.24467 .60094 m .24461 .60331 L .24667 .60044 L F
.451 .218 .468 r
.51812 .69303 m .51574 .69572 L .51597 .6936 L F
.711 .19 0 r
.5128 .79019 m .51458 .79127 L .51313 .78971 L F
0 0 .366 r
.73175 .497 m .73269 .49899 L .733 .49994 L F
.997 .854 .528 r
.73269 .49899 m .73288 .50218 L .733 .49994 L F
.612 .43 .611 r
.53578 .74392 m .53585 .74639 L .53831 .74361 L F
.75 .569 .65 r
.57707 .58944 m .57508 .59213 L .57518 .58974 L F
.57707 .58944 m .57858 .59247 L .57508 .59213 L F
.656 .748 .918 r
.77287 .61275 m .774 .61052 L .77201 .61106 L F
.77287 .61275 m .77529 .61195 L .774 .61052 L F
.884 .642 .568 r
.62919 .51687 m .62649 .51736 L .62638 .51624 L F
.62919 .51687 m .62833 .51825 L .62649 .51736 L F
.541 .17 .286 r
.46049 .69321 m .45932 .69537 L .45694 .69544 L F
.581 .247 .367 r
.46276 .69308 m .45932 .69537 L .46049 .69321 L F
0 0 .116 r
.65799 .49988 m .65825 .49842 L .65826 .49582 L F
.627 .593 .795 r
.511 .67118 m .50733 .66825 L .50945 .66831 L F
.736 .64 .752 r
.51322 .6679 m .511 .67118 L .50945 .66831 L F
.558 .403 .627 r
.51322 .6679 m .51323 .67103 L .511 .67118 L F
.975 .704 .454 r
.51071 .67331 m .511 .67118 L .51323 .67103 L F
.76 .677 .771 r
.56691 .58101 m .56807 .58393 L .56472 .58384 L F
.637 .43 .586 r
.56807 .58393 m .56545 .58635 L .56472 .58384 L F
.56807 .58393 m .56802 .5867 L .56545 .58635 L F
0 0 0 r
.48414 .75685 m .48251 .75801 L .48234 .75739 L F
.661 .333 .408 r
.51801 .7831 m .51878 .78387 L .51766 .78358 L F
.609 .342 .488 r
.51801 .7831 m .52073 .78452 L .51878 .78387 L F
.246 .713 .946 r
.28991 .58467 m .29242 .58462 L .29373 .58531 L F
0 .465 .742 r
.2942 .5853 m .29373 .58531 L .29242 .58462 L F
.2942 .5853 m .2957 .58575 L .29373 .58531 L F
.368 .278 .621 r
.70569 .50578 m .70597 .50825 L .70584 .50558 L F
.98 .882 .521 r
.54585 .75467 m .54526 .75401 L .54646 .75243 L F
.635 .51 .693 r
.54841 .75033 m .54646 .75243 L .54854 .7517 L F
.54841 .75033 m .54646 .75243 L .54854 .7517 L F
0 0 0 r
.54646 .75243 m .54733 .75157 L .54854 .7517 L F
.54646 .75243 m .54526 .75401 L .54733 .75157 L F
.655 .365 .466 r
.53067 .77533 m .53293 .77732 L .53471 .77461 L F
.75 .483 .529 r
.53293 .77732 m .53612 .77741 L .53471 .77461 L F
.852 .946 .88 r
.4914 .79691 m .48836 .79805 L .49047 .79888 L F
.996 .776 .422 r
.49048 .79635 m .4914 .79691 L .49047 .79888 L F
.768 .736 .824 r
.64029 .52487 m .63734 .52801 L .6369 .52499 L F
.59 .229 .325 r
.51122 .81401 m .50986 .81171 L .50874 .81285 L F
.288 0 .104 r
.62247 .48797 m .62472 .48789 L .62542 .48618 L F
.253 0 .09 r
.62542 .48618 m .62689 .4871 L .62762 .48536 L F
.62542 .48618 m .62472 .48789 L .62689 .4871 L F
.781 .967 .666 r
.7072 .50026 m .70562 .50265 L .70614 .50112 L F
.153 0 0 r
.70634 .50358 m .70562 .50265 L .70614 .50112 L F
.70634 .50358 m .70402 .50431 L .70562 .50265 L F
.995 .755 .429 r
.5975 .56167 m .59605 .56224 L .59601 .56447 L F
.5975 .56167 m .59621 .56038 L .59605 .56224 L F
.916 .851 .764 r
.5975 .56167 m .59703 .55812 L .59621 .56038 L F
.5975 .56167 m .59818 .55927 L .59703 .55812 L F
.619 .83 .981 r
.55729 .70753 m .55404 .70763 L .55584 .70671 L F
.558 .357 .563 r
.55954 .70724 m .55718 .70999 L .55729 .70753 L F
.373 .02 .231 r
.44677 .6987 m .44351 .70051 L .44449 .69915 L F
.259 .647 .965 r
.76593 .57328 m .76417 .57382 L .76334 .57342 L F
.76593 .57328 m .76712 .57437 L .76417 .57382 L F
.715 .45 .523 r
.37695 .7091 m .3792 .71009 L .37685 .70939 L F
.589 .805 .982 r
.28412 .65109 m .28792 .65161 L .28624 .6508 L F
.1 0 0 r
.29176 .64997 m .28905 .6505 L .28932 .6497 L F
0 0 0 r
.28932 .6497 m .28792 .65161 L .28957 .64897 L F
.355 0 .006 r
.28932 .6497 m .28624 .6508 L .28792 .65161 L F
.1 0 0 r
.28905 .6505 m .28813 .65068 L .28932 .6497 L F
0 0 0 r
.28932 .6497 m .28957 .64897 L .28982 .64856 L F
.899 .956 .827 r
.59303 .53456 m .59441 .53312 L .59521 .53388 L F
.676 .268 .264 r
.50185 .69628 m .50049 .69809 L .49832 .69619 L F
0 0 0 r
.50415 .69335 m .503 .69511 L .50185 .69628 L F
.503 .69511 m .50049 .69809 L .50185 .69628 L F
.676 .394 .487 r
.57846 .59544 m .57848 .5975 L .57628 .59731 L F
.657 .519 .684 r
.58061 .59222 m .57846 .59544 L .57858 .59247 L F
.58061 .59222 m .58166 .59464 L .57846 .59544 L F
.653 .421 .555 r
.58166 .59464 m .57848 .5975 L .57846 .59544 L F
.726 .495 .577 r
.63067 .53638 m .63112 .53896 L .62737 .53865 L F
0 0 0 r
.63765 .55582 m .63925 .55492 L .63653 .55685 L F
.655 .402 .524 r
.60384 .58685 m .60396 .58896 L .60022 .5894 L F
.62 .375 .525 r
.60384 .58685 m .60606 .58892 L .60396 .58896 L F
.69 .354 .402 r
.60624 .5873 m .60606 .58892 L .60384 .58685 L F
.693 .869 .965 r
.47834 .64072 m .47431 .64132 L .47683 .63938 L F
.751 .789 .884 r
.48021 .63946 m .47834 .64072 L .47683 .63938 L F
.655 .667 .849 r
.77497 .58587 m .7761 .58876 L .77855 .58687 L F
.84 .975 .878 r
.25266 .65349 m .25334 .65417 L .256 .65176 L F
.734 .333 .291 r
.2516 .65592 m .25334 .65417 L .25266 .65349 L F
.2516 .65592 m .25419 .65594 L .25334 .65417 L F
.896 .815 .759 r
.54308 .77103 m .54668 .76986 L .54549 .77008 L F
.54308 .77103 m .54385 .77151 L .54668 .76986 L F
.798 .602 .636 r
.54668 .76986 m .54742 .77348 L .54423 .77405 L F
.416 .148 .397 r
.54668 .76986 m .54423 .77405 L .5469 .77327 L F
.755 .644 .738 r
.54783 .76774 m .54668 .76986 L .54728 .76905 L F
.633 .496 .677 r
.5498 .77135 m .54742 .77348 L .54668 .76986 L F
.564 .255 .403 r
.5469 .77327 m .54869 .77328 L .54668 .76986 L F
.633 .496 .677 r
.5498 .77135 m .54668 .76986 L .54869 .77328 L F
.204 .573 .94 r
.77258 .57732 m .7715 .57781 L .77213 .57746 L F
.77258 .57732 m .77354 .57846 L .7715 .57781 L F
.273 .203 .593 r
.46888 .77159 m .46844 .77503 L .4705 .77388 L F
.566 .374 .58 r
.46844 .77503 m .47365 .77639 L .4705 .77388 L F
.46844 .77503 m .46923 .77728 L .47365 .77639 L F
.024 .2 .708 r
.72811 .48817 m .72996 .49 L .7292 .49117 L F
.51 0 0 r
.73029 .49228 m .7292 .49117 L .72996 .49 L F
0 .183 .716 r
.7292 .49117 m .73148 .49331 L .73176 .49436 L F
.51 0 0 r
.73029 .49228 m .73095 .49282 L .7292 .49117 L F
.985 .838 .451 r
.72975 .49128 m .72967 .49177 L .73029 .49228 L F
.72967 .49177 m .72936 .49355 L .73029 .49228 L F
.51 0 0 r
.73029 .49228 m .73148 .49331 L .73095 .49282 L F
0 0 0 r
.60973 .56626 m .61263 .56393 L .61039 .56452 L F
.382 0 .157 r
.44402 .6896 m .4471 .68793 L .44482 .68838 L F
.7 .724 .868 r
.69309 .48865 m .69413 .48499 L .69184 .48548 L F
.69309 .48865 m .69449 .48774 L .69413 .48499 L F
.598 .905 .983 r
.58885 .68629 m .58999 .68693 L .58884 .68712 L F
.829 .427 .285 r
.58885 .68629 m .5926 .6894 L .58999 .68693 L F
.613 .404 .574 r
.38748 .65646 m .38731 .65409 L .38517 .65653 L F
.554 .356 .566 r
.38748 .65646 m .38983 .65374 L .38731 .65409 L F
.651 .742 .916 r
.67472 .4859 m .6784 .48662 L .67707 .48519 L F
.54 .195 .332 r
.4506 .69711 m .44907 .69875 L .44677 .6987 L F
.466 .121 .296 r
.45249 .69614 m .44907 .69875 L .4506 .69711 L F
.88 .549 .419 r
.7096 .49809 m .71113 .50048 L .71179 .50009 L F
.263 .062 .408 r
.48748 .8025 m .48706 .80522 L .4857 .80519 L F
.395 .14 .405 r
.34846 .63024 m .34696 .62881 L .349 .62826 L F
.34846 .63024 m .3465 .63089 L .34696 .62881 L F
.879 .796 .764 r
.71833 .51346 m .7193 .51271 L .71762 .51096 L F
.836 .663 .12 r
.73155 .49562 m .73176 .49436 L .73148 .49331 L F
.73155 .49562 m .73175 .497 L .73176 .49436 L F
.316 .201 .56 r
.58786 .7157 m .58987 .71483 L .58965 .71247 L F
.499 .34 .596 r
.58759 .7182 m .58987 .71483 L .58786 .7157 L F
.466 .767 .996 r
.33477 .59045 m .33267 .591 L .33115 .58993 L F
.773 .975 .7 r
.6166 .5186 m .61829 .51741 L .61653 .51607 L F
.742 .708 .819 r
.71142 .48002 m .70943 .48189 L .70798 .47953 L F
.574 .787 .98 r
.62801 .50161 m .63132 .50226 L .62901 .50282 L F
.36 .209 .537 r
.63017 .50463 m .63132 .50226 L .62901 .50282 L F
.479 .301 .561 r
.28221 .61717 m .28016 .62012 L .28035 .61767 L F
.993 .828 .576 r
.66059 .51142 m .65955 .51044 L .66012 .50803 L F
.923 .884 .778 r
.66059 .51142 m .65829 .51241 L .65955 .51044 L F
.66059 .51142 m .65925 .51347 L .65829 .51241 L F
.426 .233 .514 r
.60556 .57008 m .60772 .56699 L .60553 .56762 L F
.347 .231 .576 r
.46773 .78009 m .46923 .77728 L .46714 .77777 L F
.455 .033 .149 r
.42803 .66537 m .42699 .6671 L .42438 .66737 L F
.091 0 0 r
.42869 .66639 m .42803 .66537 L .42991 .66444 L F
.42869 .66639 m .42699 .6671 L .42803 .66537 L F
.968 .902 .701 r
.64894 .50934 m .64901 .51264 L .6504 .51128 L F
.645 .837 .974 r
.64901 .51264 m .6523 .51216 L .6504 .51128 L F
.588 .736 .946 r
.64894 .50934 m .6504 .51128 L .65142 .51035 L F
.532 .631 .894 r
.6504 .51128 m .6523 .51216 L .65142 .51035 L F
.588 .736 .946 r
.64894 .50934 m .6504 .51128 L .65142 .51035 L F
.476 .21 .431 r
.36162 .61414 m .36077 .61709 L .35863 .61749 L F
.419 .157 .408 r
.3629 .61655 m .36077 .61709 L .36162 .61414 L F
.71 .558 .679 r
.66926 .53415 m .6687 .53666 L .66779 .53391 L F
.607 .815 .98 r
.47948 .75938 m .47766 .76012 L .48036 .76022 L F
.418 0 0 r
.4207 .65039 m .423 .65058 L .42459 .64948 L F
.32 0 0 r
.42459 .64948 m .423 .65058 L .42645 .64979 L F
.655 .772 .935 r
.47431 .64132 m .47229 .64201 L .47122 .64012 L F
.435 0 0 r
.54249 .73624 m .54129 .73731 L .53882 .73619 L F
.188 0 0 r
.54365 .73679 m .54129 .73731 L .54249 .73624 L F
.122 .515 .912 r
.6456 .48128 m .6438 .48139 L .64335 .48034 L F
.6456 .48128 m .64641 .48226 L .6438 .48139 L F
.873 .696 .66 r
.65401 .51573 m .65517 .51924 L .65565 .51699 L F
.57 0 0 r
.64901 .51264 m .64759 .51276 L .64465 .5117 L F
.968 .902 .701 r
.64894 .50934 m .64759 .51276 L .64901 .51264 L F
.802 .681 .731 r
.64457 .53566 m .6488 .53447 L .64501 .53346 L F
.64457 .53566 m .64775 .53626 L .6488 .53447 L F
0 .227 .747 r
.71706 .49994 m .71699 .49895 L .71503 .49725 L F
.012 .376 .841 r
.71706 .49994 m .71879 .50078 L .71699 .49895 L F
.736 .38 .378 r
.51074 .7604 m .51186 .76247 L .51285 .76011 L F
.622 .257 .328 r
.51285 .76011 m .5154 .76214 L .51545 .76141 L F
.51285 .76011 m .51186 .76247 L .5154 .76214 L F
.541 .811 .996 r
.68064 .47723 m .67918 .47867 L .67805 .47766 L F
.68064 .47723 m .68171 .47811 L .67918 .47867 L F
.438 .426 .749 r
.37883 .68199 m .37962 .68533 L .38147 .68405 L F
.468 .484 .792 r
.37962 .68533 m .38241 .68707 L .38147 .68405 L F
.51 .056 .109 r
.54163 .77153 m .53829 .77337 L .53857 .77197 L F
0 0 0 r
.54308 .77103 m .53829 .77337 L .54163 .77153 L F
.51 .056 .109 r
.54163 .77153 m .53829 .77337 L .53857 .77197 L F
.407 .839 .95 r
.65652 .4836 m .65911 .48297 L .65977 .48336 L F
.547 .369 .592 r
.65977 .48336 m .66209 .48287 L .662 .48033 L F
.679 .969 .924 r
.65977 .48336 m .66102 .48169 L .66209 .48287 L F
.65977 .48336 m .65911 .48297 L .66102 .48169 L F
.801 .422 .338 r
.52103 .77565 m .52124 .77712 L .52276 .7767 L F
.483 0 0 r
.52124 .77712 m .52481 .77721 L .52276 .7767 L F
.54 .037 .01 r
.52189 .77815 m .52481 .77721 L .52124 .77712 L F
.52225 .7785 m .52481 .77721 L .52189 .77815 L F
.52267 .77857 m .52481 .77721 L .52222 .77851 L F
.52189 .77815 m .52124 .77712 L .5213 .77925 L F
0 0 .332 r
.5213 .77925 m .52173 .778 L .52189 .77815 L F
.5213 .77925 m .52189 .77815 L .52231 .77856 L F
.5213 .77925 m .52231 .77856 L .52214 .77856 L F
.54 .037 .01 r
.52214 .77856 m .52189 .77815 L .5213 .77925 L F
0 0 .332 r
.52148 .77874 m .52124 .77712 L .5224 .77607 L F
.5213 .77925 m .52124 .77712 L .52148 .77874 L F
.5213 .77925 m .52214 .77856 L .52001 .77852 L F
.236 .308 .735 r
.5213 .77925 m .52297 .77893 L .52231 .77856 L F
0 0 0 r
.5223 .77881 m .5213 .77925 L .52231 .77856 L F
.54 .037 .01 r
.52267 .77857 m .52231 .77853 L .52231 .77856 L F
.236 .308 .735 r
.52231 .77856 m .52297 .77893 L .52281 .77822 L F
.54 .037 .01 r
.5223 .77881 m .52267 .77857 L .52214 .77856 L F
0 0 0 r
.5223 .77881 m .52231 .77856 L .52254 .7784 L F
0 0 .332 r
.52231 .77856 m .5224 .77607 L .52254 .7784 L F
.54 .037 .01 r
.52231 .77853 m .52222 .77851 L .52231 .77856 L F
.52231 .77856 m .52222 .77851 L .52214 .77856 L F
.728 .52 .61 r
.5224 .77607 m .52254 .7784 L .52232 .77839 L F
.5224 .77607 m .52584 .77572 L .52263 .77852 L F
.52254 .77836 m .52263 .77852 L .52256 .77859 L F
.5224 .77607 m .52263 .77852 L .52254 .77836 L F
.675 .953 .705 r
.52584 .77572 m .52481 .77721 L .5223 .77881 L F
.499 .769 .992 r
.52305 .77928 m .52494 .77995 L .52281 .77822 L F
.52352 .78138 m .52396 .78094 L .52305 .77928 L F
.52396 .78094 m .52494 .77995 L .52305 .77928 L F
0 0 .332 r
.52254 .7784 m .52254 .77839 L .52281 .77822 L F
.52254 .77839 m .5224 .77607 L .52281 .77822 L F
.289 .431 .831 r
.5236 .77772 m .52281 .77822 L .52392 .77809 L F
.353 .211 .545 r
.5224 .77607 m .52232 .77839 L .52281 .77822 L F
0 0 .332 r
.52173 .778 m .5224 .77607 L .52231 .77856 L F
.108 .213 .692 r
.5224 .77607 m .52124 .77712 L .52049 .7736 L F
.289 .431 .831 r
.52104 .77485 m .52281 .77822 L .5236 .77772 L F
0 0 .332 r
.52231 .77856 m .52254 .7784 L .52226 .77841 L F
.728 .52 .61 r
.52232 .77839 m .52254 .7784 L .5223 .77881 L F
.52254 .7784 m .52256 .77859 L .5223 .77881 L F
0 0 0 r
.5223 .77881 m .52254 .7784 L .52281 .77822 L F
.353 .211 .545 r
.52232 .77839 m .5223 .77881 L .52281 .77822 L F
0 0 .332 r
.52188 .77855 m .52226 .77841 L .52028 .77849 L F
.54 .037 .01 r
.52214 .77856 m .52225 .7785 L .52189 .77815 L F
0 0 .332 r
.52231 .77856 m .52226 .77841 L .52188 .77855 L F
.52254 .7784 m .52281 .77822 L .52146 .77836 L F
.52254 .7784 m .52146 .77836 L .52028 .77849 L F
.54 .037 .01 r
.5223 .77881 m .52214 .77856 L .5213 .77925 L F
.236 .308 .735 r
.5213 .77925 m .52352 .78138 L .52297 .77893 L F
0 0 .332 r
.52231 .77856 m .52028 .77849 L .52001 .77852 L F
.801 .422 .338 r
.51919 .77452 m .52124 .77712 L .52103 .77565 L F
.004 0 0 r
.44346 .64735 m .44552 .64701 L .44726 .64641 L F
.456 .878 .766 r
.44726 .64641 m .44814 .64569 L .44953 .6458 L F
.44726 .64641 m .44552 .64701 L .44814 .64569 L F
.679 .51 .65 r
.4775 .66693 m .4801 .66922 L .48087 .66795 L F
.064 0 .36 r
.61359 .49732 m .61469 .49815 L .61522 .49642 L F
.61359 .49732 m .61339 .49952 L .61469 .49815 L F
.914 .52 .13 r
.59088 .69375 m .59027 .69474 L .58826 .69252 L F
.59088 .69375 m .59134 .69554 L .59027 .69474 L F
.58 .37 .56 r
.56311 .69652 m .56562 .69805 L .56552 .69624 L F
.56311 .69652 m .56319 .69917 L .56562 .69805 L F
.725 .409 .444 r
.51934 .76498 m .52342 .76322 L .51879 .76338 L F
.51934 .76498 m .5214 .76601 L .52342 .76322 L F
.596 .25 .354 r
.52342 .76322 m .52567 .76476 L .52453 .7631 L F
.52342 .76322 m .5214 .76601 L .52567 .76476 L F
.301 0 0 r
.43889 .70207 m .43739 .70331 L .43518 .70349 L F
.457 0 .061 r
.44109 .70184 m .43739 .70331 L .43889 .70207 L F
.381 .324 .669 r
.24284 .6177 m .24376 .61402 L .24178 .6149 L F
.24284 .6177 m .24419 .6173 L .24376 .61402 L F
.386 .342 .686 r
.24284 .6177 m .24414 .61954 L .24419 .6173 L F
.523 .387 .637 r
.2427 .62034 m .24414 .61954 L .24284 .6177 L F
.793 .705 .768 r
.50376 .66765 m .50733 .66825 L .50596 .66484 L F
.604 .644 .863 r
.50733 .66825 m .50807 .66447 L .50596 .66484 L F
.50733 .66825 m .50945 .66831 L .50807 .66447 L F
.424 .117 .339 r
.50761 .66976 m .50945 .66831 L .50733 .66825 L F
.84 .975 .878 r
.25266 .65349 m .256 .65176 L .25367 .65189 L F
.634 .942 .956 r
.25367 .65189 m .256 .65176 L .25649 .65056 L F
.882 .964 .844 r
.5751 .56183 m .57287 .56463 L .57312 .56237 L F
.94 .952 .637 r
.57198 .56653 m .57312 .56237 L .57287 .56463 L F
.768 .678 .763 r
.54978 .75748 m .55099 .76064 L .54752 .76032 L F
.753 .523 .583 r
.55136 .76221 m .54752 .76032 L .55099 .76064 L F
.75 .669 .771 r
.5535 .75815 m .55099 .76064 L .54978 .75748 L F
.366 .023 .245 r
.53016 .76267 m .53289 .76065 L .53053 .76085 L F
.527 .435 .694 r
.24178 .6149 m .24331 .61169 L .2429 .6118 L F
.24178 .6149 m .24376 .61402 L .24331 .61169 L F
.451 .619 .922 r
.24739 .64061 m .24799 .63879 L .24671 .63981 L F
.24739 .64061 m .24938 .64039 L .24799 .63879 L F
.574 .548 .788 r
.61247 .54729 m .61359 .54384 L .61137 .54418 L F
.61247 .54729 m .61471 .54683 L .61359 .54384 L F
.641 .807 .963 r
.78336 .60731 m .78564 .60644 L .78459 .60519 L F
.568 .62 .864 r
.47636 .65946 m .47718 .65605 L .47502 .65716 L F
.47636 .65946 m .47839 .65909 L .47718 .65605 L F
0 0 .168 r
.63085 .50622 m .62777 .51144 L .63053 .50589 L F
.63085 .50622 m .62953 .51026 L .62777 .51144 L F
.3 .476 .866 r
.62953 .51026 m .63059 .51289 L .62777 .51144 L F
.634 .554 .746 r
.67861 .53123 m .67966 .53382 L .68188 .53325 L F
0 0 0 r
.67929 .53537 m .68188 .53325 L .67966 .53382 L F
.695 .575 .717 r
.36902 .7037 m .37001 .70738 L .37229 .70465 L F
.586 .628 .859 r
.68956 .48611 m .69113 .48284 L .68892 .48512 L F
.68956 .48611 m .69184 .48548 L .69113 .48284 L F
.121 0 0 r
.25752 .64782 m .26029 .64619 L .25922 .64777 L F
.152 0 .15 r
.25649 .65056 m .25752 .64782 L .25922 .64777 L F
.688 .671 .828 r
.76132 .60291 m .76477 .60369 L .76247 .60461 L F
.858 .717 .706 r
.59658 .56979 m .59525 .56641 L .59321 .56938 L F
.59658 .56979 m .59673 .56746 L .59525 .56641 L F
.939 .676 .512 r
.59321 .56938 m .59466 .57231 L .59658 .56979 L F
.797 .617 .657 r
.59466 .57231 m .59765 .57275 L .59658 .56979 L F
.432 .468 .797 r
.5057 .77096 m .50369 .77214 L .5026 .76925 L F
.46 .356 .65 r
.50518 .77282 m .50369 .77214 L .5057 .77096 L F
.50518 .77282 m .50408 .77447 L .50369 .77214 L F
.50369 .77214 m .50408 .77447 L .50518 .77282 L F
0 0 .024 r
.47536 .7705 m .47527 .7693 L .47556 .76823 L F
.47536 .7705 m .47491 .77205 L .47527 .7693 L F
.105 0 0 r
.31429 .58855 m .31635 .58867 L .31801 .5886 L F
.35 0 0 r
.31635 .58867 m .31995 .5891 L .31801 .5886 L F
.78 .694 .768 r
.49046 .66277 m .49229 .66555 L .49458 .66261 L F
.495 .155 .318 r
.70808 .50472 m .70584 .50558 L .7108 .50421 L F
.48 .313 .576 r
.24913 .59525 m .25108 .59717 L .25133 .59485 L F
.24913 .59525 m .2491 .59774 L .25108 .59717 L F
.466 .121 .296 r
.45249 .69614 m .45133 .69848 L .44907 .69875 L F
.528 .18 .323 r
.45475 .69591 m .45133 .69848 L .45249 .69614 L F
.724 .402 .433 r
.53012 .7678 m .52599 .76822 L .52578 .76644 L F
.371 .04 .268 r
.61678 .52831 m .61861 .52898 L .61651 .52946 L F
.392 0 .058 r
.6196 .52809 m .61861 .52898 L .61678 .52831 L F
.735 .441 .483 r
.49362 .78969 m .49671 .79101 L .4952 .79006 L F
.728 .472 .54 r
.49521 .79318 m .49671 .79101 L .49362 .78969 L F
.962 .942 .69 r
.49617 .79022 m .49671 .79101 L .49521 .79318 L F
.49642 .78947 m .49671 .79101 L .49617 .79022 L F
0 .117 .636 r
.49671 .79101 m .49883 .79335 L .49737 .792 L F
.49671 .79101 m .49737 .792 L .49641 .79112 L F
.834 .927 .894 r
.66581 .50168 m .66948 .50032 L .66763 .50026 L F
.94 .916 .763 r
.66836 .4989 m .66948 .50032 L .6715 .49935 L F
.66836 .4989 m .66763 .50026 L .66948 .50032 L F
0 0 0 r
.56736 .77434 m .56595 .77634 L .56574 .77654 L F
.56456 .77832 m .56574 .77654 L .56595 .77634 L F
.076 0 0 r
.31467 .6005 m .31321 .60102 L .31115 .6013 L F
.23 0 0 r
.3167 .60028 m .31321 .60102 L .31467 .6005 L F
.605 .408 .589 r
.58444 .5921 m .58166 .59464 L .58061 .59222 L F
.474 .218 .445 r
.33097 .62321 m .33309 .62273 L .33351 .62063 L F
.502 .33 .58 r
.33351 .62063 m .3357 .6201 L .33568 .61752 L F
.424 .174 .428 r
.33351 .62063 m .3351 .62211 L .3357 .6201 L F
.33351 .62063 m .33309 .62273 L .3351 .62211 L F
.568 .542 .786 r
.28093 .62592 m .27965 .62813 L .27906 .62626 L F
.589 .568 .799 r
.28093 .62592 m .28217 .62942 L .27965 .62813 L F
.51 .543 .826 r
.28299 .63045 m .27965 .62813 L .28217 .62942 L F
.991 .838 .592 r
.6523 .51216 m .65122 .51377 L .65142 .51035 L F
.6523 .51216 m .65191 .51454 L .65122 .51377 L F
0 0 .169 r
.5384 .73245 m .5401 .73147 L .54051 .73004 L F
.034 0 .271 r
.5384 .73245 m .53849 .73453 L .5401 .73147 L F
.501 .24 .45 r
.56211 .70488 m .56198 .70693 L .55954 .70724 L F
.363 .13 .421 r
.56421 .70604 m .56211 .70488 L .56432 .70477 L F
.56421 .70604 m .56198 .70693 L .56211 .70488 L F
0 0 0 r
.41155 .7108 m .40993 .71182 L .40857 .71249 L F
.187 0 0 r
.41324 .71113 m .40993 .71182 L .41155 .7108 L F
.324 .067 .362 r
.61789 .4919 m .61957 .49281 L .62015 .49116 L F
.61789 .4919 m .61761 .49367 L .61957 .49281 L F
.6 .345 .503 r
.56954 .69868 m .56904 .70124 L .56757 .70098 L F
.382 .15 .433 r
.57116 .70039 m .56954 .69868 L .57003 .69725 L F
.57116 .70039 m .56904 .70124 L .56954 .69868 L F
.157 .652 .915 r
.51127 .69938 m .50972 .69867 L .50761 .69853 L F
.581 .052 0 r
.51366 .69903 m .50972 .69867 L .51127 .69938 L F
.78 .384 .305 r
.501 .69245 m .503 .69511 L .50415 .69335 L F
.351 .462 .834 r
.46944 .65391 m .47089 .65287 L .46742 .65309 L F
.46944 .65391 m .47123 .654 L .47089 .65287 L F
.694 .412 .492 r
.49749 .79948 m .4939 .80161 L .49543 .80008 L F
.754 .429 .435 r
.53878 .78296 m .54055 .78331 L .54097 .78524 L F
.221 .525 .918 r
.77661 .57939 m .77943 .58047 L .77985 .58161 L F
.567 .733 .953 r
.50874 .81285 m .50697 .81367 L .50448 .8121 L F
0 0 0 r
.56266 .77456 m .56037 .77739 L .56161 .7765 L F
.416 .813 .591 r
.56161 .7765 m .56037 .77739 L .5576 .7793 L F
.564 .508 .751 r
.4085 .68747 m .40741 .69208 L .40634 .68794 L F
.4085 .68747 m .41012 .69196 L .40741 .69208 L F
.565 .457 .69 r
.41012 .69196 m .40768 .69331 L .40741 .69208 L F
.291 .405 .807 r
.52049 .7736 m .51919 .77452 L .51778 .77154 L F
.244 .315 .739 r
.52049 .7736 m .52124 .77712 L .51919 .77452 L F
.686 .442 .547 r
.60952 .58662 m .60606 .58892 L .60624 .5873 L F
.798 .672 .725 r
.56234 .58902 m .56049 .58569 L .56236 .58687 L F
.826 .814 .838 r
.56472 .58384 m .56236 .58687 L .56049 .58569 L F
.693 .599 .746 r
.56472 .58384 m .56545 .58635 L .56236 .58687 L F
.681 .477 .603 r
.56545 .58635 m .56234 .58902 L .56236 .58687 L F
.72 .716 .845 r
.66209 .48287 m .66577 .48214 L .662 .48033 L F
.835 .627 .622 r
.57518 .58974 m .57248 .59151 L .57233 .58918 L F
.57518 .58974 m .57508 .59213 L .57248 .59151 L F
0 0 0 r
.62984 .49399 m .62908 .49576 L .62747 .49704 L F
.192 .014 .396 r
.62916 .49798 m .62747 .49704 L .62908 .49576 L F
.62916 .49798 m .62716 .49966 L .62747 .49704 L F
.257 .018 .347 r
.52032 .68781 m .51992 .68992 L .51829 .69049 L F
.52 .392 .646 r
.51992 .68992 m .51812 .69303 L .51829 .69049 L F
.27 0 0 r
.40857 .71249 m .40832 .7131 L .40582 .7133 L F
0 0 0 r
.40993 .71182 m .40832 .7131 L .40857 .71249 L F
.474 .828 .996 r
.48209 .78784 m .48428 .78872 L .4862 .78812 L F
.617 .744 .937 r
.52939 .80788 m .53235 .80861 L .53101 .80811 L F
.638 .923 .976 r
.53101 .80811 m .53235 .80861 L .53416 .8076 L F
.716 .554 .669 r
.61355 .54128 m .61655 .54217 L .61609 .53857 L F
.698 .542 .671 r
.61609 .53857 m .61655 .54217 L .61889 .5389 L F
.783 .506 .516 r
.59463 .57465 m .59765 .57275 L .59466 .57231 L F
.59463 .57465 m .59785 .57495 L .59765 .57275 L F
.717 .518 .618 r
.59785 .57495 m .60014 .57259 L .59765 .57275 L F
.7 .676 .823 r
.55058 .74939 m .55203 .7522 L .54854 .7517 L F
.33 .475 .854 r
.55327 .75111 m .55203 .7522 L .55058 .74939 L F
.143 0 .382 r
.55319 .75369 m .55203 .7522 L .55327 .75111 L F
.55319 .75369 m .55133 .75478 L .55203 .7522 L F
.046 .58 .856 r
.34623 .59183 m .34779 .5924 L .34415 .5915 L F
.271 .715 .961 r
.34849 .59176 m .34779 .5924 L .34623 .59183 L F
.34849 .59176 m .35061 .59252 L .34779 .5924 L F
.742 .379 .365 r
.47697 .68718 m .47888 .68918 L .48006 .68732 L F
.687 .3 .309 r
.47888 .68918 m .48222 .68794 L .48006 .68732 L F
.801 .454 .4 r
.66701 .50484 m .6691 .50729 L .67033 .50567 L F
.698 .325 .338 r
.6691 .50729 m .67081 .50745 L .67033 .50567 L F
.925 .959 .64 r
.66571 .48353 m .66449 .48433 L .66487 .48541 L F
.953 .877 .722 r
.66221 .48722 m .66487 .48541 L .66449 .48433 L F
.66221 .48722 m .66311 .48927 L .66487 .48541 L F
.78 .694 .768 r
.49046 .66277 m .49458 .66261 L .49288 .66185 L F
.673 .787 .935 r
.49288 .66185 m .49458 .66261 L .49703 .66216 L F
.85 .741 .743 r
.59673 .56746 m .59601 .56447 L .59525 .56641 L F
0 0 .521 r
.25089 .6569 m .25021 .65368 L .24998 .65394 L F
0 .48 .845 r
.2512 .65581 m .2516 .65592 L .25136 .65577 L F
0 0 .521 r
.25068 .65593 m .2512 .65581 L .25021 .65368 L F
.472 .173 .377 r
.24795 .65518 m .25021 .65368 L .2512 .65581 L F
0 .48 .845 r
.2512 .65581 m .25136 .65577 L .25023 .65505 L F
0 0 .521 r
.25089 .6569 m .2512 .65581 L .25068 .65593 L F
.816 .796 .834 r
.2504 .65912 m .2512 .65581 L .25089 .6569 L F
.32 .668 .975 r
.30916 .58636 m .30857 .58745 L .30709 .58654 L F
.30916 .58636 m .31101 .58761 L .30857 .58745 L F
.291 .71 .972 r
.36837 .69254 m .3698 .69334 L .37079 .69267 L F
.36837 .69254 m .3698 .69334 L .37079 .69267 L F
.856 .962 .873 r
.46663 .64242 m .46708 .63998 L .46866 .64142 L F
.46663 .64242 m .46543 .64206 L .46708 .63998 L F
.852 .727 .725 r
.70376 .51115 m .70035 .51288 L .70278 .51122 L F
.70376 .51115 m .70172 .51377 L .70035 .51288 L F
.769 .594 .662 r
.70376 .51115 m .70416 .51373 L .70172 .51377 L F
0 .293 .79 r
.70521 .51089 m .70376 .51115 L .70278 .51122 L F
.70521 .51089 m .70486 .51128 L .70376 .51115 L F
.584 .467 .685 r
.70687 .5128 m .70376 .51115 L .70486 .51128 L F
.70687 .5128 m .70416 .51373 L .70376 .51115 L F
.641 .395 .531 r
.59543 .58951 m .59463 .5921 L .59225 .5921 L F
.605 .359 .517 r
.59795 .59149 m .59543 .58951 L .598 .58923 L F
.59795 .59149 m .59463 .5921 L .59543 .58951 L F
.844 .494 .391 r
.66675 .49336 m .66991 .49607 L .66841 .49389 L F
.687 .304 .317 r
.55743 .78884 m .55285 .78894 L .55604 .78683 L F
0 0 0 r
.55439 .79235 m .55743 .78884 L .55663 .78979 L F
.256 .471 .876 r
.55872 .78798 m .55743 .78884 L .55604 .78683 L F
0 0 0 r
.55663 .78979 m .55743 .78884 L .55872 .78798 L F
.617 .852 .483 r
.37804 .70428 m .37566 .70741 L .37653 .70612 L F
.152 .303 .765 r
.37566 .70741 m .37765 .70907 L .37653 .70612 L F
.456 .335 .626 r
.49021 .76338 m .49037 .76614 L .49238 .76546 L F
.331 0 0 r
.55285 .78894 m .55324 .78908 L .55286 .78908 L F
.245 0 0 r
.55609 .78988 m .55324 .78908 L .55299 .79078 L F
.2 0 0 r
.55286 .78908 m .55324 .78908 L .55609 .78988 L F
.127 0 0 r
.27481 .5853 m .27689 .58507 L .27876 .58425 L F
0 0 0 r
.27876 .58425 m .27912 .58437 L .28082 .5841 L F
.27876 .58425 m .27689 .58507 L .27912 .58437 L F
.841 .932 .889 r
.64832 .52441 m .65128 .52301 L .64998 .52168 L F
.762 .775 .863 r
.64998 .52168 m .65128 .52301 L .65334 .52198 L F
.57 .745 .959 r
.69312 .47906 m .69413 .48044 L .69089 .47959 L F
.612 .777 .96 r
.69548 .47845 m .69413 .48044 L .69312 .47906 L F
.69548 .47845 m .6965 .47979 L .69413 .48044 L F
.826 .955 .614 r
.67657 .52641 m .67612 .52809 L .67773 .52545 L F
0 .18 .696 r
.67771 .52971 m .67612 .52809 L .67657 .52641 L F
.347 .231 .576 r
.46773 .78009 m .46922 .77987 L .46923 .77728 L F
.359 .348 .711 r
.46773 .78009 m .47008 .78233 L .46922 .77987 L F
.584 .231 .336 r
.28982 .64856 m .29176 .64997 L .28932 .6497 L F
.508 .537 .821 r
.63899 .48759 m .63834 .49129 L .63686 .48811 L F
.63899 .48759 m .64054 .49121 L .63834 .49129 L F
.124 0 0 r
.25922 .64777 m .26029 .64619 L .26221 .64539 L F
.069 0 0 r
.32431 .64555 m .32274 .64718 L .32076 .64796 L F
.085 0 0 r
.32478 .64639 m .32431 .64555 L .32643 .64511 L F
.32478 .64639 m .32274 .64718 L .32431 .64555 L F
.569 .396 .607 r
.57295 .68768 m .57335 .69028 L .57524 .68729 L F
.57295 .68768 m .57335 .69028 L .57524 .68729 L F
.452 .25 .513 r
.37811 .66519 m .38016 .66464 L .38031 .66234 L F
.518 .437 .704 r
.37871 .66793 m .38016 .66464 L .37811 .66519 L F
.706 .267 .204 r
.53164 .78284 m .53527 .78348 L .53547 .78446 L F
.662 .234 .22 r
.53547 .78446 m .53527 .78348 L .53747 .78527 L F
.602 .281 .398 r
.53747 .78527 m .53527 .78348 L .53878 .78296 L F
.728 .309 .253 r
.52902 .77631 m .53293 .77732 L .53067 .77533 L F
.843 .399 .167 r
.67616 .51618 m .6752 .51364 L .67408 .51376 L F
.02 0 0 r
.2957 .64833 m .29552 .64889 L .2937 .6497 L F
.2957 .64833 m .29779 .64797 L .29552 .64889 L F
.151 .042 .466 r
.51624 .65901 m .51454 .66253 L .51408 .6593 L F
.51624 .65901 m .51622 .66147 L .51454 .66253 L F
.391 .234 .545 r
.5166 .66375 m .51454 .66253 L .51622 .66147 L F
.5166 .66375 m .51458 .6649 L .51454 .66253 L F
.218 0 .26 r
.62247 .48797 m .62412 .48912 L .62472 .48789 L F
.62247 .48797 m .62215 .49026 L .62412 .48912 L F
.731 .523 .611 r
.57263 .58692 m .56807 .589 L .56802 .5867 L F
.57263 .58692 m .57233 .58918 L .56807 .589 L F
.384 0 0 r
.43597 .66267 m .43456 .66385 L .43247 .66371 L F
.463 0 .017 r
.43866 .66274 m .43456 .66385 L .43597 .66267 L F
.495 .656 .931 r
.67861 .53123 m .6801 .52918 L .67771 .52971 L F
.67861 .53123 m .6815 .5312 L .6801 .52918 L F
.634 .554 .746 r
.67861 .53123 m .68188 .53325 L .6815 .5312 L F
.903 .791 .727 r
.64467 .53833 m .64775 .53626 L .64457 .53566 L F
.64467 .53833 m .64622 .53946 L .64775 .53626 L F
.765 .661 .747 r
.48409 .65893 m .48807 .65945 L .4868 .65658 L F
.765 .659 .745 r
.48409 .65893 m .48558 .66025 L .48807 .65945 L F
.531 .498 .764 r
.48807 .65945 m .48967 .65695 L .4868 .65658 L F
.48807 .65945 m .49018 .65913 L .48967 .65695 L F
.465 .471 .78 r
.48807 .65945 m .4912 .66074 L .49018 .65913 L F
.529 .669 .926 r
.53635 .73585 m .53882 .73619 L .53849 .73453 L F
.873 .696 .66 r
.65401 .51573 m .65233 .51951 L .65517 .51924 L F
.867 .818 .799 r
.65233 .51951 m .65334 .52198 L .65517 .51924 L F
.428 .853 .713 r
.48672 .79636 m .48486 .79398 L .48462 .79661 L F
.48672 .79636 m .48705 .796 L .48486 .79398 L F
.48672 .79636 m .48835 .79548 L .48705 .796 L F
.706 .264 .199 r
.48836 .79805 m .48672 .79636 L .48462 .79661 L F
.359 .68 .978 r
.35774 .59353 m .35722 .59471 L .35615 .59327 L F
.35774 .59353 m .35906 .59473 L .35722 .59471 L F
.833 .403 .214 r
.55152 .73916 m .5505 .74005 L .54889 .73778 L F
.984 .7 .355 r
.55534 .74142 m .55519 .7412 L .55535 .74095 L F
.55532 .74336 m .55479 .74181 L .55534 .74142 L F
.55479 .74181 m .55478 .74177 L .55484 .74173 L F
.55479 .74181 m .55484 .74173 L .55534 .74142 L F
.776 .393 .329 r
.55462 .74209 m .55406 .743 L .551 .74244 L F
.984 .7 .355 r
.55532 .74336 m .5546 .74312 L .55479 .74181 L F
.5546 .74312 m .55446 .74307 L .55472 .74208 L F
.5546 .74312 m .55472 .74208 L .55479 .74181 L F
.776 .393 .329 r
.55476 .7418 m .551 .74244 L .5505 .74005 L F
.55531 .74203 m .55472 .74208 L .55476 .7418 L F
.55472 .74208 m .551 .74244 L .55476 .7418 L F
.55531 .74203 m .55406 .743 L .55462 .74209 L F
.763 .376 .321 r
.55535 .74095 m .55488 .7417 L .55152 .73916 L F
.764 .302 .149 r
.55152 .73916 m .55485 .74167 L .5505 .74005 L F
.55485 .74167 m .55488 .7417 L .55484 .74169 L F
.55485 .74167 m .55484 .74169 L .5505 .74005 L F
.984 .7 .355 r
.55479 .74181 m .55446 .74307 L .55436 .74234 L F
.764 .302 .149 r
.55488 .7417 m .55474 .74179 L .5505 .74005 L F
.984 .7 .355 r
.55478 .74177 m .55436 .74234 L .55397 .73939 L F
.55479 .74181 m .55436 .74234 L .55478 .74177 L F
.776 .393 .329 r
.55459 .74259 m .55446 .74307 L .55406 .743 L F
.55531 .74203 m .55446 .74307 L .55459 .74259 L F
.763 .376 .321 r
.55535 .74095 m .55531 .74203 L .55488 .7417 L F
.984 .7 .355 r
.55519 .7412 m .55397 .73939 L .55535 .74095 L F
.55478 .74177 m .55397 .73939 L .55534 .74142 L F
.764 .302 .149 r
.55488 .7417 m .55531 .74203 L .55474 .74179 L F
.461 .369 .665 r
.51458 .6649 m .51512 .66761 L .51322 .6679 L F
.618 .518 .718 r
.51512 .66761 m .51323 .67103 L .51322 .6679 L F
.75 .669 .771 r
.5535 .75815 m .54978 .75748 L .552 .75747 L F
0 0 0 r
.5535 .75815 m .55456 .75735 L .55618 .75485 L F
.406 .79 .991 r
.552 .75747 m .55456 .75735 L .5535 .75815 L F
.669 .812 .951 r
.68492 .47846 m .68171 .47811 L .68389 .47722 L F
.583 .783 .974 r
.68713 .47781 m .68492 .47846 L .68389 .47722 L F
.376 .141 .425 r
.61548 .49445 m .61725 .49557 L .61761 .49367 L F
.61548 .49445 m .61522 .49642 L .61725 .49557 L F
.779 .355 .241 r
.58731 .72716 m .58613 .72858 L .58406 .72625 L F
.7 .98 .802 r
.58949 .72638 m .58613 .72858 L .58731 .72716 L F
.79 .813 .87 r
.46023 .65456 m .46345 .65428 L .46209 .65336 L F
.299 .769 .938 r
.46558 .65352 m .46209 .65336 L .46345 .65428 L F
.762 .775 .864 r
.65233 .51951 m .64998 .52168 L .65334 .52198 L F
.66 .748 .915 r
.52516 .80777 m .52204 .80959 L .5229 .808 L F
.178 .172 .613 r
.46888 .77159 m .4705 .77388 L .47035 .77036 L F
.753 .732 .833 r
.67777 .53886 m .67433 .5387 L .67715 .53712 L F
.141 .678 .845 r
.67777 .53886 m .67678 .53865 L .67433 .5387 L F
.372 .678 .977 r
.67777 .53886 m .67903 .53784 L .67678 .53865 L F
.67777 .53886 m .68011 .53903 L .67903 .53784 L F
0 0 0 r
.64631 .49765 m .64591 .49745 L .64701 .49608 L F
.687 .3 .309 r
.47888 .68918 m .48219 .68958 L .48222 .68794 L F
.661 .278 .309 r
.48219 .68958 m .48441 .68983 L .48222 .68794 L F
.562 .443 .675 r
.71471 .4943 m .7174 .4937 L .71611 .4903 L F
.355 .263 .611 r
.71471 .4943 m .71722 .49558 L .7174 .4937 L F
.71471 .4943 m .71503 .49725 L .71722 .49558 L F
.74 .744 .855 r
.70687 .5128 m .70743 .5146 L .70337 .51588 L F
.642 .353 .464 r
.51731 .69071 m .51572 .68868 L .51588 .69089 L F
.709 .379 .417 r
.51572 .68868 m .51731 .69071 L .52032 .68781 L F
.51731 .69071 m .51745 .69089 L .51773 .69058 L F
.51731 .69071 m .51773 .69058 L .52032 .68781 L F
.329 0 .126 r
.51731 .69071 m .51737 .69077 L .51759 .69068 L F
.51588 .69089 m .51636 .69102 L .51731 .69071 L F
.709 .379 .417 r
.51572 .68868 m .51702 .69134 L .51745 .69089 L F
.642 .353 .464 r
.51748 .69075 m .51702 .69134 L .51679 .69088 L F
.329 0 .126 r
.51737 .69077 m .5174 .69081 L .51748 .69075 L F
.51741 .69076 m .51748 .69075 L .51742 .69075 L F
.51742 .69075 m .51748 .69075 L .51759 .69068 L F
.642 .353 .464 r
.51744 .6907 m .51572 .68868 L .51731 .69071 L F
.51845 .69057 m .51784 .69015 L .51744 .6907 L F
.51784 .69015 m .51572 .68868 L .51744 .6907 L F
.51791 .6902 m .51748 .69075 L .51745 .69071 L F
.51784 .69015 m .51745 .69071 L .51572 .68868 L F
.51791 .6902 m .51745 .69071 L .51784 .69015 L F
.936 .967 .706 r
.52032 .68781 m .51773 .69058 L .51833 .68967 L F
.51988 .68768 m .51833 .68967 L .51966 .68762 L F
.52032 .68781 m .51833 .68967 L .51988 .68768 L F
.51773 .69058 m .5174 .69081 L .51966 .68762 L F
0 0 0 r
.51966 .68762 m .5174 .69081 L .51999 .68821 L F
.51966 .68762 m .51965 .68765 L .51966 .68762 L F
.51965 .68765 m .5174 .69081 L .51966 .68762 L F
.936 .967 .706 r
.51773 .69058 m .51702 .69134 L .5174 .69081 L F
.642 .353 .464 r
.51845 .69057 m .51702 .69134 L .51748 .69075 L F
.329 0 .126 r
.51759 .69068 m .51762 .69073 L .51845 .69057 L F
.642 .353 .464 r
.51845 .69057 m .51748 .69075 L .51791 .6902 L F
.329 0 .126 r
.51762 .69073 m .51806 .69147 L .51845 .69057 L F
0 0 0 r
.5174 .69081 m .51702 .69134 L .51733 .69102 L F
.5174 .69081 m .51733 .69102 L .51999 .68821 L F
.329 0 .126 r
.51737 .69077 m .51741 .69076 L .51742 .69075 L F
.642 .353 .464 r
.51748 .69075 m .51679 .69088 L .51572 .68868 L F
.329 0 .126 r
.51753 .69094 m .5177 .69087 L .51759 .69068 L F
0 0 .467 r
.51845 .69057 m .51999 .68821 L .51733 .69102 L F
.51845 .69057 m .51733 .69102 L .51702 .69134 L F
.329 0 .126 r
.5174 .69081 m .51753 .69094 L .51759 .69068 L F
.51753 .69094 m .51806 .69147 L .5177 .69087 L F
.51636 .69102 m .51806 .69147 L .51731 .69071 L F
.917 .979 .734 r
.52003 .68692 m .52151 .68449 L .51924 .68447 L F
.52032 .68781 m .52096 .68603 L .52003 .68692 L F
.52096 .68603 m .52151 .68449 L .52003 .68692 L F
.52032 .68781 m .51966 .68762 L .52151 .68449 L F
.472 0 0 r
.5225 .68444 m .52402 .68516 L .52473 .68432 L F
.563 .406 .627 r
.52151 .68449 m .51966 .68762 L .52239 .68467 L F
.472 0 0 r
.52151 .68449 m .52239 .68467 L .5225 .68444 L F
.563 .406 .627 r
.52151 .68449 m .52239 .68467 L .52255 .6845 L F
.472 0 0 r
.52151 .68449 m .52237 .68472 L .52239 .68467 L F
.52237 .68472 m .52402 .68516 L .5225 .68444 L F
0 0 0 r
.51966 .68762 m .51999 .68821 L .52232 .68483 L F
.532 .234 .408 r
.52255 .6845 m .52402 .68516 L .52237 .68472 L F
0 0 0 r
.52239 .68467 m .52237 .68472 L .52255 .6845 L F
.563 .406 .627 r
.52151 .68449 m .52255 .6845 L .52255 .6845 L F
.532 .234 .408 r
.52255 .6845 m .52237 .68472 L .52151 .68449 L F
0 0 0 r
.52255 .6845 m .52232 .68483 L .52255 .6845 L F
.52237 .68472 m .52232 .68483 L .52255 .6845 L F
.51966 .68762 m .52232 .68483 L .52239 .68467 L F
.917 .979 .734 r
.51924 .68447 m .52151 .68449 L .51921 .68439 L F
.457 .188 .416 r
.5226 .68735 m .51992 .68992 L .52032 .68781 L F
.617 .852 .483 r
.37804 .70428 m .37653 .70612 L .37635 .70262 L F
.637 .781 .95 r
.37937 .70371 m .37804 .70428 L .37635 .70262 L F
.739 .785 .89 r
.37833 .70462 m .37804 .70428 L .37937 .70371 L F
.37833 .70462 m .37934 .70642 L .37804 .70428 L F
.955 .609 .25 r
.55397 .73939 m .55531 .74203 L .55535 .74095 L F
.498 .9 .927 r
.64313 .51566 m .6407 .51674 L .64196 .51595 L F
.579 .24 .359 r
.63988 .51653 m .64196 .51595 L .6407 .51674 L F
.495 .291 .532 r
.54908 .71538 m .55123 .71492 L .54932 .71287 L F
.598 .905 .983 r
.58885 .68629 m .58884 .68712 L .58677 .68711 L F
.859 .671 .647 r
.58677 .68711 m .58884 .68712 L .58854 .69035 L F
.72 .716 .845 r
.66209 .48287 m .66571 .48353 L .66577 .48214 L F
.615 .094 0 r
.66391 .4832 m .66449 .48433 L .66571 .48353 L F
.824 .868 .425 r
.6658 .48228 m .66489 .48511 L .66449 .48433 L F
.66489 .48511 m .66442 .48658 L .66449 .48433 L F
.615 .094 0 r
.66209 .48287 m .66449 .48433 L .66391 .4832 L F
.658 .663 .843 r
.66577 .48214 m .66571 .48353 L .66783 .48229 L F
.35 0 .103 r
.45849 .68538 m .46007 .6861 L .46151 .68431 L F
.541 .118 .187 r
.46007 .6861 m .4637 .68445 L .46151 .68431 L F
.406 .05 .244 r
.36852 .60886 m .37144 .607 L .37068 .60844 L F
.142 0 .328 r
.37144 .607 m .37356 .60311 L .37344 .60606 L F
.254 0 .161 r
.37068 .60844 m .37144 .607 L .37344 .60606 L F
.78 .485 .488 r
.50053 .78597 m .49757 .7878 L .49677 .78614 L F
.50053 .78597 m .50073 .78806 L .49757 .7878 L F
.565 .457 .69 r
.41012 .69196 m .40986 .69284 L .40768 .69331 L F
.621 .373 .52 r
.61421 .5842 m .61416 .58621 L .61177 .58641 L F
.624 .375 .52 r
.61685 .58588 m .61421 .5842 L .61701 .58368 L F
.61685 .58588 m .61416 .58621 L .61421 .5842 L F
.408 .196 .477 r
.38031 .66234 m .38253 .66163 L .38252 .65915 L F
.383 .125 .393 r
.38252 .65915 m .38439 .65881 L .38517 .65653 L F
.433 .215 .481 r
.38252 .65915 m .38429 .6609 L .38439 .65881 L F
.38252 .65915 m .38253 .66163 L .38429 .6609 L F
0 .133 .614 r
.56262 .7248 m .56138 .72362 L .55925 .72197 L F
0 .217 .685 r
.56262 .7248 m .56355 .72541 L .56138 .72362 L F
.985 .708 .393 r
.56916 .75499 m .57019 .75105 L .56887 .75111 L F
.988 .874 .625 r
.56915 .75263 m .56922 .75571 L .56916 .75499 L F
.74 .323 .258 r
.56923 .7562 m .57031 .75438 L .56916 .75499 L F
.988 .874 .625 r
.56922 .75571 m .56923 .7562 L .56916 .75499 L F
.985 .708 .393 r
.56916 .75499 m .56887 .75111 L .56873 .75112 L F
.56916 .75499 m .57031 .75438 L .57019 .75105 L F
.374 .075 .324 r
.55404 .70763 m .55137 .70996 L .55338 .7094 L F
.55404 .70763 m .55137 .70996 L .55338 .7094 L F
.292 .012 .305 r
.55338 .7094 m .55584 .70671 L .55404 .70763 L F
.379 .187 .49 r
.55726 .75391 m .55679 .75652 L .55888 .75347 L F
.867 .855 .828 r
.55888 .75347 m .5579 .75396 L .55726 .75391 L F
.506 .3 .535 r
.55456 .75735 m .55679 .75652 L .55726 .75391 L F
.867 .855 .828 r
.5579 .75396 m .55519 .75533 L .55726 .75391 L F
0 0 .364 r
.5564 .75383 m .55726 .75391 L .55699 .75113 L F
.55618 .75485 m .55726 .75391 L .5564 .75383 L F
.823 .811 .839 r
.70337 .51588 m .70172 .51377 L .70416 .51373 L F
.70337 .51588 m .70159 .51629 L .70172 .51377 L F
.74 .744 .855 r
.70687 .5128 m .70337 .51588 L .70416 .51373 L F
.756 .642 .734 r
.56585 .57559 m .56679 .57846 L .56468 .57808 L F
.801 .597 .626 r
.56679 .57846 m .56395 .58061 L .56468 .57808 L F
.56679 .57846 m .56691 .58101 L .56395 .58061 L F
.548 .213 .353 r
.24805 .64795 m .25043 .6471 L .24857 .6468 L F
.456 .066 .209 r
.44351 .70051 m .44344 .70172 L .44109 .70184 L F
.373 .02 .231 r
.44677 .6987 m .4455 .70118 L .44351 .70051 L F
.377 .005 .199 r
.4455 .70118 m .44344 .70172 L .44351 .70051 L F
.497 .053 .126 r
.40005 .65573 m .39909 .65399 L .39779 .65591 L F
.40005 .65573 m .40142 .65406 L .39909 .65399 L F
.781 .956 .927 r
.69674 .52414 m .6949 .52497 L .69736 .52203 L F
.725 .404 .435 r
.53012 .7678 m .52805 .77073 L .52599 .76822 L F
.45 .045 .178 r
.53153 .76856 m .52805 .77073 L .53012 .7678 L F
.395 .337 .675 r
.46928 .79409 m .46759 .7943 L .46985 .79625 L F
.547 .134 .211 r
.56125 .77493 m .56266 .77456 L .56161 .7765 L F
.965 .937 .683 r
.56284 .78183 m .56388 .78017 L .56209 .78174 L F
.799 .973 .677 r
.56209 .78174 m .56388 .78017 L .56456 .77832 L F
.426 .233 .514 r
.60556 .57008 m .60742 .56931 L .60772 .56699 L F
0 0 0 r
.60513 .57184 m .60742 .56931 L .60556 .57008 L F
.881 .446 .09 r
.67622 .51709 m .677 .51675 L .67616 .51618 L F
.67622 .51709 m .67852 .5195 L .677 .51675 L F
.055 0 0 r
.42645 .64979 m .42856 .64946 L .43005 .64882 L F
.016 0 0 r
.42856 .64946 m .43213 .64849 L .43005 .64882 L F
.373 .31 .657 r
.51458 .78803 m .51233 .7857 L .51766 .78358 L F
.51458 .78803 m .51314 .78881 L .51233 .7857 L F
.22 0 .204 r
.48408 .75263 m .48646 .75158 L .48424 .75193 L F
.48408 .75263 m .48583 .75372 L .48646 .75158 L F
.26 0 .126 r
.48408 .75263 m .48491 .75503 L .48583 .75372 L F
.48408 .75263 m .48283 .75597 L .48491 .75503 L F
0 0 0 r
.55904 .7022 m .55806 .70384 L .56039 .70104 L F
.555 .414 .644 r
.63655 .4857 m .63686 .48811 L .63454 .48868 L F
.47 0 0 r
.48705 .796 m .48835 .79548 L .49048 .79635 L F
.984 .725 .452 r
.53593 .76541 m .53708 .76798 L .53724 .76621 L F
.844 .907 .879 r
.53469 .76469 m .53593 .76541 L .5385 .76305 L F
.742 .254 .08 r
.53469 .76469 m .53478 .76474 L .53593 .76541 L F
.882 .913 .844 r
.53593 .76541 m .53725 .76619 L .53977 .76326 L F
.587 .405 .603 r
.53724 .76621 m .53969 .76618 L .53977 .76326 L F
.218 .035 .406 r
.53724 .76621 m .53879 .76683 L .53969 .76618 L F
.882 .913 .844 r
.53593 .76541 m .53977 .76326 L .5385 .76305 L F
.742 .254 .08 r
.53478 .76474 m .53834 .76654 L .53593 .76541 L F
.882 .913 .844 r
.53593 .76541 m .53724 .76621 L .53725 .76619 L F
.218 .035 .406 r
.53724 .76621 m .53708 .76798 L .53879 .76683 L F
.662 .595 .77 r
.76132 .60291 m .75898 .60369 L .75804 .60024 L F
0 .015 .574 r
.55559 .79272 m .55439 .79235 L .55663 .78979 L F
.55559 .79272 m .55515 .79413 L .55439 .79235 L F
.648 .224 .225 r
.43842 .69155 m .44069 .69211 L .44205 .69042 L F
.53 .192 .338 r
.44069 .69211 m .44402 .6896 L .44205 .69042 L F
.576 .895 .986 r
.5418 .76279 m .5385 .76305 L .53977 .76326 L F
.576 .426 .64 r
.53969 .76618 m .5418 .76279 L .53977 .76326 L F
.78 .305 0 r
.48508 .63669 m .48621 .63764 L .48475 .63598 L F
.715 .871 .955 r
.48831 .63664 m .48621 .63764 L .48508 .63669 L F
.681 .477 .603 r
.56545 .58635 m .56716 .58901 L .56234 .58902 L F
.707 .542 .662 r
.56802 .5867 m .56716 .58901 L .56545 .58635 L F
.726 .699 .825 r
.24367 .62447 m .24557 .62296 L .24266 .62278 L F
.314 .667 .974 r
.37064 .59871 m .36984 .59959 L .36803 .59799 L F
.37064 .59871 m .37191 .59978 L .36984 .59959 L F
.906 .983 .775 r
.58598 .54744 m .58747 .5439 L .58776 .54429 L F
.862 .989 .725 r
.58747 .5439 m .58998 .54138 L .58776 .54429 L F
.993 .784 .407 r
.65925 .51347 m .65838 .51469 L .65829 .51241 L F
.65925 .51347 m .65922 .51596 L .65838 .51469 L F
0 0 0 r
.54854 .7517 m .55058 .74939 L .54841 .75033 L F
.7 .676 .823 r
.55058 .74939 m .54854 .7517 L .54841 .75033 L F
.403 .131 .384 r
.63908 .48297 m .63655 .4857 L .63675 .48318 L F
.263 0 .282 r
.34448 .6315 m .34384 .6338 L .34224 .63398 L F
.254 0 .278 r
.34559 .63297 m .34448 .6315 L .3465 .63089 L F
.34559 .63297 m .34384 .6338 L .34448 .6315 L F
.534 .73 .965 r
.68466 .52899 m .68459 .53043 L .68353 .52725 L F
.68466 .52899 m .68687 .53008 L .68459 .53043 L F
.503 .328 .577 r
.38016 .66464 m .38253 .66163 L .38031 .66234 L F
.953 .892 .502 r
.67895 .52442 m .67971 .52225 L .67875 .52333 L F
.698 .886 .506 r
.67875 .52333 m .67971 .52225 L .68059 .52052 L F
.404 .499 .842 r
.37514 .60286 m .37356 .60311 L .37191 .59978 L F
.509 .39 .653 r
.37514 .60286 m .37344 .60606 L .37356 .60311 L F
.697 .472 0 r
.658 .49428 m .65826 .49582 L .65776 .49287 L F
.859 .972 .863 r
.66124 .49071 m .658 .49428 L .65776 .49287 L F
0 0 .241 r
.6702 .51354 m .67013 .51118 L .67005 .51222 L F
.621 .163 .142 r
.67106 .51538 m .67005 .51222 L .66851 .51593 L F
.429 .086 .28 r
.67264 .51336 m .66988 .51435 L .67005 .51222 L F
.66988 .51435 m .66969 .51442 L .67005 .51222 L F
0 0 .241 r
.67013 .51118 m .6701 .50994 L .67005 .51222 L F
.789 .41 .338 r
.53857 .77197 m .53531 .77124 L .53611 .77123 L F
.53857 .77197 m .53722 .77384 L .53531 .77124 L F
.138 0 0 r
.53968 .77316 m .53829 .77337 L .54308 .77103 L F
.25 0 .005 r
.53968 .77316 m .53857 .77197 L .53829 .77337 L F
.53968 .77316 m .53722 .77384 L .53857 .77197 L F
.643 .39 .522 r
.48951 .80483 m .48706 .80522 L .48748 .8025 L F
.604 .937 .95 r
.68829 .5383 m .68903 .53869 L .6911 .53752 L F
.281 .68 .972 r
.77661 .57939 m .77354 .57846 L .77553 .57844 L F
.09 .501 .902 r
.7786 .57945 m .77661 .57939 L .77553 .57844 L F
.7786 .57945 m .77943 .58047 L .77661 .57939 L F
.886 .872 .817 r
.5772 .55905 m .57385 .56074 L .57612 .55817 L F
.5772 .55905 m .5751 .56183 L .57385 .56074 L F
.867 .915 .86 r
.5772 .55905 m .57708 .5569 L .57962 .55627 L F
.5772 .55905 m .57612 .55817 L .57708 .5569 L F
.465 .122 .299 r
.67715 .53712 m .67903 .53784 L .67929 .53537 L F
0 0 0 r
.67929 .53537 m .68107 .53451 L .68188 .53325 L F
.04 0 .199 r
.67929 .53537 m .67903 .53784 L .68107 .53451 L F
.35 0 .103 r
.45849 .68538 m .45768 .68659 L .46007 .6861 L F
.351 .212 .548 r
.33568 .61752 m .33727 .61928 L .33728 .6168 L F
.33568 .61752 m .3357 .6201 L .33727 .61928 L F
.862 .989 .725 r
.58747 .5439 m .5896 .54091 L .58998 .54138 L F
.689 .201 .084 r
.62479 .52519 m .62672 .52698 L .62368 .52634 L F
.634 .078 0 r
.62815 .52764 m .62672 .52698 L .62479 .52519 L F
.669 .488 .631 r
.61117 .54161 m .61137 .54418 L .61355 .54128 L F
0 0 0 r
.55663 .78979 m .55872 .78798 L .55665 .79086 L F
0 0 .012 r
.55559 .79272 m .55663 .78979 L .55665 .79086 L F
.206 0 0 r
.72272 .50146 m .72107 .50125 L .71879 .50078 L F
.518 0 0 r
.72272 .50146 m .72377 .50214 L .72107 .50125 L F
.027 .599 .72 r
.28082 .5841 m .28303 .58405 L .28444 .58404 L F
.094 0 0 r
.28303 .58405 m .28642 .58387 L .28444 .58404 L F
.673 .787 .935 r
.49288 .66185 m .49703 .66216 L .49557 .65873 L F
.739 .673 .787 r
.49557 .65873 m .49703 .66216 L .49912 .6593 L F
.623 .508 .702 r
.49703 .66216 m .50021 .66216 L .49912 .6593 L F
.53 .458 .72 r
.49703 .66216 m .50015 .66466 L .50021 .66216 L F
.49703 .66216 m .49774 .66546 L .50015 .66466 L F
.502 .404 .677 r
.51535 .65736 m .51408 .6593 L .51457 .65801 L F
.51535 .65736 m .51624 .65901 L .51408 .6593 L F
.351 .353 .721 r
.33751 .6005 m .33803 .60362 L .33968 .6023 L F
.436 .384 .702 r
.33839 .60634 m .33968 .6023 L .33803 .60362 L F
.793 .88 .91 r
.55481 .71416 m .55286 .71589 L .55123 .71492 L F
.962 .659 .41 r
.55286 .71589 m .55182 .71707 L .55123 .71492 L F
.605 .408 .589 r
.58444 .5921 m .58441 .59465 L .58166 .59464 L F
.704 .503 .614 r
.58652 .59238 m .58441 .59465 L .58444 .5921 L F
.312 .38 .772 r
.54047 .74341 m .54311 .7456 L .54428 .74366 L F
.476 .319 .588 r
.54638 .74314 m .54428 .74539 L .54428 .74366 L F
0 0 0 r
.54428 .74366 m .54311 .7456 L .5445 .74371 L F
.535 .625 .888 r
.54442 .74376 m .5445 .74371 L .54333 .74456 L F
.54626 .74241 m .5445 .74371 L .54442 .74376 L F
0 0 0 r
.54474 .74354 m .5445 .74371 L .54638 .74314 L F
.54428 .74366 m .5445 .74371 L .54474 .74354 L F
.6329 .48229 m .63454 .48145 L .63555 .4802 L F
.63555 .4802 m .63674 .48023 L .6375 .4789 L F
.422 .241 .528 r
.33784 .61476 m .33977 .61412 L .33991 .61177 L F
.348 .079 .357 r
.33784 .61476 m .33728 .6168 L .33977 .61412 L F
.611 .146 .125 r
.63132 .50226 m .63378 .50373 L .63471 .50232 L F
.801 .517 .508 r
.63378 .50373 m .63708 .50245 L .63471 .50232 L F
.663 .381 .483 r
.51766 .78358 m .51696 .78785 L .51458 .78803 L F
.51766 .78358 m .51878 .78387 L .51696 .78785 L F
.363 .816 .939 r
.67358 .48433 m .67019 .48191 L .67128 .48289 L F
.638 .48 .653 r
.50596 .74117 m .50598 .74313 L .50822 .74075 L F
.547 .492 .746 r
.47709 .75848 m .47766 .76012 L .47948 .75938 L F
.301 0 0 r
.55623 .72077 m .55266 .72055 L .55387 .72116 L F
.534 .866 .994 r
.6688 .47796 m .6723 .4779 L .66986 .47838 L F
.323 0 .192 r
.33097 .62321 m .33217 .6239 L .33309 .62273 L F
.33097 .62321 m .33027 .62454 L .33217 .6239 L F
.221 0 0 r
.25601 .59189 m .25791 .59141 L .25941 .58977 L F
.286 0 .007 r
.25941 .58977 m .26038 .59077 L .26147 .58927 L F
.25941 .58977 m .25791 .59141 L .26038 .59077 L F
.534 0 0 r
.55925 .72197 m .55971 .72266 L .55937 .72273 L F
.55925 .72197 m .56138 .72362 L .55971 .72266 L F
.527 .473 .739 r
.37749 .67638 m .37812 .67958 L .38028 .67837 L F
.588 .536 .765 r
.37883 .68199 m .38028 .67837 L .37812 .67958 L F
.56 .73 .955 r
.28686 .63036 m .28621 .63227 L .28476 .63109 L F
.28686 .63036 m .28832 .63186 L .28621 .63227 L F
.239 0 .272 r
.5383 .75694 m .53938 .75902 L .54072 .75639 L F
.5383 .75694 m .53778 .75964 L .53938 .75902 L F
.58 .513 .745 r
.61489 .52217 m .61557 .52452 L .61324 .52504 L F
.518 .437 .704 r
.37871 .66793 m .38073 .66749 L .38016 .66464 L F
.538 .413 .658 r
.37888 .67061 m .38073 .66749 L .37871 .66793 L F
.565 .713 .941 r
.70009 .48568 m .70189 .48793 L .70386 .48733 L F
.639 .16 .1 r
.47394 .68378 m .47795 .6848 L .47556 .68321 L F
.637 .781 .95 r
.37937 .70371 m .37852 .7009 L .38022 .70164 L F
.442 .776 .998 r
.37852 .7009 m .38077 .70051 L .38022 .70164 L F
.291 .282 .676 r
.38077 .70051 m .37937 .70371 L .38022 .70164 L F
.751 .959 .938 r
.71065 .52066 m .71424 .51949 L .71362 .51909 L F
.439 .857 .954 r
.71362 .51909 m .71424 .51949 L .71659 .51888 L F
.621 .445 .623 r
.49774 .66546 m .50015 .667 L .50015 .66466 L F
.49774 .66546 m .498 .66772 L .50015 .667 L F
.623 .862 .988 r
.461 .64367 m .46183 .64196 L .46324 .64313 L F
.461 .64367 m .45965 .64276 L .46183 .64196 L F
.898 .974 .813 r
.58084 .55254 m .58378 .55037 L .58178 .55333 L F
.58084 .55254 m .58289 .55003 L .58378 .55037 L F
.894 .975 .819 r
.58378 .55037 m .58573 .54648 L .58598 .54744 L F
.58378 .55037 m .58289 .55003 L .58573 .54648 L F
.453 .28 .555 r
.24258 .60612 m .2445 .60568 L .24461 .60331 L F
.424 .303 .611 r
.24258 .60612 m .24444 .60804 L .2445 .60568 L F
.24258 .60612 m .24285 .60881 L .24444 .60804 L F
.354 .493 .86 r
.5043 .63591 m .5032 .63793 L .50207 .63642 L F
.5043 .63591 m .50592 .63879 L .5032 .63793 L F
.785 .715 .786 r
.48021 .63946 m .47683 .63938 L .48056 .63542 L F
.798 .862 .897 r
.48475 .63598 m .48416 .63643 L .48467 .63656 L F
.48416 .63643 m .48021 .63946 L .48467 .63656 L F
.666 .609 .782 r
.48467 .63656 m .48056 .63542 L .48365 .63566 L F
0 .439 .838 r
.4836 .63565 m .48467 .63656 L .48365 .63566 L F
.4836 .63565 m .485 .63664 L .48467 .63656 L F
.78 .305 0 r
.48508 .63669 m .48475 .63598 L .48467 .63656 L F
0 .439 .838 r
.485 .63664 m .48508 .63669 L .48467 .63656 L F
.666 .609 .782 r
.48467 .63656 m .48021 .63946 L .48056 .63542 L F
.438 .426 .749 r
.37883 .68199 m .38147 .68405 L .38108 .68158 L F
.588 .536 .765 r
.37883 .68199 m .38108 .68158 L .38028 .67837 L F
0 0 0 r
.54566 .79866 m .54453 .79927 L .54329 .79887 L F
.54566 .79866 m .54735 .79732 L .54453 .79927 L F
.754 .429 .435 r
.53878 .78296 m .54097 .78524 L .53747 .78527 L F
.779 .465 .456 r
.64434 .50438 m .6423 .50468 L .64074 .50419 L F
.553 .056 .028 r
.64434 .50438 m .64613 .50493 L .6423 .50468 L F
0 .305 .792 r
.55676 .78259 m .55713 .78219 L .55598 .78348 L F
.55676 .78259 m .55791 .78342 L .55713 .78219 L F
.412 0 .139 r
.58218 .69042 m .58102 .69237 L .57878 .69259 L F
.03 0 .237 r
.58504 .68658 m .58218 .69042 L .58218 .69021 L F
.58504 .68658 m .58388 .6893 L .58218 .69042 L F
.684 .287 .288 r
.5845 .6924 m .58218 .69042 L .58388 .6893 L F
.5845 .6924 m .58102 .69237 L .58218 .69042 L F
0 0 0 r
.54854 .7517 m .54981 .75144 L .55058 .74939 L F
.131 .677 .808 r
.54733 .75157 m .54981 .75144 L .54854 .7517 L F
0 0 .057 r
.62145 .57789 m .62105 .57978 L .61967 .58094 L F
.101 0 .376 r
.62105 .57978 m .61904 .58307 L .61967 .58094 L F
.589 .325 .485 r
.38517 .65653 m .38696 .65825 L .38748 .65646 L F
.38517 .65653 m .38439 .65881 L .38696 .65825 L F
.547 .492 .746 r
.47709 .75848 m .47948 .75938 L .48047 .75931 L F
.539 .674 .925 r
.75423 .61027 m .75596 .60818 L .75341 .60844 L F
.75423 .61027 m .75631 .60981 L .75596 .60818 L F
.558 .357 .563 r
.55954 .70724 m .55963 .70962 L .55718 .70999 L F
.531 .335 .561 r
.56198 .70693 m .55963 .70962 L .55954 .70724 L F
.223 .663 .954 r
.32973 .60289 m .33165 .60306 L .32843 .60208 L F
.691 .245 .187 r
.5365 .7694 m .53394 .7705 L .53153 .76856 L F
.915 .855 .768 r
.53708 .76798 m .53394 .7705 L .5365 .7694 L F
.744 .519 .589 r
.24266 .62278 m .24414 .61954 L .2427 .62034 L F
.403 .131 .384 r
.63908 .48297 m .63925 .48496 L .63655 .4857 L F
.632 .295 .382 r
.64054 .48423 m .64157 .48511 L .64023 .48502 L F
.64054 .48423 m .64023 .48502 L .63925 .48496 L F
0 0 0 r
.6409 .484 m .63925 .48496 L .64157 .48511 L F
.6409 .484 m .64 .48623 L .6395 .4869 L F
.6399 .48588 m .6395 .4869 L .63899 .48759 L F
.6409 .484 m .6395 .4869 L .6399 .48588 L F
.632 .295 .382 r
.63908 .48297 m .64054 .48423 L .63925 .48496 L F
.594 .843 .992 r
.5036 .80151 m .50294 .80249 L .50095 .80227 L F
.45 0 0 r
.50095 .80227 m .50294 .80249 L .50297 .8029 L F
0 0 0 r
.50297 .8029 m .50294 .80249 L .5036 .80151 L F
.623 .593 .799 r
.38565 .69978 m .38759 .69917 L .38472 .69832 L F
.205 .663 .945 r
.29955 .6483 m .30149 .64922 L .30155 .64871 L F
.118 0 0 r
.29787 .63321 m .29967 .63346 L .30125 .63361 L F
.477 .88 .953 r
.30125 .63361 m .30182 .63278 L .30323 .63336 L F
.30125 .63361 m .29967 .63346 L .30182 .63278 L F
.882 .964 .844 r
.5751 .56183 m .57312 .56237 L .57385 .56074 L F
.984 .796 .57 r
.65387 .51287 m .65531 .5112 L .65142 .51035 L F
.65387 .51287 m .65511 .51407 L .65531 .5112 L F
.228 .682 .951 r
.3224 .59996 m .32587 .60087 L .32438 .60018 L F
.365 0 0 r
.32587 .60087 m .32661 .60141 L .32438 .60018 L F
.32587 .60087 m .32843 .60208 L .32661 .60141 L F
.751 .344 .281 r
.50432 .7887 m .50303 .79036 L .50073 .78806 L F
.131 .301 .769 r
.50432 .7887 m .50524 .78747 L .50303 .79036 L F
.50432 .7887 m .50661 .79059 L .50524 .78747 L F
.49 .351 .619 r
.55137 .70996 m .55359 .71202 L .55338 .7094 L F
.55137 .70996 m .55359 .71202 L .55338 .7094 L F
.617 .759 .946 r
.5441 .75718 m .54072 .75639 L .54274 .75605 L F
.866 .842 .819 r
.54585 .75467 m .5441 .75718 L .54274 .75605 L F
.576 .537 .775 r
.54752 .76032 m .5441 .75718 L .54645 .75753 L F
.653 .421 .555 r
.58166 .59464 m .58186 .59745 L .57848 .5975 L F
.587 .371 .555 r
.5845 .59677 m .58166 .59464 L .58441 .59465 L F
.5845 .59677 m .58186 .59745 L .58166 .59464 L F
.729 .457 .516 r
.56811 .69316 m .5705 .6954 L .56978 .69354 L F
.56811 .69316 m .56837 .69553 L .5705 .6954 L F
.542 .856 .997 r
.49426 .63495 m .49519 .63372 L .49638 .63399 L F
.49426 .63495 m .49287 .63435 L .49519 .63372 L F
0 0 0 r
.56044 .78479 m .56001 .78438 L .56284 .78183 L F
.576 .48 .709 r
.48164 .79476 m .4847 .79662 L .48128 .79368 L F
.906 .983 .775 r
.58598 .54744 m .58573 .54648 L .58747 .5439 L F
.851 .704 .699 r
.58852 .70667 m .5893 .70996 L .58821 .70899 L F
.916 .642 .506 r
.58965 .71247 m .58821 .70899 L .5893 .70996 L F
.741 .64 .747 r
.59197 .70746 m .5893 .70996 L .58852 .70667 L F
.315 0 .191 r
.34305 .63555 m .34224 .63398 L .34384 .6338 L F
.34305 .63555 m .34105 .63614 L .34224 .63398 L F
.15 0 0 r
.41825 .70967 m .41694 .70942 L .41909 .70888 L F
.41825 .70967 m .4155 .71066 L .41694 .70942 L F
.919 .574 .367 r
.56658 .74834 m .56757 .74661 L .56617 .74593 L F
.56658 .74834 m .56813 .74877 L .56757 .74661 L F
.663 .445 .579 r
.5794 .68478 m .58345 .68432 L .58311 .68201 L F
.761 .663 .753 r
.50026 .79657 m .5008 .79993 L .49749 .79948 L F
.816 .585 .588 r
.5008 .79993 m .49722 .80168 L .49749 .79948 L F
.5008 .79993 m .50095 .80227 L .49722 .80168 L F
.244 .288 .71 r
.50218 .7985 m .5008 .79993 L .50026 .79657 L F
.621 .603 .811 r
.50218 .7985 m .50095 .80227 L .5008 .79993 L F
.575 .034 0 r
.77419 .60771 m .77407 .60643 L .77061 .60594 L F
.805 .451 0 r
.77469 .60862 m .77407 .60643 L .77419 .60771 L F
.843 .657 .65 r
.77469 .60862 m .77662 .60582 L .77407 .60643 L F
.519 .317 .545 r
.40616 .67357 m .40604 .67603 L .40385 .67645 L F
.455 .241 .498 r
.40844 .67075 m .40817 .6731 L .40616 .67357 L F
.536 .33 .548 r
.40827 .67556 m .40616 .67357 L .40817 .6731 L F
.40827 .67556 m .40604 .67603 L .40616 .67357 L F
.959 .912 .726 r
.6084 .53741 m .60915 .53899 L .6102 .53639 L F
.898 .898 .818 r
.6084 .53741 m .60766 .54107 L .60915 .53899 L F
.68 .134 0 r
.47231 .80254 m .47296 .80393 L .47188 .80242 L F
.47231 .80254 m .47453 .80464 L .47296 .80393 L F
.959 .912 .726 r
.6084 .53741 m .6102 .53639 L .60933 .53544 L F
.798 .927 .553 r
.60971 .53482 m .60933 .53544 L .61107 .53251 L F
.933 .914 .776 r
.61087 .53339 m .60935 .53546 L .6102 .53639 L F
.311 .025 .307 r
.61248 .53374 m .61015 .53619 L .60971 .53483 L F
.60972 .53482 m .60971 .53483 L .60971 .53482 L F
.61248 .53374 m .60971 .53483 L .60972 .53482 L F
.933 .914 .776 r
.6109 .53324 m .61033 .53406 L .61087 .53339 L F
.61033 .53406 m .60935 .53546 L .61087 .53339 L F
.61107 .53251 m .60974 .53479 L .6109 .53324 L F
.60974 .53479 m .60935 .53546 L .6109 .53324 L F
.102 0 .14 r
.61327 .53144 m .61248 .53374 L .60972 .53482 L F
.60974 .53479 m .60972 .53482 L .60971 .53482 L F
.61327 .53144 m .60972 .53482 L .60974 .53479 L F
.61327 .53144 m .60974 .53479 L .61107 .53251 L F
.60974 .53479 m .60971 .53482 L .61107 .53251 L F
.933 .914 .776 r
.61107 .53251 m .60933 .53544 L .60935 .53546 L F
.996 .785 .424 r
.5712 .76326 m .57027 .7648 L .57116 .76553 L F
.5712 .76326 m .57042 .76252 L .57027 .7648 L F
.555 .46 .702 r
.28061 .62255 m .28093 .62592 L .27906 .62626 L F
.496 .578 .868 r
.65387 .51287 m .65191 .51454 L .65122 .51377 L F
.65387 .51287 m .65401 .51573 L .65191 .51454 L F
0 .322 .741 r
.65262 .51472 m .65191 .51454 L .65122 .51377 L F
.65262 .51472 m .65401 .51573 L .65191 .51454 L F
.238 .362 .788 r
.47779 .78479 m .47698 .78579 L .47553 .78267 L F
.944 .756 .29 r
.47779 .78479 m .47752 .78693 L .478 .7826 L F
0 0 0 r
.47779 .78484 m .47752 .78693 L .47779 .78479 L F
.535 .189 .328 r
.47752 .78693 m .48215 .78383 L .47807 .78262 L F
.47752 .78693 m .47807 .78262 L .478 .7826 L F
0 0 .165 r
.47779 .78479 m .47752 .78693 L .47698 .78579 L F
.648 .239 0 r
.47706 .78498 m .47777 .78618 L .47774 .78605 L F
.851 .56 .025 r
.4826 .78519 m .48234 .78312 L .48186 .78205 L F
.4826 .78519 m .48186 .78205 L .48189 .78222 L F
0 0 .365 r
.48236 .78367 m .48237 .78371 L .48206 .78293 L F
.48237 .78371 m .4826 .78519 L .48218 .78345 L F
.48237 .78371 m .48218 .78345 L .48206 .78293 L F
.812 .64 .669 r
.4826 .78519 m .48503 .78254 L .48234 .78312 L F
.762 .562 .627 r
.48239 .78374 m .48272 .78421 L .48247 .78361 L F
0 0 .365 r
.48237 .78369 m .4826 .78519 L .48236 .78367 L F
.48269 .78447 m .48267 .78462 L .48237 .78368 L F
.663 .403 .516 r
.48233 .78358 m .48247 .78361 L .48183 .78199 L F
0 0 .365 r
.48272 .78421 m .48269 .78447 L .48183 .78199 L F
.535 .189 .328 r
.48237 .78368 m .48247 .78361 L .48233 .78358 L F
.48237 .78368 m .48239 .78374 L .48247 .78361 L F
.851 .56 .025 r
.48189 .78222 m .48186 .78205 L .48183 .78199 L F
0 0 .365 r
.48269 .78447 m .48206 .78293 L .48183 .78199 L F
.762 .562 .627 r
.48013 .78696 m .48272 .78421 L .48239 .78374 L F
.663 .403 .516 r
.478 .7826 m .48233 .78358 L .48183 .78199 L F
0 0 .365 r
.48237 .78368 m .48237 .78369 L .48236 .78367 L F
.48267 .78462 m .4826 .78519 L .48237 .78368 L F
.535 .189 .328 r
.48215 .78383 m .48237 .78368 L .4821 .78353 L F
.48237 .78368 m .48233 .78358 L .4821 .78353 L F
.47752 .78693 m .48013 .78696 L .48239 .78374 L F
.47752 .78693 m .48239 .78374 L .48237 .78368 L F
.312 0 0 r
.4788 .78793 m .48013 .78696 L .47752 .78693 L F
.4788 .78793 m .47752 .78693 L .47774 .78605 L F
0 0 0 r
.47774 .78605 m .47752 .78693 L .47767 .78576 L F
.847 .425 .229 r
.47702 .78746 m .4788 .78793 L .47774 .78605 L F
.648 .239 0 r
.47777 .78618 m .4788 .78793 L .47774 .78605 L F
0 0 0 r
.47774 .78605 m .47767 .78576 L .47779 .78484 L F
.535 .189 .328 r
.48215 .78383 m .4821 .78353 L .478 .7826 L F
.743 .691 .801 r
.48062 .65645 m .48413 .65676 L .48281 .6535 L F
.757 .638 .729 r
.48062 .65645 m .48183 .65948 L .48413 .65676 L F
.611 .424 .605 r
.48413 .65676 m .48183 .65948 L .48409 .65893 L F
.728 .683 .807 r
.48281 .6535 m .48413 .65676 L .48609 .65407 L F
.657 .581 .757 r
.48413 .65676 m .4868 .65658 L .48609 .65407 L F
.765 .661 .747 r
.48409 .65893 m .4868 .65658 L .48413 .65676 L F
0 0 0 r
.52073 .78452 m .52365 .78278 L .52248 .78483 L F
.504 .069 .146 r
.52365 .78278 m .52484 .78449 L .52248 .78483 L F
.52365 .78278 m .526 .78278 L .52484 .78449 L F
.415 .311 .628 r
.30854 .66781 m .3105 .6699 L .31064 .66751 L F
.30854 .66781 m .309 .6708 L .3105 .6699 L F
.771 .265 0 r
.56177 .74026 m .56375 .74279 L .56488 .7432 L F
.846 .469 .335 r
.56359 .74505 m .56488 .7432 L .56375 .74279 L F
.56359 .74505 m .56617 .74593 L .56488 .7432 L F
.26 0 .31 r
.61904 .58307 m .61685 .58588 L .61701 .58368 L F
.506 .153 .302 r
.4487 .70012 m .44677 .6987 L .44907 .69875 L F
.4487 .70012 m .4455 .70118 L .44677 .6987 L F
.741 .64 .747 r
.59197 .70746 m .58852 .70667 L .59047 .70626 L F
.647 .884 .534 r
.59197 .70746 m .59276 .70618 L .59284 .70626 L F
.438 .734 .99 r
.59047 .70626 m .59276 .70618 L .59197 .70746 L F
.602 .61 .832 r
.6204 .54462 m .61778 .54296 L .61917 .54299 L F
.475 .513 .817 r
.62125 .5411 m .6204 .54462 L .61917 .54299 L F
.509 .493 .774 r
.6196 .54583 m .62053 .54302 L .61917 .54299 L F
.62053 .54302 m .62092 .54184 L .61917 .54299 L F
.602 .61 .832 r
.61778 .54296 m .61655 .54217 L .61917 .54299 L F
.475 .513 .817 r
.62125 .5411 m .62274 .54446 L .6204 .54462 L F
.713 .571 .694 r
.62386 .54711 m .6204 .54462 L .62274 .54446 L F
.588 .944 .815 r
.53605 .80663 m .53972 .80476 L .53928 .80506 L F
.691 .927 .969 r
.53972 .80476 m .54127 .80298 L .53928 .80506 L F
.53972 .80476 m .5428 .80358 L .54127 .80298 L F
.821 .905 .898 r
.72028 .51002 m .71833 .51346 L .71762 .51096 L F
.72028 .51002 m .72127 .511 L .71833 .51346 L F
.859 .491 .35 r
.54742 .79874 m .54735 .79732 L .54566 .79866 L F
.319 .072 .374 r
.54906 .79672 m .54735 .79732 L .54742 .79874 L F
.813 .783 .824 r
.54742 .77348 m .54445 .77621 L .54423 .77405 L F
.729 .728 .85 r
.71071 .47718 m .71142 .48002 L .70798 .47953 L F
.612 .653 .866 r
.71373 .47924 m .71142 .48002 L .71071 .47718 L F
.665 .786 .939 r
.38696 .70747 m .38459 .70827 L .38575 .70641 L F
.65 .846 .975 r
.38459 .70827 m .38696 .70747 L .38575 .70641 L F
.993 .785 .519 r
.71456 .48797 m .71565 .48952 L .71487 .48517 L F
.56 .331 .524 r
.41057 .67272 m .40844 .67075 L .4106 .67029 L F
.41057 .67272 m .40817 .6731 L .40844 .67075 L F
.596 .754 .954 r
.70115 .47852 m .69982 .48041 L .69893 .47943 L F
.70115 .47852 m .70229 .47984 L .69982 .48041 L F
0 0 .328 r
.54783 .76774 m .54718 .7662 L .54694 .76523 L F
.028 0 0 r
.43421 .64884 m .433 .64921 L .43449 .64893 L F
.147 0 0 r
.43379 .64872 m .43421 .64884 L .43592 .649 L F
.028 0 0 r
.43421 .64884 m .43449 .64893 L .43643 .64857 L F
.147 0 0 r
.43213 .64849 m .43421 .64884 L .43379 .64872 L F
.683 .711 .87 r
.69413 .48499 m .69449 .48774 L .69773 .48616 L F
.691 .194 0 r
.47453 .80464 m .47575 .80571 L .47737 .80782 L F
.022 0 .165 r
.49813 .76064 m .50039 .75742 L .49839 .75854 L F
.49813 .76064 m .49935 .76036 L .50039 .75742 L F
.206 .658 .947 r
.49813 .76064 m .50032 .76086 L .49935 .76036 L F
.435 .474 .801 r
.2836 .62744 m .28217 .62942 L .28093 .62592 L F
.386 .417 .771 r
.2836 .62744 m .28299 .63045 L .28217 .62942 L F
.993 .745 .414 r
.76963 .60253 m .77061 .60594 L .77058 .60345 L F
.601 .898 .987 r
.74621 .58604 m .74297 .58622 L .74537 .58498 L F
.455 .556 .869 r
.74792 .58386 m .74621 .58604 L .74537 .58498 L F
.74792 .58386 m .75074 .58656 L .74621 .58604 L F
.912 .541 .313 r
.47737 .80782 m .47896 .80843 L .47793 .80993 L F
.665 .202 .143 r
.47896 .80843 m .48144 .81022 L .47793 .80993 L F
.627 .552 .75 r
.40604 .67603 m .40421 .67871 L .40385 .67645 L F
.324 .52 .893 r
.24998 .65394 m .25021 .65368 L .24972 .65354 L F
.791 .701 .765 r
.64568 .52743 m .64893 .52786 L .64832 .52441 L F
.353 .495 .862 r
.74312 .59743 m .74461 .59611 L .74162 .59466 L F
.341 .474 .849 r
.74312 .59743 m .74482 .59779 L .74461 .59611 L F
.461 .559 .868 r
.75153 .60869 m .75234 .60567 L .7501 .60559 L F
.75153 .60869 m .75341 .60844 L .75234 .60567 L F
0 0 0 r
.61116 .5072 m .61158 .50697 L .61198 .50541 L F
.61198 .50541 m .61237 .50573 L .61268 .50366 L F
.61198 .50541 m .61158 .50697 L .61237 .50573 L F
.908 .942 .817 r
.5797 .55394 m .58178 .55333 L .57962 .55627 L F
.912 .936 .811 r
.58084 .55254 m .58178 .55333 L .5797 .55394 L F
.633 .821 .972 r
.29204 .63214 m .28832 .63186 L .29058 .63139 L F
.623 .865 .988 r
.29402 .63133 m .29204 .63214 L .29058 .63139 L F
.578 .575 .814 r
.62502 .54356 m .62386 .54711 L .62274 .54446 L F
.62502 .54356 m .62566 .54665 L .62386 .54711 L F
.626 .143 .086 r
.53768 .77946 m .53962 .77777 L .53612 .77741 L F
.678 .208 .128 r
.54185 .77947 m .53962 .77777 L .53768 .77946 L F
.597 .181 .224 r
.44835 .65937 m .44546 .6608 L .44389 .65946 L F
.389 0 0 r
.44976 .65957 m .44546 .6608 L .44835 .65937 L F
.533 .809 .997 r
.26221 .64539 m .26574 .64576 L .26425 .64485 L F
.603 .834 .988 r
.26425 .64485 m .26574 .64576 L .26791 .64514 L F
.599 .82 .984 r
.68011 .53903 m .68347 .53942 L .68245 .53837 L F
.542 .75 .972 r
.68347 .53942 m .68478 .53776 L .68245 .53837 L F
.68347 .53942 m .68587 .53903 L .68478 .53776 L F
.437 .76 .996 r
.32416 .58854 m .32354 .58977 L .32204 .58883 L F
.32416 .58854 m .32563 .58956 L .32354 .58977 L F
.718 .556 .67 r
.51776 .76899 m .51536 .77136 L .51394 .76891 L F
.51776 .76899 m .51778 .77154 L .51536 .77136 L F
.585 .392 .586 r
.52026 .76877 m .51778 .77154 L .51776 .76899 L F
.258 .763 .874 r
.2957 .58575 m .29784 .58543 L .29957 .58553 L F
.347 0 0 r
.29784 .58543 m .30144 .58609 L .29957 .58553 L F
.556 .884 .989 r
.54127 .80298 m .5428 .80358 L .54494 .80284 L F
.363 0 0 r
.4155 .6952 m .41931 .69638 L .41692 .69659 L F
.068 0 .158 r
.60742 .56931 m .60973 .56626 L .60772 .56699 L F
.871 .921 .857 r
.57708 .5569 m .5797 .55394 L .57962 .55627 L F
0 .236 .742 r
.47379 .65681 m .47356 .65584 L .47123 .654 L F
.038 .466 .88 r
.47379 .65681 m .47502 .65716 L .47356 .65584 L F
.603 .221 .291 r
.53772 .80168 m .5394 .79947 L .53558 .79977 L F
.552 .058 .036 r
.53991 .8012 m .5394 .79947 L .53772 .80168 L F
.53991 .8012 m .54229 .80013 L .5394 .79947 L F
.775 .558 .605 r
.48128 .79368 m .48486 .79398 L .48391 .79215 L F
.038 .196 .7 r
.48391 .79215 m .48573 .79295 L .48615 .79084 L F
.48391 .79215 m .48486 .79398 L .48573 .79295 L F
0 0 0 r
.45398 .65603 m .45135 .65859 L .45245 .65702 L F
.656 .699 .878 r
.7637 .60208 m .76477 .60369 L .76132 .60291 L F
.728 .855 .941 r
.76671 .60072 m .76477 .60369 L .7637 .60208 L F
.76671 .60072 m .7674 .60244 L .76477 .60369 L F
.853 .729 .726 r
.55718 .70999 m .55359 .71202 L .55338 .7094 L F
.55718 .70999 m .55556 .71323 L .55359 .71202 L F
.717 .518 .618 r
.59785 .57495 m .60017 .57511 L .60014 .57259 L F
.618 .399 .562 r
.60017 .57511 m .60304 .57236 L .60014 .57259 L F
.366 0 .199 r
.7096 .49921 m .7096 .49809 L .7067 .49989 L F
.899 .482 .162 r
.7096 .49921 m .71113 .50048 L .7096 .49809 L F
.38 .074 .316 r
.25133 .59485 m .2533 .59432 L .25401 .59237 L F
.379 .074 .316 r
.25401 .59237 m .25528 .59375 L .25601 .59189 L F
.25401 .59237 m .2533 .59432 L .25528 .59375 L F
.505 0 0 r
.5083 .79084 m .51208 .79339 L .51005 .79365 L F
.673 .182 .075 r
.51208 .79339 m .51422 .79476 L .51005 .79365 L F
.686 .799 .935 r
.68648 .48292 m .68892 .48512 L .69113 .48284 L F
.708 .98 .787 r
.62081 .52101 m .62241 .51901 L .62397 .52028 L F
.62081 .52101 m .62011 .52111 L .62241 .51901 L F
.572 .495 .73 r
.40774 .68395 m .40634 .68794 L .40536 .68427 L F
.40774 .68395 m .4085 .68747 L .40634 .68794 L F
.321 .356 .742 r
.38882 .70134 m .38949 .70439 L .39045 .70355 L F
0 0 .093 r
.38871 .70656 m .39045 .70355 L .38949 .70439 L F
.602 .266 .374 r
.41644 .66808 m .4162 .66992 L .41291 .67005 L F
.6 .265 .374 r
.41644 .66808 m .4186 .6698 L .4162 .66992 L F
.813 .999 .839 r
.25346 .65716 m .25116 .65935 L .25116 .65952 L F
.769 .987 .899 r
.25116 .65952 m .25116 .65935 L .25091 .65955 L F
.583 .374 .563 r
.61137 .54418 m .61359 .54384 L .61355 .54128 L F
.679 .45 .568 r
.61355 .54128 m .61621 .54294 L .61655 .54217 L F
.61355 .54128 m .61359 .54384 L .61621 .54294 L F
.529 .527 .797 r
.51377 .65022 m .51487 .65354 L .51282 .65387 L F
.603 .511 .723 r
.51535 .65736 m .51282 .65387 L .51487 .65354 L F
.51535 .65736 m .51457 .65801 L .51282 .65387 L F
.243 0 .001 r
.5571 .74802 m .55659 .74706 L .55894 .74864 L F
.424 .117 .339 r
.50761 .66976 m .50939 .67007 L .50945 .66831 L F
.392 .508 .856 r
.50807 .66447 m .50945 .66831 L .51095 .66639 L F
.549 .473 .723 r
.50939 .67007 m .51095 .66639 L .50945 .66831 L F
.607 .505 .713 r
.37692 .67323 m .37982 .67596 L .37883 .67262 L F
.37692 .67323 m .37749 .67638 L .37982 .67596 L F
.628 .404 .558 r
.61177 .58641 m .60967 .58828 L .60952 .58662 L F
.686 .442 .547 r
.60952 .58662 m .60967 .58828 L .60606 .58892 L F
.539 .172 .292 r
.61621 .54294 m .61917 .54299 L .61655 .54217 L F
.972 .752 .548 r
.62647 .51395 m .62507 .51523 L .62433 .51352 L F
.62647 .51395 m .62638 .51624 L .62507 .51523 L F
.63 .722 .914 r
.67358 .48433 m .67472 .4859 L .67707 .48519 L F
.323 0 .175 r
.29496 .60597 m .29379 .60811 L .29178 .6087 L F
.361 0 .196 r
.29579 .60755 m .29496 .60597 L .2971 .60552 L F
.29579 .60755 m .29379 .60811 L .29496 .60597 L F
.336 .76 .974 r
.33874 .59105 m .33477 .59045 L .337 .59045 L F
.299 .697 .976 r
.33929 .59018 m .33874 .59105 L .337 .59045 L F
.33929 .59018 m .34074 .5911 L .33874 .59105 L F
.866 .842 .819 r
.54585 .75467 m .54274 .75605 L .54526 .75401 L F
.697 .308 .306 r
.48921 .69328 m .48792 .69521 L .48561 .69306 L F
.631 .23 .265 r
.49142 .69489 m .48792 .69521 L .48921 .69328 L F
.734 .388 .394 r
.64313 .51566 m .6454 .51794 L .64728 .51554 L F
.619 .225 .275 r
.64768 .51772 m .64728 .51554 L .6454 .51794 L F
.349 .307 .67 r
.46831 .78578 m .47036 .78769 L .46998 .78458 L F
.46831 .78578 m .46911 .78842 L .47036 .78769 L F
.704 .503 .614 r
.58652 .59238 m .58672 .59494 L .58441 .59465 L F
.618 .393 .553 r
.5906 .59189 m .58672 .59494 L .58652 .59238 L F
.579 .676 .906 r
.71613 .47879 m .71907 .48029 L .71724 .47969 L F
.4 0 .129 r
.40932 .65343 m .41153 .65317 L .41286 .65122 L F
.411 0 .145 r
.41153 .65317 m .4151 .65093 L .41286 .65122 L F
.253 0 .159 r
.33522 .64122 m .33439 .63968 L .33642 .6391 L F
.33522 .64122 m .33332 .64196 L .33439 .63968 L F
.735 .71 .828 r
.55925 .77434 m .56125 .77493 L .56011 .77074 L F
.852 .396 .027 r
.56125 .77493 m .5603 .77578 L .56176 .77393 L F
.56125 .77493 m .56161 .7765 L .5603 .77578 L F
.794 .64 .691 r
.63845 .52185 m .64029 .52487 L .6385 .52421 L F
.768 .736 .824 r
.64029 .52487 m .6369 .52499 L .6385 .52421 L F
.739 .324 .263 r
.4947 .76508 m .4973 .76579 L .49557 .76363 L F
.327 0 .009 r
.44389 .65946 m .44254 .66109 L .44031 .66143 L F
.269 .773 .86 r
.44546 .6608 m .44254 .66109 L .44389 .65946 L F
.84 .775 .79 r
.71611 .4903 m .71291 .48986 L .71456 .48797 L F
.509 0 0 r
.71611 .4903 m .71625 .49134 L .71291 .48986 L F
.566 .757 .968 r
.71779 .4882 m .71611 .4903 L .71456 .48797 L F
.682 .525 .666 r
.7174 .4937 m .71996 .49356 L .7197 .49208 L F
.71889 .4917 m .7197 .49208 L .71949 .49089 L F
.7174 .4937 m .7197 .49208 L .71889 .4917 L F
.7174 .4937 m .71889 .4917 L .7189 .49244 L F
.71889 .4917 m .71949 .49089 L .7189 .49244 L F
.7174 .4937 m .7189 .49244 L .71611 .4903 L F
.62 .061 0 r
.71618 .49042 m .7189 .49244 L .71719 .49199 L F
.71611 .4903 m .71639 .49051 L .71618 .49042 L F
.71639 .49051 m .7189 .49244 L .71618 .49042 L F
.71611 .4903 m .71719 .49199 L .71625 .49134 L F
0 0 0 r
.53558 .79977 m .53308 .80241 L .53577 .80254 L F
.603 .221 .291 r
.53772 .80168 m .53558 .79977 L .53577 .80254 L F
.627 .552 .75 r
.40604 .67603 m .40662 .67923 L .40421 .67871 L F
.595 .474 .685 r
.40662 .67923 m .40501 .68208 L .40421 .67871 L F
.527 .473 .739 r
.37749 .67638 m .38028 .67837 L .37982 .67596 L F
.929 .883 .767 r
.53611 .77123 m .53531 .77124 L .53708 .76798 L F
.629 .263 .33 r
.63203 .49554 m .62984 .49399 L .63316 .49367 L F
.63203 .49554 m .62908 .49576 L .62984 .49399 L F
.528 .18 .323 r
.45475 .69591 m .45358 .69834 L .45133 .69848 L F
.53 .183 .324 r
.45699 .69727 m .45475 .69591 L .45694 .69544 L F
.45699 .69727 m .45358 .69834 L .45475 .69591 L F
.668 .654 .827 r
.48183 .65948 m .48558 .66025 L .48409 .65893 L F
.933 .931 .779 r
.56585 .57559 m .56685 .57162 L .56773 .57249 L F
.875 .94 .857 r
.56773 .57249 m .56943 .56875 L .57004 .56965 L F
.56773 .57249 m .56685 .57162 L .56943 .56875 L F
0 .297 .793 r
.75325 .59468 m .75569 .59646 L .75492 .59724 L F
.099 .464 .89 r
.75569 .59646 m .75659 .59765 L .75492 .59724 L F
.738 .388 .387 r
.62702 .54101 m .62492 .53893 L .62737 .53865 L F
.62702 .54101 m .62534 .54108 L .62492 .53893 L F
.895 .851 .792 r
.62534 .54108 m .62632 .5375 L .62492 .53893 L F
.826 .814 .838 r
.56472 .58384 m .56049 .58569 L .56326 .58281 L F
.78 .709 .785 r
.56395 .58061 m .56472 .58384 L .56326 .58281 L F
.56395 .58061 m .56691 .58101 L .56472 .58384 L F
.346 0 .037 r
.61651 .52946 m .61327 .53144 L .61474 .53111 L F
.616 .294 .402 r
.51878 .78387 m .51918 .78745 L .51696 .78785 L F
.51878 .78387 m .52073 .78452 L .51918 .78745 L F
.738 .629 .738 r
.47839 .65909 m .48183 .65948 L .48062 .65645 L F
.878 .993 .769 r
.56943 .56875 m .57198 .56653 L .57004 .56965 L F
.56943 .56875 m .57148 .566 L .57198 .56653 L F
.94 .952 .637 r
.57198 .56653 m .57148 .566 L .57312 .56237 L F
.648 .263 .3 r
.55919 .76266 m .55589 .76284 L .55676 .76132 L F
.869 .805 .784 r
.64467 .53833 m .64273 .54109 L .64541 .5413 L F
.903 .853 .784 r
.6421 .54324 m .64541 .5413 L .64273 .54109 L F
.6421 .54324 m .64335 .54427 L .64541 .5413 L F
.876 .807 .779 r
.64467 .53833 m .64541 .5413 L .64622 .53946 L F
.491 .288 .532 r
.48503 .78254 m .48687 .77995 L .48473 .77999 L F
0 .096 .626 r
.59848 .70591 m .5978 .70738 L .59715 .70515 L F
.064 .237 .731 r
.59848 .70591 m .59967 .70911 L .5978 .70738 L F
.612 .057 0 r
.5978 .70738 m .59967 .70911 L .59739 .70738 L F
.744 .519 .589 r
.24266 .62278 m .24586 .6227 L .24414 .61954 L F
.24266 .62278 m .24557 .62296 L .24586 .6227 L F
.755 .628 .72 r
.24414 .61954 m .24586 .6227 L .24559 .6203 L F
.678 .551 .703 r
.24586 .6227 m .24828 .62013 L .24559 .6203 L F
.24586 .6227 m .24862 .62307 L .24828 .62013 L F
0 0 0 r
.72912 .51668 m .72827 .51668 L .73015 .51571 L F
.72912 .51668 m .72746 .51795 L .72827 .51668 L F
.56 .763 .973 r
.30992 .63238 m .3069 .63425 L .30531 .63307 L F
.30992 .63238 m .30901 .63378 L .3069 .63425 L F
.147 .547 .925 r
.53101 .80811 m .52939 .80788 L .52964 .80693 L F
.53101 .80811 m .52939 .80788 L .52964 .80693 L F
.794 .797 .305 r
.59748 .72113 m .59737 .72108 L .59668 .72332 L F
0 .499 .728 r
.56681 .72597 m .56544 .72571 L .56355 .72541 L F
.077 .629 .824 r
.56863 .72604 m .56544 .72571 L .56681 .72597 L F
0 0 .54 r
.49883 .79335 m .50026 .79657 L .49912 .7944 L F
.658 .601 .78 r
.26791 .64514 m .26983 .64862 L .27153 .64731 L F
.657 .665 .847 r
.4984 .63436 m .50049 .63717 L .49744 .63729 L F
.31 .115 .446 r
.29114 .61058 m .28978 .60908 L .29178 .6087 L F
.29114 .61058 m .28952 .61155 L .28978 .60908 L F
.905 .7 .616 r
.56026 .73773 m .55983 .74018 L .56177 .74026 L F
.577 .009 0 r
.55983 .74018 m .56375 .74279 L .56177 .74026 L F
.979 .819 .614 r
.66571 .48994 m .66684 .49098 L .66729 .48875 L F
.565 .387 .599 r
.66729 .48875 m .66684 .49098 L .66905 .48813 L F
.372 .449 .81 r
.68188 .53325 m .68387 .53223 L .6815 .5312 L F
0 0 0 r
.68188 .53325 m .68107 .53451 L .68387 .53223 L F
.823 .939 .903 r
.69608 .53479 m .69691 .53553 L .69963 .53335 L F
.696 .256 0 r
.6397 .49677 m .63859 .49925 L .63723 .49632 L F
.6397 .49677 m .64061 .49852 L .63859 .49925 L F
.633 .11 0 r
.5154 .76214 m .51721 .76285 L .51545 .76141 L F
.125 0 0 r
.48613 .77193 m .48469 .7736 L .48804 .77125 L F
.37 .443 .805 r
.64261 .48641 m .64378 .4841 L .64157 .48511 L F
.64261 .48641 m .64519 .48771 L .64378 .4841 L F
.718 .771 .895 r
.51312 .68897 m .51436 .6899 L .51537 .68638 L F
.389 0 0 r
.44976 .65957 m .44961 .66089 L .44546 .6608 L F
0 0 0 r
.45135 .65859 m .45114 .65884 L .44976 .65957 L F
.44991 .6598 m .44976 .65957 L .45114 .65884 L F
.44991 .6598 m .44961 .66089 L .44976 .65957 L F
.592 .423 .621 r
.53674 .74898 m .53615 .7491 L .53585 .74639 L F
.53585 .74639 m .53615 .7491 L .53674 .74898 L F
.721 .37 0 r
.66116 .52441 m .66098 .5242 L .65991 .52141 L F
.897 .51 .286 r
.65991 .52141 m .66098 .5242 L .65881 .52264 L F
.393 .582 .916 r
.66098 .5242 m .66299 .52257 L .66077 .52396 L F
.621 .076 0 r
.66098 .5242 m .66048 .52414 L .65881 .52264 L F
.393 .582 .916 r
.66098 .5242 m .66077 .52396 L .66048 .52414 L F
.721 .37 0 r
.66147 .52514 m .66098 .5242 L .66116 .52441 L F
0 0 .553 r
.66147 .52514 m .66288 .52687 L .66098 .5242 L F
.371 0 0 r
.50396 .77008 m .5026 .76925 L .50132 .76854 L F
.50396 .77008 m .5057 .77096 L .5026 .76925 L F
.726 .743 .865 r
.36772 .72702 m .36667 .72895 L .37 .72628 L F
0 0 .342 r
.55732 .74943 m .55699 .75113 L .55741 .75124 L F
.367 .157 .457 r
.55699 .75113 m .55888 .75347 L .55741 .75124 L F
.55699 .75113 m .55726 .75391 L .55888 .75347 L F
.494 .441 .727 r
.2429 .6118 m .24331 .61169 L .24285 .60881 L F
.379 .451 .809 r
.41426 .69195 m .41362 .69503 L .41217 .69223 L F
.41426 .69195 m .4155 .6952 L .41362 .69503 L F
.655 .772 .935 r
.47431 .64132 m .47122 .64012 L .47339 .63908 L F
.744 .772 .876 r
.47683 .63938 m .47431 .64132 L .47339 .63908 L F
.602 .505 .717 r
.40726 .68165 m .40536 .68427 L .40501 .68208 L F
.586 .484 .705 r
.40726 .68165 m .40774 .68395 L .40536 .68427 L F
.592 .582 .81 r
.70386 .48733 m .7044 .4899 L .70614 .48686 L F
.577 .56 .798 r
.70455 .48988 m .70614 .48686 L .7044 .4899 L F
.062 .308 .793 r
.50839 .64048 m .50663 .64032 L .50592 .63879 L F
.50839 .64048 m .50886 .64209 L .50663 .64032 L F
.947 .922 .751 r
.56468 .57808 m .56401 .57624 L .56585 .57559 L F
.958 .766 .602 r
.56468 .57808 m .56252 .57973 L .56401 .57624 L F
.56468 .57808 m .56395 .58061 L .56252 .57973 L F
.267 0 0 r
.42712 .69555 m .42935 .69512 L .43087 .69358 L F
.279 0 0 r
.43087 .69358 m .43168 .6947 L .43301 .69314 L F
.43087 .69358 m .42935 .69512 L .43168 .6947 L F
0 .243 .757 r
.65915 .50249 m .66001 .50414 L .6594 .50429 L F
.65915 .50249 m .66081 .50464 L .66001 .50414 L F
.974 .765 .341 r
.66001 .50414 m .6594 .50565 L .6594 .50429 L F
.66001 .50414 m .66012 .50803 L .6594 .50565 L F
.451 .205 .448 r
.36601 .6114 m .36852 .60886 L .36815 .61061 L F
.474 .198 .415 r
.36852 .60886 m .37024 .61024 L .36815 .61061 L F
.36852 .60886 m .37068 .60844 L .37024 .61024 L F
.849 .989 .723 r
.60602 .54196 m .60766 .54107 L .60621 .54056 L F
.60602 .54196 m .60525 .54429 L .60766 .54107 L F
.898 .898 .818 r
.6084 .53741 m .60621 .54056 L .60766 .54107 L F
.797 .782 .839 r
.774 .61052 m .77529 .61195 L .77769 .6093 L F
.475 .124 .29 r
.49935 .76036 m .50279 .75765 L .50039 .75742 L F
.552 .519 .772 r
.38423 .69608 m .38472 .69832 L .38642 .69576 L F
.614 .602 .815 r
.38472 .69832 m .38759 .69917 L .38642 .69576 L F
.305 .735 .971 r
.33011 .58913 m .3292 .59002 L .32781 .58935 L F
.33011 .58913 m .33115 .58993 L .3292 .59002 L F
.595 .474 .685 r
.40662 .67923 m .40726 .68165 L .40501 .68208 L F
.767 .432 .418 r
.5083 .79084 m .50647 .79309 L .50661 .79059 L F
.5083 .79084 m .51005 .79365 L .50647 .79309 L F
.561 .37 .579 r
.50598 .74313 m .5082 .74344 L .50822 .74075 L F
.50598 .74313 m .5082 .74344 L .50822 .74075 L F
0 0 0 r
.51815 .81344 m .52085 .81132 L .51929 .81257 L F
.386 .417 .771 r
.2836 .62744 m .28476 .63109 L .28299 .63045 L F
.581 .124 .132 r
.30466 .60428 m .30299 .60313 L .30514 .60273 L F
.30466 .60428 m .30141 .60466 L .30299 .60313 L F
.67 .256 .252 r
.47775 .69272 m .47649 .69341 L .47423 .6925 L F
.446 0 0 r
.47997 .69333 m .47649 .69341 L .47775 .69272 L F
.835 .497 .414 r
.61929 .51457 m .62227 .5136 L .62122 .51236 L F
.509 .745 .98 r
.62122 .51236 m .62227 .5136 L .62326 .51207 L F
.855 .417 .172 r
.62433 .51352 m .6236 .51253 L .62227 .5136 L F
.6236 .51253 m .62299 .5125 L .62227 .5136 L F
.652 .38 .495 r
.62305 .51361 m .62128 .51507 L .62122 .5124 L F
.62127 .5124 m .62122 .5124 L .62122 .51236 L F
.62305 .51361 m .62122 .5124 L .62127 .5124 L F
.855 .417 .172 r
.6236 .51253 m .62326 .51207 L .62299 .5125 L F
.119 0 0 r
.49832 .69619 m .49699 .69605 L .49494 .69577 L F
.481 0 0 r
.49832 .69619 m .4994 .69718 L .49699 .69605 L F
.49832 .69619 m .50049 .69809 L .4994 .69718 L F
.517 .681 .94 r
.69089 .47959 m .68713 .47781 L .68943 .47748 L F
.578 .701 .926 r
.69312 .47906 m .69089 .47959 L .68943 .47748 L F
.68 .19 .08 r
.50733 .76329 m .50645 .76444 L .50403 .76258 L F
.78 .318 .148 r
.50733 .76329 m .50889 .76556 L .50645 .76444 L F
0 0 .342 r
.55732 .74943 m .55741 .75124 L .55894 .74864 L F
.274 0 0 r
.26561 .58832 m .26937 .58653 L .26736 .58704 L F
.966 .645 .345 r
.67953 .52392 m .67971 .52683 L .67895 .52442 L F
0 .177 .665 r
.68205 .52583 m .68353 .52725 L .67953 .52392 L F
.68205 .52583 m .67953 .52392 L .67895 .52442 L F
0 0 0 r
.47021 .7684 m .47173 .7678 L .47284 .76628 L F
.047 .356 .829 r
.47415 .76603 m .47556 .76823 L .47284 .76628 L F
.47415 .76603 m .47284 .76628 L .47173 .7678 L F
.975 .675 .307 r
.64722 .50798 m .64637 .50714 L .64651 .50598 L F
.738 .906 .529 r
.64722 .50798 m .6453 .51061 L .64637 .50714 L F
.681 .61 .769 r
.64534 .51071 m .64527 .51053 L .64359 .51177 L F
.626 .453 .628 r
.64637 .50714 m .64524 .51046 L .64425 .50817 L F
.681 .61 .769 r
.64527 .51053 m .64524 .51046 L .64502 .51066 L F
.626 .453 .628 r
.64524 .51046 m .6451 .51089 L .64502 .51066 L F
.64524 .51046 m .64502 .51066 L .64425 .50817 L F
.729 .51 .595 r
.64425 .50817 m .64502 .51066 L .64066 .5096 L F
.681 .61 .769 r
.64502 .51066 m .64519 .51033 L .64457 .51089 L F
.64524 .51046 m .64519 .51033 L .64502 .51066 L F
.76 .548 .611 r
.64359 .51177 m .64066 .5096 L .64476 .51079 L F
.681 .61 .769 r
.64527 .51053 m .64476 .51079 L .64359 .51177 L F
.76 .548 .611 r
.64359 .51177 m .64476 .51079 L .6451 .51089 L F
.681 .61 .769 r
.64476 .51079 m .64457 .51089 L .64359 .51177 L F
.729 .51 .595 r
.64502 .51066 m .6451 .51089 L .64476 .51079 L F
.64502 .51066 m .64476 .51079 L .64066 .5096 L F
.738 .906 .529 r
.6453 .51061 m .6451 .51089 L .64524 .51046 L F
.6453 .51061 m .64524 .51046 L .64637 .50714 L F
.681 .61 .769 r
.64465 .5117 m .64534 .51071 L .64359 .51177 L F
.738 .906 .529 r
.6453 .51061 m .64465 .5117 L .6451 .51089 L F
.64722 .50798 m .64465 .5117 L .6453 .51061 L F
.681 .61 .769 r
.64534 .51071 m .64634 .50929 L .6458 .50978 L F
.6453 .51061 m .6458 .50978 L .64519 .51033 L F
.64534 .51071 m .6458 .50978 L .6453 .51061 L F
.804 .584 .603 r
.64637 .50714 m .64894 .50934 L .64845 .50694 L F
.64637 .50714 m .64634 .50929 L .64894 .50934 L F
.984 .767 .365 r
.64637 .50714 m .64598 .50935 L .64634 .50929 L F
0 0 .101 r
.6476 .50557 m .64637 .50714 L .64845 .50694 L F
.6476 .50557 m .64616 .50895 L .64637 .50714 L F
.64616 .50895 m .64598 .50935 L .64637 .50714 L F
.975 .675 .307 r
.64651 .50598 m .64637 .50714 L .64613 .50493 L F
.108 0 0 r
.71896 .5191 m .71659 .51888 L .7199 .519 L F
.38 0 0 r
.72233 .51864 m .71896 .5191 L .7199 .519 L F
.83 .659 .67 r
.57248 .59151 m .57508 .59213 L .57439 .59453 L F
.585 .392 .586 r
.52026 .76877 m .52034 .77126 L .51778 .77154 L F
.455 .253 .516 r
.52238 .76847 m .52034 .77126 L .52026 .76877 L F
.879 .484 .028 r
.5926 .6894 m .59443 .6926 L .59359 .69032 L F
.886 .689 .63 r
.64315 .53253 m .64457 .53566 L .64501 .53346 L F
.837 .676 .683 r
.66991 .49607 m .6715 .49935 L .67047 .49688 L F
.337 .443 .822 r
.47829 .7957 m .47718 .79698 L .47555 .79374 L F
0 .303 .739 r
.25021 .65368 m .24817 .65224 L .24972 .65354 L F
.452 .419 .73 r
.33912 .60815 m .33991 .61177 L .34168 .61106 L F
.354 .185 .508 r
.33991 .61177 m .34152 .61342 L .34168 .61106 L F
.33991 .61177 m .33977 .61412 L .34152 .61342 L F
.996 .768 .425 r
.48751 .81055 m .48681 .80768 L .48511 .81095 L F
.016 0 .357 r
.48802 .8127 m .48751 .81055 L .48511 .81095 L F
.873 .439 .046 r
.55058 .74939 m .54969 .74887 L .54985 .74802 L F
.639 .611 .805 r
.54662 .74553 m .54974 .74859 L .54499 .74914 L F
.54974 .74859 m .55007 .74891 L .54961 .74893 L F
.54974 .74859 m .54961 .74893 L .54499 .74914 L F
.166 .442 .874 r
.54955 .74702 m .5499 .74829 L .54662 .74553 L F
.5499 .74829 m .55007 .74891 L .54974 .74859 L F
.5499 .74829 m .54974 .74859 L .54662 .74553 L F
0 0 0 r
.55099 .74529 m .54993 .74822 L .55108 .74508 L F
.732 .861 .941 r
.54955 .74702 m .54678 .74864 L .54965 .74887 L F
.5499 .74829 m .54965 .74887 L .55007 .74891 L F
.54955 .74702 m .54965 .74887 L .5499 .74829 L F
0 0 0 r
.54975 .74856 m .54973 .74869 L .55099 .74529 L F
.977 .92 .645 r
.5499 .74829 m .54969 .74887 L .55007 .74891 L F
0 0 0 r
.54973 .74869 m .54969 .74887 L .5499 .74829 L F
.977 .92 .645 r
.54955 .74702 m .54969 .74887 L .5499 .74829 L F
0 0 0 r
.5499 .74829 m .54969 .74887 L .54997 .74811 L F
.54973 .74869 m .54997 .74811 L .55099 .74529 L F
.54993 .74822 m .54969 .74887 L .54993 .74821 L F
.54993 .74822 m .54993 .74821 L .55108 .74508 L F
.54985 .74802 m .54975 .74856 L .55099 .74529 L F
.324 .743 .976 r
.75943 .60951 m .76047 .61012 L .76268 .60991 L F
.515 .271 .483 r
.4879 .76867 m .49015 .76833 L .49037 .76614 L F
.383 .162 .449 r
.49037 .76614 m .49015 .76833 L .49238 .76546 L F
.933 .931 .779 r
.56585 .57559 m .56484 .57506 L .56685 .57162 L F
.949 .919 .748 r
.56585 .57559 m .56401 .57624 L .56484 .57506 L F
.181 .187 .629 r
.63017 .50463 m .63085 .50622 L .63053 .50589 L F
.854 .509 .401 r
.63017 .50463 m .62809 .50634 L .63085 .50622 L F
.36 .209 .537 r
.63017 .50463 m .63137 .50456 L .63132 .50226 L F
.806 .569 .579 r
.63137 .50456 m .62809 .50634 L .63017 .50463 L F
.439 .141 .361 r
.32521 .62847 m .32741 .62799 L .32813 .62526 L F
.344 .057 .325 r
.32813 .62526 m .32931 .62723 L .33027 .62454 L F
.32813 .62526 m .32741 .62799 L .32931 .62723 L F
.82 .972 .666 r
.60403 .5451 m .60319 .54715 L .60525 .54429 L F
.842 .973 .664 r
.60602 .54196 m .60403 .5451 L .60525 .54429 L F
.501 .618 .9 r
.64259 .47835 m .64117 .48036 L .64035 .47803 L F
.502 .619 .9 r
.64259 .47835 m .64335 .48034 L .64117 .48036 L F
.793 .955 .921 r
.33361 .60207 m .33575 .60158 L .33751 .6005 L F
.33361 .60207 m .33751 .6005 L .33594 .60157 L F
.65 .092 0 r
.33751 .6005 m .33802 .60179 L .33594 .60157 L F
.33751 .6005 m .33968 .6023 L .33802 .60179 L F
.447 .004 .102 r
.40318 .65499 m .40479 .65318 L .40142 .65406 L F
.62 .24 .301 r
.40318 .65499 m .40694 .65329 L .40479 .65318 L F
.403 .14 .397 r
.36815 .61061 m .36578 .61271 L .36601 .6114 L F
.133 .018 .445 r
.24671 .63981 m .24815 .63655 L .24608 .637 L F
.24671 .63981 m .24799 .63879 L .24815 .63655 L F
.618 .399 .562 r
.60017 .57511 m .60311 .57491 L .60304 .57236 L F
.443 .208 .46 r
.60311 .57491 m .60513 .57184 L .60304 .57236 L F
.629 .814 .971 r
.51765 .65876 m .51973 .65943 L .51624 .65901 L F
.67 .452 .58 r
.51824 .6612 m .51624 .65901 L .51973 .65943 L F
.547 .804 .993 r
.52193 .65886 m .51973 .65943 L .51765 .65876 L F
.574 .193 .282 r
.52171 .66075 m .51973 .65943 L .52193 .65886 L F
.52171 .66075 m .51824 .6612 L .51973 .65943 L F
.719 .422 .475 r
.49322 .80544 m .4894 .80738 L .48951 .80483 L F
.49322 .80544 m .49312 .80728 L .4894 .80738 L F
.779 .674 .748 r
.49544 .80473 m .49312 .80728 L .49322 .80544 L F
0 .303 .797 r
.66221 .48722 m .66366 .48922 L .66311 .48927 L F
.938 .793 .673 r
.65116 .51795 m .65401 .51573 L .65262 .51472 L F
.65116 .51795 m .65233 .51951 L .65401 .51573 L F
.887 .875 .819 r
.65387 .51287 m .65401 .51573 L .65511 .51407 L F
.961 .727 .538 r
.62815 .52764 m .62795 .52995 L .62672 .52698 L F
.433 .691 .973 r
.35398 .59145 m .3533 .59303 L .35195 .59185 L F
.35398 .59145 m .35615 .59327 L .3533 .59303 L F
.594 .925 .965 r
.62562 .51855 m .62397 .52028 L .62241 .51901 L F
.62562 .51855 m .62602 .5192 L .62397 .52028 L F
.504 .237 .442 r
.42438 .66737 m .42184 .66953 L .42221 .66789 L F
.901 .485 .134 r
.51523 .79332 m .51458 .79127 L .5128 .79019 L F
.739 .76 .87 r
.72811 .48817 m .72294 .48817 L .72839 .48702 L F
.073 .278 .765 r
.72839 .48702 m .72879 .48681 L .72811 .48817 L F
.012 .197 .708 r
.72879 .48681 m .72996 .49 L .72811 .48817 L F
.997 .854 .528 r
.73269 .49899 m .73219 .50112 L .73288 .50218 L F
.945 .702 .539 r
.7312 .50388 m .73288 .50218 L .73219 .50112 L F
.563 .826 .995 r
.68185 .48443 m .68562 .48149 L .68086 .48284 L F
.68185 .48443 m .68505 .48347 L .68562 .48149 L F
.813 .981 .698 r
.65341 .48536 m .65524 .48234 L .65652 .4836 L F
.13 .651 .885 r
.65524 .48234 m .65911 .48297 L .65652 .4836 L F
.182 .713 .839 r
.32008 .60014 m .31881 .60008 L .3167 .60028 L F
.184 .714 .84 r
.3224 .59996 m .31881 .60008 L .32008 .60014 L F
.513 .392 .653 r
.63925 .48496 m .63686 .48811 L .63655 .4857 L F
.589 .87 .994 r
.48095 .79889 m .47651 .79927 L .47872 .80029 L F
.662 .572 .743 r
.48095 .79889 m .48359 .79956 L .4847 .79662 L F
.587 .065 0 r
.481 .80034 m .48095 .79889 L .47872 .80029 L F
.481 .80034 m .48359 .79956 L .48095 .79889 L F
.505 .845 .996 r
.6757 .47812 m .6723 .4779 L .67455 .47744 L F
.517 .847 .997 r
.67455 .47744 m .67805 .47766 L .6757 .47812 L F
.732 .721 .84 r
.64668 .51988 m .64417 .52219 L .64753 .52199 L F
.594 .165 .197 r
.64417 .52219 m .64662 .52353 L .64753 .52199 L F
.625 .685 .886 r
.64753 .52199 m .64832 .52038 L .64668 .51988 L F
.64753 .52199 m .64998 .52168 L .64832 .52038 L F
.936 .612 .399 r
.64753 .52199 m .64832 .52441 L .64998 .52168 L F
.64753 .52199 m .64662 .52353 L .64832 .52441 L F
.715 .871 .955 r
.48831 .63664 m .48508 .63669 L .48699 .63592 L F
.797 .914 .919 r
.48831 .63664 m .48905 .63406 L .4906 .63539 L F
.48831 .63664 m .48699 .63592 L .48905 .63406 L F
.022 0 .187 r
.62386 .57497 m .62316 .57688 L .62145 .57789 L F
0 0 .116 r
.62316 .57688 m .62105 .57978 L .62145 .57789 L F
.688 .673 .83 r
.498 .66772 m .50134 .66842 L .50015 .667 L F
.669 .668 .84 r
.50015 .667 m .50134 .66842 L .50376 .66765 L F
.887 .458 .126 r
.51819 .76439 m .51879 .76338 L .51721 .76285 L F
.51819 .76439 m .51934 .76498 L .51879 .76338 L F
.686 .632 .79 r
.59507 .70192 m .59715 .70515 L .59574 .70416 L F
.399 .401 .746 r
.59715 .70515 m .59284 .70626 L .59574 .70416 L F
.444 .528 .849 r
.59788 .70363 m .59715 .70515 L .59507 .70192 L F
0 .096 .626 r
.59848 .70591 m .59715 .70515 L .59788 .70363 L F
.532 .347 .575 r
.55133 .75478 m .552 .75747 L .54978 .75748 L F
.299 .224 .601 r
.55319 .75369 m .552 .75747 L .55133 .75478 L F
.754 .498 .545 r
.48806 .69224 m .49153 .69022 L .48809 .69061 L F
.48806 .69224 m .49191 .69308 L .49153 .69022 L F
.583 .377 .567 r
.49153 .69022 m .49191 .69308 L .4935 .69262 L F
.436 .187 .438 r
.36028 .619 m .35863 .61749 L .36077 .61709 L F
.36028 .619 m .35823 .61964 L .35863 .61749 L F
0 .505 .795 r
.2444 .63114 m .24497 .63132 L .2448 .63128 L F
.577 .56 .798 r
.70455 .48988 m .70705 .48929 L .70614 .48686 L F
.284 .517 .902 r
.67024 .53029 m .67163 .52965 L .66846 .52782 L F
.982 .869 .5 r
.6716 .53183 m .67163 .52965 L .67024 .53029 L F
.352 .773 .976 r
.30155 .64871 m .30664 .64946 L .30517 .64855 L F
.358 .726 .987 r
.30664 .64946 m .30565 .64837 L .30517 .64855 L F
.122 .375 .833 r
.31151 .64912 m .31065 .64986 L .31215 .64969 L F
.31151 .64912 m .31145 .64966 L .31065 .64986 L F
.358 .726 .987 r
.30664 .64946 m .31145 .64966 L .30565 .64837 L F
.319 .742 .974 r
.30664 .64946 m .31065 .64986 L .31145 .64966 L F
.702 .658 .804 r
.24414 .61954 m .24559 .6203 L .24828 .62013 L F
.581 .247 .367 r
.46276 .69308 m .46161 .6955 L .45932 .69537 L F
.608 .275 .381 r
.4649 .69483 m .46161 .6955 L .46276 .69308 L F
.613 .272 .368 r
.46512 .69327 m .4649 .69483 L .46276 .69308 L F
.662 .595 .77 r
.76132 .60291 m .75804 .60024 L .76005 .60034 L F
.657 .791 .946 r
.76239 .6004 m .76132 .60291 L .76005 .60034 L F
.76239 .6004 m .7637 .60208 L .76132 .60291 L F
.619 .775 .955 r
.76671 .60072 m .7637 .60208 L .76239 .6004 L F
.76671 .60072 m .76239 .6004 L .76575 .60046 L F
.238 0 0 r
.76239 .6004 m .76193 .60082 L .76557 .60048 L F
.76239 .6004 m .76557 .60048 L .76575 .60046 L F
.657 .791 .946 r
.76239 .6004 m .76005 .60034 L .76005 .60034 L F
.648 .337 .431 r
.50279 .75765 m .50501 .75974 L .5064 .75681 L F
.665 .356 .44 r
.5064 .75681 m .50877 .75919 L .50798 .75767 L F
.5064 .75681 m .50501 .75974 L .50877 .75919 L F
.176 .708 .722 r
.41931 .69638 m .42112 .69598 L .42253 .69572 L F
.221 0 0 r
.42112 .69598 m .42487 .69583 L .42253 .69572 L F
0 0 0 r
.6329 .48229 m .63273 .48276 L .63454 .48145 L F
.3 .793 .772 r
.31664 .64906 m .31873 .64863 L .32076 .64796 L F
.108 0 .237 r
.24461 .60331 m .24601 .60259 L .24667 .60044 L F
.265 .164 .548 r
.24461 .60331 m .24603 .6051 L .24601 .60259 L F
.325 .177 .52 r
.2445 .60568 m .24603 .6051 L .24461 .60331 L F
.291 .405 .807 r
.52049 .7736 m .51778 .77154 L .52034 .77126 L F
.798 .601 .635 r
.54669 .78281 m .54331 .78529 L .54458 .78292 L F
.54669 .78281 m .54735 .78603 L .54331 .78529 L F
.8 .482 .451 r
.54669 .78281 m .5495 .78444 L .54735 .78603 L F
0 .326 .785 r
.53882 .73619 m .54009 .73635 L .53849 .73453 L F
.53882 .73619 m .54129 .73731 L .54009 .73635 L F
.717 .881 .957 r
.39062 .71524 m .39206 .71613 L .39398 .71504 L F
.603 .135 .115 r
.76584 .60947 m .76515 .61062 L .76268 .60991 L F
0 0 0 r
.76806 .60775 m .76584 .60947 L .76794 .60892 L F
.638 .712 .901 r
.76584 .60947 m .7687 .60979 L .76794 .60892 L F
0 0 0 r
.76806 .60775 m .76515 .61062 L .76584 .60947 L F
.254 .709 .954 r
.77529 .57783 m .77424 .57821 L .77351 .5775 L F
.309 0 0 r
.7743 .57809 m .77529 .57783 L .77258 .57732 L F
0 .073 .569 r
.77232 .57624 m .7743 .57809 L .77241 .57642 L F
.77215 .57616 m .77241 .57642 L .7721 .57613 L F
.77232 .57624 m .77241 .57642 L .77215 .57616 L F
.254 .709 .954 r
.77351 .5775 m .77354 .57846 L .77258 .57732 L F
.77424 .57821 m .77354 .57846 L .77351 .5775 L F
.77529 .57783 m .77553 .57844 L .77354 .57846 L F
0 0 .541 r
.65223 .49285 m .65294 .49637 L .65219 .49453 L F
.859 .871 .846 r
.69736 .52203 m .6949 .52497 L .69376 .52384 L F
.75 .647 .746 r
.78346 .59792 m .7831 .59845 L .78136 .59804 L F
.509 .33 .574 r
.78346 .59792 m .78638 .59734 L .7831 .59845 L F
.145 0 .333 r
.78638 .59734 m .7838 .60079 L .7831 .59845 L F
.823 .939 .903 r
.69608 .53479 m .69963 .53335 L .6983 .53362 L F
.175 .709 .742 r
.45169 .64515 m .4539 .64471 L .45496 .64458 L F
.227 .746 .764 r
.45496 .64458 m .45613 .64418 L .45769 .64355 L F
.45496 .64458 m .4539 .64471 L .45613 .64418 L F
.334 .334 .71 r
.51286 .64677 m .51129 .64841 L .51075 .64483 L F
.377 .399 .756 r
.51286 .64677 m .51377 .65022 L .51129 .64841 L F
.228 0 .076 r
.28668 .61347 m .28751 .61228 L .28952 .61155 L F
.81 .999 .794 r
.48128 .79368 m .48439 .79079 L .48238 .79315 L F
.339 .557 .916 r
.48615 .79084 m .48439 .79079 L .48209 .78784 L F
.338 0 .1 r
.48238 .79315 m .48439 .79079 L .48615 .79084 L F
.866 .982 .847 r
.5498 .77135 m .54939 .77019 L .55214 .76863 L F
.5498 .77135 m .54904 .77086 L .54939 .77019 L F
.998 .819 .476 r
.5498 .77135 m .54869 .77328 L .54904 .77086 L F
.3 0 0 r
.43307 .7036 m .43153 .7053 L .42917 .70565 L F
.358 0 0 r
.43518 .70349 m .43153 .7053 L .43307 .7036 L F
.993 .768 .488 r
.65922 .51596 m .65785 .51794 L .65838 .51469 L F
.65922 .51596 m .65886 .51883 L .65785 .51794 L F
.381 .63 .951 r
.69788 .51655 m .69584 .51638 L .69705 .51512 L F
.69788 .51655 m .69584 .51638 L .69705 .51512 L F
.846 .481 .361 r
.48128 .79368 m .4847 .79662 L .48462 .79661 L F
.48128 .79368 m .48462 .79661 L .48486 .79398 L F
.074 .252 .742 r
.48573 .79295 m .48486 .79398 L .48705 .796 L F
.702 .658 .804 r
.24414 .61954 m .24828 .62013 L .24618 .61718 L F
.391 .557 .898 r
.24618 .61718 m .24828 .62013 L .24925 .61879 L F
.212 .306 .743 r
.24828 .62013 m .25005 .62201 L .24925 .61879 L F
.414 .357 .684 r
.24828 .62013 m .24862 .62307 L .25005 .62201 L F
.858 .47 .308 r
.48341 .8126 m .48654 .81404 L .48496 .8153 L F
.497 .844 .574 r
.48496 .8153 m .48654 .81404 L .48802 .8127 L F
.946 .625 .393 r
.24931 .6257 m .24939 .62782 L .24792 .62689 L F
.526 .469 .736 r
.24862 .62307 m .24931 .6257 L .25074 .62285 L F
.946 .625 .393 r
.24931 .6257 m .24939 .62782 L .24792 .62689 L F
.635 .601 .798 r
.24931 .6257 m .252 .62551 L .25074 .62285 L F
.79 .64 .696 r
.24939 .62782 m .252 .62551 L .24931 .6257 L F
.665 .832 .964 r
.47004 .63915 m .46866 .64142 L .46708 .63998 L F
.47004 .63915 m .47122 .64012 L .46866 .64142 L F
.859 .671 .647 r
.58677 .68711 m .58854 .69035 L .58741 .68973 L F
.903 .779 .714 r
.58826 .69252 m .58741 .68973 L .58854 .69035 L F
.265 0 0 r
.7687 .60979 m .77201 .61106 L .77093 .61066 L F
.7687 .60979 m .77093 .61066 L .76794 .60892 L F
.679 .323 .365 r
.56744 .70425 m .56421 .70604 L .56432 .70477 L F
.56744 .70425 m .56701 .70662 L .56421 .70604 L F
.224 .07 .45 r
.56904 .70124 m .56744 .70425 L .56757 .70098 L F
.56904 .70124 m .56919 .70377 L .56744 .70425 L F
.185 0 .235 r
.56873 .70559 m .56744 .70425 L .56919 .70377 L F
.56873 .70559 m .56701 .70662 L .56744 .70425 L F
.681 .824 .952 r
.78346 .59792 m .78136 .59804 L .78122 .59648 L F
.562 .659 .902 r
.78459 .59432 m .78346 .59792 L .78122 .59648 L F
.78459 .59432 m .78638 .59734 L .78346 .59792 L F
.629 .834 .979 r
.66613 .51827 m .66743 .51951 L .6695 .51857 L F
.6695 .51857 m .66743 .51951 L .66613 .51827 L F
.618 .393 .553 r
.5906 .59189 m .59063 .59374 L .58672 .59494 L F
.629 .371 .509 r
.59225 .5921 m .59063 .59374 L .5906 .59189 L F
.317 .796 .908 r
.28624 .6508 m .28238 .65105 L .28412 .65109 L F
.982 .697 .336 r
.63268 .50815 m .63171 .50724 L .63137 .50456 L F
.996 .823 .554 r
.63268 .50815 m .63146 .50902 L .63171 .50724 L F
.673 .359 .435 r
.6351 .50752 m .63146 .50902 L .63268 .50815 L F
.572 .469 .699 r
.7072 .50026 m .7096 .49921 L .7067 .49989 L F
0 0 0 r
.44814 .64569 m .45169 .64515 L .44953 .6458 L F
.70372 .52927 m .70211 .53061 L .70354 .52946 L F
.70372 .52927 m .70107 .5321 L .70211 .53061 L F
.574 .883 .992 r
.74968 .58923 m .75178 .58876 L .75111 .58782 L F
.753 .962 .935 r
.75111 .58782 m .75178 .58876 L .75462 .58636 L F
.311 .651 .97 r
.75199 .58858 m .75299 .58906 L .75462 .58636 L F
.75247 .58893 m .75299 .58906 L .75199 .58858 L F
0 .165 .622 r
.7537 .58965 m .75315 .58943 L .75111 .58782 L F
.75315 .58943 m .75307 .5894 L .7527 .5891 L F
.75315 .58943 m .7527 .5891 L .75111 .58782 L F
.311 .651 .97 r
.75178 .58876 m .75247 .58893 L .75199 .58858 L F
.75299 .58906 m .75488 .58952 L .75482 .58879 L F
.75299 .58906 m .75482 .58879 L .75462 .58636 L F
.714 .52 .626 r
.7527 .5891 m .74968 .58923 L .75111 .58782 L F
.75307 .5894 m .7513 .58931 L .7527 .5891 L F
.7513 .58931 m .74968 .58923 L .7527 .5891 L F
.75307 .5894 m .74955 .59134 L .74968 .58923 L F
.905 .869 .792 r
.75488 .58952 m .75682 .58486 L .75462 .58636 L F
.933 .559 .251 r
.75396 .58959 m .7537 .58965 L .75507 .58824 L F
0 0 .401 r
.7537 .58965 m .75479 .59291 L .75325 .58977 L F
.069 .033 .504 r
.75479 .59291 m .75325 .59468 L .75307 .5894 L F
0 0 .258 r
.75443 .59174 m .75479 .59291 L .75462 .5924 L F
.75443 .59174 m .75462 .5924 L .7537 .58965 L F
.933 .559 .251 r
.75306 .59066 m .75421 .59113 L .7537 .58965 L F
.416 .346 .671 r
.75306 .59066 m .75425 .59114 L .75443 .59174 L F
.75425 .59114 m .75609 .59189 L .75443 .59174 L F
.933 .559 .251 r
.75306 .59066 m .7537 .58965 L .75396 .58959 L F
0 0 .401 r
.7537 .58965 m .75325 .58977 L .75307 .5894 L F
0 0 0 r
.44962 .68657 m .45093 .68633 L .45222 .68615 L F
.44962 .68657 m .44915 .68726 L .45093 .68633 L F
.762 .504 .544 r
.55374 .76408 m .55393 .76542 L .54981 .76512 L F
.876 .993 .767 r
.55458 .76517 m .55214 .76863 L .55232 .76802 L F
.714 .424 .485 r
.55284 .76619 m .54981 .76512 L .55328 .76603 L F
.876 .993 .767 r
.55357 .76592 m .55232 .76802 L .55274 .76653 L F
.55458 .76517 m .55232 .76802 L .55366 .76585 L F
.55355 .76577 m .55274 .76653 L .55284 .76619 L F
.714 .424 .485 r
.55284 .76619 m .55328 .76603 L .55405 .76623 L F
.876 .993 .767 r
.55366 .76585 m .55363 .7659 L .55357 .76592 L F
.55363 .7659 m .55232 .76802 L .55357 .76592 L F
.975 .67 .359 r
.55566 .76513 m .55458 .76517 L .5538 .76563 L F
.358 .224 .559 r
.55396 .76559 m .55566 .76513 L .55405 .76623 L F
.876 .993 .767 r
.55458 .76517 m .55274 .76653 L .55355 .76577 L F
.975 .67 .359 r
.55566 .76513 m .5538 .76563 L .55284 .76619 L F
.358 .224 .559 r
.55393 .76542 m .55566 .76513 L .55396 .76559 L F
.55374 .76408 m .5545 .7645 L .55393 .76542 L F
.5545 .7645 m .55566 .76513 L .55393 .76542 L F
.762 .504 .544 r
.55393 .76542 m .55405 .76623 L .55328 .76603 L F
.55393 .76542 m .55328 .76603 L .54981 .76512 L F
.864 .99 .832 r
.55214 .76863 m .54939 .77019 L .55284 .76619 L F
.753 .523 .583 r
.55136 .76221 m .54752 .76277 L .54752 .76032 L F
.615 .29 .396 r
.55136 .76221 m .54981 .76512 L .54694 .76523 L F
.107 0 0 r
.31115 .6013 m .30972 .60252 L .30761 .60307 L F
0 0 0 r
.31321 .60102 m .30972 .60252 L .31115 .6013 L F
.334 .809 .747 r
.33165 .60306 m .33575 .60158 L .33361 .60207 L F
.859 .972 .863 r
.66124 .49071 m .65776 .49287 L .65763 .49048 L F
.118 0 0 r
.32011 .63033 m .32156 .6303 L .32308 .62891 L F
.257 0 0 r
.32156 .6303 m .32521 .62847 L .32308 .62891 L F
.777 .82 .886 r
.25091 .65955 m .25116 .65935 L .2504 .65912 L F
.35 0 .169 r
.54097 .78524 m .54458 .78292 L .54331 .78529 L F
.898 .926 .829 r
.55599 .77599 m .55678 .77697 L .55774 .77566 L F
.619 .467 .653 r
.55678 .77697 m .55925 .77434 L .55774 .77566 L F
0 0 .41 r
.5576 .7793 m .55678 .77697 L .55694 .78098 L F
.796 .722 .783 r
.50217 .81035 m .50336 .81325 L .49991 .81318 L F
.801 .694 .747 r
.49991 .81318 m .50336 .81325 L .50115 .81645 L F
.622 .447 .624 r
.50336 .81325 m .50363 .81655 L .50115 .81645 L F
.729 .508 .591 r
.50219 .80787 m .50549 .80786 L .50294 .81057 L F
.50259 .81048 m .50294 .81057 L .50265 .81088 L F
.50219 .80787 m .50294 .81057 L .50259 .81048 L F
.164 .7 .828 r
.50549 .80786 m .50689 .80759 L .50482 .80885 L F
.666 .659 .834 r
.50239 .81052 m .50219 .81039 L .50225 .81041 L F
.50448 .8121 m .50236 .81052 L .50239 .81052 L F
.50236 .81052 m .50219 .81039 L .50239 .81052 L F
.164 .7 .828 r
.50549 .80786 m .50477 .80892 L .50385 .8096 L F
.63 .439 .606 r
.50259 .81048 m .50508 .80869 L .50219 .80787 L F
.50265 .81088 m .50321 .81038 L .50259 .81048 L F
.164 .7 .828 r
.50385 .8096 m .50409 .80959 L .50294 .81057 L F
.50409 .80959 m .50321 .81038 L .50294 .81057 L F
.63 .439 .606 r
.5027 .81083 m .50511 .8087 L .50508 .80869 L F
.666 .659 .834 r
.50448 .8121 m .50241 .81094 L .50268 .81076 L F
.63 .439 .606 r
.50265 .81088 m .5027 .81083 L .5027 .81083 L F
.5027 .81083 m .50511 .8087 L .5027 .81083 L F
.666 .659 .834 r
.50448 .8121 m .50336 .81325 L .50241 .81094 L F
.50448 .8121 m .50239 .81052 L .50471 .81283 L F
.839 .533 .47 r
.50463 .80561 m .50792 .80771 L .50549 .80786 L F
.164 .7 .828 r
.50549 .80786 m .50792 .80771 L .50689 .80759 L F
0 0 0 r
.50689 .80759 m .50511 .8087 L .5027 .81083 L F
.50271 .81083 m .5027 .81083 L .50265 .81088 L F
.50689 .80759 m .5027 .81083 L .50271 .81083 L F
.666 .659 .834 r
.50471 .81283 m .50271 .81087 L .50479 .81309 L F
.50268 .81076 m .50241 .81094 L .50219 .81039 L F
.50225 .81041 m .50219 .81039 L .50217 .81035 L F
.752 .524 .586 r
.50217 .81035 m .50265 .81088 L .50219 .80787 L F
.50217 .81035 m .50265 .81088 L .50219 .80787 L F
.666 .659 .834 r
.50271 .81087 m .50217 .81035 L .50271 .81091 L F
.625 .468 .649 r
.49991 .81318 m .50381 .81205 L .50217 .81035 L F
.54 .038 0 r
.50217 .81035 m .50381 .81205 L .50479 .81309 L F
.666 .659 .834 r
.50271 .81087 m .50271 .81091 L .50479 .81309 L F
.50239 .81052 m .50217 .81035 L .50471 .81283 L F
.164 .7 .828 r
.50477 .80892 m .50434 .80957 L .50385 .8096 L F
.63 .439 .606 r
.50321 .81038 m .50508 .80869 L .50259 .81048 L F
.164 .7 .828 r
.50409 .80959 m .50434 .80957 L .50321 .81038 L F
.72 .714 .844 r
.50463 .80561 m .50549 .80786 L .50219 .80787 L F
.601 .504 .716 r
.50219 .80787 m .50508 .80869 L .50463 .80561 L F
.50508 .80869 m .50511 .8087 L .50511 .80867 L F
.50508 .80869 m .50511 .80867 L .50463 .80561 L F
.494 .428 .711 r
.50463 .80561 m .50511 .80867 L .50689 .80759 L F
.50511 .80867 m .50511 .8087 L .50689 .80759 L F
.164 .7 .828 r
.50482 .80885 m .50689 .80759 L .50434 .80957 L F
.50294 .81057 m .50434 .80957 L .50265 .81088 L F
.584 .036 0 r
.50336 .81325 m .50688 .81611 L .50363 .81655 L F
.629 .398 .549 r
.598 .58923 m .60035 .59136 L .59795 .59149 L F
.677 .385 .471 r
.60022 .5894 m .60035 .59136 L .598 .58923 L F
.123 .629 .901 r
.28823 .58371 m .29242 .58462 L .28991 .58467 L F
.497 .476 .764 r
.33912 .60815 m .34104 .60792 L .33839 .60634 L F
.452 .419 .73 r
.33912 .60815 m .34168 .61106 L .34104 .60792 L F
.66 .137 0 r
.47387 .77674 m .47799 .778 L .47522 .77766 L F
.509 .189 .36 r
.51195 .77396 m .51429 .77365 L .51536 .77136 L F
.937 .572 .287 r
.51536 .77136 m .51523 .77182 L .51394 .76891 L F
0 0 0 r
.51536 .77136 m .51429 .77365 L .51523 .77182 L F
.637 .781 .95 r
.37937 .70371 m .37635 .70262 L .37852 .7009 L F
.291 .282 .676 r
.38077 .70051 m .38038 .70294 L .37937 .70371 L F
0 0 0 r
.38102 .70336 m .37937 .70371 L .38038 .70294 L F
.38102 .70336 m .37833 .70462 L .37937 .70371 L F
.598 .56 .783 r
.4868 .65658 m .48832 .65367 L .48609 .65407 L F
.4868 .65658 m .48967 .65695 L .48832 .65367 L F
.806 .954 .618 r
.60319 .54715 m .60189 .54831 L .60117 .55021 L F
.808 .955 .618 r
.60403 .5451 m .60189 .54831 L .60319 .54715 L F
.713 .593 .72 r
.54978 .75748 m .54752 .76032 L .54645 .75753 L F
.589 .936 .763 r
.78125 .58389 m .77977 .58455 L .78044 .58568 L F
.422 .173 .429 r
.2491 .59774 m .2486 .59985 L .25108 .59717 L F
.805 .737 .788 r
.54988 .7826 m .55294 .78311 L .55159 .78028 L F
.816 .71 .748 r
.54982 .78602 m .55294 .78311 L .54988 .7826 L F
.527 .509 .779 r
.55294 .78311 m .55353 .77899 L .55159 .78028 L F
.55294 .78311 m .55598 .78348 L .55353 .77899 L F
.225 .457 .873 r
.65027 .48595 m .65071 .48743 L .64784 .48599 L F
.837 .778 .795 r
.24478 .63157 m .24497 .63132 L .2444 .63114 L F
.506 .311 .55 r
.24497 .63132 m .24668 .63326 L .24478 .63157 L F
.24497 .63132 m .24668 .63326 L .24478 .63157 L F
.526 .469 .736 r
.24862 .62307 m .25074 .62285 L .25005 .62201 L F
.72 .704 .834 r
.49557 .65873 m .49912 .6593 L .49789 .65619 L F
.761 .724 .819 r
.49789 .65619 m .49912 .6593 L .50117 .65644 L F
.608 .505 .711 r
.50117 .65644 m .49912 .6593 L .50154 .65888 L F
.707 .552 .675 r
.49912 .6593 m .50251 .66204 L .50154 .65888 L F
.49912 .6593 m .50021 .66216 L .50251 .66204 L F
.975 .704 .454 r
.51071 .67331 m .51323 .67103 L .51311 .67227 L F
.618 .518 .718 r
.51512 .66761 m .51637 .67095 L .51323 .67103 L F
.777 .665 .74 r
.51637 .67095 m .51311 .67227 L .51323 .67103 L F
.708 .478 .574 r
.57233 .58918 m .56809 .59144 L .56807 .589 L F
.57233 .58918 m .57248 .59151 L .56809 .59144 L F
.8 .678 .73 r
.25166 .63946 m .25542 .63958 L .25417 .63583 L F
0 0 0 r
.25542 .63958 m .25347 .64263 L .2543 .64176 L F
.798 .692 .748 r
.25166 .63946 m .25347 .64263 L .25542 .63958 L F
0 0 .423 r
.25417 .63583 m .25542 .63958 L .2554 .63839 L F
0 0 0 r
.25542 .63958 m .25572 .63959 L .2554 .63839 L F
.25542 .63958 m .2543 .64176 L .25572 .63959 L F
.051 0 0 r
.44019 .6479 m .44346 .64735 L .44117 .64779 L F
.889 .812 .766 r
.58267 .72099 m .57931 .72303 L .58114 .72018 L F
.661 .497 .652 r
.58364 .72337 m .58284 .72361 L .58267 .72099 L F
0 0 0 r
.63447 .52048 m .63259 .52185 L .63507 .51886 L F
.246 .116 .498 r
.63447 .52048 m .63217 .52364 L .63259 .52185 L F
.9 .745 .679 r
.7096 .49921 m .70955 .50114 L .71113 .50048 L F
.895 .603 .485 r
.55599 .77599 m .55774 .77566 L .55709 .77544 L F
.717 .635 .765 r
.55774 .77566 m .55688 .77392 L .55709 .77544 L F
.55774 .77566 m .55925 .77434 L .55688 .77392 L F
0 0 0 r
.40191 .71467 m .40582 .7133 L .40408 .71263 L F
.316 .767 .956 r
.40582 .7133 m .40642 .71248 L .40408 .71263 L F
.40582 .7133 m .40832 .7131 L .40642 .71248 L F
.816 .796 .834 r
.2504 .65912 m .25116 .65935 L .25346 .65716 L F
.583 .007 0 r
.51309 .76753 m .50889 .76556 L .5103 .76658 L F
.554 .356 .566 r
.38748 .65646 m .38974 .65612 L .38983 .65374 L F
0 .068 .617 r
.51394 .76891 m .51553 .76987 L .51309 .76753 L F
.51394 .76891 m .51523 .77182 L .51553 .76987 L F
.703 .903 .967 r
.48047 .75931 m .47948 .75938 L .48251 .75801 L F
.04 .284 .777 r
.71503 .49725 m .71683 .49758 L .71722 .49558 L F
.71503 .49725 m .71699 .49895 L .71683 .49758 L F
.5 .665 .936 r
.36684 .59642 m .36601 .59825 L .36482 .59653 L F
.36684 .59642 m .36803 .59799 L .36601 .59825 L F
0 0 .042 r
.51254 .68564 m .51077 .68701 L .51229 .68543 L F
.724 .617 .737 r
.52297 .79628 m .52393 .79956 L .52031 .79918 L F
.65 .218 .208 r
.52031 .79918 m .52393 .79956 L .52202 .80081 L F
0 .03 .587 r
.5242 .79723 m .52393 .79956 L .52297 .79628 L F
.89 .99 .768 r
.52202 .80081 m .52393 .79956 L .5242 .79723 L F
.911 .979 .713 r
.70457 .5254 m .7042 .52761 L .7061 .5244 L F
.813 .638 .665 r
.25078 .63144 m .24668 .63326 L .24932 .63103 L F
.25078 .63144 m .24893 .6344 L .24668 .63326 L F
.801 .517 .508 r
.63378 .50373 m .63713 .50447 L .63708 .50245 L F
.538 .413 .658 r
.37888 .67061 m .38104 .67013 L .38073 .66749 L F
.526 .347 .581 r
.37883 .67262 m .38104 .67013 L .37888 .67061 L F
.427 .375 .698 r
.24331 .61169 m .24444 .60804 L .24285 .60881 L F
.24331 .61169 m .24489 .61128 L .24444 .60804 L F
.512 .462 .737 r
.24376 .61402 m .24489 .61128 L .24331 .61169 L F
.375 .54 .891 r
.75659 .59765 m .76001 .59911 L .75804 .60024 L F
.396 .59 .922 r
.76001 .59911 m .76005 .60034 L .75804 .60024 L F
.734 .38 .381 r
.4867 .69038 m .48806 .69224 L .48809 .69061 L F
.707 .542 .662 r
.56802 .5867 m .56807 .589 L .56716 .58901 L F
.529 .358 .594 r
.34373 .74026 m .34385 .74293 L .34161 .74066 L F
.34373 .74026 m .34385 .74293 L .34161 .74066 L F
.868 .713 .687 r
.70172 .51377 m .70159 .51629 L .70035 .51288 L F
.757 .551 .617 r
.63008 .54088 m .62737 .53865 L .63112 .53896 L F
.541 .118 .187 r
.46007 .6861 m .46243 .68628 L .4637 .68445 L F
.543 .193 .323 r
.46243 .68628 m .4658 .68392 L .4637 .68445 L F
.157 0 0 r
.57403 .69265 m .57658 .6932 L .5729 .69241 L F
.932 .705 .573 r
.57403 .69265 m .5729 .69241 L .57335 .69028 L F
.739 .854 .419 r
.60117 .55021 m .60189 .54831 L .60024 .55171 L F
.795 .872 .436 r
.60117 .55021 m .60024 .55171 L .60028 .55206 L F
.436 .384 .702 r
.33839 .60634 m .34032 .60595 L .33968 .6023 L F
.453 .482 .799 r
.33839 .60634 m .34104 .60792 L .34032 .60595 L F
.459 .252 .51 r
.25133 .59485 m .25108 .59717 L .2533 .59432 L F
.405 .754 .994 r
.30556 .58558 m .305 .58669 L .30351 .5858 L F
.30556 .58558 m .30709 .58654 L .305 .58669 L F
.628 .404 .558 r
.61177 .58641 m .61181 .58858 L .60967 .58828 L F
.622 .394 .551 r
.61416 .58621 m .61181 .58858 L .61177 .58641 L F
.911 .979 .713 r
.70457 .5254 m .7061 .5244 L .70523 .52359 L F
.788 .971 .915 r
.7061 .5244 m .70822 .5216 L .70523 .52359 L F
.7061 .5244 m .70895 .52228 L .70822 .5216 L F
.015 .586 .762 r
.76823 .60239 m .7674 .60244 L .76671 .60072 L F
.76823 .60239 m .76963 .60253 L .7674 .60244 L F
.05 .582 .86 r
.34477 .59128 m .34415 .5915 L .34265 .59136 L F
.34477 .59128 m .34623 .59183 L .34415 .5915 L F
.72 .194 0 r
.58852 .70667 m .58512 .70465 L .58702 .70363 L F
.58852 .70667 m .58698 .70671 L .58512 .70465 L F
.645 .259 0 r
.58821 .70899 m .58698 .70671 L .58852 .70667 L F
.503 .688 .95 r
.58932 .70491 m .58852 .70667 L .58702 .70363 L F
.58932 .70491 m .59047 .70626 L .58852 .70667 L F
.658 .663 .843 r
.66577 .48214 m .66783 .48229 L .66659 .47901 L F
.568 .795 .985 r
.63373 .49993 m .63597 .49941 L .63452 .49806 L F
.297 .374 .773 r
.66318 .48108 m .66209 .48287 L .66102 .48169 L F
.66318 .48108 m .66449 .48433 L .66209 .48287 L F
.798 .672 .725 r
.56234 .58902 m .55884 .58858 L .56049 .58569 L F
.778 .586 .64 r
.56234 .58902 m .5583 .5911 L .55884 .58858 L F
.56234 .58902 m .5612 .59141 L .5583 .5911 L F
.852 .682 .67 r
.56234 .58902 m .5627 .59272 L .5612 .59141 L F
.625 .515 .709 r
.56664 .59146 m .56234 .58902 L .56716 .58901 L F
.56664 .59146 m .5627 .59272 L .56234 .58902 L F
.607 .556 .772 r
.78794 .6056 m .78564 .60644 L .78469 .60279 L F
.638 .806 .963 r
.78459 .60519 m .78564 .60644 L .78794 .6056 L F
.784 .935 .577 r
.55367 .79577 m .55515 .79413 L .55559 .79272 L F
.728 .605 .719 r
.54499 .74914 m .5416 .74673 L .54428 .74539 L F
.476 .319 .588 r
.54638 .74314 m .54662 .74553 L .54428 .74539 L F
.639 .611 .805 r
.54662 .74553 m .54499 .74914 L .54428 .74539 L F
.638 .758 .935 r
.76464 .58029 m .76579 .5818 L .76781 .58097 L F
.298 .69 .976 r
.31486 .58769 m .31429 .58855 L .31281 .58777 L F
.31486 .58769 m .31635 .58867 L .31429 .58855 L F
.793 .88 .91 r
.55481 .71416 m .55123 .71492 L .55359 .71202 L F
.813 .752 .795 r
.55556 .71323 m .55481 .71416 L .55359 .71202 L F
.399 .083 .309 r
.38696 .65825 m .38974 .65612 L .38748 .65646 L F
.668 .403 .51 r
.60396 .58896 m .60035 .59136 L .60022 .5894 L F
.792 .68 .741 r
.70035 .51288 m .70159 .51629 L .69788 .51655 L F
.919 .888 .786 r
.70159 .51629 m .69847 .51882 L .69788 .51655 L F
.70159 .51629 m .6996 .51982 L .69847 .51882 L F
.72 .409 .451 r
.52874 .78307 m .53164 .78284 L .53176 .78472 L F
.706 .267 .204 r
.53164 .78284 m .53547 .78446 L .53176 .78472 L F
.829 .711 .734 r
.59507 .70192 m .59574 .70416 L .5927 .70356 L F
.813 .746 .79 r
.5927 .70356 m .59574 .70416 L .59284 .70626 L F
.342 .566 .921 r
.29864 .63192 m .29787 .63321 L .29563 .63112 L F
.29864 .63192 m .29967 .63346 L .29787 .63321 L F
.664 .111 0 r
.58082 .7248 m .57934 .72472 L .57931 .72303 L F
.688 .195 .071 r
.58406 .72625 m .58276 .72654 L .58082 .7248 L F
0 .319 .808 r
.50877 .75919 m .51186 .76247 L .51074 .7604 L F
.864 .992 .827 r
.73215 .50976 m .73213 .51083 L .7348 .50786 L F
0 0 .313 r
.73215 .50976 m .73265 .51301 L .73213 .51083 L F
.909 .549 .342 r
.5627 .59272 m .5621 .59357 L .5612 .59141 L F
.718 .542 .651 r
.56664 .59146 m .5621 .59357 L .5627 .59272 L F
.479 .301 .561 r
.28221 .61717 m .28217 .61972 L .28016 .62012 L F
.51 .412 .68 r
.28217 .61972 m .28261 .62196 L .28016 .62012 L F
.505 .412 .684 r
.28261 .62196 m .28061 .62255 L .28016 .62012 L F
.448 .002 .094 r
.40318 .65499 m .40142 .65406 L .40005 .65573 L F
.728 .605 .719 r
.54499 .74914 m .5421 .74963 L .5416 .74673 L F
.532 .117 .2 r
.54499 .74914 m .54152 .75081 L .5421 .74963 L F
.54499 .74914 m .54397 .75105 L .54152 .75081 L F
.775 .715 .797 r
.54454 .74834 m .54678 .74864 L .54512 .74778 L F
.008 0 0 r
.54678 .74864 m .54499 .74914 L .54911 .74895 L F
.54678 .74864 m .54397 .75105 L .54499 .74914 L F
.775 .715 .797 r
.5421 .75067 m .54678 .74864 L .54454 .74834 L F
.008 0 0 r
.54678 .74864 m .54911 .74895 L .55007 .74891 L F
.437 .155 .386 r
.24667 .60044 m .24802 .60202 L .2486 .59985 L F
.24667 .60044 m .24601 .60259 L .24802 .60202 L F
.299 0 0 r
.4151 .65093 m .41726 .65072 L .4187 .64993 L F
.565 .114 .141 r
.4187 .64993 m .41726 .65072 L .4207 .65039 L F
.393 .402 .75 r
.38696 .70747 m .3882 .71102 L .38921 .70911 L F
.521 .499 .773 r
.3882 .71102 m .39137 .71232 L .38921 .70911 L F
.3882 .71102 m .39036 .71447 L .39137 .71232 L F
.816 .796 .834 r
.2504 .65912 m .25346 .65716 L .2516 .65592 L F
.773 .831 .897 r
.2516 .65592 m .25346 .65716 L .25419 .65594 L F
.833 .81 .828 r
.6996 .51982 m .69576 .52094 L .69847 .51882 L F
.6996 .51982 m .69736 .52203 L .69576 .52094 L F
.56 .002 0 r
.62801 .50161 m .63032 .50258 L .63132 .50226 L F
.04 .355 .829 r
.63271 .5022 m .63132 .50226 L .63032 .50258 L F
.63271 .5022 m .63378 .50373 L .63132 .50226 L F
0 0 .066 r
.47537 .77294 m .47491 .77205 L .47536 .7705 L F
.47537 .77294 m .47392 .77412 L .47491 .77205 L F
.728 .243 .089 r
.54832 .73087 m .5493 .72979 L .546 .72872 L F
.782 .314 .13 r
.54832 .73087 m .55128 .73207 L .5493 .72979 L F
.772 .333 .208 r
.5493 .72979 m .55128 .73207 L .55301 .73201 L F
0 0 0 r
.64145 .55167 m .63839 .55414 L .63925 .55492 L F
.64145 .55167 m .64098 .55217 L .63839 .55414 L F
.974 .716 .299 r
.64099 .54923 m .64098 .55217 L .64145 .55167 L F
.365 .149 .447 r
.49695 .69348 m .49907 .69462 L .501 .69245 L F
.214 .71 .918 r
.49907 .69462 m .503 .69511 L .501 .69245 L F
.442 .857 .958 r
.77093 .61066 m .77201 .61106 L .774 .61052 L F
.7 .762 .9 r
.66504 .52706 m .66573 .52993 L .66846 .52782 L F
.326 .111 .426 r
.57524 .68729 m .57335 .69028 L .57506 .68956 L F
.535 .28 .476 r
.57524 .68729 m .57506 .68956 L .57815 .68888 L F
.683 .719 .876 r
.70582 .4804 m .70229 .47984 L .70456 .479 L F
.726 .731 .854 r
.70798 .47953 m .70582 .4804 L .70456 .479 L F
.711 .19 0 r
.5128 .79019 m .51314 .78881 L .51458 .78803 L F
.273 0 .109 r
.62762 .48536 m .62912 .48638 L .62989 .48468 L F
.62762 .48536 m .62689 .4871 L .62912 .48638 L F
.112 0 .011 r
.61664 .55997 m .61948 .55774 L .61753 .55871 L F
.285 0 0 r
.26937 .58653 m .2715 .58623 L .27269 .5853 L F
.399 0 .003 r
.2715 .58623 m .27481 .5853 L .27269 .5853 L F
.629 .371 .509 r
.59225 .5921 m .59237 .59415 L .59063 .59374 L F
.607 .334 .477 r
.59463 .5921 m .59237 .59415 L .59225 .5921 L F
.38 .543 .891 r
.7731 .5829 m .77411 .58386 L .77408 .58264 L F
0 .025 .589 r
.77411 .58386 m .77497 .58587 L .77408 .58264 L F
.231 0 .237 r
.349 .62826 m .35143 .6256 L .35119 .6278 L F
.215 0 .338 r
.35143 .6256 m .35343 .62272 L .35337 .62503 L F
.417 .201 .475 r
.35119 .6278 m .35143 .6256 L .35337 .62503 L F
.21 0 .018 r
.43099 .66557 m .42991 .66444 L .43247 .66371 L F
.43099 .66557 m .42869 .66639 L .42991 .66444 L F
.999 .839 .514 r
.59739 .70738 m .59704 .71259 L .59765 .71325 L F
.719 .273 0 r
.59704 .71259 m .59893 .71527 L .59765 .71325 L F
.866 .449 .004 r
.63507 .51886 m .63358 .51688 L .63436 .51799 L F
0 0 0 r
.63447 .52048 m .63507 .51886 L .63436 .51799 L F
.457 0 .061 r
.44109 .70184 m .43972 .70338 L .43739 .70331 L F
.281 0 0 r
.44344 .70172 m .43972 .70338 L .44109 .70184 L F
.53 .621 .887 r
.50067 .63421 m .50049 .63717 L .4984 .63436 L F
.50067 .63421 m .50207 .63642 L .50049 .63717 L F
.976 .716 .306 r
.55713 .78219 m .55791 .78342 L .55746 .78367 L F
.547 0 0 r
.55746 .78367 m .55791 .78342 L .56044 .78479 L F
.976 .716 .306 r
.55713 .78219 m .55791 .78342 L .55746 .78367 L F
.749 .719 .825 r
.67715 .53712 m .67433 .5387 L .6737 .53584 L F
.452 .723 .983 r
.67433 .5387 m .6756 .53739 L .6737 .53584 L F
.67433 .5387 m .67678 .53865 L .6756 .53739 L F
.809 .747 .795 r
.47718 .65605 m .47839 .65909 L .48062 .65645 L F
.366 .023 .245 r
.53016 .76267 m .5324 .76212 L .53289 .76065 L F
.514 .177 .333 r
.5324 .76212 m .53523 .76039 L .53289 .76065 L F
.547 .376 .601 r
.4879 .76867 m .48804 .77125 L .49015 .76833 L F
.939 .676 .512 r
.59321 .56938 m .59328 .57167 L .59466 .57231 L F
.867 .588 .514 r
.59313 .57409 m .59466 .57231 L .59328 .57167 L F
.59313 .57409 m .59463 .57465 L .59466 .57231 L F
.607 .181 .207 r
.52484 .78449 m .526 .78278 L .52839 .78438 L F
.593 .205 .276 r
.526 .78278 m .52874 .78307 L .52839 .78438 L F
.382 0 .157 r
.44402 .6896 m .44619 .68922 L .4471 .68793 L F
.243 0 .071 r
.4471 .68793 m .44619 .68922 L .44915 .68726 L F
.611 .952 .911 r
.25248 .64474 m .2543 .64176 L .25347 .64263 L F
0 0 .281 r
.4847 .79662 m .48359 .79956 L .48468 .79848 L F
.61 .955 .846 r
.48468 .79848 m .48359 .79956 L .481 .80034 L F
0 0 .495 r
.73155 .49562 m .73269 .49899 L .73175 .497 L F
.317 .014 .283 r
.35614 .6202 m .35545 .62213 L .35343 .62272 L F
.419 .108 .329 r
.35756 .62163 m .35614 .6202 L .35823 .61964 L F
.35756 .62163 m .35545 .62213 L .35614 .6202 L F
.94 .823 .702 r
.6421 .54324 m .64297 .54594 L .64335 .54427 L F
.944 .76 .623 r
.63845 .52185 m .63707 .52211 L .63724 .52077 L F
.63845 .52185 m .6385 .52421 L .63707 .52211 L F
.145 0 .333 r
.78638 .59734 m .7862 .59926 L .7838 .60079 L F
.072 0 .207 r
.7838 .60079 m .78533 .60069 L .78469 .60279 L F
.7838 .60079 m .7862 .59926 L .78533 .60069 L F
.399 .585 .917 r
.3633 .59435 m .36255 .59605 L .36114 .59447 L F
.3633 .59435 m .36482 .59653 L .36255 .59605 L F
0 0 0 r
.60973 .56626 m .6115 .5653 L .61263 .56393 L F
.61263 .56393 m .61416 .56297 L .61492 .56112 L F
.61263 .56393 m .6115 .5653 L .61416 .56297 L F
.63587 .49659 m .63644 .49627 L .63723 .49632 L F
.587 .378 .564 r
.63723 .49632 m .63859 .49925 L .63597 .49941 L F
.376 .536 .887 r
.63723 .49632 m .63938 .49441 L .63623 .49303 L F
.558 .928 .788 r
.63723 .49632 m .63644 .49627 L .63938 .49441 L F
0 .303 .739 r
.25021 .65368 m .25001 .65333 L .24817 .65224 L F
.472 .173 .377 r
.24795 .65518 m .25001 .65333 L .25021 .65368 L F
.542 .473 .728 r
.24419 .6173 m .24414 .61954 L .24618 .61718 L F
.859 .871 .846 r
.69736 .52203 m .69376 .52384 L .69576 .52094 L F
.547 .719 .953 r
.69777 .47795 m .6965 .47979 L .69548 .47845 L F
.69777 .47795 m .69893 .47943 L .6965 .47979 L F
.944 .719 .249 r
.58821 .70899 m .58758 .71087 L .58777 .70822 L F
0 0 0 r
.58777 .70822 m .58758 .71087 L .5878 .70832 L F
.58777 .70822 m .5878 .70832 L .5879 .70721 L F
.645 .259 0 r
.58773 .70811 m .58777 .70822 L .58698 .70671 L F
.58821 .70899 m .58777 .70822 L .58773 .70811 L F
.944 .719 .249 r
.58821 .70899 m .5882 .71259 L .58758 .71087 L F
.916 .642 .506 r
.58965 .71247 m .5882 .71259 L .58821 .70899 L F
.826 .924 .9 r
.62833 .51825 m .62602 .5192 L .62649 .51736 L F
.779 .674 .748 r
.49544 .80473 m .49646 .80792 L .49312 .80728 L F
.778 .434 .404 r
.49312 .80728 m .49646 .80792 L .49417 .81126 L F
.004 .167 .682 r
.49724 .80683 m .49646 .80792 L .49544 .80473 L F
0 0 0 r
.49417 .81126 m .49646 .80792 L .49724 .80683 L F
.55158 .79663 m .55191 .79644 L .55367 .79577 L F
.821 .713 .746 r
.47935 .65306 m .47718 .65605 L .48062 .65645 L F
.729 .669 .791 r
.47935 .65306 m .48062 .65645 L .48281 .6535 L F
.946 .934 .753 r
.59413 .56546 m .59321 .56938 L .59525 .56641 L F
.926 .959 .781 r
.59601 .56447 m .59413 .56546 L .59525 .56641 L F
.487 .535 .832 r
.74482 .59779 m .74621 .60064 L .74808 .59891 L F
.481 .525 .826 r
.74621 .60064 m .74912 .60211 L .74808 .59891 L F
.494 .488 .779 r
.38882 .70134 m .39078 .70105 L .38759 .69917 L F
.321 .356 .742 r
.38882 .70134 m .39045 .70355 L .39078 .70105 L F
.544 .46 .71 r
.38423 .69608 m .38576 .69233 L .38334 .69281 L F
.38423 .69608 m .38642 .69576 L .38576 .69233 L F
.621 .575 .781 r
.61359 .54384 m .61471 .54683 L .61712 .54629 L F
.459 .506 .82 r
.38642 .69576 m .38759 .69917 L .38921 .69748 L F
.451 .493 .811 r
.38759 .69917 m .39078 .70105 L .38921 .69748 L F
.485 .309 .566 r
.5729 .69241 m .57506 .68956 L .57335 .69028 L F
.497 .465 .752 r
.51749 .6552 m .51535 .65736 L .51487 .65354 L F
.64 .461 .626 r
.51765 .65876 m .51535 .65736 L .51749 .6552 L F
.51765 .65876 m .51624 .65901 L .51535 .65736 L F
.454 .222 .471 r
.28464 .61428 m .28438 .61674 L .28221 .61717 L F
.504 .264 .483 r
.28646 .61607 m .28464 .61428 L .28668 .61347 L F
.28646 .61607 m .28438 .61674 L .28464 .61428 L F
0 0 0 r
.53297 .8036 m .53308 .80241 L .53167 .80558 L F
.468 .005 .07 r
.5341 .80439 m .53308 .80241 L .53297 .8036 L F
.5341 .80439 m .53577 .80254 L .53308 .80241 L F
.254 0 0 r
.42187 .70762 m .42111 .70844 L .41909 .70888 L F
.24 0 0 r
.42341 .70782 m .42187 .70762 L .42464 .70655 L F
.42341 .70782 m .42111 .70844 L .42187 .70762 L F
.491 .272 .508 r
.50761 .69853 m .50972 .69867 L .51024 .69592 L F
.058 .247 .742 r
.50103 .79556 m .50026 .79657 L .49883 .79335 L F
.052 .238 .735 r
.50103 .79556 m .50218 .7985 L .50026 .79657 L F
.23 0 0 r
.3167 .60028 m .31503 .60119 L .31321 .60102 L F
.159 0 0 r
.31881 .60008 m .31503 .60119 L .3167 .60028 L F
.772 .681 .763 r
.49991 .81318 m .50115 .81645 L .4977 .81631 L F
.06 0 0 r
.4977 .81631 m .50115 .81645 L .49986 .81643 L F
.42 0 0 r
.49986 .81643 m .50115 .81645 L .50323 .81734 L F
.512 .067 .129 r
.50115 .81645 m .50363 .81655 L .50323 .81734 L F
.557 .216 .346 r
.57994 .68659 m .58345 .68432 L .5794 .68478 L F
0 0 .101 r
.60946 .51044 m .60779 .51353 L .60926 .51213 L F
.144 .015 .434 r
.60739 .51567 m .60926 .51213 L .60779 .51353 L F
.147 0 0 r
.54201 .75662 m .54274 .75605 L .54072 .75639 L F
.545 .28 .464 r
.53938 .75902 m .54201 .75662 L .54072 .75639 L F
.451 .218 .468 r
.51812 .69303 m .51784 .6952 L .51574 .69572 L F
.52 .392 .646 r
.51992 .68992 m .52025 .69253 L .51812 .69303 L F
.463 .228 .472 r
.52025 .69253 m .51784 .6952 L .51812 .69303 L F
.513 .472 .749 r
.40867 .6778 m .40662 .67923 L .40604 .67603 L F
.558 .489 .734 r
.40867 .6778 m .40726 .68165 L .40662 .67923 L F
.637 .367 .492 r
.52567 .76476 m .52985 .76251 L .52453 .7631 L F
.793 .817 .871 r
.47795 .6848 m .4752 .68686 L .47697 .68718 L F
.755 .371 .325 r
.47568 .68857 m .47697 .68718 L .4752 .68686 L F
.47568 .68857 m .47888 .68918 L .47697 .68718 L F
.94 .823 .702 r
.6421 .54324 m .64067 .54667 L .64297 .54594 L F
.936 .771 .652 r
.64297 .54594 m .6403 .5486 L .64099 .54923 L F
.64297 .54594 m .64067 .54667 L .6403 .5486 L F
.914 .757 .672 r
.65991 .52141 m .65822 .52093 L .65886 .51883 L F
.897 .51 .286 r
.65991 .52141 m .65881 .52264 L .65822 .52093 L F
.781 .709 .784 r
.4912 .66074 m .49288 .66185 L .49235 .65876 L F
.752 .716 .818 r
.4912 .66074 m .49046 .66277 L .49288 .66185 L F
.761 .696 .79 r
.49235 .65876 m .49288 .66185 L .49557 .65873 L F
.064 0 0 r
.32685 .64577 m .32643 .64511 L .32841 .64435 L F
.32685 .64577 m .32478 .64639 L .32643 .64511 L F
.495 .795 .998 r
.66783 .48229 m .66807 .48129 L .66659 .47901 L F
.66783 .48229 m .67019 .48191 L .66807 .48129 L F
.801 .978 .902 r
.6541 .50683 m .65142 .51035 L .65501 .50774 L F
.6541 .50683 m .65142 .51035 L .65501 .50774 L F
.962 .941 .65 r
.58351 .70585 m .58439 .70408 L .58512 .70465 L F
.948 .958 .689 r
.58512 .70465 m .58512 .70252 L .58702 .70363 L F
.58512 .70465 m .58439 .70408 L .58512 .70252 L F
.696 .235 .153 r
.58512 .70465 m .58698 .70671 L .58351 .70585 L F
0 .482 .748 r
.49816 .76777 m .50132 .76854 L .50116 .76855 L F
.03 0 .001 r
.61492 .56112 m .61597 .56179 L .61664 .55997 L F
.61492 .56112 m .61416 .56297 L .61597 .56179 L F
.812 .873 .892 r
.6385 .52421 m .63651 .52339 L .63707 .52211 L F
.6385 .52421 m .6369 .52499 L .63651 .52339 L F
.628 .915 .98 r
.52712 .77613 m .52481 .77721 L .52584 .77572 L F
.137 0 0 r
.57658 .6932 m .57196 .6947 L .5729 .69241 L F
.57658 .6932 m .57509 .69436 L .57196 .6947 L F
0 0 0 r
.57717 .69367 m .57658 .6932 L .57878 .69259 L F
.57717 .69367 m .57509 .69436 L .57658 .6932 L F
.762 .723 .816 r
.77769 .6093 m .77978 .60822 L .77882 .60526 L F
.69 .707 .861 r
.77978 .60822 m .77879 .60503 L .77882 .60526 L F
.327 .089 .392 r
.78109 .60242 m .77917 .60333 L .77882 .60526 L F
.702 .701 .847 r
.77906 .60503 m .78249 .60636 L .78459 .60519 L F
0 0 0 r
.78109 .60242 m .77882 .60526 L .77906 .60503 L F
.702 .701 .847 r
.77906 .60503 m .78459 .60519 L .77914 .60496 L F
0 0 0 r
.77907 .60503 m .77906 .60503 L .77907 .60503 L F
.77908 .60502 m .77906 .60503 L .77907 .60503 L F
.702 .701 .847 r
.77914 .60496 m .78459 .60519 L .78343 .60409 L F
.77879 .60503 m .77906 .60503 L .77914 .60496 L F
0 0 0 r
.78109 .60242 m .77906 .60503 L .77908 .60502 L F
.78109 .60242 m .77908 .60501 L .78067 .60319 L F
.77908 .60501 m .7791 .605 L .78067 .60319 L F
.542 .846 .999 r
.77879 .60503 m .77914 .60496 L .7803 .60387 L F
.77914 .60496 m .78343 .60409 L .7803 .60387 L F
0 0 0 r
.77908 .60501 m .77907 .60503 L .7791 .605 L F
.531 .815 .998 r
.77882 .60526 m .77879 .60503 L .7803 .60387 L F
.702 .701 .847 r
.77879 .60503 m .779 .6051 L .77906 .60503 L F
.779 .6051 m .78249 .60636 L .77906 .60503 L F
0 0 0 r
.78067 .60319 m .77907 .60503 L .7803 .60387 L F
.69 .707 .861 r
.77978 .60822 m .78249 .60636 L .779 .6051 L F
.77886 .60526 m .779 .6051 L .77879 .60503 L F
.77978 .60822 m .779 .6051 L .77886 .60526 L F
.437 .302 .599 r
.46923 .77728 m .47158 .77901 L .47352 .77655 L F
.874 .494 .319 r
.47357 .77674 m .47312 .77834 L .47348 .77674 L F
.111 0 .126 r
.47365 .77639 m .47352 .77655 L .47333 .77739 L F
.47352 .77655 m .47158 .77901 L .47312 .77834 L F
.874 .494 .319 r
.47387 .77674 m .47367 .77716 L .47357 .77674 L F
.437 .302 .599 r
.47349 .77642 m .47352 .77655 L .47365 .77639 L F
.46923 .77728 m .47352 .77655 L .47349 .77642 L F
.27 .211 .605 r
.47537 .77294 m .47387 .77674 L .47392 .77412 L F
.66 .137 0 r
.47387 .77674 m .47644 .77857 L .47799 .778 L F
.111 0 .126 r
.47365 .77639 m .47338 .77737 L .47387 .77674 L F
.874 .494 .319 r
.47367 .77716 m .47312 .77834 L .47357 .77674 L F
.111 0 .126 r
.47338 .77737 m .47312 .77834 L .4735 .77753 L F
.47338 .77737 m .4735 .77753 L .47387 .77674 L F
.27 .211 .605 r
.47537 .77294 m .47579 .7759 L .47387 .77674 L F
.331 .362 .743 r
.47579 .7759 m .47644 .77857 L .47387 .77674 L F
.94 .704 .553 r
.47387 .77674 m .47261 .77675 L .47365 .77639 L F
.829 .441 .318 r
.47365 .77639 m .47261 .77675 L .4705 .77388 L F
.539 .31 .516 r
.47276 .77649 m .47424 .77708 L .47379 .77472 L F
.47261 .77675 m .473 .77683 L .47276 .77649 L F
.874 .494 .319 r
.47348 .77674 m .47312 .77834 L .47261 .77675 L F
.539 .31 .516 r
.473 .77683 m .47424 .77708 L .47276 .77649 L F
.47424 .77708 m .47621 .77747 L .47549 .77664 L F
.47424 .77708 m .47549 .77664 L .47379 .77472 L F
.111 0 .126 r
.47338 .77737 m .47333 .77739 L .47312 .77834 L F
.47365 .77639 m .47333 .77739 L .47338 .77737 L F
.437 .302 .599 r
.46923 .77728 m .46922 .77987 L .47158 .77901 L F
.811 .855 .882 r
.55474 .78518 m .55604 .78683 L .55285 .78894 L F
.46 .41 .715 r
.55746 .78367 m .55604 .78683 L .55474 .78518 L F
.55746 .78367 m .55872 .78798 L .55604 .78683 L F
.664 .786 .939 r
.38575 .70641 m .38696 .70747 L .38871 .70656 L F
.523 .391 .643 r
.38696 .70747 m .38871 .70656 L .38575 .70641 L F
.38696 .70747 m .38921 .70911 L .38871 .70656 L F
.926 .959 .781 r
.59601 .56447 m .59605 .56224 L .59413 .56546 L F
.101 .538 .911 r
.76884 .57474 m .76712 .57437 L .76593 .57328 L F
.735 .71 .828 r
.55925 .77434 m .56011 .77074 L .55688 .77392 L F
0 0 0 r
.56044 .78479 m .56284 .78183 L .56209 .78174 L F
.604 .936 .953 r
.28063 .74884 m .28249 .74788 L .28194 .749 L F
.28063 .74884 m .28249 .74788 L .28194 .749 L F
.435 .341 .65 r
.5166 .66375 m .51512 .66761 L .51458 .6649 L F
.299 .769 .938 r
.46558 .65352 m .46434 .65315 L .46209 .65336 L F
.34 0 0 r
.46742 .65309 m .46434 .65315 L .46558 .65352 L F
.274 0 .133 r
.39036 .71447 m .39062 .71524 L .39137 .71232 L F
.39036 .71447 m .38843 .71599 L .39062 .71524 L F
.962 .827 .662 r
.72272 .4885 m .7225 .48863 L .72294 .48817 L F
.72272 .4885 m .72198 .49065 L .72092 .4895 L F
.72272 .4885 m .72092 .4895 L .7225 .48863 L F
.399 .271 .588 r
.51391 .6906 m .51588 .69089 L .51572 .68868 L F
.51391 .6906 m .51451 .69269 L .51588 .69089 L F
.921 .753 .656 r
.66571 .48994 m .66675 .49336 L .66684 .49098 L F
.581 .415 .621 r
.56552 .69624 m .568 .69751 L .56837 .69553 L F
.56552 .69624 m .56562 .69805 L .568 .69751 L F
.319 0 0 r
.48861 .75089 m .49097 .75062 L .49246 .74914 L F
.389 .121 .381 r
.49246 .74914 m .49177 .75108 L .49442 .74854 L F
.997 .844 .56 r
.49246 .74914 m .49097 .75062 L .49177 .75108 L F
.389 .121 .381 r
.49246 .74914 m .49177 .75108 L .49442 .74854 L F
.941 .573 .245 r
.62649 .51736 m .62507 .51523 L .62638 .51624 L F
.758 .961 .663 r
.78055 .59888 m .77987 .59925 L .78136 .59804 L F
.958 .947 .666 r
.78136 .59804 m .77987 .59925 L .78122 .59648 L F
.813 .981 .698 r
.65341 .48536 m .6535 .48471 L .65524 .48234 L F
.709 .35 .366 r
.53569 .77906 m .53612 .77741 L .53293 .77732 L F
.459 .113 .291 r
.53768 .77946 m .53612 .77741 L .53569 .77906 L F
.694 .412 .492 r
.49749 .79948 m .49722 .80168 L .4939 .80161 L F
.625 .062 0 r
.48441 .68983 m .48806 .69224 L .4867 .69038 L F
.635 .609 .807 r
.48265 .8107 m .4837 .80738 L .48144 .81022 L F
.48265 .8107 m .48511 .81095 L .4837 .80738 L F
.512 .462 .737 r
.24376 .61402 m .24577 .61341 L .24489 .61128 L F
.541 .458 .711 r
.24419 .6173 m .24577 .61341 L .24376 .61402 L F
.802 .898 .911 r
.64364 .52084 m .64417 .52219 L .64668 .51988 L F
.796 .542 .554 r
.64364 .52084 m .64662 .52353 L .64417 .52219 L F
.668 .403 .51 r
.60396 .58896 m .60402 .59107 L .60035 .59136 L F
.645 .402 .536 r
.60606 .58892 m .60402 .59107 L .60396 .58896 L F
.157 0 .331 r
.47036 .78769 m .46911 .78842 L .46855 .79065 L F
0 0 0 r
.5252 .81086 m .52776 .80789 L .52787 .8104 L F
0 .119 .608 r
.52855 .8084 m .52776 .80789 L .52739 .80746 L F
0 0 .247 r
.52787 .8104 m .52776 .80789 L .52855 .8084 L F
.032 0 .31 r
.60946 .51044 m .61158 .50697 L .61116 .5072 L F
.124 0 0 r
.25922 .64777 m .26221 .64539 L .25997 .64624 L F
.347 .821 .883 r
.26221 .64539 m .26302 .64479 L .25997 .64624 L F
.26221 .64539 m .26425 .64485 L .26302 .64479 L F
.772 .385 .323 r
.49722 .80168 m .50095 .80227 L .49967 .80412 L F
.621 .603 .811 r
.50218 .7985 m .5036 .80151 L .50095 .80227 L F
.442 0 .015 r
.50297 .8029 m .49967 .80412 L .50095 .80227 L F
.843 .657 .65 r
.77469 .60862 m .77769 .6093 L .77662 .60582 L F
.797 .782 .839 r
.774 .61052 m .77769 .6093 L .77469 .60862 L F
.762 .723 .816 r
.77769 .6093 m .77882 .60526 L .77662 .60582 L F
.638 .923 .976 r
.53101 .80811 m .53416 .8076 L .5331 .80705 L F
.565 .862 .996 r
.68064 .47723 m .68389 .47722 L .68171 .47811 L F
.301 0 0 r
.67339 .51505 m .67185 .51424 L .67106 .51538 L F
.67339 .51505 m .67408 .51376 L .67185 .51424 L F
.081 .413 .863 r
.39964 .71347 m .40093 .71326 L .39753 .71322 L F
.39964 .71347 m .40191 .71467 L .40093 .71326 L F
.578 .622 .859 r
.69184 .48548 m .69281 .48263 L .69113 .48284 L F
.69184 .48548 m .69413 .48499 L .69281 .48263 L F
.717 .392 .427 r
.57628 .59731 m .57481 .59923 L .57288 .59722 L F
.748 .433 .45 r
.57628 .59731 m .57845 .59982 L .57481 .59923 L F
.683 .439 .546 r
.57848 .5975 m .57845 .59982 L .57628 .59731 L F
.576 .426 .64 r
.53969 .76618 m .54226 .76609 L .5418 .76279 L F
.677 .35 .414 r
.53879 .76683 m .54226 .76609 L .53969 .76618 L F
.471 .268 .522 r
.51784 .6952 m .5156 .69807 L .51574 .69572 L F
.344 .377 .752 r
.63267 .51245 m .63188 .51554 L .63059 .51289 L F
.63267 .51245 m .63358 .51688 L .63188 .51554 L F
.749 .274 .118 r
.56544 .72571 m .56138 .72362 L .56355 .72541 L F
.291 .614 .957 r
.49727 .63301 m .49638 .63399 L .49519 .63372 L F
.49727 .63301 m .4984 .63436 L .49638 .63399 L F
.682 .487 .617 r
.50015 .66466 m .50251 .66204 L .50021 .66216 L F
.50015 .66466 m .50246 .6645 L .50251 .66204 L F
.642 .577 .767 r
.50154 .65888 m .50251 .66204 L .50472 .6614 L F
.752 .633 .728 r
.50246 .6645 m .50472 .6614 L .50251 .66204 L F
.254 0 .161 r
.37068 .60844 m .37344 .60606 L .37325 .60842 L F
.509 .39 .653 r
.37514 .60286 m .37557 .60559 L .37344 .60606 L F
.411 .122 .361 r
.37344 .60606 m .37494 .60739 L .37325 .60842 L F
.37344 .60606 m .37557 .60559 L .37494 .60739 L F
.763 .628 .711 r
.5416 .74673 m .5421 .74963 L .53966 .74848 L F
.81 .436 .348 r
.5421 .74963 m .54152 .75081 L .53966 .74848 L F
.338 0 0 r
.27912 .58437 m .28303 .58405 L .28082 .5841 L F
.984 .811 .59 r
.66012 .50803 m .65846 .50923 L .6594 .50565 L F
.66012 .50803 m .65955 .51044 L .65846 .50923 L F
.905 .869 .792 r
.75488 .58952 m .75763 .5862 L .75682 .58486 L F
.542 .728 .961 r
.75682 .58486 m .75763 .5862 L .75846 .58483 L F
.954 .642 .401 r
.66527 .50334 m .6659 .5057 L .66701 .50484 L F
.801 .454 .4 r
.66763 .50557 m .66774 .50707 L .6691 .50729 L F
.66701 .50484 m .66774 .50707 L .66763 .50557 L F
.77 .628 .704 r
.66774 .50707 m .6701 .50994 L .6691 .50729 L F
.66774 .50707 m .66713 .50964 L .6701 .50994 L F
.545 .497 .753 r
.66887 .50559 m .66782 .50804 L .66774 .50707 L F
.66782 .50804 m .66713 .50964 L .66774 .50707 L F
.13 .085 .535 r
.66887 .50559 m .66774 .50707 L .66701 .50484 L F
.66887 .50559 m .66701 .50484 L .6659 .5057 L F
.527 .513 .784 r
.38296 .69029 m .38396 .68682 L .38241 .68707 L F
.38296 .69029 m .38496 .69006 L .38396 .68682 L F
.641 .484 .655 r
.38296 .69029 m .38576 .69233 L .38496 .69006 L F
.38296 .69029 m .38334 .69281 L .38576 .69233 L F
.58 .783 .976 r
.72092 .4895 m .71949 .49089 L .71898 .4896 L F
.72092 .4895 m .72198 .49065 L .71949 .49089 L F
.899 .908 .821 r
.72198 .49065 m .7189 .49244 L .71949 .49089 L F
.84 .798 .81 r
.54742 .79874 m .5488 .79835 L .54906 .79672 L F
.383 .805 .616 r
.5488 .79835 m .55158 .79663 L .54906 .79672 L F
0 0 .247 r
.61339 .49952 m .61298 .50152 L .61469 .49815 L F
.837 .676 .683 r
.66991 .49607 m .66836 .4989 L .6715 .49935 L F
.757 .551 .617 r
.63008 .54088 m .62702 .54101 L .62737 .53865 L F
.979 .692 .397 r
.51581 .79435 m .51715 .79695 L .51569 .79581 L F
.889 .469 .074 r
.51569 .79581 m .51715 .79695 L .51719 .79803 L F
.687 .644 .802 r
.51885 .79398 m .51715 .79695 L .51581 .79435 L F
.51885 .79398 m .52057 .79713 L .51715 .79695 L F
.86 .599 .543 r
.51689 .79749 m .51963 .79701 L .51569 .79581 L F
.856 .735 .729 r
.51846 .7977 m .51883 .798 L .51719 .79803 L F
.51883 .798 m .52031 .79918 L .51831 .79844 L F
.51883 .798 m .51831 .79844 L .51719 .79803 L F
.52057 .79713 m .52046 .79796 L .5198 .79787 L F
.51989 .79731 m .5198 .79787 L .51846 .7977 L F
.52057 .79713 m .5198 .79787 L .51989 .79731 L F
.724 .617 .737 r
.52297 .79628 m .52031 .79918 L .52057 .79713 L F
.74 .703 .816 r
.52145 .79328 m .52297 .79628 L .52057 .79713 L F
.52145 .79328 m .52057 .79713 L .51885 .79398 L F
.751 .705 .808 r
.5225 .79779 m .52202 .80081 L .5242 .79723 L F
.5215 .79812 m .52177 .79952 L .5225 .79779 L F
.52177 .79952 m .52202 .80081 L .5225 .79779 L F
.398 .854 .829 r
.52344 .79737 m .5242 .79723 L .52435 .79702 L F
.378 .283 .619 r
.52239 .79804 m .52242 .79797 L .52145 .79328 L F
.856 .735 .729 r
.51937 .79707 m .51719 .79803 L .51715 .79695 L F
.52057 .79713 m .51953 .79741 L .51937 .79707 L F
.51946 .79726 m .51719 .79803 L .51937 .79707 L F
.51846 .7977 m .51719 .79803 L .51946 .79726 L F
.86 .599 .543 r
.51846 .7977 m .51963 .79701 L .51689 .79749 L F
.51909 .79778 m .51946 .79726 L .51846 .7977 L F
.51946 .79726 m .51963 .79701 L .51846 .7977 L F
.856 .735 .729 r
.51953 .79741 m .51846 .7977 L .51946 .79726 L F
.465 0 0 r
.5215 .79812 m .51985 .79714 L .51956 .79748 L F
.856 .735 .729 r
.52046 .79796 m .52031 .79918 L .51846 .7977 L F
.884 .601 .503 r
.51719 .79803 m .52031 .79918 L .52043 .80189 L F
.51719 .79803 m .52043 .80189 L .51811 .79919 L F
.465 0 0 r
.52004 .79858 m .51956 .79748 L .51811 .79919 L F
.5215 .79812 m .51956 .79748 L .52004 .79858 L F
.378 .283 .619 r
.51992 .79712 m .52244 .79809 L .52011 .79602 L F
.465 0 0 r
.5215 .79812 m .52244 .79809 L .51963 .79701 L F
.507 .522 .806 r
.52414 .79292 m .52297 .79628 L .52145 .79328 L F
.52414 .79292 m .52515 .7965 L .52297 .79628 L F
0 .03 .587 r
.5242 .79723 m .52297 .79628 L .52515 .7965 L F
.417 .308 .623 r
.52145 .79328 m .52244 .79809 L .52374 .79671 L F
.378 .283 .619 r
.52011 .79602 m .52223 .79791 L .52145 .79328 L F
.52223 .79791 m .52235 .79785 L .52145 .79328 L F
.701 .753 .892 r
.52374 .79671 m .52288 .79763 L .5215 .79812 L F
.398 .854 .829 r
.5215 .79812 m .5225 .79779 L .5228 .79765 L F
.378 .283 .619 r
.52223 .79791 m .52239 .79804 L .52235 .79785 L F
.52239 .79804 m .52244 .79809 L .52242 .79797 L F
.701 .753 .892 r
.52288 .79763 m .52244 .79809 L .5215 .79812 L F
.398 .854 .829 r
.5215 .79812 m .5228 .79765 L .52344 .79737 L F
.5225 .79779 m .5242 .79723 L .52344 .79737 L F
.378 .283 .619 r
.51963 .79701 m .51992 .79712 L .52011 .79602 L F
.465 0 0 r
.51985 .79714 m .51963 .79701 L .51909 .79778 L F
.51985 .79714 m .51909 .79778 L .51811 .79919 L F
.86 .599 .543 r
.51811 .79919 m .51909 .79778 L .51689 .79749 L F
.65 .218 .208 r
.52031 .79918 m .52202 .80081 L .52043 .80189 L F
.456 .28 .552 r
.35545 .62213 m .35337 .62503 L .35343 .62272 L F
.363 .529 .886 r
.51172 .64338 m .51075 .64483 L .50886 .64209 L F
.204 .31 .751 r
.51172 .64338 m .51286 .64677 L .51075 .64483 L F
.202 0 .284 r
.309 .6708 m .30826 .67275 L .3105 .6699 L F
.3105 .6699 m .30826 .67275 L .309 .6708 L F
.309 .6708 m .30826 .67275 L .3105 .6699 L F
.34 .546 .908 r
.7731 .5829 m .7734 .58119 L .77036 .58091 L F
.7731 .5829 m .77408 .58264 L .7734 .58119 L F
.556 .118 .163 r
.55108 .74508 m .55532 .74336 L .55233 .74351 L F
.55108 .74508 m .55412 .74508 L .55532 .74336 L F
1 .808 .5 r
.55532 .74336 m .55412 .74508 L .55446 .74307 L F
.749 .719 .825 r
.67715 .53712 m .6737 .53584 L .67618 .53498 L F
.236 .375 .801 r
.67767 .53474 m .67715 .53712 L .67618 .53498 L F
.67767 .53474 m .67903 .53784 L .67715 .53712 L F
.443 .183 .424 r
.67903 .53784 m .67678 .53865 L .67715 .53712 L F
.963 .649 .376 r
.49563 .69443 m .49695 .69348 L .4935 .69262 L F
.49563 .69443 m .49699 .69605 L .49695 .69348 L F
.365 .149 .447 r
.49695 .69348 m .49699 .69605 L .49907 .69462 L F
.446 0 0 r
.47997 .69333 m .47867 .69421 L .47649 .69341 L F
.563 .033 0 r
.47997 .69333 m .48215 .69454 L .47867 .69421 L F
.55 .17 .274 r
.48349 .6927 m .48215 .69454 L .47997 .69333 L F
.781 .967 .666 r
.7072 .50026 m .70614 .50112 L .70437 .50077 L F
.572 .469 .699 r
.7072 .50026 m .70955 .50114 L .7096 .49921 L F
.655 .55 .724 r
.41217 .69223 m .40986 .69284 L .41012 .69196 L F
.357 .411 .78 r
.38147 .68405 m .38241 .68707 L .38396 .68682 L F
.685 .405 .493 r
.24714 .64995 m .25043 .6471 L .24805 .64795 L F
.24714 .64995 m .24998 .65015 L .25043 .6471 L F
0 0 0 r
.25043 .6471 m .25139 .64685 L .25248 .64474 L F
0 0 .027 r
.25043 .6471 m .25053 .64904 L .25139 .64685 L F
.25043 .6471 m .24998 .65015 L .25053 .64904 L F
.355 .645 .964 r
.68529 .52697 m .68353 .52725 L .68205 .52583 L F
.346 .292 .653 r
.68529 .52697 m .68466 .52899 L .68353 .52725 L F
.83 .659 .67 r
.57248 .59151 m .57439 .59453 L .57435 .59556 L F
.261 0 0 r
.31713 .63156 m .31887 .63181 L .32011 .63033 L F
.641 .36 .477 r
.31887 .63181 m .32156 .6303 L .32011 .63033 L F
.774 .667 .745 r
.39271 .71196 m .39398 .71504 L .39511 .71476 L F
.315 .017 .291 r
.39854 .71314 m .39511 .71476 L .39753 .71322 L F
.481 .555 .855 r
.39753 .71322 m .40093 .71326 L .39967 .71038 L F
.39753 .71322 m .39967 .71038 L .39854 .71314 L F
.6 .602 .826 r
.39501 .71099 m .39511 .71476 L .39854 .71314 L F
.294 0 .145 r
.33938 .63701 m .33836 .63867 L .33642 .6391 L F
.266 0 .129 r
.3404 .6379 m .33938 .63701 L .34105 .63614 L F
.3404 .6379 m .33836 .63867 L .33938 .63701 L F
.326 0 .098 r
.56319 .69917 m .56527 .69878 L .56562 .69805 L F
.56319 .69917 m .56238 .70046 L .56527 .69878 L F
.202 0 0 r
.55036 .78842 m .55285 .78894 L .55286 .78908 L F
.811 .855 .882 r
.55474 .78518 m .55285 .78894 L .55286 .78908 L F
.581 .052 0 r
.51364 .69903 m .51203 .6998 L .51021 .6989 L F
.51366 .69903 m .51203 .6998 L .51364 .69903 L F
.933 .603 .386 r
.51203 .6998 m .51069 .70105 L .51059 .70049 L F
.581 .052 0 r
.51366 .69903 m .51021 .6989 L .51014 .6987 L F
.51014 .6987 m .51021 .6989 L .50972 .69867 L F
.436 .402 .722 r
.50972 .69867 m .51203 .6998 L .51071 .69829 L F
.804 .407 .299 r
.51203 .6998 m .51059 .70017 L .51071 .69829 L F
0 0 .17 r
.51071 .69829 m .5106 .70002 L .51068 .69988 L F
.51071 .69829 m .51068 .69988 L .51085 .6993 L F
.5106 .70002 m .51059 .70017 L .51063 .7001 L F
.921 .687 .566 r
.51097 .6989 m .51059 .70017 L .5102 .69825 L F
.51203 .6998 m .51059 .70017 L .51097 .6989 L F
0 0 .17 r
.51085 .6993 m .51068 .69988 L .51088 .69951 L F
.933 .603 .386 r
.51203 .6998 m .51143 .70009 L .51097 .6989 L F
.51143 .70009 m .51074 .70042 L .51085 .69968 L F
.51143 .70009 m .51085 .69968 L .51097 .6989 L F
0 0 .17 r
.51112 .69785 m .51088 .69951 L .51272 .69615 L F
.51071 .69829 m .51088 .69951 L .51112 .69785 L F
.5106 .70002 m .51063 .7001 L .51272 .69615 L F
.431 .387 .709 r
.50972 .69867 m .51071 .69829 L .51084 .69448 L F
.786 .594 .641 r
.51451 .69269 m .51129 .69564 L .51095 .69207 L F
.331 .302 .675 r
.51084 .69448 m .51071 .69829 L .51272 .69615 L F
.849 .783 .787 r
.51272 .69615 m .51085 .69968 L .5096 .69714 L F
.51085 .69968 m .51059 .70017 L .5103 .69929 L F
.933 .603 .386 r
.51097 .6989 m .51059 .70049 L .5102 .69825 L F
.916 .635 .145 r
.5096 .69714 m .5102 .69825 L .50723 .69907 L F
.72 .47 .547 r
.51033 .69939 m .50723 .69907 L .5102 .69825 L F
.51051 .70095 m .50894 .70005 L .51033 .69939 L F
.50894 .70005 m .50723 .69907 L .51033 .69939 L F
.916 .635 .145 r
.5096 .69714 m .51033 .69939 L .5102 .69825 L F
.51033 .69939 m .51059 .70017 L .5102 .69825 L F
.849 .783 .787 r
.51064 .69924 m .5103 .69929 L .5096 .69714 L F
.51085 .69968 m .51039 .69936 L .51064 .69924 L F
.51039 .69936 m .5103 .69929 L .51064 .69924 L F
.72 .47 .547 r
.51069 .70105 m .51051 .70095 L .5102 .69825 L F
.933 .603 .386 r
.51074 .70042 m .51059 .70049 L .51097 .6989 L F
.52 .102 .187 r
.5156 .69807 m .51203 .6998 L .51366 .69903 L F
.637 .367 .492 r
.52567 .76476 m .52706 .76567 L .52985 .76251 L F
.402 .063 .273 r
.52706 .76567 m .53016 .76267 L .52985 .76251 L F
.728 .474 .544 r
.59655 .57684 m .60017 .57511 L .59785 .57495 L F
.59655 .57684 m .6002 .57734 L .60017 .57511 L F
.608 .362 .518 r
.60279 .57714 m .60017 .57511 L .6002 .57734 L F
.60279 .57714 m .60311 .57491 L .60017 .57511 L F
.713 .745 .877 r
.7071 .477 m .70798 .47953 L .70456 .479 L F
.744 .762 .867 r
.71071 .47718 m .70798 .47953 L .7071 .477 L F
.682 .734 .89 r
.48281 .6535 m .48609 .65407 L .48518 .65268 L F
.576 .656 .891 r
.48609 .65407 m .48743 .65209 L .48518 .65268 L F
.48609 .65407 m .48832 .65367 L .48743 .65209 L F
.22 0 .311 r
.3357 .6201 m .3351 .62211 L .33727 .61928 L F
.856 .688 .672 r
.50321 .77544 m .50418 .77685 L .50518 .77282 L F
.64 .464 .629 r
.50418 .77685 m .50673 .77471 L .50518 .77282 L F
.856 .688 .672 r
.50321 .77544 m .50518 .77282 L .5055 .77485 L F
.137 .504 .909 r
.50747 .773 m .50518 .77282 L .5057 .77096 L F
.614 .122 .06 r
.50518 .77282 m .50747 .7738 L .50951 .77374 L F
.137 .504 .909 r
.50747 .773 m .50747 .7738 L .50518 .77282 L F
.563 .382 .594 r
.50747 .773 m .50518 .77282 L .50747 .7738 L F
.468 .332 .613 r
.50673 .77471 m .50747 .7738 L .50518 .77282 L F
.563 .382 .594 r
.50747 .773 m .5055 .77485 L .50518 .77282 L F
.854 .983 .696 r
.51929 .81257 m .52085 .81132 L .5219 .80953 L F
.371 0 0 r
.29552 .64889 m .29779 .64797 L .29955 .6483 L F
.658 .601 .78 r
.26791 .64514 m .27153 .64731 L .26995 .64466 L F
.435 .57 .891 r
.27153 .64731 m .27161 .64441 L .26995 .64466 L F
.27153 .64731 m .27339 .64743 L .27161 .64441 L F
.623 .181 .179 r
.47423 .6925 m .47273 .69417 L .47068 .69257 L F
.614 .15 .127 r
.47649 .69341 m .47273 .69417 L .47423 .6925 L F
.491 .288 .532 r
.48503 .78254 m .48694 .78241 L .48687 .77995 L F
.797 .758 .817 r
.48543 .77684 m .48687 .77995 L .48919 .77669 L F
.622 .504 .698 r
.48687 .77995 m .48858 .78015 L .48919 .77669 L F
.597 .356 .522 r
.48694 .78241 m .48858 .78015 L .48687 .77995 L F
0 0 0 r
.62152 .52709 m .61861 .52898 L .6196 .52809 L F
.502 .319 .566 r
.28414 .61912 m .28221 .61717 L .28438 .61674 L F
.28414 .61912 m .28217 .61972 L .28221 .61717 L F
.663 .417 .538 r
.58441 .59465 m .58665 .59699 L .5845 .59677 L F
.697 .413 .49 r
.58672 .59494 m .58665 .59699 L .58441 .59465 L F
.668 .309 .355 r
.48579 .69443 m .48349 .6927 L .48561 .69306 L F
.702 .304 .292 r
.48561 .69306 m .48792 .69521 L .48579 .69443 L F
.841 .446 .3 r
.58965 .71247 m .58828 .71381 L .5882 .71259 L F
.967 .686 .448 r
.58965 .71247 m .58987 .71483 L .58828 .71381 L F
.529 .828 .999 r
.35195 .59185 m .35061 .59252 L .34849 .59176 L F
.475 .124 .29 r
.49935 .76036 m .50107 .76005 L .50279 .75765 L F
.656 .334 .415 r
.50107 .76005 m .50501 .75974 L .50279 .75765 L F
0 0 .263 r
.65142 .51035 m .65123 .51365 L .65175 .51118 L F
.65123 .51365 m .65122 .51377 L .65175 .51118 L F
.733 .208 0 r
.65175 .51118 m .65387 .51287 L .65142 .51035 L F
.65175 .51118 m .65142 .51035 L .6541 .50683 L F
.892 .893 .823 r
.65237 .50822 m .65175 .51118 L .6541 .50683 L F
.65034 .50986 m .65175 .51118 L .65237 .50822 L F
0 0 .263 r
.65142 .51035 m .65175 .51118 L .64894 .50934 L F
.725 .662 .787 r
.5442 .7607 m .5418 .76279 L .54539 .76223 L F
.442 .177 .414 r
.54226 .76609 m .54539 .76223 L .5418 .76279 L F
.54226 .76609 m .54447 .76569 L .54539 .76223 L F
.557 .595 .847 r
.54539 .76223 m .54631 .76022 L .5442 .7607 L F
.54539 .76223 m .54752 .76277 L .54631 .76022 L F
.719 .474 .554 r
.54447 .76569 m .54752 .76277 L .54539 .76223 L F
.786 .464 .445 r
.54331 .78529 m .54735 .78603 L .54683 .78764 L F
.011 .019 .517 r
.51095 .69207 m .51024 .69592 L .51084 .69448 L F
.7 .98 .802 r
.58949 .72638 m .58883 .72637 L .58613 .72858 L F
0 0 0 r
.59126 .72297 m .58949 .72638 L .5914 .72448 L F
.59126 .72297 m .59068 .72449 L .58949 .72638 L F
.717 .984 .797 r
.59068 .72449 m .58883 .72637 L .58949 .72638 L F
.35 .039 .289 r
.35119 .6278 m .34846 .63024 L .349 .62826 L F
.016 0 0 r
.42856 .64946 m .43076 .64908 L .43213 .64849 L F
.258 0 0 r
.43076 .64908 m .43421 .64884 L .43213 .64849 L F
.442 .375 .687 r
.28287 .62411 m .28061 .62255 L .28261 .62196 L F
.28287 .62411 m .28093 .62592 L .28061 .62255 L F
.068 0 .158 r
.60742 .56931 m .60938 .56826 L .60973 .56626 L F
0 0 .137 r
.60973 .56626 m .60938 .56826 L .6115 .5653 L F
.461 .819 .549 r
.67657 .52641 m .67895 .52442 L .67875 .52333 L F
.606 .382 .55 r
.67971 .52683 m .68205 .52583 L .67895 .52442 L F
.668 .309 .355 r
.48579 .69443 m .48215 .69454 L .48349 .6927 L F
.654 .513 .679 r
.64637 .50714 m .6423 .50468 L .64613 .50493 L F
.748 .756 .86 r
.26675 .64371 m .26425 .64485 L .26791 .64514 L F
.554 .75 .968 r
.26791 .64514 m .26865 .6434 L .26675 .64371 L F
.26791 .64514 m .26995 .64466 L .26865 .6434 L F
0 0 0 r
.60513 .57184 m .60685 .57071 L .60742 .56931 L F
.49 .383 .66 r
.60529 .57416 m .60685 .57071 L .60513 .57184 L F
.443 .208 .46 r
.60311 .57491 m .60529 .57416 L .60513 .57184 L F
.637 .679 .873 r
.77497 .58587 m .77855 .58687 L .77746 .58523 L F
.611 .789 .967 r
.78044 .58568 m .77746 .58523 L .77855 .58687 L F
.57 .235 .362 r
.46963 .69236 m .4649 .69483 L .46512 .69327 L F
.384 .782 .986 r
.31635 .58867 m .31843 .58844 L .31995 .5891 L F
.328 .764 .967 r
.31843 .58844 m .32204 .58883 L .31995 .5891 L F
.709 .505 .61 r
.56809 .59144 m .56716 .58901 L .56807 .589 L F
.658 .145 .011 r
.55301 .73201 m .55128 .73207 L .55197 .73306 L F
.779 .361 .258 r
.55197 .73306 m .55542 .73391 L .55301 .73201 L F
.709 .505 .61 r
.56809 .59144 m .56664 .59146 L .56716 .58901 L F
.368 0 0 r
.51229 .68543 m .51537 .68638 L .51254 .68564 L F
.513 .392 .653 r
.63925 .48496 m .63899 .48759 L .63686 .48811 L F
.276 0 0 r
.42563 .70736 m .42464 .70655 L .42709 .70606 L F
.42563 .70736 m .42341 .70782 L .42464 .70655 L F
.859 .427 .191 r
.55542 .73391 m .55853 .73701 L .5564 .73485 L F
.799 .925 .92 r
.70961 .5199 m .70895 .52228 L .71065 .52066 L F
.86 .978 .857 r
.70822 .5216 m .70895 .52228 L .70961 .5199 L F
.766 .63 .71 r
.63008 .54088 m .62839 .54397 L .62702 .54101 L F
.398 .304 .632 r
.38108 .68158 m .38306 .68352 L .38311 .68112 L F
.38108 .68158 m .38147 .68405 L .38306 .68352 L F
.539 .504 .766 r
.38028 .67837 m .38108 .68158 L .38311 .68112 L F
.79 .544 .566 r
.59655 .57684 m .59785 .57495 L .59463 .57465 L F
.44 .064 .227 r
.44907 .69875 m .45113 .69949 L .4487 .70012 L F
.44907 .69875 m .45133 .69848 L .45113 .69949 L F
.752 .633 .728 r
.50246 .6645 m .50596 .66484 L .50472 .6614 L F
.751 .639 .737 r
.50246 .6645 m .50376 .66765 L .50596 .66484 L F
.494 .398 .675 r
.50596 .66484 m .50904 .66011 L .50472 .6614 L F
.50596 .66484 m .50807 .66447 L .50904 .66011 L F
.032 0 .31 r
.60946 .51044 m .61117 .50917 L .61158 .50697 L F
.128 0 .173 r
.60946 .51044 m .61087 .51128 L .61117 .50917 L F
.60946 .51044 m .60926 .51213 L .61087 .51128 L F
.975 .67 .359 r
.55566 .76513 m .55696 .76559 L .55458 .76517 L F
.675 .84 .962 r
.46543 .64206 m .46324 .64313 L .46183 .64196 L F
.855 .417 .172 r
.62433 .51352 m .62305 .51361 L .62326 .51207 L F
.62433 .51352 m .62507 .51523 L .62305 .51361 L F
.199 0 .302 r
.63198 .56295 m .62977 .56587 L .63031 .56402 L F
.6 .528 .746 r
.41187 .69053 m .41012 .69196 L .4085 .68747 L F
.655 .55 .724 r
.41217 .69223 m .41012 .69196 L .41187 .69053 L F
.583 .783 .974 r
.68713 .47781 m .68389 .47722 L .68621 .47655 L F
.53 .713 .956 r
.68853 .47604 m .68713 .47781 L .68621 .47655 L F
.68853 .47604 m .68943 .47748 L .68713 .47781 L F
.346 0 .037 r
.61651 .52946 m .61563 .53115 L .61327 .53144 L F
.593 .336 .496 r
.58672 .59494 m .58929 .59679 L .58665 .59699 L F
.58672 .59494 m .59063 .59374 L .58929 .59679 L F
.915 .855 .768 r
.53708 .76798 m .53531 .77124 L .53394 .7705 L F
.511 .571 .853 r
.53879 .76683 m .53708 .76798 L .53593 .76541 L F
.546 .516 .773 r
.61848 .54881 m .6196 .54583 L .61712 .54629 L F
.61848 .54881 m .62037 .54973 L .6196 .54583 L F
.498 .463 .749 r
.28287 .62411 m .2836 .62744 L .28093 .62592 L F
.473 .831 .567 r
.76334 .57342 m .76139 .57505 L .76268 .57394 L F
0 0 .163 r
.7612 .57736 m .76268 .57394 L .76139 .57505 L F
.812 .64 .669 r
.4826 .78519 m .48509 .78619 L .48503 .78254 L F
.104 .074 .536 r
.48503 .78254 m .48662 .78454 L .48694 .78241 L F
.48503 .78254 m .48509 .78619 L .48662 .78454 L F
.645 .371 .49 r
.58078 .59817 m .57868 .60177 L .57845 .59982 L F
0 0 0 r
.58186 .59745 m .58078 .59817 L .57845 .59982 L F
.58186 .59745 m .57845 .59982 L .57848 .5975 L F
.257 0 .175 r
.34747 .63229 m .3465 .63089 L .34846 .63024 L F
.34747 .63229 m .34559 .63297 L .3465 .63089 L F
.761 .827 .904 r
.25044 .63604 m .25219 .63711 L .25417 .63583 L F
.93 .73 .611 r
.25044 .63604 m .25166 .63946 L .25219 .63711 L F
.8 .678 .73 r
.25166 .63946 m .25417 .63583 L .25219 .63711 L F
.45 .045 .178 r
.53153 .76856 m .53032 .77062 L .52805 .77073 L F
.67 .28 .299 r
.53394 .7705 m .53032 .77062 L .53153 .76856 L F
.276 0 .256 r
.62015 .49116 m .61957 .49281 L .62215 .49026 L F
0 0 0 r
.53966 .74848 m .54024 .74806 L .5416 .74673 L F
.312 .38 .772 r
.54047 .74341 m .5416 .74673 L .54311 .7456 L F
0 0 0 r
.5416 .74673 m .54024 .74806 L .54311 .7456 L F
.669 .668 .84 r
.50015 .667 m .50376 .66765 L .50246 .6645 L F
.246 .116 .498 r
.63447 .52048 m .63403 .52305 L .63217 .52364 L F
.373 .769 .986 r
.63403 .52305 m .63651 .52339 L .63217 .52364 L F
.614 .663 .874 r
.6369 .52499 m .63217 .52364 L .63651 .52339 L F
.379 .245 .57 r
.61929 .51457 m .61864 .51714 L .61653 .51607 L F
.551 .313 .507 r
.61893 .5178 m .61653 .51607 L .61864 .51714 L F
.61893 .5178 m .6166 .5186 L .61653 .51607 L F
.858 .904 .865 r
.54889 .73778 m .54677 .73725 L .5482 .73675 L F
.591 .036 0 r
.5505 .74005 m .54685 .73748 L .54889 .73778 L F
.662 .267 .286 r
.54664 .7373 m .54597 .73869 L .54498 .73788 L F
.54677 .73725 m .54671 .73736 L .54664 .7373 L F
.54671 .73736 m .54597 .73869 L .54664 .7373 L F
.591 .036 0 r
.5505 .74005 m .54914 .73931 L .54718 .73778 L F
.662 .267 .286 r
.54696 .73783 m .54597 .73869 L .54677 .73725 L F
.5482 .73675 m .54498 .73788 L .54365 .73679 L F
.786 .451 .419 r
.54638 .73715 m .54597 .73869 L .5471 .73771 L F
.591 .036 0 r
.54685 .73748 m .5471 .73771 L .54638 .73715 L F
.54685 .73748 m .54638 .73715 L .54677 .73725 L F
.5505 .74005 m .54718 .73778 L .54685 .73748 L F
.662 .267 .286 r
.5482 .73675 m .54696 .73783 L .54677 .73725 L F
.858 .904 .865 r
.54677 .73725 m .54638 .73715 L .5482 .73675 L F
.786 .451 .419 r
.54638 .73715 m .5471 .73771 L .5482 .73675 L F
.591 .036 0 r
.5471 .73771 m .54718 .73778 L .54638 .73715 L F
.54685 .73748 m .54677 .73725 L .54889 .73778 L F
.622 .819 .976 r
.70818 .4844 m .70939 .48557 L .71165 .48474 L F
.2 0 0 r
.71165 .48474 m .70939 .48557 L .70913 .4866 L F
.355 0 .006 r
.28932 .6497 m .28813 .65068 L .28624 .6508 L F
.503 .455 .736 r
.37982 .67596 m .38096 .6723 L .37883 .67262 L F
.37982 .67596 m .38171 .67548 L .38096 .6723 L F
.448 .361 .665 r
.37982 .67596 m .38195 .67779 L .38171 .67548 L F
.37982 .67596 m .38028 .67837 L .38195 .67779 L F
.498 .844 .996 r
.55058 .74939 m .54969 .74887 L .55208 .74836 L F
.709 .339 .345 r
.55058 .74939 m .54981 .75144 L .55327 .75111 L F
.449 .106 .291 r
.568 .69751 m .5705 .6954 L .56837 .69553 L F
.712 .649 .785 r
.57196 .6947 m .5705 .6954 L .5729 .69241 L F
.072 0 .207 r
.5705 .6954 m .57168 .69519 L .5729 .69241 L F
.754 .398 .38 r
.57285 .69751 m .5705 .6954 L .57196 .6947 L F
.57285 .69751 m .57003 .69725 L .5705 .6954 L F
.42 .205 .479 r
.57003 .69725 m .57168 .69519 L .5705 .6954 L F
.524 .908 .76 r
.45769 .64355 m .45809 .64291 L .45965 .64276 L F
.45769 .64355 m .45613 .64418 L .45809 .64291 L F
.987 .765 .514 r
.76949 .60546 m .77061 .60594 L .76963 .60253 L F
.991 .757 .383 r
.55458 .72085 m .55355 .72203 L .55358 .7212 L F
.301 0 0 r
.55502 .7207 m .55458 .72085 L .55266 .72055 L F
.991 .757 .383 r
.55458 .72085 m .55365 .71932 L .55266 .72055 L F
.55458 .72085 m .55358 .7212 L .55365 .71932 L F
.301 0 0 r
.55623 .72077 m .55458 .72085 L .55502 .7207 L F
.628 .126 .038 r
.55623 .72077 m .55687 .72228 L .55458 .72085 L F
.55623 .72077 m .55937 .72273 L .55687 .72228 L F
.62 .286 .383 r
.61181 .58858 m .60842 .5907 L .60967 .58828 L F
.621 .284 .378 r
.60606 .58892 m .60967 .58828 L .60842 .5907 L F
.136 0 0 r
.26038 .59077 m .26362 .58888 L .26147 .58927 L F
.764 .699 .79 r
.62839 .54397 m .62566 .54665 L .62502 .54356 L F
.877 .687 .641 r
.64296 .53497 m .64457 .53566 L .64315 .53253 L F
.863 .612 .558 r
.64361 .53721 m .64457 .53566 L .64296 .53497 L F
.64361 .53721 m .64467 .53833 L .64457 .53566 L F
.712 .593 .721 r
.61783 .52172 m .61557 .52452 L .61489 .52217 L F
.505 .816 1 r
.71487 .48517 m .71399 .48428 L .71165 .48474 L F
.999 .806 .467 r
.71373 .48702 m .71487 .48517 L .71165 .48474 L F
.71373 .48702 m .71456 .48797 L .71487 .48517 L F
.859 .94 .873 r
.71647 .48155 m .71487 .48517 L .71759 .48308 L F
.71647 .48155 m .71399 .48428 L .71487 .48517 L F
0 0 .169 r
.47651 .79927 m .47829 .7957 L .47861 .79824 L F
.35 .371 .742 r
.47872 .80029 m .47651 .79927 L .47861 .79824 L F
.279 0 .108 r
.33217 .6239 m .3351 .62211 L .33309 .62273 L F
.582 .737 .949 r
.28897 .62983 m .28832 .63186 L .28686 .63036 L F
.28897 .62983 m .29058 .63139 L .28832 .63186 L F
.623 .865 .988 r
.29402 .63133 m .29058 .63139 L .29256 .63059 L F
.397 .76 .993 r
.29457 .63035 m .29402 .63133 L .29256 .63059 L F
.29457 .63035 m .29563 .63112 L .29402 .63133 L F
.557 .216 .346 r
.57994 .68659 m .58177 .6865 L .58345 .68432 L F
0 .133 .68 r
.58345 .68432 m .58528 .68641 L .58504 .68658 L F
.657 .338 .42 r
.58177 .6865 m .58528 .68641 L .58345 .68432 L F
.541 .458 .711 r
.24419 .6173 m .24618 .61718 L .24577 .61341 L F
.622 .394 .551 r
.61416 .58621 m .61456 .58882 L .61181 .58858 L F
.41 .25 .551 r
.61633 .5877 m .61416 .58621 L .61685 .58588 L F
.61633 .5877 m .61456 .58882 L .61416 .58621 L F
0 0 0 r
.62737 .56816 m .62503 .57148 L .62604 .56984 L F
.383 0 0 r
.50363 .81655 m .50688 .81611 L .505 .81724 L F
.125 0 0 r
.50688 .81611 m .50844 .81641 L .505 .81724 L F
.50688 .81611 m .50956 .81631 L .50844 .81641 L F
.576 .895 .986 r
.5418 .76279 m .54061 .76221 L .5385 .76305 L F
.709 .939 .96 r
.54185 .76131 m .5418 .76279 L .5442 .7607 L F
.54185 .76131 m .54061 .76221 L .5418 .76279 L F
.439 .857 .954 r
.71362 .51909 m .71659 .51888 L .7158 .51746 L F
.265 .551 .927 r
.7158 .51746 m .71659 .51888 L .71896 .5191 L F
.79 .64 .696 r
.24939 .62782 m .25241 .62816 L .252 .62551 L F
.643 .152 .069 r
.24939 .62782 m .25063 .62968 L .25241 .62816 L F
.25063 .62968 m .25094 .62979 L .25241 .62816 L F
.09 0 0 r
.25241 .62816 m .25094 .62979 L .25309 .62837 L F
.25094 .62979 m .25124 .62964 L .25309 .62837 L F
.663 .158 .035 r
.24955 .6292 m .25063 .62968 L .24939 .62782 L F
.671 .272 .281 r
.25309 .62837 m .25124 .62964 L .24955 .6292 L F
.421 .035 .199 r
.25224 .62991 m .24986 .62928 L .24976 .6293 L F
.25063 .62968 m .24976 .6293 L .24959 .62932 L F
.25191 .63013 m .24976 .6293 L .25063 .62968 L F
.25017 .63131 m .25191 .63013 L .24959 .62932 L F
.663 .158 .035 r
.24955 .6292 m .2508 .62995 L .25063 .62968 L F
.09 0 0 r
.25094 .62979 m .2508 .62995 L .25124 .62964 L F
.643 .152 .069 r
.25063 .62968 m .2508 .62995 L .25094 .62979 L F
.671 .272 .281 r
.25124 .62964 m .2508 .62995 L .24955 .6292 L F
.421 .035 .199 r
.25191 .63013 m .25224 .62991 L .24976 .6293 L F
.25224 .62991 m .25413 .62863 L .24986 .62928 L F
.24959 .62932 m .2529 .62882 L .24955 .6292 L F
.2529 .62882 m .25413 .62863 L .25299 .62878 L F
.2529 .62882 m .25299 .62878 L .24955 .6292 L F
.407 .351 .683 r
.25241 .62816 m .25364 .6247 L .252 .62551 L F
.25241 .62816 m .25412 .62754 L .25364 .6247 L F
.09 0 0 r
.25241 .62816 m .25309 .62837 L .25412 .62754 L F
.694 .606 .753 r
.50015 .66466 m .50015 .667 L .50246 .6645 L F
.621 .575 .781 r
.61359 .54384 m .61712 .54629 L .61621 .54294 L F
.589 .464 .677 r
.61712 .54629 m .61917 .54299 L .61621 .54294 L F
.642 .351 .462 r
.71933 .49471 m .7174 .4937 L .71722 .49558 L F
.71933 .49471 m .71996 .49356 L .7174 .4937 L F
.463 0 .017 r
.43866 .66274 m .43692 .66406 L .43456 .66385 L F
.311 0 .104 r
.44031 .66143 m .43692 .66406 L .43866 .66274 L F
.689 .601 .753 r
.48967 .65695 m .49018 .65913 L .49202 .6561 L F
.59 .474 .689 r
.49202 .6561 m .49018 .65913 L .49235 .65876 L F
.781 .709 .784 r
.4912 .66074 m .49235 .65876 L .49018 .65913 L F
.864 .496 0 r
.46985 .79625 m .47126 .79924 L .47055 .79837 L F
.97 .653 .338 r
.47126 .79924 m .47042 .80118 L .47055 .79837 L F
.47126 .79924 m .47188 .80242 L .47042 .80118 L F
.617 .601 .812 r
.50939 .67007 m .51071 .67331 L .51311 .67227 L F
.51 .684 .945 r
.70486 .51128 m .70873 .5122 L .70687 .5128 L F
.402 .063 .273 r
.52706 .76567 m .5295 .76508 L .53016 .76267 L F
.031 0 .135 r
.53016 .76267 m .53119 .76383 L .5324 .76212 L F
.53016 .76267 m .5295 .76508 L .53119 .76383 L F
0 0 0 r
.43421 .64884 m .43643 .64857 L .43799 .64828 L F
.503 .328 .577 r
.38016 .66464 m .38224 .66423 L .38253 .66163 L F
.552 .469 .715 r
.38073 .66749 m .38224 .66423 L .38016 .66464 L F
.681 .559 .71 r
.58364 .72337 m .58406 .72625 L .58284 .72361 L F
.983 .889 .652 r
.56921 .76807 m .57116 .76553 L .57027 .7648 L F
.56921 .76807 m .57019 .76895 L .57116 .76553 L F
.721 .691 .821 r
.64832 .52038 m .64998 .52168 L .65233 .51951 L F
.219 0 .178 r
.5226 .68735 m .52176 .68927 L .51992 .68992 L F
.321 0 .229 r
.52409 .68823 m .5226 .68735 L .52429 .68653 L F
.52409 .68823 m .52176 .68927 L .5226 .68735 L F
.607 .334 .477 r
.59463 .5921 m .5947 .5942 L .59237 .59415 L F
.626 .349 .478 r
.59789 .59347 m .59463 .5921 L .59795 .59149 L F
.59789 .59347 m .5947 .5942 L .59463 .5921 L F
.298 0 0 r
.50747 .7738 m .51195 .77396 L .50951 .77374 L F
.601 .801 .977 r
.68011 .53903 m .68135 .53722 L .67903 .53784 L F
.68011 .53903 m .68245 .53837 L .68135 .53722 L F
.453 .762 .995 r
.35975 .59347 m .35906 .59473 L .35774 .59353 L F
.35975 .59347 m .36114 .59447 L .35906 .59473 L F
.121 .669 .809 r
.50792 .80771 m .51057 .80761 L .50689 .80759 L F
.766 .741 .83 r
.47683 .63938 m .47339 .63908 L .47569 .63643 L F
.809 .761 .808 r
.48056 .63542 m .47683 .63938 L .47569 .63643 L F
.117 0 .172 r
.56124 .70866 m .55963 .70962 L .56198 .70693 L F
0 0 0 r
.56124 .70866 m .55938 .71195 L .55963 .70962 L F
.60742 .56931 m .60685 .57071 L .60938 .56826 L F
.816 .796 .834 r
.2504 .65912 m .2516 .65592 L .2512 .65581 L F
.825 .564 .544 r
.6423 .50468 m .64324 .50721 L .64074 .50419 L F
.6423 .50468 m .64425 .50817 L .64324 .50721 L F
.654 .513 .679 r
.64637 .50714 m .64425 .50817 L .6423 .50468 L F
.831 .723 .745 r
.51569 .79581 m .51963 .79701 L .51885 .79398 L F
.378 .283 .619 r
.51963 .79701 m .52145 .79328 L .51885 .79398 L F
0 0 0 r
.63198 .56295 m .63278 .5613 L .63391 .55997 L F
.103 0 0 r
.42111 .70844 m .42017 .7091 L .41909 .70888 L F
.091 0 0 r
.42017 .7091 m .41825 .70967 L .41909 .70888 L F
.637 .707 .897 r
.77497 .58587 m .77596 .58286 L .77408 .58264 L F
.77497 .58587 m .77746 .58523 L .77596 .58286 L F
.63 .722 .914 r
.67358 .48433 m .67707 .48519 L .67617 .48365 L F
.81 .781 .826 r
.67617 .48365 m .67707 .48519 L .67904 .48297 L F
.738 .725 .839 r
.68951 .52794 m .68687 .53008 L .68466 .52899 L F
.186 .717 .746 r
.46023 .65456 m .45804 .6549 L .45632 .65526 L F
.698 .974 .918 r
.46076 .65337 m .46023 .65456 L .46209 .65336 L F
.46076 .65337 m .45804 .6549 L .46023 .65456 L F
.333 .085 .38 r
.61761 .49367 m .61725 .49557 L .61957 .49281 L F
.492 .037 .099 r
.46874 .80478 m .47242 .80396 L .47134 .80509 L F
.47134 .80509 m .47242 .80396 L .46874 .80478 L F
0 0 0 r
.47134 .80509 m .47242 .80396 L .47296 .80393 L F
.47134 .80509 m .47242 .80396 L .47296 .80393 L F
.724 .568 .679 r
.56727 .5972 m .56914 .59789 L .57056 .59688 L F
.787 .63 .687 r
.5695 .59724 m .57056 .59688 L .56914 .59789 L F
.683 .404 .493 r
.57033 .5969 m .56918 .59734 L .56727 .5972 L F
.806 .731 .782 r
.57138 .59383 m .5695 .59724 L .56948 .59577 L F
.5695 .59724 m .56914 .59789 L .56923 .59735 L F
.5695 .59724 m .56923 .59735 L .56948 .59577 L F
.683 .404 .493 r
.57056 .59688 m .5695 .59724 L .57033 .5969 L F
.5695 .59724 m .56918 .59734 L .57033 .5969 L F
.684 .616 .773 r
.56923 .59735 m .56914 .59789 L .56727 .5972 L F
.683 .404 .493 r
.56918 .59734 m .56781 .5978 L .56727 .5972 L F
.684 .616 .773 r
.56948 .59577 m .56923 .59735 L .56727 .5972 L F
.787 .63 .687 r
.57138 .59383 m .57056 .59688 L .5695 .59724 L F
.683 .404 .493 r
.57056 .59688 m .56935 .59948 L .56781 .5978 L F
.787 .63 .687 r
.57138 .59383 m .57288 .59722 L .57056 .59688 L F
.708 .453 .537 r
.57288 .59722 m .56935 .59948 L .57056 .59688 L F
.415 .348 .673 r
.56992 .72567 m .56992 .72581 L .5678 .7258 L F
.56992 .72581 m .56999 .72766 L .5678 .7258 L F
.077 .629 .824 r
.5662 .72578 m .5678 .7258 L .56544 .72571 L F
.56863 .72604 m .5678 .7258 L .5662 .72578 L F
.865 .703 .679 r
.39205 .71383 m .39398 .71504 L .39271 .71196 L F
.717 .881 .957 r
.39062 .71524 m .39398 .71504 L .39205 .71383 L F
.684 .788 .929 r
.70115 .47852 m .70456 .479 L .70229 .47984 L F
.558 .489 .734 r
.40867 .6778 m .40941 .6812 L .40726 .68165 L F
.55 .459 .704 r
.40941 .6812 m .40774 .68395 L .40726 .68165 L F
.291 .693 .974 r
.37239 .59886 m .37191 .59978 L .37064 .59871 L F
.37239 .59886 m .37383 .59976 L .37191 .59978 L F
.404 .499 .842 r
.37514 .60286 m .37191 .59978 L .37383 .59976 L F
.789 .477 .46 r
.62286 .55144 m .62037 .54973 L .62393 .5497 L F
.865 .849 .825 r
.64443 .52645 m .64832 .52441 L .64662 .52353 L F
.64443 .52645 m .64568 .52743 L .64832 .52441 L F
.599 .622 .846 r
.62011 .52111 m .61783 .52172 L .6166 .5186 L F
.515 .539 .818 r
.25074 .62285 m .252 .62551 L .25364 .6247 L F
.045 0 0 r
.3224 .59996 m .32093 .60006 L .31881 .60008 L F
.277 0 0 r
.32438 .60018 m .32093 .60006 L .3224 .59996 L F
.556 .884 .989 r
.54127 .80298 m .54494 .80284 L .54346 .8021 L F
.88 .901 .841 r
.54346 .8021 m .54494 .80284 L .54598 .80086 L F
.343 .058 .329 r
.61469 .49815 m .61725 .49557 L .61522 .49642 L F
.292 .012 .305 r
.55338 .7094 m .55554 .70894 L .55584 .70671 L F
.029 0 .136 r
.55584 .70671 m .55752 .70588 L .55806 .70384 L F
.335 .046 .316 r
.55584 .70671 m .55741 .70826 L .55752 .70588 L F
.55584 .70671 m .55554 .70894 L .55741 .70826 L F
.659 .62 .799 r
.64233 .48948 m .64054 .49121 L .63899 .48759 L F
0 .082 .633 r
.58406 .72625 m .58472 .7264 L .58276 .72654 L F
.58406 .72625 m .58613 .72858 L .58472 .7264 L F
.691 .826 .948 r
.49287 .63435 m .4906 .63539 L .48905 .63406 L F
.164 .429 .865 r
.76794 .60892 m .76997 .60891 L .76806 .60775 L F
.76794 .60892 m .77093 .61066 L .76997 .60891 L F
.221 0 0 r
.42133 .69597 m .42325 .69628 L .42487 .69583 L F
.257 0 0 r
.42205 .69573 m .4242 .69643 L .42325 .69628 L F
.575 .1 .089 r
.42325 .69628 m .42556 .69687 L .42712 .69555 L F
.257 0 0 r
.4242 .69643 m .42556 .69687 L .42325 .69628 L F
.221 0 0 r
.42112 .69598 m .42325 .69628 L .42133 .69597 L F
.575 .1 .089 r
.42325 .69628 m .42712 .69555 L .42487 .69583 L F
.521 .447 .714 r
.4099 .68357 m .4085 .68747 L .40774 .68395 L F
.4099 .68357 m .41054 .68706 L .4085 .68747 L F
.6 .528 .746 r
.41187 .69053 m .4085 .68747 L .41054 .68706 L F
.567 .733 .953 r
.50874 .81285 m .50448 .8121 L .50901 .81238 L F
.584 .89 .989 r
.50882 .81166 m .50901 .81238 L .50624 .81218 L F
.187 .489 .901 r
.50882 .81166 m .50874 .81285 L .50901 .81238 L F
.50882 .81166 m .51122 .81401 L .50874 .81285 L F
.683 .711 .87 r
.69413 .48499 m .69773 .48616 L .69651 .48489 L F
.542 .801 .993 r
.69773 .48616 m .699 .48464 L .69651 .48489 L F
.69773 .48616 m .70009 .48568 L .699 .48464 L F
.513 .472 .749 r
.40867 .6778 m .40604 .67603 L .40827 .67556 L F
.466 .262 .518 r
.5246 .7703 m .52238 .76847 L .52599 .76822 L F
.761 .398 .368 r
.52599 .76822 m .52805 .77073 L .5246 .7703 L F
.952 .678 .481 r
.55397 .73939 m .55446 .74307 L .55531 .74203 L F
0 0 0 r
.58741 .68973 m .58885 .68629 L .58677 .68711 L F
.414 .807 .987 r
.30182 .63278 m .30531 .63307 L .30323 .63336 L F
.797 .999 .834 r
.54329 .79887 m .54229 .80013 L .53991 .8012 L F
.533 0 0 r
.32843 .60208 m .33165 .60306 L .33016 .60297 L F
.608 .937 .952 r
.33016 .60297 m .33165 .60306 L .33361 .60207 L F
.777 .665 .74 r
.51637 .67095 m .51643 .67312 L .51311 .67227 L F
.657 .134 0 r
.51643 .67312 m .51494 .67324 L .51311 .67227 L F
.004 0 .412 r
.51782 .66947 m .51643 .67312 L .51637 .67095 L F
.51782 .66947 m .51779 .67228 L .51643 .67312 L F
.422 .866 .888 r
.51643 .67312 m .51779 .67228 L .51494 .67324 L F
.645 .376 .497 r
.57415 .70296 m .56904 .70124 L .57116 .70039 L F
.57415 .70296 m .56919 .70377 L .56904 .70124 L F
.34 0 0 r
.46742 .65309 m .4652 .65335 L .46434 .65315 L F
.809 .962 .909 r
.46834 .65028 m .46742 .65309 L .47089 .65287 L F
.367 .834 .885 r
.46577 .65244 m .46283 .6532 L .46434 .65315 L F
.809 .962 .909 r
.46834 .65028 m .46634 .65223 L .46785 .65179 L F
0 0 0 r
.46756 .65122 m .46641 .65225 L .46834 .65028 L F
.809 .962 .909 r
.46634 .65223 m .4652 .65335 L .46785 .65179 L F
0 0 0 r
.46641 .65225 m .4652 .65335 L .46634 .65223 L F
.46641 .65225 m .46634 .65223 L .46834 .65028 L F
.312 .802 .86 r
.4665 .65228 m .46423 .65285 L .46577 .65244 L F
.46666 .65224 m .46651 .65228 L .4665 .65228 L F
.367 .834 .885 r
.46577 .65244 m .46434 .65315 L .4652 .65335 L F
.312 .802 .86 r
.46651 .65228 m .46423 .65285 L .4665 .65228 L F
.46423 .65285 m .46283 .6532 L .46455 .65276 L F
.46423 .65285 m .46455 .65276 L .46577 .65244 L F
.809 .962 .909 r
.46785 .65179 m .4652 .65335 L .46742 .65309 L F
.612 .653 .866 r
.71373 .47924 m .71071 .47718 L .7134 .47677 L F
.585 .566 .799 r
.71533 .47575 m .71373 .47924 L .7134 .47677 L F
.71533 .47575 m .71613 .47879 L .71373 .47924 L F
.089 0 .339 r
.57509 .69436 m .57285 .69751 L .57196 .6947 L F
.809 .761 .808 r
.48056 .63542 m .47569 .63643 L .47783 .63575 L F
.426 .867 .899 r
.48056 .63542 m .48016 .63509 L .48365 .63566 L F
.48056 .63542 m .47783 .63575 L .48016 .63509 L F
.429 .392 .715 r
.62916 .49798 m .62801 .50161 L .62716 .49966 L F
.379 .805 .969 r
.2942 .5853 m .29784 .58543 L .2957 .58575 L F
.492 .783 .997 r
.71043 .48978 m .7099 .4889 L .70705 .48929 L F
.669 .145 0 r
.71291 .48986 m .7099 .4889 L .71043 .48978 L F
.897 .824 .767 r
.64443 .52645 m .64498 .5294 L .64568 .52743 L F
.64443 .52645 m .64266 .52951 L .64498 .5294 L F
.899 .817 .758 r
.64266 .52951 m .64315 .53253 L .64498 .5294 L F
.467 .135 .32 r
.51918 .78745 m .52073 .78452 L .52248 .78483 L F
.928 .726 .61 r
.55853 .73701 m .55983 .74018 L .56026 .73773 L F
.332 .544 .909 r
.56027 .71563 m .56421 .71759 L .56367 .71827 L F
.57 .885 .991 r
.56421 .71759 m .56534 .71682 L .56367 .71827 L F
0 0 .237 r
.56534 .71682 m .56466 .71977 L .56367 .71827 L F
.925 .723 .611 r
.63085 .50622 m .62805 .50869 L .62809 .50634 L F
.63085 .50622 m .62953 .51026 L .6285 .50916 L F
.63085 .50622 m .6285 .50916 L .62855 .50825 L F
.821 .598 .6 r
.63146 .50902 m .62863 .50676 L .63171 .50724 L F
.62863 .50676 m .62809 .50634 L .62864 .50648 L F
.62863 .50676 m .62864 .50648 L .63171 .50724 L F
.925 .723 .611 r
.62855 .50825 m .6285 .50916 L .62805 .50869 L F
.337 .443 .822 r
.47829 .7957 m .47555 .79374 L .47772 .7939 L F
.765 .6 .673 r
.49202 .6561 m .49557 .65873 L .49475 .65595 L F
.49202 .6561 m .49235 .65876 L .49557 .65873 L F
.675 .628 .795 r
.49475 .65595 m .49557 .65873 L .49789 .65619 L F
.411 0 .145 r
.41153 .65317 m .41379 .65289 L .4151 .65093 L F
.39 0 .132 r
.4151 .65093 m .41597 .65249 L .41726 .65072 L F
.4151 .65093 m .41379 .65289 L .41597 .65249 L F
.35 0 0 r
.53747 .78527 m .54097 .78524 L .53968 .78559 L F
.381 0 0 r
.54097 .78524 m .54164 .78662 L .53968 .78559 L F
.54097 .78524 m .54331 .78529 L .54164 .78662 L F
.363 0 0 r
.4155 .6952 m .4178 .69611 L .41931 .69638 L F
.101 .657 .765 r
.4178 .69611 m .42112 .69598 L .41931 .69638 L F
0 .558 .727 r
.50624 .81218 m .50448 .8121 L .50479 .81309 L F
.50624 .81218 m .50901 .81238 L .50448 .8121 L F
.435 .181 .428 r
.56421 .70604 m .56124 .70866 L .56198 .70693 L F
.67 .132 0 r
.50403 .76258 m .50261 .76258 L .50032 .76086 L F
.753 .334 .253 r
.50645 .76444 m .50261 .76258 L .50403 .76258 L F
.44 .465 .789 r
.27339 .64743 m .27451 .65133 L .27582 .65051 L F
.536 0 0 r
.278 .65266 m .2767 .65259 L .27451 .65133 L F
.382 .348 .696 r
.27451 .65133 m .2767 .65259 L .27582 .65051 L F
.689 .433 .531 r
.50073 .78806 m .49671 .79101 L .49757 .7878 L F
.50073 .78806 m .50061 .79064 L .49671 .79101 L F
.634 .388 .527 r
.50073 .78806 m .50303 .79036 L .50061 .79064 L F
.931 .576 .331 r
.67622 .51709 m .67772 .5203 L .67852 .5195 L F
.26 0 .31 r
.61904 .58307 m .61898 .58528 L .61685 .58588 L F
.101 0 .376 r
.62105 .57978 m .62074 .58199 L .61904 .58307 L F
.039 0 .26 r
.62074 .58199 m .61898 .58528 L .61904 .58307 L F
.62 .24 .301 r
.40318 .65499 m .40557 .65538 L .40694 .65329 L F
.4 0 .077 r
.40557 .65538 m .40932 .65343 L .40694 .65329 L F
.761 .268 0 r
.53531 .77124 m .53589 .77288 L .53394 .7705 L F
.53633 .77263 m .53722 .77384 L .53589 .77288 L F
.554 .83 .997 r
.53589 .77288 m .53722 .77384 L .53968 .77316 L F
.568 0 0 r
.53869 .77413 m .5356 .77304 L .53589 .77288 L F
.5356 .77304 m .53452 .77266 L .53589 .77288 L F
.761 .268 0 r
.53531 .77124 m .53633 .77263 L .53589 .77288 L F
.565 .713 .941 r
.70009 .48568 m .70386 .48733 L .70317 .48564 L F
.575 .762 .967 r
.70386 .48733 m .70509 .48517 L .70317 .48564 L F
.70386 .48733 m .70614 .48686 L .70509 .48517 L F
.677 .704 .868 r
.24799 .63879 m .24938 .64039 L .25166 .63946 L F
.094 0 0 r
.28303 .58405 m .28476 .58412 L .28642 .58387 L F
.245 .758 .769 r
.28642 .58387 m .28693 .58357 L .28823 .58371 L F
.28642 .58387 m .28476 .58412 L .28693 .58357 L F
.38 0 0 r
.72233 .51864 m .72133 .51946 L .71902 .51911 L F
.72233 .51864 m .71902 .51911 L .719 .51909 L F
.719 .51909 m .71902 .51911 L .71896 .5191 L F
.727 .314 .265 r
.72133 .51946 m .71749 .51791 L .71896 .5191 L F
.72133 .51946 m .72016 .51982 L .71749 .51791 L F
0 .185 .648 r
.71749 .51791 m .71992 .51965 L .71744 .51771 L F
.71992 .51965 m .72016 .51982 L .72 .5197 L F
.71992 .51965 m .72 .5197 L .71744 .51771 L F
.452 0 0 r
.72473 .51816 m .72133 .51946 L .72233 .51864 L F
.946 .934 .753 r
.59413 .56546 m .59227 .56883 L .59321 .56938 L F
.985 .733 .344 r
.5925 .571 m .59321 .56938 L .59227 .56883 L F
.5925 .571 m .59328 .57167 L .59321 .56938 L F
0 0 0 r
.7401 .58856 m .73953 .59021 L .74006 .58841 L F
.7401 .58856 m .73889 .59171 L .73953 .59021 L F
.811 .848 .877 r
.74165 .58548 m .7401 .58856 L .74006 .58841 L F
.74165 .58548 m .74297 .58622 L .7401 .58856 L F
.949 .593 .241 r
.56759 .75021 m .56813 .74877 L .56658 .74834 L F
.56759 .75021 m .56873 .75112 L .56813 .74877 L F
.552 .469 .715 r
.38073 .66749 m .38285 .66705 L .38224 .66423 L F
.542 .416 .658 r
.38073 .66749 m .38318 .66962 L .38285 .66705 L F
.38073 .66749 m .38104 .67013 L .38318 .66962 L F
.313 .297 .681 r
.53297 .8036 m .53167 .80558 L .5331 .80705 L F
0 0 0 r
.48343 .81265 m .48511 .81095 L .48341 .8126 L F
.48405 .81228 m .48511 .81095 L .48343 .81265 L F
.324 0 0 r
.48586 .812 m .48511 .81095 L .48356 .81289 L F
.388 .782 .987 r
.48456 .81135 m .48514 .81164 L .48309 .81177 L F
.48514 .81164 m .48586 .812 L .48469 .8119 L F
.48514 .81164 m .48469 .8119 L .48309 .81177 L F
0 0 0 r
.48356 .81289 m .48405 .81228 L .48343 .81265 L F
.783 .684 .755 r
.4837 .80738 m .48511 .81095 L .48681 .80768 L F
.016 0 .357 r
.48802 .8127 m .48511 .81095 L .48745 .81112 L F
.324 0 0 r
.48586 .812 m .48745 .81112 L .48511 .81095 L F
.758 .714 .811 r
.68954 .51637 m .69069 .51908 L .6886 .51899 L F
.68954 .51637 m .6886 .51899 L .68827 .51847 L F
.68954 .51637 m .68797 .51896 L .68758 .51753 L F
.564 .934 .811 r
.68819 .51674 m .68954 .51637 L .68758 .51753 L F
.08 .357 .827 r
.68819 .51674 m .68941 .51899 L .68775 .51767 L F
.68762 .51747 m .68775 .51767 L .68758 .51753 L F
.68819 .51674 m .68775 .51767 L .68762 .51747 L F
.758 .714 .811 r
.68827 .51847 m .6886 .51899 L .68797 .51896 L F
.002 .578 .736 r
.68941 .51899 m .69069 .51908 L .68797 .51896 L F
.767 .681 .768 r
.68797 .51896 m .69069 .51908 L .68797 .52175 L F
.521 .587 .862 r
.69167 .51785 m .69069 .51908 L .68954 .51637 L F
.754 .981 .913 r
.68941 .51899 m .69069 .51908 L .69167 .51785 L F
.983 .82 .421 r
.52402 .68516 m .52429 .68653 L .52473 .68432 L F
.668 .474 .613 r
.41291 .67005 m .41057 .67272 L .4106 .67029 L F
.792 .979 .699 r
.65122 .51377 m .64921 .51632 L .64967 .51486 L F
.539 .1 .155 r
.47772 .7939 m .47994 .79543 L .47829 .7957 L F
.47772 .7939 m .48128 .79368 L .47994 .79543 L F
.55 .459 .704 r
.40941 .6812 m .4099 .68357 L .40774 .68395 L F
.899 .908 .821 r
.72198 .49065 m .71996 .49356 L .7189 .49244 L F
.984 .856 .634 r
.7189 .49244 m .71996 .49356 L .71933 .49471 L F
.53 .192 .338 r
.44069 .69211 m .44311 .69199 L .44402 .6896 L F
.421 .087 .291 r
.44402 .6896 m .44529 .6915 L .44619 .68922 L F
.44402 .6896 m .44311 .69199 L .44529 .6915 L F
.426 .662 .959 r
.69921 .50419 m .70165 .50492 L .70052 .50326 L F
.543 .345 .562 r
.69135 .51037 m .69379 .51188 L .69134 .51266 L F
.69135 .51037 m .69379 .51188 L .69134 .51266 L F
.608 .85 .99 r
.68587 .53903 m .68721 .5373 L .68478 .53776 L F
.68587 .53903 m .68829 .5383 L .68721 .5373 L F
0 0 .281 r
.4847 .79662 m .48468 .79848 L .48462 .79661 L F
.57 .235 .362 r
.46963 .69236 m .46713 .69502 L .4649 .69483 L F
.616 .295 .403 r
.47045 .69428 m .46963 .69236 L .47068 .69257 L F
.47045 .69428 m .46713 .69502 L .46963 .69236 L F
.779 .65 .72 r
.62839 .54397 m .62534 .54108 L .62702 .54101 L F
.62839 .54397 m .62502 .54356 L .62534 .54108 L F
.368 .837 .852 r
.6375 .4789 m .63914 .47814 L .64035 .47803 L F
.403 .14 .397 r
.36815 .61061 m .3675 .6135 L .36578 .61271 L F
.432 .095 .292 r
.36578 .61271 m .36681 .61516 L .36464 .61558 L F
.36578 .61271 m .3675 .6135 L .36681 .61516 L F
.648 .244 .265 r
.53176 .78472 m .53547 .78446 L .53382 .78693 L F
.658 .215 .188 r
.53547 .78446 m .53629 .78681 L .53382 .78693 L F
.53547 .78446 m .53747 .78527 L .53629 .78681 L F
.438 .412 .732 r
.63146 .50902 m .63059 .51289 L .62953 .51026 L F
.63146 .50902 m .63267 .51245 L .63059 .51289 L F
.645 .402 .536 r
.60606 .58892 m .60605 .59111 L .60402 .59107 L F
.546 .322 .527 r
.60606 .58892 m .60842 .5907 L .60605 .59111 L F
.474 .828 .996 r
.48209 .78784 m .4862 .78812 L .48509 .78619 L F
0 .172 .704 r
.48509 .78619 m .4862 .78812 L .4868 .7873 L F
0 .167 .701 r
.4868 .7873 m .4862 .78812 L .4882 .79024 L F
.493 .472 .762 r
.51429 .77365 m .51553 .76987 L .51523 .77182 L F
.461 .1 .264 r
.29922 .60523 m .29579 .60755 L .2971 .60552 L F
.607 .556 .772 r
.78794 .6056 m .78469 .60279 L .78459 .60519 L F
0 0 .174 r
.78459 .60519 m .78469 .60279 L .78533 .60069 L F
0 0 0 r
.55359 .71202 m .55554 .70894 L .55338 .7094 L F
.611 .789 .967 r
.78044 .58568 m .77977 .58455 L .77746 .58523 L F
.435 .341 .65 r
.5166 .66375 m .51715 .66777 L .51512 .66761 L F
.42 .424 .758 r
.51715 .66777 m .51782 .66947 L .51512 .66761 L F
.451 .423 .736 r
.51782 .66947 m .51637 .67095 L .51512 .66761 L F
.298 .047 .355 r
.55806 .70384 m .56 .70324 L .56039 .70104 L F
.413 .134 .377 r
.55752 .70588 m .56 .70324 L .55806 .70384 L F
.473 .756 .992 r
.32618 .58809 m .32563 .58956 L .32416 .58854 L F
.32618 .58809 m .32781 .58935 L .32563 .58956 L F
.975 .925 .646 r
.59893 .71527 m .59732 .71666 L .59795 .71721 L F
0 0 .427 r
.60011 .71154 m .59893 .71527 L .59704 .71259 L F
.60011 .71154 m .6002 .71431 L .59893 .71527 L F
0 0 0 r
.6002 .71431 m .59732 .71666 L .59893 .71527 L F
.829 .711 .734 r
.59507 .70192 m .5927 .70356 L .59566 .70058 L F
0 .119 .668 r
.59566 .70058 m .59788 .70363 L .59507 .70192 L F
.535 .342 .565 r
.41057 .67272 m .40827 .67556 L .40817 .6731 L F
.903 .779 .714 r
.58826 .69252 m .58649 .69233 L .58741 .68973 L F
.771 .278 .047 r
.58826 .69252 m .58868 .69442 L .58649 .69233 L F
.58826 .69252 m .59027 .69474 L .58868 .69442 L F
.311 .795 .896 r
.27994 .65235 m .2767 .65259 L .278 .65266 L F
.386 .007 .191 r
.56527 .69878 m .568 .69751 L .56562 .69805 L F
.574 .26 .399 r
.6815 .5312 m .68395 .53154 L .6801 .52918 L F
.6815 .5312 m .68387 .53223 L .68395 .53154 L F
.455 .253 .516 r
.52238 .76847 m .52236 .77079 L .52034 .77126 L F
.397 .223 .524 r
.52236 .77079 m .52049 .7736 L .52034 .77126 L F
.4 .09 .319 r
.25528 .59375 m .25791 .59141 L .25601 .59189 L F
.113 .624 .894 r
.57071 .75743 m .5715 .75785 L .57128 .75757 L F
.858 .742 .225 r
.57071 .75743 m .57042 .76252 L .5715 .75785 L F
.168 .456 .883 r
.4952 .79006 m .49186 .7879 L .49352 .78739 L F
.395 .104 .348 r
.54051 .73004 m .5401 .73147 L .54226 .72969 L F
.799 .574 .597 r
.70052 .50326 m .70402 .50431 L .70437 .50077 L F
.511 .319 .557 r
.70437 .50077 m .70634 .50358 L .70614 .50112 L F
.70437 .50077 m .70402 .50431 L .70634 .50358 L F
.933 .802 .34 r
.6276 .53218 m .62729 .53127 L .62795 .52995 L F
0 0 .391 r
.62795 .52995 m .62768 .52899 L .62672 .52698 L F
.922 .808 .341 r
.62795 .52995 m .62729 .53127 L .62768 .52899 L F
.69 .937 .964 r
.31078 .63233 m .30901 .63378 L .30992 .63238 L F
.604 .937 .95 r
.68829 .5383 m .6911 .53752 L .69052 .53741 L F
.518 .916 .884 r
.69052 .53741 m .6911 .53752 L .69427 .53624 L F
.466 .558 .865 r
.41277 .68915 m .41217 .69223 L .41187 .69053 L F
.41277 .68915 m .41426 .69195 L .41217 .69223 L F
.62 .662 .869 r
.75631 .60981 m .75833 .60736 L .75596 .60818 L F
.75631 .60981 m .75943 .60951 L .75833 .60736 L F
.64 .337 .441 r
.48468 .79848 m .48724 .79863 L .48462 .79661 L F
.356 .627 .955 r
.31125 .58601 m .31101 .58761 L .30916 .58636 L F
.31125 .58601 m .31281 .58777 L .31101 .58761 L F
0 0 0 r
.45281 .65785 m .45135 .65859 L .45398 .65603 L F
.45281 .65785 m .45114 .65884 L .45135 .65859 L F
.77 .649 .729 r
.59497 .69472 m .59667 .69777 L .59641 .69589 L F
.769 .705 .791 r
.50049 .65356 m .49789 .65619 L .50117 .65644 L F
.68 .649 .813 r
.50049 .65356 m .50117 .65644 L .50358 .65606 L F
.586 .489 .712 r
.50117 .65644 m .50377 .65832 L .50358 .65606 L F
.50117 .65644 m .50154 .65888 L .50377 .65832 L F
.513 .41 .675 r
.24444 .60804 m .24603 .6051 L .2445 .60568 L F
.474 .828 .996 r
.48209 .78784 m .48509 .78619 L .4826 .78519 L F
0 .172 .704 r
.48509 .78619 m .4868 .7873 L .48662 .78454 L F
.816 .71 .748 r
.54982 .78602 m .54988 .7826 L .5495 .78444 L F
.316 0 .145 r
.33733 .64064 m .33642 .6391 L .33836 .63867 L F
.33733 .64064 m .33522 .64122 L .33642 .6391 L F
.766 .678 .766 r
.56602 .59421 m .56727 .5972 L .56385 .59686 L F
.738 .497 .565 r
.56808 .59914 m .56385 .59686 L .56727 .5972 L F
.684 .616 .773 r
.56948 .59577 m .56727 .5972 L .56602 .59421 L F
.663 .405 .519 r
.56727 .5972 m .56935 .59948 L .56808 .59914 L F
.998 .792 .498 r
.54301 .77582 m .54423 .77405 L .54364 .77688 L F
.211 0 0 r
.5469 .77327 m .54423 .77405 L .54301 .77582 L F
.922 .937 .797 r
.56912 .77044 m .57019 .76895 L .56921 .76807 L F
.174 .496 .906 r
.77258 .57732 m .77213 .57746 L .76884 .57474 L F
.685 .24 .188 r
.50032 .76086 m .50261 .76258 L .49938 .76207 L F
.948 .629 .397 r
.50032 .76086 m .49938 .76207 L .49935 .76036 L F
.529 .264 .457 r
.38429 .6609 m .38696 .65825 L .38439 .65881 L F
.893 .967 .647 r
.59703 .55812 m .59872 .55521 L .59741 .55616 L F
.791 .89 .474 r
.60028 .55206 m .59924 .55347 L .59872 .55521 L F
.816 .969 .656 r
.59872 .55521 m .59924 .55347 L .59741 .55616 L F
.572 .37 .569 r
.33728 .6168 m .33965 .6165 L .33977 .61412 L F
.33728 .6168 m .33965 .6165 L .33977 .61412 L F
.388 .22 .529 r
.33977 .61412 m .34142 .61567 L .34152 .61342 L F
.33977 .61412 m .33965 .6165 L .34142 .61567 L F
.448 .193 .434 r
.58651 .71979 m .58731 .72036 L .58759 .7182 L F
.499 .34 .596 r
.58759 .7182 m .58999 .71769 L .58987 .71483 L F
.418 .126 .36 r
.5893 .71957 m .58759 .7182 L .58731 .72036 L F
.5893 .71957 m .58999 .71769 L .58759 .7182 L F
.81 .781 .826 r
.67617 .48365 m .67904 .48297 L .67844 .48221 L F
.317 .721 .979 r
.67904 .48297 m .68029 .48215 L .67844 .48221 L F
.67904 .48297 m .68086 .48284 L .68029 .48215 L F
.562 .25 .397 r
.37068 .60844 m .37249 .60983 L .37024 .61024 L F
.37068 .60844 m .37325 .60842 L .37249 .60983 L F
.642 .577 .767 r
.50154 .65888 m .50472 .6614 L .50377 .65832 L F
.72 .409 .451 r
.52874 .78307 m .53176 .78472 L .52839 .78438 L F
0 0 0 r
.47994 .79543 m .48128 .79368 L .48238 .79315 L F
.683 .548 .695 r
.48469 .7736 m .48267 .77656 L .48208 .77363 L F
.48469 .7736 m .48543 .77684 L .48267 .77656 L F
.457 .133 .327 r
.48543 .77684 m .48194 .77922 L .48267 .77656 L F
.48543 .77684 m .48482 .77882 L .48194 .77922 L F
.544 .399 .634 r
.48194 .77922 m .48482 .77882 L .48283 .77565 L F
0 0 .463 r
.48208 .77363 m .48217 .77407 L .48241 .77497 L F
.48217 .77407 m .48267 .77656 L .48241 .77497 L F
.754 .592 .676 r
.48208 .77363 m .48043 .77717 L .48267 .77656 L F
.48208 .77363 m .48043 .77717 L .48267 .77656 L F
0 0 .174 r
.48267 .77656 m .48125 .77961 L .48071 .77798 L F
.48267 .77656 m .48071 .77798 L .48178 .7768 L F
.48178 .7768 m .48071 .77798 L .48043 .77717 L F
.632 .437 .6 r
.48053 .78074 m .48267 .77656 L .48043 .77717 L F
.544 .399 .634 r
.48194 .77922 m .48241 .77497 L .48267 .77656 L F
.48226 .77627 m .48264 .77586 L .48241 .77497 L F
.48264 .77586 m .48283 .77565 L .48241 .77497 L F
.48194 .77922 m .48283 .77565 L .48226 .77627 L F
0 0 .335 r
.48201 .78083 m .48193 .78161 L .48125 .77961 L F
.371 .698 .983 r
.48179 .78092 m .48183 .78199 L .48201 .78083 L F
.48115 .78119 m .48183 .78199 L .48179 .78092 L F
0 0 .278 r
.48125 .77961 m .4818 .78121 L .48183 .78199 L F
.4818 .78121 m .48193 .78161 L .48183 .78199 L F
.395 .491 .84 r
.66288 .52687 m .66417 .52516 L .66098 .5242 L F
.66288 .52687 m .66504 .52706 L .66417 .52516 L F
.571 .301 .468 r
.45694 .69544 m .45906 .69712 L .45699 .69727 L F
.585 .295 .441 r
.45932 .69537 m .45906 .69712 L .45694 .69544 L F
0 .212 .73 r
.53966 .74848 m .54152 .75081 L .54024 .74806 L F
.452 .203 .444 r
.56 .70324 m .56238 .70046 L .56039 .70104 L F
.776 .581 .635 r
.51057 .80761 m .5114 .80517 L .50711 .80458 L F
.31 .104 .43 r
.51242 .80462 m .5114 .80517 L .51057 .80761 L F
.204 0 0 r
.49494 .69577 m .49421 .69562 L .49142 .69489 L F
.361 .594 .934 r
.49494 .69577 m .49563 .69443 L .49421 .69562 L F
.49494 .69577 m .49699 .69605 L .49563 .69443 L F
.526 .347 .581 r
.37883 .67262 m .38096 .6723 L .38104 .67013 L F
.67 .452 .58 r
.51824 .6612 m .51622 .66147 L .51624 .65901 L F
.819 .536 .509 r
.64074 .50419 m .63943 .50601 L .63933 .50378 L F
.64074 .50419 m .64324 .50721 L .63943 .50601 L F
.503 .827 1 r
.48618 .80686 m .4837 .80738 L .48681 .80768 L F
.466 .262 .518 r
.5246 .7703 m .52236 .77079 L .52238 .76847 L F
.165 .249 .705 r
.65427 .49459 m .65294 .49637 L .65223 .49285 L F
0 0 .493 r
.65367 .49653 m .65294 .49637 L .65427 .49459 L F
.65367 .49653 m .65388 .49835 L .65294 .49637 L F
.775 .49 .504 r
.72107 .50125 m .71699 .49895 L .71879 .50078 L F
.597 .356 .522 r
.48694 .78241 m .48926 .78239 L .48858 .78015 L F
.544 .431 .675 r
.48919 .77669 m .48858 .78015 L .49191 .77898 L F
.596 .434 .633 r
.48926 .78239 m .49191 .77898 L .48858 .78015 L F
.466 .767 .996 r
.33477 .59045 m .33115 .58993 L .33377 .58985 L F
.364 0 0 r
.33377 .58985 m .337 .59045 L .33477 .59045 L F
.274 0 0 r
.26561 .58832 m .26771 .58797 L .26937 .58653 L F
.273 0 0 r
.26937 .58653 m .27092 .58692 L .2715 .58623 L F
.26937 .58653 m .26771 .58797 L .27092 .58692 L F
.42 .324 .64 r
.52176 .68927 m .52198 .69158 L .51992 .68992 L F
.426 .324 .636 r
.52198 .69158 m .52025 .69253 L .51992 .68992 L F
.778 .672 .746 r
.5495 .78444 m .55036 .78842 L .54683 .78764 L F
.776 .409 .361 r
.54683 .78764 m .55036 .78842 L .5472 .79041 L F
.174 .253 .706 r
.55286 .78908 m .55036 .78842 L .5495 .78444 L F
.304 0 0 r
.5472 .79041 m .55036 .78842 L .55286 .78908 L F
.81 .594 .61 r
.64378 .4841 m .64641 .48226 L .6456 .48128 L F
.64378 .4841 m .64669 .48549 L .64641 .48226 L F
.461 .452 .762 r
.74912 .60211 m .7501 .60559 L .75181 .60374 L F
.439 .418 .739 r
.7501 .60559 m .75234 .60567 L .75181 .60374 L F
.271 .46 .862 r
.74162 .59466 m .74316 .59354 L .74128 .59306 L F
.29 .496 .885 r
.74162 .59466 m .74461 .59611 L .74316 .59354 L F
.512 .21 .391 r
.59237 .59415 m .58929 .59679 L .59063 .59374 L F
.691 .608 .759 r
.48832 .65367 m .48967 .65695 L .49202 .6561 L F
.466 .686 .962 r
.31734 .66327 m .31861 .6646 L .3194 .66304 L F
.31734 .66327 m .31861 .6646 L .3194 .66304 L F
.761 .827 .904 r
.25044 .63604 m .25417 .63583 L .25228 .6343 L F
.316 .494 .875 r
.25417 .63583 m .25441 .63371 L .25228 .6343 L F
.25417 .63583 m .25575 .63604 L .25441 .63371 L F
0 0 .423 r
.25417 .63583 m .2554 .63839 L .25575 .63604 L F
.84 .593 .565 r
.72335 .50333 m .72107 .50125 L .72377 .50214 L F
.222 .129 .533 r
.47008 .78233 m .47158 .77901 L .46922 .77987 L F
.791 .89 .474 r
.60028 .55206 m .60024 .55171 L .59924 .55347 L F
.507 .246 .454 r
.30514 .60273 m .30679 .60409 L .30466 .60428 L F
.598 .21 .279 r
.30761 .60307 m .30679 .60409 L .30514 .60273 L F
.708 .453 .537 r
.57288 .59722 m .57288 .5997 L .56935 .59948 L F
.648 .404 .536 r
.57288 .59722 m .57481 .59923 L .57288 .5997 L F
.35 .75 .984 r
.29992 .58532 m .30144 .58609 L .29784 .58543 L F
.449 .785 .998 r
.30194 .58494 m .30144 .58609 L .29992 .58532 L F
.30194 .58494 m .30351 .5858 L .30144 .58609 L F
.405 .091 .316 r
.33027 .62454 m .33142 .62668 L .33217 .6239 L F
.33027 .62454 m .32931 .62723 L .33142 .62668 L F
.313 .794 .908 r
.31215 .64969 m .31326 .64913 L .31151 .64912 L F
.31215 .64969 m .31485 .64928 L .31326 .64913 L F
.645 .371 .49 r
.58078 .59817 m .5809 .60183 L .57868 .60177 L F
.567 .326 .509 r
.5845 .59677 m .58078 .59817 L .58186 .59745 L F
.5845 .59677 m .58487 .59897 L .58078 .59817 L F
.603 .339 .49 r
.58463 .60086 m .58078 .59817 L .58487 .59897 L F
.58463 .60086 m .5809 .60183 L .58078 .59817 L F
.452 .469 .785 r
.51575 .64993 m .51487 .65354 L .51377 .65022 L F
.51575 .64993 m .51688 .65322 L .51487 .65354 L F
.453 .47 .786 r
.51688 .65322 m .51749 .6552 L .51487 .65354 L F
.369 0 0 r
.31534 .63239 m .31887 .63181 L .31713 .63156 L F
.841 .896 .878 r
.72281 .50531 m .72058 .50752 L .71946 .5053 L F
.972 .753 .547 r
.72058 .50752 m .719 .50886 L .71946 .5053 L F
.72058 .50752 m .72028 .51002 L .719 .50886 L F
.544 .6 .86 r
.63498 .49477 m .63203 .49554 L .63316 .49367 L F
.752 .596 .683 r
.5445 .74371 m .54662 .74553 L .54638 .74314 L F
.879 .484 .028 r
.5926 .6894 m .59346 .69201 L .59443 .6926 L F
.952 .74 .58 r
.59346 .69201 m .59497 .69472 L .59443 .6926 L F
.778 .602 .66 r
.47644 .77857 m .48043 .77717 L .47799 .778 L F
.539 .504 .766 r
.38028 .67837 m .38311 .68112 L .38195 .67779 L F
.219 .647 .954 r
.34112 .59037 m .34074 .5911 L .33929 .59018 L F
.34112 .59037 m .34265 .59136 L .34074 .5911 L F
.975 .67 .359 r
.55566 .76513 m .55686 .76784 L .55696 .76559 L F
0 0 0 r
.55919 .76266 m .55696 .76559 L .55915 .76525 L F
.466 .196 .419 r
.55696 .76559 m .55686 .76784 L .55915 .76525 L F
.311 0 0 r
.43301 .69314 m .43416 .69414 L .43524 .69262 L F
.43301 .69314 m .43168 .6947 L .43416 .69414 L F
.625 .59 .794 r
.50377 .65832 m .50472 .6614 L .50701 .65917 L F
.629 .597 .798 r
.50472 .6614 m .50904 .66011 L .50701 .65917 L F
.337 .545 .907 r
.56185 .71445 m .56027 .71563 L .55946 .71448 L F
.56185 .71445 m .56421 .71759 L .56027 .71563 L F
.208 0 .178 r
.61898 .58528 m .61633 .5877 L .61685 .58588 L F
.436 .289 .582 r
.5583 .5911 m .55836 .5914 L .55884 .58858 L F
.884 .716 .668 r
.55884 .58858 m .55836 .59135 L .55602 .59055 L F
.55836 .59135 m .55836 .5914 L .55832 .59138 L F
.55836 .59135 m .55832 .59138 L .55602 .59055 L F
.815 .514 .48 r
.55836 .5914 m .55872 .59323 L .55556 .59292 L F
.835 .541 0 r
.5583 .5911 m .55872 .59323 L .55836 .5914 L F
.782 .509 .524 r
.5612 .59141 m .55872 .59323 L .55835 .59136 L F
.55865 .59114 m .55835 .59136 L .5583 .5911 L F
.5612 .59141 m .55835 .59136 L .55865 .59114 L F
.5612 .59141 m .5621 .59357 L .55872 .59323 L F
.051 0 0 r
.44019 .6479 m .44247 .64765 L .44346 .64735 L F
.241 .756 .773 r
.44247 .64765 m .44552 .64701 L .44346 .64735 L F
.679 .74 .897 r
.47935 .65306 m .48281 .6535 L .48275 .65265 L F
.682 .742 .896 r
.48275 .65265 m .48281 .6535 L .48518 .65268 L F
.973 .688 .424 r
.65915 .50249 m .65776 .50246 L .65816 .50093 L F
.65915 .50249 m .6594 .50429 L .65776 .50246 L F
.455 .292 .57 r
.33728 .6168 m .33914 .61865 L .33965 .6165 L F
.33728 .6168 m .33727 .61928 L .33914 .61865 L F
.983 .698 .359 r
.78055 .59888 m .78109 .60242 L .77987 .59925 L F
.578 .701 .926 r
.69312 .47906 m .68943 .47748 L .69204 .47755 L F
.605 .719 .925 r
.6945 .47691 m .69312 .47906 L .69204 .47755 L F
.6945 .47691 m .69548 .47845 L .69312 .47906 L F
.383 0 0 r
.50363 .81655 m .505 .81724 L .50323 .81734 L F
.705 .774 .285 r
.24893 .6344 m .24815 .63655 L .24857 .63517 L F
.512 .802 .998 r
.24815 .63655 m .25044 .63604 L .24857 .63517 L F
.721 .642 .769 r
.24799 .63879 m .25044 .63604 L .24815 .63655 L F
0 0 0 r
.31321 .60102 m .31162 .60196 L .30972 .60252 L F
.237 0 0 r
.31503 .60119 m .31162 .60196 L .31321 .60102 L F
0 0 0 r
.44814 .64569 m .44991 .64552 L .45169 .64515 L F
.368 .834 .789 r
.45169 .64515 m .4522 .64472 L .4539 .64471 L F
.45169 .64515 m .44991 .64552 L .4522 .64472 L F
.518 .916 .884 r
.69052 .53741 m .69427 .53624 L .69256 .53648 L F
.585 .946 .878 r
.69561 .53498 m .69427 .53624 L .69608 .53479 L F
.69561 .53498 m .69256 .53648 L .69427 .53624 L F
.498 .225 .43 r
.36974 .61304 m .36815 .61061 L .37024 .61024 L F
.36974 .61304 m .3675 .6135 L .36815 .61061 L F
.412 0 0 r
.45222 .68615 m .45093 .68633 L .45446 .68664 L F
.872 .751 .727 r
.24939 .62782 m .24932 .63103 L .24581 .62982 L F
.805 .999 .809 r
.24932 .63103 m .2474 .63162 L .24581 .62982 L F
.24932 .63103 m .24668 .63326 L .2474 .63162 L F
.757 .415 .406 r
.53279 .77897 m .53293 .77732 L .52902 .77631 L F
.709 .35 .366 r
.53569 .77906 m .53293 .77732 L .53279 .77897 L F
.939 .808 .689 r
.56252 .57973 m .56395 .58061 L .56326 .58281 L F
.515 .915 .852 r
.54544 .75961 m .5442 .7607 L .54631 .76022 L F
.54544 .75961 m .54185 .76131 L .5442 .7607 L F
.611 .469 .664 r
.38224 .66423 m .38429 .6609 L .38253 .66163 L F
.503 .32 .566 r
.49621 .79882 m .4939 .80161 L .49427 .7987 L F
0 0 .396 r
.65776 .49287 m .65669 .4904 L .65763 .49048 L F
.517 .847 .997 r
.67455 .47744 m .67686 .47688 L .67805 .47766 L F
.507 .807 .999 r
.67931 .47625 m .67805 .47766 L .67686 .47688 L F
.67931 .47625 m .68064 .47723 L .67805 .47766 L F
.806 .595 .617 r
.48951 .80483 m .48618 .80686 L .48706 .80522 L F
.838 .984 .871 r
.37852 .7009 m .37555 .70246 L .37696 .69994 L F
.37852 .7009 m .37635 .70262 L .37555 .70246 L F
.501 .681 .947 r
.37736 .69898 m .37852 .7009 L .37696 .69994 L F
.37736 .69898 m .38077 .70051 L .37852 .7009 L F
.727 .85 .939 r
.74537 .58498 m .74297 .58622 L .74165 .58548 L F
.74 .323 .258 r
.56923 .7562 m .56982 .75564 L .57031 .75438 L F
.899 .839 .778 r
.54598 .80086 m .54742 .79874 L .54566 .79866 L F
.407 .132 .38 r
.3629 .61655 m .36028 .619 L .36077 .61709 L F
.504 .237 .442 r
.42438 .66737 m .42424 .6694 L .42184 .66953 L F
.635 .345 .461 r
.42438 .66737 m .42676 .66942 L .42424 .6694 L F
.59 .358 .534 r
.42699 .6671 m .42676 .66942 L .42438 .66737 L F
.624 .621 .827 r
.65175 .51118 m .65122 .51377 L .65387 .51287 L F
.665 .197 .132 r
.65122 .51377 m .64967 .51486 L .65262 .51472 L F
.536 .354 .581 r
.65122 .51377 m .65262 .51472 L .65387 .51287 L F
.797 .758 .817 r
.48543 .77684 m .48919 .77669 L .48779 .77649 L F
.579 .098 .077 r
.49137 .77635 m .48779 .77649 L .48919 .77669 L F
.544 .431 .675 r
.48919 .77669 m .49191 .77898 L .49137 .77635 L F
.69 .805 .936 r
.47356 .65584 m .47502 .65716 L .47718 .65605 L F
.222 .281 .713 r
.54752 .76277 m .54826 .7599 L .54631 .76022 L F
.54752 .76277 m .54919 .76194 L .54826 .7599 L F
0 0 .192 r
.54752 .76277 m .54825 .76385 L .54919 .76194 L F
.556 .671 .914 r
.55127 .79561 m .55158 .79663 L .54906 .79672 L F
.55127 .79561 m .55158 .79663 L .54906 .79672 L F
.712 .502 .602 r
.67568 .53264 m .67351 .53512 L .6716 .53183 L F
.67568 .53264 m .67618 .53498 L .67351 .53512 L F
0 0 .085 r
.67771 .52971 m .67683 .53179 L .67646 .53151 L F
.992 .88 .561 r
.67664 .53012 m .67683 .53179 L .67771 .52971 L F
.91 .727 .641 r
.67664 .53012 m .67706 .53196 L .67683 .53179 L F
.67706 .53196 m .67767 .53474 L .67683 .53179 L F
0 0 .085 r
.67646 .53151 m .67683 .53179 L .67568 .53264 L F
.372 .322 .673 r
.67683 .53179 m .67618 .53498 L .67568 .53264 L F
.259 .452 .86 r
.73889 .59171 m .74128 .59306 L .73953 .59021 L F
.429 .392 .715 r
.62916 .49798 m .62989 .50134 L .62801 .50161 L F
.439 .509 .834 r
.62989 .50134 m .63032 .50258 L .62801 .50161 L F
.764 .845 .913 r
.71759 .48308 m .72001 .48151 L .71647 .48155 L F
.513 0 0 r
.7786 .57945 m .78254 .58255 L .77943 .58047 L F
.251 .673 .963 r
.71719 .5103 m .71693 .51078 L .71423 .51005 L F
.71719 .5103 m .71423 .51005 L .71446 .51235 L F
.602 .936 .739 r
.7174 .50991 m .71719 .5103 L .71589 .5109 L F
.719 .50886 m .71719 .5103 L .7174 .50991 L F
.251 .673 .963 r
.71719 .5103 m .71762 .51096 L .71693 .51078 L F
.654 .81 .958 r
.719 .50886 m .71762 .51096 L .71719 .5103 L F
.719 .50886 m .72028 .51002 L .71762 .51096 L F
.506 .246 .454 r
.29379 .60811 m .29114 .61058 L .29178 .6087 L F
.555 .098 .122 r
.41726 .65072 m .41921 .65194 L .4207 .65039 L F
.26 0 0 r
.41921 .65194 m .423 .65058 L .4207 .65039 L F
0 0 0 r
.70372 .52927 m .70118 .53248 L .70107 .5321 L F
.95 .934 .593 r
.5677 .77402 m .56912 .77044 L .56839 .77036 L F
.922 .937 .797 r
.56912 .77044 m .56921 .76807 L .56839 .77036 L F
.642 .613 .806 r
.4939 .80161 m .49544 .80473 L .49548 .80423 L F
.267 .11 .474 r
.49722 .80168 m .4968 .80449 L .49544 .80473 L F
.302 .252 .635 r
.4968 .80449 m .49724 .80683 L .49544 .80473 L F
.663 .764 .925 r
.72575 .48552 m .72839 .48702 L .72294 .48817 L F
0 0 0 r
.72294 .48817 m .7225 .48863 L .72575 .48552 L F
.925 .958 .783 r
.69972 .51215 m .70035 .51288 L .69788 .51655 L F
.721 .934 .958 r
.70278 .51122 m .70035 .51288 L .69972 .51215 L F
.206 .571 .94 r
.35774 .59353 m .35615 .59327 L .35398 .59145 L F
.591 .626 .855 r
.47089 .65287 m .47123 .654 L .47333 .65272 L F
.479 .384 .67 r
.47123 .654 m .47356 .65584 L .47333 .65272 L F
.563 .374 .583 r
.38974 .65612 m .392 .65582 L .39205 .65334 L F
.446 .28 .561 r
.39205 .65334 m .39398 .65517 L .39427 .65287 L F
.428 .175 .427 r
.55589 .76284 m .55566 .76513 L .55374 .76408 L F
.711 .264 .188 r
.51005 .79365 m .51422 .79476 L .51173 .79562 L F
.901 .485 .134 r
.51523 .79332 m .5128 .79019 L .51255 .79301 L F
.208 .017 .388 r
.5135 .79291 m .51255 .79301 L .51345 .79227 L F
.858 .985 .851 r
.5125 .79511 m .51422 .79476 L .51523 .79332 L F
.51173 .79562 m .51523 .79332 L .51255 .79301 L F
.208 .017 .388 r
.51365 .79471 m .51308 .79383 L .5135 .79291 L F
.51308 .79383 m .51255 .79301 L .5135 .79291 L F
.858 .985 .851 r
.51173 .79562 m .51237 .7954 L .5125 .79511 L F
.51237 .7954 m .51422 .79476 L .5125 .79511 L F
.317 .796 .908 r
.28624 .6508 m .28487 .65061 L .28238 .65105 L F
.461 .841 .986 r
.28813 .65068 m .28487 .65061 L .28624 .6508 L F
.257 0 0 r
.32156 .6303 m .3238 .62987 L .32521 .62847 L F
.135 0 0 r
.3238 .62987 m .32741 .62799 L .32521 .62847 L F
.974 .716 .299 r
.64099 .54923 m .6403 .5486 L .64098 .55217 L F
.363 .816 .939 r
.67358 .48433 m .67025 .48438 L .67019 .48191 L F
.67358 .48433 m .67278 .48392 L .67025 .48438 L F
.745 .987 .897 r
.67499 .48227 m .67358 .48433 L .67617 .48365 L F
.67499 .48227 m .67278 .48392 L .67358 .48433 L F
.399 .083 .309 r
.38696 .65825 m .38943 .658 L .38974 .65612 L F
.601 .256 .357 r
.38974 .65612 m .39181 .65785 L .392 .65582 L F
.38974 .65612 m .38943 .658 L .39181 .65785 L F
.3 .793 .772 r
.31664 .64906 m .32076 .64796 L .3189 .64854 L F
0 0 0 r
.32076 .64796 m .32097 .64836 L .3189 .64854 L F
.32076 .64796 m .32274 .64718 L .32097 .64836 L F
.59691 .52978 m .59768 .52899 L .59858 .52718 L F
.535 .171 .296 r
.59606 .5298 m .59816 .5285 L .59768 .52899 L F
0 0 0 r
.59858 .52718 m .59768 .52899 L .59942 .52772 L F
.535 .171 .296 r
.59816 .5285 m .59942 .52772 L .59768 .52899 L F
0 0 0 r
.59653 .53037 m .59768 .52899 L .59691 .52978 L F
.59858 .52718 m .59973 .52588 L .60048 .52412 L F
.59858 .52718 m .59942 .52772 L .59973 .52588 L F
.589 .464 .677 r
.61712 .54629 m .6196 .54583 L .61917 .54299 L F
.505 .545 .831 r
.37707 .60235 m .37514 .60286 L .37383 .59976 L F
.459 .356 .651 r
.37707 .60235 m .37733 .60478 L .37514 .60286 L F
.461 .356 .65 r
.37733 .60478 m .37557 .60559 L .37514 .60286 L F
.448 .608 .916 r
.50063 .79314 m .49883 .79335 L .49671 .79101 L F
.058 .247 .742 r
.50103 .79556 m .49883 .79335 L .50063 .79314 L F
.718 .578 .696 r
.57248 .59151 m .56948 .59577 L .56809 .59144 L F
.57248 .59151 m .57138 .59383 L .56948 .59577 L F
.196 0 0 r
.52314 .81015 m .52516 .80777 L .5219 .80953 L F
.873 .976 .846 r
.73059 .5132 m .73265 .51301 L .73188 .51232 L F
.73059 .5132 m .73015 .51571 L .73265 .51301 L F
.996 .793 .434 r
.73215 .50976 m .73188 .51232 L .73265 .51301 L F
.547 .804 .993 r
.52193 .65886 m .51765 .65876 L .52096 .65613 L F
.611 .558 .77 r
.52282 .6553 m .52193 .65886 L .52096 .65613 L F
.52282 .6553 m .52443 .65876 L .52193 .65886 L F
.313 0 .206 r
.52443 .65876 m .52171 .66075 L .52193 .65886 L F
.905 .857 .783 r
.56039 .58261 m .56049 .58569 L .55923 .58461 L F
.906 .836 .766 r
.56049 .58569 m .55745 .58759 L .55923 .58461 L F
.56049 .58569 m .55884 .58858 L .55745 .58759 L F
.812 .791 .833 r
.56326 .58281 m .56049 .58569 L .56039 .58261 L F
.361 .794 .616 r
.48469 .7736 m .48631 .77265 L .48804 .77125 L F
.176 0 .29 r
.49015 .76833 m .48804 .77125 L .4894 .77036 L F
0 0 0 r
.48804 .77125 m .48927 .77093 L .4894 .77036 L F
.48804 .77125 m .48631 .77265 L .48927 .77093 L F
.477 .281 .535 r
.60518 .57681 m .60311 .57491 L .60279 .57714 L F
.60518 .57681 m .60529 .57416 L .60311 .57491 L F
.365 0 .16 r
.45632 .65526 m .45281 .65785 L .45398 .65603 L F
.668 .474 .613 r
.41291 .67005 m .41334 .67287 L .41057 .67272 L F
.408 .13 .376 r
.4162 .66992 m .41334 .67287 L .41291 .67005 L F
.773 .759 .84 r
.71134 .47391 m .7134 .47677 L .70947 .47587 L F
.726 .791 .904 r
.70947 .47587 m .7134 .47677 L .71071 .47718 L F
.113 .556 .917 r
.71134 .47391 m .71533 .47575 L .7134 .47677 L F
.893 .94 .574 r
.73059 .5132 m .72912 .51668 L .73015 .51571 L F
.357 .367 .734 r
.46855 .79065 m .46928 .79409 L .471 .7927 L F
.237 .234 .653 r
.46928 .79409 m .47137 .79574 L .471 .7927 L F
.46928 .79409 m .46985 .79625 L .47137 .79574 L F
.812 .558 .554 r
.64259 .47835 m .6456 .48128 L .64335 .48034 L F
.844 .494 .391 r
.66675 .49336 m .66736 .49565 L .66991 .49607 L F
.868 .722 .697 r
.66736 .49565 m .66836 .4989 L .66991 .49607 L F
.277 .341 .749 r
.75479 .59291 m .75569 .59646 L .75325 .59468 L F
.357 .411 .78 r
.38147 .68405 m .38396 .68682 L .38306 .68352 L F
.115 0 .37 r
.47035 .77036 m .47173 .7678 L .47021 .7684 L F
.291 0 0 r
.42917 .70565 m .42563 .70736 L .42709 .70606 L F
.725 .393 .417 r
.64189 .51759 m .64313 .51566 L .64196 .51595 L F
.64189 .51759 m .6454 .51794 L .64313 .51566 L F
.016 0 .104 r
.60048 .52412 m .60231 .52308 L .60278 .5213 L F
.448 .2 .444 r
.59973 .52588 m .60231 .52308 L .60048 .52412 L F
.214 .673 .946 r
.51979 .7461 m .51614 .74512 L .51743 .74611 L F
.51979 .7461 m .51614 .74512 L .51743 .74611 L F
.878 .993 .765 r
.52006 .80949 m .522 .8084 L .51929 .81213 L F
.854 .983 .696 r
.52046 .81121 m .5219 .80953 L .52072 .81013 L F
.196 0 0 r
.52314 .81015 m .5219 .80953 L .522 .8084 L F
.321 0 0 r
.5219 .80953 m .52314 .81015 L .52032 .81032 L F
.708 .26 .186 r
.52314 .81015 m .522 .8084 L .52006 .80949 L F
.52314 .81015 m .52083 .80966 L .52259 .80919 L F
.52083 .80966 m .52006 .80949 L .52089 .80939 L F
.52083 .80966 m .52089 .80939 L .52259 .80919 L F
.854 .983 .696 r
.51929 .81257 m .52046 .81121 L .52032 .81032 L F
.52046 .81121 m .52072 .81013 L .52032 .81032 L F
.447 .551 .869 r
.74482 .59779 m .74663 .59594 L .74461 .59611 L F
.74482 .59779 m .74808 .59891 L .74663 .59594 L F
.254 .721 .946 r
.33205 .58929 m .33115 .58993 L .33011 .58913 L F
.33205 .58929 m .33377 .58985 L .33115 .58993 L F
.656 .611 .792 r
.52096 .65613 m .51765 .65876 L .51749 .6552 L F
.673 .359 .435 r
.6351 .50752 m .63488 .50967 L .63146 .50902 L F
.886 .871 .818 r
.63391 .50614 m .6351 .50752 L .63713 .50447 L F
.588 .285 .423 r
.63721 .50903 m .63488 .50967 L .6351 .50752 L F
.414 0 0 r
.6349 .50738 m .6351 .50752 L .63391 .50614 L F
.6349 .50738 m .63721 .50903 L .6351 .50752 L F
.638 .758 .935 r
.76464 .58029 m .76781 .58097 L .7671 .57952 L F
.434 .737 .991 r
.76781 .58097 m .76952 .57991 L .7671 .57952 L F
.76781 .58097 m .77036 .58091 L .76952 .57991 L F
.739 .785 .89 r
.37833 .70462 m .37653 .70612 L .37934 .70642 L F
.792 .691 .753 r
.37653 .70612 m .37765 .70907 L .37934 .70642 L F
.691 .773 .914 r
.55521 .74921 m .55741 .75124 L .55327 .75111 L F
.741 .533 .612 r
.55741 .75124 m .55319 .75369 L .55327 .75111 L F
.55741 .75124 m .55726 .75391 L .55319 .75369 L F
.837 .786 .803 r
.55894 .74864 m .55741 .75124 L .55521 .74921 L F
.401 .247 .554 r
.55888 .75347 m .55726 .75391 L .55741 .75124 L F
.75 .513 .574 r
.50838 .77619 m .51195 .77396 L .50747 .7738 L F
.50838 .77619 m .51192 .77628 L .51195 .77396 L F
.603 .41 .594 r
.51192 .77628 m .51429 .77365 L .51195 .77396 L F
.102 0 0 r
.33332 .64196 m .33048 .64365 L .33138 .64271 L F
.648 .966 .818 r
.59471 .53102 m .59768 .52899 L .59653 .53037 L F
.895 .985 .796 r
.59471 .53102 m .59653 .53037 L .59441 .53312 L F
.598 .756 .954 r
.70052 .50326 m .70165 .50492 L .70402 .50431 L F
.684 .785 .927 r
.48062 .7564 m .48251 .75801 L .48414 .75685 L F
.611 .952 .911 r
.25248 .64474 m .25325 .64351 L .2543 .64176 L F
.25248 .64474 m .25231 .64432 L .25325 .64351 L F
.245 0 .136 r
.25248 .64474 m .25341 .64591 L .25231 .64432 L F
.25248 .64474 m .25139 .64685 L .25341 .64591 L F
.514 .177 .333 r
.5324 .76212 m .53472 .76214 L .53523 .76039 L F
.786 .655 .718 r
.53472 .76214 m .53778 .75964 L .53523 .76039 L F
.354 0 0 r
.63859 .49925 m .63848 .49971 L .63597 .49941 L F
.761 .442 .446 r
.63848 .49971 m .63452 .49806 L .63597 .49941 L F
.806 .569 .579 r
.63137 .50456 m .63171 .50724 L .62809 .50634 L F
.228 0 .076 r
.28668 .61347 m .28952 .61155 L .28881 .61284 L F
.071 0 .065 r
.28881 .61284 m .28952 .61155 L .29114 .61058 L F
.806 .595 .617 r
.48951 .80483 m .4894 .80738 L .48618 .80686 L F
.68 .649 .813 r
.50049 .65356 m .50358 .65606 L .5032 .65369 L F
.62 .531 .732 r
.5032 .65369 m .50358 .65606 L .50564 .65328 L F
.663 .59 .764 r
.50358 .65606 m .50669 .65602 L .50564 .65328 L F
.618 .446 .627 r
.50358 .65606 m .506 .65787 L .50669 .65602 L F
.50358 .65606 m .50377 .65832 L .506 .65787 L F
.968 .868 .473 r
.66581 .50168 m .66483 .50301 L .66527 .50334 L F
0 0 .335 r
.66669 .49858 m .66581 .50168 L .66763 .50026 L F
.66669 .49858 m .66697 .50035 L .66581 .50168 L F
.754 .669 .767 r
.66697 .50035 m .66483 .50301 L .66581 .50168 L F
.979 .726 .48 r
.52248 .78483 m .52372 .78797 L .52247 .78729 L F
.97 .67 .394 r
.52372 .78797 m .52406 .79042 L .52247 .78729 L F
.217 .35 .785 r
.52505 .78724 m .52372 .78797 L .52248 .78483 L F
.97 .67 .394 r
.52247 .78729 m .52372 .78797 L .52505 .78724 L F
.52247 .78729 m .52406 .79042 L .52372 .78797 L F
.549 .563 .821 r
.75341 .60844 m .75499 .60481 L .75234 .60567 L F
.75341 .60844 m .75596 .60818 L .75499 .60481 L F
.61 .366 .523 r
.60035 .59136 m .59789 .59347 L .59795 .59149 L F
.614 .15 .127 r
.47649 .69341 m .4751 .69477 L .47273 .69417 L F
.467 0 .021 r
.47867 .69421 m .4751 .69477 L .47649 .69341 L F
.569 .521 .761 r
.70705 .48929 m .70913 .4866 L .70614 .48686 L F
.70705 .48929 m .7099 .4889 L .70913 .4866 L F
.324 .746 .975 r
.34669 .59103 m .34623 .59183 L .34477 .59128 L F
.34669 .59103 m .34849 .59176 L .34623 .59183 L F
.123 .65 .874 r
.49419 .81582 m .4977 .81631 L .49653 .81591 L F
.49419 .81582 m .4977 .81631 L .49653 .81591 L F
.908 .949 .816 r
.49991 .81318 m .4977 .81631 L .49653 .81591 L F
.438 .649 .948 r
.4977 .81631 m .49859 .81479 L .49653 .81591 L F
.4977 .81631 m .49986 .81643 L .49859 .81479 L F
.123 .65 .874 r
.49653 .81591 m .4977 .81631 L .49419 .81582 L F
.327 0 .033 r
.75791 .58185 m .76114 .57956 L .75919 .58111 L F
.595 .206 .275 r
.43456 .66385 m .43099 .66557 L .43247 .66371 L F
.899 .817 .758 r
.64266 .52951 m .64169 .53195 L .64315 .53253 L F
.951 .757 .606 r
.64138 .53271 m .64315 .53253 L .64169 .53195 L F
.64138 .53271 m .64296 .53497 L .64315 .53253 L F
.262 .311 .725 r
.6196 .54583 m .62037 .54973 L .62209 .54772 L F
.789 .477 .46 r
.62068 .54994 m .62054 .55159 L .62037 .54973 L F
.62286 .55144 m .62072 .55157 L .62068 .54994 L F
.62072 .55157 m .62054 .55159 L .62068 .54994 L F
.967 .856 .678 r
.62286 .55144 m .62078 .55403 L .62054 .55159 L F
.902 .968 .815 r
.62074 .55236 m .62081 .55208 L .6207 .55033 L F
.62078 .55403 m .62078 .55373 L .62074 .55236 L F
.62078 .55373 m .62081 .55208 L .62074 .55236 L F
.056 0 .414 r
.62037 .54973 m .6207 .55033 L .62209 .54772 L F
.62037 .54973 m .62054 .55159 L .6207 .55033 L F
.62 .286 .383 r
.61181 .58858 m .61087 .59112 L .60842 .5907 L F
.551 .216 .354 r
.61359 .58964 m .61181 .58858 L .61456 .58882 L F
.61359 .58964 m .61087 .59112 L .61181 .58858 L F
.743 .773 .877 r
.66613 .51827 m .6695 .51857 L .66856 .51674 L F
0 0 .093 r
.38878 .70643 m .39007 .70557 L .39045 .70355 L F
.482 .431 .725 r
.39007 .70557 m .39149 .70395 L .39045 .70355 L F
.572 .544 .786 r
.38863 .70285 m .38791 .70599 L .38656 .70308 L F
.38863 .70285 m .39007 .70557 L .38791 .70599 L F
.724 .878 .953 r
.38863 .70285 m .38656 .70308 L .3873 .70149 L F
.359 .599 .938 r
.38821 .70231 m .38954 .70465 L .38863 .70285 L F
.38954 .70465 m .39007 .70557 L .38941 .70432 L F
.38954 .70465 m .38941 .70432 L .38863 .70285 L F
.482 .431 .725 r
.39007 .70557 m .39234 .70585 L .39149 .70395 L F
.359 .599 .938 r
.38821 .70231 m .39116 .70483 L .39104 .70491 L F
.38954 .70465 m .39104 .70491 L .39007 .70557 L F
.38821 .70231 m .39104 .70491 L .38954 .70465 L F
.39104 .70491 m .39234 .70585 L .39007 .70557 L F
.39116 .70483 m .39131 .70496 L .39104 .70491 L F
.39131 .70496 m .39234 .70585 L .39104 .70491 L F
.626 .504 .694 r
.39149 .70395 m .39234 .70585 L .39452 .7048 L F
0 0 .164 r
.39045 .70355 m .39253 .70025 L .39078 .70105 L F
.39045 .70355 m .39149 .70395 L .39253 .70025 L F
.4 .148 .412 r
.39253 .70025 m .39149 .70395 L .39366 .70327 L F
.626 .504 .694 r
.39149 .70395 m .39452 .7048 L .39366 .70327 L F
.694 .696 .848 r
.39452 .7048 m .39275 .7041 L .39366 .70327 L F
.39452 .7048 m .39366 .70327 L .39372 .70322 L F
.626 .504 .694 r
.39366 .70327 m .39452 .7048 L .39371 .70326 L F
.4 .148 .412 r
.39371 .70323 m .39366 .70327 L .39371 .70326 L F
.39253 .70025 m .39368 .70318 L .39427 .70017 L F
.39368 .70318 m .39366 .70327 L .39371 .70323 L F
.694 .696 .848 r
.39275 .7041 m .38821 .70231 L .39372 .70322 L F
.39371 .70323 m .39372 .70322 L .39372 .70322 L F
.4 .148 .412 r
.39371 .70323 m .39372 .70322 L .39372 .70321 L F
.694 .696 .848 r
.39275 .7041 m .39372 .70322 L .39371 .70323 L F
.4 .148 .412 r
.39368 .70318 m .39371 .70323 L .39372 .70321 L F
.39371 .70323 m .39371 .70326 L .39372 .70322 L F
.39368 .70318 m .39372 .70321 L .39427 .70017 L F
.747 .677 .782 r
.39376 .70328 m .39452 .7048 L .39774 .7048 L F
.39371 .70326 m .39452 .7048 L .39376 .70328 L F
.745 .477 .525 r
.39427 .70017 m .39372 .70321 L .39638 .7018 L F
.39372 .70321 m .39371 .70326 L .39374 .70324 L F
.39372 .70321 m .39374 .70324 L .39638 .7018 L F
0 .122 .672 r
.39374 .70323 m .39372 .70322 L .39372 .70321 L F
.39459 .70399 m .39374 .70323 L .39374 .70323 L F
.39374 .70323 m .39372 .70322 L .39374 .70323 L F
.4 .148 .412 r
.39253 .70025 m .3936 .7031 L .39368 .70318 L F
.747 .677 .782 r
.39374 .70324 m .39774 .7048 L .39638 .7018 L F
.39371 .70326 m .39376 .70328 L .39374 .70324 L F
0 .122 .672 r
.39454 .70392 m .39373 .70322 L .39291 .7016 L F
.747 .677 .782 r
.39376 .70328 m .3952 .70382 L .39374 .70324 L F
0 .122 .672 r
.39462 .70355 m .39459 .70399 L .39291 .7016 L F
.39459 .70399 m .39452 .7048 L .39372 .70322 L F
.694 .696 .848 r
.39452 .7048 m .394 .70505 L .39416 .70466 L F
.394 .70505 m .39234 .70585 L .39416 .70466 L F
.39416 .70466 m .39234 .70585 L .38821 .70231 L F
.237 0 0 r
.39234 .70585 m .38977 .70544 L .39007 .70557 L F
.39234 .70585 m .38975 .70552 L .38977 .70544 L F
.457 0 0 r
.39273 .70566 m .38975 .70552 L .39234 .70585 L F
.39452 .7048 m .39313 .70501 L .39273 .70566 L F
.39313 .70501 m .38975 .70552 L .39273 .70566 L F
.39452 .7048 m .394 .70488 L .394 .70488 L F
.394 .70488 m .39237 .70515 L .394 .70488 L F
.394 .70488 m .39237 .70515 L .39229 .70514 L F
.39452 .7048 m .39371 .70539 L .39237 .70515 L F
.39371 .70539 m .39281 .70603 L .39237 .70515 L F
.45 .617 .921 r
.39234 .70585 m .39527 .70726 L .39452 .7048 L F
.4 .148 .412 r
.3936 .7031 m .39366 .70327 L .39368 .70318 L F
.694 .696 .848 r
.39372 .70322 m .38821 .70231 L .39291 .7016 L F
.65 .574 .756 r
.38821 .70231 m .39397 .70478 L .39291 .7016 L F
.834 .984 .704 r
.39436 .70417 m .3938 .70532 L .39392 .70523 L F
.39462 .70355 m .39426 .70433 L .39436 .70417 L F
.39426 .70433 m .3938 .70532 L .39436 .70417 L F
.457 0 0 r
.39229 .70514 m .38991 .70555 L .38989 .7055 L F
.39237 .70515 m .38991 .70555 L .39229 .70514 L F
.65 .574 .756 r
.38821 .70231 m .38975 .70552 L .3903 .70331 L F
.739 .745 .857 r
.38656 .70308 m .38791 .70599 L .38432 .70571 L F
.221 .743 .816 r
.39007 .70557 m .38977 .70544 L .38679 .70594 L F
0 0 0 r
.38974 .70552 m .38976 .70547 L .38975 .70552 L F
.38976 .70547 m .38977 .70544 L .38975 .70552 L F
.65 .574 .756 r
.3903 .70331 m .38975 .70552 L .39382 .70499 L F
.39397 .70478 m .39382 .70499 L .39432 .70493 L F
.38821 .70231 m .39382 .70499 L .39397 .70478 L F
.834 .984 .704 r
.39457 .70423 m .39392 .70523 L .39454 .70455 L F
.39462 .70355 m .39417 .70464 L .39457 .70423 L F
.39417 .70464 m .39392 .70523 L .39457 .70423 L F
.39416 .70455 m .39308 .70584 L .3938 .70532 L F
.532 .178 .312 r
.39382 .70499 m .39281 .70603 L .39432 .70493 L F
.457 0 0 r
.39237 .70515 m .39281 .70603 L .38991 .70555 L F
.38989 .7055 m .38991 .70555 L .38975 .70552 L F
.532 .178 .312 r
.38975 .70552 m .39281 .70603 L .39382 .70499 L F
.65 .574 .756 r
.39397 .70478 m .39432 .70493 L .39416 .70455 L F
.39397 .70478 m .39416 .70455 L .39291 .7016 L F
.834 .984 .704 r
.39462 .70355 m .39281 .70603 L .39308 .70584 L F
.39462 .70355 m .39308 .70584 L .39416 .70455 L F
.39454 .70455 m .39392 .70523 L .39452 .7048 L F
.235 .255 .678 r
.39462 .70355 m .39432 .70493 L .39416 .70455 L F
0 .122 .672 r
.39459 .70399 m .39372 .70321 L .39454 .70392 L F
.235 .255 .678 r
.39462 .70355 m .39416 .70455 L .39386 .70383 L F
0 .122 .672 r
.39373 .70322 m .39372 .70321 L .39371 .70319 L F
.39373 .70322 m .39371 .70319 L .39291 .7016 L F
.235 .255 .678 r
.39427 .70315 m .39386 .70383 L .39291 .7016 L F
.39462 .70355 m .39386 .70383 L .39427 .70315 L F
.747 .677 .782 r
.3952 .70382 m .39774 .7048 L .39521 .70381 L F
.3952 .70382 m .39521 .70381 L .39374 .70324 L F
0 0 .093 r
.38871 .70656 m .39007 .70557 L .38878 .70643 L F
.464 .352 .641 r
.38871 .70656 m .39069 .70666 L .39007 .70557 L F
.38871 .70656 m .38921 .70911 L .39069 .70666 L F
.118 0 0 r
.423 .65058 m .42518 .65033 L .42645 .64979 L F
.001 0 0 r
.42518 .65033 m .42856 .64946 L .42645 .64979 L F
.496 .154 .317 r
.45446 .68916 m .45768 .68659 L .45446 .68664 L F
.45446 .68916 m .45685 .68888 L .45768 .68659 L F
.409 .073 .281 r
.45768 .68659 m .4591 .68837 L .46007 .6861 L F
.45768 .68659 m .45685 .68888 L .4591 .68837 L F
.802 .898 .911 r
.64364 .52084 m .64668 .51988 L .6454 .51794 L F
.615 .632 .845 r
.64668 .51988 m .64768 .51772 L .6454 .51794 L F
.64668 .51988 m .64832 .52038 L .64768 .51772 L F
.691 .608 .759 r
.48832 .65367 m .49202 .6561 L .49079 .65295 L F
.72 .658 .787 r
.49079 .65295 m .49202 .6561 L .49423 .65337 L F
.669 .58 .746 r
.49202 .6561 m .49475 .65595 L .49423 .65337 L F
.547 .239 .396 r
.47068 .69257 m .47273 .69417 L .47045 .69428 L F
0 0 0 r
.63273 .48276 m .62989 .48468 L .63193 .48333 L F
.203 0 .039 r
.62989 .48468 m .63125 .48559 L .63193 .48333 L F
.62989 .48468 m .62912 .48638 L .63125 .48559 L F
.565 .862 .996 r
.68064 .47723 m .68301 .47654 L .68389 .47722 L F
.557 .858 .997 r
.68389 .47722 m .68541 .47583 L .68621 .47655 L F
.68389 .47722 m .68301 .47654 L .68541 .47583 L F
.98 .715 .455 r
.73027 .4946 m .73148 .49331 L .73029 .49228 L F
.73027 .4946 m .73155 .49562 L .73148 .49331 L F
.921 .753 .656 r
.66571 .48994 m .66531 .49328 L .66675 .49336 L F
.499 .257 .479 r
.66531 .49328 m .66575 .49475 L .66675 .49336 L F
.889 .522 .34 r
.66575 .49475 m .66736 .49565 L .66675 .49336 L F
.604 .436 .627 r
.49048 .79635 m .49047 .79888 L .48836 .79805 L F
.705 .774 .285 r
.24893 .6344 m .24857 .63517 L .24668 .63326 L F
.742 .59 .686 r
.6691 .50729 m .6701 .50994 L .67081 .50745 L F
.832 .838 .37 r
.70354 .52946 m .70457 .5254 L .70372 .52927 L F
.741 .602 .702 r
.50418 .77925 m .50673 .77471 L .50418 .77685 L F
.50418 .77925 m .50714 .77963 L .50673 .77471 L F
.468 .332 .613 r
.50673 .77471 m .50838 .77619 L .50747 .7738 L F
.16 .095 .529 r
.50714 .77963 m .50838 .77619 L .50673 .77471 L F
.95 .61 .333 r
.50321 .77544 m .50373 .77852 L .50418 .77685 L F
.952 .76 .303 r
.50373 .77852 m .50418 .77925 L .50418 .77685 L F
.043 0 .152 r
.60278 .5213 m .60449 .52037 L .605 .51838 L F
.371 .137 .424 r
.60231 .52308 m .60449 .52037 L .60278 .5213 L F
.994 .828 .572 r
.73126 .50015 m .73269 .49899 L .7317 .49795 L F
.73126 .50015 m .73219 .50112 L .73269 .49899 L F
.982 .699 .335 r
.73155 .49562 m .7317 .49795 L .73269 .49899 L F
.827 .997 .769 r
.59269 .53409 m .59441 .53312 L .59303 .53456 L F
.904 .985 .758 r
.59269 .53409 m .59471 .53102 L .59441 .53312 L F
.714 .538 .65 r
.56809 .59144 m .56602 .59421 L .56664 .59146 L F
.754 .596 .68 r
.56809 .59144 m .56948 .59577 L .56602 .59421 L F
.33 .805 .909 r
.77093 .61066 m .774 .61052 L .77343 .6102 L F
.923 .959 .638 r
.77343 .6102 m .774 .61052 L .77469 .60862 L F
0 0 0 r
.55299 .79078 m .55229 .79402 L .55138 .7934 L F
.993 .858 .595 r
.55229 .79402 m .55158 .79663 L .55127 .79561 L F
.55229 .79402 m .55237 .795 L .55138 .7934 L F
.55229 .79402 m .55127 .79561 L .55367 .79577 L F
.55229 .79402 m .55367 .79577 L .55237 .795 L F
.742 .897 .949 r
.71065 .52066 m .71237 .51816 L .70961 .5199 L F
.71065 .52066 m .71362 .51909 L .71237 .51816 L F
.799 .728 .786 r
.25001 .65333 m .25266 .65349 L .25367 .65189 L F
.956 .82 .67 r
.25023 .65505 m .25266 .65349 L .25001 .65333 L F
.25023 .65505 m .2516 .65592 L .25266 .65349 L F
.727 .758 .878 r
.70361 .47659 m .70456 .479 L .70115 .47852 L F
.716 .753 .881 r
.7071 .477 m .70456 .479 L .70361 .47659 L F
.515 .337 .577 r
.38096 .6723 m .38318 .66962 L .38104 .67013 L F
.86 .975 .667 r
.65955 .51044 m .65814 .5116 L .65846 .50923 L F
.65955 .51044 m .65829 .51241 L .65814 .5116 L F
.399 0 .003 r
.2715 .58623 m .27317 .58684 L .27481 .5853 L F
.517 .099 .186 r
.27317 .58684 m .27689 .58507 L .27481 .5853 L F
.843 .399 .167 r
.67616 .51618 m .67408 .51376 L .67666 .51518 L F
.893 .796 .746 r
.67303 .51566 m .67339 .51505 L .67256 .51589 L F
.515 .052 .094 r
.67666 .51518 m .67413 .51379 L .67339 .51505 L F
.893 .796 .746 r
.67557 .51438 m .67666 .51518 L .67339 .51505 L F
.67557 .51438 m .67339 .51505 L .67303 .51566 L F
.515 .052 .094 r
.67413 .51379 m .67408 .51376 L .67339 .51505 L F
.534 .866 .994 r
.6688 .47796 m .67117 .47732 L .6723 .4779 L F
.508 .817 1 r
.67364 .47665 m .6723 .4779 L .67117 .47732 L F
.67364 .47665 m .67455 .47744 L .6723 .4779 L F
.579 .676 .906 r
.71613 .47879 m .71852 .47838 L .71907 .48029 L F
.04 .269 .765 r
.71852 .47838 m .72001 .48151 L .71907 .48029 L F
.358 0 0 r
.43518 .70349 m .43373 .70504 L .43153 .7053 L F
.301 0 0 r
.43739 .70331 m .43373 .70504 L .43518 .70349 L F
.444 .237 .502 r
.49015 .76833 m .49244 .76807 L .49238 .76546 L F
.424 .168 .419 r
.49015 .76833 m .4894 .77036 L .49244 .76807 L F
.49015 .76833 m .4894 .77036 L .49244 .76807 L F
.516 0 0 r
.50587 .78039 m .50714 .77963 L .50418 .77925 L F
.16 .095 .529 r
.50714 .77963 m .50871 .77892 L .50838 .77619 L F
0 0 0 r
.50587 .78039 m .50871 .77892 L .50714 .77963 L F
0 0 .02 r
.62491 .57349 m .62316 .57688 L .62386 .57497 L F
.809 .674 .715 r
.64634 .50929 m .64759 .51276 L .64894 .50934 L F
.489 .592 .883 r
.64845 .50694 m .64894 .50934 L .64793 .50762 L F
0 .276 .733 r
.64894 .50934 m .65034 .50986 L .64793 .50762 L F
.64894 .50934 m .65175 .51118 L .65034 .50986 L F
.44 .641 .942 r
.71987 .48794 m .71898 .4896 L .71779 .4882 L F
.71987 .48794 m .72092 .4895 L .71898 .4896 L F
.095 0 .117 r
.25108 .59717 m .2486 .59985 L .25017 .59903 L F
.088 0 .182 r
.2533 .59432 m .25108 .59717 L .25257 .59627 L F
.29 0 .224 r
.25108 .59717 m .25201 .59827 L .25257 .59627 L F
.25108 .59717 m .25017 .59903 L .25201 .59827 L F
.576 .187 .267 r
.54226 .72969 m .54467 .73086 L .546 .72872 L F
.685 .311 .332 r
.54467 .73086 m .54832 .73087 L .546 .72872 L F
.611 .273 .373 r
.49312 .80728 m .48937 .80967 L .4894 .80738 L F
.49312 .80728 m .4919 .80975 L .48937 .80967 L F
.724 .401 .432 r
.49312 .80728 m .49417 .81126 L .4919 .80975 L F
.107 0 0 r
.72746 .51795 m .72737 .5181 L .72473 .51816 L F
0 0 0 r
.72912 .51668 m .72737 .5181 L .72746 .51795 L F
.841 .896 .878 r
.72281 .50531 m .71946 .5053 L .72116 .5037 L F
.869 .762 .742 r
.72335 .50333 m .72281 .50531 L .72116 .5037 L F
.944 .904 .517 r
.62562 .51855 m .62602 .5192 L .62649 .51736 L F
.532 .471 .732 r
.63656 .51549 m .63685 .51737 L .63436 .51799 L F
.611 .83 .984 r
.63833 .51671 m .63796 .51684 L .63839 .51664 L F
.63695 .51853 m .6356 .51793 L .63833 .51671 L F
.516 .459 .731 r
.63839 .51664 m .63694 .51794 L .63685 .51737 L F
.63839 .51664 m .63685 .51737 L .63656 .51549 L F
.611 .83 .984 r
.63796 .51684 m .63524 .51777 L .63839 .51664 L F
.532 .471 .732 r
.63685 .51737 m .6355 .51797 L .63436 .51799 L F
.611 .83 .984 r
.6356 .51793 m .63524 .51777 L .63833 .51671 L F
.532 .471 .732 r
.63685 .51737 m .63694 .51794 L .6355 .51797 L F
.314 .718 .978 r
.63695 .51853 m .63694 .51794 L .63524 .51777 L F
.331 .733 .981 r
.63436 .51799 m .63694 .51794 L .63695 .51853 L F
.751 .521 .582 r
.63695 .51853 m .63447 .52048 L .63436 .51799 L F
.63695 .51853 m .63724 .52077 L .63447 .52048 L F
.708 .985 .877 r
.63839 .51664 m .63988 .51653 L .63695 .51853 L F
.097 .654 .754 r
.46434 .65315 m .46076 .65337 L .46209 .65336 L F
.543 .193 .323 r
.46243 .68628 m .46466 .68637 L .4658 .68392 L F
.215 .689 .938 r
.4658 .68392 m .46868 .68401 L .46892 .68424 L F
.688 .347 .394 r
.4658 .68392 m .46815 .68613 L .46868 .68401 L F
.4658 .68392 m .46466 .68637 L .46815 .68613 L F
.718 .542 .651 r
.56664 .59146 m .56602 .59421 L .5621 .59357 L F
.237 0 .182 r
.63193 .48333 m .63454 .48145 L .63273 .48276 L F
.082 0 0 r
.5214 .76601 m .5234 .76567 L .52567 .76476 L F
.687 .192 .065 r
.52565 .76668 m .52567 .76476 L .5234 .76567 L F
.52565 .76668 m .52706 .76567 L .52567 .76476 L F
.171 0 .173 r
.71446 .51235 m .71252 .51355 L .71278 .51582 L F
.419 .744 .993 r
.30745 .58529 m .30709 .58654 L .30556 .58558 L F
.30745 .58529 m .30916 .58636 L .30709 .58654 L F
.374 .207 .523 r
.46998 .78458 m .47159 .78431 L .47008 .78233 L F
.673 .258 .249 r
.47008 .78233 m .47159 .78431 L .47107 .78384 L F
.222 .129 .533 r
.47008 .78233 m .47107 .78384 L .47158 .77901 L F
.48 .218 .439 r
.55781 .76439 m .55589 .76284 L .55919 .76266 L F
.982 .743 .497 r
.55919 .76266 m .55915 .76525 L .55781 .76439 L F
.729 .51 .595 r
.64425 .50817 m .64066 .5096 L .64324 .50721 L F
.307 0 .212 r
.48583 .75372 m .48861 .75089 L .48646 .75158 L F
.726 .848 .939 r
.47339 .63908 m .47122 .64012 L .47004 .63915 L F
.281 0 0 r
.44344 .70172 m .44192 .7031 L .43972 .70338 L F
.408 0 .077 r
.4455 .70118 m .44192 .7031 L .44344 .70172 L F
.26 .554 .93 r
.77792 .57813 m .77553 .57844 L .77529 .57783 L F
.77792 .57813 m .7786 .57945 L .77553 .57844 L F
.529 .264 .457 r
.38429 .6609 m .38672 .66058 L .38696 .65825 L F
.544 .337 .55 r
.38672 .66058 m .38943 .658 L .38696 .65825 L F
.6 .553 .773 r
.28686 .63036 m .28476 .63109 L .2836 .62744 L F
.987 .714 .387 r
.65829 .51241 m .65739 .51362 L .65814 .5116 L F
.65829 .51241 m .65838 .51469 L .65739 .51362 L F
.74 .928 .952 r
.40642 .71248 m .40832 .7131 L .40993 .71182 L F
.771 .671 .752 r
.50211 .65051 m .50049 .65356 L .5032 .65369 L F
.627 .591 .794 r
.50211 .65051 m .5032 .65369 L .50564 .65328 L F
.446 .793 .998 r
.52945 .79286 m .53076 .79365 L .52729 .79319 L F
.52729 .79319 m .53076 .79365 L .52945 .79286 L F
.277 0 0 r
.32438 .60018 m .32312 .6005 L .32093 .60006 L F
.002 .548 .831 r
.32661 .60141 m .32312 .6005 L .32438 .60018 L F
.908 .949 .816 r
.49991 .81318 m .49653 .81591 L .49859 .81479 L F
.35 0 .082 r
.50107 .81452 m .49991 .81318 L .49859 .81479 L F
.50107 .81452 m .50381 .81205 L .49991 .81318 L F
.653 .279 .322 r
.42184 .66953 m .42058 .67168 L .4186 .6698 L F
.351 0 .105 r
.42424 .6694 m .42058 .67168 L .42184 .66953 L F
.187 0 0 r
.41324 .71113 m .41236 .71162 L .40993 .71182 L F
0 0 0 r
.41418 .71067 m .41324 .71113 L .4155 .71066 L F
.41418 .71067 m .41236 .71162 L .41324 .71113 L F
.824 .851 .393 r
.59703 .55812 m .59629 .55954 L .59621 .56038 L F
.59703 .55812 m .59741 .55616 L .59629 .55954 L F
.669 .824 .958 r
.48699 .63592 m .48508 .63669 L .4836 .63565 L F
.738 .725 .839 r
.68951 .52794 m .68466 .52899 L .68808 .52693 L F
.74 .952 .946 r
.69057 .52613 m .68951 .52794 L .68808 .52693 L F
.69057 .52613 m .69149 .52669 L .68951 .52794 L F
.381 .239 .561 r
.58528 .68641 m .58388 .6893 L .58504 .68658 L F
.323 .028 .3 r
.2533 .59432 m .25453 .59551 L .25528 .59375 L F
.2533 .59432 m .25257 .59627 L .25453 .59551 L F
.577 .57 .809 r
.38576 .69233 m .38678 .68857 L .38496 .69006 L F
.38576 .69233 m .38798 .69203 L .38678 .68857 L F
.456 .352 .647 r
.38642 .69576 m .38798 .69203 L .38576 .69233 L F
.428 .139 .369 r
.36028 .619 m .35756 .62163 L .35823 .61964 L F
.381 .63 .951 r
.69788 .51655 m .69705 .51512 L .69654 .51222 L F
.925 .958 .783 r
.69972 .51215 m .69788 .51655 L .69654 .51222 L F
0 0 .462 r
.69788 .51655 m .69827 .51513 L .69705 .51512 L F
.69788 .51655 m .69847 .51882 L .69827 .51513 L F
.886 .871 .818 r
.63391 .50614 m .63713 .50447 L .63378 .50373 L F
.989 .75 .369 r
.63943 .50601 m .63933 .50378 L .63713 .50447 L F
.569 .413 .63 r
.63933 .50378 m .63943 .50601 L .63713 .50447 L F
.665 .665 .84 r
.64768 .51772 m .64832 .52038 L .65116 .51795 L F
.721 .691 .821 r
.64832 .52038 m .65233 .51951 L .65116 .51795 L F
.612 .525 .731 r
.25074 .62285 m .25286 .62227 L .25005 .62201 L F
.25074 .62285 m .25364 .6247 L .25286 .62227 L F
.159 0 0 r
.31881 .60008 m .31712 .60097 L .31503 .60119 L F
.019 0 0 r
.32093 .60006 m .31712 .60097 L .31881 .60008 L F
.636 .132 .034 r
.48806 .69224 m .49035 .69318 L .49191 .69308 L F
.524 .063 .1 r
.49035 .69318 m .4935 .69262 L .49191 .69308 L F
.53 .921 .898 r
.66659 .47901 m .66816 .47778 L .6688 .47796 L F
.585 .409 .609 r
.66659 .47901 m .66807 .48129 L .66765 .48099 L F
.521 .917 .835 r
.66659 .47901 m .66584 .47904 L .66816 .47778 L F
.485 .309 .566 r
.5729 .69241 m .57504 .692 L .57506 .68956 L F
.562 .307 .487 r
.5729 .69241 m .57509 .69436 L .57504 .692 L F
.5729 .69241 m .57168 .69519 L .57509 .69436 L F
.687 .626 .782 r
.62502 .54356 m .62274 .54446 L .62125 .5411 L F
.711 .665 .803 r
.38921 .70911 m .39262 .71023 L .39069 .70666 L F
.744 .608 .706 r
.38921 .70911 m .39271 .71196 L .39262 .71023 L F
.508 .569 .852 r
.39069 .70666 m .39262 .71023 L .39394 .70817 L F
.596 .479 .69 r
.39262 .71023 m .39501 .71099 L .39394 .70817 L F
.39262 .71023 m .39271 .71196 L .39501 .71099 L F
0 .117 .667 r
.50416 .80088 m .5036 .80151 L .50218 .7985 L F
.637 .495 .673 r
.50416 .80088 m .50297 .8029 L .5036 .80151 L F
.299 .224 .601 r
.55319 .75369 m .5541 .75679 L .552 .75747 L F
0 0 0 r
.55519 .75533 m .55447 .75649 L .5541 .75679 L F
.388 .788 .985 r
.5541 .75679 m .55456 .75735 L .55335 .75741 L F
0 0 0 r
.55447 .75649 m .55309 .75869 L .5541 .75679 L F
.388 .788 .985 r
.5541 .75679 m .55335 .75741 L .552 .75747 L F
.967 .856 .678 r
.62286 .55144 m .62192 .55508 L .62078 .55403 L F
.1 0 0 r
.29176 .64997 m .29101 .65051 L .28813 .65068 L F
.481 0 0 r
.2937 .6497 m .29101 .65051 L .29176 .64997 L F
.023 0 0 r
.53772 .80168 m .53577 .80254 L .5341 .80439 L F
.13 .651 .885 r
.65524 .48234 m .65765 .48242 L .65911 .48297 L F
.438 0 0 r
.65765 .48242 m .66102 .48169 L .65911 .48297 L F
.21 .319 .758 r
.41277 .68915 m .41187 .69053 L .41054 .68706 L F
.966 .64 .321 r
.56539 .74762 m .56617 .74593 L .56359 .74505 L F
.56539 .74762 m .56658 .74834 L .56617 .74593 L F
.023 0 .075 r
.605 .51838 m .607 .5173 L .60739 .51567 L F
.294 0 .246 r
.605 .51838 m .60674 .51952 L .607 .5173 L F
.605 .51838 m .60449 .52037 L .60674 .51952 L F
.436 .772 .997 r
.31693 .58751 m .31635 .58867 L .31486 .58769 L F
.31693 .58751 m .31843 .58844 L .31635 .58867 L F
.572 .609 .851 r
.74912 .60211 m .75021 .59861 L .74808 .59891 L F
.74912 .60211 m .7516 .60162 L .75021 .59861 L F
.461 .452 .762 r
.74912 .60211 m .75181 .60374 L .7516 .60162 L F
.452 .819 .559 r
.54526 .75401 m .54274 .75605 L .54201 .75662 L F
.84 .593 .565 r
.72335 .50333 m .72116 .5037 L .72107 .50125 L F
0 .176 .705 r
.58987 .71483 m .59071 .71401 L .58828 .71381 L F
.58987 .71483 m .59184 .71665 L .59071 .71401 L F
.36 .234 .57 r
.58999 .71769 m .59184 .71665 L .58987 .71483 L F
.899 .839 .778 r
.54598 .80086 m .54566 .79866 L .54473 .79978 L F
.88 .901 .841 r
.54346 .8021 m .54598 .80086 L .54473 .79978 L F
.357 0 0 r
.6346 .49768 m .63452 .49806 L .63245 .49782 L F
.437 .242 .516 r
.24802 .60202 m .25017 .59903 L .2486 .59985 L F
.749 .594 .685 r
.47175 .68693 m .47394 .68378 L .47154 .68425 L F
.47175 .68693 m .4752 .68686 L .47394 .68378 L F
.684 .563 .713 r
.47394 .68378 m .4752 .68686 L .47795 .6848 L F
.47394 .68378 m .4752 .68686 L .47795 .6848 L F
0 0 .236 r
.67657 .52641 m .67748 .52902 L .67771 .52971 L F
.888 .981 .694 r
.67748 .52902 m .67664 .53012 L .67771 .52971 L F
.471 .835 .993 r
.67771 .52971 m .67748 .52902 L .6801 .52918 L F
.675 .416 .521 r
.49238 .76546 m .49496 .76768 L .4947 .76508 L F
.49238 .76546 m .49244 .76807 L .49496 .76768 L F
.798 .656 .706 r
.64324 .50721 m .64066 .5096 L .63943 .50601 L F
.156 .671 .893 r
.52584 .77572 m .52902 .77631 L .52712 .77613 L F
.828 .756 .785 r
.56039 .58261 m .56252 .57973 L .56326 .58281 L F
.854 .746 .744 r
.64083 .51203 m .64196 .51595 L .63869 .51473 L F
.579 .24 .359 r
.64196 .51595 m .63839 .51664 L .63869 .51473 L F
.64196 .51595 m .63988 .51653 L .63839 .51664 L F
.64196 .51595 m .64189 .51759 L .63988 .51653 L F
.63988 .51653 m .64189 .51759 L .64196 .51595 L F
.59 .594 .824 r
.64454 .51339 m .64196 .51595 L .64083 .51203 L F
0 0 0 r
.64454 .51339 m .64189 .51759 L .64196 .51595 L F
.59 .594 .824 r
.64454 .51339 m .64196 .51595 L .64083 .51203 L F
.744 .762 .867 r
.71071 .47718 m .7071 .477 L .70947 .47587 L F
.509 .303 .536 r
.28854 .61559 m .28668 .61347 L .28881 .61284 L F
.28854 .61559 m .28646 .61607 L .28668 .61347 L F
.144 .015 .434 r
.60739 .51567 m .60917 .5146 L .60926 .51213 L F
.014 0 .072 r
.60739 .51567 m .60849 .51635 L .60917 .5146 L F
.60739 .51567 m .607 .5173 L .60849 .51635 L F
.799 .728 .786 r
.25001 .65333 m .25367 .65189 L .2521 .65026 L F
.543 .006 0 r
.25649 .65056 m .2521 .65026 L .25367 .65189 L F
.553 .524 .778 r
.34104 .60792 m .34258 .60537 L .34032 .60595 L F
.34104 .60792 m .34319 .60758 L .34258 .60537 L F
.543 .463 .715 r
.34104 .60792 m .34371 .61053 L .34319 .60758 L F
.34104 .60792 m .34168 .61106 L .34371 .61053 L F
.635 .227 .253 r
.58102 .69237 m .57717 .69367 L .57878 .69259 L F
0 0 0 r
.49108 .75313 m .48991 .75422 L .49177 .75108 L F
.49108 .75313 m .48864 .75604 L .48991 .75422 L F
.65 .238 .249 r
.47182 .68798 m .4752 .68686 L .47175 .68693 L F
.47182 .68798 m .47379 .68867 L .4752 .68686 L F
.843 .493 .39 r
.4752 .68686 m .47379 .68867 L .47568 .68857 L F
.494 .428 .711 r
.50463 .80561 m .50689 .80759 L .50711 .80458 L F
.116 .54 .916 r
.66464 .4889 m .66366 .48922 L .66221 .48722 L F
.66464 .4889 m .66571 .48994 L .66366 .48922 L F
.442 0 .015 r
.50297 .8029 m .50184 .80426 L .49967 .80412 L F
.637 .495 .673 r
.50416 .80088 m .50184 .80426 L .50297 .8029 L F
.405 .656 .961 r
.46874 .80478 m .47134 .80509 L .46974 .80352 L F
.46974 .80352 m .47134 .80509 L .46874 .80478 L F
.46874 .80478 m .47134 .80509 L .46974 .80352 L F
.268 0 .099 r
.44619 .68922 m .44816 .68871 L .44915 .68726 L F
.544 .284 .472 r
.44816 .68871 m .45093 .68633 L .44915 .68726 L F
.622 .803 .969 r
.6756 .53739 m .67678 .53865 L .67903 .53784 L F
.149 0 0 r
.33048 .64365 m .32685 .64577 L .32841 .64435 L F
.691 .194 0 r
.47453 .80464 m .47737 .80782 L .4738 .80671 L F
.887 .526 .355 r
.4738 .80671 m .47737 .80782 L .47793 .80993 L F
.884 .716 .668 r
.55884 .58858 m .55602 .59055 L .55745 .58759 L F
.944 .904 .517 r
.62562 .51855 m .62649 .51736 L .62607 .5184 L F
.941 .573 .245 r
.62649 .51736 m .62607 .5184 L .62507 .51523 L F
.688 .215 .122 r
.62649 .51736 m .62765 .5195 L .62607 .5184 L F
.417 .604 .925 r
.36883 .59645 m .36803 .59799 L .36684 .59642 L F
.36883 .59645 m .37064 .59871 L .36803 .59799 L F
.941 .832 .708 r
.65822 .52093 m .65785 .51794 L .65886 .51883 L F
.665 .579 .749 r
.5918 .69789 m .59396 .7012 L .59566 .70058 L F
.721 .642 .769 r
.24799 .63879 m .25166 .63946 L .25044 .63604 L F
.677 .35 .414 r
.53879 .76683 m .54142 .76773 L .54226 .76609 L F
.385 .042 .256 r
.54226 .76609 m .54142 .76773 L .54447 .76569 L F
.691 .826 .948 r
.49287 .63435 m .48905 .63406 L .49174 .63365 L F
.543 .855 .998 r
.49519 .63372 m .49287 .63435 L .49174 .63365 L F
.35 .039 .289 r
.35119 .6278 m .35031 .63034 L .34846 .63024 L F
.417 .201 .475 r
.35119 .6278 m .35337 .62503 L .35316 .62714 L F
.312 .004 .273 r
.3523 .62941 m .35119 .6278 L .35316 .62714 L F
.3523 .62941 m .35031 .63034 L .35119 .6278 L F
.669 .772 .927 r
.70115 .47852 m .69893 .47943 L .69777 .47795 L F
.786 .594 .641 r
.51451 .69269 m .51095 .69207 L .51308 .69405 L F
0 0 0 r
.51451 .69269 m .51507 .69305 L .51588 .69089 L F
.51451 .69269 m .51308 .69405 L .51507 .69305 L F
.351 .212 .547 r
.28414 .61912 m .28261 .62196 L .28217 .61972 L F
.569 .055 0 r
.47888 .68918 m .48273 .69098 L .48219 .68958 L F
.552 .044 .001 r
.48273 .69098 m .48441 .68983 L .48219 .68958 L F
.744 .608 .706 r
.38921 .70911 m .39137 .71232 L .39271 .71196 L F
.69 .525 .658 r
.39137 .71232 m .39205 .71383 L .39271 .71196 L F
.002 .578 .736 r
.68941 .51899 m .68797 .51896 L .68758 .51753 L F
.837 .786 .803 r
.55894 .74864 m .55521 .74921 L .5571 .74802 L F
.675 .84 .962 r
.46543 .64206 m .46183 .64196 L .46408 .64121 L F
.833 .889 .882 r
.46708 .63998 m .46543 .64206 L .46408 .64121 L F
.793 .34 0 r
.67025 .48438 m .66807 .48129 L .67019 .48191 L F
.456 .352 .647 r
.38642 .69576 m .38853 .69511 L .38798 .69203 L F
.501 .503 .791 r
.38642 .69576 m .38921 .69748 L .38853 .69511 L F
0 0 0 r
.62737 .56816 m .62658 .57025 L .62503 .57148 L F
.15 .059 .489 r
.62658 .57025 m .62491 .57349 L .62503 .57148 L F
.338 0 0 r
.27912 .58437 m .28127 .58461 L .28303 .58405 L F
.191 0 0 r
.28127 .58461 m .28476 .58412 L .28303 .58405 L F
.475 .283 .54 r
.34168 .61106 m .34348 .61287 L .34371 .61053 L F
.34168 .61106 m .34152 .61342 L .34348 .61287 L F
.227 .254 .681 r
.59145 .72457 m .59126 .72297 L .5914 .72448 L F
.608 .799 .973 r
.77746 .58523 m .77858 .58335 L .77596 .58286 L F
.77746 .58523 m .77977 .58455 L .77858 .58335 L F
0 0 0 r
.61818 .55899 m .61948 .55774 L .61664 .55997 L F
.872 .964 .855 r
.62192 .55508 m .61948 .55774 L .61885 .55686 L F
.99 .884 .563 r
.61885 .55686 m .61948 .55774 L .61818 .55899 L F
.211 0 .202 r
.34559 .63297 m .34305 .63555 L .34384 .6338 L F
.71 .783 .909 r
.47802 .65053 m .47576 .65272 L .47935 .65306 L F
.848 .757 .763 r
.47564 .65483 m .47935 .65306 L .47576 .65272 L F
.47564 .65483 m .47718 .65605 L .47935 .65306 L F
.669 .764 .921 r
.47802 .65053 m .47935 .65306 L .48275 .65265 L F
.552 .044 .001 r
.48273 .69098 m .48315 .69098 L .48441 .68983 L F
.687 .207 .103 r
.48315 .69098 m .4866 .69167 L .48441 .68983 L F
.625 .062 0 r
.48441 .68983 m .4866 .69167 L .48806 .69224 L F
.479 .62 .912 r
.36522 .59394 m .36482 .59653 L .3633 .59435 L F
.36522 .59394 m .36684 .59642 L .36482 .59653 L F
.555 .547 .801 r
.24925 .61879 m .25005 .62201 L .25172 .6193 L F
.615 .626 .839 r
.25005 .62201 m .25286 .62227 L .25172 .6193 L F
.788 .576 .614 r
.49353 .77598 m .49707 .77383 L .49489 .77478 L F
.49353 .77598 m .49728 .77644 L .49707 .77383 L F
.535 .387 .627 r
.49707 .77383 m .49728 .77644 L .49955 .77582 L F
.332 0 0 r
.49955 .77582 m .49489 .77478 L .49707 .77383 L F
.005 .021 .523 r
.50659 .63526 m .50592 .63879 L .5043 .63591 L F
.50659 .63526 m .50705 .63751 L .50592 .63879 L F
.24 .385 .809 r
.50705 .63751 m .50839 .64048 L .50592 .63879 L F
.99 .767 .503 r
.66925 .51005 m .67005 .51222 L .6701 .50994 L F
.315 .369 .759 r
.67146 .51066 m .66925 .51005 L .67065 .50752 L F
.67155 .51101 m .66925 .51005 L .67146 .51066 L F
.99 .767 .503 r
.66925 .51005 m .6701 .50994 L .6681 .50974 L F
.66925 .51005 m .6681 .50974 L .66713 .50964 L F
.653 .694 .875 r
.48743 .65209 m .48832 .65367 L .49079 .65295 L F
.767 .678 .764 r
.54756 .78175 m .54988 .7826 L .55159 .78028 L F
.798 .631 .674 r
.54756 .78175 m .5495 .78444 L .54988 .7826 L F
.481 .099 .237 r
.45113 .69949 m .45133 .69848 L .45345 .69942 L F
.485 .083 .202 r
.45133 .69848 m .45358 .69834 L .45345 .69942 L F
0 0 .125 r
.60971 .53482 m .6084 .53741 L .60933 .53544 L F
.60971 .53482 m .61015 .53619 L .6084 .53741 L F
.557 .135 .197 r
.51122 .81401 m .51338 .81479 L .51135 .81495 L F
.216 .736 .851 r
.51135 .81495 m .51266 .81464 L .51249 .81467 L F
.05 0 .222 r
.51135 .81495 m .51037 .81518 L .51122 .81401 L F
.216 .736 .851 r
.51135 .81495 m .51249 .81467 L .50909 .81531 L F
.05 0 .222 r
.51135 .81495 m .50956 .81631 L .51037 .81518 L F
.566 .935 .818 r
.50844 .81641 m .50956 .81631 L .51135 .81495 L F
.471 0 0 r
.52011 .76584 m .51934 .76498 L .51819 .76439 L F
.52011 .76584 m .5214 .76601 L .51934 .76498 L F
.604 .436 .627 r
.49048 .79635 m .48724 .79863 L .48705 .796 L F
.628 .902 .985 r
.5331 .80705 m .53605 .80663 L .53539 .8062 L F
.084 0 0 r
.53605 .80663 m .53928 .80506 L .53771 .80659 L F
.53605 .80663 m .53771 .80659 L .53539 .8062 L F
.299 .025 .318 r
.51961 .69446 m .51784 .6952 L .52025 .69253 L F
.308 .058 .362 r
.52198 .69158 m .51961 .69446 L .52025 .69253 L F
.067 .174 .668 r
.55182 .71707 m .55266 .72055 L .55365 .71932 L F
.992 .758 .477 r
.37635 .70262 m .37653 .70612 L .37555 .70246 L F
0 0 .163 r
.7612 .57736 m .76244 .57576 L .76268 .57394 L F
0 0 .439 r
.76114 .57956 m .76244 .57576 L .7612 .57736 L F
.52 .102 .187 r
.5156 .69807 m .51445 .69998 L .51203 .6998 L F
.42 .205 .479 r
.51756 .69723 m .5156 .69807 L .51784 .6952 L F
.231 0 .035 r
.51657 .69927 m .5156 .69807 L .51756 .69723 L F
.51657 .69927 m .51445 .69998 L .5156 .69807 L F
.414 .807 .987 r
.30182 .63278 m .30389 .63245 L .30531 .63307 L F
.166 .682 .89 r
.30609 .63169 m .30808 .63168 L .30899 .63222 L F
.30609 .63169 m .30899 .63222 L .30992 .63238 L F
.579 .88 .993 r
.30531 .63307 m .30609 .63169 L .30992 .63238 L F
.30531 .63307 m .30389 .63245 L .30609 .63169 L F
0 .268 .659 r
.32843 .60208 m .32863 .60211 L .32661 .60141 L F
.32843 .60208 m .33016 .60297 L .32863 .60211 L F
.962 .942 .687 r
.59795 .71721 m .59586 .71952 L .59737 .72108 L F
.985 .83 .609 r
.59737 .72108 m .59524 .72311 L .59668 .72332 L F
.59737 .72108 m .59586 .71952 L .59524 .72311 L F
.552 .612 .866 r
.69413 .48499 m .69623 .48326 L .69281 .48263 L F
.69413 .48499 m .69651 .48489 L .69623 .48326 L F
0 0 0 r
.62977 .56587 m .62881 .56734 L .62737 .56816 L F
.62881 .56734 m .62658 .57025 L .62737 .56816 L F
.069 0 0 r
.58799 .70358 m .58702 .70363 L .58512 .70252 L F
.524 .418 .676 r
.58965 .70329 m .58932 .70491 L .58702 .70363 L F
.069 0 0 r
.58799 .70358 m .58965 .70329 L .58702 .70363 L F
.407 0 0 r
.53747 .78527 m .53849 .78644 L .53629 .78681 L F
.53747 .78527 m .53968 .78559 L .53849 .78644 L F
.4 0 .077 r
.40557 .65538 m .40793 .65519 L .40932 .65343 L F
.36 0 .052 r
.40932 .65343 m .41024 .65487 L .41153 .65317 L F
.40932 .65343 m .40793 .65519 L .41024 .65487 L F
0 0 .486 r
.46985 .79625 m .47116 .79826 L .47137 .79574 L F
.46985 .79625 m .47055 .79837 L .47116 .79826 L F
.608 .099 0 r
.50625 .77188 m .5057 .77096 L .50396 .77008 L F
.50625 .77188 m .50747 .773 L .5057 .77096 L F
.872 .751 .727 r
.24939 .62782 m .24581 .62982 L .24792 .62689 L F
.663 .158 .035 r
.24955 .6292 m .24939 .62782 L .24792 .62689 L F
.864 .636 .591 r
.59313 .57409 m .5944 .57693 L .59463 .57465 L F
.79 .544 .566 r
.59655 .57684 m .59463 .57465 L .5944 .57693 L F
.637 .842 .979 r
.47825 .78216 m .48183 .78199 L .48115 .78119 L F
.663 .403 .516 r
.478 .7826 m .48183 .78199 L .47825 .78216 L F
0 0 .295 r
.48183 .78199 m .48236 .78303 L .48201 .78083 L F
.165 .207 .66 r
.48228 .7825 m .48272 .78421 L .48236 .78303 L F
.48201 .78083 m .48272 .78421 L .48228 .7825 L F
.215 .242 .674 r
.48416 .78313 m .48272 .78421 L .48201 .78083 L F
0 0 .259 r
.48265 .78396 m .48272 .78421 L .48282 .78428 L F
.48247 .78361 m .48272 .78421 L .48265 .78396 L F
0 0 .295 r
.48236 .78303 m .48267 .78364 L .48201 .78083 L F
.165 .207 .66 r
.48201 .78083 m .48236 .78303 L .48193 .78161 L F
0 0 .365 r
.48236 .78303 m .48183 .78199 L .48193 .78161 L F
0 0 .295 r
.48183 .78199 m .48247 .78361 L .48268 .784 L F
0 0 .365 r
.4826 .78382 m .48183 .78199 L .48236 .78303 L F
0 0 .295 r
.48183 .78199 m .48268 .784 L .48282 .78428 L F
0 0 .365 r
.48272 .78421 m .48183 .78199 L .4826 .78382 L F
0 0 .295 r
.48183 .78199 m .48282 .78428 L .48267 .78364 L F
.512 .21 .391 r
.59237 .59415 m .59209 .59624 L .58929 .59679 L F
.561 .235 .374 r
.5947 .5942 m .59209 .59624 L .59237 .59415 L F
.456 .28 .552 r
.35545 .62213 m .35535 .6245 L .35337 .62503 L F
.509 .318 .557 r
.35535 .6245 m .35316 .62714 L .35337 .62503 L F
.633 .894 .57 r
.57481 .5594 m .57612 .55817 L .57385 .56074 L F
.648 .878 .519 r
.57612 .55817 m .57713 .55661 L .57708 .5569 L F
.67 .91 .583 r
.57481 .5594 m .57713 .55661 L .57612 .55817 L F
.391 .212 .516 r
.47036 .78769 m .46855 .79065 L .47029 .79038 L F
.427 .372 .693 r
.46855 .79065 m .471 .7927 L .47029 .79038 L F
.835 .487 0 r
.5591 .73886 m .55983 .74018 L .55853 .73701 L F
.577 .009 0 r
.55983 .74018 m .56235 .74215 L .56375 .74279 L F
.573 .006 0 r
.56089 .74145 m .55983 .74018 L .5591 .73886 L F
.56089 .74145 m .56235 .74215 L .55983 .74018 L F
.056 0 .124 r
.55359 .71202 m .55123 .71492 L .55313 .71352 L F
0 0 0 r
.55359 .71202 m .55477 .71082 L .55554 .70894 L F
.643 .614 .805 r
.55313 .71352 m .55477 .71082 L .55359 .71202 L F
.937 .943 .604 r
.57312 .56237 m .57253 .56221 L .57385 .56074 L F
.612 .862 .509 r
.57385 .56074 m .57253 .56221 L .57481 .5594 L F
.093 .65 .766 r
.76489 .57325 m .76334 .57342 L .76268 .57394 L F
.76489 .57325 m .76593 .57328 L .76334 .57342 L F
.822 .719 .751 r
.71647 .48155 m .72001 .48151 L .71852 .47838 L F
.5 .161 .324 r
.46161 .6955 m .45906 .69712 L .45932 .69537 L F
0 0 0 r
.49108 .75313 m .49177 .75108 L .49097 .75062 L F
.659 .62 .799 r
.64233 .48948 m .63899 .48759 L .64155 .48859 L F
.364 .835 .829 r
.64155 .48859 m .64519 .48771 L .64233 .48948 L F
.633 .954 .933 r
.26493 .6437 m .26425 .64485 L .26675 .64371 L F
.637 .957 .927 r
.26302 .64479 m .26425 .64485 L .26493 .6437 L F
.414 .57 .899 r
.51861 .81006 m .51929 .81213 L .51652 .81055 L F
.537 .451 .705 r
.51652 .81055 m .51929 .81257 L .51861 .81006 L F
.356 .343 .707 r
.38301 .70243 m .38038 .70294 L .38077 .70051 L F
.157 0 .01 r
.38301 .70243 m .38102 .70336 L .38038 .70294 L F
.703 .813 .933 r
.53101 .80811 m .5331 .80705 L .52964 .80693 L F
.53101 .80811 m .5331 .80705 L .52964 .80693 L F
.682 .742 .896 r
.48275 .65265 m .48518 .65268 L .48403 .65132 L F
.601 .765 .958 r
.48403 .65132 m .48518 .65268 L .48743 .65209 L F
.513 .41 .675 r
.24444 .60804 m .24646 .60761 L .24603 .6051 L F
.362 .328 .685 r
.24444 .60804 m .2464 .61002 L .24646 .60761 L F
.24444 .60804 m .24489 .61128 L .2464 .61002 L F
.545 .366 .589 r
.5927 .70356 m .59276 .70618 L .59047 .70626 L F
.8 .742 .799 r
.58965 .70329 m .59047 .70626 L .58932 .70491 L F
.58965 .70329 m .5927 .70356 L .59047 .70626 L F
.36 .324 .682 r
.24489 .61128 m .24697 .6133 L .2464 .61002 L F
.235 .301 .727 r
.24577 .61341 m .24697 .6133 L .24489 .61128 L F
.97 .661 .372 r
.6594 .50565 m .65776 .50246 L .6594 .50429 L F
.408 .13 .376 r
.4162 .66992 m .4152 .67246 L .41334 .67287 L F
.651 .377 .491 r
.41845 .67178 m .4162 .66992 L .4186 .6698 L F
.41845 .67178 m .4152 .67246 L .4162 .66992 L F
.324 .743 .976 r
.75943 .60951 m .76268 .60991 L .76163 .60964 L F
.54 .567 .831 r
.76268 .60991 m .76415 .60741 L .76163 .60964 L F
.76268 .60991 m .76515 .61062 L .76415 .60741 L F
.968 .663 .386 r
.52758 .77765 m .52902 .77631 L .52584 .77572 L F
.52758 .77765 m .52946 .77891 L .52902 .77631 L F
.757 .415 .406 r
.53279 .77897 m .52902 .77631 L .52946 .77891 L F
.933 .593 .366 r
.47296 .80393 m .47453 .80464 L .4738 .80671 L F
.162 0 0 r
.56527 .69878 m .56238 .70046 L .56476 .69976 L F
.408 0 .005 r
.56476 .69976 m .56716 .6996 L .56527 .69878 L F
.386 .007 .191 r
.56527 .69878 m .56716 .6996 L .568 .69751 L F
.671 .752 .912 r
.56342 .60139 m .56488 .60258 L .56142 .60199 L F
.678 .417 .519 r
.56297 .60422 m .56142 .60199 L .56488 .60258 L F
.504 .315 .558 r
.56808 .59914 m .56488 .60258 L .56342 .60139 L F
.56808 .59914 m .56852 .602 L .56488 .60258 L F
.672 .484 .623 r
.56852 .602 m .56297 .60422 L .56488 .60258 L F
.5 0 0 r
.5845 .6924 m .58353 .69353 L .58102 .69237 L F
.461 .49 .803 r
.58558 .68876 m .58649 .69233 L .58388 .6893 L F
.57 .564 .808 r
.58558 .68876 m .5845 .6924 L .58388 .6893 L F
.58558 .68876 m .58649 .69233 L .5845 .6924 L F
.707 .301 .276 r
.58649 .69233 m .58353 .69353 L .5845 .6924 L F
.62 .715 .914 r
.30182 .63278 m .29967 .63346 L .29864 .63192 L F
.687 .573 .721 r
.49475 .65595 m .4968 .65296 L .49423 .65337 L F
.49475 .65595 m .49789 .65619 L .4968 .65296 L F
.347 .699 .983 r
.71632 .48705 m .71456 .48797 L .71373 .48702 L F
.71632 .48705 m .71779 .4882 L .71456 .48797 L F
.872 .964 .855 r
.62192 .55508 m .61885 .55686 L .62078 .55403 L F
.69 .447 .55 r
.59698 .57965 m .6002 .57734 L .59655 .57684 L F
.59698 .57965 m .60022 .57958 L .6002 .57734 L F
.509 .251 .459 r
.60022 .57958 m .60279 .57714 L .6002 .57734 L F
.47 .704 .971 r
.49949 .63278 m .4984 .63436 L .49727 .63301 L F
.49949 .63278 m .50067 .63421 L .4984 .63436 L F
.643 .757 .932 r
.29256 .63059 m .29058 .63139 L .28897 .62983 L F
0 0 0 r
.58741 .68973 m .588 .68909 L .5885 .68712 L F
.644 .283 .344 r
.58558 .68876 m .58741 .68973 L .58649 .69233 L F
.58558 .68876 m .588 .68909 L .58741 .68973 L F
.58558 .68876 m .58764 .69048 L .588 .68909 L F
.58764 .69048 m .58785 .69066 L .588 .68909 L F
0 0 0 r
.5885 .68712 m .588 .68909 L .58885 .68629 L F
.74 .432 .46 r
.588 .68909 m .59085 .68924 L .58885 .68629 L F
.829 .427 .285 r
.58885 .68629 m .59085 .68924 L .5926 .6894 L F
.311 0 .104 r
.44031 .66143 m .43899 .66353 L .43692 .66406 L F
.723 .35 .344 r
.44234 .66355 m .44031 .66143 L .44254 .66109 L F
.44234 .66355 m .43899 .66353 L .44031 .66143 L F
.681 .61 .769 r
.64465 .5117 m .64759 .51276 L .64634 .50929 L F
.166 .309 .765 r
.41644 .69387 m .4155 .6952 L .41426 .69195 L F
.285 .478 .872 r
.41644 .69387 m .4178 .69611 L .4155 .6952 L F
0 0 0 r
.54444 .80048 m .54473 .79978 L .54566 .79866 L F
.54386 .79967 m .54566 .79866 L .54329 .79887 L F
.54444 .80048 m .54533 .79916 L .54386 .79967 L F
.54533 .79916 m .54566 .79866 L .54386 .79967 L F
.54444 .80048 m .54374 .7995 L .54388 .79944 L F
.797 .999 .834 r
.54329 .79887 m .53991 .8012 L .54388 .79944 L F
.693 .927 .968 r
.54278 .79869 m .54388 .79944 L .54152 .80049 L F
.75 .265 0 r
.54444 .80048 m .54388 .79944 L .54278 .79869 L F
.693 .927 .968 r
.54243 .79844 m .54278 .79869 L .54146 .80052 L F
.75 .265 0 r
.54291 .79892 m .54278 .79869 L .54243 .79844 L F
.54444 .80048 m .54278 .79869 L .54291 .79892 L F
.54444 .80048 m .54307 .79725 L .54462 .79873 L F
.54444 .80048 m .54243 .79844 L .54307 .79725 L F
0 0 .411 r
.54309 .79825 m .5431 .79931 L .54349 .79768 L F
.5431 .79931 m .54311 .80018 L .54321 .79952 L F
.5431 .79931 m .54321 .79952 L .54349 .79768 L F
.964 .712 .507 r
.54321 .79485 m .54462 .79873 L .54307 .79725 L F
.565 .261 .411 r
.54431 .79895 m .54321 .79485 L .54307 .79725 L F
0 0 .411 r
.54307 .79725 m .54417 .79837 L .54431 .79895 L F
.54349 .79768 m .54311 .80018 L .54417 .79837 L F
.54307 .79725 m .54309 .79825 L .54349 .79768 L F
.693 .927 .968 r
.54278 .79869 m .54152 .80049 L .54146 .80052 L F
.5401 .80099 m .54146 .80052 L .53991 .8012 L F
.54243 .79844 m .54146 .80052 L .5401 .80099 L F
.364 .835 .829 r
.64155 .48859 m .64368 .48781 L .64519 .48771 L F
.755 .663 .76 r
.64378 .4841 m .64519 .48771 L .64669 .48549 L F
.983 .909 .615 r
.64519 .48771 m .64513 .48472 L .64669 .48549 L F
.64519 .48771 m .64436 .48732 L .64513 .48472 L F
.939 .964 .73 r
.64519 .48771 m .64368 .48781 L .64436 .48732 L F
.497 .494 .784 r
.38396 .68682 m .38496 .69006 L .38678 .68857 L F
.727 .85 .939 r
.74537 .58498 m .74165 .58548 L .74574 .58527 L F
0 0 0 r
.74537 .58498 m .74643 .58199 L .74792 .58386 L F
.74537 .58498 m .74574 .58527 L .74643 .58199 L F
.567 .661 .901 r
.78681 .59382 m .78638 .59734 L .78459 .59432 L F
.78681 .59382 m .78823 .59635 L .78638 .59734 L F
.278 .048 .374 r
.78823 .59635 m .7862 .59926 L .78638 .59734 L F
.405 .192 .474 r
.51937 .69624 m .51784 .6952 L .51961 .69446 L F
.51937 .69624 m .51756 .69723 L .51784 .6952 L F
.61 .696 .904 r
.47598 .76648 m .47556 .76823 L .47415 .76603 L F
0 0 .079 r
.47598 .76648 m .47536 .7705 L .47556 .76823 L F
.798 .888 .91 r
.6451 .51089 m .64465 .5117 L .64359 .51177 L F
0 0 0 r
.61664 .55997 m .61597 .56179 L .61818 .55899 L F
.514 .732 .972 r
.26865 .6434 m .26995 .64466 L .2707 .64312 L F
.365 .552 .904 r
.26995 .64466 m .27161 .64441 L .2707 .64312 L F
0 0 0 r
.6409 .484 m .63899 .48759 L .63925 .48496 L F
.573 .274 .424 r
.58665 .59699 m .58487 .59897 L .5845 .59677 L F
.767 .678 .764 r
.54756 .78175 m .55159 .78028 L .54998 .77889 L F
.763 .766 .855 r
.55159 .78028 m .55353 .77899 L .54998 .77889 L F
.89 .969 .652 r
.59099 .53716 m .59303 .53456 L .59121 .53771 L F
.59099 .53716 m .59269 .53409 L .59303 .53456 L F
.861 .971 .656 r
.56595 .77634 m .5677 .77402 L .56603 .77558 L F
.95 .934 .593 r
.5677 .77402 m .56839 .77036 L .5669 .77337 L F
.978 .918 .643 r
.56603 .77558 m .5677 .77402 L .5669 .77337 L F
.77 .406 0 r
.68648 .48292 m .68562 .48149 L .68505 .48347 L F
.527 .865 .993 r
.68245 .53837 m .68396 .5371 L .68135 .53722 L F
.68245 .53837 m .68478 .53776 L .68396 .5371 L F
.642 .351 .462 r
.71933 .49471 m .71722 .49558 L .7189 .49244 L F
.673 .906 .568 r
.58084 .55254 m .58169 .55118 L .58289 .55003 L F
.815 .986 .716 r
.58573 .54648 m .58289 .55003 L .58381 .54792 L F
.784 .941 .592 r
.58289 .55003 m .58169 .55118 L .58381 .54792 L F
.827 .732 .76 r
.64103 .53997 m .64467 .53833 L .64361 .53721 L F
.64103 .53997 m .64273 .54109 L .64467 .53833 L F
0 0 0 r
.62092 .5279 m .61861 .52898 L .62152 .52709 L F
.62192 .52725 m .62152 .52709 L .62368 .52634 L F
.62192 .52725 m .62092 .5279 L .62152 .52709 L F
.608 .937 .952 r
.33016 .60297 m .33361 .60207 L .33244 .60265 L F
0 0 0 r
.33361 .60207 m .33388 .6021 L .33244 .60265 L F
.33361 .60207 m .33594 .60157 L .33388 .6021 L F
.678 .208 .128 r
.54185 .77947 m .53768 .77946 L .54075 .77866 L F
.934 .562 .178 r
.5422 .78117 m .54185 .77947 L .54075 .77866 L F
.712 .548 .665 r
.5422 .78117 m .5444 .7789 L .54185 .77947 L F
0 .183 .687 r
.50587 .78039 m .50418 .77925 L .50373 .77852 L F
.634 .593 .791 r
.68808 .52693 m .68466 .52899 L .68529 .52697 L F
.831 .723 .745 r
.51569 .79581 m .51885 .79398 L .51581 .79435 L F
.2 0 0 r
.71165 .48474 m .70913 .4866 L .71083 .48581 L F
.636 .151 .083 r
.71165 .48474 m .71083 .48581 L .70818 .4844 L F
.755 .295 .159 r
.71083 .48581 m .71373 .48702 L .71165 .48474 L F
.71083 .48581 m .71373 .48702 L .71165 .48474 L F
0 0 0 r
.71165 .48474 m .71261 .48455 L .71083 .48581 L F
.71165 .48474 m .71399 .48428 L .71261 .48455 L F
.742 .921 .562 r
.58573 .54648 m .58631 .54509 L .58747 .5439 L F
.76 .974 .703 r
.58573 .54648 m .58381 .54792 L .58631 .54509 L F
.69 .525 .658 r
.39137 .71232 m .39062 .71524 L .39205 .71383 L F
.268 0 .053 r
.30972 .60252 m .30679 .60409 L .30761 .60307 L F
.911 .598 .441 r
.76843 .60388 m .76963 .60253 L .76823 .60239 L F
.981 .757 .526 r
.76843 .60388 m .76949 .60546 L .76963 .60253 L F
.584 .682 .908 r
.50341 .63427 m .50207 .63642 L .50067 .63421 L F
.50341 .63427 m .5043 .63591 L .50207 .63642 L F
.022 0 .284 r
.61469 .49815 m .61298 .50152 L .61452 .50022 L F
.281 .147 .515 r
.61268 .50366 m .61452 .50022 L .61298 .50152 L F
.549 .473 .723 r
.50939 .67007 m .51152 .66968 L .51095 .66639 L F
.617 .601 .812 r
.50939 .67007 m .51311 .67227 L .51152 .66968 L F
.633 .56 .755 r
.50669 .65602 m .50801 .65267 L .50564 .65328 L F
.50669 .65602 m .50872 .65591 L .50801 .65267 L F
.698 .539 .668 r
.506 .65787 m .50872 .65591 L .50669 .65602 L F
.328 .764 .967 r
.31843 .58844 m .32058 .58827 L .32204 .58883 L F
.372 .792 .976 r
.32272 .58803 m .32204 .58883 L .32058 .58827 L F
.32272 .58803 m .32416 .58854 L .32204 .58883 L F
0 0 0 r
.61917 .54299 m .62092 .54184 L .62125 .5411 L F
.136 0 0 r
.26038 .59077 m .2621 .59037 L .26362 .58888 L F
.192 0 0 r
.2621 .59037 m .26561 .58832 L .26362 .58888 L F
.535 .342 .565 r
.41057 .67272 m .41048 .67514 L .40827 .67556 L F
.637 .548 .737 r
.41048 .67514 m .40867 .6778 L .40827 .67556 L F
.61 .366 .523 r
.60035 .59136 m .60037 .5935 L .59789 .59347 L F
.672 .416 .526 r
.60035 .59136 m .6026 .59356 L .60037 .5935 L F
.60035 .59136 m .60402 .59107 L .6026 .59356 L F
.665 .579 .749 r
.5918 .69789 m .59566 .70058 L .59374 .6976 L F
.761 .409 .388 r
.50647 .79309 m .51005 .79365 L .50993 .79558 L F
.608 .275 .38 r
.50993 .79558 m .51005 .79365 L .51173 .79562 L F
.587 .495 .717 r
.24817 .65224 m .24998 .65015 L .24714 .64995 L F
.24817 .65224 m .25001 .65333 L .24998 .65015 L F
.892 .716 .656 r
.64138 .53271 m .64361 .53721 L .64296 .53497 L F
.542 .125 .201 r
.41726 .65072 m .41597 .65249 L .41921 .65194 L F
.51 .152 .296 r
.56716 .6996 m .57003 .69725 L .568 .69751 L F
.572 .372 .571 r
.41286 .67475 m .41048 .67514 L .41057 .67272 L F
.649 .355 .46 r
.41334 .67287 m .41286 .67475 L .41057 .67272 L F
.63 .556 .752 r
.55353 .77899 m .55598 .78348 L .55713 .78219 L F
.761 .349 .269 r
.49816 .76777 m .5003 .77015 L .50132 .76854 L F
.626 .188 .189 r
.50132 .76854 m .5003 .77015 L .50396 .77008 L F
.046 .083 .576 r
.24577 .61341 m .24618 .61718 L .24712 .6155 L F
.416 .558 .889 r
.24618 .61718 m .24925 .61879 L .24712 .6155 L F
.101 .657 .765 r
.4178 .69611 m .41983 .69596 L .42112 .69598 L F
.031 .555 .862 r
.42205 .69573 m .42112 .69598 L .41983 .69596 L F
.42205 .69573 m .42325 .69628 L .42112 .69598 L F
.695 .156 0 r
.76001 .59911 m .76239 .6004 L .76005 .60034 L F
.628 .858 .986 r
.68721 .5373 m .68829 .5383 L .69052 .53741 L F
.446 .119 .316 r
.62412 .48912 m .62689 .4871 L .62472 .48789 L F
.511 .571 .853 r
.53879 .76683 m .53801 .76644 L .53834 .76654 L F
.207 0 0 r
.53703 .76693 m .53881 .76668 L .53834 .76654 L F
.331 .613 .952 r
.54042 .76646 m .53879 .76683 L .53834 .76654 L F
.207 0 0 r
.53881 .76668 m .54042 .76646 L .53834 .76654 L F
.511 .571 .853 r
.53801 .76644 m .53593 .76541 L .53834 .76654 L F
.275 0 .298 r
.37494 .60739 m .37557 .60559 L .37733 .60478 L F
.838 .905 .884 r
.5385 .80323 m .53928 .80506 L .54127 .80298 L F
.988 .893 .621 r
.53771 .80659 m .53928 .80506 L .5385 .80323 L F
.424 .328 .643 r
.55123 .71492 m .55325 .71692 L .55313 .71352 L F
.37 .321 .673 r
.55182 .71707 m .55325 .71692 L .55123 .71492 L F
.756 .413 .403 r
.52839 .78438 m .53176 .78472 L .5305 .78695 L F
.616 .25 .325 r
.53176 .78472 m .53382 .78693 L .5305 .78695 L F
.568 .536 .779 r
.63656 .51549 m .63358 .51688 L .63267 .51245 L F
.532 .471 .732 r
.63656 .51549 m .63436 .51799 L .63358 .51688 L F
.66 .41 .53 r
.60605 .59111 m .6026 .59356 L .60402 .59107 L F
.982 .869 .5 r
.6716 .53183 m .67097 .53112 L .67163 .52965 L F
.925 .907 .785 r
.67043 .53406 m .67097 .53112 L .6716 .53183 L F
.78 .576 .624 r
.6716 .53183 m .67351 .53512 L .67043 .53406 L F
.645 .391 .519 r
.63203 .49554 m .62916 .49798 L .62908 .49576 L F
.63203 .49554 m .63245 .49782 L .62916 .49798 L F
.336 0 0 r
.42341 .70782 m .42017 .7091 L .42111 .70844 L F
.558 .553 .805 r
.38921 .69748 m .39078 .70105 L .39253 .70025 L F
.509 .006 0 r
.43643 .64857 m .43874 .64903 L .44019 .6479 L F
0 0 0 r
.44019 .6479 m .44077 .64809 L .44247 .64765 L F
.44019 .6479 m .43874 .64903 L .44077 .64809 L F
.776 .581 .635 r
.51057 .80761 m .50711 .80458 L .50689 .80759 L F
.528 .669 .927 r
.47089 .65287 m .47077 .64994 L .46834 .65028 L F
.591 .626 .855 r
.47089 .65287 m .47333 .65272 L .47295 .65286 L F
.528 .669 .927 r
.47089 .65287 m .47295 .65286 L .47077 .64994 L F
.997 .797 .443 r
.59313 .57409 m .59328 .57167 L .5925 .571 L F
.309 .773 .944 r
.26675 .64371 m .2668 .64295 L .26493 .6437 L F
.26675 .64371 m .26865 .6434 L .2668 .64295 L F
0 .119 .668 r
.59566 .70058 m .59764 .70262 L .59788 .70363 L F
.696 .425 0 r
.59764 .70262 m .59848 .70591 L .59788 .70363 L F
.7 .762 .9 r
.66504 .52706 m .66846 .52782 L .66746 .52639 L F
.48 .535 .836 r
.66846 .52782 m .66974 .52546 L .66746 .52639 L F
.66846 .52782 m .67163 .52965 L .66974 .52546 L F
.339 .557 .916 r
.48615 .79084 m .48209 .78784 L .48456 .78948 L F
.338 0 .1 r
.48238 .79315 m .48615 .79084 L .48573 .79295 L F
.39 .147 .42 r
.4882 .79024 m .48615 .79084 L .48573 .79295 L F
.4882 .79024 m .48615 .79084 L .48573 .79295 L F
.123 .629 .901 r
.28823 .58371 m .29072 .58396 L .29242 .58462 L F
0 .363 .707 r
.29264 .58461 m .29242 .58462 L .29072 .58396 L F
.29264 .58461 m .2942 .5853 L .29242 .58462 L F
.397 .223 .524 r
.52236 .77079 m .52228 .77322 L .52049 .7736 L F
.108 .213 .692 r
.5224 .77607 m .52049 .7736 L .52228 .77322 L F
.858 .742 .225 r
.57071 .75743 m .57024 .76199 L .57042 .76252 L F
.957 .828 .396 r
.57024 .76199 m .57027 .7648 L .57042 .76252 L F
.625 .485 .671 r
.62128 .51507 m .61929 .51457 L .62122 .51236 L F
.652 .38 .495 r
.62305 .51361 m .62122 .51236 L .62326 .51207 L F
.52 .917 .892 r
.45965 .64276 m .46067 .64184 L .46183 .64196 L F
.45965 .64276 m .45809 .64291 L .46067 .64184 L F
0 0 .425 r
.51152 .66968 m .51311 .67227 L .51274 .67157 L F
.861 .416 .132 r
.51494 .67324 m .51274 .67157 L .51311 .67227 L F
.184 .717 .773 r
.6737 .53584 m .67351 .53512 L .67618 .53498 L F
.6737 .53584 m .67224 .53596 L .67351 .53512 L F
.6737 .53584 m .67478 .53553 L .67224 .53596 L F
.023 .291 .786 r
.6737 .53584 m .6756 .53739 L .67478 .53553 L F
.728 .299 .23 r
.47568 .68857 m .47743 .68967 L .47888 .68918 L F
.566 .058 .006 r
.47743 .68967 m .48273 .69098 L .47888 .68918 L F
.046 .083 .576 r
.24577 .61341 m .24712 .6155 L .24697 .6133 L F
.669 .764 .921 r
.47802 .65053 m .48275 .65265 L .48029 .64933 L F
.57 .653 .892 r
.48029 .64933 m .48275 .65265 L .48403 .65132 L F
.53 .345 .576 r
.38306 .68352 m .38523 .68309 L .38311 .68112 L F
.481 .488 .788 r
.38195 .67779 m .38311 .68112 L .3849 .68062 L F
.441 .344 .648 r
.38311 .68112 m .38523 .68309 L .3849 .68062 L F
.962 .942 .687 r
.59795 .71721 m .59732 .71666 L .59586 .71952 L F
.472 .24 .481 r
.57504 .692 m .57815 .68888 L .57506 .68956 L F
.772 .903 .932 r
.71237 .51816 m .71362 .51909 L .7158 .51746 L F
.178 .413 .851 r
.27161 .64441 m .27339 .64743 L .27395 .64614 L F
.173 .407 .847 r
.27339 .64743 m .27573 .64898 L .27395 .64614 L F
.44 .465 .789 r
.27339 .64743 m .27582 .65051 L .27573 .64898 L F
.567 .145 .201 r
.51186 .76247 m .51455 .76291 L .5154 .76214 L F
.377 0 0 r
.51614 .76263 m .5154 .76214 L .51455 .76291 L F
.51614 .76263 m .51721 .76285 L .5154 .76214 L F
.221 .044 .417 r
.53849 .73453 m .53977 .73394 L .5401 .73147 L F
.303 .218 .591 r
.53849 .73453 m .54009 .73635 L .53977 .73394 L F
.659 .871 .495 r
.58843 .54229 m .5896 .54091 L .58759 .54373 L F
0 0 .177 r
.58913 .54285 m .58933 .54077 L .58843 .54229 L F
.799 .919 .532 r
.58843 .54229 m .5902 .53905 L .5896 .54091 L F
.621 .783 .338 r
.58843 .54229 m .58934 .54062 L .5902 .53905 L F
0 0 .177 r
.58933 .54077 m .58934 .54062 L .58843 .54229 L F
.659 .871 .495 r
.58843 .54229 m .58759 .54373 L .58747 .5439 L F
.677 .898 .546 r
.58631 .54509 m .58843 .54229 L .58747 .5439 L F
.328 .62 .956 r
.29664 .62997 m .29563 .63112 L .29457 .63035 L F
.29664 .62997 m .29864 .63192 L .29563 .63112 L F
.369 .689 .981 r
.70731 .51098 m .70486 .51128 L .70521 .51089 L F
.70731 .51098 m .70873 .5122 L .70486 .51128 L F
.599 .622 .846 r
.62011 .52111 m .6166 .5186 L .61893 .5178 L F
.696 .638 .788 r
.62241 .51901 m .62011 .52111 L .61893 .5178 L F
.687 .626 .782 r
.62502 .54356 m .62125 .5411 L .62434 .54061 L F
.937 .802 .685 r
.62534 .54108 m .62502 .54356 L .62434 .54061 L F
.614 .308 .427 r
.48662 .78454 m .48926 .78239 L .48694 .78241 L F
.776 .614 .678 r
.56385 .59686 m .56023 .59653 L .5621 .59357 L F
.676 .565 .722 r
.56395 .59938 m .56023 .59653 L .56385 .59686 L F
.709 .59 .72 r
.56602 .59421 m .56385 .59686 L .5621 .59357 L F
.738 .497 .565 r
.56808 .59914 m .56395 .59938 L .56385 .59686 L F
.879 .715 .675 r
.47211 .6358 m .47339 .63908 L .4718 .63739 L F
.726 .848 .939 r
.47339 .63908 m .47004 .63915 L .4718 .63739 L F
.704 .638 .78 r
.47569 .63643 m .47339 .63908 L .47211 .6358 L F
.475 .583 .883 r
.75833 .60736 m .75943 .60951 L .76163 .60964 L F
.351 .799 .654 r
.69775 .53387 m .69608 .53479 L .6983 .53362 L F
.354 .803 .664 r
.69775 .53387 m .69561 .53498 L .69608 .53479 L F
.783 .891 .479 r
.5896 .54091 m .5902 .53905 L .59121 .53771 L F
.905 .9 .488 r
.5902 .53905 m .59099 .53716 L .59121 .53771 L F
.263 0 0 r
.64035 .47803 m .63914 .47814 L .64259 .47835 L F
.623 .442 .616 r
.57285 .69751 m .57116 .70039 L .57003 .69725 L F
.57285 .69751 m .57439 .70156 L .57116 .70039 L F
.089 0 .339 r
.57509 .69436 m .5747 .69642 L .57285 .69751 L F
.591 .425 .625 r
.57742 .70085 m .57285 .69751 L .5747 .69642 L F
.57742 .70085 m .57439 .70156 L .57285 .69751 L F
.574 .313 .484 r
.57845 .59982 m .57607 .60214 L .57481 .59923 L F
.57845 .59982 m .57868 .60177 L .57607 .60214 L F
.279 0 .108 r
.33217 .6239 m .33389 .62407 L .3351 .62211 L F
.476 .28 .535 r
.3351 .62211 m .33714 .62151 L .33727 .61928 L F
.408 .047 .238 r
.33389 .62407 m .33714 .62151 L .3351 .62211 L F
.786 .464 .445 r
.54331 .78529 m .54683 .78764 L .54577 .78476 L F
.122 0 0 r
.54224 .78635 m .54331 .78529 L .54577 .78476 L F
.821 .66 .684 r
.54577 .78476 m .54571 .78208 L .54471 .78239 L F
.122 0 0 r
.54164 .78662 m .54577 .78476 L .54255 .78639 L F
.821 .66 .684 r
.54577 .78476 m .54471 .78239 L .54508 .78261 L F
.892 .857 .801 r
.54255 .78639 m .54577 .78476 L .54508 .78261 L F
.332 .11 .419 r
.54582 .78583 m .54379 .78618 L .54508 .78261 L F
.54379 .78618 m .54255 .78639 L .54261 .78631 L F
.54379 .78618 m .54261 .78631 L .54508 .78261 L F
.122 0 0 r
.54164 .78662 m .54194 .78638 L .54224 .78635 L F
.54194 .78638 m .54331 .78529 L .54224 .78635 L F
0 0 .4 r
.51345 .79227 m .5128 .79019 L .51589 .7889 L F
.537 .214 .368 r
.51696 .78785 m .51675 .78946 L .51589 .7889 L F
0 0 .4 r
.51589 .78894 m .51589 .7889 L .51617 .78878 L F
.537 .214 .368 r
.51583 .78793 m .51589 .7889 L .51458 .78803 L F
.512 .232 .426 r
.51617 .78878 m .51589 .7889 L .51458 .78803 L F
.514 .228 .417 r
.51458 .78803 m .51589 .78894 L .51617 .78878 L F
.537 .214 .368 r
.51675 .78946 m .51674 .78953 L .51458 .78803 L F
.514 .228 .417 r
.51589 .78894 m .51674 .78953 L .51617 .78878 L F
0 0 .4 r
.5159 .78912 m .51589 .78894 L .51617 .78878 L F
.51345 .79227 m .51589 .7889 L .5159 .78912 L F
.537 .214 .368 r
.51696 .78785 m .51589 .7889 L .51583 .78793 L F
.512 .232 .426 r
.51589 .7889 m .5128 .79019 L .51458 .78803 L F
.564 .683 .92 r
.69077 .47528 m .68943 .47748 L .68853 .47604 L F
.69077 .47528 m .69204 .47755 L .68943 .47748 L F
0 0 0 r
.63198 .56295 m .631 .5645 L .62977 .56587 L F
.631 .5645 m .62881 .56734 L .62977 .56587 L F
.831 .865 .871 r
.59556 .70841 m .59739 .70738 L .59664 .7073 L F
.997 .835 .555 r
.59739 .70738 m .59625 .71118 L .59556 .70841 L F
0 .101 .58 r
.59698 .70748 m .59523 .70545 L .59664 .7073 L F
.429 0 0 r
.59739 .70738 m .59862 .70831 L .59664 .7073 L F
.59739 .70738 m .59932 .70884 L .59862 .70831 L F
.59932 .70884 m .59967 .70911 L .59862 .70831 L F
.997 .835 .555 r
.59722 .70795 m .59704 .71259 L .59625 .71118 L F
.59734 .70818 m .59704 .71259 L .59722 .70795 L F
.898 .556 .39 r
.59556 .70841 m .59625 .71118 L .59436 .70975 L F
.782 .705 .779 r
.59862 .70831 m .59436 .70975 L .59787 .70775 L F
0 .101 .58 r
.59779 .70761 m .59797 .7077 L .59523 .70545 L F
.59862 .70831 m .59797 .7077 L .59779 .70761 L F
.989 .814 .428 r
.59832 .70535 m .59797 .7077 L .59862 .70831 L F
.664 .259 0 r
.59823 .70782 m .59797 .7077 L .59792 .70647 L F
.782 .705 .779 r
.59862 .70831 m .59787 .70775 L .59797 .7077 L F
0 .101 .58 r
.59862 .70831 m .5965 .70652 L .59698 .70748 L F
.887 .883 .824 r
.59967 .70911 m .59704 .71259 L .59625 .71118 L F
.585 .412 .613 r
.60011 .71154 m .59704 .71259 L .59967 .70911 L F
.887 .883 .824 r
.59967 .70911 m .59625 .71118 L .59862 .70831 L F
.001 .227 .738 r
.59862 .70831 m .60011 .71154 L .59967 .70911 L F
.59862 .70831 m .60067 .71033 L .60011 .71154 L F
.782 .705 .779 r
.59862 .70831 m .59625 .71118 L .59436 .70975 L F
.865 .447 .225 r
.59797 .7077 m .5992 .70997 L .60067 .71033 L F
.664 .259 0 r
.59846 .70879 m .59797 .7077 L .59823 .70782 L F
0 .101 .58 r
.5965 .70652 m .59523 .70545 L .59698 .70748 L F
.997 .835 .555 r
.59739 .70738 m .59734 .70818 L .59722 .70795 L F
.111 .664 .757 r
.49421 .69562 m .48985 .69591 L .49142 .69489 L F
.908 .916 .813 r
.49385 .6942 m .49214 .69571 L .49421 .69562 L F
.49378 .69393 m .49327 .69448 L .49385 .6942 L F
.49327 .69448 m .49214 .69571 L .49385 .6942 L F
.524 .063 .1 r
.49035 .69318 m .4932 .6945 L .4935 .69262 L F
.4932 .6945 m .49322 .6945 L .4935 .69262 L F
.49321 .69451 m .49338 .69443 L .4935 .69262 L F
0 0 .05 r
.4935 .69262 m .49337 .69458 L .49378 .69393 L F
.021 .231 .737 r
.49107 .69297 m .49297 .69433 L .49378 .69393 L F
0 .349 .782 r
.49107 .69297 m .4932 .6945 L .49035 .69318 L F
.021 .231 .737 r
.49183 .69491 m .49327 .69448 L .49378 .69393 L F
.49183 .69491 m .49214 .69571 L .49327 .69448 L F
.524 .063 .1 r
.4932 .6945 m .49321 .69451 L .49322 .6945 L F
0 .349 .782 r
.49107 .69297 m .49337 .69458 L .4932 .6945 L F
.021 .231 .737 r
.49107 .69297 m .49183 .69491 L .49297 .69433 L F
.524 .063 .1 r
.49321 .69451 m .49337 .69458 L .49338 .69443 L F
0 0 .05 r
.4935 .69262 m .49378 .69393 L .49563 .69443 L F
.972 .705 .466 r
.50524 .78747 m .50661 .79059 L .50524 .78988 L F
.998 .782 .449 r
.50661 .79059 m .50559 .79244 L .50524 .78988 L F
.50661 .79059 m .50647 .79309 L .50559 .79244 L F
.334 .632 .961 r
.64187 .48653 m .641 .48802 L .64099 .48739 L F
.7 .831 .945 r
.6409 .484 m .64157 .48511 L .64378 .4841 L F
.777 .741 .82 r
.64348 .48169 m .6409 .484 L .64378 .4841 L F
.85 .789 .792 r
.64348 .48169 m .64378 .4841 L .6456 .48128 L F
.599 .913 .658 r
.64236 .48239 m .6411 .48378 L .64264 .48242 L F
.6411 .48378 m .64115 .48377 L .64348 .48169 L F
.334 .632 .961 r
.64169 .48602 m .64099 .48739 L .64097 .48628 L F
.64133 .48492 m .64097 .48628 L .64094 .48375 L F
.64169 .48602 m .64097 .48628 L .64133 .48492 L F
.64115 .48437 m .64095 .48379 L .641 .4846 L F
.64158 .48567 m .64115 .48437 L .641 .4846 L F
.833 .669 .68 r
.64448 .48316 m .64209 .48663 L .641 .4846 L F
.64209 .48663 m .64197 .4868 L .641 .4846 L F
.628 .689 .888 r
.64197 .4868 m .64208 .48665 L .641 .4846 L F
.334 .632 .961 r
.6416 .48574 m .64158 .48567 L .641 .4846 L F
.599 .913 .658 r
.6411 .48378 m .6409 .484 L .64115 .48377 L F
0 0 0 r
.64236 .48239 m .64094 .48375 L .6409 .484 L F
.334 .632 .961 r
.64095 .48379 m .64094 .48375 L .64094 .48379 L F
.64095 .48379 m .64094 .48379 L .641 .4846 L F
0 0 0 r
.64236 .48239 m .641 .4846 L .64094 .48375 L F
.833 .669 .68 r
.64153 .48438 m .641 .4846 L .64147 .48383 L F
.724 .79 .307 r
.64094 .48375 m .64 .48623 L .6409 .484 L F
.897 .518 .065 r
.64089 .48758 m .64055 .4882 L .63899 .48759 L F
.64 .48623 m .641 .48802 L .64155 .48859 L F
.853 .713 .707 r
.64094 .48375 m .641 .48802 L .64 .48623 L F
.706 .363 .394 r
.63839 .48228 m .63997 .48385 L .64236 .48239 L F
.63997 .48385 m .64083 .48472 L .64143 .48415 L F
.628 .689 .888 r
.64119 .48495 m .64133 .48453 L .641 .4846 L F
0 0 0 r
.641 .4846 m .64103 .48491 L .64139 .48422 L F
.833 .669 .68 r
.64153 .48438 m .64147 .48383 L .64236 .48239 L F
0 0 0 r
.641 .4846 m .64139 .48422 L .64236 .48239 L F
.706 .363 .394 r
.63997 .48385 m .64143 .48415 L .64236 .48239 L F
.812 .872 .434 r
.64176 .48328 m .64131 .48428 L .64194 .4826 L F
.518 .845 .555 r
.64141 .48421 m .64022 .48527 L .641 .4846 L F
.64146 .48416 m .64083 .48472 L .64141 .48421 L F
.64083 .48472 m .64022 .48527 L .64141 .48421 L F
.722 .356 .355 r
.63799 .48376 m .64074 .4848 L .63839 .48228 L F
.91 .532 .297 r
.64016 .48532 m .64187 .48653 L .641 .4846 L F
.722 .356 .355 r
.64074 .4848 m .64103 .48491 L .64083 .48472 L F
.64074 .4848 m .64083 .48472 L .63839 .48228 L F
.706 .363 .394 r
.64083 .48472 m .64103 .48491 L .64139 .48422 L F
.833 .669 .68 r
.64448 .48316 m .64153 .48438 L .64236 .48239 L F
.518 .845 .555 r
.64146 .48416 m .641 .4846 L .64225 .48432 L F
.812 .872 .434 r
.64131 .48428 m .64103 .48491 L .64126 .48432 L F
.64131 .48428 m .64126 .48432 L .64194 .4826 L F
.64163 .48376 m .64152 .48397 L .64176 .48328 L F
.64152 .48397 m .64103 .48491 L .64176 .48328 L F
.64236 .48239 m .64163 .48376 L .64204 .48235 L F
.64163 .48376 m .64194 .4826 L .64204 .48235 L F
.812 .558 .554 r
.64259 .47835 m .64348 .48169 L .6456 .48128 L F
.704 .358 .388 r
.63862 .47984 m .64236 .48239 L .64316 .48036 L F
.533 .253 .436 r
.63862 .47984 m .64289 .47954 L .64145 .47829 L F
0 0 .196 r
.64283 .47912 m .64348 .48169 L .64259 .47835 L F
.533 .253 .436 r
.64294 .47954 m .6435 .4795 L .64282 .4791 L F
0 0 .196 r
.64285 .4792 m .64288 .47933 L .64283 .47912 L F
.64288 .47933 m .64348 .48169 L .64283 .47912 L F
.533 .253 .436 r
.64289 .47954 m .64294 .47954 L .64217 .47872 L F
.64294 .47954 m .64283 .47912 L .64218 .47873 L F
0 0 .196 r
.64289 .47932 m .64283 .47912 L .64145 .47829 L F
.64283 .47912 m .64259 .47835 L .64145 .47829 L F
.533 .253 .436 r
.64218 .47873 m .64282 .4791 L .64217 .47872 L F
.64283 .47912 m .64282 .4791 L .64218 .47873 L F
.64289 .47954 m .64217 .47872 L .64145 .47829 L F
.704 .358 .388 r
.64297 .47966 m .64326 .48009 L .6435 .4795 L F
0 0 0 r
.64326 .48009 m .64297 .47966 L .64326 .48008 L F
.64416 .48144 m .64348 .48169 L .64297 .47966 L F
.704 .358 .388 r
.64297 .47966 m .64316 .48036 L .64326 .48009 L F
0 0 .196 r
.64297 .47966 m .64348 .48169 L .64285 .4792 L F
.704 .358 .388 r
.63862 .47984 m .64316 .48036 L .64294 .47954 L F
.811 .87 .43 r
.64322 .47998 m .64236 .48239 L .64281 .4804 L F
.64326 .48009 m .64236 .48239 L .64329 .47976 L F
0 0 0 r
.64416 .48144 m .64326 .48009 L .64326 .48008 L F
.64416 .48144 m .64296 .47962 L .64329 .48 L F
.64426 .4814 m .64416 .48144 L .64289 .47932 L F
.857 .405 .029 r
.64328 .47991 m .64281 .4804 L .64426 .4814 L F
0 0 0 r
.64326 .48008 m .64297 .47966 L .64296 .47962 L F
.64329 .48 m .64296 .47962 L .64289 .47932 L F
0 0 .196 r
.64289 .47932 m .64297 .47966 L .64285 .4792 L F
.857 .405 .029 r
.64289 .47932 m .64281 .4804 L .64328 .47991 L F
.811 .87 .43 r
.64329 .47976 m .64322 .47998 L .64281 .4804 L F
.6435 .4795 m .64326 .48009 L .64329 .47976 L F
.704 .358 .388 r
.64294 .47954 m .64297 .47966 L .6435 .4795 L F
.63862 .47984 m .63839 .48228 L .64236 .48239 L F
.812 .872 .434 r
.64236 .48239 m .64204 .48235 L .64281 .4804 L F
.599 .913 .658 r
.64236 .48239 m .64264 .48242 L .64348 .48169 L F
0 0 0 r
.64426 .4814 m .64236 .48239 L .64348 .48169 L F
.833 .669 .68 r
.64448 .48316 m .64236 .48239 L .64426 .4814 L F
.645 .843 .976 r
.64426 .4814 m .64236 .48239 L .64281 .4804 L F
.328 .188 .533 r
.64281 .4804 m .64126 .48432 L .64298 .48268 L F
.518 .845 .555 r
.64298 .48268 m .64128 .4843 L .64146 .48416 L F
.706 .363 .394 r
.64083 .48472 m .64139 .48422 L .64143 .48415 L F
.518 .845 .555 r
.64114 .48441 m .64139 .48422 L .64146 .48416 L F
.94 .871 .742 r
.64436 .48732 m .64197 .4868 L .64448 .48316 L F
.518 .845 .555 r
.64298 .48268 m .64146 .48416 L .64412 .48391 L F
.64146 .48416 m .64225 .48432 L .64412 .48391 L F
.328 .188 .533 r
.64126 .48432 m .64103 .48491 L .64298 .48268 L F
.518 .845 .555 r
.64298 .48268 m .64114 .48441 L .64128 .4843 L F
.64114 .48441 m .64022 .48527 L .64139 .48422 L F
.731 .386 .395 r
.63938 .4852 m .64052 .485 L .63799 .48376 L F
.64052 .485 m .64103 .48491 L .64074 .4848 L F
.64052 .485 m .64074 .4848 L .63799 .48376 L F
.518 .845 .555 r
.64027 .48522 m .64016 .48532 L .64022 .48527 L F
.731 .386 .395 r
.64052 .485 m .64016 .48532 L .64103 .48491 L F
.63938 .4852 m .64016 .48532 L .64052 .485 L F
.518 .845 .555 r
.64028 .48522 m .64016 .48532 L .64027 .48522 L F
.64245 .48317 m .64017 .48531 L .64028 .48522 L F
.64017 .48531 m .64016 .48532 L .64028 .48522 L F
.64298 .48268 m .64247 .48315 L .64245 .48317 L F
.64247 .48315 m .64016 .48532 L .64245 .48317 L F
.628 .689 .888 r
.64208 .48665 m .64133 .48453 L .64119 .48495 L F
.102 .657 .751 r
.641 .48802 m .64368 .48781 L .64155 .48859 L F
.94 .871 .742 r
.64436 .48732 m .64448 .48316 L .64513 .48472 L F
.962 .651 .385 r
.64368 .48781 m .64197 .4868 L .64436 .48732 L F
.102 .657 .751 r
.641 .48802 m .64276 .48783 L .64368 .48781 L F
.962 .651 .385 r
.64368 .48781 m .64276 .48783 L .64197 .4868 L F
.628 .689 .888 r
.64197 .4868 m .64276 .48783 L .64537 .48618 L F
.64197 .4868 m .64537 .48618 L .64412 .48391 L F
.656 .341 .427 r
.64187 .48653 m .64405 .48862 L .64508 .48671 L F
.64396 .48632 m .64508 .48671 L .64537 .48618 L F
.64187 .48653 m .64508 .48671 L .64396 .48632 L F
.628 .689 .888 r
.64169 .48554 m .64412 .48391 L .64133 .48453 L F
.64208 .48665 m .64266 .48587 L .64169 .48554 L F
.64266 .48587 m .64412 .48391 L .64169 .48554 L F
.334 .632 .961 r
.64171 .48606 m .6417 .48607 L .64169 .48602 L F
.64187 .48653 m .6416 .48574 L .641 .4846 L F
.6417 .48607 m .64099 .48739 L .64169 .48602 L F
.64187 .48653 m .64099 .48739 L .64163 .4862 L F
.64187 .48653 m .64276 .48783 L .641 .48802 L F
0 .1 .581 r
.64016 .48532 m .64227 .48711 L .64187 .48653 L F
.64227 .48711 m .64405 .48862 L .64187 .48653 L F
.334 .632 .961 r
.64187 .48653 m .64163 .4862 L .64171 .48606 L F
.897 .518 .065 r
.64 .48623 m .64089 .48758 L .63899 .48759 L F
.64089 .48758 m .64155 .48859 L .64055 .4882 L F
.737 .299 .213 r
.62672 .52698 m .62556 .52813 L .62368 .52634 L F
.859 .478 .324 r
.62672 .52698 m .62768 .52899 L .62556 .52813 L F
.716 .833 .937 r
.58965 .70329 m .59348 .70161 L .5927 .70356 L F
.703 .697 .842 r
.59054 .69969 m .59348 .70161 L .58965 .70329 L F
.626 .082 0 r
.59054 .69969 m .5929 .70161 L .59348 .70161 L F
.672 .26 .256 r
.59348 .70161 m .59461 .70163 L .5927 .70356 L F
.626 .082 0 r
.5929 .70161 m .59383 .70236 L .59348 .70161 L F
.672 .26 .256 r
.59348 .70161 m .59566 .70058 L .59461 .70163 L F
.542 .363 .588 r
.5927 .70356 m .59523 .70545 L .59276 .70618 L F
.5927 .70356 m .59523 .70545 L .59276 .70618 L F
.312 .624 .959 r
.33968 .6023 m .3401 .60102 L .33802 .60179 L F
.33968 .6023 m .3413 .6023 L .3401 .60102 L F
.559 .47 .711 r
.33968 .6023 m .34258 .60537 L .3413 .6023 L F
.33968 .6023 m .34032 .60595 L .34258 .60537 L F
.303 .754 .958 r
.70009 .48568 m .70151 .48496 L .699 .48464 L F
.70009 .48568 m .70317 .48564 L .70151 .48496 L F
.631 .182 .168 r
.49955 .77582 m .50321 .77544 L .50167 .77604 L F
.829 .52 .466 r
.50167 .77604 m .50373 .77852 L .50321 .77544 L F
.631 .182 .168 r
.49955 .77582 m .50321 .77544 L .50167 .77604 L F
0 0 0 r
.50167 .77604 m .50321 .77544 L .5055 .77485 L F
.394 .21 .509 r
.24603 .6051 m .24802 .60202 L .24601 .60259 L F
.927 .566 .143 r
.66856 .51674 m .66851 .51593 L .66753 .51506 L F
.946 .917 .752 r
.66753 .51506 m .66851 .51593 L .67005 .51222 L F
.456 .115 .297 r
.67106 .51538 m .66851 .51593 L .66856 .51674 L F
.515 .46 .733 r
.41144 .68078 m .40941 .6812 L .40867 .6778 L F
.51 .436 .708 r
.41144 .68078 m .41197 .68327 L .40941 .6812 L F
.516 .436 .704 r
.40941 .6812 m .41197 .68327 L .4099 .68357 L F
.321 .516 .891 r
.50839 .64048 m .50996 .64068 L .50886 .64209 L F
.33 .529 .898 r
.50996 .64068 m .51172 .64338 L .50886 .64209 L F
.371 0 0 r
.29552 .64889 m .29955 .6483 L .29722 .64867 L F
.154 .643 .919 r
.29955 .6483 m .30014 .64777 L .29722 .64867 L F
.29955 .6483 m .30162 .64845 L .30014 .64777 L F
.205 .663 .945 r
.29955 .6483 m .30155 .64871 L .30162 .64845 L F
.298 0 .173 r
.34944 .6317 m .34846 .63024 L .35031 .63034 L F
.34944 .6317 m .34747 .63229 L .34846 .63024 L F
.749 .274 .118 r
.56544 .72571 m .56398 .72589 L .56138 .72362 L F
.297 0 0 r
.5678 .7258 m .56398 .72589 L .56544 .72571 L F
.166 .64 .929 r
.64873 .48513 m .64669 .48549 L .64513 .48472 L F
.021 .495 .876 r
.64448 .48316 m .64787 .48424 L .64873 .48513 L F
.85 .519 .427 r
.64781 .48442 m .64873 .48513 L .64787 .48424 L F
.166 .64 .929 r
.64873 .48513 m .64971 .48588 L .64669 .48549 L F
.021 .495 .876 r
.64448 .48316 m .64873 .48513 L .64513 .48472 L F
.85 .519 .427 r
.64718 .48631 m .64873 .48513 L .64781 .48442 L F
.166 .64 .929 r
.64873 .48513 m .65027 .48595 L .64971 .48588 L F
.495 .648 .925 r
.77408 .58264 m .77588 .58116 L .7734 .58119 L F
.407 .483 .826 r
.77408 .58264 m .77596 .58286 L .77588 .58116 L F
.826 .868 .876 r
.70509 .48517 m .70614 .48686 L .70818 .4844 L F
.607 .506 .713 r
.70614 .48686 m .70913 .4866 L .70818 .4844 L F
.672 .26 .256 r
.59348 .70161 m .59383 .70236 L .59566 .70058 L F
.769 .651 .731 r
.59374 .6976 m .59566 .70058 L .59667 .69777 L F
.662 .122 0 r
.59624 .70183 m .59566 .70058 L .59383 .70236 L F
.59624 .70183 m .59764 .70262 L .59566 .70058 L F
.134 0 .144 r
.37249 .60983 m .37325 .60842 L .37494 .60739 L F
.068 .134 .624 r
.65776 .49287 m .65826 .49582 L .65857 .49509 L F
0 0 .053 r
.65825 .49842 m .65857 .49509 L .65826 .49582 L F
.351 .212 .547 r
.28414 .61912 m .28412 .62152 L .28261 .62196 L F
.413 .31 .629 r
.2844 .62358 m .28261 .62196 L .28412 .62152 L F
.2844 .62358 m .28287 .62411 L .28261 .62196 L F
.765 .682 .77 r
.52729 .79319 m .52515 .7965 L .52414 .79292 L F
.55 .397 .627 r
.52729 .79319 m .52786 .79621 L .52515 .7965 L F
.395 0 .12 r
.52515 .7965 m .52699 .79724 L .5242 .79723 L F
.52515 .7965 m .52786 .79621 L .52699 .79724 L F
.476 .465 .766 r
.5148 .64651 m .51377 .65022 L .51286 .64677 L F
.5148 .64651 m .51575 .64993 L .51377 .65022 L F
.035 0 0 r
.54981 .75144 m .55224 .75131 L .55327 .75111 L F
0 0 0 r
.55327 .75111 m .55427 .75043 L .55521 .74921 L F
.383 .841 .778 r
.55224 .75131 m .55427 .75043 L .55327 .75111 L F
.358 .164 .475 r
.42869 .66639 m .42676 .66942 L .42699 .6671 L F
.476 .309 .575 r
.28605 .61841 m .28438 .61674 L .28646 .61607 L F
.28605 .61841 m .28414 .61912 L .28438 .61674 L F
.461 .1 .264 r
.29922 .60523 m .29788 .60758 L .29579 .60755 L F
.462 .1 .265 r
.30075 .60654 m .29922 .60523 L .30141 .60466 L F
.30075 .60654 m .29788 .60758 L .29922 .60523 L F
.773 .689 .145 r
.59629 .55954 m .59605 .56224 L .59621 .56038 L F
0 0 0 r
.56124 .70866 m .56053 .7108 L .55938 .71195 L F
.695 .577 .719 r
.4968 .65296 m .49789 .65619 L .50049 .65356 L F
.669 .145 0 r
.71291 .48986 m .71166 .48995 L .7099 .4889 L F
.419 0 0 r
.71625 .49134 m .71166 .48995 L .71291 .48986 L F
.703 .956 .688 r
.5793 .55364 m .58084 .55254 L .5797 .55394 L F
.5793 .55364 m .58169 .55118 L .58084 .55254 L F
.449 .053 .195 r
.61861 .52898 m .61799 .53089 L .61563 .53115 L F
.366 0 .166 r
.61993 .52941 m .61861 .52898 L .62092 .5279 L F
.61993 .52941 m .61799 .53089 L .61861 .52898 L F
0 0 .324 r
.48333 .78656 m .4826 .78519 L .48272 .78421 L F
.48333 .78656 m .48209 .78784 L .4826 .78519 L F
0 0 0 r
.69376 .52384 m .69149 .52669 L .69284 .52522 L F
.597 .905 .983 r
.69284 .52522 m .69149 .52669 L .69057 .52613 L F
.611 .469 .664 r
.38224 .66423 m .38474 .66413 L .38429 .6609 L F
.544 .464 .715 r
.38224 .66423 m .38493 .66657 L .38474 .66413 L F
.38224 .66423 m .38285 .66705 L .38493 .66657 L F
.895 .851 .792 r
.62534 .54108 m .62434 .54061 L .62632 .5375 L F
.786 .545 .572 r
.47793 .80993 m .48144 .81022 L .48127 .81267 L F
.889 .92 .837 r
.48063 .80923 m .48144 .81022 L .4837 .80738 L F
.997 .773 .427 r
.48127 .81267 m .48144 .81022 L .48063 .80923 L F
.8 .631 .672 r
.54577 .78476 m .5495 .78444 L .54756 .78175 L F
.693 .305 .309 r
.54778 .78669 m .5495 .78444 L .54577 .78476 L F
.753 .382 .352 r
.55103 .78692 m .5495 .78444 L .54778 .78669 L F
.174 .253 .706 r
.55286 .78908 m .5495 .78444 L .55103 .78692 L F
.774 .596 .658 r
.75161 .58368 m .74792 .58386 L .74984 .58218 L F
.75161 .58368 m .75074 .58656 L .74792 .58386 L F
.468 .833 .993 r
.29631 .58485 m .29784 .58543 L .2942 .5853 L F
.412 .738 .992 r
.29841 .58427 m .29784 .58543 L .29631 .58485 L F
.29841 .58427 m .29992 .58532 L .29784 .58543 L F
.492 0 0 r
.75569 .59646 m .76001 .59911 L .75659 .59765 L F
.311 .795 .896 r
.27994 .65235 m .27878 .65219 L .2767 .65259 L F
.441 0 0 r
.28238 .65105 m .27878 .65219 L .27994 .65235 L F
.168 .456 .883 r
.4952 .79006 m .49352 .78739 L .49362 .78969 L F
.731 .476 .543 r
.4918 .79302 m .49509 .79303 L .49362 .78969 L F
.728 .472 .54 r
.49521 .79318 m .49362 .78969 L .49509 .79303 L F
0 0 0 r
.49302 .792 m .49362 .78969 L .49476 .78879 L F
.689 .277 .26 r
.49488 .78837 m .49757 .7878 L .49642 .78947 L F
.49513 .78755 m .49757 .7878 L .49488 .78837 L F
.223 .23 .656 r
.49528 .78837 m .49352 .78739 L .49597 .78916 L F
.49528 .78837 m .49597 .78916 L .49642 .78947 L F
.689 .277 .26 r
.49352 .78739 m .49513 .78755 L .49488 .78837 L F
0 0 0 r
.49342 .78586 m .49324 .78607 L .49528 .78837 L F
.223 .23 .656 r
.49528 .78837 m .49362 .78969 L .49352 .78739 L F
0 0 0 r
.49324 .78607 m .49147 .78829 L .49528 .78837 L F
.49451 .7896 m .49476 .78879 L .49528 .78837 L F
.49302 .792 m .49476 .78879 L .49451 .7896 L F
.972 .893 .527 r
.49757 .7878 m .49671 .79101 L .49642 .78947 L F
.579 .012 0 r
.65276 .49378 m .65427 .49459 L .65223 .49285 L F
.65276 .49378 m .65223 .49285 L .65302 .49174 L F
0 .401 .769 r
.48892 .69238 m .48806 .69224 L .4866 .69167 L F
.48892 .69238 m .49035 .69318 L .48806 .69224 L F
.534 .325 .542 r
.69376 .51436 m .69134 .51266 L .69138 .51501 L F
.69311 .5139 m .69379 .51188 L .69134 .51266 L F
.69376 .51436 m .69377 .51349 L .69311 .5139 L F
.69377 .51349 m .69379 .51188 L .69311 .5139 L F
.165 0 0 r
.693 .51317 m .69134 .51266 L .69138 .51501 L F
.684 .975 .904 r
.69138 .515 m .69083 .51467 L .693 .51317 L F
.69138 .51501 m .69137 .51501 L .69138 .515 L F
.69137 .51501 m .69083 .51467 L .69138 .515 L F
.165 0 0 r
.693 .51317 m .69379 .51188 L .69134 .51266 L F
.547 .758 .975 r
.71687 .47794 m .71765 .47708 L .71852 .47838 L F
.3 .371 .769 r
.71533 .47575 m .71763 .47707 L .71687 .47794 L F
.71533 .47575 m .71687 .47794 L .71612 .47876 L F
.71763 .47707 m .71765 .47708 L .71712 .47766 L F
.71763 .47707 m .71687 .47795 L .71687 .47794 L F
.547 .758 .975 r
.71687 .47794 m .71765 .47708 L .7154 .47755 L F
.71852 .47838 m .71765 .47708 L .71687 .47794 L F
.3 .371 .769 r
.71712 .47766 m .71765 .47708 L .71687 .47795 L F
.547 .758 .975 r
.71687 .47794 m .71852 .47838 L .71613 .47879 L F
.3 .371 .769 r
.71687 .47794 m .71687 .47795 L .71613 .47879 L F
.71612 .47876 m .71687 .47794 L .71613 .47879 L F
.547 .758 .975 r
.7154 .47755 m .71687 .47794 L .71613 .47879 L F
.7176 .47981 m .7154 .47755 L .71647 .48155 L F
.71852 .47838 m .71687 .47794 L .7176 .47981 L F
.71687 .47794 m .7154 .47755 L .7176 .47981 L F
.7154 .47755 m .71765 .47708 L .71687 .47794 L F
.983 .893 .556 r
.6276 .53218 m .62645 .53348 L .62729 .53127 L F
.6276 .53218 m .62695 .53533 L .62645 .53348 L F
.991 .886 .592 r
.62632 .5375 m .62645 .53348 L .62695 .53533 L F
.786 .655 .718 r
.53472 .76214 m .5385 .76305 L .53778 .75964 L F
.844 .907 .879 r
.53469 .76469 m .5385 .76305 L .53472 .76214 L F
.003 .107 .622 r
.53778 .75964 m .5385 .76305 L .53959 .76225 L F
.429 .872 .86 r
.5385 .76305 m .54061 .76221 L .53959 .76225 L F
.155 0 .085 r
.34305 .63555 m .3404 .6379 L .34105 .63614 L F
.053 .26 .755 r
.71699 .49895 m .71903 .49935 L .71683 .49758 L F
.782 .546 .579 r
.72107 .50125 m .72116 .5037 L .72037 .5036 L F
.71943 .50224 m .72037 .5036 L .71777 .50324 L F
.72107 .50125 m .72037 .5036 L .71943 .50224 L F
.72107 .50125 m .71943 .50224 L .72042 .50338 L F
.71943 .50224 m .71777 .50324 L .72042 .50338 L F
.775 .49 .504 r
.72107 .50125 m .72042 .50338 L .71935 .50028 L F
.71727 .4991 m .72042 .50338 L .71699 .49895 L F
.053 .26 .755 r
.71718 .49898 m .72042 .50338 L .71903 .49935 L F
.71699 .49895 m .71851 .50091 L .71718 .49898 L F
.71851 .50091 m .72042 .50338 L .71718 .49898 L F
.77 .649 .729 r
.59497 .69472 m .59374 .6976 L .59667 .69777 L F
.736 .52 .599 r
.59451 .57947 m .59655 .57684 L .5944 .57693 L F
.59451 .57947 m .59698 .57965 L .59655 .57684 L F
.625 .59 .794 r
.50377 .65832 m .50701 .65917 L .506 .65787 L F
0 .039 .564 r
.49151 .78405 m .49277 .78557 L .49342 .78586 L F
.945 .72 .567 r
.56235 .74215 m .56359 .74505 L .56375 .74279 L F
.522 .234 .418 r
.44529 .6915 m .44816 .68871 L .44619 .68922 L F
.617 .215 0 r
.48341 .8126 m .48496 .8153 L .48356 .81289 L F
.646 .637 .827 r
.51811 .79919 m .52043 .80189 L .52202 .80081 L F
.48 .218 .439 r
.55781 .76439 m .55566 .76513 L .55589 .76284 L F
.712 .478 .569 r
.49496 .76768 m .4973 .76579 L .4947 .76508 L F
.49496 .76768 m .49816 .76777 L .4973 .76579 L F
.327 .292 .666 r
.47035 .77036 m .4705 .77388 L .47243 .77241 L F
.364 .357 .718 r
.4705 .77388 m .47261 .77675 L .47243 .77241 L F
.472 .173 .377 r
.24795 .65518 m .2512 .65581 L .24805 .6554 L F
0 .48 .845 r
.2512 .65581 m .24792 .65564 L .24805 .6554 L F
.472 .173 .377 r
.24795 .65518 m .25023 .65505 L .25001 .65333 L F
.931 .555 .172 r
.24857 .65243 m .25023 .65505 L .25001 .65333 L F
.004 .287 .785 r
.2494 .65374 m .25044 .65388 L .25023 .65505 L F
.24857 .65243 m .25044 .65388 L .2494 .65374 L F
.605 .273 .381 r
.25044 .65388 m .25354 .65404 L .25246 .65529 L F
.113 0 0 r
.25188 .65399 m .25044 .65388 L .25246 .65529 L F
.25188 .65399 m .25175 .65405 L .25044 .65388 L F
.814 .974 .673 r
.25044 .65388 m .25031 .65405 L .25023 .65505 L F
0 .48 .845 r
.25017 .65575 m .25023 .65505 L .24792 .65564 L F
.517 .587 .864 r
.24857 .65243 m .25023 .65505 L .24795 .65518 L F
0 0 0 r
.25023 .65505 m .24684 .65724 L .24792 .65564 L F
.25023 .65505 m .24843 .6566 L .24684 .65724 L F
.814 .974 .673 r
.25031 .65405 m .24843 .6566 L .25023 .65505 L F
.8 .967 .657 r
.24882 .65524 m .24843 .6566 L .25044 .65388 L F
.113 0 0 r
.25175 .65405 m .24882 .65524 L .25044 .65388 L F
0 .48 .845 r
.2512 .65581 m .25023 .65505 L .25017 .65575 L F
.641 .853 .468 r
.76763 .57714 m .7663 .57902 L .7661 .57949 L F
.402 .857 .856 r
.7661 .57949 m .76464 .58029 L .76593 .57989 L F
.7661 .57949 m .7627 .58036 L .76464 .58029 L F
.169 0 0 r
.7661 .57949 m .76544 .58024 L .76287 .5806 L F
.641 .853 .468 r
.7663 .57902 m .76544 .58024 L .7661 .57949 L F
.402 .857 .856 r
.7661 .57949 m .76593 .57989 L .7671 .57952 L F
.793 .338 .163 r
.6534 .5008 m .65388 .49835 L .65367 .49653 L F
.437 .721 .985 r
.36189 .59314 m .36114 .59447 L .35975 .59347 L F
.36189 .59314 m .3633 .59435 L .36114 .59447 L F
.294 .26 .649 r
.47036 .78769 m .47159 .78431 L .46998 .78458 L F
.47036 .78769 m .47225 .78678 L .47159 .78431 L F
.317 .154 .496 r
.47036 .78769 m .47245 .78969 L .47225 .78678 L F
.47036 .78769 m .47029 .79038 L .47245 .78969 L F
.832 .983 .7 r
.57713 .55661 m .5797 .55394 L .57708 .5569 L F
.826 .49 .42 r
.45093 .68633 m .45446 .68916 L .45446 .68664 L F
.926 .903 .782 r
.58114 .72018 m .57809 .72236 L .58068 .71974 L F
.58114 .72018 m .57931 .72303 L .57809 .72236 L F
.447 .807 .996 r
.5835 .71881 m .58114 .72018 L .58068 .71974 L F
.691 .862 .963 r
.51709 .80375 m .51837 .80475 L .51909 .80345 L F
.372 .322 .673 r
.67683 .53179 m .67767 .53474 L .67618 .53498 L F
.452 0 0 r
.72473 .51816 m .72367 .51945 L .72133 .51946 L F
0 0 0 r
.72673 .51748 m .72473 .51816 L .72737 .5181 L F
.72673 .51748 m .72367 .51945 L .72473 .51816 L F
.841 .455 .318 r
.59085 .68924 m .59144 .69109 L .5926 .6894 L F
.85 .468 .325 r
.59144 .69109 m .59346 .69201 L .5926 .6894 L F
.728 .81 .916 r
.54998 .77889 m .55353 .77899 L .55237 .7778 L F
.846 .827 .829 r
.55237 .7778 m .55353 .77899 L .55599 .77599 L F
.685 .559 .706 r
.55353 .77899 m .55694 .78098 L .55599 .77599 L F
.63 .556 .752 r
.55353 .77899 m .55713 .78219 L .55694 .78098 L F
.393 0 0 r
.49142 .69489 m .48985 .69591 L .48792 .69521 L F
.71 .214 0 r
.47042 .80118 m .47188 .80242 L .47296 .80393 L F
.931 .943 .78 r
.57148 .566 m .57253 .56221 L .57312 .56237 L F
.269 .773 .86 r
.44546 .6608 m .4446 .6607 L .44254 .66109 L F
.264 .744 .932 r
.44961 .66089 m .4446 .6607 L .44546 .6608 L F
.316 0 0 r
.42556 .69687 m .42935 .69512 L .42712 .69555 L F
.262 .036 .37 r
.33965 .6165 m .34076 .61787 L .34142 .61567 L F
.33965 .6165 m .33914 .61865 L .34076 .61787 L F
.168 0 .149 r
.62215 .49026 m .61957 .49281 L .62144 .49182 L F
.346 .068 .34 r
.62144 .49182 m .62412 .48912 L .62215 .49026 L F
.511 .342 .588 r
.51824 .6612 m .5166 .66375 L .51622 .66147 L F
.51824 .6612 m .51895 .66354 L .5166 .66375 L F
.432 .339 .649 r
.51943 .66572 m .5166 .66375 L .51895 .66354 L F
.51943 .66572 m .51715 .66777 L .5166 .66375 L F
.759 .666 .76 r
.49515 .64946 m .49916 .6502 L .49768 .6466 L F
.761 .66 .751 r
.49515 .64946 m .4968 .65296 L .49916 .6502 L F
.551 .355 .569 r
.4968 .65296 m .49876 .65271 L .49916 .6502 L F
.559 .562 .813 r
.49768 .6466 m .49916 .6502 L .50117 .64935 L F
.786 .69 .758 r
.49876 .65271 m .50117 .64935 L .49916 .6502 L F
.364 0 0 r
.33377 .58985 m .33551 .5904 L .337 .59045 L F
.457 .856 .971 r
.33551 .5904 m .33929 .59018 L .337 .59045 L F
.43 .822 .986 r
.30155 .64871 m .30369 .64776 L .30162 .64845 L F
.30155 .64871 m .30517 .64855 L .30369 .64776 L F
.632 .432 .593 r
.49967 .80412 m .4968 .80449 L .49722 .80168 L F
.714 .616 .747 r
.49621 .79882 m .49722 .80168 L .4939 .80161 L F
.815 .514 .48 r
.55836 .5914 m .55556 .59292 L .55602 .59055 L F
.085 0 .212 r
.69576 .52094 m .69376 .52384 L .69518 .52275 L F
.799 .967 .912 r
.69632 .51885 m .69576 .52094 L .6959 .51957 L F
.69632 .51885 m .69847 .51882 L .69576 .52094 L F
.829 .81 .322 r
.6959 .51957 m .69576 .52094 L .69518 .52275 L F
.406 .33 .658 r
.38171 .67548 m .38309 .67198 L .38096 .6723 L F
.38171 .67548 m .38337 .67529 L .38309 .67198 L F
.415 .417 .753 r
.38171 .67548 m .38414 .67742 L .38337 .67529 L F
.552 .416 .649 r
.38195 .67779 m .38414 .67742 L .38171 .67548 L F
.37 0 .147 r
.76169 .58265 m .75912 .58465 L .75846 .58483 L F
.76169 .58265 m .76139 .5842 L .75912 .58465 L F
.721 .336 .318 r
.56138 .72362 m .55855 .72465 L .55971 .72266 L F
.56138 .72362 m .56081 .72556 L .55855 .72465 L F
.729 .343 .32 r
.56138 .72362 m .56398 .72589 L .56081 .72556 L F
.562 .092 .097 r
.30466 .60428 m .30348 .60514 L .30141 .60466 L F
.358 0 0 r
.30679 .60409 m .30348 .60514 L .30466 .60428 L F
.718 .666 .798 r
.493 .65224 m .4968 .65296 L .49515 .64946 L F
.493 .65224 m .49423 .65337 L .4968 .65296 L F
.695 .577 .719 r
.4968 .65296 m .50049 .65356 L .49876 .65271 L F
.237 0 .182 r
.63193 .48333 m .634 .48344 L .63454 .48145 L F
.272 0 .136 r
.63193 .48333 m .63341 .48484 L .634 .48344 L F
.63193 .48333 m .63125 .48559 L .63341 .48484 L F
.513 .354 .602 r
.38285 .66705 m .38503 .66899 L .38493 .66657 L F
.454 .354 .652 r
.38285 .66705 m .38318 .66962 L .38503 .66899 L F
0 0 0 r
.69518 .52275 m .69376 .52384 L .69284 .52522 L F
.138 0 0 r
.53968 .77316 m .54308 .77103 L .5413 .77251 L F
.004 0 0 r
.54373 .77154 m .54308 .77103 L .54549 .77008 L F
.54373 .77154 m .5413 .77251 L .54308 .77103 L F
.754 .797 .887 r
.48311 .80592 m .4837 .80738 L .48002 .80682 L F
.889 .92 .837 r
.48244 .80682 m .48247 .80684 L .48311 .80592 L F
.48247 .80684 m .4837 .80738 L .48365 .80727 L F
.48247 .80684 m .48365 .80727 L .48311 .80592 L F
.503 .827 1 r
.48002 .80682 m .4837 .80738 L .48247 .80684 L F
.797 .678 .733 r
.48063 .80923 m .48243 .80682 L .47899 .80688 L F
.55 .919 .944 r
.47899 .80688 m .48002 .80682 L .48124 .80446 L F
.47899 .80688 m .48051 .80653 L .48002 .80682 L F
.48051 .80653 m .48311 .80592 L .48002 .80682 L F
.443 .821 .99 r
.48002 .80682 m .48333 .80571 L .4826 .80528 L F
.48002 .80682 m .4826 .80528 L .48124 .80446 L F
.797 .678 .733 r
.48111 .80669 m .48311 .80592 L .48018 .8066 L F
.48245 .8068 m .48311 .80592 L .48111 .80669 L F
.443 .821 .99 r
.48054 .80665 m .48468 .80628 L .48333 .80571 L F
.48002 .80682 m .48111 .80669 L .48054 .80665 L F
.48111 .80669 m .48468 .80628 L .48054 .80665 L F
.797 .678 .733 r
.48243 .80682 m .48245 .8068 L .48111 .80669 L F
.503 .827 1 r
.48002 .80682 m .48247 .80684 L .48243 .80682 L F
.48002 .80682 m .48243 .80682 L .48111 .80669 L F
.797 .678 .733 r
.48243 .80682 m .48018 .8066 L .47899 .80688 L F
.503 .827 1 r
.48111 .80669 m .48243 .80682 L .48184 .80661 L F
.48184 .80661 m .48618 .80686 L .48468 .80628 L F
.48247 .80684 m .48618 .80686 L .48184 .80661 L F
.48247 .80684 m .4837 .80738 L .48618 .80686 L F
.889 .92 .837 r
.48063 .80923 m .4837 .80738 L .48244 .80682 L F
.174 .496 .906 r
.77258 .57732 m .76884 .57474 L .7721 .57613 L F
.309 0 0 r
.7743 .57809 m .77258 .57732 L .7721 .57613 L F
0 0 0 r
.6084 .53741 m .60719 .5392 L .60621 .54056 L F
.192 .167 .6 r
.60719 .5392 m .60602 .54196 L .60621 .54056 L F
.358 .184 .504 r
.33727 .61928 m .33877 .62065 L .33914 .61865 L F
.33727 .61928 m .33714 .62151 L .33877 .62065 L F
.686 .799 .935 r
.68648 .48292 m .69113 .48284 L .6902 .48193 L F
.503 .776 .993 r
.69113 .48284 m .69164 .48164 L .6902 .48193 L F
.69113 .48284 m .69281 .48263 L .69164 .48164 L F
.852 .717 .712 r
.64103 .53997 m .6421 .54324 L .64273 .54109 L F
.588 .192 .259 r
.53119 .76383 m .53472 .76214 L .5324 .76212 L F
.313 0 .206 r
.52443 .65876 m .52349 .66069 L .52171 .66075 L F
.409 .416 .755 r
.52651 .6532 m .52612 .65549 L .52524 .65246 L F
.928 .898 .495 r
.52651 .6532 m .526 .65471 L .52612 .65549 L F
.519 .51 .786 r
.52561 .65688 m .52443 .65876 L .52282 .6553 L F
.66 .574 .748 r
.52524 .65246 m .52612 .65549 L .52282 .6553 L F
.519 .51 .786 r
.52579 .65698 m .52282 .6553 L .52612 .65549 L F
.928 .898 .495 r
.526 .65471 m .52515 .6572 L .52574 .65617 L F
.526 .65471 m .52574 .65617 L .52612 .65549 L F
.519 .51 .786 r
.52579 .65698 m .52553 .65731 L .52561 .65688 L F
.52553 .65731 m .52443 .65876 L .52561 .65688 L F
0 0 0 r
.52515 .6572 m .52443 .65876 L .52579 .65698 L F
.52515 .6572 m .52349 .66069 L .52443 .65876 L F
.716 .666 .8 r
.49079 .65295 m .49423 .65337 L .493 .65224 L F
.654 .819 .962 r
.67499 .48227 m .67617 .48365 L .67844 .48221 L F
.343 .044 .305 r
.33217 .6239 m .33338 .62599 L .33389 .62407 L F
.33217 .6239 m .33142 .62668 L .33338 .62599 L F
.924 .904 .787 r
.56685 .57162 m .56367 .57375 L .56593 .57079 L F
.56685 .57162 m .56484 .57506 L .56367 .57375 L F
.875 .938 .857 r
.56943 .56875 m .56685 .57162 L .56593 .57079 L F
.545 .303 .498 r
.4186 .6698 m .42058 .67168 L .41845 .67178 L F
.645 .465 .626 r
.67971 .52683 m .6801 .52918 L .68205 .52583 L F
.793 .619 .666 r
.63707 .52211 m .63447 .52048 L .63724 .52077 L F
.63707 .52211 m .63403 .52305 L .63447 .52048 L F
.767 .542 .593 r
.63707 .52211 m .63651 .52339 L .63403 .52305 L F
.79 .632 .686 r
.5621 .59357 m .56023 .59653 L .55872 .59323 L F
.892 .716 .656 r
.64138 .53271 m .64018 .5367 L .64361 .53721 L F
.877 .784 .755 r
.64018 .5367 m .64103 .53997 L .64361 .53721 L F
.69 .805 .936 r
.47356 .65584 m .47718 .65605 L .47564 .65483 L F
.637 .548 .737 r
.41048 .67514 m .41097 .67813 L .40867 .6778 L F
.515 .46 .733 r
.41144 .68078 m .40867 .6778 L .41097 .67813 L F
.795 .951 .921 r
.63653 .55685 m .63839 .55414 L .63601 .55683 L F
.63653 .55685 m .63925 .55492 L .63839 .55414 L F
.752 .596 .683 r
.5445 .74371 m .54876 .74502 L .54662 .74553 L F
.918 .682 .566 r
.54876 .74502 m .54852 .7465 L .54662 .74553 L F
.752 .596 .683 r
.5445 .74371 m .5475 .74568 L .54876 .74502 L F
.818 .823 .853 r
.54876 .74502 m .5475 .74568 L .54902 .74345 L F
.54876 .74502 m .54902 .74345 L .55 .74201 L F
.918 .682 .566 r
.54876 .74502 m .54955 .74702 L .54852 .7465 L F
.302 0 .001 r
.51842 .74529 m .52249 .7427 L .51979 .7461 L F
.511 .3 .529 r
.52249 .7427 m .5222 .74572 L .51979 .7461 L F
.302 0 .001 r
.51842 .74529 m .52086 .74491 L .52249 .7427 L F
.471 .266 .519 r
.52429 .74486 m .52249 .7427 L .5242 .74221 L F
.52429 .74486 m .5222 .74572 L .52222 .74547 L F
.52429 .74486 m .52222 .74547 L .52249 .7427 L F
.502 .338 .59 r
.5242 .74221 m .52639 .74426 L .52429 .74486 L F
.55 .824 .997 r
.52429 .74486 m .52639 .74426 L .52636 .74426 L F
.52429 .74486 m .52636 .74426 L .52289 .74393 L F
.11 0 0 r
.52249 .7427 m .52289 .74393 L .5242 .74221 L F
.52249 .7427 m .52086 .74491 L .52289 .74393 L F
.101 .538 .911 r
.76884 .57474 m .76593 .57328 L .76824 .57349 L F
.072 .474 .89 r
.77217 .57551 m .76884 .57474 L .76824 .57349 L F
.77217 .57551 m .7721 .57613 L .76884 .57474 L F
.467 .442 .747 r
.28539 .62715 m .2836 .62744 L .28287 .62411 L F
.6 .553 .773 r
.28686 .63036 m .2836 .62744 L .28539 .62715 L F
.529 .828 .999 r
.35195 .59185 m .34849 .59176 L .35054 .59151 L F
.408 .816 .979 r
.35312 .59146 m .35195 .59185 L .35054 .59151 L F
.35312 .59146 m .35398 .59145 L .35195 .59185 L F
.371 .341 .696 r
.41194 .68522 m .4099 .68357 L .41197 .68327 L F
.41194 .68522 m .41054 .68706 L .4099 .68357 L F
.762 .614 .695 r
.6801 .52918 m .68395 .53154 L .68205 .52583 L F
.099 .205 .687 r
.68205 .52583 m .68395 .53154 L .68362 .52774 L F
.98 .686 .363 r
.68395 .53154 m .68264 .53106 L .68362 .52774 L F
.68395 .53154 m .68387 .53223 L .68264 .53106 L F
.986 .712 .394 r
.59862 .70831 m .59967 .70911 L .59848 .70591 L F
.954 .672 .462 r
.4894 .80738 m .488 .80939 L .48618 .80686 L F
.4894 .80738 m .48937 .80967 L .488 .80939 L F
0 0 0 r
.52214 .76619 m .5214 .76601 L .52011 .76584 L F
.52214 .76619 m .5234 .76567 L .5214 .76601 L F
.398 0 0 r
.27092 .58692 m .27317 .58684 L .2715 .58623 L F
.923 .959 .638 r
.77343 .6102 m .77469 .60862 L .77419 .60771 L F
.79 .669 .73 r
.55474 .78518 m .55746 .78367 L .55713 .78219 L F
.198 0 0 r
.5556 .78602 m .55746 .78367 L .55474 .78518 L F
.79 .669 .73 r
.55474 .78518 m .55746 .78367 L .55713 .78219 L F
.322 .355 .74 r
.55713 .78219 m .55746 .78367 L .55962 .78405 L F
.677 .543 .694 r
.56044 .78479 m .55872 .78798 L .55746 .78367 L F
.357 0 .02 r
.55962 .78405 m .55746 .78367 L .5556 .78602 L F
.59 .557 .785 r
.50807 .66447 m .51071 .65936 L .50904 .66011 L F
.50807 .66447 m .51048 .66406 L .51071 .65936 L F
.392 .508 .856 r
.50807 .66447 m .51095 .66639 L .51048 .66406 L F
0 .319 .808 r
.50877 .75919 m .5122 .76235 L .51186 .76247 L F
.256 .665 .965 r
.51235 .76164 m .51455 .76291 L .51186 .76247 L F
0 .326 .812 r
.5122 .76235 m .51235 .76164 L .51186 .76247 L F
.426 .778 .996 r
.55665 .76995 m .56011 .77074 L .55904 .76981 L F
.456 .795 .999 r
.56011 .77074 m .56302 .77036 L .55904 .76981 L F
.2 .342 .783 r
.56011 .77074 m .56318 .77339 L .56302 .77036 L F
.779 .643 .712 r
.46902 .68472 m .47175 .68693 L .47154 .68425 L F
.715 .976 .92 r
.46892 .68424 m .46868 .68401 L .47014 .68327 L F
.751 .602 .692 r
.46868 .68401 m .46857 .68446 L .47014 .68327 L F
.46857 .68446 m .46815 .68613 L .46902 .68487 L F
.715 .976 .92 r
.46892 .68424 m .47014 .68327 L .47154 .68425 L F
.852 .408 .155 r
.46902 .68472 m .46964 .68544 L .47175 .68693 L F
.749 .351 .297 r
.46815 .68613 m .47182 .68798 L .46902 .68472 L F
.078 0 .171 r
.47014 .68327 m .46815 .68613 L .46902 .68472 L F
.751 .602 .692 r
.46857 .68446 m .46902 .68487 L .47014 .68327 L F
.852 .408 .155 r
.46964 .68544 m .47182 .68798 L .47178 .68739 L F
.46964 .68544 m .47178 .68739 L .47175 .68693 L F
.478 .283 .537 r
.35756 .62163 m .35535 .6245 L .35545 .62213 L F
.384 .713 .987 r
.328 .58782 m .32781 .58935 L .32618 .58809 L F
.328 .58782 m .33011 .58913 L .32781 .58935 L F
.27 .386 .797 r
.77987 .59925 m .78109 .60242 L .78285 .60132 L F
0 0 0 r
.78285 .60132 m .78109 .60242 L .7803 .60387 L F
.573 .274 .424 r
.58665 .59699 m .58675 .59883 L .58487 .59897 L F
.661 .398 .511 r
.58929 .59679 m .58675 .59883 L .58665 .59699 L F
.23 .742 .874 r
.31326 .64913 m .31485 .64928 L .31664 .64906 L F
.66 .266 .288 r
.43842 .69155 m .43723 .6921 L .44069 .69211 L F
.941 .832 .708 r
.65822 .52093 m .65693 .52008 L .65785 .51794 L F
.891 .474 .077 r
.65822 .52093 m .65772 .52178 L .65693 .52008 L F
.65822 .52093 m .65881 .52264 L .65772 .52178 L F
0 0 0 r
.63198 .56295 m .63391 .55997 L .63327 .56156 L F
.63327 .56156 m .631 .5645 L .63198 .56295 L F
.986 .859 .49 r
.56401 .57624 m .56367 .57375 L .56484 .57506 L F
.379 .352 .703 r
.41194 .68522 m .41277 .68915 L .41054 .68706 L F
.775 .653 .728 r
.49161 .81194 m .49543 .8127 L .49322 .81554 L F
.763 .935 .588 r
.49302 .81521 m .49322 .81554 L .49381 .81408 L F
.189 .71 .872 r
.49322 .81554 m .49337 .81579 L .49067 .81569 L F
.776 .526 .557 r
.49067 .81569 m .49419 .81582 L .49412 .81821 L F
.837 .46 .339 r
.48825 .81358 m .49067 .81569 L .48932 .81727 L F
.776 .526 .557 r
.49067 .81569 m .49412 .81821 L .49322 .81554 L F
.357 0 .002 r
.48932 .81727 m .49067 .81569 L .49322 .81554 L F
.118 0 0 r
.49322 .81554 m .49067 .81569 L .48911 .81613 L F
.48935 .81612 m .48911 .81613 L .48893 .81618 L F
.49322 .81554 m .48911 .81613 L .48935 .81612 L F
.837 .46 .339 r
.48825 .81358 m .48899 .81614 L .48752 .81597 L F
.48899 .81614 m .48932 .81727 L .48783 .8162 L F
.48899 .81614 m .48783 .8162 L .48752 .81597 L F
.838 .446 .305 r
.48893 .81618 m .49067 .81569 L .48825 .81358 L F
.118 0 0 r
.49322 .81554 m .48893 .81618 L .49161 .81194 L F
.357 0 .002 r
.48932 .81727 m .49322 .81554 L .49168 .81714 L F
.763 .935 .588 r
.49168 .81714 m .49322 .81554 L .49302 .81521 L F
.189 .71 .872 r
.49322 .81554 m .49419 .81582 L .49337 .81579 L F
.074 .625 .826 r
.49653 .81591 m .49419 .81582 L .49322 .81554 L F
.123 .65 .874 r
.49419 .81582 m .49653 .81591 L .49412 .81821 L F
.481 .079 .2 r
.52255 .6845 m .52212 .68754 L .52402 .68516 L F
.52255 .6845 m .51999 .68821 L .52212 .68754 L F
.492 .748 .986 r
.30565 .64837 m .31145 .64966 L .31151 .64912 L F
.366 0 .037 r
.60983 .53871 m .6084 .53741 L .61015 .53619 L F
.60983 .53871 m .60719 .5392 L .6084 .53741 L F
.4 .09 .319 r
.25528 .59375 m .25731 .59322 L .25791 .59141 L F
.497 .198 .389 r
.25731 .59322 m .26038 .59077 L .25791 .59141 L F
.764 .728 .819 r
.7109 .48095 m .71365 .48169 L .71426 .47931 L F
.736 .265 .13 r
.7109 .48095 m .71329 .48304 L .71365 .48169 L F
.578 .521 .755 r
.71365 .48169 m .7154 .47755 L .71426 .47931 L F
.71365 .48169 m .71647 .48155 L .7154 .47755 L F
.855 .919 .873 r
.71329 .48304 m .71647 .48155 L .71365 .48169 L F
.532 .095 .154 r
.43524 .69262 m .43416 .69414 L .43696 .69384 L F
.449 .153 .369 r
.43524 .69262 m .43696 .69384 L .43723 .6921 L F
.241 .756 .773 r
.44247 .64765 m .44465 .64711 L .44552 .64701 L F
0 0 0 r
.44552 .64701 m .44685 .64651 L .44814 .64569 L F
.27 .775 .783 r
.44552 .64701 m .44465 .64711 L .44685 .64651 L F
.939 .568 .247 r
.5505 .74005 m .551 .74244 L .54914 .73931 L F
.412 .812 .983 r
.30369 .64776 m .30517 .64855 L .30565 .64837 L F
.878 .921 .85 r
.4994 .69718 m .50049 .69809 L .503 .69511 L F
.241 0 .146 r
.61633 .5877 m .61359 .58964 L .61456 .58882 L F
.753 .962 .935 r
.75111 .58782 m .75462 .58636 L .75384 .5852 L F
.806 .894 .906 r
.75384 .5852 m .75462 .58636 L .75682 .58486 L F
.453 .299 .58 r
.392 .65582 m .394 .65763 L .39398 .65517 L F
.548 .291 .478 r
.39181 .65785 m .394 .65763 L .392 .65582 L F
.603 .41 .594 r
.51192 .77628 m .51429 .77625 L .51429 .77365 L F
.493 .472 .762 r
.51429 .77365 m .51614 .77336 L .51553 .76987 L F
.854 .617 .579 r
.51429 .77365 m .51469 .7754 L .51614 .77336 L F
.51429 .77365 m .51429 .77625 L .51469 .7754 L F
.765 .739 .829 r
.48699 .63592 m .4836 .63565 L .48577 .63351 L F
.726 .723 .847 r
.48905 .63406 m .48699 .63592 L .48577 .63351 L F
.583 .007 0 r
.51309 .76753 m .5118 .76734 L .50889 .76556 L F
0 .038 .541 r
.51309 .76753 m .51327 .76759 L .5118 .76734 L F
.51309 .76753 m .51553 .76987 L .51327 .76759 L F
.859 .995 .762 r
.65524 .48234 m .6535 .48471 L .65419 .48239 L F
.775 .387 .32 r
.67351 .53512 m .67224 .53596 L .67043 .53406 L F
.515 .337 .577 r
.38096 .6723 m .38309 .67198 L .38318 .66962 L F
.786 .69 .758 r
.49876 .65271 m .50049 .65356 L .50211 .65051 L F
.878 .993 .765 r
.52006 .80949 m .51929 .81213 L .51861 .81006 L F
.441 0 0 r
.28238 .65105 m .28125 .65228 L .27878 .65219 L F
0 0 0 r
.28319 .65143 m .28238 .65105 L .28487 .65061 L F
.28319 .65143 m .28125 .65228 L .28238 .65105 L F
.78 .678 .751 r
.66669 .49858 m .66836 .4989 L .66736 .49565 L F
0 0 .335 r
.66669 .49858 m .66763 .50026 L .66836 .4989 L F
.44 .82 .99 r
.52314 .81015 m .5252 .81086 L .52787 .8104 L F
.373 .043 .272 r
.52171 .66075 m .51895 .66354 L .51824 .6612 L F
.087 .266 .751 r
.54577 .78476 m .54683 .78764 L .54778 .78669 L F
0 0 .31 r
.54778 .78669 m .54683 .78764 L .5472 .79041 L F
.315 .233 .602 r
.55519 .75533 m .55319 .75369 L .55726 .75391 L F
.343 .058 .329 r
.61469 .49815 m .61688 .49761 L .61725 .49557 L F
.271 .011 .323 r
.61957 .49281 m .61725 .49557 L .61911 .49449 L F
.408 .159 .422 r
.61688 .49761 m .61911 .49449 L .61725 .49557 L F
.533 .392 .634 r
.38474 .66413 m .38672 .66058 L .38429 .6609 L F
.837 .689 .699 r
.57335 .60199 m .57257 .60243 L .57288 .5997 L F
.688 .386 .459 r
.57335 .60199 m .57299 .60434 L .57257 .60243 L F
.655 .542 .713 r
.57481 .59923 m .57335 .60199 L .57288 .5997 L F
.57481 .59923 m .57607 .60214 L .57335 .60199 L F
.752 .529 .593 r
.57607 .60214 m .57299 .60434 L .57335 .60199 L F
.366 .745 .989 r
.34325 .59043 m .34265 .59136 L .34112 .59037 L F
.34325 .59043 m .34477 .59128 L .34265 .59136 L F
0 0 .396 r
.65776 .49287 m .65744 .49188 L .65669 .4904 L F
.941 .573 .216 r
.65776 .49287 m .65711 .49392 L .65744 .49188 L F
.65776 .49287 m .65857 .49509 L .65711 .49392 L F
.56 .39 .607 r
.4835 .76461 m .48583 .7651 L .48537 .76234 L F
.4835 .76461 m .48583 .7651 L .48537 .76234 L F
.028 .146 .653 r
.56759 .75021 m .56916 .75499 L .56873 .75112 L F
.509 .493 .774 r
.6196 .54583 m .62185 .54535 L .62092 .54184 L F
.262 .311 .725 r
.6196 .54583 m .62209 .54772 L .62185 .54535 L F
.846 .827 .829 r
.55237 .7778 m .55599 .77599 L .55539 .77515 L F
.66 .41 .53 r
.60605 .59111 m .60625 .59326 L .6026 .59356 L F
.572 .408 .62 r
.60605 .59111 m .60854 .59333 L .60625 .59326 L F
.60605 .59111 m .60842 .5907 L .60854 .59333 L F
0 0 .174 r
.78459 .60519 m .78533 .60069 L .78343 .60409 L F
.482 .043 .128 r
.50523 .76116 m .50877 .75919 L .50501 .75974 L F
.50523 .76116 m .50708 .76104 L .50877 .75919 L F
0 .517 .79 r
.50708 .76104 m .5122 .76235 L .50877 .75919 L F
.149 .254 .717 r
.24668 .63326 m .24857 .63517 L .2474 .63162 L F
.409 .132 .378 r
.4152 .67246 m .41286 .67475 L .41334 .67287 L F
.155 .462 .888 r
.72826 .48552 m .72839 .48702 L .72575 .48552 L F
.72826 .48552 m .72879 .48681 L .72839 .48702 L F
.238 0 .176 r
.54226 .72969 m .5401 .73147 L .54247 .73066 L F
.58 .115 .113 r
.54247 .73066 m .54467 .73086 L .54226 .72969 L F
.374 .171 .472 r
.53977 .73394 m .54247 .73066 L .5401 .73147 L F
.988 .877 .628 r
.73126 .50015 m .7312 .50388 L .73219 .50112 L F
.64 .726 .91 r
.55127 .79561 m .55158 .79663 L .55367 .79577 L F
.373 .043 .272 r
.52171 .66075 m .52098 .66329 L .51895 .66354 L F
.162 0 .19 r
.5224 .66231 m .52171 .66075 L .52349 .66069 L F
.5224 .66231 m .52098 .66329 L .52171 .66075 L F
.637 .842 .979 r
.47825 .78216 m .48115 .78119 L .47755 .78049 L F
.832 .983 .7 r
.57713 .55661 m .5793 .55364 L .5797 .55394 L F
.152 0 .15 r
.25649 .65056 m .25922 .64777 L .2583 .64909 L F
.765 .904 .511 r
.25997 .64624 m .2583 .64909 L .25922 .64777 L F
.315 .471 .857 r
.48333 .78656 m .48456 .78948 L .48209 .78784 L F
.875 .938 .857 r
.56943 .56875 m .56593 .57079 L .56835 .56787 L F
.879 .958 .85 r
.56835 .56787 m .57148 .566 L .56943 .56875 L F
0 0 .463 r
.48208 .77363 m .48241 .77497 L .48463 .77363 L F
.683 .548 .695 r
.48469 .7736 m .48208 .77363 L .48463 .77363 L F
.593 .688 .908 r
.69682 .47632 m .69548 .47845 L .6945 .47691 L F
.69682 .47632 m .69777 .47795 L .69548 .47845 L F
.336 .088 .382 r
.61911 .49449 m .62144 .49182 L .61957 .49281 L F
.541 .197 .335 r
.64061 .49852 m .63848 .49971 L .63859 .49925 L F
.115 0 .37 r
.47035 .77036 m .47133 .7703 L .47173 .7678 L F
.327 .292 .666 r
.47035 .77036 m .47243 .77241 L .47133 .7703 L F
.405 .398 .738 r
.25286 .62227 m .25364 .6247 L .25526 .62424 L F
.689 .662 .819 r
.25412 .62754 m .25526 .62424 L .25364 .6247 L F
.26 0 0 r
.41921 .65194 m .42147 .65171 L .423 .65058 L F
.314 0 0 r
.42147 .65171 m .42518 .65033 L .423 .65058 L F
.631 .406 .557 r
.57815 .68888 m .57989 .68942 L .57994 .68659 L F
.778 .529 .558 r
.57994 .68659 m .58388 .6893 L .58177 .6865 L F
.57994 .68659 m .57989 .68942 L .58388 .6893 L F
.627 .591 .794 r
.50211 .65051 m .50564 .65328 L .50461 .6499 L F
.652 .567 .746 r
.50461 .6499 m .50564 .65328 L .50801 .65267 L F
.886 .731 .684 r
.64124 .54271 m .6421 .54324 L .64103 .53997 L F
.89 .749 .7 r
.63907 .54525 m .6421 .54324 L .64124 .54271 L F
.63907 .54525 m .64067 .54667 L .6421 .54324 L F
.331 .027 .29 r
.49938 .76207 m .50107 .76005 L .49935 .76036 L F
.393 .582 .916 r
.66098 .5242 m .66417 .52516 L .66299 .52257 L F
.752 .283 .133 r
.54832 .73087 m .55197 .73306 L .55128 .73207 L F
.502 0 0 r
.57989 .68942 m .58295 .69051 L .58388 .6893 L F
.381 .239 .561 r
.58388 .6893 m .58528 .68641 L .58177 .6865 L F
.58388 .6893 m .58558 .68876 L .58528 .68641 L F
.76 .451 .464 r
.58295 .69051 m .58558 .68876 L .58388 .6893 L F
.381 .239 .561 r
.58528 .68641 m .58558 .68876 L .58388 .6893 L F
.794 .629 .676 r
.58177 .6865 m .57989 .68942 L .58388 .6893 L F
.727 .778 .893 r
.40093 .71326 m .40191 .71467 L .40408 .71263 L F
.511 .647 .918 r
.75682 .58486 m .75912 .58465 L .75827 .58305 L F
.542 .728 .961 r
.75682 .58486 m .75846 .58483 L .75912 .58465 L F
.532 .577 .846 r
.25172 .6193 m .25286 .62227 L .25496 .62115 L F
.405 .398 .738 r
.25286 .62227 m .25526 .62424 L .25496 .62115 L F
0 .537 .835 r
.51197 .81388 m .51122 .81401 L .50882 .81166 L F
.51197 .81388 m .51297 .81438 L .51122 .81401 L F
.299 .457 .85 r
.52402 .68516 m .52562 .68544 L .52429 .68653 L F
.046 0 .273 r
.52576 .68585 m .52429 .68653 L .52562 .68544 L F
.52576 .68585 m .52409 .68823 L .52429 .68653 L F
.078 0 .171 r
.47014 .68327 m .46902 .68472 L .47154 .68425 L F
0 .563 .783 r
.2891 .58365 m .28823 .58371 L .28693 .58357 L F
.2891 .58365 m .29072 .58396 L .28823 .58371 L F
.603 .431 .622 r
.52145 .79328 m .52414 .79292 L .52406 .79042 L F
.417 .308 .623 r
.52145 .79328 m .52374 .79671 L .52414 .79292 L F
.603 .431 .622 r
.52145 .79328 m .52414 .79292 L .52406 .79042 L F
.274 .778 .845 r
.4522 .64472 m .45613 .64418 L .4539 .64471 L F
.452 .819 .559 r
.54526 .75401 m .54201 .75662 L .54449 .75603 L F
0 0 0 r
.54733 .75157 m .54526 .75401 L .54691 .7529 L F
.293 0 .21 r
.54526 .75401 m .54671 .75513 L .54691 .7529 L F
.54526 .75401 m .54449 .75603 L .54671 .75513 L F
.122 .641 .887 r
.54152 .75081 m .5421 .75067 L .54024 .74806 L F
.54152 .75081 m .54397 .75105 L .5421 .75067 L F
.954 .718 .542 r
.73049 .51079 m .73215 .50976 L .73134 .50898 L F
.73049 .51079 m .73188 .51232 L .73215 .50976 L F
.865 .596 .066 r
.5882 .71259 m .58828 .71381 L .58758 .71087 L F
.214 .673 .946 r
.51979 .7461 m .51842 .74529 L .51614 .74512 L F
.51979 .7461 m .51842 .74529 L .51614 .74512 L F
.42 .801 .991 r
.5222 .74572 m .51842 .74529 L .51979 .7461 L F
.748 .24 0 r
.51614 .76263 m .51819 .76439 L .51721 .76285 L F
.478 .656 .938 r
.313 .58551 m .31281 .58777 L .31125 .58601 L F
.313 .58551 m .31486 .58769 L .31281 .58777 L F
.502 .848 .995 r
.68311 .52459 m .68487 .52528 L .68205 .52583 L F
.355 .645 .964 r
.68529 .52697 m .68205 .52583 L .68487 .52528 L F
0 0 .416 r
.68362 .52774 m .68311 .52459 L .68205 .52583 L F
0 0 .259 r
.52375 .79452 m .52374 .79671 L .52364 .79475 L F
.664 .21 .164 r
.52521 .79386 m .52676 .79314 L .52414 .79292 L F
.52642 .79493 m .52676 .79314 L .52521 .79386 L F
.172 .261 .715 r
.52642 .79493 m .52414 .79292 L .52514 .79169 L F
0 0 .259 r
.52514 .79169 m .52414 .79292 L .52376 .79651 L F
.52381 .79645 m .52376 .79651 L .52374 .79671 L F
.52514 .79169 m .52376 .79651 L .52381 .79645 L F
.448 .635 .935 r
.52435 .79702 m .52516 .79553 L .52476 .79532 L F
0 0 .259 r
.52444 .79421 m .52374 .79671 L .52375 .79452 L F
.448 .635 .935 r
.52407 .79614 m .52476 .79532 L .52364 .79475 L F
.52435 .79702 m .52476 .79532 L .52407 .79614 L F
0 0 .259 r
.52514 .79169 m .52444 .79421 L .52375 .79452 L F
.664 .21 .164 r
.52642 .79493 m .52729 .79319 L .52676 .79314 L F
.446 .793 .998 r
.52729 .79319 m .52797 .79556 L .52786 .79621 L F
.478 .233 .465 r
.52797 .79556 m .52729 .79319 L .52642 .79493 L F
.52797 .79556 m .52945 .79286 L .52729 .79319 L F
.446 .793 .998 r
.52729 .79319 m .52945 .79286 L .52797 .79556 L F
0 0 0 r
.44814 .64569 m .449 .64592 L .44991 .64552 L F
.44814 .64569 m .44685 .64651 L .449 .64592 L F
.328 .771 .963 r
.30413 .5851 m .30351 .5858 L .30194 .58494 L F
.30413 .5851 m .30556 .58558 L .30351 .5858 L F
.163 .259 .716 r
.39622 .65476 m .39518 .65522 L .39427 .65287 L F
.557 .38 .598 r
.39398 .65517 m .39399 .6556 L .39622 .65476 L F
.39399 .6556 m .394 .65763 L .39505 .65627 L F
.669 .198 .125 r
.39592 .65682 m .39779 .65591 L .39518 .65522 L F
.39606 .65711 m .39622 .657 L .39592 .65682 L F
.39606 .65711 m .39518 .65522 L .39622 .65476 L F
.557 .38 .598 r
.39399 .6556 m .39505 .65627 L .39622 .65476 L F
.669 .198 .125 r
.39622 .657 m .39779 .65591 L .39592 .65682 L F
0 0 0 r
.39902 .65599 m .39779 .65591 L .39606 .65711 L F
.013 0 0 r
.39902 .65599 m .40005 .65573 L .39779 .65591 L F
.647 .916 .979 r
.55405 .76623 m .55566 .76513 L .55284 .76619 L F
.535 .06 .076 r
.55456 .75735 m .55309 .75869 L .55661 .75847 L F
.457 .2 .435 r
.55456 .75735 m .55661 .75847 L .55679 .75652 L F
0 0 .41 r
.5576 .7793 m .55694 .78098 L .55792 .77863 L F
.844 .916 .882 r
.5603 .77578 m .56161 .7765 L .5576 .7793 L F
.5603 .77578 m .5576 .7793 L .55792 .77863 L F
.484 .407 .693 r
.55694 .78098 m .55911 .78142 L .55792 .77863 L F
.55694 .78098 m .55713 .78219 L .55911 .78142 L F
.067 .174 .668 r
.55182 .71707 m .55365 .71932 L .55325 .71692 L F
.755 .644 .738 r
.54783 .76774 m .54904 .77086 L .54549 .77008 L F
.238 0 0 r
.54549 .77008 m .54904 .77086 L .54764 .77063 L F
.507 .509 .793 r
.54939 .77019 m .54904 .77086 L .54783 .76774 L F
.966 .755 .568 r
.54904 .77086 m .54869 .77328 L .54764 .77063 L F
.316 .05 .342 r
.59652 .7233 m .59145 .72457 L .59668 .72332 L F
.59524 .72311 m .59319 .7239 L .59652 .7233 L F
.59319 .7239 m .59145 .72457 L .59652 .7233 L F
.642 .295 .368 r
.59073 .72435 m .5932 .72503 L .59068 .72449 L F
.316 .05 .342 r
.59524 .72311 m .5932 .72503 L .59145 .72457 L F
.227 .254 .681 r
.59145 .72457 m .5932 .72503 L .59126 .72297 L F
.642 .295 .368 r
.59126 .72297 m .59229 .72406 L .59073 .72435 L F
.59229 .72406 m .5932 .72503 L .59073 .72435 L F
.461 .841 .986 r
.28813 .65068 m .28683 .65013 L .28487 .65061 L F
.313 .705 .979 r
.28813 .65068 m .28889 .64965 L .28683 .65013 L F
.28813 .65068 m .29101 .65051 L .28889 .64965 L F
.879 .958 .85 r
.56835 .56787 m .57058 .56534 L .57148 .566 L F
.931 .943 .78 r
.57148 .566 m .57058 .56534 L .57253 .56221 L F
.504 .315 .558 r
.56808 .59914 m .56342 .60139 L .56395 .59938 L F
.587 .372 .556 r
.56944 .60156 m .56808 .59914 L .56935 .59948 L F
.56944 .60156 m .56852 .602 L .56808 .59914 L F
.946 .917 .752 r
.66753 .51506 m .67005 .51222 L .66969 .51442 L F
.246 .396 .816 r
.67155 .51101 m .67005 .51222 L .66925 .51005 L F
.429 .086 .28 r
.67264 .51336 m .67005 .51222 L .67155 .51101 L F
.506 .246 .454 r
.29379 .60811 m .2933 .6102 L .29114 .61058 L F
.541 .304 .505 r
.29579 .60755 m .2933 .6102 L .29379 .60811 L F
.435 .181 .428 r
.56421 .70604 m .56375 .7082 L .56124 .70866 L F
.882 .541 .399 r
.56193 .7112 m .56124 .70866 L .56375 .7082 L F
.56193 .7112 m .56053 .7108 L .56124 .70866 L F
.565 .203 .313 r
.4649 .69483 m .46133 .69703 L .46161 .6955 L F
.4649 .69483 m .46359 .69712 L .46133 .69703 L F
.52 .141 .263 r
.46713 .69502 m .46359 .69712 L .4649 .69483 L F
.477 .593 .891 r
.54631 .76022 m .54745 .75818 L .54544 .75961 L F
.54631 .76022 m .54826 .7599 L .54745 .75818 L F
.838 .905 .884 r
.5385 .80323 m .54127 .80298 L .53991 .8012 L F
.639 .89 .985 r
.54127 .80298 m .54199 .80151 L .53991 .8012 L F
.54127 .80298 m .54346 .8021 L .54199 .80151 L F
.732 .483 .552 r
.51655 .77817 m .51672 .78033 L .52012 .77881 L F
.707 .169 0 r
.5212 .77991 m .5213 .77925 L .52001 .77852 L F
.52224 .78111 m .52208 .7808 L .5212 .77991 L F
.52208 .7808 m .5213 .77925 L .5212 .77991 L F
.535 .352 .58 r
.52093 .77845 m .52224 .78111 L .52001 .77852 L F
.732 .483 .552 r
.51968 .77837 m .52012 .77881 L .52093 .77845 L F
.754 .73 .83 r
.51655 .77817 m .52001 .77852 L .51882 .77586 L F
.62 .613 .821 r
.52001 .77852 m .52104 .77485 L .51882 .77586 L F
.52001 .77852 m .52281 .77822 L .52104 .77485 L F
.732 .483 .552 r
.51655 .77817 m .52093 .77845 L .52001 .77852 L F
.51655 .77817 m .52012 .77881 L .51968 .77837 L F
.707 .169 0 r
.52224 .78111 m .52352 .78138 L .5213 .77925 L F
0 0 0 r
.4918 .79302 m .49362 .78969 L .49302 .792 L F
.53 .299 .509 r
.39398 .65517 m .39622 .65476 L .39427 .65287 L F
.446 .456 .775 r
.57439 .70156 m .57415 .70296 L .57116 .70039 L F
0 .014 .551 r
.67666 .51518 m .67622 .51709 L .67616 .51618 L F
.654 .605 .788 r
.37555 .70246 m .37653 .70612 L .37833 .70462 L F
.561 .369 .578 r
.62507 .51523 m .62241 .51901 L .62096 .51703 L F
.62507 .51523 m .62562 .51855 L .62241 .51901 L F
.652 .431 .571 r
.62507 .51523 m .62607 .5184 L .62562 .51855 L F
.85 .699 .695 r
.64967 .51486 m .65116 .51795 L .65262 .51472 L F
.929 .97 .695 r
.56044 .78479 m .56209 .78174 L .56151 .78133 L F
.873 .994 .783 r
.56151 .78133 m .56209 .78174 L .56456 .77832 L F
.351 0 .165 r
.52873 .76611 m .52706 .76567 L .52565 .76668 L F
.52873 .76611 m .5295 .76508 L .52706 .76567 L F
.786 .69 .758 r
.49876 .65271 m .50211 .65051 L .50117 .64935 L F
.7 .748 .888 r
.50117 .64935 m .50211 .65051 L .50461 .6499 L F
.698 .539 .668 r
.506 .65787 m .50936 .65827 L .50872 .65591 L F
.497 .469 .756 r
.50801 .65267 m .50872 .65591 L .51096 .65501 L F
.347 .256 .609 r
.50936 .65827 m .51096 .65501 L .50872 .65591 L F
.593 .836 .991 r
.68192 .47548 m .68064 .47723 L .67931 .47625 L F
.68192 .47548 m .68301 .47654 L .68064 .47723 L F
0 0 .053 r
.65825 .49842 m .65845 .49746 L .65857 .49509 L F
.976 .686 .404 r
.73027 .4946 m .7317 .49795 L .73155 .49562 L F
.543 .006 0 r
.25649 .65056 m .256 .65171 L .2521 .65026 L F
0 0 0 r
.25675 .65084 m .25649 .65056 L .2583 .64909 L F
.25675 .65084 m .256 .65171 L .25649 .65056 L F
.89 .99 .769 r
.55665 .79086 m .55867 .78805 L .55686 .78896 L F
.895 .943 .582 r
.55559 .79272 m .55665 .79086 L .55686 .78896 L F
.55559 .79272 m .55686 .78896 L .55509 .79255 L F
.709 .818 .362 r
.55378 .78706 m .55474 .78518 L .55426 .78619 L F
.55378 .78706 m .55418 .78636 L .55286 .78908 L F
0 0 0 r
.5556 .78602 m .55378 .78706 L .55356 .78746 L F
.656 .674 .855 r
.55286 .78908 m .55399 .78721 L .55378 .78706 L F
.55399 .78721 m .55411 .78702 L .55378 .78706 L F
.55286 .78908 m .55414 .78712 L .55399 .78721 L F
.304 0 0 r
.5472 .79041 m .55286 .78908 L .55103 .78692 L F
.656 .674 .855 r
.55286 .78908 m .55492 .78959 L .55414 .78712 L F
.55492 .78959 m .55609 .78988 L .55572 .78934 L F
.55492 .78959 m .55572 .78934 L .55448 .78756 L F
.55433 .78772 m .55448 .78756 L .55411 .78702 L F
.55492 .78959 m .55448 .78756 L .55433 .78772 L F
.921 .974 .698 r
.55064 .79253 m .55299 .79078 L .55138 .7934 L F
.702 .662 .807 r
.54988 .79124 m .55046 .79298 L .5511 .79145 L F
.921 .974 .698 r
.55061 .7925 m .55068 .79245 L .55064 .79253 L F
.55068 .79245 m .55299 .79078 L .55064 .79253 L F
.061 0 0 r
.55609 .78988 m .55299 .79078 L .55068 .79245 L F
.55609 .78988 m .55068 .79245 L .55081 .79241 L F
.55609 .78988 m .55081 .79241 L .55391 .78732 L F
.55081 .79241 m .55076 .79228 L .55391 .78732 L F
.921 .974 .698 r
.55049 .79248 m .55138 .7934 L .54896 .79232 L F
.55053 .79249 m .55055 .79251 L .55049 .79248 L F
.55055 .79251 m .55138 .7934 L .55049 .79248 L F
.881 .733 .694 r
.54896 .79232 m .55127 .79561 L .54693 .79481 L F
0 .148 .686 r
.55087 .79419 m .55127 .79561 L .54896 .79232 L F
.55087 .79419 m .54896 .79232 L .55138 .7934 L F
.795 .711 .772 r
.54775 .79412 m .55087 .79419 L .55026 .79238 L F
.801 .685 .737 r
.54727 .78999 m .55103 .78692 L .54778 .78669 L F
.5472 .79041 m .54751 .79013 L .54727 .78999 L F
.54751 .79013 m .55103 .78692 L .54727 .78999 L F
0 .367 .77 r
.54502 .78869 m .54674 .78975 L .54408 .78821 L F
.061 0 .411 r
.54778 .78669 m .54674 .78975 L .54744 .78995 L F
0 .367 .77 r
.54744 .78995 m .54696 .78981 L .54502 .78869 L F
.54696 .78981 m .54674 .78975 L .54502 .78869 L F
.175 .41 .849 r
.55037 .7923 m .54896 .79232 L .54744 .78995 L F
.55061 .7925 m .55049 .79248 L .55037 .7923 L F
.55049 .79248 m .54896 .79232 L .55037 .7923 L F
.795 .711 .772 r
.54934 .79197 m .55026 .79238 L .55008 .79185 L F
.175 .41 .849 r
.55061 .7925 m .54744 .78995 L .54988 .79124 L F
.795 .711 .772 r
.54978 .79137 m .55008 .79185 L .54988 .79124 L F
.54934 .79197 m .55008 .79185 L .54978 .79137 L F
.54775 .79412 m .55026 .79238 L .54934 .79197 L F
.921 .974 .698 r
.55064 .79253 m .55138 .7934 L .55053 .79249 L F
.702 .662 .807 r
.55046 .79298 m .55087 .79419 L .55099 .79267 L F
.55064 .79253 m .55099 .79267 L .5511 .79145 L F
.55046 .79298 m .55099 .79267 L .55064 .79253 L F
.921 .974 .698 r
.55061 .7925 m .55064 .79253 L .55053 .79249 L F
.061 0 0 r
.55081 .79241 m .55068 .79245 L .55061 .7925 L F
.702 .662 .807 r
.5527 .79173 m .55098 .79281 L .55383 .79192 L F
0 0 0 r
.55377 .78748 m .55372 .78749 L .55167 .7897 L F
.55167 .78969 m .55167 .7897 L .55166 .78971 L F
.55377 .78748 m .55167 .7897 L .55167 .78969 L F
.924 .974 .716 r
.55197 .78938 m .55391 .78732 L .55076 .79228 L F
.702 .662 .807 r
.54988 .79124 m .5511 .79145 L .55129 .7908 L F
.5511 .79145 m .55109 .79147 L .5511 .79145 L F
.924 .974 .716 r
.55104 .79151 m .55076 .79228 L .55061 .7925 L F
.55198 .78935 m .5509 .79194 L .55104 .79151 L F
.5509 .79194 m .55076 .79228 L .55104 .79151 L F
.55166 .78971 m .54988 .79124 L .55129 .7908 L F
.55166 .78971 m .55198 .78935 L .55116 .79124 L F
.55166 .78971 m .55116 .79124 L .55129 .7908 L F
.661 .665 .843 r
.54988 .79124 m .55129 .7908 L .55166 .78971 L F
.924 .974 .716 r
.55166 .78971 m .55129 .7908 L .5514 .79041 L F
.661 .665 .843 r
.55129 .7908 m .55158 .79071 L .55166 .78971 L F
.924 .974 .716 r
.55166 .78971 m .55129 .7908 L .55158 .79071 L F
.061 0 0 r
.55609 .78988 m .55391 .78732 L .55417 .7871 L F
0 0 0 r
.5556 .78602 m .55168 .78969 L .55481 .78868 L F
.663 .662 .839 r
.55168 .78969 m .55158 .79071 L .5535 .78854 L F
0 0 0 r
.55168 .78969 m .55166 .78971 L .55481 .78868 L F
.663 .662 .839 r
.5535 .78854 m .5528 .78933 L .55481 .78868 L F
.5528 .78933 m .55158 .79071 L .55481 .78868 L F
0 0 0 r
.55372 .78749 m .55277 .78832 L .55166 .78971 L F
.55399 .78721 m .55334 .78762 L .55419 .78734 L F
.924 .974 .716 r
.55198 .78935 m .55411 .78702 L .55391 .78732 L F
.55198 .78935 m .55391 .78732 L .55197 .78938 L F
0 0 0 r
.55419 .78734 m .55377 .78748 L .55166 .78971 L F
.55372 .78749 m .55334 .78762 L .55277 .78832 L F
.55356 .78746 m .55378 .78706 L .55334 .78762 L F
.55167 .78969 m .55378 .78706 L .55331 .78789 L F
.55166 .78971 m .55167 .7897 L .55167 .78969 L F
.55167 .7897 m .55378 .78706 L .55167 .78969 L F
.663 .662 .839 r
.55318 .78851 m .55168 .78969 L .5535 .78854 L F
.55182 .78836 m .55169 .78968 L .55318 .78851 L F
.55169 .78968 m .55168 .78969 L .55318 .78851 L F
.702 .662 .807 r
.55129 .7908 m .55383 .79192 L .55158 .79071 L F
.5511 .79145 m .55383 .79192 L .55129 .7908 L F
.924 .974 .716 r
.5514 .79041 m .55116 .79124 L .55061 .7925 L F
.702 .662 .807 r
.5511 .79145 m .55102 .79233 L .5527 .79173 L F
.55109 .79147 m .55102 .79233 L .5511 .79145 L F
.55102 .79233 m .55098 .79281 L .5527 .79173 L F
.061 0 0 r
.55081 .79241 m .55061 .7925 L .55076 .79228 L F
.702 .662 .807 r
.55098 .79281 m .55087 .79419 L .55139 .79378 L F
.55098 .79281 m .55139 .79378 L .55383 .79192 L F
.357 0 .02 r
.55962 .78405 m .5556 .78602 L .5586 .78584 L F
.58 .578 .815 r
.55682 .78273 m .5586 .78584 L .5556 .78602 L F
.838 .767 .784 r
.55481 .78868 m .5565 .78684 L .55601 .7869 L F
0 0 .035 r
.55707 .78534 m .55603 .78582 L .55481 .78868 L F
.55603 .78582 m .55548 .78644 L .55481 .78868 L F
0 0 0 r
.55331 .78789 m .55378 .78706 L .55411 .78702 L F
.5556 .78602 m .55334 .78762 L .55499 .78659 L F
.838 .767 .784 r
.55481 .78868 m .55601 .7869 L .55335 .78724 L F
.55481 .78868 m .5565 .78684 L .55335 .78724 L F
0 0 .035 r
.55707 .78534 m .55707 .78534 L .55481 .78868 L F
.55603 .78582 m .5556 .78602 L .55548 .78644 L F
.656 .674 .855 r
.55399 .78721 m .55414 .78712 L .55411 .78702 L F
.061 0 0 r
.55417 .7871 m .55391 .78732 L .55411 .78702 L F
0 0 0 r
.55499 .78659 m .55399 .78721 L .55419 .78734 L F
.709 .818 .362 r
.55378 .78706 m .55426 .78619 L .55418 .78636 L F
.939 .894 .757 r
.55383 .79192 m .55686 .78896 L .55474 .78999 L F
.55383 .79192 m .55509 .79255 L .55686 .78896 L F
0 0 0 r
.55495 .78992 m .55672 .78903 L .55821 .78882 L F
.55672 .78903 m .55686 .78896 L .55699 .78894 L F
.55672 .78903 m .55699 .78894 L .55821 .78882 L F
.55474 .78999 m .55686 .78896 L .55495 .78992 L F
.89 .99 .769 r
.55867 .78805 m .55872 .78798 L .55686 .78896 L F
.323 0 0 r
.54841 .75256 m .54733 .75157 L .54691 .7529 L F
.54841 .75256 m .54981 .75144 L .54733 .75157 L F
.509 .329 .572 r
.5246 .7703 m .52228 .77322 L .52236 .77079 L F
.501 .834 .998 r
.37458 .59854 m .37383 .59976 L .37239 .59886 L F
.37458 .59854 m .376 .59929 L .37383 .59976 L F
.505 .545 .831 r
.37707 .60235 m .37383 .59976 L .376 .59929 L F
.648 .287 .344 r
.50479 .81309 m .50381 .81205 L .50107 .81452 L F
.561 .235 .374 r
.5947 .5942 m .59467 .59579 L .59209 .59624 L F
.584 .253 .375 r
.5947 .5942 m .59695 .59574 L .59467 .59579 L F
.583 .254 .379 r
.59789 .59347 m .59695 .59574 L .5947 .5942 L F
.989 .75 .369 r
.63943 .50601 m .63849 .50542 L .63933 .50378 L F
0 0 .392 r
.63933 .50378 m .64064 .49999 L .64245 .50133 L F
.63933 .50378 m .64067 .50233 L .64064 .49999 L F
0 0 0 r
.63933 .50378 m .63849 .50542 L .64067 .50233 L F
.494 .332 .59 r
.50838 .77619 m .5107 .77751 L .51192 .77628 L F
.385 0 0 r
.51295 .77743 m .51192 .77628 L .5107 .77751 L F
.51295 .77743 m .51429 .77625 L .51192 .77628 L F
.467 .135 .32 r
.51918 .78745 m .52248 .78483 L .52247 .78729 L F
.217 .35 .785 r
.52505 .78724 m .52248 .78483 L .52484 .78449 L F
.684 .785 .927 r
.48062 .7564 m .48414 .75685 L .48283 .75597 L F
.497 .678 .946 r
.48414 .75685 m .48491 .75503 L .48283 .75597 L F
.48414 .75685 m .48642 .75689 L .48491 .75503 L F
.976 .679 .383 r
.57931 .72303 m .57934 .72472 L .57809 .72236 L F
.631 .961 .821 r
.69138 .51501 m .68954 .51637 L .68819 .51674 L F
.521 .587 .862 r
.69167 .51785 m .68954 .51637 L .69138 .51501 L F
.813 .839 .373 r
.70457 .5254 m .70523 .52359 L .70446 .52504 L F
.691 .979 .892 r
.70476 .52317 m .70523 .52359 L .70822 .5216 L F
.955 .82 .382 r
.70446 .52504 m .70523 .52359 L .70476 .52317 L F
0 0 0 r
.32097 .64836 m .32274 .64718 L .32478 .64639 L F
.408 0 .077 r
.4455 .70118 m .44412 .70294 L .44192 .7031 L F
.388 0 .065 r
.44731 .70183 m .44412 .70294 L .4455 .70118 L F
.386 0 .102 r
.4487 .70012 m .44731 .70183 L .4455 .70118 L F
.355 .566 .917 r
.59556 .70841 m .59523 .70545 L .59664 .7073 L F
.59556 .70841 m .59276 .70618 L .59523 .70545 L F
.59556 .70841 m .59629 .70692 L .59276 .70618 L F
.898 .556 .39 r
.59556 .70841 m .59436 .70975 L .59629 .70692 L F
.001 0 0 r
.42518 .65033 m .42735 .64993 L .42856 .64946 L F
.407 0 0 r
.42735 .64993 m .43076 .64908 L .42856 .64946 L F
.733 .491 .561 r
.49393 .77852 m .49728 .77644 L .49353 .77598 L F
.49393 .77852 m .49712 .77881 L .49728 .77644 L F
.478 .274 .524 r
.49728 .77644 m .49921 .77842 L .49955 .77582 L F
.49728 .77644 m .49712 .77881 L .49921 .77842 L F
.322 .355 .74 r
.55713 .78219 m .55962 .78405 L .55911 .78142 L F
.545 .497 .753 r
.66887 .50559 m .66925 .51005 L .66713 .50964 L F
.579 .098 .077 r
.49137 .77635 m .49009 .77786 L .48779 .77649 L F
.57 .608 .852 r
.49137 .77635 m .49276 .77314 L .49154 .77549 L F
.49137 .77635 m .49353 .77598 L .49276 .77314 L F
.786 .912 .522 r
.49154 .77549 m .49009 .77786 L .49137 .77635 L F
.545 .43 .673 r
.49191 .77898 m .49353 .77598 L .49137 .77635 L F
.214 .71 .918 r
.49907 .69462 m .50217 .69469 L .503 .69511 L F
.878 .921 .85 r
.4994 .69718 m .503 .69511 L .50217 .69469 L F
0 .014 .551 r
.67666 .51518 m .67681 .51767 L .67622 .51709 L F
.854 .455 0 r
.67674 .51933 m .67772 .5203 L .67674 .5182 L F
.67674 .51933 m .67674 .5182 L .67622 .51709 L F
.888 .951 .841 r
.67538 .52295 m .67772 .5203 L .67674 .51933 L F
.105 0 0 r
.6782 .51984 m .67675 .52056 L .67674 .51933 L F
.67675 .52056 m .67592 .52097 L .67674 .51933 L F
.854 .455 0 r
.67674 .51933 m .67622 .51709 L .67681 .51767 L F
.452 .218 .468 r
.61452 .50022 m .61688 .49761 L .61469 .49815 L F
.616 .194 .219 r
.48579 .69443 m .48444 .6952 L .48215 .69454 L F
.511 0 0 r
.48792 .69521 m .48444 .6952 L .48579 .69443 L F
.455 .734 .987 r
.71085 .51183 m .70873 .5122 L .70731 .51098 L F
0 .217 .739 r
.71278 .51582 m .70873 .5122 L .71085 .51183 L F
.311 .192 .552 r
.48049 .79711 m .47829 .7957 L .47994 .79543 L F
.48049 .79711 m .47861 .79824 L .47829 .7957 L F
.545 0 0 r
.50889 .76556 m .50956 .76627 L .50645 .76444 L F
.496 0 0 r
.5118 .76734 m .50956 .76627 L .50889 .76556 L F
0 0 .151 r
.61158 .50697 m .61117 .50917 L .61237 .50573 L F
.291 0 0 r
.42917 .70565 m .42815 .70697 L .42563 .70736 L F
.524 .123 .223 r
.43153 .7053 m .42815 .70697 L .42917 .70565 L F
.894 .569 .074 r
.66483 .50301 m .6659 .5057 L .66527 .50334 L F
.805 .675 .72 r
.55915 .76525 m .55566 .76513 L .55781 .76439 L F
.55915 .76525 m .55686 .76784 L .55566 .76513 L F
.81 .615 .058 r
.64793 .50762 m .6476 .50557 L .64845 .50694 L F
.64793 .50762 m .64782 .50943 L .6476 .50557 L F
.796 .709 .769 r
.65034 .50986 m .64782 .50943 L .64793 .50762 L F
0 0 0 r
.63391 .55997 m .63601 .55683 L .63417 .55978 L F
.63327 .56156 m .63391 .55997 L .63417 .55978 L F
0 0 .572 r
.72999 .48902 m .72996 .49 L .72879 .48681 L F
.896 .619 .11 r
.72975 .49128 m .72996 .49 L .72999 .48902 L F
.72975 .49128 m .73029 .49228 L .72996 .49 L F
.503 .174 .342 r
.37024 .61024 m .37176 .61241 L .36974 .61304 L F
.37024 .61024 m .37249 .60983 L .37176 .61241 L F
.726 .537 .636 r
.25325 .64351 m .25572 .63959 L .2543 .64176 L F
.833 .889 .882 r
.46708 .63998 m .46408 .64121 L .46616 .64002 L F
.324 .81 .821 r
.46708 .63998 m .46809 .63943 L .47004 .63915 L F
.46708 .63998 m .46616 .64002 L .46809 .63943 L F
.07 0 0 r
.62092 .54184 m .62434 .54061 L .62125 .5411 L F
.56 .558 .808 r
.63227 .50003 m .63032 .50258 L .62989 .50134 L F
.63227 .50003 m .63271 .5022 L .63032 .50258 L F
.135 0 0 r
.3238 .62987 m .3258 .62935 L .32741 .62799 L F
.263 0 0 r
.3258 .62935 m .32931 .62723 L .32741 .62799 L F
.754 .981 .913 r
.68941 .51899 m .69167 .51785 L .69188 .51814 L F
.407 .411 .752 r
.6943 .51718 m .69167 .51785 L .69138 .51501 L F
.06 0 0 r
.69188 .51814 m .69167 .51785 L .6943 .51718 L F
.301 0 0 r
.43739 .70331 m .43594 .70477 L .43373 .70504 L F
.237 0 0 r
.43972 .70338 m .43594 .70477 L .43739 .70331 L F
.448 .608 .916 r
.50063 .79314 m .49671 .79101 L .50061 .79064 L F
.611 .319 .449 r
.50061 .79064 m .50266 .79247 L .50063 .79314 L F
.50061 .79064 m .50303 .79036 L .50266 .79247 L F
.686 .417 .511 r
.60037 .5935 m .59695 .59574 L .59789 .59347 L F
.719 .419 .469 r
.53279 .77897 m .53523 .78149 L .53569 .77906 L F
.459 .113 .291 r
.53768 .77946 m .53569 .77906 L .53808 .77854 L F
.73 .619 .734 r
.53523 .78149 m .53808 .77854 L .53569 .77906 L F
.771 .643 .72 r
.63943 .50601 m .64066 .5096 L .63721 .50903 L F
.718 .586 .707 r
.64083 .51203 m .63721 .50903 L .64066 .5096 L F
.76 .548 .611 r
.64359 .51177 m .64083 .51203 L .64066 .5096 L F
.003 .107 .622 r
.53778 .75964 m .53959 .76225 L .53938 .75902 L F
.5 .301 .541 r
.66442 .48658 m .66221 .48722 L .66449 .48433 L F
.518 .347 .589 r
.66442 .48658 m .66464 .4889 L .66221 .48722 L F
.721 .914 .559 r
.26208 .64953 m .262 .6501 L .26242 .64903 L F
.756 .318 .211 r
.2583 .64909 m .262 .6501 L .26088 .65125 L F
.721 .914 .559 r
.26088 .65125 m .262 .6501 L .26208 .64953 L F
0 0 .146 r
.26208 .64953 m .26213 .65076 L .26088 .65125 L F
.706 .864 .454 r
.26242 .64903 m .262 .6501 L .26214 .64952 L F
0 0 .146 r
.26242 .64903 m .26214 .64952 L .26208 .64953 L F
.706 .864 .454 r
.26242 .64903 m .26214 .64952 L .26216 .64944 L F
0 0 .146 r
.26242 .64903 m .26235 .64947 L .26214 .64952 L F
.184 .659 .933 r
.26216 .64944 m .262 .6501 L .26209 .64943 L F
0 0 .146 r
.26235 .64947 m .26213 .65076 L .26208 .64953 L F
.184 .659 .933 r
.26133 .64936 m .26159 .64964 L .2583 .64909 L F
.26159 .64964 m .262 .6501 L .26092 .6498 L F
.26159 .64964 m .26092 .6498 L .2583 .64909 L F
.26209 .64943 m .26207 .64959 L .26133 .64936 L F
.26207 .64959 m .262 .6501 L .26133 .64936 L F
.188 .66 .935 r
.25898 .64864 m .26216 .64944 L .2583 .64909 L F
.811 .722 .766 r
.26088 .65125 m .25898 .64864 L .2583 .64909 L F
.26088 .65125 m .25675 .65084 L .25897 .64865 L F
.25899 .64865 m .25897 .64865 L .25898 .64864 L F
.26088 .65125 m .25897 .64865 L .25899 .64865 L F
.523 .575 .85 r
.27573 .64898 m .27582 .65051 L .27764 .64882 L F
.564 .529 .774 r
.2767 .65259 m .27764 .64882 L .27582 .65051 L F
.587 .595 .827 r
.28897 .62983 m .28686 .63036 L .28539 .62715 L F
.49 .468 .76 r
.38306 .68352 m .38396 .68682 L .38585 .68645 L F
.494 .494 .786 r
.38396 .68682 m .38678 .68857 L .38585 .68645 L F
.829 .756 .783 r
.54571 .78208 m .54756 .78175 L .54598 .77882 L F
.821 .66 .684 r
.54577 .78476 m .54756 .78175 L .54571 .78208 L F
.764 .735 .826 r
.54598 .77882 m .54756 .78175 L .54998 .77889 L F
.457 .06 .198 r
.45345 .69942 m .45358 .69834 L .45699 .69727 L F
.941 .922 .763 r
.55108 .74508 m .54969 .74887 L .54955 .74702 L F
.828 .428 .291 r
.55208 .74836 m .54955 .74702 L .54969 .74887 L F
.452 .203 .444 r
.56 .70324 m .56189 .70325 L .56238 .70046 L F
.48 .227 .453 r
.56238 .70046 m .56395 .70245 L .56476 .69976 L F
.56238 .70046 m .56189 .70325 L .56395 .70245 L F
0 0 0 r
.41825 .70967 m .41418 .71067 L .4155 .71066 L F
.669 .772 .927 r
.70115 .47852 m .69777 .47795 L .70001 .47705 L F
.737 .785 .891 r
.70361 .47659 m .70115 .47852 L .70001 .47705 L F
.942 .848 .721 r
.69827 .51513 m .69847 .51882 L .69632 .51885 L F
0 0 0 r
.55958 .78669 m .55872 .78798 L .56044 .78479 L F
.667 .963 .759 r
.55686 .78896 m .55872 .78798 L .55958 .78669 L F
.551 .772 .98 r
.68766 .47488 m .68621 .47655 L .68541 .47583 L F
.68766 .47488 m .68853 .47604 L .68621 .47655 L F
.653 .694 .875 r
.48743 .65209 m .49079 .65295 L .48962 .65023 L F
.72 .691 .821 r
.48962 .65023 m .49079 .65295 L .493 .65224 L F
.721 .934 .958 r
.70278 .51122 m .69972 .51215 L .70175 .51098 L F
.007 0 0 r
.70429 .51118 m .70278 .51122 L .70175 .51098 L F
.70429 .51118 m .70521 .51089 L .70278 .51122 L F
.902 .968 .815 r
.62078 .55403 m .6207 .55033 L .62054 .55159 L F
.014 0 .427 r
.6207 .55033 m .62217 .5502 L .62209 .54772 L F
0 0 .064 r
.6207 .55033 m .62081 .55208 L .62217 .5502 L F
.564 .649 .892 r
.39501 .71099 m .39527 .70726 L .39394 .70817 L F
.39501 .71099 m .39735 .71067 L .39527 .70726 L F
.6 .602 .826 r
.39501 .71099 m .39854 .71314 L .39735 .71067 L F
.279 .35 .758 r
.50366 .79719 m .50218 .7985 L .50103 .79556 L F
.50366 .79719 m .50417 .79877 L .50218 .7985 L F
.306 .272 .656 r
.50417 .79877 m .50416 .80088 L .50218 .7985 L F
.365 0 .16 r
.45632 .65526 m .45511 .65737 L .45281 .65785 L F
.012 0 0 r
.45784 .65499 m .45632 .65526 L .45804 .6549 L F
.45784 .65499 m .45511 .65737 L .45632 .65526 L F
.576 .509 .743 r
.53297 .8036 m .5331 .80705 L .53539 .8062 L F
.5 .161 .324 r
.46161 .6955 m .46133 .69703 L .45906 .69712 L F
.197 0 .157 r
.46007 .6861 m .46088 .6877 L .46243 .68628 L F
.46007 .6861 m .4591 .68837 L .46088 .6877 L F
.346 0 .072 r
.52739 .80746 m .52314 .81015 L .52586 .80711 L F
.657 .103 0 r
.52855 .8084 m .52739 .80746 L .52586 .80711 L F
.784 .783 .852 r
.68107 .53451 m .67767 .53474 L .6802 .532 L F
.8 .69 .743 r
.68107 .53451 m .67903 .53784 L .67767 .53474 L F
.789 .785 .85 r
.68387 .53223 m .68107 .53451 L .6802 .532 L F
.438 0 0 r
.65765 .48242 m .65997 .48271 L .66102 .48169 L F
.628 .868 .987 r
.66318 .48108 m .66102 .48169 L .66259 .47989 L F
.586 .404 .602 r
.65997 .48271 m .66259 .47989 L .66102 .48169 L F
.401 .451 .797 r
.56393 .7135 m .56421 .71759 L .56185 .71445 L F
.56393 .7135 m .56534 .71682 L .56421 .71759 L F
.781 .61 .668 r
.56142 .60199 m .558 .59932 L .562 .60125 L F
.56142 .60199 m .55778 .60175 L .558 .59932 L F
.56 .328 .522 r
.56142 .60199 m .56131 .60285 L .55778 .60175 L F
.56142 .60199 m .5616 .60436 L .56131 .60285 L F
.656 .601 .781 r
.56342 .60139 m .56142 .60199 L .562 .60125 L F
.678 .417 .519 r
.56297 .60422 m .5616 .60436 L .56142 .60199 L F
.179 0 .093 r
.33911 .63984 m .33836 .63867 L .3404 .6379 L F
.33911 .63984 m .33733 .64064 L .33836 .63867 L F
.287 .367 .771 r
.6658 .48228 m .66449 .48433 L .66318 .48108 L F
.867 .767 .262 r
.66525 .49137 m .66571 .48994 L .66464 .4889 L F
.66525 .49137 m .66531 .49328 L .66571 .48994 L F
.59 .594 .824 r
.64454 .51339 m .64083 .51203 L .64359 .51177 L F
.122 0 .236 r
.64598 .50935 m .64359 .51177 L .64634 .50929 L F
.64598 .50935 m .6463 .511 L .64359 .51177 L F
.84 .373 .06 r
.64452 .50978 m .64598 .50935 L .64538 .50771 L F
.64452 .50978 m .6463 .51102 L .64598 .50935 L F
.94 .814 .361 r
.64588 .50552 m .64598 .50935 L .6476 .50557 L F
.64588 .50552 m .64538 .50771 L .64598 .50935 L F
.837 .745 .762 r
.6474 .50937 m .64452 .50978 L .64654 .50678 L F
.64765 .51012 m .64695 .51004 L .6474 .50937 L F
.64695 .51004 m .64452 .50978 L .6474 .50937 L F
.122 0 .236 r
.6463 .511 m .6463 .51102 L .64629 .51102 L F
.6463 .511 m .64629 .51102 L .64359 .51177 L F
0 0 .272 r
.6463 .51102 m .64454 .51339 L .64359 .51177 L F
.467 .442 .747 r
.28539 .62715 m .28287 .62411 L .2844 .62358 L F
.74 .928 .952 r
.40642 .71248 m .40993 .71182 L .40853 .71244 L F
.585 .125 .126 r
.41236 .71162 m .40853 .71244 L .40993 .71182 L F
.689 .662 .819 r
.25412 .62754 m .25689 .62749 L .25526 .62424 L F
.413 0 0 r
.25309 .62837 m .25689 .62749 L .25412 .62754 L F
0 0 .237 r
.56534 .71682 m .56525 .71924 L .56466 .71977 L F
.108 .48 .897 r
.56525 .71924 m .56675 .72076 L .56466 .71977 L F
.672 .169 .041 r
.55687 .72228 m .55355 .72203 L .55458 .72085 L F
.49 .383 .66 r
.60529 .57416 m .60735 .57348 L .60685 .57071 L F
.492 .314 .568 r
.60518 .57681 m .60735 .57348 L .60529 .57416 L F
.602 .565 .785 r
.51948 .65452 m .51749 .6552 L .51688 .65322 L F
.656 .611 .792 r
.52096 .65613 m .51749 .6552 L .51948 .65452 L F
.759 .677 .772 r
.5229 .6532 m .52282 .6553 L .51948 .65452 L F
.763 .669 .759 r
.52282 .6553 m .52096 .65613 L .51948 .65452 L F
.66 .574 .748 r
.52524 .65246 m .52282 .6553 L .5229 .6532 L F
.929 .97 .695 r
.56044 .78479 m .56151 .78133 L .55962 .78405 L F
.995 .767 .411 r
.55958 .78669 m .56044 .78479 L .55962 .78405 L F
.457 .06 .198 r
.45345 .69942 m .45699 .69727 L .45553 .69944 L F
.531 .162 .286 r
.45906 .69712 m .45553 .69944 L .45699 .69727 L F
.517 .099 .186 r
.27317 .58684 m .27537 .58702 L .27689 .58507 L F
.427 .044 .208 r
.27537 .58702 m .27912 .58437 L .27689 .58507 L F
.361 .794 .616 r
.48469 .7736 m .48463 .77363 L .48631 .77265 L F
.804 .837 .876 r
.24857 .63517 m .25044 .63604 L .25228 .6343 L F
.752 .936 .946 r
.66593 .51728 m .66613 .51827 L .66856 .51674 L F
.334 0 .059 r
.45113 .69949 m .44731 .70183 L .4487 .70012 L F
.677 .734 .893 r
.49907 .69462 m .49699 .69605 L .49563 .69443 L F
.491 .354 .622 r
.49699 .69605 m .49907 .69462 L .49563 .69443 L F
.49699 .69605 m .4994 .69718 L .49907 .69462 L F
.757 .648 .741 r
.67538 .52295 m .67875 .52333 L .67772 .5203 L F
.758 .646 .738 r
.67538 .52295 m .67657 .52641 L .67875 .52333 L F
.701 .618 .761 r
.67772 .5203 m .67875 .52333 L .68059 .52052 L F
.57 .481 .715 r
.24998 .65015 m .25001 .65333 L .2521 .65026 L F
.329 0 .126 r
.51588 .69089 m .51507 .69305 L .51806 .69147 L F
.166 0 .236 r
.5893 .71957 m .59184 .71665 L .58999 .71769 L F
.331 .613 .952 r
.54042 .76646 m .54142 .76773 L .53879 .76683 L F
.526 .581 .853 r
.39735 .71067 m .39854 .71314 L .39967 .71038 L F
.308 0 .128 r
.33332 .64196 m .33244 .64318 L .33048 .64365 L F
.283 0 .111 r
.33457 .64258 m .33332 .64196 L .33522 .64122 L F
.33457 .64258 m .33244 .64318 L .33332 .64196 L F
.683 .137 0 r
.5534 .77499 m .55539 .77515 L .55403 .77432 L F
.479 .47 .77 r
.5139 .64298 m .51286 .64677 L .51172 .64338 L F
.5139 .64298 m .5148 .64651 L .51286 .64677 L F
.817 .671 .701 r
.57288 .5997 m .56944 .60156 L .56935 .59948 L F
.57288 .5997 m .57257 .60243 L .56944 .60156 L F
.491 .888 .951 r
.54643 .76491 m .54694 .76523 L .54523 .76555 L F
.481 .044 .131 r
.54502 .76599 m .54752 .76433 L .54643 .76491 L F
.54752 .76433 m .54825 .76385 L .54643 .76491 L F
.491 .888 .951 r
.54643 .76491 m .54523 .76555 L .54447 .76569 L F
.639 .362 .483 r
.54981 .76512 m .54977 .76728 L .54694 .76523 L F
.473 .412 .708 r
.54694 .76523 m .54977 .76728 L .54783 .76774 L F
.875 .973 .661 r
.71788 .49434 m .71722 .49558 L .71733 .49395 L F
0 0 0 r
.71722 .49558 m .7175 .49571 L .71733 .49395 L F
.882 .579 .066 r
.71694 .49368 m .71733 .49395 L .7175 .49571 L F
.854 .52 .421 r
.71431 .49104 m .71719 .49199 L .71733 .49395 L F
.71431 .49104 m .71733 .49395 L .71667 .49269 L F
.882 .579 .066 r
.71667 .49269 m .71733 .49395 L .71694 .49368 L F
.875 .973 .661 r
.7189 .49244 m .71788 .49434 L .71733 .49395 L F
0 0 0 r
.71722 .49558 m .71683 .49758 L .7175 .49571 L F
.584 .463 .681 r
.38309 .67198 m .38503 .66899 L .38318 .66962 L F
.628 .358 .489 r
.56421 .70604 m .56609 .70779 L .56375 .7082 L F
.682 .34 .389 r
.56701 .70662 m .56609 .70779 L .56421 .70604 L F
.693 .573 .716 r
.506 .65787 m .50701 .65917 L .50936 .65827 L F
.074 .252 .742 r
.48573 .79295 m .48705 .796 L .4853 .79604 L F
.966 .728 .528 r
.48705 .796 m .48566 .79791 L .4853 .79604 L F
.48705 .796 m .48724 .79863 L .48566 .79791 L F
.751 .835 .915 r
.64396 .49924 m .64245 .50133 L .64064 .49999 L F
.444 .623 .928 r
.50701 .65917 m .51071 .65936 L .50936 .65827 L F
.50701 .65917 m .50904 .66011 L .51071 .65936 L F
.661 .972 .879 r
.6688 .47796 m .67015 .47642 L .67117 .47732 L F
.6688 .47796 m .66816 .47778 L .67015 .47642 L F
.595 .206 .275 r
.43456 .66385 m .43329 .66592 L .43099 .66557 L F
.367 0 .042 r
.43692 .66406 m .43329 .66592 L .43456 .66385 L F
.523 .098 .175 r
.43696 .69384 m .44069 .69211 L .43723 .6921 L F
.43696 .69384 m .43938 .6939 L .44069 .69211 L F
.464 .036 .141 r
.43938 .6939 m .44311 .69199 L .44069 .69211 L F
.097 .654 .754 r
.46434 .65315 m .46283 .6532 L .46076 .65337 L F
.421 .782 .995 r
.36529 .81565 m .36599 .81466 L .36385 .81501 L F
.36529 .81565 m .36762 .81546 L .36599 .81466 L F
.36529 .81565 m .36599 .81466 L .36385 .81501 L F
.36529 .81565 m .36762 .81546 L .36599 .81466 L F
.481 .488 .788 r
.38195 .67779 m .3849 .68062 L .38414 .67742 L F
.502 0 0 r
.49123 .77201 m .4894 .77036 L .48927 .77093 L F
.49123 .77201 m .49276 .77314 L .4894 .77036 L F
.603 .448 .644 r
.4894 .77036 m .49134 .77129 L .49244 .76807 L F
.661 .356 .444 r
.4894 .77036 m .49276 .77314 L .49134 .77129 L F
.568 .649 .89 r
.47755 .78049 m .47644 .77857 L .47644 .78099 L F
.47755 .78049 m .48053 .78074 L .47644 .77857 L F
.47755 .78049 m .48115 .78119 L .48053 .78074 L F
.568 0 0 r
.58204 .72616 m .5815 .72617 L .57934 .72472 L F
.039 .454 .877 r
.5815 .72617 m .58219 .72569 L .58071 .72618 L F
.41 0 0 r
.5815 .72617 m .58017 .72636 L .57796 .72551 L F
.039 .454 .877 r
.5815 .72617 m .58071 .72618 L .58017 .72636 L F
.568 0 0 r
.58276 .72654 m .5815 .72617 L .58204 .72616 L F
.519 0 0 r
.58472 .7264 m .5815 .72617 L .58276 .72654 L F
0 .49 .713 r
.48016 .63509 m .4836 .63565 L .48365 .63566 L F
.817 .675 .706 r
.67347 .52591 m .67657 .52641 L .67538 .52295 L F
.727 .479 .552 r
.67327 .5288 m .67657 .52641 L .67347 .52591 L F
.67327 .5288 m .67748 .52902 L .67657 .52641 L F
.001 .578 .714 r
.65419 .48239 m .65765 .48242 L .65524 .48234 L F
.518 .702 .953 r
.77036 .58091 m .77212 .57921 L .76952 .57991 L F
.77036 .58091 m .7734 .58119 L .77212 .57921 L F
.335 .754 .977 r
.37322 .72256 m .37456 .72322 L .37082 .72269 L F
.37322 .72256 m .37456 .72322 L .37082 .72269 L F
.507 .507 .791 r
.38798 .69203 m .3888 .68829 L .38678 .68857 L F
.38798 .69203 m .38994 .69149 L .3888 .68829 L F
.444 .344 .646 r
.38798 .69203 m .39032 .69411 L .38994 .69149 L F
.38798 .69203 m .38853 .69511 L .39032 .69411 L F
.509 .251 .459 r
.60022 .57958 m .6026 .57912 L .60279 .57714 L F
.456 .125 .315 r
.60466 .57834 m .60279 .57714 L .6026 .57912 L F
.60466 .57834 m .60518 .57681 L .60279 .57714 L F
.718 .702 .834 r
.66765 .48099 m .66318 .48108 L .66584 .47904 L F
.287 .367 .771 r
.6658 .48228 m .66318 .48108 L .66765 .48099 L F
.728 .297 0 r
.66807 .48129 m .6658 .48228 L .66765 .48099 L F
.238 0 .206 r
.36211 .61826 m .36028 .619 L .3629 .61655 L F
.166 0 .167 r
.36211 .61826 m .3629 .61655 L .36464 .61558 L F
0 0 0 r
.62316 .57688 m .62225 .57839 L .62105 .57978 L F
0 0 .146 r
.62166 .58045 m .62105 .57978 L .62225 .57839 L F
.62166 .58045 m .62074 .58199 L .62105 .57978 L F
.019 0 0 r
.32093 .60006 m .3193 .60064 L .31712 .60097 L F
.398 0 0 r
.32312 .6005 m .3193 .60064 L .32093 .60006 L F
.592 .309 .455 r
.51429 .77625 m .51655 .77817 L .51469 .7754 L F
.514 .427 .695 r
.51469 .7754 m .51745 .77614 L .51614 .77336 L F
.557 .299 .482 r
.51745 .77614 m .51655 .77817 L .51469 .7754 L F
.72 .691 .821 r
.48962 .65023 m .493 .65224 L .49177 .64921 L F
.792 .747 .812 r
.49177 .64921 m .493 .65224 L .49515 .64946 L F
.54 .835 .999 r
.67602 .47606 m .67455 .47744 L .67364 .47665 L F
.67602 .47606 m .67686 .47688 L .67455 .47744 L F
.413 0 0 r
.25309 .62837 m .25436 .62857 L .25689 .62749 L F
.783 .564 .604 r
.25436 .62857 m .257 .6302 L .25689 .62749 L F
.459 .472 .785 r
.25689 .62749 m .2575 .62378 L .25526 .62424 L F
.25689 .62749 m .25848 .62688 L .2575 .62378 L F
.38 .261 .59 r
.25689 .62749 m .25867 .62931 L .25848 .62688 L F
.394 .263 .582 r
.25689 .62749 m .257 .6302 L .25867 .62931 L F
.409 .807 .985 r
.34916 .59072 m .34849 .59176 L .34669 .59103 L F
.34916 .59072 m .35054 .59151 L .34849 .59176 L F
.683 .137 0 r
.5534 .77499 m .55403 .77432 L .55337 .77255 L F
.902 .934 .824 r
.55337 .77255 m .55403 .77432 L .55665 .76995 L F
.69 .937 .964 r
.31078 .63233 m .30992 .63238 L .30899 .63222 L F
.224 .725 .906 r
.30899 .63222 m .30808 .63168 L .31183 .6319 L F
.255 .732 .936 r
.30899 .63222 m .31301 .63231 L .31078 .63233 L F
.249 0 .203 r
.48241 .77497 m .48631 .77265 L .48463 .77363 L F
.48241 .77497 m .48571 .77452 L .48631 .77265 L F
.533 .499 .764 r
.48482 .77882 m .48571 .77452 L .48241 .77497 L F
.716 .753 .881 r
.7071 .477 m .70361 .47659 L .70593 .47566 L F
.721 .851 .943 r
.70838 .47475 m .7071 .477 L .70593 .47566 L F
.70838 .47475 m .70947 .47587 L .7071 .477 L F
.492 .792 .998 r
.50117 .64935 m .50461 .6499 L .50321 .64892 L F
.481 .694 .962 r
.50461 .6499 m .50529 .64836 L .50321 .64892 L F
.50461 .6499 m .50654 .64956 L .50529 .64836 L F
.652 .567 .746 r
.50461 .6499 m .50801 .65267 L .50654 .64956 L F
.535 .343 .567 r
.70614 .50112 m .70861 .50286 L .70853 .50043 L F
.514 .349 .595 r
.70614 .50112 m .70634 .50358 L .70861 .50286 L F
.535 .343 .567 r
.70614 .50112 m .70861 .50286 L .70853 .50043 L F
.514 .349 .595 r
.70614 .50112 m .70634 .50358 L .70861 .50286 L F
.873 .841 .811 r
.64203 .51976 m .64364 .52084 L .6454 .51794 L F
.96 .725 .538 r
.64203 .51976 m .64325 .523 L .64364 .52084 L F
.796 .542 .554 r
.64364 .52084 m .64325 .523 L .64662 .52353 L F
.997 .797 .443 r
.59313 .57409 m .5925 .571 L .59197 .57241 L F
.783 .656 .723 r
.5898 .57611 m .59313 .57409 L .59197 .57241 L F
.5898 .57611 m .59318 .57633 L .59313 .57409 L F
.81 .618 .644 r
.59318 .57633 m .5944 .57693 L .59313 .57409 L F
.862 .828 .813 r
.3158 .66119 m .31734 .66327 L .31422 .66345 L F
.909 .951 .814 r
.3158 .66119 m .31422 .66345 L .31448 .66244 L F
.862 .905 .861 r
.31422 .66345 m .31634 .66167 L .31448 .66244 L F
.31634 .66167 m .31653 .6615 L .31632 .6616 L F
.469 .68 .957 r
.31634 .66167 m .3165 .66213 L .31611 .6616 L F
.31627 .6616 m .31611 .6616 L .3158 .66119 L F
.31634 .66167 m .31611 .6616 L .31627 .6616 L F
.862 .905 .861 r
.31634 .66167 m .31632 .6616 L .31448 .66244 L F
.469 .68 .957 r
.31634 .66167 m .31734 .66327 L .3165 .66213 L F
.852 .849 .839 r
.31634 .66167 m .31734 .66327 L .31653 .6615 L F
.424 0 .055 r
.31632 .6616 m .31653 .6615 L .31668 .66161 L F
.479 .656 .938 r
.31653 .6615 m .31734 .66327 L .3194 .66304 L F
.469 .68 .957 r
.3194 .66304 m .31734 .66327 L .31615 .66137 L F
.852 .849 .839 r
.31422 .66345 m .31734 .66327 L .31634 .66167 L F
.424 0 .055 r
.31448 .66244 m .31632 .6616 L .31755 .66221 L F
.31632 .6616 m .31668 .66161 L .31755 .66221 L F
.469 .68 .957 r
.31615 .66137 m .31634 .66167 L .3158 .66119 L F
.717 .497 .59 r
.52656 .77273 m .5246 .7703 L .52805 .77073 L F
.535 .18 .313 r
.53191 .77218 m .52805 .77073 L .53032 .77062 L F
.53191 .77218 m .52656 .77273 L .52805 .77073 L F
.949 .757 .61 r
.65838 .51469 m .65629 .51676 L .65739 .51362 L F
.65838 .51469 m .65785 .51794 L .65629 .51676 L F
.113 .624 .894 r
.57071 .75743 m .57128 .75757 L .56982 .75564 L F
.822 .912 .9 r
.58613 .72858 m .58725 .7258 L .58472 .7264 L F
.58613 .72858 m .58883 .72637 L .58725 .7258 L F
.471 .43 .73 r
.41306 .67714 m .41097 .67813 L .41048 .67514 L F
.532 .445 .703 r
.41306 .67714 m .41144 .68078 L .41097 .67813 L F
.772 .903 .932 r
.71237 .51816 m .7158 .51746 L .71458 .51747 L F
.284 0 0 r
.71458 .51747 m .7158 .51746 L .71749 .51791 L F
.265 .551 .927 r
.7158 .51746 m .71896 .5191 L .71749 .51791 L F
.789 .586 .626 r
.59109 .57904 m .5944 .57693 L .59318 .57633 L F
.59109 .57904 m .59451 .57947 L .5944 .57693 L F
.905 .89 .805 r
.56252 .57973 m .56334 .57593 L .56401 .57624 L F
.986 .859 .49 r
.56401 .57624 m .56334 .57593 L .56367 .57375 L F
.215 .686 .94 r
.27933 .74818 m .28063 .74884 L .27676 .74807 L F
.27676 .74807 m .28063 .74884 L .27933 .74818 L F
.665 .822 .959 r
.28086 .74692 m .28063 .74884 L .27933 .74818 L F
.28086 .74692 m .28249 .74788 L .28063 .74884 L F
.28063 .74884 m .28086 .74692 L .27933 .74818 L F
.28063 .74884 m .28249 .74788 L .28086 .74692 L F
.526 .331 .559 r
.51084 .69448 m .51308 .69405 L .51095 .69207 L F
.373 .056 .294 r
.634 .48344 m .63674 .48023 L .63454 .48145 L F
.42 0 0 r
.49986 .81643 m .50323 .81734 L .50213 .81706 L F
.221 .521 .916 r
.49859 .81479 m .49986 .81643 L .50213 .81706 L F
.961 .9 .716 r
.78122 .59648 m .77907 .59825 L .78082 .59522 L F
.78122 .59648 m .77987 .59925 L .77907 .59825 L F
.725 .917 .959 r
.78459 .59432 m .78122 .59648 L .78082 .59522 L F
.741 .42 .44 r
.57257 .60243 m .56945 .60397 L .56944 .60156 L F
.57257 .60243 m .57299 .60434 L .56945 .60397 L F
.635 .227 .253 r
.58102 .69237 m .58104 .69374 L .57717 .69367 L F
.496 .118 .252 r
.58102 .69237 m .58353 .69353 L .58104 .69374 L F
.211 0 0 r
.5469 .77327 m .54301 .77582 L .54625 .77605 L F
.59 .364 .542 r
.54853 .77558 m .5469 .77327 L .54625 .77605 L F
.54853 .77558 m .54869 .77328 L .5469 .77327 L F
.774 .707 .788 r
.76415 .60741 m .76515 .61062 L .76806 .60775 L F
.491 .834 .997 r
.68029 .48215 m .68086 .48284 L .68562 .48149 L F
.779 .361 .258 r
.55197 .73306 m .55357 .73402 L .55542 .73391 L F
.807 .418 .318 r
.55357 .73402 m .55409 .73563 L .55542 .73391 L F
.821 .438 .329 r
.55409 .73563 m .55728 .73702 L .55542 .73391 L F
.859 .427 .191 r
.55542 .73391 m .55728 .73702 L .55853 .73701 L F
.534 .25 .431 r
.24452 .62424 m .24351 .62642 L .2429 .62466 L F
.24452 .62424 m .24351 .62642 L .2429 .62466 L F
.307 0 .212 r
.48583 .75372 m .48757 .75335 L .48861 .75089 L F
.693 .35 .389 r
.48861 .75089 m .49108 .75313 L .49097 .75062 L F
.48861 .75089 m .48757 .75335 L .49108 .75313 L F
.239 .209 .622 r
.63509 .49981 m .63378 .50373 L .63271 .5022 L F
.63509 .49981 m .63478 .50314 L .63378 .50373 L F
.161 .082 .512 r
.63514 .5049 m .63378 .50373 L .63478 .50314 L F
.63514 .5049 m .63391 .50614 L .63378 .50373 L F
.62 .653 .861 r
.68737 .52483 m .68529 .52697 L .68487 .52528 L F
.68737 .52483 m .68808 .52693 L .68529 .52697 L F
.45 .206 .452 r
.29083 .61245 m .28881 .61284 L .29114 .61058 L F
.482 .287 .539 r
.29083 .61245 m .28854 .61559 L .28881 .61284 L F
.207 .715 .898 r
.50213 .81706 m .50323 .81734 L .505 .81724 L F
.563 .683 .92 r
.58381 .72115 m .58436 .72029 L .58341 .72147 L F
.76 .302 .163 r
.58436 .72029 m .58731 .72036 L .58477 .71965 L F
.69 .349 .393 r
.58436 .72029 m .5893 .71957 L .58731 .72036 L F
.58436 .72029 m .59161 .72189 L .5893 .71957 L F
.563 .683 .92 r
.58719 .71847 m .59161 .72189 L .58436 .72029 L F
.58719 .71847 m .58436 .72029 L .58381 .72115 L F
.76 .302 .163 r
.58436 .72029 m .58477 .71965 L .5847 .71963 L F
.419 .126 .358 r
.57082 .70505 m .56919 .70377 L .57415 .70296 L F
.57082 .70505 m .56873 .70559 L .56919 .70377 L F
.707 .489 .591 r
.50142 .76153 m .50501 .75974 L .50107 .76005 L F
.50142 .76153 m .50523 .76116 L .50501 .75974 L F
.258 0 0 r
.43076 .64908 m .433 .64921 L .43421 .64884 L F
0 0 0 r
.41825 .70967 m .41642 .71023 L .41418 .71067 L F
.4 0 0 r
.42017 .7091 m .41642 .71023 L .41825 .70967 L F
.674 .443 .564 r
.55446 .74307 m .55108 .74508 L .551 .74244 L F
.55446 .74307 m .55412 .74508 L .55108 .74508 L F
.61 .955 .846 r
.48468 .79848 m .481 .80034 L .4827 .79964 L F
0 0 0 r
.48566 .79791 m .48468 .79848 L .4827 .79964 L F
.324 .746 .975 r
.48566 .79791 m .48724 .79863 L .48468 .79848 L F
.023 0 0 r
.53772 .80168 m .5341 .80439 L .53681 .8039 L F
.708 .287 .244 r
.5385 .80323 m .53772 .80168 L .53681 .8039 L F
.459 .186 .411 r
.53991 .8012 m .53772 .80168 L .5385 .80323 L F
.614 .308 .427 r
.48662 .78454 m .48894 .78417 L .48926 .78239 L F
.596 .434 .633 r
.48926 .78239 m .49165 .78238 L .49191 .77898 L F
.715 .515 .617 r
.48894 .78417 m .49165 .78238 L .48926 .78239 L F
.704 .638 .78 r
.47398 .63613 m .47211 .6358 L .47478 .63555 L F
.479 .898 .858 r
.47478 .63555 m .47246 .63611 L .4757 .63487 L F
.47478 .63555 m .4757 .63487 L .47683 .63444 L F
.704 .638 .78 r
.47569 .63643 m .47398 .63613 L .47478 .63555 L F
.648 .864 .981 r
.47783 .63575 m .47569 .63643 L .47478 .63555 L F
.394 .21 .509 r
.24603 .6051 m .24787 .60462 L .24802 .60202 L F
.452 .382 .688 r
.24603 .6051 m .24824 .607 L .24787 .60462 L F
.474 .383 .672 r
.24603 .6051 m .24646 .60761 L .24824 .607 L F
.538 .621 .882 r
.24712 .6155 m .24925 .61879 L .25099 .61811 L F
.555 .547 .801 r
.24925 .61879 m .25172 .6193 L .25099 .61811 L F
.793 .34 0 r
.67025 .48438 m .66929 .48357 L .66807 .48129 L F
.668 .898 .979 r
.67145 .48255 m .67025 .48438 L .67278 .48392 L F
.67145 .48255 m .66929 .48357 L .67025 .48438 L F
0 0 0 r
.62422 .57534 m .62316 .57688 L .62491 .57349 L F
.62422 .57534 m .62225 .57839 L .62316 .57688 L F
.349 .504 .871 r
.37128 .59666 m .37064 .59871 L .36883 .59645 L F
.37128 .59666 m .37239 .59886 L .37064 .59871 L F
.568 .918 .961 r
.78254 .58255 m .77858 .58335 L .77977 .58455 L F
.601 .533 .75 r
.74274 .50506 m .73949 .50666 L .73844 .50344 L F
.74274 .50506 m .74196 .50621 L .73949 .50666 L F
0 0 0 r
.74196 .50621 m .73853 .5081 L .73949 .50666 L F
.707 .301 .276 r
.58649 .69233 m .58593 .69421 L .58353 .69353 L F
.713 .307 .278 r
.58649 .69233 m .58868 .69442 L .58593 .69421 L F
.861 .416 .132 r
.51494 .67324 m .5139 .67388 L .51274 .67157 L F
.77 .954 .635 r
.51639 .67064 m .51494 .67324 L .51779 .67228 L F
.51639 .67064 m .5139 .67388 L .51494 .67324 L F
.462 .293 .566 r
.28605 .61841 m .28412 .62152 L .28414 .61912 L F
.543 .855 .998 r
.49519 .63372 m .49174 .63365 L .4939 .63278 L F
.586 .84 .993 r
.49727 .63301 m .49519 .63372 L .4939 .63278 L F
0 .043 .548 r
.55728 .73702 m .5591 .73886 L .55853 .73701 L F
.206 .571 .94 r
.35774 .59353 m .35398 .59145 L .35661 .59203 L F
.409 .637 .949 r
.35844 .59202 m .35774 .59353 L .35661 .59203 L F
.442 .676 .963 r
.35844 .59202 m .35975 .59347 L .35774 .59353 L F
.427 .266 .559 r
.34152 .61342 m .34324 .61482 L .34348 .61287 L F
.34152 .61342 m .34142 .61567 L .34324 .61482 L F
.622 .803 .969 r
.6756 .53739 m .67903 .53784 L .67805 .5371 L F
.555 .849 .998 r
.67903 .53784 m .68032 .53644 L .67805 .5371 L F
.67903 .53784 m .68135 .53722 L .68032 .53644 L F
.092 0 0 r
.76489 .57325 m .76824 .57349 L .76593 .57328 L F
.428 .139 .369 r
.36028 .619 m .35965 .62113 L .35756 .62163 L F
.419 .13 .365 r
.36177 .62056 m .36028 .619 L .36211 .61826 L F
.36177 .62056 m .35965 .62113 L .36028 .619 L F
.689 .919 .971 r
.47456 .65148 m .47333 .65272 L .47576 .65272 L F
.647 .512 .684 r
.47333 .65272 m .47564 .65483 L .47576 .65272 L F
.728 .822 .923 r
.47456 .65148 m .47576 .65272 L .47802 .65053 L F
.811 .848 .877 r
.74165 .58548 m .74057 .58748 L .74136 .5868 L F
.74057 .58748 m .74006 .58841 L .74136 .5868 L F
.434 .516 .843 r
.74289 .58547 m .74136 .5868 L .74354 .58583 L F
.992 .772 .396 r
.74165 .58548 m .74136 .5868 L .74068 .58423 L F
.409 .439 .78 r
.74296 .58285 m .74165 .58548 L .74068 .58423 L F
.74296 .58285 m .74574 .58527 L .74165 .58548 L F
.803 .927 .917 r
.74296 .58285 m .74165 .58548 L .74068 .58423 L F
.434 .516 .843 r
.74068 .58423 m .74136 .5868 L .74289 .58547 L F
.952 .74 .58 r
.59346 .69201 m .59341 .69446 L .59497 .69472 L F
.992 .876 .602 r
.59341 .69446 m .59374 .6976 L .59497 .69472 L F
.347 .256 .609 r
.50936 .65827 m .51091 .65796 L .51096 .65501 L F
.368 .345 .702 r
.50936 .65827 m .51186 .65973 L .51091 .65796 L F
.591 .061 0 r
.51071 .65936 m .51186 .65973 L .50936 .65827 L F
.385 .017 .212 r
.48779 .77649 m .48482 .77882 L .48543 .77684 L F
.855 .722 .715 r
.64303 .5251 m .64443 .52645 L .64325 .523 L F
.881 .798 .763 r
.64113 .52832 m .64443 .52645 L .64303 .5251 L F
.64113 .52832 m .64266 .52951 L .64443 .52645 L F
.781 .687 .761 r
.64325 .523 m .64443 .52645 L .64662 .52353 L F
.752 .529 .593 r
.57607 .60214 m .57605 .60449 L .57299 .60434 L F
.56 .346 .547 r
.57868 .60177 m .57605 .60449 L .57607 .60214 L F
.817 .559 .55 r
.73705 .50924 m .7346 .51085 L .73489 .50908 L F
.73705 .50924 m .73662 .51128 L .7346 .51085 L F
.326 .072 .367 r
.73853 .5081 m .73662 .51128 L .73705 .50924 L F
.402 .071 .286 r
.25528 .59375 m .25652 .59496 L .25731 .59322 L F
.25528 .59375 m .25453 .59551 L .25652 .59496 L F
.492 .233 .449 r
.2933 .6102 m .29083 .61245 L .29114 .61058 L F
.882 .822 .784 r
.48991 .81302 m .48954 .81522 L .48921 .81346 L F
.49161 .81194 m .49108 .81278 L .48991 .81302 L F
.49108 .81278 m .48954 .81522 L .48991 .81302 L F
.838 .446 .305 r
.48893 .81618 m .48802 .8127 L .48895 .81321 L F
0 0 .552 r
.48895 .81321 m .48802 .8127 L .48782 .81213 L F
.48895 .81321 m .48782 .81213 L .48745 .81112 L F
.497 .844 .574 r
.48496 .8153 m .48802 .8127 L .48825 .81358 L F
.838 .446 .305 r
.48893 .81618 m .48825 .81358 L .48802 .8127 L F
.586 .095 .054 r
.48885 .81323 m .48745 .81112 L .48586 .812 L F
0 0 .552 r
.4894 .81346 m .48919 .81334 L .48916 .81317 L F
.48919 .81334 m .48895 .81321 L .48916 .81317 L F
.586 .095 .054 r
.4894 .81346 m .48916 .81317 L .48885 .81323 L F
0 0 .552 r
.48916 .81317 m .48895 .81321 L .48745 .81112 L F
.586 .095 .054 r
.48916 .81317 m .48745 .81112 L .48885 .81323 L F
.838 .446 .305 r
.48893 .81618 m .48895 .81321 L .48918 .81348 L F
.882 .822 .784 r
.48921 .81346 m .48893 .81618 L .48918 .81348 L F
.48954 .81522 m .48893 .81618 L .48921 .81346 L F
.846 .768 .776 r
.49134 .81654 m .49168 .81714 L .49381 .81408 L F
.49134 .81654 m .49381 .81408 L .49249 .81593 L F
.246 .417 .835 r
.4909 .81441 m .49134 .81654 L .49249 .81593 L F
.882 .822 .784 r
.49161 .81194 m .48921 .81346 L .49001 .81423 L F
.49161 .81194 m .49001 .81423 L .49015 .81426 L F
.775 .655 .73 r
.49417 .81126 m .49543 .8127 L .49161 .81194 L F
0 0 0 r
.49282 .81161 m .49161 .81194 L .49015 .81426 L F
.246 .417 .835 r
.48997 .81422 m .49134 .81654 L .49103 .81502 L F
.49044 .81431 m .49103 .81502 L .4909 .81441 L F
.48997 .81422 m .49103 .81502 L .49044 .81431 L F
0 0 0 r
.49282 .81161 m .49015 .81426 L .49031 .81417 L F
.246 .417 .835 r
.48903 .81263 m .48997 .81422 L .49015 .81426 L F
.772 .595 .659 r
.48958 .8111 m .48993 .81377 L .48903 .81263 L F
.246 .417 .835 r
.48903 .81263 m .49015 .81426 L .49026 .8142 L F
.838 .446 .305 r
.48893 .81618 m .48918 .81348 L .48935 .8137 L F
.882 .822 .784 r
.48918 .81348 m .48893 .81618 L .48798 .81424 L F
.838 .446 .305 r
.48937 .81361 m .4893 .8134 L .4894 .81346 L F
.48935 .8137 m .4893 .8134 L .48937 .81361 L F
.764 .783 .868 r
.48798 .81424 m .48893 .81618 L .48935 .8137 L F
.882 .822 .784 r
.48918 .81348 m .48798 .81424 L .48935 .8137 L F
.764 .783 .868 r
.48798 .81424 m .48935 .8137 L .4894 .81346 L F
.882 .822 .784 r
.48935 .8137 m .48798 .81424 L .48987 .81431 L F
.459 .536 .848 r
.48798 .81424 m .49134 .81654 L .48997 .81422 L F
.882 .822 .784 r
.49011 .81432 m .48987 .81431 L .49002 .81447 L F
.772 .595 .659 r
.48993 .81377 m .49002 .81447 L .48903 .81263 L F
.703 .571 .703 r
.49282 .81161 m .49031 .81417 L .48903 .81263 L F
.246 .417 .835 r
.48903 .81263 m .49026 .8142 L .49052 .81405 L F
0 0 0 r
.49031 .81417 m .49015 .81426 L .49002 .81447 L F
.882 .822 .784 r
.49015 .81426 m .49001 .81423 L .49011 .81432 L F
.49 .81422 m .49 .81422 L .49011 .81432 L F
.703 .571 .703 r
.49031 .81417 m .49002 .81447 L .48903 .81263 L F
.246 .417 .835 r
.49052 .81405 m .49015 .81426 L .4909 .81441 L F
.838 .446 .305 r
.48935 .8137 m .48919 .81334 L .4893 .8134 L F
.882 .822 .784 r
.48921 .81346 m .48918 .81348 L .49 .81422 L F
.838 .446 .305 r
.48918 .81348 m .48919 .81334 L .48935 .8137 L F
.882 .822 .784 r
.48987 .81431 m .48798 .81424 L .48999 .81446 L F
.48987 .81431 m .48999 .81446 L .49002 .81447 L F
.48921 .81346 m .49 .81422 L .49 .81422 L F
.48918 .81348 m .48987 .81431 L .49011 .81432 L F
.838 .446 .305 r
.48918 .81348 m .48895 .81321 L .48919 .81334 L F
.648 .41 .545 r
.48825 .81358 m .48752 .81597 L .48496 .8153 L F
.764 .783 .868 r
.48798 .81424 m .4894 .81346 L .48586 .812 L F
.459 .536 .848 r
.48798 .81424 m .48997 .81422 L .48903 .81263 L F
.643 .757 .932 r
.29256 .63059 m .28897 .62983 L .29108 .62926 L F
.513 .706 .958 r
.29322 .62879 m .29256 .63059 L .29108 .62926 L F
.29322 .62879 m .29457 .63035 L .29256 .63059 L F
.429 .755 .995 r
.31893 .58722 m .31843 .58844 L .31693 .58751 L F
.31893 .58722 m .32058 .58827 L .31843 .58844 L F
.631 .665 .864 r
.25441 .63371 m .25575 .63604 L .25797 .63548 L F
.361 .097 .371 r
.2554 .63839 m .25797 .63548 L .25575 .63604 L F
.616 .729 .927 r
.6932 .47483 m .69204 .47755 L .69077 .47528 L F
.6932 .47483 m .6945 .47691 L .69204 .47755 L F
.619 .933 .702 r
.53845 .79278 m .5412 .7905 L .53884 .79208 L F
.042 0 0 r
.53884 .79208 m .5412 .7905 L .54321 .7899 L F
0 0 0 r
.54321 .7899 m .5412 .7905 L .5401 .79107 L F
0 .113 .587 r
.59374 .6976 m .59282 .69678 L .59027 .69474 L F
.992 .876 .602 r
.59341 .69446 m .59282 .69678 L .59374 .6976 L F
.513 .189 .355 r
.61563 .53115 m .61248 .53374 L .61327 .53144 L F
.821 .598 .6 r
.63146 .50902 m .62805 .50869 L .62809 .50634 L F
.798 .755 .814 r
.63146 .50902 m .62953 .51026 L .62805 .50869 L F
.665 .543 .706 r
.63488 .50967 m .63267 .51245 L .63146 .50902 L F
.57 .481 .715 r
.24998 .65015 m .2521 .65026 L .25053 .64904 L F
.308 .433 .826 r
.74128 .59306 m .7424 .59176 L .73953 .59021 L F
.74128 .59306 m .74316 .59354 L .7424 .59176 L F
.49 .297 .545 r
.50524 .78988 m .50303 .79036 L .50524 .78747 L F
.44 .167 .402 r
.50266 .79247 m .50303 .79036 L .50524 .78988 L F
.531 .525 .793 r
.38921 .69748 m .39032 .69411 L .38853 .69511 L F
.38921 .69748 m .39121 .69711 L .39032 .69411 L F
.558 .553 .805 r
.38921 .69748 m .39253 .70025 L .39121 .69711 L F
.86 .599 .543 r
.51811 .79919 m .51569 .79581 L .51719 .79803 L F
0 .236 .752 r
.51719 .79803 m .51811 .79919 L .51569 .79581 L F
.511 0 0 r
.48792 .69521 m .48652 .69618 L .48444 .6952 L F
.575 .127 .15 r
.48985 .69591 m .48652 .69618 L .48792 .69521 L F
.637 .376 .507 r
.51918 .78745 m .51674 .78953 L .51696 .78785 L F
.452 .322 .613 r
.71353 .51352 m .71537 .51412 L .71318 .51338 L F
.891 .896 .479 r
.71353 .51352 m .71278 .51582 L .71085 .51183 L F
.452 .322 .613 r
.71353 .51352 m .71318 .51338 L .71238 .51311 L F
.891 .896 .479 r
.71353 .51352 m .71446 .51235 L .71383 .51365 L F
.71353 .51352 m .71383 .51365 L .71278 .51582 L F
.582 .927 .735 r
.71719 .5103 m .71446 .51235 L .71589 .5109 L F
0 0 0 r
.71589 .5109 m .71446 .51235 L .71353 .51352 L F
.358 0 .045 r
.41153 .65317 m .4126 .65446 L .41316 .65371 L F
.41153 .65317 m .41024 .65487 L .4126 .65446 L F
.326 0 0 r
.41153 .65317 m .41316 .65371 L .41379 .65289 L F
.315 .233 .602 r
.55519 .75533 m .5541 .75679 L .55319 .75369 L F
.149 0 0 r
.33048 .64365 m .32904 .64507 L .32685 .64577 L F
.173 0 0 r
.3311 .6445 m .33048 .64365 L .33244 .64318 L F
.3311 .6445 m .32904 .64507 L .33048 .64365 L F
.982 .911 .626 r
.66617 .49674 m .66669 .49858 L .66736 .49565 L F
.774 .513 0 r
.66617 .49674 m .66697 .50035 L .66669 .49858 L F
.481 0 0 r
.2937 .6497 m .29251 .65063 L .29101 .65051 L F
0 0 0 r
.29641 .64891 m .29426 .64968 L .29552 .64889 L F
.878 .989 .728 r
.294 .64981 m .29394 .65004 L .29609 .64879 L F
0 0 0 r
.29641 .64891 m .2942 .64972 L .29426 .64968 L F
.878 .989 .728 r
.29609 .64879 m .29503 .64941 L .29641 .64891 L F
.29503 .64941 m .29394 .65004 L .29641 .64891 L F
0 0 0 r
.29552 .64889 m .29426 .64968 L .2937 .6497 L F
.29426 .64968 m .29419 .64972 L .2937 .6497 L F
.878 .989 .728 r
.29443 .64818 m .294 .64981 L .29609 .64879 L F
0 0 0 r
.29426 .64968 m .2942 .64972 L .29419 .64972 L F
.655 .103 0 r
.29394 .65004 m .29375 .64996 L .29251 .65063 L F
.59 .768 .964 r
.29399 .64971 m .29251 .65063 L .2937 .6497 L F
.29375 .64996 m .29251 .65063 L .29399 .64971 L F
.655 .103 0 r
.29375 .64996 m .29081 .64877 L .29251 .65063 L F
.29375 .64996 m .29299 .65026 L .29081 .64877 L F
.59 .768 .964 r
.2942 .64972 m .29251 .65063 L .2942 .64972 L F
.655 .103 0 r
.29361 .65012 m .29299 .65026 L .29375 .64996 L F
.29375 .64996 m .29375 .64996 L .29375 .64996 L F
.59 .768 .964 r
.29375 .64996 m .29394 .65004 L .29251 .65063 L F
.655 .103 0 r
.29361 .65012 m .29375 .64996 L .29375 .64996 L F
.878 .989 .728 r
.294 .64983 m .29399 .64984 L .29394 .65004 L F
.59 .768 .964 r
.29399 .64984 m .29394 .65004 L .29375 .64996 L F
.655 .103 0 r
.29394 .65004 m .29361 .65012 L .29375 .64996 L F
.878 .989 .728 r
.29399 .64984 m .29361 .65012 L .29394 .65004 L F
.59 .768 .964 r
.2942 .64972 m .29394 .65004 L .29399 .64984 L F
.878 .989 .728 r
.29443 .64818 m .29299 .65026 L .29361 .65012 L F
.59 .768 .964 r
.29415 .64972 m .29375 .64996 L .29399 .64971 L F
.294 .64983 m .29375 .64996 L .29415 .64972 L F
.878 .989 .728 r
.29443 .64818 m .29361 .65012 L .294 .64983 L F
.59 .768 .964 r
.2942 .64972 m .294 .64983 L .29415 .64972 L F
.681 .646 .808 r
.75499 .60481 m .75596 .60818 L .75833 .60736 L F
.62 .715 .914 r
.30182 .63278 m .29864 .63192 L .30034 .63147 L F
.535 .71 .952 r
.30264 .63097 m .30182 .63278 L .30034 .63147 L F
.30264 .63097 m .30389 .63245 L .30182 .63278 L F
.446 .343 .645 r
.52386 .69049 m .52176 .68927 L .52409 .68823 L F
.52386 .69049 m .52198 .69158 L .52176 .68927 L F
.647 .715 .898 r
.37888 .69634 m .37736 .69898 L .37702 .69676 L F
.647 .717 .899 r
.37702 .69676 m .37888 .69634 L .37655 .69466 L F
.462 .307 .584 r
.37702 .69676 m .37781 .69817 L .37655 .69466 L F
.374 .659 .968 r
.37736 .69898 m .38173 .69944 L .38077 .70051 L F
.625 .801 .369 r
.37888 .69634 m .37747 .69879 L .37978 .69483 L F
.37747 .69879 m .37736 .69898 L .37745 .69883 L F
.37747 .69879 m .37745 .69883 L .37978 .69483 L F
.37888 .69634 m .37736 .69898 L .37978 .69483 L F
.151 0 0 r
.37843 .69928 m .38173 .69944 L .37736 .69898 L F
.37843 .69928 m .37736 .69898 L .37888 .69634 L F
.462 .307 .584 r
.37781 .69817 m .37843 .69928 L .37791 .69799 L F
.37781 .69817 m .37791 .69799 L .37655 .69466 L F
.327 0 .033 r
.75791 .58185 m .7605 .58124 L .76114 .57956 L F
0 0 .439 r
.76114 .57956 m .76276 .57896 L .76244 .57576 L F
0 0 0 r
.76114 .57956 m .7605 .58124 L .76276 .57896 L F
0 .349 .782 r
.49107 .69297 m .49035 .69318 L .48892 .69238 L F
.601 .765 .958 r
.48403 .65132 m .48743 .65209 L .48676 .65072 L F
.742 .805 .903 r
.48676 .65072 m .48743 .65209 L .48962 .65023 L F
.444 .82 .992 r
.68396 .5371 m .68478 .53776 L .68721 .5373 L F
.488 .477 .771 r
.7099 .4889 m .71083 .48581 L .70913 .4866 L F
.7099 .4889 m .71166 .48995 L .71083 .48581 L F
.661 .398 .511 r
.58929 .59679 m .58906 .59893 L .58675 .59883 L F
.567 .346 .54 r
.58929 .59679 m .59151 .59877 L .58906 .59893 L F
.58929 .59679 m .59209 .59624 L .59151 .59877 L F
.416 .641 .949 r
.70718 .48403 m .70398 .48516 L .70509 .48517 L F
.862 .653 .618 r
.70588 .48273 m .70749 .48394 L .70713 .48033 L F
.70749 .48394 m .70752 .48397 L .70751 .48394 L F
.70749 .48394 m .70751 .48394 L .70713 .48033 L F
.826 .868 .876 r
.70509 .48517 m .70818 .4844 L .70785 .4839 L F
.862 .653 .618 r
.70752 .48397 m .70788 .48424 L .70782 .48391 L F
.70752 .48397 m .70782 .48391 L .70713 .48033 L F
.826 .868 .876 r
.70752 .48397 m .70785 .4839 L .70774 .48373 L F
.416 .641 .949 r
.70774 .48373 m .70788 .48424 L .70752 .48397 L F
.70774 .48373 m .70752 .48397 L .70588 .48273 L F
.826 .868 .876 r
.70718 .48403 m .70752 .48397 L .70774 .48373 L F
.416 .641 .949 r
.70774 .48373 m .70624 .4843 L .70718 .48403 L F
.70624 .4843 m .70398 .48516 L .70718 .48403 L F
.826 .868 .876 r
.70509 .48517 m .70785 .4839 L .70718 .48403 L F
.546 .445 .692 r
.70713 .48033 m .70781 .48387 L .7097 .48252 L F
.70781 .48387 m .70788 .48424 L .7081 .48404 L F
.70781 .48387 m .7081 .48404 L .7097 .48252 L F
.995 .755 .438 r
.70967 .48485 m .7097 .48252 L .7081 .48404 L F
0 .321 .751 r
.70818 .4844 m .70926 .48473 L .7081 .48404 L F
.70818 .4844 m .7081 .48404 L .70787 .48392 L F
.70926 .48473 m .70967 .48485 L .70785 .48389 L F
.995 .755 .438 r
.70967 .48485 m .7081 .48404 L .70788 .48424 L F
0 .321 .751 r
.70787 .48392 m .7081 .48404 L .70785 .48389 L F
.70785 .48389 m .70967 .48485 L .70774 .48373 L F
.70818 .4844 m .71083 .48581 L .70967 .48485 L F
.86 .691 .671 r
.76603 .60593 m .76806 .60775 L .76633 .60452 L F
.774 .707 .788 r
.76415 .60741 m .76806 .60775 L .76603 .60593 L F
.86 .691 .671 r
.76603 .60593 m .76806 .60775 L .76633 .60452 L F
.119 .381 .839 r
.76806 .60775 m .769 .60693 L .76603 .60593 L F
.76806 .60775 m .76997 .60891 L .769 .60693 L F
.144 .444 .878 r
.77241 .60678 m .76949 .60546 L .76843 .60388 L F
.756 .77 .864 r
.77119 .60612 m .77241 .60678 L .77134 .60607 L F
.346 0 0 r
.77353 .60739 m .76949 .60546 L .77241 .60678 L F
.756 .77 .864 r
.769 .60693 m .77241 .60678 L .77119 .60612 L F
.346 0 0 r
.77419 .60771 m .77353 .60739 L .77241 .60678 L F
.429 .378 .7 r
.51943 .66572 m .51782 .66947 L .51715 .66777 L F
.51943 .66572 m .51975 .66765 L .51876 .66728 L F
0 .429 .824 r
.51934 .66714 m .51994 .66878 L .51943 .66572 L F
.51934 .66714 m .52078 .66778 L .52138 .66825 L F
.52081 .66804 m .52138 .66825 L .52213 .66886 L F
.51934 .66714 m .52138 .66825 L .52081 .66804 L F
.429 .378 .7 r
.51876 .66728 m .51994 .66878 L .51782 .66947 L F
.51975 .66765 m .51994 .66878 L .51876 .66728 L F
.143 .038 .466 r
.51955 .67065 m .51779 .67228 L .5178 .67084 L F
.51861 .67001 m .5178 .67084 L .51782 .66947 L F
.51955 .67065 m .5178 .67084 L .51861 .67001 L F
0 .429 .824 r
.51934 .66714 m .52213 .66886 L .51994 .66878 L F
.172 .334 .786 r
.51994 .66878 m .52078 .66778 L .52054 .66801 L F
.547 .701 .941 r
.51639 .67064 m .51775 .67064 L .51782 .66947 L F
.51775 .67064 m .51955 .67065 L .51861 .67001 L F
.51775 .67064 m .51861 .67001 L .51782 .66947 L F
.51639 .67064 m .51994 .66878 L .51832 .67005 L F
.172 .334 .786 r
.51934 .66925 m .52054 .66801 L .51832 .67005 L F
.51994 .66878 m .52054 .66801 L .51934 .66925 L F
.547 .701 .941 r
.51639 .67064 m .51782 .66947 L .51994 .66878 L F
.239 .422 .842 r
.41582 .69232 m .41426 .69195 L .41277 .68915 L F
.317 .337 .724 r
.41582 .69232 m .41644 .69387 L .41426 .69195 L F
.518 .434 .7 r
.34319 .60758 m .34489 .60469 L .34258 .60537 L F
.34319 .60758 m .34517 .60701 L .34489 .60469 L F
.543 .462 .714 r
.34319 .60758 m .34577 .60995 L .34517 .60701 L F
.34319 .60758 m .34371 .61053 L .34577 .60995 L F
.789 .785 .85 r
.68387 .53223 m .6802 .532 L .68264 .53106 L F
.446 .456 .775 r
.57439 .70156 m .57466 .7034 L .57415 .70296 L F
.756 .456 .475 r
.57429 .70524 m .57415 .70296 L .57466 .7034 L F
.57429 .70524 m .57082 .70505 L .57415 .70296 L F
.465 .521 .831 r
.74461 .59611 m .74556 .5929 L .74316 .59354 L F
.74461 .59611 m .74663 .59594 L .74556 .5929 L F
.608 .705 .913 r
.47077 .64994 m .47295 .65286 L .47456 .65148 L F
.689 .919 .971 r
.47456 .65148 m .47295 .65286 L .47333 .65272 L F
.647 .512 .684 r
.47333 .65272 m .47356 .65584 L .47564 .65483 L F
.733 .594 .701 r
.56023 .59653 m .562 .60125 L .558 .59932 L F
.676 .565 .722 r
.56395 .59938 m .562 .60125 L .56023 .59653 L F
.656 .601 .781 r
.56342 .60139 m .562 .60125 L .56395 .59938 L F
.949 .831 .693 r
.52782 .78174 m .52946 .77891 L .52758 .77765 L F
.796 .589 .621 r
.52782 .78174 m .52975 .78244 L .52946 .77891 L F
.682 .406 .497 r
.53282 .78118 m .52946 .77891 L .52975 .78244 L F
.53282 .78118 m .53279 .77897 L .52946 .77891 L F
.472 .249 .494 r
.28854 .61559 m .28605 .61841 L .28646 .61607 L F
.951 .7 .523 r
.56905 .75819 m .57071 .75743 L .56982 .75564 L F
.998 .816 .467 r
.56907 .76157 m .57071 .75743 L .56905 .75819 L F
.999 .828 .502 r
.56891 .76142 m .56981 .76443 L .57024 .76199 L F
.56891 .76142 m .57024 .76199 L .56907 .76157 L F
.998 .816 .467 r
.56907 .76157 m .57024 .76199 L .57071 .75743 L F
.533 .392 .634 r
.38474 .66413 m .38677 .66367 L .38672 .66058 L F
.457 .308 .59 r
.38493 .66657 m .38677 .66367 L .38474 .66413 L F
.933 .898 .498 r
.57027 .7648 m .56908 .76664 L .56921 .76807 L F
.957 .828 .396 r
.57024 .76199 m .56981 .76443 L .57027 .7648 L F
.953 .892 .501 r
.57027 .7648 m .56981 .76443 L .56908 .76664 L F
.453 .877 .923 r
.46067 .64184 m .46408 .64121 L .46183 .64196 L F
.581 .564 .799 r
.3781 .59887 m .37707 .60235 L .376 .59929 L F
.3781 .59887 m .37921 .60179 L .37707 .60235 L F
.555 .432 .667 r
.37921 .60179 m .37733 .60478 L .37707 .60235 L F
.511 .799 .998 r
.71088 .5 m .71198 .50094 L .70853 .50043 L F
0 0 .406 r
.50166 .79458 m .50063 .79314 L .50266 .79247 L F
.50166 .79458 m .50103 .79556 L .50063 .79314 L F
.623 .194 .206 r
.30369 .64776 m .30014 .64777 L .30162 .64845 L F
.30369 .64776 m .3045 .64995 L .30014 .64777 L F
.412 .812 .983 r
.30369 .64776 m .30565 .64837 L .30554 .64811 L F
.30369 .64776 m .30554 .64811 L .30529 .64804 L F
0 0 .356 r
.30441 .64757 m .30369 .64776 L .30546 .64807 L F
.705 .3 .276 r
.30441 .64757 m .30577 .64806 L .30585 .64806 L F
.30558 .64766 m .30585 .64806 L .30857 .64787 L F
.30441 .64757 m .30585 .64806 L .30558 .64766 L F
.24 .687 .955 r
.30565 .64837 m .30857 .64787 L .30585 .64806 L F
.30565 .64837 m .30585 .64806 L .30553 .6481 L F
.486 .251 .482 r
.30589 .64811 m .30579 .64823 L .3055 .64809 L F
.30577 .64806 m .3055 .64809 L .30441 .64757 L F
.24 .687 .955 r
.30553 .6481 m .30585 .64806 L .30577 .64806 L F
.30553 .6481 m .30577 .64806 L .30553 .64809 L F
.486 .251 .482 r
.30589 .64811 m .3055 .64809 L .30577 .64806 L F
.24 .687 .955 r
.30553 .64809 m .30577 .64806 L .30553 .64808 L F
.30565 .64837 m .31009 .64861 L .30857 .64787 L F
.486 .251 .482 r
.30593 .64805 m .30643 .64892 L .30589 .64811 L F
.30629 .64757 m .30634 .648 L .30593 .64805 L F
.492 .748 .986 r
.30565 .64837 m .31138 .6491 L .31009 .64861 L F
.31138 .6491 m .31151 .64912 L .31009 .64861 L F
.777 .287 .056 r
.31071 .64953 m .30894 .64816 L .31009 .64861 L F
.30894 .64816 m .30857 .64787 L .31009 .64861 L F
.486 .251 .482 r
.30634 .648 m .30643 .64892 L .30593 .64805 L F
.30589 .64811 m .30651 .64961 L .30439 .65008 L F
.30643 .64892 m .30651 .64961 L .30589 .64811 L F
.30629 .64757 m .30589 .64811 L .30441 .64757 L F
.705 .3 .276 r
.30441 .64757 m .30553 .64808 L .30577 .64806 L F
0 0 .356 r
.30441 .64757 m .30546 .64807 L .30553 .64808 L F
.412 .812 .983 r
.30529 .64804 m .30554 .64811 L .30553 .64809 L F
.30546 .64807 m .30553 .64809 L .30553 .64808 L F
.30529 .64804 m .30553 .64809 L .30546 .64807 L F
.448 0 0 r
.30215 .64883 m .3045 .64995 L .30364 .64961 L F
.30204 .64872 m .3045 .64995 L .30215 .64883 L F
.30014 .64777 m .30364 .64961 L .30217 .64896 L F
0 0 .356 r
.30441 .64757 m .3045 .64995 L .30381 .64807 L F
.30441 .64757 m .30379 .64804 L .30369 .64776 L F
.696 .519 .644 r
.30241 .64907 m .30439 .65008 L .302 .64937 L F
.448 0 0 r
.30217 .64896 m .30364 .64961 L .3036 .64959 L F
.30217 .64896 m .3036 .64959 L .3022 .64898 L F
.775 .611 .676 r
.30428 .64791 m .3045 .64995 L .30442 .64781 L F
.696 .519 .644 r
.30441 .64757 m .3036 .64959 L .30241 .64907 L F
.30439 .64994 m .30439 .65008 L .30241 .64907 L F
.448 0 0 r
.3022 .64898 m .3036 .64959 L .30249 .64915 L F
.775 .611 .676 r
.30249 .64915 m .3036 .64959 L .30428 .64791 L F
.3036 .64959 m .3045 .64995 L .30428 .64791 L F
.696 .519 .644 r
.30441 .64757 m .30439 .64994 L .3036 .64959 L F
.30441 .64757 m .30241 .64907 L .30249 .64915 L F
.30241 .64907 m .302 .64937 L .30249 .64915 L F
.448 0 0 r
.30014 .64777 m .30204 .64872 L .30215 .64883 L F
.486 .251 .482 r
.30579 .64823 m .30447 .64997 L .30441 .6478 L F
.30447 .64997 m .30439 .65008 L .30439 .64994 L F
.30447 .64997 m .30439 .64994 L .30441 .6478 L F
.30546 .64807 m .30441 .6478 L .30441 .64757 L F
.30579 .64823 m .30441 .6478 L .30546 .64807 L F
.775 .611 .676 r
.3042 .64775 m .30442 .64781 L .30441 .64757 L F
.30249 .64915 m .30442 .64781 L .3042 .64775 L F
.773 .297 0 r
.56539 .74762 m .56759 .75021 L .56658 .74834 L F
.721 .589 .707 r
.5446 .62063 m .54208 .62176 L .54441 .61885 L F
.903 .722 .648 r
.5446 .62063 m .54279 .62415 L .54208 .62176 L F
.5446 .62063 m .54418 .62508 L .54279 .62415 L F
.577 .423 .636 r
.54735 .61864 m .5446 .62063 L .54441 .61885 L F
.54735 .61864 m .54734 .61974 L .5446 .62063 L F
.235 .134 .53 r
.54653 .62254 m .5446 .62063 L .54734 .61974 L F
.54653 .62254 m .54418 .62508 L .5446 .62063 L F
.386 .49 .842 r
.50654 .64956 m .50801 .65267 L .50947 .65132 L F
.365 .454 .819 r
.50801 .65267 m .51096 .65501 L .50947 .65132 L F
.149 .309 .771 r
.38173 .69944 m .38301 .70243 L .38077 .70051 L F
.383 .16 .447 r
.34348 .61287 m .34577 .60995 L .34371 .61053 L F
.77 .406 0 r
.68648 .48292 m .68626 .48291 L .68562 .48149 L F
.497 .904 .908 r
.6902 .48193 m .68626 .48291 L .68648 .48292 L F
.56 .583 .834 r
.25042 .6662 m .25275 .66595 L .25067 .66672 L F
.323 .02 .286 r
.25067 .66672 m .25275 .66595 L .25032 .66762 L F
.513 .549 .83 r
.74808 .59891 m .74903 .59544 L .74663 .59594 L F
.74808 .59891 m .75021 .59861 L .74903 .59544 L F
0 0 0 r
.54572 .79997 m .54444 .80048 L .5467 .79764 L F
.273 .762 .912 r
.54476 .80005 m .54444 .80048 L .54572 .79997 L F
0 0 0 r
.54409 .80094 m .54473 .79978 L .54444 .80048 L F
.273 .762 .912 r
.54311 .80018 m .54444 .80048 L .54476 .80005 L F
0 0 0 r
.54346 .8021 m .54409 .80094 L .54444 .80048 L F
.449 .758 .995 r
.31125 .58601 m .30916 .58636 L .30745 .58529 L F
.749 .714 .819 r
.54319 .61578 m .54441 .61885 L .54081 .61845 L F
.768 .662 .745 r
.54441 .61885 m .54208 .62176 L .54081 .61845 L F
.703 .691 .835 r
.54662 .61646 m .54441 .61885 L .54319 .61578 L F
.636 .58 .775 r
.54662 .61646 m .54735 .61864 L .54441 .61885 L F
.646 .637 .827 r
.51811 .79919 m .52202 .80081 L .5215 .79812 L F
0 0 0 r
.45281 .65785 m .44991 .6598 L .45114 .65884 L F
.679 .74 .897 r
.76997 .60891 m .77093 .61066 L .77193 .60806 L F
.588 .638 .868 r
.77093 .61066 m .77343 .6102 L .77193 .60806 L F
.558 .38 .595 r
.44483 .66307 m .44254 .66109 L .4446 .6607 L F
.44483 .66307 m .44234 .66355 L .44254 .66109 L F
.351 0 .105 r
.42424 .6694 m .42296 .67128 L .42058 .67168 L F
.714 .334 .327 r
.4252 .67108 m .42424 .6694 L .42676 .66942 L F
.4252 .67108 m .42296 .67128 L .42424 .6694 L F
.97 .661 .372 r
.6594 .50565 m .6583 .50501 L .65776 .50246 L F
.962 .827 .664 r
.6594 .50565 m .65729 .50811 L .6583 .50501 L F
.6594 .50565 m .65846 .50923 L .65729 .50811 L F
.336 0 0 r
.42341 .70782 m .42257 .70876 L .42017 .7091 L F
.292 0 0 r
.42563 .70736 m .42257 .70876 L .42341 .70782 L F
.728 .297 0 r
.66807 .48129 m .66829 .48224 L .6658 .48228 L F
.66807 .48129 m .66929 .48357 L .66829 .48224 L F
.545 .43 .673 r
.49191 .77898 m .49393 .77852 L .49353 .77598 L F
.517 .366 .615 r
.49191 .77898 m .49409 .78108 L .49393 .77852 L F
.49191 .77898 m .49165 .78238 L .49409 .78108 L F
.714 .237 .114 r
.47379 .68867 m .47743 .68967 L .47568 .68857 L F
.925 .907 .785 r
.67043 .53406 m .66923 .53396 L .67097 .53112 L F
.737 .409 .426 r
.67043 .53406 m .66878 .53629 L .66923 .53396 L F
.67043 .53406 m .67224 .53596 L .66878 .53629 L F
.703 .422 .497 r
.53282 .78118 m .53523 .78149 L .53279 .77897 L F
.49 .468 .76 r
.38306 .68352 m .38585 .68645 L .38523 .68309 L F
.507 .509 .793 r
.54939 .77019 m .54783 .76774 L .54977 .76728 L F
.829 .813 .835 r
.55284 .76619 m .54939 .77019 L .54977 .76728 L F
.493 .568 .86 r
.69623 .48326 m .69651 .48489 L .69804 .48272 L F
.56 .662 .905 r
.69651 .48489 m .699 .48464 L .69804 .48272 L F
.413 .134 .377 r
.55752 .70588 m .55964 .70533 L .56 .70324 L F
.362 .055 .304 r
.55964 .70533 m .56189 .70325 L .56 .70324 L F
.237 .618 .956 r
.7671 .57952 m .76869 .57896 L .7661 .57949 L F
.7671 .57952 m .76952 .57991 L .76869 .57896 L F
.198 0 0 r
.5556 .78602 m .55474 .78518 L .55378 .78706 L F
0 0 .181 r
.74006 .58841 m .73953 .59021 L .74136 .5868 L F
.845 .744 .751 r
.59083 .56704 m .59413 .56546 L .59295 .56454 L F
.59083 .56704 m .59227 .56883 L .59413 .56546 L F
.622 .938 .716 r
.59605 .56224 m .59295 .56454 L .59413 .56546 L F
.398 0 0 r
.53394 .7705 m .53265 .77095 L .53032 .77062 L F
.681 .137 0 r
.53589 .77288 m .53265 .77095 L .53394 .7705 L F
.788 .289 0 r
.76575 .60046 m .76823 .60239 L .76671 .60072 L F
.331 .027 .29 r
.49938 .76207 m .50142 .76153 L .50107 .76005 L F
.988 .877 .628 r
.73126 .50015 m .73041 .50304 L .7312 .50388 L F
.77 .544 .592 r
.73041 .50304 m .73449 .50539 L .7312 .50388 L F
.436 .667 .959 r
.69281 .48263 m .69503 .48157 L .69164 .48164 L F
.69281 .48263 m .69623 .48326 L .69503 .48157 L F
0 0 0 r
.56873 .70559 m .56609 .70779 L .56701 .70662 L F
.502 0 0 r
.53849 .78644 m .53968 .78559 L .54164 .78662 L F
.457 .542 .855 r
.7516 .60162 m .75253 .59867 L .75021 .59861 L F
.7516 .60162 m .75366 .6014 L .75253 .59867 L F
.585 .547 .779 r
.75181 .60374 m .75366 .6014 L .7516 .60162 L F
.712 .548 .665 r
.5422 .78117 m .54571 .78208 L .5444 .7789 L F
.414 .502 .84 r
.54301 .77582 m .5444 .7789 L .54598 .77882 L F
.829 .756 .783 r
.54571 .78208 m .54598 .77882 L .5444 .7789 L F
.542 .573 .835 r
.48049 .79711 m .47872 .80029 L .47861 .79824 L F
.48049 .79711 m .481 .80034 L .47872 .80029 L F
.992 .87 .533 r
.4718 .63739 m .47084 .63744 L .47211 .6358 L F
.991 .766 .501 r
.50647 .79309 m .50639 .79563 L .50517 .79489 L F
0 0 0 r
.47211 .6358 m .47246 .63611 L .47478 .63555 L F
.47211 .6358 m .47084 .63744 L .47246 .63611 L F
1 .827 .524 r
.50559 .79244 m .50647 .79309 L .50517 .79489 L F
.761 .409 .388 r
.50647 .79309 m .50993 .79558 L .50639 .79563 L F
.516 .516 .794 r
.67163 .52965 m .67201 .52471 L .66974 .52546 L F
.67163 .52965 m .67327 .5288 L .67201 .52471 L F
.142 0 .13 r
.67163 .52965 m .67097 .53112 L .67327 .5288 L F
0 0 .242 r
.47055 .79837 m .47106 .80038 L .47116 .79826 L F
.47055 .79837 m .47042 .80118 L .47106 .80038 L F
.471 .43 .73 r
.41306 .67714 m .41048 .67514 L .41286 .67475 L F
.779 .628 .694 r
.55872 .59323 m .56023 .59653 L .55676 .59614 L F
.774 .657 .733 r
.56023 .59653 m .558 .59932 L .55676 .59614 L F
.51 .152 .296 r
.56716 .6996 m .56955 .69936 L .57003 .69725 L F
.42 .205 .479 r
.57003 .69725 m .57195 .69749 L .57168 .69519 L F
.509 .199 .377 r
.56955 .69936 m .57195 .69749 L .57003 .69725 L F
.633 .149 .084 r
.48215 .69454 m .48116 .69585 L .47867 .69421 L F
.677 .239 .201 r
.48444 .6952 m .48116 .69585 L .48215 .69454 L F
0 0 .4 r
.51345 .79227 m .51255 .79301 L .5128 .79019 L F
.056 0 0 r
.63914 .47814 m .64145 .47829 L .64259 .47835 L F
.714 .424 .485 r
.55284 .76619 m .54977 .76728 L .54981 .76512 L F
.873 .841 .811 r
.64203 .51976 m .6454 .51794 L .64189 .51759 L F
.15 .059 .489 r
.62658 .57025 m .62667 .57263 L .62491 .57349 L F
0 0 0 r
.62667 .57263 m .62422 .57534 L .62491 .57349 L F
.9 .865 .796 r
.66244 .49405 m .66531 .49328 L .66525 .49137 L F
.66244 .49405 m .66365 .49537 L .66531 .49328 L F
.499 .257 .479 r
.66531 .49328 m .66365 .49537 L .66575 .49475 L F
.287 .648 .968 r
.58644 .70162 m .58799 .70358 L .58512 .70252 L F
.76 .802 .887 r
.58736 .69934 m .58799 .70358 L .58644 .70162 L F
.58736 .69934 m .59054 .69969 L .58799 .70358 L F
.703 .697 .842 r
.59054 .69969 m .58965 .70329 L .58799 .70358 L F
.456 .115 .297 r
.67106 .51538 m .66856 .51674 L .67078 .51702 L F
.364 0 .093 r
.67256 .51589 m .67106 .51538 L .67078 .51702 L F
.67256 .51589 m .67339 .51505 L .67106 .51538 L F
.651 .475 .633 r
.49496 .76768 m .49818 .76955 L .49816 .76777 L F
.644 .377 .499 r
.49818 .76955 m .5003 .77015 L .49816 .76777 L F
.607 .181 .207 r
.52484 .78449 m .52839 .78438 L .52818 .78452 L F
.74 .415 .432 r
.52839 .78438 m .52699 .78662 L .52818 .78452 L F
.52839 .78438 m .5305 .78695 L .52699 .78662 L F
.487 .08 .194 r
.59068 .72449 m .58725 .7258 L .58883 .72637 L F
.472 .24 .481 r
.57504 .692 m .5772 .69153 L .57815 .68888 L F
.496 .322 .575 r
.57504 .692 m .57717 .69367 L .5772 .69153 L F
.57504 .692 m .57509 .69436 L .57717 .69367 L F
.74 .784 .889 r
.7225 .48863 m .72092 .4895 L .71987 .48794 L F
.581 .34 .515 r
.53511 .75082 m .53461 .753 L .53236 .75094 L F
.53511 .75082 m .53461 .753 L .53236 .75094 L F
.509 .318 .557 r
.35535 .6245 m .35524 .6267 L .35316 .62714 L F
.39 .066 .29 r
.35434 .6289 m .35316 .62714 L .35524 .6267 L F
.35434 .6289 m .3523 .62941 L .35316 .62714 L F
.276 0 .107 r
.51868 .69861 m .51756 .69723 L .51937 .69624 L F
.51868 .69861 m .51657 .69927 L .51756 .69723 L F
.713 .773 .899 r
.46974 .80352 m .47134 .80509 L .47296 .80393 L F
.47296 .80393 m .47134 .80509 L .46974 .80352 L F
.46974 .80352 m .47134 .80509 L .47296 .80393 L F
.467 .859 .663 r
.69964 .53256 m .6983 .53362 L .70118 .53248 L F
.69964 .53256 m .69775 .53387 L .6983 .53362 L F
.827 .734 .762 r
.5602 .61298 m .55912 .60954 L .56039 .61113 L F
.5602 .61298 m .55698 .61256 L .55912 .60954 L F
.653 .33 .413 r
.5602 .61298 m .55771 .6145 L .55698 .61256 L F
.5602 .61298 m .56025 .61493 L .55771 .6145 L F
.463 .397 .698 r
.56039 .61113 m .56288 .61204 L .5602 .61298 L F
.335 .092 .389 r
.56288 .61204 m .56025 .61493 L .5602 .61298 L F
0 .147 .664 r
.71533 .47575 m .71616 .47553 L .71596 .47409 L F
.554 .595 .85 r
.71596 .47409 m .71616 .47553 L .71593 .47525 L F
0 .275 .72 r
.716 .47422 m .71595 .47432 L .71596 .47409 L F
.71595 .47432 m .71533 .47575 L .71596 .47409 L F
.71591 .47544 m .71533 .47575 L .716 .47422 L F
.554 .595 .85 r
.71596 .47409 m .71593 .47525 L .7126 .47138 L F
.505 .578 .862 r
.7124 .47178 m .71593 .47525 L .71134 .47391 L F
.71371 .47267 m .71593 .47525 L .7124 .47178 L F
.71593 .47525 m .71616 .47553 L .71591 .47544 L F
.71593 .47525 m .71591 .47544 L .71134 .47391 L F
0 .275 .72 r
.71631 .47524 m .71591 .47544 L .716 .47422 L F
.113 .556 .917 r
.71591 .47544 m .71616 .47553 L .71533 .47575 L F
0 .275 .72 r
.7166 .47617 m .71533 .47575 L .71631 .47524 L F
.113 .556 .917 r
.71134 .47391 m .71591 .47544 L .71533 .47575 L F
0 .275 .72 r
.7166 .47617 m .71765 .47708 L .71557 .47588 L F
.7166 .47617 m .71557 .47588 L .71533 .47575 L F
.778 .494 .506 r
.7132 .47594 m .7166 .47617 L .716 .47422 L F
.767 .745 .833 r
.71451 .47582 m .7166 .47617 L .7132 .47594 L F
0 .263 .754 r
.7175 .47642 m .7166 .47617 L .71451 .47582 L F
.71789 .4765 m .71898 .47793 L .71703 .47649 L F
.71789 .4765 m .71703 .47649 L .7166 .47617 L F
.676 .305 .337 r
.71765 .47708 m .71454 .47841 L .7154 .47755 L F
.696 .889 .513 r
.71426 .47931 m .7154 .47755 L .71454 .47841 L F
.676 .305 .337 r
.71765 .47708 m .71693 .47915 L .71454 .47841 L F
.533 .415 .664 r
.7166 .47617 m .71693 .47915 L .71765 .47708 L F
.7166 .47617 m .71898 .47793 L .71693 .47915 L F
.82 .998 .843 r
.71989 .47561 m .71898 .47793 L .71789 .4765 L F
0 0 0 r
.71678 .47804 m .7187 .47651 L .71789 .4765 L F
.7187 .47651 m .71969 .47573 L .71789 .4765 L F
0 .263 .754 r
.71789 .4765 m .7166 .47617 L .7175 .47642 L F
.778 .494 .506 r
.71588 .47414 m .716 .47422 L .71596 .47409 L F
.7132 .47594 m .716 .47422 L .71588 .47414 L F
.505 .578 .862 r
.7126 .47138 m .71371 .47267 L .7124 .47178 L F
.712 .612 .743 r
.63496 .51207 m .63267 .51245 L .63488 .50967 L F
.568 .536 .779 r
.63656 .51549 m .63267 .51245 L .63496 .51207 L F
.68 .569 .723 r
.63721 .50903 m .63496 .51207 L .63488 .50967 L F
.63721 .50903 m .63865 .51229 L .63496 .51207 L F
.66 .505 .663 r
.63869 .51473 m .63496 .51207 L .63865 .51229 L F
.63869 .51473 m .63656 .51549 L .63496 .51207 L F
.628 .858 .986 r
.68721 .5373 m .69052 .53741 L .68951 .5361 L F
.638 .791 .956 r
.68951 .5361 m .69052 .53741 L .69256 .53648 L F
.544 .284 .472 r
.44816 .68871 m .45122 .68874 L .45093 .68633 L F
.826 .49 .42 r
.45093 .68633 m .45122 .68874 L .45446 .68916 L F
.778 .602 .66 r
.47644 .77857 m .48053 .78074 L .48043 .77717 L F
.956 .78 .624 r
.53743 .78893 m .53845 .79278 L .53557 .79261 L F
.736 .36 .34 r
.53557 .79261 m .53845 .79278 L .53745 .79491 L F
.545 .62 .877 r
.53557 .79261 m .53617 .79 L .53743 .78893 L F
.53557 .79261 m .53829 .79316 L .53617 .79 L F
.53829 .79316 m .53869 .79324 L .53843 .7929 L F
.53829 .79316 m .53843 .7929 L .53617 .79 L F
0 0 0 r
.5388 .79215 m .53845 .79278 L .53884 .79208 L F
.53804 .79367 m .53845 .79278 L .53862 .79249 L F
.53829 .79316 m .53862 .79249 L .53881 .79214 L F
.53804 .79367 m .53862 .79249 L .53829 .79316 L F
.641 .364 .483 r
.53745 .79491 m .53869 .79324 L .53829 .79316 L F
.53745 .79491 m .53829 .79316 L .53557 .79261 L F
.566 .628 .873 r
.53617 .79 m .53843 .7929 L .53884 .79208 L F
.53843 .7929 m .53869 .79324 L .53884 .79208 L F
0 0 0 r
.53881 .79214 m .5388 .79215 L .53884 .79208 L F
.53745 .79491 m .53804 .79367 L .53881 .79214 L F
.489 .289 .534 r
.69603 .51151 m .69379 .51188 L .69376 .51436 L F
.234 0 0 r
.693 .51317 m .69379 .51188 L .69603 .51151 L F
.873 .994 .783 r
.56151 .78133 m .56456 .77832 L .56381 .77848 L F
.875 .993 .756 r
.56381 .77848 m .56456 .77832 L .56595 .77634 L F
.763 .606 .684 r
.45122 .68874 m .45406 .69073 L .45446 .68916 L F
.596 .277 .4 r
.45406 .69073 m .45651 .69094 L .45446 .68916 L F
.548 .291 .477 r
.45446 .68916 m .45651 .69094 L .45685 .68888 L F
.83 .734 .758 r
.55413 .74752 m .55521 .74921 L .5571 .74802 L F
.55413 .74752 m .55521 .74921 L .5571 .74802 L F
.844 .695 .697 r
.54081 .61845 m .54208 .62176 L .53928 .62051 L F
.846 .44 .27 r
.54208 .62176 m .54089 .62307 L .53928 .62051 L F
.893 .515 .314 r
.54208 .62176 m .54279 .62415 L .54089 .62307 L F
.526 .322 .547 r
.59523 .70545 m .59629 .70692 L .59276 .70618 L F
.804 .837 .876 r
.24857 .63517 m .25228 .6343 L .25023 .6329 L F
.576 .785 .978 r
.25023 .6329 m .25228 .6343 L .25441 .63371 L F
.748 .616 .712 r
.56131 .60285 m .55569 .60453 L .55778 .60175 L F
.7 .498 .611 r
.5578 .60634 m .55569 .60453 L .56131 .60285 L F
.668 .455 .587 r
.5616 .60436 m .5578 .60634 L .56131 .60285 L F
.574 .543 .782 r
.51828 .6512 m .51688 .65322 L .51575 .64993 L F
.602 .565 .785 r
.51948 .65452 m .51688 .65322 L .51828 .6512 L F
.718 .693 .826 r
.62096 .51703 m .61893 .5178 L .61864 .51714 L F
.099 0 0 r
.38791 .70599 m .38679 .70594 L .38432 .70571 L F
.221 .743 .816 r
.39007 .70557 m .38679 .70594 L .38791 .70599 L F
.678 .632 .796 r
.64768 .51772 m .65116 .51795 L .64967 .51486 L F
.734 .589 .693 r
.63943 .50601 m .6349 .50738 L .63849 .50542 L F
.63943 .50601 m .63721 .50903 L .6349 .50738 L F
.493 .787 .997 r
.49938 .76207 m .50261 .76258 L .50142 .76153 L F
0 0 .495 r
.50261 .76258 m .50353 .76352 L .50142 .76153 L F
.753 .334 .253 r
.50645 .76444 m .50468 .76481 L .50261 .76258 L F
0 0 .495 r
.50261 .76258 m .50468 .76481 L .50353 .76352 L F
.641 .36 .477 r
.31887 .63181 m .3211 .63239 L .32156 .6303 L F
.481 .208 .423 r
.3211 .63239 m .3238 .62987 L .32156 .6303 L F
.851 .408 0 r
.39488 .71611 m .39605 .71759 L .3947 .71652 L F
.593 .62 .848 r
.39488 .71611 m .39826 .71674 L .39605 .71759 L F
.601 .838 .989 r
.39605 .71759 m .39826 .71674 L .3947 .71652 L F
.779 .939 .932 r
.66584 .47904 m .66318 .48108 L .66259 .47989 L F
.642 .712 .898 r
.50659 .63526 m .5043 .63591 L .50341 .63427 L F
.402 .686 .976 r
.56063 .71331 m .56185 .71445 L .55946 .71448 L F
.671 .272 .281 r
.25309 .62837 m .24955 .6292 L .25413 .62863 L F
.413 0 0 r
.25396 .62851 m .25494 .62911 L .25436 .62857 L F
.25309 .62837 m .25395 .62872 L .25396 .62851 L F
.25395 .62872 m .25494 .62911 L .25396 .62851 L F
0 0 0 r
.25413 .62863 m .25394 .62888 L .25444 .63024 L F
0 .256 .648 r
.25271 .63268 m .25107 .63179 L .25023 .6329 L F
.25107 .63179 m .25017 .63131 L .25021 .63234 L F
.25107 .63179 m .25021 .63234 L .25023 .6329 L F
.25107 .63179 m .25105 .63176 L .25017 .63131 L F
.421 .035 .199 r
.25017 .63131 m .25134 .63226 L .25153 .63201 L F
.271 .22 .614 r
.25413 .62863 m .25494 .62911 L .25309 .62837 L F
.619 .829 .981 r
.25271 .63268 m .25441 .63371 L .25662 .63294 L F
.25271 .63268 m .25662 .63294 L .25509 .63207 L F
.773 .382 .313 r
.25509 .63207 m .25336 .63301 L .25223 .63239 L F
.421 .035 .199 r
.25017 .63131 m .25153 .63201 L .2529 .63023 L F
.773 .382 .313 r
.25509 .63207 m .25196 .6318 L .25271 .63268 L F
0 0 0 r
.25388 .62999 m .25171 .63193 L .25384 .63063 L F
.25171 .63193 m .25201 .63177 L .25384 .63063 L F
.421 .035 .199 r
.2532 .62926 m .2529 .63023 L .25413 .62863 L F
.25017 .63131 m .2529 .63023 L .2532 .62926 L F
0 0 0 r
.25394 .62888 m .25232 .63099 L .25388 .62999 L F
0 .256 .648 r
.25271 .63268 m .25154 .63201 L .25107 .63179 L F
0 0 0 r
.25232 .63099 m .25134 .63226 L .25388 .62999 L F
.25394 .62888 m .25384 .63063 L .25444 .63024 L F
.475 .383 .671 r
.25444 .63024 m .25237 .63159 L .25061 .62763 L F
.773 .382 .313 r
.25196 .6318 m .25181 .63179 L .25154 .63201 L F
.25181 .63179 m .2514 .63193 L .25154 .63201 L F
.25196 .6318 m .25154 .63201 L .25271 .63268 L F
0 0 0 r
.25171 .63193 m .25159 .63203 L .25195 .63181 L F
.25196 .6318 m .25195 .63181 L .25201 .63177 L F
.25171 .63193 m .25195 .63181 L .25196 .6318 L F
.773 .382 .313 r
.25241 .63184 m .25223 .63239 L .25176 .63213 L F
.475 .383 .671 r
.25181 .63179 m .25134 .63226 L .25129 .63197 L F
.773 .382 .313 r
.25196 .6318 m .2519 .63189 L .25181 .63179 L F
.475 .383 .671 r
.25237 .63159 m .2519 .63189 L .25181 .63179 L F
0 0 0 r
.25159 .63203 m .25134 .63226 L .25164 .63206 L F
.25159 .63203 m .25164 .63206 L .25384 .63063 L F
.475 .383 .671 r
.2519 .63189 m .25134 .63226 L .25181 .63179 L F
.25237 .63159 m .25129 .63197 L .25061 .62763 L F
.773 .382 .313 r
.25181 .63179 m .25102 .63172 L .2514 .63193 L F
.25181 .63179 m .25176 .63213 L .25102 .63172 L F
.2519 .63189 m .25176 .63213 L .25181 .63179 L F
.25241 .63184 m .25176 .63213 L .25196 .6318 L F
.25509 .63207 m .25223 .63239 L .25241 .63184 L F
.071 .093 .576 r
.25061 .62763 m .25128 .63187 L .25017 .63131 L F
0 .256 .648 r
.25105 .63176 m .25104 .63175 L .25017 .63131 L F
.25154 .63201 m .25102 .63172 L .25107 .63179 L F
.071 .093 .576 r
.25128 .63187 m .25134 .63226 L .25017 .63131 L F
0 .256 .648 r
.25104 .63175 m .25102 .63172 L .25017 .63131 L F
.715 .325 .31 r
.62368 .52634 m .62556 .52813 L .62192 .52725 L F
.727 .239 .082 r
.65405 .50648 m .6532 .50741 L .6541 .50683 L F
.534 .463 .722 r
.63227 .50003 m .62916 .49798 L .63245 .49782 L F
.63227 .50003 m .62989 .50134 L .62916 .49798 L F
.348 .82 .762 r
.44247 .64765 m .44301 .64719 L .44465 .64711 L F
.44247 .64765 m .44077 .64809 L .44301 .64719 L F
.841 .406 .195 r
.59027 .69474 m .58995 .69638 L .58868 .69442 L F
.58995 .69638 m .58956 .69617 L .58868 .69442 L F
.841 .686 .69 r
.58817 .69542 m .58833 .69535 L .58826 .6953 L F
.58809 .69553 m .58824 .69546 L .58817 .69542 L F
.851 .406 .151 r
.58868 .69442 m .58956 .69617 L .58838 .69538 L F
.841 .686 .69 r
.58824 .69546 m .58838 .69538 L .58817 .69542 L F
.58838 .69538 m .5913 .69391 L .58833 .69535 L F
.58838 .69538 m .58833 .69535 L .58817 .69542 L F
.851 .406 .151 r
.58956 .69617 m .58987 .69679 L .58817 .69524 L F
.841 .406 .195 r
.58995 .69638 m .58987 .69679 L .58956 .69617 L F
.218 .344 .779 r
.59027 .69474 m .59282 .69678 L .5913 .69391 L F
.59027 .69474 m .5913 .69391 L .58987 .69679 L F
.797 .574 .6 r
.58987 .69679 m .5913 .69391 L .58838 .69538 L F
.58987 .69679 m .58838 .69538 L .58809 .69553 L F
.851 .406 .151 r
.58827 .69528 m .58838 .69538 L .58826 .6953 L F
.58868 .69442 m .58838 .69538 L .58827 .69528 L F
.841 .686 .69 r
.58809 .69553 m .58826 .6953 L .58807 .69512 L F
.851 .406 .151 r
.58818 .69523 m .58826 .6953 L .58817 .69524 L F
.58868 .69442 m .58826 .6953 L .58818 .69523 L F
.58868 .69442 m .58551 .6959 L .58593 .69421 L F
.08 .281 .766 r
.58798 .69533 m .58796 .69558 L .58809 .69553 L F
.851 .406 .151 r
.58803 .69473 m .58799 .6952 L .58551 .6959 L F
.977 .743 .517 r
.58798 .69533 m .58809 .69553 L .58808 .69526 L F
.851 .406 .151 r
.58825 .69512 m .58796 .69558 L .58761 .69562 L F
.58825 .69512 m .58761 .69562 L .58551 .6959 L F
.08 .281 .766 r
.58661 .69279 m .58796 .69558 L .58798 .69533 L F
.851 .406 .151 r
.58868 .69442 m .58825 .69512 L .58799 .6952 L F
.58868 .69442 m .58799 .6952 L .58803 .69473 L F
.977 .743 .517 r
.58661 .69279 m .58798 .69533 L .58785 .69066 L F
.58798 .69533 m .58808 .69526 L .58785 .69066 L F
.841 .686 .69 r
.58807 .69512 m .59144 .69109 L .58785 .69066 L F
.58826 .6953 m .59144 .69109 L .58807 .69512 L F
.797 .574 .6 r
.58987 .69679 m .58809 .69553 L .58796 .69558 L F
.851 .406 .151 r
.58817 .69524 m .58987 .69679 L .58796 .69558 L F
.841 .686 .69 r
.58826 .6953 m .5913 .69391 L .59144 .69109 L F
.58833 .69535 m .5913 .69391 L .58826 .6953 L F
.703 .477 .578 r
.5969 .58185 m .60022 .57958 L .59698 .57965 L F
.5969 .58185 m .60025 .58193 L .60022 .57958 L F
.53 .306 .519 r
.60244 .58129 m .60022 .57958 L .60025 .58193 L F
.60244 .58129 m .6026 .57912 L .60022 .57958 L F
.192 0 0 r
.2621 .59037 m .26404 .58986 L .26561 .58832 L F
.291 0 0 r
.26561 .58832 m .26687 .58882 L .26771 .58797 L F
.26561 .58832 m .26404 .58986 L .26687 .58882 L F
.855 .919 .873 r
.71329 .48304 m .71399 .48428 L .71647 .48155 L F
.99 .885 .615 r
.71261 .48455 m .71399 .48428 L .71329 .48304 L F
.704 .47 .566 r
.59451 .58188 m .59698 .57965 L .59451 .57947 L F
.59451 .58188 m .5969 .58185 L .59698 .57965 L F
.636 .838 .439 r
.60301 .54647 m .60189 .54831 L .60403 .5451 L F
0 0 0 r
.60602 .54196 m .6053 .54362 L .60403 .5451 L F
.6053 .54362 m .60301 .54647 L .60403 .5451 L F
.263 .164 .55 r
.47158 .77901 m .47316 .78083 L .47312 .77834 L F
.47158 .77901 m .47107 .78384 L .47316 .78083 L F
.916 .786 .703 r
.63971 .53892 m .64124 .54271 L .64103 .53997 L F
.63971 .53892 m .63839 .54167 L .64124 .54271 L F
.963 .74 .297 r
.63839 .54167 m .63907 .54525 L .64124 .54271 L F
.375 .575 .918 r
.39069 .70666 m .39234 .70585 L .39007 .70557 L F
.39069 .70666 m .39394 .70817 L .39234 .70585 L F
.893 .801 .751 r
.64113 .52832 m .64169 .53195 L .64266 .52951 L F
.64113 .52832 m .63951 .53107 L .64169 .53195 L F
.896 .719 .656 r
.63951 .53107 m .64138 .53271 L .64169 .53195 L F
.474 .815 .999 r
.33016 .60297 m .33083 .60179 L .32863 .60211 L F
.33016 .60297 m .33244 .60265 L .33083 .60179 L F
.541 .197 .335 r
.64061 .49852 m .64064 .49999 L .63848 .49971 L F
.616 .256 .336 r
.64396 .49924 m .64064 .49999 L .64061 .49852 L F
.588 .322 .481 r
.57168 .69519 m .5747 .69642 L .57509 .69436 L F
.57168 .69519 m .57195 .69749 L .5747 .69642 L F
.437 .242 .516 r
.24802 .60202 m .24977 .60163 L .25017 .59903 L F
.512 .306 .537 r
.24802 .60202 m .24983 .60406 L .24977 .60163 L F
.24802 .60202 m .24787 .60462 L .24983 .60406 L F
.274 .779 .828 r
.70317 .48564 m .70398 .48516 L .70151 .48496 L F
.70317 .48564 m .70509 .48517 L .70398 .48516 L F
.523 .89 .685 r
.47415 .76603 m .47258 .76718 L .47294 .7667 L F
.224 .276 .706 r
.47292 .76906 m .47332 .76619 L .47294 .7667 L F
.677 .977 .832 r
.47294 .7667 m .47341 .76558 L .47414 .76572 L F
.224 .276 .706 r
.47332 .76619 m .47341 .76558 L .47294 .7667 L F
.523 .89 .685 r
.47258 .76718 m .47173 .7678 L .47294 .7667 L F
.05 0 .34 r
.47173 .7678 m .47292 .76906 L .47294 .7667 L F
.47173 .7678 m .47133 .7703 L .47292 .76906 L F
.805 .707 .757 r
.49397 .64611 m .49515 .64946 L .49524 .64712 L F
.705 .752 .889 r
.49524 .64712 m .49633 .64412 L .49397 .64611 L F
.49524 .64712 m .49768 .6466 L .49633 .64412 L F
.759 .666 .76 r
.49515 .64946 m .49768 .6466 L .49524 .64712 L F
.911 .585 .108 r
.65845 .49746 m .65711 .49392 L .65857 .49509 L F
0 0 .467 r
.51845 .69057 m .51988 .6904 L .51999 .68821 L F
0 0 0 r
.51845 .69057 m .51806 .69147 L .51988 .6904 L F
.802 .81 .858 r
.74984 .58218 m .74792 .58386 L .74643 .58199 L F
.519 .51 .786 r
.52579 .65698 m .52612 .65549 L .52515 .6572 L F
.508 .445 .721 r
.51095 .66639 m .51152 .66968 L .51327 .66874 L F
.208 .132 .546 r
.51274 .67157 m .51327 .66874 L .51152 .66968 L F
.658 .638 .819 r
.66417 .52516 m .66504 .52706 L .66746 .52639 L F
.379 .045 .268 r
.5772 .69153 m .57989 .68942 L .57815 .68888 L F
.691 .979 .892 r
.70476 .52317 m .70822 .5216 L .70653 .52089 L F
.841 .888 .874 r
.70653 .52089 m .70822 .5216 L .70961 .5199 L F
.438 .782 .998 r
.25104 .66506 m .25042 .6662 L .24882 .66575 L F
.25104 .66506 m .25275 .66595 L .25042 .6662 L F
.43 .836 .975 r
.29479 .58444 m .2942 .5853 L .29264 .58461 L F
.29479 .58444 m .29631 .58485 L .2942 .5853 L F
.446 .119 .316 r
.62412 .48912 m .62642 .48869 L .62689 .4871 L F
.362 .043 .283 r
.62689 .4871 m .62863 .48795 L .62912 .48638 L F
.62689 .4871 m .62642 .48869 L .62863 .48795 L F
.17 .708 .796 r
.33802 .60179 m .33388 .6021 L .33594 .60157 L F
.815 .832 .863 r
.54447 .76569 m .54042 .76646 L .54262 .76579 L F
.54447 .76569 m .54142 .76773 L .54042 .76646 L F
.294 0 0 r
.54262 .76579 m .54643 .76491 L .54447 .76569 L F
.549 .164 .264 r
.47045 .69428 m .46943 .69625 L .46713 .69502 L F
.656 .342 .428 r
.47273 .69417 m .46943 .69625 L .47045 .69428 L F
.726 .723 .847 r
.48905 .63406 m .48577 .63351 L .48805 .63287 L F
.603 .776 .963 r
.49174 .63365 m .48905 .63406 L .48805 .63287 L F
.783 .656 .723 r
.5898 .57611 m .59106 .57653 L .59318 .57633 L F
.771 .57 .627 r
.59106 .57653 m .59109 .57904 L .59318 .57633 L F
.759 .677 .772 r
.5229 .6532 m .51948 .65452 L .52167 .65188 L F
.704 .712 .855 r
.52524 .65246 m .5229 .6532 L .52167 .65188 L F
0 .157 .665 r
.5341 .80439 m .53297 .8036 L .53292 .80308 L F
.5341 .80439 m .53297 .8036 L .53292 .80308 L F
.576 .509 .743 r
.53297 .8036 m .53539 .8062 L .5341 .80439 L F
.577 .552 .79 r
.57685 .70279 m .57466 .7034 L .57439 .70156 L F
.531 .29 .494 r
.57685 .70279 m .57429 .70524 L .57466 .7034 L F
.564 .529 .774 r
.2767 .65259 m .27878 .65219 L .27764 .64882 L F
.326 .072 .367 r
.73853 .5081 m .73935 .51055 L .73662 .51128 L F
0 0 0 r
.74196 .50621 m .74019 .50754 L .73853 .5081 L F
.055 0 .39 r
.74019 .50754 m .73935 .51055 L .73853 .5081 L F
0 0 .312 r
.60098 .71281 m .60011 .71154 L .60067 .71033 L F
.60098 .71281 m .6002 .71431 L .60011 .71154 L F
.606 .526 .738 r
.75234 .60567 m .75499 .60481 L .75181 .60374 L F
.458 .359 .655 r
.49904 .80618 m .4968 .80449 L .49967 .80412 L F
.49904 .80618 m .49724 .80683 L .4968 .80449 L F
.66 .924 .63 r
.51464 .8122 m .5163 .81088 L .51297 .81438 L F
.078 0 0 r
.51696 .81158 m .5163 .81088 L .51464 .8122 L F
.531 .602 .869 r
.51929 .81257 m .5163 .81088 L .51861 .81006 L F
.078 0 0 r
.51696 .81158 m .51861 .81006 L .5163 .81088 L F
.805 .707 .757 r
.49397 .64611 m .49177 .64921 L .49515 .64946 L F
.847 .487 .371 r
.71946 .5053 m .71777 .50324 L .72116 .5037 L F
.969 .833 .654 r
.70246 .52804 m .70457 .5254 L .70446 .52504 L F
.70246 .52804 m .70372 .52927 L .70457 .5254 L F
.321 .531 .902 r
.36759 .59491 m .36684 .59642 L .36522 .59394 L F
.422 .655 .956 r
.36759 .59491 m .36883 .59645 L .36684 .59642 L F
.552 .435 .674 r
.2464 .61002 m .24824 .607 L .24646 .60761 L F
.316 0 0 r
.42556 .69687 m .42782 .69663 L .42935 .69512 L F
.248 0 0 r
.42935 .69512 m .42995 .69628 L .43168 .6947 L F
.42935 .69512 m .42782 .69663 L .42995 .69628 L F
.408 .141 .394 r
.34502 .63499 m .34305 .63555 L .34559 .63297 L F
.368 .105 .378 r
.34697 .63432 m .34559 .63297 L .34747 .63229 L F
.34697 .63432 m .34502 .63499 L .34559 .63297 L F
.675 .524 .673 r
.49244 .76807 m .49496 .77046 L .49496 .76768 L F
.651 .475 .633 r
.49496 .76768 m .49496 .77046 L .49818 .76955 L F
.189 0 0 r
.30905 .60339 m .30679 .60409 L .30972 .60252 L F
.276 0 .04 r
.31162 .60196 m .30905 .60339 L .30972 .60252 L F
.847 .766 .772 r
.66593 .51728 m .66856 .51674 L .66753 .51506 L F
.642 .212 .211 r
.66593 .51728 m .66743 .51891 L .66856 .51674 L F
.393 0 .093 r
.66856 .51674 m .67001 .51829 L .67078 .51702 L F
.66856 .51674 m .66743 .51891 L .67001 .51829 L F
.494 .332 .59 r
.50838 .77619 m .50871 .77892 L .5107 .77751 L F
.622 .938 .716 r
.59605 .56224 m .59569 .56225 L .59295 .56454 L F
.773 .689 .145 r
.59629 .55954 m .59624 .55937 L .59605 .56224 L F
.915 .86 .42 r
.59605 .56224 m .59624 .55937 L .59569 .56225 L F
0 .484 .85 r
.334 .58947 m .33377 .58985 L .33205 .58929 L F
.334 .58947 m .33551 .5904 L .33377 .58985 L F
.603 .607 .828 r
.63839 .51664 m .63694 .51794 L .63524 .51777 L F
0 0 0 r
.60189 .54831 m .60119 .55005 L .60024 .55171 L F
.695 .92 .589 r
.60024 .55171 m .60119 .55005 L .59891 .55291 L F
.947 .936 .595 r
.59924 .55347 m .60024 .55171 L .59891 .55291 L F
.8 .976 .904 r
.64631 .49765 m .64396 .49924 L .64484 .49914 L F
.576 .218 .324 r
.40193 .65726 m .40318 .65499 L .40005 .65573 L F
.574 .114 .123 r
.40425 .65684 m .40318 .65499 L .40193 .65726 L F
.40425 .65684 m .40557 .65538 L .40318 .65499 L F
.11 0 0 r
.54764 .77063 m .54373 .77154 L .54549 .77008 L F
.367 .562 .911 r
.39253 .70025 m .39222 .69714 L .39121 .69711 L F
.39253 .70025 m .39427 .70017 L .39222 .69714 L F
.602 .518 .732 r
.51048 .66406 m .51095 .66639 L .5133 .66573 L F
.508 .445 .721 r
.51095 .66639 m .51327 .66874 L .5133 .66573 L F
.594 .343 .506 r
.48961 .80125 m .49019 .79947 L .48724 .79863 L F
.48961 .80125 m .49019 .79947 L .48724 .79863 L F
.395 .827 .957 r
.32501 .58779 m .32416 .58854 L .32272 .58803 L F
.32501 .58779 m .32618 .58809 L .32416 .58854 L F
.281 .147 .515 r
.61268 .50366 m .61468 .50272 L .61452 .50022 L F
.175 0 .346 r
.61237 .50573 m .61468 .50272 L .61268 .50366 L F
.478 .283 .537 r
.35756 .62163 m .35742 .62397 L .35535 .6245 L F
.469 .285 .548 r
.35725 .62609 m .35535 .6245 L .35742 .62397 L F
.35725 .62609 m .35524 .6267 L .35535 .6245 L F
.771 .653 .732 r
.58512 .70252 m .58439 .70408 L .58215 .70295 L F
.801 .621 .658 r
.58215 .70295 m .58439 .70408 L .58351 .70585 L F
0 0 .051 r
.58351 .70585 m .58512 .70252 L .58215 .70295 L F
.58351 .70585 m .58487 .70473 L .58512 .70252 L F
0 0 .045 r
.58512 .70252 m .58487 .70473 L .58644 .70162 L F
.91 .888 .798 r
.55943 .58192 m .56252 .57973 L .56039 .58261 L F
.55943 .58192 m .56137 .57882 L .56252 .57973 L F
.905 .89 .805 r
.56252 .57973 m .56137 .57882 L .56334 .57593 L F
.517 .587 .864 r
.24857 .65243 m .24795 .65518 L .24642 .6537 L F
.906 .737 .661 r
.6403 .5486 m .64067 .54667 L .63907 .54525 L F
.897 .57 .419 r
.66575 .49475 m .66617 .49674 L .66736 .49565 L F
.741 .7 .812 r
.66816 .50346 m .6659 .5057 L .66483 .50301 L F
.13 .085 .535 r
.66887 .50559 m .6659 .5057 L .66816 .50346 L F
.579 .414 .623 r
.55686 .76784 m .55904 .76981 L .55665 .76995 L F
.426 .778 .996 r
.55665 .76995 m .55904 .76981 L .55686 .76784 L F
.134 0 .144 r
.37249 .60983 m .37494 .60739 L .37466 .60857 L F
.304 0 .268 r
.37176 .61241 m .37249 .60983 L .37466 .60857 L F
.887 .526 .355 r
.4738 .80671 m .47793 .80993 L .47447 .80915 L F
.91 .702 .61 r
.47793 .80993 m .47593 .81213 L .47447 .80915 L F
.47793 .80993 m .47778 .81248 L .47593 .81213 L F
.786 .545 .572 r
.47793 .80993 m .48127 .81267 L .47778 .81248 L F
.192 .126 .549 r
.47697 .76955 m .47536 .7705 L .47598 .76648 L F
.097 0 .442 r
.47697 .76955 m .47537 .77294 L .47536 .7705 L F
.719 .758 .884 r
.49633 .64412 m .49768 .6466 L .49926 .64408 L F
.625 .629 .835 r
.49768 .6466 m .50032 .6466 L .49926 .64408 L F
.559 .562 .813 r
.49768 .6466 m .50117 .64935 L .50032 .6466 L F
.926 .97 .762 r
.62632 .5375 m .62434 .54061 L .62446 .53857 L F
.991 .886 .592 r
.62632 .5375 m .62561 .53665 L .62645 .53348 L F
.95 .941 .74 r
.62632 .5375 m .62446 .53857 L .62561 .53665 L F
.824 .873 .881 r
.71134 .47391 m .70947 .47587 L .70838 .47475 L F
.526 .901 .72 r
.5418 .76112 m .54061 .76221 L .54185 .76131 L F
.539 .926 .878 r
.53959 .76225 m .54061 .76221 L .5418 .76112 L F
.768 .982 .908 r
.47004 .63915 m .47084 .63744 L .4718 .63739 L F
.221 .075 .46 r
.60926 .51213 m .61059 .51336 L .61087 .51128 L F
.60926 .51213 m .60917 .5146 L .61059 .51336 L F
.585 .547 .779 r
.75181 .60374 m .75499 .60481 L .75366 .6014 L F
.472 .706 .971 r
.5018 .63257 m .50067 .63421 L .49949 .63278 L F
.5018 .63257 m .50341 .63427 L .50067 .63421 L F
.339 .086 .376 r
.25201 .59827 m .25453 .59551 L .25257 .59627 L F
.654 .605 .788 r
.37555 .70246 m .37833 .70462 L .37706 .70325 L F
.707 .798 .921 r
.37706 .70325 m .37833 .70462 L .38102 .70336 L F
.408 .047 .238 r
.33389 .62407 m .33605 .62367 L .33714 .62151 L F
.405 .105 .34 r
.33605 .62367 m .33877 .62065 L .33714 .62151 L F
.362 0 .086 r
.30348 .60514 m .30075 .60654 L .30141 .60466 L F
.718 .693 .826 r
.62096 .51703 m .61864 .51714 L .62128 .51507 L F
.766 .545 .598 r
.48127 .81267 m .47779 .81504 L .47778 .81248 L F
.48127 .81267 m .48137 .81519 L .47779 .81504 L F
.997 .773 .427 r
.48127 .81267 m .48063 .80923 L .48309 .81177 L F
.493 .42 .703 r
.48309 .81177 m .48137 .81519 L .48127 .81267 L F
.764 .919 .94 r
.7109 .48095 m .71426 .47931 L .71195 .47885 L F
.696 .889 .513 r
.71426 .47931 m .71454 .47841 L .71195 .47885 L F
.696 .425 0 r
.59764 .70262 m .59832 .70535 L .59848 .70591 L F
.989 .814 .428 r
.59832 .70535 m .59862 .70831 L .59848 .70591 L F
.824 .564 .547 r
.58874 .57023 m .59227 .56883 L .59083 .56704 L F
.58874 .57023 m .5925 .571 L .59227 .56883 L F
.776 .658 .732 r
.55676 .59614 m .558 .59932 L .55462 .59902 L F
.702 .683 .829 r
.55778 .60175 m .55462 .59902 L .558 .59932 L F
.636 .116 0 r
.50956 .76627 m .50468 .76481 L .50645 .76444 L F
.945 .72 .567 r
.56235 .74215 m .56215 .74462 L .56359 .74505 L F
.794 .307 0 r
.56417 .74685 m .56359 .74505 L .56215 .74462 L F
.56417 .74685 m .56539 .74762 L .56359 .74505 L F
.686 .417 .511 r
.60037 .5935 m .60045 .59561 L .59695 .59574 L F
.683 .415 .511 r
.60037 .5935 m .60265 .59599 L .60045 .59561 L F
.673 .416 .524 r
.6026 .59356 m .60265 .59599 L .60037 .5935 L F
.705 .231 .121 r
.51235 .76164 m .51614 .76263 L .51455 .76291 L F
0 0 0 r
.54346 .8021 m .54444 .80048 L .54199 .80151 L F
.905 .72 .642 r
.64098 .55217 m .63877 .54779 L .63821 .54923 L F
.64098 .55217 m .6403 .5486 L .63877 .54779 L F
.871 .751 .728 r
.63839 .55414 m .64098 .55217 L .63821 .54923 L F
.515 .701 .954 r
.29852 .62951 m .29864 .63192 L .29664 .62997 L F
.29852 .62951 m .30034 .63147 L .29864 .63192 L F
.334 0 .059 r
.45113 .69949 m .44954 .70141 L .44731 .70183 L F
.41 0 .092 r
.45345 .69942 m .44954 .70141 L .45113 .69949 L F
.308 .058 .362 r
.52198 .69158 m .52159 .69394 L .51961 .69446 L F
.347 .159 .478 r
.52159 .69394 m .51937 .69624 L .51961 .69446 L F
.497 .198 .389 r
.25731 .59322 m .25955 .59289 L .26038 .59077 L F
.319 .027 .302 r
.26038 .59077 m .26141 .59218 L .2621 .59037 L F
.26038 .59077 m .25955 .59289 L .26141 .59218 L F
.928 .905 .78 r
.55825 .58362 m .56039 .58261 L .55923 .58461 L F
.923 .922 .794 r
.55943 .58192 m .56039 .58261 L .55825 .58362 L F
.683 .143 0 r
.514 .77741 m .51429 .77625 L .51295 .77743 L F
.514 .77741 m .51655 .77817 L .51429 .77625 L F
.886 .948 .844 r
.70123 .53023 m .70118 .53248 L .70372 .52927 L F
.929 .964 .767 r
.70123 .53023 m .69964 .53256 L .70118 .53248 L F
0 .507 .784 r
.58351 .70585 m .58667 .70663 L .58591 .70634 L F
.984 .7 .35 r
.58525 .70609 m .58591 .70634 L .5854 .70664 L F
.362 .599 .938 r
.58351 .70585 m .58591 .70634 L .58487 .70473 L F
.984 .7 .35 r
.58487 .70473 m .58591 .70634 L .58525 .70609 L F
0 .507 .784 r
.58667 .70663 m .58698 .70671 L .58591 .70634 L F
.214 .576 .942 r
.5879 .70721 m .58591 .70634 L .58698 .70671 L F
0 .12 .663 r
.58698 .70671 m .58777 .70822 L .5879 .70721 L F
0 0 0 r
.60301 .54647 m .60119 .55005 L .60189 .54831 L F
.695 .156 0 r
.76001 .59911 m .76193 .60082 L .76239 .6004 L F
.827 .701 .724 r
.55872 .59323 m .55676 .59614 L .55556 .59292 L F
.875 .993 .756 r
.56381 .77848 m .56595 .77634 L .56603 .77558 L F
.649 .448 .599 r
.55477 .71082 m .55741 .70826 L .55554 .70894 L F
.508 .301 .534 r
.52386 .69049 m .52159 .69394 L .52198 .69158 L F
.531 .162 .286 r
.45906 .69712 m .45775 .6995 L .45553 .69944 L F
.556 .189 .3 r
.46123 .69869 m .45906 .69712 L .46133 .69703 L F
.46123 .69869 m .45775 .6995 L .45906 .69712 L F
.675 .524 .673 r
.49244 .76807 m .49134 .77129 L .49496 .77046 L F
.718 .586 .707 r
.64083 .51203 m .63865 .51229 L .63721 .50903 L F
.704 .514 .628 r
.64083 .51203 m .63869 .51473 L .63865 .51229 L F
.648 .864 .981 r
.47783 .63575 m .47478 .63555 L .47657 .6349 L F
.656 .861 .978 r
.48016 .63509 m .47783 .63575 L .47657 .6349 L F
.585 .387 .579 r
.61087 .59112 m .60854 .59333 L .60842 .5907 L F
.625 .485 .671 r
.62128 .51507 m .61864 .51714 L .61929 .51457 L F
.63 .591 .792 r
.51071 .65936 m .51048 .66406 L .51345 .66173 L F
.722 .796 .91 r
.51345 .66173 m .51048 .66406 L .51276 .66338 L F
.602 .518 .732 r
.51048 .66406 m .5133 .66573 L .51276 .66338 L F
.358 0 0 r
.30679 .60409 m .305 .60579 L .30348 .60514 L F
.162 0 0 r
.30727 .6051 m .30679 .60409 L .30905 .60339 L F
.30727 .6051 m .305 .60579 L .30679 .60409 L F
.39 .184 .476 r
.24977 .60163 m .25201 .59827 L .25017 .59903 L F
.457 .856 .971 r
.33551 .5904 m .33764 .58986 L .33929 .59018 L F
0 .561 .78 r
.33764 .58986 m .34112 .59037 L .33929 .59018 L F
0 0 0 r
.47994 .79543 m .48238 .79315 L .48212 .7953 L F
.798 .652 .702 r
.48573 .79295 m .48212 .7953 L .48238 .79315 L F
.849 .479 .351 r
.54693 .79481 m .55127 .79561 L .54955 .79693 L F
.54693 .79481 m .54955 .79693 L .54799 .79607 L F
.54693 .79481 m .54905 .79732 L .5467 .79764 L F
.54799 .79607 m .54955 .79693 L .54905 .79732 L F
.342 .422 .8 r
.54693 .79481 m .54905 .79732 L .54775 .79412 L F
.833 .689 .704 r
.54775 .79412 m .5467 .79764 L .54693 .79481 L F
.54728 .79568 m .54578 .79538 L .5467 .79764 L F
.54775 .79412 m .54623 .79509 L .54728 .79568 L F
.54623 .79509 m .54578 .79538 L .54728 .79568 L F
.917 .973 .688 r
.54905 .79732 m .55127 .79561 L .55087 .79419 L F
.618 .878 .99 r
.68941 .51899 m .6907 .51717 L .68819 .51674 L F
.68941 .51899 m .69188 .51814 L .6907 .51717 L F
.743 .667 .776 r
.54009 .73635 m .5415 .73967 L .5393 .73718 L F
.924 .575 .354 r
.5415 .73967 m .54033 .74092 L .5393 .73718 L F
.769 .688 .774 r
.54009 .73635 m .54129 .73731 L .54365 .73679 L F
.771 .68 .762 r
.54365 .73679 m .5415 .73967 L .54009 .73635 L F
.26 .022 .351 r
.54348 .73865 m .5415 .73967 L .54365 .73679 L F
.619 .325 .449 r
.54348 .73865 m .54033 .74092 L .5415 .73967 L F
.74 .784 .889 r
.7225 .48863 m .71987 .48794 L .72283 .48622 L F
.826 .904 .894 r
.72575 .48552 m .7225 .48863 L .72283 .48622 L F
.223 .381 .811 r
.77987 .59925 m .78173 .59854 L .77907 .59825 L F
.77987 .59925 m .78285 .60132 L .78173 .59854 L F
.768 .982 .908 r
.47004 .63915 m .46809 .63943 L .47084 .63744 L F
.52 .141 .263 r
.46713 .69502 m .46594 .6971 L .46359 .69712 L F
.546 .169 .277 r
.46943 .69625 m .46594 .6971 L .46713 .69502 L F
.639 .62 .816 r
.34258 .60537 m .34341 .60248 L .3413 .6023 L F
.34258 .60537 m .34489 .60469 L .34341 .60248 L F
.297 0 0 r
.5678 .7258 m .56726 .72635 L .56398 .72589 L F
0 .377 .749 r
.56999 .72766 m .56726 .72635 L .5678 .7258 L F
0 0 .088 r
.42869 .66639 m .42802 .66883 L .42676 .66942 L F
0 0 0 r
.42802 .66883 m .4252 .67108 L .42676 .66942 L F
.212 .702 .924 r
.31151 .64912 m .31326 .64913 L .31009 .64861 L F
.631 .961 .821 r
.69138 .51501 m .68819 .51674 L .69083 .51467 L F
.165 0 0 r
.693 .51317 m .69138 .51501 L .69376 .51436 L F
.684 .975 .904 r
.69138 .51501 m .693 .51317 L .69376 .51436 L F
.407 .411 .752 r
.6943 .51718 m .69138 .51501 L .69376 .51436 L F
.22 0 0 r
.5159 .81361 m .51929 .81257 L .51884 .81267 L F
.424 .469 .802 r
.51861 .81006 m .51929 .81257 L .52032 .81032 L F
0 .147 .669 r
.51954 .81133 m .51929 .81257 L .51861 .81006 L F
.86 .937 .562 r
.51884 .81267 m .51929 .81257 L .51954 .81133 L F
.517 .781 .992 r
.30052 .58389 m .29992 .58532 L .29841 .58427 L F
.30052 .58389 m .30194 .58494 L .29992 .58532 L F
.917 .976 .701 r
.67347 .52591 m .67538 .52295 L .67494 .52225 L F
.636 .962 .907 r
.67421 .52191 m .67494 .52225 L .67592 .52097 L F
.67357 .52226 m .67494 .52225 L .67421 .52191 L F
.888 .951 .841 r
.67538 .52295 m .67554 .52253 L .67494 .52225 L F
.67554 .52253 m .67674 .51933 L .67494 .52225 L F
.764 .735 .826 r
.54598 .77882 m .54998 .77889 L .54901 .77938 L F
.078 0 0 r
.54998 .77889 m .55089 .7797 L .54901 .77938 L F
.54998 .77889 m .55237 .7778 L .55089 .7797 L F
.588 .192 .259 r
.53119 .76383 m .53406 .76407 L .53472 .76214 L F
.985 .777 .377 r
.53406 .76407 m .53469 .76469 L .53472 .76214 L F
.472 .243 .485 r
.37715 .60679 m .37494 .60739 L .37733 .60478 L F
.555 .432 .667 r
.37921 .60179 m .37951 .60428 L .37733 .60478 L F
.559 .316 .504 r
.37733 .60478 m .37932 .60676 L .37715 .60679 L F
.518 .316 .546 r
.37951 .60428 m .37932 .60676 L .37733 .60478 L F
.849 .537 .459 r
.48143 .78422 m .47771 .78487 L .47754 .78427 L F
.937 .649 .184 r
.47706 .78498 m .47774 .78605 L .47754 .78427 L F
.849 .537 .459 r
.47771 .78487 m .47706 .78498 L .47754 .78427 L F
.697 .38 0 r
.47754 .78427 m .47779 .78479 L .47733 .78348 L F
.47754 .78427 m .47733 .78348 L .47644 .78099 L F
0 0 0 r
.47774 .78605 m .47779 .78479 L .47754 .78427 L F
.17 0 0 r
.46088 .6877 m .46466 .68637 L .46243 .68628 L F
.874 .653 .6 r
.62768 .52899 m .62729 .53127 L .62556 .52813 L F
.495 .326 .58 r
.61338 .59251 m .61087 .59112 L .61359 .58964 L F
.241 0 .146 r
.61633 .5877 m .61558 .58983 L .61359 .58964 L F
.362 .082 .347 r
.61549 .59163 m .61359 .58964 L .61558 .58983 L F
.61549 .59163 m .61338 .59251 L .61359 .58964 L F
.544 .337 .55 r
.38672 .66058 m .38906 .66024 L .38943 .658 L F
.472 .343 .624 r
.38672 .66058 m .38882 .66272 L .38906 .66024 L F
.38672 .66058 m .38677 .66367 L .38882 .66272 L F
.764 .904 .938 r
.72824 .51579 m .72737 .5181 L .72912 .51668 L F
.843 .986 .862 r
.72673 .51748 m .72737 .5181 L .72824 .51579 L F
.508 .342 .591 r
.56256 .60953 m .56039 .61113 L .55912 .60954 L F
.56256 .60953 m .56288 .61204 L .56039 .61113 L F
.155 0 .085 r
.34305 .63555 m .34187 .63776 L .3404 .6379 L F
.489 .168 .348 r
.34502 .63499 m .34187 .63776 L .34305 .63555 L F
.347 .59 .935 r
.48053 .78074 m .48201 .78083 L .48194 .77922 L F
.5 .243 .456 r
.48467 .78095 m .48194 .77922 L .48201 .78083 L F
.48467 .78095 m .48482 .77882 L .48194 .77922 L F
.48467 .78095 m .48194 .77922 L .48201 .78083 L F
.48467 .78095 m .48482 .77882 L .48194 .77922 L F
.681 .646 .808 r
.75499 .60481 m .75833 .60736 L .75738 .60432 L F
.667 .595 .766 r
.75738 .60432 m .75833 .60736 L .76062 .60483 L F
.625 .531 .728 r
.75833 .60736 m .76068 .60695 L .76062 .60483 L F
.475 .583 .883 r
.75833 .60736 m .76163 .60964 L .76068 .60695 L F
.95 .925 .745 r
.55745 .58759 m .55825 .58362 L .55923 .58461 L F
.802 .81 .858 r
.74984 .58218 m .74643 .58199 L .74894 .58118 L F
.41 .727 .99 r
.75172 .58135 m .74984 .58218 L .74894 .58118 L F
.75172 .58135 m .75445 .58212 L .74984 .58218 L F
.956 .813 .663 r
.63971 .53892 m .64103 .53997 L .64018 .5367 L F
.934 .562 .178 r
.5422 .78117 m .54075 .77866 L .5384 .78122 L F
.624 .176 .166 r
.5384 .78122 m .54068 .78189 L .5422 .78117 L F
.557 0 0 r
.5439 .78283 m .5422 .78117 L .54068 .78189 L F
.5439 .78283 m .54471 .78239 L .5422 .78117 L F
.712 .343 .348 r
.5422 .78117 m .54471 .78239 L .54571 .78208 L F
0 .197 .71 r
.78023 .58028 m .7786 .57945 L .77792 .57813 L F
.513 0 0 r
.7786 .57945 m .78176 .58208 L .78254 .58255 L F
0 .197 .71 r
.78023 .58028 m .78176 .58208 L .7786 .57945 L F
.895 .876 .809 r
.55237 .795 m .55367 .79577 L .55559 .79272 L F
.457 .308 .59 r
.38493 .66657 m .38691 .666 L .38677 .66367 L F
.436 .285 .577 r
.38503 .66899 m .38691 .666 L .38493 .66657 L F
.772 .55 .597 r
.59105 .58152 m .59451 .57947 L .59109 .57904 L F
.59105 .58152 m .59451 .58188 L .59451 .57947 L F
.465 .218 .454 r
.37715 .60679 m .37466 .60857 L .37494 .60739 L F
.541 .304 .505 r
.29579 .60755 m .29577 .60992 L .2933 .6102 L F
.246 .077 .444 r
.29721 .60897 m .29579 .60755 L .29788 .60758 L F
.29721 .60897 m .29577 .60992 L .29579 .60755 L F
.487 .291 .539 r
.35949 .62342 m .35756 .62163 L .35965 .62113 L F
.35949 .62342 m .35742 .62397 L .35756 .62163 L F
.986 .849 .474 r
.62255 .54396 m .62253 .54188 L .62212 .5417 L F
.07 0 0 r
.62176 .54154 m .62212 .5417 L .62434 .54061 L F
.909 .966 .806 r
.62434 .54061 m .62212 .5417 L .62446 .53857 L F
.986 .849 .474 r
.62253 .54188 m .62251 .54079 L .62212 .5417 L F
.07 0 0 r
.62092 .54184 m .62212 .5417 L .62176 .54154 L F
.764 .919 .94 r
.7109 .48095 m .71195 .47885 L .70944 .48019 L F
.72 .312 .272 r
.7097 .48252 m .7109 .48095 L .70944 .48019 L F
.7097 .48252 m .71329 .48304 L .7109 .48095 L F
.437 .819 .989 r
.68737 .52483 m .68487 .52528 L .68311 .52459 L F
.23 .742 .874 r
.31326 .64913 m .31664 .64906 L .31541 .64902 L F
.159 0 0 r
.3189 .64854 m .31541 .64902 L .31664 .64906 L F
.576 .218 .324 r
.40193 .65726 m .40005 .65573 L .39902 .65599 L F
.771 .537 .579 r
.55971 .72266 m .55855 .72465 L .55687 .72228 L F
.688 .247 .198 r
.55687 .72228 m .55937 .72273 L .55971 .72266 L F
.798 .652 .702 r
.48573 .79295 m .4853 .79604 L .48212 .7953 L F
.66 .924 .63 r
.51464 .8122 m .51297 .81438 L .51197 .81388 L F
.347 .59 .935 r
.48053 .78074 m .48115 .78119 L .48201 .78083 L F
.875 .973 .661 r
.7189 .49244 m .71733 .49395 L .71719 .49199 L F
.576 .807 .987 r
.55043 .77234 m .55322 .7725 L .54983 .7714 L F
.372 0 0 r
.55177 .77228 m .55322 .7725 L .55242 .77244 L F
.371 .47 .832 r
.54764 .77063 m .54826 .77101 L .54983 .7714 L F
.54826 .77101 m .55043 .77234 L .55006 .77176 L F
.54826 .77101 m .55006 .77176 L .54983 .7714 L F
.372 0 0 r
.55068 .77202 m .55114 .77206 L .55177 .77228 L F
.54859 .77152 m .55038 .7719 L .55068 .77202 L F
.55038 .7719 m .55114 .77206 L .55068 .77202 L F
.55114 .77206 m .55322 .7725 L .55177 .77228 L F
.371 .47 .832 r
.54826 .77101 m .54869 .77328 L .55043 .77234 L F
.54764 .77063 m .54771 .77081 L .54826 .77101 L F
.54771 .77081 m .54869 .77328 L .54826 .77101 L F
.159 .016 .423 r
.55043 .77234 m .54869 .77328 L .54853 .77558 L F
.499 .537 .827 r
.51276 .66338 m .51501 .66297 L .51345 .66173 L F
.256 .103 .473 r
.5133 .66573 m .51501 .66297 L .51276 .66338 L F
.286 .36 .765 r
.24296 .63388 m .24451 .63487 L .24356 .63563 L F
.537 .924 .825 r
.24356 .63563 m .24451 .63487 L .24281 .63584 L F
.186 0 0 r
.46024 .65358 m .46076 .65337 L .46283 .6532 L F
.312 .802 .86 r
.46524 .6526 m .46024 .65358 L .46283 .6532 L F
.46666 .65224 m .46502 .65258 L .46524 .6526 L F
.46502 .65258 m .46024 .65358 L .46524 .6526 L F
.644 .965 .902 r
.46756 .65122 m .46577 .65244 L .46565 .65262 L F
.46598 .65264 m .46565 .65262 L .4652 .65335 L F
.46756 .65122 m .46565 .65262 L .46598 .65264 L F
.877 .742 .71 r
.49276 .77314 m .49489 .77478 L .49496 .77046 L F
.826 .763 .793 r
.49276 .77314 m .49353 .77598 L .49489 .77478 L F
.084 .081 .555 r
.49496 .77046 m .49489 .77478 L .49654 .77212 L F
.332 0 0 r
.49638 .77511 m .49687 .77543 L .49489 .77478 L F
.49955 .77582 m .49687 .77543 L .49638 .77511 L F
.973 .739 .523 r
.49955 .77582 m .4979 .77784 L .49687 .77543 L F
0 0 .5 r
.49687 .77543 m .4979 .77784 L .49736 .77574 L F
.49687 .77543 m .49736 .77574 L .49717 .77499 L F
0 0 .445 r
.49687 .77543 m .49654 .77212 L .49489 .77478 L F
.655 .78 .94 r
.69828 .51069 m .69972 .51215 L .69603 .51151 L F
.925 .958 .783 r
.69972 .51215 m .69654 .51222 L .69953 .51428 L F
.784 .535 .56 r
.69603 .51151 m .69972 .51215 L .69953 .51428 L F
.647 .778 .943 r
.70175 .51098 m .69972 .51215 L .69828 .51069 L F
.689 .621 .775 r
.76068 .60695 m .76163 .60964 L .76415 .60741 L F
.608 .304 .428 r
.54365 .73679 m .54597 .73869 L .54348 .73865 L F
.867 .855 .828 r
.55888 .75347 m .55679 .75652 L .55519 .75533 L F
.014 .217 .725 r
.55661 .75847 m .55519 .75533 L .55679 .75652 L F
.741 .838 .387 r
.50909 .78258 m .50847 .78358 L .50875 .78325 L F
.829 .558 .529 r
.50875 .78325 m .51018 .78451 L .50909 .78258 L F
.483 .437 .73 r
.51018 .78451 m .51198 .78389 L .50909 .78258 L F
.825 .562 .541 r
.50875 .78325 m .50965 .7868 L .51018 .78451 L F
.897 .571 .08 r
.50847 .78358 m .50965 .7868 L .50875 .78325 L F
.682 .249 .215 r
.5071 .78524 m .50847 .78358 L .50496 .78329 L F
.556 .819 .455 r
.50754 .7847 m .50847 .78358 L .5071 .78524 L F
.50933 .78251 m .50847 .78358 L .50754 .7847 L F
.597 .088 .012 r
.50909 .78258 m .50924 .78265 L .50847 .78358 L F
.50924 .78265 m .51198 .78389 L .50847 .78358 L F
.646 .345 .447 r
.52484 .78449 m .52699 .78662 L .52505 .78724 L F
.52484 .78449 m .52818 .78452 L .52699 .78662 L F
.409 .144 .397 r
.60685 .57071 m .60886 .57043 L .60938 .56826 L F
.143 0 .263 r
.6115 .5653 m .60938 .56826 L .61086 .56727 L F
.298 .046 .353 r
.60938 .56826 m .61129 .56933 L .61086 .56727 L F
.60938 .56826 m .60886 .57043 L .61129 .56933 L F
.531 .665 .922 r
.51224 .6407 m .51172 .64338 L .50996 .64068 L F
.51224 .6407 m .5139 .64298 L .51172 .64338 L F
.675 .695 .862 r
.48228 .63369 m .4836 .63565 L .48016 .63509 L F
.757 .723 .821 r
.48577 .63351 m .4836 .63565 L .48228 .63369 L F
.781 .348 0 r
.65669 .4904 m .65744 .49188 L .65634 .49058 L F
.568 .918 .961 r
.78254 .58255 m .78176 .58208 L .77858 .58335 L F
.773 .987 .898 r
.78176 .58208 m .78334 .5807 L .78254 .58255 L F
.78176 .58208 m .78334 .5807 L .78254 .58255 L F
.775 .715 .797 r
.5421 .75067 m .54397 .75105 L .54678 .74864 L F
.443 .105 .297 r
.36681 .61516 m .3675 .6135 L .36974 .61304 L F
.436 .167 .405 r
.54024 .74806 m .54245 .74797 L .54311 .7456 L F
.474 .447 .748 r
.54024 .74806 m .5421 .75067 L .54245 .74797 L F
.618 .342 .477 r
.60625 .59326 m .60265 .59599 L .6026 .59356 L F
.795 .3 0 r
.48618 .80686 m .48706 .80915 L .48468 .80628 L F
.48618 .80686 m .488 .80939 L .48706 .80915 L F
.446 .542 .861 r
.68942 .52486 m .68808 .52693 L .68737 .52483 L F
.644 .81 .963 r
.68942 .52486 m .69057 .52613 L .68808 .52693 L F
.658 .299 .353 r
.63623 .49303 m .63938 .49441 L .63612 .49405 L F
.856 .955 .608 r
.52699 .79724 m .52786 .79621 L .52797 .79556 L F
.681 .771 .919 r
.69928 .47501 m .69777 .47795 L .69682 .47632 L F
.69928 .47501 m .70001 .47705 L .69777 .47795 L F
.61 .802 .973 r
.66575 .49475 m .66365 .49537 L .66244 .49405 L F
.532 .445 .703 r
.41306 .67714 m .4135 .68036 L .41144 .68078 L F
.512 .437 .708 r
.41399 .68274 m .41144 .68078 L .4135 .68036 L F
.41399 .68274 m .41197 .68327 L .41144 .68078 L F
.243 .222 .635 r
.25231 .64432 m .25341 .64591 L .25325 .64351 L F
.984 .904 .628 r
.37696 .69994 m .37702 .69676 L .37736 .69898 L F
.759 .983 .741 r
.5445 .74371 m .54311 .7456 L .54333 .74456 L F
.628 .592 .794 r
.54245 .74797 m .54333 .74456 L .54311 .7456 L F
.713 .701 .837 r
.52437 .64979 m .52524 .65246 L .52167 .65188 L F
0 0 0 r
.52793 .6498 m .52701 .6514 L .52524 .65246 L F
.451 .877 .777 r
.52701 .6514 m .5263 .65165 L .52524 .65246 L F
.801 .748 .803 r
.52793 .6498 m .52524 .65246 L .52437 .64979 L F
.965 .93 .614 r
.5263 .65165 m .52651 .6532 L .52524 .65246 L F
.951 .7 .523 r
.56905 .75819 m .56982 .75564 L .56923 .7562 L F
0 .517 .79 r
.50708 .76104 m .50931 .76151 L .5122 .76235 L F
.457 .818 .995 r
.50931 .76151 m .51235 .76164 L .5122 .76235 L F
.545 .28 .464 r
.53938 .75902 m .54174 .75878 L .54201 .75662 L F
.556 .289 .466 r
.54201 .75662 m .54402 .75779 L .54449 .75603 L F
.54201 .75662 m .54174 .75878 L .54402 .75779 L F
.287 0 0 r
.55081 .75219 m .54981 .75144 L .54841 .75256 L F
.55081 .75219 m .55224 .75131 L .54981 .75144 L F
.473 .738 .986 r
.36522 .59394 m .3633 .59435 L .36189 .59314 L F
.472 .371 .659 r
.60685 .57071 m .60932 .57283 L .60886 .57043 L F
.60735 .57348 m .60932 .57283 L .60685 .57071 L F
.801 .748 .803 r
.52793 .6498 m .52437 .64979 L .52775 .64927 L F
.857 .861 .409 r
.52775 .64927 m .52765 .64915 L .52793 .6498 L F
.57 .783 .979 r
.52518 .64846 m .52775 .64927 L .52437 .64979 L F
.919 .522 .184 r
.52765 .64915 m .52701 .6514 L .52793 .6498 L F
.51 .096 .191 r
.41845 .67178 m .41698 .67374 L .4152 .67246 L F
.648 .254 .283 r
.42041 .67364 m .41845 .67178 L .42058 .67168 L F
.42041 .67364 m .41698 .67374 L .41845 .67178 L F
.717 .864 .448 r
.37696 .69994 m .37555 .70246 L .37549 .70214 L F
0 .292 .718 r
.37555 .70246 m .37706 .70325 L .37549 .70214 L F
0 0 .529 r
.47029 .79038 m .47159 .79175 L .47245 .78969 L F
.47029 .79038 m .471 .7927 L .47159 .79175 L F
.548 .278 .458 r
.38906 .66024 m .39181 .65785 L .38943 .658 L F
.762 .711 .804 r
.49412 .81821 m .49653 .81591 L .49322 .81554 L F
.997 .861 .55 r
.48961 .80125 m .49044 .80135 L .49019 .79947 L F
0 .062 .608 r
.49019 .79947 m .49044 .80135 L .49059 .79926 L F
.923 .976 .742 r
.49059 .79926 m .49044 .80135 L .48961 .80125 L F
.603 .388 .562 r
.58675 .59883 m .58463 .60086 L .58487 .59897 L F
.628 .37 .508 r
.63452 .49806 m .63227 .50003 L .63245 .49782 L F
.584 .832 .992 r
.68541 .47583 m .68301 .47654 L .68192 .47548 L F
.192 .167 .6 r
.60719 .5392 m .60786 .5414 L .60602 .54196 L F
0 0 0 r
.60786 .5414 m .6053 .54362 L .60602 .54196 L F
.61416 .56297 m .6115 .5653 L .61333 .56436 L F
.61416 .56297 m .61483 .56329 L .61597 .56179 L F
.61416 .56297 m .61333 .56436 L .61483 .56329 L F
.523 .588 .862 r
.7734 .58119 m .7743 .57809 L .77212 .57921 L F
.7734 .58119 m .77588 .58116 L .7743 .57809 L F
.832 .732 .755 r
.551 .74244 m .55108 .74508 L .55023 .74447 L F
.941 .922 .763 r
.55108 .74508 m .54955 .74702 L .55023 .74447 L F
.501 .304 .545 r
.55752 .70588 m .55982 .70771 L .55964 .70533 L F
.55752 .70588 m .55741 .70826 L .55982 .70771 L F
.286 .078 .413 r
.33877 .62065 m .34076 .61787 L .33914 .61865 L F
.542 .724 .958 r
.4882 .79024 m .48456 .78948 L .4868 .7873 L F
.237 0 0 r
.43972 .70338 m .43817 .70452 L .43594 .70477 L F
.299 0 0 r
.44192 .7031 m .43817 .70452 L .43972 .70338 L F
.79 .609 .656 r
.55565 .60213 m .55225 .60416 L .55425 .60135 L F
.55565 .60213 m .55569 .60453 L .55225 .60416 L F
.702 .683 .829 r
.55778 .60175 m .55565 .60213 L .55425 .60135 L F
.682 .522 .663 r
.55778 .60175 m .55569 .60453 L .55565 .60213 L F
.731 .894 .953 r
.54512 .74778 m .54678 .74864 L .54955 .74702 L F
.728 .718 .84 r
.4868 .7873 m .48456 .78948 L .48333 .78656 L F
.092 .218 .703 r
.69603 .51151 m .69705 .51512 L .69752 .51382 L F
.451 .636 .934 r
.69752 .51382 m .69705 .51512 L .69827 .51513 L F
.53 .698 .946 r
.71907 .48597 m .71779 .4882 L .71632 .48705 L F
.71907 .48597 m .71987 .48794 L .71779 .4882 L F
.937 .909 .768 r
.78533 .60069 m .7862 .59926 L .78437 .59995 L F
.882 .99 .739 r
.78823 .59635 m .78667 .59728 L .7862 .59926 L F
.859 .987 .844 r
.7862 .59926 m .78667 .59728 L .78437 .59995 L F
.274 .778 .845 r
.4522 .64472 m .45505 .64414 L .45613 .64418 L F
.5 .906 .901 r
.45613 .64418 m .45717 .64323 L .45809 .64291 L F
.45613 .64418 m .45505 .64414 L .45717 .64323 L F
.208 .017 .388 r
.51365 .79471 m .51173 .79562 L .51255 .79301 L F
.481 .615 .906 r
.78887 .59411 m .78823 .59635 L .78681 .59382 L F
.877 .99 .74 r
.78887 .59411 m .78667 .59728 L .78823 .59635 L F
.417 .209 .487 r
.75276 .5875 m .75111 .58782 L .75384 .5852 L F
.465 .373 .667 r
.75276 .5875 m .7537 .58965 L .75111 .58782 L F
.602 .285 .406 r
.52247 .78729 m .51909 .78973 L .51918 .78745 L F
.52247 .78729 m .5214 .78972 L .51909 .78973 L F
.623 .308 .416 r
.52247 .78729 m .52471 .78944 L .5214 .78972 L F
.97 .67 .394 r
.52247 .78729 m .52505 .78724 L .52471 .78944 L F
.522 .234 .418 r
.44529 .6915 m .44758 .6913 L .44816 .68871 L F
.687 .389 .465 r
.44816 .68871 m .45079 .69104 L .45122 .68874 L F
.44816 .68871 m .44758 .6913 L .45079 .69104 L F
.895 .876 .809 r
.55237 .795 m .55559 .79272 L .55509 .79255 L F
.716 .637 .769 r
.52167 .65188 m .51948 .65452 L .51828 .6512 L F
.822 .707 .738 r
.25932 .6435 m .25684 .64617 L .25997 .64624 L F
0 .18 .712 r
.25684 .64617 m .2583 .64909 L .25997 .64624 L F
.721 .727 .856 r
.25997 .64624 m .26126 .64303 L .25932 .6435 L F
.25997 .64624 m .26302 .64479 L .26126 .64303 L F
0 0 .547 r
.72972 .48708 m .72879 .48681 L .72826 .48552 L F
0 .113 .649 r
.72991 .48614 m .72972 .48708 L .72826 .48552 L F
.926 .769 .29 r
.7298 .4865 m .72972 .48708 L .72991 .48614 L F
0 0 .547 r
.72972 .48708 m .72956 .48822 L .72879 .48681 L F
.926 .769 .29 r
.72926 .48827 m .72972 .48708 L .7298 .4865 L F
0 0 .547 r
.72972 .48708 m .72999 .48902 L .72956 .48822 L F
.565 .789 .983 r
.48332 .62631 m .48474 .62747 L .4811 .62684 L F
.48332 .62631 m .48474 .62747 L .4811 .62684 L F
.784 .411 .35 r
.48212 .7953 m .4853 .79604 L .48566 .79791 L F
.584 .463 .681 r
.38309 .67198 m .38554 .67162 L .38503 .66899 L F
.555 .443 .681 r
.38309 .67198 m .38554 .67466 L .38554 .67162 L F
.38309 .67198 m .38337 .67529 L .38554 .67466 L F
.531 .489 .754 r
.50117 .64935 m .50268 .64664 L .50032 .6466 L F
.50117 .64935 m .50321 .64892 L .50268 .64664 L F
.888 .772 .727 r
.7375 .50016 m .73844 .50344 L .73716 .50174 L F
.753 .703 .805 r
.74076 .50071 m .73844 .50344 L .7375 .50016 L F
.652 .545 .721 r
.74076 .50071 m .74274 .50506 L .73844 .50344 L F
.476 0 0 r
.52214 .76619 m .52565 .76668 L .5234 .76567 L F
.908 .596 .444 r
.76843 .60388 m .76823 .60239 L .76575 .60046 L F
.404 .771 .994 r
.34552 .59025 m .34477 .59128 L .34325 .59043 L F
.34552 .59025 m .34669 .59103 L .34477 .59128 L F
.995 .754 .411 r
.72936 .49355 m .73027 .4946 L .73029 .49228 L F
.2 .631 .948 r
.35506 .59098 m .35398 .59145 L .35312 .59146 L F
.35506 .59098 m .35661 .59203 L .35398 .59145 L F
.603 .431 .622 r
.2489 .63101 m .2474 .63162 L .24843 .63046 L F
.63 .434 .598 r
.24674 .62853 m .24843 .63046 L .24792 .62689 L F
.24843 .63046 m .2489 .63101 L .24862 .62985 L F
.24843 .63046 m .24862 .62985 L .24792 .62689 L F
.57 .396 .607 r
.24792 .62689 m .2489 .63101 L .24955 .6292 L F
.603 .431 .622 r
.2489 .63101 m .24843 .63046 L .24955 .6292 L F
.533 .335 .558 r
.24843 .63046 m .25017 .63131 L .24955 .6292 L F
.615 .459 .647 r
.24832 .63078 m .2474 .63162 L .2489 .63101 L F
.533 .335 .558 r
.2474 .63162 m .24832 .63078 L .24843 .63046 L F
.615 .459 .647 r
.24581 .62982 m .2474 .63162 L .24832 .63078 L F
.533 .335 .558 r
.2474 .63162 m .24808 .63154 L .24832 .63078 L F
.63 .434 .598 r
.24581 .62982 m .2489 .63101 L .24674 .62853 L F
.533 .335 .558 r
.24808 .63154 m .25017 .63131 L .24843 .63046 L F
.628 .962 .871 r
.46076 .65337 m .45895 .6537 L .45804 .6549 L F
.597 .872 .545 r
.45895 .6537 m .45784 .65499 L .45804 .6549 L F
.717 .864 .448 r
.37696 .69994 m .37549 .70214 L .37603 .70011 L F
.984 .904 .628 r
.37696 .69994 m .37603 .70011 L .37702 .69676 L F
.615 .731 .929 r
.48491 .75503 m .48642 .75689 L .48864 .75604 L F
.748 .24 0 r
.51614 .76263 m .51753 .76464 L .51819 .76439 L F
.708 .177 0 r
.51753 .76464 m .52011 .76584 L .51819 .76439 L F
.314 0 0 r
.42147 .65171 m .42377 .6515 L .42518 .65033 L F
.258 0 0 r
.42518 .65033 m .42695 .65057 L .42735 .64993 L F
.42518 .65033 m .42377 .6515 L .42695 .65057 L F
.477 .14 .316 r
.43104 .66764 m .42869 .66639 L .43099 .66557 L F
.43104 .66764 m .42802 .66883 L .42869 .66639 L F
.267 0 0 r
.31503 .60119 m .31355 .6023 L .31162 .60196 L F
.242 0 0 r
.31712 .60097 m .31355 .6023 L .31503 .60119 L F
0 0 0 r
.64454 .51339 m .64358 .51608 L .64189 .51759 L F
0 0 .281 r
.64268 .51753 m .64189 .51759 L .64358 .51608 L F
.64268 .51753 m .64203 .51976 L .64189 .51759 L F
0 .075 .622 r
.50408 .77841 m .50167 .77604 L .5055 .77485 L F
.50408 .77841 m .50373 .77852 L .50167 .77604 L F
.466 .818 .997 r
.3781 .59887 m .376 .59929 L .37458 .59854 L F
.073 0 .038 r
.61778 .58698 m .61633 .5877 L .61898 .58528 L F
.303 0 .171 r
.61782 .58902 m .61633 .5877 L .61778 .58698 L F
.61782 .58902 m .61558 .58983 L .61633 .5877 L F
.56 .346 .547 r
.57868 .60177 m .57861 .60429 L .57605 .60449 L F
.601 .38 .552 r
.581 .60383 m .57861 .60429 L .57868 .60177 L F
.645 .37 .489 r
.5809 .60183 m .581 .60383 L .57868 .60177 L F
.977 .726 .313 r
.65814 .5116 m .65729 .50811 L .65846 .50923 L F
.421 .404 .734 r
.38414 .67742 m .3849 .68062 L .38661 .67997 L F
.414 .324 .645 r
.3849 .68062 m .38702 .68262 L .38661 .67997 L F
.3849 .68062 m .38523 .68309 L .38702 .68262 L F
.877 .742 .71 r
.49276 .77314 m .49496 .77046 L .49134 .77129 L F
.201 .226 .664 r
.67065 .50752 m .66925 .51005 L .66887 .50559 L F
.464 .036 .141 r
.43938 .6939 m .44178 .69377 L .44311 .69199 L F
.471 .044 .146 r
.44311 .69199 m .44178 .69377 L .44468 .6931 L F
.416 .076 .279 r
.44311 .69199 m .44468 .6931 L .44529 .6915 L F
0 0 0 r
.62034 .58366 m .61898 .58528 L .62074 .58199 L F
.17 0 .374 r
.62034 .58366 m .61778 .58698 L .61898 .58528 L F
.213 .002 .361 r
.61086 .56727 m .61333 .56436 L .6115 .5653 L F
.59 .145 .162 r
.46466 .68637 m .46679 .68774 L .46815 .68613 L F
.754 .348 .281 r
.46679 .68774 m .47013 .68839 L .46815 .68613 L F
.749 .351 .297 r
.46815 .68613 m .47013 .68839 L .47182 .68798 L F
.77 .662 .744 r
.4868 .7873 m .49024 .78728 L .48894 .78417 L F
.206 .725 .866 r
.48885 .78711 m .49024 .78728 L .4868 .7873 L F
.89 .844 .793 r
.49024 .78728 m .49151 .78405 L .48894 .78417 L F
.224 0 0 r
.49147 .78829 m .49024 .78728 L .48885 .78711 L F
.525 .387 .635 r
.41399 .68274 m .41194 .68522 L .41197 .68327 L F
.385 .017 .212 r
.48779 .77649 m .4868 .77854 L .48482 .77882 L F
.551 .182 .294 r
.49009 .77786 m .4868 .77854 L .48779 .77649 L F
.75 .561 .639 r
.57029 .72303 m .56675 .72076 L .56873 .71956 L F
.57029 .72303 m .56919 .72472 L .56675 .72076 L F
.423 .474 .808 r
.57175 .7211 m .57029 .72303 L .56873 .71956 L F
.486 .235 .458 r
.57217 .72441 m .57029 .72303 L .57175 .7211 L F
.57217 .72441 m .56992 .72567 L .57029 .72303 L F
.367 .798 .967 r
.35118 .59054 m .35054 .59151 L .34916 .59072 L F
.35118 .59054 m .35312 .59146 L .35054 .59151 L F
.828 .428 .291 r
.55208 .74836 m .55065 .74964 L .54955 .74702 L F
.783 .554 .59 r
.55413 .74752 m .55065 .74964 L .55208 .74836 L F
.525 .453 .718 r
.27573 .64898 m .27778 .64702 L .27395 .64614 L F
.27573 .64898 m .27764 .64882 L .27778 .64702 L F
.419 .796 .993 r
.26865 .6434 m .26977 .64217 L .2668 .64295 L F
.26865 .6434 m .2707 .64312 L .26977 .64217 L F
.737 .785 .891 r
.70361 .47659 m .70001 .47705 L .70275 .47549 L F
.685 .807 .94 r
.70485 .47435 m .70361 .47659 L .70275 .47549 L F
.70485 .47435 m .70593 .47566 L .70361 .47659 L F
.592 .334 .495 r
.52873 .65521 m .53098 .65717 L .53125 .65515 L F
.52873 .65521 m .53098 .65717 L .53125 .65515 L F
.515 0 0 r
.25494 .62911 m .257 .6302 L .25436 .62857 L F
.694 .311 .317 r
.25494 .62911 m .25867 .62931 L .257 .6302 L F
.093 .392 .85 r
.50166 .79458 m .50366 .79719 L .50103 .79556 L F
0 0 0 r
.28507 .65075 m .28487 .65061 L .28683 .65013 L F
.28507 .65075 m .28319 .65143 L .28487 .65061 L F
.245 .729 .928 r
.40523 .7223 m .40784 .72223 L .40879 .72264 L F
.40523 .7223 m .40784 .72223 L .40879 .72264 L F
.435 .504 .831 r
.63514 .5049 m .6349 .50738 L .63391 .50614 L F
.621 .675 .88 r
.63849 .50542 m .6349 .50738 L .63514 .5049 L F
.897 .735 .672 r
.63877 .54779 m .6403 .5486 L .63907 .54525 L F
.931 .789 .682 r
.73049 .51079 m .73059 .5132 L .73188 .51232 L F
0 0 0 r
.32097 .64836 m .32478 .64639 L .32307 .64783 L F
.095 0 0 r
.32307 .64783 m .32478 .64639 L .32685 .64577 L F
.198 0 .169 r
.4152 .67246 m .41465 .67411 L .41286 .67475 L F
.476 .119 .28 r
.41698 .67374 m .41465 .67411 L .4152 .67246 L F
.509 .329 .572 r
.5246 .7703 m .52458 .7729 L .52228 .77322 L F
.745 .692 .801 r
.52458 .7729 m .5224 .77607 L .52228 .77322 L F
.054 .263 .757 r
.48937 .80967 m .49061 .80924 L .488 .80939 L F
.638 .373 .502 r
.4919 .80975 m .49161 .81194 L .48937 .80967 L F
.733 .572 .673 r
.49061 .80924 m .49326 .80909 L .49182 .80653 L F
0 0 0 r
.49103 .80851 m .49061 .80924 L .49124 .80815 L F
.054 .263 .757 r
.48999 .8103 m .49161 .81194 L .49061 .80924 L F
0 0 0 r
.48958 .8111 m .49061 .80924 L .49103 .80851 L F
.054 .263 .757 r
.48937 .80967 m .48999 .8103 L .49061 .80924 L F
.267 .295 .705 r
.47107 .78384 m .47324 .78316 L .47316 .78083 L F
.47107 .78384 m .47159 .78431 L .47324 .78316 L F
.297 .038 .342 r
.34076 .61787 m .34324 .61482 L .34142 .61567 L F
0 0 .147 r
.52098 .66329 m .51943 .66572 L .51895 .66354 L F
.454 0 0 r
.3947 .71652 m .39826 .71674 L .39488 .71611 L F
.488 .092 .214 r
.52212 .68754 m .52562 .68544 L .52402 .68516 L F
.893 .79 .74 r
.55745 .58759 m .55428 .5896 L .55655 .58676 L F
.55745 .58759 m .55602 .59055 L .55428 .5896 L F
.95 .925 .745 r
.55745 .58759 m .55655 .58676 L .55825 .58362 L F
.583 .308 .465 r
.51674 .78953 m .51345 .79227 L .51617 .78878 L F
.841 .888 .874 r
.70653 .52089 m .70961 .5199 L .70879 .51915 L F
.758 .884 .936 r
.70961 .5199 m .71149 .51702 L .70879 .51915 L F
.70961 .5199 m .71237 .51816 L .71149 .51702 L F
.977 .92 .619 r
.56769 .76991 m .56921 .76807 L .56908 .76664 L F
.56769 .76991 m .56839 .77036 L .56921 .76807 L F
.587 .595 .827 r
.28897 .62983 m .28539 .62715 L .28739 .62674 L F
.593 .614 .842 r
.29108 .62926 m .28897 .62983 L .28739 .62674 L F
.702 .683 .829 r
.55778 .60175 m .55425 .60135 L .55462 .59902 L F
.778 .702 .779 r
.57934 .72472 m .57571 .72535 L .57809 .72236 L F
.431 0 0 r
.57934 .72472 m .57796 .72551 L .57571 .72535 L F
.41 0 0 r
.5815 .72617 m .57796 .72551 L .57934 .72472 L F
.867 .711 .687 r
.77193 .60806 m .77419 .60771 L .77241 .60678 L F
.77193 .60806 m .77343 .6102 L .77419 .60771 L F
.186 0 0 r
.46024 .65358 m .45895 .6537 L .46076 .65337 L F
.771 .495 .516 r
.54418 .62508 m .5421 .62643 L .54279 .62415 L F
.54418 .62508 m .54559 .62683 L .5421 .62643 L F
0 0 .171 r
.54653 .62254 m .54559 .62683 L .54418 .62508 L F
0 0 0 r
.69518 .52275 m .69284 .52522 L .6941 .52393 L F
.829 .81 .322 r
.6959 .51957 m .69518 .52275 L .69578 .5222 L F
0 0 0 r
.69578 .5222 m .69518 .52275 L .6941 .52393 L F
.277 .743 .946 r
.35506 .59098 m .35312 .59146 L .35118 .59054 L F
.711 .393 .437 r
.48137 .81519 m .48496 .8153 L .48293 .8163 L F
.018 .542 .859 r
.48496 .8153 m .48346 .81609 L .48293 .8163 L F
.637 .207 .209 r
.48316 .81612 m .48496 .8153 L .48137 .81519 L F
.52 .881 .98 r
.4828 .81614 m .48293 .8163 L .48346 .81609 L F
.637 .207 .209 r
.48329 .81618 m .48346 .81609 L .48316 .81612 L F
.48346 .81609 m .48496 .8153 L .48316 .81612 L F
.698 .547 .678 r
.48356 .81289 m .48373 .81591 L .48586 .812 L F
.637 .207 .209 r
.48376 .81642 m .48496 .8153 L .48329 .81618 L F
.698 .547 .678 r
.48373 .81591 m .48376 .81642 L .48402 .81586 L F
.48373 .81591 m .48402 .81586 L .48586 .812 L F
.493 .42 .703 r
.48309 .81177 m .48368 .81591 L .48137 .81519 L F
.52 .881 .98 r
.48349 .81599 m .48346 .81609 L .48408 .81585 L F
.48316 .81612 m .48346 .81609 L .48349 .81599 L F
.493 .42 .703 r
.48368 .81591 m .48376 .81642 L .48316 .81612 L F
.48368 .81591 m .48316 .81612 L .48137 .81519 L F
.52 .881 .98 r
.4828 .81614 m .48316 .81612 L .48349 .81599 L F
.737 .594 .696 r
.48586 .812 m .48402 .81586 L .48309 .81177 L F
.48402 .81586 m .48401 .81586 L .48309 .81177 L F
.018 .542 .859 r
.48496 .8153 m .48548 .81521 L .48346 .81609 L F
.737 .594 .696 r
.48401 .81588 m .4837 .81602 L .48368 .81591 L F
.48401 .81586 m .48368 .81591 L .48309 .81177 L F
.52 .881 .98 r
.4828 .81614 m .48408 .81585 L .48325 .816 L F
.737 .594 .696 r
.48401 .81588 m .48368 .81591 L .48401 .81586 L F
.018 .542 .859 r
.48548 .81521 m .48589 .81515 L .48407 .81585 L F
.48548 .81521 m .48407 .81585 L .48346 .81609 L F
.52 .881 .98 r
.48341 .81595 m .48408 .81585 L .48589 .81515 L F
.48325 .816 m .48402 .81586 L .48341 .81595 L F
.48402 .81586 m .48408 .81585 L .48341 .81595 L F
.737 .594 .696 r
.48402 .81586 m .48401 .81588 L .48401 .81586 L F
.52 .881 .98 r
.48235 .81561 m .48272 .81605 L .48589 .81515 L F
.48272 .81605 m .4828 .81614 L .48341 .81595 L F
.48272 .81605 m .48341 .81595 L .48589 .81515 L F
.737 .594 .696 r
.48401 .81588 m .48376 .81642 L .4837 .81602 L F
.018 .542 .859 r
.48496 .8153 m .48752 .81597 L .48589 .81515 L F
.643 .614 .805 r
.55313 .71352 m .556 .71407 L .55477 .71082 L F
.064 .046 .523 r
.55313 .71352 m .55464 .71572 L .556 .71407 L F
.55313 .71352 m .55325 .71692 L .55464 .71572 L F
.618 .342 .477 r
.60625 .59326 m .60614 .59494 L .60265 .59599 L F
.569 .256 .398 r
.60854 .59333 m .60614 .59494 L .60625 .59326 L F
.61 .696 .904 r
.47598 .76648 m .47415 .76603 L .47579 .76538 L F
.256 .476 .88 r
.47579 .76538 m .47812 .76658 L .47598 .76648 L F
.038 0 .365 r
.47812 .76658 m .47697 .76955 L .47598 .76648 L F
.886 .948 .844 r
.70123 .53023 m .70372 .52927 L .70246 .52804 L F
.507 .659 .929 r
.41826 .694 m .4178 .69611 L .41644 .69387 L F
.41826 .694 m .41983 .69596 L .4178 .69611 L F
.631 .665 .864 r
.25441 .63371 m .25797 .63548 L .25662 .63294 L F
.361 .097 .371 r
.2554 .63839 m .25736 .63799 L .25797 .63548 L F
.669 .687 .858 r
.25662 .63294 m .25797 .63548 L .26015 .63428 L F
.463 .188 .409 r
.25797 .63548 m .25736 .63799 L .25953 .63696 L F
.43 .189 .446 r
.25797 .63548 m .25953 .63696 L .26015 .63428 L F
0 0 0 r
.49318 .69528 m .49294 .69555 L .49214 .69571 L F
.111 .664 .757 r
.49421 .69562 m .49214 .69571 L .49175 .69579 L F
0 0 0 r
.49294 .69555 m .49097 .69781 L .49214 .69571 L F
.111 .664 .757 r
.49175 .69579 m .49214 .69571 L .48985 .69591 L F
.908 .916 .813 r
.49378 .69393 m .49421 .69562 L .49563 .69443 L F
.374 .171 .472 r
.53977 .73394 m .54187 .73353 L .54247 .73066 L F
.363 .261 .603 r
.53977 .73394 m .54147 .73558 L .54187 .73353 L F
.53977 .73394 m .54009 .73635 L .54147 .73558 L F
.714 .237 .114 r
.47379 .68867 m .47609 .69072 L .47743 .68967 L F
.565 .052 0 r
.47743 .68967 m .47609 .69072 L .47955 .69085 L F
.566 .058 .006 r
.47743 .68967 m .47955 .69085 L .48273 .69098 L F
0 0 .29 r
.61117 .50917 m .61258 .50765 L .61237 .50573 L F
0 0 .201 r
.61087 .51128 m .61258 .50765 L .61117 .50917 L F
.718 .773 .896 r
.56525 .71924 m .56873 .71956 L .56675 .72076 L F
.408 .159 .422 r
.61688 .49761 m .61924 .49687 L .61911 .49449 L F
.336 .088 .382 r
.61911 .49449 m .62138 .4941 L .62144 .49182 L F
.321 .097 .41 r
.61911 .49449 m .62107 .49598 L .62138 .4941 L F
.61911 .49449 m .61924 .49687 L .62107 .49598 L F
.973 .739 .523 r
.49955 .77582 m .49921 .77842 L .4979 .77784 L F
.656 .861 .978 r
.48016 .63509 m .47657 .6349 L .47829 .63379 L F
.713 .816 .929 r
.48228 .63369 m .48016 .63509 L .47829 .63379 L F
.029 .08 .581 r
.47243 .77241 m .47261 .77675 L .47379 .77472 L F
.539 .31 .516 r
.47261 .77675 m .47312 .77834 L .47621 .77747 L F
.961 .704 .501 r
.73031 .49688 m .7317 .49795 L .73027 .4946 L F
.972 .794 .603 r
.7301 .4992 m .7317 .49795 L .73031 .49688 L F
.7301 .4992 m .73126 .50015 L .7317 .49795 L F
.57 .653 .892 r
.48029 .64933 m .48403 .65132 L .48303 .64889 L F
.649 .643 .831 r
.48303 .64889 m .48403 .65132 L .48676 .65072 L F
.462 .293 .566 r
.28605 .61841 m .28623 .62167 L .28412 .62152 L F
.453 .41 .721 r
.28623 .62167 m .28645 .62324 L .28412 .62152 L F
.517 .404 .664 r
.28412 .62152 m .28645 .62324 L .2844 .62358 L F
.579 .334 .51 r
.50679 .81461 m .50624 .81218 L .50479 .81309 L F
.584 .89 .989 r
.50882 .81166 m .50624 .81218 L .50894 .8126 L F
.614 .38 .539 r
.50679 .81461 m .50894 .8126 L .50624 .81218 L F
.391 .671 .971 r
.3413 .6023 m .34207 .60106 L .3401 .60102 L F
.3413 .6023 m .34341 .60248 L .34207 .60106 L F
.727 .778 .893 r
.40093 .71326 m .40408 .71263 L .40195 .71222 L F
.106 .66 .772 r
.40408 .71263 m .40492 .71246 L .40195 .71222 L F
.40408 .71263 m .40642 .71248 L .40492 .71246 L F
.715 .515 .617 r
.48894 .78417 m .49151 .78405 L .49165 .78238 L F
.546 .368 .591 r
.49165 .78238 m .4948 .78302 L .49409 .78108 L F
.49165 .78238 m .49151 .78405 L .4948 .78302 L F
.745 .692 .801 r
.52458 .7729 m .52584 .77572 L .5224 .77607 L F
.501 .451 .734 r
.52656 .77273 m .52584 .77572 L .52458 .7729 L F
.52656 .77273 m .52659 .77612 L .52584 .77572 L F
.648 .303 .373 r
.52584 .77572 m .52659 .77612 L .52758 .77765 L F
.637 .376 .507 r
.51918 .78745 m .51909 .78973 L .51674 .78953 L F
.585 .125 .126 r
.41236 .71162 m .41066 .7131 L .40853 .71244 L F
0 0 0 r
.41233 .71178 m .41236 .71162 L .41418 .71067 L F
.41233 .71178 m .41066 .7131 L .41236 .71162 L F
.599 .816 .983 r
.67282 .47554 m .67117 .47732 L .67015 .47642 L F
.67282 .47554 m .67364 .47665 L .67117 .47732 L F
.492 0 0 r
.75569 .59646 m .75889 .59863 L .76001 .59911 L F
.964 .917 .712 r
.76001 .59911 m .75889 .59863 L .75916 .59747 L F
.652 .641 .826 r
.75889 .59863 m .76001 .59911 L .75916 .59747 L F
.75889 .59863 m .76193 .60082 L .76001 .59911 L F
.712 .296 .254 r
.55904 .76981 m .56302 .77036 L .56151 .77215 L F
.423 .284 .586 r
.56302 .77036 m .56318 .77339 L .56481 .77242 L F
.711 .293 .253 r
.56302 .77036 m .56481 .77242 L .56151 .77215 L F
.44 .82 .99 r
.52314 .81015 m .52787 .8104 L .52643 .80962 L F
.944 .865 .732 r
.52643 .80962 m .52787 .8104 L .52855 .8084 L F
.48 .467 .766 r
.51776 .64828 m .51575 .64993 L .5148 .64651 L F
.529 .556 .827 r
.51776 .64828 m .51828 .6512 L .51575 .64993 L F
.702 .306 .295 r
.50894 .8126 m .51197 .81388 L .50882 .81166 L F
.524 .123 .223 r
.43153 .7053 m .43012 .70731 L .42815 .70697 L F
.385 0 .114 r
.43373 .70504 m .43012 .70731 L .43153 .7053 L F
.499 .611 .895 r
.77596 .58286 m .77779 .58098 L .77588 .58116 L F
.77596 .58286 m .77858 .58335 L .77779 .58098 L F
.285 .013 .313 r
.49667 .80943 m .49417 .81126 L .49724 .80683 L F
.333 .053 .33 r
.49806 .80889 m .49724 .80683 L .49904 .80618 L F
.49806 .80889 m .49667 .80943 L .49724 .80683 L F
.402 .618 .939 r
.31552 .58609 m .31486 .58769 L .313 .58551 L F
.481 .709 .97 r
.31552 .58609 m .31693 .58751 L .31486 .58769 L F
.346 .068 .34 r
.62144 .49182 m .62367 .49139 L .62412 .48912 L F
.414 .103 .326 r
.62367 .49139 m .62642 .48869 L .62412 .48912 L F
.501 .266 .491 r
.66356 .48786 m .6636 .48785 L .6645 .48572 L F
.824 .868 .425 r
.66531 .48379 m .6645 .48572 L .66442 .48658 L F
0 0 .459 r
.66591 .48729 m .66442 .48658 L .6645 .48572 L F
.66591 .48729 m .66464 .4889 L .66442 .48658 L F
.501 .266 .491 r
.6636 .48785 m .66591 .48729 L .6645 .48572 L F
.824 .868 .425 r
.6658 .48228 m .6645 .48572 L .66531 .48379 L F
.902 .934 .824 r
.55337 .77255 m .55665 .76995 L .55517 .7709 L F
.652 .184 .128 r
.55904 .76981 m .55775 .77017 L .55665 .76995 L F
.55775 .77017 m .55681 .77044 L .55669 .77008 L F
.55775 .77017 m .55669 .77008 L .55665 .76995 L F
.55904 .76981 m .55756 .7716 L .55517 .7709 L F
.263 .372 .787 r
.55663 .76612 m .55836 .77023 L .55959 .76889 L F
.55836 .77023 m .55852 .77061 L .55874 .77026 L F
.55836 .77023 m .55874 .77026 L .55959 .76889 L F
.732 .64 .756 r
.55435 .76918 m .55768 .77032 L .55663 .76612 L F
.55768 .77032 m .55852 .77061 L .55836 .77023 L F
.55768 .77032 m .55836 .77023 L .55663 .76612 L F
.652 .184 .128 r
.55681 .77044 m .55517 .7709 L .55565 .7706 L F
.55681 .77044 m .55565 .7706 L .55665 .76995 L F
.472 .024 .103 r
.49967 .80412 m .50162 .80511 L .49904 .80618 L F
.49967 .80412 m .50184 .80426 L .50162 .80511 L F
.715 .488 .58 r
.49409 .78108 m .49712 .77881 L .49393 .77852 L F
.49409 .78108 m .49699 .78127 L .49712 .77881 L F
.702 .589 .726 r
.49699 .78127 m .49921 .77842 L .49712 .77881 L F
.43 .324 .633 r
.54886 .61546 m .54735 .61864 L .54662 .61646 L F
.54886 .61546 m .54921 .61809 L .54735 .61864 L F
.194 0 .326 r
.54921 .61809 m .54734 .61974 L .54735 .61864 L F
.569 .913 .699 r
.47415 .76603 m .47414 .76572 L .47579 .76538 L F
.47415 .76603 m .47294 .7667 L .47414 .76572 L F
.987 .819 .589 r
.65693 .52008 m .65629 .51676 L .65785 .51794 L F
.42 .801 .991 r
.5222 .74572 m .52086 .74491 L .51842 .74529 L F
.687 .915 .972 r
.52289 .74393 m .5222 .74572 L .52429 .74486 L F
.52289 .74393 m .52086 .74491 L .5222 .74572 L F
0 0 0 r
.52873 .76611 m .53119 .76383 L .5295 .76508 L F
.648 .287 .344 r
.50479 .81309 m .50107 .81452 L .50338 .81469 L F
.685 .231 .168 r
.50338 .81469 m .50679 .81461 L .50479 .81309 L F
.577 .552 .79 r
.57685 .70279 m .57439 .70156 L .57742 .70085 L F
.635 .877 .986 r
.49938 .76207 m .49586 .76219 L .49797 .76114 L F
.49797 .76114 m .49586 .76219 L .49938 .76207 L F
.49797 .76114 m .49938 .76207 L .49738 .76239 L F
.475 .809 .999 r
.49797 .76114 m .50142 .76153 L .49938 .76207 L F
.493 .787 .997 r
.49938 .76207 m .50142 .76153 L .49738 .76239 L F
.029 .123 .629 r
.51553 .76987 m .51614 .77336 L .5171 .77222 L F
0 0 .57 r
.51614 .77336 m .51764 .77486 L .5171 .77222 L F
.728 .814 .918 r
.51764 .77486 m .51882 .77586 L .52104 .77485 L F
.666 .852 .971 r
.51764 .77486 m .52104 .77485 L .51977 .77371 L F
.146 0 .056 r
.51824 .77526 m .51764 .77486 L .51977 .77371 L F
0 0 .57 r
.51649 .77411 m .51745 .77614 L .51764 .77486 L F
.146 0 .056 r
.51659 .77693 m .51764 .77486 L .51824 .77526 L F
0 0 .57 r
.51614 .77336 m .51649 .77411 L .51764 .77486 L F
.407 0 0 r
.42735 .64993 m .42936 .65049 L .43076 .64908 L F
.577 .145 .184 r
.42936 .65049 m .433 .64921 L .43076 .64908 L F
.138 0 .01 r
.34187 .63776 m .33911 .63984 L .3404 .6379 L F
.368 .794 .971 r
.30636 .58481 m .30556 .58558 L .30413 .5851 L F
.30636 .58481 m .30745 .58529 L .30556 .58558 L F
.506 .761 .988 r
.6756 .53739 m .67685 .53592 L .67478 .53553 L F
.6756 .53739 m .67805 .5371 L .67685 .53592 L F
.477 0 0 r
.44234 .66355 m .44079 .66442 L .43899 .66353 L F
.032 0 0 r
.44271 .66399 m .44234 .66355 L .44483 .66307 L F
.44271 .66399 m .44079 .66442 L .44234 .66355 L F
.937 .909 .768 r
.78533 .60069 m .78437 .59995 L .78285 .60132 L F
.892 .804 .756 r
.78285 .60132 m .78343 .60409 L .78533 .60069 L F
.539 .495 .755 r
.28645 .62324 m .28539 .62715 L .2844 .62358 L F
.28645 .62324 m .28739 .62674 L .28539 .62715 L F
.657 .103 0 r
.52855 .8084 m .52586 .80711 L .52643 .80962 L F
.617 .194 .216 r
.24206 .63481 m .24451 .63487 L .24296 .63388 L F
.548 .278 .458 r
.38906 .66024 m .3914 .65987 L .39181 .65785 L F
.546 .277 .46 r
.3914 .65987 m .394 .65763 L .39181 .65785 L F
.771 .873 .923 r
.25032 .66762 m .25104 .66506 L .24882 .66575 L F
.25032 .66762 m .25275 .66595 L .25104 .66506 L F
.761 .442 .446 r
.63848 .49971 m .63509 .49981 L .63452 .49806 L F
.702 .621 .763 r
.63933 .50289 m .63509 .49981 L .63848 .49971 L F
.325 .184 .53 r
.64064 .49999 m .63933 .50289 L .63848 .49971 L F
.707 .462 .552 r
.57605 .60449 m .57292 .60674 L .57299 .60434 L F
.57605 .60449 m .57654 .60699 L .57292 .60674 L F
.582 .46 .679 r
.57605 .60449 m .57883 .60691 L .57654 .60699 L F
.57605 .60449 m .57861 .60429 L .57883 .60691 L F
0 0 0 r
.62166 .58045 m .62034 .58366 L .62074 .58199 L F
.789 .592 .634 r
.5898 .57611 m .59109 .57904 L .59106 .57653 L F
.263 0 0 r
.3258 .62935 m .32789 .62888 L .32931 .62723 L F
.351 0 .094 r
.32789 .62888 m .33142 .62668 L .32931 .62723 L F
.742 .254 .08 r
.53469 .76469 m .53703 .76693 L .53834 .76654 L F
.349 .484 .854 r
.50868 .63781 m .50839 .64048 L .50705 .63751 L F
.50868 .63781 m .50996 .64068 L .50839 .64048 L F
.494 .58 .87 r
.53539 .8062 m .53681 .8039 L .5341 .80439 L F
.53539 .8062 m .53771 .80659 L .53681 .8039 L F
.367 0 .042 r
.43692 .66406 m .4358 .6656 L .43329 .66592 L F
.031 0 0 r
.43744 .66487 m .43692 .66406 L .43899 .66353 L F
.43744 .66487 m .4358 .6656 L .43692 .66406 L F
.526 .336 .566 r
.70853 .50043 m .70861 .50286 L .71088 .5 L F
.71088 .5 m .70861 .50286 L .70853 .50043 L F
.882 .541 .399 r
.56193 .7112 m .56375 .7082 L .56421 .71086 L F
.713 .496 .593 r
.56421 .71086 m .56393 .7135 L .56193 .7112 L F
.596 .474 .684 r
.56609 .70779 m .56421 .71086 L .56375 .7082 L F
.56609 .70779 m .5661 .71033 L .56421 .71086 L F
.639 .562 .752 r
.56791 .70679 m .56856 .70881 L .56615 .71023 L F
.499 .396 .668 r
.56791 .70679 m .5661 .71036 L .5661 .71033 L F
.56791 .70679 m .5661 .71033 L .56609 .70779 L F
.639 .562 .752 r
.56791 .70679 m .56615 .71023 L .56579 .71044 L F
.56856 .70881 m .56919 .71076 L .5659 .71045 L F
.56856 .70881 m .5659 .71045 L .56579 .71044 L F
.596 .474 .684 r
.5661 .71033 m .5661 .71036 L .56601 .71039 L F
.5661 .71033 m .56601 .71039 L .56421 .71086 L F
0 0 0 r
.5661 .71036 m .56579 .71044 L .56421 .71086 L F
.703 .539 .663 r
.56579 .71044 m .56393 .7135 L .56421 .71086 L F
.661 .256 .266 r
.54467 .73086 m .54696 .73272 L .54832 .73087 L F
.718 .326 .305 r
.54696 .73272 m .55048 .73306 L .54832 .73087 L F
.752 .283 .133 r
.54832 .73087 m .55048 .73306 L .55197 .73306 L F
.422 .43 .762 r
.71083 .48581 m .71166 .48995 L .71374 .48793 L F
.419 0 0 r
.71625 .49134 m .71431 .49104 L .71166 .48995 L F
.395 .386 .731 r
.71166 .48995 m .71431 .49104 L .71374 .48793 L F
.56 .547 .797 r
.38678 .68857 m .38762 .68511 L .38585 .68645 L F
.38678 .68857 m .3888 .68829 L .38762 .68511 L F
.523 .611 .882 r
.39735 .71067 m .39767 .70707 L .39527 .70726 L F
.39735 .71067 m .39967 .71038 L .39767 .70707 L F
.658 .638 .819 r
.66417 .52516 m .66746 .52639 L .66664 .52454 L F
.667 .683 .856 r
.66664 .52454 m .66746 .52639 L .66974 .52546 L F
.871 .983 .839 r
.55237 .7778 m .5534 .77499 L .55357 .77755 L F
0 0 0 r
.55089 .7797 m .55237 .7778 L .55357 .77755 L F
.484 .404 .691 r
.38414 .67742 m .38554 .67466 L .38337 .67529 L F
.38414 .67742 m .38611 .67701 L .38554 .67466 L F
.421 .404 .734 r
.38414 .67742 m .38661 .67997 L .38611 .67701 L F
.429 .448 .778 r
.75479 .59291 m .75801 .59516 L .75569 .59646 L F
.409 .403 .741 r
.75801 .59516 m .75889 .59863 L .75569 .59646 L F
.987 .729 .441 r
.50639 .79563 m .50657 .79817 L .50517 .79489 L F
.627 .4 .553 r
.50993 .79558 m .50657 .79817 L .50639 .79563 L F
.745 .401 .4 r
.58785 .69066 m .59085 .68924 L .588 .68909 L F
.58785 .69066 m .59144 .69109 L .59085 .68924 L F
.892 .893 .823 r
.65034 .50986 m .6541 .50683 L .6532 .50741 L F
.824 .873 .881 r
.71134 .47391 m .70838 .47475 L .71056 .47234 L F
.505 .578 .862 r
.7126 .47138 m .71134 .47391 L .71056 .47234 L F
0 0 0 r
.74423 .50335 m .74196 .50621 L .74274 .50506 L F
.74423 .50335 m .74341 .5047 L .74196 .50621 L F
.567 .892 .632 r
.74341 .5047 m .74019 .50754 L .74196 .50621 L F
.563 .847 .997 r
.67931 .47625 m .67686 .47688 L .67602 .47606 L F
.516 .303 .528 r
.51084 .69448 m .51272 .69615 L .51308 .69405 L F
0 .043 .548 r
.55728 .73702 m .55804 .73771 L .5591 .73886 L F
.815 .356 .138 r
.55946 .74095 m .5591 .73886 L .55804 .73771 L F
.55946 .74095 m .56089 .74145 L .5591 .73886 L F
.652 .633 .818 r
.25099 .61811 m .25172 .6193 L .25368 .61858 L F
.532 .577 .846 r
.25172 .6193 m .25496 .62115 L .25368 .61858 L F
.389 .128 .392 r
.62144 .49182 m .62349 .49332 L .62367 .49139 L F
.62144 .49182 m .62138 .4941 L .62349 .49332 L F
.71 .214 0 r
.47042 .80118 m .47296 .80393 L .4719 .80329 L F
.956 .623 .337 r
.47296 .80393 m .4721 .80572 L .4719 .80329 L F
.47296 .80393 m .47362 .80712 L .4721 .80572 L F
.933 .593 .366 r
.47296 .80393 m .4738 .80671 L .47362 .80712 L F
.379 .045 .268 r
.5772 .69153 m .57958 .69097 L .57989 .68942 L F
.538 .182 .312 r
.57989 .68942 m .57958 .69097 L .58295 .69051 L F
.247 0 0 r
.40629 .65622 m .40557 .65538 L .40425 .65684 L F
.40629 .65622 m .40793 .65519 L .40557 .65538 L F
.552 .435 .674 r
.2464 .61002 m .24853 .60968 L .24824 .607 L F
.489 .386 .664 r
.24697 .6133 m .24853 .60968 L .2464 .61002 L F
.427 .044 .208 r
.27537 .58702 m .27758 .58674 L .27912 .58437 L F
.246 0 0 r
.27758 .58674 m .28127 .58461 L .27912 .58437 L F
.788 .391 .302 r
.52924 .78371 m .52975 .78244 L .52782 .78174 L F
.466 .163 .367 r
.53161 .78367 m .52975 .78244 L .52924 .78371 L F
.53161 .78367 m .53282 .78118 L .52975 .78244 L F
.432 .175 .422 r
.76268 .57394 m .76484 .57518 L .76489 .57325 L F
.76268 .57394 m .76244 .57576 L .76484 .57518 L F
.522 .234 .418 r
.53308 .77161 m .53032 .77062 L .53265 .77095 L F
.53308 .77161 m .53191 .77218 L .53032 .77062 L F
.59 .614 .844 r
.75912 .58465 m .7605 .58124 L .75827 .58305 L F
.75912 .58465 m .76139 .5842 L .7605 .58124 L F
.453 .877 .923 r
.46067 .64184 m .46278 .64113 L .46408 .64121 L F
.325 .807 .888 r
.46408 .64121 m .46526 .64061 L .46616 .64002 L F
.46408 .64121 m .46278 .64113 L .46526 .64061 L F
.608 .438 .626 r
.49907 .69462 m .4994 .69718 L .50217 .69469 L F
.636 .786 .954 r
.72042 .50338 m .71928 .50238 L .71903 .49935 L F
.72042 .50338 m .71777 .50324 L .71928 .50238 L F
.357 .743 .987 r
.70628 .51018 m .70521 .51089 L .70429 .51118 L F
.70628 .51018 m .70731 .51098 L .70521 .51089 L F
.373 .056 .294 r
.634 .48344 m .63624 .48281 L .63674 .48023 L F
.417 .151 .401 r
.63674 .48023 m .63862 .47984 L .63914 .47814 L F
.446 .139 .35 r
.63624 .48281 m .63862 .47984 L .63674 .48023 L F
.754 .669 .767 r
.66697 .50035 m .66816 .50346 L .66483 .50301 L F
.604 .588 .809 r
.67003 .50282 m .66816 .50346 L .66697 .50035 L F
0 0 0 r
.67003 .50282 m .66887 .50559 L .66816 .50346 L F
.628 .37 .508 r
.63452 .49806 m .63509 .49981 L .63227 .50003 L F
.59 .35 .521 r
.59467 .59579 m .59151 .59877 L .59209 .59624 L F
.615 .804 .972 r
.69077 .47528 m .68853 .47604 L .68766 .47488 L F
.516 .459 .731 r
.63839 .51664 m .63656 .51549 L .63869 .51473 L F
0 .062 .552 r
.65881 .52264 m .65938 .5231 L .65772 .52178 L F
.65881 .52264 m .66048 .52414 L .65938 .5231 L F
.492 .233 .449 r
.2933 .6102 m .29285 .61214 L .29083 .61245 L F
.466 .209 .44 r
.29497 .61158 m .2933 .6102 L .29577 .60992 L F
.29497 .61158 m .29285 .61214 L .2933 .6102 L F
.726 .537 .636 r
.25325 .64351 m .25677 .64389 L .25572 .63959 L F
.459 .432 .741 r
.25572 .63959 m .25829 .63974 L .2554 .63839 L F
.747 .55 .629 r
.25572 .63959 m .25932 .6435 L .25829 .63974 L F
.25572 .63959 m .25677 .64389 L .25932 .6435 L F
.91 .727 .641 r
.67664 .53012 m .67604 .53436 L .67767 .53474 L F
.827 .387 .191 r
.67767 .53474 m .67685 .53592 L .67604 .53436 L F
.843 .852 .851 r
.67767 .53474 m .67908 .53068 L .6802 .532 L F
.67767 .53474 m .67604 .53436 L .67908 .53068 L F
.827 .387 .191 r
.67767 .53474 m .67685 .53592 L .67604 .53436 L F
.565 .058 .008 r
.2521 .65026 m .25144 .65141 L .25053 .64904 L F
.2521 .65026 m .256 .65171 L .25144 .65141 L F
.896 .719 .656 r
.63951 .53107 m .639 .53332 L .64138 .53271 L F
.934 .769 .654 r
.63884 .53573 m .64138 .53271 L .639 .53332 L F
.63884 .53573 m .64018 .5367 L .64138 .53271 L F
.558 .296 .475 r
.51018 .78451 m .51209 .78637 L .51198 .78389 L F
.51018 .78451 m .50965 .7868 L .51209 .78637 L F
.703 .287 .255 r
.52289 .74393 m .52639 .74426 L .5242 .74221 L F
.191 0 0 r
.28127 .58461 m .28358 .58454 L .28476 .58412 L F
0 0 0 r
.28358 .58454 m .28693 .58357 L .28476 .58412 L F
.664 .629 .805 r
.63509 .49981 m .63271 .5022 L .63227 .50003 L F
.444 .745 .992 r
.68135 .53722 m .68286 .53599 L .68032 .53644 L F
.68135 .53722 m .68396 .5371 L .68286 .53599 L F
.37 .231 .559 r
.41465 .67411 m .41462 .67668 L .41286 .67475 L F
.324 .224 .584 r
.41286 .67475 m .41462 .67668 L .41306 .67714 L F
.666 .364 .452 r
.40195 .71222 m .39967 .71038 L .40093 .71326 L F
.369 0 0 r
.31534 .63239 m .31748 .63243 L .31887 .63181 L F
.596 .129 .116 r
.31887 .63181 m .31748 .63243 L .3211 .63239 L F
.589 .233 .333 r
.41316 .65371 m .41597 .65249 L .41379 .65289 L F
0 .18 .712 r
.25684 .64617 m .25898 .64864 L .2583 .64909 L F
0 0 0 r
.25898 .64864 m .25675 .65084 L .2583 .64909 L F
.547 .51 .766 r
.50032 .6466 m .50175 .64354 L .49926 .64408 L F
.50032 .6466 m .50268 .64664 L .50175 .64354 L F
.72 .512 .609 r
.741 .49289 m .74058 .49165 L .74178 .49211 L F
.641 .805 .962 r
.76297 .60411 m .76633 .60452 L .76565 .60321 L F
.738 .638 .749 r
.76297 .60411 m .76603 .60593 L .76633 .60452 L F
.067 0 0 r
.74436 .49104 m .74178 .49211 L .74155 .49203 L F
.74436 .49104 m .74155 .49203 L .74351 .49118 L F
.74436 .49104 m .74273 .49191 L .74178 .49211 L F
.606 .6 .819 r
.74221 .4871 m .74394 .49026 L .74058 .49165 L F
.74394 .49026 m .74436 .49104 L .74351 .49118 L F
.74394 .49026 m .74351 .49118 L .74058 .49165 L F
.228 .173 .585 r
.74382 .49104 m .74383 .49391 L .74296 .49233 L F
.74342 .49136 m .74296 .49233 L .74273 .49191 L F
.74382 .49104 m .74296 .49233 L .74342 .49136 L F
.416 .502 .839 r
.74396 .48691 m .74436 .49104 L .74221 .4871 L F
.74396 .48691 m .74527 .48988 L .74436 .49104 L F
.618 .801 .97 r
.74436 .49104 m .74527 .48988 L .74273 .49191 L F
.228 .173 .585 r
.74527 .48988 m .74504 .49051 L .74382 .49104 L F
.74504 .49051 m .74383 .49391 L .74382 .49104 L F
.067 0 0 r
.74351 .49118 m .74155 .49203 L .74058 .49165 L F
.661 .448 .585 r
.74273 .49191 m .741 .49289 L .74178 .49211 L F
.091 0 .399 r
.76633 .60452 m .76791 .60464 L .76565 .60321 L F
.908 .596 .444 r
.76843 .60388 m .76733 .60248 L .76807 .60502 L F
.76733 .60248 m .76575 .60046 L .76774 .60438 L F
.76733 .60248 m .76774 .60438 L .76807 .60502 L F
.091 0 .399 r
.76633 .60452 m .76603 .60593 L .76781 .60471 L F
.616 .44 .621 r
.76565 .60321 m .76807 .60502 L .76575 .60046 L F
.215 .422 .848 r
.76565 .60321 m .76791 .60464 L .76684 .60222 L F
.212 .418 .846 r
.76684 .60222 m .76791 .60466 L .76565 .60321 L F
.372 .494 .852 r
.76603 .60593 m .769 .60693 L .76801 .60486 L F
.76786 .60467 m .76801 .60486 L .76791 .60464 L F
.212 .418 .846 r
.76786 .60467 m .76807 .60502 L .76767 .60473 L F
.76797 .6048 m .76807 .60502 L .76786 .60467 L F
.372 .494 .852 r
.76603 .60593 m .76801 .60486 L .76786 .60467 L F
.212 .418 .846 r
.76791 .60466 m .76797 .6048 L .76786 .60467 L F
.091 0 .399 r
.76779 .60463 m .76781 .60469 L .76791 .60464 L F
.76781 .60469 m .76786 .60467 L .76791 .60464 L F
.212 .418 .846 r
.76791 .60466 m .76767 .60473 L .76565 .60321 L F
.091 0 .399 r
.76781 .60469 m .76781 .60471 L .76786 .60467 L F
.76633 .60452 m .76781 .60471 L .76779 .60463 L F
.748 .588 .677 r
.74423 .50335 m .74076 .50071 L .74328 .49991 L F
.74423 .50335 m .74274 .50506 L .74076 .50071 L F
.587 .538 .767 r
.74579 .49929 m .74423 .50335 L .74328 .49991 L F
.74579 .49929 m .74663 .5028 L .74423 .50335 L F
.289 0 0 r
.74663 .5028 m .74341 .5047 L .74423 .50335 L F
.41 0 0 r
.51445 .69998 m .51069 .70105 L .51203 .6998 L F
.906 .647 .534 r
.47593 .81213 m .47778 .81248 L .47779 .81504 L F
.944 .806 .677 r
.64155 .52325 m .64303 .5251 L .64325 .523 L F
.909 .8 .727 r
.63975 .52715 m .64303 .5251 L .64155 .52325 L F
.63975 .52715 m .64113 .52832 L .64303 .5251 L F
.761 .696 .789 r
.54081 .61845 m .53728 .61824 L .53965 .6152 L F
.857 .561 .487 r
.53928 .62051 m .53728 .61824 L .54081 .61845 L F
.728 .679 .802 r
.54319 .61578 m .54081 .61845 L .53965 .6152 L F
.084 .081 .555 r
.49496 .77046 m .49654 .77212 L .49818 .76955 L F
.613 .604 .818 r
.66417 .52516 m .66544 .52181 L .66299 .52257 L F
.66417 .52516 m .66664 .52454 L .66544 .52181 L F
.099 0 0 r
.33733 .64064 m .33457 .64258 L .33522 .64122 L F
.617 .752 .942 r
.69572 .47434 m .6945 .47691 L .6932 .47483 L F
.69572 .47434 m .69682 .47632 L .6945 .47691 L F
.603 .776 .963 r
.49174 .63365 m .48805 .63287 L .49031 .63207 L F
.637 .777 .948 r
.4939 .63278 m .49174 .63365 L .49031 .63207 L F
.714 .509 .611 r
.55569 .60453 m .552 .60661 L .55225 .60416 L F
.55569 .60453 m .55567 .60697 L .552 .60661 L F
.7 .498 .611 r
.5578 .60634 m .55567 .60697 L .55569 .60453 L F
.492 .314 .568 r
.60518 .57681 m .60757 .57614 L .60735 .57348 L F
.37 .046 .279 r
.60466 .57834 m .60757 .57614 L .60518 .57681 L F
.539 .458 .712 r
.27161 .64441 m .27299 .644 L .2707 .64312 L F
.27161 .64441 m .27395 .64614 L .27299 .644 L F
0 .204 .726 r
.471 .7927 m .4733 .79535 L .47159 .79175 L F
.478 .379 .664 r
.471 .7927 m .47137 .79574 L .4733 .79535 L F
.715 .695 .83 r
.67874 .51405 m .67996 .51739 L .67681 .51767 L F
.084 .28 .764 r
.68045 .51573 m .67996 .51739 L .67874 .51405 L F
.714 .638 .771 r
.68007 .51527 m .67937 .51649 L .67938 .51705 L F
.37 .819 .942 r
.67681 .51767 m .67939 .51744 L .67938 .51705 L F
.67681 .51767 m .67938 .51705 L .67674 .51933 L F
.714 .638 .771 r
.67937 .51649 m .67825 .51846 L .67938 .51705 L F
.37 .819 .942 r
.67939 .51744 m .67996 .51739 L .67938 .51705 L F
.787 .996 .865 r
.67938 .51705 m .67996 .51739 L .68045 .51573 L F
.642 .712 .898 r
.50659 .63526 m .50341 .63427 L .50554 .63396 L F
.098 .482 .897 r
.50554 .63396 m .50679 .63444 L .50659 .63526 L F
.033 .164 .67 r
.50679 .63444 m .50705 .63751 L .50659 .63526 L F
.517 .376 .628 r
.52576 .68585 m .52386 .69049 L .52409 .68823 L F
.677 .239 .201 r
.48444 .6952 m .48318 .69672 L .48116 .69585 L F
.52 .058 .095 r
.48652 .69618 m .48318 .69672 L .48444 .6952 L F
.105 .219 .7 r
.58828 .71381 m .58952 .71288 L .58758 .71087 L F
.797 .837 .882 r
.58952 .71288 m .59264 .71284 L .59162 .71005 L F
.589 .568 .798 r
.59053 .71166 m .5904 .71205 L .58952 .71288 L F
.975 .741 .521 r
.59071 .71401 m .58952 .71288 L .58851 .71383 L F
.797 .837 .882 r
.58952 .71288 m .59071 .71401 L .59264 .71284 L F
.975 .741 .521 r
.59071 .71401 m .58934 .71539 L .58952 .71288 L F
.58952 .71288 m .58934 .71539 L .59071 .71401 L F
.589 .568 .798 r
.5904 .71205 m .58934 .71539 L .58952 .71288 L F
.975 .741 .521 r
.58851 .71383 m .58952 .71288 L .58828 .71381 L F
.463 .43 .736 r
.2554 .63839 m .25829 .63974 L .25736 .63799 L F
.448 .2 .444 r
.59973 .52588 m .60199 .52524 L .60231 .52308 L F
.371 .137 .424 r
.60231 .52308 m .60429 .52235 L .60449 .52037 L F
.418 .175 .436 r
.60231 .52308 m .60413 .52449 L .60429 .52235 L F
.60231 .52308 m .60199 .52524 L .60413 .52449 L F
.779 .939 .932 r
.66584 .47904 m .66259 .47989 L .66397 .47856 L F
.681 .92 .973 r
.66816 .47778 m .66584 .47904 L .66397 .47856 L F
.718 .834 .936 r
.52026 .80255 m .51909 .80345 L .51709 .80375 L F
.647 .298 .367 r
.51709 .80375 m .51909 .80345 L .51903 .80447 L F
.39 .207 .509 r
.52153 .8034 m .51909 .80345 L .52026 .80255 L F
.362 .069 .327 r
.51903 .80447 m .51909 .80345 L .52153 .8034 L F
.636 .388 .526 r
.58463 .60086 m .581 .60383 L .5809 .60183 L F
.499 .031 .074 r
.47867 .69421 m .47738 .69576 L .4751 .69477 L F
.63 .178 .16 r
.48116 .69585 m .47738 .69576 L .47867 .69421 L F
.717 .497 .59 r
.52656 .77273 m .52458 .7729 L .5246 .7703 L F
.32 0 0 r
.433 .64921 m .43525 .64922 L .43643 .64857 L F
.127 .676 .78 r
.43525 .64922 m .43874 .64903 L .43643 .64857 L F
.259 0 0 r
.26771 .58797 m .26922 .58831 L .27092 .58692 L F
.222 0 0 r
.26922 .58831 m .27317 .58684 L .27092 .58692 L F
.586 .84 .993 r
.49727 .63301 m .4939 .63278 L .49605 .63192 L F
.496 .721 .972 r
.49827 .63143 m .49727 .63301 L .49605 .63192 L F
.49827 .63143 m .49949 .63278 L .49727 .63301 L F
.742 .629 .735 r
.75366 .6014 m .75738 .60432 L .75608 .60085 L F
.75366 .6014 m .75499 .60481 L .75738 .60432 L F
.717 .669 .801 r
.75608 .60085 m .75738 .60432 L .75944 .60138 L F
.667 .596 .767 r
.75738 .60432 m .76062 .60483 L .75944 .60138 L F
.757 .723 .821 r
.48577 .63351 m .48228 .63369 L .48458 .63228 L F
.624 .784 .958 r
.48805 .63287 m .48577 .63351 L .48458 .63228 L F
.194 0 .326 r
.54921 .61809 m .5482 .62054 L .54734 .61974 L F
.249 0 .269 r
.5482 .62054 m .54653 .62254 L .54734 .61974 L F
.799 .691 .745 r
.55462 .59902 m .55425 .60135 L .55076 .60095 L F
.807 .641 .677 r
.55425 .60135 m .55225 .60416 L .55076 .60095 L F
.564 .07 .039 r
.67327 .5288 m .67567 .53004 L .67748 .52902 L F
.938 .963 .739 r
.67748 .52902 m .67567 .53004 L .67664 .53012 L F
.533 .253 .436 r
.63862 .47984 m .64145 .47829 L .63914 .47814 L F
.654 .819 .962 r
.67499 .48227 m .67844 .48221 L .67722 .48036 L F
.558 .584 .836 r
.67844 .48221 m .67961 .47954 L .67722 .48036 L F
.67844 .48221 m .68029 .48215 L .67961 .47954 L F
.786 .682 .749 r
.55556 .59292 m .55676 .59614 L .55353 .59583 L F
.788 .676 .741 r
.55676 .59614 m .55462 .59902 L .55353 .59583 L F
0 0 .272 r
.6463 .51102 m .6456 .51328 L .64454 .51339 L F
0 0 .057 r
.6456 .51328 m .64358 .51608 L .64454 .51339 L F
.412 .171 .435 r
.60449 .52037 m .60643 .52163 L .60674 .51952 L F
.60449 .52037 m .60429 .52235 L .60643 .52163 L F
.4 0 0 r
.42017 .7091 m .41865 .7103 L .41642 .71023 L F
.476 .021 .09 r
.42257 .70876 m .41865 .7103 L .42017 .7091 L F
.315 .009 .277 r
.50613 .77759 m .5055 .77485 L .50765 .77579 L F
.50613 .77759 m .50408 .77841 L .5055 .77485 L F
.563 .382 .594 r
.50747 .773 m .50765 .77579 L .5055 .77485 L F
.742 .805 .903 r
.48676 .65072 m .48962 .65023 L .48829 .64864 L F
.692 .714 .865 r
.48829 .64864 m .48962 .65023 L .49177 .64921 L F
.732 .672 .791 r
.56722 .60689 m .56849 .61028 L .5646 .60979 L F
.524 .14 .255 r
.56849 .61028 m .565 .61217 L .5646 .60979 L F
.56849 .61028 m .5669 .61225 L .565 .61217 L F
.577 .513 .747 r
.56944 .60602 m .56849 .61028 L .56722 .60689 L F
.56944 .60602 m .57071 .60956 L .56849 .61028 L F
.72 .378 .399 r
.56849 .61028 m .57012 .61193 L .5669 .61225 L F
.844 .708 .712 r
.57071 .60956 m .57012 .61193 L .56849 .61028 L F
.693 .927 .968 r
.54243 .79844 m .54 .80111 L .53993 .8006 L F
0 0 .539 r
.53985 .79999 m .53993 .8006 L .54032 .80102 L F
.727 .981 .91 r
.54243 .79844 m .53993 .8006 L .53974 .79972 L F
0 0 .539 r
.53974 .79972 m .53993 .8006 L .53985 .79999 L F
.693 .927 .968 r
.54 .80111 m .53991 .8012 L .53993 .8006 L F
.218 .629 .954 r
.54199 .80151 m .53991 .8012 L .53993 .8006 L F
.951 .726 .561 r
.64189 .52209 m .64325 .523 L .64203 .51976 L F
.944 .806 .677 r
.64155 .52325 m .64325 .523 L .64189 .52209 L F
.656 .342 .428 r
.47273 .69417 m .47147 .69687 L .46943 .69625 L F
.56 .239 .38 r
.47559 .69558 m .47273 .69417 L .4751 .69477 L F
.47559 .69558 m .47147 .69687 L .47273 .69417 L F
.45 .617 .921 r
.39234 .70585 m .39394 .70817 L .39527 .70726 L F
.723 .829 .93 r
.71311 .50892 m .71008 .50874 L .71369 .50714 L F
.522 .312 .536 r
.71311 .50892 m .71085 .51183 L .71008 .50874 L F
.71311 .50892 m .7132 .51115 L .71085 .51183 L F
.18 .106 .53 r
.71484 .50514 m .71311 .50892 L .71369 .50714 L F
.71484 .50514 m .71489 .50767 L .71311 .50892 L F
.036 0 .421 r
.71483 .50949 m .71311 .50892 L .71489 .50767 L F
.71483 .50949 m .7132 .51115 L .71311 .50892 L F
.553 .329 .53 r
.45651 .69094 m .4591 .68837 L .45685 .68888 L F
.057 .556 .886 r
.32499 .60083 m .32706 .60128 L .3265 .60083 L F
.32499 .60083 m .3265 .60083 L .32627 .60086 L F
.32499 .60083 m .32627 .60086 L .3229 .60119 L F
.002 .548 .831 r
.32435 .60082 m .32499 .60083 L .32312 .6005 L F
.32661 .60141 m .32499 .60083 L .32435 .60082 L F
0 .43 .79 r
.32661 .60141 m .32706 .60128 L .32499 .60083 L F
.32661 .60141 m .32863 .60211 L .32706 .60128 L F
.944 .944 .752 r
.65776 .50246 m .65701 .50181 L .65838 .49975 L F
0 0 .423 r
.62185 .54535 m .62212 .5417 L .62092 .54184 L F
.62185 .54535 m .62255 .54396 L .62212 .5417 L F
.811 .589 .03 r
.62185 .54535 m .62171 .54632 L .62255 .54396 L F
.62185 .54535 m .62209 .54772 L .62171 .54632 L F
.489 .386 .664 r
.24697 .6133 m .24907 .61272 L .24853 .60968 L F
.594 .424 .62 r
.24697 .6133 m .24939 .61483 L .24907 .61272 L F
.24697 .6133 m .24712 .6155 L .24939 .61483 L F
.313 .055 .352 r
.5747 .69642 m .57717 .69367 L .57509 .69436 L F
.726 .615 .733 r
.57717 .69367 m .5747 .69642 L .57509 .69436 L F
.757 .675 .771 r
.54995 .60714 m .55098 .61027 L .54769 .60996 L F
.696 .538 .669 r
.55098 .61027 m .54882 .61273 L .54769 .60996 L F
.55098 .61027 m .55118 .61271 L .54882 .61273 L F
.631 .546 .74 r
.552 .60661 m .55098 .61027 L .54995 .60714 L F
.552 .60661 m .55342 .60982 L .55098 .61027 L F
.618 .479 .671 r
.55342 .60982 m .55118 .61271 L .55098 .61027 L F
.472 .249 .494 r
.28854 .61559 m .28827 .6182 L .28605 .61841 L F
.518 .336 .573 r
.28779 .62104 m .28605 .61841 L .28827 .6182 L F
.28779 .62104 m .28623 .62167 L .28605 .61841 L F
.482 .287 .539 r
.29083 .61245 m .2905 .61509 L .28854 .61559 L F
.49 .265 .498 r
.29032 .61711 m .28854 .61559 L .2905 .61509 L F
.29032 .61711 m .28827 .6182 L .28854 .61559 L F
.207 .715 .898 r
.50213 .81706 m .505 .81724 L .50391 .81667 L F
.627 .597 .8 r
.505 .81724 m .50679 .81461 L .50391 .81667 L F
.505 .81724 m .50844 .81641 L .50679 .81461 L F
.778 .822 .887 r
.67145 .48255 m .67278 .48392 L .67499 .48227 L F
.414 .502 .84 r
.54301 .77582 m .54598 .77882 L .54625 .77605 L F
.491 .144 .305 r
.54774 .77742 m .54625 .77605 L .54598 .77882 L F
.54774 .77742 m .54853 .77558 L .54625 .77605 L F
.158 .306 .765 r
.55477 .71082 m .556 .71407 L .55706 .71288 L F
0 0 0 r
.556 .71407 m .55464 .71572 L .55706 .71288 L F
.241 0 .248 r
.25139 .64685 m .25266 .64781 L .25341 .64591 L F
.25139 .64685 m .25053 .64904 L .25266 .64781 L F
.156 0 0 r
.25652 .59496 m .25955 .59289 L .25731 .59322 L F
.968 .718 .505 r
.28924 .73936 m .28778 .7388 L .28785 .73618 L F
.521 .33 .562 r
.28785 .73618 m .28778 .7388 L .28924 .73936 L F
.493 .721 .973 r
.29517 .62867 m .29457 .63035 L .29322 .62879 L F
.29517 .62867 m .29664 .62997 L .29457 .63035 L F
.704 .307 .293 r
.52699 .79724 m .52435 .79702 L .5242 .79723 L F
.595 .078 0 r
.56398 .72589 m .56302 .72693 L .56081 .72556 L F
.089 .595 .892 r
.56398 .72589 m .56417 .72537 L .56302 .72693 L F
.56398 .72589 m .56726 .72635 L .56417 .72537 L F
.264 .744 .932 r
.44961 .66089 m .44683 .66051 L .4446 .6607 L F
.768 .834 .903 r
.44871 .6595 m .44961 .66089 L .44991 .6598 L F
.44871 .6595 m .44683 .66051 L .44961 .66089 L F
.603 .388 .562 r
.58675 .59883 m .58656 .60114 L .58463 .60086 L F
.574 .364 .557 r
.58675 .59883 m .58898 .60076 L .58656 .60114 L F
.648 .344 .441 r
.58906 .59893 m .58898 .60076 L .58675 .59883 L F
.753 .981 .737 r
.38656 .70308 m .38432 .70571 L .3848 .7044 L F
.943 .692 .528 r
.38679 .70594 m .3848 .7044 L .38432 .70571 L F
.724 .306 .253 r
.53357 .76639 m .53469 .76469 L .53406 .76407 L F
.53357 .76639 m .53703 .76693 L .53469 .76469 L F
.626 .151 .106 r
.47182 .68798 m .47013 .68839 L .47379 .68867 L F
.893 .796 .746 r
.67557 .51438 m .67681 .51767 L .67666 .51518 L F
.744 .733 .842 r
.67874 .51405 m .67681 .51767 L .67557 .51438 L F
.383 .16 .447 r
.34348 .61287 m .34555 .61238 L .34577 .60995 L F
.463 .291 .561 r
.34324 .61482 m .34555 .61238 L .34348 .61287 L F
.561 .434 .664 r
.38691 .666 m .38882 .66272 L .38677 .66367 L F
.292 0 0 r
.42563 .70736 m .42476 .70838 L .42257 .70876 L F
.298 0 0 r
.42815 .70697 m .42476 .70838 L .42563 .70736 L F
.74 .64 .749 r
.59184 .71665 m .59541 .71654 L .59431 .71463 L F
.71 .433 .504 r
.59404 .71885 m .59541 .71654 L .59184 .71665 L F
.564 .762 .971 r
.59541 .71654 m .59694 .71541 L .59431 .71463 L F
.59541 .71654 m .59732 .71666 L .59694 .71541 L F
.693 .508 .633 r
.59586 .71952 m .59541 .71654 L .59404 .71885 L F
.59586 .71952 m .59732 .71666 L .59541 .71654 L F
.707 .798 .921 r
.37706 .70325 m .38102 .70336 L .37952 .70238 L F
.653 .852 .976 r
.37952 .70238 m .38102 .70336 L .38301 .70243 L F
.794 .484 .465 r
.56193 .7112 m .56063 .71331 L .56053 .7108 L F
.56193 .7112 m .56393 .7135 L .56063 .71331 L F
.627 .4 .553 r
.50993 .79558 m .50883 .79844 L .50657 .79817 L F
.716 .527 .633 r
.51173 .79562 m .50883 .79844 L .50993 .79558 L F
.948 .956 .674 r
.5669 .77337 m .56839 .77036 L .56614 .77238 L F
.962 .943 .669 r
.56614 .77238 m .56839 .77036 L .56769 .76991 L F
.599 .661 .882 r
.55911 .78142 m .56135 .77927 L .55792 .77863 L F
.55911 .78142 m .56151 .78133 L .56135 .77927 L F
.613 .45 .637 r
.55911 .78142 m .55962 .78405 L .56151 .78133 L F
.672 .484 .623 r
.56852 .602 m .56772 .60457 L .56297 .60422 L F
.614 .424 .601 r
.56945 .60397 m .56852 .602 L .56944 .60156 L F
.56945 .60397 m .56772 .60457 L .56852 .602 L F
.612 .611 .826 r
.38035 .59854 m .37921 .60179 L .3781 .59887 L F
.38035 .59854 m .38149 .60129 L .37921 .60179 L F
.508 .358 .612 r
.38149 .60129 m .37951 .60428 L .37921 .60179 L F
.76 .451 .464 r
.58295 .69051 m .58615 .69011 L .58558 .68876 L F
.497 .327 .58 r
.58615 .69011 m .58785 .69066 L .58558 .68876 L F
.473 .418 .716 r
.38523 .68309 m .38585 .68645 L .38762 .68511 L F
.692 .887 .511 r
.61885 .55686 m .61969 .55529 L .62078 .55403 L F
.014 0 .415 r
.61818 .55899 m .61969 .55529 L .61885 .55686 L F
.929 .727 .608 r
.55602 .59055 m .55556 .59292 L .55428 .5896 L F
.786 .451 .419 r
.54638 .73715 m .54914 .73931 L .54597 .73869 L F
.36 .757 .985 r
.33083 .60179 m .33244 .60265 L .33388 .6021 L F
.566 .935 .818 r
.50844 .81641 m .51135 .81495 L .50909 .81531 L F
.216 .736 .851 r
.51135 .81495 m .51338 .81479 L .51266 .81464 L F
.77 .29 .098 r
.64903 .48694 m .65027 .48595 L .64873 .48513 L F
.64903 .48694 m .65404 .48996 L .65027 .48595 L F
0 .132 .623 r
.71683 .49758 m .71802 .49832 L .7175 .49571 L F
.71683 .49758 m .71903 .49935 L .71802 .49832 L F
.013 .019 .516 r
.55325 .71692 m .55485 .71813 L .55464 .71572 L F
.55325 .71692 m .55365 .71932 L .55485 .71813 L F
.166 0 .167 r
.36211 .61826 m .36464 .61558 L .36416 .61766 L F
.489 .209 .415 r
.36638 .61719 m .36464 .61558 L .36681 .61516 L F
.36638 .61719 m .36416 .61766 L .36464 .61558 L F
.699 .657 .805 r
.54174 .75878 m .54185 .76131 L .54544 .75961 L F
.497 .904 .908 r
.6902 .48193 m .68706 .4822 L .68626 .48291 L F
.665 .963 .931 r
.691 .48064 m .6902 .48193 L .69164 .48164 L F
.691 .48064 m .68706 .4822 L .6902 .48193 L F
.296 .172 .537 r
.60735 .57348 m .60885 .57484 L .60932 .57283 L F
.60735 .57348 m .60757 .57614 L .60885 .57484 L F
.321 0 0 r
.2891 .58365 m .29264 .58461 L .29072 .58396 L F
.637 .116 0 r
.48315 .69098 m .4859 .69277 L .4866 .69167 L F
.625 .13 .055 r
.4859 .69277 m .48892 .69238 L .4866 .69167 L F
.473 .418 .716 r
.38523 .68309 m .38762 .68511 L .38702 .68262 L F
.393 .787 .988 r
.32105 .58721 m .32058 .58827 L .31893 .58722 L F
.32105 .58721 m .32272 .58803 L .32058 .58827 L F
.643 .38 .505 r
.50318 .78157 m .50493 .78093 L .50373 .77852 L F
0 .183 .687 r
.50587 .78039 m .50373 .77852 L .50493 .78093 L F
.643 .38 .505 r
.50318 .78157 m .50373 .77852 L .50408 .77841 L F
.688 .721 .875 r
.26126 .64303 m .26302 .64479 L .26493 .6437 L F
.702 .788 .918 r
.51338 .81479 m .51464 .8122 L .51266 .81464 L F
.51338 .81479 m .5159 .81361 L .51464 .8122 L F
.727 .501 .584 r
.5632 .60643 m .5616 .60436 L .56297 .60422 L F
.682 .5 .634 r
.56772 .60457 m .5632 .60643 L .56297 .60422 L F
.647 .39 .517 r
.61993 .52941 m .61804 .53315 L .61799 .53089 L F
.61993 .52941 m .62061 .53331 L .61804 .53315 L F
.58 .472 .696 r
.62192 .52725 m .61993 .52941 L .62092 .5279 L F
.62192 .52725 m .62438 .53056 L .61993 .52941 L F
.661 .399 .514 r
.62438 .53293 m .61993 .52941 L .62438 .53056 L F
.62438 .53293 m .62061 .53331 L .61993 .52941 L F
.891 .902 .828 r
.61939 .52646 m .61993 .52941 L .62092 .5279 L F
.638 .719 .907 r
.52041 .6496 m .52167 .65188 L .51828 .6512 L F
.74 .766 .874 r
.52437 .64979 m .52167 .65188 L .52041 .6496 L F
0 .095 .579 r
.55584 .72405 m .55355 .72203 L .55687 .72228 L F
.804 .538 .536 r
.55687 .72228 m .55855 .72465 L .55584 .72405 L F
.734 .647 .763 r
.48491 .75503 m .48757 .75335 L .48583 .75372 L F
.428 .395 .721 r
.54826 .7599 m .54964 .75806 L .54745 .75818 L F
.54826 .7599 m .55124 .7603 L .54964 .75806 L F
.54826 .7599 m .54919 .76194 L .55124 .7603 L F
.26 0 0 r
.26771 .58797 m .26687 .58882 L .26922 .58831 L F
.63 .751 .934 r
.30609 .63169 m .30389 .63245 L .30264 .63097 L F
.44 .22 .481 r
.29285 .61214 m .2905 .61509 L .29083 .61245 L F
.692 .614 .765 r
.76068 .60695 m .76297 .60411 L .76062 .60483 L F
.76068 .60695 m .76415 .60741 L .76297 .60411 L F
.585 .387 .579 r
.61087 .59112 m .61123 .59329 L .60854 .59333 L F
.495 .326 .58 r
.61338 .59251 m .61123 .59329 L .61087 .59112 L F
.097 0 .442 r
.47697 .76955 m .47623 .77317 L .47537 .77294 L F
.022 .154 .663 r
.47623 .77317 m .47708 .77507 L .47537 .77294 L F
.312 .241 .614 r
.47708 .77507 m .47579 .7759 L .47537 .77294 L F
.451 .15 .362 r
.60854 .59333 m .61042 .59508 L .60819 .59496 L F
.515 .141 .27 r
.61123 .59329 m .61042 .59508 L .60854 .59333 L F
.569 .256 .398 r
.60854 .59333 m .60819 .59496 L .60614 .59494 L F
.79 .421 .357 r
.73662 .51128 m .73681 .51333 L .7346 .51085 L F
.452 .241 .502 r
.73935 .51055 m .73681 .51333 L .73662 .51128 L F
.591 .381 .565 r
.49165 .79584 m .49509 .79303 L .4918 .79302 L F
.49165 .79584 m .49408 .79498 L .49509 .79303 L F
.669 .479 .618 r
.49408 .79498 m .49521 .79318 L .49509 .79303 L F
.547 .701 .941 r
.51639 .67064 m .51779 .67228 L .51955 .67065 L F
.33 0 .049 r
.33457 .64258 m .3311 .6445 L .33244 .64318 L F
.838 .787 .802 r
.72421 .48327 m .72575 .48552 L .72424 .48416 L F
.826 .904 .894 r
.72575 .48552 m .72283 .48622 L .72424 .48416 L F
.518 .597 .873 r
.72652 .48268 m .72575 .48552 L .72421 .48327 L F
.72652 .48268 m .72826 .48552 L .72575 .48552 L F
.902 .968 .815 r
.62078 .55403 m .62032 .55301 L .62081 .55208 L F
.979 .887 .528 r
.62078 .55403 m .61969 .55529 L .62032 .55301 L F
.347 .159 .478 r
.52159 .69394 m .52161 .69662 L .51937 .69624 L F
.282 0 .191 r
.52052 .69793 m .51937 .69624 L .52161 .69662 L F
.52052 .69793 m .51868 .69861 L .51937 .69624 L F
.263 0 0 r
.54508 .78261 m .54471 .78239 L .5439 .78283 L F
.208 .132 .546 r
.51274 .67157 m .51333 .67206 L .51327 .66874 L F
.145 .136 .588 r
.51274 .67157 m .5139 .67388 L .51333 .67206 L F
.775 .655 .73 r
.49417 .81126 m .49161 .81194 L .4919 .80975 L F
.616 .351 .493 r
.62607 .5184 m .62765 .5195 L .62562 .51855 L F
.502 .703 .96 r
.69623 .48326 m .69714 .48133 L .69503 .48157 L F
.69623 .48326 m .69804 .48272 L .69714 .48133 L F
.554 .83 .997 r
.53589 .77288 m .53968 .77316 L .53869 .77413 L F
.09 0 .361 r
.5413 .77251 m .53869 .77413 L .53968 .77316 L F
.917 .976 .701 r
.67347 .52591 m .67494 .52225 L .67201 .52471 L F
.904 .731 .657 r
.67201 .52471 m .67327 .5288 L .67347 .52591 L F
.818 .823 .853 r
.54876 .74502 m .551 .74244 L .55023 .74447 L F
.918 .682 .566 r
.54955 .74702 m .54876 .74502 L .55023 .74447 L F
.513 .189 .355 r
.61563 .53115 m .61455 .53359 L .61248 .53374 L F
.646 .328 .419 r
.61804 .53315 m .61563 .53115 L .61799 .53089 L F
.61804 .53315 m .61455 .53359 L .61563 .53115 L F
0 .148 .686 r
.55087 .79419 m .55138 .7934 L .55237 .795 L F
.789 .385 .289 r
.48029 .64933 m .47602 .64915 L .47802 .65053 L F
.48029 .64933 m .47893 .65089 L .47602 .64915 L F
.367 .822 .931 r
.48303 .64889 m .48137 .64865 L .48079 .64925 L F
.368 .823 .931 r
.48512 .64839 m .48137 .64865 L .48303 .64889 L F
.649 .643 .831 r
.48303 .64889 m .48676 .65072 L .48512 .64839 L F
.596 .139 .137 r
.48512 .64839 m .48338 .64997 L .48137 .64865 L F
0 .296 .793 r
.48137 .64865 m .48338 .64997 L .48199 .64802 L F
.48137 .64865 m .48199 .64802 L .48167 .64759 L F
.367 .822 .931 r
.48079 .64925 m .48137 .64865 L .48029 .64933 L F
0 0 0 r
.48137 .64865 m .47893 .65089 L .48029 .64933 L F
.602 .936 .739 r
.719 .50886 m .71589 .5109 L .71852 .50816 L F
.847 .487 .371 r
.71926 .50505 m .71821 .50524 L .71777 .50324 L F
.71946 .5053 m .71821 .50524 L .71926 .50505 L F
.469 .33 .609 r
.71565 .50692 m .71489 .50767 L .71484 .50514 L F
.71583 .5073 m .71533 .5075 L .71565 .50692 L F
.71533 .5075 m .71489 .50767 L .71565 .50692 L F
.721 .443 .504 r
.71484 .50514 m .71564 .50689 L .71821 .50524 L F
.883 .939 .848 r
.71821 .50524 m .71928 .50238 L .71777 .50324 L F
.653 .247 .263 r
.71821 .50524 m .7177 .50593 L .71705 .50575 L F
.71821 .50524 m .71705 .50575 L .71484 .50514 L F
.469 .33 .609 r
.71702 .50683 m .71583 .5073 L .71564 .50689 L F
.71614 .50615 m .71564 .50689 L .71484 .50514 L F
.883 .939 .848 r
.71821 .50524 m .71564 .50689 L .71626 .5061 L F
.71564 .50689 m .71579 .50668 L .71626 .5061 L F
.796 .739 .8 r
.71626 .5061 m .71579 .50668 L .7161 .50612 L F
.469 .33 .609 r
.71702 .50683 m .71564 .50689 L .71614 .50615 L F
.883 .939 .848 r
.71564 .50689 m .71557 .50693 L .71579 .50668 L F
.653 .247 .263 r
.7177 .50593 m .7161 .50612 L .71484 .50514 L F
.883 .939 .848 r
.71821 .50524 m .71626 .5061 L .71675 .5055 L F
.796 .739 .8 r
.71962 .50201 m .71626 .5061 L .71834 .50208 L F
.71626 .5061 m .7161 .50612 L .71834 .50208 L F
.653 .247 .263 r
.7177 .50593 m .71702 .50683 L .7161 .50612 L F
.796 .739 .8 r
.71834 .50208 m .71557 .50693 L .71565 .50223 L F
.71579 .50668 m .71557 .50693 L .71834 .50208 L F
.721 .443 .504 r
.71484 .50514 m .71557 .50693 L .71564 .50689 L F
.883 .939 .848 r
.71821 .50524 m .71962 .50201 L .71928 .50238 L F
.71821 .50524 m .71675 .5055 L .71962 .50201 L F
.922 .679 .188 r
.719 .50886 m .71821 .50524 L .71946 .5053 L F
.719 .50886 m .71852 .50816 L .71821 .50524 L F
.668 .455 .587 r
.5616 .60436 m .56171 .60708 L .5578 .60634 L F
.727 .501 .584 r
.5632 .60643 m .56171 .60708 L .5616 .60436 L F
.745 .635 .738 r
.55567 .60697 m .55708 .61018 L .55342 .60982 L F
.694 .502 .623 r
.55708 .61018 m .55353 .61217 L .55342 .60982 L F
.55708 .61018 m .55698 .61256 L .55353 .61217 L F
.669 .6 .768 r
.55912 .60954 m .55708 .61018 L .55567 .60697 L F
.619 .439 .616 r
.55912 .60954 m .55698 .61256 L .55708 .61018 L F
.926 .92 .538 r
.59629 .55954 m .59741 .55616 L .59619 .55777 L F
.929 .955 .633 r
.59629 .55954 m .59619 .55777 L .59456 .56123 L F
.59629 .55954 m .59456 .56123 L .59624 .55937 L F
.397 .175 .456 r
.59162 .71922 m .59184 .71665 L .5893 .71957 L F
.751 .617 .71 r
.59177 .72182 m .59404 .71885 L .59162 .71922 L F
0 0 .108 r
.59162 .71922 m .59179 .72092 L .59177 .72182 L F
.027 .25 .752 r
.5893 .71957 m .59179 .72092 L .59162 .71922 L F
.5893 .71957 m .59161 .72189 L .59179 .72092 L F
.844 .708 .712 r
.57071 .60956 m .57189 .61284 L .57012 .61193 L F
.848 .419 .208 r
.57012 .61193 m .57189 .61284 L .57095 .61402 L F
.72 .556 .667 r
.57071 .60956 m .57319 .61221 L .57189 .61284 L F
.612 .249 .33 r
.57319 .61221 m .57095 .61402 L .57189 .61284 L F
.383 .354 .703 r
.52947 .77468 m .52659 .77612 L .52656 .77273 L F
.313 .202 .564 r
.52758 .77765 m .52659 .77612 L .52947 .77468 L F
.362 0 .086 r
.30348 .60514 m .30282 .60621 L .30075 .60654 L F
.343 0 .076 r
.30348 .60514 m .305 .60579 L .30282 .60621 L F
.691 .699 .852 r
.49302 .792 m .49165 .79584 L .4918 .79302 L F
.49302 .792 m .49408 .79498 L .49165 .79584 L F
0 0 0 r
.49165 .79584 m .4903 .79751 L .49151 .79774 L F
.49165 .79584 m .49189 .7962 L .4903 .79751 L F
.683 .458 .574 r
.49151 .79774 m .49408 .79498 L .49165 .79584 L F
.796 .552 .568 r
.49211 .79981 m .49449 .79817 L .4934 .79757 L F
.594 .127 .116 r
.4934 .79757 m .49449 .79817 L .49316 .79798 L F
.4934 .79757 m .49316 .79798 L .49151 .79774 L F
.694 .827 .386 r
.49316 .79798 m .4934 .79757 L .49327 .79777 L F
.683 .458 .574 r
.49327 .79777 m .49449 .79817 L .49444 .7978 L F
.49151 .79774 m .49316 .79798 L .49327 .79777 L F
.49316 .79798 m .49449 .79817 L .49327 .79777 L F
.694 .827 .386 r
.49234 .79934 m .49316 .79798 L .49271 .7986 L F
.49316 .79798 m .49327 .79777 L .49271 .7986 L F
.392 0 0 r
.49327 .79777 m .4934 .79757 L .49151 .79774 L F
.683 .458 .574 r
.49151 .79774 m .49327 .79777 L .49408 .79498 L F
.49327 .79777 m .49444 .7978 L .49421 .79599 L F
.49327 .79777 m .49421 .79599 L .49408 .79498 L F
.694 .827 .386 r
.49211 .79981 m .49307 .79815 L .49234 .79934 L F
.49307 .79815 m .4934 .79757 L .49316 .79798 L F
.49307 .79815 m .49316 .79798 L .49234 .79934 L F
.392 0 0 r
.49271 .7986 m .49327 .79777 L .49151 .79774 L F
.994 .754 .403 r
.49296 .79486 m .49408 .79498 L .49302 .792 L F
0 .285 .785 r
.49436 .79544 m .49296 .79486 L .49315 .79353 L F
.722 .519 .614 r
.49449 .79817 m .49654 .79533 L .49408 .79498 L F
0 .285 .785 r
.49487 .79626 m .49382 .79549 L .49436 .79544 L F
.49382 .79549 m .49296 .79486 L .49436 .79544 L F
0 0 0 r
.49165 .79584 m .49224 .79563 L .49189 .7962 L F
.49224 .79563 m .49408 .79498 L .49304 .79556 L F
.49224 .79563 m .49304 .79556 L .49189 .7962 L F
.51 .05 .097 r
.6002 .71431 m .59694 .71541 L .59732 .71666 L F
.674 .633 .801 r
.34341 .60248 m .34489 .60469 L .34728 .60422 L F
.66 .537 .703 r
.34489 .60469 m .34517 .60701 L .34728 .60422 L F
.628 .59 .792 r
.54245 .74797 m .5421 .75067 L .54512 .74778 L F
.515 .341 .583 r
.53959 .76225 m .5418 .76112 L .53938 .75902 L F
.562 .335 .528 r
.53938 .75902 m .5418 .76112 L .54174 .75878 L F
.623 .634 .841 r
.48202 .79774 m .481 .80034 L .48049 .79711 L F
.48202 .79774 m .4827 .79964 L .481 .80034 L F
.289 .785 .875 r
.31232 .65787 m .31275 .65741 L .31465 .65744 L F
.31232 .65787 m .31275 .65741 L .31465 .65744 L F
.984 .765 .528 r
.56094 .74388 m .56235 .74215 L .56089 .74145 L F
.56094 .74388 m .56215 .74462 L .56235 .74215 L F
.524 .723 .964 r
.36054 .59171 m .35975 .59347 L .35844 .59202 L F
.36054 .59171 m .36189 .59314 L .35975 .59347 L F
.676 .361 .434 r
.59987 .58349 m .60025 .58193 L .5969 .58185 L F
.457 .18 .403 r
.59987 .58349 m .60244 .58129 L .60025 .58193 L F
.431 .162 .404 r
.59973 .52588 m .59942 .52772 L .60199 .52524 L F
.62 .555 .76 r
.34577 .60995 m .34721 .6065 L .34517 .60701 L F
.34577 .60995 m .34811 .60959 L .34721 .6065 L F
.392 .095 .337 r
.34555 .61238 m .34811 .60959 L .34577 .60995 L F
.591 .569 .798 r
.75585 .58346 m .75827 .58305 L .75791 .58185 L F
.256 .103 .473 r
.5133 .66573 m .51503 .66538 L .51501 .66297 L F
.3 .223 .6 r
.5133 .66573 m .51503 .66743 L .51503 .66538 L F
.5133 .66573 m .51327 .66874 L .51503 .66743 L F
.574 .334 .514 r
.59523 .70545 m .59797 .7077 L .59629 .70692 L F
.738 .638 .749 r
.76297 .60411 m .76415 .60741 L .76603 .60593 L F
.627 .643 .847 r
.25526 .62424 m .2554 .62068 L .25496 .62115 L F
.25526 .62424 m .2575 .62378 L .2554 .62068 L F
.195 .707 .891 r
.7664 .57321 m .76824 .57349 L .76489 .57325 L F
.494 0 0 r
.76965 .57458 m .76824 .57349 L .7664 .57321 L F
.76965 .57458 m .77217 .57551 L .76824 .57349 L F
.304 0 .268 r
.37176 .61241 m .37466 .60857 L .37363 .61172 L F
.465 .218 .454 r
.37715 .60679 m .37714 .60748 L .37466 .60857 L F
.352 .022 .259 r
.37466 .60857 m .37558 .61097 L .37363 .61172 L F
.37466 .60857 m .37714 .60748 L .37558 .61097 L F
0 0 0 r
.54321 .7899 m .5401 .79107 L .54182 .78884 L F
0 .247 .739 r
.53847 .78931 m .54 .79097 L .53743 .78893 L F
.54 .79097 m .5401 .79107 L .54002 .79101 L F
.54 .79097 m .54002 .79101 L .53743 .78893 L F
.805 .793 .842 r
.54182 .78884 m .5401 .79107 L .53847 .78931 L F
.822 .999 .79 r
.53984 .79054 m .54182 .78884 L .54083 .78903 L F
.53884 .79208 m .53996 .79086 L .53984 .79054 L F
.53996 .79086 m .54182 .78884 L .53984 .79054 L F
.042 0 0 r
.53884 .79208 m .54321 .7899 L .54182 .78884 L F
.607 .728 .93 r
.54408 .78821 m .54674 .78975 L .54321 .7899 L F
.605 .73 .933 r
.54674 .78975 m .54624 .79023 L .54321 .7899 L F
.981 .737 .494 r
.54624 .79023 m .54523 .79202 L .54321 .7899 L F
.213 .241 .674 r
.54408 .78821 m .54321 .7899 L .54523 .79202 L F
.744 .679 .788 r
.53808 .77854 m .54075 .77866 L .53768 .77946 L F
.023 .594 .755 r
.53984 .77856 m .54075 .77866 L .53808 .77854 L F
.752 .635 .731 r
.5384 .78122 m .54075 .77866 L .53808 .77854 L F
.548 .928 .902 r
.53984 .77856 m .54075 .77866 L .54179 .77759 L F
.53984 .77856 m .54075 .77866 L .54179 .77759 L F
.326 .13 .455 r
.74136 .5868 m .73953 .59021 L .74144 .58916 L F
.56 .446 .681 r
.74144 .58916 m .74354 .58583 L .74136 .5868 L F
.703 .691 .835 r
.54662 .61646 m .54319 .61578 L .54521 .61464 L F
.677 .629 .794 r
.54886 .61546 m .54662 .61646 L .54521 .61464 L F
.417 .197 .47 r
.60441 .58054 m .6026 .57912 L .60244 .58129 L F
.60441 .58054 m .60466 .57834 L .6026 .57912 L F
.823 .908 .898 r
.47728 .80626 m .47899 .80688 L .48124 .80446 L F
.47728 .80626 m .48124 .80446 L .48 .80275 L F
.68 .655 .819 r
.48013 .80315 m .48047 .80773 L .48021 .80761 L F
.797 .678 .733 r
.48063 .80923 m .47899 .80688 L .48055 .80811 L F
.68 .655 .819 r
.47843 .805 m .48021 .80761 L .47728 .80626 L F
.48013 .80315 m .48021 .80761 L .47843 .805 L F
.797 .678 .733 r
.48096 .80871 m .48055 .80811 L .48108 .80852 L F
.48063 .80923 m .48055 .80811 L .48096 .80871 L F
0 .232 .751 r
.48108 .80852 m .48309 .81177 L .48063 .80923 L F
.598 .377 .552 r
.56476 .69976 m .56708 .70206 L .56716 .6996 L F
.56476 .69976 m .56395 .70245 L .56708 .70206 L F
.76 .69 .784 r
.73963 .49735 m .74076 .50071 L .7375 .50016 L F
.706 .661 .803 r
.74328 .49991 m .74076 .50071 L .73963 .49735 L F
.315 .626 .96 r
.699 .48464 m .70061 .48381 L .69804 .48272 L F
.699 .48464 m .70151 .48496 L .70061 .48381 L F
.481 .208 .423 r
.3211 .63239 m .32327 .63198 L .3238 .62987 L F
.448 .186 .422 r
.32327 .63198 m .3258 .62935 L .3238 .62987 L F
.422 .43 .762 r
.71083 .48581 m .71374 .48793 L .71373 .48702 L F
.125 0 .004 r
.71373 .48702 m .7159 .48702 L .71632 .48705 L F
.71373 .48702 m .71374 .48793 L .7159 .48702 L F
.453 .149 .359 r
.35725 .62609 m .35434 .6289 L .35524 .6267 L F
.63 .166 .133 r
.47779 .81504 m .48137 .81519 L .47988 .81624 L F
0 .218 .685 r
.48137 .81519 m .48235 .81561 L .47988 .81624 L F
.741 .987 .894 r
.48193 .8151 m .48235 .81561 L .48453 .81384 L F
0 .218 .685 r
.48137 .81519 m .48285 .81624 L .48235 .81561 L F
.741 .987 .894 r
.48095 .81557 m .48235 .81561 L .48193 .8151 L F
0 .218 .685 r
.48285 .81624 m .48293 .8163 L .48235 .81561 L F
.645 .417 .558 r
.59453 .58434 m .5969 .58185 L .59451 .58188 L F
.59453 .58434 m .597 .58453 L .5969 .58185 L F
.676 .361 .434 r
.59987 .58349 m .5969 .58185 L .597 .58453 L F
.685 .81 .942 r
.58588 .57581 m .5898 .57611 L .58843 .57267 L F
.58588 .57581 m .58799 .57616 L .5898 .57611 L F
.742 .527 .603 r
.58799 .57616 m .58797 .57885 L .5898 .57611 L F
.789 .592 .634 r
.5898 .57611 m .58797 .57885 L .59109 .57904 L F
.802 .712 .766 r
.58843 .57267 m .5898 .57611 L .59197 .57241 L F
.725 .917 .959 r
.78459 .59432 m .78082 .59522 L .784 .59329 L F
.568 .634 .877 r
.78606 .59201 m .78459 .59432 L .784 .59329 L F
.78606 .59201 m .78681 .59382 L .78459 .59432 L F
.828 .528 0 r
.39032 .69411 m .39121 .69711 L .39064 .69582 L F
0 .434 .831 r
.39121 .69711 m .39161 .69673 L .39064 .69582 L F
.39121 .69711 m .39222 .69714 L .39161 .69673 L F
.703 .801 .926 r
.70149 .47402 m .70001 .47705 L .69928 .47501 L F
.70149 .47402 m .70275 .47549 L .70001 .47705 L F
.44 .167 .402 r
.50266 .79247 m .50524 .78988 L .50392 .79174 L F
.938 .652 .471 r
.50524 .78988 m .50559 .79244 L .50392 .79174 L F
.505 .42 .694 r
.44683 .66051 m .44735 .66243 L .4446 .6607 L F
.55 .405 .636 r
.44735 .66243 m .44483 .66307 L .4446 .6607 L F
.973 .735 .518 r
.54333 .62968 m .54203 .62932 L .5421 .62643 L F
.559 .563 .814 r
.54536 .62914 m .54333 .62968 L .5421 .62643 L F
.519 .014 0 r
.54536 .62914 m .54203 .62932 L .54333 .62968 L F
.4 .256 .567 r
.56711 .71371 m .56534 .71682 L .56393 .7135 L F
.56711 .71371 m .56702 .71649 L .56534 .71682 L F
.387 .213 .519 r
.56534 .71682 m .56702 .71649 L .56525 .71924 L F
.496 .204 .399 r
.3523 .62941 m .34944 .6317 L .35031 .63034 L F
.436 .285 .577 r
.38503 .66899 m .38694 .6686 L .38691 .666 L F
.484 .396 .68 r
.38503 .66899 m .38734 .67098 L .38694 .6686 L F
.38503 .66899 m .38554 .67162 L .38734 .67098 L F
0 .428 .755 r
.328 .58782 m .33205 .58929 L .33011 .58913 L F
.525 .387 .635 r
.41399 .68274 m .41426 .68492 L .41194 .68522 L F
.532 .455 .714 r
.41426 .68492 m .41277 .68915 L .41194 .68522 L F
.701 .753 .892 r
.52374 .79671 m .5215 .79812 L .52435 .79702 L F
.936 .906 .768 r
.72824 .51579 m .72912 .51668 L .73059 .5132 L F
.779 .741 .818 r
.7803 .60387 m .78343 .60409 L .78285 .60132 L F
.818 .823 .853 r
.54876 .74502 m .55 .74201 L .551 .74244 L F
.938 .567 .243 r
.551 .74244 m .55 .74201 L .54914 .73931 L F
.001 0 .482 r
.47225 .78678 m .47324 .78316 L .47159 .78431 L F
.675 .29 .309 r
.5003 .77015 m .50248 .7721 L .50396 .77008 L F
.692 .311 .32 r
.50396 .77008 m .50248 .7721 L .50625 .77188 L F
.51 .338 .583 r
.34728 .60422 m .34517 .60701 L .34721 .6065 L F
.987 .819 .589 r
.65693 .52008 m .65582 .51963 L .65629 .51676 L F
0 .043 .554 r
.65693 .52008 m .65845 .52063 L .65582 .51963 L F
.65693 .52008 m .65772 .52178 L .65845 .52063 L F
.655 .211 .185 r
.42995 .69628 m .43348 .69638 L .43168 .6947 L F
.529 .252 .438 r
.43168 .6947 m .43348 .69638 L .43416 .69414 L F
.669 .479 .618 r
.49408 .79498 m .49654 .79533 L .49521 .79318 L F
.962 .942 .69 r
.49642 .78947 m .49521 .79318 L .49794 .79174 L F
.194 .283 .728 r
.49521 .79318 m .49794 .79436 L .49794 .79174 L F
.49521 .79318 m .49654 .79533 L .49794 .79436 L F
.152 0 0 r
.67224 .53596 m .67136 .53628 L .66878 .53629 L F
.353 .812 .933 r
.67224 .53596 m .67478 .53553 L .67348 .53522 L F
.374 .824 .707 r
.67348 .53522 m .67136 .53628 L .67224 .53596 L F
.348 .314 .679 r
.38994 .69149 m .39102 .68792 L .3888 .68829 L F
.38994 .69149 m .39144 .69093 L .39102 .68792 L F
.31 .215 .583 r
.38994 .69149 m .39171 .69318 L .39144 .69093 L F
.277 .213 .602 r
.38994 .69149 m .39032 .69411 L .39171 .69318 L F
.425 .455 .788 r
.5155 .64309 m .5148 .64651 L .5139 .64298 L F
.5155 .64309 m .51657 .64653 L .5148 .64651 L F
.48 .467 .766 r
.51776 .64828 m .5148 .64651 L .51657 .64653 L F
.638 .791 .956 r
.68951 .5361 m .69256 .53648 L .69177 .5357 L F
.589 .927 .96 r
.69561 .53498 m .69177 .5357 L .69256 .53648 L F
.613 .876 .991 r
.6907 .51717 m .69188 .51814 L .6943 .51718 L F
.863 .663 .631 r
.59529 .71421 m .59625 .71118 L .59436 .70975 L F
.186 .21 .653 r
.59529 .71421 m .59436 .70975 L .59625 .71118 L F
.455 .734 .987 r
.71085 .51183 m .70731 .51098 L .71008 .50874 L F
.554 .393 .617 r
.7132 .51115 m .71353 .51352 L .71085 .51183 L F
0 .039 .564 r
.49151 .78405 m .49342 .78586 L .4948 .78302 L F
.779 .672 .745 r
.55462 .59902 m .55141 .59869 L .55353 .59583 L F
.799 .691 .745 r
.55462 .59902 m .55076 .60095 L .55141 .59869 L F
.458 .481 .794 r
.50654 .64956 m .50751 .64591 L .50529 .64836 L F
.50654 .64956 m .50839 .64937 L .50751 .64591 L F
.458 .488 .802 r
.50654 .64956 m .50947 .65132 L .50839 .64937 L F
.576 .785 .978 r
.25023 .6329 m .25441 .63371 L .25271 .63268 L F
.784 .535 .56 r
.69603 .51151 m .69953 .51428 L .69654 .51222 L F
.469 .68 .957 r
.3194 .66304 m .3158 .66119 L .31799 .66011 L F
.479 .656 .938 r
.31653 .6615 m .3194 .66304 L .31755 .66221 L F
.004 .239 .747 r
.31995 .66191 m .3194 .66304 L .31799 .66011 L F
.484 .828 .998 r
.31995 .66191 m .3194 .66304 L .31755 .66221 L F
.276 0 .04 r
.31162 .60196 m .31069 .60316 L .30905 .60339 L F
.224 .737 .703 r
.31355 .6023 m .31069 .60316 L .31162 .60196 L F
0 0 0 r
.59099 .53716 m .59219 .53585 L .59269 .53409 L F
.075 0 .329 r
.5902 .53905 m .59219 .53585 L .59099 .53716 L F
.772 .363 .276 r
.51696 .81158 m .51954 .81133 L .51861 .81006 L F
.424 .469 .802 r
.51861 .81006 m .52032 .81032 L .52006 .80949 L F
.59 .35 .521 r
.59467 .59579 m .59501 .59807 L .59151 .59877 L F
.632 .387 .529 r
.59695 .59574 m .59501 .59807 L .59467 .59579 L F
.538 .621 .882 r
.24712 .6155 m .25099 .61811 L .24939 .61483 L F
.519 .533 .81 r
.25099 .61811 m .25157 .61459 L .24939 .61483 L F
.25099 .61811 m .25279 .61765 L .25157 .61459 L F
.525 .72 .962 r
.25099 .61811 m .25368 .61858 L .25279 .61765 L F
.415 .702 .981 r
.50843 .77189 m .50747 .773 L .50625 .77188 L F
.079 .023 .486 r
.50826 .77569 m .50747 .773 L .50843 .77189 L F
.50826 .77569 m .50765 .77579 L .50747 .773 L F
.981 .737 .494 r
.54624 .79023 m .5466 .79262 L .54523 .79202 L F
.084 0 .326 r
.54744 .78995 m .54624 .79023 L .54674 .78975 L F
.595 .639 .865 r
.54744 .78995 m .5466 .79262 L .54624 .79023 L F
.893 .776 .725 r
.47362 .80712 m .47447 .80915 L .47221 .80687 L F
.961 .691 .478 r
.47221 .80687 m .47447 .80915 L .47311 .81099 L F
.985 .77 .531 r
.4738 .80671 m .47447 .80915 L .47362 .80712 L F
.864 .518 .394 r
.47447 .80915 m .47593 .81213 L .47311 .81099 L F
.722 .674 .802 r
.56171 .60708 m .56256 .60953 L .55912 .60954 L F
.654 .566 .743 r
.5632 .60643 m .56256 .60953 L .56171 .60708 L F
.5632 .60643 m .5646 .60979 L .56256 .60953 L F
.671 .46 .591 r
.5646 .60979 m .56288 .61204 L .56256 .60953 L F
.743 .635 .74 r
.54769 .60996 m .54882 .61273 L .54739 .61221 L F
.713 .546 .661 r
.54882 .61273 m .54521 .61464 L .54739 .61221 L F
.54882 .61273 m .54886 .61546 L .54521 .61464 L F
.564 .427 .652 r
.55116 .61493 m .54882 .61273 L .55118 .61271 L F
.55116 .61493 m .54886 .61546 L .54882 .61273 L F
.444 .82 .992 r
.68396 .5371 m .68721 .5373 L .68607 .53589 L F
.718 .792 .91 r
.68721 .5373 m .68951 .5361 L .68607 .53589 L F
.555 0 0 r
.51709 .80375 m .51805 .80533 L .51559 .80344 L F
.019 0 0 r
.51738 .8042 m .51709 .80375 L .51559 .80344 L F
.555 0 0 r
.51709 .80375 m .51903 .80447 L .51805 .80533 L F
.019 0 0 r
.51738 .8042 m .52026 .80255 L .51709 .80375 L F
.98 .815 .411 r
.59394 .53265 m .59471 .53102 L .59269 .53409 L F
.39 .235 .548 r
.59219 .53585 m .59394 .53265 L .59269 .53409 L F
.81 .691 .733 r
.59197 .57241 m .5925 .571 L .58874 .57023 L F
.64 .901 .984 r
.45396 .65822 m .44991 .6598 L .45281 .65785 L F
.443 .826 .593 r
.45511 .65737 m .45396 .65822 L .45281 .65785 L F
.51 .05 .097 r
.6002 .71431 m .59891 .71587 L .59694 .71541 L F
.689 .882 .502 r
.60098 .71281 m .59891 .71587 L .6002 .71431 L F
.679 .598 .758 r
.63938 .49441 m .63644 .49627 L .63612 .49405 L F
.532 .455 .714 r
.41426 .68492 m .41509 .68901 L .41277 .68915 L F
.239 .422 .842 r
.41582 .69232 m .41277 .68915 L .41509 .68901 L F
.908 .983 .746 r
.63417 .55978 m .63601 .55683 L .63421 .55783 L F
.915 .929 .554 r
.63327 .56156 m .63417 .55978 L .63421 .55783 L F
.69 .551 .691 r
.48662 .78454 m .4868 .7873 L .48894 .78417 L F
.661 .601 .777 r
.76062 .60483 m .76193 .60082 L .75944 .60138 L F
.76062 .60483 m .76297 .60411 L .76193 .60082 L F
.023 0 .333 r
.607 .5173 m .60799 .51828 L .60849 .51635 L F
.607 .5173 m .60674 .51952 L .60799 .51828 L F
.225 0 0 r
.44301 .64719 m .44685 .64651 L .44465 .64711 L F
0 .095 .636 r
.27764 .64882 m .27878 .65219 L .27939 .65094 L F
.417 .736 .992 r
.27878 .65219 m .28125 .65228 L .27939 .65094 L F
.489 .863 .983 r
.29841 .58427 m .29631 .58485 L .29479 .58444 L F
.288 0 0 r
.49654 .77212 m .5003 .77015 L .49818 .76955 L F
.637 .963 .899 r
.77162 .57557 m .7721 .57613 L .77217 .57551 L F
0 .073 .569 r
.77232 .57624 m .7721 .57613 L .77162 .57557 L F
.559 .563 .814 r
.54536 .62914 m .5421 .62643 L .54559 .62683 L F
0 0 .171 r
.54653 .62254 m .54632 .6255 L .54559 .62683 L F
.151 .153 .605 r
.54632 .6255 m .54536 .62914 L .54559 .62683 L F
.511 .497 .778 r
.73953 .59021 m .7424 .59176 L .74144 .58916 L F
.17 0 0 r
.46088 .6877 m .46329 .68735 L .46466 .68637 L F
.597 .076 0 r
.46466 .68637 m .46329 .68735 L .46679 .68774 L F
.755 .55 .619 r
.5911 .58395 m .59451 .58188 L .59105 .58152 L F
.5911 .58395 m .59453 .58434 L .59451 .58188 L F
.589 .927 .96 r
.69561 .53498 m .6937 .53489 L .69177 .5357 L F
.628 .938 .96 r
.69679 .53327 m .69561 .53498 L .69775 .53387 L F
.69679 .53327 m .6937 .53489 L .69561 .53498 L F
.687 .872 .968 r
.62192 .52725 m .61939 .52646 L .62092 .5279 L F
.81 .691 .733 r
.59197 .57241 m .58874 .57023 L .58843 .57267 L F
.625 .354 .487 r
.59151 .59877 m .58898 .60076 L .58906 .59893 L F
.171 .278 .733 r
.2575 .62378 m .25848 .62688 L .25947 .62567 L F
.585 .414 .616 r
.25848 .62688 m .26096 .62895 L .25947 .62567 L F
.25848 .62688 m .25867 .62931 L .26096 .62895 L F
.636 .388 .526 r
.58463 .60086 m .58336 .60382 L .581 .60383 L F
.634 .386 .526 r
.58669 .60327 m .58463 .60086 L .58656 .60114 L F
.58669 .60327 m .58336 .60382 L .58463 .60086 L F
.463 .291 .562 r
.5772 .69153 m .57837 .69244 L .57958 .69097 L F
.5772 .69153 m .57717 .69367 L .57837 .69244 L F
0 .152 .687 r
.25496 .62115 m .2554 .62068 L .25368 .61858 L F
.652 .832 .969 r
.70721 .47367 m .70593 .47566 L .70485 .47435 L F
.70721 .47367 m .70838 .47475 L .70593 .47566 L F
.926 .969 .684 r
.59924 .55347 m .59729 .55606 L .59741 .55616 L F
.73 .886 .488 r
.59741 .55616 m .59729 .55606 L .59619 .55777 L F
.751 .396 .382 r
.47994 .79543 m .48202 .79774 L .48049 .79711 L F
.635 .411 .56 r
.48212 .7953 m .48202 .79774 L .47994 .79543 L F
.758 .597 .678 r
.25677 .64389 m .25684 .64617 L .25932 .6435 L F
.568 .655 .895 r
.25932 .6435 m .25934 .64006 L .25829 .63974 L F
.25932 .6435 m .26126 .64303 L .25934 .64006 L F
.474 .232 .466 r
.36387 .62006 m .36211 .61826 L .36416 .61766 L F
.36387 .62006 m .36177 .62056 L .36211 .61826 L F
.773 .297 0 r
.56539 .74762 m .56564 .74882 L .56759 .75021 L F
.825 .391 .208 r
.56755 .75214 m .56759 .75021 L .56564 .74882 L F
.028 .146 .653 r
.56759 .75021 m .56915 .75263 L .56916 .75499 L F
.825 .391 .208 r
.56755 .75214 m .56915 .75263 L .56759 .75021 L F
.519 0 0 r
.58472 .7264 m .58378 .72708 L .5815 .72617 L F
.743 .968 .933 r
.58725 .7258 m .58378 .72708 L .58472 .7264 L F
0 0 0 r
.52515 .6572 m .52368 .6604 L .52349 .66069 L F
.595 .806 .399 r
.52368 .6604 m .5224 .66231 L .52349 .66069 L F
.401 .477 .823 r
.50947 .65132 m .51096 .65501 L .51239 .65415 L F
.375 .279 .618 r
.51096 .65501 m .51287 .65697 L .51239 .65415 L F
.51096 .65501 m .51091 .65796 L .51287 .65697 L F
.767 .309 .162 r
.55048 .73306 m .55357 .73402 L .55197 .73306 L F
.73 .619 .734 r
.53523 .78149 m .5384 .78122 L .53808 .77854 L F
.549 .211 .348 r
.53501 .78369 m .5384 .78122 L .53523 .78149 L F
.53501 .78369 m .53744 .7833 L .5384 .78122 L F
.633 .205 .213 r
.53972 .78323 m .5384 .78122 L .53744 .7833 L F
.53972 .78323 m .54068 .78189 L .5384 .78122 L F
.87 .653 .607 r
.62556 .52813 m .62729 .53127 L .62537 .53044 L F
.906 .712 .63 r
.62645 .53348 m .62537 .53044 L .62729 .53127 L F
.667 .719 .888 r
.71237 .51816 m .7138 .51534 L .71149 .51702 L F
.71237 .51816 m .71458 .51747 L .7138 .51534 L F
.499 .396 .668 r
.56791 .70679 m .56609 .70779 L .56729 .70741 L F
0 0 0 r
.56873 .70559 m .56729 .70741 L .56609 .70779 L F
.727 .522 .614 r
.57299 .60434 m .56944 .60602 L .56945 .60397 L F
.57299 .60434 m .57292 .60674 L .56944 .60602 L F
.651 .813 .961 r
.69284 .52522 m .69057 .52613 L .68942 .52486 L F
.531 .29 .494 r
.57685 .70279 m .57663 .70509 L .57429 .70524 L F
.741 .659 .769 r
.57926 .69979 m .57685 .70279 L .57742 .70085 L F
.463 .273 .537 r
.57926 .69979 m .57909 .70228 L .57685 .70279 L F
.442 .215 .473 r
.57909 .70228 m .57663 .70509 L .57685 .70279 L F
.62 .421 .59 r
.52699 .78662 m .52471 .78944 L .52505 .78724 L F
.451 .636 .934 r
.69752 .51382 m .69827 .51513 L .69766 .51336 L F
.964 .907 .711 r
.69766 .51336 m .69827 .51513 L .69632 .51885 L F
.772 .997 .854 r
.69632 .51885 m .6959 .51957 L .69611 .51831 L F
.914 .741 .248 r
.6959 .51957 m .69538 .52058 L .69611 .51831 L F
.6959 .51957 m .69578 .5222 L .69538 .52058 L F
.68 .566 .72 r
.55353 .61217 m .55118 .61271 L .55342 .60982 L F
.699 .436 .522 r
.55276 .61471 m .55118 .61271 L .55353 .61217 L F
.55276 .61471 m .55116 .61493 L .55118 .61271 L F
.949 .831 .693 r
.52782 .78174 m .52758 .77765 L .52565 .78126 L F
.769 .393 .344 r
.52629 .78326 m .52782 .78174 L .52565 .78126 L F
.52629 .78326 m .52924 .78371 L .52782 .78174 L F
.452 .218 .468 r
.61452 .50022 m .61679 .49965 L .61688 .49761 L F
.434 .208 .47 r
.61679 .49965 m .61924 .49687 L .61688 .49761 L F
.302 0 0 r
.7743 .57809 m .77792 .57813 L .77529 .57783 L F
.58 .273 .413 r
.50756 .78115 m .50871 .77892 L .50587 .78039 L F
.65 .97 .867 r
.5107 .77751 m .50871 .77892 L .50945 .77771 L F
0 0 0 r
.50945 .77771 m .50871 .77892 L .50756 .78115 L F
.865 .447 .225 r
.59797 .7077 m .60067 .71033 L .59862 .70831 L F
.434 .233 .507 r
.4733 .79535 m .47137 .79574 L .47116 .79826 L F
.234 0 0 r
.693 .51317 m .69603 .51151 L .69376 .51436 L F
0 0 .221 r
.6942 .51544 m .69376 .51436 L .693 .51317 L F
.6942 .51544 m .69426 .51698 L .69376 .51436 L F
.687 .329 .363 r
.6922 .51515 m .6942 .51544 L .693 .51317 L F
.649 .661 .848 r
.69038 .51587 m .6907 .51717 L .69302 .5162 L F
.69038 .51587 m .69302 .5162 L .6922 .51515 L F
.61 .724 .926 r
.6922 .51515 m .69302 .5162 L .6942 .51544 L F
.812 .553 .548 r
.6942 .51544 m .69189 .51699 L .69417 .51456 L F
.6942 .51544 m .69417 .51456 L .69418 .51455 L F
0 0 .221 r
.6942 .51544 m .6943 .51718 L .69426 .51698 L F
.237 .215 .63 r
.47133 .7703 m .47313 .77248 L .47292 .76906 L F
0 .109 .655 r
.47243 .77241 m .47313 .77248 L .47133 .7703 L F
.933 .571 .16 r
.5393 .73718 m .54033 .74092 L .53882 .73812 L F
0 0 0 r
.5393 .73718 m .53882 .73812 L .54009 .73635 L F
0 0 .416 r
.68362 .52774 m .68394 .52719 L .68311 .52459 L F
.963 .828 .662 r
.68362 .52774 m .68148 .53002 L .68394 .52719 L F
.68362 .52774 m .68264 .53106 L .68148 .53002 L F
.375 .041 .266 r
.54187 .73353 m .54467 .73086 L .54247 .73066 L F
0 0 0 r
.73489 .50908 m .7346 .51085 L .73474 .51104 L F
.73489 .50908 m .73474 .51104 L .73456 .5075 L F
.41 0 .092 r
.45345 .69942 m .45187 .70122 L .44954 .70141 L F
.318 0 0 r
.45553 .69944 m .45187 .70122 L .45345 .69942 L F
.951 .854 .71 r
.65814 .5116 m .65627 .51244 L .65741 .51089 L F
.65814 .5116 m .65739 .51362 L .65627 .51244 L F
.977 .726 .313 r
.65814 .5116 m .65741 .51089 L .65729 .50811 L F
.766 .695 .784 r
.56702 .71649 m .56873 .71956 L .56525 .71924 L F
.143 .362 .819 r
.56702 .71649 m .56973 .71866 L .56873 .71956 L F
.355 .717 .986 r
.56973 .71866 m .57035 .71917 L .56873 .71956 L F
.423 .474 .808 r
.57175 .7211 m .56873 .71956 L .57035 .71917 L F
.594 .051 0 r
.31009 .64861 m .31326 .64913 L .31071 .64953 L F
0 0 0 r
.31326 .64913 m .31229 .64929 L .31071 .64953 L F
.31326 .64913 m .31541 .64902 L .31229 .64929 L F
.729 .649 .769 r
.27764 .64882 m .28104 .64928 L .27972 .64595 L F
0 .095 .636 r
.27764 .64882 m .27939 .65094 L .28104 .64928 L F
.558 .557 .808 r
.27972 .64595 m .28104 .64928 L .28304 .64875 L F
.8 .586 .612 r
.27939 .65094 m .28304 .64875 L .28104 .64928 L F
.793 .602 .643 r
.5913 .69391 m .59346 .69201 L .59144 .69109 L F
.5913 .69391 m .59341 .69446 L .59346 .69201 L F
0 0 0 r
.59437 .53057 m .59768 .52899 L .59471 .53102 L F
.98 .815 .411 r
.59394 .53265 m .59437 .53057 L .59471 .53102 L F
.424 .252 .542 r
.61452 .50022 m .61669 .50187 L .61679 .49965 L F
.61452 .50022 m .61468 .50272 L .61669 .50187 L F
.793 .877 .447 r
.75276 .5875 m .75384 .5852 L .75392 .58441 L F
.9 .865 .796 r
.66244 .49405 m .66525 .49137 L .66575 .49475 L F
.929 .711 .226 r
.66525 .49137 m .66521 .4937 L .66575 .49475 L F
.829 .531 0 r
.66521 .4937 m .66617 .49674 L .66575 .49475 L F
.678 .264 0 r
.59624 .70183 m .59832 .70535 L .59764 .70262 L F
.703 .539 .663 r
.56579 .71044 m .56711 .71371 L .56393 .7135 L F
.639 .562 .752 r
.56791 .70679 m .56579 .71044 L .5661 .71036 L F
.588 .481 .699 r
.56926 .71251 m .56579 .71044 L .56919 .71076 L F
.56926 .71251 m .56711 .71371 L .56579 .71044 L F
0 0 0 r
.59437 .53057 m .59606 .5298 L .59768 .52899 L F
.564 .201 .311 r
.46133 .69703 m .46329 .6985 L .46123 .69869 L F
.46133 .69703 m .46359 .69712 L .46329 .6985 L F
.578 .591 .83 r
.52041 .6496 m .51828 .6512 L .51776 .64828 L F
.967 .836 .66 r
.7294 .49958 m .73126 .50015 L .7301 .4992 L F
.7294 .49958 m .73041 .50304 L .73126 .50015 L F
.716 .527 .633 r
.51173 .79562 m .51248 .79799 L .50883 .79844 L F
.156 .189 .645 r
.51404 .79708 m .51173 .79562 L .51365 .79471 L F
.51404 .79708 m .51248 .79799 L .51173 .79562 L F
.496 0 0 r
.5118 .76734 m .51039 .76688 L .50956 .76627 L F
.181 0 0 r
.51327 .76759 m .51039 .76688 L .5118 .76734 L F
.702 .621 .763 r
.63933 .50289 m .63478 .50314 L .63509 .49981 L F
.692 .443 .542 r
.63933 .50289 m .63514 .5049 L .63478 .50314 L F
.464 .223 .463 r
.53125 .65515 m .53098 .65717 L .53342 .65465 L F
.53342 .65465 m .53098 .65717 L .53125 .65515 L F
.73 .887 .491 r
.56791 .70679 m .56729 .70741 L .56873 .70559 L F
.725 .623 .743 r
.57082 .70505 m .56791 .70679 L .56873 .70559 L F
.988 .73 .442 r
.56873 .70559 m .56729 .70741 L .56718 .70462 L F
.522 .41 .667 r
.24824 .607 m .24983 .60406 L .24787 .60462 L F
.913 .961 .803 r
.67097 .53112 m .67275 .52709 L .67327 .5288 L F
0 0 0 r
.67275 .52709 m .67182 .529 L .67288 .52746 L F
.67275 .52709 m .67392 .52593 L .67479 .52692 L F
.67275 .52709 m .67288 .52746 L .67392 .52593 L F
0 0 .216 r
.67275 .52709 m .67327 .5288 L .67269 .52692 L F
.67275 .52709 m .67269 .52692 L .67201 .52471 L F
.261 .372 .788 r
.67479 .52692 m .67327 .5288 L .67275 .52709 L F
.67479 .52692 m .67567 .53004 L .67327 .5288 L F
.284 0 0 r
.71458 .51747 m .71749 .51791 L .71744 .51771 L F
.918 .682 .566 r
.54876 .74502 m .54731 .74631 L .54955 .74702 L F
.731 .894 .953 r
.54512 .74778 m .54955 .74702 L .54731 .74631 L F
.918 .682 .566 r
.54955 .74702 m .54731 .74631 L .54876 .74502 L F
.72 .345 0 r
.54955 .74702 m .54928 .74684 L .54731 .74631 L F
.54955 .74702 m .55065 .74964 L .54928 .74684 L F
.51 0 0 r
.40853 .71244 m .40492 .71246 L .40642 .71248 L F
.974 .692 .427 r
.54523 .79202 m .5466 .79262 L .54578 .79538 L F
.595 .639 .865 r
.54744 .78995 m .54896 .79232 L .5466 .79262 L F
.513 .213 .395 r
.5466 .79262 m .54896 .79232 L .54693 .79481 L F
.5466 .79262 m .54693 .79481 L .54775 .79412 L F
.5466 .79262 m .54775 .79412 L .54578 .79538 L F
.328 .012 .268 r
.62912 .48638 m .62863 .48795 L .63125 .48559 L F
0 .103 .627 r
.47723 .77754 m .47644 .77857 L .47579 .7759 L F
.068 0 .458 r
.47772 .77988 m .47644 .77857 L .47723 .77754 L F
.47772 .77988 m .47644 .78099 L .47644 .77857 L F
.706 .661 .803 r
.74328 .49991 m .73963 .49735 L .74202 .4967 L F
.592 .581 .81 r
.74486 .49606 m .74328 .49991 L .74202 .4967 L F
.74486 .49606 m .74579 .49929 L .74328 .49991 L F
.425 .867 .808 r
.45809 .64291 m .45912 .64215 L .46067 .64184 L F
.429 .857 .729 r
.45809 .64291 m .45717 .64323 L .45912 .64215 L F
.487 .08 .194 r
.59068 .72449 m .58966 .7266 L .58725 .7258 L F
.604 .158 .165 r
.59068 .72449 m .59185 .7266 L .58965 .72663 L F
.59068 .72449 m .5932 .72503 L .59185 .7266 L F
.62 .635 .844 r
.59123 .72648 m .59093 .72375 L .58749 .72572 L F
.59185 .7266 m .59179 .72643 L .59123 .72648 L F
.59179 .72643 m .59093 .72375 L .59123 .72648 L F
.487 .08 .194 r
.58966 .7266 m .58965 .72663 L .58958 .7266 L F
.58966 .7266 m .58958 .7266 L .58725 .7258 L F
.795 .761 .822 r
.63601 .55683 m .63667 .55269 L .6359 .55492 L F
.63601 .55683 m .63839 .55414 L .63667 .55269 L F
.941 .963 .727 r
.63421 .55783 m .63601 .55683 L .6359 .55492 L F
.443 .105 .297 r
.36681 .61516 m .36974 .61304 L .36906 .61487 L F
.377 .064 .302 r
.37116 .61427 m .36974 .61304 L .37176 .61241 L F
.37116 .61427 m .36906 .61487 L .36974 .61304 L F
.965 .93 .614 r
.5263 .65165 m .52576 .65308 L .52651 .6532 L F
.968 .899 .7 r
.52576 .65308 m .52515 .6572 L .52651 .6532 L F
.53 .84 .999 r
.33618 .58913 m .33551 .5904 L .334 .58947 L F
.33618 .58913 m .33764 .58986 L .33551 .5904 L F
.784 .766 .837 r
.49276 .64349 m .49057 .64597 L .49397 .64611 L F
.804 .705 .757 r
.49057 .64597 m .49177 .64921 L .49397 .64611 L F
.718 .736 .866 r
.49276 .64349 m .49397 .64611 L .49633 .64412 L F
.323 .749 .973 r
.2424 .63178 m .2441 .63174 L .2451 .63239 L F
.772 .332 .205 r
.2451 .63239 m .24352 .63293 L .2424 .63178 L F
.951 .92 .744 r
.2441 .63174 m .24352 .63293 L .2451 .63239 L F
.047 .568 .87 r
.77024 .60381 m .77116 .60455 L .76843 .60388 L F
.452 0 0 r
.77116 .60455 m .77298 .60514 L .76843 .60388 L F
.144 .444 .878 r
.77241 .60678 m .76843 .60388 L .77298 .60514 L F
.62 .636 .845 r
.7684 .60484 m .769 .60693 L .77134 .60607 L F
.047 .568 .87 r
.76866 .60469 m .76843 .60388 L .76807 .60502 L F
.77016 .60382 m .76843 .60388 L .76866 .60469 L F
.61 .685 .896 r
.76791 .60464 m .77024 .60381 L .76926 .60173 L F
.603 .641 .861 r
.76791 .60464 m .76821 .60477 L .77024 .60381 L F
.047 .568 .87 r
.77024 .60381 m .77016 .60382 L .76866 .60469 L F
.615 .688 .895 r
.76866 .60469 m .77024 .60381 L .76821 .60477 L F
.603 .641 .861 r
.76821 .60477 m .77134 .60607 L .77024 .60381 L F
.615 .688 .895 r
.76821 .60477 m .77024 .60381 L .76815 .60478 L F
.76815 .60478 m .77024 .60381 L .76926 .60173 L F
.76807 .60502 m .76866 .60469 L .76815 .60478 L F
.62 .636 .845 r
.76821 .60477 m .76809 .60502 L .7684 .60484 L F
.61 .685 .896 r
.76791 .60464 m .76926 .60173 L .76684 .60222 L F
.615 .688 .895 r
.76794 .60474 m .76926 .60173 L .76684 .60222 L F
.76807 .60502 m .76815 .60478 L .76794 .60474 L F
.62 .636 .845 r
.76791 .60464 m .76796 .60474 L .76821 .60477 L F
.76796 .60474 m .76815 .60478 L .76821 .60477 L F
.615 .688 .895 r
.76815 .60478 m .76926 .60173 L .76794 .60474 L F
.62 .636 .845 r
.76796 .60474 m .76799 .6048 L .76815 .60478 L F
.76799 .6048 m .76809 .60502 L .76821 .60477 L F
.76809 .60502 m .769 .60693 L .7684 .60484 L F
.836 .747 .765 r
.66371 .51658 m .66753 .51506 L .66636 .5129 L F
.66371 .51658 m .66593 .51728 L .66753 .51506 L F
.463 .625 .922 r
.66636 .5129 m .66753 .51506 L .66842 .51287 L F
.624 .809 .971 r
.66842 .51287 m .66753 .51506 L .66969 .51442 L F
.556 .356 .565 r
.38906 .66024 m .3911 .66231 L .3914 .65987 L F
.38906 .66024 m .38882 .66272 L .3911 .66231 L F
.39 .184 .476 r
.24977 .60163 m .25204 .60089 L .25201 .59827 L F
.382 .241 .563 r
.24977 .60163 m .25158 .60267 L .25204 .60089 L F
.24977 .60163 m .24983 .60406 L .25158 .60267 L F
.17 .708 .796 r
.33802 .60179 m .33542 .60177 L .33388 .6021 L F
.115 .667 .77 r
.33805 .60163 m .33802 .60179 L .3401 .60102 L F
.33805 .60163 m .33542 .60177 L .33802 .60179 L F
.64 .901 .984 r
.45396 .65822 m .44871 .6595 L .44991 .6598 L F
.81 .42 .317 r
.55048 .73306 m .55409 .73563 L .55357 .73402 L F
0 .33 .803 r
.51553 .76987 m .51606 .76944 L .51327 .76759 L F
0 0 .573 r
.51553 .76987 m .5171 .77222 L .51606 .76944 L F
.728 .718 .84 r
.4868 .7873 m .48333 .78656 L .48537 .7889 L F
.423 .055 .233 r
.48804 .78912 m .4868 .7873 L .48537 .7889 L F
.48804 .78912 m .48885 .78711 L .4868 .7873 L F
.894 .989 .758 r
.56593 .57079 m .56367 .57375 L .56412 .57191 L F
.839 .997 .773 r
.56835 .56787 m .56593 .57079 L .5664 .56909 L F
.84 .996 .762 r
.56593 .57079 m .56412 .57191 L .5664 .56909 L F
.103 .292 .77 r
.48752 .81597 m .48798 .81424 L .48589 .81515 L F
.48752 .81597 m .48932 .81727 L .48798 .81424 L F
.508 .358 .612 r
.38149 .60129 m .38159 .60374 L .37951 .60428 L F
.482 .286 .538 r
.38159 .60374 m .37932 .60676 L .37951 .60428 L F
.625 .876 .989 r
.69726 .50984 m .69828 .51069 L .69603 .51151 L F
0 .041 .61 r
.69603 .51151 m .69727 .51218 L .69726 .50984 L F
.69603 .51151 m .69752 .51382 L .69742 .51318 L F
.859 .711 .696 r
.69754 .51343 m .69611 .51831 L .6942 .51544 L F
.39 .651 .962 r
.69727 .51218 m .69752 .51382 L .69766 .51336 L F
.859 .711 .696 r
.69766 .51336 m .6976 .51356 L .69754 .51343 L F
.6976 .51356 m .69611 .51831 L .69754 .51343 L F
0 .041 .61 r
.69686 .51196 m .69742 .51318 L .69727 .51218 L F
.69603 .51151 m .69742 .51318 L .69686 .51196 L F
.624 .461 .641 r
.51327 .66874 m .51639 .67064 L .51503 .66743 L F
.51327 .66874 m .51333 .67206 L .51639 .67064 L F
.477 .489 .791 r
.75021 .59861 m .75134 .59505 L .74903 .59544 L F
.75021 .59861 m .75253 .59867 L .75134 .59505 L F
.798 .664 .716 r
.55771 .6145 m .55512 .61544 L .55698 .61256 L F
.679 .452 .571 r
.55771 .6145 m .55467 .61778 L .55512 .61544 L F
.55771 .6145 m .55731 .61785 L .55467 .61778 L F
.639 .404 .546 r
.56025 .61493 m .55731 .61785 L .55771 .6145 L F
.738 .542 .629 r
.58741 .58121 m .59109 .57904 L .58797 .57885 L F
.58741 .58121 m .59105 .58152 L .59109 .57904 L F
.604 .588 .809 r
.67003 .50282 m .66697 .50035 L .66918 .50018 L F
.958 .79 .63 r
.66868 .50086 m .66811 .50387 L .66939 .50461 L F
0 .367 .805 r
.66956 .5044 m .66939 .50461 L .66811 .50387 L F
.67096 .50492 m .66939 .50461 L .66956 .5044 L F
0 0 0 r
.66919 .50485 m .66939 .50461 L .66887 .50559 L F
.67003 .50282 m .66939 .50461 L .66919 .50485 L F
0 .137 .68 r
.66939 .50461 m .67065 .50752 L .66887 .50559 L F
.766 .743 .832 r
.48512 .64839 m .48676 .65072 L .48829 .64864 L F
.475 .697 .965 r
.25368 .61858 m .25521 .61767 L .25279 .61765 L F
.988 .809 .573 r
.2554 .62068 m .25521 .61767 L .25368 .61858 L F
.948 .956 .674 r
.5669 .77337 m .56614 .77238 L .56481 .77242 L F
0 0 0 r
.56679 .77439 m .56603 .77558 L .5669 .77337 L F
.56679 .77439 m .5669 .77337 L .56481 .77242 L F
.339 .086 .376 r
.25201 .59827 m .25401 .59791 L .25453 .59551 L F
.295 .113 .456 r
.25201 .59827 m .25344 .59998 L .25401 .59791 L F
.25201 .59827 m .25204 .60089 L .25344 .59998 L F
.778 .822 .887 r
.67145 .48255 m .67499 .48227 L .67427 .48073 L F
.766 .859 .919 r
.67427 .48073 m .67499 .48227 L .67722 .48036 L F
.012 0 0 r
.54009 .73635 m .54179 .73604 L .54147 .73558 L F
.54009 .73635 m .53882 .73812 L .54179 .73604 L F
.437 .853 .694 r
.48631 .77265 m .48735 .77187 L .48927 .77093 L F
.501 .416 .691 r
.48571 .77452 m .48735 .77187 L .48631 .77265 L F
.307 .696 .978 r
.35698 .59101 m .35661 .59203 L .35506 .59098 L F
.35698 .59101 m .35844 .59202 L .35661 .59203 L F
.388 0 .075 r
.41556 .65395 m .41921 .65194 L .41597 .65249 L F
.41556 .65395 m .41784 .6537 L .41921 .65194 L F
.439 .014 .133 r
.41784 .6537 m .42147 .65171 L .41921 .65194 L F
.483 .718 .974 r
.50456 .63267 m .50341 .63427 L .5018 .63257 L F
.50456 .63267 m .50554 .63396 L .50341 .63427 L F
0 0 0 r
.44991 .64552 m .45117 .6453 L .4522 .64472 L F
.4522 .64472 m .45335 .6447 L .45505 .64414 L F
.4522 .64472 m .45117 .6453 L .45335 .6447 L F
.932 .673 .521 r
.53629 .78681 m .53743 .78893 L .53617 .79 L F
0 .247 .739 r
.53847 .78931 m .53743 .78893 L .53629 .78681 L F
.765 .692 .781 r
.59071 .71401 m .59184 .71665 L .59431 .71463 L F
.704 .434 .514 r
.59162 .71922 m .59404 .71885 L .59184 .71665 L F
.637 .452 .616 r
.42296 .67128 m .42041 .67364 L .42058 .67168 L F
.772 .958 .643 r
.49322 .81554 m .49543 .8127 L .49381 .81408 L F
.58 .615 .852 r
.49736 .81189 m .49543 .8127 L .49417 .81126 L F
0 0 0 r
.49381 .81408 m .49543 .8127 L .49736 .81189 L F
.221 .521 .916 r
.49859 .81479 m .50213 .81706 L .50107 .81452 L F
.362 .055 .304 r
.55964 .70533 m .56148 .70489 L .56189 .70325 L F
.645 .41 .548 r
.56148 .70489 m .56395 .70245 L .56189 .70325 L F
.723 .304 .251 r
.31183 .6319 m .31369 .63388 L .31534 .63239 L F
.094 0 0 r
.31369 .63388 m .31748 .63243 L .31534 .63239 L F
.821 .593 .594 r
.58593 .57811 m .58799 .57616 L .58588 .57581 L F
.58593 .57811 m .58797 .57885 L .58799 .57616 L F
.761 .7 .794 r
.59071 .71401 m .59431 .71463 L .59264 .71284 L F
.863 .663 .631 r
.59529 .71421 m .59264 .71284 L .59431 .71463 L F
.467 .498 .807 r
.59431 .71463 m .59694 .71541 L .59529 .71421 L F
.911 .585 .108 r
.65845 .49746 m .65766 .4964 L .65711 .49392 L F
.994 .773 .407 r
.65838 .49975 m .65766 .4964 L .65845 .49746 L F
.818 .4 .249 r
.71625 .49134 m .71719 .49199 L .71431 .49104 L F
.692 .443 .542 r
.63933 .50289 m .63849 .50542 L .63514 .5049 L F
.325 .184 .53 r
.64064 .49999 m .64067 .50233 L .63933 .50289 L F
.235 0 .337 r
.64067 .50233 m .63849 .50542 L .63933 .50289 L F
0 0 .116 r
.54825 .76385 m .55124 .7603 L .54919 .76194 L F
.737 .68 .134 r
.67634 .53177 m .67664 .53012 L .67567 .53004 L F
.757 .66 .754 r
.67794 .52718 m .67908 .53068 L .67659 .53021 L F
.6768 .52861 m .67659 .53021 L .67567 .53004 L F
.67794 .52718 m .67659 .53021 L .6768 .52861 L F
.737 .68 .134 r
.67649 .53095 m .67604 .53436 L .67664 .53012 L F
.67634 .53177 m .6764 .5316 L .67649 .53095 L F
.599 .313 .455 r
.67567 .53004 m .67811 .53182 L .67634 .53177 L F
0 0 0 r
.6773 .53146 m .67634 .53177 L .67811 .53182 L F
.6773 .53146 m .67626 .53197 L .67634 .53177 L F
.862 .913 .865 r
.67244 .53431 m .67634 .53177 L .67442 .53286 L F
0 0 0 r
.67626 .53197 m .67442 .53286 L .67634 .53177 L F
.737 .68 .134 r
.67634 .53177 m .6761 .53384 L .6764 .5316 L F
.6761 .53384 m .67604 .53436 L .67649 .53095 L F
.455 .265 .532 r
.35923 .62544 m .35742 .62397 L .35949 .62342 L F
.35923 .62544 m .35725 .62609 L .35742 .62397 L F
.354 .67 .975 r
.51764 .77486 m .51745 .77614 L .51882 .77586 L F
.228 0 .298 r
.51745 .77614 m .51655 .77817 L .51882 .77586 L F
.375 .041 .266 r
.54187 .73353 m .54378 .73321 L .54467 .73086 L F
.626 .285 .374 r
.54467 .73086 m .54378 .73321 L .54696 .73272 L F
.175 0 .346 r
.61237 .50573 m .61441 .50467 L .61468 .50272 L F
0 0 .279 r
.61237 .50573 m .61343 .50631 L .61441 .50467 L F
.61237 .50573 m .61258 .50765 L .61343 .50631 L F
.311 .684 .977 r
.30268 .58412 m .30194 .58494 L .30052 .58389 L F
.30268 .58412 m .30413 .5851 L .30194 .58494 L F
.449 .758 .995 r
.31125 .58601 m .30745 .58529 L .3097 .58554 L F
.479 .85 .988 r
.31187 .58504 m .31125 .58601 L .3097 .58554 L F
.31187 .58504 m .313 .58551 L .31125 .58601 L F
.98 .741 .331 r
.72957 .49591 m .73027 .4946 L .72936 .49355 L F
.72957 .49591 m .73031 .49688 L .73027 .4946 L F
.236 .736 .904 r
.32501 .58779 m .328 .58782 L .32618 .58809 L F
.538 .627 .888 r
.54598 .77882 m .54901 .77938 L .54774 .77742 L F
.649 .573 .756 r
.2474 .63162 m .24857 .63517 L .25023 .6329 L F
.669 .6 .768 r
.55912 .60954 m .55567 .60697 L .5578 .60634 L F
.649 .548 .726 r
.56171 .60708 m .55912 .60954 L .5578 .60634 L F
.792 .681 .741 r
.54769 .60996 m .54739 .61221 L .54393 .61183 L F
.788 .696 .763 r
.54739 .61221 m .54521 .61464 L .54393 .61183 L F
.001 .578 .714 r
.65419 .48239 m .65651 .48241 L .65765 .48242 L F
.157 0 0 r
.65765 .48242 m .65651 .48241 L .65997 .48271 L F
0 0 .114 r
.60917 .5146 m .60849 .51635 L .61059 .51336 L F
.926 .969 .684 r
.59924 .55347 m .59891 .55291 L .59729 .55606 L F
.408 .661 .963 r
.36967 .59503 m .36883 .59645 L .36759 .59491 L F
.36967 .59503 m .37128 .59666 L .36883 .59645 L F
.799 .925 .92 r
.71008 .50874 m .70731 .51098 L .70628 .51018 L F
.728 .822 .923 r
.47456 .65148 m .47802 .65053 L .47602 .64915 L F
0 .07 .567 r
.3873 .70149 m .38821 .70231 L .38863 .70285 L F
.705 .436 .515 r
.53501 .78369 m .53282 .78118 L .53161 .78367 L F
.53501 .78369 m .53523 .78149 L .53282 .78118 L F
.78 .71 .786 r
.57452 .72205 m .57571 .72535 L .57217 .72441 L F
.471 0 0 r
.57571 .72535 m .57448 .7253 L .57217 .72441 L F
.784 .712 .784 r
.57809 .72236 m .57571 .72535 L .57452 .72205 L F
.36 0 0 r
.57796 .72551 m .57448 .7253 L .57571 .72535 L F
.674 .633 .801 r
.34341 .60248 m .34728 .60422 L .34568 .60214 L F
.465 .611 .91 r
.34568 .60214 m .34728 .60422 L .34813 .60249 L F
.25 .346 .767 r
.34728 .60422 m .34945 .606 L .34813 .60249 L F
.53 .354 .587 r
.34721 .6065 m .34945 .606 L .34728 .60422 L F
.667 .683 .856 r
.66664 .52454 m .66974 .52546 L .66849 .52408 L F
.643 .77 .94 r
.66849 .52408 m .66974 .52546 L .67201 .52471 L F
.508 .599 .88 r
.37343 .59666 m .37239 .59886 L .37128 .59666 L F
.536 .633 .894 r
.37343 .59666 m .37458 .59854 L .37239 .59886 L F
.523 .804 .997 r
.33977 .58941 m .34112 .59037 L .33764 .58986 L F
.386 .716 .988 r
.34172 .58925 m .34112 .59037 L .33977 .58941 L F
.34172 .58925 m .34325 .59043 L .34112 .59037 L F
.11 0 0 r
.54764 .77063 m .54662 .77128 L .54373 .77154 L F
.361 0 0 r
.54764 .77063 m .54859 .77152 L .54662 .77128 L F
.54764 .77063 m .54983 .7714 L .54859 .77152 L F
.756 .77 .864 r
.769 .60693 m .76997 .60891 L .77241 .60678 L F
.679 .74 .897 r
.76997 .60891 m .77193 .60806 L .77241 .60678 L F
0 0 0 r
.44991 .64552 m .449 .64592 L .45117 .6453 L F
.031 .18 .686 r
.47042 .80118 m .4719 .80329 L .47106 .80038 L F
.401 .141 .401 r
.34894 .63373 m .34747 .63229 L .34944 .6317 L F
.34894 .63373 m .34697 .63432 L .34747 .63229 L F
.784 .666 .734 r
.50657 .79817 m .50416 .80088 L .50417 .79877 L F
.792 .772 .835 r
.50657 .79817 m .50417 .79877 L .50467 .79733 L F
.885 .586 .476 r
.50657 .79817 m .50462 .79962 L .50467 .79733 L F
.454 .2 .438 r
.50651 .80032 m .50416 .80088 L .50657 .79817 L F
0 0 .574 r
.50523 .79503 m .50657 .79817 L .50693 .79728 L F
.863 .544 .447 r
.50657 .79817 m .50651 .80032 L .50462 .79962 L F
.73 .504 .585 r
.50883 .79844 m .50651 .80032 L .50657 .79817 L F
.605 .404 .583 r
.50538 .7999 m .50755 .79811 L .50693 .79728 L F
.50755 .79811 m .50944 .79654 L .50693 .79728 L F
0 0 .574 r
.50517 .79489 m .50523 .79503 L .50693 .79728 L F
.634 .929 .669 r
.50657 .79817 m .50462 .79962 L .50693 .79728 L F
.763 .606 .684 r
.45122 .68874 m .45079 .69104 L .45406 .69073 L F
.624 .213 .243 r
.45079 .69104 m .45274 .69256 L .45406 .69073 L F
.325 0 0 r
.45274 .69256 m .45651 .69094 L .45406 .69073 L F
.507 .4 .667 r
.38554 .67466 m .38734 .67098 L .38554 .67162 L F
.522 .41 .667 r
.24824 .607 m .25025 .60649 L .24983 .60406 L F
.551 .435 .674 r
.24824 .607 m .25083 .60906 L .25025 .60649 L F
.24824 .607 m .24853 .60968 L .25083 .60906 L F
.594 .583 .811 r
.74663 .59594 m .74793 .59224 L .74556 .5929 L F
.74663 .59594 m .74903 .59544 L .74793 .59224 L F
.498 .024 .058 r
.4751 .69477 m .47738 .69576 L .47559 .69558 L F
.881 .874 .825 r
.52379 .80736 m .52586 .80711 L .52314 .81015 L F
.853 .537 .453 r
.52643 .80962 m .52586 .80711 L .52379 .80736 L F
.897 .981 .702 r
.57253 .56221 m .57058 .56534 L .57097 .56331 L F
.825 .991 .738 r
.57253 .56221 m .57318 .56038 L .57481 .5594 L F
.824 .984 .705 r
.57097 .56331 m .57318 .56038 L .57253 .56221 L F
.935 .955 .766 r
.67097 .53112 m .6686 .53314 L .67015 .53049 L F
.67097 .53112 m .66923 .53396 L .6686 .53314 L F
.913 .961 .803 r
.67097 .53112 m .67015 .53049 L .67275 .52709 L F
.385 0 .114 r
.43373 .70504 m .43233 .70703 L .43012 .70731 L F
.204 0 .008 r
.43442 .70625 m .43373 .70504 L .43594 .70477 L F
.43442 .70625 m .43233 .70703 L .43373 .70504 L F
.294 0 0 r
.54262 .76579 m .54502 .76599 L .54643 .76491 L F
.328 .076 .371 r
.25453 .59551 m .25577 .59708 L .25652 .59496 L F
.25453 .59551 m .25401 .59791 L .25577 .59708 L F
.671 .46 .591 r
.5646 .60979 m .565 .61217 L .56288 .61204 L F
.672 .575 .738 r
.56722 .60689 m .5646 .60979 L .5632 .60643 L F
.691 .72 .871 r
.24281 .63584 m .24451 .63487 L .24206 .63481 L F
.768 .678 .763 r
.50392 .79174 m .50166 .79458 L .50266 .79247 L F
.737 .579 .678 r
.55698 .61256 m .55276 .61471 L .55353 .61217 L F
.726 .615 .733 r
.57717 .69367 m .57849 .69837 L .5747 .69642 L F
.716 .597 .722 r
.57926 .69979 m .5747 .69642 L .57849 .69837 L F
.166 .248 .705 r
.57942 .69582 m .57849 .69837 L .57717 .69367 L F
0 0 .256 r
.57942 .69582 m .57926 .69979 L .57849 .69837 L F
.669 .687 .858 r
.25662 .63294 m .26015 .63428 L .25844 .63185 L F
.784 .757 .829 r
.25844 .63185 m .26015 .63428 L .26227 .63217 L F
.455 .241 .498 r
.26015 .63428 m .26248 .63416 L .26227 .63217 L F
.447 .204 .452 r
.26015 .63428 m .25953 .63696 L .26248 .63416 L F
.953 .894 .732 r
.58799 .56986 m .59083 .56704 L .58961 .56635 L F
.58799 .56986 m .58874 .57023 L .59083 .56704 L F
.871 .94 .861 r
.58961 .56635 m .59083 .56704 L .59295 .56454 L F
.989 .754 .372 r
.65711 .49392 m .65634 .49058 L .65744 .49188 L F
.452 .243 .504 r
.36177 .62056 m .35949 .62342 L .35965 .62113 L F
.552 .925 .926 r
.48283 .75597 m .48377 .7549 L .48491 .75503 L F
.48283 .75597 m .48377 .7549 L .48491 .75503 L F
.794 .468 .436 r
.55855 .72465 m .55738 .72544 L .55584 .72405 L F
.038 .606 .761 r
.56081 .72556 m .55738 .72544 L .55855 .72465 L F
.726 .667 .792 r
.48829 .64864 m .49177 .64921 L .49057 .64597 L F
.719 .265 .173 r
.54914 .73931 m .5488 .74121 L .54597 .73869 L F
.936 .563 .203 r
.54914 .73931 m .55 .74201 L .5488 .74121 L F
.476 .404 .697 r
.41519 .67976 m .41306 .67714 L .41462 .67668 L F
.41519 .67976 m .4135 .68036 L .41306 .67714 L F
.498 .12 .254 r
.37715 .60679 m .3794 .6071 L .37714 .60748 L F
.37715 .60679 m .37932 .60676 L .3794 .6071 L F
.546 .277 .46 r
.3914 .65987 m .39366 .65936 L .394 .65763 L F
.487 .291 .539 r
.39622 .65476 m .394 .65763 L .39606 .65711 L F
.508 .273 .493 r
.39366 .65936 m .39606 .65711 L .394 .65763 L F
.634 .555 .748 r
.57352 .70677 m .57082 .70505 L .57429 .70524 L F
.223 0 0 r
.57663 .70509 m .57352 .70677 L .57429 .70524 L F
.935 .78 .665 r
.65739 .51362 m .65485 .51568 L .65627 .51244 L F
.65739 .51362 m .65629 .51676 L .65485 .51568 L F
.159 .016 .423 r
.55043 .77234 m .54853 .77558 L .55059 .77485 L F
.145 0 .138 r
.55059 .77485 m .54853 .77558 L .54774 .77742 L F
.862 .993 .823 r
.56856 .56622 m .57058 .56534 L .56835 .56787 L F
.878 .993 .772 r
.5664 .56909 m .56856 .56622 L .56835 .56787 L F
.499 .769 .992 r
.52352 .78138 m .52565 .78126 L .52494 .77995 L F
.769 .431 .414 r
.5228 .78312 m .52352 .78138 L .52224 .78111 L F
.5228 .78312 m .52565 .78126 L .52352 .78138 L F
.603 .324 .466 r
.29897 .64882 m .29928 .64981 L .29641 .64891 L F
.225 .637 .956 r
.29928 .64981 m .29675 .64896 L .29641 .64891 L F
.29675 .64896 m .29443 .64818 L .29641 .64891 L F
0 0 0 r
.29641 .64891 m .29552 .64889 L .29593 .64884 L F
.29641 .64891 m .29593 .64884 L .29722 .64867 L F
.25413 .62863 m .25444 .63024 L .25494 .62911 L F
.877 .989 .818 r
.57524 .55721 m .57713 .55661 L .57481 .5594 L F
.894 .986 .729 r
.57481 .5594 m .57318 .56038 L .57524 .55721 L F
.649 .448 .599 r
.55477 .71082 m .55768 .71097 L .55741 .70826 L F
.404 .27 .583 r
.55741 .70826 m .55963 .71003 L .55982 .70771 L F
.55741 .70826 m .55768 .71097 L .55963 .71003 L F
.608 .705 .913 r
.47077 .64994 m .47456 .65148 L .47343 .65024 L F
.674 .792 .938 r
.47343 .65024 m .47456 .65148 L .47602 .64915 L F
.547 .097 .134 r
.52153 .8034 m .52026 .80255 L .51738 .8042 L F
.926 .974 .726 r
.49189 .7962 m .49408 .79498 L .49296 .79486 L F
.053 0 0 r
.31748 .63243 m .31978 .63246 L .3211 .63239 L F
.162 .701 .754 r
.31978 .63246 m .32327 .63198 L .3211 .63239 L F
.482 .44 .734 r
.51186 .65973 m .51287 .65697 L .51091 .65796 L F
.489 .168 .348 r
.34502 .63499 m .3442 .63746 L .34187 .63776 L F
.398 .105 .346 r
.34697 .63432 m .3442 .63746 L .34502 .63499 L F
.583 .74 .95 r
.30048 .62916 m .30034 .63147 L .29852 .62951 L F
.30048 .62916 m .30264 .63097 L .30034 .63147 L F
.36 0 .155 r
.44468 .6931 m .44758 .6913 L .44529 .6915 L F
.299 0 0 r
.44192 .7031 m .44041 .70434 L .43817 .70452 L F
.405 0 0 r
.44412 .70294 m .44041 .70434 L .44192 .7031 L F
.17 .411 .851 r
.75609 .59189 m .75479 .59291 L .75443 .59174 L F
.75609 .59189 m .75801 .59516 L .75479 .59291 L F
.584 .832 .992 r
.68541 .47583 m .68192 .47548 L .68427 .47461 L F
.645 .829 .971 r
.68766 .47488 m .68541 .47583 L .68427 .47461 L F
.931 .789 .682 r
.73049 .51079 m .72915 .51406 L .73059 .5132 L F
.936 .906 .768 r
.72824 .51579 m .73059 .5132 L .72915 .51406 L F
.594 .788 .973 r
.76952 .57991 m .77112 .57808 L .76869 .57896 L F
.76952 .57991 m .77212 .57921 L .77112 .57808 L F
.725 .685 .812 r
.5423 .61242 m .54319 .61578 L .53965 .6152 L F
.755 .703 .802 r
.54521 .61464 m .54319 .61578 L .5423 .61242 L F
.44 .157 .386 r
.33389 .62407 m .33548 .62548 L .33605 .62367 L F
.33389 .62407 m .33338 .62599 L .33548 .62548 L F
.708 .768 .899 r
.68264 .53106 m .6802 .532 L .67908 .53068 L F
.411 0 .009 r
.42695 .65057 m .42936 .65049 L .42735 .64993 L F
.755 .703 .802 r
.54521 .61464 m .5423 .61242 L .54393 .61183 L F
.583 .308 .465 r
.51674 .78953 m .51582 .79236 L .51345 .79227 L F
.618 .288 .389 r
.51674 .78953 m .51905 .79178 L .51582 .79236 L F
.51674 .78953 m .51909 .78973 L .51905 .79178 L F
.405 .105 .34 r
.33605 .62367 m .33816 .62316 L .33877 .62065 L F
.286 .078 .413 r
.33877 .62065 m .34069 .6202 L .34076 .61787 L F
.384 .087 .333 r
.33877 .62065 m .34016 .62251 L .34069 .6202 L F
.33877 .62065 m .33816 .62316 L .34016 .62251 L F
.923 .969 .771 r
.65404 .48996 m .65302 .49174 L .6548 .4886 L F
.598 .7 .915 r
.50213 .81706 m .50338 .81469 L .50107 .81452 L F
.50213 .81706 m .50391 .81667 L .50338 .81469 L F
.01 0 0 r
.55317 .75157 m .55224 .75131 L .55081 .75219 L F
.55317 .75157 m .55427 .75043 L .55224 .75131 L F
.669 .684 .855 r
.75468 .58119 m .75791 .58185 L .75564 .58302 L F
.956 .808 .657 r
.66383 .51832 m .66593 .51728 L .66371 .51658 L F
.66383 .51832 m .66509 .51941 L .66593 .51728 L F
.447 .217 .47 r
.66593 .51728 m .66509 .51941 L .66743 .51891 L F
.705 .801 .925 r
.72283 .48622 m .71987 .48794 L .71907 .48597 L F
.988 .874 .625 r
.56915 .75263 m .56827 .75544 L .56923 .7562 L F
.978 .732 .321 r
.56827 .75544 m .56905 .75819 L .56923 .7562 L F
.648 .596 .782 r
.67256 .51589 m .67078 .51702 L .66969 .51442 L F
0 0 .356 r
.67036 .51601 m .67078 .51702 L .67045 .516 L F
.953 .847 .421 r
.67078 .51702 m .67001 .51829 L .67045 .516 L F
.445 .482 .803 r
.67001 .51829 m .67055 .51598 L .67045 .516 L F
.648 .596 .782 r
.67256 .51589 m .66969 .51442 L .67264 .51336 L F
.445 .482 .803 r
.67055 .51598 m .67086 .51466 L .67045 .516 L F
0 0 .356 r
.66969 .51442 m .67036 .51601 L .67045 .516 L F
0 0 .484 r
.66578 .48947 m .66464 .4889 L .66591 .48729 L F
.66578 .48947 m .66525 .49137 L .66464 .4889 L F
0 .561 .802 r
.73891 .52003 m .73746 .5196 L .73539 .51938 L F
0 .535 .774 r
.73539 .51938 m .73833 .51982 L .73891 .52003 L F
.617 .935 .961 r
.73891 .52003 m .7404 .51851 L .73952 .51883 L F
.558 .501 .748 r
.73721 .51601 m .73825 .51953 L .73539 .51938 L F
.644 .601 .791 r
.73935 .51514 m .73842 .51942 L .73721 .51601 L F
.617 .935 .961 r
.73891 .52003 m .73947 .51894 L .73788 .51972 L F
.644 .601 .791 r
.73935 .51514 m .7404 .51851 L .73842 .51942 L F
.617 .935 .961 r
.73947 .51894 m .73952 .51883 L .73853 .51937 L F
.73947 .51894 m .73853 .51937 L .73788 .51972 L F
.644 .601 .791 r
.73842 .51942 m .7404 .51851 L .73833 .51982 L F
.73842 .51942 m .73833 .51982 L .73825 .51953 L F
.73842 .51942 m .73825 .51953 L .73721 .51601 L F
.558 .501 .748 r
.73825 .51953 m .73784 .51975 L .73539 .51938 L F
.617 .935 .961 r
.73788 .51972 m .73825 .51953 L .73746 .5196 L F
.73825 .51953 m .73952 .51883 L .73923 .51894 L F
.73825 .51953 m .73923 .51894 L .73746 .5196 L F
.558 .501 .748 r
.73825 .51953 m .73833 .51982 L .73784 .51975 L F
.623 .96 .876 r
.73833 .51982 m .7404 .51851 L .73891 .52003 L F
.411 .653 .958 r
.28938 .85107 m .29177 .85134 L .28987 .85158 L F
.116 0 0 r
.28987 .85158 m .29177 .85134 L .28933 .85193 L F
.683 .408 .499 r
.59695 .59574 m .60045 .59561 L .59946 .59808 L F
.493 .124 .268 r
.60265 .59599 m .59946 .59808 L .60045 .59561 L F
.222 0 0 r
.26922 .58831 m .27137 .58807 L .27317 .58684 L F
.344 0 0 r
.27137 .58807 m .27537 .58702 L .27317 .58684 L F
.389 .693 .981 r
.26402 .68451 m .26535 .6857 L .26587 .68446 L F
.26402 .68451 m .26535 .6857 L .26587 .68446 L F
.167 0 0 r
.31028 .60368 m .30905 .60339 L .31069 .60316 L F
.31028 .60368 m .30727 .6051 L .30905 .60339 L F
.567 .424 .646 r
.55116 .61493 m .54921 .61809 L .54886 .61546 L F
.871 .741 .228 r
.72962 .4885 m .72999 .48902 L .72972 .48708 L F
.72962 .4885 m .72975 .49128 L .72999 .48902 L F
.784 .411 .35 r
.48212 .7953 m .48566 .79791 L .48202 .79774 L F
.711 .584 .712 r
.55567 .60697 m .55342 .60982 L .552 .60661 L F
.357 .318 .677 r
.41547 .6823 m .4135 .68036 L .41519 .67976 L F
.41547 .6823 m .41399 .68274 L .4135 .68036 L F
.682 .5 .634 r
.56772 .60457 m .56722 .60689 L .5632 .60643 L F
.621 .441 .617 r
.56945 .60397 m .56722 .60689 L .56772 .60457 L F
.532 .837 .999 r
.675 .47523 m .67364 .47665 L .67282 .47554 L F
.675 .47523 m .67602 .47606 L .67364 .47665 L F
.346 0 .181 r
.2993 .60845 m .29788 .60758 L .30075 .60654 L F
.2993 .60845 m .29721 .60897 L .29788 .60758 L F
0 0 0 r
.46616 .64002 m .46736 .63965 L .46809 .63943 L F
.46616 .64002 m .46526 .64061 L .46736 .63965 L F
.675 .887 .976 r
.71083 .48581 m .71261 .48455 L .70967 .48485 L F
.341 .769 .973 r
.72133 .51946 m .72367 .51945 L .72328 .51889 L F
.72133 .51946 m .72328 .51889 L .72016 .51982 L F
.727 .276 .18 r
.55904 .76981 m .56151 .77215 L .55756 .7716 L F
.713 .816 .929 r
.48228 .63369 m .47829 .63379 L .48097 .63259 L F
.718 .853 .946 r
.48458 .63228 m .48228 .63369 L .48097 .63259 L F
.593 .614 .842 r
.29108 .62926 m .28739 .62674 L .28925 .62644 L F
.569 .743 .959 r
.29185 .62735 m .29108 .62926 L .28925 .62644 L F
.29185 .62735 m .29322 .62879 L .29108 .62926 L F
.567 .717 .943 r
.52834 .79681 m .52699 .79724 L .52797 .79556 L F
.52834 .79681 m .52797 .79556 L .52642 .79493 L F
.716 .597 .722 r
.57926 .69979 m .57742 .70085 L .5747 .69642 L F
0 0 .256 r
.57942 .69582 m .57974 .6983 L .57926 .69979 L F
0 0 .541 r
.57926 .69979 m .58036 .70096 L .57909 .70228 L F
.519 .428 .692 r
.58222 .69807 m .58036 .70096 L .57974 .6983 L F
0 0 0 r
.58035 .69942 m .58084 .69942 L .58222 .69807 L F
0 0 .541 r
.57926 .69979 m .5794 .69936 L .58036 .70096 L F
.5794 .69936 m .58 .6994 L .58036 .70096 L F
0 0 0 r
.57894 .70044 m .58078 .69945 L .58035 .69942 L F
.58078 .69945 m .58084 .69942 L .58035 .69942 L F
0 0 .541 r
.5794 .69936 m .57974 .6983 L .58 .6994 L F
.806 .971 .669 r
.57778 .55484 m .5793 .55364 L .57713 .55661 L F
.799 .999 .842 r
.57524 .55721 m .57778 .55484 L .57713 .55661 L F
.739 .409 .424 r
.52699 .78662 m .5305 .78695 L .53054 .78835 L F
.635 .326 .43 r
.53054 .78835 m .5305 .78695 L .5327 .78909 L F
.643 .324 .417 r
.5305 .78695 m .53382 .78693 L .5327 .78909 L F
.857 .561 .487 r
.53928 .62051 m .53738 .62041 L .53728 .61824 L F
.769 .533 .577 r
.54089 .62307 m .53738 .62041 L .53928 .62051 L F
.88 .987 .816 r
.57097 .56331 m .57058 .56534 L .56856 .56622 L F
.095 0 0 r
.32307 .64783 m .32685 .64577 L .32507 .64737 L F
.105 0 0 r
.32685 .64577 m .3272 .64663 L .32507 .64737 L F
.32685 .64577 m .32904 .64507 L .3272 .64663 L F
.547 .666 .915 r
.2707 .64312 m .27299 .644 L .27268 .6427 L F
.559 .674 .916 r
.27268 .6427 m .27299 .644 L .27484 .64233 L F
.654 .515 .681 r
.27299 .644 m .27622 .64525 L .27484 .64233 L F
.27299 .644 m .27395 .64614 L .27622 .64525 L F
.696 .295 .284 r
.47013 .68839 m .47244 .69053 L .47379 .68867 L F
.688 .285 .279 r
.47379 .68867 m .47244 .69053 L .47609 .69072 L F
0 .112 .658 r
.66918 .50018 m .67051 .50236 L .67003 .50282 L F
0 0 0 r
.67051 .50236 m .66939 .50461 L .67003 .50282 L F
.589 .233 .333 r
.41316 .65371 m .41556 .65395 L .41597 .65249 L F
.753 .771 .867 r
.57809 .72236 m .57452 .72205 L .57705 .72096 L F
.818 .786 .822 r
.58068 .71974 m .57809 .72236 L .57705 .72096 L F
.227 0 .246 r
.2621 .59037 m .26323 .59127 L .26404 .58986 L F
.2621 .59037 m .26141 .59218 L .26323 .59127 L F
.756 .818 .902 r
.56393 .7135 m .56185 .71445 L .56063 .71331 L F
.699 .657 .805 r
.54174 .75878 m .54544 .75961 L .54402 .75779 L F
.691 .636 .79 r
.54402 .75779 m .54544 .75961 L .54745 .75818 L F
.696 .622 .77 r
.54402 .75779 m .54671 .75513 L .54449 .75603 L F
.437 .819 .989 r
.68737 .52483 m .68311 .52459 L .68629 .52188 L F
.455 .515 .831 r
.68942 .52486 m .68737 .52483 L .68629 .52188 L F
.242 0 0 r
.31712 .60097 m .31542 .60214 L .31355 .6023 L F
.263 0 0 r
.3193 .60064 m .31542 .60214 L .31712 .60097 L F
.951 .789 .644 r
.63738 .54681 m .63907 .54525 L .6385 .54419 L F
.63738 .54681 m .63877 .54779 L .63907 .54525 L F
.963 .74 .297 r
.63839 .54167 m .6385 .54419 L .63907 .54525 L F
0 0 .056 r
.48961 .80125 m .49019 .79947 L .49059 .79926 L F
.504 .907 .806 r
.56481 .77242 m .56318 .77339 L .56176 .77393 L F
.246 0 0 r
.27758 .58674 m .27964 .5863 L .28127 .58461 L F
.241 0 0 r
.27964 .5863 m .28358 .58454 L .28127 .58461 L F
.766 .662 .748 r
.48757 .75335 m .48864 .75604 L .49108 .75313 L F
.132 0 0 r
.42639 .67047 m .42571 .67195 L .42468 .67161 L F
0 0 0 r
.42639 .67047 m .42574 .671 L .42555 .67103 L F
.42639 .67047 m .42555 .67103 L .4252 .67108 L F
.132 0 0 r
.42639 .67047 m .42468 .67161 L .42459 .67158 L F
.42639 .67047 m .42547 .67103 L .42574 .671 L F
.42547 .67103 m .42459 .67158 L .42574 .671 L F
.078 .638 .717 r
.42502 .6711 m .42574 .671 L .42296 .67128 L F
.4252 .67108 m .42574 .671 L .42502 .6711 L F
0 0 0 r
.42802 .66883 m .42639 .67047 L .4252 .67108 L F
.5603 .77578 m .55792 .77863 L .55939 .77746 L F
.507 .912 .856 r
.56178 .77771 m .56256 .77773 L .56205 .77758 L F
.41 .624 .94 r
.55792 .77863 m .55998 .77901 L .55939 .77746 L F
.55998 .77901 m .56059 .77857 L .55939 .77746 L F
.749 .72 .824 r
.55939 .77746 m .56135 .77927 L .56256 .77773 L F
.55939 .77746 m .56256 .77773 L .55936 .77881 L F
.507 .912 .856 r
.55936 .77881 m .56105 .77824 L .56178 .77771 L F
.56105 .77824 m .56256 .77773 L .56178 .77771 L F
.41 .624 .94 r
.55998 .77901 m .56135 .77927 L .56059 .77857 L F
.79 .506 .507 r
.62537 .53044 m .62192 .52725 L .62556 .52813 L F
.988 .813 .579 r
.66923 .53396 m .6677 .53531 L .6686 .53314 L F
.66923 .53396 m .66878 .53629 L .6677 .53531 L F
.66 .659 .838 r
.75253 .59867 m .75366 .6014 L .75608 .60085 L F
.455 .818 .995 r
.26977 .64217 m .2707 .64312 L .27268 .6427 L F
.766 .708 .798 r
.54619 .60873 m .54769 .60996 L .54435 .60957 L F
.792 .681 .741 r
.54769 .60996 m .54393 .61183 L .54435 .60957 L F
.777 .707 .786 r
.54995 .60714 m .54769 .60996 L .54619 .60873 L F
.029 .08 .581 r
.47243 .77241 m .47379 .77472 L .47313 .77248 L F
.705 .231 .121 r
.51244 .76166 m .51504 .76355 L .51614 .76263 L F
.51239 .76166 m .51504 .76355 L .51244 .76166 L F
0 .274 .76 r
.51474 .76284 m .51235 .76164 L .51375 .76226 L F
.51474 .76284 m .51504 .76355 L .51235 .76164 L F
.275 0 0 r
.51071 .76175 m .51089 .76208 L .51375 .76226 L F
.50931 .76151 m .51006 .76178 L .51071 .76175 L F
.51006 .76178 m .51089 .76208 L .51071 .76175 L F
.705 .231 .121 r
.51235 .76164 m .51239 .76166 L .51244 .76166 L F
.746 .286 .158 r
.51504 .76355 m .51753 .76464 L .51614 .76263 L F
.47 .476 .782 r
.41745 .69022 m .41582 .69232 L .41509 .68901 L F
.439 .422 .743 r
.41745 .69022 m .41644 .69387 L .41582 .69232 L F
.479 .898 .858 r
.47478 .63555 m .47683 .63444 L .47657 .6349 L F
.632 .387 .529 r
.59695 .59574 m .59702 .59792 L .59501 .59807 L F
.683 .408 .499 r
.59695 .59574 m .59946 .59808 L .59702 .59792 L F
.663 .724 .895 r
.77858 .58335 m .78023 .58028 L .77779 .58098 L F
.77858 .58335 m .78176 .58208 L .78023 .58028 L F
.745 .631 .734 r
.552 .60661 m .54995 .60714 L .55225 .60416 L F
.783 .554 .59 r
.55413 .74752 m .55427 .75043 L .55065 .74964 L F
.517 .349 .592 r
.55648 .74963 m .55427 .75043 L .55413 .74752 L F
.55648 .74963 m .55427 .75043 L .55413 .74752 L F
0 0 0 r
.46904 .65002 m .46834 .65028 L .47077 .64994 L F
.46904 .65002 m .46756 .65122 L .46834 .65028 L F
.626 .166 .142 r
.50162 .80511 m .50184 .80426 L .50406 .80584 L F
.637 .495 .673 r
.50416 .80088 m .50544 .80405 L .50184 .80426 L F
.57 .239 .368 r
.50184 .80426 m .50544 .80405 L .50406 .80584 L F
.243 0 0 r
.28972 .64748 m .2884 .64793 L .28799 .64822 L F
.974 .794 .597 r
.2853 .64824 m .28507 .65075 L .28683 .65013 L F
.2853 .64824 m .28889 .64965 L .28799 .64822 L F
.2853 .64824 m .28595 .64904 L .28659 .64875 L F
.881 .701 .654 r
.28636 .64802 m .2853 .64824 L .28799 .64822 L F
.28347 .64766 m .28517 .6482 L .28636 .64802 L F
.28517 .6482 m .2853 .64824 L .28636 .64802 L F
.28347 .64766 m .28507 .65075 L .2853 .64824 L F
.28347 .64766 m .28636 .64802 L .28547 .64892 L F
.28636 .64802 m .28799 .64822 L .28547 .64892 L F
.243 0 0 r
.2884 .64793 m .28547 .64892 L .2874 .64838 L F
.2884 .64793 m .2874 .64838 L .28799 .64822 L F
.598 .626 .85 r
.28799 .64822 m .28889 .64965 L .29081 .64877 L F
.28799 .64822 m .29081 .64877 L .28972 .64748 L F
.649 .094 0 r
.29081 .64877 m .2921 .6477 L .28972 .64748 L F
.719 .988 .837 r
.29224 .64782 m .2898 .64885 L .28914 .64856 L F
0 .331 .805 r
.28914 .64856 m .2898 .64885 L .28968 .64872 L F
.243 0 0 r
.28966 .6475 m .28914 .64856 L .28775 .64815 L F
.719 .988 .837 r
.29224 .64782 m .28914 .64856 L .28972 .64748 L F
0 .331 .805 r
.28914 .64856 m .28968 .64872 L .28839 .64732 L F
.243 0 0 r
.28775 .64815 m .28914 .64856 L .28547 .64892 L F
.28972 .64748 m .28971 .64749 L .28966 .6475 L F
.28971 .64749 m .28914 .64856 L .28966 .6475 L F
.974 .794 .597 r
.28659 .64875 m .28683 .65013 L .28889 .64965 L F
.28595 .64904 m .28683 .65013 L .28659 .64875 L F
.818 .786 .822 r
.58068 .71974 m .57705 .72096 L .57907 .71893 L F
.567 .572 .817 r
.5813 .71588 m .58068 .71974 L .57907 .71893 L F
.5813 .71588 m .5835 .71881 L .58068 .71974 L F
.983 .702 .338 r
.65276 .49378 m .65367 .49653 L .65427 .49459 L F
.383 .354 .703 r
.52947 .77468 m .52656 .77273 L .53191 .77218 L F
.563 .847 .997 r
.67931 .47625 m .67602 .47606 L .67814 .47554 L F
.616 .869 .99 r
.67814 .47554 m .68192 .47548 L .67931 .47625 L F
.939 .634 .435 r
.53728 .61824 m .53578 .6195 L .53567 .61725 L F
.53728 .61824 m .53738 .62041 L .53578 .6195 L F
.854 .863 .847 r
.53965 .6152 m .53728 .61824 L .53567 .61725 L F
.881 .897 .838 r
.56151 .78133 m .56256 .77773 L .56135 .77927 L F
.56151 .78133 m .56381 .77848 L .56256 .77773 L F
.466 .818 .997 r
.3781 .59887 m .37458 .59854 L .3768 .59777 L F
.5 .762 .989 r
.37889 .59749 m .3781 .59887 L .3768 .59777 L F
.37889 .59749 m .38035 .59854 L .3781 .59887 L F
0 0 .352 r
.58758 .71087 m .58847 .70704 L .5879 .70721 L F
.58758 .71087 m .58843 .7102 L .58847 .70704 L F
0 .044 .585 r
.58758 .71087 m .58835 .7113 L .58843 .7102 L F
.58758 .71087 m .58952 .71288 L .58835 .7113 L F
.42 .849 .714 r
.44606 .6622 m .44483 .66307 L .44735 .66243 L F
.44606 .6622 m .44271 .66399 L .44483 .66307 L F
.716 .459 .536 r
.52213 .66886 m .52227 .67136 L .51994 .66878 L F
.867 .923 .863 r
.52213 .66886 m .52078 .66778 L .52279 .66695 L F
.607 .606 .824 r
.52078 .66778 m .52173 .66864 L .52279 .66695 L F
.867 .923 .863 r
.52213 .66886 m .52279 .66695 L .52246 .66748 L F
.725 .529 .625 r
.52279 .66695 m .52298 .66765 L .52514 .66698 L F
.627 .772 .949 r
.52243 .66761 m .52512 .66881 L .52213 .66886 L F
.52276 .66763 m .52512 .66881 L .52243 .66761 L F
.5228 .66759 m .52512 .66881 L .52246 .66748 L F
.413 .231 .522 r
.52371 .67046 m .52213 .66886 L .52512 .66881 L F
.774 .763 .843 r
.52514 .66698 m .52512 .66881 L .52247 .66742 L F
.725 .529 .625 r
.52298 .66765 m .52371 .67046 L .52482 .66776 L F
.52298 .66765 m .52482 .66776 L .52514 .66698 L F
.627 .772 .949 r
.52246 .66748 m .52276 .66763 L .52243 .66761 L F
.607 .606 .824 r
.52246 .66748 m .52298 .66765 L .52279 .66695 L F
.627 .772 .949 r
.52247 .66742 m .5228 .66759 L .52246 .66748 L F
.607 .606 .824 r
.52173 .66864 m .52371 .67046 L .52298 .66765 L F
.52173 .66864 m .52298 .66765 L .52246 .66748 L F
.867 .923 .863 r
.52246 .66748 m .52279 .66695 L .52247 .66742 L F
.413 .231 .522 r
.52371 .67046 m .52227 .67136 L .52213 .66886 L F
.59 .864 .994 r
.35145 .76123 m .34941 .76194 L .34789 .76125 L F
.35145 .76123 m .34941 .76194 L .34789 .76125 L F
.699 .606 .749 r
.27778 .64702 m .27764 .64882 L .27972 .64595 L F
.77 .544 .592 r
.73041 .50304 m .73014 .50531 L .73449 .50539 L F
.847 .818 .82 r
.72978 .50769 m .73449 .50539 L .73014 .50531 L F
.72978 .50769 m .73134 .50898 L .73449 .50539 L F
.647 .778 .943 r
.70175 .51098 m .69828 .51069 L .70062 .50978 L F
.583 .562 .796 r
.70303 .50753 m .70175 .51098 L .70062 .50978 L F
.70303 .50753 m .70429 .51118 L .70175 .51098 L F
.709 .451 .533 r
.49711 .78365 m .49699 .78127 L .49409 .78108 L F
.702 .589 .726 r
.49699 .78127 m .50015 .78189 L .49921 .77842 L F
.779 .576 .626 r
.49711 .78365 m .50015 .78189 L .49699 .78127 L F
.692 .711 .862 r
.70369 .48036 m .70713 .48033 L .70619 .47931 L F
.862 .653 .618 r
.70588 .48273 m .70713 .48033 L .70369 .48036 L F
.648 .752 .926 r
.70713 .48033 m .70876 .47856 L .70619 .47931 L F
.70713 .48033 m .70944 .48019 L .70876 .47856 L F
.546 .445 .692 r
.70713 .48033 m .7097 .48252 L .70944 .48019 L F
.525 .624 .893 r
.66892 .4983 m .66697 .50035 L .66617 .49674 L F
.66892 .4983 m .66918 .50018 L .66697 .50035 L F
.996 .764 .437 r
.5586 .78584 m .55958 .78669 L .55962 .78405 L F
.863 .978 .855 r
.57949 .55154 m .5793 .55364 L .57862 .55273 L F
.57949 .55154 m .58169 .55118 L .5793 .55364 L F
.983 .908 .626 r
.57778 .55484 m .57862 .55273 L .5793 .55364 L F
.617 .648 .859 r
.74316 .59354 m .74463 .59118 L .7424 .59176 L F
.74316 .59354 m .74556 .5929 L .74463 .59118 L F
.975 .775 .353 r
.65729 .50811 m .65668 .50434 L .6583 .50501 L F
.779 .576 .626 r
.49711 .78365 m .50035 .78344 L .50015 .78189 L F
.594 .551 .776 r
.50015 .78189 m .50141 .77851 L .49921 .77842 L F
.50015 .78189 m .50318 .78157 L .50141 .77851 L F
.604 .478 .682 r
.50035 .78344 m .50318 .78157 L .50015 .78189 L F
.414 .103 .326 r
.62367 .49139 m .626 .49078 L .62642 .48869 L F
.381 .075 .316 r
.62642 .48869 m .62823 .49009 L .62863 .48795 L F
.62642 .48869 m .626 .49078 L .62823 .49009 L F
.996 .779 .487 r
.64083 .521 m .64189 .52209 L .64203 .51976 L F
.849 .942 .576 r
.64268 .51753 m .64083 .521 L .64203 .51976 L F
.737 .579 .678 r
.55698 .61256 m .55512 .61544 L .55276 .61471 L F
.836 .665 .671 r
.59524 .72311 m .59586 .71952 L .59404 .71885 L F
0 0 0 r
.61597 .56179 m .61761 .5607 L .61818 .55899 L F
.61597 .56179 m .61483 .56329 L .61761 .5607 L F
.76 .514 .561 r
.26126 .64303 m .26493 .6437 L .2645 .64437 L F
.295 0 .248 r
.2645 .64437 m .26493 .6437 L .2668 .64295 L F
.871 .751 .728 r
.63839 .55414 m .63821 .54923 L .63667 .55269 L F
.456 .286 .561 r
.55964 .70533 m .55982 .70771 L .56148 .70489 L F
.564 .396 .613 r
.76297 .60411 m .76575 .60046 L .76193 .60082 L F
.76297 .60411 m .76565 .60321 L .76575 .60046 L F
.708 .287 .244 r
.5385 .80323 m .53681 .8039 L .53861 .80279 L F
.933 .813 .703 r
.53681 .8039 m .5385 .80323 L .53861 .80279 L F
.53681 .8039 m .53771 .80659 L .5385 .80323 L F
.229 .062 .436 r
.54691 .7529 m .54808 .75531 L .54841 .75256 L F
.558 .841 .997 r
.54943 .75117 m .54858 .75234 L .54657 .7533 L F
.54858 .75234 m .54841 .75256 L .54827 .75262 L F
.54858 .75234 m .54827 .75262 L .54657 .7533 L F
.229 .062 .436 r
.54724 .75357 m .54671 .75513 L .54808 .75531 L F
.54691 .7529 m .54681 .75396 L .54724 .75357 L F
.54681 .75396 m .54671 .75513 L .54724 .75357 L F
.555 .733 .959 r
.34341 .60248 m .34426 .6005 L .34207 .60106 L F
.34341 .60248 m .34568 .60214 L .34426 .6005 L F
.734 .647 .763 r
.48491 .75503 m .48864 .75604 L .48757 .75335 L F
.644 .766 .937 r
.69928 .47501 m .69682 .47632 L .69572 .47434 L F
.398 0 0 r
.32312 .6005 m .32148 .60096 L .3193 .60064 L F
.386 0 0 r
.32499 .60083 m .32148 .60096 L .32312 .6005 L F
0 0 0 r
.41443 .71085 m .41418 .71067 L .41642 .71023 L F
.41443 .71085 m .41233 .71178 L .41418 .71067 L F
.624 .784 .958 r
.48805 .63287 m .48458 .63228 L .48679 .6315 L F
.622 .774 .953 r
.49031 .63207 m .48805 .63287 L .48679 .6315 L F
.577 .145 .184 r
.42936 .65049 m .43168 .65095 L .433 .64921 L F
.271 0 0 r
.433 .64921 m .43384 .65045 L .43525 .64922 L F
.433 .64921 m .43168 .65095 L .43384 .65045 L F
.704 .555 .682 r
.25341 .64591 m .25677 .64389 L .25325 .64351 L F
.25341 .64591 m .25684 .64617 L .25677 .64389 L F
.741 .913 .543 r
.58381 .54792 m .58169 .55118 L .5826 .54925 L F
.774 .99 .89 r
.5826 .54925 m .58169 .55118 L .57949 .55154 L F
.664 .824 .96 r
.5159 .81361 m .51696 .81158 L .51464 .8122 L F
.556 .235 .379 r
.43329 .66592 m .43104 .66764 L .43099 .66557 L F
.033 .164 .67 r
.50679 .63444 m .50795 .63626 L .50705 .63751 L F
.226 .445 .864 r
.50795 .63626 m .50868 .63781 L .50705 .63751 L F
.508 .301 .534 r
.52386 .69049 m .52385 .69381 L .52159 .69394 L F
.517 .376 .628 r
.52576 .68585 m .52628 .69055 L .52386 .69049 L F
.491 .278 .518 r
.52628 .69055 m .52385 .69381 L .52386 .69049 L F
.637 .502 .681 r
.57883 .60691 m .57861 .60429 L .581 .60383 L F
0 .103 .627 r
.47723 .77754 m .47579 .7759 L .47708 .77507 L F
.587 .604 .836 r
.67961 .47954 m .68029 .48215 L .68344 .48051 L F
.491 .834 .997 r
.68029 .48215 m .68562 .48149 L .68344 .48051 L F
.762 .562 .627 r
.48013 .78696 m .48333 .78656 L .48272 .78421 L F
0 0 .152 r
.48416 .78313 m .48232 .78668 L .48272 .78421 L F
0 0 0 r
.48272 .78421 m .48232 .78668 L .48282 .78428 L F
.166 .248 .705 r
.57942 .69582 m .57717 .69367 L .58104 .69374 L F
.637 .243 .28 r
.58359 .69533 m .58104 .69374 L .58353 .69353 L F
.58359 .69533 m .57942 .69582 L .58104 .69374 L F
.104 .063 .522 r
.47279 .78736 m .47237 .78887 L .47225 .78678 L F
.571 .374 .575 r
.47324 .78316 m .47442 .78509 L .47467 .77931 L F
.314 .276 .655 r
.47378 .78382 m .47279 .78736 L .47417 .7843 L F
.47279 .78736 m .47237 .78887 L .47417 .7843 L F
.001 0 .482 r
.47225 .78678 m .47237 .78887 L .4725 .788 L F
.126 .065 .511 r
.47225 .78678 m .47236 .78832 L .4725 .788 L F
.47225 .78678 m .4725 .788 L .47279 .78736 L F
.001 0 .482 r
.47225 .78678 m .4725 .788 L .47324 .78316 L F
.314 .276 .655 r
.47324 .78316 m .47237 .78887 L .47378 .78382 L F
.571 .374 .575 r
.47324 .78316 m .47442 .78516 L .47442 .78509 L F
0 0 .29 r
.47467 .77931 m .47442 .78509 L .47451 .78471 L F
.314 .276 .655 r
.47417 .7843 m .47408 .78453 L .47447 .78487 L F
.47417 .7843 m .47447 .78487 L .47451 .78471 L F
.339 .283 .647 r
.47324 .78316 m .47451 .78471 L .47442 .78516 L F
.314 .276 .655 r
.47451 .78471 m .47447 .78487 L .47502 .78533 L F
.47408 .78453 m .47477 .78566 L .47502 .78533 L F
.339 .283 .647 r
.47451 .78471 m .47502 .78533 L .47442 .78516 L F
0 0 .29 r
.4753 .78095 m .47451 .78471 L .47538 .78114 L F
.47467 .77931 m .47451 .78471 L .4753 .78095 L F
.47538 .78114 m .47442 .78516 L .47566 .78187 L F
.47442 .78509 m .47442 .78516 L .47538 .78114 L F
.314 .276 .655 r
.47408 .78453 m .47237 .78887 L .47477 .78566 L F
.053 0 .383 r
.47502 .78533 m .47237 .78887 L .4737 .78831 L F
.104 .063 .522 r
.4737 .78831 m .47237 .78887 L .47279 .78736 L F
.126 .065 .511 r
.47279 .78736 m .47245 .78969 L .4737 .78831 L F
.47236 .78832 m .47245 .78969 L .47279 .78736 L F
.793 .877 .447 r
.75276 .5875 m .75392 .58441 L .75494 .58589 L F
.158 .206 .662 r
.75507 .58824 m .75276 .5875 L .75494 .58589 L F
.75507 .58824 m .7537 .58965 L .75276 .5875 L F
.561 .434 .664 r
.38691 .666 m .38905 .6656 L .38882 .66272 L F
.554 .378 .597 r
.38691 .666 m .38918 .66812 L .38905 .6656 L F
.38691 .666 m .38694 .6686 L .38918 .66812 L F
.401 .769 .993 r
.34916 .59072 m .34669 .59103 L .34552 .59025 L F
.083 0 0 r
.48927 .77093 m .48969 .77142 L .49123 .77201 L F
.48927 .77093 m .48735 .77187 L .48969 .77142 L F
.535 .625 .888 r
.54626 .74241 m .5475 .74568 L .5445 .74371 L F
.782 .764 .837 r
.55 .74201 m .5475 .74568 L .54626 .74241 L F
.683 .862 .967 r
.65938 .5231 m .66048 .52414 L .66299 .52257 L F
.902 .801 .739 r
.72978 .50769 m .73049 .51079 L .73134 .50898 L F
.626 .551 .751 r
.50268 .64664 m .50321 .64892 L .50529 .64836 L F
.136 .609 .921 r
.51444 .64241 m .5139 .64298 L .51224 .6407 L F
.51444 .64241 m .5155 .64309 L .5139 .64298 L F
.533 .499 .764 r
.48482 .77882 m .4868 .77854 L .48571 .77452 L F
.437 .136 .356 r
.48689 .7804 m .48482 .77882 L .48467 .78095 L F
.48689 .7804 m .4868 .77854 L .48482 .77882 L F
.48689 .7804 m .48482 .77882 L .48467 .78095 L F
.48689 .7804 m .4868 .77854 L .48482 .77882 L F
.569 .121 .147 r
.52565 .76668 m .52841 .76718 L .52873 .76611 L F
0 0 0 r
.52873 .76611 m .53008 .76598 L .53119 .76383 L F
.52873 .76611 m .52841 .76718 L .53008 .76598 L F
.567 .547 .792 r
.3888 .68829 m .39 .6847 L .38762 .68511 L F
.3888 .68829 m .39102 .68792 L .39 .6847 L F
.872 .726 .698 r
.54279 .62415 m .5421 .62643 L .54089 .62307 L F
.486 .233 .455 r
.56708 .70206 m .56955 .69936 L .56716 .6996 L F
.894 .989 .763 r
.77342 .60066 m .77116 .60455 L .77024 .60381 L F
.835 .707 .723 r
.77342 .60066 m .77298 .60514 L .77116 .60455 L F
.229 0 0 r
.41024 .65487 m .40793 .65519 L .40948 .65566 L F
.232 0 0 r
.40948 .65566 m .40793 .65519 L .40629 .65622 L F
.524 .715 .959 r
.4203 .69407 m .41983 .69596 L .41826 .694 L F
.4203 .69407 m .42205 .69573 L .41983 .69596 L F
.481 0 .027 r
.44079 .66442 m .43744 .66487 L .43899 .66353 L F
.58 .273 .413 r
.50756 .78115 m .50587 .78039 L .50493 .78093 L F
.699 .261 .206 r
.51039 .76688 m .50925 .76839 L .507 .7664 L F
0 0 0 r
.50906 .7679 m .507 .7664 L .50925 .76839 L F
.636 .116 0 r
.50736 .76561 m .507 .7664 L .50494 .76489 L F
.50956 .76627 m .507 .7664 L .50736 .76561 L F
.527 0 0 r
.50956 .76627 m .51039 .76688 L .507 .7664 L F
0 0 0 r
.50796 .76507 m .507 .7664 L .50906 .7679 L F
.50796 .76507 m .50654 .76741 L .507 .7664 L F
.50654 .76741 m .50607 .76819 L .507 .7664 L F
.636 .116 0 r
.50494 .76489 m .507 .7664 L .50468 .76481 L F
.868 .994 .764 r
.56381 .77848 m .5652 .77562 L .56256 .77773 L F
.56381 .77848 m .56603 .77558 L .5652 .77562 L F
.014 0 .415 r
.61818 .55899 m .61968 .55767 L .61969 .55529 L F
0 0 0 r
.61818 .55899 m .61761 .5607 L .61968 .55767 L F
.508 .724 .97 r
.69164 .48164 m .69329 .47995 L .691 .48064 L F
.69164 .48164 m .69503 .48157 L .69329 .47995 L F
.41 0 0 r
.51445 .69998 m .51299 .70117 L .51069 .70105 L F
.374 0 .041 r
.51657 .69927 m .51299 .70117 L .51445 .69998 L F
0 .072 .611 r
.70474 .48097 m .70369 .48036 L .70619 .47931 L F
.505 .433 .709 r
.70767 .48005 m .70532 .48126 L .70474 .48097 L F
0 .072 .611 r
.70474 .48097 m .70588 .48273 L .70385 .48053 L F
.918 .878 .78 r
.70288 .48401 m .70588 .48273 L .70474 .48097 L F
.505 .433 .709 r
.70532 .48126 m .70463 .48162 L .70474 .48097 L F
0 .072 .611 r
.70474 .48097 m .70385 .48053 L .70369 .48036 L F
.159 0 0 r
.3189 .64854 m .31759 .6489 L .31541 .64902 L F
.129 0 0 r
.32097 .64836 m .31759 .6489 L .3189 .64854 L F
.408 .278 .591 r
.48201 .78083 m .48416 .78313 L .48467 .78095 L F
.48201 .78083 m .48282 .78428 L .48416 .78313 L F
.215 .242 .674 r
.48416 .78313 m .48201 .78083 L .48467 .78095 L F
.476 .021 .09 r
.42257 .70876 m .42103 .71041 L .41865 .7103 L F
.332 0 0 r
.42424 .70924 m .42103 .71041 L .42257 .70876 L F
.332 0 .054 r
.42476 .70838 m .42424 .70924 L .42257 .70876 L F
.63 .591 .792 r
.51071 .65936 m .51345 .66173 L .51186 .65973 L F
.408 .521 .861 r
.51345 .66173 m .51334 .6601 L .51186 .65973 L F
.51345 .66173 m .51501 .66297 L .51334 .6601 L F
.06 0 0 r
.45912 .64215 m .46278 .64113 L .46067 .64184 L F
.906 .712 .63 r
.62645 .53348 m .62438 .53293 L .62537 .53044 L F
.952 .81 .666 r
.62645 .53348 m .62423 .53541 L .62438 .53293 L F
.62645 .53348 m .62561 .53665 L .62423 .53541 L F
.713 .19 0 r
.55409 .73563 m .55638 .73769 L .55728 .73702 L F
.513 0 0 r
.55728 .73702 m .55638 .73769 L .55804 .73771 L F
.804 .918 .915 r
.56176 .77393 m .5603 .77578 L .55947 .77481 L F
.998 .786 .445 r
.55947 .77481 m .5603 .77578 L .55939 .77746 L F
.767 .719 .808 r
.7605 .58124 m .76139 .5842 L .7627 .58036 L F
.405 .225 .521 r
.77588 .58116 m .77792 .57813 L .7743 .57809 L F
.77588 .58116 m .77779 .58098 L .77792 .57813 L F
.789 .619 .671 r
.5913 .69391 m .59282 .69678 L .59341 .69446 L F
.924 .859 .759 r
.63834 .53029 m .64113 .52832 L .63975 .52715 L F
.63834 .53029 m .63951 .53107 L .64113 .52832 L F
.783 .732 .806 r
.51704 .66265 m .51503 .66538 L .51943 .66572 L F
.488 .055 .143 r
.51503 .66743 m .51943 .66572 L .51503 .66538 L F
.51503 .66743 m .51704 .66727 L .51943 .66572 L F
0 0 .147 r
.51943 .66572 m .51946 .6622 L .51704 .66265 L F
.51943 .66572 m .52098 .66329 L .51946 .6622 L F
.51943 .66572 m .51934 .66714 L .52098 .66329 L F
.671 .394 .493 r
.51704 .66727 m .51934 .66714 L .51943 .66572 L F
0 0 .147 r
.52098 .66329 m .51934 .66714 L .51943 .66572 L F
.56 .229 .364 r
.43348 .69638 m .43696 .69384 L .43416 .69414 L F
.43348 .69638 m .43589 .6964 L .43696 .69384 L F
.592 .262 .379 r
.43696 .69384 m .43903 .6954 L .43938 .6939 L F
.43696 .69384 m .43589 .6964 L .43903 .6954 L F
.773 .7 .783 r
.68607 .53589 m .68951 .5361 L .68836 .53318 L F
.545 .759 .976 r
.68951 .5361 m .69063 .53446 L .68836 .53318 L F
.68951 .5361 m .69177 .5357 L .69063 .53446 L F
.709 .451 .533 r
.49711 .78365 m .49409 .78108 L .4948 .78302 L F
.331 .2 .548 r
.56917 .71495 m .56711 .71371 L .56926 .71251 L F
.56917 .71495 m .56702 .71649 L .56711 .71371 L F
.625 .48 .664 r
.24853 .60968 m .25125 .61215 L .25083 .60906 L F
.24853 .60968 m .24907 .61272 L .25125 .61215 L F
.038 .606 .761 r
.56081 .72556 m .55957 .72543 L .55738 .72544 L F
.19 .338 .784 r
.56081 .72556 m .56176 .72376 L .55957 .72543 L F
.56081 .72556 m .56302 .72693 L .56176 .72376 L F
.982 .905 .646 r
.52514 .66698 m .52371 .67046 L .52512 .66881 L F
.693 .163 0 r
.53265 .77095 m .53452 .77266 L .53308 .77161 L F
.681 .137 0 r
.53589 .77288 m .53452 .77266 L .53265 .77095 L F
.704 .307 .293 r
.52699 .79724 m .52658 .79784 L .52435 .79702 L F
.567 .717 .943 r
.52834 .79681 m .52658 .79784 L .52699 .79724 L F
.423 0 .122 r
.52699 .79724 m .52859 .79764 L .52658 .79784 L F
.519 .515 .791 r
.66664 .52454 m .66761 .52118 L .66544 .52181 L F
.66664 .52454 m .66849 .52408 L .66761 .52118 L F
.392 .095 .337 r
.34555 .61238 m .34733 .61208 L .34811 .60959 L F
.524 .471 .739 r
.34811 .60959 m .34945 .606 L .34721 .6065 L F
.34811 .60959 m .35009 .60909 L .34945 .606 L F
.428 .141 .373 r
.34733 .61208 m .35009 .60909 L .34811 .60959 L F
.791 .292 0 r
.7346 .51085 m .73681 .51333 L .73471 .51163 L F
.7346 .51085 m .73471 .51163 L .73474 .51104 L F
0 0 .182 r
.51308 .69405 m .51381 .69481 L .51507 .69305 L F
.51308 .69405 m .51272 .69615 L .51381 .69481 L F
.351 0 .094 r
.32789 .62888 m .32996 .62857 L .33142 .62668 L F
.304 0 .065 r
.33142 .62668 m .33264 .62727 L .33338 .62599 L F
.33142 .62668 m .32996 .62857 L .33264 .62727 L F
.681 .92 .973 r
.66816 .47778 m .66397 .47856 L .66689 .47656 L F
.746 .848 .927 r
.67015 .47642 m .66816 .47778 L .66689 .47656 L F
.711 .68 .819 r
.75608 .60085 m .75944 .60138 L .75889 .59863 L F
.652 .641 .826 r
.75889 .59863 m .75944 .60138 L .76193 .60082 L F
.536 .183 .316 r
.60614 .59494 m .60514 .59728 L .60265 .59599 L F
.672 .372 .457 r
.60819 .59496 m .60514 .59728 L .60614 .59494 L F
.615 .804 .972 r
.69077 .47528 m .68766 .47488 L .68988 .47382 L F
.585 .703 .924 r
.69226 .47319 m .69077 .47528 L .68988 .47382 L F
.69226 .47319 m .6932 .47483 L .69077 .47528 L F
0 0 .201 r
.61087 .51128 m .61219 .50977 L .61258 .50765 L F
0 0 .358 r
.61059 .51336 m .61219 .50977 L .61087 .51128 L F
.721 .599 .72 r
.57292 .60674 m .5738 .60956 L .57071 .60956 L F
.72 .556 .667 r
.57071 .60956 m .5738 .60956 L .57319 .61221 L F
.623 .452 .631 r
.57654 .60699 m .5738 .60956 L .57292 .60674 L F
.57654 .60699 m .57628 .60909 L .5738 .60956 L F
.566 .288 .453 r
.5738 .60956 m .57529 .61191 L .57319 .61221 L F
.5738 .60956 m .57628 .60909 L .57529 .61191 L F
.509 .199 .377 r
.56955 .69936 m .57193 .69905 L .57195 .69749 L F
.448 .111 .301 r
.57193 .69905 m .5747 .69642 L .57195 .69749 L F
.43 .217 .487 r
.29721 .60897 m .29497 .61158 L .29577 .60992 L F
.661 .241 .237 r
.58295 .69051 m .58664 .69259 L .58615 .69011 L F
.204 0 .076 r
.58664 .69259 m .58785 .69066 L .58615 .69011 L F
.827 .694 .718 r
.55428 .5896 m .55556 .59292 L .55251 .59237 L F
.874 .828 .799 r
.55556 .59292 m .55206 .59484 L .55251 .59237 L F
.55556 .59292 m .55353 .59583 L .55206 .59484 L F
.944 .918 .758 r
.56334 .57593 m .56412 .57191 L .56367 .57375 L F
.56 .372 .583 r
.47312 .77834 m .47467 .77931 L .47621 .77747 L F
.47312 .77834 m .47316 .78083 L .47467 .77931 L F
.509 .874 .982 r
.67805 .5371 m .67964 .53589 L .67685 .53592 L F
.67805 .5371 m .68032 .53644 L .67964 .53589 L F
.105 .367 .83 r
.2554 .62068 m .2575 .62378 L .25838 .62276 L F
.023 .238 .742 r
.2575 .62378 m .25947 .62567 L .25838 .62276 L F
.874 .482 .29 r
.61891 .5247 m .62192 .52725 L .62253 .52518 L F
.61891 .5247 m .61939 .52646 L .62192 .52725 L F
0 .54 .817 r
.61939 .52646 m .62182 .52693 L .62192 .52725 L F
.673 .911 .582 r
.62192 .52725 m .62416 .52415 L .62253 .52518 L F
.62192 .52725 m .62182 .52693 L .62416 .52415 L F
.79 .506 .507 r
.62537 .53044 m .62438 .53056 L .62192 .52725 L F
.871 .916 .856 r
.70533 .52045 m .70476 .52317 L .70653 .52089 L F
.998 .825 .482 r
.70366 .52419 m .70476 .52317 L .70533 .52045 L F
.70366 .52419 m .70446 .52504 L .70476 .52317 L F
.691 .457 .563 r
.53382 .78693 m .53629 .78681 L .53617 .79 L F
.472 .805 .999 r
.53621 .78601 m .53629 .78681 L .53849 .78644 L F
0 .093 .65 r
.53847 .78931 m .53629 .78681 L .53621 .78601 L F
.545 .827 .483 r
.58381 .54792 m .58499 .54654 L .58631 .54509 L F
.546 .828 .484 r
.58381 .54792 m .5826 .54925 L .58499 .54654 L F
.828 .528 0 r
.39032 .69411 m .39064 .69582 L .39171 .69318 L F
.306 0 .077 r
.30158 .60786 m .30075 .60654 L .30282 .60621 L F
.30158 .60786 m .2993 .60845 L .30075 .60654 L F
.493 .124 .268 r
.60265 .59599 m .60262 .59742 L .59946 .59808 L F
.544 .165 .272 r
.60265 .59599 m .60514 .59728 L .60262 .59742 L F
.507 .4 .667 r
.38554 .67466 m .38769 .67453 L .38734 .67098 L F
.554 .478 .724 r
.38611 .67701 m .38769 .67453 L .38554 .67466 L F
.614 .38 .539 r
.50679 .81461 m .5096 .81439 L .50894 .8126 L F
.674 .37 .451 r
.5096 .81439 m .51197 .81388 L .50894 .8126 L F
.439 .422 .743 r
.41745 .69022 m .41826 .694 L .41644 .69387 L F
0 0 0 r
.28358 .58454 m .28557 .58398 L .28693 .58357 L F
.251 0 0 r
.28693 .58357 m .28557 .58398 L .2891 .58365 L F
.639 .404 .546 r
.56025 .61493 m .56064 .61799 L .55731 .61785 L F
.536 .355 .582 r
.56288 .61204 m .56257 .61492 L .56025 .61493 L F
.65 .412 .544 r
.56274 .61725 m .56025 .61493 L .56257 .61492 L F
.56274 .61725 m .56064 .61799 L .56025 .61493 L F
.213 .002 .361 r
.61086 .56727 m .61301 .56636 L .61333 .56436 L F
.299 .13 .476 r
.61129 .56933 m .61301 .56636 L .61086 .56727 L F
.422 .564 .891 r
.7138 .51534 m .71458 .51747 L .71744 .51771 L F
.58 .615 .852 r
.49736 .81189 m .49417 .81126 L .49667 .80943 L F
.658 .971 .84 r
.5652 .77562 m .56603 .77558 L .56679 .77439 L F
.297 .038 .342 r
.34076 .61787 m .34271 .61735 L .34324 .61482 L F
.463 .291 .561 r
.34324 .61482 m .34516 .61452 L .34555 .61238 L F
.474 .191 .403 r
.34324 .61482 m .3449 .61686 L .34516 .61452 L F
.34324 .61482 m .34271 .61735 L .3449 .61686 L F
.807 .688 .733 r
.26096 .62895 m .25844 .63185 L .26227 .63217 L F
.928 .595 .142 r
.26227 .63217 m .26159 .63171 L .26096 .62895 L F
.99 .867 .519 r
.26227 .63217 m .26133 .63322 L .26159 .63171 L F
.938 .604 .372 r
.26227 .63217 m .26241 .63345 L .26133 .63322 L F
.424 .285 .587 r
.26133 .63322 m .26277 .63314 L .26159 .63171 L F
.169 .691 .877 r
.26277 .63314 m .25971 .63288 L .26133 .63322 L F
0 .131 .671 r
.26159 .63171 m .26277 .63314 L .26208 .63117 L F
.26176 .63082 m .26208 .63117 L .26183 .63045 L F
.26159 .63171 m .26208 .63117 L .26176 .63082 L F
.777 .725 .804 r
.26142 .6317 m .25895 .63281 L .26277 .63314 L F
.525 .24 .425 r
.26142 .6317 m .26121 .63285 L .26313 .63229 L F
.26263 .63175 m .26313 .63229 L .26464 .63184 L F
.26142 .6317 m .26313 .63229 L .26263 .63175 L F
.938 .604 .372 r
.26241 .63345 m .26248 .63416 L .26133 .63322 L F
.214 0 .273 r
.26248 .63416 m .26296 .63578 L .26277 .63314 L F
.652 .761 .929 r
.26277 .63314 m .26626 .63361 L .26535 .63223 L F
.562 .249 .395 r
.26296 .63578 m .26626 .63361 L .26277 .63314 L F
.169 .691 .877 r
.25971 .63288 m .25956 .63287 L .26133 .63322 L F
.25956 .63287 m .25895 .63281 L .25927 .63287 L F
.25956 .63287 m .25927 .63287 L .26133 .63322 L F
.704 .273 .224 r
.26277 .63314 m .26087 .63473 L .25895 .63281 L F
0 0 0 r
.26464 .63184 m .26087 .63473 L .26277 .63314 L F
.525 .24 .425 r
.26121 .63285 m .26087 .63473 L .26337 .63282 L F
.26121 .63285 m .26337 .63282 L .26464 .63184 L F
.678 .852 .966 r
.52032 .81032 m .52314 .81015 L .52259 .80919 L F
.881 .874 .825 r
.52379 .80736 m .52327 .80958 L .52259 .80919 L F
.425 .808 .99 r
.52325 .80871 m .52259 .80919 L .52498 .80881 L F
.5213 .80859 m .52259 .80919 L .52325 .80871 L F
0 0 0 r
.52382 .80839 m .52382 .8083 L .52325 .80871 L F
.52382 .8083 m .52379 .80736 L .52259 .80919 L F
.425 .808 .99 r
.5213 .80859 m .52325 .80871 L .52382 .80839 L F
.52325 .80871 m .52498 .80881 L .52382 .80839 L F
0 0 0 r
.52382 .80839 m .52325 .80871 L .52259 .80919 L F
.52152 .80857 m .52259 .80919 L .5213 .80859 L F
.52382 .80839 m .52259 .80919 L .52152 .80857 L F
.881 .874 .825 r
.52327 .80958 m .52314 .81015 L .52259 .80919 L F
.537 .819 .998 r
.52314 .81015 m .52498 .80881 L .52259 .80919 L F
.52314 .81015 m .52643 .80962 L .52498 .80881 L F
.496 .743 .982 r
.31753 .58595 m .31693 .58751 L .31552 .58609 L F
.31753 .58595 m .31893 .58722 L .31693 .58751 L F
.605 .607 .827 r
.38328 .6005 m .38149 .60129 L .38035 .59854 L F
.301 .199 .568 r
.38311 .60305 m .38149 .60129 L .38328 .6005 L F
.38311 .60305 m .38159 .60374 L .38149 .60129 L F
.625 .354 .487 r
.59151 .59877 m .59138 .60067 L .58898 .60076 L F
.638 .411 .558 r
.59501 .59807 m .59138 .60067 L .59151 .59877 L F
.721 .689 .819 r
.48202 .79774 m .48566 .79791 L .4827 .79964 L F
.486 .439 .731 r
.55355 .72203 m .55485 .71813 L .55365 .71932 L F
.614 .258 .344 r
.55312 .76042 m .55661 .75847 L .55309 .75869 L F
.55312 .76042 m .55542 .76088 L .55661 .75847 L F
.014 .217 .725 r
.55661 .75847 m .55732 .7576 L .55519 .75533 L F
0 0 0 r
.55661 .75847 m .55542 .76088 L .55732 .7576 L F
.691 .457 .563 r
.53382 .78693 m .53617 .79 L .5327 .78909 L F
0 .534 .796 r
.30636 .58481 m .3097 .58554 L .30745 .58529 L F
.344 .276 .635 r
.41547 .6823 m .41589 .68471 L .41399 .68274 L F
.377 .281 .618 r
.41399 .68274 m .41589 .68471 L .41426 .68492 L F
.95 .954 .711 r
.53884 .79208 m .53869 .79324 L .53745 .79491 L F
.727 .525 .617 r
.51248 .79799 m .50865 .80037 L .50883 .79844 L F
.51248 .79799 m .51255 .80081 L .50865 .80037 L F
.228 .347 .778 r
.51404 .79708 m .51489 .79991 L .51248 .79799 L F
.514 .357 .605 r
.51248 .79799 m .51489 .79991 L .51255 .80081 L F
.172 .334 .786 r
.51994 .66878 m .52227 .67136 L .52078 .66778 L F
.493 .446 .733 r
.2886 .62285 m .28739 .62674 L .28645 .62324 L F
.2886 .62285 m .28925 .62644 L .28739 .62674 L F
.039 .454 .877 r
.5815 .72617 m .58378 .72708 L .58219 .72569 L F
.649 .573 .756 r
.2474 .63162 m .25023 .6329 L .25017 .63131 L F
.615 .851 .481 r
.58631 .54509 m .58731 .54363 L .58843 .54229 L F
.627 .868 .513 r
.58499 .54654 m .58731 .54363 L .58631 .54509 L F
.551 .457 .701 r
.50651 .80032 m .50544 .80405 L .50416 .80088 L F
.922 .71 .6 r
.63619 .54969 m .63877 .54779 L .63738 .54681 L F
.63619 .54969 m .63821 .54923 L .63877 .54779 L F
.871 .94 .861 r
.58961 .56635 m .59295 .56454 L .59144 .56393 L F
.822 .907 .899 r
.59295 .56454 m .59456 .56123 L .59144 .56393 L F
.59295 .56454 m .59569 .56225 L .59456 .56123 L F
.511 .152 .293 r
.25266 .64781 m .25477 .6479 L .25341 .64591 L F
.612 .177 .19 r
.25341 .64591 m .25477 .6479 L .25684 .64617 L F
.156 0 0 r
.25652 .59496 m .25835 .59461 L .25955 .59289 L F
.026 0 0 r
.25955 .59289 m .2599 .59385 L .26141 .59218 L F
.25955 .59289 m .25835 .59461 L .2599 .59385 L F
.776 .63 .699 r
.55076 .60095 m .55225 .60416 L .54886 .60385 L F
.769 .668 .752 r
.55225 .60416 m .54995 .60714 L .54886 .60385 L F
.699 .78 .914 r
.70876 .47856 m .70944 .48019 L .71195 .47885 L F
.288 0 0 r
.49654 .77212 m .49912 .77189 L .5003 .77015 L F
.448 0 .016 r
.5003 .77015 m .50074 .77141 L .50248 .7721 L F
.5003 .77015 m .49912 .77189 L .50074 .77141 L F
.637 .777 .948 r
.4939 .63278 m .49031 .63207 L .49249 .63084 L F
.642 .679 .87 r
.49605 .63192 m .4939 .63278 L .49249 .63084 L F
.74 .766 .874 r
.52437 .64979 m .52041 .6496 L .52315 .64934 L F
.57 .783 .979 r
.52518 .64846 m .52437 .64979 L .52315 .64934 L F
.289 0 0 r
.74663 .5028 m .74596 .50415 L .74341 .5047 L F
.081 .183 .671 r
.74754 .50114 m .74663 .5028 L .74579 .49929 L F
0 0 0 r
.74754 .50114 m .74596 .50415 L .74663 .5028 L F
.999 .794 .485 r
.73716 .50174 m .73631 .49908 L .7375 .50016 L F
.73716 .50174 m .7361 .50081 L .73631 .49908 L F
.957 .935 .726 r
.73716 .50174 m .73464 .50419 L .7361 .50081 L F
.73716 .50174 m .73523 .50527 L .73464 .50419 L F
.477 .611 .905 r
.49528 .78837 m .49642 .78947 L .49732 .78826 L F
.176 .188 .632 r
.49732 .78826 m .49642 .78947 L .49794 .79174 L F
.719 .758 .884 r
.49633 .64412 m .49926 .64408 L .49854 .64328 L F
.645 .798 .956 r
.49854 .64328 m .49926 .64408 L .50175 .64354 L F
.683 .828 .953 r
.66829 .48224 m .66929 .48357 L .67145 .48255 L F
.789 .679 .742 r
.54886 .60385 m .54995 .60714 L .54659 .60698 L F
.777 .707 .786 r
.54995 .60714 m .54619 .60873 L .54659 .60698 L F
.442 .09 .271 r
.59146 .58683 m .59453 .58434 L .5911 .58395 L F
.59146 .58683 m .59379 .58647 L .59453 .58434 L F
.575 .216 .322 r
.59379 .58647 m .59676 .58592 L .59453 .58434 L F
.591 .199 .269 r
.59453 .58434 m .59676 .58592 L .597 .58453 L F
.207 0 0 r
.53703 .76693 m .53918 .76685 L .54042 .76646 L F
0 0 0 r
.54042 .76646 m .53918 .76685 L .54262 .76579 L F
.514 0 0 r
.24486 .65246 m .24857 .65243 L .24642 .6537 L F
.702 .553 .682 r
.56944 .60602 m .56722 .60689 L .56945 .60397 L F
.259 0 .273 r
.49105 .77721 m .49009 .77786 L .49154 .77549 L F
.782 .9 .496 r
.49173 .77453 m .49154 .77549 L .49276 .77314 L F
0 0 .367 r
.49173 .77453 m .49105 .77721 L .49154 .77549 L F
.99 .775 .52 r
.72906 .50438 m .73041 .50304 L .7294 .49958 L F
.72906 .50438 m .73014 .50531 L .73041 .50304 L F
.127 .676 .78 r
.43525 .64922 m .43746 .64902 L .43874 .64903 L F
.266 0 0 r
.43746 .64902 m .44077 .64809 L .43874 .64903 L F
.625 .814 .973 r
.37549 .70214 m .37706 .70325 L .37952 .70238 L F
.722 .519 .614 r
.49449 .79817 m .49725 .79778 L .49654 .79533 L F
.412 .333 .657 r
.49654 .79533 m .49885 .7978 L .49794 .79436 L F
.49654 .79533 m .49725 .79778 L .49885 .7978 L F
.994 .755 .45 r
.50468 .76481 m .50367 .76604 L .50353 .76352 L F
.637 .171 .131 r
.50468 .76481 m .507 .7664 L .50367 .76604 L F
.17 0 .374 r
.62034 .58366 m .6199 .58585 L .61778 .58698 L F
.116 0 .269 r
.6199 .58585 m .61782 .58902 L .61778 .58698 L F
.138 .66 .882 r
.49921 .77842 m .49997 .77812 L .4979 .77784 L F
.49921 .77842 m .50141 .77851 L .49997 .77812 L F
.594 .023 0 r
.48108 .80852 m .47899 .80688 L .47728 .80626 L F
.841 .393 .15 r
.56094 .74388 m .56417 .74685 L .56215 .74462 L F
.522 .713 .959 r
.29101 .65051 m .29081 .64877 L .28889 .64965 L F
.29101 .65051 m .29251 .65063 L .29081 .64877 L F
.143 0 .413 r
.60932 .57283 m .61129 .56933 L .60886 .57043 L F
.473 .738 .986 r
.36522 .59394 m .36189 .59314 L .36402 .59269 L F
.313 .531 .905 r
.36567 .59257 m .36522 .59394 L .36402 .59269 L F
.36567 .59257 m .36759 .59491 L .36522 .59394 L F
.478 .811 .999 r
.28842 .73503 m .29001 .7358 L .28785 .73618 L F
.521 .33 .562 r
.28785 .73618 m .29001 .7358 L .28778 .7388 L F
.879 .86 .818 r
.28778 .7388 m .28842 .73503 L .28785 .73618 L F
.586 .626 .858 r
.39427 .70017 m .39484 .69638 L .39222 .69714 L F
.39427 .70017 m .39602 .69985 L .39484 .69638 L F
.745 .477 .525 r
.39427 .70017 m .39638 .7018 L .39602 .69985 L F
.748 .232 0 r
.25708 .64742 m .25684 .64617 L .25477 .6479 L F
.25708 .64742 m .25898 .64864 L .25684 .64617 L F
.542 .284 .475 r
.57883 .60691 m .57628 .60909 L .57654 .60699 L F
.485 .042 .122 r
.5439 .78283 m .54068 .78189 L .53972 .78323 L F
.787 .678 .744 r
.38173 .69944 m .37952 .70238 L .38301 .70243 L F
.51 .298 .528 r
.38301 .70243 m .3848 .7044 L .38517 .70201 L F
.815 .729 .769 r
.55353 .59583 m .54949 .59764 L .55206 .59484 L F
.55353 .59583 m .55141 .59869 L .54949 .59764 L F
.906 .647 .534 r
.47593 .81213 m .47779 .81504 L .47639 .81468 L F
0 .287 .732 r
.47779 .81504 m .4792 .81557 L .47639 .81468 L F
.351 .826 .869 r
.47988 .81624 m .48095 .81557 L .4792 .81557 L F
.077 0 0 r
.47965 .81566 m .4792 .81557 L .48095 .81557 L F
.47745 .81582 m .4792 .81557 L .47965 .81566 L F
0 .287 .732 r
.47779 .81504 m .47842 .8154 L .4792 .81557 L F
.47842 .8154 m .47988 .81624 L .4792 .81557 L F
.448 .111 .301 r
.57193 .69905 m .57427 .69867 L .5747 .69642 L F
.313 .055 .352 r
.5747 .69642 m .5763 .69702 L .57717 .69367 L F
.359 .036 .276 r
.5747 .69642 m .57649 .698 L .5763 .69702 L F
.5747 .69642 m .57427 .69867 L .57649 .698 L F
.127 0 .223 r
.62881 .56734 m .62859 .56935 L .62658 .57025 L F
.002 0 .291 r
.62859 .56935 m .62667 .57263 L .62658 .57025 L F
.934 .702 .222 r
.62209 .54772 m .62143 .54807 L .62171 .54632 L F
.62209 .54772 m .62217 .5502 L .62143 .54807 L F
.277 .444 .847 r
.52562 .68544 m .5282 .68712 L .52576 .68585 L F
.533 .388 .629 r
.52825 .69003 m .52576 .68585 L .5282 .68712 L F
.52825 .69003 m .52628 .69055 L .52576 .68585 L F
.631 .296 .385 r
.51672 .78033 m .5189 .78264 L .52093 .77845 L F
.751 .426 .435 r
.5189 .78264 m .52224 .78111 L .52093 .77845 L F
.584 .395 .592 r
.58656 .60114 m .58902 .60321 L .58669 .60327 L F
.58656 .60114 m .58898 .60076 L .58902 .60321 L F
.553 .283 .46 r
.76484 .57518 m .7664 .57321 L .76489 .57325 L F
.707 .489 .591 r
.50142 .76153 m .50353 .76185 L .50523 .76116 L F
.564 .218 .341 r
.50523 .76116 m .50353 .76185 L .50708 .76104 L F
.848 .841 .838 r
.73963 .49735 m .7375 .50016 L .73631 .49908 L F
.694 .311 .317 r
.25494 .62911 m .25686 .63091 L .25867 .62931 L F
.831 .731 .753 r
.25686 .63091 m .26096 .62895 L .25867 .62931 L F
.099 0 0 r
.33733 .64064 m .33586 .64263 L .33457 .64258 L F
.21 0 .002 r
.33791 .64194 m .33733 .64064 L .33911 .63984 L F
.33791 .64194 m .33586 .64263 L .33733 .64064 L F
0 0 0 r
.51805 .80533 m .51903 .80447 L .52153 .8034 L F
.63 .335 .452 r
.55477 .71082 m .55706 .71288 L .55768 .71097 L F
.851 .819 .818 r
.64673 .50224 m .64588 .50552 L .6476 .50557 L F
.64673 .50224 m .64588 .50552 L .6476 .50557 L F
.739 .287 .178 r
.6476 .50557 m .64654 .50678 L .64588 .50552 L F
.987 .721 .425 r
.6476 .50557 m .64782 .50943 L .64654 .50678 L F
.689 .618 .771 r
.27395 .64614 m .27778 .64702 L .27622 .64525 L F
.705 .62 .759 r
.27622 .64525 m .27778 .64702 L .27972 .64595 L F
.169 0 0 r
.7661 .57949 m .76287 .5806 L .7627 .58036 L F
.641 .853 .468 r
.76763 .57714 m .7661 .57949 L .76869 .57896 L F
.714 .588 .714 r
.57292 .60674 m .57071 .60956 L .56944 .60602 L F
.316 .101 .42 r
.34076 .61787 m .34232 .61944 L .34271 .61735 L F
.34076 .61787 m .34069 .6202 L .34232 .61944 L F
.391 .475 .826 r
.47703 .76359 m .47579 .76538 L .47414 .76572 L F
.47703 .76359 m .47812 .76658 L .47579 .76538 L F
0 0 .575 r
.59177 .72182 m .5932 .72503 L .59524 .72311 L F
.59177 .72182 m .59299 .72359 L .5932 .72503 L F
.944 .931 .579 r
.5932 .72503 m .59299 .72359 L .59185 .7266 L F
.486 .131 .289 r
.46329 .6985 m .46359 .69712 L .46563 .69832 L F
.505 .105 .216 r
.46359 .69712 m .46594 .6971 L .46563 .69832 L F
.63 .751 .934 r
.30609 .63169 m .30264 .63097 L .30455 .63075 L F
.381 .696 .982 r
.30663 .63049 m .30609 .63169 L .30455 .63075 L F
.30663 .63049 m .30808 .63168 L .30609 .63169 L F
.708 .768 .899 r
.68264 .53106 m .67908 .53068 L .68148 .53002 L F
.948 .819 .683 r
.72922 .50962 m .73049 .51079 L .72978 .50769 L F
.934 .794 .682 r
.72789 .51279 m .73049 .51079 L .72922 .50962 L F
.72789 .51279 m .72915 .51406 L .73049 .51079 L F
.619 .325 .449 r
.54348 .73865 m .54257 .74163 L .54033 .74092 L F
.54 .219 .372 r
.54597 .73869 m .54257 .74163 L .54348 .73865 L F
.625 .13 .055 r
.4859 .69277 m .48856 .69336 L .48892 .69238 L F
.405 0 0 r
.48892 .69238 m .48856 .69336 L .49107 .69297 L F
0 0 .177 r
.58913 .54285 m .58843 .54229 L .58731 .54363 L F
.542 .284 .475 r
.57883 .60691 m .57867 .60891 L .57628 .60909 L F
.561 .403 .624 r
.581 .60383 m .5812 .60644 L .57883 .60691 L F
.533 .288 .49 r
.5812 .60644 m .57867 .60891 L .57883 .60691 L F
.979 .88 .514 r
.64018 .5367 m .63912 .53831 L .63971 .53892 L F
.956 .666 .446 r
.63884 .53573 m .63912 .53831 L .64018 .5367 L F
.678 .538 .687 r
.5711 .7081 m .56919 .71076 L .56791 .70679 L F
.5711 .7081 m .57225 .71064 L .56919 .71076 L F
.656 .441 .58 r
.57225 .71064 m .56926 .71251 L .56919 .71076 L F
.783 .7 .773 r
.48698 .64558 m .48512 .64839 L .48829 .64864 L F
.732 .677 .797 r
.48698 .64558 m .48829 .64864 L .49057 .64597 L F
.573 .027 0 r
.56505 .74863 m .56539 .74762 L .56417 .74685 L F
.56505 .74863 m .56564 .74882 L .56539 .74762 L F
.703 .572 .705 r
.58741 .58121 m .5911 .58395 L .59105 .58152 L F
.446 .139 .35 r
.63624 .48281 m .63839 .48228 L .63862 .47984 L F
.568 .56 .804 r
.55827 .71365 m .55768 .71097 L .55706 .71288 L F
.55827 .71365 m .55963 .71003 L .55768 .71097 L F
.532 .343 .571 r
.56053 .7108 m .56063 .71331 L .55827 .71365 L F
.568 .56 .804 r
.55827 .71365 m .56063 .71331 L .55963 .71003 L F
.469 .795 .999 r
.55938 .71249 m .55827 .71365 L .55706 .71288 L F
.55938 .71249 m .56063 .71331 L .55827 .71365 L F
.557 .476 .719 r
.50268 .64664 m .50413 .64299 L .50175 .64354 L F
.50268 .64664 m .50472 .64641 L .50413 .64299 L F
.626 .551 .751 r
.50268 .64664 m .50529 .64836 L .50472 .64641 L F
.725 .623 .743 r
.57082 .70505 m .5711 .7081 L .56791 .70679 L F
.634 .555 .748 r
.57352 .70677 m .5711 .7081 L .57082 .70505 L F
0 0 .016 r
.57352 .70677 m .57225 .71064 L .5711 .7081 L F
.765 .67 .758 r
.48273 .69098 m .47955 .69085 L .48315 .69098 L F
.486 0 0 r
.47955 .69085 m .48236 .69199 L .48315 .69098 L F
.767 .369 .299 r
.48236 .69199 m .4859 .69277 L .48315 .69098 L F
.553 .329 .53 r
.45651 .69094 m .45883 .69075 L .4591 .68837 L F
.346 .154 .472 r
.4591 .68837 m .45883 .69075 L .46088 .6877 L F
.109 0 .206 r
.631 .5645 m .63077 .56673 L .62881 .56734 L F
.243 .007 .343 r
.63077 .56673 m .62859 .56935 L .62881 .56734 L F
.287 0 .163 r
.61338 .59251 m .61042 .59508 L .61123 .59329 L F
.448 .635 .935 r
.52435 .79702 m .52364 .79475 L .52374 .79671 L F
.443 .083 .257 r
.37714 .60748 m .37767 .61033 L .37558 .61097 L F
.37714 .60748 m .3794 .6071 L .37767 .61033 L F
.081 0 .015 r
.69038 .51587 m .69083 .51467 L .68819 .51674 L F
.444 .519 .841 r
.69038 .51587 m .6907 .51717 L .68819 .51674 L F
.44 .22 .481 r
.29285 .61214 m .29262 .61454 L .2905 .61509 L F
.515 .282 .499 r
.29458 .6141 m .29285 .61214 L .29497 .61158 L F
.29458 .6141 m .29262 .61454 L .29285 .61214 L F
.45 .533 .85 r
.51501 .66297 m .51581 .65993 L .51334 .6601 L F
.51501 .66297 m .51704 .66265 L .51581 .65993 L F
.395 .208 .505 r
.51501 .66297 m .51503 .66538 L .51704 .66265 L F
.51501 .66297 m .51503 .66538 L .51704 .66265 L F
.653 .375 .487 r
.5018 .80852 m .49904 .80618 L .50162 .80511 L F
.5018 .80852 m .49806 .80889 L .49904 .80618 L F
.276 .127 .491 r
.54299 .77443 m .5397 .77625 L .5413 .77251 L F
.09 0 .361 r
.5413 .77251 m .5397 .77625 L .5411 .77551 L F
0 0 0 r
.54056 .7769 m .5397 .77625 L .54299 .77443 L F
0 0 .009 r
.5411 .77551 m .5397 .77625 L .54056 .7769 L F
.559 .278 .445 r
.57717 .69367 m .57942 .69582 L .57837 .69244 L F
.57717 .69367 m .5763 .69702 L .57942 .69582 L F
.481 .03 .103 r
.30014 .64777 m .29641 .64891 L .29722 .64867 L F
.72 .868 .951 r
.68286 .53599 m .68396 .5371 L .68607 .53589 L F
.54 0 0 r
.6435 .4795 m .64289 .47932 L .64145 .47829 L F
.726 .396 .42 r
.49939 .78582 m .50035 .78344 L .49711 .78365 L F
.604 .478 .682 r
.50035 .78344 m .50276 .78369 L .50318 .78157 L F
.573 .206 .307 r
.50194 .78524 m .50035 .78344 L .49939 .78582 L F
.50194 .78524 m .50276 .78369 L .50035 .78344 L F
.517 .236 .427 r
.36681 .61516 m .36864 .61679 L .36638 .61719 L F
.36681 .61516 m .36906 .61487 L .36864 .61679 L F
.628 .592 .794 r
.54245 .74797 m .54512 .74778 L .54333 .74456 L F
.503 .317 .56 r
.29262 .61454 m .29032 .61711 L .2905 .61509 L F
.835 .707 .723 r
.77342 .60066 m .77452 .60395 L .77298 .60514 L F
.883 .854 .809 r
.77298 .60514 m .77452 .60395 L .77241 .60678 L F
.804 .97 .664 r
.77241 .60678 m .77452 .60395 L .7733 .60484 L F
.307 .75 .964 r
.77342 .60066 m .77496 .60254 L .77452 .60395 L F
.83 .973 .664 r
.7733 .60484 m .77452 .60395 L .77496 .60254 L F
.595 .399 .586 r
.51333 .67206 m .5139 .67388 L .51639 .67064 L F
0 .428 .755 r
.328 .58782 m .33055 .58865 L .33205 .58929 L F
.142 .641 .91 r
.33055 .58865 m .334 .58947 L .33205 .58929 L F
.929 .928 .785 r
.56131 .57635 m .56334 .57593 L .56137 .57882 L F
.56131 .57635 m .56228 .57537 L .56334 .57593 L F
.944 .918 .758 r
.56334 .57593 m .56228 .57537 L .56412 .57191 L F
.652 .75 .922 r
.47814 .65875 m .47929 .66041 L .4812 .65949 L F
.388 .117 .376 r
.3911 .66231 m .39366 .65936 L .3914 .65987 L F
.84 .709 .718 r
.55141 .59869 m .55076 .60095 L .54949 .59764 L F
.565 .582 .829 r
.50679 .81461 m .50844 .81641 L .50909 .81531 L F
.697 .354 .391 r
.5193 .78999 m .52107 .7921 L .51905 .79178 L F
.407 .747 .994 r
.51905 .79178 m .52107 .7921 L .52015 .791 L F
.51905 .79178 m .52015 .791 L .51873 .794 L F
.51905 .79178 m .51873 .794 L .51867 .79415 L F
.697 .354 .391 r
.51909 .78973 m .5193 .78999 L .51905 .79178 L F
.621 .354 .491 r
.5214 .78972 m .52107 .7921 L .51909 .78973 L F
.628 .822 .975 r
.27939 .65094 m .28125 .65228 L .28319 .65143 L F
.995 .755 .438 r
.70967 .48485 m .70788 .48424 L .70774 .48373 L F
.938 .735 .603 r
.50559 .79244 m .50517 .79489 L .50392 .79174 L F
.619 .602 .811 r
.31448 .66244 m .31799 .66011 L .3158 .66119 L F
.65 .915 .614 r
.71056 .47234 m .7085 .47462 L .70964 .47306 L F
.066 0 0 r
.71056 .47234 m .70964 .47306 L .71196 .47242 L F
.957 .641 .387 r
.71056 .47234 m .70964 .47306 L .70937 .47096 L F
.066 0 0 r
.71056 .47234 m .71196 .47242 L .7126 .47138 L F
.535 .334 .554 r
.71196 .47242 m .70964 .47306 L .70937 .47096 L F
.454 .807 .997 r
.71196 .47242 m .71028 .47218 L .70964 .47306 L F
.428 .584 .905 r
.70753 .47162 m .70964 .47306 L .70937 .47096 L F
.7066 .47195 m .70774 .47237 L .70753 .47162 L F
.70774 .47237 m .70964 .47306 L .70753 .47162 L F
.599 .811 .981 r
.70964 .47306 m .70838 .47475 L .70721 .47367 L F
.65 .915 .614 r
.7085 .47462 m .70838 .47475 L .70964 .47306 L F
.599 .811 .981 r
.70964 .47306 m .70721 .47367 L .70944 .47544 L F
.428 .584 .905 r
.70792 .47243 m .70856 .47195 L .70964 .47306 L F
.7066 .47195 m .70856 .47195 L .70792 .47243 L F
.7066 .47195 m .70937 .47096 L .70781 .47136 L F
.875 .944 .857 r
.70937 .47096 m .70781 .47136 L .71073 .46722 L F
.684 .718 .875 r
.71111 .46816 m .7126 .47138 L .70937 .47096 L F
.535 .334 .554 r
.71196 .47242 m .70937 .47096 L .7126 .47138 L F
.875 .944 .857 r
.70937 .47096 m .71073 .46722 L .71111 .46816 L F
.605 .798 .973 r
.70856 .47195 m .71164 .47209 L .70977 .46948 L F
0 0 .101 r
.70977 .46948 m .70955 .4712 L .70856 .47195 L F
.454 .807 .997 r
.71028 .47218 m .70856 .47195 L .70964 .47306 L F
.71196 .47242 m .71164 .47209 L .70856 .47195 L F
0 0 .101 r
.70955 .4712 m .70916 .47417 L .70856 .47195 L F
0 .298 .795 r
.70916 .47417 m .70825 .47366 L .70856 .47195 L F
.7082 .47392 m .70787 .47282 L .70856 .47195 L F
.428 .584 .905 r
.7066 .47195 m .70721 .47367 L .70856 .47195 L F
.723 .617 .739 r
.70944 .47544 m .71196 .47242 L .70964 .47306 L F
.764 .75 .84 r
.70781 .46714 m .70781 .47136 L .70535 .46921 L F
.781 .764 .837 r
.71073 .46722 m .70781 .47136 L .70781 .46714 L F
.723 .617 .739 r
.70944 .47544 m .7132 .47594 L .71196 .47242 L F
.512 .265 .476 r
.70944 .47544 m .71257 .476 L .7132 .47594 L F
.70944 .47544 m .7104 .47813 L .71257 .476 L F
.336 .528 .895 r
.70945 .47353 m .71242 .47538 L .71115 .47595 L F
0 0 .101 r
.70977 .46948 m .70954 .47265 L .70916 .47417 L F
.70954 .47265 m .70952 .47287 L .70939 .47334 L F
.70954 .47265 m .70939 .47334 L .70916 .47417 L F
.796 .654 .705 r
.71196 .47242 m .7132 .47594 L .71478 .4731 L F
.336 .528 .895 r
.70955 .47259 m .71308 .47386 L .71242 .47538 L F
.763 .619 .7 r
.70711 .47016 m .70977 .46948 L .7072 .46996 L F
.336 .528 .895 r
.70717 .47028 m .70724 .47032 L .70732 .47042 L F
.70821 .47175 m .70952 .47287 L .70945 .47353 L F
.70955 .47259 m .71242 .47538 L .70945 .47353 L F
0 0 .101 r
.70952 .47287 m .70948 .47348 L .70945 .47353 L F
.70952 .47287 m .70945 .47353 L .70916 .47417 L F
.763 .619 .7 r
.70734 .47052 m .70775 .47096 L .70732 .47042 L F
0 .193 .724 r
.70729 .4705 m .70777 .47118 L .70916 .47417 L F
.70777 .47118 m .70939 .47366 L .70916 .47417 L F
.70777 .47118 m .70945 .47353 L .70939 .47366 L F
.763 .619 .7 r
.70932 .47341 m .70947 .47362 L .70948 .47348 L F
0 .193 .724 r
.70945 .47353 m .71038 .47485 L .70916 .47417 L F
0 0 .101 r
.70948 .47348 m .70947 .47362 L .70916 .47417 L F
0 .193 .724 r
.70757 .47091 m .70916 .47417 L .70938 .47377 L F
.70729 .4705 m .70916 .47417 L .70757 .47091 L F
.763 .619 .7 r
.70767 .47102 m .70775 .47096 L .70734 .47052 L F
0 .193 .724 r
.70717 .47028 m .70821 .47175 L .70729 .4705 L F
.763 .619 .7 r
.70735 .47054 m .70767 .47102 L .70734 .47052 L F
.70766 .47103 m .70767 .47102 L .70735 .47054 L F
.70766 .47103 m .70952 .47287 L .70977 .46948 L F
.70749 .47115 m .70809 .47166 L .70766 .47103 L F
.70809 .47166 m .70952 .47287 L .70766 .47103 L F
0 .193 .724 r
.70717 .47028 m .70757 .47091 L .7073 .47046 L F
.70757 .47091 m .70938 .47377 L .70766 .47103 L F
.70757 .47091 m .70766 .47103 L .7073 .47046 L F
.70766 .47103 m .70938 .47377 L .70947 .47362 L F
.70821 .47175 m .70945 .47353 L .70729 .4705 L F
.699 .757 .896 r
.7066 .47195 m .70721 .47367 L .70381 .4731 L F
.763 .619 .7 r
.70711 .47143 m .70952 .47287 L .70749 .47115 L F
.70625 .47206 m .70718 .47229 L .70711 .47143 L F
.70718 .47229 m .70952 .47287 L .70711 .47143 L F
.70625 .47206 m .70932 .47341 L .70882 .47269 L F
.70625 .47206 m .70947 .47362 L .70932 .47341 L F
.701 .778 .912 r
.7066 .47195 m .70381 .4731 L .70275 .47166 L F
.796 .75 .81 r
.70781 .47136 m .7066 .47195 L .70535 .46921 L F
.701 .778 .912 r
.7066 .47195 m .70275 .47166 L .70535 .46921 L F
.763 .619 .7 r
.70625 .47206 m .70711 .47143 L .70711 .47016 L F
.70711 .47143 m .70749 .47115 L .70725 .47052 L F
0 .298 .795 r
.70916 .47417 m .7082 .47392 L .70825 .47366 L F
.7082 .47392 m .70721 .47367 L .70787 .47282 L F
.70916 .47417 m .70944 .47544 L .70721 .47367 L F
.61 .793 .969 r
.70381 .4731 m .70721 .47367 L .70485 .47435 L F
.361 .311 .666 r
.70727 .47578 m .70947 .47362 L .70625 .47206 L F
.70727 .47578 m .70718 .4706 L .70947 .47362 L F
.70718 .4706 m .70717 .47028 L .7073 .47046 L F
0 .193 .724 r
.7073 .47046 m .70766 .47103 L .70947 .47362 L F
.70717 .47028 m .70729 .4705 L .70757 .47091 L F
.763 .619 .7 r
.70749 .47115 m .70766 .47103 L .70735 .47054 L F
.336 .528 .895 r
.70717 .47028 m .70732 .47042 L .70734 .47052 L F
.763 .619 .7 r
.70749 .47115 m .70732 .47042 L .70724 .47032 L F
.689 .48 .6 r
.7072 .47034 m .70724 .47032 L .70717 .47028 L F
.763 .619 .7 r
.70719 .47035 m .70724 .47032 L .70711 .47016 L F
.70749 .47115 m .70724 .47032 L .70719 .47035 L F
.361 .311 .666 r
.70718 .4706 m .7073 .47046 L .70947 .47362 L F
.763 .619 .7 r
.70882 .47269 m .70948 .47348 L .70892 .47272 L F
.70932 .47341 m .70948 .47348 L .70882 .47269 L F
.70892 .47272 m .70948 .47348 L .70952 .47287 L F
.336 .528 .895 r
.70734 .47052 m .70955 .47259 L .70952 .47287 L F
.70734 .47052 m .70952 .47287 L .70821 .47175 L F
.70732 .47042 m .70955 .47259 L .70734 .47052 L F
.763 .619 .7 r
.70775 .47096 m .70977 .46948 L .70711 .47016 L F
.336 .528 .895 r
.70732 .47042 m .70972 .47182 L .70955 .47259 L F
.70724 .47032 m .70972 .47182 L .70732 .47042 L F
.70972 .47182 m .71308 .47386 L .70955 .47259 L F
0 .193 .724 r
.71038 .47485 m .71115 .47595 L .70916 .47417 L F
0 0 .29 r
.70916 .47417 m .7098 .47623 L .70944 .47544 L F
.7098 .47623 m .7104 .47813 L .70976 .47635 L F
.7098 .47623 m .70976 .47635 L .70944 .47544 L F
.778 .494 .506 r
.7132 .47594 m .71596 .47409 L .71478 .4731 L F
.538 .595 .859 r
.71081 .4787 m .71257 .476 L .7104 .47813 L F
.273 .773 .875 r
.71195 .47885 m .71454 .47841 L .71081 .4787 L F
.402 0 0 r
.71081 .4787 m .71221 .47859 L .7134 .47897 L F
.71221 .47859 m .71454 .47841 L .7134 .47897 L F
.952 .649 .424 r
.71693 .47915 m .71539 .48037 L .7134 .47897 L F
.281 .345 .752 r
.7134 .47897 m .71539 .48037 L .71523 .47955 L F
.952 .649 .424 r
.71693 .47915 m .7134 .47897 L .71454 .47841 L F
.281 .345 .752 r
.7134 .47897 m .71523 .47955 L .71459 .47631 L F
.538 .595 .859 r
.71081 .4787 m .7134 .47897 L .71257 .476 L F
.246 0 0 r
.71257 .476 m .71451 .47582 L .7132 .47594 L F
.71257 .476 m .71459 .47631 L .71451 .47582 L F
.281 .345 .752 r
.7134 .47897 m .71459 .47631 L .71257 .476 L F
.871 .654 .606 r
.70944 .47624 m .7104 .47813 L .70916 .47417 L F
.748 .618 .714 r
.70944 .47624 m .7104 .47813 L .71257 .476 L F
.70944 .47624 m .7104 .47813 L .71257 .476 L F
.177 0 0 r
.71257 .476 m .71459 .47631 L .71115 .47595 L F
.71257 .476 m .71459 .47631 L .71115 .47595 L F
.718 .761 .886 r
.71115 .47595 m .71459 .47631 L .71242 .47538 L F
.216 0 0 r
.71242 .47538 m .71165 .47582 L .71115 .47595 L F
0 0 .148 r
.70944 .47624 m .70763 .47874 L .7104 .47813 L F
.748 .618 .714 r
.70944 .47624 m .71257 .476 L .71115 .47595 L F
.216 0 0 r
.71165 .47582 m .70944 .47706 L .71115 .47595 L F
.748 .618 .714 r
.70982 .47618 m .71047 .47613 L .71115 .47595 L F
.71047 .47613 m .71257 .476 L .71115 .47595 L F
.70944 .47624 m .70981 .47621 L .70982 .47618 L F
.70981 .47621 m .71257 .476 L .70982 .47618 L F
.689 .48 .6 r
.70904 .47488 m .71308 .47386 L .70724 .47032 L F
.70904 .47488 m .70724 .47032 L .7072 .47034 L F
.763 .619 .7 r
.70718 .4706 m .70725 .47052 L .7072 .47038 L F
.70711 .47143 m .70725 .47052 L .70718 .4706 L F
.361 .311 .666 r
.70718 .4706 m .7072 .47034 L .70717 .47028 L F
.763 .619 .7 r
.70711 .47143 m .7072 .47038 L .70711 .47016 L F
.361 .311 .666 r
.70722 .47295 m .70904 .47488 L .7072 .47034 L F
.70722 .47295 m .7072 .47034 L .70718 .4706 L F
.70727 .47578 m .70742 .47571 L .70722 .47295 L F
.70742 .47571 m .70904 .47488 L .70722 .47295 L F
.923 .742 .64 r
.5421 .62643 m .54003 .6263 L .54089 .62307 L F
.985 .77 .37 r
.5421 .62643 m .54127 .62761 L .54003 .6263 L F
.5421 .62643 m .54203 .62932 L .54127 .62761 L F
.743 .968 .933 r
.58725 .7258 m .58534 .72562 L .58378 .72708 L F
0 .408 .769 r
.58725 .7258 m .58749 .72572 L .58534 .72562 L F
.58725 .7258 m .58965 .72663 L .58749 .72572 L F
.591 .55 .777 r
.50467 .79733 m .50417 .79877 L .50366 .79719 L F
.634 .596 .793 r
.75827 .58305 m .7605 .58124 L .75791 .58185 L F
.339 0 0 r
.44731 .70183 m .44609 .7032 L .44412 .70294 L F
.262 0 0 r
.44954 .70141 m .44609 .7032 L .44731 .70183 L F
.49 .677 .948 r
.50052 .63104 m .49949 .63278 L .49827 .63143 L F
.50052 .63104 m .5018 .63257 L .49949 .63278 L F
0 0 .352 r
.71928 .50238 m .71962 .50201 L .71903 .49935 L F
.782 .86 .417 r
.65288 .48555 m .65319 .48413 L .65419 .48239 L F
.059 .319 .802 r
.65288 .48555 m .65493 .48698 L .65319 .48413 L F
.647 .879 .522 r
.63327 .56156 m .63191 .56302 L .631 .5645 L F
0 0 .122 r
.63167 .5655 m .631 .5645 L .63191 .56302 L F
.63167 .5655 m .63077 .56673 L .631 .5645 L F
.575 .36 .55 r
.76244 .57576 m .76613 .57777 L .76484 .57518 L F
.76244 .57576 m .76276 .57896 L .76613 .57777 L F
.715 .693 .827 r
.61891 .5247 m .62253 .52518 L .6216 .52235 L F
0 0 0 r
.62253 .52518 m .62489 .52237 L .6216 .52235 L F
.62253 .52518 m .62416 .52415 L .62489 .52237 L F
.699 .863 .96 r
.51946 .6622 m .52098 .66329 L .5224 .66231 L F
.799 .925 .92 r
.71008 .50874 m .70628 .51018 L .70881 .50746 L F
.723 .807 .917 r
.71369 .50714 m .71008 .50874 L .70881 .50746 L F
.21 .661 .948 r
.28993 .85045 m .28938 .85107 L .28877 .85115 L F
.28993 .85045 m .29177 .85134 L .28938 .85107 L F
.604 .948 .92 r
.50116 .74743 m .50024 .74724 L .50208 .74623 L F
.50116 .74743 m .50024 .74724 L .50208 .74623 L F
.685 .339 .383 r
.57012 .61193 m .56707 .61388 L .5669 .61225 L F
.57012 .61193 m .57095 .61402 L .56707 .61388 L F
.865 .882 .847 r
.71483 .50949 m .71353 .51352 L .7132 .51115 L F
.943 .692 .528 r
.38679 .70594 m .38499 .70693 L .3848 .7044 L F
.441 0 0 r
.38884 .70676 m .38679 .70594 L .38977 .70544 L F
.38884 .70676 m .38499 .70693 L .38679 .70594 L F
.99 .857 .611 r
.56908 .76664 m .56981 .76443 L .56891 .76142 L F
.877 .765 .735 r
.74058 .49165 m .73726 .4927 L .73923 .48983 L F
.74058 .49165 m .73869 .49398 L .73726 .4927 L F
.72 .512 .609 r
.741 .49289 m .73869 .49398 L .74058 .49165 L F
.606 .6 .819 r
.74221 .4871 m .74058 .49165 L .73923 .48983 L F
.478 .887 .938 r
.31465 .65744 m .31275 .65741 L .31555 .65655 L F
.31555 .65655 m .31275 .65741 L .31465 .65744 L F
.73 .504 .585 r
.50883 .79844 m .50865 .80037 L .50651 .80032 L F
.658 .867 .978 r
.25509 .63207 m .25662 .63294 L .25844 .63185 L F
.782 .9 .496 r
.49173 .77453 m .49276 .77314 L .49123 .77201 L F
0 0 .491 r
.66969 .51442 m .67086 .51466 L .66842 .51287 L F
.66969 .51442 m .67045 .516 L .67086 .51466 L F
.318 0 0 r
.45553 .69944 m .45412 .70095 L .45187 .70122 L F
.288 0 0 r
.45775 .6995 m .45412 .70095 L .45553 .69944 L F
.843 .981 .691 r
.59436 .70975 m .59357 .70985 L .59629 .70692 L F
0 0 0 r
.59436 .70975 m .59162 .71005 L .59264 .71284 L F
.59436 .70975 m .59357 .70985 L .59162 .71005 L F
.863 .663 .631 r
.59529 .71421 m .59436 .70975 L .59264 .71284 L F
.843 .981 .691 r
.59436 .70975 m .59629 .70692 L .59797 .7077 L F
.59436 .70975 m .59357 .70985 L .59629 .70692 L F
.186 .21 .653 r
.59529 .71421 m .59609 .71292 L .59436 .70975 L F
.909 .506 .202 r
.59609 .71292 m .59357 .70985 L .59436 .70975 L F
.718 .979 .914 r
.72328 .51889 m .72367 .51945 L .72673 .51748 L F
.626 .082 0 r
.59054 .69969 m .5926 .70164 L .59383 .70236 L F
.059 .62 .79 r
.5926 .70164 m .59624 .70183 L .59383 .70236 L F
.214 .576 .942 r
.5879 .70721 m .58847 .70704 L .58591 .70634 L F
.439 0 0 r
.58591 .70634 m .58847 .70704 L .5854 .70664 L F
.388 .19 .486 r
.52348 .69573 m .52159 .69394 L .52385 .69381 L F
.52348 .69573 m .52161 .69662 L .52159 .69394 L F
.075 0 .329 r
.5902 .53905 m .59195 .53805 L .59219 .53585 L F
0 0 0 r
.59099 .53945 m .5902 .53905 L .58934 .54062 L F
.59099 .53945 m .59195 .53805 L .5902 .53905 L F
.823 .713 .744 r
.53965 .6152 m .53663 .61496 L .53844 .61182 L F
.854 .863 .847 r
.53965 .6152 m .53567 .61725 L .53663 .61496 L F
.708 .656 .796 r
.5423 .61242 m .53965 .6152 L .53844 .61182 L F
.565 .666 .905 r
.26126 .64303 m .2645 .64437 L .26143 .63962 L F
.614 .689 .896 r
.26143 .63962 m .2645 .64437 L .26531 .63995 L F
.295 0 .248 r
.2645 .64437 m .2668 .64295 L .26531 .63995 L F
.169 .696 .865 r
.51173 .7772 m .5107 .77751 L .50945 .77771 L F
.51173 .7772 m .51295 .77743 L .5107 .77751 L F
0 .481 .766 r
.29107 .5841 m .29264 .58461 L .29018 .58394 L F
.094 0 0 r
.28946 .58481 m .29231 .58431 L .29107 .5841 L F
.203 .722 .871 r
.29316 .58417 m .29264 .58461 L .29107 .5841 L F
.094 0 0 r
.29231 .58431 m .29316 .58417 L .29107 .5841 L F
0 .481 .766 r
.29107 .5841 m .29018 .58394 L .2891 .58365 L F
.203 .722 .871 r
.29316 .58417 m .29479 .58444 L .29264 .58461 L F
.645 .41 .548 r
.56148 .70489 m .56411 .70494 L .56395 .70245 L F
.612 .385 .548 r
.56395 .70245 m .56718 .70462 L .56708 .70206 L F
.56395 .70245 m .56411 .70494 L .56718 .70462 L F
.723 .746 .87 r
.77618 .59811 m .7768 .6011 L .77342 .60066 L F
.307 .75 .964 r
.77342 .60066 m .7768 .6011 L .77651 .60059 L F
.857 .628 .091 r
.77618 .59811 m .7768 .6011 L .77651 .60059 L F
.696 .622 .77 r
.54402 .75779 m .54745 .75818 L .54671 .75513 L F
.372 .788 .978 r
.32348 .58709 m .32272 .58803 L .32105 .58721 L F
.32348 .58709 m .32501 .58779 L .32272 .58803 L F
.915 .929 .554 r
.63327 .56156 m .63421 .55783 L .6339 .56017 L F
.723 .908 .542 r
.6339 .56017 m .63191 .56302 L .63327 .56156 L F
.14 .115 .566 r
.47772 .77988 m .47754 .78427 L .47644 .78099 L F
.554 .478 .724 r
.38611 .67701 m .38825 .67657 L .38769 .67453 L F
.536 .451 .707 r
.38611 .67701 m .3889 .67926 L .38825 .67657 L F
.38611 .67701 m .38661 .67997 L .3889 .67926 L F
.639 .966 .864 r
.47657 .6349 m .47758 .63359 L .47829 .63379 L F
.638 .952 .752 r
.47657 .6349 m .47683 .63444 L .47758 .63359 L F
.305 .489 .875 r
.39767 .70707 m .39967 .71038 L .40074 .70928 L F
.666 .364 .452 r
.40195 .71222 m .40187 .71345 L .39967 .71038 L F
.125 .2 .672 r
.39967 .71038 m .40187 .71345 L .40074 .70928 L F
.753 .981 .737 r
.38656 .70308 m .3848 .7044 L .38517 .70201 L F
.582 .709 .93 r
.3873 .70149 m .38656 .70308 L .38517 .70201 L F
.257 0 0 r
.42205 .69573 m .42399 .6964 L .42556 .69687 L F
.092 0 0 r
.42399 .6964 m .42782 .69663 L .42556 .69687 L F
.838 .757 .774 r
.62374 .52089 m .62489 .52237 L .62765 .5195 L F
.62374 .52089 m .62765 .5195 L .62627 .52027 L F
.744 .588 .682 r
.62489 .52237 m .62667 .5224 L .62765 .5195 L F
.375 .205 .519 r
.62765 .5195 m .62667 .5224 L .6277 .52175 L F
.978 .701 .431 r
.62765 .5195 m .6277 .52175 L .62627 .52027 L F
.652 .244 .259 r
.54963 .75672 m .54671 .75513 L .54808 .75531 L F
.512 .61 .887 r
.54745 .75818 m .54964 .75806 L .54871 .75643 L F
.652 .244 .259 r
.54959 .75669 m .54871 .75643 L .54671 .75513 L F
.54871 .75643 m .54789 .75619 L .54776 .75607 L F
.54871 .75643 m .54776 .75607 L .54671 .75513 L F
.403 .572 .905 r
.55074 .75634 m .54963 .75672 L .54808 .75531 L F
.534 .699 .946 r
.54871 .75643 m .55074 .75634 L .54808 .75531 L F
.54891 .75679 m .54951 .75673 L .54881 .75659 L F
.54964 .75806 m .54951 .75675 L .54891 .75679 L F
.54951 .75675 m .54951 .75673 L .54891 .75679 L F
.54964 .75806 m .5503 .75703 L .54951 .75673 L F
.512 .61 .887 r
.54745 .75818 m .54871 .75643 L .54789 .75619 L F
.534 .699 .946 r
.54964 .75806 m .55195 .7578 L .55098 .75663 L F
.55052 .75668 m .55098 .75663 L .55074 .75634 L F
.54964 .75806 m .55098 .75663 L .55052 .75668 L F
.153 0 0 r
.55084 .75739 m .5475 .75766 L .54939 .75682 L F
.54966 .75679 m .54939 .75682 L .54957 .75674 L F
.55084 .75739 m .54939 .75682 L .54966 .75679 L F
.54967 .75674 m .54957 .75674 L .54963 .75672 L F
.55084 .75739 m .54957 .75674 L .54967 .75674 L F
.512 .61 .887 r
.54745 .75818 m .54789 .75619 L .54671 .75513 L F
.467 0 0 r
.54951 .75673 m .5475 .75766 L .54488 .75732 L F
.54963 .75672 m .54957 .75674 L .54951 .75673 L F
.54957 .75674 m .5475 .75766 L .54951 .75673 L F
.534 .699 .946 r
.54881 .75659 m .54951 .75673 L .54871 .75643 L F
.652 .244 .259 r
.54963 .75672 m .54789 .75619 L .54959 .75669 L F
.534 .699 .946 r
.5503 .75703 m .55074 .75634 L .5496 .75677 L F
.153 0 0 r
.55084 .75739 m .54967 .75674 L .55074 .75634 L F
.54967 .75674 m .54963 .75672 L .55074 .75634 L F
.534 .699 .946 r
.5496 .75677 m .55074 .75634 L .54871 .75643 L F
.512 .61 .887 r
.54789 .75619 m .54871 .75643 L .54808 .75531 L F
.652 .244 .259 r
.54963 .75672 m .54862 .75684 L .54789 .75619 L F
.54862 .75684 m .54488 .75732 L .54671 .75513 L F
.512 .61 .887 r
.54789 .75619 m .54808 .75531 L .54671 .75513 L F
.496 .204 .399 r
.3523 .62941 m .35171 .63133 L .34944 .6317 L F
.424 .137 .37 r
.35434 .6289 m .35171 .63133 L .3523 .62941 L F
.704 .327 .333 r
.44758 .6913 m .45037 .69269 L .45079 .69104 L F
.549 .262 .432 r
.45037 .69269 m .45274 .69256 L .45079 .69104 L F
.225 0 0 r
.44301 .64719 m .4452 .64717 L .44685 .64651 L F
0 0 0 r
.44685 .64651 m .44732 .64643 L .449 .64592 L F
.44685 .64651 m .4452 .64717 L .44732 .64643 L F
.705 .62 .759 r
.27622 .64525 m .27972 .64595 L .27777 .64361 L F
.494 .623 .907 r
.27972 .64595 m .28048 .64407 L .27777 .64361 L F
.27972 .64595 m .28174 .6457 L .28048 .64407 L F
.558 .557 .808 r
.27972 .64595 m .28304 .64875 L .28174 .6457 L F
.84 .97 .882 r
.67348 .53522 m .67478 .53553 L .67604 .53436 L F
.671 .438 .559 r
.74643 .58199 m .74574 .58527 L .74296 .58285 L F
.74643 .58199 m .74335 .58369 L .74597 .58365 L F
.74643 .58199 m .74296 .58285 L .74335 .58369 L F
.519 .227 .41 r
.74643 .58199 m .74892 .58291 L .74894 .58118 L F
.74643 .58199 m .74597 .58365 L .74892 .58291 L F
.918 .952 .8 r
.69538 .52058 m .69578 .5222 L .6941 .52393 L F
.683 .83 .954 r
.69945 .50858 m .69828 .51069 L .69726 .50984 L F
.69945 .50858 m .70062 .50978 L .69828 .51069 L F
.995 .755 .438 r
.70967 .48485 m .70871 .4843 L .7097 .48252 L F
.531 .874 .989 r
.71046 .48419 m .70871 .4843 L .70967 .48485 L F
.69 .241 .18 r
.7097 .48252 m .71187 .4842 L .71329 .48304 L F
.262 0 .034 r
.71115 .48364 m .71128 .48351 L .71212 .4844 L F
.7097 .48252 m .71128 .48351 L .71115 .48364 L F
.244 .446 .859 r
.70931 .48034 m .71269 .48241 L .71128 .48351 L F
.44 .818 .572 r
.71269 .48241 m .71143 .48338 L .71128 .48351 L F
.531 .874 .989 r
.71128 .48351 m .70909 .48418 L .71046 .48419 L F
.262 0 .034 r
.7097 .48252 m .70871 .4843 L .71128 .48351 L F
.899 .906 .82 r
.70871 .4843 m .70931 .48034 L .71128 .48351 L F
.70871 .4843 m .70747 .48372 L .70931 .48034 L F
.437 0 0 r
.71128 .48351 m .70747 .48372 L .70871 .4843 L F
.71128 .48351 m .71012 .48438 L .70747 .48372 L F
.44 .818 .572 r
.71143 .48338 m .71012 .48438 L .71128 .48351 L F
.531 .874 .989 r
.70909 .48418 m .70871 .4843 L .71046 .48419 L F
.69 .241 .18 r
.71187 .4842 m .71212 .4844 L .71229 .48421 L F
.71187 .4842 m .71229 .48421 L .71329 .48304 L F
.947 .917 .548 r
.71329 .48304 m .71212 .4844 L .71261 .48455 L F
.482 .44 .734 r
.51186 .65973 m .51334 .6601 L .51287 .65697 L F
.651 .813 .961 r
.69284 .52522 m .68942 .52486 L .69173 .52405 L F
.763 .857 .92 r
.6941 .52393 m .69284 .52522 L .69173 .52405 L F
.562 .378 .589 r
.56492 .61433 m .56288 .61204 L .565 .61217 L F
.56492 .61433 m .56257 .61492 L .56288 .61204 L F
.915 .9 .797 r
.55911 .57957 m .56137 .57882 L .55943 .58192 L F
.9 .931 .827 r
.56131 .57635 m .56137 .57882 L .55911 .57957 L F
.524 .591 .863 r
.51142 .63864 m .50996 .64068 L .50868 .63781 L F
.5 .558 .846 r
.51142 .63864 m .51224 .6407 L .50996 .64068 L F
.305 0 .205 r
.60466 .57834 m .60639 .57774 L .60757 .57614 L F
.189 0 .245 r
.60639 .57774 m .60885 .57484 L .60757 .57614 L F
.742 .568 .658 r
.55512 .61544 m .55467 .61778 L .55276 .61471 L F
.702 .801 .926 r
.70485 .47435 m .70275 .47549 L .70149 .47402 L F
0 0 0 r
.5341 .80439 m .53681 .8039 L .53507 .80448 L F
.53564 .80423 m .5341 .80439 L .53292 .80308 L F
.53564 .80423 m .53681 .8039 L .5341 .80439 L F
.507 .444 .72 r
.53425 .79917 m .53292 .80308 L .53209 .80243 L F
0 0 0 r
.53564 .80423 m .53681 .8039 L .53463 .8043 L F
.507 .444 .72 r
.53425 .79917 m .53564 .80423 L .53292 .80308 L F
.506 .897 .744 r
.53681 .8039 m .53608 .80396 L .53542 .80436 L F
.507 .444 .72 r
.53564 .80423 m .53564 .80423 L .53564 .80423 L F
.53564 .80423 m .53564 .80423 L .53292 .80308 L F
.506 .897 .744 r
.53681 .8039 m .53786 .80305 L .53608 .80396 L F
0 0 0 r
.53564 .80423 m .53463 .8043 L .53473 .80433 L F
.617 .247 .319 r
.53292 .80308 m .53564 .80423 L .53507 .80448 L F
.506 .897 .744 r
.53542 .80436 m .53564 .80423 L .53507 .80448 L F
.617 .247 .319 r
.53564 .80423 m .53564 .80423 L .53507 .80448 L F
.506 .897 .744 r
.53564 .80423 m .53608 .80396 L .53507 .80448 L F
0 .193 .636 r
.53209 .80243 m .53292 .80308 L .53492 .80438 L F
.53493 .80439 m .53492 .80438 L .53507 .80448 L F
.53209 .80243 m .53492 .80438 L .53493 .80439 L F
0 0 0 r
.53473 .80433 m .53463 .8043 L .5341 .80439 L F
.5341 .80439 m .53507 .80448 L .53292 .80308 L F
.776 .634 .704 r
.49797 .76114 m .49738 .76239 L .50142 .76153 L F
.682 .324 .361 r
.50142 .76153 m .50353 .76352 L .50353 .76185 L F
.559 .35 .553 r
.77779 .58098 m .78023 .58028 L .77792 .57813 L F
.962 .872 .7 r
.59569 .56225 m .59624 .55937 L .59456 .56123 L F
.529 .434 .691 r
.28779 .62104 m .28645 .62324 L .28623 .62167 L F
.28779 .62104 m .2886 .62285 L .28645 .62324 L F
.113 .218 .695 r
.50826 .77569 m .50945 .77771 L .50765 .77579 L F
.683 .275 .265 r
.50765 .77579 m .50945 .77771 L .50613 .77759 L F
.46 .367 .663 r
.25025 .60649 m .25158 .60267 L .24983 .60406 L F
.218 .629 .954 r
.54199 .80151 m .53993 .8006 L .54032 .80102 L F
.593 .925 .965 r
.54199 .80151 m .54311 .80018 L .54032 .80102 L F
.54199 .80151 m .54444 .80048 L .54311 .80018 L F
0 0 0 r
.51198 .78389 m .50965 .7868 L .50847 .78358 L F
.612 .468 .661 r
.50965 .7868 m .51224 .78909 L .51209 .78637 L F
.323 0 0 r
.51047 .78621 m .51263 .78629 L .51166 .78711 L F
.51047 .78621 m .51166 .78711 L .51081 .7862 L F
0 0 0 r
.51198 .78389 m .51047 .78621 L .51012 .78621 L F
.323 0 0 r
.51047 .78621 m .51081 .7862 L .50957 .78488 L F
0 0 0 r
.51012 .78621 m .51047 .78621 L .50965 .7868 L F
.562 .396 .614 r
.51209 .78637 m .51438 .78593 L .51198 .78389 L F
.711 .336 .336 r
.51438 .78593 m .51047 .78621 L .51198 .78389 L F
.645 .55 .733 r
.24907 .61272 m .24939 .61483 L .25125 .61215 L F
.563 .441 .672 r
.24939 .61483 m .25157 .61459 L .25125 .61215 L F
.837 .707 .721 r
.55076 .60095 m .54775 .60078 L .54949 .59764 L F
.835 .717 .734 r
.55076 .60095 m .54886 .60385 L .54775 .60078 L F
.481 .044 .131 r
.54502 .76599 m .54724 .76584 L .54825 .76385 L F
0 0 .116 r
.54825 .76385 m .54983 .76321 L .55124 .7603 L F
.537 .292 .491 r
.54724 .76584 m .54983 .76321 L .54825 .76385 L F
.804 .97 .664 r
.77241 .60678 m .7733 .60484 L .77134 .60607 L F
.298 0 0 r
.42815 .70697 m .42678 .70803 L .42476 .70838 L F
.511 .081 .16 r
.43012 .70731 m .42678 .70803 L .42815 .70697 L F
.982 .728 .47 r
.58593 .57811 m .58588 .57581 L .58445 .57452 L F
.836 .812 .827 r
.58588 .57581 m .5867 .57179 L .58445 .57452 L F
.58588 .57581 m .58843 .57267 L .5867 .57179 L F
.612 .249 .33 r
.57319 .61221 m .57318 .61422 L .57095 .61402 L F
.599 .386 .563 r
.57529 .61191 m .57318 .61422 L .57319 .61221 L F
.66 .659 .838 r
.75253 .59867 m .75608 .60085 L .75521 .59837 L F
.753 .78 .875 r
.75521 .59837 m .75608 .60085 L .75889 .59863 L F
.893 .79 .739 r
.51884 .81267 m .51954 .81133 L .51696 .81158 L F
.096 .651 .71 r
.48232 .78668 m .48333 .78656 L .48013 .78696 L F
.521 .917 .843 r
.48426 .78564 m .48333 .78656 L .48232 .78668 L F
.689 .166 0 r
.4841 .78808 m .48537 .7889 L .48333 .78656 L F
.4841 .78808 m .48333 .78656 L .48426 .78564 L F
.489 .863 .983 r
.29841 .58427 m .29479 .58444 L .29683 .58407 L F
0 0 0 r
.2988 .58421 m .29841 .58427 L .29683 .58407 L F
.2988 .58421 m .30052 .58389 L .29841 .58427 L F
.834 .934 .894 r
.55237 .795 m .55383 .79192 L .55087 .79419 L F
.55237 .795 m .55509 .79255 L .55383 .79192 L F
.702 .725 .868 r
.67439 .51251 m .67256 .51589 L .67264 .51336 L F
.67439 .51251 m .67557 .51438 L .67256 .51589 L F
.871 .916 .856 r
.70533 .52045 m .70653 .52089 L .706 .51934 L F
.793 .854 .896 r
.70653 .52089 m .70778 .51801 L .706 .51934 L F
.70653 .52089 m .70879 .51915 L .70778 .51801 L F
.325 0 0 r
.45274 .69256 m .45504 .69235 L .45651 .69094 L F
.327 0 0 r
.45504 .69235 m .45883 .69075 L .45651 .69094 L F
.11 0 0 r
.77618 .59811 m .7783 .59826 L .77907 .59825 L F
.77618 .59811 m .7783 .59826 L .77907 .59825 L F
.884 .991 .752 r
.77907 .59825 m .78076 .59477 L .78082 .59522 L F
.77907 .59825 m .7783 .59826 L .78076 .59477 L F
.348 .642 .964 r
.78076 .59732 m .77907 .59825 L .7783 .59826 L F
.78076 .59732 m .78173 .59854 L .77907 .59825 L F
.77907 .59825 m .78173 .59854 L .78076 .59732 L F
.77907 .59825 m .78173 .59854 L .78076 .59732 L F
.915 .9 .797 r
.55911 .57957 m .55943 .58192 L .55821 .58059 L F
.979 .893 .543 r
.55825 .58362 m .55821 .58059 L .55943 .58192 L F
.488 .092 .214 r
.52212 .68754 m .52432 .68749 L .52562 .68544 L F
.691 .317 .334 r
.52562 .68544 m .52432 .68749 L .5282 .68712 L F
0 0 0 r
.54885 .61978 m .5482 .62054 L .54921 .61809 L F
0 0 .001 r
.54993 .61885 m .54921 .61809 L .55086 .61806 L F
.54993 .61885 m .54885 .61978 L .54921 .61809 L F
.567 .424 .646 r
.55116 .61493 m .55086 .61806 L .54921 .61809 L F
.59 .581 .811 r
.24958 .66199 m .24882 .66575 L .24723 .66492 L F
.24958 .66199 m .25104 .66506 L .24882 .66575 L F
.635 .178 .149 r
.25104 .66506 m .24723 .66492 L .24882 .66575 L F
.772 .277 .04 r
.50938 .78819 m .51224 .78909 L .50965 .7868 L F
.50938 .78819 m .50965 .7868 L .51047 .78621 L F
.457 .18 .403 r
.59987 .58349 m .60224 .58324 L .60244 .58129 L F
.498 .274 .505 r
.60224 .58324 m .60441 .58054 L .60244 .58129 L F
.448 .186 .422 r
.32327 .63198 m .32535 .63143 L .3258 .62935 L F
.445 .183 .421 r
.3258 .62935 m .32743 .63088 L .32789 .62888 L F
.3258 .62935 m .32535 .63143 L .32743 .63088 L F
0 .179 .697 r
.25785 .65444 m .25675 .65084 L .26088 .65125 L F
.586 .382 .571 r
.26088 .65125 m .26044 .65435 L .25785 .65444 L F
.793 .695 .756 r
.26061 .65069 m .26088 .65125 L .26213 .65076 L F
.111 .064 .519 r
.26213 .65076 m .26197 .65344 L .26088 .65125 L F
.793 .695 .756 r
.26061 .65069 m .26197 .65344 L .26088 .65125 L F
.327 .155 .489 r
.26197 .65344 m .26044 .65435 L .26088 .65125 L F
.549 .433 .674 r
.38661 .67997 m .3891 .68221 L .3889 .67926 L F
.38661 .67997 m .38702 .68262 L .3891 .68221 L F
.769 .431 .414 r
.5228 .78312 m .52629 .78326 L .52565 .78126 L F
.929 .941 .785 r
.52494 .77995 m .52565 .78126 L .52758 .77765 L F
.619 .602 .811 r
.31448 .66244 m .31652 .65958 L .31799 .66011 L F
.574 .304 .47 r
.31799 .66011 m .31755 .66221 L .31652 .65958 L F
.31799 .66011 m .31995 .66191 L .31755 .66221 L F
.869 .837 .812 r
.78076 .59477 m .77721 .59647 L .77947 .59502 L F
.642 .134 .025 r
.77947 .59502 m .7796 .59506 L .78076 .59477 L F
.869 .837 .812 r
.78076 .59477 m .7783 .59826 L .77721 .59647 L F
.642 .134 .025 r
.7796 .59506 m .7827 .596 L .78076 .59477 L F
.252 0 0 r
.78076 .59477 m .784 .59329 L .78211 .59444 L F
.78076 .59477 m .78211 .59444 L .78082 .59522 L F
.515 .802 .998 r
.36251 .59182 m .36189 .59314 L .36054 .59171 L F
.36251 .59182 m .36402 .59269 L .36189 .59314 L F
.34 0 .222 r
.634 .48344 m .63341 .48484 L .63624 .48281 L F
.123 .619 .908 r
.48739 .8119 m .48586 .812 L .48456 .81135 L F
.707 .523 .637 r
.48958 .8111 m .48812 .81178 L .48739 .8119 L F
.187 .272 .72 r
.48739 .8119 m .48798 .81424 L .486 .81214 L F
.707 .523 .637 r
.48812 .81178 m .48607 .81273 L .48739 .8119 L F
.187 .272 .72 r
.48739 .8119 m .486 .81214 L .48586 .812 L F
.697 .964 .94 r
.69892 .5321 m .69775 .53387 L .69964 .53256 L F
.693 .959 .946 r
.69679 .53327 m .69775 .53387 L .69892 .5321 L F
.45 .142 .35 r
.50353 .76185 m .50576 .76311 L .50708 .76104 L F
.50353 .76185 m .50353 .76352 L .50576 .76311 L F
.613 .876 .991 r
.6907 .51717 m .6943 .51718 L .69302 .5162 L F
.646 .871 .983 r
.69302 .5162 m .6943 .51718 L .6942 .51544 L F
.028 .317 .804 r
.6942 .51544 m .6943 .51718 L .69611 .51831 L F
.729 .381 .39 r
.48468 .80628 m .48359 .80786 L .48333 .80571 L F
.48468 .80628 m .48706 .80915 L .48359 .80786 L F
.535 .316 .529 r
.58336 .60382 m .5812 .60644 L .581 .60383 L F
0 0 .445 r
.49687 .77543 m .49717 .77499 L .49654 .77212 L F
.923 .751 .651 r
.63752 .53234 m .63951 .53107 L .63834 .53029 L F
.63752 .53234 m .639 .53332 L .63951 .53107 L F
0 .377 .749 r
.56999 .72766 m .56882 .72698 L .56726 .72635 L F
.755 .921 .945 r
.57064 .72581 m .56999 .72766 L .56992 .72567 L F
.57064 .72581 m .56882 .72698 L .56999 .72766 L F
.867 .714 .69 r
.63657 .54093 m .63971 .53892 L .63912 .53831 L F
.63657 .54093 m .63839 .54167 L .63971 .53892 L F
.975 .758 .546 r
.72893 .4979 m .73031 .49688 L .72957 .49591 L F
.72893 .4979 m .7301 .4992 L .73031 .49688 L F
.964 .907 .711 r
.69766 .51336 m .69632 .51885 L .69611 .51831 L F
.168 .699 .85 r
.31541 .64902 m .31605 .6487 L .31229 .64929 L F
.31541 .64902 m .31759 .6489 L .31605 .6487 L F
.432 .786 .997 r
.54964 .75806 m .55309 .75869 L .55195 .7578 L F
.661 .356 .446 r
.55124 .7603 m .55309 .75869 L .54964 .75806 L F
.55124 .7603 m .55312 .76042 L .55309 .75869 L F
.91 .92 .811 r
.55195 .7578 m .55309 .75869 L .55519 .75533 L F
.432 .214 .48 r
.60429 .52235 m .60413 .52449 L .60643 .52163 L F
.755 .921 .945 r
.57064 .72581 m .56992 .72567 L .57217 .72441 L F
.84 .97 .882 r
.67348 .53522 m .67604 .53436 L .67634 .53177 L F
.557 .823 .462 r
.67908 .53068 m .67604 .53436 L .67811 .53182 L F
.567 .539 .784 r
.67685 .53592 m .67811 .53182 L .67604 .53436 L F
.519 .014 0 r
.54536 .62914 m .54397 .62998 L .54203 .62932 L F
.151 .153 .605 r
.54632 .6255 m .54689 .62806 L .54536 .62914 L F
.429 .833 .636 r
.54689 .62806 m .54397 .62998 L .54536 .62914 L F
.462 .307 .584 r
.37702 .69676 m .37603 .70011 L .37843 .69928 L F
.443 .826 .593 r
.45511 .65737 m .45426 .65795 L .45396 .65822 L F
0 0 0 r
.45784 .65499 m .45661 .65683 L .45511 .65737 L F
.15 0 0 r
.45541 .65779 m .45511 .65737 L .45661 .65683 L F
.45541 .65779 m .45426 .65795 L .45511 .65737 L F
.33 0 .049 r
.33457 .64258 m .33403 .64343 L .3311 .6445 L F
.099 0 0 r
.33586 .64263 m .33403 .64343 L .33457 .64258 L F
.643 .77 .94 r
.66849 .52408 m .67201 .52471 L .67101 .52315 L F
.79 .8 .861 r
.67101 .52315 m .67201 .52471 L .67494 .52225 L F
.656 .441 .58 r
.57225 .71064 m .57205 .71329 L .56926 .71251 L F
0 0 .016 r
.57352 .70677 m .57307 .70938 L .57225 .71064 L F
0 0 .352 r
.57307 .70938 m .57205 .71329 L .57225 .71064 L F
.18 0 .152 r
.60199 .52524 m .59942 .52772 L .60135 .52674 L F
.33 0 .238 r
.60135 .52674 m .60413 .52449 L .60199 .52524 L F
.129 .391 .844 r
.54774 .77742 m .54901 .77938 L .55089 .7797 L F
.493 .34 .602 r
.38905 .6656 m .3911 .66231 L .38882 .66272 L F
.094 0 0 r
.31369 .63388 m .31576 .6335 L .31748 .63243 L F
0 0 0 r
.31748 .63243 m .3179 .63287 L .31978 .63246 L F
.31748 .63243 m .31576 .6335 L .3179 .63287 L F
.565 .666 .905 r
.26126 .64303 m .26143 .63962 L .25934 .64006 L F
.592 .642 .869 r
.27484 .64233 m .27622 .64525 L .27777 .64361 L F
.453 .149 .359 r
.35725 .62609 m .35655 .62849 L .35434 .6289 L F
.387 .089 .333 r
.35859 .62788 m .35725 .62609 L .35923 .62544 L F
.35859 .62788 m .35655 .62849 L .35725 .62609 L F
.405 .054 .252 r
.74068 .58423 m .74335 .58369 L .74296 .58285 L F
.74068 .58423 m .74335 .58369 L .74296 .58285 L F
0 0 .575 r
.59177 .72182 m .59524 .72311 L .59415 .72169 L F
.836 .665 .671 r
.59524 .72311 m .59404 .71885 L .59415 .72169 L F
0 0 0 r
.46904 .65002 m .47077 .64994 L .46974 .64819 L F
.466 .699 .969 r
.47077 .64994 m .4716 .64818 L .46974 .64819 L F
.47077 .64994 m .47343 .65024 L .4716 .64818 L F
.902 .647 .542 r
.47249 .80793 m .47362 .80712 L .47221 .80687 L F
.945 .76 .621 r
.4721 .80572 m .47362 .80712 L .47249 .80793 L F
.474 .62 .913 r
.78702 .59239 m .78681 .59382 L .78606 .59201 L F
.78702 .59239 m .78887 .59411 L .78681 .59382 L F
.795 .661 .715 r
.58741 .58121 m .58797 .57885 L .58593 .57811 L F
.49 .342 .606 r
.52767 .6733 m .52567 .67422 L .52542 .67134 L F
.52767 .6733 m .52567 .67422 L .52542 .67134 L F
.798 .752 .81 r
.58987 .69679 m .59054 .69969 L .58736 .69934 L F
0 0 .467 r
.58987 .69679 m .5907 .69892 L .59054 .69969 L F
.599 .06 0 r
.59141 .70085 m .59054 .69969 L .5907 .69892 L F
.949 .596 .289 r
.58958 .69789 m .59016 .70021 L .59141 .70085 L F
.623 .06 0 r
.59016 .70021 m .59066 .70045 L .59141 .70085 L F
.599 .06 0 r
.59141 .70085 m .59225 .70131 L .59054 .69969 L F
.059 .62 .79 r
.5926 .70164 m .59458 .70167 L .59624 .70183 L F
.599 .06 0 r
.59141 .70085 m .5926 .70164 L .59225 .70131 L F
.509 0 0 r
.59141 .70085 m .59458 .70167 L .5926 .70164 L F
.59141 .70085 m .59415 .70221 L .59458 .70167 L F
.623 .06 0 r
.59066 .70045 m .59415 .70221 L .59141 .70085 L F
.279 .288 .691 r
.52281 .77822 m .52494 .77995 L .52392 .77809 L F
.661 .448 .585 r
.74273 .49191 m .74383 .49391 L .741 .49289 L F
.042 0 0 r
.3401 .60102 m .34027 .6011 L .33805 .60163 L F
.3401 .60102 m .34207 .60106 L .34027 .6011 L F
.46 .807 .998 r
.32863 .60211 m .32972 .60098 L .32706 .60128 L F
.32863 .60211 m .33083 .60179 L .32972 .60098 L F
.983 .702 .338 r
.65276 .49378 m .65295 .49602 L .65367 .49653 L F
0 0 .087 r
.65405 .4971 m .65367 .49653 L .65295 .49602 L F
.522 0 0 r
.6534 .50118 m .65371 .50126 L .65301 .50026 L F
0 0 .087 r
.65358 .49979 m .6534 .5008 L .65351 .49905 L F
.65405 .4971 m .65358 .49979 L .65367 .49653 L F
.65358 .49979 m .65351 .49905 L .65367 .49653 L F
0 .486 .838 r
.65301 .50026 m .6534 .5008 L .65405 .4971 L F
.65301 .50026 m .65692 .50215 L .6534 .5008 L F
.522 0 0 r
.65371 .50126 m .65692 .50215 L .65364 .50057 L F
.65371 .50126 m .65364 .50057 L .65301 .50026 L F
.093 .561 .908 r
.59694 .71541 m .59609 .71292 L .59529 .71421 L F
.807 .829 .867 r
.50391 .81667 m .50679 .81461 L .50338 .81469 L F
.97 .725 .297 r
.66452 .4926 m .66525 .49137 L .66578 .48947 L F
.66452 .4926 m .66521 .4937 L .66525 .49137 L F
.766 .859 .919 r
.67427 .48073 m .67722 .48036 L .67615 .47978 L F
.669 .264 .268 r
.67935 .48042 m .67722 .48036 L .67961 .47954 L F
.67935 .48042 m .67615 .47978 L .67722 .48036 L F
.565 .582 .829 r
.50679 .81461 m .50909 .81531 L .5096 .81439 L F
.769 .658 .74 r
.73869 .49398 m .73963 .49735 L .73819 .49628 L F
.848 .841 .838 r
.73963 .49735 m .73631 .49908 L .73819 .49628 L F
.678 .605 .766 r
.74202 .4967 m .73963 .49735 L .73869 .49398 L F
.393 0 0 r
.50576 .76311 m .50931 .76151 L .50708 .76104 L F
.62 .421 .59 r
.52699 .78662 m .52699 .78914 L .52471 .78944 L F
.739 .409 .424 r
.52699 .78662 m .53054 .78835 L .52699 .78914 L F
.951 .919 .744 r
.52334 .65824 m .52515 .6572 L .52411 .65649 L F
.52334 .65824 m .52368 .6604 L .52515 .6572 L F
.968 .899 .7 r
.52576 .65308 m .52411 .65649 L .52515 .6572 L F
.493 .825 .999 r
.33831 .58867 m .33764 .58986 L .33618 .58913 L F
.33831 .58867 m .33977 .58941 L .33764 .58986 L F
.718 .736 .866 r
.49276 .64349 m .49633 .64412 L .49512 .64253 L F
.035 .577 .845 r
.49854 .64328 m .49512 .64253 L .49633 .64412 L F
.439 .014 .133 r
.41784 .6537 m .42012 .65354 L .42147 .65171 L F
.472 .048 .153 r
.42147 .65171 m .42347 .65266 L .42377 .6515 L F
.42147 .65171 m .42012 .65354 L .42347 .65266 L F
.439 .215 .476 r
.60441 .58054 m .60639 .57774 L .60466 .57834 L F
.796 .709 .769 r
.65034 .50986 m .64765 .51012 L .64782 .50943 L F
.457 .189 .418 r
.64905 .51128 m .64765 .51012 L .65034 .50986 L F
0 0 0 r
.65262 .50701 m .65034 .50986 L .6532 .50741 L F
.65262 .50701 m .65067 .50983 L .65034 .50986 L F
.65067 .50983 m .64905 .51128 L .65034 .50986 L F
.124 .369 .828 r
.72652 .48268 m .72899 .48427 L .72826 .48552 L F
0 .113 .649 r
.72991 .48614 m .72826 .48552 L .72899 .48427 L F
.929 .854 .747 r
.52137 .66116 m .52368 .6604 L .52334 .65824 L F
.52137 .66116 m .5224 .66231 L .52368 .6604 L F
.976 .825 .417 r
.62446 .53857 m .62423 .53541 L .62561 .53665 L F
.758 .709 .805 r
.50517 .79489 m .50366 .79719 L .50166 .79458 L F
.607 .502 .708 r
.50517 .79489 m .50467 .79733 L .50366 .79719 L F
.536 .739 .969 r
.29852 .62951 m .29664 .62997 L .29517 .62867 L F
.859 .731 .721 r
.49302 .792 m .49528 .78837 L .49147 .78829 L F
.735 .765 .877 r
.49342 .78586 m .49528 .78837 L .49697 .78615 L F
.477 .611 .905 r
.49528 .78837 m .49732 .78826 L .49697 .78615 L F
.516 .337 .578 r
.29032 .61711 m .28779 .62104 L .28827 .6182 L F
.311 .025 .307 r
.61248 .53374 m .61214 .53557 L .61015 .53619 L F
.462 .152 .353 r
.61489 .53473 m .61248 .53374 L .61455 .53359 L F
.61489 .53473 m .61214 .53557 L .61248 .53374 L F
.994 .773 .407 r
.65838 .49975 m .65753 .49872 L .65766 .4964 L F
.999 .813 .479 r
.65838 .49975 m .65728 .50112 L .65753 .49872 L F
.544 .27 .451 r
.57867 .60891 m .57529 .61191 L .57628 .60909 L F
0 0 .148 r
.70944 .47624 m .70845 .47838 L .70763 .47874 L F
.273 .776 .771 r
.70876 .47856 m .70763 .47874 L .70664 .47918 L F
.699 .78 .914 r
.70876 .47856 m .71195 .47885 L .71081 .4787 L F
.157 0 0 r
.70876 .47856 m .71081 .4787 L .70763 .47874 L F
.345 .801 .944 r
.71081 .4787 m .7104 .47813 L .70763 .47874 L F
0 0 .148 r
.70845 .47838 m .70767 .48005 L .70763 .47874 L F
.273 .776 .771 r
.70664 .47918 m .70763 .47874 L .70619 .47931 L F
0 0 0 r
.70763 .47874 m .70474 .48097 L .70619 .47931 L F
.795 .661 .715 r
.58741 .58121 m .58593 .57811 L .58439 .58072 L F
.852 .647 .624 r
.58713 .58371 m .58741 .58121 L .58439 .58072 L F
.826 .621 .626 r
.58713 .58371 m .58878 .58421 L .58741 .58121 L F
.703 .572 .705 r
.58741 .58121 m .58878 .58421 L .5911 .58395 L F
.09 0 .361 r
.5413 .77251 m .5411 .77551 L .53869 .77413 L F
.276 .127 .491 r
.54299 .77443 m .5413 .77251 L .54373 .77154 L F
.729 .567 .672 r
.55467 .61778 m .55116 .61493 L .55276 .61471 L F
.792 .571 .601 r
.53008 .76598 m .53406 .76407 L .53119 .76383 L F
.637 .578 .772 r
.5467 .79764 m .54462 .79873 L .54321 .79485 L F
.517 .323 .557 r
.54444 .80048 m .54462 .79873 L .5467 .79764 L F
.817 .597 .606 r
.62537 .53044 m .62438 .53293 L .62438 .53056 L F
.835 .724 .742 r
.66383 .51832 m .66544 .52181 L .66509 .51941 L F
.571 .488 .721 r
.66544 .52181 m .66743 .51891 L .66509 .51941 L F
.324 .714 .981 r
.67136 .53628 m .6677 .53531 L .66878 .53629 L F
.678 .264 0 r
.59624 .70183 m .59758 .70429 L .59832 .70535 L F
.815 .732 .205 r
.59792 .70647 m .59832 .70535 L .59758 .70429 L F
.59792 .70647 m .59797 .7077 L .59832 .70535 L F
.448 .635 .935 r
.52435 .79702 m .52658 .79784 L .52516 .79553 L F
.751 .34 .271 r
.46679 .68774 m .46893 .69003 L .47013 .68839 L F
.707 .284 .241 r
.46893 .69003 m .47244 .69053 L .47013 .68839 L F
0 0 .3 r
.60674 .51952 m .60643 .52163 L .60799 .51828 L F
.279 .767 .689 r
.24684 .65724 m .24843 .6566 L .24613 .65749 L F
0 0 0 r
.55686 .78896 m .55958 .78669 L .55821 .78882 L F
0 .095 .579 r
.55584 .72405 m .5559 .724 L .55355 .72203 L F
0 .074 .567 r
.55584 .72405 m .55738 .72544 L .5559 .724 L F
.827 .355 .063 r
.66617 .49674 m .6656 .49712 L .66335 .49541 L F
.97 .722 .505 r
.6637 .49485 m .66461 .49589 L .66521 .4937 L F
.66367 .49487 m .66412 .49536 L .6637 .49485 L F
.66412 .49536 m .66461 .49589 L .6637 .49485 L F
.66459 .49594 m .66552 .49639 L .66534 .49485 L F
.66467 .49567 m .66534 .49485 L .66521 .4937 L F
.66459 .49594 m .66534 .49485 L .66467 .49567 L F
0 .243 .655 r
.66461 .49595 m .66617 .49674 L .66335 .49541 L F
.66552 .49639 m .66617 .49674 L .66461 .49595 L F
.97 .722 .505 r
.66459 .49594 m .6656 .49712 L .66552 .49639 L F
.986 .729 .347 r
.66552 .49639 m .6656 .49712 L .66617 .49674 L F
0 .243 .655 r
.66606 .49657 m .66892 .4983 L .66617 .49674 L F
.342 .596 .94 r
.66412 .49536 m .66461 .49595 L .66335 .49541 L F
.66412 .49536 m .66335 .49541 L .66367 .49487 L F
.315 .588 .941 r
.66335 .49541 m .6656 .49712 L .66367 .49487 L F
.098 .526 .909 r
.66783 .49718 m .66892 .4983 L .66606 .49657 L F
0 .243 .655 r
.66503 .49613 m .66552 .49639 L .66461 .49595 L F
.986 .729 .347 r
.66521 .4937 m .66552 .49639 L .66617 .49674 L F
0 .243 .655 r
.66606 .49657 m .66617 .49674 L .66503 .49613 L F
.707 .55 .673 r
.66335 .49541 m .66868 .50086 L .66783 .49718 L F
.66335 .49541 m .66527 .50134 L .66868 .50086 L F
.084 .119 .6 r
.66573 .49859 m .66414 .4964 L .66783 .49718 L F
.66408 .49638 m .66451 .49587 L .66783 .49718 L F
.234 .551 .931 r
.66689 .4958 m .66783 .49718 L .66632 .49666 L F
.66689 .4958 m .66632 .49666 L .66606 .49657 L F
0 0 0 r
.66757 .49474 m .6675 .49488 L .66689 .4958 L F
.962 .853 .687 r
.66699 .49595 m .66573 .49859 L .66783 .49718 L F
0 0 0 r
.6675 .49488 m .66573 .49859 L .66689 .4958 L F
.989 .861 .502 r
.66767 .50208 m .66811 .50387 L .66827 .50302 L F
.66767 .50208 m .66827 .50302 L .66868 .50086 L F
.505 .021 .042 r
.66497 .50164 m .66868 .50086 L .66527 .50134 L F
.66497 .50164 m .66767 .50208 L .66868 .50086 L F
0 0 .381 r
.66706 .50112 m .66767 .50208 L .66686 .50092 L F
.6688 .50286 m .66767 .50208 L .66706 .50112 L F
.842 .804 .314 r
.6671 .49847 m .66693 .50024 L .66679 .49745 L F
.66693 .50024 m .66686 .50092 L .66573 .49859 L F
.6669 .50053 m .66677 .49923 L .66686 .50092 L F
.66725 .49695 m .66677 .49923 L .6669 .50053 L F
.66679 .49745 m .66693 .50024 L .66573 .49859 L F
.66725 .49695 m .6671 .49847 L .66679 .49745 L F
.983 .901 .575 r
.66665 .49872 m .66677 .49923 L .66682 .499 L F
.66665 .49872 m .66682 .499 L .66725 .49695 L F
0 0 0 r
.66757 .49474 m .66725 .49695 L .66685 .49738 L F
.66711 .4957 m .66685 .49738 L .66573 .49859 L F
.66757 .49474 m .66685 .49738 L .66711 .4957 L F
.084 .119 .6 r
.66573 .49859 m .66408 .49638 L .66414 .4964 L F
.617 .499 .697 r
.66268 .50087 m .66527 .50134 L .66335 .49541 L F
.326 .24 .602 r
.66512 .49921 m .66268 .50087 L .66335 .49541 L F
.084 .119 .6 r
.66573 .49859 m .66512 .49921 L .66335 .49541 L F
.328 .734 .98 r
.66314 .49798 m .66664 .49872 L .66429 .49654 L F
.66664 .49872 m .66665 .49872 L .66664 .49871 L F
.66664 .49872 m .66664 .49871 L .66429 .49654 L F
.983 .901 .575 r
.66665 .49872 m .66725 .49695 L .66429 .49654 L F
.606 .878 .992 r
.66665 .49872 m .66559 .49795 L .66605 .49778 L F
.66665 .49872 m .66605 .49778 L .66784 .49713 L F
0 0 .402 r
.66665 .49872 m .66676 .49903 L .66677 .49923 L F
.971 .659 .296 r
.66677 .49923 m .6688 .50286 L .66686 .50092 L F
.66677 .49923 m .66776 .50188 L .66828 .50237 L F
0 0 .402 r
.66676 .49903 m .66776 .50188 L .66677 .49923 L F
.971 .659 .296 r
.66799 .5014 m .66828 .50237 L .6688 .50286 L F
.66677 .49923 m .66828 .50237 L .66799 .5014 L F
.084 .119 .6 r
.66408 .49638 m .66335 .49541 L .66451 .49587 L F
.342 .596 .94 r
.66541 .49526 m .66606 .49657 L .66461 .49595 L F
.66541 .49526 m .66461 .49595 L .66412 .49536 L F
.66541 .49526 m .66412 .49536 L .66367 .49487 L F
.97 .722 .505 r
.66367 .49487 m .66459 .49594 L .66461 .49589 L F
.561 .501 .745 r
.7424 .59176 m .74345 .58782 L .74144 .58916 L F
.7424 .59176 m .74463 .59118 L .74345 .58782 L F
.36 0 0 r
.57796 .72551 m .57674 .7259 L .57448 .7253 L F
0 .425 .851 r
.57796 .72551 m .57917 .72538 L .57674 .7259 L F
.57796 .72551 m .58017 .72636 L .57917 .72538 L F
.645 .798 .956 r
.49854 .64328 m .50175 .64354 L .50065 .6425 L F
.639 .768 .941 r
.50065 .6425 m .50175 .64354 L .50413 .64299 L F
.239 .649 .96 r
.50182 .81375 m .50107 .81452 L .50338 .81469 L F
.50182 .81375 m .50107 .81452 L .50338 .81469 L F
.652 .616 .801 r
.50472 .64641 m .50529 .64836 L .50751 .64591 L F
.547 .227 .378 r
.59925 .58592 m .597 .58453 L .59676 .58592 L F
.59925 .58592 m .59987 .58349 L .597 .58453 L F
.307 .776 .658 r
.46049 .65298 m .45895 .6537 L .46024 .65358 L F
.021 0 .033 r
.46756 .65122 m .46666 .65224 L .46577 .65244 L F
.239 .756 .821 r
.46666 .65224 m .46049 .65298 L .46024 .65358 L F
.568 .528 .771 r
.41589 .68471 m .41509 .68901 L .41426 .68492 L F
.559 .539 .789 r
.25279 .61765 m .25368 .61375 L .25157 .61459 L F
.25279 .61765 m .25521 .61767 L .25368 .61375 L F
.076 0 .014 r
.693 .51317 m .69083 .51467 L .69038 .51587 L F
.998 .787 .477 r
.65741 .51089 m .65672 .50706 L .65729 .50811 L F
.505 .828 1 r
.30808 .63168 m .31017 .63121 L .31183 .6319 L F
0 .123 .672 r
.31221 .63139 m .31183 .6319 L .31017 .63121 L F
.31221 .63139 m .31369 .63388 L .31183 .6319 L F
.875 .691 .65 r
.58694 .58631 m .58878 .58421 L .58713 .58371 L F
.58694 .58631 m .58879 .58679 L .58878 .58421 L F
.699 .547 .677 r
.58878 .58421 m .58879 .58679 L .5911 .58395 L F
.937 .887 .756 r
.55825 .58362 m .55543 .58589 L .55762 .58298 L F
.55825 .58362 m .55655 .58676 L .55543 .58589 L F
.979 .893 .543 r
.55825 .58362 m .55762 .58298 L .55821 .58059 L F
.978 .732 .321 r
.56827 .75544 m .56832 .75762 L .56905 .75819 L F
.982 .696 .379 r
.56826 .7601 m .56905 .75819 L .56832 .75762 L F
.56826 .7601 m .56907 .76157 L .56905 .75819 L F
.398 .133 .391 r
.25577 .59708 m .25835 .59461 L .25652 .59496 L F
0 .173 .703 r
.49061 .80924 m .49161 .81194 L .49282 .81161 L F
.509 .475 .755 r
.39638 .7018 m .39902 .70106 L .39602 .69985 L F
.622 .581 .788 r
.39774 .7048 m .39902 .70106 L .39638 .7018 L F
.556 .235 .379 r
.43329 .66592 m .43291 .66754 L .43104 .66764 L F
.503 .186 .363 r
.43329 .66592 m .43509 .66724 L .43291 .66754 L F
.5 .188 .368 r
.4358 .6656 m .43509 .66724 L .43329 .66592 L F
.47 .271 .528 r
.38136 .60595 m .37932 .60676 L .38159 .60374 L F
.341 .029 .282 r
.3794 .6071 m .37932 .60676 L .38136 .60595 L F
.143 0 .413 r
.60932 .57283 m .61117 .5717 L .61129 .56933 L F
.126 0 .354 r
.60885 .57484 m .61117 .5717 L .60932 .57283 L F
.616 .371 .524 r
.59925 .58592 m .60224 .58324 L .59987 .58349 L F
0 0 .495 r
.55238 .62066 m .55086 .61806 L .55467 .61778 L F
.55238 .62066 m .55205 .61978 L .55086 .61806 L F
.604 .447 .643 r
.55467 .61778 m .55476 .62051 L .55238 .62066 L F
.771 .318 .172 r
.55476 .62051 m .55205 .61978 L .55238 .62066 L F
.897 .584 .446 r
.514 .77741 m .51672 .78033 L .51655 .77817 L F
.8 .586 .612 r
.27939 .65094 m .28319 .65143 L .28304 .64875 L F
0 .178 .706 r
.28304 .64875 m .28347 .64766 L .28174 .6457 L F
.472 .334 .612 r
.28304 .64875 m .28507 .65075 L .28347 .64766 L F
.28304 .64875 m .28319 .65143 L .28507 .65075 L F
.563 .304 .481 r
.56707 .61388 m .565 .61217 L .5669 .61225 L F
.56707 .61388 m .56492 .61433 L .565 .61217 L F
.582 .834 .993 r
.28933 .85193 m .28993 .85045 L .28877 .85115 L F
.28933 .85193 m .29177 .85134 L .28993 .85045 L F
.811 .662 .698 r
.53841 .6094 m .53572 .60952 L .53688 .60852 L F
.736 .519 .599 r
.53841 .6094 m .53485 .6115 L .53572 .60952 L F
.53841 .6094 m .53844 .61182 L .53485 .6115 L F
.67 .713 .881 r
.54088 .60932 m .53841 .6094 L .53688 .60852 L F
.71 .498 .6 r
.54098 .61181 m .53841 .6094 L .54088 .60932 L F
.54098 .61181 m .53844 .61182 L .53841 .6094 L F
.989 .754 .372 r
.65711 .49392 m .65634 .49298 L .65634 .49058 L F
.982 .695 .378 r
.65766 .4964 m .65634 .49298 L .65711 .49392 L F
.503 .848 .577 r
.55442 .77155 m .55337 .77255 L .55517 .7709 L F
0 0 .354 r
.55439 .77406 m .55337 .77255 L .55442 .77155 L F
.55439 .77406 m .5534 .77499 L .55337 .77255 L F
.784 .588 .634 r
.49342 .78586 m .49711 .78365 L .4948 .78302 L F
.558 .501 .748 r
.73721 .51601 m .73539 .51938 L .73439 .51838 L F
.323 .526 .898 r
.73539 .51938 m .73692 .51806 L .73439 .51838 L F
.73539 .51938 m .73746 .5196 L .73692 .51806 L F
.639 .462 .627 r
.58879 .58679 m .59146 .58683 L .5911 .58395 L F
.599 .263 .372 r
.74892 .58291 m .75186 .58289 L .74894 .58118 L F
.598 .264 .376 r
.74894 .58118 m .75186 .58289 L .75172 .58135 L F
.303 .153 .505 r
.25829 .63974 m .25953 .63696 L .25736 .63799 L F
.405 0 0 r
.44412 .70294 m .44274 .70434 L .44041 .70434 L F
.34 0 0 r
.44609 .7032 m .44274 .70434 L .44412 .70294 L F
.983 .822 .606 r
.64059 .52211 m .64189 .52209 L .64083 .521 L F
.64059 .52211 m .64155 .52325 L .64189 .52209 L F
.547 .544 .803 r
.50947 .65132 m .51052 .64751 L .50839 .64937 L F
.50947 .65132 m .5116 .65094 L .51052 .64751 L F
.401 .477 .823 r
.50947 .65132 m .51239 .65415 L .5116 .65094 L F
.513 .228 .418 r
.57837 .69244 m .58295 .69051 L .57958 .69097 L F
.57837 .69244 m .58179 .69286 L .58295 .69051 L F
.515 .313 .544 r
.57942 .69582 m .58179 .69286 L .57837 .69244 L F
.765 .705 .795 r
.54659 .60698 m .54619 .60873 L .54435 .60957 L F
.599 .936 .949 r
.48706 .80915 m .488 .80939 L .48906 .80815 L F
.48706 .80915 m .488 .80939 L .48906 .80815 L F
.474 .158 .349 r
.48739 .8119 m .488 .80939 L .49061 .80924 L F
.263 0 0 r
.54508 .78261 m .5439 .78283 L .545 .78364 L F
.332 .11 .419 r
.54582 .78583 m .54508 .78261 L .545 .78364 L F
.575 .255 .388 r
.43903 .6954 m .44138 .69559 L .43938 .6939 L F
.558 .261 .419 r
.43938 .6939 m .44138 .69559 L .44178 .69377 L F
.438 .653 .95 r
.74738 .49766 m .74579 .49929 L .74486 .49606 L F
.74738 .49766 m .74775 .49909 L .74579 .49929 L F
.081 .183 .671 r
.74754 .50114 m .74579 .49929 L .74775 .49909 L F
.825 .75 .781 r
.25833 .65083 m .26061 .65069 L .25941 .65003 L F
0 .179 .697 r
.25756 .65347 m .2579 .65228 L .25675 .65084 L F
.25785 .65444 m .25857 .65312 L .2579 .65228 L F
.25785 .65444 m .2579 .65228 L .25756 .65347 L F
.794 .302 .022 r
.25675 .65084 m .25857 .65312 L .25662 .65208 L F
.825 .75 .781 r
.25662 .65208 m .25811 .65156 L .25833 .65083 L F
.25811 .65156 m .26061 .65069 L .25833 .65083 L F
.508 .13 .259 r
.26044 .65435 m .25929 .65598 L .25785 .65444 L F
0 .067 .61 r
.25785 .65444 m .25929 .65598 L .25857 .65312 L F
.535 .171 .296 r
.59606 .5298 m .59879 .52968 L .59942 .52772 L F
.368 .018 .234 r
.59942 .52772 m .60101 .52906 L .60135 .52674 L F
.59942 .52772 m .59879 .52968 L .60101 .52906 L F
.494 .33 .587 r
.41669 .67612 m .41465 .67411 L .41698 .67374 L F
.41669 .67612 m .41462 .67668 L .41465 .67411 L F
.57 .507 .745 r
.38762 .68511 m .3891 .68221 L .38702 .68262 L F
.38762 .68511 m .39 .6847 L .3891 .68221 L F
.678 .852 .966 r
.52032 .81032 m .52259 .80919 L .52006 .80949 L F
.974 .86 .664 r
.58843 .57267 m .58799 .56986 L .5867 .57179 L F
.58843 .57267 m .58874 .57023 L .58799 .56986 L F
.663 .488 .637 r
.61042 .59508 m .60778 .59728 L .60819 .59496 L F
.672 .372 .457 r
.60819 .59496 m .60778 .59728 L .60514 .59728 L F
.564 .493 .734 r
.74068 .58423 m .74354 .58583 L .74335 .58369 L F
.805 .793 .842 r
.54182 .78884 m .53849 .78644 L .54164 .78662 L F
0 0 .504 r
.54313 .78842 m .54164 .78662 L .54255 .78639 L F
.54313 .78842 m .54182 .78884 L .54164 .78662 L F
.426 .809 .99 r
.52006 .80949 m .52259 .80919 L .5213 .80859 L F
.52006 .80949 m .52259 .80919 L .5213 .80859 L F
.549 .177 .287 r
.49147 .78829 m .48885 .78711 L .48804 .78912 L F
.426 .752 .995 r
.34349 .58925 m .34325 .59043 L .34172 .58925 L F
.34349 .58925 m .34552 .59025 L .34325 .59043 L F
.746 .848 .927 r
.67015 .47642 m .66689 .47656 L .66921 .47538 L F
.615 .844 .987 r
.67282 .47554 m .67015 .47642 L .66921 .47538 L F
.678 .605 .766 r
.74202 .4967 m .73869 .49398 L .741 .49289 L F
.623 .513 .708 r
.74383 .49391 m .74202 .4967 L .741 .49289 L F
.344 0 0 r
.27137 .58807 m .27352 .5881 L .27537 .58702 L F
.221 0 0 r
.27352 .5881 m .27758 .58674 L .27537 .58702 L F
.551 .457 .701 r
.50651 .80032 m .50683 .80369 L .50544 .80405 L F
.55 .256 .421 r
.50683 .80369 m .50406 .80584 L .50544 .80405 L F
0 0 .127 r
.47593 .81213 m .47625 .81391 L .47621 .81364 L F
.47625 .81391 m .47639 .81468 L .47621 .81364 L F
.464 0 0 r
.47639 .81468 m .4792 .81557 L .47745 .81582 L F
0 0 .393 r
.47613 .81314 m .47621 .81364 L .47735 .81565 L F
.884 .918 .843 r
.47636 .81351 m .47669 .81444 L .4748 .81444 L F
.749 .661 .763 r
.47607 .81302 m .47669 .81444 L .47832 .81234 L F
.884 .918 .843 r
.47832 .81234 m .47675 .81435 L .47636 .81351 L F
.47675 .81435 m .47669 .81444 L .47636 .81351 L F
0 0 .393 r
.47716 .81523 m .47735 .81565 L .47745 .81582 L F
.47613 .81314 m .47735 .81565 L .47716 .81523 L F
0 0 .127 r
.47593 .81213 m .47621 .81364 L .47311 .81099 L F
0 0 .393 r
.47607 .81302 m .47621 .81364 L .47613 .81314 L F
0 0 0 r
.65945 .48318 m .6591 .48353 L .65944 .4832 L F
.235 0 0 r
.65967 .48269 m .65945 .48318 L .65997 .48271 L F
.833 .817 .835 r
.65945 .48318 m .66285 .4848 L .6612 .48374 L F
.65945 .48318 m .66177 .48589 L .66285 .4848 L F
.65945 .48318 m .65916 .48598 L .66177 .48589 L F
.932 .9 .771 r
.65847 .48468 m .65916 .48598 L .65945 .48318 L F
.65847 .48468 m .65945 .48318 L .66023 .48242 L F
0 0 0 r
.65945 .48318 m .65944 .4832 L .66023 .48242 L F
.235 0 0 r
.65651 .48241 m .65945 .48318 L .65967 .48269 L F
.513 0 0 r
.65997 .48271 m .6612 .48374 L .66248 .48262 L F
.65997 .48271 m .65945 .48318 L .6612 .48374 L F
.586 .404 .602 r
.65997 .48271 m .66248 .48262 L .66259 .47989 L F
.996 .835 .565 r
.65629 .51676 m .65515 .51756 L .65485 .51568 L F
.65629 .51676 m .65582 .51963 L .65515 .51756 L F
.073 0 .17 r
.54147 .73558 m .54378 .73321 L .54187 .73353 L F
.486 .233 .455 r
.56708 .70206 m .56943 .70162 L .56955 .69936 L F
.591 .318 .472 r
.56955 .69936 m .57178 .70129 L .57193 .69905 L F
.56955 .69936 m .56943 .70162 L .57178 .70129 L F
.434 .233 .507 r
.4733 .79535 m .47116 .79826 L .47242 .79688 L F
.083 0 .388 r
.47116 .79826 m .47106 .80038 L .47242 .79688 L F
.575 .127 .15 r
.48985 .69591 m .48904 .69669 L .48652 .69618 L F
.401 0 .02 r
.49214 .69571 m .48904 .69669 L .48985 .69591 L F
.568 .528 .771 r
.41589 .68471 m .41681 .68821 L .41509 .68901 L F
.536 .45 .705 r
.41681 .68821 m .41745 .69022 L .41509 .68901 L F
.357 .118 .408 r
.61468 .50272 m .61441 .50467 L .61669 .50187 L F
.36 0 .155 r
.44468 .6931 m .44683 .69273 L .44758 .6913 L F
.704 .327 .333 r
.44758 .6913 m .44683 .69273 L .45037 .69269 L F
.89 .599 .489 r
.26046 .64832 m .26242 .64903 L .26216 .64944 L F
.604 .822 .984 r
.26488 .6482 m .26242 .64903 L .26046 .64832 L F
.825 .706 .732 r
.26488 .6482 m .26213 .65076 L .26242 .64903 L F
.298 .628 .962 r
.31421 .58475 m .313 .58551 L .31187 .58504 L F
.31421 .58475 m .31552 .58609 L .313 .58551 L F
.153 0 0 r
.32097 .64836 m .3199 .64878 L .31759 .6489 L F
0 0 0 r
.32195 .64824 m .32097 .64836 L .32307 .64783 L F
.32195 .64824 m .3199 .64878 L .32097 .64836 L F
.573 .82 .992 r
.34978 .7464 m .35183 .74748 L .35089 .74649 L F
.173 .578 .937 r
.35183 .74748 m .35233 .74711 L .35089 .74649 L F
.741 .551 .636 r
.35233 .74711 m .3534 .74933 L .35117 .7468 L F
.35233 .74711 m .35117 .7468 L .35089 .74649 L F
.224 .66 .955 r
.34987 .74645 m .35233 .74711 L .35183 .74748 L F
.741 .551 .636 r
.35233 .74711 m .3534 .74933 L .35089 .74649 L F
.224 .66 .955 r
.34978 .7464 m .35233 .74711 L .34987 .74645 L F
.649 .806 .958 r
.6277 .52175 m .62667 .5224 L .62489 .52237 L F
.559 .556 .807 r
.74903 .59544 m .75046 .59186 L .74793 .59224 L F
.74903 .59544 m .75134 .59505 L .75046 .59186 L F
.389 .203 .504 r
.38327 .60533 m .38159 .60374 L .38311 .60305 L F
.38327 .60533 m .38136 .60595 L .38159 .60374 L F
.271 0 0 r
.43817 .70452 m .43442 .70625 L .43594 .70477 L F
.301 .417 .813 r
.68562 .48149 m .68626 .48291 L .68528 .47979 L F
0 0 .262 r
.68626 .48291 m .68769 .47905 L .68528 .47979 L F
.68626 .48291 m .68706 .4822 L .68769 .47905 L F
.442 .874 .913 r
.45396 .65822 m .45002 .65853 L .44871 .6595 L F
.017 0 0 r
.45426 .65795 m .45002 .65853 L .45396 .65822 L F
.674 .37 .451 r
.5096 .81439 m .51266 .81464 L .51197 .81388 L F
.543 .367 .593 r
.51197 .81388 m .51266 .81464 L .51464 .8122 L F
.452 .243 .504 r
.36177 .62056 m .36151 .62301 L .35949 .62342 L F
.529 .346 .577 r
.36151 .62301 m .35923 .62544 L .35949 .62342 L F
0 0 0 r
.65419 .48239 m .65569 .48258 L .65651 .48241 L F
.65419 .48239 m .65319 .48413 L .65569 .48258 L F
.408 .54 .877 r
.48456 .81135 m .48309 .81177 L .48108 .80852 L F
.413 .254 .554 r
.61214 .53557 m .61193 .53765 L .61015 .53619 L F
.419 .253 .548 r
.61193 .53765 m .60983 .53871 L .61015 .53619 L F
.91 .92 .811 r
.55195 .7578 m .55519 .75533 L .55311 .75665 L F
0 .087 .635 r
.55519 .75533 m .55714 .75741 L .55609 .75576 L F
.55714 .75741 m .55732 .7576 L .55609 .75576 L F
.701 .742 .883 r
.5551 .75422 m .55609 .75576 L .5555 .75373 L F
0 .087 .635 r
.55519 .75533 m .55609 .75576 L .55311 .75665 L F
.701 .742 .883 r
.55311 .75665 m .55609 .75576 L .5551 .75422 L F
.871 .81 .787 r
.72421 .48327 m .72424 .48416 L .72136 .4848 L F
.871 .803 .78 r
.72136 .4848 m .72424 .48416 L .72283 .48622 L F
0 0 0 r
.45803 .65551 m .45784 .65499 L .45895 .6537 L F
.45803 .65551 m .45661 .65683 L .45784 .65499 L F
.568 .167 .243 r
.41316 .65371 m .4126 .65446 L .41556 .65395 L F
.293 0 0 r
.50931 .76151 m .51375 .76226 L .51235 .76164 L F
.621 .261 .337 r
.58593 .69421 m .58359 .69533 L .58353 .69353 L F
.727 .757 .25 r
.73456 .5075 m .73475 .5066 L .73523 .50527 L F
.951 .71 .251 r
.73523 .50527 m .73475 .5066 L .73464 .50419 L F
.54 .219 .372 r
.54597 .73869 m .54381 .74144 L .54257 .74163 L F
.635 .335 .445 r
.5488 .74121 m .54381 .74144 L .54597 .73869 L F
.485 .252 .486 r
.36638 .61719 m .36387 .62006 L .36416 .61766 L F
.718 .979 .914 r
.72328 .51889 m .72673 .51748 L .72493 .51712 L F
.843 .92 .884 r
.72493 .51712 m .72673 .51748 L .72824 .51579 L F
.927 .95 .784 r
.70246 .52804 m .70446 .52504 L .70366 .52419 L F
.718 .853 .946 r
.48458 .63228 m .48097 .63259 L .48327 .63118 L F
.631 .82 .973 r
.48679 .6315 m .48458 .63228 L .48327 .63118 L F
.091 0 0 r
.33009 .64532 m .32904 .64507 L .3311 .6445 L F
.084 0 0 r
.3272 .64663 m .32904 .64507 L .33009 .64532 L F
.795 .639 .689 r
.52471 .78944 m .52107 .7921 L .5214 .78972 L F
.711 .956 .68 r
.71632 .48705 m .71794 .48471 L .71907 .48597 L F
.71632 .48705 m .7159 .48702 L .71794 .48471 L F
0 0 .479 r
.44759 .66069 m .44683 .66051 L .44871 .6595 L F
.44759 .66069 m .44735 .66243 L .44683 .66051 L F
.396 .098 .338 r
.63125 .48559 m .62863 .48795 L .63093 .48699 L F
.472 .211 .437 r
.63093 .48699 m .63341 .48484 L .63125 .48559 L F
.548 .729 .958 r
.69714 .48133 m .69804 .48272 L .69965 .48097 L F
.372 .448 .81 r
.69804 .48272 m .70061 .48381 L .69965 .48097 L F
.599 .411 .598 r
.60983 .53871 m .60786 .5414 L .60719 .5392 L F
.919 .522 .184 r
.52765 .64915 m .5263 .65165 L .52701 .6514 L F
.52765 .64915 m .52975 .65154 L .5263 .65165 L F
.52765 .64915 m .52856 .65099 L .52975 .65154 L F
.566 .884 .99 r
.53077 .65024 m .52856 .65099 L .52975 .65154 L F
.53077 .65024 m .52856 .65099 L .52975 .65154 L F
.339 0 0 r
.53068 .65035 m .52856 .65099 L .53077 .65024 L F
.513 .862 .991 r
.52975 .65154 m .52856 .65099 L .5264 .65165 L F
.339 0 0 r
.52928 .65206 m .52856 .65099 L .53068 .65035 L F
.513 .862 .991 r
.5264 .65165 m .52856 .65099 L .5263 .65165 L F
.979 .716 .46 r
.51248 .79232 m .51345 .79227 L .51224 .78909 L F
.986 .757 .506 r
.51189 .79397 m .51345 .79227 L .51248 .79232 L F
.179 .311 .762 r
.51224 .78909 m .51345 .79227 L .51474 .79161 L F
.476 .235 .469 r
.51582 .79236 m .51365 .79471 L .51345 .79227 L F
.341 .734 .984 r
.51345 .79227 m .51582 .79236 L .51474 .79161 L F
.767 .632 .712 r
.51189 .79397 m .51474 .79161 L .51345 .79227 L F
.162 .701 .754 r
.31978 .63246 m .32135 .63216 L .32327 .63198 L F
0 0 0 r
.32135 .63216 m .32535 .63143 L .32327 .63198 L F
.744 .733 .842 r
.67874 .51405 m .67557 .51438 L .67816 .51353 L F
.673 .767 .922 r
.68021 .51173 m .67874 .51405 L .67816 .51353 L F
.68021 .51173 m .68142 .51375 L .67874 .51405 L F
.647 .372 .489 r
.67874 .51405 m .68142 .51375 L .68045 .51573 L F
0 .031 .543 r
.68007 .51527 m .68045 .51573 L .67874 .51405 L F
.68007 .51527 m .68045 .51573 L .67874 .51405 L F
.68007 .51527 m .67874 .51405 L .67816 .51353 L F
.68007 .51527 m .67874 .51405 L .67816 .51353 L F
.67 .713 .881 r
.54088 .60932 m .53688 .60852 L .53966 .60616 L F
.781 .746 .82 r
.54294 .60623 m .54088 .60932 L .53966 .60616 L F
.695 .622 .77 r
.54294 .60623 m .54435 .60957 L .54088 .60932 L F
.762 .632 .717 r
.54435 .60957 m .54098 .61181 L .54088 .60932 L F
.729 .567 .672 r
.55467 .61778 m .55086 .61806 L .55116 .61493 L F
.621 .261 .337 r
.58593 .69421 m .58551 .6959 L .58359 .69533 L F
.735 .991 .829 r
.47829 .63379 m .47974 .63172 L .48097 .63259 L F
.47829 .63379 m .47758 .63359 L .47974 .63172 L F
.523 .338 .571 r
.59394 .53265 m .59606 .5298 L .59437 .53057 L F
.449 .711 .979 r
.30314 .62949 m .30264 .63097 L .30048 .62916 L F
.30314 .62949 m .30455 .63075 L .30264 .63097 L F
.583 .895 .621 r
.66397 .47856 m .66259 .47989 L .66417 .47819 L F
.538 .909 .732 r
.66689 .47656 m .66397 .47856 L .66417 .47819 L F
.307 .34 .732 r
.66259 .47989 m .66445 .48123 L .66417 .47819 L F
.755 .546 .614 r
.66259 .47989 m .6658 .48228 L .66445 .48123 L F
.66259 .47989 m .66248 .48262 L .6658 .48228 L F
.767 .666 .751 r
.68227 .51968 m .68372 .52234 L .68071 .5221 L F
.821 .678 .705 r
.68372 .52234 m .68033 .52422 L .68071 .5221 L F
.68372 .52234 m .68311 .52459 L .68033 .52422 L F
.696 .64 .789 r
.68456 .52028 m .68372 .52234 L .68227 .51968 L F
.68456 .52028 m .68629 .52188 L .68372 .52234 L F
.678 .528 .674 r
.68372 .52234 m .68629 .52188 L .68311 .52459 L F
.279 0 .243 r
.54313 .78842 m .54255 .78639 L .54582 .78583 L F
.206 0 .351 r
.49064 .80207 m .49059 .79926 L .4901 .80298 L F
.49271 .7986 m .49059 .79926 L .49064 .80207 L F
.017 0 .307 r
.49059 .79926 m .48961 .80125 L .4906 .79994 L F
.49059 .79926 m .4906 .79994 L .49108 .79931 L F
.825 .827 .85 r
.78285 .60132 m .78408 .5974 L .78173 .59854 L F
.78285 .60132 m .78437 .59995 L .78408 .5974 L F
.416 .014 .165 r
.26323 .59127 m .26687 .58882 L .26404 .58986 L F
.26323 .59127 m .26544 .59096 L .26687 .58882 L F
.311 0 .103 r
.26687 .58882 m .26759 .59043 L .26922 .58831 L F
.26687 .58882 m .26544 .59096 L .26759 .59043 L F
.389 .144 .418 r
.37843 .69928 m .37603 .70011 L .37549 .70214 L F
.37843 .69928 m .37603 .70011 L .37549 .70214 L F
0 0 0 r
.49381 .81408 m .49736 .81189 L .49608 .81446 L F
0 .128 .647 r
.49832 .81092 m .49736 .81189 L .49667 .80943 L F
.765 .689 .779 r
.49832 .81092 m .49608 .81446 L .49736 .81189 L F
.998 .82 .535 r
.55821 .78882 m .55958 .78669 L .5586 .78584 L F
.645 .829 .971 r
.68766 .47488 m .68427 .47461 L .68654 .47365 L F
.691 .831 .95 r
.68988 .47382 m .68766 .47488 L .68654 .47365 L F
.52 .484 .756 r
.51639 .67064 m .51704 .66727 L .51503 .66743 L F
.51639 .67064 m .51832 .67005 L .51704 .66727 L F
.233 .373 .8 r
.65772 .52178 m .65938 .5231 L .65845 .52063 L F
.704 .548 .674 r
.59177 .72182 m .59415 .72169 L .59404 .71885 L F
.234 0 .266 r
.33605 .62367 m .33736 .62447 L .33816 .62316 L F
.33605 .62367 m .33548 .62548 L .33736 .62447 L F
.169 0 0 r
.45335 .6447 m .45717 .64323 L .45505 .64414 L F
.637 .452 .616 r
.42296 .67128 m .4228 .67375 L .42041 .67364 L F
.999 .798 .473 r
.42228 .67314 m .4228 .67375 L .42296 .67128 L F
.42228 .67314 m .42422 .67193 L .42459 .67158 L F
.42422 .67193 m .42574 .671 L .42459 .67158 L F
.42422 .67193 m .42559 .67101 L .42574 .671 L F
.42228 .67314 m .42416 .67193 L .42422 .67193 L F
.162 0 0 r
.42537 .67204 m .42422 .67193 L .42459 .67158 L F
.999 .798 .473 r
.42416 .67193 m .42559 .67101 L .42422 .67193 L F
.162 0 0 r
.42571 .67195 m .42537 .67204 L .42459 .67158 L F
.42537 .67204 m .42365 .67249 L .42422 .67193 L F
.42365 .67249 m .4234 .67255 L .42459 .67158 L F
0 0 0 r
.42459 .67158 m .42416 .67193 L .42228 .67314 L F
.42416 .67193 m .4234 .67255 L .42228 .67314 L F
.999 .798 .473 r
.42228 .67314 m .42296 .67128 L .42559 .67101 L F
.857 .669 .646 r
.54983 .7714 m .55322 .7725 L .54859 .77152 L F
0 .555 .718 r
.55242 .77244 m .55322 .7725 L .55043 .77234 L F
.899 .5 .243 r
.61891 .5247 m .61772 .52589 L .61939 .52646 L F
0 0 0 r
.6216 .52235 m .62039 .52351 L .61891 .5247 L F
.62039 .52351 m .61772 .52589 L .61891 .5247 L F
.62 .584 .791 r
.70628 .51018 m .70429 .51118 L .70303 .50753 L F
.638 .411 .558 r
.59501 .59807 m .59494 .60099 L .59138 .60067 L F
.558 .312 .5 r
.59702 .59792 m .59494 .60099 L .59501 .59807 L F
.434 .208 .47 r
.61679 .49965 m .61894 .49898 L .61924 .49687 L F
.28 .101 .45 r
.61679 .49965 m .61843 .50073 L .61894 .49898 L F
.61679 .49965 m .61669 .50187 L .61843 .50073 L F
.762 .632 .717 r
.54435 .60957 m .54393 .61183 L .54098 .61181 L F
.762 .599 .676 r
.54098 .61181 m .54393 .61183 L .5423 .61242 L F
.514 0 0 r
.24486 .65246 m .24684 .6532 L .24857 .65243 L F
.281 0 0 r
.24684 .6532 m .25044 .65388 L .24857 .65243 L F
.552 .439 .678 r
.38734 .67098 m .38918 .66812 L .38694 .6686 L F
.392 0 0 r
.49271 .7986 m .49151 .79774 L .4903 .79751 L F
.765 .705 .795 r
.54659 .60698 m .54435 .60957 L .54294 .60623 L F
.796 .552 .568 r
.49211 .79981 m .49725 .79778 L .49449 .79817 L F
.49211 .79981 m .49714 .80024 L .49725 .79778 L F
.407 .227 .522 r
.49725 .79778 m .49714 .80024 L .49885 .7978 L F
.49725 .79778 m .49714 .80024 L .49885 .7978 L F
.454 .414 .724 r
.56917 .71495 m .56973 .71866 L .56702 .71649 L F
.758 .61 .695 r
.75468 .58119 m .75445 .58212 L .75172 .58135 L F
.86 .654 .623 r
.75186 .58289 m .75468 .58119 L .75172 .58135 L F
.75186 .58289 m .75392 .58441 L .75468 .58119 L F
.751 .752 .853 r
.70879 .51915 m .71014 .5154 L .70778 .51801 L F
.70879 .51915 m .71149 .51702 L .71014 .5154 L F
.34 .788 .956 r
.30474 .58428 m .30413 .5851 L .30268 .58412 L F
.30474 .58428 m .30636 .58481 L .30413 .5851 L F
.825 .827 .85 r
.78437 .59995 m .78667 .59728 L .78408 .5974 L F
.223 0 0 r
.57663 .70509 m .5755 .7068 L .57352 .70677 L F
.312 .055 .353 r
.5788 .70377 m .57663 .70509 L .57909 .70228 L F
.456 .121 .309 r
.5788 .70377 m .5755 .7068 L .57663 .70509 L F
.46 .367 .663 r
.25025 .60649 m .25203 .60599 L .25158 .60267 L F
.437 .361 .674 r
.25083 .60906 m .25203 .60599 L .25025 .60649 L F
.987 .838 .457 r
.72879 .4925 m .72975 .49128 L .72962 .4885 L F
.72879 .4925 m .72936 .49355 L .72975 .49128 L F
.409 .22 .511 r
.34516 .61452 m .34733 .61208 L .34555 .61238 L F
.515 .114 .219 r
.46563 .69832 m .46943 .69625 L .46797 .69836 L F
.46563 .69832 m .46594 .6971 L .46943 .69625 L F
.449 0 .051 r
.47147 .69687 m .46797 .69836 L .46943 .69625 L F
.616 .869 .99 r
.67814 .47554 m .68044 .47474 L .68192 .47548 L F
.659 .881 .98 r
.68192 .47548 m .68318 .47362 L .68427 .47461 L F
.68192 .47548 m .68044 .47474 L .68318 .47362 L F
.7 .523 .645 r
.55827 .62013 m .55467 .61778 L .55731 .61785 L F
.55827 .62013 m .55476 .62051 L .55467 .61778 L F
.59 .864 .994 r
.35145 .76123 m .34789 .76125 L .34999 .76052 L F
.35145 .76123 m .34789 .76125 L .34999 .76052 L F
.34 .435 .813 r
.51657 .64653 m .51915 .64809 L .51776 .64828 L F
.578 .591 .83 r
.52041 .6496 m .51776 .64828 L .51915 .64809 L F
.505 .23 .432 r
.57124 .71428 m .56926 .71251 L .57205 .71329 L F
.57124 .71428 m .56917 .71495 L .56926 .71251 L F
.286 .654 .969 r
.40098 .65629 m .40193 .65726 L .39902 .65599 L F
.721 .298 .242 r
.40098 .65629 m .40425 .65684 L .40193 .65726 L F
.495 .281 .517 r
.36387 .62006 m .36151 .62301 L .36177 .62056 L F
.658 .867 .978 r
.25509 .63207 m .25844 .63185 L .25686 .63091 L F
.017 0 0 r
.25607 .63212 m .25509 .63207 L .25686 .63091 L F
.964 .789 .618 r
.25444 .63024 m .25529 .63143 L .25686 .63091 L F
0 .32 .807 r
.25468 .63041 m .2561 .63196 L .25529 .63143 L F
.964 .789 .618 r
.25444 .63022 m .25686 .63091 L .25494 .62911 L F
0 .32 .807 r
.2542 .62962 m .25517 .6308 L .25468 .63041 L F
.25517 .6308 m .2561 .63196 L .25468 .63041 L F
.964 .789 .618 r
.25444 .63024 m .25448 .63025 L .25444 .63022 L F
.25448 .63025 m .25686 .63091 L .25444 .63022 L F
.967 .718 .505 r
.71821 .50524 m .71852 .50816 L .71702 .50683 L F
.455 .197 .433 r
.62349 .49332 m .626 .49078 L .62367 .49139 L F
.529 .529 .799 r
.50751 .64591 m .50839 .64937 L .51052 .64751 L F
.531 .59 .858 r
.4733 .79535 m .47392 .79189 L .47159 .79175 L F
.4733 .79535 m .47534 .79497 L .47392 .79189 L F
.358 0 .214 r
.47242 .79688 m .47534 .79497 L .4733 .79535 L F
.508 .273 .493 r
.39366 .65936 m .39592 .65923 L .39606 .65711 L F
0 0 0 r
.39902 .65599 m .39606 .65711 L .39792 .65469 L F
.356 .154 .463 r
.39606 .65711 m .39803 .65675 L .39792 .65469 L F
.632 .523 .712 r
.39592 .65923 m .39803 .65675 L .39606 .65711 L F
.51 0 0 r
.40853 .71244 m .40699 .71295 L .40492 .71246 L F
.547 .025 0 r
.41066 .7131 m .40699 .71295 L .40853 .71244 L F
.718 .706 .838 r
.48698 .64558 m .49057 .64597 L .48923 .6429 L F
.763 .727 .82 r
.48923 .6429 m .49057 .64597 L .49276 .64349 L F
.87 .681 .645 r
.49378 .69393 m .49337 .69458 L .49107 .69297 L F
.633 .656 .855 r
.74463 .59118 m .74556 .5929 L .74793 .59224 L F
.361 .413 .78 r
.51803 .64474 m .51657 .64653 L .5155 .64309 L F
.376 .434 .794 r
.51803 .64474 m .51915 .64809 L .51657 .64653 L F
.407 .667 .966 r
.2938 .62735 m .29322 .62879 L .29185 .62735 L F
.434 .697 .976 r
.2938 .62735 m .29517 .62867 L .29322 .62879 L F
.711 .307 .281 r
.54696 .73272 m .54921 .73484 L .55048 .73306 L F
.8 .423 .342 r
.54921 .73484 m .55236 .73573 L .55048 .73306 L F
.81 .42 .317 r
.55048 .73306 m .55236 .73573 L .55409 .73563 L F
.082 .47 .89 r
.71744 .51771 m .72016 .51982 L .71959 .51861 L F
.562 .834 .996 r
.71959 .51861 m .72016 .51982 L .72328 .51889 L F
.684 .341 .388 r
.58536 .58868 m .58879 .58679 L .58694 .58631 L F
.58536 .58868 m .58889 .58858 L .58879 .58679 L F
.611 .285 .393 r
.58889 .58858 m .59109 .58856 L .58879 .58679 L F
.604 .289 .41 r
.58879 .58679 m .59109 .58856 L .59146 .58683 L F
.929 .941 .785 r
.52494 .77995 m .52758 .77765 L .52745 .78052 L F
.313 .202 .564 r
.52758 .77765 m .52947 .77468 L .52822 .77591 L F
.198 0 .329 r
.52898 .77945 m .52758 .77765 L .52822 .77591 L F
.52898 .77945 m .52745 .78052 L .52758 .77765 L F
.587 .493 .715 r
.58036 .70096 m .5788 .70377 L .57909 .70228 L F
.553 .283 .46 r
.76484 .57518 m .76754 .57494 L .7664 .57321 L F
.632 .303 .396 r
.7664 .57321 m .76754 .57494 L .76965 .57458 L F
.943 .591 .315 r
.66248 .48262 m .6645 .48572 L .6658 .48228 L F
.504 .67 .938 r
.6658 .48228 m .66658 .48084 L .66445 .48123 L F
.6658 .48228 m .66829 .48224 L .66658 .48084 L F
.388 .117 .376 r
.3911 .66231 m .39302 .66178 L .39366 .65936 L F
.604 .372 .538 r
.39302 .66178 m .39592 .65923 L .39366 .65936 L F
.675 .768 .921 r
.68244 .511 m .68142 .51375 L .68021 .51173 L F
.53 .518 .788 r
.68139 .5085 m .68231 .51113 L .68021 .51173 L F
.917 .967 .663 r
.68007 .51527 m .68045 .51573 L .68117 .514 L F
.675 .768 .921 r
.68244 .511 m .68021 .51173 L .6817 .51246 L F
.917 .967 .663 r
.6817 .51246 m .68117 .514 L .68244 .511 L F
.759 .85 .404 r
.68117 .514 m .68142 .51375 L .68244 .511 L F
.675 .768 .921 r
.68244 .511 m .6817 .51246 L .683 .5131 L F
.917 .967 .663 r
.68181 .51213 m .6817 .51246 L .68244 .511 L F
.68007 .51527 m .68117 .514 L .68181 .51213 L F
.53 .518 .788 r
.68185 .51213 m .68177 .5125 L .6817 .51246 L F
.759 .85 .404 r
.68045 .51573 m .68065 .51531 L .68117 .514 L F
.68065 .51531 m .68142 .51375 L .68117 .514 L F
.917 .967 .663 r
.68007 .51527 m .68181 .51213 L .68257 .5146 L F
.68181 .51213 m .68244 .511 L .68248 .51208 L F
.53 .518 .788 r
.68192 .51213 m .68177 .5125 L .68185 .51213 L F
.68193 .51209 m .683 .5131 L .68177 .5125 L F
.68231 .51113 m .68264 .51208 L .68193 .51209 L F
.68264 .51208 m .683 .5131 L .68193 .51209 L F
.485 0 0 r
.68448 .51257 m .68244 .511 L .683 .5131 L F
.744 .287 .167 r
.68244 .511 m .68589 .51243 L .68543 .51307 L F
.68244 .511 m .68543 .51307 L .68482 .51275 L F
.68244 .511 m .68537 .51315 L .68484 .51284 L F
.485 0 0 r
.68512 .51234 m .68244 .511 L .68448 .51257 L F
.68512 .51234 m .68589 .51243 L .68244 .511 L F
.616 .58 .791 r
.6838 .50805 m .68512 .51234 L .68448 .51257 L F
.68318 .51195 m .68448 .51257 L .683 .5131 L F
.744 .287 .167 r
.68248 .51219 m .68494 .51377 L .68257 .5146 L F
.68248 .51208 m .68259 .51216 L .68248 .51219 L F
.68259 .51216 m .68494 .51377 L .68248 .51219 L F
.68244 .511 m .68328 .51193 L .68248 .51208 L F
.616 .58 .791 r
.68318 .51195 m .683 .5131 L .68264 .51208 L F
.744 .287 .167 r
.68328 .51193 m .6834 .51206 L .68264 .51208 L F
.68328 .51193 m .68264 .51208 L .68248 .51208 L F
.616 .58 .791 r
.68319 .51188 m .68318 .51195 L .68241 .51143 L F
.68318 .51195 m .68264 .51208 L .68241 .51143 L F
.68319 .51188 m .68327 .51192 L .68318 .51195 L F
.68327 .51192 m .68448 .51257 L .68318 .51195 L F
.744 .287 .167 r
.68244 .511 m .68533 .51322 L .68494 .51377 L F
.616 .58 .791 r
.6838 .50805 m .68448 .51257 L .68319 .51188 L F
.744 .287 .167 r
.68482 .51275 m .68543 .51307 L .68537 .51315 L F
.68484 .51284 m .68537 .51315 L .68533 .51322 L F
.616 .58 .791 r
.6838 .50805 m .68319 .51188 L .68139 .5085 L F
.68319 .51188 m .68241 .51143 L .68139 .5085 L F
.744 .287 .167 r
.6834 .51206 m .68494 .51377 L .68248 .51208 L F
.917 .967 .663 r
.68181 .51213 m .68248 .51208 L .68257 .5146 L F
.53 .518 .788 r
.68231 .51113 m .68192 .51213 L .68185 .51213 L F
.68213 .51119 m .6817 .51246 L .68021 .51173 L F
.68231 .51113 m .6817 .51246 L .68213 .51119 L F
.697 .458 .559 r
.51212 .8029 m .50865 .80037 L .51255 .80081 L F
.993 .774 .5 r
.51489 .79991 m .51212 .8029 L .51255 .80081 L F
.518 .249 .447 r
.35171 .63133 m .34894 .63373 L .34944 .6317 L F
.535 .316 .529 r
.58336 .60382 m .58342 .60605 L .5812 .60644 L F
.577 .307 .47 r
.58669 .60327 m .58342 .60605 L .58336 .60382 L F
.662 .956 .736 r
.46809 .63943 m .46892 .63821 L .47084 .63744 L F
.46809 .63943 m .46736 .63965 L .46892 .63821 L F
0 0 0 r
.45002 .65853 m .44759 .66069 L .44871 .6595 L F
.921 .818 .728 r
.50297 .79634 m .50467 .79733 L .50517 .79489 L F
.755 .469 .499 r
.50251 .79949 m .50467 .79733 L .50297 .79634 L F
.50251 .79949 m .50462 .79962 L .50467 .79733 L F
.619 .508 .705 r
.74486 .49606 m .74202 .4967 L .74383 .49391 L F
.617 .085 0 r
.55065 .74964 m .55427 .75043 L .55282 .75053 L F
.911 .836 .759 r
.55428 .5896 m .55124 .5917 L .55325 .58869 L F
.55428 .5896 m .55251 .59237 L .55124 .5917 L F
.89 .913 .834 r
.55428 .5896 m .55543 .58589 L .55655 .58676 L F
.55428 .5896 m .55325 .58869 L .55543 .58589 L F
.28 .72 .964 r
.35698 .59101 m .36054 .59171 L .35844 .59202 L F
.79 .53 .544 r
.52639 .78536 m .52924 .78371 L .52629 .78326 L F
.52639 .78536 m .53029 .78594 L .52924 .78371 L F
.366 .336 .693 r
.52924 .78371 m .53029 .78594 L .53147 .78595 L F
.615 .355 .5 r
.52924 .78371 m .53147 .78595 L .53161 .78367 L F
.481 .03 .103 r
.30014 .64777 m .29897 .64882 L .29641 .64891 L F
.595 .319 .469 r
.302 .64937 m .29928 .64981 L .29897 .64882 L F
.159 .451 .881 r
.29927 .64959 m .29964 .64859 L .29927 .64938 L F
.29928 .64981 m .29936 .64954 L .29927 .64959 L F
.29936 .64954 m .29964 .64859 L .29927 .64959 L F
.448 0 0 r
.30014 .64777 m .30127 .64843 L .29897 .64882 L F
.30127 .64843 m .30249 .64915 L .30037 .64895 L F
.30127 .64843 m .30037 .64895 L .29897 .64882 L F
.835 .724 .742 r
.66383 .51832 m .66193 .52146 L .66544 .52181 L F
.789 .813 .871 r
.66193 .52146 m .66299 .52257 L .66544 .52181 L F
.571 .488 .721 r
.66544 .52181 m .66761 .52118 L .66743 .51891 L F
.263 0 0 r
.3193 .60064 m .31751 .60195 L .31542 .60214 L F
.095 0 0 r
.32148 .60096 m .31751 .60195 L .3193 .60064 L F
.684 .635 .795 r
.77212 .57921 m .77232 .57624 L .77112 .57808 L F
.77212 .57921 m .7743 .57809 L .77232 .57624 L F
.241 0 0 r
.27964 .5863 m .28175 .58597 L .28358 .58454 L F
.227 0 0 r
.28358 .58454 m .2852 .58469 L .28557 .58398 L F
.28358 .58454 m .28175 .58597 L .2852 .58469 L F
.31 .442 .833 r
.39484 .69638 m .39602 .69985 L .39719 .6983 L F
.368 .525 .882 r
.39602 .69985 m .39902 .70106 L .39719 .6983 L F
.795 .705 .764 r
.67041 .48202 m .66829 .48224 L .67145 .48255 L F
.338 0 .044 r
.67427 .48073 m .67041 .48202 L .67145 .48255 L F
.493 .34 .602 r
.38905 .6656 m .39109 .6652 L .3911 .66231 L F
.548 .38 .605 r
.38905 .6656 m .39139 .66765 L .39109 .6652 L F
.38905 .6656 m .38918 .66812 L .39139 .66765 L F
.521 .832 1 r
.67814 .47554 m .67602 .47606 L .675 .47523 L F
.931 .844 .736 r
.63667 .55269 m .63821 .54923 L .63619 .54969 L F
.47 .661 .945 r
.37172 .59476 m .37128 .59666 L .36967 .59503 L F
.37172 .59476 m .37343 .59666 L .37128 .59666 L F
.561 .698 .932 r
.52516 .79553 m .52658 .79784 L .52834 .79681 L F
.567 .717 .943 r
.52834 .79681 m .52859 .79764 L .52658 .79784 L F
.756 .491 .532 r
.52859 .79764 m .52792 .79814 L .52658 .79784 L F
.52859 .79764 m .52927 .7998 L .52878 .79974 L F
.52859 .79764 m .52878 .79974 L .52792 .79814 L F
.416 .356 .683 r
.52658 .79784 m .52895 .80006 L .52878 .79974 L F
.526 .419 .675 r
.52852 .80223 m .52626 .7994 L .52878 .79974 L F
.52913 .80025 m .52878 .79974 L .52927 .7998 L F
.52852 .80223 m .52878 .79974 L .52913 .80025 L F
.416 .356 .683 r
.52766 .79809 m .52878 .79974 L .52792 .79814 L F
.52658 .79784 m .52878 .79974 L .52766 .79809 L F
.52921 .80019 m .52937 .80045 L .52928 .80013 L F
.52792 .79814 m .52921 .80019 L .52878 .79834 L F
.52895 .80006 m .52937 .80045 L .52792 .79814 L F
.756 .491 .532 r
.52792 .79814 m .52878 .79974 L .52626 .7994 L F
.52792 .79814 m .52626 .7994 L .52658 .79784 L F
.416 .356 .683 r
.52658 .79784 m .52878 .79834 L .52834 .79681 L F
.72 .541 .648 r
.52626 .7994 m .52914 .80037 L .52834 .79681 L F
.52914 .80037 m .52937 .80045 L .52928 .80013 L F
.49 .792 .998 r
.52913 .80025 m .52928 .80014 L .52903 .80055 L F
.416 .356 .683 r
.52921 .80019 m .52928 .80013 L .52878 .79834 L F
.72 .541 .648 r
.52914 .80037 m .52928 .80013 L .52834 .79681 L F
.49 .792 .998 r
.53083 .79898 m .53163 .79966 L .52927 .7998 L F
.52927 .7998 m .53163 .79966 L .53083 .79898 L F
.52927 .7998 m .53062 .79909 L .52928 .80013 L F
.53062 .79909 m .53083 .79898 L .52913 .80025 L F
.53083 .79898 m .52927 .7998 L .52859 .79764 L F
.53083 .79898 m .52859 .79764 L .52935 .79844 L F
.402 .348 .682 r
.52834 .79681 m .52935 .79844 L .53083 .79898 L F
.52935 .79844 m .53004 .79956 L .53083 .79898 L F
.49 .792 .998 r
.53083 .79898 m .52935 .79844 L .53005 .79918 L F
0 0 .577 r
.53005 .79918 m .52935 .79844 L .52834 .79681 L F
.52935 .79844 m .52859 .79764 L .52834 .79681 L F
.402 .348 .682 r
.52834 .79681 m .52928 .80013 L .53004 .79956 L F
.52928 .80013 m .52937 .80045 L .53083 .79898 L F
.49 .792 .998 r
.52913 .80024 m .52928 .80013 L .52913 .80025 L F
.52927 .7998 m .52928 .80013 L .52913 .80024 L F
.739 .449 .491 r
.52852 .80223 m .52937 .80045 L .52914 .80037 L F
.49 .792 .998 r
.52903 .80055 m .5291 .8005 L .52852 .80223 L F
.739 .449 .491 r
.52852 .80223 m .52914 .80037 L .52626 .7994 L F
0 0 0 r
.53083 .79898 m .52937 .80045 L .52852 .80223 L F
.49 .792 .998 r
.5291 .8005 m .53083 .79898 L .52852 .80223 L F
.52928 .80014 m .53083 .79898 L .52903 .80055 L F
.72 .541 .648 r
.52626 .7994 m .52834 .79681 L .52658 .79784 L F
0 0 .418 r
.25053 .64904 m .25119 .64949 L .25266 .64781 L F
.25053 .64904 m .25144 .65141 L .25119 .64949 L F
.434 .208 .47 r
.61924 .49687 m .62109 .49826 L .62107 .49598 L F
.61924 .49687 m .61894 .49898 L .62109 .49826 L F
.653 .688 .87 r
.3768 .59777 m .37458 .59854 L .37343 .59666 L F
.563 .395 .612 r
.2424 .63178 m .24352 .63293 L .2441 .63174 L F
.16 0 .304 r
.62361 .57731 m .62225 .57839 L .62422 .57534 L F
.03 0 .205 r
.62361 .57731 m .62166 .58045 L .62225 .57839 L F
.943 .591 .315 r
.66248 .48262 m .66285 .4848 L .6645 .48572 L F
.501 .266 .491 r
.66356 .48786 m .6645 .48572 L .66285 .4848 L F
.656 .271 .303 r
.42041 .67364 m .41907 .67568 L .41698 .67374 L F
.613 .221 .277 r
.4217 .67561 m .42041 .67364 L .4228 .67375 L F
.4217 .67561 m .41907 .67568 L .42041 .67364 L F
.849 .783 .787 r
.51272 .69615 m .5096 .69714 L .51208 .69613 L F
.633 .961 .819 r
.51272 .69615 m .51208 .69613 L .51381 .69481 L F
.619 .602 .811 r
.31448 .66244 m .31755 .66221 L .31652 .65958 L F
.754 .679 .779 r
.54775 .60078 m .54886 .60385 L .5452 .60338 L F
.765 .642 .726 r
.54886 .60385 m .54659 .60698 L .5452 .60338 L F
.735 .606 .713 r
.50276 .78369 m .50493 .78093 L .50318 .78157 L F
.515 .305 .533 r
.50496 .78329 m .50493 .78093 L .50276 .78369 L F
.776 .599 .659 r
.50496 .78329 m .50756 .78115 L .50493 .78093 L F
.073 0 .17 r
.54147 .73558 m .54343 .73472 L .54378 .73321 L F
.039 0 .091 r
.54147 .73558 m .54179 .73604 L .54343 .73472 L F
.038 0 .365 r
.47812 .76658 m .47781 .76922 L .47697 .76955 L F
.361 .239 .576 r
.47859 .77162 m .47697 .76955 L .47781 .76922 L F
.47859 .77162 m .47623 .77317 L .47697 .76955 L F
.79 .8 .861 r
.67101 .52315 m .67494 .52225 L .67357 .52226 L F
0 0 0 r
.67592 .52097 m .67494 .52225 L .67674 .51933 L F
.552 .329 .53 r
.39527 .70726 m .39774 .7048 L .39452 .7048 L F
.39527 .70726 m .39767 .70707 L .39774 .7048 L F
.622 .581 .788 r
.39774 .7048 m .40014 .70465 L .39902 .70106 L F
.627 .409 .567 r
.39767 .70707 m .40014 .70465 L .39774 .7048 L F
.56 .446 .681 r
.74144 .58916 m .74345 .58782 L .74354 .58583 L F
0 0 .004 r
.4737 .78831 m .47245 .78969 L .47159 .79175 L F
.723 .807 .917 r
.71369 .50714 m .70881 .50746 L .71089 .50615 L F
.789 .724 .792 r
.71484 .50514 m .71369 .50714 L .71089 .50615 L F
.628 .418 .579 r
.59138 .60067 m .58902 .60321 L .58898 .60076 L F
.795 .639 .689 r
.52471 .78944 m .52514 .79169 L .52107 .7921 L F
.897 .944 .583 r
.52514 .79169 m .52326 .79391 L .52107 .7921 L F
.52514 .79169 m .52364 .79475 L .52326 .79391 L F
.493 .437 .723 r
.52701 .79175 m .52514 .79169 L .52471 .78944 L F
0 .136 .659 r
.52716 .7942 m .52514 .79169 L .52701 .79175 L F
.52716 .7942 m .52642 .79493 L .52514 .79169 L F
.561 .347 .548 r
.37472 .69367 m .37655 .69466 L .37749 .69341 L F
.37472 .69367 m .37655 .69466 L .37749 .69341 L F
.427 .635 .942 r
.34568 .60214 m .34619 .60032 L .34426 .6005 L F
.34568 .60214 m .34813 .60249 L .34619 .60032 L F
.705 .801 .925 r
.72283 .48622 m .71907 .48597 L .72136 .4848 L F
.219 0 0 r
.4126 .65446 m .41024 .65487 L .40948 .65566 L F
.831 .731 .753 r
.25686 .63091 m .25844 .63185 L .26096 .62895 L F
.053 .02 .497 r
.26096 .62895 m .26196 .62539 L .25947 .62567 L F
.26096 .62895 m .26215 .62804 L .26196 .62539 L F
0 0 .366 r
.26096 .62895 m .26183 .63045 L .26215 .62804 L F
.26096 .62895 m .26159 .63171 L .26183 .63045 L F
.384 .702 .984 r
.70151 .48496 m .70288 .48401 L .70061 .48381 L F
.70151 .48496 m .70398 .48516 L .70288 .48401 L F
.749 .742 .845 r
.62374 .52089 m .6216 .52235 L .62489 .52237 L F
0 0 0 r
.62489 .52237 m .62531 .52295 L .6277 .52175 L F
.62489 .52237 m .62416 .52415 L .62531 .52295 L F
.552 .439 .678 r
.38734 .67098 m .38953 .67054 L .38918 .66812 L F
.527 .414 .669 r
.38734 .67098 m .38971 .67316 L .38953 .67054 L F
.38734 .67098 m .38769 .67453 L .38971 .67316 L F
.303 .153 .505 r
.25829 .63974 m .25934 .64006 L .25953 .63696 L F
.334 0 .048 r
.305 .60579 m .30158 .60786 L .30282 .60621 L F
.135 .492 .904 r
.50456 .63267 m .50679 .63444 L .50554 .63396 L F
.06 0 0 r
.45912 .64215 m .46138 .64179 L .46278 .64113 L F
.437 .852 .688 r
.46278 .64113 m .46328 .64064 L .46526 .64061 L F
.46278 .64113 m .46138 .64179 L .46328 .64064 L F
.361 .549 .903 r
.55738 .72544 m .55841 .72345 L .5559 .724 L F
.55738 .72544 m .55957 .72543 L .55841 .72345 L F
.673 .611 .778 r
.54333 .74456 m .54512 .74778 L .54731 .74631 L F
.662 .783 .317 r
.62212 .5417 m .62391 .53777 L .62446 .53857 L F
.976 .825 .417 r
.62446 .53857 m .62391 .53777 L .62423 .53541 L F
.331 .053 .332 r
.37363 .61172 m .37116 .61427 L .37176 .61241 L F
.662 .666 .843 r
.49479 .62908 m .49605 .63192 L .49249 .63084 L F
.584 .596 .831 r
.49698 .62836 m .49605 .63192 L .49479 .62908 L F
.49698 .62836 m .49827 .63143 L .49605 .63192 L F
.571 .374 .575 r
.47324 .78316 m .47467 .77931 L .47316 .78083 L F
.605 .607 .827 r
.38328 .6005 m .38035 .59854 L .3824 .59779 L F
.425 .546 .875 r
.38361 .59777 m .38328 .6005 L .3824 .59779 L F
.38361 .59777 m .38525 .59961 L .38328 .6005 L F
.318 .12 .446 r
.38496 .60146 m .38328 .6005 L .38525 .59961 L F
.38496 .60146 m .38311 .60305 L .38328 .6005 L F
.72 .868 .951 r
.68286 .53599 m .68607 .53589 L .68488 .53457 L F
.847 .841 .838 r
.68488 .53457 m .68607 .53589 L .68836 .53318 L F
.937 .917 .77 r
.70037 .52909 m .70246 .52804 L .70138 .52697 L F
.70037 .52909 m .70123 .53023 L .70246 .52804 L F
.927 .95 .784 r
.70246 .52804 m .70366 .52419 L .70138 .52697 L F
.776 .505 .524 r
.68311 .52459 m .68034 .52661 L .68033 .52422 L F
.68311 .52459 m .68394 .52719 L .68034 .52661 L F
.672 .269 .273 r
.50248 .7721 m .50469 .77401 L .50625 .77188 L F
.266 0 .022 r
.50625 .77188 m .50692 .77348 L .50843 .77189 L F
.50625 .77188 m .50469 .77401 L .50692 .77348 L F
.305 .529 .905 r
.68721 .52039 m .68629 .52188 L .68456 .52028 L F
.183 .363 .809 r
.68721 .52039 m .68819 .52321 L .68629 .52188 L F
.455 .515 .831 r
.68942 .52486 m .68629 .52188 L .68819 .52321 L F
.623 .822 .977 r
.64188 .50042 m .64067 .50233 L .64302 .50172 L F
.574 .371 .568 r
.64067 .50233 m .64301 .50404 L .64302 .50172 L F
.3 .391 .789 r
.64188 .50042 m .64301 .50404 L .64067 .50233 L F
0 0 0 r
.67825 .51846 m .67674 .51933 L .67938 .51705 L F
.105 0 0 r
.6782 .51984 m .67674 .51933 L .67825 .51846 L F
.566 .628 .873 r
.53617 .79 m .53884 .79208 L .53847 .78931 L F
.822 .999 .79 r
.53884 .79208 m .54083 .78903 L .53847 .78931 L F
.809 .714 .76 r
.37843 .69928 m .37952 .70238 L .38173 .69944 L F
.562 .634 .88 r
.38173 .69944 m .38409 .6993 L .38287 .69691 L F
.38173 .69944 m .38409 .6993 L .38287 .69691 L F
.715 .595 .721 r
.57452 .72205 m .57217 .72441 L .57175 .7211 L F
.291 .789 .852 r
.57448 .7253 m .57064 .72581 L .57217 .72441 L F
.493 .437 .723 r
.52701 .79175 m .52471 .78944 L .52699 .78914 L F
.41 .154 .411 r
.62138 .4941 m .62322 .4953 L .62349 .49332 L F
.62138 .4941 m .62107 .49598 L .62322 .4953 L F
.307 .117 .452 r
.55982 .70771 m .56189 .70667 L .56148 .70489 L F
.603 .815 .413 r
.55963 .71003 m .56189 .70667 L .55982 .70771 L F
.802 .86 .892 r
.70303 .50753 m .70062 .50978 L .69945 .50858 L F
.416 .641 .949 r
.70774 .48373 m .70588 .48273 L .70398 .48516 L F
.814 .702 .741 r
.37655 .69466 m .37888 .69634 L .37749 .69341 L F
.37749 .69341 m .37888 .69634 L .37655 .69466 L F
.881 .643 .575 r
.37843 .69928 m .37888 .69634 L .37655 .69466 L F
.176 0 0 r
.43384 .65045 m .43746 .64902 L .43525 .64922 L F
.735 .745 .859 r
.78023 .58028 m .78334 .5807 L .78176 .58208 L F
.78176 .58208 m .78334 .5807 L .78023 .58028 L F
.268 0 .286 r
.5755 .7068 m .57307 .70938 L .57352 .70677 L F
.753 .64 .737 r
.48916 .62849 m .49031 .63207 L .48679 .6315 L F
.704 .614 .753 r
.49249 .63084 m .49031 .63207 L .48916 .62849 L F
.947 .73 .577 r
.63745 .53471 m .639 .53332 L .63752 .53234 L F
.63745 .53471 m .63884 .53573 L .639 .53332 L F
0 0 0 r
.61059 .51336 m .60849 .51635 L .60993 .51487 L F
.396 .28 .602 r
.60799 .51828 m .60993 .51487 L .60849 .51635 L F
.46 .416 .721 r
.48124 .80446 m .48232 .80313 L .48 .80275 L F
.48124 .80446 m .48333 .80571 L .48232 .80313 L F
.741 .362 .334 r
.52214 .76619 m .52425 .76862 L .52565 .76668 L F
.584 .174 .231 r
.52565 .76668 m .52763 .76835 L .52841 .76718 L F
.52565 .76668 m .52425 .76862 L .52763 .76835 L F
.839 .749 .764 r
.73819 .49628 m .73726 .4927 L .73869 .49398 L F
.73819 .49628 m .73525 .49576 L .73726 .4927 L F
.849 .722 .722 r
.73819 .49628 m .73631 .49908 L .73525 .49576 L F
.961 .764 .593 r
.72847 .50663 m .73014 .50531 L .72906 .50438 L F
.72847 .50663 m .72978 .50769 L .73014 .50531 L F
.711 .62 .754 r
.56064 .61799 m .55827 .62013 L .55731 .61785 L F
.769 .734 .821 r
.56151 .77215 m .56481 .77242 L .56176 .77393 L F
.276 .347 .756 r
.56652 .77141 m .56481 .77242 L .56614 .77238 L F
.95 .952 .657 r
.56614 .77238 m .56769 .76991 L .56733 .76872 L F
.253 .297 .715 r
.56652 .77141 m .56679 .77439 L .56481 .77242 L F
.477 .464 .764 r
.67439 .51251 m .67264 .51336 L .67155 .51101 L F
.825 .706 .732 r
.26488 .6482 m .26578 .65143 L .26213 .65076 L F
.816 .472 .407 r
.26213 .65076 m .26578 .65143 L .26444 .65364 L F
.187 .291 .739 r
.26697 .65043 m .26578 .65143 L .26488 .6482 L F
0 0 0 r
.26444 .65364 m .26578 .65143 L .26697 .65043 L F
.98 .707 .433 r
.66955 .50862 m .67078 .50991 L .67065 .50752 L F
0 .297 .76 r
.66992 .50884 m .67078 .50991 L .66955 .50862 L F
.315 .369 .759 r
.6715 .51081 m .67065 .50752 L .67078 .50991 L F
0 .297 .76 r
.67251 .5104 m .67078 .50991 L .66992 .50884 L F
.315 .369 .759 r
.67155 .51101 m .6715 .51081 L .67078 .50991 L F
0 .284 .743 r
.67078 .50991 m .67439 .51251 L .67155 .51101 L F
.416 .821 .979 r
.67964 .53589 m .68032 .53644 L .68286 .53599 L F
.817 .984 .884 r
.44759 .66069 m .44606 .6622 L .44735 .66243 L F
.024 0 0 r
.51507 .69305 m .51668 .69288 L .51806 .69147 L F
0 0 0 r
.51806 .69147 m .51859 .69199 L .51988 .6904 L F
.51806 .69147 m .51668 .69288 L .51859 .69199 L F
.443 .826 .988 r
.47609 .69072 m .47809 .69032 L .47955 .69085 L F
.505 0 0 r
.47809 .69032 m .48236 .69199 L .47955 .69085 L F
.832 .486 .402 r
.26977 .64217 m .27268 .6427 L .27108 .64474 L F
.035 0 0 r
.27268 .6427 m .27229 .64332 L .27108 .64474 L F
.27268 .6427 m .27484 .64233 L .27229 .64332 L F
.074 .496 .897 r
.42274 .69519 m .42205 .69573 L .4203 .69407 L F
.42274 .69519 m .42399 .6964 L .42205 .69573 L F
.232 0 0 r
.73934 .52407 m .74141 .52392 L .73786 .52431 L F
.73934 .52407 m .74141 .52392 L .73786 .52431 L F
.303 0 .19 r
.34187 .63776 m .34132 .63919 L .33911 .63984 L F
.422 .058 .24 r
.34334 .63878 m .34132 .63919 L .34187 .63776 L F
.436 .05 .208 r
.3442 .63746 m .34334 .63878 L .34187 .63776 L F
.398 .105 .346 r
.34697 .63432 m .34639 .63684 L .3442 .63746 L F
.202 0 .274 r
.34803 .63582 m .34697 .63432 L .34894 .63373 L F
.34803 .63582 m .34639 .63684 L .34697 .63432 L F
.736 .474 .534 r
.53147 .78595 m .53501 .78369 L .53161 .78367 L F
.53147 .78595 m .53621 .78601 L .53501 .78369 L F
.472 .805 .999 r
.53621 .78601 m .53744 .7833 L .53501 .78369 L F
.098 0 .14 r
.62667 .57263 m .62631 .57462 L .62422 .57534 L F
0 0 0 r
.62631 .57462 m .62361 .57731 L .62422 .57534 L F
.285 0 .03 r
.42634 .70864 m .42476 .70838 L .42678 .70803 L F
.42634 .70864 m .42424 .70924 L .42476 .70838 L F
.776 .352 .244 r
.55236 .73573 m .55299 .73735 L .55409 .73563 L F
.711 .271 .205 r
.55409 .73563 m .55299 .73735 L .55638 .73769 L F
.797 .735 .794 r
.54486 .75221 m .54671 .75513 L .54284 .75571 L F
.632 .22 .245 r
.54671 .75513 m .54488 .75732 L .54284 .75571 L F
.129 .392 .845 r
.54808 .75531 m .54671 .75513 L .54486 .75221 L F
.751 .401 .39 r
.57252 .72143 m .57452 .72205 L .57175 .7211 L F
.716 .615 .743 r
.57705 .72096 m .57452 .72205 L .57252 .72143 L F
.805 .793 .842 r
.54182 .78884 m .53847 .78931 L .53849 .78644 L F
.216 .735 .727 r
.54083 .78903 m .54182 .78884 L .54313 .78842 L F
0 0 .497 r
.47621 .77747 m .47561 .7767 L .47379 .77472 L F
0 0 .1 r
.47467 .77931 m .47561 .7767 L .47621 .77747 L F
.714 .638 .771 r
.68007 .51527 m .67938 .51705 L .68045 .51573 L F
.354 0 0 r
.41865 .7103 m .41443 .71085 L .41642 .71023 L F
.06 .274 .765 r
.52716 .7942 m .52834 .79681 L .52642 .79493 L F
.667 .382 .479 r
.52699 .78914 m .53054 .78835 L .52935 .79159 L F
.634 .255 .307 r
.53054 .78835 m .53318 .79066 L .52935 .79159 L F
.53054 .78835 m .5327 .78909 L .53318 .79066 L F
.687 .365 .424 r
.52514 .66698 m .52247 .66742 L .52279 .66695 L F
.224 .737 .703 r
.31355 .6023 m .31203 .60273 L .31069 .60316 L F
0 0 0 r
.31203 .60273 m .31028 .60368 L .31069 .60316 L F
.433 .377 .696 r
.25125 .61215 m .25246 .60842 L .25083 .60906 L F
.25125 .61215 m .25298 .61184 L .25246 .60842 L F
.444 .445 .766 r
.25125 .61215 m .25368 .61375 L .25298 .61184 L F
.545 .428 .671 r
.25125 .61215 m .25157 .61459 L .25368 .61375 L F
.557 .823 .462 r
.67908 .53068 m .67811 .53182 L .67567 .53004 L F
.607 .574 .792 r
.68148 .53002 m .67908 .53068 L .67794 .52718 L F
.674 .198 .113 r
.67908 .53068 m .67811 .53182 L .67567 .53004 L F
.374 0 .041 r
.51657 .69927 m .51532 .70093 L .51299 .70117 L F
.113 0 0 r
.51729 .70018 m .51657 .69927 L .51868 .69861 L F
.51729 .70018 m .51532 .70093 L .51657 .69927 L F
.535 .527 .793 r
.39 .6847 m .39102 .68792 L .39303 .68742 L F
.499 .418 .696 r
.39144 .69093 m .39303 .68742 L .39102 .68792 L F
.662 .783 .317 r
.62212 .5417 m .62251 .54079 L .62391 .53777 L F
.409 .861 .856 r
.38117 .59788 m .38035 .59854 L .37889 .59749 L F
.38117 .59788 m .3824 .59779 L .38035 .59854 L F
.68 .823 .952 r
.69177 .5357 m .69246 .53376 L .69063 .53446 L F
.69177 .5357 m .6937 .53489 L .69246 .53376 L F
.591 .688 .909 r
.69467 .47257 m .6932 .47483 L .69226 .47319 L F
.69467 .47257 m .69572 .47434 L .6932 .47483 L F
.91 .65 .532 r
.55937 .74385 m .56089 .74145 L .55946 .74095 L F
.55937 .74385 m .56094 .74388 L .56089 .74145 L F
.469 .04 .141 r
.46123 .69869 m .45979 .70029 L .45775 .6995 L F
.347 0 .019 r
.46329 .6985 m .45979 .70029 L .46123 .69869 L F
.168 .088 .514 r
.47859 .77162 m .47708 .77507 L .47623 .77317 L F
.398 .028 .215 r
.50496 .78329 m .50276 .78369 L .50194 .78524 L F
.206 0 0 r
.3229 .60119 m .32148 .60096 L .32499 .60083 L F
.297 .319 .715 r
.41668 .67862 m .41519 .67976 L .41462 .67668 L F
.265 .196 .589 r
.41714 .68101 m .41519 .67976 L .41668 .67862 L F
.41714 .68101 m .41547 .6823 L .41519 .67976 L F
.643 .38 .505 r
.50318 .78157 m .50408 .77841 L .50141 .77851 L F
.404 .102 .336 r
.62823 .49009 m .63093 .48699 L .62863 .48795 L F
.777 .549 .59 r
.71014 .5154 m .71353 .51352 L .71238 .51311 L F
.71014 .5154 m .7138 .51534 L .71353 .51352 L F
.865 .882 .847 r
.71483 .50949 m .71589 .5109 L .71353 .51352 L F
.452 .322 .613 r
.71353 .51352 m .71565 .51561 L .71537 .51412 L F
.71353 .51352 m .7138 .51534 L .71565 .51561 L F
0 .555 .718 r
.55242 .77244 m .55043 .77234 L .55059 .77485 L F
0 0 .1 r
.47467 .77931 m .47526 .77935 L .47561 .7767 L F
0 0 .29 r
.47467 .77931 m .47566 .78187 L .47526 .77935 L F
.957 .948 .698 r
.70037 .52909 m .69964 .53256 L .70123 .53023 L F
.782 .764 .837 r
.55 .74201 m .54626 .74241 L .5488 .74121 L F
.716 .615 .743 r
.57705 .72096 m .57252 .72143 L .57568 .71891 L F
.823 .792 .823 r
.57907 .71893 m .57705 .72096 L .57568 .71891 L F
.746 .226 0 r
.52498 .80881 m .52428 .80795 L .52382 .80839 L F
.52428 .80795 m .52379 .80736 L .52382 .80839 L F
.336 0 0 r
.5213 .80859 m .52382 .80839 L .52243 .80976 L F
0 0 0 r
.52361 .80859 m .52382 .80839 L .52307 .80899 L F
.853 .537 .453 r
.52593 .8092 m .52379 .80736 L .52498 .80881 L F
.746 .226 0 r
.52498 .80881 m .52387 .80836 L .52562 .80711 L F
.749 .951 .943 r
.52382 .80839 m .52498 .80881 L .52562 .80711 L F
.746 .226 0 r
.52498 .80881 m .52382 .80839 L .52387 .80836 L F
0 0 0 r
.52373 .80868 m .52382 .80839 L .52562 .80711 L F
.52243 .80976 m .5231 .8091 L .52373 .80868 L F
.5231 .8091 m .52382 .80839 L .52373 .80868 L F
.52562 .80711 m .52382 .80839 L .52361 .80859 L F
.279 0 0 r
.52307 .80899 m .52382 .80839 L .5213 .80859 L F
0 0 0 r
.52562 .80711 m .52307 .80899 L .52568 .80769 L F
.655 .765 .931 r
.52504 .80704 m .52113 .80675 L .52391 .80589 L F
.523 .916 .816 r
.52387 .80768 m .52392 .80766 L .52514 .80692 L F
.52392 .80766 m .52562 .80711 L .52521 .80694 L F
.655 .765 .931 r
.52432 .80741 m .52113 .80675 L .52504 .80704 L F
.523 .916 .816 r
.52392 .80766 m .52521 .80694 L .52514 .80692 L F
.52514 .80692 m .52562 .80711 L .52651 .80621 L F
0 0 0 r
.52651 .80621 m .52562 .80711 L .52568 .80769 L F
.685 .69 .849 r
.52651 .80621 m .52568 .80769 L .52504 .80704 L F
.52651 .80621 m .52504 .80704 L .52391 .80589 L F
0 0 0 r
.52373 .80868 m .52562 .80711 L .52387 .80768 L F
.655 .765 .931 r
.52568 .80769 m .52432 .80741 L .52504 .80704 L F
.52532 .80762 m .52375 .80858 L .52392 .80733 L F
.523 .916 .816 r
.52328 .80787 m .52368 .80774 L .52514 .80692 L F
.52368 .80774 m .52387 .80768 L .52432 .80741 L F
.52368 .80774 m .52432 .80741 L .52514 .80692 L F
.719 .612 .737 r
.52359 .80688 m .52651 .80621 L .52391 .80589 L F
.52328 .80787 m .52514 .80692 L .52359 .80688 L F
.52514 .80692 m .52651 .80621 L .52359 .80688 L F
.655 .765 .931 r
.52392 .80733 m .52369 .80779 L .52136 .80684 L F
.5216 .80684 m .52136 .80684 L .52113 .80675 L F
.52392 .80733 m .52136 .80684 L .5216 .80684 L F
.52369 .80779 m .52307 .80899 L .5226 .80845 L F
.52369 .80779 m .5226 .80845 L .52113 .80675 L F
.279 0 0 r
.52307 .80899 m .5213 .80859 L .5194 .80606 L F
0 .267 .759 r
.52113 .80675 m .52307 .80899 L .5194 .80606 L F
0 0 0 r
.52243 .80976 m .52373 .80868 L .52328 .80787 L F
.655 .765 .931 r
.52375 .80858 m .52307 .80899 L .52392 .80733 L F
0 0 0 r
.52373 .80868 m .52387 .80768 L .52328 .80787 L F
.655 .765 .931 r
.52568 .80769 m .52382 .80862 L .52532 .80762 L F
.52382 .80862 m .52307 .80899 L .52532 .80762 L F
.853 .537 .453 r
.52643 .80962 m .52593 .8092 L .52498 .80881 L F
.093 .561 .908 r
.59694 .71541 m .59761 .71493 L .59609 .71292 L F
.59694 .71541 m .59891 .71587 L .59761 .71493 L F
.823 .792 .823 r
.57907 .71893 m .57568 .71891 L .57783 .71832 L F
.217 .018 .381 r
.57907 .71893 m .58193 .71763 L .5813 .71588 L F
.584 .294 .442 r
.57783 .71832 m .58193 .71763 L .57907 .71893 L F
.574 .715 .938 r
.26531 .63995 m .2668 .64295 L .26977 .64217 L F
.499 .418 .696 r
.39144 .69093 m .39347 .69074 L .39303 .68742 L F
.629 .528 .721 r
.39171 .69318 m .39347 .69074 L .39144 .69093 L F
.528 .439 .699 r
.50886 .80344 m .50651 .80032 L .50865 .80037 L F
.697 .458 .559 r
.51212 .8029 m .50886 .80344 L .50865 .80037 L F
.437 .361 .674 r
.25083 .60906 m .25246 .60842 L .25203 .60599 L F
.558 .312 .5 r
.59702 .59792 m .59725 .6002 L .59494 .60099 L F
.643 .374 .497 r
.59702 .59792 m .59932 .59997 L .59725 .6002 L F
.656 .37 .474 r
.59946 .59808 m .59932 .59997 L .59702 .59792 L F
0 .128 .647 r
.49832 .81092 m .49667 .80943 L .49806 .80889 L F
.363 .616 .948 r
.59179 .72092 m .59161 .72189 L .58719 .71847 L F
.766 .344 .248 r
.59093 .72375 m .59177 .72182 L .59179 .72092 L F
.59093 .72375 m .59299 .72359 L .59177 .72182 L F
.002 0 .291 r
.62859 .56935 m .62832 .57148 L .62667 .57263 L F
0 0 .067 r
.62749 .57317 m .62667 .57263 L .62832 .57148 L F
.62749 .57317 m .62631 .57462 L .62667 .57263 L F
.136 .256 .725 r
.47106 .80038 m .4719 .80329 L .47313 .80257 L F
0 0 .193 r
.4719 .80329 m .47239 .80502 L .47313 .80257 L F
.4719 .80329 m .4721 .80572 L .47239 .80502 L F
.863 .416 .043 r
.66868 .50086 m .66918 .50018 L .66892 .4983 L F
.66868 .50086 m .67051 .50236 L .66918 .50018 L F
.768 .678 .763 r
.50392 .79174 m .50517 .79489 L .50166 .79458 L F
.921 .818 .728 r
.50297 .79634 m .50517 .79489 L .50385 .79436 L F
.76 .246 0 r
.50385 .79436 m .50517 .79489 L .50693 .79728 L F
.303 .345 .74 r
.48571 .77452 m .4868 .77854 L .48841 .77686 L F
.767 .523 .566 r
.48757 .77838 m .48689 .7804 L .4868 .77854 L F
.49009 .77786 m .48826 .7793 L .48757 .77838 L F
.48826 .7793 m .48689 .7804 L .48757 .77838 L F
.49009 .77786 m .48963 .77973 L .48852 .78 L F
.012 .097 .607 r
.48839 .77966 m .48839 .78009 L .48853 .78003 L F
.863 .824 .808 r
.48689 .7804 m .48839 .78009 L .48839 .77966 L F
.767 .523 .566 r
.48826 .7793 m .48839 .77966 L .48689 .7804 L F
.863 .824 .808 r
.48689 .7804 m .48839 .77966 L .48841 .77686 L F
.767 .523 .566 r
.48839 .77966 m .48852 .78 L .48689 .7804 L F
.49009 .77786 m .48852 .78 L .48826 .7793 L F
.012 .097 .607 r
.48839 .77948 m .48839 .77966 L .48874 .77994 L F
.48839 .77966 m .48853 .78003 L .48874 .77994 L F
.515 .304 .531 r
.49105 .77721 m .48963 .77973 L .49009 .77786 L F
.49105 .77721 m .49335 .77941 L .48963 .77973 L F
.012 .097 .607 r
.48841 .77686 m .48839 .77948 L .48997 .77944 L F
.48839 .77948 m .48874 .77994 L .48997 .77944 L F
.863 .824 .808 r
.48689 .7804 m .48841 .77686 L .4868 .77854 L F
.919 .828 .74 r
.63842 .52606 m .64155 .52325 L .64059 .52211 L F
.63842 .52606 m .63975 .52715 L .64155 .52325 L F
.594 .464 .673 r
.51224 .78909 m .51438 .78593 L .51209 .78637 L F
.517 .124 .235 r
.42377 .6515 m .42556 .65274 L .42695 .65057 L F
.344 0 .052 r
.42556 .65274 m .42936 .65049 L .42695 .65057 L F
.341 .029 .282 r
.3794 .6071 m .38136 .60595 L .38141 .60688 L F
.369 .009 .216 r
.37767 .61033 m .3794 .6071 L .38141 .60688 L F
.69 .563 .706 r
.50909 .81531 m .51266 .81464 L .5096 .81439 L F
.587 .604 .836 r
.67961 .47954 m .68344 .48051 L .68192 .4791 L F
0 0 0 r
.68192 .4791 m .67935 .48042 L .67961 .47954 L F
.052 .235 .732 r
.24989 .67342 m .25019 .67371 L .25009 .67389 L F
.694 .97 .755 r
.25009 .67389 m .25019 .67371 L .24985 .67402 L F
.846 .88 .865 r
.71852 .50816 m .71589 .5109 L .71483 .50949 L F
.312 0 .198 r
.53139 .77429 m .53191 .77218 L .53308 .77161 L F
.53139 .77429 m .52947 .77468 L .53191 .77218 L F
.557 .089 .099 r
.28557 .58398 m .28733 .58506 L .2891 .58365 L F
.108 0 0 r
.28733 .58506 m .29107 .5841 L .2891 .58365 L F
.301 .417 .813 r
.68562 .48149 m .68528 .47979 L .68344 .48051 L F
.449 0 0 r
.51915 .64809 m .52315 .64934 L .52041 .6496 L F
0 0 .358 r
.61059 .51336 m .61205 .51202 L .61219 .50977 L F
.445 .256 .529 r
.60993 .51487 m .61205 .51202 L .61059 .51336 L F
.981 .844 .633 r
.66295 .51319 m .66262 .51675 L .66371 .51658 L F
.813 .679 .716 r
.66262 .51675 m .66383 .51832 L .66371 .51658 L F
.833 .788 .809 r
.66295 .51319 m .66371 .51658 L .66636 .5129 L F
.702 .801 .926 r
.70485 .47435 m .70149 .47402 L .70381 .4731 L F
.472 .805 .999 r
.53621 .78601 m .53849 .78644 L .53744 .7833 L F
.206 .289 .729 r
.53744 .7833 m .53849 .78644 L .54004 .78635 L F
.193 .076 .483 r
.54004 .78635 m .53849 .78644 L .53847 .78931 L F
.522 .33 .561 r
.56708 .70206 m .56919 .70388 L .56943 .70162 L F
.56708 .70206 m .56718 .70462 L .56919 .70388 L F
.895 .96 .626 r
.56908 .76664 m .56733 .76872 L .56769 .76991 L F
.56908 .76664 m .5687 .7663 L .56733 .76872 L F
.99 .857 .611 r
.56908 .76664 m .56891 .76142 L .5687 .7663 L F
.318 .711 .98 r
.53974 .79972 m .53993 .8006 L .53757 .79962 L F
0 0 .539 r
.54032 .80102 m .53993 .8006 L .53974 .79972 L F
.049 0 0 r
.51507 .69305 m .51381 .69481 L .51668 .69288 L F
.803 .319 .049 r
.55086 .61806 m .55205 .61978 L .54993 .61885 L F
.751 .401 .39 r
.57252 .72143 m .57175 .7211 L .57035 .71917 L F
.35 .406 .779 r
.75134 .59505 m .75253 .59867 L .75399 .59692 L F
.538 .688 .936 r
.75253 .59867 m .75521 .59837 L .75399 .59692 L F
.776 .599 .659 r
.50496 .78329 m .50847 .78358 L .50756 .78115 L F
0 0 0 r
.50945 .77771 m .50756 .78115 L .50974 .78031 L F
0 .127 .65 r
.50756 .78115 m .50933 .78251 L .50974 .78031 L F
.50756 .78115 m .50847 .78358 L .50933 .78251 L F
.419 .148 .393 r
.36864 .61679 m .36906 .61487 L .37116 .61427 L F
.871 .81 .787 r
.72421 .48327 m .72136 .4848 L .72355 .48188 L F
.636 .747 .928 r
.72355 .48188 m .72652 .48268 L .72421 .48327 L F
.804 .918 .915 r
.56176 .77393 m .55947 .77481 L .56151 .77215 L F
.727 .624 .743 r
.5452 .60338 m .54659 .60698 L .54294 .60623 L F
.847 .841 .838 r
.68488 .53457 m .68836 .53318 L .68723 .53332 L F
.244 .423 .84 r
.68836 .53318 m .68997 .53214 L .68723 .53332 L F
.68836 .53318 m .69063 .53446 L .68997 .53214 L F
.516 .337 .578 r
.29032 .61711 m .2903 .62181 L .28779 .62104 L F
.373 .351 .706 r
.29006 .62257 m .28779 .62104 L .2903 .62181 L F
.29006 .62257 m .2886 .62285 L .28779 .62104 L F
.62 .948 .766 r
.47084 .63744 m .47176 .63625 L .47246 .63611 L F
.619 .955 .809 r
.47084 .63744 m .46892 .63821 L .47176 .63625 L F
.288 0 0 r
.45775 .6995 m .45636 .70075 L .45412 .70095 L F
.475 0 0 r
.45979 .70029 m .45636 .70075 L .45775 .6995 L F
.266 0 0 r
.43746 .64902 m .43943 .64917 L .44077 .64809 L F
0 0 0 r
.44077 .64809 m .44192 .64783 L .44301 .64719 L F
.463 .118 .294 r
.43943 .64917 m .44192 .64783 L .44077 .64809 L F
.739 .844 .929 r
.52137 .66116 m .51946 .6622 L .5224 .66231 L F
.894 .989 .763 r
.77342 .60066 m .77024 .60381 L .77249 .59978 L F
.21 0 0 r
.77249 .59978 m .77618 .59811 L .77342 .60066 L F
.307 .75 .964 r
.77342 .60066 m .77651 .60059 L .77496 .60254 L F
.788 .575 .613 r
.56189 .70667 m .56411 .70494 L .56148 .70489 L F
.763 .857 .92 r
.6941 .52393 m .69173 .52405 L .69373 .52303 L F
.918 .952 .8 r
.69538 .52058 m .6941 .52393 L .69373 .52303 L F
.885 .633 .551 r
.53738 .62041 m .53465 .62147 L .53578 .6195 L F
.53738 .62041 m .53738 .62278 L .53465 .62147 L F
.769 .533 .577 r
.54089 .62307 m .53738 .62278 L .53738 .62041 L F
.533 .288 .49 r
.5812 .60644 m .58103 .60856 L .57867 .60891 L F
.517 .273 .483 r
.58342 .60605 m .58103 .60856 L .5812 .60644 L F
.543 .578 .839 r
.57217 .71769 m .57252 .72143 L .57035 .71917 L F
.661 .668 .846 r
.57568 .71891 m .57252 .72143 L .57217 .71769 L F
.577 .307 .47 r
.58669 .60327 m .5859 .60583 L .58342 .60605 L F
.55 .261 .429 r
.58902 .60321 m .5859 .60583 L .58669 .60327 L F
.767 .719 .808 r
.7605 .58124 m .7627 .58036 L .76287 .5806 L F
.792 .571 .601 r
.53008 .76598 m .53357 .76639 L .53406 .76407 L F
.708 .656 .796 r
.5423 .61242 m .53844 .61182 L .54098 .61181 L F
.944 .958 .731 r
.72754 .51518 m .72915 .51406 L .72789 .51279 L F
.72754 .51518 m .72824 .51579 L .72915 .51406 L F
.89 .599 .489 r
.26046 .64832 m .26216 .64944 L .25898 .64864 L F
.536 .337 .559 r
.3848 .7044 m .3873 .70149 L .38517 .70201 L F
.345 .666 .974 r
.32105 .58721 m .31893 .58722 L .31753 .58595 L F
.879 .86 .818 r
.28778 .7388 m .29001 .7358 L .28842 .73503 L F
.544 .492 .748 r
.71374 .48793 m .71431 .49104 L .71652 .49031 L F
0 .213 .692 r
.71431 .49104 m .71667 .49269 L .71456 .49077 L F
.879 .521 .365 r
.71667 .49269 m .71597 .49368 L .71474 .49113 L F
.71489 .49106 m .71474 .49113 L .71456 .49077 L F
.71667 .49269 m .71474 .49113 L .71489 .49106 L F
0 .213 .692 r
.71627 .49039 m .71619 .49055 L .71652 .49031 L F
.71431 .49104 m .71568 .49068 L .71627 .49039 L F
.71568 .49068 m .71619 .49055 L .71627 .49039 L F
.71431 .49104 m .71456 .49077 L .71619 .49055 L F
.748 .683 .789 r
.37549 .70214 m .37952 .70238 L .37843 .69928 L F
.638 .266 .321 r
.53372 .76856 m .53703 .76693 L .53357 .76639 L F
.53372 .76856 m .5361 .76912 L .53703 .76693 L F
.599 .225 .304 r
.53703 .76693 m .5361 .76912 L .5392 .76849 L F
.566 .252 .395 r
.53703 .76693 m .5392 .76849 L .53918 .76685 L F
.035 .577 .845 r
.49854 .64328 m .49739 .64284 L .49512 .64253 L F
.628 .9 .986 r
.49959 .6418 m .49854 .64328 L .50065 .6425 L F
.641 .919 .978 r
.49959 .6418 m .49739 .64284 L .49854 .64328 L F
.544 .339 .552 r
.47814 .65875 m .48055 .65656 L .47793 .65698 L F
.749 .673 .777 r
.48055 .65656 m .47814 .65875 L .47793 .65698 L F
.565 .152 .218 r
.6182 .53322 m .61455 .53359 L .61804 .53315 L F
.666 .341 .413 r
.62043 .53469 m .61705 .53675 L .6182 .53322 L F
.639 .128 .016 r
.61804 .53315 m .62043 .53469 L .6182 .53322 L F
.614 .259 .345 r
.62061 .53331 m .62043 .53469 L .61804 .53315 L F
.843 .92 .884 r
.72493 .51712 m .72824 .51579 L .72754 .51518 L F
.421 .112 .334 r
.48179 .78839 m .48013 .78696 L .4788 .78793 L F
.48179 .78839 m .48232 .78668 L .48013 .78696 L F
.277 0 .152 r
.53344 .77357 m .53308 .77161 L .53452 .77266 L F
.53344 .77357 m .53139 .77429 L .53308 .77161 L F
.404 .236 .538 r
.61301 .56636 m .61483 .56329 L .61333 .56436 L F
.634 .697 .89 r
.67816 .51353 m .67557 .51438 L .67439 .51251 L F
.749 .673 .777 r
.48055 .65656 m .4812 .65949 L .47814 .65875 L F
.349 0 0 r
.4812 .65949 m .4802 .65944 L .47814 .65875 L F
.213 .299 .736 r
.48055 .65656 m .48293 .65913 L .4812 .65949 L F
.046 0 0 r
.48293 .65913 m .4802 .65944 L .4812 .65949 L F
.269 .773 .856 r
.71261 .48455 m .71212 .4844 L .70967 .48485 L F
.368 .013 .224 r
.33264 .62727 m .33548 .62548 L .33338 .62599 L F
.47 .291 .555 r
.48698 .64558 m .48569 .6491 L .48512 .64839 L F
.007 0 0 r
.48569 .6491 m .48338 .64997 L .48512 .64839 L F
.393 0 0 r
.50576 .76311 m .50815 .76289 L .50931 .76151 L F
.275 0 0 r
.50931 .76151 m .50815 .76289 L .51089 .76208 L F
.641 .534 .717 r
.50413 .64299 m .50472 .64641 L .50751 .64591 L F
0 .508 .808 r
.52518 .64846 m .52765 .64915 L .52775 .64927 L F
.704 .614 .753 r
.49249 .63084 m .48916 .62849 L .49128 .62843 L F
.687 .721 .876 r
.49479 .62908 m .49249 .63084 L .49128 .62843 L F
.784 .588 .634 r
.49342 .78586 m .49697 .78615 L .49711 .78365 L F
.726 .396 .42 r
.49939 .78582 m .49711 .78365 L .49697 .78615 L F
.503 .317 .56 r
.29262 .61454 m .29244 .61677 L .29032 .61711 L F
.313 .178 .531 r
.29158 .62009 m .29032 .61711 L .29244 .61677 L F
.29158 .62009 m .2903 .62181 L .29032 .61711 L F
.982 .728 .47 r
.58593 .57811 m .58445 .57452 L .58298 .57743 L F
.851 .68 .669 r
.58439 .58072 m .58593 .57811 L .58298 .57743 L F
.753 .78 .875 r
.75521 .59837 m .75889 .59863 L .75757 .59753 L F
.566 .507 .748 r
.75916 .59747 m .75889 .59863 L .75801 .59516 L F
.93 .877 .763 r
.75757 .59753 m .75889 .59863 L .75916 .59747 L F
.371 .104 .373 r
.25953 .63696 m .26123 .63658 L .26248 .63416 L F
.475 .308 .573 r
.25934 .64006 m .26123 .63658 L .25953 .63696 L F
.754 .417 .414 r
.5476 .79163 m .54408 .78821 L .54523 .79202 L F
.5476 .79163 m .54744 .78995 L .54408 .78821 L F
.637 .578 .772 r
.5467 .79764 m .54321 .79485 L .54578 .79538 L F
.587 .709 .928 r
.54311 .80018 m .54572 .79997 L .54455 .79876 L F
.54391 .7988 m .54455 .79876 L .54417 .79837 L F
.54311 .80018 m .54455 .79876 L .54391 .7988 L F
.565 .261 .411 r
.54427 .79878 m .54578 .79538 L .54321 .79485 L F
.54431 .79895 m .54438 .79877 L .54427 .79878 L F
.54438 .79877 m .54578 .79538 L .54427 .79878 L F
.679 .744 .9 r
.50065 .6425 m .50413 .64299 L .50419 .6423 L F
.484 .569 .866 r
.50413 .64299 m .50589 .64171 L .50419 .6423 L F
.50413 .64299 m .50614 .64281 L .50589 .64171 L F
.641 .534 .717 r
.50413 .64299 m .50751 .64591 L .50614 .64281 L F
.789 .724 .792 r
.71484 .50514 m .71089 .50615 L .71372 .50433 L F
.04 .092 .59 r
.71565 .50223 m .71484 .50514 L .71372 .50433 L F
.71565 .50223 m .71557 .50693 L .71484 .50514 L F
.607 .606 .824 r
.52078 .66778 m .52227 .67136 L .52371 .67046 L F
.428 .141 .373 r
.34733 .61208 m .3493 .61174 L .35009 .60909 L F
.448 .411 .725 r
.35009 .60909 m .35125 .60563 L .34945 .606 L F
.35009 .60909 m .35197 .60837 L .35125 .60563 L F
.404 .119 .363 r
.35009 .60909 m .3516 .61063 L .35197 .60837 L F
.35009 .60909 m .3493 .61174 L .3516 .61063 L F
.879 .826 .791 r
.53688 .60852 m .53409 .60856 L .53617 .60592 L F
.53688 .60852 m .53572 .60952 L .53409 .60856 L F
.728 .789 .901 r
.53966 .60616 m .53688 .60852 L .53617 .60592 L F
.43 .217 .487 r
.29721 .60897 m .29688 .61123 L .29497 .61158 L F
.407 .193 .473 r
.29688 .61123 m .29458 .6141 L .29497 .61158 L F
.88 .992 .756 r
.72926 .49889 m .7301 .4992 L .72893 .4979 L F
.72926 .49889 m .7294 .49958 L .7301 .4992 L F
.489 .354 .623 r
.25158 .60267 m .25344 .59998 L .25204 .60089 L F
.949 .912 .538 r
.62081 .55208 m .62143 .54807 L .62217 .5502 L F
.517 .679 .939 r
.69503 .48157 m .69703 .4803 L .69329 .47995 L F
.69503 .48157 m .69714 .48133 L .69703 .4803 L F
.918 .878 .78 r
.70288 .48401 m .70398 .48516 L .70588 .48273 L F
.673 .29 .313 r
.24969 .67369 m .25019 .67371 L .24989 .67342 L F
.6 .191 .24 r
.48652 .69618 m .4852 .6981 L .48318 .69672 L F
.641 .239 .266 r
.48859 .69788 m .4852 .6981 L .48652 .69618 L F
.612 .26 .349 r
.48904 .69669 m .48859 .69788 L .48652 .69618 L F
.644 .592 .781 r
.66761 .52118 m .66849 .52408 L .67101 .52315 L F
.883 .665 .602 r
.63657 .54093 m .6385 .54419 L .63839 .54167 L F
.992 .741 .393 r
.56755 .75214 m .56827 .75544 L .56915 .75263 L F
.286 .654 .969 r
.40098 .65629 m .39902 .65599 L .39792 .65469 L F
.652 .374 .485 r
.39792 .65469 m .39803 .65675 L .40098 .65629 L F
.642 .527 .708 r
.56492 .61433 m .56274 .61725 L .56257 .61492 L F
.708 .177 0 r
.51753 .76464 m .519 .76588 L .52011 .76584 L F
.259 0 0 r
.52011 .76584 m .519 .76588 L .52214 .76619 L F
.766 .258 0 r
.54397 .62998 m .54127 .62761 L .54203 .62932 L F
.711 .62 .754 r
.56064 .61799 m .56039 .62042 L .55827 .62013 L F
.722 .463 .535 r
.56039 .62042 m .56044 .62276 L .55827 .62013 L F
.734 .641 .756 r
.56274 .61725 m .56039 .62042 L .56064 .61799 L F
.656 .53 .698 r
.56322 .62015 m .56039 .62042 L .56274 .61725 L F
.623 .385 .536 r
.56459 .62133 m .56039 .62042 L .56322 .62015 L F
.56459 .62133 m .56044 .62276 L .56039 .62042 L F
.565 .152 .218 r
.6182 .53322 m .61489 .53473 L .61455 .53359 L F
.672 .318 .365 r
.6182 .53322 m .61705 .53675 L .61489 .53473 L F
.814 .845 .873 r
.78408 .5974 m .78667 .59728 L .78671 .59494 L F
.897 .904 .822 r
.78671 .59494 m .78667 .59728 L .78887 .59411 L F
.968 .923 .697 r
.65215 .49263 m .65276 .49378 L .65302 .49174 L F
.883 .644 .122 r
.65251 .4948 m .65276 .49378 L .65215 .49263 L F
.65251 .4948 m .65295 .49602 L .65276 .49378 L F
.392 0 0 r
.49271 .7986 m .4903 .79751 L .49059 .79926 L F
0 .18 .701 r
.49108 .79931 m .49059 .79926 L .4903 .79751 L F
.019 0 .281 r
.4901 .80298 m .49059 .79926 L .49108 .79931 L F
.262 0 0 r
.44954 .70141 m .4482 .70289 L .44609 .7032 L F
.328 0 0 r
.45187 .70122 m .4482 .70289 L .44954 .70141 L F
.676 .791 .935 r
.4716 .64818 m .47343 .65024 L .47596 .64875 L F
.674 .792 .938 r
.47343 .65024 m .47602 .64915 L .47596 .64875 L F
.825 .461 0 r
.71962 .50201 m .71802 .49832 L .71903 .49935 L F
.852 .647 .624 r
.58713 .58371 m .58439 .58072 L .58408 .58312 L F
.808 .59 .608 r
.58403 .58569 m .58713 .58371 L .58408 .58312 L F
.58403 .58569 m .58694 .58631 L .58713 .58371 L F
.604 .271 .378 r
.256 .65171 m .25044 .65388 L .25144 .65141 L F
.256 .65171 m .25354 .65404 L .25044 .65388 L F
.693 .849 .958 r
.25515 .65015 m .256 .65171 L .25675 .65084 L F
0 0 0 r
.25637 .65191 m .256 .65171 L .25515 .65015 L F
.25637 .65191 m .25354 .65404 L .256 .65171 L F
.54885 .61978 m .54653 .62254 L .5482 .62054 L F
.236 .736 .904 r
.32501 .58779 m .32709 .58756 L .328 .58782 L F
0 .407 .708 r
.32709 .58756 m .33055 .58865 L .328 .58782 L F
.448 .065 .218 r
.4293 .66997 m .42802 .66883 L .43104 .66764 L F
.4293 .66997 m .42639 .67047 L .42802 .66883 L F
.86 .743 .733 r
.73681 .51333 m .73371 .51318 L .73471 .51163 L F
.73681 .51333 m .73445 .5159 L .73371 .51318 L F
.72 .509 .603 r
.73681 .51333 m .73721 .51601 L .73445 .5159 L F
.452 .241 .502 r
.73935 .51055 m .73915 .51267 L .73681 .51333 L F
.458 .326 .613 r
.73935 .51514 m .73681 .51333 L .73915 .51267 L F
.73935 .51514 m .73721 .51601 L .73681 .51333 L F
.986 .897 .58 r
.63522 .55387 m .63667 .55269 L .63525 .55223 L F
.63522 .55387 m .6359 .55492 L .63667 .55269 L F
.931 .844 .736 r
.63667 .55269 m .63619 .54969 L .63525 .55223 L F
.473 .139 .318 r
.2599 .59385 m .26323 .59127 L .26141 .59218 L F
.204 0 .076 r
.58664 .69259 m .58661 .69279 L .58785 .69066 L F
.357 0 .061 r
.5467 .79764 m .54782 .79908 L .54572 .79997 L F
.5467 .79764 m .54905 .79732 L .54782 .79908 L F
.486 .439 .731 r
.55355 .72203 m .55541 .72128 L .55485 .71813 L F
.451 .35 .649 r
.55355 .72203 m .5559 .724 L .55541 .72128 L F
.275 .51 .9 r
.36829 .59353 m .36759 .59491 L .36567 .59257 L F
.382 .643 .959 r
.36829 .59353 m .36967 .59503 L .36759 .59491 L F
.554 .595 .85 r
.71596 .47409 m .7126 .47138 L .71478 .4731 L F
.09 .648 .776 r
.50141 .77851 m .50304 .77829 L .49997 .77812 L F
.50141 .77851 m .50408 .77841 L .50304 .77829 L F
.528 .439 .699 r
.50886 .80344 m .50683 .80369 L .50651 .80032 L F
.628 .418 .579 r
.59138 .60067 m .59142 .60327 L .58902 .60321 L F
.671 .484 .624 r
.59494 .60099 m .59142 .60327 L .59138 .60067 L F
.96 .792 .629 r
.54089 .62307 m .53876 .62503 L .53738 .62278 L F
.54089 .62307 m .54003 .6263 L .53876 .62503 L F
.468 .477 .784 r
.51239 .65415 m .51331 .65053 L .5116 .65094 L F
.51239 .65415 m .51435 .65392 L .51331 .65053 L F
.562 .451 .685 r
.51239 .65415 m .51506 .65644 L .51435 .65392 L F
.51239 .65415 m .51287 .65697 L .51506 .65644 L F
.239 0 .082 r
.33993 .64121 m .33911 .63984 L .34132 .63919 L F
.33993 .64121 m .33791 .64194 L .33911 .63984 L F
.485 .116 .264 r
.5392 .76849 m .54262 .76579 L .53918 .76685 L F
.5392 .76849 m .5416 .76838 L .54262 .76579 L F
.59 .219 .307 r
.54262 .76579 m .54642 .76757 L .54502 .76599 L F
.54262 .76579 m .5416 .76838 L .54642 .76757 L F
.36 .504 .867 r
.65582 .51963 m .65769 .5179 L .65515 .51756 L F
.65582 .51963 m .65845 .52063 L .65769 .5179 L F
.98 .757 .53 r
.55963 .71003 m .56063 .71331 L .55938 .71249 L F
.396 .376 .72 r
.51287 .65697 m .51334 .6601 L .51492 .65829 L F
.478 .498 .8 r
.51334 .6601 m .51581 .65993 L .51492 .65829 L F
.893 .988 .742 r
.62081 .55208 m .62032 .55301 L .62042 .55144 L F
.897 .855 .404 r
.62032 .55301 m .61969 .55336 L .62042 .55144 L F
.62032 .55301 m .61969 .55529 L .61969 .55336 L F
.993 .774 .5 r
.51489 .79991 m .51559 .80344 L .5145 .80252 L F
.977 .675 .335 r
.5145 .80252 m .51559 .80344 L .51501 .805 L F
0 .412 .821 r
.5145 .80252 m .51559 .80344 L .51489 .79991 L F
.5145 .80252 m .51738 .8042 L .51559 .80344 L F
.805 .348 .15 r
.51805 .80533 m .51501 .805 L .51559 .80344 L F
.645 .733 .913 r
.69058 .52252 m .68942 .52486 L .68819 .52321 L F
.69058 .52252 m .69173 .52405 L .68942 .52486 L F
.647 .21 .198 r
.48116 .69585 m .47959 .69648 L .47738 .69576 L F
.436 0 0 r
.48318 .69672 m .47959 .69648 L .48116 .69585 L F
.868 .851 .392 r
.51274 .76538 m .51225 .76736 L .51257 .76743 L F
.503 .05 .109 r
.51257 .76743 m .51193 .76865 L .50925 .76839 L F
.868 .851 .392 r
.51225 .76736 m .51193 .76865 L .51257 .76743 L F
.181 0 0 r
.5128 .76748 m .51257 .76743 L .51039 .76688 L F
.51327 .76759 m .51257 .76743 L .5128 .76748 L F
.211 .428 .854 r
.51327 .76759 m .51477 .76669 L .51257 .76743 L F
.51327 .76759 m .51606 .76944 L .51477 .76669 L F
.648 .141 .03 r
.58343 .69222 m .58295 .69051 L .58179 .69286 L F
.5864 .69256 m .58664 .69259 L .5862 .69234 L F
.707 .247 .157 r
.58343 .69222 m .58661 .69279 L .58664 .69259 L F
.577 .005 0 r
.58768 .69393 m .58672 .69291 L .58555 .69149 L F
.08 .281 .766 r
.58661 .69279 m .58875 .69446 L .58796 .69558 L F
.577 .005 0 r
.58768 .69393 m .58875 .69446 L .58661 .69279 L F
.58672 .69291 m .58661 .69279 L .58658 .69276 L F
.58672 .69291 m .58658 .69276 L .58555 .69149 L F
0 0 .364 r
.58179 .69286 m .5827 .69444 L .58343 .69222 L F
.996 .86 .538 r
.58343 .69222 m .5827 .69444 L .58213 .69363 L F
.723 .445 .505 r
.58213 .69363 m .58284 .69318 L .58343 .69222 L F
.648 .141 .03 r
.58343 .69222 m .5864 .69256 L .58406 .69117 L F
.5864 .69256 m .5862 .69234 L .58295 .69051 L F
.594 .806 .981 r
.58343 .69222 m .58555 .69149 L .58661 .69279 L F
.58343 .69222 m .58555 .69149 L .58661 .69279 L F
.723 .445 .505 r
.58284 .69318 m .58555 .69149 L .58343 .69222 L F
.648 .141 .03 r
.58343 .69222 m .58406 .69117 L .58295 .69051 L F
.635 .312 .407 r
.55827 .62013 m .55671 .62232 L .55476 .62051 L F
.753 .462 .49 r
.55827 .62013 m .56044 .62276 L .55671 .62232 L F
.409 .22 .511 r
.34516 .61452 m .34744 .6139 L .34733 .61208 L F
.532 .34 .566 r
.3449 .61686 m .34744 .6139 L .34516 .61452 L F
.988 .809 .573 r
.2554 .62068 m .25446 .62009 L .25521 .61767 L F
.191 .385 .825 r
.2554 .62068 m .25655 .61946 L .25446 .62009 L F
.2554 .62068 m .25838 .62276 L .25655 .61946 L F
.464 .145 .34 r
.61338 .59251 m .61408 .59458 L .61042 .59508 L F
.585 .211 .299 r
.61553 .59399 m .61408 .59458 L .61338 .59251 L F
.466 .283 .548 r
.61549 .59163 m .61553 .59399 L .61338 .59251 L F
.514 .372 .625 r
.39109 .6652 m .39302 .66178 L .3911 .66231 L F
.34 .336 .71 r
.29063 .6245 m .28925 .62644 L .2886 .62285 L F
.481 .528 .829 r
.29063 .6245 m .29185 .62735 L .28925 .62644 L F
.755 .718 .818 r
.64301 .50404 m .64588 .50552 L .64673 .50224 L F
.859 .583 .519 r
.64301 .50404 m .64538 .50771 L .64588 .50552 L F
.932 .97 .724 r
.64588 .50552 m .64749 .50055 L .64673 .50224 L F
.625 .521 .715 r
.64302 .50172 m .64673 .50224 L .64593 .50025 L F
.755 .718 .818 r
.64301 .50404 m .64673 .50224 L .64302 .50172 L F
.354 .368 .737 r
.64593 .50025 m .64673 .50224 L .64749 .50055 L F
.932 .97 .724 r
.64588 .50552 m .64451 .50569 L .64749 .50055 L F
.887 .701 .646 r
.64654 .50678 m .64451 .50569 L .64588 .50552 L F
.468 .059 .181 r
.49214 .69571 m .48859 .69788 L .48904 .69669 L F
.49214 .69571 m .49097 .69781 L .48859 .69788 L F
.021 .231 .737 r
.4915 .69405 m .49318 .69528 L .49214 .69571 L F
.652 .496 .66 r
.49471 .6969 m .49097 .69781 L .49318 .69528 L F
.386 0 0 r
.49169 .6947 m .49468 .69638 L .49318 .69528 L F
.159 .36 .813 r
.49318 .69528 m .49561 .69689 L .49471 .6969 L F
.386 0 0 r
.49468 .69638 m .49561 .69689 L .49318 .69528 L F
.021 .231 .737 r
.49107 .69297 m .49318 .69528 L .4915 .69405 L F
.327 0 0 r
.45504 .69235 m .45743 .69215 L .45883 .69075 L F
.472 .305 .573 r
.46088 .6877 m .45883 .69075 L .46091 .6901 L F
.587 .113 .096 r
.45883 .69075 m .46092 .69218 L .46091 .6901 L F
.45883 .69075 m .45743 .69215 L .46092 .69218 L F
.919 .969 .672 r
.59729 .55606 m .59891 .55291 L .59744 .55392 L F
.919 .97 .676 r
.59729 .55606 m .59575 .55728 L .59619 .55777 L F
.59729 .55606 m .59744 .55392 L .59575 .55728 L F
.771 .318 .172 r
.55476 .62051 m .55345 .62167 L .55205 .61978 L F
.717 .244 .125 r
.55476 .62051 m .55671 .62232 L .55345 .62167 L F
.541 .206 .35 r
.44138 .69559 m .44468 .6931 L .44178 .69377 L F
.44138 .69559 m .44368 .69558 L .44468 .6931 L F
.556 .221 .357 r
.44468 .6931 m .44706 .69443 L .44683 .69273 L F
.44468 .6931 m .44368 .69558 L .44706 .69443 L F
.071 .093 .576 r
.25061 .62763 m .25017 .63131 L .24896 .63098 L F
.305 0 0 r
.25017 .63131 m .24945 .63098 L .24896 .63098 L F
.25017 .63131 m .25102 .63172 L .24945 .63098 L F
.551 .837 .998 r
.50723 .69907 m .50393 .69877 L .50601 .69809 L F
.825 .557 .534 r
.50723 .69907 m .50387 .70018 L .50393 .69877 L F
.50723 .69907 m .50726 .70158 L .50387 .70018 L F
.764 .91 .939 r
.5096 .69714 m .50723 .69907 L .50601 .69809 L F
.72 .47 .547 r
.51069 .70105 m .50726 .70158 L .50723 .69907 L F
.795 .711 .771 r
.66658 .48084 m .67041 .48202 L .66931 .47903 L F
.66658 .48084 m .66829 .48224 L .67041 .48202 L F
.324 .574 .931 r
.67041 .48202 m .67198 .47998 L .66931 .47903 L F
.338 0 .044 r
.67427 .48073 m .67523 .48226 L .67041 .48202 L F
.324 .574 .931 r
.67041 .48202 m .67523 .48226 L .67198 .47998 L F
.014 .213 .722 r
.48571 .64233 m .48698 .64558 L .48923 .6429 L F
.48571 .64233 m .48778 .64408 L .48698 .64558 L F
0 0 0 r
.48742 .64569 m .48698 .64558 L .48778 .64408 L F
.48742 .64569 m .48569 .6491 L .48698 .64558 L F
.644 .766 .937 r
.69928 .47501 m .69572 .47434 L .69808 .47354 L F
.678 .783 .929 r
.70149 .47402 m .69928 .47501 L .69808 .47354 L F
.214 0 .273 r
.26248 .63416 m .26123 .63658 L .26296 .63578 L F
.583 .496 .722 r
.38769 .67453 m .39053 .67616 L .38971 .67316 L F
.38769 .67453 m .38825 .67657 L .39053 .67616 L F
.55 .256 .421 r
.50683 .80369 m .50654 .80563 L .50406 .80584 L F
.319 .061 .357 r
.50854 .80494 m .50683 .80369 L .50886 .80344 L F
.50854 .80494 m .50654 .80563 L .50683 .80369 L F
.898 .8 .744 r
.54949 .59764 m .54628 .59964 L .54797 .59657 L F
.54949 .59764 m .54775 .60078 L .54628 .59964 L F
.827 .835 .854 r
.55206 .59484 m .54949 .59764 L .54797 .59657 L F
.491 .278 .518 r
.52628 .69055 m .52601 .69355 L .52385 .69381 L F
.537 .317 .528 r
.52808 .69121 m .52628 .69055 L .52825 .69003 L F
.52808 .69121 m .52601 .69355 L .52628 .69055 L F
.547 .097 .134 r
.52153 .8034 m .51738 .8042 L .5192 .80348 L F
0 0 0 r
.51805 .80533 m .52153 .8034 L .5192 .80348 L F
.216 .739 .828 r
.52283 .80297 m .52153 .8034 L .5192 .80348 L F
.52283 .80297 m .52375 .80306 L .52153 .8034 L F
.52153 .8034 m .52283 .80297 L .5192 .80348 L F
.52153 .8034 m .52375 .80306 L .52283 .80297 L F
.241 0 0 r
.32348 .58709 m .32709 .58756 L .32501 .58779 L F
.623 .215 0 r
.66551 .51149 m .66636 .5129 L .66458 .50991 L F
.833 .788 .809 r
.66295 .51319 m .66636 .5129 L .66551 .51149 L F
.414 .682 .972 r
.66636 .5129 m .66551 .51149 L .66458 .50991 L F
.66636 .5129 m .66842 .51287 L .66551 .51149 L F
.625 .505 .696 r
.76276 .57896 m .7605 .58124 L .76287 .5806 L F
.568 .394 .606 r
.25344 .59998 m .25577 .59708 L .25401 .59791 L F
.671 .803 .945 r
.53829 .77727 m .53984 .77856 L .54179 .77759 L F
.53829 .77727 m .53984 .77856 L .54179 .77759 L F
.651 .416 .55 r
.60262 .59742 m .59932 .59997 L .59946 .59808 L F
.605 .068 0 r
.59458 .70167 m .59758 .70429 L .59624 .70183 L F
.957 .948 .698 r
.70037 .52909 m .69892 .5321 L .69964 .53256 L F
.877 .948 .854 r
.54069 .7531 m .54075 .75464 L .53919 .75458 L F
.54069 .7531 m .54263 .75255 L .54075 .75464 L F
.739 .273 .141 r
.54284 .75571 m .53919 .75458 L .54075 .75464 L F
.617 .45 .634 r
.54263 .75255 m .54284 .75571 L .54075 .75464 L F
.092 0 0 r
.42399 .6964 m .426 .69658 L .42782 .69663 L F
.233 .75 .837 r
.426 .69658 m .42995 .69628 L .42782 .69663 L F
.091 0 0 r
.30099 .58399 m .30052 .58389 L .2988 .58421 L F
.30099 .58399 m .30268 .58412 L .30052 .58389 L F
.696 .64 .789 r
.68456 .52028 m .68227 .51968 L .68397 .5196 L F
.305 .529 .905 r
.68721 .52039 m .68456 .52028 L .68397 .5196 L F
.763 .727 .82 r
.48923 .6429 m .49276 .64349 L .49159 .64227 L F
.725 .711 .837 r
.49159 .64227 m .49276 .64349 L .49512 .64253 L F
.897 .904 .822 r
.78671 .59494 m .78887 .59411 L .78702 .59239 L F
.837 .745 .762 r
.64765 .51012 m .6463 .51102 L .64452 .50978 L F
.621 .327 .449 r
.64765 .51012 m .64749 .51178 L .6463 .51102 L F
.833 .748 .77 r
.64782 .50943 m .64765 .51012 L .64654 .50678 L F
.457 .189 .418 r
.64905 .51128 m .64749 .51178 L .64765 .51012 L F
.415 .722 .988 r
.73934 .52407 m .7405 .52286 L .73844 .52244 L F
.73934 .52407 m .74141 .52392 L .7405 .52286 L F
.73934 .52407 m .7405 .52286 L .73844 .52244 L F
.73934 .52407 m .74141 .52392 L .7405 .52286 L F
.846 .88 .865 r
.71852 .50816 m .71483 .50949 L .71702 .50683 L F
.517 .124 .234 r
.42347 .65266 m .42556 .65274 L .42377 .6515 L F
0 .326 .781 r
.52326 .79391 m .52364 .79475 L .52516 .79553 L F
.503 .05 .109 r
.51257 .76743 m .50925 .76839 L .51039 .76688 L F
.206 .289 .729 r
.53744 .7833 m .54004 .78635 L .53972 .78323 L F
.449 0 .051 r
.47147 .69687 m .4703 .69838 L .46797 .69836 L F
.284 0 0 r
.47265 .69783 m .47147 .69687 L .47475 .69756 L F
.47265 .69783 m .4703 .69838 L .47147 .69687 L F
.369 0 .056 r
.47559 .69558 m .47475 .69756 L .47147 .69687 L F
.85 .519 .427 r
.64718 .48631 m .64903 .48694 L .64873 .48513 L F
.531 .303 .513 r
.41698 .67374 m .41907 .67568 L .41669 .67612 L F
.607 .406 .583 r
.53882 .73812 m .53898 .7393 L .53899 .73929 L F
.97 .664 .376 r
.53899 .73931 m .54033 .74092 L .53913 .74031 L F
.53899 .73929 m .54033 .74092 L .53899 .73931 L F
.705 .639 .781 r
.54509 .74327 m .54269 .74208 L .54257 .74163 L F
.035 .172 .678 r
.54257 .74163 m .54269 .74208 L .54322 .74233 L F
.705 .639 .781 r
.54509 .74327 m .54333 .74456 L .54269 .74208 L F
.035 .172 .678 r
.54269 .74208 m .54333 .74456 L .54322 .74233 L F
.619 .257 .334 r
.54257 .74163 m .54322 .74233 L .54042 .74095 L F
.5404 .74094 m .54322 .74233 L .54033 .74092 L F
.97 .664 .376 r
.53899 .73929 m .53899 .73929 L .53899 .73931 L F
.53912 .73869 m .54033 .74092 L .53899 .73929 L F
.635 .554 .747 r
.54074 .7411 m .54283 .73695 L .53899 .73929 L F
.53899 .73931 m .53899 .73929 L .53898 .7393 L F
.54074 .7411 m .53899 .73929 L .53899 .73931 L F
.462 0 0 r
.54322 .74233 m .53967 .74058 L .53953 .74051 L F
.53967 .74058 m .53911 .7403 L .53929 .74039 L F
.53967 .74058 m .53929 .74039 L .53953 .74051 L F
.629 .41 .565 r
.53911 .7403 m .54143 .74181 L .54093 .74129 L F
.462 0 0 r
.53967 .74058 m .54045 .74103 L .53911 .7403 L F
.54186 .74167 m .53953 .74051 L .54033 .74092 L F
.629 .41 .565 r
.53911 .7403 m .54093 .74129 L .53899 .73931 L F
.462 0 0 r
.54322 .74233 m .53953 .74051 L .54186 .74167 L F
.54322 .74233 m .54262 .74226 L .54222 .74203 L F
.54129 .74138 m .54222 .74203 L .53967 .74058 L F
.54322 .74233 m .54222 .74203 L .54129 .74138 L F
.705 .639 .781 r
.54626 .74241 m .54509 .74327 L .54257 .74163 L F
0 0 0 r
.54253 .74224 m .54446 .74215 L .542 .74187 L F
.54253 .74224 m .542 .74187 L .54143 .74181 L F
.705 .639 .781 r
.54626 .74241 m .54257 .74163 L .54381 .74144 L F
.665 .699 .872 r
.54381 .74144 m .54626 .74241 L .5488 .74121 L F
.635 .554 .747 r
.54149 .74161 m .54446 .74215 L .54283 .73695 L F
.54143 .74181 m .542 .74187 L .54149 .74161 L F
.542 .74187 m .54446 .74215 L .54149 .74161 L F
.462 0 0 r
.54045 .74103 m .54112 .74142 L .53911 .7403 L F
.635 .554 .747 r
.54143 .74181 m .54149 .74161 L .54093 .74129 L F
.462 0 0 r
.54112 .74142 m .54253 .74224 L .54074 .74123 L F
.54112 .74142 m .54074 .74123 L .53911 .7403 L F
.54262 .74226 m .54253 .74224 L .53967 .74058 L F
.635 .554 .747 r
.54093 .74129 m .54153 .74148 L .54074 .7411 L F
.54149 .74161 m .54153 .74148 L .54093 .74129 L F
.54153 .74148 m .54283 .73695 L .54074 .7411 L F
.629 .41 .565 r
.53911 .7403 m .53899 .73931 L .53898 .7393 L F
.97 .664 .376 r
.53882 .73812 m .53912 .73869 L .53899 .73929 L F
.163 0 .184 r
.54179 .73604 m .53899 .73929 L .54283 .73695 L F
.53899 .73929 m .53898 .7393 L .53899 .73929 L F
.53899 .73929 m .53899 .73929 L .54283 .73695 L F
.607 .406 .583 r
.53882 .73812 m .53899 .73929 L .54179 .73604 L F
.629 .41 .565 r
.53911 .7403 m .53898 .7393 L .53882 .73812 L F
.97 .664 .376 r
.53882 .73812 m .53913 .74031 L .53911 .7403 L F
.473 .402 .696 r
.38825 .67657 m .39063 .67864 L .39053 .67616 L F
.38825 .67657 m .3889 .67926 L .39063 .67864 L F
.683 .862 .967 r
.65938 .5231 m .66299 .52257 L .66193 .52146 L F
.228 .173 .585 r
.74527 .48988 m .74564 .49229 L .74383 .49391 L F
.351 .373 .743 r
.74564 .49229 m .74486 .49606 L .74383 .49391 L F
.471 .74 .987 r
.30869 .63026 m .30808 .63168 L .30663 .63049 L F
.533 .808 .997 r
.30869 .63026 m .31017 .63121 L .30808 .63168 L F
.679 .914 .974 r
.29641 .64891 m .29394 .65004 L .2942 .64972 L F
.295 0 0 r
.29316 .58417 m .29683 .58407 L .29479 .58444 L F
.252 0 0 r
.78076 .59477 m .78329 .59456 L .784 .59329 L F
.782 .905 .927 r
.78512 .59106 m .784 .59329 L .78329 .59456 L F
.78512 .59106 m .78606 .59201 L .784 .59329 L F
.076 0 .014 r
.693 .51317 m .69273 .51344 L .6922 .51515 L F
.69273 .51344 m .69038 .51587 L .6922 .51515 L F
.967 .665 .399 r
.69178 .51652 m .6922 .51515 L .69189 .51699 L F
.69132 .51465 m .6922 .51515 L .69178 .51652 L F
.076 0 .014 r
.693 .51317 m .6922 .51515 L .69167 .51234 L F
.687 .329 .363 r
.6922 .51515 m .693 .51317 L .69167 .51234 L F
.145 .685 .828 r
.31759 .6489 m .31722 .64849 L .31605 .6487 L F
.31759 .6489 m .3199 .64878 L .31722 .64849 L F
.378 .835 .751 r
.449 .64592 m .44974 .6454 L .45117 .6453 L F
.449 .64592 m .44732 .64643 L .44974 .6454 L F
.86 .996 .777 r
.59891 .55291 m .60119 .55005 L .59932 .55094 L F
.867 .979 .683 r
.59891 .55291 m .59932 .55094 L .59744 .55392 L F
.469 .451 .755 r
.34945 .606 m .3504 .60222 L .34813 .60249 L F
.34945 .606 m .35125 .60563 L .3504 .60222 L F
.771 .756 .84 r
.71014 .5154 m .71149 .51702 L .7138 .51534 L F
.117 .627 .896 r
.33261 .58891 m .334 .58947 L .33055 .58865 L F
.425 .81 .99 r
.33511 .58857 m .334 .58947 L .33261 .58891 L F
.33511 .58857 m .33618 .58913 L .334 .58947 L F
.948 .798 .662 r
.6277 .52175 m .62531 .52295 L .62627 .52027 L F
.419 .093 .304 r
.59109 .58856 m .59379 .58647 L .59146 .58683 L F
.629 .287 .372 r
.41556 .65395 m .41195 .65602 L .41439 .65603 L F
.41556 .65395 m .4126 .65446 L .41195 .65602 L F
.361 0 .119 r
.41439 .65603 m .41784 .6537 L .41556 .65395 L F
.378 .077 .323 r
.35372 .63079 m .35171 .63133 L .35434 .6289 L F
.408 .104 .335 r
.3558 .63022 m .35434 .6289 L .35655 .62849 L F
.3558 .63022 m .35372 .63079 L .35434 .6289 L F
.584 .343 .518 r
.48416 .78313 m .48632 .78305 L .48467 .78095 L F
.48416 .78313 m .48632 .78305 L .48467 .78095 L F
.102 .648 .833 r
.514 .77741 m .51295 .77743 L .51173 .7772 L F
.007 .49 .869 r
.64583 .48325 m .64448 .48316 L .64426 .4814 L F
.64583 .48325 m .64787 .48424 L .64448 .48316 L F
.667 .382 .479 r
.52699 .78914 m .52935 .79159 L .52701 .79175 L F
0 .26 .766 r
.42228 .67314 m .4217 .67561 L .4228 .67375 L F
.518 .307 .533 r
.60983 .53871 m .61017 .54088 L .60786 .5414 L F
.409 .234 .53 r
.61193 .53765 m .61017 .54088 L .60983 .53871 L F
.718 .846 .411 r
.60197 .54815 m .60119 .55005 L .60301 .54647 L F
.148 0 .235 r
.6053 .54362 m .60455 .54633 L .60301 .54647 L F
.193 0 0 r
.60436 .54742 m .60301 .54647 L .60455 .54633 L F
.60436 .54742 m .60197 .54815 L .60301 .54647 L F
.869 .637 .106 r
.73456 .5075 m .73474 .51104 L .73436 .50884 L F
.73456 .5075 m .73436 .50884 L .73475 .5066 L F
.797 .735 .794 r
.54486 .75221 m .54284 .75571 L .54263 .75255 L F
.575 .186 .267 r
.54069 .7531 m .54486 .75221 L .54263 .75255 L F
.168 .088 .514 r
.47859 .77162 m .47869 .77417 L .47708 .77507 L F
.09 .03 .489 r
.47861 .77621 m .47708 .77507 L .47869 .77417 L F
.47861 .77621 m .47723 .77754 L .47708 .77507 L F
.59 .736 .945 r
.53017 .68628 m .53142 .68786 L .5282 .68712 L F
.639 .48 .651 r
.53109 .68955 m .5282 .68712 L .53142 .68786 L F
.519 .778 .991 r
.53286 .68626 m .53142 .68786 L .53017 .68628 L F
.53286 .68626 m .53384 .68757 L .53142 .68786 L F
.24 0 .09 r
.53384 .68757 m .53109 .68955 L .53142 .68786 L F
.497 .34 .598 r
.41669 .67612 m .41668 .67862 L .41462 .67668 L F
0 0 .342 r
.47782 .76553 m .47812 .76658 L .47703 .76359 L F
.747 .614 .046 r
.47782 .76553 m .47781 .76922 L .47812 .76658 L F
.735 .594 .698 r
.53844 .61182 m .53663 .61496 L .53485 .6115 L F
0 0 0 r
.38974 .70552 m .38884 .70676 L .38977 .70544 L F
.511 .616 .893 r
.75939 .59424 m .75801 .59516 L .75609 .59189 L F
.566 .507 .748 r
.75916 .59747 m .75801 .59516 L .75939 .59424 L F
.945 .789 .657 r
.55251 .59237 m .55206 .59484 L .55124 .5917 L F
0 0 0 r
.67275 .52709 m .67015 .53049 L .67182 .529 L F
.914 .921 .806 r
.68227 .51968 m .68071 .5221 L .68023 .52096 L F
.995 .842 .489 r
.68023 .52096 m .68071 .5221 L .68033 .52422 L F
.543 .578 .839 r
.57217 .71769 m .57035 .71917 L .56973 .71866 L F
.728 .668 .791 r
.24985 .67402 m .25019 .67371 L .24969 .67369 L F
.958 .721 .536 r
.24811 .67529 m .24985 .67402 L .24969 .67369 L F
.24811 .67529 m .24815 .67539 L .24985 .67402 L F
.859 .731 .721 r
.49302 .792 m .49147 .78829 L .4924 .79181 L F
.967 .749 .312 r
.49296 .79486 m .49302 .792 L .4924 .79181 L F
.475 .256 .501 r
.29889 .61065 m .29721 .60897 L .2993 .60845 L F
.29889 .61065 m .29688 .61123 L .29721 .60897 L F
.637 .48 .653 r
.50406 .80584 m .5018 .80852 L .50162 .80511 L F
.522 .557 .833 r
.48798 .81424 m .48932 .81727 L .49168 .81714 L F
.348 .479 .85 r
.58404 .71769 m .5835 .71881 L .58208 .71693 L F
.58404 .71769 m .58208 .71693 L .58246 .71665 L F
.58404 .71769 m .5813 .71588 L .58366 .71537 L F
0 0 0 r
.58193 .71763 m .5828 .71696 L .58331 .71601 L F
.58298 .71626 m .58331 .71601 L .58366 .71537 L F
.58193 .71763 m .58331 .71601 L .58298 .71626 L F
.348 .479 .85 r
.58246 .71665 m .58208 .71693 L .5813 .71588 L F
.592 .138 .142 r
.4759 .6975 m .47559 .69558 L .47738 .69576 L F
.4759 .6975 m .47475 .69756 L .47559 .69558 L F
.635 .178 .149 r
.25104 .66506 m .24881 .66633 L .24723 .66492 L F
0 0 .06 r
.25156 .66162 m .25104 .66506 L .24958 .66199 L F
.25156 .66162 m .25138 .66402 L .25104 .66506 L F
.719 .98 .77 r
.25138 .66402 m .24881 .66633 L .25104 .66506 L F
.396 .723 .989 r
.5327 .78909 m .53617 .79 L .53629 .78869 L F
.547 .883 .987 r
.53617 .79 m .53744 .7888 L .53629 .78869 L F
.53617 .79 m .53847 .78931 L .53744 .7888 L F
0 .534 .796 r
.30636 .58481 m .30824 .5851 L .3097 .58554 L F
.031 0 0 r
.30824 .5851 m .31187 .58504 L .3097 .58554 L F
.912 .516 .123 r
.5992 .70997 m .60098 .71281 L .60067 .71033 L F
.243 0 0 r
.43012 .70731 m .42634 .70864 L .42678 .70803 L F
.43012 .70731 m .42856 .70838 L .42634 .70864 L F
.12 0 0 r
.43094 .70785 m .43012 .70731 L .43233 .70703 L F
.43094 .70785 m .42856 .70838 L .43012 .70731 L F
.087 .168 .654 r
.4192 .69244 m .41826 .694 L .41745 .69022 L F
.434 .629 .936 r
.4192 .69244 m .4203 .69407 L .41826 .694 L F
.759 .634 .721 r
.55259 .63714 m .54854 .63378 L .55097 .63383 L F
.55259 .63714 m .54927 .63733 L .54854 .63378 L F
.75 .431 .444 r
.55259 .63714 m .54929 .63861 L .54927 .63733 L F
.55259 .63714 m .55129 .63943 L .54929 .63861 L F
.051 .298 .787 r
.55097 .63383 m .55339 .63626 L .55259 .63714 L F
.602 .258 .36 r
.55477 .63907 m .55259 .63714 L .55339 .63626 L F
.55477 .63907 m .55129 .63943 L .55259 .63714 L F
.238 .504 .903 r
.56726 .72635 m .56773 .72564 L .56417 .72537 L F
.56726 .72635 m .56882 .72698 L .56773 .72564 L F
.474 .255 .5 r
.61782 .58902 m .61549 .59163 L .61558 .58983 L F
.356 .222 .558 r
.39064 .69582 m .39161 .69673 L .39171 .69318 L F
.766 .646 .729 r
.48143 .78422 m .47772 .77988 L .47954 .7796 L F
.48143 .78422 m .47754 .78427 L .47772 .77988 L F
.849 .537 .459 r
.48143 .78422 m .47769 .78558 L .47706 .78498 L F
0 .123 .672 r
.48137 .78165 m .48143 .78422 L .47954 .7796 L F
.831 .987 .87 r
.48137 .78165 m .47769 .78558 L .48143 .78422 L F
.395 .764 .993 r
.33083 .60179 m .33273 .60082 L .32972 .60098 L F
.33083 .60179 m .33372 .60164 L .33273 .60082 L F
.36 .757 .985 r
.33083 .60179 m .33388 .6021 L .33372 .60164 L F
.148 .187 .646 r
.33388 .6021 m .33513 .60152 L .33372 .60164 L F
.33388 .6021 m .33542 .60177 L .33513 .60152 L F
.45 .82 .993 r
.24802 .62603 m .24884 .62506 L .25073 .62576 L F
.607 .384 .552 r
.25073 .62576 m .25061 .62763 L .24802 .62603 L F
.959 .624 .317 r
.25061 .62763 m .24884 .62506 L .24802 .62603 L F
.274 .026 .344 r
.32789 .62888 m .32929 .62977 L .32996 .62857 L F
.32789 .62888 m .32743 .63088 L .32929 .62977 L F
.784 .736 .808 r
.54294 .60623 m .53966 .60616 L .54221 .6034 L F
.804 .747 .8 r
.5452 .60338 m .54294 .60623 L .54221 .6034 L F
.801 .997 .784 r
.59932 .55094 m .60119 .55005 L .60197 .54815 L F
.671 .477 .614 r
.54662 .77128 m .54299 .77443 L .54373 .77154 L F
.401 .769 .993 r
.34916 .59072 m .34552 .59025 L .34768 .58987 L F
.369 .76 .988 r
.34977 .58982 m .34916 .59072 L .34768 .58987 L F
.34977 .58982 m .35118 .59054 L .34916 .59072 L F
.662 .392 .501 r
.65569 .48258 m .65945 .48318 L .65651 .48241 L F
.439 .215 .476 r
.60441 .58054 m .60594 .57979 L .60639 .57774 L F
.189 0 .245 r
.60639 .57774 m .60887 .57675 L .60885 .57484 L F
.37 .204 .521 r
.60594 .57979 m .60887 .57675 L .60639 .57774 L F
.544 .27 .451 r
.57867 .60891 m .57864 .61059 L .57529 .61191 L F
.544 .285 .473 r
.58103 .60856 m .57864 .61059 L .57867 .60891 L F
0 0 .352 r
.57307 .70938 m .57315 .71191 L .57205 .71329 L F
.605 .567 .786 r
.57315 .71191 m .57124 .71428 L .57205 .71329 L F
.544 .492 .748 r
.71374 .48793 m .71652 .49031 L .7159 .48702 L F
.967 .706 .486 r
.50985 .79026 m .51224 .78909 L .50938 .78819 L F
.50985 .79026 m .51248 .79232 L .51224 .78909 L F
.594 .464 .673 r
.51224 .78909 m .51463 .78895 L .51438 .78593 L F
.179 .311 .762 r
.51224 .78909 m .51474 .79161 L .51463 .78895 L F
.342 .192 .528 r
.5298 .77728 m .52822 .77591 L .52947 .77468 L F
.43 .184 .439 r
.5298 .77728 m .52898 .77945 L .52822 .77591 L F
.691 .831 .95 r
.68988 .47382 m .68654 .47365 L .68885 .47297 L F
.563 .841 .997 r
.68988 .47382 m .69122 .47229 L .69226 .47319 L F
.567 .846 .997 r
.68885 .47297 m .69122 .47229 L .68988 .47382 L F
.914 .921 .806 r
.68227 .51968 m .68023 .52096 L .68158 .51852 L F
.534 .756 .978 r
.68158 .51852 m .68397 .5196 L .68227 .51968 L F
.566 .507 .748 r
.75916 .59747 m .75939 .59424 L .75933 .59643 L F
.93 .877 .763 r
.75757 .59753 m .75916 .59747 L .75933 .59643 L F
.4 .736 .992 r
.36472 .59163 m .36402 .59269 L .36251 .59182 L F
.36472 .59163 m .36567 .59257 L .36402 .59269 L F
.673 .611 .778 r
.54333 .74456 m .54731 .74631 L .54616 .74601 L F
0 .516 .798 r
.54928 .74684 m .54616 .74601 L .54731 .74631 L F
0 0 0 r
.26197 .65344 m .25929 .65598 L .26044 .65435 L F
.467 .595 .897 r
.71239 .4709 m .71494 .47037 L .7126 .47138 L F
.71382 .46972 m .71494 .47037 L .71239 .4709 L F
.728 .265 .149 r
.71196 .47242 m .71478 .4731 L .7126 .47138 L F
.728 .642 .763 r
.71494 .47037 m .71353 .47134 L .7126 .47138 L F
.71353 .47134 m .71196 .47242 L .71243 .47166 L F
.71353 .47134 m .71243 .47166 L .7126 .47138 L F
.71494 .47037 m .71321 .4725 L .71196 .47242 L F
.571 .595 .839 r
.71298 .46645 m .71494 .47037 L .71111 .46816 L F
.721 .306 .259 r
.71298 .46645 m .71531 .46751 L .71494 .47037 L F
.848 .855 .848 r
.71531 .46751 m .71384 .47101 L .71494 .47037 L F
.71384 .47101 m .71321 .4725 L .71366 .47194 L F
.71384 .47101 m .71366 .47194 L .71494 .47037 L F
.392 .412 .762 r
.71474 .46457 m .71493 .46524 L .71298 .46645 L F
.76 .99 .775 r
.71565 .4682 m .71469 .469 L .71531 .46751 L F
.71595 .46878 m .71469 .469 L .71565 .4682 L F
.721 .306 .259 r
.71298 .46645 m .71595 .46878 L .71531 .46751 L F
.474 .206 .426 r
.71531 .46751 m .71595 .46878 L .71846 .46757 L F
.996 .786 .501 r
.71846 .46757 m .71595 .46878 L .71531 .46751 L F
.392 .412 .762 r
.71464 .46674 m .71595 .46878 L .71448 .46763 L F
.762 .315 0 r
.71514 .46752 m .71595 .46878 L .71479 .46753 L F
.71531 .46751 m .71595 .46878 L .71514 .46752 L F
.392 .412 .762 r
.71493 .46524 m .71595 .46878 L .71464 .46674 L F
.71493 .46524 m .71448 .46763 L .71298 .46645 L F
.76 .99 .775 r
.71595 .46878 m .71421 .47114 L .71469 .469 L F
.71421 .47114 m .71321 .4725 L .71372 .47128 L F
.71421 .47114 m .71372 .47128 L .71469 .469 L F
.467 .595 .897 r
.71111 .46816 m .71382 .46972 L .71239 .4709 L F
.462 .249 .503 r
.29458 .6141 m .29244 .61677 L .29262 .61454 L F
.301 0 .153 r
.43139 .66933 m .43104 .66764 L .43291 .66754 L F
.43139 .66933 m .4293 .66997 L .43104 .66764 L F
0 0 0 r
.54885 .61978 m .54768 .62175 L .54653 .62254 L F
0 0 .232 r
.54713 .6242 m .54653 .62254 L .54768 .62175 L F
.54713 .6242 m .54632 .6255 L .54653 .62254 L F
.696 .31 .312 r
.44683 .69273 m .4492 .69468 L .45037 .69269 L F
.54 .16 .268 r
.4492 .69468 m .45274 .69256 L .45037 .69269 L F
.834 .774 .795 r
.48916 .62849 m .48533 .62995 L .48788 .62814 L F
.48916 .62849 m .48679 .6315 L .48533 .62995 L F
.661 .943 .961 r
.48916 .62849 m .48788 .62814 L .48999 .62703 L F
.433 .672 .963 r
.48999 .62703 m .49128 .62843 L .48916 .62849 L F
.971 .854 .668 r
.63842 .52606 m .63834 .53029 L .63975 .52715 L F
.46 .248 .504 r
.57193 .69905 m .57383 .70063 L .57427 .69867 L F
.57193 .69905 m .57178 .70129 L .57383 .70063 L F
.61 .309 .434 r
.5476 .79163 m .54988 .79124 L .54744 .78995 L F
.027 0 0 r
.42995 .69628 m .43207 .69634 L .43348 .69638 L F
.607 .104 .029 r
.43207 .69634 m .43537 .69715 L .43348 .69638 L F
.443 0 .017 r
.43348 .69638 m .43537 .69715 L .43589 .6964 L F
.126 0 .354 r
.60885 .57484 m .61084 .57389 L .61117 .5717 L F
0 0 .208 r
.60885 .57484 m .60996 .57587 L .61084 .57389 L F
.60885 .57484 m .60887 .57675 L .60996 .57587 L F
.129 .392 .845 r
.54808 .75531 m .54657 .7533 L .54841 .75256 L F
.558 .841 .997 r
.54943 .75117 m .55081 .75219 L .54841 .75256 L F
.718 .208 .014 r
.76965 .57458 m .77162 .57557 L .77217 .57551 L F
.642 .527 .708 r
.56492 .61433 m .56528 .61698 L .56274 .61725 L F
.577 .437 .654 r
.56528 .61698 m .56322 .62015 L .56274 .61725 L F
.476 .235 .469 r
.51582 .79236 m .51578 .79469 L .51365 .79471 L F
.689 .482 .601 r
.51905 .79178 m .51578 .79469 L .51582 .79236 L F
.635 .664 .861 r
.76763 .57714 m .76869 .57896 L .77112 .57808 L F
.281 .09 .434 r
.48282 .78428 m .48232 .78668 L .48416 .78313 L F
.145 0 .138 r
.55059 .77485 m .54774 .77742 L .55057 .77747 L F
.129 .391 .844 r
.54774 .77742 m .55089 .7797 L .55057 .77747 L F
.627 .409 .567 r
.39767 .70707 m .40002 .70705 L .40014 .70465 L F
.356 .411 .781 r
.39902 .70106 m .40014 .70465 L .40152 .703 L F
.577 .514 .748 r
.40002 .70705 m .40152 .703 L .40014 .70465 L F
.37 .338 .692 r
.29006 .62257 m .29063 .6245 L .2886 .62285 L F
.244 0 .237 r
.43744 .66487 m .43509 .66724 L .4358 .6656 L F
.846 .516 .429 r
.6612 .48374 m .66285 .4848 L .66248 .48262 L F
.914 .64 .507 r
.78512 .59106 m .78702 .59239 L .78606 .59201 L F
.369 .765 .986 r
.34007 .58854 m .33977 .58941 L .33831 .58867 L F
.34007 .58854 m .34172 .58925 L .33977 .58941 L F
.983 .696 .357 r
.72851 .49484 m .72936 .49355 L .72879 .4925 L F
.72851 .49484 m .72957 .49591 L .72936 .49355 L F
.788 .575 .613 r
.56189 .70667 m .56502 .7081 L .56411 .70494 L F
.562 .444 .676 r
.56411 .70494 m .56729 .70741 L .56718 .70462 L F
.56411 .70494 m .56502 .7081 L .56729 .70741 L F
.313 .046 .338 r
.52546 .69479 m .52385 .69381 L .52601 .69355 L F
.52546 .69479 m .52348 .69573 L .52385 .69381 L F
.775 .45 .437 r
.52639 .78536 m .52807 .78846 L .53029 .78594 L F
.524 .169 .308 r
.52807 .78846 m .53147 .78595 L .53029 .78594 L F
.058 0 .392 r
.74105 .50884 m .73935 .51055 L .74019 .50754 L F
.332 .236 .593 r
.74105 .50884 m .73915 .51267 L .73935 .51055 L F
.313 .42 .811 r
.54322 .74233 m .54333 .74456 L .5447 .74294 L F
.319 .43 .817 r
.54333 .74456 m .54616 .74601 L .5447 .74294 L F
.044 .567 .867 r
.52315 .77472 m .51977 .77371 L .52104 .77485 L F
.289 .431 .831 r
.52104 .77485 m .52392 .77809 L .52315 .77472 L F
.432 .857 .721 r
.58118 .70656 m .58487 .70473 L .58245 .70734 L F
.693 .59 .735 r
.58487 .70473 m .5854 .70664 L .58245 .70734 L F
.62 .885 .989 r
.5854 .70664 m .58118 .70656 L .58245 .70734 L F
.712 .459 .541 r
.49176 .77728 m .49214 .77793 L .49207 .7769 L F
.535 .786 .99 r
.49446 .77998 m .49451 .77891 L .49412 .77967 L F
0 0 .163 r
.4931 .78163 m .49335 .77941 L .49446 .77998 L F
0 .299 .684 r
.49418 .77972 m .49105 .77721 L .49185 .77774 L F
.49428 .77981 m .49335 .77941 L .49105 .77721 L F
.403 .203 .492 r
.49335 .77941 m .48922 .7842 L .48963 .77973 L F
.49335 .77941 m .49115 .78372 L .48922 .7842 L F
0 0 .163 r
.4931 .78163 m .49115 .78372 L .49335 .77941 L F
.712 .459 .541 r
.48997 .77944 m .49405 .77979 L .49214 .77793 L F
.535 .786 .99 r
.49439 .78007 m .49414 .77969 L .4931 .78163 L F
.49414 .77969 m .49413 .77968 L .49411 .77972 L F
.49414 .77969 m .49411 .77972 L .4931 .78163 L F
.49413 .77968 m .49412 .77967 L .49408 .77976 L F
.49413 .77968 m .49408 .77976 L .4931 .78163 L F
.49412 .77967 m .4941 .77971 L .4931 .78163 L F
.993 .743 .414 r
.49428 .77981 m .4931 .78163 L .4941 .77971 L F
.535 .786 .99 r
.49446 .77998 m .49412 .77967 L .49421 .7798 L F
.49446 .77998 m .49421 .7798 L .49439 .78007 L F
0 .299 .684 r
.49414 .77975 m .49446 .77998 L .49335 .77941 L F
.49428 .77981 m .49446 .77998 L .49414 .77975 L F
.49428 .77981 m .49418 .77972 L .49413 .77969 L F
.49428 .77981 m .49413 .77969 L .49412 .77967 L F
.712 .459 .541 r
.4941 .77971 m .49428 .77981 L .49412 .77967 L F
0 .299 .684 r
.49412 .77967 m .49413 .77969 L .49214 .77793 L F
.49418 .77972 m .49185 .77774 L .49214 .77793 L F
.712 .459 .541 r
.49405 .77979 m .49412 .77967 L .49214 .77793 L F
.535 .786 .99 r
.49412 .77967 m .49412 .77967 L .4941 .77971 L F
.993 .743 .414 r
.49428 .77981 m .4941 .77971 L .49451 .77891 L F
.712 .459 .541 r
.49405 .77979 m .49428 .77981 L .4941 .77971 L F
.622 .215 .25 r
.49399 .77988 m .49342 .78181 L .49428 .77981 L F
.744 .559 .644 r
.48911 .78025 m .48922 .7842 L .48649 .78311 L F
.48911 .78025 m .48649 .78311 L .48691 .78245 L F
.48963 .77973 m .48958 .78029 L .48911 .78025 L F
.48958 .78029 m .48922 .7842 L .48911 .78025 L F
0 0 0 r
.48852 .78003 m .48845 .78006 L .48842 .78018 L F
.48845 .78006 m .48839 .78009 L .48837 .78019 L F
.744 .559 .644 r
.48832 .7803 m .48632 .78305 L .48689 .7804 L F
.48963 .77973 m .48691 .78245 L .48855 .77999 L F
.48691 .78245 m .48632 .78305 L .48855 .77999 L F
.633 .179 .157 r
.4879 .78223 m .48834 .7803 L .48689 .7804 L F
.48834 .7803 m .48837 .78019 L .48689 .7804 L F
.48837 .78019 m .48839 .78009 L .488 .78017 L F
.48837 .78019 m .488 .78017 L .48689 .7804 L F
.744 .559 .644 r
.48855 .77999 m .48832 .7803 L .48689 .7804 L F
0 0 0 r
.48997 .77944 m .48852 .78003 L .4879 .78223 L F
.48852 .78003 m .48842 .78018 L .4879 .78223 L F
.48845 .78006 m .48837 .78019 L .4879 .78223 L F
.744 .559 .644 r
.48691 .78245 m .48649 .78311 L .48632 .78305 L F
.622 .215 .25 r
.4892 .7811 m .49263 .78168 L .49399 .77988 L F
.49292 .78173 m .49381 .78047 L .49399 .77988 L F
.993 .743 .414 r
.49428 .77981 m .49312 .78135 L .49311 .78146 L F
.49428 .77981 m .49311 .78146 L .4931 .78163 L F
.622 .215 .25 r
.49263 .78168 m .49292 .78173 L .49399 .77988 L F
.49292 .78173 m .49342 .78181 L .49381 .78047 L F
.4892 .7811 m .49399 .77988 L .48997 .77944 L F
.49399 .77988 m .49428 .77981 L .49405 .77979 L F
.49399 .77988 m .49405 .77979 L .48997 .77944 L F
.012 .097 .607 r
.48841 .77686 m .48997 .77944 L .49157 .77751 L F
0 0 .367 r
.49125 .77641 m .49167 .77762 L .49105 .77721 L F
.012 .097 .607 r
.49123 .77722 m .49157 .77751 L .49176 .77728 L F
.48841 .77686 m .49157 .77751 L .49123 .77722 L F
.712 .459 .541 r
.48997 .77944 m .49214 .77793 L .49176 .77728 L F
0 0 .367 r
.49144 .77565 m .4916 .77701 L .49125 .77641 L F
.4916 .77701 m .49167 .77762 L .49125 .77641 L F
.49173 .77453 m .49168 .7769 L .49144 .77565 L F
.49168 .7769 m .49167 .77762 L .49144 .77565 L F
.012 .097 .607 r
.49168 .7769 m .49176 .77728 L .49207 .7769 L F
.736 .531 .614 r
.49168 .7769 m .49207 .7769 L .49173 .77453 L F
0 0 .367 r
.49173 .77453 m .49214 .77793 L .49167 .77762 L F
.012 .097 .607 r
.48841 .77686 m .49176 .77728 L .49168 .7769 L F
.736 .531 .614 r
.48841 .77686 m .49168 .7769 L .49173 .77453 L F
.39 .651 .962 r
.69727 .51218 m .69766 .51336 L .6942 .51544 L F
.489 .256 .488 r
.74343 .50658 m .74019 .50754 L .74341 .5047 L F
.506 .188 .362 r
.74343 .50658 m .74105 .50884 L .74019 .50754 L F
0 0 0 r
.45803 .65551 m .45895 .6537 L .45874 .65379 L F
.307 .776 .658 r
.46049 .65298 m .45874 .65379 L .45895 .6537 L F
.732 .991 .839 r
.59144 .56393 m .59456 .56123 L .5926 .56194 L F
.614 .795 .365 r
.59144 .56393 m .5926 .56194 L .59078 .56502 L F
0 0 .253 r
.59261 .56138 m .59078 .56502 L .5926 .56194 L F
.59261 .56138 m .5922 .56365 L .59078 .56502 L F
.594 .95 .866 r
.59078 .56502 m .5922 .56365 L .59179 .56389 L F
.59078 .56502 m .59179 .56389 L .58991 .56501 L F
0 0 0 r
.58969 .56625 m .59078 .56502 L .58961 .56635 L F
.59144 .56393 m .59078 .56502 L .58969 .56625 L F
.537 .815 .997 r
.49159 .64227 m .49512 .64253 L .49321 .64127 L F
.478 .489 .791 r
.49512 .64253 m .49597 .63894 L .49321 .64127 L F
.49512 .64253 m .49739 .64284 L .49597 .63894 L F
.137 .39 .842 r
.51666 .6424 m .5155 .64309 L .51444 .64241 L F
.51666 .6424 m .51803 .64474 L .5155 .64309 L F
.986 .714 .405 r
.55243 .77688 m .55357 .77755 L .5534 .77499 L F
.55243 .77688 m .5534 .77499 L .55439 .77406 L F
.501 .416 .691 r
.48571 .77452 m .48784 .77451 L .48735 .77187 L F
.303 .345 .74 r
.48571 .77452 m .48841 .77686 L .48784 .77451 L F
.642 .553 .738 r
.74335 .58369 m .74588 .58508 L .74597 .58365 L F
.553 .319 .515 r
.74588 .58508 m .74892 .58291 L .74597 .58365 L F
.39 .235 .548 r
.59219 .53585 m .59406 .53508 L .59394 .53265 L F
.187 0 .142 r
.59333 .53665 m .59219 .53585 L .59195 .53805 L F
.59333 .53665 m .59406 .53508 L .59219 .53585 L F
.304 0 .271 r
.60786 .5414 m .60734 .543 L .6053 .54362 L F
.553 .242 .395 r
.60765 .54554 m .6053 .54362 L .60734 .543 L F
.60765 .54554 m .60455 .54633 L .6053 .54362 L F
.642 .083 0 r
.24843 .6566 m .24583 .65671 L .24613 .65749 L F
0 0 0 r
.49061 .80924 m .49182 .80653 L .49124 .80815 L F
.051 .237 .734 r
.49182 .80653 m .49326 .80909 L .49376 .8088 L F
.77 .379 .314 r
.49182 .80653 m .49376 .8088 L .49124 .80815 L F
.903 .923 .821 r
.65627 .51244 m .65644 .50997 L .65741 .51089 L F
.998 .787 .477 r
.65741 .51089 m .65644 .50997 L .65672 .50706 L F
.729 .762 .879 r
.48533 .62995 m .48679 .6315 L .48327 .63118 L F
0 0 .483 r
.50933 .77319 m .50826 .77569 L .50843 .77189 L F
0 0 0 r
.50933 .77319 m .50809 .77619 L .50826 .77569 L F
.835 .386 0 r
.50809 .77619 m .50945 .77771 L .50826 .77569 L F
.506 .897 .744 r
.53786 .80305 m .53681 .8039 L .53564 .80423 L F
.53786 .80305 m .53861 .80279 L .53681 .8039 L F
.53681 .8039 m .53861 .80279 L .53786 .80305 L F
.976 .922 .649 r
.5263 .65165 m .52493 .6522 L .52594 .6526 L F
.211 0 0 r
.52856 .65099 m .52493 .6522 L .5263 .65165 L F
.52805 .65116 m .52735 .65221 L .52493 .6522 L F
.52856 .65099 m .52735 .65221 L .52805 .65116 L F
.985 .858 .63 r
.52725 .65167 m .52726 .65235 L .52735 .65221 L F
.104 .641 .857 r
.52493 .6522 m .52735 .65221 L .52415 .6519 L F
.52493 .6522 m .52415 .6519 L .52374 .65186 L F
.976 .922 .649 r
.52594 .6526 m .52493 .6522 L .52576 .65308 L F
.881 .74 .702 r
.52217 .65495 m .52576 .65308 L .52493 .6522 L F
.52217 .65495 m .52411 .65649 L .52576 .65308 L F
.613 .426 .605 r
.52374 .65186 m .52217 .65495 L .52493 .6522 L F
.766 .545 .599 r
.52728 .65471 m .52374 .65186 L .52735 .65221 L F
.985 .858 .63 r
.52726 .65235 m .52728 .65471 L .52735 .65221 L F
.89 .978 .819 r
.55149 .76866 m .55207 .76937 L .55434 .76653 L F
.737 .319 .255 r
.55125 .77127 m .55207 .76937 L .55149 .76866 L F
.55125 .77127 m .55442 .77155 L .55207 .76937 L F
.594 .426 .623 r
.55207 .76937 m .55435 .76918 L .55434 .76653 L F
.585 .382 .573 r
.55207 .76937 m .55442 .77155 L .55435 .76918 L F
0 0 .293 r
.67561 .48049 m .67427 .48073 L .67615 .47978 L F
.67561 .48049 m .67523 .48226 L .67427 .48073 L F
.664 .259 0 r
.59846 .70879 m .5992 .70997 L .59797 .7077 L F
.711 .856 .951 r
.64188 .50042 m .64302 .50172 L .64593 .50025 L F
.653 .688 .87 r
.3768 .59777 m .37343 .59666 L .37536 .59671 L F
.44 .795 .997 r
.37742 .59671 m .3768 .59777 L .37536 .59671 L F
.37742 .59671 m .37889 .59749 L .3768 .59777 L F
.396 .376 .72 r
.51287 .65697 m .51492 .65829 L .51506 .65644 L F
.568 .193 .291 r
.62438 .53293 m .62043 .53469 L .62061 .53331 L F
.903 .923 .821 r
.65627 .51244 m .65435 .51252 L .65644 .50997 L F
.925 .831 .734 r
.65485 .51568 m .65435 .51252 L .65627 .51244 L F
.62 .584 .791 r
.70628 .51018 m .70303 .50753 L .70577 .50714 L F
.707 .601 .735 r
.70881 .50746 m .70628 .51018 L .70577 .50714 L F
.291 .789 .852 r
.57448 .7253 m .57346 .72515 L .57064 .72581 L F
0 .455 .712 r
.57674 .7259 m .57346 .72515 L .57448 .7253 L F
.802 .86 .892 r
.70303 .50753 m .69945 .50858 L .70175 .50624 L F
.648 .792 .951 r
.70577 .50714 m .70303 .50753 L .70175 .50624 L F
.645 .469 .63 r
.46329 .68735 m .46552 .68931 L .46679 .68774 L F
.716 .359 .371 r
.46552 .68931 m .46893 .69003 L .46679 .68774 L F
.342 .098 .392 r
.38141 .60688 m .38136 .60595 L .38327 .60533 L F
.897 .584 .446 r
.514 .77741 m .5149 .78024 L .51672 .78033 L F
.706 .273 .22 r
.51588 .78219 m .51672 .78033 L .5149 .78024 L F
.51588 .78219 m .5189 .78264 L .51672 .78033 L F
.422 .564 .891 r
.7138 .51534 m .71744 .51771 L .71565 .51561 L F
.485 .252 .486 r
.36638 .61719 m .36597 .61958 L .36387 .62006 L F
.417 .145 .391 r
.36864 .61679 m .36597 .61958 L .36638 .61719 L F
.677 .822 .953 r
.69246 .53376 m .6937 .53489 L .69679 .53327 L F
.171 .256 .71 r
.41786 .68671 m .41681 .68821 L .41589 .68471 L F
.35 .335 .703 r
.41885 .68982 m .41681 .68821 L .41786 .68671 L F
.41885 .68982 m .41745 .69022 L .41681 .68821 L F
.221 0 0 r
.27352 .5881 m .27574 .58784 L .27758 .58674 L F
.424 0 .031 r
.27574 .58784 m .27964 .5863 L .27758 .58674 L F
.95 .611 .207 r
.63354 .5158 m .63423 .5181 L .63515 .51884 L F
.63354 .5158 m .63423 .5181 L .63515 .51884 L F
.913 .632 .496 r
.63758 .53703 m .63884 .53573 L .63745 .53471 L F
.63758 .53703 m .63912 .53831 L .63884 .53573 L F
.546 .643 .897 r
.50277 .63037 m .5018 .63257 L .50052 .63104 L F
.50277 .63037 m .50456 .63267 L .5018 .63257 L F
.369 .774 .983 r
.38281 .70965 m .3813 .70893 L .38074 .70984 L F
.38281 .70965 m .3813 .70893 L .38074 .70984 L F
.254 0 .177 r
.62374 .52089 m .62326 .5229 L .6216 .52235 L F
.36 0 0 r
.62304 .52301 m .6216 .52235 L .62326 .5229 L F
.62304 .52301 m .62039 .52351 L .6216 .52235 L F
.324 .714 .981 r
.67136 .53628 m .67023 .53536 L .6677 .53531 L F
.675 .888 .976 r
.67244 .53431 m .67136 .53628 L .67348 .53522 L F
.67244 .53431 m .67023 .53536 L .67136 .53628 L F
.277 .743 .946 r
.35506 .59098 m .35118 .59054 L .3533 .59072 L F
.076 .63 .814 r
.3533 .59072 m .35698 .59101 L .35506 .59098 L F
.489 .354 .623 r
.25158 .60267 m .25356 .60235 L .25344 .59998 L F
.468 .362 .65 r
.25203 .60599 m .25356 .60235 L .25158 .60267 L F
.196 .725 .822 r
.47414 .76572 m .47527 .76539 L .47703 .76359 L F
.47414 .76572 m .47341 .76558 L .47527 .76539 L F
.529 .346 .577 r
.36151 .62301 m .3614 .62508 L .35923 .62544 L F
.318 .039 .323 r
.36049 .6271 m .35923 .62544 L .3614 .62508 L F
.36049 .6271 m .35859 .62788 L .35923 .62544 L F
.633 .656 .855 r
.74463 .59118 m .74793 .59224 L .74677 .58863 L F
.569 .548 .792 r
.74793 .59224 m .74929 .58832 L .74677 .58863 L F
.74793 .59224 m .75046 .59186 L .74929 .58832 L F
.902 .811 .748 r
.53572 .60952 m .53485 .6115 L .53409 .60856 L F
.33 0 .238 r
.60135 .52674 m .60355 .52635 L .60413 .52449 L F
.383 .153 .437 r
.60643 .52163 m .60413 .52449 L .60612 .52366 L F
.392 .091 .331 r
.60355 .52635 m .60612 .52366 L .60413 .52449 L F
.534 .426 .677 r
.38918 .66812 m .39163 .67004 L .39139 .66765 L F
.38918 .66812 m .38953 .67054 L .39163 .67004 L F
.569 .217 .331 r
.26759 .59043 m .27137 .58807 L .26922 .58831 L F
.351 .373 .743 r
.74564 .49229 m .74639 .4957 L .74486 .49606 L F
.344 .341 .712 r
.74639 .4957 m .74738 .49766 L .74486 .49606 L F
.494 .501 .793 r
.25368 .61375 m .25521 .61767 L .25659 .61668 L F
.155 0 .3 r
.25521 .61767 m .25446 .62009 L .25659 .61668 L F
.615 .844 .987 r
.67282 .47554 m .66921 .47538 L .67168 .47491 L F
.378 .791 .979 r
.67168 .47491 m .675 .47523 L .67282 .47554 L F
.803 .738 .792 r
.66177 .48589 m .66356 .48786 L .66285 .4848 L F
.949 .645 .425 r
.66177 .48589 m .66235 .48773 L .66356 .48786 L F
.989 .753 .487 r
.66469 .48837 m .66356 .48786 L .66235 .48773 L F
.66469 .48837 m .66591 .48729 L .66356 .48786 L F
.58 .578 .815 r
.55682 .78273 m .5556 .78602 L .55707 .78534 L F
.683 .475 .598 r
.76484 .57518 m .76763 .57714 L .76754 .57494 L F
.76484 .57518 m .76613 .57777 L .76763 .57714 L F
.491 .402 .683 r
.47221 .80687 m .47311 .81099 L .47249 .80793 L F
.399 .353 .69 r
.41714 .68101 m .41589 .68471 L .41547 .6823 L F
.218 0 .085 r
.63624 .48281 m .63341 .48484 L .6358 .48394 L F
.469 .113 .278 r
.6358 .48394 m .63839 .48228 L .63624 .48281 L F
.615 .496 .695 r
.54578 .79538 m .5476 .79163 L .54523 .79202 L F
.769 .727 .813 r
.54419 .60085 m .5452 .60338 L .5436 .60216 L F
.804 .747 .8 r
.5452 .60338 m .54221 .6034 L .5436 .60216 L F
.783 .733 .806 r
.54775 .60078 m .5452 .60338 L .54419 .60085 L F
.407 .054 .251 r
.54983 .76321 m .55312 .76042 L .55124 .7603 L F
.477 .174 .372 r
.61017 .54088 m .60734 .543 L .60786 .5414 L F
.222 .394 .823 r
.55065 .74964 m .55192 .7486 L .54928 .74684 L F
.325 .58 .934 r
.55065 .74964 m .55282 .75053 L .55192 .7486 L F
.89 .978 .819 r
.55149 .76866 m .55434 .76653 L .55369 .76549 L F
.55 .773 .981 r
.55434 .76653 m .55553 .76498 L .55369 .76549 L F
.55434 .76653 m .55663 .76612 L .55553 .76498 L F
.732 .64 .756 r
.55435 .76918 m .55663 .76612 L .55434 .76653 L F
.673 .695 .863 r
.28048 .64407 m .28174 .6457 L .28398 .64485 L F
.55 .339 .546 r
.28174 .6457 m .28347 .64766 L .28398 .64485 L F
.405 .337 .667 r
.3889 .67926 m .3908 .68093 L .39063 .67864 L F
.3889 .67926 m .3891 .68221 L .3908 .68093 L F
.949 .912 .538 r
.62081 .55208 m .62042 .55144 L .62143 .54807 L F
.948 .819 .683 r
.72818 .50817 m .72978 .50769 L .72847 .50663 L F
.72818 .50817 m .72922 .50962 L .72978 .50769 L F
.731 .895 .954 r
.48097 .63259 m .48199 .63035 L .48327 .63118 L F
.48097 .63259 m .47974 .63172 L .48199 .63035 L F
.333 .373 .754 r
.51354 .63869 m .51224 .6407 L .51142 .63864 L F
.51354 .63869 m .51444 .64241 L .51224 .6407 L F
.576 .51 .744 r
.74345 .58782 m .74463 .59118 L .74677 .58863 L F
.351 .826 .869 r
.47988 .81624 m .48235 .81561 L .48095 .81557 L F
.271 0 0 r
.43817 .70452 m .43673 .70592 L .43442 .70625 L F
.338 0 0 r
.44041 .70434 m .43673 .70592 L .43817 .70452 L F
.951 .858 .713 r
.7361 .50081 m .73597 .49786 L .73631 .49908 L F
0 0 .261 r
.73525 .49576 m .73631 .49908 L .73597 .49786 L F
.536 .739 .969 r
.29852 .62951 m .29517 .62867 L .29736 .62863 L F
.511 .798 .998 r
.29927 .62827 m .29852 .62951 L .29736 .62863 L F
.29927 .62827 m .30048 .62916 L .29852 .62951 L F
.403 0 .095 r
.54343 .73472 m .54696 .73272 L .54378 .73321 L F
.54343 .73472 m .54573 .73451 L .54696 .73272 L F
.711 .307 .279 r
.54696 .73272 m .54573 .73451 L .54921 .73484 L F
.98 .902 .57 r
.58736 .70698 m .5857 .70815 L .58608 .70711 L F
.23 0 0 r
.58773 .70694 m .58736 .70698 L .5854 .70664 L F
.432 .857 .721 r
.58118 .70656 m .58327 .70533 L .58487 .70473 L F
.122 .607 .913 r
.5854 .70664 m .58736 .70698 L .58327 .70533 L F
0 0 0 r
.58644 .70162 m .58487 .70473 L .58586 .70324 L F
.832 .765 .789 r
.58327 .70533 m .58586 .70324 L .58487 .70473 L F
.58327 .70533 m .58736 .70698 L .58586 .70324 L F
.98 .902 .57 r
.58736 .70698 m .58608 .70711 L .58668 .70548 L F
.23 0 0 r
.58847 .70704 m .58736 .70698 L .58773 .70694 L F
.458 .278 .548 r
.58847 .70704 m .59043 .70685 L .59029 .70455 L F
.58847 .70704 m .59043 .70685 L .59029 .70455 L F
.718 .413 .461 r
.59043 .70685 m .58736 .70698 L .58847 .70704 L F
.745 .666 .774 r
.58843 .7102 m .59043 .70685 L .58847 .70704 L F
.577 .437 .654 r
.56528 .61698 m .56678 .62066 L .56322 .62015 L F
.609 .457 .651 r
.56678 .62066 m .56459 .62133 L .56322 .62015 L F
.09 0 0 r
.3311 .6445 m .33222 .64474 L .33009 .64532 L F
.3311 .6445 m .33403 .64343 L .33222 .64474 L F
0 0 .108 r
.62166 .58045 m .62158 .58233 L .62034 .58366 L F
0 0 0 r
.62158 .58233 m .6199 .58585 L .62034 .58366 L F
.71 .584 .712 r
.53485 .6115 m .53663 .61496 L .53256 .61424 L F
.856 .469 .311 r
.53567 .61725 m .53256 .61424 L .53663 .61496 L F
.752 .328 .243 r
.55687 .7714 m .55435 .76918 L .55517 .7709 L F
.55756 .7716 m .55709 .77125 L .55687 .7714 L F
.55709 .77125 m .55435 .76918 L .55687 .7714 L F
.739 .991 .82 r
.55693 .77132 m .55709 .77125 L .55682 .77142 L F
.55709 .77125 m .55852 .77061 L .55688 .77139 L F
.55709 .77125 m .55688 .77139 L .55682 .77142 L F
.752 .328 .243 r
.55709 .77125 m .55852 .77061 L .55435 .76918 L F
.739 .991 .82 r
.55959 .76889 m .55852 .77061 L .55693 .77132 L F
.752 .328 .243 r
.55756 .7716 m .55852 .77061 L .55709 .77125 L F
.219 0 0 r
.4126 .65446 m .40948 .65566 L .41195 .65602 L F
.642 .553 .738 r
.74335 .58369 m .74354 .58583 L .74588 .58508 L F
.6 .463 .667 r
.74345 .58782 m .74588 .58508 L .74354 .58583 L F
.169 0 0 r
.45335 .6447 m .45561 .64431 L .45717 .64323 L F
.437 .824 .595 r
.45717 .64323 m .45725 .6431 L .45912 .64215 L F
.45717 .64323 m .45561 .64431 L .45725 .6431 L F
.568 .193 .291 r
.62438 .53293 m .6221 .53483 L .62043 .53469 L F
.861 .645 .608 r
.62423 .53541 m .6221 .53483 L .62438 .53293 L F
0 .39 .713 r
.31421 .58475 m .31753 .58595 L .31552 .58609 L F
.608 .439 .628 r
.46091 .6901 m .46329 .68735 L .46088 .6877 L F
.193 .053 .45 r
.60799 .51828 m .60643 .52163 L .60835 .52031 L F
.179 .003 .389 r
.60612 .52366 m .60835 .52031 L .60643 .52163 L F
.487 .294 .544 r
.51578 .79469 m .51404 .79708 L .51365 .79471 L F
.973 .662 .324 r
.5171 .77222 m .51764 .77486 L .51654 .77288 L F
.228 .37 .799 r
.51606 .76944 m .5171 .77222 L .51828 .77107 L F
0 0 0 r
.5171 .77222 m .51654 .77288 L .51828 .77107 L F
.331 .814 .865 r
.34207 .60106 m .34267 .60043 L .34027 .6011 L F
.34207 .60106 m .34426 .6005 L .34267 .60043 L F
.633 .844 .981 r
.68427 .47461 m .6855 .47278 L .68654 .47365 L F
.68427 .47461 m .68318 .47362 L .6855 .47278 L F
.076 .55 .9 r
.27046 .77418 m .27096 .7743 L .27169 .77495 L F
.465 .815 .998 r
.27169 .77495 m .27096 .7743 L .27409 .77471 L F
.951 .931 .743 r
.27169 .77495 m .27096 .7743 L .27038 .77538 L F
.465 .815 .998 r
.27169 .77495 m .27096 .7743 L .27409 .77471 L F
.762 .939 .941 r
.50028 .64081 m .50065 .6425 L .50419 .6423 L F
.50028 .64081 m .49959 .6418 L .50065 .6425 L F
.478 .453 .752 r
.3891 .68221 m .39 .6847 L .39178 .68406 L F
.535 .527 .793 r
.39 .6847 m .39303 .68742 L .39178 .68406 L F
.871 .688 .162 r
.65634 .49058 m .6557 .48892 L .65492 .48926 L F
.65634 .49058 m .65634 .49298 L .6557 .48892 L F
.346 .12 .421 r
.60406 .58314 m .60594 .57979 L .60441 .58054 L F
.498 .274 .505 r
.60224 .58324 m .60406 .58314 L .60441 .58054 L F
0 .173 .703 r
.49061 .80924 m .49282 .81161 L .49326 .80909 L F
0 0 .097 r
.49376 .8088 m .49326 .80909 L .49282 .81161 L F
.797 .724 .784 r
.67794 .52718 m .67567 .53004 L .67479 .52692 L F
.699 .983 .845 r
.73474 .51104 m .73471 .51163 L .73293 .51202 L F
.835 .554 .514 r
.73471 .51163 m .73128 .51464 L .73293 .51202 L F
.73471 .51163 m .73371 .51318 L .73128 .51464 L F
.88 .665 .607 r
.63659 .54332 m .6385 .54419 L .63657 .54093 L F
.942 .882 .745 r
.63606 .54532 m .6385 .54419 L .63659 .54332 L F
.63606 .54532 m .63738 .54681 L .6385 .54419 L F
.945 .701 .234 r
.53256 .61424 m .53179 .61138 L .53485 .6115 L F
.53256 .61424 m .53196 .61336 L .53179 .61138 L F
.955 .666 .447 r
.53353 .6167 m .53196 .61336 L .53256 .61424 L F
.856 .469 .311 r
.53567 .61725 m .53353 .6167 L .53256 .61424 L F
.347 0 .019 r
.46329 .6985 m .46223 .70016 L .45979 .70029 L F
.515 .095 .182 r
.46563 .69832 m .46223 .70016 L .46329 .6985 L F
.058 0 0 r
.32507 .64737 m .32195 .64824 L .32307 .64783 L F
.55 .261 .429 r
.58902 .60321 m .58919 .60485 L .5859 .60583 L F
.58 .282 .427 r
.58902 .60321 m .59135 .60492 L .58919 .60485 L F
.595 .272 .392 r
.59142 .60327 m .59135 .60492 L .58902 .60321 L F
.6 .463 .667 r
.74345 .58782 m .74677 .58863 L .74588 .58508 L F
.319 .442 .829 r
.66939 .50461 m .67203 .50594 L .67065 .50752 L F
.553 .844 .516 r
.67203 .50594 m .66955 .50862 L .67065 .50752 L F
.501 .712 .965 r
.50419 .6423 m .50374 .6395 L .50028 .64081 L F
.50419 .6423 m .50589 .64171 L .50374 .6395 L F
.982 .695 .378 r
.65766 .4964 m .65647 .49546 L .65634 .49298 L F
.944 .698 .535 r
.65766 .4964 m .65586 .49771 L .65647 .49546 L F
.65766 .4964 m .65753 .49872 L .65586 .49771 L F
.499 .422 .701 r
.49697 .78615 m .49951 .78843 L .49939 .78582 L F
.49697 .78615 m .49732 .78826 L .49951 .78843 L F
.518 .249 .447 r
.35171 .63133 m .35127 .63337 L .34894 .63373 L F
.4 .138 .397 r
.35372 .63079 m .35127 .63337 L .35171 .63133 L F
.212 .732 .725 r
.31978 .63246 m .31998 .63232 L .32135 .63216 L F
.31978 .63246 m .3179 .63287 L .31998 .63232 L F
.843 .745 .755 r
.55124 .5917 m .55206 .59484 L .55033 .59361 L F
.827 .835 .854 r
.55206 .59484 m .54797 .59657 L .55033 .59361 L F
.751 .426 .435 r
.5189 .78264 m .5228 .78312 L .52224 .78111 L F
.071 .325 .804 r
.24583 .65671 m .24614 .65571 L .24469 .6547 L F
.515 .323 .559 r
.24684 .6532 m .24675 .65564 L .24882 .65524 L F
.24675 .65564 m .24673 .65617 L .24847 .6554 L F
.24675 .65564 m .24847 .6554 L .24882 .65524 L F
.642 .083 0 r
.24843 .6566 m .24617 .65572 L .24583 .65671 L F
.24617 .65572 m .24614 .65571 L .24614 .65573 L F
.24617 .65572 m .24614 .65573 L .24583 .65671 L F
.923 .975 .723 r
.67015 .53049 m .6686 .53314 L .6687 .5311 L F
.488 .886 .729 r
.67086 .52986 m .67091 .52969 L .67182 .529 L F
.241 .557 .933 r
.67091 .52969 m .67246 .52929 L .67095 .52955 L F
.986 .895 .575 r
.67091 .52969 m .67019 .52968 L .67083 .52769 L F
.241 .557 .933 r
.67091 .52969 m .67095 .52955 L .67019 .52968 L F
.488 .886 .729 r
.67015 .53049 m .67091 .52969 L .67086 .52986 L F
.67015 .53049 m .6687 .5311 L .67091 .52969 L F
0 0 .169 r
.61258 .50765 m .61219 .50977 L .61343 .50631 L F
.472 .763 .994 r
.50987 .63672 m .50868 .63781 L .50795 .63626 L F
.50987 .63672 m .51034 .63752 L .50868 .63781 L F
.524 .591 .863 r
.51142 .63864 m .50868 .63781 L .51034 .63752 L F
.62 .885 .989 r
.5854 .70664 m .58327 .70533 L .58118 .70656 L F
.021 0 .033 r
.46756 .65122 m .46837 .6521 L .46666 .65224 L F
0 0 .329 r
.46816 .64978 m .46756 .65122 L .46904 .65002 L F
.46816 .64978 m .46837 .6521 L .46756 .65122 L F
.835 .779 .798 r
.53485 .6115 m .53179 .61138 L .53409 .60856 L F
.461 .505 .818 r
.50614 .64281 m .50751 .64591 L .50902 .64415 L F
.482 .537 .837 r
.50751 .64591 m .51052 .64751 L .50902 .64415 L F
.55 .064 .054 r
.52432 .68749 m .52655 .68865 L .5282 .68712 L F
.639 .48 .651 r
.53109 .68955 m .52825 .69003 L .5282 .68712 L F
.434 .021 .153 r
.52655 .68865 m .53017 .68628 L .5282 .68712 L F
.721 .298 .242 r
.40098 .65629 m .40264 .65816 L .40425 .65684 L F
.637 .187 .165 r
.40264 .65816 m .40609 .65846 L .40425 .65684 L F
.46 .244 .497 r
.40425 .65684 m .40609 .65846 L .40629 .65622 L F
.303 .725 .973 r
.32223 .63144 m .32387 .63176 L .32351 .6318 L F
.471 0 0 r
.32351 .6318 m .32743 .63088 L .32535 .63143 L F
.32351 .6318 m .3256 .6321 L .32743 .63088 L F
.303 .725 .973 r
.32387 .63176 m .3256 .6321 L .32351 .6318 L F
0 0 0 r
.3229 .63188 m .32351 .6318 L .32535 .63143 L F
.32135 .63216 m .32351 .6318 L .3229 .63188 L F
.472 .454 .757 r
.3891 .68221 m .39178 .68406 L .3908 .68093 L F
.629 .528 .721 r
.39171 .69318 m .39413 .69306 L .39347 .69074 L F
.16 .066 .491 r
.39171 .69318 m .39297 .6957 L .39413 .69306 L F
.39171 .69318 m .39161 .69673 L .39297 .6957 L F
.677 .755 .91 r
.58378 .72708 m .5844 .7242 L .58219 .72569 L F
.58378 .72708 m .58534 .72562 L .5844 .7242 L F
.423 .464 .798 r
.51052 .64751 m .5116 .65094 L .51331 .65053 L F
.51 .904 .768 r
.47246 .63611 m .47355 .63512 L .47683 .63444 L F
.761 .981 .912 r
.47683 .63444 m .47651 .63305 L .47758 .63359 L F
.47683 .63444 m .47355 .63512 L .47651 .63305 L F
.146 0 0 r
.41066 .7131 m .40977 .71319 L .40699 .71295 L F
.644 .966 .832 r
.41147 .71191 m .41066 .7131 L .41233 .71178 L F
.643 .966 .838 r
.41147 .71191 m .40977 .71319 L .41066 .7131 L F
.983 .867 .642 r
.63529 .54883 m .63738 .54681 L .63606 .54532 L F
.63529 .54883 m .63619 .54969 L .63738 .54681 L F
.573 .321 .497 r
.74341 .5047 m .74597 .50642 L .74343 .50658 L F
.541 .338 .554 r
.74596 .50415 m .74597 .50642 L .74341 .5047 L F
.135 .492 .904 r
.50456 .63267 m .5068 .63325 L .50679 .63444 L F
0 0 .576 r
.5068 .63325 m .50795 .63626 L .50679 .63444 L F
.902 .515 .277 r
.55638 .73769 m .55946 .74095 L .55804 .73771 L F
.378 .137 .418 r
.71483 .50949 m .71489 .50767 L .71702 .50683 L F
.594 .023 0 r
.48108 .80852 m .47728 .80626 L .48047 .80773 L F
.701 .58 .717 r
.48333 .80571 m .48359 .80786 L .48132 .80846 L F
.48125 .80831 m .48132 .80846 L .48108 .80852 L F
.48333 .80571 m .48132 .80846 L .48125 .80831 L F
0 0 0 r
.48311 .80625 m .48333 .80571 L .48125 .80831 L F
.48311 .80625 m .48125 .80831 L .48108 .80852 L F
0 0 .476 r
.48232 .80313 m .48333 .80571 L .48319 .80434 L F
.419 .45 .785 r
.48151 .80458 m .48038 .80471 L .48013 .80315 L F
.48311 .80625 m .48038 .80471 L .48151 .80458 L F
.48311 .80625 m .48013 .80315 L .48065 .80479 L F
.882 .7 .651 r
.48319 .80434 m .48311 .80625 L .48065 .80479 L F
.48319 .80438 m .48065 .80479 L .48319 .80443 L F
.48319 .80434 m .48247 .80446 L .48319 .80438 L F
.48247 .80446 m .48065 .80479 L .48319 .80438 L F
.419 .45 .785 r
.48311 .80625 m .48083 .80753 L .48038 .80471 L F
.48083 .80753 m .48047 .80773 L .4804 .80672 L F
.48083 .80753 m .4804 .80672 L .48013 .80315 L F
0 0 0 r
.48311 .80625 m .48108 .80852 L .48047 .80773 L F
.458 .192 .422 r
.40362 .71286 m .40195 .71222 L .40492 .71246 L F
.40362 .71286 m .40187 .71345 L .40195 .71222 L F
0 0 .05 r
.47242 .79688 m .47106 .80038 L .47205 .79904 L F
.147 .26 .724 r
.47106 .80038 m .47313 .80257 L .47205 .79904 L F
.604 .822 .984 r
.26488 .6482 m .26046 .64832 L .26298 .6456 L F
.144 0 0 r
.26298 .6456 m .26367 .64541 L .26418 .64502 L F
.678 .66 .825 r
.26298 .6456 m .26046 .64832 L .25931 .64438 L F
.144 0 0 r
.26298 .6456 m .26143 .64653 L .26327 .64561 L F
.26298 .6456 m .26327 .64561 L .26367 .64541 L F
.054 .344 .821 r
.26428 .64547 m .26523 .64708 L .26488 .6482 L F
.188 .443 .871 r
.26471 .6454 m .26418 .64502 L .26367 .64541 L F
.865 .82 .802 r
.26719 .64394 m .26653 .64501 L .26418 .64502 L F
.26653 .64501 m .26578 .6462 L .26471 .6454 L F
.26653 .64501 m .26471 .6454 L .26418 .64502 L F
.26578 .6462 m .26523 .64708 L .26441 .64547 L F
0 0 0 r
.26415 .64547 m .26558 .64539 L .26355 .64549 L F
.865 .82 .802 r
.26471 .6454 m .26441 .64547 L .26418 .64502 L F
.26578 .6462 m .26441 .64547 L .26471 .6454 L F
0 0 0 r
.26355 .64549 m .26452 .64544 L .26367 .64541 L F
.26452 .64544 m .26558 .64539 L .26471 .6454 L F
.26452 .64544 m .26471 .6454 L .26367 .64541 L F
.054 .344 .821 r
.26441 .64547 m .26523 .64708 L .26428 .64547 L F
.188 .443 .871 r
.26558 .64539 m .26523 .64708 L .26441 .64547 L F
0 0 0 r
.26441 .64547 m .26469 .64545 L .26443 .64546 L F
.188 .443 .871 r
.26558 .64539 m .26418 .64502 L .26471 .6454 L F
0 0 0 r
.26546 .64541 m .26558 .64539 L .26352 .64551 L F
.188 .443 .871 r
.26558 .64539 m .26441 .64547 L .26418 .64502 L F
0 0 0 r
.26314 .64574 m .26546 .64541 L .26469 .64545 L F
.054 .344 .821 r
.26428 .64547 m .26433 .64568 L .26312 .64553 L F
0 0 0 r
.26314 .64574 m .26469 .64545 L .26441 .64547 L F
.054 .344 .821 r
.26312 .64553 m .26433 .64568 L .26298 .6456 L F
0 0 0 r
.26314 .64574 m .26443 .64546 L .26352 .64551 L F
.054 .344 .821 r
.26433 .64568 m .26488 .6482 L .26306 .64571 L F
.26327 .64561 m .26306 .64571 L .26298 .6456 L F
.26433 .64568 m .26306 .64571 L .26327 .64561 L F
0 0 0 r
.26352 .64551 m .26143 .64653 L .26314 .64574 L F
.26367 .64541 m .26327 .64561 L .26352 .64551 L F
.26327 .64561 m .26143 .64653 L .26352 .64551 L F
.26314 .64574 m .26443 .64546 L .26314 .64574 L F
.054 .344 .821 r
.26418 .64502 m .26441 .64547 L .26428 .64547 L F
0 0 0 r
.26352 .64551 m .26415 .64547 L .26355 .64549 L F
.422 .818 .597 r
.26367 .64541 m .26352 .64551 L .26418 .64502 L F
.054 .344 .821 r
.26418 .64502 m .26352 .64551 L .26312 .64553 L F
.422 .818 .597 r
.26352 .64551 m .26314 .64574 L .26418 .64502 L F
.054 .344 .821 r
.26418 .64502 m .26428 .64547 L .26352 .64551 L F
0 .206 .729 r
.26523 .64708 m .26697 .65043 L .26488 .6482 L F
.095 0 0 r
.32148 .60096 m .31975 .60167 L .31751 .60195 L F
.029 0 0 r
.3229 .60119 m .31975 .60167 L .32148 .60096 L F
.461 0 0 r
.24342 .65236 m .2446 .65208 L .24356 .65052 L F
.24339 .65277 m .24356 .65052 L .24474 .65011 L F
.746 .592 .685 r
.24327 .65239 m .24474 .65011 L .24481 .64983 L F
.24306 .65275 m .24329 .65239 L .24327 .65239 L F
.24329 .65239 m .24474 .65011 L .24327 .65239 L F
.461 0 0 r
.24339 .65277 m .24486 .65246 L .2446 .65208 L F
.24339 .65277 m .2446 .65208 L .24342 .65236 L F
.24339 .65277 m .24684 .6532 L .24486 .65246 L F
.794 .611 .654 r
.76965 .57458 m .77232 .57624 L .77162 .57557 L F
.76965 .57458 m .77112 .57808 L .77232 .57624 L F
.785 .752 .823 r
.67794 .52718 m .67479 .52692 L .67655 .5258 L F
.586 .708 .927 r
.68034 .52661 m .67794 .52718 L .67655 .5258 L F
.607 .574 .792 r
.68148 .53002 m .67794 .52718 L .68034 .52661 L F
.522 .345 .582 r
.34016 .62251 m .34232 .61944 L .34069 .6202 L F
.657 .81 .957 r
.26046 .64832 m .25898 .64864 L .25708 .64742 L F
.495 .281 .517 r
.36387 .62006 m .36363 .62246 L .36151 .62301 L F
.5 .285 .518 r
.36571 .62181 m .36387 .62006 L .36597 .61958 L F
.36571 .62181 m .36363 .62246 L .36387 .62006 L F
.407 .054 .251 r
.54983 .76321 m .55204 .76283 L .55312 .76042 L F
.271 0 0 r
.55204 .76283 m .55542 .76088 L .55312 .76042 L F
.626 .41 .568 r
.52763 .76835 m .53008 .76598 L .52841 .76718 L F
.667 .736 .902 r
.72626 .48092 m .72652 .48268 L .72355 .48188 L F
.316 .382 .772 r
.72933 .48311 m .72864 .4831 L .72863 .48261 L F
.72958 .48329 m .72937 .48325 L .72933 .48311 L F
.72937 .48325 m .72864 .4831 L .72933 .48311 L F
.72958 .48329 m .72899 .48427 L .72652 .48268 L F
.258 .428 .84 r
.72864 .48167 m .7292 .48263 L .72863 .48261 L F
.7292 .48263 m .72958 .48329 L .72933 .48311 L F
.7292 .48263 m .72933 .48311 L .72863 .48261 L F
.538 .344 .566 r
.72739 .47953 m .72848 .47993 L .72958 .48329 L F
.439 .542 .865 r
.72848 .47993 m .72899 .48427 L .72958 .48329 L F
.904 .653 .147 r
.72864 .4813 m .72991 .48614 L .72899 .48427 L F
.72865 .48091 m .72991 .48614 L .72864 .4813 L F
.72853 .48017 m .72991 .48614 L .72854 .48049 L F
.72865 .48067 m .72942 .4855 L .72991 .48614 L F
.72853 .48017 m .72857 .48039 L .72865 .48067 L F
.72848 .47993 m .72853 .48017 L .72854 .48049 L F
.72848 .47993 m .72849 .48003 L .72853 .48017 L F
.72849 .48003 m .72942 .4855 L .72853 .48017 L F
.72857 .48039 m .72871 .48123 L .72865 .48067 L F
.72871 .48123 m .72942 .4855 L .7288 .48159 L F
.72871 .48123 m .7288 .48159 L .72865 .48067 L F
.167 .203 .655 r
.72983 .48208 m .72942 .4855 L .72906 .48336 L F
.72969 .48186 m .72906 .48336 L .72848 .47993 L F
.72983 .48208 m .72906 .48336 L .72969 .48186 L F
.538 .344 .566 r
.72909 .48091 m .72995 .48161 L .72848 .47993 L F
.167 .203 .655 r
.7294 .48081 m .72909 .48091 L .72848 .47993 L F
.208 .335 .774 r
.72856 .47797 m .72962 .48073 L .72852 .48045 L F
.72962 .48073 m .72995 .48161 L .7294 .48081 L F
.167 .203 .655 r
.72992 .48129 m .7294 .48081 L .72995 .48161 L F
.7294 .48081 m .72848 .47993 L .72995 .48161 L F
.208 .335 .774 r
.7294 .48081 m .72995 .48161 L .72909 .48091 L F
.72962 .48073 m .72909 .48091 L .72852 .48045 L F
.167 .203 .655 r
.72992 .48129 m .72909 .48091 L .7294 .48081 L F
.72992 .48129 m .72992 .48131 L .72909 .48091 L F
.658 .879 .98 r
.72991 .48133 m .72981 .48147 L .72995 .48161 L F
.982 .866 .644 r
.72995 .48161 m .72981 .48157 L .72991 .48133 L F
.167 .203 .655 r
.72992 .48131 m .72983 .48208 L .72962 .48175 L F
.72981 .48126 m .72962 .48175 L .72909 .48091 L F
.982 .866 .644 r
.72981 .48157 m .72894 .48067 L .72854 .48119 L F
.72995 .48161 m .72981 .48147 L .72981 .48157 L F
.167 .203 .655 r
.72981 .48147 m .72962 .48175 L .72981 .48126 L F
.982 .866 .644 r
.72981 .48147 m .72894 .48067 L .72981 .48157 L F
.167 .203 .655 r
.72992 .48131 m .72981 .48147 L .72981 .48126 L F
.658 .879 .98 r
.7299 .48128 m .72894 .48067 L .72981 .48147 L F
.298 .395 .793 r
.73119 .4797 m .72995 .48161 L .72856 .47797 L F
.658 .879 .98 r
.7299 .48129 m .72981 .48147 L .72991 .48133 L F
.7299 .48129 m .72981 .48147 L .7299 .48129 L F
.982 .866 .644 r
.72981 .48157 m .72854 .48119 L .72992 .48129 L F
.258 .428 .84 r
.72739 .47953 m .72864 .48167 L .72626 .48092 L F
.72864 .48167 m .72863 .48261 L .72626 .48092 L F
.316 .382 .772 r
.72863 .48261 m .72652 .48268 L .72626 .48092 L F
.72864 .4831 m .72652 .48268 L .72863 .48261 L F
.949 .95 .648 r
.72721 .48577 m .72992 .4813 L .72854 .48119 L F
.72992 .4813 m .72992 .48129 L .7299 .48129 L F
.72992 .4813 m .7299 .48129 L .72854 .48119 L F
.658 .879 .98 r
.7299 .48128 m .7299 .48129 L .7299 .48129 L F
.72974 .48032 m .72936 .48049 L .7299 .48128 L F
.72936 .48049 m .72894 .48067 L .7299 .48128 L F
.976 .878 .672 r
.72765 .48652 m .72942 .4855 L .72992 .48131 L F
.982 .866 .644 r
.72995 .48161 m .72991 .48133 L .72992 .48129 L F
.976 .878 .672 r
.72992 .48131 m .72992 .48131 L .72992 .48129 L F
.72765 .48652 m .72992 .48131 L .72992 .48131 L F
.658 .879 .98 r
.73119 .4797 m .72974 .48032 L .72995 .48161 L F
.538 .344 .566 r
.72739 .47953 m .72909 .48091 L .72848 .47993 L F
.208 .335 .774 r
.72809 .47861 m .72852 .48045 L .72739 .47953 L F
.72856 .47797 m .72852 .48045 L .72809 .47861 L F
.904 .653 .147 r
.72854 .48049 m .72865 .48091 L .72864 .4813 L F
0 0 0 r
.33222 .64474 m .33403 .64343 L .33586 .64263 L F
.604 .584 .804 r
.53673 .65949 m .53945 .65948 L .53788 .65682 L F
.53788 .65682 m .53945 .65948 L .53673 .65949 L F
.817 .939 .908 r
.56256 .77773 m .56383 .77508 L .56205 .77758 L F
.56256 .77773 m .5652 .77562 L .56383 .77508 L F
.769 .434 .419 r
.49578 .80218 m .49714 .80024 L .49211 .79981 L F
.778 .445 .425 r
.49578 .80218 m .49938 .80321 L .49714 .80024 L F
.687 .587 .738 r
.49714 .80024 m .49981 .80019 L .49885 .7978 L F
.672 .441 .562 r
.49714 .80024 m .49938 .80321 L .49981 .80019 L F
.334 0 .048 r
.305 .60579 m .30362 .60748 L .30158 .60786 L F
.234 0 0 r
.30568 .60695 m .305 .60579 L .30727 .6051 L F
.30568 .60695 m .30362 .60748 L .305 .60579 L F
.86 .732 .719 r
.6463 .51102 m .6456 .51328 L .64452 .50978 L F
.6463 .51102 m .6456 .51328 L .64452 .50978 L F
.534 .381 .62 r
.64749 .51178 m .6456 .51328 L .6463 .51102 L F
.945 .76 .621 r
.4721 .80572 m .47249 .80793 L .47335 .80799 L F
0 0 .45 r
.47249 .80793 m .47373 .81061 L .47335 .80799 L F
.47249 .80793 m .47311 .81099 L .47373 .81061 L F
.623 .527 .725 r
.66743 .51891 m .66761 .52118 L .67044 .52065 L F
.644 .592 .781 r
.66761 .52118 m .67101 .52315 L .67044 .52065 L F
.699 .447 .54 r
.58222 .69807 m .57942 .69582 L .58359 .69533 L F
.784 .605 .659 r
.58551 .6959 m .58222 .69807 L .58359 .69533 L F
.947 .744 .595 r
.58359 .69533 m .58222 .69807 L .5818 .69564 L F
.988 .892 .624 r
.66452 .4926 m .66367 .49487 L .66521 .4937 L F
.492 0 0 r
.40492 .71246 m .40699 .71295 L .40362 .71286 L F
.544 .339 .552 r
.47814 .65875 m .4802 .65944 L .48055 .65656 L F
.471 .398 .692 r
.49732 .78826 m .49885 .79081 L .49951 .78843 L F
.49732 .78826 m .49794 .79174 L .49885 .79081 L F
0 0 0 r
.6686 .53314 m .66885 .53283 L .6687 .5311 L F
.6686 .53314 m .6677 .53531 L .66885 .53283 L F
.954 .851 .701 r
.64358 .51608 m .64146 .51704 L .64268 .51753 L F
.742 .933 .594 r
.64442 .51433 m .64358 .51608 L .6456 .51328 L F
.765 .996 .83 r
.64442 .51433 m .64146 .51704 L .64358 .51608 L F
.802 .76 .814 r
.58987 .69679 m .58736 .69934 L .58566 .69846 L F
.848 .729 .732 r
.58736 .69934 m .58644 .70162 L .58566 .69846 L F
.692 .224 .135 r
.519 .76588 m .52059 .76732 L .52214 .76619 L F
0 0 .51 r
.52328 .76737 m .52214 .76619 L .52059 .76732 L F
.52328 .76737 m .52425 .76862 L .52217 .76622 L F
.48 .06 .165 r
.52156 .76946 m .52404 .76815 L .52328 .76737 L F
0 .131 .652 r
.52328 .76737 m .52427 .76803 L .52425 .76862 L F
.48 .06 .165 r
.52404 .76815 m .52427 .76803 L .52328 .76737 L F
0 0 .51 r
.52328 .76737 m .52217 .76622 L .52214 .76619 L F
.449 0 0 r
.51915 .64809 m .52117 .64926 L .52315 .64934 L F
.52117 .64926 m .52133 .64935 L .52178 .64934 L F
.52117 .64926 m .52178 .64934 L .52315 .64934 L F
.52133 .64935 m .52141 .64939 L .52175 .64949 L F
.672 .528 .68 r
.52143 .6494 m .52178 .65308 L .52168 .64949 L F
.449 0 0 r
.52141 .64939 m .5216 .6495 L .5217 .64949 L F
.52141 .64939 m .5217 .64949 L .52175 .64949 L F
.672 .528 .68 r
.52168 .64949 m .52178 .65308 L .52374 .65186 L F
.449 0 0 r
.52133 .64935 m .52175 .64949 L .52315 .64934 L F
.672 .528 .68 r
.52141 .64919 m .52143 .6494 L .52168 .64949 L F
.238 .166 .568 r
.52141 .64919 m .5216 .6495 L .5214 .64939 L F
.52141 .64919 m .5214 .64939 L .51915 .64809 L F
.571 .453 .679 r
.51907 .65321 m .52109 .65311 L .52141 .64919 L F
.52109 .65311 m .52178 .65308 L .52141 .64919 L F
.238 .166 .568 r
.52141 .64919 m .51915 .64809 L .51808 .64952 L F
.628 .631 .835 r
.51931 .64866 m .52098 .64923 L .51808 .64952 L F
.825 .912 .511 r
.51906 .64764 m .51808 .64952 L .51915 .64809 L F
.628 .631 .835 r
.52112 .6474 m .51917 .64876 L .51906 .64764 L F
.51917 .64876 m .51808 .64952 L .51876 .64821 L F
.51917 .64876 m .51876 .64821 L .51906 .64764 L F
.608 .14 .116 r
.52098 .64923 m .51664 .64924 L .51808 .64952 L F
.52074 .64919 m .51664 .64924 L .52098 .64923 L F
.569 .486 .721 r
.51667 .65368 m .51808 .64952 L .51564 .65028 L F
.51667 .65368 m .51907 .65321 L .51808 .64952 L F
.205 .719 .883 r
.51808 .64952 m .51439 .64934 L .51564 .65028 L F
.51808 .64952 m .51664 .64924 L .51439 .64934 L F
.571 .453 .679 r
.51907 .65321 m .52141 .64919 L .51808 .64952 L F
.608 .14 .116 r
.51949 .64921 m .51896 .65062 L .51664 .64924 L F
.628 .631 .835 r
.52112 .6474 m .52141 .64919 L .52098 .64923 L F
.608 .14 .116 r
.52141 .64919 m .52074 .64919 L .52098 .64923 L F
.52141 .64919 m .52006 .64998 L .51949 .64921 L F
.52006 .64998 m .51896 .65062 L .51949 .64921 L F
.628 .631 .835 r
.52112 .6474 m .52098 .64923 L .51931 .64866 L F
.522 0 0 r
.52195 .64947 m .52241 .64927 L .52315 .64934 L F
.52169 .64949 m .52193 .64941 L .52195 .64947 L F
.52172 .64947 m .52193 .64941 L .52169 .64949 L F
.52193 .64941 m .52241 .64927 L .52195 .64947 L F
.52241 .64927 m .52518 .64846 L .52363 .64913 L F
.52241 .64927 m .52363 .64913 L .52315 .64934 L F
.52172 .64947 m .52375 .64946 L .52518 .64846 L F
.672 .528 .68 r
.52169 .6495 m .5222 .64974 L .52172 .64947 L F
.522 0 0 r
.5216 .6495 m .52172 .64947 L .52169 .64949 L F
.5216 .6495 m .52178 .6495 L .52172 .64947 L F
.52178 .6495 m .52375 .64946 L .52172 .64947 L F
.672 .528 .68 r
.52169 .6495 m .52374 .65186 L .5222 .64974 L F
.52172 .64947 m .5222 .64974 L .5219 .64933 L F
.5219 .64933 m .52374 .65186 L .52228 .64944 L F
.242 0 0 r
.52141 .64919 m .52375 .64946 L .52178 .6495 L F
.672 .528 .68 r
.52141 .64919 m .52169 .6495 L .52173 .64946 L F
.242 0 0 r
.52141 .64919 m .52178 .6495 L .5216 .6495 L F
.672 .528 .68 r
.52141 .64919 m .52173 .64946 L .5219 .64933 L F
.242 0 0 r
.52226 .64929 m .52228 .64944 L .52375 .64946 L F
.5219 .64933 m .52228 .64944 L .52226 .64929 L F
.673 .506 .651 r
.52266 .64641 m .52501 .64565 L .52228 .64944 L F
0 0 0 r
.52279 .64938 m .52187 .64925 L .52228 .64944 L F
.242 0 0 r
.52141 .64919 m .5219 .64933 L .52226 .64929 L F
.192 .082 .491 r
.52266 .64641 m .52228 .64944 L .52141 .64919 L F
0 0 0 r
.52187 .64925 m .52141 .64919 L .5219 .64933 L F
.52187 .64925 m .5219 .64933 L .52228 .64944 L F
.309 .728 .975 r
.34349 .58925 m .34768 .58987 L .34552 .59025 L F
.672 .687 .855 r
.70797 .50616 m .70881 .50746 L .70577 .50714 L F
.174 0 0 r
.70797 .50616 m .71089 .50615 L .70881 .50746 L F
.697 .638 .786 r
.68192 .4791 m .68344 .48051 L .68528 .47979 L F
.181 .171 .61 r
.47292 .76906 m .47313 .77248 L .47453 .77127 L F
.28 .28 .681 r
.47313 .77248 m .47546 .77349 L .47453 .77127 L F
.47313 .77248 m .47379 .77472 L .47546 .77349 L F
.007 0 0 r
.48569 .6491 m .48561 .64951 L .48338 .64997 L F
0 0 0 r
.48742 .64569 m .48561 .64951 L .48569 .6491 L F
.567 .539 .784 r
.67685 .53592 m .67964 .53589 L .67811 .53182 L F
.77 .612 .683 r
.68769 .47905 m .691 .48064 L .68997 .47851 L F
.68769 .47905 m .68706 .4822 L .691 .48064 L F
.575 .786 .979 r
.691 .48064 m .69236 .47859 L .68997 .47851 L F
.691 .48064 m .69329 .47995 L .69236 .47859 L F
.502 .423 .7 r
.75134 .59505 m .75306 .59066 L .75046 .59186 L F
.75134 .59505 m .75259 .59526 L .75306 .59066 L F
.511 .394 .657 r
.75134 .59505 m .75399 .59692 L .75259 .59526 L F
.32 .238 .604 r
.41885 .68982 m .4192 .69244 L .41745 .69022 L F
.538 .909 .732 r
.66689 .47656 m .66417 .47819 L .66588 .47606 L F
.666 .931 .971 r
.66921 .47538 m .66689 .47656 L .66815 .47484 L F
.672 .94 .965 r
.66689 .47656 m .66588 .47606 L .66815 .47484 L F
.886 .64 .562 r
.53578 .6195 m .53353 .6167 L .53567 .61725 L F
0 0 0 r
.38361 .59777 m .3824 .59779 L .38117 .59788 L F
.397 .121 .373 r
.53318 .79066 m .5327 .78909 L .53629 .78869 L F
.079 0 0 r
.52348 .69573 m .52052 .69793 L .52161 .69662 L F
.644 .193 .166 r
.47244 .69053 m .47471 .69213 L .47609 .69072 L F
.337 0 .003 r
.47471 .69213 m .47809 .69032 L .47609 .69072 L F
0 0 0 r
.47728 .80626 m .48 .80275 L .48013 .80315 L F
.353 .774 .976 r
.48076 .8019 m .48 .80275 L .48228 .80248 L F
0 0 .01 r
.48013 .80315 m .48 .80275 L .48076 .8019 L F
.45 .738 .989 r
.48 .80275 m .48232 .80313 L .48228 .80248 L F
.945 .648 .445 r
.48969 .77142 m .49173 .77453 L .49123 .77201 L F
.635 .951 .941 r
.46526 .64061 m .46623 .63916 L .46736 .63965 L F
.46526 .64061 m .46328 .64064 L .46623 .63916 L F
.547 .115 .172 r
.2852 .58469 m .28733 .58506 L .28557 .58398 L F
.993 .828 .573 r
.46974 .64819 m .46816 .64978 L .46904 .65002 L F
0 0 0 r
.47022 .64804 m .46974 .64819 L .4716 .64818 L F
.47022 .64804 m .46816 .64978 L .46974 .64819 L F
.648 .792 .951 r
.70577 .50714 m .70175 .50624 L .70416 .50417 L F
.678 .712 .874 r
.70797 .50616 m .70577 .50714 L .70416 .50417 L F
.472 .211 .437 r
.63093 .48699 m .63321 .48639 L .63341 .48484 L F
.54 .35 .572 r
.63321 .48639 m .6358 .48394 L .63341 .48484 L F
.783 .733 .806 r
.54775 .60078 m .54419 .60085 L .54628 .59964 L F
.354 0 0 r
.41865 .7103 m .41678 .71108 L .41443 .71085 L F
.179 0 0 r
.41865 .7103 m .41906 .7108 L .41678 .71108 L F
.41865 .7103 m .42103 .71041 L .41906 .7108 L F
.854 .838 .829 r
.25044 .65388 m .25119 .64949 L .25144 .65141 L F
.683 .655 .816 r
.65845 .52063 m .65938 .5231 L .66193 .52146 L F
.559 .388 .607 r
.76287 .5806 m .76613 .57777 L .76276 .57896 L F
.436 0 0 r
.48318 .69672 m .48171 .69734 L .47959 .69648 L F
.614 .073 0 r
.48318 .69672 m .4852 .6981 L .48171 .69734 L F
0 0 0 r
.58193 .71763 m .58366 .71537 L .5813 .71588 L F
.724 .557 .664 r
.47602 .64915 m .4786 .64879 L .47818 .6475 L F
.47602 .64915 m .47893 .65089 L .4786 .64879 L F
.53 .596 .865 r
.47818 .6475 m .4786 .64879 L .48014 .64691 L F
.678 .525 .671 r
.4786 .64879 m .48137 .64865 L .48014 .64691 L F
.4786 .64879 m .47893 .65089 L .48137 .64865 L F
.786 .453 .424 r
.7516 .5855 m .75392 .58441 L .75186 .58289 L F
.7516 .5855 m .75494 .58589 L .75392 .58441 L F
.31 0 0 r
.30474 .58428 m .30824 .5851 L .30636 .58481 L F
.224 .276 .706 r
.47292 .76906 m .47402 .76893 L .47341 .76558 L F
.212 .181 .604 r
.47292 .76906 m .47453 .77127 L .47402 .76893 L F
.773 .538 .58 r
.52232 .7856 m .52629 .78326 L .5228 .78312 L F
.52232 .7856 m .52639 .78536 L .52629 .78326 L F
.651 .416 .55 r
.60262 .59742 m .6027 .59996 L .59932 .59997 L F
.629 .415 .572 r
.60262 .59742 m .6051 .59962 L .6027 .59996 L F
.60262 .59742 m .60514 .59728 L .6051 .59962 L F
.847 .809 .813 r
.56151 .77215 m .55947 .77481 L .55864 .77286 L F
.709 .596 .024 r
.55947 .77481 m .55941 .77667 L .55864 .77286 L F
.55947 .77481 m .55939 .77746 L .55941 .77667 L F
.765 .662 .748 r
.38606 .69594 m .38409 .6993 L .38256 .69607 L F
.791 .417 0 r
.38256 .69607 m .38409 .6993 L .38287 .69691 L F
.503 .773 .992 r
.38409 .6993 m .38452 .69769 L .38287 .69691 L F
.519 .353 .595 r
.38606 .69594 m .38622 .69894 L .38409 .6993 L F
.503 .773 .992 r
.38409 .6993 m .38622 .69894 L .38452 .69769 L F
.455 .197 .433 r
.62349 .49332 m .62576 .49273 L .626 .49078 L F
.428 .175 .426 r
.626 .49078 m .62798 .49201 L .62823 .49009 L F
.626 .49078 m .62576 .49273 L .62798 .49201 L F
.987 .747 .359 r
.61969 .55529 m .61889 .55684 L .61969 .55336 L F
.61969 .55529 m .61968 .55767 L .61889 .55684 L F
.787 .674 .74 r
.55405 .63163 m .5491 .63195 L .55352 .62889 L F
.745 .452 .486 r
.55405 .63163 m .5537 .63359 L .5491 .63195 L F
.645 .528 .707 r
.55604 .62817 m .55405 .63163 L .55352 .62889 L F
.55604 .62817 m .55669 .63131 L .55405 .63163 L F
.412 .149 .402 r
.55587 .63261 m .55405 .63163 L .55669 .63131 L F
.55587 .63261 m .5537 .63359 L .55405 .63163 L F
.631 .6 .8 r
.25947 .62567 m .26038 .62168 L .25838 .62276 L F
.25947 .62567 m .26196 .62539 L .26038 .62168 L F
.51 .904 .768 r
.47246 .63611 m .47176 .63625 L .47355 .63512 L F
.992 .741 .393 r
.56755 .75214 m .56741 .75576 L .56827 .75544 L F
.936 .62 .167 r
.56741 .75576 m .56832 .75762 L .56827 .75544 L F
.717 .831 .935 r
.72136 .4848 m .71907 .48597 L .71794 .48471 L F
.661 .65 .829 r
.51581 .65993 m .51704 .66265 L .51946 .6622 L F
.521 .832 1 r
.67814 .47554 m .675 .47523 L .67718 .47495 L F
.6 .883 .991 r
.67948 .47399 m .67814 .47554 L .67718 .47495 L F
.67948 .47399 m .68044 .47474 L .67814 .47554 L F
.247 0 .094 r
.34525 .63814 m .3442 .63746 L .34639 .63684 L F
.34525 .63814 m .34334 .63878 L .3442 .63746 L F
.366 .208 .531 r
.55059 .77485 m .55243 .77688 L .55242 .77244 L F
.55059 .77485 m .55057 .77747 L .55243 .77688 L F
.867 .925 .535 r
.58844 .56776 m .58799 .56986 L .58961 .56635 L F
0 0 0 r
.58961 .56635 m .59078 .56502 L .58844 .56776 L F
.344 0 .052 r
.42556 .65274 m .42786 .65236 L .42936 .65049 L F
.435 0 .014 r
.42786 .65236 m .43168 .65095 L .42936 .65049 L F
.259 0 .091 r
.34016 .62251 m .33816 .62316 L .33736 .62447 L F
.989 .721 .402 r
.50499 .8104 m .50535 .81148 L .5044 .81128 L F
.046 .206 .706 r
.50617 .81005 m .50535 .81148 L .50433 .80841 L F
.658 .964 .925 r
.5044 .81128 m .50535 .81148 L .50617 .81005 L F
0 0 0 r
.50358 .81251 m .5044 .81128 L .50617 .81005 L F
.50302 .81303 m .5044 .81128 L .50358 .81251 L F
.989 .721 .402 r
.50433 .80841 m .50499 .8104 L .5044 .81128 L F
.52 .281 .492 r
.34232 .61944 m .3449 .61686 L .34271 .61735 L F
.583 .58 .816 r
.67101 .52315 m .67253 .52001 L .67044 .52065 L F
.67101 .52315 m .67357 .52226 L .67253 .52001 L F
.924 .775 .677 r
.66868 .50086 m .66939 .50461 L .67051 .50236 L F
.55 .429 .668 r
.38971 .67316 m .39163 .67004 L .38953 .67054 L F
.299 .13 .476 r
.61129 .56933 m .61289 .56861 L .61301 .56636 L F
.15 .006 .416 r
.61129 .56933 m .61245 .57059 L .61289 .56861 L F
.61129 .56933 m .61117 .5717 L .61245 .57059 L F
.94 .823 .702 r
.72789 .51279 m .72922 .50962 L .72818 .50817 L F
.404 .102 .336 r
.62823 .49009 m .63042 .48951 L .63093 .48699 L F
.482 .187 .388 r
.63042 .48951 m .63321 .48639 L .63093 .48699 L F
.718 .448 .517 r
.5018 .80852 m .49832 .81092 L .49806 .80889 L F
.567 .578 .824 r
.4992 .62774 m .49827 .63143 L .49698 .62836 L F
.4992 .62774 m .50052 .63104 L .49827 .63143 L F
0 .1 .624 r
.49717 .77499 m .4979 .77784 L .49877 .77672 L F
.341 .644 .966 r
.4979 .77784 m .49997 .77812 L .49877 .77672 L F
.03 0 .205 r
.62361 .57731 m .62357 .57938 L .62166 .58045 L F
.009 0 .162 r
.62357 .57938 m .62158 .58233 L .62166 .58045 L F
.52 .881 .98 r
.48235 .81561 m .48589 .81515 L .48453 .81384 L F
.7 .768 .905 r
.48589 .81515 m .48798 .81424 L .48453 .81384 L F
.761 .675 .767 r
.68394 .52719 m .68148 .53002 L .68034 .52661 L F
.695 .757 .9 r
.78173 .59854 m .7827 .596 L .78076 .59732 L F
.78173 .59854 m .78408 .5974 L .7827 .596 L F
.62 .789 .963 r
.78076 .59732 m .78173 .59854 L .7783 .59826 L F
.7783 .59826 m .78173 .59854 L .78076 .59732 L F
.22 .742 .782 r
.31542 .60214 m .31203 .60273 L .31355 .6023 L F
.456 .121 .309 r
.5788 .70377 m .57776 .70648 L .5755 .7068 L F
.587 .493 .715 r
.58036 .70096 m .58102 .70442 L .5788 .70377 L F
.73 .402 .425 r
.58118 .70656 m .5788 .70377 L .58102 .70442 L F
.58118 .70656 m .57776 .70648 L .5788 .70377 L F
.671 .394 .493 r
.51704 .66727 m .52078 .66778 L .51934 .66714 L F
.387 .169 .456 r
.36363 .62246 m .3614 .62508 L .36151 .62301 L F
.666 .556 .721 r
.51704 .66727 m .51832 .67005 L .52078 .66778 L F
.623 .527 .725 r
.66743 .51891 m .67044 .52065 L .67001 .51829 L F
.559 .388 .607 r
.76287 .5806 m .76544 .58024 L .76613 .57777 L F
.993 .774 .5 r
.51489 .79991 m .5145 .80252 L .51212 .8029 L F
.814 .52 0 r
.51386 .79675 m .51489 .79991 L .51404 .79708 L F
.87 .845 .817 r
.51198 .7962 m .51404 .79708 L .51578 .79469 L F
.862 .676 .649 r
.51198 .7962 m .51386 .79675 L .51404 .79708 L F
.999 .795 .467 r
.5145 .80252 m .51489 .79991 L .51386 .79675 L F
.192 .241 .684 r
.55196 .75078 m .55081 .75219 L .54943 .75117 L F
.541 .365 .592 r
.55081 .75219 m .55332 .75586 L .55317 .75157 L F
.192 .241 .684 r
.55196 .75078 m .55332 .75586 L .55081 .75219 L F
.251 .501 .899 r
.71565 .51561 m .71744 .51771 L .71839 .51678 L F
.243 .488 .892 r
.71744 .51771 m .71959 .51861 L .71839 .51678 L F
.802 .76 .814 r
.58987 .69679 m .58566 .69846 L .58796 .69558 L F
.913 .529 .111 r
.58958 .69789 m .58987 .69679 L .58796 .69558 L F
.58958 .69789 m .5907 .69892 L .58987 .69679 L F
0 .086 .621 r
.52315 .77472 m .52392 .77809 L .52405 .77674 L F
0 0 .514 r
.52392 .77809 m .52511 .77923 L .52405 .77674 L F
.52392 .77809 m .52494 .77995 L .52511 .77923 L F
.239 .756 .821 r
.46666 .65224 m .46264 .65257 L .46049 .65298 L F
.123 .673 .768 r
.46837 .6521 m .46264 .65257 L .46666 .65224 L F
.503 .264 .485 r
.60101 .52906 m .60355 .52635 L .60135 .52674 L F
.567 .169 .248 r
.43537 .69715 m .43903 .6954 L .43589 .6964 L F
.43537 .69715 m .43769 .69748 L .43903 .6954 L F
.38 0 .041 r
.43769 .69748 m .44138 .69559 L .43903 .6954 L F
0 0 0 r
.62486 .51977 m .62374 .52089 L .62627 .52027 L F
.62486 .51977 m .62326 .5229 L .62374 .52089 L F
.179 0 0 r
.51438 .78593 m .51263 .78629 L .51047 .78621 L F
.024 0 0 r
.51545 .78607 m .51438 .78593 L .51551 .78615 L F
.533 .573 .841 r
.51463 .78895 m .51551 .78615 L .51438 .78593 L F
.024 0 0 r
.51545 .78607 m .51263 .78629 L .51438 .78593 L F
.568 0 0 r
.53869 .77413 m .53706 .77411 L .53452 .77266 L F
.692 .165 0 r
.53869 .77413 m .5411 .77551 L .53706 .77411 L F
.847 .809 .813 r
.56151 .77215 m .55864 .77286 L .55756 .7716 L F
0 0 0 r
.61441 .50467 m .61343 .50631 L .61396 .50577 L F
.642 .885 .54 r
.61441 .50467 m .61524 .50344 L .61669 .50187 L F
.274 .088 .437 r
.61396 .50577 m .61524 .50344 L .61441 .50467 L F
.501 .031 .07 r
.51069 .70105 m .50911 .70258 L .50726 .70158 L F
.237 0 0 r
.51299 .70117 m .50911 .70258 L .51069 .70105 L F
.237 .096 .477 r
.34733 .61208 m .3488 .61311 L .3493 .61174 L F
.34733 .61208 m .34744 .6139 L .3488 .61311 L F
.8 .676 .727 r
.54905 .79732 m .55087 .79419 L .54775 .79412 L F
.718 .762 .887 r
.68405 .51729 m .68397 .5196 L .68158 .51852 L F
.446 .526 .846 r
.68607 .51723 m .68397 .5196 L .68405 .51729 L F
.427 .496 .828 r
.68607 .51723 m .68721 .52039 L .68397 .5196 L F
0 0 0 r
.64694 .51225 m .6456 .51328 L .64749 .51178 L F
.64694 .51225 m .64442 .51433 L .6456 .51328 L F
.616 .371 .524 r
.59925 .58592 m .60214 .58589 L .60224 .58324 L F
.546 .334 .543 r
.60214 .58589 m .60406 .58314 L .60224 .58324 L F
.473 0 0 r
.53452 .77266 m .53563 .77366 L .53344 .77357 L F
.53452 .77266 m .53706 .77411 L .53563 .77366 L F
.833 .943 .581 r
.63493 .55564 m .6359 .55492 L .63522 .55387 L F
.63493 .55564 m .63421 .55783 L .6359 .55492 L F
.83 .423 .273 r
.55937 .74385 m .55987 .74545 L .56094 .74388 L F
.823 .413 .268 r
.55987 .74545 m .56258 .7463 L .56094 .74388 L F
.841 .393 .15 r
.56094 .74388 m .56258 .7463 L .56417 .74685 L F
.176 0 0 r
.43384 .65045 m .43605 .65009 L .43746 .64902 L F
.264 0 0 r
.43746 .64902 m .43605 .65009 L .43943 .64917 L F
.474 .158 .349 r
.48739 .8119 m .49061 .80924 L .48958 .8111 L F
0 0 .476 r
.48232 .80313 m .48319 .80434 L .48228 .80248 L F
.79 .518 0 r
.58644 .70162 m .58614 .70088 L .58566 .69846 L F
0 0 0 r
.58644 .70162 m .58586 .70324 L .58614 .70088 L F
.79 .518 0 r
.58644 .70162 m .58614 .70088 L .58566 .69846 L F
.329 0 .039 r
.61669 .50187 m .61764 .50275 L .61843 .50073 L F
.61669 .50187 m .61524 .50344 L .61764 .50275 L F
.917 .595 .419 r
.56258 .7463 m .563 .74859 L .56417 .74685 L F
.793 .41 .331 r
.56417 .74685 m .563 .74859 L .56505 .74863 L F
.391 .613 .939 r
.37424 .59507 m .37343 .59666 L .37172 .59476 L F
.37424 .59507 m .37536 .59671 L .37343 .59666 L F
.667 .844 .967 r
.38472 .69459 m .38606 .69594 L .38256 .69607 L F
.765 .365 .295 r
.38452 .69769 m .38606 .69594 L .38472 .69459 L F
.013 0 .462 r
.38606 .69594 m .38694 .69846 L .38622 .69894 L F
.765 .365 .295 r
.38452 .69769 m .38694 .69846 L .38606 .69594 L F
.646 .65 .84 r
.49981 .80019 m .50153 .79845 L .49885 .7978 L F
.49981 .80019 m .50251 .79949 L .50153 .79845 L F
.612 .386 .55 r
.49981 .80019 m .50205 .80276 L .50251 .79949 L F
.49981 .80019 m .49938 .80321 L .50205 .80276 L F
.512 .714 .963 r
.30527 .62907 m .30455 .63075 L .30314 .62949 L F
.30527 .62907 m .30663 .63049 L .30455 .63075 L F
.531 .874 .989 r
.71128 .48351 m .70967 .48485 L .71212 .4844 L F
.416 .865 .849 r
.50304 .77829 m .50408 .77841 L .50613 .77759 L F
.582 .373 .562 r
.4802 .65944 m .48293 .65913 L .48055 .65656 L F
.56 .716 .946 r
.51863 .68721 m .51999 .68821 L .51631 .68765 L F
.845 .717 .722 r
.51999 .68821 m .51863 .68721 L .51631 .68765 L F
.36 .059 .312 r
.61894 .49898 m .61843 .50073 L .62109 .49826 L F
.517 .273 .483 r
.58342 .60605 m .58334 .60813 L .58103 .60856 L F
.587 .331 .496 r
.5859 .60583 m .58334 .60813 L .58342 .60605 L F
.517 .714 .961 r
.34813 .60249 m .34914 .60058 L .34619 .60032 L F
.34813 .60249 m .3504 .60222 L .34914 .60058 L F
.651 .236 .244 r
.53383 .78774 m .53621 .78601 L .53147 .78595 L F
.772 .412 .374 r
.53744 .7888 m .53621 .78601 L .53383 .78774 L F
0 .093 .65 r
.53847 .78931 m .53621 .78601 L .53744 .7888 L F
.657 .81 .957 r
.26046 .64832 m .25708 .64742 L .25931 .64438 L F
.584 .46 .678 r
.56707 .61388 m .56528 .61698 L .56492 .61433 L F
0 0 0 r
.62631 .57462 m .62538 .57609 L .62361 .57731 L F
0 0 .193 r
.62538 .57609 m .62357 .57938 L .62361 .57731 L F
.28 .72 .964 r
.35698 .59101 m .35901 .591 L .36054 .59171 L F
.312 .68 .977 r
.36113 .59073 m .36054 .59171 L .35901 .591 L F
.36113 .59073 m .36251 .59182 L .36054 .59171 L F
.592 .642 .869 r
.27484 .64233 m .27777 .64361 L .2764 .64222 L F
.317 .693 .979 r
.27777 .64361 m .27824 .64269 L .2764 .64222 L F
.27777 .64361 m .28048 .64407 L .27824 .64269 L F
.305 .489 .875 r
.39767 .70707 m .40074 .70928 L .40002 .70705 L F
.604 .372 .538 r
.39302 .66178 m .39586 .66156 L .39592 .65923 L F
.632 .523 .712 r
.39592 .65923 m .39833 .65912 L .39803 .65675 L F
.668 .461 .595 r
.39586 .66156 m .39833 .65912 L .39592 .65923 L F
.527 .152 .274 r
.49912 .7741 m .50248 .7721 L .50074 .77141 L F
.49912 .7741 m .50153 .77434 L .50248 .7721 L F
.654 .284 .33 r
.50248 .7721 m .50153 .77434 L .50469 .77401 L F
.775 .513 .539 r
.53007 .76809 m .53357 .76639 L .53008 .76598 L F
.53007 .76809 m .53372 .76856 L .53357 .76639 L F
.258 0 0 r
.43375 .6687 m .43291 .66754 L .43509 .66724 L F
.43375 .6687 m .43139 .66933 L .43291 .66754 L F
.989 .891 .618 r
.62255 .54396 m .62108 .54516 L .62201 .54299 L F
.62255 .54396 m .62171 .54632 L .62108 .54516 L F
.986 .849 .474 r
.62255 .54396 m .62201 .54299 L .62251 .54079 L F
.015 0 .009 r
.50332 .81243 m .5044 .81128 L .50182 .81375 L F
.562 .898 .982 r
.50208 .81423 m .50302 .81303 L .50417 .81486 L F
0 0 0 r
.50227 .81348 m .50437 .81131 L .50302 .81303 L F
.50182 .81375 m .50359 .81205 L .50326 .81241 L F
.561 .581 .831 r
.50182 .81375 m .50326 .81241 L .50332 .81243 L F
0 0 0 r
.50182 .81375 m .50326 .81241 L .50227 .81348 L F
.561 .581 .831 r
.50182 .81375 m .49832 .81092 L .50326 .81241 L F
.718 .448 .517 r
.5033 .81237 m .50332 .81243 L .50326 .81241 L F
.61 .395 .565 r
.5033 .81237 m .5044 .81128 L .50332 .81243 L F
0 0 0 r
.5033 .81237 m .5044 .81128 L .50227 .81348 L F
.50359 .81205 m .5044 .81128 L .5033 .81237 L F
.61 .395 .565 r
.5018 .80852 m .5044 .81128 L .5033 .81237 L F
.765 .689 .779 r
.49832 .81092 m .49957 .81402 L .49608 .81446 L F
.561 .581 .831 r
.50182 .81375 m .49957 .81402 L .49832 .81092 L F
0 0 0 r
.49844 .81416 m .49957 .81402 L .50182 .81375 L F
.49844 .81416 m .50182 .81375 L .50082 .81383 L F
.385 .847 .833 r
.50082 .81383 m .50182 .81375 L .50302 .81303 L F
.562 .898 .982 r
.49912 .81334 m .50082 .81383 L .50302 .81303 L F
.49912 .81334 m .50302 .81303 L .50208 .81423 L F
0 0 0 r
.50437 .81131 m .5044 .81128 L .50302 .81303 L F
.718 .448 .517 r
.5018 .80852 m .5033 .81237 L .49832 .81092 L F
.5033 .81237 m .50326 .81241 L .49832 .81092 L F
.618 .453 .636 r
.50406 .80584 m .50433 .80841 L .5018 .80852 L F
.989 .721 .402 r
.50433 .80841 m .5044 .81128 L .5018 .80852 L F
.448 .695 .971 r
.29581 .62716 m .29517 .62867 L .2938 .62735 L F
.29581 .62716 m .29736 .62863 L .29517 .62867 L F
.79 .653 .711 r
.54854 .63378 m .54927 .63733 L .5456 .63635 L F
.641 .08 0 r
.54929 .63861 m .5456 .63635 L .54927 .63733 L F
0 0 0 r
.57862 .55273 m .57977 .55134 L .57949 .55154 L F
0 0 .156 r
.57917 .55374 m .57862 .55273 L .57778 .55484 L F
.57917 .55374 m .57977 .55134 L .57862 .55273 L F
.523 .338 .571 r
.59394 .53265 m .59625 .53217 L .59606 .5298 L F
.353 .127 .425 r
.59406 .53508 m .59625 .53217 L .59394 .53265 L F
.569 .926 .755 r
.47425 .79531 m .47534 .79497 L .47242 .79688 L F
.806 .725 .775 r
.47392 .79189 m .47534 .79497 L .47748 .79169 L F
0 0 0 r
.47764 .79429 m .47534 .79497 L .47425 .79531 L F
.52 .345 .584 r
.47748 .79169 m .47534 .79497 L .47764 .79429 L F
.528 .047 .057 r
.47959 .69648 m .4759 .6975 L .47738 .69576 L F
.949 .946 .739 r
.56412 .57191 m .56146 .57484 L .56364 .57146 L F
.56412 .57191 m .56228 .57537 L .56146 .57484 L F
.899 .983 .791 r
.56364 .57146 m .5664 .56909 L .56412 .57191 L F
.359 .648 .965 r
.27484 .64233 m .2764 .64222 L .27536 .64098 L F
.732 .991 .839 r
.27229 .64332 m .27484 .64233 L .27536 .64098 L F
.359 .648 .965 r
.27484 .64233 m .2764 .64222 L .27536 .64098 L F
.805 .618 .649 r
.58403 .58569 m .58536 .58868 L .58694 .58631 L F
0 0 .483 r
.50933 .77319 m .50843 .77189 L .5105 .77156 L F
.783 .537 .564 r
.50692 .77348 m .5105 .77156 L .50843 .77189 L F
.638 .71 .9 r
.69808 .47354 m .69572 .47434 L .69467 .47257 L F
.398 .028 .215 r
.50496 .78329 m .50194 .78524 L .50373 .78515 L F
.633 .28 .354 r
.5071 .78524 m .50496 .78329 L .50373 .78515 L F
.584 .46 .678 r
.56707 .61388 m .57041 .61889 L .56528 .61698 L F
.461 .31 .589 r
.57065 .61899 m .56868 .62188 L .56838 .61983 L F
.166 0 0 r
.57041 .61889 m .56838 .61983 L .56678 .62066 L F
.57041 .61889 m .56678 .62066 L .56528 .61698 L F
.844 .411 .2 r
.53738 .62278 m .53634 .62385 L .53465 .62147 L F
.817 .371 .176 r
.53738 .62278 m .53876 .62503 L .53634 .62385 L F
.436 .207 .467 r
.55464 .71572 m .55655 .71559 L .55706 .71288 L F
.626 .432 .6 r
.55655 .71559 m .55938 .71249 L .55706 .71288 L F
.856 .867 .848 r
.70419 .51935 m .70533 .52045 L .706 .51934 L F
.944 .842 .711 r
.70366 .52419 m .70533 .52045 L .70419 .51935 L F
.52 .36 .605 r
.55464 .71572 m .55706 .71775 L .55655 .71559 L F
.55464 .71572 m .55485 .71813 L .55706 .71775 L F
.514 .372 .625 r
.39109 .6652 m .39334 .66494 L .39302 .66178 L F
.614 .461 .65 r
.39109 .6652 m .39386 .66732 L .39334 .66494 L F
.39109 .6652 m .39139 .66765 L .39386 .66732 L F
.697 .638 .786 r
.68192 .4791 m .68528 .47979 L .68424 .47836 L F
.693 .726 .875 r
.68424 .47836 m .68528 .47979 L .68769 .47905 L F
.522 0 0 r
.6534 .50118 m .65673 .50235 L .65692 .50215 L F
.888 .557 .415 r
.65626 .5035 m .65504 .5048 L .65546 .50354 L F
.65608 .50295 m .65546 .50354 L .65587 .50232 L F
.65626 .5035 m .65546 .50354 L .65608 .50295 L F
.852 .991 .845 r
.65411 .50234 m .65656 .50249 L .65371 .50131 L F
.65358 .50147 m .65371 .50131 L .6534 .50118 L F
.65411 .50234 m .65371 .50131 L .65358 .50147 L F
.65455 .50307 m .65498 .50294 L .65411 .50234 L F
.65498 .50294 m .65656 .50249 L .65411 .50234 L F
.855 .928 .875 r
.65359 .5027 m .6509 .5072 L .65386 .50267 L F
.538 0 0 r
.65249 .50163 m .65455 .50307 L .6534 .50118 L F
.972 .877 .681 r
.65374 .50258 m .65339 .50272 L .65331 .50226 L F
.65382 .50264 m .65341 .50272 L .65374 .50258 L F
.65341 .50272 m .65339 .50272 L .65374 .50258 L F
.846 .886 .868 r
.65172 .50342 m .65367 .50256 L .65322 .50245 L F
.64889 .50531 m .65338 .50273 L .65172 .50342 L F
.65338 .50273 m .65339 .50272 L .65172 .50342 L F
.65339 .50272 m .65367 .50256 L .65338 .50269 L F
.65339 .50272 m .65338 .50269 L .65172 .50342 L F
.972 .877 .681 r
.65331 .50226 m .65339 .50272 L .65298 .50222 L F
0 0 .522 r
.65339 .50272 m .6534 .50273 L .65286 .5019 L F
.538 0 0 r
.65249 .50163 m .65386 .50267 L .65455 .50307 L F
.855 .928 .875 r
.65386 .50267 m .65361 .50306 L .65455 .50307 L F
.65361 .50306 m .65401 .50368 L .65455 .50307 L F
.972 .877 .681 r
.6556 .50248 m .65399 .50345 L .6534 .50273 L F
.65399 .50266 m .6534 .50273 L .65339 .50272 L F
.6556 .50248 m .6534 .50273 L .65399 .50266 L F
.846 .886 .868 r
.64889 .50531 m .64991 .5064 L .65352 .50271 L F
.65338 .50273 m .65352 .50271 L .65367 .50256 L F
.64889 .50531 m .65352 .50271 L .65338 .50273 L F
0 0 .522 r
.6534 .50273 m .65399 .50345 L .65334 .50256 L F
.6534 .50273 m .65334 .50256 L .65286 .5019 L F
.855 .928 .875 r
.65359 .5027 m .64991 .5064 L .6509 .5072 L F
.65352 .50271 m .64991 .5064 L .65359 .5027 L F
.65361 .50306 m .6509 .5072 L .65401 .50368 L F
.847 .982 .865 r
.65455 .50307 m .6509 .5072 L .65262 .50701 L F
.962 .745 .564 r
.65402 .50521 m .65316 .50246 L .65399 .50345 L F
0 0 .522 r
.65286 .5019 m .65399 .50345 L .65344 .50263 L F
.538 0 0 r
.65249 .50163 m .65367 .50256 L .65374 .50258 L F
.972 .877 .681 r
.65332 .5018 m .65298 .50222 L .65249 .50163 L F
.65587 .50232 m .65298 .50222 L .65332 .5018 L F
.657 .23 .22 r
.65301 .50026 m .65249 .50163 L .6534 .50118 L F
.766 .676 .763 r
.6547 .49898 m .65249 .50163 L .65301 .50026 L F
.972 .877 .681 r
.65587 .50232 m .6556 .50248 L .65298 .50222 L F
.766 .676 .763 r
.6527 .50137 m .65332 .5018 L .65249 .50163 L F
.236 .533 .921 r
.65249 .50163 m .65254 .50042 L .65168 .50024 L F
.747 .268 0 r
.65168 .50024 m .6526 .50131 L .65249 .50163 L F
.6526 .50131 m .65367 .50256 L .65249 .50163 L F
.65168 .50024 m .65236 .50123 L .65275 .50163 L F
.6526 .50131 m .65275 .50163 L .65367 .50256 L F
.65168 .50024 m .65275 .50163 L .6526 .50131 L F
0 0 .522 r
.6526 .50131 m .65302 .50202 L .65271 .501 L F
.65249 .50163 m .65289 .50192 L .6526 .50131 L F
.747 .268 0 r
.65236 .50123 m .65331 .50247 L .65367 .50256 L F
0 0 .522 r
.65289 .50192 m .65302 .50202 L .6526 .50131 L F
.65249 .50163 m .65271 .501 L .65254 .50042 L F
.747 .268 0 r
.65331 .50247 m .65332 .50247 L .65367 .50256 L F
.538 0 0 r
.65374 .50258 m .65367 .50256 L .65386 .50267 L F
0 0 .522 r
.65289 .50192 m .65344 .50263 L .65302 .50202 L F
.65286 .5019 m .65344 .50263 L .65289 .50192 L F
.65249 .50163 m .65339 .50272 L .65286 .5019 L F
.747 .268 0 r
.65236 .50123 m .65316 .5024 L .65332 .50247 L F
.65316 .5024 m .65322 .50245 L .65332 .50247 L F
.962 .745 .564 r
.65322 .50245 m .65302 .50202 L .6533 .50243 L F
.791 .944 .925 r
.65316 .50245 m .64889 .50531 L .65316 .50246 L F
.65154 .50185 m .64889 .50531 L .65297 .50258 L F
.846 .886 .868 r
.65172 .50342 m .65322 .50245 L .65316 .50246 L F
.961 .744 .564 r
.65278 .50231 m .65253 .50517 L .65124 .50419 L F
.65302 .50202 m .65296 .50238 L .65278 .50231 L F
.65296 .50238 m .65253 .50517 L .65278 .50231 L F
.791 .944 .925 r
.65149 .50183 m .65149 .50183 L .65154 .50185 L F
.65149 .50183 m .64889 .50531 L .65154 .50185 L F
.65278 .50231 m .65297 .50258 L .65316 .50245 L F
.65149 .50183 m .65297 .50258 L .65278 .50231 L F
.988 .81 .574 r
.65106 .49945 m .65179 .50143 L .65254 .50197 L F
.961 .744 .564 r
.65302 .50202 m .65278 .50231 L .65259 .50192 L F
.962 .745 .564 r
.65316 .50245 m .65296 .50238 L .65302 .50202 L F
.65316 .50246 m .65313 .50238 L .65322 .50245 L F
.988 .81 .574 r
.65273 .5018 m .65254 .50197 L .65319 .50244 L F
.65106 .49945 m .65254 .50197 L .65273 .5018 L F
.961 .744 .564 r
.65279 .50175 m .65259 .50192 L .65218 .50105 L F
.988 .81 .574 r
.65106 .49945 m .65273 .5018 L .65168 .50024 L F
.65273 .5018 m .65319 .50244 L .65307 .50227 L F
.65273 .5018 m .65307 .50227 L .65168 .50024 L F
.961 .744 .564 r
.65302 .50202 m .65286 .50198 L .65279 .50175 L F
.65286 .50198 m .65259 .50192 L .65273 .5018 L F
.65286 .50198 m .65273 .5018 L .65279 .50175 L F
.791 .944 .925 r
.65179 .50143 m .65149 .50183 L .65316 .50245 L F
.961 .744 .564 r
.65278 .50231 m .65124 .50419 L .65209 .50134 L F
.65278 .50231 m .65209 .50134 L .65218 .50105 L F
.962 .745 .564 r
.65402 .50521 m .65253 .50517 L .65296 .50238 L F
.65402 .50521 m .65296 .50238 L .65316 .50245 L F
.65316 .50245 m .65313 .50238 L .65316 .50246 L F
.791 .944 .925 r
.65281 .50217 m .65316 .50246 L .65319 .50244 L F
.65179 .50143 m .65316 .50246 L .65281 .50217 L F
.962 .745 .564 r
.65316 .50246 m .65316 .50245 L .65316 .50246 L F
.65313 .50238 m .65302 .50202 L .65322 .50245 L F
.747 .268 0 r
.65316 .5024 m .65319 .50244 L .65322 .50245 L F
.962 .745 .564 r
.65316 .50246 m .6533 .50243 L .65399 .50345 L F
.846 .886 .868 r
.65316 .50246 m .65322 .50245 L .65319 .50244 L F
.972 .877 .681 r
.65498 .50242 m .65382 .50264 L .65331 .50226 L F
.6556 .50248 m .65359 .5027 L .65498 .50242 L F
.65359 .5027 m .65339 .50272 L .65498 .50242 L F
.855 .928 .875 r
.65367 .50256 m .65352 .50271 L .65359 .5027 L F
.65367 .50256 m .65359 .5027 L .65386 .50267 L F
.852 .991 .845 r
.65656 .50249 m .65658 .50248 L .6534 .50118 L F
.65659 .50249 m .65673 .50235 L .6534 .50118 L F
.766 .676 .763 r
.6547 .49898 m .65587 .50232 L .65332 .5018 L F
.6547 .49898 m .65332 .5018 L .6527 .50137 L F
.852 .991 .845 r
.65656 .50249 m .65659 .50249 L .65658 .50248 L F
.65659 .50249 m .65688 .5024 L .65673 .50235 L F
.975 .921 .616 r
.65728 .50112 m .65676 .50233 L .65587 .50232 L F
.522 0 0 r
.65673 .50235 m .65688 .50236 L .65692 .50215 L F
.975 .921 .616 r
.65676 .50233 m .65675 .50235 L .65673 .50235 L F
.65676 .50233 m .65673 .50235 L .65587 .50232 L F
.65675 .50235 m .65626 .5035 L .65587 .50233 L F
.65675 .50235 m .65587 .50233 L .65587 .50232 L F
.522 0 0 r
.65673 .50235 m .65688 .5024 L .65688 .50236 L F
.279 .162 .536 r
.49794 .79174 m .50004 .79294 L .49885 .79081 L F
.49794 .79174 m .49794 .79436 L .50004 .79294 L F
.671 .484 .624 r
.59494 .60099 m .59469 .60245 L .59142 .60327 L F
.601 .415 .602 r
.59725 .6002 m .59469 .60245 L .59494 .60099 L F
.464 0 0 r
.47639 .81468 m .47745 .81582 L .47621 .81364 L F
.6 .439 .636 r
.50654 .80563 m .50433 .80841 L .50406 .80584 L F
.50654 .80563 m .50433 .80841 L .50406 .80584 L F
.558 .501 .748 r
.73721 .51601 m .73439 .51838 L .73445 .5159 L F
.219 .366 .799 r
.24593 .66029 m .24756 .66131 L .24677 .66219 L F
.683 .494 .624 r
.24958 .66199 m .24677 .66219 L .24756 .66131 L F
.24958 .66199 m .24922 .66212 L .24677 .66219 L F
.689 .548 .689 r
.24677 .66219 m .24922 .66212 L .24723 .66492 L F
.61 .768 .956 r
.53974 .79972 m .54032 .80102 L .54311 .80018 L F
.745 .666 .774 r
.58843 .7102 m .59162 .71005 L .59043 .70685 L F
0 0 0 r
.59162 .71005 m .59053 .71166 L .58952 .71288 L F
.488 .04 .111 r
.58835 .7113 m .59162 .71005 L .58843 .7102 L F
.58835 .7113 m .59053 .71166 L .59162 .71005 L F
.985 .705 .373 r
.59043 .70685 m .59162 .71005 L .59031 .70843 L F
.992 .75 .461 r
.59162 .71005 m .59053 .71166 L .59031 .70843 L F
.728 .425 .466 r
.59357 .70985 m .59053 .71166 L .59162 .71005 L F
.686 .896 .973 r
.25073 .62576 m .25007 .6246 L .25258 .62502 L F
.25073 .62576 m .24884 .62506 L .25007 .6246 L F
.227 .011 .363 r
.25258 .62502 m .25061 .62763 L .25073 .62576 L F
.468 .362 .65 r
.25203 .60599 m .25378 .60559 L .25356 .60235 L F
.478 .399 .689 r
.25203 .60599 m .25437 .60792 L .25378 .60559 L F
.491 .399 .679 r
.25246 .60842 m .25437 .60792 L .25203 .60599 L F
.489 .174 .358 r
.52701 .79175 m .52901 .79341 L .52716 .7942 L F
.52701 .79175 m .52935 .79159 L .52901 .79341 L F
.52 .396 .651 r
.4737 .78831 m .47159 .79175 L .47392 .79189 L F
.749 .936 .947 r
.56383 .77508 m .5652 .77562 L .56679 .77439 L F
.971 .854 .668 r
.63842 .52606 m .63724 .52946 L .63834 .53029 L F
.933 .827 .718 r
.63627 .53115 m .63834 .53029 L .63724 .52946 L F
.63627 .53115 m .63752 .53234 L .63834 .53029 L F
0 0 .557 r
.65251 .4948 m .65405 .4971 L .65295 .49602 L F
.845 .717 .722 r
.51999 .68821 m .51988 .6904 L .51863 .68721 L F
0 0 .068 r
.52212 .68754 m .51988 .6904 L .52171 .68855 L F
.754 .741 .841 r
.52212 .68754 m .51999 .68821 L .51863 .68721 L F
.777 .688 .766 r
.51863 .68721 m .51988 .6904 L .52212 .68754 L F
.219 0 0 r
.51988 .6904 m .52076 .69144 L .52171 .68855 L F
.51988 .6904 m .51859 .69199 L .52076 .69144 L F
.724 .557 .664 r
.47602 .64915 m .47818 .6475 L .47596 .64875 L F
.678 .783 .929 r
.70149 .47402 m .69808 .47354 L .7004 .47262 L F
.669 .787 .936 r
.7004 .47262 m .70381 .4731 L .70149 .47402 L F
0 0 .396 r
.74738 .49766 m .74754 .50114 L .74775 .49909 L F
.672 .129 0 r
.51504 .76355 m .519 .76588 L .51753 .76464 L F
.079 0 0 r
.51955 .69931 m .51868 .69861 L .52052 .69793 L F
.51955 .69931 m .51729 .70018 L .51868 .69861 L F
.504 .434 .711 r
.49654 .77212 m .49912 .7741 L .49912 .77189 L F
.503 .434 .712 r
.49654 .77212 m .49717 .77499 L .49912 .7741 L F
.825 .601 .599 r
.25262 .64963 m .25266 .64781 L .25119 .64949 L F
.25262 .64963 m .25477 .6479 L .25266 .64781 L F
.902 .515 .277 r
.55638 .73769 m .55765 .74045 L .55946 .74095 L F
.974 .711 .47 r
.55783 .74314 m .55946 .74095 L .55765 .74045 L F
.55783 .74314 m .55937 .74385 L .55946 .74095 L F
.401 .796 .987 r
.49159 .64227 m .49058 .64144 L .48805 .64186 L F
.77 .724 .81 r
.48805 .64186 m .48923 .6429 L .49159 .64227 L F
.544 .875 .991 r
.49321 .64127 m .49058 .64144 L .49159 .64227 L F
.586 .708 .927 r
.68034 .52661 m .67878 .52309 L .68033 .52422 L F
.995 .842 .489 r
.68023 .52096 m .68033 .52422 L .67878 .52309 L F
.513 .33 .57 r
.59606 .5298 m .59851 .53157 L .59879 .52968 L F
.59606 .5298 m .59625 .53217 L .59851 .53157 L F
.729 .505 .587 r
.58952 .71288 m .58588 .71509 L .58835 .7113 L F
.58952 .71288 m .58934 .71539 L .58588 .71509 L F
.811 .87 .43 r
.6435 .4795 m .64281 .4804 L .64289 .47932 L F
.372 .511 .868 r
.65493 .48698 m .65783 .4857 L .65319 .48413 L F
.174 0 0 r
.70797 .50616 m .71099 .50633 L .71089 .50615 L F
0 0 0 r
.71089 .50615 m .71273 .50389 L .71372 .50433 L F
.71089 .50615 m .71099 .50633 L .71273 .50389 L F
.457 .201 .437 r
.62349 .49332 m .62322 .4953 L .62576 .49273 L F
.328 0 0 r
.45187 .70122 m .45062 .70265 L .4482 .70289 L F
.441 0 .091 r
.45412 .70095 m .45062 .70265 L .45187 .70122 L F
.914 .64 .507 r
.78512 .59106 m .7853 .59351 L .78702 .59239 L F
.947 .724 .569 r
.7853 .59351 m .78671 .59494 L .78702 .59239 L F
0 .296 .793 r
.48137 .64865 m .48167 .64759 L .48014 .64691 L F
.806 .725 .775 r
.47471 .79184 m .47748 .79169 L .47567 .79156 L F
0 0 .406 r
.47748 .79169 m .47764 .79429 L .47854 .79383 L F
.47748 .79169 m .47854 .79383 L .47567 .79156 L F
.449 .421 .735 r
.47567 .79156 m .47854 .79383 L .47747 .79104 L F
.47567 .79156 m .47747 .79104 L .47724 .79042 L F
.806 .725 .775 r
.47392 .79189 m .47471 .79184 L .47567 .79156 L F
.536 .337 .559 r
.3848 .7044 m .38932 .70518 L .3873 .70149 L F
0 0 .171 r
.3848 .7044 m .38516 .70532 L .38932 .70518 L F
.3848 .7044 m .38499 .70693 L .38516 .70532 L F
.695 .708 .858 r
.69309 .5203 m .69173 .52405 L .69058 .52252 L F
.69309 .5203 m .69373 .52303 L .69173 .52405 L F
.586 .657 .886 r
.56417 .72537 m .56176 .72376 L .56302 .72693 L F
.639 .694 .885 r
.67671 .51193 m .67816 .51353 L .67439 .51251 L F
.723 .716 .843 r
.68021 .51173 m .67816 .51353 L .67671 .51193 L F
0 0 .516 r
.4721 .80572 m .47335 .80799 L .47239 .80502 L F
.909 .506 .202 r
.59609 .71292 m .5944 .71214 L .59357 .70985 L F
.764 .581 .65 r
.59761 .71493 m .5944 .71214 L .59609 .71292 L F
0 0 0 r
.55149 .76994 m .55125 .77127 L .55149 .76866 L F
.846 .814 .329 r
.55143 .77013 m .55125 .77127 L .55149 .76994 L F
.372 0 0 r
.54859 .77152 m .55111 .77213 L .55125 .77127 L F
.722 .543 .648 r
.54859 .77152 m .55164 .77315 L .54834 .77228 L F
.843 .795 .805 r
.55125 .77127 m .55164 .77315 L .54859 .77152 L F
.55087 .77333 m .55086 .77339 L .55164 .77315 L F
.519 .06 .104 r
.55164 .77315 m .55086 .77339 L .5508 .7735 L F
.724 .374 .385 r
.54764 .77481 m .5508 .7735 L .54738 .77577 L F
.5508 .7735 m .55164 .77315 L .55071 .77372 L F
.5508 .7735 m .55071 .77372 L .54738 .77577 L F
.835 .836 .365 r
.5508 .7735 m .55086 .77339 L .55085 .77339 L F
.724 .374 .385 r
.54786 .77402 m .55164 .77315 L .54764 .77481 L F
.519 .06 .104 r
.55164 .77315 m .54963 .77585 L .54738 .77577 L F
.835 .836 .365 r
.54963 .77585 m .5508 .7735 L .55046 .77339 L F
.5508 .7735 m .55085 .77339 L .55046 .77339 L F
.519 .06 .104 r
.55164 .77315 m .5508 .7735 L .54963 .77585 L F
.724 .374 .385 r
.54834 .77228 m .55099 .77298 L .54786 .77402 L F
.55099 .77298 m .55087 .77333 L .54786 .77402 L F
.846 .814 .329 r
.55046 .77339 m .55085 .77339 L .55125 .77127 L F
.55085 .77339 m .55086 .77339 L .55087 .77333 L F
.55085 .77339 m .55087 .77333 L .55125 .77127 L F
.724 .374 .385 r
.55099 .77298 m .55164 .77315 L .55087 .77333 L F
.843 .795 .805 r
.55125 .77127 m .55087 .77333 L .55164 .77315 L F
.846 .814 .329 r
.55046 .77339 m .55125 .77127 L .55143 .77013 L F
.372 0 0 r
.55111 .77213 m .55242 .77244 L .55125 .77127 L F
.442 .254 .529 r
.55242 .77244 m .55442 .77155 L .55125 .77127 L F
.55242 .77244 m .55439 .77406 L .55442 .77155 L F
.463 .251 .506 r
.55242 .77244 m .55243 .77688 L .55439 .77406 L F
.892 .988 .745 r
.5867 .57179 m .58799 .56986 L .58635 .57083 L F
.8 .991 .88 r
.5867 .57179 m .58334 .57334 L .58445 .57452 L F
.5867 .57179 m .58635 .57083 L .58334 .57334 L F
.419 .019 .171 r
.52171 .68855 m .52432 .68749 L .52212 .68754 L F
.794 .302 .022 r
.25675 .65084 m .25662 .65208 L .25515 .65015 L F
.252 .23 .639 r
.47379 .77472 m .47561 .7767 L .47546 .77349 L F
.408 .54 .877 r
.48456 .81135 m .48108 .80852 L .48359 .80786 L F
.696 .276 0 r
.3873 .70149 m .38932 .70518 L .38899 .70449 L F
.918 .546 .119 r
.38899 .70449 m .38821 .70231 L .3873 .70149 L F
.033 .514 .881 r
.56395 .7075 m .56398 .70762 L .56189 .70667 L F
.277 .411 .818 r
.56373 .70672 m .56395 .7075 L .56311 .70736 L F
.56497 .70544 m .56395 .7075 L .56373 .70672 L F
.033 .514 .881 r
.56395 .7075 m .56502 .7081 L .56398 .70762 L F
.476 0 .012 r
.56395 .7075 m .56729 .70741 L .56502 .7081 L F
.399 .353 .69 r
.41714 .68101 m .41746 .68424 L .41589 .68471 L F
.381 .297 .635 r
.41746 .68424 m .41786 .68671 L .41589 .68471 L F
.32 .04 .322 r
.37307 .61359 m .37116 .61427 L .37363 .61172 L F
.528 .295 .505 r
.37558 .61097 m .37307 .61359 L .37363 .61172 L F
.972 .736 .522 r
.50367 .76604 m .50213 .76568 L .50353 .76352 L F
.57 .235 .362 r
.50213 .76568 m .50576 .76311 L .50353 .76352 L F
.242 0 .171 r
.35013 .63475 m .34894 .63373 L .35127 .63337 L F
.35013 .63475 m .34803 .63582 L .34894 .63373 L F
.425 .192 .455 r
.48906 .80815 m .48947 .80589 L .48706 .80915 L F
.48706 .80915 m .48947 .80589 L .48906 .80815 L F
.38 .153 .439 r
.48906 .80815 m .48947 .80589 L .49132 .8053 L F
.48906 .80815 m .48947 .80589 L .49132 .8053 L F
.968 .911 .561 r
.59619 .55777 m .59495 .55863 L .59456 .56123 L F
.59619 .55777 m .59575 .55728 L .59495 .55863 L F
.739 .273 .141 r
.54284 .75571 m .5414 .75674 L .53919 .75458 L F
.151 .289 .752 r
.54284 .75571 m .54356 .75401 L .5414 .75674 L F
.54284 .75571 m .54488 .75732 L .54356 .75401 L F
.579 .184 .258 r
.39484 .69638 m .39161 .69673 L .39222 .69714 L F
.416 .821 .979 r
.67964 .53589 m .68286 .53599 L .68161 .5346 L F
.764 .811 .89 r
.68161 .5346 m .68286 .53599 L .68488 .53457 L F
.968 .923 .697 r
.65215 .49263 m .65302 .49174 L .6522 .4913 L F
.923 .969 .771 r
.65326 .49132 m .65221 .49119 L .65302 .49174 L F
.65404 .48996 m .65287 .49075 L .65326 .49132 L F
.65287 .49075 m .65221 .49119 L .65326 .49132 L F
.837 .527 .466 r
.65079 .48965 m .65404 .48996 L .64903 .48694 L F
.761 .289 0 r
.6497 .48865 m .65079 .48965 L .6507 .48951 L F
.6497 .48865 m .6507 .48951 L .64903 .48694 L F
.706 .206 .051 r
.64645 .4876 m .6497 .48865 L .64718 .48631 L F
.092 .528 .907 r
.6485 .48772 m .6487 .48781 L .6497 .48865 L F
.837 .527 .466 r
.65079 .48965 m .65221 .49119 L .65404 .48996 L F
.366 .472 .835 r
.65238 .49003 m .65454 .49054 L .65279 .49183 L F
.65221 .49119 m .65279 .49183 L .65204 .49238 L F
.923 .969 .771 r
.65221 .49119 m .6522 .4913 L .65302 .49174 L F
.366 .472 .835 r
.65238 .49003 m .65279 .49183 L .65221 .49119 L F
.65079 .48965 m .65238 .49003 L .65204 .49238 L F
.837 .527 .466 r
.65079 .48965 m .65212 .49126 L .65221 .49119 L F
.761 .289 0 r
.6497 .48865 m .64903 .48694 L .64718 .48631 L F
.092 .528 .907 r
.6487 .48781 m .65364 .4901 L .6497 .48865 L F
0 .411 .768 r
.6497 .48865 m .65209 .48959 L .65079 .48965 L F
.65209 .48959 m .65454 .49054 L .65238 .49003 L F
.65209 .48959 m .65238 .49003 L .65079 .48965 L F
.968 .923 .697 r
.65215 .49263 m .6522 .4913 L .65212 .49126 L F
.366 .472 .835 r
.65204 .49238 m .65216 .49229 L .65215 .49263 L F
.65216 .49229 m .65454 .49054 L .65215 .49263 L F
.923 .969 .771 r
.65221 .49119 m .65212 .49126 L .6522 .4913 L F
.582 .193 .27 r
.51212 .8029 m .50854 .80494 L .50886 .80344 L F
.51212 .8029 m .51171 .80454 L .50854 .80494 L F
.443 .818 .992 r
.5145 .80252 m .51286 .80203 L .51212 .8029 L F
0 0 0 r
.51286 .80203 m .51171 .80454 L .51212 .8029 L F
.479 .306 .567 r
.50607 .76819 m .50367 .76604 L .507 .7664 L F
.295 .353 .753 r
.49794 .79436 m .49885 .7978 L .50046 .79643 L F
.443 .616 .924 r
.49885 .7978 m .50153 .79845 L .50046 .79643 L F
0 0 0 r
.6768 .48415 m .67973 .48163 L .67935 .48042 L F
.67873 .48134 m .67935 .48042 L .67913 .4814 L F
.669 .264 .268 r
.67935 .48042 m .67973 .48163 L .67932 .48142 L F
0 .402 .834 r
.67933 .48143 m .67973 .48163 L .67953 .48145 L F
0 0 0 r
.6768 .48415 m .67855 .48273 L .67861 .48268 L F
.67745 .4836 m .67861 .48268 L .67973 .48163 L F
.6768 .48415 m .67861 .48268 L .67745 .4836 L F
.6768 .48415 m .67873 .48134 L .67872 .48247 L F
.036 0 .188 r
.67928 .48234 m .67871 .48324 L .67894 .48222 L F
.836 .82 .833 r
.6793 .48175 m .67928 .48175 L .67953 .48145 L F
.036 0 .188 r
.67928 .48175 m .67895 .48218 L .67913 .4814 L F
.6793 .48142 m .67913 .4814 L .67935 .48042 L F
.67928 .48175 m .67913 .4814 L .6793 .48142 L F
.6793 .48172 m .67928 .48175 L .6793 .48142 L F
.67932 .48142 m .6793 .48142 L .67935 .48042 L F
.6793 .48172 m .6793 .48142 L .67932 .48142 L F
0 .402 .834 r
.67933 .48143 m .67953 .48145 L .67952 .48144 L F
.669 .264 .268 r
.67935 .48042 m .67932 .48126 L .67814 .48018 L F
.67932 .48126 m .67932 .48142 L .67814 .48018 L F
.67814 .48018 m .67932 .48142 L .67615 .47978 L F
0 .402 .834 r
.67932 .48142 m .67952 .48144 L .67793 .47999 L F
.67933 .48143 m .67952 .48144 L .67932 .48142 L F
.735 .936 .604 r
.67886 .47826 m .67796 .47946 L .67793 .47999 L F
0 .402 .834 r
.67615 .47978 m .6779 .48069 L .67793 .47999 L F
.588 .43 .634 r
.67793 .47999 m .67528 .4828 L .67561 .48049 L F
.735 .936 .604 r
.67796 .47946 m .67664 .4812 L .67793 .47999 L F
0 .402 .834 r
.6779 .48069 m .67932 .48142 L .67793 .47999 L F
.67932 .48142 m .67933 .48143 L .67932 .48142 L F
.67932 .48142 m .67932 .48142 L .67793 .47999 L F
0 0 0 r
.67873 .48134 m .67913 .4814 L .67871 .48324 L F
.836 .82 .833 r
.67928 .48175 m .67528 .4828 L .6795 .48146 L F
.67928 .48175 m .6795 .48146 L .67953 .48145 L F
.036 0 .188 r
.67928 .48175 m .67894 .48222 L .67895 .48218 L F
.836 .82 .833 r
.6793 .48175 m .67924 .48181 L .67928 .48175 L F
.67973 .48163 m .67855 .48273 L .6793 .48175 L F
.036 0 .188 r
.67928 .48234 m .67894 .48222 L .6793 .48172 L F
.836 .82 .833 r
.67928 .48175 m .67667 .48448 L .67528 .4828 L F
.67924 .48181 m .67667 .48448 L .67928 .48175 L F
0 0 0 r
.67843 .48283 m .67872 .48247 L .67872 .48252 L F
.67843 .48283 m .67872 .48252 L .67855 .48273 L F
.6768 .48415 m .67872 .48247 L .67843 .48283 L F
.6768 .48415 m .67871 .4826 L .67871 .48324 L F
.6768 .48415 m .67667 .48448 L .67855 .48273 L F
.836 .82 .833 r
.67855 .48273 m .67667 .48448 L .6793 .48175 L F
0 0 0 r
.67855 .48273 m .67872 .48252 L .67871 .4826 L F
.036 0 .188 r
.67951 .48197 m .67929 .48215 L .6793 .48172 L F
.67947 .48151 m .6793 .48172 L .67935 .48042 L F
.67951 .48197 m .6793 .48172 L .67947 .48151 L F
.836 .82 .833 r
.67952 .48144 m .67528 .4828 L .67793 .47999 L F
.67953 .48145 m .6795 .48146 L .67952 .48144 L F
.6795 .48146 m .67528 .4828 L .67952 .48144 L F
.67973 .48163 m .6793 .48175 L .67953 .48145 L F
.036 0 .188 r
.68066 .48016 m .67951 .48197 L .67935 .48042 L F
.67951 .48197 m .67928 .48234 L .67929 .48215 L F
0 .402 .834 r
.67615 .47978 m .67793 .47999 L .67561 .48049 L F
0 0 .329 r
.52728 .64838 m .52765 .64915 L .52518 .64846 L F
.52728 .64838 m .52856 .65099 L .52765 .64915 L F
.871 .686 .649 r
.58285 .57957 m .58439 .58072 L .58298 .57743 L F
.862 .694 .672 r
.58408 .58312 m .58439 .58072 L .58285 .57957 L F
.368 .013 .224 r
.33264 .62727 m .33435 .62783 L .33548 .62548 L F
.331 0 .205 r
.33548 .62548 m .33647 .62713 L .33736 .62447 L F
.33548 .62548 m .33435 .62783 L .33647 .62713 L F
.464 .815 .998 r
.53829 .77727 m .54179 .77759 L .54056 .7769 L F
.899 .983 .791 r
.56364 .57146 m .56581 .56848 L .5664 .56909 L F
.878 .992 .795 r
.56581 .56848 m .56856 .56622 L .5664 .56909 L F
.603 .815 .413 r
.55963 .71003 m .5604 .70883 L .56189 .70667 L F
.191 .173 .607 r
.55938 .71249 m .5604 .70883 L .55963 .71003 L F
0 .124 .628 r
.52015 .791 m .52107 .7921 L .52326 .79391 L F
.261 .058 .405 r
.56729 .70741 m .56919 .70388 L .56718 .70462 L F
0 .1 .624 r
.49717 .77499 m .49877 .77672 L .49912 .7741 L F
.544 .097 .139 r
.44079 .66442 m .43958 .66614 L .43744 .66487 L F
.16 0 0 r
.4425 .6645 m .44079 .66442 L .44271 .66399 L F
.4425 .6645 m .43958 .66614 L .44079 .66442 L F
.689 .482 .601 r
.51905 .79178 m .51826 .79467 L .51578 .79469 L F
.407 .747 .994 r
.51905 .79178 m .51867 .79415 L .51826 .79467 L F
0 0 0 r
.52375 .64946 m .52728 .64838 L .52518 .64846 L F
.893 .988 .744 r
.58635 .57083 m .58799 .56986 L .58844 .56776 L F
0 0 0 r
.68192 .4791 m .68066 .48016 L .67935 .48042 L F
.68358 .47793 m .68192 .4791 L .68424 .47836 L F
.68358 .47793 m .68066 .48016 L .68192 .4791 L F
.123 0 .137 r
.61489 .53473 m .61193 .53765 L .61214 .53557 L F
0 .278 .781 r
.47311 .81099 m .47621 .81364 L .47373 .81061 L F
.714 .422 .48 r
.24564 .66409 m .24958 .66199 L .24756 .66131 L F
.59 .581 .811 r
.24958 .66199 m .24723 .66492 L .24922 .66212 L F
.714 .422 .48 r
.24564 .66409 m .24922 .66457 L .24958 .66199 L F
.577 .297 .455 r
.24958 .66199 m .25138 .66402 L .25156 .66162 L F
.24958 .66199 m .24922 .66457 L .25138 .66402 L F
.511 .322 .561 r
.56943 .70162 m .57138 .70336 L .57178 .70129 L F
.56943 .70162 m .56919 .70388 L .57138 .70336 L F
.723 .747 .871 r
.77134 .60607 m .77307 .60242 L .77024 .60381 L F
.77134 .60607 m .7733 .60484 L .77307 .60242 L F
0 .407 .708 r
.32709 .58756 m .3289 .5881 L .33055 .58865 L F
.174 .648 .931 r
.33075 .58809 m .33055 .58865 L .3289 .5881 L F
.33075 .58809 m .33261 .58891 L .33055 .58865 L F
.514 .53 .81 r
.39178 .68406 m .39303 .68742 L .39495 .68695 L F
.47 .398 .693 r
.39303 .68742 m .39546 .68934 L .39495 .68695 L F
.39303 .68742 m .39347 .69074 L .39546 .68934 L F
.419 .148 .393 r
.36864 .61679 m .37116 .61427 L .37076 .61626 L F
.491 .284 .527 r
.37307 .61359 m .37076 .61626 L .37116 .61427 L F
.949 .662 .46 r
.61772 .52589 m .618 .52833 L .61939 .52646 L F
.484 .046 .131 r
.61939 .52646 m .62026 .52769 L .62182 .52693 L F
.61939 .52646 m .618 .52833 L .62026 .52769 L F
.676 .487 .623 r
.5709 .61656 m .56707 .61388 L .57095 .61402 L F
.603 .364 .527 r
.57095 .61402 m .57302 .61621 L .5709 .61656 L F
.64 .362 .482 r
.57318 .61422 m .57302 .61621 L .57095 .61402 L F
.672 .515 .663 r
.53575 .6707 m .53347 .67323 L .53345 .67075 L F
.53575 .6707 m .53347 .67323 L .53345 .67075 L F
.684 .559 .707 r
.48359 .80786 m .48706 .80915 L .48456 .81135 L F
.193 .076 .483 r
.54004 .78635 m .53847 .78931 L .53744 .7888 L F
.343 .795 .95 r
.53847 .78931 m .53991 .78858 L .53744 .7888 L F
.53847 .78931 m .54083 .78903 L .53991 .78858 L F
.468 .284 .547 r
.62107 .49598 m .62109 .49826 L .62322 .4953 L F
.347 0 0 r
.44301 .64719 m .44192 .64783 L .4452 .64717 L F
.896 .89 .816 r
.59761 .71493 m .59891 .71587 L .60098 .71281 L F
.745 .52 .589 r
.53974 .79972 m .54307 .79725 L .54243 .79844 L F
.53974 .79972 m .54311 .80018 L .54307 .79725 L F
.854 .74 .737 r
.73371 .51318 m .73445 .5159 L .73347 .51631 L F
.519 .086 .157 r
.73347 .51631 m .73445 .5159 L .73344 .51725 L F
.997 .804 .525 r
.73445 .5159 m .73439 .51838 L .73344 .51725 L F
.108 0 0 r
.28733 .58506 m .28946 .58481 L .29107 .5841 L F
.782 .978 .705 r
.56085 .57628 m .56228 .57537 L .56131 .57635 L F
.988 .893 .62 r
.56146 .57484 m .56228 .57537 L .56085 .57628 L F
.553 .319 .515 r
.74588 .58508 m .74816 .5848 L .74892 .58291 L F
.627 .498 .686 r
.74677 .58863 m .74816 .5848 L .74588 .58508 L F
.017 0 0 r
.25607 .63212 m .25336 .63301 L .25509 .63207 L F
.878 .992 .795 r
.56581 .56848 m .56812 .56558 L .56856 .56622 L F
.858 .994 .822 r
.56856 .56622 m .57046 .56293 L .57097 .56331 L F
.56856 .56622 m .56812 .56558 L .57046 .56293 L F
.925 .831 .734 r
.65485 .51568 m .65348 .51481 L .65435 .51252 L F
.132 .367 .825 r
.65515 .51756 m .65348 .51481 L .65485 .51568 L F
.663 .488 .637 r
.61042 .59508 m .6106 .59682 L .60778 .59728 L F
.4 .156 .425 r
.61408 .59458 m .6106 .59682 L .61042 .59508 L F
.057 .061 .545 r
.55282 .75053 m .55317 .75157 L .55415 .75145 L F
.467 0 0 r
.55196 .75078 m .55282 .75053 L .55415 .75145 L F
1 .828 .507 r
.55192 .7486 m .55282 .75053 L .55196 .75078 L F
.813 .679 .716 r
.66262 .51675 m .66055 .51787 L .66383 .51832 L F
.811 .689 .73 r
.66055 .51787 m .66193 .52146 L .66383 .51832 L F
.888 .472 .2 r
.54127 .62761 m .53876 .62503 L .54003 .6263 L F
.673 .695 .863 r
.28048 .64407 m .28398 .64485 L .28143 .64259 L F
.421 .74 .992 r
.28398 .64485 m .2845 .6436 L .28143 .64259 L F
.28398 .64485 m .28594 .64466 L .2845 .6436 L F
.477 .272 .522 r
.28398 .64485 m .28347 .64766 L .28594 .64466 L F
.388 .237 .552 r
.24723 .66492 m .24922 .66457 L .24564 .66409 L F
.24723 .66492 m .24881 .66633 L .24922 .66457 L F
.523 .255 .451 r
.53109 .68955 m .52808 .69121 L .52825 .69003 L F
.989 .812 .575 r
.728 .50347 m .7294 .49958 L .72926 .49889 L F
.728 .50347 m .72906 .50438 L .7294 .49958 L F
.289 .346 .749 r
.47861 .77621 m .47954 .7796 L .47723 .77754 L F
.437 .365 .678 r
.47723 .77754 m .47954 .7796 L .47772 .77988 L F
.395 .079 .308 r
.50205 .80276 m .50462 .79962 L .50251 .79949 L F
.50205 .80276 m .50518 .80252 L .50462 .79962 L F
0 0 .099 r
.50693 .79728 m .50462 .79962 L .50538 .7999 L F
.149 0 .315 r
.50462 .79962 m .50614 .80139 L .50538 .7999 L F
.50462 .79962 m .50518 .80252 L .50614 .80139 L F
.428 .13 .355 r
.54004 .78635 m .5439 .78283 L .53972 .78323 L F
.687 .721 .876 r
.49479 .62908 m .49128 .62843 L .49351 .62769 L F
.648 .756 .928 r
.49698 .62836 m .49479 .62908 L .49351 .62769 L F
.411 .322 .645 r
.39053 .67616 m .39209 .67358 L .38971 .67316 L F
.39053 .67616 m .39222 .67572 L .39209 .67358 L F
.421 .358 .681 r
.39053 .67616 m .39271 .67817 L .39222 .67572 L F
.51 .362 .616 r
.39053 .67616 m .39063 .67864 L .39271 .67817 L F
.829 .694 .156 r
.48319 .80434 m .48333 .80571 L .48311 .80625 L F
.123 .619 .908 r
.48739 .8119 m .48456 .81135 L .48706 .80915 L F
.908 .513 .104 r
.6942 .51544 m .69611 .51831 L .695 .5172 L F
.88 .732 .694 r
.69611 .51831 m .69309 .5203 L .695 .5172 L F
.69611 .51831 m .69538 .52058 L .69309 .5203 L F
.462 .249 .503 r
.29458 .6141 m .29447 .61615 L .29244 .61677 L F
.404 .185 .464 r
.29412 .61827 m .29244 .61677 L .29447 .61615 L F
.29412 .61827 m .29158 .62009 L .29244 .61677 L F
.833 .689 .704 r
.54775 .79412 m .54905 .79732 L .54717 .7965 L F
.856 .497 .371 r
.54782 .79908 m .54905 .79732 L .54717 .7965 L F
.569 .926 .755 r
.47425 .79531 m .47242 .79688 L .47231 .79706 L F
0 0 .138 r
.47242 .79688 m .47205 .79904 L .47289 .79875 L F
.47242 .79688 m .47289 .79875 L .47231 .79706 L F
.295 0 0 r
.29316 .58417 m .29518 .58446 L .29683 .58407 L F
.123 .673 .769 r
.29518 .58446 m .2988 .58421 L .29683 .58407 L F
.361 0 .119 r
.41439 .65603 m .41661 .65559 L .41784 .6537 L F
.414 0 .126 r
.41661 .65559 m .42012 .65354 L .41784 .6537 L F
.66 .381 .487 r
.59469 .60245 m .59135 .60492 L .59142 .60327 L F
.475 .308 .573 r
.25934 .64006 m .26143 .63962 L .26123 .63658 L F
.187 .602 .943 r
.42481 .69572 m .42399 .6964 L .42274 .69519 L F
.42481 .69572 m .426 .69658 L .42399 .6964 L F
.599 .386 .563 r
.57529 .61191 m .57533 .61365 L .57318 .61422 L F
.57 .34 .528 r
.57864 .61059 m .57533 .61365 L .57529 .61191 L F
.407 .193 .473 r
.29688 .61123 m .29652 .61377 L .29458 .6141 L F
.468 .282 .544 r
.29652 .61377 m .29447 .61615 L .29458 .6141 L F
.548 .353 .569 r
.55435 .76918 m .55442 .77155 L .55517 .7709 L F
.533 .573 .841 r
.51463 .78895 m .51701 .78845 L .51551 .78615 L F
.448 .27 .546 r
.51474 .79161 m .51701 .78845 L .51463 .78895 L F
.672 .128 0 r
.51531 .76472 m .51504 .76355 L .51474 .76284 L F
.51531 .76472 m .51751 .76563 L .51504 .76355 L F
.672 .129 0 r
.51504 .76355 m .51751 .76563 L .519 .76588 L F
.868 .836 .812 r
.77496 .60254 m .77651 .60059 L .77512 .59913 L F
.976 .761 .547 r
.77512 .59913 m .77651 .60059 L .77618 .59811 L F
.944 .696 .533 r
.56589 .7507 m .56755 .75214 L .56564 .74882 L F
.94 .617 .176 r
.56589 .7507 m .56741 .75576 L .56755 .75214 L F
.432 .795 .996 r
.55248 .62768 m .55503 .62737 L .55604 .62817 L F
.743 .739 .848 r
.55604 .62817 m .55352 .62889 L .55248 .62768 L F
.432 .795 .996 r
.55248 .62768 m .55503 .62737 L .55604 .62817 L F
.544 .521 .78 r
.55725 .62438 m .55604 .62817 L .55503 .62737 L F
.55725 .62438 m .558 .62819 L .55604 .62817 L F
.246 .135 .524 r
.55872 .62992 m .55669 .63131 L .558 .62819 L F
.356 .332 .694 r
.55872 .62992 m .55604 .62817 L .558 .62819 L F
.55872 .62992 m .55669 .63131 L .55611 .62853 L F
.55872 .62992 m .55611 .62853 L .55656 .62851 L F
.16 0 0 r
.558 .62819 m .55469 .62969 L .55872 .62992 L F
.55737 .62847 m .55746 .62917 L .55469 .62969 L F
.558 .62819 m .55786 .62845 L .55737 .62847 L F
.55786 .62845 m .55746 .62917 L .55737 .62847 L F
.356 .332 .694 r
.55656 .62851 m .55611 .62853 L .55604 .62817 L F
.529 .517 .787 r
.25368 .61375 m .25466 .61036 L .25298 .61184 L F
.25368 .61375 m .25564 .61331 L .25466 .61036 L F
.494 .501 .793 r
.25368 .61375 m .25659 .61668 L .25564 .61331 L F
.896 .778 .286 r
.6339 .56017 m .63421 .55783 L .63366 .55934 L F
.684 .745 .244 r
.63366 .55934 m .63421 .55783 L .63493 .55564 L F
.564 .688 .924 r
.69714 .48133 m .69937 .4798 L .69703 .4803 L F
.69714 .48133 m .69965 .48097 L .69937 .4798 L F
.881 .99 .737 r
.57097 .56331 m .57249 .56001 L .57318 .56038 L F
.57097 .56331 m .57046 .56293 L .57249 .56001 L F
.912 .516 .123 r
.5992 .70997 m .59991 .71208 L .60098 .71281 L F
.896 .89 .816 r
.59761 .71493 m .60098 .71281 L .59991 .71208 L F
.568 .394 .606 r
.25344 .59998 m .25575 .59956 L .25577 .59708 L F
.515 .34 .583 r
.25356 .60235 m .25575 .59956 L .25344 .59998 L F
.65 .43 .573 r
.74816 .5848 m .75186 .58289 L .74892 .58291 L F
.951 .858 .713 r
.7361 .50081 m .73494 .5002 L .73597 .49786 L F
.966 .914 .708 r
.7361 .50081 m .73394 .50304 L .73494 .5002 L F
.7361 .50081 m .73464 .50419 L .73394 .50304 L F
.547 .501 .756 r
.39413 .69306 m .39546 .68934 L .39347 .69074 L F
.342 .192 .528 r
.5298 .77728 m .52947 .77468 L .53139 .77429 L F
.594 .653 .877 r
.45541 .65779 m .45734 .65967 L .45944 .65885 L F
.45541 .65779 m .45734 .65967 L .45944 .65885 L F
.24 0 .09 r
.53384 .68757 m .53356 .68869 L .53109 .68955 L F
.564 .803 .989 r
.53589 .68691 m .53384 .68757 L .53286 .68626 L F
.033 .167 .673 r
.53286 .68626 m .53384 .68757 L .53589 .68691 L F
.53286 .68626 m .53356 .68869 L .53384 .68757 L F
.479 .317 .584 r
.53589 .68691 m .53596 .68949 L .53384 .68757 L F
.504 .841 .998 r
.51407 .7764 m .514 .77741 L .51173 .7772 L F
.816 .477 0 r
.51433 .77921 m .5149 .78024 L .514 .77741 L F
.976 .715 .47 r
.51654 .77288 m .514 .77741 L .51407 .7764 L F
.51654 .77288 m .51659 .77693 L .514 .77741 L F
.244 0 .24 r
.51659 .77693 m .51433 .77921 L .514 .77741 L F
.445 .482 .803 r
.67001 .51829 m .67172 .51792 L .67086 .51466 L F
.533 .484 .747 r
.67044 .52065 m .67172 .51792 L .67001 .51829 L F
.54 .16 .268 r
.4492 .69468 m .45158 .69477 L .45274 .69256 L F
.437 .05 .206 r
.45158 .69477 m .45504 .69235 L .45274 .69256 L F
.55 .429 .668 r
.38971 .67316 m .39209 .67358 L .39163 .67004 L F
.55 .575 .833 r
.39902 .70106 m .39971 .6978 L .39719 .6983 L F
.39902 .70106 m .40129 .70102 L .39971 .6978 L F
.356 .411 .781 r
.39902 .70106 m .40152 .703 L .40129 .70102 L F
.418 .794 .993 r
.32706 .60128 m .3286 .60053 L .3265 .60083 L F
.32706 .60128 m .32972 .60098 L .3286 .60053 L F
.419 .033 .197 r
.32929 .62977 m .33264 .62727 L .32996 .62857 L F
.32929 .62977 m .33143 .62946 L .33264 .62727 L F
.191 0 .077 r
.33264 .62727 m .33336 .62862 L .33435 .62783 L F
.33264 .62727 m .33143 .62946 L .33336 .62862 L F
.353 0 .021 r
.42424 .70924 m .42323 .7102 L .42103 .71041 L F
.182 0 0 r
.42634 .70864 m .42539 .70957 L .42424 .70924 L F
.177 0 0 r
.42539 .70957 m .42323 .7102 L .42424 .70924 L F
.626 .749 .936 r
.77721 .59647 m .7783 .59826 L .77618 .59811 L F
.77618 .59811 m .7783 .59826 L .77721 .59647 L F
.583 .553 .786 r
.7783 .59826 m .77947 .59502 L .77721 .59647 L F
.7783 .59826 m .78076 .59732 L .77947 .59502 L F
.725 .726 .851 r
.56773 .72564 m .56882 .72698 L .57064 .72581 L F
.318 .656 .972 r
.31079 .63015 m .31017 .63121 L .30869 .63026 L F
.31079 .63015 m .31221 .63139 L .31017 .63121 L F
.249 0 .237 r
.50387 .70018 m .50601 .69809 L .50393 .69877 L F
.813 .671 .706 r
.4865 .79935 m .49108 .79931 L .4903 .79751 L F
.809 .608 .63 r
.48904 .80236 m .49108 .79931 L .4865 .79935 L F
.019 0 .281 r
.4901 .80298 m .49108 .79931 L .48904 .80236 L F
.562 .834 .996 r
.71959 .51861 m .72328 .51889 L .72185 .51757 L F
.805 .826 .867 r
.72185 .51757 m .72328 .51889 L .72493 .51712 L F
.79 .653 .711 r
.54854 .63378 m .5456 .63635 L .54854 .63302 L F
.316 .367 .757 r
.54854 .63302 m .54986 .63321 L .54854 .63378 L F
.417 .739 .992 r
.54986 .63321 m .55097 .63383 L .54854 .63378 L F
.764 .91 .939 r
.5096 .69714 m .50601 .69809 L .50824 .69748 L F
.312 0 0 r
.50824 .69748 m .51208 .69613 L .5096 .69714 L F
.547 .501 .756 r
.39413 .69306 m .39622 .69258 L .39546 .68934 L F
.741 .425 .447 r
.39413 .69306 m .39297 .6957 L .39583 .6953 L F
.52 .388 .642 r
.39413 .69306 m .39583 .6953 L .39622 .69258 L F
.39413 .69306 m .39583 .6953 L .39622 .69258 L F
.819 .775 .811 r
.70468 .518 m .70778 .51801 L .70703 .51502 L F
.806 .805 .85 r
.706 .51934 m .70778 .51801 L .70468 .518 L F
.8 .764 .82 r
.70703 .51502 m .70778 .51801 L .71014 .5154 L F
.953 .724 .554 r
.63682 .53342 m .63752 .53234 L .63627 .53115 L F
.63682 .53342 m .63745 .53471 L .63752 .53234 L F
.991 .742 .379 r
.69726 .50984 m .69641 .51123 L .69613 .50868 L F
.69726 .50984 m .69727 .51218 L .69641 .51123 L F
.755 .849 .921 r
.69945 .50858 m .69726 .50984 L .69613 .50868 L F
.21 0 0 r
.77249 .59978 m .77512 .59913 L .77618 .59811 L F
.661 .65 .829 r
.51581 .65993 m .51946 .6622 L .51817 .65911 L F
.71 .697 .836 r
.51817 .65911 m .51946 .6622 L .52137 .66116 L F
.062 0 0 r
.31028 .60368 m .30878 .60502 L .30727 .6051 L F
0 0 0 r
.3103 .60393 m .31028 .60368 L .31203 .60273 L F
.3103 .60393 m .30878 .60502 L .31028 .60368 L F
.636 .728 .915 r
.75399 .59692 m .75521 .59837 L .75757 .59753 L F
.949 .723 .562 r
.63532 .54168 m .63657 .54093 L .63534 .53983 L F
.63532 .54168 m .63659 .54332 L .63657 .54093 L F
.841 .87 .864 r
.63534 .53983 m .63657 .54093 L .63912 .53831 L F
.541 .834 .999 r
.71652 .49031 m .71837 .48893 L .7159 .48702 L F
.71652 .49031 m .71906 .48983 L .71837 .48893 L F
.71652 .49031 m .71837 .48893 L .71619 .49055 L F
.71652 .49031 m .71906 .48983 L .71837 .48893 L F
.396 .28 .602 r
.60799 .51828 m .61032 .51749 L .60993 .51487 L F
.245 .034 .382 r
.60835 .52031 m .61032 .51749 L .60799 .51828 L F
.856 .867 .848 r
.70419 .51935 m .706 .51934 L .70468 .518 L F
.881 .992 .781 r
.52626 .7994 m .52375 .80306 L .52283 .80297 L F
.646 .088 0 r
.52283 .80297 m .52375 .80306 L .52591 .80496 L F
.598 .478 .686 r
.52626 .7994 m .52624 .80284 L .52375 .80306 L F
.561 .309 .491 r
.52375 .80306 m .52624 .80284 L .52591 .80496 L F
.544 .285 .473 r
.58103 .60856 m .58089 .6105 L .57864 .61059 L F
.535 .29 .49 r
.58334 .60813 m .58089 .6105 L .58103 .60856 L F
.656 .408 .533 r
.60778 .59728 m .6051 .59962 L .60514 .59728 L F
.419 .093 .304 r
.59109 .58856 m .59339 .58802 L .59379 .58647 L F
.61 .289 .402 r
.59597 .58817 m .59379 .58647 L .59339 .58802 L F
.59597 .58817 m .59676 .58592 L .59379 .58647 L F
.983 .737 .485 r
.48414 .79087 m .48537 .7889 L .4841 .78808 L F
.608 .2 .242 r
.48754 .79067 m .48537 .7889 L .48414 .79087 L F
.593 .21 .286 r
.48754 .79067 m .48804 .78912 L .48537 .7889 L F
.422 .37 .695 r
.25246 .60842 m .25466 .61036 L .25437 .60792 L F
.25246 .60842 m .25298 .61184 L .25466 .61036 L F
.512 .358 .608 r
.38554 .60429 m .38311 .60305 L .38496 .60146 L F
.38554 .60429 m .38327 .60533 L .38311 .60305 L F
.152 0 0 r
.30099 .58399 m .30474 .58428 L .30268 .58412 L F
.825 .471 .385 r
.53706 .77411 m .5411 .77551 L .54056 .7769 L F
.157 0 .155 r
.6106 .59682 m .60813 .60003 L .60778 .59728 L F
.656 .408 .533 r
.60778 .59728 m .60813 .60003 L .6051 .59962 L F
.86 .654 .621 r
.62423 .53541 m .62391 .53777 L .6221 .53483 L F
.511 .05 .095 r
.44974 .6454 m .45335 .6447 L .45117 .6453 L F
.7 .638 .783 r
.58626 .71688 m .58341 .72147 L .58404 .71769 L F
.58626 .71688 m .58719 .71847 L .58341 .72147 L F
.659 .34 .421 r
.59597 .58817 m .59915 .58791 L .59676 .58592 L F
.635 .352 .472 r
.59676 .58592 m .59915 .58791 L .59925 .58592 L F
.711 .856 .951 r
.64309 .50037 m .64593 .50025 L .64407 .49947 L F
0 .509 .816 r
.64593 .50025 m .64749 .50055 L .64407 .49947 L F
.711 .856 .951 r
.64188 .50042 m .64309 .50037 L .64407 .49947 L F
.259 .249 .658 r
.64407 .49947 m .64301 .50404 L .64188 .50042 L F
.64407 .49947 m .64451 .50569 L .64301 .50404 L F
.773 .647 .724 r
.64749 .50055 m .64451 .50569 L .64407 .49947 L F
0 0 0 r
.64407 .49947 m .64322 .50082 L .64486 .49874 L F
.64407 .49947 m .64486 .49874 L .64488 .49872 L F
.228 0 0 r
.67667 .48448 m .67556 .48458 L .6768 .48415 L F
.6768 .48415 m .67556 .48458 L .67667 .48448 L F
0 0 0 r
.67871 .48324 m .67667 .48448 L .6768 .48415 L F
.633 .753 .935 r
.66445 .48123 m .66543 .47848 L .66417 .47819 L F
.66445 .48123 m .66658 .48084 L .66543 .47848 L F
.562 .372 .582 r
.26123 .63658 m .26353 .63909 L .26296 .63578 L F
.26123 .63658 m .26143 .63962 L .26353 .63909 L F
.014 .213 .722 r
.48571 .64233 m .48923 .6429 L .48805 .64186 L F
.508 .217 .408 r
.48805 .64186 m .48778 .64408 L .48571 .64233 L F
.705 .3 .276 r
.30441 .64757 m .30857 .64787 L .30629 .64757 L F
.707 .324 .322 r
.30857 .64787 m .30651 .64961 L .30629 .64757 L F
.30857 .64787 m .31001 .64968 L .30651 .64961 L F
.777 .287 .056 r
.31071 .64953 m .31001 .64968 L .30857 .64787 L F
.6 .606 .83 r
.68959 .5198 m .68819 .52321 L .68721 .52039 L F
.68959 .5198 m .69058 .52252 L .68819 .52321 L F
.722 .42 .466 r
.4859 .69277 m .48778 .69374 L .48856 .69336 L F
.373 0 0 r
.48778 .69374 m .49107 .69297 L .48856 .69336 L F
.274 .775 .871 r
.42725 .69606 m .4288 .69621 L .426 .69658 L F
.238 0 0 r
.42725 .69606 m .42755 .69612 L .4288 .69621 L F
.42755 .69612 m .43072 .69672 L .4288 .69621 L F
.233 .75 .837 r
.42979 .69629 m .4288 .69621 L .42995 .69628 L F
.426 .69658 m .4288 .69621 L .42979 .69629 L F
.165 0 0 r
.43072 .69672 m .42995 .69628 L .4288 .69621 L F
.43072 .69672 m .43207 .69634 L .42995 .69628 L F
.899 .82 .76 r
.73675 .48972 m .73726 .4927 L .73587 .49172 L F
.924 .918 .79 r
.73726 .4927 m .7345 .4946 L .73587 .49172 L F
.73726 .4927 m .73525 .49576 L .7345 .4946 L F
.848 .791 .796 r
.73923 .48983 m .73726 .4927 L .73675 .48972 L F
.823 .77 .802 r
.55352 .62889 m .55014 .63064 L .55248 .62768 L F
.55352 .62889 m .5491 .63195 L .55014 .63064 L F
.868 .836 .812 r
.77496 .60254 m .77512 .59913 L .77307 .60242 L F
.905 .867 .791 r
.77307 .60242 m .7733 .60484 L .77496 .60254 L F
.729 .604 .717 r
.76754 .57494 m .76763 .57714 L .76965 .57458 L F
.708 .573 .701 r
.76763 .57714 m .77112 .57808 L .76965 .57458 L F
0 0 .278 r
.51803 .64474 m .51906 .64764 L .51915 .64809 L F
.404 .236 .538 r
.61301 .56636 m .6148 .56563 L .61483 .56329 L F
.386 .199 .501 r
.61301 .56636 m .61289 .56861 L .6148 .56563 L F
.547 .633 .888 r
.31382 .63125 m .31369 .63388 L .31221 .63139 L F
.31382 .63125 m .31576 .6335 L .31369 .63388 L F
.649 .094 0 r
.29081 .64877 m .29224 .64782 L .2921 .6477 L F
.29081 .64877 m .29022 .64927 L .29224 .64782 L F
.29081 .64877 m .29299 .65026 L .29022 .64927 L F
.52 .56 .837 r
.6677 .53531 m .67023 .53536 L .66885 .53283 L F
.281 0 0 r
.24684 .6532 m .24869 .65363 L .25044 .65388 L F
.854 .838 .829 r
.25044 .65388 m .24869 .65363 L .25119 .64949 L F
.772 .422 .393 r
.54921 .73484 m .55299 .73735 L .55236 .73573 L F
.888 .902 .833 r
.58445 .57452 m .58135 .57605 L .58298 .57743 L F
.58445 .57452 m .58334 .57334 L .58135 .57605 L F
.392 .15 .424 r
.61751 .59081 m .61549 .59163 L .61782 .58902 L F
0 0 .31 r
.61643 .59242 m .61549 .59163 L .61751 .59081 L F
.61643 .59242 m .61553 .59399 L .61549 .59163 L F
.912 .981 .761 r
.57524 .55721 m .57318 .56038 L .57249 .56001 L F
.632 .542 .735 r
.57217 .71769 m .56973 .71866 L .56917 .71495 L F
.346 .12 .421 r
.60406 .58314 m .60665 .58211 L .60594 .57979 L F
.37 .204 .521 r
.60594 .57979 m .60887 .57931 L .60887 .57675 L F
.123 .002 .429 r
.60594 .57979 m .60772 .58107 L .60887 .57931 L F
.60594 .57979 m .60665 .58211 L .60772 .58107 L F
.18 0 0 r
.43442 .70625 m .43094 .70785 L .43233 .70703 L F
0 0 0 r
.55872 .62992 m .55587 .63261 L .55669 .63131 L F
.031 0 0 r
.30824 .5851 m .31035 .5851 L .31187 .58504 L F
.45 .861 .958 r
.31035 .5851 m .31421 .58475 L .31187 .58504 L F
.402 .685 .976 r
.78226 .59356 m .78076 .59477 L .77947 .59357 L F
.78226 .59356 m .78329 .59456 L .78076 .59477 L F
.241 .386 .809 r
.78076 .59477 m .78226 .59356 L .77947 .59357 L F
.78076 .59477 m .7827 .596 L .78226 .59356 L F
.85 .786 .789 r
.73923 .48983 m .73675 .48972 L .73883 .48674 L F
.774 .736 .818 r
.74221 .4871 m .73923 .48983 L .73883 .48674 L F
.745 .743 .85 r
.50613 .77759 m .50945 .77771 L .50809 .77619 L F
.542 .396 .632 r
.50974 .78031 m .51173 .7772 L .50945 .77771 L F
.767 .369 .299 r
.48236 .69199 m .48384 .69283 L .4859 .69277 L F
.709 .249 .158 r
.48384 .69283 m .48778 .69374 L .4859 .69277 L F
.338 .012 .257 r
.35779 .62961 m .35655 .62849 L .35859 .62788 L F
.35779 .62961 m .3558 .63022 L .35655 .62849 L F
.785 .473 .46 r
.50863 .79371 m .51248 .79232 L .50985 .79026 L F
.50863 .79371 m .51189 .79397 L .51248 .79232 L F
.897 .979 .807 r
.59456 .56123 m .59495 .55863 L .5926 .56194 L F
.66 .381 .487 r
.59469 .60245 m .5937 .60513 L .59135 .60492 L F
.601 .415 .602 r
.59725 .6002 m .59709 .60236 L .59469 .60245 L F
.614 .351 .496 r
.59709 .60236 m .5937 .60513 L .59469 .60245 L F
0 .284 .743 r
.67078 .50991 m .6743 .51213 L .67439 .51251 L F
.795 .87 .433 r
.67439 .51251 m .67494 .51047 L .67671 .51193 L F
.67439 .51251 m .6743 .51213 L .67494 .51047 L F
.766 .673 .761 r
.25279 .66725 m .25419 .67048 L .25054 .67011 L F
.095 .64 .84 r
.25419 .67048 m .25291 .67019 L .25054 .67011 L F
.965 .661 .399 r
.25281 .66946 m .25291 .67019 L .25419 .67048 L F
.544 .361 .582 r
.25054 .67011 m .25282 .67018 L .25281 .66946 L F
.965 .661 .399 r
.2521 .66893 m .25291 .67019 L .25281 .66946 L F
.544 .361 .582 r
.25255 .66755 m .25281 .66946 L .25279 .66725 L F
.25054 .67011 m .25281 .66946 L .25255 .66755 L F
.97 .715 .493 r
.25281 .66946 m .25419 .67048 L .25279 .66725 L F
.544 .361 .582 r
.25282 .67018 m .25291 .67019 L .25279 .66725 L F
.97 .715 .493 r
.2521 .66893 m .25281 .66946 L .25279 .66725 L F
.468 .833 .993 r
.33714 .58807 m .33618 .58913 L .33511 .58857 L F
.33714 .58807 m .33831 .58867 L .33618 .58913 L F
.651 .829 .968 r
.58534 .72562 m .58749 .72572 L .58577 .72457 L F
.645 .709 .893 r
.58749 .72572 m .58932 .7223 L .58577 .72457 L F
.58749 .72572 m .59093 .72375 L .58932 .7223 L F
.62 .635 .844 r
.59185 .7266 m .58749 .72572 L .58965 .72663 L F
.658 .794 .947 r
.48453 .81384 m .48798 .81424 L .48607 .81273 L F
.369 .415 .778 r
.49002 .81447 m .48798 .81424 L .48903 .81263 L F
.522 .557 .833 r
.48798 .81424 m .49168 .81714 L .49134 .81654 L F
.923 .914 .791 r
.39291 .7016 m .3935 .69789 L .39437 .70035 L F
.39291 .7016 m .3917 .70126 L .3935 .69789 L F
0 .357 .822 r
.3917 .70126 m .39437 .70035 L .39291 .7016 L F
.245 .258 .675 r
.39437 .70035 m .39462 .70355 L .39291 .7016 L F
.39437 .70035 m .39462 .70355 L .39291 .7016 L F
.163 0 .184 r
.54179 .73604 m .54283 .73695 L .54343 .73472 L F
.369 .009 .216 r
.37767 .61033 m .38141 .60688 L .37985 .60986 L F
.342 .098 .392 r
.38141 .60688 m .38327 .60533 L .38318 .60689 L F
.451 .1 .278 r
.38318 .60689 m .37985 .60986 L .38141 .60688 L F
.645 .875 .984 r
.69226 .47319 m .69356 .47134 L .69467 .47257 L F
.69226 .47319 m .69122 .47229 L .69356 .47134 L F
.127 0 0 r
.56044 .62276 m .55725 .62438 L .55671 .62232 L F
.56044 .62276 m .55927 .62399 L .55725 .62438 L F
.923 .556 .308 r
.56044 .62276 m .56075 .62502 L .55927 .62399 L F
.668 .356 .437 r
.56274 .62447 m .56044 .62276 L .56459 .62133 L F
.56274 .62447 m .56075 .62502 L .56044 .62276 L F
.479 .552 .852 r
.29231 .6244 m .29185 .62735 L .29063 .6245 L F
.29231 .6244 m .2938 .62735 L .29185 .62735 L F
.017 0 0 r
.25607 .63212 m .25686 .63091 L .25529 .63143 L F
.607 .364 .523 r
.44706 .69443 m .4492 .69468 L .44683 .69273 L F
.504 .335 .585 r
.48416 .78313 m .48232 .78668 L .48426 .78564 L F
.597 .406 .595 r
.48416 .78313 m .48426 .78564 L .48632 .78305 L F
.666 .744 .909 r
.68424 .47836 m .68769 .47905 L .68658 .47748 L F
.592 .691 .911 r
.68769 .47905 m .68922 .47679 L .68658 .47748 L F
.68769 .47905 m .68997 .47851 L .68922 .47679 L F
.417 .145 .391 r
.36864 .61679 m .36831 .61917 L .36597 .61958 L F
.423 .14 .376 r
.37076 .61626 m .36831 .61917 L .36864 .61679 L F
.789 .983 .719 r
.55821 .58059 m .55876 .57924 L .55911 .57957 L F
.822 .974 .67 r
.55876 .57924 m .56131 .57635 L .55911 .57957 L F
.439 .219 .481 r
.30098 .60971 m .2993 .60845 L .30158 .60786 L F
.30098 .60971 m .29889 .61065 L .2993 .60845 L F
.912 .981 .761 r
.57524 .55721 m .57249 .56001 L .57486 .55718 L F
.997 .771 .459 r
.57664 .55603 m .57524 .55721 L .57486 .55718 L F
.57664 .55603 m .57778 .55484 L .57524 .55721 L F
.746 .894 .946 r
.48533 .62995 m .48327 .63118 L .48199 .63035 L F
.712 .544 .66 r
.76613 .57777 m .76544 .58024 L .76763 .57714 L F
.732 .795 .902 r
.73746 .5196 m .7404 .51851 L .73692 .51806 L F
.373 0 0 r
.48778 .69374 m .49059 .69402 L .49107 .69297 L F
.469 0 0 r
.49059 .69402 m .49318 .69528 L .49107 .69297 L F
.874 .846 .814 r
.72238 .48063 m .72355 .48188 L .72136 .4848 L F
.663 .698 .872 r
.72447 .47835 m .72355 .48188 L .72238 .48063 L F
.72447 .47835 m .72626 .48092 L .72355 .48188 L F
.398 .133 .391 r
.25577 .59708 m .2577 .59656 L .25835 .59461 L F
.51 .363 .617 r
.25575 .59956 m .2577 .59656 L .25577 .59708 L F
0 0 .077 r
.6199 .58585 m .61966 .58767 L .61782 .58902 L F
0 0 .261 r
.61966 .58767 m .61751 .59081 L .61782 .58902 L F
.862 .694 .672 r
.58408 .58312 m .58285 .57957 L .58079 .5826 L F
.83 .631 .634 r
.58403 .58569 m .58408 .58312 L .58079 .5826 L F
.392 .842 .92 r
.31722 .64849 m .3199 .64878 L .32195 .64824 L F
.674 .2 .118 r
.73692 .51806 m .73344 .51725 L .73439 .51838 L F
.561 .698 .932 r
.52516 .79553 m .52834 .79681 L .52716 .7942 L F
.402 .348 .682 r
.52834 .79681 m .53083 .79898 L .53005 .79918 L F
.757 .514 .565 r
.35089 .74649 m .35233 .74711 L .34978 .7464 L F
.615 .496 .695 r
.54578 .79538 m .54775 .79412 L .5476 .79163 L F
.692 .396 .469 r
.54438 .79879 m .54717 .7965 L .54578 .79538 L F
.54448 .7988 m .54717 .7965 L .54438 .79879 L F
.689 .392 .466 r
.54782 .79908 m .54717 .7965 L .54448 .7988 L F
.633 .725 .913 r
.54459 .79881 m .54459 .79881 L .54782 .79908 L F
.54459 .79881 m .54572 .79997 L .54779 .7991 L F
.54459 .79881 m .54779 .7991 L .54782 .79908 L F
.689 .392 .466 r
.54782 .79908 m .54448 .7988 L .54431 .79895 L F
.633 .725 .913 r
.54417 .79837 m .54459 .79881 L .54782 .79908 L F
.692 .396 .469 r
.54431 .79895 m .54448 .7988 L .54438 .79879 L F
.833 .689 .704 r
.54775 .79412 m .54717 .7965 L .54578 .79538 L F
.683 .436 .542 r
.57649 .698 m .57942 .69582 L .5763 .69702 L F
.321 .022 .293 r
.48426 .78564 m .48232 .78668 L .48179 .78839 L F
.69 .816 .942 r
.67106 .48531 m .66821 .48668 L .67189 .48691 L F
.67189 .48691 m .66821 .48668 L .67106 .48531 L F
.461 .725 .982 r
.67189 .48691 m .67286 .48541 L .67106 .48531 L F
.67189 .48691 m .67404 .48664 L .67286 .48541 L F
.67286 .48541 m .67189 .48691 L .67106 .48531 L F
.67286 .48541 m .67404 .48664 L .67189 .48691 L F
.243 .007 .343 r
.63077 .56673 m .63033 .56844 L .62859 .56935 L F
.271 .056 .393 r
.63033 .56844 m .62832 .57148 L .62859 .56935 L F
.631 .398 .545 r
.50185 .7886 m .49939 .78582 L .49951 .78843 L F
.50185 .7886 m .50194 .78524 L .49939 .78582 L F
.248 .512 .907 r
.36726 .59186 m .36567 .59257 L .36472 .59163 L F
.36726 .59186 m .36829 .59353 L .36567 .59257 L F
.747 .614 .046 r
.47782 .76553 m .47771 .7677 L .47781 .76922 L F
.187 .102 .52 r
.47981 .77354 m .47869 .77417 L .47859 .77162 L F
.696 .565 .703 r
.47642 .76951 m .47656 .77353 L .47925 .77288 L F
0 0 .539 r
.47909 .77046 m .47981 .77354 L .47859 .77162 L F
.295 .35 .75 r
.48147 .77246 m .47981 .77354 L .47909 .77046 L F
.696 .565 .703 r
.47886 .77159 m .47925 .77288 L .48012 .77267 L F
0 .184 .711 r
.47773 .76789 m .47859 .77162 L .47781 .76922 L F
.47784 .76825 m .47859 .77162 L .47773 .76789 L F
.47771 .7677 m .47909 .77046 L .47859 .77162 L F
.696 .565 .703 r
.47642 .76951 m .47925 .77288 L .47886 .77159 L F
0 .184 .711 r
.47771 .7677 m .47784 .76825 L .47773 .76789 L F
.447 .227 .486 r
.2577 .59656 m .2599 .59385 L .25835 .59461 L F
.551 .399 .628 r
.39302 .66178 m .39557 .66439 L .39586 .66156 L F
.39302 .66178 m .39334 .66494 L .39557 .66439 L F
.468 .577 .881 r
.70061 .48381 m .70209 .48227 L .69965 .48097 L F
.70061 .48381 m .70288 .48401 L .70209 .48227 L F
.389 .177 .467 r
.29866 .61298 m .29688 .61123 L .29889 .61065 L F
.29866 .61298 m .29652 .61377 L .29688 .61123 L F
.805 .348 .15 r
.51805 .80533 m .51738 .8042 L .5145 .80252 L F
.461 .251 .507 r
.5192 .80348 m .51738 .8042 L .51805 .80533 L F
.642 .083 0 r
.24843 .6566 m .24673 .65617 L .24614 .65571 L F
.637 .907 .983 r
.24882 .65524 m .24673 .65617 L .24843 .6566 L F
.835 .718 .188 r
.65672 .50706 m .65644 .50709 L .6569 .50562 L F
.65672 .50706 m .65644 .50997 L .65644 .50709 L F
.779 .848 .903 r
.47413 .64773 m .47818 .6475 L .47634 .64675 L F
.285 0 0 r
.47634 .64675 m .4755 .64715 L .47413 .64773 L F
.676 .791 .935 r
.47275 .64833 m .47596 .64875 L .47413 .64773 L F
.285 0 0 r
.4755 .64715 m .47259 .6485 L .47413 .64773 L F
.676 .791 .935 r
.4716 .64818 m .47275 .64833 L .47413 .64773 L F
.779 .848 .903 r
.47413 .64773 m .47596 .64875 L .47818 .6475 L F
.717 .831 .935 r
.72136 .4848 m .71794 .48471 L .72025 .48366 L F
.874 .846 .814 r
.72238 .48063 m .72136 .4848 L .72025 .48366 L F
.87 .939 .862 r
.55089 .7797 m .55357 .77755 L .55243 .77688 L F
.976 .715 .47 r
.51654 .77288 m .51764 .77486 L .51659 .77693 L F
.969 .924 .605 r
.64146 .51704 m .64083 .521 L .64268 .51753 L F
.714 .553 .669 r
.58559 .59109 m .58889 .58858 L .58536 .58868 L F
.58559 .59109 m .58883 .59142 L .58889 .58858 L F
.659 .507 .667 r
.58889 .58858 m .58883 .59142 L .59109 .58856 L F
.432 .561 .884 r
.51034 .63752 m .51354 .63869 L .51142 .63864 L F
.918 .546 .119 r
.38899 .70449 m .38975 .70552 L .38821 .70231 L F
.571 .124 0 r
.38899 .70449 m .38974 .70552 L .38975 .70552 L F
.784 .578 .622 r
.64193 .50709 m .64523 .50769 L .64301 .50404 L F
.64523 .50769 m .64538 .50771 L .64529 .50758 L F
.64523 .50769 m .64529 .50758 L .64301 .50404 L F
.788 .639 .697 r
.64086 .50923 m .64538 .50771 L .64193 .50709 L F
.64086 .50923 m .64452 .50978 L .64538 .50771 L F
.965 .868 .691 r
.64457 .50891 m .64343 .50886 L .64472 .50615 L F
.64452 .50978 m .64423 .50953 L .64457 .50891 L F
.64423 .50953 m .64343 .50886 L .64457 .50891 L F
.556 .334 .533 r
.64301 .50404 m .64439 .50674 L .64193 .50709 L F
.64 .367 .489 r
.64472 .50615 m .64301 .50404 L .64451 .50569 L F
.64472 .50615 m .64439 .50674 L .64301 .50404 L F
.728 .789 .901 r
.53966 .60616 m .53617 .60592 L .53806 .60474 L F
.794 .754 .816 r
.54221 .6034 m .53966 .60616 L .53806 .60474 L F
.966 .867 .689 r
.72769 .4967 m .72957 .49591 L .72851 .49484 L F
.72769 .4967 m .72893 .4979 L .72957 .49591 L F
.317 0 0 r
.49381 .81408 m .49471 .81465 L .49249 .81593 L F
.49381 .81408 m .49608 .81446 L .49471 .81465 L F
.572 .846 .996 r
.6855 .47278 m .68885 .47297 L .68654 .47365 L F
.577 .514 .748 r
.40002 .70705 m .40223 .70665 L .40152 .703 L F
.342 .199 .538 r
.40074 .70928 m .40223 .70665 L .40002 .70705 L F
.629 .414 .572 r
.59932 .59997 m .59709 .60236 L .59725 .6002 L F
.81 .53 .515 r
.47703 .76359 m .47527 .76539 L .47782 .76553 L F
.586 .426 .631 r
.47703 .76359 m .47782 .76553 L .4794 .76325 L F
.47703 .76359 m .47782 .76553 L .4794 .76325 L F
.176 0 .323 r
.57427 .69867 m .57558 .69947 L .57649 .698 L F
.57427 .69867 m .57383 .70063 L .57558 .69947 L F
.676 .487 .623 r
.5709 .61656 m .57041 .61889 L .56707 .61388 L F
.106 .484 .899 r
.50614 .64281 m .50773 .64272 L .50589 .64171 L F
.50614 .64281 m .50902 .64415 L .50773 .64272 L F
.595 .319 .469 r
.302 .64937 m .29897 .64882 L .30249 .64915 L F
.608 .439 .628 r
.46091 .6901 m .46332 .6898 L .46329 .68735 L F
.582 .343 .52 r
.46091 .6901 m .46092 .69218 L .46332 .6898 L F
.678 .712 .874 r
.70797 .50616 m .70416 .50417 L .70691 .50382 L F
.52 .603 .877 r
.70908 .50264 m .70797 .50616 L .70691 .50382 L F
.70908 .50264 m .71099 .50633 L .70797 .50616 L F
.977 .687 .402 r
.65634 .49298 m .6552 .49432 L .6557 .48892 L F
.65634 .49298 m .65647 .49546 L .6552 .49432 L F
.506 .215 .407 r
.52808 .69121 m .52546 .69479 L .52601 .69355 L F
.52808 .69121 m .52782 .69446 L .52546 .69479 L F
.523 .255 .451 r
.53109 .68955 m .53079 .69232 L .52808 .69121 L F
.584 .316 .476 r
.53079 .69232 m .52782 .69446 L .52808 .69121 L F
.512 .534 .816 r
.26038 .62168 m .26196 .62539 L .26372 .62475 L F
.412 .286 .598 r
.26196 .62539 m .26332 .62763 L .26372 .62475 L F
.26196 .62539 m .26215 .62804 L .26332 .62763 L F
.592 .527 .751 r
.51435 .65392 m .51506 .65644 L .51748 .65592 L F
.64 .499 .675 r
.51492 .65829 m .51748 .65592 L .51506 .65644 L F
.271 0 0 r
.55204 .76283 m .55434 .76233 L .55542 .76088 L F
0 0 .033 r
.55542 .76088 m .55698 .75952 L .55732 .7576 L F
.47 .261 .514 r
.55434 .76233 m .55698 .75952 L .55542 .76088 L F
0 0 0 r
.55941 .77667 m .55939 .77746 L .55936 .77881 L F
.745 .252 .063 r
.50726 .70158 m .50594 .70231 L .50387 .70018 L F
.446 0 0 r
.50911 .70258 m .50594 .70231 L .50726 .70158 L F
.469 .113 .278 r
.6358 .48394 m .63799 .48376 L .63839 .48228 L F
.495 .754 .987 r
.37036 .59356 m .36967 .59503 L .36829 .59353 L F
.37036 .59356 m .37172 .59476 L .36967 .59503 L F
.551 .378 .6 r
.41907 .67568 m .41668 .67862 L .41669 .67612 L F
0 0 0 r
.71484 .50293 m .71757 .50236 L .71803 .50214 L F
.823 .93 .553 r
.71803 .50214 m .71757 .50236 L .71765 .5022 L F
.825 .461 0 r
.7194 .50151 m .71893 .50102 L .71802 .49832 L F
.71962 .50201 m .71893 .50102 L .7194 .50151 L F
.823 .93 .553 r
.71803 .50214 m .71864 .50072 L .71893 .50102 L F
0 0 .515 r
.71802 .49832 m .71893 .50102 L .71938 .49903 L F
.823 .93 .553 r
.71864 .50072 m .71938 .49903 L .71893 .50102 L F
.71803 .50214 m .71765 .5022 L .71938 .49903 L F
.796 .739 .8 r
.71962 .50201 m .71841 .50208 L .71803 .50214 L F
.71841 .50208 m .71565 .50223 L .71803 .50214 L F
.929 .946 .783 r
.71962 .50201 m .71803 .50214 L .71893 .50102 L F
.998 .816 .53 r
.56768 .76556 m .56891 .76142 L .56779 .76258 L F
.962 .739 .555 r
.56779 .76258 m .56891 .76142 L .56907 .76157 L F
.56779 .76258 m .56907 .76157 L .56826 .7601 L F
.502 .311 .554 r
.39163 .67004 m .39386 .66732 L .39139 .66765 L F
.996 .761 .445 r
.66783 .49718 m .66868 .50086 L .66892 .4983 L F
.464 .4 .701 r
.39803 .65675 m .40016 .65868 L .40098 .65629 L F
.583 .313 .473 r
.40016 .65868 m .40264 .65816 L .40098 .65629 L F
.378 .681 .977 r
.30119 .6279 m .30048 .62916 L .29927 .62827 L F
.30119 .6279 m .30314 .62949 L .30048 .62916 L F
.775 .77 .848 r
.5436 .60216 m .54281 .5994 L .54419 .60085 L F
.5436 .60216 m .54029 .60198 L .54281 .5994 L F
.801 .699 .753 r
.5436 .60216 m .54221 .6034 L .54029 .60198 L F
.302 .727 .972 r
.34143 .58855 m .34172 .58925 L .34007 .58854 L F
.34143 .58855 m .34349 .58925 L .34172 .58925 L F
.473 .139 .318 r
.2599 .59385 m .26229 .59358 L .26323 .59127 L F
.253 0 .213 r
.26323 .59127 m .26407 .59284 L .26544 .59096 L F
.26323 .59127 m .26229 .59358 L .26407 .59284 L F
.348 .639 .962 r
.32745 .66633 m .32909 .66762 L .32684 .66757 L F
.32684 .66757 m .32909 .66762 L .32745 .66633 L F
.784 .605 .659 r
.58551 .6959 m .58566 .69846 L .58222 .69807 L F
.645 .498 .669 r
.58551 .6959 m .58796 .69558 L .58566 .69846 L F
.766 .258 0 r
.54397 .62998 m .5432 .63006 L .54127 .62761 L F
.396 .849 .779 r
.54506 .62918 m .54397 .62998 L .54689 .62806 L F
.54506 .62918 m .5432 .63006 L .54397 .62998 L F
.862 .913 .865 r
.67244 .53431 m .67348 .53522 L .67634 .53177 L F
.356 0 .191 r
.30878 .60502 m .30568 .60695 L .30727 .6051 L F
.483 0 0 r
.46893 .69003 m .47102 .69105 L .47244 .69053 L F
.515 0 0 r
.47333 .69153 m .47244 .69053 L .47102 .69105 L F
.47333 .69153 m .47471 .69213 L .47244 .69053 L F
.779 .786 .858 r
.68421 .53234 m .68161 .5346 L .68488 .53457 L F
.736 .762 .874 r
.68421 .53234 m .68488 .53457 L .68723 .53332 L F
.19 .319 .765 r
.42417 .67418 m .42475 .67539 L .42249 .67334 L F
0 .26 .766 r
.42228 .67314 m .42249 .67334 L .42369 .67415 L F
.42249 .67334 m .42475 .67539 L .42369 .67415 L F
.318 .396 .785 r
.42572 .67445 m .42475 .67539 L .4234 .67255 L F
.325 .407 .793 r
.42369 .67415 m .42475 .67539 L .42572 .67445 L F
.569 .457 .687 r
.4243 .67424 m .42426 .67454 L .42369 .67415 L F
.42426 .67454 m .42391 .67753 L .42369 .67415 L F
.42572 .67445 m .42549 .67483 L .4243 .67424 L F
.42549 .67483 m .42391 .67753 L .4243 .67424 L F
.19 .319 .765 r
.4234 .67255 m .42417 .67418 L .42228 .67314 L F
.42417 .67418 m .42249 .67334 L .42228 .67314 L F
0 .26 .766 r
.42228 .67314 m .42369 .67415 L .4217 .67561 L F
.332 .236 .593 r
.74105 .50884 m .74134 .51172 L .73915 .51267 L F
0 0 0 r
.74134 .51172 m .73935 .51514 L .73915 .51267 L F
.06 .578 .876 r
.37998 .59724 m .37889 .59749 L .37742 .59671 L F
.37998 .59724 m .38117 .59788 L .37889 .59749 L F
.967 .749 .312 r
.49296 .79486 m .4924 .79181 L .49315 .79353 L F
.557 .264 .426 r
.49189 .7962 m .49296 .79486 L .49487 .79626 L F
.574 .715 .938 r
.26531 .63995 m .26977 .64217 L .26725 .6402 L F
.165 .508 .912 r
.26977 .64217 m .27018 .64142 L .26725 .6402 L F
.777 .472 .472 r
.26977 .64217 m .27108 .64474 L .26719 .64394 L F
.26977 .64217 m .26939 .64334 L .27018 .64142 L F
.26977 .64217 m .26719 .64394 L .26939 .64334 L F
.464 .4 .701 r
.39803 .65675 m .39833 .65912 L .40016 .65868 L F
.477 .873 .697 r
.45912 .64215 m .46015 .64127 L .46138 .64179 L F
.45912 .64215 m .45725 .6431 L .46015 .64127 L F
.836 .81 .323 r
.55821 .58059 m .55781 .58087 L .55876 .57924 L F
.55821 .58059 m .55762 .58298 L .55781 .58087 L F
.284 .762 .929 r
.48014 .64691 m .47634 .64675 L .47818 .6475 L F
.668 .461 .595 r
.39586 .66156 m .39827 .66156 L .39833 .65912 L F
.586 .464 .68 r
.39827 .66156 m .40016 .65868 L .39833 .65912 L F
.462 0 0 r
.66551 .51149 m .66842 .51287 L .66761 .51267 L F
.548 0 0 r
.66761 .51267 m .66842 .51287 L .67086 .51466 L F
.338 0 0 r
.44041 .70434 m .43896 .70577 L .43673 .70592 L F
.406 0 0 r
.44274 .70434 m .43896 .70577 L .44041 .70434 L F
.645 .469 .63 r
.46329 .68735 m .46332 .6898 L .46552 .68931 L F
.416 .346 .671 r
.75306 .59066 m .75259 .59526 L .75553 .59293 L F
.569 .525 .766 r
.75399 .59692 m .75553 .59293 L .75259 .59526 L F
.329 .384 .767 r
.50502 .62962 m .50456 .63267 L .50277 .63037 L F
.50502 .62962 m .5068 .63325 L .50456 .63267 L F
.304 0 .111 r
.34203 .64065 m .34132 .63919 L .34334 .63878 L F
.34203 .64065 m .33993 .64121 L .34132 .63919 L F
.48 .817 .999 r
.58466 .71418 m .58588 .71509 L .58366 .71537 L F
.597 .456 .661 r
.58588 .71509 m .58404 .71769 L .58366 .71537 L F
0 0 0 r
.58366 .71537 m .5828 .71696 L .58466 .71418 L F
.958 .928 .726 r
.6404 .52006 m .64059 .52211 L .64083 .521 L F
.969 .924 .605 r
.64146 .51704 m .6404 .52006 L .64083 .521 L F
.609 .457 .651 r
.56678 .62066 m .56653 .62212 L .56459 .62133 L F
.667 .454 .586 r
.56653 .62212 m .56274 .62447 L .56459 .62133 L F
.697 .834 .949 r
.27824 .64269 m .28048 .64407 L .28143 .64259 L F
.533 .484 .747 r
.67044 .52065 m .67253 .52001 L .67172 .51792 L F
.586 .657 .886 r
.56417 .72537 m .56407 .72335 L .56176 .72376 L F
.607 .661 .877 r
.56417 .72537 m .56639 .72286 L .56407 .72335 L F
.56417 .72537 m .56773 .72564 L .56639 .72286 L F
.476 .882 .946 r
.64905 .51128 m .64882 .51073 L .64749 .51178 L F
0 0 0 r
.64882 .51073 m .64694 .51225 L .64749 .51178 L F
.834 .749 .77 r
.52217 .65495 m .52334 .65824 L .52411 .65649 L F
.52217 .65495 m .5204 .65852 L .52334 .65824 L F
.834 .75 .771 r
.5204 .65852 m .52137 .66116 L .52334 .65824 L F
.67 .206 0 r
.56078 .64501 m .5627 .64757 L .56308 .64787 L F
.94 .889 .484 r
.56308 .64787 m .56212 .64872 L .5627 .64757 L F
.67 .206 0 r
.56078 .64501 m .5627 .64757 L .56308 .64787 L F
.94 .889 .484 r
.56308 .64787 m .56212 .64872 L .5627 .64757 L F
.754 .68 .779 r
.74929 .58832 m .75381 .58881 L .7516 .5855 L F
.694 .622 .771 r
.74929 .58832 m .75306 .59066 L .75381 .58881 L F
.54 .599 .862 r
.7516 .5855 m .75381 .58881 L .75507 .58824 L F
.336 .119 .43 r
.75381 .58881 m .75306 .59066 L .75507 .58824 L F
.696 .764 .904 r
.55074 .75634 m .55195 .7578 L .55311 .75665 L F
.544 .846 .998 r
.40362 .71286 m .40699 .71295 L .40558 .7122 L F
.316 .693 .979 r
.40699 .71295 m .4079 .71201 L .40558 .7122 L F
.40699 .71295 m .40977 .71319 L .4079 .71201 L F
.153 .655 .909 r
.55921 .76573 m .55553 .76498 L .55663 .76612 L F
.263 .372 .787 r
.55663 .76612 m .55959 .76889 L .55921 .76573 L F
.332 0 0 r
.66815 .47484 m .67168 .47491 L .66921 .47538 L F
.663 .831 .964 r
.57917 .72538 m .58017 .72636 L .58219 .72569 L F
.522 .453 .72 r
.55541 .72128 m .55706 .71775 L .55485 .71813 L F
.55541 .72128 m .55785 .72093 L .55706 .71775 L F
.564 .458 .692 r
.5559 .724 m .55785 .72093 L .55541 .72128 L F
.897 .78 .724 r
.59185 .7266 m .59299 .72359 L .59093 .72375 L F
.424 0 .031 r
.27574 .58784 m .27812 .58768 L .27964 .5863 L F
.343 0 .002 r
.27812 .58768 m .28175 .58597 L .27964 .5863 L F
.94 .823 .702 r
.72789 .51279 m .72818 .50817 L .72631 .51183 L F
.929 .732 .616 r
.72631 .51183 m .72754 .51518 L .72789 .51279 L F
.885 .511 .04 r
.73525 .49576 m .73505 .49676 L .7345 .4946 L F
.73525 .49576 m .73597 .49786 L .73505 .49676 L F
.54 .599 .862 r
.7516 .5855 m .75507 .58824 L .75494 .58589 L F
.387 .169 .456 r
.36363 .62246 m .36347 .62512 L .3614 .62508 L F
.314 0 .197 r
.36253 .6265 m .3614 .62508 L .36347 .62512 L F
.36253 .6265 m .36049 .6271 L .3614 .62508 L F
.555 .561 .816 r
.54126 .65858 m .53945 .65948 L .53788 .65682 L F
.54126 .65858 m .53945 .65948 L .53788 .65682 L F
.274 .415 .823 r
.53816 .65667 m .53945 .65948 L .53788 .65682 L F
.528 .047 .057 r
.47959 .69648 m .47829 .69778 L .4759 .6975 L F
.465 0 .014 r
.48171 .69734 m .47829 .69778 L .47959 .69648 L F
.787 .294 .029 r
.55205 .61978 m .55258 .62133 L .54993 .61885 L F
.55205 .61978 m .55345 .62167 L .55258 .62133 L F
.785 .773 .842 r
.7827 .596 m .78408 .5974 L .78671 .59494 L F
.34 0 0 r
.44609 .7032 m .44496 .70416 L .44274 .70434 L F
.23 0 0 r
.4482 .70289 m .44496 .70416 L .44609 .7032 L F
.699 .635 .781 r
.65845 .52063 m .66193 .52146 L .66055 .51787 L F
0 0 .524 r
.54769 .62651 m .54632 .6255 L .54713 .6242 L F
.54769 .62651 m .54689 .62806 L .54632 .6255 L F
.841 .87 .864 r
.63534 .53983 m .63912 .53831 L .63758 .53703 L F
.81 .484 .438 r
.70703 .51502 m .71014 .5154 L .70885 .51521 L F
.798 .753 .811 r
.70885 .51521 m .71014 .5154 L .71238 .51311 L F
.801 .689 .741 r
.73692 .51806 m .7404 .51851 L .73935 .51514 L F
.385 .118 .381 r
.57138 .70336 m .57383 .70063 L .57178 .70129 L F
.629 .353 .481 r
.57551 .61514 m .57318 .61422 L .57533 .61365 L F
.57551 .61514 m .57302 .61621 L .57318 .61422 L F
0 0 .151 r
.50209 .76841 m .50213 .76568 L .50367 .76604 L F
.735 .501 .574 r
.50367 .76604 m .50383 .76903 L .50209 .76841 L F
.479 .306 .567 r
.50607 .76819 m .50383 .76903 L .50367 .76604 L F
.97 .917 .695 r
.70037 .52909 m .70138 .52697 L .69969 .52801 L F
.872 .895 .847 r
.70038 .52587 m .70138 .52697 L .70366 .52419 L F
.979 .849 .643 r
.69969 .52801 m .70138 .52697 L .70038 .52587 L F
.477 .174 .372 r
.61017 .54088 m .60981 .54257 L .60734 .543 L F
0 0 .183 r
.61182 .53845 m .61017 .54088 L .61193 .53765 L F
.532 .345 .573 r
.61182 .53845 m .60981 .54257 L .61017 .54088 L F
.515 .095 .182 r
.46563 .69832 m .46434 .7002 L .46223 .70016 L F
.588 .201 .277 r
.46797 .69836 m .46434 .7002 L .46563 .69832 L F
.989 .753 .487 r
.66469 .48837 m .66578 .48947 L .66591 .48729 L F
.622 .121 .04 r
.24443 .66096 m .24756 .66131 L .24593 .66029 L F
.167 .473 .894 r
.42181 .69371 m .4203 .69407 L .4192 .69244 L F
.42181 .69371 m .42274 .69519 L .4203 .69407 L F
.579 .184 .258 r
.39484 .69638 m .3935 .69789 L .39161 .69673 L F
.598 .472 .68 r
.39484 .69638 m .39583 .6953 L .3935 .69789 L F
.39484 .69638 m .39708 .69548 L .39583 .6953 L F
.39484 .69638 m .39719 .6983 L .39708 .69548 L F
.575 .186 .267 r
.54069 .7531 m .54356 .75401 L .54486 .75221 L F
.129 .392 .845 r
.54808 .75531 m .54486 .75221 L .54657 .7533 L F
.649 .271 .316 r
.54486 .75221 m .54356 .75401 L .54657 .7533 L F
.157 0 .155 r
.6106 .59682 m .60992 .59896 L .60813 .60003 L F
.4 .156 .425 r
.61408 .59458 m .61237 .59637 L .6106 .59682 L F
.309 0 .215 r
.61202 .59822 m .6106 .59682 L .61237 .59637 L F
.61202 .59822 m .60992 .59896 L .6106 .59682 L F
.723 .566 .677 r
.48735 .77187 m .49173 .77453 L .48969 .77142 L F
.48735 .77187 m .48784 .77451 L .49173 .77453 L F
.523 .188 .342 r
.52245 .78803 m .52639 .78536 L .52232 .7856 L F
.52245 .78803 m .52467 .7878 L .52639 .78536 L F
.728 .437 .486 r
.52467 .7878 m .52807 .78846 L .52639 .78536 L F
.629 .414 .572 r
.59932 .59997 m .59941 .60237 L .59709 .60236 L F
.656 .443 .583 r
.59932 .59997 m .60257 .60209 L .59941 .60237 L F
.59932 .59997 m .6027 .59996 L .60257 .60209 L F
.989 .789 .543 r
.65753 .49872 m .6561 .49997 L .65586 .49771 L F
.65753 .49872 m .65728 .50112 L .6561 .49997 L F
.21 .426 .853 r
.51052 .64751 m .5114 .64621 L .50902 .64415 L F
.51052 .64751 m .51177 .64757 L .5114 .64621 L F
.423 .464 .798 r
.51052 .64751 m .51331 .65053 L .51177 .64757 L F
.857 .803 .796 r
.69538 .52058 m .69373 .52303 L .69309 .5203 L F
.587 .331 .496 r
.5859 .60583 m .58577 .60794 L .58334 .60813 L F
.577 .318 .487 r
.5859 .60583 m .58835 .6078 L .58577 .60794 L F
.5859 .60583 m .58919 .60485 L .58835 .6078 L F
.997 .771 .459 r
.57664 .55603 m .57685 .55379 L .57778 .55484 L F
0 0 .156 r
.57917 .55374 m .57778 .55484 L .57685 .55379 L F
.281 .678 .972 r
.3519 .58977 m .35118 .59054 L .34977 .58982 L F
.3519 .58977 m .3533 .59072 L .35118 .59054 L F
0 .297 .76 r
.67251 .5104 m .6743 .51213 L .67078 .50991 L F
.537 .341 .563 r
.24614 .65571 m .24317 .65287 L .24469 .6547 L F
.113 .065 .52 r
.26213 .65076 m .26306 .65041 L .26061 .65069 L F
.816 .472 .407 r
.26213 .65076 m .26444 .65364 L .26197 .65344 L F
.113 .065 .52 r
.26213 .65076 m .26307 .65245 L .26306 .65041 L F
.26213 .65076 m .26197 .65344 L .26307 .65245 L F
.519 .428 .692 r
.58222 .69807 m .58282 .70113 L .58036 .70096 L F
0 0 0 r
.58282 .70113 m .58102 .70442 L .58036 .70096 L F
.62158 .58233 m .62085 .58429 L .6199 .58585 L F
.62085 .58429 m .61966 .58767 L .6199 .58585 L F
.953 .712 .255 r
.73464 .50419 m .73415 .50582 L .73394 .50304 L F
.73464 .50419 m .73475 .5066 L .73415 .50582 L F
.775 .524 .556 r
.38241 .70833 m .38499 .70693 L .38314 .70923 L F
.516 .326 .562 r
.38499 .70693 m .38515 .70962 L .38281 .70965 L F
.775 .524 .556 r
.3813 .70893 m .38241 .70833 L .38281 .70965 L F
.38241 .70833 m .38314 .70923 L .38281 .70965 L F
.3813 .70893 m .38515 .70962 L .38499 .70693 L F
.792 .779 .841 r
.38429 .70801 m .38189 .7077 L .38174 .7066 L F
.38189 .7077 m .38006 .70746 L .38122 .70687 L F
.38189 .7077 m .38122 .70687 L .38174 .7066 L F
.38429 .70801 m .3813 .70893 L .38006 .70746 L F
0 .45 .815 r
.38314 .70704 m .38429 .70801 L .38367 .70767 L F
.38314 .70704 m .38367 .70767 L .38174 .7066 L F
.657 .904 .981 r
.38174 .7066 m .38027 .70735 L .38007 .70674 L F
.385 0 0 r
.38314 .70704 m .38174 .7066 L .37962 .7065 L F
.38314 .70704 m .38001 .70656 L .38316 .70607 L F
.38001 .70656 m .37962 .7065 L .37998 .70646 L F
.38001 .70656 m .37998 .70646 L .38316 .70607 L F
.657 .904 .981 r
.38007 .70674 m .38006 .70746 L .37814 .70689 L F
.38027 .70735 m .38006 .70746 L .38007 .70674 L F
.851 .987 .712 r
.38283 .70668 m .38314 .70704 L .38316 .70607 L F
.604 .06 0 r
.37791 .70819 m .3813 .70893 L .37953 .70931 L F
.323 .806 .774 r
.37953 .70931 m .3813 .70893 L .38276 .70848 L F
.37953 .70931 m .38276 .70848 L .38429 .70801 L F
.276 .722 .961 r
.38281 .70965 m .38362 .70964 L .3813 .70893 L F
.323 .806 .774 r
.37953 .70931 m .38295 .70838 L .38153 .70914 L F
.38295 .70838 m .38429 .70801 L .38367 .70827 L F
.38295 .70838 m .38367 .70827 L .38153 .70914 L F
.697 .756 .898 r
.38006 .70746 m .38108 .70867 L .37791 .70819 L F
.38108 .70867 m .3813 .70893 L .38051 .70876 L F
.38108 .70867 m .38051 .70876 L .37791 .70819 L F
.851 .987 .712 r
.38153 .70914 m .38314 .70704 L .38283 .70668 L F
.904 .984 .773 r
.38225 .7082 m .38429 .70801 L .38314 .70704 L F
.38153 .70914 m .38269 .70866 L .38225 .7082 L F
.38269 .70866 m .38429 .70801 L .38225 .7082 L F
.276 .722 .961 r
.38362 .70964 m .38515 .70962 L .38329 .70929 L F
.38362 .70964 m .38329 .70929 L .3813 .70893 L F
.95 .952 .657 r
.56614 .77238 m .56733 .76872 L .56652 .77141 L F
.613 .61 .824 r
.53077 .65024 m .52856 .65099 L .52728 .64838 L F
.339 0 0 r
.52928 .65206 m .52735 .65221 L .52856 .65099 L F
.736 .531 .614 r
.48841 .77686 m .49173 .77453 L .48784 .77451 L F
.787 .55 0 r
.49207 .7769 m .49214 .77793 L .49173 .77453 L F
.632 .542 .735 r
.57217 .71769 m .56917 .71495 L .57124 .71428 L F
.515 .313 .544 r
.57942 .69582 m .5818 .69564 L .58179 .69286 L F
0 0 .364 r
.58179 .69286 m .5818 .69564 L .5827 .69444 L F
.343 .793 .952 r
.49844 .81416 m .49912 .81334 L .49814 .8142 L F
.09 .646 .703 r
.49608 .81446 m .4986 .81415 L .49844 .81416 L F
.191 0 0 r
.49608 .81446 m .49844 .81416 L .49698 .81522 L F
.343 .793 .952 r
.49844 .81416 m .49814 .8142 L .49698 .81522 L F
.09 .646 .703 r
.4986 .81415 m .49957 .81402 L .49844 .81416 L F
.435 0 .014 r
.42786 .65236 m .43019 .65238 L .43168 .65095 L F
.402 0 .08 r
.43019 .65238 m .43384 .65045 L .43168 .65095 L F
.714 .684 .82 r
.53558 .79686 m .53757 .79962 L .53425 .79917 L F
.743 .588 .682 r
.53757 .79962 m .53564 .80423 L .53425 .79917 L F
.506 .897 .744 r
.53786 .80305 m .53564 .80423 L .53757 .79962 L F
.05 .61 .801 r
.53782 .79947 m .53757 .79962 L .53558 .79686 L F
.801 .419 .332 r
.53546 .79909 m .53782 .79947 L .53558 .79686 L F
.646 .849 .978 r
.53724 .79811 m .53782 .79947 L .53546 .79909 L F
.732 .406 0 r
.53769 .79934 m .53782 .79947 L .53724 .79811 L F
.05 .61 .801 r
.53782 .79947 m .53798 .79964 L .53757 .79962 L F
.502 .355 .614 r
.5399 .80225 m .53757 .79962 L .53974 .79972 L F
.732 .406 0 r
.53841 .80131 m .53782 .79947 L .53769 .79934 L F
.05 .61 .801 r
.53782 .79947 m .53974 .79972 L .53798 .79964 L F
.502 .355 .614 r
.5399 .80225 m .53786 .80305 L .53757 .79962 L F
.886 .64 .562 r
.53578 .6195 m .53313 .6188 L .53353 .6167 L F
0 .001 .573 r
.53465 .62147 m .53313 .6188 L .53578 .6195 L F
.668 .723 .891 r
.68997 .53214 m .69063 .53446 L .69246 .53376 L F
.606 .854 .495 r
.50507 .80732 m .50433 .80841 L .50654 .80563 L F
0 .197 .711 r
.50617 .81005 m .50433 .80841 L .50507 .80732 L F
.649 .901 .983 r
.67948 .47399 m .68318 .47362 L .68044 .47474 L F
.952 .649 .424 r
.71693 .47915 m .71671 .48085 L .71539 .48037 L F
.67 .49 .634 r
.71898 .47793 m .71671 .48085 L .71693 .47915 L F
.949 .596 .289 r
.58958 .69789 m .59141 .70085 L .5907 .69892 L F
.392 .253 .57 r
.38256 .69607 m .38287 .69691 L .38452 .69769 L F
.667 .841 .967 r
.38472 .69459 m .38256 .69607 L .3811 .69479 L F
0 .086 .562 r
.3811 .69479 m .38256 .69607 L .38452 .69769 L F
.924 .974 .716 r
.55166 .78971 m .55061 .7925 L .54988 .79124 L F
.716 .381 0 r
.58586 .70324 m .58736 .70698 L .58668 .70548 L F
.644 .131 .009 r
.58736 .70698 m .58859 .70799 L .5857 .70815 L F
.718 .413 .461 r
.59043 .70685 m .58859 .70799 L .58736 .70698 L F
.813 .671 .706 r
.4865 .79935 m .4903 .79751 L .48866 .79773 L F
.775 .952 .931 r
.48866 .79773 m .4903 .79751 L .49189 .7962 L F
.502 .908 .826 r
.5604 .70883 m .56395 .7075 L .56189 .70667 L F
.42 .16 .411 r
.43724 .66666 m .43509 .66724 L .43744 .66487 L F
.467 .198 .422 r
.43958 .66614 m .43724 .66666 L .43744 .66487 L F
.928 .702 .576 r
.72769 .4967 m .72926 .49889 L .72893 .4979 L F
.683 .436 .542 r
.57649 .698 m .57974 .6983 L .57942 .69582 L F
.699 .447 .54 r
.58222 .69807 m .57942 .69582 L .5818 .69564 L F
.58222 .69807 m .57974 .6983 L .57942 .69582 L F
.58222 .69807 m .57974 .6983 L .57942 .69582 L F
.566 .381 .59 r
.50185 .7886 m .50373 .78515 L .50194 .78524 L F
.139 .684 .793 r
.34267 .60043 m .34426 .6005 L .34619 .60032 L F
.57 .34 .528 r
.57864 .61059 m .57861 .61323 L .57533 .61365 L F
.576 .357 .545 r
.58089 .6105 m .57861 .61323 L .57864 .61059 L F
.331 .725 .982 r
.33273 .60082 m .33372 .60164 L .33513 .60152 L F
.469 .291 .556 r
.38654 .70805 m .38499 .70693 L .38884 .70676 L F
.723 .989 .833 r
.38974 .70552 m .38654 .70805 L .38884 .70676 L F
.755 .849 .921 r
.69945 .50858 m .69613 .50868 L .69881 .50619 L F
.804 .818 .863 r
.70175 .50624 m .69945 .50858 L .69881 .50619 L F
.929 .807 .704 r
.73371 .51318 m .73347 .51631 L .73128 .51464 L F
.697 .222 0 r
.73344 .51725 m .73128 .51464 L .73347 .51631 L F
.345 .666 .974 r
.32105 .58721 m .31753 .58595 L .31937 .58601 L F
.412 .762 .995 r
.32193 .58622 m .32105 .58721 L .31937 .58601 L F
.32193 .58622 m .32348 .58709 L .32105 .58721 L F
.958 .928 .726 r
.6404 .52006 m .63937 .52164 L .64059 .52211 L F
.936 .919 .771 r
.63937 .52164 m .63842 .52606 L .64059 .52211 L F
0 0 0 r
.58282 .70113 m .58179 .70306 L .58102 .70442 L F
.436 .349 .659 r
.58179 .70306 m .58118 .70656 L .58102 .70442 L F
.59 .51 .733 r
.40074 .70928 m .40187 .71345 L .40362 .71286 L F
.289 .783 .748 r
.31205 .64899 m .31071 .64953 L .31229 .64929 L F
.31205 .64899 m .31001 .64968 L .31071 .64953 L F
.033 .34 .82 r
.55609 .75576 m .55732 .7576 L .55705 .75564 L F
.845 .709 .179 r
.55732 .7576 m .55698 .75952 L .55705 .75564 L F
.627 .239 .288 r
.52494 .77995 m .52745 .78052 L .52629 .7813 L F
.975 .672 .302 r
.52629 .7813 m .52511 .77923 L .52494 .77995 L F
.314 .334 .722 r
.39161 .69673 m .3935 .69789 L .39297 .6957 L F
.593 .147 .161 r
.39161 .69673 m .3935 .69789 L .39058 .69781 L F
.933 .81 .7 r
.62143 .54807 m .62108 .54516 L .62171 .54632 L F
.569 .217 .331 r
.26759 .59043 m .26999 .59046 L .27137 .58807 L F
.349 0 .113 r
.26999 .59046 m .27352 .5881 L .27137 .58807 L F
.609 .342 .488 r
.6017 .58794 m .59925 .58592 L .59915 .58791 L F
.6017 .58794 m .60214 .58589 L .59925 .58592 L F
.641 .08 0 r
.54929 .63861 m .54795 .63823 L .5456 .63635 L F
.201 .33 .772 r
.5456 .63635 m .54795 .63823 L .54678 .63501 L F
.961 .744 .565 r
.5468 .63731 m .54618 .63568 L .54678 .63501 L F
.54618 .63568 m .54558 .63412 L .54678 .63501 L F
.533 .817 .471 r
.54804 .63359 m .54678 .63501 L .54854 .63302 L F
.5456 .63635 m .54678 .63501 L .54804 .63359 L F
.722 .91 .548 r
.54854 .63302 m .5488 .63202 L .54986 .63321 L F
.54854 .63302 m .54678 .63501 L .5488 .63202 L F
.998 .816 .53 r
.56768 .76556 m .5687 .7663 L .56891 .76142 L F
.935 .774 .657 r
.7272 .50563 m .72906 .50438 L .728 .50347 L F
.7272 .50563 m .72847 .50663 L .72906 .50438 L F
.674 .21 .144 r
.42833 .67192 m .42639 .67047 L .4293 .66997 L F
.42833 .67192 m .42571 .67195 L .42639 .67047 L F
.524 .169 .308 r
.52807 .78846 m .5304 .78842 L .53147 .78595 L F
.621 .269 .353 r
.5304 .78842 m .53383 .78774 L .53147 .78595 L F
.755 .469 .499 r
.50251 .79949 m .50297 .79634 L .50153 .79845 L F
.315 .678 .977 r
.53662 .65538 m .5355 .65626 L .53426 .65542 L F
.53662 .65538 m .53816 .65667 L .5355 .65626 L F
.53662 .65538 m .5355 .65626 L .53426 .65542 L F
.53662 .65538 m .53816 .65667 L .5355 .65626 L F
.545 .551 .812 r
.51435 .65392 m .51564 .65028 L .51331 .65053 L F
.51435 .65392 m .51667 .65368 L .51564 .65028 L F
.592 .527 .751 r
.51435 .65392 m .51748 .65592 L .51667 .65368 L F
.793 .695 .756 r
.26061 .65069 m .25857 .65312 L .26197 .65344 L F
.796 .683 .74 r
.25857 .65312 m .25929 .65598 L .26197 .65344 L F
.472 .675 .953 r
.26197 .65344 m .26444 .65364 L .26307 .65245 L F
.936 .62 .167 r
.56741 .75576 m .5675 .75663 L .56832 .75762 L F
.998 .777 .442 r
.56726 .75945 m .56832 .75762 L .5675 .75663 L F
.56726 .75945 m .56826 .7601 L .56832 .75762 L F
.734 .691 .809 r
.55158 .79071 m .55383 .79192 L .55474 .78999 L F
.791 .991 .753 r
.54912 .74496 m .54808 .74618 L .54861 .74652 L F
0 .516 .798 r
.54898 .74676 m .54861 .74652 L .54616 .74601 L F
.973 .663 .351 r
.5447 .74294 m .54548 .74458 L .54476 .74508 L F
.54548 .74458 m .54616 .74601 L .54476 .74508 L F
.786 .368 .257 r
.54861 .74652 m .54476 .74508 L .54616 .74601 L F
.54861 .74652 m .54831 .74669 L .54476 .74508 L F
.54831 .74669 m .54698 .74745 L .54567 .74605 L F
.54831 .74669 m .54567 .74605 L .54476 .74508 L F
.11 .294 .769 r
.54476 .74508 m .54698 .74745 L .54607 .74494 L F
.54476 .74508 m .54607 .74494 L .54601 .74478 L F
.54476 .74508 m .54601 .74478 L .54417 .7455 L F
.54476 .74508 m .54417 .7455 L .54377 .74565 L F
0 .367 .749 r
.54322 .74233 m .5447 .74294 L .54348 .7422 L F
.937 .685 .531 r
.54476 .74508 m .54348 .7422 L .5447 .74294 L F
.54476 .74508 m .54377 .74565 L .54348 .7422 L F
.592 .815 .985 r
.5438 .7456 m .54601 .74478 L .54472 .74372 L F
.54377 .74565 m .54387 .74561 L .5438 .7456 L F
.54387 .74561 m .54601 .74478 L .5438 .7456 L F
.791 .991 .753 r
.54808 .74618 m .54698 .74745 L .54861 .74652 L F
0 .516 .798 r
.54928 .74684 m .54861 .74652 L .54898 .74676 L F
.299 .401 .799 r
.54928 .74684 m .55045 .74528 L .54861 .74652 L F
.54928 .74684 m .55192 .7486 L .55045 .74528 L F
.71 .697 .836 r
.51817 .65911 m .52137 .66116 L .5204 .65852 L F
.762 .756 .847 r
.74221 .4871 m .73883 .48674 L .74125 .48464 L F
.419 .452 .789 r
.74312 .4836 m .74221 .4871 L .74125 .48464 L F
.74312 .4836 m .74396 .48691 L .74221 .4871 L F
.176 0 .248 r
.58669 .54541 m .58731 .54363 L .58499 .54654 L F
.119 0 .144 r
.58669 .54541 m .58913 .54285 L .58731 .54363 L F
.935 .745 .621 r
.58285 .57957 m .58298 .57743 L .58135 .57605 L F
.926 .769 .29 r
.72926 .48827 m .72962 .4885 L .72972 .48708 L F
.148 0 0 r
.42103 .71041 m .4216 .71099 L .41906 .7108 L F
.42103 .71041 m .42323 .7102 L .4216 .71099 L F
0 0 .075 r
.74766 .50242 m .74596 .50415 L .74754 .50114 L F
.283 .138 .501 r
.74782 .50529 m .74596 .50415 L .74766 .50242 L F
.74782 .50529 m .74597 .50642 L .74596 .50415 L F
0 0 0 r
.61483 .56329 m .61636 .5619 L .61761 .5607 L F
0 0 .276 r
.61483 .56329 m .61564 .56409 L .61636 .5619 L F
.61483 .56329 m .6148 .56563 L .61564 .56409 L F
.798 .753 .811 r
.70885 .51521 m .71238 .51311 L .71146 .51199 L F
.38 .55 .897 r
.71238 .51311 m .7137 .51141 L .71146 .51199 L F
.71238 .51311 m .71537 .51412 L .7137 .51141 L F
.459 .43 .739 r
.35125 .60563 m .3523 .60184 L .3504 .60222 L F
.35125 .60563 m .35306 .6054 L .3523 .60184 L F
.506 .449 .727 r
.35125 .60563 m .35387 .6077 L .35306 .6054 L F
.35125 .60563 m .35197 .60837 L .35387 .6077 L F
.329 0 .115 r
.57977 .55134 m .5826 .54925 L .57949 .55154 L F
.268 .179 .566 r
.49951 .78843 m .49885 .79081 L .50153 .79014 L F
.226 .122 .521 r
.49885 .79081 m .50096 .79358 L .50153 .79014 L F
.49885 .79081 m .50004 .79294 L .50096 .79358 L F
.914 .953 .805 r
.61968 .55767 m .61761 .5607 L .61695 .55958 L F
.991 .878 .551 r
.61761 .5607 m .61636 .5619 L .61695 .55958 L F
.123 0 .137 r
.61489 .53473 m .61358 .53698 L .61193 .53765 L F
.377 .195 .503 r
.61358 .53698 m .61182 .53845 L .61193 .53765 L F
.725 .726 .851 r
.56773 .72564 m .57064 .72581 L .56972 .72503 L F
.49 .814 1 r
.57064 .72581 m .57227 .72465 L .56972 .72503 L F
.57064 .72581 m .57346 .72515 L .57227 .72465 L F
.058 0 0 r
.32507 .64737 m .3242 .64783 L .32195 .64824 L F
0 0 0 r
.3272 .64663 m .32626 .64715 L .32507 .64737 L F
.32507 .64737 m .32626 .64715 L .3242 .64783 L F
.648 .7 .884 r
.51477 .76669 m .51606 .76944 L .51751 .76755 L F
.424 .381 .706 r
.51606 .76944 m .51828 .77107 L .51751 .76755 L F
.661 .668 .846 r
.57568 .71891 m .57217 .71769 L .57441 .717 L F
.627 .681 .881 r
.57783 .71832 m .57568 .71891 L .57441 .717 L F
0 0 0 r
.58499 .54654 m .5826 .54925 L .58403 .54808 L F
.168 0 .168 r
.58403 .54808 m .58669 .54541 L .58499 .54654 L F
.38 0 .041 r
.43769 .69748 m .43998 .69727 L .44138 .69559 L F
.434 0 .063 r
.43998 .69727 m .44368 .69558 L .44138 .69559 L F
.402 .566 .901 r
.51162 .6362 m .51034 .63752 L .50987 .63672 L F
.51162 .6362 m .51354 .63869 L .51034 .63752 L F
.329 0 .115 r
.57977 .55134 m .58185 .55104 L .5826 .54925 L F
.169 0 .159 r
.58185 .55104 m .58403 .54808 L .5826 .54925 L F
.428 .13 .355 r
.54004 .78635 m .54247 .78555 L .5439 .78283 L F
.362 .062 .316 r
.5439 .78283 m .54433 .78468 L .545 .78364 L F
.5439 .78283 m .54247 .78555 L .54433 .78468 L F
0 .378 .791 r
.63889 .51064 m .6401 .51136 L .64111 .51172 L F
.6401 .51136 m .64315 .51316 L .64111 .51172 L F
.986 .718 .351 r
.64086 .50923 m .64181 .51197 L .64111 .51172 L F
.64181 .51197 m .64202 .51257 L .64111 .51172 L F
.64086 .50923 m .64202 .51257 L .64111 .51172 L F
.401 .154 .421 r
.53315 .69013 m .53109 .68955 L .53263 .68901 L F
.53342 .68918 m .53263 .68901 L .53356 .68869 L F
.53315 .69013 m .53263 .68901 L .53342 .68918 L F
.565 .423 .647 r
.53463 .68897 m .53388 .689 L .53356 .68869 L F
.033 .167 .673 r
.53286 .68626 m .53463 .68897 L .53356 .68869 L F
.168 .227 .68 r
.53366 .689 m .53463 .68897 L .53286 .68626 L F
.53372 .68924 m .53463 .68897 L .53366 .689 L F
.565 .423 .647 r
.53463 .68897 m .53432 .68942 L .53388 .689 L F
.53432 .68942 m .53269 .69174 L .53342 .68918 L F
.194 0 0 r
.53357 .68922 m .53359 .68923 L .53368 .68924 L F
.53367 .68923 m .53368 .68924 L .53372 .68924 L F
.798 .621 .661 r
.53367 .68923 m .53372 .68924 L .5337 .68917 L F
.475 0 0 r
.53359 .68923 m .53463 .68897 L .53372 .68924 L F
.565 .423 .647 r
.53401 .68912 m .53342 .68918 L .53356 .68869 L F
.53359 .68923 m .53356 .68922 L .53401 .68912 L F
.53356 .68922 m .53342 .68918 L .53358 .68916 L F
.53356 .68922 m .53358 .68916 L .53401 .68912 L F
.798 .621 .661 r
.53367 .68923 m .5337 .68917 L .53366 .689 L F
.53362 .68908 m .53366 .689 L .53286 .68626 L F
.53367 .68923 m .53366 .689 L .53362 .68908 L F
.194 0 0 r
.52886 .68854 m .53359 .68923 L .53357 .68922 L F
.52886 .68854 m .53368 .68924 L .53367 .68923 L F
.798 .621 .661 r
.52886 .68854 m .53367 .68923 L .53286 .68626 L F
.475 0 0 r
.5312 .68895 m .53463 .68897 L .53359 .68923 L F
.565 .423 .647 r
.53432 .68942 m .53359 .68923 L .53401 .68912 L F
.194 0 0 r
.52886 .68854 m .5312 .68895 L .53359 .68923 L F
.401 .154 .421 r
.53269 .69174 m .53243 .69138 L .53315 .69013 L F
.53243 .69138 m .53109 .68955 L .53315 .69013 L F
.53269 .69174 m .53079 .69232 L .53109 .68955 L F
.467 .241 .486 r
.35197 .60837 m .35369 .61007 L .35387 .6077 L F
.35197 .60837 m .3516 .61063 L .35369 .61007 L F
.909 .877 .792 r
.55008 .59081 m .55325 .58869 L .55124 .5917 L F
.55008 .59081 m .55198 .58779 L .55325 .58869 L F
.854 .892 .863 r
.55325 .58869 m .55441 .58523 L .55543 .58589 L F
.55325 .58869 m .55198 .58779 L .55441 .58523 L F
.822 .974 .67 r
.55876 .57924 m .56085 .57628 L .56131 .57635 L F
.694 .622 .771 r
.74929 .58832 m .75046 .59186 L .75306 .59066 L F
.538 .924 .828 r
.41407 .71058 m .41233 .71178 L .41443 .71085 L F
.41407 .71058 m .41147 .71191 L .41233 .71178 L F
.805 .826 .867 r
.72185 .51757 m .72493 .51712 L .72438 .51505 L F
.764 .777 .863 r
.72493 .51712 m .72611 .51415 L .72438 .51505 L F
.72493 .51712 m .72754 .51518 L .72611 .51415 L F
.475 .263 .511 r
.29199 .62279 m .2903 .62181 L .29158 .62009 L F
.29199 .62279 m .29006 .62257 L .2903 .62181 L F
.367 0 .074 r
.43724 .66666 m .43375 .6687 L .43509 .66724 L F
.044 .567 .867 r
.52315 .77472 m .52202 .77419 L .51977 .77371 L F
0 0 .375 r
.52315 .77472 m .52405 .77674 L .52406 .77626 L F
.52315 .77472 m .52406 .77626 L .52202 .77419 L F
.709 .249 .158 r
.48384 .69283 m .48647 .6949 L .48778 .69374 L F
.118 0 0 r
.48647 .6949 m .49059 .69402 L .48778 .69374 L F
.158 .045 .464 r
.61343 .50631 m .61219 .50977 L .61385 .50855 L F
.324 .334 .716 r
.61219 .50977 m .61446 .51151 L .61385 .50855 L F
.524 .314 .538 r
.61205 .51202 m .61446 .51151 L .61219 .50977 L F
.342 .199 .538 r
.40074 .70928 m .4022 .70907 L .40223 .70665 L F
.59 .51 .733 r
.40074 .70928 m .40362 .71286 L .4022 .70907 L F
.24 0 0 r
.3256 .6321 m .32929 .62977 L .32743 .63088 L F
.749 .936 .947 r
.56383 .77508 m .56679 .77439 L .56605 .77389 L F
.996 .82 .46 r
.56605 .77389 m .56679 .77439 L .56652 .77141 L F
.469 .291 .556 r
.38499 .70693 m .38654 .70805 L .38516 .70532 L F
.38499 .70693 m .38515 .70962 L .38654 .70805 L F
.38654 .70805 m .38515 .70962 L .38499 .70693 L F
.701 .732 .875 r
.66162 .50945 m .66458 .50991 L .66423 .50827 L F
.761 .508 .552 r
.66162 .50945 m .66551 .51149 L .66458 .50991 L F
.547 .627 .883 r
.66423 .50827 m .66458 .50991 L .66614 .50812 L F
.464 .449 .757 r
.66551 .51149 m .66614 .50812 L .66458 .50991 L F
.953 .65 .422 r
.55707 .78534 m .5586 .78584 L .55682 .78273 L F
.735 .369 .359 r
.5565 .78684 m .5586 .78584 L .55707 .78534 L F
.998 .82 .535 r
.55821 .78882 m .5586 .78584 L .56036 .7881 L F
.735 .369 .359 r
.5565 .78684 m .56036 .7881 L .5586 .78584 L F
.799 .793 .847 r
.65769 .5179 m .65845 .52063 L .66055 .51787 L F
.794 .754 .816 r
.54221 .6034 m .53806 .60474 L .54029 .60198 L F
.615 .305 .422 r
.48988 .79085 m .49147 .78829 L .48804 .78912 L F
.835 .584 .559 r
.48988 .79085 m .4924 .79181 L .49147 .78829 L F
.636 .763 .94 r
.49351 .62769 m .49128 .62843 L .48999 .62703 L F
0 .367 .805 r
.67096 .50492 m .67203 .50594 L .66939 .50461 L F
.429 .214 .484 r
.36831 .61917 m .36571 .62181 L .36597 .61958 L F
.89 .82 .772 r
.50046 .79643 m .50297 .79634 L .50385 .79436 L F
.889 .821 .774 r
.50153 .79845 m .50297 .79634 L .50046 .79643 L F
.771 .802 .878 r
.6618 .51188 m .66295 .51319 L .66551 .51149 L F
.761 .508 .552 r
.66162 .50945 m .6618 .51188 L .6623 .51182 L F
.66314 .51025 m .6623 .51182 L .66551 .51149 L F
.66162 .50945 m .6623 .51182 L .66314 .51025 L F
.974 .837 .645 r
.66218 .51205 m .66262 .51675 L .66295 .51319 L F
.66218 .51205 m .66295 .51319 L .6621 .51222 L F
.6618 .51149 m .66188 .51197 L .6618 .51188 L F
.6618 .51149 m .66196 .51248 L .66218 .51205 L F
.66196 .51248 m .66262 .51675 L .66218 .51205 L F
.848 .806 .809 r
.6588 .51593 m .66262 .51675 L .6618 .51149 L F
.6588 .51593 m .66055 .51787 L .66262 .51675 L F
.22 .742 .782 r
.31542 .60214 m .31405 .60229 L .31203 .60273 L F
0 0 0 r
.31751 .60195 m .31405 .60229 L .31542 .60214 L F
.723 .716 .843 r
.68021 .51173 m .67671 .51193 L .67808 .51116 L F
.53 .518 .788 r
.68139 .5085 m .68021 .51173 L .67808 .51116 L F
.114 .656 .842 r
.35544 .59074 m .35698 .59101 L .3533 .59072 L F
.302 .722 .974 r
.35753 .59023 m .35698 .59101 L .35544 .59074 L F
.35753 .59023 m .35901 .591 L .35698 .59101 L F
.132 .367 .825 r
.65515 .51756 m .65606 .51648 L .65348 .51481 L F
.28 .588 .946 r
.65515 .51756 m .65769 .5179 L .65606 .51648 L F
.232 0 0 r
.40948 .65566 m .40629 .65622 L .40863 .65591 L F
.586 .355 .533 r
.40848 .65837 m .40629 .65622 L .40609 .65846 L F
.40848 .65837 m .40863 .65591 L .40629 .65622 L F
.65 .43 .573 r
.74816 .5848 m .7516 .5855 L .75186 .58289 L F
.52 .281 .492 r
.34232 .61944 m .34454 .61905 L .3449 .61686 L F
.532 .34 .566 r
.3449 .61686 m .34711 .61642 L .34744 .6139 L F
.507 .269 .488 r
.34454 .61905 m .34711 .61642 L .3449 .61686 L F
.237 0 0 r
.51299 .70117 m .51168 .70231 L .50911 .70258 L F
.393 0 0 r
.51532 .70093 m .51168 .70231 L .51299 .70117 L F
.495 .244 .463 r
.59851 .53157 m .60101 .52906 L .59879 .52968 L F
.691 .775 .915 r
.70275 .47166 m .70381 .4731 L .7004 .47262 L F
.063 0 0 r
.50507 .80732 m .50654 .80563 L .50854 .80494 L F
.872 .895 .847 r
.70038 .52587 m .70366 .52419 L .70238 .52308 L F
.944 .842 .711 r
.70366 .52419 m .70419 .51935 L .70238 .52308 L F
.337 0 .003 r
.47471 .69213 m .47704 .69178 L .47809 .69032 L F
.083 0 0 r
.47704 .69178 m .4806 .69164 L .47809 .69032 L F
.505 0 0 r
.47809 .69032 m .4806 .69164 L .48236 .69199 L F
.914 .953 .805 r
.61968 .55767 m .61695 .55958 L .61889 .55684 L F
.604 .432 .622 r
.59109 .58856 m .58883 .59142 L .59125 .59105 L F
.599 .461 .665 r
.59125 .59105 m .59339 .58802 L .59109 .58856 L F
.986 .732 .456 r
.51826 .79467 m .51886 .79687 L .51763 .79601 L F
.837 .38 0 r
.51763 .79601 m .51886 .79687 L .51901 .79791 L F
.569 .523 .764 r
.52166 .79627 m .51886 .79687 L .51826 .79467 L F
.734 .52 .603 r
.52166 .79627 m .51901 .79791 L .51886 .79687 L F
.542 .396 .632 r
.50974 .78031 m .51198 .77997 L .51173 .7772 L F
.471 .178 .385 r
.51089 .7814 m .50951 .78153 L .50933 .78251 L F
.51143 .78191 m .51198 .77997 L .50974 .78031 L F
.574 .813 .989 r
.51433 .77921 m .5149 .78024 L .51198 .77997 L F
.391 .105 .354 r
.51162 .78125 m .51433 .77921 L .51198 .77997 L F
.51143 .78191 m .51212 .78127 L .51162 .78125 L F
.51212 .78127 m .51433 .77921 L .51162 .78125 L F
.562 .336 .53 r
.51425 .78161 m .51427 .78123 L .51143 .78191 L F
.183 0 0 r
.51224 .78127 m .51226 .78127 L .51225 .78127 L F
.562 .336 .53 r
.51427 .78123 m .51433 .77921 L .51212 .78127 L F
.51224 .78127 m .5121 .78129 L .51143 .78191 L F
.183 0 0 r
.51219 .78128 m .51222 .78128 L .50911 .78224 L F
0 0 0 r
.51218 .78128 m .51225 .78127 L .51213 .78129 L F
.51225 .78127 m .51226 .78127 L .51224 .78127 L F
.183 0 0 r
.51219 .78128 m .51224 .78127 L .51222 .78128 L F
0 0 0 r
.51225 .78127 m .51224 .78127 L .51213 .78129 L F
.562 .336 .53 r
.51427 .78123 m .51224 .78127 L .51143 .78191 L F
.51224 .78127 m .51212 .78127 L .5121 .78129 L F
.183 0 0 r
.51224 .78127 m .51225 .78127 L .51222 .78128 L F
.50731 .78199 m .51219 .78128 L .50911 .78224 L F
0 0 0 r
.50964 .78174 m .51218 .78128 L .50731 .78199 L F
.51218 .78128 m .51213 .78129 L .50731 .78199 L F
.471 .178 .385 r
.51143 .78191 m .51089 .7814 L .50933 .78251 L F
.51089 .7814 m .50974 .78031 L .50951 .78153 L F
.965 .868 .691 r
.64452 .50978 m .64472 .50615 L .64654 .50678 L F
.887 .701 .646 r
.64654 .50678 m .64472 .50615 L .64451 .50569 L F
.903 .939 .823 r
.55762 .58298 m .55543 .58589 L .55441 .58523 L F
.392 .091 .331 r
.60355 .52635 m .60603 .52576 L .60612 .52366 L F
.179 .003 .389 r
.60612 .52366 m .60815 .52261 L .60835 .52031 L F
.205 0 .294 r
.60612 .52366 m .60772 .52479 L .60815 .52261 L F
.60612 .52366 m .60603 .52576 L .60772 .52479 L F
.515 .34 .583 r
.25356 .60235 m .25581 .602 L .25575 .59956 L F
.405 .261 .571 r
.25378 .60559 m .25581 .602 L .25356 .60235 L F
.502 .908 .826 r
.5604 .70883 m .56311 .70736 L .56395 .7075 L F
.476 0 .012 r
.56395 .7075 m .56635 .70834 L .56729 .70741 L F
.277 .411 .818 r
.56429 .70682 m .56635 .70834 L .56395 .7075 L F
.56577 .70713 m .56635 .70834 L .56429 .70682 L F
.062 0 0 r
.56729 .70741 m .56635 .70834 L .56812 .70765 L F
.261 .058 .405 r
.56729 .70741 m .56907 .70651 L .56919 .70388 L F
.062 0 0 r
.56729 .70741 m .56812 .70765 L .56907 .70651 L F
.646 .62 .81 r
.56812 .70765 m .56635 .70834 L .56497 .70544 L F
.533 .263 .452 r
.56457 .7109 m .56747 .70748 L .56552 .70734 L F
.646 .62 .81 r
.56812 .70765 m .56497 .70544 L .56724 .70513 L F
.375 .146 .434 r
.56919 .70388 m .56907 .70651 L .57107 .70577 L F
.204 0 .09 r
.56907 .70651 m .56812 .70765 L .57107 .70577 L F
.572 .025 0 r
.56771 .70645 m .57107 .70577 L .56812 .70765 L F
.56724 .70513 m .56926 .70547 L .56771 .70645 L F
.56926 .70547 m .57107 .70577 L .56771 .70645 L F
.533 .263 .452 r
.56747 .70748 m .56823 .70658 L .56691 .70695 L F
.56642 .70726 m .56691 .70695 L .56607 .70719 L F
.56747 .70748 m .56691 .70695 L .56642 .70726 L F
.56747 .70748 m .56607 .70719 L .56552 .70734 L F
.277 .411 .818 r
.56497 .70544 m .56577 .70713 L .56429 .70682 L F
.389 .362 .707 r
.49794 .79436 m .50046 .79643 L .50004 .79294 L F
.594 .41 .602 r
.58644 .5942 m .58883 .59142 L .58559 .59109 L F
.58644 .5942 m .5889 .59384 L .58883 .59142 L F
.615 .436 .616 r
.5889 .59384 m .59125 .59105 L .58883 .59142 L F
.053 0 .383 r
.47502 .78533 m .4737 .78831 L .47565 .78849 L F
.604 .461 .66 r
.47392 .79189 m .47565 .78849 L .4737 .78831 L F
0 .39 .713 r
.31421 .58475 m .31604 .58536 L .31753 .58595 L F
.198 .675 .935 r
.31823 .58543 m .31753 .58595 L .31604 .58536 L F
.31823 .58543 m .31937 .58601 L .31753 .58595 L F
.903 .939 .823 r
.55762 .58298 m .55441 .58523 L .55547 .58383 L F
.886 .984 .815 r
.55762 .58298 m .55547 .58383 L .55781 .58087 L F
0 0 0 r
.33222 .64474 m .33586 .64263 L .33428 .64408 L F
.002 0 0 r
.33625 .64329 m .33586 .64263 L .33791 .64194 L F
.33625 .64329 m .33428 .64408 L .33586 .64263 L F
.714 .75 .88 r
.55953 .63323 m .55705 .63376 L .55925 .63159 L F
0 0 0 r
.55925 .63159 m .55705 .63376 L .55874 .63247 L F
.638 .464 .631 r
.56017 .63591 m .55817 .63453 L .55953 .63323 L F
.55817 .63453 m .55705 .63376 L .55897 .63335 L F
.55817 .63453 m .55897 .63335 L .55953 .63323 L F
.56017 .63591 m .55714 .6362 L .55705 .63376 L F
.888 .974 .67 r
.55714 .6362 m .55874 .63247 L .55705 .63376 L F
.55732 .63578 m .55667 .6359 L .55874 .63247 L F
.55714 .6362 m .55706 .63615 L .55732 .63578 L F
.55706 .63615 m .55667 .6359 L .55732 .63578 L F
.557 .018 0 r
.67168 .47491 m .67339 .47583 L .675 .47523 L F
.348 .825 .827 r
.67339 .47583 m .67718 .47495 L .675 .47523 L F
.241 0 0 r
.32348 .58709 m .32535 .58747 L .32709 .58756 L F
.345 0 0 r
.32535 .58747 m .3289 .5881 L .32709 .58756 L F
.366 .495 .856 r
.509 .63458 m .50795 .63626 L .5068 .63325 L F
.509 .63458 m .50987 .63672 L .50795 .63626 L F
.717 .561 .676 r
.58614 .70088 m .58222 .69807 L .58566 .69846 L F
.21 0 0 r
.66931 .47903 m .66543 .47848 L .66658 .48084 L F
.956 .71 .524 r
.63498 .54458 m .63659 .54332 L .63532 .54168 L F
.63498 .54458 m .63606 .54532 L .63659 .54332 L F
.421 .85 .715 r
.44606 .6622 m .4441 .66307 L .44271 .66399 L F
0 0 0 r
.4441 .66307 m .4425 .6645 L .44271 .66399 L F
.89 .82 .772 r
.50046 .79643 m .50385 .79436 L .50247 .79422 L F
0 .506 .759 r
.50385 .79436 m .50505 .79444 L .50247 .79422 L F
.50385 .79436 m .50646 .79483 L .50505 .79444 L F
.76 .246 0 r
.50385 .79436 m .50693 .79728 L .50646 .79483 L F
.789 .646 .705 r
.58559 .59109 m .58198 .5883 L .58187 .59066 L F
.58559 .59109 m .58536 .58868 L .58198 .5883 L F
.888 .778 .734 r
.58183 .59313 m .58559 .59109 L .58187 .59066 L F
.58183 .59313 m .58343 .59377 L .58559 .59109 L F
.804 .632 .668 r
.58343 .59377 m .58644 .5942 L .58559 .59109 L F
0 0 0 r
.55252 .76792 m .55149 .76866 L .55369 .76549 L F
.55252 .76792 m .55369 .76549 L .55287 .76512 L F
.499 .549 .838 r
.55369 .76549 m .55434 .76233 L .55204 .76283 L F
.55369 .76549 m .55553 .76498 L .55434 .76233 L F
.96 .895 .717 r
.63525 .55223 m .63619 .54969 L .63529 .54883 L F
.586 .708 .927 r
.68034 .52661 m .67655 .5258 L .67878 .52309 L F
.726 .454 .515 r
.253 .61875 m .25659 .61668 L .25446 .62009 L F
.253 .61875 m .25655 .61946 L .25659 .61668 L F
.224 .21 .632 r
.25659 .61668 m .25753 .61301 L .25564 .61331 L F
.25659 .61668 m .25809 .61568 L .25753 .61301 L F
.62 .366 .512 r
.25659 .61668 m .25881 .61871 L .25809 .61568 L F
.25659 .61668 m .25655 .61946 L .25881 .61871 L F
.489 .368 .641 r
.39063 .67864 m .39284 .68068 L .39271 .67817 L F
.39063 .67864 m .3908 .68093 L .39284 .68068 L F
.509 .738 .977 r
.25446 .62009 m .25655 .61946 L .253 .61875 L F
.048 0 .463 r
.55317 .75157 m .55332 .75586 L .55415 .75145 L F
.81 .906 .908 r
.67655 .5258 m .67392 .52593 L .67604 .52304 L F
.67655 .5258 m .67479 .52692 L .67392 .52593 L F
.838 .831 .84 r
.67878 .52309 m .67655 .5258 L .67604 .52304 L F
.511 .616 .893 r
.75939 .59424 m .75609 .59189 L .75854 .59106 L F
.413 .413 .75 r
.76046 .59061 m .75939 .59424 L .75854 .59106 L F
.76046 .59061 m .76171 .59304 L .75939 .59424 L F
.553 .478 .725 r
.76171 .59304 m .75933 .59643 L .75939 .59424 L F
.771 .756 .84 r
.55841 .72345 m .55957 .72543 L .56176 .72376 L F
.932 .88 .76 r
.55033 .59361 m .54906 .59263 L .55124 .5917 L F
.932 .881 .761 r
.55124 .5917 m .54906 .59263 L .55008 .59081 L F
.959 .624 .317 r
.25061 .62763 m .24933 .62824 L .24891 .62554 L F
.977 .883 .67 r
.25061 .62763 m .24864 .62869 L .24933 .62824 L F
.25061 .62763 m .24896 .63098 L .24864 .62869 L F
.959 .624 .317 r
.25061 .62763 m .24891 .62554 L .24885 .62508 L F
.24885 .62508 m .24891 .62554 L .24884 .62506 L F
.341 .187 .522 r
.24884 .62506 m .24933 .62824 L .25007 .62661 L F
.538 .402 .643 r
.24933 .62824 m .24864 .62869 L .25007 .62661 L F
.364 .187 .503 r
.24921 .62785 m .25025 .62874 L .25007 .62661 L F
.24864 .62869 m .24933 .62871 L .24921 .62785 L F
.24933 .62871 m .25025 .62874 L .24921 .62785 L F
.227 .011 .363 r
.25258 .62502 m .25198 .62725 L .25061 .62763 L F
.475 .383 .671 r
.25444 .63024 m .25061 .62763 L .25198 .62725 L F
.688 .553 .696 r
.54775 .79412 m .54988 .79124 L .5476 .79163 L F
.4 .138 .397 r
.35372 .63079 m .35301 .63292 L .35127 .63337 L F
.229 0 .202 r
.3558 .63022 m .35301 .63292 L .35372 .63079 L F
.808 .564 .57 r
.58331 .59588 m .58644 .5942 L .58343 .59377 L F
.58331 .59588 m .58653 .59658 L .58644 .5942 L F
.589 .392 .582 r
.58653 .59658 m .5889 .59384 L .58644 .5942 L F
.482 .187 .388 r
.63042 .48951 m .63299 .48904 L .63321 .48639 L F
.54 .35 .572 r
.63321 .48639 m .6379 .48556 L .6358 .48394 L F
.284 .032 .344 r
.63321 .48639 m .63489 .48798 L .6379 .48556 L F
.63321 .48639 m .63299 .48904 L .63489 .48798 L F
.728 .425 .466 r
.59357 .70985 m .5944 .71214 L .59053 .71166 L F
.48 .338 .61 r
.56167 .6305 m .55953 .63323 L .55925 .63159 L F
.414 .004 .149 r
.56258 .63458 m .56398 .63479 L .56166 .63504 L F
.339 .243 .598 r
.56166 .63504 m .55953 .63323 L .56233 .63492 L F
.701 .492 .601 r
.56535 .63322 m .56233 .63492 L .56167 .6305 L F
.414 .004 .149 r
.56535 .63322 m .56166 .63504 L .56233 .63492 L F
.56535 .63322 m .5641 .63466 L .56258 .63458 L F
.5641 .63466 m .56398 .63479 L .56258 .63458 L F
.48 .338 .61 r
.56167 .6305 m .56228 .63457 L .55953 .63323 L F
.56228 .63457 m .56233 .63492 L .56171 .63454 L F
.56228 .63457 m .56171 .63454 L .55953 .63323 L F
.339 .243 .598 r
.56166 .63504 m .56017 .63591 L .55953 .63323 L F
.554 .186 .297 r
.42012 .65354 m .42208 .65494 L .42347 .65266 L F
.517 .141 .267 r
.42208 .65494 m .42556 .65274 L .42347 .65266 L F
.627 .498 .686 r
.74677 .58863 m .74929 .58832 L .74816 .5848 L F
0 0 .396 r
.74738 .49766 m .7479 .50031 L .74754 .50114 L F
0 0 .074 r
.7479 .50031 m .74766 .50242 L .74754 .50114 L F
.363 .616 .948 r
.59179 .72092 m .58719 .71847 L .59027 .71765 L F
.258 .05 .396 r
.59027 .71765 m .59104 .71911 L .59179 .72092 L F
.897 .681 .603 r
.58932 .7223 m .59179 .72092 L .59104 .71911 L F
.58932 .7223 m .59093 .72375 L .59179 .72092 L F
.373 .158 .452 r
.36524 .62409 m .36363 .62246 L .36571 .62181 L F
.36524 .62409 m .36347 .62512 L .36363 .62246 L F
.419 .019 .171 r
.52171 .68855 m .52432 .68825 L .52432 .68749 L F
.545 .115 .175 r
.52432 .68825 m .52655 .68865 L .52432 .68749 L F
.798 .967 .912 r
.46892 .63821 m .46736 .63965 L .46792 .63771 L F
.788 .959 .922 r
.46736 .63965 m .46623 .63916 L .46792 .63771 L F
.312 0 0 r
.50824 .69748 m .51053 .69734 L .51208 .69613 L F
0 0 0 r
.51208 .69613 m .51257 .69652 L .51381 .69481 L F
.51208 .69613 m .51053 .69734 L .51257 .69652 L F
.638 .71 .9 r
.69808 .47354 m .69467 .47257 L .69701 .47205 L F
.67 .771 .925 r
.7004 .47262 m .69808 .47354 L .69701 .47205 L F
.746 .894 .946 r
.48533 .62995 m .48199 .63035 L .48398 .62904 L F
.768 .885 .929 r
.48788 .62814 m .48533 .62995 L .48398 .62904 L F
.732 .782 .893 r
.54628 .59964 m .54419 .60085 L .54281 .5994 L F
.155 .279 .74 r
.49597 .63894 m .49739 .64284 L .4981 .64099 L F
.671 .869 .974 r
.4981 .64099 m .49739 .64284 L .49959 .6418 L F
0 0 0 r
.52516 .79553 m .52716 .7942 L .52571 .79568 L F
.52516 .79553 m .52571 .79568 L .52326 .79391 L F
.615 .305 .422 r
.48988 .79085 m .48804 .78912 L .48754 .79067 L F
.736 .762 .874 r
.68421 .53234 m .68723 .53332 L .68623 .53104 L F
.613 .696 .903 r
.68623 .53104 m .68723 .53332 L .68997 .53214 L F
.87 .939 .862 r
.55089 .7797 m .55243 .77688 L .55057 .77747 L F
.737 .428 .459 r
.55305 .73973 m .55638 .73769 L .55299 .73735 L F
.55305 .73973 m .55518 .74019 L .55638 .73769 L F
.788 .49 .484 r
.55518 .74019 m .55765 .74045 L .55638 .73769 L F
.506 .188 .362 r
.74343 .50658 m .74264 .50843 L .74105 .50884 L F
.658 .413 .538 r
.74597 .50642 m .74264 .50843 L .74343 .50658 L F
.259 0 .091 r
.34016 .62251 m .33736 .62447 L .3395 .62415 L F
.522 .345 .582 r
.34016 .62251 m .34233 .62205 L .34232 .61944 L F
.401 .054 .257 r
.34156 .62358 m .34016 .62251 L .3395 .62415 L F
.34156 .62358 m .34233 .62205 L .34016 .62251 L F
0 0 .132 r
.63167 .5655 m .63033 .56844 L .63077 .56673 L F
.854 .818 .813 r
.55033 .59361 m .54673 .59535 L .54906 .59263 L F
.55033 .59361 m .54797 .59657 L .54673 .59535 L F
.651 .829 .968 r
.58534 .72562 m .58577 .72457 L .5844 .7242 L F
.76 .353 .282 r
.48922 .7842 m .48669 .7849 L .48632 .78305 L F
.48922 .7842 m .48859 .7854 L .48669 .7849 L F
.725 .552 .656 r
.49115 .78372 m .48859 .7854 L .48922 .7842 L F
.908 .675 .171 r
.63482 .55298 m .63525 .55223 L .63418 .55094 L F
.63482 .55298 m .63522 .55387 L .63525 .55223 L F
.96 .895 .717 r
.63525 .55223 m .63529 .54883 L .63418 .55094 L F
.882 .579 .066 r
.71667 .49269 m .7175 .49571 L .71747 .49489 L F
.986 .723 .434 r
.7175 .49571 m .71688 .49733 L .71747 .49489 L F
.7175 .49571 m .71802 .49832 L .71688 .49733 L F
0 0 0 r
.59099 .53945 m .59333 .53665 L .59195 .53805 L F
.523 .632 .9 r
.24337 .65025 m .24474 .65011 L .24356 .65052 L F
.524 .412 .668 r
.34711 .61642 m .3488 .61311 L .34744 .6139 L F
.677 .822 .953 r
.69246 .53376 m .69679 .53327 L .69553 .5319 L F
.745 .856 .931 r
.69679 .53327 m .69781 .53097 L .69553 .5319 L F
.69679 .53327 m .69892 .5321 L .69781 .53097 L F
.375 .146 .434 r
.56919 .70388 m .57107 .70577 L .57138 .70336 L F
.376 .712 .987 r
.38622 .69894 m .38694 .69846 L .38452 .69769 L F
.017 0 0 r
.45426 .65795 m .45207 .65834 L .45002 .65853 L F
0 0 0 r
.45541 .65779 m .45207 .65834 L .45426 .65795 L F
.909 .523 .271 r
.59827 .71104 m .5992 .70997 L .59846 .70879 L F
.59827 .71104 m .59991 .71208 L .5992 .70997 L F
.162 0 0 r
.2921 .6477 m .29224 .64782 L .28972 .64748 L F
0 0 .152 r
.2921 .6477 m .29225 .64751 L .29224 .64782 L F
.29224 .64782 m .29225 .64751 L .2921 .6477 L F
.377 0 .043 r
.28175 .58597 m .284 .58576 L .2852 .58469 L F
.211 0 0 r
.284 .58576 m .28733 .58506 L .2852 .58469 L F
.562 .249 .395 r
.26296 .63578 m .26559 .63568 L .26626 .63361 L F
.215 .508 .909 r
.26626 .63361 m .26666 .6323 L .26535 .63223 L F
.597 .556 .779 r
.26559 .63568 m .26666 .6323 L .26626 .63361 L F
.29 .08 .412 r
.60397 .58518 m .60665 .58211 L .60406 .58314 L F
.546 .334 .543 r
.60214 .58589 m .60397 .58518 L .60406 .58314 L F
.83 .631 .634 r
.58403 .58569 m .58079 .5826 L .58052 .58512 L F
.79 .61 .657 r
.58198 .5883 m .58403 .58569 L .58052 .58512 L F
.792 .613 .659 r
.58198 .5883 m .58536 .58868 L .58403 .58569 L F
.609 .042 0 r
.65916 .48598 m .66235 .48773 L .66177 .48589 L F
.832 .819 .837 r
.54797 .59657 m .54528 .59654 L .54673 .59535 L F
.856 .742 .737 r
.54797 .59657 m .54628 .59964 L .54528 .59654 L F
.597 .456 .661 r
.58588 .71509 m .58626 .71688 L .58404 .71769 L F
.873 .842 .812 r
.62416 .52415 m .62039 .52351 L .62304 .52301 L F
.62416 .52415 m .6203 .52543 L .62039 .52351 L F
.62416 .52415 m .62182 .52693 L .6203 .52543 L F
.669 .755 .915 r
.62531 .52295 m .62416 .52415 L .62304 .52301 L F
.633 .179 .157 r
.4879 .78223 m .48689 .7804 L .48632 .78305 L F
.878 .943 .854 r
.7159 .48702 m .71623 .48452 L .71794 .48471 L F
.7159 .48702 m .71493 .48612 L .71623 .48452 L F
.629 .271 .344 r
.7159 .48702 m .7148 .48905 L .71493 .48612 L F
.7159 .48702 m .71837 .48893 L .7148 .48905 L F
.502 .311 .554 r
.39163 .67004 m .39378 .6696 L .39386 .66732 L F
.525 .411 .666 r
.39163 .67004 m .39401 .67232 L .39378 .6696 L F
.39163 .67004 m .39209 .67358 L .39401 .67232 L F
.606 .559 .775 r
.51492 .65829 m .51581 .65993 L .51817 .65911 L F
.259 0 0 r
.71459 .47631 m .71789 .4765 L .71451 .47582 L F
.636 .579 .773 r
.67811 .53182 m .67964 .53589 L .68161 .5346 L F
.872 .596 .517 r
.64281 .4804 m .64583 .48325 L .64426 .4814 L F
.858 .798 .792 r
.68158 .51852 m .68023 .52096 L .6782 .51984 L F
.867 .793 .775 r
.68023 .52096 m .67878 .52309 L .6782 .51984 L F
.606 .563 .78 r
.50158 .62695 m .50052 .63104 L .4992 .62774 L F
.50158 .62695 m .50277 .63037 L .50052 .63104 L F
.718 .413 .461 r
.59043 .70685 m .59031 .70843 L .58859 .70799 L F
0 0 .554 r
.58927 .69673 m .58796 .69558 L .58875 .69446 L F
.58927 .69673 m .58958 .69789 L .58796 .69558 L F
.217 0 .225 r
.46049 .65298 m .45803 .65551 L .45874 .65379 L F
.662 .749 .914 r
.49582 .6268 m .49698 .62836 L .49351 .62769 L F
.59 .718 .933 r
.49803 .62626 m .49698 .62836 L .49582 .6268 L F
.592 .721 .933 r
.4992 .62774 m .49698 .62836 L .49803 .62626 L F
.316 .629 .961 r
.49877 .77672 m .49997 .77812 L .50304 .77829 L F
.093 0 .312 r
.58913 .54285 m .59099 .53945 L .58934 .54062 L F
.319 .007 .269 r
.59333 .53665 m .59606 .53418 L .59406 .53508 L F
.353 .127 .425 r
.59406 .53508 m .59606 .53418 L .59625 .53217 L F
.323 0 .018 r
.76926 .60173 m .77055 .60095 L .77024 .60381 L F
.77055 .60095 m .77249 .59978 L .77109 .60229 L F
.77055 .60095 m .77109 .60229 L .77024 .60381 L F
.76926 .60173 m .77175 .60133 L .77249 .59978 L F
.648 .694 .879 r
.77095 .59755 m .77191 .60025 L .76986 .59924 L F
.76938 .59804 m .76986 .59924 L .76818 .59842 L F
.77095 .59755 m .76986 .59924 L .76938 .59804 L F
.887 .828 .783 r
.77175 .60133 m .77512 .59913 L .77249 .59978 L F
.434 .021 .153 r
.52655 .68865 m .52886 .68854 L .53017 .68628 L F
.798 .621 .661 r
.52886 .68854 m .53286 .68626 L .53017 .68628 L F
.823 .694 .722 r
.49912 .77189 m .49912 .7741 L .50074 .77141 L F
.626 .334 .454 r
.61705 .53675 m .61358 .53698 L .61489 .53473 L F
.558 .727 .953 r
.69329 .47995 m .69466 .47779 L .69236 .47859 L F
.69329 .47995 m .69703 .4803 L .69466 .47779 L F
.696 .154 0 r
.59415 .70221 m .59667 .70373 L .59458 .70167 L F
.605 .068 0 r
.59458 .70167 m .59667 .70373 L .59758 .70429 L F
.506 .808 .999 r
.64086 .50923 m .64343 .50886 L .64452 .50978 L F
.767 .632 .712 r
.51189 .79397 m .51578 .79469 L .51474 .79161 L F
.87 .845 .817 r
.51198 .7962 m .51578 .79469 L .51189 .79397 L F
.577 .546 .783 r
.51578 .79469 m .51717 .79072 L .51474 .79161 L F
.51578 .79469 m .51867 .79415 L .51717 .79072 L F
.609 .219 .279 r
.51826 .79467 m .51763 .79601 L .51578 .79469 L F
.696 .314 .319 r
.51763 .79601 m .52166 .79627 L .51826 .79467 L F
0 0 0 r
.51867 .79415 m .51763 .79601 L .51826 .79467 L F
.512 .284 .505 r
.51578 .79469 m .51763 .79601 L .51867 .79415 L F
.729 .593 .704 r
.58588 .71509 m .58934 .71539 L .58719 .71847 L F
.705 .56 .688 r
.58934 .71539 m .59027 .71765 L .58719 .71847 L F
.589 .568 .798 r
.59053 .71166 m .59164 .71489 L .58934 .71539 L F
.54 .361 .587 r
.59164 .71489 m .59172 .71735 L .58934 .71539 L F
.341 .362 .738 r
.58934 .71539 m .59172 .71735 L .59027 .71765 L F
.626 .41 .568 r
.52763 .76835 m .53007 .76809 L .53008 .76598 L F
.785 .773 .842 r
.7827 .596 m .78671 .59494 L .7853 .59351 L F
.868 .851 .392 r
.51274 .76538 m .51257 .76743 L .51477 .76669 L F
.194 0 .347 r
.62823 .49009 m .62986 .49051 L .63042 .48951 L F
.62823 .49009 m .62798 .49201 L .62986 .49051 L F
.413 .329 .652 r
.29199 .62279 m .29063 .6245 L .29006 .62257 L F
.671 .477 .614 r
.54662 .77128 m .54834 .77228 L .54299 .77443 L F
.722 .543 .648 r
.54859 .77152 m .54834 .77228 L .54662 .77128 L F
.666 .341 .413 r
.62043 .53469 m .62126 .53684 L .61705 .53675 L F
.662 .375 .475 r
.6221 .53483 m .62126 .53684 L .62043 .53469 L F
.847 .661 .65 r
.63682 .53342 m .63758 .53703 L .63745 .53471 L F
.429 .868 .903 r
.68879 .51143 m .68589 .51243 L .68512 .51234 L F
.107 0 0 r
.68494 .51377 m .68589 .51243 L .68879 .51143 L F
.355 0 .108 r
.35301 .63292 m .35013 .63475 L .35127 .63337 L F
.495 .315 .567 r
.38554 .60429 m .38318 .60689 L .38327 .60533 L F
.416 .542 .875 r
.71537 .51412 m .71565 .51561 L .71729 .51377 L F
.382 .49 .844 r
.71565 .51561 m .71839 .51678 L .71729 .51377 L F
.533 .347 .574 r
.60989 .54495 m .60734 .543 L .60981 .54257 L F
.60989 .54495 m .60765 .54554 L .60734 .543 L F
.879 .521 .365 r
.71667 .49269 m .71747 .49489 L .71597 .49368 L F
.196 0 .086 r
.52348 .69573 m .52246 .6978 L .52052 .69793 L F
.285 0 .129 r
.52449 .69719 m .52348 .69573 L .52546 .69479 L F
.52449 .69719 m .52246 .6978 L .52348 .69573 L F
.569 .364 .562 r
.57861 .61323 m .57551 .61514 L .57533 .61365 L F
.637 .504 .684 r
.74816 .5848 m .74929 .58832 L .7516 .5855 L F
.881 .992 .781 r
.52626 .7994 m .52283 .80297 L .52453 .80166 L F
.526 .419 .675 r
.52852 .80223 m .52624 .80284 L .52626 .7994 L F
.739 .449 .491 r
.52852 .80223 m .52626 .7994 L .52453 .80166 L F
.561 .02 0 r
.53007 .76809 m .53221 .76885 L .53372 .76856 L F
.667 .211 .161 r
.53221 .76885 m .5361 .76912 L .53372 .76856 L F
.825 .601 .599 r
.25262 .64963 m .25515 .65015 L .25477 .6479 L F
.002 0 .136 r
.25515 .65015 m .25708 .64742 L .25477 .6479 L F
.667 .291 .324 r
.40863 .65591 m .41195 .65602 L .40948 .65566 L F
.507 .444 .72 r
.53425 .79917 m .53209 .80243 L .53163 .79966 L F
.071 0 0 r
.53311 .79966 m .53425 .79917 L .53163 .79966 L F
.869 .989 .727 r
.53558 .79686 m .53425 .79917 L .53311 .79966 L F
.935 .745 .621 r
.58285 .57957 m .58135 .57605 L .57957 .57955 L F
.832 .688 .705 r
.58079 .5826 m .58285 .57957 L .57957 .57955 L F
.935 .884 .759 r
.62391 .53777 m .62113 .53991 L .6229 .53683 L F
.62391 .53777 m .62251 .54079 L .62113 .53991 L F
.861 .446 0 r
.62391 .53777 m .6229 .53683 L .6221 .53483 L F
.621 .895 .987 r
.68553 .4767 m .68424 .47836 L .68658 .47748 L F
.666 .962 .934 r
.68553 .4767 m .68358 .47793 L .68424 .47836 L F
.356 .027 .263 r
.52171 .68855 m .52347 .68945 L .52432 .68825 L F
.52171 .68855 m .52076 .69144 L .52347 .68945 L F
.737 .917 .555 r
.63255 .56167 m .6339 .56017 L .63366 .55934 L F
.63255 .56167 m .63191 .56302 L .6339 .56017 L F
.495 .711 .967 r
.30736 .62885 m .30663 .63049 L .30527 .62907 L F
.30736 .62885 m .30869 .63026 L .30663 .63049 L F
0 0 0 r
.47764 .79429 m .47425 .79531 L .47638 .79617 L F
.47854 .79383 m .47764 .79429 L .47638 .79617 L F
.34803 .63582 m .34525 .63814 L .34639 .63684 L F
0 0 .515 r
.71802 .49832 m .71938 .49903 L .71688 .49733 L F
.731 .383 .389 r
.49376 .8088 m .49133 .81045 L .49124 .80815 L F
0 0 .097 r
.49376 .8088 m .49282 .81161 L .49479 .81058 L F
.703 .571 .703 r
.49282 .81161 m .48903 .81263 L .49189 .81375 L F
.763 .877 .929 r
.49288 .8113 m .49282 .81161 L .49189 .81375 L F
.4935 .80976 m .49312 .81079 L .49288 .8113 L F
.49312 .81079 m .49282 .81161 L .49288 .8113 L F
.731 .383 .389 r
.49376 .8088 m .49393 .80909 L .49133 .81045 L F
.49393 .80909 m .49479 .81058 L .49325 .81052 L F
.49393 .80909 m .49325 .81052 L .49133 .81045 L F
.463 .259 .517 r
.34233 .62205 m .34454 .61905 L .34232 .61944 L F
.816 .734 .774 r
.54162 .77081 m .54587 .77149 L .54642 .76757 L F
.596 .047 0 r
.54162 .77081 m .54395 .7722 L .54587 .77149 L F
0 0 0 r
.54587 .77149 m .5474 .7684 L .54642 .76757 L F
.54587 .77149 m .54686 .77062 L .5474 .7684 L F
.53 .229 .401 r
.54395 .7722 m .54686 .77062 L .54587 .77149 L F
.514 .53 .81 r
.39178 .68406 m .39495 .68695 L .39354 .68385 L F
.443 .436 .756 r
.3908 .68093 m .39178 .68406 L .39354 .68385 L F
.9 .68 .596 r
.62251 .54079 m .62016 .54187 L .62113 .53991 L F
.62251 .54079 m .62201 .54299 L .62016 .54187 L F
0 0 0 r
.25246 .65529 m .25354 .65404 L .25637 .65191 L F
.807 .668 .71 r
.63096 .51414 m .63354 .5158 L .63277 .51229 L F
.868 .495 .34 r
.63096 .51414 m .63259 .51609 L .63354 .5158 L F
.927 .632 .465 r
.63259 .51609 m .63423 .5181 L .63354 .5158 L F
.36 .37 .735 r
.63277 .51229 m .63354 .5158 L .63519 .51396 L F
.701 .984 .851 r
.63354 .5158 m .63259 .51609 L .63519 .51396 L F
.927 .632 .465 r
.63354 .5158 m .63423 .5181 L .63259 .51609 L F
.626 .432 .6 r
.55655 .71559 m .55874 .71738 L .55938 .71249 L F
.191 .173 .607 r
.55938 .71249 m .56092 .7113 L .5604 .70883 L F
.322 .211 .569 r
.55874 .71738 m .56092 .7113 L .55938 .71249 L F
.598 .522 .74 r
.57441 .717 m .57217 .71769 L .57124 .71428 L F
.571 .357 .551 r
.59606 .53418 m .59851 .53157 L .59625 .53217 L F
.046 0 0 r
.48293 .65913 m .48196 .65931 L .4802 .65944 L F
.48293 .65913 m .48196 .65931 L .4802 .65944 L F
.501 .217 .414 r
.3488 .61311 m .3516 .61063 L .3493 .61174 L F
.93 .859 .75 r
.69781 .53097 m .70037 .52909 L .69969 .52801 L F
.69781 .53097 m .69892 .5321 L .70037 .52909 L F
.246 0 0 r
.42856 .70838 m .42539 .70957 L .42634 .70864 L F
.441 0 .091 r
.45412 .70095 m .45273 .70268 L .45062 .70265 L F
.343 0 .011 r
.45636 .70075 m .45273 .70268 L .45412 .70095 L F
.439 .807 .994 r
.5051 .62738 m .5083 .62732 L .50855 .62791 L F
.019 0 0 r
.50855 .62791 m .50502 .62962 L .5051 .62738 L F
.50855 .62791 m .50804 .62852 L .50502 .62962 L F
.817 .996 .856 r
.50855 .62791 m .5083 .62732 L .50884 .62567 L F
.5089 .62564 m .50884 .62567 L .50895 .62532 L F
.50855 .62791 m .50884 .62567 L .5089 .62564 L F
.50897 .62536 m .50895 .62532 L .50898 .62529 L F
.50855 .62791 m .50894 .6254 L .50897 .62536 L F
.50894 .6254 m .50895 .62532 L .50897 .62536 L F
.632 .831 .977 r
.50901 .62512 m .5083 .62732 L .50594 .62618 L F
.424 .238 .522 r
.50858 .62576 m .50858 .62577 L .5086 .62576 L F
.446 0 .025 r
.50751 .62626 m .50848 .62594 L .5086 .62576 L F
.822 .872 .431 r
.50888 .62559 m .50804 .62852 L .50897 .62536 L F
.424 .238 .522 r
.50884 .6257 m .5088 .62745 L .51058 .62527 L F
.822 .872 .431 r
.50893 .62563 m .50804 .62852 L .50855 .62791 L F
.50888 .62566 m .50804 .62852 L .50893 .62563 L F
0 0 .208 r
.5088 .62745 m .50804 .62852 L .50885 .62569 L F
.822 .872 .431 r
.50897 .62536 m .50888 .62566 L .50893 .62563 L F
.817 .996 .856 r
.50898 .62529 m .50895 .62532 L .50901 .62512 L F
.822 .872 .431 r
.50901 .62512 m .50888 .62559 L .50897 .62536 L F
0 0 .208 r
.50896 .62569 m .50885 .62569 L .50901 .62512 L F
.5088 .62745 m .50885 .62569 L .50896 .62569 L F
.424 .238 .522 r
.5086 .62576 m .50865 .62617 L .50884 .6257 L F
.50865 .62617 m .5088 .62745 L .50884 .6257 L F
.50858 .62577 m .5088 .62745 L .5086 .62576 L F
0 0 .208 r
.5088 .62745 m .50896 .62569 L .50858 .62576 L F
.446 0 .025 r
.5088 .62572 m .50892 .6257 L .50884 .6257 L F
0 0 .208 r
.50896 .62569 m .50901 .62512 L .50858 .62576 L F
.446 0 .025 r
.50848 .62594 m .50922 .6257 L .50892 .6257 L F
.50848 .62594 m .50892 .6257 L .5088 .62572 L F
.50922 .6257 m .51058 .62527 L .50887 .62569 L F
.50922 .6257 m .50887 .62569 L .50884 .6257 L F
.50848 .62594 m .50884 .6257 L .5086 .62576 L F
.50856 .62577 m .5086 .62576 L .50858 .62576 L F
.50751 .62626 m .5086 .62576 L .50856 .62577 L F
.577 .382 .58 r
.5088 .62745 m .50598 .62864 L .50597 .62806 L F
.531 .804 .996 r
.50594 .62618 m .5083 .62732 L .5051 .62738 L F
.577 .382 .58 r
.50734 .6268 m .50597 .62806 L .50594 .62625 L F
.531 .804 .996 r
.50507 .62609 m .5051 .62738 L .50286 .62585 L F
.50594 .62618 m .50572 .6265 L .50507 .62609 L F
.50572 .6265 m .5051 .62738 L .50507 .62609 L F
.788 .507 .511 r
.50144 .62505 m .50158 .62695 L .49803 .62626 L F
.557 .478 .721 r
.50356 .62311 m .50286 .62585 L .50144 .62505 L F
.706 .482 .582 r
.50286 .62585 m .50158 .62695 L .50144 .62505 L F
.50286 .62585 m .5051 .62738 L .50158 .62695 L F
.501 .422 .698 r
.50588 .62381 m .50286 .62585 L .50356 .62311 L F
.531 .804 .996 r
.50594 .62618 m .50286 .62585 L .50588 .62381 L F
.712 .431 .498 r
.50023 .62624 m .50355 .62641 L .50301 .62478 L F
.769 .87 .923 r
.50144 .62505 m .50256 .62341 L .50356 .62311 L F
.712 .431 .498 r
.50197 .62412 m .50301 .62478 L .50256 .62341 L F
.788 .507 .511 r
.50144 .62505 m .49803 .62626 L .49932 .62421 L F
.769 .87 .923 r
.50144 .62505 m .49932 .62421 L .50256 .62341 L F
.712 .431 .498 r
.50023 .62624 m .50301 .62478 L .50197 .62412 L F
.577 .382 .58 r
.5088 .62745 m .50598 .62864 L .50594 .62618 L F
.019 0 0 r
.50492 .62664 m .50751 .62626 L .50848 .62581 L F
.50814 .62587 m .50848 .62581 L .50858 .62576 L F
.50492 .62664 m .50848 .62581 L .50814 .62587 L F
.577 .382 .58 r
.50605 .62623 m .50594 .62625 L .50594 .62618 L F
.50734 .6268 m .50594 .62625 L .50605 .62623 L F
.5088 .62745 m .50597 .62806 L .50734 .6268 L F
.606 .887 .577 r
.71372 .50433 m .71484 .50293 L .71565 .50223 L F
.632 .928 .972 r
.71372 .50433 m .71273 .50389 L .71484 .50293 L F
.404 0 0 r
.27016 .77427 m .27096 .7743 L .27046 .77418 L F
.601 .637 .858 r
.54083 .78903 m .54138 .78687 L .53991 .78858 L F
.54083 .78903 m .54313 .78842 L .54138 .78687 L F
.775 .498 .516 r
.55671 .62232 m .5534 .62409 L .55345 .62167 L F
.55671 .62232 m .55725 .62438 L .5534 .62409 L F
.641 .396 .533 r
.6027 .59996 m .60491 .60189 L .60257 .60209 L F
.6027 .59996 m .6051 .59962 L .60491 .60189 L F
0 0 .333 r
.48632 .78305 m .48748 .78398 L .4879 .78223 L F
.48632 .78305 m .48669 .7849 L .48748 .78398 L F
.411 .808 .985 r
.33446 .58824 m .33261 .58891 L .33075 .58809 L F
.33446 .58824 m .33511 .58857 L .33261 .58891 L F
.663 .831 .964 r
.57917 .72538 m .58219 .72569 L .58103 .7247 L F
.71 .867 .956 r
.58103 .7247 m .58219 .72569 L .5844 .7242 L F
.414 0 .126 r
.41661 .65559 m .4187 .65539 L .42012 .65354 L F
.574 .166 .231 r
.42012 .65354 m .4187 .65539 L .42208 .65494 L F
.599 .285 .409 r
.51751 .76755 m .519 .76588 L .51751 .76563 L F
.51751 .76755 m .52059 .76732 L .519 .76588 L F
.443 .004 .107 r
.44164 .64893 m .4452 .64717 L .44192 .64783 L F
.44164 .64893 m .44387 .64896 L .4452 .64717 L F
.104 0 0 r
.4452 .64717 m .44591 .6481 L .44732 .64643 L F
.4452 .64717 m .44387 .64896 L .44591 .6481 L F
.097 0 .342 r
.61117 .5717 m .61084 .57389 L .61245 .57059 L F
.535 .554 .822 r
.24481 .64983 m .24337 .65025 L .24178 .64941 L F
.24481 .64983 m .24474 .65011 L .24337 .65025 L F
.691 .833 .951 r
.67808 .51116 m .67671 .51193 L .67494 .51047 L F
.993 .869 .601 r
.72798 .49152 m .72962 .4885 L .72926 .48827 L F
.72798 .49152 m .72879 .4925 L .72962 .4885 L F
.574 .307 .475 r
.59135 .60492 m .58835 .6078 L .58919 .60485 L F
.897 .61 .105 r
.59738 .70556 m .59758 .70429 L .59667 .70373 L F
.59738 .70556 m .59792 .70647 L .59758 .70429 L F
.498 .698 .959 r
.3504 .60222 m .35105 .60023 L .34914 .60058 L F
.3504 .60222 m .3523 .60184 L .35105 .60023 L F
.515 .348 .593 r
.75306 .59066 m .75495 .59054 L .75507 .58824 L F
.416 .346 .671 r
.75306 .59066 m .75553 .59293 L .75609 .59189 L F
.515 .35 .595 r
.75306 .59066 m .75553 .59293 L .75495 .59054 L F
.714 .638 .771 r
.68007 .51527 m .68158 .51852 L .67825 .51846 L F
.858 .798 .792 r
.68158 .51852 m .6782 .51984 L .67825 .51846 L F
.679 .622 .785 r
.68405 .51729 m .68158 .51852 L .68007 .51527 L F
0 .367 .749 r
.54322 .74233 m .54348 .7422 L .54253 .74224 L F
.609 .933 .717 r
.45803 .65551 m .45541 .65779 L .45661 .65683 L F
.614 .351 .496 r
.59709 .60236 m .59739 .60418 L .5937 .60513 L F
.621 .359 .5 r
.59941 .60237 m .59739 .60418 L .59709 .60236 L F
.956 .931 .73 r
.56733 .76872 m .5687 .7663 L .5666 .76768 L F
.964 .906 .713 r
.5666 .76768 m .5687 .7663 L .56768 .76556 L F
.667 .482 .626 r
.54642 .76757 m .54724 .76584 L .54502 .76599 L F
.785 .728 .799 r
.55841 .72345 m .56176 .72376 L .56021 .72095 L F
.596 .642 .867 r
.56407 .72335 m .56021 .72095 L .56176 .72376 L F
.497 0 0 r
.45541 .65779 m .45434 .65926 L .45207 .65834 L F
0 0 .01 r
.45803 .65551 m .45696 .65771 L .45541 .65779 L F
.471 .132 .31 r
.45696 .65771 m .45434 .65926 L .45541 .65779 L F
.211 0 0 r
.5215 .69877 m .52052 .69793 L .52246 .6978 L F
.5215 .69877 m .51955 .69931 L .52052 .69793 L F
.417 0 0 r
.66527 .50134 m .66497 .50164 L .66268 .50087 L F
.384 .343 .69 r
.66512 .49921 m .66497 .50164 L .66268 .50087 L F
.657 .502 .663 r
.56868 .62188 m .56678 .62066 L .56838 .61983 L F
.56868 .62188 m .56653 .62212 L .56678 .62066 L F
.416 .865 .849 r
.50304 .77829 m .50613 .77759 L .50377 .77824 L F
.743 .98 .915 r
.50611 .77653 m .50613 .77759 L .50809 .77619 L F
.811 1 .83 r
.50377 .77824 m .50613 .77759 L .50611 .77653 L F
.64 .499 .675 r
.51492 .65829 m .51817 .65911 L .51748 .65592 L F
.51 .363 .617 r
.25575 .59956 m .25782 .59916 L .2577 .59656 L F
.406 .214 .504 r
.25581 .602 m .25782 .59916 L .25575 .59956 L F
.621 .315 .43 r
.49022 .64379 m .48805 .64186 L .49058 .64144 L F
.49022 .64379 m .48778 .64408 L .48805 .64186 L F
.913 .949 .808 r
.6509 .5072 m .65067 .50983 L .65262 .50701 L F
.847 .956 .613 r
.6509 .5072 m .64905 .51128 L .65067 .50983 L F
.537 .292 .491 r
.54724 .76584 m .54952 .7654 L .54983 .76321 L F
.489 .25 .478 r
.54983 .76321 m .54952 .7654 L .55204 .76283 L F
.537 .675 .927 r
.29802 .62649 m .29736 .62863 L .29581 .62716 L F
.29802 .62649 m .29927 .62827 L .29736 .62863 L F
.57 .364 .563 r
.39586 .66156 m .39792 .66372 L .39827 .66156 L F
.39586 .66156 m .39557 .66439 L .39792 .66372 L F
.498 .137 .285 r
.52935 .79159 m .53141 .79289 L .52901 .79341 L F
.52935 .79159 m .53318 .79066 L .53141 .79289 L F
.658 .452 .594 r
.46092 .69218 m .46336 .69266 L .46332 .6898 L F
.502 .273 .5 r
.46336 .69266 m .46552 .68931 L .46332 .6898 L F
.526 .559 .832 r
.47502 .78533 m .47566 .78187 L .47442 .78516 L F
.23 .385 .812 r
.65079 .48965 m .65215 .49263 L .65212 .49126 L F
0 0 .345 r
.65454 .49054 m .65251 .4948 L .65215 .49263 L F
.8 .605 .638 r
.52177 .78423 m .5228 .78312 L .5189 .78264 L F
.52177 .78423 m .52232 .7856 L .5228 .78312 L F
.534 .182 .317 r
.40848 .65837 m .41195 .65602 L .40863 .65591 L F
.40848 .65837 m .41086 .65819 L .41195 .65602 L F
.485 .037 .111 r
.41301 .65759 m .41195 .65602 L .41086 .65819 L F
.41301 .65759 m .41439 .65603 L .41195 .65602 L F
.268 .179 .566 r
.49951 .78843 m .50153 .79014 L .50185 .7886 L F
.123 .566 .921 r
.53311 .79966 m .53163 .79966 L .53083 .79898 L F
0 0 .384 r
.53163 .79966 m .53251 .80055 L .53311 .79966 L F
.53163 .79966 m .53209 .80243 L .53251 .80055 L F
.258 .05 .396 r
.59027 .71765 m .59172 .71735 L .59104 .71911 L F
.43 .758 .995 r
.36325 .59065 m .36251 .59182 L .36113 .59073 L F
.36325 .59065 m .36472 .59163 L .36251 .59182 L F
.57 .235 .362 r
.50213 .76568 m .50407 .76572 L .50576 .76311 L F
.688 .373 .438 r
.50576 .76311 m .50407 .76572 L .50796 .76507 L F
.604 .398 .575 r
.50576 .76311 m .50796 .76507 L .50815 .76289 L F
.252 0 .203 r
.61843 .50073 m .62069 .50011 L .62109 .49826 L F
.357 .149 .454 r
.62322 .4953 m .62109 .49826 L .62297 .49747 L F
.214 0 .191 r
.62109 .49826 m .62247 .49924 L .62297 .49747 L F
.62109 .49826 m .62069 .50011 L .62247 .49924 L F
.785 .957 .924 r
.47758 .63359 m .47805 .63168 L .47974 .63172 L F
.47758 .63359 m .47651 .63305 L .47805 .63168 L F
.381 .112 .376 r
.53919 .75458 m .54134 .7544 L .54069 .7531 L F
.576 .193 .279 r
.54069 .7531 m .54134 .7544 L .54356 .75401 L F
.564 .458 .692 r
.5559 .724 m .55841 .72345 L .55785 .72093 L F
.517 .427 .692 r
.39386 .66732 m .39557 .66439 L .39334 .66494 L F
.39386 .66732 m .3959 .6668 L .39557 .66439 L F
.43 .236 .513 r
.39378 .6696 m .3959 .6668 L .39386 .66732 L F
.809 .759 .806 r
.70703 .51502 m .70885 .51521 L .70798 .51099 L F
.69 .684 .839 r
.70798 .51099 m .70885 .51521 L .71146 .51199 L F
.45 .212 .46 r
.52852 .80223 m .52624 .80284 L .52591 .80496 L F
.91 .793 .719 r
.51361 .79992 m .51286 .80203 L .5145 .80252 L F
.754 .567 .643 r
.51171 .80454 m .51501 .805 L .51232 .80769 L F
.908 .644 .527 r
.51286 .80496 m .51501 .805 L .5145 .80252 L F
.999 .795 .467 r
.5145 .80252 m .51386 .79675 L .51361 .79992 L F
.908 .644 .527 r
.51286 .80496 m .51501 .805 L .5145 .80252 L F
.805 .348 .15 r
.51805 .80533 m .5145 .80252 L .51501 .805 L F
.43 .341 .653 r
.53919 .75458 m .5414 .75674 L .54134 .7544 L F
.847 .425 .229 r
.47702 .78746 m .47774 .78605 L .47502 .78533 L F
.992 .748 .455 r
.73844 .52244 m .73736 .52471 L .73731 .52143 L F
.214 .597 .948 r
.73952 .52177 m .73844 .52244 L .73731 .52143 L F
.289 .635 .964 r
.73875 .52068 m .73952 .52177 L .73731 .52143 L F
.973 .709 .294 r
.73875 .52076 m .73952 .52177 L .73875 .52068 L F
.214 .597 .948 r
.73952 .52177 m .74031 .52282 L .73844 .52244 L F
0 0 0 r
.73952 .52177 m .73844 .52244 L .7405 .52286 L F
.73952 .52177 m .73736 .52471 L .73844 .52244 L F
.73892 .52288 m .73736 .52471 L .73861 .523 L F
.73892 .52288 m .73861 .523 L .73952 .52177 L F
.973 .709 .294 r
.73892 .52288 m .73952 .52177 L .73875 .52076 L F
.455 0 0 r
.73926 .52274 m .73892 .52288 L .7385 .5218 L F
.74025 .52395 m .73892 .52288 L .73926 .52274 L F
.214 .597 .948 r
.73952 .52177 m .7405 .52286 L .74031 .52282 L F
.772 .754 .836 r
.691 .50962 m .69167 .51234 L .68879 .51143 L F
.974 .711 .471 r
.69167 .51234 m .69132 .51465 L .68879 .51143 L F
.69167 .51234 m .6922 .51515 L .69132 .51465 L F
.576 .628 .866 r
.69387 .51166 m .69167 .51234 L .691 .50962 L F
.41 .348 .677 r
.69418 .51455 m .69167 .51234 L .69387 .51166 L F
.69418 .51455 m .6922 .51515 L .69167 .51234 L F
.951 .821 .679 r
.63591 .52838 m .63842 .52606 L .63746 .52509 L F
.63591 .52838 m .63724 .52946 L .63842 .52606 L F
.936 .919 .771 r
.63937 .52164 m .63746 .52509 L .63842 .52606 L F
.741 .987 .894 r
.48095 .81557 m .48453 .81384 L .48314 .81509 L F
.6 .952 .852 r
.48487 .81303 m .48453 .81384 L .48607 .81273 L F
.676 .915 .59 r
.48314 .81509 m .48453 .81384 L .48487 .81303 L F
.698 .638 .786 r
.67357 .52226 m .67592 .52097 L .67253 .52001 L F
.303 .608 .953 r
.50589 .64171 m .50672 .64042 L .50374 .6395 L F
.072 .29 .776 r
.50589 .64171 m .50773 .64272 L .50672 .64042 L F
.858 .787 .781 r
.67878 .52309 m .67604 .52304 L .6782 .51984 L F
.729 .593 .704 r
.58588 .71509 m .58719 .71847 L .58626 .71688 L F
.958 .815 .659 r
.62627 .52027 m .62531 .52295 L .62486 .51977 L F
.476 .847 .989 r
.62486 .51977 m .62727 .51921 L .62627 .52027 L F
.385 .483 .837 r
.74396 .48691 m .7468 .48829 L .74527 .48988 L F
.975 .683 .297 r
.74473 .4912 m .74564 .49229 L .74527 .48988 L F
.74473 .4912 m .74527 .48988 L .7468 .48829 L F
.639 .81 .965 r
.5537 .63359 m .55097 .63383 L .54986 .63321 L F
.677 .441 .556 r
.5537 .63359 m .55339 .63626 L .55097 .63383 L F
.828 .768 .796 r
.70175 .50624 m .69881 .50619 L .70093 .5035 L F
.739 .721 .835 r
.70416 .50417 m .70175 .50624 L .70093 .5035 L F
.082 0 .07 r
.62576 .49273 m .62322 .4953 L .625 .4943 L F
.039 0 0 r
.625 .4943 m .62798 .49201 L .62576 .49273 L F
0 0 .002 r
.54993 .61885 m .54768 .62175 L .54885 .61978 L F
.318 .5 .879 r
.38361 .59777 m .38638 .59916 L .38525 .59961 L F
.551 .54 .795 r
.38638 .59916 m .38496 .60146 L .38525 .59961 L F
.476 .059 .169 r
.47577 .76761 m .47782 .76553 L .47527 .76539 L F
.47577 .76761 m .47771 .7677 L .47782 .76553 L F
.739 .972 .713 r
.54769 .62651 m .54506 .62918 L .54689 .62806 L F
.459 .758 .994 r
.24903 .63605 m .25096 .63575 L .24961 .63466 L F
.24903 .63605 m .25096 .63575 L .24961 .63466 L F
.618 .671 .879 r
.52008 .64346 m .51803 .64474 L .51666 .6424 L F
.348 .232 .577 r
.52008 .64346 m .51906 .64764 L .51803 .64474 L F
.633 .676 .873 r
.56639 .72286 m .56773 .72564 L .56972 .72503 L F
.783 .537 .564 r
.50692 .77348 m .50933 .77319 L .5105 .77156 L F
.464 .377 .673 r
.51173 .7772 m .51433 .77921 L .51407 .7764 L F
.51 .372 .629 r
.51198 .77997 m .51433 .77921 L .51173 .7772 L F
.668 .723 .891 r
.68997 .53214 m .69246 .53376 L .69203 .53089 L F
.664 .669 .844 r
.69203 .53089 m .69246 .53376 L .69553 .5319 L F
.551 .378 .6 r
.41907 .67568 m .41905 .67819 L .41668 .67862 L F
.565 .432 .658 r
.41905 .67819 m .41714 .68101 L .41668 .67862 L F
.526 .035 .033 r
.48859 .69788 m .48754 .69918 L .4852 .6981 L F
.63 .232 .271 r
.49097 .69781 m .48754 .69918 L .48859 .69788 L F
.879 .451 .172 r
.48076 .8019 m .48228 .80248 L .48319 .80434 L F
.562 .157 .232 r
.5361 .76912 m .53813 .7705 L .5392 .76849 L F
.779 .551 .589 r
.53813 .7705 m .5416 .76838 L .5392 .76849 L F
.33 .534 .902 r
.72739 .47953 m .72626 .48092 L .72447 .47835 L F
.847 .956 .613 r
.6509 .5072 m .64882 .51073 L .64905 .51128 L F
.929 .825 .722 r
.62182 .52693 m .62026 .52769 L .6203 .52543 L F
.605 .567 .786 r
.57315 .71191 m .57313 .71356 L .57124 .71428 L F
.598 .522 .74 r
.57441 .717 m .57124 .71428 L .57313 .71356 L F
.677 .612 .776 r
.56075 .62502 m .558 .62819 L .55725 .62438 L F
.869 .425 .062 r
.55872 .62992 m .55746 .62917 L .558 .62819 L F
.701 .65 .796 r
.56075 .62502 m .56159 .62792 L .558 .62819 L F
.812 .621 .644 r
.56159 .62792 m .55872 .62992 L .558 .62819 L F
.575 .34 .522 r
.6358 .48394 m .63938 .4852 L .63799 .48376 L F
.6358 .48394 m .6379 .48556 L .63938 .4852 L F
.98 .868 .492 r
.72805 .50642 m .72847 .50663 L .7272 .50563 L F
.72805 .50642 m .72818 .50817 L .72847 .50663 L F
.888 .472 .2 r
.54127 .62761 m .53975 .62697 L .53876 .62503 L F
.72 .214 0 r
.54127 .62761 m .54187 .62905 L .53975 .62697 L F
.54127 .62761 m .5432 .63006 L .54187 .62905 L F
.608 .934 .958 r
.65319 .48413 m .65456 .48272 L .65569 .48258 L F
.051 .503 .89 r
.65319 .48413 m .65449 .48341 L .65456 .48272 L F
.65319 .48413 m .65783 .4857 L .65449 .48341 L F
.897 .724 .659 r
.72611 .51415 m .72754 .51518 L .72631 .51183 L F
.903 .754 .687 r
.55113 .6247 m .55248 .62768 L .55068 .62692 L F
.813 .764 .251 r
.55014 .63064 m .55068 .62692 L .55248 .62768 L F
.567 .566 .812 r
.5534 .62409 m .55248 .62768 L .55113 .6247 L F
.5534 .62409 m .55503 .62737 L .55248 .62768 L F
.528 .32 .541 r
.55248 .62768 m .55469 .62969 L .55503 .62737 L F
.55248 .62768 m .55469 .62969 L .55503 .62737 L F
.744 .401 .401 r
.5491 .63195 m .5537 .63359 L .54986 .63321 L F
.646 .87 .982 r
.55458 .63166 m .5537 .63359 L .55587 .63261 L F
0 0 .166 r
.5541 .63419 m .5537 .63359 L .55458 .63166 L F
.5541 .63419 m .55339 .63626 L .5537 .63359 L F
.744 .401 .401 r
.5491 .63195 m .54986 .63321 L .55014 .63064 L F
.514 .244 .442 r
.55439 .77406 m .55682 .77142 L .55442 .77155 L F
.768 .602 .673 r
.55682 .77142 m .55439 .77406 L .55442 .77155 L F
.475 0 0 r
.45979 .70029 m .45867 .70102 L .45636 .70075 L F
.261 0 0 r
.46223 .70016 m .45867 .70102 L .45979 .70029 L F
.537 .341 .563 r
.24614 .65571 m .24684 .6532 L .24339 .65277 L F
.24614 .65571 m .24673 .65617 L .24684 .6532 L F
.515 .323 .559 r
.24684 .6532 m .24882 .65524 L .24869 .65363 L F
.103 .411 .861 r
.53911 .7403 m .54253 .74224 L .54143 .74181 L F
.437 .05 .206 r
.45158 .69477 m .45382 .69449 L .45504 .69235 L F
.539 .156 .262 r
.45504 .69235 m .4574 .69344 L .45743 .69215 L F
.45504 .69235 m .45382 .69449 L .4574 .69344 L F
.026 0 .322 r
.26215 .62804 m .26282 .62928 L .26332 .62763 L F
.26215 .62804 m .26183 .63045 L .26282 .62928 L F
.907 .923 .816 r
.58835 .7113 m .58588 .71509 L .58466 .71418 L F
.27 .329 .74 r
.51577 .64055 m .51444 .64241 L .51354 .63869 L F
.471 .608 .906 r
.51577 .64055 m .51666 .6424 L .51444 .64241 L F
.528 .295 .505 r
.37558 .61097 m .37528 .61317 L .37307 .61359 L F
.406 .167 .435 r
.37767 .61033 m .37528 .61317 L .37558 .61097 L F
.675 .72 .883 r
.71839 .51678 m .71959 .51861 L .72185 .51757 L F
.405 .261 .571 r
.25378 .60559 m .25548 .60539 L .25581 .602 L F
.344 .274 .634 r
.25437 .60792 m .25548 .60539 L .25378 .60559 L F
0 0 .312 r
.55014 .63064 m .5512 .63168 L .55008 .62986 L F
.633 .597 .796 r
.5512 .63168 m .54982 .63067 L .55008 .62986 L F
.54982 .63067 m .54762 .62904 L .55008 .62986 L F
.813 .764 .251 r
.55041 .6288 m .55008 .62986 L .55068 .62692 L F
.55014 .63064 m .55008 .62986 L .55041 .6288 L F
0 0 .312 r
.55014 .63064 m .54986 .63321 L .5512 .63168 L F
.535 .29 .49 r
.58334 .60813 m .58327 .61021 L .58089 .6105 L F
.592 .336 .498 r
.58334 .60813 m .58572 .61007 L .58327 .61021 L F
.589 .337 .503 r
.58577 .60794 m .58572 .61007 L .58334 .60813 L F
.775 .952 .931 r
.48866 .79773 m .49189 .7962 L .49096 .79875 L F
.71 .516 .625 r
.49337 .80232 m .49578 .80218 L .49211 .79981 L F
.49337 .80232 m .49211 .79981 L .49271 .7986 L F
.206 0 .351 r
.49271 .7986 m .4901 .80298 L .49337 .80232 L F
.53 .174 .309 r
.49189 .7962 m .49379 .79878 L .49096 .79875 L F
.49189 .7962 m .49487 .79626 L .49379 .79878 L F
.728 .453 .512 r
.49606 .80502 m .49938 .80321 L .49578 .80218 L F
.49606 .80502 m .49935 .80516 L .49938 .80321 L F
.656 .394 .511 r
.49938 .80321 m .50167 .80409 L .50205 .80276 L F
.49938 .80321 m .49935 .80516 L .50167 .80409 L F
.321 .022 .293 r
.48426 .78564 m .48179 .78839 L .4841 .78808 L F
.823 .998 .78 r
.66588 .47606 m .66417 .47819 L .66458 .47649 L F
.485 .338 .606 r
.66483 .47912 m .66417 .47819 L .66543 .47848 L F
.66483 .47912 m .66458 .47649 L .66417 .47819 L F
.609 .042 0 r
.65916 .48598 m .66201 .48827 L .66235 .48773 L F
.339 0 0 r
.66235 .48773 m .66201 .48827 L .66469 .48837 L F
.85 .998 .814 r
.69727 .51218 m .69418 .51455 L .69641 .51123 L F
.69727 .51218 m .6942 .51544 L .69418 .51455 L F
.413 .329 .652 r
.29199 .62279 m .29231 .6244 L .29063 .6245 L F
.225 .637 .956 r
.29928 .64981 m .29927 .64938 L .29443 .64818 L F
.255 0 0 r
.302 .64937 m .30066 .65002 L .29928 .64981 L F
.159 .451 .881 r
.29928 .64981 m .30066 .65002 L .29964 .64859 L F
.443 .436 .756 r
.3908 .68093 m .39354 .68385 L .39284 .68068 L F
.727 .67 .795 r
.25655 .61946 m .25838 .62276 L .26038 .62168 L F
.636 .728 .915 r
.75399 .59692 m .75757 .59753 L .75651 .59679 L F
.281 0 0 r
.75933 .59643 m .75651 .59679 L .75757 .59753 L F
.456 .05 .181 r
.44759 .66069 m .4441 .66307 L .44606 .6622 L F
.667 .454 .586 r
.56653 .62212 m .56625 .62482 L .56274 .62447 L F
.685 .469 .588 r
.56879 .62463 m .56653 .62212 L .56868 .62188 L F
.56879 .62463 m .56625 .62482 L .56653 .62212 L F
.191 0 0 r
.49608 .81446 m .49698 .81522 L .49471 .81465 L F
.524 .297 .512 r
.6051 .59962 m .60728 .60147 L .60491 .60189 L F
.628 .262 .329 r
.6051 .59962 m .60813 .60003 L .60728 .60147 L F
.975 .921 .616 r
.65728 .50112 m .65587 .50232 L .6561 .49997 L F
.686 .709 .865 r
.75854 .59106 m .75609 .59189 L .75495 .59054 L F
.448 .27 .546 r
.51474 .79161 m .51717 .79072 L .51701 .78845 L F
.689 .821 .946 r
.77024 .60381 m .77175 .60133 L .76926 .60173 L F
.77024 .60381 m .77307 .60242 L .77175 .60133 L F
.812 .621 .644 r
.56159 .62792 m .56167 .6305 L .55872 .62992 L F
.695 .599 .744 r
.56274 .62447 m .56159 .62792 L .56075 .62502 L F
.56274 .62447 m .56405 .62769 L .56159 .62792 L F
.686 .521 .658 r
.56405 .62769 m .56167 .6305 L .56159 .62792 L F
.678 .66 .825 r
.26298 .6456 m .25931 .64438 L .26142 .6441 L F
.067 .312 .795 r
.2845 .6436 m .2863 .64512 L .28499 .64239 L F
.2863 .64512 m .28709 .64579 L .28659 .64499 L F
.2863 .64512 m .28659 .64499 L .28499 .64239 L F
0 0 0 r
.28551 .64547 m .28347 .64766 L .28501 .64641 L F
.28594 .64466 m .28514 .64563 L .28551 .64547 L F
.28514 .64563 m .28347 .64766 L .28551 .64547 L F
.328 .349 .731 r
.28347 .64766 m .28547 .64892 L .28501 .64641 L F
.94 .862 .736 r
.50938 .78819 m .51047 .78621 L .51006 .7856 L F
.50938 .78819 m .51006 .7856 L .50949 .78622 L F
0 0 .321 r
.50985 .79026 m .50938 .78819 L .50933 .78605 L F
0 0 .448 r
.51026 .79029 m .50985 .79026 L .50933 .78605 L F
.712 .441 .513 r
.50639 .79005 m .51026 .79029 L .50939 .78633 L F
.50807 .78777 m .50939 .78633 L .50933 .78605 L F
.50639 .79005 m .50939 .78633 L .50807 .78777 L F
.94 .862 .736 r
.50949 .78622 m .51006 .7856 L .50957 .78488 L F
.705 .86 .956 r
.66318 .50696 m .66162 .50945 L .66423 .50827 L F
0 0 .143 r
.66192 .51004 m .66162 .50945 L .66318 .50696 L F
.66192 .51004 m .6618 .51188 L .66162 .50945 L F
.75 .654 .755 r
.55723 .63863 m .55854 .64195 L .55467 .64158 L F
.94 .625 .413 r
.55854 .64195 m .55456 .64412 L .55467 .64158 L F
.55854 .64195 m .55717 .64337 L .55456 .64412 L F
.55854 .64195 m .55883 .64461 L .55717 .64337 L F
0 0 .055 r
.56004 .63874 m .55854 .64195 L .55723 .63863 L F
.56004 .63874 m .55971 .64045 L .55854 .64195 L F
.94 .625 .413 r
.55717 .64337 m .55854 .64195 L .55971 .64045 L F
.55717 .64337 m .55883 .64461 L .55854 .64195 L F
.335 0 .054 r
.46561 .69221 m .46893 .69003 L .46552 .68931 L F
.46561 .69221 m .4682 .6916 L .46893 .69003 L F
.506 .06 .124 r
.46893 .69003 m .4682 .6916 L .47102 .69105 L F
.662 .276 0 r
.51588 .78219 m .5149 .78024 L .51433 .77921 L F
.799 .716 .772 r
.53409 .60856 m .52991 .61011 L .53225 .60714 L F
.53409 .60856 m .53179 .61138 L .52991 .61011 L F
.791 .725 .791 r
.53617 .60592 m .53409 .60856 L .53225 .60714 L F
.896 .596 .47 r
.56349 .75054 m .56505 .74863 L .563 .74859 L F
.56349 .75054 m .56589 .7507 L .56505 .74863 L F
.944 .696 .533 r
.56589 .7507 m .56564 .74882 L .56505 .74863 L F
.548 .609 .866 r
.40129 .70102 m .4016 .69738 L .39971 .6978 L F
.40129 .70102 m .40323 .70059 L .4016 .69738 L F
.433 .281 .574 r
.40152 .703 m .40323 .70059 L .40129 .70102 L F
.957 .691 .49 r
.25279 .66725 m .25291 .67019 L .2521 .66893 L F
.777 .626 .693 r
.39583 .6953 m .39708 .69548 L .39622 .69258 L F
.441 .424 .744 r
.39622 .69258 m .39708 .69548 L .39859 .69475 L F
.602 .475 .68 r
.39708 .69548 m .39971 .6978 L .39859 .69475 L F
.39708 .69548 m .39719 .6983 L .39971 .6978 L F
.734 .691 .809 r
.55158 .79071 m .55474 .78999 L .55481 .78868 L F
.723 .694 .822 r
.55474 .78999 m .5565 .78684 L .55481 .78868 L F
.55474 .78999 m .55821 .78882 L .5565 .78684 L F
.309 .728 .975 r
.34349 .58925 m .34621 .58907 L .34768 .58987 L F
.185 .673 .924 r
.34621 .58907 m .34977 .58982 L .34768 .58987 L F
.464 .449 .757 r
.66551 .51149 m .66761 .51267 L .66614 .50812 L F
.468 .282 .544 r
.29652 .61377 m .29584 .61572 L .29447 .61615 L F
.463 .221 .461 r
.29584 .61572 m .29412 .61827 L .29447 .61615 L F
.389 .612 .939 r
.37614 .59519 m .37536 .59671 L .37424 .59507 L F
.443 .678 .964 r
.37614 .59519 m .37742 .59671 L .37536 .59671 L F
.511 .05 .095 r
.44974 .6454 m .45197 .64625 L .45335 .6447 L F
0 0 0 r
.45335 .6447 m .45398 .64498 L .45561 .64431 L F
.45335 .6447 m .45197 .64625 L .45398 .64498 L F
.575 .721 .942 r
.69587 .47048 m .69467 .47257 L .69356 .47134 L F
.69587 .47048 m .69701 .47205 L .69467 .47257 L F
.588 .201 .277 r
.46797 .69836 m .46691 .70048 L .46434 .7002 L F
.325 0 .033 r
.4703 .69838 m .46691 .70048 L .46797 .69836 L F
.768 .602 .673 r
.55682 .77142 m .55864 .77286 L .55439 .77406 L F
.335 0 0 r
.55439 .77406 m .55864 .77286 L .55665 .774 L F
.677 .62 .785 r
.55756 .7716 m .55864 .77286 L .55682 .77142 L F
.927 .6 .141 r
.55864 .77286 m .55862 .77579 L .55665 .774 L F
.55864 .77286 m .55941 .77667 L .55862 .77579 L F
.18 0 0 r
.43442 .70625 m .4331 .70744 L .43094 .70785 L F
.363 0 0 r
.43673 .70592 m .4331 .70744 L .43442 .70625 L F
0 .455 .712 r
.57674 .7259 m .57565 .72563 L .57346 .72515 L F
.533 .904 .958 r
.57778 .72485 m .57674 .7259 L .57917 .72538 L F
.57778 .72485 m .57565 .72563 L .57674 .7259 L F
.311 .344 .735 r
.74784 .49375 m .74639 .4957 L .74564 .49229 L F
0 .097 .64 r
.74771 .49589 m .74639 .4957 L .74784 .49375 L F
.74771 .49589 m .74738 .49766 L .74639 .4957 L F
.178 0 0 r
.34403 .63991 m .34334 .63878 L .34525 .63814 L F
.34403 .63991 m .34203 .64065 L .34334 .63878 L F
.537 0 0 r
.51664 .64924 m .51511 .6491 L .51439 .64934 L F
.821 .34 .021 r
.51439 .64934 m .5114 .64621 L .51177 .64757 L F
.233 .399 .823 r
.51295 .64983 m .51439 .64934 L .51177 .64757 L F
.821 .34 .021 r
.51439 .64934 m .51311 .6489 L .5114 .64621 L F
.537 0 0 r
.51511 .6491 m .51311 .6489 L .51439 .64934 L F
.233 .399 .823 r
.51331 .65053 m .51439 .64934 L .51295 .64983 L F
.433 .71 .982 r
.51331 .65053 m .51564 .65028 L .51439 .64934 L F
.564 .321 .507 r
.6017 .58794 m .60397 .58518 L .60214 .58589 L F
.254 0 .043 r
.26544 .59096 m .26607 .59226 L .26759 .59043 L F
.26544 .59096 m .26407 .59284 L .26607 .59226 L F
.31 0 0 r
.30474 .58428 m .30664 .58487 L .30824 .5851 L F
.111 .656 .832 r
.30664 .58487 m .31035 .5851 L .30824 .5851 L F
.392 .842 .92 r
.31722 .64849 m .32195 .64824 L .31962 .64835 L F
.143 .688 .752 r
.3242 .64783 m .31962 .64835 L .32195 .64824 L F
.427 .825 .613 r
.52629 .7813 m .52745 .78052 L .52898 .77945 L F
.924 .648 .499 r
.78363 .5921 m .78512 .59106 L .78329 .59456 L F
.78363 .5921 m .7853 .59351 L .78512 .59106 L F
.421 .461 .796 r
.42069 .68837 m .41885 .68982 L .41786 .68671 L F
.432 .374 .692 r
.42069 .68837 m .4192 .69244 L .41885 .68982 L F
.374 .479 .839 r
.69965 .48097 m .70054 .47782 L .69937 .4798 L F
.69965 .48097 m .70131 .48108 L .70054 .47782 L F
.379 .467 .825 r
.69965 .48097 m .70209 .48227 L .70131 .48108 L F
.158 .045 .464 r
.61343 .50631 m .61385 .50855 L .61396 .50577 L F
.604 .461 .66 r
.47392 .79189 m .47567 .79156 L .47565 .78849 L F
0 0 0 r
.26367 .64541 m .26143 .64653 L .26314 .64574 L F
.541 .509 .769 r
.40362 .71286 m .40449 .70855 L .4022 .70907 L F
.40362 .71286 m .40558 .7122 L .40449 .70855 L F
.897 .915 .826 r
.39432 .70493 m .39281 .70603 L .39462 .70355 L F
.065 0 0 r
.31405 .60229 m .3103 .60393 L .31203 .60273 L F
.776 .703 .783 r
.54528 .59654 m .54628 .59964 L .54281 .5994 L F
.171 .527 .921 r
.27536 .64098 m .2764 .64222 L .27824 .64269 L F
.572 .846 .996 r
.6855 .47278 m .68785 .4721 L .68885 .47297 L F
.59 .853 .994 r
.68885 .47297 m .6902 .47134 L .69122 .47229 L F
.68885 .47297 m .68785 .4721 L .6902 .47134 L F
0 0 0 r
.61553 .59399 m .61237 .59637 L .61408 .59458 L F
.61553 .59399 m .6139 .5953 L .61237 .59637 L F
.709 .947 .653 r
.61643 .59242 m .6139 .5953 L .61553 .59399 L F
.6 .319 .464 r
.39792 .66372 m .4003 .66359 L .39827 .66156 L F
.586 .464 .68 r
.39827 .66156 m .40054 .66107 L .40016 .65868 L F
.542 .322 .531 r
.39827 .66156 m .4003 .66359 L .40054 .66107 L F
.877 .651 .593 r
.53179 .61138 m .52971 .61287 L .52991 .61011 L F
.875 .646 .589 r
.53196 .61336 m .52971 .61287 L .53179 .61138 L F
.098 0 .267 r
.62297 .49747 m .625 .4943 L .62322 .4953 L F
.697 .662 .811 r
.69309 .5203 m .69058 .52252 L .68959 .5198 L F
.596 .491 .705 r
.55706 .71775 m .55874 .71738 L .55655 .71559 L F
.401 .15 .415 r
.5755 .7068 m .57528 .70929 L .57307 .70938 L F
.65 .424 .564 r
.57549 .71136 m .57307 .70938 L .57528 .70929 L F
.57549 .71136 m .57315 .71191 L .57307 .70938 L F
.423 .14 .376 r
.37076 .61626 m .37004 .6188 L .36831 .61917 L F
.491 .284 .527 r
.37307 .61359 m .37288 .61574 L .37076 .61626 L F
.481 .209 .423 r
.37288 .61574 m .37004 .6188 L .37076 .61626 L F
.476 .087 .222 r
.44368 .69558 m .44564 .69655 L .44706 .69443 L F
.445 .015 .126 r
.44564 .69655 m .4492 .69468 L .44706 .69443 L F
.785 .714 .786 r
.5194 .80606 m .5213 .80859 L .51819 .80777 L F
.71 .215 .064 r
.51819 .80777 m .5213 .80859 L .52015 .80941 L F
.336 0 0 r
.5213 .80859 m .52243 .80976 L .52015 .80941 L F
.444 .156 .38 r
.30362 .60748 m .30098 .60971 L .30158 .60786 L F
.551 .54 .795 r
.38638 .59916 m .38783 .60167 L .38496 .60146 L F
.533 .378 .616 r
.38783 .60167 m .38554 .60429 L .38496 .60146 L F
.955 .666 .447 r
.53353 .6167 m .53207 .61591 L .53196 .61336 L F
.927 .688 .556 r
.53353 .6167 m .53161 .61791 L .53207 .61591 L F
.53353 .6167 m .53313 .6188 L .53161 .61791 L F
.966 .754 .314 r
.56726 .75945 m .56779 .76258 L .56826 .7601 L F
0 0 0 r
.61289 .56861 m .61412 .56713 L .6148 .56563 L F
.61289 .56861 m .61306 .56885 L .61412 .56713 L F
.61289 .56861 m .61245 .57059 L .61306 .56885 L F
.06 .611 .829 r
.34143 .58855 m .34621 .58907 L .34349 .58925 L F
.739 .591 .691 r
.27038 .77538 m .27096 .7743 L .27016 .77427 L F
0 0 .331 r
.52405 .77674 m .52511 .77923 L .52406 .77626 L F
.546 .27 .447 r
.57764 .70872 m .5755 .7068 L .57776 .70648 L F
.57764 .70872 m .57528 .70929 L .5755 .7068 L F
.816 .579 .58 r
.25007 .6246 m .25198 .62725 L .25258 .62502 L F
.65 .423 .561 r
.4217 .67561 m .41905 .67819 L .41907 .67568 L F
.4217 .67561 m .42171 .678 L .41905 .67819 L F
.519 .335 .572 r
.42369 .67415 m .42171 .678 L .4217 .67561 L F
.696 .764 .904 r
.55074 .75634 m .55311 .75665 L .55276 .75594 L F
.606 .514 .724 r
.55415 .75145 m .55332 .75586 L .55196 .75078 L F
.58 .489 .716 r
.55332 .75586 m .5555 .75373 L .55415 .75145 L F
.701 .742 .883 r
.55311 .75665 m .5555 .75373 L .55276 .75594 L F
.323 .762 .966 r
.33876 .58832 m .33831 .58867 L .33714 .58807 L F
.33876 .58832 m .34007 .58854 L .33831 .58867 L F
.539 .659 .914 r
.68922 .47679 m .68997 .47851 L .69147 .47653 L F
.457 .541 .854 r
.68997 .47851 m .69236 .47859 L .69147 .47653 L F
.679 .51 .651 r
.56436 .6302 m .56167 .6305 L .56405 .62769 L F
.607 .509 .717 r
.56625 .62482 m .56405 .62769 L .56274 .62447 L F
.56625 .62482 m .5666 .62729 L .56405 .62769 L F
.65 .525 .699 r
.5666 .62729 m .56436 .6302 L .56405 .62769 L F
.957 .902 .728 r
.72631 .51183 m .72818 .50817 L .72805 .50642 L F
.894 .472 .152 r
.55783 .74314 m .55987 .74545 L .55937 .74385 L F
.676 .624 .789 r
.55723 .63863 m .55519 .637 L .55714 .6362 L F
.652 .97 .873 r
.55714 .6362 m .55519 .637 L .55667 .6359 L F
.597 .396 .579 r
.56017 .63591 m .55723 .63863 L .55714 .6362 L F
.46 .385 .686 r
.28501 .64641 m .2845 .6436 L .28594 .64466 L F
.582 .446 .661 r
.57065 .61899 m .56838 .61983 L .57041 .61889 L F
.45 .861 .958 r
.31035 .5851 m .31244 .58452 L .31421 .58475 L F
0 .428 .78 r
.31447 .58457 m .31421 .58475 L .31244 .58452 L F
.31447 .58457 m .31604 .58536 L .31421 .58475 L F
.387 .149 .427 r
.61764 .50275 m .62069 .50011 L .61843 .50073 L F
.393 .364 .708 r
.39622 .69258 m .39728 .68896 L .39546 .68934 L F
.39622 .69258 m .39793 .69226 L .39728 .68896 L F
.402 .417 .762 r
.39622 .69258 m .39859 .69475 L .39793 .69226 L F
0 0 0 r
.52571 .79568 m .52716 .7942 L .52901 .79341 L F
.638 .717 .905 r
.48313 .79637 m .48649 .79724 L .48595 .79549 L F
.867 .634 .583 r
.48341 .79837 m .48649 .79724 L .48313 .79637 L F
.48341 .79837 m .4865 .79935 L .48649 .79724 L F
.515 .636 .907 r
.48595 .79549 m .48649 .79724 L .48894 .79512 L F
.506 .872 .645 r
.4865 .79935 m .48894 .79512 L .48649 .79724 L F
.414 .393 .727 r
.40223 .70665 m .40311 .70298 L .40152 .703 L F
.40223 .70665 m .40427 .70673 L .40311 .70298 L F
.415 .384 .716 r
.40223 .70665 m .40449 .70855 L .40427 .70673 L F
.568 .379 .586 r
.40223 .70665 m .4022 .70907 L .40449 .70855 L F
.879 .506 .332 r
.55987 .74545 m .563 .74859 L .56258 .7463 L F
.727 .815 .92 r
.55936 .77881 m .56205 .77758 L .56167 .77543 L F
.55936 .77881 m .56167 .77543 L .56023 .77887 L F
0 0 0 r
.55941 .77667 m .55936 .77881 L .56023 .77887 L F
.434 .121 .334 r
.54343 .73472 m .54455 .73643 L .54573 .73451 L F
.54343 .73472 m .54283 .73695 L .54455 .73643 L F
.502 .273 .5 r
.46336 .69266 m .46561 .69221 L .46552 .68931 L F
.743 .638 .744 r
.64537 .48618 m .64718 .48631 L .64583 .48325 L F
.305 0 .226 r
.64537 .48618 m .64645 .4876 L .64718 .48631 L F
.74 .637 .745 r
.64583 .48325 m .64718 .48631 L .64787 .48424 L F
.865 .84 .819 r
.55166 .78971 m .55158 .79071 L .55182 .78836 L F
.851 .725 .724 r
.66237 .49166 m .66578 .48947 L .66469 .48837 L F
.66237 .49166 m .66452 .4926 L .66578 .48947 L F
.727 .67 .795 r
.25655 .61946 m .26038 .62168 L .25881 .61871 L F
.542 .549 .812 r
.26038 .62168 m .26148 .61852 L .25881 .61871 L F
.26038 .62168 m .26242 .62126 L .26148 .61852 L F
.512 .534 .816 r
.26038 .62168 m .26372 .62475 L .26242 .62126 L F
.619 .593 .802 r
.51748 .65592 m .52007 .65526 L .51667 .65368 L F
.51748 .65592 m .52066 .65608 L .52007 .65526 L F
.687 .529 .667 r
.51748 .65592 m .5204 .65852 L .52066 .65608 L F
.51748 .65592 m .51817 .65911 L .5204 .65852 L F
.574 .747 .959 r
.69703 .4803 m .6971 .4775 L .69466 .47779 L F
.69703 .4803 m .69937 .4798 L .6971 .4775 L F
.598 .133 .121 r
.33513 .60152 m .33805 .60163 L .33711 .60122 L F
.33513 .60152 m .33542 .60177 L .33805 .60163 L F
.245 .752 .878 r
.34027 .6011 m .33711 .60122 L .33805 .60163 L F
.153 .655 .909 r
.55921 .76573 m .55768 .76512 L .55553 .76498 L F
.293 .21 .589 r
.55921 .76573 m .55959 .76889 L .56085 .76763 L F
.459 0 0 r
.56085 .76763 m .55768 .76512 L .55921 .76573 L F
.895 .88 .812 r
.73626 .51664 m .73935 .51514 L .73818 .5148 L F
.73626 .51664 m .73692 .51806 L .73935 .51514 L F
.754 .463 .491 r
.74387 .51387 m .74057 .51387 L .74134 .51172 L F
.46 .805 .998 r
.74057 .51387 m .74234 .51263 L .7417 .51282 L F
0 0 0 r
.74134 .51172 m .74057 .51387 L .73952 .51486 L F
.46 .805 .998 r
.74057 .51387 m .7417 .51282 L .73924 .51353 L F
0 0 0 r
.73952 .51486 m .74057 .51387 L .73935 .51514 L F
.561 .913 .964 r
.74057 .51387 m .73818 .5148 L .73935 .51514 L F
.56 .319 .508 r
.49912 .7741 m .49877 .77672 L .50153 .77434 L F
.645 .306 .384 r
.52425 .76862 m .52664 .77034 L .52763 .76835 L F
.44 .052 .206 r
.52664 .77034 m .53007 .76809 L .52763 .76835 L F
.193 .076 .483 r
.54004 .78635 m .53744 .7888 L .53991 .78858 L F
.653 .894 .554 r
.53991 .78858 m .54247 .78555 L .54004 .78635 L F
.559 .902 .977 r
.26464 .63184 m .26277 .63314 L .26535 .63223 L F
.687 .791 .929 r
.26531 .63995 m .26725 .6402 L .26581 .6386 L F
.44 .5 .824 r
.26725 .6402 m .26846 .63811 L .26581 .6386 L F
.26725 .6402 m .27018 .64142 L .26846 .63811 L F
.396 .096 .334 r
.33736 .62447 m .33857 .62659 L .3395 .62415 L F
.33736 .62447 m .33647 .62713 L .33857 .62659 L F
.342 .098 .392 r
.30025 .61233 m .29889 .61065 L .30098 .60971 L F
.30025 .61233 m .29866 .61298 L .29889 .61065 L F
.502 .498 .785 r
.25564 .61331 m .25644 .60968 L .25466 .61036 L F
.25564 .61331 m .25753 .61301 L .25644 .60968 L F
.406 0 0 r
.44274 .70434 m .44128 .70578 L .43896 .70577 L F
.207 0 0 r
.44496 .70416 m .44128 .70578 L .44274 .70434 L F
.978 .805 .392 r
.63191 .56302 m .63122 .56444 L .63167 .5655 L F
.642 .774 .311 r
.63255 .56167 m .63122 .56444 L .63191 .56302 L F
.394 .485 .834 r
.39354 .68385 m .39495 .68695 L .39656 .68659 L F
.377 .379 .735 r
.39495 .68695 m .39728 .68896 L .39656 .68659 L F
.468 .386 .681 r
.39546 .68934 m .39728 .68896 L .39495 .68695 L F
.973 .72 .49 r
.63477 .53076 m .63682 .53342 L .63627 .53115 L F
.63477 .53076 m .6345 .5321 L .63682 .53342 L F
.988 .879 .627 r
.6345 .5321 m .63434 .53662 L .63682 .53342 L F
.847 .661 .65 r
.63682 .53342 m .63434 .53662 L .63758 .53703 L F
.915 .612 .128 r
.63203 .511 m .63258 .5117 L .63157 .50857 L F
.63157 .50857 m .63258 .5117 L .63203 .511 L F
.63258 .5117 m .63277 .51229 L .63203 .511 L F
.941 .638 .436 r
.63157 .50857 m .63043 .5103 L .63203 .511 L F
.452 .802 .998 r
.63203 .511 m .63043 .5103 L .63157 .50857 L F
.954 .716 .539 r
.63203 .511 m .63043 .5103 L .6314 .51019 L F
.452 .802 .998 r
.63203 .511 m .63157 .50857 L .63396 .50831 L F
.915 .612 .128 r
.63157 .50857 m .63203 .511 L .63396 .50831 L F
.954 .716 .539 r
.63203 .511 m .6314 .51019 L .63329 .50998 L F
.452 .802 .998 r
.63203 .511 m .63329 .50998 L .6314 .51019 L F
.63203 .511 m .6314 .51019 L .63043 .5103 L F
.915 .612 .128 r
.63203 .511 m .63277 .51229 L .63258 .5117 L F
0 0 .325 r
.63203 .511 m .63096 .51414 L .63277 .51229 L F
.795 .564 .586 r
.63519 .51396 m .63203 .511 L .63277 .51229 L F
.687 .865 .966 r
.66978 .48425 m .66821 .48668 L .67106 .48531 L F
.66978 .48425 m .66821 .48668 L .67106 .48531 L F
.623 .885 .557 r
.65492 .48926 m .65568 .48816 L .65642 .48743 L F
.988 .722 .409 r
.6557 .48892 m .65568 .48816 L .65492 .48926 L F
.945 .834 .703 r
.65495 .49083 m .6552 .49432 L .65402 .49319 L F
.6557 .48892 m .65547 .49135 L .65495 .49083 L F
.65547 .49135 m .6552 .49432 L .65495 .49083 L F
.6557 .48892 m .65402 .49319 L .65575 .49046 L F
.686 .831 .953 r
.65575 .49046 m .65432 .49022 L .65357 .489 L F
.65432 .49022 m .65364 .4901 L .6536 .48951 L F
.65432 .49022 m .6536 .48951 L .65357 .489 L F
.65575 .49046 m .65431 .4895 L .65568 .48816 L F
0 .411 .768 r
.6497 .48865 m .65364 .4901 L .65454 .49054 L F
.956 .929 .589 r
.65288 .48995 m .65269 .49213 L .65364 .4901 L F
.75 .815 .343 r
.65269 .49213 m .65341 .49002 L .65364 .4901 L F
0 .077 .632 r
.65364 .4901 m .65373 .48957 L .6528 .48681 L F
.982 .832 .617 r
.65512 .48595 m .65358 .489 L .65449 .48341 L F
.65568 .48816 m .65393 .48885 L .65512 .48595 L F
.65393 .48885 m .65358 .489 L .65512 .48595 L F
0 .077 .632 r
.65373 .48957 m .65357 .48898 L .6528 .48681 L F
.9 .738 .672 r
.65449 .48341 m .65357 .48898 L .6528 .48681 L F
0 .077 .632 r
.65357 .48898 m .65315 .48741 L .6528 .48681 L F
.9 .738 .672 r
.65357 .48898 m .65357 .489 L .6528 .48681 L F
.092 .528 .907 r
.6485 .48772 m .65327 .48946 L .65364 .4901 L F
.956 .929 .589 r
.65288 .48995 m .65364 .4901 L .65327 .48946 L F
0 .077 .632 r
.65362 .48974 m .6528 .48681 L .65357 .489 L F
.65364 .4901 m .65358 .48988 L .65362 .48974 L F
.65358 .48988 m .6528 .48681 L .65362 .48974 L F
.75 .815 .343 r
.65321 .49061 m .65296 .49083 L .65387 .48869 L F
.982 .832 .617 r
.65358 .489 m .65357 .48898 L .65449 .48341 L F
0 .077 .632 r
.65373 .48957 m .65388 .48866 L .65315 .48741 L F
.75 .815 .343 r
.65386 .48872 m .65387 .48869 L .65388 .48866 L F
.65321 .49061 m .65387 .48869 L .65386 .48872 L F
.65269 .49213 m .65279 .49163 L .65321 .49061 L F
.65279 .49163 m .65296 .49083 L .65321 .49061 L F
.982 .832 .617 r
.65358 .489 m .65357 .489 L .65357 .48898 L F
.75 .815 .343 r
.65341 .49002 m .65388 .48866 L .65375 .48943 L F
.65341 .49002 m .65375 .48943 L .65364 .4901 L F
.686 .831 .953 r
.65431 .4895 m .65388 .48921 L .65568 .48816 L F
.65388 .48921 m .65357 .489 L .65413 .48878 L F
.65388 .48921 m .65413 .48878 L .65568 .48816 L F
.623 .885 .557 r
.65642 .48743 m .65568 .48816 L .65783 .4857 L F
.532 .206 .36 r
.54299 .77443 m .54834 .77228 L .54506 .7761 L F
.724 .374 .385 r
.54834 .77228 m .54738 .77577 L .54506 .7761 L F
.383 .774 .988 r
.33273 .60082 m .3286 .60053 L .32972 .60098 L F
.065 0 0 r
.74276 .53189 m .74181 .53264 L .74295 .53218 L F
.585 .134 0 r
.74276 .53189 m .74295 .53218 L .7429 .53211 L F
.241 0 0 r
.74513 .53104 m .7429 .53212 L .74276 .53189 L F
.7429 .53211 m .74181 .53264 L .74276 .53189 L F
.638 .078 0 r
.74181 .53264 m .7384 .53031 L .74285 .53214 L F
.74181 .53264 m .74285 .53214 L .74295 .53218 L F
.241 0 0 r
.7429 .53212 m .74181 .53264 L .7429 .53211 L F
.585 .134 0 r
.74276 .53189 m .7429 .53211 L .74105 .52959 L F
.695 .675 .827 r
.74513 .53104 m .74276 .53189 L .74105 .52959 L F
.483 .419 .709 r
.5476 .78498 m .54582 .78583 L .545 .78364 L F
.634 .201 .202 r
.54433 .78468 m .5476 .78498 L .545 .78364 L F
.945 .643 .433 r
.55562 .78452 m .55682 .78273 L .55707 .78534 L F
.55707 .78534 m .55682 .78273 L .55562 .78452 L F
.973 .718 .487 r
.53596 .68949 m .53463 .68897 L .53589 .68691 L F
.707 .321 .316 r
.53589 .68691 m .53826 .68905 L .53773 .68645 L F
.548 .371 .593 r
.53826 .68905 m .53596 .68949 L .53589 .68691 L F
.707 .321 .316 r
.53589 .68691 m .53463 .68897 L .53826 .68905 L F
.548 .371 .593 r
.53826 .68905 m .53589 .68691 L .53773 .68645 L F
.445 .256 .529 r
.60993 .51487 m .612 .51427 L .61205 .51202 L F
.335 .238 .593 r
.60993 .51487 m .61182 .51597 L .612 .51427 L F
.60993 .51487 m .61032 .51749 L .61182 .51597 L F
.305 .79 .899 r
.51525 .7726 m .51654 .77288 L .51303 .77286 L F
0 0 0 r
.51654 .77288 m .51407 .7764 L .51506 .77569 L F
.51654 .77288 m .51506 .77569 L .51303 .77286 L F
.797 .99 .883 r
.51828 .77107 m .51654 .77288 L .51525 .7726 L F
.5 .381 .649 r
.39222 .67572 m .39401 .67232 L .39209 .67358 L F
.575 .01 0 r
.43072 .69672 m .43418 .69759 L .43207 .69634 L F
.607 .104 .029 r
.43207 .69634 m .43418 .69759 L .43537 .69715 L F
.615 .436 .616 r
.5889 .59384 m .59129 .59348 L .59125 .59105 L F
.599 .461 .665 r
.59125 .59105 m .5935 .59052 L .59339 .58802 L F
.651 .5 .666 r
.59129 .59348 m .5935 .59052 L .59125 .59105 L F
.847 .425 .229 r
.47702 .78746 m .47502 .78533 L .47565 .78849 L F
.362 .267 .611 r
.47565 .78849 m .47724 .79042 L .47702 .78746 L F
.47565 .78849 m .47567 .79156 L .47724 .79042 L F
.264 0 .288 r
.69189 .51699 m .6922 .51515 L .69418 .51455 L F
.367 .065 .314 r
.36049 .6271 m .35779 .62961 L .35859 .62788 L F
.95 .707 .535 r
.26465 .64901 m .26697 .65043 L .26523 .64708 L F
0 0 0 r
.26444 .65364 m .26697 .65043 L .26616 .65286 L F
.271 .672 .969 r
.26777 .65003 m .26697 .65043 L .26465 .64901 L F
.555 .446 .685 r
.26777 .65003 m .26616 .65286 L .26697 .65043 L F
.944 .743 .602 r
.26465 .64901 m .26616 .65286 L .26697 .65043 L F
.812 .553 .548 r
.6942 .51544 m .695 .5172 L .69189 .51699 L F
0 0 0 r
.52375 .64946 m .52698 .6488 L .52728 .64838 L F
.613 .61 .824 r
.53077 .65024 m .52728 .64838 L .52945 .64819 L F
.367 0 0 r
.52728 .64838 m .52816 .649 L .52945 .64819 L F
.52728 .64838 m .52698 .6488 L .52816 .649 L F
.782 .966 .921 r
.46892 .63821 m .47046 .63581 L .47176 .63625 L F
.46892 .63821 m .46792 .63771 L .47046 .63581 L F
.354 .373 .741 r
.47341 .76558 m .47402 .76893 L .47577 .76761 L F
.338 .265 .625 r
.47402 .76893 m .47642 .76951 L .47577 .76761 L F
.47402 .76893 m .47453 .77127 L .47642 .76951 L F
.649 .901 .983 r
.67948 .47399 m .68222 .47292 L .68318 .47362 L F
.619 .889 .989 r
.68318 .47362 m .6845 .47201 L .6855 .47278 L F
.68318 .47362 m .68222 .47292 L .6845 .47201 L F
.064 0 0 r
.33009 .64532 m .32626 .64715 L .3272 .64663 L F
.33009 .64532 m .3284 .64656 L .32626 .64715 L F
0 0 0 r
.33035 .6458 m .33009 .64532 L .33222 .64474 L F
.33035 .6458 m .3284 .64656 L .33009 .64532 L F
0 .193 .636 r
.53209 .80243 m .53507 .80448 L .53171 .80487 L F
.571 .099 .095 r
.53171 .80487 m .53507 .80448 L .53312 .80609 L F
.319 0 .131 r
.53507 .80448 m .53786 .80305 L .53718 .8041 L F
.168 0 0 r
.53312 .80609 m .53507 .80448 L .53718 .8041 L F
.029 0 0 r
.3229 .60119 m .32193 .60146 L .31975 .60167 L F
.228 .749 .802 r
.3265 .60083 m .32193 .60146 L .3229 .60119 L F
.609 .663 .877 r
.5565 .78684 m .55821 .78882 L .56036 .7881 L F
.61 .655 .869 r
.3179 .63287 m .31576 .6335 L .31382 .63125 L F
.791 .725 .791 r
.53617 .60592 m .53225 .60714 L .53472 .60452 L F
.766 .785 .868 r
.53806 .60474 m .53617 .60592 L .53472 .60452 L F
.714 .199 0 r
.4806 .69164 m .48384 .69283 L .48236 .69199 L F
.784 .698 .769 r
.38974 .70552 m .38932 .70518 L .38899 .70449 L F
.249 0 .237 r
.50387 .70018 m .50552 .70047 L .50601 .69809 L F
.017 0 .158 r
.50601 .69809 m .50691 .69931 L .50824 .69748 L F
.50601 .69809 m .50552 .70047 L .50691 .69931 L F
.681 .594 .752 r
.77947 .59502 m .78076 .59732 L .7827 .596 L F
.365 .825 .918 r
.31605 .6487 m .31205 .64899 L .31229 .64929 L F
.31605 .6487 m .31426 .64832 L .31205 .64899 L F
.399 0 0 r
.31722 .64849 m .31426 .64832 L .31605 .6487 L F
.749 .401 .394 r
.54573 .73451 m .54948 .73672 L .54921 .73484 L F
.769 .423 .399 r
.54948 .73672 m .55118 .73717 L .54921 .73484 L F
.772 .422 .393 r
.54921 .73484 m .55118 .73717 L .55299 .73735 L F
.743 .98 .915 r
.50611 .77653 m .50809 .77619 L .50692 .77348 L F
.808 .762 .81 r
.50692 .77348 m .50809 .77619 L .50933 .77319 L F
.693 .651 .804 r
.57656 .71511 m .57783 .71832 L .57441 .717 L F
.616 .643 .854 r
.57887 .71492 m .57783 .71832 L .57656 .71511 L F
.58105 .71818 m .58124 .71847 L .57783 .71832 L F
.607 .273 .378 r
.58124 .71847 m .58019 .71992 L .57783 .71832 L F
.584 .294 .442 r
.57809 .71828 m .58153 .71816 L .58193 .71763 L F
.57783 .71832 m .58085 .71819 L .57809 .71828 L F
.58085 .71819 m .58153 .71816 L .57809 .71828 L F
.61 .642 .858 r
.58155 .71419 m .5828 .71696 L .58156 .71816 L F
.58126 .71817 m .58156 .71816 L .58124 .71847 L F
.584 .294 .442 r
.58105 .71818 m .58152 .71817 L .58153 .71816 L F
.61 .642 .858 r
.58155 .71419 m .58156 .71816 L .58126 .71817 L F
.58155 .71419 m .58126 .71817 L .57887 .71492 L F
.58126 .71817 m .58124 .71847 L .58105 .71818 L F
.58126 .71817 m .58105 .71818 L .57887 .71492 L F
.584 .294 .442 r
.57783 .71832 m .58019 .71992 L .58152 .71817 L F
.57783 .71832 m .58152 .71817 L .58105 .71818 L F
.616 .643 .854 r
.57887 .71492 m .58105 .71818 L .57783 .71832 L F
.714 .179 0 r
.55147 .64096 m .54795 .63823 L .54929 .63861 L F
.743 .347 .301 r
.55129 .63943 m .55147 .64096 L .54929 .63861 L F
.907 .923 .816 r
.58835 .7113 m .58466 .71418 L .58668 .71109 L F
.527 .395 .644 r
.59031 .70843 m .58835 .7113 L .58668 .71109 L F
.59031 .70843 m .59053 .71166 L .58835 .7113 L F
.495 .267 .497 r
.37528 .61317 m .37288 .61574 L .37307 .61359 L F
.985 .832 .443 r
.73415 .50582 m .73475 .5066 L .73436 .50884 L F
.784 .603 .655 r
.50967 .63052 m .50502 .62962 L .50804 .62852 L F
.50967 .63052 m .5068 .63325 L .50502 .62962 L F
.691 .453 .558 r
.50967 .63052 m .509 .63458 L .5068 .63325 L F
.398 .412 .758 r
.50994 .63121 m .509 .63458 L .50967 .63052 L F
.64 .176 0 r
.50804 .62852 m .50994 .63121 L .50967 .63052 L F
.988 .78 .535 r
.72739 .49377 m .72879 .4925 L .72798 .49152 L F
.72739 .49377 m .72851 .49484 L .72879 .4925 L F
.795 .802 .858 r
.6588 .51593 m .65769 .5179 L .66055 .51787 L F
.837 .728 .743 r
.63434 .53662 m .63534 .53983 L .63758 .53703 L F
.745 .346 .295 r
.25244 .65057 m .25515 .65015 L .25262 .64963 L F
.25244 .65057 m .25637 .65191 L .25515 .65015 L F
.002 0 .136 r
.25515 .65015 m .25608 .65003 L .25708 .64742 L F
.072 .19 .682 r
.25515 .65015 m .25662 .65208 L .25608 .65003 L F
.582 .446 .661 r
.57065 .61899 m .57041 .61889 L .5709 .61656 L F
.627 .438 .608 r
.57302 .61621 m .57065 .61899 L .5709 .61656 L F
0 0 .261 r
.61966 .58767 m .61915 .58979 L .61751 .59081 L F
0 0 0 r
.61915 .58979 m .61643 .59242 L .61751 .59081 L F
.614 .689 .896 r
.26143 .63962 m .26531 .63995 L .26353 .63909 L F
.662 .375 .475 r
.6221 .53483 m .6229 .53683 L .62126 .53684 L F
.379 .64 .958 r
.37244 .59333 m .37172 .59476 L .37036 .59356 L F
.37244 .59333 m .37424 .59507 L .37172 .59476 L F
.459 .692 .967 r
.31284 .62978 m .31221 .63139 L .31079 .63015 L F
.31284 .62978 m .31382 .63125 L .31221 .63139 L F
.434 0 .063 r
.43998 .69727 m .44225 .69727 L .44368 .69558 L F
.492 .037 .1 r
.44368 .69558 m .44225 .69727 L .44564 .69655 L F
.532 .345 .573 r
.61182 .53845 m .61232 .54223 L .60981 .54257 L F
.377 .195 .503 r
.61358 .53698 m .61357 .53861 L .61182 .53845 L F
.653 .525 .695 r
.61357 .53861 m .61232 .54223 L .61182 .53845 L F
0 0 0 r
.55149 .76994 m .55149 .76866 L .55252 .76792 L F
.569 .525 .766 r
.75399 .59692 m .75651 .59679 L .75553 .59293 L F
.146 0 .056 r
.51659 .77693 m .51977 .77371 L .51855 .77615 L F
.474 0 0 r
.51977 .77371 m .5205 .77493 L .51855 .77615 L F
.51977 .77371 m .52202 .77419 L .5205 .77493 L F
.889 .874 .816 r
.65644 .50997 m .65435 .51252 L .65391 .51075 L F
.887 .88 .821 r
.65644 .50997 m .65391 .51075 L .65644 .50709 L F
.171 .271 .726 r
.50445 .70078 m .50594 .70231 L .50552 .70047 L F
.97 .784 .596 r
.50594 .70231 m .50469 .70244 L .50552 .70047 L F
.50594 .70231 m .50469 .70244 L .50552 .70047 L F
.008 0 .145 r
.50552 .70047 m .50469 .70244 L .50624 .70025 L F
.50552 .70047 m .50624 .70025 L .50691 .69931 L F
.171 .271 .726 r
.50387 .70018 m .50445 .70078 L .50552 .70047 L F
.536 .774 .985 r
.30387 .62784 m .30314 .62949 L .30119 .6279 L F
.30387 .62784 m .30527 .62907 L .30314 .62949 L F
.503 .264 .485 r
.60101 .52906 m .60333 .5286 L .60355 .52635 L F
.384 .165 .454 r
.60355 .52635 m .60553 .52765 L .60603 .52576 L F
.60355 .52635 m .60333 .5286 L .60553 .52765 L F
.339 0 0 r
.52928 .65206 m .53077 .65024 L .53109 .65257 L F
.492 .804 1 r
.53189 .64857 m .53077 .65024 L .52945 .64819 L F
.53189 .64857 m .53277 .64983 L .53077 .65024 L F
.498 .312 .559 r
.53277 .64983 m .53109 .65257 L .53077 .65024 L F
.53277 .64983 m .53109 .65257 L .53077 .65024 L F
0 0 0 r
.55941 .77667 m .55909 .77988 L .55756 .77973 L F
.55941 .77667 m .56023 .77887 L .55909 .77988 L F
.489 .881 .961 r
.55756 .77973 m .55909 .77988 L .56023 .77887 L F
.182 0 .284 r
.25931 .64438 m .25708 .64742 L .25899 .64615 L F
.162 0 .22 r
.25708 .64742 m .25771 .64879 L .25899 .64615 L F
.25708 .64742 m .25608 .65003 L .25771 .64879 L F
.349 0 .113 r
.26999 .59046 m .2721 .59005 L .27352 .5881 L F
.362 0 .091 r
.2721 .59005 m .27574 .58784 L .27352 .5881 L F
0 0 0 r
.54056 .7769 m .54299 .77443 L .54287 .77664 L F
.532 .206 .36 r
.54299 .77443 m .54506 .7761 L .54287 .77664 L F
.825 .657 .674 r
.55477 .63907 m .55147 .64096 L .55129 .63943 L F
.908 .792 .721 r
.63963 .50806 m .64086 .50923 L .64193 .50709 L F
.64178 .50746 m .64193 .50709 L .64439 .50674 L F
.63963 .50806 m .64085 .50755 L .64178 .50746 L F
.64085 .50755 m .64193 .50709 L .64178 .50746 L F
.63963 .50806 m .64439 .50674 L .64208 .50677 L F
.518 .565 .843 r
.64343 .50886 m .64208 .50677 L .64439 .50674 L F
.64248 .5074 m .6445 .50654 L .64208 .50677 L F
.64343 .50886 m .64417 .50724 L .64248 .5074 L F
.64417 .50724 m .6445 .50654 L .64248 .5074 L F
.667 .482 .626 r
.54642 .76757 m .5474 .7684 L .54724 .76584 L F
.061 .026 .5 r
.54724 .76584 m .54887 .76744 L .54952 .7654 L F
.54724 .76584 m .5474 .7684 L .54887 .76744 L F
.343 0 .002 r
.27812 .58768 m .2805 .58733 L .28175 .58597 L F
.274 0 0 r
.28175 .58597 m .28325 .58634 L .284 .58576 L F
.28175 .58597 m .2805 .58733 L .28325 .58634 L F
.451 .1 .278 r
.38318 .60689 m .38208 .60957 L .37985 .60986 L F
.495 .315 .567 r
.38554 .60429 m .38557 .60591 L .38318 .60689 L F
.508 .209 .394 r
.38557 .60591 m .38208 .60957 L .38318 .60689 L F
0 0 0 r
.43139 .66933 m .42833 .67192 L .4293 .66997 L F
.595 .703 .918 r
.67253 .52001 m .67592 .52097 L .67489 .51905 L F
.455 .623 .924 r
.67489 .51905 m .67592 .52097 L .67694 .51899 L F
.649 .86 .98 r
.67694 .51899 m .67592 .52097 L .6782 .51984 L F
.768 .885 .929 r
.48788 .62814 m .48398 .62904 L .48662 .62737 L F
.807 .915 .912 r
.48788 .62814 m .48869 .62561 L .48999 .62703 L F
.48788 .62814 m .48662 .62737 L .48869 .62561 L F
.694 .951 .955 r
.46328 .64064 m .46138 .64179 L .4622 .64018 L F
.668 .925 .973 r
.46138 .64179 m .46015 .64127 L .4622 .64018 L F
.755 .974 .923 r
.47974 .63172 m .48086 .62975 L .48199 .63035 L F
.47974 .63172 m .47805 .63168 L .48086 .62975 L F
.514 .244 .442 r
.55439 .77406 m .55665 .774 L .55682 .77142 L F
.739 .991 .82 r
.55959 .76889 m .55682 .77142 L .55878 .76975 L F
.538 .885 .644 r
.55878 .76975 m .55682 .77142 L .55795 .77021 L F
.934 .723 .243 r
.55682 .77142 m .55665 .774 L .55636 .77289 L F
.55682 .77142 m .55636 .77289 L .55795 .77021 L F
.344 .274 .634 r
.25437 .60792 m .25586 .60741 L .25548 .60539 L F
.369 .348 .704 r
.25437 .60792 m .25644 .60968 L .25586 .60741 L F
.454 .351 .649 r
.25437 .60792 m .25466 .61036 L .25644 .60968 L F
.933 .81 .7 r
.62143 .54807 m .61993 .54812 L .62108 .54516 L F
.969 .878 .689 r
.62143 .54807 m .61944 .55049 L .61993 .54812 L F
.62143 .54807 m .62042 .55144 L .61944 .55049 L F
.908 .848 .773 r
.73494 .5002 m .73505 .49676 L .73597 .49786 L F
.461 .31 .589 r
.57065 .61899 m .57068 .62147 L .56868 .62188 L F
.567 .404 .62 r
.57114 .62412 m .56868 .62188 L .57068 .62147 L F
.57114 .62412 m .56879 .62463 L .56868 .62188 L F
.382 0 0 r
.47413 .64773 m .47022 .64804 L .4716 .64818 L F
.908 .981 .775 r
.29291 .64826 m .29299 .65026 L .29443 .64818 L F
.371 0 0 r
.29443 .64818 m .29475 .64918 L .29291 .64826 L F
.29784 .64903 m .29927 .64938 L .29721 .64929 L F
.29443 .64818 m .29784 .64903 L .29492 .64917 L F
.29471 .64907 m .29492 .64917 L .29475 .64918 L F
.29443 .64818 m .29492 .64917 L .29471 .64907 L F
.29784 .64903 m .29721 .64929 L .29563 .64922 L F
.29557 .64914 m .29563 .64922 L .29475 .64918 L F
.29784 .64903 m .29563 .64922 L .29557 .64914 L F
.684 .95 .956 r
.29498 .64915 m .29927 .64938 L .29964 .64859 L F
.29496 .64919 m .29927 .64938 L .29498 .64915 L F
.29475 .64918 m .29496 .64919 L .29498 .64915 L F
.29475 .64918 m .29964 .64859 L .29539 .64988 L F
.739 .767 .875 r
.29591 .64923 m .30123 .64749 L .29839 .64615 L F
.29539 .64988 m .29624 .64953 L .29591 .64923 L F
.29624 .64953 m .30123 .64749 L .29591 .64923 L F
0 0 0 r
.29839 .64615 m .29604 .64958 L .29593 .64963 L F
.29839 .64615 m .29593 .64963 L .29577 .64941 L F
.539 .853 .998 r
.29518 .64859 m .29446 .64777 L .29502 .64904 L F
0 0 0 r
.29577 .64941 m .29593 .64963 L .29539 .64988 L F
.539 .853 .998 r
.29604 .64958 m .29518 .64859 L .29511 .64926 L F
.29518 .64859 m .29502 .64904 L .29511 .64926 L F
.29593 .64963 m .29511 .64926 L .29539 .64988 L F
.29604 .64958 m .29511 .64926 L .29593 .64963 L F
.064 .179 .674 r
.29291 .64826 m .29475 .64918 L .29446 .64777 L F
.688 .633 .788 r
.29475 .64918 m .29539 .64988 L .29446 .64777 L F
.533 .382 .622 r
.29446 .64777 m .29391 .65019 L .29604 .64958 L F
.539 .853 .998 r
.29604 .64958 m .29391 .65019 L .29446 .64777 L F
.533 .382 .622 r
.29428 .64775 m .29604 .64958 L .29411 .64772 L F
.29446 .64777 m .29507 .64847 L .29428 .64775 L F
.29507 .64847 m .29604 .64958 L .29428 .64775 L F
.584 .731 .945 r
.30066 .65002 m .30162 .64808 L .29964 .64859 L F
.604 .942 .939 r
.30162 .64808 m .2967 .6495 L .29964 .64859 L F
.2967 .6495 m .29539 .64988 L .29688 .64943 L F
.2967 .6495 m .29688 .64943 L .29964 .64859 L F
.576 .357 .545 r
.58089 .6105 m .5809 .61308 L .57861 .61323 L F
.563 .354 .555 r
.58327 .61021 m .5809 .61308 L .58089 .6105 L F
.624 .439 .613 r
.58653 .59658 m .589 .59628 L .5889 .59384 L F
.599 .411 .599 r
.589 .59628 m .59129 .59348 L .5889 .59384 L F
.975 .915 .674 r
.56733 .76872 m .56537 .77097 L .56652 .77141 L F
.56733 .76872 m .5666 .76768 L .56537 .77097 L F
.606 .555 .771 r
.50693 .79728 m .50863 .79371 L .50646 .79483 L F
.50693 .79728 m .50944 .79654 L .50863 .79371 L F
.759 .936 .943 r
.71794 .48471 m .7192 .48257 L .72025 .48366 L F
.71794 .48471 m .71623 .48452 L .7192 .48257 L F
.662 .842 .969 r
.53662 .65538 m .53816 .65667 L .54024 .65554 L F
.53662 .65538 m .53816 .65667 L .54024 .65554 L F
0 .502 .77 r
.71321 .4725 m .71164 .47209 L .71196 .47242 L F
.71321 .4725 m .71245 .47213 L .71164 .47209 L F
.76 .99 .775 r
.71595 .46878 m .71245 .47213 L .71321 .4725 L F
.012 0 0 r
.49597 .63894 m .49478 .64081 L .49321 .64127 L F
.694 .295 .288 r
.49597 .63894 m .4981 .64099 L .49478 .64081 L F
0 0 0 r
.38361 .59777 m .38117 .59788 L .38358 .59752 L F
0 .41 .839 r
.38532 .59817 m .38361 .59777 L .38358 .59752 L F
.38532 .59817 m .38638 .59916 L .38361 .59777 L F
0 .223 .711 r
.52427 .76803 m .52664 .77034 L .52425 .76862 L F
.447 .227 .486 r
.2577 .59656 m .25967 .59606 L .2599 .59385 L F
.481 .336 .607 r
.25782 .59916 m .25967 .59606 L .2577 .59656 L F
0 0 .01 r
.48013 .80315 m .48076 .8019 L .48065 .80479 L F
.505 .374 .636 r
.41953 .68072 m .41746 .68424 L .41714 .68101 L F
.41953 .68072 m .41972 .68373 L .41746 .68424 L F
.507 .385 .648 r
.41996 .68629 m .41746 .68424 L .41972 .68373 L F
.41996 .68629 m .41786 .68671 L .41746 .68424 L F
.496 0 0 r
.29299 .65026 m .29174 .65004 L .29022 .64927 L F
.858 .971 .865 r
.29291 .64826 m .29174 .65004 L .29299 .65026 L F
.218 0 .072 r
.53718 .8041 m .53786 .80305 L .5399 .80225 L F
.621 .359 .5 r
.59941 .60237 m .59937 .60438 L .59739 .60418 L F
.59 .237 .339 r
.59941 .60237 m .60175 .60401 L .59937 .60438 L F
.59941 .60237 m .60257 .60209 L .60175 .60401 L F
.305 .003 .276 r
.25967 .59606 m .26229 .59358 L .2599 .59385 L F
.853 .474 .329 r
.53841 .80131 m .53974 .79972 L .53782 .79947 L F
.967 .684 .443 r
.5399 .80225 m .53974 .79972 L .53841 .80131 L F
.807 .656 .695 r
.39297 .6957 m .3935 .69789 L .39583 .6953 L F
.547 .346 .56 r
.57551 .61514 m .57327 .61874 L .57302 .61621 L F
.57551 .61514 m .57589 .61827 L .57327 .61874 L F
.569 .364 .562 r
.57861 .61323 m .57885 .61509 L .57551 .61514 L F
.56 .317 .505 r
.57551 .61514 m .57799 .61787 L .57589 .61827 L F
.57551 .61514 m .57885 .61509 L .57799 .61787 L F
.627 .766 .946 r
.49232 .62628 m .49351 .62769 L .48999 .62703 L F
.663 .78 .936 r
.49582 .6268 m .49351 .62769 L .49232 .62628 L F
.517 .546 .825 r
.29441 .62391 m .2938 .62735 L .29231 .6244 L F
.29441 .62391 m .29581 .62716 L .2938 .62735 L F
.625 .945 .947 r
.67943 .53033 m .67811 .53182 L .68054 .53142 L F
.67943 .53033 m .6773 .53146 L .67811 .53182 L F
.636 .579 .773 r
.67811 .53182 m .68161 .5346 L .68054 .53142 L F
.77 .597 .664 r
.63913 .49871 m .64188 .50042 L .6405 .4969 L F
.63913 .49871 m .63784 .50072 L .64188 .50042 L F
0 0 .173 r
.63867 .50278 m .63988 .50334 L .64053 .50171 L F
.944 .799 .343 r
.64053 .50171 m .63988 .50334 L .63995 .50278 L F
.458 .347 .64 r
.63784 .50072 m .64053 .50171 L .6412 .50047 L F
.63784 .50072 m .63867 .50278 L .64053 .50171 L F
.944 .799 .343 r
.64053 .50171 m .63995 .50278 L .64019 .50101 L F
.458 .347 .64 r
.6412 .50047 m .64053 .50171 L .64188 .50042 L F
.598 .597 .821 r
.6405 .4969 m .64188 .50042 L .64407 .49947 L F
.136 0 0 r
.64188 .50042 m .64322 .50082 L .64407 .49947 L F
.64188 .50042 m .64053 .50171 L .64322 .50082 L F
.679 .622 .785 r
.68405 .51729 m .68007 .51527 L .68257 .5146 L F
.454 .48 .797 r
.68494 .51377 m .68405 .51729 L .68257 .5146 L F
.68494 .51377 m .68607 .51723 L .68405 .51729 L F
.471 .783 .998 r
.25996 .64313 m .26142 .6441 L .25931 .64438 L F
.669 .463 .596 r
.25899 .64615 m .25996 .64313 L .25931 .64438 L F
.667 .211 .161 r
.53221 .76885 m .53435 .7704 L .5361 .76912 L F
.588 .11 .089 r
.5361 .76912 m .53435 .7704 L .53813 .7705 L F
.535 .786 .99 r
.49451 .77891 m .49446 .77998 L .49428 .77981 L F
.49451 .77891 m .49676 .77956 L .49446 .77998 L F
.49446 .77998 m .49676 .77956 L .49451 .77891 L F
.67 .49 .634 r
.71898 .47793 m .71918 .48111 L .71671 .48085 L F
.82 .998 .843 r
.71989 .47561 m .72102 .47561 L .71898 .47793 L F
.647 .576 .761 r
.72102 .47561 m .72171 .47861 L .71898 .47793 L F
.732 .58 .685 r
.72171 .47861 m .71918 .48111 L .71898 .47793 L F
.571 .595 .839 r
.71298 .46645 m .71111 .46816 L .71073 .46722 L F
.518 .373 .623 r
.29412 .61827 m .29199 .62279 L .29158 .62009 L F
.699 .35 .38 r
.45743 .69215 m .45958 .69441 L .46092 .69218 L F
.375 0 .004 r
.45958 .69441 m .46336 .69266 L .46092 .69218 L F
.7 .176 0 r
.4806 .69164 m .48288 .69364 L .48384 .69283 L F
.696 .17 0 r
.48288 .69364 m .48647 .6949 L .48384 .69283 L F
.539 .796 .992 r
.69936 .47155 m .7004 .47262 L .69701 .47205 L F
.683 .857 .965 r
.70275 .47166 m .7004 .47262 L .69936 .47155 L F
.622 .447 .624 r
.63914 .51005 m .64086 .50923 L .63796 .50916 L F
.857 .629 .591 r
.63742 .50856 m .63914 .51005 L .63796 .50916 L F
.572 .75 .962 r
.63796 .50916 m .63963 .50806 L .63742 .50856 L F
.63796 .50916 m .64086 .50923 L .63963 .50806 L F
0 0 0 r
.62749 .57317 m .62538 .57609 L .62631 .57462 L F
0 .001 .573 r
.53465 .62147 m .53477 .62107 L .53313 .6188 L F
0 .004 .575 r
.53465 .62147 m .53634 .62385 L .53477 .62107 L F
0 0 0 r
.6148 .56563 m .61412 .56713 L .61564 .56409 L F
.604 .72 .926 r
.26307 .65245 m .26444 .65364 L .26616 .65286 L F
.201 0 .096 r
.70763 .47874 m .70767 .48005 L .70474 .48097 L F
.402 0 .08 r
.43019 .65238 m .43257 .65217 L .43384 .65045 L F
.222 0 0 r
.43384 .65045 m .43471 .65155 L .43605 .65009 L F
.43384 .65045 m .43257 .65217 L .43471 .65155 L F
.463 .118 .294 r
.43943 .64917 m .44164 .64893 L .44192 .64783 L F
.517 .141 .267 r
.42208 .65494 m .42438 .65496 L .42556 .65274 L F
.504 .156 .309 r
.42438 .65496 m .42786 .65236 L .42556 .65274 L F
.654 .221 .207 r
.58118 .70656 m .58002 .70821 L .57776 .70648 L F
.436 .349 .659 r
.58179 .70306 m .58327 .70533 L .58118 .70656 L F
.718 .506 .602 r
.58327 .70533 m .58002 .70821 L .58118 .70656 L F
.646 .621 .811 r
.66885 .53283 m .67023 .53536 L .67244 .53431 L F
.825 .75 .781 r
.25662 .65208 m .25857 .65312 L .26061 .65069 L F
.314 .767 .955 r
.25941 .65003 m .26061 .65069 L .26306 .65041 L F
.906 .667 .566 r
.5643 .77299 m .56652 .77141 L .56537 .77097 L F
.5643 .77299 m .56605 .77389 L .56652 .77141 L F
.354 .057 .315 r
.53318 .79066 m .53372 .7928 L .53141 .79289 L F
.53318 .79066 m .53629 .78869 L .53372 .7928 L F
.691 .833 .951 r
.67808 .51116 m .67494 .51047 L .6785 .50862 L F
.788 .891 .918 r
.68139 .5085 m .67808 .51116 L .6785 .50862 L F
.723 .701 .829 r
.76235 .59621 m .76333 .59944 L .76106 .5978 L F
.76131 .59647 m .76106 .5978 L .75977 .59686 L F
.76235 .59621 m .76106 .5978 L .76131 .59647 L F
.455 0 0 r
.76169 .59633 m .76237 .5962 L .76237 .5962 L F
.76169 .59633 m .76237 .5962 L .76169 .59633 L F
.75924 .59664 m .76237 .5962 L .75933 .59643 L F
.75918 .5968 m .76146 .59637 L .75924 .59664 L F
.76146 .59637 m .76237 .5962 L .75924 .59664 L F
.553 .478 .725 r
.76171 .59304 m .76237 .5962 L .75933 .59643 L F
.347 .379 .752 r
.76046 .59061 m .76333 .59252 L .76171 .59304 L F
.711 .582 .71 r
.76468 .59562 m .76171 .59304 L .76333 .59252 L F
.76468 .59562 m .76237 .5962 L .76171 .59304 L F
.305 .246 .625 r
.76146 .59637 m .76211 .59228 L .76138 .59612 L F
.76158 .59678 m .76163 .59635 L .76146 .59637 L F
.455 0 0 r
.76146 .59637 m .76169 .59633 L .76169 .59633 L F
.305 .246 .625 r
.76163 .59635 m .76211 .59228 L .76146 .59637 L F
.723 .701 .829 r
.76237 .5962 m .76237 .59621 L .76235 .59621 L F
.647 .655 .844 r
.76587 .59877 m .76237 .5962 L .76468 .59562 L F
.305 .246 .625 r
.76176 .59634 m .76394 .59634 L .76333 .59252 L F
.723 .701 .829 r
.76237 .59621 m .76333 .59944 L .76235 .59621 L F
.647 .655 .844 r
.76587 .59877 m .76333 .59944 L .76237 .5962 L F
.305 .246 .625 r
.76158 .59678 m .76332 .59646 L .76176 .59634 L F
.76332 .59646 m .76394 .59634 L .76176 .59634 L F
.455 0 0 r
.75918 .5968 m .75977 .59686 L .76235 .59621 L F
.735 .673 .79 r
.75918 .5968 m .76146 .59637 L .76146 .59637 L F
.455 0 0 r
.75918 .5968 m .76235 .59621 L .76237 .5962 L F
.735 .673 .79 r
.75918 .5968 m .76158 .59678 L .76146 .59637 L F
.455 0 0 r
.75918 .5968 m .76146 .59637 L .76146 .59637 L F
.76146 .59637 m .76237 .5962 L .76146 .59637 L F
.305 .246 .625 r
.76163 .59635 m .76333 .59252 L .76211 .59228 L F
.76158 .59678 m .76176 .59634 L .76163 .59635 L F
.76176 .59634 m .76333 .59252 L .76163 .59635 L F
.76138 .59612 m .76211 .59228 L .7601 .59189 L F
.735 .673 .79 r
.75918 .5968 m .76146 .59637 L .76138 .59612 L F
.75934 .59595 m .76138 .59612 L .7601 .59189 L F
.75918 .5968 m .76138 .59612 L .75934 .59595 L F
.82 .341 .044 r
.76333 .59944 m .76215 .59917 L .75977 .59686 L F
.19 0 0 r
.76587 .59877 m .76215 .59917 L .76333 .59944 L F
.743 .638 .744 r
.64537 .48618 m .64583 .48325 L .64412 .48391 L F
.305 0 .226 r
.64537 .48618 m .64405 .48862 L .64645 .4876 L F
0 0 0 r
.53087 .77602 m .5298 .77728 L .53139 .77429 L F
.358 .114 .402 r
.53079 .77881 m .5298 .77728 L .53087 .77602 L F
.53079 .77881 m .52898 .77945 L .5298 .77728 L F
.699 .983 .845 r
.73474 .51104 m .73293 .51202 L .73436 .50884 L F
.448 .881 .874 r
.32135 .63216 m .32223 .63144 L .32351 .6318 L F
.32135 .63216 m .31998 .63232 L .32223 .63144 L F
.707 .352 .372 r
.57558 .69947 m .57894 .70044 L .57649 .698 L F
.67 .364 .446 r
.57894 .70044 m .57974 .6983 L .57649 .698 L F
.385 .118 .381 r
.57138 .70336 m .57349 .70342 L .57383 .70063 L F
.355 .094 .373 r
.57383 .70063 m .57589 .70115 L .57558 .69947 L F
.57383 .70063 m .57349 .70342 L .57589 .70115 L F
.265 0 .13 r
.53087 .77602 m .53139 .77429 L .53344 .77357 L F
.773 .775 .854 r
.53806 .60474 m .53472 .60452 L .53746 .60218 L F
.851 .818 .817 r
.54029 .60198 m .53806 .60474 L .53746 .60218 L F
.221 0 0 r
.302 .64937 m .30257 .64957 L .30066 .65002 L F
.302 .64937 m .30439 .65008 L .30257 .64957 L F
.626 .511 .703 r
.41905 .67819 m .41953 .68072 L .41714 .68101 L F
.73 .678 .8 r
.68054 .53142 m .68161 .5346 L .68421 .53234 L F
.851 .818 .817 r
.54029 .60198 m .53746 .60218 L .53886 .60089 L F
.818 .869 .884 r
.54281 .5994 m .54029 .60198 L .53886 .60089 L F
.524 .508 .78 r
.51701 .78845 m .51873 .78557 L .51551 .78615 L F
.51701 .78845 m .51892 .78826 L .51873 .78557 L F
.479 .24 .474 r
.5192 .79051 m .51701 .78845 L .51717 .79072 L F
.5192 .79051 m .51892 .78826 L .51701 .78845 L F
.5 .381 .649 r
.39222 .67572 m .39426 .67528 L .39401 .67232 L F
.519 .43 .694 r
.39271 .67817 m .39426 .67528 L .39222 .67572 L F
.995 .768 .471 r
.55925 .63159 m .55872 .62992 L .56167 .6305 L F
.701 .492 .601 r
.56535 .63322 m .56167 .6305 L .56436 .6302 L F
.234 .551 .931 r
.66689 .4958 m .66606 .49657 L .66541 .49526 L F
.488 .21 .418 r
.62039 .52351 m .6203 .52543 L .61772 .52589 L F
.139 .684 .793 r
.34267 .60043 m .34619 .60032 L .34496 .59994 L F
.263 .69 .965 r
.34619 .60032 m .34739 .59958 L .34496 .59994 L F
.34619 .60032 m .34914 .60058 L .34739 .59958 L F
.802 .436 .363 r
.5189 .78264 m .51792 .78454 L .52177 .78423 L F
.488 .357 .629 r
.51792 .78454 m .51873 .78557 L .52177 .78423 L F
.783 .707 .78 r
.51873 .78557 m .52232 .7856 L .52177 .78423 L F
.658 .413 .538 r
.74597 .50642 m .74577 .50842 L .74264 .50843 L F
.441 .302 .595 r
.74782 .50529 m .74577 .50842 L .74597 .50642 L F
.833 .764 .786 r
.70209 .48227 m .70288 .48401 L .70474 .48097 L F
.982 .839 .627 r
.65647 .49546 m .65484 .49668 L .6552 .49432 L F
.65647 .49546 m .65586 .49771 L .65484 .49668 L F
0 0 0 r
.48958 .8111 m .49124 .80815 L .49133 .81045 L F
.325 .108 .422 r
.29866 .61298 m .29584 .61572 L .29652 .61377 L F
0 .002 .572 r
.47205 .79904 m .47313 .80257 L .47368 .80161 L F
0 0 0 r
.47368 .80161 m .47313 .80257 L .47239 .80502 L F
.988 .862 .623 r
.62042 .55144 m .61892 .55252 L .61944 .55049 L F
.62042 .55144 m .61969 .55336 L .61892 .55252 L F
.243 .592 .948 r
.32409 .58619 m .32348 .58709 L .32193 .58622 L F
.32409 .58619 m .32535 .58747 L .32348 .58709 L F
.792 .351 .201 r
.49315 .79353 m .4924 .79181 L .48988 .79085 L F
.973 .855 .459 r
.47698 .6868 m .47602 .68874 L .47663 .68586 L F
.427 .717 .985 r
.4779 .68556 m .47698 .6868 L .47663 .68586 L F
.159 0 .052 r
.47786 .68798 m .47698 .6868 L .4779 .68556 L F
.47786 .68798 m .47602 .68874 L .47698 .6868 L F
.881 .793 .758 r
.70145 .5197 m .70419 .51935 L .70468 .518 L F
.883 .759 .72 r
.70238 .52308 m .70419 .51935 L .70145 .5197 L F
.351 .827 .857 r
.32621 .60041 m .32412 .60103 L .3265 .60083 L F
.25 0 0 r
.32621 .60041 m .32521 .60073 L .32412 .60103 L F
.228 .749 .802 r
.3265 .60083 m .32412 .60103 L .32311 .6013 L F
.25 0 0 r
.32521 .60073 m .32213 .60174 L .32412 .60103 L F
.228 .749 .802 r
.32311 .6013 m .32412 .60103 L .32193 .60146 L F
.351 .827 .857 r
.32621 .60041 m .3265 .60083 L .3286 .60053 L F
.825 .657 .674 r
.55477 .63907 m .55467 .64158 L .55147 .64096 L F
.676 .624 .789 r
.55723 .63863 m .55477 .63907 L .55339 .63626 L F
.75 .654 .755 r
.55723 .63863 m .55467 .64158 L .55477 .63907 L F
0 .036 .572 r
.47373 .81061 m .47621 .81364 L .47607 .81302 L F
.354 .722 .987 r
.35394 .58976 m .3533 .59072 L .3519 .58977 L F
.35394 .58976 m .35544 .59074 L .3533 .59072 L F
.456 .05 .181 r
.44759 .66069 m .44633 .66296 L .4441 .66307 L F
.362 .097 .372 r
.4501 .65879 m .44759 .66069 L .45002 .65853 L F
.664 .27 .29 r
.4502 .66279 m .44759 .66069 L .4501 .65879 L F
.4502 .66279 m .44633 .66296 L .44759 .66069 L F
0 0 0 r
.50028 .64081 m .50057 .64077 L .49959 .6418 L F
.447 .789 .998 r
.49959 .6418 m .50057 .64077 L .4981 .64099 L F
0 0 0 r
.57894 .70044 m .58222 .69807 L .57974 .6983 L F
0 .01 .551 r
.5818 .69564 m .58222 .69807 L .58306 .69655 L F
.687 .911 .572 r
.58222 .69807 m .58084 .69942 L .58306 .69655 L F
.717 .561 .676 r
.58614 .70088 m .58282 .70113 L .58222 .69807 L F
.013 0 0 r
.51381 .69481 m .51541 .69455 L .51668 .69288 L F
.51381 .69481 m .51257 .69652 L .51541 .69455 L F
.543 .167 .278 r
.60765 .54554 m .60436 .54742 L .60455 .54633 L F
.755 .568 .643 r
.51501 .805 m .51458 .80777 L .51232 .80769 L F
.684 .631 .79 r
.51633 .80542 m .51458 .80777 L .51501 .805 L F
.339 0 0 r
.51633 .80542 m .51501 .805 L .51286 .80496 L F
.393 0 0 r
.51532 .70093 m .51391 .70224 L .51168 .70231 L F
.296 0 .001 r
.51729 .70018 m .51391 .70224 L .51532 .70093 L F
.507 .269 .488 r
.34454 .61905 m .3468 .61866 L .34711 .61642 L F
.524 .412 .668 r
.34711 .61642 m .34933 .61596 L .3488 .61311 L F
.409 .185 .46 r
.34711 .61642 m .34871 .61801 L .34933 .61596 L F
.34711 .61642 m .3468 .61866 L .34871 .61801 L F
.443 .259 .536 r
.50167 .80409 m .50518 .80252 L .50205 .80276 L F
.849 .735 .737 r
.25055 .6511 m .25188 .65399 L .25244 .65057 L F
.394 0 0 r
.25244 .65057 m .2521 .65158 L .25055 .6511 L F
0 .424 .792 r
.25055 .6511 m .2521 .65158 L .25105 .65102 L F
0 0 0 r
.25119 .64949 m .25018 .65117 L .25055 .6511 L F
0 .424 .792 r
.25055 .6511 m .25105 .65102 L .24976 .65033 L F
0 0 0 r
.25018 .65117 m .24869 .65363 L .25055 .6511 L F
.568 .265 .415 r
.24869 .65363 m .25188 .65399 L .25055 .6511 L F
.24869 .65363 m .24882 .65524 L .25188 .65399 L F
.94 .862 .736 r
.50938 .78819 m .50957 .78488 L .50933 .78605 L F
.789 .374 .264 r
.49045 .80437 m .4901 .80298 L .48904 .80236 L F
.767 .556 .613 r
.49045 .80437 m .49337 .80232 L .4901 .80298 L F
.87 .692 .658 r
.66237 .49166 m .66367 .49487 L .66452 .4926 L F
.35 .64 .963 r
.50902 .64415 m .50978 .64296 L .50773 .64272 L F
.107 .309 .783 r
.50902 .64415 m .5114 .64621 L .50978 .64296 L F
.809 .608 .63 r
.48904 .80236 m .4865 .79935 L .48662 .80175 L F
.802 .37 .222 r
.48868 .80429 m .48904 .80236 L .48662 .80175 L F
.48868 .80429 m .49045 .80437 L .48904 .80236 L F
.526 .32 .544 r
.61205 .51202 m .612 .51427 L .61446 .51151 L F
.44 0 0 r
.43537 .69715 m .43418 .69759 L .43769 .69748 L F
0 0 0 r
.4216 .71099 m .42323 .7102 L .42539 .70957 L F
.331 .725 .982 r
.33273 .60082 m .33513 .60152 L .33387 .60062 L F
.415 .769 .995 r
.33711 .60122 m .33387 .60062 L .33513 .60152 L F
.421 .828 .976 r
.68922 .47679 m .68553 .4767 L .68658 .47748 L F
.878 .547 .419 r
.56394 .75303 m .56589 .7507 L .56349 .75054 L F
.56394 .75303 m .56668 .75596 L .56589 .7507 L F
.955 .614 .236 r
.56656 .75595 m .5675 .75663 L .56741 .75576 L F
.56656 .75595 m .56741 .75576 L .56668 .75596 L F
.94 .617 .176 r
.56589 .7507 m .56668 .75596 L .56741 .75576 L F
0 0 0 r
.53251 .80055 m .53209 .80243 L .53171 .80487 L F
.429 .214 .484 r
.36831 .61917 m .36784 .62177 L .36571 .62181 L F
.378 .104 .366 r
.36722 .62343 m .36571 .62181 L .36784 .62177 L F
.36722 .62343 m .36524 .62409 L .36571 .62181 L F
.603 .397 .575 r
.50815 .76289 m .51061 .76447 L .51089 .76208 L F
.50815 .76289 m .50796 .76507 L .51061 .76447 L F
.863 .984 .701 r
.6288 .56946 m .62832 .57148 L .63033 .56844 L F
0 0 0 r
.6288 .56946 m .62749 .57317 L .62832 .57148 L F
.574 .307 .475 r
.59135 .60492 m .59141 .607 L .58835 .6078 L F
.639 .358 .477 r
.59135 .60492 m .59369 .60701 L .59141 .607 L F
.654 .353 .45 r
.5937 .60513 m .59369 .60701 L .59135 .60492 L F
.476 0 0 r
.50383 .76903 m .50231 .76894 L .50209 .76841 L F
0 0 .151 r
.50209 .76841 m .50231 .76894 L .50213 .76568 L F
0 0 .393 r
.54356 .75401 m .54603 .75616 L .54657 .7533 L F
.686 .98 .838 r
.54657 .7533 m .54892 .75161 L .54943 .75117 L F
.532 .146 .254 r
.54657 .7533 m .54855 .75559 L .54892 .75161 L F
.54657 .7533 m .54603 .75616 L .54855 .75559 L F
.808 .579 .591 r
.58662 .59893 m .58653 .59658 L .58331 .59588 L F
.621 .431 .603 r
.58905 .599 m .58653 .59658 L .58662 .59893 L F
.58905 .599 m .589 .59628 L .58653 .59658 L F
.503 .521 .808 r
.67086 .51466 m .67172 .51792 L .67409 .51632 L F
.5 .514 .803 r
.67172 .51792 m .67489 .51905 L .67409 .51632 L F
.595 .703 .918 r
.67253 .52001 m .67489 .51905 L .67172 .51792 L F
.725 .642 .765 r
.75748 .58774 m .75854 .59106 L .75495 .59054 L F
.584 .531 .762 r
.75748 .58774 m .76046 .59061 L .75854 .59106 L F
.762 .265 0 r
.55705 .75564 m .5555 .75373 L .55609 .75576 L F
.779 .72 .797 r
.70329 .51674 m .70468 .518 L .70363 .51477 L F
.881 .793 .758 r
.70145 .5197 m .70468 .518 L .70329 .51674 L F
.791 .726 .792 r
.70363 .51477 m .70468 .518 L .70703 .51502 L F
.332 0 0 r
.66815 .47484 m .67034 .47516 L .67168 .47491 L F
.341 0 0 r
.67287 .47557 m .67168 .47491 L .67034 .47516 L F
.67287 .47557 m .67339 .47583 L .67168 .47491 L F
0 .129 .668 r
.47239 .80502 m .47335 .80799 L .4737 .80733 L F
0 0 .23 r
.47335 .80799 m .47371 .80902 L .4737 .80733 L F
.47335 .80799 m .47373 .81061 L .47371 .80902 L F
0 0 .098 r
.6139 .5953 m .61202 .59822 L .61237 .59637 L F
.277 0 0 r
.31751 .60195 m .31625 .60234 L .31405 .60229 L F
0 0 0 r
.31975 .60167 m .31625 .60234 L .31751 .60195 L F
.739 .721 .835 r
.70416 .50417 m .70093 .5035 L .70326 .50245 L F
.558 .673 .915 r
.70558 .50201 m .70416 .50417 L .70326 .50245 L F
.70558 .50201 m .70691 .50382 L .70416 .50417 L F
.281 0 0 r
.75933 .59643 m .75918 .5968 L .75651 .59679 L F
.279 0 .243 r
.54313 .78842 m .54582 .78583 L .54475 .78672 L F
0 0 0 r
.54475 .78672 m .54582 .78583 L .5476 .78498 L F
.783 .707 .78 r
.51873 .78557 m .52245 .78803 L .52232 .7856 L F
.857 .629 .591 r
.63742 .50856 m .63747 .51181 L .63914 .51005 L F
.622 .447 .624 r
.63914 .51005 m .64111 .51172 L .64086 .50923 L F
0 0 0 r
.63914 .51005 m .63889 .51064 L .64111 .51172 L F
.63914 .51005 m .63747 .51181 L .63889 .51064 L F
.526 .559 .832 r
.47502 .78533 m .47706 .78498 L .47566 .78187 L F
.95 .882 .731 r
.65348 .51481 m .65391 .51075 L .65435 .51252 L F
.727 .845 .937 r
.4079 .71201 m .40977 .71319 L .41147 .71191 L F
.433 .281 .574 r
.40152 .703 m .40311 .70298 L .40323 .70059 L F
.177 0 0 r
.50607 .76819 m .50231 .76894 L .50383 .76903 L F
.296 .377 .777 r
.26372 .62475 m .26395 .62122 L .26242 .62126 L F
.26372 .62475 m .26504 .62441 L .26395 .62122 L F
.637 .481 .654 r
.26372 .62475 m .26614 .62724 L .26504 .62441 L F
.26372 .62475 m .26332 .62763 L .26614 .62724 L F
.211 0 0 r
.284 .58576 m .28544 .58604 L .28733 .58506 L F
.254 0 0 r
.28544 .58604 m .28946 .58481 L .28733 .58506 L F
.855 .796 .792 r
.73883 .48674 m .73526 .48845 L .7376 .48551 L F
.73883 .48674 m .73675 .48972 L .73526 .48845 L F
.79 .826 .88 r
.74125 .48464 m .73883 .48674 L .7376 .48551 L F
.32 .214 .574 r
.47981 .77354 m .47861 .77621 L .47869 .77417 L F
.495 .244 .463 r
.59851 .53157 m .60085 .53104 L .60101 .52906 L F
.443 .175 .411 r
.60085 .53104 m .60333 .5286 L .60101 .52906 L F
.304 0 0 r
.4482 .70289 m .44691 .70432 L .44496 .70416 L F
.25 0 0 r
.45062 .70265 m .44691 .70432 L .4482 .70289 L F
.794 .511 .508 r
.51198 .7962 m .51189 .79397 L .50863 .79371 L F
.746 .592 .685 r
.24306 .65275 m .24339 .65277 L .24474 .65011 L F
.187 0 0 r
.51668 .69288 m .51746 .69393 L .51859 .69199 L F
.51668 .69288 m .51541 .69455 L .51746 .69393 L F
.833 .764 .786 r
.70209 .48227 m .70474 .48097 L .70463 .48162 L F
.563 .782 .981 r
.26719 .64394 m .27108 .64474 L .26939 .64334 L F
.703 .827 .941 r
.26939 .64334 m .27108 .64474 L .27229 .64332 L F
.715 .247 .138 r
.4852 .6981 m .48389 .69927 L .48171 .69734 L F
.505 0 0 r
.48754 .69918 m .48389 .69927 L .4852 .6981 L F
.395 .012 .191 r
.41591 .65702 m .41661 .65559 L .41439 .65603 L F
.434 0 .077 r
.41591 .65702 m .41439 .65603 L .41301 .65759 L F
.578 .45 .67 r
.5051 .62738 m .50277 .63037 L .50158 .62695 L F
.5051 .62738 m .50502 .62962 L .50277 .63037 L F
.057 0 .005 r
.60813 .60003 m .60992 .59896 L .60728 .60147 L F
.703 .696 .84 r
.71273 .50389 m .71099 .50633 L .70908 .50264 L F
.914 .627 .485 r
.53196 .61336 m .53016 .61496 L .52971 .61287 L F
.53196 .61336 m .53207 .61591 L .53016 .61496 L F
.82 .478 .407 r
.74079 .52749 m .74422 .5302 L .74105 .52959 L F
.781 .401 0 r
.74107 .52895 m .74175 .5299 L .74144 .52913 L F
.74101 .52861 m .74144 .52913 L .74079 .52749 L F
.74107 .52895 m .74144 .52913 L .74101 .52861 L F
.695 .675 .827 r
.74513 .53104 m .74215 .52998 L .74422 .5302 L F
.74215 .52998 m .74105 .52959 L .74197 .52977 L F
.74215 .52998 m .74197 .52977 L .74422 .5302 L F
.768 .478 .495 r
.74105 .52959 m .7429 .53211 L .7384 .53031 L F
.7429 .53211 m .74295 .53218 L .74284 .53213 L F
.7429 .53211 m .74284 .53213 L .7384 .53031 L F
.241 0 0 r
.74311 .53202 m .74426 .53229 L .74181 .53264 L F
.74513 .53104 m .74504 .53118 L .74311 .53202 L F
.74504 .53118 m .74426 .53229 L .74311 .53202 L F
.353 .762 .981 r
.74422 .5302 m .74749 .53073 L .74513 .53104 L F
.979 .727 .32 r
.74422 .5302 m .74513 .53104 L .74749 .53073 L F
.74422 .5302 m .74426 .53229 L .74513 .53104 L F
.515 .888 .97 r
.48313 .79637 m .48595 .79549 L .48392 .79524 L F
0 0 .272 r
.48341 .79837 m .48313 .79637 L .48392 .79524 L F
.335 0 0 r
.37998 .59724 m .38358 .59752 L .38117 .59788 L F
.306 0 0 r
.71565 .50223 m .71484 .50293 L .71803 .50214 L F
.348 .825 .827 r
.67339 .47583 m .67689 .47482 L .67718 .47495 L F
.595 .916 .975 r
.67718 .47495 m .67859 .47348 L .67948 .47399 L F
.599 .941 .769 r
.67718 .47495 m .67689 .47482 L .67859 .47348 L F
.716 .6 .726 r
.5935 .59052 m .59597 .58817 L .59339 .58802 L F
.924 .648 .499 r
.78363 .5921 m .78329 .59456 L .78226 .59356 L F
.791 .792 .853 r
.78226 .59356 m .7827 .596 L .7853 .59351 L F
.241 0 0 r
.43605 .65009 m .43828 .64989 L .43943 .64917 L F
.222 0 0 r
.43828 .64989 m .44164 .64893 L .43943 .64917 L F
.446 .87 .752 r
.66815 .47484 m .66588 .47606 L .66458 .47649 L F
.637 .765 .94 r
.67667 .48448 m .67556 .48458 L .67528 .4828 L F
.67667 .48448 m .67556 .48458 L .67528 .4828 L F
.783 .707 .78 r
.51873 .78557 m .51892 .78826 L .52245 .78803 L F
.924 .948 .791 r
.5192 .79051 m .52245 .78803 L .51892 .78826 L F
.5192 .79051 m .52015 .791 L .52245 .78803 L F
.701 .519 .639 r
.52015 .791 m .52284 .79102 L .52245 .78803 L F
.494 .32 .573 r
.52284 .79102 m .52467 .7878 L .52245 .78803 L F
.29 .08 .412 r
.60397 .58518 m .6063 .58422 L .60665 .58211 L F
.23 .073 .451 r
.60469 .58742 m .6063 .58422 L .60397 .58518 L F
.564 .321 .507 r
.6017 .58794 m .60469 .58742 L .60397 .58518 L F
.674 .2 .118 r
.73692 .51806 m .73649 .51914 L .73344 .51725 L F
.967 .715 .282 r
.73626 .51664 m .73649 .51914 L .73692 .51806 L F
.494 .092 .207 r
.33993 .64121 m .33625 .64329 L .33791 .64194 L F
.928 .702 .576 r
.72769 .4967 m .72682 .50137 L .72926 .49889 L F
.963 .834 .668 r
.72692 .50241 m .72926 .49889 L .72682 .50137 L F
.72692 .50241 m .728 .50347 L .72926 .49889 L F
.89 .91 .833 r
.56205 .77758 m .56282 .77406 L .56167 .77543 L F
.56205 .77758 m .56383 .77508 L .56282 .77406 L F
.713 .454 .532 r
.60491 .60189 m .60175 .60401 L .60257 .60209 L F
.501 .217 .414 r
.3488 .61311 m .35107 .61273 L .3516 .61063 L F
.261 .004 .322 r
.3516 .61063 m .35281 .61178 L .35369 .61007 L F
.3516 .61063 m .35107 .61273 L .35281 .61178 L F
.725 .64 .763 r
.57665 .58233 m .58079 .5826 L .57957 .57955 L F
.797 .655 .705 r
.57661 .5845 m .58079 .5826 L .57665 .58233 L F
.57661 .5845 m .58052 .58512 L .58079 .5826 L F
.202 .344 .785 r
.74681 .49092 m .74564 .49229 L .74473 .4912 L F
.74681 .49092 m .74784 .49375 L .74564 .49229 L F
0 0 .322 r
.74771 .49589 m .7479 .50031 L .74738 .49766 L F
.821 .585 .581 r
.47999 .79026 m .48179 .78839 L .4788 .78793 L F
.47999 .79026 m .48167 .79026 L .48179 .78839 L F
.628 .415 .574 r
.48167 .79026 m .4841 .78808 L .48179 .78839 L F
.556 .447 .686 r
.26296 .63578 m .26581 .6386 L .26559 .63568 L F
.26296 .63578 m .26353 .63909 L .26581 .6386 L F
.094 0 0 r
.28946 .58481 m .29158 .58462 L .29316 .58417 L F
.358 0 0 r
.29316 .58417 m .29158 .58462 L .29518 .58446 L F
.649 .434 .579 r
.58614 .70088 m .58179 .70306 L .58282 .70113 L F
.58614 .70088 m .58586 .70324 L .58179 .70306 L F
.65 .525 .699 r
.5666 .62729 m .56732 .63042 L .56436 .6302 L F
.727 .529 .624 r
.56754 .63282 m .56436 .6302 L .56732 .63042 L F
.56754 .63282 m .56535 .63322 L .56436 .6302 L F
.44 .052 .206 r
.52664 .77034 m .52881 .77033 L .53007 .76809 L F
.234 0 0 r
.52881 .77033 m .53221 .76885 L .53007 .76809 L F
.284 .762 .929 r
.48014 .64691 m .47853 .64655 L .47634 .64675 L F
.581 .01 0 r
.48167 .64759 m .47853 .64655 L .48014 .64691 L F
.584 .588 .823 r
.51667 .65368 m .52007 .65526 L .51907 .65321 L F
.853 .466 .312 r
.53975 .62697 m .53634 .62385 L .53876 .62503 L F
.758 .357 0 r
.58183 .59313 m .58331 .59588 L .58343 .59377 L F
.135 .606 .922 r
.66614 .50812 m .66318 .50696 L .66423 .50827 L F
.531 .263 .454 r
.58835 .6078 m .58572 .61007 L .58577 .60794 L F
.635 .547 .738 r
.57656 .71511 m .57441 .717 L .57313 .71356 L F
.66 .945 .959 r
.48458 .65801 m .48196 .65931 L .48293 .65913 L F
.48293 .65913 m .48196 .65931 L .48458 .65801 L F
0 0 .184 r
.59744 .55392 m .59703 .55613 L .59575 .55728 L F
.45 .282 .56 r
.59703 .55613 m .59495 .55863 L .59575 .55728 L F
0 0 0 r
.30439 .65008 m .30497 .65012 L .30257 .64957 L F
.30439 .65008 m .30651 .64961 L .30497 .65012 L F
.229 0 .202 r
.3558 .63022 m .35498 .63259 L .35301 .63292 L F
.143 0 .165 r
.35669 .63148 m .3558 .63022 L .35779 .62961 L F
.35669 .63148 m .35498 .63259 L .3558 .63022 L F
.869 .989 .727 r
.53558 .79686 m .53311 .79966 L .53546 .79909 L F
.707 .523 .637 r
.48958 .8111 m .48903 .81263 L .48607 .81273 L F
.36 .164 .473 r
.49133 .81045 m .48903 .81263 L .48958 .8111 L F
0 .01 .551 r
.5818 .69564 m .58306 .69655 L .5827 .69444 L F
.566 .381 .59 r
.50185 .7886 m .50418 .78804 L .50373 .78515 L F
.62 .372 .52 r
.50418 .78804 m .5071 .78524 L .50373 .78515 L F
.596 .491 .705 r
.55706 .71775 m .55943 .71734 L .55874 .71738 L F
.626 .534 .731 r
.55785 .72093 m .55943 .71734 L .55706 .71775 L F
.878 .789 .759 r
.73526 .48845 m .73675 .48972 L .73587 .49172 L F
.816 .734 .774 r
.54162 .77081 m .54642 .76757 L .5416 .76838 L F
.537 .341 .563 r
.24614 .65571 m .24339 .65277 L .24317 .65287 L F
.368 0 0 r
.55031 .75245 m .54943 .75117 L .54892 .75161 L F
.579 .475 .699 r
.54855 .75559 m .55031 .75245 L .54892 .75161 L F
.373 .79 .977 r
.35965 .5902 m .35901 .591 L .35753 .59023 L F
.35965 .5902 m .36113 .59073 L .35901 .591 L F
.908 .853 .777 r
.63591 .52838 m .63627 .53115 L .63724 .52946 L F
.791 .678 .74 r
.57839 .58783 m .58052 .58512 L .57661 .5845 L F
.731 .587 .694 r
.57839 .58783 m .58198 .5883 L .58052 .58512 L F
.3 0 0 r
.70549 .4828 m .70747 .48372 L .70871 .4843 L F
.70871 .4843 m .70747 .48372 L .70549 .4828 L F
.633 .676 .873 r
.56639 .72286 m .56972 .72503 L .56879 .72237 L F
.511 .604 .883 r
.56972 .72503 m .57099 .72205 L .56879 .72237 L F
.56972 .72503 m .57227 .72465 L .57099 .72205 L F
.969 .65 .329 r
.53706 .77411 m .53629 .77573 L .53563 .77366 L F
.53706 .77411 m .53748 .77662 L .53629 .77573 L F
.825 .471 .385 r
.53706 .77411 m .54056 .7769 L .53748 .77662 L F
.553 .381 .603 r
.40054 .66107 m .40264 .65816 L .40016 .65868 L F
.717 .568 .685 r
.57327 .61874 m .57065 .61899 L .57302 .61621 L F
.95 .882 .731 r
.65348 .51481 m .65242 .51386 L .65391 .51075 L F
0 .32 .804 r
.65348 .51481 m .65525 .51549 L .65242 .51386 L F
.65348 .51481 m .65606 .51648 L .65525 .51549 L F
.533 0 0 r
.51252 .76198 m .51375 .76226 L .51089 .76208 L F
.51252 .76198 m .51474 .76284 L .51375 .76226 L F
.878 .789 .759 r
.73526 .48845 m .73587 .49172 L .73435 .49146 L F
.969 .922 .695 r
.73587 .49172 m .73402 .49325 L .73435 .49146 L F
.73587 .49172 m .7345 .4946 L .73402 .49325 L F
.415 .283 .592 r
.40264 .65816 m .4047 .66016 L .40609 .65846 L F
.36 0 0 r
.40684 .65962 m .40609 .65846 L .4047 .66016 L F
.40684 .65962 m .40848 .65837 L .40609 .65846 L F
.733 .572 .673 r
.58187 .59066 m .58198 .5883 L .57839 .58783 L F
.463 .259 .517 r
.34233 .62205 m .34436 .62144 L .34454 .61905 L F
.328 0 .218 r
.34156 .62358 m .34436 .62144 L .34233 .62205 L F
.124 .017 .449 r
.60887 .57675 m .60887 .57931 L .60996 .57587 L F
.968 .927 .692 r
.63167 .5655 m .62985 .56772 L .63033 .56844 L F
.938 .963 .681 r
.6288 .56946 m .63033 .56844 L .62985 .56772 L F
.577 .903 .981 r
.47176 .63625 m .47266 .63498 L .47355 .63512 L F
.47176 .63625 m .47046 .63581 L .47266 .63498 L F
.125 0 0 r
.55276 .75594 m .55084 .75739 L .55074 .75634 L F
.815 .702 .74 r
.695 .5172 m .69309 .5203 L .69189 .51699 L F
.506 .872 .645 r
.4865 .79935 m .48866 .79773 L .48757 .79836 L F
.472 0 0 r
.48757 .79836 m .48866 .79773 L .49096 .79875 L F
.74 .358 .33 r
.51588 .78219 m .51792 .78454 L .5189 .78264 L F
.245 .034 .382 r
.60835 .52031 m .60999 .51954 L .61032 .51749 L F
.263 .068 .417 r
.60835 .52031 m .60815 .52261 L .60999 .51954 L F
.705 .492 .597 r
.49272 .80469 m .49578 .80218 L .49337 .80232 L F
.715 .508 .608 r
.49272 .80469 m .49606 .80502 L .49578 .80218 L F
.453 .251 .515 r
.34454 .61905 m .34636 .62081 L .3468 .61866 L F
.34454 .61905 m .34436 .62144 L .34636 .62081 L F
.896 .681 .604 r
.55467 .64158 m .55167 .643 L .55147 .64096 L F
.55467 .64158 m .55456 .64412 L .55167 .643 L F
.751 .641 .739 r
.52066 .65608 m .5204 .65852 L .52217 .65495 L F
.523 .156 .285 r
.71747 .49489 m .71975 .49498 L .71856 .49437 L F
.71747 .49489 m .71975 .49498 L .71856 .49437 L F
.451 .25 .516 r
.72167 .49386 m .71975 .49498 L .71856 .49437 L F
.72167 .49386 m .71975 .49498 L .71856 .49437 L F
.651 .488 .651 r
.24922 .66457 m .24881 .66633 L .25138 .66402 L F
.663 .662 .839 r
.55182 .78836 m .55481 .78868 L .55335 .78724 L F
.672 .749 .908 r
.55335 .78724 m .55166 .78971 L .55182 .78836 L F
.55335 .78724 m .55481 .78868 L .55166 .78971 L F
.168 0 .168 r
.58403 .54808 m .58618 .54752 L .58669 .54541 L F
.119 0 .144 r
.58669 .54541 m .58868 .54471 L .58913 .54285 L F
.19 0 .324 r
.58827 .54667 m .58669 .54541 L .58618 .54752 L F
.58827 .54667 m .58868 .54471 L .58669 .54541 L F
.292 .508 .894 r
.51162 .6362 m .51451 .63731 L .51354 .63869 L F
.151 .308 .77 r
.51451 .63731 m .51577 .64055 L .51354 .63869 L F
.612 .463 .655 r
.5944 .71214 m .59164 .71489 L .59053 .71166 L F
.5944 .71214 m .5945 .71478 L .59164 .71489 L F
.558 .237 .379 r
.5945 .71478 m .5938 .716 L .59164 .71489 L F
.486 .319 .58 r
.59164 .71489 m .5938 .716 L .59172 .71735 L F
.693 .786 .922 r
.67528 .4828 m .67667 .48448 L .67871 .48324 L F
.687 .791 .929 r
.26531 .63995 m .26581 .6386 L .26353 .63909 L F
.672 .656 .826 r
.68841 .51646 m .68721 .52039 L .68607 .51723 L F
.68841 .51646 m .68959 .5198 L .68721 .52039 L F
.246 0 0 r
.42856 .70838 m .42761 .70923 L .42539 .70957 L F
.31 0 0 r
.43094 .70785 m .42761 .70923 L .42856 .70838 L F
.367 0 .074 r
.43724 .66666 m .43594 .66837 L .43375 .6687 L F
.214 0 0 r
.43815 .66755 m .43724 .66666 L .43958 .66614 L F
.43815 .66755 m .43594 .66837 L .43724 .66666 L F
.597 .396 .579 r
.56017 .63591 m .56004 .63874 L .55723 .63863 L F
.398 .232 .537 r
.56182 .63754 m .56017 .63591 L .56166 .63504 L F
.56182 .63754 m .56004 .63874 L .56017 .63591 L F
.188 0 .299 r
.57138 .70336 m .57271 .70447 L .57349 .70342 L F
.57138 .70336 m .57107 .70577 L .57271 .70447 L F
.519 .43 .694 r
.39271 .67817 m .39478 .67769 L .39426 .67528 L F
.467 .334 .615 r
.39271 .67817 m .39483 .68011 L .39478 .67769 L F
.39271 .67817 m .39284 .68068 L .39483 .68011 L F
.406 .214 .504 r
.25581 .602 m .25764 .60144 L .25782 .59916 L F
.413 .268 .573 r
.25581 .602 m .25758 .60381 L .25764 .60144 L F
.25581 .602 m .25548 .60539 L .25758 .60381 L F
.635 .244 .286 r
.50153 .77434 m .5034 .776 L .50469 .77401 L F
.807 .647 .684 r
.5034 .776 m .50692 .77348 L .50469 .77401 L F
0 0 .345 r
.65391 .49186 m .65402 .49319 L .65251 .4948 L F
0 .269 .773 r
.65478 .49558 m .65251 .4948 L .65402 .49319 L F
.806 .668 .711 r
.65269 .49213 m .65414 .49452 L .65402 .49319 L F
.65414 .49452 m .65478 .49558 L .65402 .49319 L F
0 0 .345 r
.65454 .49054 m .65402 .49319 L .65391 .49186 L F
0 .269 .773 r
.65478 .49558 m .65484 .49668 L .65251 .4948 L F
.272 .321 .731 r
.65251 .4948 m .65484 .49668 L .65405 .4971 L F
.795 .973 .91 r
.47425 .79531 m .47231 .79706 L .47242 .79546 L F
0 0 .303 r
.47242 .79546 m .47231 .79706 L .47289 .79875 L F
.804 .627 .662 r
.62201 .54299 m .61822 .54483 L .62016 .54187 L F
.62201 .54299 m .62108 .54516 L .61822 .54483 L F
.626 .534 .731 r
.55785 .72093 m .56021 .72095 L .55943 .71734 L F
.626 .499 .687 r
.55785 .72093 m .55841 .72345 L .56021 .72095 L F
.593 .559 .786 r
.35387 .6077 m .35548 .60484 L .35306 .6054 L F
.35387 .6077 m .35605 .60736 L .35548 .60484 L F
.549 .344 .555 r
.35369 .61007 m .35605 .60736 L .35387 .6077 L F
.862 .676 .649 r
.51198 .7962 m .51361 .79992 L .51386 .79675 L F
.872 .596 .517 r
.64281 .4804 m .64298 .48268 L .64583 .48325 L F
.842 .787 .798 r
.64298 .48268 m .64412 .48391 L .64583 .48325 L F
.535 .554 .822 r
.24481 .64983 m .24178 .64941 L .24439 .64802 L F
.746 .592 .685 r
.24306 .65275 m .24481 .64983 L .24337 .65053 L F
.204 .396 .83 r
.24439 .64802 m .24592 .64864 L .24481 .64983 L F
.601 .425 .615 r
.24169 .64953 m .24451 .6498 L .24439 .64802 L F
.392 .298 .628 r
.24439 .64802 m .24482 .64957 L .24592 .64864 L F
.567 .916 .713 r
.24561 .64897 m .24482 .64957 L .24481 .64983 L F
.392 .298 .628 r
.24482 .64957 m .2449 .64984 L .24592 .64864 L F
.567 .916 .713 r
.24482 .64957 m .24451 .6498 L .24454 .6498 L F
.24482 .64957 m .24454 .6498 L .24481 .64983 L F
.24445 .64985 m .24383 .65031 L .24387 .65029 L F
.24444 .64985 m .24383 .65031 L .24445 .64985 L F
.24451 .6498 m .24387 .65029 L .24481 .64983 L F
.459 .017 .11 r
.24445 .64985 m .24337 .65053 L .2449 .64984 L F
.24174 .64991 m .24337 .65053 L .24445 .64985 L F
.24445 .64985 m .24451 .6498 L .24169 .64953 L F
.567 .916 .713 r
.24451 .6498 m .24444 .64985 L .24445 .64985 L F
.459 .017 .11 r
.24174 .64991 m .24445 .64985 L .24169 .64953 L F
.24445 .64985 m .2449 .64984 L .24451 .6498 L F
.601 .425 .615 r
.24451 .6498 m .2449 .64984 L .24482 .64957 L F
.24451 .6498 m .24482 .64957 L .24439 .64802 L F
.567 .916 .713 r
.24592 .64864 m .24337 .65053 L .24383 .65031 L F
.24592 .64864 m .24383 .65031 L .24561 .64897 L F
.169 0 .159 r
.58185 .55104 m .58367 .55003 L .58403 .54808 L F
.164 0 .158 r
.58367 .55003 m .58618 .54752 L .58403 .54808 L F
.109 0 0 r
.29395 .58472 m .29537 .58484 L .29733 .58425 L F
.525 .073 .12 r
.29537 .58484 m .29719 .58417 L .29733 .58425 L F
.29719 .58417 m .29955 .58329 L .29733 .58425 L F
.123 .673 .769 r
.29743 .58431 m .29733 .58425 L .2988 .58421 L F
.29518 .58446 m .29733 .58425 L .29743 .58431 L F
.517 .912 .917 r
.2988 .58421 m .29955 .58329 L .30099 .58399 L F
.2988 .58421 m .29733 .58425 L .29955 .58329 L F
.585 .267 .396 r
.49935 .80516 m .5015 .80699 L .50167 .80409 L F
.443 .259 .536 r
.50167 .80409 m .50452 .80446 L .50518 .80252 L F
.776 .681 .759 r
.5015 .80699 m .50452 .80446 L .50167 .80409 L F
.732 .58 .685 r
.72171 .47861 m .72238 .48063 L .71918 .48111 L F
.617 .622 .833 r
.72346 .47534 m .72171 .47861 L .72102 .47561 L F
.72346 .47534 m .72447 .47835 L .72171 .47861 L F
.617 .516 .717 r
.72447 .47835 m .72238 .48063 L .72171 .47861 L F
0 0 .217 r
.62304 .52301 m .62486 .51977 L .62531 .52295 L F
.603 .085 0 r
.53748 .77662 m .54056 .7769 L .53771 .77815 L F
.151 0 0 r
.54056 .7769 m .54179 .77738 L .53771 .77815 L F
.54056 .7769 m .54287 .77664 L .54179 .77738 L F
.368 .005 .21 r
.53245 .75727 m .53563 .75434 L .53569 .75693 L F
.53245 .75727 m .53569 .75693 L .53364 .75619 L F
.53245 .75727 m .53364 .75619 L .53338 .75609 L F
.53245 .75727 m .53562 .7544 L .53563 .75434 L F
.261 .768 .853 r
.53569 .75693 m .53245 .75727 L .53338 .75609 L F
.368 .005 .21 r
.53245 .75727 m .53507 .75678 L .53562 .7544 L F
0 0 .068 r
.53563 .75434 m .53566 .75594 L .53569 .75693 L F
.53563 .75434 m .53507 .75678 L .53566 .75594 L F
.273 .723 .958 r
.32535 .58747 m .32724 .58751 L .3289 .5881 L F
.528 .544 .816 r
.33077 .58757 m .3289 .5881 L .32724 .58751 L F
.33077 .58757 m .33075 .58809 L .3289 .5881 L F
.773 .664 .742 r
.24564 .66409 m .24756 .66131 L .24443 .66096 L F
.965 .786 .612 r
.63407 .53872 m .63532 .54168 L .63534 .53983 L F
.63407 .53872 m .63311 .5419 L .63532 .54168 L F
.966 .68 .437 r
.63311 .5419 m .63498 .54458 L .63532 .54168 L F
.791 .726 .792 r
.70363 .51477 m .70703 .51502 L .70544 .51378 L F
.809 .759 .806 r
.70703 .51502 m .70798 .51099 L .70544 .51378 L F
.672 .722 .887 r
.71839 .51678 m .72185 .51757 L .72048 .51608 L F
.757 .741 .837 r
.72048 .51608 m .72185 .51757 L .72438 .51505 L F
.24 0 0 r
.3256 .6321 m .32761 .63162 L .32929 .62977 L F
.029 0 0 r
.32929 .62977 m .33037 .62983 L .33143 .62946 L F
.32929 .62977 m .32761 .63162 L .33037 .62983 L F
.643 .541 .723 r
.57549 .71136 m .57313 .71356 L .57315 .71191 L F
.57549 .71136 m .57656 .71511 L .57313 .71356 L F
.779 .61 .67 r
.63512 .4996 m .63913 .49871 L .63777 .49878 L F
.63512 .4996 m .63784 .50072 L .63913 .49871 L F
.711 .404 .456 r
.6405 .4969 m .63777 .49878 L .63913 .49871 L F
.911 .854 .774 r
.63591 .52838 m .63477 .53076 L .63627 .53115 L F
.388 .439 .793 r
.48008 .77629 m .47954 .7796 L .47861 .77621 L F
.48008 .77629 m .48101 .77935 L .47954 .7796 L F
.359 .269 .616 r
.48101 .77935 m .48137 .78165 L .47954 .7796 L F
.354 0 0 r
.31089 .64897 m .30863 .64968 L .30873 .64967 L F
.21 0 0 r
.30651 .64961 m .30873 .64967 L .30703 .65017 L F
.354 0 0 r
.30863 .64968 m .30703 .65017 L .30873 .64967 L F
.025 0 0 r
.30651 .64961 m .30882 .64966 L .30873 .64967 L F
.30882 .64966 m .31001 .64968 L .30873 .64967 L F
.412 .86 .89 r
.31089 .64897 m .31001 .64968 L .31205 .64899 L F
.411 .859 .892 r
.30873 .64967 m .31001 .64968 L .31089 .64897 L F
.908 .848 .773 r
.73494 .5002 m .73332 .49938 L .73505 .49676 L F
.977 .915 .6 r
.73494 .5002 m .73344 .50212 L .73332 .49938 L F
.73494 .5002 m .73394 .50304 L .73344 .50212 L F
.748 .726 .832 r
.69529 .50588 m .69613 .50868 L .69278 .50843 L F
.57 .366 .565 r
.69613 .50868 m .69387 .51166 L .69278 .50843 L F
.69613 .50868 m .69641 .51123 L .69387 .51166 L F
.751 .728 .831 r
.69881 .50619 m .69613 .50868 L .69529 .50588 L F
.343 0 .011 r
.45636 .70075 m .45497 .70241 L .45273 .70268 L F
.312 0 0 r
.45867 .70102 m .45497 .70241 L .45636 .70075 L F
.274 .088 .437 r
.61396 .50577 m .61551 .50528 L .61524 .50344 L F
.448 .321 .614 r
.61385 .50855 m .61551 .50528 L .61396 .50577 L F
0 0 .217 r
.62304 .52301 m .62326 .5229 L .62486 .51977 L F
.854 .741 .738 r
.7148 .48905 m .71619 .49055 L .71456 .49077 L F
.683 .724 .881 r
.71837 .48893 m .71619 .49055 L .7148 .48905 L F
.396 .074 .297 r
.58106 .55269 m .57977 .55134 L .57917 .55374 L F
.58106 .55269 m .58185 .55104 L .57977 .55134 L F
.326 .411 .796 r
.24811 .67529 m .24821 .67534 L .24815 .67539 L F
0 0 0 r
.24815 .67539 m .24821 .67534 L .2481 .67546 L F
.578 .414 .624 r
.64086 .50923 m .64111 .51172 L .64343 .50886 L F
.696 .761 .902 r
.50158 .62695 m .4992 .62774 L .49803 .62626 L F
.574 .397 .604 r
.61232 .54223 m .60989 .54495 L .60981 .54257 L F
.767 .556 .613 r
.49045 .80437 m .49272 .80469 L .49337 .80232 L F
.688 .483 .605 r
.58586 .70324 m .58327 .70533 L .58179 .70306 L F
.603 .43 .62 r
.74264 .50843 m .74134 .51172 L .74105 .50884 L F
.432 .374 .692 r
.42069 .68837 m .42089 .6929 L .4192 .69244 L F
.342 .463 .838 r
.42089 .6929 m .42181 .69371 L .4192 .69244 L F
.573 .362 .556 r
.5809 .61308 m .57885 .61509 L .57861 .61323 L F
0 0 .325 r
.63203 .511 m .63185 .5137 L .63096 .51414 L F
.078 .318 .798 r
.63185 .5137 m .63259 .51609 L .63096 .51414 L F
.47 .145 .333 r
.49321 .64127 m .49022 .64379 L .49058 .64144 L F
.49321 .64127 m .49269 .64369 L .49022 .64379 L F
.113 0 .213 r
.49478 .64081 m .49269 .64369 L .49321 .64127 L F
.896 .486 .211 r
.71539 .48037 m .71671 .48085 L .71596 .48217 L F
.662 .17 .071 r
.71671 .48085 m .7192 .48257 L .71596 .48217 L F
.634 .271 .336 r
.71918 .48111 m .7192 .48257 L .71671 .48085 L F
.84 .67 .671 r
.51458 .80777 m .5156 .81071 L .51268 .80997 L F
.771 .321 .18 r
.51268 .80997 m .5156 .81071 L .51391 .81168 L F
.628 .56 .758 r
.51757 .80866 m .5156 .81071 L .51458 .80777 L F
.697 .963 .721 r
.51391 .81168 m .5156 .81071 L .51757 .80866 L F
.716 .6 .726 r
.5935 .59052 m .59687 .5908 L .59597 .58817 L F
.719 .5 .592 r
.59689 .5932 m .59687 .5908 L .5935 .59052 L F
.724 .605 .723 r
.59687 .5908 m .59915 .58791 L .59597 .58817 L F
.513 .336 .578 r
.59689 .5932 m .59915 .59263 L .59687 .5908 L F
.632 .473 .649 r
.5994 .5906 m .59915 .58791 L .59687 .5908 L F
.592 .315 .465 r
.59687 .5908 m .59915 .59263 L .5994 .5906 L F
.51 0 0 r
.24797 .6753 m .24821 .67534 L .24811 .67529 L F
.533 .378 .616 r
.38783 .60167 m .38766 .60405 L .38554 .60429 L F
.405 .168 .438 r
.38766 .60405 m .38557 .60591 L .38554 .60429 L F
.665 .646 .821 r
.54138 .78687 m .54313 .78842 L .54475 .78672 L F
.093 0 .312 r
.58913 .54285 m .59088 .54164 L .59099 .53945 L F
.109 0 .34 r
.59061 .54386 m .58913 .54285 L .58868 .54471 L F
.59061 .54386 m .59088 .54164 L .58913 .54285 L F
.28 .674 .971 r
.32053 .58523 m .31937 .58601 L .31823 .58543 L F
.32053 .58523 m .32193 .58622 L .31937 .58601 L F
.43 .236 .513 r
.39378 .6696 m .3957 .66916 L .3959 .6668 L F
.551 .46 .705 r
.39401 .67232 m .3957 .66916 L .39378 .6696 L F
.783 .663 .73 r
.55725 .62438 m .55503 .62737 L .5534 .62409 L F
.677 .612 .776 r
.56075 .62502 m .55725 .62438 L .55927 .62399 L F
.625 .564 .766 r
.51061 .76447 m .51252 .76198 L .51089 .76208 L F
.676 .624 .789 r
.55723 .63863 m .55339 .63626 L .55519 .637 L F
.995 .768 .471 r
.55925 .63159 m .55874 .63247 L .55872 .62992 L F
.839 .67 .673 r
.72306 .5136 m .72631 .51183 L .72491 .51103 L F
.72306 .5136 m .72611 .51415 L .72631 .51183 L F
.957 .902 .728 r
.72631 .51183 m .72805 .50642 L .72491 .51103 L F
.764 .776 .863 r
.25188 .65399 m .25246 .65529 L .25637 .65191 L F
.596 .642 .867 r
.56407 .72335 m .56285 .72043 L .56021 .72095 L F
.62 .602 .811 r
.56407 .72335 m .56524 .71963 L .56285 .72043 L F
.56407 .72335 m .56639 .72286 L .56524 .71963 L F
.547 .349 .564 r
.5994 .5906 m .6017 .58794 L .59915 .58791 L F
.888 .557 .415 r
.65626 .5035 m .6569 .50562 L .65504 .5048 L F
.867 .584 .507 r
.48662 .80175 m .4865 .79935 L .48341 .79837 L F
.816 .573 .571 r
.48757 .79836 m .48747 .80082 L .4867 .80086 L F
.506 .872 .645 r
.4865 .79935 m .48757 .79836 L .4883 .79624 L F
.867 .584 .507 r
.48662 .80175 m .48341 .79837 L .48684 .80305 L F
.836 .37 0 r
.48427 .80097 m .48684 .80305 L .4852 .80081 L F
.48402 .80022 m .4852 .80081 L .48341 .79837 L F
.48427 .80097 m .4852 .80081 L .48402 .80022 L F
0 0 .272 r
.48341 .79837 m .48392 .79524 L .48383 .79785 L F
.988 .771 .521 r
.48199 .79712 m .48383 .79785 L .48281 .7996 L F
.48253 .79946 m .48281 .7996 L .48263 .7999 L F
.48199 .79712 m .48281 .7996 L .48253 .79946 L F
.816 .573 .571 r
.48757 .79836 m .4867 .80086 L .48427 .80097 L F
.506 .872 .645 r
.4883 .79624 m .48757 .79836 L .48894 .79512 L F
.475 .16 .351 r
.45225 .65835 m .45002 .65853 L .45207 .65834 L F
.45225 .65835 m .4501 .65879 L .45002 .65853 L F
.58 .277 .42 r
.5937 .60513 m .59606 .60666 L .59369 .60701 L F
.5937 .60513 m .59739 .60418 L .59606 .60666 L F
.737 .612 .719 r
.71918 .48111 m .72238 .48063 L .72025 .48366 L F
.746 .63 .731 r
.52007 .65526 m .52217 .65495 L .52187 .65324 L F
.52007 .65526 m .52066 .65608 L .52217 .65495 L F
.613 .426 .605 r
.52374 .65186 m .52187 .65324 L .52217 .65495 L F
.463 .221 .461 r
.29584 .61572 m .2962 .61809 L .29412 .61827 L F
.325 .108 .422 r
.29866 .61298 m .29817 .61519 L .29584 .61572 L F
.403 .182 .46 r
.2981 .61743 m .29584 .61572 L .29817 .61519 L F
.2981 .61743 m .2962 .61809 L .29584 .61572 L F
.235 .504 .904 r
.36726 .59186 m .36895 .59227 L .36829 .59353 L F
.38 .684 .978 r
.36895 .59227 m .37036 .59356 L .36829 .59353 L F
.518 .565 .843 r
.64343 .50886 m .64439 .50674 L .64472 .50615 L F
.723 .531 .63 r
.57327 .61874 m .57068 .62147 L .57065 .61899 L F
.57327 .61874 m .5729 .6216 L .57068 .62147 L F
.588 .424 .626 r
.57589 .61827 m .5729 .6216 L .57327 .61874 L F
.905 .768 .699 r
.58859 .70799 m .58668 .71109 L .5857 .70815 L F
.527 .395 .644 r
.59031 .70843 m .58668 .71109 L .58859 .70799 L F
.924 .605 .42 r
.59698 .70785 m .59792 .70647 L .59738 .70556 L F
.59698 .70785 m .59846 .70879 L .59792 .70647 L F
.206 .501 .906 r
.42344 .69413 m .42274 .69519 L .42181 .69371 L F
.244 .553 .931 r
.42344 .69413 m .42481 .69572 L .42274 .69519 L F
.777 .677 .753 r
.57265 .5903 m .5762 .59072 L .57465 .58691 L F
.781 .664 .734 r
.57265 .5903 m .5739 .59344 L .5762 .59072 L F
.664 .486 .635 r
.5739 .59344 m .57675 .59374 L .5762 .59072 L F
.764 .671 .76 r
.57465 .58691 m .5762 .59072 L .57839 .58783 L F
.575 .406 .614 r
.5762 .59072 m .57811 .59042 L .57839 .58783 L F
.75 .544 .617 r
.5762 .59072 m .57964 .5935 L .57811 .59042 L F
.5762 .59072 m .57675 .59374 L .57964 .5935 L F
.445 .015 .126 r
.44564 .69655 m .44787 .69647 L .4492 .69468 L F
.325 0 0 r
.44787 .69647 m .45158 .69477 L .4492 .69468 L F
.783 .497 .503 r
.53629 .78869 m .53744 .7888 L .53383 .78774 L F
.355 0 .108 r
.35301 .63292 m .35217 .63448 L .35013 .63475 L F
.277 0 .07 r
.35422 .63392 m .35301 .63292 L .35498 .63259 L F
.35422 .63392 m .35217 .63448 L .35301 .63292 L F
.354 .373 .741 r
.47341 .76558 m .47577 .76761 L .47527 .76539 L F
.697 .834 .949 r
.27824 .64269 m .28143 .64259 L .28101 .64098 L F
.278 .589 .946 r
.28143 .64259 m .28325 .6422 L .28101 .64098 L F
.28143 .64259 m .2845 .6436 L .28325 .6422 L F
.682 .762 .912 r
.24317 .65287 m .24339 .65277 L .24306 .65275 L F
.274 .775 .871 r
.42725 .69606 m .426 .69658 L .42481 .69572 L F
.702 .804 .928 r
.56383 .77508 m .5643 .77299 L .56282 .77406 L F
.56383 .77508 m .56605 .77389 L .5643 .77299 L F
.151 .211 .671 r
.3523 .60184 m .35306 .6054 L .35416 .6039 L F
.541 .761 .978 r
.35306 .6054 m .35548 .60484 L .35416 .6039 L F
.734 .52 .603 r
.51901 .79791 m .52166 .79627 L .51763 .79601 L F
.51901 .79791 m .52123 .79936 L .52166 .79627 L F
.52166 .79627 m .52123 .79936 L .51901 .79791 L F
.535 .339 .562 r
.52166 .79627 m .52123 .79936 L .5238 .79834 L F
.52166 .79627 m .52123 .79936 L .5238 .79834 L F
.159 0 0 r
.44974 .6454 m .44732 .64643 L .44972 .64574 L F
.129 0 0 r
.44732 .64643 m .44836 .64683 L .44972 .64574 L F
.44732 .64643 m .44591 .6481 L .44836 .64683 L F
.571 .357 .551 r
.59606 .53418 m .59849 .53385 L .59851 .53157 L F
.536 .335 .555 r
.59849 .53385 m .60085 .53104 L .59851 .53157 L F
.543 .167 .278 r
.60765 .54554 m .60677 .54739 L .60436 .54742 L F
.465 .12 .295 r
.60989 .54495 m .60677 .54739 L .60765 .54554 L F
.887 .828 .783 r
.77175 .60133 m .77307 .60242 L .77512 .59913 L F
.583 .889 .99 r
.57778 .72485 m .57917 .72538 L .58103 .7247 L F
.547 .815 .996 r
.5512 .63168 m .54986 .63321 L .5488 .63202 L F
.784 .756 .828 r
.2481 .67546 m .24821 .67534 L .24797 .6753 L F
.63 .232 .271 r
.49097 .69781 m .48966 .6998 L .48754 .69918 L F
.734 .357 .336 r
.49097 .69781 m .49305 .70017 L .48966 .6998 L F
.607 .367 .528 r
.49471 .6969 m .49305 .70017 L .49097 .69781 L F
.812 .547 .538 r
.55118 .73717 m .55305 .73973 L .55299 .73735 L F
.957 .77 .609 r
.63407 .53872 m .63534 .53983 L .63434 .53662 L F
.325 0 .033 r
.4703 .69838 m .46914 .70014 L .46691 .70048 L F
.634 .203 .204 r
.47231 .69996 m .46914 .70014 L .4703 .69838 L F
.531 .267 .46 r
.47265 .69783 m .47231 .69996 L .4703 .69838 L F
.187 .711 .692 r
.52347 .68945 m .52655 .68865 L .52432 .68825 L F
.469 0 0 r
.49059 .69402 m .49169 .6947 L .49318 .69528 L F
.582 .66 .891 r
.48338 .64997 m .48466 .64724 L .48167 .64759 L F
.48338 .64997 m .48561 .64951 L .48466 .64724 L F
.58 .502 .732 r
.50925 .76839 m .51061 .76447 L .50796 .76507 L F
.50925 .76839 m .51193 .76865 L .51061 .76447 L F
.055 0 .405 r
.59908 .5504 m .59744 .55392 L .59932 .55094 L F
.59908 .5504 m .59903 .55264 L .59744 .55392 L F
.49 .37 .644 r
.59903 .55264 m .59703 .55613 L .59744 .55392 L F
.62 .372 .52 r
.50418 .78804 m .50757 .78695 L .5071 .78524 L F
.582 .407 .609 r
.5071 .78524 m .50957 .78488 L .50933 .78251 L F
.868 .859 .829 r
.50757 .78695 m .50957 .78488 L .5071 .78524 L F
.582 .407 .609 r
.5071 .78524 m .50957 .78488 L .50933 .78251 L F
.369 .809 .956 r
.33446 .58824 m .33714 .58807 L .33511 .58857 L F
.375 0 .004 r
.45958 .69441 m .4618 .69427 L .46336 .69266 L F
.408 0 .027 r
.46336 .69266 m .46524 .69343 L .46561 .69221 L F
.46336 .69266 m .4618 .69427 L .46524 .69343 L F
.874 .981 .69 r
.56146 .57484 m .5621 .57262 L .56364 .57146 L F
0 0 0 r
.56468 .57014 m .56581 .56848 L .56364 .57146 L F
.624 .917 .644 r
.5621 .57262 m .56468 .57014 L .56364 .57146 L F
.315 .072 .378 r
.75773 .58872 m .75748 .58774 L .75495 .59054 L F
.466 .32 .597 r
.75553 .59293 m .75773 .58872 L .75495 .59054 L F
.519 .335 .572 r
.42369 .67415 m .42391 .67753 L .42171 .678 L F
.34 0 .039 r
.63042 .48951 m .63209 .49001 L .63299 .48904 L F
.63042 .48951 m .62986 .49051 L .63209 .49001 L F
.52 .441 .707 r
.41996 .68629 m .42069 .68837 L .41786 .68671 L F
.723 .495 .58 r
.62026 .52769 m .61772 .52589 L .6203 .52543 L F
.62026 .52769 m .618 .52833 L .61772 .52589 L F
.194 .153 .581 r
.58294 .71917 m .58198 .71771 L .58019 .71992 L F
0 0 0 r
.58125 .7185 m .5828 .71696 L .58131 .71874 L F
.58124 .71847 m .58156 .71816 L .58125 .7185 L F
.58156 .71816 m .5828 .71696 L .58125 .7185 L F
.194 .153 .581 r
.58198 .71771 m .58193 .71763 L .58136 .71838 L F
.58198 .71771 m .58136 .71838 L .58019 .71992 L F
.58294 .71917 m .5828 .71696 L .58193 .71763 L F
.599 .411 .599 r
.589 .59628 m .5915 .59609 L .59129 .59348 L F
.651 .5 .666 r
.59129 .59348 m .59463 .59303 L .5935 .59052 L F
.569 .342 .532 r
.5915 .59609 m .59463 .59303 L .59129 .59348 L F
.44 .684 .968 r
.30933 .62875 m .30869 .63026 L .30736 .62885 L F
.458 .704 .974 r
.30933 .62875 m .31079 .63015 L .30869 .63026 L F
.453 .153 .365 r
.61551 .50528 m .61764 .50275 L .61524 .50344 L F
.471 .674 .953 r
.78086 .59209 m .78226 .59356 L .77947 .59357 L F
.78086 .59209 m .78226 .59356 L .77947 .59357 L F
.416 .57 .899 r
.7137 .51141 m .71537 .51412 L .71729 .51377 L F
.646 .87 .982 r
.55458 .63166 m .55587 .63261 L .55469 .62969 L F
.734 .682 .801 r
.55469 .62969 m .55587 .63261 L .55872 .62992 L F
.737 .612 .719 r
.71918 .48111 m .72025 .48366 L .7192 .48257 L F
0 0 .393 r
.54356 .75401 m .54488 .75732 L .54453 .75613 L F
.364 .69 .981 r
.54488 .75732 m .54603 .75616 L .54453 .75613 L F
.54488 .75732 m .5475 .75766 L .54603 .75616 L F
.09 .494 .9 r
.25102 .63172 m .25167 .63153 L .24945 .63098 L F
.25102 .63172 m .25336 .63301 L .25167 .63153 L F
.719 .5 .592 r
.59689 .5932 m .5935 .59052 L .59463 .59303 L F
.478 0 0 r
.44972 .64574 m .45197 .64625 L .44974 .6454 L F
.779 .551 .589 r
.53813 .7705 m .54162 .77081 L .5416 .76838 L F
.473 .274 .529 r
.42171 .678 m .41953 .68072 L .41905 .67819 L F
.361 .299 .652 r
.47453 .77127 m .47656 .77353 L .47642 .76951 L F
.189 .256 .702 r
.47546 .77349 m .47656 .77353 L .47453 .77127 L F
.528 .186 .331 r
.26282 .62928 m .26614 .62724 L .26332 .62763 L F
.351 .124 .422 r
.54993 .61885 m .55003 .6212 L .54768 .62175 L F
.539 .315 .523 r
.54992 .62365 m .54768 .62175 L .55003 .6212 L F
.54992 .62365 m .54713 .6242 L .54768 .62175 L F
.823 .538 .507 r
.55503 .74208 m .55765 .74045 L .55518 .74019 L F
.55503 .74208 m .55783 .74314 L .55765 .74045 L F
.71 .867 .956 r
.58103 .7247 m .5844 .7242 L .58412 .72245 L F
.445 .566 .883 r
.58577 .72457 m .58412 .72245 L .5844 .7242 L F
.733 .572 .673 r
.58187 .59066 m .57839 .58783 L .57811 .59042 L F
.75 .632 .729 r
.57811 .59042 m .57964 .5935 L .58187 .59066 L F
.532 .331 .553 r
.57964 .5935 m .58183 .59313 L .58187 .59066 L F
.422 .29 .595 r
.50933 .78251 m .51073 .78563 L .51143 .78191 L F
.50933 .78251 m .50957 .78488 L .51073 .78563 L F
0 0 0 r
.58124 .71847 m .58131 .71874 L .58019 .71992 L F
.729 .68 .802 r
.68054 .53142 m .68421 .53234 L .68294 .53033 L F
.705 .672 .814 r
.68294 .53033 m .68421 .53234 L .68623 .53104 L F
.872 .994 .792 r
.55988 .57536 m .56146 .57484 L .56085 .57628 L F
.55988 .57536 m .5621 .57262 L .56146 .57484 L F
.667 .841 .967 r
.38472 .69459 m .3811 .69479 L .38352 .69505 L F
.204 .727 .853 r
.38589 .6973 m .38452 .69769 L .38472 .69459 L F
.38589 .6973 m .38472 .69459 L .38352 .69505 L F
.764 .581 .65 r
.59761 .71493 m .59506 .71491 L .5944 .71214 L F
.753 .715 .817 r
.59827 .71104 m .59761 .71493 L .59991 .71208 L F
.59827 .71104 m .59506 .71491 L .59761 .71493 L F
.765 .67 .757 r
.57465 .58691 m .57839 .58783 L .57661 .5845 L F
.565 .822 .454 r
.56581 .56848 m .56686 .56714 L .56812 .56558 L F
0 0 0 r
.56621 .56869 m .56581 .56848 L .56468 .57014 L F
.56621 .56869 m .56686 .56714 L .56581 .56848 L F
.771 .637 .714 r
.39058 .69781 m .3905 .70109 L .38898 .69975 L F
.39058 .69781 m .38816 .70074 L .38694 .69846 L F
0 0 .474 r
.38858 .69816 m .39029 .70006 L .39058 .69781 L F
.38694 .69846 m .38805 .69898 L .38858 .69816 L F
.38805 .69898 m .39029 .70006 L .38858 .69816 L F
.38694 .69846 m .38816 .70074 L .38662 .69746 L F
.898 .719 .652 r
.38662 .69746 m .38763 .69961 L .38612 .70036 L F
.38763 .69961 m .38816 .70074 L .38703 .70053 L F
.38763 .69961 m .38703 .70053 L .38612 .70036 L F
0 0 .474 r
.38818 .69905 m .38809 .69816 L .39029 .70006 L F
.38694 .69846 m .38738 .69834 L .38818 .69905 L F
.38738 .69834 m .38809 .69816 L .38818 .69905 L F
.771 .637 .714 r
.39058 .69781 m .3917 .70126 L .3905 .70109 L F
.38898 .69975 m .3905 .70109 L .38816 .70074 L F
.59 .8 .98 r
.38816 .70074 m .3917 .70126 L .39029 .70006 L F
.714 .607 .736 r
.3935 .69789 m .3917 .70126 L .39058 .69781 L F
.575 .351 .54 r
.3917 .70126 m .39437 .70035 L .39029 .70006 L F
0 .357 .822 r
.3917 .70126 m .39462 .70355 L .39437 .70035 L F
.575 .351 .54 r
.3917 .70126 m .3946 .70298 L .39437 .70035 L F
0 .357 .822 r
.3917 .70126 m .3946 .70298 L .39462 .70355 L F
.553 .381 .603 r
.40054 .66107 m .40294 .66064 L .40264 .65816 L F
.532 .314 .529 r
.40054 .66107 m .4003 .66359 L .40294 .66064 L F
.367 .19 .506 r
.3959 .6668 m .39792 .66372 L .39557 .66439 L F
.968 .927 .692 r
.63167 .5655 m .63122 .56444 L .62985 .56772 L F
.975 .744 .322 r
.57599 .58129 m .57661 .5845 L .57665 .58233 L F
.827 .859 .871 r
.57665 .58233 m .57829 .57845 L .57599 .58129 L F
.57665 .58233 m .57957 .57955 L .57829 .57845 L F
.681 .355 .416 r
.4574 .69344 m .45958 .69441 L .45743 .69215 L F
.732 .209 0 r
.24884 .62506 m .25198 .62725 L .25007 .6246 L F
.24884 .62506 m .25007 .62661 L .25198 .62725 L F
.502 .657 .93 r
.30119 .6279 m .29927 .62827 L .29802 .62649 L F
.942 .792 .666 r
.63381 .54765 m .63606 .54532 L .63498 .54458 L F
.63381 .54765 m .63529 .54883 L .63606 .54532 L F
.871 .73 .703 r
.51171 .80454 m .50737 .80711 L .50854 .80494 L F
.51171 .80454 m .50888 .80765 L .50737 .80711 L F
.792 .591 .629 r
.51171 .80454 m .51232 .80769 L .50888 .80765 L F
.733 .842 .399 r
.51184 .80375 m .51171 .80454 L .51286 .80203 L F
0 .38 .829 r
.51184 .80375 m .51286 .80496 L .51171 .80454 L F
.939 .918 .544 r
.64047 .51792 m .64146 .51704 L .64152 .51646 L F
.64047 .51792 m .6404 .52006 L .64146 .51704 L F
.755 .865 .434 r
.64315 .51316 m .64146 .51704 L .64442 .51433 L F
.64315 .51316 m .64152 .51646 L .64146 .51704 L F
.746 .592 .685 r
.24306 .65275 m .24337 .65053 L .24174 .64991 L F
.723 .755 .878 r
.33107 .6667 m .32909 .66762 L .32745 .66633 L F
.33107 .6667 m .32909 .66762 L .32745 .66633 L F
.562 .862 .553 r
.55204 .76283 m .54952 .7654 L .55085 .7639 L F
0 0 .543 r
.55204 .76283 m .55287 .76512 L .55275 .7641 L F
.55275 .7641 m .55287 .76512 L .55204 .76283 L F
.302 0 0 r
.55085 .7639 m .55275 .7641 L .55204 .76283 L F
.357 0 .059 r
.39462 .70355 m .39151 .70545 L .3946 .70298 L F
.39462 .70355 m .39374 .70522 L .39151 .70545 L F
.827 .904 .494 r
.39601 .69987 m .39462 .70355 L .39437 .70035 L F
.39601 .69987 m .3946 .70298 L .39462 .70355 L F
.823 .851 .393 r
.3946 .70298 m .39374 .70522 L .39462 .70355 L F
.444 .156 .38 r
.30362 .60748 m .30294 .61049 L .30098 .60971 L F
.251 0 .309 r
.30462 .60961 m .30362 .60748 L .30568 .60695 L F
.30462 .60961 m .30294 .61049 L .30362 .60748 L F
.993 .872 .549 r
.72991 .48614 m .72857 .48752 L .72926 .48827 L F
.95 .928 .578 r
.72942 .4855 m .72857 .48752 L .72991 .48614 L F
.473 .891 .804 r
.50646 .79483 m .50686 .79418 L .50505 .79444 L F
.50646 .79483 m .50863 .79371 L .50686 .79418 L F
.745 .841 .392 r
.71975 .49498 m .71974 .49398 L .71976 .49309 L F
.71972 .49499 m .71974 .4932 L .71976 .49309 L F
.71975 .49498 m .71976 .49309 L .72167 .49386 L F
.484 .684 .955 r
.71974 .49355 m .71975 .49498 L .71984 .49349 L F
.71747 .49489 m .71975 .49498 L .71974 .49355 L F
.745 .841 .392 r
.71975 .49498 m .71972 .49499 L .71974 .49398 L F
.71972 .49499 m .71942 .49511 L .71974 .4932 L F
.484 .684 .955 r
.71747 .49489 m .71974 .49355 L .71597 .49368 L F
.71974 .49355 m .71984 .49349 L .71974 .4935 L F
.71974 .49355 m .71974 .4935 L .71597 .49368 L F
.186 .026 .418 r
.71747 .49489 m .71914 .49597 L .71975 .49498 L F
.71747 .49489 m .71688 .49733 L .71914 .49597 L F
.702 .577 .711 r
.56879 .62463 m .5666 .62729 L .56625 .62482 L F
.493 .29 .533 r
.56879 .62463 m .5686 .62681 L .5666 .62729 L F
.683 .547 .693 r
.56986 .62992 m .5666 .62729 L .5686 .62681 L F
.56986 .62992 m .56732 .63042 L .5666 .62729 L F
.66 .914 .602 r
.56812 .56558 m .56903 .56421 L .57046 .56293 L F
.042 0 0 r
.56812 .56558 m .56883 .56627 L .56903 .56421 L F
.56812 .56558 m .56686 .56714 L .56883 .56627 L F
.018 0 .126 r
.5474 .7684 m .54825 .7696 L .54887 .76744 L F
.5474 .7684 m .54686 .77062 L .54825 .7696 L F
.47 .556 .861 r
.24896 .63098 m .24945 .63098 L .24864 .62869 L F
.477 .27 .52 r
.24896 .63098 m .24757 .63294 L .24945 .63098 L F
.373 .499 .857 r
.51074 .63464 m .50987 .63672 L .509 .63458 L F
.57 .729 .949 r
.51074 .63464 m .51162 .6362 L .50987 .63672 L F
.097 0 .148 r
.57486 .55718 m .57249 .56001 L .57411 .55876 L F
0 0 .006 r
.57411 .55876 m .57664 .55603 L .57486 .55718 L F
.705 .647 .789 r
.69189 .51699 m .69309 .5203 L .68959 .5198 L F
.648 .7 .884 r
.51477 .76669 m .51751 .76755 L .51751 .76563 L F
0 0 .161 r
.51828 .77107 m .52059 .76732 L .51751 .76755 L F
.217 .672 .948 r
.55553 .76498 m .55652 .76192 L .55434 .76233 L F
.55553 .76498 m .55275 .7641 L .55652 .76192 L F
.55553 .76498 m .55768 .76512 L .55275 .7641 L F
.683 .857 .965 r
.70275 .47166 m .69936 .47155 L .70146 .47087 L F
.838 .94 .891 r
.70275 .47166 m .70442 .4682 L .70535 .46921 L F
.70275 .47166 m .70146 .47087 L .70442 .4682 L F
.707 .606 .741 r
.54943 .75117 m .55196 .75078 L .55192 .7486 L F
.368 0 0 r
.55031 .75245 m .55196 .75078 L .54943 .75117 L F
.707 .606 .741 r
.54943 .75117 m .55196 .75078 L .55192 .7486 L F
.366 .7 .984 r
.41443 .71085 m .4148 .70991 L .41407 .71058 L F
.41443 .71085 m .41678 .71108 L .4148 .70991 L F
.577 .827 .992 r
.48607 .81273 m .48903 .81263 L .48721 .81092 L F
.787 .897 .921 r
.48721 .81092 m .48903 .81263 L .49133 .81045 L F
.246 .417 .835 r
.48903 .81263 m .49249 .81593 L .49189 .81375 L F
.262 0 .191 r
.34803 .63582 m .34695 .63826 L .34525 .63814 L F
.37 .025 .243 r
.34912 .63766 m .34803 .63582 L .35013 .63475 L F
.34912 .63766 m .34695 .63826 L .34803 .63582 L F
.699 .726 .871 r
.66614 .50812 m .66955 .50862 L .66891 .50614 L F
.512 .479 .757 r
.66614 .50812 m .66995 .51182 L .66955 .50862 L F
.812 .792 .834 r
.66891 .50614 m .66955 .50862 L .67203 .50594 L F
0 0 .4 r
.66955 .50862 m .67083 .50952 L .67251 .5104 L F
.66955 .50862 m .66995 .51182 L .67083 .50952 L F
.461 .243 .495 r
.36984 .62099 m .36831 .61917 L .37004 .6188 L F
.36984 .62099 m .36784 .62177 L .36831 .61917 L F
.481 .336 .607 r
.25782 .59916 m .25988 .59862 L .25967 .59606 L F
.379 .162 .454 r
.25764 .60144 m .25988 .59862 L .25782 .59916 L F
0 0 0 r
.61084 .57389 m .61199 .57247 L .61245 .57059 L F
.61084 .57389 m .61089 .57424 L .61199 .57247 L F
.61084 .57389 m .60996 .57587 L .61089 .57424 L F
.152 0 0 r
.30099 .58399 m .30306 .58423 L .30474 .58428 L F
.379 0 0 r
.30306 .58423 m .30664 .58487 L .30474 .58428 L F
.661 .466 .61 r
.48167 .79026 m .48414 .79087 L .4841 .78808 L F
.697 .222 0 r
.73344 .51725 m .73249 .51632 L .73128 .51464 L F
.995 .755 .44 r
.73344 .51725 m .73282 .51892 L .73249 .51632 L F
.664 .294 .335 r
.73344 .51725 m .73649 .51914 L .73282 .51892 L F
.365 .415 .78 r
.74573 .48524 m .74396 .48691 L .74312 .4836 L F
.405 .48 .824 r
.74573 .48524 m .7468 .48829 L .74396 .48691 L F
.451 .098 .275 r
.52782 .69446 m .52449 .69719 L .52546 .69479 L F
.083 0 0 r
.60197 .54815 m .59908 .5504 L .59932 .55094 L F
.625 .779 .955 r
.49232 .62628 m .48999 .62703 L .48869 .62561 L F
.528 .89 .976 r
.46328 .64064 m .46422 .63943 L .46623 .63916 L F
.46328 .64064 m .4622 .64018 L .46422 .63943 L F
.965 .669 .419 r
.65586 .49771 m .6547 .49898 L .65484 .49668 L F
.65586 .49771 m .6561 .49997 L .6547 .49898 L F
.356 .321 .681 r
.55192 .7486 m .55196 .75078 L .55399 .75058 L F
.807 .611 .637 r
.55031 .75245 m .55399 .75058 L .55196 .75078 L F
.332 .672 .976 r
.36539 .59062 m .36472 .59163 L .36325 .59065 L F
.36539 .59062 m .36726 .59186 L .36472 .59163 L F
.732 .623 .737 r
.51717 .79072 m .51867 .79415 L .52015 .791 L F
.773 .733 .816 r
.38516 .70532 m .38654 .70805 L .38974 .70552 L F
.763 .877 .929 r
.4935 .80976 m .49479 .81058 L .49282 .81161 L F
.689 .44 .541 r
.50153 .79014 m .50418 .78804 L .50185 .7886 L F
.759 .907 .941 r
.48398 .62904 m .48199 .63035 L .48264 .62829 L F
.797 .943 .921 r
.48264 .62829 m .48199 .63035 L .48086 .62975 L F
.994 .808 .546 r
.634 .55537 m .63522 .55387 L .63482 .55298 L F
.634 .55537 m .63493 .55564 L .63522 .55387 L F
.725 .531 .628 r
.42832 .67448 m .42571 .67195 L .42833 .67192 L F
0 0 0 r
.43139 .66933 m .43025 .6712 L .42833 .67192 L F
.248 .062 .421 r
.43026 .67359 m .42833 .67192 L .43025 .6712 L F
.43026 .67359 m .42832 .67448 L .42833 .67192 L F
.406 .167 .435 r
.37767 .61033 m .37723 .61261 L .37528 .61317 L F
.469 .222 .456 r
.37945 .61201 m .37767 .61033 L .37985 .60986 L F
.37945 .61201 m .37723 .61261 L .37767 .61033 L F
.67 .775 .929 r
.25167 .63153 m .25336 .63301 L .2561 .63196 L F
.575 .915 .969 r
.2561 .63196 m .25336 .63301 L .25607 .63212 L F
.473 .274 .529 r
.42171 .678 m .42156 .68025 L .41953 .68072 L F
.529 .393 .639 r
.42172 .68322 m .41953 .68072 L .42156 .68025 L F
.42172 .68322 m .41972 .68373 L .41953 .68072 L F
1 .814 .5 r
.57739 .59165 m .57736 .59231 L .57825 .59298 L F
.074 0 .048 r
.57675 .59374 m .57825 .59298 L .57902 .59355 L F
1 .814 .5 r
.57736 .59231 m .57729 .59402 L .57825 .59298 L F
.074 0 .048 r
.57902 .59355 m .57825 .59298 L .57964 .5935 L F
.696 .289 .272 r
.57825 .59298 m .58183 .59313 L .57964 .5935 L F
.606 .42 .604 r
.57114 .62412 m .5686 .62681 L .56879 .62463 L F
.445 .566 .883 r
.58577 .72457 m .586 .7223 L .58412 .72245 L F
.75 .841 .92 r
.58932 .7223 m .586 .7223 L .58577 .72457 L F
.577 .827 .992 r
.48607 .81273 m .48721 .81092 L .48487 .81303 L F
.891 .979 .817 r
.58135 .57605 m .57829 .57845 L .57957 .57955 L F
.58135 .57605 m .58057 .57559 L .57829 .57845 L F
.723 .973 .735 r
.58334 .57334 m .58057 .57559 L .58135 .57605 L F
.483 .26 .499 r
.58905 .599 m .5915 .59609 L .589 .59628 L F
.864 .711 .69 r
.56754 .63282 m .56398 .63479 L .56535 .63322 L F
.56754 .63282 m .56592 .63545 L .56398 .63479 L F
.765 .57 .633 r
.56754 .63282 m .56839 .63574 L .56592 .63545 L F
.689 .576 .723 r
.56986 .62992 m .56754 .63282 L .56732 .63042 L F
.61 .463 .658 r
.56986 .62992 m .5703 .63235 L .56754 .63282 L F
.629 .501 .687 r
.5703 .63235 m .56839 .63574 L .56754 .63282 L F
.382 0 0 r
.47413 .64773 m .47259 .6485 L .47022 .64804 L F
.789 .458 .428 r
.55258 .62133 m .55003 .6212 L .54993 .61885 L F
.81 .754 .801 r
.72438 .51505 m .72611 .51415 L .72306 .5136 L F
.192 .695 .908 r
.33876 .58832 m .34143 .58855 L .34007 .58854 L F
.083 0 .093 r
.45965 .65418 m .45803 .65551 L .46049 .65298 L F
.456 .155 .365 r
.4626 .65388 m .46049 .65298 L .46264 .65257 L F
.4626 .65388 m .45965 .65418 L .46049 .65298 L F
.596 .289 .418 r
.59937 .60438 m .59606 .60666 L .59739 .60418 L F
.454 .835 .988 r
.53826 .68905 m .53463 .68897 L .53596 .68949 L F
.971 .795 .369 r
.72739 .49377 m .72769 .4967 L .72851 .49484 L F
.415 .283 .592 r
.40264 .65816 m .40294 .66064 L .4047 .66016 L F
0 0 0 r
.56085 .76763 m .55959 .76889 L .55878 .76975 L F
.45561 .64431 m .45684 .64342 L .45725 .6431 L F
.443 .863 .725 r
.45561 .64431 m .45398 .64498 L .45684 .64342 L F
.739 .791 .895 r
.63519 .51396 m .63259 .51609 L .63185 .5137 L F
.432 .394 .716 r
.39971 .6978 m .40093 .69439 L .39859 .69475 L F
.39971 .6978 m .4016 .69738 L .40093 .69439 L F
.682 .389 .47 r
.51873 .78557 m .51545 .78607 L .51551 .78615 L F
.039 0 0 r
.625 .4943 m .62712 .49339 L .62798 .49201 L F
0 0 0 r
.62986 .49051 m .62798 .49201 L .62959 .49076 L F
.251 0 .002 r
.62798 .49201 m .62952 .49271 L .62959 .49076 L F
.62798 .49201 m .62712 .49339 L .62952 .49271 L F
.79 .826 .88 r
.74125 .48464 m .7376 .48551 L .74011 .48303 L F
.679 .775 .923 r
.74011 .48303 m .74312 .4836 L .74125 .48464 L F
.111 0 .329 r
.61032 .51749 m .60999 .51954 L .61182 .51597 L F
.725 .552 .656 r
.49115 .78372 m .49213 .78517 L .48859 .7854 L F
.413 .443 .782 r
.49356 .78447 m .49115 .78372 L .4931 .78163 L F
.49356 .78447 m .49213 .78517 L .49115 .78372 L F
.063 .589 .869 r
.26535 .63223 m .26666 .6323 L .26464 .63184 L F
.561 .576 .827 r
.51907 .65321 m .52007 .65526 L .52187 .65324 L F
.063 0 0 r
.50507 .80732 m .50854 .80494 L .50737 .80711 L F
.369 .003 .206 r
.45923 .65706 m .45803 .65551 L .45965 .65418 L F
.45923 .65706 m .45696 .65771 L .45803 .65551 L F
.319 .007 .269 r
.59333 .53665 m .59533 .53621 L .59606 .53418 L F
.52 .195 .357 r
.59606 .53418 m .59822 .53552 L .59849 .53385 L F
.59606 .53418 m .59533 .53621 L .59822 .53552 L F
.367 .19 .506 r
.3959 .6668 m .39769 .66619 L .39792 .66372 L F
.507 .355 .609 r
.3957 .66916 m .39769 .66619 L .3959 .6668 L F
0 0 0 r
.54952 .7654 m .54887 .76744 L .55085 .7639 L F
.374 .622 .949 r
.57346 .72515 m .57443 .72429 L .57227 .72465 L F
.57346 .72515 m .57565 .72563 L .57443 .72429 L F
.8 .623 .662 r
.5534 .62409 m .55258 .62133 L .55345 .62167 L F
.571 .856 .996 r
.6845 .47201 m .68785 .4721 L .6855 .47278 L F
.975 .672 .302 r
.52629 .7813 m .5256 .78187 L .52511 .77923 L F
.138 0 0 r
.52877 .78118 m .52629 .7813 L .52898 .77945 L F
.52877 .78118 m .5256 .78187 L .52629 .7813 L F
.791 .792 .853 r
.78226 .59356 m .7853 .59351 L .78363 .5921 L F
.081 .065 .537 r
.47561 .7767 m .47656 .77353 L .47546 .77349 L F
.47561 .7767 m .47695 .77591 L .47656 .77353 L F
0 0 .292 r
.47561 .7767 m .47642 .77877 L .47695 .77591 L F
.47561 .7767 m .47526 .77935 L .47642 .77877 L F
.261 0 .213 r
.3395 .62415 m .34042 .62577 L .34156 .62358 L F
.3395 .62415 m .33857 .62659 L .34042 .62577 L F
.718 .405 .447 r
.54455 .73643 m .54769 .73691 L .54573 .73451 L F
.749 .401 .394 r
.54573 .73451 m .54769 .73691 L .54948 .73672 L F
.797 .99 .883 r
.51828 .77107 m .51525 .7726 L .51769 .77322 L F
0 0 .161 r
.51828 .77107 m .51981 .77029 L .52059 .76732 L F
0 0 .036 r
.51828 .77107 m .51769 .77322 L .51981 .77029 L F
.818 .869 .884 r
.54281 .5994 m .53886 .60089 L .54166 .59864 L F
.887 .908 .836 r
.54281 .5994 m .54398 .59566 L .54528 .59654 L F
.54281 .5994 m .54166 .59864 L .54398 .59566 L F
.6 .308 .445 r
.25895 .63281 m .26087 .63473 L .26142 .6317 L F
.535 .501 .765 r
.26142 .6317 m .26464 .63184 L .26282 .62928 L F
.135 .022 .449 r
.26183 .63045 m .26142 .6317 L .26282 .62928 L F
.899 .795 .737 r
.73436 .50884 m .7314 .51072 L .73311 .50769 L F
.73436 .50884 m .73293 .51202 L .7314 .51072 L F
.985 .832 .443 r
.73415 .50582 m .73436 .50884 L .73311 .50769 L F
.576 .628 .866 r
.69387 .51166 m .691 .50962 L .69278 .50843 L F
.583 .409 .612 r
.69641 .51123 m .69418 .51455 L .69387 .51166 L F
.083 0 0 r
.60197 .54815 m .60105 .54966 L .59908 .5504 L F
.665 .367 .459 r
.60436 .54742 m .60105 .54966 L .60197 .54815 L F
.84 .67 .671 r
.51458 .80777 m .51268 .80997 L .51232 .80769 L F
.684 .631 .79 r
.51633 .80542 m .51819 .80777 L .51458 .80777 L F
.628 .56 .758 r
.51757 .80866 m .51458 .80777 L .51819 .80777 L F
.812 .641 .67 r
.51252 .76198 m .51531 .76472 L .51474 .76284 L F
.65 .865 .981 r
.69356 .47134 m .69122 .47229 L .6902 .47134 L F
.718 .23 .084 r
.5205 .77493 m .52202 .77419 L .52406 .77626 L F
.646 .088 0 r
.52283 .80297 m .52591 .80496 L .52453 .80166 L F
.45 .212 .46 r
.52852 .80223 m .52591 .80496 L .52817 .8046 L F
.765 .531 .579 r
.52817 .8046 m .52453 .80166 L .52591 .80496 L F
.495 .267 .497 r
.37528 .61317 m .37503 .61528 L .37288 .61574 L F
.471 .246 .491 r
.37714 .61471 m .37528 .61317 L .37723 .61261 L F
.37714 .61471 m .37503 .61528 L .37528 .61317 L F
.348 .232 .577 r
.52008 .64346 m .52112 .6474 L .51906 .64764 L F
.593 .814 .417 r
.57046 .56293 m .57147 .56145 L .57249 .56001 L F
0 0 0 r
.57046 .56293 m .571 .56328 L .57147 .56145 L F
.57046 .56293 m .56903 .56421 L .571 .56328 L F
.968 .786 .353 r
.52991 .61011 m .52912 .61162 L .52849 .60917 L F
.52991 .61011 m .52971 .61287 L .52912 .61162 L F
.879 .874 .827 r
.53225 .60714 m .52991 .61011 L .52849 .60917 L F
.53225 .60714 m .52849 .60917 L .53083 .60616 L F
.834 .882 .877 r
.53472 .60452 m .53225 .60714 L .53083 .60616 L F
.593 .949 .853 r
.67091 .52969 m .67019 .52968 L .6687 .5311 L F
.67091 .52969 m .67019 .52968 L .6687 .5311 L F
.671 .605 .773 r
.66885 .53283 m .67091 .52969 L .6687 .5311 L F
.245 .752 .878 r
.34027 .6011 m .33917 .60095 L .33711 .60122 L F
.038 0 0 r
.34267 .60043 m .33917 .60095 L .34027 .6011 L F
.765 .531 .579 r
.52817 .8046 m .52852 .80223 L .52453 .80166 L F
.55 .333 .538 r
.53009 .8047 m .52852 .80223 L .52817 .8046 L F
.53009 .8047 m .52852 .80223 L .52817 .8046 L F
.514 .307 .537 r
.55469 .62969 m .55746 .62917 L .55503 .62737 L F
.868 .859 .829 r
.50757 .78695 m .50933 .78605 L .50957 .78488 L F
.712 .441 .513 r
.50639 .79005 m .50933 .78605 L .50757 .78695 L F
.613 .696 .903 r
.68623 .53104 m .68997 .53214 L .68856 .53037 L F
.738 .721 .836 r
.68856 .53037 m .68997 .53214 L .69203 .53089 L F
.728 .499 .58 r
.52476 .79062 m .52807 .78846 L .52467 .7878 L F
.52476 .79062 m .52886 .79067 L .52807 .78846 L F
.291 .258 .648 r
.52807 .78846 m .53074 .7901 L .5304 .78842 L F
.52807 .78846 m .52886 .79067 L .53074 .7901 L F
.19 0 0 r
.76587 .59877 m .76524 .59917 L .76215 .59917 L F
.547 .498 .752 r
.76766 .59564 m .76587 .59877 L .76468 .59562 L F
.76766 .59564 m .76818 .59842 L .76587 .59877 L F
.525 .916 .914 r
.76818 .59842 m .76524 .59917 L .76587 .59877 L F
0 0 .544 r
.49502 .79592 m .49487 .79626 L .49315 .79353 L F
.683 .334 .378 r
.49507 .79648 m .49689 .79853 L .49379 .79878 L F
.589 .877 .993 r
.49379 .79878 m .49689 .79853 L .49564 .79785 L F
.49379 .79878 m .49564 .79785 L .49291 .80034 L F
.49379 .79878 m .49291 .80034 L .49275 .8005 L F
.683 .334 .378 r
.49487 .79626 m .49507 .79648 L .49379 .79878 L F
.701 .174 0 r
.49564 .79785 m .49689 .79853 L .49487 .79626 L F
.49564 .79785 m .49487 .79626 L .49502 .79592 L F
.218 .533 .923 r
.35105 .60023 m .3523 .60184 L .35271 .60056 L F
0 .135 .677 r
.3523 .60184 m .35416 .6039 L .35271 .60056 L F
.207 0 0 r
.44496 .70416 m .44352 .70541 L .44128 .70578 L F
.107 0 0 r
.44691 .70432 m .44352 .70541 L .44496 .70416 L F
.164 0 .062 r
.57147 .56145 m .57411 .55876 L .57249 .56001 L F
.895 .988 .763 r
.66129 .51136 m .6618 .51188 L .66192 .51004 L F
.929 .947 .782 r
.66127 .51185 m .6618 .51149 L .66004 .51134 L F
.837 .981 .875 r
.66196 .50921 m .65951 .51135 L .66129 .51136 L F
.875 .994 .793 r
.66022 .51136 m .66129 .51136 L .66004 .51134 L F
.6618 .51149 m .66129 .51136 L .66022 .51136 L F
.828 .83 .85 r
.65768 .513 m .65982 .5115 L .65793 .51274 L F
.837 .981 .875 r
.65951 .51135 m .65887 .51235 L .65989 .51143 L F
.828 .83 .85 r
.65982 .5115 m .66004 .51134 L .65793 .51274 L F
.65768 .513 m .65781 .51331 L .65982 .5115 L F
.837 .981 .875 r
.65913 .51195 m .65793 .51274 L .65887 .51235 L F
.65951 .51135 m .65793 .51274 L .65913 .51195 L F
.65989 .51143 m .65887 .51235 L .66069 .51161 L F
.65951 .51135 m .66069 .51161 L .66022 .51136 L F
.829 .984 .877 r
.66069 .51161 m .65887 .51235 L .66004 .51134 L F
.828 .83 .85 r
.65982 .5115 m .6598 .51155 L .66004 .51134 L F
.829 .984 .877 r
.65887 .51235 m .65793 .51274 L .66004 .51134 L F
.828 .83 .85 r
.6598 .51155 m .65858 .51508 L .66004 .51134 L F
.65781 .51331 m .65858 .51508 L .65982 .5115 L F
.929 .947 .782 r
.65935 .51311 m .66121 .51189 L .66004 .51134 L F
.66121 .51189 m .66127 .51185 L .66069 .51161 L F
.66121 .51189 m .66069 .51161 L .66004 .51134 L F
.837 .981 .875 r
.66022 .51136 m .66069 .51161 L .66129 .51136 L F
.829 .984 .877 r
.66129 .51136 m .66069 .51161 L .66004 .51134 L F
.929 .947 .782 r
.65858 .51508 m .6618 .51149 L .65935 .51311 L F
.875 .994 .793 r
.6618 .51149 m .6618 .51188 L .66157 .51165 L F
.6618 .51149 m .66157 .51165 L .66129 .51136 L F
.538 .343 .565 r
.45225 .65835 m .4502 .66279 L .4501 .65879 L F
.143 .688 .752 r
.3242 .64783 m .32249 .64793 L .31962 .64835 L F
.203 0 0 r
.32626 .64715 m .32249 .64793 L .3242 .64783 L F
.603 .43 .62 r
.74264 .50843 m .74419 .51352 L .74134 .51172 L F
.589 .422 .623 r
.74624 .50962 m .74264 .50843 L .74577 .50842 L F
.74624 .50962 m .74419 .51352 L .74264 .50843 L F
.663 .78 .936 r
.49582 .6268 m .49232 .62628 L .49454 .62585 L F
0 .56 .762 r
.49454 .62585 m .49803 .62626 L .49582 .6268 L F
.362 0 .091 r
.2721 .59005 m .27422 .58973 L .27574 .58784 L F
.43 .008 .135 r
.27574 .58784 m .2774 .58866 L .27812 .58768 L F
.27574 .58784 m .27422 .58973 L .2774 .58866 L F
.848 .885 .866 r
.54673 .59535 m .54398 .59566 L .5456 .59417 L F
.54673 .59535 m .54528 .59654 L .54398 .59566 L F
.854 .917 .874 r
.54906 .59263 m .54673 .59535 L .5456 .59417 L F
.701 .806 .931 r
.63639 .50712 m .63396 .50831 L .63742 .50856 L F
.994 .758 .399 r
.63659 .50956 m .63742 .50856 L .63396 .50831 L F
.63659 .50956 m .63747 .51181 L .63742 .50856 L F
.573 .77 .972 r
.63742 .50856 m .63805 .50628 L .63639 .50712 L F
.63742 .50856 m .63963 .50806 L .63805 .50628 L F
.671 .605 .773 r
.66885 .53283 m .67244 .53431 L .67091 .52969 L F
.363 0 0 r
.43673 .70592 m .43526 .70741 L .4331 .70744 L F
.362 0 0 r
.43896 .70577 m .43526 .70741 L .43673 .70592 L F
.8 .685 .738 r
.686 .51136 m .6838 .50805 L .68591 .50761 L F
.686 .51136 m .68512 .51234 L .6838 .50805 L F
.429 .868 .903 r
.68879 .51143 m .68512 .51234 L .686 .51136 L F
.776 .771 .848 r
.68921 .5079 m .686 .51136 L .68591 .50761 L F
.727 .656 .778 r
.68921 .5079 m .68879 .51143 L .686 .51136 L F
.185 .673 .924 r
.34621 .58907 m .34834 .58921 L .34977 .58982 L F
.348 .734 .985 r
.35033 .58888 m .34977 .58982 L .34834 .58921 L F
.35033 .58888 m .3519 .58977 L .34977 .58982 L F
.423 .001 .131 r
.26759 .59043 m .26844 .59189 L .26999 .59046 L F
.26759 .59043 m .26607 .59226 L .26844 .59189 L F
.799 .672 .724 r
.57082 .59341 m .5739 .59344 L .57265 .5903 L F
.792 .564 .591 r
.57374 .59594 m .5739 .59344 L .57082 .59341 L F
.472 .29 .552 r
.57374 .59594 m .57551 .59565 L .5739 .59344 L F
.646 .327 .418 r
.5739 .59344 m .57551 .59565 L .57675 .59374 L F
.518 .373 .623 r
.29412 .61827 m .29362 .62251 L .29199 .62279 L F
.543 .427 .671 r
.29362 .62251 m .29231 .6244 L .29199 .62279 L F
.61 .655 .869 r
.3179 .63287 m .31382 .63125 L .31651 .63195 L F
.554 .815 .994 r
.31998 .63232 m .3179 .63287 L .31651 .63195 L F
.715 .406 .452 r
.4991 .80734 m .49935 .80516 L .49606 .80502 L F
.566 .273 .43 r
.4991 .80734 m .5015 .80699 L .49935 .80516 L F
.548 .302 .494 r
.57776 .70648 m .58002 .70821 L .57764 .70872 L F
.203 0 0 r
.34614 .63909 m .34525 .63814 L .34695 .63826 L F
.34614 .63909 m .34403 .63991 L .34525 .63814 L F
0 .231 .748 r
.66107 .48676 m .65916 .48598 L .65847 .48468 L F
.66107 .48676 m .66201 .48827 L .65916 .48598 L F
.065 0 0 r
.31405 .60229 m .3124 .6034 L .3103 .60393 L F
.219 0 0 r
.31625 .60234 m .3124 .6034 L .31405 .60229 L F
.781 .764 .837 r
.71073 .46722 m .70781 .46714 L .70973 .46579 L F
.639 .761 .936 r
.71298 .46645 m .71073 .46722 L .70973 .46579 L F
.653 .894 .554 r
.53991 .78858 m .54138 .78687 L .54247 .78555 L F
.665 .646 .821 r
.54138 .78687 m .54433 .78468 L .54247 .78555 L F
0 .002 .572 r
.47205 .79904 m .47368 .80161 L .47289 .79875 L F
.805 .532 .526 r
.66767 .50208 m .67096 .50492 L .66811 .50387 L F
.731 .689 .81 r
.69189 .51699 m .68959 .5198 L .68841 .51646 L F
.339 .487 .861 r
.4016 .69738 m .40323 .70059 L .404 .69944 L F
.328 .472 .852 r
.40323 .70059 m .40476 .70075 L .404 .69944 L F
.612 .535 .744 r
.40311 .70298 m .40476 .70075 L .40323 .70059 L F
.879 .451 .172 r
.48076 .8019 m .48319 .80434 L .48319 .80443 L F
.211 0 0 r
.51166 .78711 m .51263 .78629 L .51545 .78607 L F
.893 .911 .83 r
.67392 .52593 m .67182 .529 L .67083 .52769 L F
.986 .895 .575 r
.67091 .52969 m .67083 .52769 L .67182 .529 L F
.582 .631 .865 r
.69782 .46817 m .69701 .47205 L .69587 .47048 L F
.69782 .46817 m .69936 .47155 L .69701 .47205 L F
.304 .678 .976 r
.67106 .48531 m .67132 .48436 L .66978 .48425 L F
.67106 .48531 m .67286 .48541 L .67132 .48436 L F
.67106 .48531 m .67132 .48436 L .66978 .48425 L F
.67106 .48531 m .67286 .48541 L .67132 .48436 L F
.653 .677 .86 r
.69203 .53089 m .69553 .5319 L .69458 .53002 L F
.673 .687 .855 r
.69458 .53002 m .69553 .5319 L .69781 .53097 L F
.725 .635 .758 r
.67091 .52969 m .67244 .53431 L .67442 .53286 L F
.966 .754 .314 r
.56726 .75945 m .5672 .76124 L .56779 .76258 L F
.983 .763 .527 r
.56645 .76474 m .56779 .76258 L .5672 .76124 L F
.56645 .76474 m .56768 .76556 L .56779 .76258 L F
.571 .592 .835 r
.5541 .63419 m .55519 .637 L .55339 .63626 L F
.32 .575 .932 r
.37815 .5953 m .37742 .59671 L .37614 .59519 L F
.37815 .5953 m .37998 .59724 L .37742 .59671 L F
.494 .101 .224 r
.57854 .55483 m .57685 .55379 L .57664 .55603 L F
.57854 .55483 m .57917 .55374 L .57685 .55379 L F
.713 .454 .532 r
.60491 .60189 m .6049 .60362 L .60175 .60401 L F
.544 .356 .577 r
.60491 .60189 m .60732 .60369 L .6049 .60362 L F
.60491 .60189 m .60728 .60147 L .60732 .60369 L F
.551 .46 .705 r
.39401 .67232 m .39623 .67189 L .3957 .66916 L F
.5 .363 .626 r
.39426 .67528 m .39623 .67189 L .39401 .67232 L F
.343 .104 .399 r
.59099 .53945 m .59318 .53899 L .59333 .53665 L F
.351 .123 .422 r
.59294 .54103 m .59099 .53945 L .59088 .54164 L F
.59294 .54103 m .59318 .53899 L .59099 .53945 L F
.913 .663 .548 r
.47702 .78746 m .4788 .78793 L .47706 .78498 L F
.689 .469 .583 r
.47724 .79042 m .4788 .78793 L .47702 .78746 L F
.47724 .79042 m .47999 .79026 L .4788 .78793 L F
0 0 0 r
.53372 .7928 m .53629 .78869 L .5359 .79002 L F
.783 .497 .503 r
.53629 .78869 m .53383 .78774 L .5359 .79002 L F
.799 .716 .773 r
.69941 .52229 m .70238 .52308 L .70145 .5197 L F
.902 .908 .818 r
.69933 .52499 m .70238 .52308 L .69941 .52229 L F
.69933 .52499 m .70038 .52587 L .70238 .52308 L F
.979 .85 .642 r
.69933 .52499 m .69969 .52801 L .70038 .52587 L F
.487 .641 .924 r
.72253 .47364 m .72102 .47561 L .71989 .47561 L F
.72253 .47364 m .72346 .47534 L .72102 .47561 L F
.136 .456 .886 r
.2542 .62962 m .25529 .63143 L .25444 .63024 L F
.017 0 0 r
.25607 .63212 m .25529 .63143 L .2561 .63196 L F
.481 .209 .423 r
.37288 .61574 m .37241 .61844 L .37004 .6188 L F
.437 .17 .41 r
.37449 .61791 m .37288 .61574 L .37503 .61528 L F
.37449 .61791 m .37241 .61844 L .37288 .61574 L F
.784 .698 .769 r
.38974 .70552 m .38516 .70532 L .38932 .70518 L F
0 .065 .629 r
.53313 .6188 m .53414 .61942 L .53161 .61791 L F
.53313 .6188 m .53477 .62107 L .53414 .61942 L F
.742 .433 .46 r
.54271 .61488 m .54357 .61615 L .54053 .61507 L F
.54271 .61488 m .54357 .61615 L .54053 .61507 L F
.442 .356 .663 r
.3488 .61311 m .35098 .61513 L .35107 .61273 L F
.3488 .61311 m .34933 .61596 L .35098 .61513 L F
.501 .254 .471 r
.30294 .61049 m .30025 .61233 L .30098 .60971 L F
0 0 .474 r
.38694 .69846 m .38662 .69746 L .38809 .69816 L F
.798 .992 .878 r
.64103 .48491 m .64016 .48532 L .64298 .48268 L F
.739 .909 .952 r
.69937 .4798 m .69946 .47731 L .6971 .4775 L F
.69937 .4798 m .70054 .47782 L .69946 .47731 L F
0 0 .366 r
.66307 .4932 m .66337 .49412 L .66237 .49166 L F
.861 .429 .003 r
.6612 .49074 m .66307 .4932 L .66237 .49166 L F
0 .292 .791 r
.6612 .49074 m .66262 .49177 L .66307 .4932 L F
.66262 .49177 m .6634 .49233 L .66307 .4932 L F
0 0 .366 r
.66307 .4932 m .66367 .49487 L .66337 .49412 L F
.66307 .4932 m .66367 .49487 L .66237 .49166 L F
.35 .611 .947 r
.66479 .49372 m .66367 .49487 L .66307 .4932 L F
.66479 .49372 m .66541 .49526 L .66367 .49487 L F
.545 .353 .571 r
.42391 .67753 m .42156 .68025 L .42171 .678 L F
.732 .623 .737 r
.51717 .79072 m .52015 .791 L .5192 .79051 L F
0 .124 .628 r
.52015 .791 m .52326 .79391 L .52284 .79102 L F
.34 .315 .685 r
.52284 .79102 m .52326 .79391 L .52509 .793 L F
.366 .374 .736 r
.52326 .79391 m .52571 .79568 L .52509 .793 L F
.912 .599 .439 r
.25007 .62661 m .25025 .62874 L .25198 .62725 L F
.136 .456 .886 r
.2542 .62962 m .25444 .63024 L .25198 .62725 L F
.735 .316 .252 r
.25025 .62874 m .2542 .62962 L .25198 .62725 L F
.512 .479 .757 r
.66614 .50812 m .66761 .51267 L .66995 .51182 L F
.548 0 0 r
.66761 .51267 m .67086 .51466 L .66995 .51182 L F
.107 0 0 r
.68494 .51377 m .68879 .51143 L .68752 .51303 L F
.727 .656 .778 r
.68921 .5079 m .691 .50962 L .68879 .51143 L F
.81 .566 .57 r
.68879 .51143 m .69132 .51465 L .68752 .51303 L F
.394 .485 .834 r
.39354 .68385 m .39656 .68659 L .39563 .68338 L F
.526 .466 .732 r
.39284 .68068 m .39354 .68385 L .39563 .68338 L F
.227 0 0 r
.39058 .69781 m .39297 .6981 L .3935 .69789 L F
.456 .861 .69 r
.39484 .69691 m .39297 .6981 L .3935 .69789 L F
.439 .399 .718 r
.3935 .69789 m .39437 .70035 L .39601 .69987 L F
.456 .861 .69 r
.39484 .69691 m .39297 .6981 L .3935 .69789 L F
.439 .399 .718 r
.39601 .69987 m .39437 .70035 L .3935 .69789 L F
.768 .478 .495 r
.74105 .52959 m .7384 .53031 L .74079 .52749 L F
.96 .824 .666 r
.61969 .55336 m .61759 .55581 L .61892 .55252 L F
.61969 .55336 m .61889 .55684 L .61759 .55581 L F
.723 .973 .735 r
.58334 .57334 m .58324 .57295 L .58057 .57559 L F
.785 .948 .61 r
.58526 .56996 m .58334 .57334 L .58635 .57083 L F
.58526 .56996 m .58324 .57295 L .58334 .57334 L F
.65 .412 .545 r
.61705 .53675 m .61357 .53861 L .61358 .53698 L F
.746 .592 .685 r
.56078 .64501 m .5627 .64757 L .55836 .64716 L F
.711 .342 .348 r
.56212 .64872 m .55836 .64716 L .5627 .64757 L F
.676 .578 .738 r
.56264 .64599 m .5627 .64757 L .56078 .64501 L F
.37 .334 .688 r
.56264 .64599 m .56453 .64894 L .5627 .64757 L F
.62 .259 .335 r
.5627 .64757 m .56453 .64894 L .56212 .64872 L F
.5627 .64757 m .56453 .64894 L .56212 .64872 L F
.218 0 0 r
.28325 .58634 m .28544 .58604 L .284 .58576 L F
.111 .656 .832 r
.30664 .58487 m .30879 .58485 L .31035 .5851 L F
.179 .714 .797 r
.30879 .58485 m .31244 .58452 L .31035 .5851 L F
.322 .211 .569 r
.55874 .71738 m .56089 .71335 L .56092 .7113 L F
.592 .53 .755 r
.55943 .71734 m .56089 .71335 L .55874 .71738 L F
.343 .793 .952 r
.49844 .81416 m .50082 .81383 L .49912 .81334 L F
.842 .776 .788 r
.55481 .78868 m .5565 .78684 L .55707 .78534 L F
.618 .671 .879 r
.52008 .64346 m .51666 .6424 L .5196 .64272 L F
.421 .684 .972 r
.52131 .64257 m .52008 .64346 L .5196 .64272 L F
.52131 .64257 m .52252 .64382 L .52008 .64346 L F
.585 .377 .565 r
.52266 .64641 m .52008 .64346 L .52252 .64382 L F
.52266 .64641 m .52112 .6474 L .52008 .64346 L F
.081 0 .009 r
.36524 .62409 m .36253 .6265 L .36347 .62512 L F
.442 0 0 r
.48859 .7854 m .49213 .78517 L .49066 .7864 L F
0 0 0 r
.49066 .7864 m .49213 .78517 L .49356 .78447 L F
.81 .498 0 r
.7345 .4946 m .73445 .49541 L .73402 .49325 L F
.7345 .4946 m .73505 .49676 L .73445 .49541 L F
.609 .17 .18 r
.53251 .80055 m .53311 .79966 L .53083 .79898 L F
.21 0 0 r
.66931 .47903 m .66892 .47913 L .66543 .47848 L F
.336 0 0 r
.66931 .47903 m .67198 .47998 L .66892 .47913 L F
.494 .32 .573 r
.52284 .79102 m .52476 .79062 L .52467 .7878 L F
.34 .315 .685 r
.52284 .79102 m .52509 .793 L .52476 .79062 L F
.912 .687 .584 r
.512 .79945 m .51361 .79992 L .51198 .7962 L F
.894 .772 .72 r
.512 .79945 m .51286 .80203 L .51361 .79992 L F
.512 .79945 m .51286 .80203 L .51361 .79992 L F
.152 0 0 r
.50824 .69748 m .50894 .69859 L .51053 .69734 L F
.50824 .69748 m .50691 .69931 L .50894 .69859 L F
0 .013 .588 r
.55192 .7486 m .55224 .74787 L .55045 .74528 L F
.356 .321 .681 r
.55192 .7486 m .55399 .75058 L .55224 .74787 L F
.601 .616 .838 r
.25881 .61871 m .25942 .61492 L .25809 .61568 L F
.25881 .61871 m .26148 .61852 L .25942 .61492 L F
.705 .344 .361 r
.25119 .64949 m .25244 .65057 L .25262 .64963 L F
.25119 .64949 m .25055 .6511 L .25244 .65057 L F
.099 0 0 r
.55116 .77888 m .55148 .77887 L .55115 .7794 L F
.55148 .77887 m .55333 .7788 L .55115 .7794 L F
.55116 .77888 m .55333 .7788 L .55115 .7794 L F
0 0 0 r
.55116 .77888 m .55243 .77688 L .55115 .7794 L F
.59 .644 .872 r
.55188 .77608 m .55333 .7788 L .55115 .7794 L F
.515 .853 .995 r
.55115 .7794 m .55333 .7788 L .55225 .77803 L F
.55115 .7794 m .55225 .77803 L .55056 .78035 L F
.55115 .7794 m .55056 .78035 L .55034 .78067 L F
.584 .531 .762 r
.75748 .58774 m .7599 .58724 L .76046 .59061 L F
.654 .46 .609 r
.75773 .58872 m .7599 .58724 L .75748 .58774 L F
.808 .579 .591 r
.58662 .59893 m .58331 .59588 L .58359 .59792 L F
.762 .283 .103 r
.58359 .59792 m .58547 .59989 L .58662 .59893 L F
.564 .078 .06 r
.58547 .59989 m .58905 .599 L .58662 .59893 L F
.316 .558 .922 r
.31469 .62971 m .31382 .63125 L .31284 .62978 L F
.31469 .62971 m .31651 .63195 L .31382 .63125 L F
.563 .354 .555 r
.58327 .61021 m .58328 .61258 L .5809 .61308 L F
.602 .382 .555 r
.58572 .61007 m .58328 .61258 L .58327 .61021 L F
0 0 0 r
.62314 .58087 m .62158 .58233 L .62357 .57938 L F
.211 .06 .447 r
.62314 .58087 m .62085 .58429 L .62158 .58233 L F
.555 .518 .769 r
.40449 .70855 m .40558 .7122 L .40693 .70926 L F
.528 .487 .754 r
.40558 .7122 m .4079 .71201 L .40693 .70926 L F
.346 0 .085 r
.33336 .62862 m .33647 .62713 L .33435 .62783 L F
.098 0 .267 r
.62297 .49747 m .62467 .4965 L .625 .4943 L F
.548 .367 .588 r
.62247 .49924 m .62467 .4965 L .62297 .49747 L F
.605 .404 .583 r
.50538 .7999 m .50957 .79842 L .50944 .79654 L F
.794 .511 .508 r
.51198 .7962 m .50863 .79371 L .50944 .79654 L F
.659 .477 .628 r
.50957 .79842 m .51198 .7962 L .50944 .79654 L F
.665 .646 .821 r
.54138 .78687 m .54475 .78672 L .54433 .78468 L F
.938 .855 .734 r
.72692 .50241 m .7272 .50563 L .728 .50347 L F
.742 .321 .248 r
.47333 .69153 m .47704 .69178 L .47471 .69213 L F
.812 .792 .834 r
.66891 .50614 m .67203 .50594 L .67096 .50492 L F
.665 .666 .841 r
.71729 .51377 m .71839 .51678 L .72048 .51608 L F
.678 .961 .737 r
.50153 .77434 m .49877 .77672 L .49984 .77537 L F
.666 .219 .181 r
.49984 .77537 m .5034 .776 L .50153 .77434 L F
.725 .635 .758 r
.67091 .52969 m .67442 .53286 L .67378 .53072 L F
.677 .768 .92 r
.67378 .53072 m .67442 .53286 L .6773 .53146 L F
.562 .211 .331 r
.50256 .62341 m .50588 .62381 L .50356 .62311 L F
.802 .744 .798 r
.55068 .62692 m .54992 .62365 L .55113 .6247 L F
.634 .824 .974 r
.5534 .62409 m .55113 .6247 L .54992 .62365 L F
0 0 0 r
.33035 .6458 m .33222 .64474 L .33428 .64408 L F
.393 .531 .876 r
.24945 .63098 m .25025 .62874 L .24864 .62869 L F
.24945 .63098 m .25167 .63153 L .25025 .62874 L F
.398 .719 .988 r
.53426 .65542 m .53662 .65538 L .53462 .65429 L F
.903 .558 .379 r
.53662 .65538 m .53462 .65429 L .53426 .65542 L F
.448 .219 .473 r
.59318 .53899 m .59533 .53621 L .59333 .53665 L F
.733 .484 .552 r
.63527 .50243 m .63784 .50072 L .63512 .4996 L F
.63527 .50243 m .63867 .50278 L .63784 .50072 L F
0 .102 .656 r
.71164 .47209 m .71142 .46943 L .70977 .46948 L F
.71164 .47209 m .71245 .47213 L .71142 .46943 L F
.486 .228 .448 r
.39297 .6981 m .39029 .70006 L .39058 .69781 L F
.39058 .69781 m .39029 .70006 L .39297 .6981 L F
.899 .968 .654 r
.6404 .52006 m .63885 .5214 L .63937 .52164 L F
.948 .951 .646 r
.64047 .51792 m .63885 .5214 L .6404 .52006 L F
.737 .643 .755 r
.5194 .80606 m .51819 .80777 L .51633 .80542 L F
.703 .182 0 r
.51819 .80777 m .51855 .80907 L .51757 .80866 L F
.51819 .80777 m .52015 .80941 L .51855 .80907 L F
.432 .756 .995 r
.30585 .62779 m .30527 .62907 L .30387 .62784 L F
.30585 .62779 m .30736 .62885 L .30527 .62907 L F
.857 .724 .715 r
.68029 .50532 m .68139 .5085 L .67979 .50717 L F
.788 .891 .918 r
.68139 .5085 m .6785 .50862 L .67979 .50717 L F
.589 .59 .821 r
.68252 .50471 m .68139 .5085 L .68029 .50532 L F
.68252 .50471 m .6838 .50805 L .68139 .5085 L F
.746 .592 .685 r
.56078 .64501 m .55883 .64461 L .56079 .6445 L F
.56078 .64501 m .55836 .64716 L .55883 .64461 L F
.676 .578 .738 r
.56264 .64599 m .56078 .64501 L .56079 .6445 L F
.789 .318 0 r
.50407 .76572 m .50607 .76819 L .50796 .76507 L F
.612 .166 .167 r
.43418 .69759 m .43625 .69906 L .43769 .69748 L F
.368 0 .005 r
.43625 .69906 m .43998 .69727 L .43769 .69748 L F
.9 .763 .7 r
.62108 .54516 m .61832 .54718 L .61822 .54483 L F
.62108 .54516 m .61993 .54812 L .61832 .54718 L F
.454 .7 .973 r
.5177 .64101 m .51666 .6424 L .51577 .64055 L F
.5177 .64101 m .5196 .64272 L .51666 .6424 L F
.526 .466 .732 r
.39284 .68068 m .39563 .68338 L .39483 .68011 L F
.555 .258 .418 r
.50614 .80139 m .50957 .79842 L .50538 .7999 L F
.335 0 0 r
.37998 .59724 m .38174 .59769 L .38358 .59752 L F
.388 0 0 r
.38174 .59769 m .38532 .59817 L .38358 .59752 L F
.582 .503 .731 r
.56021 .72095 m .5618 .71684 L .55943 .71734 L F
.56021 .72095 m .56285 .72043 L .5618 .71684 L F
.547 .349 .564 r
.5994 .5906 m .6017 .5902 L .6017 .58794 L F
.599 .433 .628 r
.60446 .58965 m .6017 .58794 L .6017 .5902 L F
.60446 .58965 m .60469 .58742 L .6017 .58794 L F
.879 .506 .332 r
.55987 .74545 m .5612 .74813 L .563 .74859 L F
.858 .5 .371 r
.56173 .75031 m .563 .74859 L .5612 .74813 L F
.56173 .75031 m .56349 .75054 L .563 .74859 L F
.969 .869 .683 r
.72627 .50417 m .7272 .50563 L .72692 .50241 L F
.818 .512 .472 r
.72467 .50758 m .7272 .50563 L .72627 .50417 L F
.72467 .50758 m .72805 .50642 L .7272 .50563 L F
.889 .575 .448 r
.55456 .64412 m .55169 .64446 L .55167 .643 L F
.55456 .64412 m .5548 .6466 L .55169 .64446 L F
.789 .628 .681 r
.55883 .64461 m .55456 .64412 L .55717 .64337 L F
.55883 .64461 m .5548 .6466 L .55456 .64412 L F
.496 .565 .855 r
.26892 .64835 m .26809 .64956 L .26558 .64539 L F
.802 .966 .653 r
.26822 .6485 m .26892 .64835 L .26835 .64833 L F
.086 .327 .804 r
.26543 .64609 m .26809 .64956 L .26523 .64708 L F
.26662 .64712 m .26809 .64956 L .26543 .64609 L F
.673 .384 .475 r
.26523 .64708 m .26809 .64956 L .26465 .64901 L F
.451 .723 .984 r
.26809 .64956 m .26777 .65003 L .26465 .64901 L F
.802 .966 .653 r
.26719 .6499 m .26849 .64873 L .26822 .6485 L F
.26849 .64873 m .26892 .64835 L .26822 .6485 L F
.086 .327 .804 r
.26558 .64539 m .26662 .64712 L .26543 .64609 L F
.453 .153 .365 r
.61551 .50528 m .61782 .50474 L .61764 .50275 L F
.387 .149 .427 r
.61764 .50275 m .62032 .50212 L .62069 .50011 L F
.503 .272 .496 r
.61782 .50474 m .62032 .50212 L .61764 .50275 L F
.986 .709 .373 r
.73394 .50304 m .73307 .50491 L .73344 .50212 L F
.73394 .50304 m .73415 .50582 L .73307 .50491 L F
.454 .39 .696 r
.57103 .62625 m .56986 .62992 L .5686 .62681 L F
.57103 .62625 m .57172 .62957 L .56986 .62992 L F
.486 .398 .682 r
.57172 .62957 m .5703 .63235 L .56986 .62992 L F
.219 .637 .954 r
.26242 .62126 m .26247 .61766 L .26148 .61852 L F
.26242 .62126 m .26271 .62039 L .26247 .61766 L F
.26242 .62126 m .26395 .62122 L .26271 .62039 L F
.778 .878 .92 r
.41001 .71103 m .41407 .71058 L .4126 .70782 L F
.41001 .71103 m .41147 .71191 L .41407 .71058 L F
.19 .418 .852 r
.4126 .70782 m .41407 .71058 L .4148 .70991 L F
0 0 0 r
.61245 .57059 m .61199 .57247 L .61306 .56885 L F
.403 .115 .358 r
.47854 .79383 m .48167 .79026 L .47999 .79026 L F
.47854 .79383 m .48081 .79327 L .48167 .79026 L F
.631 .194 .193 r
.48275 .79249 m .48167 .79026 L .48081 .79327 L F
.48275 .79249 m .48414 .79087 L .48167 .79026 L F
.548 .452 .698 r
.57659 .71121 m .57656 .71511 L .57549 .71136 L F
.57659 .71121 m .57887 .71492 L .57656 .71511 L F
.51 .245 .448 r
.59915 .59263 m .6017 .5902 L .5994 .5906 L F
.625 .564 .766 r
.51061 .76447 m .51313 .76524 L .51252 .76198 L F
.742 .723 .833 r
.51303 .7654 m .51477 .76669 L .51733 .7657 L F
.51709 .76561 m .51733 .7657 L .51751 .76563 L F
.51303 .7654 m .51733 .7657 L .51709 .76561 L F
.812 .641 .67 r
.51252 .76198 m .51368 .76435 L .51531 .76472 L F
.742 .723 .833 r
.51274 .76538 m .51751 .76563 L .51531 .76472 L F
.669 .402 .508 r
.51531 .76472 m .51428 .7656 L .51274 .76538 L F
.812 .641 .67 r
.51368 .76435 m .51428 .7656 L .51512 .76488 L F
.51368 .76435 m .51512 .76488 L .51531 .76472 L F
.625 .564 .766 r
.51313 .76524 m .51428 .7656 L .51368 .76435 L F
.51313 .76524 m .51368 .76435 L .51252 .76198 L F
.742 .723 .833 r
.51274 .76538 m .51296 .76552 L .51303 .7654 L F
.51296 .76552 m .51477 .76669 L .51303 .7654 L F
.599 .434 .63 r
.53277 .64983 m .53337 .65245 L .53109 .65257 L F
.188 .592 .943 r
.53189 .64857 m .53388 .6495 L .53277 .64983 L F
.433 .448 .775 r
.53388 .6495 m .53337 .65245 L .53277 .64983 L F
.012 .584 .762 r
.52817 .8046 m .53171 .80487 L .53009 .8047 L F
.52817 .8046 m .53171 .80487 L .53009 .8047 L F
0 0 0 r
.53251 .80055 m .53171 .80487 L .53009 .8047 L F
.604 .042 0 r
.53009 .8047 m .53171 .80487 L .53312 .80609 L F
.32 .214 .574 r
.47981 .77354 m .48008 .77629 L .47861 .77621 L F
.505 .433 .709 r
.70767 .48005 m .70747 .48372 L .70549 .4828 L F
.70767 .48005 m .70549 .4828 L .70648 .4819 L F
.199 .482 .895 r
.70549 .4828 m .70747 .48372 L .70648 .4819 L F
.845 .784 .792 r
.70025 .5163 m .70329 .51674 L .70363 .51477 L F
.867 .717 .694 r
.70145 .5197 m .70329 .51674 L .70025 .5163 L F
.677 .638 .804 r
.26307 .65245 m .26465 .64901 L .26306 .65041 L F
.26307 .65245 m .26616 .65286 L .26465 .64901 L F
.969 .692 .452 r
.46816 .64978 m .46828 .65213 L .46837 .6521 L F
0 0 0 r
.46959 .64859 m .46816 .64978 L .47022 .64804 L F
0 0 .339 r
.46914 .65073 m .46816 .64978 L .46959 .64859 L F
.46914 .65073 m .46828 .65213 L .46816 .64978 L F
.748 .908 .529 r
.55072 .5893 m .55198 .58779 L .55008 .59081 L F
0 0 0 r
.55198 .58779 m .55333 .58648 L .55441 .58523 L F
.55072 .5893 m .55333 .58648 L .55198 .58779 L F
.601 .585 .808 r
.75651 .59679 m .75761 .59263 L .75553 .59293 L F
.75651 .59679 m .75918 .5968 L .75761 .59263 L F
.654 .606 .789 r
.57764 .70872 m .57549 .71136 L .57528 .70929 L F
.693 .667 .82 r
.57764 .70872 m .57659 .71121 L .57549 .71136 L F
.501 .903 .921 r
.49932 .62421 m .49935 .62388 L .50256 .62341 L F
.939 .81 .691 r
.4989 .62497 m .50256 .62341 L .49935 .62388 L F
.4989 .62497 m .50023 .62624 L .50256 .62341 L F
.615 .379 .536 r
.50256 .62341 m .50594 .62618 L .50588 .62381 L F
.50256 .62341 m .50355 .62641 L .50594 .62618 L F
.446 .87 .752 r
.66815 .47484 m .66458 .47649 L .66696 .47518 L F
.096 .612 .886 r
.66969 .47465 m .66815 .47484 L .66696 .47518 L F
.66969 .47465 m .67034 .47516 L .66815 .47484 L F
0 0 .056 r
.62538 .57609 m .62502 .57813 L .62357 .57938 L F
0 0 0 r
.62402 .57994 m .62357 .57938 L .62502 .57813 L F
.62402 .57994 m .62314 .58087 L .62357 .57938 L F
.685 .22 .142 r
.41047 .66015 m .40848 .65837 L .40684 .65962 L F
.573 .287 .443 r
.41047 .66015 m .41086 .65819 L .40848 .65837 L F
.594 .559 .785 r
.38813 .60101 m .38783 .60167 L .38638 .59916 L F
.473 .347 .628 r
.38813 .60101 m .38766 .60405 L .38783 .60167 L F
.852 .857 .846 r
.67494 .51047 m .6743 .51213 L .67251 .5104 L F
.76 .548 .61 r
.49664 .70007 m .49471 .6969 L .49561 .69689 L F
.49664 .70007 m .49305 .70017 L .49471 .6969 L F
.305 .003 .276 r
.25967 .59606 m .2615 .59545 L .26229 .59358 L F
.28 0 .263 r
.26229 .59358 m .2615 .59545 L .26407 .59284 L F
.504 .156 .309 r
.42438 .65496 m .42685 .65477 L .42786 .65236 L F
.359 .016 .241 r
.42786 .65236 m .42892 .6542 L .43019 .65238 L F
.42786 .65236 m .42685 .65477 L .42892 .6542 L F
.597 .556 .779 r
.26559 .63568 m .26799 .63553 L .26666 .6323 L F
.648 .478 .64 r
.26559 .63568 m .26846 .63811 L .26799 .63553 L F
.26559 .63568 m .26581 .6386 L .26846 .63811 L F
.727 .845 .937 r
.4079 .71201 m .41147 .71191 L .41001 .71103 L F
.669 .463 .596 r
.25899 .64615 m .26142 .6441 L .25996 .64313 L F
.25899 .64615 m .26143 .64653 L .26142 .6441 L F
.096 0 .09 r
.53079 .77881 m .52877 .78118 L .52898 .77945 L F
0 .409 .793 r
.47468 .79515 m .47425 .79531 L .47242 .79546 L F
.47468 .79515 m .47638 .79617 L .47425 .79531 L F
0 0 0 r
.31975 .60167 m .31811 .6022 L .31625 .60234 L F
.131 0 0 r
.32193 .60146 m .31811 .6022 L .31975 .60167 L F
.584 .316 .476 r
.53079 .69232 m .53029 .69455 L .52782 .69446 L F
.39 .139 .409 r
.53234 .69373 m .53079 .69232 L .53269 .69174 L F
.53234 .69373 m .53029 .69455 L .53079 .69232 L F
.705 .672 .814 r
.68294 .53033 m .68623 .53104 L .68499 .52968 L F
.627 .767 .947 r
.68499 .52968 m .68623 .53104 L .68856 .53037 L F
.748 .707 .813 r
.70009 .50076 m .70093 .5035 L .69772 .50277 L F
.803 .725 .779 r
.70093 .5035 m .69722 .50483 L .69772 .50277 L F
.70093 .5035 m .69881 .50619 L .69722 .50483 L F
.673 .664 .833 r
.70326 .50245 m .70093 .5035 L .70009 .50076 L F
.881 .974 .838 r
.58844 .56776 m .58526 .56996 L .58635 .57083 L F
.58844 .56776 m .5876 .56723 L .58526 .56996 L F
.796 .999 .823 r
.59078 .56502 m .5876 .56723 L .58844 .56776 L F
.941 .745 .609 r
.61476 .54207 m .61595 .54538 L .61459 .54511 L F
.867 .452 .236 r
.61595 .54538 m .61504 .5467 L .61459 .54511 L F
.597 .552 .775 r
.61677 .54158 m .61595 .54538 L .61476 .54207 L F
.61677 .54158 m .61822 .54483 L .61595 .54538 L F
.799 .541 .549 r
.61822 .54483 m .61504 .5467 L .61595 .54538 L F
.676 .578 .738 r
.56264 .64599 m .56079 .6445 L .56325 .64347 L F
.599 .44 .637 r
.5664 .64367 m .56264 .64599 L .56325 .64347 L F
.5664 .64367 m .56644 .64656 L .56264 .64599 L F
.601 .418 .606 r
.56644 .64656 m .56453 .64894 L .56264 .64599 L F
.904 .838 .77 r
.72467 .50758 m .72491 .51103 L .72805 .50642 L F
.751 .728 .831 r
.69881 .50619 m .69529 .50588 L .69722 .50483 L F
.594 .275 .399 r
.43375 .6687 m .43025 .6712 L .43139 .66933 L F
.662 .276 0 r
.51588 .78219 m .51433 .77921 L .51425 .78161 L F
.75 .232 0 r
.51639 .78373 m .51588 .78219 L .51425 .78161 L F
.51639 .78373 m .51792 .78454 L .51588 .78219 L F
.784 .699 .771 r
.38932 .70518 m .38516 .70532 L .38435 .70249 L F
.38932 .70518 m .38516 .70532 L .38435 .70249 L F
.383 .774 .988 r
.33273 .60082 m .33057 .59995 L .3286 .60053 L F
.345 .758 .98 r
.33273 .60082 m .3319 .59986 L .33057 .59995 L F
.33273 .60082 m .33387 .60062 L .3319 .59986 L F
.692 .766 .908 r
.68856 .53037 m .69203 .53089 L .69106 .5293 L F
.658 .751 .918 r
.69106 .5293 m .69203 .53089 L .69458 .53002 L F
.415 0 .043 r
.46223 .70016 m .46101 .7016 L .45867 .70102 L F
.515 .068 .128 r
.46434 .7002 m .46101 .7016 L .46223 .70016 L F
.378 .25 .578 r
.29586 .61998 m .29412 .61827 L .2962 .61809 L F
.29586 .61998 m .29362 .62251 L .29412 .61827 L F
.699 .322 0 r
.71456 .49077 m .71597 .49368 L .7147 .49133 L F
.482 .54 .84 r
.71597 .49368 m .7172 .49003 L .7147 .49133 L F
.71597 .49368 m .71984 .49349 L .7172 .49003 L F
.232 .75 .836 r
.33057 .59995 m .32621 .60041 L .3286 .60053 L F
.347 0 0 r
.43471 .65155 m .43828 .64989 L .43605 .65009 L F
.218 0 .072 r
.53718 .8041 m .5399 .80225 L .53841 .80131 L F
.248 .62 .958 r
.25607 .63212 m .25738 .63194 L .2561 .63196 L F
.25607 .63212 m .25738 .63194 L .2561 .63196 L F
.648 .694 .879 r
.77095 .59755 m .77191 .60025 L .76818 .59842 L F
.969 .71 .284 r
.77191 .60025 m .77175 .60133 L .77095 .59755 L F
.077 .629 .821 r
.53337 .65245 m .52928 .65206 L .53109 .65257 L F
.595 .409 .6 r
.53337 .65245 m .5307 .65509 L .53109 .65257 L F
.938 .744 .615 r
.53109 .65257 m .5307 .65509 L .52928 .65206 L F
.82 .849 .87 r
.64315 .51316 m .64442 .51433 L .64694 .51225 L F
.772 .551 .599 r
.48768 .79286 m .48988 .79085 L .48754 .79067 L F
.48768 .79286 m .48965 .7933 L .48988 .79085 L F
.792 .351 .201 r
.49315 .79353 m .48988 .79085 L .48965 .7933 L F
.946 .592 .21 r
.58908 .69925 m .58958 .69789 L .58927 .69673 L F
.58908 .69925 m .59016 .70021 L .58958 .69789 L F
.508 .209 .394 r
.38557 .60591 m .38436 .60934 L .38208 .60957 L F
.405 .168 .438 r
.38766 .60405 m .38613 .60894 L .38557 .60591 L F
.215 .737 .749 r
.38613 .60894 m .38436 .60934 L .38557 .60591 L F
.569 .342 .532 r
.5915 .59609 m .59401 .59591 L .59463 .59303 L F
.696 .475 .584 r
.59401 .59591 m .59689 .5932 L .59463 .59303 L F
.302 0 0 r
.52945 .64819 m .52816 .649 L .53189 .64857 L F
.178 0 .256 r
.52059 .76732 m .52156 .76946 L .52328 .76737 L F
.52059 .76732 m .51981 .77029 L .52156 .76946 L F
.757 .741 .837 r
.72048 .51608 m .72438 .51505 L .72306 .5136 L F
.614 .567 .777 r
.58002 .70821 m .57659 .71121 L .57764 .70872 L F
.58002 .70821 m .58379 .71291 L .57659 .71121 L F
.58379 .71291 m .58379 .71305 L .57659 .71121 L F
.153 0 0 r
.58379 .71305 m .57887 .71492 L .57659 .71121 L F
.816 .729 .769 r
.58379 .71305 m .58466 .71418 L .5838 .71419 L F
.153 0 0 r
.58393 .71309 m .5837 .71317 L .58379 .71305 L F
.5837 .71317 m .57887 .71492 L .58379 .71305 L F
.816 .729 .769 r
.58377 .71124 m .58417 .71255 L .58379 .71305 L F
.58417 .71255 m .58466 .71418 L .58379 .71305 L F
.153 0 0 r
.5837 .71317 m .58155 .71419 L .57887 .71492 L F
.816 .729 .769 r
.58379 .71313 m .5838 .71419 L .58155 .71419 L F
.153 0 0 r
.58393 .71309 m .58155 .71419 L .5837 .71317 L F
.816 .729 .769 r
.58377 .71124 m .58379 .71291 L .58372 .7113 L F
.605 .564 .782 r
.58371 .71105 m .58393 .71309 L .58379 .71291 L F
.58371 .71105 m .58379 .71291 L .58002 .70821 L F
.816 .729 .769 r
.58372 .7113 m .58379 .71313 L .58155 .71419 L F
.58379 .71291 m .58379 .71313 L .58372 .7113 L F
.58371 .71105 m .58377 .71124 L .58155 .71419 L F
.614 .567 .777 r
.58379 .71291 m .58393 .71309 L .58379 .71305 L F
.547 .546 .805 r
.39859 .69475 m .39955 .6907 L .39793 .69226 L F
.39859 .69475 m .40093 .69439 L .39955 .6907 L F
.621 .926 .972 r
.67948 .47399 m .68075 .47244 L .68222 .47292 L F
.67948 .47399 m .67859 .47348 L .68075 .47244 L F
.011 .211 .721 r
.26465 .64901 m .26616 .65286 L .26672 .65137 L F
.555 .446 .685 r
.26777 .65003 m .26843 .6524 L .26616 .65286 L F
.52 .807 .998 r
.26616 .65286 m .26843 .6524 L .26672 .65137 L F
.529 .524 .794 r
.25753 .61301 m .25827 .60925 L .25644 .60968 L F
.25753 .61301 m .25939 .61249 L .25827 .60925 L F
.464 .305 .579 r
.25753 .61301 m .25942 .61492 L .25939 .61249 L F
.342 .291 .655 r
.25809 .61568 m .25942 .61492 L .25753 .61301 L F
.791 .616 .663 r
.69132 .51465 m .68841 .51646 L .68752 .51303 L F
.967 .665 .399 r
.69132 .51465 m .69189 .51699 L .68841 .51646 L F
.914 .817 .737 r
.63418 .55094 m .63529 .54883 L .63381 .54765 L F
.582 .302 .457 r
.53338 .75609 m .53245 .75727 L .52987 .75701 L F
.53338 .75609 m .53245 .75727 L .52987 .75701 L F
.482 .756 .991 r
.5945 .71478 m .59506 .71491 L .59473 .71331 L F
.86 .978 .857 r
.59473 .71331 m .59506 .71491 L .59827 .71104 L F
.463 .353 .644 r
.25586 .60741 m .25758 .60381 L .25548 .60539 L F
.367 .065 .314 r
.36049 .6271 m .3598 .62913 L .35779 .62961 L F
.375 .075 .321 r
.36253 .6265 m .3598 .62913 L .36049 .6271 L F
0 0 0 r
.62662 .57452 m .62538 .57609 L .62749 .57317 L F
.6288 .56946 m .62765 .57304 L .62749 .57317 L F
.62765 .57304 m .62662 .57452 L .62749 .57317 L F
.894 .798 .747 r
.7314 .51072 m .73293 .51202 L .73128 .51464 L F
.485 .856 .986 r
.4759 .6975 m .47265 .69783 L .47475 .69756 L F
.589 .267 .391 r
.4759 .6975 m .47231 .69996 L .47265 .69783 L F
.4759 .6975 m .47485 .70014 L .47231 .69996 L F
.59 .267 .391 r
.47821 .69931 m .4759 .6975 L .47829 .69778 L F
.47821 .69931 m .47485 .70014 L .4759 .6975 L F
.47 .272 .53 r
.64111 .51172 m .64387 .51134 L .64343 .50886 L F
.488 .344 .611 r
.64111 .51172 m .64315 .51316 L .64387 .51134 L F
.662 .842 .969 r
.53662 .65538 m .54024 .65554 L .5388 .6545 L F
.53662 .65538 m .54024 .65554 L .5388 .6545 L F
.304 .706 .977 r
.31662 .58445 m .31604 .58536 L .31447 .58457 L F
.31662 .58445 m .31823 .58543 L .31604 .58536 L F
.598 .597 .821 r
.6405 .4969 m .64407 .49947 L .64278 .49615 L F
.405 .48 .824 r
.64278 .49615 m .64407 .49947 L .64488 .49872 L F
.441 .302 .595 r
.74782 .50529 m .74738 .50798 L .74577 .50842 L F
.763 .643 .729 r
.74738 .50798 m .74624 .50962 L .74577 .50842 L F
.531 .263 .454 r
.58835 .6078 m .58805 .60981 L .58572 .61007 L F
.58 .321 .489 r
.58835 .6078 m .5905 .60973 L .58805 .60981 L F
.58835 .6078 m .59141 .607 L .5905 .60973 L F
.791 .991 .753 r
.54912 .74496 m .54861 .74652 L .55045 .74528 L F
.519 .509 .785 r
.70209 .48227 m .70345 .4789 L .70131 .48108 L F
.70209 .48227 m .70463 .48162 L .70345 .4789 L F
.697 .963 .721 r
.51538 .81148 m .51757 .80866 L .51573 .81144 L F
.51468 .81158 m .51589 .81004 L .51538 .81148 L F
.5143 .81136 m .51589 .81004 L .51468 .81158 L F
.375 .262 .595 r
.51391 .81168 m .51527 .80979 L .51356 .80964 L F
.697 .963 .721 r
.51391 .81168 m .5143 .81136 L .51468 .81158 L F
.51589 .81004 m .51757 .80866 L .51538 .81148 L F
.375 .262 .595 r
.51391 .81168 m .51573 .81144 L .51527 .80979 L F
0 .104 .659 r
.51356 .80964 m .51524 .81189 L .51519 .81171 L F
.51524 .81189 m .51569 .81249 L .51533 .81194 L F
.51524 .81189 m .51533 .81194 L .51519 .81171 L F
.713 .501 .601 r
.51232 .80769 m .51268 .80997 L .50858 .81016 L F
.375 .262 .595 r
.51391 .81168 m .51356 .80964 L .51569 .81249 L F
.856 .439 .235 r
.51167 .80869 m .51519 .81202 L .51356 .80964 L F
.51519 .81202 m .51569 .81249 L .51524 .81189 L F
.51519 .81202 m .51524 .81189 L .51356 .80964 L F
.176 0 0 r
.51573 .81144 m .51757 .80866 L .51855 .80907 L F
.737 .643 .755 r
.5194 .80606 m .51633 .80542 L .519 .80766 L F
.51932 .8077 m .519 .80766 L .51918 .80782 L F
.622 .546 .748 r
.51874 .80764 m .51855 .80907 L .5197 .80804 L F
.51918 .80782 m .5197 .80804 L .5197 .80804 L F
.51874 .80764 m .5197 .80804 L .51918 .80782 L F
.782 .694 .766 r
.51811 .80803 m .51855 .80907 L .51874 .80764 L F
.51743 .80749 m .51874 .80764 L .51874 .80763 L F
.693 .236 .163 r
.51829 .80757 m .51852 .8076 L .51527 .80652 L F
.51918 .80782 m .51633 .80542 L .51554 .80624 L F
.51918 .80782 m .51554 .80624 L .51527 .80652 L F
.51829 .80757 m .51527 .80652 L .51897 .80586 L F
.782 .694 .766 r
.51746 .80746 m .51874 .80763 L .51897 .80586 L F
.51743 .80749 m .51874 .80763 L .51746 .80746 L F
.693 .236 .163 r
.51931 .80793 m .51918 .80782 L .51852 .8076 L F
.51931 .80793 m .51852 .8076 L .51829 .80757 L F
.737 .643 .755 r
.51931 .80788 m .51918 .80782 L .51931 .80793 L F
.51932 .8077 m .51918 .80782 L .51931 .80788 L F
.5194 .80606 m .519 .80766 L .51932 .8077 L F
0 .267 .759 r
.52113 .80675 m .5194 .80606 L .51931 .80788 L F
.622 .546 .748 r
.51931 .80788 m .5197 .80804 L .52113 .80675 L F
0 .267 .759 r
.52113 .80675 m .51931 .80788 L .51931 .80793 L F
.622 .546 .748 r
.51874 .80764 m .51931 .80788 L .52113 .80675 L F
.51897 .80586 m .51874 .80764 L .52113 .80675 L F
.693 .236 .163 r
.51931 .80793 m .51829 .80757 L .51897 .80586 L F
.782 .694 .766 r
.51527 .80979 m .51761 .80928 L .51811 .80803 L F
.51761 .80928 m .51855 .80907 L .51811 .80803 L F
.51527 .80979 m .51874 .80764 L .51743 .80749 L F
.624 .623 .829 r
.55667 .6359 m .55519 .637 L .5541 .63419 L F
.734 .947 .636 r
.55878 .76975 m .56032 .76724 L .56085 .76763 L F
.55878 .76975 m .55795 .77021 L .56032 .76724 L F
.528 .186 .331 r
.26282 .62928 m .26579 .62993 L .26614 .62724 L F
.446 .501 .823 r
.26504 .62441 m .26614 .62724 L .26797 .62633 L F
.354 .043 .292 r
.26614 .62724 m .2673 .62892 L .26797 .62633 L F
.26614 .62724 m .26579 .62993 L .2673 .62892 L F
.169 .327 .781 r
.51411 .8009 m .51286 .80203 L .512 .79945 L F
0 0 0 r
.51411 .8009 m .51184 .80375 L .51286 .80203 L F
.759 .752 .846 r
.65606 .51648 m .65769 .5179 L .6588 .51593 L F
0 0 .012 r
.62662 .57452 m .62502 .57813 L .62538 .57609 L F
.592 .53 .755 r
.55943 .71734 m .5618 .71684 L .56089 .71335 L F
.234 0 0 r
.52881 .77033 m .53111 .76999 L .53221 .76885 L F
.669 .187 .097 r
.53111 .76999 m .53435 .7704 L .53221 .76885 L F
.789 .628 .681 r
.55883 .64461 m .55836 .64716 L .5548 .6466 L F
.511 .715 .964 r
.5595 .64296 m .55883 .64461 L .55717 .64337 L F
.5595 .64296 m .56079 .6445 L .55883 .64461 L F
.543 .427 .671 r
.29362 .62251 m .29441 .62391 L .29231 .6244 L F
.433 .031 .174 r
.41812 .65672 m .41661 .65559 L .41591 .65702 L F
.41812 .65672 m .4187 .65539 L .41661 .65559 L F
.873 .814 .788 r
.6782 .51984 m .67468 .52187 L .67694 .51899 L F
.6782 .51984 m .67604 .52304 L .67468 .52187 L F
.713 .501 .601 r
.51232 .80769 m .50858 .81016 L .50888 .80765 L F
.158 .029 .443 r
.6547 .49898 m .65301 .50026 L .65405 .4971 L F
.841 .729 .741 r
.67955 .47964 m .67793 .47999 L .68066 .48016 L F
.836 .75 .768 r
.67793 .47999 m .67871 .48324 L .68066 .48016 L F
.772 .772 .853 r
.67955 .47964 m .68066 .48016 L .68358 .47793 L F
.893 .911 .83 r
.67392 .52593 m .67083 .52769 L .67227 .52472 L F
.837 .795 .811 r
.67604 .52304 m .67392 .52593 L .67227 .52472 L F
.772 .745 .828 r
.39029 .70006 m .39437 .70035 L .39297 .6981 L F
.373 .206 .521 r
.39437 .70035 m .3946 .70298 L .39601 .69987 L F
.957 .757 .592 r
.55874 .63247 m .55746 .62917 L .55872 .62992 L F
.688 .483 .605 r
.58586 .70324 m .58668 .70548 L .58327 .70533 L F
.318 .396 .785 r
.42572 .67445 m .4234 .67255 L .42571 .67195 L F
.739 .656 .767 r
.68921 .5079 m .69278 .50843 L .691 .50962 L F
.828 .561 .535 r
.54802 .73895 m .55118 .73717 L .54948 .73672 L F
.54802 .73895 m .55111 .7396 L .55118 .73717 L F
.812 .547 .538 r
.55118 .73717 m .55111 .7396 L .55305 .73973 L F
.864 .97 .86 r
.54906 .59263 m .55072 .5893 L .55008 .59081 L F
.206 .045 .43 r
.25988 .59862 m .2615 .59545 L .25967 .59606 L F
0 0 0 r
.50283 .6401 m .50028 .64081 L .50374 .6395 L F
.50283 .6401 m .50057 .64077 L .50028 .64081 L F
.802 .744 .798 r
.55068 .62692 m .54769 .62651 L .54992 .62365 L F
.866 .658 .619 r
.55068 .62692 m .54762 .62904 L .54769 .62651 L F
.55068 .62692 m .55008 .62986 L .54762 .62904 L F
.094 0 .137 r
.612 .51427 m .61275 .5139 L .61446 .51151 L F
.307 .101 .429 r
.612 .51427 m .61291 .51486 L .61275 .5139 L F
.612 .51427 m .61182 .51597 L .61291 .51486 L F
0 0 0 r
.55781 .58087 m .55779 .58091 L .55876 .57924 L F
.784 .954 .626 r
.55949 .57741 m .56085 .57628 L .55876 .57924 L F
.713 .834 .39 r
.55876 .57924 m .55779 .58091 L .55949 .57741 L F
.796 .999 .823 r
.59078 .56502 m .58991 .56501 L .5876 .56723 L F
.788 .465 .441 r
.48669 .7849 m .48859 .7854 L .48857 .78734 L F
.442 0 0 r
.48859 .7854 m .49066 .7864 L .48857 .78734 L F
.573 .178 .256 r
.53261 .78983 m .53383 .78774 L .5304 .78842 L F
.717 .341 .337 r
.53261 .78983 m .5359 .79002 L .53383 .78774 L F
.835 .566 .533 r
.51901 .79791 m .51771 .79885 L .51763 .79601 L F
.752 .517 .576 r
.56839 .63574 m .56564 .63803 L .56592 .63545 L F
.56839 .63574 m .5685 .63823 L .56564 .63803 L F
.629 .501 .687 r
.5703 .63235 m .5707 .63547 L .56839 .63574 L F
.639 .446 .606 r
.5707 .63547 m .5685 .63823 L .56839 .63574 L F
.711 .404 .456 r
.6405 .4969 m .6398 .49955 L .63777 .49878 L F
.577 .272 .415 r
.64283 .4992 m .6405 .4969 L .64278 .49615 L F
.64283 .4992 m .6398 .49955 L .6405 .4969 L F
.693 .681 .835 r
.70798 .51099 m .71146 .51199 L .71019 .50908 L F
.595 .629 .855 r
.71019 .50908 m .71146 .51199 L .7137 .51141 L F
0 0 .411 r
.61446 .51151 m .61576 .50784 L .61385 .50855 L F
.61446 .51151 m .61588 .5101 L .61576 .50784 L F
0 0 .013 r
.61446 .51151 m .61543 .51212 L .61588 .5101 L F
.61446 .51151 m .61275 .5139 L .61543 .51212 L F
.82 .849 .87 r
.64315 .51316 m .64694 .51225 L .6455 .51035 L F
.705 .744 .882 r
.6455 .51035 m .64694 .51225 L .64882 .51073 L F
.265 0 .13 r
.53087 .77602 m .53163 .7753 L .53145 .77556 L F
.378 .814 .959 r
.53123 .77588 m .53145 .77556 L .53135 .77481 L F
0 0 .457 r
.53163 .77783 m .53087 .77602 L .53145 .77556 L F
.378 .814 .959 r
.53105 .77735 m .53145 .77556 L .53123 .77588 L F
.265 0 .13 r
.53163 .7753 m .53344 .77357 L .53145 .77556 L F
0 0 0 r
.53449 .77254 m .53145 .77556 L .53344 .77357 L F
.395 .712 .986 r
.53344 .77357 m .53563 .77366 L .53449 .77254 L F
.446 0 0 r
.50911 .70258 m .50821 .70286 L .50594 .70231 L F
.048 0 0 r
.51168 .70231 m .50821 .70286 L .50911 .70258 L F
.744 .905 .949 r
.48662 .62737 m .48398 .62904 L .48264 .62829 L F
.135 .606 .922 r
.66614 .50812 m .66524 .50732 L .66318 .50696 L F
.829 .969 .892 r
.66793 .5048 m .66614 .50812 L .66891 .50614 L F
.66793 .5048 m .66524 .50732 L .66614 .50812 L F
.589 .605 .836 r
.72669 .47598 m .72447 .47835 L .72346 .47534 L F
.512 .484 .763 r
.72669 .47598 m .72739 .47953 L .72447 .47835 L F
.903 .975 .803 r
.59473 .71331 m .5938 .716 L .5945 .71478 L F
0 0 0 r
.4216 .71099 m .42539 .70957 L .42383 .71066 L F
.188 0 0 r
.42539 .70957 m .42602 .71037 L .42383 .71066 L F
.42539 .70957 m .42761 .70923 L .42602 .71037 L F
.867 .883 .846 r
.50046 .79643 m .50247 .79422 L .50096 .79358 L F
.139 .636 .91 r
.50096 .79358 m .50247 .79422 L .50505 .79444 L F
.421 .828 .976 r
.68922 .47679 m .68795 .47625 L .68553 .4767 L F
.452 .824 .992 r
.69147 .47653 m .68795 .47625 L .68922 .47679 L F
.722 .572 .686 r
.54134 .7544 m .5414 .75674 L .54356 .75401 L F
0 0 .393 r
.54356 .75401 m .54453 .75613 L .54603 .75616 L F
0 0 0 r
.52571 .79568 m .52901 .79341 L .52849 .79591 L F
.262 0 0 r
.52901 .79341 m .52984 .79452 L .52849 .79591 L F
0 0 .426 r
.53074 .7901 m .53079 .79219 L .53154 .79157 L F
.262 0 0 r
.53031 .79313 m .53119 .79294 L .53077 .79354 L F
.53031 .79313 m .53077 .79354 L .5307 .79363 L F
.764 .661 .749 r
.52685 .79258 m .53082 .79358 L .53074 .7901 L F
.53082 .79358 m .53082 .79358 L .53074 .7901 L F
.284 .727 .963 r
.53 .79085 m .53201 .79119 L .53154 .79157 L F
.768 .68 .766 r
.53261 .78983 m .53372 .7928 L .5359 .79002 L F
.574 .574 .816 r
.53576 .79201 m .53372 .7928 L .53261 .78983 L F
.285 0 .038 r
.53333 .79141 m .53261 .78983 L .53154 .79157 L F
.284 .727 .963 r
.53201 .79119 m .53333 .79141 L .53154 .79157 L F
0 0 .426 r
.53079 .79219 m .53082 .79358 L .53154 .79157 L F
.53082 .79358 m .53082 .79359 L .53082 .79358 L F
.53082 .79358 m .53082 .79358 L .53154 .79157 L F
.262 0 0 r
.52901 .79341 m .53031 .79313 L .5307 .79363 L F
.53119 .79294 m .53141 .79289 L .53092 .7934 L F
.53119 .79294 m .53092 .7934 L .5307 .79363 L F
.52953 .7941 m .5307 .79363 L .52984 .79452 L F
.52901 .79341 m .5307 .79363 L .52953 .7941 L F
.928 .961 .653 r
.52766 .79335 m .53081 .79359 L .52685 .79258 L F
.52994 .79423 m .53081 .79359 L .52766 .79335 L F
.53081 .79359 m .53082 .79359 L .53082 .79358 L F
.53081 .79359 m .53082 .79358 L .52685 .79258 L F
.764 .661 .749 r
.53082 .79358 m .53082 .79359 L .53082 .79358 L F
.173 0 0 r
.53141 .79289 m .53135 .79299 L .52984 .79452 L F
.928 .961 .653 r
.53061 .79374 m .52984 .79452 L .53082 .79359 L F
.173 0 0 r
.53135 .79299 m .53104 .79348 L .52984 .79452 L F
.928 .961 .653 r
.52917 .79478 m .52984 .79452 L .53061 .79374 L F
.651 .627 .813 r
.52984 .79452 m .53154 .79157 L .53082 .79359 L F
.53 .79425 m .53104 .79348 L .53154 .79157 L F
.52984 .79452 m .5301 .79429 L .53 .79425 L F
.5301 .79429 m .53104 .79348 L .53 .79425 L F
.928 .961 .653 r
.52917 .79478 m .52994 .79423 L .52766 .79335 L F
.748 .627 .726 r
.69257 .50661 m .69278 .50843 L .68921 .5079 L F
.649 .556 .736 r
.69529 .50588 m .69278 .50843 L .69257 .50661 L F
.421 .867 .829 r
.5019 .793 m .50096 .79358 L .50359 .7925 L F
.867 .883 .846 r
.50018 .79407 m .50096 .79358 L .50004 .79294 L F
.971 .853 .452 r
.50153 .79014 m .50096 .79358 L .50048 .79235 L F
.953 .952 .703 r
.50048 .79235 m .50096 .79358 L .49943 .79373 L F
.421 .867 .829 r
.49943 .79373 m .50096 .79358 L .5019 .793 L F
.867 .883 .846 r
.50046 .79643 m .50096 .79358 L .50018 .79407 L F
.719 .988 .837 r
.29224 .64782 m .29022 .64927 L .2898 .64885 L F
0 .015 .581 r
.29225 .64751 m .29291 .64826 L .29224 .64782 L F
.21 0 .066 r
.29291 .64826 m .29022 .64927 L .29224 .64782 L F
.615 .601 .813 r
.29802 .62649 m .29581 .62716 L .29441 .62391 L F
.528 .825 .999 r
.35604 .58939 m .35544 .59074 L .35394 .58976 L F
.35604 .58939 m .35753 .59023 L .35544 .59074 L F
.35 .453 .825 r
.66995 .51182 m .67086 .51466 L .6722 .51305 L F
.532 .727 .964 r
.67086 .51466 m .67303 .51433 L .6722 .51305 L F
.503 .521 .808 r
.67086 .51466 m .67409 .51632 L .67303 .51433 L F
0 0 .349 r
.50213 .76568 m .50317 .76665 L .50407 .76572 L F
.50213 .76568 m .50231 .76894 L .50317 .76665 L F
.653 .297 .356 r
.48611 .79272 m .48754 .79067 L .48414 .79087 L F
.868 .583 .504 r
.48611 .79272 m .48768 .79286 L .48754 .79067 L F
.711 .464 .549 r
.49569 .80716 m .49606 .80502 L .49272 .80469 L F
.715 .406 .452 r
.4991 .80734 m .49606 .80502 L .49569 .80716 L F
.691 .544 .682 r
.57359 .62269 m .57068 .62147 L .5729 .6216 L F
.588 .424 .626 r
.57589 .61827 m .57583 .62151 L .5729 .6216 L F
.546 .364 .586 r
.57583 .62151 m .57359 .62269 L .5729 .6216 L F
0 .086 .562 r
.3811 .69479 m .38452 .69769 L .38304 .69699 L F
.3811 .69479 m .38304 .69699 L .38352 .69505 L F
.481 .185 .386 r
.625 .4943 m .62711 .49578 L .62712 .49339 L F
.625 .4943 m .62467 .4965 L .62711 .49578 L F
.573 .362 .556 r
.5809 .61308 m .58076 .61505 L .57885 .61509 L F
.552 .339 .544 r
.58328 .61258 m .58076 .61505 L .5809 .61308 L F
.8 .746 .803 r
.69586 .49845 m .69425 .49833 L .69679 .49678 L F
.278 0 0 r
.69425 .49833 m .69645 .49874 L .69586 .49845 L F
0 0 .234 r
.69679 .49678 m .69645 .49874 L .69586 .49845 L F
.278 0 0 r
.69586 .49845 m .69645 .49874 L .69425 .49833 L F
.69586 .49845 m .69645 .49874 L .69425 .49833 L F
.222 0 0 r
.43828 .64989 m .44044 .64966 L .44164 .64893 L F
.223 0 0 r
.44044 .64966 m .44387 .64896 L .44164 .64893 L F
.822 1 .805 r
.55547 .58383 m .55441 .58523 L .55507 .5834 L F
.787 .919 .537 r
.55441 .58523 m .55333 .58648 L .55507 .5834 L F
.754 .463 .491 r
.74387 .51387 m .74134 .51172 L .74419 .51352 L F
.168 0 0 r
.53312 .80609 m .53718 .8041 L .53684 .80476 L F
.218 0 .072 r
.53718 .8041 m .53841 .80131 L .53774 .80324 L F
0 0 0 r
.53684 .80476 m .53718 .8041 L .53774 .80324 L F
.758 .357 0 r
.58183 .59313 m .58291 .59544 L .58331 .59588 L F
.952 .624 .364 r
.58244 .59743 m .58331 .59588 L .58291 .59544 L F
.58244 .59743 m .58359 .59792 L .58331 .59588 L F
.438 .554 .875 r
.49877 .77672 m .5013 .77681 L .49984 .77537 L F
.316 .629 .961 r
.49877 .77672 m .50304 .77829 L .5013 .77681 L F
.203 0 .023 r
.51859 .69199 m .51955 .69315 L .52076 .69144 L F
.51859 .69199 m .51746 .69393 L .51955 .69315 L F
.966 .847 .673 r
.59104 .71911 m .59172 .71735 L .59055 .71658 L F
.379 .841 .885 r
.5938 .716 m .59055 .71658 L .59172 .71735 L F
.998 .801 .51 r
.55988 .57536 m .56085 .57628 L .55949 .57741 L F
.549 .344 .555 r
.35369 .61007 m .356 .6097 L .35605 .60736 L F
.555 .43 .665 r
.35605 .60736 m .3579 .60406 L .35548 .60484 L F
.35605 .60736 m .35834 .60699 L .3579 .60406 L F
.454 .231 .485 r
.356 .6097 m .35834 .60699 L .35605 .60736 L F
.988 .775 .529 r
.56616 .75834 m .5675 .75663 L .56656 .75595 L F
.56616 .75834 m .56726 .75945 L .5675 .75663 L F
.254 0 0 r
.28544 .58604 m .28764 .58589 L .28946 .58481 L F
.325 0 0 r
.28764 .58589 m .29158 .58462 L .28946 .58481 L F
.367 .372 .732 r
.71688 .49733 m .71938 .49903 L .71914 .49597 L F
.029 0 .304 r
.60665 .58211 m .6063 .58422 L .60772 .58107 L F
.734 .439 .48 r
.68598 .50302 m .68252 .50471 L .68485 .50181 L F
.68598 .50302 m .68618 .50518 L .68252 .50471 L F
.507 .768 .99 r
.68485 .50181 m .68788 .50251 L .68598 .50302 L F
.411 .204 .486 r
.68788 .50251 m .68618 .50518 L .68598 .50302 L F
.786 .512 .523 r
.48602 .79507 m .48768 .79286 L .48611 .79272 L F
.48601 .79526 m .48614 .79508 L .48602 .79507 L F
.48614 .79508 m .48768 .79286 L .48602 .79507 L F
.254 .753 .897 r
.48392 .79524 m .48595 .79549 L .48823 .79521 L F
.48743 .79516 m .48823 .79521 L .48894 .79512 L F
.48392 .79524 m .48823 .79521 L .48743 .79516 L F
.615 .651 .862 r
.70054 .47782 m .70131 .48108 L .70345 .4789 L F
.647 .618 .806 r
.56524 .71963 m .56639 .72286 L .56879 .72237 L F
.443 .175 .411 r
.60085 .53104 m .6031 .53044 L .60333 .5286 L F
.234 .006 .349 r
.60333 .5286 m .6048 .52946 L .60553 .52765 L F
.60333 .5286 m .6031 .53044 L .6048 .52946 L F
.074 0 .048 r
.57675 .59374 m .57551 .59565 L .57825 .59298 L F
.171 .527 .921 r
.27536 .64098 m .27824 .64269 L .27768 .64157 L F
.752 .955 .94 r
.27768 .64157 m .27824 .64269 L .28101 .64098 L F
.118 0 0 r
.48647 .6949 m .48872 .69463 L .49059 .69402 L F
.592 .113 .085 r
.49059 .69402 m .48872 .69463 L .49169 .6947 L F
.596 .289 .418 r
.59937 .60438 m .59928 .60658 L .59606 .60666 L F
.556 .285 .461 r
.60175 .60401 m .59928 .60658 L .59937 .60438 L F
0 0 0 r
.4425 .6645 m .4407 .6656 L .43958 .66614 L F
.44272 .66484 m .4425 .6645 L .4441 .66307 L F
.44272 .66484 m .4407 .6656 L .4425 .6645 L F
.021 0 0 r
.6379 .48556 m .63708 .48682 L .63938 .4852 L F
.6379 .48556 m .63489 .48798 L .63708 .48682 L F
.083 0 0 r
.47704 .69178 m .47873 .69177 L .4806 .69164 L F
.705 .198 .027 r
.48106 .69336 m .4806 .69164 L .47873 .69177 L F
.48106 .69336 m .48288 .69364 L .4806 .69164 L F
.479 .211 .428 r
.39769 .66619 m .4003 .66359 L .39792 .66372 L F
.866 .829 .809 r
.4935 .80976 m .49359 .80705 L .4922 .80959 L F
.49359 .80705 m .4936 .80662 L .49331 .80724 L F
.755 .285 .128 r
.49265 .80706 m .49045 .80437 L .48868 .80429 L F
.49292 .80717 m .49045 .80437 L .49265 .80706 L F
.49314 .80735 m .49045 .80437 L .49309 .80736 L F
.716 .317 .293 r
.49302 .80721 m .49272 .80469 L .49045 .80437 L F
.549 .486 .738 r
.48997 .80963 m .49085 .80681 L .4887 .80647 L F
.48997 .80963 m .4922 .80959 L .49152 .80736 L F
.755 .285 .128 r
.49206 .80722 m .49085 .80681 L .49109 .807 L F
.49174 .80694 m .48868 .80429 L .4887 .80647 L F
.49206 .80722 m .49174 .80694 L .49085 .80681 L F
.49265 .80706 m .48868 .80429 L .49206 .80722 L F
.49206 .80722 m .49109 .807 L .49111 .80599 L F
.549 .486 .738 r
.49085 .80681 m .49109 .807 L .49111 .80599 L F
.48997 .80963 m .49152 .80736 L .49085 .80681 L F
.755 .285 .128 r
.49109 .807 m .49085 .80681 L .4887 .80647 L F
.549 .486 .738 r
.49085 .80681 m .49111 .80599 L .4887 .80647 L F
.755 .285 .128 r
.49109 .807 m .4887 .80647 L .49111 .80599 L F
.549 .486 .738 r
.49109 .807 m .49152 .80736 L .49111 .80599 L F
.779 .62 .684 r
.49152 .80736 m .49265 .80706 L .49125 .80648 L F
.49252 .80782 m .49327 .80731 L .49265 .80706 L F
.755 .285 .128 r
.49327 .80749 m .49265 .80706 L .49206 .80722 L F
.49327 .80749 m .49206 .80722 L .49111 .80599 L F
.779 .62 .684 r
.4922 .80959 m .49284 .80823 L .49252 .80782 L F
.49284 .80823 m .49327 .80731 L .49252 .80782 L F
.4922 .80959 m .49265 .80706 L .49152 .80736 L F
.716 .317 .293 r
.49314 .80735 m .49312 .80722 L .49302 .80721 L F
.49312 .80722 m .49272 .80469 L .49302 .80721 L F
.779 .62 .684 r
.49327 .80731 m .49331 .80724 L .49302 .80721 L F
.716 .317 .293 r
.49323 .80729 m .49272 .80469 L .49314 .80735 L F
.769 .275 .047 r
.4936 .80662 m .49272 .80469 L .49322 .80723 L F
.779 .62 .684 r
.49331 .80724 m .4936 .80662 L .49322 .80723 L F
.769 .275 .047 r
.4936 .80662 m .49322 .80723 L .49327 .80749 L F
.779 .62 .684 r
.49322 .80723 m .4936 .80662 L .49302 .80721 L F
.49302 .80721 m .4936 .80662 L .49125 .80648 L F
.49125 .80648 m .4936 .80662 L .49111 .80599 L F
.755 .285 .128 r
.49309 .80736 m .49292 .80717 L .49265 .80706 L F
.49327 .80749 m .49314 .80735 L .49309 .80736 L F
.866 .829 .809 r
.49359 .80705 m .49331 .80724 L .49327 .80731 L F
.49347 .80726 m .49327 .80731 L .4922 .80959 L F
.49359 .80705 m .49327 .80731 L .49347 .80726 L F
.716 .317 .293 r
.49327 .80749 m .49323 .80729 L .49314 .80735 L F
.769 .275 .047 r
.4936 .80662 m .49569 .80716 L .49272 .80469 L F
.312 0 0 r
.45867 .70102 m .45722 .70226 L .45497 .70241 L F
.398 0 0 r
.46101 .7016 m .45722 .70226 L .45867 .70102 L F
.374 .625 .95 r
.37508 .5937 m .37424 .59507 L .37244 .59333 L F
.37508 .5937 m .37614 .59519 L .37424 .59507 L F
0 0 .322 r
.74771 .49589 m .74818 .4987 L .7479 .50031 L F
.271 .305 .714 r
.74818 .4987 m .74766 .50242 L .7479 .50031 L F
.65 .412 .545 r
.61705 .53675 m .61715 .53918 L .61357 .53861 L F
.771 .603 .67 r
.62126 .53684 m .61715 .53918 L .61705 .53675 L F
.971 .927 .622 r
.63309 .55861 m .63493 .55564 L .634 .55537 L F
.63309 .55861 m .63366 .55934 L .63493 .55564 L F
.325 0 0 r
.44787 .69647 m .45016 .69624 L .45158 .69477 L F
.511 .084 .166 r
.45016 .69624 m .45382 .69449 L .45158 .69477 L F
.192 .695 .908 r
.33876 .58832 m .34117 .588 L .34143 .58855 L F
.212 0 0 r
.34117 .588 m .34459 .58871 L .34143 .58855 L F
.06 .611 .829 r
.34143 .58855 m .34459 .58871 L .34621 .58907 L F
.296 0 .001 r
.51729 .70018 m .51616 .70181 L .51391 .70224 L F
.111 0 0 r
.51813 .70104 m .51729 .70018 L .51955 .69931 L F
.51813 .70104 m .51616 .70181 L .51729 .70018 L F
.888 .862 .809 r
.61889 .55684 m .61571 .5584 L .61759 .55581 L F
.61889 .55684 m .61695 .55958 L .61571 .5584 L F
.751 .851 .925 r
.67943 .53033 m .68054 .53142 L .68294 .53033 L F
.763 .707 .8 r
.67793 .47999 m .67528 .4828 L .67871 .48324 L F
.476 .193 .404 r
.47022 .64804 m .47259 .6485 L .46959 .64859 L F
.771 .603 .67 r
.62126 .53684 m .62113 .53991 L .61715 .53918 L F
.691 .534 .669 r
.6229 .53683 m .62113 .53991 L .62126 .53684 L F
.376 .734 .99 r
.32554 .58642 m .32535 .58747 L .32409 .58619 L F
.32554 .58642 m .32724 .58751 L .32535 .58747 L F
.25 0 0 r
.45062 .70265 m .44916 .70399 L .44691 .70432 L F
.36 0 0 r
.45273 .70268 m .44916 .70399 L .45062 .70265 L F
.583 .889 .99 r
.57778 .72485 m .58103 .7247 L .5803 .72241 L F
.782 .774 .846 r
.5803 .72241 m .58103 .7247 L .58412 .72245 L F
.468 .355 .642 r
.42174 .6856 m .41972 .68373 L .42172 .68322 L F
.42174 .6856 m .41996 .68629 L .41972 .68373 L F
.278 .735 .954 r
.33704 .58797 m .33876 .58832 L .33714 .58807 L F
.33704 .58797 m .33766 .58729 L .33876 .58832 L F
.363 0 0 r
.33766 .58729 m .34117 .588 L .33876 .58832 L F
.158 .029 .443 r
.6547 .49898 m .65405 .4971 L .65484 .49668 L F
0 0 0 r
.33143 .62946 m .33255 .62927 L .33336 .62862 L F
.33143 .62946 m .33037 .62983 L .33255 .62927 L F
.077 0 0 r
.47745 .81582 m .48095 .81557 L .47965 .81539 L F
.354 .818 .919 r
.47965 .81539 m .48095 .81557 L .48314 .81509 L F
.285 0 0 r
.47634 .64675 m .47528 .6483 L .47259 .6485 L F
.521 .081 .143 r
.47853 .64655 m .47528 .6483 L .47634 .64675 L F
.696 .475 .584 r
.59401 .59591 m .59692 .59555 L .59689 .5932 L F
.47 .224 .459 r
.59881 .59466 m .59689 .5932 L .59692 .59555 L F
.59881 .59466 m .59915 .59263 L .59689 .5932 L F
.694 .55 .686 r
.51407 .7764 m .51659 .77693 L .51506 .77569 L F
.51407 .7764 m .51433 .77921 L .51659 .77693 L F
.804 .704 .755 r
.70224 .51338 m .70544 .51378 L .70446 .51058 L F
.795 .73 .792 r
.70363 .51477 m .70544 .51378 L .70224 .51338 L F
.746 .673 .78 r
.70446 .51058 m .70544 .51378 L .70798 .51099 L F
.834 .882 .877 r
.53472 .60452 m .53083 .60616 L .53325 .60334 L F
.788 .815 .873 r
.53746 .60218 m .53472 .60452 L .53325 .60334 L F
.369 .721 .988 r
.38781 .59843 m .38638 .59916 L .38532 .59817 L F
.38781 .59843 m .38846 .59902 L .38638 .59916 L F
.594 .559 .785 r
.38813 .60101 m .38638 .59916 L .38846 .59902 L F
.207 .336 .776 r
.27018 .64142 m .27162 .64231 L .27064 .63908 L F
.51 .25 .456 r
.27018 .64142 m .26939 .64334 L .27162 .64231 L F
.268 .401 .812 r
.26846 .63811 m .27018 .64142 L .27064 .63908 L F
.21 0 0 r
.30651 .64961 m .30703 .65017 L .30497 .65012 L F
.994 .793 .529 r
.48778 .64408 m .48669 .64614 L .48742 .64569 L F
.27 0 .146 r
.48881 .64525 m .48778 .64408 L .49022 .64379 L F
.48881 .64525 m .48669 .64614 L .48778 .64408 L F
.964 .795 .359 r
.55275 .7641 m .55252 .76792 L .55287 .76512 L F
.575 .335 .516 r
.58076 .61505 m .57799 .61787 L .57885 .61509 L F
.494 .092 .207 r
.33993 .64121 m .33866 .64332 L .33625 .64329 L F
.171 0 .03 r
.34061 .64248 m .33993 .64121 L .34203 .64065 L F
.34061 .64248 m .33866 .64332 L .33993 .64121 L F
.894 .472 .152 r
.55783 .74314 m .55861 .74483 L .55987 .74545 L F
.893 .503 .28 r
.55896 .74704 m .55987 .74545 L .55861 .74483 L F
.55896 .74704 m .5612 .74813 L .55987 .74545 L F
.837 .795 .811 r
.67604 .52304 m .67227 .52472 L .67468 .52187 L F
.691 .544 .682 r
.57359 .62269 m .57114 .62412 L .57068 .62147 L F
.854 .741 .738 r
.7148 .48905 m .71456 .49077 L .7147 .49133 L F
.115 .335 .803 r
.53634 .62385 m .53717 .62292 L .53477 .62107 L F
0 .049 .61 r
.53634 .62385 m .53786 .62511 L .53717 .62292 L F
.853 .466 .312 r
.53975 .62697 m .53813 .62695 L .53634 .62385 L F
0 .049 .61 r
.53634 .62385 m .53813 .62695 L .53786 .62511 L F
.561 .035 0 r
.53975 .62697 m .54068 .62809 L .53813 .62695 L F
.772 .264 0 r
.54187 .62905 m .54138 .62975 L .54068 .62809 L F
0 0 .388 r
.54138 .62975 m .54117 .62869 L .54068 .62809 L F
.561 .035 0 r
.53975 .62697 m .54187 .62905 L .54068 .62809 L F
0 0 .388 r
.54117 .62869 m .54083 .62696 L .54068 .62809 L F
.561 .035 0 r
.53975 .62697 m .53975 .62697 L .54068 .62809 L F
.473 .347 .628 r
.38813 .60101 m .38938 .60366 L .38766 .60405 L F
.396 .449 .798 r
.38846 .59902 m .39082 .60048 L .38813 .60101 L F
.462 .342 .63 r
.39178 .6028 m .38813 .60101 L .39082 .60048 L F
.39178 .6028 m .38938 .60366 L .38813 .60101 L F
.5 .363 .626 r
.39426 .67528 m .39649 .67486 L .39623 .67189 L F
.477 .38 .666 r
.39478 .67769 m .39649 .67486 L .39426 .67528 L F
.763 .877 .929 r
.4935 .80976 m .49189 .81375 L .49404 .81254 L F
.736 .697 .814 r
.49249 .81593 m .49404 .81254 L .49189 .81375 L F
.497 .876 .675 r
.47355 .63512 m .47469 .63412 L .47651 .63305 L F
.507 .907 .917 r
.47355 .63512 m .47266 .63498 L .47469 .63412 L F
.994 .865 .589 r
.61695 .55958 m .61555 .5608 L .61571 .5584 L F
.61695 .55958 m .61636 .5619 L .61555 .5608 L F
.445 .789 .998 r
.34739 .59958 m .34914 .60058 L .35105 .60023 L F
0 0 0 r
.59495 .55863 m .59261 .56138 L .5926 .56194 L F
.816 .343 .084 r
.72597 .49703 m .72617 .49714 L .72715 .49603 L F
.431 .218 .488 r
.73009 .49919 m .72769 .4967 L .72715 .49603 L F
.73009 .49919 m .72682 .50137 L .72769 .4967 L F
.816 .343 .084 r
.72617 .49714 m .73009 .49919 L .72715 .49603 L F
.971 .795 .369 r
.72757 .49555 m .72715 .49603 L .72769 .4967 L F
.72739 .49377 m .72715 .49603 L .72757 .49555 L F
.561 .576 .827 r
.51907 .65321 m .52187 .65324 L .52178 .65308 L F
.526 .204 .364 r
.35281 .61178 m .356 .6097 L .35369 .61007 L F
.713 .61 .74 r
.54475 .78672 m .5476 .78498 L .54433 .78468 L F
.518 .565 .843 r
.64343 .50886 m .645 .50831 L .6445 .50654 L F
.471 .405 .701 r
.64343 .50886 m .6455 .51035 L .645 .50831 L F
.612 .367 .521 r
.64343 .50886 m .64387 .51134 L .6455 .51035 L F
.699 .38 .434 r
.48171 .69734 m .47821 .69931 L .47829 .69778 L F
.48171 .69734 m .4805 .69997 L .47821 .69931 L F
.644 .319 .407 r
.48389 .69927 m .4805 .69997 L .48171 .69734 L F
.457 .193 .425 r
.34933 .61596 m .35084 .61749 L .35098 .61513 L F
.34933 .61596 m .34871 .61801 L .35084 .61749 L F
.734 .636 .75 r
.69162 .50491 m .69257 .50661 L .68962 .50579 L F
.748 .627 .726 r
.69257 .50661 m .68921 .5079 L .68962 .50579 L F
.658 .595 .773 r
.69409 .50227 m .69257 .50661 L .69162 .50491 L F
.69409 .50227 m .69529 .50588 L .69257 .50661 L F
.601 .425 .615 r
.24169 .64953 m .24439 .64802 L .24178 .64941 L F
.204 .727 .853 r
.38589 .6973 m .38662 .69746 L .38452 .69769 L F
.38452 .69769 m .38589 .6973 L .38304 .69699 L F
.38452 .69769 m .38662 .69746 L .38589 .6973 L F
.11 .627 .888 r
.33077 .58757 m .33446 .58824 L .33075 .58809 L F
.261 .768 .853 r
.53569 .75693 m .53507 .75678 L .53245 .75727 L F
.862 .991 .733 r
.53569 .75693 m .53507 .75678 L .53566 .75594 L F
.534 .318 .533 r
.53758 .75675 m .53777 .7592 L .53569 .75693 L F
.862 .991 .733 r
.53566 .75594 m .53507 .75678 L .53569 .75693 L F
.33 .045 .319 r
.46138 .65625 m .45965 .65418 L .4626 .65388 L F
.46138 .65625 m .45923 .65706 L .45965 .65418 L F
.343 .31 .677 r
.51073 .78563 m .50957 .78488 L .51166 .78711 L F
.423 .209 .483 r
.5604 .70883 m .56207 .70878 L .56311 .70736 L F
.436 .296 .591 r
.5604 .70883 m .56248 .71095 L .56207 .70878 L F
.36 .287 .638 r
.56092 .7113 m .56248 .71095 L .5604 .70883 L F
.279 .391 .798 r
.45207 .65834 m .45434 .65926 L .45225 .65835 L F
.828 .847 .862 r
.27162 .64231 m .27536 .64098 L .27385 .63998 L F
.27162 .64231 m .27229 .64332 L .27536 .64098 L F
.022 .476 .876 r
.27536 .64098 m .2756 .64033 L .27385 .63998 L F
.27536 .64098 m .27768 .64157 L .2756 .64033 L F
.049 .19 .691 r
.47371 .80902 m .47373 .81061 L .47607 .81302 L F
.465 .219 .455 r
.3468 .61866 m .34848 .6203 L .34871 .61801 L F
.3468 .61866 m .34636 .62081 L .34848 .6203 L F
.456 .174 .397 r
.60992 .59896 m .6096 .60092 L .60728 .60147 L F
.476 .192 .402 r
.61159 .60034 m .60992 .59896 L .61202 .59822 L F
.61159 .60034 m .6096 .60092 L .60992 .59896 L F
0 0 0 r
.50302 .81303 m .50617 .81005 L .50531 .81238 L F
.588 .602 .833 r
.50737 .80711 m .50617 .81005 L .50507 .80732 L F
.50737 .80711 m .50858 .81016 L .50617 .81005 L F
.578 .254 .385 r
.50617 .81005 m .50869 .81098 L .50531 .81238 L F
.50617 .81005 m .50858 .81016 L .50869 .81098 L F
.854 .917 .874 r
.54906 .59263 m .5456 .59417 L .54822 .59195 L F
.864 .97 .86 r
.54906 .59263 m .54822 .59195 L .55072 .5893 L F
.63 .96 .907 r
.46623 .63916 m .4672 .63794 L .46792 .63771 L F
.46623 .63916 m .46422 .63943 L .4672 .63794 L F
.295 0 .112 r
.47155 .65001 m .46959 .64859 L .47259 .6485 L F
.47155 .65001 m .46914 .65073 L .46959 .64859 L F
.215 0 .311 r
.60603 .52576 m .60553 .52765 L .60772 .52479 L F
0 0 .023 r
.50948 .79247 m .50863 .79371 L .50985 .79026 L F
.657 .971 .84 r
.50686 .79418 m .50863 .79371 L .50948 .79247 L F
.192 0 0 r
.29158 .58462 m .29395 .58472 L .29518 .58446 L F
.109 0 0 r
.29395 .58472 m .29733 .58425 L .29518 .58446 L F
.689 .392 .466 r
.54782 .79908 m .54431 .79895 L .54417 .79837 L F
.387 0 .035 r
.2774 .58866 m .27955 .58855 L .27812 .58768 L F
.376 0 .07 r
.27812 .58768 m .27955 .58855 L .2805 .58733 L F
.415 .769 .995 r
.33711 .60122 m .33588 .60033 L .33387 .60062 L F
.362 .79 .971 r
.33711 .60122 m .33761 .60045 L .33588 .60033 L F
.33711 .60122 m .33917 .60095 L .33761 .60045 L F
.31 0 0 r
.43094 .70785 m .43004 .70882 L .42761 .70923 L F
.253 0 0 r
.4331 .70744 m .43004 .70882 L .43094 .70785 L F
.789 .318 0 r
.50407 .76572 m .50511 .76758 L .50607 .76819 L F
.177 0 0 r
.50607 .76819 m .50629 .7688 L .50487 .76843 L F
0 .16 .69 r
.50629 .7688 m .50609 .76875 L .50511 .76758 L F
.6 .066 0 r
.50511 .76758 m .50632 .7689 L .50629 .7688 L F
.50511 .76758 m .50629 .7688 L .50607 .76819 L F
0 .16 .69 r
.50644 .76884 m .50629 .7688 L .50511 .76758 L F
.50543 .76627 m .50644 .76884 L .50511 .76758 L F
.50644 .76884 m .50668 .76945 L .50609 .76875 L F
.624 .077 0 r
.50668 .76945 m .50596 .76887 L .50632 .7689 L F
.177 0 0 r
.50629 .7688 m .50632 .7689 L .50487 .76843 L F
.624 .077 0 r
.50596 .76887 m .50317 .76665 L .50632 .7689 L F
.177 0 0 r
.50346 .76871 m .50596 .76887 L .50231 .76894 L F
.50596 .76887 m .50596 .7689 L .50231 .76894 L F
.50487 .76843 m .50632 .7689 L .50346 .76871 L F
.447 .542 .861 r
.50231 .76894 m .50596 .7689 L .50317 .76665 L F
.624 .077 0 r
.50596 .76887 m .50591 .76886 L .50317 .76665 L F
.177 0 0 r
.50596 .76887 m .50632 .7689 L .50596 .7689 L F
.447 .542 .861 r
.50596 .7689 m .50632 .7689 L .50317 .76665 L F
.624 .077 0 r
.50591 .76886 m .5054 .76875 L .50317 .76665 L F
.50668 .76945 m .50597 .76906 L .50596 .76887 L F
.50597 .76906 m .5054 .76875 L .50596 .76887 L F
.703 .696 .84 r
.71273 .50389 m .70908 .50264 L .71202 .50178 L F
.668 .685 .857 r
.71484 .50293 m .71273 .50389 L .71202 .50178 L F
.004 0 0 r
.54179 .77738 m .54287 .77664 L .54506 .7761 L F
0 .078 .599 r
.7599 .58724 m .761 .59014 L .76046 .59061 L F
.644 .236 .256 r
.7601 .59189 m .76333 .59252 L .76046 .59061 L F
0 0 0 r
.761 .59014 m .7601 .59189 L .76046 .59061 L F
.408 .531 .869 r
.47706 .78498 m .47769 .78558 L .47834 .78309 L F
.838 .961 .888 r
.47834 .78309 m .47769 .78558 L .48137 .78165 L F
.879 .513 .348 r
.59573 .70499 m .59667 .70373 L .59415 .70221 L F
.59573 .70499 m .59738 .70556 L .59667 .70373 L F
.612 .631 .845 r
.69147 .47653 m .69236 .47859 L .69466 .47779 L F
0 0 0 r
.54253 .74224 m .54348 .7422 L .54446 .74215 L F
.432 .429 .756 r
.54283 .73695 m .54446 .74215 L .54619 .73978 L F
.555 .428 .662 r
.54348 .7422 m .54619 .73978 L .54446 .74215 L F
.863 .498 .356 r
.38612 .70036 m .38816 .70074 L .38657 .70201 L F
.044 0 0 r
.38657 .70201 m .38816 .70074 L .39029 .70006 L F
.812 .904 .905 r
.70781 .46714 m .70535 .46921 L .70442 .4682 L F
.722 .568 .68 r
.56182 .63754 m .55971 .64045 L .56004 .63874 L F
.817 .352 0 r
.53629 .77573 m .53748 .77662 L .53771 .77815 L F
.369 .745 .989 r
.36181 .58978 m .36113 .59073 L .35965 .5902 L F
.36181 .58978 m .36325 .59065 L .36113 .59073 L F
.751 .851 .925 r
.67943 .53033 m .68294 .53033 L .68143 .52812 L F
.576 .681 .912 r
.68294 .53033 m .68413 .52733 L .68143 .52812 L F
.68294 .53033 m .68499 .52968 L .68413 .52733 L F
.309 0 0 r
.26844 .59189 m .2721 .59005 L .26999 .59046 L F
.735 .421 .448 r
.55305 .73973 m .55503 .74208 L .55518 .74019 L F
.694 .59 .735 r
.40427 .70673 m .40449 .70855 L .40661 .70577 L F
.627 .495 .683 r
.40449 .70855 m .4068 .7085 L .40661 .70577 L F
.555 .518 .769 r
.40449 .70855 m .40693 .70926 L .4068 .7085 L F
.736 .369 .357 r
.53813 .7705 m .54036 .7729 L .54162 .77081 L F
.605 .217 .281 r
.54162 .77081 m .54036 .7729 L .54395 .7722 L F
.688 .726 .879 r
.70908 .50264 m .70691 .50382 L .70558 .50201 L F
.393 .169 .451 r
.49316 .66948 m .49278 .67163 L .49505 .66878 L F
.49316 .66948 m .49278 .67163 L .49505 .66878 L F
.448 .321 .614 r
.61385 .50855 m .61576 .50784 L .61551 .50528 L F
.408 .531 .869 r
.47706 .78498 m .47834 .78309 L .47566 .78187 L F
.578 .365 .555 r
.48076 .8019 m .48319 .80443 L .48065 .80479 L F
.894 .808 .757 r
.69837 .52714 m .69969 .52801 L .69933 .52499 L F
.873 .819 .792 r
.69697 .5293 m .69969 .52801 L .69837 .52714 L F
.69697 .5293 m .69781 .53097 L .69969 .52801 L F
.356 0 .191 r
.30878 .60502 m .30767 .60647 L .30568 .60695 L F
0 0 0 r
.3103 .60393 m .30767 .60647 L .30878 .60502 L F
.465 .12 .295 r
.60989 .54495 m .60911 .54689 L .60677 .54739 L F
.574 .397 .604 r
.61232 .54223 m .61249 .54452 L .60989 .54495 L F
.62 .342 .474 r
.61249 .54452 m .60911 .54689 L .60989 .54495 L F
.592 .809 .983 r
.51506 .77569 m .51659 .77693 L .51855 .77615 L F
.762 .304 0 r
.55795 .64797 m .55827 .64926 L .55796 .64887 L F
.51 0 0 r
.55793 .64709 m .55795 .64797 L .5548 .6466 L F
0 .376 .778 r
.5548 .6466 m .55795 .64797 L .55642 .64696 L F
.762 .304 0 r
.55795 .64797 m .55796 .64887 L .55642 .64696 L F
.51 0 0 r
.55836 .64716 m .55795 .64797 L .55793 .64709 L F
.721 .19 0 r
.55836 .64716 m .56088 .64955 L .55795 .64797 L F
.711 .342 .348 r
.56212 .64872 m .56088 .64955 L .55836 .64716 L F
.215 0 .094 r
.34156 .62358 m .34355 .62315 L .34436 .62144 L F
.342 0 .153 r
.34436 .62144 m .34572 .62226 L .34636 .62081 L F
.34436 .62144 m .34355 .62315 L .34572 .62226 L F
.33 0 .129 r
.35885 .63096 m .35779 .62961 L .3598 .62913 L F
.35885 .63096 m .35669 .63148 L .35779 .62961 L F
0 .324 .728 r
.29022 .64927 m .29174 .65004 L .2898 .64885 L F
.584 .731 .945 r
.30066 .65002 m .30257 .64957 L .30162 .64808 L F
0 0 .186 r
.60996 .57587 m .60887 .57931 L .6101 .5777 L F
0 0 .181 r
.60772 .58107 m .6101 .5777 L .60887 .57931 L F
.586 .596 .829 r
.62625 .51609 m .62486 .51977 L .62791 .51704 L F
.538 .382 .618 r
.62791 .51704 m .62727 .51921 L .62486 .51977 L F
.586 .596 .829 r
.62625 .51609 m .62727 .51921 L .62486 .51977 L F
.483 .26 .499 r
.58905 .599 m .59142 .59827 L .5915 .59609 L F
.552 .28 .457 r
.59358 .59765 m .5915 .59609 L .59142 .59827 L F
.59358 .59765 m .59401 .59591 L .5915 .59609 L F
.865 .688 .661 r
.59698 .70785 m .59827 .71104 L .59846 .70879 L F
.929 .947 .782 r
.65858 .51508 m .6588 .51593 L .6618 .51149 L F
.001 0 0 r
.49073 .6445 m .49022 .64379 L .49269 .64369 L F
.49073 .6445 m .48881 .64525 L .49022 .64379 L F
.963 .873 .7 r
.66201 .48827 m .66237 .49166 L .66469 .48837 L F
.66201 .48827 m .6612 .49074 L .66237 .49166 L F
.764 .776 .863 r
.25188 .65399 m .25637 .65191 L .25244 .65057 L F
.824 .668 .69 r
.55258 .62133 m .54992 .62365 L .55003 .6212 L F
.8 .623 .662 r
.5534 .62409 m .54992 .62365 L .55258 .62133 L F
.874 .982 .836 r
.57265 .5903 m .56939 .59251 L .57082 .59341 L F
.57265 .5903 m .57196 .58969 L .56939 .59251 L F
.908 .976 .794 r
.57396 .58696 m .57265 .5903 L .57465 .58691 L F
.57396 .58696 m .57196 .58969 L .57265 .5903 L F
.689 .44 .541 r
.50153 .79014 m .50373 .79035 L .50418 .78804 L F
.577 .335 .512 r
.50418 .78804 m .50639 .79005 L .50757 .78695 L F
.50418 .78804 m .50373 .79035 L .50639 .79005 L F
.575 .574 .815 r
.28547 .64892 m .28709 .64579 L .28501 .64641 L F
.28547 .64892 m .28914 .64856 L .28709 .64579 L F
0 0 0 r
.4407 .6656 m .43815 .66755 L .43958 .66614 L F
.659 .477 .628 r
.50957 .79842 m .512 .79945 L .51198 .7962 L F
.673 .687 .855 r
.69458 .53002 m .69781 .53097 L .69697 .5293 L F
.943 .775 .643 r
.6569 .50562 m .65519 .50615 L .65504 .5048 L F
.6569 .50562 m .65644 .50709 L .65519 .50615 L F
.612 .535 .744 r
.40311 .70298 m .40611 .70216 L .40476 .70075 L F
.631 .571 .769 r
.40611 .70216 m .40661 .70577 L .40889 .70514 L F
.40611 .70216 m .40889 .70514 L .4078 .70417 L F
.489 .488 .782 r
.40505 .70043 m .4078 .70417 L .4064 .69895 L F
.40476 .70075 m .4055 .70159 L .40505 .70043 L F
.839 .494 .403 r
.40611 .70216 m .4078 .70417 L .40476 .70075 L F
.489 .488 .782 r
.4055 .70159 m .4078 .70417 L .40505 .70043 L F
.682 .556 .706 r
.40311 .70298 m .40661 .70577 L .40633 .70372 L F
.40576 .70226 m .40633 .70372 L .40611 .70216 L F
.40311 .70298 m .40633 .70372 L .40576 .70226 L F
.40311 .70298 m .40427 .70673 L .40661 .70577 L F
.486 .398 .682 r
.57172 .62957 m .57234 .63186 L .5703 .63235 L F
.447 .354 .657 r
.57234 .63186 m .5707 .63547 L .5703 .63235 L F
.987 .721 .424 r
.54678 .63501 m .54795 .63823 L .5468 .63731 L F
.714 .179 0 r
.55039 .64012 m .55004 .64036 L .54795 .63823 L F
.55147 .64096 m .55004 .64036 L .55039 .64012 L F
.923 .549 .134 r
.55004 .64036 m .54964 .64168 L .54949 .64075 L F
.55004 .64036 m .54949 .64075 L .54925 .63927 L F
0 .053 .584 r
.54795 .63823 m .54925 .63927 L .5468 .63731 L F
.54795 .63823 m .54953 .63984 L .54925 .63927 L F
.045 .449 .877 r
.54925 .63927 m .54537 .63676 L .5468 .63731 L F
.54925 .63927 m .54878 .63808 L .54537 .63676 L F
0 0 .514 r
.54964 .64168 m .54888 .63855 L .54925 .63927 L F
.54888 .63855 m .54885 .63843 L .54925 .63927 L F
0 .053 .584 r
.54953 .63984 m .55004 .64036 L .54925 .63927 L F
.399 .711 .986 r
.54603 .75616 m .5475 .75766 L .55084 .75739 L F
.885 .633 .552 r
.24841 .64604 m .24888 .64309 L .24628 .64376 L F
.568 .328 .511 r
.24628 .64376 m .24841 .64604 L .24888 .64309 L F
.612 .564 .776 r
.25608 .65003 m .25662 .65208 L .25941 .65003 L F
.771 .455 .453 r
.54769 .73691 m .54802 .73895 L .54948 .73672 L F
.404 .372 .709 r
.39728 .68896 m .39793 .69226 L .39955 .6907 L F
.665 .666 .841 r
.71729 .51377 m .72048 .51608 L .71964 .51328 L F
.721 .679 .809 r
.71964 .51328 m .72048 .51608 L .72306 .5136 L F
.187 .711 .692 r
.52347 .68945 m .52546 .68893 L .52655 .68865 L F
.496 0 0 r
.52546 .68893 m .52886 .68854 L .52655 .68865 L F
0 0 0 r
.47368 .80161 m .47239 .80502 L .47446 .80385 L F
0 .143 .676 r
.47239 .80502 m .47402 .80688 L .47446 .80385 L F
.47239 .80502 m .4737 .80733 L .47402 .80688 L F
.805 .676 .722 r
.5803 .72241 m .58412 .72245 L .58294 .71917 L F
.455 .473 .789 r
.58412 .72245 m .5849 .7189 L .58294 .71917 L F
.58412 .72245 m .586 .7223 L .5849 .7189 L F
.038 0 0 r
.63938 .4852 m .63925 .48602 L .64016 .48532 L F
.206 .302 .742 r
.64185 .48389 m .64016 .48532 L .63925 .48602 L F
.64185 .48389 m .64291 .48757 L .64016 .48532 L F
0 .1 .581 r
.64016 .48532 m .64291 .48757 L .64405 .48862 L F
.798 .343 .161 r
.54556 .6317 m .5432 .63006 L .54506 .62918 L F
.54556 .6317 m .54187 .62905 L .5432 .63006 L F
.435 .819 .989 r
.31205 .64899 m .31291 .64804 L .31089 .64897 L F
.31205 .64899 m .31426 .64832 L .31291 .64804 L F
.961 .943 .655 r
.63366 .55934 m .63213 .56057 L .63255 .56167 L F
.964 .939 .653 r
.63309 .55861 m .63213 .56057 L .63366 .55934 L F
.995 .849 .581 r
.63381 .54765 m .63326 .55079 L .63418 .55094 L F
.912 .543 .1 r
.63381 .55179 m .63418 .55094 L .63326 .55079 L F
.63381 .55179 m .63482 .55298 L .63418 .55094 L F
.695 .463 .568 r
.25771 .64879 m .26143 .64653 L .25899 .64615 L F
.999 .836 .526 r
.71493 .48612 m .7148 .48905 L .71375 .48731 L F
.936 .639 .175 r
.71375 .48731 m .7148 .48905 L .7147 .49133 L F
.533 .486 .749 r
.39728 .68896 m .39887 .68567 L .39656 .68659 L F
.39728 .68896 m .39934 .68852 L .39887 .68567 L F
.404 .372 .709 r
.39728 .68896 m .39955 .6907 L .39934 .68852 L F
.536 .335 .555 r
.59849 .53385 m .60085 .53334 L .60085 .53104 L F
.495 .301 .547 r
.60085 .53334 m .6031 .53044 L .60085 .53104 L F
0 .114 .666 r
.53161 .61791 m .53016 .61496 L .53207 .61591 L F
.824 .736 .767 r
.73649 .51914 m .73731 .52143 L .73396 .52182 L F
.847 .617 .59 r
.73731 .52143 m .73413 .52369 L .73396 .52182 L F
.73731 .52143 m .73736 .52471 L .73413 .52369 L F
.289 .635 .964 r
.73875 .52068 m .73731 .52143 L .73649 .51914 L F
.506 .353 .608 r
.57799 .61787 m .57583 .62151 L .57589 .61827 L F
.695 .272 .239 r
.48611 .79272 m .48414 .79087 L .48275 .79249 L F
.742 .915 .951 r
.69297 .49591 m .69043 .49717 L .6915 .49484 L F
.68 .55 .701 r
.69297 .49591 m .69425 .49833 L .69043 .49717 L F
.645 .155 .074 r
.69425 .49833 m .69292 .4988 L .69043 .49717 L F
0 .193 .634 r
.69043 .49717 m .69115 .49755 L .6915 .49484 L F
.69043 .49717 m .69292 .4988 L .69115 .49755 L F
.155 .638 .922 r
.29955 .58329 m .30306 .58423 L .30099 .58399 L F
.972 .93 .652 r
.72742 .49067 m .72926 .48827 L .72857 .48752 L F
.72742 .49067 m .72798 .49152 L .72926 .48827 L F
.729 .569 .674 r
.69679 .49678 m .69297 .49591 L .69452 .49505 L F
.69679 .49678 m .69425 .49833 L .69297 .49591 L F
.205 .546 .929 r
.69743 .49577 m .69679 .49678 L .69452 .49505 L F
0 .204 .725 r
.69743 .49577 m .6986 .49873 L .69679 .49678 L F
.654 .354 .452 r
.69679 .49678 m .6986 .49873 L .69645 .49874 L F
.505 .89 .96 r
.48556 .81569 m .48673 .81598 L .48766 .81498 L F
.48556 .81569 m .48673 .81598 L .48766 .81498 L F
.949 .927 .748 r
.38938 .60366 m .38613 .60894 L .38766 .60405 L F
.428 .763 .996 r
.41678 .71108 m .4181 .71022 L .4148 .70991 L F
.41678 .71108 m .41906 .7108 L .4181 .71022 L F
.586 .55 .781 r
.5399 .68603 m .53826 .68905 L .53773 .68645 L F
.5399 .68603 m .54057 .68869 L .53826 .68905 L F
0 .068 .583 r
.53773 .68645 m .5393 .68773 L .5399 .68603 L F
.53773 .68645 m .53826 .68905 L .5393 .68773 L F
.629 .531 .725 r
.51061 .76447 m .51274 .76538 L .51428 .7656 L F
.51061 .76447 m .51193 .76865 L .51274 .76538 L F
.772 .772 .853 r
.67955 .47964 m .68358 .47793 L .68258 .4776 L F
.566 .916 .964 r
.68488 .47667 m .68358 .47793 L .68553 .4767 L F
.68488 .47667 m .68258 .4776 L .68358 .47793 L F
.581 .01 0 r
.48167 .64759 m .48115 .64823 L .47853 .64655 L F
.48115 .64823 m .48106 .64823 L .47853 .64655 L F
.663 .957 .942 r
.48115 .64823 m .48124 .64823 L .48466 .64724 L F
0 0 0 r
.48466 .64724 m .48041 .64847 L .48112 .64827 L F
.48466 .64724 m .48112 .64827 L .48115 .64823 L F
.48466 .64724 m .48115 .64823 L .48167 .64759 L F
.599 .166 .192 r
.47853 .64655 m .48102 .6482 L .47726 .64821 L F
.48102 .6482 m .48095 .64823 L .47726 .64821 L F
.48106 .64823 m .48093 .64826 L .47726 .64821 L F
.374 0 0 r
.48086 .64826 m .47949 .64851 L .47726 .64821 L F
.663 .957 .942 r
.48113 .64823 m .48041 .64847 L .48124 .64823 L F
.374 0 0 r
.48093 .64826 m .48078 .64829 L .48086 .64826 L F
.663 .957 .942 r
.48092 .64822 m .48078 .64829 L .48113 .64823 L F
.48078 .64829 m .48041 .64847 L .48113 .64823 L F
.468 .887 .787 r
.48061 .64834 m .48053 .6484 L .48068 .64832 L F
.48053 .6484 m .48041 .64847 L .48071 .64832 L F
.521 .911 .929 r
.48112 .64827 m .48041 .64847 L .48061 .64834 L F
.374 0 0 r
.48112 .64827 m .48061 .64834 L .48078 .64829 L F
.48112 .64827 m .48078 .64829 L .48093 .64826 L F
.468 .887 .787 r
.48207 .6474 m .48061 .64834 L .48315 .64709 L F
.48207 .6474 m .48315 .64709 L .48566 .64585 L F
.2 .419 .85 r
.48121 .64595 m .48082 .64776 L .48207 .6474 L F
.599 .166 .192 r
.48102 .6482 m .48106 .64823 L .48095 .64823 L F
.48106 .64823 m .48112 .64827 L .48093 .64826 L F
.581 .01 0 r
.48115 .64823 m .48112 .64827 L .48106 .64823 L F
.521 .911 .929 r
.48112 .64827 m .48061 .64834 L .48207 .6474 L F
.374 0 0 r
.48112 .64827 m .48061 .64834 L .48061 .64834 L F
.48061 .64834 m .47949 .64851 L .48086 .64826 L F
.521 .911 .928 r
.48207 .6474 m .47949 .64851 L .48112 .64827 L F
.693 .916 .58 r
.47949 .64851 m .47781 .65098 L .47748 .64933 L F
.47949 .64851 m .47748 .64933 L .47726 .64821 L F
.302 0 0 r
.48207 .6474 m .48144 .64772 L .47949 .64851 L F
.693 .916 .58 r
.47949 .64851 m .47871 .64911 L .47781 .65098 L F
.302 0 0 r
.48144 .64772 m .47871 .64911 L .47949 .64851 L F
.48207 .6474 m .48059 .64877 L .47871 .64911 L F
.2 .419 .85 r
.48082 .64776 m .48059 .64877 L .48207 .6474 L F
.468 .887 .787 r
.48061 .64834 m .48068 .64832 L .48566 .64585 L F
.48053 .6484 m .48071 .64832 L .48566 .64585 L F
.663 .957 .942 r
.48428 .64734 m .48115 .64823 L .48466 .64724 L F
.48092 .64822 m .48106 .64823 L .48428 .64734 L F
.48106 .64823 m .48115 .64823 L .48428 .64734 L F
.48566 .64585 m .48092 .64822 L .48466 .64724 L F
.642 .597 .788 r
.68841 .51646 m .68607 .51723 L .68494 .51377 L F
.547 .229 .38 r
.59822 .53552 m .60063 .53534 L .59849 .53385 L F
.505 .253 .466 r
.59849 .53385 m .60063 .53534 L .60085 .53334 L F
.93 .712 .228 r
.63512 .4996 m .63481 .50158 L .63527 .50243 L F
.09 0 .151 r
.63633 .50063 m .63512 .4996 L .63777 .49878 L F
.63633 .50063 m .63481 .50158 L .63512 .4996 L F
.534 .513 .779 r
.39563 .68338 m .39656 .68659 L .39887 .68567 L F
.843 .79 .8 r
.48466 .64724 m .48561 .64951 L .48742 .64569 L F
.657 .42 .55 r
.48561 .64951 m .48812 .65231 L .48557 .65176 L F
0 .283 .707 r
.48432 .65002 m .48812 .65231 L .48561 .64951 L F
.67 .775 .929 r
.25167 .63153 m .2561 .63196 L .2542 .62962 L F
.679 .603 .764 r
.54271 .61454 m .54357 .61615 L .54053 .61507 L F
.54271 .61454 m .54357 .61615 L .54053 .61507 L F
.103 0 0 r
.54053 .61507 m .53955 .61548 L .54271 .61454 L F
.54271 .61454 m .53955 .61548 L .54053 .61507 L F
.942 .956 .657 r
.71493 .48612 m .71596 .48217 L .71623 .48452 L F
.71493 .48612 m .71462 .48527 L .71596 .48217 L F
.953 .927 .578 r
.71493 .48612 m .71375 .48731 L .71462 .48527 L F
.697 .867 .962 r
.71984 .49349 m .71975 .49498 L .72167 .49386 L F
.745 .841 .392 r
.71975 .49498 m .71914 .49597 L .71942 .49511 L F
0 0 .143 r
.57589 .58612 m .57576 .58585 L .57484 .58507 L F
.57598 .5862 m .57605 .58837 L .57587 .58675 L F
.57598 .5862 m .57587 .58675 L .57576 .58585 L F
.57598 .5862 m .57576 .58585 L .57589 .58612 L F
.542 .925 .818 r
.57576 .58585 m .57465 .58691 L .57567 .58565 L F
.009 .467 .87 r
.57453 .5853 m .57598 .5862 L .57484 .58507 L F
.57453 .5853 m .57618 .5859 L .57598 .5862 L F
.847 .766 .773 r
.57604 .58594 m .57598 .5862 L .57618 .5859 L F
.542 .925 .818 r
.57576 .58585 m .57396 .58696 L .57465 .58691 L F
.675 .455 .579 r
.57576 .58585 m .57422 .58842 L .57396 .58696 L F
.57576 .58585 m .57605 .58837 L .57422 .58842 L F
.847 .766 .773 r
.57358 .58678 m .57598 .5862 L .57604 .58594 L F
.542 .925 .818 r
.57576 .58585 m .57567 .58565 L .57661 .5845 L F
.72 .813 .923 r
.27162 .64231 m .26939 .64334 L .27229 .64332 L F
.77 .653 .733 r
.4935 .80976 m .49741 .81058 L .49569 .80716 L F
.786 .525 .542 r
.49578 .81303 m .49741 .81058 L .4935 .80976 L F
.513 .534 .815 r
.49569 .80716 m .49741 .81058 L .49911 .80951 L F
.017 0 .024 r
.49911 .80951 m .49741 .81058 L .49578 .81303 L F
.807 .647 .684 r
.5034 .776 m .50611 .77653 L .50692 .77348 L F
.47 .261 .514 r
.55434 .76233 m .55652 .76192 L .55698 .75952 L F
.339 0 0 r
.51633 .80542 m .51286 .80496 L .51527 .80652 L F
0 .29 .787 r
.75977 .59686 m .76215 .59917 L .76146 .59774 L F
.455 0 0 r
.75918 .5968 m .76146 .59774 L .75977 .59686 L F
.506 0 0 r
.75918 .5968 m .76146 .59774 L .76158 .59678 L F
.284 0 0 r
.76158 .59678 m .76375 .59709 L .76394 .59634 L F
.76158 .59678 m .76146 .59774 L .76375 .59709 L F
.729 .443 .494 r
.54835 .74166 m .55305 .73973 L .55111 .7396 L F
.54835 .74166 m .55125 .74222 L .55305 .73973 L F
.714 .423 .483 r
.55125 .74222 m .55503 .74208 L .55305 .73973 L F
.314 .767 .955 r
.25941 .65003 m .26306 .65041 L .26121 .64887 L F
.713 .748 .879 r
.26121 .64887 m .26306 .65041 L .26465 .64901 L F
.719 .75 .876 r
.74266 .48193 m .74312 .4836 L .74011 .48303 L F
.485 .595 .889 r
.74457 .4817 m .74312 .4836 L .74266 .48193 L F
.358 .415 .784 r
.74457 .4817 m .74573 .48524 L .74312 .4836 L F
.915 .973 .782 r
.63885 .5214 m .63746 .52509 L .63937 .52164 L F
.606 .42 .604 r
.57114 .62412 m .57103 .62625 L .5686 .62681 L F
.528 .305 .52 r
.57359 .62269 m .57103 .62625 L .57114 .62412 L F
.643 .237 .261 r
.52685 .79258 m .52886 .79067 L .52476 .79062 L F
.764 .661 .749 r
.52685 .79258 m .53074 .7901 L .52886 .79067 L F
.602 .382 .555 r
.58572 .61007 m .58568 .61232 L .58328 .61258 L F
.567 .386 .596 r
.58572 .61007 m .58808 .61194 L .58568 .61232 L F
.58572 .61007 m .58805 .60981 L .58808 .61194 L F
.914 .743 .657 r
.61993 .54812 m .61944 .55049 L .61832 .54718 L F
.477 .38 .666 r
.39478 .67769 m .39668 .67719 L .39649 .67486 L F
.509 .348 .598 r
.39478 .67769 m .39694 .6796 L .39668 .67719 L F
.39478 .67769 m .39483 .68011 L .39694 .6796 L F
.463 .353 .644 r
.25586 .60741 m .25774 .607 L .25758 .60381 L F
.489 .432 .72 r
.25644 .60968 m .25774 .607 L .25586 .60741 L F
.418 .205 .482 r
.30025 .61233 m .29817 .61519 L .29866 .61298 L F
.949 .927 .748 r
.38938 .60366 m .38966 .60445 L .38613 .60894 L F
.304 0 .24 r
.38613 .60894 m .38966 .60445 L .38866 .60826 L F
0 0 .474 r
.39034 .60527 m .38966 .60445 L .38938 .60366 L F
.153 0 .185 r
.38866 .60826 m .38966 .60445 L .39034 .60527 L F
.344 .714 .985 r
.67489 .51905 m .67533 .51564 L .67409 .51632 L F
.67489 .51905 m .67545 .51807 L .67533 .51564 L F
.67489 .51905 m .67694 .51899 L .67545 .51807 L F
.616 .228 .285 r
.46524 .69343 m .46755 .69379 L .46561 .69221 L F
.528 .268 .465 r
.46561 .69221 m .46755 .69379 L .4682 .6916 L F
.466 .32 .597 r
.75553 .59293 m .75761 .59263 L .75773 .58872 L F
.564 .078 .06 r
.58547 .59989 m .58779 .60034 L .58905 .599 L F
.517 .026 .029 r
.58779 .60034 m .59129 .60018 L .58905 .599 L F
.446 .178 .413 r
.58905 .599 m .59129 .60018 L .59142 .59827 L F
.538 .343 .565 r
.45225 .65835 m .4521 .66279 L .4502 .66279 L F
.458 .278 .549 r
.45434 .65926 m .4521 .66279 L .45225 .65835 L F
.528 .305 .52 r
.57359 .62269 m .57375 .626 L .57103 .62625 L F
.546 .364 .586 r
.57583 .62151 m .57624 .62215 L .57359 .62269 L F
.44 .203 .457 r
.57624 .62215 m .57375 .626 L .57359 .62269 L F
.475 0 0 r
.49664 .70007 m .49542 .70106 L .49305 .70017 L F
.842 .41 .204 r
.49561 .69689 m .49895 .69987 L .49664 .70007 L F
.576 .135 .166 r
.49895 .69987 m .49705 .70051 L .49664 .70007 L F
.49895 .69987 m .49765 .70156 L .49542 .70106 L F
.032 0 0 r
.5012 .69944 m .49765 .70156 L .49895 .69987 L F
.5012 .69944 m .50003 .70066 L .49765 .70156 L F
.842 .41 .204 r
.49561 .69689 m .49829 .70121 L .49895 .69987 L F
.189 .219 .662 r
.49854 .6977 m .49833 .70075 L .49577 .69713 L F
.49833 .70075 m .49797 .70068 L .49561 .69689 L F
.991 .778 .521 r
.49969 .69962 m .49896 .70069 L .50003 .70066 L F
.632 .618 .818 r
.49973 .69873 m .49829 .70121 L .49854 .6977 L F
0 0 0 r
.49895 .69987 m .50028 .69954 L .5012 .69944 L F
.991 .778 .521 r
.50058 .69947 m .50059 .69947 L .50043 .69931 L F
.632 .618 .818 r
.50052 .69942 m .49854 .6977 L .49909 .69782 L F
.50052 .69942 m .50005 .69988 L .49973 .69873 L F
0 0 0 r
.50057 .69947 m .50059 .69947 L .50059 .69947 L F
.50059 .69947 m .50059 .69947 L .50059 .69947 L F
.49895 .69987 m .49829 .70121 L .50059 .69947 L F
.632 .618 .818 r
.50005 .69988 m .49829 .70121 L .49973 .69873 L F
.991 .778 .521 r
.49909 .69782 m .49969 .69962 L .5005 .69928 L F
.50027 .69813 m .5005 .69928 L .50208 .69862 L F
.49909 .69782 m .5005 .69928 L .50027 .69813 L F
.49969 .69962 m .50058 .69947 L .50043 .69931 L F
.632 .618 .818 r
.50059 .69947 m .50054 .69951 L .50052 .69942 L F
.50054 .69951 m .50005 .69988 L .50052 .69942 L F
.50059 .69947 m .50052 .69942 L .49909 .69782 L F
.991 .778 .521 r
.50043 .69931 m .50059 .69947 L .50208 .69862 L F
.513 .9 .744 r
.5012 .69944 m .50059 .69947 L .50208 .69862 L F
.991 .778 .521 r
.50059 .69947 m .50135 .69934 L .50208 .69862 L F
.513 .9 .744 r
.50059 .69947 m .50059 .69947 L .50208 .69862 L F
.991 .778 .521 r
.49909 .69782 m .49901 .69971 L .49969 .69962 L F
.49901 .69971 m .49896 .70069 L .49969 .69962 L F
0 0 0 r
.50028 .69954 m .50057 .69947 L .501 .69945 L F
.50028 .69954 m .501 .69945 L .5012 .69944 L F
.50057 .69947 m .50059 .69947 L .5012 .69944 L F
.50208 .69862 m .50003 .70066 L .5012 .69944 L F
.991 .778 .521 r
.49969 .69962 m .50003 .70066 L .50135 .69934 L F
.245 0 0 r
.49854 .6977 m .49526 .69832 L .49908 .69782 L F
.49854 .6977 m .49908 .69782 L .49909 .69782 L F
.189 .219 .662 r
.49854 .6977 m .49577 .69713 L .49561 .69689 L F
.49833 .70075 m .49829 .70121 L .49797 .70068 L F
.576 .135 .166 r
.49705 .70051 m .49542 .70106 L .49628 .70036 L F
.49705 .70051 m .49628 .70036 L .49664 .70007 L F
0 0 .426 r
.57599 .58129 m .57685 .58404 L .57661 .5845 L F
.627 .807 .381 r
.57685 .58404 m .57576 .58585 L .57661 .5845 L F
.752 .955 .94 r
.27768 .64157 m .28101 .64098 L .27935 .64016 L F
0 .28 .703 r
.28101 .64098 m .2796 .64276 L .27935 .64016 L F
.28101 .64098 m .28325 .6422 L .28144 .64097 L F
.28101 .64098 m .28144 .64097 L .2796 .64276 L F
.156 0 .179 r
.4003 .66359 m .40204 .66288 L .40294 .66064 L F
.378 .057 .289 r
.40294 .66064 m .40432 .66205 L .4047 .66016 L F
.40294 .66064 m .40204 .66288 L .40432 .66205 L F
.625 .779 .955 r
.49232 .62628 m .48869 .62561 L .49079 .6247 L F
.555 .688 .928 r
.49301 .62343 m .49232 .62628 L .49079 .6247 L F
.49301 .62343 m .49454 .62585 L .49232 .62628 L F
.845 .784 .792 r
.70025 .5163 m .70363 .51477 L .70224 .51338 L F
0 0 0 r
.63299 .48904 m .63209 .49001 L .63489 .48798 L F
.451 .098 .275 r
.52782 .69446 m .5268 .69684 L .52449 .69719 L F
.415 .014 .167 r
.53029 .69455 m .5268 .69684 L .52782 .69446 L F
.038 0 0 r
.63938 .4852 m .63708 .48682 L .63925 .48602 L F
.81 .738 .785 r
.58824 .71943 m .586 .7223 L .58932 .7223 L F
.828 .746 .773 r
.58824 .71943 m .58932 .7223 L .59104 .71911 L F
.653 .525 .695 r
.61357 .53861 m .61476 .54207 L .61232 .54223 L F
.693 .524 .654 r
.61476 .54207 m .61249 .54452 L .61232 .54223 L F
.327 .657 .972 r
.66686 .50092 m .66497 .50164 L .66512 .49921 L F
.66686 .50092 m .66767 .50208 L .66497 .50164 L F
.726 .99 .844 r
.47805 .63168 m .47651 .63305 L .4773 .63162 L F
.729 .979 .752 r
.47651 .63305 m .47469 .63412 L .4773 .63162 L F
.999 .833 .535 r
.6335 .53567 m .63407 .53872 L .63434 .53662 L F
.988 .879 .627 r
.6345 .5321 m .6335 .53567 L .63434 .53662 L F
.574 .178 .254 r
.53261 .78983 m .5304 .78842 L .53074 .7901 L F
.596 .251 .355 r
.46264 .65257 m .46477 .65431 L .4626 .65388 L F
.123 .673 .768 r
.46837 .6521 m .46546 .65232 L .46483 .65239 L F
.154 0 0 r
.46828 .65213 m .46546 .65232 L .46837 .6521 L F
.299 .012 .299 r
.46735 .65194 m .46546 .65232 L .46596 .65228 L F
.46735 .65194 m .46596 .65228 L .46828 .65213 L F
.671 .97 .913 r
.46914 .65073 m .46735 .65194 L .46828 .65213 L F
0 0 0 r
.46914 .65073 m .46794 .6518 L .46735 .65194 L F
.46794 .6518 m .46645 .65313 L .46735 .65194 L F
.299 .012 .299 r
.46735 .65194 m .46717 .65211 L .46546 .65232 L F
.46717 .65211 m .46477 .65431 L .46546 .65232 L F
.123 .673 .768 r
.46483 .65239 m .46546 .65232 L .46264 .65257 L F
.565 .264 .417 r
.46546 .65232 m .46477 .65431 L .46264 .65257 L F
.65 .865 .981 r
.69356 .47134 m .6902 .47134 L .69243 .47035 L F
.752 .885 .939 r
.69356 .47134 m .69532 .46852 L .69587 .47048 L F
.69356 .47134 m .69243 .47035 L .69532 .46852 L F
.946 .859 .724 r
.5666 .76768 m .56768 .76556 L .56645 .76474 L F
.479 .827 .997 r
.32703 .58645 m .33077 .58757 L .32724 .58751 L F
0 .337 .707 r
.32718 .58569 m .33077 .58757 L .32703 .58645 L F
.32718 .58569 m .32966 .58692 L .33077 .58757 L F
.11 .627 .888 r
.33077 .58757 m .32966 .58692 L .33446 .58824 L F
.376 .492 .849 r
.51289 .63429 m .51162 .6362 L .51074 .63464 L F
.51289 .63429 m .51451 .63731 L .51162 .6362 L F
.61 .653 .868 r
.76583 .5919 m .76468 .59562 L .76333 .59252 L F
.76583 .5919 m .76766 .59564 L .76468 .59562 L F
.648 .392 .518 r
.59369 .60701 m .5905 .60973 L .59141 .607 L F
.307 .607 .952 r
.28325 .6422 m .2845 .6436 L .28499 .64239 L F
.46 .385 .686 r
.28501 .64641 m .28709 .64579 L .2845 .6436 L F
.468 .246 .493 r
.372 .6205 m .37004 .6188 L .37241 .61844 L F
.372 .6205 m .36984 .62099 L .37004 .6188 L F
.372 .062 .304 r
.35129 .63705 m .35013 .63475 L .35217 .63448 L F
.35129 .63705 m .34912 .63766 L .35013 .63475 L F
.568 .401 .616 r
.54992 .62365 m .54769 .62651 L .54713 .6242 L F
.026 0 0 r
.44836 .64683 m .45197 .64625 L .44972 .64574 L F
.965 .746 .558 r
.6561 .49997 m .65587 .50232 L .6547 .49898 L F
0 0 .417 r
.55045 .74528 m .55224 .74787 L .55148 .7467 L F
.55045 .74528 m .55148 .7467 L .54912 .74496 L F
.919 .909 .795 r
.55941 .77667 m .55756 .77973 L .55666 .7785 L F
.598 .816 .983 r
.55666 .7785 m .55756 .77973 L .56023 .77887 L F
.847 .616 .588 r
.56592 .63545 m .56379 .63688 L .56398 .63479 L F
.56592 .63545 m .56564 .63803 L .56379 .63688 L F
.289 .745 .955 r
.32966 .58692 m .33704 .58797 L .33446 .58824 L F
.369 .809 .956 r
.33446 .58824 m .33704 .58797 L .33714 .58807 L F
.696 .289 .272 r
.57825 .59298 m .5805 .59454 L .58183 .59313 L F
.837 .488 .393 r
.5805 .59454 m .58291 .59544 L .58183 .59313 L F
.285 .347 .751 r
.48669 .7849 m .48857 .78734 L .48748 .78398 L F
.622 .87 .989 r
.48748 .78398 m .48669 .7849 L .48509 .78466 L F
.762 .644 .731 r
.62113 .53991 m .61677 .54158 L .61715 .53918 L F
.62113 .53991 m .62016 .54187 L .61677 .54158 L F
.543 .676 .925 r
.52302 .64123 m .52252 .64382 L .52131 .64257 L F
.52302 .64123 m .52401 .64198 L .52252 .64382 L F
.713 .643 .778 r
.52401 .64198 m .52266 .64641 L .52252 .64382 L F
.492 .445 .732 r
.52501 .64565 m .52375 .64946 L .52228 .64944 L F
.52501 .64565 m .52698 .6488 L .52375 .64946 L F
.431 .16 .4 r
.41301 .65759 m .41086 .65819 L .41047 .66015 L F
.392 .642 .956 r
.65678 .4819 m .65569 .48258 L .65456 .48272 L F
.662 .392 .501 r
.65569 .48258 m .6591 .48353 L .65945 .48318 L F
.392 .642 .956 r
.65678 .4819 m .6591 .48353 L .65569 .48258 L F
.72 .722 .851 r
.70446 .51058 m .70798 .51099 L .70701 .50819 L F
.71 .716 .854 r
.70701 .50819 m .70798 .51099 L .71019 .50908 L F
.965 .922 .707 r
.6353 .5265 m .63746 .52509 L .63678 .52445 L F
.6353 .5265 m .63591 .52838 L .63746 .52509 L F
.915 .973 .782 r
.63885 .5214 m .63678 .52445 L .63746 .52509 L F
.764 .631 .714 r
.62016 .54187 m .61822 .54483 L .61677 .54158 L F
.919 .909 .795 r
.55941 .77667 m .55666 .7785 L .55862 .77579 L F
.681 .741 .896 r
.71241 .46492 m .71298 .46645 L .70973 .46579 L F
.55 .662 .91 r
.71474 .46457 m .71298 .46645 L .71241 .46492 L F
0 .111 .647 r
.5088 .62745 m .50994 .63121 L .50804 .62852 L F
.552 .926 .923 r
.5088 .62745 m .50804 .62852 L .50598 .62864 L F
.632 .094 0 r
.43072 .69672 m .43285 .69828 L .43418 .69759 L F
.618 .075 0 r
.43285 .69828 m .43625 .69906 L .43418 .69759 L F
.496 .805 1 r
.53826 .68905 m .54057 .68869 L .5393 .68773 L F
.219 0 0 r
.31625 .60234 m .31477 .60323 L .3124 .6034 L F
0 0 0 r
.31662 .60228 m .31625 .60234 L .31811 .6022 L F
.31662 .60228 m .31477 .60323 L .31625 .60234 L F
.555 .258 .418 r
.50614 .80139 m .50765 .80151 L .50957 .79842 L F
.593 .251 .359 r
.50765 .80151 m .512 .79945 L .50957 .79842 L F
.736 .697 .814 r
.49249 .81593 m .49471 .81465 L .49404 .81254 L F
.586 .51 .736 r
.29586 .61998 m .29441 .62391 L .29362 .62251 L F
.239 0 .191 r
.57854 .55483 m .58106 .55269 L .57917 .55374 L F
.611 .363 .517 r
.26581 .6386 m .26785 .6403 L .26846 .63811 L F
.352 0 0 r
.66892 .47913 m .66483 .47912 L .66543 .47848 L F
0 0 0 r
.59495 .55863 m .59446 .55928 L .59261 .56138 L F
.45 .282 .56 r
.59703 .55613 m .59748 .55744 L .59495 .55863 L F
.153 0 .045 r
.59495 .55863 m .59626 .55937 L .59446 .55928 L F
.59495 .55863 m .59748 .55744 L .59626 .55937 L F
.234 .512 .909 r
.66479 .49372 m .66689 .4958 L .66541 .49526 L F
.379 .162 .454 r
.25764 .60144 m .25938 .60084 L .25988 .59862 L F
.453 .289 .568 r
.25764 .60144 m .25941 .60321 L .25938 .60084 L F
.25764 .60144 m .25758 .60381 L .25941 .60321 L F
.515 .068 .128 r
.46434 .7002 m .46297 .70186 L .46101 .7016 L F
.506 .043 .089 r
.46691 .70048 m .46297 .70186 L .46434 .7002 L F
.648 .743 .919 r
.57443 .72429 m .57565 .72563 L .57778 .72485 L F
.787 .897 .921 r
.48721 .81092 m .49133 .81045 L .48997 .80963 L F
.465 .881 .934 r
.49133 .81045 m .4922 .80959 L .48997 .80963 L F
.49133 .81045 m .4935 .80976 L .4922 .80959 L F
.822 .518 0 r
.52971 .61287 m .53016 .61496 L .52912 .61162 L F
.923 .821 .728 r
.7314 .51072 m .73128 .51464 L .73048 .51302 L F
.771 .46 .46 r
.73128 .51464 m .729 .51589 L .73048 .51302 L F
.73128 .51464 m .73249 .51632 L .729 .51589 L F
.792 .491 0 r
.48643 .80239 m .48662 .80175 L .48684 .80305 L F
.716 .211 0 r
.48768 .80374 m .48662 .80175 L .48643 .80239 L F
.48768 .80374 m .48868 .80429 L .48662 .80175 L F
.305 .226 .6 r
.47526 .77935 m .47744 .78088 L .47642 .77877 L F
.47526 .77935 m .47566 .78187 L .47744 .78088 L F
.489 .432 .72 r
.25644 .60968 m .25827 .60925 L .25774 .607 L F
.921 .73 .628 r
.5535 .75332 m .5555 .75373 L .55399 .75058 L F
.017 .019 .515 r
.5535 .75332 m .55276 .75594 L .5555 .75373 L F
.055 .274 .766 r
.55399 .75058 m .5555 .75373 L .55628 .75265 L F
.732 .337 .303 r
.5555 .75373 m .55401 .75566 L .55628 .75265 L F
.5555 .75373 m .55693 .75582 L .55401 .75566 L F
.762 .265 0 r
.55705 .75564 m .55693 .75582 L .5555 .75373 L F
.738 .649 .76 r
.69162 .50491 m .68788 .50251 L .69051 .50215 L F
.69162 .50491 m .68962 .50579 L .68788 .50251 L F
.758 .759 .853 r
.69409 .50227 m .69162 .50491 L .69051 .50215 L F
.559 .368 .579 r
.55746 .62917 m .55458 .63166 L .55469 .62969 L F
.673 .664 .833 r
.70326 .50245 m .70009 .50076 L .70213 .49958 L F
.582 .589 .825 r
.70451 .49882 m .70326 .50245 L .70213 .49958 L F
.70451 .49882 m .70558 .50201 L .70326 .50245 L F
.576 .17 .235 r
.42208 .65494 m .41812 .65672 L .42023 .65624 L F
.42208 .65494 m .4187 .65539 L .41812 .65672 L F
.522 .047 .069 r
.42023 .65624 m .42438 .65496 L .42208 .65494 L F
.64 .518 .699 r
.61715 .53918 m .61476 .54207 L .61357 .53861 L F
.966 .847 .673 r
.59104 .71911 m .59055 .71658 L .58824 .71943 L F
0 0 0 r
.60999 .51954 m .60815 .52261 L .60911 .52102 L F
.004 0 .281 r
.60815 .52261 m .60929 .52345 L .60911 .52102 L F
.60815 .52261 m .60772 .52479 L .60929 .52345 L F
.525 .752 .979 r
.31139 .62848 m .31079 .63015 L .30933 .62875 L F
.31139 .62848 m .31284 .62978 L .31079 .63015 L F
.938 .587 .326 r
.55167 .643 m .55004 .64036 L .55147 .64096 L F
.07 .099 .583 r
.50304 .77829 m .5034 .776 L .5013 .77681 L F
.50304 .77829 m .50377 .77824 L .5034 .776 L F
.54 .875 .991 r
.6915 .49484 m .69452 .49505 L .69297 .49591 L F
.792 .564 .591 r
.57374 .59594 m .57082 .59341 L .56932 .59605 L F
.691 .524 .656 r
.5718 .59896 m .57374 .59594 L .56932 .59605 L F
.5718 .59896 m .57408 .5984 L .57374 .59594 L F
.576 .479 .708 r
.57408 .5984 m .57551 .59565 L .57374 .59594 L F
.718 .506 .602 r
.58327 .70533 m .5845 .70872 L .58002 .70821 L F
.625 .458 .635 r
.5857 .70815 m .58327 .70533 L .58668 .70548 L F
.5857 .70815 m .5845 .70872 L .58327 .70533 L F
.476 .205 .422 r
.38208 .60957 m .37945 .61201 L .37985 .60986 L F
.936 .893 .762 r
.51019 .77959 m .51226 .78127 L .50964 .78174 L F
.349 .441 .814 r
.50798 .77757 m .50964 .78174 L .50649 .77882 L F
0 0 0 r
.50964 .78174 m .50731 .78199 L .50649 .77882 L F
.713 .654 .789 r
.51019 .77959 m .50964 .78174 L .50798 .77757 L F
.977 .851 .649 r
.50911 .78224 m .51226 .78127 L .51019 .77959 L F
.571 .856 .996 r
.6845 .47201 m .68688 .47129 L .68785 .4721 L F
.58 .86 .995 r
.68785 .4721 m .68921 .47055 L .6902 .47134 L F
.68785 .4721 m .68688 .47129 L .68921 .47055 L F
.486 .706 .967 r
.37109 .59188 m .37036 .59356 L .36895 .59227 L F
.37109 .59188 m .37244 .59333 L .37036 .59356 L F
0 0 .204 r
.62062 .58625 m .61966 .58767 L .62085 .58429 L F
0 0 .172 r
.62062 .58625 m .61915 .58979 L .61966 .58767 L F
.456 .24 .495 r
.51073 .78563 m .51425 .78161 L .51143 .78191 L F
.564 .917 .96 r
.57589 .70115 m .57894 .70044 L .57558 .69947 L F
.831 .738 .762 r
.58668 .71109 m .58371 .71105 L .5857 .70815 L F
.831 .736 .76 r
.58668 .71109 m .58466 .71418 L .58371 .71105 L F
.497 .087 .192 r
.4574 .69344 m .45382 .69449 L .45586 .69558 L F
.569 .118 .14 r
.45586 .69558 m .45958 .69441 L .4574 .69344 L F
.639 .446 .606 r
.5707 .63547 m .5713 .63802 L .5685 .63823 L F
.447 .354 .657 r
.57234 .63186 m .57347 .63434 L .5707 .63547 L F
.558 .395 .616 r
.57308 .63567 m .5707 .63547 L .57347 .63434 L F
.57308 .63567 m .5713 .63802 L .5707 .63547 L F
.183 0 .182 r
.58106 .55269 m .58367 .55003 L .58185 .55104 L F
.81 .681 .722 r
.68962 .50579 m .68921 .5079 L .68591 .50761 L F
.818 .484 .423 r
.52427 .76803 m .52881 .77033 L .52664 .77034 L F
.241 .557 .933 r
.67091 .52969 m .67378 .53072 L .67246 .52929 L F
.423 .564 .891 r
.63889 .51064 m .63747 .51181 L .63659 .50956 L F
.735 .598 .704 r
.55874 .63247 m .55458 .63166 L .55709 .63159 L F
.55874 .63247 m .5541 .63419 L .55458 .63166 L F
.55874 .63247 m .55667 .6359 L .5541 .63419 L F
.957 .757 .592 r
.55874 .63247 m .55709 .63159 L .55746 .62917 L F
.866 .785 .769 r
.48277 .65019 m .48341 .65199 L .48121 .64958 L F
.951 .74 .581 r
.48341 .65199 m .48188 .6542 L .48121 .64958 L F
.579 .625 .862 r
.48432 .65002 m .48341 .65199 L .48277 .65019 L F
.48432 .65002 m .48557 .65176 L .48341 .65199 L F
.598 .284 .409 r
.48557 .65176 m .48188 .6542 L .48341 .65199 L F
.852 .857 .846 r
.67494 .51047 m .67251 .5104 L .67458 .51026 L F
.027 0 0 r
.67458 .51026 m .6785 .50862 L .67494 .51047 L F
.748 .786 .883 r
.7192 .48257 m .71623 .48452 L .71596 .48217 L F
.922 .846 .75 r
.7364 .48408 m .73501 .48657 L .73356 .4866 L F
0 .443 .863 r
.7363 .48714 m .73356 .4866 L .73679 .48653 L F
.73526 .48845 m .73356 .4866 L .7363 .48714 L F
.73526 .48845 m .73449 .48749 L .73356 .4866 L F
.942 .834 .708 r
.73356 .4866 m .73449 .48749 L .73348 .48658 L F
.73356 .4866 m .73348 .48658 L .73327 .4864 L F
.922 .846 .75 r
.73501 .48657 m .73449 .48749 L .73356 .4866 L F
0 .443 .863 r
.73679 .48653 m .73356 .4866 L .7376 .48551 L F
.909 .799 .726 r
.7376 .48551 m .73356 .4866 L .7364 .48408 L F
.786 .797 .862 r
.74011 .48303 m .7376 .48551 L .7364 .48408 L F
.3 0 .234 r
.30657 .60887 m .30568 .60695 L .30767 .60647 L F
.30657 .60887 m .30462 .60961 L .30568 .60695 L F
.43 .306 .609 r
.35107 .61273 m .35305 .6146 L .35281 .61178 L F
.49 .307 .56 r
.35098 .61513 m .35305 .6146 L .35107 .61273 L F
.614 .175 .183 r
.5324 .80119 m .53311 .79966 L .53251 .80055 L F
.111 0 0 r
.53373 .80036 m .53311 .79966 L .5324 .80119 L F
.53373 .80036 m .53546 .79909 L .53311 .79966 L F
.776 .662 .737 r
.68788 .50251 m .68962 .50579 L .68618 .50518 L F
.81 .681 .722 r
.68962 .50579 m .68591 .50761 L .68618 .50518 L F
.704 .561 .69 r
.47724 .79042 m .47854 .79383 L .47999 .79026 L F
.398 .412 .758 r
.50994 .63121 m .51074 .63464 L .509 .63458 L F
.702 .631 .775 r
.56889 .64132 m .57008 .64404 L .5664 .64367 L F
.706 .516 .629 r
.57008 .64404 m .56644 .64656 L .5664 .64367 L F
.57008 .64404 m .57002 .64633 L .56644 .64656 L F
.673 .617 .785 r
.57221 .64362 m .57008 .64404 L .56889 .64132 L F
.64 .46 .624 r
.57221 .64362 m .57002 .64633 L .57008 .64404 L F
0 0 .539 r
.50543 .76627 m .50511 .76758 L .50407 .76572 L F
.50543 .76627 m .50407 .76572 L .50317 .76665 L F
.299 .309 .702 r
.42208 .68812 m .41996 .68629 L .42174 .6856 L F
.42208 .68812 m .42069 .68837 L .41996 .68629 L F
.429 .186 .442 r
.62069 .50011 m .62246 .50145 L .62247 .49924 L F
.62069 .50011 m .62032 .50212 L .62246 .50145 L F
.479 .211 .428 r
.39769 .66619 m .39988 .66577 L .4003 .66359 L F
.521 .248 .441 r
.4003 .66359 m .40213 .66537 L .40204 .66288 L F
.4003 .66359 m .39988 .66577 L .40213 .66537 L F
.584 .804 .402 r
.26892 .64835 m .26777 .65003 L .26809 .64956 L F
.868 .823 .801 r
.26892 .64835 m .26909 .65152 L .26777 .65003 L F
.563 .451 .684 r
.26909 .65152 m .26843 .6524 L .26777 .65003 L F
.646 .285 .345 r
.60175 .60401 m .6049 .60362 L .60408 .60588 L F
.592 .255 .368 r
.60732 .60369 m .60408 .60588 L .6049 .60362 L F
.547 .279 .461 r
.34042 .62577 m .34355 .62315 L .34156 .62358 L F
.795 .564 .586 r
.63519 .51396 m .63185 .5137 L .63203 .511 L F
.052 0 .378 r
.63559 .50485 m .63396 .50831 L .63639 .50712 L F
.63559 .50485 m .63585 .50735 L .63396 .50831 L F
.287 .477 .871 r
.63585 .50735 m .63659 .50956 L .63396 .50831 L F
.675 .568 .726 r
.4068 .7085 m .40889 .70514 L .40661 .70577 L F
.507 .355 .609 r
.3957 .66916 m .3978 .66876 L .39769 .66619 L F
.554 .462 .705 r
.3957 .66916 m .39848 .67129 L .3978 .66876 L F
.3957 .66916 m .39623 .67189 L .39848 .67129 L F
.767 .839 .907 r
.63805 .50628 m .63963 .50806 L .64208 .50677 L F
.984 .876 .646 r
.73526 .48845 m .73359 .48977 L .73449 .48749 L F
.73526 .48845 m .73435 .49146 L .73359 .48977 L F
.316 .753 .967 r
.34459 .58871 m .34834 .58921 L .34621 .58907 L F
.741 .808 .905 r
.35416 .6039 m .3579 .60406 L .35633 .60303 L F
.35416 .6039 m .35548 .60484 L .3579 .60406 L F
.296 .75 .956 r
.3603 .60362 m .35633 .60303 L .3579 .60406 L F
.553 .429 .665 r
.3579 .60406 m .36057 .60648 L .3603 .60362 L F
.3579 .60406 m .35834 .60699 L .36057 .60648 L F
.164 0 .062 r
.57147 .56145 m .57345 .56057 L .57411 .55876 L F
0 0 .006 r
.57411 .55876 m .57592 .55793 L .57664 .55603 L F
0 0 .072 r
.57516 .55958 m .57411 .55876 L .57345 .56057 L F
.57516 .55958 m .57592 .55793 L .57411 .55876 L F
.203 0 0 r
.32626 .64715 m .32424 .64783 L .32249 .64793 L F
.205 0 0 r
.3284 .64656 m .32424 .64783 L .32626 .64715 L F
.413 .519 .857 r
.25942 .61492 m .26148 .61852 L .26247 .61766 L F
0 .56 .762 r
.49454 .62585 m .49673 .62604 L .49803 .62626 L F
0 0 0 r
.49803 .62626 m .49935 .62388 L .49932 .62421 L F
.49803 .62626 m .4989 .62497 L .49935 .62388 L F
.611 .94 .949 r
.49803 .62626 m .49673 .62604 L .4989 .62497 L F
.142 .142 .597 r
.42222 .69069 m .42089 .6929 L .42069 .68837 L F
.347 .423 .798 r
.42222 .69069 m .42181 .69371 L .42089 .6929 L F
.529 .629 .894 r
.76215 .59917 m .76375 .59709 L .76146 .59774 L F
.76215 .59917 m .76524 .59917 L .76375 .59709 L F
.587 .909 .979 r
.6845 .47201 m .68222 .47292 L .68075 .47244 L F
.313 .803 .795 r
.6751 .4751 m .67339 .47583 L .67287 .47557 L F
.6751 .4751 m .67689 .47482 L .67339 .47583 L F
.125 0 0 r
.55276 .75594 m .55204 .75704 L .55084 .75739 L F
.017 .019 .515 r
.5535 .75332 m .55401 .75566 L .55276 .75594 L F
0 0 0 r
.55401 .75566 m .55204 .75704 L .55276 .75594 L F
.934 .84 .727 r
.6522 .5104 m .6523 .51079 L .65391 .51075 L F
.915 .889 .792 r
.65391 .51075 m .6523 .51079 L .65239 .51064 L F
.17 .334 .787 r
.65258 .50877 m .65231 .51073 L .6522 .5104 L F
.65231 .51073 m .6523 .51079 L .6522 .5104 L F
.955 .893 .728 r
.65256 .51047 m .65226 .51059 L .6522 .5104 L F
.65226 .51059 m .65215 .51063 L .6522 .5104 L F
.65391 .51075 m .65239 .51064 L .65256 .51047 L F
.65239 .51064 m .65215 .51063 L .65256 .51047 L F
.908 .981 .718 r
.65519 .50615 m .65239 .51064 L .65258 .50877 L F
.65239 .51064 m .6523 .51079 L .65231 .51073 L F
.65239 .51064 m .65231 .51073 L .65258 .50877 L F
.915 .889 .792 r
.65391 .51075 m .65239 .51064 L .65519 .50615 L F
.955 .893 .728 r
.65391 .51075 m .6518 .5122 L .65215 .51063 L F
.65391 .51075 m .65242 .51386 L .6518 .5122 L F
.915 .889 .792 r
.65391 .51075 m .65519 .50615 L .65644 .50709 L F
.077 .629 .821 r
.53337 .65245 m .53136 .65212 L .52928 .65206 L F
.433 .448 .775 r
.53388 .6495 m .53528 .65173 L .53337 .65245 L F
.347 .22 .562 r
.53528 .65173 m .53462 .65429 L .53337 .65245 L F
0 .32 .76 r
.53462 .65429 m .53136 .65212 L .53337 .65245 L F
.204 .727 .853 r
.38589 .6973 m .38352 .69505 L .38304 .69699 L F
.966 .68 .437 r
.63311 .5419 m .63339 .5439 L .63498 .54458 L F
.978 .851 .646 r
.6328 .54655 m .63498 .54458 L .63339 .5439 L F
.6328 .54655 m .63381 .54765 L .63498 .54458 L F
.724 .944 .954 r
.67886 .47826 m .67793 .47999 L .67955 .47964 L F
.659 .913 .978 r
.68113 .47701 m .67955 .47964 L .68258 .4776 L F
.68113 .47701 m .67886 .47826 L .67955 .47964 L F
.432 .429 .756 r
.54283 .73695 m .54619 .73978 L .54455 .73643 L F
.297 .751 .955 r
.31651 .63195 m .31844 .63177 L .31998 .63232 L F
.527 .908 .946 r
.31998 .63232 m .32048 .63135 L .32223 .63144 L F
.433 .824 .985 r
.31998 .63232 m .31844 .63177 L .32048 .63135 L F
.401 .216 .512 r
.47663 .68586 m .47786 .68798 L .4779 .68556 L F
.47663 .68586 m .47602 .68874 L .47786 .68798 L F
.47786 .68798 m .47602 .68874 L .47663 .68586 L F
.362 0 0 r
.43896 .70577 m .43748 .70728 L .43526 .70741 L F
.072 0 0 r
.44128 .70578 m .43748 .70728 L .43896 .70577 L F
.294 .73 .967 r
.30306 .58423 m .30508 .58418 L .30664 .58487 L F
.311 .718 .977 r
.30717 .584 m .30664 .58487 L .30508 .58418 L F
.30717 .584 m .30879 .58485 L .30664 .58487 L F
.312 0 0 r
.42892 .6542 m .43257 .65217 L .43019 .65238 L F
.595 .277 .4 r
.63559 .50485 m .63867 .50278 L .63527 .50243 L F
.63559 .50485 m .63822 .50502 L .63867 .50278 L F
0 0 .173 r
.63867 .50278 m .63822 .50502 L .63988 .50334 L F
.742 .321 .248 r
.47333 .69153 m .47644 .69313 L .47704 .69178 L F
.506 .131 .263 r
.47644 .69313 m .4789 .69315 L .47704 .69178 L F
.503 .133 .27 r
.47704 .69178 m .4789 .69315 L .47873 .69177 L F
.647 .618 .806 r
.56524 .71963 m .56879 .72237 L .56737 .71935 L F
.462 .68 .96 r
.56879 .72237 m .57027 .72109 L .56737 .71935 L F
.56879 .72237 m .57099 .72205 L .57027 .72109 L F
.816 .707 .746 r
.5664 .64367 m .56325 .64347 L .56522 .64044 L F
.717 .659 .791 r
.56889 .64132 m .5664 .64367 L .56522 .64044 L F
.954 .716 .539 r
.63048 .51217 m .63203 .511 L .63043 .5103 L F
.63048 .51217 m .63185 .5137 L .63203 .511 L F
.63203 .511 m .63048 .51217 L .63043 .5103 L F
.63203 .511 m .63185 .5137 L .63048 .51217 L F
.534 .356 .586 r
.6096 .60092 m .60732 .60369 L .60728 .60147 L F
.802 .69 .742 r
.56836 .596 m .57082 .59341 L .56939 .59251 L F
.56836 .596 m .56932 .59605 L .57082 .59341 L F
.788 .815 .873 r
.53746 .60218 m .53325 .60334 L .53586 .60128 L F
.816 .846 .872 r
.53886 .60089 m .53746 .60218 L .53586 .60128 L F
.399 .68 .974 r
.52019 .64126 m .5196 .64272 L .5177 .64101 L F
.52019 .64126 m .52131 .64257 L .5196 .64272 L F
.192 0 .144 r
.57592 .55793 m .57854 .55483 L .57664 .55603 L F
.801 .718 .773 r
.56311 .70736 m .56552 .70734 L .56497 .70544 L F
.56311 .70736 m .56207 .70878 L .56552 .70734 L F
.465 .158 .36 r
.56248 .71095 m .56552 .70734 L .56207 .70878 L F
.56248 .71095 m .56457 .7109 L .56552 .70734 L F
.563 .559 .807 r
.56552 .70734 m .56724 .70513 L .56497 .70544 L F
.56552 .70734 m .56823 .70658 L .56724 .70513 L F
.262 .173 .561 r
.48203 .77493 m .47981 .77354 L .48147 .77246 L F
.48203 .77493 m .48008 .77629 L .47981 .77354 L F
.735 .673 .79 r
.75918 .5968 m .7601 .59189 L .75761 .59263 L F
.812 .904 .905 r
.70781 .46714 m .70442 .4682 L .70678 .46561 L F
.763 .838 .909 r
.70973 .46579 m .70781 .46714 L .70678 .46561 L F
.441 .14 .357 r
.36939 .62294 m .36784 .62177 L .36984 .62099 L F
.36939 .62294 m .36722 .62343 L .36784 .62177 L F
.526 .836 .524 r
.58019 .71992 m .57871 .72136 L .5803 .72241 L F
.58019 .71992 m .58131 .71874 L .57871 .72136 L F
.805 .676 .722 r
.5803 .72241 m .58294 .71917 L .58019 .71992 L F
.758 .616 .701 r
.67198 .47998 m .67523 .48226 L .67561 .48049 L F
.73 .598 .709 r
.67528 .4828 m .67198 .47998 L .67561 .48049 L F
.23 .073 .451 r
.60469 .58742 m .6061 .58653 L .6063 .58422 L F
.321 .206 .562 r
.60446 .58965 m .6061 .58653 L .60469 .58742 L F
.545 .353 .571 r
.42391 .67753 m .4238 .68005 L .42156 .68025 L F
.402 .306 .631 r
.42364 .68231 m .42156 .68025 L .4238 .68005 L F
.42364 .68231 m .42172 .68322 L .42156 .68025 L F
.612 .564 .776 r
.25608 .65003 m .25941 .65003 L .25771 .64879 L F
.658 .751 .918 r
.69106 .5293 m .69458 .53002 L .69355 .52801 L F
.616 .68 .888 r
.69458 .53002 m .69573 .52678 L .69355 .52801 L F
.69458 .53002 m .69697 .5293 L .69573 .52678 L F
0 .047 .535 r
.55665 .774 m .55772 .77495 L .55636 .77289 L F
.55665 .774 m .55862 .77579 L .55772 .77495 L F
.682 .664 .825 r
.26799 .63553 m .26882 .63127 L .26666 .6323 L F
.26799 .63553 m .27034 .63501 L .26882 .63127 L F
.661 .529 .692 r
.26799 .63553 m .26846 .63811 L .27034 .63501 L F
.349 .735 .986 r
.32259 .58526 m .32193 .58622 L .32053 .58523 L F
.32259 .58526 m .32409 .58619 L .32193 .58622 L F
.4 .124 .376 r
.37654 .61717 m .37503 .61528 L .37714 .61471 L F
.37654 .61717 m .37449 .61791 L .37503 .61528 L F
.839 .863 .862 r
.7348 .51581 m .73626 .51664 L .73818 .5148 L F
.182 .362 .808 r
.7348 .51581 m .73649 .51914 L .73626 .51664 L F
.431 0 0 r
.69645 .49874 m .69292 .4988 L .69425 .49833 L F
.965 .795 .361 r
.55177 .76681 m .55252 .76792 L .55275 .7641 L F
.55177 .76681 m .55275 .7641 L .55346 .76452 L F
.302 0 0 r
.55085 .7639 m .55346 .76452 L .55275 .7641 L F
.2 0 .079 r
.55275 .7641 m .5555 .7634 L .55652 .76192 L F
.367 0 0 r
.55768 .76512 m .5568 .76549 L .55581 .76473 L F
.304 .713 .976 r
.56032 .76724 m .55841 .76645 L .55768 .76512 L F
.55841 .76645 m .55645 .76564 L .55716 .76534 L F
.55841 .76645 m .55716 .76534 L .55768 .76512 L F
.459 0 0 r
.56085 .76763 m .56032 .76724 L .55768 .76512 L F
.723 .725 .851 r
.55877 .76677 m .56085 .76686 L .55877 .76643 L F
.304 .713 .976 r
.56032 .76724 m .55877 .76643 L .55645 .76564 L F
.953 .696 .509 r
.56032 .76724 m .55878 .76891 L .55877 .76643 L F
.723 .725 .851 r
.55878 .76891 m .55991 .76779 L .55877 .76677 L F
.55991 .76779 m .56085 .76686 L .55877 .76677 L F
0 0 0 r
.55722 .76148 m .55603 .76305 L .5575 .76449 L F
.55722 .76148 m .5563 .76279 L .55603 .76305 L F
0 0 .54 r
.55557 .76349 m .55733 .76589 L .55603 .76305 L F
.367 0 0 r
.5568 .76549 m .55654 .7656 L .55581 .76473 L F
.328 0 0 r
.55645 .76564 m .55744 .76604 L .5555 .7634 L F
0 0 0 r
.5563 .76279 m .55521 .76434 L .55603 .76305 L F
0 0 .54 r
.5555 .7634 m .55557 .76349 L .55603 .76305 L F
.55733 .76589 m .55744 .76604 L .55739 .76594 L F
.55733 .76589 m .55739 .76594 L .55603 .76305 L F
.367 0 0 r
.55581 .76473 m .55654 .7656 L .55275 .7641 L F
.55654 .7656 m .55645 .76564 L .55586 .76539 L F
.55654 .7656 m .55586 .76539 L .55275 .7641 L F
.335 .117 .427 r
.55275 .7641 m .55586 .76539 L .5555 .7634 L F
.55586 .76539 m .55645 .76564 L .5555 .7634 L F
.544 .249 .418 r
.55346 .76452 m .55338 .76463 L .5555 .7634 L F
.55338 .76463 m .55177 .76681 L .55396 .76481 L F
.55338 .76463 m .55396 .76481 L .5555 .7634 L F
.102 0 0 r
.55275 .7641 m .55346 .76452 L .5555 .7634 L F
.55275 .7641 m .55346 .76452 L .5555 .7634 L F
.368 .633 .956 r
.50773 .64272 m .5071 .64157 L .50672 .64042 L F
.50773 .64272 m .50978 .64296 L .5071 .64157 L F
.559 .4 .622 r
.56398 .63479 m .56182 .63754 L .56166 .63504 L F
.509 .023 .038 r
.50858 .81016 m .51268 .80997 L .50989 .81166 L F
.429 0 0 r
.51391 .81168 m .50989 .81166 L .51268 .80997 L F
.901 .759 .263 r
.55705 .75564 m .55698 .75952 L .55659 .75866 L F
.013 .103 .613 r
.55652 .76192 m .55659 .75866 L .55698 .75952 L F
.695 .463 .568 r
.25771 .64879 m .26121 .64887 L .26143 .64653 L F
0 0 0 r
.26121 .64887 m .26314 .64574 L .26143 .64653 L F
0 0 .218 r
.6552 .49432 m .65589 .49507 L .65402 .49319 L F
.6552 .49432 m .65484 .49668 L .65589 .49507 L F
.627 .767 .947 r
.68499 .52968 m .68856 .53037 L .68765 .52808 L F
.692 .759 .903 r
.68765 .52808 m .68856 .53037 L .69106 .5293 L F
.251 .615 .957 r
.42602 .69503 m .42481 .69572 L .42344 .69413 L F
.42602 .69503 m .42725 .69606 L .42481 .69572 L F
.358 .457 .826 r
.49404 .81254 m .49471 .81465 L .49698 .81522 L F
.179 .714 .797 r
.30879 .58485 m .31087 .58456 L .31244 .58452 L F
.127 .673 .813 r
.31087 .58456 m .31447 .58457 L .31244 .58452 L F
.814 .739 .781 r
.58466 .71418 m .5828 .71696 L .58155 .71419 L F
0 .075 .584 r
.5828 .71696 m .5849 .7189 L .58368 .71758 L F
.455 .353 .65 r
.58294 .71917 m .5849 .7189 L .5828 .71696 L F
0 .075 .584 r
.5828 .71696 m .58368 .71758 L .58131 .71874 L F
.987 .878 .533 r
.72739 .49377 m .72798 .49152 L .72742 .49067 L F
0 0 0 r
.45725 .6431 m .45876 .6428 L .46015 .64127 L F
.45725 .6431 m .45684 .64342 L .45876 .6428 L F
.791 .999 .835 r
.55547 .58383 m .55779 .58091 L .55781 .58087 L F
.55547 .58383 m .55507 .5834 L .55779 .58091 L F
.827 .777 .805 r
.78226 .59356 m .78363 .5921 L .78086 .59209 L F
.78226 .59356 m .78363 .5921 L .78086 .59209 L F
.393 0 0 r
.50594 .70231 m .50821 .70286 L .50469 .70244 L F
0 0 .172 r
.61564 .56409 m .61555 .5608 L .61636 .5619 L F
0 0 .139 r
.50948 .79247 m .50985 .79026 L .51026 .79029 L F
.368 0 .005 r
.43625 .69906 m .43854 .69886 L .43998 .69727 L F
.097 0 0 r
.43998 .69727 m .44068 .6981 L .44225 .69727 L F
.43998 .69727 m .43854 .69886 L .44068 .6981 L F
.46 .177 .396 r
.36524 .62409 m .36468 .62605 L .36253 .6265 L F
.425 .145 .382 r
.36678 .62547 m .36524 .62409 L .36722 .62343 L F
.36678 .62547 m .36468 .62605 L .36524 .62409 L F
.825 .428 .297 r
.48288 .69364 m .48563 .69629 L .48647 .6949 L F
.467 .038 .141 r
.48647 .6949 m .48838 .69596 L .48872 .69463 L F
.48647 .6949 m .48563 .69629 L .48838 .69596 L F
.75 .666 .767 r
.69645 .49874 m .69772 .50277 L .69409 .50227 L F
.717 .628 .757 r
.69722 .50483 m .69409 .50227 L .69772 .50277 L F
.719 .648 .778 r
.70009 .50076 m .69772 .50277 L .69645 .49874 L F
.449 .785 .998 r
.3525 .58862 m .3519 .58977 L .35033 .58888 L F
.381 .708 .986 r
.3525 .58862 m .35394 .58976 L .3519 .58977 L F
.588 .634 .865 r
.70146 .47087 m .69936 .47155 L .69782 .46817 L F
.206 .045 .43 r
.25988 .59862 m .26124 .59792 L .2615 .59545 L F
.565 .446 .676 r
.25938 .60084 m .26124 .59792 L .25988 .59862 L F
.51 .245 .448 r
.59915 .59263 m .60153 .59217 L .6017 .5902 L F
.541 .242 .41 r
.60153 .59217 m .60446 .58965 L .6017 .5902 L F
.57 .416 .632 r
.39623 .67189 m .3985 .67419 L .39848 .67129 L F
.39623 .67189 m .39649 .67486 L .3985 .67419 L F
.326 .397 .782 r
.48008 .77629 m .48266 .77828 L .48101 .77935 L F
0 0 .175 r
.48139 .7799 m .48101 .77935 L .48266 .77828 L F
.48129 .78 m .48137 .78165 L .48101 .77935 L F
.4813 .78003 m .4813 .78012 L .48129 .78 L F
.4813 .78012 m .48137 .78165 L .48129 .78 L F
.7 .658 .806 r
.47808 .77697 m .47974 .78063 L .48125 .77969 L F
.627 .499 .687 r
.48296 .77861 m .4813 .78003 L .48266 .77828 L F
.7 .658 .806 r
.48107 .77833 m .48125 .77969 L .48242 .77895 L F
.47808 .77697 m .48125 .77969 L .48107 .77833 L F
.48283 .77857 m .48242 .77895 L .48296 .77861 L F
.47808 .77697 m .48242 .77895 L .48283 .77857 L F
0 0 .175 r
.4813 .78003 m .48129 .78 L .48139 .7799 L F
.48129 .78 m .48101 .77935 L .48139 .7799 L F
0 0 .17 r
.60996 .57587 m .6101 .5777 L .61089 .57424 L F
.569 .457 .687 r
.42572 .67445 m .42615 .67705 L .42391 .67753 L F
.583 .407 .609 r
.42615 .67705 m .4238 .68005 L .42391 .67753 L F
.575 .652 .888 r
.57227 .72465 m .57325 .72171 L .57099 .72205 L F
.57227 .72465 m .57443 .72429 L .57325 .72171 L F
.913 .844 .762 r
.72371 .51026 m .72491 .51103 L .72467 .50758 L F
0 0 0 r
.72375 .51323 m .72306 .5136 L .72491 .51103 L F
.72375 .51323 m .72491 .51103 L .72371 .51026 L F
.767 .839 .907 r
.63805 .50628 m .64208 .50677 L .63908 .50531 L F
0 .519 .786 r
.6445 .50654 m .63908 .50531 L .64208 .50677 L F
.717 .628 .757 r
.69722 .50483 m .69529 .50588 L .69409 .50227 L F
.648 .392 .518 r
.59369 .60701 m .59378 .60915 L .5905 .60973 L F
.706 .509 .62 r
.59606 .60666 m .59378 .60915 L .59369 .60701 L F
.744 .905 .949 r
.48662 .62737 m .48264 .62829 L .48532 .62638 L F
.801 .882 .904 r
.48869 .62561 m .48662 .62737 L .48532 .62638 L F
.502 .657 .93 r
.30119 .6279 m .29802 .62649 L .29996 .62626 L F
.547 .701 .941 r
.30199 .62593 m .30119 .6279 L .29996 .62626 L F
.30199 .62593 m .30387 .62784 L .30119 .6279 L F
.759 .752 .846 r
.65606 .51648 m .6588 .51593 L .65858 .51508 L F
.772 .512 .541 r
.48768 .79286 m .48969 .79568 L .48965 .7933 L F
.608 .172 .189 r
.49225 .7951 m .48965 .7933 L .48969 .79568 L F
.49225 .7951 m .49315 .79353 L .48965 .7933 L F
.9 .981 .704 r
.73505 .49676 m .73332 .49938 L .73331 .49816 L F
.976 .913 .67 r
.73505 .49676 m .73331 .49816 L .73445 .49541 L F
.242 .578 .943 r
.67214 .47441 m .67034 .47516 L .66969 .47465 L F
.67214 .47441 m .67287 .47557 L .67034 .47516 L F
.807 .926 .914 r
.64991 .5064 m .64816 .5077 L .6509 .5072 L F
.871 .799 .777 r
.64816 .5077 m .64882 .51073 L .6509 .5072 L F
.718 .798 .915 r
.68029 .50532 m .67662 .50525 L .67872 .50319 L F
.981 .907 .592 r
.68029 .50532 m .67888 .50648 L .67662 .50525 L F
.68029 .50532 m .67979 .50717 L .67888 .50648 L F
.58 .635 .87 r
.68189 .50204 m .68029 .50532 L .67872 .50319 L F
.68189 .50204 m .68252 .50471 L .68029 .50532 L F
.654 .46 .609 r
.75773 .58872 m .761 .59014 L .7599 .58724 L F
.325 .791 .935 r
.74387 .51387 m .74324 .51352 L .74057 .51387 L F
0 0 0 r
.74529 .5123 m .74419 .51352 L .7442 .51349 L F
.74529 .5123 m .7442 .51349 L .74624 .50962 L F
.451 .108 .292 r
.7478 .50882 m .74771 .51184 L .74529 .5123 L F
.614 .089 0 r
.74771 .51184 m .74597 .51155 L .74529 .5123 L F
.451 .108 .292 r
.7478 .50882 m .74529 .5123 L .74624 .50962 L F
.614 .089 0 r
.74597 .51155 m .74431 .51128 L .74529 .5123 L F
.639 .956 .932 r
.74529 .5123 m .74324 .51352 L .74387 .51387 L F
0 0 0 r
.51053 .69734 m .51089 .69766 L .51257 .69652 L F
.51053 .69734 m .50894 .69859 L .51089 .69766 L F
.906 .866 .789 r
.61182 .51597 m .60999 .51954 L .60869 .51848 L F
.164 0 0 r
.60999 .51954 m .61126 .52025 L .60869 .51848 L F
.60999 .51954 m .60911 .52102 L .61126 .52025 L F
.346 0 .085 r
.33336 .62862 m .33554 .62825 L .33647 .62713 L F
.249 0 .02 r
.33647 .62713 m .33554 .62825 L .33857 .62659 L F
.799 .541 .549 r
.61822 .54483 m .61832 .54718 L .61504 .5467 L F
.425 .854 .724 r
.46792 .63771 m .4672 .63794 L .46913 .63687 L F
0 0 0 r
.4672 .63794 m .46774 .6383 L .46913 .63687 L F
.659 .893 .548 r
.46913 .63687 m .46774 .6383 L .46835 .63752 L F
0 0 0 r
.46792 .63771 m .46913 .63687 L .46983 .63628 L F
.659 .893 .548 r
.46913 .63687 m .46835 .63752 L .46998 .63547 L F
0 0 0 r
.46983 .63628 m .46913 .63687 L .47046 .63581 L F
.251 .228 .637 r
.74766 .50242 m .74921 .50445 L .74782 .50529 L F
.356 .225 .562 r
.75015 .5065 m .74782 .50529 L .74921 .50445 L F
.75015 .5065 m .74738 .50798 L .74782 .50529 L F
.803 .681 .73 r
.56836 .596 m .56812 .59831 L .56932 .59605 L F
.712 .564 .685 r
.56812 .59831 m .5718 .59896 L .56932 .59605 L F
.839 .863 .862 r
.7348 .51581 m .73818 .5148 L .73708 .51294 L F
.658 .747 .916 r
.73708 .51294 m .73818 .5148 L .74057 .51387 L F
.273 .166 .546 r
.61291 .51486 m .61543 .51212 L .61275 .5139 L F
0 0 0 r
.47854 .79383 m .47638 .79617 L .47702 .79495 L F
.157 0 0 r
.47702 .79495 m .48081 .79327 L .47854 .79383 L F
.362 .792 .969 r
.4981 .64099 m .49692 .64049 L .49478 .64081 L F
.494 .861 .986 r
.49897 .63993 m .4981 .64099 L .50057 .64077 L F
.49897 .63993 m .49692 .64049 L .4981 .64099 L F
.354 0 .139 r
.45876 .6428 m .4622 .64018 L .46015 .64127 L F
.636 .771 .945 r
.56325 .64347 m .56079 .6445 L .5595 .64296 L F
.643 .237 .261 r
.52685 .79258 m .52476 .79062 L .52509 .793 L F
.525 .916 .914 r
.76818 .59842 m .76744 .59818 L .76524 .59917 L F
.621 .549 .752 r
.77095 .59755 m .76818 .59842 L .76766 .59564 L F
.548 .927 .913 r
.76968 .59712 m .76818 .59842 L .77095 .59755 L F
.76968 .59712 m .76744 .59818 L .76818 .59842 L F
.84 .994 .747 r
.25524 .62537 m .25402 .62672 L .25462 .62515 L F
.973 .849 .447 r
.255 .62309 m .25462 .62515 L .25524 .62537 L F
.683 .468 .589 r
.25524 .62537 m .25706 .62703 L .25402 .62672 L F
0 .454 .726 r
.25462 .62515 m .25724 .62581 L .25524 .62537 L F
.973 .849 .447 r
.255 .62309 m .25462 .62515 L .25524 .62537 L F
.297 .423 .82 r
.25724 .62581 m .25706 .62703 L .25524 .62537 L F
.725 .531 .628 r
.42832 .67448 m .42572 .67445 L .42571 .67195 L F
.492 .415 .697 r
.56089 .71335 m .56248 .71095 L .56092 .7113 L F
.533 .389 .631 r
.68618 .50518 m .6838 .50805 L .68252 .50471 L F
.68618 .50518 m .68591 .50761 L .6838 .50805 L F
.754 .341 .268 r
.49225 .7951 m .49502 .79592 L .49315 .79353 L F
.552 .339 .544 r
.58328 .61258 m .58364 .6148 L .58076 .61505 L F
.703 .513 .629 r
.58568 .61232 m .58364 .6148 L .58328 .61258 L F
.209 0 0 r
.52449 .69719 m .5215 .69877 L .52246 .6978 L F
.811 .618 .642 r
.50377 .77824 m .50611 .77653 L .5034 .776 L F
.211 .06 .447 r
.62314 .58087 m .62297 .58326 L .62085 .58429 L F
.212 .021 .39 r
.62297 .58326 m .62062 .58625 L .62085 .58429 L F
.579 .064 0 r
.50374 .6395 m .50672 .64042 L .50283 .6401 L F
.564 .917 .96 r
.57589 .70115 m .57792 .70057 L .57894 .70044 L F
.506 .205 .39 r
.57792 .70057 m .58084 .69942 L .57894 .70044 L F
.675 .568 .726 r
.4068 .7085 m .41 .70852 L .40889 .70514 L F
.689 .51 .639 r
.40693 .70926 m .41 .70852 L .4068 .7085 L F
.479 .497 .798 r
.26395 .62122 m .26504 .62441 L .26642 .62313 L F
.482 .501 .801 r
.26504 .62441 m .26797 .62633 L .26642 .62313 L F
.665 .367 .459 r
.60436 .54742 m .60319 .54975 L .60105 .54966 L F
.654 .389 .506 r
.60677 .54739 m .60319 .54975 L .60436 .54742 L F
.449 .257 .526 r
.37916 .61415 m .37723 .61261 L .37945 .61201 L F
.37916 .61415 m .37714 .61471 L .37723 .61261 L F
.466 .109 .275 r
.46755 .69379 m .47102 .69105 L .4682 .6916 L F
.46755 .69379 m .46987 .69352 L .47102 .69105 L F
.491 .134 .288 r
.47102 .69105 m .47144 .69312 L .47333 .69153 L F
.47102 .69105 m .46987 .69352 L .47144 .69312 L F
.199 .514 .914 r
.36775 .59073 m .36726 .59186 L .36539 .59062 L F
.36775 .59073 m .36895 .59227 L .36726 .59186 L F
.682 .389 .47 r
.51873 .78557 m .51763 .78706 L .51545 .78607 L F
.488 .357 .629 r
.51792 .78454 m .51763 .78706 L .51873 .78557 L F
.864 .778 .765 r
.62625 .51609 m .62791 .51704 L .629 .51587 L F
.799 .655 .704 r
.62791 .51704 m .62727 .51921 L .629 .51587 L F
.867 .748 .73 r
.629 .51587 m .62727 .51921 L .62625 .51609 L F
.693 .524 .654 r
.61476 .54207 m .61459 .54511 L .61249 .54452 L F
.66 .547 .716 r
.61677 .54158 m .61476 .54207 L .61715 .53918 L F
0 0 0 r
.33035 .6458 m .33428 .64408 L .33248 .64531 L F
.33248 .64531 m .33428 .64408 L .33625 .64329 L F
.952 .953 .681 r
.63054 .564 m .63255 .56167 L .63213 .56057 L F
.63054 .564 m .63122 .56444 L .63255 .56167 L F
0 0 .367 r
.5114 .64621 m .512 .6426 L .50978 .64296 L F
.5114 .64621 m .51211 .64519 L .51187 .64337 L F
0 0 .517 r
.5114 .64621 m .51246 .64719 L .51223 .64503 L F
.5114 .64621 m .51311 .6489 L .51246 .64719 L F
.698 .439 .528 r
.51237 .64704 m .50903 .64784 L .50992 .64325 L F
.51246 .64719 m .51239 .6472 L .51237 .64704 L F
.51239 .6472 m .50903 .64784 L .51237 .64704 L F
0 0 .367 r
.51187 .64337 m .51223 .64503 L .512 .6426 L F
.51211 .64519 m .51223 .64503 L .51187 .64337 L F
.944 .744 .602 r
.57814 .65787 m .57651 .65754 L .57691 .65443 L F
0 .518 .75 r
.57814 .65787 m .57783 .65772 L .57651 .65754 L F
.526 0 0 r
.57691 .65443 m .58067 .6574 L .57814 .65787 L F
.425 .864 .78 r
.57975 .65683 m .57814 .65787 L .58067 .6574 L F
.57975 .65683 m .57783 .65772 L .57814 .65787 L F
.816 .846 .872 r
.53886 .60089 m .53586 .60128 L .53809 .60034 L F
.844 .989 .857 r
.53886 .60089 m .54054 .59777 L .54166 .59864 L F
.53886 .60089 m .53809 .60034 L .54054 .59777 L F
.796 .461 .421 r
.55512 .74414 m .55783 .74314 L .55503 .74208 L F
.55512 .74414 m .55861 .74483 L .55783 .74314 L F
.831 .711 .732 r
.61832 .54718 m .61944 .55049 L .61765 .54939 L F
.89 .69 .625 r
.61892 .55252 m .61765 .54939 L .61944 .55049 L F
.594 .275 .399 r
.43375 .6687 m .43283 .67119 L .43025 .6712 L F
.421 .088 .292 r
.43594 .66837 m .43283 .67119 L .43375 .6687 L F
.274 .188 .573 r
.42208 .68812 m .42222 .69069 L .42069 .68837 L F
.575 .335 .516 r
.58076 .61505 m .58121 .61741 L .57799 .61787 L F
.609 .403 .576 r
.58364 .6148 m .58121 .61741 L .58076 .61505 L F
.131 0 0 r
.32193 .60146 m .31958 .60214 L .31811 .6022 L F
0 0 0 r
.32213 .60174 m .32193 .60146 L .32412 .60103 L F
.32213 .60174 m .31958 .60214 L .32193 .60146 L F
.271 .305 .714 r
.74818 .4987 m .74925 .50106 L .74766 .50242 L F
.22 .218 .644 r
.74925 .50106 m .74921 .50445 L .74766 .50242 L F
.038 0 0 r
.34267 .60043 m .34129 .60074 L .33917 .60095 L F
.463 .89 .846 r
.34326 .59981 m .34267 .60043 L .34496 .59994 L F
.34326 .59981 m .34129 .60074 L .34267 .60043 L F
.918 .978 .747 r
.6785 .50862 m .67888 .50648 L .67979 .50717 L F
.347 .423 .798 r
.42222 .69069 m .42344 .69413 L .42181 .69371 L F
.999 .833 .535 r
.6335 .53567 m .63307 .53787 L .63407 .53872 L F
.995 .847 .582 r
.63258 .5393 m .63407 .53872 L .63307 .53787 L F
.63258 .5393 m .63311 .5419 L .63407 .53872 L F
.916 .838 .753 r
.73415 .50582 m .73195 .50644 L .73307 .50491 L F
.73415 .50582 m .73311 .50769 L .73195 .50644 L F
.737 .727 .843 r
.67378 .53072 m .6773 .53146 L .67591 .52952 L F
.664 .703 .876 r
.67591 .52952 m .6773 .53146 L .67943 .53033 L F
.871 .976 .671 r
.27034 .63501 m .26846 .63811 L .26854 .63658 L F
.124 .417 .863 r
.26846 .63811 m .27064 .63908 L .26854 .63658 L F
.497 .253 .474 r
.26846 .63811 m .26785 .6403 L .27064 .63908 L F
.733 .839 .93 r
.25981 .6267 m .25706 .62703 L .25724 .62581 L F
.25981 .6267 m .25706 .62703 L .25724 .62581 L F
.479 .827 .997 r
.32703 .58645 m .32724 .58751 L .32554 .58642 L F
.615 .601 .813 r
.29802 .62649 m .29441 .62391 L .29661 .62334 L F
.5 .561 .849 r
.29848 .6233 m .29802 .62649 L .29661 .62334 L F
.29848 .6233 m .29996 .62626 L .29802 .62649 L F
.642 .597 .788 r
.68841 .51646 m .68494 .51377 L .68752 .51303 L F
0 0 .321 r
.4737 .80733 m .47435 .80879 L .47402 .80688 L F
.4737 .80733 m .47371 .80902 L .47435 .80879 L F
.842 .791 .802 r
.69779 .52146 m .70145 .5197 L .69992 .5186 L F
.69779 .52146 m .69941 .52229 L .70145 .5197 L F
.867 .717 .694 r
.70145 .5197 m .70025 .5163 L .69992 .5186 L F
.71 .658 .796 r
.56285 .72043 m .56396 .71648 L .5618 .71684 L F
.56285 .72043 m .56524 .71963 L .56396 .71648 L F
.657 .477 .629 r
.75773 .58872 m .7601 .59189 L .761 .59014 L F
.75773 .58872 m .75761 .59263 L .7601 .59189 L F
.535 .507 .772 r
.5618 .71684 m .56297 .71303 L .56089 .71335 L F
.5618 .71684 m .56396 .71648 L .56297 .71303 L F
.642 .9 .984 r
.37791 .70819 m .37814 .70689 L .37627 .7078 L F
.37791 .70819 m .38006 .70746 L .37814 .70689 L F
.559 0 0 r
.37627 .7078 m .37791 .70819 L .37953 .70931 L F
.327 .657 .972 r
.66686 .50092 m .66512 .49921 L .66573 .49859 L F
.865 .688 .661 r
.59698 .70785 m .5956 .71094 L .59827 .71104 L F
.86 .978 .857 r
.59473 .71331 m .59827 .71104 L .5956 .71094 L F
.503 .338 .591 r
.61576 .50784 m .61782 .50474 L .61551 .50528 L F
.776 .681 .759 r
.5015 .80699 m .50507 .80732 L .50452 .80446 L F
.729 .344 .321 r
.5044 .8098 m .50507 .80732 L .5015 .80699 L F
.544 .524 .784 r
.50452 .80446 m .50507 .80732 L .50737 .80711 L F
.427 .057 .232 r
.50737 .80711 m .50507 .80732 L .5044 .8098 L F
.728 .715 .839 r
.6455 .51035 m .64882 .51073 L .64816 .5077 L F
.885 .633 .552 r
.24841 .64604 m .24646 .64553 L .24888 .64309 L F
.346 .133 .441 r
.25046 .64287 m .24841 .64604 L .24888 .64309 L F
0 0 0 r
.24888 .64309 m .24843 .64399 L .25046 .64287 L F
.24888 .64309 m .24646 .64553 L .24843 .64399 L F
.169 0 0 r
.64291 .48757 m .64645 .4876 L .64405 .48862 L F
.784 .645 .709 r
.56807 .60075 m .57177 .60137 L .5718 .59896 L F
.584 .543 .775 r
.56807 .60075 m .57146 .60338 L .57177 .60137 L F
.707 .581 .712 r
.57177 .60137 m .57408 .5984 L .5718 .59896 L F
.581 .408 .612 r
.57177 .60137 m .57427 .60108 L .57408 .5984 L F
.538 .252 .429 r
.57146 .60338 m .57427 .60108 L .57177 .60137 L F
.957 .704 .512 r
.56611 .76078 m .56726 .75945 L .56616 .75834 L F
.56611 .76078 m .5672 .76124 L .56726 .75945 L F
.173 0 0 r
.53141 .79289 m .53372 .7928 L .53104 .79348 L F
.784 .826 .885 r
.2898 .64885 m .29174 .65004 L .29291 .64826 L F
.673 .617 .785 r
.57221 .64362 m .56889 .64132 L .57092 .63994 L F
.694 .537 .669 r
.57221 .64362 m .57254 .64645 L .57002 .64633 L F
.572 .477 .708 r
.57349 .63974 m .57221 .64362 L .57092 .63994 L F
.57349 .63974 m .57452 .64315 L .57221 .64362 L F
.555 .431 .666 r
.57452 .64315 m .57254 .64645 L .57221 .64362 L F
.668 .685 .857 r
.71484 .50293 m .71202 .50178 L .71379 .50161 L F
.556 .777 .981 r
.71634 .50107 m .71484 .50293 L .71379 .50161 L F
.71634 .50107 m .71757 .50236 L .71484 .50293 L F
.925 .707 .588 r
.69769 .52377 m .69941 .52229 L .69779 .52146 L F
.69769 .52377 m .69933 .52499 L .69941 .52229 L F
.347 0 0 r
.43471 .65155 m .43689 .65133 L .43828 .64989 L F
.389 0 .039 r
.43689 .65133 m .44044 .64966 L .43828 .64989 L F
.429 .76 .996 r
.33387 .60062 m .33445 .59939 L .3319 .59986 L F
.33387 .60062 m .33588 .60033 L .33445 .59939 L F
.192 .082 .491 r
.52266 .64641 m .52141 .64919 L .52112 .6474 L F
.602 .662 .881 r
.52374 .65186 m .52526 .64918 L .52228 .64944 L F
.052 0 0 r
.52332 .64941 m .52304 .6494 L .52279 .64938 L F
0 0 0 r
.52279 .64938 m .51896 .65062 L .52131 .64924 L F
.556 .872 .994 r
.52279 .64938 m .51997 .64931 L .51896 .65062 L F
.052 0 0 r
.52304 .6494 m .51997 .64931 L .52279 .64938 L F
0 0 0 r
.52279 .64938 m .52131 .64924 L .52141 .64919 L F
.534 .513 .779 r
.39563 .68338 m .39887 .68567 L .39781 .68294 L F
.564 .5 .742 r
.39483 .68011 m .39563 .68338 L .39781 .68294 L F
.965 .919 .709 r
.5666 .76768 m .56481 .76916 L .56537 .77097 L F
.5666 .76768 m .56576 .76708 L .56481 .76916 L F
.946 .859 .724 r
.5666 .76768 m .56645 .76474 L .56576 .76708 L F
.263 .332 .746 r
.71539 .48037 m .71678 .47804 L .71459 .47631 L F
0 0 0 r
.7149 .48123 m .71539 .48037 L .71596 .48217 L F
.7149 .48123 m .71678 .47804 L .71539 .48037 L F
.496 .308 .555 r
.7468 .48829 m .74681 .49092 L .74473 .4912 L F
.867 .738 .717 r
.50888 .80765 m .50858 .81016 L .50737 .80711 L F
.163 0 .376 r
.50869 .81098 m .50858 .81016 L .50989 .81166 L F
.946 .924 .754 r
.63411 .5291 m .63477 .53076 L .63591 .52838 L F
.998 .785 .444 r
.6336 .53089 m .63477 .53076 L .63411 .5291 L F
.6336 .53089 m .6345 .5321 L .63477 .53076 L F
.784 .645 .709 r
.56807 .60075 m .5718 .59896 L .56812 .59831 L F
.254 .583 .945 r
.26381 .62839 m .26579 .62993 L .26282 .62928 L F
.206 .357 .795 r
.26282 .62928 m .26501 .63109 L .26381 .62839 L F
.26282 .62928 m .26464 .63184 L .26501 .63109 L F
.965 .674 .257 r
.63464 .50313 m .63527 .50243 L .63481 .50158 L F
.63464 .50313 m .63559 .50485 L .63527 .50243 L F
.763 .643 .729 r
.74738 .50798 m .7478 .50882 L .74624 .50962 L F
.457 .461 .774 r
.75015 .5065 m .7478 .50882 L .74738 .50798 L F
.75015 .5065 m .75097 .50989 L .7478 .50882 L F
.53 .143 .252 r
.75097 .50989 m .74771 .51184 L .7478 .50882 L F
.576 .479 .708 r
.57408 .5984 m .57657 .5979 L .57551 .59565 L F
.572 .412 .626 r
.57427 .60108 m .57657 .5979 L .57408 .5984 L F
.303 .725 .973 r
.32223 .63144 m .32434 .63144 L .3256 .6321 L F
.5 .826 1 r
.3256 .6321 m .32434 .63144 L .32761 .63162 L F
.614 .204 .241 r
.56212 .64872 m .56125 .65071 L .56088 .64955 L F
.865 .662 .625 r
.56453 .64894 m .56125 .65071 L .56212 .64872 L F
0 0 .523 r
.53563 .77366 m .53713 .77281 L .53449 .77254 L F
.53563 .77366 m .53708 .77479 L .53713 .77281 L F
.53563 .77366 m .53629 .77573 L .53708 .77479 L F
.834 .868 .869 r
.26672 .65137 m .26843 .6524 L .26909 .65152 L F
.044 .572 .863 r
.30585 .62779 m .30933 .62875 L .30736 .62885 L F
.653 .561 .738 r
.70931 .48034 m .70747 .48372 L .70767 .48005 L F
.612 .05 0 r
.71012 .48438 m .70648 .4819 L .70747 .48372 L F
.843 .79 .8 r
.48466 .64724 m .48742 .64569 L .48669 .64614 L F
.71 .597 .728 r
.56634 .59837 m .56812 .59831 L .56836 .596 L F
.716 .49 .582 r
.56589 .60035 m .56812 .59831 L .56634 .59837 L F
.56589 .60035 m .56807 .60075 L .56812 .59831 L F
.379 .841 .885 r
.5938 .716 m .59279 .71594 L .59055 .71658 L F
.903 .975 .803 r
.59473 .71331 m .59279 .71594 L .5938 .716 L F
.906 .866 .789 r
.61182 .51597 m .60869 .51848 L .61083 .51735 L F
.36 0 .169 r
.61083 .51735 m .61291 .51486 L .61182 .51597 L F
.463 .294 .565 r
.60105 .54966 m .59903 .55264 L .59908 .5504 L F
.944 .927 .757 r
.6353 .5265 m .63411 .5291 L .63591 .52838 L F
.752 .644 .741 r
.56476 .59557 m .56422 .59832 L .56634 .59837 L F
.686 .503 .633 r
.56422 .59832 m .56589 .60035 L .56634 .59837 L F
.71 .597 .728 r
.56634 .59837 m .56836 .596 L .56476 .59557 L F
.75 .588 .676 r
.5685 .63823 m .56522 .64044 L .56564 .63803 L F
.5685 .63823 m .56889 .64132 L .56522 .64044 L F
.655 .521 .688 r
.57092 .63994 m .5685 .63823 L .5713 .63802 L F
.57092 .63994 m .56889 .64132 L .5685 .63823 L F
.652 .147 .034 r
.51198 .80623 m .51286 .80496 L .51184 .80375 L F
.51198 .80623 m .51527 .80652 L .51286 .80496 L F
.511 .084 .166 r
.45016 .69624 m .45247 .69644 L .45382 .69449 L F
.502 .075 .161 r
.45382 .69449 m .45247 .69644 L .45586 .69558 L F
.586 .51 .736 r
.29586 .61998 m .29661 .62334 L .29441 .62391 L F
.364 .187 .503 r
.24864 .62869 m .25025 .62874 L .25007 .62661 L F
.977 .676 .361 r
.7384 .53031 m .73727 .52759 L .73856 .52843 L F
.7384 .53031 m .73735 .53061 L .73727 .52759 L F
.415 0 0 r
.7384 .53031 m .73807 .53094 L .73735 .53061 L F
.708 .628 .766 r
.74079 .52749 m .7384 .53031 L .73856 .52843 L F
.638 .078 0 r
.74181 .53264 m .74125 .53272 L .7384 .53031 L F
.85 .995 .753 r
.74113 .53226 m .74125 .53272 L .74215 .53158 L F
0 .184 .705 r
.74109 .53212 m .74125 .53272 L .74157 .53244 L F
.549 .347 .559 r
.74181 .53264 m .74422 .5302 L .74175 .5299 L F
.74181 .53264 m .74175 .5299 L .74215 .53158 L F
.85 .995 .753 r
.74109 .5319 m .74215 .53158 L .74189 .53106 L F
0 .184 .705 r
.7384 .53031 m .74116 .53265 L .74109 .53212 L F
.7384 .53031 m .74111 .53214 L .73807 .53094 L F
.74111 .53214 m .74157 .53244 L .74095 .53218 L F
.74111 .53214 m .74095 .53218 L .73807 .53094 L F
.85 .995 .753 r
.74008 .53296 m .74113 .53226 L .74111 .53214 L F
.19 .514 .914 r
.73807 .53094 m .74095 .53218 L .73892 .53022 L F
.85 .995 .753 r
.74095 .53218 m .74111 .53214 L .741 .53199 L F
.74113 .53226 m .74215 .53158 L .74109 .5319 L F
.19 .514 .914 r
.74095 .53218 m .74107 .53203 L .741 .53199 L F
.74095 .53218 m .74098 .53206 L .73892 .53022 L F
.872 .931 .858 r
.74071 .53132 m .74189 .53106 L .74128 .52983 L F
.19 .514 .914 r
.74098 .53206 m .741 .53199 L .74092 .5319 L F
.741 .53199 m .74098 .53195 L .74092 .5319 L F
.74098 .53206 m .74092 .5319 L .73892 .53022 L F
.761 .681 .774 r
.73892 .53022 m .74098 .53195 L .74008 .53296 L F
.872 .931 .858 r
.74008 .53296 m .741 .53199 L .74098 .53195 L F
.741 .53199 m .74189 .53106 L .74071 .53132 L F
.74128 .52983 m .74189 .53106 L .74008 .53296 L F
.19 .514 .914 r
.741 .53199 m .74101 .53197 L .74098 .53195 L F
.85 .995 .753 r
.74078 .53222 m .74095 .53218 L .741 .53199 L F
.761 .681 .774 r
.74098 .53195 m .74101 .53197 L .74008 .53296 L F
.85 .995 .753 r
.74008 .53296 m .74111 .53214 L .74078 .53222 L F
.617 .44 .621 r
.741 .53199 m .74105 .53205 L .74008 .53296 L F
.19 .514 .914 r
.74095 .53218 m .74157 .53244 L .74107 .53203 L F
0 .184 .705 r
.74116 .53265 m .74125 .53272 L .74113 .53226 L F
.74116 .53265 m .74113 .53226 L .74109 .53212 L F
.85 .995 .753 r
.74008 .53296 m .74125 .53272 L .74113 .53226 L F
.761 .681 .774 r
.74107 .53203 m .74157 .53244 L .74008 .53296 L F
.332 .81 .758 r
.74157 .53244 m .74125 .53272 L .74008 .53296 L F
.617 .44 .621 r
.74105 .53205 m .74239 .53358 L .74008 .53296 L F
.85 .995 .753 r
.741 .53199 m .74111 .53214 L .74109 .5319 L F
.549 .347 .559 r
.74181 .53264 m .74426 .53229 L .74422 .5302 L F
.803 .979 .698 r
.74215 .53158 m .74125 .53272 L .74181 .53264 L F
.617 .44 .621 r
.74189 .53106 m .74219 .53255 L .741 .53199 L F
.19 .514 .914 r
.741 .53199 m .74107 .53203 L .74101 .53197 L F
.761 .681 .774 r
.74101 .53197 m .74107 .53203 L .74008 .53296 L F
.872 .931 .858 r
.74008 .53296 m .74098 .53195 L .74071 .53132 L F
.761 .681 .774 r
.73892 .53022 m .74008 .53296 L .73916 .5324 L F
.872 .931 .858 r
.74008 .53296 m .74071 .53132 L .73916 .5324 L F
.74071 .53132 m .74128 .52983 L .7405 .53077 L F
.74071 .53132 m .7405 .53077 L .73916 .5324 L F
.617 .44 .621 r
.74219 .53255 m .74239 .53358 L .741 .53199 L F
.221 0 0 r
.42761 .70923 m .42838 .71033 L .42602 .71037 L F
.42761 .70923 m .42906 .70983 L .42838 .71033 L F
.247 0 0 r
.43004 .70882 m .42906 .70983 L .42761 .70923 L F
.716 .696 .83 r
.70819 .49971 m .70908 .50264 L .70558 .50201 L F
.693 .682 .835 r
.71202 .50178 m .70908 .50264 L .70819 .49971 L F
0 .114 .666 r
.53161 .61791 m .53206 .6172 L .53016 .61496 L F
.033 .402 .856 r
.53161 .61791 m .53414 .61942 L .53206 .6172 L F
.416 .487 .825 r
.74573 .48524 m .74889 .48697 L .7468 .48829 L F
.083 0 .381 r
.74889 .48697 m .74681 .49092 L .7468 .48829 L F
.595 .629 .855 r
.71019 .50908 m .7137 .51141 L .71314 .50942 L F
.495 .571 .861 r
.71314 .50942 m .7137 .51141 L .71522 .5092 L F
.531 .62 .885 r
.71522 .5092 m .7137 .51141 L .71633 .51125 L F
.416 .57 .899 r
.7137 .51141 m .71729 .51377 L .71633 .51125 L F
.723 .445 .505 r
.58213 .69363 m .58499 .69398 L .58555 .69149 L F
.771 .493 .515 r
.58499 .69398 m .58768 .69393 L .58555 .69149 L F
.325 0 0 r
.28764 .58589 m .2899 .58579 L .29158 .58462 L F
.14 0 0 r
.2899 .58579 m .29395 .58472 L .29158 .58462 L F
.516 .409 .671 r
.57375 .626 m .57172 .62957 L .57103 .62625 L F
.593 .614 .843 r
.26882 .63127 m .27034 .63501 L .27243 .6345 L F
.902 .589 .444 r
.26854 .63658 m .27041 .63765 L .27034 .63501 L F
.599 .382 .558 r
.27041 .63765 m .27243 .6345 L .27034 .63501 L F
.675 .22 .166 r
.71459 .47631 m .71678 .47804 L .71789 .4765 L F
0 0 0 r
.71789 .4765 m .71969 .47573 L .71989 .47561 L F
.348 0 0 r
.47669 .81444 m .47698 .81461 L .47638 .81456 L F
.47669 .81444 m .47638 .81456 L .4748 .81444 L F
0 0 .393 r
.47607 .81302 m .47675 .81441 L .47669 .81444 L F
.47675 .81441 m .47745 .81582 L .47669 .81444 L F
.2 .728 .772 r
.47745 .81582 m .47854 .81548 L .47669 .81444 L F
.47745 .81582 m .47965 .81539 L .47854 .81548 L F
.433 .245 .524 r
.53993 .75851 m .53777 .7592 L .53758 .75675 L F
.493 .854 .99 r
.53777 .7592 m .53993 .75851 L .53758 .75675 L F
.648 .335 .427 r
.59632 .59744 m .59692 .59555 L .59401 .59591 L F
.448 .206 .454 r
.59632 .59744 m .59881 .59466 L .59692 .59555 L F
.73 .598 .709 r
.67528 .4828 m .67197 .48313 L .67198 .47998 L F
.293 0 .192 r
.67453 .48243 m .67197 .48313 L .67528 .4828 L F
.577 .868 .554 r
.67793 .47999 m .67664 .4812 L .67668 .48132 L F
.023 0 .131 r
.67886 .47826 m .67864 .4801 L .67664 .4812 L F
.526 .195 .351 r
.67864 .4801 m .6766 .48107 L .67664 .4812 L F
.104 0 0 r
.67664 .4812 m .6732 .4817 L .67453 .48243 L F
.67664 .4812 m .67546 .48161 L .6732 .4817 L F
.526 .195 .351 r
.6766 .48107 m .67546 .48161 L .67664 .4812 L F
.577 .868 .554 r
.67668 .48132 m .67664 .4812 L .67528 .4828 L F
.653 .956 .941 r
.67664 .4812 m .67453 .48243 L .67528 .4828 L F
.279 .142 .509 r
.47642 .76951 m .47782 .76728 L .47577 .76761 L F
.371 .775 .984 r
.71964 .51328 m .72306 .5136 L .72375 .51323 L F
0 0 0 r
.52076 .69144 m .52212 .69085 L .52347 .68945 L F
.202 0 0 r
.52212 .69085 m .52546 .68893 L .52347 .68945 L F
0 0 0 r
.48997 .77944 m .4879 .78223 L .4892 .7811 L F
0 0 .223 r
.4879 .78223 m .48748 .78398 L .4892 .7811 L F
.34 .735 .983 r
.3581 .58932 m .35753 .59023 L .35604 .58939 L F
.3581 .58932 m .35965 .5902 L .35753 .59023 L F
.565 .423 .647 r
.53463 .68897 m .53498 .69132 L .53269 .69174 L F
.53 .272 .468 r
.53498 .69132 m .53234 .69373 L .53269 .69174 L F
.289 .745 .955 r
.32966 .58692 m .33384 .58688 L .33704 .58797 L F
.13 .66 .869 r
.33384 .58688 m .33766 .58729 L .33704 .58797 L F
.903 .558 .379 r
.53662 .65538 m .53529 .65656 L .53462 .65429 L F
.664 .794 .944 r
.5388 .6545 m .53662 .65538 L .53462 .65429 L F
0 0 0 r
.53697 .65558 m .53662 .65538 L .5388 .6545 L F
.53697 .65558 m .53529 .65656 L .53662 .65538 L F
.381 .104 .362 r
.2615 .59545 m .26352 .59486 L .26407 .59284 L F
.544 .254 .424 r
.26352 .59486 m .26582 .59454 L .26407 .59284 L F
.472 .257 .506 r
.26407 .59284 m .26582 .59454 L .26607 .59226 L F
.556 .285 .461 r
.60175 .60401 m .6018 .60613 L .59928 .60658 L F
.593 .314 .463 r
.60175 .60401 m .60408 .60588 L .6018 .60613 L F
.664 .157 .027 r
.58928 .70137 m .59016 .70021 L .58908 .69925 L F
.58928 .70137 m .5927 .702 L .59016 .70021 L F
.623 .06 0 r
.59016 .70021 m .5927 .702 L .59415 .70221 L F
.844 .563 .513 r
.64488 .49872 m .64283 .4992 L .64278 .49615 L F
.628 .545 .741 r
.40693 .70926 m .4079 .71201 L .41001 .71103 L F
.36 0 0 r
.45273 .70268 m .45139 .70398 L .44916 .70399 L F
.502 .066 .144 r
.45497 .70241 m .45139 .70398 L .45273 .70268 L F
.681 .978 .879 r
.67859 .47348 m .67689 .47482 L .6751 .4751 L F
.556 .393 .615 r
.39769 .66619 m .40004 .66826 L .39988 .66577 L F
.39769 .66619 m .3978 .66876 L .40004 .66826 L F
.526 .204 .364 r
.35281 .61178 m .35527 .61165 L .356 .6097 L F
.454 .231 .485 r
.356 .6097 m .35801 .60923 L .35834 .60699 L F
.563 .308 .488 r
.35527 .61165 m .35801 .60923 L .356 .6097 L F
.524 .571 .845 r
.56524 .71963 m .56598 .71638 L .56396 .71648 L F
.56524 .71963 m .56737 .71935 L .56598 .71638 L F
.836 .37 0 r
.48427 .80097 m .48341 .79837 L .48383 .79785 L F
.56 .165 .25 r
.44633 .66296 m .44272 .66484 L .4441 .66307 L F
.479 .08 .206 r
.27955 .58855 m .28325 .58634 L .2805 .58733 L F
.28 .51 .898 r
.65242 .51386 m .65403 .51271 L .6518 .5122 L F
.65242 .51386 m .65525 .51549 L .65403 .51271 L F
.224 .36 .792 r
.74681 .49092 m .74943 .49276 L .74784 .49375 L F
.435 .408 .731 r
.74943 .49276 m .74771 .49589 L .74784 .49375 L F
.506 .353 .608 r
.57799 .61787 m .57809 .6203 L .57583 .62151 L F
.525 .381 .627 r
.57809 .6203 m .57624 .62215 L .57583 .62151 L F
.366 .534 .89 r
.53414 .61942 m .53477 .62107 L .53599 .61959 L F
.249 .36 .781 r
.53477 .62107 m .53717 .62292 L .53599 .61959 L F
.993 .743 .414 r
.49428 .77981 m .49342 .78181 L .49312 .78135 L F
.353 0 0 r
.44225 .69727 m .4445 .69726 L .44564 .69655 L F
.171 .702 .699 r
.4445 .69726 m .44787 .69647 L .44564 .69655 L F
.797 .999 .815 r
.47805 .63168 m .47984 .62899 L .48086 .62975 L F
.47805 .63168 m .4773 .63162 L .47984 .62899 L F
.49 .262 .495 r
.35834 .60699 m .36022 .6087 L .36057 .60648 L F
.35834 .60699 m .35801 .60923 L .36022 .6087 L F
.706 .843 .948 r
.47702 .79495 m .47638 .79617 L .47468 .79515 L F
.223 0 0 r
.44044 .64966 m .44233 .64987 L .44387 .64896 L F
.413 0 .053 r
.44233 .64987 m .44591 .6481 L .44387 .64896 L F
.866 .829 .809 r
.4935 .80976 m .49569 .80716 L .4936 .80662 L F
.513 .534 .815 r
.49569 .80716 m .49911 .80951 L .4991 .80734 L F
.346 0 .05 r
.62986 .49051 m .62959 .49076 L .63209 .49001 L F
.998 .847 .52 r
.73435 .49146 m .73328 .4923 L .73359 .48977 L F
.73435 .49146 m .73402 .49325 L .73328 .4923 L F
.375 .747 .99 r
.31662 .58445 m .32053 .58523 L .31823 .58543 L F
0 .318 .797 r
.67533 .51564 m .6722 .51305 L .67303 .51433 L F
.377 .417 .776 r
.67409 .51632 m .67533 .51564 L .67303 .51433 L F
.593 .251 .359 r
.50765 .80151 m .51185 .80132 L .512 .79945 L F
.58 .24 .358 r
.512 .79945 m .51185 .80132 L .51411 .8009 L F
.962 .942 .656 r
.62985 .56772 m .63122 .56444 L .63054 .564 L F
.445 .423 .74 r
.25939 .61249 m .26038 .60875 L .25827 .60925 L F
.25939 .61249 m .26113 .61187 L .26038 .60875 L F
.408 .273 .584 r
.25942 .61492 m .26113 .61187 L .25939 .61249 L F
.767 .497 .526 r
.58552 .69638 m .58875 .69446 L .58768 .69393 L F
.58552 .69638 m .58927 .69673 L .58875 .69446 L F
.762 .754 .846 r
.70105 .51008 m .70446 .51058 L .7036 .50763 L F
.796 .69 .748 r
.70105 .51008 m .70224 .51338 L .70446 .51058 L F
.726 .734 .857 r
.7036 .50763 m .70446 .51058 L .70701 .50819 L F
.651 .467 .622 r
.54455 .73643 m .54802 .73895 L .54769 .73691 L F
.719 .648 .778 r
.70009 .50076 m .69645 .49874 L .6986 .49873 L F
.678 .662 .827 r
.70213 .49958 m .70009 .50076 L .6986 .49873 L F
.644 .937 .965 r
.68427 .49298 m .68254 .49372 L .6835 .49392 L F
.68481 .49231 m .68319 .49332 L .68427 .49298 L F
.68319 .49332 m .68254 .49372 L .68427 .49298 L F
.757 .66 .754 r
.68129 .48953 m .68269 .4926 L .67999 .49117 L F
.68269 .4926 m .68295 .49316 L .68259 .49292 L F
.68269 .4926 m .68259 .49292 L .67999 .49117 L F
.67999 .49117 m .68304 .49337 L .67901 .4924 L F
.68295 .49316 m .68304 .49337 L .67999 .49117 L F
.965 .934 .63 r
.68259 .49292 m .68242 .4935 L .68254 .49372 L F
.68259 .49292 m .68254 .49372 L .68319 .49332 L F
.757 .66 .754 r
.68304 .49337 m .68266 .49348 L .67901 .4924 L F
.311 .693 .978 r
.68254 .49372 m .67901 .4924 L .68244 .49342 L F
.68254 .49372 m .68244 .49342 L .68316 .49363 L F
.965 .934 .63 r
.68243 .49338 m .6819 .4926 L .68242 .4935 L F
.68295 .49316 m .68319 .49332 L .68481 .49231 L F
.587 .578 .81 r
.68481 .49231 m .68316 .49363 L .68295 .49316 L F
.68481 .49231 m .68295 .49316 L .68129 .48953 L F
.965 .934 .63 r
.68259 .49292 m .68295 .49316 L .68481 .49231 L F
.587 .578 .81 r
.68481 .49231 m .68129 .48953 L .68276 .49048 L F
.965 .934 .63 r
.68276 .49048 m .68205 .49221 L .68243 .49338 L F
.68205 .49221 m .6819 .4926 L .68243 .49338 L F
.68276 .49048 m .68242 .4935 L .68259 .49292 L F
.68276 .49048 m .68259 .49292 L .68481 .49231 L F
.757 .66 .754 r
.68304 .49337 m .68316 .49363 L .68266 .49348 L F
.29 .772 .918 r
.68254 .49372 m .68316 .49363 L .6835 .49392 L F
.666 .974 .872 r
.6835 .49392 m .68316 .49363 L .68481 .49231 L F
.804 .715 .767 r
.66326 .47826 m .66236 .48016 L .65877 .47924 L F
.891 .587 .081 r
.66236 .48016 m .66155 .479 L .65877 .47924 L F
.482 .225 .446 r
.66236 .48016 m .66258 .48185 L .66023 .48242 L F
.891 .587 .081 r
.66236 .48016 m .66258 .48185 L .66155 .479 L F
.485 .338 .606 r
.66483 .47912 m .66236 .48016 L .66326 .47826 L F
.404 .172 .445 r
.66483 .47912 m .66258 .48185 L .66236 .48016 L F
.375 .075 .321 r
.36253 .6265 m .36168 .62904 L .3598 .62913 L F
.472 .164 .362 r
.36404 .62792 m .36253 .6265 L .36468 .62605 L F
.36404 .62792 m .36168 .62904 L .36253 .6265 L F
.348 .224 .565 r
.42364 .68451 m .42172 .68322 L .42364 .68231 L F
.42364 .68451 m .42174 .6856 L .42172 .68322 L F
.489 .488 .782 r
.40476 .70075 m .4064 .69895 L .404 .69944 L F
.564 .5 .742 r
.39483 .68011 m .39781 .68294 L .39694 .6796 L F
.102 0 0 r
.52076 .69144 m .52156 .69231 L .52212 .69085 L F
.52076 .69144 m .51955 .69315 L .52156 .69231 L F
.918 .611 .131 r
.5827 .69444 m .58306 .69655 L .58213 .69363 L F
.254 .753 .897 r
.48392 .79524 m .48609 .79519 L .48601 .79526 L F
.48609 .79519 m .48894 .79512 L .48601 .79526 L F
.48392 .79524 m .48601 .79526 L .48611 .79272 L F
.447 .744 .991 r
.4855 .79415 m .48601 .79526 L .48392 .79524 L F
.815 .512 0 r
.48588 .79538 m .48601 .79526 L .4855 .79415 L F
.584 .357 .537 r
.48392 .79524 m .48601 .79526 L .48651 .79743 L F
.815 .512 0 r
.48651 .79743 m .48601 .79526 L .48588 .79538 L F
.96 .881 .711 r
.48894 .79512 m .48651 .79743 L .48601 .79526 L F
.48894 .79512 m .48757 .79836 L .48663 .79754 L F
.48838 .79566 m .48663 .79754 L .48651 .79743 L F
.48894 .79512 m .48663 .79754 L .48838 .79566 L F
.786 .512 .523 r
.48601 .79526 m .48849 .79554 L .48768 .79286 L F
.48849 .79554 m .48969 .79568 L .48911 .79487 L F
.48849 .79554 m .48911 .79487 L .48768 .79286 L F
.321 .206 .562 r
.60446 .58965 m .60638 .58894 L .6061 .58653 L F
.214 0 .309 r
.60407 .59197 m .60638 .58894 L .60446 .58965 L F
.541 .242 .41 r
.60153 .59217 m .60407 .59197 L .60446 .58965 L F
.719 .684 .816 r
.56476 .59557 m .56836 .596 L .56629 .59331 L F
.802 .69 .742 r
.56836 .596 m .56939 .59251 L .56629 .59331 L F
.494 .766 .992 r
.76854 .59381 m .76766 .59564 L .76583 .5919 L F
.76854 .59381 m .76981 .59532 L .76766 .59564 L F
.621 .549 .752 r
.77095 .59755 m .76766 .59564 L .76981 .59532 L F
.521 .081 .143 r
.47853 .64655 m .47726 .64821 L .47528 .6483 L F
.726 .709 .834 r
.25025 .62874 m .25167 .63153 L .2542 .62962 L F
.321 0 .094 r
.57349 .70342 m .57571 .70308 L .57589 .70115 L F
.57349 .70342 m .57271 .70447 L .57571 .70308 L F
.096 0 .09 r
.53079 .77881 m .53003 .7809 L .52877 .78118 L F
0 0 .457 r
.53163 .77783 m .53079 .77881 L .53087 .77602 L F
0 0 0 r
.53163 .77783 m .53003 .7809 L .53079 .77881 L F
.741 .837 .924 r
.66793 .5048 m .66891 .50614 L .67096 .50492 L F
0 .028 .58 r
.30257 .64957 m .30224 .64829 L .30162 .64808 L F
.072 .542 .899 r
.30257 .64957 m .30497 .65012 L .30224 .64829 L F
.503 .266 .487 r
.39151 .70545 m .39374 .70522 L .3946 .70298 L F
.763 .838 .909 r
.70973 .46579 m .70678 .46561 L .70865 .46452 L F
.681 .757 .908 r
.71241 .46492 m .70973 .46579 L .70865 .46452 L F
.891 .742 .691 r
.64488 .49872 m .64322 .50082 L .64283 .4992 L F
.412 .457 .797 r
.52511 .77923 m .52778 .77883 L .52406 .77626 L F
0 0 .193 r
.5256 .78187 m .52778 .77883 L .52511 .77923 L F
.479 .08 .206 r
.27955 .58855 m .28175 .58849 L .28325 .58634 L F
.422 .027 .183 r
.28175 .58849 m .28544 .58604 L .28325 .58634 L F
.452 .824 .992 r
.69147 .47653 m .69039 .47584 L .68795 .47625 L F
.586 .888 .99 r
.69272 .47497 m .69147 .47653 L .69391 .47598 L F
.69272 .47497 m .69039 .47584 L .69147 .47653 L F
.612 .631 .845 r
.69147 .47653 m .69466 .47779 L .69391 .47598 L F
0 .04 .607 r
.51451 .63731 m .51625 .63979 L .51577 .64055 L F
.135 .548 .923 r
.51625 .63979 m .5177 .64101 L .51577 .64055 L F
.64 .309 .396 r
.53449 .77254 m .53813 .7705 L .53435 .7704 L F
.53449 .77254 m .53713 .77281 L .53813 .7705 L F
.704 .379 .425 r
.53713 .77281 m .54036 .7729 L .53813 .7705 L F
.49 .37 .644 r
.59903 .55264 m .59935 .55555 L .59703 .55613 L F
.249 .004 .334 r
.59935 .55555 m .59748 .55744 L .59703 .55613 L F
.648 .335 .427 r
.59632 .59744 m .59401 .59591 L .59358 .59765 L F
.913 .839 .758 r
.73195 .50644 m .73311 .50769 L .7314 .51072 L F
.761 .522 .571 r
.57002 .64633 m .56662 .64852 L .56644 .64656 L F
.57002 .64633 m .56999 .64889 L .56662 .64852 L F
.655 .434 .571 r
.57258 .64839 m .57002 .64633 L .57254 .64645 L F
.57258 .64839 m .56999 .64889 L .57002 .64633 L F
.689 .51 .639 r
.40693 .70926 m .41001 .71103 L .41 .70852 L F
.667 .563 .729 r
.40889 .70514 m .41 .70852 L .4126 .70782 L F
.778 .878 .92 r
.41001 .71103 m .4126 .70782 L .41 .70852 L F
.702 .747 .887 r
.65525 .51549 m .65606 .51648 L .65858 .51508 L F
.737 .45 .494 r
.26465 .64901 m .26144 .65079 L .26121 .64887 L F
.26465 .64901 m .26434 .65137 L .26144 .65079 L F
.642 .363 .48 r
.26465 .64901 m .26672 .65137 L .26434 .65137 L F
.504 .726 .972 r
.26464 .63184 m .26666 .6323 L .26501 .63109 L F
.26464 .63184 m .26666 .6323 L .26501 .63109 L F
.605 .757 .951 r
.26501 .63109 m .26666 .6323 L .26882 .63127 L F
.459 0 .022 r
.51168 .70231 m .51001 .70354 L .50821 .70286 L F
.273 0 0 r
.51391 .70224 m .51001 .70354 L .51168 .70231 L F
.455 0 0 r
.49305 .70017 m .49222 .70086 L .48966 .6998 L F
.682 .228 .168 r
.49542 .70106 m .49222 .70086 L .49305 .70017 L F
.533 .538 .806 r
.39955 .6907 m .40093 .69439 L .40286 .69376 L F
.665 .55 .714 r
.40093 .69439 m .40414 .69698 L .40286 .69376 L F
.40093 .69439 m .4016 .69738 L .40414 .69698 L F
.626 .206 .227 r
.48838 .69596 m .49169 .6947 L .48872 .69463 L F
.48838 .69596 m .49061 .6964 L .49169 .6947 L F
.615 .194 .22 r
.49169 .6947 m .49061 .6964 L .49422 .69617 L F
.386 0 0 r
.49169 .6947 m .49422 .69617 L .49561 .69689 L F
.62 .342 .474 r
.61249 .54452 m .61144 .54671 L .60911 .54689 L F
.626 .299 .397 r
.61459 .54511 m .61144 .54671 L .61249 .54452 L F
.506 .043 .089 r
.46691 .70048 m .46542 .70206 L .46297 .70186 L F
.29 0 0 r
.46914 .70014 m .46542 .70206 L .46691 .70048 L F
.339 .487 .861 r
.4016 .69738 m .404 .69944 L .40414 .69698 L F
.69 .331 .36 r
.4502 .66279 m .4485 .66494 L .44633 .66296 L F
.764 .54 .594 r
.4521 .66279 m .4485 .66494 L .4502 .66279 L F
.499 .315 .562 r
.2981 .61743 m .29586 .61998 L .2962 .61809 L F
.253 .762 .86 r
.51303 .77286 m .51375 .77255 L .51525 .7726 L F
0 .209 .722 r
.51303 .77286 m .51506 .77569 L .51375 .77255 L F
.063 0 0 r
.34252 .64161 m .34203 .64065 L .34403 .63991 L F
.34252 .64161 m .34061 .64248 L .34203 .64065 L F
.756 .814 .898 r
.69782 .46817 m .69587 .47048 L .69532 .46852 L F
.853 .485 .354 r
.56173 .75031 m .56235 .75228 L .56349 .75054 L F
.912 .577 .396 r
.56235 .75228 m .56394 .75303 L .56349 .75054 L F
.982 .832 .617 r
.65568 .48816 m .65449 .48341 L .65783 .4857 L F
.757 .304 .175 r
.58415 .59981 m .58359 .59792 L .58244 .59743 L F
.58415 .59981 m .58547 .59989 L .58359 .59792 L F
.823 .668 .69 r
.54802 .73895 m .54835 .74166 L .55111 .7396 L F
.96 .734 .286 r
.73332 .49938 m .73278 .50057 L .73331 .49816 L F
.73332 .49938 m .73344 .50212 L .73278 .50057 L F
.109 0 .364 r
.6063 .58422 m .6081 .58307 L .60772 .58107 L F
.044 0 .332 r
.6061 .58653 m .6081 .58307 L .6063 .58422 L F
.885 .906 .837 r
.5488 .63202 m .54678 .63501 L .54558 .63412 L F
.378 0 0 r
.68795 .47625 m .68488 .47667 L .68553 .4767 L F
.309 0 0 r
.26844 .59189 m .27074 .59152 L .2721 .59005 L F
.13 0 0 r
.2721 .59005 m .27261 .5909 L .27422 .58973 L F
.2721 .59005 m .27074 .59152 L .27261 .5909 L F
0 0 0 r
.47046 .63581 m .47081 .63564 L .47266 .63498 L F
.47046 .63581 m .46913 .63687 L .47081 .63564 L F
.2 0 0 r
.65449 .48341 m .65341 .48372 L .65456 .48272 L F
0 0 0 r
.65575 .4829 m .65483 .48478 L .65538 .48389 L F
.65601 .48218 m .65575 .4829 L .65678 .4819 L F
.757 .705 .802 r
.66023 .48242 m .6591 .48353 L .65678 .4819 L F
0 .067 .627 r
.65678 .4819 m .65847 .48468 L .66023 .48242 L F
.65678 .4819 m .65885 .48425 L .65847 .48468 L F
0 .129 .675 r
.6583 .48249 m .65885 .48425 L .65678 .4819 L F
.6583 .48249 m .65678 .4819 L .65575 .4829 L F
.588 .695 .916 r
.65732 .48075 m .6583 .48249 L .65575 .4829 L F
0 0 0 r
.65575 .4829 m .65538 .48389 L .65732 .48075 L F
.65456 .48272 m .65575 .4829 L .65601 .48218 L F
.65456 .48272 m .65341 .48372 L .65575 .4829 L F
.697 .717 .864 r
.71729 .51377 m .71862 .51023 L .71633 .51125 L F
.71729 .51377 m .71964 .51328 L .71862 .51023 L F
.313 .695 .979 r
.64645 .4876 m .6485 .48772 L .6497 .48865 L F
.697 .867 .962 r
.71984 .49349 m .72167 .49386 L .71976 .49309 L F
.379 0 .136 r
.60065 .59377 m .59915 .59263 L .59881 .59466 L F
.60065 .59377 m .60153 .59217 L .59915 .59263 L F
.198 0 0 r
.33336 .62862 m .33255 .62927 L .33554 .62825 L F
.786 .797 .862 r
.74011 .48303 m .7364 .48408 L .73887 .48148 L F
.716 .73 .862 r
.74266 .48193 m .74011 .48303 L .73887 .48148 L F
0 0 .148 r
.70767 .48005 m .70944 .47624 L .70727 .47578 L F
.70767 .48005 m .70856 .47923 L .70944 .47624 L F
.70944 .47624 m .70856 .47923 L .70767 .48005 L F
.26 .75 .917 r
.70944 .47624 m .71115 .47595 L .70727 .47578 L F
.868 .823 .801 r
.26892 .64835 m .26672 .65137 L .26909 .65152 L F
.801 .882 .904 r
.48869 .62561 m .48532 .62638 L .48735 .62493 L F
.696 .891 .969 r
.48869 .62561 m .48998 .62366 L .49079 .6247 L F
.48869 .62561 m .48735 .62493 L .48998 .62366 L F
.62 .209 .243 r
.25402 .62672 m .25602 .62769 L .25706 .62703 L F
.25706 .62703 m .25602 .62769 L .25402 .62672 L F
.344 .461 .836 r
.25402 .62672 m .25602 .62769 L .25462 .62515 L F
.524 .393 .645 r
.25402 .62672 m .2542 .62962 L .25602 .62769 L F
.25402 .62672 m .2542 .62962 L .25602 .62769 L F
.681 .498 .632 r
.42832 .67448 m .42615 .67705 L .42572 .67445 L F
.42832 .67448 m .42808 .67662 L .42615 .67705 L F
.383 .237 .556 r
.43061 .67619 m .42832 .67448 L .43026 .67359 L F
.43061 .67619 m .42808 .67662 L .42832 .67448 L F
.495 .773 .994 r
.69466 .47779 m .69552 .47668 L .69391 .47598 L F
.69466 .47779 m .6971 .4775 L .69552 .47668 L F
.9 .736 .669 r
.59573 .70499 m .59698 .70785 L .59738 .70556 L F
.804 .715 .767 r
.66326 .47826 m .65877 .47924 L .66176 .47685 L F
.796 .761 .82 r
.66458 .47649 m .66326 .47826 L .66176 .47685 L F
.485 .338 .606 r
.66483 .47912 m .66326 .47826 L .66458 .47649 L F
.39 .207 .509 r
.50518 .80252 m .50611 .80375 L .50614 .80139 L F
.50518 .80252 m .50452 .80446 L .50611 .80375 L F
.972 .877 .681 r
.65587 .50232 m .65504 .5048 L .65399 .50345 L F
.492 .415 .697 r
.56089 .71335 m .56297 .71303 L .56248 .71095 L F
.415 .014 .167 r
.53029 .69455 m .52928 .69657 L .5268 .69684 L F
.257 0 .092 r
.53144 .69584 m .53029 .69455 L .53234 .69373 L F
.53144 .69584 m .52928 .69657 L .53029 .69455 L F
.903 .833 .767 r
.56304 .77178 m .56537 .77097 L .56481 .76916 L F
.56304 .77178 m .5643 .77299 L .56537 .77097 L F
.404 .167 .438 r
.56644 .64656 m .56662 .64852 L .56453 .64894 L F
.56644 .64656 m .56662 .64852 L .56453 .64894 L F
.493 .854 .99 r
.53777 .7592 m .5414 .75921 L .53993 .75851 L F
.433 0 0 r
.53777 .7592 m .5414 .75921 L .54051 .75951 L F
.476 .846 .989 r
.54235 .75807 m .5414 .75921 L .53993 .75851 L F
.578 .938 .799 r
.54051 .75951 m .5414 .75921 L .54235 .75807 L F
.565 .628 .873 r
.72496 .47301 m .72346 .47534 L .72253 .47364 L F
.72496 .47301 m .72669 .47598 L .72346 .47534 L F
.407 .442 .785 r
.47566 .78187 m .47834 .78309 L .47744 .78088 L F
.681 .775 .922 r
.48219 .81285 m .48487 .81303 L .48465 .81154 L F
.75 .642 .74 r
.48314 .81509 m .48487 .81303 L .48219 .81285 L F
.584 .401 .599 r
.48314 .81509 m .48556 .81569 L .48487 .81303 L F
.711 .796 .917 r
.48465 .81154 m .48487 .81303 L .48721 .81092 L F
.963 .833 .668 r
.63284 .55451 m .63482 .55298 L .63381 .55179 L F
.63284 .55451 m .634 .55537 L .63482 .55298 L F
.211 0 0 r
.51166 .78711 m .51545 .78607 L .51393 .78688 L F
.683 .241 .195 r
.51545 .78607 m .51763 .78706 L .51393 .78688 L F
.824 .607 .609 r
.5927 .702 m .59573 .70499 L .59415 .70221 L F
.506 .319 .562 r
.26124 .59792 m .26352 .59486 L .2615 .59545 L F
.516 .409 .671 r
.57375 .626 m .5748 .63054 L .57172 .62957 L F
.506 .424 .697 r
.5748 .63054 m .57435 .6313 L .57172 .62957 L F
.521 .42 .681 r
.57172 .62957 m .57435 .6313 L .57234 .63186 L F
.569 .118 .14 r
.45586 .69558 m .4582 .69599 L .45958 .69441 L F
.315 0 0 r
.4582 .69599 m .4618 .69427 L .45958 .69441 L F
.555 .431 .666 r
.57452 .64315 m .57487 .64612 L .57254 .64645 L F
.384 .115 .378 r
.57487 .64612 m .57258 .64839 L .57254 .64645 L F
.839 .873 .432 r
.66318 .50696 m .66196 .50921 L .66192 .51004 L F
.043 0 0 r
.66486 .50686 m .66318 .50696 L .66524 .50732 L F
.66486 .50686 m .66196 .50921 L .66318 .50696 L F
.296 .75 .956 r
.3603 .60362 m .35854 .60293 L .35633 .60303 L F
.506 .858 .992 r
.36068 .60235 m .3603 .60362 L .36259 .60336 L F
.36068 .60235 m .35854 .60293 L .3603 .60362 L F
.482 .298 .554 r
.36057 .60648 m .36259 .60336 L .3603 .60362 L F
.651 .467 .622 r
.54455 .73643 m .54619 .73978 L .54802 .73895 L F
.512 .578 .859 r
.40889 .70514 m .40947 .70182 L .4078 .70417 L F
.40889 .70514 m .41104 .70484 L .40947 .70182 L F
.667 .563 .729 r
.40889 .70514 m .4126 .70782 L .41104 .70484 L F
.721 .987 .877 r
.38751 .69593 m .38662 .69746 L .38589 .6973 L F
.38751 .69593 m .38662 .69746 L .38589 .6973 L F
.63 .455 .628 r
.38612 .70036 m .38809 .69816 L .38662 .69746 L F
.996 .855 .524 r
.38662 .69746 m .38612 .70036 L .38589 .6973 L F
.354 .818 .919 r
.47965 .81539 m .48314 .81509 L .48219 .81285 L F
.722 .192 0 r
.5548 .6466 m .55358 .64619 L .55169 .64446 L F
0 .376 .778 r
.5548 .6466 m .55642 .64696 L .55358 .64619 L F
.706 .509 .62 r
.59606 .60666 m .59648 .60908 L .59378 .60915 L F
.63 .418 .577 r
.59606 .60666 m .59852 .60922 L .59648 .60908 L F
.59606 .60666 m .59928 .60658 L .59852 .60922 L F
.523 .413 .671 r
.25774 .607 m .25941 .60321 L .25758 .60381 L F
0 0 0 r
.49066 .7864 m .49356 .78447 L .49305 .7866 L F
.454 .432 .744 r
.49614 .78412 m .49356 .78447 L .4931 .78163 L F
.34 .014 .257 r
.49305 .7866 m .49356 .78447 L .49614 .78412 L F
.6 .381 .556 r
.54769 .62651 m .54762 .62904 L .54506 .62918 L F
.104 0 0 r
.5215 .69877 m .51813 .70104 L .51955 .69931 L F
.889 .728 .676 r
.67198 .47998 m .67197 .48313 L .66931 .48172 L F
.996 .863 .564 r
.67197 .48313 m .67072 .48292 L .66931 .48172 L F
.67197 .48313 m .67132 .48436 L .67072 .48292 L F
.293 0 .192 r
.67453 .48243 m .67132 .48436 L .67197 .48313 L F
.044 0 0 r
.38657 .70201 m .39029 .70006 L .38809 .69816 L F
.618 .426 .6 r
.58805 .60981 m .59053 .61182 L .58808 .61194 L F
.58805 .60981 m .5905 .60973 L .59053 .61182 L F
.728 .63 .749 r
.57428 .63776 m .5713 .63802 L .57308 .63567 L F
.688 .518 .652 r
.57428 .63776 m .57092 .63994 L .5713 .63802 L F
.57428 .63776 m .57349 .63974 L .57092 .63994 L F
.426 .303 .608 r
.57567 .63459 m .57428 .63776 L .57308 .63567 L F
.57567 .63459 m .576 .6374 L .57428 .63776 L F
.03 0 .085 r
.576 .6374 m .57349 .63974 L .57428 .63776 L F
0 .279 .696 r
.66995 .51182 m .67114 .51231 L .67083 .50952 L F
.66995 .51182 m .6722 .51305 L .67114 .51231 L F
.824 .649 .665 r
.73249 .51632 m .72901 .51828 L .729 .51589 L F
.73249 .51632 m .73282 .51892 L .72901 .51828 L F
.869 .86 .829 r
.56167 .77543 m .56282 .77406 L .56147 .77315 L F
.808 .868 .892 r
.56282 .77406 m .5643 .77299 L .56147 .77315 L F
.347 .505 .873 r
.38028 .59512 m .37998 .59724 L .37815 .5953 L F
.38028 .59512 m .38174 .59769 L .37998 .59724 L F
.613 .426 .605 r
.52187 .65324 m .52374 .65186 L .52178 .65308 L F
.648 .743 .919 r
.57443 .72429 m .57778 .72485 L .57712 .72252 L F
.802 .801 .851 r
.57712 .72252 m .57778 .72485 L .5803 .72241 L F
.004 0 0 r
.54179 .77738 m .54506 .7761 L .54408 .77762 L F
.525 .286 .495 r
.54506 .7761 m .54572 .77749 L .54408 .77762 L F
.54506 .7761 m .54738 .77577 L .54572 .77749 L F
.889 .728 .676 r
.67198 .47998 m .66947 .48162 L .66892 .47913 L F
.66947 .48162 m .66927 .48143 L .66892 .47913 L F
.136 .386 .839 r
.66931 .48172 m .66702 .47931 L .66892 .47913 L F
.094 .394 .851 r
.66705 .47929 m .66991 .48046 L .6685 .47841 L F
.66702 .47931 m .66711 .47934 L .66705 .47929 L F
.66711 .47934 m .66991 .48046 L .66705 .47929 L F
.889 .728 .676 r
.66947 .48162 m .66931 .48172 L .66927 .48143 L F
.716 .552 .666 r
.73649 .51914 m .73396 .52182 L .73282 .51892 L F
.182 .362 .808 r
.7348 .51581 m .73732 .51758 L .73649 .51914 L F
.601 .038 0 r
.73721 .52054 m .73875 .52068 L .73649 .51914 L F
.73721 .52054 m .73649 .51914 L .73732 .51758 L F
.869 .86 .829 r
.56167 .77543 m .56147 .77315 L .55862 .77579 L F
.822 .688 .716 r
.55862 .77579 m .56023 .77887 L .56167 .77543 L F
0 0 0 r
.48755 .69864 m .48496 .7008 L .48615 .69972 L F
.48496 .7008 m .48482 .70091 L .48615 .69972 L F
.505 0 0 r
.48672 .6992 m .48615 .69972 L .48389 .69927 L F
.48754 .69918 m .48615 .69972 L .48672 .6992 L F
.585 .09 .045 r
.48966 .6998 m .48615 .69972 L .48754 .69918 L F
.948 .589 .252 r
.6634 .49233 m .66479 .49372 L .66307 .4932 L F
.572 .025 0 r
.56724 .70513 m .56993 .70655 L .57107 .70577 L F
.69 .368 .425 r
.56993 .70655 m .57271 .70447 L .57107 .70577 L F
.613 .426 .605 r
.52187 .65324 m .52386 .65457 L .52374 .65186 L F
.52374 .65186 m .52386 .65457 L .52187 .65324 L F
.786 .525 .542 r
.49578 .81303 m .4935 .80976 L .49404 .81254 L F
.988 .722 .409 r
.6557 .48892 m .65575 .49046 L .65568 .48816 L F
.495 .301 .547 r
.60085 .53334 m .60309 .53273 L .6031 .53044 L F
.459 .214 .454 r
.60085 .53334 m .60063 .53534 L .60309 .53273 L F
.172 .692 .882 r
.34129 .60074 m .33761 .60045 L .33917 .60095 L F
.892 .826 .776 r
.56359 .59511 m .56422 .59832 L .56476 .59557 L F
.56359 .59511 m .56124 .5979 L .56422 .59832 L F
.892 .825 .774 r
.56124 .5979 m .56237 .60087 L .56422 .59832 L F
.686 .503 .633 r
.56422 .59832 m .56237 .60087 L .56589 .60035 L F
.574 .38 .581 r
.49911 .80951 m .5015 .80699 L .4991 .80734 L F
.436 0 .085 r
.4331 .70744 m .42906 .70983 L .43004 .70882 L F
.4331 .70744 m .43131 .70977 L .42906 .70983 L F
.26 0 0 r
.43297 .70932 m .4331 .70744 L .43526 .70741 L F
.43297 .70932 m .43131 .70977 L .4331 .70744 L F
.792 .689 .751 r
.54738 .77577 m .5486 .77894 L .54572 .77749 L F
.805 .344 .14 r
.54572 .77749 m .5486 .77894 L .54761 .78006 L F
.934 .564 .174 r
.5495 .78758 m .55107 .79023 L .55028 .79007 L F
.991 .743 .378 r
.55028 .79007 m .5511 .79275 L .55107 .79023 L F
.549 .581 .839 r
.54963 .77585 m .5486 .77894 L .54738 .77577 L F
.54963 .77585 m .55115 .7794 L .5486 .77894 L F
.517 .014 0 r
.5486 .77894 m .55034 .78067 L .54761 .78006 L F
.5486 .77894 m .55115 .7794 L .55034 .78067 L F
.934 .564 .174 r
.5495 .78758 m .55107 .79023 L .55028 .79007 L F
.991 .743 .378 r
.55028 .79007 m .5511 .79275 L .55107 .79023 L F
.705 .198 .027 r
.48106 .69336 m .47873 .69177 L .4789 .69315 L F
.901 .759 .263 r
.55705 .75564 m .55659 .75866 L .55693 .75582 L F
.294 .14 .494 r
.63639 .50712 m .63822 .50502 L .63559 .50485 L F
.63639 .50712 m .63805 .50628 L .63822 .50502 L F
.601 .706 .917 r
.645 .50831 m .64677 .50627 L .6445 .50654 L F
.645 .50831 m .64816 .5077 L .64677 .50627 L F
.587 .481 .7 r
.645 .50831 m .6455 .51035 L .64816 .5077 L F
.189 .219 .662 r
.49854 .6977 m .49561 .69689 L .49422 .69617 L F
.448 .219 .473 r
.59318 .53899 m .59528 .53837 L .59533 .53621 L F
.514 .236 .43 r
.59528 .53837 m .59822 .53552 L .59533 .53621 L F
.763 .389 .348 r
.50048 .79235 m .50359 .7925 L .50153 .79014 L F
.684 .404 .493 r
.50359 .7925 m .50373 .79035 L .50153 .79014 L F
.712 .503 .604 r
.69517 .51264 m .69538 .51479 L .69707 .51219 L F
.471 .513 .82 r
.69707 .51219 m .69766 .50962 L .69517 .51264 L F
.69707 .51219 m .69858 .5132 L .69766 .50962 L F
.775 .497 .514 r
.69538 .51479 m .69856 .51541 L .69707 .51219 L F
.878 .624 .551 r
.69856 .51541 m .69858 .5132 L .69707 .51219 L F
0 0 .132 r
.6139 .5953 m .61374 .59733 L .61202 .59822 L F
0 0 0 r
.61374 .59733 m .61159 .60034 L .61202 .59822 L F
.943 .783 .322 r
.72739 .49377 m .72677 .49502 L .72715 .49603 L F
.987 .878 .533 r
.72739 .49377 m .72742 .49067 L .72666 .4927 L F
.972 .719 .296 r
.72666 .4927 m .72677 .49502 L .72739 .49377 L F
.894 .718 .655 r
.73736 .52471 m .73458 .52627 L .73413 .52369 L F
.73736 .52471 m .73727 .52759 L .73458 .52627 L F
.762 .605 .683 r
.73736 .52471 m .73856 .52843 L .73727 .52759 L F
.4 .51 .855 r
.73892 .52288 m .73921 .52492 L .73736 .52471 L F
.687 .564 .711 r
.74079 .52749 m .73736 .52471 L .73921 .52492 L F
.74079 .52749 m .73856 .52843 L .73736 .52471 L F
.375 .734 .99 r
.36383 .58962 m .36325 .59065 L .36181 .58978 L F
.36383 .58962 m .36539 .59062 L .36325 .59065 L F
.456 .24 .495 r
.51073 .78563 m .51404 .78452 L .51425 .78161 L F
.568 .453 .683 r
.51166 .78711 m .51404 .78452 L .51073 .78563 L F
.85 .695 .689 r
.71016 .48961 m .71186 .49133 L .71351 .48814 L F
.936 .639 .175 r
.71246 .49006 m .71351 .48814 L .71186 .49133 L F
.802 .564 .578 r
.71351 .48814 m .71246 .49006 L .71016 .48961 L F
.918 .909 .797 r
.71375 .48731 m .71246 .49006 L .71118 .48976 L F
.71246 .49006 m .71186 .49133 L .71159 .49071 L F
.802 .564 .578 r
.71246 .49006 m .71159 .49071 L .71016 .48961 L F
.918 .909 .797 r
.71246 .49006 m .71159 .49071 L .71118 .48976 L F
.802 .564 .578 r
.71246 .49006 m .71195 .49099 L .71159 .49071 L F
.215 .505 .907 r
.71159 .49071 m .71186 .49133 L .71016 .48961 L F
.802 .564 .578 r
.71195 .49099 m .7113 .49218 L .71016 .48961 L F
.215 .505 .907 r
.71118 .48976 m .71159 .49071 L .71056 .48992 L F
.71118 .48976 m .71056 .48992 L .71016 .48961 L F
.802 .564 .578 r
.71351 .48814 m .71144 .4925 L .7113 .49218 L F
.333 .336 .713 r
.71016 .48961 m .71144 .4925 L .71118 .48976 L F
.993 .812 .558 r
.71043 .49135 m .71144 .4925 L .71041 .49139 L F
.71118 .48976 m .71127 .49064 L .71043 .49135 L F
.71127 .49064 m .71144 .4925 L .71043 .49135 L F
.552 .189 .306 r
.7147 .49133 m .71144 .4925 L .71351 .48814 L F
.7147 .49133 m .71426 .49255 L .71144 .4925 L F
.302 0 0 r
.71426 .49255 m .71372 .49297 L .71158 .49252 L F
.71153 .4925 m .71158 .49252 L .71144 .4925 L F
.71426 .49255 m .71158 .49252 L .71153 .4925 L F
.722 .322 .291 r
.71158 .49252 m .71041 .49139 L .71144 .4925 L F
.71372 .49297 m .71041 .49139 L .71158 .49252 L F
.71339 .49281 m .71285 .49338 L .71041 .49139 L F
.71372 .49297 m .71285 .49338 L .71339 .49281 L F
.626 .582 .784 r
.71405 .49649 m .71278 .49345 L .71285 .49338 L F
.71269 .49323 m .71205 .49171 L .71285 .49338 L F
0 .135 .623 r
.71271 .49325 m .71285 .49338 L .71271 .49325 L F
.71261 .49318 m .71285 .49338 L .71271 .49325 L F
.626 .582 .784 r
.71278 .49345 m .71269 .49323 L .71285 .49338 L F
.538 .505 .766 r
.71091 .49172 m .70815 .49474 L .70743 .49175 L F
.71205 .49171 m .71145 .49217 L .71091 .49172 L F
.71145 .49217 m .71169 .49735 L .70815 .49474 L F
.71205 .49171 m .71199 .49263 L .71145 .49217 L F
0 .135 .623 r
.71202 .49265 m .71145 .49217 L .71091 .49172 L F
.626 .582 .784 r
.71269 .49323 m .71199 .49263 L .71205 .49171 L F
0 .135 .623 r
.71214 .49275 m .71199 .49263 L .71202 .49265 L F
.71199 .49263 m .71145 .49217 L .71202 .49265 L F
.626 .582 .784 r
.71405 .49649 m .71169 .49735 L .71199 .49263 L F
.71405 .49649 m .71199 .49263 L .71269 .49323 L F
0 .135 .623 r
.71041 .49139 m .71261 .49318 L .71228 .49286 L F
.538 .505 .766 r
.71199 .49263 m .71169 .49735 L .71145 .49217 L F
0 .135 .623 r
.71041 .49139 m .71214 .49275 L .71091 .49172 L F
.71214 .49275 m .71228 .49286 L .71145 .49217 L F
.71045 .49141 m .71091 .49172 L .71072 .49156 L F
.71041 .49139 m .71091 .49172 L .71045 .49141 L F
.375 0 0 r
.70943 .49219 m .71114 .49188 L .70998 .49173 L F
.71114 .49188 m .71205 .49171 L .71091 .49172 L F
.71114 .49188 m .71091 .49172 L .70998 .49173 L F
.538 .505 .766 r
.71145 .49217 m .70815 .49474 L .71091 .49172 L F
.682 .754 .906 r
.70815 .49474 m .70559 .49504 L .70743 .49175 L F
.375 0 0 r
.70756 .49254 m .70987 .49268 L .71135 .49202 L F
.71114 .49188 m .71135 .49202 L .71205 .49171 L F
.70756 .49254 m .71135 .49202 L .71114 .49188 L F
0 .135 .623 r
.71072 .49156 m .71087 .49169 L .71126 .49186 L F
.971 .685 .429 r
.71126 .49186 m .71205 .49171 L .71135 .49202 L F
0 .135 .623 r
.71087 .49169 m .71142 .49215 L .71135 .49202 L F
.71087 .49169 m .71159 .49219 L .71126 .49186 L F
.971 .685 .429 r
.71126 .49186 m .71135 .49202 L .70987 .49268 L F
0 .135 .623 r
.71135 .49202 m .71228 .49286 L .71159 .49219 L F
.71142 .49215 m .71228 .49286 L .71135 .49202 L F
.71261 .49318 m .71271 .49325 L .71126 .49186 L F
.375 0 0 r
.70756 .49254 m .70943 .49219 L .70743 .49175 L F
.70943 .49219 m .70998 .49173 L .70743 .49175 L F
.993 .812 .558 r
.71118 .48976 m .71041 .49139 L .71197 .48956 L F
.71118 .48976 m .71197 .48956 L .71281 .48857 L F
.936 .639 .175 r
.71375 .48731 m .71351 .48814 L .71246 .49006 L F
.71375 .48731 m .7147 .49133 L .71351 .48814 L F
.445 .789 .998 r
.34739 .59958 m .35105 .60023 L .34933 .59946 L F
.162 .545 .927 r
.35105 .60023 m .35146 .59932 L .34933 .59946 L F
.35105 .60023 m .35271 .60056 L .35146 .59932 L F
.993 .874 .594 r
.6547 .49898 m .65478 .49558 L .65484 .49668 L F
.918 .935 .802 r
.6547 .49898 m .65589 .49507 L .65484 .49668 L F
.026 0 0 r
.44836 .64683 m .45003 .64675 L .45197 .64625 L F
.392 .847 .784 r
.45197 .64625 m .45295 .64559 L .45398 .64498 L F
.45197 .64625 m .45003 .64675 L .45295 .64559 L F
.009 0 .068 r
.61643 .59242 m .6161 .59423 L .6139 .5953 L F
.072 0 .155 r
.61523 .59606 m .6139 .5953 L .6161 .59423 L F
.61523 .59606 m .61374 .59733 L .6139 .5953 L F
.419 .483 .819 r
.47782 .76728 m .47909 .77046 L .47771 .7677 L F
0 0 .445 r
.48006 .7669 m .47909 .77046 L .47782 .76728 L F
.48006 .7669 m .48027 .76962 L .47909 .77046 L F
.146 .321 .783 r
.48027 .76962 m .48147 .77246 L .47909 .77046 L F
.496 0 0 r
.52546 .68893 m .52759 .68981 L .52886 .68854 L F
.607 .147 .136 r
.52759 .68981 m .5312 .68895 L .52886 .68854 L F
.626 .299 .397 r
.61459 .54511 m .61504 .5467 L .61144 .54671 L F
.865 .662 .625 r
.56453 .64894 m .56398 .65172 L .56125 .65071 L F
.613 .487 .685 r
.56662 .64852 m .56398 .65172 L .56453 .64894 L F
.521 .574 .849 r
.52015 .80941 m .52113 .80675 L .51855 .80907 L F
.52015 .80941 m .52243 .80976 L .52113 .80675 L F
.722 .568 .68 r
.56182 .63754 m .56291 .64072 L .55971 .64045 L F
.546 .383 .611 r
.56398 .63479 m .56379 .63688 L .56182 .63754 L F
.691 .552 .691 r
.56522 .64044 m .56182 .63754 L .56379 .63688 L F
.56522 .64044 m .56291 .64072 L .56182 .63754 L F
.838 .961 .888 r
.47834 .78309 m .48137 .78165 L .47967 .78169 L F
.822 .995 .857 r
.4813 .78003 m .47967 .78169 L .48137 .78165 L F
.735 .66 .776 r
.69858 .5132 m .70224 .51338 L .70105 .51008 L F
.743 .592 .688 r
.69858 .5132 m .70025 .5163 L .70224 .51338 L F
.828 .842 .858 r
.56147 .77315 m .5643 .77299 L .56304 .77178 L F
.89 .69 .625 r
.61892 .55252 m .61667 .55257 L .61765 .54939 L F
.838 .687 .695 r
.61892 .55252 m .61573 .55466 L .61667 .55257 L F
.61892 .55252 m .61759 .55581 L .61573 .55466 L F
.407 .091 .315 r
.57571 .70308 m .57792 .70057 L .57589 .70115 L F
.57571 .70308 m .57753 .70257 L .57792 .70057 L F
.506 .205 .39 r
.57792 .70057 m .58053 .70127 L .58084 .69942 L F
.681 .42 .521 r
.57773 .70389 m .57792 .70057 L .57753 .70257 L F
.57773 .70389 m .58053 .70127 L .57792 .70057 L F
.248 .545 .927 r
.37508 .5937 m .37679 .59403 L .37614 .59519 L F
.336 .656 .971 r
.37679 .59403 m .37815 .5953 L .37614 .59519 L F
.962 .942 .656 r
.62985 .56772 m .63054 .564 L .62976 .56568 L F
.949 .957 .696 r
.6288 .56946 m .62985 .56772 L .62976 .56568 L F
.692 .759 .903 r
.68765 .52808 m .69106 .5293 L .68989 .52708 L F
.636 .73 .916 r
.68989 .52708 m .69106 .5293 L .69355 .52801 L F
.924 .715 .601 r
.5676 .60315 m .56926 .60434 L .56807 .60075 L F
0 0 .379 r
.5676 .60315 m .56706 .60693 L .56926 .60434 L F
.698 .542 .672 r
.56706 .60693 m .56998 .60687 L .56926 .60434 L F
.584 .543 .775 r
.56807 .60075 m .56926 .60434 L .57146 .60338 L F
.489 .317 .574 r
.56926 .60434 m .57168 .60593 L .57146 .60338 L F
.38 .345 .695 r
.56998 .60687 m .57168 .60593 L .56926 .60434 L F
.476 .617 .911 r
.31738 .63012 m .31651 .63195 L .31469 .62971 L F
.31738 .63012 m .31844 .63177 L .31651 .63195 L F
.522 .047 .069 r
.42023 .65624 m .42293 .65636 L .42438 .65496 L F
.548 .125 .192 r
.42293 .65636 m .42685 .65477 L .42438 .65496 L F
.853 .532 .445 r
.55876 .74954 m .5612 .74813 L .55896 .74704 L F
.55876 .74954 m .56173 .75031 L .5612 .74813 L F
.279 .142 .509 r
.47642 .76951 m .47778 .76976 L .47782 .76728 L F
.696 .565 .703 r
.47642 .76951 m .48012 .77267 L .47778 .76976 L F
.553 .356 .569 r
.34848 .6203 m .35084 .61749 L .34871 .61801 L F
.459 .762 .995 r
.68725 .50159 m .68788 .50251 L .68485 .50181 L F
.561 .73 .954 r
.68956 .5007 m .68788 .50251 L .68725 .50159 L F
.68956 .5007 m .69051 .50215 L .68788 .50251 L F
.108 .189 .667 r
.72856 .47797 m .72739 .47953 L .72669 .47598 L F
.242 .22 .633 r
.56707 .60921 m .56874 .60691 L .56706 .60693 L F
0 0 0 r
.57829 .57845 m .57775 .58003 L .57599 .58129 L F
0 0 .082 r
.57775 .58003 m .57685 .58404 L .57599 .58129 L F
0 .213 .726 r
.65885 .48425 m .66107 .48676 L .65847 .48468 L F
.335 0 0 r
.51375 .77255 m .51769 .77322 L .51525 .7726 L F
.658 .55 .721 r
.54825 .7696 m .55098 .76994 L .55 .76598 L F
.55098 .76994 m .55162 .77002 L .55124 .76908 L F
.55098 .76994 m .55124 .76908 L .55 .76598 L F
.226 .298 .729 r
.55187 .76696 m .55149 .76994 L .55252 .76792 L F
.55177 .76681 m .55171 .76751 L .55187 .76696 L F
.55171 .76751 m .55149 .76994 L .55187 .76696 L F
0 0 0 r
.57825 .59298 m .57551 .59565 L .57729 .59402 L F
.702 .248 .17 r
.57729 .59402 m .5805 .59454 L .57825 .59298 L F
.71 .716 .854 r
.70701 .50819 m .71019 .50908 L .70927 .50714 L F
.557 .657 .902 r
.71019 .50908 m .71151 .5068 L .70927 .50714 L F
.71019 .50908 m .71314 .50942 L .71151 .5068 L F
.54 .875 .991 r
.6915 .49484 m .69198 .49452 L .69452 .49505 L F
.326 .514 .887 r
.69663 .49399 m .69452 .49505 L .69198 .49452 L F
.69663 .49399 m .69743 .49577 L .69452 .49505 L F
.703 .513 .629 r
.58568 .61232 m .58574 .61492 L .58364 .6148 L F
.637 .473 .644 r
.58808 .61194 m .58574 .61492 L .58568 .61232 L F
.988 .727 .361 r
.73282 .51892 m .73273 .52184 L .73163 .52035 L F
.918 .63 .483 r
.73282 .51892 m .73396 .52182 L .73273 .52184 L F
0 0 .502 r
.73163 .52035 m .73273 .52184 L .73354 .52277 L F
.954 .66 .223 r
.73396 .52182 m .73354 .52277 L .73273 .52184 L F
0 0 .502 r
.73163 .52035 m .73354 .52277 L .73415 .52176 L F
.631 .194 .192 r
.73163 .52035 m .73415 .52176 L .73281 .5224 L F
.73163 .52035 m .73281 .5224 L .73283 .52222 L F
.73163 .52035 m .73283 .52222 L .73327 .51817 L F
.988 .727 .361 r
.73045 .51852 m .73163 .52035 L .72901 .51828 L F
.73282 .51892 m .73163 .52035 L .73045 .51852 L F
0 .417 .695 r
.29955 .58329 m .30148 .5838 L .30306 .58423 L F
.016 .584 .781 r
.30148 .5838 m .30508 .58418 L .30306 .58423 L F
.693 .682 .835 r
.71202 .50178 m .70819 .49971 L .71033 .4986 L F
.424 .539 .869 r
.7126 .49911 m .71202 .50178 L .71033 .4986 L F
.7126 .49911 m .71379 .50161 L .71202 .50178 L F
.669 .737 .901 r
.68413 .52733 m .68499 .52968 L .68765 .52808 L F
.602 .662 .881 r
.52374 .65186 m .52725 .65167 L .52526 .64918 L F
.766 .545 .599 r
.52728 .65471 m .52386 .65457 L .52374 .65186 L F
.506 .343 .595 r
.52374 .65186 m .52625 .65396 L .52725 .65167 L F
.52374 .65186 m .52386 .65457 L .52625 .65396 L F
.795 .578 .607 r
.54348 .7422 m .54377 .74565 L .53998 .74433 L F
.54348 .7422 m .53998 .74433 L .54231 .74478 L F
.555 .428 .662 r
.54348 .7422 m .54575 .7418 L .54619 .73978 L F
.282 0 .131 r
.54348 .7422 m .54472 .74372 L .54575 .7418 L F
.54348 .7422 m .54231 .74478 L .54472 .74372 L F
.372 .043 .272 r
.62952 .49271 m .63209 .49001 L .62959 .49076 L F
.709 .658 .797 r
.70345 .4789 m .70767 .48005 L .70535 .47604 L F
.488 .155 .328 r
.70463 .48162 m .70767 .48005 L .70345 .4789 L F
.70463 .48162 m .70648 .4819 L .70767 .48005 L F
.505 .433 .709 r
.70767 .48005 m .70648 .4819 L .70463 .48162 L F
0 0 .148 r
.70767 .48005 m .70727 .47578 L .70535 .47604 L F
.653 .561 .738 r
.70931 .48034 m .70767 .48005 L .70856 .47923 L F
0 0 0 r
.70767 .48005 m .70843 .47948 L .70856 .47923 L F
.70767 .48005 m .70648 .4819 L .70843 .47948 L F
.34 0 .203 r
.34572 .62226 m .34848 .6203 L .34636 .62081 L F
.617 .636 .847 r
.71964 .51328 m .72094 .5093 L .71862 .51023 L F
.71964 .51328 m .72375 .51323 L .72094 .5093 L F
.784 .68 .75 r
.69409 .50227 m .69051 .50215 L .69292 .4988 L F
.747 .662 .766 r
.69645 .49874 m .69409 .50227 L .69292 .4988 L F
.576 .101 .089 r
.47231 .69996 m .47097 .70139 L .46914 .70014 L F
.303 0 0 r
.47434 .70111 m .47097 .70139 L .47231 .69996 L F
.521 .077 .136 r
.47485 .70014 m .47434 .70111 L .47231 .69996 L F
.796 .974 .908 r
.2449 .64984 m .24337 .65053 L .24592 .64864 L F
.281 0 .029 r
.54299 .68836 m .53957 .69056 L .54057 .68869 L F
.553 .394 .62 r
.54273 .6856 m .54057 .68869 L .5399 .68603 L F
.54273 .6856 m .54299 .68836 L .54057 .68869 L F
.943 .944 .616 r
.49149 .65201 m .49243 .64809 L .49393 .64922 L F
.717 .947 .649 r
.4923 .65052 m .49149 .65201 L .49393 .64922 L F
.8 .392 .278 r
.49475 .65078 m .4923 .65052 L .49393 .64922 L F
.226 .728 .904 r
.49462 .64873 m .49393 .64922 L .49243 .64809 L F
.49462 .64873 m .49614 .64886 L .49393 .64922 L F
.301 .202 .572 r
.49614 .64886 m .49475 .65078 L .49393 .64922 L F
.598 .284 .409 r
.48557 .65176 m .48497 .654 L .48188 .6542 L F
.615 .18 .192 r
.48812 .65231 m .48772 .65441 L .48557 .65176 L F
.48772 .65441 m .48757 .65518 L .4871 .65437 L F
.48772 .65441 m .4871 .65437 L .48557 .65176 L F
0 .283 .707 r
.48432 .65002 m .48809 .65207 L .48812 .65231 L F
.713 .983 .897 r
.49084 .65144 m .49074 .65151 L .49149 .65201 L F
.49093 .65163 m .4904 .65205 L .49149 .65201 L F
.864 .761 .747 r
.49102 .6516 m .49056 .6518 L .48874 .65016 L F
.713 .983 .897 r
.49074 .65151 m .49056 .6518 L .49093 .65163 L F
.49056 .6518 m .4904 .65205 L .49093 .65163 L F
.864 .761 .747 r
.49243 .64809 m .49102 .6516 L .48874 .65016 L F
.49102 .6516 m .49084 .65205 L .49056 .6518 L F
.943 .944 .616 r
.49149 .65201 m .49084 .65205 L .49102 .6516 L F
.49149 .65201 m .49102 .6516 L .49243 .64809 L F
.713 .983 .897 r
.4923 .65052 m .49084 .65144 L .49149 .65201 L F
0 0 0 r
.48812 .65231 m .49056 .6518 L .4904 .65205 L F
.713 .983 .897 r
.49074 .65151 m .48985 .65207 L .4904 .65205 L F
0 0 0 r
.48812 .65231 m .48874 .65016 L .49056 .6518 L F
.4904 .65205 m .49056 .6518 L .49079 .652 L F
.152 0 .091 r
.4904 .65205 m .48812 .65231 L .49149 .65201 L F
0 0 0 r
.48812 .65231 m .49079 .652 L .49084 .65205 L F
.152 0 .091 r
.48985 .65207 m .48812 .65231 L .4904 .65205 L F
.673 .377 .463 r
.48868 .65245 m .48985 .65207 L .48802 .65202 L F
0 .283 .707 r
.48809 .65207 m .48821 .65213 L .4882 .65214 L F
.48809 .65207 m .4882 .65214 L .48812 .65231 L F
.673 .377 .463 r
.48802 .65202 m .48985 .65207 L .48925 .65104 L F
.079 .639 .719 r
.48812 .65231 m .49084 .65205 L .49149 .65201 L F
.152 0 .091 r
.48985 .65207 m .48757 .65518 L .48812 .65231 L F
.611 .111 .039 r
.48295 .6507 m .48796 .65206 L .48432 .65002 L F
.673 .377 .463 r
.48664 .65312 m .48868 .65245 L .48809 .65207 L F
.611 .111 .039 r
.48796 .65206 m .48821 .65213 L .48809 .65207 L F
.48796 .65206 m .48809 .65207 L .48432 .65002 L F
.673 .377 .463 r
.48796 .65206 m .48809 .65207 L .48802 .65202 L F
.48664 .65312 m .48809 .65207 L .48796 .65206 L F
.704 .485 .589 r
.48606 .65155 m .48664 .65312 L .48796 .65206 L F
0 0 0 r
.48812 .65231 m .4882 .65214 L .48874 .65016 L F
.673 .377 .463 r
.48829 .6518 m .48925 .65104 L .48874 .65016 L F
0 0 0 r
.4882 .65214 m .48821 .65213 L .48874 .65016 L F
.673 .377 .463 r
.48664 .65312 m .48829 .6518 L .48874 .65016 L F
.704 .485 .589 r
.48796 .65206 m .48664 .65312 L .48821 .65213 L F
0 0 .458 r
.48557 .65176 m .4871 .65437 L .48664 .65312 L F
.48557 .65176 m .48664 .65312 L .48497 .654 L F
.704 .485 .589 r
.48295 .6507 m .48664 .65312 L .48606 .65155 L F
0 0 .458 r
.4871 .65437 m .4871 .65437 L .48664 .65312 L F
.4871 .65437 m .48757 .65518 L .48664 .65312 L F
.712 .52 .628 r
.48313 .65346 m .48346 .65413 L .48664 .65312 L F
.582 .309 .468 r
.48497 .654 m .48402 .65789 L .48188 .6542 L F
.48497 .654 m .48541 .65812 L .48402 .65789 L F
.244 .076 .444 r
.48664 .65312 m .48541 .65812 L .48497 .654 L F
.712 .52 .628 r
.48346 .65413 m .48541 .65812 L .48634 .65432 L F
.48346 .65413 m .48634 .65432 L .48664 .65312 L F
.297 .148 .503 r
.6031 .53044 m .60483 .53155 L .6048 .52946 L F
.6031 .53044 m .60309 .53273 L .60483 .53155 L F
.525 .341 .574 r
.55971 .64045 m .5595 .64296 L .55717 .64337 L F
.309 .013 .289 r
.30989 .60558 m .30767 .60647 L .3103 .60393 L F
.407 .093 .318 r
.3124 .6034 m .30989 .60558 L .3103 .60393 L F
.475 0 0 r
.5312 .68895 m .53326 .68984 L .53463 .68897 L F
.577 .398 .602 r
.53705 .68958 m .53498 .69132 L .53463 .68897 L F
.035 0 0 r
.53463 .68897 m .53538 .68935 L .53705 .68958 L F
.53463 .68897 m .53326 .68984 L .53538 .68935 L F
.326 .376 .761 r
.47808 .77697 m .47835 .77537 L .47789 .7747 L F
0 0 .481 r
.47703 .77342 m .47789 .7747 L .48012 .77267 L F
.212 0 0 r
.47789 .7747 m .48147 .77246 L .48012 .77267 L F
.47789 .7747 m .48059 .77406 L .48147 .77246 L F
.465 .831 .993 r
.47789 .7747 m .47863 .77363 L .48059 .77406 L F
.326 .376 .761 r
.47835 .77537 m .47863 .77363 L .47789 .7747 L F
0 0 .481 r
.47656 .77353 m .47789 .7747 L .47703 .77342 L F
.47656 .77353 m .47695 .77591 L .47789 .7747 L F
.592 .809 .983 r
.51506 .77569 m .51855 .77615 L .51697 .77746 L F
0 0 0 r
.52008 .77559 m .51855 .77615 L .5205 .77493 L F
.51697 .77746 m .51855 .77615 L .52008 .77559 L F
.57 .38 .584 r
.58121 .61741 m .57809 .6203 L .57799 .61787 L F
.889 .916 .836 r
.54398 .59566 m .54166 .59864 L .54054 .59777 L F
.814 .658 .689 r
.56564 .63803 m .56522 .64044 L .56379 .63688 L F
.9 .736 .669 r
.59573 .70499 m .59437 .70762 L .59698 .70785 L F
.913 .756 .673 r
.59399 .71007 m .59698 .70785 L .59437 .70762 L F
.59399 .71007 m .5956 .71094 L .59698 .70785 L F
.654 .389 .506 r
.60677 .54739 m .60673 .54956 L .60319 .54975 L F
.73 .559 .659 r
.60911 .54689 m .60673 .54956 L .60677 .54739 L F
.36 0 .169 r
.61083 .51735 m .61336 .51677 L .61291 .51486 L F
.273 .166 .546 r
.61291 .51486 m .61558 .51449 L .61543 .51212 L F
.197 0 .194 r
.61291 .51486 m .61336 .51677 L .61558 .51449 L F
.965 .861 .687 r
.72692 .50241 m .72524 .50312 L .72627 .50417 L F
.782 .961 .924 r
.73009 .49919 m .72692 .50241 L .72682 .50137 L F
.73009 .49919 m .72623 .50166 L .72692 .50241 L F
.923 .964 .782 r
.72623 .50166 m .72524 .50312 L .72692 .50241 L F
.425 .267 .562 r
.39668 .67719 m .3985 .67419 L .39649 .67486 L F
.683 .48 .605 r
.50359 .7925 m .50639 .79005 L .50373 .79035 L F
.489 .298 .547 r
.35084 .61749 m .35305 .6146 L .35098 .61513 L F
.086 0 .081 r
.35669 .63148 m .35422 .63392 L .35498 .63259 L F
0 0 .381 r
.67083 .52769 m .67083 .52381 L .67227 .52472 L F
.847 .838 .837 r
.67468 .52187 m .67227 .52472 L .67083 .52381 L F
0 0 0 r
.60772 .52479 m .60553 .52765 L .60681 .52623 L F
.34 .196 .535 r
.6048 .52946 m .60681 .52623 L .60553 .52765 L F
0 0 .474 r
.39034 .60527 m .38938 .60366 L .39178 .6028 L F
.802 .708 .761 r
.58371 .71105 m .58155 .71419 L .58393 .71309 L F
0 0 .181 r
.60772 .58107 m .60938 .57984 L .6101 .5777 L F
.22 .097 .491 r
.6081 .58307 m .60938 .57984 L .60772 .58107 L F
.44 .203 .457 r
.57624 .62215 m .57556 .62523 L .57375 .626 L F
.525 .381 .627 r
.57809 .6203 m .57841 .62342 L .57624 .62215 L F
.687 .515 .649 r
.57841 .62342 m .57556 .62523 L .57624 .62215 L F
.774 .644 .718 r
.48757 .79836 m .49096 .79875 L .48969 .79568 L F
.614 .605 .818 r
.49096 .79875 m .49225 .7951 L .48969 .79568 L F
.49096 .79875 m .49379 .79878 L .49225 .7951 L F
.569 .218 .334 r
.49096 .79875 m .49379 .79878 L .49275 .8005 L F
.49096 .79875 m .49379 .79878 L .49275 .8005 L F
0 0 0 r
.61915 .58979 m .61837 .59168 L .61643 .59242 L F
0 0 .057 r
.61761 .59299 m .61643 .59242 L .61837 .59168 L F
.61761 .59299 m .6161 .59423 L .61643 .59242 L F
.418 .205 .482 r
.30025 .61233 m .30008 .6146 L .29817 .61519 L F
.32 .116 .439 r
.30008 .6146 m .2981 .61743 L .29817 .61519 L F
.559 .368 .579 r
.55746 .62917 m .55709 .63159 L .55458 .63166 L F
.534 .356 .586 r
.6096 .60092 m .60955 .60319 L .60732 .60369 L F
.229 0 .137 r
.60955 .60319 m .60687 .60589 L .60732 .60369 L F
.592 .255 .368 r
.60732 .60369 m .60687 .60589 L .60408 .60588 L F
.686 .479 .601 r
.59129 .60018 m .59358 .59765 L .59142 .59827 L F
.501 .254 .471 r
.30294 .61049 m .30279 .61212 L .30025 .61233 L F
.351 .152 .464 r
.30179 .61389 m .30025 .61233 L .30279 .61212 L F
.30179 .61389 m .30008 .6146 L .30025 .61233 L F
0 0 0 r
.49478 .64081 m .49369 .64278 L .49269 .64369 L F
.292 0 .094 r
.49618 .642 m .49478 .64081 L .49692 .64049 L F
.49618 .642 m .49369 .64278 L .49478 .64081 L F
0 .08 .632 r
.47371 .80902 m .47587 .81224 L .47435 .80879 L F
.049 .19 .691 r
.47572 .81243 m .47607 .81302 L .47587 .81224 L F
.752 .834 .914 r
.47607 .81302 m .47832 .81234 L .47587 .81224 L F
.884 .918 .843 r
.47832 .81234 m .4748 .81444 L .47587 .81224 L F
0 0 0 r
.47614 .81186 m .47587 .81224 L .4748 .81444 L F
.47648 .8112 m .47587 .81224 L .47614 .81186 L F
.049 .19 .691 r
.47371 .80902 m .47572 .81243 L .47587 .81224 L F
.461 .434 .742 r
.39887 .68567 m .39934 .68852 L .40109 .68796 L F
.426 .326 .638 r
.39934 .68852 m .40143 .69048 L .40109 .68796 L F
.453 .327 .618 r
.39955 .6907 m .40143 .69048 L .39934 .68852 L F
.476 .205 .422 r
.38208 .60957 m .38164 .61155 L .37945 .61201 L F
.474 .202 .421 r
.38379 .61102 m .38208 .60957 L .38436 .60934 L F
.38379 .61102 m .38164 .61155 L .38208 .60957 L F
.797 .941 .921 r
.48264 .62829 m .48086 .62975 L .47984 .62899 L F
.749 .632 .731 r
.64387 .51134 m .64315 .51316 L .6455 .51035 L F
.316 .049 .342 r
.47786 .68798 m .47505 .69078 L .47602 .68874 L F
.47786 .68798 m .47505 .69078 L .47602 .68874 L F
.906 .973 .802 r
.25724 .62581 m .25602 .62769 L .25706 .62703 L F
0 0 0 r
.58057 .57559 m .57965 .57729 L .57829 .57845 L F
.57829 .57845 m .57965 .57729 L .57775 .58003 L F
.526 .503 .773 r
.48748 .78398 m .48857 .78734 L .49066 .7864 L F
0 0 0 r
.53251 .80055 m .53009 .8047 L .53175 .80253 L F
.477 .503 .806 r
.53009 .8047 m .53276 .80557 L .53175 .80253 L F
.604 .042 0 r
.53009 .8047 m .53312 .80609 L .53276 .80557 L F
.635 .913 .981 r
.69243 .47035 m .6902 .47134 L .69156 .46969 L F
.61 .874 .991 r
.6902 .47134 m .68921 .47055 L .69156 .46969 L F
.587 .909 .979 r
.6845 .47201 m .68075 .47244 L .6836 .47118 L F
.59 .863 .994 r
.6836 .47118 m .68688 .47129 L .6845 .47201 L F
.922 .57 .126 r
.52849 .60917 m .52912 .61162 L .52763 .60841 L F
.936 .945 .771 r
.52849 .60917 m .52956 .60528 L .53083 .60616 L F
.52849 .60917 m .52763 .60841 L .52956 .60528 L F
.356 .067 .329 r
.5925 .54287 m .59088 .54164 L .59061 .54386 L F
.5925 .54287 m .59294 .54103 L .59088 .54164 L F
.236 .361 .787 r
.40286 .69376 m .40414 .69698 L .40522 .69561 L F
.218 .333 .768 r
.40414 .69698 m .40533 .69657 L .40522 .69561 L F
.558 .574 .827 r
.404 .69944 m .40533 .69657 L .40414 .69698 L F
.505 .834 .999 r
.52625 .65396 m .52386 .65457 L .52728 .65471 L F
.985 .858 .63 r
.52725 .65167 m .52625 .65396 L .52728 .65471 L F
.263 .459 .864 r
.74142 .52588 m .74079 .52749 L .73921 .52492 L F
.82 .478 .407 r
.74079 .52749 m .74175 .5299 L .74422 .5302 L F
.781 .401 0 r
.74107 .52895 m .74079 .52749 L .74142 .52588 L F
.974 .669 .304 r
.65504 .5048 m .65402 .50521 L .65399 .50345 L F
.65504 .5048 m .65519 .50615 L .65402 .50521 L F
.646 .232 .245 r
.26571 .62062 m .26271 .62039 L .26395 .62122 L F
.479 .497 .798 r
.26395 .62122 m .26642 .62313 L .26571 .62062 L F
.212 0 .135 r
.30851 .60791 m .30767 .60647 L .30989 .60558 L F
.30851 .60791 m .30657 .60887 L .30767 .60647 L F
.726 .68 .805 r
.27064 .63908 m .27162 .64231 L .27385 .63998 L F
.597 .357 .523 r
.51404 .78452 m .51639 .78373 L .51425 .78161 L F
0 .248 .756 r
.4126 .70782 m .41314 .70683 L .41104 .70484 L F
.102 .392 .849 r
.4126 .70782 m .41516 .70941 L .41314 .70683 L F
.19 .418 .852 r
.4126 .70782 m .4148 .70991 L .41516 .70941 L F
.796 .761 .82 r
.66458 .47649 m .66176 .47685 L .66365 .47544 L F
.771 .898 .932 r
.66696 .47518 m .66458 .47649 L .66365 .47544 L F
.696 .657 .807 r
.70819 .49971 m .70558 .50201 L .70451 .49882 L F
.389 .403 .754 r
.48203 .77493 m .48266 .77828 L .48008 .77629 L F
.1 0 .144 r
.3529 .63595 m .35217 .63448 L .35422 .63392 L F
.3529 .63595 m .35129 .63705 L .35217 .63448 L F
.027 0 0 r
.67458 .51026 m .67697 .50956 L .6785 .50862 L F
.918 .978 .747 r
.6785 .50862 m .67697 .50956 L .67888 .50648 L F
.46 .224 .468 r
.59294 .54103 m .59528 .53837 L .59318 .53899 L F
0 0 .172 r
.62062 .58625 m .62043 .58843 L .61915 .58979 L F
0 0 0 r
.61987 .59046 m .61915 .58979 L .62043 .58843 L F
.61987 .59046 m .61837 .59168 L .61915 .58979 L F
.979 .687 .323 r
.73727 .52759 m .73615 .52883 L .73458 .52627 L F
.73727 .52759 m .73735 .53061 L .73615 .52883 L F
.499 .519 .808 r
.49544 .62257 m .49454 .62585 L .49301 .62343 L F
.49544 .62257 m .49673 .62604 L .49454 .62585 L F
.713 .836 .394 r
.58263 .57207 m .58173 .57388 L .58177 .57412 L F
.605 .9 .614 r
.58181 .57437 m .58177 .57412 L .58057 .57559 L F
0 0 0 r
.58057 .57559 m .58177 .57412 L .57965 .57729 L F
.713 .836 .394 r
.58173 .57388 m .5808 .57575 L .58177 .57412 L F
.605 .9 .614 r
.58324 .57295 m .58177 .57412 L .58181 .57437 L F
.872 .89 .844 r
.53325 .60334 m .53083 .60616 L .52956 .60528 L F
.32 .438 .825 r
.48012 .77267 m .48027 .76962 L .47778 .76976 L F
.48012 .77267 m .48147 .77246 L .48027 .76962 L F
.234 .512 .909 r
.66479 .49372 m .66757 .49474 L .66689 .4958 L F
.913 .807 .728 r
.7314 .51072 m .72844 .51277 L .73029 .5097 L F
.7314 .51072 m .73048 .51302 L .72844 .51277 L F
.913 .839 .758 r
.73195 .50644 m .7314 .51072 L .73029 .5097 L F
.889 .916 .836 r
.54398 .59566 m .54054 .59777 L .543 .5952 L F
.801 .992 .878 r
.5456 .59417 m .54398 .59566 L .54471 .59379 L F
.771 .966 .926 r
.54398 .59566 m .543 .5952 L .54471 .59379 L F
.038 .607 .754 r
.32223 .63144 m .32048 .63135 L .32434 .63144 L F
.715 .924 .962 r
.56505 .59385 m .56476 .59557 L .56629 .59331 L F
.56505 .59385 m .56359 .59511 L .56476 .59557 L F
.337 .449 .827 r
.38949 .59853 m .38846 .59902 L .38781 .59843 L F
.38949 .59853 m .39082 .60048 L .38846 .59902 L F
.072 0 0 r
.44128 .70578 m .43969 .70678 L .43748 .70728 L F
.065 0 0 r
.4419 .70628 m .44128 .70578 L .44352 .70541 L F
.4419 .70628 m .43969 .70678 L .44128 .70578 L F
.805 .532 .526 r
.66767 .50208 m .66793 .5048 L .67096 .50492 L F
0 0 .381 r
.6688 .50286 m .66793 .5048 L .66767 .50208 L F
.397 .043 .243 r
.36168 .62904 m .35885 .63096 L .3598 .62913 L F
.329 .081 .379 r
.58827 .54667 m .59061 .54386 L .58868 .54471 L F
.858 .764 .758 r
.69769 .52377 m .69837 .52714 L .69933 .52499 L F
.431 .16 .4 r
.41301 .65759 m .41047 .66015 L .41273 .65967 L F
.454 .014 .112 r
.41473 .65874 m .41301 .65759 L .41273 .65967 L F
.41473 .65874 m .41591 .65702 L .41301 .65759 L F
.605 .564 .782 r
.58371 .71105 m .58002 .70821 L .5845 .70872 L F
.615 .436 .616 r
.5857 .70815 m .58371 .71105 L .5845 .70872 L F
.756 .577 .654 r
.56291 .64072 m .5595 .64296 L .55971 .64045 L F
.56291 .64072 m .56325 .64347 L .5595 .64296 L F
.687 .528 .665 r
.56522 .64044 m .56325 .64347 L .56291 .64072 L F
.527 0 0 r
.42725 .69606 m .42919 .69679 L .43072 .69672 L F
0 .193 .687 r
.43195 .69737 m .43072 .69672 L .42919 .69679 L F
.43195 .69737 m .43285 .69828 L .43072 .69672 L F
.926 .953 .624 r
.61306 .56885 m .61271 .56843 L .61412 .56713 L F
.938 .966 .709 r
.61564 .56409 m .61412 .56713 L .61361 .56638 L F
.964 .931 .613 r
.61412 .56713 m .61271 .56843 L .61361 .56638 L F
.376 .659 .968 r
.3134 .62842 m .31284 .62978 L .31139 .62848 L F
.3134 .62842 m .31469 .62971 L .31284 .62978 L F
.558 .574 .827 r
.404 .69944 m .4064 .69895 L .40533 .69657 L F
.312 0 0 r
.42892 .6542 m .4311 .65385 L .43257 .65217 L F
.448 .051 .194 r
.4311 .65385 m .43471 .65155 L .43257 .65217 L F
.199 .256 .697 r
.52509 .793 m .52571 .79568 L .52715 .79402 L F
.989 .794 .551 r
.52849 .79591 m .52715 .79402 L .52571 .79568 L F
.544 .524 .784 r
.50452 .80446 m .50737 .80711 L .50611 .80375 L F
.503 .338 .591 r
.61576 .50784 m .61797 .50729 L .61782 .50474 L F
.481 .279 .528 r
.61576 .50784 m .61588 .5101 L .61797 .50729 L F
.928 .594 .143 r
.73402 .49325 m .73359 .49473 L .73328 .4923 L F
.73402 .49325 m .73445 .49541 L .73359 .49473 L F
.107 0 0 r
.44691 .70432 m .44572 .70502 L .44352 .70541 L F
.387 0 0 r
.44916 .70399 m .44572 .70502 L .44691 .70432 L F
.071 .622 .828 r
.50821 .70286 m .50665 .70254 L .50469 .70244 L F
.704 .28 .236 r
.51001 .70354 m .50665 .70254 L .50821 .70286 L F
.387 .148 .425 r
.37389 .61972 m .37241 .61844 L .37449 .61791 L F
.37389 .61972 m .372 .6205 L .37241 .61844 L F
.03 0 .085 r
.576 .6374 m .57499 .63978 L .57349 .63974 L F
.594 .49 .705 r
.57692 .64258 m .57349 .63974 L .57499 .63978 L F
.57692 .64258 m .57452 .64315 L .57349 .63974 L F
.79 .637 .691 r
.48049 .65063 m .48188 .6542 L .47854 .65351 L F
.48121 .64958 m .48134 .65049 L .48049 .65063 L F
.48134 .65049 m .48188 .6542 L .48049 .65063 L F
.413 0 0 r
.48074 .65067 m .48432 .65002 L .48399 .65005 L F
.48187 .65041 m .48399 .65005 L .48277 .65019 L F
.48074 .65067 m .48399 .65005 L .48187 .65041 L F
.907 .601 .456 r
.48121 .64958 m .48074 .65067 L .48277 .65019 L F
.34 0 .143 r
.49369 .64278 m .49073 .6445 L .49269 .64369 L F
0 .378 .791 r
.63889 .51064 m .64251 .5125 L .64315 .51316 L F
.929 .93 .785 r
.64251 .5125 m .64152 .51646 L .64315 .51316 L F
.959 .946 .67 r
.64387 .51134 m .64251 .5125 L .64315 .51316 L F
.716 .73 .862 r
.74266 .48193 m .73887 .48148 L .74111 .47929 L F
.486 .586 .88 r
.74302 .47892 m .74266 .48193 L .74111 .47929 L F
.74302 .47892 m .74457 .4817 L .74266 .48193 L F
0 0 .379 r
.5676 .60315 m .56799 .60584 L .56706 .60693 L F
0 0 0 r
.56706 .60693 m .56874 .60691 L .56998 .60687 L F
.217 .457 .875 r
.56799 .60584 m .56874 .60691 L .56706 .60693 L F
.205 0 0 r
.3284 .64656 m .32649 .64758 L .32424 .64783 L F
.075 0 0 r
.33035 .6458 m .32649 .64758 L .3284 .64656 L F
.347 .09 .375 r
.37129 .62224 m .36984 .62099 L .372 .6205 L F
.37129 .62224 m .36939 .62294 L .36984 .62099 L F
.316 .753 .967 r
.34459 .58871 m .34675 .58861 L .34834 .58921 L F
.42 .807 .989 r
.34675 .58861 m .35033 .58888 L .34834 .58921 L F
0 0 0 r
.53724 .79811 m .53546 .79909 L .53373 .80036 L F
.354 0 .139 r
.45876 .6428 m .46108 .64232 L .4622 .64018 L F
.075 0 .002 r
.4622 .64018 m .46289 .64133 L .46422 .63943 L F
.4622 .64018 m .46108 .64232 L .46289 .64133 L F
.399 0 0 r
.31722 .64849 m .3165 .64858 L .31426 .64832 L F
.514 .02 .021 r
.31962 .64835 m .3165 .64858 L .31722 .64849 L F
.367 0 0 r
.50023 .62624 m .50255 .62661 L .50355 .62641 L F
.264 0 0 r
.50255 .62661 m .50594 .62618 L .50355 .62641 L F
.358 .457 .826 r
.49404 .81254 m .49698 .81522 L .49578 .81303 L F
.658 .747 .916 r
.73878 .51339 m .74057 .51387 L .73924 .51353 L F
.066 0 0 r
.73992 .51375 m .73924 .51353 L .74234 .51263 L F
.73879 .51428 m .73924 .51353 L .73992 .51375 L F
.658 .747 .916 r
.73708 .51294 m .73878 .51339 L .73924 .51353 L F
.46 .805 .998 r
.74057 .51387 m .74324 .51352 L .74234 .51263 L F
.703 .581 .716 r
.25771 .64879 m .25941 .65003 L .26121 .64887 L F
.858 .764 .758 r
.69769 .52377 m .69573 .52678 L .69837 .52714 L F
.851 .782 .783 r
.69573 .52678 m .69697 .5293 L .69837 .52714 L F
.447 .43 .748 r
.57657 .5979 m .57729 .59402 L .57551 .59565 L F
.872 .89 .844 r
.53325 .60334 m .52956 .60528 L .53219 .60263 L F
.811 .951 .911 r
.53325 .60334 m .53461 .60059 L .53586 .60128 L F
.53325 .60334 m .53219 .60263 L .53461 .60059 L F
.995 .859 .586 r
.56564 .76402 m .5672 .76124 L .56611 .76078 L F
.56564 .76402 m .56645 .76474 L .5672 .76124 L F
.37 0 0 r
.44068 .6981 m .4445 .69726 L .44225 .69727 L F
.837 .981 .875 r
.66196 .50921 m .66129 .51136 L .66192 .51004 L F
.444 .636 .937 r
.30412 .62579 m .30387 .62784 L .30199 .62593 L F
.30412 .62579 m .30585 .62779 L .30387 .62784 L F
.468 .248 .497 r
.60681 .52623 m .60929 .52345 L .60772 .52479 L F
.013 .103 .613 r
.55652 .76192 m .55753 .76077 L .55659 .75866 L F
0 0 0 r
.5555 .7634 m .55753 .76077 L .55652 .76192 L F
.427 .845 .962 r
.34739 .59958 m .34326 .59981 L .34496 .59994 L F
.807 .611 .637 r
.55031 .75245 m .5535 .75332 L .55399 .75058 L F
.076 .338 .814 r
.55224 .74787 m .55399 .75058 L .55522 .74978 L F
.627 .074 0 r
.55399 .75058 m .55628 .75265 L .55489 .75191 L F
.55399 .75058 m .55489 .75191 L .55522 .74978 L F
.716 .986 .822 r
.67872 .50319 m .67662 .50525 L .67816 .50319 L F
.3 .363 .761 r
.67662 .50525 m .67888 .50648 L .67816 .50319 L F
.072 .407 .86 r
.71134 .48065 m .70931 .48034 L .70856 .47923 L F
.71134 .48065 m .71269 .48241 L .70931 .48034 L F
.804 .692 .741 r
.57435 .6313 m .57347 .63434 L .57234 .63186 L F
.003 .575 .768 r
.67132 .48436 m .66846 .48406 L .66978 .48425 L F
.67132 .48436 m .66846 .48406 L .66978 .48425 L F
.847 .838 .837 r
.67468 .52187 m .67083 .52381 L .67321 .52049 L F
.818 .758 .796 r
.67694 .51899 m .67468 .52187 L .67321 .52049 L F
.583 .407 .609 r
.42615 .67705 m .42615 .6798 L .4238 .68005 L F
.493 .241 .46 r
.42615 .6798 m .42364 .68231 L .4238 .68005 L F
.753 .659 .758 r
.54762 .62904 m .5488 .63202 L .54556 .6317 L F
.885 .906 .837 r
.5488 .63202 m .54558 .63412 L .54556 .6317 L F
.633 .597 .796 r
.5512 .63168 m .5488 .63202 L .54762 .62904 L F
.488 .357 .629 r
.51792 .78454 m .51998 .78703 L .51763 .78706 L F
0 .154 .693 r
.51948 .78615 m .51792 .78454 L .51639 .78373 L F
.51948 .78615 m .51998 .78703 L .51907 .78593 L F
.946 .66 .464 r
.51761 .78805 m .5192 .79051 L .51757 .78991 L F
.51763 .78706 m .51798 .78784 L .51761 .78805 L F
.51798 .78784 m .5192 .79051 L .51761 .78805 L F
.51757 .78991 m .5192 .79051 L .51763 .78706 L F
.728 .27 .162 r
.5161 .78905 m .517 .78845 L .51694 .78842 L F
.516 .78895 m .51694 .78842 L .51393 .78688 L F
.5161 .78905 m .51694 .78842 L .516 .78895 L F
.956 .671 .455 r
.51763 .78706 m .51761 .78805 L .517 .78845 L F
.51763 .78706 m .517 .78845 L .51687 .78805 L F
.946 .66 .464 r
.51757 .78991 m .51763 .78706 L .51998 .78703 L F
.667 .536 .696 r
.51753 .78762 m .51804 .78851 L .51773 .78747 L F
.51804 .78851 m .5182 .78858 L .51755 .78684 L F
.956 .671 .455 r
.51763 .78706 m .51687 .78805 L .51393 .78688 L F
.667 .536 .696 r
.51393 .78688 m .517 .78845 L .51577 .78453 L F
.711 .559 .68 r
.51639 .78373 m .51837 .78903 L .51948 .78615 L F
.51837 .78903 m .51842 .78918 L .51855 .78881 L F
.51837 .78903 m .51855 .78881 L .51948 .78615 L F
0 0 0 r
.51975 .78734 m .51832 .78906 L .51998 .78703 L F
.51936 .78787 m .51869 .78864 L .51975 .78734 L F
.51869 .78864 m .51832 .78906 L .51975 .78734 L F
.51832 .78906 m .51757 .78991 L .51835 .78898 L F
.51832 .78906 m .51835 .78898 L .51998 .78703 L F
.956 .671 .455 r
.51761 .78805 m .51757 .78991 L .5161 .78905 L F
.728 .27 .162 r
.5161 .78905 m .51827 .78917 L .517 .78845 L F
.51827 .78917 m .51842 .78918 L .5183 .78912 L F
0 0 0 r
.51783 .78966 m .51757 .78991 L .51862 .78872 L F
.51848 .7889 m .51862 .78872 L .51936 .78787 L F
.51783 .78966 m .51862 .78872 L .51848 .7889 L F
.667 .536 .696 r
.517 .78845 m .5183 .78912 L .51577 .78453 L F
.5183 .78912 m .51835 .78905 L .51577 .78453 L F
.51804 .78851 m .51842 .78918 L .5182 .78858 L F
.861 .731 .718 r
.51948 .78615 m .51855 .78881 L .5161 .78905 L F
.667 .536 .696 r
.5183 .78912 m .51842 .78918 L .51835 .78905 L F
.861 .731 .718 r
.51855 .78881 m .51842 .78918 L .51827 .78917 L F
.728 .27 .162 r
.51827 .78917 m .5183 .78912 L .517 .78845 L F
.861 .731 .718 r
.51855 .78881 m .51827 .78917 L .5161 .78905 L F
0 0 0 r
.51863 .78888 m .51783 .78966 L .51936 .78787 L F
.861 .731 .718 r
.51934 .78633 m .5161 .78905 L .51779 .78828 L F
.51948 .78615 m .51895 .7866 L .51934 .78633 L F
.51895 .7866 m .5161 .78905 L .51934 .78633 L F
.667 .536 .696 r
.51715 .78696 m .51753 .78762 L .51755 .78684 L F
.51753 .78762 m .51773 .78747 L .51755 .78684 L F
.956 .671 .455 r
.51687 .78805 m .5161 .78905 L .51393 .78688 L F
.318 0 0 r
.52069 .78678 m .51965 .78623 L .51779 .78828 L F
.51965 .78623 m .51948 .78615 L .51934 .78633 L F
.51965 .78623 m .51934 .78633 L .51779 .78828 L F
.667 .536 .696 r
.51577 .78453 m .51715 .78696 L .51639 .78373 L F
.51715 .78696 m .51755 .78684 L .51639 .78373 L F
.956 .671 .455 r
.51687 .78805 m .517 .78845 L .5161 .78905 L F
.595 .546 .77 r
.522 .78592 m .51998 .78703 L .51948 .78615 L F
.318 0 0 r
.52117 .78653 m .51948 .78615 L .52069 .78678 L F
0 .154 .693 r
.51948 .78615 m .51907 .78593 L .51792 .78454 L F
.403 0 .129 r
.26892 .64835 m .27203 .64731 L .27116 .64908 L F
.005 .517 .861 r
.27116 .64908 m .27091 .64854 L .26892 .64835 L F
.616 .655 .865 r
.27203 .64731 m .27313 .64949 L .27116 .64908 L F
.005 .517 .861 r
.27116 .64908 m .27266 .64937 L .27091 .64854 L F
0 .468 .717 r
.27116 .64908 m .27313 .64949 L .27266 .64937 L F
.819 .379 .194 r
.49312 .78135 m .49481 .78185 L .4931 .78163 L F
.454 .432 .744 r
.49614 .78412 m .4931 .78163 L .49481 .78185 L F
.771 .898 .932 r
.66696 .47518 m .66365 .47544 L .66604 .47458 L F
.054 0 0 r
.66604 .47458 m .66969 .47465 L .66696 .47518 L F
.743 .796 .895 r
.57347 .63434 m .57567 .63459 L .57308 .63567 L F
.736 .769 .88 r
.47832 .81234 m .48219 .81285 L .48038 .81042 L F
.788 .679 .744 r
.47965 .81539 m .48219 .81285 L .47832 .81234 L F
.675 .748 .906 r
.48038 .81042 m .48219 .81285 L .48465 .81154 L F
.766 .669 .756 r
.55666 .7785 m .56023 .77887 L .55862 .77579 L F
.822 .963 .9 r
.77243 .59491 m .77095 .59755 L .76981 .59532 L F
.77243 .59491 m .76968 .59712 L .77095 .59755 L F
.045 .587 .847 r
.4216 .71099 m .4181 .71022 L .41906 .7108 L F
.415 .176 .439 r
.42808 .67662 m .42615 .6798 L .42615 .67705 L F
.802 .801 .851 r
.57712 .72252 m .5803 .72241 L .57871 .72136 L F
.484 .9 .879 r
.56874 .60691 m .57168 .60593 L .56998 .60687 L F
.665 .343 .419 r
.41473 .65874 m .41812 .65672 L .41591 .65702 L F
.224 0 .112 r
.63209 .49001 m .63431 .48972 L .63489 .48798 L F
.213 0 .108 r
.63489 .48798 m .63634 .48891 L .63708 .48682 L F
.63489 .48798 m .63431 .48972 L .63634 .48891 L F
.977 .679 .369 r
.53329 .77179 m .53435 .7704 L .53111 .76999 L F
.53329 .77179 m .53449 .77254 L .53435 .7704 L F
.614 .46 .649 r
.54762 .62904 m .54556 .6317 L .54506 .62918 L F
.103 .64 .858 r
.38384 .5978 m .38532 .59817 L .38174 .59769 L F
.142 .647 .904 r
.38627 .59782 m .38532 .59817 L .38384 .5978 L F
.38627 .59782 m .38781 .59843 L .38532 .59817 L F
.425 .267 .562 r
.39668 .67719 m .39858 .67677 L .3985 .67419 L F
.457 .378 .679 r
.39668 .67719 m .399 .67918 L .39858 .67677 L F
.507 .378 .639 r
.39694 .6796 m .399 .67918 L .39668 .67719 L F
.844 .596 .563 r
.5805 .59454 m .58244 .59743 L .58291 .59544 L F
.593 .857 .994 r
.54273 .6856 m .53967 .68571 L .54146 .68479 L F
.737 .752 .865 r
.54273 .6856 m .5399 .68603 L .53967 .68571 L F
.435 .308 .608 r
.54479 .68746 m .54299 .68836 L .54273 .6856 L F
0 .2 .68 r
.54146 .68479 m .54479 .68746 L .54273 .6856 L F
0 0 0 r
.58517 .54891 m .58618 .54752 L .58367 .55003 L F
.312 0 .124 r
.58517 .54891 m .58827 .54667 L .58618 .54752 L F
.977 .82 .622 r
.63214 .54878 m .63326 .55079 L .63381 .54765 L F
.979 .85 .643 r
.63214 .54878 m .63381 .54765 L .6328 .54655 L F
0 0 0 r
.26121 .64887 m .26193 .64803 L .26314 .64574 L F
.26144 .65079 m .26193 .64803 L .26121 .64887 L F
0 0 .172 r
.61564 .56409 m .61575 .56318 L .61555 .5608 L F
.938 .966 .709 r
.61564 .56409 m .61361 .56638 L .61575 .56318 L F
.868 .987 .715 r
.58363 .57101 m .58324 .57295 L .58526 .56996 L F
.867 .974 .664 r
.58363 .57101 m .58177 .57412 L .58324 .57295 L F
.632 .792 .959 r
.52725 .65167 m .52735 .65221 L .52928 .65206 L F
.139 .636 .91 r
.50096 .79358 m .50505 .79444 L .50359 .7925 L F
.476 .482 .785 r
.50505 .79444 m .50628 .79295 L .50359 .7925 L F
.50505 .79444 m .50686 .79418 L .50628 .79295 L F
.663 .7 .874 r
.57325 .72171 m .57443 .72429 L .57712 .72252 L F
.681 .757 .908 r
.71241 .46492 m .70865 .46452 L .71356 .4639 L F
.468 .784 .998 r
.70762 .46334 m .71249 .4638 L .70865 .46452 L F
.71249 .4638 m .71356 .4639 L .71285 .46399 L F
.71249 .4638 m .71285 .46399 L .70865 .46452 L F
.517 .746 .978 r
.71385 .46319 m .71474 .46457 L .7141 .46467 L F
.71308 .46412 m .7141 .46467 L .71241 .46492 L F
.468 .784 .998 r
.70762 .46334 m .71251 .46273 L .71356 .4639 L F
.517 .746 .978 r
.71385 .46319 m .71241 .46492 L .71356 .4639 L F
.71385 .46319 m .7141 .46467 L .71308 .46412 L F
.506 .882 .681 r
.51257 .69652 m .51365 .69554 L .51541 .69455 L F
.441 .845 .656 r
.51541 .69455 m .51559 .6943 L .51746 .69393 L F
.51541 .69455 m .51365 .69554 L .51559 .6943 L F
.666 .22 .181 r
.50283 .6401 m .49897 .63993 L .50057 .64077 L F
.188 0 .288 r
.61159 .60034 m .60955 .60319 L .6096 .60092 L F
.415 .176 .439 r
.42808 .67662 m .42828 .67955 L .42615 .6798 L F
.426 .183 .44 r
.43033 .67876 m .42808 .67662 L .43061 .67619 L F
.43033 .67876 m .42828 .67955 L .42808 .67662 L F
.372 .043 .272 r
.62952 .49271 m .63175 .49215 L .63209 .49001 L F
.392 .12 .377 r
.63175 .49215 m .63431 .48972 L .63209 .49001 L F
.818 .758 .796 r
.67694 .51899 m .67321 .52049 L .67545 .51807 L F
.385 .646 .96 r
.37309 .5919 m .37244 .59333 L .37109 .59188 L F
.37309 .5919 m .37508 .5937 L .37244 .59333 L F
.523 .413 .671 r
.25774 .607 m .25972 .60664 L .25941 .60321 L F
.554 .487 .734 r
.25827 .60925 m .25972 .60664 L .25774 .607 L F
.727 .358 .352 r
.55125 .74222 m .55512 .74414 L .55503 .74208 L F
.421 .088 .292 r
.43594 .66837 m .43527 .67072 L .43283 .67119 L F
.045 0 .145 r
.43673 .66975 m .43594 .66837 L .43815 .66755 L F
.43673 .66975 m .43527 .67072 L .43594 .66837 L F
.954 .66 .223 r
.73396 .52182 m .73413 .52369 L .73354 .52277 L F
.565 .446 .676 r
.25938 .60084 m .26157 .6004 L .26124 .59792 L F
.517 .339 .578 r
.25941 .60321 m .26157 .6004 L .25938 .60084 L F
0 0 .303 r
.47242 .79546 m .47289 .79875 L .47258 .79731 L F
0 0 .37 r
.47289 .79875 m .47368 .80161 L .47258 .79731 L F
.637 .276 .342 r
.50869 .81098 m .50799 .81255 L .50531 .81238 L F
.50799 .81255 m .50753 .81276 L .50531 .81238 L F
.484 .356 .63 r
.50531 .81238 m .50522 .8148 L .50302 .81303 L F
.598 .033 0 r
.50302 .81303 m .50522 .8148 L .50382 .81425 L F
.652 .495 .659 r
.50531 .81238 m .50787 .81282 L .50522 .8148 L F
.814 .913 .906 r
.50407 .81435 m .50599 .81196 L .50382 .81425 L F
.50522 .8148 m .50553 .81368 L .50407 .81435 L F
.50553 .81368 m .50599 .81196 L .50407 .81435 L F
.637 .276 .342 r
.50799 .81255 m .50787 .81282 L .50753 .81276 L F
.163 0 .376 r
.50869 .81098 m .50989 .81166 L .50965 .81173 L F
.115 0 .094 r
.50869 .81098 m .50965 .81173 L .50787 .81282 L F
.674 .665 .833 r
.70126 .49761 m .70213 .49958 L .6986 .49873 L F
.62 .637 .846 r
.70451 .49882 m .70213 .49958 L .70126 .49761 L F
.79 .582 .62 r
.58499 .69398 m .58552 .69638 L .58768 .69393 L F
.664 .703 .876 r
.67591 .52952 m .67943 .53033 L .67823 .52696 L F
.706 .634 .774 r
.67823 .52696 m .67943 .53033 L .68143 .52812 L F
.508 .406 .674 r
.39848 .67129 m .40004 .66826 L .3978 .66876 L F
.372 .087 .346 r
.37844 .61649 m .37714 .61471 L .37916 .61415 L F
.37844 .61649 m .37654 .61717 L .37714 .61471 L F
.783 .937 .583 r
.55795 .77021 m .55636 .77289 L .55673 .77175 L F
0 0 .55 r
.55673 .77175 m .55636 .77289 L .55772 .77495 L F
.758 .654 .747 r
.5849 .7189 m .586 .7223 L .58824 .71943 L F
.595 .4 .588 r
.50611 .80375 m .50765 .80151 L .50614 .80139 L F
0 0 0 r
.32761 .63162 m .32914 .6311 L .33037 .62983 L F
.05 0 0 r
.33037 .62983 m .33107 .63042 L .33255 .62927 L F
.33037 .62983 m .32914 .6311 L .33107 .63042 L F
.538 .252 .429 r
.57146 .60338 m .57391 .60301 L .57427 .60108 L F
.572 .412 .626 r
.57427 .60108 m .57676 .60056 L .57657 .5979 L F
.592 .348 .516 r
.57391 .60301 m .57676 .60056 L .57427 .60108 L F
.548 .367 .588 r
.62247 .49924 m .62493 .4987 L .62467 .4965 L F
.567 .359 .558 r
.62246 .50145 m .62493 .4987 L .62247 .49924 L F
.503 .272 .496 r
.61782 .50474 m .6202 .50419 L .62032 .50212 L F
.341 .095 .389 r
.6202 .50419 m .62246 .50145 L .62032 .50212 L F
.477 .301 .563 r
.58084 .69942 m .5833 .69893 L .58306 .69655 L F
.589 .376 .561 r
.58053 .70127 m .5833 .69893 L .58084 .69942 L F
.698 .352 .386 r
.47144 .69312 m .47567 .69384 L .47333 .69153 L F
.742 .321 .248 r
.47333 .69153 m .47567 .69384 L .47644 .69313 L F
.723 .614 .735 r
.5013 .77681 m .5034 .776 L .49984 .77537 L F
.643 .411 .552 r
.50334 .77843 m .5034 .776 L .5013 .77681 L F
.218 .419 .845 r
.53813 .62695 m .53895 .62514 L .53786 .62511 L F
.53813 .62695 m .54068 .62809 L .53895 .62514 L F
.525 .793 .994 r
.5849 .7189 m .58824 .71943 L .58706 .71841 L F
.886 .932 .844 r
.58824 .71943 m .58792 .71601 L .58706 .71841 L F
.58824 .71943 m .59055 .71658 L .58792 .71601 L F
.467 .473 .781 r
.4064 .69895 m .4078 .70417 L .40947 .70182 L F
.554 .487 .734 r
.25827 .60925 m .26038 .60875 L .25972 .60664 L F
.878 .624 .551 r
.69856 .51541 m .70025 .5163 L .69858 .5132 L F
.844 .69 .691 r
.69684 .51815 m .70025 .5163 L .69856 .51541 L F
.69684 .51815 m .69992 .5186 L .70025 .5163 L F
.577 .488 .718 r
.42364 .68451 m .42208 .68812 L .42174 .6856 L F
.697 .797 .927 r
.53454 .78911 m .5359 .79002 L .53261 .78983 L F
.574 .574 .816 r
.53576 .79201 m .53261 .78983 L .5359 .79002 L F
.697 .797 .927 r
.53454 .78911 m .5359 .79002 L .53261 .78983 L F
.971 .67 .39 r
.53333 .79141 m .53434 .79226 L .53454 .78911 L F
.361 .831 .794 r
.53104 .79348 m .53372 .7928 L .53567 .79204 L F
.53562 .79205 m .53567 .79204 L .53576 .79201 L F
.53104 .79348 m .53567 .79204 L .53562 .79205 L F
.53104 .79348 m .53576 .79201 L .53492 .79276 L F
.971 .67 .39 r
.53434 .79226 m .53492 .79276 L .53486 .79218 L F
.53434 .79226 m .53486 .79218 L .53454 .78911 L F
.514 .02 .021 r
.31962 .64835 m .31892 .64895 L .3165 .64858 L F
.205 0 0 r
.31962 .64835 m .32104 .64854 L .31892 .64895 L F
.31962 .64835 m .32249 .64793 L .32104 .64854 L F
.504 .284 .513 r
.38657 .70201 m .38809 .69816 L .38612 .70036 L F
.926 .817 .718 r
.72336 .50649 m .72627 .50417 L .72524 .50312 L F
.72336 .50649 m .72467 .50758 L .72627 .50417 L F
.564 .377 .585 r
.53191 .74724 m .53438 .74433 L .53228 .74521 L F
.53191 .74724 m .53438 .74433 L .53228 .74521 L F
.818 .484 .423 r
.52427 .76803 m .52669 .77008 L .52881 .77033 L F
.787 .396 .313 r
.52669 .77008 m .52755 .77207 L .52881 .77033 L F
.691 .384 .451 r
.52755 .77207 m .53111 .76999 L .52881 .77033 L F
.701 .317 .317 r
.63777 .49878 m .64019 .50101 L .63633 .50063 L F
.706 .312 .299 r
.6398 .49955 m .64019 .50101 L .63777 .49878 L F
.136 0 .365 r
.30405 .611 m .30294 .61049 L .30462 .60961 L F
.30405 .611 m .30279 .61212 L .30294 .61049 L F
0 0 0 r
.58281 .5517 m .58367 .55003 L .58106 .55269 L F
.481 .26 .501 r
.58281 .5517 m .58517 .54891 L .58367 .55003 L F
.654 .197 .155 r
.50672 .64042 m .50494 .64181 L .50283 .6401 L F
.907 .585 .423 r
.5071 .64157 m .50494 .64181 L .50672 .64042 L F
.254 .68 .964 r
.32259 .58526 m .32433 .58535 L .32409 .58619 L F
.166 .586 .936 r
.32433 .58535 m .32554 .58642 L .32409 .58619 L F
0 0 0 r
.46477 .65431 m .46138 .65625 L .4626 .65388 L F
.976 .878 .672 r
.72765 .48652 m .72857 .48752 L .72942 .4855 L F
.761 .702 .795 r
.69766 .50962 m .69858 .5132 L .70105 .51008 L F
.893 .79 .74 r
.73048 .51302 m .72748 .51573 L .72844 .51277 L F
.73048 .51302 m .729 .51589 L .72748 .51573 L F
.981 .907 .653 r
.53774 .80324 m .53841 .80131 L .53745 .80117 L F
.987 .714 .395 r
.53745 .80117 m .53841 .80131 L .53724 .79811 L F
.793 .619 .665 r
.52725 .65167 m .52816 .649 L .52698 .6488 L F
.52725 .65167 m .52928 .65206 L .52816 .649 L F
.226 .293 .723 r
.52816 .649 m .52919 .64964 L .53057 .64905 L F
.473 .394 .687 r
.53065 .64904 m .53054 .65047 L .53063 .64907 L F
.226 .293 .723 r
.53068 .64871 m .53065 .64902 L .53162 .6486 L F
.59 .037 0 r
.53054 .65047 m .53057 .64905 L .53063 .64907 L F
.792 .76 .823 r
.53062 .64903 m .53063 .64907 L .53057 .64905 L F
.226 .293 .723 r
.52919 .64964 m .53054 .65047 L .53162 .6486 L F
.473 .394 .687 r
.53188 .64672 m .53054 .65047 L .53065 .64904 L F
.226 .293 .723 r
.53058 .64872 m .53057 .64903 L .53065 .64902 L F
.53058 .64872 m .53065 .64902 L .53068 .64871 L F
.52816 .649 m .53057 .64905 L .53058 .64872 L F
.48 .592 .888 r
.53188 .64672 m .53065 .64904 L .52902 .64538 L F
.53065 .64904 m .53063 .64907 L .53062 .64903 L F
.226 .293 .723 r
.53057 .64903 m .53062 .64903 L .53065 .64902 L F
.48 .592 .888 r
.53065 .64904 m .53062 .64903 L .52902 .64538 L F
.226 .293 .723 r
.53057 .64903 m .53057 .64905 L .53062 .64903 L F
.59 .037 0 r
.53054 .65047 m .52726 .64796 L .53057 .64905 L F
.792 .76 .823 r
.52902 .64538 m .53062 .64903 L .52726 .64796 L F
.53062 .64903 m .53057 .64905 L .52726 .64796 L F
.226 .293 .723 r
.53162 .6486 m .53054 .65047 L .53189 .64857 L F
.52816 .649 m .52928 .65206 L .53054 .65047 L F
.929 .744 .631 r
.5044 .8098 m .50531 .81238 L .5032 .81326 L F
.683 .27 .257 r
.49985 .81356 m .50302 .81303 L .50417 .81486 L F
.49912 .81334 m .4994 .81332 L .49985 .81356 L F
.4994 .81332 m .50302 .81303 L .49985 .81356 L F
.474 .25 .494 r
.50273 .81767 m .50522 .8148 L .50505 .81767 L F
.886 .928 .843 r
.50445 .81602 m .50273 .81767 L .50505 .81767 L F
.546 .647 .9 r
.49912 .81334 m .50417 .81486 L .50021 .81136 L F
.598 .033 0 r
.50366 .81401 m .50382 .81425 L .50403 .81462 L F
.50366 .81401 m .50403 .81462 L .50417 .81486 L F
0 .255 .737 r
.50021 .81136 m .50417 .81486 L .50382 .81425 L F
.886 .928 .843 r
.50382 .81425 m .50522 .8148 L .50273 .81767 L F
.50382 .81425 m .50343 .81547 L .50445 .81602 L F
.50343 .81547 m .50273 .81767 L .50445 .81602 L F
.929 .744 .631 r
.50309 .81308 m .5032 .81326 L .50298 .81335 L F
.5044 .8098 m .5032 .81326 L .50309 .81308 L F
.598 .033 0 r
.50302 .81303 m .50366 .81401 L .50417 .81486 L F
.72 .75 .876 r
.55887 .60046 m .56237 .60087 L .56124 .5979 L F
.537 .145 .247 r
.55893 .60274 m .56237 .60087 L .55887 .60046 L F
.55893 .60274 m .56141 .60277 L .56237 .60087 L F
.515 .124 .237 r
.56237 .60087 m .56141 .60277 L .56457 .60197 L F
.521 .105 .192 r
.56237 .60087 m .56457 .60197 L .56589 .60035 L F
.664 .794 .944 r
.5388 .6545 m .53462 .65429 L .53776 .65115 L F
0 .185 .718 r
.53776 .65115 m .53975 .65372 L .5388 .6545 L F
0 0 0 r
.54042 .65385 m .5388 .6545 L .53975 .65372 L F
.54042 .65385 m .53697 .65558 L .5388 .6545 L F
.982 .709 .327 r
.52912 .61162 m .53016 .61496 L .52927 .61403 L F
.601 .104 0 r
.53016 .61496 m .53094 .6161 L .52927 .61403 L F
.53016 .61496 m .53206 .6172 L .53094 .6161 L F
.588 .634 .865 r
.70146 .47087 m .69782 .46817 L .70066 .46778 L F
.771 .725 .81 r
.70442 .4682 m .70146 .47087 L .70066 .46778 L F
.449 .617 .922 r
.52928 .65206 m .53136 .65212 L .53054 .65047 L F
.985 .77 .532 r
.73344 .50212 m .73186 .50378 L .73278 .50057 L F
.73344 .50212 m .73307 .50491 L .73186 .50378 L F
.593 .367 .543 r
.40432 .66205 m .40684 .65962 L .4047 .66016 L F
.841 .66 .657 r
.61765 .54939 m .61504 .5467 L .61832 .54718 L F
.508 .406 .674 r
.39848 .67129 m .4005 .67076 L .40004 .66826 L F
.463 .336 .623 r
.3985 .67419 m .4005 .67076 L .39848 .67129 L F
.784 .826 .885 r
.2898 .64885 m .29291 .64826 L .29202 .64826 L F
.064 .179 .674 r
.29291 .64826 m .29446 .64777 L .29202 .64826 L F
.718 .23 .084 r
.5205 .77493 m .52406 .77626 L .52379 .7747 L F
.281 .416 .821 r
.52379 .7747 m .52406 .77626 L .52527 .77493 L F
.3 .446 .84 r
.52406 .77626 m .52778 .77883 L .52527 .77493 L F
.509 .324 .565 r
.35305 .6146 m .35527 .61165 L .35281 .61178 L F
.782 .776 .848 r
.57563 .65157 m .57691 .65443 L .57398 .65372 L F
.872 .669 .625 r
.57691 .65443 m .57386 .65635 L .57398 .65372 L F
.57691 .65443 m .57651 .65754 L .57386 .65635 L F
0 0 .496 r
.57563 .65157 m .57684 .65367 L .57691 .65443 L F
.526 0 0 r
.57691 .65443 m .57975 .65683 L .58067 .6574 L F
.601 .041 0 r
.57771 .65555 m .57691 .65443 L .57684 .65367 L F
.57771 .65555 m .57975 .65683 L .57691 .65443 L F
.561 .376 .588 r
.62712 .49339 m .62981 .49512 L .62952 .49271 L F
.62712 .49339 m .62711 .49578 L .62981 .49512 L F
.804 .692 .741 r
.57435 .6313 m .57567 .63459 L .57347 .63434 L F
.473 .432 .731 r
.57676 .6307 m .57567 .63459 L .57435 .6313 L F
.57676 .6307 m .57767 .63407 L .57567 .63459 L F
.418 .297 .607 r
.57783 .6365 m .57567 .63459 L .57767 .63407 L F
.57783 .6365 m .576 .6374 L .57567 .63459 L F
.192 0 .144 r
.57592 .55793 m .57785 .55702 L .57854 .55483 L F
.239 0 .191 r
.57854 .55483 m .5805 .55471 L .58106 .55269 L F
.16 0 .084 r
.57785 .55702 m .5805 .55471 L .57854 .55483 L F
.91 .758 .68 r
.6313 .55731 m .634 .55537 L .63284 .55451 L F
.6313 .55731 m .63309 .55861 L .634 .55537 L F
.273 0 0 r
.51391 .70224 m .51249 .70328 L .51001 .70354 L F
.082 0 0 r
.51538 .70232 m .51391 .70224 L .51616 .70181 L F
.51538 .70232 m .51249 .70328 L .51391 .70224 L F
.414 .221 .508 r
.24761 .66849 m .24533 .67143 L .24514 .67083 L F
.24761 .66849 m .24718 .67087 L .24533 .67143 L F
0 0 .076 r
.24718 .67087 m .24554 .67405 L .24533 .67143 L F
.603 .648 .867 r
.27473 .64863 m .27313 .64949 L .27203 .64731 L F
.54 .926 .892 r
.27266 .64937 m .27313 .64949 L .27473 .64863 L F
.017 0 .024 r
.49911 .80951 m .49578 .81303 L .49795 .81197 L F
.574 .38 .581 r
.49911 .80951 m .50152 .80943 L .5015 .80699 L F
.458 .035 .149 r
.50021 .81136 m .49911 .80951 L .49795 .81197 L F
.50021 .81136 m .50152 .80943 L .49911 .80951 L F
.501 .282 .514 r
.38657 .70201 m .38612 .70036 L .38435 .70249 L F
.751 .785 .881 r
.67246 .52929 m .67378 .53072 L .67591 .52952 L F
0 0 0 r
.59446 .55928 m .59407 .56014 L .59261 .56138 L F
.239 0 0 r
.59446 .55928 m .59626 .55937 L .59407 .56014 L F
.628 .886 .554 r
.58526 .56996 m .5876 .56723 L .58632 .56849 L F
.668 .947 .695 r
.58632 .56849 m .58363 .57101 L .58526 .56996 L F
.982 .855 .474 r
.6336 .53089 m .6335 .53567 L .6345 .5321 L F
.841 .66 .657 r
.61765 .54939 m .61467 .54913 L .61504 .5467 L F
.822 .609 .615 r
.61765 .54939 m .61448 .55143 L .61467 .54913 L F
.61765 .54939 m .61667 .55257 L .61448 .55143 L F
0 .331 .805 r
.28914 .64856 m .28839 .64732 L .28709 .64579 L F
.496 .862 .629 r
.51257 .69652 m .51089 .69766 L .51365 .69554 L F
.443 .213 .469 r
.52877 .78118 m .52592 .78479 L .5256 .78187 L F
.52877 .78118 m .52836 .78408 L .52592 .78479 L F
.174 0 .375 r
.53003 .7809 m .52836 .78408 L .52877 .78118 L F
.448 .444 .761 r
.39781 .68294 m .39887 .68567 L .40035 .6849 L F
.461 .434 .742 r
.39887 .68567 m .40109 .68796 L .40035 .6849 L F
.729 .344 .321 r
.5044 .8098 m .5015 .80699 L .50152 .80943 L F
.93 .935 .784 r
.64152 .51646 m .63952 .51716 L .64047 .51792 L F
.929 .93 .785 r
.64251 .5125 m .64057 .51557 L .64152 .51646 L F
.934 .927 .776 r
.64057 .51557 m .63952 .51716 L .64152 .51646 L F
.197 .335 .778 r
.26642 .62313 m .26797 .62633 L .26877 .62484 L F
0 0 0 r
.26797 .62633 m .2673 .62892 L .26877 .62484 L F
.78 .403 .343 r
.55512 .74414 m .55727 .74659 L .55861 .74483 L F
.874 .541 .416 r
.55727 .74659 m .55896 .74704 L .55861 .74483 L F
.82 .641 .66 r
.5256 .78187 m .52592 .78479 L .52423 .78303 L F
0 0 0 r
.5256 .78187 m .52423 .78303 L .52406 .78337 L F
0 0 .193 r
.5256 .78187 m .52697 .78096 L .52778 .77883 L F
.896 .588 .457 r
.52592 .78479 m .52533 .78616 L .52423 .78303 L F
.778 .537 .57 r
.52423 .78303 m .52533 .78616 L .522 .78592 L F
0 0 0 r
.52406 .78337 m .52697 .78096 L .5256 .78187 L F
.928 .608 .148 r
.63464 .50313 m .63585 .50735 L .63559 .50485 L F
.199 .256 .697 r
.52509 .793 m .52715 .79402 L .52685 .79258 L F
.375 .651 .964 r
.50117 .62498 m .50023 .62624 L .4989 .62497 L F
.50117 .62498 m .50255 .62661 L .50023 .62624 L F
.713 .643 .778 r
.52401 .64198 m .52501 .64565 L .52266 .64641 L F
.499 .264 .489 r
.38164 .61155 m .37916 .61415 L .37945 .61201 L F
0 0 .381 r
.67083 .52769 m .67144 .52635 L .67083 .52381 L F
.048 .257 .753 r
.67083 .52769 m .67246 .52929 L .67144 .52635 L F
.291 0 .044 r
.34912 .63766 m .34614 .63909 L .34695 .63826 L F
.415 .719 .987 r
.4148 .70991 m .4168 .70913 L .41516 .70941 L F
.4148 .70991 m .4181 .71022 L .4168 .70913 L F
.547 .661 .912 r
.5071 .64157 m .50978 .64296 L .512 .6426 L F
.623 .602 .808 r
.35271 .60056 m .35416 .6039 L .35633 .60303 L F
.465 .399 .698 r
.29791 .61957 m .29661 .62334 L .29586 .61998 L F
.29791 .61957 m .29848 .6233 L .29661 .62334 L F
.698 .246 .175 r
.40684 .65962 m .40886 .66153 L .41047 .66015 L F
.477 .041 .131 r
.40886 .66153 m .41273 .65967 L .41047 .66015 L F
.514 .236 .43 r
.59528 .53837 m .59784 .53792 L .59822 .53552 L F
.449 .18 .412 r
.59822 .53552 m .60015 .53723 L .60063 .53534 L F
.59822 .53552 m .59784 .53792 L .60015 .53723 L F
.73 .892 .953 r
.53312 .80609 m .53684 .80476 L .53515 .80389 L F
.889 .874 .816 r
.53515 .80389 m .53684 .80476 L .53774 .80324 L F
.53 .333 .557 r
.62493 .4987 m .62711 .49578 L .62467 .4965 L F
0 .446 .771 r
.56363 .75484 m .56656 .75595 L .56668 .75596 L F
.964 .767 .591 r
.56485 .7574 m .56656 .75595 L .56363 .75484 L F
.56485 .7574 m .56616 .75834 L .56656 .75595 L F
.045 .587 .847 r
.4216 .71099 m .42004 .71047 L .4181 .71022 L F
.301 0 0 r
.42383 .71066 m .42004 .71047 L .4216 .71099 L F
.528 .385 .63 r
.57692 .64258 m .57487 .64612 L .57452 .64315 L F
.476 .253 .496 r
.5805 .55471 m .58281 .5517 L .58106 .55269 L F
.384 .721 .989 r
.56457 .60197 m .56807 .60075 L .56589 .60035 L F
.984 .729 .464 r
.53492 .79276 m .5359 .79002 L .53454 .78911 L F
.53492 .79276 m .53576 .79201 L .5359 .79002 L F
.663 .957 .942 r
.48566 .64585 m .48466 .64724 L .48669 .64614 L F
0 0 .052 r
.59407 .56014 m .5922 .56365 L .59261 .56138 L F
.408 .273 .584 r
.25942 .61492 m .26092 .61488 L .26113 .61187 L F
.413 .519 .857 r
.25942 .61492 m .26247 .61766 L .26092 .61488 L F
.832 .794 .815 r
.68485 .50181 m .68252 .50471 L .68189 .50204 L F
.531 .36 .594 r
.61782 .50474 m .62028 .50666 L .6202 .50419 L F
.61782 .50474 m .61797 .50729 L .62028 .50666 L F
.475 .215 .439 r
.36888 .62494 m .36722 .62343 L .36939 .62294 L F
.36888 .62494 m .36678 .62547 L .36722 .62343 L F
.885 .885 .456 r
.6278 .57102 m .6288 .56946 L .6279 .56874 L F
.6278 .57102 m .62765 .57304 L .6288 .56946 L F
.949 .957 .696 r
.6288 .56946 m .62976 .56568 L .6279 .56874 L F
.389 0 .039 r
.43689 .65133 m .43934 .65116 L .44044 .64966 L F
.282 0 0 r
.44044 .64966 m .43934 .65116 L .44233 .64987 L F
.619 .384 .539 r
.59378 .60915 m .59053 .61182 L .5905 .60973 L F
.757 .438 0 r
.64053 .50171 m .64019 .50101 L .6398 .49955 L F
.676 .581 .741 r
.64322 .50082 m .64053 .50171 L .6398 .49955 L F
.615 .651 .862 r
.70054 .47782 m .70345 .4789 L .70288 .47712 L F
.709 .658 .797 r
.70345 .4789 m .70535 .47604 L .70288 .47712 L F
.938 .587 .326 r
.55167 .643 m .55131 .64384 L .55004 .64036 L F
.92 .819 .73 r
.55169 .64446 m .55131 .64384 L .55167 .643 L F
.433 .807 .993 r
.30947 .5838 m .30879 .58485 L .30717 .584 L F
.30947 .5838 m .31087 .58456 L .30879 .58485 L F
.441 .815 .992 r
.35465 .58878 m .35394 .58976 L .3525 .58862 L F
.35465 .58878 m .35604 .58939 L .35394 .58976 L F
.384 .721 .989 r
.56457 .60197 m .5676 .60315 L .56807 .60075 L F
0 0 0 r
.33248 .64531 m .33625 .64329 L .33458 .64476 L F
.278 0 0 r
.33625 .64329 m .33666 .64412 L .33458 .64476 L F
.33625 .64329 m .33866 .64332 L .33666 .64412 L F
0 0 .26 r
.24415 .67082 m .2472 .66849 L .24514 .67083 L F
.414 .221 .508 r
.24761 .66849 m .24514 .67083 L .2472 .66849 L F
.127 .673 .813 r
.31087 .58456 m .31295 .58443 L .31447 .58457 L F
.418 .857 .923 r
.31447 .58457 m .3153 .58371 L .31662 .58445 L F
.31447 .58457 m .31295 .58443 L .3153 .58371 L F
.525 .871 .99 r
.59279 .71594 m .59168 .71539 L .59055 .71658 L F
.545 .9 .973 r
.59055 .71658 m .59168 .71539 L .58792 .71601 L F
0 0 0 r
.33554 .62825 m .33683 .62811 L .33857 .62659 L F
.371 0 .114 r
.33683 .62811 m .34042 .62577 L .33857 .62659 L F
.908 .909 .81 r
.48651 .79743 m .48969 .79568 L .48601 .79526 L F
.48651 .79743 m .48757 .79836 L .48969 .79568 L F
.069 0 0 r
.52449 .69719 m .52319 .69868 L .5215 .69877 L F
.267 0 0 r
.5268 .69684 m .52319 .69868 L .52449 .69719 L F
.104 0 0 r
.5215 .69877 m .52006 .70053 L .51813 .70104 L F
.069 0 0 r
.52319 .69868 m .52006 .70053 L .5215 .69877 L F
.724 .977 .75 r
.5876 .56723 m .58991 .56501 L .58857 .56565 L F
.681 .909 .57 r
.5876 .56723 m .58857 .56565 L .58632 .56849 L F
.784 .99 .888 r
.5456 .59417 m .54753 .59154 L .54822 .59195 L F
.5456 .59417 m .54471 .59379 L .54753 .59154 L F
.679 .687 .85 r
.70126 .49761 m .6986 .49873 L .69743 .49577 L F
.691 .434 .529 r
.59648 .60908 m .59597 .61144 L .59378 .60915 L F
.689 .506 .634 r
.59852 .60922 m .59597 .61144 L .59648 .60908 L F
.477 .868 .97 r
.70054 .47782 m .70171 .477 L .69946 .47731 L F
.70054 .47782 m .70288 .47712 L .70171 .477 L F
.268 0 .239 r
.56883 .56627 m .56686 .56714 L .56621 .56869 L F
.489 .064 .16 r
.46524 .69343 m .4618 .69427 L .46383 .69525 L F
.568 .103 .109 r
.46615 .69529 m .46524 .69343 L .46383 .69525 L F
.46615 .69529 m .46755 .69379 L .46524 .69343 L F
.702 .747 .887 r
.65525 .51549 m .65858 .51508 L .65768 .513 L F
.797 .941 .921 r
.48264 .62829 m .47984 .62899 L .48133 .62744 L F
.771 .895 .931 r
.48532 .62638 m .48264 .62829 L .48133 .62744 L F
.831 .742 .766 r
.69684 .51815 m .69779 .52146 L .69992 .5186 L F
.593 .614 .843 r
.26882 .63127 m .27243 .6345 L .2711 .63126 L F
.799 .755 .812 r
.273 .63763 m .27385 .63998 L .27181 .63905 L F
.307 .189 .55 r
.27243 .6345 m .273 .63763 L .27389 .63633 L F
.609 .462 .657 r
.27041 .63765 m .27181 .63905 L .273 .63763 L F
.821 .996 .762 r
.273 .63763 m .27181 .63905 L .27389 .63633 L F
0 0 0 r
.27243 .63824 m .27293 .6384 L .27389 .63633 L F
.27181 .63905 m .27196 .63897 L .27243 .63824 L F
.27196 .63897 m .27293 .6384 L .27243 .63824 L F
.599 .382 .558 r
.27041 .63765 m .27283 .63763 L .27243 .6345 L F
.27283 .63763 m .273 .63763 L .27296 .63743 L F
.27283 .63763 m .27296 .63743 L .27243 .6345 L F
.601 .593 .815 r
.2711 .63126 m .27243 .6345 L .27485 .63345 L F
.307 .189 .55 r
.27243 .6345 m .27389 .63633 L .27485 .63345 L F
.461 .056 .184 r
.27422 .58973 m .27584 .59079 L .2774 .58866 L F
.571 .215 .325 r
.27584 .59079 m .27955 .58855 L .2774 .58866 L F
.583 .368 .555 r
.6018 .60613 m .59852 .60922 L .59928 .60658 L F
.548 .496 .75 r
.39694 .6796 m .39781 .68294 L .39983 .6824 L F
.534 .443 .698 r
.39781 .68294 m .40035 .6849 L .39983 .6824 L F
.171 .702 .699 r
.4445 .69726 m .44676 .69672 L .44787 .69647 L F
.015 0 0 r
.44676 .69672 m .45016 .69624 L .44787 .69647 L F
.79 .628 .679 r
.47528 .6483 m .47155 .65001 L .47259 .6485 L F
.398 .29 .615 r
.48748 .78398 m .48946 .78378 L .4892 .7811 L F
.526 .503 .773 r
.48748 .78398 m .49066 .7864 L .48951 .78628 L F
.393 .266 .586 r
.48748 .78398 m .48951 .78628 L .48946 .78378 L F
.471 .132 .31 r
.45696 .65771 m .45655 .6592 L .45434 .65926 L F
.601 .343 .499 r
.45923 .65706 m .45655 .6592 L .45696 .65771 L F
.697 .774 .911 r
.65403 .51271 m .65525 .51549 L .65768 .513 L F
.649 .856 .47 r
.71989 .47561 m .72173 .47226 L .72253 .47364 L F
.71989 .47561 m .72097 .47383 L .72173 .47226 L F
.71989 .47561 m .71969 .47573 L .72097 .47383 L F
.53 .272 .468 r
.53498 .69132 m .53468 .69349 L .53234 .69373 L F
.577 .398 .602 r
.53705 .68958 m .53739 .69116 L .53498 .69132 L F
.49 .237 .457 r
.53694 .69305 m .53498 .69132 L .53739 .69116 L F
.53694 .69305 m .53468 .69349 L .53498 .69132 L F
.301 .409 .806 r
.7267 .47273 m .72669 .47598 L .72496 .47301 L F
.7267 .47273 m .72811 .47558 L .72669 .47598 L F
.108 .189 .667 r
.72856 .47797 m .72669 .47598 L .72811 .47558 L F
.608 .506 .713 r
.47258 .79731 m .47468 .79515 L .47242 .79546 L F
.637 .473 .644 r
.58808 .61194 m .58849 .61463 L .58574 .61492 L F
.6 .432 .626 r
.59053 .61182 m .58849 .61463 L .58808 .61194 L F
.975 .724 .492 r
.5399 .68603 m .5393 .68773 L .53967 .68571 L F
.545 .617 .875 r
.5255 .64241 m .52501 .64565 L .52401 .64198 L F
.5255 .64241 m .52736 .64561 L .52501 .64565 L F
0 .192 .712 r
.52726 .64796 m .52501 .64565 L .52736 .64561 L F
.699 .233 .141 r
.52726 .64796 m .52922 .64972 L .52898 .64967 L F
0 .192 .712 r
.52726 .64796 m .52698 .6488 L .5251 .64579 L F
.865 .715 .694 r
.52526 .64918 m .52725 .65167 L .52698 .6488 L F
.52526 .64918 m .52698 .6488 L .52726 .64796 L F
.699 .233 .141 r
.52726 .64796 m .52898 .64967 L .52568 .64908 L F
0 .192 .712 r
.52726 .64796 m .5251 .64579 L .52501 .64565 L F
.249 .004 .334 r
.59935 .55555 m .59895 .55766 L .59748 .55744 L F
.249 0 .102 r
.59748 .55744 m .59895 .55766 L .59626 .55937 L F
.56 .165 .25 r
.44633 .66296 m .44497 .66516 L .44272 .66484 L F
.7 .324 .332 r
.4485 .66494 m .44497 .66516 L .44633 .66296 L F
.518 .177 .328 r
.26314 .64574 m .26509 .64733 L .26558 .64539 L F
.26314 .64574 m .26193 .64803 L .26509 .64733 L F
.862 .819 .806 r
.61759 .55581 m .61401 .55752 L .61573 .55466 L F
.61759 .55581 m .61571 .5584 L .61401 .55752 L F
.447 .43 .748 r
.57657 .5979 m .57861 .59726 L .57729 .59402 L F
.416 .331 .653 r
.57657 .5979 m .57832 .59986 L .57861 .59726 L F
.481 .344 .616 r
.57657 .5979 m .57676 .60056 L .57832 .59986 L F
.633 .673 .87 r
.76524 .59917 m .76744 .59818 L .76375 .59709 L F
.276 .764 .912 r
.52019 .64126 m .52302 .64123 L .52131 .64257 L F
.619 .384 .539 r
.59378 .60915 m .59403 .61151 L .59053 .61182 L F
.688 .434 .533 r
.59378 .60915 m .59597 .61144 L .59403 .61151 L F
.563 .822 .456 r
.56091 .57406 m .5621 .57262 L .55988 .57536 L F
.987 .777 .533 r
.55988 .57536 m .55842 .57693 L .56091 .57406 L F
.55988 .57536 m .55949 .57741 L .55842 .57693 L F
.982 .761 .528 r
.61571 .5584 m .61426 .56003 L .61401 .55752 L F
.61571 .5584 m .61555 .5608 L .61426 .56003 L F
.133 0 0 r
.32434 .63144 m .32649 .63163 L .32761 .63162 L F
.295 .791 .856 r
.32761 .63162 m .32649 .63163 L .32914 .6311 L F
0 0 0 r
.6278 .57102 m .62662 .57452 L .62765 .57304 L F
.72 .484 .568 r
.50948 .79247 m .51026 .79029 L .50639 .79005 L F
.53 .229 .401 r
.54395 .7722 m .54601 .77243 L .54686 .77062 L F
.004 0 .104 r
.54686 .77062 m .54601 .77243 L .54825 .7696 L F
.899 .771 .711 r
.7364 .48408 m .73362 .48467 L .73573 .48143 L F
.7364 .48408 m .73356 .4866 L .73362 .48467 L F
.813 .799 .839 r
.73887 .48148 m .7364 .48408 L .73573 .48143 L F
.899 .771 .711 r
.7364 .48408 m .73356 .4866 L .73362 .48467 L F
.681 .978 .879 r
.67859 .47348 m .6751 .4751 L .67749 .47378 L F
.446 .878 .807 r
.67859 .47348 m .68012 .47247 L .68075 .47244 L F
.433 .863 .748 r
.67859 .47348 m .67749 .47378 L .68012 .47247 L F
.423 0 0 r
.48862 .69973 m .48885 .70001 L .48853 .69966 L F
0 0 0 r
.48755 .69864 m .48615 .69972 L .48862 .69973 L F
.423 0 0 r
.48862 .69973 m .48853 .69966 L .48755 .69864 L F
.022 .595 .741 r
.48868 .69978 m .48862 .69973 L .48615 .69972 L F
.48966 .6998 m .48862 .69973 L .48868 .69978 L F
.621 .102 0 r
.49222 .70086 m .48862 .69973 L .48966 .6998 L F
.609 .403 .576 r
.58364 .6148 m .58355 .61707 L .58121 .61741 L F
.644 .397 .529 r
.58574 .61492 m .58355 .61707 L .58364 .6148 L F
.657 .904 .981 r
.38174 .7066 m .37814 .70689 L .37962 .7065 L F
.516 .084 .157 r
.48389 .69927 m .48246 .70111 L .4805 .69997 L F
.304 0 0 r
.48615 .69972 m .48246 .70111 L .48389 .69927 L F
.537 .854 .557 r
.56354 .57118 m .56468 .57014 L .5621 .57262 L F
.335 0 .228 r
.56091 .57406 m .56354 .57118 L .5621 .57262 L F
.395 .187 .476 r
.5732 .5628 m .57147 .56145 L .571 .56328 L F
.5732 .5628 m .57345 .56057 L .57147 .56145 L F
.463 .294 .565 r
.60105 .54966 m .60166 .55243 L .59903 .55264 L F
.478 .383 .67 r
.60166 .55243 m .60115 .55537 L .59903 .55264 L F
.524 .396 .647 r
.59903 .55264 m .60115 .55537 L .59935 .55555 L F
.284 .615 .957 r
.28325 .6422 m .28192 .64018 L .28144 .64097 L F
.28325 .6422 m .28499 .64239 L .28192 .64018 L F
.73 .892 .953 r
.53312 .80609 m .53515 .80389 L .53276 .80557 L F
.499 .315 .562 r
.2981 .61743 m .29791 .61957 L .29586 .61998 L F
.91 .858 .778 r
.71938 .49903 m .71634 .50107 L .719 .49832 L F
.71938 .49903 m .71757 .50236 L .71634 .50107 L F
.947 .838 .403 r
.71938 .49903 m .71942 .49511 L .71914 .49597 L F
.71938 .49903 m .719 .49832 L .71942 .49511 L F
.832 .794 .815 r
.68485 .50181 m .68189 .50204 L .68392 .50033 L F
.478 .682 .956 r
.68611 .5002 m .68485 .50181 L .68392 .50033 L F
.506 .723 .97 r
.68611 .5002 m .68725 .50159 L .68485 .50181 L F
.169 0 0 r
.64291 .48757 m .64405 .48781 L .64645 .4876 L F
.542 .925 .906 r
.64645 .4876 m .64712 .48668 L .6485 .48772 L F
.64645 .4876 m .64405 .48781 L .64712 .48668 L F
.202 0 .183 r
.56354 .57118 m .56621 .56869 L .56468 .57014 L F
.644 .397 .529 r
.58574 .61492 m .58568 .61719 L .58355 .61707 L F
.641 .693 .883 r
.58574 .61492 m .58869 .61504 L .58568 .61719 L F
.58574 .61492 m .58849 .61463 L .58869 .61504 L F
.502 .066 .144 r
.45497 .70241 m .45362 .70421 L .45139 .70398 L F
.339 0 .01 r
.45722 .70226 m .45362 .70421 L .45497 .70241 L F
.788 .679 .744 r
.47965 .81539 m .48071 .81478 L .48189 .81504 L F
.47965 .81539 m .47832 .81234 L .48071 .81478 L F
.319 .793 .921 r
.47965 .81539 m .48071 .81478 L .47854 .81548 L F
.47965 .81539 m .48189 .81504 L .48071 .81478 L F
.533 .538 .806 r
.39955 .6907 m .40286 .69376 L .40143 .69048 L F
.981 .907 .653 r
.53774 .80324 m .53745 .80117 L .53515 .80389 L F
.545 .301 .497 r
.26582 .59454 m .26844 .59189 L .26607 .59226 L F
.14 0 0 r
.2899 .58579 m .29208 .58554 L .29395 .58472 L F
.124 0 0 r
.29395 .58472 m .29208 .58554 L .29537 .58484 L F
0 0 0 r
.52836 .78408 m .52533 .78616 L .52592 .78479 L F
.556 .405 .631 r
.39988 .66577 m .40228 .66781 L .40213 .66537 L F
.39988 .66577 m .40004 .66826 L .40228 .66781 L F
.772 .264 0 r
.54187 .62905 m .54354 .63112 L .54138 .62975 L F
.798 .343 .161 r
.54556 .6317 m .54354 .63112 L .54187 .62905 L F
.582 .94 .8 r
.47266 .63498 m .47389 .6337 L .47469 .63412 L F
.47266 .63498 m .47081 .63564 L .47389 .6337 L F
.984 .711 .338 r
.4887 .80647 m .48868 .80429 L .48768 .80374 L F
0 0 0 r
.53251 .80055 m .53175 .80253 L .5324 .80119 L F
.427 .057 .232 r
.50655 .80786 m .5044 .8098 L .50651 .80822 L F
.577 .327 .501 r
.50298 .81335 m .5044 .8098 L .50152 .80943 L F
.929 .744 .631 r
.5044 .8098 m .50531 .81238 L .50298 .81335 L F
.251 .004 .33 r
.50651 .80822 m .5044 .8098 L .50298 .81335 L F
.921 .917 .795 r
.50651 .80822 m .50282 .81174 L .50496 .80817 L F
.342 0 0 r
.50496 .80817 m .50649 .80837 L .50651 .80822 L F
.50649 .80837 m .50823 .80859 L .50651 .80822 L F
.427 .057 .232 r
.50737 .80711 m .50655 .80786 L .50651 .80822 L F
.465 .484 .794 r
.50611 .80375 m .50737 .80711 L .50929 .80626 L F
0 0 0 r
.50929 .80626 m .50737 .80711 L .50651 .80822 L F
.482 .298 .554 r
.36057 .60648 m .36263 .60593 L .36259 .60336 L F
.471 .247 .492 r
.36022 .6087 m .36263 .60593 L .36057 .60648 L F
.435 .408 .731 r
.74943 .49276 m .75011 .49463 L .74771 .49589 L F
.381 .273 .606 r
.75056 .4969 m .74771 .49589 L .75011 .49463 L F
.75056 .4969 m .74818 .4987 L .74771 .49589 L F
.676 .581 .741 r
.64322 .50082 m .6398 .49955 L .64283 .4992 L F
0 0 0 r
.58991 .56501 m .59086 .56509 L .58857 .56565 L F
.58991 .56501 m .5922 .56365 L .59086 .56509 L F
.083 0 .381 r
.74889 .48697 m .74878 .48891 L .74681 .49092 L F
.367 .365 .725 r
.74878 .48891 m .74943 .49276 L .74681 .49092 L F
.771 .725 .81 r
.70442 .4682 m .70066 .46778 L .70274 .46701 L F
.8 .787 .84 r
.70678 .46561 m .70442 .4682 L .70274 .46701 L F
.781 .824 .887 r
.47921 .79203 m .48081 .79327 L .47702 .79495 L F
.617 .793 .966 r
.48275 .79249 m .48081 .79327 L .47921 .79203 L F
.481 .806 1 r
.36181 .58978 m .35965 .5902 L .3581 .58932 L F
.638 .825 .972 r
.49301 .62343 m .49079 .6247 L .48998 .62366 L F
.38 .174 .471 r
.56903 .56421 m .56883 .56627 L .571 .56328 L F
.491 .464 .755 r
.56396 .71648 m .56514 .71277 L .56297 .71303 L F
.56396 .71648 m .56598 .71638 L .56514 .71277 L F
.533 .263 .452 r
.56457 .7109 m .56756 .7106 L .56823 .70658 L F
.244 .408 .827 r
.56823 .70658 m .56993 .70655 L .56724 .70513 L F
.499 .233 .442 r
.56823 .70658 m .56957 .70955 L .56993 .70655 L F
.56823 .70658 m .56756 .7106 L .56957 .70955 L F
.264 0 0 r
.50255 .62661 m .50492 .62664 L .50594 .62618 L F
.019 0 0 r
.50492 .62664 m .50858 .62576 L .50594 .62618 L F
.632 .831 .977 r
.50901 .62512 m .50594 .62618 L .50858 .62576 L F
.384 .76 .991 r
.24552 .66768 m .24761 .66849 L .2472 .66849 L F
0 0 .26 r
.24415 .67082 m .24552 .66768 L .2472 .66849 L F
.607 .147 .136 r
.52759 .68981 m .53023 .69046 L .5312 .68895 L F
.488 .021 .072 r
.5312 .68895 m .53023 .69046 L .53326 .68984 L F
.764 .54 .594 r
.4521 .66279 m .45202 .66563 L .4485 .66494 L F
.636 .497 .677 r
.45434 .65926 m .45488 .66257 L .4521 .66279 L F
.659 .452 .592 r
.45501 .66454 m .4521 .66279 L .45488 .66257 L F
.45501 .66454 m .45202 .66563 L .4521 .66279 L F
.362 .058 .308 r
.36678 .62547 m .36404 .62792 L .36468 .62605 L F
.181 .374 .819 r
.53629 .77573 m .53807 .77742 L .53708 .77479 L F
.817 .352 0 r
.53629 .77573 m .53771 .77815 L .53807 .77742 L F
.821 .699 .73 r
.71242 .47538 m .71459 .47631 L .71368 .47298 L F
.57 .38 .584 r
.58121 .61741 m .58082 .62026 L .57809 .6203 L F
.552 .387 .611 r
.58082 .62026 m .57841 .62342 L .57809 .6203 L F
.964 .69 .468 r
.26247 .61766 m .26271 .62039 L .26117 .6192 L F
.239 .42 .84 r
.26092 .61488 m .26247 .61766 L .26342 .61633 L F
.733 .627 .741 r
.26117 .6192 m .26342 .61633 L .26247 .61766 L F
.751 .785 .881 r
.67246 .52929 m .67591 .52952 L .67487 .52791 L F
.822 .828 .853 r
.67487 .52791 m .67591 .52952 L .67823 .52696 L F
.428 0 .098 r
.60317 .59341 m .60153 .59217 L .60065 .59377 L F
.60317 .59341 m .60407 .59197 L .60153 .59217 L F
.964 .915 .711 r
.63952 .51716 m .63885 .5214 L .64047 .51792 L F
0 .145 .67 r
.74558 .48338 m .74573 .48524 L .74457 .4817 L F
.291 .486 .877 r
.74698 .48392 m .74573 .48524 L .74558 .48338 L F
.74698 .48392 m .74889 .48697 L .74573 .48524 L F
.422 .027 .183 r
.28175 .58849 m .28398 .58819 L .28544 .58604 L F
.349 0 .087 r
.28398 .58819 m .28764 .58589 L .28544 .58604 L F
.59 .486 .704 r
.49578 .81303 m .49912 .81334 L .49795 .81197 L F
.49578 .81303 m .49698 .81522 L .49912 .81334 L F
.996 .786 .501 r
.71846 .46757 m .7191 .4711 L .718 .4698 L F
.633 .636 .835 r
.71991 .46701 m .7191 .4711 L .71846 .46757 L F
.71991 .46701 m .72231 .47092 L .7191 .4711 L F
.207 .441 .865 r
.7191 .4711 m .72117 .47063 L .718 .4698 L F
.556 .203 .325 r
.7191 .4711 m .72231 .47092 L .72173 .47226 L F
.207 .441 .865 r
.72001 .4715 m .72173 .47226 L .72117 .47063 L F
.59 .617 .847 r
.72403 .46954 m .72231 .47092 L .71991 .46701 L F
.844 .779 .788 r
.72097 .47383 m .72117 .47063 L .72173 .47226 L F
.173 .414 .853 r
.72215 .47086 m .72173 .47226 L .72117 .47063 L F
.72215 .47086 m .72173 .47226 L .72117 .47063 L F
.844 .779 .788 r
.72097 .47383 m .71835 .47425 L .72117 .47063 L F
.357 .561 .913 r
.72517 .46802 m .72564 .46957 L .72403 .46954 L F
0 0 0 r
.72517 .46802 m .72403 .46954 L .72482 .4685 L F
.59 .617 .847 r
.72403 .46954 m .71991 .46701 L .72482 .4685 L F
0 .401 .701 r
.72189 .46756 m .72482 .4685 L .71991 .46701 L F
.266 .322 .735 r
.72117 .47063 m .72215 .47086 L .72189 .46756 L F
0 .03 .569 r
.72189 .46756 m .72211 .47034 L .72258 .46951 L F
.72211 .47034 m .72215 .47086 L .72258 .46951 L F
0 0 0 r
.72117 .47063 m .72258 .46951 L .72215 .47086 L F
.72117 .47063 m .72242 .46968 L .72258 .46951 L F
.578 .822 .991 r
.72517 .46802 m .72482 .4685 L .72189 .46756 L F
.72517 .46802 m .72189 .46756 L .72432 .46678 L F
.638 .831 .422 r
.72258 .46951 m .72432 .46678 L .72189 .46756 L F
.684 .916 .587 r
.72258 .46951 m .72109 .47091 L .72333 .46817 L F
.72258 .46951 m .72333 .46817 L .72338 .4681 L F
0 0 0 r
.72117 .47063 m .71975 .47262 L .72242 .46968 L F
.207 .441 .865 r
.7191 .4711 m .72001 .4715 L .72117 .47063 L F
.555 .59 .844 r
.51088 .63086 m .51074 .63464 L .50994 .63121 L F
.51088 .63086 m .51289 .63429 L .51074 .63464 L F
.487 .62 .908 r
.71151 .5068 m .71314 .50942 L .71522 .5092 L F
.537 0 0 r
.51664 .64924 m .51614 .65039 L .51311 .6489 L F
.592 .048 0 r
.51896 .65062 m .51614 .65039 L .51664 .64924 L F
.539 .593 .856 r
.30027 .62307 m .29996 .62626 L .29848 .6233 L F
.30027 .62307 m .30199 .62593 L .29996 .62626 L F
.374 .766 .988 r
.36259 .60336 m .36367 .60274 L .36068 .60235 L F
.288 .149 .512 r
.36259 .60336 m .36418 .60503 L .36367 .60274 L F
.36259 .60336 m .36263 .60593 L .36418 .60503 L F
.608 .506 .713 r
.47258 .79731 m .47493 .79696 L .47468 .79515 L F
.591 .503 .723 r
.47258 .79731 m .47586 .80093 L .47493 .79696 L F
.47258 .79731 m .47368 .80161 L .47586 .80093 L F
.775 .433 .407 r
.4813 .69576 m .48288 .69364 L .48106 .69336 L F
.4813 .69576 m .4848 .69651 L .48288 .69364 L F
.825 .428 .297 r
.48288 .69364 m .4848 .69651 L .48563 .69629 L F
.232 .75 .836 r
.33057 .59995 m .32836 .60005 L .32621 .60041 L F
.277 .773 .886 r
.3319 .59986 m .32836 .60005 L .33057 .59995 L F
.661 .777 .935 r
.66716 .51557 m .66458 .51676 L .66586 .51473 L F
.439 .2 .453 r
.66716 .51557 m .66663 .51761 L .66458 .51676 L F
.317 .322 .707 r
.66458 .51676 m .66663 .51761 L .66586 .51473 L F
0 .519 .786 r
.6445 .50654 m .6433 .50612 L .63908 .50531 L F
.275 .757 .925 r
.64677 .50627 m .6433 .50612 L .6445 .50654 L F
.413 0 0 r
.48074 .65067 m .48295 .6507 L .48432 .65002 L F
.726 .734 .857 r
.7036 .50763 m .70701 .50819 L .7058 .50647 L F
.703 .719 .861 r
.7058 .50647 m .70701 .50819 L .70927 .50714 L F
.568 .453 .683 r
.51166 .78711 m .51393 .78688 L .51404 .78452 L F
.463 .336 .623 r
.3985 .67419 m .40036 .67392 L .4005 .67076 L F
.53 .383 .625 r
.39858 .67677 m .40036 .67392 L .3985 .67419 L F
.465 .035 .138 r
.47821 .69931 m .47434 .70111 L .47485 .70014 L F
.47821 .69931 m .47675 .70106 L .47434 .70111 L F
.494 .002 .016 r
.4805 .69997 m .47675 .70106 L .47821 .69931 L F
.461 .357 .65 r
.63805 .50628 m .63659 .50956 L .63585 .50735 L F
.63805 .50628 m .63863 .5096 L .63659 .50956 L F
.423 .564 .891 r
.63889 .51064 m .63659 .50956 L .63863 .5096 L F
.5 .01 .025 r
.27422 .58973 m .27261 .5909 L .27584 .59079 L F
.83 .422 .272 r
.56125 .65071 m .55795 .64797 L .56088 .64955 L F
.571 .156 .217 r
.54395 .7722 m .54036 .7729 L .54223 .77467 L F
.476 .034 .119 r
.54476 .77416 m .54395 .7722 L .54223 .77467 L F
.54476 .77416 m .54601 .77243 L .54395 .7722 L F
.422 .734 .991 r
.27064 .63908 m .27385 .63998 L .27181 .63905 L F
.958 .815 .378 r
.27131 .64235 m .27181 .63905 L .27385 .63998 L F
.946 .946 .745 r
.27194 .63996 m .27131 .64235 L .27385 .63998 L F
.27194 .63996 m .27385 .63998 L .2756 .64033 L F
.73 .559 .659 r
.60911 .54689 m .6094 .54956 L .60673 .54956 L F
.637 .491 .668 r
.61255 .54911 m .60911 .54689 L .61144 .54671 L F
.61255 .54911 m .6094 .54956 L .60911 .54689 L F
.923 .549 .134 r
.55004 .64036 m .55131 .64384 L .54964 .64168 L F
.993 .874 .594 r
.6547 .49898 m .65394 .49796 L .65478 .49558 L F
.948 .926 .75 r
.6547 .49898 m .65254 .50042 L .65394 .49796 L F
.918 .935 .802 r
.6547 .49898 m .65394 .49796 L .65589 .49507 L F
.948 .926 .75 r
.6547 .49898 m .65254 .50042 L .65394 .49796 L F
.044 .572 .863 r
.30585 .62779 m .30779 .6281 L .30933 .62875 L F
.385 .787 .984 r
.30779 .6281 m .31139 .62848 L .30933 .62875 L F
.541 .359 .584 r
.47368 .80161 m .47592 .80342 L .47586 .80093 L F
.368 .365 .725 r
.47368 .80161 m .47446 .80385 L .47592 .80342 L F
.354 0 0 r
.31089 .64897 m .30908 .65024 L .30703 .65017 L F
.513 .868 .626 r
.31154 .64831 m .31089 .64897 L .31249 .64823 L F
.31154 .64831 m .30908 .65024 L .31089 .64897 L F
.846 .883 .867 r
.30757 .64944 m .30893 .64905 L .30977 .64844 L F
.30893 .64905 m .31154 .64831 L .30977 .64844 L F
.30757 .64944 m .30908 .65024 L .31154 .64831 L F
.134 0 0 r
.31311 .64896 m .30982 .64844 L .31154 .64831 L F
.30982 .64844 m .30977 .64844 L .31154 .64831 L F
.31311 .64896 m .31177 .64877 L .30977 .64844 L F
.362 .603 .94 r
.30977 .64844 m .31177 .64877 L .31116 .64743 L F
.30977 .64844 m .31116 .64743 L .31112 .64735 L F
.513 .868 .626 r
.31154 .64831 m .31249 .64823 L .31291 .64804 L F
.31 .452 .842 r
.51569 .63601 m .51451 .63731 L .51289 .63429 L F
.136 .184 .648 r
.51569 .63601 m .51625 .63979 L .51451 .63731 L F
.76 .553 .616 r
.58573 .69892 m .58927 .69673 L .58552 .69638 L F
.58573 .69892 m .58908 .69925 L .58927 .69673 L F
.413 0 .053 r
.44233 .64987 m .44455 .64979 L .44591 .6481 L F
.126 0 0 r
.44591 .6481 m .4475 .6481 L .44836 .64683 L F
.39 .015 .201 r
.44455 .64979 m .4475 .6481 L .44591 .6481 L F
.824 .361 .115 r
.63211 .55115 m .63326 .55079 L .63214 .54878 L F
.63211 .55115 m .63381 .55179 L .63326 .55079 L F
.59 .455 .666 r
.58306 .69655 m .58499 .69398 L .58213 .69363 L F
.58306 .69655 m .58552 .69638 L .58499 .69398 L F
.671 .506 .653 r
.5833 .69893 m .58552 .69638 L .58306 .69655 L F
.315 0 0 r
.4582 .69599 m .46046 .69573 L .4618 .69427 L F
.496 .021 .058 r
.4618 .69427 m .46046 .69573 L .46383 .69525 L F
.59 .644 .872 r
.55188 .77608 m .55115 .7794 L .54963 .77585 L F
.972 .684 .42 r
.63204 .54309 m .63311 .5419 L .63258 .5393 L F
.63204 .54309 m .63339 .5439 L .63311 .5419 L F
.202 0 0 r
.52212 .69085 m .52427 .69035 L .52546 .68893 L F
.5 .033 .077 r
.52546 .68893 m .52427 .69035 L .52759 .68981 L F
.525 .073 .12 r
.29537 .58484 m .2977 .58502 L .29955 .58329 L F
.223 0 0 r
.2977 .58502 m .30148 .5838 L .29955 .58329 L F
.044 0 .332 r
.6061 .58653 m .60787 .58522 L .6081 .58307 L F
0 0 .318 r
.6061 .58653 m .60686 .5872 L .60787 .58522 L F
.6061 .58653 m .60638 .58894 L .60686 .5872 L F
.642 .318 .408 r
.47567 .69384 m .4789 .69315 L .47644 .69313 L F
.961 .744 .565 r
.5468 .63731 m .54537 .63676 L .54558 .63412 L F
.941 .701 .547 r
.5071 .64157 m .50635 .64312 L .50494 .64181 L F
.779 .7 .776 r
.50992 .64325 m .50635 .64312 L .5071 .64157 L F
.592 .398 .587 r
.512 .6426 m .50992 .64325 L .5071 .64157 L F
0 .194 .714 r
.49225 .7951 m .49379 .79878 L .49427 .79724 L F
.755 .875 .455 r
.49427 .79724 m .49379 .79878 L .49327 .79964 L F
.49307 .79981 m .49327 .79964 L .49275 .8005 L F
.49427 .79724 m .49327 .79964 L .49307 .79981 L F
.49479 .79748 m .49275 .8005 L .49564 .79785 L F
0 0 0 r
.49275 .8005 m .49379 .79878 L .49336 .79959 L F
.755 .875 .455 r
.49427 .79724 m .49275 .8005 L .49479 .79748 L F
0 0 0 r
.49275 .8005 m .49336 .79959 L .4931 .80008 L F
.47 .88 .944 r
.4931 .80008 m .49095 .80095 L .48972 .79824 L F
.555 0 0 r
.49065 .7995 m .49284 .80001 L .48972 .79824 L F
.49284 .80001 m .4931 .80008 L .49289 .79996 L F
.49284 .80001 m .49289 .79996 L .48972 .79824 L F
.212 .021 .39 r
.62297 .58326 m .62257 .58546 L .62062 .58625 L F
.166 0 .284 r
.62257 .58546 m .62043 .58843 L .62062 .58625 L F
.563 .308 .488 r
.35527 .61165 m .35771 .61138 L .35801 .60923 L F
.277 .066 .403 r
.35801 .60923 m .3594 .6105 L .36022 .6087 L F
.35801 .60923 m .35771 .61138 L .3594 .6105 L F
.548 .496 .75 r
.39694 .6796 m .39983 .6824 L .399 .67918 L F
.908 .981 .718 r
.65519 .50615 m .65258 .50877 L .65402 .50521 L F
.833 .743 .765 r
.69452 .52117 m .69779 .52146 L .69684 .51815 L F
.815 .592 .6 r
.69456 .52337 m .69779 .52146 L .69452 .52117 L F
.69456 .52337 m .69769 .52377 L .69779 .52146 L F
.756 .595 .678 r
.56999 .64889 m .56668 .6515 L .56662 .64852 L F
.56999 .64889 m .56995 .65164 L .56668 .6515 L F
.622 .448 .626 r
.57258 .64839 m .56995 .65164 L .56999 .64889 L F
.777 .681 .757 r
.48392 .79524 m .48611 .79272 L .48275 .79249 L F
.341 .117 .422 r
.5393 .68773 m .54146 .68479 L .53967 .68571 L F
.493 .659 .935 r
.77076 .59301 m .76981 .59532 L .76854 .59381 L F
.469 .316 .591 r
.76981 .59532 m .77243 .59491 L .77134 .5943 L F
.822 .963 .9 r
.77243 .59491 m .76981 .59532 L .77134 .5943 L F
.472 .314 .585 r
.77134 .5943 m .77243 .59491 L .77435 .59367 L F
.77134 .5943 m .77243 .59491 L .77435 .59367 L F
.493 .659 .935 r
.77076 .59301 m .77243 .59491 L .76981 .59532 L F
0 0 .246 r
.66288 .48876 m .66201 .48827 L .66107 .48676 L F
.66288 .48876 m .6612 .49074 L .66201 .48827 L F
.525 .729 .967 r
.57099 .72205 m .57223 .72074 L .57027 .72109 L F
.57099 .72205 m .57325 .72171 L .57223 .72074 L F
.332 .673 .976 r
.33588 .60033 m .33621 .59923 L .33445 .59939 L F
.33588 .60033 m .33761 .60045 L .33621 .59923 L F
.126 0 0 r
.44836 .64683 m .44951 .64738 L .45003 .64675 L F
.44836 .64683 m .4475 .6481 L .44951 .64738 L F
.33255 .62927 m .33384 .62944 L .33554 .62825 L F
0 0 0 r
.33554 .62825 m .33384 .62944 L .33683 .62811 L F
.683 .48 .605 r
.50359 .7925 m .50628 .79295 L .50639 .79005 L F
.72 .484 .568 r
.50948 .79247 m .50639 .79005 L .50628 .79295 L F
.807 .47 .418 r
.56398 .65172 m .56145 .65298 L .56125 .65071 L F
.56398 .65172 m .56415 .65392 L .56145 .65298 L F
.613 .487 .685 r
.56662 .64852 m .56668 .6515 L .56398 .65172 L F
.529 .258 .449 r
.56652 .65332 m .56398 .65172 L .56668 .6515 L F
.56652 .65332 m .56415 .65392 L .56398 .65172 L F
.994 .751 .442 r
.729 .51589 m .72793 .51731 L .72748 .51573 L F
.729 .51589 m .72901 .51828 L .72793 .51731 L F
.109 .641 .868 r
.31426 .64832 m .3165 .64858 L .31291 .64804 L F
.98 .742 .505 r
.66663 .51761 m .66779 .52094 L .66802 .5184 L F
.979 .776 .562 r
.66716 .51557 m .66663 .51761 L .66802 .5184 L F
.98 .742 .505 r
.66802 .5184 m .66779 .52094 L .66663 .51761 L F
.815 .624 .644 r
.53538 .68935 m .5393 .68773 L .53705 .68958 L F
.521 .362 .605 r
.53705 .68958 m .53957 .69056 L .5393 .68773 L F
.53705 .68958 m .53739 .69116 L .53957 .69056 L F
.816 .343 .084 r
.72597 .49703 m .72715 .49603 L .72677 .49502 L F
.126 0 0 r
.34457 .64087 m .34403 .63991 L .34614 .63909 L F
.34457 .64087 m .34252 .64161 L .34403 .63991 L F
.02 0 .309 r
.47695 .77591 m .47808 .77697 L .47789 .7747 L F
.47695 .77591 m .47642 .77877 L .47808 .77697 L F
.811 .67 .707 r
.55097 .60569 m .55432 .60656 L .55391 .6039 L F
.722 .237 .091 r
.55097 .60569 m .55311 .60761 L .55432 .60656 L F
.565 .248 .39 r
.55432 .60656 m .55671 .60813 L .55684 .60641 L F
0 .216 .679 r
.55539 .60699 m .55671 .60813 L .55432 .60656 L F
.55539 .60699 m .55432 .60656 L .55311 .60761 L F
.628 .574 .774 r
.55432 .60656 m .55653 .60359 L .55391 .6039 L F
.55432 .60656 m .55684 .60641 L .55653 .60359 L F
.471 0 0 r
.53054 .65047 m .53388 .6495 L .53189 .64857 L F
.53054 .65047 m .53364 .65126 L .53388 .6495 L F
0 0 0 r
.53388 .6495 m .53507 .64968 L .5369 .65009 L F
.676 .545 .697 r
.53776 .65115 m .53388 .6495 L .5369 .65009 L F
.53776 .65115 m .53528 .65173 L .53388 .6495 L F
0 0 0 r
.53388 .6495 m .53364 .65126 L .53507 .64968 L F
.686 .479 .601 r
.59129 .60018 m .59406 .60044 L .59358 .59765 L F
.459 .21 .448 r
.59406 .60044 m .59632 .59744 L .59358 .59765 L F
.548 .125 .192 r
.42293 .65636 m .42549 .65654 L .42685 .65477 L F
.318 0 .047 r
.42685 .65477 m .42784 .65605 L .42892 .6542 L F
.42685 .65477 m .42549 .65654 L .42784 .65605 L F
.717 .624 .753 r
.67823 .52696 m .68143 .52812 L .68134 .5271 L F
.593 .531 .754 r
.68134 .5271 m .68143 .52812 L .68413 .52733 L F
.29 0 0 r
.46914 .70014 m .46767 .70169 L .46542 .70206 L F
.569 .117 .139 r
.47097 .70139 m .46767 .70169 L .46914 .70014 L F
.94 .808 .685 r
.65454 .49054 m .65269 .49213 L .65364 .4901 L F
.65454 .49054 m .65402 .49319 L .65269 .49213 L F
.892 .839 .787 r
.65575 .49046 m .65269 .49213 L .65364 .4901 L F
.65575 .49046 m .65402 .49319 L .65269 .49213 L F
.595 .473 .684 r
.57556 .62523 m .5748 .63054 L .57375 .626 L F
.9 .644 .541 r
.54556 .6317 m .54376 .63338 L .54354 .63112 L F
.54556 .6317 m .54558 .63412 L .54376 .63338 L F
.835 .745 .765 r
.72094 .5093 m .72371 .51026 L .72467 .50758 L F
.863 .693 .669 r
.72094 .5093 m .72375 .51323 L .72371 .51026 L F
.37 .687 .98 r
.54963 .77585 m .54738 .77577 L .54873 .77481 L F
.54963 .77585 m .54738 .77577 L .54873 .77481 L F
.384 .76 .991 r
.24552 .66768 m .24643 .66765 L .24761 .66849 L F
.953 .796 .649 r
.24643 .66765 m .24718 .67087 L .24761 .66849 L F
0 0 .078 r
.28709 .64579 m .28942 .64203 L .28499 .64239 L F
.28709 .64579 m .28793 .64535 L .28942 .64203 L F
.052 .139 .637 r
.28709 .64579 m .28839 .64732 L .28793 .64535 L F
.378 0 0 r
.68795 .47625 m .68797 .47767 L .68488 .47667 L F
.21 0 0 r
.68967 .47697 m .68795 .47625 L .69039 .47584 L F
.68967 .47697 m .68797 .47767 L .68795 .47625 L F
.411 0 0 r
.69552 .47668 m .69272 .47497 L .69391 .47598 L F
0 .286 .739 r
.48643 .80239 m .48684 .80305 L .48427 .80097 L F
.583 .935 .937 r
.48643 .80239 m .48684 .80305 L .48319 .80443 L F
.608 .434 .621 r
.51506 .77569 m .51764 .77659 L .51769 .77322 L F
.753 .674 .774 r
.51375 .77255 m .51506 .77569 L .51769 .77322 L F
.634 .233 .267 r
.51697 .77746 m .51764 .77659 L .51506 .77569 L F
0 0 0 r
.47778 .76976 m .48006 .7669 L .47782 .76728 L F
.553 .439 .677 r
.54835 .74166 m .55167 .74408 L .55125 .74222 L F
.727 .358 .352 r
.55125 .74222 m .55167 .74408 L .55512 .74414 L F
.017 0 0 r
.45398 .64498 m .45524 .64503 L .45684 .64342 L F
.023 0 0 r
.45398 .64498 m .45295 .64559 L .45524 .64503 L F
.26 .708 .958 r
.69946 .47731 m .69552 .47668 L .6971 .4775 L F
.803 .744 .798 r
.71142 .46943 m .71595 .46878 L .71479 .46753 L F
.71142 .46943 m .71245 .47213 L .71595 .46878 L F
.658 .582 .759 r
.71846 .46757 m .71595 .46878 L .71474 .46457 L F
.234 .384 .81 r
.71595 .46878 m .71668 .46679 L .71479 .46753 L F
.996 .786 .501 r
.71846 .46757 m .718 .4698 L .71595 .46878 L F
.234 .384 .81 r
.71595 .46878 m .718 .4698 L .71668 .46679 L F
0 .355 .805 r
.71595 .46878 m .718 .4698 L .71479 .46753 L F
.755 .715 .815 r
.69766 .50962 m .70105 .51008 L .70013 .50687 L F
.737 .705 .82 r
.70013 .50687 m .70105 .51008 L .7036 .50763 L F
.355 .611 .946 r
.36775 .59073 m .36966 .5909 L .36895 .59227 L F
.504 .79 .997 r
.36966 .5909 m .37109 .59188 L .36895 .59227 L F
.752 .955 .94 r
.27768 .64157 m .27935 .64016 L .2796 .64276 L F
.826 .769 .799 r
.73887 .48148 m .73573 .48143 L .73795 .47844 L F
.701 .701 .847 r
.74111 .47929 m .73887 .48148 L .73795 .47844 L F
.531 .397 .643 r
.45655 .6592 m .45677 .66188 L .45434 .65926 L F
.481 .389 .675 r
.45677 .66188 m .45488 .66257 L .45434 .65926 L F
.816 .573 .571 r
.48757 .79836 m .48427 .80097 L .48651 .79743 L F
.16 .693 .847 r
.48826 .79806 m .48757 .79836 L .48651 .79743 L F
0 .235 .671 r
.48815 .79787 m .48826 .79806 L .4868 .79699 L F
.681 .55 .699 r
.48972 .79824 m .48747 .80082 L .48757 .79836 L F
.48972 .79824 m .49095 .80095 L .48747 .80082 L F
.16 .693 .847 r
.48826 .79806 m .48972 .79824 L .48841 .79831 L F
.555 0 0 r
.49065 .7995 m .48972 .79824 L .48826 .79806 L F
0 .235 .671 r
.49065 .7995 m .48826 .79806 L .48815 .79787 L F
.16 .693 .847 r
.48826 .79806 m .48841 .79831 L .48757 .79836 L F
.255 .007 .333 r
.57422 .58842 m .57196 .58969 L .57396 .58696 L F
.447 .744 .991 r
.4855 .79415 m .48392 .79524 L .48275 .79249 L F
.584 .357 .537 r
.48392 .79524 m .48651 .79743 L .48383 .79785 L F
.978 .839 .441 r
.56564 .76402 m .56576 .76708 L .56645 .76474 L F
.423 .472 .806 r
.42484 .69225 m .42344 .69413 L .42222 .69069 L F
.437 .492 .818 r
.42484 .69225 m .42602 .69503 L .42344 .69413 L F
.787 .825 .881 r
.70865 .46452 m .70542 .46426 L .70762 .46334 L F
.809 .799 .842 r
.70865 .46452 m .70678 .46561 L .70542 .46426 L F
.601 .878 .992 r
.53586 .60128 m .53703 .59974 L .53809 .60034 L F
.53586 .60128 m .53461 .60059 L .53703 .59974 L F
.429 0 0 r
.51391 .81168 m .51569 .81249 L .50989 .81166 L F
.834 .702 .718 r
.71462 .48527 m .7149 .48123 L .71596 .48217 L F
.71462 .48527 m .71269 .48241 L .7149 .48123 L F
.71462 .48527 m .71258 .48484 L .71269 .48241 L F
.981 .914 .633 r
.71462 .48527 m .71317 .48622 L .71258 .48484 L F
.71462 .48527 m .71375 .48731 L .71317 .48622 L F
.66 .651 .83 r
.52113 .80675 m .52243 .80976 L .52328 .80787 L F
.384 .115 .378 r
.57377 .64722 m .57459 .64796 L .57258 .64839 L F
.384 .257 .581 r
.57459 .64796 m .57315 .65168 L .57258 .64839 L F
.57459 .64796 m .57494 .65085 L .57315 .65168 L F
.6 .578 .8 r
.57335 .64709 m .57575 .649 L .57459 .64796 L F
.493 .334 .593 r
.57687 .64989 m .57494 .65085 L .57459 .64796 L F
.6 .578 .8 r
.57575 .649 m .57687 .64989 L .57459 .64796 L F
.384 .115 .378 r
.57487 .64612 m .57459 .64796 L .57377 .64722 L F
.528 .385 .63 r
.57692 .64258 m .57719 .64562 L .57487 .64612 L F
.631 .428 .588 r
.57719 .64562 m .57459 .64796 L .57487 .64612 L F
.579 .279 .423 r
.58869 .61504 m .58804 .61888 L .58568 .61719 L F
.527 .337 .567 r
.59149 .61415 m .58869 .61504 L .58849 .61463 L F
.59149 .61415 m .59102 .61585 L .58869 .61504 L F
.549 .28 .46 r
.58869 .61504 m .59046 .61871 L .58804 .61888 L F
.58869 .61504 m .59102 .61585 L .59046 .61871 L F
.633 .604 .803 r
.26642 .62313 m .26791 .62029 L .26571 .62062 L F
.26642 .62313 m .26909 .62309 L .26791 .62029 L F
.197 .335 .778 r
.26642 .62313 m .26877 .62484 L .26817 .62479 L F
.26642 .62313 m .26817 .62479 L .26909 .62309 L F
0 0 .076 r
.24718 .67087 m .24614 .67347 L .24554 .67405 L F
0 0 0 r
.24614 .67347 m .24514 .67635 L .24554 .67405 L F
.881 .847 .806 r
.69292 .4988 m .68956 .5007 L .69115 .49755 L F
.69292 .4988 m .69051 .50215 L .68956 .5007 L F
.435 .52 .846 r
.56598 .71638 m .56737 .71935 L .56893 .71802 L F
.434 .517 .844 r
.56737 .71935 m .57027 .72109 L .56893 .71802 L F
.384 .281 .613 r
.47446 .80385 m .47654 .80607 L .47592 .80342 L F
.47446 .80385 m .47402 .80688 L .47654 .80607 L F
.803 .961 .913 r
.69243 .47035 m .69243 .46851 L .69532 .46852 L F
.69243 .47035 m .69156 .46969 L .69243 .46851 L F
.509 .374 .633 r
.47435 .80879 m .47654 .80607 L .47402 .80688 L F
.076 .573 .893 r
.54231 .74478 m .54377 .74565 L .53998 .74433 L F
.592 .815 .985 r
.54377 .74565 m .54472 .74372 L .54231 .74478 L F
.21 0 .297 r
.51981 .77029 m .51769 .77322 L .51951 .7725 L F
.573 .384 .587 r
.51951 .7725 m .52156 .76946 L .51981 .77029 L F
.635 .673 .869 r
.71522 .5092 m .71633 .51125 L .71862 .51023 L F
.159 .7 .777 r
.68488 .47667 m .68113 .47701 L .68258 .4776 L F
.518 .855 .995 r
.49275 .79154 m .49461 .79235 L .49179 .79285 L F
.763 .624 .706 r
.49461 .79235 m .49225 .7951 L .49179 .79285 L F
0 0 .419 r
.49179 .79285 m .49296 .79407 L .49275 .79154 L F
.49179 .79285 m .49225 .7951 L .49296 .79407 L F
.352 0 0 r
.66892 .47913 m .66702 .47931 L .66483 .47912 L F
.428 .256 .543 r
.40213 .66537 m .40432 .66205 L .40204 .66288 L F
.555 .723 .952 r
.53777 .7592 m .54051 .75951 L .53993 .75851 L F
0 .446 .771 r
.56363 .75484 m .56668 .75596 L .56394 .75303 L F
.326 0 0 r
.31291 .64804 m .3165 .64858 L .31468 .64847 L F
0 .547 .79 r
.3165 .64858 m .31704 .64843 L .31468 .64847 L F
.3165 .64858 m .31892 .64895 L .31704 .64843 L F
.562 .35 .55 r
.58355 .61707 m .58082 .62026 L .58121 .61741 L F
.594 .024 0 r
.53599 .61959 m .53206 .6172 L .53414 .61942 L F
.302 .773 .657 r
.56793 .59256 m .56629 .59331 L .56939 .59251 L F
.56793 .59256 m .56505 .59385 L .56629 .59331 L F
.622 .448 .626 r
.57258 .64839 m .57315 .65168 L .56995 .65164 L F
0 0 0 r
.55085 .7639 m .54887 .76744 L .55 .76598 L F
.658 .39 .503 r
.55 .76598 m .55346 .76452 L .55085 .7639 L F
.079 0 0 r
.52526 .64918 m .52279 .64938 L .52228 .64944 L F
.989 .794 .551 r
.52849 .79591 m .52687 .79751 L .52715 .79402 L F
.474 .275 .529 r
.52917 .79478 m .52849 .79591 L .52984 .79452 L F
.52917 .79478 m .52687 .79751 L .52849 .79591 L F
.308 .349 .741 r
.66288 .48876 m .6634 .49233 L .6612 .49074 L F
.971 .892 .691 r
.72677 .48796 m .72857 .48752 L .72765 .48652 L F
.72677 .48796 m .72742 .49067 L .72857 .48752 L F
.976 .918 .665 r
.61089 .57424 m .61032 .57355 L .61199 .57247 L F
.964 .94 .673 r
.61199 .57247 m .61271 .56843 L .61306 .56885 L F
.61199 .57247 m .61118 .57204 L .61271 .56843 L F
.959 .946 .687 r
.61199 .57247 m .61032 .57355 L .61118 .57204 L F
.798 .861 .896 r
.48721 .81092 m .48997 .80963 L .48854 .8087 L F
.549 .486 .738 r
.48997 .80963 m .4887 .80647 L .48854 .8087 L F
.172 .692 .882 r
.34129 .60074 m .33981 .60041 L .33761 .60045 L F
0 0 0 r
.34326 .59981 m .33981 .60041 L .34129 .60074 L F
.345 .669 .975 r
.42602 .69503 m .42807 .69515 L .42725 .69606 L F
.266 .551 .928 r
.42807 .69515 m .42919 .69679 L .42725 .69606 L F
.466 .294 .563 r
.43229 .67308 m .43025 .6712 L .43283 .67119 L F
.43229 .67308 m .43026 .67359 L .43025 .6712 L F
.506 .319 .562 r
.26124 .59792 m .26337 .59742 L .26352 .59486 L F
.537 .424 .672 r
.26157 .6004 m .26337 .59742 L .26124 .59792 L F
.01 0 .368 r
.62402 .57994 m .62297 .58326 L .62314 .58087 L F
.658 .55 .721 r
.54825 .7696 m .55 .76598 L .54887 .76744 L F
.723 .57 .682 r
.55031 .75245 m .55401 .75566 L .5535 .75332 L F
.853 .995 .828 r
.54822 .59195 m .54865 .58972 L .55072 .5893 L F
.54822 .59195 m .54753 .59154 L .54865 .58972 L F
.756 .767 .861 r
.27671 .64606 m .27801 .64791 L .27473 .64863 L F
.354 0 0 r
.27473 .64863 m .27801 .64791 L .27724 .64864 L F
.08 .401 .856 r
.27913 .64765 m .27801 .64791 L .27671 .64606 L F
0 0 0 r
.27724 .64864 m .27801 .64791 L .27913 .64765 L F
.595 .934 .951 r
.4875 .64495 m .48669 .64614 L .48881 .64525 L F
.4875 .64495 m .48566 .64585 L .48669 .64614 L F
.292 .681 .974 r
.36633 .5897 m .36539 .59062 L .36383 .58962 L F
.36633 .5897 m .36775 .59073 L .36539 .59062 L F
.706 .843 .948 r
.47702 .79495 m .47468 .79515 L .47672 .7944 L F
.781 .824 .887 r
.47921 .79203 m .47702 .79495 L .47672 .7944 L F
.777 .997 .808 r
.63164 .50716 m .62931 .50945 L .63031 .50822 L F
.554 .737 .961 r
.63043 .5103 m .63034 .50868 L .62931 .50945 L F
.63043 .5103 m .63329 .50998 L .63093 .50859 L F
.549 .372 .594 r
.63026 .50851 m .63182 .50757 L .63164 .50716 L F
.62931 .50945 m .63052 .50854 L .63026 .50851 L F
.63052 .50854 m .63182 .50757 L .63026 .50851 L F
.335 .663 .973 r
.63249 .50876 m .63329 .50998 L .63528 .50908 L F
.63093 .50859 m .63226 .50938 L .63249 .50876 L F
.63226 .50938 m .63329 .50998 L .63249 .50876 L F
.549 .372 .594 r
.63204 .50845 m .63222 .50847 L .63219 .5084 L F
.554 .737 .961 r
.63043 .5103 m .63093 .50859 L .63034 .50868 L F
.549 .372 .594 r
.62931 .50945 m .63222 .50847 L .63204 .50845 L F
.62931 .50945 m .63256 .50924 L .63222 .50847 L F
.63034 .50868 m .63219 .5084 L .63182 .50757 L F
.62931 .50945 m .63219 .5084 L .63034 .50868 L F
.496 .347 .608 r
.63164 .50716 m .63235 .50875 L .63563 .50892 L F
.335 .663 .973 r
.63235 .50875 m .63528 .50908 L .63534 .50906 L F
.63457 .50887 m .63534 .50906 L .63563 .50892 L F
.63235 .50875 m .63534 .50906 L .63457 .50887 L F
.496 .347 .608 r
.63235 .50875 m .63256 .50924 L .63563 .50892 L F
.335 .663 .973 r
.63093 .50859 m .63235 .50875 L .63563 .50892 L F
.557 .254 .41 r
.63031 .50822 m .63563 .50892 L .63164 .50716 L F
.335 .663 .973 r
.63031 .50822 m .63093 .50859 L .63563 .50892 L F
.419 .804 .99 r
.63043 .5103 m .63256 .50924 L .62931 .50945 L F
.63043 .5103 m .63329 .50998 L .63256 .50924 L F
.623 .172 .158 r
.63262 .50838 m .63299 .50884 L .6329 .50764 L F
.63299 .50884 m .63346 .50943 L .63318 .50854 L F
.63299 .50884 m .63318 .50854 L .6329 .50764 L F
.359 .766 .983 r
.63481 .50901 m .63329 .50998 L .63266 .50934 L F
.63274 .50922 m .63266 .50934 L .63256 .50924 L F
.63481 .50901 m .63266 .50934 L .63274 .50922 L F
.63563 .50892 m .63534 .50906 L .63481 .50901 L F
.63534 .50906 m .63329 .50998 L .63481 .50901 L F
.623 .172 .158 r
.63299 .50884 m .62958 .5097 L .63346 .50943 L F
.63262 .50838 m .63183 .50873 L .63299 .50884 L F
.63183 .50873 m .62958 .5097 L .63299 .50884 L F
.63164 .50716 m .63097 .50798 L .63262 .50838 L F
.63097 .50798 m .62958 .5097 L .63262 .50838 L F
.63164 .50716 m .63262 .50838 L .63277 .50724 L F
.63262 .50838 m .6329 .50764 L .63277 .50724 L F
.554 .737 .961 r
.63034 .50868 m .63093 .50859 L .63031 .50822 L F
.63034 .50868 m .63031 .50822 L .62931 .50945 L F
.989 .738 .45 r
.62931 .50945 m .63048 .51217 L .63043 .5103 L F
0 0 0 r
.56939 .59251 m .57196 .58969 L .57114 .59072 L F
.237 0 .241 r
.57422 .58842 m .57114 .59072 L .57196 .58969 L F
.669 .767 .285 r
.53208 .69422 m .53234 .69373 L .53468 .69349 L F
.589 .022 0 r
.52885 .69226 m .53063 .69377 L .532 .69441 L F
.669 .767 .285 r
.53225 .6939 m .53144 .69584 L .53234 .69373 L F
.53203 .69434 m .53144 .69584 L .53225 .6939 L F
.635 .617 .815 r
.53214 .69447 m .53144 .69584 L .53208 .69422 L F
.589 .022 0 r
.53201 .69439 m .532 .69441 L .53214 .69447 L F
.52885 .69226 m .532 .69441 L .53201 .69439 L F
.669 .767 .285 r
.53208 .69422 m .53203 .69434 L .53225 .6939 L F
0 0 0 r
.52175 .77461 m .5205 .77493 L .52379 .7747 L F
.52175 .77461 m .52008 .77559 L .5205 .77493 L F
.725 .461 .527 r
.60297 .552 m .60166 .55243 L .60105 .54966 L F
.728 .461 .523 r
.60434 .55191 m .60105 .54966 L .60319 .54975 L F
.60434 .55191 m .60297 .552 L .60105 .54966 L F
0 0 .038 r
.73645 .51502 m .7348 .51581 L .73708 .51294 L F
.668 .2 .132 r
.73386 .51707 m .73732 .51758 L .7348 .51581 L F
.73386 .51707 m .7348 .51581 L .73645 .51502 L F
.326 .056 .342 r
.5496 .77339 m .5514 .77038 L .54825 .7696 L F
0 0 .045 r
.55312 .76908 m .55093 .77207 L .55149 .76994 L F
.326 .056 .342 r
.5514 .77038 m .55162 .77002 L .55151 .77001 L F
.5514 .77038 m .55151 .77001 L .54825 .7696 L F
0 0 0 r
.55108 .77151 m .55046 .77339 L .55149 .76994 L F
.55093 .77207 m .55085 .77228 L .55108 .77151 L F
.55085 .77228 m .55046 .77339 L .55108 .77151 L F
.226 .298 .729 r
.55177 .76681 m .55312 .76908 L .55149 .76994 L F
.32 .116 .439 r
.30008 .6146 m .29977 .61677 L .2981 .61743 L F
.507 .322 .564 r
.30011 .61893 m .2981 .61743 L .29977 .61677 L F
.30011 .61893 m .29791 .61957 L .2981 .61743 L F
.829 .964 .638 r
.24865 .64454 m .24841 .64604 L .25046 .64287 L F
.303 0 0 r
.24843 .64399 m .24865 .64454 L .25046 .64287 L F
0 0 .082 r
.57775 .58003 m .57751 .58232 L .57685 .58404 L F
.793 .997 .79 r
.57685 .58404 m .57484 .58507 L .57576 .58585 L F
.57685 .58404 m .57751 .58232 L .57484 .58507 L F
.512 .434 .705 r
.56248 .71095 m .56514 .71277 L .56457 .7109 L F
.519 .433 .698 r
.56297 .71303 m .56514 .71277 L .56248 .71095 L F
.696 .657 .807 r
.70819 .49971 m .70451 .49882 L .70678 .49783 L F
.699 .636 .783 r
.71033 .4986 m .70819 .49971 L .70678 .49783 L F
.448 .206 .454 r
.59632 .59744 m .59885 .597 L .59881 .59466 L F
.437 .27 .555 r
.59885 .597 m .60065 .59377 L .59881 .59466 L F
.698 .69 .839 r
.67823 .52696 m .68134 .5271 L .67946 .52306 L F
.651 .667 .852 r
.67946 .52306 m .68134 .5271 L .68269 .52398 L F
.593 .531 .754 r
.68134 .5271 m .68413 .52733 L .68269 .52398 L F
.456 .485 .801 r
.40286 .69376 m .40348 .69009 L .40143 .69048 L F
.40286 .69376 m .40457 .69325 L .40348 .69009 L F
.236 .361 .787 r
.40286 .69376 m .40522 .69561 L .40457 .69325 L F
.521 .014 0 r
.65402 .49319 m .65479 .49403 L .65269 .49213 L F
.65402 .49319 m .65589 .49507 L .65479 .49403 L F
.709 .587 .717 r
.54802 .73895 m .54575 .7418 L .54835 .74166 L F
.811 .601 .618 r
.54751 .74354 m .54835 .74166 L .54575 .7418 L F
.54751 .74354 m .54912 .74496 L .54835 .74166 L F
.553 .439 .677 r
.54835 .74166 m .54912 .74496 L .55167 .74408 L F
.83 .967 .892 r
.66605 .50499 m .66524 .50732 L .66793 .5048 L F
.866 .99 .729 r
.66605 .50499 m .66486 .50686 L .66524 .50732 L F
.461 0 .027 r
.46101 .7016 m .45945 .70242 L .45722 .70226 L F
.369 0 0 r
.46297 .70186 m .45945 .70242 L .46101 .7016 L F
.865 .518 .392 r
.24841 .64604 m .24642 .64739 L .24646 .64553 L F
.822 .989 .729 r
.24865 .64454 m .24642 .64739 L .24841 .64604 L F
.188 0 .288 r
.61159 .60034 m .61162 .60267 L .60955 .60319 L F
0 0 0 r
.61374 .59733 m .61258 .59942 L .61159 .60034 L F
.009 0 .253 r
.61287 .60091 m .61159 .60034 L .61258 .59942 L F
.61287 .60091 m .61162 .60267 L .61159 .60034 L F
.63 .743 .929 r
.67533 .5096 m .67251 .5104 L .67083 .50952 L F
.67533 .5096 m .67458 .51026 L .67251 .5104 L F
.595 .4 .588 r
.50611 .80375 m .50875 .80302 L .50765 .80151 L F
.737 .601 .706 r
.50875 .80302 m .51185 .80132 L .50765 .80151 L F
.553 .356 .569 r
.34848 .6203 m .35076 .61996 L .35084 .61749 L F
.489 .298 .547 r
.35084 .61749 m .35292 .61698 L .35305 .6146 L F
.38 .217 .531 r
.35084 .61749 m .35244 .6188 L .35292 .61698 L F
.35084 .61749 m .35076 .61996 L .35244 .6188 L F
.977 .756 .536 r
.55693 .75582 m .55539 .75791 L .55401 .75566 L F
.55693 .75582 m .55659 .75866 L .55539 .75791 L F
.691 .561 .703 r
.54619 .73978 m .54575 .7418 L .54802 .73895 L F
.69 .368 .425 r
.56993 .70655 m .57186 .70676 L .57271 .70447 L F
.076 0 0 r
.57271 .70447 m .57535 .7035 L .57571 .70308 L F
.635 .398 .541 r
.57186 .70676 m .57535 .7035 L .57271 .70447 L F
.795 .397 .3 r
.54575 .7418 m .54472 .74372 L .54751 .74354 L F
.754 .708 .808 r
.54601 .74478 m .54698 .74745 L .54912 .74496 L F
.996 .844 .502 r
.6335 .53567 m .63236 .53712 L .63307 .53787 L F
.982 .855 .474 r
.6336 .53089 m .63299 .53478 L .6335 .53567 L F
.983 .876 .516 r
.63299 .53478 m .63236 .53712 L .6335 .53567 L F
.028 0 0 r
.45684 .64342 m .45735 .64412 L .45876 .6428 L F
.45684 .64342 m .45524 .64503 L .45735 .64412 L F
.551 .388 .613 r
.51769 .77322 m .52008 .77559 L .51951 .7725 L F
.51769 .77322 m .51764 .77659 L .52008 .77559 L F
.973 .922 .678 r
.63143 .55973 m .63309 .55861 L .6313 .55731 L F
.63143 .55973 m .63213 .56057 L .63309 .55861 L F
.757 .85 .92 r
.67072 .48292 m .67132 .48436 L .67453 .48243 L F
.427 .845 .962 r
.34739 .59958 m .34548 .59923 L .34326 .59981 L F
.022 .593 .759 r
.34933 .59946 m .34548 .59923 L .34739 .59958 L F
.215 .737 .749 r
.38613 .60894 m .38655 .60881 L .38436 .60934 L F
.343 .047 .309 r
.38573 .61044 m .38436 .60934 L .38655 .60881 L F
.38573 .61044 m .38379 .61102 L .38436 .60934 L F
.355 .083 .355 r
.60309 .53273 m .60063 .53534 L .60275 .53447 L F
.062 0 .201 r
.60275 .53447 m .60483 .53155 L .60309 .53273 L F
.586 .192 .261 r
.46615 .69529 m .46987 .69352 L .46755 .69379 L F
0 0 0 r
.54963 .77585 m .55046 .77339 L .55093 .77207 L F
.517 .339 .578 r
.25941 .60321 m .2616 .60273 L .26157 .6004 L F
.491 .389 .667 r
.25941 .60321 m .26177 .60527 L .2616 .60273 L F
.25941 .60321 m .25972 .60664 L .26177 .60527 L F
.247 0 0 r
.57114 .59072 m .56793 .59256 L .56939 .59251 L F
.553 .42 .654 r
.76624 .59474 m .76333 .59252 L .76583 .5919 L F
.76624 .59474 m .76394 .59634 L .76333 .59252 L F
.705 .702 .844 r
.58706 .71841 m .58368 .71758 L .5849 .7189 L F
.585 .387 .579 r
.57146 .60338 m .57168 .60593 L .57391 .60301 L F
.494 .002 .016 r
.4805 .69997 m .47906 .70135 L .47675 .70106 L F
.529 .041 .041 r
.48246 .70111 m .47906 .70135 L .4805 .69997 L F
.547 .279 .461 r
.34042 .62577 m .3427 .62559 L .34355 .62315 L F
.409 .113 .349 r
.3427 .62559 m .34572 .62226 L .34355 .62315 L F
.676 .543 .695 r
.53776 .65115 m .53462 .65429 L .53528 .65173 L F
.661 .961 .759 r
.66176 .47685 m .65877 .47924 L .66034 .47743 L F
.779 .535 .567 r
.66034 .47743 m .66365 .47544 L .66176 .47685 L F
.511 .552 .834 r
.7172 .49003 m .71984 .49349 L .71976 .49309 L F
.407 .093 .318 r
.3124 .6034 m .31172 .6056 L .30989 .60558 L F
.289 0 .27 r
.31338 .60504 m .3124 .6034 L .31477 .60323 L F
.31338 .60504 m .31172 .6056 L .3124 .6034 L F
.229 0 .137 r
.60955 .60319 m .60899 .60506 L .60687 .60589 L F
.126 0 .101 r
.61162 .60267 m .60899 .60506 L .60955 .60319 L F
.493 .241 .46 r
.42615 .6798 m .42585 .68188 L .42364 .68231 L F
.192 0 .362 r
.4275 .68093 m .42615 .6798 L .42828 .67955 L F
.4275 .68093 m .42585 .68188 L .42615 .6798 L F
.686 .738 .89 r
.5063 .77758 m .50649 .77882 L .50334 .77843 L F
.747 .618 .716 r
.50334 .77843 m .50649 .77882 L .50521 .78085 L F
.702 .558 .689 r
.50649 .77882 m .50731 .78199 L .50521 .78085 L F
.389 .513 .862 r
.50798 .77757 m .50649 .77882 L .5063 .77758 L F
.818 .58 .579 r
.56995 .65164 m .56652 .65332 L .56668 .6515 L F
.56995 .65164 m .56973 .65623 L .56652 .65332 L F
0 0 .076 r
.57019 .65262 m .56995 .65164 L .57236 .65177 L F
.5701 .65224 m .56979 .65558 L .56995 .65164 L F
.56979 .65558 m .56973 .65623 L .56977 .65546 L F
.56979 .65558 m .56977 .65546 L .56995 .65164 L F
.56986 .6552 m .56977 .65592 L .5701 .65224 L F
.56977 .65592 m .56973 .65623 L .56976 .65594 L F
.56977 .65592 m .56976 .65594 L .5701 .65224 L F
.136 .185 .65 r
.56998 .65571 m .57019 .65262 L .5709 .65477 L F
.538 .877 .62 r
.5709 .65477 m .57003 .65551 L .56998 .65571 L F
.136 .185 .65 r
.56998 .65571 m .56973 .65623 L .57019 .65262 L F
.683 .559 .708 r
.56998 .65571 m .56652 .65332 L .56958 .65609 L F
.56998 .65571 m .56958 .65609 L .56973 .65623 L F
.194 .067 .469 r
.56866 .65667 m .56982 .65574 L .56983 .65582 L F
.683 .559 .708 r
.56998 .65571 m .56982 .65574 L .56983 .65561 L F
.538 .877 .62 r
.57003 .65551 m .56866 .65667 L .56983 .65582 L F
.194 .067 .469 r
.56983 .65582 m .56982 .65574 L .56998 .65571 L F
.538 .877 .62 r
.57003 .65551 m .56983 .65582 L .56998 .65571 L F
.194 .067 .469 r
.56866 .65667 m .56717 .65612 L .56982 .65574 L F
.683 .559 .708 r
.56983 .65561 m .56717 .65612 L .56652 .65332 L F
.56982 .65574 m .56717 .65612 L .56983 .65561 L F
0 0 .076 r
.57019 .65262 m .56986 .6552 L .5701 .65224 L F
.096 0 0 r
.57315 .65168 m .57236 .65177 L .56995 .65164 L F
.34 0 .203 r
.34572 .62226 m .34786 .6222 L .34848 .6203 L F
0 0 .066 r
.34848 .6203 m .34913 .62136 L .35076 .61996 L F
.34848 .6203 m .34786 .6222 L .34913 .62136 L F
.723 .674 .802 r
.26579 .62993 m .26501 .63109 L .2673 .62892 L F
.747 .736 .842 r
.26381 .62839 m .26579 .62993 L .2673 .62892 L F
.752 .729 .832 r
.26381 .62839 m .26501 .63109 L .2673 .62892 L F
.605 .757 .951 r
.26501 .63109 m .26882 .63127 L .2673 .62892 L F
.071 0 0 r
.43531 .70893 m .43526 .70741 L .43748 .70728 L F
.43465 .70904 m .43297 .70932 L .4353 .70868 L F
0 0 0 r
.43248 .70982 m .43224 .71085 L .43185 .71045 L F
.43297 .70932 m .43281 .70966 L .43248 .70982 L F
.43281 .70966 m .43224 .71085 L .43248 .70982 L F
.071 0 0 r
.43531 .70893 m .43465 .70904 L .4353 .70868 L F
.293 .177 .546 r
.43489 .70869 m .43297 .70932 L .43531 .70893 L F
.077 0 0 r
.43489 .70869 m .43224 .71085 L .43297 .70932 L F
.835 .946 .894 r
.43107 .71034 m .43436 .70893 L .4332 .70937 L F
.071 0 0 r
.4353 .70868 m .43297 .70932 L .43526 .70741 L F
.835 .946 .894 r
.43436 .70893 m .43489 .70869 L .43457 .70882 L F
.43436 .70893 m .43457 .70882 L .4332 .70937 L F
.43107 .71034 m .43177 .71065 L .43489 .70869 L F
.43177 .71065 m .43224 .71085 L .43405 .70938 L F
.43177 .71065 m .43405 .70938 L .43489 .70869 L F
.281 0 .029 r
.54299 .68836 m .5418 .69009 L .53957 .69056 L F
.339 0 .187 r
.54479 .68746 m .5418 .69009 L .54299 .68836 L F
.756 .814 .898 r
.69782 .46817 m .69532 .46852 L .69717 .46709 L F
.61 .733 .932 r
.69717 .46709 m .70066 .46778 L .69782 .46817 L F
.475 0 0 r
.73708 .51294 m .73879 .51428 L .73645 .51502 L F
.73708 .51294 m .73924 .51353 L .73879 .51428 L F
.861 .511 .003 r
.53462 .65429 m .53448 .6551 L .53367 .65337 L F
0 0 .541 r
.53448 .6551 m .53456 .65373 L .53367 .65337 L F
.53456 .65373 m .53468 .65158 L .53367 .65337 L F
0 .32 .76 r
.53254 .6529 m .53367 .65337 L .53136 .65212 L F
.53462 .65429 m .53367 .65337 L .53254 .6529 L F
.861 .511 .003 r
.53462 .65429 m .53529 .65656 L .53448 .6551 L F
.535 .207 .359 r
.57535 .7035 m .57753 .70257 L .57571 .70308 L F
.781 .361 .252 r
.54572 .77749 m .54631 .78045 L .54408 .77762 L F
.54572 .77749 m .54761 .78006 L .54631 .78045 L F
.811 .67 .707 r
.55097 .60569 m .55391 .6039 L .55322 .60264 L F
.567 .699 .93 r
.55391 .6039 m .55538 .60237 L .55322 .60264 L F
.55391 .6039 m .55653 .60359 L .55538 .60237 L F
.733 .652 .768 r
.25462 .62515 m .25602 .62769 L .25724 .62581 L F
.82 .759 .795 r
.66155 .479 m .66483 .47912 L .66377 .47798 L F
.66155 .479 m .66258 .48185 L .66483 .47912 L F
.504 .686 .948 r
.66483 .47912 m .6662 .47728 L .66377 .47798 L F
.66483 .47912 m .66702 .47931 L .6662 .47728 L F
.824 .607 .609 r
.5927 .702 m .59262 .70449 L .59573 .70499 L F
.916 .761 .674 r
.59287 .70679 m .59573 .70499 L .59262 .70449 L F
.59287 .70679 m .59437 .70762 L .59573 .70499 L F
.818 .998 .783 r
.55127 .58752 m .55333 .58648 L .55072 .5893 L F
.879 .971 .658 r
.55507 .5834 m .55333 .58648 L .55353 .58465 L F
.863 .996 .778 r
.55353 .58465 m .55333 .58648 L .55127 .58752 L F
.212 0 0 r
.34117 .588 m .34311 .58847 L .34459 .58871 L F
.186 .707 .873 r
.34459 .58871 m .34311 .58847 L .34675 .58861 L F
.135 0 .054 r
.4407 .6656 m .43953 .6676 L .43815 .66755 L F
.293 0 .06 r
.43894 .66923 m .43815 .66755 L .43953 .6676 L F
.43894 .66923 m .43673 .66975 L .43815 .66755 L F
.684 .51 .645 r
.61504 .5467 m .61255 .54911 L .61144 .54671 L F
.567 .37 .574 r
.26352 .59486 m .26561 .59689 L .26582 .59454 L F
.26352 .59486 m .26337 .59742 L .26561 .59689 L F
.885 .877 .822 r
.50691 .69931 m .50469 .70244 L .50319 .70178 L F
.675 .183 .07 r
.50665 .70254 m .50319 .70178 L .50469 .70244 L F
.835 .745 .765 r
.72094 .5093 m .72467 .50758 L .72336 .50649 L F
.59 .863 .994 r
.6836 .47118 m .68583 .47045 L .68688 .47129 L F
.585 .861 .995 r
.68688 .47129 m .68832 .46967 L .68921 .47055 L F
.68688 .47129 m .68583 .47045 L .68832 .46967 L F
.098 0 0 r
.55555 .77876 m .55666 .7785 L .55333 .7788 L F
.55555 .77876 m .55666 .7785 L .55333 .7788 L F
.769 .745 .831 r
.64677 .50627 m .64816 .5077 L .64991 .5064 L F
.311 .693 .978 r
.68254 .49372 m .6819 .4926 L .67901 .4924 L F
.726 .471 .541 r
.51573 .81144 m .51855 .80907 L .51527 .80979 L F
.658 .459 .604 r
.60673 .54956 m .60434 .55191 L .60319 .54975 L F
.744 .538 .616 r
.63822 .50502 m .63908 .50531 L .63988 .50334 L F
.63822 .50502 m .63805 .50628 L .63908 .50531 L F
.539 .106 .166 r
.6433 .50612 m .64101 .50637 L .63908 .50531 L F
.259 .318 .734 r
.63908 .50531 m .64101 .50637 L .63988 .50334 L F
.8 .997 .857 r
.55072 .5893 m .54865 .58972 L .55127 .58752 L F
.822 .828 .853 r
.67487 .52791 m .67823 .52696 L .67678 .52619 L F
.698 .69 .839 r
.67823 .52696 m .67946 .52306 L .67678 .52619 L F
.779 .7 .776 r
.50992 .64325 m .50616 .64512 L .50635 .64312 L F
.568 .317 .496 r
.50992 .64325 m .50651 .64809 L .50616 .64512 L F
.50992 .64325 m .50903 .64784 L .50651 .64809 L F
.592 .398 .587 r
.512 .6426 m .51223 .64503 L .50992 .64325 L F
.698 .439 .528 r
.51246 .64719 m .50992 .64325 L .51223 .64503 L F
.375 .747 .99 r
.31662 .58445 m .3191 .5843 L .32053 .58523 L F
.322 0 0 r
.3191 .5843 m .32259 .58526 L .32053 .58523 L F
.494 .597 .885 r
.38307 .59577 m .38174 .59769 L .38028 .59512 L F
.38307 .59577 m .38384 .5978 L .38174 .59769 L F
.977 .9 .674 r
.59388 .71249 m .5956 .71094 L .59399 .71007 L F
.59388 .71249 m .59473 .71331 L .5956 .71094 L F
.751 .534 .602 r
.60928 .55157 m .60673 .54956 L .6094 .54956 L F
.592 .396 .585 r
.61255 .54911 m .60928 .55157 L .6094 .54956 L F
.8 .787 .84 r
.70678 .46561 m .70274 .46701 L .70542 .46426 L F
.893 .913 .831 r
.63798 .52061 m .63678 .52445 L .63885 .5214 L F
.964 .915 .711 r
.63952 .51716 m .63798 .52061 L .63885 .5214 L F
.828 .471 .38 r
.56041 .75202 m .56173 .75031 L .55876 .74954 L F
.56041 .75202 m .56235 .75228 L .56173 .75031 L F
.016 .584 .781 r
.30244 .5839 m .30319 .58385 L .30508 .58418 L F
.255 .766 .81 r
.30199 .5841 m .3036 .58383 L .30319 .58385 L F
.352 .802 .948 r
.30319 .58385 m .30529 .58354 L .30717 .584 L F
.255 .766 .81 r
.3036 .58383 m .30529 .58354 L .30319 .58385 L F
.016 .584 .781 r
.30148 .5838 m .30319 .58385 L .30244 .5839 L F
.352 .802 .948 r
.30319 .58385 m .30717 .584 L .30508 .58418 L F
.747 .618 .716 r
.50334 .77843 m .50521 .78085 L .50391 .78047 L F
.742 .453 .492 r
.50713 .78279 m .50391 .78047 L .50521 .78085 L F
.703 .179 0 r
.50521 .78085 m .50731 .78199 L .50713 .78279 L F
.281 0 .139 r
.63708 .48682 m .63855 .48817 L .63925 .48602 L F
.63708 .48682 m .63634 .48891 L .63855 .48817 L F
.459 .21 .448 r
.59406 .60044 m .59611 .5999 L .59632 .59744 L F
.468 .263 .518 r
.59865 .59944 m .59632 .59744 L .59611 .5999 L F
.59865 .59944 m .59885 .597 L .59632 .59744 L F
.834 .923 .893 r
.55862 .77579 m .56034 .77249 L .55772 .77495 L F
.55862 .77579 m .56147 .77315 L .56034 .77249 L F
.778 .537 .57 r
.52423 .78303 m .522 .78592 L .52406 .78337 L F
.509 .324 .565 r
.35305 .6146 m .35518 .6141 L .35527 .61165 L F
.504 .311 .551 r
.35305 .6146 m .35292 .61698 L .35518 .6141 L F
.83 .665 .679 r
.47781 .65098 m .47528 .6483 L .47726 .64821 L F
.47781 .65098 m .47496 .65074 L .47528 .6483 L F
.582 .023 0 r
.47781 .65098 m .47371 .6506 L .47496 .65074 L F
.47781 .65098 m .47584 .6519 L .47371 .6506 L F
.579 .356 .542 r
.47871 .64911 m .47584 .6519 L .47781 .65098 L F
.341 .007 .245 r
.60063 .53534 m .60234 .53655 L .60275 .53447 L F
.60063 .53534 m .60015 .53723 L .60234 .53655 L F
.948 .589 .252 r
.6634 .49233 m .66402 .4945 L .66479 .49372 L F
.52 0 0 r
.66479 .49372 m .66402 .4945 L .66757 .49474 L F
.6 .432 .626 r
.59053 .61182 m .59149 .61415 L .58849 .61463 L F
.617 .423 .597 r
.59403 .61151 m .59149 .61415 L .59053 .61182 L F
.947 .902 .747 r
.63445 .52553 m .63678 .52445 L .63565 .52334 L F
.63445 .52553 m .6353 .5265 L .63678 .52445 L F
.893 .913 .831 r
.63798 .52061 m .63565 .52334 L .63678 .52445 L F
.645 .885 .539 r
.56032 .76724 m .55795 .77021 L .55878 .76891 L F
.633 .861 .491 r
.55878 .76891 m .55795 .77021 L .55673 .77175 L F
.986 .825 .436 r
.63822 .50502 m .63805 .50628 L .63793 .50538 L F
.392 .124 .384 r
.60112 .55671 m .59935 .55555 L .60115 .55537 L F
.60112 .55671 m .59895 .55766 L .59935 .55555 L F
.948 .829 .694 r
.73327 .4864 m .73449 .48749 L .73359 .48977 L F
.605 .734 .936 r
.26882 .63127 m .26957 .62967 L .2673 .62892 L F
.26882 .63127 m .2711 .63126 L .26957 .62967 L F
.216 0 0 r
.44572 .70502 m .4419 .70628 L .44352 .70541 L F
.583 .368 .555 r
.6018 .60613 m .60172 .60847 L .59852 .60922 L F
.597 .367 .539 r
.60408 .60588 m .60172 .60847 L .6018 .60613 L F
.125 0 0 r
.51874 .64124 m .5177 .64101 L .51625 .63979 L F
.51874 .64124 m .52019 .64126 L .5177 .64101 L F
.304 0 .24 r
.38613 .60894 m .38866 .60826 L .38655 .60881 L F
0 0 0 r
.56124 .5979 m .56047 .59931 L .55887 .60046 L F
0 0 .233 r
.56047 .59931 m .55893 .60274 L .55887 .60046 L F
.375 .106 .371 r
.35669 .63148 m .35612 .63336 L .35422 .63392 L F
.44 .161 .391 r
.35885 .63096 m .35612 .63336 L .35669 .63148 L F
.531 .481 .745 r
.26038 .60875 m .26113 .61187 L .26274 .61116 L F
.303 .185 .549 r
.26113 .61187 m .26285 .61293 L .26274 .61116 L F
.26113 .61187 m .26092 .61488 L .26285 .61293 L F
.272 0 .064 r
.35498 .63537 m .35422 .63392 L .35612 .63336 L F
.35498 .63537 m .3529 .63595 L .35422 .63392 L F
.377 .501 .857 r
.40947 .70182 m .41104 .70484 L .41192 .70291 L F
.22 .312 .746 r
.41104 .70484 m .41314 .70683 L .41192 .70291 L F
.559 0 0 r
.37627 .7078 m .37953 .70931 L .37814 .70689 L F
.16 .699 .819 r
.37953 .70931 m .37998 .70906 L .37814 .70689 L F
.37953 .70931 m .38153 .70914 L .37998 .70906 L F
.399 .711 .986 r
.54603 .75616 m .55084 .75739 L .54855 .75559 L F
.57 .609 .853 r
.55084 .75739 m .55096 .7558 L .54855 .75559 L F
.55084 .75739 m .55204 .75704 L .55096 .7558 L F
.885 .877 .822 r
.50691 .69931 m .50319 .70178 L .50601 .69963 L F
.296 .777 .688 r
.50691 .69931 m .50827 .69871 L .50894 .69859 L F
.50691 .69931 m .50601 .69963 L .50827 .69871 L F
0 0 0 r
.46477 .65431 m .46262 .65588 L .46138 .65625 L F
.046 0 .03 r
.46645 .65313 m .46477 .65431 L .46735 .65194 L F
.495 .091 .203 r
.46645 .65313 m .46262 .65588 L .46477 .65431 L F
.577 .488 .718 r
.42364 .68451 m .4243 .6876 L .42208 .68812 L F
.468 .296 .564 r
.4243 .6876 m .42222 .69069 L .42208 .68812 L F
.448 .051 .194 r
.4311 .65385 m .43348 .6535 L .43471 .65155 L F
.375 0 .152 r
.43471 .65155 m .4363 .65229 L .43689 .65133 L F
.43471 .65155 m .43348 .6535 L .4363 .65229 L F
.65 .126 0 r
.43285 .69828 m .4351 .69936 L .43625 .69906 L F
.218 .741 .796 r
.4351 .69936 m .43854 .69886 L .43625 .69906 L F
.37 0 0 r
.44068 .6981 m .44302 .69821 L .4445 .69726 L F
0 0 0 r
.4445 .69726 m .44503 .69716 L .44676 .69672 L F
.4445 .69726 m .44302 .69821 L .44503 .69716 L F
.679 .687 .85 r
.70126 .49761 m .69743 .49577 L .70007 .49538 L F
.674 .769 .922 r
.7036 .49599 m .70126 .49761 L .70007 .49538 L F
.62 .637 .846 r
.70451 .49882 m .70126 .49761 L .7036 .49599 L F
.666 .22 .181 r
.50283 .6401 m .5011 .6414 L .49897 .63993 L F
.652 .201 .168 r
.50283 .6401 m .50494 .64181 L .5011 .6414 L F
.898 .64 .54 r
.56228 .75488 m .56394 .75303 L .56235 .75228 L F
.56228 .75488 m .56363 .75484 L .56394 .75303 L F
0 .259 .72 r
.6722 .51305 m .67345 .51351 L .67114 .51231 L F
.6722 .51305 m .67475 .51466 L .67345 .51351 L F
0 .318 .797 r
.67533 .51564 m .67475 .51466 L .6722 .51305 L F
.925 .731 .621 r
.56388 .76048 m .56616 .75834 L .56485 .7574 L F
.56388 .76048 m .56611 .76078 L .56616 .75834 L F
.803 .904 .912 r
.49892 .64828 m .49614 .64886 L .49777 .64742 L F
.404 .166 .437 r
.49892 .64828 m .49653 .65153 L .49614 .64886 L F
.49892 .64828 m .49858 .65095 L .49653 .65153 L F
.563 .836 .996 r
.50138 .64755 m .49892 .64828 L .49777 .64742 L F
.316 .094 .41 r
.50033 .64999 m .49892 .64828 L .50138 .64755 L F
.50033 .64999 m .49858 .65095 L .49892 .64828 L F
.578 .938 .799 r
.54051 .75951 m .54235 .75807 L .54312 .7593 L F
.368 .609 .942 r
.53993 .75851 m .54051 .75951 L .54312 .7593 L F
.225 .734 .888 r
.32048 .63135 m .32239 .63118 L .32434 .63144 L F
.343 .775 .97 r
.32239 .63118 m .32649 .63163 L .32434 .63144 L F
.511 .552 .834 r
.7172 .49003 m .71976 .49309 L .71775 .49199 L F
.914 .632 .494 r
.71942 .49511 m .71775 .49199 L .71976 .49309 L F
.771 .895 .931 r
.48532 .62638 m .48133 .62744 L .484 .62539 L F
.785 .878 .915 r
.48735 .62493 m .48532 .62638 L .484 .62539 L F
.53 .333 .557 r
.62493 .4987 m .62737 .4983 L .62711 .49578 L F
.494 .276 .512 r
.62737 .4983 m .62981 .49512 L .62711 .49578 L F
.665 .343 .419 r
.41473 .65874 m .41735 .65889 L .41812 .65672 L F
.512 .23 .422 r
.41735 .65889 m .42023 .65624 L .41812 .65672 L F
.701 .721 .865 r
.7058 .50647 m .70927 .50714 L .70837 .50537 L F
.537 .637 .896 r
.70837 .50537 m .70927 .50714 L .71151 .5068 L F
0 0 .338 r
.6518 .5122 m .65258 .50877 L .6522 .5104 L F
.531 .402 .65 r
.4005 .67076 m .40228 .66781 L .40004 .66826 L F
.522 .674 .933 r
.65877 .47924 m .66155 .479 L .66034 .47743 L F
.769 .745 .831 r
.64677 .50627 m .64991 .5064 L .64889 .50531 L F
0 0 0 r
.62588 .57641 m .62502 .57813 L .62662 .57452 L F
0 0 .003 r
.62588 .57641 m .62402 .57994 L .62502 .57813 L F
.167 0 .154 r
.57783 .6365 m .57499 .63978 L .576 .6374 L F
.717 .434 .496 r
.57783 .65772 m .57386 .65635 L .57651 .65754 L F
.628 .763 .944 r
.72173 .47226 m .72496 .47301 L .72253 .47364 L F
0 0 .426 r
.53074 .7901 m .53154 .79157 L .53261 .78983 L F
.285 0 .038 r
.53333 .79141 m .53454 .78911 L .53261 .78983 L F
.592 .348 .516 r
.57391 .60301 m .5764 .60274 L .57676 .60056 L F
.53 .292 .499 r
.57676 .60056 m .57859 .60211 L .57832 .59986 L F
.57676 .60056 m .5764 .60274 L .57859 .60211 L F
.183 0 0 r
.50731 .78199 m .50911 .78224 L .50713 .78279 L F
.537 .424 .672 r
.26157 .6004 m .26369 .59996 L .26337 .59742 L F
.347 .131 .437 r
.2616 .60273 m .26369 .59996 L .26157 .6004 L F
.102 .649 .832 r
.34675 .58861 m .34891 .58863 L .35033 .58888 L F
.288 .771 .918 r
.35095 .58835 m .35033 .58888 L .34891 .58863 L F
.35095 .58835 m .3525 .58862 L .35033 .58888 L F
.877 .761 .731 r
.67545 .51807 m .67475 .51466 L .67533 .51564 L F
.554 .657 .904 r
.32048 .63135 m .31844 .63177 L .31738 .63012 L F
.44 .157 .386 r
.37603 .61921 m .37449 .61791 L .37654 .61717 L F
.37603 .61921 m .37389 .61972 L .37449 .61791 L F
.604 .942 .939 r
.30162 .64808 m .30123 .64749 L .29539 .64988 L F
0 0 0 r
.30162 .64808 m .30201 .64839 L .30123 .64749 L F
.30162 .64808 m .30223 .64829 L .30201 .64839 L F
.593 .677 .9 r
.3019 .64834 m .30224 .64828 L .30283 .64638 L F
.017 0 0 r
.30558 .64745 m .3019 .64834 L .30224 .64829 L F
.593 .677 .9 r
.30224 .64828 m .30378 .64802 L .3035 .64754 L F
.30224 .64828 m .3035 .64754 L .30283 .64638 L F
0 0 0 r
.30223 .64829 m .30224 .64829 L .3022 .64831 L F
.30223 .64829 m .3022 .64831 L .30201 .64839 L F
.517 .396 .654 r
.60869 .51848 m .61126 .52025 L .61083 .51735 L F
.579 .475 .699 r
.54855 .75559 m .55096 .7558 L .55031 .75245 L F
.012 0 0 r
.53975 .65372 m .54042 .65385 L .54211 .65273 L F
.54211 .65273 m .54042 .65385 L .53975 .65372 L F
.854 .398 .074 r
.5369 .65009 m .54042 .65385 L .53776 .65115 L F
0 .185 .718 r
.53776 .65115 m .54042 .65385 L .53975 .65372 L F
.075 0 0 r
.33035 .6458 m .32857 .64704 L .32649 .64758 L F
0 0 0 r
.3306 .64638 m .33035 .6458 L .33248 .64531 L F
.3306 .64638 m .32857 .64704 L .33035 .6458 L F
.48 .06 .165 r
.52156 .76946 m .52397 .76928 L .52427 .76803 L F
0 .343 .819 r
.52639 .76893 m .52669 .77008 L .52427 .76803 L F
.52639 .76893 m .52427 .76803 L .52397 .76928 L F
.46 .224 .468 r
.59294 .54103 m .59515 .54043 L .59528 .53837 L F
.534 .284 .483 r
.59515 .54043 m .59784 .53792 L .59528 .53837 L F
.774 .747 .828 r
.69193 .51211 m .69517 .51264 L .69456 .50941 L F
.812 .642 .671 r
.69193 .51211 m .6932 .51555 L .69517 .51264 L F
.712 .503 .604 r
.69517 .51264 m .6932 .51555 L .69538 .51479 L F
.793 .759 .821 r
.69456 .50941 m .69517 .51264 L .69766 .50962 L F
.986 .885 .635 r
.72666 .4927 m .72742 .49067 L .72677 .48796 L F
.78 .998 .824 r
.55779 .58091 m .55507 .5834 L .55579 .58161 L F
.78 .962 .651 r
.55507 .5834 m .55353 .58465 L .55579 .58161 L F
.481 .714 .973 r
.37892 .59373 m .37815 .5953 L .37679 .59403 L F
.37892 .59373 m .38028 .59512 L .37815 .5953 L F
.545 .301 .497 r
.26582 .59454 m .2681 .59423 L .26844 .59189 L F
.455 .195 .429 r
.2681 .59423 m .27074 .59152 L .26844 .59189 L F
.721 .694 .824 r
.70641 .49628 m .70451 .49882 L .7036 .49599 L F
.726 .701 .827 r
.70678 .49783 m .70451 .49882 L .70641 .49628 L F
.775 .594 .654 r
.69684 .51815 m .69856 .51541 L .69538 .51479 L F
.675 .748 .906 r
.48038 .81042 m .48465 .81154 L .48085 .81042 L F
.234 .678 .955 r
.48085 .81042 m .48465 .81154 L .48341 .8109 L F
.711 .796 .917 r
.48465 .81154 m .48721 .81092 L .48341 .8109 L F
.69 .917 .971 r
.74234 .51263 m .74324 .51352 L .74529 .5123 L F
.669 .737 .901 r
.68413 .52733 m .68765 .52808 L .68644 .5264 L F
.689 .729 .88 r
.68644 .5264 m .68765 .52808 L .68989 .52708 L F
.611 .768 .955 r
.67497 .50947 m .67458 .51026 L .67533 .5096 L F
.67497 .50947 m .67697 .50956 L .67458 .51026 L F
.67557 .50823 m .67497 .50947 L .67533 .5096 L F
.67557 .50823 m .67685 .50944 L .67497 .50947 L F
.67685 .50944 m .67697 .50956 L .67497 .50947 L F
.5 .809 1 r
.67253 .5086 m .67497 .50947 L .67083 .50952 L F
.67497 .50947 m .67533 .5096 L .67138 .50953 L F
.67497 .50947 m .67138 .50953 L .67083 .50952 L F
.67262 .50856 m .67533 .5096 L .67253 .5086 L F
.465 .484 .794 r
.50611 .80375 m .50929 .80626 L .50875 .80302 L F
.484 0 0 r
.55522 .74978 m .55148 .7467 L .55224 .74787 L F
.348 0 0 r
.47669 .81444 m .47854 .81548 L .47698 .81461 L F
.047 0 0 r
.46422 .63943 m .46583 .63931 L .4672 .63794 L F
.07 0 0 r
.46422 .63943 m .46289 .64133 L .46583 .63931 L F
.531 .394 .639 r
.45801 .66359 m .45488 .66257 L .45677 .66188 L F
.45801 .66359 m .45501 .66454 L .45488 .66257 L F
.887 .685 .624 r
.26854 .63658 m .27064 .63908 L .27041 .63765 L F
.553 .457 .701 r
.27064 .63908 m .27181 .63905 L .27041 .63765 L F
.472 .097 .246 r
.4418 .66704 m .4407 .6656 L .44272 .66484 L F
.4418 .66704 m .43953 .6676 L .4407 .6656 L F
.443 0 0 r
.27768 .64157 m .27764 .64169 L .2756 .64033 L F
.27768 .64157 m .2796 .64276 L .27764 .64169 L F
.343 .135 .447 r
.30179 .61389 m .29977 .61677 L .30008 .6146 L F
.519 .295 .515 r
.35518 .6141 m .35771 .61138 L .35527 .61165 L F
.13 0 0 r
.33107 .63042 m .33384 .62944 L .33255 .62927 L F
0 0 0 r
.53724 .79811 m .53373 .80036 L .53578 .8011 L F
.558 .511 .759 r
.53832 .79431 m .53952 .79781 L .53724 .79811 L F
.53832 .79431 m .53724 .79811 L .53808 .79711 L F
.987 .714 .395 r
.53745 .80117 m .53724 .79811 L .53952 .79781 L F
0 0 0 r
.53808 .79711 m .53724 .79811 L .53578 .8011 L F
.623 .602 .808 r
.35271 .60056 m .35633 .60303 L .3545 .60055 L F
.243 .507 .905 r
.3545 .60055 m .35633 .60303 L .35701 .6018 L F
.433 .744 .993 r
.35633 .60303 m .35854 .60293 L .35701 .6018 L F
.387 0 0 r
.44916 .70399 m .44792 .70491 L .44572 .70502 L F
.374 0 0 r
.45139 .70398 m .44792 .70491 L .44916 .70399 L F
0 0 .551 r
.5088 .62745 m .51031 .63002 L .50994 .63121 L F
.3 .652 .97 r
.51031 .63002 m .51088 .63086 L .50994 .63121 L F
.855 .415 .165 r
.2635 .65318 m .26144 .65079 L .26434 .65137 L F
.02 0 .175 r
.26475 .65249 m .26434 .65137 L .26672 .65137 L F
.26475 .65249 m .2635 .65318 L .26434 .65137 L F
.661 .681 .858 r
.70815 .49474 m .71033 .4986 L .70678 .49783 L F
.274 .467 .868 r
.70815 .49474 m .71169 .49735 L .71033 .4986 L F
.328 .561 .921 r
.71169 .49735 m .7126 .49911 L .71033 .4986 L F
.791 .608 .653 r
.57729 .59402 m .57861 .59726 L .5805 .59454 L F
.779 .591 .645 r
.57861 .59726 m .58244 .59743 L .5805 .59454 L F
.885 .483 .255 r
.49475 .65078 m .49432 .65249 L .4923 .65052 L F
.49475 .65078 m .49594 .65354 L .49432 .65249 L F
.593 .592 .82 r
.49614 .64886 m .49653 .65153 L .49475 .65078 L F
.723 .425 .474 r
.49653 .65153 m .49594 .65354 L .49475 .65078 L F
.325 .743 .977 r
.38863 .59751 m .38781 .59843 L .38627 .59782 L F
.38863 .59751 m .38949 .59853 L .38781 .59843 L F
.978 .701 .432 r
.61555 .5608 m .61575 .56318 L .61426 .56003 L F
.529 .687 .939 r
.57851 .63964 m .57692 .64258 L .57499 .63978 L F
.57851 .63964 m .5791 .64222 L .57692 .64258 L F
.524 .388 .638 r
.5791 .64222 m .57719 .64562 L .57692 .64258 L F
.153 0 .185 r
.38866 .60826 m .39034 .60527 L .391 .60795 L F
.494 .35 .614 r
.39329 .60262 m .39034 .60527 L .39178 .6028 L F
.45 .187 .422 r
.39305 .60735 m .39034 .60527 L .39329 .60262 L F
.39305 .60735 m .391 .60795 L .39034 .60527 L F
.18 .382 .826 r
.73892 .52288 m .74142 .52588 L .73921 .52492 L F
.636 .73 .916 r
.68989 .52708 m .69355 .52801 L .69221 .52619 L F
.701 .714 .859 r
.69221 .52619 m .69355 .52801 L .69573 .52678 L F
.614 .739 .934 r
.2898 .64885 m .29202 .64826 L .28839 .64732 L F
.353 0 0 r
.67214 .47441 m .6751 .4751 L .67287 .47557 L F
.567 .359 .558 r
.62246 .50145 m .62514 .50114 L .62493 .4987 L F
.398 .236 .542 r
.62493 .4987 m .62701 .50014 L .62737 .4983 L F
.62493 .4987 m .62514 .50114 L .62701 .50014 L F
.92 .819 .73 r
.55169 .64446 m .55017 .64499 L .55131 .64384 L F
0 .176 .689 r
.55169 .64446 m .55358 .64619 L .55236 .64467 L F
.55169 .64446 m .55236 .64467 L .55017 .64499 L F
.808 .443 .366 r
.50298 .81335 m .50152 .80943 L .50021 .81136 L F
0 0 0 r
.49793 .64088 m .49692 .64049 L .49897 .63993 L F
.49793 .64088 m .49618 .642 L .49692 .64049 L F
.798 .861 .896 r
.48721 .81092 m .48854 .8087 L .48341 .8109 L F
.669 .432 .553 r
.57832 .59986 m .58244 .59743 L .57861 .59726 L F
.57832 .59986 m .58213 .59981 L .58244 .59743 L F
.707 .467 .559 r
.58213 .59981 m .58415 .59981 L .58244 .59743 L F
.181 0 .273 r
.61797 .50729 m .61588 .5101 L .61767 .50907 L F
.51 .197 .371 r
.61767 .50907 m .62007 .50874 L .61797 .50729 L F
.473 .217 .444 r
.61797 .50729 m .62007 .50874 L .62028 .50666 L F
.56 .391 .609 r
.42585 .68188 m .42364 .68451 L .42364 .68231 L F
.691 .384 .451 r
.52755 .77207 m .53088 .77233 L .53111 .76999 L F
.583 .29 .437 r
.53088 .77233 m .53329 .77179 L .53111 .76999 L F
.835 .684 .695 r
.51356 .80964 m .51527 .80652 L .51198 .80623 L F
.758 .58 .656 r
.51356 .80964 m .51527 .80979 L .51527 .80652 L F
.782 .694 .766 r
.51527 .80979 m .51897 .80586 L .51527 .80652 L F
.767 .924 .939 r
.70171 .477 m .70535 .47604 L .70474 .47558 L F
.70171 .477 m .70288 .47712 L .70535 .47604 L F
.796 .994 .871 r
.70609 .4745 m .70535 .47604 L .70727 .47578 L F
.70609 .4745 m .70474 .47558 L .70535 .47604 L F
.658 .459 .604 r
.60673 .54956 m .60677 .55189 L .60434 .55191 L F
.751 .534 .602 r
.60928 .55157 m .60677 .55189 L .60673 .54956 L F
.853 .734 .731 r
.57824 .66252 m .57526 .66218 L .57783 .65772 L F
.782 .552 .588 r
.57824 .66252 m .57477 .66461 L .57526 .66218 L F
.57824 .66252 m .57824 .66508 L .57477 .66461 L F
.592 .023 0 r
.57647 .66134 m .57882 .66249 L .57857 .66205 L F
.071 .242 .733 r
.58025 .66319 m .57824 .66252 L .57857 .66205 L F
.592 .023 0 r
.57882 .66249 m .58025 .66319 L .57857 .66205 L F
0 0 .282 r
.57814 .66131 m .57857 .66205 L .57824 .66252 L F
.57783 .65772 m .57857 .66205 L .57814 .66131 L F
.071 .242 .733 r
.58025 .66319 m .58043 .6643 L .57824 .66252 L F
.409 .252 .555 r
.57824 .66252 m .58043 .6643 L .57824 .66508 L F
.453 .271 .542 r
.61543 .51212 m .61767 .50907 L .61588 .5101 L F
.139 .15 .608 r
.75088 .5027 m .74921 .50445 L .74925 .50106 L F
.375 .323 .672 r
.75165 .50642 m .74921 .50445 L .75088 .5027 L F
.75165 .50642 m .75015 .5065 L .74921 .50445 L F
.88 .518 .033 r
.52763 .60841 m .52912 .61162 L .5283 .61057 L F
.782 .493 0 r
.52927 .61403 m .5283 .61057 L .52912 .61162 L F
.659 .585 .761 r
.5748 .63054 m .57676 .6307 L .57435 .6313 L F
.637 .6 .795 r
.4989 .62497 m .49673 .62604 L .49544 .62257 L F
0 0 0 r
.4672 .63794 m .46583 .63931 L .46774 .6383 L F
.302 0 .264 r
.37389 .61972 m .37129 .62224 L .372 .6205 L F
.347 .626 .956 r
.4181 .71022 m .41893 .70907 L .4168 .70913 L F
.4181 .71022 m .42004 .71047 L .41893 .70907 L F
0 0 0 r
.30405 .611 m .30179 .61389 L .30279 .61212 L F
.326 0 0 r
.58415 .59981 m .58779 .60034 L .58547 .59989 L F
.815 .391 .237 r
.48188 .6542 m .47918 .65688 L .47854 .65351 L F
.48188 .6542 m .48089 .65583 L .47918 .65688 L F
.48188 .6542 m .48402 .65789 L .48089 .65583 L F
.885 .878 .822 r
.73186 .50378 m .73195 .50644 L .73065 .50547 L F
.949 .886 .736 r
.73195 .50644 m .72929 .50869 L .73065 .50547 L F
.73195 .50644 m .73029 .5097 L .72929 .50869 L F
.875 .871 .83 r
.73307 .50491 m .73195 .50644 L .73186 .50378 L F
.502 .548 .836 r
.64108 .50904 m .63889 .51064 L .63863 .5096 L F
.64108 .50904 m .64251 .5125 L .63889 .51064 L F
.384 .721 .989 r
.56457 .60197 m .56703 .60218 L .5676 .60315 L F
.889 .595 .085 r
.56703 .60218 m .56799 .60584 L .5676 .60315 L F
.43 0 0 r
.27291 .64791 m .27473 .64863 L .27203 .64731 L F
.774 .908 .933 r
.27266 .64937 m .27473 .64863 L .27291 .64791 L F
.829 .902 .891 r
.27671 .64606 m .27473 .64863 L .27291 .64791 L F
.328 .724 .982 r
.27473 .64863 m .27538 .64758 L .27291 .64791 L F
.27473 .64863 m .27724 .64864 L .27538 .64758 L F
.273 .616 .958 r
.35146 .59932 m .35271 .60056 L .3545 .60055 L F
.399 .771 .993 r
.30947 .5838 m .31295 .58443 L .31087 .58456 L F
.796 .998 .792 r
.53135 .77481 m .53449 .77254 L .53329 .77179 L F
.53135 .77481 m .53145 .77556 L .53449 .77254 L F
.397 .779 .991 r
.53329 .77179 m .53561 .77163 L .53449 .77254 L F
.53329 .77179 m .53561 .77163 L .53449 .77254 L F
.375 .299 .642 r
.26038 .60875 m .26177 .60527 L .25972 .60664 L F
.927 .859 .423 r
.73331 .49816 m .73359 .49473 L .73445 .49541 L F
.582 .41 .614 r
.44174 .671 m .44455 .67061 L .44401 .66814 L F
.56 .331 .526 r
.44174 .671 m .44411 .67314 L .44455 .67061 L F
.582 .41 .614 r
.44174 .671 m .44455 .67061 L .44401 .66814 L F
.992 .784 .522 r
.44455 .67061 m .44411 .67314 L .44174 .671 L F
0 0 0 r
.55949 .57741 m .55779 .58091 L .55874 .57983 L F
.379 .832 .736 r
.55779 .58091 m .55802 .58055 L .55874 .57983 L F
.55779 .58091 m .55579 .58161 L .55802 .58055 L F
.689 .506 .634 r
.59852 .60922 m .59932 .61137 L .59597 .61144 L F
.605 .432 .621 r
.59852 .60922 m .60127 .61006 L .59932 .61137 L F
.59852 .60922 m .60172 .60847 L .60127 .61006 L F
.375 .299 .642 r
.26038 .60875 m .26194 .60845 L .26177 .60527 L F
.531 .481 .745 r
.26038 .60875 m .26274 .61116 L .26194 .60845 L F
.601 .209 .273 r
.4848 .69651 m .48838 .69596 L .48563 .69629 L F
.99 .76 .378 r
.63204 .54309 m .6328 .54655 L .63339 .5439 L F
.927 .837 .736 r
.56481 .76916 m .56576 .76708 L .56333 .76864 L F
.978 .839 .441 r
.56564 .76402 m .56519 .76673 L .56576 .76708 L F
.819 1 .818 r
.56576 .76708 m .56519 .76673 L .56333 .76864 L F
.761 .66 .75 r
.72403 .46954 m .72173 .47226 L .72231 .47092 L F
.763 .624 .706 r
.49461 .79235 m .49502 .79592 L .49225 .7951 L F
.527 .206 .366 r
.4971 .79463 m .49943 .79373 L .49884 .79405 L F
.495 .765 .991 r
.49856 .794 m .4971 .79463 L .49884 .79405 L F
.627 .333 .452 r
.49461 .79235 m .4971 .79463 L .49498 .79555 L F
.49461 .79235 m .50034 .79109 L .4971 .79463 L F
.527 .206 .366 r
.4971 .79463 m .50034 .79109 L .50048 .79235 L F
.4971 .79463 m .50048 .79235 L .49943 .79373 L F
.495 .765 .991 r
.49542 .79349 m .4971 .79463 L .49856 .794 L F
.627 .333 .452 r
.49498 .79555 m .4971 .79463 L .49502 .79592 L F
.943 .591 .316 r
.49427 .79724 m .49564 .79785 L .49502 .79592 L F
.49427 .79724 m .49502 .79592 L .4971 .79463 L F
0 0 .052 r
.59407 .56014 m .59349 .56248 L .5922 .56365 L F
0 0 0 r
.5922 .56365 m .59349 .56248 L .59086 .56509 L F
.79 .637 .691 r
.48121 .64958 m .47854 .65351 L .48074 .65067 L F
0 0 .33 r
.73458 .52627 m .73354 .52277 L .73413 .52369 L F
.901 .937 .826 r
.59388 .71249 m .59279 .71594 L .59473 .71331 L F
.59388 .71249 m .59168 .71539 L .59279 .71594 L F
.845 .856 .852 r
.67321 .52049 m .67046 .52041 L .67335 .51743 L F
.868 .815 .795 r
.67321 .52049 m .67083 .52381 L .67046 .52041 L F
.81 .829 .865 r
.67545 .51807 m .67321 .52049 L .67335 .51743 L F
.252 0 0 r
.51559 .6943 m .51955 .69315 L .51746 .69393 L F
.41 .114 .348 r
.5925 .54287 m .59515 .54043 L .59294 .54103 L F
.301 .422 .818 r
.4064 .69895 m .40797 .6987 L .40533 .69657 L F
.467 .473 .781 r
.4064 .69895 m .40947 .70182 L .40797 .6987 L F
.499 .264 .489 r
.38164 .61155 m .3812 .61376 L .37916 .61415 L F
.363 .09 .358 r
.38379 .61102 m .3812 .61376 L .38164 .61155 L F
.719 .786 .905 r
.49557 .79037 m .50034 .79109 L .49461 .79235 L F
.763 .381 .331 r
.50048 .79235 m .50034 .79109 L .49557 .79037 L F
.473 .698 .967 r
.5033 .6248 m .50255 .62661 L .50117 .62498 L F
.5033 .6248 m .50492 .62664 L .50255 .62661 L F
.479 .204 .418 r
.53957 .69056 m .53694 .69305 L .53739 .69116 L F
.421 .867 .829 r
.49943 .79373 m .50359 .7925 L .50048 .79235 L F
.428 .256 .543 r
.40213 .66537 m .40421 .66495 L .40432 .66205 L F
.563 .455 .689 r
.40228 .66781 m .40421 .66495 L .40213 .66537 L F
.409 .113 .349 r
.3427 .62559 m .34484 .62505 L .34572 .62226 L F
.428 .131 .357 r
.34572 .62226 m .34699 .62453 L .34786 .6222 L F
.34572 .62226 m .34484 .62505 L .34699 .62453 L F
.628 .194 .198 r
.53923 .77454 m .54036 .7729 L .53713 .77281 L F
.589 .15 .175 r
.54223 .77467 m .54036 .7729 L .53923 .77454 L F
.267 0 0 r
.5268 .69684 m .52541 .69833 L .52319 .69868 L F
.358 0 0 r
.52928 .69657 m .52541 .69833 L .5268 .69684 L F
.292 .77 .669 r
.33666 .64412 m .33866 .64332 L .34061 .64248 L F
.612 .05 0 r
.71012 .48438 m .70883 .48383 L .70648 .4819 L F
.411 .372 .705 r
.70648 .4819 m .70883 .48383 L .70843 .47948 L F
0 0 0 r
.51813 .70104 m .51744 .70146 L .51616 .70181 L F
.51744 .70146 m .51538 .70232 L .51616 .70181 L F
.405 .463 .807 r
.53807 .77742 m .53923 .77454 L .53708 .77479 L F
.53807 .77742 m .54033 .77716 L .53923 .77454 L F
.593 .206 .278 r
.53807 .77742 m .54179 .77738 L .54033 .77716 L F
.53807 .77742 m .53771 .77815 L .54179 .77738 L F
.304 0 0 r
.48615 .69972 m .48482 .70091 L .48246 .70111 L F
.601 .343 .499 r
.45923 .65706 m .45886 .65925 L .45655 .6592 L F
.541 .29 .483 r
.46154 .65874 m .45923 .65706 L .46138 .65625 L F
.46154 .65874 m .45886 .65925 L .45923 .65706 L F
.25 0 0 r
.32621 .60041 m .32447 .60148 L .32213 .60174 L F
.556 .123 .174 r
.32836 .60005 m .32447 .60148 L .32621 .60041 L F
.312 0 .124 r
.58517 .54891 m .58749 .54833 L .58827 .54667 L F
0 0 .059 r
.58827 .54667 m .59006 .54557 L .59061 .54386 L F
.152 0 .359 r
.58978 .54779 m .58827 .54667 L .58749 .54833 L F
.58978 .54779 m .59006 .54557 L .58827 .54667 L F
.621 .592 .799 r
.53175 .80253 m .53276 .80557 L .53515 .80389 L F
.992 .784 .522 r
.44455 .67061 m .44528 .67381 L .44411 .67314 L F
.991 .75 .468 r
.44528 .67381 m .44519 .67624 L .44411 .67314 L F
.992 .784 .522 r
.44411 .67314 m .44528 .67381 L .44455 .67061 L F
.591 .464 .676 r
.44519 .67624 m .44528 .67381 L .44411 .67314 L F
.44519 .67624 m .44712 .67366 L .44528 .67381 L F
.44712 .67366 m .44519 .67624 L .44528 .67381 L F
0 0 .333 r
.52639 .76893 m .52755 .77207 L .52669 .77008 L F
0 0 .338 r
.6518 .5122 m .65272 .51135 L .65258 .50877 L F
.205 .545 .929 r
.6518 .5122 m .65403 .51271 L .65272 .51135 L F
.53 .143 .252 r
.75097 .50989 m .7506 .51165 L .74771 .51184 L F
.382 .411 .766 r
.75165 .50642 m .75097 .50989 L .75015 .5065 L F
.75165 .50642 m .75285 .50877 L .75097 .50989 L F
.313 0 .194 r
.7533 .51068 m .75097 .50989 L .75285 .50877 L F
.7533 .51068 m .7506 .51165 L .75097 .50989 L F
0 0 0 r
.6278 .57102 m .62714 .57342 L .62662 .57452 L F
.62714 .57342 m .62588 .57641 L .62662 .57452 L F
.684 .51 .645 r
.61504 .5467 m .61467 .54913 L .61255 .54911 L F
.562 .35 .55 r
.58355 .61707 m .58335 .6197 L .58082 .62026 L F
.555 .295 .478 r
.58568 .61719 m .58335 .6197 L .58355 .61707 L F
0 0 0 r
.47954 .81127 m .47832 .81234 L .48038 .81042 L F
.161 .274 .733 r
.47954 .81127 m .48071 .81478 L .47832 .81234 L F
.559 .461 .699 r
.47493 .79696 m .47672 .7944 L .47468 .79515 L F
.431 .647 .948 r
.71585 .46289 m .71474 .46457 L .71385 .46319 L F
.71585 .46289 m .71602 .46422 L .71474 .46457 L F
.658 .582 .759 r
.71846 .46757 m .71474 .46457 L .71602 .46422 L F
.215 .385 .818 r
.39178 .59908 m .39082 .60048 L .38949 .59853 L F
.198 .362 .803 r
.39178 .59908 m .39318 .60222 L .39082 .60048 L F
.376 .377 .733 r
.39318 .60222 m .39178 .6028 L .39082 .60048 L F
.198 0 .234 r
.59194 .54494 m .59061 .54386 L .59006 .54557 L F
.59194 .54494 m .5925 .54287 L .59061 .54386 L F
.559 .461 .699 r
.47493 .79696 m .47716 .7974 L .47672 .7944 L F
.47 .415 .714 r
.47493 .79696 m .47718 .7994 L .47716 .7974 L F
.47493 .79696 m .47586 .80093 L .47718 .7994 L F
.638 .581 .774 r
.55653 .60359 m .55684 .60641 L .5591 .606 L F
.353 .078 .35 r
.55684 .60641 m .55867 .60705 L .5591 .606 L F
.55684 .60641 m .55671 .60813 L .55867 .60705 L F
.787 .974 .912 r
.6688 .50286 m .66605 .50499 L .66793 .5048 L F
.658 .582 .759 r
.71846 .46757 m .71602 .46422 L .71668 .46679 L F
.537 .855 .997 r
.71846 .46757 m .72045 .4661 L .71991 .46701 L F
0 .401 .701 r
.72189 .46756 m .71991 .46701 L .72077 .46524 L F
0 .065 .582 r
.71991 .46701 m .72045 .4661 L .72077 .46524 L F
.537 .855 .997 r
.71846 .46757 m .71668 .46679 L .72045 .4661 L F
.34 .196 .535 r
.6048 .52946 m .60681 .52855 L .60681 .52623 L F
.507 .377 .637 r
.60483 .53155 m .60681 .52855 L .6048 .52946 L F
.498 .352 .614 r
.62981 .49512 m .63175 .49215 L .62952 .49271 L F
.482 .52 .82 r
.26791 .62029 m .26909 .62309 L .27114 .62224 L F
.703 .332 .342 r
.26909 .62309 m .2714 .62497 L .27114 .62224 L F
.26909 .62309 m .26817 .62479 L .2714 .62497 L F
.661 .681 .858 r
.70815 .49474 m .70678 .49783 L .70641 .49628 L F
.763 .351 .269 r
.71317 .48622 m .70883 .48383 L .71012 .48438 L F
.65 .544 .722 r
.71269 .48241 m .71258 .48484 L .71012 .48438 L F
.639 .249 .288 r
.71258 .48484 m .71317 .48622 L .71012 .48438 L F
.646 .232 .245 r
.26571 .62062 m .26469 .62223 L .26271 .62039 L F
1 .823 .499 r
.2651 .61938 m .26571 .62062 L .26791 .62029 L F
.2651 .61938 m .26469 .62223 L .26571 .62062 L F
.699 .836 .399 r
.71368 .47298 m .71308 .47386 L .71242 .47538 L F
.301 0 0 r
.42383 .71066 m .4222 .71082 L .42004 .71047 L F
.229 .749 .793 r
.42486 .71026 m .42383 .71066 L .42602 .71037 L F
.42486 .71026 m .4222 .71082 L .42383 .71066 L F
.147 0 0 r
.52379 .7747 m .52527 .77493 L .52175 .77461 L F
.79 .553 .58 r
.49111 .80599 m .4936 .80662 L .49327 .80749 L F
0 0 .394 r
.50334 .77843 m .50431 .77999 L .5063 .77758 L F
.50334 .77843 m .50391 .78047 L .50431 .77999 L F
.228 .432 .853 r
.74477 .48047 m .74457 .4817 L .74302 .47892 L F
.065 .22 .714 r
.74477 .48047 m .74558 .48338 L .74457 .4817 L F
.593 .367 .543 r
.40432 .66205 m .40664 .66196 L .40684 .65962 L F
.52 .305 .528 r
.40664 .66196 m .40886 .66153 L .40684 .65962 L F
.452 .437 .751 r
.40035 .6849 m .40109 .68796 L .40283 .68711 L F
.515 .436 .705 r
.40143 .69048 m .40283 .68711 L .40109 .68796 L F
.07 .235 .727 r
.53717 .62292 m .53799 .62163 L .53599 .61959 L F
.008 .146 .66 r
.53717 .62292 m .53895 .62514 L .53799 .62163 L F
.199 .206 .642 r
.53786 .62511 m .53895 .62514 L .53717 .62292 L F
.571 .215 .325 r
.27584 .59079 m .27821 .5909 L .27955 .58855 L F
.357 0 .125 r
.27821 .5909 m .28175 .58849 L .27955 .58855 L F
.496 .565 .855 r
.26892 .64835 m .26558 .64539 L .26835 .64833 L F
.802 .966 .653 r
.26719 .6499 m .26672 .65137 L .26892 .64835 L F
.403 0 .129 r
.26892 .64835 m .27091 .64854 L .27203 .64731 L F
.315 .591 .942 r
.26946 .64702 m .27091 .64854 L .26892 .64835 L F
.26892 .64835 m .27091 .64854 L .26946 .64702 L F
.875 .716 .682 r
.61573 .55466 m .61293 .55423 L .61448 .55143 L F
.909 .811 .738 r
.61573 .55466 m .6125 .55663 L .61293 .55423 L F
.61573 .55466 m .61401 .55752 L .6125 .55663 L F
.766 .67 .757 r
.61448 .55143 m .61667 .55257 L .61573 .55466 L F
.291 0 .044 r
.34912 .63766 m .34832 .63861 L .34614 .63909 L F
.275 0 .066 r
.35129 .63705 m .34832 .63861 L .34912 .63766 L F
.045 .454 .878 r
.52302 .64123 m .5255 .64241 L .52401 .64198 L F
.494 .636 .917 r
.2711 .63126 m .27145 .62939 L .26957 .62967 L F
.2711 .63126 m .27301 .63093 L .27145 .62939 L F
.601 .593 .815 r
.2711 .63126 m .27485 .63345 L .27301 .63093 L F
.59 .647 .875 r
.7149 .49939 m .71379 .50161 L .7126 .49911 L F
.7149 .49939 m .71634 .50107 L .71379 .50161 L F
.319 .076 .379 r
.37077 .62421 m .36939 .62294 L .37129 .62224 L F
.37077 .62421 m .36888 .62494 L .36939 .62294 L F
.397 .558 .897 r
.30604 .62526 m .30585 .62779 L .30412 .62579 L F
.30604 .62526 m .30779 .6281 L .30585 .62779 L F
.472 0 0 r
.70843 .47948 m .71134 .48065 L .70856 .47923 L F
0 0 0 r
.26144 .65079 m .26161 .64993 L .26193 .64803 L F
.855 .415 .165 r
.2635 .65318 m .26278 .65353 L .26144 .65079 L F
0 0 .471 r
.26144 .65079 m .26278 .65353 L .26161 .64993 L F
0 .544 .726 r
.49066 .7864 m .49305 .7866 L .48951 .78628 L F
.687 .515 .649 r
.57841 .62342 m .57869 .62559 L .57556 .62523 L F
.552 .387 .611 r
.58082 .62026 m .58084 .62286 L .57841 .62342 L F
.548 .406 .639 r
.58084 .62286 m .57869 .62559 L .57841 .62342 L F
.666 .39 .493 r
.58562 .70153 m .58908 .69925 L .58573 .69892 L F
.58562 .70153 m .58928 .70137 L .58908 .69925 L F
.516 .202 .373 r
.31172 .6056 m .30851 .60791 L .30989 .60558 L F
.448 .879 .807 r
.68075 .47244 m .68232 .4714 L .6836 .47118 L F
.68075 .47244 m .68012 .47247 L .68232 .4714 L F
.616 .65 .861 r
.70944 .47706 m .71134 .48065 L .70843 .47948 L F
0 0 .21 r
.70843 .47948 m .70931 .4791 L .70945 .47761 L F
.53 0 0 r
.71115 .47595 m .70944 .47706 L .70917 .4769 L F
.71115 .47595 m .70917 .4769 L .70875 .47584 L F
.70875 .47584 m .70917 .4769 L .70727 .47578 L F
.322 .227 .589 r
.70727 .47578 m .70944 .47706 L .70904 .47488 L F
.445 .13 .337 r
.70944 .47706 m .71308 .47386 L .70904 .47488 L F
0 0 .21 r
.70843 .47948 m .70961 .47591 L .70944 .47706 L F
.70923 .47706 m .70945 .47761 L .70961 .47591 L F
.70843 .47948 m .70945 .47761 L .70923 .47706 L F
.277 .773 .886 r
.3319 .59986 m .33032 .59974 L .32836 .60005 L F
.322 .801 .904 r
.33445 .59939 m .33032 .59974 L .3319 .59986 L F
.477 .041 .131 r
.40886 .66153 m .41139 .66139 L .41273 .65967 L F
.037 0 0 r
.41473 .65874 m .41273 .65967 L .41359 .66004 L F
.487 .224 .441 r
.41139 .66139 m .41359 .66004 L .41273 .65967 L F
.374 .703 .984 r
.32571 .585 m .32554 .58642 L .32433 .58535 L F
.32571 .585 m .32703 .58645 L .32554 .58642 L F
.824 .922 .901 r
.49557 .79037 m .49461 .79235 L .49275 .79154 L F
.341 .095 .389 r
.6202 .50419 m .62221 .5035 L .62246 .50145 L F
.576 .46 .685 r
.62028 .50666 m .62221 .5035 L .6202 .50419 L F
.414 .111 .339 r
.4344 .67255 m .43283 .67119 L .43527 .67072 L F
.4344 .67255 m .43229 .67308 L .43283 .67119 L F
.568 .851 .997 r
.51669 .65349 m .51464 .65421 L .51539 .65272 L F
.51669 .65349 m .51464 .65421 L .51539 .65272 L F
.015 0 0 r
.44676 .69672 m .4491 .69649 L .45016 .69624 L F
.278 0 0 r
.4491 .69649 m .45247 .69644 L .45016 .69624 L F
.278 0 .162 r
.62221 .5035 m .62514 .50114 L .62246 .50145 L F
.287 .732 .962 r
.3581 .58932 m .35604 .58939 L .35465 .58878 L F
.973 .761 .557 r
.56414 .76317 m .56611 .76078 L .56388 .76048 L F
.56414 .76317 m .56564 .76402 L .56611 .76078 L F
.366 .208 .53 r
.63633 .50063 m .63464 .50313 L .63481 .50158 L F
.754 .708 .808 r
.54601 .74478 m .54912 .74496 L .54751 .74354 L F
.522 .357 .599 r
.54912 .74496 m .55148 .7467 L .55167 .74408 L F
.546 .593 .852 r
.30497 .65012 m .30558 .64745 L .30224 .64829 L F
.30497 .65012 m .30703 .65017 L .30558 .64745 L F
.326 .386 .771 r
.64472 .48591 m .64291 .48757 L .64185 .48389 L F
.115 .046 .493 r
.64472 .48591 m .64405 .48781 L .64291 .48757 L F
.564 .377 .585 r
.53191 .74724 m .53443 .74716 L .53438 .74433 L F
.53191 .74724 m .53443 .74716 L .53438 .74433 L F
.808 .686 .73 r
.69456 .52337 m .69573 .52678 L .69769 .52377 L F
.287 .029 .336 r
.71281 .48857 m .71041 .49139 L .7126 .49045 L F
.288 .282 .679 r
.7126 .49045 m .71249 .48914 L .71281 .48857 L F
.918 .909 .797 r
.71327 .48777 m .71118 .48976 L .71281 .48857 L F
.288 .282 .679 r
.71249 .48914 m .71231 .48718 L .71281 .48857 L F
.918 .909 .797 r
.71375 .48731 m .71327 .48777 L .71281 .48857 L F
0 .289 .765 r
.71375 .48731 m .7172 .49003 L .71665 .48916 L F
.652 .179 .115 r
.71281 .48857 m .71665 .48916 L .71375 .48731 L F
.71375 .48731 m .71281 .48857 L .71317 .48622 L F
.71375 .48731 m .71665 .48916 L .71281 .48857 L F
.737 .705 .82 r
.70013 .50687 m .7036 .50763 L .70238 .50591 L F
.725 .705 .831 r
.7036 .50763 m .7058 .50647 L .70238 .50591 L F
.378 .814 .959 r
.53105 .77735 m .53163 .77783 L .53145 .77556 L F
.671 .322 .375 r
.58779 .60034 m .58991 .60223 L .59129 .60018 L F
.712 .372 .401 r
.58991 .60223 m .59369 .60241 L .59129 .60018 L F
.675 .388 .479 r
.59369 .60241 m .59406 .60044 L .59129 .60018 L F
.461 .357 .65 r
.63805 .50628 m .63585 .50735 L .63793 .50538 L F
.523 .477 .748 r
.63988 .50334 m .63805 .50628 L .63793 .50538 L F
.63988 .50334 m .64101 .50637 L .63805 .50628 L F
.514 .386 .643 r
.64101 .50637 m .63863 .5096 L .63805 .50628 L F
.755 .474 0 r
.74189 .53106 m .74175 .5299 L .74107 .52895 L F
.74189 .53106 m .74215 .53158 L .74175 .5299 L F
0 0 0 r
.55949 .57741 m .55874 .57983 L .55842 .57693 L F
.64 .253 .294 r
.60928 .55157 m .60927 .55366 L .60677 .55189 L F
.592 .396 .585 r
.61255 .54911 m .61277 .5517 L .60928 .55157 L F
.773 .57 .623 r
.61277 .5517 m .60927 .55366 L .60928 .55157 L F
.352 .755 .983 r
.36154 .755 m .36386 .75489 L .36299 .75572 L F
.36154 .755 m .36386 .75489 L .36299 .75572 L F
.258 .019 .348 r
.60407 .59197 m .60554 .59102 L .60638 .58894 L F
.243 0 .125 r
.60317 .59341 m .60554 .59102 L .60407 .59197 L F
.265 0 .301 r
.49836 .65207 m .49653 .65153 L .49858 .65095 L F
.49836 .65207 m .49594 .65354 L .49653 .65153 L F
.315 .512 .89 r
.37591 .59222 m .37508 .5937 L .37309 .5919 L F
.37591 .59222 m .37679 .59403 L .37508 .5937 L F
.339 0 .01 r
.45722 .70226 m .45588 .70392 L .45362 .70421 L F
.322 0 0 r
.45945 .70242 m .45588 .70392 L .45722 .70226 L F
.24 .442 .858 r
.52806 .6438 m .52736 .64561 L .5255 .64241 L F
.315 .532 .904 r
.52806 .6438 m .52902 .64538 L .52736 .64561 L F
.792 .76 .823 r
.52902 .64538 m .52726 .64796 L .52736 .64561 L F
.679 .639 .803 r
.76375 .59709 m .76744 .59818 L .76624 .59474 L F
.632 .612 .812 r
.76624 .59474 m .76744 .59818 L .76968 .59712 L F
.765 .955 .935 r
.7147 .49133 m .7172 .49003 L .71665 .48916 L F
.818 .48 0 r
.71665 .48916 m .7172 .49003 L .71775 .49199 L F
.731 .943 .952 r
.51995 .80633 m .51931 .80793 L .51897 .80586 L F
.51995 .80633 m .52113 .80675 L .51931 .80793 L F
.43 0 0 r
.27291 .64791 m .27203 .64731 L .27091 .64854 L F
.932 .895 .769 r
.54315 .63701 m .54558 .63412 L .54537 .63676 L F
.54315 .63701 m .54376 .63338 L .54558 .63412 L F
.54315 .63701 m .54189 .63672 L .54376 .63338 L F
.111 .661 .808 r
.54537 .63676 m .54189 .63672 L .54315 .63701 L F
.815 .803 .841 r
.56147 .77315 m .56236 .76933 L .56034 .77249 L F
.56147 .77315 m .56304 .77178 L .56236 .76933 L F
.879 .985 .824 r
.47469 .63412 m .47609 .63099 L .4773 .63162 L F
.47469 .63412 m .47389 .6337 L .47609 .63099 L F
0 .115 .59 r
.72793 .51731 m .72901 .51828 L .73163 .52035 L F
.796 .865 .9 r
.48735 .62493 m .484 .62539 L .48596 .62394 L F
.705 .853 .953 r
.48998 .62366 m .48735 .62493 L .48596 .62394 L F
.737 .601 .706 r
.50875 .80302 m .51184 .80375 L .51185 .80132 L F
.695 .567 .706 r
.51411 .8009 m .51184 .80375 L .51185 .80132 L F
.441 .376 .688 r
.75056 .4969 m .75071 .50028 L .74818 .4987 L F
.411 .382 .717 r
.75071 .50028 m .74925 .50106 L .74818 .4987 L F
.451 .68 .963 r
.3155 .62824 m .31469 .62971 L .3134 .62842 L F
.3155 .62824 m .31738 .63012 L .31469 .62971 L F
.723 .605 .725 r
.50686 .79418 m .50948 .79247 L .50628 .79295 L F
.494 .209 .411 r
.3812 .61376 m .37844 .61649 L .37916 .61415 L F
.489 .491 .785 r
.47744 .78088 m .47834 .78309 L .47967 .78169 L F
.941 .955 .65 r
.63065 .5619 m .63213 .56057 L .63143 .55973 L F
.63065 .5619 m .63054 .564 L .63213 .56057 L F
.707 .806 .927 r
.57554 .72117 m .57871 .72136 L .57766 .7204 L F
.773 .71 .792 r
.57554 .72117 m .57712 .72252 L .57871 .72136 L F
.823 .867 .879 r
.57871 .72136 m .58005 .71774 L .57766 .7204 L F
.57871 .72136 m .58131 .71874 L .58005 .71774 L F
.627 .385 .532 r
.50929 .80626 m .51184 .80375 L .50875 .80302 L F
.50929 .80626 m .51198 .80623 L .51184 .80375 L F
0 0 .25 r
.47586 .80093 m .47652 .80259 L .47718 .7994 L F
.47586 .80093 m .47592 .80342 L .47652 .80259 L F
.247 0 0 r
.57114 .59072 m .57059 .59171 L .56793 .59256 L F
.237 0 .241 r
.57422 .58842 m .57314 .59093 L .57114 .59072 L F
.219 0 0 r
.57114 .59072 m .57314 .59093 L .57059 .59171 L F
.43 .274 .567 r
.60911 .52102 m .61115 .5227 L .61126 .52025 L F
.60911 .52102 m .60929 .52345 L .61115 .5227 L F
.757 .85 .92 r
.67072 .48292 m .67453 .48243 L .6732 .4817 L F
.867 .829 .807 r
.56236 .76933 m .56304 .77178 L .56481 .76916 L F
.531 .402 .65 r
.4005 .67076 m .4026 .67039 L .40228 .66781 L F
.471 .343 .625 r
.4005 .67076 m .40254 .67276 L .4026 .67039 L F
.4005 .67076 m .40036 .67392 L .40254 .67276 L F
.371 0 .114 r
.33683 .62811 m .33891 .62778 L .34042 .62577 L F
.452 .04 .166 r
.34042 .62577 m .34205 .6267 L .3427 .62559 L F
.34042 .62577 m .33891 .62778 L .34205 .6267 L F
.995 .867 .585 r
.67083 .52381 m .6698 .52345 L .67046 .52041 L F
.93 .552 .174 r
.67083 .52381 m .67144 .52635 L .6698 .52345 L F
.796 .998 .8 r
.26719 .6499 m .26475 .65249 L .26672 .65137 L F
.838 .537 .48 r
.26509 .64733 m .26835 .64833 L .26558 .64539 L F
.508 .477 .758 r
.399 .67918 m .39983 .6824 L .40182 .68211 L F
.546 .451 .698 r
.39983 .6824 m .40249 .68444 L .40182 .68211 L F
.39983 .6824 m .40035 .6849 L .40249 .68444 L F
.45 .271 .545 r
.26271 .62039 m .2651 .61938 L .26117 .6192 L F
.26271 .62039 m .26469 .62223 L .2651 .61938 L F
.747 .736 .842 r
.26381 .62839 m .2673 .62892 L .26591 .62765 L F
.752 .729 .832 r
.26381 .62839 m .2673 .62892 L .26591 .62765 L F
.866 .845 .822 r
.26877 .62484 m .2673 .62892 L .26591 .62765 L F
.233 .533 .921 r
.2673 .62892 m .26762 .62757 L .26591 .62765 L F
.2673 .62892 m .26957 .62967 L .26762 .62757 L F
0 0 0 r
.37981 .70664 m .37962 .7065 L .37814 .70689 L F
.38316 .70607 m .37962 .7065 L .37981 .70664 L F
.597 .367 .539 r
.60408 .60588 m .60412 .60807 L .60172 .60847 L F
.564 .342 .536 r
.60408 .60588 m .60643 .6078 L .60412 .60807 L F
.613 .326 .457 r
.60408 .60588 m .60687 .60589 L .60643 .6078 L F
.452 .188 .422 r
.30657 .60887 m .30405 .611 L .30462 .60961 L F
.349 0 .087 r
.28398 .58819 m .28614 .5878 L .28764 .58589 L F
.381 0 .066 r
.28614 .5878 m .2899 .58579 L .28764 .58589 L F
.663 .7 .874 r
.57325 .72171 m .57712 .72252 L .57554 .72117 L F
.844 .624 .606 r
.58934 .70377 m .5927 .702 L .58928 .70137 L F
.58934 .70377 m .59262 .70449 L .5927 .702 L F
.002 .474 .867 r
.39035 .59799 m .38949 .59853 L .38863 .59751 L F
.39035 .59799 m .39178 .59908 L .38949 .59853 L F
.116 0 0 r
.34671 .64007 m .34614 .63909 L .34832 .63861 L F
.34671 .64007 m .34457 .64087 L .34614 .63909 L F
.671 .506 .653 r
.5833 .69893 m .58573 .69892 L .58552 .69638 L F
.626 .923 .975 r
.69532 .46852 m .69686 .46702 L .69717 .46709 L F
.69532 .46852 m .69243 .46851 L .69686 .46702 L F
.543 .909 .958 r
.48071 .81478 m .48189 .81504 L .48275 .81397 L F
.48071 .81478 m .48189 .81504 L .48275 .81397 L F
.298 .42 .817 r
.53136 .65212 m .53408 .65247 L .53054 .65047 L F
.53136 .65212 m .53367 .65337 L .53408 .65247 L F
.667 .536 .696 r
.51393 .78688 m .51639 .78373 L .51404 .78452 L F
.757 .445 .455 r
.55167 .74408 m .55402 .74645 L .55512 .74414 L F
.736 .419 .445 r
.55512 .74414 m .55402 .74645 L .55727 .74659 L F
0 .457 .821 r
.6501 .48788 m .6485 .48772 L .64712 .48668 L F
.6501 .48788 m .65327 .48946 L .6485 .48772 L F
.768 .69 .777 r
.50616 .64512 m .50393 .64553 L .50635 .64312 L F
.62 .415 .582 r
.50616 .64512 m .50392 .64811 L .50393 .64553 L F
.50616 .64512 m .50651 .64809 L .50392 .64811 L F
.765 .991 .777 r
.47984 .62899 m .4773 .63162 L .47804 .62999 L F
.669 .924 .973 r
.4773 .63162 m .47609 .63099 L .47804 .62999 L F
.927 .837 .736 r
.56481 .76916 m .56333 .76864 L .56236 .76933 L F
.595 .473 .684 r
.57556 .62523 m .57675 .62891 L .5748 .63054 L F
.612 .433 .616 r
.57869 .62559 m .57675 .62891 L .57556 .62523 L F
.73 .989 .818 r
.67872 .50319 m .68079 .50084 L .68189 .50204 L F
.67872 .50319 m .67816 .50319 L .68079 .50084 L F
.449 .709 .978 r
.48178 .65844 m .48324 .65958 L .48427 .65826 L F
.48178 .65844 m .48324 .65958 L .48427 .65826 L F
.659 .585 .761 r
.5748 .63054 m .57675 .62891 L .57676 .6307 L F
.948 .829 .694 r
.73327 .4864 m .73359 .48977 L .73276 .48871 L F
1 .829 .519 r
.73359 .48977 m .73241 .49144 L .73276 .48871 L F
.73359 .48977 m .73328 .4923 L .73241 .49144 L F
.494 .35 .614 r
.39329 .60262 m .39178 .6028 L .39318 .60222 L F
.454 .261 .527 r
.45055 .66668 m .4485 .66494 L .45202 .66563 L F
.526 .189 .339 r
.45501 .66454 m .45457 .66561 L .45202 .66563 L F
0 0 0 r
.45256 .66553 m .45202 .66563 L .45457 .66561 L F
.45256 .66553 m .45055 .66668 L .45202 .66563 L F
0 .324 .747 r
.51311 .6489 m .51447 .64927 L .51246 .64719 L F
.51311 .6489 m .51614 .65039 L .51447 .64927 L F
.313 0 .238 r
.45708 .6655 m .45501 .66454 L .45801 .66359 L F
.45708 .6655 m .45457 .66561 L .45501 .66454 L F
.57 .31 .483 r
.48946 .78378 m .49342 .78181 L .4892 .7811 L F
.386 .128 .395 r
.5324 .80119 m .53358 .80114 L .53373 .80036 L F
.5324 .80119 m .53175 .80253 L .53358 .80114 L F
.598 .502 .717 r
.76394 .59634 m .76375 .59709 L .76624 .59474 L F
.595 .847 .992 r
.2869 .64176 m .28499 .64239 L .28942 .64203 L F
.615 .729 .927 r
.28942 .64203 m .28879 .63968 L .2869 .64176 L F
.28942 .64203 m .2911 .64211 L .28879 .63968 L F
.64 .417 .564 r
.28793 .64535 m .28953 .64644 L .28942 .64203 L F
.679 .448 .565 r
.28942 .64203 m .28953 .64644 L .2911 .64211 L F
.965 .896 .523 r
.48204 .79247 m .48275 .79249 L .48207 .79177 L F
.809 .812 .853 r
.48207 .79177 m .48246 .79252 L .48204 .7923 L F
.48207 .79177 m .48204 .7923 L .48024 .79135 L F
.965 .896 .523 r
.48198 .79247 m .48204 .79247 L .48207 .79177 L F
.48182 .79376 m .48275 .79249 L .48198 .79247 L F
.149 0 0 r
.48215 .79247 m .48275 .79249 L .47921 .79203 L F
.48246 .79252 m .48275 .79249 L .48215 .79247 L F
.834 .478 0 r
.48207 .79177 m .48275 .79249 L .48246 .79252 L F
.631 .243 .289 r
.48237 .7945 m .48275 .79249 L .48182 .79376 L F
.48237 .7945 m .4855 .79415 L .48275 .79249 L F
.499 .401 .676 r
.30011 .61893 m .29848 .6233 L .29791 .61957 L F
.937 .563 .23 r
.27485 .63345 m .2736 .63296 L .27301 .63093 L F
.022 .112 .619 r
.27389 .63633 m .2736 .63296 L .27485 .63345 L F
.82 .954 .904 r
.53809 .60034 m .53832 .59833 L .54054 .59777 L F
.53809 .60034 m .53703 .59974 L .53832 .59833 L F
.69 .511 .639 r
.24448 .6735 m .24718 .67087 L .24565 .67007 L F
.24448 .6735 m .24614 .67347 L .24718 .67087 L F
.953 .796 .649 r
.24643 .66765 m .24565 .67007 L .24718 .67087 L F
.53 .383 .625 r
.39858 .67677 m .40074 .67641 L .40036 .67392 L F
.565 .465 .7 r
.399 .67918 m .40074 .67641 L .39858 .67677 L F
.544 .249 .418 r
.55346 .76452 m .55177 .76681 L .5555 .7634 L F
0 0 .159 r
.5555 .7634 m .556 .7601 L .55753 .76077 L F
.5555 .7634 m .55603 .76305 L .556 .7601 L F
.622 .546 .748 r
.51897 .80586 m .52113 .80675 L .51995 .80633 L F
.397 .043 .243 r
.36168 .62904 m .36099 .63053 L .35885 .63096 L F
.278 0 .183 r
.36308 .62968 m .36168 .62904 L .36404 .62792 L F
.36308 .62968 m .36099 .63053 L .36168 .62904 L F
0 0 .063 r
.60554 .59102 m .60686 .5872 L .60638 .58894 L F
.954 .694 .505 r
.45708 .6904 m .45541 .68989 L .45699 .68782 L F
.477 .847 .989 r
.45541 .68989 m .45708 .6904 L .45699 .68782 L F
0 0 0 r
.32056 .64878 m .31892 .64895 L .32104 .64854 L F
.143 .671 .87 r
.31704 .64843 m .31892 .64895 L .32056 .64878 L F
.568 .397 .61 r
.76583 .5919 m .76624 .59474 L .76854 .59381 L F
.216 0 0 r
.71242 .47538 m .71259 .47674 L .70944 .47706 L F
.66 .321 .388 r
.71308 .47386 m .71479 .47583 L .71259 .47674 L F
.71308 .47386 m .71479 .47583 L .71259 .47674 L F
0 0 0 r
.71267 .47629 m .71259 .47674 L .71253 .47631 L F
.71308 .47386 m .71267 .47629 L .71242 .47538 L F
.71267 .47629 m .71253 .47631 L .71242 .47538 L F
.445 .13 .337 r
.70944 .47706 m .71259 .47674 L .71308 .47386 L F
0 0 0 r
.71138 .47657 m .71479 .47583 L .71259 .47674 L F
.7127 .47628 m .71446 .47592 L .71479 .47583 L F
.71138 .47657 m .7128 .47627 L .7127 .47628 L F
.7128 .47627 m .71446 .47592 L .7127 .47628 L F
.93 .805 .701 r
.63182 .55322 m .63381 .55179 L .63211 .55115 L F
.63182 .55322 m .63284 .55451 L .63381 .55179 L F
.375 .194 .502 r
.26582 .59454 m .26733 .59623 L .2681 .59423 L F
.26582 .59454 m .26561 .59689 L .26733 .59623 L F
.094 .394 .851 r
.66702 .47931 m .6685 .47841 L .6662 .47728 L F
.136 .386 .839 r
.66931 .48172 m .66991 .48046 L .66702 .47931 L F
.776 .846 .904 r
.27764 .64169 m .2796 .64276 L .28144 .64097 L F
.755 .303 .178 r
.26377 .64799 m .26835 .64833 L .26509 .64733 L F
.26377 .64799 m .26719 .6499 L .26835 .64833 L F
.97 .895 .694 r
.63236 .53712 m .63258 .5393 L .63307 .53787 L F
.652 .79 .948 r
.68956 .5007 m .68725 .50159 L .68611 .5002 L F
.797 .751 .81 r
.69456 .50941 m .69766 .50962 L .69691 .50644 L F
.764 .731 .822 r
.69691 .50644 m .69766 .50962 L .70013 .50687 L F
.127 0 .093 r
.56621 .56869 m .56792 .56771 L .56883 .56627 L F
.286 .063 .39 r
.571 .56328 m .56883 .56627 L .57051 .56522 L F
.272 0 .265 r
.56792 .56771 m .57051 .56522 L .56883 .56627 L F
0 .553 .763 r
.54179 .77738 m .5426 .77737 L .54033 .77716 L F
.54179 .77738 m .54408 .77762 L .5426 .77737 L F
.656 .278 .317 r
.49061 .6964 m .49285 .69827 L .49422 .69617 L F
.433 0 0 r
.49285 .69827 m .49854 .6977 L .49422 .69617 L F
.362 .058 .308 r
.36678 .62547 m .36597 .62802 L .36404 .62792 L F
.301 .004 .282 r
.36792 .62716 m .36678 .62547 L .36888 .62494 L F
.36792 .62716 m .36597 .62802 L .36678 .62547 L F
.335 0 .228 r
.56091 .57406 m .56307 .5734 L .56354 .57118 L F
.202 0 .183 r
.56354 .57118 m .56557 .57091 L .56621 .56869 L F
.203 0 .188 r
.56307 .5734 m .56557 .57091 L .56354 .57118 L F
.575 .408 .617 r
.60396 .55458 m .60297 .552 L .60434 .55191 L F
.435 .121 .332 r
.60677 .55189 m .60396 .55458 L .60434 .55191 L F
.623 .437 .61 r
.57168 .60593 m .57403 .60544 L .57391 .60301 L F
.531 .317 .534 r
.57403 .60544 m .5764 .60274 L .57391 .60301 L F
.642 .318 .408 r
.47567 .69384 m .47766 .69568 L .4789 .69315 L F
.727 .414 .45 r
.4789 .69315 m .4813 .69576 L .48106 .69336 L F
.4789 .69315 m .47766 .69568 L .4813 .69576 L F
.75 .514 .574 r
.61448 .55143 m .61255 .54911 L .61467 .54913 L F
.61448 .55143 m .61277 .5517 L .61255 .54911 L F
.62 .294 .397 r
.52715 .79402 m .52917 .79478 L .52685 .79258 L F
.451 .188 .422 r
.59369 .60241 m .59611 .5999 L .59406 .60044 L F
.933 .895 .768 r
.69115 .49755 m .69194 .49483 L .6915 .49484 L F
.165 0 .246 r
.69198 .49452 m .69403 .49324 L .69663 .49399 L F
.69403 .49324 m .69515 .49254 L .69646 .49382 L F
.69403 .49324 m .69646 .49382 L .69663 .49399 L F
.8 .497 .477 r
.69346 .4931 m .68956 .49118 L .69299 .49166 L F
.165 0 .246 r
.69198 .49452 m .69374 .49394 L .69515 .49254 L F
.8 .497 .477 r
.69374 .49394 m .6919 .49272 L .69346 .4931 L F
.6919 .49272 m .68956 .49118 L .69346 .4931 L F
.361 .421 .788 r
.6915 .49484 m .69374 .49394 L .69198 .49452 L F
.062 0 .077 r
.69194 .49483 m .69374 .49394 L .6915 .49484 L F
.34 .014 .257 r
.49305 .7866 m .49614 .78412 L .49565 .78636 L F
.95 .719 .554 r
.49565 .78636 m .49614 .78412 L .4948 .78277 L F
.819 .379 .194 r
.49402 .78282 m .49424 .7828 L .49431 .78268 L F
.49423 .78256 m .49431 .78268 L .49481 .78185 L F
.49402 .78282 m .49431 .78268 L .49423 .78256 L F
.95 .719 .554 r
.49439 .78279 m .4948 .78277 L .49415 .78212 L F
.49565 .78636 m .4948 .78277 L .49439 .78279 L F
.819 .379 .194 r
.49312 .78135 m .49402 .78282 L .49481 .78185 L F
.987 .734 .353 r
.49481 .78185 m .49413 .78298 L .49415 .78212 L F
0 .113 .651 r
.49625 .78517 m .49615 .78537 L .49415 .78212 L F
.49615 .78537 m .49565 .78636 L .49439 .78279 L F
.49615 .78537 m .49439 .78279 L .49415 .78212 L F
.819 .379 .194 r
.49402 .78282 m .49413 .78298 L .49424 .7828 L F
.915 .514 .159 r
.49415 .78212 m .49614 .78412 L .49481 .78185 L F
.806 .668 .711 r
.65269 .49213 m .65106 .49527 L .65478 .49558 L F
.785 .766 .836 r
.65067 .49794 m .65168 .50024 L .65394 .49796 L F
.802 .594 .622 r
.65106 .49527 m .65067 .49794 L .65394 .49796 L F
.65285 .49695 m .65394 .49796 L .65293 .49543 L F
0 0 .21 r
.65254 .50042 m .65323 .49675 L .65394 .49796 L F
.65274 .49935 m .65313 .49935 L .65323 .49675 L F
.65254 .50042 m .6527 .50012 L .65274 .49935 L F
.6527 .50012 m .65313 .49935 L .65274 .49935 L F
.802 .594 .622 r
.65293 .49543 m .65394 .49796 L .65478 .49558 L F
.65106 .49527 m .65285 .49695 L .65293 .49543 L F
.159 .7 .777 r
.68488 .47667 m .68347 .47669 L .68113 .47701 L F
.241 0 0 r
.68488 .47667 m .68587 .47706 L .68347 .47669 L F
.68488 .47667 m .68797 .47767 L .68587 .47706 L F
.065 .611 .84 r
.3153 .58371 m .3191 .5843 L .31662 .58445 L F
.054 0 0 r
.66604 .47458 m .66846 .47467 L .66969 .47465 L F
.215 0 0 r
.66846 .47467 m .67214 .47441 L .66969 .47465 L F
.566 .388 .6 r
.58335 .6197 m .58084 .62286 L .58082 .62026 L F
.449 .401 .712 r
.26092 .61488 m .26342 .61633 L .26285 .61293 L F
.696 .477 .586 r
.59597 .61144 m .59428 .61337 L .59403 .61151 L F
.59597 .61144 m .59608 .6142 L .59428 .61337 L F
.681 .458 .576 r
.59597 .61144 m .59897 .61333 L .59608 .6142 L F
.59597 .61144 m .59932 .61137 L .59897 .61333 L F
.329 .762 .97 r
.37226 .75845 m .37304 .75767 L .37081 .75773 L F
.37226 .75845 m .37462 .75834 L .37304 .75767 L F
.37226 .75845 m .37304 .75767 L .37081 .75773 L F
.37226 .75845 m .37462 .75834 L .37304 .75767 L F
.981 .848 .637 r
.63317 .52839 m .6336 .53089 L .63411 .5291 L F
.95 .917 .744 r
.63445 .52553 m .63411 .5291 L .6353 .5265 L F
.63445 .52553 m .63317 .52839 L .63411 .5291 L F
.218 0 .189 r
.57516 .55958 m .57785 .55702 L .57592 .55793 L F
0 0 .546 r
.48328 .77714 m .48266 .77828 L .48203 .77493 L F
0 0 .205 r
.48328 .77714 m .48296 .77861 L .48266 .77828 L F
.471 .247 .492 r
.36022 .6087 m .36232 .60818 L .36263 .60593 L F
.457 .235 .488 r
.36263 .60593 m .36432 .6075 L .36418 .60503 L F
.36263 .60593 m .36232 .60818 L .36432 .6075 L F
.468 .296 .564 r
.4243 .6876 m .42426 .69025 L .42222 .69069 L F
.423 .472 .806 r
.42484 .69225 m .42222 .69069 L .42426 .69025 L F
.478 .595 .892 r
.41314 .70683 m .41516 .70941 L .4168 .70913 L F
.521 .337 .572 r
.53998 .74433 m .54 .74687 L .54231 .74478 L F
.422 .594 .915 r
.43016 .69495 m .42919 .69679 L .42807 .69515 L F
.43016 .69495 m .43195 .69737 L .42919 .69679 L F
0 0 0 r
.47778 .76976 m .47891 .76914 L .48006 .7669 L F
.289 .755 .946 r
.48027 .76962 m .47891 .76914 L .47778 .76976 L F
0 0 .006 r
.56292 .59671 m .56124 .5979 L .56359 .59511 L F
0 0 0 r
.5644 .59489 m .56359 .59511 L .56505 .59385 L F
.5644 .59489 m .56292 .59671 L .56359 .59511 L F
.972 .657 .325 r
.48147 .77246 m .48059 .77406 L .48203 .77493 L F
.003 .533 .849 r
.33981 .60041 m .33621 .59923 L .33761 .60045 L F
.382 .085 .33 r
.56557 .57091 m .56792 .56771 L .56621 .56869 L F
.628 .194 .198 r
.53923 .77454 m .53713 .77281 L .53708 .77479 L F
.505 .598 .881 r
.55555 .77876 m .55333 .7788 L .55188 .77608 L F
.302 .731 .971 r
.55225 .77803 m .55333 .7788 L .55555 .77876 L F
0 0 .26 r
.24415 .67082 m .24489 .67019 L .24552 .66768 L F
.69 .511 .639 r
.24448 .6735 m .24489 .67019 L .24415 .67082 L F
.871 .865 .83 r
.54472 .74372 m .54601 .74478 L .54751 .74354 L F
.481 .806 1 r
.36181 .58978 m .3581 .58932 L .36019 .58903 L F
.374 .763 .988 r
.3625 .58871 m .36181 .58978 L .36019 .58903 L F
.3625 .58871 m .36383 .58962 L .36181 .58978 L F
.452 .437 .751 r
.40035 .6849 m .40283 .68711 L .40249 .68444 L F
.499 .401 .676 r
.30011 .61893 m .30027 .62307 L .29848 .6233 L F
.369 0 0 r
.46297 .70186 m .46168 .70285 L .45945 .70242 L F
.241 0 0 r
.46542 .70206 m .46168 .70285 L .46297 .70186 L F
.432 0 0 r
.31291 .64804 m .31311 .64896 L .31154 .64831 L F
.31291 .64804 m .31468 .64847 L .31311 .64896 L F
.617 .423 .597 r
.59403 .61151 m .59428 .61337 L .59149 .61415 L F
.975 .924 .638 r
.62976 .56568 m .63054 .564 L .62915 .56495 L F
.941 .959 .666 r
.62915 .56495 m .63054 .564 L .63065 .5619 L F
.3 .583 .941 r
.28879 .63968 m .2911 .64211 L .29187 .64128 L F
0 0 0 r
.2911 .64211 m .28953 .64644 L .29187 .64128 L F
.236 .415 .837 r
.51088 .63086 m .51391 .63296 L .51289 .63429 L F
.258 .447 .856 r
.51391 .63296 m .51569 .63601 L .51289 .63429 L F
.681 .685 .847 r
.69936 .46664 m .70066 .46778 L .69717 .46709 L F
.71 .688 .826 r
.70274 .46701 m .70066 .46778 L .69936 .46664 L F
.364 .023 .246 r
.3594 .6105 m .36232 .60818 L .36022 .6087 L F
.589 .376 .561 r
.58053 .70127 m .58341 .70147 L .5833 .69893 L F
.728 .53 .623 r
.58341 .70147 m .58573 .69892 L .5833 .69893 L F
.658 .39 .503 r
.55 .76598 m .55177 .76681 L .55346 .76452 L F
.555 .295 .478 r
.58568 .61719 m .58577 .61938 L .58335 .6197 L F
.553 .294 .478 r
.58568 .61719 m .58804 .61888 L .58577 .61938 L F
.91 .681 .579 r
.66586 .51473 m .66663 .51761 L .66716 .51557 L F
.559 .384 .6 r
.54601 .77243 m .5496 .77339 L .54825 .7696 L F
.559 .127 .177 r
.54822 .77485 m .54601 .77243 L .54476 .77416 L F
.54822 .77485 m .5496 .77339 L .54601 .77243 L F
.682 .747 .901 r
.70238 .50591 m .7058 .50647 L .70508 .50419 L F
.705 .749 .886 r
.7058 .50647 m .70711 .50298 L .70508 .50419 L F
.7058 .50647 m .70837 .50537 L .70711 .50298 L F
.451 .253 .519 r
.43229 .67308 m .43208 .67549 L .43026 .67359 L F
.329 .24 .601 r
.43208 .67549 m .43061 .67619 L .43026 .67359 L F
.91 .909 .807 r
.5499 .60488 m .55322 .60264 L .55192 .6023 L F
.5499 .60488 m .55097 .60569 L .55322 .60264 L F
.286 .767 .922 r
.55538 .60237 m .55192 .6023 L .55322 .60264 L F
.711 .707 .844 r
.67144 .52635 m .67246 .52929 L .67487 .52791 L F
.765 .955 .935 r
.7147 .49133 m .71582 .49203 L .71426 .49255 L F
.7147 .49133 m .71665 .48916 L .71582 .49203 L F
.123 0 .301 r
.5732 .5628 m .57516 .55958 L .57345 .56057 L F
.427 .535 .864 r
.30295 .62401 m .30199 .62593 L .30027 .62307 L F
.506 .633 .909 r
.30295 .62401 m .30412 .62579 L .30199 .62593 L F
.528 .561 .833 r
.57027 .72109 m .57085 .71757 L .56893 .71802 L F
.57027 .72109 m .57223 .72074 L .57085 .71757 L F
.864 .55 .453 r
.51519 .81171 m .51573 .81144 L .51527 .80979 L F
.66 .651 .83 r
.52113 .80675 m .52328 .80787 L .52391 .80589 L F
.725 .647 .771 r
.55096 .7558 m .55204 .75704 L .55401 .75566 L F
.944 .89 .49 r
.61089 .57424 m .6101 .5777 L .60981 .57592 L F
.753 .687 .142 r
.60938 .57984 m .60981 .57592 L .6101 .5777 L F
0 .165 .675 r
.66931 .48172 m .66986 .48174 L .66991 .48046 L F
.66931 .48172 m .67072 .48292 L .66986 .48174 L F
.608 .334 .476 r
.51883 .77706 m .5168 .77877 L .51697 .77746 L F
.5168 .77877 m .51589 .77955 L .51697 .77746 L F
.302 0 .051 r
.51684 .77824 m .51688 .77815 L .51697 .77746 L F
.51688 .77815 m .51764 .77659 L .51697 .77746 L F
.193 0 0 r
.52008 .77559 m .51764 .77659 L .51697 .77746 L F
.556 .535 .787 r
.47744 .78088 m .47974 .78063 L .47642 .77877 L F
.489 .491 .785 r
.47744 .78088 m .47967 .78169 L .47974 .78063 L F
.819 .586 .586 r
.55689 .74917 m .55896 .74704 L .55727 .74659 L F
.55689 .74917 m .55876 .74954 L .55896 .74704 L F
.055 0 .219 r
.57563 .65157 m .57471 .65336 L .57398 .65372 L F
0 0 .281 r
.57398 .65372 m .57462 .65523 L .57471 .65336 L F
.57398 .65372 m .57386 .65635 L .57462 .65523 L F
.774 .908 .933 r
.27266 .64937 m .27291 .64791 L .27091 .64854 L F
.682 .171 .015 r
.69039 .47584 m .69296 .47779 L .68967 .47697 L F
.523 .348 .585 r
.69272 .47497 m .69296 .47779 L .69039 .47584 L F
.579 .378 .573 r
.40432 .66205 m .40648 .66442 L .40664 .66196 L F
.40432 .66205 m .40421 .66495 L .40648 .66442 L F
.623 .739 .93 r
.28192 .64018 m .28499 .64239 L .2869 .64176 L F
.624 .812 .972 r
.30991 .62736 m .31139 .62848 L .30779 .6281 L F
.30991 .62736 m .31139 .62848 L .30779 .6281 L F
.631 .814 .97 r
.31234 .62666 m .31139 .62848 L .30991 .62736 L F
.474 .62 .914 r
.31234 .62666 m .3134 .62842 L .31139 .62848 L F
.24 0 .074 r
.48006 .7669 m .48095 .76828 L .48027 .76962 L F
.48006 .7669 m .47891 .76914 L .48095 .76828 L F
.972 .687 .428 r
.48747 .80082 m .48768 .80374 L .48639 .80254 L F
.761 .405 .38 r
.48427 .80097 m .48747 .80082 L .48643 .80239 L F
.972 .687 .428 r
.48747 .80082 m .48768 .80374 L .48639 .80254 L F
.676 .454 .578 r
.48747 .80082 m .48973 .80261 L .48768 .80374 L F
.48747 .80082 m .49095 .80095 L .48973 .80261 L F
.694 .62 .769 r
.48973 .80261 m .4887 .80647 L .48768 .80374 L F
.48973 .80261 m .49111 .80599 L .4887 .80647 L F
.18 0 0 r
.4887 .80647 m .48729 .80781 L .48854 .8087 L F
.4887 .80647 m .48949 .80706 L .48729 .80781 L F
.4887 .80647 m .49111 .80599 L .48949 .80706 L F
.424 .869 .838 r
.57494 .65085 m .57236 .65177 L .57315 .65168 L F
.699 .378 .429 r
.49073 .6445 m .4875 .64495 L .48881 .64525 L F
.7 .72 .865 r
.68644 .5264 m .68989 .52708 L .68879 .52552 L F
.68 .713 .873 r
.68879 .52552 m .68989 .52708 L .69221 .52619 L F
.323 0 .103 r
.42892 .6542 m .42985 .65544 L .4311 .65385 L F
.42892 .6542 m .42784 .65605 L .42985 .65544 L F
.534 .707 .951 r
.55017 .64499 m .54964 .64168 L .55131 .64384 L F
.535 .207 .359 r
.57535 .7035 m .57773 .70389 L .57753 .70257 L F
.986 .885 .635 r
.72666 .4927 m .72677 .48796 L .72588 .49167 L F
.986 .716 .419 r
.7256 .49399 m .72666 .4927 L .72588 .49167 L F
.7256 .49399 m .72677 .49502 L .72666 .4927 L F
.933 .696 .556 r
.2521 .65158 m .24972 .65253 L .24976 .65033 L F
.502 .786 .996 r
.2529 .65085 m .2521 .65158 L .24976 .65033 L F
.655 .18 .112 r
.2521 .65158 m .25344 .65299 L .24972 .65253 L F
.139 .161 .621 r
.2529 .65085 m .25344 .65299 L .2521 .65158 L F
.2529 .65085 m .25344 .65299 L .2521 .65158 L F
.681 .42 .521 r
.57773 .70389 m .57997 .70408 L .58053 .70127 L F
.667 .462 .598 r
.57997 .70408 m .58341 .70147 L .58053 .70127 L F
.934 .894 .766 r
.72929 .50869 m .73029 .5097 L .72844 .51277 L F
.085 0 0 r
.53694 .69305 m .53208 .69422 L .53468 .69349 L F
.601 .209 .273 r
.4848 .69651 m .48755 .69864 L .48838 .69596 L F
.6 .209 .273 r
.48838 .69596 m .48904 .69819 L .49061 .6964 L F
.48838 .69596 m .48755 .69864 L .48904 .69819 L F
.546 .647 .9 r
.49912 .81334 m .50021 .81136 L .49795 .81197 L F
.664 .627 .802 r
.68269 .52398 m .68413 .52733 L .68644 .5264 L F
.579 .481 .708 r
.57938 .63038 m .57767 .63407 L .57676 .6307 L F
.57938 .63038 m .57986 .63373 L .57767 .63407 L F
.559 .392 .612 r
.57767 .63407 m .57986 .63373 L .57783 .6365 L F
.612 .433 .616 r
.57869 .62559 m .57891 .62805 L .57675 .62891 L F
.548 .406 .639 r
.58084 .62286 m .58112 .6253 L .57869 .62559 L F
.543 .383 .613 r
.57869 .62559 m .58112 .6253 L .57891 .62805 L F
.996 .854 .575 r
.73331 .49816 m .73199 .49936 L .73302 .49747 L F
.73331 .49816 m .73278 .50057 L .73199 .49936 L F
.927 .859 .423 r
.73331 .49816 m .73302 .49747 L .73359 .49473 L F
.958 .815 .378 r
.27131 .64235 m .27088 .64181 L .27181 .63905 L F
.27088 .64181 m .27086 .64178 L .27089 .6417 L F
.27088 .64181 m .27089 .6417 L .27181 .63905 L F
0 0 0 r
.27181 .63905 m .27158 .64004 L .27293 .6384 L F
.746 .632 .734 r
.27293 .6384 m .27158 .64004 L .27099 .63936 L F
.27107 .63754 m .27099 .63936 L .26836 .63628 L F
.27293 .6384 m .27099 .63936 L .27107 .63754 L F
.152 0 .116 r
.27181 .63905 m .27102 .64165 L .27158 .64004 L F
.27181 .63905 m .27086 .64178 L .27102 .64165 L F
.635 .673 .869 r
.71522 .5092 m .71862 .51023 L .71756 .50864 L F
.689 .737 .888 r
.71862 .51023 m .72094 .5093 L .71756 .50864 L F
.674 .597 .762 r
.57675 .62891 m .57891 .62805 L .57676 .6307 L F
.612 .507 .71 r
.57891 .62805 m .57938 .63038 L .57676 .6307 L F
.586 .192 .261 r
.46615 .69529 m .46835 .69541 L .46987 .69352 L F
.709 .341 .35 r
.46835 .69541 m .47213 .69579 L .46987 .69352 L F
.6 .364 .531 r
.46987 .69352 m .47213 .69579 L .47144 .69312 L F
.933 .895 .768 r
.69115 .49755 m .69007 .49658 L .69194 .49483 L F
.89 .767 .719 r
.69115 .49755 m .6883 .49918 L .69007 .49658 L F
.69115 .49755 m .68956 .5007 L .6883 .49918 L F
.276 .764 .912 r
.52019 .64126 m .52273 .64094 L .52302 .64123 L F
0 .336 .731 r
.52273 .64094 m .5255 .64241 L .52302 .64123 L F
.223 0 0 r
.2977 .58502 m .29999 .58476 L .30148 .5838 L F
0 0 0 r
.30148 .5838 m .30199 .5841 L .30319 .58385 L F
.30148 .5838 m .29999 .58476 L .30199 .5841 L F
.518 .314 .543 r
.60127 .61006 m .59897 .61333 L .59932 .61137 L F
.74 .652 .762 r
.69221 .52619 m .69573 .52678 L .69456 .52337 L F
.453 .085 .248 r
.34913 .62136 m .35244 .6188 L .35076 .61996 L F
.682 .228 .168 r
.49542 .70106 m .49402 .70162 L .49222 .70086 L F
.528 .018 0 r
.49765 .70156 m .49402 .70162 L .49542 .70106 L F
.06 0 0 r
.45876 .6428 m .45946 .64343 L .46108 .64232 L F
.45876 .6428 m .45735 .64412 L .45946 .64343 L F
.318 .697 .98 r
.37309 .5919 m .37109 .59188 L .36966 .5909 L F
.739 .578 .675 r
.69327 .51777 m .69538 .51479 L .6932 .51555 L F
.69327 .51777 m .69684 .51815 L .69538 .51479 L F
.646 .781 .945 r
.57325 .72171 m .57471 .72091 L .57223 .72074 L F
.57325 .72171 m .57554 .72117 L .57471 .72091 L F
.63 .098 0 r
.2756 .64033 m .27764 .64169 L .27194 .63996 L F
0 .2 .715 r
.49296 .79407 m .49225 .7951 L .49427 .79724 L F
.701 .701 .847 r
.74111 .47929 m .73795 .47844 L .74052 .47769 L F
.568 .618 .862 r
.74312 .47708 m .74111 .47929 L .74052 .47769 L F
.74312 .47708 m .74302 .47892 L .74111 .47929 L F
.695 .294 .283 r
.58692 .60155 m .58779 .60034 L .58415 .59981 L F
.7 .3 .286 r
.58692 .60155 m .58991 .60223 L .58779 .60034 L F
.012 .511 .868 r
.55358 .64619 m .55523 .64616 L .55236 .64467 L F
.55358 .64619 m .55642 .64696 L .55523 .64616 L F
.565 .465 .7 r
.399 .67918 m .40121 .67875 L .40074 .67641 L F
.508 .477 .758 r
.399 .67918 m .40182 .68211 L .40121 .67875 L F
.394 0 0 r
.45247 .69644 m .45473 .69635 L .45586 .69558 L F
.261 0 0 r
.45473 .69635 m .4582 .69599 L .45586 .69558 L F
.363 0 0 r
.33766 .58729 m .33949 .58787 L .34117 .588 L F
.278 0 0 r
.33949 .58787 m .34311 .58847 L .34117 .588 L F
0 0 0 r
.57051 .56522 m .5732 .5628 L .571 .56328 L F
.444 .823 .99 r
.54917 .75188 m .55031 .75245 L .55142 .75147 L F
.54917 .75188 m .55031 .75245 L .55142 .75147 L F
.723 .57 .682 r
.55031 .75245 m .55096 .7558 L .55401 .75566 L F
.877 .761 .731 r
.67545 .51807 m .67335 .51743 L .67475 .51466 L F
.212 .684 .939 r
.32718 .58569 m .33384 .58688 L .32966 .58692 L F
.68 .849 .964 r
.67557 .50823 m .67533 .5096 L .67262 .50856 L F
.26 .708 .958 r
.69946 .47731 m .69845 .47676 L .69552 .47668 L F
.516 .803 .998 r
.69946 .47731 m .70044 .47625 L .69845 .47676 L F
.69946 .47731 m .70171 .477 L .70044 .47625 L F
.672 .378 .466 r
.50431 .77999 m .50798 .77757 L .5063 .77758 L F
.385 .031 .237 r
.38798 .6099 m .38655 .60881 L .38866 .60826 L F
.38798 .6099 m .38573 .61044 L .38655 .60881 L F
.693 .805 .935 r
.55415 .61715 m .55671 .61714 L .55431 .61606 L F
.703 .355 .384 r
.55415 .61715 m .55558 .61894 L .55671 .61714 L F
.376 0 0 r
.55911 .61701 m .55431 .61606 L .55671 .61714 L F
0 0 0 r
.55671 .61714 m .55771 .61702 L .55911 .61701 L F
.55671 .61714 m .55558 .61894 L .55771 .61702 L F
.484 .386 .668 r
.26337 .59742 m .26556 .59932 L .26561 .59689 L F
.26337 .59742 m .26369 .59996 L .26556 .59932 L F
0 0 .27 r
.62402 .57994 m .62426 .58209 L .62297 .58326 L F
0 0 .05 r
.6234 .5838 m .62297 .58326 L .62426 .58209 L F
.6234 .5838 m .62257 .58546 L .62297 .58326 L F
.803 .692 .743 r
.60297 .552 m .60115 .55537 L .60166 .55243 L F
.575 .408 .617 r
.60396 .55458 m .60115 .55537 L .60297 .552 L F
0 0 0 r
.52836 .78408 m .52633 .78568 L .52533 .78616 L F
.761 .887 .477 r
.52877 .7827 m .52836 .78408 L .53003 .7809 L F
.817 .986 .882 r
.52877 .7827 m .52633 .78568 L .52836 .78408 L F
.387 .007 .191 r
.36597 .62802 m .36308 .62968 L .36404 .62792 L F
.048 .01 .487 r
.67083 .50952 m .67264 .51036 L .67262 .50856 L F
.67083 .50952 m .67114 .51231 L .67264 .51036 L F
.524 .442 .705 r
.56598 .71638 m .56743 .71239 L .56514 .71277 L F
.56598 .71638 m .56831 .71604 L .56743 .71239 L F
.532 .507 .773 r
.56598 .71638 m .56893 .71802 L .56831 .71604 L F
.635 .398 .541 r
.57186 .70676 m .57619 .70671 L .57535 .7035 L F
.535 .393 .634 r
.57763 .70665 m .57535 .7035 L .57619 .70671 L F
.57763 .70665 m .57773 .70389 L .57535 .7035 L F
0 .313 .801 r
.73735 .53061 m .73807 .53094 L .73615 .52883 L F
.378 .814 .959 r
.53105 .77735 m .52878 .77773 L .53163 .77783 L F
0 0 0 r
.53106 .77999 m .53003 .7809 L .53163 .77783 L F
.53106 .77999 m .53163 .77783 L .52878 .77773 L F
.151 0 0 r
.43969 .70678 m .43531 .70893 L .43748 .70728 L F
.417 .081 .286 r
.31662 .60228 m .31338 .60504 L .31477 .60323 L F
.515 .436 .705 r
.40143 .69048 m .40348 .69009 L .40283 .68711 L F
.248 .243 .656 r
.37814 .70689 m .37998 .70906 L .37981 .70664 L F
.933 .926 .779 r
.52956 .60528 m .5267 .60757 L .52862 .60457 L F
.52956 .60528 m .52763 .60841 L .5267 .60757 L F
.848 .96 .88 r
.53219 .60263 m .52956 .60528 L .52862 .60457 L F
.419 .129 .362 r
.59428 .61337 m .59102 .61585 L .59149 .61415 L F
.883 .651 .128 r
.7385 .5218 m .73875 .52068 L .73721 .52054 L F
.7385 .5218 m .73892 .52288 L .73875 .52068 L F
.623 .857 .488 r
.55628 .75265 m .55401 .75566 L .55506 .75408 L F
.594 .811 .41 r
.55401 .75566 m .55283 .75735 L .55506 .75408 L F
.739 .377 .367 r
.55401 .75566 m .55539 .75791 L .55283 .75735 L F
.26 0 .224 r
.51863 .78888 m .51998 .78703 L .522 .78592 L F
.761 .66 .75 r
.72403 .46954 m .72496 .47301 L .72173 .47226 L F
.526 .551 .824 r
.72564 .46957 m .72496 .47301 L .72403 .46954 L F
.72564 .46957 m .7267 .47273 L .72496 .47301 L F
.723 .856 .945 r
.54115 .79318 m .54219 .79454 L .53975 .79513 L F
.658 .377 .483 r
.53975 .79513 m .54219 .79454 L .54156 .79677 L F
.323 .643 .967 r
.54407 .79459 m .54219 .79454 L .54115 .79318 L F
.43 .159 .399 r
.54156 .79677 m .54219 .79454 L .54407 .79459 L F
.638 .581 .774 r
.55653 .60359 m .5591 .606 L .55893 .60274 L F
0 0 0 r
.5591 .606 m .55867 .60705 L .56118 .60467 L F
.375 .32 .668 r
.55902 .60446 m .5591 .606 L .56118 .60467 L F
.828 .865 .873 r
.56118 .60467 m .55867 .60705 L .55721 .60614 L F
.396 .841 .931 r
.5598 .60498 m .56243 .60479 L .56118 .60467 L F
.56243 .60479 m .56357 .6047 L .56118 .60467 L F
.375 .32 .668 r
.55893 .60274 m .55902 .60446 L .56118 .60467 L F
.12 0 0 r
.34548 .59923 m .34193 .60011 L .34326 .59981 L F
.34548 .59923 m .34483 .59982 L .34193 .60011 L F
0 0 0 r
.34483 .59982 m .34411 .59987 L .34193 .60011 L F
.34326 .59981 m .34193 .60011 L .34094 .60022 L F
.34411 .59987 m .34035 .60015 L .34193 .60011 L F
.34094 .60022 m .34193 .60011 L .33981 .60041 L F
.59626 .55937 m .59349 .56248 L .59407 .56014 L F
.944 .89 .49 r
.61089 .57424 m .60981 .57592 L .61032 .57355 L F
.616 .461 .648 r
.45886 .65925 m .45677 .66188 L .45655 .6592 L F
.719 .913 .962 r
.68921 .47055 m .69042 .46843 L .69156 .46969 L F
.68921 .47055 m .68832 .46967 L .69042 .46843 L F
.542 .423 .667 r
.40074 .67641 m .40254 .67276 L .40036 .67392 L F
.779 .992 .766 r
.543 .5952 m .54054 .59777 L .54139 .59605 L F
.764 .988 .896 r
.54054 .59777 m .53832 .59833 L .54139 .59605 L F
.744 .578 .669 r
.63793 .50538 m .63464 .50313 L .63636 .50257 L F
.63793 .50538 m .63585 .50735 L .63464 .50313 L F
.692 .704 .856 r
.63988 .50334 m .63793 .50538 L .63636 .50257 L F
.139 .15 .608 r
.75088 .5027 m .74925 .50106 L .75071 .50028 L F
.631 .428 .588 r
.57719 .64562 m .57709 .64812 L .57459 .64796 L F
.524 .388 .638 r
.5791 .64222 m .57973 .64502 L .57719 .64562 L F
.551 .361 .577 r
.5793 .64655 m .57719 .64562 L .57973 .64502 L F
.5793 .64655 m .57709 .64812 L .57719 .64562 L F
.705 .745 .883 r
.7149 .48123 m .71269 .48241 L .71134 .48065 L F
.71 .688 .826 r
.70274 .46701 m .69936 .46664 L .70233 .46431 L F
.803 .804 .852 r
.70542 .46426 m .70274 .46701 L .70233 .46431 L F
.351 .796 .644 r
.26475 .65249 m .26278 .65353 L .2635 .65318 L F
.808 .696 .741 r
.50393 .64553 m .50074 .64533 L .50285 .64262 L F
.728 .578 .686 r
.50393 .64553 m .50138 .64755 L .50074 .64533 L F
.50393 .64553 m .50392 .64811 L .50138 .64755 L F
.758 .672 .767 r
.50635 .64312 m .50393 .64553 L .50285 .64262 L F
.514 .778 .992 r
.71307 .46202 m .71356 .4639 L .71251 .46273 L F
.71307 .46202 m .71385 .46319 L .71356 .4639 L F
.519 .295 .515 r
.35518 .6141 m .3574 .61368 L .35771 .61138 L F
.301 .11 .447 r
.35771 .61138 m .3574 .61368 L .3594 .6105 L F
.239 0 0 r
.55893 .60274 m .55538 .60237 L .55653 .60359 L F
.55893 .60274 m .55813 .60283 L .55538 .60237 L F
0 0 .233 r
.56047 .59931 m .56023 .60162 L .55893 .60274 L F
.512 .911 .811 r
.55893 .60274 m .56023 .60162 L .55813 .60283 L F
.375 .32 .668 r
.55893 .60274 m .56118 .60467 L .56141 .60277 L F
.723 .52 .615 r
.57128 .60806 m .57168 .60593 L .56874 .60691 L F
.944 .752 .613 r
.57023 .6059 m .57168 .60593 L .57128 .60806 L F
.667 .495 .643 r
.57128 .60806 m .57403 .60544 L .57168 .60593 L F
.487 .62 .908 r
.71151 .5068 m .71522 .5092 L .71363 .50661 L F
.587 .659 .888 r
.71363 .50661 m .71522 .5092 L .71756 .50864 L F
.779 .535 .567 r
.66034 .47743 m .66377 .47798 L .66365 .47544 L F
.544 .353 .572 r
.66365 .47544 m .6662 .47728 L .66604 .47458 L F
.66365 .47544 m .66377 .47798 L .6662 .47728 L F
.402 .455 .801 r
.49295 .80562 m .49111 .80599 L .48973 .80261 L F
.004 0 0 r
.48949 .80706 m .49111 .80599 L .49295 .80562 L F
.806 .741 .792 r
.72698 .5116 m .72748 .51573 L .72438 .51492 L F
.848 .469 0 r
.72748 .51573 m .7271 .51618 L .72438 .51492 L F
.72748 .51573 m .72779 .51682 L .7271 .51618 L F
0 .287 .715 r
.72656 .51569 m .7271 .51618 L .72993 .51774 L F
.72607 .51539 m .7271 .51618 L .72656 .51569 L F
.848 .469 0 r
.72779 .51682 m .72793 .51731 L .7271 .51618 L F
.869 .783 .763 r
.72844 .51277 m .72748 .51573 L .72698 .5116 L F
.022 .593 .759 r
.34933 .59946 m .34777 .59932 L .34548 .59923 L F
.167 .7 .842 r
.35146 .59932 m .34777 .59932 L .34933 .59946 L F
.595 .546 .77 r
.522 .78592 m .51948 .78615 L .52117 .78653 L F
.864 .761 .747 r
.49243 .64809 m .491 .64967 L .4923 .65052 L F
.49243 .64809 m .48874 .65016 L .491 .64967 L F
.153 .038 .459 r
.49243 .64809 m .49399 .64922 L .49462 .64873 L F
.49243 .64809 m .4923 .65052 L .49399 .64922 L F
.347 .131 .437 r
.2616 .60273 m .2633 .60216 L .26369 .59996 L F
.443 .331 .63 r
.26177 .60527 m .2633 .60216 L .2616 .60273 L F
.56 .391 .609 r
.42585 .68188 m .42593 .6842 L .42364 .68451 L F
.544 .466 .718 r
.42642 .68706 m .42364 .68451 L .42593 .6842 L F
.42642 .68706 m .4243 .6876 L .42364 .68451 L F
.851 .987 .712 r
.38153 .70914 m .38316 .70607 L .37998 .70906 L F
.561 .18 .277 r
.32249 .64793 m .32424 .64783 L .32104 .64854 L F
.361 0 .06 r
.4363 .65229 m .4386 .65201 L .43689 .65133 L F
.367 0 0 r
.43689 .65133 m .4386 .65201 L .43934 .65116 L F
0 0 0 r
.24614 .67347 m .24526 .67603 L .24514 .67635 L F
.693 .977 .904 r
.24514 .67635 m .24526 .67603 L .24472 .6764 L F
.728 .53 .623 r
.58341 .70147 m .58562 .70153 L .58573 .69892 L F
.603 .86 .992 r
.69936 .46664 m .69717 .46709 L .69841 .46543 L F
.663 .945 .694 r
.69717 .46709 m .69686 .46702 L .69841 .46543 L F
.224 .73 .896 r
.34311 .58847 m .34525 .58832 L .34675 .58861 L F
.164 .681 .889 r
.34741 .58823 m .34675 .58861 L .34525 .58832 L F
.34741 .58823 m .34891 .58863 L .34675 .58861 L F
.675 .183 .07 r
.50665 .70254 m .50559 .70353 L .50319 .70178 L F
.698 .211 .088 r
.50665 .70254 m .50944 .70432 L .50559 .70353 L F
.704 .28 .236 r
.51001 .70354 m .50944 .70432 L .50665 .70254 L F
.435 .121 .332 r
.60677 .55189 m .60625 .55414 L .60396 .55458 L F
.614 .283 .386 r
.60927 .55366 m .60625 .55414 L .60677 .55189 L F
.995 .801 .531 r
.54849 .77735 m .54963 .77585 L .54873 .77481 L F
0 0 0 r
.54963 .77585 m .55093 .77207 L .54873 .77481 L F
.737 .485 .548 r
.54849 .77735 m .55188 .77608 L .54963 .77585 L F
.727 .861 .944 r
.5161 .78905 m .51757 .78991 L .51863 .78888 L F
.815 .624 .644 r
.53538 .68935 m .53957 .69056 L .5393 .68773 L F
.341 .117 .422 r
.5393 .68773 m .54117 .68714 L .54146 .68479 L F
0 0 .138 r
.53957 .69056 m .54117 .68714 L .5393 .68773 L F
.076 0 .171 r
.35518 .6141 m .35292 .61698 L .35453 .61595 L F
.219 0 .347 r
.35292 .61698 m .35415 .61742 L .35453 .61595 L F
.35292 .61698 m .35244 .6188 L .35415 .61742 L F
.907 .517 .263 r
.55659 .75866 m .556 .7601 L .55539 .75791 L F
.55659 .75866 m .55753 .76077 L .556 .7601 L F
.93 .866 .755 r
.72597 .49703 m .72623 .50166 L .73009 .49919 L F
.272 0 0 r
.52533 .78616 m .52432 .78631 L .522 .78592 L F
.43 .871 .887 r
.52633 .78568 m .5258 .7857 L .52533 .78616 L F
.461 .887 .826 r
.5258 .7857 m .52432 .78631 L .52533 .78616 L F
.567 .667 .905 r
.6989 .49365 m .69743 .49577 L .69663 .49399 L F
.553 .647 .897 r
.70007 .49538 m .69743 .49577 L .6989 .49365 L F
.823 .867 .879 r
.68392 .50033 m .68189 .50204 L .68079 .50084 L F
.218 .741 .796 r
.4351 .69936 m .4375 .6989 L .43854 .69886 L F
.495 .886 .959 r
.43854 .69886 m .43942 .69789 L .44068 .6981 L F
.538 .926 .878 r
.43854 .69886 m .4375 .6989 L .43942 .69789 L F
.727 .623 .742 r
.52739 .74777 m .52889 .74985 L .52612 .74977 L F
.672 .31 .352 r
.52889 .74985 m .52838 .75184 L .52612 .74977 L F
.165 .38 .828 r
.52805 .74868 m .52928 .74971 L .52889 .74985 L F
.52739 .74777 m .52869 .74911 L .52805 .74868 L F
.52869 .74911 m .52928 .74971 L .52805 .74868 L F
.584 .337 .509 r
.52869 .74911 m .52922 .74946 L .5294 .74893 L F
.647 .517 .69 r
.52739 .74777 m .52869 .74911 L .5294 .74893 L F
.165 .38 .828 r
.52904 .74947 m .53009 .74941 L .52928 .74971 L F
.139 0 .288 r
.5294 .74893 m .52922 .74946 L .53009 .74941 L F
.165 .38 .828 r
.52739 .74777 m .53009 .74941 L .52904 .74947 L F
0 0 .097 r
.53009 .74941 m .52838 .75184 L .52889 .74985 L F
.139 0 .288 r
.52922 .74946 m .52838 .75184 L .53009 .74941 L F
.584 .337 .509 r
.52612 .74977 m .52838 .75184 L .52922 .74946 L F
.52612 .74977 m .52922 .74946 L .52869 .74911 L F
.647 .517 .69 r
.52739 .74777 m .52612 .74977 L .52869 .74911 L F
.487 .545 .841 r
.47642 .77877 m .47974 .78063 L .47808 .77697 L F
.993 .768 .489 r
.55015 .60507 m .55091 .60814 L .55097 .60569 L F
.55006 .60541 m .55091 .60814 L .55015 .60507 L F
.768 .701 .789 r
.54732 .60769 m .55091 .60814 L .5499 .60488 L F
.097 0 .101 r
.55065 .60794 m .54976 .60659 L .55102 .60603 L F
.54976 .60659 m .54958 .60632 L .54984 .60627 L F
.54976 .60659 m .54984 .60627 L .55102 .60603 L F
.993 .768 .489 r
.5499 .60488 m .55006 .60541 L .55015 .60507 L F
.311 0 0 r
.51249 .70328 m .50944 .70432 L .51001 .70354 L F
.93 .866 .755 r
.72597 .49703 m .72492 .50064 L .72623 .50166 L F
.904 .878 .799 r
.72492 .50064 m .72524 .50312 L .72623 .50166 L F
.758 .449 .462 r
.48951 .78628 m .49305 .7866 L .49284 .78927 L F
.605 .315 .449 r
.49284 .78927 m .49305 .7866 L .49396 .78938 L F
.546 .282 .467 r
.49305 .7866 m .49565 .78636 L .49396 .78938 L F
.993 .777 .402 r
.56402 .61813 m .56499 .61698 L .5628 .61642 L F
.735 .566 .664 r
.56284 .61756 m .5633 .61789 L .56402 .61813 L F
.993 .777 .402 r
.56402 .61813 m .56473 .61939 L .56484 .61841 L F
.558 .322 .514 r
.56499 .61698 m .56473 .61939 L .56724 .61893 L F
.673 .16 .011 r
.56402 .61813 m .56724 .61893 L .56473 .61939 L F
.735 .566 .664 r
.5633 .61789 m .56593 .61977 L .56402 .61813 L F
.993 .777 .402 r
.56402 .61813 m .56484 .61841 L .56499 .61698 L F
.844 .892 .873 r
.56616 .6137 m .56499 .61698 L .56721 .61643 L F
.56616 .6137 m .5628 .61642 L .56499 .61698 L F
.558 .322 .514 r
.56499 .61698 m .56724 .61893 L .56721 .61643 L F
.738 .592 .694 r
.69327 .51777 m .69452 .52117 L .69684 .51815 L F
.507 .33 .576 r
.42642 .68706 m .42426 .69025 L .4243 .6876 L F
.758 .672 .767 r
.50635 .64312 m .50285 .64262 L .50494 .64181 L F
.694 .718 .867 r
.58131 .71874 m .58242 .71513 L .58005 .71774 L F
.58131 .71874 m .58368 .71758 L .58242 .71513 L F
.343 .775 .97 r
.32239 .63118 m .32493 .63073 L .32649 .63163 L F
.18 0 0 r
.32493 .63073 m .32914 .6311 L .32649 .63163 L F
.835 .684 .695 r
.51356 .80964 m .51198 .80623 L .51167 .80869 L F
.602 .91 .981 r
.52213 .80547 m .52113 .80675 L .51995 .80633 L F
.52213 .80547 m .52113 .80675 L .51995 .80633 L F
.612 .349 .495 r
.60396 .55458 m .60112 .55671 L .60115 .55537 L F
.116 .219 .695 r
.55466 .6162 m .55558 .61894 L .55415 .61715 L F
.376 0 0 r
.55911 .61701 m .55839 .61712 L .5544 .61608 L F
.55438 .61607 m .5544 .61608 L .55431 .61606 L F
.55911 .61701 m .5544 .61608 L .55438 .61607 L F
.355 .673 .976 r
.55431 .61606 m .55587 .61647 L .55695 .61536 L F
.641 .586 .777 r
.55771 .61702 m .55558 .61894 L .55483 .61587 L F
.355 .673 .976 r
.55587 .61647 m .55804 .61703 L .55695 .61536 L F
.641 .586 .777 r
.55771 .61702 m .55483 .61587 L .55695 .61536 L F
.116 .219 .695 r
.55483 .61587 m .55494 .61633 L .55466 .6162 L F
.55494 .61633 m .55558 .61894 L .55466 .6162 L F
.198 .325 .768 r
.55431 .61606 m .55483 .61587 L .55415 .61715 L F
.355 .673 .976 r
.55431 .61606 m .55695 .61536 L .55445 .61331 L F
.125 .105 .563 r
.55445 .61331 m .55483 .61587 L .55431 .61606 L F
.321 .245 .613 r
.55445 .61331 m .55695 .61536 L .55483 .61587 L F
.537 .842 .526 r
.55436 .61804 m .55695 .61536 L .55337 .61483 L F
.508 .824 .51 r
.55695 .61536 m .55554 .61676 L .55762 .61468 L F
.583 .545 .778 r
.55523 .61238 m .55695 .61536 L .56017 .61214 L F
.508 .824 .51 r
.55695 .61536 m .55762 .61468 L .56017 .61214 L F
.355 .673 .976 r
.55804 .61703 m .55839 .61712 L .55821 .61691 L F
.55804 .61703 m .55821 .61691 L .55695 .61536 L F
.47 .893 .878 r
.55911 .61701 m .55806 .61702 L .56052 .61602 L F
.55806 .61702 m .55771 .61702 L .55837 .61679 L F
.689 .848 .959 r
.55695 .61536 m .55821 .61691 L .56052 .61602 L F
.47 .893 .878 r
.55806 .61702 m .55821 .61691 L .56052 .61602 L F
.689 .848 .959 r
.55821 .61691 m .55839 .61712 L .56052 .61602 L F
.47 .893 .878 r
.55821 .61691 m .55837 .61679 L .56052 .61602 L F
.457 .881 .785 r
.55911 .61701 m .55839 .61712 L .56052 .61602 L F
.69 .511 .639 r
.24448 .6735 m .24565 .67007 L .24489 .67019 L F
.701 .515 .633 r
.24453 .67604 m .24614 .67347 L .24448 .6735 L F
.179 .118 .546 r
.46358 .6564 m .46417 .65834 L .463 .65823 L F
.495 .091 .203 r
.46645 .65313 m .4655 .65588 L .46301 .65588 L F
.46645 .65313 m .46301 .65588 L .46283 .65572 L F
.46283 .65572 m .46301 .65588 L .46262 .65588 L F
.545 .66 .911 r
.46262 .65588 m .4655 .65588 L .46417 .65455 L F
.179 .118 .546 r
.46417 .65455 m .46417 .65693 L .46358 .6564 L F
.46417 .65693 m .46417 .65834 L .46358 .6564 L F
0 0 0 r
.46914 .65073 m .46806 .65268 L .46645 .65313 L F
0 0 .021 r
.46806 .65268 m .4655 .65588 L .46645 .65313 L F
.637 .6 .795 r
.4989 .62497 m .49544 .62257 L .4977 .62193 L F
.517 .531 .81 r
.49994 .6216 m .4989 .62497 L .4977 .62193 L F
.49994 .6216 m .50117 .62498 L .4989 .62497 L F
.677 .458 .582 r
.57859 .60211 m .58213 .59981 L .57832 .59986 L F
.705 .702 .844 r
.58706 .71841 m .58583 .71563 L .58368 .71758 L F
.631 .517 .706 r
.58792 .71601 m .58583 .71563 L .58706 .71841 L F
.923 .746 .644 r
.59287 .70679 m .59399 .71007 L .59437 .70762 L F
.601 .414 .601 r
.69451 .47577 m .6943 .47605 L .69449 .47612 L F
.415 .269 .572 r
.69449 .47612 m .69296 .47779 L .69272 .47497 L F
.601 .414 .601 r
.6943 .47605 m .69296 .47779 L .69449 .47612 L F
.674 .156 0 r
.69296 .47779 m .6918 .47854 L .68967 .47697 L F
.601 .414 .601 r
.6943 .47605 m .6918 .47854 L .69296 .47779 L F
.69451 .47577 m .69425 .47603 L .6943 .47605 L F
.69425 .47603 m .6918 .47854 L .6943 .47605 L F
.411 0 0 r
.69476 .47621 m .69449 .47612 L .69448 .47611 L F
.69474 .4762 m .69448 .47611 L .69272 .47497 L F
.69476 .47621 m .69448 .47611 L .69474 .4762 L F
.69552 .47668 m .69449 .47612 L .69476 .47621 L F
.511 .596 .875 r
.69552 .47668 m .69741 .47402 L .69449 .47612 L F
.69552 .47668 m .69845 .47676 L .69741 .47402 L F
.814 .913 .906 r
.50522 .8148 m .50787 .81282 L .50599 .81196 L F
.386 0 0 r
.50604 .81526 m .50522 .8148 L .50382 .81425 L F
.303 .114 .45 r
.50505 .81767 m .50522 .8148 L .50604 .81526 L F
.947 .608 .344 r
.54376 .63338 m .54138 .62975 L .54354 .63112 L F
.494 .276 .512 r
.62737 .4983 m .62975 .49776 L .62981 .49512 L F
.498 .352 .614 r
.62981 .49512 m .63204 .49453 L .63175 .49215 L F
.383 .189 .489 r
.62981 .49512 m .63167 .49677 L .63204 .49453 L F
.62981 .49512 m .62975 .49776 L .63167 .49677 L F
.798 .772 .83 r
.70882 .46897 m .7072 .46996 L .70977 .46948 L F
.618 .741 .934 r
.70977 .46948 m .71151 .46823 L .70882 .46897 L F
.70977 .46948 m .71142 .46943 L .71151 .46823 L F
.702 .484 .588 r
.64433 .5067 m .6433 .50612 L .64677 .50627 L F
.639 .903 .984 r
.64788 .5046 m .64677 .50627 L .64889 .50531 L F
.42 .218 .497 r
.64788 .5046 m .64433 .5067 L .64677 .50627 L F
.563 .455 .689 r
.40228 .66781 m .4045 .66738 L .40421 .66495 L F
.495 .376 .647 r
.40228 .66781 m .40455 .66984 L .4045 .66738 L F
.40228 .66781 m .4026 .67039 L .40455 .66984 L F
.026 .339 .819 r
.40533 .69657 m .40664 .69526 L .40522 .69561 L F
.40533 .69657 m .40698 .69711 L .40664 .69526 L F
.40533 .69657 m .40797 .6987 L .40698 .69711 L F
0 0 .33 r
.73458 .52627 m .73478 .52605 L .73354 .52277 L F
0 .042 .605 r
.73458 .52627 m .73584 .52703 L .73478 .52605 L F
.73458 .52627 m .73615 .52883 L .73584 .52703 L F
.838 .712 .725 r
.61426 .56003 m .61575 .56318 L .6123 .56295 L F
.902 .875 .8 r
.61575 .56318 m .6129 .56417 L .6123 .56295 L F
.61575 .56318 m .61361 .56638 L .6129 .56417 L F
.99 .76 .378 r
.63204 .54309 m .63206 .5456 L .6328 .54655 L F
.99 .881 .616 r
.6328 .54655 m .63132 .54798 L .63214 .54878 L F
.6328 .54655 m .63206 .5456 L .63132 .54798 L F
.887 .962 .84 r
.66068 .52171 m .65858 .52303 L .6605 .52039 L F
.519 .112 .209 r
.66068 .52171 m .66134 .52314 L .65858 .52303 L F
.196 .457 .879 r
.6605 .52039 m .66355 .52226 L .66068 .52171 L F
.365 .043 .281 r
.66355 .52226 m .66134 .52314 L .66068 .52171 L F
.762 .304 0 r
.55795 .64797 m .55932 .65027 L .55827 .64926 L F
.83 .422 .272 r
.56125 .65071 m .55932 .65027 L .55795 .64797 L F
.937 .87 .747 r
.63016 .55638 m .63284 .55451 L .63182 .55322 L F
.63016 .55638 m .6313 .55731 L .63284 .55451 L F
.886 .991 .776 r
.47984 .62899 m .48021 .62705 L .48133 .62744 L F
.47984 .62899 m .47804 .62999 L .48021 .62705 L F
.8 .994 .766 r
.543 .5952 m .54387 .59332 L .54471 .59379 L F
.543 .5952 m .54139 .59605 L .54387 .59332 L F
.79 .628 .679 r
.47528 .6483 m .47496 .65074 L .47155 .65001 L F
.66 .4 .516 r
.47144 .69312 m .47593 .69492 L .47567 .69384 L F
.47144 .69312 m .47213 .69579 L .47593 .69492 L F
.47 .88 .944 r
.4931 .80008 m .49275 .8005 L .49095 .80095 L F
.611 .381 .544 r
.49095 .80095 m .49225 .80328 L .48973 .80261 L F
.49095 .80095 m .49275 .8005 L .49225 .80328 L F
.706 .28 .234 r
.47593 .69492 m .47766 .69568 L .47567 .69384 L F
.452 .484 .801 r
.26194 .60845 m .26274 .61116 L .26464 .61001 L F
.299 .095 .426 r
.26274 .61116 m .26438 .61245 L .26464 .61001 L F
.26274 .61116 m .26285 .61293 L .26438 .61245 L F
.924 .946 .792 r
.75271 .51779 m .75088 .51916 L .75235 .51693 L F
.75271 .51779 m .75088 .51916 L .75235 .51693 L F
.972 .927 .674 r
.75235 .51693 m .75109 .52025 L .75271 .51779 L F
.623 .857 .488 r
.55628 .75265 m .55506 .75408 L .55489 .75191 L F
0 .2 .68 r
.54146 .68479 m .5448 .68734 L .54479 .68746 L F
.711 .437 .509 r
.54117 .68714 m .5448 .68734 L .54146 .68479 L F
.638 .825 .972 r
.49301 .62343 m .48998 .62366 L .49193 .62289 L F
.729 .859 .942 r
.49544 .62257 m .49301 .62343 L .49193 .62289 L F
.771 .277 0 r
.49471 .66676 m .4965 .6681 L .49605 .66742 L F
.49471 .66676 m .4965 .6681 L .49605 .66742 L F
.543 .749 .972 r
.28839 .64732 m .29202 .64826 L .29042 .64691 L F
.479 .722 .977 r
.29042 .64691 m .29202 .64826 L .29446 .64777 L F
.926 .639 .479 r
.48263 .7999 m .48427 .80097 L .48383 .79785 L F
.605 .413 .595 r
.48383 .79785 m .48427 .80097 L .48263 .7999 L F
.48383 .79785 m .48651 .79743 L .48427 .80097 L F
.489 .265 .5 r
.60899 .60506 m .60643 .6078 L .60687 .60589 L F
.57 .637 .879 r
.75003 .48553 m .74889 .48697 L .74698 .48392 L F
.052 0 .369 r
.75003 .48553 m .74878 .48891 L .74889 .48697 L F
.958 .616 .288 r
.73328 .4923 m .73241 .49364 L .73241 .49144 L F
.73328 .4923 m .73359 .49473 L .73241 .49364 L F
0 .27 .771 r
.65885 .48425 m .66104 .4859 L .66107 .48676 L F
0 .104 .655 r
.66104 .4859 m .66288 .48876 L .66107 .48676 L F
.534 .284 .483 r
.59515 .54043 m .59756 .54001 L .59784 .53792 L F
.528 .28 .482 r
.59784 .53792 m .60002 .5395 L .60015 .53723 L F
.59784 .53792 m .59756 .54001 L .60002 .5395 L F
.404 .094 .323 r
.35518 .6141 m .35681 .61512 L .3574 .61368 L F
.35518 .6141 m .35453 .61595 L .35681 .61512 L F
.794 .537 .549 r
.61401 .55752 m .61069 .5594 L .6125 .55663 L F
.61401 .55752 m .61426 .56003 L .61069 .5594 L F
.552 .332 .535 r
.60412 .60807 m .60127 .61006 L .60172 .60847 L F
.287 .456 .854 r
.38459 .59591 m .38384 .5978 L .38307 .59577 L F
.474 .675 .952 r
.38459 .59591 m .38627 .59782 L .38384 .5978 L F
.366 .208 .53 r
.63633 .50063 m .63636 .50257 L .63464 .50313 L F
.899 .569 .414 r
.563 .7561 m .56363 .75484 L .56228 .75488 L F
.563 .7561 m .56485 .7574 L .56363 .75484 L F
.216 0 0 r
.44572 .70502 m .44415 .70606 L .4419 .70628 L F
.275 0 0 r
.44792 .70491 m .44415 .70606 L .44572 .70502 L F
.721 .694 .824 r
.70641 .49628 m .7036 .49599 L .70559 .49504 L F
.682 .754 .906 r
.70815 .49474 m .70641 .49628 L .70559 .49504 L F
.612 .753 .945 r
.53448 .6551 m .53529 .65656 L .53697 .65558 L F
.53448 .6551 m .53529 .65656 L .53697 .65558 L F
.44 .161 .391 r
.35885 .63096 m .35808 .63298 L .35612 .63336 L F
.325 .002 .255 r
.36099 .63053 m .35808 .63298 L .35885 .63096 L F
.687 .787 .927 r
.52778 .77883 m .52869 .77714 L .52527 .77493 L F
.52778 .77883 m .52878 .77773 L .52869 .77714 L F
.027 0 .248 r
.52778 .77883 m .52697 .78096 L .52878 .77773 L F
.701 .515 .633 r
.24453 .67604 m .24526 .67603 L .24614 .67347 L F
.539 .853 .998 r
.29604 .64958 m .29544 .65085 L .29391 .65019 L F
.29391 .65019 m .29544 .65085 L .29604 .64958 L F
.898 .875 .806 r
.72492 .50064 m .72303 .50317 L .72524 .50312 L F
.935 .878 .754 r
.72229 .50547 m .72524 .50312 L .72303 .50317 L F
.72229 .50547 m .72336 .50649 L .72524 .50312 L F
.621 .499 .693 r
.56457 .7109 m .56743 .71239 L .56756 .7106 L F
.56457 .7109 m .56514 .71277 L .56743 .71239 L F
.312 .8 .779 r
.6836 .47118 m .68463 .47063 L .68583 .47045 L F
.6836 .47118 m .68232 .4714 L .68463 .47063 L F
.712 .718 .853 r
.2651 .61938 m .26791 .62029 L .26717 .61874 L F
.522 .617 .888 r
.26717 .61874 m .26791 .62029 L .26923 .61849 L F
.454 .521 .837 r
.26791 .62029 m .27114 .62224 L .26923 .61849 L F
.69 .917 .971 r
.74234 .51263 m .74529 .5123 L .74431 .51128 L F
.217 0 .238 r
.50275 .64764 m .50138 .64755 L .50392 .64811 L F
.187 .325 .773 r
.50392 .64811 m .50492 .6466 L .50275 .64764 L F
.136 0 0 r
.50413 .64811 m .50604 .64834 L .50392 .64811 L F
.50651 .64809 m .50604 .64834 L .50413 .64811 L F
.817 .551 .536 r
.50903 .64784 m .50855 .64983 L .50604 .64834 L F
.198 .09 .497 r
.50604 .64834 m .50719 .64871 L .50718 .64849 L F
.817 .551 .536 r
.50903 .64784 m .50604 .64834 L .50651 .64809 L F
.198 .09 .497 r
.50604 .64834 m .50718 .64849 L .50712 .64619 L F
.187 .325 .773 r
.50392 .64811 m .50604 .64834 L .50492 .6466 L F
.729 .859 .942 r
.49544 .62257 m .49193 .62289 L .49437 .62239 L F
.761 .887 .477 r
.52877 .7827 m .53003 .7809 L .52864 .78045 L F
.561 .927 .936 r
.49544 .62257 m .49645 .62142 L .4977 .62193 L F
.49544 .62257 m .49437 .62239 L .49645 .62142 L F
.431 .848 .961 r
.52864 .78045 m .53003 .7809 L .53106 .77999 L F
.362 .069 .326 r
.63925 .48602 m .64157 .48557 L .64185 .48389 L F
.681 .284 .287 r
.63925 .48602 m .64212 .48833 L .64157 .48557 L F
.63925 .48602 m .63855 .48817 L .64212 .48833 L F
.823 .867 .879 r
.68392 .50033 m .68079 .50084 L .68253 .49907 L F
.507 .621 .899 r
.68483 .49769 m .68392 .50033 L .68253 .49907 L F
.68483 .49769 m .68611 .5002 L .68392 .50033 L F
.38 .053 .28 r
.52212 .69085 m .52156 .69231 L .52427 .69035 L F
.938 .568 .248 r
.52763 .60841 m .52688 .60964 L .5267 .60757 L F
.52763 .60841 m .5283 .61057 L .52688 .60964 L F
.446 0 .025 r
.50751 .62626 m .50926 .62669 L .51058 .62527 L F
0 .44 .725 r
.50775 .62623 m .50926 .62669 L .50751 .62626 L F
0 0 .554 r
.50898 .62686 m .50926 .62669 L .50775 .62623 L F
.608 .862 .513 r
.50926 .62669 m .5088 .62745 L .50957 .62651 L F
0 .142 .669 r
.50926 .62669 m .51114 .62901 L .51031 .63002 L F
0 0 .554 r
.51031 .62754 m .50926 .62669 L .50898 .62686 L F
.608 .862 .513 r
.50926 .62669 m .50957 .62651 L .51058 .62527 L F
0 0 .545 r
.50926 .62669 m .51031 .63002 L .5088 .62745 L F
.621 .592 .799 r
.53175 .80253 m .53515 .80389 L .53358 .80114 L F
.991 .741 .442 r
.4485 .66494 m .44726 .6662 L .44497 .66516 L F
.4485 .66494 m .4484 .66764 L .44726 .6662 L F
.454 .261 .527 r
.45055 .66668 m .4484 .66764 L .4485 .66494 L F
.065 .22 .714 r
.74477 .48047 m .74648 .48219 L .74558 .48338 L F
.171 .377 .824 r
.74648 .48219 m .74698 .48392 L .74558 .48338 L F
.455 .195 .429 r
.2681 .59423 m .27017 .59375 L .27074 .59152 L F
.516 .284 .502 r
.27017 .59375 m .27261 .5909 L .27074 .59152 L F
.514 .386 .643 r
.64101 .50637 m .64108 .50904 L .63863 .5096 L F
.723 .856 .945 r
.54115 .79318 m .53975 .79513 L .53832 .79431 L F
.79 .639 .694 r
.53975 .79513 m .53952 .79781 L .53832 .79431 L F
.512 .393 .655 r
.54156 .79677 m .53952 .79781 L .53975 .79513 L F
.54156 .79677 m .53952 .79781 L .53975 .79513 L F
.136 0 .008 r
.46998 .65183 m .46914 .65073 L .47155 .65001 L F
.46998 .65183 m .46806 .65268 L .46914 .65073 L F
.777 .398 .339 r
.57824 .66508 m .57453 .66593 L .57477 .66461 L F
.57824 .66508 m .57716 .66679 L .57453 .66593 L F
.657 .253 .267 r
.57824 .66508 m .5806 .66691 L .57716 .66679 L F
.445 .34 .642 r
.58043 .6643 m .5806 .66691 L .57824 .66508 L F
.58043 .6643 m .5806 .66691 L .57824 .66508 L F
.22 .097 .491 r
.6081 .58307 m .60938 .58212 L .60938 .57984 L F
.141 0 .37 r
.6081 .58307 m .60787 .58522 L .60938 .58212 L F
.866 .808 .791 r
.67888 .50648 m .67557 .50823 L .67871 .50637 L F
.67888 .50648 m .67697 .50956 L .67557 .50823 L F
.214 .299 .736 r
.67816 .50319 m .67888 .50648 L .67955 .5041 L F
.797 .854 .402 r
.67888 .50648 m .67871 .50637 L .67955 .5041 L F
.97 .895 .694 r
.63236 .53712 m .63158 .53862 L .63258 .5393 L F
1 .814 .504 r
.63158 .53862 m .63204 .54309 L .63258 .5393 L F
.121 .642 .885 r
.35321 .58828 m .3525 .58862 L .35095 .58835 L F
.35321 .58828 m .35465 .58878 L .3525 .58862 L F
.428 .658 .956 r
.43195 .69737 m .43414 .69741 L .43285 .69828 L F
.381 .554 .9 r
.43414 .69741 m .4351 .69936 L .43285 .69828 L F
.799 .636 .68 r
.69054 .51512 m .6932 .51555 L .69193 .51211 L F
.79 .63 .683 r
.69054 .51512 m .69327 .51777 L .6932 .51555 L F
.794 .757 .819 r
.67367 .52545 m .67678 .52619 L .67609 .52265 L F
.804 .745 .798 r
.67367 .52545 m .67487 .52791 L .67678 .52619 L F
.768 .741 .828 r
.67609 .52265 m .67678 .52619 L .67946 .52306 L F
.46 .198 .43 r
.3782 .61869 m .37654 .61717 L .37844 .61649 L F
.3782 .61869 m .37603 .61921 L .37654 .61717 L F
0 0 0 r
.33259 .64574 m .33248 .64531 L .33458 .64476 L F
.33259 .64574 m .3306 .64638 L .33248 .64531 L F
.787 .822 .879 r
.70762 .46334 m .70414 .46301 L .70822 .46107 L F
.70762 .46334 m .70542 .46426 L .70414 .46301 L F
0 .335 .665 r
.70822 .46107 m .71251 .46273 L .70762 .46334 L F
.705 .853 .953 r
.48998 .62366 m .48596 .62394 L .48861 .6227 L F
.607 .85 .99 r
.49193 .62289 m .48998 .62366 L .48861 .6227 L F
.664 .153 .018 r
.5011 .6414 m .49793 .64088 L .49897 .63993 L F
.988 .882 .544 r
.61271 .56843 m .6129 .56417 L .61361 .56638 L F
.26 .667 .966 r
.32571 .585 m .32718 .58569 L .32703 .58645 L F
.368 .609 .942 r
.53993 .75851 m .54312 .7593 L .54235 .75807 L F
.079 0 0 r
.52526 .64918 m .52332 .64941 L .52309 .64935 L F
.23 0 0 r
.52726 .64796 m .52332 .64941 L .52526 .64918 L F
.5244 .64901 m .52568 .64908 L .52332 .64941 L F
.52726 .64796 m .52568 .64908 L .5244 .64901 L F
.85 .51 .41 r
.52922 .64972 m .52635 .64912 L .52568 .64908 L F
.52635 .64912 m .52479 .6488 L .52568 .64908 L F
.508 .811 1 r
.52332 .64941 m .52568 .64908 L .52436 .64834 L F
0 0 .095 r
.52436 .64834 m .52385 .64954 L .52332 .64941 L F
.52385 .64954 m .52301 .6515 L .52332 .64941 L F
.079 0 0 r
.52309 .64935 m .52332 .64941 L .52279 .64938 L F
.763 .539 .594 r
.64019 .50101 m .63636 .50257 L .63633 .50063 L F
.64019 .50101 m .63988 .50334 L .63636 .50257 L F
.666 .269 .284 r
.48904 .69819 m .49285 .69827 L .49061 .6964 L F
.664 .905 .979 r
.50787 .81282 m .5083 .8111 L .50599 .81196 L F
.50787 .81282 m .50965 .81173 L .5083 .8111 L F
.57 .931 .936 r
.51089 .69766 m .50894 .69859 L .51009 .69743 L F
.572 .934 .792 r
.50894 .69859 m .50827 .69871 L .51009 .69743 L F
.427 .174 .425 r
.47672 .7944 m .47937 .79411 L .47921 .79203 L F
.71 .715 .852 r
.47716 .7974 m .47937 .79411 L .47672 .7944 L F
.395 .173 .455 r
.26369 .59996 m .2633 .60216 L .26556 .59932 L F
.665 .969 .91 r
.46913 .63687 m .46998 .63547 L .47081 .63564 L F
.623 .566 .769 r
.57459 .64796 m .57374 .64458 L .57335 .64709 L F
.57459 .64796 m .57624 .64459 L .57374 .64458 L F
.57459 .64796 m .57709 .64812 L .57624 .64459 L F
.717 .434 .496 r
.57783 .65772 m .57352 .65881 L .57386 .65635 L F
.57783 .65772 m .57583 .6594 L .57352 .65881 L F
.95 .951 .726 r
.57783 .65772 m .57352 .65881 L .57583 .6594 L F
.5752 .65839 m .57465 .65996 L .57352 .65881 L F
.57607 .65817 m .57548 .65891 L .5752 .65839 L F
.57548 .65891 m .57465 .65996 L .5752 .65839 L F
.57579 .65914 m .57465 .65996 L .57607 .65817 L F
.57603 .65899 m .57465 .65996 L .57774 .65775 L F
.915 .836 .752 r
.57783 .65772 m .57526 .66218 L .57583 .6594 L F
.781 .319 0 r
.57573 .65937 m .57597 .65983 L .57583 .6594 L F
.57573 .65937 m .57583 .6594 L .57579 .65917 L F
.928 .894 .775 r
.57579 .65917 m .57583 .6594 L .57603 .65899 L F
.924 .886 .777 r
.57603 .65899 m .57583 .6594 L .57783 .65772 L F
.769 .26 0 r
.57583 .6594 m .57616 .65972 L .57783 .65772 L F
.95 .951 .726 r
.57616 .65972 m .57526 .66218 L .57515 .66093 L F
.57783 .65772 m .57664 .65979 L .57616 .65972 L F
.57664 .65979 m .57526 .66218 L .57616 .65972 L F
.769 .26 0 r
.57616 .65972 m .57647 .66134 L .57857 .66205 L F
.57583 .6594 m .57592 .65969 L .57616 .65972 L F
.95 .951 .726 r
.57588 .65966 m .57515 .66093 L .57511 .66042 L F
.57783 .65772 m .57609 .6598 L .57588 .65966 L F
.57609 .6598 m .57515 .66093 L .57588 .65966 L F
.57566 .65925 m .57511 .66042 L .57465 .65996 L F
.57783 .65772 m .57588 .65966 L .57566 .65925 L F
.57588 .65966 m .57511 .66042 L .57566 .65925 L F
.781 .319 0 r
.57496 .65915 m .57597 .65983 L .57588 .65966 L F
.57524 .65923 m .57588 .65966 L .57573 .65937 L F
.57496 .65915 m .57588 .65966 L .57524 .65923 L F
.769 .26 0 r
.57592 .65969 m .57647 .66134 L .57616 .65972 L F
.57616 .65972 m .57857 .66205 L .57783 .65772 L F
.781 .319 0 r
.57496 .65915 m .57647 .66134 L .57597 .65983 L F
.57496 .65915 m .57573 .65937 L .57534 .65668 L F
.57573 .65937 m .57579 .65917 L .57534 .65668 L F
.95 .951 .726 r
.57774 .65775 m .57579 .65914 L .57607 .65817 L F
.57783 .65772 m .57603 .65899 L .57774 .65775 L F
.928 .894 .775 r
.57534 .65668 m .57579 .65917 L .57771 .65555 L F
.57579 .65917 m .57603 .65899 L .57771 .65555 L F
.924 .886 .777 r
.57771 .65555 m .57603 .65899 L .57783 .65772 L F
.57771 .65555 m .57783 .65772 L .57975 .65683 L F
.339 0 .187 r
.54479 .68746 m .54402 .68958 L .5418 .69009 L F
.434 .869 .781 r
.54479 .68746 m .5448 .68734 L .54632 .6865 L F
.255 0 .153 r
.54606 .6888 m .54479 .68746 L .54632 .6865 L F
.54606 .6888 m .54402 .68958 L .54479 .68746 L F
.57 .31 .483 r
.48946 .78378 m .49186 .78352 L .49342 .78181 L F
.217 .129 .536 r
.48946 .78378 m .49066 .78639 L .49186 .78352 L F
.48946 .78378 m .48951 .78628 L .49066 .78639 L F
.202 .082 .483 r
.4275 .68093 m .42593 .6842 L .42585 .68188 L F
.08 0 .005 r
.24843 .64399 m .24646 .64553 L .24865 .64454 L F
.267 .031 .358 r
.24646 .64553 m .24642 .64739 L .24865 .64454 L F
.488 .524 .82 r
.4268 .69204 m .42602 .69503 L .42484 .69225 L F
.4268 .69204 m .42807 .69515 L .42602 .69503 L F
.141 0 0 r
.32104 .64854 m .32424 .64783 L .32273 .64867 L F
.18 0 0 r
.32424 .64783 m .3245 .64852 L .32273 .64867 L F
.32424 .64783 m .32649 .64758 L .3245 .64852 L F
.17 .708 .804 r
.51874 .64124 m .52273 .64094 L .52019 .64126 L F
.934 .894 .766 r
.72929 .50869 m .72844 .51277 L .72698 .5116 L F
.357 0 .125 r
.27821 .5909 m .28038 .59046 L .28175 .58849 L F
.324 0 .063 r
.28038 .59046 m .28398 .58819 L .28175 .58849 L F
.463 .831 .992 r
.30529 .58354 m .30947 .5838 L .30717 .584 L F
.363 .09 .358 r
.38379 .61102 m .38324 .61359 L .3812 .61376 L F
.452 .167 .389 r
.38543 .61301 m .38379 .61102 L .38573 .61044 L F
.38543 .61301 m .38324 .61359 L .38379 .61102 L F
.765 .595 .668 r
.58934 .70377 m .59287 .70679 L .59262 .70449 L F
.662 .42 .544 r
.58207 .60241 m .58415 .59981 L .58213 .59981 L F
.58207 .60241 m .58444 .60201 L .58415 .59981 L F
.695 .294 .283 r
.58692 .60155 m .58415 .59981 L .58444 .60201 L F
.755 .546 .613 r
.47854 .65351 m .47918 .65688 L .4766 .65626 L F
.47854 .65351 m .47918 .65688 L .4766 .65626 L F
.419 .321 .637 r
.47854 .65351 m .47918 .65688 L .48072 .65593 L F
.48058 .65552 m .48072 .65593 L .48089 .65583 L F
.47854 .65351 m .48072 .65593 L .48058 .65552 L F
.667 .46 .594 r
.48074 .65067 m .47955 .65249 L .48313 .65346 L F
.419 .321 .637 r
.47854 .65351 m .48058 .65552 L .478 .65486 L F
.48058 .65552 m .48089 .65583 L .478 .65486 L F
.667 .46 .594 r
.47955 .65249 m .478 .65486 L .48015 .65427 L F
.47955 .65249 m .48015 .65427 L .48313 .65346 L F
0 0 .004 r
.47854 .65351 m .478 .65486 L .48074 .65067 L F
.571 .805 .987 r
.35701 .6018 m .35854 .60293 L .36068 .60235 L F
.763 .562 .625 r
.61448 .55143 m .61293 .55423 L .61277 .5517 L F
.512 .71 .961 r
.31761 .62789 m .31738 .63012 L .3155 .62824 L F
.31761 .62789 m .31954 .62976 L .31738 .63012 L F
.554 .657 .904 r
.32048 .63135 m .31738 .63012 L .31954 .62976 L F
.576 .46 .685 r
.62028 .50666 m .62276 .50616 L .62221 .5035 L F
.508 .246 .452 r
.62028 .50666 m .62248 .50821 L .62276 .50616 L F
.62028 .50666 m .62007 .50874 L .62248 .50821 L F
.512 .23 .422 r
.41735 .65889 m .41968 .65838 L .42023 .65624 L F
.473 .193 .408 r
.42023 .65624 m .42167 .6584 L .42293 .65636 L F
.42023 .65624 m .41968 .65838 L .42167 .6584 L F
.916 .543 .302 r
.56145 .65298 m .55932 .65027 L .56125 .65071 L F
.744 .397 0 r
.65067 .49794 m .65106 .49945 L .65168 .50024 L F
.36 .564 .914 r
.32125 .62985 m .32048 .63135 L .31954 .62976 L F
.484 .716 .973 r
.32125 .62985 m .32239 .63118 L .32048 .63135 L F
.773 .713 .795 r
.69691 .50644 m .70013 .50687 L .69905 .50402 L F
.738 .722 .837 r
.70013 .50687 m .70126 .50298 L .69905 .50402 L F
.70013 .50687 m .70238 .50591 L .70126 .50298 L F
.353 0 0 r
.67214 .47441 m .67428 .4751 L .6751 .4751 L F
.015 0 0 r
.6751 .4751 m .6769 .47465 L .67749 .47378 L F
.368 0 .03 r
.67428 .4751 m .6769 .47465 L .6751 .4751 L F
.062 0 .201 r
.60275 .53447 m .60446 .53354 L .60483 .53155 L F
.591 .434 .638 r
.60234 .53655 m .60446 .53354 L .60275 .53447 L F
.591 .464 .676 r
.44519 .67624 m .44778 .67648 L .44712 .67366 L F
.44712 .67366 m .44778 .67648 L .44519 .67624 L F
.472 .327 .602 r
.61126 .52025 m .61336 .51677 L .61083 .51735 L F
.637 .306 .394 r
.64157 .48557 m .64472 .48591 L .64185 .48389 L F
.509 .374 .633 r
.47435 .80879 m .47598 .80891 L .47654 .80607 L F
.029 .184 .691 r
.47435 .80879 m .47648 .8112 L .47598 .80891 L F
.47435 .80879 m .47587 .81224 L .47648 .8112 L F
.836 .746 .764 r
.63868 .51402 m .64251 .5125 L .64146 .51156 L F
.63868 .51402 m .64057 .51557 L .64251 .5125 L F
.978 .681 .318 r
.64108 .50904 m .64133 .5107 L .64186 .51093 L F
.903 .862 .79 r
.64043 .51031 m .64335 .50887 L .64223 .50872 L F
.64024 .51048 m .6405 .51034 L .64043 .51031 L F
.6405 .51034 m .64335 .50887 L .64043 .51031 L F
.978 .681 .318 r
.64186 .51093 m .64146 .51156 L .64251 .5125 L F
.64133 .5107 m .64146 .51156 L .64186 .51093 L F
.094 0 0 r
.71479 .46753 m .71151 .46823 L .71142 .46943 L F
.531 .317 .534 r
.57403 .60544 m .57626 .60503 L .5764 .60274 L F
.664 .486 .635 r
.57626 .60503 m .57859 .60211 L .5764 .60274 L F
.782 .493 0 r
.52927 .61403 m .52891 .61334 L .5283 .61057 L F
0 .024 .591 r
.52927 .61403 m .53055 .615 L .52891 .61334 L F
.52927 .61403 m .53094 .6161 L .53055 .615 L F
.563 .836 .996 r
.50138 .64755 m .49777 .64742 L .50074 .64533 L F
.217 0 .238 r
.50275 .64764 m .50033 .64999 L .50138 .64755 L F
.564 .619 .865 r
.70837 .50537 m .70956 .50215 L .70711 .50298 L F
.70837 .50537 m .71089 .50494 L .70956 .50215 L F
.537 .637 .896 r
.70837 .50537 m .71151 .5068 L .71089 .50494 L F
.522 .501 .775 r
.48085 .81042 m .48417 .80824 L .48166 .80843 L F
.234 .678 .955 r
.4828 .81079 m .48341 .8109 L .48518 .81125 L F
.48085 .81042 m .48319 .81086 L .4828 .81079 L F
.48319 .81086 m .48341 .8109 L .4828 .81079 L F
.602 .56 .779 r
.48275 .81397 m .48071 .81478 L .47954 .81127 L F
.76 .872 .929 r
.48341 .8109 m .48854 .8087 L .48729 .80781 L F
.48341 .8109 m .48729 .80781 L .48518 .81125 L F
.522 .501 .775 r
.48085 .81042 m .48518 .81125 L .48417 .80824 L F
.602 .56 .779 r
.48221 .81068 m .48116 .81048 L .4821 .81002 L F
.48275 .81397 m .48116 .81048 L .48221 .81068 L F
.48275 .81397 m .47954 .81127 L .48116 .81048 L F
.993 .758 .468 r
.48169 .81363 m .48275 .81397 L .48221 .8107 L F
.48203 .81067 m .48221 .8107 L .4821 .81002 L F
.48169 .81363 m .48221 .8107 L .48203 .81067 L F
.522 .501 .775 r
.48085 .81042 m .48166 .80843 L .4821 .81002 L F
.288 .739 .958 r
.48038 .81042 m .48085 .81042 L .4821 .81002 L F
.48038 .81042 m .4821 .81002 L .47954 .81127 L F
.218 .645 .954 r
.48024 .79135 m .48246 .79252 L .47921 .79203 L F
.661 .343 .425 r
.47921 .79203 m .48182 .79376 L .48024 .79135 L F
.47921 .79203 m .47937 .79411 L .48182 .79376 L F
0 0 .003 r
.62588 .57641 m .62521 .57862 L .62402 .57994 L F
0 0 .271 r
.62514 .58036 m .62402 .57994 L .62521 .57862 L F
.62514 .58036 m .62426 .58209 L .62402 .57994 L F
.711 .707 .844 r
.67144 .52635 m .67487 .52791 L .67367 .52545 L F
.303 0 0 r
.47434 .70111 m .4732 .70151 L .47097 .70139 L F
.227 0 0 r
.47675 .70106 m .4732 .70151 L .47434 .70111 L F
0 0 0 r
.5385 .79975 m .53745 .80117 L .53952 .79781 L F
.111 0 0 r
.5385 .79975 m .53952 .79781 L .54156 .79677 L F
0 0 0 r
.50929 .80626 m .50651 .80822 L .50823 .80859 L F
.779 .609 .669 r
.50823 .80859 m .51198 .80623 L .50929 .80626 L F
.182 .669 .924 r
.4813 .69576 m .4835 .69588 L .4848 .69651 L F
0 .151 .647 r
.48622 .69732 m .4848 .69651 L .4835 .69588 L F
.48622 .69732 m .48755 .69864 L .4848 .69651 L F
.848 .96 .88 r
.53219 .60263 m .52862 .60457 L .53123 .60209 L F
.84 .968 .883 r
.53219 .60263 m .53346 .59993 L .53461 .60059 L F
.53219 .60263 m .53123 .60209 L .53346 .59993 L F
.783 .932 .93 r
.69936 .46664 m .70127 .46326 L .70233 .46431 L F
.69936 .46664 m .69841 .46543 L .70127 .46326 L F
.396 .619 .941 r
.38102 .59355 m .38028 .59512 L .37892 .59373 L F
.38102 .59355 m .38307 .59577 L .38028 .59512 L F
.426 0 0 r
.31958 .60214 m .31662 .60228 L .31811 .6022 L F
.266 .697 .965 r
.30703 .65017 m .30757 .64944 L .30558 .64745 L F
.30703 .65017 m .30908 .65024 L .30757 .64944 L F
.355 .149 .457 r
.30179 .61389 m .30135 .61669 L .29977 .61677 L F
.378 .327 .674 r
.30135 .61669 m .30174 .61861 L .29977 .61677 L F
.407 .329 .657 r
.29977 .61677 m .30174 .61861 L .30011 .61893 L F
.446 .077 .243 r
.35808 .63298 m .35498 .63537 L .35612 .63336 L F
.336 .074 .361 r
.62737 .4983 m .62912 .49885 L .62975 .49776 L F
.62737 .4983 m .62701 .50014 L .62912 .49885 L F
.307 .066 .375 r
.67901 .4924 m .68023 .49211 L .68129 .48953 L F
.44 .654 .95 r
.67901 .4924 m .6819 .4926 L .68023 .49211 L F
.594 .024 0 r
.53599 .61959 m .5345 .61903 L .53206 .6172 L F
0 .016 .53 r
.53599 .61959 m .53709 .62061 L .5345 .61903 L F
.812 .328 0 r
.53799 .62163 m .53789 .62284 L .53709 .62061 L F
.868 .656 .125 r
.53789 .62284 m .53765 .62111 L .53709 .62061 L F
.53765 .62111 m .5374 .61937 L .53709 .62061 L F
0 .016 .53 r
.53599 .61959 m .53615 .61976 L .53709 .62061 L F
.53615 .61976 m .53799 .62163 L .53709 .62061 L F
.322 0 0 r
.3191 .5843 m .32077 .58488 L .32259 .58526 L F
.077 .623 .84 r
.32077 .58488 m .32433 .58535 L .32259 .58526 L F
.98 .914 .615 r
.62976 .56568 m .62825 .56705 L .6279 .56874 L F
.62976 .56568 m .62915 .56495 L .62825 .56705 L F
0 0 0 r
.44503 .69716 m .4491 .69649 L .44676 .69672 L F
.889 .897 .828 r
.53515 .80389 m .53745 .80117 L .53578 .8011 L F
.628 .935 .964 r
.53578 .8011 m .53745 .80117 L .5385 .79975 L F
.154 0 0 r
.34205 .6267 m .34484 .62505 L .3427 .62559 L F
.608 .716 .921 r
.48973 .80261 m .49258 .80205 L .49065 .7995 L F
.251 0 0 r
.49427 .80219 m .49304 .80196 L .49289 .80212 L F
0 0 .098 r
.49225 .80328 m .49257 .8021 L .49427 .80219 L F
.402 .455 .801 r
.49295 .80562 m .48973 .80261 L .49225 .80328 L F
.365 .343 .702 r
.49517 .80518 m .49225 .80328 L .49427 .80219 L F
.49517 .80518 m .49295 .80562 L .49225 .80328 L F
.251 0 0 r
.49427 .80219 m .49289 .80212 L .49103 .80416 L F
0 0 .098 r
.49257 .8021 m .49258 .80206 L .49427 .80219 L F
.49288 .80179 m .4931 .80008 L .49368 .80111 L F
.49266 .80173 m .4931 .80008 L .49288 .80179 L F
.815 .366 .172 r
.49427 .80219 m .49288 .80179 L .49304 .80196 L F
.608 .716 .921 r
.49259 .80204 m .49304 .80196 L .49288 .80179 L F
0 0 .098 r
.49258 .80206 m .49368 .80111 L .49427 .80219 L F
.49258 .80206 m .49275 .8005 L .4931 .80008 L F
.4924 .80248 m .49254 .80168 L .49258 .80206 L F
.49254 .80168 m .49275 .8005 L .49258 .80203 L F
.49254 .80168 m .49258 .80203 L .49258 .80206 L F
.49225 .80328 m .4924 .80248 L .49258 .80206 L F
.346 0 .056 r
.49103 .80416 m .49263 .80241 L .48973 .80261 L F
.49263 .80241 m .49304 .80196 L .49258 .80205 L F
.49263 .80241 m .49258 .80205 L .48973 .80261 L F
.815 .366 .172 r
.49427 .80219 m .49065 .7995 L .49288 .80179 L F
0 0 .098 r
.49258 .80206 m .49266 .80173 L .49288 .80179 L F
.608 .716 .921 r
.49258 .80205 m .49259 .80204 L .49275 .80166 L F
.49259 .80204 m .49288 .80179 L .49275 .80166 L F
.49258 .80205 m .49275 .80166 L .49065 .7995 L F
.902 .838 .378 r
.62825 .56705 m .6278 .57102 L .6279 .56874 L F
.381 0 .066 r
.28614 .5878 m .28842 .58754 L .2899 .58579 L F
.275 0 0 r
.28842 .58754 m .29208 .58554 L .2899 .58579 L F
.77 .973 .92 r
.484 .62539 m .48133 .62744 L .48021 .62705 L F
.677 .458 .582 r
.57859 .60211 m .58207 .60241 L .58213 .59981 L F
.47 .448 .751 r
.55 .76598 m .55312 .76908 L .55177 .76681 L F
.55 .76598 m .55162 .77002 L .55312 .76908 L F
.322 0 0 r
.45945 .70242 m .45812 .70375 L .45588 .70392 L F
.388 0 0 r
.46168 .70285 m .45812 .70375 L .45945 .70242 L F
.221 .645 .955 r
.36821 .58994 m .36775 .59073 L .36633 .5897 L F
.36821 .58994 m .36966 .5909 L .36775 .59073 L F
.933 .948 .774 r
.73573 .48143 m .73275 .48431 L .73456 .4799 L F
.73573 .48143 m .73362 .48467 L .73275 .48431 L F
.833 .782 .803 r
.73795 .47844 m .73573 .48143 L .73456 .4799 L F
.312 0 0 r
.45139 .70398 m .44997 .70524 L .44792 .70491 L F
.39 0 0 r
.45362 .70421 m .44997 .70524 L .45139 .70398 L F
.697 .774 .911 r
.65403 .51271 m .65768 .513 L .65614 .51154 L F
.453 .65 .944 r
.65614 .51154 m .65768 .513 L .65793 .51274 L F
.47 .752 .991 r
.50587 .625 m .50492 .62664 L .5033 .6248 L F
.50587 .625 m .50751 .62626 L .50492 .62664 L F
.556 .123 .174 r
.32836 .60005 m .32685 .60178 L .32447 .60148 L F
.354 0 .058 r
.33032 .59974 m .32685 .60178 L .32836 .60005 L F
.419 .129 .362 r
.59428 .61337 m .59304 .61596 L .59102 .61585 L F
.593 .392 .579 r
.59304 .61596 m .59046 .61871 L .59102 .61585 L F
.278 0 0 r
.4491 .69649 m .451 .69692 L .45247 .69644 L F
.627 .152 .106 r
.451 .69692 m .45473 .69635 L .45247 .69644 L F
.852 .732 .731 r
.5793 .64655 m .58052 .648 L .57973 .64502 L F
.291 0 0 r
.47496 .65074 m .47371 .6506 L .47155 .65001 L F
.501 .593 .878 r
.71089 .50494 m .71151 .5068 L .71311 .50473 L F
.519 .619 .891 r
.71151 .5068 m .71363 .50661 L .71311 .50473 L F
.9 .852 .786 r
.49342 .78181 m .49186 .78352 L .49312 .78135 L F
.404 .493 .837 r
.40797 .6987 m .40947 .70182 L .41123 .70048 L F
.406 .496 .839 r
.40947 .70182 m .41192 .70291 L .41123 .70048 L F
.481 .26 .501 r
.58281 .5517 m .58511 .55118 L .58517 .54891 L F
.482 .264 .506 r
.58511 .55118 m .58749 .54833 L .58517 .54891 L F
.632 .612 .812 r
.76624 .59474 m .76968 .59712 L .76854 .59381 L F
.748 .666 .77 r
.76854 .59381 m .76968 .59712 L .77243 .59491 L F
.518 .314 .543 r
.60127 .61006 m .60147 .61308 L .59897 .61333 L F
.552 .332 .535 r
.60412 .60807 m .60414 .60903 L .60127 .61006 L F
.526 .306 .523 r
.60414 .60903 m .60147 .61308 L .60127 .61006 L F
.425 0 0 r
.5294 .74893 m .53009 .74941 L .52739 .74777 L F
.71 .715 .852 r
.47716 .7974 m .47892 .79642 L .47937 .79411 L F
.311 .118 .45 r
.47718 .7994 m .47892 .79642 L .47716 .7974 L F
.708 .768 .899 r
.57471 .72091 m .57554 .72117 L .57766 .7204 L F
.278 0 .162 r
.62221 .5035 m .62419 .50285 L .62514 .50114 L F
.115 0 .07 r
.62514 .50114 m .62419 .50285 L .62701 .50014 L F
.853 .396 .042 r
.48059 .77406 m .48328 .77714 L .48203 .77493 L F
.82 .736 .772 r
.68895 .51155 m .69193 .51211 L .691 .50875 L F
.857 .712 .701 r
.68862 .51388 m .69193 .51211 L .68895 .51155 L F
.68862 .51388 m .69054 .51512 L .69193 .51211 L F
.746 .695 .803 r
.691 .50875 m .69193 .51211 L .69456 .50941 L F
.68 .713 .873 r
.68879 .52552 m .69221 .52619 L .69134 .5231 L F
.797 .748 .807 r
.69134 .5231 m .69221 .52619 L .69456 .52337 L F
.326 .056 .342 r
.5496 .77339 m .55093 .77207 L .55162 .77002 L F
.165 0 .263 r
.55162 .77002 m .55093 .77207 L .55312 .76908 L F
0 0 0 r
.44497 .66516 m .4418 .66704 L .44272 .66484 L F
.468 .248 .497 r
.60681 .52623 m .60904 .5256 L .60929 .52345 L F
.532 .364 .599 r
.60681 .52855 m .60904 .5256 L .60681 .52623 L F
.254 0 0 r
.53538 .68935 m .53833 .69026 L .53957 .69056 L F
.479 .204 .418 r
.53957 .69056 m .53923 .69261 L .53694 .69305 L F
0 0 .138 r
.53957 .69056 m .54063 .68963 L .54117 .68714 L F
.342 0 0 r
.53833 .69026 m .54063 .68963 L .53957 .69056 L F
.242 .006 .342 r
.54101 .69126 m .53957 .69056 L .5418 .69009 L F
.54101 .69126 m .53923 .69261 L .53957 .69056 L F
.252 0 0 r
.51559 .6943 m .51813 .69429 L .51955 .69315 L F
.274 0 0 r
.51813 .69429 m .52156 .69231 L .51955 .69315 L F
.981 .848 .637 r
.63317 .52839 m .63239 .53056 L .6336 .53089 L F
.98 .855 .47 r
.63234 .53164 m .6336 .53089 L .63239 .53056 L F
.63234 .53164 m .63299 .53478 L .6336 .53089 L F
.658 .679 .859 r
.70126 .50298 m .70238 .50591 L .70508 .50419 L F
.829 .902 .891 r
.27671 .64606 m .27291 .64791 L .27583 .64449 L F
.309 .453 .843 r
.27716 .64524 m .27671 .64606 L .27583 .64449 L F
.27716 .64524 m .27913 .64765 L .27671 .64606 L F
.451 .181 .412 r
.37341 .62174 m .37129 .62224 L .37389 .61972 L F
.418 .151 .4 r
.37546 .62117 m .37389 .61972 L .37603 .61921 L F
.37546 .62117 m .37341 .62174 L .37389 .61972 L F
.79 .63 .683 r
.69054 .51512 m .68981 .51726 L .69327 .51777 L F
.784 .619 .676 r
.68981 .51983 m .69327 .51777 L .68981 .51726 L F
.68981 .51983 m .69294 .52037 L .69327 .51777 L F
.774 .61 .676 r
.69294 .52037 m .69452 .52117 L .69327 .51777 L F
.454 .484 .8 r
.40348 .69009 m .40457 .69325 L .4065 .69228 L F
.317 .269 .645 r
.40522 .69561 m .4065 .69228 L .40457 .69325 L F
0 .238 .736 r
.53206 .6172 m .53352 .61774 L .53094 .6161 L F
.53206 .6172 m .5345 .61903 L .53352 .61774 L F
.194 .177 .61 r
.47592 .80342 m .47763 .80635 L .47652 .80259 L F
.47592 .80342 m .47654 .80607 L .47763 .80635 L F
.566 .388 .6 r
.58335 .6197 m .5835 .62251 L .58084 .62286 L F
.597 .456 .661 r
.5835 .62251 m .58112 .6253 L .58084 .62286 L F
.818 .617 .631 r
.69294 .52037 m .69456 .52337 L .69452 .52117 L F
.624 .768 .949 r
.71756 .50864 m .72094 .5093 L .71955 .50805 L F
.827 .802 .828 r
.71955 .50805 m .72094 .5093 L .72336 .50649 L F
0 0 .115 r
.68017 .4787 m .67886 .47826 L .68113 .47701 L F
.68017 .4787 m .67864 .4801 L .67886 .47826 L F
.584 .347 .522 r
.68129 .48953 m .68023 .49211 L .68276 .49048 L F
.292 .77 .669 r
.33666 .64412 m .34061 .64248 L .33881 .64368 L F
0 0 0 r
.33881 .64368 m .34061 .64248 L .34252 .64161 L F
.961 .809 .647 r
.73278 .50057 m .73068 .50255 L .73199 .49936 L F
.73278 .50057 m .73186 .50378 L .73068 .50255 L F
.603 .321 .462 r
.5962 .61563 m .59428 .61337 L .59608 .6142 L F
.5962 .61563 m .59304 .61596 L .59428 .61337 L F
0 .22 .742 r
.53895 .62514 m .54068 .62809 L .54083 .62696 L F
.9 .738 .672 r
.65449 .48341 m .6528 .48681 L .65341 .48372 L F
.664 .627 .802 r
.68269 .52398 m .68644 .5264 L .68534 .52324 L F
.692 .673 .827 r
.68534 .52324 m .68644 .5264 L .68879 .52552 L F
.982 .909 .641 r
.26854 .63658 m .2668 .63823 L .26783 .6359 L F
.674 .62 .787 r
.26836 .63628 m .26854 .63658 L .26783 .6359 L F
.26836 .63628 m .2668 .63823 L .26854 .63658 L F
.667 .495 .643 r
.57128 .60806 m .57446 .60785 L .57403 .60544 L F
.417 .248 .542 r
.57446 .60785 m .57626 .60503 L .57403 .60544 L F
0 .364 .832 r
.42602 .71037 m .42638 .70955 L .42486 .71026 L F
.441 0 .054 r
.42838 .71033 m .42924 .7117 L .42602 .71037 L F
0 .364 .832 r
.42602 .71037 m .42924 .7117 L .42638 .70955 L F
.358 0 0 r
.52928 .69657 m .52763 .69814 L .52541 .69833 L F
.36 0 0 r
.5311 .69731 m .52928 .69657 L .53144 .69584 L F
.5311 .69731 m .52763 .69814 L .52928 .69657 L F
.942 .834 .708 r
.73356 .4866 m .73327 .4864 L .73362 .48467 L F
.503 .295 .53 r
.24489 .67019 m .24643 .66765 L .24552 .66768 L F
.863 .629 .583 r
.56228 .75488 m .56235 .75228 L .56041 .75202 L F
.678 .489 .622 r
.57471 .65336 m .57684 .65367 L .57563 .65157 L F
.917 .81 .725 r
.57494 .65085 m .57471 .65336 L .57563 .65157 L F
.53 .341 .57 r
.50317 .76665 m .5054 .76875 L .50543 .76627 L F
.411 .473 .814 r
.72985 .47407 m .72811 .47558 L .7267 .47273 L F
.403 .323 .652 r
.7313 .47698 m .72811 .47558 L .72985 .47407 L F
.7313 .47698 m .72856 .47797 L .72811 .47558 L F
.318 .608 .951 r
.41893 .70907 m .42004 .71047 L .42081 .70921 L F
.347 .645 .966 r
.42004 .71047 m .4222 .71082 L .42081 .70921 L F
.494 .209 .411 r
.3812 .61376 m .38079 .61626 L .37844 .61649 L F
.41 .138 .386 r
.38281 .61556 m .3812 .61376 L .38324 .61359 L F
.38281 .61556 m .38079 .61626 L .3812 .61376 L F
.748 .666 .77 r
.76854 .59381 m .77243 .59491 L .77076 .59301 L F
.671 .728 .892 r
.77076 .59301 m .77243 .59491 L .77435 .59367 L F
.77435 .59367 m .77243 .59491 L .77076 .59301 L F
.203 .43 .858 r
.58014 .64158 m .5791 .64222 L .57851 .63964 L F
.356 .278 .63 r
.5811 .64405 m .57973 .64502 L .5791 .64222 L F
.665 .226 .196 r
.57807 .64331 m .5811 .64405 L .5791 .64222 L F
.57807 .64331 m .5791 .64222 L .58014 .64158 L F
.476 .253 .496 r
.5805 .55471 m .58273 .5541 L .58281 .5517 L F
.472 .246 .49 r
.58273 .5541 m .58511 .55118 L .58281 .5517 L F
.833 .782 .803 r
.73795 .47844 m .73456 .4799 L .73683 .47726 L F
.707 .816 .933 r
.73833 .47643 m .73795 .47844 L .73683 .47726 L F
.73833 .47643 m .74052 .47769 L .73795 .47844 L F
.886 .602 .501 r
.56427 .65631 m .56145 .65298 L .56415 .65392 L F
.615 .492 .689 r
.56652 .65332 m .56427 .65631 L .56415 .65392 L F
.776 .846 .904 r
.27764 .64169 m .28144 .64097 L .27936 .63973 L F
.733 .991 .85 r
.28144 .64097 m .28165 .63972 L .27936 .63973 L F
.28144 .64097 m .28192 .64018 L .28165 .63972 L F
.408 .112 .347 r
.5925 .54287 m .59486 .54216 L .59515 .54043 L F
.571 .252 .389 r
.59486 .54216 m .59739 .54206 L .59515 .54043 L F
.53 .274 .472 r
.59515 .54043 m .59739 .54206 L .59756 .54001 L F
0 0 0 r
.51977 .70086 m .51813 .70104 L .52006 .70053 L F
.51977 .70086 m .51744 .70146 L .51813 .70104 L F
.576 .619 .858 r
.57023 .6059 m .56874 .60691 L .56799 .60584 L F
.57023 .6059 m .57128 .60806 L .56874 .60691 L F
0 0 0 r
.57128 .60806 m .5692 .61081 L .56874 .60691 L F
.665 .488 .636 r
.5692 .61081 m .57128 .60806 L .56874 .60691 L F
.533 .626 .89 r
.56799 .60584 m .57128 .60806 L .56874 .60691 L F
.846 .743 .75 r
.63868 .51402 m .63952 .51716 L .64057 .51557 L F
.283 0 .203 r
.26733 .59623 m .27017 .59375 L .2681 .59423 L F
.537 .366 .597 r
.60904 .5256 m .61115 .5227 L .60929 .52345 L F
.483 .266 .508 r
.40648 .66442 m .40886 .66153 L .40664 .66196 L F
.111 .661 .808 r
.54537 .63676 m .54442 .63663 L .54189 .63672 L F
.117 .455 .886 r
.54537 .63676 m .54647 .63603 L .54442 .63663 L F
.54537 .63676 m .54878 .63808 L .54647 .63603 L F
.803 .804 .852 r
.70542 .46426 m .70233 .46431 L .70414 .46301 L F
.907 .705 .619 r
.70609 .4745 m .70727 .47578 L .70625 .47206 L F
.633 .861 .491 r
.55878 .76891 m .55673 .77175 L .56034 .77249 L F
.64 .502 .679 r
.55772 .77495 m .56034 .77249 L .55673 .77175 L F
.438 .243 .517 r
.43233 .67799 m .43061 .67619 L .43208 .67549 L F
.43233 .67799 m .43033 .67876 L .43061 .67619 L F
.779 .5 0 r
.54925 .63927 m .54885 .63843 L .54878 .63808 L F
.273 .03 .351 r
.45843 .66122 m .45677 .66188 L .45886 .65925 L F
.45843 .66122 m .45677 .66188 L .45886 .65925 L F
.662 .627 .805 r
.45843 .66122 m .45801 .66359 L .45677 .66188 L F
.141 0 0 r
.32104 .64854 m .32273 .64867 L .32056 .64878 L F
.243 0 .125 r
.60317 .59341 m .60538 .59275 L .60554 .59102 L F
0 0 .063 r
.60554 .59102 m .60596 .59057 L .60686 .5872 L F
0 0 .002 r
.60554 .59102 m .60538 .59275 L .60596 .59057 L F
.59 .407 .602 r
.5857 .62177 m .58335 .6197 L .58577 .61938 L F
.5857 .62177 m .5835 .62251 L .58335 .6197 L F
.674 .769 .922 r
.7036 .49599 m .70007 .49538 L .70237 .49459 L F
.681 .788 .93 r
.70559 .49504 m .7036 .49599 L .70237 .49459 L F
.471 0 0 r
.33445 .59939 m .33246 .6005 L .33032 .59974 L F
.263 0 0 r
.33621 .59923 m .33246 .6005 L .33445 .59939 L F
.225 0 .254 r
.56292 .59671 m .56047 .59931 L .56124 .5979 L F
.453 .271 .542 r
.61543 .51212 m .61784 .51138 L .61767 .50907 L F
.503 .355 .612 r
.61558 .51449 m .61784 .51138 L .61543 .51212 L F
.241 0 0 r
.46542 .70206 m .46386 .70286 L .46168 .70285 L F
.508 .033 .063 r
.46767 .70169 m .46386 .70286 L .46542 .70206 L F
.949 .95 .648 r
.72721 .48577 m .72765 .48652 L .72992 .48129 L F
.358 .38 .747 r
.39499 .60185 m .39329 .60262 L .39318 .60222 L F
.39499 .60185 m .39539 .60387 L .39329 .60262 L F
.644 .452 .609 r
.39539 .60387 m .39305 .60735 L .39329 .60262 L F
.262 0 .136 r
.43033 .67876 m .4275 .68093 L .42828 .67955 L F
.851 .72 .718 r
.59287 .70679 m .59144 .7098 L .59399 .71007 L F
.843 .626 .609 r
.59144 .7098 m .59388 .71249 L .59399 .71007 L F
.507 .377 .637 r
.60483 .53155 m .60648 .5311 L .60681 .52855 L F
.391 .081 .316 r
.60446 .53354 m .60648 .5311 L .60483 .53155 L F
.766 .69 .779 r
.719 .49832 m .71634 .50107 L .7149 .49939 L F
.466 0 0 r
.29757 .7298 m .29982 .73021 L .30048 .72982 L F
.29757 .7298 m .29982 .73021 L .30048 .72982 L F
.528 .378 .621 r
.30259 .72754 m .29982 .73021 L .30048 .72982 L F
.29982 .73021 m .30259 .72754 L .30048 .72982 L F
.979 .726 .481 r
.50543 .76627 m .5054 .76875 L .50668 .76945 L F
.667 .46 .594 r
.48074 .65067 m .48313 .65346 L .48295 .6507 L F
.709 .749 .883 r
.66034 .47743 m .66155 .479 L .66377 .47798 L F
.419 .142 .383 r
.26193 .64803 m .26377 .64799 L .26509 .64733 L F
.26193 .64803 m .26161 .64993 L .26377 .64799 L F
.332 .082 .377 r
.49777 .64742 m .49614 .64886 L .49791 .64781 L F
.595 .318 .467 r
.49462 .64873 m .49791 .64781 L .49614 .64886 L F
.719 .749 .876 r
.6883 .49918 m .68956 .5007 L .68611 .5002 L F
.889 .897 .828 r
.53515 .80389 m .53373 .80036 L .53358 .80114 L F
.53515 .80389 m .53578 .8011 L .53373 .80036 L F
.295 .055 .369 r
.30405 .611 m .30342 .61325 L .30179 .61389 L F
.477 .295 .555 r
.30342 .61325 m .30135 .61669 L .30179 .61389 L F
.911 .954 .809 r
.71404 .48008 m .71678 .47804 L .7149 .48123 L F
.71404 .48008 m .71616 .47715 L .71678 .47804 L F
.812 .835 .867 r
.71835 .47425 m .71678 .47804 L .71616 .47715 L F
.71835 .47425 m .71969 .47573 L .71678 .47804 L F
.573 .384 .587 r
.51951 .7725 m .52198 .77229 L .52156 .76946 L F
.713 .541 .655 r
.52198 .77229 m .52397 .76928 L .52156 .76946 L F
.628 .289 .378 r
.57783 .6365 m .57413 .63847 L .57499 .63978 L F
.727 .384 .398 r
.58027 .63871 m .57879 .63949 L .57783 .6365 L F
.57879 .63949 m .57851 .63964 L .57845 .63936 L F
.57879 .63949 m .57845 .63936 L .57783 .6365 L F
.104 0 .439 r
.5786 .63912 m .57851 .63964 L .57866 .63934 L F
.57783 .6365 m .57845 .63936 L .5786 .63912 L F
.57845 .63936 m .57851 .63964 L .5786 .63912 L F
.628 .289 .378 r
.57783 .6365 m .5786 .63912 L .57413 .63847 L F
.594 .615 .843 r
.57438 .63779 m .57862 .63908 L .57543 .63495 L F
.628 .289 .378 r
.57783 .6365 m .57886 .63916 L .5786 .63912 L F
.594 .615 .843 r
.57862 .63908 m .57886 .63916 L .5787 .63896 L F
.727 .384 .398 r
.58027 .63871 m .57783 .6365 L .58034 .63616 L F
.104 0 .439 r
.57783 .6365 m .57954 .63765 L .57886 .63916 L F
.57952 .63764 m .57945 .63778 L .57954 .63765 L F
.57783 .6365 m .5786 .63912 L .57952 .63764 L F
.588 .613 .844 r
.57543 .63495 m .5787 .63896 L .57954 .63765 L F
.5787 .63896 m .57886 .63916 L .57954 .63765 L F
.104 0 .439 r
.57945 .63778 m .57866 .63934 L .57954 .63765 L F
.594 .615 .843 r
.5786 .63912 m .57886 .63916 L .57862 .63908 L F
.104 0 .439 r
.5786 .63912 m .57866 .63934 L .57952 .63764 L F
.594 .615 .843 r
.57737 .63894 m .5786 .63912 L .57438 .63779 L F
.5786 .63912 m .57862 .63908 L .57438 .63779 L F
.57862 .63908 m .5787 .63896 L .57543 .63495 L F
.57413 .63847 m .57737 .63894 L .57438 .63779 L F
.608 .456 .65 r
.57986 .63373 m .58034 .63616 L .57783 .6365 L F
.477 .847 .989 r
.45541 .68989 m .45846 .68937 L .45708 .6904 L F
.569 .312 .488 r
.45846 .68937 m .45541 .68989 L .45708 .6904 L F
.261 0 0 r
.45473 .69635 m .45661 .69675 L .4582 .69599 L F
.481 0 0 r
.45661 .69675 m .46046 .69573 L .4582 .69599 L F
.085 0 0 r
.31311 .64896 m .31468 .64847 L .31704 .64843 L F
.868 .834 .81 r
.69007 .49658 m .68979 .49328 L .69194 .49483 L F
.523 .815 .999 r
.69194 .49483 m .68979 .49328 L .69374 .49394 L F
.583 .845 .994 r
.47698 .81461 m .47854 .81548 L .48071 .81478 L F
.4 .432 .778 r
.56636 .59206 m .56505 .59385 L .56793 .59256 L F
.309 0 0 r
.57059 .59171 m .56636 .59206 L .56793 .59256 L F
.653 .862 .979 r
.27538 .64758 m .27724 .64864 L .27913 .64765 L F
.669 .556 .719 r
.58112 .6253 m .58151 .62778 L .57891 .62805 L F
.511 .329 .57 r
.58151 .62778 m .57938 .63038 L .57891 .62805 L F
.694 .669 .821 r
.24472 .6764 m .24526 .67603 L .24453 .67604 L F
.359 .065 .322 r
.54115 .79318 m .53832 .79431 L .53908 .79588 L F
.532 .534 .803 r
.53808 .79711 m .53908 .79588 L .53832 .79431 L F
.443 .331 .63 r
.26177 .60527 m .26356 .60466 L .2633 .60216 L F
.476 .383 .672 r
.26194 .60845 m .26356 .60466 L .26177 .60527 L F
.811 .969 .659 r
.57775 .58003 m .57965 .57729 L .5782 .57839 L F
.805 .947 .598 r
.57775 .58003 m .57629 .58138 L .57751 .58232 L F
.57775 .58003 m .5782 .57839 L .57629 .58138 L F
.985 .714 .421 r
.63016 .55638 m .63143 .55973 L .6313 .55731 L F
.437 .27 .555 r
.59885 .597 m .60078 .59627 L .60065 .59377 L F
.52 .347 .587 r
.59865 .59944 m .60078 .59627 L .59885 .597 L F
.541 .397 .634 r
.40254 .67276 m .40455 .66984 L .4026 .67039 L F
.534 .707 .951 r
.55017 .64499 m .55173 .64324 L .54964 .64168 L F
.55017 .64499 m .55236 .64467 L .55173 .64324 L F
.392 .12 .377 r
.63175 .49215 m .6339 .49153 L .63431 .48972 L F
.349 .082 .361 r
.63431 .48972 m .6339 .49153 L .63634 .48891 L F
.083 0 .157 r
.57476 .58951 m .57422 .58842 L .57605 .58837 L F
.57476 .58951 m .57314 .59093 L .57422 .58842 L F
.914 .826 .746 r
.64971 .49411 m .65269 .49213 L .65288 .48995 L F
.64971 .49411 m .65106 .49527 L .65269 .49213 L F
0 .129 .653 r
.65269 .49213 m .65384 .49273 L .65296 .49083 L F
.65269 .49213 m .65479 .49403 L .65384 .49273 L F
.566 .248 .389 r
.56118 .60467 m .56457 .60197 L .56141 .60277 L F
.56118 .60467 m .56357 .6047 L .56457 .60197 L F
.603 .551 .769 r
.56594 .5997 m .56703 .60218 L .56457 .60197 L F
.56594 .5997 m .56457 .60197 L .5655 .60128 L F
.094 0 .172 r
.56457 .60197 m .56529 .60338 L .5655 .60128 L F
.56457 .60197 m .56357 .6047 L .56529 .60338 L F
.927 .711 .59 r
.62969 .55029 m .63214 .54878 L .63132 .54798 L F
.62969 .55029 m .63211 .55115 L .63214 .54878 L F
.056 .622 .753 r
.45256 .66553 m .45457 .66561 L .45708 .6655 L F
.364 .008 .22 r
.37006 .62662 m .36888 .62494 L .37077 .62421 L F
.37006 .62662 m .36792 .62716 L .36888 .62494 L F
.705 .745 .883 r
.7149 .48123 m .71134 .48065 L .71404 .48008 L F
.287 .732 .962 r
.3581 .58932 m .35465 .58878 L .35679 .58864 L F
.4 .782 .991 r
.36019 .58903 m .3581 .58932 L .35679 .58864 L F
.886 .602 .501 r
.56427 .65631 m .56166 .65587 L .56145 .65298 L F
.81 .576 .585 r
.56427 .65631 m .56073 .65818 L .56166 .65587 L F
.56427 .65631 m .56412 .65873 L .56073 .65818 L F
.648 .536 .714 r
.56652 .65332 m .56717 .65612 L .56427 .65631 L F
.567 .325 .508 r
.56717 .65612 m .56412 .65873 L .56427 .65631 L F
.648 .465 .622 r
.55167 .74408 m .55148 .7467 L .55402 .74645 L F
.006 0 .081 r
.43673 .66975 m .4344 .67255 L .43527 .67072 L F
.623 .739 .93 r
.28192 .64018 m .2869 .64176 L .28569 .64041 L F
.751 .83 .912 r
.28569 .64041 m .2869 .64176 L .28879 .63968 L F
.462 .316 .595 r
.63204 .49453 m .6339 .49153 L .63175 .49215 L F
.914 .632 .494 r
.71942 .49511 m .71826 .49548 L .71775 .49199 L F
.947 .804 .669 r
.71942 .49511 m .7176 .49705 L .71826 .49548 L F
.71942 .49511 m .719 .49832 L .7176 .49705 L F
.841 .463 .337 r
.50391 .78047 m .50569 .78341 L .50437 .78389 L F
.742 .453 .492 r
.50713 .78279 m .50569 .78341 L .50391 .78047 L F
.841 .463 .337 r
.50391 .78047 m .50437 .78389 L .50431 .77999 L F
.626 .401 .556 r
.46154 .65874 m .45843 .66122 L .45886 .65925 L F
.219 0 .065 r
.59895 .55766 m .59736 .55916 L .59626 .55937 L F
.682 .34 .389 r
.59736 .55916 m .59557 .56104 L .59626 .55937 L F
0 0 0 r
.59626 .55937 m .59557 .56104 L .59349 .56248 L F
.53 .165 .292 r
.59897 .61333 m .5962 .61563 L .59608 .6142 L F
.59897 .61333 m .59846 .61549 L .5962 .61563 L F
.498 .245 .461 r
.59897 .61333 m .60096 .61575 L .59846 .61549 L F
.59897 .61333 m .60147 .61308 L .60096 .61575 L F
.665 .488 .636 r
.5692 .61081 m .572 .61087 L .57147 .60881 L F
.57046 .60914 m .57147 .60881 L .57128 .60806 L F
.5692 .61081 m .57147 .60881 L .57046 .60914 L F
.666 .489 .635 r
.572 .61087 m .57446 .60785 L .57128 .60806 L F
.968 .648 .336 r
.57065 .6096 m .572 .61087 L .57128 .60806 L F
.106 0 0 r
.57065 .6096 m .57446 .60785 L .572 .61087 L F
.57065 .6096 m .57313 .60904 L .57445 .60786 L F
.57443 .60787 m .57445 .60786 L .57446 .60785 L F
.57065 .6096 m .57445 .60786 L .57443 .60787 L F
0 0 0 r
.57128 .60806 m .57065 .6096 L .5692 .61081 L F
0 .23 .745 r
.57023 .6059 m .57166 .60719 L .57128 .60806 L F
0 0 0 r
.57128 .60806 m .57166 .60719 L .57065 .6096 L F
.57128 .60806 m .57166 .60719 L .57065 .6096 L F
.712 .69 .15 r
.65341 .48372 m .6528 .48681 L .65312 .48507 L F
0 0 0 r
.65312 .48507 m .65575 .4829 L .65341 .48372 L F
.918 .935 .802 r
.65589 .49507 m .65323 .49675 L .65479 .49403 L F
.65589 .49507 m .65394 .49796 L .65323 .49675 L F
.386 .232 .548 r
.26561 .59689 m .26729 .59862 L .26733 .59623 L F
.26561 .59689 m .26556 .59932 L .26729 .59862 L F
.399 .771 .993 r
.30947 .5838 m .31153 .58361 L .31295 .58443 L F
.391 .807 .975 r
.31153 .58361 m .3153 .58371 L .31295 .58443 L F
.827 .802 .828 r
.71955 .50805 m .72336 .50649 L .72229 .50547 L F
.275 0 .066 r
.35129 .63705 m .35022 .63814 L .34832 .63861 L F
0 0 0 r
.3529 .63595 m .35022 .63814 L .35129 .63705 L F
.559 .668 .91 r
.7407 .47464 m .74052 .47769 L .73833 .47643 L F
.7407 .47464 m .74312 .47708 L .74052 .47769 L F
.549 .298 .488 r
.60112 .55671 m .59736 .55916 L .59895 .55766 L F
.401 .151 .416 r
.3055 .61258 m .30405 .611 L .30614 .6105 L F
.3055 .61258 m .30342 .61325 L .30405 .611 L F
.452 .188 .422 r
.30657 .60887 m .30614 .6105 L .30405 .611 L F
.74 .473 .526 r
.51896 .65062 m .51539 .65272 L .51614 .65039 L F
.51896 .65062 m .51751 .65337 L .51539 .65272 L F
.4 .097 .332 r
.52073 .65234 m .51896 .65062 L .51997 .64931 L F
.52073 .65234 m .51751 .65337 L .51896 .65062 L F
.511 .329 .57 r
.58151 .62778 m .58175 .63015 L .57938 .63038 L F
.405 .3 .621 r
.58175 .63015 m .57986 .63373 L .57938 .63038 L F
.969 .778 .592 r
.56369 .76609 m .56564 .76402 L .56414 .76317 L F
.56369 .76609 m .56519 .76673 L .56564 .76402 L F
.554 .308 .497 r
.60412 .60807 m .60609 .60989 L .60414 .60903 L F
.60412 .60807 m .60643 .6078 L .60609 .60989 L F
.569 .179 .264 r
.42481 .65787 m .42549 .65654 L .42293 .65636 L F
.564 .182 .277 r
.42167 .6584 m .42481 .65787 L .42293 .65636 L F
.335 .449 .829 r
.71668 .46679 m .718 .4698 L .71944 .46801 L F
.409 .559 .893 r
.718 .4698 m .72117 .47063 L .71944 .46801 L F
.203 0 0 r
.35022 .63814 m .34671 .64007 L .34832 .63861 L F
.626 .677 .878 r
.30991 .62736 m .30779 .6281 L .30604 .62526 L F
0 .165 .697 r
.54408 .77762 m .54529 .77762 L .5426 .77737 L F
.54408 .77762 m .54631 .78045 L .54529 .77762 L F
.34 0 .143 r
.49369 .64278 m .49303 .64422 L .49073 .6445 L F
.444 .046 .19 r
.49547 .64385 m .49369 .64278 L .49618 .642 L F
.49547 .64385 m .49303 .64422 L .49369 .64278 L F
.311 .118 .45 r
.47718 .7994 m .47926 .79985 L .47892 .79642 L F
.325 .035 .309 r
.47652 .80259 m .47926 .79985 L .47718 .7994 L F
.397 .321 .654 r
.30229 .62107 m .30011 .61893 L .30174 .61861 L F
.30229 .62107 m .30027 .62307 L .30011 .61893 L F
.818 .617 .631 r
.69294 .52037 m .69134 .5231 L .69456 .52337 L F
.317 .269 .645 r
.40522 .69561 m .40664 .69526 L .4065 .69228 L F
.763 .381 .331 r
.50048 .79235 m .49557 .79037 L .49948 .79162 L F
.88 .97 .654 r
.49884 .79405 m .50048 .79235 L .49948 .79162 L F
.49884 .79405 m .49943 .79373 L .50048 .79235 L F
.193 0 0 r
.52008 .77559 m .51697 .77746 L .51907 .77653 L F
0 0 0 r
.51697 .77746 m .52008 .77559 L .51907 .77653 L F
.498 .445 .728 r
.51951 .7725 m .52008 .77559 L .52175 .77461 L F
0 0 0 r
.51935 .77659 m .52175 .77461 L .52174 .77709 L F
.51935 .77659 m .52008 .77559 L .51898 .77689 L F
.52175 .77461 m .52103 .77504 L .51935 .77659 L F
.52103 .77504 m .52008 .77559 L .51935 .77659 L F
.685 .388 .466 r
.51907 .77653 m .51935 .77659 L .51883 .77706 L F
.51935 .77659 m .52174 .77709 L .51883 .77706 L F
0 0 0 r
.51907 .77653 m .52175 .77461 L .51935 .77659 L F
.52175 .77461 m .51898 .77689 L .51883 .77706 L F
.51907 .77653 m .52008 .77559 L .52175 .77461 L F
.766 .69 .779 r
.719 .49832 m .7149 .49939 L .7176 .49705 L F
.746 .703 .811 r
.48919 .70256 m .4882 .70028 L .48885 .70001 L F
.635 .354 .475 r
.48534 .70094 m .4882 .70017 L .4882 .70014 L F
.746 .703 .811 r
.4882 .70028 m .48814 .70013 L .4882 .70012 L F
.4882 .70028 m .4882 .70012 L .48885 .70001 L F
.635 .354 .475 r
.48534 .70094 m .48796 .70033 L .4882 .70017 L F
.48534 .70094 m .48828 .70012 L .48814 .70013 L F
.746 .703 .811 r
.4882 .70028 m .48534 .70094 L .48814 .70013 L F
.48919 .70256 m .48554 .70103 L .48819 .70028 L F
.687 .417 .508 r
.48811 .70029 m .48826 .70027 L .48828 .70012 L F
.746 .703 .811 r
.4882 .70028 m .48819 .70028 L .4882 .70028 L F
.48919 .70256 m .48819 .70028 L .4882 .70028 L F
.48919 .70256 m .48708 .70247 L .48534 .70094 L F
.64 .144 .057 r
.48919 .70256 m .48546 .70297 L .48708 .70247 L F
.48919 .70256 m .48789 .70384 L .48546 .70297 L F
.672 .698 .865 r
.48512 .7011 m .48708 .70247 L .48342 .70238 L F
.48534 .70094 m .48546 .70105 L .48512 .7011 L F
.48546 .70105 m .48708 .70247 L .48512 .7011 L F
.33 0 0 r
.48708 .70247 m .48546 .70297 L .48342 .70238 L F
.687 .417 .508 r
.48546 .70297 m .48768 .70073 L .48462 .70257 L F
.48768 .70073 m .48811 .70029 L .48737 .70077 L F
.48768 .70073 m .48737 .70077 L .48462 .70257 L F
.48546 .70297 m .48789 .70384 L .48826 .70027 L F
.48546 .70297 m .48826 .70027 L .48811 .70029 L F
.48811 .70029 m .48828 .70012 L .48796 .70033 L F
.48811 .70029 m .48796 .70033 L .48462 .70257 L F
.746 .703 .811 r
.48554 .70103 m .48534 .70094 L .48796 .70033 L F
.48554 .70103 m .48796 .70033 L .4882 .70028 L F
.635 .354 .475 r
.48534 .70094 m .48462 .70257 L .48796 .70033 L F
.4882 .70014 m .4882 .70017 L .48828 .70012 L F
.555 .106 .141 r
.48814 .70013 m .48877 .70002 L .48885 .70001 L F
.621 .102 0 r
.49222 .70086 m .49046 .70093 L .48862 .69973 L F
.555 .106 .141 r
.48877 .70002 m .49151 .69957 L .48885 .70001 L F
.423 0 0 r
.48862 .69973 m .48899 .69997 L .48885 .70001 L F
.48899 .69997 m .49046 .70093 L .48885 .70001 L F
.366 .11 .388 r
.30851 .60791 m .30614 .6105 L .30657 .60887 L F
.818 .832 .859 r
.48639 .80254 m .48973 .80261 L .48768 .80374 L F
.764 .358 .283 r
.48841 .80469 m .48973 .80261 L .48639 .80254 L F
.74 .308 .226 r
.48639 .80254 m .48973 .80261 L .48823 .80326 L F
.608 .716 .921 r
.48973 .80261 m .49065 .7995 L .48823 .80326 L F
.346 0 .056 r
.49103 .80416 m .48973 .80261 L .48841 .80469 L F
.832 .837 .851 r
.72097 .47383 m .71969 .47573 L .71835 .47425 L F
0 0 .269 r
.71585 .46289 m .71668 .46679 L .71602 .46422 L F
.562 .638 .884 r
.71405 .49649 m .7126 .49911 L .71169 .49735 L F
.71405 .49649 m .7149 .49939 L .7126 .49911 L F
.998 .839 .504 r
.73327 .4864 m .73275 .48431 L .73362 .48467 L F
.394 0 0 r
.49765 .70156 m .49608 .70229 L .49402 .70162 L F
.409 .837 .683 r
.49896 .70069 m .49765 .70156 L .50003 .70066 L F
.49896 .70069 m .49608 .70229 L .49765 .70156 L F
0 0 .309 r
.73354 .52277 m .73423 .52418 L .73415 .52176 L F
.73354 .52277 m .73478 .52605 L .73423 .52418 L F
.719 .729 .858 r
.58368 .71758 m .58583 .71563 L .58242 .71513 L F
.022 .112 .619 r
.27389 .63633 m .27553 .63597 L .2736 .63296 L F
.27553 .63597 m .2756 .63572 L .2736 .63296 L F
.9 .882 .807 r
.2763 .63864 m .27389 .63633 L .27293 .6384 L F
.909 .875 .791 r
.27703 .63492 m .27583 .63655 L .2763 .63864 L F
.9 .882 .807 r
.2763 .63864 m .27583 .63655 L .27553 .63597 L F
.883 .818 .779 r
.27563 .63561 m .27583 .63655 L .27703 .63492 L F
.022 .112 .619 r
.27565 .63595 m .27564 .63577 L .2756 .63572 L F
.883 .818 .779 r
.27555 .63565 m .27565 .63595 L .27563 .63561 L F
.27565 .63595 m .27583 .63655 L .27563 .63561 L F
.022 .112 .619 r
.27553 .63597 m .27565 .63595 L .2756 .63572 L F
.27565 .63595 m .27575 .63592 L .27564 .63577 L F
.9 .882 .807 r
.27583 .63655 m .27569 .63594 L .27565 .63595 L F
.27583 .63655 m .27565 .63595 L .27553 .63597 L F
.2754 .63778 m .27553 .63597 L .27389 .63633 L F
.2763 .63864 m .27553 .63597 L .2754 .63778 L F
.883 .818 .779 r
.27319 .63682 m .2747 .6381 L .27583 .63655 L F
.27319 .63682 m .27583 .63655 L .27555 .63565 L F
.909 .875 .791 r
.27583 .63655 m .2747 .6381 L .2763 .63864 L F
.9 .882 .807 r
.2763 .63864 m .27575 .63595 L .27569 .63594 L F
.27575 .63595 m .27575 .63592 L .27574 .63593 L F
.2763 .63864 m .2747 .6381 L .27575 .63592 L F
.323 .045 .327 r
.27612 .63863 m .2747 .6381 L .2763 .63864 L F
.27293 .6384 m .2747 .6381 L .27612 .63863 L F
.71 .637 .774 r
.27764 .64169 m .27583 .64449 L .27194 .63996 L F
.323 .045 .327 r
.27293 .6384 m .27224 .6403 L .2747 .6381 L F
.466 .238 .483 r
.27224 .6403 m .27461 .64017 L .2747 .6381 L F
.966 .684 .447 r
.2747 .6381 m .27461 .64017 L .27355 .63767 L F
.2747 .6381 m .27355 .63767 L .27319 .63682 L F
.909 .875 .791 r
.27703 .63492 m .2763 .63864 L .27689 .63706 L F
.588 .478 .696 r
.2747 .6381 m .27689 .63706 L .2763 .63864 L F
.2747 .6381 m .27739 .64005 L .27697 .63753 L F
.27669 .63716 m .27697 .63753 L .27689 .63706 L F
.2747 .6381 m .27697 .63753 L .27669 .63716 L F
.9 .882 .807 r
.27575 .63595 m .27574 .63593 L .27569 .63594 L F
.883 .818 .779 r
.27563 .63458 m .27563 .63561 L .276 .63425 L F
.558 .355 .561 r
.27301 .63093 m .2736 .63296 L .27534 .63035 L F
.867 .977 .673 r
.2736 .63296 m .27352 .63195 L .27534 .63035 L F
.826 .568 .55 r
.2756 .63572 m .27352 .63195 L .2736 .63296 L F
.27575 .63592 m .27558 .63563 L .2756 .63572 L F
.27558 .63563 m .27352 .63195 L .2756 .63572 L F
.27558 .63563 m .27334 .63634 L .27352 .63195 L F
.27334 .63634 m .27319 .63623 L .27352 .63195 L F
.98 .73 .482 r
.27352 .63195 m .27338 .63377 L .27229 .63335 L F
.631 .68 .878 r
.27145 .62939 m .27301 .63093 L .27534 .63035 L F
.27145 .62939 m .27534 .63035 L .27463 .62775 L F
.761 .917 .545 r
.27352 .63195 m .27229 .63335 L .2745 .62971 L F
.424 .425 .756 r
.27229 .63335 m .2727 .62886 L .2745 .62971 L F
0 0 .465 r
.27463 .62775 m .27502 .62916 L .27535 .62842 L F
.27502 .62916 m .27534 .63035 L .27535 .62842 L F
.657 .825 .4 r
.27535 .62842 m .2745 .62971 L .27578 .62749 L F
0 0 .465 r
.27463 .62775 m .27535 .62842 L .27631 .62703 L F
.657 .825 .4 r
.27535 .62842 m .27578 .62749 L .27622 .62673 L F
.925 .967 .675 r
.27534 .63035 m .27352 .63195 L .27535 .62842 L F
.706 .84 .405 r
.27535 .62842 m .27352 .63195 L .2745 .62971 L F
.424 .425 .756 r
.27229 .63335 m .27402 .63311 L .2727 .62886 L F
.284 .749 .947 r
.27402 .63311 m .27087 .63282 L .27229 .63335 L F
.27087 .63282 m .27041 .63278 L .27229 .63335 L F
.98 .73 .482 r
.27338 .63377 m .27319 .63623 L .27229 .63335 L F
.727 .631 .752 r
.27229 .63335 m .273 .63609 L .27313 .63602 L F
.273 .63609 m .27355 .63649 L .276 .63425 L F
.98 .73 .482 r
.27319 .63623 m .27318 .63639 L .27229 .63335 L F
.727 .631 .752 r
.27229 .63335 m .27313 .63602 L .276 .63425 L F
.273 .63609 m .27319 .63682 L .27337 .63636 L F
.861 .823 .81 r
.27337 .63636 m .27319 .63682 L .27318 .63639 L F
.883 .818 .779 r
.27319 .63682 m .27555 .63565 L .27555 .63564 L F
.826 .568 .55 r
.27423 .6362 m .27318 .63639 L .27558 .63563 L F
.883 .818 .779 r
.27319 .63682 m .27556 .63553 L .27554 .63542 L F
.861 .823 .81 r
.27423 .6362 m .27319 .63682 L .27337 .63636 L F
.883 .818 .779 r
.27319 .63682 m .27554 .63542 L .27541 .63479 L F
.861 .823 .81 r
.27575 .63592 m .27319 .63682 L .27423 .6362 L F
.727 .631 .752 r
.27337 .63636 m .27319 .63682 L .27355 .63649 L F
.826 .568 .55 r
.27334 .63634 m .27318 .63639 L .27319 .63623 L F
.883 .818 .779 r
.27319 .63682 m .27555 .63564 L .27469 .63601 L F
.826 .568 .55 r
.27575 .63592 m .27423 .6362 L .27558 .63563 L F
.883 .818 .779 r
.27469 .63601 m .27555 .63564 L .27556 .63553 L F
.27541 .63479 m .27556 .63553 L .27563 .63458 L F
.27555 .63565 m .27563 .63561 L .27563 .63458 L F
.27563 .63561 m .27703 .63492 L .27601 .63426 L F
.27563 .63561 m .27601 .63426 L .276 .63425 L F
.141 0 0 r
.45003 .64675 m .45169 .64681 L .45295 .64559 L F
.45003 .64675 m .44951 .64738 L .45169 .64681 L F
.773 .57 .623 r
.61277 .5517 m .61293 .55423 L .60927 .55366 L F
.542 .423 .667 r
.40074 .67641 m .40296 .676 L .40254 .67276 L F
.576 .489 .719 r
.40121 .67875 m .40296 .676 L .40074 .67641 L F
.561 .558 .808 r
.28839 .64732 m .28953 .64644 L .28793 .64535 L F
.28839 .64732 m .29042 .64691 L .28953 .64644 L F
.393 0 .085 r
.4386 .65201 m .44233 .64987 L .43934 .65116 L F
.4386 .65201 m .44088 .65182 L .44233 .64987 L F
.472 .047 .152 r
.44088 .65182 m .44455 .64979 L .44233 .64987 L F
.513 .508 .787 r
.75054 .48914 m .74943 .49276 L .74878 .48891 L F
.75054 .48914 m .75137 .49243 L .74943 .49276 L F
.51 .48 .759 r
.75137 .49243 m .75244 .49401 L .74943 .49276 L F
.532 .466 .727 r
.74943 .49276 m .75244 .49401 L .75011 .49463 L F
.843 .741 .752 r
.63868 .51402 m .63695 .51707 L .63952 .51716 L F
.886 .775 .734 r
.63648 .51933 m .63952 .51716 L .63695 .51707 L F
.63648 .51933 m .63798 .52061 L .63952 .51716 L F
.18 .382 .826 r
.73892 .52288 m .74221 .52518 L .74142 .52588 L F
.455 0 0 r
.74025 .52395 m .74221 .52518 L .73892 .52288 L F
.94 .946 .617 r
.57598 .5862 m .57476 .58951 L .57605 .58837 L F
.444 .168 .398 r
.37341 .62174 m .37077 .62421 L .37129 .62224 L F
.713 .859 .951 r
.70044 .47625 m .70171 .477 L .70474 .47558 L F
.141 0 0 r
.6732 .4817 m .66986 .48174 L .67072 .48292 L F
.451 .188 .422 r
.59369 .60241 m .59593 .60182 L .59611 .5999 L F
.514 .253 .458 r
.59835 .60145 m .59611 .5999 L .59593 .60182 L F
.59835 .60145 m .59865 .59944 L .59611 .5999 L F
.809 .43 .339 r
.54732 .60769 m .54991 .61004 L .55091 .60814 L F
.381 .044 .263 r
.55091 .60814 m .54991 .61004 L .55311 .60761 L F
.13 .66 .869 r
.33384 .58688 m .33591 .58691 L .33766 .58729 L F
0 .484 .841 r
.338 .587 m .33766 .58729 L .33591 .58691 L F
.338 .587 m .33949 .58787 L .33766 .58729 L F
.682 .446 .559 r
.58338 .70394 m .58562 .70153 L .58341 .70147 L F
.58338 .70394 m .58572 .7039 L .58562 .70153 L F
.686 .454 .565 r
.58572 .7039 m .58928 .70137 L .58562 .70153 L F
.16 0 .084 r
.57785 .55702 m .57985 .55606 L .5805 .55471 L F
.327 0 .166 r
.57985 .55606 m .58273 .5541 L .5805 .55471 L F
.708 .768 .899 r
.57471 .72091 m .57766 .7204 L .57661 .71765 L F
.764 .783 .869 r
.57766 .7204 m .58005 .71774 L .57661 .71765 L F
.787 .575 .614 r
.68981 .51983 m .69134 .5231 L .69294 .52037 L F
.875 .665 .614 r
.57386 .65635 m .5709 .65743 L .56998 .65571 L F
0 0 .482 r
.5709 .65743 m .5709 .6562 L .56998 .65571 L F
.369 0 0 r
.56998 .65571 m .57078 .65614 L .57081 .65614 L F
.5702 .65575 m .57081 .65614 L .57386 .65635 L F
.56998 .65571 m .57081 .65614 L .5702 .65575 L F
0 0 .482 r
.5709 .65743 m .57107 .65738 L .571 .65627 L F
.596 .903 .985 r
.57386 .65635 m .57081 .65614 L .57462 .65523 L F
0 0 .482 r
.57078 .65614 m .5709 .65477 L .56998 .65571 L F
.596 .903 .985 r
.57081 .65614 m .57078 .65614 L .5709 .65599 L F
.57078 .65614 m .5709 .656 L .5709 .65599 L F
.57081 .65614 m .5709 .65599 L .57462 .65523 L F
0 0 .482 r
.5709 .6562 m .5709 .65599 L .57078 .65614 L F
.742 .671 .781 r
.57462 .65523 m .5709 .656 L .5709 .65477 L F
0 0 .482 r
.5709 .656 m .5709 .65477 L .57078 .65614 L F
.742 .671 .781 r
.5709 .656 m .57034 .65611 L .5709 .65477 L F
0 0 .482 r
.5709 .65599 m .5709 .65477 L .5709 .656 L F
.596 .903 .985 r
.57078 .65614 m .57034 .65611 L .5709 .656 L F
0 0 .482 r
.5709 .6562 m .571 .65627 L .57098 .65587 L F
.5709 .65599 m .57098 .65587 L .5709 .65477 L F
.5709 .6562 m .57098 .65587 L .5709 .65599 L F
.5709 .65743 m .571 .65627 L .5709 .6562 L F
.369 0 0 r
.56998 .65571 m .57034 .65611 L .57078 .65614 L F
.875 .665 .614 r
.57386 .65635 m .57352 .65881 L .5709 .65743 L F
.779 .975 .915 r
.54471 .59379 m .54558 .59178 L .54753 .59154 L F
.54471 .59379 m .54387 .59332 L .54558 .59178 L F
.713 .654 .789 r
.51019 .77959 m .50798 .77757 L .50813 .77967 L F
.917 .773 .686 r
.50813 .77967 m .50911 .78224 L .51019 .77959 L F
.405 .3 .621 r
.58175 .63015 m .58166 .63365 L .57986 .63373 L F
.409 .388 .724 r
.58166 .63365 m .58245 .63563 L .57986 .63373 L F
.495 .38 .653 r
.57986 .63373 m .58245 .63563 L .58034 .63616 L F
.15 .139 .59 r
.46262 .65588 m .463 .65823 L .46138 .65625 L F
.26 .164 .552 r
.46138 .65625 m .463 .65823 L .46154 .65874 L F
.801 .947 .918 r
.70779 .46803 m .7072 .46996 L .70882 .46897 L F
.649 .868 .982 r
.71151 .46823 m .70779 .46803 L .70882 .46897 L F
.717 .583 .705 r
.7256 .49399 m .72597 .49703 L .72677 .49502 L F
.699 .719 .865 r
.57223 .72074 m .57471 .72091 L .5742 .71822 L F
.668 .698 .869 r
.5742 .71822 m .57471 .72091 L .57661 .71765 L F
.824 .809 .836 r
.6583 .51025 m .66196 .50921 L .6611 .50848 L F
.6583 .51025 m .65793 .51274 L .66196 .50921 L F
.769 .949 .936 r
.66264 .50711 m .66196 .50921 L .66486 .50686 L F
.66264 .50711 m .6611 .50848 L .66196 .50921 L F
.678 .579 .737 r
.50989 .81166 m .51167 .80869 L .50965 .81173 L F
.50989 .81166 m .51569 .81249 L .51167 .80869 L F
.818 .48 0 r
.71665 .48916 m .71775 .49199 L .71582 .49203 L F
.956 .662 .437 r
.71775 .49199 m .71651 .49343 L .71582 .49203 L F
.71775 .49199 m .71826 .49548 L .71651 .49343 L F
0 0 0 r
.61523 .59606 m .61258 .59942 L .61374 .59733 L F
.849 .493 .378 r
.5577 .75148 m .55876 .74954 L .55689 .74917 L F
.5577 .75148 m .56041 .75202 L .55876 .74954 L F
.945 .591 .3 r
.66254 .49312 m .66402 .4945 L .6634 .49233 L F
0 0 .373 r
.66288 .48876 m .6636 .49158 L .6634 .49233 L F
.75 .922 .56 r
.6636 .49158 m .66254 .49312 L .6634 .49233 L F
.704 .485 .589 r
.48295 .6507 m .48313 .65346 L .48664 .65312 L F
.701 .837 .948 r
.49471 .66676 m .4965 .6681 L .49808 .66684 L F
.49471 .66676 m .4965 .6681 L .49808 .66684 L F
.609 .91 .982 r
.48095 .76828 m .47891 .76914 L .48027 .76962 L F
.615 .89 .989 r
.53461 .60059 m .53569 .59904 L .53703 .59974 L F
.53461 .60059 m .53346 .59993 L .53569 .59904 L F
.484 .09 .216 r
.42906 .70983 m .43131 .70977 L .42838 .71033 L F
.815 .512 0 r
.48651 .79743 m .4855 .79415 L .4868 .79699 L F
0 .473 .862 r
.4868 .79699 m .48826 .79806 L .48651 .79743 L F
.753 .687 .142 r
.60938 .57984 m .60943 .57899 L .60981 .57592 L F
.73 .593 .019 r
.60938 .57984 m .60933 .57997 L .60943 .57899 L F
.60938 .57984 m .60938 .58212 L .60933 .57997 L F
.01 0 .134 r
.61761 .59299 m .61523 .59606 L .6161 .59423 L F
0 0 0 r
.58177 .57412 m .5808 .57575 L .57965 .57729 L F
.635 .916 .63 r
.57965 .57729 m .5808 .57575 L .5782 .57839 L F
.881 .708 .664 r
.56197 .76006 m .56485 .7574 L .563 .7561 L F
.56197 .76006 m .56388 .76048 L .56485 .7574 L F
0 0 0 r
.61987 .59046 m .61761 .59299 L .61837 .59168 L F
.536 .429 .679 r
.44987 .67557 m .44778 .67648 L .44712 .67366 L F
0 0 .497 r
.44712 .67366 m .44827 .67449 L .44987 .67557 L F
.44712 .67366 m .44778 .67648 L .44827 .67449 L F
.429 .13 .354 r
.52649 .78309 m .52697 .78096 L .52406 .78337 L F
.257 .074 .431 r
.52878 .77773 m .52697 .78096 L .52864 .78045 L F
.561 .248 .395 r
.52649 .78309 m .52877 .7827 L .52697 .78096 L F
.322 .248 .616 r
.52697 .78096 m .52877 .7827 L .52864 .78045 L F
.95 .949 .644 r
.72677 .48796 m .72765 .48652 L .72721 .48577 L F
.259 .693 .963 r
.36633 .5897 m .36383 .58962 L .3625 .58871 L F
.525 .458 .723 r
.40121 .67875 m .40182 .68211 L .40392 .68096 L F
.6 .548 .768 r
.40249 .68444 m .40392 .68096 L .40182 .68211 L F
.512 .052 .097 r
.52427 .69035 m .52641 .69135 L .52759 .68981 L F
.62 .172 .165 r
.52759 .68981 m .52998 .69135 L .53023 .69046 L F
.52759 .68981 m .52641 .69135 L .52998 .69135 L F
.495 .282 .519 r
.60078 .59627 m .60317 .59341 L .60065 .59377 L F
.469 .293 .559 r
.47892 .79642 m .48182 .79376 L .47937 .79411 L F
.47892 .79642 m .48199 .79712 L .48182 .79376 L F
.769 .67 .753 r
.47926 .79985 m .48199 .79712 L .47892 .79642 L F
.18 0 0 r
.32493 .63073 m .32662 .63092 L .32914 .6311 L F
.043 0 0 r
.32662 .63092 m .33107 .63042 L .32914 .6311 L F
.498 .445 .728 r
.51951 .7725 m .52175 .77461 L .52198 .77229 L F
.746 .334 .269 r
.49858 .65095 m .5006 .65302 L .49836 .65207 L F
.143 0 .128 r
.50033 .64999 m .49836 .65207 L .49858 .65095 L F
.567 .156 .222 r
.4311 .65385 m .42985 .65544 L .43303 .6552 L F
.518 .199 .365 r
.4311 .65385 m .43303 .6552 L .43348 .6535 L F
.511 .421 .689 r
.40249 .68444 m .40512 .6867 L .40495 .68408 L F
.40249 .68444 m .40283 .68711 L .40512 .6867 L F
.6 .548 .768 r
.40249 .68444 m .40495 .68408 L .40392 .68096 L F
.686 .454 .565 r
.58572 .7039 m .58934 .70377 L .58928 .70137 L F
.858 .807 .798 r
.70566 .47107 m .70609 .4745 L .70625 .47206 L F
.911 .973 .792 r
.70779 .46803 m .70625 .47206 L .7072 .46996 L F
.70779 .46803 m .70566 .47107 L .70625 .47206 L F
.503 .295 .53 r
.24489 .67019 m .24565 .67007 L .24643 .66765 L F
.623 .247 .31 r
.53023 .69046 m .53205 .69194 L .53326 .68984 L F
.757 .546 .612 r
.53205 .69194 m .53538 .68935 L .53326 .68984 L F
.382 .085 .33 r
.56557 .57091 m .56779 .5702 L .56792 .56771 L F
.272 0 .265 r
.56792 .56771 m .57028 .56742 L .57051 .56522 L F
.231 0 .3 r
.56792 .56771 m .56957 .56908 L .57028 .56742 L F
.56792 .56771 m .56779 .5702 L .56957 .56908 L F
0 0 .016 r
.74141 .52741 m .74124 .52748 L .74142 .52588 L F
0 0 .066 r
.74322 .52424 m .74141 .52741 L .74142 .52588 L F
0 0 0 r
.74142 .52588 m .74221 .52518 L .74322 .52424 L F
.695 .825 .944 r
.74322 .52424 m .74221 .52518 L .74025 .52395 L F
.909 .881 .794 r
.74022 .52634 m .74141 .52741 L .74322 .52424 L F
0 .183 .665 r
.74162 .52732 m .74141 .52741 L .74022 .52634 L F
.74247 .52791 m .74141 .52741 L .74162 .52732 L F
0 0 .016 r
.74141 .52741 m .74107 .52895 L .74124 .52748 L F
.917 .944 .804 r
.50285 .64262 m .50028 .64475 L .5011 .6414 L F
.50285 .64262 m .50074 .64533 L .50028 .64475 L F
.693 .74 .887 r
.50494 .64181 m .50285 .64262 L .5011 .6414 L F
.412 .256 .557 r
.75244 .49401 m .75056 .4969 L .75011 .49463 L F
.673 .377 .463 r
.48664 .65312 m .48757 .65518 L .48985 .65207 L F
.765 .724 .814 r
.48874 .65016 m .48985 .65207 L .4923 .65052 L F
.529 .11 .19 r
.66429 .49654 m .66757 .49474 L .66402 .4945 L F
.66429 .49654 m .66725 .49695 L .66757 .49474 L F
.998 .85 .559 r
.73327 .4864 m .73191 .48775 L .73254 .48539 L F
.73327 .4864 m .73276 .48871 L .73191 .48775 L F
.998 .839 .504 r
.73327 .4864 m .73254 .48539 L .73275 .48431 L F
.064 .265 .757 r
.74312 .47708 m .74477 .48047 L .74302 .47892 L F
.02 0 .154 r
.62257 .58546 m .62178 .58746 L .62043 .58843 L F
0 0 0 r
.62178 .58746 m .61987 .59046 L .62043 .58843 L F
.69 .631 .785 r
.67946 .52306 m .68269 .52398 L .68199 .52046 L F
.611 .578 .792 r
.68199 .52046 m .68269 .52398 L .68534 .52324 L F
.003 .533 .849 r
.33981 .60041 m .33791 .5996 L .33621 .59923 L F
.253 0 0 r
.34193 .60011 m .33791 .5996 L .33981 .60041 L F
.376 .364 .719 r
.5179 .6377 m .51625 .63979 L .51569 .63601 L F
.403 .403 .745 r
.5179 .6377 m .51874 .64124 L .51625 .63979 L F
.967 .928 .695 r
.61271 .56843 m .61106 .56932 L .6121 .56761 L F
.61271 .56843 m .61118 .57204 L .61106 .56932 L F
.988 .882 .544 r
.61271 .56843 m .6121 .56761 L .6129 .56417 L F
.782 .658 .727 r
.50208 .69862 m .50319 .70178 L .50003 .70066 L F
.752 .284 .137 r
.50319 .70178 m .50231 .70298 L .50003 .70066 L F
.496 0 0 r
.50208 .69862 m .50601 .69963 L .50319 .70178 L F
.676 .19 .088 r
.50319 .70178 m .50559 .70353 L .50231 .70298 L F
.692 .673 .827 r
.68534 .52324 m .68879 .52552 L .68766 .5224 L F
.678 .649 .814 r
.68766 .5224 m .68879 .52552 L .69134 .5231 L F
.767 .377 .315 r
.57471 .65336 m .57771 .65555 L .57684 .65367 L F
.57471 .65336 m .57462 .65523 L .57771 .65555 L F
.686 .606 .761 r
.57624 .64459 m .57709 .64812 L .5793 .64655 L F
.364 .023 .246 r
.3594 .6105 m .36149 .60997 L .36232 .60818 L F
.513 .226 .416 r
.36149 .60997 m .36432 .6075 L .36232 .60818 L F
.865 .651 .612 r
.73449 .51907 m .73732 .51758 L .73386 .51707 L F
.73449 .51907 m .73721 .52054 L .73732 .51758 L F
.705 .714 .856 r
.36068 .60235 m .36367 .60274 L .36078 .59968 L F
.506 .533 .818 r
.36367 .60274 m .36572 .60119 L .36078 .59968 L F
.36367 .60274 m .36553 .60248 L .36572 .60119 L F
.606 .528 .741 r
.36418 .60503 m .36553 .60248 L .36367 .60274 L F
.472 .327 .602 r
.61126 .52025 m .61336 .51971 L .61336 .51677 L F
.615 .486 .682 r
.61115 .5227 m .61336 .51971 L .61126 .52025 L F
.779 .609 .669 r
.50823 .80859 m .51167 .80869 L .51198 .80623 L F
.765 .724 .814 r
.48874 .65016 m .4923 .65052 L .491 .64967 L F
.363 .401 .767 r
.4923 .65052 m .49432 .65249 L .49399 .64922 L F
.508 .493 .775 r
.30229 .62107 m .30295 .62401 L .30027 .62307 L F
.688 .682 .839 r
.65614 .51154 m .65793 .51274 L .6583 .51025 L F
.727 .861 .944 r
.5161 .78905 m .51863 .78888 L .51868 .78907 L F
.26 0 .224 r
.51863 .78888 m .522 .78592 L .52069 .78811 L F
0 0 0 r
.52069 .78811 m .51868 .78907 L .51863 .78888 L F
.744 .92 .951 r
.2552 .66271 m .25377 .66491 L .25589 .66451 L F
.2552 .66271 m .25231 .66431 L .25377 .66491 L F
.25377 .66491 m .2552 .66271 L .25589 .66451 L F
.25377 .66491 m .25231 .66431 L .2552 .66271 L F
.576 .489 .719 r
.40121 .67875 m .40349 .67831 L .40296 .676 L F
.525 .458 .723 r
.40121 .67875 m .40392 .68096 L .40349 .67831 L F
.476 .383 .672 r
.26194 .60845 m .26396 .60815 L .26356 .60466 L F
.49 .478 .772 r
.26194 .60845 m .26464 .61001 L .26396 .60815 L F
.085 0 0 r
.53694 .69305 m .53437 .69401 L .53208 .69422 L F
.248 .743 .663 r
.53848 .69247 m .53694 .69305 L .53923 .69261 L F
.53848 .69247 m .53437 .69401 L .53694 .69305 L F
.566 .354 .552 r
.61767 .50907 m .61784 .51138 L .62007 .50874 L F
0 0 0 r
.57051 .56522 m .57242 .56445 L .5732 .5628 L F
.034 0 .203 r
.57051 .56522 m .57175 .56617 L .57242 .56445 L F
.57051 .56522 m .57028 .56742 L .57175 .56617 L F
.434 0 0 r
.51257 .63211 m .51088 .63086 L .51031 .63002 L F
.51257 .63211 m .51391 .63296 L .51088 .63086 L F
.505 .223 .42 r
.59194 .54494 m .59486 .54216 L .5925 .54287 L F
.544 .753 .974 r
.43581 .69746 m .4351 .69936 L .43414 .69741 L F
.43581 .69746 m .4375 .6989 L .4351 .69936 L F
.278 .487 .882 r
.37754 .59253 m .37679 .59403 L .37591 .59222 L F
.495 .753 .987 r
.37754 .59253 m .37892 .59373 L .37679 .59403 L F
.487 .303 .557 r
.49186 .78352 m .49413 .78298 L .49312 .78135 L F
.494 .339 .6 r
.4045 .66738 m .40648 .66442 L .40421 .66495 L F
.667 .462 .598 r
.57997 .70408 m .58338 .70394 L .58341 .70147 L F
.223 0 0 r
.45169 .64681 m .45524 .64503 L .45295 .64559 L F
.866 .845 .822 r
.26877 .62484 m .26591 .62765 L .26817 .62479 L F
.576 .58 .82 r
.41314 .70683 m .41369 .70257 L .41192 .70291 L F
.41314 .70683 m .41545 .70639 L .41369 .70257 L F
.478 .595 .892 r
.41314 .70683 m .4168 .70913 L .41545 .70639 L F
.516 .202 .373 r
.31172 .6056 m .31088 .60774 L .30851 .60791 L F
.356 .047 .297 r
.31289 .60696 m .31172 .6056 L .31338 .60504 L F
.31289 .60696 m .31088 .60774 L .31172 .6056 L F
.123 0 .301 r
.5732 .5628 m .57507 .56162 L .57516 .55958 L F
0 0 .027 r
.57423 .56342 m .5732 .5628 L .57242 .56445 L F
.57423 .56342 m .57507 .56162 L .5732 .5628 L F
.547 .391 .621 r
.47395 .66159 m .47654 .6618 L .47615 .65881 L F
.47615 .65881 m .47654 .6618 L .47395 .66159 L F
.405 0 0 r
.26817 .62479 m .27031 .62525 L .2714 .62497 L F
.311 .373 .765 r
.2714 .62497 m .27188 .62138 L .27114 .62224 L F
.2714 .62497 m .27301 .62491 L .27188 .62138 L F
.547 .175 .288 r
.27031 .62525 m .27301 .62491 L .2714 .62497 L F
.744 .846 .927 r
.69243 .46851 m .69156 .46969 L .69042 .46843 L F
.632 .513 .7 r
.47974 .78063 m .47967 .78169 L .4813 .78003 L F
.627 .499 .687 r
.48296 .77861 m .47974 .78063 L .4813 .78003 L F
.503 .009 .017 r
.47097 .70139 m .46963 .70269 L .46767 .70169 L F
.576 .136 .168 r
.4732 .70151 m .46963 .70269 L .47097 .70139 L F
.037 0 .425 r
.48951 .78628 m .49046 .78726 L .49066 .78639 L F
.758 .449 .462 r
.48951 .78628 m .49284 .78927 L .48948 .78877 L F
.037 0 .425 r
.48951 .78628 m .48948 .78877 L .49046 .78726 L F
.275 0 0 r
.44792 .70491 m .44641 .70596 L .44415 .70606 L F
.099 0 0 r
.44997 .70524 m .44641 .70596 L .44792 .70491 L F
.287 .093 .434 r
.41359 .66004 m .41574 .65945 L .41473 .65874 L F
.352 0 0 r
.41574 .65945 m .41735 .65889 L .41473 .65874 L F
.571 .463 .692 r
.58347 .62471 m .58151 .62778 L .58112 .6253 L F
.58347 .62471 m .58417 .6276 L .58151 .62778 L F
.428 .19 .449 r
.58417 .6276 m .58175 .63015 L .58151 .62778 L F
.777 .973 .69 r
.52406 .78337 m .522 .78592 L .52117 .78653 L F
.134 .613 .919 r
.522 .78592 m .52432 .78631 L .52346 .78564 L F
.522 .78592 m .52346 .78564 L .52069 .78811 L F
.777 .973 .69 r
.52406 .78337 m .522 .78592 L .52117 .78653 L F
.311 0 0 r
.51249 .70328 m .51184 .70411 L .50944 .70432 L F
.2 0 0 r
.51405 .70357 m .51249 .70328 L .51538 .70232 L F
.51405 .70357 m .51184 .70411 L .51249 .70328 L F
.539 0 0 r
.27145 .62939 m .26762 .62757 L .26957 .62967 L F
.694 .75 .895 r
.691 .50875 m .69456 .50941 L .69316 .50799 L F
.807 .767 .816 r
.69316 .50799 m .69456 .50941 L .69691 .50644 L F
.4 .432 .778 r
.56636 .59206 m .56806 .59276 L .56505 .59385 L F
.001 0 0 r
.56505 .59385 m .56806 .59276 L .5644 .59489 L F
.59 .606 .836 r
.55804 .62787 m .5592 .62447 L .55667 .62711 L F
.55804 .62787 m .56057 .62783 L .5592 .62447 L F
.717 .273 .197 r
.55667 .62711 m .56057 .62783 L .55804 .62787 L F
.733 .627 .741 r
.26117 .6192 m .2651 .61938 L .26342 .61633 L F
.706 .663 .806 r
.2651 .61938 m .2658 .61589 L .26342 .61633 L F
.2651 .61938 m .26717 .61874 L .2658 .61589 L F
.426 .388 .714 r
.7313 .47698 m .73119 .4797 L .72856 .47797 L F
.791 .704 .768 r
.74912 .51976 m .75053 .52318 L .74708 .5224 L F
.826 .555 .529 r
.75053 .52318 m .74754 .52473 L .74708 .5224 L F
.75053 .52318 m .75074 .52558 L .74754 .52473 L F
.521 .562 .838 r
.75224 .52243 m .75053 .52318 L .74912 .51976 L F
.387 .231 .544 r
.75224 .52243 m .75074 .52558 L .75053 .52318 L F
.662 .627 .805 r
.45843 .66122 m .46004 .66462 L .45801 .66359 L F
.763 .473 .495 r
.46029 .66659 m .45801 .66359 L .46004 .66462 L F
.6 .57 .792 r
.46108 .66102 m .46004 .66462 L .45843 .66122 L F
.46108 .66102 m .4624 .66426 L .46004 .66462 L F
.679 .33 .376 r
.46004 .66462 m .46224 .66669 L .46029 .66659 L F
.558 .354 .56 r
.4624 .66426 m .46224 .66669 L .46004 .66462 L F
.672 .49 .63 r
.56993 .70655 m .57218 .70919 L .57186 .70676 L F
.56993 .70655 m .56957 .70955 L .57218 .70919 L F
.91 .511 .221 r
.73566 .52729 m .73651 .52927 L .73498 .52828 L F
.73584 .52703 m .73604 .52771 L .73566 .52729 L F
.19 .514 .914 r
.73861 .53048 m .7379 .52971 L .73615 .52883 L F
.412 0 0 r
.73615 .52883 m .73892 .53022 L .73651 .52927 L F
.73615 .52883 m .73651 .52927 L .73584 .52703 L F
.91 .511 .221 r
.73604 .52771 m .73651 .52927 L .73566 .52729 L F
.19 .514 .914 r
.73807 .53094 m .73861 .53048 L .73615 .52883 L F
.73861 .53048 m .73892 .53022 L .7379 .52971 L F
.248 .714 .947 r
.34154 .58786 m .34311 .58847 L .33949 .58787 L F
.17 .683 .896 r
.34154 .58786 m .34525 .58832 L .34311 .58847 L F
.202 .082 .483 r
.4275 .68093 m .42746 .68366 L .42593 .6842 L F
.287 .316 .718 r
.42746 .68366 m .428 .68605 L .42593 .6842 L F
.495 .573 .864 r
.428 .68605 m .42642 .68706 L .42593 .6842 L F
.985 .828 .605 r
.63118 .53611 m .63299 .53478 L .63234 .53164 L F
.63118 .53611 m .63236 .53712 L .63299 .53478 L F
.507 .405 .673 r
.62221 .5035 m .62478 .50533 L .62419 .50285 L F
.496 .407 .684 r
.62221 .5035 m .62276 .50616 L .62478 .50533 L F
.642 .443 .598 r
.57218 .70919 m .57619 .70671 L .57186 .70676 L F
.371 0 .086 r
.45946 .64343 m .46289 .64133 L .46108 .64232 L F
.616 .408 .576 r
.49066 .78639 m .49413 .78298 L .49186 .78352 L F
.505 .598 .881 r
.55555 .77876 m .55188 .77608 L .55394 .77677 L F
.302 .731 .971 r
.55225 .77803 m .55555 .77876 L .55394 .77677 L F
.151 0 0 r
.43969 .70678 m .43839 .70797 L .43531 .70893 L F
.478 .013 .07 r
.4419 .70628 m .43839 .70797 L .43969 .70678 L F
.591 .41 .605 r
.54312 .7593 m .54472 .75771 L .54235 .75807 L F
.54312 .7593 m .54472 .75771 L .54235 .75807 L F
.378 .035 .251 r
.39016 .60933 m .38866 .60826 L .391 .60795 L F
.39016 .60933 m .38798 .6099 L .38866 .60826 L F
.824 .922 .901 r
.49557 .79037 m .49275 .79154 L .49396 .78938 L F
0 .442 .77 r
.49766 .79087 m .49557 .79037 L .49396 .78938 L F
.103 .507 .906 r
.49615 .78969 m .49766 .79087 L .49396 .78938 L F
.49672 .78977 m .49696 .79005 L .49615 .78969 L F
.49696 .79005 m .49766 .79087 L .49615 .78969 L F
.647 .807 .369 r
.49396 .78938 m .49565 .78636 L .49579 .78608 L F
.495 .78746 m .49579 .78608 L .49625 .78517 L F
.49396 .78938 m .49579 .78608 L .495 .78746 L F
.605 .315 .449 r
.49284 .78927 m .49396 .78938 L .49385 .78813 L F
.611 .495 .696 r
.49396 .78938 m .49284 .78927 L .49385 .78813 L F
.446 .393 .705 r
.49046 .78726 m .49366 .78981 L .49413 .7888 L F
.647 .807 .369 r
.49396 .78938 m .49625 .78517 L .49385 .78813 L F
.103 .507 .906 r
.49672 .78977 m .49396 .78938 L .49385 .78813 L F
.446 .393 .705 r
.49366 .78981 m .495 .79088 L .49418 .7889 L F
.49366 .78981 m .49418 .7889 L .49413 .7888 L F
.49093 .78738 m .49413 .7888 L .49385 .78813 L F
.49046 .78726 m .49413 .7888 L .49093 .78738 L F
0 0 0 r
.49678 .79042 m .49766 .79087 L .49672 .78977 L F
0 .442 .77 r
.49766 .79087 m .49859 .79134 L .49557 .79037 L F
.708 .658 .799 r
.49542 .79349 m .49884 .79405 L .49766 .79087 L F
.65 .568 .75 r
.49657 .79297 m .49542 .79349 L .49766 .79087 L F
0 0 0 r
.49698 .79251 m .49657 .79297 L .49766 .79087 L F
.49698 .79251 m .49766 .79087 L .49678 .79042 L F
0 .442 .77 r
.49766 .79087 m .49948 .79162 L .49859 .79134 L F
.776 .921 .547 r
.58263 .57207 m .58177 .57412 L .58363 .57101 L F
.516 .631 .903 r
.30493 .6237 m .30412 .62579 L .30295 .62401 L F
.30493 .6237 m .30604 .62526 L .30412 .62579 L F
.468 .887 .787 r
.48207 .6474 m .48566 .64585 L .48389 .64626 L F
.131 0 0 r
.4875 .64495 m .48389 .64626 L .48566 .64585 L F
.791 .944 .925 r
.65179 .50143 m .64788 .5046 L .64889 .50531 L F
.69 .84 .955 r
.55867 .60705 m .55671 .60813 L .55539 .60699 L F
.59 .037 0 r
.53054 .65047 m .52922 .64972 L .52726 .64796 L F
.514 .601 .879 r
.4168 .70913 m .41721 .70622 L .41545 .70639 L F
.4168 .70913 m .41893 .70907 L .41721 .70622 L F
.661 .824 .962 r
.53104 .79348 m .53333 .79141 L .53154 .79157 L F
.53104 .79348 m .53492 .79276 L .53333 .79141 L F
.768 .74 .827 r
.67854 .52001 m .67609 .52265 L .67946 .52306 L F
.744 .727 .836 r
.67854 .52001 m .67946 .52306 L .68199 .52046 L F
.699 .719 .865 r
.57223 .72074 m .5742 .71822 L .57085 .71757 L F
.597 .456 .661 r
.5835 .62251 m .58347 .62471 L .58112 .6253 L F
.473 .394 .687 r
.53188 .64672 m .53364 .65126 L .53054 .65047 L F
0 .334 .769 r
.53054 .65047 m .53205 .65089 L .52922 .64972 L F
.53054 .65047 m .53408 .65247 L .53205 .65089 L F
.611 .29 .401 r
.2555 .63598 m .25523 .63829 L .25336 .63633 L F
.557 .177 .277 r
.25336 .63633 m .25562 .63643 L .2555 .63598 L F
.25562 .63643 m .25672 .63647 L .2555 .63598 L F
.283 .019 .325 r
.25592 .63761 m .25523 .63829 L .2555 .63598 L F
.44 .742 .992 r
.25389 .63501 m .25628 .63625 L .25336 .63633 L F
.25628 .63625 m .25672 .63647 L .25562 .63643 L F
.25628 .63625 m .25562 .63643 L .25336 .63633 L F
.41 .405 .743 r
.2555 .63598 m .25672 .63647 L .25827 .6353 L F
.596 .788 .972 r
.25827 .6353 m .25672 .63647 L .25628 .63625 L F
.283 .019 .325 r
.25827 .6353 m .257 .63591 L .2555 .63598 L F
.25768 .63588 m .25562 .63643 L .2555 .63598 L F
.596 .788 .972 r
.25827 .6353 m .25628 .63625 L .25389 .63501 L F
.283 .019 .325 r
.25827 .6353 m .25768 .63588 L .257 .63591 L F
.25768 .63588 m .25592 .63761 L .25562 .63643 L F
0 .183 .704 r
.25336 .63633 m .25523 .63829 L .25389 .63501 L F
.682 .598 .756 r
.56756 .7106 m .56743 .71239 L .56957 .70955 L F
.622 .514 .71 r
.56743 .71239 m .56996 .7121 L .56957 .70955 L F
.577 .476 .703 r
.56743 .71239 m .57068 .71538 L .56996 .7121 L F
.56743 .71239 m .56831 .71604 L .57068 .71538 L F
.468 .404 .703 r
.40283 .68711 m .40542 .68969 L .40512 .6867 L F
.40283 .68711 m .40348 .69009 L .40542 .68969 L F
.838 .554 .508 r
.55402 .74645 m .55689 .74917 L .55727 .74659 L F
.779 .316 .146 r
.57446 .60785 m .57313 .60904 L .57594 .60977 L F
.417 .248 .542 r
.57446 .60785 m .57628 .60739 L .57626 .60503 L F
.801 .629 .669 r
.57594 .60977 m .57628 .60739 L .57446 .60785 L F
.546 .515 .773 r
.56831 .71604 m .56893 .71802 L .57085 .71757 L F
.654 .752 .922 r
.49432 .65249 m .49594 .65354 L .49836 .65207 L F
.612 .349 .495 r
.60396 .55458 m .60384 .55671 L .60112 .55671 L F
.348 .136 .444 r
.60576 .55575 m .60396 .55458 L .60625 .55414 L F
.60576 .55575 m .60384 .55671 L .60396 .55458 L F
.976 .756 .54 r
.57065 .6096 m .572 .61087 L .5692 .61081 L F
.094 0 0 r
.71479 .46753 m .71319 .46816 L .71151 .46823 L F
.831 1 .803 r
.71596 .46518 m .71479 .46753 L .71668 .46679 L F
.71596 .46518 m .71319 .46816 L .71479 .46753 L F
.426 0 0 r
.31958 .60214 m .31894 .60246 L .31662 .60228 L F
.158 0 0 r
.32213 .60174 m .31894 .60246 L .31958 .60214 L F
.64 .585 .777 r
.2715 .64437 m .27091 .64854 L .26946 .64702 L F
.2715 .64437 m .27291 .64791 L .27091 .64854 L F
.653 .801 .954 r
.27091 .64854 m .27155 .64657 L .26946 .64702 L F
.27091 .64854 m .27291 .64791 L .27155 .64657 L F
.797 .419 .34 r
.51492 .77724 m .51697 .77746 L .51589 .77955 L F
.711 .236 .119 r
.51492 .77724 m .51697 .77746 L .51684 .77824 L F
.17 0 .029 r
.51883 .77706 m .51697 .77746 L .51684 .77824 L F
.247 0 .245 r
.51883 .77706 m .51697 .77746 L .51907 .77653 L F
.17 0 .029 r
.51684 .77824 m .51697 .77746 L .51883 .77706 L F
.109 0 .402 r
.49777 .64742 m .49908 .64681 L .50074 .64533 L F
.49777 .64742 m .49791 .64781 L .49908 .64681 L F
.453 .085 .248 r
.34913 .62136 m .35141 .62103 L .35244 .6188 L F
.432 .151 .385 r
.35141 .62103 m .35415 .61742 L .35244 .6188 L F
.43 .828 .981 r
.55538 .60237 m .55406 .60188 L .55192 .6023 L F
.317 0 0 r
.55538 .60237 m .55669 .60308 L .55406 .60188 L F
.55538 .60237 m .55813 .60283 L .55669 .60308 L F
.664 .486 .635 r
.57626 .60503 m .57873 .60496 L .57859 .60211 L F
.701 .538 .663 r
.57873 .60496 m .58207 .60241 L .57859 .60211 L F
.656 .154 .043 r
.49222 .70086 m .49402 .70162 L .49046 .70093 L F
.395 .466 .815 r
.72713 .47091 m .7267 .47273 L .72564 .46957 L F
.304 .495 .879 r
.72939 .47242 m .7267 .47273 L .72713 .47091 L F
.72939 .47242 m .72985 .47407 L .7267 .47273 L F
.291 .773 .92 r
.35146 .59932 m .34998 .59906 L .34777 .59932 L F
.028 .558 .857 r
.35146 .59932 m .35227 .59917 L .34998 .59906 L F
.35146 .59932 m .35358 .5997 L .35227 .59917 L F
.273 .616 .958 r
.35146 .59932 m .3545 .60055 L .35358 .5997 L F
.507 .33 .576 r
.42642 .68706 m .4264 .68978 L .42426 .69025 L F
.537 .433 .684 r
.4264 .68978 m .4268 .69204 L .42426 .69025 L F
.482 .44 .734 r
.42426 .69025 m .4268 .69204 L .42484 .69225 L F
.808 .98 .697 r
.54865 .58972 m .54753 .59154 L .5482 .58976 L F
.78 .986 .897 r
.54753 .59154 m .54558 .59178 L .5482 .58976 L F
.765 .489 .515 r
.27583 .64449 m .27131 .64235 L .27194 .63996 L F
.27583 .64449 m .2715 .64437 L .27131 .64235 L F
.782 .656 .723 r
.27583 .64449 m .27291 .64791 L .2715 .64437 L F
.552 .429 .667 r
.27764 .64169 m .27716 .64524 L .27583 .64449 L F
.524 0 0 r
.54761 .78006 m .55034 .78067 L .54631 .78045 L F
0 0 0 r
.62291 .58562 m .62257 .58546 L .6234 .5838 L F
.62291 .58562 m .62178 .58746 L .62257 .58546 L F
.892 .534 .058 r
.65302 .50202 m .65218 .50105 L .65254 .50042 L F
.622 .79 .352 r
.65254 .50042 m .65218 .50105 L .65313 .49935 L F
.615 .873 .99 r
.40965 .70617 m .4073 .70704 L .40825 .70545 L F
.40965 .70617 m .4073 .70704 L .40825 .70545 L F
.521 .325 .556 r
.4073 .70704 m .40717 .70954 L .40965 .70617 L F
.77 .973 .92 r
.484 .62539 m .48021 .62705 L .48146 .62583 L F
.785 .969 .918 r
.48596 .62394 m .484 .62539 L .48462 .62355 L F
.793 .975 .909 r
.484 .62539 m .48146 .62583 L .48462 .62355 L F
.243 0 0 r
.29208 .58554 m .29429 .58528 L .29537 .58484 L F
.403 0 0 r
.29429 .58528 m .2977 .58502 L .29537 .58484 L F
.496 0 0 r
.50208 .69862 m .50387 .69969 L .50601 .69963 L F
.334 .815 .865 r
.50601 .69963 m .50628 .69903 L .50827 .69871 L F
.50601 .69963 m .50387 .69969 L .50628 .69903 L F
.359 .177 .493 r
.43401 .67485 m .43229 .67308 L .4344 .67255 L F
.43401 .67485 m .43208 .67549 L .43229 .67308 L F
.205 0 .176 r
.57713 .55903 m .57785 .55702 L .57516 .55958 L F
.423 .134 .366 r
.57713 .55903 m .57985 .55606 L .57785 .55702 L F
.29 .753 .947 r
.52175 .77461 m .52527 .77493 L .52427 .77446 L F
.44 .543 .865 r
.52527 .77493 m .5266 .77351 L .52427 .77446 L F
.52527 .77493 m .52869 .77714 L .5266 .77351 L F
.404 0 0 r
.46046 .69573 m .46287 .69587 L .46383 .69525 L F
.353 0 0 r
.46287 .69587 m .46615 .69529 L .46383 .69525 L F
.711 .541 .657 r
.6433 .50612 m .64108 .50904 L .64101 .50637 L F
.62 .418 .587 r
.6433 .50612 m .64335 .50887 L .64108 .50904 L F
.702 .484 .588 r
.64433 .5067 m .64335 .50887 L .6433 .50612 L F
.062 0 0 r
.41823 .6592 m .41735 .65889 L .41574 .65945 L F
.41823 .6592 m .41968 .65838 L .41735 .65889 L F
.516 .873 .985 r
.4977 .62193 m .49863 .62076 L .49994 .6216 L F
.4977 .62193 m .49645 .62142 L .49863 .62076 L F
.699 .378 .429 r
.49073 .6445 m .48955 .64693 L .4875 .64495 L F
.627 .298 .393 r
.49355 .64655 m .49073 .6445 L .49303 .64422 L F
.49355 .64655 m .48955 .64693 L .49073 .6445 L F
0 0 .535 r
.65258 .50877 m .65253 .50517 L .65374 .50592 L F
.65258 .50877 m .65391 .50783 L .65253 .50517 L F
.805 .339 0 r
.65253 .50517 m .65291 .50679 L .65143 .50448 L F
.65253 .50517 m .65143 .50448 L .65124 .50419 L F
0 0 .535 r
.65374 .50592 m .65253 .50517 L .65402 .50521 L F
.5 .667 .937 r
.31422 .62652 m .3134 .62842 L .31234 .62666 L F
.31422 .62652 m .3155 .62824 L .3134 .62842 L F
.489 .563 .857 r
.43248 .69443 m .43195 .69737 L .43016 .69495 L F
.43248 .69443 m .43414 .69741 L .43195 .69737 L F
.947 .608 .344 r
.54376 .63338 m .54237 .63313 L .54138 .62975 L F
0 0 0 r
.54376 .63338 m .54189 .63671 L .54352 .63475 L F
.54189 .63671 m .54189 .63672 L .54352 .63475 L F
.859 .479 .325 r
.54557 .63426 m .54462 .63342 L .54352 .63475 L F
0 0 0 r
.54376 .63338 m .54352 .63475 L .54237 .63313 L F
.859 .479 .325 r
.54462 .63342 m .54246 .63154 L .54352 .63475 L F
.692 .317 .333 r
.5926 .60446 m .59369 .60241 L .58991 .60223 L F
.479 .253 .492 r
.59579 .60392 m .59369 .60241 L .5926 .60446 L F
.59579 .60392 m .59593 .60182 L .59369 .60241 L F
.021 .134 .643 r
.56703 .60218 m .56858 .60467 L .56799 .60584 L F
.931 .571 .312 r
.56858 .60467 m .57023 .6059 L .56799 .60584 L F
.99 .884 .612 r
.57526 .66218 m .57406 .66347 L .57511 .66042 L F
.57526 .66218 m .57477 .66461 L .57406 .66347 L F
.844 .969 .879 r
.66536 .50464 m .66486 .50686 L .66605 .50499 L F
.66536 .50464 m .66264 .50711 L .66486 .50686 L F
.215 0 0 r
.66846 .47467 m .67066 .4747 L .67214 .47441 L F
.511 0 0 r
.67066 .4747 m .67428 .4751 L .67214 .47441 L F
.763 .473 .495 r
.46029 .66659 m .45708 .6655 L .45801 .66359 L F
.987 .731 .352 r
.64971 .49411 m .65067 .49794 L .65106 .49527 L F
0 0 0 r
.32649 .64758 m .32646 .64812 L .3245 .64852 L F
.32649 .64758 m .32857 .64704 L .32646 .64812 L F
.328 0 0 r
.55645 .76564 m .55877 .76643 L .55744 .76604 L F
.217 .53 .921 r
.55877 .76643 m .56002 .76567 L .55744 .76604 L F
.55877 .76643 m .56085 .76686 L .56002 .76567 L F
.308 0 0 r
.25619 .6493 m .25835 .65015 L .25933 .65044 L F
.25933 .65044 m .25835 .65015 L .25619 .6493 L F
.814 .727 .769 r
.67345 .51351 m .67264 .51036 L .67114 .51231 L F
0 .038 .564 r
.57453 .66593 m .57406 .66347 L .57477 .66461 L F
.896 .791 .736 r
.67475 .51466 m .67171 .51645 L .67345 .51351 L F
.67475 .51466 m .67335 .51743 L .67171 .51645 L F
.858 .711 .698 r
.68862 .51388 m .68981 .51726 L .69054 .51512 L F
.299 .793 .775 r
.68583 .47045 m .68692 .4699 L .68832 .46967 L F
.68583 .47045 m .68463 .47063 L .68692 .4699 L F
0 0 0 r
.58632 .56849 m .58525 .57001 L .58363 .57101 L F
.293 .046 .358 r
.58632 .56849 m .58857 .56565 L .58795 .5676 L F
0 0 0 r
.58795 .5676 m .58525 .57001 L .58632 .56849 L F
.903 .64 .135 r
.27131 .64235 m .2715 .64437 L .27086 .64178 L F
.417 .081 .286 r
.31662 .60228 m .31567 .60455 L .31338 .60504 L F
.508 .17 .329 r
.31825 .60336 m .31662 .60228 L .31894 .60246 L F
.31825 .60336 m .31567 .60455 L .31662 .60228 L F
.474 .275 .529 r
.52687 .79751 m .52917 .79478 L .52715 .79402 L F
.494 .339 .6 r
.4045 .66738 m .40657 .6669 L .40648 .66442 L F
.559 .42 .649 r
.40455 .66984 m .40657 .6669 L .4045 .66738 L F
.67 .7 .869 r
.47817 .65691 m .47918 .65688 L .4766 .65626 L F
.4766 .65626 m .47918 .65688 L .47817 .65691 L F
.615 .777 .958 r
.48089 .65583 m .47918 .65688 L .47817 .65691 L F
.47817 .65691 m .47918 .65688 L .48089 .65583 L F
.793 .566 .592 r
.52928 .77455 m .53088 .77233 L .52755 .77207 L F
.52928 .77455 m .53135 .77481 L .53088 .77233 L F
.653 .473 .628 r
.53088 .77233 m .53135 .77481 L .53329 .77179 L F
.614 .089 0 r
.74771 .51184 m .74843 .5134 L .74431 .51128 L F
.495 0 0 r
.74771 .51184 m .74931 .5133 L .74843 .5134 L F
.74771 .51184 m .75027 .514 L .74931 .5133 L F
.686 .28 .27 r
.75143 .51344 m .74771 .51184 L .7506 .51165 L F
.75143 .51344 m .75027 .514 L .74771 .51184 L F
.381 .202 .509 r
.3594 .6105 m .3574 .61368 L .35929 .61288 L F
.531 .299 .509 r
.35681 .61512 m .35929 .61288 L .3574 .61368 L F
.587 .659 .888 r
.71363 .50661 m .71756 .50864 L .71678 .50739 L F
.628 .697 .895 r
.71756 .50864 m .71912 .50525 L .71678 .50739 L F
.71756 .50864 m .71955 .50805 L .71912 .50525 L F
.065 .611 .84 r
.3153 .58371 m .31735 .58387 L .3191 .5843 L F
.295 0 0 r
.31735 .58387 m .32077 .58488 L .3191 .5843 L F
.146 0 0 r
.58857 .56565 m .5896 .56634 L .58795 .5676 L F
.58857 .56565 m .59086 .56509 L .5896 .56634 L F
0 .324 .719 r
.52273 .64094 m .52435 .6417 L .5255 .64241 L F
.26 .443 .852 r
.52696 .64141 m .5255 .64241 L .52435 .6417 L F
.52696 .64141 m .52806 .6438 L .5255 .64241 L F
.483 .89 .935 r
.51089 .69766 m .51218 .69664 L .51365 .69554 L F
.51089 .69766 m .51009 .69743 L .51218 .69664 L F
.527 .58 .851 r
.26717 .61874 m .2676 .61539 L .2658 .61589 L F
.26717 .61874 m .26923 .61849 L .2676 .61539 L F
.451 0 0 r
.53261 .80036 m .53373 .80036 L .53104 .79979 L F
.53261 .80036 m .53373 .80036 L .53104 .79979 L F
.181 .536 .925 r
.53475 .79968 m .53373 .80036 L .53261 .80036 L F
.53475 .79968 m .53578 .8011 L .53373 .80036 L F
.53475 .79968 m .53373 .80036 L .53261 .80036 L F
.53475 .79968 m .53578 .8011 L .53373 .80036 L F
.748 .668 .772 r
.5242 .77208 m .52755 .77207 L .52639 .76893 L F
.598 .347 .507 r
.5242 .77208 m .5266 .77351 L .52755 .77207 L F
.811 .446 .365 r
.5266 .77351 m .52928 .77455 L .52755 .77207 L F
.565 .7 .931 r
.52869 .77714 m .52878 .77773 L .53105 .77735 L F
.569 .322 .503 r
.53106 .77999 m .52878 .77773 L .52864 .78045 L F
.446 .32 .615 r
.53185 .77824 m .52878 .77773 L .53106 .77999 L F
.357 .155 .464 r
.27261 .5909 m .27419 .59252 L .27584 .59079 L F
.351 0 .027 r
.27584 .59079 m .27645 .59214 L .27821 .5909 L F
.27584 .59079 m .27419 .59252 L .27645 .59214 L F
.777 .973 .69 r
.52406 .78337 m .52117 .78653 L .52346 .78564 L F
.897 .837 .778 r
.52346 .78564 m .52649 .78309 L .52406 .78337 L F
.816 .735 .775 r
.63399 .52234 m .63798 .52061 L .63648 .51933 L F
.63399 .52234 m .63565 .52334 L .63798 .52061 L F
.746 .794 .891 r
.65272 .51135 m .65403 .51271 L .65614 .51154 L F
.402 .516 .859 r
.3545 .60055 m .35569 .59909 L .35358 .5997 L F
.3545 .60055 m .35701 .6018 L .35569 .59909 L F
.968 .8 .621 r
.6302 .55042 m .63211 .55115 L .62969 .55029 L F
.6302 .55042 m .63182 .55322 L .63211 .55115 L F
.572 .305 .473 r
.5105 .64923 m .50903 .64784 L .51246 .64719 L F
.605 .254 .347 r
.51246 .64719 m .51447 .64927 L .5105 .64923 L F
.938 .902 .51 r
.61032 .57355 m .61106 .56932 L .61118 .57204 L F
.62 .238 .298 r
.71582 .49203 m .71372 .49297 L .71426 .49255 L F
.326 .306 .683 r
.70843 .47948 m .70883 .48383 L .71083 .48186 L F
.763 .351 .269 r
.71317 .48622 m .71273 .48695 L .70883 .48383 L F
.426 .463 .796 r
.70883 .48383 m .71273 .48695 L .71083 .48186 L F
.433 0 .006 r
.6775 .50181 m .68079 .50084 L .67816 .50319 L F
.6775 .50181 m .67823 .50215 L .68079 .50084 L F
.733 .991 .826 r
.68184 .49917 m .68143 .49951 L .68019 .49967 L F
.68143 .49951 m .67823 .50215 L .68019 .49967 L F
0 0 0 r
.67823 .50215 m .67814 .50234 L .68019 .49967 L F
.858 .433 0 r
.67893 .50356 m .67823 .50215 L .6775 .50181 L F
0 .192 .644 r
.67816 .50319 m .67893 .50356 L .678 .50242 L F
.67816 .50319 m .678 .50242 L .67784 .50251 L F
.858 .433 0 r
.67893 .50356 m .67795 .50277 L .67823 .50215 L F
0 0 0 r
.67814 .50234 m .67795 .50277 L .67834 .50223 L F
.67814 .50234 m .67834 .50223 L .68019 .49967 L F
.748 .994 .839 r
.68079 .50084 m .67823 .50215 L .68184 .49917 L F
.837 .98 .876 r
.67795 .50277 m .67858 .49988 L .68019 .49967 L F
.67858 .49988 m .67858 .49985 L .68019 .49967 L F
0 .192 .644 r
.67784 .50251 m .678 .50242 L .6775 .50181 L F
.67816 .50319 m .67955 .5041 L .67893 .50356 L F
.607 .43 .616 r
.66604 .47458 m .6662 .47728 L .66846 .47467 L F
.308 .782 .925 r
.34949 .58793 m .34891 .58863 L .34741 .58823 L F
.34949 .58793 m .35095 .58835 L .34891 .58863 L F
0 0 0 r
.51559 .6943 m .51365 .69554 L .51596 .69421 L F
.228 0 0 r
.51218 .69664 m .51596 .69421 L .51365 .69554 L F
.526 .306 .523 r
.60414 .60903 m .60412 .6119 L .60147 .61308 L F
.526 .308 .527 r
.60414 .60903 m .60536 .61184 L .60412 .6119 L F
.60414 .60903 m .60609 .60989 L .60536 .61184 L F
.78 .477 .475 r
.47908 .80867 m .47654 .80607 L .47598 .80891 L F
.47908 .80867 m .47931 .80986 L .47871 .80904 L F
.521 .13 .24 r
.47751 .81018 m .47871 .80904 L .47598 .80891 L F
.47871 .80904 m .47908 .80867 L .47823 .80874 L F
.47871 .80904 m .47823 .80874 L .47598 .80891 L F
.78 .477 .475 r
.47908 .80867 m .47871 .80904 L .47654 .80607 L F
.131 .275 .745 r
.47654 .80607 m .47871 .80904 L .47763 .80635 L F
.818 .687 .719 r
.48059 .80869 m .48166 .80843 L .48002 .80858 L F
.47991 .80868 m .48002 .80858 L .47908 .80867 L F
.48059 .80869 m .48002 .80858 L .47991 .80868 L F
.518 .758 .984 r
.47908 .80867 m .47999 .80854 L .47991 .80868 L F
.47908 .80867 m .47991 .80868 L .47931 .80986 L F
.818 .687 .719 r
.47883 .80912 m .48059 .80869 L .47908 .80867 L F
.946 .861 .724 r
.47931 .80986 m .47991 .80868 L .47932 .80923 L F
.818 .687 .719 r
.47899 .8092 m .48166 .80843 L .47883 .80912 L F
.47971 .80957 m .48017 .8093 L .47899 .8092 L F
.48017 .8093 m .48166 .80843 L .47899 .8092 L F
.131 .275 .745 r
.47871 .80904 m .47872 .80906 L .47883 .80912 L F
.521 .13 .24 r
.47799 .81057 m .47908 .80867 L .47751 .81018 L F
.946 .861 .724 r
.47899 .8092 m .47941 .80456 L .47763 .80635 L F
.47931 .80986 m .47932 .80923 L .47899 .8092 L F
.518 .758 .984 r
.47908 .80867 m .48002 .80858 L .47999 .80854 L F
.48002 .80858 m .48166 .80843 L .47999 .80854 L F
.946 .861 .724 r
.47935 .8078 m .47999 .80854 L .47941 .80456 L F
.47932 .80923 m .47999 .80854 L .47935 .8078 L F
.47932 .80923 m .47941 .80456 L .47899 .8092 L F
.47991 .80868 m .47999 .80854 L .47932 .80923 L F
.131 .275 .745 r
.47883 .80912 m .47931 .80986 L .479 .80923 L F
.47872 .80906 m .47931 .80986 L .47883 .80912 L F
.818 .687 .719 r
.47799 .81057 m .47971 .80957 L .47883 .80912 L F
.131 .275 .745 r
.47871 .80904 m .479 .80923 L .47763 .80635 L F
.324 0 .063 r
.28038 .59046 m .28252 .59002 L .28398 .58819 L F
.412 .003 .151 r
.28252 .59002 m .28614 .5878 L .28398 .58819 L F
.318 .697 .98 r
.37309 .5919 m .36966 .5909 L .37177 .59066 L F
.395 .684 .976 r
.37387 .59068 m .37309 .5919 L .37177 .59066 L F
.37387 .59068 m .37591 .59222 L .37309 .5919 L F
.852 .66 .643 r
.62719 .50471 m .63164 .50716 L .62977 .5039 L F
.62719 .50471 m .62726 .50783 L .63164 .50716 L F
.363 0 0 r
.62747 .50988 m .63164 .50716 L .62726 .50783 L F
.62747 .50988 m .62958 .5097 L .63164 .50716 L F
0 0 .56 r
.63164 .50716 m .63183 .50363 L .62977 .5039 L F
.63164 .50716 m .63277 .50724 L .63183 .50363 L F
.465 .464 .773 r
.39383 .59808 m .39318 .60222 L .39178 .59908 L F
.39383 .59808 m .39499 .60185 L .39318 .60222 L F
.713 .541 .655 r
.52198 .77229 m .5242 .77208 L .52397 .76928 L F
.748 .668 .772 r
.5242 .77208 m .52639 .76893 L .52397 .76928 L F
.521 .309 .533 r
.60015 .53723 m .60238 .53893 L .60234 .53655 L F
.60015 .53723 m .60002 .5395 L .60238 .53893 L F
.325 .002 .255 r
.36099 .63053 m .35989 .6326 L .35808 .63298 L F
.384 .078 .319 r
.36308 .62968 m .35989 .6326 L .36099 .63053 L F
.454 .484 .8 r
.40348 .69009 m .4065 .69228 L .40542 .68969 L F
.575 .616 .856 r
.56721 .61643 m .56837 .61314 L .56616 .6137 L F
.56721 .61643 m .56945 .61591 L .56837 .61314 L F
.513 .333 .575 r
.56721 .61643 m .56724 .61893 L .56945 .61591 L F
.495 .573 .864 r
.428 .68605 m .42818 .68646 L .42642 .68706 L F
.539 .357 .582 r
.42868 .68933 m .42642 .68706 L .42818 .68646 L F
.42868 .68933 m .4264 .68978 L .42642 .68706 L F
0 0 0 r
.58525 .57001 m .58263 .57207 L .58363 .57101 L F
.361 .129 .421 r
.57507 .56162 m .57713 .55903 L .57516 .55958 L F
.567 .325 .508 r
.56717 .65612 m .56743 .65831 L .56412 .65873 L F
.194 .067 .469 r
.56866 .65667 m .56743 .65831 L .56717 .65612 L F
.376 0 0 r
.47675 .70106 m .47573 .70165 L .4732 .70151 L F
.484 0 0 r
.47906 .70135 m .47573 .70165 L .47675 .70106 L F
.135 .007 .427 r
.75091 .48638 m .74878 .48891 L .75003 .48553 L F
.407 .379 .715 r
.75091 .48638 m .75054 .48914 L .74878 .48891 L F
.362 .662 .971 r
.27114 .62224 m .27077 .61824 L .26923 .61849 L F
.27114 .62224 m .27096 .62055 L .27077 .61824 L F
.27114 .62224 m .27188 .62138 L .27096 .62055 L F
.401 .157 .426 r
.55842 .57693 m .5605 .57611 L .56091 .57406 L F
.377 .071 .314 r
.56233 .575 m .56091 .57406 L .5605 .57611 L F
.56233 .575 m .56307 .5734 L .56091 .57406 L F
.516 .284 .502 r
.27017 .59375 m .27244 .5933 L .27261 .5909 L F
.357 .155 .464 r
.27261 .5909 m .27244 .5933 L .27419 .59252 L F
.055 .614 .803 r
.43942 .69789 m .44302 .69821 L .44068 .6981 L F
.737 .485 .548 r
.54849 .77735 m .55225 .77803 L .55188 .77608 L F
.655 .43 .567 r
.55188 .77608 m .55225 .77803 L .55394 .77677 L F
.35 .477 .847 r
.26921 .79291 m .27136 .79377 L .2701 .79467 L F
.435 .835 .632 r
.2701 .79467 m .27136 .79377 L .26905 .79532 L F
.067 0 0 r
.51613 .7029 m .51538 .70232 L .51744 .70146 L F
.51613 .7029 m .51405 .70357 L .51538 .70232 L F
.961 .926 .719 r
.50074 .64533 m .49908 .64681 L .50028 .64475 L F
.50074 .64533 m .49908 .64681 L .50028 .64475 L F
.835 .707 .723 r
.61426 .56003 m .61052 .56184 L .61069 .5594 L F
.61426 .56003 m .6123 .56295 L .61052 .56184 L F
.627 .152 .106 r
.451 .69692 m .45343 .69769 L .45473 .69635 L F
.272 0 0 r
.45473 .69635 m .45587 .69728 L .45661 .69675 L F
.45473 .69635 m .45343 .69769 L .45587 .69728 L F
.896 .904 .824 r
.73186 .50378 m .73065 .50547 L .72969 .50441 L F
.962 .879 .707 r
.72969 .50441 m .73065 .50547 L .72929 .50869 L F
.912 .897 .799 r
.5083 .8111 m .51167 .80869 L .50823 .80859 L F
.5083 .8111 m .50965 .81173 L .51167 .80869 L F
.176 0 0 r
.33384 .62944 m .33516 .62955 L .33683 .62811 L F
.359 0 0 r
.33683 .62811 m .33516 .62955 L .33812 .62889 L F
.338 0 .041 r
.33683 .62811 m .33812 .62889 L .33891 .62778 L F
.653 .507 .672 r
.50484 .79524 m .50582 .79463 L .50355 .79748 L F
.622 .463 .646 r
.50582 .79463 m .50625 .79775 L .50355 .79748 L F
.581 .205 .293 r
.50355 .79748 m .50625 .79775 L .50541 .79826 L F
.525 .352 .589 r
.50355 .79748 m .50541 .79826 L .50484 .79524 L F
.498 .375 .644 r
.5083 .79697 m .50582 .79463 L .50743 .79519 L F
.5083 .79697 m .50625 .79775 L .50582 .79463 L F
.533 .416 .666 r
.50484 .79524 m .50743 .79519 L .50582 .79463 L F
.50484 .79524 m .5083 .79697 L .50743 .79519 L F
0 0 0 r
.50541 .79826 m .50625 .79775 L .5083 .79697 L F
.573 .384 .587 r
.50541 .79826 m .5083 .79697 L .50484 .79524 L F
.607 .85 .99 r
.49193 .62289 m .48861 .6227 L .49057 .62185 L F
.535 .819 .998 r
.49288 .62146 m .49193 .62289 L .49057 .62185 L F
.49288 .62146 m .49437 .62239 L .49193 .62289 L F
.817 .986 .882 r
.52877 .7827 m .5258 .7857 L .52633 .78568 L F
.375 .803 .969 r
.47834 .6957 m .48005 .69527 L .48078 .69575 L F
.47766 .69568 m .48005 .69527 L .47834 .6957 L F
.48078 .69575 m .48005 .69527 L .4813 .69576 L F
.389 .663 .968 r
.4822 .69446 m .4813 .69576 L .48005 .69527 L F
.47 .074 .205 r
.47864 .69653 m .48141 .69492 L .48005 .69527 L F
.48141 .69492 m .4822 .69446 L .48005 .69527 L F
.238 0 0 r
.47766 .69568 m .47864 .69653 L .48005 .69527 L F
.981 .913 .634 r
.48005 .69527 m .47864 .69653 L .47935 .6948 L F
.48005 .69527 m .47935 .6948 L .47952 .69439 L F
.389 .663 .968 r
.4822 .69446 m .4835 .69588 L .4813 .69576 L F
.455 .215 .459 r
.64599 .5082 m .64335 .50887 L .64433 .5067 L F
.42 .218 .497 r
.64788 .5046 m .64599 .5082 L .64433 .5067 L F
.916 .543 .302 r
.56145 .65298 m .55989 .65238 L .55932 .65027 L F
.98 .687 .375 r
.56145 .65298 m .5602 .65384 L .55989 .65238 L F
.56145 .65298 m .56166 .65587 L .5602 .65384 L F
.911 .829 .752 r
.43185 .71045 m .42838 .71033 L .43131 .70977 L F
.43185 .71045 m .42924 .7117 L .42838 .71033 L F
.043 0 0 r
.34777 .59932 m .34483 .59982 L .34548 .59923 L F
.681 .788 .93 r
.70559 .49504 m .70237 .49459 L .7047 .49379 L F
.901 .879 .804 r
.70743 .49175 m .70559 .49504 L .7047 .49379 L F
.711 .453 0 r
.5283 .61057 m .52854 .61183 L .52688 .60964 L F
.5283 .61057 m .52891 .61334 L .52854 .61183 L F
.043 .325 .808 r
.66061 .48426 m .65885 .48425 L .6583 .48249 L F
.66061 .48426 m .66104 .4859 L .65885 .48425 L F
.39 .015 .201 r
.44455 .64979 m .44678 .64936 L .4475 .6481 L F
.488 .185 .377 r
.44678 .64936 m .44951 .64738 L .4475 .6481 L F
0 0 .437 r
.53408 .65247 m .53367 .65337 L .53468 .65158 L F
.432 .165 .407 r
.34786 .6222 m .34907 .6239 L .34913 .62136 L F
.34786 .6222 m .34699 .62453 L .34907 .6239 L F
.63 .835 .979 r
.44827 .67449 m .44778 .67648 L .44987 .67557 L F
1 .814 .504 r
.63158 .53862 m .63077 .54205 L .63204 .54309 L F
.986 .804 .575 r
.63077 .54205 m .63206 .5456 L .63204 .54309 L F
.433 .22 .488 r
.55842 .57693 m .56002 .57811 L .5605 .57611 L F
.321 .243 .61 r
.55874 .57983 m .56002 .57811 L .55842 .57693 L F
.546 .515 .773 r
.56831 .71604 m .57085 .71757 L .57068 .71538 L F
.649 .463 .619 r
.57763 .70665 m .57997 .70408 L .57773 .70389 L F
0 0 0 r
.44497 .66516 m .44372 .66618 L .4418 .66704 L F
.546 .042 .011 r
.44726 .6662 m .44372 .66618 L .44497 .66516 L F
.517 0 0 r
.49462 .64873 m .49399 .64922 L .4963 .64929 L F
.595 .318 .467 r
.49462 .64873 m .4963 .64929 L .49791 .64781 L F
.532 .364 .599 r
.60681 .52855 m .60924 .52805 L .60904 .5256 L F
.459 .291 .565 r
.60648 .5311 m .60924 .52805 L .60681 .52855 L F
0 0 0 r
.33259 .64574 m .33458 .64476 L .33666 .64412 L F
.339 .481 .855 r
.51652 .6341 m .51495 .63474 L .51391 .63296 L F
.629 .066 0 r
.51257 .63211 m .51652 .6341 L .51391 .63296 L F
.51257 .63211 m .51493 .63387 L .51652 .6341 L F
.381 .834 .924 r
.51652 .6341 m .51493 .63387 L .51778 .63358 L F
.712 .669 .806 r
.51997 .63517 m .51652 .6341 L .51766 .63349 L F
0 .48 .766 r
.51766 .63349 m .52204 .63463 L .51997 .63517 L F
.381 .834 .924 r
.51652 .6341 m .51835 .63365 L .51766 .63349 L F
.51835 .63365 m .51926 .63343 L .51766 .63349 L F
.51652 .6341 m .51778 .63358 L .51811 .63355 L F
.51835 .63365 m .51829 .63363 L .51926 .63343 L F
.518 .208 .381 r
.51926 .63343 m .5206 .63415 L .51829 .63363 L F
.51926 .63343 m .51829 .63363 L .51766 .63349 L F
.381 .834 .924 r
.51829 .63363 m .51811 .63355 L .51926 .63343 L F
0 .48 .766 r
.51766 .63349 m .51829 .63363 L .51835 .63365 L F
.381 .834 .924 r
.51652 .6341 m .51811 .63355 L .51835 .63365 L F
0 .48 .766 r
.51766 .63349 m .52115 .63433 L .52204 .63463 L F
.339 .481 .855 r
.51652 .6341 m .51569 .63601 L .51495 .63474 L F
.51652 .6341 m .51747 .63579 L .51569 .63601 L F
.712 .669 .806 r
.51997 .63517 m .51747 .63579 L .51652 .6341 L F
.667 .28 .303 r
.51493 .63387 m .51722 .63576 L .51897 .63377 L F
.51811 .63355 m .51897 .63377 L .51926 .63343 L F
.51493 .63387 m .51897 .63377 L .51811 .63355 L F
0 .48 .766 r
.51835 .63365 m .51963 .63393 L .52115 .63433 L F
.51963 .63393 m .5206 .63415 L .521 .63428 L F
.51963 .63393 m .521 .63428 L .52115 .63433 L F
.51829 .63363 m .5206 .63415 L .51835 .63365 L F
.376 .364 .719 r
.5179 .6377 m .51569 .63601 L .51747 .63579 L F
.064 .265 .757 r
.74312 .47708 m .74527 .47893 L .74477 .48047 L F
.015 .206 .716 r
.74527 .47893 m .74648 .48219 L .74477 .48047 L F
.484 0 0 r
.55522 .74978 m .55384 .74868 L .55148 .7467 L F
.619 .358 .499 r
.55148 .7467 m .55384 .74868 L .55402 .74645 L F
.378 .159 .45 r
.38011 .61793 m .37844 .61649 L .38079 .61626 L F
.38011 .61793 m .3782 .61869 L .37844 .61649 L F
.366 .129 .416 r
.62276 .50616 m .62248 .50821 L .62478 .50533 L F
.896 .904 .824 r
.73186 .50378 m .72969 .50441 L .73068 .50255 L F
.807 .767 .816 r
.69316 .50799 m .69691 .50644 L .69547 .50506 L F
.788 .739 .807 r
.69547 .50506 m .69691 .50644 L .69905 .50402 L F
.591 .394 .584 r
.58577 .61938 m .58808 .62134 L .5857 .62177 L F
.58577 .61938 m .58804 .61888 L .58808 .62134 L F
.589 .413 .612 r
.58291 .63823 m .58034 .63616 L .58245 .63563 L F
.58291 .63823 m .58027 .63871 L .58034 .63616 L F
.527 .594 .865 r
.54189 .63672 m .54442 .63663 L .54352 .63475 L F
.769 .968 .925 r
.48596 .62394 m .4871 .62168 L .48861 .6227 L F
.48596 .62394 m .48462 .62355 L .4871 .62168 L F
.192 .68 .924 r
.51596 .69421 m .51813 .69429 L .51559 .6943 L F
.571 .805 .987 r
.35701 .6018 m .36068 .60235 L .35915 .60151 L F
.896 .868 .802 r
.35915 .60151 m .36068 .60235 L .36078 .59968 L F
.283 .153 .521 r
.57973 .64502 m .5793 .64655 L .5811 .64405 L F
0 0 .076 r
.57019 .65262 m .57236 .65177 L .57107 .64997 L F
.732 .681 .802 r
.57107 .64997 m .57236 .65177 L .57494 .65085 L F
0 0 0 r
.47648 .8112 m .4748 .81444 L .47698 .81461 L F
.301 .417 .813 r
.57375 .63648 m .57543 .63495 L .57242 .63337 L F
.221 .365 .797 r
.57242 .63337 m .57375 .63648 L .57383 .635 L F
.594 .615 .843 r
.57413 .63847 m .57543 .63495 L .57375 .63648 L F
.87 .738 .714 r
.57383 .635 m .57413 .63847 L .57375 .63648 L F
.686 .606 .761 r
.57624 .64459 m .5793 .64655 L .57807 .64331 L F
.646 .632 .822 r
.57807 .64331 m .5793 .64655 L .5811 .64405 L F
.487 .69 .957 r
.38653 .5958 m .38627 .59782 L .38459 .59591 L F
.38653 .5958 m .38863 .59751 L .38627 .59782 L F
.432 .703 .978 r
.32292 .62965 m .32239 .63118 L .32125 .62985 L F
.32292 .62965 m .32493 .63073 L .32239 .63118 L F
.275 0 0 r
.28842 .58754 m .29052 .58717 L .29208 .58554 L F
.292 0 0 r
.29052 .58717 m .29429 .58528 L .29208 .58554 L F
.606 .528 .741 r
.36418 .60503 m .36657 .60463 L .36553 .60248 L F
.538 .364 .594 r
.36432 .6075 m .36657 .60463 L .36418 .60503 L F
.521 .13 .24 r
.47799 .81057 m .47598 .80891 L .47648 .8112 L F
.714 .734 .867 r
.7176 .49705 m .7149 .49939 L .71405 .49649 L F
.828 .648 .659 r
.61293 .55423 m .60932 .55614 L .60927 .55366 L F
.61293 .55423 m .6125 .55663 L .60932 .55614 L F
.723 .725 .851 r
.55878 .76891 m .56236 .76933 L .56085 .76686 L F
.758 .646 .737 r
.56034 .77249 m .56236 .76933 L .55878 .76891 L F
.669 .742 .905 r
.56333 .76864 m .56085 .76686 L .56236 .76933 L F
0 0 0 r
.52175 .69988 m .52006 .70053 L .52319 .69868 L F
.248 0 0 r
.52541 .69833 m .52175 .69988 L .52319 .69868 L F
.96 .782 .619 r
.63399 .52234 m .63445 .52553 L .63565 .52334 L F
.367 0 .134 r
.6769 .47465 m .68012 .47247 L .67749 .47378 L F
.749 .653 .755 r
.57107 .64997 m .57494 .65085 L .57335 .64709 L F
.6 .578 .8 r
.57335 .64709 m .57494 .65085 L .57687 .64989 L F
.541 .397 .634 r
.40254 .67276 m .40481 .67237 L .40455 .66984 L F
.532 .416 .666 r
.40254 .67276 m .4049 .67542 L .40481 .67237 L F
.40254 .67276 m .40296 .676 L .4049 .67542 L F
.723 .259 .15 r
.27112 .66461 m .26862 .66541 L .26816 .66406 L F
.451 0 0 r
.26816 .66406 m .26992 .66469 L .27112 .66461 L F
.932 .956 .772 r
.27112 .66461 m .27177 .66136 L .27186 .66364 L F
.27112 .66461 m .26992 .66469 L .27177 .66136 L F
.577 .941 .83 r
.27186 .66364 m .26862 .66541 L .27112 .66461 L F
.384 .275 .605 r
.47615 .65881 m .47654 .6618 L .47745 .66067 L F
.47745 .66067 m .47654 .6618 L .47615 .65881 L F
.47615 .65881 m .47654 .6618 L .47745 .66067 L F
.988 .887 .559 r
.6278 .57102 m .62657 .57227 L .62714 .57342 L F
.902 .838 .378 r
.62825 .56705 m .62756 .5705 L .6278 .57102 L F
.89 .947 .589 r
.62756 .5705 m .62657 .57227 L .6278 .57102 L F
.823 .996 .851 r
.47081 .63564 m .47258 .63273 L .47389 .6337 L F
.47081 .63564 m .46998 .63547 L .47258 .63273 L F
.542 .062 .065 r
.48246 .70111 m .48103 .70251 L .47906 .70135 L F
.373 0 0 r
.48482 .70091 m .48103 .70251 L .48246 .70111 L F
.858 .807 .798 r
.70566 .47107 m .70349 .4741 L .70609 .4745 L F
.829 .842 .857 r
.70349 .4741 m .70474 .47558 L .70609 .4745 L F
.53 .589 .858 r
.501 .62168 m .50117 .62498 L .49994 .6216 L F
.501 .62168 m .5033 .6248 L .50117 .62498 L F
.673 .799 .943 r
.5882 .71504 m .59168 .71539 L .58951 .71468 L F
.772 .665 .745 r
.58792 .71601 m .59168 .71539 L .5882 .71504 L F
.809 .737 .784 r
.58951 .71468 m .59168 .71539 L .59388 .71249 L F
.854 .398 .074 r
.5369 .65009 m .53874 .65343 L .54042 .65385 L F
.697 .967 .936 r
.53861 .65396 m .53697 .65558 L .54042 .65385 L F
.374 .841 .847 r
.53874 .65343 m .54211 .65273 L .54042 .65385 L F
.53874 .65343 m .54027 .65295 L .54211 .65273 L F
.593 .94 .935 r
.54027 .65295 m .54042 .65385 L .54211 .65273 L F
.54027 .65295 m .53861 .65396 L .54042 .65385 L F
.041 0 .382 r
.56877 .59863 m .56703 .60218 L .56594 .5997 L F
.216 .217 .645 r
.56855 .60091 m .56858 .60467 L .56703 .60218 L F
0 0 .509 r
.56846 .60022 m .56851 .6021 L .56855 .60091 L F
.56851 .6021 m .56858 .60467 L .56855 .60091 L F
.56851 .6021 m .56912 .60273 L .56858 .60467 L F
.56846 .60022 m .56911 .60268 L .56851 .6021 L F
.56911 .60268 m .56912 .60273 L .56851 .6021 L F
.041 0 .382 r
.56861 .59895 m .56855 .60091 L .56786 .60148 L F
.56753 .60116 m .56786 .60148 L .56703 .60218 L F
.56861 .59895 m .56786 .60148 L .56753 .60116 L F
.56877 .59863 m .56855 .60091 L .56861 .59895 L F
.863 .629 .583 r
.56228 .75488 m .56041 .75202 L .5604 .75462 L F
.87 .573 .484 r
.5604 .75462 m .56073 .7568 L .56228 .75488 L F
.827 .508 .449 r
.56073 .7568 m .563 .7561 L .56228 .75488 L F
.316 .756 .965 r
.35543 .58795 m .35465 .58878 L .35321 .58828 L F
.35543 .58795 m .35679 .58864 L .35465 .58878 L F
.386 0 0 r
.50604 .81526 m .50382 .81425 L .50505 .81767 L F
.53 .203 .358 r
.42481 .65787 m .42784 .65605 L .42549 .65654 L F
0 0 0 r
.47371 .6506 m .46998 .65183 L .47155 .65001 L F
.701 .43 .51 r
.54117 .68714 m .54402 .68958 L .5448 .68734 L F
.356 .076 .344 r
.54606 .6888 m .5448 .68734 L .54632 .6865 L F
.54606 .6888 m .54402 .68958 L .5448 .68734 L F
.39 0 0 r
.45362 .70421 m .45218 .70538 L .44997 .70524 L F
.522 .08 .139 r
.45588 .70392 m .45218 .70538 L .45362 .70421 L F
.621 .434 .607 r
.61336 .51677 m .61573 .51689 L .61558 .51449 L F
.61336 .51677 m .61573 .51689 L .61558 .51449 L F
.503 .355 .612 r
.61558 .51449 m .61788 .51386 L .61784 .51138 L F
.51 .374 .632 r
.61558 .51449 m .61805 .51632 L .61788 .51386 L F
.535 .369 .602 r
.61573 .51689 m .61805 .51632 L .61558 .51449 L F
.606 .384 .552 r
.59739 .54206 m .60002 .5395 L .59756 .54001 L F
.651 .69 .873 r
.6989 .49365 m .70237 .49459 L .70007 .49538 L F
.721 .542 .647 r
.53808 .78047 m .53861 .78361 L .53608 .78259 L F
.335 .028 .288 r
.53608 .78259 m .53721 .78313 L .53808 .78047 L F
.523 .406 .661 r
.54095 .78285 m .53861 .78361 L .53808 .78047 L F
.684 .363 .425 r
.53808 .78047 m .53721 .78313 L .54095 .78285 L F
.354 0 .058 r
.33032 .59974 m .32904 .60147 L .32685 .60178 L F
.488 .053 .138 r
.33246 .6005 m .32904 .60147 L .33032 .59974 L F
.669 .742 .905 r
.56333 .76864 m .56369 .76609 L .56085 .76686 L F
.859 .909 .866 r
.56333 .76864 m .56519 .76673 L .56369 .76609 L F
.462 .316 .595 r
.63204 .49453 m .63407 .49391 L .6339 .49153 L F
.564 .369 .575 r
.63167 .49677 m .63407 .49391 L .63204 .49453 L F
.976 .756 .54 r
.57065 .6096 m .57065 .61178 L .572 .61087 L F
.499 .297 .537 r
.57223 .6115 m .572 .61087 L .57065 .61178 L F
.57223 .6115 m .57065 .6096 L .572 .61087 L F
.098 .6 .898 r
.71307 .46202 m .71585 .46289 L .71385 .46319 L F
.788 .619 .671 r
.67046 .52041 m .66676 .52232 L .66923 .51941 L F
.67046 .52041 m .6698 .52345 L .66676 .52232 L F
.841 .847 .849 r
.67335 .51743 m .67046 .52041 L .66923 .51941 L F
0 0 0 r
.44503 .69716 m .44742 .69684 L .4491 .69649 L F
.278 0 0 r
.44742 .69684 m .451 .69692 L .4491 .69649 L F
.701 .538 .663 r
.57873 .60496 m .58206 .60485 L .58207 .60241 L F
.694 .532 .663 r
.58207 .60241 m .58206 .60485 L .58444 .60201 L F
.718 .53 .635 r
.57628 .60739 m .57873 .60496 L .57626 .60503 L F
.843 .626 .609 r
.59144 .7098 m .591 .71237 L .59388 .71249 L F
.809 .737 .784 r
.58951 .71468 m .59388 .71249 L .591 .71237 L F
.212 .684 .939 r
.32718 .58569 m .33236 .58617 L .33384 .58688 L F
.31 .731 .974 r
.33236 .58617 m .33591 .58691 L .33384 .58688 L F
.566 .671 .909 r
.69763 .49125 m .69663 .49399 L .69515 .49254 L F
.69763 .49125 m .6989 .49365 L .69663 .49399 L F
.089 0 0 r
.52156 .69231 m .5231 .69223 L .52427 .69035 L F
.509 .085 .172 r
.52427 .69035 m .5231 .69223 L .52641 .69135 L F
.422 .206 .478 r
.2633 .60216 m .26519 .60164 L .26556 .59932 L F
.459 .342 .633 r
.2633 .60216 m .26533 .60403 L .26519 .60164 L F
.2633 .60216 m .26356 .60466 L .26533 .60403 L F
.309 0 0 r
.57059 .59171 m .56951 .59229 L .56636 .59206 L F
.856 .973 .66 r
.57132 .58939 m .57059 .59171 L .57314 .59093 L F
.57132 .58939 m .56951 .59229 L .57059 .59171 L F
.454 .245 .505 r
.26591 .62765 m .26762 .62757 L .26817 .62479 L F
.713 .859 .951 r
.70044 .47625 m .70474 .47558 L .70349 .4741 L F
.686 .609 .764 r
.6698 .52345 m .67144 .52635 L .67367 .52545 L F
.711 .236 .12 r
.50944 .70432 m .5079 .70556 L .50559 .70353 L F
.463 0 .04 r
.51184 .70411 m .5079 .70556 L .50944 .70432 L F
.715 .728 .861 r
.6883 .49918 m .68611 .5002 L .68483 .49769 L F
0 0 .128 r
.5709 .65477 m .57034 .65611 L .56998 .65571 L F
.632 .787 .956 r
.44726 .6662 m .4484 .66764 L .45055 .66668 L F
.326 .306 .683 r
.70843 .47948 m .71083 .48186 L .71134 .48065 L F
.521 0 0 r
.70843 .47948 m .7102 .48052 L .71134 .48065 L F
.595 .678 .899 r
.71259 .47674 m .71134 .48065 L .70944 .47706 L F
.71259 .47674 m .71404 .48008 L .71134 .48065 L F
.43 .491 .822 r
.40797 .6987 m .40944 .69695 L .40698 .69711 L F
.40797 .6987 m .41123 .70048 L .40944 .69695 L F
.554 .213 .345 r
.4418 .66704 m .43894 .66923 L .43953 .6676 L F
.672 .378 .466 r
.50431 .77999 m .50813 .77967 L .50798 .77757 L F
.654 .476 .63 r
.58206 .60485 m .58462 .60463 L .58444 .60201 L F
.63 .443 .611 r
.58462 .60463 m .58692 .60155 L .58444 .60201 L F
.446 .077 .243 r
.35808 .63298 m .35724 .6351 L .35498 .63537 L F
.288 0 .174 r
.35927 .63441 m .35808 .63298 L .35989 .6326 L F
.35927 .63441 m .35724 .6351 L .35808 .63298 L F
.792 .681 .742 r
.68862 .51388 m .68647 .51684 L .68981 .51726 L F
.793 .678 .738 r
.68647 .51684 m .68766 .52009 L .68981 .51726 L F
.731 .585 .692 r
.68981 .51726 m .68766 .52009 L .68981 .51983 L F
.829 .739 .765 r
.50208 .69862 m .50059 .69947 L .49909 .69782 L F
.27 0 .225 r
.50003 .70066 m .50095 .70099 L .50208 .69862 L F
.433 .108 .313 r
.50208 .69862 m .50095 .70099 L .50387 .69969 L F
.017 0 0 r
.30558 .64745 m .30378 .64802 L .3019 .64834 L F
0 .203 .725 r
.30558 .64745 m .30606 .64627 L .30378 .64802 L F
.30558 .64745 m .30757 .64944 L .30606 .64627 L F
.315 0 0 r
.53697 .65558 m .53682 .6558 L .53448 .6551 L F
0 0 0 r
.53861 .65396 m .53682 .6558 L .53697 .65558 L F
.649 .463 .619 r
.57763 .70665 m .58008 .7064 L .57997 .70408 L F
.682 .501 .634 r
.58008 .7064 m .58338 .70394 L .57997 .70408 L F
.255 .725 .943 r
.32334 .58496 m .32433 .58535 L .32077 .58488 L F
.369 .792 .973 r
.32571 .585 m .32433 .58535 L .32334 .58496 L F
.502 .786 .996 r
.2529 .65085 m .24976 .65033 L .25219 .64954 L F
.98 .729 .479 r
.25219 .64954 m .25344 .65299 L .2529 .65085 L F
.142 0 0 r
.50911 .78224 m .50569 .78341 L .50713 .78279 L F
.983 .702 .392 r
.65258 .50877 m .65272 .51135 L .6516 .51008 L F
.654 .183 .121 r
.65258 .50877 m .65419 .50876 L .65391 .50783 L F
.65258 .50877 m .65504 .51039 L .65419 .50876 L F
.65258 .50877 m .6516 .51008 L .65504 .51039 L F
.942 .834 .708 r
.62887 .55541 m .63182 .55322 L .6302 .55042 L F
.62887 .55541 m .63016 .55638 L .63182 .55322 L F
.419 .347 .669 r
.7526 .49638 m .75071 .50028 L .75056 .4969 L F
.7526 .49638 m .75326 .49904 L .75071 .50028 L F
.426 .254 .544 r
.75349 .50198 m .75071 .50028 L .75326 .49904 L F
.75349 .50198 m .75088 .5027 L .75071 .50028 L F
.809 .67 .711 r
.6501 .48788 m .65288 .48995 L .65327 .48946 L F
.323 .643 .967 r
.54407 .79459 m .54115 .79318 L .54248 .79412 L F
.842 .89 .874 r
.54156 .79677 m .54407 .79459 L .54248 .79412 L F
.538 .369 .6 r
.5857 .62177 m .58347 .62471 L .5835 .62251 L F
.111 0 0 r
.5385 .79975 m .54156 .79677 L .5408 .79722 L F
.842 .89 .874 r
.54156 .79677 m .54248 .79412 L .54222 .79507 L F
.833 .971 .658 r
.5408 .79722 m .54156 .79677 L .54222 .79507 L F
.614 .518 .721 r
.26285 .61293 m .26342 .61633 L .2658 .61589 L F
.274 .477 .875 r
.38373 .59414 m .38307 .59577 L .38102 .59355 L F
.38373 .59414 m .38459 .59591 L .38307 .59577 L F
.668 .494 .641 r
.68023 .49211 m .6819 .4926 L .68276 .49048 L F
.746 .794 .891 r
.65272 .51135 m .65614 .51154 L .65504 .51039 L F
.73 .86 .942 r
.65504 .51039 m .65614 .51154 L .6583 .51025 L F
0 0 0 r
.60787 .58522 m .60899 .58374 L .60938 .58212 L F
0 0 .053 r
.60686 .5872 m .60899 .58374 L .60787 .58522 L F
.551 0 0 r
.49402 .70162 m .49277 .70226 L .49046 .70093 L F
.246 0 0 r
.49608 .70229 m .49277 .70226 L .49402 .70162 L F
.584 .414 .617 r
.35929 .61288 m .36149 .60997 L .3594 .6105 L F
.489 .265 .5 r
.60899 .60506 m .60869 .60725 L .60643 .6078 L F
.229 0 .209 r
.61162 .60267 m .61058 .6046 L .60899 .60506 L F
.456 .285 .56 r
.61058 .6046 m .60869 .60725 L .60899 .60506 L F
.371 0 .072 r
.64405 .48781 m .64645 .48803 L .64712 .48668 L F
.582 .14 .166 r
.64712 .48668 m .64645 .48803 L .6501 .48788 L F
.827 .888 .886 r
.748 .52883 m .74803 .53081 L .74664 .53089 L F
.748 .321 .237 r
.74664 .53089 m .74803 .53081 L .74737 .53209 L F
0 .132 .66 r
.748 .52883 m .7487 .53093 L .74803 .53081 L F
.072 0 0 r
.74803 .53081 m .7487 .53093 L .74737 .53209 L F
.505 .276 .5 r
.60869 .60725 m .60609 .60989 L .60643 .6078 L F
.555 .758 .972 r
.42081 .70921 m .4222 .71082 L .42486 .71026 L F
.953 .718 .546 r
.57413 .63847 m .57428 .6411 L .57499 .63978 L F
.612 .4 .57 r
.57428 .6411 m .57851 .63964 L .57499 .63978 L F
.838 .554 .508 r
.55402 .74645 m .55384 .74868 L .55689 .74917 L F
.699 .205 .069 r
.55384 .74868 m .55626 .75068 L .55689 .74917 L F
.889 .466 .163 r
.55626 .75068 m .5577 .75148 L .55689 .74917 L F
.004 0 .307 r
.26817 .62479 m .26899 .6261 L .27031 .62525 L F
.26817 .62479 m .26762 .62757 L .26899 .6261 L F
.367 0 .134 r
.6769 .47465 m .67924 .4742 L .68012 .47247 L F
.235 0 .071 r
.68012 .47247 m .68242 .472 L .68232 .4714 L F
.68012 .47247 m .67924 .4742 L .68242 .472 L F
.391 .081 .316 r
.60446 .53354 m .60663 .533 L .60648 .5311 L F
.459 .291 .565 r
.60648 .5311 m .60933 .53059 L .60924 .52805 L F
.497 .155 .317 r
.60648 .5311 m .60911 .53258 L .60933 .53059 L F
.60648 .5311 m .60663 .533 L .60911 .53258 L F
.483 .266 .508 r
.40648 .66442 m .40861 .66401 L .40886 .66153 L F
.577 .346 .53 r
.40886 .66153 m .40861 .66401 L .41104 .66359 L F
.6 .344 .501 r
.40886 .66153 m .41104 .66359 L .41139 .66139 L F
.622 .446 .624 r
.61336 .51677 m .61336 .51971 L .61573 .51689 L F
.744 .676 .785 r
.57374 .64458 m .57624 .64459 L .57428 .6411 L F
.624 .626 .832 r
.57428 .6411 m .57624 .64459 L .57807 .64331 L F
0 .327 .806 r
.70843 .47948 m .7102 .48052 L .70931 .4791 L F
.44 .153 .379 r
.37764 .62063 m .37603 .61921 L .3782 .61869 L F
.37764 .62063 m .37546 .62117 L .37603 .61921 L F
.654 .215 .195 r
.52998 .69135 m .53205 .69194 L .53023 .69046 L F
.434 .248 .527 r
.26519 .60164 m .26729 .59862 L .26556 .59932 L F
.888 .585 .467 r
.57352 .65881 m .57294 .66099 L .5709 .65743 L F
.636 .312 .406 r
.57511 .66042 m .57294 .66099 L .57352 .65881 L F
.539 .54 .804 r
.42892 .69172 m .42807 .69515 L .4268 .69204 L F
.42892 .69172 m .43016 .69495 L .42807 .69515 L F
.066 0 0 r
.73879 .51428 m .74234 .51263 L .74098 .51084 L F
.733 .763 .877 r
.74098 .51084 m .74234 .51263 L .74431 .51128 L F
.854 .997 .808 r
.66776 .50188 m .66605 .50499 L .6688 .50286 L F
.66776 .50188 m .66536 .50464 L .66605 .50499 L F
.896 .908 .825 r
.65858 .52303 m .66008 .51878 L .6605 .52039 L F
.65858 .52303 m .65746 .52218 L .66008 .51878 L F
.358 .737 .988 r
.66134 .52314 m .65746 .52218 L .65858 .52303 L F
.571 .455 .683 r
.54033 .77716 m .54223 .77467 L .53923 .77454 L F
.54033 .77716 m .5426 .77737 L .54223 .77467 L F
.116 0 .045 r
.62975 .49776 m .62912 .49885 L .63167 .49677 L F
.614 .518 .721 r
.26285 .61293 m .2658 .61589 L .26438 .61245 L F
.415 .194 .467 r
.58978 .54779 m .59194 .54494 L .59006 .54557 L F
.841 .847 .849 r
.67335 .51743 m .66923 .51941 L .67171 .51645 L F
.688 .644 .801 r
.4963 .64929 m .49908 .64681 L .49791 .64781 L F
.842 .994 .746 r
.72698 .5116 m .72438 .51492 L .7239 .51456 L F
0 .358 .771 r
.72438 .51492 m .72607 .51539 L .7239 .51456 L F
.72438 .51492 m .7271 .51618 L .72607 .51539 L F
.765 .595 .668 r
.58934 .70377 m .58923 .70651 L .59287 .70679 L F
.815 .673 .706 r
.58913 .70907 m .59287 .70679 L .58923 .70651 L F
.58913 .70907 m .59144 .7098 L .59287 .70679 L F
.626 .401 .556 r
.46154 .65874 m .46108 .66102 L .45843 .66122 L F
.594 .506 .724 r
.463 .65823 m .46108 .66102 L .46154 .65874 L F
.954 .688 .493 r
.75382 .51404 m .75027 .514 L .75143 .51344 L F
.876 .921 .853 r
.75209 .51546 m .75159 .51501 L .75194 .51462 L F
.954 .688 .493 r
.75382 .51404 m .75344 .5144 L .75027 .514 L F
.832 .752 .775 r
.75194 .51462 m .74823 .51878 L .74553 .51555 L F
.954 .688 .493 r
.75344 .5144 m .75229 .51549 L .75119 .51467 L F
.46 .782 .998 r
.75229 .51549 m .75235 .51693 L .75194 .51462 L F
.805 .321 0 r
.75188 .51459 m .75229 .51549 L .75194 .51462 L F
.954 .688 .493 r
.7517 .51418 m .75119 .51467 L .75027 .514 L F
.75188 .51459 m .75119 .51467 L .7517 .51418 L F
.832 .752 .775 r
.75121 .5147 m .74553 .51555 L .7462 .51528 L F
.75194 .51462 m .75123 .51472 L .75121 .5147 L F
.75123 .51472 m .74553 .51555 L .75121 .5147 L F
0 .16 .631 r
.75019 .51377 m .75054 .51406 L .75016 .5137 L F
.832 .752 .775 r
.75188 .51459 m .75119 .51467 L .75016 .5137 L F
0 .16 .631 r
.75027 .514 m .75119 .51467 L .75019 .51377 L F
.75119 .51467 m .75095 .51445 L .75019 .51377 L F
.832 .752 .775 r
.75119 .51467 m .7462 .51528 L .75016 .5137 L F
0 .16 .631 r
.75119 .51467 m .75129 .51475 L .75095 .51445 L F
.832 .752 .775 r
.75194 .51462 m .75121 .5147 L .75188 .51459 L F
.75121 .5147 m .7462 .51528 L .75119 .51467 L F
.75121 .5147 m .75119 .51467 L .75188 .51459 L F
0 .16 .631 r
.75129 .51475 m .75229 .51549 L .75054 .51406 L F
.75095 .51445 m .75054 .51406 L .75019 .51377 L F
.75129 .51475 m .75054 .51406 L .75095 .51445 L F
.75054 .51406 m .75229 .51549 L .75016 .5137 L F
.805 .321 0 r
.75016 .5137 m .75229 .51549 L .75188 .51459 L F
.954 .688 .493 r
.75344 .5144 m .75188 .51459 L .7517 .51418 L F
.876 .921 .853 r
.75235 .51693 m .74823 .51878 L .75159 .51501 L F
.75235 .51693 m .75159 .51501 L .75209 .51546 L F
.75235 .51693 m .74912 .51976 L .74823 .51878 L F
.776 .643 .715 r
.75235 .51693 m .75109 .52025 L .74912 .51976 L F
.46 .782 .998 r
.75229 .51549 m .75388 .51638 L .75235 .51693 L F
.412 .249 .548 r
.75437 .51875 m .75235 .51693 L .75388 .51638 L F
.75437 .51875 m .75109 .52025 L .75235 .51693 L F
.274 0 0 r
.51813 .69429 m .52025 .69393 L .52156 .69231 L F
.074 0 0 r
.52156 .69231 m .52025 .69393 L .5231 .69223 L F
.154 0 0 r
.34205 .6267 m .34343 .62681 L .34484 .62505 L F
.208 0 0 r
.34484 .62505 m .34556 .62619 L .34699 .62453 L F
.34484 .62505 m .34343 .62681 L .34556 .62619 L F
.968 .734 .53 r
.63003 .55872 m .63143 .55973 L .63016 .55638 L F
.911 .787 .711 r
.63003 .55872 m .63065 .5619 L .63143 .55973 L F
.493 .504 .797 r
.71292 .48374 m .71273 .48695 L .7135 .48426 L F
.71083 .48186 m .71273 .48695 L .71292 .48374 L F
.958 .872 .469 r
.71317 .48622 m .71274 .4867 L .71273 .48695 L F
.71274 .4867 m .71231 .48718 L .71273 .48695 L F
.983 .833 .442 r
.71307 .48689 m .71281 .48857 L .71231 .48718 L F
.288 .282 .679 r
.71333 .4899 m .71421 .48924 L .71231 .48718 L F
.67 .742 .243 r
.71286 .48647 m .71326 .48542 L .7135 .48426 L F
.71273 .48695 m .71326 .48542 L .71286 .48647 L F
.289 .652 .969 r
.71352 .48475 m .71326 .48542 L .71198 .4849 L F
.604 .444 .637 r
.71326 .48542 m .71558 .48587 L .71517 .483 L F
.289 .652 .969 r
.71455 .48464 m .71326 .48542 L .71352 .48475 L F
.708 .307 .286 r
.71231 .48718 m .71229 .48757 L .71176 .48784 L F
.71151 .48775 m .71176 .48784 L .71047 .48848 L F
.71231 .48718 m .71176 .48784 L .71151 .48775 L F
.761 .356 .286 r
.71226 .48801 m .71233 .48804 L .71231 .48718 L F
.481 .652 .934 r
.71226 .48801 m .71233 .48804 L .71232 .48803 L F
.288 .282 .679 r
.71237 .48792 m .71248 .48763 L .71231 .48718 L F
.939 .573 .192 r
.71231 .48718 m .71233 .48804 L .71248 .48763 L F
.708 .307 .286 r
.71165 .48789 m .71205 .4888 L .71047 .48848 L F
.71255 .48744 m .71233 .48803 L .71165 .48789 L F
.658 .7 .877 r
.71233 .48803 m .71233 .48804 L .71232 .48803 L F
.708 .307 .286 r
.71233 .48803 m .71205 .4888 L .71165 .48789 L F
.779 .414 .365 r
.71231 .48718 m .71047 .48848 L .70854 .48634 L F
.761 .356 .286 r
.71103 .4869 m .71226 .48797 L .71231 .48718 L F
.70854 .48634 m .71226 .48797 L .71103 .4869 L F
.70854 .48634 m .71226 .48801 L .71226 .48797 L F
.708 .307 .286 r
.71231 .48718 m .71255 .48744 L .71229 .48757 L F
.939 .573 .192 r
.71231 .48718 m .71248 .48763 L .71269 .48704 L F
.71231 .48718 m .71269 .48704 L .71273 .48695 L F
.658 .7 .877 r
.71326 .48542 m .71233 .48803 L .70898 .48511 L F
.71233 .48803 m .71232 .48803 L .70898 .48511 L F
.481 .652 .934 r
.70854 .48634 m .71226 .48801 L .70898 .48511 L F
.71226 .48801 m .71232 .48803 L .70898 .48511 L F
.67 .742 .243 r
.71233 .48803 m .71233 .48804 L .71233 .48803 L F
.288 .282 .679 r
.7126 .49045 m .71333 .4899 L .71248 .48763 L F
.7126 .49045 m .71248 .48763 L .71237 .48792 L F
.708 .307 .286 r
.71255 .48744 m .71421 .48924 L .71205 .4888 L F
.67 .742 .243 r
.71305 .48602 m .71233 .48803 L .71326 .48542 L F
.71233 .48803 m .71233 .48803 L .71326 .48542 L F
.983 .833 .442 r
.71317 .48622 m .71307 .48689 L .71269 .48704 L F
.71287 .48656 m .71269 .48704 L .71231 .48718 L F
.67 .742 .243 r
.71273 .48695 m .71269 .48704 L .71274 .48692 L F
.983 .833 .442 r
.71317 .48622 m .71269 .48704 L .71287 .48656 L F
.67 .742 .243 r
.71274 .48692 m .71248 .48763 L .71305 .48602 L F
.71269 .48704 m .71248 .48763 L .71274 .48692 L F
.71248 .48763 m .71233 .48804 L .71305 .48602 L F
.521 .204 .37 r
.43303 .6552 m .4363 .65229 L .43348 .6535 L F
.756 .674 .771 r
.48821 .65213 m .48664 .65312 L .48874 .65016 L F
.901 .879 .804 r
.70743 .49175 m .7047 .49379 L .70756 .49254 L F
.974 .824 .411 r
.73276 .48871 m .73189 .48988 L .73191 .48775 L F
.73276 .48871 m .73241 .49144 L .73189 .48988 L F
0 .384 .822 r
.72793 .51731 m .72993 .51774 L .7271 .51618 L F
.72793 .51731 m .73072 .5187 L .72993 .51774 L F
0 .115 .59 r
.72793 .51731 m .73163 .52035 L .73072 .5187 L F
.508 .033 .063 r
.46767 .70169 m .46603 .7032 L .46386 .70286 L F
.502 .026 .058 r
.46963 .70269 m .46603 .7032 L .46767 .70169 L F
.788 .739 .807 r
.69547 .50506 m .69905 .50402 L .69784 .50236 L F
.698 .709 .857 r
.69784 .50236 m .69905 .50402 L .70126 .50298 L F
.412 .256 .557 r
.75244 .49401 m .7526 .49638 L .75056 .4969 L F
.718 .548 .659 r
.68766 .5224 m .68981 .51983 L .68766 .52009 L F
.68766 .5224 m .69134 .5231 L .68981 .51983 L F
.471 0 0 r
.56412 .65873 m .56345 .65934 L .56073 .65818 L F
.564 0 0 r
.56412 .65873 m .56637 .6602 L .56345 .65934 L F
.524 .208 .374 r
.56743 .65831 m .56637 .6602 L .56412 .65873 L F
.574 .402 .61 r
.40648 .66442 m .40888 .66648 L .40861 .66401 L F
.40648 .66442 m .40657 .6669 L .40888 .66648 L F
.283 0 .203 r
.26733 .59623 m .26945 .5956 L .27017 .59375 L F
.48 .127 .29 r
.27017 .59375 m .26945 .5956 L .27171 .59511 L F
.453 .133 .332 r
.27017 .59375 m .27171 .59511 L .27244 .5933 L F
0 0 0 r
.33881 .64368 m .34252 .64161 L .3409 .64308 L F
.051 0 0 r
.3409 .64308 m .34252 .64161 L .34457 .64087 L F
.503 .584 .869 r
.70956 .50215 m .71089 .50494 L .71311 .50473 L F
.587 .634 .865 r
.53029 .64305 m .52902 .64538 L .52806 .6438 L F
.53029 .64305 m .5316 .64486 L .52902 .64538 L F
.48 .592 .888 r
.53188 .64672 m .52902 .64538 L .5316 .64486 L F
.502 .257 .475 r
.38798 .6099 m .38543 .61301 L .38573 .61044 L F
.636 .65 .847 r
.69845 .47676 m .69986 .47339 L .69741 .47402 L F
.69845 .47676 m .70044 .47625 L .69986 .47339 L F
.518 .116 .217 r
.47213 .69579 m .47409 .69692 L .47593 .69492 L F
.354 0 0 r
.47409 .69692 m .47766 .69568 L .47593 .69492 L F
.701 .43 .51 r
.54117 .68714 m .54063 .68963 L .54402 .68958 L F
.481 0 0 r
.45661 .69675 m .45898 .69699 L .46046 .69573 L F
.438 0 0 r
.45898 .69699 m .46287 .69587 L .46046 .69573 L F
.626 .677 .878 r
.30991 .62736 m .30604 .62526 L .30849 .62587 L F
.646 .75 .925 r
.31234 .62666 m .30991 .62736 L .30849 .62587 L F
.523 .637 .904 r
.71363 .50661 m .71539 .50455 L .71311 .50473 L F
.71363 .50661 m .71678 .50739 L .71539 .50455 L F
.494 .735 .98 r
.27155 .64657 m .27291 .64791 L .27538 .64758 L F
.353 .572 .922 r
.32015 .62824 m .31954 .62976 L .31761 .62789 L F
.32015 .62824 m .32125 .62985 L .31954 .62976 L F
.134 .231 .7 r
.7519 .50478 m .75165 .50642 L .75088 .5027 L F
.361 .476 .842 r
.7535 .50481 m .75165 .50642 L .7519 .50478 L F
.681 .185 .061 r
.75165 .50642 m .7553 .50803 L .75285 .50877 L F
.032 0 .072 r
.7553 .50803 m .7533 .51068 L .75285 .50877 L F
.75418 .50951 m .75532 .5086 L .7533 .51068 L F
.111 0 .074 r
.7553 .50803 m .75532 .5086 L .75729 .50736 L F
.7553 .50803 m .75532 .5086 L .75729 .50736 L F
.62 .622 .832 r
.75729 .50736 m .75532 .5086 L .75708 .50722 L F
.449 .858 .691 r
.75681 .50763 m .75532 .5086 L .75729 .50736 L F
.032 0 .072 r
.7553 .50803 m .75532 .5086 L .75442 .5092 L F
.681 .185 .061 r
.75498 .50788 m .75532 .5086 L .7553 .50803 L F
.75165 .50642 m .75532 .5086 L .75498 .50788 L F
.62 .622 .832 r
.75708 .50722 m .75532 .5086 L .7535 .50481 L F
.361 .476 .842 r
.7535 .50481 m .75511 .50817 L .75165 .50642 L F
.75511 .50817 m .75532 .5086 L .75473 .50825 L F
.75511 .50817 m .75473 .50825 L .75165 .50642 L F
.449 .858 .691 r
.75412 .50915 m .75532 .5086 L .75681 .50763 L F
.75412 .50915 m .75634 .5079 L .75634 .50846 L F
.75634 .5079 m .75729 .50736 L .75694 .50777 L F
.75634 .5079 m .75694 .50777 L .75634 .50846 L F
.032 0 .072 r
.75442 .5092 m .75532 .5086 L .75418 .50951 L F
.463 .831 .992 r
.30529 .58354 m .30795 .58311 L .30947 .5838 L F
.284 0 0 r
.30795 .58311 m .31153 .58361 L .30947 .5838 L F
.635 .617 .815 r
.53214 .69447 m .5311 .69731 L .53144 .69584 L F
.224 .068 .448 r
.29187 .64128 m .28953 .64644 L .29172 .64411 L F
.546 .538 .797 r
.29042 .64691 m .29172 .64411 L .28953 .64644 L F
.537 .366 .597 r
.60904 .5256 m .61132 .52513 L .61115 .5227 L F
.507 .33 .575 r
.60924 .52805 m .61132 .52513 L .60904 .5256 L F
.85 .826 .824 r
.49427 .79724 m .4971 .79463 L .49542 .79349 L F
.471 .166 .367 r
.43033 .67876 m .42979 .68069 L .4275 .68093 L F
.606 .294 .414 r
.43248 .68046 m .42979 .68069 L .43033 .67876 L F
.478 .332 .604 r
.43233 .67799 m .43248 .68046 L .43033 .67876 L F
.182 0 .181 r
.61255 .6033 m .61162 .60267 L .61287 .60091 L F
.61255 .6033 m .61058 .6046 L .61162 .60267 L F
.583 .845 .994 r
.47698 .81461 m .48071 .81478 L .47925 .81427 L F
.599 .894 .989 r
.47925 .81427 m .48071 .81478 L .48275 .81397 L F
.253 .284 .7 r
.75003 .48553 m .75085 .48538 L .75183 .48441 L F
.385 0 .177 r
.75184 .48442 m .75175 .48448 L .75183 .48441 L F
.75175 .48448 m .75003 .48553 L .75183 .48441 L F
.447 .599 .909 r
.75183 .48441 m .75085 .48538 L .75078 .48529 L F
.385 0 .177 r
.75072 .48533 m .75003 .48553 L .75184 .48442 L F
.447 .599 .909 r
.75183 .48441 m .75078 .48529 L .74848 .48226 L F
.442 .596 .909 r
.74848 .48226 m .75078 .48529 L .74698 .48392 L F
.75078 .48529 m .75085 .48538 L .75072 .48533 L F
.75078 .48529 m .75072 .48533 L .74698 .48392 L F
.385 0 .177 r
.75192 .48497 m .75072 .48533 L .75184 .48442 L F
.57 .637 .879 r
.75003 .48553 m .75072 .48533 L .75085 .48538 L F
.385 0 .177 r
.75222 .48697 m .75003 .48553 L .75192 .48497 L F
.57 .637 .879 r
.75003 .48553 m .74698 .48392 L .75072 .48533 L F
.385 0 .177 r
.75222 .48697 m .75091 .48638 L .75003 .48553 L F
.539 0 0 r
.27145 .62939 m .27019 .62921 L .26762 .62757 L F
.813 .937 .911 r
.27239 .62639 m .27185 .62794 L .27414 .62707 L F
.884 .989 .802 r
.27239 .62639 m .27145 .62939 L .27185 .62794 L F
.27239 .62639 m .27019 .62921 L .27145 .62939 L F
.631 .68 .878 r
.27145 .62939 m .27463 .62775 L .27185 .62794 L F
.649 .868 .982 r
.71151 .46823 m .71025 .46698 L .70779 .46803 L F
.305 .573 .934 r
.71151 .46823 m .71187 .46643 L .71025 .46698 L F
.71151 .46823 m .71319 .46816 L .71187 .46643 L F
.572 .305 .473 r
.5105 .64923 m .50855 .64983 L .50903 .64784 L F
.558 .782 .982 r
.56453 .59801 m .56594 .5997 L .56223 .59851 L F
.995 .754 .441 r
.56594 .5997 m .56453 .59801 L .56223 .59851 L F
.56594 .5997 m .5655 .60128 L .56453 .59801 L F
.609 .656 .871 r
.56706 .59546 m .56594 .5997 L .56453 .59801 L F
.56706 .59546 m .56877 .59863 L .56594 .5997 L F
.253 0 0 r
.34193 .60011 m .34035 .60015 L .33791 .5996 L F
.521 .204 .37 r
.43303 .6552 m .43538 .65499 L .4363 .65229 L F
.495 .185 .371 r
.43538 .65499 m .4386 .65201 L .4363 .65229 L F
.489 .039 .107 r
.68264 .47846 m .68113 .47701 L .68347 .47669 L F
.68264 .47846 m .68017 .4787 L .68113 .47701 L F
.482 .264 .506 r
.58511 .55118 m .58743 .55068 L .58749 .54833 L F
.456 .218 .464 r
.58952 .54993 m .58749 .54833 L .58743 .55068 L F
.58952 .54993 m .58978 .54779 L .58749 .54833 L F
.563 .369 .576 r
.54472 .75771 m .54516 .76102 L .54312 .7593 L F
0 0 0 r
.54312 .7593 m .54418 .7592 L .54472 .75771 L F
.712 .532 .645 r
.5447 .7615 m .54312 .7593 L .54516 .76102 L F
.5447 .7615 m .54138 .76013 L .54312 .7593 L F
0 0 0 r
.54312 .7593 m .54138 .76013 L .54418 .7592 L F
.263 0 0 r
.33621 .59923 m .33455 .60038 L .33246 .6005 L F
.418 0 0 r
.33791 .5996 m .33455 .60038 L .33621 .59923 L F
.863 .919 .865 r
.47389 .6337 m .47388 .63126 L .47609 .63099 L F
.47389 .6337 m .47258 .63273 L .47388 .63126 L F
.502 .557 .844 r
.37081 .75773 m .37304 .75767 L .372 .75534 L F
.372 .75534 m .37304 .75767 L .37081 .75773 L F
.37081 .75773 m .37304 .75767 L .372 .75534 L F
.917 .519 .169 r
.73327 .51817 m .73386 .51707 L .73252 .51599 L F
.817 .848 .872 r
.73252 .51599 m .73386 .51707 L .73645 .51502 L F
.916 .517 .168 r
.73449 .51907 m .73386 .51707 L .73327 .51817 L F
.472 .047 .152 r
.44088 .65182 m .44327 .6517 L .44455 .64979 L F
.518 .145 .273 r
.44327 .6517 m .44678 .64936 L .44455 .64979 L F
.626 .353 .485 r
.58812 .60455 m .58991 .60223 L .58692 .60155 L F
.58812 .60455 m .59016 .60423 L .58991 .60223 L F
.692 .317 .333 r
.5926 .60446 m .58991 .60223 L .59016 .60423 L F
.757 .66 .755 r
.58242 .71513 m .58583 .71563 L .58559 .71495 L F
.654 .64 .824 r
.58583 .71563 m .58695 .71185 L .58559 .71495 L F
.58583 .71563 m .5882 .71504 L .58695 .71185 L F
.631 .517 .706 r
.58792 .71601 m .5882 .71504 L .58583 .71563 L F
.995 .834 .571 r
.65481 .48674 m .65469 .48471 L .65312 .48507 L F
0 0 0 r
.65312 .48507 m .65469 .48471 L .65575 .4829 L F
.65469 .48471 m .65488 .48467 L .65508 .48427 L F
.65469 .48471 m .65508 .48427 L .65575 .4829 L F
.995 .834 .571 r
.65481 .48674 m .65387 .4857 L .65393 .48557 L F
.65369 .48494 m .65465 .48403 L .65312 .48507 L F
.65469 .48471 m .65465 .48403 L .65369 .48494 L F
0 0 0 r
.65369 .48494 m .65483 .48478 L .65488 .48467 L F
.65312 .48507 m .6537 .48497 L .65369 .48494 L F
.6537 .48497 m .65483 .48478 L .65369 .48494 L F
.995 .834 .571 r
.65469 .48471 m .65393 .48557 L .65467 .4844 L F
.098 .05 .51 r
.65465 .48403 m .65483 .48478 L .65312 .48507 L F
0 0 0 r
.65465 .48403 m .65393 .48557 L .6553 .48341 L F
.65393 .48557 m .65387 .4857 L .65394 .48559 L F
.65393 .48557 m .65394 .48559 L .6553 .48341 L F
.686 .412 .502 r
.65732 .48075 m .65483 .48478 L .65465 .48403 L F
0 0 0 r
.65465 .48403 m .6553 .48341 L .65575 .48268 L F
.995 .834 .571 r
.65481 .48674 m .65393 .48557 L .65469 .48471 L F
.3 0 .101 r
.54402 .68958 m .54101 .69126 L .5418 .69009 L F
.866 .595 .527 r
.56205 .76248 m .56388 .76048 L .56197 .76006 L F
.56205 .76248 m .56414 .76317 L .56388 .76048 L F
.653 .862 .979 r
.27538 .64758 m .27913 .64765 L .27741 .64589 L F
.638 .491 .667 r
.56996 .7121 m .57218 .70919 L .56957 .70955 L F
.527 .292 .502 r
.52175 .77461 m .5242 .77208 L .52198 .77229 L F
.52175 .77461 m .52427 .77446 L .5242 .77208 L F
.598 .347 .507 r
.5242 .77208 m .52427 .77446 L .5266 .77351 L F
.826 .437 .315 r
.55028 .78261 m .55333 .7835 L .54979 .78318 L F
.795 .357 .207 r
.55125 .78331 m .55333 .7835 L .55028 .78261 L F
.718 .624 .752 r
.55034 .78067 m .55225 .77803 L .54849 .77735 L F
0 .065 .626 r
.55059 .77934 m .55175 .78224 L .55034 .78067 L F
.55175 .78224 m .55155 .78243 L .55034 .78067 L F
.5522 .78338 m .55201 .78337 L .55034 .78067 L F
0 0 0 r
.5545 .7833 m .55556 .78291 L .55333 .7835 L F
.55333 .7835 m .55556 .78291 L .55411 .78337 L F
.5545 .7833 m .55333 .7835 L .55256 .78426 L F
.55333 .7835 m .55411 .78337 L .5537 .78348 L F
.552 .559 .815 r
.55407 .78351 m .5522 .78338 L .55059 .77934 L F
0 0 0 r
.5537 .78348 m .55411 .78337 L .55378 .78348 L F
.552 .559 .815 r
.5545 .7833 m .55407 .78351 L .55399 .78341 L F
.55447 .78328 m .55399 .78341 L .55059 .77934 L F
.5545 .7833 m .55399 .78341 L .55411 .78337 L F
0 0 0 r
.55378 .78348 m .55411 .78337 L .5545 .7833 L F
.55411 .78337 m .55556 .78291 L .5545 .7833 L F
.552 .559 .815 r
.5545 .7833 m .55411 .78337 L .55447 .78328 L F
0 0 0 r
.55333 .7835 m .5537 .78348 L .55272 .78341 L F
.55333 .7835 m .5525 .78338 L .55193 .78337 L F
.795 .357 .207 r
.55256 .78426 m .55333 .7835 L .55125 .78331 L F
.552 .559 .815 r
.55407 .78351 m .55256 .78426 L .5522 .78338 L F
0 0 0 r
.55272 .78341 m .55378 .78348 L .5525 .78338 L F
.5537 .78348 m .55378 .78348 L .55272 .78341 L F
.594 .677 .899 r
.54979 .78318 m .55211 .7819 L .55096 .78244 L F
.552 .559 .815 r
.5545 .7833 m .55059 .77934 L .55302 .78139 L F
.594 .677 .899 r
.55211 .7819 m .55302 .78139 L .55221 .7818 L F
.55211 .7819 m .55221 .7818 L .55096 .78244 L F
0 .065 .626 r
.55175 .78224 m .5522 .78338 L .55155 .78243 L F
.5522 .78338 m .55256 .78426 L .55201 .78337 L F
0 0 0 r
.55193 .78337 m .5525 .78338 L .55004 .7832 L F
.55333 .7835 m .55004 .7832 L .54979 .78318 L F
.366 0 0 r
.73747 .52075 m .73721 .52054 L .73449 .51907 L F
0 .018 .518 r
.73747 .52075 m .7385 .5218 L .73721 .52054 L F
.796 .976 .906 r
.27796 .63942 m .27764 .64169 L .27936 .63973 L F
.305 .54 .913 r
.27796 .63942 m .27986 .64216 L .27764 .64169 L F
.676 .542 .695 r
.28028 .64423 m .27764 .64169 L .27986 .64216 L F
.28028 .64423 m .27716 .64524 L .27764 .64169 L F
.95 .949 .644 r
.72677 .48796 m .72721 .48577 L .72608 .48715 L F
.987 .885 .632 r
.72507 .49072 m .72677 .48796 L .72608 .48715 L F
.72507 .49072 m .72588 .49167 L .72677 .48796 L F
.7 .658 .806 r
.47808 .77697 m .48296 .77861 L .47988 .77742 L F
.316 0 0 r
.48328 .77714 m .47988 .77742 L .48296 .77861 L F
.842 .994 .746 r
.72698 .5116 m .7239 .51456 L .72623 .51058 L F
.892 .938 .837 r
.72929 .50869 m .72698 .5116 L .72623 .51058 L F
.834 .701 .717 r
.27414 .62707 m .27185 .62794 L .27463 .62775 L F
.615 .642 .854 r
.27414 .62707 m .27463 .62775 L .27631 .62703 L F
.697 .393 .457 r
.4868 .79699 m .4855 .79415 L .48237 .7945 L F
.913 .817 .349 r
.60981 .57592 m .60959 .57513 L .61032 .57355 L F
.938 .902 .51 r
.61032 .57355 m .60999 .57296 L .61106 .56932 L F
.931 .811 .351 r
.61032 .57355 m .60959 .57513 L .60999 .57296 L F
.931 .553 .243 r
.55932 .65027 m .55846 .65133 L .55827 .64926 L F
.55932 .65027 m .55989 .65238 L .55846 .65133 L F
0 0 0 r
.43297 .70932 m .43185 .71045 L .43131 .70977 L F
.836 .59 .567 r
.5574 .75396 m .56041 .75202 L .5577 .75148 L F
.5574 .75396 m .5604 .75462 L .56041 .75202 L F
.931 .571 .312 r
.56858 .60467 m .56938 .60673 L .57023 .6059 L F
.701 .217 .094 r
.56938 .60673 m .57166 .60719 L .57023 .6059 L F
.682 .34 .389 r
.59736 .55916 m .59794 .56131 L .59557 .56104 L F
.549 .298 .488 r
.60112 .55671 m .60103 .55865 L .59736 .55916 L F
.568 .271 .424 r
.60245 .56011 m .59736 .55916 L .60103 .55865 L F
.60245 .56011 m .59794 .56131 L .59736 .55916 L F
.761 .254 0 r
.30123 .64749 m .30201 .64839 L .29839 .64615 L F
.827 .813 .837 r
.64472 .48591 m .64212 .48833 L .64405 .48781 L F
.691 .345 .385 r
.64212 .48833 m .6445 .49043 L .64405 .48781 L F
.421 .165 .418 r
.64405 .48781 m .6445 .49043 L .64645 .48803 L F
.773 .767 .848 r
.73456 .4799 m .73119 .4797 L .73366 .47734 L F
.883 .745 .705 r
.73456 .4799 m .73131 .482 L .73119 .4797 L F
.73456 .4799 m .73275 .48431 L .73131 .482 L F
.813 .787 .828 r
.73683 .47726 m .73456 .4799 L .73366 .47734 L F
.472 .246 .49 r
.58273 .5541 m .58503 .55346 L .58511 .55118 L F
.425 .124 .349 r
.58689 .55239 m .58511 .55118 L .58503 .55346 L F
.58689 .55239 m .58743 .55068 L .58511 .55118 L F
.614 .447 .632 r
.54873 .77481 m .5496 .77339 L .54822 .77485 L F
.54873 .77481 m .55093 .77207 L .5496 .77339 L F
.403 0 0 r
.29429 .58528 m .29577 .5861 L .2977 .58502 L F
0 0 0 r
.29577 .5861 m .29999 .58476 L .2977 .58502 L F
.61523 .59606 m .61442 .5978 L .61258 .59942 L F
.252 .204 .608 r
.61442 .5978 m .61287 .60091 L .61258 .59942 L F
.947 .874 .732 r
.57751 .58232 m .57453 .5853 L .57484 .58507 L F
.419 .168 .424 r
.35415 .61742 m .35681 .61512 L .35453 .61595 L F
.831 .418 .26 r
.41369 .70257 m .41123 .70048 L .41192 .70291 L F
.528 .378 .621 r
.30259 .72754 m .30201 .72969 L .29982 .73021 L F
.29982 .73021 m .30201 .72969 L .30259 .72754 L F
.579 .627 .863 r
.30091 .728 m .30201 .72969 L .29982 .73021 L F
.30091 .728 m .30201 .72969 L .29982 .73021 L F
.638 .491 .667 r
.56996 .7121 m .57323 .71232 L .57218 .70919 L F
.61 .473 .669 r
.56996 .7121 m .57312 .71485 L .57323 .71232 L F
.56996 .7121 m .57068 .71538 L .57312 .71485 L F
.718 .53 .635 r
.57628 .60739 m .57981 .60764 L .57873 .60496 L F
.699 .521 .644 r
.57873 .60496 m .57981 .60764 L .58206 .60485 L F
.528 .344 .576 r
.547 .75979 m .54516 .76102 L .54472 .75771 L F
.722 .252 .133 r
.54418 .7592 m .547 .75979 L .54472 .75771 L F
.578 .322 .493 r
.60112 .55671 m .60351 .55858 L .60103 .55865 L F
.602 .312 .449 r
.60384 .55671 m .60351 .55858 L .60112 .55671 L F
.658 .679 .859 r
.70126 .50298 m .70508 .50419 L .7036 .50229 L F
.701 .692 .838 r
.70508 .50419 m .70711 .50298 L .7036 .50229 L F
.755 .99 .781 r
.53832 .59833 m .53703 .59974 L .5379 .5981 L F
.651 .891 .983 r
.53703 .59974 m .53569 .59904 L .5379 .5981 L F
.421 .775 .996 r
.37035 .58982 m .36966 .5909 L .36821 .58994 L F
.37035 .58982 m .37177 .59066 L .36966 .5909 L F
.707 .602 .737 r
.26161 .64993 m .26278 .65353 L .26475 .65249 L F
.63 .443 .611 r
.58462 .60463 m .58812 .60455 L .58692 .60155 L F
.776 .751 .831 r
.73302 .51381 m .73645 .51502 L .73521 .51294 L F
.817 .848 .872 r
.73252 .51599 m .73645 .51502 L .73302 .51381 L F
.592 .582 .811 r
.73645 .51502 m .7376 .51043 L .73521 .51294 L F
.73645 .51502 m .73879 .51428 L .7376 .51043 L F
.682 .618 .778 r
.7533 .51068 m .75143 .51344 L .7506 .51165 L F
.921 .917 .795 r
.50651 .80822 m .50298 .81335 L .50282 .81174 L F
.647 .797 .954 r
.69232 .49028 m .69299 .49166 L .68956 .49118 L F
.532 .394 .639 r
.69515 .49254 m .69299 .49166 L .69232 .49028 L F
.69515 .49254 m .69374 .49394 L .69299 .49166 L F
.01 0 .134 r
.61761 .59299 m .61708 .59519 L .61523 .59606 L F
0 0 0 r
.61708 .59519 m .61442 .5978 L .61523 .59606 L F
.521 .562 .838 r
.75224 .52243 m .74912 .51976 L .75109 .52025 L F
.327 .341 .723 r
.75434 .52126 m .75109 .52025 L .75437 .51875 L F
.75434 .52126 m .75224 .52243 L .75109 .52025 L F
.898 .828 .768 r
.63221 .52758 m .63239 .53056 L .63317 .52839 L F
.969 .907 .699 r
.63361 .52524 m .63317 .52839 L .63445 .52553 L F
.63361 .52524 m .63221 .52758 L .63317 .52839 L F
.449 .215 .466 r
.30814 .60988 m .30614 .6105 L .30851 .60791 L F
.186 0 .088 r
.31088 .60774 m .30814 .60988 L .30851 .60791 L F
.225 0 .254 r
.56292 .59671 m .56223 .59851 L .56047 .59931 L F
.308 .091 .413 r
.56223 .59851 m .56023 .60162 L .56047 .59931 L F
.171 .451 .879 r
.55236 .64467 m .55281 .64341 L .55173 .64324 L F
0 .389 .841 r
.55236 .64467 m .5535 .64446 L .55281 .64341 L F
.55236 .64467 m .55523 .64616 L .5535 .64446 L F
.446 .318 .612 r
.40495 .68408 m .40699 .68599 L .40658 .68351 L F
.40495 .68408 m .40512 .6867 L .40699 .68599 L F
.44 .449 .772 r
.40392 .68096 m .40495 .68408 L .40658 .68351 L F
.686 .609 .764 r
.6698 .52345 m .67367 .52545 L .67303 .52253 L F
.806 .78 .828 r
.67303 .52253 m .67367 .52545 L .67609 .52265 L F
0 .018 .579 r
.53799 .62163 m .53895 .62514 L .53924 .62369 L F
.764 .388 0 r
.54083 .62696 m .53924 .62369 L .53895 .62514 L F
.515 .227 .415 r
.30862 .61096 m .30614 .6105 L .30814 .60988 L F
.30862 .61096 m .3055 .61258 L .30614 .6105 L F
.827 .732 .206 r
.60938 .58212 m .60899 .58374 L .60933 .57997 L F
.538 .369 .6 r
.5857 .62177 m .58577 .62421 L .58347 .62471 L F
.482 .365 .644 r
.58577 .62421 m .58417 .6276 L .58347 .62471 L F
.464 0 0 r
.51874 .64124 m .52132 .64161 L .52273 .64094 L F
0 .344 .75 r
.52334 .64095 m .52273 .64094 L .52132 .64161 L F
.52334 .64095 m .52435 .6417 L .52273 .64094 L F
.722 .623 .747 r
.54958 .60632 m .54732 .60769 L .5499 .60488 L F
.809 .43 .339 r
.54962 .60978 m .54772 .61025 L .54991 .61004 L F
.54732 .60769 m .54772 .61025 L .54962 .60978 L F
0 0 0 r
.54958 .60632 m .54772 .61025 L .54732 .60769 L F
.54958 .60632 m .54873 .60922 L .54772 .61025 L F
.864 .816 .8 r
.5466 .61053 m .54772 .61025 L .54873 .60922 L F
.54581 .61102 m .54772 .61025 L .5466 .61053 L F
.706 .549 .673 r
.62007 .50874 m .61784 .51138 L .62047 .51133 L F
.622 .514 .71 r
.62047 .51133 m .62248 .50821 L .62007 .50874 L F
.752 .687 .789 r
.5266 .77351 m .52869 .77714 L .52928 .77455 L F
.565 .7 .931 r
.52869 .77714 m .53135 .77481 L .52928 .77455 L F
.52869 .77714 m .53105 .77735 L .53135 .77481 L F
.52 .347 .587 r
.59865 .59944 m .60101 .59882 L .60078 .59627 L F
.485 .256 .491 r
.60073 .60095 m .59865 .59944 L .59835 .60145 L F
.60073 .60095 m .60101 .59882 L .59865 .59944 L F
.286 0 .259 r
.27884 .64529 m .27716 .64524 L .28028 .64423 L F
.27884 .64529 m .27741 .64589 L .27716 .64524 L F
.703 .527 .647 r
.57981 .60764 m .58229 .60732 L .58206 .60485 L F
.65 .452 .603 r
.58456 .60708 m .58206 .60485 L .58229 .60732 L F
.58456 .60708 m .58462 .60463 L .58206 .60485 L F
.782 .62 .679 r
.66254 .49312 m .66429 .49654 L .66402 .4945 L F
.158 0 0 r
.32213 .60174 m .32105 .60219 L .31894 .60246 L F
.236 0 0 r
.32447 .60148 m .32105 .60219 L .32213 .60174 L F
.674 .466 .595 r
.57553 .70972 m .57763 .70665 L .57619 .70671 L F
.57553 .70972 m .57763 .70909 L .57763 .70665 L F
.687 .504 .633 r
.57763 .70909 m .58008 .7064 L .57763 .70665 L F
.546 .86 .563 r
.62701 .50014 m .62419 .50285 L .62595 .50106 L F
.525 .192 .346 r
.62595 .50106 m .62912 .49885 L .62701 .50014 L F
.972 .771 .574 r
.54849 .77735 m .54873 .77481 L .54705 .77585 L F
.614 .447 .632 r
.54873 .77481 m .54822 .77485 L .54949 .77361 L F
.643 .94 .695 r
.54705 .77585 m .54949 .77361 L .54822 .77485 L F
.665 .953 .718 r
.54873 .77481 m .54949 .77361 L .54705 .77585 L F
.698 .63 .778 r
.68403 .51958 m .68766 .52009 L .68647 .51684 L F
.685 .562 .709 r
.68403 .51958 m .68766 .5224 L .68766 .52009 L F
.347 0 0 r
.46836 .69743 m .47213 .69579 L .46835 .69541 L F
.46836 .69743 m .47062 .69729 L .47213 .69579 L F
.538 .064 .077 r
.47213 .69579 m .47062 .69729 L .47409 .69692 L F
.642 .443 .598 r
.57218 .70919 m .57553 .70972 L .57619 .70671 L F
.586 .542 .773 r
.478 .65486 m .48089 .65583 L .48293 .65513 L F
.561 .225 .356 r
.478 .65486 m .48293 .65513 L .48313 .65346 L F
.475 .713 .974 r
.5161 .78905 m .51868 .78907 L .51779 .78828 L F
.442 .596 .909 r
.74848 .48226 m .74698 .48392 L .74648 .48219 L F
.098 0 .159 r
.49793 .64088 m .49547 .64385 L .49618 .642 L F
.918 .852 .762 r
.63118 .53611 m .63158 .53862 L .63236 .53712 L F
.845 .384 .012 r
.53737 .65263 m .5369 .65009 L .53507 .64968 L F
.53737 .65263 m .53874 .65343 L .5369 .65009 L F
0 .113 .651 r
.49625 .78517 m .49415 .78212 L .49413 .78298 L F
.96 .782 .619 r
.63399 .52234 m .63361 .52524 L .63445 .52553 L F
.729 .375 0 r
.74128 .52983 m .74107 .52895 L .74141 .52741 L F
.74128 .52983 m .74189 .53106 L .74107 .52895 L F
.62 .238 .298 r
.71582 .49203 m .71651 .49343 L .71372 .49297 L F
.651 .589 .772 r
.71585 .46289 m .71668 .46679 L .72045 .4661 L F
.564 .28 .443 r
.71668 .46679 m .72045 .4661 L .71596 .46518 L F
.71668 .46679 m .71944 .46801 L .72045 .4661 L F
.682 .501 .634 r
.58008 .7064 m .58341 .70651 L .58338 .70394 L F
.693 .509 .634 r
.58338 .70394 m .58341 .70651 L .58572 .7039 L F
.928 .894 .775 r
.57534 .65668 m .57771 .65555 L .57462 .65523 L F
.748 .994 .839 r
.68079 .50084 m .68184 .49917 L .68253 .49907 L F
.533 .912 .759 r
.68253 .49907 m .68378 .49788 L .68483 .49769 L F
.68253 .49907 m .68184 .49917 L .68378 .49788 L F
.829 .752 .778 r
.68734 .51052 m .691 .50875 L .68936 .50777 L F
.68734 .51052 m .68895 .51155 L .691 .50875 L F
.694 .77 .91 r
.68936 .50777 m .691 .50875 L .69316 .50799 L F
.203 0 0 r
.35022 .63814 m .34882 .63956 L .34671 .64007 L F
.119 0 .052 r
.3529 .63595 m .35162 .63828 L .35022 .63814 L F
.117 0 0 r
.35022 .63814 m .35162 .63828 L .34882 .63956 L F
.546 .538 .797 r
.29042 .64691 m .29297 .64646 L .29172 .64411 L F
.479 .722 .977 r
.29042 .64691 m .29446 .64777 L .29297 .64646 L F
.477 .833 .995 r
.27329 .66125 m .27386 .66031 L .27581 .66095 L F
.27329 .66125 m .27386 .66031 L .27581 .66095 L F
0 0 .541 r
.53448 .6551 m .53565 .65461 L .53468 .65158 L F
.965 .826 .656 r
.53682 .6558 m .53565 .65461 L .53448 .6551 L F
.892 .938 .837 r
.72929 .50869 m .72623 .51058 L .72795 .50764 L F
.962 .879 .707 r
.72969 .50441 m .72929 .50869 L .72795 .50764 L F
.722 .475 .553 r
.55539 .75791 m .55287 .76016 L .55283 .75735 L F
.55539 .75791 m .556 .7601 L .55287 .76016 L F
.736 .425 .454 r
.54631 .78045 m .55034 .78067 L .55028 .78261 L F
.718 .624 .752 r
.55034 .78067 m .54849 .77735 L .54844 .77949 L F
0 .065 .626 r
.55059 .77934 m .55034 .78067 L .54844 .77949 L F
.819 .493 .437 r
.50784 .78519 m .50812 .78343 L .50805 .78346 L F
.609 .297 .416 r
.50708 .78456 m .50569 .78341 L .50816 .78256 L F
.50708 .78456 m .50816 .78256 L .50805 .78342 L F
.678 .241 .205 r
.50433 .78506 m .50569 .78341 L .50784 .78519 L F
.819 .493 .437 r
.50784 .78519 m .50805 .78346 L .50559 .78455 L F
.609 .297 .416 r
.50805 .78342 m .50816 .78256 L .50904 .78226 L F
.50812 .78337 m .50904 .78226 L .50911 .78224 L F
.50708 .78456 m .50904 .78226 L .50812 .78337 L F
.925 .779 .68 r
.50559 .78455 m .50805 .78346 L .50813 .77967 L F
.50805 .78346 m .50812 .78343 L .50812 .78337 L F
.50805 .78346 m .50812 .78337 L .50813 .77967 L F
.917 .773 .686 r
.50813 .77967 m .50812 .78337 L .50911 .78224 L F
.50812 .78337 m .50812 .78343 L .50911 .78224 L F
.573 .259 .399 r
.50911 .78224 m .50812 .78343 L .50784 .78519 L F
.609 .297 .416 r
.50784 .78519 m .50708 .78456 L .50911 .78224 L F
.128 .37 .828 r
.66104 .4859 m .66354 .48725 L .66288 .48876 L F
.66354 .48725 m .66377 .48772 L .66288 .48876 L F
0 0 .513 r
.66384 .48869 m .66288 .48876 L .6638 .48769 L F
.606 .622 .841 r
.66372 .48592 m .66384 .48869 L .6664 .4869 L F
0 0 .513 r
.66384 .48869 m .6638 .48769 L .66397 .48748 L F
.606 .622 .841 r
.66363 .48743 m .6638 .48769 L .66372 .48592 L F
.128 .37 .828 r
.66354 .48725 m .66397 .48748 L .6638 .48769 L F
.66363 .48743 m .6638 .48769 L .66377 .48772 L F
.66354 .48725 m .6638 .48769 L .66363 .48743 L F
.606 .622 .841 r
.66335 .48578 m .66363 .48743 L .66372 .48592 L F
.66363 .48743 m .66384 .48869 L .6638 .48769 L F
.816 .764 .804 r
.66053 .48856 m .66384 .48869 L .66363 .48743 L F
.66354 .48725 m .66363 .48743 L .66335 .48578 L F
.276 .359 .768 r
.66335 .48578 m .66397 .48748 L .66354 .48725 L F
.66335 .48578 m .66354 .48725 L .66104 .4859 L F
.816 .764 .804 r
.66298 .48614 m .66354 .48725 L .66335 .48578 L F
.66053 .48856 m .66363 .48743 L .66298 .48614 L F
0 0 .513 r
.66384 .48869 m .6636 .49158 L .66288 .48876 L F
.615 .486 .682 r
.61115 .5227 m .61384 .52236 L .61336 .51971 L F
.556 .353 .56 r
.61132 .52513 m .61384 .52236 L .61115 .5227 L F
.717 .273 .197 r
.55667 .62711 m .55886 .62934 L .56057 .62783 L F
.567 .592 .838 r
.5592 .62447 m .56057 .62783 L .56269 .62726 L F
.366 0 .029 r
.55886 .62934 m .56269 .62726 L .56057 .62783 L F
.309 .053 .353 r
.67262 .50856 m .67508 .50766 L .67557 .50823 L F
.803 .999 .845 r
.67557 .50823 m .67755 .50524 L .67871 .50637 L F
.67557 .50823 m .67508 .50766 L .67755 .50524 L F
.15 .233 .696 r
.6528 .48681 m .65388 .48866 L .65312 .48507 L F
.949 .643 .423 r
.60815 .56238 m .607 .56392 L .60695 .56138 L F
.536 .371 .605 r
.61069 .5594 m .60815 .56238 L .60695 .56138 L F
.61069 .5594 m .61052 .56184 L .60815 .56238 L F
.702 .418 .491 r
.61052 .56184 m .607 .56392 L .60815 .56238 L F
.444 .168 .398 r
.37341 .62174 m .3729 .62383 L .37077 .62421 L F
.438 .162 .396 r
.37503 .62327 m .37341 .62174 L .37546 .62117 L F
.37503 .62327 m .3729 .62383 L .37341 .62174 L F
.343 .722 .985 r
.34005 .58688 m .33949 .58787 L .338 .587 L F
.34005 .58688 m .34154 .58786 L .33949 .58787 L F
.554 .213 .345 r
.4418 .66704 m .44143 .66911 L .43894 .66923 L F
.548 .359 .576 r
.44372 .66618 m .44143 .66911 L .4418 .66704 L F
.009 0 .493 r
.55081 .60352 m .54958 .60632 L .5499 .60488 L F
.55081 .60352 m .55102 .60603 L .54958 .60632 L F
.097 0 .101 r
.55065 .60794 m .54873 .60922 L .54958 .60632 L F
.638 .657 .852 r
.58559 .71495 m .5812 .71186 L .58242 .71513 L F
.58559 .71495 m .58458 .71257 L .5812 .71186 L F
.68 .68 .843 r
.58559 .71495 m .58695 .71185 L .58458 .71257 L F
.795 .701 .761 r
.57661 .71765 m .58005 .71774 L .5789 .71477 L F
.733 .671 .79 r
.58005 .71774 m .58242 .71513 L .5789 .71477 L F
.715 .728 .861 r
.6883 .49918 m .68483 .49769 L .68727 .49682 L F
.869 .832 .809 r
.69007 .49658 m .6883 .49918 L .68727 .49682 L F
.735 .655 .77 r
.68084 .51708 m .68403 .51958 L .6831 .5161 L F
.68084 .51708 m .68199 .52046 L .68403 .51958 L F
.611 .578 .792 r
.68199 .52046 m .68534 .52324 L .68403 .51958 L F
.681 .604 .763 r
.6831 .5161 m .68403 .51958 L .68647 .51684 L F
.685 .562 .709 r
.68403 .51958 m .68534 .52324 L .68766 .5224 L F
.77 .49 .511 r
.41823 .6592 m .42167 .6584 L .41968 .65838 L F
.803 .671 .718 r
.6125 .55663 m .60896 .55898 L .60932 .55614 L F
.6125 .55663 m .61069 .5594 L .60896 .55898 L F
.621 .665 .872 r
.28192 .64018 m .28569 .64041 L .28412 .63788 L F
.235 .183 .593 r
.28165 .63972 m .28028 .64423 L .27986 .64216 L F
.28165 .63972 m .28197 .64373 L .28028 .64423 L F
.737 .317 .249 r
.28165 .63972 m .27796 .63942 L .27936 .63973 L F
.796 .769 .828 r
.28165 .63972 m .27986 .64216 L .27796 .63942 L F
.621 .665 .872 r
.28192 .64018 m .28275 .63931 L .28165 .63972 L F
.757 .577 .653 r
.28535 .64355 m .28326 .64139 L .28369 .64054 L F
.28326 .64139 m .28165 .63972 L .28369 .64054 L F
0 0 .098 r
.28452 .63895 m .28369 .64054 L .28412 .63788 L F
.682 .855 .446 r
.28452 .63895 m .28441 .63913 L .28369 .64054 L F
.757 .577 .653 r
.28535 .64355 m .28197 .64373 L .28165 .63972 L F
.176 0 .028 r
.28097 .64262 m .28369 .64054 L .28165 .63972 L F
.881 .605 .514 r
.2796 .64036 m .28097 .64262 L .28165 .63972 L F
.55 .042 0 r
.28369 .64054 m .27994 .64038 L .28165 .63972 L F
.621 .665 .872 r
.28275 .63931 m .28412 .63788 L .28165 .63972 L F
.55 .042 0 r
.28369 .64054 m .28165 .63972 L .28412 .63788 L F
.176 0 .028 r
.28097 .64262 m .28256 .64221 L .28369 .64054 L F
.69 .321 .343 r
.28369 .64054 m .28256 .64221 L .2796 .64036 L F
.682 .855 .446 r
.28441 .63913 m .28256 .64221 L .28369 .64054 L F
.55 .042 0 r
.27994 .64038 m .2796 .64036 L .28165 .63972 L F
.43 0 .061 r
.27645 .59214 m .28038 .59046 L .27821 .5909 L F
.707 .602 .737 r
.26161 .64993 m .26475 .65249 L .26428 .65134 L F
.852 .949 .879 r
.26428 .65134 m .26475 .65249 L .26719 .6499 L F
.559 .42 .649 r
.40455 .66984 m .40681 .66945 L .40657 .6669 L F
.526 .386 .633 r
.40455 .66984 m .4069 .67184 L .40681 .66945 L F
.40455 .66984 m .40481 .67237 L .4069 .67184 L F
.901 .717 .645 r
.56197 .76006 m .563 .7561 L .56073 .7568 L F
.131 0 0 r
.4875 .64495 m .48619 .64602 L .48389 .64626 L F
0 .12 .648 r
.4875 .64495 m .48955 .64693 L .48878 .64569 L F
.4875 .64495 m .48878 .64569 L .48619 .64602 L F
.04 .245 .745 r
.50003 .70066 m .50231 .70298 L .50095 .70099 L F
.287 0 0 r
.50003 .70066 m .50095 .70099 L .49896 .70069 L F
.223 0 0 r
.45169 .64681 m .45384 .64642 L .45524 .64503 L F
.382 0 .123 r
.45384 .64642 m .45735 .64412 L .45524 .64503 L F
.899 .759 .698 r
.73359 .49473 m .7313 .49618 L .73241 .49364 L F
.73359 .49473 m .73302 .49747 L .7313 .49618 L F
.474 .275 .529 r
.52687 .79751 m .52897 .79689 L .52917 .79478 L F
.52917 .79478 m .52897 .79689 L .52687 .79751 L F
.665 .963 .931 r
.47609 .63099 m .47719 .62952 L .47804 .62999 L F
.47609 .63099 m .47388 .63126 L .47719 .62952 L F
.77 .673 .757 r
.67854 .52001 m .68199 .52046 L .68084 .51708 L F
.466 .375 .669 r
.40349 .67831 m .4049 .67542 L .40296 .676 L F
.815 .366 .172 r
.49427 .80219 m .4931 .80008 L .49065 .7995 L F
.284 .727 .963 r
.53 .79085 m .53333 .79141 L .53154 .79157 L F
0 0 .267 r
.46367 .66076 m .4624 .66426 L .46108 .66102 L F
.46367 .66076 m .46348 .66332 L .4624 .66426 L F
.133 .305 .773 r
.46348 .66332 m .46494 .66677 L .4624 .66426 L F
.603 .392 .568 r
.4624 .66426 m .46494 .66677 L .46224 .66669 L F
.682 .516 .654 r
.57218 .70919 m .57542 .71194 L .57553 .70972 L F
.57218 .70919 m .57323 .71232 L .57542 .71194 L F
.749 .763 .864 r
.26339 .62073 m .26469 .62223 L .26553 .62052 L F
.665 .468 .609 r
.58341 .70651 m .5858 .70629 L .58572 .7039 L F
.737 .572 .669 r
.5858 .70629 m .58934 .70377 L .58572 .7039 L F
.043 0 0 r
.34777 .59932 m .34636 .59972 L .34483 .59982 L F
0 0 0 r
.34777 .59932 m .34853 .59944 L .34636 .59972 L F
.34777 .59932 m .34998 .59906 L .34853 .59944 L F
.427 .237 .518 r
.60312 .59579 m .60538 .59275 L .60317 .59341 L F
.495 .282 .519 r
.60078 .59627 m .60312 .59579 L .60317 .59341 L F
.978 .766 .55 r
.72437 .49292 m .72588 .49167 L .72507 .49072 L F
.72437 .49292 m .7256 .49399 L .72588 .49167 L F
.69 .84 .955 r
.55867 .60705 m .55539 .60699 L .55721 .60614 L F
.836 .785 .803 r
.48024 .79135 m .48182 .79376 L .48207 .79177 L F
.269 .144 .519 r
.48182 .79376 m .48378 .79559 L .48237 .7945 L F
.48182 .79376 m .48199 .79712 L .48378 .79559 L F
.558 .782 .982 r
.56453 .59801 m .56292 .59671 L .5644 .59489 L F
.56453 .59801 m .56223 .59851 L .56292 .59671 L F
.744 .846 .927 r
.69243 .46851 m .69042 .46843 L .69304 .46667 L F
.708 .857 .953 r
.69686 .46702 m .69243 .46851 L .69304 .46667 L F
.947 .874 .732 r
.57751 .58232 m .57629 .58138 L .57453 .5853 L F
.13 0 0 r
.33107 .63042 m .33309 .62998 L .33384 .62944 L F
.176 0 0 r
.33384 .62944 m .33309 .62998 L .33516 .62955 L F
.264 0 .095 r
.58189 .55543 m .58273 .5541 L .57985 .55606 L F
.202 0 .001 r
.58189 .55543 m .58503 .55346 L .58273 .5541 L F
.387 .007 .191 r
.36597 .62802 m .36526 .62928 L .36308 .62968 L F
.187 0 .083 r
.36792 .62716 m .36526 .62928 L .36597 .62802 L F
.867 .697 .669 r
.57154 .6463 m .57374 .64458 L .57172 .64405 L F
.57154 .6463 m .57335 .64709 L .57374 .64458 L F
.744 .676 .785 r
.57374 .64458 m .57428 .6411 L .57172 .64405 L F
.466 .375 .669 r
.40349 .67831 m .40538 .67787 L .4049 .67542 L F
.494 .404 .682 r
.40349 .67831 m .40591 .68059 L .40538 .67787 L F
.40349 .67831 m .40392 .68096 L .40591 .68059 L F
.813 .771 .813 r
.55142 .75147 m .55522 .74978 L .55489 .75191 L F
.538 0 0 r
.55506 .75408 m .55142 .75147 L .55489 .75191 L F
.35 0 .043 r
.31894 .60246 m .3198 .60319 L .31825 .60336 L F
.31894 .60246 m .32105 .60219 L .3198 .60319 L F
.004 0 0 r
.48949 .80706 m .49295 .80562 L .49205 .80663 L F
.069 0 0 r
.49205 .80663 m .49295 .80562 L .49517 .80518 L F
.26 .667 .966 r
.32571 .585 m .32873 .58537 L .32718 .58569 L F
.321 .71 .981 r
.33092 .58532 m .32718 .58569 L .32873 .58537 L F
.33092 .58532 m .33236 .58617 L .32718 .58569 L F
.432 .054 .219 r
.35481 .63659 m .3529 .63595 L .35498 .63537 L F
.35481 .63659 m .35162 .63828 L .3529 .63595 L F
.808 .636 .669 r
.5011 .6414 m .4975 .64362 L .49793 .64088 L F
.5011 .6414 m .50028 .64475 L .4975 .64362 L F
.629 .685 .884 r
.58218 .66177 m .58043 .6643 L .58025 .66319 L F
.663 .734 .902 r
.58142 .66425 m .58086 .66368 L .58218 .66177 L F
.629 .685 .884 r
.58218 .66177 m .58025 .66319 L .58167 .66317 L F
.27 .563 .934 r
.57983 .66174 m .58167 .66317 L .58037 .66319 L F
.5802 .66302 m .58037 .66319 L .58025 .66319 L F
.57983 .66174 m .58037 .66319 L .5802 .66302 L F
.663 .734 .902 r
.58311 .66418 m .58142 .66425 L .58218 .66177 L F
.58142 .66425 m .58043 .6643 L .58086 .66368 L F
.587 .38 .568 r
.58311 .66418 m .5806 .66691 L .58043 .6643 L F
.789 .808 .868 r
.71912 .50525 m .71955 .50805 L .72229 .50547 L F
.631 .194 .192 r
.73163 .52035 m .73327 .51817 L .73072 .5187 L F
.868 .834 .81 r
.69007 .49658 m .68727 .49682 L .68979 .49328 L F
.882 .554 .423 r
.6129 .56417 m .61052 .56184 L .6123 .56295 L F
.533 .382 .622 r
.29446 .64777 m .29411 .64772 L .29297 .64646 L F
.273 .736 .949 r
.25344 .65299 m .25209 .65244 L .24972 .65253 L F
.98 .729 .479 r
.25219 .64954 m .25209 .65244 L .25344 .65299 L F
.923 .876 .772 r
.63583 .51601 m .63868 .51402 L .63769 .51314 L F
.63583 .51601 m .63695 .51707 L .63868 .51402 L F
.854 .926 .875 r
.64024 .51048 m .63868 .51402 L .64146 .51156 L F
.64024 .51048 m .63769 .51314 L .63868 .51402 L F
.657 .495 .653 r
.64157 .48557 m .64212 .48833 L .64472 .48591 L F
.64 .111 0 r
.64824 .49824 m .65106 .49945 L .65067 .49794 L F
.987 .731 .352 r
.64971 .49411 m .6498 .49691 L .65067 .49794 L F
.92 .922 .798 r
.6498 .49691 m .64824 .49824 L .65067 .49794 L F
.982 .813 .599 r
.49284 .78927 m .49165 .79101 L .48948 .78877 L F
.316 .312 .696 r
.48948 .78877 m .49165 .79101 L .49046 .78726 L F
.495 .283 .52 r
.60299 .59803 m .60078 .59627 L .60101 .59882 L F
.60299 .59803 m .60312 .59579 L .60078 .59627 L F
.142 0 .162 r
.6339 .49153 m .63563 .49091 L .63634 .48891 L F
.263 0 .216 r
.63634 .48891 m .63795 .48943 L .63855 .48817 L F
.63634 .48891 m .63563 .49091 L .63795 .48943 L F
.353 0 0 r
.46287 .69587 m .46503 .69633 L .46615 .69529 L F
.257 0 0 r
.46503 .69633 m .46836 .69743 L .46615 .69529 L F
.634 .345 .462 r
.46615 .69529 m .46836 .69743 L .46835 .69541 L F
.377 .701 .984 r
.66676 .52232 m .6698 .52345 L .66919 .52236 L F
.575 .789 .98 r
.6698 .52345 m .67175 .52146 L .66919 .52236 L F
.6698 .52345 m .67303 .52253 L .67175 .52146 L F
.746 .368 .338 r
.53861 .78361 m .53787 .78472 L .53608 .78259 L F
.06 .223 .719 r
.53608 .78259 m .53787 .78472 L .53721 .78313 L F
.262 0 0 r
.33891 .62778 m .34031 .62831 L .34205 .6267 L F
.175 0 0 r
.34205 .6267 m .34238 .62781 L .34343 .62681 L F
.34205 .6267 m .34031 .62831 L .34238 .62781 L F
.776 .602 .663 r
.68524 .51342 m .68895 .51155 L .68734 .51052 L F
.68524 .51342 m .68862 .51388 L .68895 .51155 L F
.347 0 .226 r
.54991 .61004 m .55272 .60932 L .55311 .60761 L F
.041 0 0 r
.55539 .60699 m .55311 .60761 L .55372 .60783 L F
.618 .751 .941 r
.55272 .60932 m .55372 .60783 L .55311 .60761 L F
.4 .782 .991 r
.36019 .58903 m .35679 .58864 L .35885 .58849 L F
.367 .787 .976 r
.36119 .58815 m .36019 .58903 L .35885 .58849 L F
.36119 .58815 m .3625 .58871 L .36019 .58903 L F
.737 .572 .669 r
.5858 .70629 m .58923 .70651 L .58934 .70377 L F
.144 .689 .763 r
.30545 .72933 m .30201 .72969 L .30259 .72754 L F
.30201 .72969 m .30545 .72933 L .30259 .72754 L F
.30545 .72933 m .30413 .7294 L .30201 .72969 L F
.30201 .72969 m .30413 .7294 L .30545 .72933 L F
.558 .933 .903 r
.30413 .7294 m .30638 .72829 L .30545 .72933 L F
.216 0 .082 r
.30638 .72829 m .30413 .7294 L .30545 .72933 L F
.144 .689 .763 r
.30545 .72933 m .30413 .7294 L .30201 .72969 L F
.583 .184 .253 r
.26843 .79395 m .27136 .79377 L .26921 .79291 L F
.647 .438 .587 r
.58804 .61888 m .59051 .62124 L .58808 .62134 L F
.58804 .61888 m .59046 .61871 L .59051 .62124 L F
.388 .015 .203 r
.39305 .60735 m .39016 .60933 L .391 .60795 L F
.513 .226 .416 r
.36149 .60997 m .36377 .60965 L .36432 .6075 L F
.538 .364 .594 r
.36432 .6075 m .36646 .6071 L .36657 .60463 L F
.18 0 .285 r
.36432 .6075 m .36561 .60856 L .36646 .6071 L F
.36432 .6075 m .36377 .60965 L .36561 .60856 L F
.654 .893 .552 r
.55802 .58055 m .56002 .57811 L .55874 .57983 L F
0 0 0 r
.52175 .77461 m .51883 .77706 L .52113 .77631 L F
.54 .35 .572 r
.52174 .77709 m .52175 .77461 L .52113 .77631 L F
.52174 .77709 m .52427 .77446 L .52175 .77461 L F
.29 .753 .947 r
.52175 .77461 m .52427 .77446 L .52174 .77709 L F
.576 .136 .168 r
.4732 .70151 m .47201 .70311 L .46963 .70269 L F
.384 0 0 r
.47573 .70165 m .47201 .70311 L .4732 .70151 L F
.757 .546 .612 r
.53205 .69194 m .53614 .69323 L .53538 .68935 L F
.523 .392 .644 r
.53538 .68935 m .53848 .69247 L .53833 .69026 L F
.53538 .68935 m .53614 .69323 L .53848 .69247 L F
.354 0 0 r
.47409 .69692 m .4764 .6969 L .47766 .69568 L F
.238 0 0 r
.47766 .69568 m .4764 .6969 L .47864 .69653 L F
.6 .119 0 r
.55642 .64696 m .55736 .64829 L .55523 .64616 L F
.55642 .64696 m .55827 .64926 L .55736 .64829 L F
.241 0 .282 r
.6662 .47728 m .66818 .47655 L .66846 .47467 L F
.516 .192 .356 r
.66846 .47467 m .66818 .47655 L .67085 .47608 L F
.536 .166 .285 r
.66846 .47467 m .67085 .47608 L .67066 .4747 L F
.802 .878 .902 r
.70414 .46301 m .70233 .46431 L .70127 .46326 L F
.513 .281 .5 r
.60147 .61308 m .60358 .6153 L .60096 .61575 L F
.60147 .61308 m .60412 .6119 L .60358 .6153 L F
.813 .771 .813 r
.55142 .75147 m .55384 .74868 L .55522 .74978 L F
0 0 0 r
.62657 .57227 m .62588 .57641 L .62714 .57342 L F
0 .44 .725 r
.50775 .62623 m .50751 .62626 L .50587 .625 L F
.79 .999 .822 r
.53991 .69096 m .53923 .69261 L .54101 .69126 L F
.53991 .69096 m .53848 .69247 L .53923 .69261 L F
.477 .295 .555 r
.30342 .61325 m .3033 .61635 L .30135 .61669 L F
.527 .44 .7 r
.3033 .61635 m .30174 .61861 L .30135 .61669 L F
.751 .83 .912 r
.28569 .64041 m .28879 .63968 L .28795 .63916 L F
.571 .878 .993 r
.28795 .63916 m .28879 .63968 L .29025 .63888 L F
.3 .583 .941 r
.28879 .63968 m .29187 .64128 L .29025 .63888 L F
.436 .254 .535 r
.3055 .61258 m .3033 .61635 L .30342 .61325 L F
.629 .868 .51 r
.55081 .60352 m .5499 .60488 L .55192 .6023 L F
.213 0 0 r
.55192 .6023 m .55301 .60303 L .55081 .60352 L F
.55192 .6023 m .55406 .60188 L .55301 .60303 L F
.37 .37 .729 r
.6339 .49153 m .63633 .49326 L .63563 .49091 L F
.51 .352 .602 r
.6339 .49153 m .63407 .49391 L .63633 .49326 L F
.669 .657 .83 r
.27301 .62491 m .27414 .62707 L .27563 .62421 L F
.615 .642 .854 r
.27414 .62707 m .27631 .62703 L .27563 .62421 L F
.291 0 .109 r
.54095 .78285 m .53787 .78472 L .53861 .78361 L F
.535 .427 .678 r
.26356 .60466 m .26589 .60762 L .26533 .60403 L F
.26356 .60466 m .26396 .60815 L .26589 .60762 L F
.391 .297 .628 r
.6662 .47728 m .6685 .47841 L .66818 .47655 L F
.569 .916 .965 r
.52105 .80513 m .51995 .80633 L .51855 .8054 L F
.52105 .80513 m .52213 .80547 L .51995 .80633 L F
.52105 .80513 m .51995 .80633 L .51855 .8054 L F
.52105 .80513 m .52213 .80547 L .51995 .80633 L F
.292 0 0 r
.29052 .58717 m .29262 .5869 L .29429 .58528 L F
.383 0 0 r
.29429 .58528 m .29262 .5869 L .29577 .5861 L F
.272 .71 .963 r
.40965 .70617 m .41168 .70619 L .40825 .70545 L F
.40965 .70617 m .41168 .70619 L .40825 .70545 L F
.391 .807 .975 r
.31153 .58361 m .31366 .58323 L .3153 .58371 L F
.094 .626 .867 r
.31366 .58323 m .31735 .58387 L .3153 .58371 L F
.303 .646 .968 r
.2481 .69786 m .24846 .6979 L .24846 .69816 L F
.722 .972 .929 r
.24846 .69816 m .24846 .6979 L .24808 .69816 L F
.744 .629 .732 r
.37998 .70906 m .38316 .70607 L .37981 .70664 L F
.428 .19 .449 r
.58417 .6276 m .58373 .62974 L .58175 .63015 L F
.535 .423 .673 r
.58373 .62974 m .58166 .63365 L .58175 .63015 L F
.506 .503 .787 r
.75372 .49015 m .75137 .49243 L .75054 .48914 L F
.306 .278 .664 r
.75372 .49015 m .75244 .49401 L .75137 .49243 L F
.813 .787 .828 r
.73683 .47726 m .73366 .47734 L .73589 .47624 L F
.691 .913 .971 r
.73788 .47533 m .73683 .47726 L .73589 .47624 L F
.73788 .47533 m .73833 .47643 L .73683 .47726 L F
.843 .854 .852 r
.26377 .64799 m .26161 .64993 L .26241 .64857 L F
.658 .325 .399 r
.26241 .64857 m .26531 .64984 L .26377 .64799 L F
.755 .303 .178 r
.26377 .64799 m .26531 .64984 L .26719 .6499 L F
.818 .73 .768 r
.25842 .63583 m .26145 .63661 L .25827 .6353 L F
.565 .587 .835 r
.25862 .63562 m .26145 .63661 L .25842 .63583 L F
.823 .886 .889 r
.26182 .63236 m .25862 .63562 L .25853 .63354 L F
.25862 .63562 m .25842 .63583 L .25843 .63564 L F
.217 0 0 r
.25897 .63559 m .25838 .63554 L .25827 .6353 L F
.823 .886 .889 r
.25862 .63562 m .25843 .63564 L .25853 .63354 L F
.217 0 0 r
.26145 .63661 m .25862 .63562 L .25897 .63559 L F
.25862 .63562 m .25838 .63554 L .25897 .63559 L F
.25838 .63554 m .25826 .6355 L .25827 .6353 L F
.155 .293 .754 r
.25853 .63354 m .25843 .63564 L .25827 .6353 L F
.25843 .63564 m .25842 .63583 L .25827 .6353 L F
.565 .587 .835 r
.26182 .63236 m .26145 .63661 L .25862 .63562 L F
.217 0 0 r
.26145 .63661 m .25821 .63726 L .25826 .6355 L F
.26145 .63661 m .25933 .63739 L .25821 .63726 L F
.277 0 .016 r
.26544 .63515 m .26391 .63607 L .26145 .63661 L F
.26544 .63515 m .26391 .63607 L .26145 .63661 L F
.565 .587 .835 r
.26182 .63236 m .26355 .63543 L .26145 .63661 L F
.673 .636 .805 r
.26533 .63456 m .26391 .63607 L .26182 .63236 L F
.26533 .63456 m .26182 .63236 L .2635 .63207 L F
.077 .376 .84 r
.2635 .63207 m .26593 .63349 L .26533 .63456 L F
.579 .94 .908 r
.26593 .63349 m .26226 .63514 L .26484 .63465 L F
.2655 .63425 m .26484 .63465 L .26533 .63456 L F
.26593 .63349 m .26484 .63465 L .2655 .63425 L F
.565 .587 .835 r
.26355 .63543 m .26391 .63607 L .26168 .63656 L F
.26355 .63543 m .26168 .63656 L .26145 .63661 L F
.371 .825 .72 r
.26135 .63644 m .26145 .63661 L .26391 .63607 L F
.26135 .63644 m .25933 .63739 L .26145 .63661 L F
.203 .43 .858 r
.58014 .64158 m .57851 .63964 L .58027 .63871 L F
.572 .379 .582 r
.58291 .63823 m .58014 .64158 L .58027 .63871 L F
.367 .683 .979 r
.41545 .70639 m .41571 .70191 L .41369 .70257 L F
.41545 .70639 m .41597 .70513 L .41571 .70191 L F
.41545 .70639 m .41721 .70622 L .41597 .70513 L F
.85 .826 .824 r
.49427 .79724 m .49542 .79349 L .49296 .79407 L F
.929 .79 .685 r
.73199 .49936 m .7313 .49618 L .73302 .49747 L F
.511 .313 .549 r
.58808 .62134 m .58577 .62421 L .5857 .62177 L F
.587 .38 .568 r
.58311 .66418 m .58315 .66665 L .5806 .66691 L F
.542 .399 .636 r
.58514 .66114 m .58311 .66418 L .58218 .66177 L F
.58514 .66114 m .58555 .66373 L .58311 .66418 L F
.491 .305 .556 r
.58542 .66604 m .58311 .66418 L .58555 .66373 L F
.58542 .66604 m .58315 .66665 L .58311 .66418 L F
0 0 .388 r
.54138 .62975 m .54156 .62918 L .54083 .62696 L F
0 0 .45 r
.54138 .62975 m .54246 .63154 L .54156 .62918 L F
.54138 .62975 m .54237 .63313 L .54246 .63154 L F
.043 0 0 r
.32662 .63092 m .32941 .63075 L .33107 .63042 L F
.197 .722 .722 r
.33107 .63042 m .33149 .63024 L .33309 .62998 L F
.33107 .63042 m .32941 .63075 L .33149 .63024 L F
.046 0 0 r
.46583 .63931 m .46289 .64133 L .46486 .64037 L F
.177 0 .048 r
.46486 .64037 m .46774 .6383 L .46583 .63931 L F
.479 .323 .591 r
.26729 .59862 m .26945 .5956 L .26733 .59623 L F
.817 .6 .609 r
.58899 .71134 m .59144 .7098 L .58913 .70907 L F
.58899 .71134 m .591 .71237 L .59144 .7098 L F
.821 .747 .782 r
.49399 .64922 m .49432 .65249 L .4963 .64929 L F
.654 .752 .922 r
.49432 .65249 m .49836 .65207 L .4963 .64929 L F
0 0 0 r
.28028 .64423 m .28197 .64373 L .27884 .64529 L F
.665 .484 .63 r
.61784 .51138 m .62067 .51368 L .62047 .51133 L F
.622 .514 .71 r
.62047 .51133 m .62313 .51135 L .62248 .50821 L F
.582 .39 .586 r
.62047 .51133 m .62338 .51231 L .62313 .51135 L F
.62047 .51133 m .62067 .51368 L .62338 .51231 L F
.484 0 0 r
.47906 .70135 m .47763 .70249 L .47573 .70165 L F
.545 .038 0 r
.47906 .70135 m .48103 .70251 L .47763 .70249 L F
.921 .888 .783 r
.53808 .79711 m .53578 .8011 L .53475 .79968 L F
.53808 .79711 m .53475 .79968 L .53706 .79899 L F
.532 .534 .803 r
.53808 .79711 m .5408 .79722 L .53908 .79588 L F
.544 .354 .574 r
.5385 .79975 m .53808 .79711 L .53706 .79899 L F
.5385 .79975 m .5408 .79722 L .53808 .79711 L F
.665 .484 .63 r
.61784 .51138 m .61788 .51386 L .62067 .51368 L F
.17 .683 .896 r
.34154 .58786 m .34366 .58789 L .34525 .58832 L F
.287 .74 .957 r
.34579 .58749 m .34525 .58832 L .34366 .58789 L F
.34579 .58749 m .34741 .58823 L .34525 .58832 L F
.986 .804 .575 r
.63077 .54205 m .63086 .54484 L .63206 .5456 L F
.953 .877 .723 r
.63206 .5456 m .62996 .54681 L .63132 .54798 L F
.63206 .5456 m .63086 .54484 L .62996 .54681 L F
.437 .743 .992 r
.37962 .59248 m .37892 .59373 L .37754 .59253 L F
.37962 .59248 m .38102 .59355 L .37892 .59373 L F
.137 0 0 r
.5482 .58976 m .55127 .58752 L .54865 .58972 L F
.5482 .58976 m .55033 .58897 L .55127 .58752 L F
.066 0 .163 r
.55127 .58752 m .55315 .58681 L .55353 .58465 L F
0 0 0 r
.55127 .58752 m .55033 .58897 L .55315 .58681 L F
.57 .395 .605 r
.42979 .68069 m .42746 .68366 L .4275 .68093 L F
.521 .322 .552 r
.24972 .65253 m .25219 .64954 L .24976 .65033 L F
.323 .479 .86 r
.66213 .51933 m .6605 .52039 L .66008 .51878 L F
.66213 .51933 m .66355 .52226 L .6605 .52039 L F
.576 .942 .85 r
.69042 .46843 m .68832 .46967 L .68692 .4699 L F
.478 .013 .07 r
.4419 .70628 m .44032 .70791 L .43839 .70797 L F
.181 0 0 r
.4424 .70741 m .4419 .70628 L .44415 .70606 L F
.4424 .70741 m .44032 .70791 L .4419 .70628 L F
.897 .837 .778 r
.52346 .78564 m .5258 .7857 L .52649 .78309 L F
.708 .939 .961 r
.52346 .78564 m .52432 .78631 L .5258 .7857 L F
.662 .587 .76 r
.52649 .78309 m .5258 .7857 L .52877 .7827 L F
.386 .161 .445 r
.49155 .77173 m .49322 .77182 L .49383 .76887 L F
.49155 .77173 m .49322 .77182 L .49383 .76887 L F
.231 .626 .956 r
.50282 .81174 m .50021 .81136 L .5011 .81066 L F
.5011 .81066 m .50021 .81136 L .50282 .81174 L F
.808 .443 .366 r
.50298 .81335 m .50021 .81136 L .50282 .81174 L F
0 .255 .737 r
.50021 .81136 m .50382 .81425 L .50282 .81174 L F
.108 0 .141 r
.61987 .59046 m .61958 .5924 L .61761 .59299 L F
0 0 0 r
.62178 .58746 m .62101 .58915 L .61987 .59046 L F
0 0 .028 r
.62101 .58915 m .61958 .5924 L .61987 .59046 L F
0 0 0 r
.52175 .69988 m .51977 .70086 L .52006 .70053 L F
.593 .392 .579 r
.59304 .61596 m .59285 .61858 L .59046 .61871 L F
.629 .419 .579 r
.5962 .61563 m .59285 .61858 L .59304 .61596 L F
0 0 .514 r
.54964 .64168 m .54984 .64063 L .54885 .63843 L F
.049 .349 .825 r
.54964 .64168 m .55173 .64324 L .54984 .64063 L F
.895 .738 .68 r
.71826 .49548 m .7176 .49705 L .71651 .49343 L F
.482 .365 .644 r
.58577 .62421 m .58615 .62673 L .58417 .6276 L F
.523 .275 .481 r
.58616 .62919 m .58417 .6276 L .58615 .62673 L F
.58616 .62919 m .58373 .62974 L .58417 .6276 L F
.937 .954 .638 r
.72894 .48067 m .72777 .48142 L .72854 .48119 L F
.517 .873 .635 r
.73059 .47918 m .72894 .48067 L .73119 .4797 L F
.72975 .47994 m .72817 .48113 L .72894 .48067 L F
.7287 .48069 m .72784 .48138 L .72975 .47994 L F
.73059 .47918 m .7287 .48069 L .72975 .47994 L F
.945 .942 .751 r
.72861 .48128 m .7287 .48069 L .73059 .47918 L F
.7287 .48069 m .72918 .47757 L .73059 .47918 L F
.517 .873 .635 r
.73059 .47918 m .72777 .48142 L .72784 .48138 L F
.776 .532 .565 r
.73119 .4797 m .72861 .48128 L .73059 .47918 L F
.73119 .4797 m .73131 .482 L .72861 .48128 L F
.945 .942 .751 r
.7287 .48069 m .72864 .48066 L .72918 .47757 L F
.902 .963 .639 r
.72918 .47757 m .72796 .4809 L .72867 .48044 L F
.72796 .4809 m .72824 .48105 L .73059 .47918 L F
.945 .942 .751 r
.72777 .48033 m .72764 .48028 L .72918 .47757 L F
.902 .963 .639 r
.72918 .47757 m .72753 .48072 L .72755 .48077 L F
.945 .942 .751 r
.72831 .48097 m .72764 .48028 L .7287 .48069 L F
.058 .15 .645 r
.72831 .48097 m .72871 .4805 L .7277 .48029 L F
.785 .911 .521 r
.72812 .47878 m .72764 .48028 L .72918 .47757 L F
.878 .671 .619 r
.72773 .48029 m .72812 .47878 L .72764 .48028 L F
.813 .916 .524 r
.72812 .47878 m .72782 .47994 L .72918 .47757 L F
.72772 .48012 m .72773 .48035 L .72918 .47757 L F
.902 .963 .639 r
.72918 .47757 m .72774 .48038 L .72796 .4809 L F
.945 .942 .751 r
.72864 .48066 m .72777 .48033 L .72918 .47757 L F
.902 .963 .639 r
.72918 .47757 m .72867 .48044 L .73059 .47918 L F
.878 .671 .619 r
.7304 .48086 m .72812 .47878 L .72773 .48029 L F
.813 .916 .524 r
.72812 .47878 m .72772 .48012 L .72782 .47994 L F
.058 .15 .645 r
.72773 .48037 m .7277 .48029 L .72764 .48028 L F
.72773 .48035 m .7277 .48029 L .72773 .48037 L F
.813 .916 .524 r
.72772 .48012 m .72753 .48072 L .72773 .48035 L F
.058 .15 .645 r
.72774 .48038 m .72773 .48035 L .72773 .48037 L F
.72831 .48097 m .7277 .48029 L .72774 .48038 L F
.902 .963 .639 r
.72796 .4809 m .72755 .48077 L .72777 .48142 L F
.72774 .48038 m .72755 .48077 L .72796 .4809 L F
.72796 .4809 m .72777 .48142 L .72824 .48105 L F
.058 .15 .645 r
.72862 .48125 m .7304 .48086 L .72871 .4805 L F
.72861 .48128 m .72866 .48127 L .72862 .48125 L F
.72866 .48127 m .7304 .48086 L .72862 .48125 L F
.517 .873 .635 r
.72817 .48113 m .7281 .48121 L .72894 .48067 L F
.945 .942 .751 r
.72861 .48128 m .72831 .48097 L .7287 .48069 L F
.058 .15 .645 r
.72861 .48128 m .72871 .4805 L .72831 .48097 L F
.517 .873 .635 r
.72817 .48113 m .72784 .48138 L .7281 .48121 L F
.092 .344 .816 r
.74984 .52764 m .74754 .52473 L .75074 .52558 L F
.132 0 .366 r
.75184 .52424 m .75074 .52558 L .75224 .52243 L F
0 0 0 r
.75148 .52579 m .75074 .52558 L .75184 .52424 L F
.75148 .52579 m .74984 .52764 L .75074 .52558 L F
.73 .613 .727 r
.5775 .61039 m .57994 .61033 L .57981 .60764 L F
.661 .466 .61 r
.57752 .61297 m .57994 .61033 L .5775 .61039 L F
.57752 .61297 m .58016 .61321 L .57994 .61033 L F
.622 .469 .654 r
.57994 .61033 m .58229 .60732 L .57981 .60764 L F
.57994 .61033 m .58276 .6102 L .58229 .60732 L F
.606 .425 .61 r
.57994 .61033 m .58328 .6114 L .58276 .6102 L F
.57994 .61033 m .58016 .61321 L .58328 .6114 L F
.505 .223 .42 r
.59194 .54494 m .59429 .54459 L .59486 .54216 L F
.557 .271 .437 r
.59486 .54216 m .59728 .5437 L .59739 .54206 L F
.59486 .54216 m .59429 .54459 L .59728 .5437 L F
.903 .862 .79 r
.64024 .51048 m .64146 .51156 L .64335 .50887 L F
.361 .827 .904 r
.64223 .50872 m .64335 .50887 L .64599 .5082 L F
.228 0 0 r
.51218 .69664 m .51448 .69612 L .51596 .69421 L F
.341 0 0 r
.51448 .69612 m .51813 .69429 L .51596 .69421 L F
.499 .395 .668 r
.26161 .64993 m .26428 .65134 L .26241 .64857 L F
.625 .535 .733 r
.57068 .71538 m .57085 .71757 L .57312 .71485 L F
.656 .582 .76 r
.57085 .71757 m .5742 .71822 L .57312 .71485 L F
.568 .312 .488 r
.53908 .79588 m .54248 .79412 L .54115 .79318 L F
.143 .671 .87 r
.31704 .64843 m .32056 .64878 L .31969 .64828 L F
.31 .751 .965 r
.32056 .64878 m .32117 .64816 L .31969 .64828 L F
.32056 .64878 m .32273 .64867 L .32117 .64816 L F
.281 .75 .942 r
.43942 .69789 m .44161 .69775 L .44302 .69821 L F
.539 .925 .898 r
.44302 .69821 m .44392 .69721 L .44503 .69716 L F
.472 .853 .983 r
.44302 .69821 m .44161 .69775 L .44392 .69721 L F
.832 .799 .819 r
.5702 .64729 m .56831 .64979 L .57107 .64997 L F
.797 .659 .711 r
.56831 .64979 m .57019 .65262 L .57107 .64997 L F
.836 .8 .817 r
.57113 .64723 m .57107 .64997 L .57335 .64709 L F
.5702 .64729 m .57335 .64709 L .57154 .6463 L F
.297 .028 .327 r
.57215 .64524 m .57106 .64858 L .5715 .6465 L F
.57193 .64563 m .5715 .6465 L .57154 .6463 L F
.57215 .64524 m .5715 .6465 L .57193 .64563 L F
.836 .8 .817 r
.5702 .64729 m .57056 .6484 L .57113 .64723 L F
.57056 .6484 m .57107 .64997 L .57113 .64723 L F
.729 .767 .883 r
.74098 .51084 m .74431 .51128 L .74392 .50998 L F
.503 .623 .902 r
.74392 .50998 m .74431 .51128 L .74644 .50977 L F
.419 .45 .786 r
.74431 .51128 m .74843 .5134 L .74644 .50977 L F
.659 .74 .91 r
.69784 .50236 m .70126 .50298 L .70048 .50181 L F
.66 .741 .91 r
.70048 .50181 m .70126 .50298 L .7036 .50229 L F
.688 .644 .801 r
.4963 .64929 m .50033 .64999 L .49908 .64681 L F
.718 .555 .667 r
.4963 .64929 m .49836 .65207 L .50033 .64999 L F
.72 .558 .669 r
.49836 .65207 m .5006 .65302 L .50033 .64999 L F
.49836 .65207 m .5006 .65302 L .50033 .64999 L F
.742 .671 .781 r
.49908 .64681 m .50033 .64999 L .50275 .64764 L F
.711 .552 .67 r
.50369 .65184 m .50033 .64999 L .50208 .65064 L F
.50369 .65184 m .5006 .65302 L .50033 .64999 L F
.582 .525 .756 r
.5006 .65302 m .50208 .65064 L .50033 .64999 L F
.59 .522 .747 r
.53376 .64398 m .53188 .64672 L .5316 .64486 L F
.53376 .64398 m .53428 .64798 L .53188 .64672 L F
.691 .509 .637 r
.53507 .64968 m .53188 .64672 L .53428 .64798 L F
.53507 .64968 m .53364 .65126 L .53188 .64672 L F
.802 .878 .902 r
.70414 .46301 m .70127 .46326 L .70313 .46189 L F
.662 .849 .972 r
.70822 .46107 m .70414 .46301 L .70313 .46189 L F
.214 .736 .747 r
.50827 .69871 m .50866 .69847 L .51009 .69743 L F
.50827 .69871 m .50628 .69903 L .50866 .69847 L F
.89 .857 .802 r
.72177 .5023 m .72492 .50064 L .7236 .49937 L F
.72177 .5023 m .72303 .50317 L .72492 .50064 L F
.94 .794 .672 r
.72382 .49454 m .72501 .49893 L .7256 .49399 L F
.717 .583 .705 r
.7256 .49399 m .72501 .49893 L .72597 .49703 L F
.9 .802 .742 r
.72229 .49807 m .72501 .49893 L .72382 .49454 L F
.72229 .49807 m .7236 .49937 L .72501 .49893 L F
.898 .827 .769 r
.7236 .49937 m .72597 .49703 L .72501 .49893 L F
.7236 .49937 m .72492 .50064 L .72597 .49703 L F
.46 .584 .891 r
.29025 .63888 m .29187 .64128 L .29351 .64048 L F
.472 .265 .517 r
.29187 .64128 m .29385 .64295 L .29351 .64048 L F
.29187 .64128 m .29172 .64411 L .29385 .64295 L F
.644 .461 .621 r
.58456 .60708 m .58812 .60455 L .58462 .60463 L F
.982 .813 .599 r
.49284 .78927 m .49275 .79154 L .49165 .79101 L F
.611 .495 .696 r
.49396 .78938 m .49275 .79154 L .49284 .78927 L F
.687 .504 .633 r
.57763 .70909 m .58104 .70949 L .58008 .7064 L F
.653 .484 .643 r
.58008 .7064 m .58346 .70903 L .58341 .70651 L F
.58008 .7064 m .58104 .70949 L .58346 .70903 L F
.665 .457 .593 r
.55283 .75735 m .55052 .76012 L .55074 .75751 L F
.55283 .75735 m .55287 .76016 L .55052 .76012 L F
.017 0 .414 r
.55074 .75751 m .55204 .75932 L .55283 .75735 L F
.783 .959 .641 r
.55506 .75408 m .55283 .75735 L .55384 .75492 L F
0 0 0 r
.55283 .75735 m .55204 .75932 L .55384 .75492 L F
.431 .129 .35 r
.3729 .62383 m .37006 .62662 L .37077 .62421 L F
.193 .698 .906 r
.43581 .69746 m .43942 .69789 L .4375 .6989 L F
.694 .632 .782 r
.74528 .50437 m .7447 .50542 L .74458 .50407 L F
.74557 .50431 m .74441 .50391 L .74399 .503 L F
.74528 .50437 m .74336 .50355 L .74557 .50431 L F
.578 .305 .467 r
.74399 .503 m .73966 .50506 L .74013 .50541 L F
.74256 .50424 m .74013 .50541 L .74073 .50584 L F
.74399 .503 m .74013 .50541 L .74256 .50424 L F
.303 0 .068 r
.74201 .50417 m .73966 .50506 L .74399 .503 L F
.694 .632 .782 r
.74256 .50424 m .74435 .50165 L .74201 .50417 L F
.74336 .50355 m .74337 .50354 L .74557 .50431 L F
.74528 .50437 m .74458 .50407 L .74455 .50378 L F
.77 .732 .818 r
.7447 .50542 m .74597 .50543 L .74603 .50422 L F
.74534 .50427 m .74603 .50422 L .74609 .5029 L F
.74528 .50437 m .74557 .50431 L .74534 .50427 L F
.74557 .50431 m .74603 .50422 L .74534 .50427 L F
.811 .536 .522 r
.74413 .5034 m .74543 .50429 L .74399 .503 L F
.77 .732 .818 r
.7447 .50542 m .74586 .50437 L .74528 .50437 L F
.74586 .50437 m .74603 .50422 L .74557 .50431 L F
.74586 .50437 m .74557 .50431 L .74528 .50437 L F
.694 .632 .782 r
.74535 .5044 m .74528 .50437 L .74535 .50436 L F
.746 .50467 m .74545 .50434 L .74557 .50431 L F
.746 .50467 m .7447 .50542 L .74534 .50427 L F
.811 .536 .522 r
.74543 .50429 m .746 .50467 L .74557 .50431 L F
.694 .632 .782 r
.746 .50467 m .74534 .50427 L .74556 .50386 L F
.77 .732 .818 r
.7447 .50542 m .74495 .50443 L .74458 .50407 L F
.694 .632 .782 r
.74528 .50437 m .74201 .50417 L .74318 .50348 L F
.746 .50467 m .74461 .5045 L .74528 .50437 L F
.74461 .5045 m .74201 .50417 L .74528 .50437 L F
.77 .732 .818 r
.74458 .50407 m .74465 .50387 L .74455 .50378 L F
.694 .632 .782 r
.74528 .50437 m .74455 .50378 L .74522 .5042 L F
.77 .732 .818 r
.74495 .50443 m .74501 .5042 L .74458 .50407 L F
.811 .536 .522 r
.74487 .50408 m .74534 .50427 L .74455 .50378 L F
.74543 .50429 m .74557 .50431 L .74399 .503 L F
.74455 .50378 m .74534 .50427 L .74413 .5034 L F
.74534 .50427 m .746 .50467 L .74543 .50429 L F
.74534 .50427 m .74543 .50429 L .74413 .5034 L F
.694 .632 .782 r
.74522 .5042 m .74455 .50378 L .74435 .50165 L F
.74556 .50386 m .74528 .50437 L .74435 .50165 L F
.7454 .50397 m .7451 .50302 L .74474 .50319 L F
.746 .50467 m .74556 .50386 L .7454 .50397 L F
.74556 .50386 m .7451 .50302 L .7454 .50397 L F
.77 .732 .818 r
.74501 .5042 m .74465 .50387 L .74458 .50407 L F
.811 .536 .522 r
.74505 .50421 m .74534 .50427 L .74429 .50384 L F
.77 .732 .818 r
.74511 .50422 m .74519 .50411 L .74505 .50421 L F
.811 .536 .522 r
.74535 .50435 m .746 .50467 L .74534 .50427 L F
.694 .632 .782 r
.746 .50467 m .74522 .50429 L .74508 .50456 L F
.53 .856 .997 r
.74564 .50508 m .74597 .50543 L .7447 .50542 L F
.492 .492 .785 r
.74627 .49918 m .74597 .50543 L .7493 .50064 L F
.092 0 .416 r
.7493 .50064 m .74597 .50543 L .74726 .5045 L F
.288 .101 .444 r
.74726 .5045 m .746 .50467 L .74597 .5051 L F
.53 .856 .997 r
.74726 .5045 m .74638 .50513 L .74597 .5051 L F
.74638 .50513 m .74597 .50543 L .74564 .50508 L F
.288 .101 .444 r
.74726 .5045 m .74597 .5051 L .7458 .50808 L F
.53 .856 .997 r
.74726 .5045 m .74597 .5051 L .74564 .50508 L F
.811 .536 .522 r
.74543 .50507 m .746 .50467 L .74535 .50435 L F
.7458 .50808 m .74597 .5051 L .74543 .50507 L F
.74597 .5051 m .746 .50467 L .74564 .50508 L F
.53 .856 .997 r
.74726 .5045 m .74564 .50508 L .746 .50467 L F
.74564 .50508 m .7447 .50542 L .746 .50467 L F
.811 .536 .522 r
.74564 .50508 m .746 .50467 L .74543 .50507 L F
.694 .632 .782 r
.746 .50467 m .7454 .50397 L .74522 .50429 L F
.7454 .50397 m .74474 .50319 L .745 .50424 L F
.77 .732 .818 r
.74495 .50443 m .74511 .50422 L .74505 .50421 L F
.74528 .50437 m .74609 .5029 L .74495 .50443 L F
.694 .632 .782 r
.74522 .50429 m .745 .50424 L .74508 .50456 L F
.77 .732 .818 r
.74495 .50443 m .74505 .50421 L .745 .50424 L F
.694 .632 .782 r
.74508 .50456 m .74498 .50418 L .74256 .50424 L F
.74498 .50418 m .74429 .50384 L .74256 .50424 L F
.74441 .50391 m .74318 .50348 L .74367 .50319 L F
.74441 .50391 m .74367 .50319 L .74399 .503 L F
.811 .536 .522 r
.74429 .50384 m .74399 .503 L .74366 .50371 L F
.694 .632 .782 r
.74429 .50384 m .74385 .50362 L .74366 .50371 L F
.74429 .50384 m .74366 .50371 L .74256 .50424 L F
.77 .732 .818 r
.7447 .50542 m .74528 .50437 L .74495 .50443 L F
.811 .536 .522 r
.7458 .50808 m .74429 .50384 L .7422 .50691 L F
.74429 .50384 m .74366 .50371 L .7422 .50691 L F
.7458 .50808 m .74535 .50435 L .74437 .50407 L F
.74535 .50435 m .74534 .50427 L .74505 .50421 L F
.694 .632 .782 r
.74505 .50421 m .745 .50424 L .74522 .50429 L F
.77 .732 .818 r
.745 .50424 m .74505 .50421 L .74501 .5042 L F
.811 .536 .522 r
.74535 .50435 m .74505 .50421 L .74437 .50407 L F
.694 .632 .782 r
.7454 .50397 m .74505 .50421 L .74522 .50429 L F
.77 .732 .818 r
.74505 .50421 m .74609 .5029 L .74501 .5042 L F
.74519 .50411 m .74609 .5029 L .74505 .50421 L F
.74501 .5042 m .74609 .5029 L .74627 .49918 L F
.74455 .50378 m .7448 .50344 L .74435 .50165 L F
.694 .632 .782 r
.74336 .50355 m .74318 .50348 L .74337 .50354 L F
.578 .305 .467 r
.74399 .503 m .74073 .50584 L .7422 .50691 L F
.694 .632 .782 r
.74474 .50319 m .74435 .50165 L .74256 .50424 L F
.7451 .50302 m .74435 .50165 L .74474 .50319 L F
.77 .732 .818 r
.74501 .5042 m .74627 .49918 L .7448 .50344 L F
.74498 .50418 m .7448 .50344 L .74465 .50387 L F
.74501 .5042 m .7448 .50344 L .74498 .50418 L F
.811 .536 .522 r
.74429 .50384 m .74487 .50408 L .74419 .50356 L F
.74487 .50408 m .74455 .50378 L .74419 .50356 L F
.74437 .50407 m .74505 .50421 L .74429 .50384 L F
.74419 .50356 m .74455 .50378 L .74413 .5034 L F
.77 .732 .818 r
.74465 .50387 m .7448 .50344 L .74455 .50378 L F
.694 .632 .782 r
.74498 .50418 m .74474 .50319 L .74385 .50362 L F
.77 .732 .818 r
.7448 .50344 m .74627 .49918 L .74435 .50165 L F
.803 .78 .831 r
.2552 .66271 m .25589 .66451 L .25711 .6624 L F
.2552 .66271 m .25589 .66451 L .25711 .6624 L F
.747 .503 .561 r
.60927 .55366 m .60576 .55575 L .60625 .55414 L F
.60927 .55366 m .60932 .55614 L .60576 .55575 L F
.414 .445 .784 r
.36572 .60119 m .36553 .60248 L .36717 .60072 L F
.555 .571 .825 r
.36657 .60463 m .36717 .60072 L .36553 .60248 L F
.981 .711 .44 r
.49275 .79154 m .49296 .79407 L .49165 .79101 L F
.487 .224 .441 r
.41139 .66139 m .41375 .6611 L .41359 .66004 L F
.497 .253 .474 r
.41139 .66139 m .41104 .66359 L .41375 .6611 L F
.82 .741 .776 r
.67453 .52165 m .67303 .52253 L .67609 .52265 L F
.776 .754 .833 r
.67453 .52165 m .67609 .52265 L .67854 .52001 L F
.331 .235 .594 r
.43386 .67745 m .43208 .67549 L .43401 .67485 L F
.43386 .67745 m .43233 .67799 L .43208 .67549 L F
.273 .543 .921 r
.7438 .47574 m .74312 .47708 L .7407 .47464 L F
.059 .264 .757 r
.7438 .47574 m .74527 .47893 L .74312 .47708 L F
.368 .559 .908 r
.51615 .77593 m .51492 .77724 L .51235 .77712 L F
.51615 .77593 m .51684 .77824 L .51492 .77724 L F
.769 .407 .369 r
.51235 .77712 m .51492 .77724 L .51589 .77955 L F
.205 .408 .84 r
.72795 .46948 m .72564 .46957 L .72517 .46802 L F
.72795 .46948 m .72713 .47091 L .72564 .46957 L F
.187 0 .198 r
.61881 .59423 m .61761 .59299 L .61958 .5924 L F
.61881 .59423 m .61708 .59519 L .61761 .59299 L F
.808 .538 .53 r
.5083 .8111 m .50823 .80859 L .50496 .80817 L F
.308 .058 .361 r
.43613 .67199 m .4344 .67255 L .43673 .66975 L F
.313 .068 .373 r
.43401 .67485 m .4344 .67255 L .43613 .67199 L F
.673 .16 .011 r
.56402 .61813 m .56593 .61977 L .56724 .61893 L F
.174 0 .288 r
.56945 .61591 m .56724 .61893 L .56899 .61771 L F
.001 0 0 r
.56593 .61977 m .56899 .61771 L .56724 .61893 L F
.419 .481 .817 r
.41893 .70907 m .4193 .70588 L .41721 .70622 L F
.41893 .70907 m .42081 .70921 L .4193 .70588 L F
.342 .261 .619 r
.26464 .61001 m .26589 .60762 L .26396 .60815 L F
.26464 .61001 m .26617 .60964 L .26589 .60762 L F
.517 .399 .657 r
.26438 .61245 m .26617 .60964 L .26464 .61001 L F
.667 .418 .535 r
.49677 .77146 m .49322 .77182 L .49383 .76887 L F
.107 0 .327 r
.49383 .76887 m .49501 .7704 L .49527 .76979 L F
.49383 .76887 m .49322 .77182 L .49501 .7704 L F
.667 .418 .535 r
.49677 .77146 m .49402 .76904 L .49527 .76979 L F
.516 0 0 r
.49527 .76979 m .49501 .7704 L .4964 .77047 L F
.512 .562 .843 r
.49832 .77057 m .49677 .77146 L .49527 .76979 L F
.516 0 0 r
.49527 .76979 m .4964 .77047 L .49832 .77057 L F
.667 .418 .535 r
.49402 .76904 m .49383 .76887 L .49527 .76979 L F
.484 .333 .6 r
.47027 .66875 m .46802 .66661 L .47157 .66695 L F
.44 0 0 r
.46802 .66661 m .47139 .66727 L .47157 .66695 L F
.699 .289 .267 r
.47383 .66904 m .47157 .66695 L .4731 .66588 L F
0 0 0 r
.47157 .66695 m .47139 .66727 L .4731 .66588 L F
.699 .289 .267 r
.47383 .66904 m .47027 .66875 L .47157 .66695 L F
.654 .688 .869 r
.70126 .49284 m .70237 .49459 L .6989 .49365 L F
.64 .682 .874 r
.7047 .49379 m .70237 .49459 L .70126 .49284 L F
0 0 0 r
.32646 .64812 m .32857 .64704 L .3306 .64638 L F
.555 .571 .825 r
.36657 .60463 m .36854 .60403 L .36717 .60072 L F
.557 .38 .597 r
.36657 .60463 m .36895 .60646 L .36854 .60403 L F
.36657 .60463 m .36646 .6071 L .36895 .60646 L F
.978 .826 .624 r
.63583 .51601 m .63648 .51933 L .63695 .51707 L F
.44 .449 .772 r
.40392 .68096 m .40658 .68351 L .40591 .68059 L F
.911 .787 .711 r
.63003 .55872 m .62849 .56203 L .63065 .5619 L F
.912 .754 .672 r
.63065 .5619 m .62809 .56397 L .62915 .56495 L F
.63065 .5619 m .62849 .56203 L .62809 .56397 L F
.412 .003 .151 r
.28252 .59002 m .28478 .58979 L .28614 .5878 L F
.361 0 .12 r
.28614 .5878 m .28698 .58934 L .28842 .58754 L F
.28614 .5878 m .28478 .58979 L .28698 .58934 L F
.681 .828 .954 r
.55813 .60283 m .55874 .60047 L .55669 .60308 L F
.55813 .60283 m .56023 .60162 L .55874 .60047 L F
.542 .339 .554 r
.61573 .51689 m .61336 .51971 L .61572 .51917 L F
.645 .491 .66 r
.61572 .51917 m .61805 .51632 L .61573 .51689 L F
.874 .979 .684 r
.52862 .60457 m .52631 .60709 L .52783 .60393 L F
.52862 .60457 m .5267 .60757 L .52631 .60709 L F
.843 .927 .886 r
.53003 .60134 m .52862 .60457 L .52783 .60393 L F
.53003 .60134 m .53123 .60209 L .52862 .60457 L F
.828 .865 .873 r
.56118 .60467 m .55721 .60614 L .5598 .60498 L F
.554 .438 .675 r
.42868 .68933 m .4268 .69204 L .4264 .68978 L F
.73 .86 .942 r
.65504 .51039 m .6583 .51025 L .65669 .50941 L F
.752 .891 .942 r
.65669 .50941 m .6583 .51025 L .6611 .50848 L F
.6 .465 .668 r
.62419 .50285 m .62719 .50471 L .62595 .50106 L F
.62419 .50285 m .62478 .50533 L .62719 .50471 L F
.471 .186 .399 r
.31567 .60455 m .31289 .60696 L .31338 .60504 L F
.141 0 0 r
.6732 .4817 m .67211 .48185 L .66986 .48174 L F
.269 .774 .78 r
.67454 .48118 m .6732 .4817 L .67546 .48161 L F
.67454 .48118 m .67211 .48185 L .6732 .4817 L F
.682 .835 .957 r
.53475 .79968 m .53578 .8011 L .5385 .79975 L F
.235 .721 .926 r
.3516 .58769 m .35095 .58835 L .34949 .58793 L F
.3516 .58769 m .35321 .58828 L .35095 .58835 L F
.026 .353 .829 r
.53094 .6161 m .53281 .6163 L .53055 .615 L F
.53094 .6161 m .53352 .61774 L .53281 .6163 L F
.469 .209 .437 r
.43894 .66923 m .43613 .67199 L .43673 .66975 L F
.011 0 .137 r
.55353 .58465 m .55536 .58365 L .55579 .58161 L F
.089 0 .295 r
.55491 .58577 m .55353 .58465 L .55315 .58681 L F
.55491 .58577 m .55536 .58365 L .55353 .58465 L F
.527 .44 .7 r
.3033 .61635 m .30378 .61813 L .30174 .61861 L F
.237 .084 .461 r
.30378 .61813 m .30229 .62107 L .30174 .61861 L F
.708 .857 .953 r
.69686 .46702 m .69304 .46667 L .69561 .46598 L F
.796 .912 .919 r
.69841 .46543 m .69686 .46702 L .69561 .46598 L F
.841 .956 .888 r
.56303 .61511 m .56616 .6137 L .56401 .6142 L F
.898 .634 .53 r
.56065 .61472 m .56119 .61542 L .56303 .61511 L F
.641 .783 .949 r
.56052 .61602 m .5628 .61642 L .56303 .61511 L F
.56052 .61602 m .5628 .61642 L .56303 .61511 L F
.898 .634 .53 r
.56119 .61542 m .56284 .61756 L .56303 .61511 L F
.841 .956 .888 r
.56303 .61511 m .5628 .61642 L .56479 .61481 L F
.56303 .61511 m .56479 .61481 L .56616 .6137 L F
.517 .746 .978 r
.56616 .6137 m .56712 .61189 L .56401 .6142 L F
.56616 .6137 m .56837 .61314 L .56712 .61189 L F
.487 .259 .494 r
.59579 .60392 m .59818 .60338 L .59593 .60182 L F
.522 .242 .431 r
.59593 .60182 m .59818 .60338 L .59835 .60145 L F
.829 .442 .318 r
.50437 .78389 m .50569 .78341 L .50433 .78506 L F
.531 .553 .822 r
.30361 .62046 m .30295 .62401 L .30229 .62107 L F
.30361 .62046 m .30493 .6237 L .30295 .62401 L F
.262 0 0 r
.33891 .62778 m .33812 .62889 L .34031 .62831 L F
.306 .278 .664 r
.75372 .49015 m .75399 .49438 L .75244 .49401 L F
.373 .244 .572 r
.75399 .49438 m .7526 .49638 L .75244 .49401 L F
.694 .77 .91 r
.68936 .50777 m .69316 .50799 L .69226 .5049 L F
.811 .754 .799 r
.69226 .5049 m .69316 .50799 L .69547 .50506 L F
.682 .618 .778 r
.7533 .51068 m .75382 .51404 L .75143 .51344 L F
.498 .503 .792 r
.2658 .61589 m .26637 .61205 L .26438 .61245 L F
.2658 .61589 m .2676 .61539 L .26637 .61205 L F
.371 0 .086 r
.45946 .64343 m .46176 .6431 L .46289 .64133 L F
.131 0 0 r
.46289 .64133 m .46376 .64225 L .46486 .64037 L F
.46289 .64133 m .46176 .6431 L .46376 .64225 L F
.954 .688 .493 r
.75382 .51404 m .75388 .51638 L .75229 .51549 L F
.437 .44 .765 r
.7556 .51322 m .75382 .51404 L .7533 .51068 L F
.392 .331 .669 r
.7556 .51322 m .75617 .51573 L .75382 .51404 L F
.492 .312 .565 r
.75382 .51404 m .75617 .51573 L .75388 .51638 L F
.697 .393 .457 r
.4868 .79699 m .48264 .79466 L .48378 .79559 L F
.795 .325 .113 r
.48481 .79751 m .4868 .79699 L .48378 .79559 L F
0 0 .527 r
.4847 .79635 m .48378 .79559 L .48458 .79512 L F
.48481 .79751 m .48378 .79559 L .4847 .79635 L F
.697 .393 .457 r
.48264 .79466 m .48237 .7945 L .48378 .79559 L F
0 0 0 r
.62657 .57227 m .62602 .57588 L .62588 .57641 L F
.62624 .57704 m .62588 .57641 L .62602 .57588 L F
.62624 .57704 m .62521 .57862 L .62588 .57641 L F
.551 .583 .839 r
.35701 .6018 m .35785 .5985 L .35569 .59909 L F
.35701 .6018 m .35915 .60151 L .35785 .5985 L F
.694 .689 .841 r
.69986 .47339 m .70044 .47625 L .70349 .4741 L F
0 0 0 r
.58795 .5676 m .58721 .56897 L .58525 .57001 L F
.58795 .5676 m .5896 .56634 L .58721 .56897 L F
.542 .333 .546 r
.26822 .64425 m .27086 .64178 L .2715 .64437 L F
.958 .667 .44 r
.2715 .64437 m .26998 .64571 L .26822 .64425 L F
.64 .585 .777 r
.2715 .64437 m .26946 .64702 L .27155 .64657 L F
.958 .667 .44 r
.2715 .64437 m .27155 .64657 L .26998 .64571 L F
.309 .053 .353 r
.67262 .50856 m .67264 .51036 L .67508 .50766 L F
.568 .187 .281 r
.67066 .4747 m .67311 .47586 L .67428 .4751 L F
.31 0 0 r
.67428 .4751 m .67311 .47586 L .67645 .47544 L F
.368 0 .03 r
.67428 .4751 m .67645 .47544 L .6769 .47465 L F
0 .135 .623 r
.71041 .49139 m .71126 .49186 L .7126 .49045 L F
.579 .424 .635 r
.58276 .6102 m .58456 .60708 L .58229 .60732 L F
.87 .738 .714 r
.57383 .635 m .57179 .63858 L .57413 .63847 L F
.827 .619 .622 r
.57097 .64053 m .57413 .63847 L .57179 .63858 L F
.57097 .64053 m .57428 .6411 L .57413 .63847 L F
.919 .946 .801 r
.74708 .5224 m .74823 .51878 L .74912 .51976 L F
.593 .471 .683 r
.54223 .77467 m .54486 .77435 L .54476 .77416 L F
.54223 .77467 m .5426 .77737 L .54486 .77435 L F
.066 .367 .835 r
.5345 .61903 m .535 .61797 L .53352 .61774 L F
.5345 .61903 m .53709 .62061 L .535 .61797 L F
.718 .66 .792 r
.58951 .71468 m .58695 .71185 L .5882 .71504 L F
.317 0 .007 r
.51977 .70086 m .51613 .7029 L .51744 .70146 L F
.017 0 .414 r
.55074 .75751 m .55052 .76012 L .55204 .75932 L F
.537 .41 .654 r
.61384 .52236 m .61572 .51917 L .61336 .51971 L F
.79 .377 .266 r
.7439 .52172 m .7458 .52281 L .74708 .5224 L F
.919 .946 .801 r
.74708 .5224 m .7458 .52281 L .74593 .52259 L F
.693 .184 .022 r
.74708 .5224 m .74593 .52259 L .7439 .52172 L F
.822 .763 .797 r
.74823 .51878 m .74593 .52259 L .74508 .51868 L F
.74593 .52259 m .7458 .52281 L .74576 .52255 L F
.74593 .52259 m .74576 .52255 L .74508 .51868 L F
.693 .184 .022 r
.74593 .52259 m .74586 .5226 L .74576 .52255 L F
.74593 .52259 m .74576 .52255 L .7439 .52172 L F
.611 .621 .837 r
.74576 .52255 m .7458 .52281 L .7439 .52172 L F
.693 .184 .022 r
.74586 .5226 m .74538 .52268 L .7439 .52172 L F
.611 .621 .837 r
.74508 .51868 m .74576 .52255 L .7439 .52172 L F
.919 .946 .801 r
.74708 .5224 m .74593 .52259 L .74823 .51878 L F
.693 .184 .022 r
.74708 .5224 m .74672 .52354 L .74538 .52268 L F
.932 .609 .155 r
.74708 .5224 m .74754 .52473 L .74672 .52354 L F
.616 .408 .576 r
.49066 .78639 m .49428 .78597 L .49413 .78298 L F
.556 .361 .573 r
.49428 .78597 m .49625 .78517 L .49413 .78298 L F
.094 0 .08 r
.5648 .5724 m .56557 .57091 L .56307 .5734 L F
.079 0 0 r
.5648 .5724 m .56779 .5702 L .56557 .57091 L F
.022 .555 .852 r
.31735 .58387 m .31913 .58422 L .32077 .58488 L F
.24 .71 .944 r
.31913 .58422 m .32334 .58496 L .32077 .58488 L F
.978 .698 .421 r
.73241 .49144 m .73126 .49288 L .73189 .48988 L F
.73241 .49144 m .73241 .49364 L .73126 .49288 L F
.644 .452 .609 r
.39539 .60387 m .39548 .60694 L .39305 .60735 L F
.482 .415 .706 r
.39733 .60127 m .39539 .60387 L .39499 .60185 L F
.39733 .60127 m .39791 .60402 L .39539 .60387 L F
.294 .181 .55 r
.39732 .60604 m .39539 .60387 L .39791 .60402 L F
.39732 .60604 m .39548 .60694 L .39539 .60387 L F
.472 .763 .994 r
.31603 .62654 m .3155 .62824 L .31422 .62652 L F
.31603 .62654 m .31761 .62789 L .3155 .62824 L F
0 0 .469 r
.52688 .60964 m .52631 .60709 L .5267 .60757 L F
.462 .848 .982 r
.49288 .62146 m .49645 .62142 L .49437 .62239 L F
.432 .151 .385 r
.35141 .62103 m .35354 .62055 L .35415 .61742 L F
.419 .168 .424 r
.35415 .61742 m .35608 .61798 L .35681 .61512 L F
.465 .18 .396 r
.35415 .61742 m .3558 .62004 L .35608 .61798 L F
.35415 .61742 m .35354 .62055 L .3558 .62004 L F
.705 .687 .83 r
.7036 .50229 m .70711 .50298 L .70643 .50193 L F
.656 .669 .85 r
.70643 .50193 m .70711 .50298 L .70956 .50215 L F
.106 .585 .91 r
.50057 .62121 m .49994 .6216 L .49863 .62076 L F
.50057 .62121 m .501 .62168 L .49994 .6216 L F
.476 .183 .387 r
.50259 .65441 m .5006 .65302 L .50369 .65184 L F
.624 .847 .985 r
.50557 .65029 m .50369 .65184 L .50208 .65064 L F
.50557 .65029 m .50757 .65053 L .50369 .65184 L F
.557 .269 .434 r
.50757 .65053 m .50529 .65231 L .50369 .65184 L F
.50529 .65231 m .50321 .65297 L .50369 .65184 L F
.602 .535 .752 r
.50208 .65064 m .50294 .65279 L .50507 .65238 L F
.50529 .65231 m .50507 .65238 L .50547 .6523 L F
.557 .269 .434 r
.50529 .65231 m .50502 .65414 L .50259 .65441 L F
.50757 .65053 m .50641 .65218 L .50529 .65231 L F
.875 .435 .087 r
.50604 .64834 m .50757 .65053 L .50557 .65029 L F
.485 .12 .27 r
.50836 .65186 m .50724 .65262 L .50757 .65053 L F
.50724 .65262 m .50502 .65414 L .50651 .65224 L F
.512 .198 .372 r
.50502 .65414 m .50723 .6522 L .50651 .65224 L F
.557 .269 .434 r
.50565 .65229 m .50502 .65414 L .50529 .65231 L F
.512 .198 .372 r
.50502 .65414 m .50651 .65224 L .50565 .65228 L F
.557 .269 .434 r
.50635 .65226 m .50502 .65414 L .50565 .65229 L F
.512 .198 .372 r
.50502 .65414 m .50565 .65228 L .50553 .65229 L F
.485 .12 .27 r
.50651 .65224 m .50502 .65414 L .50641 .65218 L F
.50724 .65262 m .50641 .65218 L .50757 .65053 L F
.629 .547 .744 r
.50641 .65218 m .50723 .6522 L .50723 .65208 L F
.50565 .65228 m .50651 .65224 L .50641 .65218 L F
.50651 .65224 m .50723 .6522 L .50641 .65218 L F
.875 .435 .087 r
.50604 .64834 m .50836 .65186 L .50757 .65053 L F
.824 .527 .487 r
.50855 .64983 m .50836 .65186 L .50604 .64834 L F
.629 .547 .744 r
.50553 .65229 m .50565 .65228 L .50719 .64871 L F
.557 .269 .434 r
.50641 .65218 m .50554 .6523 L .50529 .65231 L F
.629 .547 .744 r
.50565 .65228 m .50723 .65208 L .50719 .64871 L F
.557 .269 .434 r
.50641 .65218 m .50635 .65226 L .50554 .6523 L F
.602 .535 .752 r
.50546 .65226 m .50529 .65231 L .50553 .65229 L F
.50529 .65231 m .50547 .6523 L .50553 .65229 L F
.50208 .65064 m .50507 .65238 L .50546 .65226 L F
.557 .269 .434 r
.50507 .65238 m .50259 .65441 L .50321 .65297 L F
.558 .271 .436 r
.50507 .65238 m .50259 .65441 L .50294 .65279 L F
.50553 .65229 m .50259 .65441 L .50507 .65238 L F
.557 .269 .434 r
.50529 .65231 m .50259 .65441 L .50507 .65238 L F
.734 .532 .619 r
.58568 .70867 m .58923 .70651 L .5858 .70629 L F
.58568 .70867 m .58913 .70907 L .58923 .70651 L F
.55 .337 .544 r
.59285 .61858 m .59051 .62124 L .59046 .61871 L F
.196 0 .193 r
.59086 .56509 m .59349 .56248 L .59288 .56379 L F
.205 0 0 r
.59288 .56379 m .5896 .56634 L .59086 .56509 L F
.488 .185 .377 r
.44678 .64936 m .44903 .64909 L .44951 .64738 L F
.41 .114 .348 r
.44951 .64738 m .4511 .64855 L .45169 .64681 L F
.44951 .64738 m .44903 .64909 L .4511 .64855 L F
.606 .384 .552 r
.59739 .54206 m .59993 .54189 L .60002 .5395 L F
.571 .378 .581 r
.59993 .54189 m .60238 .53893 L .60002 .5395 L F
.433 0 0 r
.49285 .69827 m .49526 .69832 L .49854 .6977 L F
.326 .376 .761 r
.47808 .77697 m .47988 .77742 L .47863 .77363 L F
.685 .395 .476 r
.5806 .66691 m .57708 .66909 L .57716 .66679 L F
.5806 .66691 m .58042 .66882 L .57708 .66909 L F
.595 .317 .464 r
.5806 .66691 m .58291 .66884 L .58042 .66882 L F
.571 .324 .503 r
.58315 .66665 m .58291 .66884 L .5806 .66691 L F
.801 .629 .669 r
.57594 .60977 m .5775 .61039 L .57628 .60739 L F
.857 .642 .61 r
.57594 .60977 m .57752 .61297 L .5775 .61039 L F
.716 .591 .715 r
.57628 .60739 m .5775 .61039 L .57981 .60764 L F
.918 .852 .762 r
.63118 .53611 m .62943 .53916 L .63158 .53862 L F
.75 .491 .54 r
.62876 .54109 m .63158 .53862 L .62943 .53916 L F
.62876 .54109 m .63077 .54205 L .63158 .53862 L F
.753 .744 .844 r
.60896 .55898 m .61069 .5594 L .60695 .55912 L F
.536 .371 .605 r
.61069 .5594 m .60695 .56138 L .60695 .55912 L F
.653 .708 .888 r
.71539 .50455 m .71678 .50739 L .71912 .50525 L F
.484 .233 .458 r
.38543 .61301 m .38281 .61556 L .38324 .61359 L F
.095 0 0 r
.54027 .65295 m .54385 .65283 L .54211 .65273 L F
.664 .124 0 r
.54397 .65283 m .54027 .65295 L .54389 .65251 L F
.5444 .65465 m .54027 .65295 L .54397 .65283 L F
.095 0 0 r
.54027 .65295 m .5439 .65284 L .54385 .65283 L F
.852 .949 .879 r
.26428 .65134 m .26719 .6499 L .26531 .64984 L F
.373 0 0 r
.48482 .70091 m .48342 .70238 L .48103 .70251 L F
0 0 0 r
.48755 .69864 m .48534 .70094 L .48482 .70091 L F
.48482 .70091 m .48534 .70094 L .48342 .70238 L F
.488 .282 .525 r
.59557 .56104 m .59288 .56379 L .59349 .56248 L F
.191 .531 .923 r
.37622 .59106 m .37591 .59222 L .37387 .59068 L F
.37622 .59106 m .37754 .59253 L .37591 .59222 L F
.769 .646 .726 r
.68524 .51342 m .68647 .51684 L .68862 .51388 L F
.216 0 0 r
.48885 .70001 m .49285 .69827 L .48904 .69819 L F
.48885 .70001 m .49151 .69957 L .49285 .69827 L F
.565 .07 .039 r
.49285 .69827 m .49151 .69957 L .49519 .6997 L F
.537 .146 .247 r
.49285 .69827 m .49519 .6997 L .49526 .69832 L F
.384 .078 .319 r
.36308 .62968 m .36215 .63242 L .35989 .6326 L F
.423 .106 .322 r
.36526 .62928 m .36215 .63242 L .36308 .62968 L F
.512 .568 .848 r
.48402 .65789 m .48293 .65513 L .48089 .65583 L F
.48402 .65789 m .48541 .65812 L .48293 .65513 L F
0 0 0 r
.75434 .52126 m .75184 .52424 L .75224 .52243 L F
.554 .416 .648 r
.40657 .6669 m .40904 .669 L .40888 .66648 L F
.40657 .6669 m .40681 .66945 L .40904 .669 L F
.342 .411 .788 r
.57242 .63337 m .57543 .63495 L .57383 .635 L F
.57383 .635 m .57543 .63495 L .57242 .63337 L F
.77 .781 .861 r
.48417 .80824 m .48729 .80781 L .48476 .80714 L F
.777 .647 .718 r
.48518 .81125 m .48729 .80781 L .48417 .80824 L F
.6 .817 .983 r
.48476 .80714 m .48729 .80781 L .48949 .80706 L F
.813 .757 .8 r
.58512 .64923 m .58352 .65334 L .58255 .65227 L F
0 0 .283 r
.58352 .65334 m .5839 .65548 L .58255 .65227 L F
.58352 .65334 m .5841 .65566 L .5839 .65548 L F
.255 .143 .527 r
.58702 .65142 m .58352 .65334 L .58512 .64923 L F
.237 .116 .504 r
.58672 .65339 m .58352 .65334 L .58702 .65142 L F
.58672 .65339 m .5841 .65566 L .58352 .65334 L F
.759 .73 .826 r
.50282 .81174 m .50382 .81425 L .50599 .81196 L F
.809 .67 .711 r
.6501 .48788 m .64854 .49056 L .65288 .48995 L F
.905 .891 .806 r
.64864 .49295 m .65288 .48995 L .64854 .49056 L F
.64864 .49295 m .64971 .49411 L .65288 .48995 L F
.172 .11 .54 r
.56945 .61591 m .57065 .61178 L .56837 .61314 L F
.56945 .61591 m .57109 .61583 L .57065 .61178 L F
0 0 0 r
.56899 .61771 m .57109 .61583 L .56945 .61591 L F
.673 .836 .961 r
.39383 .59808 m .39178 .59908 L .39035 .59799 L F
.39383 .59808 m .39178 .59908 L .39035 .59799 L F
0 0 0 r
.47371 .6506 m .47308 .65104 L .46998 .65183 L F
.982 .693 .364 r
.47222 .65128 m .47319 .65013 L .47118 .65099 L F
.47482 .65201 m .4738 .65083 L .47222 .65128 L F
.4738 .65083 m .47319 .65013 L .47222 .65128 L F
0 0 0 r
.47308 .65104 m .47308 .65104 L .47303 .65105 L F
.47308 .65104 m .47303 .65105 L .46998 .65183 L F
.402 .799 .986 r
.46998 .65183 m .47308 .65104 L .47118 .65099 L F
.608 .792 .969 r
.47308 .65104 m .47482 .65201 L .47118 .65099 L F
.982 .693 .364 r
.47482 .65201 m .47463 .65367 L .47374 .65147 L F
.917 .6 .43 r
.47544 .65165 m .47308 .65104 L .47371 .6506 L F
.982 .693 .364 r
.47442 .65154 m .47374 .65147 L .47319 .65013 L F
.917 .6 .43 r
.47584 .6519 m .47482 .65201 L .47308 .65104 L F
.982 .693 .364 r
.47482 .65201 m .47374 .65147 L .47442 .65154 L F
.917 .6 .43 r
.47584 .6519 m .47485 .65159 L .47544 .65165 L F
.47485 .65159 m .47308 .65104 L .47544 .65165 L F
.458 .188 .415 r
.52213 .80547 m .5245 .80309 L .52464 .80452 L F
.798 .953 .918 r
.52671 .80068 m .5245 .80309 L .52406 .80201 L F
.439 .563 .883 r
.52464 .80452 m .52406 .80201 L .5245 .80309 L F
.711 .749 .881 r
.52758 .80237 m .5245 .80309 L .52671 .80068 L F
.544 .217 .363 r
.52758 .80237 m .52464 .80452 L .5245 .80309 L F
.318 0 0 r
.52117 .78653 m .51779 .78828 L .52069 .78811 L F
.241 0 .245 r
.52346 .78564 m .52117 .78653 L .52069 .78811 L F
.65 .847 .976 r
.49057 .62185 m .48861 .6227 L .4871 .62168 L F
.329 .467 .847 r
.2676 .61539 m .26923 .61849 L .27077 .61824 L F
.895 .77 .716 r
.72095 .50408 m .72303 .50317 L .72177 .5023 L F
.72095 .50408 m .72229 .50547 L .72303 .50317 L F
.021 .49 .876 r
.25616 .64873 m .25835 .65015 L .25619 .6493 L F
.25619 .6493 m .25835 .65015 L .25616 .64873 L F
.25619 .6493 m .25835 .65015 L .25616 .64873 L F
.816 .737 .777 r
.69226 .5049 m .69547 .50506 L .69444 .50197 L F
.779 .719 .796 r
.69444 .50197 m .69547 .50506 L .69784 .50236 L F
.646 .75 .925 r
.31234 .62666 m .30849 .62587 L .31108 .62536 L F
.291 .731 .965 r
.31257 .6258 m .31234 .62666 L .31108 .62536 L F
.31257 .6258 m .31422 .62652 L .31234 .62666 L F
0 0 0 r
.72117 .47063 m .71835 .47425 L .71975 .47262 L F
.266 .322 .735 r
.72117 .47063 m .72189 .46756 L .71944 .46801 L F
.872 .84 .811 r
.63361 .51934 m .63271 .52175 L .63399 .52234 L F
.909 .729 .645 r
.63116 .52409 m .63399 .52234 L .63271 .52175 L F
.63116 .52409 m .63361 .52524 L .63399 .52234 L F
.84 .821 .83 r
.63361 .51934 m .63399 .52234 L .63648 .51933 L F
.423 .134 .366 r
.57713 .55903 m .57941 .55848 L .57985 .55606 L F
.471 .201 .422 r
.57941 .55848 m .58189 .55543 L .57985 .55606 L F
.743 .634 .738 r
.5789 .71477 m .58242 .71513 L .5812 .71186 L F
.259 .693 .963 r
.36633 .5897 m .3625 .58871 L .36474 .58879 L F
.165 .624 .934 r
.36821 .58994 m .36633 .5897 L .36474 .58879 L F
.561 .936 .87 r
.53832 .59833 m .53927 .59718 L .54139 .59605 L F
.53832 .59833 m .5379 .5981 L .53927 .59718 L F
.438 .459 .784 r
.4065 .69228 m .40818 .69181 L .40542 .68969 L F
0 0 .185 r
.40664 .69526 m .40818 .69181 L .4065 .69228 L F
.74 .624 .73 r
.60576 .55575 m .60351 .55858 L .60384 .55671 L F
0 0 0 r
.33259 .64574 m .33666 .64412 L .33481 .64511 L F
.067 0 0 r
.33666 .64412 m .33677 .64477 L .33481 .64511 L F
.33666 .64412 m .33881 .64368 L .33677 .64477 L F
.937 .897 .763 r
.67955 .5041 m .67871 .50637 L .67755 .50524 L F
.248 0 0 r
.52541 .69833 m .52406 .69957 L .52175 .69988 L F
.631 .232 .27 r
.52763 .69814 m .52406 .69957 L .52541 .69833 L F
.02 0 0 r
.55579 .58161 m .55762 .58112 L .55802 .58055 L F
.229 0 .209 r
.55579 .58161 m .55723 .58287 L .55762 .58112 L F
.55579 .58161 m .55536 .58365 L .55723 .58287 L F
.522 .08 .139 r
.45588 .70392 m .45443 .70564 L .45218 .70538 L F
.263 0 0 r
.45812 .70375 m .45443 .70564 L .45588 .70392 L F
.53 .203 .358 r
.42481 .65787 m .42719 .65772 L .42784 .65605 L F
.575 .299 .461 r
.42719 .65772 m .42985 .65544 L .42784 .65605 L F
.666 .476 .619 r
.58568 .70867 m .58341 .70651 L .58346 .70903 L F
.58568 .70867 m .5858 .70629 L .58341 .70651 L F
.386 .428 .781 r
.43472 .69409 m .43414 .69741 L .43248 .69443 L F
.43472 .69409 m .43581 .69746 L .43414 .69741 L F
.131 .63 .907 r
.2465 .69718 m .24846 .6979 L .2481 .69786 L F
.543 .842 .999 r
.35227 .59917 m .35358 .5997 L .35569 .59909 L F
0 0 .074 r
.51614 .65039 m .51539 .65272 L .51642 .65133 L F
.51614 .65039 m .51642 .65133 L .51447 .64927 L F
.882 .554 .423 r
.6129 .56417 m .6108 .56411 L .61052 .56184 L F
.939 .785 .663 r
.6129 .56417 m .61057 .56656 L .6108 .56411 L F
.6129 .56417 m .6121 .56761 L .61057 .56656 L F
.423 .204 .474 r
.54631 .78045 m .54849 .77735 L .54705 .77585 L F
.54631 .78045 m .54844 .77949 L .54849 .77735 L F
.535 .423 .673 r
.58373 .62974 m .58407 .63217 L .58166 .63365 L F
.585 .485 .707 r
.58482 .63514 m .58166 .63365 L .58407 .63217 L F
.58482 .63514 m .58245 .63563 L .58166 .63365 L F
.954 .679 .477 r
.49046 .70093 m .48919 .70256 L .48885 .70001 L F
.562 .131 .181 r
.49277 .70226 m .48919 .70256 L .49046 .70093 L F
.605 .358 .516 r
.48195 .66388 m .48185 .66625 L .47963 .66401 L F
.48195 .66388 m .48185 .66625 L .47963 .66401 L F
.976 .712 .466 r
.40664 .69526 m .40698 .69711 L .40555 .69698 L F
0 0 .185 r
.40664 .69526 m .40774 .6944 L .40818 .69181 L F
.547 .652 .904 r
.40698 .69711 m .40774 .6944 L .40664 .69526 L F
.081 0 0 r
.32447 .60148 m .32317 .60194 L .32105 .60219 L F
.23 0 0 r
.32447 .60148 m .32549 .60201 L .32317 .60194 L F
.32447 .60148 m .32685 .60178 L .32549 .60201 L F
.565 .487 .725 r
.40542 .68969 m .40699 .68599 L .40512 .6867 L F
.999 .791 .453 r
.58271 .64984 m .58255 .65227 L .58159 .65146 L F
.813 .757 .8 r
.58512 .64923 m .58255 .65227 L .58271 .64984 L F
.586 .211 .299 r
.58159 .65146 m .58512 .64923 L .58271 .64984 L F
.681 .733 .889 r
.50132 .64593 m .50275 .64764 L .49908 .64681 L F
.683 .733 .889 r
.50132 .64593 m .50275 .64764 L .50492 .6466 L F
0 0 0 r
.62291 .58562 m .62101 .58915 L .62178 .58746 L F
.287 .093 .434 r
.41359 .66004 m .41538 .65987 L .41574 .65945 L F
.41359 .66004 m .41375 .6611 L .41538 .65987 L F
.975 .855 .657 r
.62825 .56705 m .62915 .56495 L .62809 .56397 L F
.238 0 .268 r
.56233 .575 m .5648 .5724 L .56307 .5734 L F
.591 .434 .638 r
.60234 .53655 m .60478 .53616 L .60446 .53354 L F
.568 .374 .578 r
.60238 .53893 m .60478 .53616 L .60234 .53655 L F
.929 .79 .685 r
.73199 .49936 m .73012 .49905 L .7313 .49618 L F
.955 .856 .704 r
.73199 .49936 m .7296 .50151 L .73012 .49905 L F
.73199 .49936 m .73068 .50255 L .7296 .50151 L F
.561 .599 .848 r
.30743 .62319 m .30604 .62526 L .30493 .6237 L F
.30743 .62319 m .30849 .62587 L .30604 .62526 L F
.708 .679 .82 r
.54772 .61025 m .54969 .6123 L .54991 .61004 L F
.515 .341 .584 r
.54969 .6123 m .55272 .60932 L .54991 .61004 L F
.64 .674 .866 r
.28412 .63788 m .28569 .64041 L .28795 .63916 L F
.554 .438 .675 r
.42868 .68933 m .42892 .69172 L .4268 .69204 L F
.812 .328 0 r
.53799 .62163 m .53924 .62369 L .53789 .62284 L F
.585 .628 .861 r
.47941 .80456 m .47999 .80854 L .48308 .80593 L F
.674 .749 .906 r
.48166 .80843 m .48308 .80593 L .47999 .80854 L F
.926 .75 .644 r
.49884 .79405 m .49948 .79162 L .49766 .79087 L F
.477 .194 .404 r
.38281 .61556 m .38011 .61793 L .38079 .61626 L F
.777 .715 .794 r
.68304 .51431 m .68084 .51708 L .6831 .5161 L F
.683 .601 .759 r
.6831 .5161 m .68524 .51342 L .68304 .51431 L F
.6831 .5161 m .68647 .51684 L .68524 .51342 L F
.507 .33 .575 r
.60924 .52805 m .61145 .52748 L .61132 .52513 L F
.493 .317 .571 r
.60924 .52805 m .61156 .52984 L .61145 .52748 L F
.60924 .52805 m .60933 .53059 L .61156 .52984 L F
.715 .206 .02 r
.48389 .64626 m .48121 .64595 L .48207 .6474 L F
.48389 .64626 m .48258 .64694 L .48121 .64595 L F
.729 .968 .706 r
.4854 .64385 m .48262 .64685 L .48389 .64626 L F
.145 .404 .851 r
.48232 .64621 m .48258 .64694 L .48121 .64595 L F
.82 .811 .842 r
.48172 .64493 m .48262 .64685 L .4854 .64385 L F
.145 .404 .851 r
.48284 .64632 m .48262 .64685 L .48232 .64621 L F
.48262 .64685 m .48258 .64694 L .48232 .64621 L F
.48172 .64493 m .48284 .64632 L .48121 .64595 L F
.82 .811 .842 r
.48172 .64493 m .48249 .64698 L .48262 .64685 L F
.729 .968 .706 r
.48262 .64685 m .48249 .64698 L .48258 .64694 L F
.48262 .64685 m .48258 .64694 L .48389 .64626 L F
.145 .404 .851 r
.48284 .64632 m .48437 .64823 L .48258 .64694 L F
.48437 .64823 m .48443 .6483 L .48121 .64595 L F
.2 .419 .85 r
.48121 .64595 m .48443 .6483 L .48372 .64847 L F
.715 .206 .02 r
.48258 .64694 m .48249 .64698 L .48121 .64595 L F
.729 .968 .706 r
.4854 .64385 m .48389 .64626 L .48619 .64602 L F
.494 .377 .649 r
.40481 .67237 m .40704 .6744 L .4069 .67184 L F
.40481 .67237 m .4049 .67542 L .40704 .6744 L F
.124 .261 .734 r
.56303 .61511 m .56402 .61813 L .5628 .61642 L F
.339 0 0 r
.46168 .70285 m .46038 .70367 L .45812 .70375 L F
.383 0 0 r
.46386 .70286 m .46038 .70367 L .46168 .70285 L F
.657 .718 .893 r
.70126 .49284 m .6989 .49365 L .69763 .49125 L F
.757 .439 .446 r
.5006 .65302 m .5003 .65486 L .49836 .65207 L F
.5006 .65302 m .5003 .65486 L .49836 .65207 L F
.393 .704 .984 r
.26544 .63515 m .26783 .6359 L .26533 .63456 L F
.522 .404 .659 r
.2668 .63823 m .26836 .63628 L .26783 .6359 L F
.419 0 0 r
.26783 .6359 m .26836 .63628 L .26533 .63456 L F
.582 .525 .756 r
.5006 .65302 m .50294 .65279 L .50208 .65064 L F
.476 .183 .387 r
.5006 .65302 m .50259 .65441 L .50294 .65279 L F
.5006 .65302 m .5003 .65486 L .50259 .65441 L F
.50259 .65441 m .5003 .65486 L .5006 .65302 L F
.68 .505 .643 r
.57323 .71232 m .57312 .71485 L .57542 .71194 L F
.538 .017 0 r
.63855 .48817 m .64304 .48961 L .64212 .48833 L F
.054 .537 .889 r
.64304 .48961 m .6445 .49043 L .64212 .48833 L F
.843 .939 .888 r
.53346 .59993 m .53123 .60209 L .53149 .59976 L F
.827 .928 .899 r
.53149 .59976 m .53123 .60209 L .53003 .60134 L F
.037 0 .167 r
.56002 .57811 m .56233 .575 L .5605 .57611 L F
.911 .829 .752 r
.43185 .71045 m .43012 .71216 L .42924 .7117 L F
.006 0 0 r
.43224 .71085 m .43012 .71216 L .43185 .71045 L F
.544 .217 .363 r
.52758 .80237 m .52687 .80493 L .52464 .80452 L F
.265 .487 .885 r
.52671 .80068 m .52907 .80193 L .52758 .80237 L F
.055 0 .173 r
.52758 .80237 m .52907 .80193 L .52687 .80493 L F
.675 .193 .099 r
.51751 .65337 m .51773 .65446 L .51539 .65272 L F
.577 .312 .478 r
.52073 .65234 m .51773 .65446 L .51751 .65337 L F
.718 .66 .792 r
.58951 .71468 m .58899 .71134 L .58695 .71185 L F
.742 .676 .787 r
.58951 .71468 m .591 .71237 L .58899 .71134 L F
.263 .723 .951 r
.35885 .58849 m .35679 .58864 L .35543 .58795 L F
.69 .77 .913 r
.74459 .53007 m .74664 .53089 L .74189 .53106 L F
.709 .461 .547 r
.74189 .53106 m .74664 .53089 L .7454 .53196 L F
.744 .755 .861 r
.748 .52883 m .74664 .53089 L .74459 .53007 L F
.586 .281 .418 r
.7454 .53196 m .74664 .53089 L .74737 .53209 L F
.949 .713 .548 r
.62852 .55784 m .63016 .55638 L .62887 .55541 L F
.62852 .55784 m .63003 .55872 L .63016 .55638 L F
.913 .705 .607 r
.58255 .65227 m .5839 .65548 L .58195 .65392 L F
.87 .425 .096 r
.5839 .65548 m .5824 .65495 L .58195 .65392 L F
.035 .541 .874 r
.5841 .65566 m .5824 .65495 L .5839 .65548 L F
.955 .768 .612 r
.58442 .65749 m .58514 .66114 L .58331 .65895 L F
0 0 0 r
.58218 .66177 m .58331 .65895 L .58514 .66114 L F
.408 .394 .732 r
.58624 .65743 m .58514 .66114 L .58442 .65749 L F
.58624 .65743 m .58672 .66043 L .58514 .66114 L F
.778 .55 .591 r
.58672 .66043 m .58637 .66256 L .58514 .66114 L F
.591 .521 .745 r
.58862 .65974 m .58682 .66193 L .58672 .66043 L F
.067 .066 .546 r
.58637 .66256 m .58555 .66373 L .58522 .66167 L F
.58637 .66256 m .58522 .66167 L .58566 .66174 L F
.778 .55 .591 r
.58672 .66043 m .58579 .66318 L .58637 .66256 L F
.591 .521 .745 r
.58682 .66193 m .58579 .66318 L .58625 .66183 L F
.58682 .66193 m .58625 .66183 L .58672 .66043 L F
.067 .066 .546 r
.58566 .66174 m .58522 .66167 L .58514 .66114 L F
.99 .81 .567 r
.27716 .62535 m .27797 .62367 L .27563 .62421 L F
.27716 .62535 m .27651 .6257 L .27797 .62367 L F
.227 0 .04 r
.27797 .62367 m .27707 .62493 L .27892 .62487 L F
.27707 .62493 m .27651 .6257 L .27816 .62513 L F
.27707 .62493 m .27816 .62513 L .27892 .62487 L F
.13 .25 .721 r
.27643 .62481 m .27631 .62703 L .27716 .62535 L F
.27563 .62421 m .27574 .62468 L .27643 .62481 L F
.27574 .62468 m .27631 .62703 L .27643 .62481 L F
.686 .857 .45 r
.27631 .62703 m .27535 .62842 L .27716 .62535 L F
.657 .583 .76 r
.57312 .71485 m .5742 .71822 L .57661 .71765 L F
.754 .859 .927 r
.24808 .69816 m .24846 .6979 L .2465 .69718 L F
.898 .828 .768 r
.63221 .52758 m .63039 .53013 L .63239 .53056 L F
.757 .569 .643 r
.63039 .53013 m .63234 .53164 L .63239 .53056 L F
.599 .894 .989 r
.47925 .81427 m .48275 .81397 L .48169 .81363 L F
.358 .737 .988 r
.66134 .52314 m .6598 .52211 L .65746 .52218 L F
.136 .677 .834 r
.66355 .52226 m .6598 .52211 L .66134 .52314 L F
.594 .506 .724 r
.463 .65823 m .46367 .66076 L .46108 .66102 L F
.192 .343 .788 r
.51539 .65272 m .51773 .65446 L .51642 .65133 L F
.529 .386 .631 r
.5426 .77737 m .54529 .77762 L .54486 .77435 L F
.199 .153 .578 r
.61204 .60525 m .60939 .61016 L .61047 .60693 L F
.61204 .60525 m .61254 .6078 L .61121 .6088 L F
.61065 .60782 m .61121 .6088 L .60939 .61016 L F
.61204 .60525 m .61121 .6088 L .61065 .60782 L F
0 0 .337 r
.61037 .61014 m .60939 .61016 L .61035 .61075 L F
0 0 .09 r
.61037 .61014 m .61254 .6078 L .611 .61013 L F
.60939 .61016 m .61096 .60898 L .61034 .61014 L F
0 0 .337 r
.61047 .60693 m .60939 .61016 L .61037 .61014 L F
.61032 .61021 m .61035 .61075 L .61019 .61042 L F
0 0 .09 r
.61014 .61051 m .611 .61013 L .6106 .61072 L F
.60939 .61016 m .61037 .61014 L .61014 .61051 L F
0 0 .337 r
.61037 .61014 m .61035 .61075 L .61032 .61021 L F
0 0 .09 r
.61037 .61014 m .611 .61013 L .61014 .61051 L F
0 0 .337 r
.61045 .60747 m .61037 .61014 L .61017 .60698 L F
.61037 .61014 m .61032 .61021 L .61017 .60698 L F
.505 .276 .5 r
.60869 .60725 m .61019 .61042 L .60609 .60989 L F
0 0 0 r
.61014 .61051 m .61035 .61075 L .60939 .61016 L F
.505 .276 .5 r
.61019 .61042 m .61035 .61075 L .61014 .61051 L F
0 0 0 r
.6106 .61072 m .61035 .61075 L .61014 .61051 L F
.505 .276 .5 r
.61014 .61051 m .61035 .61075 L .61005 .61069 L F
.61019 .61042 m .61005 .61069 L .60609 .60989 L F
0 0 .09 r
.61034 .61014 m .61121 .6088 L .61037 .61014 L F
.61096 .60898 m .61121 .6088 L .61034 .61014 L F
.61121 .6088 m .61254 .6078 L .61037 .61014 L F
0 0 .337 r
.61017 .60698 m .61032 .61021 L .60869 .60725 L F
.61032 .61021 m .61019 .61042 L .60869 .60725 L F
.61047 .60693 m .61045 .60747 L .61017 .60698 L F
.72 .787 .906 r
.57132 .58939 m .57314 .59093 L .57476 .58951 L F
.806 .638 .674 r
.50028 .64475 m .49908 .64681 L .4975 .64362 L F
.529 .295 .505 r
.50132 .64593 m .49908 .64681 L .50028 .64475 L F
.8 .497 .477 r
.69374 .49394 m .68979 .49328 L .68956 .49118 L F
.531 0 0 r
.29839 .64615 m .30201 .64839 L .3019 .64834 L F
.387 .805 .975 r
.30201 .64839 m .30224 .64829 L .3019 .64834 L F
0 .335 .665 r
.70822 .46107 m .71076 .46205 L .71251 .46273 L F
.784 .944 .929 r
.71251 .46273 m .71218 .46096 L .71307 .46202 L F
.71251 .46273 m .71076 .46205 L .71218 .46096 L F
.295 .477 .868 r
.50436 .62334 m .5033 .6248 L .501 .62168 L F
.414 .644 .952 r
.50436 .62334 m .50587 .625 L .5033 .6248 L F
.339 .008 .248 r
.68232 .4714 m .68429 .47085 L .68463 .47063 L F
.68232 .4714 m .68242 .472 L .68429 .47085 L F
.982 .906 .59 r
.54437 .61247 m .54362 .61486 L .54504 .6131 L F
.819 .984 .884 r
.54581 .61102 m .54504 .6131 L .5475 .61288 L F
.54581 .61102 m .54437 .61247 L .54504 .6131 L F
.668 .263 .269 r
.54362 .61486 m .54743 .61505 L .54504 .6131 L F
.982 .906 .59 r
.54437 .61247 m .54362 .61486 L .54504 .6131 L F
.588 .314 .47 r
.54504 .6131 m .54743 .61505 L .5475 .61288 L F
.377 .538 .889 r
.26913 .66306 m .26992 .66469 L .26816 .66406 L F
0 0 .352 r
.26816 .66406 m .26862 .66541 L .26913 .66306 L F
.614 .431 .612 r
.26241 .64857 m .26428 .65134 L .26531 .64984 L F
0 0 .169 r
.60686 .5872 m .60596 .59057 L .60695 .58918 L F
0 0 .195 r
.60686 .5872 m .60778 .58815 L .60823 .58591 L F
0 0 .081 r
.60778 .58815 m .60786 .58735 L .60823 .58591 L F
.60786 .58735 m .60808 .58508 L .60823 .58591 L F
0 0 .053 r
.60865 .5843 m .60823 .58591 L .60899 .58374 L F
.60686 .5872 m .60823 .58591 L .60865 .5843 L F
0 0 .195 r
.60686 .5872 m .60695 .58918 L .60778 .58815 L F
.358 .711 .986 r
.51902 .65549 m .52022 .65464 L .51773 .65446 L F
0 .366 .824 r
.48364 .69499 m .4835 .69588 L .4822 .69446 L F
.48364 .69499 m .48622 .69732 L .4835 .69588 L F
.789 .808 .868 r
.71912 .50525 m .72229 .50547 L .72095 .50408 L F
0 0 .178 r
.60538 .59275 m .60695 .58918 L .60596 .59057 L F
.859 .812 .802 r
.71479 .47583 m .71616 .47715 L .71404 .48008 L F
.902 .967 .816 r
.71751 .47371 m .71616 .47715 L .71479 .47583 L F
.71751 .47371 m .71835 .47425 L .71616 .47715 L F
.531 .299 .509 r
.35681 .61512 m .35913 .61472 L .35929 .61288 L F
.584 .414 .617 r
.35929 .61288 m .3616 .6126 L .36149 .60997 L F
.581 .355 .538 r
.35913 .61472 m .3616 .6126 L .35929 .61288 L F
.252 .204 .608 r
.61442 .5978 m .61512 .60039 L .61287 .60091 L F
.056 0 .224 r
.61512 .60039 m .61255 .6033 L .61287 .60091 L F
.989 .843 .472 r
.73275 .48431 m .73195 .48462 L .73131 .482 L F
.73275 .48431 m .73254 .48539 L .73195 .48462 L F
.755 .669 .767 r
.71651 .49343 m .7176 .49705 L .71405 .49649 L F
0 0 .04 r
.53507 .64968 m .53481 .6504 L .53468 .65158 L F
.845 .384 .012 r
.53737 .65263 m .53507 .64968 L .53468 .65158 L F
.518 .327 .561 r
.53733 .64966 m .53737 .65263 L .53468 .65158 L F
0 .33 .659 r
.53468 .65158 m .53737 .65263 L .53493 .65168 L F
0 0 .04 r
.53481 .6504 m .53443 .65149 L .53468 .65158 L F
0 .33 .659 r
.53468 .65158 m .53493 .65168 L .53371 .65121 L F
0 0 .04 r
.53443 .65149 m .53408 .65247 L .53468 .65158 L F
.945 .588 .281 r
.53468 .65158 m .53565 .65461 L .53455 .65268 L F
0 .523 .808 r
.53468 .65158 m .53205 .65089 L .53408 .65247 L F
.945 .588 .281 r
.53468 .65158 m .53455 .65268 L .53371 .65121 L F
.568 .081 .058 r
.26899 .6261 m .27239 .62639 L .27031 .62525 L F
.547 .175 .288 r
.27031 .62525 m .27239 .62639 L .27301 .62491 L F
.624 .626 .832 r
.57428 .6411 m .57807 .64331 L .57746 .64093 L F
.738 .698 .813 r
.57746 .64093 m .57807 .64331 L .58014 .64158 L F
.23 0 .224 r
.27244 .5933 m .27171 .59511 L .27419 .59252 L F
.098 .6 .898 r
.71307 .46202 m .7143 .46226 L .71585 .46289 L F
.957 .682 .473 r
.71451 .46388 m .71585 .46289 L .7143 .46226 L F
.71451 .46388 m .71596 .46518 L .71585 .46289 L F
.651 .589 .772 r
.71585 .46289 m .72045 .4661 L .71596 .46518 L F
.738 .933 .596 r
.48021 .62705 m .47804 .62999 L .47873 .62845 L F
.677 .95 .956 r
.47804 .62999 m .47719 .62952 L .47873 .62845 L F
.71 .548 .667 r
.57542 .71194 m .57312 .71485 L .57561 .71452 L F
.718 .597 .721 r
.57542 .71194 m .57763 .70909 L .57553 .70972 L F
.676 .538 .689 r
.57542 .71194 m .5789 .7124 L .57763 .70909 L F
.672 .559 .718 r
.5789 .71477 m .57542 .71194 L .57561 .71452 L F
.5789 .71477 m .5789 .7124 L .57542 .71194 L F
.034 .252 .753 r
.51114 .62901 m .51257 .63211 L .51031 .63002 L F
0 0 0 r
.29577 .5861 m .29794 .58556 L .29999 .58476 L F
.207 0 0 r
.29794 .58556 m .30199 .5841 L .29999 .58476 L F
.556 .353 .56 r
.61132 .52513 m .61394 .52469 L .61384 .52236 L F
.537 .41 .654 r
.61384 .52236 m .61624 .52183 L .61572 .51917 L F
.459 .279 .549 r
.61384 .52236 m .61601 .52394 L .61624 .52183 L F
.61384 .52236 m .61394 .52469 L .61601 .52394 L F
.523 .386 .636 r
.60446 .53354 m .60688 .53557 L .60663 .533 L F
.60446 .53354 m .60478 .53616 L .60688 .53557 L F
.857 .642 .61 r
.57594 .60977 m .57451 .61244 L .57752 .61297 L F
.753 .47 .503 r
.5742 .61499 m .57752 .61297 L .57451 .61244 L F
.5742 .61499 m .5774 .61525 L .57752 .61297 L F
.595 .334 .492 r
.5774 .61525 m .57987 .61488 L .57752 .61297 L F
.638 .315 .408 r
.57752 .61297 m .57987 .61488 L .58016 .61321 L F
.423 .204 .474 r
.54631 .78045 m .54705 .77585 L .54529 .77762 L F
.736 .425 .454 r
.54631 .78045 m .55028 .78261 L .54889 .78313 L F
.518 .398 .656 r
.54889 .78313 m .54844 .77949 L .54631 .78045 L F
.749 .913 .948 r
.51677 .7763 m .51684 .77824 L .51615 .77593 L F
.51677 .7763 m .51883 .77706 L .51684 .77824 L F
.853 .772 .772 r
.63511 .51806 m .63648 .51933 L .63583 .51601 L F
.84 .821 .83 r
.63361 .51934 m .63648 .51933 L .63511 .51806 L F
.934 .897 .767 r
.65479 .49403 m .6523 .49559 L .65384 .49273 L F
.65479 .49403 m .65323 .49675 L .6523 .49559 L F
.496 0 0 r
.45055 .66668 m .44963 .667 L .44726 .6662 L F
0 0 0 r
.45256 .66553 m .45206 .66618 L .45055 .66668 L F
.422 .082 .281 r
.45206 .66618 m .44963 .667 L .45055 .66668 L F
.859 .812 .802 r
.71479 .47583 m .71404 .48008 L .71259 .47674 L F
.749 .94 .947 r
.7407 .47464 m .73833 .47643 L .73788 .47533 L F
.545 .389 .62 r
.71944 .46801 m .72077 .46524 L .72045 .4661 L F
.456 .285 .56 r
.61058 .6046 m .61047 .60693 L .60869 .60725 L F
.276 .636 .964 r
.48639 .80254 m .48823 .80326 L .48683 .80152 L F
.865 .914 .862 r
.48683 .80152 m .48823 .80326 L .49065 .7995 L F
.487 .255 .488 r
.38011 .61793 m .37764 .62063 L .3782 .61869 L F
.64 .929 .972 r
.71975 .47262 m .71835 .47425 L .71751 .47371 L F
.352 .35 .718 r
.7535 .50481 m .75088 .5027 L .75349 .50198 L F
.7535 .50481 m .7519 .50478 L .75088 .5027 L F
.733 .783 .893 r
.69701 .50111 m .69444 .50197 L .69784 .50236 L F
.656 .752 .921 r
.69701 .50111 m .69784 .50236 L .70048 .50181 L F
.458 .183 .408 r
.35608 .61798 m .35913 .61472 L .35681 .61512 L F
.602 .336 .486 r
.54705 .77585 m .54476 .77416 L .54486 .77435 L F
.54705 .77585 m .54822 .77485 L .54476 .77416 L F
.817 .821 .341 r
.72769 .48274 m .72854 .48119 L .72777 .48142 L F
.898 .986 .738 r
.72563 .48664 m .72721 .48577 L .72769 .48274 L F
0 0 .082 r
.72766 .48399 m .72563 .48664 L .72769 .48274 L F
.672 .936 .655 r
.72699 .48486 m .72425 .48762 L .72563 .48664 L F
.72766 .48399 m .72692 .48478 L .72699 .48486 L F
.72692 .48478 m .72425 .48762 L .72699 .48486 L F
.817 .821 .341 r
.72769 .48274 m .7273 .48522 L .72854 .48119 L F
.7273 .48522 m .72721 .48577 L .72735 .48528 L F
.7273 .48522 m .72735 .48528 L .72854 .48119 L F
.051 0 0 r
.3409 .64308 m .34457 .64087 L .34302 .64249 L F
.09 0 0 r
.34302 .64249 m .34457 .64087 L .34671 .64007 L F
.629 .419 .579 r
.5962 .61563 m .59608 .6184 L .59285 .61858 L F
.571 .353 .546 r
.59846 .61549 m .59608 .6184 L .5962 .61563 L F
.438 0 0 r
.45898 .69699 m .46138 .69713 L .46287 .69587 L F
.366 0 0 r
.46287 .69587 m .46138 .69713 L .46503 .69633 L F
0 0 0 r
.56866 .65667 m .56637 .6602 L .56743 .65831 L F
.569 .402 .616 r
.36149 .60997 m .3616 .6126 L .36377 .60965 L F
.95 .62 .366 r
.68956 .49118 m .69097 .48985 L .69232 .49028 L F
.68956 .49118 m .68849 .49242 L .69097 .48985 L F
.68956 .49118 m .68979 .49328 L .68849 .49242 L F
.172 .364 .813 r
.72795 .46948 m .72939 .47242 L .72713 .47091 L F
.112 .205 .682 r
.65312 .48507 m .65388 .48866 L .65481 .48674 L F
.756 .818 .347 r
.65388 .48866 m .65383 .48809 L .65481 .48674 L F
.65388 .48866 m .65296 .49083 L .65383 .48809 L F
.708 .554 .677 r
.57763 .70909 m .5812 .71186 L .58104 .70949 L F
.57763 .70909 m .5789 .7124 L .5812 .71186 L F
.51 .579 .86 r
.54442 .63663 m .54557 .63426 L .54352 .63475 L F
.54442 .63663 m .54647 .63603 L .54557 .63426 L F
.547 .652 .904 r
.40698 .69711 m .40944 .69695 L .40774 .6944 L F
.584 .557 .791 r
.47698 .81461 m .47799 .81057 L .47648 .8112 L F
.47698 .81461 m .47925 .81427 L .47799 .81057 L F
.117 0 0 r
.34699 .62453 m .34744 .62555 L .34907 .6239 L F
.34699 .62453 m .34556 .62619 L .34744 .62555 L F
.615 .926 .682 r
.48021 .62705 m .48123 .62577 L .48146 .62583 L F
.585 .87 .55 r
.48021 .62705 m .47873 .62845 L .48123 .62577 L F
.675 .811 .948 r
.6516 .51008 m .65272 .51135 L .65504 .51039 L F
.521 .316 .543 r
.61145 .52748 m .61394 .52469 L .61132 .52513 L F
.575 .465 .691 r
.58482 .63514 m .58291 .63823 L .58245 .63563 L F
.05 0 .101 r
.54387 .59332 m .54139 .59605 L .54296 .59479 L F
0 0 0 r
.54139 .59605 m .54278 .59542 L .54296 .59479 L F
.54139 .59605 m .53927 .59718 L .54278 .59542 L F
.602 .427 .617 r
.62478 .50533 m .62248 .50821 L .6249 .50774 L F
.644 .493 .664 r
.6249 .50774 m .62719 .50471 L .62478 .50533 L F
.669 .531 .687 r
.49547 .64385 m .49355 .64655 L .49303 .64422 L F
.296 0 0 r
.45452 .68834 m .45846 .68937 L .45541 .68989 L F
.164 .369 .819 r
.45541 .68989 m .45676 .68907 L .45452 .68834 L F
.569 .312 .488 r
.45846 .68937 m .45777 .69144 L .45541 .68989 L F
.164 .369 .819 r
.45541 .68989 m .45777 .69144 L .45676 .68907 L F
.502 .257 .475 r
.38798 .6099 m .38763 .61264 L .38543 .61301 L F
.459 .22 .464 r
.38977 .61203 m .38798 .6099 L .39016 .60933 L F
.38977 .61203 m .38763 .61264 L .38798 .6099 L F
.377 .399 .756 r
.26762 .62757 m .27019 .62921 L .26899 .6261 L F
.987 .883 .631 r
.62996 .54681 m .62969 .55029 L .63132 .54798 L F
.565 .537 .783 r
.39605 .59745 m .39499 .60185 L .39383 .59808 L F
.39605 .59745 m .39733 .60127 L .39499 .60185 L F
.522 .659 .922 r
.65969 .4807 m .6583 .48249 L .65732 .48075 L F
.273 .301 .709 r
.65969 .4807 m .66061 .48426 L .6583 .48249 L F
.552 .438 .677 r
.61035 .61075 m .60536 .61184 L .60609 .60989 L F
.769 .67 .753 r
.47926 .79985 m .48263 .7999 L .48199 .79712 L F
.716 .793 .912 r
.48134 .79858 m .48263 .7999 L .47926 .79985 L F
.952 .765 .614 r
.48199 .79712 m .48263 .7999 L .48134 .79858 L F
.565 .487 .725 r
.40542 .68969 m .40745 .68916 L .40699 .68599 L F
.558 .458 .697 r
.40542 .68969 m .40818 .69181 L .40745 .68916 L F
0 .032 .577 r
.56073 .65818 m .5602 .65384 L .56166 .65587 L F
.31 .731 .974 r
.33236 .58617 m .33441 .58619 L .33591 .58691 L F
.324 .704 .981 r
.33652 .58601 m .33591 .58691 L .33441 .58619 L F
.33652 .58601 m .338 .587 L .33591 .58691 L F
.617 .419 .591 r
.61805 .51632 m .62067 .51368 L .61788 .51386 L F
.609 .58 .796 r
.43248 .69443 m .43016 .69495 L .42892 .69172 L F
.94 .794 .672 r
.72382 .49454 m .7256 .49399 L .72437 .49292 L F
.524 .399 .652 r
.62313 .51135 m .6249 .50774 L .62248 .50821 L F
.434 .248 .527 r
.26519 .60164 m .2671 .60118 L .26729 .59862 L F
.48 .391 .677 r
.26519 .60164 m .26746 .60358 L .2671 .60118 L F
.535 .389 .63 r
.26533 .60403 m .26746 .60358 L .26519 .60164 L F
.186 0 .088 r
.31088 .60774 m .30993 .60925 L .30814 .60988 L F
.303 0 .176 r
.31289 .60696 m .30993 .60925 L .31088 .60774 L F
.518 .145 .273 r
.44327 .6517 m .44564 .65163 L .44678 .64936 L F
.481 .122 .279 r
.44564 .65163 m .44903 .64909 L .44678 .64936 L F
.463 0 .04 r
.51184 .70411 m .51032 .70568 L .5079 .70556 L F
.399 0 .086 r
.51405 .70357 m .51032 .70568 L .51184 .70411 L F
.48 .456 .753 r
.52008 .63887 m .51874 .64124 L .5179 .6377 L F
.559 .554 .805 r
.52008 .63887 m .52132 .64161 L .51874 .64124 L F
.568 .187 .281 r
.67066 .4747 m .67085 .47608 L .67311 .47586 L F
.27 .563 .934 r
.57983 .66174 m .58025 .66319 L .57647 .66134 L F
.75 .37 .333 r
.48479 .80449 m .48639 .80254 L .48683 .80152 L F
.48479 .80449 m .48841 .80469 L .48639 .80254 L F
.592 .536 .761 r
.42979 .68323 m .42818 .68646 L .428 .68605 L F
.42979 .68323 m .43045 .6864 L .42818 .68646 L F
.578 .443 .66 r
.43045 .6864 m .42868 .68933 L .42818 .68646 L F
.791 .525 .535 r
.57716 .66679 m .57708 .66909 L .57453 .66593 L F
.284 0 0 r
.30795 .58311 m .3099 .58355 L .31153 .58361 L F
.316 .799 .896 r
.3099 .58355 m .31366 .58323 L .31153 .58361 L F
.421 .822 .981 r
.66355 .52226 m .66589 .52175 L .66676 .52232 L F
.66355 .52226 m .66589 .52175 L .66676 .52232 L F
.713 .954 .951 r
.66676 .52232 m .66805 .52043 L .66923 .51941 L F
.66676 .52232 m .66589 .52175 L .66805 .52043 L F
.477 .623 .915 r
.66676 .52232 m .66805 .52043 L .66589 .52175 L F
.66676 .52232 m .66919 .52236 L .66805 .52043 L F
.421 .822 .981 r
.66676 .52232 m .66589 .52175 L .66355 .52226 L F
.818 .687 .719 r
.47799 .81057 m .4821 .81002 L .48166 .80843 L F
.785 .526 .546 r
.48169 .81363 m .4821 .81002 L .47799 .81057 L F
.495 .185 .371 r
.43538 .65499 m .43762 .65467 L .4386 .65201 L F
.56 .275 .439 r
.43762 .65467 m .44088 .65182 L .4386 .65201 L F
.376 .177 .479 r
.53833 .69026 m .53848 .69247 L .53991 .69096 L F
.342 0 0 r
.53833 .69026 m .54101 .69126 L .54063 .68963 L F
.53833 .69026 m .53991 .69096 L .54101 .69126 L F
.544 .312 .513 r
.60536 .61184 m .60358 .6153 L .60412 .6119 L F
.937 .897 .763 r
.67955 .5041 m .67755 .50524 L .67893 .50356 L F
.503 .319 .563 r
.34913 .62136 m .35119 .62336 L .35141 .62103 L F
.34913 .62136 m .34907 .6239 L .35119 .62336 L F
.675 .493 .632 r
.49046 .78726 m .49428 .78597 L .49066 .78639 L F
.776 .754 .833 r
.67453 .52165 m .67854 .52001 L .67722 .51852 L F
.801 .725 .78 r
.67722 .51852 m .67854 .52001 L .68084 .51708 L F
.804 .773 .824 r
.25711 .6624 m .2552 .66271 L .25655 .66053 L F
.703 .353 .382 r
.25711 .6624 m .2562 .66537 L .2552 .66271 L F
0 .207 .722 r
.25655 .66053 m .25847 .66249 L .25711 .6624 L F
.033 0 .128 r
.25847 .66249 m .2562 .66537 L .25711 .6624 L F
0 0 .154 r
.69416 .47344 m .69449 .47612 L .69741 .47402 L F
.69416 .47344 m .69451 .47577 L .69449 .47612 L F
.887 .586 .472 r
.55874 .75621 m .5604 .75462 L .5574 .75396 L F
.55874 .75621 m .56073 .7568 L .5604 .75462 L F
.66 .741 .91 r
.70048 .50181 m .7036 .50229 L .70204 .50116 L F
.686 .769 .914 r
.70204 .50116 m .7036 .50229 L .70643 .50193 L F
.531 0 0 r
.29839 .64615 m .3019 .64834 L .3005 .64657 L F
.593 .677 .9 r
.3019 .64834 m .30283 .64638 L .3005 .64657 L F
.316 0 0 r
.48328 .77714 m .48309 .77773 L .47988 .77742 L F
.853 .396 .042 r
.48059 .77406 m .48283 .77753 L .48328 .77714 L F
.502 .832 .537 r
.48328 .77714 m .48283 .77753 L .48439 .77605 L F
0 0 0 r
.48439 .77605 m .48309 .77773 L .48328 .77714 L F
.577 .26 .395 r
.59728 .5437 m .59967 .54365 L .59739 .54206 L F
.571 .264 .41 r
.59739 .54206 m .59967 .54365 L .59993 .54189 L F
.817 .979 .891 r
.26533 .63456 m .26391 .63607 L .26544 .63515 L F
.26533 .63456 m .26391 .63607 L .26544 .63515 L F
.967 .853 .447 r
.60981 .57592 m .60943 .57899 L .60887 .57744 L F
.939 .7 .226 r
.60933 .57997 m .60887 .57744 L .60943 .57899 L F
.801 .725 .78 r
.67722 .51852 m .68084 .51708 L .67948 .51556 L F
.778 .717 .795 r
.67948 .51556 m .68084 .51708 L .68304 .51431 L F
.564 .369 .575 r
.63167 .49677 m .63416 .49638 L .63407 .49391 L F
.484 .308 .566 r
.63407 .49391 m .63641 .49565 L .63633 .49326 L F
.63407 .49391 m .63416 .49638 L .63641 .49565 L F
.613 .47 .663 r
.40861 .66401 m .40888 .66648 L .41104 .66359 L F
.418 0 0 r
.33791 .5996 m .33672 .6006 L .33455 .60038 L F
.419 0 0 r
.34035 .60015 m .33672 .6006 L .33791 .5996 L F
.68 .668 .831 r
.53376 .64398 m .5316 .64486 L .53029 .64305 L F
0 0 0 r
.57349 .64249 m .57172 .64405 L .57428 .6411 L F
.113 .012 .45 r
.57215 .64524 m .57172 .64405 L .57349 .64249 L F
.57215 .64524 m .57154 .6463 L .57172 .64405 L F
.452 .537 .854 r
.75222 .48697 m .75054 .48914 L .75091 .48638 L F
.75222 .48697 m .75372 .49015 L .75054 .48914 L F
.296 0 0 r
.26339 .62073 m .26552 .62091 L .26553 .62052 L F
.26553 .62052 m .26552 .62091 L .26339 .62073 L F
.828 .602 .596 r
.57223 .6115 m .57594 .60977 L .57313 .60904 L F
.57223 .6115 m .57451 .61244 L .57594 .60977 L F
.525 .192 .346 r
.62595 .50106 m .62865 .50087 L .62912 .49885 L F
.328 .018 .278 r
.63167 .49677 m .62912 .49885 L .63149 .49769 L F
.491 .216 .424 r
.62865 .50087 m .63149 .49769 L .62912 .49885 L F
.521 .322 .552 r
.24972 .65253 m .25209 .65244 L .25219 .64954 L F
.524 .399 .652 r
.62313 .51135 m .62553 .51075 L .6249 .50774 L F
.245 0 .213 r
.62338 .51231 m .62553 .51075 L .62313 .51135 L F
.596 .527 .747 r
.53623 .64673 m .53428 .64798 L .53376 .64398 L F
.393 .293 .621 r
.53623 .64673 m .53507 .64968 L .53428 .64798 L F
.615 .245 .318 r
.68352 .47798 m .68347 .47669 L .68587 .47706 L F
.68352 .47798 m .68264 .47846 L .68347 .47669 L F
.226 .585 .945 r
.53104 .79979 m .53261 .80036 L .53123 .79902 L F
.53104 .79979 m .53261 .80036 L .53123 .79902 L F
.576 .942 .85 r
.69042 .46843 m .68949 .46882 L .68973 .46785 L F
.518 .311 .539 r
.68955 .47196 m .69193 .47137 L .68969 .46788 L F
.68969 .46788 m .68969 .46788 L .68969 .46788 L F
.68955 .47196 m .68969 .46788 L .68969 .46788 L F
.576 .942 .85 r
.6898 .46779 m .68973 .46785 L .68976 .46774 L F
.297 .787 .74 r
.68976 .46774 m .69304 .46667 L .69042 .46843 L F
.755 .656 .753 r
.69422 .46849 m .69193 .47137 L .69382 .47059 L F
.695 .768 .907 r
.6906 .47303 m .69416 .47344 L .69382 .47059 L F
.878 .885 .835 r
.69382 .47059 m .69416 .47344 L .69636 .47068 L F
.69382 .47059 m .69636 .47068 L .69527 .46924 L F
.672 .975 .881 r
.69193 .47137 m .6906 .47303 L .69382 .47059 L F
.755 .656 .753 r
.69422 .46849 m .69382 .47059 L .69527 .46924 L F
.69422 .46849 m .69558 .47155 L .69193 .47137 L F
.156 .181 .635 r
.68969 .46788 m .69338 .46973 L .69422 .46849 L F
.68969 .46788 m .68969 .46788 L .68969 .46788 L F
.68969 .46788 m .69338 .46973 L .68969 .46788 L F
.576 .942 .85 r
.68984 .46782 m .68973 .46785 L .6898 .46779 L F
.69042 .46843 m .68974 .46786 L .68984 .46782 L F
.68974 .46786 m .68973 .46785 L .68984 .46782 L F
.68949 .46882 m .68917 .46895 L .68969 .46788 L F
.68949 .46882 m .68969 .46788 L .68976 .46774 L F
.518 .311 .539 r
.68955 .47196 m .68969 .46788 L .68976 .4681 L F
.68969 .46788 m .68969 .46788 L .68969 .46788 L F
.68969 .46788 m .68969 .46788 L .68976 .4681 L F
.156 .181 .635 r
.68969 .46788 m .69193 .47137 L .69338 .46973 L F
0 0 .007 r
.68976 .46774 m .68976 .4681 L .68969 .46788 L F
.68976 .46774 m .68969 .46788 L .69204 .46688 L F
.68976 .46774 m .68969 .46788 L .68969 .46788 L F
.576 .942 .85 r
.68917 .46895 m .68692 .4699 L .68976 .46774 L F
.967 .853 .447 r
.60981 .57592 m .60887 .57744 L .60959 .57513 L F
.686 .769 .914 r
.70204 .50116 m .70643 .50193 L .70481 .49918 L F
.669 .77 .926 r
.70481 .49918 m .70643 .50193 L .70807 .49987 L F
.656 .669 .85 r
.70643 .50193 m .70956 .50215 L .70807 .49987 L F
.237 .084 .461 r
.30378 .61813 m .30361 .62046 L .30229 .62107 L F
.861 .662 .633 r
.56369 .76609 m .56414 .76317 L .56205 .76248 L F
.511 .313 .549 r
.58808 .62134 m .5881 .62369 L .58577 .62421 L F
.523 .349 .587 r
.5881 .62369 m .58814 .62613 L .58577 .62421 L F
.467 .355 .643 r
.58577 .62421 m .58814 .62613 L .58615 .62673 L F
.725 .482 .558 r
.556 .7601 m .5529 .76252 L .55287 .76016 L F
.556 .7601 m .55603 .76305 L .5529 .76252 L F
.555 .758 .972 r
.42081 .70921 m .42486 .71026 L .42306 .7088 L F
.599 .78 .967 r
.42306 .7088 m .42486 .71026 L .42638 .70955 L F
.43 0 .061 r
.27645 .59214 m .27882 .59204 L .28038 .59046 L F
.309 0 0 r
.27882 .59204 m .28162 .59115 L .28038 .59046 L F
.312 0 .039 r
.28038 .59046 m .28162 .59115 L .28252 .59002 L F
0 0 0 r
.57349 .64249 m .57428 .6411 L .57097 .64053 L F
.612 .4 .57 r
.57428 .6411 m .57746 .64093 L .57851 .63964 L F
0 .032 .577 r
.56073 .65818 m .56143 .65701 L .5602 .65384 L F
.191 .44 .868 r
.56073 .65818 m .56345 .65934 L .56143 .65701 L F
.54 .609 .871 r
.30201 .72969 m .30413 .7294 L .30091 .728 L F
.30201 .72969 m .30413 .7294 L .30091 .728 L F
.733 .952 .948 r
.53346 .59993 m .53425 .5981 L .53569 .59904 L F
.53346 .59993 m .53149 .59976 L .53425 .5981 L F
.654 .78 .941 r
.51779 .78828 m .51868 .78907 L .52069 .78811 L F
.689 .864 .965 r
.73857 .50396 m .73966 .50506 L .74201 .50417 L F
0 .192 .674 r
.7422 .50691 m .73966 .50506 L .73857 .50396 L F
.649 .679 .865 r
.53029 .64305 m .52806 .6438 L .52696 .64141 L F
.243 .079 .449 r
.30993 .60925 m .30862 .61096 L .30814 .60988 L F
.539 .422 .668 r
.54558 .59178 m .54387 .59332 L .54527 .59182 L F
.106 0 .18 r
.54296 .59479 m .54527 .59182 L .54387 .59332 L F
.356 .251 .596 r
.43386 .67745 m .43248 .68046 L .43233 .67799 L F
.441 .086 .265 r
.63149 .49769 m .63416 .49638 L .63167 .49677 L F
.681 .2 .102 r
.50559 .70353 m .50442 .70472 L .50231 .70298 L F
.711 .237 .124 r
.50559 .70353 m .5079 .70556 L .50442 .70472 L F
.346 0 .191 r
.36139 .63386 m .35989 .6326 L .36215 .63242 L F
.36139 .63386 m .35927 .63441 L .35989 .6326 L F
.529 .361 .597 r
.4069 .67184 m .40904 .669 L .40681 .66945 L F
.958 .691 .487 r
.6482 .4954 m .64971 .49411 L .64864 .49295 L F
.6482 .4954 m .6498 .49691 L .64971 .49411 L F
.579 .424 .635 r
.58276 .6102 m .58602 .61038 L .58456 .60708 L F
.592 .426 .626 r
.58328 .6114 m .58602 .61038 L .58276 .6102 L F
.224 .52 .915 r
.38929 .59646 m .38863 .59751 L .38653 .5958 L F
.38929 .59646 m .39035 .59799 L .38863 .59751 L F
.382 0 .123 r
.45384 .64642 m .45601 .64608 L .45735 .64412 L F
.485 .135 .296 r
.45601 .64608 m .45946 .64343 L .45735 .64412 L F
.459 0 0 r
.46224 .66669 m .4584 .66664 L .46029 .66659 L F
.763 .473 .495 r
.46029 .66659 m .4584 .66664 L .45708 .6655 L F
.74 .723 .835 r
.46134 .66459 m .4584 .66664 L .46224 .66669 L F
.593 .593 .821 r
.46224 .66669 m .46348 .66332 L .46134 .66459 L F
.46224 .66669 m .46494 .66677 L .46348 .66332 L F
.55 .182 .296 r
.46494 .66677 m .46455 .66825 L .46224 .66669 L F
.46494 .66677 m .46455 .66825 L .46224 .66669 L F
.775 .69 .769 r
.7376 .51043 m .73879 .51428 L .74098 .51084 L F
.572 .379 .582 r
.58291 .63823 m .58285 .64133 L .58014 .64158 L F
.575 .465 .691 r
.58482 .63514 m .58521 .63764 L .58291 .63823 L F
.572 .393 .601 r
.58521 .63764 m .58285 .64133 L .58291 .63823 L F
.814 .727 .769 r
.67345 .51351 m .67037 .5133 L .67264 .51036 L F
.819 .702 .736 r
.67345 .51351 m .67171 .51645 L .67037 .5133 L F
.637 .411 .557 r
.59051 .62124 m .5881 .62369 L .58808 .62134 L F
.725 .84 .936 r
.56052 .61602 m .55771 .61702 L .55695 .61536 L F
.699 .458 .556 r
.55287 .76016 m .55095 .76233 L .55052 .76012 L F
.878 .923 .851 r
.55095 .76233 m .55204 .75932 L .55052 .76012 L F
.701 .649 .795 r
.26905 .79532 m .27136 .79377 L .26843 .79395 L F
.941 .864 .735 r
.57033 .63752 m .57383 .635 L .57254 .63507 L F
.57033 .63752 m .57179 .63858 L .57383 .635 L F
.27 .614 .957 r
.57383 .635 m .57543 .63495 L .5743 .63427 L F
.582 .944 .884 r
.5743 .63427 m .57254 .63507 L .57383 .635 L F
.27 .614 .957 r
.5743 .63427 m .57543 .63495 L .57383 .635 L F
.57383 .635 m .57543 .63495 L .5743 .63427 L F
.57383 .635 m .57543 .63495 L .5743 .63427 L F
.872 .931 .858 r
.74128 .52983 m .74008 .53296 L .73916 .5324 L F
.506 0 0 r
.74008 .53296 m .74158 .5344 L .73916 .5324 L F
.74008 .53296 m .74239 .53358 L .74158 .5344 L F
.654 .889 .982 r
.74459 .53007 m .74189 .53106 L .74366 .52906 L F
.617 .824 .98 r
.74366 .52906 m .74189 .53106 L .74128 .52983 L F
.709 .461 .547 r
.74189 .53106 m .7454 .53196 L .74239 .53358 L F
.712 .573 .697 r
.57561 .71452 m .57661 .71765 L .5789 .71477 L F
.718 .596 .719 r
.5812 .71186 m .5789 .7124 L .5789 .71477 L F
.482 .375 .656 r
.40538 .67787 m .40704 .6744 L .4049 .67542 L F
.82 .72 .754 r
.66986 .48174 m .6685 .47841 L .66991 .48046 L F
.359 0 0 r
.35227 .59917 m .34853 .59944 L .34998 .59906 L F
.996 .78 .492 r
.65313 .49935 m .6523 .49559 L .65323 .49675 L F
.712 .314 .293 r
.73668 .52355 m .7385 .5218 L .73747 .52075 L F
.73668 .52355 m .74025 .52395 L .7385 .5218 L F
0 0 0 r
.32317 .60194 m .3198 .60319 L .32105 .60219 L F
.652 .405 .533 r
.5105 .64923 m .50836 .65186 L .50855 .64983 L F
.786 .789 .855 r
.68887 .5047 m .6864 .50723 L .68936 .50777 L F
.823 .737 .769 r
.6864 .50723 m .68734 .51052 L .68936 .50777 L F
.767 .777 .861 r
.68887 .5047 m .68936 .50777 L .69226 .5049 L F
.369 .792 .973 r
.32571 .585 m .32334 .58496 L .32455 .58479 L F
.223 .661 .954 r
.32741 .58455 m .32571 .585 L .32455 .58479 L F
.32741 .58455 m .32873 .58537 L .32571 .585 L F
.814 .791 .831 r
.48904 .69819 m .48755 .69864 L .48622 .69732 L F
.945 .74 .595 r
.48622 .69732 m .48755 .69864 L .48904 .69819 L F
.909 .761 .686 r
.63081 .52633 m .63361 .52524 L .63116 .52409 L F
.63081 .52633 m .63221 .52758 L .63361 .52524 L F
.469 .206 .433 r
.59184 .54707 m .59429 .54459 L .59194 .54494 L F
.415 .194 .467 r
.58978 .54779 m .59184 .54707 L .59194 .54494 L F
.041 0 0 r
.55539 .60699 m .55372 .60783 L .55406 .60569 L F
.665 .781 .935 r
.55721 .60614 m .55539 .60699 L .55406 .60569 L F
.759 .73 .826 r
.50282 .81174 m .50599 .81196 L .50478 .81058 L F
.683 .706 .865 r
.50599 .81196 m .5083 .8111 L .50478 .81058 L F
.851 .893 .867 r
.55664 .6252 m .55667 .62711 L .5592 .62447 L F
0 .053 .587 r
.5579 .62805 m .55667 .62711 L .55664 .6252 L F
.5579 .62805 m .55886 .62934 L .55667 .62711 L F
.248 .356 .777 r
.65962 .5048 m .6611 .50848 L .66202 .50667 L F
0 0 .572 r
.66059 .50677 m .6611 .50848 L .65962 .5048 L F
.752 .891 .942 r
.65669 .50941 m .6611 .50848 L .66059 .50677 L F
.761 .976 .919 r
.66202 .50667 m .6611 .50848 L .66264 .50711 L F
.658 .593 .77 r
.27188 .62138 m .27301 .62491 L .27563 .62421 L F
.407 .688 .976 r
.36078 .59968 m .36378 .59943 L .363 .59947 L F
.36078 .59968 m .36572 .60119 L .36378 .59943 L F
.896 .868 .802 r
.35915 .60151 m .36078 .59968 L .363 .59947 L F
.499 .311 .557 r
.60073 .60095 m .60299 .59803 L .60101 .59882 L F
.668 .55 .711 r
.58104 .70949 m .5812 .71186 L .58346 .70903 L F
.689 .58 .728 r
.5812 .71186 m .58458 .71257 L .58346 .70903 L F
.319 .713 .98 r
.37239 .58977 m .37177 .59066 L .37035 .58982 L F
.37239 .58977 m .37387 .59068 L .37177 .59066 L F
.761 .791 .877 r
.27555 .64374 m .2738 .64603 L .27741 .64589 L F
.785 .716 .787 r
.2738 .64603 m .27538 .64758 L .27741 .64589 L F
.595 .736 .942 r
.27555 .64374 m .27741 .64589 L .27884 .64529 L F
.388 .015 .203 r
.39305 .60735 m .39239 .60891 L .39016 .60933 L F
.345 0 .073 r
.39548 .60694 m .39239 .60891 L .39305 .60735 L F
.476 .48 .782 r
.47652 .80259 m .47763 .80635 L .47941 .80456 L F
.69 .418 .506 r
.36561 .60856 m .36895 .60646 L .36646 .6071 L F
.602 .534 .751 r
.42979 .68323 m .428 .68605 L .42746 .68366 L F
.695 .619 .767 r
.73366 .47734 m .73119 .4797 L .7313 .47698 L F
.702 .418 .491 r
.61052 .56184 m .6108 .56411 L .607 .56392 L F
.647 .279 .331 r
.51883 .77706 m .52174 .77709 L .52027 .77933 L F
.987 .895 .578 r
.52027 .77933 m .52174 .77709 L .52113 .77631 L F
.657 .583 .76 r
.57312 .71485 m .57661 .71765 L .57561 .71452 L F
.644 .461 .621 r
.58456 .60708 m .58805 .60698 L .58812 .60455 L F
.596 .397 .582 r
.58602 .61038 m .58805 .60698 L .58456 .60708 L F
.469 .764 .995 r
.5256 .64034 m .52435 .6417 L .52334 .64095 L F
.5256 .64034 m .52696 .64141 L .52435 .6417 L F
.6 .392 .571 r
.58805 .60698 m .59016 .60423 L .58812 .60455 L F
.452 .649 .943 r
.36572 .60119 m .3667 .59992 L .36378 .59943 L F
.36572 .60119 m .36717 .60072 L .3667 .59992 L F
.571 .104 .107 r
.71285 .49338 m .71651 .49343 L .71372 .49297 L F
.71372 .49297 m .71651 .49343 L .71285 .49338 L F
.067 0 .131 r
.55258 .75071 m .55384 .74868 L .55142 .75147 L F
.538 0 0 r
.55506 .75408 m .554 .75355 L .55142 .75147 L F
.402 .328 .659 r
.55142 .75147 m .554 .75355 L .55258 .75071 L F
.653 .866 .98 r
.46802 .66661 m .46494 .66677 L .46674 .66566 L F
.84 .603 .58 r
.46802 .66661 m .46455 .66825 L .46494 .66677 L F
.46802 .66661 m .46821 .66933 L .46455 .66825 L F
.316 .684 .978 r
.46925 .66595 m .46802 .66661 L .46674 .66566 L F
.46925 .66595 m .47139 .66727 L .46802 .66661 L F
.484 .333 .6 r
.47027 .66875 m .46821 .66933 L .46802 .66661 L F
.398 .166 .442 r
.58952 .54993 m .59184 .54707 L .58978 .54779 L F
.393 .293 .621 r
.53623 .64673 m .53733 .64966 L .53507 .64968 L F
.518 .327 .561 r
.53733 .64966 m .53468 .65158 L .53507 .64968 L F
.726 .595 .709 r
.54063 .68963 m .54101 .69126 L .54402 .68958 L F
.276 .359 .768 r
.66335 .48578 m .66104 .4859 L .66061 .48426 L F
.85 .51 .41 r
.52922 .64972 m .52831 .65183 L .52479 .6488 L F
.589 .213 .298 r
.53205 .65089 m .52831 .65183 L .52922 .64972 L F
.271 0 0 r
.67645 .47544 m .67924 .4742 L .6769 .47465 L F
0 0 0 r
.62514 .58036 m .6234 .5838 L .62426 .58209 L F
.084 .383 .845 r
.7319 .47429 m .72985 .47407 L .72939 .47242 L F
.7319 .47429 m .7325 .47569 L .72985 .47407 L F
.417 .398 .73 r
.7325 .47569 m .7313 .47698 L .72985 .47407 L F
.763 .635 .72 r
.60896 .55898 m .60576 .55575 L .60932 .55614 L F
.60896 .55898 m .60695 .55912 L .60576 .55575 L F
.343 .05 .315 r
.58689 .55239 m .58952 .54993 L .58743 .55068 L F
.479 .323 .591 r
.26729 .59862 m .26924 .59807 L .26945 .5956 L F
.485 .301 .555 r
.2671 .60118 m .26924 .59807 L .26729 .59862 L F
.721 .605 .035 r
.41123 .70048 m .41132 .69686 L .40944 .69695 L F
.41123 .70048 m .41124 .6993 L .41132 .69686 L F
.831 .418 .26 r
.41369 .70257 m .4126 .703 L .41123 .70048 L F
0 0 .496 r
.41123 .70048 m .4126 .703 L .41124 .6993 L F
.396 .841 .931 r
.5598 .60498 m .56237 .60442 L .56357 .6047 L F
.624 .249 .313 r
.56237 .60442 m .56529 .60338 L .56357 .6047 L F
.983 .88 .523 r
.73142 .48661 m .73254 .48539 L .73191 .48775 L F
.99 .867 .516 r
.73195 .48462 m .73254 .48539 L .73142 .48661 L F
.379 .715 .987 r
.34201 .58656 m .34154 .58786 L .34005 .58688 L F
.34201 .58656 m .34366 .58789 L .34154 .58786 L F
.681 .479 .606 r
.60351 .55858 m .60245 .56011 L .60103 .55865 L F
.425 .211 .484 r
.54831 .6859 m .54606 .6888 L .54632 .6865 L F
.54632 .6865 m .54606 .6888 L .54831 .6859 L F
.166 .329 .784 r
.49165 .79101 m .49296 .79407 L .49387 .79331 L F
.473 .874 .959 r
.49296 .79407 m .49542 .79349 L .49387 .79331 L F
.827 .605 .602 r
.60695 .56138 m .60351 .55858 L .60695 .55912 L F
.60695 .56138 m .60342 .561 L .60351 .55858 L F
.772 .483 .497 r
.60695 .56138 m .60345 .56341 L .60342 .561 L F
.60695 .56138 m .607 .56392 L .60345 .56341 L F
.139 0 0 r
.53208 .69422 m .53614 .69323 L .53205 .69194 L F
.53208 .69422 m .53437 .69401 L .53614 .69323 L F
0 0 0 r
.53614 .69323 m .53437 .69401 L .53848 .69247 L F
.942 .956 .745 r
.46621 .67459 m .46472 .67662 L .46701 .67513 L F
.46621 .67459 m .46472 .67662 L .46701 .67513 L F
.909 .853 .775 r
.66198 .49033 m .6636 .49158 L .66384 .48869 L F
.66198 .49033 m .66254 .49312 L .6636 .49158 L F
.663 .786 .94 r
.56085 .76686 m .56369 .76609 L .56002 .76567 L F
.738 .698 .813 r
.57746 .64093 m .58014 .64158 L .57955 .63971 L F
.082 .542 .904 r
.58014 .64158 m .5818 .64121 L .57955 .63971 L F
.314 0 0 r
.58285 .64133 m .58273 .64198 L .58014 .64158 L F
.082 .542 .904 r
.58014 .64158 m .58273 .64198 L .5818 .64121 L F
.589 .469 .684 r
.48402 .66078 m .48465 .66359 L .48195 .66388 L F
.51 .28 .502 r
.48425 .66572 m .48195 .66388 L .48465 .66359 L F
.48425 .66572 m .48185 .66625 L .48195 .66388 L F
.589 .469 .684 r
.48402 .66078 m .48465 .66359 L .48195 .66388 L F
.51 .28 .502 r
.48195 .66388 m .48425 .66572 L .48465 .66359 L F
.48195 .66388 m .48185 .66625 L .48425 .66572 L F
.384 0 0 r
.47573 .70165 m .47439 .70288 L .47201 .70311 L F
.487 .017 .062 r
.47763 .70249 m .47439 .70288 L .47573 .70165 L F
.179 .118 .546 r
.46417 .65455 m .463 .65823 L .46262 .65588 L F
.567 .592 .838 r
.5592 .62447 m .56269 .62726 L .56148 .62336 L F
.366 0 .029 r
.55886 .62934 m .56097 .62943 L .56269 .62726 L F
.56097 .62943 m .56125 .62944 L .56128 .62939 L F
.56097 .62943 m .56128 .62939 L .56269 .62726 L F
.349 0 0 r
.56145 .6297 m .56511 .62818 L .56201 .62935 L F
.59 .593 .823 r
.56147 .62937 m .56197 .62938 L .56145 .6297 L F
.349 0 0 r
.56145 .6297 m .56201 .62935 L .56172 .62946 L F
.56145 .6297 m .56432 .62942 L .56511 .62818 L F
.59 .593 .823 r
.56197 .62938 m .56432 .62942 L .56145 .6297 L F
.366 0 .029 r
.56125 .62944 m .56181 .62926 L .56269 .62726 L F
.598 .636 .859 r
.56269 .62726 m .56302 .62388 L .56148 .62336 L F
.56269 .62726 m .56577 .6269 L .56302 .62388 L F
.505 .039 .081 r
.56269 .62726 m .56178 .62934 L .56511 .62818 L F
.56178 .62934 m .56172 .62946 L .56201 .62935 L F
.56178 .62934 m .56201 .62935 L .56511 .62818 L F
.5 .165 .331 r
.56511 .62818 m .56577 .6269 L .56269 .62726 L F
.59 .593 .823 r
.56167 .6256 m .56407 .62907 L .56178 .62934 L F
.366 0 .029 r
.56125 .62944 m .56172 .62946 L .56181 .62926 L F
.59 .593 .823 r
.56147 .62931 m .56178 .62934 L .56147 .62937 L F
.56167 .6256 m .56178 .62934 L .56147 .62931 L F
.56407 .62907 m .56432 .62942 L .56147 .62937 L F
.851 .893 .867 r
.55664 .6252 m .5592 .62447 L .55803 .62384 L F
.466 .459 .766 r
.55897 .62429 m .55991 .62595 L .5579 .62805 L F
.59 .593 .823 r
.56167 .6256 m .55962 .62767 L .55976 .62684 L F
.521 .275 .482 r
.55976 .62684 m .5605 .62699 L .56167 .6256 L F
.466 .459 .766 r
.55976 .62684 m .5605 .62699 L .55968 .62732 L F
.521 .275 .482 r
.55915 .62724 m .5605 .62699 L .55976 .62684 L F
.466 .459 .766 r
.55991 .62595 m .5605 .62699 L .55976 .62684 L F
.59 .593 .823 r
.56147 .62937 m .56145 .6297 L .56125 .62944 L F
.395 .588 .921 r
.56145 .6297 m .56172 .62946 L .56125 .62944 L F
.56145 .6297 m .56125 .62944 L .55886 .62934 L F
.59 .593 .823 r
.56125 .62944 m .56145 .6297 L .56122 .62945 L F
.375 .601 .935 r
.55909 .62769 m .56145 .6297 L .55886 .62934 L F
.466 .459 .766 r
.55991 .62595 m .55968 .62732 L .55884 .62766 L F
.55831 .62762 m .55884 .62766 L .5579 .62805 L F
.55991 .62595 m .55884 .62766 L .55831 .62762 L F
.528 .811 .998 r
.5579 .62805 m .55968 .62732 L .55915 .62724 L F
.55968 .62732 m .5605 .62699 L .55915 .62724 L F
.59 .593 .823 r
.55976 .62684 m .55968 .62732 L .55915 .62724 L F
.55968 .62732 m .55962 .62767 L .55915 .62724 L F
.375 .601 .935 r
.55915 .62724 m .55961 .62773 L .55909 .62769 L F
.55961 .62773 m .56145 .6297 L .55909 .62769 L F
.59 .593 .823 r
.56167 .6256 m .56147 .62937 L .55962 .62767 L F
.56147 .62937 m .56122 .62945 L .55915 .62724 L F
.255 .766 .81 r
.30199 .5841 m .30411 .58362 L .30529 .58354 L F
0 0 0 r
.30411 .58362 m .30795 .58311 L .30529 .58354 L F
.872 .9 .849 r
.67171 .51645 m .66932 .5193 L .66826 .51833 L F
.67171 .51645 m .66826 .51833 L .66847 .5156 L F
.983 .791 .567 r
.66847 .5156 m .6683 .51781 L .66708 .51728 L F
.6683 .51781 m .66826 .51833 L .66708 .51728 L F
.66847 .5156 m .66708 .51728 L .66667 .51504 L F
.781 .626 .689 r
.66708 .51728 m .66518 .51388 L .66667 .51504 L F
.66708 .51728 m .66345 .51694 L .66518 .51388 L F
.229 .394 .821 r
.66708 .51728 m .66883 .51629 L .66586 .51675 L F
.66708 .51728 m .66586 .51675 L .66559 .51679 L F
0 .118 .617 r
.66826 .51833 m .66903 .51879 L .66717 .51735 L F
.66826 .51833 m .66717 .51735 L .66708 .51728 L F
.872 .9 .849 r
.66932 .5193 m .66923 .51941 L .66826 .51833 L F
.515 .338 .58 r
.66805 .52043 m .66826 .51833 L .66923 .51941 L F
.24 .71 .944 r
.31913 .58422 m .32079 .58418 L .32334 .58496 L F
.575 .855 .996 r
.32334 .58496 m .32475 .58376 L .32455 .58479 L F
.32334 .58496 m .32079 .58418 L .32475 .58376 L F
.749 .753 .856 r
.69902 .4683 m .69636 .47068 L .69978 .47107 L F
.785 .676 .744 r
.69636 .47068 m .69741 .47402 L .69978 .47107 L F
.614 .427 .606 r
.69978 .47107 m .69741 .47402 L .69986 .47339 L F
.555 .523 .774 r
.69978 .47107 m .7011 .46693 L .69902 .4683 L F
.69978 .47107 m .70219 .47046 L .7011 .46693 L F
.722 .648 .774 r
.69986 .47339 m .70219 .47046 L .69978 .47107 L F
.608 .334 .476 r
.51883 .77706 m .51835 .77948 L .51589 .77955 L F
.462 .831 .992 r
.51677 .7763 m .52113 .77631 L .51883 .77706 L F
.647 .279 .331 r
.51883 .77706 m .52027 .77933 L .51835 .77948 L F
.617 .419 .591 r
.61805 .51632 m .62047 .5161 L .62067 .51368 L F
.668 .505 .654 r
.62047 .5161 m .62338 .51231 L .62067 .51368 L F
.294 0 .129 r
.35724 .6351 m .35481 .63659 L .35498 .63537 L F
.84 .705 .713 r
.46417 .65455 m .4655 .65588 L .46806 .65268 L F
.46417 .65455 m .46806 .65268 L .4657 .65454 L F
.053 0 0 r
.46867 .65347 m .46806 .65268 L .46998 .65183 L F
.46867 .65347 m .4657 .65454 L .46806 .65268 L F
.89 .988 .741 r
.72608 .48715 m .72721 .48577 L .72563 .48664 L F
.46 .195 .425 r
.37764 .62063 m .37503 .62327 L .37546 .62117 L F
.494 .735 .98 r
.27155 .64657 m .27538 .64758 L .2738 .64603 L F
.503 .584 .869 r
.70956 .50215 m .71311 .50473 L .71159 .50197 L F
.508 .6 .881 r
.71159 .50197 m .71311 .50473 L .71539 .50455 L F
.955 .632 .223 r
.37176 .75428 m .37304 .75767 L .372 .75534 L F
.154 .336 .794 r
.372 .75534 m .37304 .75767 L .37379 .75641 L F
.085 0 0 r
.31311 .64896 m .31704 .64843 L .31528 .64818 L F
.146 .688 .818 r
.31704 .64843 m .31759 .64821 L .31528 .64818 L F
.31704 .64843 m .31969 .64828 L .31759 .64821 L F
.701 .474 .577 r
.50431 .77999 m .50559 .78455 L .50813 .77967 L F
.733 .571 .673 r
.58695 .71185 m .58913 .70907 L .58568 .70867 L F
.679 .496 .631 r
.58695 .71185 m .58899 .71134 L .58913 .70907 L F
.471 .56 .864 r
.70956 .50215 m .71135 .50038 L .70807 .49987 L F
.70956 .50215 m .71159 .50197 L .71135 .50038 L F
.82 .72 .754 r
.66986 .48174 m .6667 .48158 L .6685 .47841 L F
.795 .472 .442 r
.66986 .48174 m .66848 .484 L .6667 .48158 L F
.65 .293 .354 r
.67222 .48392 m .66986 .48174 L .67211 .48185 L F
.67222 .48392 m .66848 .484 L .66986 .48174 L F
.601 .122 .089 r
.55406 .60188 m .55669 .60308 L .55301 .60303 L F
.924 .818 .723 r
.61106 .56932 m .61057 .56656 L .6121 .56761 L F
.596 .347 .51 r
.57987 .61488 m .58328 .6114 L .58016 .61321 L F
.783 .959 .641 r
.55506 .75408 m .55384 .75492 L .554 .75355 L F
.662 .255 .263 r
.52641 .69135 m .52885 .69226 L .52998 .69135 L F
.589 .022 0 r
.52885 .69226 m .53205 .69194 L .52998 .69135 L F
.796 .912 .919 r
.69841 .46543 m .69561 .46598 L .69788 .46464 L F
.728 .95 .95 r
.69841 .46543 m .6983 .46402 L .70127 .46326 L F
.69841 .46543 m .69788 .46464 L .6983 .46402 L F
.045 0 .42 r
.61204 .60525 m .61058 .6046 L .61255 .6033 L F
.61204 .60525 m .61047 .60693 L .61058 .6046 L F
.314 0 0 r
.56559 .59184 m .56806 .59276 L .56636 .59206 L F
.034 .596 .799 r
.56636 .59206 m .56951 .59229 L .56559 .59184 L F
.886 .713 .662 r
.56017 .75936 m .56197 .76006 L .56073 .7568 L F
.836 .586 .562 r
.55912 .76238 m .56197 .76006 L .56017 .75936 L F
.55912 .76238 m .56205 .76248 L .56197 .76006 L F
.674 .749 .906 r
.48166 .80843 m .48417 .80824 L .48308 .80593 L F
.801 .6 .629 r
.49519 .6997 m .49909 .69782 L .49526 .69832 L F
.552 .576 .832 r
.55744 .76604 m .5575 .76449 L .55603 .76305 L F
.55744 .76604 m .56002 .76567 L .5575 .76449 L F
.332 0 0 r
.50866 .69847 m .51218 .69664 L .51009 .69743 L F
.908 .835 .762 r
.73068 .50255 m .72752 .50465 L .7296 .50151 L F
.73068 .50255 m .72969 .50441 L .72752 .50465 L F
0 0 0 r
.75434 .52126 m .75347 .52277 L .75184 .52424 L F
.75347 .52277 m .75148 .52579 L .75184 .52424 L F
.797 .659 .711 r
.56831 .64979 m .56784 .65242 L .57019 .65262 L F
.783 .448 0 r
.57029 .65358 m .57019 .65262 L .56784 .65242 L F
.57029 .65358 m .5709 .65477 L .57019 .65262 L F
.64 .682 .874 r
.7047 .49379 m .70126 .49284 L .70358 .49117 L F
.531 .599 .866 r
.70638 .49175 m .7047 .49379 L .70358 .49117 L F
.682 .837 .958 r
.70756 .49254 m .7047 .49379 L .70638 .49175 L F
.55 .337 .544 r
.59285 .61858 m .5926 .62076 L .59051 .62124 L F
.685 .508 .641 r
.59608 .6184 m .5926 .62076 L .59285 .61858 L F
.474 .64 .929 r
.32227 .6281 m .32125 .62985 L .32015 .62824 L F
.435 .59 .907 r
.32227 .6281 m .32292 .62965 L .32125 .62985 L F
.193 .698 .906 r
.43581 .69746 m .43798 .69747 L .43942 .69789 L F
.072 .627 .81 r
.43798 .69747 m .44161 .69775 L .43942 .69789 L F
.782 .62 .679 r
.66254 .49312 m .6609 .49619 L .66429 .49654 L F
.227 0 0 r
.66077 .49856 m .66429 .49654 L .6609 .49619 L F
.66077 .49856 m .66314 .49798 L .66429 .49654 L F
.647 .529 .706 r
.58458 .71257 m .58568 .70867 L .58346 .70903 L F
.58458 .71257 m .58695 .71185 L .58568 .70867 L F
.717 .969 .724 r
.7533 .51068 m .75509 .50884 L .75412 .50915 L F
0 0 0 r
.75348 .50935 m .75412 .50915 L .75634 .50846 L F
.533 .332 .553 r
.75169 .51193 m .75412 .50915 L .75308 .50947 L F
0 0 0 r
.75308 .50947 m .75412 .50915 L .75348 .50935 L F
.717 .969 .724 r
.75509 .50884 m .75532 .5086 L .75412 .50915 L F
.206 .407 .838 r
.75412 .50915 m .75518 .51166 L .7533 .51068 L F
.437 .44 .765 r
.7556 .51322 m .7533 .51068 L .75518 .51166 L F
.823 .737 .769 r
.68425 .5102 m .68734 .51052 L .6864 .50723 L F
.821 .744 .779 r
.68425 .5102 m .68524 .51342 L .68734 .51052 L F
.182 .325 .775 r
.56706 .59546 m .56899 .59794 L .56877 .59863 L F
0 0 0 r
.56877 .59863 m .56846 .60022 L .56855 .60091 L F
.56877 .59863 m .56899 .59794 L .56846 .60022 L F
.517 .399 .657 r
.26438 .61245 m .26637 .61205 L .26617 .60964 L F
.202 0 .001 r
.58189 .55543 m .58419 .55499 L .58503 .55346 L F
.201 0 .09 r
.58419 .55499 m .58689 .55239 L .58503 .55346 L F
.549 .637 .89 r
.30904 .62299 m .30849 .62587 L .30743 .62319 L F
.30904 .62299 m .31108 .62536 L .30849 .62587 L F
.532 .394 .639 r
.69515 .49254 m .69232 .49028 L .69433 .49026 L F
.649 .719 .9 r
.69763 .49125 m .69515 .49254 L .69433 .49026 L F
.124 0 0 r
.33149 .63024 m .33516 .62955 L .33309 .62998 L F
.562 .246 .39 r
.42138 .66044 m .42481 .65787 L .42167 .6584 L F
.42138 .66044 m .42405 .66023 L .42481 .65787 L F
.474 .161 .355 r
.42481 .65787 m .42666 .65929 L .42719 .65772 L F
.42481 .65787 m .42405 .66023 L .42666 .65929 L F
.778 .717 .795 r
.67948 .51556 m .68304 .51431 L .68174 .51295 L F
.743 .715 .826 r
.68174 .51295 m .68304 .51431 L .68524 .51342 L F
.6 .392 .571 r
.58805 .60698 m .59012 .60661 L .59016 .60423 L F
.49 .304 .554 r
.59012 .60661 m .59246 .60587 L .59016 .60423 L F
.602 .24 .328 r
.59016 .60423 m .59246 .60587 L .5926 .60446 L F
.371 .048 .281 r
.36735 .62867 m .36526 .62928 L .36792 .62716 L F
.438 .127 .339 r
.37006 .62662 m .36735 .62867 L .36792 .62716 L F
.044 .094 .59 r
.56143 .65701 m .56129 .65348 L .5605 .65497 L F
0 .081 .601 r
.5602 .65384 m .56143 .65701 L .5605 .65497 L F
0 0 .215 r
.5602 .65384 m .5605 .65497 L .56033 .65429 L F
.5602 .65384 m .55977 .65229 L .55989 .65238 L F
.5602 .65384 m .56033 .65429 L .55973 .65192 L F
.5602 .65384 m .55846 .65133 L .55977 .65229 L F
.685 .521 .658 r
.67776 .48339 m .67727 .48306 L .67782 .48159 L F
.526 .195 .351 r
.67833 .48025 m .67782 .48159 L .67546 .48161 L F
.26 .732 .941 r
.67782 .48159 m .67454 .48118 L .67546 .48161 L F
.685 .521 .658 r
.67727 .48306 m .67454 .48118 L .67782 .48159 L F
.526 .195 .351 r
.67864 .4801 m .67782 .48159 L .67833 .48025 L F
0 0 0 r
.68017 .4787 m .67782 .48159 L .67864 .4801 L F
.648 .435 .58 r
.59818 .60338 m .60073 .60095 L .59835 .60145 L F
.541 .336 .551 r
.58542 .66604 m .58291 .66884 L .58315 .66665 L F
.524 .36 .601 r
.51997 .63517 m .5179 .6377 L .51747 .63579 L F
.51997 .63517 m .52 .6374 L .5179 .6377 L F
.48 .456 .753 r
.52008 .63887 m .5179 .6377 L .52 .6374 L F
.575 .299 .461 r
.42719 .65772 m .42958 .6575 L .42985 .65544 L F
.523 .17 .311 r
.42958 .6575 m .43303 .6552 L .42985 .65544 L F
.637 .437 .595 r
.47988 .77742 m .48059 .77406 L .47863 .77363 L F
.47988 .77742 m .48283 .77753 L .48059 .77406 L F
.784 .8 .865 r
.48308 .80593 m .48417 .80824 L .48476 .80714 L F
.586 .327 .491 r
.55258 .75071 m .55626 .75068 L .55384 .74868 L F
.902 .64 .532 r
.57294 .66099 m .57107 .65738 L .5709 .65743 L F
.392 .114 .368 r
.31714 .6059 m .31567 .60455 L .31825 .60336 L F
.26 0 .17 r
.31909 .60515 m .31825 .60336 L .3198 .60319 L F
.31909 .60515 m .31714 .6059 L .31825 .60336 L F
.767 .71 .798 r
.7376 .51043 m .74098 .51084 L .73973 .5077 L F
.728 .718 .841 r
.74098 .51084 m .7422 .50691 L .73973 .5077 L F
.74098 .51084 m .74392 .50998 L .7422 .50691 L F
.928 .86 .754 r
.64482 .5071 m .64788 .5046 L .64672 .50361 L F
.64482 .5071 m .64599 .5082 L .64788 .5046 L F
.788 .887 .916 r
.64672 .50361 m .64788 .5046 L .65108 .50201 L F
.64672 .50361 m .65108 .50201 L .65103 .50176 L F
.64672 .50361 m .65179 .50143 L .65056 .49984 L F
.819 .614 .06 r
.65124 .50419 m .65089 .50372 L .65077 .50045 L F
.65079 .50052 m .65077 .50045 L .65077 .50039 L F
.65124 .50419 m .65077 .50045 L .65079 .50052 L F
.788 .887 .916 r
.65103 .50176 m .65108 .50201 L .65179 .50143 L F
.805 .339 0 r
.65253 .50517 m .65375 .50753 L .65291 .50679 L F
.771 .292 0 r
.65124 .50419 m .65291 .50679 L .6516 .50564 L F
.651 .82 .964 r
.65161 .50564 m .65291 .50679 L .65549 .5059 L F
.6516 .50564 m .65291 .50679 L .65161 .50564 L F
.805 .339 0 r
.65375 .50753 m .65391 .50783 L .65291 .50679 L F
.256 0 .011 r
.28842 .58754 m .28982 .58799 L .29052 .58717 L F
.28842 .58754 m .28698 .58934 L .28982 .58799 L F
.799 .579 .603 r
.498 .80486 m .50205 .80564 L .5012 .80784 L F
.498 .80486 m .5012 .80784 L .49948 .80685 L F
.748 .805 .326 r
.5012 .80784 m .50177 .80609 L .49948 .80685 L F
.522 0 0 r
.49964 .8055 m .50205 .80564 L .498 .80486 L F
.50072 .8058 m .50205 .80564 L .49964 .8055 L F
.50101 .80588 m .5011 .80586 L .50072 .8058 L F
.5011 .80586 m .50205 .80564 L .50072 .8058 L F
.091 .508 .903 r
.49849 .80426 m .50017 .80571 L .498 .80486 L F
.648 .559 .74 r
.50231 .80445 m .50063 .80527 L .50019 .80286 L F
.715 .811 .925 r
.49897 .80552 m .49985 .80566 L .50231 .80445 L F
.49985 .80566 m .50072 .8058 L .50231 .80445 L F
.648 .559 .74 r
.50231 .80445 m .50076 .80594 L .50063 .80527 L F
.715 .811 .925 r
.49897 .80552 m .49948 .80685 L .50072 .8058 L F
.522 0 0 r
.50076 .80594 m .50101 .80588 L .49964 .8055 L F
.091 .508 .903 r
.49849 .80426 m .50076 .80594 L .50017 .80571 L F
.715 .811 .925 r
.49849 .80426 m .49897 .80552 L .49968 .80529 L F
.49849 .80426 m .49968 .80529 L .50231 .80445 L F
.755 .994 .82 r
.50231 .80445 m .50205 .80564 L .50101 .80588 L F
.748 .805 .326 r
.50101 .80588 m .50231 .80445 L .50072 .8058 L F
.755 .994 .82 r
.50231 .80445 m .50101 .80588 L .50076 .80594 L F
.748 .805 .326 r
.50177 .80609 m .50231 .80445 L .50101 .80588 L F
.50177 .80609 m .50072 .8058 L .49948 .80685 L F
.5012 .80784 m .50205 .80564 L .50231 .80445 L F
.289 0 0 r
.63978 .48875 m .63855 .48817 L .63795 .48943 L F
.63978 .48875 m .64304 .48961 L .63855 .48817 L F
.748 .706 .812 r
.68174 .51295 m .68524 .51342 L .68425 .5102 L F
.425 .043 .208 r
.74239 .53358 m .7454 .53196 L .74506 .5333 L F
.216 0 0 r
.7454 .53196 m .7477 .53239 L .74506 .5333 L F
.563 .882 .991 r
.74506 .5333 m .74607 .53243 L .74347 .53315 L F
.74607 .53243 m .74694 .53168 L .7449 .53255 L F
.74607 .53243 m .7449 .53255 L .74347 .53315 L F
.216 0 0 r
.7454 .53196 m .74737 .53209 L .74758 .53228 L F
.74728 .53231 m .74758 .53228 L .7477 .53239 L F
.7454 .53196 m .74758 .53228 L .74728 .53231 L F
.662 .528 .69 r
.53908 .79588 m .54222 .79507 L .54248 .79412 L F
.53908 .79588 m .5408 .79722 L .54222 .79507 L F
.427 .237 .518 r
.60312 .59579 m .60516 .59509 L .60538 .59275 L F
.357 .146 .45 r
.60299 .59803 m .60516 .59509 L .60312 .59579 L F
0 .269 .702 r
.73747 .52075 m .73449 .51907 L .73327 .51817 L F
.523 .17 .311 r
.42958 .6575 m .43197 .65726 L .43303 .6552 L F
.471 .117 .283 r
.43303 .6552 m .43494 .6563 L .43538 .65499 L F
.43303 .6552 m .43197 .65726 L .43494 .6563 L F
.224 0 0 r
.44489 .707 m .44415 .70606 L .44641 .70596 L F
.44489 .707 m .4424 .70741 L .44415 .70606 L F
.77 .49 .511 r
.41823 .6592 m .42138 .66044 L .42167 .6584 L F
.804 .678 .725 r
.57065 .6096 m .57166 .60719 L .56938 .60673 L F
.092 .344 .816 r
.74984 .52764 m .75036 .52699 L .74754 .52473 L F
.186 .292 .74 r
.748 .52883 m .74984 .52764 L .75036 .52699 L F
.748 .52883 m .74974 .52912 L .74984 .52764 L F
0 0 .009 r
.75148 .52579 m .74974 .52912 L .74984 .52764 L F
.801 .6 .629 r
.49519 .6997 m .49896 .70069 L .49909 .69782 L F
.864 .816 .8 r
.54581 .61102 m .5475 .61288 L .54772 .61025 L F
.708 .679 .82 r
.54772 .61025 m .5475 .61288 L .54969 .6123 L F
.417 .179 .444 r
.5475 .61288 m .54974 .614 L .54969 .6123 L F
.5475 .61288 m .54743 .61505 L .54974 .614 L F
.986 .723 .439 r
.56331 .59471 m .56453 .59801 L .5644 .59489 L F
.732 .621 .735 r
.56559 .59184 m .5644 .59489 L .56806 .59276 L F
.56559 .59184 m .56331 .59471 L .5644 .59489 L F
.722 .989 .838 r
.68483 .49769 m .68645 .4957 L .68727 .49682 L F
.68483 .49769 m .68378 .49788 L .68645 .4957 L F
.186 .292 .74 r
.748 .52883 m .7487 .53093 L .74974 .52912 L F
.743 .981 .746 r
.74737 .53209 m .7487 .53093 L .74974 .52912 L F
.934 .682 .532 r
.57406 .66347 m .57294 .66099 L .57511 .66042 L F
.57406 .66347 m .57232 .66317 L .57294 .66099 L F
0 0 .493 r
.57406 .66347 m .57442 .66289 L .57232 .66317 L F
.57406 .66347 m .57528 .66568 L .57442 .66289 L F
0 .038 .564 r
.57453 .66593 m .57528 .66568 L .57406 .66347 L F
.693 .419 .504 r
.68587 .47706 m .68797 .47767 L .68967 .47697 L F
.5 .002 .004 r
.68967 .47697 m .68861 .478 L .68587 .47706 L F
.683 .733 .889 r
.50132 .64593 m .50492 .6466 L .50356 .64363 L F
.557 .542 .794 r
.50492 .6466 m .50607 .64273 L .50356 .64363 L F
.50492 .6466 m .50712 .64619 L .50607 .64273 L F
.198 .09 .497 r
.50604 .64834 m .50712 .64619 L .50492 .6466 L F
.652 .405 .533 r
.5105 .64923 m .51097 .65212 L .50836 .65186 L F
.711 .446 .522 r
.51537 .65077 m .5105 .64923 L .51447 .64927 L F
.51537 .65077 m .51097 .65212 L .5105 .64923 L F
0 0 0 r
.41513 .70236 m .41369 .70257 L .41571 .70191 L F
.41513 .70236 m .4126 .703 L .41369 .70257 L F
.656 .752 .921 r
.69701 .50111 m .70048 .50181 L .70004 .50011 L F
.628 .762 .943 r
.70004 .50011 m .70048 .50181 L .70204 .50116 L F
.664 .911 .978 r
.55803 .62384 m .5592 .62447 L .56148 .62336 L F
0 0 0 r
.32685 .60178 m .32701 .60192 L .32549 .60201 L F
.32685 .60178 m .32904 .60147 L .32701 .60192 L F
.699 .458 .556 r
.55287 .76016 m .5529 .76252 L .55095 .76233 L F
.361 .129 .421 r
.57507 .56162 m .577 .56103 L .57713 .55903 L F
.254 0 .175 r
.57423 .56342 m .577 .56103 L .57507 .56162 L F
.842 .844 .846 r
.67175 .52146 m .67453 .52165 L .67412 .51842 L F
.67175 .52146 m .67303 .52253 L .67453 .52165 L F
.826 .827 .849 r
.67412 .51842 m .67453 .52165 L .67722 .51852 L F
.47 .802 .999 r
.32631 .63036 m .32662 .63092 L .32493 .63073 L F
.417 .732 .991 r
.32677 .6289 m .32662 .63092 L .32631 .63036 L F
.32677 .6289 m .32941 .63075 L .32662 .63092 L F
.63 .493 .676 r
.40888 .66648 m .41146 .66625 L .41104 .66359 L F
.529 .321 .541 r
.40904 .669 m .41146 .66625 L .40888 .66648 L F
.739 .614 .719 r
.4975 .64362 m .49908 .64681 L .49546 .64654 L F
.569 .221 .339 r
.49908 .64681 m .4951 .64893 L .49546 .64654 L F
.49908 .64681 m .49784 .64908 L .4951 .64893 L F
.474 .121 .286 r
.50056 .64847 m .49908 .64681 L .50132 .64593 L F
.50056 .64847 m .49784 .64908 L .49908 .64681 L F
.57 .395 .605 r
.42979 .68069 m .42979 .68323 L .42746 .68366 L F
.643 .681 .871 r
.7422 .50691 m .74392 .50998 L .7458 .50808 L F
.503 .623 .902 r
.74392 .50998 m .74644 .50977 L .7458 .50808 L F
.182 .325 .775 r
.56706 .59546 m .56866 .59683 L .56899 .59794 L F
.868 .766 .748 r
.56648 .5973 m .56866 .59683 L .56749 .59587 L F
.206 .324 .764 r
.5655 .60128 m .5667 .60022 L .56453 .59801 L F
.5667 .60022 m .56666 .59971 L .56453 .59801 L F
.5667 .60022 m .56699 .59997 L .56666 .59971 L F
.275 .333 .741 r
.56453 .59801 m .56699 .59997 L .566 .60042 L F
.868 .766 .748 r
.56528 .59902 m .56655 .5982 L .56648 .5973 L F
.56655 .5982 m .56866 .59683 L .56648 .5973 L F
.099 .139 .616 r
.56726 .6026 m .5655 .60128 L .56529 .60338 L F
.56726 .6026 m .56699 .59997 L .5655 .60128 L F
.639 .402 .542 r
.57107 .65738 m .57462 .65523 L .5709 .65477 L F
.57107 .65738 m .57534 .65668 L .57462 .65523 L F
.719 .647 .776 r
.25389 .63501 m .25523 .63829 L .25827 .6353 L F
.436 .254 .535 r
.3055 .61258 m .30499 .61581 L .3033 .61635 L F
.53 .459 .721 r
.30499 .61581 m .30378 .61813 L .3033 .61635 L F
.787 .701 .769 r
.29411 .64772 m .29604 .64958 L .29839 .64615 L F
.524 .215 .385 r
.26822 .64425 m .26998 .64571 L .2711 .64447 L F
.542 .333 .546 r
.26822 .64425 m .27102 .64165 L .27086 .64178 L F
.26822 .64425 m .2711 .64447 L .27102 .64165 L F
.077 .435 .874 r
.7102 .48052 m .7118 .48015 L .70931 .4791 L F
.7102 .48052 m .71268 .4815 L .7118 .48015 L F
.42 .317 .631 r
.71083 .48186 m .71268 .4815 L .7102 .48052 L F
.094 .626 .867 r
.31366 .58323 m .31568 .58339 L .31735 .58387 L F
.032 .56 .86 r
.31739 .58353 m .31735 .58387 L .31568 .58339 L F
.31739 .58353 m .31913 .58422 L .31735 .58387 L F
.78 .807 .874 r
.73302 .51381 m .73521 .51294 L .73325 .51139 L F
.73325 .51139 m .73521 .51294 L .7376 .51043 L F
.578 .443 .66 r
.43045 .6864 m .43091 .68896 L .42868 .68933 L F
.582 .458 .677 r
.43091 .68896 m .42892 .69172 L .42868 .68933 L F
.508 .356 .61 r
.75617 .51573 m .75437 .51875 L .75388 .51638 L F
.045 0 .471 r
.67203 .47955 m .67085 .47608 L .67098 .47867 L F
.67203 .47955 m .67311 .47586 L .67085 .47608 L F
.67203 .47955 m .67342 .47845 L .67311 .47586 L F
.471 .788 .999 r
.67098 .47867 m .67342 .47845 L .67203 .47955 L F
.452 .591 .901 r
.38562 .59405 m .38459 .59591 L .38373 .59414 L F
.487 .635 .92 r
.38562 .59405 m .38653 .5958 L .38459 .59591 L F
.645 .491 .66 r
.61572 .51917 m .61851 .51922 L .61805 .51632 L F
.483 .373 .653 r
.61572 .51917 m .61823 .52102 L .61851 .51922 L F
.61572 .51917 m .61624 .52183 L .61823 .52102 L F
.792 .691 .753 r
.67037 .5133 m .67171 .51645 L .66847 .5156 L F
.583 .425 .633 r
.54529 .77762 m .54705 .77585 L .54486 .77435 L F
0 0 .461 r
.58195 .65392 m .58159 .65146 L .58255 .65227 L F
.998 .778 .447 r
.50431 .77999 m .50437 .78389 L .50323 .78159 L F
.898 .554 .074 r
.50396 .78155 m .50431 .77999 L .50323 .78159 L F
.50396 .78155 m .50559 .78455 L .50431 .77999 L F
0 .255 .764 r
.52891 .61334 m .53055 .615 L .52854 .61183 L F
.908 .837 .764 r
.72969 .50441 m .72795 .50764 L .72752 .50465 L F
.656 .236 .235 r
.54516 .76102 m .54701 .76233 L .5447 .7615 L F
.525 .339 .572 r
.547 .75979 m .54701 .76233 L .54516 .76102 L F
.65 .847 .976 r
.49057 .62185 m .4871 .62168 L .48926 .6211 L F
.491 .805 1 r
.49162 .62058 m .49057 .62185 L .48926 .6211 L F
.49162 .62058 m .49288 .62146 L .49057 .62185 L F
0 0 .308 r
.58637 .66256 m .58542 .66604 L .58555 .66373 L F
.056 .622 .753 r
.45256 .66553 m .45708 .6655 L .45504 .6635 L F
.489 .505 .8 r
.45708 .6655 m .45742 .66299 L .45504 .6635 L F
.45708 .6655 m .4584 .66664 L .45742 .66299 L F
.499 .416 .693 r
.52301 .6515 m .51997 .64931 L .52332 .64941 L F
.177 0 .048 r
.46486 .64037 m .46658 .64065 L .46774 .6383 L F
0 0 .044 r
.46774 .6383 m .46926 .63768 L .46998 .63547 L F
.16 0 .04 r
.46774 .6383 m .46862 .63951 L .46926 .63768 L F
.46774 .6383 m .46658 .64065 L .46862 .63951 L F
.35 .3 .661 r
.29297 .64646 m .29385 .64295 L .29172 .64411 L F
.29297 .64646 m .29454 .64639 L .29385 .64295 L F
.351 .326 .69 r
.29297 .64646 m .29411 .64772 L .29454 .64639 L F
.149 .668 .888 r
.29297 .64646 m .29454 .64639 L .29108 .64601 L F
.303 .752 .959 r
.34579 .58749 m .34949 .58793 L .34741 .58823 L F
.674 .62 .787 r
.26836 .63628 m .27158 .64004 L .2668 .63823 L F
.746 .632 .734 r
.27293 .6384 m .26836 .63628 L .26917 .63792 L F
.798 .716 .774 r
.27293 .6384 m .27158 .64004 L .26917 .63792 L F
.219 0 .275 r
.27158 .64004 m .27224 .6403 L .27293 .6384 L F
.373 .244 .572 r
.75399 .49438 m .75461 .49604 L .7526 .49638 L F
.397 .35 .689 r
.75461 .49604 m .75499 .49818 L .7526 .49638 L F
.422 .349 .669 r
.7526 .49638 m .75499 .49818 L .75326 .49904 L F
.941 .737 .599 r
.58331 .65895 m .58218 .65904 L .58442 .65749 L F
.792 .991 .752 r
.58442 .65749 m .58522 .65573 L .58624 .65743 L F
.58442 .65749 m .58218 .65904 L .58522 .65573 L F
.988 .739 .461 r
.56303 .61511 m .56284 .61756 L .56402 .61813 L F
.589 .775 .968 r
.53123 .79902 m .53261 .80036 L .53475 .79968 L F
.53475 .79968 m .53261 .80036 L .53123 .79902 L F
.432 .186 .438 r
.57713 .55903 m .57916 .5604 L .57941 .55848 L F
.57713 .55903 m .577 .56103 L .57916 .5604 L F
.657 .718 .893 r
.70126 .49284 m .69763 .49125 L .7002 .49065 L F
.697 .767 .906 r
.70358 .49117 m .70126 .49284 L .7002 .49065 L F
.245 .745 .901 r
.39035 .59799 m .39252 .5978 L .39383 .59808 L F
.213 0 0 r
.39252 .5978 m .39605 .59745 L .39383 .59808 L F
0 0 0 r
.56154 .59971 m .56023 .60162 L .56223 .59851 L F
.653 .49 .651 r
.56453 .59801 m .56154 .59971 L .56223 .59851 L F
.634 .483 .66 r
.61805 .51632 m .6206 .51796 L .62047 .5161 L F
.61805 .51632 m .61851 .51922 L .6206 .51796 L F
.571 .353 .546 r
.59846 .61549 m .59842 .61791 L .59608 .6184 L F
.568 .35 .545 r
.59846 .61549 m .60081 .61745 L .59842 .61791 L F
.648 .322 .406 r
.60096 .61575 m .60081 .61745 L .59846 .61549 L F
.758 .662 .755 r
.69416 .47344 m .69741 .47402 L .69636 .47068 L F
.28 .392 .799 r
.74527 .47893 m .74785 .48057 L .74648 .48219 L F
.414 .593 .917 r
.74785 .48057 m .74848 .48226 L .74648 .48219 L F
.385 .78 .987 r
.32273 .64867 m .32363 .64791 L .32117 .64816 L F
.32273 .64867 m .3245 .64852 L .32363 .64791 L F
.462 .848 .982 r
.49288 .62146 m .49516 .62095 L .49645 .62142 L F
.582 .9 .985 r
.49645 .62142 m .49728 .62012 L .49863 .62076 L F
.49645 .62142 m .49516 .62095 L .49728 .62012 L F
.568 .374 .578 r
.60238 .53893 m .60481 .53853 L .60478 .53616 L F
.452 .262 .532 r
.60481 .53853 m .60688 .53557 L .60478 .53616 L F
.669 .629 .8 r
.65945 .50214 m .66077 .49856 L .65842 .50152 L F
.65945 .50214 m .6623 .50248 L .66077 .49856 L F
0 .438 .803 r
.6603 .50214 m .65945 .50214 L .65842 .50152 L F
.452 0 0 r
.65945 .50214 m .66192 .50296 L .6623 .50248 L F
0 .438 .803 r
.6603 .50214 m .66192 .50296 L .65945 .50214 L F
.345 0 .073 r
.39548 .60694 m .39468 .60844 L .39239 .60891 L F
.504 .239 .446 r
.39732 .60604 m .39468 .60844 L .39548 .60694 L F
.658 .466 .613 r
.43248 .68046 m .42979 .68323 L .42979 .68069 L F
.52 .671 .932 r
.26917 .63792 m .27158 .64004 L .2668 .63823 L F
.171 .019 .419 r
.27158 .64004 m .27102 .64165 L .27224 .6403 L F
.802 .573 .591 r
.56154 .59971 m .55874 .60047 L .56023 .60162 L F
.637 .411 .557 r
.59051 .62124 m .5905 .62358 L .5881 .62369 L F
.629 .442 .611 r
.5926 .62076 m .5905 .62358 L .59051 .62124 L F
.975 .855 .657 r
.62825 .56705 m .62809 .56397 L .62769 .56609 L F
.975 .847 .652 r
.62638 .56936 m .62825 .56705 L .62769 .56609 L F
.62638 .56936 m .62756 .5705 L .62825 .56705 L F
.229 .075 .454 r
.30678 .61376 m .3055 .61258 L .30862 .61096 L F
.30678 .61376 m .30499 .61581 L .3055 .61258 L F
0 0 0 r
.32646 .64812 m .3306 .64638 L .32846 .64739 L F
.32846 .64739 m .3306 .64638 L .33259 .64574 L F
.908 .524 .097 r
.56803 .6052 m .56938 .60673 L .56858 .60467 L F
.791 .876 .445 r
.56858 .60467 m .56912 .60273 L .56803 .6052 L F
.501 .405 .678 r
.26589 .60762 m .26746 .60358 L .26533 .60403 L F
.366 .623 .951 r
.38186 .59215 m .38102 .59355 L .37962 .59248 L F
.38186 .59215 m .38373 .59414 L .38102 .59355 L F
.291 0 .109 r
.53787 .78472 m .54095 .78285 L .53721 .78313 L F
.53787 .78472 m .53973 .78421 L .54095 .78285 L F
.54095 .78285 m .53973 .78421 L .53787 .78472 L F
.77 .7 .786 r
.70219 .47046 m .70566 .47107 L .7045 .46769 L F
.78 .677 .751 r
.70219 .47046 m .70349 .4741 L .70566 .47107 L F
.802 .716 .77 r
.7045 .46769 m .70566 .47107 L .70779 .46803 L F
.777 .526 .556 r
.57453 .66593 m .57708 .66909 L .57391 .66886 L F
.57453 .66593 m .57391 .66886 L .57528 .66568 L F
.846 .821 .825 r
.66198 .49033 m .65997 .49269 L .66254 .49312 L F
.888 .769 .724 r
.65943 .49512 m .66254 .49312 L .65997 .49269 L F
.65943 .49512 m .6609 .49619 L .66254 .49312 L F
.689 .864 .965 r
.73857 .50396 m .74201 .50417 L .74081 .50118 L F
.791 .744 .81 r
.74081 .50118 m .74201 .50417 L .74435 .50165 L F
.73 .814 .917 r
.70667 .46672 m .7045 .46769 L .70779 .46803 L F
.661 .804 .952 r
.70779 .46803 m .70983 .46571 L .70667 .46672 L F
.70779 .46803 m .71025 .46698 L .70983 .46571 L F
.586 .211 .299 r
.58159 .65146 m .58413 .65139 L .58512 .64923 L F
.487 .505 .801 r
.58512 .64923 m .58607 .64562 L .58728 .64649 L F
.36 .148 .451 r
.58728 .64649 m .58711 .64859 L .58512 .64923 L F
.487 .505 .801 r
.58512 .64923 m .58711 .64859 L .58607 .64562 L F
.255 .143 .527 r
.58702 .65142 m .58512 .64923 L .58711 .64859 L F
.605 .35 .504 r
.58413 .65139 m .58711 .64859 L .58512 .64923 L F
.931 .752 .639 r
.56557 .61097 m .56712 .61189 L .56598 .60846 L F
.988 .747 .477 r
.56598 .60846 m .56712 .61189 L .56655 .61073 L F
.874 .702 .665 r
.56938 .60673 m .56655 .61073 L .57065 .6096 L F
.826 .762 .792 r
.56655 .61073 m .57065 .61178 L .57065 .6096 L F
.985 .765 .522 r
.57184 .60824 m .57062 .60737 L .57064 .60744 L F
.508 .82 1 r
.57306 .60906 m .57184 .60824 L .57065 .6096 L F
.499 .297 .537 r
.57223 .6115 m .57313 .60904 L .57065 .6096 L F
0 0 .294 r
.57163 .61075 m .57065 .6096 L .57313 .60904 L F
.57163 .61075 m .57184 .60824 L .57065 .6096 L F
.985 .765 .522 r
.57184 .60824 m .57064 .60744 L .57163 .61075 L F
.508 .82 1 r
.57313 .60904 m .57184 .60824 L .57306 .60906 L F
0 .452 .785 r
.52863 .78784 m .52948 .78836 L .52721 .78752 L F
.785 .391 .309 r
.52948 .78836 m .52912 .78979 L .52721 .78752 L F
.973 .661 .335 r
.52948 .78836 m .53 .79085 L .52912 .78979 L F
.488 .881 .961 r
.53102 .78728 m .52948 .78836 L .52863 .78784 L F
0 0 .023 r
.53102 .78728 m .52912 .78979 L .52948 .78836 L F
.471 .186 .399 r
.31567 .60455 m .31512 .60653 L .31289 .60696 L F
.392 .114 .368 r
.31714 .6059 m .31512 .60653 L .31567 .60455 L F
.628 .701 .898 r
.53331 .64234 m .53376 .64398 L .53029 .64305 L F
.242 .422 .84 r
.53331 .64234 m .53483 .64276 L .53376 .64398 L F
.466 .761 .994 r
.53483 .64276 m .536 .64371 L .53376 .64398 L F
.596 .527 .747 r
.53623 .64673 m .53376 .64398 L .536 .64371 L F
.863 .534 .018 r
.48955 .64693 m .48984 .64842 L .48878 .64569 L F
.535 .16 .276 r
.49355 .64655 m .48984 .64842 L .48955 .64693 L F
.776 .7 .78 r
.5113 .77363 m .51235 .77712 L .50916 .77549 L F
.954 .615 .327 r
.51235 .77712 m .51121 .77739 L .50916 .77549 L F
.51235 .77712 m .51253 .77902 L .51121 .77739 L F
.534 .879 .987 r
.51413 .77552 m .51235 .77712 L .5113 .77363 L F
.862 .559 .473 r
.51255 .77517 m .51413 .77552 L .51255 .77486 L F
.534 .879 .987 r
.51413 .77552 m .51608 .77595 L .51235 .77712 L F
.769 .407 .369 r
.51235 .77712 m .51589 .77955 L .51253 .77902 L F
.862 .559 .473 r
.51254 .77794 m .51413 .77552 L .51255 .77517 L F
.534 .879 .987 r
.51413 .77552 m .51615 .77593 L .51608 .77595 L F
.482 .375 .656 r
.40538 .67787 m .4074 .67752 L .40704 .6744 L F
.523 .436 .698 r
.40538 .67787 m .40807 .6799 L .4074 .67752 L F
.40538 .67787 m .40591 .68059 L .40807 .6799 L F
.682 .835 .957 r
.53475 .79968 m .5385 .79975 L .53706 .79899 L F
.515 .341 .584 r
.54969 .6123 m .55273 .61231 L .55272 .60932 L F
.858 .669 .646 r
.55149 .61446 m .54969 .6123 L .54974 .614 L F
.55149 .61446 m .55273 .61231 L .54969 .6123 L F
.484 .233 .458 r
.38543 .61301 m .38499 .61513 L .38281 .61556 L F
.466 .203 .43 r
.38763 .61264 m .38499 .61513 L .38543 .61301 L F
.349 .773 .974 r
.71138 .47657 m .70944 .47706 L .70961 .47591 L F
.71138 .47657 m .71259 .47674 L .70944 .47706 L F
.787 .701 .769 r
.29411 .64772 m .29839 .64615 L .29659 .6455 L F
.451 .519 .837 r
.29839 .64615 m .29888 .64318 L .29659 .6455 L F
.29839 .64615 m .3005 .64657 L .29888 .64318 L F
.317 0 .007 r
.51977 .70086 m .51836 .70256 L .51613 .7029 L F
.508 .16 .313 r
.52175 .69988 m .51836 .70256 L .51977 .70086 L F
.099 0 0 r
.44997 .70524 m .44864 .70571 L .44641 .70596 L F
.306 0 0 r
.45218 .70538 m .44864 .70571 L .44997 .70524 L F
.456 .358 .655 r
.40658 .68351 m .40699 .68599 L .40884 .68551 L F
.441 .417 .736 r
.40591 .68059 m .40658 .68351 L .40817 .68314 L F
.427 .356 .675 r
.40658 .68351 m .40884 .68551 L .40817 .68314 L F
.764 .388 0 r
.54083 .62696 m .54024 .62607 L .53924 .62369 L F
.818 .466 0 r
.54083 .62696 m .54156 .62918 L .54024 .62607 L F
.571 .378 .581 r
.59993 .54189 m .60235 .54155 L .60238 .53893 L F
.543 .342 .558 r
.60235 .54155 m .60481 .53853 L .60238 .53893 L F
.694 .549 .686 r
.4975 .64362 m .49547 .64385 L .49793 .64088 L F
0 0 0 r
.55802 .58055 m .55922 .57969 L .56002 .57811 L F
.037 0 .167 r
.56002 .57811 m .56196 .57725 L .56233 .575 L F
0 0 0 r
.56002 .57811 m .55922 .57969 L .56196 .57725 L F
0 .16 .631 r
.75027 .514 m .75016 .5137 L .74931 .5133 L F
.083 .633 .825 r
.36317 .58851 m .3625 .58871 L .36119 .58815 L F
.36317 .58851 m .36474 .58879 L .3625 .58871 L F
.577 .448 .668 r
.58616 .62919 m .58407 .63217 L .58373 .62974 L F
.23 0 0 r
.53456 .78513 m .53787 .78472 L .53697 .78513 L F
.53456 .78513 m .53787 .78472 L .53697 .78513 L F
.549 .352 .567 r
.53456 .78513 m .53697 .78513 L .53474 .78271 L F
0 0 .469 r
.52688 .60964 m .52708 .60859 L .52631 .60709 L F
0 .074 .635 r
.52688 .60964 m .52854 .61183 L .52708 .60859 L F
.835 .967 .888 r
.26226 .63514 m .26391 .63607 L .26533 .63456 L F
.26226 .63514 m .26135 .63644 L .26391 .63607 L F
.229 .097 .485 r
.27102 .64165 m .2711 .64447 L .27224 .6403 L F
.399 .243 .551 r
.44563 .66797 m .44372 .66618 L .44726 .6662 L F
.21 0 0 r
.44963 .667 m .44563 .66797 L .44726 .6662 L F
.133 .312 .779 r
.54237 .63313 m .54352 .63475 L .54246 .63154 L F
0 0 .13 r
.48378 .79559 m .48199 .79712 L .48134 .79858 L F
.552 .438 .677 r
.61035 .61075 m .60866 .61323 L .60536 .61184 L F
.196 0 0 r
.60866 .61323 m .60633 .61462 L .60536 .61184 L F
.544 .312 .513 r
.60536 .61184 m .60633 .61462 L .60358 .6153 L F
.631 .232 .27 r
.52763 .69814 m .52642 .7 L .52406 .69957 L F
.601 .198 .252 r
.52989 .69966 m .52642 .7 L .52763 .69814 L F
.569 .236 .364 r
.5311 .69731 m .52989 .69966 L .52763 .69814 L F
.517 .089 .166 r
.68587 .47706 m .68861 .478 L .68352 .47798 L F
.264 0 0 r
.55028 .78261 m .54855 .78336 L .54889 .78313 L F
0 0 0 r
.55028 .78261 m .55096 .78244 L .54855 .78336 L F
.55028 .78261 m .54979 .78318 L .55096 .78244 L F
.722 .648 .774 r
.69986 .47339 m .70349 .4741 L .70219 .47046 L F
.724 .621 .743 r
.71651 .49343 m .71405 .49649 L .71285 .49338 L F
.522 .404 .659 r
.2668 .63823 m .26917 .63792 L .26836 .63628 L F
.431 .129 .35 r
.3729 .62383 m .37215 .62615 L .37006 .62662 L F
.499 .222 .424 r
.37503 .62327 m .37215 .62615 L .3729 .62383 L F
.469 .209 .437 r
.43894 .66923 m .43859 .67148 L .43613 .67199 L F
.483 .168 .355 r
.44143 .66911 m .43859 .67148 L .43894 .66923 L F
.535 .16 .276 r
.49355 .64655 m .49192 .64879 L .48984 .64842 L F
.669 .531 .687 r
.49547 .64385 m .49546 .64654 L .49355 .64655 L F
.783 .463 .447 r
.4951 .64893 m .49355 .64655 L .49546 .64654 L F
.4951 .64893 m .49192 .64879 L .49355 .64655 L F
.74 .624 .73 r
.60576 .55575 m .60695 .55912 L .60351 .55858 L F
.644 .493 .664 r
.6249 .50774 m .62726 .50783 L .62719 .50471 L F
.507 .387 .652 r
.6249 .50774 m .62747 .50988 L .62726 .50783 L F
.6249 .50774 m .62553 .51075 L .62747 .50988 L F
.376 .091 .348 r
.41104 .66359 m .41305 .66324 L .41375 .6611 L F
.473 .181 .389 r
.41375 .6611 m .41531 .66265 L .41538 .65987 L F
.41375 .6611 m .41305 .66324 L .41531 .66265 L F
.22 .742 .822 r
.44392 .69721 m .44742 .69684 L .44503 .69716 L F
.627 .662 .864 r
.36854 .60403 m .36908 .60036 L .36717 .60072 L F
.36854 .60403 m .37093 .60387 L .36908 .60036 L F
.414 .198 .474 r
.36895 .60646 m .37093 .60387 L .36854 .60403 L F
0 0 0 r
.47258 .63273 m .46998 .63547 L .47161 .63383 L F
.214 0 .152 r
.46998 .63547 m .471 .63686 L .47161 .63383 L F
.46998 .63547 m .46926 .63768 L .471 .63686 L F
.931 .818 .713 r
.62721 .56097 m .63003 .55872 L .62852 .55784 L F
.62721 .56097 m .62849 .56203 L .63003 .55872 L F
.071 0 0 r
.46486 .64037 m .46564 .64127 L .46658 .64065 L F
.46486 .64037 m .46376 .64225 L .46564 .64127 L F
.571 .878 .993 r
.28795 .63916 m .29025 .63888 L .28977 .63807 L F
.419 .583 .908 r
.29025 .63888 m .29136 .63788 L .28977 .63807 L F
.29025 .63888 m .29351 .64048 L .29136 .63788 L F
.875 .435 .087 r
.50604 .64834 m .50557 .65029 L .50719 .64871 L F
.639 .631 .826 r
.35785 .5985 m .35915 .60151 L .363 .59947 L F
.164 0 .188 r
.57851 .63964 m .57955 .63971 L .57954 .63765 L F
.57851 .63964 m .57746 .64093 L .57955 .63971 L F
.423 .106 .322 r
.36526 .62928 m .3643 .63195 L .36215 .63242 L F
.455 .137 .336 r
.36725 .63038 m .36526 .62928 L .36735 .62867 L F
.36725 .63038 m .3643 .63195 L .36526 .62928 L F
.924 .947 .792 r
.73131 .5168 m .73252 .51599 L .73085 .5161 L F
.72993 .51774 m .73072 .5187 L .73144 .51762 L F
.73131 .5168 m .73144 .51762 L .73252 .51599 L F
.72993 .51774 m .73144 .51762 L .73131 .5168 L F
.283 .507 .895 r
.73437 .51703 m .73327 .51817 L .73125 .51638 L F
.7312 .51607 m .73125 .51638 L .73074 .51593 L F
.73437 .51703 m .73125 .51638 L .7312 .51607 L F
.914 .802 .722 r
.73045 .51553 m .73302 .51381 L .7304 .51283 L F
.283 .507 .895 r
.73055 .51565 m .73074 .51593 L .73034 .51558 L F
.73061 .51574 m .73074 .51593 L .73055 .51565 L F
.787 .59 .635 r
.73034 .51558 m .73077 .51596 L .73009 .5169 L F
.914 .802 .722 r
.73046 .51613 m .73073 .51589 L .73045 .51553 L F
.73055 .51565 m .73302 .51381 L .73045 .51553 L F
.73059 .51571 m .7306 .5157 L .73055 .51565 L F
.7306 .5157 m .73302 .51381 L .73055 .51565 L F
.73075 .51587 m .73302 .51381 L .73059 .51571 L F
.73099 .51565 m .73252 .51599 L .73302 .51381 L F
.73066 .51612 m .73252 .51599 L .73099 .51565 L F
.134 .505 .909 r
.73346 .5158 m .73437 .51703 L .73055 .51565 L F
.73047 .51559 m .73055 .51565 L .73034 .51558 L F
.73346 .5158 m .73055 .51565 L .73047 .51559 L F
.73047 .51559 m .73034 .51558 L .73012 .51524 L F
.974 .796 .602 r
.73034 .51558 m .72916 .51653 L .7294 .51413 L F
.72916 .51653 m .72869 .51691 L .72916 .51506 L F
.72916 .51653 m .72916 .51506 L .7294 .51413 L F
.666 .585 .754 r
.7287 .51461 m .72917 .51471 L .72901 .51442 L F
.72917 .51471 m .7296 .51481 L .72917 .51413 L F
.72917 .51471 m .72917 .51413 L .72737 .51126 L F
.134 .505 .909 r
.72973 .51426 m .7298 .51467 L .7294 .51413 L F
.791 .62 .669 r
.72877 .51349 m .72973 .51426 L .73042 .51162 L F
.72973 .51426 m .72974 .51427 L .72974 .51427 L F
.72973 .51426 m .72974 .51427 L .73042 .51162 L F
1 .807 .499 r
.72976 .51441 m .73045 .51556 L .7304 .51283 L F
.698 .249 .182 r
.73306 .51407 m .73252 .51467 L .73354 .51338 L F
.045 .462 .881 r
.73252 .51467 m .73346 .5158 L .73203 .51521 L F
.134 .505 .909 r
.73346 .5158 m .73047 .51559 L .73042 .51552 L F
.73346 .5158 m .73042 .51552 L .72994 .51472 L F
.73346 .5158 m .7298 .51467 L .72974 .51427 L F
.914 .802 .722 r
.73073 .51589 m .73075 .51587 L .73059 .51571 L F
.283 .507 .895 r
.73437 .51703 m .73074 .51593 L .73056 .51566 L F
0 .163 .641 r
.73492 .51668 m .73346 .5158 L .73252 .51467 L F
.15 .517 .915 r
.73752 .518 m .73437 .51703 L .73346 .5158 L F
.73752 .518 m .73346 .5158 L .73594 .51766 L F
0 .163 .641 r
.73492 .51668 m .73594 .51766 L .73346 .5158 L F
.698 .249 .182 r
.7316 .51619 m .73492 .51668 L .73252 .51467 L F
.7316 .51619 m .73252 .51467 L .73306 .51407 L F
.045 .462 .881 r
.73252 .51467 m .73203 .51521 L .72973 .51426 L F
.72958 .51416 m .72973 .51426 L .7294 .51413 L F
1 .807 .499 r
.72974 .51427 m .72978 .51418 L .72976 .51418 L F
.72976 .51441 m .7304 .51283 L .72974 .51427 L F
.045 .462 .881 r
.73252 .51467 m .72973 .51426 L .72958 .51416 L F
.134 .505 .909 r
.72974 .51427 m .72974 .51427 L .72973 .51426 L F
.72974 .51427 m .7298 .51467 L .72973 .51426 L F
.791 .62 .669 r
.72737 .51126 m .72877 .51349 L .73042 .51162 L F
.032 .371 .839 r
.72486 .51374 m .72869 .51691 L .72919 .51472 L F
.994 .875 .576 r
.72931 .51422 m .72869 .51691 L .72825 .51519 L F
.7294 .51413 m .72869 .51691 L .72931 .51422 L F
.032 .371 .839 r
.72919 .51472 m .72869 .51691 L .7296 .51481 L F
.994 .875 .576 r
.7294 .51413 m .72923 .51429 L .72926 .51427 L F
.791 .62 .669 r
.72926 .51427 m .7296 .51481 L .72952 .51409 L F
.994 .875 .576 r
.72945 .51414 m .72926 .51427 L .72947 .51415 L F
.7294 .51413 m .72926 .51427 L .72945 .51414 L F
.045 .462 .881 r
.72971 .51418 m .72958 .51416 L .72958 .51418 L F
.72958 .51416 m .7294 .51413 L .72945 .51414 L F
.134 .505 .909 r
.73047 .51559 m .73012 .51524 L .7294 .51413 L F
.791 .62 .669 r
.72953 .51415 m .7296 .51481 L .72961 .51416 L F
.045 .462 .881 r
.72958 .51416 m .72945 .51414 L .72958 .51418 L F
.791 .62 .669 r
.72961 .51416 m .7296 .51481 L .72974 .51427 L F
.72952 .51409 m .72953 .51415 L .72961 .51416 L F
.72877 .51349 m .72926 .51427 L .72952 .51409 L F
.994 .875 .576 r
.72947 .51415 m .72825 .51519 L .72997 .51428 L F
.72923 .51429 m .72825 .51519 L .72947 .51415 L F
.666 .585 .754 r
.72486 .51374 m .7287 .51461 L .72737 .51126 L F
.7287 .51461 m .72901 .51442 L .72737 .51126 L F
1 .807 .499 r
.7296 .51481 m .73046 .51613 L .73045 .51556 L F
.134 .505 .909 r
.72994 .51472 m .73042 .51552 L .7298 .51467 L F
1 .807 .499 r
.7296 .51481 m .73045 .51556 L .72976 .51441 L F
.045 .462 .881 r
.73252 .51467 m .72971 .51418 L .72997 .51428 L F
.72971 .51418 m .72958 .51418 L .72997 .51428 L F
1 .807 .499 r
.72976 .51418 m .7304 .51283 L .73042 .51162 L F
.72978 .51418 m .7304 .51283 L .72976 .51418 L F
.7296 .51481 m .72976 .51441 L .72974 .51427 L F
.283 .507 .895 r
.73056 .51566 m .73061 .51574 L .73055 .51565 L F
.924 .947 .792 r
.72993 .51774 m .73131 .5168 L .73066 .51612 L F
.73131 .5168 m .73085 .5161 L .73066 .51612 L F
.787 .59 .635 r
.73077 .51596 m .73327 .51817 L .73009 .5169 L F
.924 .947 .792 r
.72993 .51774 m .73066 .51612 L .73046 .51613 L F
.787 .59 .635 r
.73009 .5169 m .73027 .51698 L .72993 .51774 L F
.73027 .51698 m .73327 .51817 L .72993 .51774 L F
.914 .802 .722 r
.73046 .51613 m .73066 .51612 L .73099 .51565 L F
.53 .459 .721 r
.30499 .61581 m .30583 .61764 L .30378 .61813 L F
.473 .276 .532 r
.30583 .61764 m .30361 .62046 L .30378 .61813 L F
.501 .405 .678 r
.26589 .60762 m .26774 .60728 L .26746 .60358 L F
.565 .461 .695 r
.26617 .60964 m .26774 .60728 L .26589 .60762 L F
.205 0 0 r
.59288 .56379 m .5919 .56569 L .5896 .56634 L F
.488 .282 .525 r
.59557 .56104 m .59569 .56324 L .59288 .56379 L F
.337 0 .13 r
.59288 .56379 m .59434 .56527 L .5919 .56569 L F
.59288 .56379 m .59569 .56324 L .59434 .56527 L F
.581 .355 .538 r
.35913 .61472 m .36146 .61457 L .3616 .6126 L F
.345 .161 .482 r
.3616 .6126 m .36302 .61365 L .36392 .61226 L F
.3616 .6126 m .36146 .61457 L .36302 .61365 L F
.574 .409 .62 r
.3616 .6126 m .36392 .61226 L .36377 .60965 L F
.341 0 0 r
.51448 .69612 m .51685 .69585 L .51813 .69429 L F
.392 0 .07 r
.51685 .69585 m .52025 .69393 L .51813 .69429 L F
.263 0 0 r
.45812 .70375 m .45673 .70526 L .45443 .70564 L F
.301 0 0 r
.46038 .70367 m .45673 .70526 L .45812 .70375 L F
.468 .359 .647 r
.58615 .62673 m .58828 .62862 L .58616 .62919 L F
.58615 .62673 m .58814 .62613 L .58828 .62862 L F
.714 .196 0 r
.74754 .52473 m .74745 .52573 L .74672 .52354 L F
.74754 .52473 m .75036 .52699 L .74745 .52573 L F
.945 .74 .595 r
.48622 .69732 m .48534 .70094 L .48755 .69864 L F
.694 .434 .525 r
.53205 .69194 m .53214 .69447 L .53208 .69422 L F
.589 .022 0 r
.52885 .69226 m .53214 .69447 L .53205 .69194 L F
.232 .371 .798 r
.55173 .64324 m .5532 .64217 L .54984 .64063 L F
.55173 .64324 m .55281 .64341 L .5532 .64217 L F
.618 .66 .868 r
.30555 .6203 m .30493 .6237 L .30361 .62046 L F
.30555 .6203 m .30743 .62319 L .30493 .6237 L F
.634 .243 .286 r
.57154 .6463 m .56867 .64825 L .5702 .64729 L F
.861 .995 .766 r
.56867 .64825 m .56831 .64979 L .5702 .64729 L F
.634 .243 .286 r
.57154 .6463 m .57106 .64858 L .56867 .64825 L F
.537 .247 .421 r
.59967 .54365 m .60235 .54155 L .59993 .54189 L F
.611 .253 .339 r
.59489 .60607 m .59579 .60392 L .5926 .60446 L F
.617 .346 .485 r
.59489 .60607 m .59818 .60338 L .59579 .60392 L F
.981 .913 .634 r
.48005 .69527 m .47864 .69653 L .47952 .69439 L F
.427 .124 .346 r
.45169 .64681 m .4511 .64855 L .45384 .64642 L F
.243 .079 .449 r
.30993 .60925 m .30984 .61111 L .30862 .61096 L F
.57 .318 .494 r
.30984 .61111 m .30678 .61376 L .30862 .61096 L F
.505 .377 .639 r
.2552 .66271 m .25706 .66355 L .25655 .66053 L F
.572 .287 .445 r
.2552 .66271 m .2562 .66537 L .25706 .66355 L F
.667 .756 .917 r
.65419 .50876 m .65504 .51039 L .65669 .50941 L F
.618 .558 .765 r
.62595 .50106 m .62719 .50471 L .62977 .5039 L F
.739 .614 .719 r
.4975 .64362 m .49546 .64654 L .49547 .64385 L F
.6 .817 .983 r
.48476 .80714 m .48949 .80706 L .48841 .80469 L F
.61 .596 .812 r
.48949 .80706 m .49103 .80416 L .48841 .80469 L F
.48949 .80706 m .49205 .80663 L .49103 .80416 L F
.607 .595 .813 r
.66077 .49856 m .6623 .50248 L .6643 .5017 L F
.058 .534 .892 r
.66192 .50296 m .6643 .5017 L .6623 .50248 L F
.596 .628 .854 r
.53106 .77999 m .53407 .77824 L .53185 .77824 L F
.53106 .77999 m .53236 .77986 L .53211 .77938 L F
.441 .028 .157 r
.53106 .77999 m .53349 .77975 L .53196 .78179 L F
.53106 .77999 m .53196 .78179 L .53187 .7789 L F
.53158 .77884 m .53187 .7789 L .53185 .77824 L F
.53106 .77999 m .53187 .7789 L .53158 .77884 L F
.596 .628 .854 r
.53211 .77938 m .53349 .77975 L .53407 .77824 L F
.871 .887 .844 r
.53286 .7791 m .53455 .77852 L .53407 .77824 L F
.961 .635 .251 r
.53082 .78056 m .53196 .78179 L .53187 .7789 L F
.596 .628 .854 r
.53236 .77986 m .53349 .77975 L .53211 .77938 L F
.871 .887 .844 r
.53082 .78056 m .53332 .77919 L .53286 .7791 L F
.53332 .77919 m .53455 .77852 L .53286 .7791 L F
.961 .635 .251 r
.5317 .77857 m .53187 .7789 L .53185 .77824 L F
.53082 .78056 m .53187 .7789 L .5317 .77857 L F
.905 .495 .137 r
.54885 .63843 m .54859 .63907 L .54818 .63736 L F
0 0 .179 r
.54818 .63736 m .54859 .63907 L .54816 .63723 L F
.54818 .63736 m .54816 .63723 L .54791 .63619 L F
.896 .583 .086 r
.54822 .63759 m .54818 .63736 L .54647 .63603 L F
.54878 .63808 m .54818 .63736 L .54822 .63759 L F
.54878 .63808 m .54885 .63843 L .54818 .63736 L F
.324 .777 .953 r
.35543 .58795 m .35321 .58828 L .3516 .58769 L F
.78 .807 .874 r
.73302 .51381 m .73325 .51139 L .7304 .51283 L F
.808 .538 .53 r
.5083 .8111 m .50496 .80817 L .50478 .81058 L F
.529 .452 .714 r
.41146 .66625 m .41305 .66324 L .41104 .66359 L F
.635 .617 .815 r
.53214 .69447 m .53323 .69713 L .5311 .69731 L F
.516 .168 .316 r
.53323 .69713 m .52989 .69966 L .5311 .69731 L F
0 0 0 r
.33677 .64477 m .33881 .64368 L .3409 .64308 L F
.643 .934 .968 r
.49387 .79331 m .49542 .79349 L .49657 .79297 L F
.668 .575 .742 r
.43173 .69117 m .42892 .69172 L .43091 .68896 L F
.609 .58 .796 r
.43248 .69443 m .42892 .69172 L .43173 .69117 L F
.247 0 0 r
.33246 .6005 m .33103 .60129 L .32904 .60147 L F
.147 0 0 r
.33455 .60038 m .33103 .60129 L .33246 .6005 L F
.859 .907 .866 r
.50231 .70298 m .50387 .69969 L .50095 .70099 L F
.841 .778 .791 r
.27177 .66136 m .26992 .66469 L .26913 .66306 L F
.604 .848 .99 r
.26998 .64571 m .27155 .64657 L .2738 .64603 L F
0 .308 .764 r
.4646 .6588 m .463 .65823 L .46417 .65834 L F
.998 .792 .447 r
.46381 .65711 m .46417 .65834 L .46417 .65455 L F
0 0 0 r
.46652 .65617 m .4646 .6588 L .46381 .65711 L F
.484 .882 .722 r
.46507 .65826 m .46475 .65846 L .4646 .6588 L F
0 .308 .764 r
.4646 .6588 m .46445 .65913 L .463 .65823 L F
.518 .457 .727 r
.46583 .65999 m .46367 .66076 L .463 .65823 L F
.484 .882 .722 r
.46475 .65846 m .46325 .65941 L .4646 .6588 L F
0 .308 .764 r
.4646 .6588 m .46583 .65999 L .46445 .65913 L F
0 0 .075 r
.57175 .56617 m .57028 .56742 L .56957 .56908 L F
.136 .677 .834 r
.66355 .52226 m .66153 .52206 L .6598 .52211 L F
.498 .784 .996 r
.66488 .5207 m .66355 .52226 L .66213 .51933 L F
.66488 .5207 m .66589 .52175 L .66355 .52226 L F
.586 .912 .976 r
.66488 .5207 m .66355 .52226 L .66589 .52175 L F
.66488 .5207 m .66153 .52206 L .66355 .52226 L F
.596 .347 .51 r
.57987 .61488 m .58223 .61466 L .58328 .6114 L F
.592 .426 .626 r
.58328 .6114 m .58569 .61225 L .58602 .61038 L F
.595 .422 .617 r
.58548 .61457 m .58328 .6114 L .58223 .61466 L F
.58548 .61457 m .58569 .61225 L .58328 .6114 L F
.296 0 0 r
.45452 .68834 m .45676 .68907 L .45846 .68937 L F
.692 .952 .954 r
.45846 .68937 m .45885 .68785 L .45842 .68752 L F
.961 .878 .482 r
.45842 .68752 m .45819 .68891 L .45846 .68937 L F
.894 .784 .733 r
.45676 .68907 m .45819 .68891 L .45842 .68752 L F
.692 .952 .954 r
.45819 .68891 m .45676 .68907 L .4579 .6884 L F
.45846 .68937 m .45676 .68907 L .45819 .68891 L F
.894 .784 .733 r
.45676 .68907 m .45777 .69144 L .45819 .68891 L F
.961 .878 .482 r
.45819 .68891 m .45777 .69144 L .45846 .68937 L F
.692 .952 .954 r
.45846 .68937 m .4579 .6884 L .45885 .68785 L F
.658 .593 .77 r
.27188 .62138 m .27563 .62421 L .2744 .62096 L F
.661 .599 .774 r
.2744 .62096 m .27563 .62421 L .27797 .62367 L F
.962 .881 .707 r
.62556 .57141 m .62756 .5705 L .62638 .56936 L F
.62556 .57141 m .62657 .57227 L .62756 .5705 L F
.106 0 .18 r
.54296 .59479 m .54494 .59432 L .54527 .59182 L F
.087 0 0 r
.54527 .59182 m .5482 .58976 L .54558 .59178 L F
.54527 .59182 m .54715 .59168 L .5482 .58976 L F
.119 0 .183 r
.54527 .59182 m .54494 .59432 L .54715 .59168 L F
.702 .179 0 r
.73478 .52605 m .73584 .52703 L .73455 .52631 L F
.91 .511 .221 r
.73584 .52703 m .73498 .52828 L .73455 .52631 L F
.756 .729 .827 r
.57358 .58678 m .57132 .58939 L .57476 .58951 L F
.847 .766 .773 r
.57358 .58678 m .57476 .58951 L .57598 .5862 L F
0 0 0 r
.47832 .80091 m .47926 .79985 L .47652 .80259 L F
.48134 .79858 m .47926 .79985 L .47832 .80091 L F
.507 .277 .499 r
.60933 .53059 m .61147 .532 L .61156 .52984 L F
.60933 .53059 m .60911 .53258 L .61147 .532 L F
.451 .078 .239 r
.67905 .47496 m .68242 .472 L .67924 .4742 L F
.67905 .47496 m .68135 .4747 L .68242 .472 L F
.433 .089 .279 r
.68135 .4747 m .68429 .47085 L .68242 .472 L F
0 0 0 r
.31528 .64818 m .31428 .64872 L .31311 .64896 L F
.139 .679 .835 r
.31311 .64896 m .31428 .64872 L .31177 .64877 L F
.675 .493 .632 r
.49046 .78726 m .49385 .78813 L .49428 .78597 L F
.446 .393 .705 r
.49046 .78726 m .49165 .79101 L .495 .79088 L F
.926 .85 .748 r
.73241 .49364 m .73009 .49506 L .73126 .49288 L F
.73241 .49364 m .7313 .49618 L .73009 .49506 L F
0 0 .3 r
.46453 .66092 m .46367 .66076 L .46583 .65999 L F
.702 .708 .853 r
.46274 .66159 m .4643 .66078 L .4646 .6588 L F
.4643 .66078 m .46583 .65999 L .465 .65919 L F
.4643 .66078 m .465 .65919 L .4646 .6588 L F
0 0 .3 r
.46453 .66092 m .46348 .66332 L .46354 .66249 L F
.46426 .66087 m .46354 .66249 L .46367 .66076 L F
.46453 .66092 m .46354 .66249 L .46426 .66087 L F
.882 .824 .785 r
.72752 .50465 m .72795 .50764 L .72682 .50779 L F
.885 .81 .769 r
.72682 .50779 m .72795 .50764 L .72623 .51058 L F
.842 .714 .722 r
.66008 .51878 m .65723 .51806 L .65793 .51626 L F
.606 .846 .477 r
.66008 .51878 m .65856 .5206 L .65723 .51806 L F
.66008 .51878 m .65766 .52192 L .65856 .5206 L F
.361 .618 .949 r
.65856 .5206 m .66027 .51944 L .65943 .51935 L F
.628 .244 0 r
.65723 .51806 m .65856 .5206 L .65782 .51919 L F
.361 .618 .949 r
.65856 .5206 m .65943 .51935 L .65782 .51919 L F
.606 .846 .477 r
.65766 .52192 m .65746 .52218 L .65856 .5206 L F
0 .321 .807 r
.65793 .51626 m .66044 .51827 L .66008 .51878 L F
.185 .538 .926 r
.66129 .51809 m .66008 .51878 L .66044 .51827 L F
.66129 .51809 m .66213 .51933 L .66008 .51878 L F
.543 .842 .999 r
.35227 .59917 m .35569 .59909 L .35384 .59923 L F
.31 .802 .828 r
.35384 .59923 m .35569 .59909 L .35785 .5985 L F
.773 .931 .936 r
.74459 .53007 m .74681 .52691 L .74783 .52792 L F
.74459 .53007 m .74366 .52906 L .74681 .52691 L F
.744 .755 .861 r
.748 .52883 m .74459 .53007 L .74783 .52792 L F
.079 0 0 r
.5648 .5724 m .56687 .57183 L .56779 .5702 L F
.101 0 .011 r
.56687 .57183 m .56957 .56908 L .56779 .5702 L F
0 0 .178 r
.60538 .59275 m .60654 .59144 L .60695 .58918 L F
0 0 .114 r
.60538 .59275 m .60581 .59359 L .60654 .59144 L F
.60538 .59275 m .60516 .59509 L .60581 .59359 L F
.908 .824 .752 r
.64715 .48947 m .6501 .48788 L .64645 .48803 L F
.64715 .48947 m .64854 .49056 L .6501 .48788 L F
.441 .417 .736 r
.40591 .68059 m .40817 .68314 L .40807 .6799 L F
.831 .804 .825 r
.71187 .46643 m .71319 .46816 L .71596 .46518 L F
.477 .194 .404 r
.38281 .61556 m .38231 .61752 L .38011 .61793 L F
.42 .142 .383 r
.38441 .61695 m .38281 .61556 L .38499 .61513 L F
.38441 .61695 m .38231 .61752 L .38281 .61556 L F
.695 .619 .767 r
.73366 .47734 m .7313 .47698 L .7325 .47569 L F
.708 .751 .885 r
.73589 .47624 m .73366 .47734 L .7325 .47569 L F
0 0 .554 r
.51031 .62754 m .51114 .62901 L .50926 .62669 L F
.902 .64 .532 r
.57294 .66099 m .57061 .66051 L .57107 .65738 L F
.706 .42 .488 r
.57294 .66099 m .57049 .66067 L .57061 .66051 L F
.57049 .66067 m .56931 .66052 L .57061 .66051 L F
.668 .409 .519 r
.57107 .65738 m .57061 .66051 L .56889 .66046 L F
0 0 .554 r
.57027 .65838 m .57088 .6601 L .57061 .66051 L F
.706 .42 .488 r
.57294 .66099 m .57028 .66304 L .56889 .66046 L F
.792 .582 .616 r
.57156 .66202 m .57338 .66048 L .57061 .66051 L F
.57338 .66048 m .57496 .65915 L .57061 .66051 L F
.644 .387 .514 r
.57107 .65738 m .57061 .66051 L .57496 .65915 L F
0 0 .554 r
.57088 .6601 m .57156 .66202 L .57061 .66051 L F
.706 .42 .488 r
.56931 .66052 m .56889 .66046 L .57061 .66051 L F
.57294 .66099 m .57232 .66317 L .57028 .66304 L F
.694 .725 .873 r
.30283 .64638 m .30378 .64802 L .30606 .64627 L F
.47 .802 .999 r
.32631 .63036 m .32493 .63073 L .32292 .62965 L F
.601 .445 .642 r
.54138 .76013 m .54147 .76299 L .53893 .76271 L F
0 0 .023 r
.54138 .76013 m .53893 .76271 L .54131 .76076 L F
.578 .552 .789 r
.53893 .76271 m .54147 .76299 L .54131 .76076 L F
.985 .902 .599 r
.72443 .48994 m .72608 .48715 L .72563 .48664 L F
.72443 .48994 m .72507 .49072 L .72608 .48715 L F
.833 .928 .894 r
.53737 .65263 m .53565 .65461 L .53861 .65396 L F
.965 .826 .656 r
.53565 .65461 m .53682 .6558 L .53861 .65396 L F
.653 .706 .886 r
.53964 .65103 m .53874 .65343 L .53737 .65263 L F
.53964 .65103 m .54027 .65295 L .53874 .65343 L F
.652 .137 .004 r
.54027 .65295 m .53737 .65263 L .53861 .65396 L F
.627 .618 .821 r
.30606 .64627 m .30757 .64944 L .30977 .64844 L F
.795 .735 .797 r
.74326 .49835 m .74081 .50118 L .74435 .50165 L F
.683 .674 .836 r
.74326 .49835 m .74435 .50165 L .74627 .49918 L F
.987 .883 .631 r
.62996 .54681 m .62863 .55032 L .62969 .55029 L F
.936 .782 .664 r
.62863 .55032 m .6302 .55042 L .62969 .55029 L F
.277 .655 .968 r
.71218 .46096 m .7143 .46226 L .71307 .46202 L F
.924 .818 .723 r
.61106 .56932 m .60975 .56878 L .61057 .56656 L F
.998 .845 .547 r
.60999 .57296 m .60975 .56878 L .61106 .56932 L F
0 0 0 r
.55802 .58055 m .55762 .58112 L .55922 .57969 L F
.186 .292 .74 r
.748 .52883 m .75036 .52699 L .74783 .52792 L F
.668 .505 .654 r
.62047 .5161 m .62301 .51594 L .62338 .51231 L F
.245 0 .213 r
.62338 .51231 m .62494 .51229 L .62553 .51075 L F
.151 .059 .488 r
.62338 .51231 m .62478 .51443 L .62494 .51229 L F
.62338 .51231 m .62301 .51594 L .62478 .51443 L F
.471 .201 .422 r
.57941 .55848 m .58185 .55801 L .58189 .55543 L F
.354 .131 .431 r
.58385 .55719 m .58189 .55543 L .58185 .55801 L F
.58385 .55719 m .58419 .55499 L .58189 .55543 L F
.402 .765 .994 r
.42924 .7117 m .43012 .71216 L .42862 .71125 L F
.694 .879 .967 r
.42862 .71125 m .43012 .71216 L .43224 .71085 L F
.547 .378 .604 r
.52228 .63663 m .51997 .63517 L .52204 .63463 L F
.52228 .63663 m .52 .6374 L .51997 .63517 L F
.57 .394 .603 r
.49428 .78597 m .49385 .78813 L .49625 .78517 L F
.597 .885 .991 r
.36561 .60856 m .36377 .60965 L .36466 .60826 L F
.082 .038 .503 r
.36522 .61068 m .36377 .60965 L .36466 .60826 L F
.36522 .61068 m .36392 .61226 L .36377 .60965 L F
.529 .361 .597 r
.4069 .67184 m .40908 .67137 L .40904 .669 L F
.538 .389 .626 r
.40704 .6744 m .40908 .67137 L .4069 .67184 L F
.948 .754 .608 r
.55626 .75068 m .5574 .75396 L .5577 .75148 L F
.626 .922 .976 r
.69232 .49028 m .69097 .48985 L .69321 .48883 L F
.409 .655 .959 r
.69321 .48883 m .69433 .49026 L .69232 .49028 L F
.538 .5 .761 r
.43266 .68577 m .43045 .6864 L .42979 .68323 L F
.454 .331 .623 r
.43266 .68577 m .43091 .68896 L .43045 .6864 L F
.462 .687 .964 r
.65746 .52218 m .6598 .52211 L .65856 .5206 L F
.361 .827 .904 r
.64223 .50872 m .64599 .5082 L .64482 .5071 L F
0 .505 .839 r
.32475 .58376 m .32741 .58455 L .32455 .58479 L F
0 0 0 r
.53697 .78513 m .53787 .78472 L .53912 .78438 L F
.53697 .78513 m .53787 .78472 L .53912 .78438 L F
.708 .646 .785 r
.45742 .66299 m .4584 .66664 L .46134 .66459 L F
.626 .778 .954 r
.27096 .62055 m .27188 .62138 L .2744 .62096 L F
.831 .804 .825 r
.71187 .46643 m .71596 .46518 L .71451 .46388 L F
.342 .806 .93 r
.5113 .77363 m .5089 .77403 L .50742 .77382 L F
.642 .128 0 r
.50916 .77549 m .50742 .77382 L .5089 .77403 L F
.776 .7 .78 r
.5113 .77363 m .50916 .77549 L .5089 .77403 L F
.561 .525 .772 r
.43398 .69069 m .43248 .69443 L .43173 .69117 L F
.43398 .69069 m .43472 .69409 L .43248 .69443 L F
.905 .495 .137 r
.54885 .63843 m .54984 .64063 L .54859 .63907 L F
.602 .535 .752 r
.50208 .65064 m .50553 .65229 L .50557 .65029 L F
.318 .691 .979 r
.31832 .62694 m .31761 .62789 L .31603 .62654 L F
.31832 .62694 m .32015 .62824 L .31761 .62789 L F
.374 .132 .413 r
.26924 .59807 m .27171 .59511 L .26945 .5956 L F
.649 .679 .865 r
.53029 .64305 m .52696 .64141 L .52863 .64077 L F
.589 .821 .988 r
.53175 .64114 m .53029 .64305 L .52863 .64077 L F
.53175 .64114 m .53331 .64234 L .53029 .64305 L F
.688 .511 .642 r
.43265 .68296 m .42979 .68323 L .43248 .68046 L F
.356 .251 .596 r
.43386 .67745 m .43413 .67993 L .43248 .68046 L F
.702 .664 .81 r
.43413 .67993 m .43265 .68296 L .43248 .68046 L F
.513 .822 1 r
.37381 .75375 m .37176 .75428 L .37019 .75342 L F
.521 .024 0 r
.37176 .75428 m .3722 .75477 L .37019 .75342 L F
.39 .297 .629 r
.372 .75534 m .37379 .75641 L .37176 .75428 L F
.521 .024 0 r
.37176 .75428 m .37379 .75641 L .3722 .75477 L F
.487 .309 .564 r
.37381 .75375 m .37379 .75641 L .37176 .75428 L F
.458 .183 .408 r
.35608 .61798 m .35842 .61763 L .35913 .61472 L F
.383 .116 .38 r
.35913 .61472 m .36043 .61686 L .36146 .61457 L F
.35913 .61472 m .35842 .61763 L .36043 .61686 L F
.065 .444 .878 r
.50321 .62196 m .501 .62168 L .50057 .62121 L F
.50321 .62196 m .50436 .62334 L .501 .62168 L F
.702 .179 0 r
.73478 .52605 m .73455 .52631 L .73423 .52418 L F
.583 .553 .787 r
.26637 .61205 m .2676 .61539 L .26976 .61488 L F
.329 .467 .847 r
.2676 .61539 m .27077 .61824 L .26976 .61488 L F
.596 .397 .582 r
.58602 .61038 m .58792 .60955 L .58805 .60698 L F
.535 .315 .528 r
.58792 .60955 m .59012 .60661 L .58805 .60698 L F
.222 0 .292 r
.57377 .56501 m .57242 .56445 L .57175 .56617 L F
.57377 .56501 m .57423 .56342 L .57242 .56445 L F
.353 .155 .467 r
.35141 .62103 m .35307 .62248 L .35354 .62055 L F
.35141 .62103 m .35119 .62336 L .35307 .62248 L F
.64 .674 .866 r
.28412 .63788 m .28795 .63916 L .28609 .63899 L F
.617 .171 .169 r
.28977 .63807 m .28609 .63899 L .28795 .63916 L F
.542 .29 .482 r
.60096 .61575 m .60337 .61716 L .60081 .61745 L F
.60096 .61575 m .60358 .6153 L .60337 .61716 L F
.527 .452 .715 r
.58645 .63311 m .58482 .63514 L .58407 .63217 L F
.58645 .63311 m .58696 .63471 L .58482 .63514 L F
.557 .471 .714 r
.58696 .63471 m .58521 .63764 L .58482 .63514 L F
.521 .316 .543 r
.61145 .52748 m .6138 .52701 L .61394 .52469 L F
.496 .311 .559 r
.61145 .52748 m .61374 .52916 L .6138 .52701 L F
.61145 .52748 m .61156 .52984 L .61374 .52916 L F
.921 .777 .685 r
.7313 .49618 m .7286 .49812 L .73009 .49506 L F
.7313 .49618 m .73012 .49905 L .7286 .49812 L F
.545 .769 .981 r
.41721 .70622 m .4193 .70588 L .41597 .70513 L F
.238 0 .268 r
.56233 .575 m .56453 .57468 L .5648 .5724 L F
.226 0 .223 r
.56196 .57725 m .56453 .57468 L .56233 .575 L F
.767 .629 .708 r
.56002 .76567 m .56369 .76609 L .56205 .76248 L F
.501 .411 .686 r
.48402 .66078 m .48465 .66359 L .4867 .66296 L F
.48402 .66078 m .48465 .66359 L .4867 .66296 L F
.679 .818 .95 r
.4731 .66588 m .47139 .66727 L .46925 .66595 L F
.785 .526 .546 r
.48169 .81363 m .47799 .81057 L .47925 .81427 L F
.77 .735 .821 r
.48422 .78198 m .48232 .78207 L .48328 .78029 L F
.577 .491 .72 r
.48232 .78207 m .48313 .78289 L .48316 .78242 L F
.667 .266 .276 r
.48422 .78198 m .48375 .78268 L .48317 .78243 L F
.553 .673 .917 r
.48342 .78316 m .48432 .78106 L .48326 .78269 L F
.48342 .78316 m .48326 .78269 L .48313 .78289 L F
.667 .266 .276 r
.48317 .78242 m .48317 .78243 L .48316 .78242 L F
.48422 .78198 m .48317 .78243 L .48317 .78242 L F
.483 .78203 m .48316 .78242 L .48232 .78207 L F
.48422 .78198 m .48316 .78242 L .483 .78203 L F
.564 .57 .817 r
.4857 .77978 m .48422 .78198 L .48328 .78029 L F
0 0 .432 r
.48328 .78029 m .48316 .78242 L .48432 .78106 L F
.48316 .78242 m .48313 .78289 L .48326 .78269 L F
.48316 .78242 m .48326 .78269 L .48432 .78106 L F
.577 .491 .72 r
.48232 .78207 m .48316 .78242 L .48328 .78029 L F
.667 .266 .276 r
.48375 .78268 m .48342 .78316 L .48232 .78207 L F
.564 .57 .817 r
.4857 .77978 m .48675 .78237 L .48422 .78198 L F
.558 .137 .198 r
.48675 .78237 m .48342 .78316 L .48422 .78198 L F
.728 .664 .786 r
.58607 .64562 m .589 .64616 L .58728 .64649 L F
.421 .362 .686 r
.589 .64616 m .58963 .64847 L .58728 .64649 L F
.598 .345 .504 r
.58728 .64649 m .58963 .64847 L .58711 .64859 L F
.577 .448 .668 r
.58616 .62919 m .58645 .63311 L .58407 .63217 L F
.179 0 0 r
.51537 .65077 m .51049 .65372 L .51097 .65212 L F
.51537 .65077 m .51178 .65373 L .51049 .65372 L F
0 .203 .726 r
.51447 .64927 m .51642 .65133 L .51537 .65077 L F
.364 0 .018 r
.51625 .65289 m .51537 .65077 L .51642 .65133 L F
.51625 .65289 m .51178 .65373 L .51537 .65077 L F
.784 .8 .865 r
.48308 .80593 m .48476 .80714 L .48479 .80449 L F
.766 .797 .878 r
.48476 .80714 m .48841 .80469 L .48479 .80449 L F
.434 .717 .984 r
.33324 .58496 m .33236 .58617 L .33092 .58532 L F
.33324 .58496 m .33441 .58619 L .33236 .58617 L F
.515 .477 .753 r
.47652 .80259 m .47941 .80456 L .47832 .80091 L F
.001 0 0 r
.56593 .61977 m .56804 .61891 L .56899 .61771 L F
0 0 0 r
.56899 .61771 m .57056 .61692 L .57109 .61583 L F
.56899 .61771 m .56804 .61891 L .57056 .61692 L F
.362 .011 .229 r
.68429 .47085 m .68692 .4699 L .68463 .47063 L F
.313 .068 .373 r
.43401 .67485 m .43613 .67199 L .4362 .67399 L F
.48 .265 .51 r
.43802 .67372 m .43613 .67199 L .43859 .67148 L F
.43802 .67372 m .4362 .67399 L .43613 .67199 L F
0 0 0 r
.54296 .59479 m .54278 .59542 L .54494 .59432 L F
.331 .315 .691 r
.40699 .68599 m .40745 .68916 L .40909 .68778 L F
.418 .369 .697 r
.40745 .68916 m .40981 .69111 L .40909 .68778 L F
.40745 .68916 m .40818 .69181 L .40981 .69111 L F
.528 .322 .544 r
.61394 .52469 m .61625 .52646 L .61601 .52394 L F
.61394 .52469 m .6138 .52701 L .61625 .52646 L F
.749 .94 .947 r
.7407 .47464 m .73788 .47533 L .74061 .47276 L F
.11 .4 .853 r
.74061 .47276 m .7438 .47574 L .7407 .47464 L F
.278 0 0 r
.44742 .69684 m .44959 .6971 L .451 .69692 L F
.181 0 0 r
.44959 .6971 m .45343 .69769 L .451 .69692 L F
.383 0 0 r
.46386 .70286 m .46246 .70418 L .46038 .70367 L F
.341 0 0 r
.46603 .7032 m .46246 .70418 L .46386 .70286 L F
.929 .545 .207 r
.65962 .5048 m .65877 .50545 L .66059 .50677 L F
.684 .153 0 r
.65962 .5048 m .66202 .50667 L .65877 .50545 L F
.958 .735 .284 r
.73191 .48775 m .73132 .48882 L .73142 .48661 L F
.73191 .48775 m .73189 .48988 L .73132 .48882 L F
.644 .387 .514 r
.57107 .65738 m .57496 .65915 L .57534 .65668 L F
.725 .605 .723 r
.56866 .65667 m .57107 .65738 L .5709 .65477 L F
.611 .253 .339 r
.59489 .60607 m .5926 .60446 L .59246 .60587 L F
.165 .624 .934 r
.36821 .58994 m .36474 .58879 L .3668 .58889 L F
.398 .745 .993 r
.36893 .58884 m .36821 .58994 L .3668 .58889 L F
.36893 .58884 m .37035 .58982 L .36821 .58994 L F
.439 .563 .883 r
.52464 .80452 m .52553 .80227 L .52406 .80201 L F
.52464 .80452 m .52687 .80493 L .52553 .80227 L F
.499 .416 .693 r
.52301 .6515 m .52073 .65234 L .51997 .64931 L F
.569 .611 .854 r
.42081 .70921 m .42242 .70783 L .4193 .70588 L F
.42081 .70921 m .42306 .7088 L .42242 .70783 L F
.68 .393 .479 r
.58042 .66882 m .57719 .67117 L .57708 .66909 L F
.58042 .66882 m .57954 .67163 L .57719 .67117 L F
.593 .305 .448 r
.58291 .67062 m .58042 .66882 L .58291 .66884 L F
.58291 .67062 m .57954 .67163 L .58042 .66882 L F
0 0 0 r
.48316 .62504 m .48219 .62682 L .48286 .62567 L F
.335 .813 .771 r
.48347 .62438 m .48316 .62504 L .48462 .62355 L F
.695 .91 .564 r
.48462 .62355 m .48316 .62504 L .48543 .62205 L F
0 0 0 r
.48316 .62504 m .48286 .62567 L .48401 .62372 L F
.335 .813 .771 r
.48146 .62583 m .48316 .62504 L .48347 .62438 L F
.48146 .62583 m .48123 .62577 L .48316 .62504 L F
.83 .828 .846 r
.67811 .51402 m .67948 .51556 L .67885 .51274 L F
.856 .817 .81 r
.67601 .51691 m .67948 .51556 L .67811 .51402 L F
.67601 .51691 m .67722 .51852 L .67948 .51556 L F
.837 .832 .842 r
.67885 .51274 m .67948 .51556 L .68174 .51295 L F
.665 .781 .935 r
.55721 .60614 m .55406 .60569 L .55669 .60308 L F
.669 .465 .6 r
.55548 .60911 m .55813 .60934 L .55721 .60614 L F
0 0 .052 r
.55721 .60614 m .55658 .60857 L .55548 .60911 L F
.677 .741 .899 r
.55884 .60297 m .55721 .60614 L .55669 .60308 L F
.55884 .60297 m .5598 .60498 L .55721 .60614 L F
.944 .61 .365 r
.55813 .60934 m .55658 .60857 L .55721 .60614 L F
.834 .814 .831 r
.67601 .51691 m .67412 .51842 L .67722 .51852 L F
.505 .485 .768 r
.53886 .64536 m .53623 .64673 L .536 .64371 L F
.584 .395 .592 r
.53967 .64859 m .53623 .64673 L .53886 .64536 L F
.53967 .64859 m .53733 .64966 L .53623 .64673 L F
.525 .536 .809 r
.52334 .64095 m .52132 .64161 L .52008 .63887 L F
.196 .723 .841 r
.74239 .53358 m .74347 .53315 L .74158 .5344 L F
.74239 .53358 m .74506 .5333 L .74347 .53315 L F
.303 0 .176 r
.31289 .60696 m .31202 .60877 L .30993 .60925 L F
.356 0 .203 r
.31445 .60764 m .31289 .60696 L .31512 .60653 L F
.31445 .60764 m .31202 .60877 L .31289 .60696 L F
.09 0 0 r
.34302 .64249 m .34671 .64007 L .34505 .6419 L F
.199 0 0 r
.34671 .64007 m .34734 .64113 L .34505 .6419 L F
.34671 .64007 m .34882 .63956 L .34734 .64113 L F
.841 .778 .791 r
.27177 .66136 m .26913 .66306 L .27003 .66235 L F
.483 .333 .601 r
.2737 .66273 m .27186 .66364 L .27177 .66136 L F
.657 .189 .131 r
.27003 .66235 m .2737 .66273 L .27177 .66136 L F
.661 .412 .533 r
.59557 .56104 m .59773 .56368 L .59569 .56324 L F
.699 .413 .488 r
.59794 .56131 m .59773 .56368 L .59557 .56104 L F
.523 .286 .496 r
.46455 .66825 m .46674 .66566 L .46494 .66677 L F
.567 .579 .825 r
.46674 .66566 m .46494 .66677 L .46348 .66332 L F
.489 .055 .141 r
.5231 .69223 m .52501 .69324 L .52641 .69135 L F
.509 .017 .024 r
.52501 .69324 m .52885 .69226 L .52641 .69135 L F
.481 .122 .279 r
.44564 .65163 m .44799 .65144 L .44903 .64909 L F
.484 .161 .343 r
.44799 .65144 m .4511 .64855 L .44903 .64909 L F
.961 .635 .251 r
.53082 .78056 m .53185 .77824 L .53407 .77824 L F
.685 .508 .641 r
.59608 .6184 m .59616 .62067 L .5926 .62076 L F
.604 .455 .653 r
.59608 .6184 m .5987 .62045 L .59616 .62067 L F
.59608 .6184 m .59842 .61791 L .5987 .62045 L F
.649 .363 .472 r
.49677 .77146 m .49608 .77356 L .49322 .77182 L F
.433 .458 .786 r
.49322 .77182 m .49608 .77356 L .49501 .7704 L F
.611 .787 .965 r
.68861 .478 m .68948 .47936 L .6918 .47854 L F
.918 .635 .49 r
.73415 .52176 m .73253 .52301 L .73281 .5224 L F
.73415 .52176 m .73423 .52418 L .73253 .52301 L F
.425 .007 .139 r
.34744 .62555 m .35119 .62336 L .34907 .6239 L F
.792 .837 .886 r
.56712 .61189 m .56837 .61314 L .57065 .61178 L F
.826 .762 .792 r
.56655 .61073 m .56712 .61189 L .57065 .61178 L F
.747 .621 .72 r
.57109 .61583 m .57223 .6115 L .57065 .61178 L F
.593 .323 .476 r
.60245 .56011 m .59773 .56368 L .59794 .56131 L F
.709 .985 .871 r
.48462 .62355 m .48543 .62205 L .4871 .62168 L F
.93 .913 .779 r
.72623 .51058 m .723 .51358 L .72449 .50971 L F
.72623 .51058 m .7239 .51456 L .723 .51358 L F
.885 .81 .769 r
.72682 .50779 m .72623 .51058 L .72449 .50971 L F
.207 0 0 r
.29794 .58556 m .30018 .58528 L .30199 .5841 L F
.422 0 .03 r
.30018 .58528 m .30411 .58362 L .30199 .5841 L F
.643 .934 .968 r
.49387 .79331 m .49657 .79297 L .49698 .79251 L F
.14 .683 .816 r
.32117 .64816 m .31759 .64821 L .31969 .64828 L F
.472 .218 .448 r
.39239 .60891 m .38977 .61203 L .39016 .60933 L F
.665 .86 .974 r
.5379 .5981 m .53569 .59904 L .53425 .5981 L F
.822 .796 .827 r
.6322 .51806 m .63271 .52175 L .63361 .51934 L F
.6322 .51806 m .62977 .52079 L .63271 .52175 L F
.881 .705 .658 r
.62977 .52079 m .63116 .52409 L .63271 .52175 L F
.433 .089 .279 r
.68135 .4747 m .68365 .47423 L .68429 .47085 L F
.362 .011 .229 r
.68429 .47085 m .68636 .47201 L .68692 .4699 L F
.347 .014 .252 r
.68365 .47423 m .68636 .47201 L .68429 .47085 L F
.998 .845 .547 r
.60999 .57296 m .60904 .57321 L .60975 .56878 L F
.986 .779 .54 r
.60999 .57296 m .60837 .57416 L .60904 .57321 L F
.60999 .57296 m .60959 .57513 L .60837 .57416 L F
.854 .397 .071 r
.54418 .7592 m .54701 .76233 L .547 .75979 L F
.437 .596 .911 r
.40774 .6944 m .40944 .69695 L .41132 .69686 L F
.464 .168 .377 r
.54947 .78159 m .54844 .77949 L .54889 .78313 L F
.54947 .78159 m .55059 .77934 L .54844 .77949 L F
.965 .826 .656 r
.53682 .6558 m .53507 .65678 L .53565 .65461 L F
.53565 .65461 m .53507 .65678 L .53682 .6558 L F
.83 .763 .788 r
.69339 .50106 m .69148 .50169 L .69444 .50197 L F
.82 .742 .779 r
.69095 .50343 m .69444 .50197 L .69148 .50169 L F
.69095 .50343 m .69226 .5049 L .69444 .50197 L F
.733 .764 .878 r
.69339 .50106 m .69444 .50197 L .69701 .50111 L F
.743 .981 .746 r
.74737 .53209 m .74974 .52912 L .7477 .53239 L F
.32 .328 .712 r
.25821 .63726 m .25853 .63354 L .25827 .6353 L F
.55 .396 .624 r
.75445 .5012 m .75326 .49904 L .75499 .49818 L F
.75445 .5012 m .75349 .50198 L .75326 .49904 L F
.393 .108 .356 r
.61823 .52102 m .6206 .51796 L .61851 .51922 L F
.119 0 .234 r
.5648 .5724 m .56614 .5734 L .56687 .57183 L F
.5648 .5724 m .56453 .57468 L .56614 .5734 L F
.263 .064 .412 r
.58219 .57418 m .5808 .57575 L .58263 .57207 L F
.326 .023 .289 r
.58525 .57001 m .58462 .57213 L .58263 .57207 L F
.202 0 .273 r
.58462 .57213 m .58219 .57418 L .58263 .57207 L F
.058 .534 .892 r
.66192 .50296 m .6647 .50432 L .6643 .5017 L F
.6647 .50432 m .66536 .50464 L .6651 .50392 L F
.6647 .50432 m .6651 .50392 L .6643 .5017 L F
.66192 .50296 m .66422 .50378 L .66536 .50464 L F
.617 .466 .655 r
.66422 .50378 m .66202 .50667 L .66224 .50677 L F
.6633 .50572 m .66221 .50681 L .66264 .50711 L F
.66422 .50378 m .66221 .50681 L .6633 .50572 L F
.66422 .50378 m .66264 .50711 L .66536 .50464 L F
.66422 .50378 m .66487 .50663 L .66202 .50667 L F
.218 .41 .838 r
.66202 .50667 m .66441 .50621 L .66112 .50628 L F
.66202 .50667 m .66112 .50628 L .66103 .50628 L F
.617 .466 .655 r
.66224 .50677 m .66202 .50667 L .66221 .50681 L F
.8 .963 .913 r
.70127 .46326 m .70221 .46117 L .70313 .46189 L F
.70127 .46326 m .6983 .46402 L .70221 .46117 L F
.441 .086 .265 r
.63149 .49769 m .63338 .49747 L .63416 .49638 L F
.18 0 .086 r
.63416 .49638 m .63571 .49651 L .63641 .49565 L F
.63416 .49638 m .63338 .49747 L .63571 .49651 L F
.35 .114 .408 r
.26428 .65134 m .26544 .65146 L .26531 .64984 L F
.231 .626 .956 r
.50282 .81174 m .5011 .81066 L .5012 .80784 L F
.66 .972 .88 r
.50358 .81061 m .50282 .81174 L .5012 .80784 L F
.50358 .81061 m .50478 .81058 L .50282 .81174 L F
.50282 .81174 m .50358 .81061 L .5011 .81066 L F
.50282 .81174 m .50478 .81058 L .50358 .81061 L F
.56 .275 .439 r
.43762 .65467 m .44015 .65463 L .44088 .65182 L F
.514 .231 .423 r
.44088 .65182 m .44276 .65304 L .44327 .6517 L F
.44088 .65182 m .44015 .65463 L .44276 .65304 L F
0 .235 .671 r
.49065 .7995 m .4868 .79699 L .48925 .79864 L F
0 .183 .626 r
.48731 .79725 m .4868 .79699 L .48481 .79751 L F
.48731 .79725 m .48925 .79864 L .4868 .79699 L F
.463 .466 .776 r
.56867 .64825 m .56784 .65242 L .56831 .64979 L F
.545 .389 .62 r
.71944 .46801 m .72189 .46756 L .72077 .46524 L F
.331 .315 .691 r
.40699 .68599 m .40909 .68778 L .40884 .68551 L F
.094 0 0 r
.28162 .59115 m .28478 .58979 L .28252 .59002 L F
.605 .876 .992 r
.31488 .62506 m .31422 .62652 L .31257 .6258 L F
.273 .493 .887 r
.31603 .62654 m .31422 .62652 L .31488 .62506 L F
.28 .389 .796 r
.55846 .65133 m .55736 .64829 L .55827 .64926 L F
.286 .787 .823 r
.50591 .81004 m .50478 .81058 L .50358 .81061 L F
.50358 .81061 m .50478 .81058 L .50591 .81004 L F
.399 0 .086 r
.51405 .70357 m .51272 .70538 L .51032 .70568 L F
.286 0 .019 r
.51504 .70482 m .51405 .70357 L .51613 .7029 L F
.51504 .70482 m .51272 .70538 L .51405 .70357 L F
.529 .321 .541 r
.40904 .669 m .41129 .66872 L .41146 .66625 L F
.529 .452 .714 r
.41146 .66625 m .41359 .66572 L .41305 .66324 L F
.491 .288 .533 r
.41146 .66625 m .4134 .6682 L .41359 .66572 L F
.41146 .66625 m .41129 .66872 L .4134 .6682 L F
0 0 0 r
.50356 .64363 m .50245 .645 L .50132 .64593 L F
.128 0 .204 r
.50241 .64745 m .50132 .64593 L .50245 .645 L F
.50241 .64745 m .50056 .64847 L .50132 .64593 L F
.171 .288 .743 r
.52721 .78752 m .52912 .78979 L .52863 .78784 L F
.414 .723 .988 r
.33857 .58573 m .338 .587 L .33652 .58601 L F
.33857 .58573 m .34005 .58688 L .338 .587 L F
.681 .479 .606 r
.60351 .55858 m .60342 .561 L .60245 .56011 L F
.246 0 0 r
.49608 .70229 m .49598 .70244 L .49277 .70226 L F
.049 .152 .652 r
.49519 .6997 m .49608 .70229 L .49896 .70069 L F
.49519 .6997 m .49598 .70244 L .49608 .70229 L F
.738 .637 .747 r
.6643 .5017 m .66536 .50464 L .66776 .50188 L F
.175 0 .263 r
.49832 .77057 m .49608 .77356 L .49677 .77146 L F
0 0 0 r
.62521 .57862 m .62515 .58052 L .62514 .58036 L F
0 0 .132 r
.62624 .57704 m .62515 .58052 L .62521 .57862 L F
0 0 0 r
.34483 .59982 m .34249 .60003 L .34035 .60015 L F
.068 0 0 r
.34636 .59972 m .34249 .60003 L .34483 .59982 L F
.736 .511 .588 r
.46534 .67053 m .46455 .66825 L .46821 .66933 L F
.36 .075 .338 r
.46927 .6679 m .46821 .66933 L .47027 .66875 L F
.46671 .66969 m .46534 .67053 L .46611 .67021 L F
.736 .511 .588 r
.46534 .67053 m .46469 .67148 L .46455 .66825 L F
.666 .456 .592 r
.46455 .66825 m .46467 .67089 L .46671 .66969 L F
.91 .982 .746 r
.46696 .66947 m .46927 .6679 L .46605 .66846 L F
.36 .075 .338 r
.46927 .6679 m .46712 .66934 L .46821 .66933 L F
.46712 .66934 m .46611 .67021 L .46821 .66933 L F
.91 .982 .746 r
.46787 .67047 m .46927 .6679 L .46696 .66947 L F
.36 .075 .338 r
.46712 .66934 m .46577 .67025 L .46623 .66997 L F
.46696 .66947 m .46623 .66997 L .46671 .66969 L F
.666 .456 .592 r
.46671 .66969 m .46696 .66947 L .46605 .66846 L F
.36 .075 .338 r
.46712 .66934 m .46623 .66997 L .46696 .66947 L F
.46577 .67025 m .46534 .67053 L .46671 .66969 L F
.764 .712 .804 r
.46676 .67237 m .46469 .67148 L .46534 .67053 L F
.666 .456 .592 r
.46671 .66969 m .4656 .67067 L .46787 .67047 L F
.4656 .67067 m .46498 .67122 L .46595 .67097 L F
.4656 .67067 m .46595 .67097 L .46787 .67047 L F
.148 .395 .843 r
.4655 .67058 m .46676 .67237 L .46534 .67053 L F
.46682 .67171 m .46676 .67237 L .46626 .67165 L F
.46605 .67105 m .46626 .67165 L .4655 .67058 L F
.46682 .67171 m .46626 .67165 L .46605 .67105 L F
.36 .075 .338 r
.46577 .67025 m .4655 .67058 L .46534 .67053 L F
.666 .456 .592 r
.46467 .67089 m .46469 .67148 L .46671 .66969 L F
.738 .798 .9 r
.46588 .67058 m .46469 .67148 L .46232 .67077 L F
.36 .075 .338 r
.46712 .66934 m .46702 .67 L .4655 .67058 L F
.738 .798 .9 r
.46787 .67047 m .46605 .67105 L .46593 .67071 L F
.46787 .67047 m .46593 .67071 L .46616 .67056 L F
.666 .456 .592 r
.46498 .67122 m .46491 .67132 L .46506 .6712 L F
.46601 .67095 m .46605 .67105 L .46787 .67047 L F
.46498 .67122 m .46469 .67148 L .4648 .67144 L F
.738 .798 .9 r
.46605 .67105 m .46469 .67148 L .46588 .67058 L F
.148 .395 .843 r
.4665 .67088 m .46682 .67171 L .4655 .67058 L F
.738 .798 .9 r
.46787 .67047 m .46616 .67056 L .46699 .67133 L F
.148 .395 .843 r
.46688 .671 m .46688 .67107 L .4665 .67088 L F
.46688 .67107 m .46682 .67171 L .4665 .67088 L F
.738 .798 .9 r
.4665 .67088 m .46232 .67077 L .46699 .67133 L F
.36 .075 .338 r
.46616 .67056 m .4665 .67088 L .46593 .67071 L F
.46702 .67 m .46593 .67071 L .4655 .67058 L F
.738 .798 .9 r
.46616 .67056 m .46593 .67071 L .46588 .67058 L F
.46616 .67056 m .46588 .67058 L .4665 .67088 L F
.46588 .67058 m .46232 .67077 L .4665 .67088 L F
.877 .808 .777 r
.46447 .67157 m .46537 .67423 L .46138 .67284 L F
.46469 .67148 m .46474 .67167 L .46447 .67157 L F
.46474 .67167 m .46537 .67423 L .46447 .67157 L F
.552 .609 .864 r
.46469 .67148 m .46621 .67459 L .46537 .67423 L F
.764 .712 .804 r
.46676 .67237 m .46621 .67459 L .46469 .67148 L F
.877 .808 .777 r
.46469 .67148 m .46138 .67284 L .46232 .67077 L F
.916 .762 .676 r
.4641 .6734 m .46638 .67229 L .46388 .67135 L F
.249 0 0 r
.46388 .67135 m .46604 .67216 L .46282 .67095 L F
.738 .798 .9 r
.46699 .67133 m .46232 .67077 L .46604 .67216 L F
.916 .762 .676 r
.46638 .67229 m .46651 .67209 L .46604 .67216 L F
.807 .354 .161 r
.46685 .67206 m .46733 .67132 L .46619 .67212 L F
.46733 .67132 m .46787 .67047 L .46713 .67119 L F
.148 .395 .843 r
.46688 .67102 m .4688 .67271 L .46676 .67237 L F
.46698 .67108 m .4688 .67271 L .46688 .67102 L F
.807 .354 .161 r
.46685 .67206 m .4688 .67271 L .46698 .67108 L F
.148 .395 .843 r
.46688 .671 m .46698 .67108 L .46688 .67102 L F
.807 .354 .161 r
.46685 .67206 m .46698 .67108 L .46688 .671 L F
.46733 .67132 m .46713 .67119 L .46694 .67138 L F
.46691 .67161 m .46694 .67138 L .46619 .67212 L F
.46733 .67132 m .46694 .67138 L .46691 .67161 L F
.916 .762 .676 r
.46651 .67209 m .46657 .67199 L .46619 .67212 L F
.46651 .67209 m .46619 .67212 L .46604 .67216 L F
.807 .354 .161 r
.46685 .67206 m .46619 .67212 L .46611 .67219 L F
.738 .798 .9 r
.46619 .67212 m .46604 .67216 L .46611 .67219 L F
.46699 .67133 m .46604 .67216 L .46619 .67212 L F
.916 .762 .676 r
.46638 .67229 m .46685 .67206 L .46657 .67199 L F
.46604 .67216 m .46657 .67199 L .46388 .67135 L F
.249 0 0 r
.46388 .67135 m .46611 .67219 L .46604 .67216 L F
.46256 .67086 m .46282 .67095 L .46232 .67077 L F
.46388 .67135 m .46282 .67095 L .46256 .67086 L F
.36 .075 .338 r
.46702 .67 m .46688 .671 L .4665 .67088 L F
.46702 .67 m .4665 .67088 L .46616 .67056 L F
.46712 .66934 m .4655 .67058 L .46577 .67025 L F
.46927 .6679 m .46833 .66911 L .46712 .66934 L F
.666 .456 .592 r
.46671 .66969 m .46787 .67047 L .46696 .66947 L F
.36 .075 .338 r
.46833 .66911 m .46688 .671 L .46712 .66934 L F
.666 .456 .592 r
.46455 .66825 m .46639 .66948 L .46605 .66846 L F
.46639 .66948 m .46671 .66969 L .46657 .66944 L F
.46639 .66948 m .46657 .66944 L .46605 .66846 L F
.874 .592 .507 r
.73651 .52927 m .73892 .53022 L .73916 .5324 L F
.533 .359 .591 r
.61601 .52394 m .61823 .52102 L .61624 .52183 L F
.971 .685 .429 r
.71126 .49186 m .71285 .49338 L .71205 .49171 L F
.572 .393 .601 r
.58521 .63764 m .58639 .64087 L .58285 .64133 L F
.557 .471 .714 r
.58696 .63471 m .5878 .63721 L .58521 .63764 L F
.642 .488 .659 r
.5878 .63721 m .58639 .64087 L .58521 .63764 L F
.955 .851 .7 r
.57033 .63752 m .57097 .64053 L .57179 .63858 L F
.491 .216 .424 r
.62865 .50087 m .63105 .50061 L .63149 .49769 L F
.49 .215 .424 r
.63149 .49769 m .63349 .49988 L .63338 .49747 L F
.63149 .49769 m .63105 .50061 L .63349 .49988 L F
.243 0 .189 r
.6206 .51796 m .62301 .51594 L .62047 .5161 L F
.996 .78 .492 r
.65313 .49935 m .6521 .49833 L .6523 .49559 L F
.911 .875 .789 r
.65218 .50105 m .6521 .49833 L .65313 .49935 L F
0 0 0 r
.5782 .57839 m .57767 .58025 L .57629 .58138 L F
.5808 .57575 m .58001 .57713 L .5782 .57839 L F
0 0 .103 r
.5782 .57839 m .5791 .57921 L .57767 .58025 L F
.5782 .57839 m .58001 .57713 L .5791 .57921 L F
.964 .806 .637 r
.55865 .75831 m .56073 .7568 L .55874 .75621 L F
.55865 .75831 m .56017 .75936 L .56073 .7568 L F
0 0 0 r
.57029 .65358 m .56866 .65667 L .5709 .65477 L F
.337 .203 .547 r
.43603 .6762 m .43401 .67485 L .4362 .67399 L F
.43603 .6762 m .43386 .67745 L .43401 .67485 L F
.359 0 0 r
.35227 .59917 m .35048 .59971 L .34853 .59944 L F
.351 0 0 r
.35384 .59923 m .35048 .59971 L .35227 .59917 L F
.519 .894 .965 r
.54418 .7592 m .54138 .76013 L .54255 .75926 L F
.712 .532 .645 r
.5447 .7615 m .54147 .76299 L .54138 .76013 L F
.071 0 .271 r
.54131 .76076 m .54255 .75926 L .54138 .76013 L F
0 .183 .665 r
.74247 .52791 m .74366 .52906 L .74141 .52741 L F
0 .396 .847 r
.72692 .46817 m .72517 .46802 L .72432 .46678 L F
.72692 .46817 m .72795 .46948 L .72517 .46802 L F
.617 .457 .643 r
.6685 .47841 m .67085 .47608 L .66818 .47655 L F
.402 .143 .402 r
.64645 .48803 m .6445 .49043 L .64715 .48947 L F
.767 .777 .861 r
.68887 .5047 m .69226 .5049 L .69095 .50343 L F
.463 .466 .776 r
.56867 .64825 m .56981 .65123 L .56784 .65242 L F
.399 .336 .67 r
.56981 .65123 m .57029 .65358 L .56784 .65242 L F
.595 .736 .942 r
.27555 .64374 m .27884 .64529 L .27809 .6432 L F
.726 .82 .923 r
.27884 .64529 m .28097 .64262 L .27809 .6432 L F
.27884 .64529 m .28197 .64373 L .28097 .64262 L F
.533 .359 .591 r
.60688 .53557 m .60911 .53258 L .60663 .533 L F
.733 .764 .878 r
.69339 .50106 m .69701 .50111 L .69557 .49862 L F
.63 .744 .93 r
.69557 .49862 m .69701 .50111 L .70004 .50011 L F
.396 .182 .467 r
.40908 .67137 m .41129 .66872 L .40904 .669 L F
.565 .461 .695 r
.26617 .60964 m .26829 .60919 L .26774 .60728 L F
.557 .429 .661 r
.26617 .60964 m .26637 .61205 L .26829 .60919 L F
.798 .953 .918 r
.52671 .80068 m .52406 .80201 L .52553 .80227 L F
.342 0 0 r
.52773 .80124 m .52671 .80068 L .52553 .80227 L F
.52773 .80124 m .52907 .80193 L .52671 .80068 L F
.846 .758 .766 r
.72006 .50102 m .7236 .49937 L .72229 .49807 L F
.72006 .50102 m .72177 .5023 L .7236 .49937 L F
.554 .368 .583 r
.56866 .65667 m .56889 .66046 L .56637 .6602 L F
.097 0 0 r
.57223 .65423 m .57148 .65544 L .56939 .65538 L F
.56943 .65527 m .56939 .65538 L .56916 .65537 L F
.57223 .65423 m .56939 .65538 L .56943 .65527 L F
0 0 0 r
.56984 .65444 m .56947 .65519 L .56944 .65526 L F
.5695 .65508 m .56944 .65526 L .56866 .65667 L F
.56984 .65444 m .56944 .65526 L .5695 .65508 L F
.56947 .65519 m .56871 .65676 L .56869 .65673 L F
.56947 .65519 m .56869 .65673 L .56866 .65667 L F
.097 0 0 r
.57223 .65423 m .56943 .65527 L .57029 .65358 L F
.56943 .65527 m .56916 .65537 L .57029 .65358 L F
.439 .241 .513 r
.56916 .65537 m .56926 .65563 L .56871 .65676 L F
.607 .747 .943 r
.57027 .65838 m .56889 .66046 L .56866 .65667 L F
.57027 .65838 m .56866 .65667 L .56871 .65676 L F
.439 .241 .513 r
.56926 .65563 m .57027 .65838 L .56871 .65676 L F
.358 .336 .697 r
.57148 .65544 m .57027 .65838 L .56926 .65563 L F
.56939 .65538 m .56926 .65563 L .56916 .65537 L F
.57148 .65544 m .56926 .65563 L .56939 .65538 L F
0 0 0 r
.57029 .65358 m .56944 .65528 L .56984 .65444 L F
.56944 .65528 m .56871 .65676 L .56926 .65563 L F
.56944 .65528 m .56926 .65563 L .56984 .65444 L F
.69 .418 .506 r
.36561 .60856 m .36835 .60891 L .36895 .60646 L F
.414 .198 .474 r
.36895 .60646 m .37086 .60607 L .37093 .60387 L F
.298 .055 .367 r
.36895 .60646 m .37014 .60809 L .37086 .60607 L F
.36895 .60646 m .36835 .60891 L .37014 .60809 L F
.257 0 0 r
.46503 .69633 m .46682 .69695 L .46836 .69743 L F
.686 .257 .224 r
.46682 .69695 m .47062 .69729 L .46836 .69743 L F
.221 0 .041 r
.5482 .58976 m .5494 .59084 L .55033 .58897 L F
.5482 .58976 m .54715 .59168 L .5494 .59084 L F
.881 .771 .736 r
.634 .51499 m .63511 .51806 L .63583 .51601 L F
.634 .51499 m .6322 .51806 L .63511 .51806 L F
.871 .811 .788 r
.6322 .51806 m .63361 .51934 L .63511 .51806 L F
.92 .765 .673 r
.55337 .61483 m .55274 .61789 L .55436 .61804 L F
.921 .75 .653 r
.55436 .61804 m .55241 .61867 L .55274 .61789 L F
.537 .842 .526 r
.55436 .61804 m .55554 .61676 L .55695 .61536 L F
.596 .95 .863 r
.55436 .61804 m .55241 .61867 L .55554 .61676 L F
.251 0 0 r
.49427 .80219 m .49103 .80416 L .49295 .80365 L F
.313 .301 .685 r
.49639 .80437 m .49517 .80518 L .49427 .80219 L F
.688 .313 .33 r
.49639 .80437 m .49427 .80219 L .49295 .80365 L F
0 0 .098 r
.28452 .63895 m .28412 .63788 L .28609 .63899 L F
.621 .195 .211 r
.28535 .64355 m .2836 .6453 L .28197 .64373 L F
.22 .421 .847 r
.2861 .64226 m .28535 .64355 L .28369 .64054 L F
.763 .38 .33 r
.28707 .64564 m .28535 .64355 L .2861 .64226 L F
.28707 .64564 m .2836 .6453 L .28535 .64355 L F
.469 .206 .433 r
.59184 .54707 m .5941 .5465 L .59429 .54459 L F
.543 .257 .43 r
.5941 .5465 m .59728 .5437 L .59429 .54459 L F
.521 .492 .765 r
.43091 .68896 m .43398 .69069 L .43173 .69117 L F
.849 .861 .851 r
.5032 .70025 m .50097 .7023 L .49954 .70138 L F
.567 .114 .136 r
.50182 .70086 m .50232 .70072 L .5032 .70025 L F
.859 .907 .866 r
.50231 .70298 m .5032 .70025 L .50375 .69996 L F
.50231 .70298 m .50097 .7023 L .5032 .70025 L F
.567 .114 .136 r
.50232 .70072 m .50575 .69976 L .5032 .70025 L F
.859 .907 .866 r
.50375 .69996 m .5032 .70025 L .50387 .69969 L F
.811 .408 .286 r
.50442 .70472 m .50097 .7023 L .50231 .70298 L F
.611 .621 .837 r
.74508 .51868 m .7439 .52172 L .74361 .52019 L F
0 .323 .788 r
.7439 .52172 m .74611 .52266 L .74361 .52019 L F
.7439 .52172 m .74672 .52354 L .74611 .52266 L F
.535 .723 .96 r
.3784 .59073 m .37754 .59253 L .37622 .59106 L F
.475 .651 .936 r
.3784 .59073 m .37962 .59248 L .37754 .59253 L F
.672 .64 .81 r
.39831 .59747 m .39733 .60127 L .39605 .59745 L F
.39831 .59747 m .39991 .60092 L .39733 .60127 L F
.448 .392 .703 r
.39955 .60314 m .39733 .60127 L .39991 .60092 L F
.39955 .60314 m .39791 .60402 L .39733 .60127 L F
.599 .78 .967 r
.42306 .7088 m .42638 .70955 L .42524 .70839 L F
.08 .331 .808 r
.42638 .70955 m .42716 .70863 L .42524 .70839 L F
.402 .765 .994 r
.42924 .7117 m .42862 .71125 L .42638 .70955 L F
.08 .331 .808 r
.42638 .70955 m .42862 .71125 L .42716 .70863 L F
.315 .599 .947 r
.55523 .64616 m .556 .64513 L .5535 .64446 L F
.084 .262 .749 r
.55523 .64616 m .55736 .64829 L .556 .64513 L F
.934 .608 .395 r
.73131 .482 m .73094 .48534 L .72861 .48128 L F
.73131 .482 m .73195 .48462 L .73094 .48534 L F
.618 .558 .765 r
.62595 .50106 m .62977 .5039 L .62865 .50087 L F
.493 .504 .797 r
.71083 .48186 m .7135 .48426 L .71268 .4815 L F
.737 .317 .249 r
.28165 .63972 m .2796 .64036 L .27796 .63942 L F
.796 .769 .828 r
.28165 .63972 m .27796 .63942 L .2796 .64036 L F
.936 .782 .664 r
.62863 .55032 m .62818 .55245 L .6302 .55042 L F
.951 .829 .687 r
.6302 .55042 m .62818 .55245 L .62887 .55541 L F
.544 .216 .362 r
.42719 .65772 m .42921 .65932 L .42958 .6575 L F
.567 .204 .311 r
.42666 .65929 m .42921 .65932 L .42719 .65772 L F
.785 .733 .804 r
.71772 .50374 m .72095 .50408 L .72006 .50102 L F
.789 .723 .79 r
.71772 .50374 m .71912 .50525 L .72095 .50408 L F
.838 .76 .777 r
.72006 .50102 m .72095 .50408 L .72177 .5023 L F
.608 .408 .586 r
.27171 .59511 m .27409 .59496 L .27419 .59252 L F
.27171 .59511 m .27409 .59496 L .27419 .59252 L F
.538 .332 .549 r
.27409 .59496 m .27645 .59214 L .27419 .59252 L F
.701 .775 .909 r
.55722 .76148 m .5575 .76449 L .55912 .76238 L F
.84 .736 .749 r
.56002 .76567 m .55912 .76238 L .5575 .76449 L F
.909 .881 .794 r
.74022 .52634 m .74322 .52424 L .74025 .52395 L F
.466 .576 .881 r
.36908 .60036 m .37093 .60387 L .37258 .60301 L F
.385 .175 .468 r
.37093 .60387 m .3727 .60543 L .37258 .60301 L F
.37093 .60387 m .37086 .60607 L .3727 .60543 L F
.464 .772 .997 r
.723 .51358 m .7239 .51456 L .72318 .51354 L F
.052 .472 .885 r
.72318 .51354 m .7239 .51456 L .72607 .51539 L F
.86 .736 .725 r
.6297 .53474 m .63118 .53611 L .63006 .53273 L F
.844 .731 .739 r
.62764 .53788 m .63118 .53611 L .6297 .53474 L F
.62764 .53788 m .62943 .53916 L .63118 .53611 L F
.808 .713 .76 r
.63006 .53273 m .63118 .53611 L .63234 .53164 L F
.489 0 .006 r
.45661 .69675 m .45587 .69728 L .45898 .69699 L F
.124 0 0 r
.33149 .63024 m .33348 .63009 L .33516 .62955 L F
.217 .727 .675 r
.33516 .62955 m .33594 .6293 L .33838 .62881 L F
.33516 .62955 m .33348 .63009 L .33594 .6293 L F
.514 .89 .967 r
.33812 .62889 m .33516 .62955 L .33838 .62881 L F
.732 .666 .785 r
.66665 .49872 m .6643 .5017 L .66776 .50188 L F
0 0 0 r
.30411 .58362 m .30629 .58338 L .30795 .58311 L F
.409 0 0 r
.30795 .58311 m .30629 .58338 L .3099 .58355 L F
.661 .599 .774 r
.2744 .62096 m .27797 .62367 L .27654 .62051 L F
.469 .547 .854 r
.27797 .62367 m .27817 .6204 L .27654 .62051 L F
.27797 .62367 m .27964 .62307 L .27817 .6204 L F
.227 0 .04 r
.27797 .62367 m .27892 .62487 L .27964 .62307 L F
.396 .301 .63 r
.25655 .66053 m .25706 .66355 L .25847 .66249 L F
.945 .649 .198 r
.50323 .78159 m .50437 .78389 L .50433 .78506 L F
.678 .207 0 r
.71218 .46096 m .71451 .46388 L .7143 .46226 L F
.512 .406 .671 r
.63633 .49326 m .63795 .48943 L .63563 .49091 L F
.63633 .49326 m .63853 .49277 L .63795 .48943 L F
.478 .294 .553 r
.63633 .49326 m .63641 .49565 L .63853 .49277 L F
.896 .895 .819 r
.68979 .49328 m .68727 .49682 L .68645 .4957 L F
.98 .857 .647 r
.72338 .49184 m .72507 .49072 L .72443 .48994 L F
.72338 .49184 m .72437 .49292 L .72507 .49072 L F
.487 .255 .488 r
.38011 .61793 m .3798 .62017 L .37764 .62063 L F
.489 .248 .476 r
.38231 .61752 m .3798 .62017 L .38011 .61793 L F
.864 .779 .765 r
.68002 .51213 m .67885 .51274 L .68174 .51295 L F
.804 .813 .858 r
.68002 .51213 m .68174 .51295 L .68425 .5102 L F
.865 .914 .862 r
.48683 .80152 m .49065 .7995 L .48925 .79864 L F
.536 .081 .118 r
.46963 .70269 m .46828 .70427 L .46603 .7032 L F
.511 .036 .062 r
.47201 .70311 m .46828 .70427 L .46963 .70269 L F
.574 .347 .534 r
.5905 .62358 m .58814 .62613 L .5881 .62369 L F
.792 .489 .475 r
.57708 .66909 m .57352 .67061 L .57391 .66886 L F
.57708 .66909 m .57719 .67117 L .57352 .67061 L F
.817 .685 .718 r
.62857 .52938 m .63221 .52758 L .63081 .52633 L F
.62857 .52938 m .63039 .53013 L .63221 .52758 L F
.516 .168 .316 r
.53323 .69713 m .5324 .69958 L .52989 .69966 L F
.624 .61 .817 r
.53533 .69575 m .53323 .69713 L .53214 .69447 L F
.361 .025 .253 r
.5346 .69885 m .53323 .69713 L .53533 .69575 L F
.5346 .69885 m .5324 .69958 L .53323 .69713 L F
.523 0 0 r
.6906 .47303 m .69397 .47429 L .69416 .47344 L F
.868 .602 .073 r
.69397 .47429 m .69451 .47577 L .69416 .47344 L F
.499 .254 .475 r
.40818 .69181 m .41005 .69368 L .40981 .69111 L F
.40818 .69181 m .40774 .6944 L .41005 .69368 L F
.877 .699 .658 r
.65943 .49512 m .66077 .49856 L .6609 .49619 L F
.838 .754 .771 r
.634 .51499 m .63769 .51314 L .63657 .51212 L F
.634 .51499 m .63583 .51601 L .63769 .51314 L F
.847 .894 .871 r
.63657 .51212 m .63769 .51314 L .64024 .51048 L F
.294 0 .129 r
.35724 .6351 m .35597 .6373 L .35481 .63659 L F
.428 .042 .203 r
.35876 .63609 m .35724 .6351 L .35927 .63441 L F
.35876 .63609 m .35597 .6373 L .35724 .6351 L F
.662 .849 .972 r
.70822 .46107 m .70313 .46189 L .70538 .46072 L F
.083 .499 .899 r
.708 .46037 m .70822 .46107 L .70538 .46072 L F
.70849 .46038 m .70822 .46107 L .708 .46037 L F
.70849 .46038 m .71076 .46205 L .70822 .46107 L F
.70852 .4603 m .70882 .46053 L .70849 .46038 L F
.70882 .46053 m .71076 .46205 L .70849 .46038 L F
.753 .772 .868 r
.71218 .46096 m .71076 .46205 L .70882 .46053 L F
.70962 .4605 m .70882 .46053 L .70852 .4603 L F
.71218 .46096 m .70882 .46053 L .70962 .4605 L F
.658 .414 .539 r
.70795 .46057 m .71068 .46231 L .71033 .46122 L F
.70714 .46035 m .70757 .46058 L .70795 .46057 L F
.70757 .46058 m .71068 .46231 L .70795 .46057 L F
.70901 .46062 m .71033 .46122 L .7102 .46079 L F
.70714 .46035 m .71033 .46122 L .70901 .46062 L F
.403 .814 .977 r
.70538 .46072 m .7067 .46028 L .70852 .4603 L F
.658 .414 .539 r
.7067 .46028 m .70681 .46034 L .70714 .46035 L F
.70681 .46034 m .71068 .46231 L .70714 .46035 L F
.083 .499 .899 r
.70852 .4603 m .70849 .46038 L .708 .46037 L F
.628 .762 .943 r
.70004 .50011 m .70204 .50116 L .70103 .49933 L F
.684 .797 .935 r
.70103 .49933 m .70204 .50116 L .70481 .49918 L F
.896 .895 .819 r
.68979 .49328 m .68645 .4957 L .68849 .49242 L F
0 .144 .68 r
.49165 .79101 m .49278 .79145 L .495 .79088 L F
.49165 .79101 m .49387 .79331 L .49278 .79145 L F
.316 .799 .896 r
.3099 .58355 m .31202 .58314 L .31366 .58323 L F
.074 0 0 r
.31366 .58323 m .31202 .58314 L .31568 .58339 L F
.986 .747 .487 r
.49317 .63943 m .49296 .64221 L .49429 .64067 L F
.423 .691 .975 r
.49429 .64067 m .49525 .63933 L .49317 .63943 L F
.53 .833 .999 r
.49429 .64067 m .49525 .63933 L .49663 .64011 L F
.599 .847 .485 r
.49429 .64067 m .49296 .64221 L .49525 .63933 L F
.53 .833 .999 r
.49429 .64067 m .49525 .63933 L .49663 .64011 L F
.989 .725 .415 r
.64756 .49174 m .64854 .49056 L .64715 .48947 L F
.64756 .49174 m .64864 .49295 L .64854 .49056 L F
.38 .622 .947 r
.70822 .49129 m .70756 .49254 L .70638 .49175 L F
.70822 .49129 m .70987 .49268 L .70756 .49254 L F
.271 0 0 r
.67645 .47544 m .67905 .47496 L .67924 .4742 L F
.548 .359 .576 r
.44372 .66618 m .44378 .6687 L .44143 .66911 L F
.399 .243 .551 r
.44563 .66797 m .44378 .6687 L .44372 .66618 L F
.043 .355 .829 r
.50699 .62461 m .50587 .625 L .50436 .62334 L F
.50699 .62461 m .50775 .62623 L .50587 .625 L F
.892 .779 .73 r
.6482 .4954 m .64824 .49824 L .6498 .49691 L F
.24 .329 .755 r
.43699 .6958 m .43581 .69746 L .43472 .69409 L F
.484 .669 .945 r
.43699 .6958 m .43798 .69747 L .43581 .69746 L F
.956 .948 .659 r
.57453 .5853 m .57629 .58138 L .57475 .5827 L F
0 0 .124 r
.57629 .58138 m .57705 .58219 L .57475 .5827 L F
.57629 .58138 m .57767 .58025 L .57705 .58219 L F
.496 .121 .257 r
.43494 .6563 m .43716 .65627 L .43538 .65499 L F
.473 .135 .312 r
.43538 .65499 m .43716 .65627 L .43762 .65467 L F
.468 .782 .998 r
.29351 .64048 m .29551 .64013 L .29302 .63952 L F
.453 .356 .655 r
.29351 .64048 m .29564 .64218 L .29551 .64013 L F
.457 0 0 r
.29302 .63952 m .29509 .64098 L .29403 .64028 L F
.468 .782 .998 r
.29351 .64048 m .29302 .63952 L .29221 .63891 L F
.457 0 0 r
.29302 .63952 m .29403 .64028 L .29185 .63885 L F
.468 .782 .998 r
.29221 .63891 m .29302 .63952 L .29136 .63788 L F
.453 .356 .655 r
.29351 .64048 m .29385 .64295 L .29564 .64218 L F
0 0 0 r
.7126 .49045 m .71126 .49186 L .71421 .48924 L F
.421 .167 .421 r
.48632 .66507 m .48465 .66359 L .4867 .66296 L F
.48632 .66507 m .48425 .66572 L .48465 .66359 L F
.48465 .66359 m .48632 .66507 L .4867 .66296 L F
.48465 .66359 m .48425 .66572 L .48632 .66507 L F
.839 .996 .764 r
.5444 .65465 m .54216 .65742 L .54262 .65533 L F
.647 .507 .678 r
.54511 .65704 m .54216 .65742 L .5444 .65465 L F
.58 .815 .988 r
.54262 .65533 m .54216 .65742 L .54511 .65704 L F
.485 .135 .296 r
.45601 .64608 m .45858 .64577 L .45946 .64343 L F
.321 0 .225 r
.45946 .64343 m .46076 .64507 L .46176 .6431 L F
.45946 .64343 m .45858 .64577 L .46076 .64507 L F
.702 .928 .607 r
.2711 .64447 m .26998 .64571 L .27223 .64293 L F
.604 .848 .99 r
.26998 .64571 m .2738 .64603 L .27223 .64293 L F
.696 .687 .837 r
.27223 .64293 m .2738 .64603 L .27555 .64374 L F
.646 .624 .813 r
.30467 .72494 m .30413 .7294 L .30408 .72697 L F
.30467 .72494 m .30638 .72829 L .30413 .7294 L F
.374 .665 .971 r
.30413 .7294 m .30442 .72779 L .30408 .72697 L F
.216 0 .082 r
.30638 .72829 m .30541 .72919 L .30413 .7294 L F
.374 .665 .971 r
.30413 .7294 m .30541 .72919 L .30442 .72779 L F
.615 .284 .387 r
.58639 .64087 m .58273 .64198 L .58285 .64133 L F
.702 .664 .81 r
.43413 .67993 m .43565 .68317 L .43265 .68296 L F
.497 .345 .605 r
.43482 .68493 m .43265 .68296 L .43565 .68317 L F
.102 .307 .783 r
.43643 .68195 m .43565 .68317 L .43413 .67993 L F
.347 0 .19 r
.43792 .68407 m .43565 .68317 L .43643 .68195 L F
.43792 .68407 m .43482 .68493 L .43565 .68317 L F
.629 .442 .611 r
.5926 .62076 m .59372 .62298 L .5905 .62358 L F
.6 .348 .507 r
.59616 .62067 m .59372 .62298 L .5926 .62076 L F
.483 .168 .355 r
.44143 .66911 m .44093 .67092 L .43859 .67148 L F
.504 .201 .385 r
.44378 .6687 m .44093 .67092 L .44143 .66911 L F
.532 .558 .827 r
.75735 .51152 m .7556 .51322 L .75518 .51166 L F
.532 .475 .738 r
.75735 .51152 m .75617 .51573 L .7556 .51322 L F
.187 0 0 r
.50387 .69969 m .50575 .69976 L .50628 .69903 L F
.144 0 0 r
.50387 .69969 m .5032 .70025 L .50575 .69976 L F
.84 .736 .749 r
.56002 .76567 m .56205 .76248 L .55912 .76238 L F
.882 .714 .67 r
.56598 .60846 m .56938 .60673 L .56803 .6052 L F
.56598 .60846 m .56655 .61073 L .56938 .60673 L F
.579 .356 .542 r
.47871 .64911 m .4782 .65185 L .47584 .6519 L F
.528 .308 .525 r
.48059 .64877 m .4782 .65185 L .47871 .64911 L F
.598 .293 .423 r
.495 .79088 m .49672 .78977 L .49385 .78813 L F
.664 .911 .978 r
.55803 .62384 m .56064 .62348 L .5602 .62308 L F
.278 .029 .346 r
.55985 .62208 m .55803 .62384 L .5602 .62308 L F
.716 .253 .15 r
.5602 .62308 m .55897 .62429 L .55965 .62258 L F
.5602 .62308 m .55965 .62258 L .55985 .62208 L F
.664 .911 .978 r
.56064 .62348 m .56148 .62336 L .5602 .62308 L F
.717 .24 .115 r
.56302 .62388 m .5602 .62308 L .56148 .62336 L F
.538 .5 .761 r
.43266 .68577 m .42979 .68323 L .43265 .68296 L F
.284 0 .002 r
.5447 .7615 m .54371 .76258 L .54147 .76299 L F
.365 .823 .927 r
.54701 .76233 m .54371 .76258 L .5447 .7615 L F
0 .073 .603 r
.52479 .6488 m .52436 .64834 L .52568 .64908 L F
.803 .783 .834 r
.65512 .50827 m .66059 .50677 L .65877 .50545 L F
.65512 .50827 m .65669 .50941 L .66059 .50677 L F
.23 0 .316 r
.39955 .60314 m .39732 .60604 L .39791 .60402 L F
.485 .301 .555 r
.2671 .60118 m .26917 .6007 L .26924 .59807 L F
.549 .453 .699 r
.26746 .60358 m .26917 .6007 L .2671 .60118 L F
.603 .419 .606 r
.55258 .75071 m .554 .75355 L .55626 .75068 L F
.163 0 0 r
.33812 .62889 m .34009 .62863 L .34031 .62831 L F
.071 0 0 r
.33838 .62881 m .34009 .62863 L .33812 .62889 L F
0 0 0 r
.58146 .57631 m .5808 .57575 L .58219 .57418 L F
.58146 .57631 m .58001 .57713 L .5808 .57575 L F
.819 .614 .06 r
.65124 .50419 m .65077 .50039 L .65218 .50105 L F
.912 .814 .738 r
.65056 .49984 m .65179 .50143 L .65106 .49945 L F
.911 .875 .789 r
.65218 .50105 m .65077 .50039 L .6521 .49833 L F
.815 .729 .77 r
.67264 .51036 m .66877 .51183 L .67103 .50899 L F
.67264 .51036 m .67037 .5133 L .66877 .51183 L F
.813 .779 .821 r
.67508 .50766 m .67264 .51036 L .67103 .50899 L F
.776 .817 .885 r
.69527 .46924 m .69636 .47068 L .69902 .4683 L F
.854 .993 .836 r
.47388 .63126 m .47258 .63273 L .47302 .63099 L F
.26 .223 .626 r
.47161 .63383 m .47302 .63099 L .47258 .63273 L F
.898 .634 .53 r
.56065 .61472 m .56303 .61511 L .56401 .6142 L F
.459 .197 .429 r
.58721 .56897 m .58462 .57213 L .58525 .57001 L F
.683 .234 .179 r
.51589 .77955 m .51511 .78073 L .51253 .77902 L F
.492 .048 .121 r
.51589 .77955 m .51686 .78132 L .51511 .78073 L F
.51589 .77955 m .51835 .77948 L .51686 .78132 L F
.618 .751 .941 r
.55272 .60932 m .55452 .6081 L .55372 .60783 L F
.55272 .60932 m .55548 .60911 L .55452 .6081 L F
.682 .5 .633 r
.55273 .61231 m .55548 .60911 L .55272 .60932 L F
.454 .331 .623 r
.43266 .68577 m .43295 .68872 L .43091 .68896 L F
.473 .501 .807 r
.43295 .68872 m .43398 .69069 L .43091 .68896 L F
.648 .435 .58 r
.59818 .60338 m .60082 .60339 L .60073 .60095 L F
.499 .311 .557 r
.60073 .60095 m .60304 .6004 L .60299 .59803 L F
.494 .297 .541 r
.60298 .60274 m .60073 .60095 L .60082 .60339 L F
.60298 .60274 m .60304 .6004 L .60073 .60095 L F
.423 .714 .984 r
.34425 .58629 m .34366 .58789 L .34201 .58656 L F
.34425 .58629 m .34579 .58749 L .34366 .58789 L F
.448 .787 .998 r
.7349 .47539 m .73589 .47624 L .7325 .47569 L F
.558 .924 .94 r
.73751 .47487 m .73589 .47624 L .7349 .47539 L F
.73751 .47487 m .73788 .47533 L .73589 .47624 L F
.288 0 .056 r
.41574 .65945 m .41764 .6592 L .41823 .6592 L F
.41574 .65945 m .41538 .65987 L .41764 .6592 L F
.577 .312 .478 r
.52073 .65234 m .52022 .65464 L .51773 .65446 L F
.399 .15 .416 r
.52226 .65378 m .52073 .65234 L .52301 .6515 L F
.52226 .65378 m .52022 .65464 L .52073 .65234 L F
0 0 0 r
.45415 .66509 m .45256 .66553 L .45504 .6635 L F
.681 .258 .234 r
.45158 .66308 m .45415 .66509 L .45504 .6635 L F
.632 .155 .102 r
.45504 .6635 m .45483 .66419 L .45158 .66308 L F
0 0 0 r
.45616 .66189 m .45504 .6635 L .45742 .66299 L F
.45616 .66189 m .45483 .66419 L .45504 .6635 L F
0 0 .461 r
.58195 .65392 m .5824 .65495 L .58159 .65146 L F
.317 0 .074 r
.35481 .63659 m .35377 .63785 L .35162 .63828 L F
.32 0 .067 r
.35481 .63659 m .35531 .63827 L .35377 .63785 L F
.35481 .63659 m .35597 .6373 L .35531 .63827 L F
.668 .508 .659 r
.57508 .61794 m .5774 .61525 L .5742 .61499 L F
.57508 .61794 m .57759 .61775 L .5774 .61525 L F
.639 .486 .659 r
.5774 .61525 m .57759 .61775 L .57987 .61488 L F
.176 .023 .422 r
.58672 .65339 m .58522 .65573 L .5841 .65566 L F
.035 .541 .874 r
.5841 .65566 m .58522 .65573 L .5824 .65495 L F
0 0 0 r
.6234 .5838 m .62296 .58558 L .62291 .58562 L F
.755 .873 .451 r
.62413 .58185 m .6234 .5838 L .62514 .58036 L F
0 0 0 r
.62413 .58185 m .62296 .58558 L .6234 .5838 L F
.91 .534 .298 r
.56664 .66322 m .56345 .65934 L .56637 .6602 L F
.655 .573 .751 r
.56889 .66046 m .56664 .66322 L .56637 .6602 L F
.393 .108 .356 r
.61823 .52102 m .62041 .52038 L .6206 .51796 L F
.243 0 .189 r
.6206 .51796 m .62282 .51759 L .62301 .51594 L F
.286 .025 .332 r
.6206 .51796 m .62041 .52038 L .62282 .51759 L F
.46 .195 .425 r
.37764 .62063 m .37721 .6228 L .37503 .62327 L F
.47 .207 .432 r
.3798 .62017 m .37721 .6228 L .37764 .62063 L F
.708 .646 .785 r
.45742 .66299 m .46134 .66459 L .45958 .66235 L F
.69 .713 .866 r
.45958 .66235 m .46134 .66459 L .46348 .66332 L F
.056 0 .224 r
.61512 .60039 m .61432 .60236 L .61255 .6033 L F
0 0 .091 r
.61432 .60236 m .61204 .60525 L .61255 .6033 L F
0 0 0 r
.58218 .66177 m .58167 .66317 L .58331 .65895 L F
.07 0 0 r
.32646 .64812 m .32363 .64791 L .3245 .64852 L F
.802 .573 .591 r
.56154 .59971 m .55884 .60297 L .55874 .60047 L F
.56154 .59971 m .56237 .60442 L .55884 .60297 L F
.653 .49 .651 r
.56453 .59801 m .56577 .60004 L .56154 .59971 L F
.56577 .60004 m .56566 .60036 L .56154 .59971 L F
.791 .566 .595 r
.56488 .60339 m .56154 .59971 L .566 .60042 L F
.945 .921 .555 r
.56528 .59902 m .56414 .60231 L .56469 .60311 L F
.56498 .60229 m .56469 .60311 L .56488 .60339 L F
.56528 .59902 m .56469 .60311 L .56498 .60229 L F
.653 .49 .651 r
.56577 .60004 m .566 .60042 L .56566 .60036 L F
.791 .566 .595 r
.56488 .60339 m .56237 .60442 L .56154 .59971 L F
.535 .315 .528 r
.58792 .60955 m .5901 .60893 L .59012 .60661 L F
.58 .402 .605 r
.5901 .60893 m .59246 .60587 L .59012 .60661 L F
.447 .39 .7 r
.75636 .49179 m .75399 .49438 L .75372 .49015 L F
.57 .483 .717 r
.75636 .49179 m .75461 .49604 L .75399 .49438 L F
.369 .04 .27 r
.62553 .51075 m .62717 .51157 L .62747 .50988 L F
.62553 .51075 m .62494 .51229 L .62717 .51157 L F
.78 .807 .874 r
.73325 .51139 m .7376 .51043 L .73645 .50926 L F
.847 .853 .847 r
.73645 .50926 m .7376 .51043 L .73973 .5077 L F
0 0 0 r
.32317 .60194 m .32193 .6026 L .3198 .60319 L F
.018 0 0 r
.32549 .60201 m .32193 .6026 L .32317 .60194 L F
.625 .701 .899 r
.66805 .52043 m .66919 .52236 L .67175 .52146 L F
.74 .649 .759 r
.27096 .62055 m .2744 .62096 L .27302 .61781 L F
.601 .58 .802 r
.27302 .61781 m .2744 .62096 L .27654 .62051 L F
.149 0 .335 r
.75575 .51793 m .75437 .51875 L .75617 .51573 L F
.314 .161 .508 r
.75591 .5199 m .75437 .51875 L .75575 .51793 L F
.75591 .5199 m .75434 .52126 L .75437 .51875 L F
.544 .073 .088 r
.47062 .69729 m .47265 .69849 L .47409 .69692 L F
.458 0 .062 r
.47265 .69849 m .4764 .6969 L .47409 .69692 L F
0 0 .109 r
.62301 .51594 m .62282 .51759 L .62478 .51443 L F
0 .01 .53 r
.56302 .62388 m .56577 .6269 L .56432 .62521 L F
0 .077 .587 r
.5672 .62813 m .56432 .62521 L .56577 .6269 L F
.59 .261 .38 r
.56511 .62818 m .5672 .62813 L .56577 .6269 L F
0 .02 .534 r
.48342 .78316 m .48313 .78289 L .48232 .78207 L F
.297 .028 .327 r
.57215 .64524 m .57329 .64725 L .57106 .64858 L F
.57329 .64725 m .57303 .64778 L .57106 .64858 L F
.309 .151 .499 r
.57602 .64206 m .57215 .64524 L .57349 .64249 L F
.57602 .64206 m .57573 .64464 L .57215 .64524 L F
.268 .019 .339 r
.57573 .64464 m .57348 .64759 L .57329 .64725 L F
.57399 .64493 m .57329 .64725 L .57215 .64524 L F
.5742 .64489 m .57408 .64518 L .57399 .64493 L F
.57402 .64501 m .57329 .64725 L .57399 .64493 L F
.57399 .64544 m .57329 .64725 L .57402 .64501 L F
.5735 .64678 m .57329 .64725 L .5742 .64489 L F
.291 .018 .315 r
.57348 .64759 m .57099 .6502 L .57106 .64858 L F
.792 .453 .414 r
.56975 .64452 m .57232 .64816 L .57396 .6458 L F
.57398 .64547 m .57396 .6458 L .57416 .64551 L F
.56975 .64452 m .57396 .6458 L .57398 .64547 L F
.268 .019 .339 r
.57408 .64518 m .57399 .64544 L .57402 .64501 L F
0 0 .329 r
.57349 .64249 m .57394 .64454 L .57413 .64311 L F
.806 .569 .58 r
.56975 .64452 m .57398 .64547 L .57349 .64249 L F
.57398 .64547 m .57409 .64519 L .57349 .64249 L F
.56975 .64452 m .57349 .64249 L .56957 .64226 L F
.815 .698 .736 r
.57413 .64311 m .57232 .64816 L .57073 .64338 L F
.57413 .64311 m .57073 .64338 L .57298 .64551 L F
.734 .527 .613 r
.57298 .64551 m .57423 .64239 L .57413 .64311 L F
0 0 .329 r
.57349 .64249 m .57413 .64311 L .57602 .64206 L F
.734 .527 .613 r
.57423 .64239 m .57464 .64134 L .57413 .64311 L F
0 0 .329 r
.57394 .64454 m .57409 .64519 L .57413 .64311 L F
.57409 .64519 m .57416 .64551 L .57416 .64538 L F
.57409 .64519 m .57416 .64538 L .57413 .64311 L F
.806 .569 .58 r
.57398 .64547 m .57416 .64551 L .57409 .64519 L F
.268 .019 .339 r
.5744 .64486 m .5735 .64678 L .5742 .64489 L F
.939 .931 .575 r
.57416 .64546 m .57403 .64565 L .57416 .64538 L F
.57416 .64551 m .57407 .64564 L .57416 .64546 L F
.268 .019 .339 r
.57573 .64464 m .57329 .64725 L .5744 .64486 L F
.939 .931 .575 r
.57416 .64538 m .57232 .64816 L .57413 .64311 L F
.57403 .64565 m .57232 .64816 L .57416 .64538 L F
.57407 .64564 m .57232 .64816 L .57416 .64546 L F
.297 .028 .327 r
.57329 .64725 m .57348 .64759 L .57303 .64778 L F
.677 .162 0 r
.50216 .8095 m .5012 .80784 L .5011 .81066 L F
.50216 .8095 m .50358 .81061 L .5012 .80784 L F
.497 .345 .605 r
.43482 .68493 m .43266 .68577 L .43265 .68296 L F
.996 .788 .507 r
.6252 .57416 m .62657 .57227 L .62556 .57141 L F
.6252 .57416 m .62602 .57588 L .62657 .57227 L F
.812 .672 .709 r
.62876 .54353 m .63086 .54484 L .63077 .54205 L F
.814 .671 .706 r
.62996 .54681 m .63086 .54484 L .62876 .54353 L F
.608 .91 .982 r
.70313 .46189 m .7041 .46081 L .70538 .46072 L F
.591 .883 .992 r
.70313 .46189 m .70221 .46117 L .70454 .46032 L F
.528 .13 .231 r
.70237 .46122 m .70129 .46297 L .70495 .4622 L F
.70221 .46117 m .70216 .46127 L .70237 .46122 L F
.70216 .46127 m .70129 .46297 L .70237 .46122 L F
.608 .91 .982 r
.7041 .46081 m .70454 .46032 L .70508 .46058 L F
.7041 .46081 m .70508 .46058 L .70538 .46072 L F
.258 .624 .96 r
.37488 .58986 m .37387 .59068 L .37239 .58977 L F
.37488 .58986 m .37622 .59106 L .37387 .59068 L F
.653 .708 .888 r
.71539 .50455 m .71912 .50525 L .71772 .50374 L F
.297 .787 .74 r
.68976 .46774 m .69204 .46688 L .69304 .46667 L F
.313 .797 .744 r
.69304 .46667 m .69421 .46611 L .69561 .46598 L F
.69304 .46667 m .69204 .46688 L .69421 .46611 L F
.796 .699 .758 r
.554 .75355 m .5574 .75396 L .55626 .75068 L F
.748 .348 .295 r
.554 .75355 m .55616 .75574 L .5574 .75396 L F
.838 .47 .357 r
.5574 .75396 m .55616 .75574 L .55874 .75621 L F
0 0 0 r
.32904 .60147 m .32872 .60154 L .32701 .60192 L F
.32904 .60147 m .33103 .60129 L .32872 .60154 L F
.686 .412 .502 r
.65732 .48075 m .65465 .48403 L .65575 .48268 L F
0 0 0 r
.65732 .48075 m .65843 .48082 L .65969 .4807 L F
.65732 .48075 m .65575 .48268 L .65843 .48082 L F
.225 0 0 r
.33782 .62953 m .33838 .62881 L .33594 .6293 L F
.33782 .62953 m .33861 .62942 L .33838 .62881 L F
.071 0 0 r
.33838 .62881 m .33861 .62942 L .34009 .62863 L F
.374 .132 .413 r
.26924 .59807 m .27116 .59759 L .27171 .59511 L F
.436 .187 .436 r
.27171 .59511 m .27318 .59693 L .27409 .59496 L F
.27171 .59511 m .27116 .59759 L .27318 .59693 L F
.351 0 0 r
.47988 .77742 m .48309 .77773 L .48283 .77753 L F
.31 0 0 r
.44864 .70571 m .44489 .707 L .44641 .70596 L F
.95 .798 .658 r
.62809 .56397 m .62849 .56203 L .62721 .56097 L F
.446 .175 .408 r
.32193 .6026 m .31909 .60515 L .3198 .60319 L F
.258 .283 .697 r
.58624 .65743 m .58862 .65974 L .58672 .66043 L F
.143 .649 .903 r
.31739 .58353 m .32079 .58418 L .31913 .58422 L F
.52 .328 .561 r
.26924 .59807 m .27125 .60014 L .27116 .59759 L F
.26924 .59807 m .26917 .6007 L .27125 .60014 L F
.792 .717 .781 r
.63873 .50893 m .64223 .50872 L .64079 .50794 L F
.63873 .50893 m .64024 .51048 L .64223 .50872 L F
.696 .929 .967 r
.64079 .50794 m .64223 .50872 L .64482 .5071 L F
.506 .29 .52 r
.67454 .48118 m .67222 .48392 L .67211 .48185 L F
.67454 .48118 m .67222 .48392 L .67211 .48185 L F
.755 .873 .451 r
.62413 .58185 m .62514 .58036 L .62515 .58052 L F
.543 .342 .558 r
.60235 .54155 m .60496 .54118 L .60481 .53853 L F
.452 .262 .532 r
.60481 .53853 m .60687 .53787 L .60688 .53557 L F
.447 .27 .548 r
.60481 .53853 m .60682 .54025 L .60687 .53787 L F
.60481 .53853 m .60496 .54118 L .60682 .54025 L F
.305 0 0 r
.28982 .58799 m .29262 .5869 L .29052 .58717 L F
0 0 0 r
.71479 .47583 m .7165 .47476 L .71751 .47371 L F
.4 .831 .679 r
.71446 .47592 m .7165 .47476 L .71479 .47583 L F
.812 .851 .878 r
.48881 .65324 m .4863 .65136 L .48838 .65029 L F
.48881 .65324 m .48561 .65553 L .4863 .65136 L F
.071 0 0 r
.48832 .65555 m .48561 .65553 L .48881 .65324 L F
.33 .357 .738 r
.4906 .64968 m .48881 .65324 L .48838 .65029 L F
.4906 .64968 m .49229 .65363 L .48881 .65324 L F
.565 .068 .033 r
.49186 .6556 m .48881 .65324 L .49229 .65363 L F
.49186 .6556 m .48832 .65555 L .48881 .65324 L F
.818 .451 0 r
.4846 .65395 m .48561 .65553 L .48515 .65456 L F
.889 .918 .837 r
.4863 .65136 m .48561 .65553 L .4846 .65395 L F
.314 0 0 r
.48561 .65553 m .484 .65603 L .4846 .65395 L F
.48561 .65553 m .48628 .65636 L .484 .65603 L F
.071 0 0 r
.48832 .65555 m .48628 .65636 L .48561 .65553 L F
.263 .723 .951 r
.35885 .58849 m .35543 .58795 L .35739 .58799 L F
.392 .805 .978 r
.3596 .58765 m .35885 .58849 L .35739 .58799 L F
.3596 .58765 m .36119 .58815 L .35885 .58849 L F
.538 .389 .626 r
.40704 .6744 m .40924 .67401 L .40908 .67137 L F
.519 .403 .66 r
.40704 .6744 m .40948 .67689 L .40924 .67401 L F
.40704 .6744 m .4074 .67752 L .40948 .67689 L F
.438 .127 .339 r
.37006 .62662 m .3695 .62822 L .36735 .62867 L F
.427 .118 .336 r
.37215 .62615 m .3695 .62822 L .37006 .62662 L F
.332 0 0 r
.50866 .69847 m .51093 .69826 L .51218 .69664 L F
.462 .052 .176 r
.51093 .69826 m .51448 .69612 L .51218 .69664 L F
.664 .124 0 r
.5444 .65465 m .54328 .65489 L .54027 .65295 L F
.839 .996 .764 r
.5444 .65465 m .54262 .65533 L .54328 .65489 L F
.628 .578 .779 r
.54609 .65228 m .5444 .65465 L .54389 .65251 L F
.54609 .65228 m .54756 .65465 L .5444 .65465 L F
0 0 0 r
.54756 .65465 m .54511 .65704 L .5444 .65465 L F
.072 .627 .81 r
.43798 .69747 m .4402 .69753 L .44161 .69775 L F
.187 .72 .809 r
.4402 .69753 m .44392 .69721 L .44161 .69775 L F
.484 .259 .496 r
.55521 .76434 m .5529 .76252 L .55603 .76305 L F
.866 .751 .734 r
.62764 .53788 m .62583 .54056 L .62876 .54109 L F
.853 .621 .586 r
.62543 .5429 m .62876 .54109 L .62583 .54056 L F
.62543 .5429 m .62876 .54353 L .62876 .54109 L F
.832 .737 .759 r
.62764 .53788 m .62876 .54109 L .62943 .53916 L F
.812 .672 .709 r
.62876 .54353 m .63077 .54205 L .62876 .54109 L F
.315 .578 .935 r
.38929 .59646 m .39108 .59668 L .39035 .59799 L F
.456 .754 .993 r
.39108 .59668 m .39252 .5978 L .39035 .59799 L F
.002 .402 .852 r
.56313 .60386 m .56237 .60442 L .56488 .60339 L F
.945 .921 .555 r
.56528 .59902 m .56488 .60339 L .566 .60042 L F
.923 .963 .654 r
.56414 .60231 m .56313 .60386 L .56488 .60339 L F
.616 .52 .723 r
.52228 .63663 m .52008 .63887 L .52 .6374 L F
.645 .508 .681 r
.58796 .61202 m .58602 .61038 L .58569 .61225 L F
.58796 .61202 m .58792 .60955 L .58602 .61038 L F
.763 .651 .738 r
.57414 .6182 m .57508 .61794 L .5742 .61499 L F
.845 .593 .558 r
.57382 .6197 m .57508 .61794 L .57414 .6182 L F
.57382 .6197 m .57539 .62041 L .57508 .61794 L F
.66 .46 .604 r
.57508 .61794 m .57539 .62041 L .57759 .61775 L F
.502 .373 .637 r
.58828 .62862 m .58645 .63311 L .58616 .62919 L F
0 0 0 r
.48134 .79858 m .47832 .80091 L .48044 .80027 L F
.48134 .79858 m .48044 .80027 L .47999 .79859 L F
.738 .631 .74 r
.48231 .79314 m .48378 .79559 L .48003 .796 L F
.85 .989 .851 r
.48378 .79559 m .47999 .79859 L .48003 .796 L F
.531 .341 .568 r
.48003 .796 m .48129 .79722 L .48207 .79563 L F
.85 .989 .851 r
.48378 .79559 m .48134 .79858 L .48031 .79858 L F
.48378 .79559 m .48031 .79858 L .48072 .79801 L F
.531 .341 .568 r
.48129 .79722 m .48224 .79814 L .4821 .79609 L F
.48129 .79722 m .4821 .79609 L .48207 .79563 L F
.85 .989 .851 r
.48072 .79801 m .48031 .79858 L .47999 .79859 L F
.779 .517 .539 r
.50433 .78506 m .50784 .78519 L .50782 .78754 L F
.819 .493 .437 r
.50784 .78519 m .50559 .78455 L .50777 .78371 L F
.743 .604 .034 r
.50782 .78754 m .50784 .78519 L .50777 .78371 L F
0 .289 .788 r
.54647 .63603 m .54647 .63427 L .54557 .63426 L F
.54647 .63603 m .54791 .63619 L .54647 .63427 L F
.54647 .63603 m .54818 .63736 L .54791 .63619 L F
.617 .507 .706 r
.26637 .61205 m .26881 .61185 L .26829 .60919 L F
.583 .553 .787 r
.26637 .61205 m .26976 .61488 L .26881 .61185 L F
.6 .348 .507 r
.59616 .62067 m .59615 .623 L .59372 .62298 L F
.612 .358 .508 r
.59616 .62067 m .59855 .62269 L .59615 .623 L F
.595 .363 .534 r
.59616 .62067 m .5987 .62045 L .59855 .62269 L F
0 .33 .814 r
.53352 .61774 m .53395 .61692 L .53281 .6163 L F
.192 .583 .941 r
.53352 .61774 m .535 .61797 L .53395 .61692 L F
.317 .794 .914 r
.47388 .63126 m .47554 .63065 L .47719 .62952 L F
.47388 .63126 m .47302 .63099 L .47554 .63065 L F
.288 .101 .444 r
.74726 .5045 m .7458 .50808 L .74732 .50668 L F
.092 0 .416 r
.7493 .50064 m .74726 .5045 L .74939 .50264 L F
.061 0 .429 r
.74726 .5045 m .74917 .50548 L .74939 .50264 L F
.74726 .5045 m .74732 .50668 L .74917 .50548 L F
.593 .323 .476 r
.60245 .56011 m .60009 .56369 L .59773 .56368 L F
.742 .519 .592 r
.60342 .561 m .60009 .56369 L .60245 .56011 L F
0 0 0 r
.47118 .65099 m .46867 .65347 L .46998 .65183 L F
.849 .759 .764 r
.66847 .5156 m .66877 .51183 L .67037 .5133 L F
.573 .357 .549 r
.59164 .54913 m .5941 .5465 L .59184 .54707 L F
.398 .166 .442 r
.58952 .54993 m .59164 .54913 L .59184 .54707 L F
.617 .171 .169 r
.28977 .63807 m .28847 .63943 L .28609 .63899 L F
0 0 0 r
.29031 .63836 m .28977 .63807 L .29136 .63788 L F
.29031 .63836 m .28847 .63943 L .28977 .63807 L F
.519 .825 1 r
.47251 .6682 m .47027 .66875 L .47383 .66904 L F
.98 .775 .557 r
.47251 .6682 m .47383 .66904 L .4731 .66588 L F
.813 .779 .821 r
.67508 .50766 m .67103 .50899 L .6736 .5063 L F
.803 .812 .859 r
.67755 .50524 m .67508 .50766 L .6736 .5063 L F
.054 .537 .889 r
.64304 .48961 m .64317 .48951 L .6445 .49043 L F
.703 .376 .42 r
.64317 .48951 m .64715 .48947 L .6445 .49043 L F
.755 .758 .855 r
.29454 .64639 m .29411 .64772 L .29659 .6455 L F
.121 0 .089 r
.58689 .55239 m .58879 .5518 L .58952 .54993 L F
.316 .01 .277 r
.59093 .55134 m .58952 .54993 L .58879 .5518 L F
.59093 .55134 m .59164 .54913 L .58952 .54993 L F
.363 0 0 r
.55095 .76233 m .54902 .76269 L .54701 .76233 L F
.55095 .76233 m .54902 .76269 L .54701 .76233 L F
.878 .923 .851 r
.55095 .76233 m .54902 .76269 L .55204 .75932 L F
.821 .441 .335 r
.55095 .76233 m .54972 .76363 L .54902 .76269 L F
.55095 .76233 m .55279 .76507 L .54972 .76363 L F
.696 .433 .522 r
.5529 .76252 m .55279 .76507 L .55095 .76233 L F
.838 .752 .769 r
.74553 .51555 m .74823 .51878 L .74666 .51765 L F
.822 .763 .797 r
.74823 .51878 m .74508 .51868 L .74666 .51765 L F
.118 .606 .911 r
.49728 .62012 m .50057 .62121 L .49863 .62076 L F
.32 .328 .712 r
.25821 .63726 m .25933 .63739 L .25853 .63354 L F
.624 .249 .313 r
.56237 .60442 m .5642 .60538 L .56529 .60338 L F
.742 .602 .701 r
.5642 .60538 m .56726 .6026 L .56529 .60338 L F
.613 .826 .982 r
.52863 .64077 m .52696 .64141 L .5256 .64034 L F
0 .205 .732 r
.52854 .61183 m .53055 .615 L .53076 .61389 L F
.048 .382 .846 r
.53055 .615 m .53281 .6163 L .53076 .61389 L F
.557 .377 .594 r
.70931 .4791 m .71138 .47657 L .70961 .47591 L F
.881 .821 .785 r
.57033 .63752 m .56931 .6399 L .57097 .64053 L F
.927 .639 .476 r
.56931 .6399 m .56957 .64226 L .57097 .64053 L F
.714 .321 .303 r
.57097 .64053 m .56957 .64226 L .57349 .64249 L F
.783 .645 .709 r
.56559 .59184 m .56951 .59229 L .56706 .59546 L F
.63 .427 .589 r
.56951 .59229 m .56971 .59498 L .56706 .59546 L F
.762 .919 .547 r
.57132 .58939 m .57004 .59078 L .56951 .59229 L F
.751 .565 0 r
.56944 .59267 m .56951 .59229 L .57004 .59078 L F
.56944 .59267 m .56971 .59498 L .56951 .59229 L F
.357 .146 .45 r
.60299 .59803 m .60475 .59731 L .60516 .59509 L F
.4 .235 .539 r
.60304 .6004 m .60475 .59731 L .60299 .59803 L F
0 0 0 r
.45415 .66509 m .45206 .66618 L .45256 .66553 L F
.45 .52 .838 r
.40176 .6002 m .39991 .60092 L .39831 .59747 L F
.273 .071 .413 r
.39955 .60314 m .39991 .60092 L .40176 .6002 L F
.211 .025 .396 r
.36302 .61365 m .36522 .61068 L .36392 .61226 L F
.58 .783 .976 r
.71025 .46698 m .7117 .46519 L .70983 .46571 L F
.71025 .46698 m .71187 .46643 L .7117 .46519 L F
.519 .348 .589 r
.31202 .60877 m .30984 .61111 L .30993 .60925 L F
0 0 0 r
.52025 .69393 m .5218 .69366 L .5231 .69223 L F
.498 .023 .058 r
.5231 .69223 m .5218 .69366 L .52501 .69324 L F
.537 .247 .421 r
.59967 .54365 m .6021 .5434 L .60235 .54155 L F
.304 0 .193 r
.6021 .5434 m .60496 .54118 L .60235 .54155 L F
.22 .742 .822 r
.44392 .69721 m .44593 .69688 L .44742 .69684 L F
.204 0 0 r
.44742 .69684 m .44593 .69688 L .44959 .6971 L F
.428 .495 .826 r
.30763 .61969 m .30743 .62319 L .30555 .6203 L F
.30763 .61969 m .30904 .62299 L .30743 .62319 L F
.543 .257 .43 r
.5941 .5465 m .59658 .54617 L .59728 .5437 L F
.527 .214 .38 r
.59658 .54617 m .59967 .54365 L .59728 .5437 L F
.484 .259 .496 r
.55521 .76434 m .55279 .76507 L .5529 .76252 L F
.718 .652 .783 r
.56706 .59546 m .56453 .59801 L .56331 .59471 L F
.616 .52 .723 r
.52228 .63663 m .52334 .64095 L .52008 .63887 L F
.26 .223 .626 r
.47161 .63383 m .47337 .63402 L .47302 .63099 L F
.368 .068 .318 r
.47161 .63383 m .47308 .6362 L .47337 .63402 L F
.47161 .63383 m .471 .63686 L .47308 .6362 L F
0 0 .284 r
.53455 .77852 m .53349 .77975 L .53407 .77824 L F
0 0 0 r
.53196 .78179 m .53349 .77975 L .53455 .77852 L F
.556 .808 .992 r
.49383 .61987 m .49288 .62146 L .49162 .62058 L F
.49383 .61987 m .49516 .62095 L .49288 .62146 L F
.667 .756 .917 r
.65419 .50876 m .65669 .50941 L .65512 .50827 L F
.301 0 0 r
.46038 .70367 m .45891 .70501 L .45673 .70526 L F
.383 0 0 r
.46246 .70418 m .45891 .70501 L .46038 .70367 L F
.181 0 0 r
.44959 .6971 m .45203 .69755 L .45343 .69769 L F
0 .42 .838 r
.45447 .69754 m .45343 .69769 L .45203 .69755 L F
.325 0 0 r
.45343 .69769 m .45504 .69814 L .45587 .69728 L F
0 .42 .838 r
.45447 .69754 m .45504 .69814 L .45343 .69769 L F
.549 .453 .699 r
.26746 .60358 m .26959 .60312 L .26917 .6007 L F
.466 .378 .672 r
.26746 .60358 m .26977 .60557 L .26959 .60312 L F
.26746 .60358 m .26774 .60728 L .26977 .60557 L F
.64 .557 .745 r
.26976 .61488 m .27077 .61824 L .27302 .61781 L F
.626 .486 .672 r
.27077 .61824 m .27096 .62055 L .27302 .61781 L F
.847 .894 .871 r
.63657 .51212 m .64024 .51048 L .63873 .50893 L F
0 .057 .623 r
.74525 .47793 m .74527 .47893 L .7438 .47574 L F
0 .328 .808 r
.74699 .47925 m .74527 .47893 L .74525 .47793 L F
.74699 .47925 m .74785 .48057 L .74527 .47893 L F
.938 .961 .745 r
.57188 .58545 m .57132 .58939 L .57358 .58678 L F
.57188 .58545 m .57067 .58855 L .57132 .58939 L F
.988 .877 .531 r
.57067 .58855 m .57004 .59078 L .57132 .58939 L F
.71 .885 .962 r
.27925 .63199 m .27966 .6324 L .28162 .63095 L F
.372 .144 .434 r
.27966 .6324 m .28116 .63374 L .28344 .63086 L F
0 .053 .548 r
.27925 .63199 m .28116 .63374 L .27966 .6324 L F
.465 .343 .629 r
.28162 .63095 m .27966 .6324 L .28344 .63086 L F
.72 .621 .746 r
.7011 .46693 m .70219 .47046 L .7045 .46769 L F
.485 .12 .27 r
.50836 .65186 m .50718 .65412 L .50502 .65414 L F
.084 .219 .707 r
.50712 .64619 m .50809 .64493 L .50607 .64273 L F
.535 .346 .572 r
.50712 .64619 m .50964 .64769 L .50809 .64493 L F
.50712 .64619 m .50719 .64871 L .50964 .64769 L F
.637 .281 .35 r
.51049 .65372 m .50718 .65412 L .50836 .65186 L F
.628 .285 .371 r
.51097 .65212 m .51049 .65372 L .50836 .65186 L F
.46 .422 .73 r
.30742 .61721 m .30499 .61581 L .30678 .61376 L F
.30742 .61721 m .30583 .61764 L .30499 .61581 L F
.138 .643 .904 r
.32741 .58455 m .33092 .58532 L .32873 .58537 L F
.961 .93 .716 r
.27765 .63072 m .27703 .63492 L .27925 .63199 L F
.27765 .63072 m .276 .63425 L .27703 .63492 L F
.706 .645 .786 r
.27925 .63199 m .27703 .63492 L .28009 .63446 L F
.523 .277 .483 r
.27703 .63492 m .27963 .63513 L .28009 .63446 L F
.27703 .63492 m .27689 .63706 L .27963 .63513 L F
.069 0 0 r
.49205 .80663 m .49517 .80518 L .49426 .80603 L F
0 0 0 r
.49426 .80603 m .49517 .80518 L .49639 .80437 L F
.547 .858 .997 r
.49639 .80437 m .498 .80486 L .49517 .80518 L F
.49517 .80518 m .498 .80486 L .49639 .80437 L F
.488 .456 .748 r
.62977 .5039 m .63105 .50061 L .62865 .50087 L F
.62977 .5039 m .63183 .50363 L .63105 .50061 L F
.47 .074 .205 r
.47864 .69653 m .48118 .69627 L .4822 .69446 L F
.72 .566 .681 r
.48118 .69627 m .48364 .69499 L .4822 .69446 L F
.541 .336 .551 r
.58542 .66604 m .58528 .66843 L .58291 .66884 L F
0 0 .381 r
.58579 .66318 m .58542 .66604 L .58637 .66256 L F
.58579 .66318 m .58632 .66468 L .58542 .66604 L F
.104 .266 .745 r
.58632 .66468 m .58754 .66794 L .58542 .66604 L F
.505 .306 .544 r
.58542 .66604 m .58754 .66794 L .58528 .66843 L F
.466 .203 .43 r
.38763 .61264 m .38716 .61468 L .38499 .61513 L F
.477 .228 .457 r
.38977 .61203 m .38716 .61468 L .38763 .61264 L F
.649 .719 .9 r
.69763 .49125 m .69433 .49026 L .69672 .48939 L F
.61 .738 .936 r
.69909 .48902 m .69763 .49125 L .69672 .48939 L F
.69909 .48902 m .7002 .49065 L .69763 .49125 L F
.598 .583 .807 r
.49205 .80663 m .49295 .80365 L .49103 .80416 L F
.49205 .80663 m .49426 .80603 L .49295 .80365 L F
.422 .52 .852 r
.75222 .48697 m .75533 .48832 L .75372 .49015 L F
.346 .403 .778 r
.75533 .48832 m .75636 .49179 L .75372 .49015 L F
.386 .138 .412 r
.35608 .61798 m .35772 .61943 L .35842 .61763 L F
.35608 .61798 m .3558 .62004 L .35772 .61943 L F
.826 .728 .757 r
.6685 .47841 m .66497 .4807 L .66732 .47895 L F
.6685 .47841 m .6667 .48158 L .66497 .4807 L F
.617 .457 .643 r
.6685 .47841 m .67098 .47867 L .67085 .47608 L F
0 0 0 r
.66732 .47895 m .67098 .47867 L .6685 .47841 L F
.91 .583 .412 r
.47584 .6519 m .47463 .65367 L .47482 .65201 L F
.249 0 .006 r
.47694 .65296 m .47584 .6519 L .4782 .65185 L F
.47683 .65305 m .47463 .65367 L .47584 .6519 L F
.672 .606 .773 r
.47319 .65013 m .47629 .65302 L .47546 .64915 L F
.47629 .65302 m .47637 .6531 L .47635 .65301 L F
.47629 .65302 m .47635 .65301 L .47546 .64915 L F
.249 0 .006 r
.47683 .65305 m .47676 .65297 L .47694 .65296 L F
.47676 .65297 m .47584 .6519 L .47694 .65296 L F
.607 .595 .813 r
.66077 .49856 m .6643 .5017 L .66314 .49798 L F
.745 .686 .795 r
.66665 .49872 m .6643 .5017 L .66314 .49798 L F
.814 .641 .667 r
.57223 .6115 m .5742 .61499 L .57451 .61244 L F
.877 .818 .787 r
.72752 .50465 m .72682 .50779 L .72422 .50648 L F
.864 .826 .808 r
.72422 .50648 m .72682 .50779 L .72449 .50971 L F
.371 .019 .231 r
.36146 .61457 m .36247 .61633 L .36302 .61365 L F
.36146 .61457 m .36043 .61686 L .36247 .61633 L F
.533 .359 .591 r
.60688 .53557 m .60914 .53502 L .60911 .53258 L F
.553 .342 .548 r
.60688 .53557 m .60924 .53739 L .60914 .53502 L F
.60688 .53557 m .60687 .53787 L .60924 .53739 L F
.947 .889 .741 r
.52783 .60393 m .52556 .60484 L .52655 .60293 L F
.52783 .60393 m .52631 .60709 L .52556 .60484 L F
.869 .907 .855 r
.52873 .60052 m .52783 .60393 L .52655 .60293 L F
.52873 .60052 m .53003 .60134 L .52783 .60393 L F
.201 0 .09 r
.58419 .55499 m .58617 .5542 L .58689 .55239 L F
.216 0 .336 r
.58847 .55364 m .58689 .55239 L .58617 .5542 L F
.58847 .55364 m .58879 .5518 L .58689 .55239 L F
.151 0 0 r
.34343 .62681 m .34238 .62781 L .34556 .62619 L F
.354 .344 .709 r
.68352 .47798 m .68533 .48144 L .68519 .4794 L F
.68352 .47798 m .68519 .4794 L .68515 .47938 L F
.344 .338 .709 r
.68758 .47954 m .68644 .4805 L .68352 .47798 L F
.68514 .47937 m .68533 .48144 L .68352 .47798 L F
.68515 .47938 m .68515 .47939 L .68514 .47937 L F
.68515 .47939 m .68533 .48144 L .68514 .47937 L F
.629 .376 .516 r
.68517 .47941 m .68276 .48292 L .68055 .48077 L F
.68519 .4794 m .68518 .47942 L .68517 .47941 L F
.68518 .47942 m .68276 .48292 L .68517 .47941 L F
.646 .417 .557 r
.68515 .47938 m .68017 .4787 L .68264 .47846 L F
.68519 .4794 m .68516 .4794 L .68515 .47938 L F
.68516 .4794 m .68017 .4787 L .68515 .47938 L F
.344 .338 .709 r
.68644 .4805 m .68629 .48063 L .68515 .47938 L F
.68629 .48063 m .68533 .48144 L .68515 .47938 L F
.354 .344 .709 r
.68352 .47798 m .68515 .47938 L .68264 .47846 L F
.344 .338 .709 r
.68758 .47954 m .68352 .47798 L .68861 .478 L F
.574 .347 .534 r
.5905 .62358 m .59058 .6256 L .58814 .62613 L F
.59 .347 .517 r
.59372 .62298 m .59058 .6256 L .5905 .62358 L F
.091 .508 .903 r
.49849 .80426 m .498 .80486 L .49639 .80437 L F
0 .197 .727 r
.498 .80486 m .49849 .80426 L .49639 .80437 L F
.498 .80486 m .49948 .80685 L .49849 .80426 L F
.906 .812 .744 r
.62887 .55541 m .62818 .55245 L .62733 .55462 L F
.903 .705 .625 r
.62598 .55742 m .62887 .55541 L .62733 .55462 L F
.62598 .55742 m .62852 .55784 L .62887 .55541 L F
.579 .944 .858 r
.4871 .62168 m .4881 .6206 L .48926 .6211 L F
.4871 .62168 m .48543 .62205 L .4881 .6206 L F
.866 .667 .631 r
.55722 .76148 m .56017 .75936 L .55865 .75831 L F
.55722 .76148 m .55912 .76238 L .56017 .75936 L F
.751 .641 .739 r
.57414 .6182 m .57109 .61583 L .57056 .61692 L F
.57414 .6182 m .5742 .61499 L .57109 .61583 L F
.864 .533 .422 r
.57056 .61692 m .57382 .6197 L .57414 .6182 L F
.105 .391 .847 r
.53709 .62061 m .5374 .61937 L .535 .61797 L F
.05 .609 .807 r
.36317 .58851 m .3668 .58889 L .36474 .58879 L F
.505 .323 .568 r
.68055 .48077 m .67782 .48159 L .68017 .4787 L F
.554 .334 .536 r
.68055 .48077 m .67776 .48339 L .67782 .48159 L F
.416 .569 .898 r
.38752 .59392 m .38653 .5958 L .38562 .59405 L F
.38752 .59392 m .38929 .59646 L .38653 .5958 L F
.772 .672 .752 r
.58331 .65895 m .58167 .66317 L .57983 .66174 L F
.624 .331 .452 r
.58291 .66884 m .58528 .67088 L .58291 .67062 L F
.545 .349 .565 r
.58528 .66843 m .58528 .67088 L .58291 .66884 L F
.287 .502 .891 r
.45452 .68834 m .45676 .68907 L .45539 .68705 L F
.45539 .68705 m .45676 .68907 L .45452 .68834 L F
0 0 .307 r
.53924 .62369 m .53979 .62486 L .53789 .62284 L F
.53924 .62369 m .54024 .62607 L .53979 .62486 L F
.227 .669 .954 r
.31832 .62694 m .32227 .6281 L .32015 .62824 L F
.726 .591 .705 r
.26913 .66306 m .27186 .66364 L .27003 .66235 L F
.26913 .66306 m .26862 .66541 L .27186 .66364 L F
.645 .806 .96 r
.27003 .66235 m .27186 .66364 L .2737 .66273 L F
.217 0 0 r
.45218 .70538 m .45079 .70575 L .44864 .70571 L F
.179 0 0 r
.45443 .70564 m .45079 .70575 L .45218 .70538 L F
.058 .15 .645 r
.72861 .48128 m .73094 .48534 L .7304 .48086 L F
.951 .621 .359 r
.65296 .49083 m .65384 .49273 L .6524 .49173 L F
.799 .867 .426 r
.65296 .49083 m .6524 .49173 L .65383 .48809 L F
.951 .621 .359 r
.65296 .49083 m .65384 .49273 L .6524 .49173 L F
.508 .6 .881 r
.71159 .50197 m .71539 .50455 L .7144 .50286 L F
.664 .712 .884 r
.71539 .50455 m .71698 .50089 L .7144 .50286 L F
.71539 .50455 m .71772 .50374 L .71698 .50089 L F
0 .177 .704 r
.54156 .62918 m .54218 .62805 L .54024 .62607 L F
.17 .294 .749 r
.54246 .63154 m .54218 .62805 L .54156 .62918 L F
.749 .661 .763 r
.41597 .70513 m .41837 .70216 L .41571 .70191 L F
.497 .035 .087 r
.41837 .70216 m .41513 .70236 L .41571 .70191 L F
.737 .991 .826 r
.68184 .49917 m .68304 .49728 L .68378 .49788 L F
.68184 .49917 m .68019 .49967 L .68304 .49728 L F
0 0 0 r
.54889 .78313 m .55096 .78244 L .54947 .78159 L F
.54889 .78313 m .54855 .78336 L .55096 .78244 L F
.444 .239 .506 r
.30583 .61764 m .30555 .6203 L .30361 .62046 L F
0 0 0 r
.32846 .64739 m .33259 .64574 L .33089 .64699 L F
.247 0 0 r
.33481 .64511 m .33089 .64699 L .33259 .64574 L F
.849 .759 .764 r
.66847 .5156 m .66667 .51504 L .66877 .51183 L F
.177 .306 .759 r
.28009 .63446 m .28116 .63374 L .27925 .63199 L F
0 0 0 r
.28009 .63446 m .27963 .63513 L .28116 .63374 L F
.558 .271 .436 r
.50553 .65229 m .50502 .65414 L .50259 .65441 L F
.629 .547 .744 r
.50553 .65229 m .50719 .64871 L .50557 .65029 L F
.598 .451 .653 r
.59842 .61791 m .60081 .61745 L .5987 .62045 L F
.686 .526 .665 r
.29385 .64295 m .29659 .6455 L .29564 .64218 L F
.29385 .64295 m .29454 .64639 L .29659 .6455 L F
0 .523 .808 r
.53468 .65158 m .53371 .65121 L .53205 .65089 L F
.521 .754 .981 r
.54147 .76299 m .54225 .76122 L .54131 .76076 L F
.54147 .76299 m .54371 .76258 L .54225 .76122 L F
.847 .777 .783 r
.68283 .50896 m .6864 .50723 L .6851 .50601 L F
.68283 .50896 m .68425 .5102 L .6864 .50723 L F
.802 .825 .869 r
.6851 .50601 m .6864 .50723 L .68887 .5047 L F
.594 .677 .899 r
.54979 .78318 m .55378 .78348 L .55302 .78139 L F
.781 .649 .716 r
.55406 .60569 m .55372 .60783 L .55102 .60603 L F
0 .562 .715 r
.55452 .6081 m .55102 .60603 L .55372 .60783 L F
.907 .707 .621 r
.62932 .54639 m .62996 .54681 L .62876 .54353 L F
.863 .68 .653 r
.62677 .54872 m .62996 .54681 L .62932 .54639 L F
.62677 .54872 m .62863 .55032 L .62996 .54681 L F
.781 .649 .716 r
.55406 .60569 m .55081 .60352 L .55301 .60303 L F
.55406 .60569 m .55102 .60603 L .55081 .60352 L F
.765 .71 .8 r
.55669 .60308 m .55406 .60569 L .55301 .60303 L F
.058 0 0 r
.48103 .70251 m .48107 .70255 L .47763 .70249 L F
.419 .777 .996 r
.48103 .70251 m .48342 .70238 L .48189 .70165 L F
0 0 0 r
.48189 .70165 m .48107 .70255 L .48103 .70251 L F
.805 .626 .659 r
.6108 .56411 m .60698 .56602 L .607 .56392 L F
.6108 .56411 m .61057 .56656 L .60698 .56602 L F
.697 .767 .906 r
.70358 .49117 m .7002 .49065 L .70265 .48984 L F
.517 .61 .884 r
.7049 .48885 m .70358 .49117 L .70265 .48984 L F
.7049 .48885 m .70638 .49175 L .70358 .49117 L F
.581 .818 .989 r
.27265 .65925 m .27386 .66031 L .27019 .65993 L F
.27019 .65993 m .27386 .66031 L .27265 .65925 L F
0 0 .26 r
.6523 .49559 m .6524 .49173 L .65384 .49273 L F
.979 .789 .577 r
.62769 .56609 m .62809 .56397 L .62686 .563 L F
.95 .798 .658 r
.62809 .56397 m .62721 .56097 L .62686 .563 L F
.363 .46 .826 r
.57475 .5827 m .57618 .5859 L .57453 .5853 L F
.532 .475 .738 r
.75735 .51152 m .75828 .51512 L .75617 .51573 L F
.35 .118 .415 r
.75832 .51699 m .75617 .51573 L .75828 .51512 L F
.75832 .51699 m .75575 .51793 L .75617 .51573 L F
.499 .222 .424 r
.37503 .62327 m .37441 .62575 L .37215 .62615 L F
.439 .167 .402 r
.37661 .62518 m .37503 .62327 L .37721 .6228 L F
.37661 .62518 m .37441 .62575 L .37503 .62327 L F
.43 .097 .298 r
.67342 .47845 m .67645 .47544 L .67311 .47586 L F
.67342 .47845 m .67574 .47805 L .67645 .47544 L F
.544 .201 .336 r
.67645 .47544 m .67886 .4772 L .67905 .47496 L F
.67645 .47544 m .67574 .47805 L .67886 .4772 L F
.928 .765 .658 r
.73012 .49905 m .7296 .50151 L .7286 .49812 L F
.494 .63 .913 r
.36717 .60072 m .36858 .59939 L .3667 .59992 L F
.36717 .60072 m .36908 .60036 L .36858 .59939 L F
.075 .551 .899 r
.41991 .65937 m .42138 .66044 L .41823 .6592 L F
.977 .678 .364 r
.41991 .65937 m .421 .66188 L .42138 .66044 L F
.582 .3 .455 r
.42352 .66242 m .42138 .66044 L .421 .66188 L F
.42352 .66242 m .42405 .66023 L .42138 .66044 L F
.258 0 .201 r
.57916 .5604 m .58185 .55801 L .57941 .55848 L F
.436 .19 .442 r
.27699 .62554 m .27839 .62699 L .27892 .62487 L F
.665 .839 .424 r
.27716 .62535 m .27622 .62673 L .27651 .6257 L F
.436 .19 .442 r
.27651 .6257 m .27678 .62588 L .27699 .62554 L F
.27678 .62588 m .27839 .62699 L .27699 .62554 L F
.665 .839 .424 r
.27716 .62535 m .27535 .62842 L .27601 .62713 L F
.27661 .62615 m .27601 .62713 L .27622 .62673 L F
.27716 .62535 m .27601 .62713 L .27661 .62615 L F
.508 .16 .313 r
.52175 .69988 m .52062 .70249 L .51836 .70256 L F
.523 .176 .32 r
.524 .70118 m .52175 .69988 L .52406 .69957 L F
.524 .70118 m .52062 .70249 L .52175 .69988 L F
.627 .618 .821 r
.30606 .64627 m .30977 .64844 L .30778 .64614 L F
.362 .603 .94 r
.30977 .64844 m .31112 .64735 L .30778 .64614 L F
.448 .602 .911 r
.384 .59164 m .38373 .59414 L .38186 .59215 L F
.384 .59164 m .38562 .59405 L .38373 .59414 L F
.588 .613 .844 r
.57543 .63495 m .57954 .63765 L .57791 .6343 L F
.59 .569 .798 r
.5814 .63289 m .58257 .63592 L .58015 .63627 L F
.5814 .63289 m .58015 .63627 L .57887 .63332 L F
.238 .386 .81 r
.57887 .63332 m .5814 .63488 L .58015 .63627 L F
.96 .671 .242 r
.5814 .63488 m .58103 .63516 L .58015 .63627 L F
.085 .278 .762 r
.57791 .6343 m .57935 .63727 L .58015 .63627 L F
.57791 .6343 m .58015 .63627 L .57911 .63388 L F
0 0 .285 r
.57911 .63388 m .58015 .63627 L .57887 .63332 L F
.322 .665 .974 r
.57791 .6343 m .57911 .63388 L .57887 .63332 L F
.758 .685 .781 r
.58015 .63627 m .57675 .6364 L .57887 .63332 L F
.639 .906 .983 r
.57702 .63601 m .57776 .63458 L .57887 .63332 L F
.57675 .6364 m .57694 .63605 L .57702 .63601 L F
.57694 .63605 m .57776 .63458 L .57702 .63601 L F
.57675 .6364 m .57543 .63553 L .57776 .63458 L F
.207 0 0 r
.58015 .63627 m .57586 .63607 L .57675 .6364 L F
.58015 .63627 m .57837 .63634 L .57675 .63616 L F
.58015 .63627 m .57936 .63644 L .57837 .63634 L F
.57684 .63611 m .57675 .63616 L .57586 .63607 L F
.58015 .63627 m .57675 .63616 L .57684 .63611 L F
.96 .671 .242 r
.58103 .63516 m .57936 .63644 L .58015 .63627 L F
.085 .278 .762 r
.57935 .63727 m .57954 .63765 L .58015 .63627 L F
.149 .183 .641 r
.57955 .63971 m .58015 .63627 L .57954 .63765 L F
.658 .408 .53 r
.6667 .48158 m .66291 .48421 L .66497 .4807 L F
.6667 .48158 m .66652 .48427 L .66291 .48421 L F
.731 .472 .535 r
.66848 .484 m .66652 .48427 L .6667 .48158 L F
.757 .569 .643 r
.63039 .53013 m .63006 .53273 L .63234 .53164 L F
.424 .724 .988 r
.32369 .62836 m .32292 .62965 L .32227 .6281 L F
.32369 .62836 m .32631 .63036 L .32292 .62965 L F
.967 .875 .691 r
.72267 .49313 m .72437 .49292 L .72338 .49184 L F
.72267 .49313 m .72382 .49454 L .72437 .49292 L F
0 0 .087 r
.60516 .59509 m .60564 .59585 L .60581 .59359 L F
.60516 .59509 m .60475 .59731 L .60564 .59585 L F
.707 .528 .644 r
.57759 .61775 m .57539 .62041 L .57806 .62038 L F
.602 .435 .628 r
.57759 .61775 m .5801 .61747 L .57987 .61488 L F
.424 .231 .513 r
.57806 .62038 m .5801 .61747 L .57759 .61775 L F
.776 .817 .885 r
.69527 .46924 m .69902 .4683 L .69768 .468 L F
.894 .838 .782 r
.69888 .47077 m .69558 .47155 L .69768 .468 L F
.516 0 0 r
.69888 .47077 m .69804 .47202 L .69558 .47155 L F
.97 .84 .659 r
.69768 .468 m .69888 .47077 L .69902 .4683 L F
0 0 .482 r
.7001 .46813 m .69888 .47077 L .69768 .468 L F
.7001 .46813 m .70048 .4713 L .69888 .47077 L F
.132 0 0 r
.70048 .4713 m .69804 .47202 L .69888 .47077 L F
.473 .199 .417 r
.36909 .62933 m .36735 .62867 L .3695 .62822 L F
.36909 .62933 m .36725 .63038 L .36735 .62867 L F
.73 .579 .686 r
.54027 .65295 m .5439 .65284 L .54389 .65251 L F
.6 .641 .863 r
.54659 .65129 m .54609 .65228 L .54389 .65251 L F
.54659 .65129 m .54389 .65251 L .5439 .65284 L F
.823 .886 .889 r
.26182 .63236 m .25853 .63354 L .26034 .63373 L F
.738 .406 .421 r
.26034 .63373 m .2635 .63207 L .26182 .63236 L F
.548 .32 .522 r
.60358 .6153 m .60601 .61689 L .60337 .61716 L F
.60358 .6153 m .60633 .61462 L .60601 .61689 L F
.509 .017 .024 r
.52501 .69324 m .52738 .69343 L .52885 .69226 L F
.642 .178 .135 r
.52738 .69343 m .53063 .69377 L .52885 .69226 L F
.957 .844 .421 r
.60933 .57997 m .60899 .58374 L .60853 .58205 L F
.906 .87 .434 r
.60899 .58374 m .60808 .58508 L .60853 .58205 L F
.60899 .58374 m .60823 .58591 L .60808 .58508 L F
0 0 .432 r
.72795 .46948 m .72941 .472 L .72933 .4723 L F
.823 .352 0 r
.72748 .47048 m .72941 .472 L .72795 .46948 L F
.832 .495 .417 r
.72748 .47048 m .72945 .47182 L .72941 .472 L F
.72945 .47182 m .73128 .47306 L .72941 .472 L F
0 0 .432 r
.72933 .4723 m .72941 .472 L .72939 .47242 L F
0 .242 .743 r
.73128 .47306 m .72939 .47242 L .72941 .472 L F
.73128 .47306 m .7319 .47429 L .72976 .4727 L F
.153 0 0 r
.72927 .4728 m .73151 .47311 L .73128 .47306 L F
.198 .659 .942 r
.73128 .47306 m .73279 .47329 L .73393 .474 L F
.153 0 0 r
.73151 .47311 m .73279 .47329 L .73128 .47306 L F
0 .242 .743 r
.73128 .47306 m .72976 .4727 L .72939 .47242 L F
.749 .661 .763 r
.41597 .70513 m .4193 .70588 L .41837 .70216 L F
.125 .233 .706 r
.4193 .70588 m .42077 .70494 L .41837 .70216 L F
.257 .511 .904 r
.4193 .70588 m .42242 .70783 L .42077 .70494 L F
.558 .137 .198 r
.48675 .78237 m .4861 .78339 L .48342 .78316 L F
.663 .632 .808 r
.48787 .7789 m .48675 .78237 L .4857 .77978 L F
.48787 .7789 m .48918 .78205 L .48675 .78237 L F
.92 .669 .542 r
.48918 .78205 m .4861 .78339 L .48675 .78237 L F
.443 0 0 r
.53483 .64276 m .53782 .6436 L .536 .64371 L F
.505 .485 .768 r
.53886 .64536 m .536 .64371 L .53782 .6436 L F
.91 .534 .298 r
.56664 .66322 m .56469 .66242 L .56345 .65934 L F
.985 .712 .413 r
.56664 .66322 m .56537 .66452 L .56469 .66242 L F
.56664 .66322 m .56659 .66555 L .56537 .66452 L F
.655 .573 .751 r
.56889 .66046 m .57028 .66304 L .56664 .66322 L F
.658 .405 .526 r
.56967 .66492 m .56664 .66322 L .57028 .66304 L F
.56967 .66492 m .56659 .66555 L .56664 .66322 L F
.395 0 .15 r
.44276 .65304 m .44564 .65163 L .44327 .6517 L F
.62 .622 .832 r
.75729 .50736 m .7535 .50481 L .75711 .50709 L F
.378 .842 .872 r
.75968 .50664 m .75729 .50736 L .75711 .50709 L F
.071 0 0 r
.75687 .50817 m .75729 .50736 L .75968 .50664 L F
.378 .842 .872 r
.75968 .50664 m .75711 .50709 L .7584 .50573 L F
.071 0 0 r
.75634 .50846 m .75649 .50829 L .75687 .50817 L F
.75649 .50829 m .75729 .50736 L .75687 .50817 L F
.75634 .50846 m .75968 .50664 L .7584 .50573 L F
.533 .345 .572 r
.76058 .50631 m .75943 .50738 L .7584 .50573 L F
.75943 .50738 m .75884 .50794 L .75877 .50758 L F
.75943 .50738 m .75877 .50758 L .7584 .50573 L F
.729 .657 .779 r
.54198 .64807 m .5439 .65284 L .54027 .65295 L F
.598 .588 .813 r
.54659 .65129 m .5439 .65284 L .54198 .64807 L F
.376 .464 .823 r
.51773 .65446 m .52048 .65345 L .51642 .65133 L F
.781 .847 .392 r
.52022 .65464 m .52048 .65345 L .51773 .65446 L F
.485 .57 .866 r
.71135 .50038 m .71159 .50197 L .71327 .50004 L F
.48 .563 .862 r
.71159 .50197 m .7144 .50286 L .71327 .50004 L F
0 .555 .713 r
.51231 .7918 m .51242 .7918 L .51378 .79188 L F
.983 .738 .487 r
.51378 .79188 m .51501 .79072 L .51493 .79194 L F
0 .555 .713 r
.51242 .7918 m .51599 .79198 L .51378 .79188 L F
.983 .738 .487 r
.51378 .79188 m .51493 .79194 L .51486 .79316 L F
.21 0 0 r
.44963 .667 m .44799 .66775 L .44563 .66797 L F
.434 0 0 r
.45138 .66771 m .44799 .66775 L .44963 .667 L F
.422 .082 .281 r
.45206 .66618 m .45138 .66771 L .44963 .667 L F
.392 0 .07 r
.51685 .69585 m .51905 .69568 L .52025 .69393 L F
.023 0 0 r
.52025 .69393 m .51905 .69568 L .5218 .69366 L F
.682 .5 .633 r
.55273 .61231 m .55523 .61238 L .55548 .60911 L F
.288 .591 .946 r
.55548 .60911 m .55658 .60857 L .55452 .6081 L F
.062 0 .055 r
.55523 .61238 m .55813 .60934 L .55548 .60911 L F
.559 .376 .59 r
.59018 .61136 m .58792 .60955 L .58796 .61202 L F
.59018 .61136 m .5901 .60893 L .58792 .60955 L F
.619 .062 0 r
.28197 .64373 m .28256 .64221 L .28097 .64262 L F
.28197 .64373 m .2836 .6453 L .28207 .64455 L F
.28197 .64373 m .28207 .64455 L .28256 .64221 L F
.837 .646 .644 r
.62857 .52938 m .63006 .53273 L .63039 .53013 L F
.277 .142 .511 r
.27224 .6403 m .2711 .64447 L .27223 .64293 L F
.599 .395 .576 r
.27224 .6403 m .27477 .64182 L .27461 .64017 L F
.27224 .6403 m .27223 .64293 L .27477 .64182 L F
0 0 0 r
.33677 .64477 m .3409 .64308 L .33908 .64402 L F
.33908 .64402 m .3409 .64308 L .34302 .64249 L F
.49 .401 .682 r
.43603 .6762 m .43413 .67993 L .43386 .67745 L F
.737 .216 0 r
.49561 .65127 m .49192 .64879 L .4951 .64893 L F
.464 .285 .553 r
.49795 .65022 m .4951 .64893 L .49784 .64908 L F
.49795 .65022 m .49561 .65127 L .4951 .64893 L F
.847 .853 .847 r
.73645 .50926 m .73973 .5077 L .73893 .50679 L F
0 .192 .674 r
.7422 .50691 m .73857 .50396 L .74121 .50588 L F
.661 .857 .974 r
.73973 .5077 m .74121 .50588 L .73893 .50679 L F
.73973 .5077 m .7422 .50691 L .74121 .50588 L F
.14 0 0 r
.50607 .64273 m .50245 .645 L .50356 .64363 L F
0 0 0 r
.54756 .65465 m .5461 .65664 L .54511 .65704 L F
.262 .661 .966 r
.54511 .65704 m .5461 .65664 L .54262 .65533 L F
.666 .86 .974 r
.75036 .52699 m .74783 .52792 L .74681 .52691 L F
.303 .393 .79 r
.7135 .48426 m .71517 .483 L .71268 .4815 L F
0 0 0 r
.7135 .48426 m .71326 .48542 L .71517 .483 L F
.31 .802 .828 r
.35384 .59923 m .35785 .5985 L .35606 .59892 L F
.047 0 0 r
.35785 .5985 m .35778 .59862 L .35606 .59892 L F
.639 .631 .826 r
.35785 .5985 m .363 .59947 L .35972 .59852 L F
.047 0 0 r
.35785 .5985 m .35972 .59852 L .35778 .59862 L F
.665 .86 .974 r
.5379 .5981 m .53425 .5981 L .53664 .59773 L F
.584 .163 .209 r
.53664 .59773 m .53927 .59718 L .5379 .5981 L F
.517 .271 .481 r
.58548 .61457 m .58796 .61202 L .58569 .61225 L F
.435 .73 .988 r
.32677 .6289 m .32631 .63036 L .32369 .62836 L F
.024 .227 .732 r
.58681 .65561 m .58624 .65743 L .58522 .65573 L F
.58681 .65561 m .58862 .65974 L .58624 .65743 L F
.709 .745 .879 r
.67961 .49139 m .68026 .49303 L .67695 .49262 L F
.246 0 0 r
.68026 .49303 m .67704 .49494 L .67695 .49262 L F
.68026 .49303 m .67947 .49428 L .67704 .49494 L F
.619 .694 .898 r
.68277 .49253 m .68026 .49303 L .67961 .49139 L F
.68277 .49253 m .67961 .49139 L .68177 .49122 L F
.169 .705 .744 r
.67755 .49472 m .67857 .49453 L .68177 .49122 L F
.67857 .49453 m .68185 .49393 L .67947 .49428 L F
.335 0 0 r
.68185 .49393 m .67941 .49437 L .67947 .49428 L F
.68185 .49393 m .67947 .49428 L .68026 .49303 L F
.169 .705 .744 r
.67947 .49428 m .68185 .49393 L .68184 .49362 L F
.335 0 0 r
.68185 .49393 m .68026 .49303 L .68277 .49253 L F
.169 .705 .744 r
.67857 .49453 m .68184 .49362 L .68177 .49122 L F
.246 0 0 r
.67947 .49428 m .67941 .49437 L .67755 .49482 L F
.67947 .49428 m .67755 .49482 L .67704 .49494 L F
.526 .085 .144 r
.69421 .46611 m .69788 .46464 L .69561 .46598 L F
.264 .447 .854 r
.31118 .62321 m .31108 .62536 L .30904 .62299 L F
.31118 .62321 m .31257 .6258 L .31108 .62536 L F
.98 .758 .53 r
.57313 .60904 m .57184 .60824 L .57163 .61075 L F
.528 .327 .552 r
.5801 .61747 m .58223 .61466 L .57987 .61488 L F
.522 .402 .656 r
.75613 .5043 m .75349 .50198 L .75445 .5012 L F
.75613 .5043 m .7535 .50481 L .75349 .50198 L F
.606 .417 .599 r
.60911 .53258 m .61178 .53463 L .61147 .532 L F
.60911 .53258 m .60914 .53502 L .61178 .53463 L F
0 0 .215 r
.5602 .65384 m .55973 .65192 L .55846 .65133 L F
.655 .381 .492 r
.42921 .65932 m .43197 .65726 L .42958 .6575 L F
.707 .585 .717 r
.26899 .6261 m .27019 .62921 L .27239 .62639 L F
.495 .421 .703 r
.26829 .60919 m .26977 .60557 L .26774 .60728 L F
.342 .806 .93 r
.5113 .77363 m .50742 .77382 L .51155 .7735 L F
.511 0 0 r
.51255 .77486 m .5113 .77363 L .51115 .77401 L F
0 0 0 r
.5113 .77363 m .51155 .7735 L .51115 .77401 L F
.511 0 0 r
.51255 .77486 m .51413 .77552 L .5113 .77363 L F
.626 .714 .91 r
.55884 .60297 m .56237 .60442 L .5598 .60498 L F
.408 .105 .335 r
.38656 .61638 m .38499 .61513 L .38716 .61468 L F
.38656 .61638 m .38441 .61695 L .38499 .61513 L F
.253 0 0 r
.39473 .59781 m .39831 .59747 L .39605 .59745 L F
.39509 .59777 m .39711 .59805 L .39831 .59747 L F
.39473 .59781 m .39711 .59805 L .39509 .59777 L F
.45 .52 .838 r
.40176 .6002 m .39831 .59747 L .40048 .5988 L F
.559 0 0 r
.39711 .59805 m .40048 .5988 L .39831 .59747 L F
.293 .473 .866 r
.39803 .59683 m .39869 .59827 L .39711 .59805 L F
.559 0 0 r
.39711 .59805 m .399 .59894 L .40048 .5988 L F
.293 .473 .866 r
.39869 .59827 m .399 .59894 L .39711 .59805 L F
.305 .582 .94 r
.39535 .59632 m .39705 .59799 L .39473 .59781 L F
.39705 .59799 m .39711 .59805 L .39473 .59781 L F
.213 0 0 r
.39343 .59771 m .39473 .59781 L .39605 .59745 L F
.39252 .5978 m .39473 .59781 L .39343 .59771 L F
.502 .288 .521 r
.30763 .61969 m .30583 .61764 L .30742 .61721 L F
.30763 .61969 m .30555 .6203 L .30583 .61764 L F
.169 .262 .717 r
.26881 .61185 m .26976 .61488 L .27058 .61327 L F
.342 .478 .852 r
.26976 .61488 m .27217 .61609 L .27058 .61327 L F
.64 .557 .745 r
.26976 .61488 m .27302 .61781 L .27217 .61609 L F
.368 .769 .985 r
.33501 .5853 m .33441 .58619 L .33324 .58496 L F
.33501 .5853 m .33652 .58601 L .33441 .58619 L F
.742 .519 .592 r
.60342 .561 m .60345 .56341 L .60009 .56369 L F
.447 .599 .909 r
.75183 .48441 m .74848 .48226 L .75223 .48325 L F
.099 .222 .705 r
.75296 .48342 m .75183 .48441 L .75223 .48325 L F
.221 .14 .547 r
.75413 .48505 m .75183 .48441 L .75296 .48342 L F
.75413 .48505 m .75222 .48697 L .75183 .48441 L F
.73 .812 .915 r
.70339 .46649 m .70574 .46665 L .70574 .46582 L F
.70574 .46665 m .70667 .46672 L .70574 .46582 L F
.541 .49 .749 r
.70574 .46582 m .7071 .46285 L .70495 .4622 L F
.70574 .46582 m .70495 .4622 L .70589 .46404 L F
.848 .843 .378 r
.70589 .46404 m .70574 .46458 L .70574 .46582 L F
.045 0 0 r
.70574 .46582 m .70549 .46604 L .70339 .46649 L F
.72 .621 .746 r
.70121 .46696 m .7045 .46769 L .70339 .46649 L F
.73 .812 .915 r
.70339 .46649 m .7045 .46769 L .70667 .46672 L F
.045 0 0 r
.70549 .46604 m .70291 .46836 L .70339 .46649 L F
.70569 .46587 m .70495 .46736 L .70291 .46836 L F
.70574 .46582 m .70495 .46736 L .70569 .46587 L F
.379 .168 .463 r
.70291 .46836 m .70495 .46736 L .70467 .46943 L F
.159 .202 .657 r
.70443 .46573 m .70458 .4681 L .70495 .46736 L F
.70458 .4681 m .70467 .46943 L .70495 .46736 L F
.848 .843 .378 r
.70574 .46458 m .70495 .46736 L .70574 .46582 L F
.72 .621 .746 r
.7011 .46693 m .70121 .46696 L .70339 .46649 L F
.666 .282 .309 r
.45483 .66419 m .45415 .66509 L .45158 .66308 L F
.147 0 0 r
.33455 .60038 m .33164 .60181 L .33103 .60129 L F
0 0 0 r
.33557 .60062 m .33455 .60038 L .33672 .6006 L F
.33557 .60062 m .33164 .60181 L .33455 .60038 L F
.042 .506 .886 r
.52406 .80201 m .52553 .80227 L .5242 .80128 L F
.5242 .80128 m .52553 .80227 L .52406 .80201 L F
.695 .665 .817 r
.3005 .64657 m .30119 .64246 L .29888 .64318 L F
.3005 .64657 m .30283 .64638 L .30119 .64246 L F
.624 .296 .395 r
.3005 .64657 m .30238 .64814 L .30283 .64638 L F
.83 .708 .73 r
.66053 .48856 m .66198 .49033 L .66384 .48869 L F
.66 .755 .92 r
.6664 .4869 m .66384 .48869 L .66397 .48748 L F
.707 .413 .475 r
.607 .56392 m .60345 .56588 L .60345 .56341 L F
.607 .56392 m .60698 .56602 L .60345 .56588 L F
.15 .463 .889 r
.53385 .64126 m .53331 .64234 L .53175 .64114 L F
.53385 .64126 m .53483 .64276 L .53331 .64234 L F
.656 .784 .942 r
.30283 .64638 m .30606 .64627 L .30513 .64492 L F
.26 .558 .932 r
.30513 .64492 m .30606 .64627 L .3067 .64515 L F
.366 .692 .982 r
.3067 .64515 m .30606 .64627 L .30778 .64614 L F
.546 .348 .564 r
.41531 .66265 m .41764 .6592 L .41538 .65987 L F
.804 .813 .858 r
.68002 .51213 m .68425 .5102 L .68283 .50896 L F
.329 .766 .967 r
.51835 .77948 m .51919 .78068 L .51686 .78132 L F
.51835 .77948 m .51816 .77885 L .51919 .78068 L F
.51835 .77948 m .52027 .77933 L .51816 .77885 L F
.823 .911 .899 r
.53149 .59976 m .53003 .60134 L .52873 .60052 L F
.396 .182 .467 r
.40908 .67137 m .41101 .67092 L .41129 .66872 L F
.39 .276 .602 r
.40908 .67137 m .41105 .67322 L .41101 .67092 L F
.40908 .67137 m .40924 .67401 L .41105 .67322 L F
.193 0 0 r
.34882 .63956 m .35162 .63828 L .35009 .6399 L F
.19 0 0 r
.34882 .63956 m .3494 .64076 L .34734 .64113 L F
.34882 .63956 m .35009 .6399 L .3494 .64076 L F
.36 .821 .923 r
.4362 .70909 m .4332 .70937 L .43489 .70869 L F
.082 0 0 r
.43531 .70893 m .43701 .70849 L .43489 .70869 L F
.257 0 0 r
.43489 .70869 m .43701 .70849 L .4362 .70909 L F
.341 0 0 r
.46603 .7032 m .46467 .70425 L .46246 .70418 L F
.529 .009 0 r
.46828 .70427 m .46467 .70425 L .46603 .7032 L F
.592 .818 .986 r
.45616 .66189 m .45742 .66299 L .45958 .66235 L F
.236 0 0 r
.35162 .63828 m .35263 .63901 L .35009 .6399 L F
.35162 .63828 m .35377 .63785 L .35263 .63901 L F
.617 .346 .485 r
.59489 .60607 m .59833 .60534 L .59818 .60338 L F
.666 .383 .482 r
.59833 .60534 m .60064 .60559 L .59818 .60338 L F
.64 .391 .526 r
.60064 .60559 m .60082 .60339 L .59818 .60338 L F
.642 .128 0 r
.50916 .77549 m .50981 .77661 L .50742 .77382 L F
.602 .053 0 r
.51121 .77739 m .50981 .77661 L .50916 .77549 L F
.078 0 0 r
.45384 .64642 m .4511 .64855 L .45293 .64764 L F
.401 .008 .174 r
.45384 .64642 m .45568 .64703 L .45601 .64608 L F
.45384 .64642 m .45293 .64764 L .45568 .64703 L F
.787 .757 .826 r
.54892 .65378 m .55012 .65672 L .54838 .65732 L F
.632 .32 .423 r
.55012 .65672 m .55058 .65828 L .54838 .65732 L F
.534 .599 .865 r
.55121 .65336 m .55012 .65672 L .54892 .65378 L F
.55121 .65336 m .55295 .65639 L .55012 .65672 L F
.481 .233 .46 r
.55295 .65639 m .55058 .65828 L .55012 .65672 L F
.694 .879 .967 r
.42862 .71125 m .43224 .71085 L .43107 .71034 L F
.877 .699 .658 r
.65943 .49512 m .65961 .49831 L .66077 .49856 L F
0 0 0 r
.65961 .49831 m .65842 .50152 L .66077 .49856 L F
.782 .659 .727 r
.63346 .50943 m .63381 .50985 L .63277 .50724 L F
.701 .506 .621 r
.63082 .51289 m .63381 .50985 L .63346 .50943 L F
.63082 .51289 m .63429 .51292 L .63381 .50985 L F
.693 .536 .668 r
.6388 .50691 m .63675 .50931 L .63873 .50893 L F
.63675 .50931 m .63646 .50965 L .63715 .50943 L F
.63675 .50931 m .63715 .50943 L .63873 .50893 L F
.133 0 .168 r
.63745 .5087 m .63646 .50965 L .63675 .50931 L F
.63745 .5087 m .63675 .50931 L .6388 .50691 L F
.633 .515 .702 r
.63316 .50822 m .63745 .5087 L .63277 .50724 L F
.63381 .50985 m .63613 .50912 L .63316 .50822 L F
.63613 .50912 m .63745 .5087 L .63316 .50822 L F
.63381 .50985 m .63646 .50965 L .63745 .5087 L F
.621 .451 .63 r
.63381 .50985 m .63657 .51212 L .63646 .50965 L F
.63381 .50985 m .63429 .51292 L .63657 .51212 L F
.989 .731 .371 r
.75412 .50915 m .75415 .51151 L .75518 .51166 L F
.786 .998 .841 r
.75518 .51166 m .75605 .50965 L .75735 .51152 L F
.75518 .51166 m .75415 .51151 L .75605 .50965 L F
.832 .793 .815 r
.69009 .50051 m .69148 .50169 L .69339 .50106 L F
.69009 .50051 m .69339 .50106 L .69262 .50096 L F
.913 .981 .751 r
.6946 .49708 m .69339 .50106 L .69557 .49862 L F
.6946 .49708 m .69262 .50096 L .69339 .50106 L F
0 0 0 r
.65961 .49831 m .65939 .49993 L .65842 .50152 L F
.245 .428 .844 r
.65939 .49993 m .6603 .50214 L .65842 .50152 L F
.239 0 0 r
.45504 .69814 m .45898 .69699 L .45587 .69728 L F
.45504 .69814 m .45717 .698 L .45898 .69699 L F
.446 .849 .662 r
.45898 .69699 m .45969 .69638 L .46138 .69713 L F
.45898 .69699 m .45717 .698 L .45969 .69638 L F
.327 .421 .805 r
.55973 .65192 m .5605 .65497 L .56129 .65348 L F
.355 0 .193 r
.36356 .63328 m .36215 .63242 L .3643 .63195 L F
.36356 .63328 m .36139 .63386 L .36215 .63242 L F
.55 .346 .556 r
.61156 .52984 m .61373 .53151 L .61374 .52916 L F
.61156 .52984 m .61147 .532 L .61373 .53151 L F
.942 .835 .71 r
.7211 .49691 m .72382 .49454 L .72267 .49313 L F
.7211 .49691 m .72229 .49807 L .72382 .49454 L F
.389 .434 .787 r
.74644 .50977 m .74843 .5134 L .74931 .5133 L F
.964 .861 .69 r
.73126 .49288 m .73132 .48882 L .73189 .48988 L F
.66 .721 .894 r
.5743 .63427 m .57543 .63495 L .57791 .6343 L F
0 0 .432 r
.48328 .78029 m .48418 .77891 L .4857 .77978 L F
.48328 .78029 m .48432 .78106 L .48418 .77891 L F
.423 .161 .41 r
.61643 .59722 m .61442 .5978 L .61708 .59519 L F
.17 0 .289 r
.61886 .59593 m .61708 .59519 L .61881 .59423 L F
.61886 .59593 m .61643 .59722 L .61708 .59519 L F
.258 0 .18 r
.57627 .56262 m .577 .56103 L .57423 .56342 L F
.343 0 .229 r
.57627 .56262 m .57916 .5604 L .577 .56103 L F
.328 0 .099 r
.47554 .63065 m .47873 .62845 L .47719 .62952 L F
.494 .52 .813 r
.43542 .69048 m .43472 .69409 L .43398 .69069 L F
.43542 .69048 m .43653 .69373 L .43472 .69409 L F
.24 .329 .755 r
.43699 .6958 m .43472 .69409 L .43653 .69373 L F
.397 .491 .838 r
.54984 .64063 m .55123 .63885 L .54859 .63907 L F
.54984 .64063 m .5532 .64217 L .55123 .63885 L F
.775 .702 .783 r
.48984 .64842 m .48618 .64848 L .48878 .64569 L F
.685 .29 .293 r
.48984 .64842 m .48838 .65029 L .48618 .64848 L F
.382 0 .092 r
.4906 .64968 m .48984 .64842 L .49192 .64879 L F
.4906 .64968 m .48838 .65029 L .48984 .64842 L F
.511 .036 .062 r
.47201 .70311 m .47049 .70461 L .46828 .70427 L F
.499 .022 .053 r
.474 .70417 m .47049 .70461 L .47201 .70311 L F
.48 .077 .198 r
.47439 .70288 m .474 .70417 L .47201 .70311 L F
.412 .598 .922 r
.74994 .48077 m .74848 .48226 L .74785 .48057 L F
.74994 .48077 m .75223 .48325 L .74848 .48226 L F
.646 .417 .557 r
.68519 .4794 m .68055 .48077 L .68017 .4787 L F
.538 .332 .549 r
.27409 .59496 m .27633 .5946 L .27645 .59214 L F
.447 .258 .53 r
.27645 .59214 m .27828 .59392 L .27882 .59204 L F
.27645 .59214 m .27633 .5946 L .27828 .59392 L F
.515 .391 .648 r
.4074 .67752 m .40973 .6794 L .40948 .67689 L F
.424 .392 .72 r
.4074 .67752 m .40807 .6799 L .40973 .6794 L F
.595 .612 .839 r
.30119 .64246 m .30283 .64638 L .30513 .64492 L F
0 0 .403 r
.52631 .60709 m .52708 .60859 L .52556 .60484 L F
.771 .292 0 r
.65124 .50419 m .6516 .50564 L .65089 .50372 L F
.547 .329 .536 r
.6138 .52701 m .61616 .5285 L .61625 .52646 L F
.6138 .52701 m .61374 .52916 L .61616 .5285 L F
0 .113 .644 r
.51121 .77739 m .51253 .77902 L .51196 .77809 L F
0 .342 .819 r
.51253 .77902 m .51381 .77892 L .51196 .77809 L F
.51253 .77902 m .51511 .78073 L .51381 .77892 L F
.402 .339 .673 r
.40807 .6799 m .40817 .68314 L .41027 .68199 L F
.507 .406 .675 r
.40817 .68314 m .41088 .68498 L .41027 .68199 L F
.40817 .68314 m .40884 .68551 L .41088 .68498 L F
.506 .087 .18 r
.54381 .61682 m .54743 .61505 L .54362 .61486 L F
.54381 .61682 m .54633 .61695 L .54743 .61505 L F
.378 0 .113 r
.54743 .61505 m .54862 .61654 L .54974 .614 L F
.54743 .61505 m .54633 .61695 L .54862 .61654 L F
.803 .812 .859 r
.67755 .50524 m .6736 .5063 L .67605 .50376 L F
.837 .808 .823 r
.67893 .50356 m .67755 .50524 L .67605 .50376 L F
.586 .622 .855 r
.48619 .64602 m .48697 .64277 L .4854 .64385 L F
.48619 .64602 m .48878 .64569 L .48697 .64277 L F
.365 .384 .747 r
.7458 .50808 m .74644 .50977 L .74793 .50918 L F
.389 .434 .787 r
.74644 .50977 m .74931 .5133 L .74793 .50918 L F
.486 .327 .591 r
.7458 .50808 m .74793 .50918 L .74732 .50668 L F
.075 .551 .899 r
.41991 .65937 m .41823 .6592 L .41764 .6592 L F
.369 0 .103 r
.7165 .47476 m .71975 .47262 L .71751 .47371 L F
.502 .373 .637 r
.58828 .62862 m .58869 .63222 L .58645 .63311 L F
.443 .337 .639 r
.58869 .63222 m .58696 .63471 L .58645 .63311 L F
.772 .672 .752 r
.58331 .65895 m .57983 .66174 L .58218 .65904 L F
.056 0 .15 r
.25706 .66355 m .2562 .66537 L .25847 .66249 L F
.08 0 0 r
.68976 .46774 m .68692 .4699 L .68976 .4681 L F
.756 .569 .644 r
.68636 .47201 m .68976 .4681 L .68692 .4699 L F
.518 .838 .536 r
.55803 .62384 m .55736 .62445 L .55664 .6252 L F
0 .012 .547 r
.55736 .62445 m .5579 .62805 L .55664 .6252 L F
.517 .271 .481 r
.58548 .61457 m .58783 .61419 L .58796 .61202 L F
.479 .35 .626 r
.58796 .61202 m .59036 .61389 L .59018 .61136 L F
.582 .325 .491 r
.58783 .61419 m .59036 .61389 L .58796 .61202 L F
.617 .43 .606 r
.63349 .49988 m .63571 .49651 L .63338 .49747 L F
.473 .379 .668 r
.63795 .48943 m .64161 .49142 L .63978 .48875 L F
.63795 .48943 m .63853 .49277 L .64161 .49142 L F
.747 .621 .72 r
.57109 .61583 m .5742 .61499 L .57223 .6115 L F
.463 .279 .545 r
.55874 .60047 m .55884 .60297 L .55669 .60308 L F
.087 .289 .772 r
.51114 .62901 m .51361 .63104 L .51257 .63211 L F
.117 .339 .806 r
.51361 .63104 m .51493 .63387 L .51257 .63211 L F
.272 0 .106 r
.31714 .6059 m .31445 .60764 L .31512 .60653 L F
.074 .157 .647 r
.54438 .75977 m .54255 .75926 L .54225 .76122 L F
.54455 .75966 m .54426 .7596 L .54438 .75977 L F
.54426 .7596 m .54255 .75926 L .54438 .75977 L F
.854 .397 .071 r
.54418 .7592 m .54526 .76104 L .54701 .76233 L F
.54526 .76104 m .54588 .76209 L .54601 .76212 L F
.54526 .76104 m .54601 .76212 L .54701 .76233 L F
.365 .823 .927 r
.54701 .76233 m .54588 .76209 L .54371 .76258 L F
.494 .351 .615 r
.54455 .75966 m .54724 .76166 L .54588 .76209 L F
.54724 .76166 m .54844 .76255 L .5466 .76222 L F
.54724 .76166 m .5466 .76222 L .54588 .76209 L F
.54455 .75966 m .54844 .76255 L .54588 .76209 L F
.807 .518 .501 r
.54757 .75716 m .54904 .75812 L .54955 .75845 L F
.568 .369 .57 r
.5505 .75879 m .55031 .75895 L .54955 .75845 L F
.55105 .75898 m .54756 .76138 L .5505 .75879 L F
.54756 .76138 m .54708 .76171 L .5505 .75879 L F
.784 .986 .736 r
.55204 .75932 m .54844 .76255 L .55105 .75898 L F
.568 .369 .57 r
.55105 .75898 m .54844 .76255 L .54708 .76171 L F
.807 .518 .501 r
.54904 .75812 m .55133 .75961 L .54955 .75845 L F
.568 .369 .57 r
.55031 .75895 m .54708 .76171 L .54955 .75845 L F
.784 .986 .736 r
.55204 .75932 m .54902 .76269 L .54844 .76255 L F
0 .23 .745 r
.54775 .76243 m .54912 .76253 L .54708 .76171 L F
0 .477 .714 r
.54701 .76233 m .54902 .76269 L .54844 .76255 L F
.54701 .76233 m .54902 .76269 L .54844 .76255 L F
.807 .319 0 r
.54902 .76269 m .54858 .76331 L .54844 .76255 L F
0 .477 .714 r
.54701 .76233 m .54844 .76255 L .54588 .76209 L F
0 .23 .745 r
.54858 .76331 m .54708 .76171 L .54844 .76255 L F
.54858 .76331 m .54905 .76264 L .54775 .76243 L F
.54905 .76264 m .54912 .76253 L .54775 .76243 L F
0 .477 .714 r
.54701 .76233 m .54844 .76255 L .54771 .76242 L F
.54659 .76224 m .54771 .76242 L .54588 .76209 L F
.54701 .76233 m .54771 .76242 L .54659 .76224 L F
.187 0 0 r
.34035 .60015 m .33901 .60056 L .33672 .6006 L F
.065 0 0 r
.34249 .60003 m .33901 .60056 L .34035 .60015 L F
.642 .791 .954 r
.5672 .62813 m .57074 .6287 L .56968 .62697 L F
.706 .473 .569 r
.56814 .63107 m .57074 .6287 L .5672 .62813 L F
.56814 .63107 m .57073 .63143 L .57074 .6287 L F
0 0 0 r
.57108 .62644 m .56968 .62697 L .57074 .6287 L F
.597 .42 .613 r
.57074 .6287 m .57364 .62597 L .57108 .62644 L F
.57074 .6287 m .57411 .62837 L .57364 .62597 L F
.545 .315 .518 r
.57073 .63143 m .57411 .62837 L .57074 .6287 L F
.513 .822 1 r
.37381 .75375 m .37019 .75342 L .373 .75166 L F
.981 .741 .337 r
.373 .75166 m .3731 .75332 L .37381 .75375 L F
.943 .69 .525 r
.3722 .75477 m .37381 .75375 L .3731 .75332 L F
.3722 .75477 m .37379 .75641 L .37381 .75375 L F
.968 .81 .633 r
.60887 .57744 m .60837 .57416 L .60959 .57513 L F
.202 0 .273 r
.58462 .57213 m .58437 .57408 L .58219 .57418 L F
.171 0 .08 r
.58219 .57418 m .58437 .57408 L .58146 .57631 L F
.791 .339 .173 r
.72777 .48142 m .72671 .48257 L .72769 .48274 L F
.916 .914 .522 r
.72753 .48072 m .72671 .48257 L .72777 .48142 L F
.101 0 .011 r
.56687 .57183 m .56876 .57091 L .56957 .56908 L F
.186 0 .297 r
.56957 .56908 m .57149 .56865 L .57175 .56617 L F
.057 0 0 r
.56957 .56908 m .5706 .56984 L .57149 .56865 L F
.56957 .56908 m .56876 .57091 L .5706 .56984 L F
.349 .195 .527 r
.61643 .59722 m .61512 .60039 L .61442 .5978 L F
.359 .504 .867 r
.69193 .47137 m .69397 .47429 L .6906 .47303 L F
.035 0 .207 r
.55762 .58112 m .55723 .58287 L .55922 .57969 L F
.92 .548 .299 r
.48467 .69662 m .48622 .69732 L .48364 .69499 L F
.948 .744 .594 r
.48467 .69662 m .48534 .70094 L .48622 .69732 L F
.503 .408 .68 r
.28312 .64779 m .28321 .64927 L .2855 .64596 L F
.28312 .64779 m .28321 .64927 L .2855 .64596 L F
.082 0 0 r
.43531 .70893 m .43839 .70797 L .43701 .70849 L F
.491 .036 .099 r
.43839 .70797 m .44032 .70791 L .43701 .70849 L F
.595 .359 .53 r
.35307 .62248 m .3558 .62004 L .35354 .62055 L F
.8 .668 .718 r
.62958 .5097 m .63082 .51289 L .63346 .50943 L F
.536 .784 .989 r
.33149 .63024 m .32941 .63075 L .32677 .6289 L F
.402 .339 .673 r
.40807 .6799 m .41027 .68199 L .40973 .6794 L F
.067 0 .333 r
.54551 .61287 m .54437 .61247 L .54581 .61102 L F
.54551 .61287 m .54362 .61486 L .54437 .61247 L F
.072 0 .187 r
.48283 .77753 m .48309 .77773 L .48439 .77605 L F
.849 .695 .692 r
.73327 .51817 m .73005 .52009 L .72993 .51774 L F
.73327 .51817 m .73281 .5224 L .73005 .52009 L F
.315 .557 .922 r
.73437 .51703 m .73522 .51868 L .73327 .51817 L F
0 .269 .702 r
.73747 .52075 m .73327 .51817 L .73522 .51868 L F
.617 .478 .67 r
.58814 .62613 m .59072 .6281 L .58828 .62862 L F
.58814 .62613 m .59058 .6256 L .59072 .6281 L F
.414 .073 .274 r
.27409 .59496 m .27567 .5963 L .27633 .5946 L F
.27409 .59496 m .27318 .59693 L .27567 .5963 L F
.422 0 .03 r
.30018 .58528 m .3025 .5852 L .30411 .58362 L F
.118 0 0 r
.30411 .58362 m .30457 .58454 L .30629 .58338 L F
.30411 .58362 m .3025 .5852 L .30457 .58454 L F
.5 .347 .605 r
.68969 .46788 m .69421 .46611 L .69204 .46688 L F
.68969 .46788 m .69422 .46849 L .69421 .46611 L F
.837 .808 .823 r
.67893 .50356 m .67605 .50376 L .67795 .50277 L F
.604 .642 .862 r
.42306 .7088 m .4233 .70551 L .42242 .70783 L F
.42306 .7088 m .42524 .70839 L .4233 .70551 L F
.44 0 .072 r
.29262 .5869 m .29429 .58773 L .29577 .5861 L F
.492 .104 .233 r
.29429 .58773 m .29794 .58556 L .29577 .5861 L F
.528 .308 .525 r
.48059 .64877 m .48054 .65151 L .4782 .65185 L F
.2 .419 .85 r
.48121 .64595 m .48372 .64847 L .48059 .64877 L F
.684 .458 .574 r
.48372 .64847 m .48054 .65151 L .48059 .64877 L F
.669 .77 .926 r
.70481 .49918 m .70807 .49987 L .70729 .49879 L F
.489 .682 .952 r
.70807 .49987 m .7097 .49822 L .70729 .49879 L F
.70807 .49987 m .71135 .50038 L .7097 .49822 L F
.42 .58 .905 r
.55281 .64341 m .55445 .64192 L .5532 .64217 L F
.485 .546 .843 r
.5535 .64446 m .55445 .64192 L .55281 .64341 L F
.733 .61 .721 r
.74326 .49835 m .74627 .49918 L .74553 .49516 L F
.312 .316 .703 r
.74553 .49516 m .74627 .49918 L .74789 .49744 L F
.436 .506 .832 r
.74627 .49918 m .7493 .50064 L .74789 .49744 L F
.874 .592 .507 r
.73651 .52927 m .73916 .5324 L .73798 .53164 L F
0 .184 .698 r
.73916 .5324 m .74063 .53312 L .73798 .53164 L F
.73916 .5324 m .74158 .5344 L .74063 .53312 L F
.495 .421 .703 r
.26829 .60919 m .27014 .60875 L .26977 .60557 L F
.497 .429 .71 r
.26829 .60919 m .27078 .61139 L .27014 .60875 L F
.503 .429 .706 r
.26881 .61185 m .27078 .61139 L .26829 .60919 L F
.28 .389 .796 r
.55846 .65133 m .56003 .65034 L .55736 .64829 L F
.276 .381 .79 r
.55846 .65133 m .55973 .65192 L .56003 .65034 L F
.094 0 0 r
.28162 .59115 m .28389 .59057 L .28478 .58979 L F
.593 .227 .317 r
.28389 .59057 m .28698 .58934 L .28478 .58979 L F
.652 .137 .004 r
.54027 .65295 m .53953 .65359 L .53737 .65263 L F
.729 .657 .779 r
.54198 .64807 m .54027 .65295 L .53964 .65103 L F
.689 .184 .033 r
.54027 .65295 m .54328 .65489 L .53953 .65359 L F
.425 .007 .139 r
.34744 .62555 m .34971 .62533 L .35119 .62336 L F
.403 .056 .258 r
.34971 .62533 m .35307 .62248 L .35119 .62336 L F
0 .18 .711 r
.5206 .63415 m .52228 .63663 L .52204 .63463 L F
.448 .18 .414 r
.43802 .67372 m .43603 .6762 L .4362 .67399 L F
.326 .089 .394 r
.55723 .58287 m .55536 .58365 L .55491 .58577 L F
.364 0 0 r
.49277 .70226 m .4915 .70324 L .48919 .70256 L F
.718 .206 .007 r
.49493 .70459 m .4915 .70324 L .49277 .70226 L F
.667 .35 .428 r
.49598 .70244 m .49493 .70459 L .49277 .70226 L F
.392 .265 .586 r
.57391 .66886 m .57582 .66774 L .57528 .66568 L F
.151 0 .193 r
.57489 .67029 m .57391 .66886 L .57352 .67061 L F
.57489 .67029 m .57582 .66774 L .57391 .66886 L F
0 .185 .715 r
.30467 .72494 m .30665 .72699 L .30638 .72829 L F
.613 .911 .982 r
.30638 .72829 m .30442 .72779 L .30541 .72919 L F
.30638 .72829 m .30665 .72699 L .30442 .72779 L F
.44 .748 .993 r
.6598 .52211 m .66041 .52117 L .65856 .5206 L F
.6598 .52211 m .66153 .52206 L .66041 .52117 L F
.472 .218 .448 r
.39239 .60891 m .39204 .61147 L .38977 .61203 L F
.397 .155 .427 r
.39401 .61073 m .39239 .60891 L .39468 .60844 L F
.39401 .61073 m .39204 .61147 L .39239 .60891 L F
.525 .84 .999 r
.46472 .67662 m .46337 .67715 L .46189 .67648 L F
.576 .065 .001 r
.46472 .67662 m .46189 .67648 L .46337 .67715 L F
.484 .161 .343 r
.44799 .65144 m .45037 .65112 L .4511 .64855 L F
.405 .09 .314 r
.4511 .64855 m .45255 .65054 L .45293 .64764 L F
.4511 .64855 m .45037 .65112 L .45255 .65054 L F
.468 .081 .221 r
.53047 .65308 m .52831 .65183 L .53205 .65089 L F
.103 .296 .774 r
.53371 .65121 m .53565 .65461 L .53608 .65335 L F
.677 .258 .242 r
.53448 .65235 m .53205 .65089 L .53371 .65121 L F
.53448 .65235 m .53047 .65308 L .53205 .65089 L F
.489 .406 .689 r
.75772 .4998 m .75445 .5012 L .75499 .49818 L F
.609 .512 .719 r
.75772 .4998 m .75613 .5043 L .75445 .5012 L F
.867 .638 .59 r
.60975 .56878 m .60698 .56602 L .61057 .56656 L F
.696 .284 .261 r
.53063 .69377 m .5344 .69426 L .53214 .69447 L F
.624 .61 .817 r
.53533 .69575 m .53214 .69447 L .5344 .69426 L F
.699 .706 .854 r
.45958 .66235 m .46348 .66332 L .46274 .66159 L F
.702 .708 .853 r
.46274 .66159 m .46348 .66332 L .46453 .66092 L F
.861 .823 .81 r
.27575 .63592 m .2747 .6381 L .27319 .63682 L F
.701 .431 .513 r
.2747 .6381 m .27461 .64017 L .27739 .64005 L F
.409 .798 .989 r
.57441 .72785 m .57679 .72746 L .57791 .72819 L F
.57441 .72785 m .57679 .72746 L .57791 .72819 L F
.443 .337 .639 r
.58869 .63222 m .58925 .63466 L .58696 .63471 L F
.444 .41 .726 r
.58696 .63471 m .58925 .63466 L .58953 .63654 L F
.453 .409 .719 r
.58696 .63471 m .58953 .63654 L .5878 .63721 L F
.512 .198 .372 r
.50502 .65414 m .50718 .65412 L .50723 .6522 L F
0 0 .208 r
.50719 .64871 m .50723 .6522 L .50769 .64999 L F
0 0 .097 r
.50723 .6522 m .50807 .65113 L .50777 .6496 L F
.679 .313 .346 r
.50785 .65105 m .5046 .65146 L .50481 .64996 L F
.50807 .65113 m .50787 .65115 L .50785 .65105 L F
.50787 .65115 m .5046 .65146 L .50785 .65105 L F
0 0 .208 r
.50758 .64932 m .50769 .64999 L .50777 .6496 L F
.50719 .64871 m .50769 .64999 L .50758 .64932 L F
0 0 .097 r
.50723 .6522 m .50718 .65412 L .50807 .65113 L F
.375 0 0 r
.7011 .46693 m .69768 .468 L .69902 .4683 L F
.7011 .46693 m .7001 .46813 L .69768 .468 L F
.587 .184 .245 r
.70339 .46649 m .7001 .46813 L .7011 .46693 L F
.359 .724 .988 r
.37239 .58977 m .37035 .58982 L .36893 .58884 L F
.601 .414 .601 r
.69451 .47577 m .69451 .47831 L .6918 .47854 L F
.73 .595 .021 r
.69447 .47586 m .69451 .47577 L .69397 .47429 L F
.69447 .47586 m .69451 .47831 L .69451 .47577 L F
.093 .336 .809 r
.48121 .64595 m .48249 .64698 L .48172 .64493 L F
0 0 0 r
.55315 .58681 m .55033 .58897 L .55211 .58783 L F
.064 0 0 r
.55211 .58783 m .55491 .58577 L .55315 .58681 L F
.489 .6 .89 r
.27217 .61609 m .27302 .61781 L .27418 .61591 L F
.386 .465 .819 r
.27302 .61781 m .27565 .61939 L .27418 .61591 L F
.601 .58 .802 r
.27302 .61781 m .27654 .62051 L .27565 .61939 L F
.14 .683 .816 r
.32117 .64816 m .31974 .64806 L .31759 .64821 L F
.429 .863 .925 r
.32194 .64738 m .32117 .64816 L .32363 .64791 L F
.32194 .64738 m .31974 .64806 L .32117 .64816 L F
.519 .379 .63 r
.43509 .68804 m .43266 .68577 L .43482 .68493 L F
.43509 .68804 m .43295 .68872 L .43266 .68577 L F
.732 .621 .735 r
.56559 .59184 m .56706 .59546 L .56331 .59471 L F
.601 .344 .499 r
.56706 .59546 m .56971 .59498 L .56866 .59683 L F
.532 .443 .7 r
.75613 .5043 m .75711 .50709 L .7535 .50481 L F
.698 .573 .71 r
.62127 .58952 m .61958 .5924 L .62101 .58915 L F
0 0 .134 r
.62127 .58952 m .61881 .59423 L .61958 .5924 L F
.702 .708 .853 r
.46274 .66159 m .46453 .66092 L .46583 .65999 L F
.686 .257 .224 r
.46682 .69695 m .46928 .69887 L .47062 .69729 L F
.54 .086 .123 r
.47062 .69729 m .46928 .69887 L .47265 .69849 L F
.503 0 0 r
.6918 .47854 m .69108 .47885 L .68861 .478 L F
0 0 0 r
.69451 .47831 m .69108 .47885 L .6918 .47854 L F
.37 .454 .817 r
.41124 .6993 m .4126 .703 L .41376 .70142 L F
.496 .25 .471 r
.4126 .703 m .41477 .70421 L .41513 .70236 L F
.4126 .703 m .41477 .70421 L .41376 .70142 L F
.4126 .703 m .41248 .70497 L .41477 .70421 L F
.4126 .703 m .41248 .70497 L .41477 .70421 L F
.074 .157 .647 r
.54455 .75966 m .54418 .7592 L .54255 .75926 L F
.54455 .75966 m .54588 .76209 L .54418 .7592 L F
.616 .217 .264 r
.4657 .65454 m .46652 .65617 L .46417 .65455 L F
.742 .631 .737 r
.46867 .65347 m .46652 .65617 L .4657 .65454 L F
.964 .776 .601 r
.64689 .49435 m .64864 .49295 L .64756 .49174 L F
.64689 .49435 m .6482 .4954 L .64864 .49295 L F
.062 0 .055 r
.55626 .6113 m .5572 .61075 L .55813 .60934 L F
.676 .534 .685 r
.55658 .60857 m .55859 .60993 L .55895 .60792 L F
.55859 .60993 m .55993 .61085 L .55946 .60942 L F
.55859 .60993 m .55946 .60942 L .55895 .60792 L F
.062 0 .055 r
.55523 .61238 m .55624 .6122 L .5572 .61075 L F
.55523 .61238 m .5572 .61075 L .55626 .6113 L F
.467 .094 .246 r
.43716 .65627 m .44015 .65463 L .43762 .65467 L F
.562 .51 .754 r
.47941 .80456 m .48044 .80027 L .47832 .80091 L F
.47941 .80456 m .48169 .80405 L .48044 .80027 L F
.585 .628 .861 r
.47941 .80456 m .48308 .80593 L .48169 .80405 L F
.886 .982 .818 r
.73839 .50194 m .73857 .50396 L .74081 .50118 L F
0 .227 .719 r
.73921 .504 m .73857 .50396 L .73839 .50194 L F
.834 .678 .689 r
.73781 .50268 m .73921 .504 L .73839 .50194 L F
0 .227 .719 r
.73921 .504 m .74119 .50586 L .73857 .50396 L F
.834 .678 .689 r
.73641 .5045 m .73921 .504 L .73781 .50268 L F
0 .227 .719 r
.73921 .504 m .74121 .50588 L .74119 .50586 L F
.523 .292 .506 r
.46652 .65617 m .46381 .65711 L .46417 .65455 L F
.605 .35 .504 r
.58413 .65139 m .58702 .65142 L .58711 .64859 L F
.196 .478 .893 r
.58963 .64847 m .58607 .64562 L .58711 .64859 L F
.582 .323 .489 r
.58963 .64847 m .58702 .65142 L .58711 .64859 L F
.58963 .64847 m .58702 .65142 L .58711 .64859 L F
.432 .209 .474 r
.44015 .67328 m .43859 .67148 L .44093 .67092 L F
.44015 .67328 m .43802 .67372 L .43859 .67148 L F
0 0 .26 r
.6523 .49559 m .65266 .49425 L .6524 .49173 L F
.931 .881 .763 r
.6521 .49833 m .65266 .49425 L .6523 .49559 L F
.533 .359 .591 r
.61601 .52394 m .61828 .52344 L .61823 .52102 L F
.522 .362 .605 r
.61601 .52394 m .61839 .52578 L .61828 .52344 L F
.61601 .52394 m .61625 .52646 L .61839 .52578 L F
.792 .768 .83 r
.68755 .50326 m .69095 .50343 L .69009 .50051 L F
.794 .764 .826 r
.68755 .50326 m .68887 .5047 L .69095 .50343 L F
.84 .792 .805 r
.69009 .50051 m .69095 .50343 L .69148 .50169 L F
.486 .68 .951 r
.7319 .47429 m .73393 .474 L .7325 .47569 L F
.52 .731 .97 r
.73393 .474 m .7349 .47539 L .7325 .47569 L F
.523 .311 .534 r
.41101 .67092 m .4134 .6682 L .41129 .66872 L F
.202 .711 .897 r
.55529 .77355 m .55456 .77323 L .5518 .77329 L F
.55529 .77355 m .55456 .77323 L .5518 .77329 L F
.738 .886 .947 r
.66488 .5207 m .66589 .52175 L .66805 .52043 L F
.66488 .5207 m .66589 .52175 L .66805 .52043 L F
.483 .305 .563 r
.5987 .62045 m .60081 .61745 L .60084 .61982 L F
.69 .558 .7 r
.60084 .61982 m .59855 .62269 L .5987 .62045 L F
.853 .734 .731 r
.7286 .49812 m .7296 .50151 L .72786 .50031 L F
.85 .761 .764 r
.7296 .50151 m .72599 .50325 L .72786 .50031 L F
.7296 .50151 m .72752 .50465 L .72599 .50325 L F
.604 .875 .992 r
.70983 .46571 m .70574 .46582 L .70667 .46672 L F
.848 .695 .162 r
.65723 .51806 m .65707 .51643 L .65793 .51626 L F
.352 .431 .803 r
.66028 .51441 m .65793 .51626 L .65707 .51643 L F
.66028 .51441 m .66044 .51827 L .65793 .51626 L F
0 0 0 r
.55033 .58897 m .55084 .58952 L .55211 .58783 L F
.55033 .58897 m .5494 .59084 L .55084 .58952 L F
.92 .669 .542 r
.48918 .78205 m .48774 .78315 L .4861 .78339 L F
.48918 .78205 m .48915 .78454 L .48774 .78315 L F
.115 .292 .767 r
.49016 .78103 m .48918 .78205 L .48787 .7789 L F
.92 .669 .542 r
.48774 .78315 m .48918 .78205 L .49016 .78103 L F
.48774 .78315 m .48915 .78454 L .48918 .78205 L F
.527 .214 .38 r
.59658 .54617 m .59925 .54585 L .59967 .54365 L F
.572 .254 .391 r
.59967 .54365 m .6021 .54547 L .6021 .5434 L F
.59967 .54365 m .59925 .54585 L .6021 .54547 L F
.889 .892 .825 r
.52687 .80493 m .52773 .80124 L .52553 .80227 L F
.52687 .80493 m .52907 .80193 L .52773 .80124 L F
0 .118 .617 r
.66826 .51833 m .67045 .52018 L .66903 .51879 L F
.515 .338 .58 r
.66805 .52043 m .67045 .52018 L .66826 .51833 L F
.169 .262 .717 r
.26881 .61185 m .27058 .61327 L .27078 .61139 L F
.167 0 0 r
.5079 .70556 m .50659 .70525 L .50442 .70472 L F
.087 .633 .836 r
.51032 .70568 m .50659 .70525 L .5079 .70556 L F
.604 .208 .265 r
.59773 .56368 m .59434 .56527 L .59569 .56324 L F
.924 .627 .462 r
.73455 .52631 m .73253 .52301 L .73423 .52418 L F
.455 0 .05 r
.46187 .69703 m .46359 .69785 L .46503 .69633 L F
.658 .106 0 r
.46237 .69688 m .46442 .69825 L .46359 .69785 L F
.725 .337 .314 r
.46359 .69785 m .46593 .69926 L .46696 .69835 L F
.658 .106 0 r
.46442 .69825 m .46593 .69926 L .46359 .69785 L F
.455 0 .05 r
.46138 .69713 m .46359 .69785 L .46187 .69703 L F
.74 .384 .377 r
.46359 .69785 m .46682 .69695 L .46503 .69633 L F
.068 0 0 r
.34636 .59972 m .34471 .59995 L .34249 .60003 L F
.19 .722 .786 r
.34853 .59944 m .34471 .59995 L .34636 .59972 L F
.659 .777 .937 r
.69672 .48939 m .69433 .49026 L .69321 .48883 L F
.886 .647 .571 r
.62543 .5429 m .62932 .54639 L .62876 .54353 L F
.62543 .5429 m .62555 .54544 L .62932 .54639 L F
.877 .725 .689 r
.62555 .54544 m .62677 .54872 L .62932 .54639 L F
.59 .347 .517 r
.59372 .62298 m .59282 .6251 L .59058 .6256 L F
.677 .492 .629 r
.59615 .623 m .59282 .6251 L .59372 .62298 L F
0 0 0 r
.62296 .58558 m .62101 .58915 L .62291 .58562 L F
.806 .793 .841 r
.55302 .78139 m .55378 .78348 L .5545 .7833 L F
0 0 0 r
.62296 .58558 m .62215 .58763 L .62101 .58915 L F
.092 .213 .698 r
.62215 .58763 m .62127 .58952 L .62101 .58915 L F
.503 .435 .713 r
.41305 .66324 m .4155 .66513 L .41531 .66265 L F
.41305 .66324 m .41359 .66572 L .4155 .66513 L F
.765 .702 .792 r
.57108 .62644 m .57364 .62597 L .57205 .62377 L F
.23 .462 .875 r
.57364 .62597 m .57439 .62475 L .57205 .62377 L F
.57439 .62475 m .57395 .62445 L .57205 .62377 L F
.23 .15 .554 r
.57233 .62285 m .57108 .62644 L .57205 .62377 L F
.58 .023 0 r
.57446 .62463 m .57233 .62285 L .57205 .62377 L F
.23 .15 .554 r
.57233 .62285 m .5736 .62592 L .57108 .62644 L F
.722 .389 .414 r
.56849 .62451 m .5736 .62592 L .57262 .62355 L F
.57187 .62305 m .57262 .62355 L .57233 .62285 L F
.56849 .62451 m .57262 .62355 L .57187 .62305 L F
.23 .462 .875 r
.57439 .62475 m .57446 .62463 L .57395 .62445 L F
0 0 .523 r
.57465 .62793 m .57364 .62597 L .57411 .62837 L F
.57465 .62793 m .57446 .62463 L .57364 .62597 L F
.489 .248 .476 r
.38231 .61752 m .38195 .61973 L .3798 .62017 L F
.433 .191 .446 r
.38441 .61695 m .38195 .61973 L .38231 .61752 L F
.983 .844 .625 r
.6476 .49752 m .64824 .49824 L .6482 .4954 L F
.912 .814 .738 r
.65056 .49984 m .65106 .49945 L .64824 .49824 L F
0 .17 .64 r
.6476 .49752 m .65056 .49984 L .64824 .49824 L F
.501 .707 .963 r
.27565 .61939 m .27654 .62051 L .27746 .61897 L F
.387 .558 .901 r
.27654 .62051 m .27817 .6204 L .27746 .61897 L F
0 0 .134 r
.62127 .58952 m .62053 .59316 L .61881 .59423 L F
.092 .213 .698 r
.62215 .58763 m .62249 .58849 L .62127 .58952 L F
0 0 .061 r
.62249 .58849 m .62053 .59316 L .62127 .58952 L F
.328 .734 .98 r
.66314 .49798 m .66559 .49795 L .66665 .49872 L F
.745 .686 .795 r
.66665 .49872 m .66314 .49798 L .66559 .49795 L F
.606 .878 .992 r
.66665 .49872 m .66784 .49713 L .66893 .49791 L F
.66665 .49872 m .66784 .49713 L .66893 .49791 L F
.66665 .49872 m .66559 .49795 L .66784 .49713 L F
.685 .622 .779 r
.29564 .64218 m .29659 .6455 L .29888 .64318 L F
.26 .747 .921 r
.30718 .58342 m .30844 .5832 L .3099 .58355 L F
.113 0 0 r
.30665 .58385 m .30971 .58298 L .30844 .5832 L F
.411 .828 .97 r
.31052 .58275 m .3099 .58355 L .30844 .5832 L F
.113 0 0 r
.30971 .58298 m .31052 .58275 L .30844 .5832 L F
.26 .747 .921 r
.30629 .58338 m .30844 .5832 L .30718 .58342 L F
.411 .828 .97 r
.31052 .58275 m .31202 .58314 L .3099 .58355 L F
.449 .499 .818 r
.54892 .65378 m .54756 .65465 L .54609 .65228 L F
.787 .757 .826 r
.54892 .65378 m .5461 .65664 L .54756 .65465 L F
.54892 .65378 m .54838 .65732 L .5461 .65664 L F
.74 .287 .176 r
.55058 .65828 m .54919 .65777 L .54889 .65754 L F
.55058 .65828 m .5484 .65884 L .5461 .65664 L F
.227 0 0 r
.55295 .65639 m .55127 .65808 L .55003 .65841 L F
.55295 .65639 m .5484 .65884 L .55058 .65828 L F
.54969 .65815 m .55003 .65841 L .5484 .65884 L F
.55295 .65639 m .55003 .65841 L .54969 .65815 L F
.74 .287 .176 r
.54889 .65754 m .5461 .65664 L .54838 .65732 L F
.54919 .65777 m .5461 .65664 L .54889 .65754 L F
.507 0 0 r
.51413 .77552 m .51677 .7763 L .51615 .77593 L F
.939 .953 .757 r
.74206 .49716 m .74081 .50118 L .74326 .49835 L F
.74206 .49716 m .74023 .50021 L .74081 .50118 L F
.922 .958 .789 r
.74081 .50118 m .74023 .50021 L .73839 .50194 L F
.527 .498 .768 r
.58159 .65146 m .5824 .65495 L .58422 .65284 L F
.554 .539 .793 r
.5824 .65495 m .58522 .65573 L .58422 .65284 L F
.049 .152 .652 r
.49519 .6997 m .49718 .70249 L .49598 .70244 L F
.064 0 .104 r
.49718 .70249 m .49493 .70459 L .49598 .70244 L F
.563 .882 .991 r
.74506 .5333 m .7477 .53239 L .74694 .53168 L F
.784 .998 .821 r
.74061 .47276 m .73788 .47533 L .73751 .47487 L F
.504 .201 .385 r
.44378 .6687 m .44324 .67066 L .44093 .67092 L F
.54 .234 .398 r
.44378 .6687 m .44562 .67042 L .44324 .67066 L F
.399 .243 .551 r
.44563 .66797 m .44562 .67042 L .44378 .6687 L F
.44563 .66797 m .44562 .67042 L .44378 .6687 L F
.399 .725 .99 r
.566 .60042 m .56699 .59997 L .56528 .59902 L F
.884 .725 .68 r
.51816 .77885 m .52113 .77631 L .51677 .7763 L F
.51816 .77885 m .52027 .77933 L .52113 .77631 L F
.987 .895 .578 r
.52027 .77933 m .52113 .77631 L .52239 .77673 L F
0 0 .135 r
.52113 .77631 m .52146 .77793 L .52239 .77673 L F
.52113 .77631 m .52027 .77933 L .52146 .77793 L F
.615 .716 .918 r
.65391 .50783 m .65419 .50876 L .65291 .50679 L F
.609 .713 .919 r
.65291 .50679 m .65419 .50876 L .65512 .50827 L F
.072 0 0 r
.46176 .6431 m .46256 .6441 L .46376 .64225 L F
.46176 .6431 m .46076 .64507 L .46256 .6441 L F
.672 .281 .296 r
.49151 .69957 m .49378 .70153 L .49519 .6997 L F
.72 .341 .33 r
.49378 .70153 m .49718 .70249 L .49519 .6997 L F
.894 .784 .733 r
.45676 .68907 m .45842 .68752 L .45885 .68785 L F
0 0 .521 r
.45742 .68451 m .45885 .68785 L .45842 .68752 L F
.77 .444 .436 r
.46925 .66595 m .47251 .6682 L .4731 .66588 L F
.589 .071 0 r
.73668 .52355 m .73964 .52494 L .74025 .52395 L F
.968 .754 .319 r
.73964 .52494 m .74022 .52634 L .74025 .52395 L F
.859 .479 .325 r
.54557 .63426 m .54405 .63417 L .54246 .63154 L F
.284 .738 .956 r
.54647 .63427 m .54405 .63417 L .54557 .63426 L F
.34 .076 .36 r
.57149 .56865 m .57377 .56501 L .57175 .56617 L F
.984 .745 .348 r
.73281 .5224 m .73173 .52226 L .73005 .52009 L F
.73281 .5224 m .73253 .52301 L .73173 .52226 L F
.996 .843 .567 r
.73094 .48534 m .73195 .48462 L .73142 .48661 L F
0 0 0 r
.63853 .49277 m .63641 .49565 L .63824 .49401 L F
.436 .292 .587 r
.63571 .49651 m .63824 .49401 L .63641 .49565 L F
.644 .362 .476 r
.54947 .78159 m .55302 .78139 L .55059 .77934 L F
.523 .286 .496 r
.46455 .66825 m .46605 .66846 L .46674 .66566 L F
.574 .333 .514 r
.46674 .66566 m .46605 .66846 L .46927 .6679 L F
.621 .322 .441 r
.46674 .66566 m .46927 .6679 L .46925 .66595 L F
.128 0 0 r
.34009 .62863 m .34238 .62781 L .34031 .62831 L F
.878 .726 .689 r
.62597 .55746 m .62605 .55743 L .62598 .55742 L F
.62553 .55959 m .62605 .55743 L .62597 .55746 L F
.825 .705 .732 r
.62438 .55627 m .62553 .55959 L .62598 .55742 L F
.823 .704 .733 r
.62608 .55749 m .62553 .55959 L .62438 .55627 L F
.81 .582 .594 r
.62581 .55753 m .62402 .56096 L .62608 .55749 L F
.62101 .55828 m .62195 .55911 L .62581 .55753 L F
.62195 .55911 m .62402 .56096 L .62581 .55753 L F
.878 .726 .689 r
.62553 .55959 m .62852 .55784 L .62605 .55743 L F
.62553 .55959 m .62721 .56097 L .62852 .55784 L F
.196 0 0 r
.60866 .61323 m .60841 .6138 L .60633 .61462 L F
0 0 0 r
.6106 .61072 m .60866 .61323 L .61035 .61075 L F
.402 .257 .568 r
.6106 .61072 m .60841 .6138 L .60866 .61323 L F
.374 .436 .796 r
.66345 .51694 m .66213 .51933 L .66129 .51809 L F
.66345 .51694 m .66488 .5207 L .66213 .51933 L F
.324 .777 .953 r
.35543 .58795 m .3516 .58769 L .35376 .58779 L F
.033 .601 .769 r
.35376 .58779 m .35739 .58799 L .35543 .58795 L F
.4 .141 .402 r
.57377 .56501 m .57627 .56262 L .57423 .56342 L F
.133 0 .168 r
.63745 .5087 m .6388 .50691 L .63776 .50797 L F
.792 .717 .781 r
.63873 .50893 m .64079 .50794 L .6388 .50691 L F
.25 .754 .886 r
.64079 .50794 m .63776 .50797 L .6388 .50691 L F
.547 .39 .619 r
.4134 .6682 m .4155 .66513 L .41359 .66572 L F
.39 0 0 r
.49119 .70315 m .48789 .70384 L .48919 .70256 L F
.49096 .70333 m .48789 .70384 L .49119 .70315 L F
.4915 .70324 m .49025 .7039 L .48789 .70384 L F
.974 .713 .474 r
.48884 .70287 m .49023 .70389 L .49018 .70122 L F
.49023 .70389 m .49025 .7039 L .49025 .70387 L F
.49023 .70389 m .49025 .70387 L .49018 .70122 L F
.39 0 0 r
.4915 .70324 m .49096 .70333 L .49119 .70315 L F
.638 .409 .554 r
.57529 .62285 m .57806 .62038 L .57539 .62041 L F
.57529 .62285 m .578 .62287 L .57806 .62038 L F
.424 .231 .513 r
.57806 .62038 m .58006 .61976 L .5801 .61747 L F
.373 .197 .509 r
.57806 .62038 m .57985 .62198 L .58006 .61976 L F
.57806 .62038 m .578 .62287 L .57985 .62198 L F
.858 .669 .646 r
.55149 .61446 m .55337 .61483 L .55273 .61231 L F
.993 .862 .601 r
.5518 .61639 m .55337 .61483 L .55149 .61446 L F
.5518 .61639 m .55274 .61789 L .55337 .61483 L F
.683 .568 .719 r
.55273 .61231 m .55337 .61483 L .55523 .61238 L F
.7 .592 .732 r
.55337 .61483 m .55695 .61536 L .55523 .61238 L F
.737 .738 .852 r
.72422 .50648 m .72449 .50971 L .72124 .50944 L F
.773 .6 .664 r
.72449 .50971 m .723 .51358 L .72124 .50944 L F
.794 .673 .731 r
.62977 .52079 m .62761 .52369 L .63116 .52409 L F
.757 .595 .676 r
.62767 .52598 m .63116 .52409 L .62761 .52369 L F
.62767 .52598 m .63081 .52633 L .63116 .52409 L F
.584 .351 .529 r
.50502 .65414 m .50509 .65642 L .50259 .65441 L F
.50502 .65414 m .50509 .65642 L .50259 .65441 L F
.303 .752 .959 r
.34579 .58749 m .34796 .5874 L .34949 .58793 L F
.352 .782 .97 r
.35019 .5872 m .34949 .58793 L .34796 .5874 L F
.35019 .5872 m .3516 .58769 L .34949 .58793 L F
.386 .735 .991 r
.36378 .59943 m .3667 .59992 L .36492 .5989 L F
.3638 .59882 m .36492 .5989 L .36382 .59827 L F
.36378 .59943 m .36492 .5989 L .3638 .59882 L F
.36378 .59943 m .3638 .59882 L .3643 .59871 L F
.3638 .59882 m .36382 .59827 L .3643 .59871 L F
.162 .672 .899 r
.35973 .59852 m .3643 .59871 L .36019 .59799 L F
.35972 .59852 m .35981 .59852 L .35973 .59852 L F
.35981 .59852 m .3643 .59871 L .35973 .59852 L F
.38 .796 .977 r
.363 .59947 m .3643 .59871 L .35972 .59852 L F
.363 .59947 m .36378 .59943 L .3643 .59871 L F
.931 .875 .76 r
.64371 .50604 m .64672 .50361 L .6455 .50241 L F
.64371 .50604 m .64482 .5071 L .64672 .50361 L F
.812 .848 .876 r
.6455 .50241 m .64672 .50361 L .65056 .49984 L F
.415 .775 .995 r
.34059 .58584 m .34005 .58688 L .33857 .58573 L F
.34059 .58584 m .34201 .58656 L .34005 .58688 L F
.983 .725 .462 r
.57188 .58545 m .57358 .58678 L .57248 .58366 L F
.848 .523 .437 r
.57447 .58582 m .57403 .58576 L .57248 .58366 L F
.307 .391 .785 r
.57358 .58678 m .57427 .58609 L .57403 .58576 L F
.57261 .58402 m .57403 .58576 L .57248 .58366 L F
.57346 .58643 m .57403 .58576 L .57261 .58402 L F
.739 .82 .355 r
.57417 .58593 m .57403 .58576 L .57447 .58582 L F
.57115 .58694 m .57067 .58855 L .57188 .58545 L F
.57115 .58694 m .57403 .58576 L .57417 .58593 L F
.146 .382 .834 r
.57248 .58366 m .57509 .58527 L .57447 .58582 L F
.532 .115 .196 r
.57509 .58527 m .57417 .58593 L .57447 .58582 L F
.307 .391 .785 r
.57427 .58609 m .57509 .58527 L .57248 .58366 L F
.532 .115 .196 r
.57509 .58527 m .57115 .58694 L .57417 .58593 L F
.307 .391 .785 r
.57358 .58678 m .57386 .58614 L .57346 .58643 L F
.57386 .58614 m .57403 .58576 L .57346 .58643 L F
.739 .82 .355 r
.57115 .58694 m .57188 .58545 L .57403 .58576 L F
.848 .523 .437 r
.57403 .58576 m .57188 .58545 L .57248 .58366 L F
.608 .905 .985 r
.57618 .5859 m .57509 .58527 L .57358 .58678 L F
.823 .682 .708 r
.62889 .53138 m .6297 .53474 L .63006 .53273 L F
.62889 .53138 m .62643 .53454 L .6297 .53474 L F
.821 .701 .732 r
.62643 .53454 m .62764 .53788 L .6297 .53474 L F
.638 .957 .778 r
.46537 .67423 m .46288 .67515 L .46138 .67284 L F
.46537 .67423 m .46189 .67648 L .46288 .67515 L F
.525 .84 .999 r
.46472 .67662 m .46537 .67423 L .46621 .67459 L F
.46472 .67662 m .46189 .67648 L .46537 .67423 L F
0 0 0 r
.57232 .66317 m .56967 .66492 L .57028 .66304 L F
.57232 .66317 m .57132 .66442 L .56967 .66492 L F
.436 .737 .991 r
.57232 .66317 m .57156 .66202 L .57132 .66442 L F
.57232 .66317 m .57442 .66289 L .57156 .66202 L F
.867 .638 .59 r
.60975 .56878 m .60712 .56848 L .60698 .56602 L F
.874 .695 .656 r
.60975 .56878 m .60705 .57101 L .60712 .56848 L F
.60975 .56878 m .60904 .57321 L .60705 .57101 L F
.678 .207 0 r
.71218 .46096 m .71363 .46303 L .71451 .46388 L F
.867 .96 .863 r
.7117 .46519 m .71451 .46388 L .71363 .46303 L F
.7117 .46519 m .71187 .46643 L .71451 .46388 L F
.443 .226 .487 r
.60064 .60559 m .60298 .60274 L .60082 .60339 L F
.319 .719 .98 r
.43856 .69662 m .43798 .69747 L .43699 .6958 L F
.43856 .69662 m .4402 .69753 L .43798 .69747 L F
.167 .423 .86 r
.5344 .69426 m .53708 .69588 L .53533 .69575 L F
.406 .121 .363 r
.53672 .69825 m .53533 .69575 L .53708 .69588 L F
.53672 .69825 m .5346 .69885 L .53533 .69575 L F
.51 .831 1 r
.47251 .6682 m .46927 .6679 L .47027 .66875 L F
.785 .583 .627 r
.57233 .62285 m .57539 .62041 L .57382 .6197 L F
.57233 .62285 m .57529 .62285 L .57539 .62041 L F
.39 .19 .484 r
.57647 .66134 m .57919 .66141 L .57983 .66174 L F
.085 0 0 r
.57919 .66141 m .58218 .65904 L .57983 .66174 L F
.962 .805 .64 r
.74438 .49367 m .74553 .49516 L .7445 .49214 L F
.878 .846 .809 r
.74206 .49716 m .74553 .49516 L .74438 .49367 L F
.74206 .49716 m .74326 .49835 L .74553 .49516 L F
.579 .544 .78 r
.74553 .49516 m .7472 .49163 L .7445 .49214 L F
.74553 .49516 m .7481 .49469 L .7472 .49163 L F
.312 .316 .703 r
.74553 .49516 m .74789 .49744 L .7481 .49469 L F
.802 .825 .869 r
.6851 .50601 m .68887 .5047 L .68755 .50326 L F
.642 .488 .659 r
.5878 .63721 m .58874 .6405 L .58639 .64087 L F
.728 .645 .766 r
.58953 .63654 m .58874 .6405 L .5878 .63721 L F
.422 .031 .191 r
.51836 .70256 m .51504 .70482 L .51613 .7029 L F
.519 .667 .929 r
.50777 .78371 m .50559 .78455 L .50396 .78155 L F
0 .075 .619 r
.28978 .64404 m .29108 .64601 L .29087 .64539 L F
.566 .576 .822 r
.28818 .64175 m .2896 .64367 L .28707 .64564 L F
.988 .777 .532 r
.28977 .64425 m .29108 .64601 L .28978 .64404 L F
.29011 .64544 m .29108 .64601 L .28977 .64425 L F
.566 .576 .822 r
.2896 .64367 m .29087 .64539 L .29011 .64544 L F
.085 .34 .813 r
.28978 .64404 m .29087 .64539 L .28978 .64392 L F
.28978 .64404 m .28818 .64175 L .29041 .64138 L F
.28978 .64404 m .28978 .64392 L .28818 .64175 L F
.28978 .64404 m .29041 .64138 L .28985 .64269 L F
.28978 .64404 m .28985 .64269 L .28967 .64313 L F
.566 .576 .822 r
.2896 .64367 m .28972 .64408 L .28707 .64564 L F
.28968 .64411 m .28901 .64551 L .28707 .64564 L F
.28972 .64408 m .28969 .64413 L .28968 .64411 L F
.28969 .64413 m .28901 .64551 L .28968 .64411 L F
.28972 .64408 m .29011 .64544 L .28901 .64551 L F
.381 .774 .988 r
.29011 .64544 m .29108 .64601 L .28707 .64564 L F
.65 .225 .224 r
.28707 .64564 m .29108 .64601 L .28959 .64774 L F
.28707 .64564 m .28959 .64774 L .2872 .64828 L F
.875 .667 .618 r
.28761 .64633 m .28959 .64774 L .28977 .64425 L F
.28969 .64413 m .28977 .64425 L .28978 .64404 L F
.28761 .64633 m .28977 .64425 L .28969 .64413 L F
.28761 .64633 m .28969 .64413 L .28967 .64313 L F
.28969 .64413 m .28978 .64404 L .28977 .64398 L F
.28969 .64413 m .28977 .64398 L .28967 .64313 L F
.988 .777 .532 r
.28972 .6452 m .29011 .64544 L .28977 .64425 L F
.28959 .64774 m .29108 .64601 L .28972 .6452 L F
.381 .774 .988 r
.29087 .64539 m .29108 .64601 L .29011 .64544 L F
.848 .695 .162 r
.65723 .51806 m .65698 .51786 L .65707 .51643 L F
.628 .244 0 r
.65723 .51806 m .65782 .51919 L .65698 .51786 L F
.458 0 .062 r
.47265 .69849 m .47503 .69849 L .4764 .6969 L F
.56 .347 .547 r
.47952 .69439 m .4764 .6969 L .47864 .69653 L F
.744 .327 .26 r
.47503 .69849 m .47866 .69923 L .4764 .6969 L F
.567 .368 .57 r
.4764 .6969 m .47866 .69923 L .47864 .69653 L F
.517 .703 .955 r
.38045 .5906 m .37962 .59248 L .3784 .59073 L F
.38045 .5906 m .38186 .59215 L .37962 .59248 L F
.684 .458 .574 r
.48372 .64847 m .48404 .65307 L .48054 .65151 L F
.366 0 0 r
.48372 .64847 m .48467 .64904 L .48618 .64848 L F
.095 0 .427 r
.48443 .6483 m .48467 .64904 L .48372 .64847 L F
.239 .129 .521 r
.48525 .64966 m .48372 .64847 L .48467 .64904 L F
.48525 .64966 m .48404 .65307 L .48382 .64996 L F
0 0 0 r
.48525 .64966 m .48446 .65002 L .48597 .64951 L F
.696 .272 .237 r
.48618 .64848 m .48838 .65029 L .48525 .64966 L F
0 0 0 r
.48525 .64966 m .48597 .64951 L .4886 .64862 L F
.239 .129 .521 r
.48525 .64966 m .48382 .64996 L .48372 .64847 L F
.824 .807 .834 r
.71698 .50089 m .71772 .50374 L .72006 .50102 L F
.662 .408 .526 r
.58225 .6171 m .58548 .61457 L .58223 .61466 L F
.58225 .6171 m .5855 .61664 L .58548 .61457 L F
.622 .434 .607 r
.5855 .61664 m .58783 .61419 L .58548 .61457 L F
.576 .094 0 r
.56345 .65934 m .56323 .65918 L .56143 .65701 L F
.696 .348 0 r
.56345 .65934 m .56414 .66126 L .56323 .65918 L F
.56345 .65934 m .56469 .66242 L .56414 .66126 L F
.939 .7 .226 r
.60933 .57997 m .60902 .57973 L .60887 .57744 L F
.957 .844 .421 r
.60933 .57997 m .60853 .58205 L .60902 .57973 L F
.613 .826 .982 r
.52863 .64077 m .5256 .64034 L .52773 .63959 L F
.358 .646 .965 r
.53017 .63964 m .52863 .64077 L .52773 .63959 L F
.53017 .63964 m .53175 .64114 L .52863 .64077 L F
0 0 0 r
.66732 .47895 m .67023 .47873 L .67098 .47867 L F
.381 0 0 r
.67023 .47873 m .67342 .47845 L .67098 .47867 L F
.566 .488 .726 r
.5256 .64034 m .52334 .64095 L .52228 .63663 L F
.63 .744 .93 r
.69557 .49862 m .70004 .50011 L .69794 .49807 L F
.609 .753 .947 r
.69794 .49807 m .70004 .50011 L .70103 .49933 L F
0 .18 .711 r
.5206 .63415 m .52273 .63606 L .52228 .63663 L F
0 .414 .844 r
.52273 .63606 m .52406 .63721 L .52228 .63663 L F
.566 .488 .726 r
.5256 .64034 m .52228 .63663 L .52406 .63721 L F
.893 .619 .514 r
.66061 .48426 m .65939 .48635 L .66075 .48661 L F
.649 .6 .786 r
.66194 .48018 m .66061 .48426 L .65969 .4807 L F
.66194 .48018 m .66291 .48421 L .66061 .48426 L F
.142 0 .075 r
.66223 .48486 m .66061 .48426 L .66291 .48421 L F
.276 .359 .768 r
.66335 .48578 m .66061 .48426 L .66075 .48661 L F
.142 0 .075 r
.66223 .48486 m .65939 .48635 L .66061 .48426 L F
.071 0 .271 r
.54131 .76076 m .54225 .76122 L .54255 .75926 L F
.974 .796 .602 r
.73034 .51558 m .72993 .51774 L .72869 .51691 L F
.321 0 0 r
.44032 .70791 m .4362 .70909 L .43701 .70849 L F
.44032 .70791 m .43881 .70907 L .4362 .70909 L F
.381 0 .001 r
.4424 .70741 m .43881 .70907 L .44032 .70791 L F
.898 .634 .53 r
.56065 .61472 m .56401 .6142 L .56352 .61596 L F
0 0 0 r
.56712 .61189 m .56592 .61324 L .56401 .6142 L F
.56592 .61324 m .56352 .61596 L .56401 .6142 L F
.627 .504 .693 r
.61828 .52344 m .62041 .52038 L .61823 .52102 L F
.855 .651 .626 r
.62889 .53138 m .63006 .53273 L .62857 .52938 L F
.631 .416 .573 r
.53964 .65103 m .53733 .64966 L .53967 .64859 L F
.53964 .65103 m .53737 .65263 L .53733 .64966 L F
.528 .327 .552 r
.5801 .61747 m .58225 .6171 L .58223 .61466 L F
.6 .205 .265 r
.47763 .70249 m .474 .70417 L .47439 .70288 L F
.47763 .70249 m .47629 .70457 L .474 .70417 L F
.491 .059 .146 r
.48107 .70255 m .47629 .70457 L .47763 .70249 L F
.696 .687 .837 r
.27223 .64293 m .27555 .64374 L .27477 .64182 L F
.6 .618 .841 r
.27477 .64182 m .27555 .64374 L .27809 .6432 L F
.561 .299 .476 r
.42352 .66242 m .42666 .65929 L .42405 .66023 L F
.72 .775 .897 r
.27765 .63072 m .27925 .63199 L .28162 .63095 L F
.3 .762 .947 r
.31202 .58314 m .31402 .583 L .31568 .58339 L F
.119 .643 .879 r
.31557 .58321 m .31568 .58339 L .31402 .583 L F
.31557 .58321 m .31739 .58353 L .31568 .58339 L F
.14 0 0 r
.50607 .64273 m .50462 .64441 L .50245 .645 L F
.721 .289 .224 r
.50607 .64273 m .50809 .64493 L .50462 .64441 L F
.568 .538 .781 r
.63277 .50724 m .6341 .50306 L .63183 .50363 L F
.709 .492 .592 r
.63277 .50724 m .63745 .5087 L .63433 .50829 L F
.568 .538 .781 r
.63277 .50724 m .63433 .50829 L .6341 .50306 L F
0 0 .545 r
.52708 .60859 m .52854 .61183 L .52837 .61084 L F
0 .054 .557 r
.52854 .61183 m .5297 .61279 L .52837 .61084 L F
.52854 .61183 m .53076 .61389 L .5297 .61279 L F
0 0 0 r
.46607 .67497 m .46621 .67459 L .46676 .67237 L F
.46607 .67497 m .46472 .67662 L .46621 .67459 L F
.271 0 .198 r
.36139 .63386 m .35876 .63609 L .35927 .63441 L F
.571 .404 .616 r
.59072 .6281 m .58869 .63222 L .58828 .62862 L F
.664 .64 .816 r
.5743 .63427 m .57073 .63143 L .57109 .63334 L F
.5743 .63427 m .57417 .63018 L .57073 .63143 L F
.985 .716 .422 r
.57109 .63334 m .57254 .63507 L .5743 .63427 L F
.164 .224 .68 r
.5743 .63427 m .57433 .63159 L .57417 .63018 L F
.66 .721 .894 r
.5743 .63427 m .57686 .63101 L .57433 .63159 L F
.5743 .63427 m .57791 .6343 L .57686 .63101 L F
0 0 .206 r
.30408 .72697 m .30442 .72779 L .30467 .72494 L F
.783 .874 .915 r
.7304 .51283 m .73325 .51139 L .73335 .50937 L F
.772 .888 .928 r
.73325 .51139 m .73546 .5082 L .73335 .50937 L F
.73325 .51139 m .73645 .50926 L .73546 .5082 L F
.305 0 0 r
.28982 .58799 m .29203 .58769 L .29262 .5869 L F
.445 0 .03 r
.29203 .58769 m .29429 .58773 L .29262 .5869 L F
.47 .207 .432 r
.3798 .62017 m .3794 .62231 L .37721 .6228 L F
.495 .238 .454 r
.38195 .61973 m .3794 .62231 L .3798 .62017 L F
.639 .471 .64 r
.60081 .61745 m .60351 .62026 L .60084 .61982 L F
.60081 .61745 m .60337 .61716 L .60351 .62026 L F
.712 .773 .9 r
.42077 .70494 m .42242 .70783 L .4233 .70551 L F
.31 0 0 r
.44864 .70571 m .44714 .70689 L .44489 .707 L F
.071 0 0 r
.45079 .70575 m .44714 .70689 L .44864 .70571 L F
.728 .664 .786 r
.58607 .64562 m .58861 .64278 L .589 .64616 L F
.561 .441 .674 r
.59052 .64301 m .589 .64616 L .58861 .64278 L F
.59052 .64301 m .59159 .64585 L .589 .64616 L F
.562 .451 .685 r
.589 .64616 m .59159 .64585 L .58963 .64847 L F
0 0 .493 r
.33103 .60129 m .33108 .60086 L .32872 .60154 L F
.33103 .60129 m .33164 .60181 L .33108 .60086 L F
.979 .789 .577 r
.62769 .56609 m .62686 .563 L .62659 .56519 L F
.958 .873 .709 r
.62534 .56827 m .62769 .56609 L .62659 .56519 L F
.62534 .56827 m .62638 .56936 L .62769 .56609 L F
.523 .871 .989 r
.48926 .6211 m .49042 .61988 L .49162 .62058 L F
.48926 .6211 m .4881 .6206 L .49042 .61988 L F
.187 .72 .809 r
.4402 .69753 m .44258 .69714 L .44392 .69721 L F
.049 0 0 r
.44258 .69714 m .44593 .69688 L .44392 .69721 L F
.752 .306 .192 r
.29302 .63952 m .29551 .64013 L .29509 .64098 L F
.444 .309 .602 r
.29564 .64218 m .29749 .64212 L .29551 .64013 L F
0 .012 .519 r
.29551 .64013 m .29607 .64064 L .29509 .64098 L F
.29551 .64013 m .29749 .64212 L .29607 .64064 L F
.823 .911 .899 r
.53149 .59976 m .52873 .60052 L .53069 .59926 L F
.61 .921 .974 r
.53149 .59976 m .53282 .59815 L .53425 .5981 L F
.53149 .59976 m .53069 .59926 L .53282 .59815 L F
.526 .085 .144 r
.69421 .46611 m .69729 .46607 L .69788 .46464 L F
0 0 0 r
.69788 .46464 m .69858 .46495 L .6983 .46402 L F
.69788 .46464 m .69729 .46607 L .69858 .46495 L F
.717 .679 .812 r
.48308 .80593 m .48479 .80449 L .48169 .80405 L F
.57 .483 .717 r
.75636 .49179 m .75691 .49552 L .75461 .49604 L F
.525 .414 .67 r
.75691 .49552 m .75499 .49818 L .75461 .49604 L F
0 0 .069 r
.75591 .5199 m .75347 .52277 L .75434 .52126 L F
.057 .285 .775 r
.48458 .79512 m .48378 .79559 L .48231 .79314 L F
.437 .596 .911 r
.40774 .6944 m .41132 .69686 L .41005 .69368 L F
.378 .271 .604 r
.40884 .68551 m .40909 .68778 L .41075 .68761 L F
0 0 .457 r
.41132 .69686 m .41137 .69614 L .41005 .69368 L F
0 .298 .793 r
.41356 .69883 m .41132 .69686 L .41124 .6993 L F
.41356 .69883 m .41137 .69614 L .41132 .69686 L F
.466 .283 .548 r
.41088 .68498 m .40884 .68551 L .41075 .68761 L F
.784 .998 .821 r
.74061 .47276 m .73751 .47487 L .73968 .47152 L F
0 .349 .813 r
.74263 .47326 m .74061 .47276 L .73968 .47152 L F
.74263 .47326 m .74339 .47436 L .74061 .47276 L F
.11 .4 .853 r
.74061 .47276 m .74339 .47436 L .7438 .47574 L F
.615 .891 .578 r
.47923 .65041 m .4782 .65185 L .48054 .65151 L F
.47923 .65041 m .47683 .65305 L .4782 .65185 L F
.375 .601 .935 r
.55915 .62724 m .55886 .62934 L .5579 .62805 L F
.586 .318 .477 r
.62717 .51157 m .62958 .5097 L .62747 .50988 L F
.666 .86 .974 r
.75036 .52699 m .74681 .52691 L .74745 .52573 L F
.731 .25 .101 r
.41543 .70225 m .41581 .70347 L .41525 .70222 L F
.275 .334 .743 r
.41376 .70142 m .41543 .70225 L .41446 .70048 L F
.731 .25 .101 r
.41543 .70225 m .41525 .70222 L .41446 .70048 L F
0 0 0 r
.41543 .70225 m .41513 .70236 L .41592 .70231 L F
.41543 .70225 m .41592 .70231 L .41837 .70216 L F
.41543 .70225 m .41477 .70421 L .41513 .70236 L F
.149 .183 .641 r
.57955 .63971 m .58064 .64008 L .58015 .63627 L F
.021 .301 .794 r
.57955 .63971 m .5818 .64121 L .58064 .64008 L F
.459 .197 .429 r
.58721 .56897 m .58768 .57062 L .58462 .57213 L F
.457 .229 .479 r
.5896 .56634 m .58951 .56864 L .58721 .56897 L F
.51 .274 .493 r
.58951 .56864 m .58768 .57062 L .58721 .56897 L F
.278 .029 .346 r
.55985 .62208 m .55736 .62445 L .55803 .62384 L F
.655 .381 .492 r
.42921 .65932 m .43165 .65952 L .43197 .65726 L F
.478 .225 .452 r
.43197 .65726 m .43393 .65901 L .43494 .6563 L F
.43197 .65726 m .43165 .65952 L .43393 .65901 L F
.543 .326 .536 r
.45415 .66509 m .45138 .66771 L .45206 .66618 L F
.79 .716 .782 r
.65802 .49183 m .65997 .49269 L .66198 .49033 L F
.822 .684 .711 r
.65802 .49183 m .65943 .49512 L .65997 .49269 L F
.611 .194 0 r
.73651 .52927 m .73721 .53044 L .73498 .52828 L F
0 .351 .824 r
.73721 .53044 m .73887 .53072 L .73715 .53037 L F
.921 .553 .309 r
.73721 .53044 m .73483 .52785 L .73498 .52828 L F
.73721 .53044 m .73584 .53011 L .73483 .52785 L F
0 .351 .824 r
.73721 .53044 m .73715 .53037 L .73584 .53011 L F
.611 .194 0 r
.73651 .52927 m .73727 .5305 L .73721 .53044 L F
.73727 .5305 m .73798 .53164 L .73721 .53044 L F
0 0 0 r
.65843 .48082 m .66194 .48018 L .65969 .4807 L F
.436 .745 .993 r
.5011 .81066 m .50358 .81061 L .50216 .8095 L F
.877 .818 .787 r
.72752 .50465 m .72422 .50648 L .72599 .50325 L F
.564 .358 .56 r
.67695 .49262 m .67755 .49472 L .67961 .49139 L F
.542 .38 .611 r
.67704 .49494 m .67755 .49472 L .67695 .49262 L F
.118 .606 .911 r
.49728 .62012 m .49921 .6204 L .50057 .62121 L F
.271 0 0 r
.49921 .6204 m .50321 .62196 L .50057 .62121 L F
.499 .384 .654 r
.26959 .60312 m .27125 .60014 L .26917 .6007 L F
.905 .975 .801 r
.68378 .49788 m .68524 .49428 L .68645 .4957 L F
.68378 .49788 m .68304 .49728 L .68524 .49428 L F
.625 .701 .899 r
.66805 .52043 m .67175 .52146 L .67045 .52018 L F
.84 .827 .835 r
.67045 .52018 m .67175 .52146 L .67412 .51842 L F
0 .562 .715 r
.55452 .6081 m .55065 .60794 L .55102 .60603 L F
.684 .646 .807 r
.52863 .78784 m .52912 .78979 L .53102 .78728 L F
.984 .778 .548 r
.56542 .63048 m .56511 .62818 L .56432 .62942 L F
.56542 .63048 m .5672 .62813 L .56511 .62818 L F
.691 .806 .936 r
.48065 .6936 m .47952 .69439 L .47784 .69309 L F
.47784 .69309 m .47952 .69439 L .48065 .6936 L F
.487 .282 .527 r
.5919 .56569 m .58951 .56864 L .5896 .56634 L F
.757 .649 .742 r
.49501 .7704 m .49608 .77356 L .49832 .77057 L F
.427 .118 .336 r
.37215 .62615 m .37175 .62772 L .3695 .62822 L F
.484 .169 .356 r
.37215 .62615 m .37396 .62747 L .37175 .62772 L F
.479 .172 .367 r
.37441 .62575 m .37396 .62747 L .37215 .62615 L F
.66 .5 .656 r
.67454 .48118 m .67436 .48435 L .67222 .48392 L F
.685 .521 .658 r
.67776 .48339 m .67436 .48435 L .67454 .48118 L F
.041 0 0 r
.36522 .61068 m .36561 .60856 L .36466 .60826 L F
.36522 .61068 m .36835 .60891 L .36561 .60856 L F
.585 .497 .721 r
.54551 .61287 m .54381 .61682 L .54362 .61486 L F
.404 .161 .428 r
.58006 .61976 m .58225 .6171 L .5801 .61747 L F
.92 .556 .121 r
.74672 .52354 m .74626 .52427 L .74611 .52266 L F
.74672 .52354 m .74745 .52573 L .74626 .52427 L F
.535 .448 .703 r
.40948 .67689 m .41105 .67322 L .40924 .67401 L F
.124 .074 .524 r
.5475 .65065 m .54609 .65228 L .54659 .65129 L F
.449 .499 .818 r
.54892 .65378 m .54609 .65228 L .5475 .65065 L F
.717 .24 .115 r
.56302 .62388 m .56253 .62501 L .5602 .62308 L F
.699 .22 .108 r
.56432 .62521 m .56253 .62501 L .56302 .62388 L F
.57 .318 .494 r
.30984 .61111 m .30946 .61383 L .30678 .61376 L F
.519 .348 .589 r
.31202 .60877 m .31142 .61086 L .30984 .61111 L F
.454 .208 .45 r
.31142 .61086 m .30946 .61383 L .30984 .61111 L F
.145 0 .025 r
.63824 .49401 m .64161 .49142 L .63853 .49277 L F
.309 .02 .301 r
.37086 .60607 m .37014 .60809 L .3727 .60543 L F
.07 0 0 r
.32646 .64812 m .32558 .64807 L .32562 .64806 L F
.329 .812 .868 r
.3277 .64753 m .32558 .64807 L .32646 .64812 L F
.39 0 0 r
.3277 .64753 m .32552 .64809 L .32558 .64807 L F
.32552 .64809 m .32402 .64847 L .32558 .64807 L F
.07 0 0 r
.32562 .64806 m .32558 .64807 L .32363 .64791 L F
.329 .812 .868 r
.3277 .64753 m .32646 .64812 L .32846 .64739 L F
.179 0 0 r
.45443 .70564 m .4531 .70598 L .45079 .70575 L F
.154 0 0 r
.45673 .70526 m .4531 .70598 L .45443 .70564 L F
.79 .716 .782 r
.65802 .49183 m .66198 .49033 L .66053 .48856 L F
.009 .516 .864 r
.3186 .58286 m .31964 .58329 L .32009 .58359 L F
.497 0 0 r
.32009 .58359 m .32475 .58376 L .32096 .58417 L F
.32009 .58359 m .32193 .58424 L .32475 .58376 L F
.009 .516 .864 r
.31964 .58329 m .32193 .58424 L .32009 .58359 L F
.497 0 0 r
.32009 .58359 m .32096 .58417 L .32079 .58418 L F
.217 .741 .794 r
.32193 .58424 m .32569 .58367 L .32475 .58376 L F
0 .505 .839 r
.32475 .58376 m .32569 .58367 L .32741 .58455 L F
.49 .401 .682 r
.43603 .6762 m .43612 .67945 L .43413 .67993 L F
.481 .37 .65 r
.43612 .67945 m .43643 .68195 L .43413 .67993 L F
.518 .765 .986 r
.3667 .59992 m .36688 .59733 L .36382 .59827 L F
.3667 .59992 m .36858 .59939 L .36688 .59733 L F
.783 .874 .915 r
.7304 .51283 m .73335 .50937 L .73042 .51162 L F
.322 .665 .974 r
.57791 .6343 m .5789 .63059 L .57686 .63101 L F
.57791 .6343 m .57887 .63332 L .5789 .63059 L F
.464 .618 .916 r
.6634 .50203 m .66192 .50296 L .6603 .50214 L F
.6634 .50203 m .66422 .50378 L .66192 .50296 L F
.64 .18 .145 r
.44593 .69688 m .44826 .6985 L .44959 .6971 L F
.218 0 0 r
.44826 .6985 m .45203 .69755 L .44959 .6971 L F
.143 .649 .903 r
.31739 .58353 m .32009 .58359 L .32079 .58418 L F
.031 0 .255 r
.60304 .6004 m .60421 .59951 L .60475 .59731 L F
.11 0 .418 r
.60298 .60274 m .60421 .59951 L .60304 .6004 L F
.847 .894 .871 r
.63657 .51212 m .63873 .50893 L .63646 .50965 L F
0 0 0 r
.54873 .60922 m .54783 .61039 L .54581 .61102 L F
.479 .282 .533 r
.54783 .61039 m .54551 .61287 L .54581 .61102 L F
.964 .861 .69 r
.73126 .49288 m .73018 .49191 L .73132 .48882 L F
.966 .905 .708 r
.73009 .49506 m .73018 .49191 L .73126 .49288 L F
.676 .762 .916 r
.48787 .7789 m .4857 .77978 L .48418 .77891 L F
.631 .838 .98 r
.49728 .62012 m .49516 .62095 L .49383 .61987 L F
.225 .729 .9 r
.55523 .61238 m .56017 .61214 L .55998 .61212 L F
.599 .421 .612 r
.56091 .61075 m .5601 .61336 L .56235 .61061 L F
.55993 .61085 m .55999 .61164 L .56091 .61075 L F
.796 .755 .816 r
.56017 .61214 m .55554 .61676 L .55522 .61624 L F
.56017 .61214 m .55522 .61624 L .55869 .61289 L F
.225 .729 .9 r
.55596 .61214 m .55998 .61212 L .55827 .61191 L F
.55639 .612 m .55827 .61191 L .55711 .61177 L F
.55596 .61214 m .55827 .61191 L .55639 .612 L F
.55523 .61238 m .55998 .61212 L .55596 .61214 L F
.676 .534 .685 r
.55658 .60857 m .55625 .61214 L .55993 .61085 L F
.55625 .61214 m .55642 .61214 L .55993 .61085 L F
.16 .293 .752 r
.55928 .6093 m .55883 .61109 L .55756 .6091 L F
.748 .365 .329 r
.55766 .61161 m .55993 .61085 L .55859 .61134 L F
.55782 .61153 m .55993 .61085 L .55766 .61161 L F
.55711 .61177 m .55782 .61153 L .55766 .61161 L F
.55711 .61177 m .55859 .61134 L .55624 .6122 L F
.796 .755 .816 r
.55973 .61209 m .55448 .61501 L .55711 .61177 L F
.748 .365 .329 r
.55711 .61177 m .55855 .61219 L .55993 .61085 L F
.16 .293 .752 r
.55883 .61109 m .55855 .61219 L .55828 .61133 L F
.55883 .61109 m .55828 .61133 L .55756 .6091 L F
.676 .534 .685 r
.55625 .61214 m .55624 .6122 L .55642 .61214 L F
.567 .935 .915 r
.55448 .61501 m .55641 .61176 L .55711 .61177 L F
0 0 .266 r
.55641 .61176 m .55684 .61185 L .55711 .61177 L F
.55684 .61185 m .55855 .61219 L .55711 .61177 L F
.796 .755 .816 r
.56017 .61214 m .55869 .61289 L .55973 .61209 L F
.55869 .61289 m .55448 .61501 L .55973 .61209 L F
.599 .421 .612 r
.55999 .61164 m .56 .61188 L .56091 .61075 L F
.56 .61188 m .5601 .61336 L .56073 .61132 L F
.56 .61188 m .56073 .61132 L .56091 .61075 L F
.796 .755 .816 r
.55869 .61289 m .55522 .61624 L .55448 .61501 L F
.392 0 .034 r
.55886 .61188 m .56235 .61061 L .55993 .61085 L F
.55855 .61219 m .55934 .61186 L .55886 .61188 L F
.55934 .61186 m .56235 .61061 L .55886 .61188 L F
.225 .729 .9 r
.55523 .61238 m .55711 .61177 L .55624 .6122 L F
.573 .357 .549 r
.59164 .54913 m .59409 .54879 L .5941 .5465 L F
.536 .304 .51 r
.59409 .54879 m .59658 .54617 L .5941 .5465 L F
.971 .929 .668 r
.56866 .59683 m .56971 .59498 L .56944 .59267 L F
.792 .582 .616 r
.57156 .66202 m .57442 .66289 L .57496 .65915 L F
.672 .469 .602 r
.57442 .66289 m .57675 .66239 L .57496 .65915 L F
.896 .5 .26 r
.57496 .65915 m .57675 .66239 L .57647 .66134 L F
.792 .678 .738 r
.59855 .62269 m .59968 .62574 L .59649 .62554 L F
.782 .506 .519 r
.59649 .62554 m .59968 .62574 L .59895 .62726 L F
.599 .508 .722 r
.60197 .62345 m .59968 .62574 L .59855 .62269 L F
.60197 .62345 m .60228 .62576 L .59968 .62574 L F
.511 .111 .219 r
.59968 .62574 m .60145 .62756 L .59895 .62726 L F
.59968 .62574 m .60228 .62576 L .60145 .62756 L F
.672 .616 .784 r
.49295 .80365 m .49426 .80603 L .49639 .80437 L F
.567 .744 .96 r
.49278 .79145 m .49387 .79331 L .49698 .79251 L F
.17 .294 .749 r
.54246 .63154 m .54336 .63161 L .54218 .62805 L F
.18 .252 .702 r
.54246 .63154 m .54405 .63417 L .54336 .63161 L F
.58 .402 .605 r
.5901 .60893 m .59251 .60852 L .59246 .60587 L F
.654 .461 .611 r
.59251 .60852 m .59489 .60607 L .59246 .60587 L F
.797 .617 .658 r
.55616 .75574 m .55865 .75831 L .55874 .75621 L F
.606 .43 .618 r
.59018 .61136 m .59251 .60852 L .5901 .60893 L F
.987 .895 .578 r
.52027 .77933 m .52239 .77673 L .52337 .77881 L F
.614 .259 .344 r
.52337 .77881 m .52283 .78118 L .52027 .77933 L F
.062 .268 .76 r
.52414 .7781 m .52337 .77881 L .52239 .77673 L F
0 0 .006 r
.52414 .7781 m .52283 .78118 L .52337 .77881 L F
.435 .641 .943 r
.54859 .63907 m .54967 .63655 L .54791 .63619 L F
.54859 .63907 m .55123 .63885 L .54967 .63655 L F
.945 .649 .198 r
.50323 .78159 m .50433 .78506 L .50324 .78365 L F
.283 .604 .953 r
.50433 .78506 m .50514 .78397 L .50324 .78365 L F
.50433 .78506 m .50646 .78553 L .50514 .78397 L F
.779 .517 .539 r
.50433 .78506 m .50782 .78754 L .50646 .78553 L F
.525 .414 .67 r
.75691 .49552 m .75726 .49761 L .75499 .49818 L F
.489 .406 .689 r
.75772 .4998 m .75499 .49818 L .75726 .49761 L F
.836 .813 .827 r
.66877 .51183 m .66602 .51177 L .66827 .50907 L F
.853 .767 .766 r
.66877 .51183 m .66667 .51504 L .66602 .51177 L F
.843 .816 .824 r
.67103 .50899 m .66877 .51183 L .66827 .50907 L F
.64 .752 .929 r
.70265 .48984 m .7002 .49065 L .69909 .48902 L F
.374 .141 .428 r
.4867 .66296 m .48632 .66507 L .48866 .66224 L F
.4867 .66296 m .48632 .66507 L .48866 .66224 L F
.336 .286 .653 r
.43509 .68804 m .43398 .69069 L .43295 .68872 L F
.43509 .68804 m .43542 .69048 L .43398 .69069 L F
.501 .5 .788 r
.74793 .50918 m .74917 .50548 L .74732 .50668 L F
.395 0 .15 r
.44276 .65304 m .44515 .65268 L .44564 .65163 L F
.354 0 .054 r
.44515 .65268 m .44799 .65144 L .44564 .65163 L F
.618 .882 .553 r
.57143 .6361 m .57033 .63752 L .57254 .63507 L F
.985 .716 .422 r
.57109 .63334 m .57143 .6361 L .57254 .63507 L F
0 0 .228 r
.60695 .58918 m .60654 .59144 L .60778 .58815 L F
.981 .863 .647 r
.7296 .51481 m .73046 .51613 L .72993 .51774 L F
.751 .639 .737 r
.62767 .52598 m .62857 .52938 L .63081 .52633 L F
.522 .324 .554 r
.27019 .65993 m .27003 .66235 L .27265 .65925 L F
.43 .728 .989 r
.39321 .59647 m .39252 .5978 L .39108 .59668 L F
.39321 .59647 m .39473 .59781 L .39252 .5978 L F
.903 .709 .63 r
.65676 .49318 m .65943 .49512 L .65802 .49183 L F
.74 .572 0 r
.65946 .49674 m .65943 .49512 L .65676 .49318 L F
.65946 .49674 m .65961 .49831 L .65943 .49512 L F
.108 .594 .909 r
.3617 .58769 m .36119 .58815 L .3596 .58765 L F
.3617 .58769 m .36317 .58851 L .36119 .58815 L F
.615 .284 .387 r
.58639 .64087 m .58486 .64236 L .58273 .64198 L F
.74 .561 .651 r
.58874 .6405 m .58486 .64236 L .58639 .64087 L F
.846 .649 .636 r
.56065 .61472 m .55952 .61747 L .56284 .61756 L F
.777 .606 .668 r
.55914 .61976 m .56284 .61756 L .55952 .61747 L F
.55914 .61976 m .56246 .62024 L .56284 .61756 L F
.735 .566 .664 r
.56284 .61756 m .56246 .62024 L .56593 .61977 L F
0 .151 .691 r
.74339 .47436 m .74525 .47793 L .7438 .47574 L F
0 0 0 r
.56246 .62024 m .56327 .62058 L .56593 .61977 L F
.346 .818 .761 r
.56593 .61977 m .56752 .619 L .56804 .61891 L F
.774 .55 .595 r
.56327 .62058 m .56752 .619 L .56593 .61977 L F
0 0 .208 r
.50719 .64871 m .50777 .6496 L .50964 .64769 L F
.607 .747 .943 r
.57027 .65838 m .57061 .66051 L .56889 .66046 L F
.504 .239 .446 r
.39732 .60604 m .39697 .60803 L .39468 .60844 L F
.371 .147 .44 r
.39921 .60532 m .39732 .60604 L .39955 .60314 L F
.571 .387 .593 r
.39921 .60532 m .39697 .60803 L .39732 .60604 L F
.775 .653 .728 r
.62512 .52889 m .62857 .52938 L .62767 .52598 L F
.791 .595 .636 r
.62512 .52889 m .62889 .53138 L .62857 .52938 L F
.809 .856 .885 r
.74508 .51868 m .74361 .52019 L .7431 .51859 L F
.899 .495 .226 r
.74611 .52266 m .7431 .51859 L .74361 .52019 L F
.202 0 .245 r
.48342 .70238 m .48462 .70257 L .48534 .70094 L F
.634 .615 .814 r
.48342 .70238 m .4823 .69924 L .48189 .70165 L F
.48342 .70238 m .48534 .70094 L .4823 .69924 L F
.029 .426 .866 r
.48342 .70238 m .48546 .70297 L .48462 .70257 L F
.841 .673 .674 r
.48878 .64569 m .48988 .64857 L .49008 .64427 L F
.48878 .64569 m .4886 .64862 L .48988 .64857 L F
.06 0 0 r
.4886 .64862 m .48932 .64905 L .48988 .64857 L F
.059 .15 .646 r
.49008 .64427 m .48988 .64857 L .49201 .64542 L F
.614 .848 .475 r
.48988 .64857 m .48985 .6486 L .49201 .64542 L F
.48985 .6486 m .4915 .64611 L .49201 .64542 L F
.518 .91 .926 r
.49095 .64311 m .49008 .64427 L .49177 .6433 L F
.059 .15 .646 r
.49008 .64427 m .49201 .64542 L .49177 .6433 L F
.854 .677 .662 r
.49201 .64542 m .49095 .64311 L .49177 .6433 L F
.913 .958 .63 r
.48932 .64905 m .49035 .64572 L .49201 .64542 L F
.854 .677 .662 r
.49201 .64542 m .49035 .64572 L .49095 .64311 L F
.792 .611 .656 r
.49095 .64311 m .49035 .64572 L .494 .64589 L F
.993 .754 .395 r
.49296 .64496 m .494 .64589 L .49172 .64578 L F
.4921 .64521 m .49172 .64578 L .49035 .64572 L F
.49296 .64496 m .49172 .64578 L .4921 .64521 L F
.614 .848 .475 r
.48985 .6486 m .48932 .64905 L .4915 .64611 L F
.485 .261 .499 r
.67119 .48537 m .66848 .484 L .67222 .48392 L F
.577 .121 .133 r
.67447 .4851 m .67119 .48537 L .67222 .48392 L F
.575 .079 .039 r
.67436 .48435 m .67447 .4851 L .67222 .48392 L F
.539 .359 .584 r
.58754 .66794 m .58528 .67088 L .58528 .66843 L F
.138 .643 .904 r
.32741 .58455 m .32935 .5847 L .33092 .58532 L F
.182 .701 .881 r
.32935 .5847 m .33324 .58496 L .33092 .58532 L F
.738 .406 .421 r
.26034 .63373 m .26369 .63419 L .2635 .63207 L F
.569 .28 .438 r
.2635 .63207 m .26369 .63419 L .26593 .63349 L F
.542 .65 .905 r
.70754 .48878 m .70638 .49175 L .7049 .48885 L F
.70754 .48878 m .70822 .49129 L .70638 .49175 L F
.553 .673 .917 r
.48342 .78316 m .4861 .78339 L .48432 .78106 L F
.783 .447 .42 r
.57719 .67117 m .57593 .6734 L .57352 .67061 L F
.655 .294 .348 r
.57719 .67117 m .57945 .67314 L .57593 .6734 L F
.662 .29 .33 r
.57954 .67163 m .57945 .67314 L .57719 .67117 L F
.845 .859 .853 r
.67304 .5174 m .67601 .51691 L .67486 .5158 L F
.67304 .5174 m .67412 .51842 L .67601 .51691 L F
.884 .888 .83 r
.67486 .5158 m .67601 .51691 L .67811 .51402 L F
.22 .421 .847 r
.2861 .64226 m .28369 .64054 L .28609 .63899 L F
.352 0 .132 r
.28256 .64221 m .2849 .64182 L .28369 .64054 L F
.249 0 .24 r
.28369 .64054 m .2849 .64182 L .28609 .63899 L F
.43 .117 .331 r
.28609 .63899 m .28256 .64221 L .28369 .64054 L F
.979 .683 .36 r
.28707 .64564 m .28615 .64643 L .2836 .6453 L F
.28707 .64564 m .2872 .64828 L .28615 .64643 L F
.566 .576 .822 r
.28818 .64175 m .28707 .64564 L .2861 .64226 L F
.228 .124 .522 r
.57528 .66568 m .57675 .66239 L .57442 .66289 L F
.57528 .66568 m .57732 .66446 L .57675 .66239 L F
.054 0 .416 r
.57582 .66774 m .57732 .66446 L .57528 .66568 L F
.858 .936 .873 r
.67919 .51076 m .67885 .51274 L .68002 .51213 L F
.861 .937 .87 r
.67919 .51076 m .68002 .51213 L .68283 .50896 L F
.636 .385 .521 r
.55384 .75492 m .55616 .75574 L .554 .75355 L F
.633 .447 .614 r
.60924 .53739 m .61178 .53463 L .60914 .53502 L F
.604 .208 .265 r
.59773 .56368 m .59876 .56538 L .59434 .56527 L F
.57 .197 .295 r
.60047 .56513 m .59876 .56538 L .59773 .56368 L F
.561 .218 .344 r
.60009 .56369 m .60047 .56513 L .59773 .56368 L F
.499 .384 .654 r
.26959 .60312 m .27156 .60259 L .27125 .60014 L F
.421 .269 .567 r
.26977 .60557 m .27156 .60259 L .26959 .60312 L F
.793 .304 .039 r
.29136 .63788 m .29302 .63952 L .29031 .63836 L F
.507 .732 .974 r
.68177 .49122 m .68409 .49092 L .68277 .49253 L F
.741 .663 .774 r
.68409 .49092 m .68185 .49393 L .68277 .49253 L F
.855 .813 .808 r
.7187 .49986 m .72229 .49807 L .7211 .49691 L F
.7187 .49986 m .72006 .50102 L .72229 .49807 L F
.839 .713 .725 r
.63111 .51417 m .634 .51499 L .63429 .51292 L F
.88 .769 .735 r
.63065 .51688 m .634 .51499 L .63111 .51417 L F
.63065 .51688 m .6322 .51806 L .634 .51499 L F
.653 .539 .712 r
.63429 .51292 m .634 .51499 L .63657 .51212 L F
.456 .222 .469 r
.60841 .6138 m .60601 .61689 L .60633 .61462 L F
0 .136 .683 r
.54024 .62607 m .54172 .62673 L .53979 .62486 L F
.54024 .62607 m .54218 .62805 L .54172 .62673 L F
0 0 0 r
.57108 .62644 m .5736 .62592 L .56968 .62697 L F
.533 .759 .98 r
.50858 .7725 m .51155 .7735 L .50742 .77382 L F
.973 .664 .349 r
.50981 .77661 m .50858 .7725 L .50742 .77382 L F
.824 .807 .834 r
.71698 .50089 m .72006 .50102 L .7187 .49986 L F
0 0 .352 r
.53436 .77589 m .53407 .77824 L .53455 .77852 L F
0 0 .284 r
.53455 .77852 m .53407 .77824 L .53436 .77589 L F
.51 .358 .61 r
.54371 .76258 m .54455 .75966 L .54225 .76122 L F
.54371 .76258 m .54588 .76209 L .54455 .75966 L F
.818 .747 .785 r
.74553 .51555 m .74666 .51765 L .74365 .51724 L F
.819 .744 .781 r
.74365 .51724 m .74666 .51765 L .74508 .51868 L F
.686 .42 .514 r
.50056 .64847 m .49795 .65022 L .49784 .64908 L F
.304 0 .193 r
.6021 .5434 m .60432 .54276 L .60496 .54118 L F
.539 .175 .298 r
.60496 .54118 m .60683 .54245 L .60682 .54025 L F
.60496 .54118 m .60432 .54276 L .60683 .54245 L F
.002 .402 .852 r
.56313 .60386 m .5642 .60538 L .56237 .60442 L F
.041 0 0 r
.36522 .61068 m .36681 .61029 L .36835 .60891 L F
.228 0 0 r
.36681 .61029 m .37014 .60809 L .36835 .60891 L F
.634 .072 0 r
.42077 .70494 m .41543 .70225 L .41837 .70216 L F
.591 .521 .745 r
.58862 .65974 m .58937 .66242 L .58579 .66318 L F
.516 .164 .309 r
.58876 .66374 m .58579 .66318 L .58937 .66242 L F
.58876 .66374 m .58632 .66468 L .58579 .66318 L F
.557 .377 .594 r
.70931 .4791 m .71115 .4796 L .71138 .47657 L F
.569 .187 .277 r
.70931 .4791 m .7118 .48015 L .71115 .4796 L F
0 .314 .735 r
.50891 .62654 m .50775 .62623 L .50699 .62461 L F
.50891 .62654 m .51031 .62754 L .50775 .62623 L F
.743 .604 .034 r
.50782 .78754 m .50777 .78371 L .50646 .78553 L F
.499 .257 .479 r
.41764 .6592 m .41991 .65937 L .42034 .6567 L F
.075 .551 .899 r
.41991 .65937 m .41764 .6592 L .42034 .6567 L F
.696 .929 .967 r
.64079 .50794 m .64482 .5071 L .64371 .50604 L F
0 0 .488 r
.46381 .65711 m .4646 .6588 L .46417 .65834 L F
.481 .652 .934 r
.70898 .48511 m .71233 .48804 L .70854 .48634 L F
.814 .682 .138 r
.65946 .49674 m .65939 .49993 L .65961 .49831 L F
.565 .16 .234 r
.51722 .63576 m .5206 .63415 L .51926 .63343 L F
.477 .228 .457 r
.38977 .61203 m .38936 .61417 L .38716 .61468 L F
.473 .223 .454 r
.39204 .61147 m .38936 .61417 L .38977 .61203 L F
.052 .472 .885 r
.72318 .51354 m .72607 .51539 L .72486 .51374 L F
.032 .371 .839 r
.72486 .51374 m .72607 .51539 L .72869 .51691 L F
0 .287 .715 r
.72826 .51672 m .72993 .51774 L .72869 .51691 L F
.981 .863 .647 r
.7296 .51481 m .72993 .51774 L .72869 .51691 L F
0 0 .472 r
.72869 .51691 m .72988 .51789 L .7295 .51725 L F
.72869 .51691 m .7295 .51725 L .72825 .51519 L F
0 .287 .715 r
.72607 .51539 m .72826 .51672 L .72869 .51691 L F
.212 0 0 r
.50628 .69903 m .50781 .69919 L .50866 .69847 L F
.50628 .69903 m .50575 .69976 L .50781 .69919 L F
.589 .395 .586 r
.60682 .54025 m .60924 .53739 L .60687 .53787 L F
.058 0 .304 r
.56916 .65537 m .56871 .65676 L .57029 .65358 L F
.451 .216 .466 r
.40134 .60471 m .39955 .60314 L .40177 .60271 L F
.40134 .60471 m .39921 .60532 L .39955 .60314 L F
.273 .071 .413 r
.39955 .60314 m .40176 .6002 L .40177 .60271 L F
.485 .546 .843 r
.5535 .64446 m .556 .64513 L .55445 .64192 L F
.941 .625 .411 r
.56557 .61097 m .56592 .61324 L .56712 .61189 L F
.628 .481 .663 r
.59282 .6251 m .59072 .6281 L .59058 .6256 L F
.84 .6 .575 r
.60345 .56341 m .60047 .56513 L .60009 .56369 L F
.60345 .56341 m .60345 .56588 L .60047 .56513 L F
.424 0 .06 r
.68533 .48144 m .68276 .48292 L .68519 .4794 L F
.68533 .48144 m .68542 .48285 L .68276 .48292 L F
.352 0 .064 r
.68783 .48224 m .68533 .48144 L .68758 .47954 L F
.68783 .48224 m .68542 .48285 L .68533 .48144 L F
.939 .851 .729 r
.73009 .49506 m .72746 .49711 L .7292 .49408 L F
.73009 .49506 m .7286 .49812 L .72746 .49711 L F
.966 .905 .708 r
.73009 .49506 m .7292 .49408 L .73018 .49191 L F
.986 .875 .637 r
.5518 .61639 m .55241 .61867 L .55274 .61789 L F
.845 .489 0 r
.63006 .51177 m .63111 .51417 L .63082 .51289 L F
.87 .528 .022 r
.62958 .5097 m .63006 .51177 L .63082 .51289 L F
.839 .713 .725 r
.63111 .51417 m .63429 .51292 L .63082 .51289 L F
.074 .385 .846 r
.535 .61797 m .53744 .61844 L .53395 .61692 L F
.535 .61797 m .5374 .61937 L .53744 .61844 L F
.578 .272 .413 r
.52406 .69957 m .52635 .70125 L .524 .70118 L F
.629 .227 .262 r
.52642 .7 m .52635 .70125 L .52406 .69957 L F
.399 .401 .746 r
.6341 .50306 m .63433 .50829 L .63666 .50485 L F
0 .027 .595 r
.63745 .5087 m .63666 .50485 L .63433 .50829 L F
.86 .745 .735 r
.67103 .50899 m .66827 .50907 L .67012 .50581 L F
.748 .685 .791 r
.6736 .5063 m .67103 .50899 L .67012 .50581 L F
.89 .832 .784 r
.68849 .49242 m .68524 .49428 L .68743 .49129 L F
.68849 .49242 m .68645 .4957 L .68524 .49428 L F
.85 .887 .865 r
.69097 .48985 m .68849 .49242 L .68743 .49129 L F
.462 .052 .176 r
.51093 .69826 m .51333 .69824 L .51448 .69612 L F
.544 .173 .288 r
.51333 .69824 m .51685 .69585 L .51448 .69612 L F
.309 0 0 r
.27882 .59204 m .28116 .59176 L .28162 .59115 L F
.073 0 0 r
.28162 .59115 m .28281 .59108 L .28389 .59057 L F
.28162 .59115 m .28116 .59176 L .28281 .59108 L F
.358 .768 .981 r
.66194 .48018 m .66414 .47995 L .66497 .4807 L F
.792 .689 .751 r
.66497 .4807 m .66291 .48421 L .66194 .48018 L F
.358 .768 .981 r
.66194 .48018 m .66414 .47995 L .66497 .4807 L F
.508 .857 .993 r
.66497 .4807 m .66649 .47938 L .66732 .47895 L F
.66497 .4807 m .66414 .47995 L .66649 .47938 L F
.31 .393 .786 r
.71268 .4815 m .71413 .47966 L .7118 .48015 L F
.71268 .4815 m .71517 .483 L .71413 .47966 L F
.546 .348 .564 r
.41531 .66265 m .41759 .66223 L .41764 .6592 L F
.504 .314 .557 r
.41764 .6592 m .41759 .66223 L .41991 .65937 L F
0 0 .074 r
.45616 .66189 m .45415 .66509 L .45483 .66419 L F
.002 0 0 r
.34196 .62826 m .34556 .62619 L .34238 .62781 L F
.34196 .62826 m .34372 .62765 L .34556 .62619 L F
.26 0 0 r
.34556 .62619 m .34598 .62721 L .34744 .62555 L F
.34556 .62619 m .34372 .62765 L .34598 .62721 L F
.856 .475 .325 r
.52831 .65183 m .52777 .6539 L .52585 .65061 L F
.52831 .65183 m .52585 .65061 L .52608 .64991 L F
.871 .469 .265 r
.52479 .6488 m .52699 .65336 L .52462 .65344 L F
.52578 .65084 m .52777 .6539 L .52699 .65336 L F
.52479 .6488 m .52585 .65061 L .52578 .65084 L F
.52585 .65061 m .52777 .6539 L .52578 .65084 L F
.856 .475 .325 r
.52608 .64991 m .52585 .65061 L .52479 .6488 L F
.468 .081 .221 r
.53047 .65308 m .52777 .6539 L .52831 .65183 L F
.72 .703 .833 r
.5276 .65319 m .53047 .65308 L .52936 .6527 L F
.52699 .65336 m .52762 .65331 L .5276 .65319 L F
.52762 .65331 m .53047 .65308 L .5276 .65319 L F
0 .094 .64 r
.5262 .65005 m .52768 .65368 L .52628 .65009 L F
.52768 .65368 m .52768 .65367 L .52628 .65009 L F
.52529 .64966 m .52777 .6539 L .52618 .65 L F
.907 .589 .433 r
.5278 .6522 m .52675 .65106 L .52791 .65025 L F
.168 0 .137 r
.52628 .65009 m .52568 .65181 L .52675 .65106 L F
.52699 .65042 m .52675 .65106 L .5274 .65061 L F
.52628 .65009 m .52675 .65106 L .52699 .65042 L F
0 .094 .64 r
.52479 .6488 m .52529 .64966 L .52618 .65 L F
.956 .949 .696 r
.52239 .65031 m .52301 .6515 L .52424 .64863 L F
.52404 .64866 m .52424 .64863 L .52436 .64834 L F
.52239 .65031 m .52424 .64863 L .52404 .64866 L F
0 .285 .727 r
.524 .64863 m .52442 .64849 L .52194 .64896 L F
.52258 .64887 m .52194 .64896 L .52136 .64907 L F
.524 .64863 m .52194 .64896 L .52258 .64887 L F
0 .094 .64 r
.52618 .65 m .5262 .65005 L .52628 .65009 L F
0 .073 .603 r
.52618 .65 m .52619 .65 L .52436 .64834 L F
.52479 .6488 m .52618 .65 L .52436 .64834 L F
.871 .469 .265 r
.52479 .6488 m .52462 .65344 L .52628 .65009 L F
0 .316 .768 r
.52619 .65 m .524 .64863 L .52436 .64834 L F
0 .073 .603 r
.52618 .65 m .52628 .65009 L .52619 .65 L F
0 .316 .768 r
.52628 .65009 m .524 .64863 L .52619 .65 L F
0 .285 .727 r
.524 .64863 m .52621 .64993 L .52442 .64849 L F
.52621 .64993 m .52664 .65018 L .52624 .64987 L F
.52621 .64993 m .52624 .64987 L .52442 .64849 L F
0 0 0 r
.52558 .65149 m .52559 .65205 L .52628 .65009 L F
0 .316 .768 r
.52628 .65009 m .5268 .65027 L .524 .64863 L F
.907 .589 .433 r
.52675 .65106 m .52529 .65131 L .52442 .64849 L F
.718 .682 .814 r
.52671 .65118 m .5278 .6522 L .52559 .65205 L F
.907 .589 .433 r
.5278 .6522 m .52671 .65118 L .52675 .65106 L F
.718 .682 .814 r
.52791 .65025 m .5278 .6522 L .52671 .65118 L F
.907 .589 .433 r
.5278 .6522 m .5265 .65174 L .52671 .65118 L F
.168 0 .137 r
.52568 .65181 m .52559 .65205 L .5271 .65085 L F
.52714 .65079 m .5271 .65085 L .5274 .65061 L F
.52568 .65181 m .5271 .65085 L .52714 .65079 L F
0 0 0 r
.52552 .65161 m .52553 .65166 L .52558 .65149 L F
.52553 .65166 m .52559 .65205 L .52558 .65149 L F
.52462 .65344 m .5252 .65262 L .52552 .65161 L F
.5252 .65262 m .52559 .65205 L .52552 .65161 L F
.541 .303 .503 r
.52226 .65378 m .52462 .65344 L .52301 .6515 L F
.52301 .6515 m .52462 .65344 L .52226 .65378 L F
.43 .738 .991 r
.52462 .65344 m .52699 .65336 L .52559 .65205 L F
0 0 0 r
.52834 .65472 m .52559 .65205 L .52699 .65336 L F
.626 .607 .812 r
.5304 .65557 m .52801 .65601 L .52699 .65336 L F
0 .162 .691 r
.52699 .65336 m .52801 .65601 L .52844 .65482 L F
0 0 0 r
.52844 .65482 m .52814 .65453 L .52834 .65472 L F
.52814 .65453 m .52559 .65205 L .52834 .65472 L F
.322 .765 .963 r
.52936 .6527 m .5278 .6522 L .52559 .65205 L F
0 .094 .64 r
.52768 .65368 m .52777 .6539 L .52768 .65367 L F
.72 .703 .833 r
.52699 .65336 m .52777 .6539 L .53047 .65308 L F
.626 .607 .812 r
.5304 .65557 m .52699 .65336 L .52936 .6527 L F
0 0 0 r
.52844 .65482 m .52936 .6527 L .52559 .65205 L F
.786 .428 .379 r
.5278 .6522 m .52629 .65276 L .5265 .65174 L F
.52629 .65276 m .52564 .65301 L .52599 .65248 L F
.52629 .65276 m .52599 .65248 L .5265 .65174 L F
.5265 .65174 m .52432 .6535 L .52529 .65131 L F
.52564 .65301 m .52432 .6535 L .5265 .65174 L F
.907 .589 .433 r
.5265 .65174 m .52529 .65131 L .52675 .65106 L F
.168 0 .137 r
.52628 .65009 m .52743 .65062 L .52751 .65056 L F
.166 0 .321 r
.52628 .65009 m .52791 .65025 L .5268 .65027 L F
.168 0 .137 r
.52638 .6501 m .52751 .65056 L .52791 .65025 L F
0 .285 .727 r
.52675 .65024 m .5268 .65027 L .52677 .65025 L F
.168 0 .137 r
.52628 .65009 m .52751 .65056 L .52638 .6501 L F
0 .285 .727 r
.52664 .65018 m .52675 .65024 L .52671 .65021 L F
.52675 .65024 m .52677 .65025 L .52671 .65021 L F
.52664 .65018 m .52671 .65021 L .52442 .64849 L F
.135 .547 .922 r
.5268 .65027 m .52791 .65025 L .52442 .64849 L F
.907 .589 .433 r
.52675 .65106 m .52442 .64849 L .52791 .65025 L F
.168 0 .137 r
.5274 .65061 m .52559 .65205 L .52743 .65062 L F
.334 .054 .331 r
.27882 .59204 m .28021 .59319 L .28116 .59176 L F
.27882 .59204 m .27828 .59392 L .28021 .59319 L F
.781 .847 .392 r
.52022 .65464 m .51946 .65594 L .52048 .65345 L F
0 0 0 r
.52021 .6552 m .52022 .65464 L .52226 .65378 L F
.52021 .6552 m .51946 .65594 L .52022 .65464 L F
.356 .484 .851 r
.27964 .62307 m .28142 .62269 L .27817 .6204 L F
.421 .137 .374 r
.27892 .62487 m .28142 .62269 L .27964 .62307 L F
.764 .594 .668 r
.66848 .484 m .6664 .4869 L .66652 .48427 L F
.534 .293 .497 r
.66888 .48627 m .6664 .4869 L .66848 .484 L F
.485 .261 .499 r
.67119 .48537 m .66888 .48627 L .66848 .484 L F
.399 0 .043 r
.4867 .70272 m .49018 .70122 L .48828 .70012 L F
.521 0 0 r
.48828 .70012 m .49018 .70122 L .48814 .70013 L F
.555 .106 .141 r
.48814 .70013 m .49018 .70122 L .49151 .69957 L F
.689 .263 .231 r
.49151 .69957 m .49018 .70122 L .49378 .70153 L F
0 .027 .595 r
.63745 .5087 m .63776 .50797 L .63666 .50485 L F
.539 .539 .803 r
.40981 .69111 m .41075 .68761 L .40909 .68778 L F
.40981 .69111 m .41193 .69077 L .41075 .68761 L F
.65 .531 .706 r
.41005 .69368 m .41193 .69077 L .40981 .69111 L F
.179 0 0 r
.70854 .48634 m .70741 .48666 L .70494 .48669 L F
.535 .303 .51 r
.70741 .48666 m .70494 .48669 L .70854 .48634 L F
.481 .652 .934 r
.70854 .48634 m .70898 .48511 L .70741 .48666 L F
0 .376 .798 r
.71047 .48848 m .70741 .48666 L .70854 .48634 L F
.417 0 0 r
.66573 .4851 m .66223 .48486 L .66291 .48421 L F
.514 .039 .066 r
.66652 .48427 m .66573 .4851 L .66291 .48421 L F
.378 .068 .308 r
.37175 .62772 m .36909 .62933 L .3695 .62822 L F
.629 .542 .737 r
.25853 .63354 m .25933 .63739 L .26135 .63644 L F
.211 .025 .396 r
.36302 .61365 m .36476 .61317 L .36522 .61068 L F
.558 .382 .6 r
.36247 .61633 m .36476 .61317 L .36302 .61365 L F
.248 .121 .503 r
.71138 .47657 m .71357 .476 L .71446 .47592 L F
.71138 .47657 m .71115 .4796 L .71357 .476 L F
.634 .131 .037 r
.51642 .65133 m .52048 .65345 L .51625 .65289 L F
.476 .071 .192 r
.45568 .64703 m .45786 .64705 L .45601 .64608 L F
.465 .091 .244 r
.45601 .64608 m .45786 .64705 L .45858 .64577 L F
.66 .604 .782 r
.74793 .50918 m .74931 .5133 L .75169 .51193 L F
.367 .07 .323 r
.75169 .51193 m .74931 .5133 L .75016 .5137 L F
.527 .498 .768 r
.58159 .65146 m .58422 .65284 L .58413 .65139 L F
.72 .775 .897 r
.27765 .63072 m .28162 .63095 L .28013 .62989 L F
.336 .714 .984 r
.28162 .63095 m .28344 .63086 L .28013 .62989 L F
.518 .752 .981 r
.377 .58941 m .37622 .59106 L .37488 .58986 L F
.377 .58941 m .3784 .59073 L .37622 .59106 L F
.196 .478 .893 r
.58963 .64847 m .58966 .64756 L .58607 .64562 L F
.582 .323 .489 r
.58963 .64847 m .5891 .65132 L .58702 .65142 L F
.58963 .64847 m .5891 .65132 L .58702 .65142 L F
.343 .622 .955 r
.58963 .64847 m .59074 .64722 L .58966 .64756 L F
.644 .564 .749 r
.58963 .64847 m .59159 .64585 L .59216 .64823 L F
.627 .441 .611 r
.58963 .64847 m .59026 .64849 L .5891 .65132 L F
.58963 .64847 m .59216 .64823 L .59026 .64849 L F
.555 .499 .747 r
.5891 .65132 m .59074 .64722 L .58963 .64847 L F
.872 .722 .692 r
.62646 .53656 m .62764 .53788 L .62643 .53454 L F
.824 .684 .709 r
.6241 .53965 m .62764 .53788 L .62646 .53656 L F
.6241 .53965 m .62583 .54056 L .62764 .53788 L F
.791 .595 .636 r
.62512 .52889 m .62663 .53214 L .62889 .53138 L F
.813 .665 .7 r
.62663 .53214 m .62643 .53454 L .62889 .53138 L F
.738 .886 .947 r
.66488 .5207 m .66805 .52043 L .66627 .51897 L F
.66488 .5207 m .66805 .52043 L .66627 .51897 L F
.136 .64 .903 r
.63978 .48875 m .64317 .48951 L .64304 .48961 L F
0 .45 .86 r
.46175 .69654 m .46138 .69713 L .45969 .69638 L F
.46175 .69654 m .46359 .69785 L .46138 .69713 L F
.601 .201 .256 r
.52989 .69966 m .52635 .70125 L .52642 .7 L F
.52989 .69966 m .52888 .70169 L .52635 .70125 L F
.325 0 .125 r
.53101 .70118 m .52989 .69966 L .5324 .69958 L F
.53101 .70118 m .52888 .70169 L .52989 .69966 L F
.417 .14 .383 r
.37868 .62462 m .37721 .6228 L .3794 .62231 L F
.37868 .62462 m .37661 .62518 L .37721 .6228 L F
.385 .158 .443 r
.48003 .796 m .48207 .79563 L .48231 .79314 L F
.531 .341 .568 r
.48003 .796 m .47999 .79859 L .48224 .79814 L F
.898 .954 .828 r
.67885 .51274 m .67698 .51348 L .67811 .51402 L F
.884 .888 .83 r
.67486 .5158 m .67811 .51402 L .67698 .51348 L F
.179 .46 .884 r
.50477 .62219 m .50436 .62334 L .50321 .62196 L F
.50477 .62219 m .50699 .62461 L .50436 .62334 L F
0 .555 .765 r
.45958 .66235 m .45842 .66212 L .45616 .66189 L F
.541 .894 .978 r
.46274 .66159 m .46025 .66119 L .45958 .66235 L F
.59 .936 .941 r
.46025 .66119 m .45842 .66212 L .45958 .66235 L F
.65 .836 .972 r
.66041 .52117 m .66153 .52206 L .66488 .5207 L F
.611 .329 .464 r
.59093 .55134 m .59409 .54879 L .59164 .54913 L F
0 0 0 r
.33908 .64402 m .34302 .64249 L .34115 .64367 L F
.34115 .64367 m .34302 .64249 L .34505 .6419 L F
.541 .303 .503 r
.52226 .65378 m .52301 .6515 L .52239 .65031 L F
.61 .478 .677 r
.61178 .53463 m .61373 .53151 L .61147 .532 L F
.656 .175 .1 r
.52027 .77933 m .51919 .78068 L .52146 .77793 L F
.52027 .77933 m .52283 .78118 L .51919 .78068 L F
.564 .132 .179 r
.31759 .64821 m .31428 .64872 L .31528 .64818 L F
.058 .623 .759 r
.33672 .6006 m .33737 .60046 L .33557 .60062 L F
.33672 .6006 m .33901 .60056 L .33737 .60046 L F
.738 .718 .833 r
.71126 .49186 m .70987 .49268 L .70822 .49129 L F
0 .35 .676 r
.66202 .50667 m .66103 .50628 L .65877 .50545 L F
.243 0 0 r
.66202 .50667 m .66458 .50663 L .6647 .50711 L F
.66458 .50663 m .66487 .50663 L .6647 .50711 L F
.997 .768 .439 r
.66602 .51177 m .66474 .50725 L .66627 .50754 L F
.66474 .50725 m .6647 .50711 L .66487 .50716 L F
.66474 .50725 m .66487 .50716 L .66627 .50754 L F
.66571 .51067 m .6651 .51076 L .6647 .50711 L F
.66602 .51177 m .6651 .51076 L .66571 .51067 L F
0 0 0 r
.66374 .51261 m .66451 .51084 L .6651 .51076 L F
0 0 .29 r
.66474 .50723 m .6651 .51076 L .66528 .50905 L F
.66472 .50726 m .6651 .51076 L .66474 .50723 L F
0 0 0 r
.66451 .51084 m .66528 .50905 L .6651 .51076 L F
0 0 .29 r
.6647 .50711 m .66472 .50726 L .66474 .50723 L F
.6647 .50711 m .66474 .50723 L .66473 .50721 L F
.218 .41 .838 r
.66202 .50667 m .6647 .50711 L .66441 .50621 L F
.874 .601 .522 r
.66412 .50534 m .66457 .50729 L .66472 .50719 L F
0 0 .29 r
.6647 .50711 m .66475 .50729 L .66441 .50621 L F
.66475 .50729 m .66442 .50625 L .66441 .50621 L F
.571 .437 .66 r
.66714 .50563 m .66487 .50663 L .66422 .50378 L F
.881 .728 .688 r
.66714 .50563 m .6647 .50711 L .66487 .50663 L F
.874 .601 .522 r
.66414 .50534 m .66472 .50719 L .66714 .50563 L F
.943 .628 .408 r
.6624 .50407 m .66441 .50621 L .66412 .50534 L F
.874 .601 .522 r
.66412 .50534 m .66472 .50719 L .66414 .50534 L F
0 0 .29 r
.66475 .50729 m .66478 .50739 L .66442 .50625 L F
.881 .728 .688 r
.66714 .50563 m .66627 .50754 L .6647 .50711 L F
.503 .875 .662 r
.66645 .50608 m .66482 .50713 L .66726 .50552 L F
.66482 .50713 m .66457 .50729 L .66483 .50712 L F
.66482 .50713 m .66483 .50712 L .66726 .50552 L F
0 0 .29 r
.66473 .50721 m .66528 .50905 L .66478 .50739 L F
.66474 .50723 m .66528 .50905 L .66473 .50721 L F
.388 .464 .817 r
.66592 .50187 m .66714 .50563 L .66422 .50378 L F
.878 .75 .717 r
.66592 .50187 m .66412 .50534 L .66714 .50563 L F
.503 .875 .662 r
.66726 .50552 m .66472 .50719 L .66847 .50442 L F
.66472 .50719 m .66457 .50729 L .66471 .50718 L F
.66472 .50719 m .66471 .50718 L .66847 .50442 L F
.66714 .50563 m .66645 .50608 L .66726 .50552 L F
.492 .27 .505 r
.62494 .51229 m .62744 .5137 L .62717 .51157 L F
.62494 .51229 m .62478 .51443 L .62744 .5137 L F
.321 .764 .964 r
.3653 .58834 m .3668 .58889 L .36317 .58851 L F
.308 .731 .973 r
.36748 .58811 m .3668 .58889 L .3653 .58834 L F
.36748 .58811 m .36893 .58884 L .3668 .58889 L F
.075 0 .457 r
.60421 .59951 m .60564 .59585 L .60475 .59731 L F
.369 0 .103 r
.7165 .47476 m .71911 .47423 L .71975 .47262 L F
.607 .882 .562 r
.72258 .46951 m .71975 .47262 L .72109 .47091 L F
.167 0 .029 r
.71975 .47262 m .72134 .47324 L .72109 .47091 L F
.71975 .47262 m .71911 .47423 L .72134 .47324 L F
.392 .651 .961 r
.51378 .79188 m .51486 .79316 L .51599 .79198 L F
.51378 .79188 m .51486 .79316 L .51599 .79198 L F
0 .562 .715 r
.55452 .6081 m .55259 .60801 L .55065 .60794 L F
.308 0 0 r
.55452 .6081 m .55658 .60857 L .55259 .60801 L F
.439 .265 .547 r
.58617 .55666 m .58419 .55499 L .58385 .55719 L F
.58617 .55666 m .58617 .5542 L .58419 .55499 L F
.611 .483 .682 r
.58826 .6464 m .58861 .64278 L .58607 .64562 L F
.656 .372 .478 r
.58607 .64562 m .58966 .64756 L .58826 .6464 L F
0 0 0 r
.68972 .47826 m .68861 .478 L .69108 .47885 L F
.68972 .47826 m .68758 .47954 L .68861 .478 L F
.571 .856 .996 r
.46064 .67049 m .45851 .67133 L .45688 .67057 L F
.45688 .67057 m .45851 .67133 L .46064 .67049 L F
.5 .18 .355 r
.43393 .65901 m .43716 .65627 L .43494 .6563 L F
.403 .814 .977 r
.70538 .46072 m .70454 .46032 L .7067 .46028 L F
.015 0 0 r
.53927 .59718 m .54156 .59661 L .54278 .59542 L F
0 0 0 r
.54278 .59542 m .54347 .59556 L .54494 .59432 L F
.54278 .59542 m .54156 .59661 L .54347 .59556 L F
.84 .827 .835 r
.67045 .52018 m .67412 .51842 L .67304 .5174 L F
.97 .845 .437 r
.65383 .48809 m .65387 .4857 L .65481 .48674 L F
.903 .709 .63 r
.65676 .49318 m .65802 .49183 L .65605 .49242 L F
.516 .916 .872 r
.65698 .49271 m .65605 .49242 L .65802 .49183 L F
.65698 .49271 m .65676 .49318 L .65605 .49242 L F
.64 .658 .851 r
.71327 .50004 m .7144 .50286 L .71698 .50089 L F
.99 .848 .483 r
.62534 .56827 m .62556 .57141 L .62638 .56936 L F
.481 .493 .793 r
.71135 .50038 m .71365 .4995 L .7097 .49822 L F
.71135 .50038 m .71327 .50004 L .71365 .4995 L F
.954 .797 .648 r
.64668 .49577 m .6482 .4954 L .64689 .49435 L F
.64668 .49577 m .6476 .49752 L .6482 .4954 L F
.895 .79 .736 r
.66602 .51177 m .66667 .51504 L .66518 .51388 L F
.595 .237 .331 r
.53595 .65354 m .53282 .65541 L .53448 .65235 L F
.792 .997 .792 r
.53655 .65309 m .53565 .65461 L .53737 .65263 L F
.53604 .65347 m .53565 .65461 L .53655 .65309 L F
.595 .237 .331 r
.53705 .65443 m .53375 .65519 L .53595 .65354 L F
.53375 .65519 m .53282 .65541 L .53595 .65354 L F
.792 .997 .792 r
.53608 .65335 m .53604 .65347 L .53655 .65309 L F
.597 .449 .651 r
.48309 .77773 m .48418 .77891 L .48439 .77605 L F
.48309 .77773 m .48418 .77891 L .48439 .77605 L F
.848 .738 .742 r
.56866 .59683 m .56846 .60022 L .56899 .59794 L F
.56866 .59683 m .56699 .59997 L .56846 .60022 L F
.693 .503 .625 r
.56726 .6026 m .56846 .60022 L .56699 .59997 L F
.56726 .6026 m .56912 .60273 L .56846 .60022 L F
.609 .713 .919 r
.65291 .50679 m .65512 .50827 L .65549 .5059 L F
.77 .823 .894 r
.65549 .5059 m .65512 .50827 L .65877 .50545 L F
.457 .306 .587 r
.27125 .60014 m .27318 .59693 L .27116 .59759 L F
.659 .514 .676 r
.48618 .64848 m .4886 .64862 L .48878 .64569 L F
0 0 0 r
.48525 .64966 m .4886 .64862 L .48618 .64848 L F
.672 .564 .725 r
.54198 .64807 m .53967 .64859 L .53886 .64536 L F
.647 .472 .632 r
.54198 .64807 m .53964 .65103 L .53967 .64859 L F
.562 .411 .634 r
.37019 .75342 m .3731 .75332 L .373 .75166 L F
.554 .356 .567 r
.37019 .75342 m .3722 .75477 L .3731 .75332 L F
.632 .839 .98 r
.42862 .71125 m .42988 .70934 L .42716 .70863 L F
.42862 .71125 m .43107 .71034 L .42988 .70934 L F
.496 .24 .456 r
.35772 .61943 m .36043 .61686 L .35842 .61763 L F
.883 .722 .677 r
.62661 .55098 m .62863 .55032 L .62677 .54872 L F
.62661 .55098 m .62818 .55245 L .62863 .55032 L F
.007 .331 .815 r
.31177 .64877 m .31222 .64785 L .31112 .64735 L F
.373 .772 .986 r
.31177 .64877 m .31428 .64872 L .31222 .64785 L F
.533 .284 .483 r
.44093 .67092 m .443 .67283 L .44015 .67328 L F
.44093 .67092 m .44324 .67066 L .443 .67283 L F
.479 .585 .882 r
.4233 .70551 m .42524 .70839 L .42673 .70678 L F
.439 .52 .845 r
.42524 .70839 m .42716 .70863 L .42673 .70678 L F
.527 .339 .569 r
.57475 .5827 m .57509 .58527 L .5757 .58484 L F
.57475 .5827 m .57705 .58219 L .57509 .58527 L F
.532 .115 .196 r
.57509 .58527 m .57403 .58643 L .57115 .58694 L F
.57403 .58643 m .5729 .58766 L .57267 .58756 L F
.57403 .58643 m .57267 .58756 L .57115 .58694 L F
.212 .083 .478 r
.57307 .5872 m .57115 .58694 L .5729 .58766 L F
.57307 .5872 m .57134 .58869 L .57115 .58694 L F
.472 .826 .554 r
.57211 .58803 m .57068 .58922 L .57134 .58869 L F
.57307 .5872 m .57118 .5888 L .57211 .58803 L F
0 0 .049 r
.57134 .58869 m .57004 .59078 L .57067 .58855 L F
.472 .826 .554 r
.57118 .5888 m .57068 .58922 L .57211 .58803 L F
.782 .945 .604 r
.57583 .58348 m .57407 .58598 L .57509 .58527 L F
.57407 .58598 m .5729 .58766 L .57509 .58527 L F
.527 .339 .569 r
.5757 .58484 m .57509 .58527 L .57618 .5859 L F
.6 .338 .493 r
.48231 .79314 m .48207 .79563 L .48458 .79512 L F
.544 .781 .986 r
.48169 .80405 m .48479 .80449 L .48359 .80338 L F
.202 0 0 r
.48572 .80366 m .48666 .80246 L .48615 .80271 L F
0 0 0 r
.48617 .80268 m .48479 .80449 L .48642 .80212 L F
.48572 .80366 m .48501 .80429 L .48637 .8024 L F
.202 0 0 r
.48572 .80366 m .48615 .80271 L .48416 .8037 L F
0 0 0 r
.48637 .8024 m .48617 .80268 L .48683 .80152 L F
.48617 .80268 m .48642 .80212 L .48683 .80152 L F
.48501 .80429 m .48479 .80449 L .48637 .8024 L F
.723 .685 .813 r
.48416 .8037 m .48615 .80271 L .48421 .79787 L F
.48615 .80271 m .48666 .80246 L .48637 .8024 L F
.735 .356 .335 r
.48637 .8024 m .48666 .80246 L .48572 .80366 L F
.48683 .80152 m .48666 .80246 L .48637 .8024 L F
.723 .685 .813 r
.48637 .8024 m .48666 .80246 L .48652 .8022 L F
.48615 .80271 m .48652 .8022 L .48421 .79787 L F
.582 .546 .779 r
.48044 .80027 m .48416 .8037 L .48224 .79814 L F
.718 .194 0 r
.48359 .80338 m .48416 .8037 L .48044 .80027 L F
.723 .685 .813 r
.48416 .8037 m .48421 .79787 L .48224 .79814 L F
.202 0 0 r
.48572 .80366 m .48416 .8037 L .48359 .80338 L F
.284 .642 .966 r
.48359 .80338 m .48479 .80449 L .48572 .80366 L F
.638 .831 .422 r
.72258 .46951 m .72338 .4681 L .72432 .46678 L F
.207 0 .225 r
.48123 .62577 m .47873 .62845 L .48013 .62773 L F
0 0 0 r
.48013 .62773 m .48316 .62504 L .48123 .62577 L F
.677 .492 .629 r
.59615 .623 m .59649 .62554 L .59282 .6251 L F
.644 .469 .632 r
.59615 .623 m .59855 .62269 L .59649 .62554 L F
.86 .558 .476 r
.51537 .77838 m .51677 .7763 L .51413 .77552 L F
.785 .453 .426 r
.51537 .77838 m .51816 .77885 L .51677 .7763 L F
.996 .766 .45 r
.49184 .63989 m .49317 .63943 L .4917 .63865 L F
.49184 .63989 m .49296 .64221 L .49317 .63943 L F
.39 .714 .987 r
.49317 .63943 m .49417 .63825 L .4917 .63865 L F
.49317 .63943 m .49525 .63933 L .49417 .63825 L F
.76 .762 .855 r
.50231 .80445 m .50076 .80594 L .49849 .80426 L F
.783 .649 .714 r
.58861 .64278 m .59067 .63985 L .59052 .64301 L F
.463 .376 .672 r
.59067 .63985 m .59317 .64176 L .59052 .64301 L F
.578 .509 .742 r
.59317 .64176 m .59159 .64585 L .59052 .64301 L F
.478 .286 .541 r
.60601 .61689 m .60351 .62026 L .60337 .61716 L F
0 .077 .587 r
.5672 .62813 m .56626 .62704 L .56432 .62521 L F
.984 .778 .548 r
.56542 .63048 m .56688 .63151 L .5672 .62813 L F
.835 .626 .62 r
.5672 .62813 m .56688 .63151 L .56814 .63107 L F
.24 .748 .879 r
.56968 .62697 m .56626 .62704 L .5672 .62813 L F
.971 .927 .623 r
.72425 .48762 m .72443 .48994 L .72563 .48664 L F
.258 0 .201 r
.57916 .5604 m .5812 .55953 L .58185 .55801 L F
.269 0 .206 r
.5812 .55953 m .58385 .55719 L .58185 .55801 L F
.39 .19 .484 r
.57647 .66134 m .57675 .66239 L .57919 .66141 L F
.776 .978 .913 r
.27963 .63513 m .27689 .63706 L .27791 .63525 L F
.263 .32 .735 r
.27689 .63706 m .27887 .63868 L .27791 .63525 L F
.605 .719 .925 r
.27739 .64005 m .27887 .63868 L .27689 .63706 L F
.636 .334 .441 r
.58291 .67062 m .57945 .67314 L .57954 .67163 L F
.36 .537 .894 r
.73819 .51962 m .73747 .52075 L .73522 .51868 L F
.301 .166 .525 r
.73918 .52199 m .73747 .52075 L .73819 .51962 L F
.73918 .52199 m .73668 .52355 L .73747 .52075 L F
.424 .109 .325 r
.38716 .61468 m .38875 .61591 L .38656 .61638 L F
.38716 .61468 m .38936 .61417 L .38875 .61591 L F
.462 .509 .821 r
.75413 .48505 m .75533 .48832 L .75222 .48697 L F
.77 .444 .436 r
.46925 .66595 m .46927 .6679 L .47251 .6682 L F
.349 .822 .888 r
.69422 .46849 m .69768 .468 L .69527 .46924 L F
.162 .672 .899 r
.35972 .59852 m .36019 .59799 L .35778 .59862 L F
.247 0 0 r
.33481 .64511 m .33297 .64656 L .33089 .64699 L F
.085 0 0 r
.3348 .64606 m .33481 .64511 L .33677 .64477 L F
.3348 .64606 m .33297 .64656 L .33481 .64511 L F
0 0 0 r
.69451 .47831 m .69286 .47864 L .69108 .47885 L F
.947 .926 .752 r
.69447 .47586 m .69286 .47864 L .69451 .47831 L F
.956 .949 .696 r
.52239 .65031 m .52436 .64834 L .524 .64863 L F
.811 .734 .779 r
.48683 .80152 m .48925 .79864 L .48731 .79725 L F
.58 .023 0 r
.57446 .62463 m .57417 .62448 L .57233 .62285 L F
.663 .229 .208 r
.57233 .62285 m .57417 .62448 L .57529 .62285 L F
.359 0 0 r
.57417 .62448 m .57737 .62419 L .57529 .62285 L F
.602 .271 .381 r
.57737 .62419 m .578 .62287 L .57529 .62285 L F
.617 .53 .733 r
.75962 .51343 m .75828 .51512 L .75735 .51152 L F
.379 .092 .345 r
.76053 .51633 m .75828 .51512 L .75962 .51343 L F
.76053 .51633 m .75832 .51699 L .75828 .51512 L F
.685 .622 .779 r
.29564 .64218 m .29888 .64318 L .29749 .64212 L F
.661 .809 .954 r
.29749 .64212 m .29888 .64318 L .30119 .64246 L F
.132 0 0 r
.54979 .60965 m .54873 .60922 L .55065 .60794 L F
.54979 .60965 m .54783 .61039 L .54873 .60922 L F
.328 0 .099 r
.47554 .63065 m .47767 .63032 L .47873 .62845 L F
.362 .008 .223 r
.47767 .63032 m .48013 .62773 L .47873 .62845 L F
.561 .299 .476 r
.42352 .66242 m .426 .66229 L .42666 .65929 L F
.444 .123 .325 r
.426 .66229 m .42921 .65932 L .42666 .65929 L F
.608 .346 .495 r
.59026 .64849 m .59227 .65388 L .5891 .65132 L F
.484 .12 .271 r
.59456 .64795 m .59026 .64849 L .59216 .64823 L F
.59456 .64795 m .59401 .64984 L .59026 .64849 L F
.59401 .64984 m .59373 .64988 L .59026 .64849 L F
.297 .119 .462 r
.59397 .64998 m .59227 .65388 L .59026 .64849 L F
.58 .522 .754 r
.59159 .64585 m .59456 .64795 L .59216 .64823 L F
.59159 .64585 m .59394 .64538 L .59456 .64795 L F
.592 .509 .73 r
.59152 .65021 m .5931 .64656 L .59074 .64722 L F
.59164 .65068 m .59182 .65017 L .59152 .65021 L F
.59182 .65017 m .5931 .64656 L .59152 .65021 L F
.484 .12 .271 r
.59401 .64984 m .59397 .64998 L .59373 .64988 L F
.311 0 0 r
.35263 .63901 m .35377 .63785 L .35531 .63827 L F
.703 .376 .42 r
.64317 .48951 m .64561 .4914 L .64715 .48947 L F
.832 .555 .52 r
.64715 .48947 m .64561 .4914 L .64756 .49174 L F
.684 .797 .935 r
.70103 .49933 m .70481 .49918 L .70383 .49754 L F
.603 .72 .927 r
.70481 .49918 m .70619 .49695 L .70383 .49754 L F
.70481 .49918 m .70729 .49879 L .70619 .49695 L F
.964 .717 .277 r
.72993 .51774 m .72938 .5189 L .72869 .51691 L F
.72993 .51774 m .73005 .52009 L .72938 .5189 L F
.469 .156 .352 r
.39697 .60803 m .39401 .61073 L .39468 .60844 L F
.864 .533 .422 r
.57056 .61692 m .57129 .61944 L .57382 .6197 L F
.901 .764 .7 r
.57056 .62171 m .57382 .6197 L .57129 .61944 L F
.57056 .62171 m .57233 .62285 L .57382 .6197 L F
.322 .749 .973 r
.55332 .77252 m .5518 .77329 L .55105 .77267 L F
.55332 .77252 m .55456 .77323 L .5518 .77329 L F
.55332 .77252 m .5518 .77329 L .55105 .77267 L F
.55332 .77252 m .55456 .77323 L .5518 .77329 L F
.503 .893 .954 r
.53282 .59815 m .53664 .59773 L .53425 .5981 L F
.554 .334 .536 r
.68055 .48077 m .68131 .48274 L .67776 .48339 L F
.635 .375 .507 r
.68055 .48077 m .68276 .48292 L .68131 .48274 L F
.314 0 .153 r
.36563 .63276 m .3643 .63195 L .36725 .63038 L F
.36563 .63276 m .36356 .63328 L .3643 .63195 L F
.968 .81 .633 r
.60887 .57744 m .60776 .57684 L .60837 .57416 L F
.983 .726 .336 r
.60887 .57744 m .6082 .57884 L .60776 .57684 L F
.60887 .57744 m .60902 .57973 L .6082 .57884 L F
.593 .227 .317 r
.28389 .59057 m .28624 .59076 L .28698 .58934 L F
.53 .197 .348 r
.28624 .59076 m .28982 .58799 L .28698 .58934 L F
.85 .887 .865 r
.69097 .48985 m .68743 .49129 L .69009 .48902 L F
.837 .946 .892 r
.69097 .48985 m .69189 .48729 L .69321 .48883 L F
.69097 .48985 m .69009 .48902 L .69189 .48729 L F
.283 .742 .952 r
.33501 .5853 m .33857 .58573 L .33652 .58601 L F
.541 .343 .561 r
.61625 .52646 m .61837 .52783 L .61839 .52578 L F
.61625 .52646 m .61616 .5285 L .61837 .52783 L F
.849 .861 .851 r
.5032 .70025 m .49954 .70138 L .50182 .70086 L F
.753 .772 .868 r
.71218 .46096 m .70852 .4603 L .7102 .46079 L F
.784 .376 .277 r
.71068 .46231 m .71218 .46096 L .7102 .46079 L F
.71068 .46231 m .71363 .46303 L .71218 .46096 L F
.306 .419 .813 r
.30992 .62113 m .30904 .62299 L .30763 .61969 L F
.412 .548 .882 r
.30992 .62113 m .31118 .62321 L .30904 .62299 L F
.319 .051 .341 r
.31445 .60764 m .31142 .61086 L .31202 .60877 L F
.53 .197 .348 r
.28624 .59076 m .28854 .59065 L .28982 .58799 L F
.469 .138 .322 r
.28854 .59065 m .29203 .58769 L .28982 .58799 L F
.578 .352 .537 r
.59251 .60852 m .59497 .60817 L .59489 .60607 L F
.614 .34 .478 r
.59754 .60797 m .59489 .60607 L .59497 .60817 L F
.59754 .60797 m .59833 .60534 L .59489 .60607 L F
.823 .352 0 r
.72748 .47048 m .72795 .46948 L .72692 .46817 L F
.437 .007 .123 r
.67776 .48339 m .67447 .4851 L .67436 .48435 L F
.185 .052 .455 r
.50502 .65414 m .50643 .65452 L .50718 .65412 L F
.50502 .65414 m .50509 .65642 L .50643 .65452 L F
.50643 .65452 m .50502 .65414 L .50718 .65412 L F
.50643 .65452 m .50509 .65642 L .50502 .65414 L F
.728 .645 .766 r
.58953 .63654 m .59067 .63985 L .58874 .6405 L F
.689 .517 .649 r
.58874 .6405 m .59067 .63985 L .58861 .64278 L F
.566 .489 .728 r
.58953 .63654 m .59224 .63974 L .59067 .63985 L F
.374 .378 .735 r
.59224 .63974 m .59317 .64176 L .59067 .63985 L F
.144 0 0 r
.56127 .62138 m .55962 .62127 L .5602 .62308 L F
.532 .56 .829 r
.55988 .62162 m .56127 .62138 L .55985 .62208 L F
.144 0 0 r
.56127 .62138 m .56021 .62157 L .5606 .62134 L F
.56127 .62138 m .5606 .62134 L .56246 .62024 L F
.5606 .62134 m .55914 .61976 L .55962 .62127 L F
.56127 .62138 m .56113 .62128 L .5606 .62134 L F
0 0 0 r
.56246 .62024 m .5606 .62134 L .56132 .62113 L F
.144 0 0 r
.56127 .62138 m .56246 .62024 L .56113 .62128 L F
0 0 0 r
.56246 .62024 m .56132 .62113 L .56327 .62058 L F
.758 .464 .487 r
.55559 .62174 m .55914 .61976 L .55804 .6194 L F
.55559 .62174 m .55985 .62208 L .55914 .61976 L F
.532 .56 .829 r
.55746 .62036 m .55985 .62208 L .55742 .6204 L F
.144 0 0 r
.56084 .62105 m .56246 .62024 L .55914 .61976 L F
.56113 .62128 m .55914 .61976 L .5606 .62134 L F
.701 .397 0 r
.55985 .62208 m .5602 .62308 L .55914 .61976 L F
.981 .914 .623 r
.55952 .61747 m .55807 .61937 L .55914 .61976 L F
.55807 .61937 m .55804 .6194 L .55807 .61941 L F
.55807 .61937 m .55807 .61941 L .55914 .61976 L F
.532 .56 .829 r
.56011 .61818 m .55993 .62087 L .55802 .62048 L F
.55805 .61988 m .55802 .62048 L .55746 .62036 L F
.56011 .61818 m .55802 .62048 L .55805 .61988 L F
.55993 .62087 m .55985 .62208 L .55746 .62036 L F
.144 0 0 r
.56113 .62128 m .5613 .62115 L .56084 .62105 L F
.5613 .62115 m .56246 .62024 L .56084 .62105 L F
0 0 0 r
.5606 .62134 m .56021 .62157 L .56117 .62127 L F
.5606 .62134 m .56117 .62127 L .56142 .62119 L F
.56202 .62093 m .56142 .62119 L .56327 .62058 L F
.5606 .62134 m .56142 .62119 L .56202 .62093 L F
.782 .699 .773 r
.56356 .6185 m .56142 .62119 L .56011 .61818 L F
.526 .336 .566 r
.56327 .62058 m .56079 .6214 L .56127 .62138 L F
.532 .56 .829 r
.56079 .6214 m .56127 .62138 L .56021 .62157 L F
.144 0 0 r
.56127 .62138 m .56012 .62162 L .56021 .62157 L F
.526 .336 .566 r
.56079 .6214 m .56012 .62162 L .56127 .62138 L F
.532 .56 .829 r
.56123 .62127 m .56127 .62138 L .56079 .6214 L F
.782 .699 .773 r
.56142 .62119 m .56127 .62138 L .56123 .62127 L F
.56142 .62119 m .56123 .62127 L .56011 .61818 L F
.532 .56 .829 r
.56011 .61818 m .56123 .62127 L .55988 .62162 L F
0 0 0 r
.56021 .62157 m .56079 .6214 L .56117 .62127 L F
.532 .56 .829 r
.56123 .62127 m .56021 .62157 L .55988 .62162 L F
0 0 0 r
.56021 .62157 m .56012 .62162 L .56079 .6214 L F
.967 .646 .279 r
.62538 .57622 m .62602 .57588 L .6252 .57416 L F
.62538 .57622 m .62624 .57704 L .62602 .57588 L F
.732 .721 .84 r
.69607 .48665 m .69672 .48939 L .69321 .48883 L F
.552 .486 .735 r
.69871 .48606 m .69672 .48939 L .69607 .48665 L F
.69871 .48606 m .69909 .48902 L .69672 .48939 L F
.38 .443 .8 r
.53782 .6436 m .5405 .64504 L .53886 .64536 L F
.672 .564 .725 r
.54198 .64807 m .53886 .64536 L .5405 .64504 L F
.466 .685 .961 r
.66314 .49798 m .66559 .49795 L .66439 .49639 L F
.66439 .49639 m .66559 .49795 L .66314 .49798 L F
.349 .195 .527 r
.61643 .59722 m .61664 .59984 L .61512 .60039 L F
.514 .345 .59 r
.61664 .59984 m .61432 .60236 L .61512 .60039 L F
.306 .129 .469 r
.75832 .51699 m .75591 .5199 L .75575 .51793 L F
.764 .676 .766 r
.71047 .48848 m .71126 .49186 L .70822 .49129 L F
.713 .645 .78 r
.71421 .48924 m .71126 .49186 L .71047 .48848 L F
.227 .669 .954 r
.31832 .62694 m .32064 .62715 L .32227 .6281 L F
.162 .436 .87 r
.32392 .62792 m .32227 .6281 L .32064 .62715 L F
.32392 .62792 m .32369 .62836 L .32227 .6281 L F
.656 .515 .68 r
.61373 .53151 m .61616 .5285 L .61374 .52916 L F
.441 .429 .75 r
.73918 .52199 m .73964 .52494 L .73668 .52355 L F
.571 .404 .616 r
.59072 .6281 m .59116 .63218 L .58869 .63222 L F
.628 .481 .663 r
.59282 .6251 m .59399 .62839 L .59072 .6281 L F
.575 .376 .574 r
.59399 .62839 m .59116 .63218 L .59072 .6281 L F
.396 .527 .871 r
.48697 .64277 m .48878 .64569 L .49008 .64427 L F
.616 .142 .105 r
.72432 .46678 m .72338 .4681 L .72692 .46817 L F
.655 .59 .77 r
.66335 .48578 m .66397 .48748 L .6664 .4869 L F
.54 .172 .292 r
.27633 .5946 m .27795 .59605 L .27828 .59392 L F
.27633 .5946 m .27567 .5963 L .27795 .59605 L F
.044 .094 .59 r
.56143 .65701 m .56266 .65563 L .56129 .65348 L F
.128 .226 .697 r
.56143 .65701 m .56323 .65918 L .56266 .65563 L F
.504 .642 .918 r
.66592 .50187 m .66422 .50378 L .6634 .50203 L F
0 0 .215 r
.57106 .64858 m .56981 .65123 L .56867 .64825 L F
.57106 .64858 m .57099 .6502 L .56981 .65123 L F
.618 .483 .675 r
.57209 .6511 m .56981 .65123 L .57099 .6502 L F
.57209 .6511 m .57029 .65358 L .56981 .65123 L F
.924 .627 .462 r
.73455 .52631 m .73312 .52626 L .73253 .52301 L F
.718 .458 0 r
.73455 .52631 m .73483 .52785 L .73312 .52626 L F
.73455 .52631 m .73498 .52828 L .73483 .52785 L F
.74 .384 .377 r
.46359 .69785 m .46696 .69835 L .46682 .69695 L F
.642 .31 .394 r
.46696 .69835 m .46928 .69887 L .46682 .69695 L F
.598 .848 .992 r
.41052 .70028 m .4077 .70101 L .41132 .70164 L F
.475 .15 .335 r
.4077 .70101 m .41052 .70028 L .41132 .70164 L F
.985 .813 .418 r
.41124 .6993 m .41132 .70164 L .41052 .70028 L F
0 .26 .756 r
.41132 .70164 m .41125 .70055 L .41052 .70028 L F
.41132 .70164 m .41125 .70055 L .41052 .70028 L F
.66 .491 .645 r
.6021 .54547 m .60432 .54276 L .6021 .5434 L F
.74 .561 .651 r
.58874 .6405 m .58861 .64278 L .58544 .64242 L F
.161 .675 .893 r
.58486 .64236 m .58544 .64242 L .58726 .64244 L F
.58544 .64242 m .58861 .64278 L .58726 .64244 L F
.665 .679 .854 r
.58797 .64525 m .58879 .64245 L .58726 .64244 L F
.58879 .64245 m .5889 .64207 L .58726 .64244 L F
.58826 .6464 m .58836 .64569 L .58797 .64525 L F
.58836 .64569 m .5889 .64207 L .58797 .64525 L F
.74 .561 .651 r
.58523 .64218 m .58544 .64242 L .58486 .64236 L F
.58874 .6405 m .58544 .64242 L .58523 .64218 L F
.636 .334 .441 r
.58291 .67062 m .58203 .67332 L .57945 .67314 L F
.457 .092 .256 r
.58528 .67088 m .58203 .67332 L .58291 .67062 L F
.759 .27 .07 r
.55279 .76507 m .55188 .76618 L .54972 .76363 L F
.82 .578 .573 r
.55521 .76434 m .55188 .76618 L .55279 .76507 L F
.602 .053 0 r
.51121 .77739 m .51025 .77701 L .50981 .77661 L F
.61 .064 0 r
.51121 .77739 m .51196 .77809 L .51025 .77701 L F
.534 .446 .702 r
.63183 .50363 m .63349 .49988 L .63105 .50061 L F
.63183 .50363 m .6341 .50306 L .63349 .49988 L F
.558 .296 .475 r
.67905 .47496 m .68135 .47666 L .68135 .4747 L F
.67905 .47496 m .67886 .4772 L .68135 .47666 L F
.466 .576 .881 r
.36908 .60036 m .37258 .60301 L .37114 .60032 L F
.475 .581 .881 r
.37114 .60032 m .37258 .60301 L .37401 .60156 L F
.603 .548 .766 r
.3727 .60543 m .37401 .60156 L .37258 .60301 L F
.451 .11 .297 r
.43949 .65601 m .44276 .65304 L .44015 .65463 L F
.43949 .65601 m .44175 .65567 L .44276 .65304 L F
.408 .055 .252 r
.44175 .65567 m .44515 .65268 L .44276 .65304 L F
.629 .542 .737 r
.25853 .63354 m .26135 .63644 L .26034 .63373 L F
.707 .768 .899 r
.55554 .61676 m .55241 .61867 L .5518 .61639 L F
.842 .794 .805 r
.72043 .50589 m .72124 .50944 L .71886 .50811 L F
.91 .545 .328 r
.71886 .50811 m .72124 .50944 L .72162 .51184 L F
.945 .589 .208 r
.72124 .50944 m .723 .51358 L .72162 .51184 L F
.733 .73 .848 r
.72422 .50648 m .72124 .50944 L .72043 .50589 L F
.467 .094 .246 r
.43716 .65627 m .43949 .65601 L .44015 .65463 L F
.286 .786 .845 r
.31759 .64821 m .31642 .64819 L .31428 .64872 L F
.432 .746 .993 r
.31759 .64821 m .31974 .64806 L .31839 .647 L F
.621 .956 .909 r
.31839 .647 m .31642 .64819 L .31759 .64821 L F
.432 .746 .993 r
.31759 .64821 m .31974 .64806 L .31839 .647 L F
.595 .359 .53 r
.35307 .62248 m .35549 .62237 L .3558 .62004 L F
.434 .219 .487 r
.3558 .62004 m .35749 .62169 L .35772 .61943 L F
.3558 .62004 m .35549 .62237 L .35749 .62169 L F
.572 .212 .32 r
.56967 .66492 m .56889 .66696 L .56659 .66555 L F
.608 .426 .61 r
.57132 .66442 m .56889 .66696 L .56967 .66492 L F
.844 .9 .877 r
.73546 .5082 m .73645 .50926 L .73893 .50679 L F
0 .194 .712 r
.55736 .64829 m .558 .64723 L .556 .64513 L F
.093 .348 .818 r
.55736 .64829 m .56003 .65034 L .558 .64723 L F
.545 .315 .518 r
.57073 .63143 m .57417 .63018 L .57411 .62837 L F
0 0 .365 r
.57411 .62837 m .57417 .63018 L .57465 .62793 L F
0 0 0 r
.30629 .58338 m .30665 .58385 L .30844 .5832 L F
.30629 .58338 m .30457 .58454 L .30665 .58385 L F
.809 .856 .885 r
.74508 .51868 m .7431 .51859 L .74365 .51724 L F
.475 .253 .497 r
.67961 .49139 m .67755 .49472 L .68177 .49122 L F
.466 .407 .708 r
.30941 .61547 m .30678 .61376 L .30946 .61383 L F
.30941 .61547 m .30742 .61721 L .30678 .61376 L F
.931 .881 .763 r
.6521 .49833 m .65098 .49733 L .65266 .49425 L F
.955 .915 .734 r
.65077 .50039 m .65098 .49733 L .6521 .49833 L F
.087 .633 .836 r
.51032 .70568 m .50855 .70528 L .50659 .70525 L F
.321 0 0 r
.51272 .70538 m .51243 .7061 L .51032 .70568 L F
.575 .041 0 r
.51243 .7061 m .50855 .70528 L .51032 .70568 L F
.723 .637 .761 r
.48685 .77562 m .48418 .77891 L .48439 .77605 L F
.161 0 0 r
.48439 .77605 m .48602 .77639 L .48685 .77562 L F
0 0 .37 r
.48439 .77605 m .48545 .77706 L .48602 .77639 L F
.48439 .77605 m .48418 .77891 L .48545 .77706 L F
.737 .326 .268 r
.49192 .64879 m .49476 .65148 L .4906 .64968 L F
.49476 .65148 m .49486 .65157 L .49471 .65151 L F
.49476 .65148 m .49471 .65151 L .4906 .64968 L F
.49486 .65157 m .49485 .65157 L .4906 .64968 L F
0 0 0 r
.49442 .65176 m .49487 .65158 L .49561 .65127 L F
.737 .216 0 r
.49561 .65127 m .49487 .65158 L .49192 .64879 L F
.166 .259 .716 r
.4933 .65204 m .4906 .64968 L .49471 .65151 L F
.703 .978 .782 r
.49422 .6517 m .4933 .65204 L .4941 .65184 L F
.49556 .65001 m .4941 .65184 L .49451 .65162 L F
.49451 .65162 m .49442 .65176 L .49475 .65159 L F
.166 .259 .716 r
.4933 .65204 m .49471 .65151 L .49487 .65158 L F
.703 .978 .782 r
.49556 .65001 m .4933 .65204 L .49422 .6517 L F
.49451 .65162 m .4941 .65184 L .49442 .65176 L F
.49556 .65001 m .49451 .65162 L .49603 .65091 L F
.49451 .65162 m .49475 .65159 L .49603 .65091 L F
.518 .916 .834 r
.49795 .65022 m .49442 .65176 L .49561 .65127 L F
.737 .326 .268 r
.49486 .65157 m .49487 .65158 L .49485 .65157 L F
.576 .431 .647 r
.41531 .66265 m .41781 .66471 L .41759 .66223 L F
.41531 .66265 m .4155 .66513 L .41781 .66471 L F
.491 .059 .146 r
.48107 .70255 m .47888 .7045 L .47629 .70457 L F
.323 0 .011 r
.48205 .70346 m .48107 .70255 L .48189 .70165 L F
.48205 .70346 m .47888 .7045 L .48107 .70255 L F
.381 .521 .873 r
.38944 .59387 m .38929 .59646 L .38752 .59392 L F
.38944 .59387 m .39108 .59668 L .38929 .59646 L F
.443 0 0 r
.53483 .64276 m .53757 .64396 L .53782 .6436 L F
.516 0 0 r
.53757 .64396 m .5405 .64504 L .53782 .6436 L F
.811 .734 .779 r
.48683 .80152 m .48731 .79725 L .48666 .80246 L F
.437 .007 .123 r
.67776 .48339 m .67727 .48504 L .67447 .4851 L F
.704 .438 .519 r
.68131 .48274 m .67727 .48504 L .67776 .48339 L F
.97 .728 .514 r
.73142 .48661 m .73005 .48774 L .73043 .48554 L F
.73142 .48661 m .73132 .48882 L .73005 .48774 L F
.996 .843 .567 r
.73094 .48534 m .73142 .48661 L .73043 .48554 L F
.898 .709 .638 r
.62553 .55959 m .62686 .563 L .62721 .56097 L F
.573 .009 0 r
.56889 .66696 m .56537 .66452 L .56659 .66555 L F
.248 0 0 r
.27791 .63525 m .28116 .63374 L .27963 .63513 L F
.618 .849 .987 r
.70494 .48669 m .70196 .48584 L .70637 .48539 L F
.78 .506 .521 r
.70494 .48669 m .7015 .48839 L .70196 .48584 L F
.70494 .48669 m .7049 .48885 L .7015 .48839 L F
.722 .681 .81 r
.70517 .48477 m .70038 .48517 L .70296 .48363 L F
.70637 .48539 m .70545 .48536 L .70517 .48477 L F
.70545 .48536 m .70038 .48517 L .70517 .48477 L F
.70545 .48536 m .70196 .48584 L .70038 .48517 L F
.70637 .48539 m .70564 .48547 L .70545 .48536 L F
.70564 .48547 m .70196 .48584 L .70545 .48536 L F
.484 .681 .953 r
.70614 .48574 m .70741 .48666 L .70607 .48667 L F
.70621 .48474 m .7072 .48633 L .70614 .48574 L F
.7072 .48633 m .70741 .48666 L .70614 .48574 L F
.7056 .48568 m .70607 .48667 L .70494 .48669 L F
.427 .727 .988 r
.70621 .48474 m .70637 .48539 L .70296 .48363 L F
.484 .681 .953 r
.70621 .48474 m .70494 .48669 L .70637 .48539 L F
.70621 .48474 m .70607 .48667 L .7056 .48568 L F
.535 .303 .51 r
.70741 .48666 m .7049 .48885 L .70494 .48669 L F
.737 .803 .905 r
.75997 .50936 m .75735 .51152 L .75605 .50965 L F
.669 .652 .824 r
.75997 .50936 m .76052 .5118 L .75735 .51152 L F
.617 .53 .733 r
.75962 .51343 m .75735 .51152 L .76052 .5118 L F
.128 0 0 r
.34009 .62863 m .34196 .62826 L .34238 .62781 L F
.012 0 0 r
.34009 .62863 m .33861 .62942 L .34196 .62826 L F
.463 .575 .882 r
.38615 .59134 m .38562 .59405 L .384 .59164 L F
.38615 .59134 m .38752 .59392 L .38562 .59405 L F
.799 .681 .734 r
.62614 .52261 m .62977 .52079 L .62827 .51968 L F
.62614 .52261 m .62761 .52369 L .62977 .52079 L F
.807 .766 .815 r
.62827 .51968 m .62977 .52079 L .6322 .51806 L F
.234 .374 .801 r
.74185 .52508 m .74022 .52634 L .73964 .52494 L F
.74185 .52508 m .74247 .52791 L .74022 .52634 L F
.535 .448 .703 r
.40948 .67689 m .4115 .67646 L .41105 .67322 L F
.479 .344 .619 r
.40973 .6794 m .4115 .67646 L .40948 .67689 L F
.352 .542 .9 r
.36858 .59939 m .36908 .60036 L .36999 .59886 L F
.429 .644 .947 r
.36908 .60036 m .37114 .60032 L .36999 .59886 L F
.667 .492 .639 r
.58422 .65284 m .58702 .65142 L .58413 .65139 L F
.065 0 0 r
.34249 .60003 m .34106 .60049 L .33901 .60056 L F
.128 0 0 r
.34471 .59995 m .34106 .60049 L .34249 .60003 L F
.512 .15 .288 r
.50097 .7023 m .49718 .70249 L .49954 .70138 L F
.50097 .7023 m .49738 .70472 L .49718 .70249 L F
.50097 .7023 m .4996 .70462 L .49738 .70472 L F
.75 .421 .427 r
.50097 .7023 m .50305 .70506 L .4996 .70462 L F
.811 .408 .286 r
.50442 .70472 m .50305 .70506 L .50097 .7023 L F
.753 .653 .751 r
.62761 .52369 m .62521 .52639 L .62767 .52598 L F
.775 .653 .728 r
.62512 .52889 m .62767 .52598 L .62521 .52639 L F
.282 0 .155 r
.4688 .67271 m .46607 .67497 L .46676 .67237 L F
0 .201 .721 r
.51256 .62959 m .51114 .62901 L .51031 .62754 L F
.51256 .62959 m .51361 .63104 L .51114 .62901 L F
.697 .36 .402 r
.54974 .614 m .5518 .61639 L .55149 .61446 L F
.54974 .614 m .54862 .61654 L .5518 .61639 L F
.772 .846 .908 r
.74681 .52691 m .74366 .52906 L .74247 .52791 L F
.44 .261 .541 r
.61841 .59857 m .61643 .59722 L .61886 .59593 L F
.61841 .59857 m .61664 .59984 L .61643 .59722 L F
.584 .163 .209 r
.53664 .59773 m .53885 .59887 L .53927 .59718 L F
.163 0 .092 r
.53927 .59718 m .53885 .59887 L .54156 .59661 L F
.651 .251 .273 r
.56688 .63151 m .56782 .63295 L .56814 .63107 L F
.731 .328 .286 r
.56814 .63107 m .57109 .63334 L .57073 .63143 L F
.56814 .63107 m .56782 .63295 L .57109 .63334 L F
.81 .888 .464 r
.57033 .63752 m .56934 .63933 L .56931 .6399 L F
0 0 .146 r
.56934 .63933 m .56957 .64226 L .56931 .6399 L F
.064 0 0 r
.55211 .58783 m .55404 .58751 L .55491 .58577 L F
.03 0 0 r
.55211 .58783 m .55084 .58952 L .55404 .58751 L F
.474 .361 .645 r
.30941 .61547 m .30763 .61969 L .30742 .61721 L F
.756 .569 .644 r
.68636 .47201 m .68955 .47196 L .68976 .4681 L F
.343 0 .229 r
.57627 .56262 m .57846 .56245 L .57916 .5604 L F
.409 .104 .333 r
.57846 .56245 m .5812 .55953 L .57916 .5604 L F
.742 .508 .576 r
.47864 .69653 m .4823 .69924 L .48118 .69627 L F
.47864 .69653 m .47866 .69923 L .4823 .69924 L F
.677 .498 .636 r
.59282 .6251 m .59629 .628 L .59399 .62839 L F
.59282 .6251 m .59649 .62554 L .59629 .628 L F
.751 .937 .947 r
.46325 .65941 m .46274 .66159 L .4646 .6588 L F
.46325 .65941 m .46025 .66119 L .46274 .66159 L F
.377 .014 .215 r
.36909 .62933 m .36563 .63276 L .36725 .63038 L F
.73 .616 .731 r
.27461 .64017 m .27477 .64182 L .27739 .64005 L F
.435 .123 .336 r
.27739 .64005 m .27477 .64182 L .27604 .64141 L F
.605 .719 .925 r
.27739 .64005 m .2796 .64036 L .27887 .63868 L F
.738 .583 .682 r
.27604 .64141 m .2796 .64036 L .27739 .64005 L F
.448 .18 .414 r
.43802 .67372 m .43761 .67593 L .43603 .6762 L F
.581 .377 .569 r
.44015 .67328 m .43761 .67593 L .43802 .67372 L F
0 .17 .64 r
.6476 .49752 m .6497 .49905 L .65056 .49984 L F
.812 .848 .876 r
.6455 .50241 m .65056 .49984 L .6497 .49905 L F
.623 .821 .976 r
.49094 .79473 m .49163 .79589 L .48808 .79558 L F
.49094 .79473 m .49163 .79589 L .48808 .79558 L F
.207 .696 .925 r
.48065 .6936 m .47984 .69308 L .47784 .69309 L F
.47784 .69309 m .47984 .69308 L .48065 .6936 L F
.493 .688 .954 r
.72162 .51184 m .723 .51358 L .72318 .51354 L F
.244 .689 .957 r
.31557 .58321 m .32009 .58359 L .31739 .58353 L F
.861 .937 .87 r
.67919 .51076 m .68283 .50896 L .68216 .50822 L F
.885 .984 .817 r
.68447 .50536 m .68283 .50896 L .6851 .50601 L F
.68447 .50536 m .68216 .50822 L .68283 .50896 L F
.174 0 0 r
.58273 .64198 m .58366 .64223 L .5818 .64121 L F
.58273 .64198 m .58486 .64236 L .58366 .64223 L F
.604 .875 .992 r
.70983 .46571 m .70883 .46442 L .70574 .46582 L F
.506 .821 1 r
.7117 .46519 m .71009 .46475 L .70983 .46571 L F
.71009 .46475 m .70883 .46442 L .70925 .46496 L F
.71009 .46475 m .70925 .46496 L .70983 .46571 L F
.849 .472 .337 r
.7117 .46519 m .71071 .46721 L .70883 .46442 L F
.107 0 .274 r
.71367 .4632 m .7117 .46519 L .71363 .46303 L F
.71394 .46431 m .71291 .46471 L .71367 .4632 L F
.71291 .46471 m .7117 .46519 L .71367 .4632 L F
.511 .203 .382 r
.71294 .46448 m .71298 .46459 L .71292 .46465 L F
.71294 .46448 m .71292 .46465 L .71213 .46557 L F
.107 0 .274 r
.71291 .46471 m .71294 .46448 L .7117 .46519 L F
.137 .009 .43 r
.71394 .46431 m .71366 .46668 L .71294 .46448 L F
.107 0 .274 r
.71394 .46431 m .71294 .46448 L .71291 .46471 L F
.511 .203 .382 r
.71298 .46459 m .71366 .46668 L .71176 .46702 L F
.71294 .46448 m .71205 .46557 L .7117 .46519 L F
.71205 .46557 m .71071 .46721 L .71117 .46627 L F
.71205 .46557 m .71117 .46627 L .7117 .46519 L F
.527 .436 .696 r
.71134 .46552 m .71319 .46466 L .71334 .46394 L F
.71319 .46466 m .71394 .46431 L .71376 .4642 L F
.71319 .46466 m .71376 .4642 L .71334 .46394 L F
.71108 .46572 m .71147 .46553 L .71134 .46552 L F
.71147 .46553 m .71394 .46431 L .71134 .46552 L F
.511 .203 .382 r
.71205 .46557 m .71213 .46557 L .71071 .46721 L F
.71294 .46448 m .71213 .46557 L .71205 .46557 L F
.71298 .46459 m .71176 .46702 L .71071 .46721 L F
.527 .436 .696 r
.71094 .46454 m .71334 .46394 L .71068 .46231 L F
.71108 .46572 m .71334 .46394 L .71094 .46454 L F
.713 .737 .87 r
.67208 .50495 m .6736 .5063 L .67012 .50581 L F
.771 .741 .826 r
.67605 .50376 m .6736 .5063 L .67208 .50495 L F
.553 .322 .519 r
.30442 .72779 m .30665 .72699 L .30467 .72494 L F
.272 0 .106 r
.31714 .6059 m .31618 .60771 L .31445 .60764 L F
.112 0 0 r
.31909 .60515 m .31618 .60771 L .31714 .6059 L F
0 0 .147 r
.62053 .59316 m .61886 .59593 L .61881 .59423 L F
.903 .68 .59 r
.60904 .57321 m .60837 .57416 L .60705 .57101 L F
.823 .431 .308 r
.50442 .70472 m .5026 .70586 L .50305 .70506 L F
.063 0 0 r
.50531 .70519 m .50442 .70472 L .50659 .70525 L F
.50531 .70519 m .5026 .70586 L .50442 .70472 L F
.643 .162 .097 r
.52414 .7781 m .52239 .77673 L .52146 .77793 L F
.759 .876 .932 r
.50192 .80146 m .50019 .80286 L .49922 .80186 L F
.511 .87 .634 r
.50207 .80133 m .50019 .80286 L .50192 .80146 L F
.531 .828 .999 r
.50282 .80066 m .50192 .80146 L .49964 .80047 L F
.511 .87 .634 r
.50282 .80066 m .50136 .80188 L .50207 .80133 L F
.50136 .80188 m .50019 .80286 L .50207 .80133 L F
.76 .762 .855 r
.50231 .80445 m .49849 .80426 L .49856 .80404 L F
.50026 .80273 m .49856 .80404 L .49922 .80186 L F
.295 .509 .893 r
.5025 .8027 m .50019 .80286 L .50282 .80066 L F
.5025 .8027 m .50231 .80445 L .50019 .80286 L F
.76 .762 .855 r
.50231 .80445 m .49922 .80186 L .50019 .80286 L F
.50231 .80445 m .49856 .80404 L .50026 .80273 L F
.108 .633 .877 r
.32363 .64791 m .32558 .64807 L .32194 .64738 L F
.352 .431 .803 r
.66028 .51441 m .66129 .51809 L .66044 .51827 L F
.492 .104 .233 r
.29429 .58773 m .29656 .58768 L .29794 .58556 L F
.396 0 .162 r
.29656 .58768 m .30018 .58528 L .29794 .58556 L F
.738 .583 .682 r
.27604 .64141 m .28097 .64262 L .2796 .64036 L F
.44 .616 .924 r
.27887 .63868 m .2796 .64036 L .28083 .63866 L F
.332 .463 .843 r
.2796 .64036 m .28256 .64221 L .28083 .63866 L F
.598 .642 .865 r
.5448 .64742 m .54198 .64807 L .5405 .64504 L F
.598 .588 .813 r
.54659 .65129 m .54198 .64807 L .5448 .64742 L F
.627 .504 .693 r
.61828 .52344 m .62049 .52316 L .62041 .52038 L F
.603 .413 .597 r
.61828 .52344 m .62043 .52516 L .62049 .52316 L F
.61828 .52344 m .61839 .52578 L .62043 .52516 L F
.498 .542 .832 r
.27217 .61609 m .2726 .61296 L .27058 .61327 L F
.27217 .61609 m .27418 .61591 L .2726 .61296 L F
.998 .808 .524 r
.66652 .48427 m .6664 .4869 L .66573 .4851 L F
.463 .738 .987 r
.34668 .58626 m .34579 .58749 L .34425 .58629 L F
.34668 .58626 m .34796 .5874 L .34579 .58749 L F
.39 .791 .985 r
.66784 .49713 m .67131 .49751 L .66893 .49791 L F
.67131 .49751 m .66784 .49713 L .66893 .49791 L F
.66784 .49713 m .67027 .49685 L .67131 .49751 L F
.67131 .49751 m .67027 .49685 L .66784 .49713 L F
.45 .824 .992 r
.66893 .49791 m .67027 .49685 L .67131 .49751 L F
.868 .656 .125 r
.53789 .62284 m .53752 .62185 L .5374 .61937 L F
0 .108 .651 r
.53789 .62284 m .53979 .62486 L .53752 .62185 L F
.76 .665 .757 r
.28116 .63374 m .28506 .63414 L .28344 .63086 L F
0 .208 .687 r
.28116 .63374 m .28468 .63654 L .28506 .63414 L F
0 .209 .728 r
.28344 .63086 m .28506 .63414 L .28539 .63279 L F
.957 .944 .642 r
.28468 .63654 m .28539 .63279 L .28506 .63414 L F
.044 .332 .814 r
.53281 .6163 m .53349 .61542 L .53076 .61389 L F
.53281 .6163 m .53395 .61692 L .53349 .61542 L F
.6 .618 .841 r
.27477 .64182 m .27809 .6432 L .27604 .64141 L F
.536 .784 .989 r
.33149 .63024 m .32677 .6289 L .32976 .62921 L F
.508 .773 .992 r
.33212 .62891 m .33149 .63024 L .32976 .62921 L F
.33212 .62891 m .33348 .63009 L .33149 .63024 L F
.576 .065 .001 r
.46472 .67662 m .46417 .67755 L .46189 .67648 L F
0 0 0 r
.46607 .67497 m .46417 .67755 L .46472 .67662 L F
.891 .961 .834 r
.67919 .51076 m .67698 .51348 L .67885 .51274 L F
.649 .663 .85 r
.31488 .62506 m .31257 .6258 L .31118 .62321 L F
.244 0 .099 r
.58462 .57213 m .58599 .57282 L .58437 .57408 L F
.58462 .57213 m .58768 .57062 L .58599 .57282 L F
.847 .736 .74 r
.62733 .55462 m .62818 .55245 L .62661 .55098 L F
.438 0 0 r
.66649 .47938 m .67023 .47873 L .66732 .47895 L F
.723 .637 .761 r
.48685 .77562 m .48787 .7789 L .48418 .77891 L F
.545 .531 .79 r
.49 .77847 m .48787 .7789 L .48685 .77562 L F
.713 .304 .272 r
.48658 .78044 m .49016 .78103 L .48787 .7789 L F
.42 .012 .155 r
.49 .77847 m .48658 .78044 L .48787 .7789 L F
.73 .607 .72 r
.27604 .64141 m .27809 .6432 L .28097 .64262 L F
.607 .61 .829 r
.76276 .51088 m .76052 .5118 L .75997 .50936 L F
.319 .046 .333 r
.76276 .51088 m .75962 .51343 L .76052 .5118 L F
.897 .647 .135 r
.65077 .50039 m .65051 .50177 L .64958 .50024 L F
.65077 .50039 m .65088 .50336 L .65051 .50177 L F
.955 .915 .734 r
.65077 .50039 m .64958 .50024 L .65098 .49733 L F
.739 .56 .65 r
.64668 .49577 m .6497 .49905 L .6476 .49752 L F
.744 .733 .841 r
.64482 .49958 m .6455 .50241 L .6497 .49905 L F
.739 .56 .65 r
.64668 .49577 m .64482 .49958 L .6497 .49905 L F
.959 .941 .711 r
.65098 .49733 m .64958 .50024 L .64911 .49864 L F
.628 .631 .834 r
.64991 .49913 m .65051 .50177 L .65294 .50099 L F
.64911 .49864 m .65051 .50177 L .64991 .49913 L F
.897 .647 .135 r
.65088 .50336 m .65089 .50372 L .65051 .50177 L F
.502 .401 .672 r
.49849 .80426 m .49639 .80437 L .49922 .80186 L F
.49922 .80186 m .49639 .80437 L .49849 .80426 L F
.208 0 0 r
.31052 .58275 m .31402 .583 L .31202 .58314 L F
0 0 0 r
.58218 .65904 m .58377 .65764 L .58522 .65573 L F
.63 .584 .784 r
.58422 .65284 m .58522 .65573 L .58672 .65339 L F
0 0 0 r
.58522 .65573 m .58619 .65528 L .58681 .65561 L F
.58522 .65573 m .58377 .65764 L .58619 .65528 L F
.658 .34 .424 r
.59976 .60728 m .59833 .60534 L .59754 .60797 L F
.59976 .60728 m .60064 .60559 L .59833 .60534 L F
.693 .703 .855 r
.45885 .68785 m .45676 .68907 L .45539 .68705 L F
.45539 .68705 m .45676 .68907 L .45885 .68785 L F
0 .399 .74 r
.30778 .64614 m .30894 .6464 L .3067 .64515 L F
.30778 .64614 m .31112 .64735 L .30894 .6464 L F
.593 .448 .653 r
.59116 .63218 m .58925 .63466 L .58869 .63222 L F
0 .096 .643 r
.43542 .69048 m .43707 .69257 L .43653 .69373 L F
0 .104 .623 r
.43707 .69257 m .43699 .6958 L .43653 .69373 L F
.498 .632 .912 r
.31679 .62495 m .31603 .62654 L .31488 .62506 L F
.31679 .62495 m .31832 .62694 L .31603 .62654 L F
.144 0 0 r
.56127 .62138 m .5602 .62308 L .55985 .62208 L F
.716 .253 .15 r
.56093 .62369 m .56253 .62501 L .56145 .62479 L F
.738 .571 .667 r
.56167 .6256 m .55897 .62429 L .56253 .62501 L F
0 0 .436 r
.56215 .62255 m .56167 .6256 L .56253 .62501 L F
.56215 .62255 m .56257 .62572 L .56184 .62562 L F
.56171 .62535 m .56184 .62562 L .56167 .6256 L F
.56215 .62255 m .56184 .62562 L .56171 .62535 L F
.716 .253 .15 r
.5602 .62308 m .56093 .62369 L .55897 .62429 L F
.56093 .62369 m .56145 .62479 L .55897 .62429 L F
.381 0 0 r
.67023 .47873 m .67232 .47912 L .67342 .47845 L F
.254 0 0 r
.67232 .47912 m .67574 .47805 L .67342 .47845 L F
.372 .111 .382 r
.45293 .64764 m .45461 .64969 L .45568 .64703 L F
.45293 .64764 m .45255 .65054 L .45461 .64969 L F
.955 .845 .695 r
.74745 .52573 m .7456 .52574 L .74626 .52427 L F
.74745 .52573 m .74681 .52691 L .7456 .52574 L F
.523 .311 .534 r
.41101 .67092 m .41328 .6705 L .4134 .6682 L F
.547 .39 .619 r
.4134 .6682 m .41566 .66785 L .4155 .66513 L F
.432 .193 .449 r
.41328 .6705 m .41566 .66785 L .4134 .6682 L F
0 0 .549 r
.56129 .65348 m .56003 .65034 L .55973 .65192 L F
.257 .551 .929 r
.73752 .518 m .73522 .51868 L .73437 .51703 L F
.73752 .518 m .73819 .51962 L .73522 .51868 L F
.149 0 .046 r
.6983 .46402 m .70129 .46297 L .70221 .46117 L F
.349 .002 .226 r
.69858 .46495 m .70129 .46297 L .6983 .46402 L F
.909 .982 .766 r
.68655 .50227 m .6851 .50601 L .68755 .50326 L F
.68655 .50227 m .68447 .50536 L .6851 .50601 L F
.696 .284 .261 r
.53063 .69377 m .53308 .69577 L .5344 .69426 L F
.668 .249 .24 r
.5344 .69426 m .53308 .69577 L .53708 .69588 L F
.719 .64 .769 r
.4863 .65136 m .48404 .65307 L .48525 .64966 L F
.721 .636 .762 r
.48838 .65029 m .4863 .65136 L .48525 .64966 L F
.06 0 0 r
.4886 .64862 m .48446 .65002 L .48932 .64905 L F
.766 .685 .773 r
.57433 .63159 m .57686 .63101 L .57417 .63018 L F
.784 .386 .299 r
.57686 .63101 m .57504 .6336 L .57417 .63018 L F
0 0 0 r
.57812 .62989 m .57686 .63101 L .5789 .63059 L F
.57812 .62989 m .57504 .6336 L .57686 .63101 L F
.718 .194 0 r
.48359 .80338 m .48044 .80027 L .48169 .80405 L F
.158 .311 .77 r
.53371 .65121 m .53608 .65335 L .53448 .65235 L F
.847 .736 .74 r
.62733 .55462 m .62661 .55098 L .62471 .55398 L F
.86 .679 .656 r
.62438 .55627 m .62733 .55462 L .62471 .55398 L F
.62438 .55627 m .62598 .55742 L .62733 .55462 L F
.085 0 0 r
.57919 .66141 m .5801 .66123 L .58218 .65904 L F
0 0 0 r
.58218 .65904 m .5801 .66123 L .58377 .65764 L F
.817 .919 .528 r
.72346 .49105 m .72443 .48994 L .72425 .48762 L F
.72346 .49105 m .72338 .49184 L .72443 .48994 L F
.807 .766 .815 r
.62827 .51968 m .6322 .51806 L .63065 .51688 L F
.502 .599 .883 r
.72318 .51354 m .72414 .51103 L .72162 .51184 L F
.72318 .51354 m .72486 .51374 L .72414 .51103 L F
.549 .407 .641 r
.43731 .68742 m .43482 .68493 L .43792 .68407 L F
.43731 .68742 m .43509 .68804 L .43482 .68493 L F
.379 .139 .419 r
.56062 .61656 m .55952 .61747 L .56065 .61472 L F
.929 .691 .207 r
.56065 .61472 m .56062 .61656 L .5601 .61336 L F
.553 .273 .446 r
.56352 .61596 m .56062 .61656 L .56065 .61472 L F
.807 .319 0 r
.54902 .76269 m .54972 .76363 L .54858 .76331 L F
.899 .826 .767 r
.72786 .50031 m .72746 .49711 L .7286 .49812 L F
.335 .48 .857 r
.54593 .64804 m .54659 .65129 L .5448 .64742 L F
.54593 .64804 m .5475 .65065 L .54659 .65129 L F
.69 .558 .7 r
.60084 .61982 m .60197 .62345 L .59855 .62269 L F
.816 .764 .804 r
.66053 .48856 m .66335 .48578 L .66075 .48661 L F
.359 .724 .988 r
.37239 .58977 m .36893 .58884 L .37093 .58855 L F
.388 .695 .981 r
.37325 .58857 m .37239 .58977 L .37093 .58855 L F
.37325 .58857 m .37488 .58986 L .37239 .58977 L F
.421 .269 .567 r
.26977 .60557 m .27156 .60502 L .27156 .60259 L F
.364 .324 .68 r
.26977 .60557 m .27155 .60736 L .27156 .60502 L F
.26977 .60557 m .27014 .60875 L .27155 .60736 L F
.633 .447 .614 r
.60924 .53739 m .61225 .53737 L .61178 .53463 L F
.61 .478 .677 r
.61178 .53463 m .61467 .53442 L .61373 .53151 L F
.593 .42 .617 r
.61178 .53463 m .61459 .53684 L .61467 .53442 L F
.61178 .53463 m .61225 .53737 L .61459 .53684 L F
.566 .639 .882 r
.4861 .78339 m .48658 .78044 L .48432 .78106 L F
.4861 .78339 m .48774 .78315 L .48658 .78044 L F
.546 .461 .71 r
.27014 .60875 m .27296 .61082 L .27155 .60736 L F
.27014 .60875 m .27078 .61139 L .27296 .61082 L F
.536 .304 .51 r
.59409 .54879 m .59649 .54838 L .59658 .54617 L F
.573 .334 .516 r
.59658 .54617 m .59895 .548 L .59925 .54585 L F
.59658 .54617 m .59649 .54838 L .59895 .548 L F
.996 .788 .506 r
.62429 .57289 m .62556 .57141 L .62491 .57073 L F
.62429 .57289 m .6252 .57416 L .62556 .57141 L F
.99 .848 .483 r
.62534 .56827 m .62491 .57073 L .62556 .57141 L F
.049 0 0 r
.44258 .69714 m .44513 .69706 L .44576 .69689 L F
.304 .756 .957 r
.44348 .69656 m .44513 .69706 L .44258 .69714 L F
.389 0 0 r
.44348 .69656 m .44487 .69714 L .44513 .69706 L F
.44487 .69714 m .44645 .69779 L .44513 .69706 L F
.049 0 0 r
.44576 .69689 m .44513 .69706 L .44593 .69688 L F
.557 0 0 r
.44645 .69779 m .44593 .69688 L .44513 .69706 L F
.44645 .69779 m .44826 .6985 L .44593 .69688 L F
.159 .256 .716 r
.55204 .75932 m .55212 .75727 L .55384 .75492 L F
.55204 .75932 m .55318 .75768 L .55212 .75727 L F
.672 .958 .943 r
.55105 .75898 m .55318 .75768 L .55204 .75932 L F
.454 .208 .45 r
.31142 .61086 m .31158 .61337 L .30946 .61383 L F
.319 .051 .341 r
.31445 .60764 m .31372 .61046 L .31142 .61086 L F
.368 .146 .44 r
.31335 .61262 m .31142 .61086 L .31372 .61046 L F
.31335 .61262 m .31158 .61337 L .31142 .61086 L F
.511 .341 .587 r
.41101 .67092 m .41314 .67275 L .41328 .6705 L F
.41101 .67092 m .41105 .67322 L .41314 .67275 L F
.263 .771 .835 r
.73638 .47478 m .7349 .47539 L .73393 .474 L F
.73638 .47478 m .73751 .47487 L .7349 .47539 L F
.587 .184 .245 r
.70339 .46649 m .70291 .46836 L .7001 .46813 L F
.586 .318 .477 r
.62717 .51157 m .63006 .51177 L .62958 .5097 L F
.433 .191 .446 r
.38441 .61695 m .38399 .61923 L .38195 .61973 L F
.526 .302 .517 r
.38656 .61638 m .38399 .61923 L .38441 .61695 L F
.686 .42 .514 r
.50056 .64847 m .49995 .65096 L .49795 .65022 L F
.308 .07 .38 r
.50225 .64968 m .50056 .64847 L .50241 .64745 L F
.50119 .65008 m .49995 .65096 L .50023 .64981 L F
.599 .559 .781 r
.50119 .65008 m .49995 .65096 L .50166 .65006 L F
.49795 .65022 m .49995 .65096 L .50119 .65008 L F
.518 .916 .834 r
.49572 .65119 m .49603 .65091 L .49442 .65176 L F
.49795 .65022 m .49603 .65091 L .49572 .65119 L F
.566 .178 .266 r
.50131 .65011 m .49711 .65235 L .49603 .65091 L F
.50119 .65008 m .49603 .65091 L .49795 .65022 L F
.50131 .65011 m .49603 .65091 L .50119 .65008 L F
.013 .053 .558 r
.49603 .65091 m .4978 .65145 L .49749 .64958 L F
.49603 .65091 m .49749 .64958 L .49732 .64858 L F
.566 .178 .266 r
.50166 .65006 m .50136 .65021 L .50131 .65011 L F
.308 .07 .38 r
.50131 .65011 m .49995 .65096 L .50119 .65008 L F
.50135 .65018 m .49995 .65096 L .50131 .65011 L F
.502 .909 .836 r
.50166 .65006 m .49995 .65096 L .50135 .65018 L F
.50166 .65006 m .50135 .65018 L .50225 .64968 L F
.566 .178 .266 r
.50136 .65021 m .49711 .65235 L .50067 .65045 L F
.50135 .65018 m .50067 .65045 L .50131 .65011 L F
.50136 .65021 m .50067 .65045 L .50135 .65018 L F
.308 .07 .38 r
.50142 .65014 m .50135 .65018 L .50131 .65011 L F
.566 .178 .266 r
.50166 .65006 m .50131 .65011 L .50119 .65008 L F
.308 .07 .38 r
.50225 .64968 m .50142 .65014 L .50056 .64847 L F
.50142 .65014 m .50023 .64981 L .50056 .64847 L F
.163 0 .261 r
.46926 .63768 m .47016 .63831 L .471 .63686 L F
.46926 .63768 m .46862 .63951 L .47016 .63831 L F
.791 .58 .614 r
.60698 .56602 m .60374 .56797 L .60345 .56588 L F
.60698 .56602 m .60712 .56848 L .60374 .56797 L F
.844 .9 .877 r
.73546 .5082 m .73893 .50679 L .73687 .50648 L F
.586 .913 .975 r
.73687 .50648 m .73893 .50679 L .74121 .50588 L F
.622 .434 .607 r
.5855 .61664 m .58797 .61664 L .58783 .61419 L F
.612 .427 .607 r
.58783 .61419 m .58797 .61664 L .59036 .61389 L F
.688 .52 .654 r
.60084 .61982 m .60366 .62203 L .60197 .62345 L F
.60084 .61982 m .60351 .62026 L .60366 .62203 L F
.601 .461 .663 r
.57209 .6511 m .57223 .65423 L .57029 .65358 L F
.094 0 0 r
.46376 .64225 m .46544 .64194 L .46564 .64127 L F
.476 .169 .366 r
.46256 .6441 m .46544 .64194 L .46376 .64225 L F
0 0 0 r
.65967 .48802 m .65802 .49183 L .66053 .48856 L F
.65967 .48802 m .65899 .48993 L .65802 .49183 L F
.713 .916 .566 r
.65899 .48993 m .65698 .49271 L .65802 .49183 L F
.151 0 0 r
.49512 .79168 m .49672 .78977 L .495 .79088 L F
.49512 .79168 m .495 .79088 L .49278 .79145 L F
.328 0 0 r
.4916 .79087 m .49512 .79168 L .49278 .79145 L F
.4916 .79087 m .49339 .79142 L .49512 .79168 L F
0 .169 .707 r
.49372 .79143 m .49512 .79168 L .49339 .79142 L F
.49608 .79153 m .49512 .79168 L .49372 .79143 L F
.953 .686 .493 r
.49512 .79168 m .49698 .79251 L .49694 .79201 L F
.49512 .79168 m .49694 .79201 L .49672 .78977 L F
.606 .43 .618 r
.59018 .61136 m .59266 .61099 L .59251 .60852 L F
.533 .338 .561 r
.59266 .61099 m .59497 .60817 L .59251 .60852 L F
.899 .826 .767 r
.72786 .50031 m .72564 .5003 L .72746 .49711 L F
.877 .792 .762 r
.72786 .50031 m .72464 .50193 L .72564 .5003 L F
.72786 .50031 m .72599 .50325 L .72464 .50193 L F
.457 0 0 r
.29302 .63952 m .29185 .63885 L .29031 .63836 L F
.609 .753 .947 r
.69794 .49807 m .70103 .49933 L .70085 .49743 L F
.734 .845 .932 r
.70085 .49743 m .70103 .49933 L .70383 .49754 L F
.82 .811 .842 r
.48172 .64493 m .4854 .64385 L .4838 .64349 L F
.896 .975 .816 r
.48585 .64142 m .4854 .64385 L .48697 .64277 L F
.48585 .64142 m .4838 .64349 L .4854 .64385 L F
.49 .799 .999 r
.26549 .6681 m .26803 .66784 L .26601 .66681 L F
.564 .313 .494 r
.26803 .66784 m .26742 .67007 L .26549 .6681 L F
0 .209 .723 r
.26601 .66681 m .26742 .67007 L .26549 .6681 L F
.655 .765 .93 r
.40048 .5988 m .4041 .59987 L .40176 .6002 L F
.664 .509 .664 r
.40176 .6002 m .4041 .59987 L .40177 .60271 L F
.655 .765 .93 r
.40048 .5988 m .4041 .59987 L .40176 .6002 L F
.256 .711 .954 r
.43856 .69662 m .44258 .69714 L .4402 .69753 L F
.715 .811 .925 r
.49849 .80426 m .50231 .80445 L .50115 .80422 L F
.84 .981 .873 r
.50115 .80422 m .50231 .80445 L .5025 .8027 L F
.958 .647 .395 r
.6524 .49173 m .65119 .49282 L .65173 .49108 L F
.6524 .49173 m .65266 .49425 L .65119 .49282 L F
.939 .965 .714 r
.6524 .49173 m .65342 .48794 L .65383 .48809 L F
.6524 .49173 m .65173 .49108 L .65342 .48794 L F
.862 .675 .648 r
.55318 .75768 m .55384 .75492 L .55212 .75727 L F
.55318 .75768 m .55616 .75574 L .55384 .75492 L F
0 0 .043 r
.55491 .58577 m .55646 .58504 L .55723 .58287 L F
0 0 0 r
.55491 .58577 m .55549 .58615 L .55646 .58504 L F
.55491 .58577 m .55404 .58751 L .55549 .58615 L F
.893 .982 .703 r
.74835 .52997 m .7477 .53239 L .74974 .52912 L F
.771 .89 .479 r
.75047 .52711 m .74974 .52912 L .75148 .52579 L F
.828 .986 .713 r
.74835 .52997 m .74974 .52912 L .75047 .52711 L F
.119 0 .119 r
.57099 .63847 m .57033 .63752 L .57143 .6361 L F
.57099 .63847 m .56934 .63933 L .57033 .63752 L F
.184 .682 .916 r
.35019 .5872 m .35376 .58779 L .3516 .58769 L F
.456 .222 .469 r
.60841 .6138 m .60847 .61655 L .60601 .61689 L F
.402 .257 .568 r
.6106 .61072 m .61087 .61349 L .60841 .6138 L F
.18 0 .278 r
.61087 .61349 m .60847 .61655 L .60841 .6138 L F
.668 .684 .856 r
.26034 .63373 m .26135 .63644 L .26226 .63514 L F
.405 .788 .991 r
.53937 .79178 m .53823 .7927 L .53683 .79201 L F
.53937 .79178 m .53823 .7927 L .53683 .79201 L F
.422 .031 .191 r
.51836 .70256 m .51719 .7046 L .51504 .70482 L F
.525 .136 .247 r
.52037 .70376 m .51719 .7046 L .51836 .70256 L F
.507 .159 .311 r
.52062 .70249 m .52037 .70376 L .51836 .70256 L F
.102 .639 .857 r
.65717 .48617 m .65939 .48635 L .66075 .48661 L F
.67 .233 .203 r
.65717 .48617 m .65967 .48802 L .66075 .48661 L F
.994 .859 .521 r
.66075 .48661 m .65967 .48802 L .66053 .48856 L F
.306 .04 .336 r
.31562 .60969 m .31445 .60764 L .31618 .60771 L F
.31562 .60969 m .31372 .61046 L .31445 .60764 L F
0 0 0 r
.75309 .5244 m .75148 .52579 L .75347 .52277 L F
.75309 .5244 m .75047 .52711 L .75148 .52579 L F
.457 .306 .587 r
.27125 .60014 m .27313 .59955 L .27318 .59693 L F
.43 .313 .619 r
.27156 .60259 m .27313 .59955 L .27125 .60014 L F
.865 .973 .857 r
.74694 .53168 m .7477 .53239 L .74835 .52997 L F
.37 .454 .817 r
.41124 .6993 m .41376 .70142 L .41356 .69883 L F
.611 .449 .638 r
.59018 .61136 m .59036 .61389 L .59266 .61099 L F
.742 .602 .701 r
.5642 .60538 m .56803 .6052 L .56726 .6026 L F
.742 .597 .696 r
.5642 .60538 m .56598 .60846 L .56803 .6052 L F
.691 .573 .717 r
.56803 .6052 m .56912 .60273 L .56726 .6026 L F
.875 .588 .066 r
.73253 .52301 m .73238 .52441 L .73173 .52226 L F
.73253 .52301 m .73312 .52626 L .73238 .52441 L F
.868 .766 .748 r
.56528 .59902 m .56699 .59997 L .56866 .59683 L F
.971 .929 .668 r
.56866 .59683 m .56944 .59267 L .56749 .59587 L F
.388 .497 .848 r
.52674 .63837 m .5256 .64034 L .52406 .63721 L F
.638 .819 .97 r
.52773 .63959 m .5256 .64034 L .52674 .63837 L F
.096 0 0 r
.35376 .58779 m .35596 .58796 L .35739 .58799 L F
.337 .81 .906 r
.35596 .58796 m .3596 .58765 L .35739 .58799 L F
.452 .164 .384 r
.37661 .62518 m .37396 .62747 L .37441 .62575 L F
.071 0 0 r
.45079 .70575 m .44941 .70651 L .44714 .70689 L F
.245 0 0 r
.4531 .70598 m .44941 .70651 L .45079 .70575 L F
.377 .014 .215 r
.36909 .62933 m .36794 .63228 L .36563 .63276 L F
.378 .068 .308 r
.37175 .62772 m .37078 .6304 L .36909 .62933 L F
.489 .151 .321 r
.37078 .6304 m .36794 .63228 L .36909 .62933 L F
.705 .647 .789 r
.60197 .62345 m .603 .62295 L .60228 .62576 L F
.392 .15 .423 r
.603 .62295 m .60145 .62756 L .60228 .62576 L F
.45 .657 .949 r
.53595 .64119 m .53483 .64276 L .53385 .64126 L F
.283 .424 .827 r
.53595 .64119 m .53757 .64396 L .53483 .64276 L F
.785 .707 .778 r
.62374 .52545 m .62521 .52639 L .62761 .52369 L F
.832 .68 .694 r
.62374 .52545 m .62512 .52889 L .62521 .52639 L F
.542 .38 .611 r
.67704 .49494 m .67941 .49437 L .67755 .49472 L F
.06 0 0 r
.67586 .4947 m .67941 .49437 L .67704 .49494 L F
.653 .483 .641 r
.67941 .49437 m .67732 .49554 L .67704 .49494 L F
.34 .076 .36 r
.57149 .56865 m .57353 .56773 L .57377 .56501 L F
.4 .141 .402 r
.57377 .56501 m .57605 .56527 L .57627 .56262 L F
.379 0 .18 r
.57524 .5666 m .57377 .56501 L .57353 .56773 L F
.57524 .5666 m .57605 .56527 L .57377 .56501 L F
.519 .265 .469 r
.48418 .77891 m .48658 .78044 L .48545 .77706 L F
.48418 .77891 m .48432 .78106 L .48658 .78044 L F
.595 .612 .839 r
.30363 .64399 m .30513 .64492 L .30448 .64431 L F
.30363 .64399 m .30448 .64431 L .30271 .64266 L F
.049 .569 .871 r
.30448 .64431 m .3042 .64431 L .30271 .64266 L F
.30513 .64492 m .3042 .64431 L .30448 .64431 L F
.30513 .64492 m .3067 .64515 L .3042 .64431 L F
.311 0 0 r
.30622 .64499 m .30392 .6443 L .3042 .64431 L F
.30392 .6443 m .30376 .64425 L .3042 .64431 L F
.3067 .64515 m .30641 .64506 L .30622 .64499 L F
.30641 .64506 m .30376 .64425 L .30622 .64499 L F
.595 .612 .839 r
.30119 .64246 m .30363 .64399 L .30271 .64266 L F
.915 .977 .709 r
.62515 .58052 m .62353 .58152 L .62413 .58185 L F
.97 .898 .694 r
.62422 .57927 m .62515 .58052 L .62624 .57704 L F
.989 .873 .622 r
.62422 .57927 m .62353 .58152 L .62515 .58052 L F
.433 .504 .832 r
.74789 .49744 m .7493 .50064 L .75089 .49869 L F
.406 .465 .808 r
.7493 .50064 m .75219 .50215 L .75089 .49869 L F
.615 .35 .493 r
.74939 .50264 m .75219 .50215 L .7493 .50064 L F
.74939 .50264 m .75219 .50215 L .7493 .50064 L F
.179 0 .159 r
.57985 .62198 m .578 .62287 L .57737 .62419 L F
0 .525 .814 r
.32569 .58367 m .32935 .5847 L .32741 .58455 L F
.495 .238 .454 r
.38195 .61973 m .38164 .62186 L .3794 .62231 L F
.494 .237 .453 r
.38387 .62136 m .38195 .61973 L .38399 .61923 L F
.38387 .62136 m .38164 .62186 L .38195 .61973 L F
.453 .515 .833 r
.50964 .64769 m .51011 .64467 L .50809 .64493 L F
.50964 .64769 m .51104 .64724 L .51011 .64467 L F
.342 0 0 r
.50964 .64769 m .51029 .64918 L .51104 .64724 L F
.50964 .64769 m .50777 .6496 L .51029 .64918 L F
.528 .13 .231 r
.70221 .46117 m .70495 .4622 L .70454 .46032 L F
.507 .314 .553 r
.27058 .61327 m .27296 .61082 L .27078 .61139 L F
.29 .463 .858 r
.55408 .65496 m .55295 .65639 L .55121 .65336 L F
.655 .48 .635 r
.55408 .65496 m .55127 .65808 L .55295 .65639 L F
.209 0 .192 r
.56687 .57183 m .56614 .5734 L .56876 .57091 L F
.64 .752 .929 r
.70265 .48984 m .69909 .48902 L .7015 .48839 L F
.673 .792 .938 r
.7049 .48885 m .70265 .48984 L .7015 .48839 L F
.848 .651 .637 r
.6241 .53965 m .62543 .5429 L .62583 .54056 L F
.911 .956 .623 r
.7481 .49469 m .74931 .49096 L .7472 .49163 L F
.7481 .49469 m .74783 .49393 L .74931 .49096 L F
.926 .761 .281 r
.7481 .49469 m .74763 .49529 L .74783 .49393 L F
.7481 .49469 m .74789 .49744 L .74763 .49529 L F
.49 .126 .274 r
.53448 .65235 m .5304 .65557 L .53047 .65308 L F
.53448 .65235 m .53282 .65541 L .5304 .65557 L F
.595 .237 .331 r
.53705 .65443 m .53448 .65235 L .53608 .65335 L F
.631 .838 .98 r
.49728 .62012 m .49383 .61987 L .49604 .61925 L F
.295 .613 .956 r
.49819 .61905 m .49728 .62012 L .49604 .61925 L F
.49819 .61905 m .49921 .6204 L .49728 .62012 L F
.785 .707 .778 r
.62374 .52545 m .62761 .52369 L .62614 .52261 L F
.066 .276 .765 r
.50396 .78155 m .50323 .78159 L .50401 .78048 L F
.519 .667 .929 r
.50777 .78371 m .50396 .78155 L .50514 .78397 L F
0 .061 .615 r
.50401 .78048 m .50514 .78397 L .50396 .78155 L F
.466 .292 .561 r
.50323 .78159 m .50514 .78397 L .50401 .78048 L F
.50323 .78159 m .50324 .78365 L .50514 .78397 L F
.659 .546 .716 r
.75714 .49437 m .75691 .49552 L .75636 .49179 L F
.435 .345 .655 r
.75714 .49437 m .75726 .49761 L .75691 .49552 L F
.782 .659 .727 r
.6217 .52839 m .62512 .52889 L .62374 .52545 L F
.789 .612 .661 r
.6217 .52839 m .62318 .53166 L .62512 .52889 L F
.773 .588 .65 r
.62318 .53166 m .62663 .53214 L .62512 .52889 L F
.404 .161 .428 r
.58006 .61976 m .58218 .61909 L .58225 .6171 L F
.62 .299 .406 r
.58448 .61895 m .58225 .6171 L .58218 .61909 L F
.58448 .61895 m .5855 .61664 L .58225 .6171 L F
.97 .898 .694 r
.62422 .57927 m .62624 .57704 L .62538 .57622 L F
.863 .784 .772 r
.74334 .49092 m .74676 .48923 L .74606 .48801 L F
.74334 .49092 m .7445 .49214 L .74676 .48923 L F
.686 .507 .639 r
.7445 .49214 m .7472 .49163 L .74676 .48923 L F
.084 .351 .822 r
.74676 .48923 m .74882 .48938 L .74606 .48801 L F
.74676 .48923 m .74931 .49096 L .74882 .48938 L F
.472 .362 .648 r
.74676 .48923 m .7472 .49163 L .74931 .49096 L F
.504 .556 .842 r
.27565 .61939 m .2759 .61578 L .27418 .61591 L F
.27565 .61939 m .27746 .61897 L .2759 .61578 L F
.192 .249 .693 r
.48054 .65151 m .48155 .64949 L .47923 .65041 L F
.868 .669 .632 r
.48404 .65307 m .48232 .65335 L .48054 .65151 L F
.192 .249 .693 r
.48054 .65151 m .48232 .65335 L .48155 .64949 L F
.271 0 .198 r
.36139 .63386 m .36052 .63628 L .35876 .63609 L F
.093 0 .121 r
.36219 .63514 m .36139 .63386 L .36356 .63328 L F
.36219 .63514 m .36052 .63628 L .36139 .63386 L F
0 0 0 r
.56196 .57725 m .56346 .57645 L .56453 .57468 L F
.114 0 0 r
.56453 .57468 m .56549 .57554 L .56614 .5734 L F
.56453 .57468 m .56346 .57645 L .56549 .57554 L F
.575 .807 .987 r
.50216 .8095 m .50358 .81061 L .50591 .81004 L F
.50216 .8095 m .50358 .81061 L .50591 .81004 L F
.354 0 .054 r
.44515 .65268 m .44744 .65237 L .44799 .65144 L F
.408 0 .08 r
.44744 .65237 m .44963 .65222 L .44799 .65144 L F
.4 0 .13 r
.44799 .65144 m .44963 .65222 L .45037 .65112 L F
.037 .315 .802 r
.75262 .48199 m .75223 .48325 L .74994 .48077 L F
.75262 .48199 m .75296 .48342 L .75223 .48325 L F
.403 .056 .258 r
.34971 .62533 m .35189 .62484 L .35307 .62248 L F
.383 0 .154 r
.35189 .62484 m .35549 .62237 L .35307 .62248 L F
0 0 .042 r
.55723 .58287 m .55874 .58166 L .55922 .57969 L F
0 0 0 r
.55772 .58349 m .55723 .58287 L .55646 .58504 L F
.55772 .58349 m .55874 .58166 L .55723 .58287 L F
.705 .647 .789 r
.60197 .62345 m .60366 .62203 L .603 .62295 L F
.66 .604 .782 r
.74793 .50918 m .75169 .51193 L .75093 .51216 L F
.367 .07 .323 r
.75169 .51193 m .75016 .5137 L .75047 .513 L F
.533 .332 .553 r
.75169 .51193 m .75308 .50947 L .75093 .51216 L F
.75169 .51193 m .75415 .51151 L .75412 .50915 L F
.344 .806 .93 r
.75356 .51117 m .75415 .51151 L .75169 .51193 L F
.75356 .51117 m .75169 .51193 L .75047 .513 L F
.319 .046 .333 r
.76276 .51088 m .76262 .51325 L .75962 .51343 L F
.445 .206 .457 r
.76279 .51563 m .75962 .51343 L .76262 .51325 L F
.76279 .51563 m .76053 .51633 L .75962 .51343 L F
.582 .546 .779 r
.48044 .80027 m .48224 .79814 L .47999 .79859 L F
.681 .415 .513 r
.58448 .61895 m .58797 .61664 L .5855 .61664 L F
.458 .478 .792 r
.75732 .48808 m .75636 .49179 L .75533 .48832 L F
.75732 .48808 m .75829 .49138 L .75636 .49179 L F
.659 .546 .716 r
.75714 .49437 m .75636 .49179 L .75829 .49138 L F
.058 0 .137 r
.60217 .60454 m .60298 .60274 L .60064 .60559 L F
.326 .066 .358 r
.59976 .60728 m .60217 .60454 L .60064 .60559 L F
.562 .817 .993 r
.49832 .77796 m .50177 .77836 L .49956 .77893 L F
.49832 .77796 m .50177 .77836 L .49956 .77893 L F
.296 0 0 r
.50866 .69847 m .50781 .69919 L .51093 .69826 L F
.305 .582 .94 r
.39535 .59632 m .39473 .59781 L .39321 .59647 L F
.19 .722 .786 r
.34853 .59944 m .34679 .5996 L .34471 .59995 L F
.347 0 0 r
.34853 .59944 m .35048 .59971 L .34679 .5996 L F
.594 .874 .993 r
.49162 .62058 m .4926 .61908 L .49383 .61987 L F
.49162 .62058 m .49042 .61988 L .4926 .61908 L F
.748 .658 .761 r
.41991 .65937 m .41759 .66223 L .421 .66188 L F
.445 .132 .34 r
.41781 .66471 m .421 .66188 L .41759 .66223 L F
.41781 .66471 m .42014 .66435 L .421 .66188 L F
.027 0 .146 r
.421 .66188 m .42159 .66347 L .42352 .66242 L F
.421 .66188 m .42014 .66435 L .42159 .66347 L F
.023 0 0 r
.55922 .57969 m .56117 .57902 L .56196 .57725 L F
0 0 0 r
.56275 .57784 m .56196 .57725 L .56117 .57902 L F
.56275 .57784 m .56346 .57645 L .56196 .57725 L F
.589 .395 .586 r
.60682 .54025 m .60942 .5399 L .60924 .53739 L F
.543 .297 .494 r
.60942 .5399 m .61225 .53737 L .60924 .53739 L F
.033 .538 .874 r
.66888 .48627 m .66573 .4851 L .6664 .4869 L F
.328 .635 .963 r
.74901 .47952 m .74785 .48057 L .74699 .47925 L F
.74901 .47952 m .74994 .48077 L .74785 .48057 L F
.511 .823 1 r
.3015 .64195 m .29749 .64212 L .30119 .64246 L F
.637 .957 .928 r
.30218 .64112 m .3015 .64195 L .30119 .64246 L F
.229 .398 .824 r
.30119 .64246 m .30271 .64266 L .30218 .64112 L F
.372 .119 .395 r
.57627 .56262 m .57817 .56435 L .57846 .56245 L F
.57627 .56262 m .57605 .56527 L .57817 .56435 L F
.381 0 .001 r
.4424 .70741 m .44107 .70901 L .43881 .70907 L F
.268 0 0 r
.44489 .707 m .44107 .70901 L .4424 .70741 L F
.877 .92 .851 r
.68895 .49945 m .68755 .50326 L .69009 .50051 L F
.68895 .49945 m .68655 .50227 L .68755 .50326 L F
.435 .345 .655 r
.75714 .49437 m .75915 .49736 L .75726 .49761 L F
.516 .493 .77 r
.75829 .49138 m .76133 .49297 L .75714 .49437 L F
.462 .354 .645 r
.7615 .49532 m .75714 .49437 L .76133 .49297 L F
.7615 .49532 m .75915 .49736 L .75714 .49437 L F
.51 .332 .576 r
.41566 .66785 m .41781 .66471 L .4155 .66513 L F
0 0 .508 r
.52556 .60484 m .52708 .60859 L .52687 .60745 L F
0 0 .428 r
.52708 .60859 m .52811 .61003 L .52687 .60745 L F
.52708 .60859 m .52837 .61084 L .52811 .61003 L F
.479 .344 .619 r
.40973 .6794 m .41175 .67893 L .4115 .67646 L F
.492 .386 .662 r
.40973 .6794 m .4121 .68138 L .41175 .67893 L F
.475 .386 .675 r
.40973 .6794 m .41027 .68199 L .4121 .68138 L F
.782 .506 .519 r
.59649 .62554 m .59895 .62726 L .59629 .628 L F
.35 .016 .25 r
.64161 .49142 m .64317 .48951 L .63978 .48875 L F
.64161 .49142 m .64217 .49147 L .64317 .48951 L F
.697 .381 .438 r
.64317 .48951 m .64217 .49147 L .64561 .4914 L F
.348 0 .084 r
.56752 .619 m .57056 .61692 L .56804 .61891 L F
.56752 .619 m .57007 .61882 L .57056 .61692 L F
.939 .569 .238 r
.57056 .61692 m .57007 .61882 L .57129 .61944 L F
.609 .512 .719 r
.75772 .4998 m .75794 .50363 L .75613 .5043 L F
.56 .459 .696 r
.7584 .50573 m .75613 .5043 L .75794 .50363 L F
.7584 .50573 m .75711 .50709 L .75613 .5043 L F
.665 .679 .854 r
.58826 .6464 m .59096 .64587 L .5889 .64207 L F
.074 0 .115 r
.58966 .64756 m .59096 .64587 L .58826 .6464 L F
.616 .235 .298 r
.43126 .66086 m .43165 .65952 L .42921 .65932 L F
.444 .123 .325 r
.426 .66229 m .42814 .66183 L .42921 .65932 L F
.581 .261 .391 r
.42921 .65932 m .42814 .66183 L .43126 .66086 L F
.11 0 .418 r
.60298 .60274 m .60479 .60159 L .60421 .59951 L F
.228 .028 .387 r
.60217 .60454 m .60479 .60159 L .60298 .60274 L F
.971 .712 .485 r
.62553 .56188 m .62686 .563 L .62553 .55959 L F
.964 .754 .57 r
.62659 .56519 m .62686 .563 L .62553 .56188 L F
.706 .588 .721 r
.4823 .69924 m .48534 .70094 L .48467 .69662 L F
.478 .286 .541 r
.60601 .61689 m .60638 .61887 L .60351 .62026 L F
.591 .529 .754 r
.60351 .62026 m .6064 .62194 L .60366 .62203 L F
.60351 .62026 m .60638 .61887 L .6064 .62194 L F
.578 .509 .742 r
.59317 .64176 m .59394 .64538 L .59159 .64585 L F
.094 0 .128 r
.55922 .57969 m .56034 .58075 L .56117 .57902 L F
.55922 .57969 m .55874 .58166 L .56034 .58075 L F
.684 .62 .779 r
.55096 .78244 m .55302 .78139 L .54947 .78159 L F
.561 .769 .976 r
.38257 .5904 m .38186 .59215 L .38045 .5906 L F
.38257 .5904 m .384 .59164 L .38186 .59215 L F
0 .472 .859 r
.51511 .78073 m .51564 .78036 L .51381 .77892 L F
.51511 .78073 m .51686 .78132 L .51564 .78036 L F
.601 .718 .927 r
.6946 .49708 m .69557 .49862 L .69794 .49807 L F
.65 .531 .706 r
.41005 .69368 m .41232 .69375 L .41193 .69077 L F
.631 .355 .482 r
.41005 .69368 m .41137 .69614 L .41232 .69375 L F
.611 .329 .464 r
.59093 .55134 m .59385 .55061 L .59409 .54879 L F
.461 .171 .385 r
.59385 .55061 m .59649 .54838 L .59409 .54879 L F
.802 .55 .557 r
.60374 .56797 m .60047 .56513 L .60345 .56588 L F
.457 .092 .256 r
.58528 .67088 m .58429 .67303 L .58203 .67332 L F
.436 .071 .246 r
.58742 .67183 m .58528 .67088 L .5876 .67047 L F
.58742 .67183 m .58429 .67303 L .58528 .67088 L F
.539 .359 .584 r
.58754 .66794 m .5876 .67047 L .58528 .67088 L F
0 0 .069 r
.75591 .5199 m .75558 .52169 L .75347 .52277 L F
0 0 .016 r
.75558 .52169 m .75309 .5244 L .75347 .52277 L F
.154 0 0 r
.45673 .70526 m .45541 .7059 L .4531 .70598 L F
.507 .001 0 r
.45891 .70501 m .45541 .7059 L .45673 .70526 L F
.695 .267 .227 r
.53953 .65359 m .53608 .65335 L .53737 .65263 L F
.708 .452 .535 r
.54262 .65533 m .53953 .65359 L .54328 .65489 L F
.3 .791 .88 r
.54493 .65514 m .54262 .65533 L .54328 .65489 L F
.806 .593 .614 r
.54262 .65533 m .54493 .65514 L .54328 .65489 L F
.442 .218 .477 r
.62041 .52038 m .62268 .52015 L .62282 .51759 L F
.686 .671 .83 r
.62049 .52316 m .62268 .52015 L .62041 .52038 L F
.617 .43 .606 r
.63349 .49988 m .63739 .50073 L .63571 .49651 L F
.436 .292 .587 r
.63571 .49651 m .63787 .49628 L .63824 .49401 L F
.709 .475 .567 r
.63571 .49651 m .63855 .50007 L .63787 .49628 L F
.63571 .49651 m .63739 .50073 L .63855 .50007 L F
.431 .778 .997 r
.34298 .58552 m .34201 .58656 L .34059 .58584 L F
.34298 .58552 m .34425 .58629 L .34201 .58656 L F
.219 .739 .847 r
.31217 .58311 m .31557 .58321 L .31402 .583 L F
.31217 .58311 m .31455 .58284 L .31557 .58321 L F
.285 .769 .918 r
.31455 .58284 m .3186 .58286 L .31557 .58321 L F
.244 .689 .957 r
.31557 .58321 m .3186 .58286 L .32009 .58359 L F
.392 .15 .423 r
.603 .62295 m .60344 .62679 L .60145 .62756 L F
.407 .018 .184 r
.6064 .62194 m .603 .62295 L .60366 .62203 L F
.6064 .62194 m .60618 .62378 L .603 .62295 L F
.605 .432 .621 r
.60618 .62378 m .60344 .62679 L .603 .62295 L F
.379 .195 .501 r
.47337 .63402 m .47554 .63065 L .47302 .63099 L F
.169 .705 .744 r
.67755 .49472 m .67941 .49437 L .68185 .49393 L F
.054 0 .416 r
.57582 .66774 m .57721 .66685 L .57732 .66446 L F
.446 .264 .54 r
.57489 .67029 m .57721 .66685 L .57582 .66774 L F
.805 .618 .649 r
.62294 .53409 m .62646 .53656 L .62643 .53454 L F
.62294 .53409 m .62279 .53655 L .62646 .53656 L F
.807 .678 .721 r
.62279 .53655 m .6241 .53965 L .62646 .53656 L F
.426 .209 .479 r
.58006 .61976 m .57985 .62198 L .58218 .61909 L F
.43 .826 .983 r
.31428 .64872 m .31488 .64764 L .31222 .64785 L F
.31428 .64872 m .31642 .64819 L .31488 .64764 L F
.413 0 0 r
.40247 .59958 m .4041 .59987 L .40048 .5988 L F
.489 .274 .514 r
.40177 .60271 m .4041 .59987 L .40394 .60215 L F
.949 .689 .508 r
.40394 .60215 m .4041 .59987 L .40247 .59958 L F
.656 .515 .68 r
.61373 .53151 m .61707 .53169 L .61616 .5285 L F
.671 .513 .662 r
.61373 .53151 m .61713 .53416 L .61707 .53169 L F
.61373 .53151 m .61467 .53442 L .61713 .53416 L F
.358 0 0 r
.51049 .65372 m .50643 .65452 L .50718 .65412 L F
.51049 .65372 m .50947 .6545 L .50643 .65452 L F
.049 0 0 r
.51197 .65382 m .51049 .65372 L .51178 .65373 L F
.51197 .65382 m .50947 .6545 L .51049 .65372 L F
.35 .266 .619 r
.57317 .6528 m .57223 .65423 L .57209 .6511 L F
0 .057 .596 r
.57099 .6502 m .57317 .6528 L .57209 .6511 L F
.894 .702 .637 r
.48019 .7012 m .4823 .69924 L .47866 .69923 L F
.48019 .7012 m .48189 .70165 L .4823 .69924 L F
.715 .602 .729 r
.48118 .69627 m .4823 .69924 L .48467 .69662 L F
.43 .117 .331 r
.28609 .63899 m .2849 .64182 L .28256 .64221 L F
.902 .643 .535 r
.28609 .63899 m .2849 .64182 L .28452 .63895 L F
.489 .288 .533 r
.28847 .63943 m .2861 .64226 L .28609 .63899 L F
.855 .658 .636 r
.48121 .64729 m .48443 .6483 L .48172 .64493 L F
.806 .374 .221 r
.48121 .64729 m .48467 .64904 L .48443 .6483 L F
.855 .658 .636 r
.48121 .64729 m .48443 .6483 L .48172 .64493 L F
.771 .741 .826 r
.67605 .50376 m .67208 .50495 L .675 .50289 L F
.726 .886 .954 r
.67795 .50277 m .67605 .50376 L .675 .50289 L F
.671 .395 .494 r
.59895 .62726 m .59637 .63033 L .59629 .628 L F
.59895 .62726 m .59901 .63034 L .59637 .63033 L F
.54 .352 .575 r
.60145 .62756 m .59901 .63034 L .59895 .62726 L F
0 .151 .691 r
.74339 .47436 m .74529 .47642 L .74525 .47793 L F
0 .271 .774 r
.74529 .47642 m .74699 .47925 L .74525 .47793 L F
.08 .632 .823 r
.5394 .77561 m .54016 .77583 L .53664 .77551 L F
.5394 .77561 m .54016 .77583 L .53664 .77551 L F
.235 .074 .448 r
.27073 .80138 m .27054 .80406 L .27026 .80394 L F
.27073 .80138 m .27054 .80406 L .27026 .80394 L F
.553 .466 .711 r
.7118 .48015 m .71357 .476 L .71115 .4796 L F
0 0 .244 r
.60654 .59144 m .60805 .59003 L .60778 .58815 L F
0 0 .072 r
.60654 .59144 m .60722 .59216 L .60805 .59003 L F
.60654 .59144 m .60581 .59359 L .60722 .59216 L F
.092 0 .235 r
.57705 .58219 m .57767 .58025 L .5791 .57921 L F
.772 .628 .702 r
.62294 .53409 m .62663 .53214 L .62318 .53166 L F
.62294 .53409 m .62643 .53454 L .62663 .53214 L F
.605 .407 .587 r
.44799 .66775 m .44562 .67042 L .44563 .66797 L F
.43 .255 .541 r
.62282 .51759 m .62537 .5168 L .62478 .51443 L F
.534 .292 .495 r
.62282 .51759 m .62519 .51937 L .62537 .5168 L F
.62282 .51759 m .62268 .52015 L .62519 .51937 L F
.544 .173 .288 r
.51333 .69824 m .51574 .69818 L .51685 .69585 L F
.505 .148 .295 r
.51574 .69818 m .51905 .69568 L .51685 .69585 L F
.485 .45 .743 r
.41027 .68199 m .41088 .68498 L .41255 .68447 L F
.426 .251 .539 r
.41088 .68498 m .41264 .68725 L .41255 .68447 L F
.41088 .68498 m .41075 .68761 L .41264 .68725 L F
.834 .851 .859 r
.50514 .78397 m .50646 .78553 L .50777 .78371 L F
.72 .566 .681 r
.48118 .69627 m .48467 .69662 L .48364 .69499 L F
.558 .746 .965 r
.66169 .50018 m .6603 .50214 L .65939 .49993 L F
.66169 .50018 m .6634 .50203 L .6603 .50214 L F
.306 .129 .469 r
.75832 .51699 m .75834 .51947 L .75591 .5199 L F
.205 0 .119 r
.75834 .51947 m .75558 .52169 L .75591 .5199 L F
.896 .984 .794 r
.72346 .49105 m .72267 .49313 L .72338 .49184 L F
.132 0 0 r
.71357 .476 m .7165 .47476 L .71446 .47592 L F
.182 .701 .881 r
.32935 .5847 m .33139 .58463 L .33324 .58496 L F
.143 0 0 r
.33139 .58463 m .33501 .5853 L .33324 .58496 L F
.278 0 .14 r
.45858 .64577 m .45786 .64705 L .46076 .64507 L F
0 0 0 r
.52757 .60181 m .52873 .60052 L .52655 .60293 L F
0 0 .054 r
.52556 .60484 m .52757 .60181 L .52655 .60293 L F
.993 .809 .555 r
.60902 .57973 m .60765 .58119 L .6082 .57884 L F
.60902 .57973 m .60853 .58205 L .60765 .58119 L F
.599 .37 .541 r
.60682 .54025 m .60957 .54199 L .60942 .5399 L F
.60682 .54025 m .60683 .54245 L .60957 .54199 L F
.34 0 .079 r
.35531 .63827 m .35876 .63609 L .35753 .6377 L F
.35531 .63827 m .35597 .6373 L .35876 .63609 L F
.257 0 .027 r
.35876 .63609 m .3597 .63721 L .35753 .6377 L F
.35876 .63609 m .36052 .63628 L .3597 .63721 L F
.501 .5 .788 r
.74793 .50918 m .75067 .50947 L .74917 .50548 L F
.512 .468 .744 r
.74793 .50918 m .75093 .51216 L .75067 .50947 L F
.772 .846 .908 r
.74681 .52691 m .74247 .52791 L .7456 .52574 L F
.428 .164 .41 r
.40345 .60409 m .40177 .60271 L .40394 .60215 L F
.40345 .60409 m .40134 .60471 L .40177 .60271 L F
.721 .845 .94 r
.5242 .80128 m .52553 .80227 L .52773 .80124 L F
.52773 .80124 m .52553 .80227 L .5242 .80128 L F
.341 .749 .981 r
.3617 .58769 m .3653 .58834 L .36317 .58851 L F
0 .356 .783 r
.51196 .77809 m .51254 .77794 L .51025 .77701 L F
.51196 .77809 m .51381 .77892 L .51254 .77794 L F
.985 .765 .522 r
.57184 .60824 m .57062 .60737 L .57163 .61075 L F
.65 .566 .747 r
.58876 .66374 m .58754 .66794 L .58632 .66468 L F
.58876 .66374 m .58965 .66779 L .58754 .66794 L F
.556 .332 .531 r
.58965 .66779 m .5876 .67047 L .58754 .66794 L F
.791 .713 .778 r
.2745 .62971 m .27765 .63072 L .27622 .62673 L F
.894 .798 .746 r
.27402 .63311 m .27765 .63072 L .2745 .62971 L F
.27402 .63311 m .276 .63425 L .27765 .63072 L F
.59 .603 .833 r
.27622 .62673 m .27765 .63072 L .28013 .62989 L F
.333 .48 .857 r
.27817 .6204 m .27935 .61882 L .27746 .61897 L F
.27817 .6204 m .28142 .62269 L .27935 .61882 L F
.686 .671 .83 r
.62049 .52316 m .62394 .52315 L .62268 .52015 L F
.735 .571 .67 r
.62043 .52516 m .62394 .52315 L .62049 .52316 L F
.139 0 .212 r
.60847 .61655 m .60638 .61887 L .60601 .61689 L F
.391 .402 .752 r
.54405 .63417 m .54518 .62957 L .54336 .63161 L F
.54405 .63417 m .54703 .63374 L .54518 .62957 L F
.284 .738 .956 r
.54647 .63427 m .54703 .63374 L .54405 .63417 L F
.41 .452 .793 r
.5532 .64217 m .5534 .63854 L .55123 .63885 L F
.5532 .64217 m .55445 .64192 L .5534 .63854 L F
0 .357 .814 r
.5475 .65065 m .55121 .65336 L .54892 .65378 L F
.015 0 0 r
.33908 .64402 m .3381 .64468 L .33677 .64477 L F
.01 0 0 r
.33677 .64477 m .3381 .64468 L .3348 .64606 L F
.449 0 .062 r
.53439 .70053 m .5324 .69958 L .5346 .69885 L F
.53439 .70053 m .53101 .70118 L .5324 .69958 L F
.5 .18 .355 r
.43393 .65901 m .43629 .65871 L .43716 .65627 L F
.466 .133 .316 r
.43629 .65871 m .43949 .65601 L .43716 .65627 L F
.826 .702 .727 r
.72599 .50325 m .72245 .50518 L .72464 .50193 L F
.72599 .50325 m .72422 .50648 L .72245 .50518 L F
.855 .839 .829 r
.71047 .48848 m .70822 .49129 L .70754 .48878 L F
.473 .223 .454 r
.39204 .61147 m .39154 .61363 L .38936 .61417 L F
.437 .191 .441 r
.39364 .61297 m .39204 .61147 L .39401 .61073 L F
.39364 .61297 m .39154 .61363 L .39204 .61147 L F
.566 .682 .918 r
.70729 .49879 m .70872 .49643 L .70619 .49695 L F
.70729 .49879 m .7097 .49822 L .70872 .49643 L F
.743 .597 .695 r
.56229 .60799 m .56598 .60846 L .5642 .60538 L F
.791 .55 .573 r
.56229 .60799 m .56557 .61097 L .56598 .60846 L F
.194 .063 .463 r
.61318 .60377 m .61254 .6078 L .61204 .60525 L F
.008 0 .106 r
.61432 .60236 m .61318 .60377 L .61204 .60525 L F
.194 .063 .463 r
.61318 .60377 m .61345 .60712 L .61254 .6078 L F
.275 0 .222 r
.61655 .60178 m .61318 .60377 L .61432 .60236 L F
.61655 .60178 m .61639 .60392 L .61318 .60377 L F
.289 .056 .376 r
.61318 .60377 m .61579 .6059 L .61345 .60712 L F
.61318 .60377 m .61639 .60392 L .61579 .6059 L F
.797 .617 .658 r
.55616 .75574 m .55601 .75823 L .55865 .75831 L F
.796 .675 .73 r
.55601 .75823 m .55722 .76148 L .55865 .75831 L F
.559 .451 .687 r
.59164 .63397 m .58953 .63654 L .58925 .63466 L F
.59164 .63397 m .59185 .63613 L .58953 .63654 L F
.566 .489 .728 r
.58953 .63654 m .59185 .63613 L .59224 .63974 L F
.585 .497 .721 r
.54551 .61287 m .54633 .61695 L .54381 .61682 L F
.198 .659 .942 r
.73128 .47306 m .73393 .474 L .7319 .47429 L F
0 0 0 r
.65843 .48082 m .66071 .48048 L .66194 .48018 L F
.193 0 0 r
.66071 .48048 m .66414 .47995 L .66194 .48018 L F
.537 .122 .202 r
.27622 .62673 m .27839 .62699 L .27651 .6257 L F
.409 .23 .525 r
.57675 .66239 m .57732 .66446 L .57919 .66141 L F
.625 .459 .638 r
.373 .75166 m .3731 .75332 L .37476 .75002 L F
.439 .368 .68 r
.75915 .49736 m .75985 .49937 L .75726 .49761 L F
.47 .362 .649 r
.75726 .49761 m .75985 .49937 L .75772 .4998 L F
.691 .535 .671 r
.61616 .5285 m .61946 .53136 L .61837 .52783 L F
.61616 .5285 m .61707 .53169 L .61946 .53136 L F
.729 .874 .949 r
.65819 .50406 m .65549 .5059 L .65877 .50545 L F
.001 .349 .826 r
.65877 .50545 m .65974 .50492 L .65819 .50406 L F
.083 .508 .901 r
.65877 .50545 m .66103 .50628 L .65974 .50492 L F
.351 0 0 r
.35384 .59923 m .3529 .59975 L .35048 .59971 L F
.148 0 0 r
.35606 .59892 m .3529 .59975 L .35384 .59923 L F
.404 .332 .662 r
.438 .6787 m .43603 .6762 L .43761 .67593 L F
.438 .6787 m .43612 .67945 L .43603 .6762 L F
0 0 0 r
.46862 .63951 m .46658 .64065 L .46564 .64127 L F
.759 .79 .879 r
.69607 .48665 m .69321 .48883 L .69189 .48729 L F
0 0 .514 r
.72938 .5189 m .73005 .52009 L .73173 .52226 L F
.358 .791 .968 r
.58726 .64244 m .58366 .64223 L .58486 .64236 L F
0 0 .074 r
.45616 .66189 m .45534 .66438 L .45415 .66509 L F
.119 0 0 r
.45842 .66212 m .45534 .66438 L .45616 .66189 L F
.361 .618 .949 r
.65856 .5206 m .66041 .52117 L .66027 .51944 L F
.655 .707 .885 r
.69009 .50051 m .69262 .50096 L .69203 .49709 L F
.84 .829 .837 r
.69203 .49709 m .69262 .50096 L .6946 .49708 L F
.722 .389 .414 r
.56849 .62451 m .57233 .62285 L .57056 .62171 L F
.553 .272 .442 r
.44324 .67066 m .44506 .67217 L .443 .67283 L F
.44324 .67066 m .44562 .67042 L .44506 .67217 L F
.25 .336 .757 r
.556 .64513 m .55786 .64401 L .55445 .64192 L F
.556 .64513 m .55688 .64488 L .55786 .64401 L F
.23 .261 .687 r
.556 .64513 m .558 .64723 L .55688 .64488 L F
.742 .631 .737 r
.46867 .65347 m .46992 .65693 L .46652 .65617 L F
.864 .43 .173 r
.46989 .65941 m .46652 .65617 L .46992 .65693 L F
.667 .592 .761 r
.47241 .65625 m .46992 .65693 L .46867 .65347 L F
.61 .469 .665 r
.47241 .65625 m .46989 .65941 L .46992 .65693 L F
.304 .698 .977 r
.5471 .77495 m .54847 .77602 L .54597 .77577 L F
.54597 .77577 m .54847 .77602 L .5471 .77495 L F
.5471 .77495 m .54847 .77602 L .54597 .77577 L F
.667 .492 .639 r
.58422 .65284 m .58672 .65339 L .58702 .65142 L F
.378 .672 .974 r
.36858 .59939 m .36821 .59719 L .36688 .59733 L F
.36858 .59939 m .36999 .59886 L .36821 .59719 L F
0 0 0 r
.52021 .6552 m .52226 .65378 L .52078 .65337 L F
.541 .303 .503 r
.52226 .65378 m .52239 .65031 L .52078 .65337 L F
.079 .636 .797 r
.33901 .60056 m .33945 .60033 L .33737 .60046 L F
.33901 .60056 m .34106 .60049 L .33945 .60033 L F
.785 .447 .415 r
.57249 .67278 m .57593 .6734 L .57352 .67061 L F
.57249 .67278 m .57336 .67095 L .57375 .67147 L F
.57249 .67278 m .57489 .67029 L .57468 .6725 L F
.57249 .67278 m .57468 .6725 L .57286 .67058 L F
.57244 .67067 m .57286 .67058 L .57243 .67013 L F
.57249 .67278 m .57286 .67058 L .57244 .67067 L F
.587 .068 0 r
.57346 .67146 m .5742 .67209 L .57243 .67013 L F
.5742 .67209 m .57389 .67167 L .57243 .67013 L F
.378 .128 .404 r
.57468 .6725 m .57716 .66937 L .57489 .67029 L F
.587 .068 0 r
.5742 .67209 m .57468 .6725 L .57389 .67167 L F
.19 0 0 r
.57346 .67146 m .57716 .66937 L .57468 .6725 L F
.57346 .67146 m .57587 .67082 L .57686 .66971 L F
.57637 .66981 m .57686 .66971 L .57716 .66937 L F
.57346 .67146 m .57686 .66971 L .57637 .66981 L F
.785 .447 .415 r
.57375 .67147 m .57352 .67061 L .57489 .67029 L F
.57336 .67095 m .57352 .67061 L .57375 .67147 L F
.735 .571 .67 r
.62043 .52516 m .62374 .52545 L .62394 .52315 L F
.694 .675 .828 r
.62268 .52015 m .62394 .52315 L .62614 .52261 L F
.785 .707 .778 r
.62374 .52545 m .62614 .52261 L .62394 .52315 L F
.43 .313 .619 r
.27156 .60259 m .27332 .60199 L .27313 .59955 L F
.415 .273 .579 r
.27156 .60259 m .27338 .60443 L .27332 .60199 L F
.429 .275 .569 r
.27156 .60502 m .27338 .60443 L .27156 .60259 L F
.155 .132 .578 r
.4377 .68059 m .43612 .67945 L .438 .6787 L F
.4377 .68059 m .43643 .68195 L .43612 .67945 L F
.466 .19 .411 r
.58847 .55364 m .59093 .55134 L .58879 .5518 L F
.473 .015 .084 r
.46246 .70418 m .46101 .70599 L .45891 .70501 L F
.531 .105 .176 r
.46467 .70425 m .46101 .70599 L .46246 .70418 L F
0 0 0 r
.3727 .60543 m .37014 .60809 L .37193 .60696 L F
.603 .548 .766 r
.3727 .60543 m .37499 .60493 L .37401 .60156 L F
0 0 0 r
.37193 .60696 m .37499 .60493 L .3727 .60543 L F
.394 .415 .764 r
.27318 .63639 m .27319 .63682 L .27229 .63335 L F
.435 .126 .342 r
.38164 .62186 m .37868 .62462 L .3794 .62231 L F
.514 .345 .59 r
.61664 .59984 m .61655 .60178 L .61432 .60236 L F
.791 .62 .669 r
.72737 .51126 m .73042 .51162 L .72994 .51076 L F
.781 .958 .926 r
.72994 .51076 m .73042 .51162 L .73335 .50937 L F
.837 .367 .016 r
.56542 .63048 m .56782 .63295 L .56688 .63151 L F
.575 .376 .574 r
.59399 .62839 m .59388 .63096 L .59116 .63218 L F
.545 .303 .499 r
.59629 .628 m .59388 .63096 L .59399 .62839 L F
0 0 .049 r
.57134 .58869 m .57067 .58855 L .57115 .58694 L F
.489 .288 .533 r
.28847 .63943 m .28818 .64175 L .2861 .64226 L F
.503 .893 .954 r
.53282 .59815 m .53602 .59708 L .53664 .59773 L F
.069 .396 .853 r
.5374 .59701 m .53664 .59773 L .53602 .59708 L F
.5374 .59701 m .53885 .59887 L .53664 .59773 L F
.751 .42 0 r
.56469 .66242 m .56537 .66452 L .56414 .66126 L F
0 .189 .72 r
.51361 .63104 m .51559 .63315 L .51493 .63387 L F
0 .257 .767 r
.51645 .63413 m .51493 .63387 L .51559 .63315 L F
.51645 .63413 m .51722 .63576 L .51493 .63387 L F
.646 .844 .976 r
.42988 .70934 m .43107 .71034 L .4332 .70937 L F
0 0 .549 r
.56129 .65348 m .56141 .65238 L .56003 .65034 L F
0 0 .531 r
.56129 .65348 m .56266 .65563 L .56141 .65238 L F
.574 .802 .986 r
.33594 .6293 m .33348 .63009 L .33212 .62891 L F
.607 .437 .626 r
.5891 .65132 m .58672 .65339 L .58702 .65142 L F
.5891 .65132 m .58672 .65339 L .58702 .65142 L F
.579 .151 .193 r
.52728 .69516 m .53063 .69377 L .52738 .69343 L F
.52728 .69516 m .5296 .69549 L .53063 .69377 L F
.696 .283 .258 r
.53063 .69377 m .5296 .69549 L .53308 .69577 L F
.606 .823 .983 r
.67012 .50581 m .66714 .50563 L .66913 .5046 L F
.79 .645 .702 r
.67012 .50581 m .66627 .50754 L .66714 .50563 L F
.67012 .50581 m .66827 .50907 L .66627 .50754 L F
.714 .869 .955 r
.67208 .50495 m .67012 .50581 L .66913 .5046 L F
.796 .674 .73 r
.66627 .51897 m .66488 .5207 L .66345 .51694 L F
.66627 .51897 m .66345 .51694 L .66381 .51958 L F
.904 .891 .807 r
.66381 .51958 m .66488 .5207 L .66627 .51897 L F
.818 .747 .785 r
.74553 .51555 m .74365 .51724 L .74586 .51484 L F
.744 .836 .92 r
.75016 .5137 m .74553 .51555 L .74586 .51484 L F
.395 .726 .99 r
.37903 .58953 m .3784 .59073 L .377 .58941 L F
.37903 .58953 m .38045 .5906 L .3784 .59073 L F
.887 .728 .679 r
.62499 .54782 m .62677 .54872 L .62555 .54544 L F
.826 .685 .708 r
.62499 .54782 m .62661 .55098 L .62677 .54872 L F
.881 .823 .786 r
.56093 .60667 m .5642 .60538 L .56313 .60386 L F
.56093 .60667 m .56229 .60799 L .5642 .60538 L F
.11 0 0 r
.42434 .66284 m .42352 .66242 L .42159 .66347 L F
.42434 .66284 m .426 .66229 L .42352 .66242 L F
.864 .43 .173 r
.46989 .65941 m .46816 .65907 L .46652 .65617 L F
.953 .618 .34 r
.4701 .6619 m .46816 .65907 L .46989 .65941 L F
.61 .469 .665 r
.47241 .65625 m .4728 .65943 L .46989 .65941 L F
.386 .089 .334 r
.4728 .65943 m .4701 .6619 L .46989 .65941 L F
.502 .118 .244 r
.51504 .70482 m .51243 .7061 L .51272 .70538 L F
.688 .417 .506 r
.62717 .51157 m .62938 .51339 L .63006 .51177 L F
.62717 .51157 m .62744 .5137 L .62938 .51339 L F
.441 .009 .121 r
.34744 .62555 m .34911 .62651 L .34971 .62533 L F
.34744 .62555 m .34598 .62721 L .34911 .62651 L F
.499 .338 .593 r
.36476 .61317 m .36681 .61029 L .36522 .61068 L F
.409 .097 .322 r
.3729 .62992 m .37175 .62772 L .37396 .62747 L F
.3729 .62992 m .37078 .6304 L .37175 .62772 L F
.807 .332 .083 r
.55188 .76618 m .54858 .76331 L .54972 .76363 L F
0 0 0 r
.34115 .64367 m .34505 .6419 L .34336 .64326 L F
.019 0 0 r
.34336 .64326 m .34505 .6419 L .34734 .64113 L F
.693 .703 .855 r
.45885 .68785 m .45752 .6871 L .45742 .68451 L F
.45885 .68785 m .45539 .68705 L .45752 .6871 L F
.45539 .68705 m .45885 .68785 L .45752 .6871 L F
.977 .703 .44 r
.45752 .6871 m .45885 .68785 L .45742 .68451 L F
.91 .982 .746 r
.46787 .67047 m .46688 .671 L .46927 .6679 L F
.807 .354 .161 r
.46685 .67206 m .46688 .671 L .46787 .67047 L F
.969 .873 .685 r
.73132 .48882 m .72931 .49065 L .73005 .48774 L F
.73132 .48882 m .73018 .49191 L .72931 .49065 L F
.61 .306 .429 r
.65939 .48635 m .65967 .48802 L .65717 .48617 L F
.489 .82 .52 r
.48685 .77562 m .48787 .77465 L .48866 .77564 L F
.48685 .77562 m .48602 .77639 L .48787 .77465 L F
.545 .531 .79 r
.49 .77847 m .48685 .77562 L .48866 .77564 L F
0 .376 .798 r
.71047 .48848 m .70971 .48767 L .70741 .48666 L F
.855 .839 .829 r
.71047 .48848 m .70754 .48878 L .70971 .48767 L F
.452 .017 .121 r
.45627 .69801 m .45864 .69795 L .45898 .69744 L F
.286 0 0 r
.45452 .69759 m .45717 .698 L .45504 .69814 L F
.45475 .69759 m .45717 .698 L .45452 .69759 L F
.45447 .69754 m .45627 .69801 L .45717 .698 L F
.452 .017 .121 r
.45627 .69801 m .45969 .69638 L .45717 .698 L F
.45735 .6975 m .45898 .69744 L .45969 .69638 L F
.45627 .69801 m .45898 .69744 L .45735 .6975 L F
.286 0 0 r
.45447 .69754 m .45475 .69759 L .45452 .69759 L F
.51 .274 .493 r
.58951 .56864 m .58968 .56875 L .58768 .57062 L F
.487 .282 .527 r
.5919 .56569 m .59204 .56844 L .58951 .56864 L F
.24 0 .178 r
.58968 .56875 m .59084 .56989 L .58886 .57086 L F
.358 0 .088 r
.58951 .56864 m .59084 .56989 L .58968 .56875 L F
.58951 .56864 m .59204 .56844 L .59084 .56989 L F
.218 0 0 r
.44826 .6985 m .45064 .6983 L .45203 .69755 L F
0 0 0 r
.45064 .6983 m .45447 .69754 L .45203 .69755 L F
.914 .719 .626 r
.55601 .75823 m .55506 .76133 L .55722 .76148 L F
.872 .986 .71 r
.55542 .76299 m .55722 .76148 L .55506 .76133 L F
.55542 .76299 m .55521 .76434 L .55722 .76148 L F
.666 .908 .581 r
.54715 .59168 m .54494 .59432 L .54593 .59277 L F
.675 .923 .613 r
.54494 .59432 m .54347 .59556 L .54593 .59277 L F
0 0 0 r
.53069 .59926 m .52873 .60052 L .52757 .60181 L F
.469 .156 .352 r
.39697 .60803 m .39602 .61043 L .39401 .61073 L F
.571 .387 .593 r
.39921 .60532 m .39924 .60774 L .39697 .60803 L F
.511 .198 .372 r
.39876 .6096 m .39697 .60803 L .39924 .60774 L F
.39876 .6096 m .39602 .61043 L .39697 .60803 L F
.765 .87 .925 r
.49964 .80047 m .50192 .80146 L .49922 .80186 L F
.516 .052 .09 r
.5218 .69366 m .52391 .69489 L .52501 .69324 L F
.69 .245 .189 r
.52501 .69324 m .52391 .69489 L .52728 .69516 L F
.624 .302 .405 r
.52501 .69324 m .52728 .69516 L .52738 .69343 L F
.647 .297 .365 r
.45138 .66771 m .44779 .66967 L .44799 .66775 L F
.45138 .66771 m .45024 .67008 L .44779 .66967 L F
.581 .226 .332 r
.45298 .66931 m .45138 .66771 L .4535 .66744 L F
.45298 .66931 m .45024 .67008 L .45138 .66771 L F
.543 .326 .536 r
.45415 .66509 m .4535 .66744 L .45138 .66771 L F
.493 .324 .58 r
.40134 .60471 m .39924 .60774 L .39921 .60532 L F
.806 .593 .614 r
.54262 .65533 m .5461 .65664 L .54493 .65514 L F
.417 .492 .829 r
.5461 .65664 m .54765 .65463 L .54493 .65514 L F
.306 .336 .728 r
.5461 .65664 m .5484 .65884 L .54765 .65463 L F
.494 .186 .373 r
.28021 .59319 m .28281 .59108 L .28116 .59176 L F
.649 .663 .85 r
.31488 .62506 m .31118 .62321 L .3135 .62353 L F
.448 .626 .928 r
.31554 .62336 m .31488 .62506 L .3135 .62353 L F
.31554 .62336 m .31679 .62495 L .31488 .62506 L F
.546 .899 .975 r
.69206 .47751 m .69108 .47885 L .69286 .47864 L F
.69206 .47751 m .68972 .47826 L .69108 .47885 L F
.382 .02 .221 r
.43393 .65901 m .43165 .65952 L .43126 .66086 L F
.464 .312 .589 r
.27318 .59693 m .27517 .5989 L .27567 .5963 L F
.27318 .59693 m .27313 .59955 L .27517 .5989 L F
0 0 .143 r
.45472 .66618 m .45415 .66509 L .45534 .66438 L F
.45472 .66618 m .4535 .66744 L .45415 .66509 L F
.439 .095 .284 r
.68636 .47201 m .68895 .47166 L .68955 .47196 L F
.499 0 0 r
.68895 .47166 m .69193 .47137 L .68955 .47196 L F
.232 .443 .86 r
.46189 .67648 m .46417 .67755 L .46288 .67515 L F
.835 .654 .657 r
.64561 .4914 m .64689 .49435 L .64756 .49174 L F
.486 .824 .533 r
.54715 .59168 m .54738 .59144 L .5494 .59084 L F
.54715 .59168 m .54593 .59277 L .54738 .59144 L F
.593 .448 .653 r
.59116 .63218 m .59164 .63397 L .58925 .63466 L F
0 .362 .821 r
.73798 .53164 m .73971 .53195 L .73721 .53044 L F
.73798 .53164 m .74063 .53312 L .73971 .53195 L F
.451 .37 .673 r
.4372 .68977 m .43509 .68804 L .43731 .68742 L F
.4372 .68977 m .43542 .69048 L .43509 .68804 L F
.51 .522 .804 r
.41075 .68761 m .41193 .69077 L .41341 .69011 L F
.283 .213 .599 r
.41232 .69375 m .41341 .69011 L .41193 .69077 L F
.681 .408 .503 r
.62478 .51443 m .62739 .51641 L .62744 .5137 L F
.62478 .51443 m .62537 .5168 L .62739 .51641 L F
.485 .45 .743 r
.41027 .68199 m .41255 .68447 L .4121 .68138 L F
.419 .104 .323 r
.38936 .61417 m .39154 .61363 L .38875 .61591 L F
.379 .195 .501 r
.47337 .63402 m .47553 .63336 L .47554 .63065 L F
.331 .083 .38 r
.47337 .63402 m .47308 .6362 L .47553 .63336 L F
.758 .739 .835 r
.59566 .66502 m .59221 .66473 L .59441 .6624 L F
.566 .574 .82 r
.59503 .66669 m .59221 .66473 L .59566 .66502 L F
.69 .708 .862 r
.59589 .6627 m .59566 .66502 L .59441 .6624 L F
.311 .21 .575 r
.59589 .6627 m .59503 .66669 L .59566 .66502 L F
.3 .791 .88 r
.54493 .65514 m .54512 .65485 L .54262 .65533 L F
.488 .078 .189 r
.54765 .65463 m .54512 .65485 L .54493 .65514 L F
.545 .309 .509 r
.59434 .56527 m .59204 .56844 L .5919 .56569 L F
.567 .114 .136 r
.50182 .70086 m .5043 .7013 L .50575 .69976 L F
.499 .106 .226 r
.5043 .7013 m .50781 .69919 L .50575 .69976 L F
.547 .107 .155 r
.28389 .59057 m .28281 .59108 L .28624 .59076 L F
.831 .658 .669 r
.60705 .57101 m .60837 .57416 L .60544 .57312 L F
.928 .759 .652 r
.60837 .57416 m .60652 .57592 L .60544 .57312 L F
.60837 .57416 m .60776 .57684 L .60652 .57592 L F
.567 .353 .55 r
.68135 .47666 m .68365 .47423 L .68135 .4747 L F
.847 .582 .539 r
.60705 .57101 m .60374 .56797 L .60712 .56848 L F
0 0 0 r
.65248 .48992 m .65301 .48918 L .65342 .48794 L F
.97 .845 .437 r
.65383 .48809 m .65342 .48794 L .65386 .48665 L F
0 0 0 r
.65301 .48918 m .65504 .48637 L .65342 .48794 L F
.97 .845 .437 r
.65386 .48665 m .65342 .48794 L .65387 .4857 L F
.434 .474 .801 r
.54218 .62805 m .54336 .63161 L .54518 .62957 L F
.655 .707 .885 r
.69009 .50051 m .69203 .49709 L .68895 .49945 L F
.92 .766 .673 r
.74334 .49092 m .74438 .49367 L .7445 .49214 L F
.74334 .49092 m .74438 .49367 L .7445 .49214 L F
.554 .348 .555 r
.58797 .61664 m .59035 .61623 L .59036 .61389 L F
.578 .405 .611 r
.59036 .61389 m .59285 .61347 L .59266 .61099 L F
.563 .354 .556 r
.59035 .61623 m .59285 .61347 L .59036 .61389 L F
.722 .584 .7 r
.61837 .52783 m .62043 .52516 L .61839 .52578 L F
.622 .643 .85 r
.50643 .65452 m .50807 .65113 L .50718 .65412 L F
.765 .931 .574 r
.74317 .49479 m .74206 .49716 L .74438 .49367 L F
.342 .454 .83 r
.74334 .49092 m .74642 .49203 L .74438 .49367 L F
0 0 0 r
.74642 .49203 m .74317 .49479 L .74438 .49367 L F
.48013 .62773 m .48219 .62682 L .48316 .62504 L F
.628 .861 .494 r
.48543 .62205 m .48316 .62504 L .48401 .62372 L F
.469 .138 .322 r
.28854 .59065 m .29077 .59033 L .29203 .58769 L F
.394 .014 .195 r
.29077 .59033 m .29429 .58773 L .29203 .58769 L F
.362 .008 .223 r
.47767 .63032 m .4799 .6298 L .48013 .62773 L F
.059 0 .158 r
.48013 .62773 m .4799 .6298 L .48219 .62682 L F
.474 .361 .645 r
.30941 .61547 m .30977 .61944 L .30763 .61969 L F
.481 .403 .691 r
.30977 .61944 m .30992 .62113 L .30763 .61969 L F
.405 .291 .61 r
.29031 .63836 m .29041 .64138 L .28847 .63943 L F
.501 .298 .536 r
.28847 .63943 m .29041 .64138 L .28818 .64175 L F
.565 .16 .234 r
.51722 .63576 m .51957 .63595 L .5206 .63415 L F
.671 .278 .292 r
.51957 .63595 m .52273 .63606 L .5206 .63415 L F
.955 .835 .686 r
.64422 .50132 m .6455 .50241 L .64482 .49958 L F
.933 .849 .737 r
.6425 .50487 m .6455 .50241 L .64422 .50132 L F
.6425 .50487 m .64371 .50604 L .6455 .50241 L F
.496 .24 .456 r
.35772 .61943 m .35994 .61901 L .36043 .61686 L F
.53 .298 .507 r
.35994 .61901 m .36247 .61633 L .36043 .61686 L F
.465 .6 .902 r
.31872 .62454 m .31832 .62694 L .31679 .62495 L F
.31872 .62454 m .32064 .62715 L .31832 .62694 L F
.283 0 0 r
.55658 .60857 m .55302 .6102 L .55259 .60801 L F
.55658 .60857 m .55605 .60922 L .5558 .60928 L F
.55564 .609 m .5558 .60928 L .5541 .6097 L F
.55658 .60857 m .5558 .60928 L .55564 .609 L F
.645 .117 0 r
.55267 .60666 m .55457 .60872 L .5558 .60929 L F
.5558 .60928 m .5558 .60929 L .5558 .60929 L F
.55267 .60666 m .5558 .60929 L .5558 .60928 L F
.704 .711 .853 r
.55267 .60666 m .5558 .60928 L .55412 .60472 L F
.5558 .60928 m .5558 .60929 L .5558 .60928 L F
.5558 .60928 m .5558 .60928 L .55412 .60472 L F
.283 0 0 r
.5541 .6097 m .55554 .60986 L .55302 .6102 L F
.55605 .60922 m .55554 .60986 L .5541 .6097 L F
.046 0 0 r
.55756 .6091 m .55658 .60857 L .55895 .60792 L F
.55756 .6091 m .55554 .60986 L .55658 .60857 L F
0 0 .001 r
.41434 .69559 m .41356 .69883 L .41564 .69843 L F
.41434 .69559 m .414 .69805 L .41356 .69883 L F
0 .298 .793 r
.41356 .69883 m .414 .69805 L .41137 .69614 L F
0 0 0 r
.41376 .70142 m .41564 .69843 L .41356 .69883 L F
.737 .251 .089 r
.51115 .77401 m .51155 .7735 L .50858 .7725 L F
.515 .886 .973 r
.49094 .79473 m .48808 .79558 L .48658 .79529 L F
.49094 .79473 m .48808 .79558 L .48658 .79529 L F
.937 .867 .744 r
.48808 .79558 m .48731 .79725 L .48658 .79529 L F
.128 0 0 r
.34471 .59995 m .34304 .60046 L .34106 .60049 L F
.34 .82 .816 r
.34679 .5996 m .34304 .60046 L .34471 .59995 L F
.283 .213 .599 r
.41232 .69375 m .41417 .69284 L .41341 .69011 L F
.333 .324 .699 r
.41232 .69375 m .41434 .69559 L .41417 .69284 L F
.6 .323 .468 r
.41232 .69375 m .41137 .69614 L .41434 .69559 L F
.41232 .69375 m .41137 .69614 L .41434 .69559 L F
.744 .836 .92 r
.75016 .5137 m .74586 .51484 L .74937 .51373 L F
.631 .961 .828 r
.75047 .513 m .75016 .5137 L .74937 .51373 L F
.174 .506 .911 r
.2836 .6453 m .28389 .64418 L .28207 .64455 L F
.2836 .6453 m .28615 .64643 L .28389 .64418 L F
0 .104 .623 r
.43707 .69257 m .43784 .69458 L .43699 .6958 L F
.192 .399 .836 r
.43784 .69458 m .43856 .69662 L .43699 .6958 L F
.018 0 0 r
.32549 .60201 m .32353 .60241 L .32193 .6026 L F
.156 0 0 r
.32701 .60192 m .32353 .60241 L .32549 .60201 L F
.769 .772 .855 r
.72414 .51103 m .72486 .51374 L .72737 .51126 L F
0 0 0 r
.69558 .47155 m .69397 .47429 L .69193 .47137 L F
.69558 .47155 m .69471 .47328 L .69397 .47429 L F
.685 .381 0 r
.69364 .47338 m .69397 .47429 L .69471 .47328 L F
.69364 .47338 m .69447 .47586 L .69397 .47429 L F
.724 .672 .799 r
.59292 .66728 m .58965 .66779 L .59221 .66473 L F
.487 .167 .35 r
.59292 .66728 m .59 .67019 L .58965 .66779 L F
.59292 .66728 m .5925 .66991 L .59 .67019 L F
.566 .574 .82 r
.59503 .66669 m .59292 .66728 L .59221 .66473 L F
.342 .047 .311 r
.59463 .6691 m .59292 .66728 L .59503 .66669 L F
.59463 .6691 m .5925 .66991 L .59292 .66728 L F
.248 0 0 r
.27791 .63525 m .27943 .63534 L .28116 .63374 L F
0 .208 .687 r
.28116 .63374 m .28416 .63588 L .28468 .63654 L F
.677 .247 .219 r
.27943 .63534 m .28416 .63588 L .28116 .63374 L F
.525 .917 .81 r
.48543 .62205 m .48665 .62096 L .4881 .6206 L F
0 0 0 r
.48543 .62205 m .48401 .62372 L .48665 .62096 L F
.419 .791 .994 r
.37093 .58855 m .36893 .58884 L .36748 .58811 L F
.228 0 0 r
.36681 .61029 m .36886 .60978 L .37014 .60809 L F
.462 .026 .122 r
.37014 .60809 m .37142 .60938 L .37193 .60696 L F
.37014 .60809 m .36886 .60978 L .37142 .60938 L F
.408 .055 .252 r
.44175 .65567 m .444 .65522 L .44515 .65268 L F
.5 .162 .326 r
.444 .65522 m .44744 .65237 L .44515 .65268 L F
.727 .631 .752 r
.27229 .63335 m .276 .63425 L .27402 .63311 L F
.717 .841 .941 r
.74063 .53312 m .74158 .5344 L .74347 .53315 L F
0 0 .081 r
.60778 .58815 m .60798 .5874 L .60808 .58508 L F
0 0 .168 r
.60778 .58815 m .60805 .59003 L .60798 .5874 L F
.865 .781 .766 r
.73855 .49928 m .74206 .49716 L .74156 .49677 L F
.73855 .49928 m .74023 .50021 L .74206 .49716 L F
.811 .999 .8 r
.74317 .49479 m .74156 .49677 L .74206 .49716 L F
.894 .837 .781 r
.66426 .51624 m .66559 .51679 L .66473 .51568 L F
.337 .774 .966 r
.66667 .51724 m .66559 .51679 L .66345 .51694 L F
.894 .837 .781 r
.66251 .51831 m .66559 .51679 L .66426 .51624 L F
.337 .774 .966 r
.66708 .51728 m .66559 .51679 L .66667 .51724 L F
.229 .394 .821 r
.66708 .51728 m .66903 .51879 L .66883 .51629 L F
.53 .592 .861 r
.53238 .63841 m .53175 .64114 L .53017 .63964 L F
.53238 .63841 m .53385 .64126 L .53175 .64114 L F
.664 .189 .115 r
.49346 .70447 m .49597 .70626 L .49237 .70579 L F
0 0 0 r
.49346 .70447 m .49237 .70579 L .49272 .70537 L F
.718 .206 .007 r
.49493 .70459 m .49346 .70447 L .49374 .70412 L F
0 0 0 r
.49346 .70447 m .49272 .70537 L .49468 .70303 L F
.718 .206 .007 r
.49374 .70412 m .49346 .70447 L .4915 .70324 L F
.623 .52 .717 r
.49718 .70249 m .49738 .70472 L .49493 .70459 L F
.66 .214 .181 r
.49738 .70472 m .49346 .70447 L .49493 .70459 L F
.868 .669 .632 r
.48404 .65307 m .4846 .65395 L .48232 .65335 L F
.868 .586 .508 r
.4846 .65395 m .48248 .65501 L .48232 .65335 L F
.938 .802 .684 r
.4846 .65395 m .484 .65603 L .48248 .65501 L F
.719 .64 .769 r
.4863 .65136 m .4846 .65395 L .48404 .65307 L F
.246 0 .305 r
.5791 .57921 m .58001 .57713 L .58146 .57631 L F
.49 0 0 r
.46828 .70427 m .46685 .70472 L .46467 .70425 L F
.532 .029 .005 r
.47049 .70461 m .46685 .70472 L .46828 .70427 L F
.313 0 .211 r
.58968 .56875 m .58599 .57282 L .58768 .57062 L F
.58968 .56875 m .58886 .57086 L .58599 .57282 L F
.943 .739 .269 r
.65707 .51643 m .65698 .51786 L .65653 .51596 L F
.774 .998 .837 r
.65707 .51643 m .65904 .51364 L .66028 .51441 L F
.65707 .51643 m .65653 .51596 L .65904 .51364 L F
.611 .499 .701 r
.63349 .49988 m .63665 .50245 L .63739 .50073 L F
.63349 .49988 m .6341 .50306 L .63665 .50245 L F
.932 .837 .728 r
.57465 .62793 m .57417 .63018 L .57231 .62903 L F
.831 .476 0 r
.57417 .63018 m .57419 .63172 L .57231 .62903 L F
.57417 .63018 m .57504 .6336 L .57419 .63172 L F
.533 .338 .561 r
.59266 .61099 m .59501 .61052 L .59497 .60817 L F
.541 .361 .587 r
.59506 .61287 m .59266 .61099 L .59285 .61347 L F
.59506 .61287 m .59501 .61052 L .59266 .61099 L F
.709 .717 .855 r
.48658 .78044 m .48774 .78315 L .49016 .78103 L F
.074 0 .115 r
.58966 .64756 m .59074 .64722 L .59096 .64587 L F
0 .209 .735 r
.59096 .64587 m .59086 .64404 L .5889 .64207 L F
.082 .147 .633 r
.59074 .64722 m .59086 .64404 L .59096 .64587 L F
.726 .886 .954 r
.67795 .50277 m .675 .50289 L .67731 .50199 L F
.837 .98 .876 r
.67795 .50277 m .67731 .50199 L .67858 .49985 L F
0 0 0 r
.57328 .65461 m .57223 .65423 L .57317 .6528 L F
.57328 .65461 m .57148 .65544 L .57223 .65423 L F
.569 .305 .476 r
.59729 .60998 m .59497 .60817 L .59501 .61052 L F
.59729 .60998 m .59754 .60797 L .59497 .60817 L F
.831 .645 .651 r
.62239 .54234 m .62543 .5429 L .6241 .53965 L F
.839 .609 .59 r
.62222 .54472 m .62543 .5429 L .62239 .54234 L F
.62222 .54472 m .62555 .54544 L .62543 .5429 L F
.694 .675 .828 r
.62268 .52015 m .62614 .52261 L .62519 .51937 L F
.829 .775 .801 r
.62519 .51937 m .62614 .52261 L .62827 .51968 L F
.376 .692 .981 r
.29185 .63885 m .29509 .64098 L .29607 .64064 L F
.511 .417 .685 r
.4115 .67646 m .41314 .67275 L .41105 .67322 L F
.542 .491 .748 r
.59142 .66138 m .58937 .66242 L .58862 .65974 L F
.658 .574 .75 r
.59142 .66138 m .58876 .66374 L .58937 .66242 L F
.394 .167 .447 r
.31158 .61337 m .30941 .61547 L .30946 .61383 L F
.545 .303 .499 r
.59629 .628 m .59637 .63033 L .59388 .63096 L F
.79 .749 .816 r
.66903 .51879 m .67045 .52018 L .67304 .5174 L F
.208 0 0 r
.31052 .58275 m .31217 .58311 L .31402 .583 L F
.536 .349 .575 r
.58617 .55666 m .58847 .55364 L .58617 .5542 L F
.283 .742 .952 r
.33501 .5853 m .33715 .5852 L .33857 .58573 L F
.238 .681 .956 r
.33923 .58506 m .33857 .58573 L .33715 .5852 L F
.33923 .58506 m .34059 .58584 L .33857 .58573 L F
.487 0 0 r
.56432 .62521 m .56478 .62565 L .56253 .62501 L F
.56432 .62521 m .56626 .62704 L .56478 .62565 L F
.751 .599 .688 r
.56444 .62502 m .56849 .62451 L .56711 .6213 L F
0 0 .436 r
.56215 .62255 m .56475 .62561 L .56358 .62347 L F
.547 .44 .684 r
.56626 .62704 m .56461 .62518 L .56475 .62562 L F
0 0 .436 r
.56475 .62561 m .56478 .62565 L .56475 .62558 L F
.56475 .62561 m .56475 .62558 L .56358 .62347 L F
.884 .73 .686 r
.56358 .62347 m .56475 .62558 L .56428 .62524 L F
0 0 .436 r
.56215 .62255 m .56476 .62564 L .56475 .62561 L F
.547 .44 .684 r
.56475 .62562 m .56474 .62558 L .56459 .62547 L F
.56475 .62562 m .56475 .62561 L .56475 .62562 L F
0 0 .436 r
.56316 .62374 m .56253 .62501 L .56476 .62564 L F
.547 .44 .684 r
.56626 .62704 m .56434 .62523 L .56428 .62524 L F
.884 .73 .686 r
.56475 .62558 m .56478 .62565 L .56428 .62524 L F
.547 .44 .684 r
.56459 .62547 m .56461 .62518 L .56434 .62523 L F
.56474 .62558 m .56461 .62518 L .56459 .62547 L F
.56475 .62561 m .56461 .62518 L .56475 .62562 L F
.751 .599 .688 r
.56428 .62524 m .56461 .62518 L .56444 .62502 L F
.56461 .62518 m .56849 .62451 L .56444 .62502 L F
0 0 .436 r
.56215 .62255 m .56219 .62278 L .56316 .62374 L F
.56219 .62278 m .56253 .62501 L .56316 .62374 L F
.56475 .62561 m .56476 .62564 L .56478 .62565 L F
.547 .44 .684 r
.56626 .62704 m .56849 .62451 L .56461 .62518 L F
.487 0 0 r
.56478 .62565 m .56626 .62704 L .56478 .62565 L F
.615 .914 .98 r
.4246 .65565 m .42224 .65652 L .42304 .65516 L F
.559 .336 .533 r
.4246 .65565 m .42435 .65843 L .42224 .65652 L F
.125 .289 .761 r
.42224 .65652 m .42435 .65843 L .42304 .65516 L F
.45 .583 .894 r
.28615 .64643 m .2872 .64828 L .28761 .64633 L F
.583 .716 .935 r
.28761 .64633 m .2872 .64828 L .28959 .64774 L F
.932 .909 .518 r
.62286 .58353 m .62413 .58185 L .62353 .58152 L F
.62286 .58353 m .62296 .58558 L .62413 .58185 L F
.412 0 0 r
.28133 .63024 m .28212 .63091 L .28013 .62989 L F
.28344 .63086 m .28248 .63089 L .28133 .63024 L F
.28248 .63089 m .28212 .63091 L .28133 .63024 L F
.183 .085 .501 r
.28309 .63123 m .28493 .63119 L .28499 .6281 L F
.719 .197 0 r
.28344 .63086 m .28539 .63279 L .28276 .63177 L F
.183 .085 .501 r
.28276 .63177 m .28362 .63154 L .28309 .63123 L F
.28362 .63154 m .28493 .63119 L .28309 .63123 L F
.2827 .6311 m .28499 .6281 L .28243 .6282 L F
.719 .197 0 r
.28344 .63086 m .28276 .63177 L .28203 .63091 L F
.183 .085 .501 r
.28276 .63177 m .28309 .63123 L .2827 .6311 L F
.28309 .63123 m .28499 .6281 L .2827 .6311 L F
.412 0 0 r
.28212 .63091 m .28203 .63091 L .28185 .63081 L F
.28212 .63091 m .28185 .63081 L .28013 .62989 L F
.767 .711 .799 r
.28416 .63588 m .28452 .63895 L .28468 .63654 L F
.957 .944 .642 r
.28468 .63654 m .28416 .63588 L .28539 .63279 L F
.257 .108 .479 r
.28468 .63654 m .28546 .63718 L .28416 .63588 L F
.28468 .63654 m .28551 .63844 L .28546 .63718 L F
.28468 .63654 m .28452 .63895 L .28551 .63844 L F
.304 0 .243 r
.5812 .55953 m .58349 .55865 L .58385 .55719 L F
.518 .215 .392 r
.58349 .55865 m .58617 .55666 L .58385 .55719 L F
0 0 .48 r
.57042 .64032 m .56957 .64226 L .56934 .63933 L F
0 0 .476 r
.57042 .64032 m .56975 .64452 L .56957 .64226 L F
.466 .459 .766 r
.55897 .62429 m .5579 .62805 L .55736 .62445 L F
.25 .754 .886 r
.64079 .50794 m .64009 .5077 L .63776 .50797 L F
.851 .998 .803 r
.6425 .50487 m .64079 .50794 L .64371 .50604 L F
.6425 .50487 m .64009 .5077 L .64079 .50794 L F
.486 .124 .277 r
.524 .70118 m .52037 .70376 L .52062 .70249 L F
.524 .70118 m .52273 .70356 L .52037 .70376 L F
.48 .093 .228 r
.52635 .70125 m .52273 .70356 L .524 .70118 L F
.556 .332 .531 r
.58965 .66779 m .59 .67019 L .5876 .67047 L F
.659 .572 .746 r
.59221 .66473 m .58965 .66779 L .58876 .66374 L F
.846 .812 .817 r
.49525 .63933 m .49296 .64221 L .49184 .63989 L F
.075 0 .457 r
.60421 .59951 m .60492 .59906 L .60564 .59585 L F
0 0 .294 r
.60421 .59951 m .60488 .60074 L .60492 .59906 L F
.60421 .59951 m .60479 .60159 L .60488 .60074 L F
0 0 .131 r
.72812 .47878 m .72671 .48257 L .72753 .48072 L F
.734 .59 .695 r
.62043 .52516 m .6217 .52839 L .62374 .52545 L F
.82 .578 .573 r
.55521 .76434 m .55512 .76678 L .55188 .76618 L F
.984 .892 .648 r
.55542 .76299 m .55512 .76678 L .55521 .76434 L F
.681 .415 .513 r
.58448 .61895 m .58796 .61884 L .58797 .61664 L F
.624 .369 .51 r
.58796 .61884 m .59041 .61868 L .58797 .61664 L F
.565 .382 .593 r
.58797 .61664 m .59041 .61868 L .59035 .61623 L F
.702 .728 .87 r
.59613 .64565 m .59773 .64789 L .59456 .64795 L F
.611 .221 .281 r
.59773 .64789 m .59397 .64998 L .59456 .64795 L F
.59773 .64789 m .59689 .64984 L .59397 .64998 L F
.238 .495 .897 r
.59853 .64667 m .59773 .64789 L .59613 .64565 L F
.571 .455 .682 r
.59853 .64667 m .59689 .64984 L .59773 .64789 L F
.398 .777 .992 r
.34868 .58645 m .34796 .5874 L .34668 .58626 L F
.34868 .58645 m .35019 .5872 L .34796 .5874 L F
.396 0 .162 r
.29656 .58768 m .2988 .58735 L .30018 .58528 L F
.277 0 .092 r
.30018 .58528 m .30087 .58673 L .3025 .5852 L F
.30018 .58528 m .2988 .58735 L .30087 .58673 L F
.921 .815 .724 r
.74365 .51724 m .74078 .51949 L .74235 .51796 L F
.74365 .51724 m .7431 .51859 L .74078 .51949 L F
0 0 0 r
.74586 .51484 m .74365 .51724 L .74522 .51577 L F
.541 .898 .686 r
.74522 .51577 m .74365 .51724 L .74235 .51796 L F
.679 .432 .542 r
.59925 .54585 m .60223 .54772 L .6021 .54547 L F
.59925 .54585 m .59895 .548 L .60223 .54772 L F
.788 .709 .777 r
.71561 .49946 m .71698 .50089 L .7187 .49986 L F
.796 .685 .741 r
.7187 .49986 m .71635 .50027 L .71561 .49946 L F
.792 .792 .852 r
.71984 .49592 m .7187 .49986 L .7211 .49691 L F
.71984 .49592 m .71635 .50027 L .7187 .49986 L F
.65 .836 .972 r
.66041 .52117 m .66488 .5207 L .66381 .51958 L F
.741 .795 .896 r
.48636 .79556 m .48731 .79725 L .48481 .79751 L F
.873 .732 .703 r
.48453 .7978 m .48666 .80246 L .48731 .79725 L F
.48421 .79787 m .48437 .79817 L .48453 .7978 L F
.48437 .79817 m .48666 .80246 L .48453 .7978 L F
.48421 .79787 m .48453 .7978 L .48675 .79746 L F
.48453 .7978 m .48731 .79725 L .48675 .79746 L F
.741 .795 .896 r
.48658 .79529 m .48663 .79542 L .48636 .79556 L F
.48658 .79529 m .48481 .79751 L .48458 .79512 L F
.518 .317 .547 r
.48675 .79746 m .48658 .79529 L .48565 .79521 L F
.48534 .79594 m .48565 .79521 L .48458 .79512 L F
.48675 .79746 m .48565 .79521 L .48534 .79594 L F
.48675 .79746 m .48543 .79603 L .48421 .79787 L F
.48543 .79603 m .48458 .79512 L .48439 .79656 L F
.48543 .79603 m .48439 .79656 L .48421 .79787 L F
.741 .795 .896 r
.48663 .79542 m .48731 .79725 L .48636 .79556 L F
.932 .667 .189 r
.48675 .79746 m .48731 .79725 L .48658 .79529 L F
.736 .735 .851 r
.55448 .61501 m .55554 .61676 L .5518 .61639 L F
.582 .813 .987 r
.31839 .647 m .31974 .64806 L .32194 .64738 L F
.31839 .647 m .31974 .64806 L .32194 .64738 L F
.721 .845 .94 r
.5242 .80128 m .52773 .80124 L .52619 .79944 L F
.52773 .80124 m .5242 .80128 L .52619 .79944 L F
.349 .822 .888 r
.69422 .46849 m .69661 .4679 L .69768 .468 L F
.783 .668 .737 r
.69768 .468 m .69422 .46849 L .69661 .4679 L F
.69768 .468 m .69558 .47155 L .69422 .46849 L F
0 .558 .728 r
.69768 .468 m .69661 .4679 L .7001 .46813 L F
.69768 .468 m .69661 .4679 L .7001 .46813 L F
.497 .424 .705 r
.76075 .50157 m .75794 .50363 L .75772 .4998 L F
.504 .416 .689 r
.76075 .50157 m .7584 .50573 L .75794 .50363 L F
.379 .044 .267 r
.45568 .64703 m .45676 .64914 L .45786 .64705 L F
.45568 .64703 m .45461 .64969 L .45676 .64914 L F
.578 .399 .604 r
.61467 .53442 m .61715 .5363 L .61713 .53416 L F
.61467 .53442 m .61459 .53684 L .61715 .5363 L F
.749 .236 0 r
.53964 .65586 m .53608 .65335 L .53953 .65359 L F
.708 .452 .535 r
.54262 .65533 m .53964 .65586 L .53953 .65359 L F
.907 .842 .769 r
.54791 .63619 m .54703 .63374 L .54647 .63427 L F
.446 .175 .408 r
.32193 .6026 m .3212 .60464 L .31909 .60515 L F
.402 .133 .387 r
.32325 .60393 m .32193 .6026 L .32353 .60241 L F
.32325 .60393 m .3212 .60464 L .32193 .6026 L F
.428 .532 .861 r
.42716 .70863 m .42828 .70649 L .42673 .70678 L F
.42716 .70863 m .42988 .70934 L .42828 .70649 L F
.571 .856 .996 r
.46064 .67049 m .45688 .67057 L .46035 .67005 L F
.45688 .67057 m .46064 .67049 L .4594 .67225 L F
.915 .918 .53 r
.4594 .67225 m .46064 .67049 L .46035 .67005 L F
.713 .43 .495 r
.55259 .60801 m .54979 .60965 L .55065 .60794 L F
.519 .329 .563 r
.27795 .59605 m .28021 .59319 L .27828 .59392 L F
.651 .633 .819 r
.66345 .51694 m .66129 .51809 L .66028 .51441 L F
.511 .417 .685 r
.4115 .67646 m .41365 .67613 L .41314 .67275 L F
.493 .351 .616 r
.41175 .67893 m .41365 .67613 L .4115 .67646 L F
.585 .51 .737 r
.7015 .48839 m .69909 .48902 L .69871 .48606 L F
0 0 0 r
.46652 .65617 m .46507 .65826 L .4646 .6588 L F
.383 0 .154 r
.35189 .62484 m .35425 .62444 L .35549 .62237 L F
.297 0 .107 r
.35549 .62237 m .35628 .62386 L .35749 .62169 L F
.35549 .62237 m .35425 .62444 L .35628 .62386 L F
.558 .877 .993 r
.67131 .49751 m .67273 .49604 L .67371 .49722 L F
.67131 .49751 m .67027 .49685 L .67273 .49604 L F
.67273 .49604 m .67131 .49751 L .67371 .49722 L F
.67273 .49604 m .67027 .49685 L .67131 .49751 L F
.944 .725 .576 r
.26803 .66784 m .26742 .67007 L .26601 .66681 L F
.664 .694 .868 r
.7067 .46028 m .7102 .46079 L .70852 .4603 L F
.402 .252 .561 r
.4372 .68977 m .43707 .69257 L .43542 .69048 L F
.543 .297 .494 r
.60942 .5399 m .61187 .53963 L .61225 .53737 L F
.575 .327 .502 r
.61225 .53737 m .6148 .53907 L .61459 .53684 L F
.61225 .53737 m .61187 .53963 L .6148 .53907 L F
.024 0 0 r
.35048 .59971 m .349 .59967 L .34679 .5996 L F
.071 .632 .78 r
.3529 .59975 m .349 .59967 L .35048 .59971 L F
.579 .682 .911 r
.56968 .62697 m .56849 .62451 L .56846 .62678 L F
.56968 .62697 m .5736 .62592 L .56849 .62451 L F
.24 .748 .879 r
.56968 .62697 m .56846 .62678 L .56647 .62704 L F
.536 .474 .733 r
.57078 .62636 m .57166 .62931 L .56846 .62678 L F
.498 .318 .567 r
.57078 .62636 m .57077 .62649 L .56846 .62678 L F
.701 .161 0 r
.56846 .62678 m .57166 .62931 L .57066 .62891 L F
.498 .318 .567 r
.57077 .62649 m .57066 .62891 L .56846 .62678 L F
.24 .748 .879 r
.56647 .62704 m .56846 .62678 L .56626 .62704 L F
.567 .744 .96 r
.49278 .79145 m .49698 .79251 L .49512 .79168 L F
.668 .684 .856 r
.26034 .63373 m .26226 .63514 L .26369 .63419 L F
.691 .59 .739 r
.26369 .63419 m .26226 .63514 L .26593 .63349 L F
.733 .73 .848 r
.72422 .50648 m .72043 .50589 L .72245 .50518 L F
.763 .821 .898 r
.56093 .60667 m .55895 .60792 L .56229 .60799 L F
.812 .717 .76 r
.55895 .60792 m .55993 .61085 L .56229 .60799 L F
.592 .391 .578 r
.55993 .61085 m .56235 .61061 L .56229 .60799 L F
.791 .55 .573 r
.56229 .60799 m .56235 .61061 L .56557 .61097 L F
.488 .304 .557 r
.50455 .64689 m .50245 .645 L .50462 .64441 L F
.50455 .64689 m .50241 .64745 L .50245 .645 L F
.714 .869 .955 r
.67208 .50495 m .66913 .5046 L .67138 .50402 L F
.731 .961 .941 r
.67208 .50495 m .67427 .50224 L .675 .50289 L F
.67208 .50495 m .67138 .50402 L .67427 .50224 L F
.586 .913 .975 r
.73687 .50648 m .74121 .50588 L .73921 .504 L F
.692 .545 .682 r
.61707 .53169 m .61713 .53416 L .61946 .53136 L F
.846 .812 .817 r
.49525 .63933 m .49184 .63989 L .49417 .63825 L F
.81 .691 .733 r
.62938 .51339 m .63111 .51417 L .63006 .51177 L F
.76 .589 .664 r
.62739 .51641 m .63111 .51417 L .62938 .51339 L F
.62739 .51641 m .63065 .51688 L .63111 .51417 L F
.28 .696 .97 r
.52882 .63887 m .52773 .63959 L .52674 .63837 L F
.52882 .63887 m .53017 .63964 L .52773 .63959 L F
.522 0 0 r
.32558 .64807 m .32402 .64847 L .32194 .64738 L F
.531 .353 .585 r
.5319 .76703 m .53201 .76955 L .52966 .76986 L F
.522 .321 .548 r
.53201 .76955 m .53186 .772 L .52966 .76986 L F
.531 .353 .585 r
.5319 .76703 m .53201 .76955 L .52966 .76986 L F
.522 .321 .548 r
.52966 .76986 m .53186 .772 L .53201 .76955 L F
0 .283 .729 r
.49008 .64427 m .48585 .64142 L .48697 .64277 L F
.557 0 0 r
.47503 .69849 m .47755 .69984 L .47866 .69923 L F
.583 .013 0 r
.47755 .69984 m .48019 .7012 L .47866 .69923 L F
.507 .314 .553 r
.27058 .61327 m .2726 .61296 L .27296 .61082 L F
.845 .728 .735 r
.62739 .51641 m .62519 .51937 L .62827 .51968 L F
.741 .67 .781 r
.62739 .51641 m .62827 .51968 L .63065 .51688 L F
.748 .747 .851 r
.42077 .70494 m .4233 .70551 L .42264 .70303 L F
.529 .606 .874 r
.42264 .70303 m .4233 .70551 L .42499 .70344 L F
.509 .576 .858 r
.4233 .70551 m .42673 .70678 L .42499 .70344 L F
.043 0 0 r
.50855 .70528 m .50531 .70519 L .50659 .70525 L F
0 0 .054 r
.52556 .60484 m .52605 .60489 L .52757 .60181 L F
0 0 .451 r
.52687 .60745 m .52605 .60489 L .52556 .60484 L F
.709 .842 .945 r
.66518 .51388 m .66374 .51261 L .66602 .51177 L F
.997 .768 .439 r
.66602 .51177 m .66627 .50754 L .66827 .50907 L F
.915 .911 .801 r
.66602 .51177 m .66374 .51261 L .6651 .51076 L F
0 0 .082 r
.72766 .48399 m .72769 .48274 L .72671 .48257 L F
.275 .334 .743 r
.41376 .70142 m .41477 .70421 L .41543 .70225 L F
.862 .675 .648 r
.55318 .75768 m .55601 .75823 L .55616 .75574 L F
.737 .803 .905 r
.75997 .50936 m .75605 .50965 L .75884 .50794 L F
.752 .79 .883 r
.76237 .5082 m .75997 .50936 L .75884 .50794 L F
.607 .61 .829 r
.76276 .51088 m .75997 .50936 L .76237 .5082 L F
.967 .821 .646 r
.7304 .48086 m .73094 .48534 L .73043 .48554 L F
.642 .769 .94 r
.66784 .49713 m .66559 .49795 L .66439 .49639 L F
.66439 .49639 m .66559 .49795 L .66784 .49713 L F
.659 .521 .684 r
.59388 .63096 m .59164 .63397 L .59116 .63218 L F
0 0 0 r
.62286 .58353 m .62215 .58763 L .62296 .58558 L F
.661 .62 .797 r
.59094 .65892 m .58862 .65974 L .58681 .65561 L F
.542 .491 .748 r
.59142 .66138 m .58862 .65974 L .59094 .65892 L F
.323 0 .011 r
.48205 .70346 m .48189 .70165 L .48019 .7012 L F
.847 .948 .884 r
.70611 .48652 m .7049 .48885 L .70741 .48666 L F
.816 .831 .861 r
.70898 .48511 m .70741 .48666 L .70621 .48474 L F
.421 0 0 r
.70741 .48666 m .70971 .48767 L .70611 .48652 L F
.095 0 .402 r
.58064 .64008 m .58257 .63592 L .58015 .63627 L F
.989 .723 .381 r
.58366 .64223 m .58246 .63821 L .58064 .64008 L F
.86 .595 .535 r
.58246 .63821 m .58252 .64129 L .58232 .64119 L F
.095 0 .402 r
.58177 .63766 m .58246 .63821 L .58256 .63595 L F
.58064 .64008 m .58246 .63821 L .58177 .63766 L F
.467 .261 .515 r
.58257 .63592 m .58246 .63821 L .58475 .63533 L F
.552 .37 .588 r
.58246 .63821 m .58496 .63779 L .58475 .63533 L F
.535 .315 .528 r
.58336 .63893 m .58246 .63821 L .58166 .63723 L F
.58479 .64036 m .58496 .63779 L .58246 .63821 L F
.58479 .64036 m .58246 .63821 L .58336 .63893 L F
.86 .595 .535 r
.58246 .63821 m .58232 .64119 L .58011 .64004 L F
.095 0 .402 r
.58256 .63595 m .58246 .63821 L .58257 .63592 L F
.989 .723 .381 r
.58366 .64223 m .58064 .64008 L .5818 .64121 L F
.871 .887 .844 r
.53082 .78056 m .53196 .78179 L .53455 .77852 L F
.399 .401 .746 r
.6341 .50306 m .63666 .50485 L .63665 .50245 L F
.667 .592 .761 r
.47241 .65625 m .46867 .65347 L .47023 .65398 L F
0 .303 .792 r
.4716 .65492 m .47241 .65625 L .47023 .65398 L F
.658 .123 0 r
.4716 .65492 m .47444 .65582 L .47241 .65625 L F
.528 .41 .662 r
.47521 .65825 m .47241 .65625 L .47444 .65582 L F
.47521 .65825 m .4728 .65943 L .47241 .65625 L F
.832 .687 .703 r
.62279 .53655 m .62086 .53924 L .6241 .53965 L F
.816 .623 .642 r
.62064 .54186 m .6241 .53965 L .62086 .53924 L F
.62064 .54186 m .62239 .54234 L .6241 .53965 L F
.432 .193 .449 r
.41328 .6705 m .41535 .66994 L .41566 .66785 L F
.51 .332 .576 r
.41566 .66785 m .41782 .66747 L .41781 .66471 L F
.341 .057 .328 r
.41535 .66994 m .41782 .66747 L .41566 .66785 L F
0 .317 .783 r
.56235 .61061 m .56592 .61324 L .56557 .61097 L F
.896 .984 .794 r
.72346 .49105 m .72097 .49405 L .72267 .49313 L F
.923 .843 .747 r
.71984 .49592 m .72267 .49313 L .72097 .49405 L F
.71984 .49592 m .7211 .49691 L .72267 .49313 L F
.964 .754 .57 r
.62659 .56519 m .62553 .56188 L .62517 .5644 L F
.922 .804 .712 r
.62373 .56725 m .62659 .56519 L .62517 .5644 L F
.62373 .56725 m .62534 .56827 L .62659 .56519 L F
.961 .702 .498 r
.62402 .56096 m .62553 .55959 L .62608 .55749 L F
.62402 .56096 m .62553 .56188 L .62553 .55959 L F
.515 .515 .794 r
.70611 .48652 m .70754 .48878 L .7049 .48885 L F
.518 .299 .522 r
.35772 .61943 m .35749 .62169 L .35994 .61901 L F
.444 .347 .65 r
.76474 .50783 m .76276 .51088 L .76237 .5082 L F
.76474 .50783 m .76521 .51095 L .76276 .51088 L F
.353 .071 .34 r
.76487 .51232 m .76276 .51088 L .76521 .51095 L F
.76487 .51232 m .76262 .51325 L .76276 .51088 L F
.891 .756 .707 r
.73839 .50194 m .74023 .50021 L .73855 .49928 L F
.704 .438 .519 r
.68131 .48274 m .67949 .48528 L .67727 .48504 L F
.508 .167 .324 r
.68276 .48292 m .67949 .48528 L .68131 .48274 L F
.101 .064 .525 r
.60776 .61837 m .6064 .62194 L .60638 .61887 L F
.60776 .61837 m .60811 .62086 L .6064 .62194 L F
.235 .031 .386 r
.60811 .62086 m .60618 .62378 L .6064 .62194 L F
.414 .788 .993 r
.71561 .49946 m .71365 .4995 L .71327 .50004 L F
.64 .658 .851 r
.71327 .50004 m .71698 .50089 L .71561 .49946 L F
.641 .472 .639 r
.61946 .53136 m .61713 .53416 L .6197 .53383 L F
.717 .603 .728 r
.61837 .52783 m .61946 .53136 L .6217 .52839 L F
.697 .574 .713 r
.61946 .53136 m .62318 .53166 L .6217 .52839 L F
.738 .594 .696 r
.6197 .53383 m .62318 .53166 L .61946 .53136 L F
0 .555 .713 r
.51231 .7918 m .51599 .79198 L .51378 .79188 L F
.337 .409 .789 r
.4377 .68059 m .4392 .68417 L .43643 .68195 L F
.374 .414 .775 r
.43643 .68195 m .4392 .68417 L .43792 .68407 L F
.743 .473 .522 r
.70495 .4622 m .7067 .46028 L .70454 .46032 L F
.70495 .4622 m .7071 .46285 L .7067 .46028 L F
.658 .414 .539 r
.7067 .46028 m .7071 .46285 L .71068 .46231 L F
.368 .101 .371 r
.44779 .66967 m .44562 .67042 L .44799 .66775 L F
.278 .029 .346 r
.55985 .62208 m .55897 .62429 L .55736 .62445 L F
.734 .845 .932 r
.70085 .49743 m .70383 .49754 L .70273 .49617 L F
.585 .663 .892 r
.70383 .49754 m .70599 .49569 L .70273 .49617 L F
.70383 .49754 m .70619 .49695 L .70599 .49569 L F
.932 .837 .728 r
.57465 .62793 m .57231 .62903 L .57427 .62693 L F
.885 .943 .846 r
.57231 .62903 m .57171 .62896 L .57427 .62693 L F
.662 .401 .515 r
.57171 .62896 m .57405 .62898 L .57427 .62693 L F
.986 .744 .485 r
.57427 .62693 m .57448 .62493 L .57465 .62793 L F
.662 .401 .515 r
.57405 .62898 m .57601 .62899 L .57427 .62693 L F
.986 .744 .485 r
.57427 .62693 m .57446 .62463 L .57448 .62493 L F
.375 .192 .5 r
.47554 .63065 m .47717 .63211 L .47767 .63032 L F
.47554 .63065 m .47553 .63336 L .47717 .63211 L F
.112 0 0 r
.31909 .60515 m .31771 .6072 L .31618 .60771 L F
.321 0 .111 r
.3212 .60464 m .31771 .6072 L .31909 .60515 L F
.311 .789 .706 r
.69804 .47202 m .69471 .47328 L .69558 .47155 L F
0 0 0 r
.73968 .47152 m .73751 .47487 L .73926 .47321 L F
.73968 .47152 m .73926 .47321 L .7386 .47063 L F
0 .283 .734 r
.7415 .47224 m .73968 .47152 L .7386 .47063 L F
.7415 .47224 m .74263 .47326 L .73968 .47152 L F
.65 .39 .512 r
.7431 .51859 m .74027 .5218 L .74078 .51949 L F
.7431 .51859 m .74447 .52204 L .74027 .5218 L F
.899 .495 .226 r
.74611 .52266 m .74447 .52204 L .7431 .51859 L F
.497 .424 .705 r
.76075 .50157 m .75772 .4998 L .75985 .49937 L F
.785 .433 .391 r
.46652 .65617 m .46816 .65907 L .46507 .65826 L F
.029 .594 .792 r
.26036 .6478 m .25873 .64754 L .25667 .64741 L F
.26036 .6478 m .25873 .64754 L .25667 .64741 L F
.211 .733 .845 r
.25873 .64754 m .26246 .64734 L .26036 .6478 L F
.25873 .64754 m .26246 .64734 L .26036 .6478 L F
.86 .72 .707 r
.62155 .55592 m .62608 .55749 L .62438 .55627 L F
.62155 .55592 m .62101 .55828 L .62608 .55749 L F
.574 .422 .638 r
.41314 .67275 m .41535 .66994 L .41328 .6705 L F
.76 .78 .869 r
.53207 .75496 m .52955 .7554 L .53192 .754 L F
.582 .171 .228 r
.53207 .75496 m .53024 .75634 L .52955 .7554 L F
.289 .427 .827 r
.53192 .754 m .53411 .75523 L .53207 .75496 L F
.326 0 0 r
.53207 .75496 m .53411 .75523 L .53024 .75634 L F
.847 .582 .539 r
.60705 .57101 m .60393 .57038 L .60374 .56797 L F
.882 .686 .632 r
.60544 .57312 m .60393 .57038 L .60705 .57101 L F
.702 .728 .87 r
.59613 .64565 m .59456 .64795 L .59394 .64538 L F
.36 .821 .923 r
.4362 .70909 m .43564 .70889 L .4332 .70937 L F
.051 .618 .759 r
.4362 .70909 m .4378 .70901 L .43564 .70889 L F
.4376 .70908 m .43881 .70907 L .4378 .70901 L F
.068 .63 .768 r
.43881 .70907 m .44107 .70901 L .4378 .70901 L F
.429 0 0 r
.4378 .70901 m .44107 .70901 L .44043 .70988 L F
0 .406 .756 r
.438 .70894 m .4378 .70901 L .44043 .70988 L F
.43641 .70833 m .4378 .70901 L .438 .70894 L F
.051 .618 .759 r
.4362 .70909 m .4376 .70908 L .4378 .70901 L F
.576 .878 .581 r
.47118 .65099 m .46939 .65255 L .46867 .65347 L F
.025 0 0 r
.47196 .65164 m .47118 .65099 L .47319 .65013 L F
.47196 .65164 m .46939 .65255 L .47118 .65099 L F
0 0 .469 r
.52837 .61084 m .5297 .61279 L .52811 .61003 L F
.202 .537 .926 r
.46939 .65255 m .47023 .65398 L .46867 .65347 L F
.033 .538 .874 r
.66888 .48627 m .66752 .48549 L .66573 .4851 L F
.472 0 0 r
.67119 .48537 m .66752 .48549 L .66888 .48627 L F
.444 0 0 r
.46593 .69926 m .46928 .69887 L .46696 .69835 L F
.461 .518 .831 r
.75608 .48501 m .75533 .48832 L .75413 .48505 L F
.75608 .48501 m .75732 .48808 L .75533 .48832 L F
.826 .685 .708 r
.62499 .54782 m .62339 .55082 L .62661 .55098 L F
.827 .667 .684 r
.62339 .55082 m .62471 .55398 L .62661 .55098 L F
.732 .362 .351 r
.51564 .78036 m .51816 .77885 L .51537 .77838 L F
.51564 .78036 m .51919 .78068 L .51816 .77885 L F
.245 .752 .719 r
.4881 .6206 m .48886 .62027 L .49042 .61988 L F
.4881 .6206 m .48665 .62096 L .48886 .62027 L F
.81 .769 .815 r
.67732 .49554 m .67371 .49722 L .67586 .4947 L F
.349 0 .055 r
.67732 .49554 m .6762 .49689 L .67371 .49722 L F
.424 .785 .996 r
.67983 .49754 m .6762 .49689 L .67732 .49554 L F
.653 .483 .641 r
.67941 .49437 m .67983 .49754 L .67732 .49554 L F
.541 .49 .749 r
.70574 .46582 m .70883 .46442 L .7071 .46285 L F
.254 0 0 r
.67232 .47912 m .67464 .47891 L .67574 .47805 L F
.315 0 0 r
.67574 .47805 m .67464 .47891 L .67814 .47843 L F
.368 0 .028 r
.67574 .47805 m .67814 .47843 L .67886 .4772 L F
.409 .104 .333 r
.57846 .56245 m .58075 .56192 L .5812 .55953 L F
.376 .111 .38 r
.58293 .56133 m .5812 .55953 L .58075 .56192 L F
.58293 .56133 m .58349 .55865 L .5812 .55953 L F
.862 .559 .473 r
.51254 .77794 m .51537 .77838 L .51413 .77552 L F
.43 .581 .902 r
.484 .65603 m .48507 .65412 L .48248 .65501 L F
.484 .65603 m .48628 .65636 L .48507 .65412 L F
.486 .276 .519 r
.484 .65603 m .48602 .65809 L .48628 .65636 L F
.484 .65603 m .48384 .65873 L .48602 .65809 L F
.484 .65603 m .48602 .65809 L .48628 .65636 L F
.484 .65603 m .48384 .65873 L .48602 .65809 L F
.598 .642 .865 r
.5448 .64742 m .5405 .64504 L .54321 .64533 L F
0 .083 .617 r
.54394 .6461 m .5448 .64742 L .54321 .64533 L F
0 .281 .758 r
.54495 .64692 m .5448 .64742 L .54394 .6461 L F
.54495 .64692 m .54593 .64804 L .5448 .64742 L F
.091 0 0 r
.56011 .61818 m .55952 .61747 L .56062 .61656 L F
.56011 .61818 m .55804 .6194 L .55952 .61747 L F
.643 .849 .979 r
.66027 .51944 m .66041 .52117 L .66381 .51958 L F
0 0 0 r
.41376 .70142 m .41446 .70048 L .41564 .69843 L F
.664 .601 .774 r
.47546 .64915 m .47637 .6531 L .47923 .65041 L F
.445 .262 .537 r
.47637 .6531 m .47683 .65305 L .47923 .65041 L F
.586 .584 .818 r
.47319 .65013 m .47683 .65305 L .47637 .6531 L F
.47319 .65013 m .47463 .65367 L .47683 .65305 L F
.205 0 .073 r
.51905 .69568 m .52067 .69585 L .5218 .69366 L F
.494 .097 .217 r
.5218 .69366 m .52067 .69585 L .52391 .69489 L F
.709 .842 .945 r
.66518 .51388 m .66229 .51352 L .66374 .51261 L F
.83 .694 .714 r
.66518 .51388 m .66345 .51694 L .66229 .51352 L F
.42 .012 .155 r
.49 .77847 m .49015 .77954 L .48658 .78044 L F
.769 .279 .061 r
.48866 .77564 m .49209 .77804 L .49 .77847 L F
.236 0 .061 r
.49179 .77826 m .49113 .77982 L .49015 .77954 L F
.49209 .77804 m .49191 .77837 L .49179 .77826 L F
.49191 .77837 m .49113 .77982 L .49179 .77826 L F
.168 .036 .445 r
.49209 .77804 m .49254 .77892 L .49376 .77684 L F
.489 0 0 r
.49206 .77853 m .49223 .77867 L .49203 .7785 L F
.49223 .77867 m .49232 .77874 L .49218 .77862 L F
.49232 .77874 m .49254 .77892 L .49219 .77863 L F
.766 .775 .86 r
.49376 .77684 m .49254 .77892 L .49206 .77853 L F
.635 .446 .609 r
.49376 .77684 m .49214 .77845 L .49209 .77804 L F
.769 .279 .061 r
.49198 .77845 m .49254 .77892 L .49209 .77804 L F
.635 .446 .609 r
.49217 .77864 m .49198 .77845 L .49209 .77804 L F
.49198 .77845 m .49191 .77837 L .49209 .77804 L F
.236 0 .061 r
.49209 .77804 m .49179 .77826 L .49164 .77813 L F
.769 .279 .061 r
.48866 .77564 m .49198 .77845 L .49209 .77804 L F
.489 0 0 r
.48981 .77671 m .49206 .77853 L .48866 .77564 L F
.49206 .77853 m .49203 .7785 L .48866 .77564 L F
.49223 .77867 m .49218 .77862 L .48866 .77564 L F
.49232 .77874 m .49219 .77863 L .48866 .77564 L F
.766 .775 .86 r
.49376 .77684 m .49206 .77853 L .48981 .77671 L F
.635 .446 .609 r
.49376 .77684 m .49217 .77864 L .49214 .77845 L F
.49217 .77864 m .49113 .77982 L .49191 .77837 L F
.236 0 .061 r
.49164 .77813 m .49015 .77954 L .49 .77847 L F
.49179 .77826 m .49015 .77954 L .49164 .77813 L F
.717 .628 .757 r
.68185 .49393 m .68409 .49092 L .68177 .49122 L F
.66 .491 .645 r
.6021 .54547 m .6045 .54527 L .60432 .54276 L F
.646 .481 .645 r
.60432 .54276 m .6045 .54527 L .60683 .54245 L F
.017 .577 .808 r
.35019 .5872 m .35227 .58743 L .35376 .58779 L F
.352 .764 .981 r
.35227 .58743 m .35596 .58796 L .35376 .58779 L F
0 0 .152 r
.61841 .59857 m .61655 .60178 L .61664 .59984 L F
.759 .702 .798 r
.68304 .49728 m .68019 .49967 L .67983 .49754 L F
.749 .551 .627 r
.68258 .49692 m .67983 .49754 L .67941 .49437 L F
.68304 .49728 m .68211 .49736 L .68258 .49692 L F
.68211 .49736 m .67983 .49754 L .68258 .49692 L F
0 .059 .602 r
.67983 .49754 m .68019 .49967 L .68083 .49722 L F
.837 .999 .793 r
.68037 .49899 m .67858 .49985 L .68083 .49722 L F
.68019 .49967 m .67958 .49974 L .68037 .49899 L F
.67958 .49974 m .67858 .49985 L .68037 .49899 L F
.423 .264 .559 r
.41781 .66471 m .41976 .66663 L .42014 .66435 L F
.41781 .66471 m .41782 .66747 L .41976 .66663 L F
.777 .755 .833 r
.76058 .50631 m .76237 .5082 L .75884 .50794 L F
.058 0 0 r
.76313 .5086 m .76474 .50783 L .76237 .5082 L F
.76313 .5086 m .76237 .5082 L .76058 .50631 L F
.325 0 .23 r
.471 .63686 m .47016 .63831 L .47308 .6362 L F
.79 .749 .816 r
.66903 .51879 m .67304 .5174 L .67159 .51612 L F
.803 .807 .854 r
.67159 .51612 m .67304 .5174 L .67486 .5158 L F
.711 .506 .61 r
.61715 .5363 m .6197 .53383 L .61713 .53416 L F
.64 .966 .872 r
.73926 .47321 m .73751 .47487 L .73638 .47478 L F
.738 .594 .696 r
.6197 .53383 m .62294 .53409 L .62318 .53166 L F
.158 0 .309 r
.61254 .6078 m .61181 .61018 L .6106 .61072 L F
.243 .112 .495 r
.61181 .61018 m .61203 .61209 L .6106 .61072 L F
.198 .111 .525 r
.6106 .61072 m .61203 .61209 L .61087 .61349 L F
.722 .584 .7 r
.61837 .52783 m .6217 .52839 L .62043 .52516 L F
.542 .38 .611 r
.69422 .46849 m .69661 .4679 L .69421 .46611 L F
.631 .346 .467 r
.69421 .46611 m .69661 .4679 L .69729 .46607 L F
0 0 .554 r
.57027 .65838 m .57172 .66077 L .57156 .66202 L F
0 0 .311 r
.57172 .66077 m .57132 .66442 L .57156 .66202 L F
.956 .695 .501 r
.62419 .57534 m .6252 .57416 L .62429 .57289 L F
.62419 .57534 m .62538 .57622 L .6252 .57416 L F
.526 .302 .517 r
.38656 .61638 m .38627 .61882 L .38399 .61923 L F
.477 .26 .504 r
.38839 .61825 m .38656 .61638 L .38875 .61591 L F
.38839 .61825 m .38627 .61882 L .38656 .61638 L F
0 0 0 r
.53069 .59926 m .52757 .60181 L .5293 .60067 L F
.5293 .60067 m .53282 .59815 L .53069 .59926 L F
.955 .878 .719 r
.73018 .49191 m .7282 .49304 L .72931 .49065 L F
.73018 .49191 m .7292 .49408 L .7282 .49304 L F
.471 .362 .648 r
.48207 .79563 m .48421 .79787 L .48458 .79512 L F
.48207 .79563 m .48224 .79814 L .48421 .79787 L F
.467 .547 .855 r
.38813 .59073 m .38752 .59392 L .38615 .59134 L F
.38813 .59073 m .38944 .59387 L .38752 .59392 L F
.716 .913 .962 r
.69607 .48665 m .69704 .4848 L .69871 .48606 L F
.623 .849 .986 r
.70038 .48517 m .69871 .48606 L .69704 .4848 L F
.585 .51 .737 r
.7015 .48839 m .69871 .48606 L .70038 .48517 L F
.271 0 0 r
.49921 .6204 m .5018 .62142 L .50321 .62196 L F
.707 .22 .086 r
.5018 .62142 m .50477 .62219 L .50321 .62196 L F
.432 0 0 r
.474 .70417 m .47288 .70483 L .47049 .70461 L F
.338 0 0 r
.47629 .70457 m .47288 .70483 L .474 .70417 L F
.377 0 0 r
.33782 .62953 m .34196 .62826 L .33861 .62942 L F
.33782 .62953 m .33979 .62977 L .34196 .62826 L F
.072 0 0 r
.34196 .62826 m .34206 .62911 L .34372 .62765 L F
.34196 .62826 m .33979 .62977 L .34206 .62911 L F
.085 0 0 r
.33089 .64699 m .3277 .64753 L .32846 .64739 L F
0 .419 .83 r
.53395 .61692 m .5361 .61731 L .53349 .61542 L F
.53395 .61692 m .53744 .61844 L .5361 .61731 L F
0 .095 .649 r
.74478 .47511 m .74339 .47436 L .74263 .47326 L F
.74478 .47511 m .74529 .47642 L .74339 .47436 L F
.463 .706 .973 r
.66481 .50028 m .6634 .50203 L .66169 .50018 L F
.66481 .50028 m .66592 .50187 L .6634 .50203 L F
.298 0 .072 r
.45037 .65112 m .45179 .65174 L .45255 .65054 L F
.45037 .65112 m .44963 .65222 L .45179 .65174 L F
.492 .578 .87 r
.37114 .60032 m .37225 .59827 L .36999 .59886 L F
.37114 .60032 m .37401 .60156 L .37225 .59827 L F
.519 .647 .914 r
.39211 .59465 m .39108 .59668 L .38944 .59387 L F
.39211 .59465 m .39321 .59647 L .39108 .59668 L F
.503 .875 .662 r
.66714 .50563 m .66847 .50442 L .66913 .5046 L F
.67 .709 .877 r
.29607 .64064 m .29749 .64212 L .3015 .64195 L F
.071 0 0 r
.74937 .51373 m .74586 .51484 L .74522 .51577 L F
.06 0 0 r
.67586 .4947 m .6783 .49458 L .67941 .49437 L F
.749 .551 .627 r
.68304 .49728 m .67941 .49437 L .68185 .49393 L F
.35 0 0 r
.6783 .49458 m .68185 .49393 L .67941 .49437 L F
.535 .573 .84 r
.31192 .62063 m .31118 .62321 L .30992 .62113 L F
.31192 .62063 m .3135 .62353 L .31118 .62321 L F
.387 .159 .443 r
.66178 .4867 m .65939 .48635 L .66223 .48486 L F
.66178 .4867 m .65967 .48802 L .65939 .48635 L F
.555 .499 .747 r
.5891 .65132 m .59164 .65068 L .59074 .64722 L F
.518 .367 .616 r
.5891 .65132 m .59227 .65388 L .59164 .65068 L F
.507 .001 0 r
.45891 .70501 m .45746 .70624 L .45541 .7059 L F
.475 0 0 r
.46101 .70599 m .45746 .70624 L .45891 .70501 L F
.329 .784 .95 r
.48155 .64949 m .48467 .64904 L .48121 .64729 L F
.48155 .64949 m .48525 .64966 L .48467 .64904 L F
.439 .51 .835 r
.2726 .61296 m .27418 .61591 L .2759 .61578 L F
.336 .522 .89 r
.74789 .49744 m .74939 .49603 L .74763 .49529 L F
.74789 .49744 m .75089 .49869 L .74939 .49603 L F
.586 .215 .304 r
.67814 .47843 m .68135 .47666 L .67886 .4772 L F
.816 .831 .861 r
.70898 .48511 m .70621 .48474 L .7088 .48474 L F
.197 .714 .882 r
.70898 .48511 m .7088 .48474 L .71198 .4849 L F
.658 .7 .877 r
.71326 .48542 m .70898 .48511 L .71198 .4849 L F
.463 0 0 r
.46928 .69887 m .47161 .69961 L .47265 .69849 L F
.55 .099 .134 r
.47161 .69961 m .47503 .69849 L .47265 .69849 L F
.424 .035 .193 r
.36563 .63276 m .36219 .63514 L .36356 .63328 L F
.248 0 0 r
.3494 .64076 m .35009 .6399 L .35263 .63901 L F
.436 .192 .444 r
.60957 .54199 m .61187 .53963 L .60942 .5399 L F
.202 0 .026 r
.46564 .64127 m .46757 .64117 L .46862 .63951 L F
.46564 .64127 m .46544 .64194 L .46757 .64117 L F
0 .021 .539 r
.50592 .62336 m .50699 .62461 L .50477 .62219 L F
.525 .017 0 r
.50777 .62547 m .50699 .62461 L .50592 .62336 L F
.661 .108 0 r
.50405 .62336 m .50633 .62525 L .50777 .62547 L F
0 .552 .752 r
.50633 .62525 m .50766 .6254 L .50777 .62547 L F
.50766 .6254 m .50987 .62566 L .50777 .62547 L F
.525 .017 0 r
.50777 .62547 m .50891 .62654 L .50796 .62558 L F
.50777 .62547 m .50796 .62558 L .50699 .62461 L F
.268 0 0 r
.44489 .707 m .44319 .70865 L .44107 .70901 L F
.222 0 0 r
.44568 .70807 m .44489 .707 L .44714 .70689 L F
.44568 .70807 m .44319 .70865 L .44489 .707 L F
.224 .729 .897 r
.4926 .61908 m .49604 .61925 L .49383 .61987 L F
.553 .466 .711 r
.7118 .48015 m .71413 .47966 L .71357 .476 L F
.234 .72 .928 r
.50168 .77799 m .50177 .77836 L .49832 .77796 L F
.724 .327 .297 r
.50177 .77836 m .50043 .78048 L .49832 .77796 L F
.688 .971 .767 r
.50168 .77799 m .50133 .77806 L .50177 .77836 L F
.575 .419 .632 r
.50133 .77806 m .50043 .78048 L .50177 .77836 L F
.337 .81 .906 r
.35596 .58796 m .35811 .58751 L .3596 .58765 L F
.394 .807 .978 r
.35811 .58751 m .3617 .58769 L .3596 .58765 L F
.25 .102 .476 r
.57749 .64345 m .57573 .64464 L .57602 .64206 L F
0 .557 .755 r
.57413 .64311 m .57749 .64345 L .57602 .64206 L F
.759 .79 .879 r
.69607 .48665 m .69189 .48729 L .69496 .486 L F
.716 .913 .962 r
.69607 .48665 m .69496 .486 L .69704 .4848 L F
.147 0 0 r
.46862 .63951 m .46951 .64044 L .47016 .63831 L F
.46862 .63951 m .46757 .64117 L .46951 .64044 L F
.347 .014 .252 r
.68365 .47423 m .68594 .47355 L .68636 .47201 L F
.439 .095 .284 r
.68636 .47201 m .68594 .47355 L .68895 .47166 L F
0 0 .367 r
.53752 .62185 m .53744 .61844 L .5374 .61937 L F
.509 .682 .944 r
.55123 .63885 m .55247 .63701 L .54967 .63655 L F
.55123 .63885 m .5534 .63854 L .55247 .63701 L F
.461 .171 .385 r
.59385 .55061 m .59632 .55011 L .59649 .54838 L F
.625 .309 .414 r
.59632 .55011 m .59888 .55023 L .59649 .54838 L F
.573 .334 .516 r
.59649 .54838 m .59888 .55023 L .59895 .548 L F
.766 .584 .651 r
.61964 .53626 m .62294 .53409 L .6197 .53383 L F
.61964 .53626 m .62279 .53655 L .62294 .53409 L F
.259 .463 .869 r
.53979 .62486 m .54042 .62343 L .53752 .62185 L F
.095 .259 .742 r
.53979 .62486 m .54172 .62673 L .54042 .62343 L F
.817 .536 .514 r
.74611 .52266 m .7438 .52423 L .74447 .52204 L F
.74611 .52266 m .74626 .52427 L .7438 .52423 L F
.583 .558 .792 r
.49849 .80426 m .49964 .80047 L .49922 .80186 L F
.49849 .80426 m .50115 .80422 L .49964 .80047 L F
.345 .058 .326 r
.28281 .59108 m .28447 .59211 L .28624 .59076 L F
.423 0 0 r
.28447 .59211 m .28854 .59065 L .28624 .59076 L F
.452 .164 .384 r
.37661 .62518 m .37605 .62703 L .37396 .62747 L F
.41 .125 .367 r
.37868 .62462 m .37605 .62703 L .37661 .62518 L F
.581 .377 .569 r
.44015 .67328 m .44044 .67582 L .43761 .67593 L F
.496 .316 .566 r
.44263 .67468 m .44015 .67328 L .443 .67283 L F
.44263 .67468 m .44044 .67582 L .44015 .67328 L F
.104 .416 .864 r
.53076 .61389 m .53091 .61272 L .5297 .61279 L F
.53076 .61389 m .53349 .61542 L .53091 .61272 L F
.658 .574 .75 r
.59142 .66138 m .59221 .66473 L .58876 .66374 L F
.132 0 0 r
.71357 .476 m .7155 .47575 L .7165 .47476 L F
.43 0 0 r
.7155 .47575 m .71902 .47559 L .7165 .47476 L F
.446 .089 .265 r
.7165 .47476 m .71902 .47559 L .71911 .47423 L F
.781 .958 .926 r
.72994 .51076 m .73335 .50937 L .73213 .50765 L F
.715 .696 .831 r
.73335 .50937 m .73546 .5082 L .73213 .50765 L F
.601 .718 .927 r
.6946 .49708 m .69794 .49807 L .69701 .49635 L F
.619 .693 .897 r
.69701 .49635 m .69794 .49807 L .70085 .49743 L F
.364 .093 .363 r
.44506 .67217 m .44562 .67042 L .44779 .66967 L F
.827 .651 .664 r
.64561 .4914 m .64369 .49383 L .64689 .49435 L F
.813 .675 .711 r
.64369 .49383 m .64668 .49577 L .64689 .49435 L F
.12 0 0 r
.5706 .56984 m .57353 .56773 L .57149 .56865 L F
.585 .406 .606 r
.50697 .6464 m .50462 .64441 L .50809 .64493 L F
.255 0 0 r
.50917 .64553 m .50809 .64493 L .51011 .64467 L F
.50917 .64553 m .50697 .6464 L .50809 .64493 L F
.529 .845 .542 r
.75605 .50965 m .75415 .51151 L .75563 .50998 L F
.621 .954 .92 r
.75563 .50998 m .75415 .51151 L .75356 .51117 L F
.289 .652 .969 r
.71455 .48464 m .71558 .48587 L .71326 .48542 L F
.882 .626 .546 r
.6082 .57884 m .60652 .57592 L .60776 .57684 L F
.713 .43 .495 r
.55259 .60801 m .55302 .6102 L .54979 .60965 L F
.462 .469 .779 r
.27155 .60736 m .27296 .61082 L .27456 .61012 L F
.578 .468 .692 r
.2726 .61296 m .27456 .61012 L .27296 .61082 L F
.107 0 .274 r
.71394 .46431 m .71363 .46303 L .71068 .46231 L F
.295 0 0 r
.31112 .64735 m .31222 .64785 L .30894 .6464 L F
.539 .763 .98 r
.377 .58941 m .37488 .58986 L .37325 .58857 L F
.516 .916 .872 r
.65698 .49271 m .65502 .49368 L .65676 .49318 L F
0 .136 .682 r
.65698 .49271 m .65676 .49318 L .65502 .49368 L F
.65698 .49271 m .65946 .49674 L .65676 .49318 L F
.599 .388 .567 r
.7584 .50573 m .75884 .50794 L .75634 .50846 L F
.504 .416 .689 r
.76075 .50157 m .76058 .50631 L .7584 .50573 L F
.189 .309 .757 r
.5814 .63488 m .58246 .63821 L .58015 .63627 L F
.48 0 0 r
.67447 .4851 m .67354 .48571 L .67119 .48537 L F
.783 .522 .542 r
.67727 .48504 m .67354 .48571 L .67447 .4851 L F
.499 .789 .997 r
.50891 .62654 m .51129 .62621 L .51031 .62754 L F
.145 .289 .753 r
.51129 .62621 m .51256 .62959 L .51031 .62754 L F
.803 .807 .854 r
.67159 .51612 m .67486 .5158 L .67401 .51357 L F
.806 .805 .85 r
.67401 .51357 m .67486 .5158 L .67698 .51348 L F
.426 .333 .647 r
.59414 .63567 m .59224 .63974 L .59185 .63613 L F
.59414 .63567 m .5943 .63776 L .59224 .63974 L F
.392 .336 .675 r
.5943 .63776 m .59317 .64176 L .59224 .63974 L F
.335 .341 .718 r
.59317 .64176 m .59549 .64388 L .59394 .64538 L F
.479 .576 .875 r
.59549 .64388 m .59613 .64565 L .59394 .64538 L F
.594 .384 .565 r
.60223 .54772 m .6045 .54527 L .6021 .54547 L F
.553 0 0 r
.52273 .63606 m .52674 .63837 L .52406 .63721 L F
.466 .133 .316 r
.43629 .65871 m .43861 .65835 L .43949 .65601 L F
.424 .082 .279 r
.43861 .65835 m .44175 .65567 L .43949 .65601 L F
.582 .232 .34 r
.50781 .69919 m .50988 .70067 L .51093 .69826 L F
.624 .276 .359 r
.51093 .69826 m .51285 .70038 L .51333 .69824 L F
.51093 .69826 m .50988 .70067 L .51285 .70038 L F
.607 .197 .239 r
.48546 .70297 m .4847 .70328 L .48462 .70257 L F
.722 .779 .898 r
.68743 .49129 m .68409 .49092 L .68634 .48979 L F
.78 .684 .757 r
.68743 .49129 m .68524 .49428 L .68409 .49092 L F
.789 .799 .861 r
.69009 .48902 m .68743 .49129 L .68634 .48979 L F
.747 .637 .738 r
.68524 .49428 m .68304 .49728 L .68185 .49393 L F
.997 .859 .551 r
.60853 .58205 m .6073 .58406 L .60765 .58119 L F
.60853 .58205 m .60808 .58508 L .6073 .58406 L F
.519 .18 .332 r
.59 .67019 m .58742 .67183 L .5876 .67047 L F
.468 .83 .994 r
.5789 .63059 m .58119 .63012 L .57812 .62989 L F
.5789 .63059 m .58119 .63012 L .57812 .62989 L F
.62 .464 .649 r
.57887 .63332 m .58119 .63012 L .5789 .63059 L F
.638 .373 .501 r
.59434 .56527 m .59645 .56734 L .59463 .56729 L F
.66 .369 .468 r
.59876 .56538 m .59645 .56734 L .59434 .56527 L F
.545 .309 .509 r
.59434 .56527 m .59463 .56729 L .59204 .56844 L F
.359 0 0 r
.57417 .62448 m .57603 .62454 L .57737 .62419 L F
.601 .305 .439 r
.57603 .62454 m .57985 .62198 L .57737 .62419 L F
.97 .8 .616 r
.55374 .76054 m .55601 .75823 L .55318 .75768 L F
.55374 .76054 m .55506 .76133 L .55601 .75823 L F
.508 .167 .324 r
.68276 .48292 m .68202 .48496 L .67949 .48528 L F
.507 .166 .324 r
.68541 .48425 m .68276 .48292 L .68542 .48285 L F
.68541 .48425 m .68202 .48496 L .68276 .48292 L F
.741 .663 .774 r
.68409 .49092 m .68524 .49428 L .68185 .49393 L F
.56 .474 .714 r
.27155 .60736 m .27338 .60443 L .27156 .60502 L F
.672 .334 .394 r
.57945 .67314 m .57812 .67551 L .57593 .6734 L F
.628 .284 .369 r
.58168 .67497 m .57812 .67551 L .57945 .67314 L F
.624 .286 .378 r
.58203 .67332 m .58168 .67497 L .57945 .67314 L F
.457 .324 .611 r
.27332 .60199 m .27517 .5989 L .27313 .59955 L F
.984 .889 .645 r
.57004 .59078 m .56856 .59169 L .56944 .59267 L F
.728 .972 .724 r
.57134 .58869 m .56856 .59169 L .57004 .59078 L F
.505 .148 .295 r
.51574 .69818 m .51826 .69836 L .51905 .69568 L F
.36 .019 .244 r
.51905 .69568 m .52039 .69748 L .52067 .69585 L F
.51905 .69568 m .51826 .69836 L .52039 .69748 L F
.557 .748 .966 r
.68994 .4814 m .68873 .48346 L .68783 .48224 L F
.209 0 0 r
.68873 .48346 m .69154 .48305 L .69101 .4829 L F
.69101 .4829 m .69154 .48305 L .68873 .48346 L F
.151 0 .209 r
.69336 .48168 m .69154 .48305 L .69101 .4829 L F
.69101 .4829 m .69154 .48305 L .69336 .48168 L F
.69101 .4829 m .69154 .48305 L .69336 .48168 L F
.557 .748 .966 r
.68994 .4814 m .69154 .48305 L .68873 .48346 L F
.68994 .4814 m .68873 .48346 L .68783 .48224 L F
.68994 .4814 m .69154 .48305 L .68873 .48346 L F
.448 .846 .977 r
.4246 .65565 m .42526 .65465 L .42688 .65532 L F
.4246 .65565 m .42304 .65516 L .42526 .65465 L F
.518 .301 .524 r
.42688 .65532 m .42435 .65843 L .4246 .65565 L F
.772 .696 .779 r
.28083 .63866 m .28256 .64221 L .28452 .63895 L F
.468 .214 .445 r
.28207 .64455 m .2849 .64182 L .28256 .64221 L F
.486 .754 .989 r
.3848 .59025 m .384 .59164 L .38257 .5904 L F
.3848 .59025 m .38615 .59134 L .384 .59164 L F
0 .078 .609 r
.73312 .52626 m .73418 .52689 L .73238 .52441 L F
.73312 .52626 m .73483 .52785 L .73418 .52689 L F
0 0 0 r
.4838 .64349 m .48291 .64426 L .48172 .64493 L F
.77 .972 .689 r
.48291 .64426 m .48121 .64729 L .48172 .64493 L F
.554 .325 .522 r
.38606 .62093 m .38399 .61923 L .38627 .61882 L F
.38606 .62093 m .38387 .62136 L .38399 .61923 L F
.762 .554 .616 r
.71517 .483 m .71887 .48574 L .7182 .48496 L F
.71517 .483 m .71558 .48587 L .71887 .48574 L F
.56 .867 .996 r
.71887 .48574 m .71558 .48587 L .7182 .48496 L F
.857 .627 .589 r
.56694 .63477 m .57109 .63334 L .56782 .63295 L F
.56694 .63477 m .57143 .6361 L .57109 .63334 L F
.757 .735 .832 r
.47771 .64883 m .48155 .64949 L .47904 .64765 L F
.59 .423 .623 r
.47904 .64765 m .48155 .64949 L .48121 .64729 L F
.757 .735 .832 r
.47771 .64883 m .47904 .64765 L .48121 .64729 L F
.145 0 .025 r
.63824 .49401 m .6399 .49339 L .64161 .49142 L F
.788 .957 .634 r
.64161 .49142 m .64061 .49273 L .64217 .49147 L F
.64161 .49142 m .6399 .49339 L .64061 .49273 L F
.414 .447 .786 r
.71517 .483 m .71618 .47938 L .71413 .47966 L F
.71517 .483 m .71749 .48205 L .71618 .47938 L F
0 0 .07 r
.71917 .48076 m .71876 .48125 L .71749 .48205 L F
.4 .406 .751 r
.71557 .48326 m .7182 .48496 L .71749 .48205 L F
0 0 .07 r
.71876 .48125 m .71677 .48357 L .71749 .48205 L F
.4 .406 .751 r
.71517 .483 m .71557 .48326 L .71749 .48205 L F
0 .525 .814 r
.32569 .58367 m .32775 .58411 L .32935 .5847 L F
.373 .739 .99 r
.32989 .58369 m .32935 .5847 L .32775 .58411 L F
.32989 .58369 m .33139 .58463 L .32935 .5847 L F
.404 .216 .509 r
.61345 .60712 m .61181 .61018 L .61254 .6078 L F
.659 .521 .684 r
.59388 .63096 m .59408 .63328 L .59164 .63397 L F
.66 .526 .69 r
.59164 .63397 m .59408 .63328 L .59185 .63613 L F
.437 .116 .323 r
.32548 .60336 m .32353 .60241 L .32701 .60192 L F
.189 0 0 r
.32758 .60283 m .32701 .60192 L .32872 .60154 L F
.32758 .60283 m .32548 .60336 L .32701 .60192 L F
.989 .873 .624 r
.65098 .49733 m .65119 .49282 L .65266 .49425 L F
.702 .27 .22 r
.56356 .6185 m .56062 .61656 L .56352 .61596 L F
.56356 .6185 m .56011 .61818 L .56062 .61656 L F
.506 .358 .615 r
.43974 .67817 m .43761 .67593 L .44044 .67582 L F
.43974 .67817 m .438 .6787 L .43761 .67593 L F
.67 .709 .877 r
.29607 .64064 m .3015 .64195 L .29812 .63845 L F
.382 .584 .922 r
.29812 .63845 m .3015 .64195 L .30218 .64112 L F
.51 .522 .804 r
.41075 .68761 m .41341 .69011 L .41363 .68955 L F
.483 .504 .804 r
.41075 .68761 m .41363 .68955 L .41264 .68725 L F
0 0 0 r
.37193 .60696 m .37331 .6064 L .37499 .60493 L F
.587 .539 .768 r
.37401 .60156 m .37499 .60493 L .37723 .6044 L F
.505 .022 .042 r
.37499 .60493 m .37652 .60625 L .37723 .6044 L F
.37499 .60493 m .37331 .6064 L .37652 .60625 L F
.66 .214 .181 r
.49738 .70472 m .49597 .70626 L .49346 .70447 L F
.502 .032 .071 r
.49973 .70573 m .49597 .70626 L .49738 .70472 L F
.496 .11 .239 r
.4996 .70462 m .49973 .70573 L .49738 .70472 L F
.813 .675 .711 r
.64369 .49383 m .64335 .4962 L .64668 .49577 L F
.81 .648 .682 r
.64335 .4962 m .64482 .49958 L .64668 .49577 L F
.09 0 .444 r
.43868 .68638 m .43792 .68407 L .4392 .68417 L F
.43868 .68638 m .43731 .68742 L .43792 .68407 L F
.592 .502 .721 r
.54862 .61654 m .54633 .61695 L .54551 .61287 L F
0 0 .092 r
.65387 .4857 m .65551 .48453 L .65575 .48268 L F
0 0 0 r
.65575 .48268 m .65762 .4818 L .65843 .48082 L F
.153 0 .15 r
.65575 .48268 m .65735 .48352 L .65762 .4818 L F
.65575 .48268 m .65551 .48453 L .65735 .48352 L F
.494 .186 .373 r
.28021 .59319 m .28245 .59288 L .28281 .59108 L F
.345 .058 .326 r
.28281 .59108 m .28245 .59288 L .28447 .59211 L F
.907 .842 .769 r
.54791 .63619 m .5463 .63538 L .54703 .63374 L F
.535 .831 .999 r
.54858 .63489 m .5463 .63538 L .54791 .63619 L F
.215 .439 .862 r
.54791 .63619 m .54967 .63655 L .54858 .63489 L F
.535 .831 .999 r
.54858 .63489 m .5463 .63538 L .54791 .63619 L F
.493 .324 .58 r
.40134 .60471 m .40133 .60718 L .39924 .60774 L F
.513 .249 .452 r
.40133 .60718 m .39876 .6096 L .39924 .60774 L F
.477 .518 .821 r
.27887 .63868 m .27943 .63534 L .27791 .63525 L F
.27887 .63868 m .28083 .63866 L .27943 .63534 L F
.695 .259 .211 r
.5026 .70586 m .4996 .70462 L .50305 .70506 L F
.479 .282 .533 r
.54783 .61039 m .54758 .6127 L .54551 .61287 L F
.592 .502 .721 r
.54862 .61654 m .54551 .61287 L .54758 .6127 L F
0 .436 .838 r
.50054 .62042 m .49921 .6204 L .49819 .61905 L F
.50054 .62042 m .5018 .62142 L .49921 .6204 L F
.651 .82 .964 r
.6516 .50564 m .65549 .5059 L .65396 .5059 L F
.711 .959 .947 r
.65697 .50331 m .65549 .5059 L .65819 .50406 L F
.738 .987 .895 r
.65396 .5059 m .65549 .5059 L .65697 .50331 L F
.346 .134 .443 r
.55039 .77546 m .55105 .77267 L .54847 .77602 L F
.54847 .77602 m .55105 .77267 L .55039 .77546 L F
.55039 .77546 m .54847 .77602 L .5471 .77495 L F
.467 .791 .999 r
.5471 .77495 m .55039 .77546 L .54847 .77602 L F
.671 .841 .965 r
.72414 .51103 m .72737 .51126 L .72708 .51001 L F
.466 .696 .967 r
.72708 .51001 m .72737 .51126 L .72918 .50978 L F
.522 .811 .998 r
.72737 .51126 m .72994 .51076 L .72918 .50978 L F
.279 0 0 r
.42728 .66288 m .426 .66229 L .42434 .66284 L F
.213 0 0 r
.42728 .66288 m .42814 .66183 L .426 .66229 L F
.324 0 .105 r
.34911 .62651 m .3511 .62611 L .34971 .62533 L F
.327 0 .096 r
.34971 .62533 m .3511 .62611 L .35189 .62484 L F
.555 0 0 r
.53757 .64396 m .5396 .64503 L .5405 .64504 L F
.302 .657 .971 r
.5421 .64436 m .5405 .64504 L .5396 .64503 L F
.5421 .64436 m .54321 .64533 L .5405 .64504 L F
.343 0 0 r
.75091 .50363 m .74939 .50264 L .74917 .50548 L F
.75091 .50363 m .75219 .50215 L .74939 .50264 L F
0 0 .316 r
.49378 .70153 m .49468 .70303 L .49698 .70251 L F
.575 .166 .229 r
.49468 .70303 m .49577 .70273 L .49698 .70251 L F
.49577 .70273 m .49834 .70201 L .49698 .70251 L F
.456 0 0 r
.49714 .70248 m .49698 .70251 L .49718 .70249 L F
.49378 .70153 m .49698 .70251 L .49714 .70248 L F
0 0 0 r
.49698 .70251 m .49954 .70138 L .49718 .70249 L F
.111 0 .092 r
.56614 .5734 m .56802 .57283 L .56876 .57091 L F
.372 .064 .307 r
.56802 .57283 m .5706 .56984 L .56876 .57091 L F
.386 .089 .334 r
.4728 .65943 m .47203 .6614 L .4701 .6619 L F
.9 .649 .549 r
.47261 .66033 m .4728 .65943 L .47521 .65825 L F
.47261 .66033 m .47203 .6614 L .4728 .65943 L F
0 .195 .711 r
.51104 .64724 m .51173 .6464 L .51011 .64467 L F
0 0 0 r
.51104 .64724 m .51029 .64918 L .51173 .6464 L F
0 .12 .671 r
.75262 .48199 m .75413 .48505 L .75296 .48342 L F
.643 .301 .378 r
.5346 .69885 m .53674 .70074 L .53439 .70053 L F
.497 .331 .586 r
.53672 .69825 m .53674 .70074 L .5346 .69885 L F
.887 .811 .768 r
.7292 .49408 m .72604 .49591 L .7282 .49304 L F
.7292 .49408 m .72746 .49711 L .72604 .49591 L F
.949 .689 .508 r
.40394 .60215 m .40563 .59973 L .40613 .60117 L F
.40394 .60215 m .40247 .59958 L .40563 .59973 L F
.49 .275 .514 r
.40613 .60117 m .40345 .60409 L .40394 .60215 L F
.426 .166 .414 r
.56549 .57554 m .56802 .57283 L .56614 .5734 L F
.633 .677 .874 r
.7097 .49822 m .71365 .4995 L .71121 .49558 L F
.501 .604 .888 r
.71365 .4995 m .71346 .4952 L .71121 .49558 L F
.71365 .4995 m .71562 .49914 L .71346 .4952 L F
.414 .788 .993 r
.71561 .49946 m .71562 .49914 L .71365 .4995 L F
.394 .167 .447 r
.31158 .61337 m .31116 .61503 L .30941 .61547 L F
.572 .434 .655 r
.31179 .6187 m .30941 .61547 L .31116 .61503 L F
.31179 .6187 m .30977 .61944 L .30941 .61547 L F
.804 .601 .628 r
.49025 .7039 m .49378 .70153 L .49018 .70122 L F
.756 .358 .298 r
.4915 .70324 m .49346 .70447 L .49025 .7039 L F
.804 .601 .628 r
.49025 .7039 m .49346 .70447 L .49378 .70153 L F
0 0 .316 r
.49378 .70153 m .49346 .70447 L .49468 .70303 L F
0 0 .472 r
.72869 .51691 m .72938 .5189 L .72988 .51789 L F
.403 .406 .749 r
.27746 .61897 m .27817 .61514 L .2759 .61578 L F
.27746 .61897 m .27935 .61882 L .27817 .61514 L F
.717 .628 .757 r
.68185 .49393 m .68381 .49561 L .68409 .49092 L F
.279 0 0 r
.68185 .49393 m .68385 .49448 L .68371 .49552 L F
.623 .301 .404 r
.68089 .495 m .68311 .49548 L .68385 .49448 L F
.77 .924 .556 r
.68385 .49448 m .68311 .49548 L .68388 .49422 L F
0 0 .459 r
.68409 .49092 m .68381 .49561 L .68549 .49161 L F
.77 .924 .556 r
.68385 .49448 m .68388 .49422 L .68549 .49161 L F
.279 0 0 r
.68371 .49552 m .68385 .49448 L .68381 .49561 L F
.77 .924 .556 r
.68385 .49448 m .68549 .49161 L .68381 .49561 L F
.181 0 .019 r
.59082 .55316 m .59385 .55061 L .59093 .55134 L F
.466 .19 .411 r
.58847 .55364 m .59082 .55316 L .59093 .55134 L F
.762 .931 .942 r
.53192 .754 m .52955 .7554 L .53129 .75404 L F
.358 .124 .417 r
.52955 .7554 m .53024 .75634 L .53129 .75404 L F
.464 .403 .704 r
.45472 .66618 m .45298 .66931 L .4535 .66744 L F
.274 0 0 r
.55158 .75716 m .55318 .75768 L .55212 .75727 L F
.55158 .75716 m .55318 .75768 L .55212 .75727 L F
.452 .789 .999 r
.32502 .62782 m .32369 .62836 L .32392 .62792 L F
.435 .73 .988 r
.32677 .6289 m .32369 .62836 L .32502 .62782 L F
0 .357 .814 r
.5475 .65065 m .55149 .653 L .55121 .65336 L F
.544 .842 .521 r
.55121 .65336 m .55149 .653 L .55277 .65163 L F
.355 .463 .833 r
.55277 .65163 m .55408 .65496 L .55121 .65336 L F
.733 .705 .824 r
.27441 .64815 m .27547 .65079 L .27176 .65007 L F
.124 .64 .89 r
.27547 .65079 m .27408 .65025 L .27176 .65007 L F
.547 .604 .862 r
.2762 .64798 m .27547 .65079 L .27441 .64815 L F
.2762 .64798 m .27749 .65032 L .27547 .65079 L F
.868 .929 .863 r
.2762 .64798 m .27547 .65079 L .27749 .65032 L F
.2762 .64798 m .27408 .65025 L .27547 .65079 L F
.394 .014 .195 r
.29077 .59033 m .29302 .58996 L .29429 .58773 L F
.258 0 .12 r
.29429 .58773 m .29501 .58926 L .29656 .58768 L F
.29429 .58773 m .29302 .58996 L .29501 .58926 L F
.794 .943 .923 r
.49278 .79145 m .48926 .79252 L .4916 .79087 L F
0 0 0 r
.49115 .79453 m .49094 .79473 L .49278 .79145 L F
.853 .763 .762 r
.49278 .79145 m .49094 .79473 L .48926 .79252 L F
.757 .523 .578 r
.49512 .79168 m .49115 .79453 L .49278 .79145 L F
.723 .73 .856 r
.7456 .52574 m .74247 .52791 L .74185 .52508 L F
.133 .373 .83 r
.56003 .65034 m .56065 .64903 L .558 .64723 L F
0 .047 .595 r
.56003 .65034 m .56141 .65238 L .56065 .64903 L F
.661 .62 .797 r
.59094 .65892 m .58681 .65561 L .59023 .65554 L F
0 0 .285 r
.5922 .6548 m .59094 .65892 L .59023 .65554 L F
.5922 .6548 m .59221 .65607 L .59121 .65801 L F
.526 .265 .462 r
.5946 .65411 m .5922 .6548 L .59551 .65559 L F
.5946 .65411 m .59426 .65459 L .5922 .6548 L F
.59426 .65459 m .59223 .65747 L .5922 .6548 L F
.53 .732 .967 r
.594 .65462 m .59551 .65559 L .59385 .65519 L F
.868 .727 .705 r
.59405 .65442 m .5946 .65411 L .59412 .65415 L F
.59405 .65442 m .59412 .65415 L .59408 .65416 L F
.59402 .65443 m .59405 .65442 L .59408 .65416 L F
.53 .732 .967 r
.59339 .65393 m .59385 .65519 L .5922 .6548 L F
.59429 .65327 m .59408 .65416 L .59339 .65393 L F
.59408 .65416 m .59385 .65519 L .59339 .65393 L F
.59436 .65322 m .59385 .65519 L .59429 .65327 L F
0 0 .285 r
.59221 .65607 m .59223 .65747 L .59121 .65801 L F
.868 .727 .705 r
.5911 .65606 m .59223 .65747 L .59426 .65459 L F
.59402 .65443 m .59426 .65459 L .5946 .65411 L F
.53 .732 .967 r
.59404 .65445 m .59426 .65459 L .594 .65462 L F
.868 .727 .705 r
.5911 .65606 m .59426 .65459 L .59402 .65443 L F
.53 .732 .967 r
.59499 .65452 m .59551 .65559 L .594 .65462 L F
.868 .727 .705 r
.59267 .65519 m .59402 .65443 L .59316 .65423 L F
.59402 .65443 m .59408 .65416 L .59316 .65423 L F
.498 .249 .468 r
.59532 .65417 m .5946 .65411 L .59551 .65559 L F
.156 .132 .577 r
.59584 .6545 m .59551 .65559 L .59499 .65451 L F
.59505 .65445 m .59499 .65451 L .59495 .65444 L F
.59584 .6545 m .59499 .65451 L .59505 .65445 L F
.59663 .65186 m .59687 .6543 L .59551 .65559 L F
.498 .249 .468 r
.59687 .6543 m .59532 .65417 L .59551 .65559 L F
.59687 .6543 m .59735 .65613 L .59505 .65445 L F
.59532 .65417 m .59505 .65445 L .5946 .65411 L F
.156 .132 .577 r
.59663 .65186 m .59584 .6545 L .5953 .65403 L F
.498 .249 .468 r
.59687 .6543 m .59505 .65445 L .59532 .65417 L F
.156 .132 .577 r
.59512 .65276 m .5953 .65403 L .59436 .65322 L F
.59663 .65186 m .5953 .65403 L .59512 .65276 L F
.59584 .6545 m .59495 .65444 L .59436 .65322 L F
.731 .428 .467 r
.59451 .65441 m .5929 .65425 L .59408 .65416 L F
.59735 .65613 m .59306 .65432 L .59451 .65441 L F
.59306 .65432 m .5929 .65425 L .59451 .65441 L F
.59511 .65449 m .59408 .65416 L .5946 .65411 L F
.59735 .65613 m .59408 .65416 L .59511 .65449 L F
.53 .732 .967 r
.59436 .65322 m .59499 .65452 L .59426 .65459 L F
.59436 .65322 m .59426 .65459 L .59404 .65445 L F
.868 .727 .705 r
.5911 .65606 m .59267 .65519 L .5929 .65425 L F
.59267 .65519 m .59316 .65423 L .5929 .65425 L F
0 0 .285 r
.59121 .65801 m .59223 .65747 L .59094 .65892 L F
.177 .308 .76 r
.59223 .65747 m .59327 .66092 L .59094 .65892 L F
.424 .337 .653 r
.59094 .65892 m .59327 .66092 L .59142 .66138 L F
.576 .384 .585 r
.6045 .54527 m .60689 .54492 L .60683 .54245 L F
.603 .4 .579 r
.60689 .54492 m .60957 .54199 L .60683 .54245 L F
0 0 .122 r
.65342 .48794 m .65551 .48453 L .65387 .4857 L F
0 .346 .817 r
.3067 .64515 m .30665 .6442 L .30376 .64425 L F
.3067 .64515 m .30894 .6464 L .30665 .6442 L F
.946 .76 .619 r
.62339 .56964 m .62534 .56827 L .62373 .56725 L F
.62339 .56964 m .62491 .57073 L .62534 .56827 L F
.603 .461 .662 r
.59388 .63096 m .5965 .6329 L .59408 .63328 L F
.59388 .63096 m .59637 .63033 L .5965 .6329 L F
.435 .126 .342 r
.38164 .62186 m .38085 .62417 L .37868 .62462 L F
.426 .119 .338 r
.38301 .62369 m .38164 .62186 L .38387 .62136 L F
.38301 .62369 m .38085 .62417 L .38164 .62186 L F
0 .364 .71 r
.40114 .59897 m .40048 .5988 L .399 .59894 L F
.40114 .59897 m .40247 .59958 L .40048 .5988 L F
.601 .305 .439 r
.57603 .62454 m .57992 .6238 L .57985 .62198 L F
.391 .166 .449 r
.57985 .62198 m .5821 .62136 L .58218 .61909 L F
.622 .464 .647 r
.57992 .6238 m .5821 .62136 L .57985 .62198 L F
.518 .335 .572 r
.59408 .63328 m .59414 .63567 L .59185 .63613 L F
.563 .354 .556 r
.59035 .61623 m .59277 .61584 L .59285 .61347 L F
.597 .429 .625 r
.59277 .61584 m .59506 .61287 L .59285 .61347 L F
.843 .68 .68 r
.62205 .5473 m .62555 .54544 L .62222 .54472 L F
.62205 .5473 m .62499 .54782 L .62555 .54544 L F
.272 .712 .963 r
.34298 .58552 m .34668 .58626 L .34425 .58629 L F
.613 .1 .005 r
.66573 .4851 m .66444 .48622 L .66223 .48486 L F
.552 .061 .046 r
.66752 .48549 m .66444 .48622 L .66573 .4851 L F
0 0 .48 r
.57042 .64032 m .56934 .63933 L .57099 .63847 L F
.341 .749 .981 r
.3617 .58769 m .36381 .58759 L .3653 .58834 L F
.407 .777 .994 r
.36602 .58731 m .3653 .58834 L .36381 .58759 L F
.36602 .58731 m .36748 .58811 L .3653 .58834 L F
.654 .403 .527 r
.64061 .49273 m .64561 .4914 L .64217 .49147 L F
.64061 .49273 m .64369 .49383 L .64561 .4914 L F
.493 .351 .616 r
.41175 .67893 m .41379 .67847 L .41365 .67613 L F
.506 .396 .663 r
.4121 .68138 m .41379 .67847 L .41175 .67893 L F
0 0 0 r
.49698 .70251 m .49834 .70201 L .49954 .70138 L F
.359 0 0 r
.49834 .70201 m .50182 .70086 L .49954 .70138 L F
.574 .641 .879 r
.71561 .49946 m .71635 .50027 L .71766 .49651 L F
.86 .954 .871 r
.71766 .49651 m .71635 .50027 L .71984 .49592 L F
.48 .093 .228 r
.52635 .70125 m .52509 .70343 L .52273 .70356 L F
.474 .035 .124 r
.52888 .70169 m .52509 .70343 L .52635 .70125 L F
.392 .336 .675 r
.5943 .63776 m .59508 .64165 L .59317 .64176 L F
.393 .349 .69 r
.59508 .64165 m .59549 .64388 L .59317 .64176 L F
.912 .801 .724 r
.52048 .65345 m .51739 .65484 L .51625 .65289 L F
.52048 .65345 m .51946 .65594 L .51739 .65484 L F
.985 .789 .389 r
.51986 .6519 m .52021 .6552 L .52078 .65337 L F
.924 .947 .791 r
.51986 .6519 m .52078 .65337 L .52239 .65031 L F
.559 .826 .996 r
.51564 .78036 m .51686 .78132 L .51919 .78068 L F
0 0 .144 r
.60581 .59359 m .60627 .5943 L .60722 .59216 L F
.60581 .59359 m .60564 .59585 L .60627 .5943 L F
.015 0 .167 r
.69729 .46607 m .69661 .4679 L .69858 .46495 L F
.683 .597 .753 r
.75067 .50947 m .75093 .51216 L .75308 .50947 L F
.711 .506 .61 r
.61715 .5363 m .61964 .53626 L .6197 .53383 L F
.421 .137 .374 r
.27892 .62487 m .2808 .62523 L .28142 .62269 L F
.2808 .62523 m .28094 .62515 L .28142 .62269 L F
.382 .104 .362 r
.28142 .62269 m .28094 .62515 L .28282 .62389 L F
.719 .713 .843 r
.28094 .62515 m .2826 .62416 L .28282 .62389 L F
.382 .104 .362 r
.28094 .62515 m .28092 .62526 L .28282 .62389 L F
.719 .713 .843 r
.2808 .62523 m .28094 .62515 L .28078 .62522 L F
.27907 .62341 m .28045 .62544 L .28282 .62389 L F
.22 .508 .909 r
.27907 .62341 m .28092 .62526 L .2808 .62523 L F
.27907 .62341 m .2808 .62523 L .27892 .62487 L F
.719 .713 .843 r
.28078 .62522 m .28094 .62515 L .28282 .62389 L F
.28045 .62544 m .2808 .62523 L .28078 .62522 L F
.28045 .62544 m .28093 .62617 L .2826 .62416 L F
.421 .137 .374 r
.2808 .62523 m .28092 .62526 L .28094 .62515 L F
.616 .636 .847 r
.27935 .61882 m .28142 .62269 L .28304 .62159 L F
.382 .104 .362 r
.28142 .62269 m .28282 .62389 L .28304 .62159 L F
.493 .147 .309 r
.37556 .6286 m .37396 .62747 L .37605 .62703 L F
.37556 .6286 m .3729 .62992 L .37396 .62747 L F
.224 .415 .84 r
.54593 .64804 m .54857 .64949 L .5475 .65065 L F
.244 .447 .86 r
.54857 .64949 m .55149 .653 L .5475 .65065 L F
.677 .418 .523 r
.61459 .53684 m .61724 .53891 L .61715 .5363 L F
.61459 .53684 m .6148 .53907 L .61724 .53891 L F
.55 .325 .526 r
.4594 .67225 m .46035 .67005 L .45688 .67057 L F
.717 .841 .941 r
.74063 .53312 m .74347 .53315 L .74279 .53251 L F
.669 .918 .975 r
.74347 .53315 m .74437 .53152 L .74279 .53251 L F
.74347 .53315 m .74694 .53168 L .74437 .53152 L F
.646 .844 .976 r
.42988 .70934 m .4332 .70937 L .43201 .7094 L F
.45 .841 .981 r
.4332 .70937 m .43425 .70842 L .43201 .7094 L F
.4332 .70937 m .43564 .70889 L .43425 .70842 L F
.139 0 .212 r
.60847 .61655 m .60776 .61837 L .60638 .61887 L F
.507 .208 .393 r
.59729 .60998 m .59976 .60728 L .59754 .60797 L F
.502 .118 .244 r
.51504 .70482 m .51438 .70604 L .51243 .7061 L F
.368 0 .174 r
.51675 .70535 m .51504 .70482 L .51719 .7046 L F
.51675 .70535 m .51438 .70604 L .51504 .70482 L F
.209 0 0 r
.53308 .69577 m .53546 .69601 L .53708 .69588 L F
.606 .578 .796 r
.53845 .69645 m .53672 .69825 L .53708 .69588 L F
0 .563 .794 r
.53546 .69601 m .53845 .69645 L .53708 .69588 L F
.181 0 .019 r
.59082 .55316 m .59293 .5524 L .59385 .55061 L F
.605 .279 .391 r
.59293 .5524 m .59632 .55011 L .59385 .55061 L F
.358 .791 .968 r
.58726 .64244 m .58635 .64189 L .58366 .64223 L F
.48 .739 .984 r
.58726 .64244 m .58817 .64088 L .58635 .64189 L F
.58726 .64244 m .5889 .64207 L .58817 .64088 L F
.189 0 0 r
.65843 .48082 m .65965 .4813 L .66071 .48048 L F
.65843 .48082 m .65762 .4818 L .65965 .4813 L F
.574 .071 .022 r
.72338 .4681 m .72587 .46942 L .72692 .46817 L F
.876 .467 .242 r
.72587 .46942 m .72748 .47048 L .72692 .46817 L F
.521 .779 .991 r
.32796 .62782 m .32976 .62921 L .32677 .6289 L F
.538 .763 .98 r
.33018 .62716 m .32976 .62921 L .32796 .62782 L F
.33018 .62716 m .33212 .62891 L .32976 .62921 L F
.659 .331 .407 r
.54262 .65533 m .54254 .65582 L .53964 .65586 L F
.321 0 .119 r
.54512 .65485 m .54254 .65582 L .54262 .65533 L F
.531 .105 .176 r
.46467 .70425 m .46329 .70613 L .46101 .70599 L F
.565 .142 .198 r
.4667 .70577 m .46467 .70425 L .46685 .70472 L F
.4667 .70577 m .46329 .70613 L .46467 .70425 L F
.986 .764 .366 r
.60798 .5874 m .6073 .58406 L .60808 .58508 L F
.008 .129 .643 r
.56266 .65563 m .56323 .65918 L .56382 .65818 L F
0 0 .353 r
.56323 .65918 m .56383 .66021 L .56382 .65818 L F
.56323 .65918 m .56414 .66126 L .56383 .66021 L F
.166 .259 .716 r
.4933 .65204 m .49229 .65363 L .4906 .64968 L F
.14 .465 .89 r
.54218 .62805 m .54433 .62809 L .54172 .62673 L F
.54218 .62805 m .54518 .62957 L .54433 .62809 L F
.214 .472 .886 r
.75218 .48049 m .74994 .48077 L .74901 .47952 L F
.75218 .48049 m .75262 .48199 L .74994 .48077 L F
.408 .206 .49 r
.76041 .5184 m .75832 .51699 L .76053 .51633 L F
.76041 .5184 m .75834 .51947 L .75832 .51699 L F
.946 .923 .754 r
.69206 .47751 m .69447 .47586 L .69364 .47338 L F
.69206 .47751 m .69286 .47864 L .69447 .47586 L F
.567 .353 .55 r
.68135 .47666 m .68369 .47633 L .68365 .47423 L F
.446 .246 .515 r
.68369 .47633 m .68594 .47355 L .68365 .47423 L F
.24 0 0 r
.30087 .58673 m .30457 .58454 L .3025 .5852 L F
0 0 .426 r
.54708 .76171 m .54757 .75716 L .54955 .75845 L F
.54708 .76171 m .54814 .75958 L .54757 .75716 L F
.001 .207 .72 r
.54708 .76171 m .54912 .76253 L .54814 .75958 L F
.329 .784 .95 r
.48383 .64959 m .48457 .64929 L .48525 .64966 L F
.631 .931 .68 r
.48575 .64866 m .48525 .64966 L .48457 .64929 L F
.48575 .64866 m .48446 .65002 L .48525 .64966 L F
.673 .795 .939 r
.48932 .64905 m .48446 .65002 L .48575 .64866 L F
.596 .507 .724 r
.48373 .65157 m .48562 .64885 L .48457 .64929 L F
.48562 .64885 m .48575 .64866 L .48457 .64929 L F
.329 .784 .95 r
.48155 .64949 m .48457 .64929 L .48383 .64959 L F
.085 0 0 r
.33089 .64699 m .32991 .6473 L .3277 .64753 L F
.277 0 0 r
.33297 .64656 m .32991 .6473 L .33089 .64699 L F
.594 .384 .565 r
.60223 .54772 m .60452 .54759 L .6045 .54527 L F
.492 .303 .552 r
.6045 .54527 m .60679 .54695 L .60689 .54492 L F
.6045 .54527 m .60452 .54759 L .60679 .54695 L F
.439 .409 .729 r
.4121 .68138 m .41255 .68447 L .4147 .68362 L F
.518 .393 .649 r
.41264 .68725 m .4147 .68362 L .41255 .68447 L F
.91 .545 .328 r
.71886 .50811 m .72162 .51184 L .72037 .50986 L F
.618 .606 .817 r
.72162 .51184 m .72326 .51021 L .72037 .50986 L F
.72162 .51184 m .72414 .51103 L .72326 .51021 L F
0 0 .128 r
.43868 .68638 m .4372 .68977 L .43731 .68742 L F
.228 .028 .387 r
.60217 .60454 m .6043 .60382 L .60479 .60159 L F
.263 .112 .48 r
.60422 .60611 m .60217 .60454 L .60216 .60684 L F
.60422 .60611 m .6043 .60382 L .60217 .60454 L F
.326 .066 .358 r
.59976 .60728 m .60216 .60684 L .60217 .60454 L F
.449 .169 .395 r
.27517 .5989 m .27795 .59605 L .27567 .5963 L F
.892 .923 .835 r
.57129 .61944 m .56937 .62029 L .57056 .62171 L F
.57129 .61944 m .57007 .61882 L .56937 .62029 L F
.507 .208 .393 r
.59729 .60998 m .59978 .60956 L .59976 .60728 L F
.351 .137 .442 r
.60191 .60901 m .59976 .60728 L .59978 .60956 L F
.60191 .60901 m .60216 .60684 L .59976 .60728 L F
.77 .925 .558 r
.57509 .58527 m .57705 .58219 L .57583 .58348 L F
.247 .026 .369 r
.5791 .57921 m .57861 .58129 L .57705 .58219 L F
.008 0 0 r
.57861 .58129 m .57583 .58348 L .57705 .58219 L F
.56 .474 .714 r
.27155 .60736 m .27377 .60714 L .27338 .60443 L F
.462 .469 .779 r
.27155 .60736 m .27456 .61012 L .27377 .60714 L F
.444 .217 .474 r
.3957 .61236 m .39401 .61073 L .39602 .61043 L F
.3957 .61236 m .39364 .61297 L .39401 .61073 L F
.802 .55 .557 r
.60374 .56797 m .60041 .56744 L .60047 .56513 L F
.793 .541 .556 r
.60374 .56797 m .60051 .5699 L .60041 .56744 L F
.60374 .56797 m .60393 .57038 L .60051 .5699 L F
0 .064 .626 r
.65698 .51786 m .65782 .51919 L .65653 .51596 L F
.978 .918 .625 r
.4077 .70101 m .40629 .70159 L .40631 .7001 L F
.4077 .70101 m .40699 .70219 L .40629 .70159 L F
.59 .855 .994 r
.41052 .70028 m .4077 .70101 L .40631 .7001 L F
.475 .15 .335 r
.4077 .70101 m .40699 .70219 L .41052 .70028 L F
.41052 .70028 m .40699 .70219 L .4077 .70101 L F
.664 .578 .749 r
.59441 .6624 m .59221 .66473 L .59142 .66138 L F
.975 .797 .601 r
.73043 .48554 m .72886 .4865 L .72962 .48461 L F
.73043 .48554 m .73005 .48774 L .72886 .4865 L F
.967 .821 .646 r
.7304 .48086 m .73043 .48554 L .72962 .48461 L F
.326 .604 .948 r
.73928 .51851 m .73819 .51962 L .73752 .518 L F
.407 .731 .991 r
.74078 .51949 m .73819 .51962 L .73928 .51851 L F
.585 .508 .735 r
.74078 .51949 m .73918 .52199 L .73819 .51962 L F
.371 .757 .988 r
.33139 .58463 m .33353 .58448 L .33501 .5853 L F
.408 .742 .993 r
.33565 .58409 m .33501 .5853 L .33353 .58448 L F
.33565 .58409 m .33715 .5852 L .33501 .5853 L F
.632 .358 .485 r
.5821 .62136 m .58455 .62108 L .58218 .61909 L F
.609 .366 .523 r
.58218 .61909 m .58455 .62108 L .58448 .61895 L F
.464 .416 .719 r
.74027 .5218 m .73964 .52494 L .73918 .52199 L F
.74027 .5218 m .74185 .52508 L .73964 .52494 L F
.682 .731 .887 r
.73213 .50765 m .73546 .5082 L .73446 .50649 L F
.73 .751 .869 r
.73446 .50649 m .73546 .5082 L .73687 .50648 L F
.94 .949 .625 r
.56856 .59169 m .56749 .59587 L .56944 .59267 L F
.15 0 0 r
.46076 .64507 m .45786 .64705 L .45979 .64628 L F
.314 0 .231 r
.45979 .64628 m .46256 .6441 L .46076 .64507 L F
.532 .029 .005 r
.47049 .70461 m .46909 .70582 L .46685 .70472 L F
.409 0 0 r
.47288 .70483 m .46909 .70582 L .47049 .70461 L F
.34 .82 .816 r
.34679 .5996 m .34399 .60005 L .34304 .60046 L F
.229 .748 .763 r
.34734 .59926 m .34679 .5996 L .349 .59967 L F
.34734 .59926 m .34399 .60005 L .34679 .5996 L F
0 .057 .596 r
.57099 .6502 m .57366 .65301 L .57317 .6528 L F
0 0 0 r
.57328 .65461 m .57317 .6528 L .57366 .65301 L F
.444 0 0 r
.46593 .69926 m .46779 .70002 L .46928 .69887 L F
.317 0 0 r
.46779 .70002 m .47161 .69961 L .46928 .69887 L F
.714 .475 .562 r
.60047 .56513 m .59645 .56734 L .59876 .56538 L F
0 0 .152 r
.61841 .59857 m .61819 .60073 L .61655 .60178 L F
0 0 .147 r
.61655 .60178 m .61819 .60073 L .61639 .60392 L F
.437 .116 .323 r
.32548 .60336 m .32325 .60393 L .32353 .60241 L F
.422 .46 .794 r
.5534 .63854 m .55445 .64192 L .55642 .64072 L F
.408 .429 .771 r
.55445 .64192 m .55786 .64401 L .55642 .64072 L F
.76 .589 .664 r
.62739 .51641 m .62938 .51339 L .62744 .5137 L F
.59 .603 .833 r
.27622 .62673 m .28013 .62989 L .27839 .62699 L F
.792 .382 0 r
.27839 .62699 m .28013 .62989 L .27909 .62852 L F
.027 .223 .728 r
.28013 .62989 m .28047 .62813 L .27909 .62852 L F
.28013 .62989 m .28203 .63091 L .28047 .62813 L F
.499 0 0 r
.68895 .47166 m .69095 .47255 L .69193 .47137 L F
.239 0 0 r
.69193 .47137 m .69309 .47211 L .69338 .46973 L F
.69193 .47137 m .69095 .47255 L .69309 .47211 L F
.53 .298 .507 r
.35994 .61901 m .36222 .61865 L .36247 .61633 L F
.558 .382 .6 r
.36247 .61633 m .36476 .616 L .36476 .61317 L F
.48 .255 .494 r
.36247 .61633 m .36436 .61814 L .36476 .616 L F
.36247 .61633 m .36222 .61865 L .36436 .61814 L F
.678 .134 0 r
.53238 .63841 m .53595 .64119 L .53385 .64126 L F
.486 .647 .929 r
.66103 .50628 m .6624 .50407 L .65974 .50492 L F
.66103 .50628 m .66441 .50621 L .6624 .50407 L F
.778 .329 .182 r
.72671 .48257 m .72607 .48396 L .72766 .48399 L F
0 0 .131 r
.72812 .47878 m .72761 .48134 L .72671 .48257 L F
0 0 0 r
.72761 .48134 m .72607 .48396 L .72671 .48257 L F
.515 .886 .973 r
.49094 .79473 m .48658 .79529 L .48926 .79252 L F
.49094 .79473 m .48658 .79529 L .48883 .7948 L F
.152 .695 .785 r
.48883 .7948 m .49094 .79473 L .49115 .79453 L F
.651 .633 .819 r
.66345 .51694 m .66028 .51441 L .66229 .51352 L F
.766 .588 .657 r
.61964 .53626 m .62086 .53924 L .62279 .53655 L F
.499 .106 .226 r
.5043 .7013 m .50617 .70119 L .50781 .69919 L F
.596 .218 .296 r
.50781 .69919 m .50617 .70119 L .50988 .70067 L F
.18 0 0 r
.34115 .64367 m .3381 .64468 L .33908 .64402 L F
.714 .475 .562 r
.60047 .56513 m .60041 .56744 L .59645 .56734 L F
.989 .873 .624 r
.65098 .49733 m .65007 .49631 L .65119 .49282 L F
.959 .941 .711 r
.65098 .49733 m .64911 .49864 L .65007 .49631 L F
.84 .829 .837 r
.69203 .49709 m .6946 .49708 L .69349 .49584 L F
.634 .798 .961 r
.69349 .49584 m .6946 .49708 L .69701 .49635 L F
.521 .779 .991 r
.32796 .62782 m .32677 .6289 L .32502 .62782 L F
.694 .643 .794 r
.63787 .49628 m .6399 .49339 L .63824 .49401 L F
.382 .02 .221 r
.43393 .65901 m .43126 .66086 L .43346 .66057 L F
.571 .272 .422 r
.43346 .66057 m .43629 .65871 L .43393 .65901 L F
.937 .603 .166 r
.49119 .6384 m .49184 .63989 L .4917 .63865 L F
.49125 .63872 m .49184 .63989 L .49119 .6384 L F
.943 .773 .642 r
.49106 .63834 m .49025 .64059 L .49184 .63989 L F
.727 .469 .536 r
.49025 .64059 m .49294 .63898 L .49184 .63989 L F
.49294 .63898 m .49417 .63825 L .49274 .63925 L F
.49294 .63898 m .49274 .63925 L .49184 .63989 L F
.49294 .63898 m .49398 .64081 L .49417 .63825 L F
.49398 .64081 m .49399 .64083 L .494 .64079 L F
.49398 .64081 m .494 .64079 L .49417 .63825 L F
.49149 .63985 m .49314 .64054 L .49294 .63898 L F
.49314 .64054 m .49405 .64092 L .49294 .63898 L F
.49025 .64059 m .49168 .64072 L .49149 .63985 L F
.49168 .64072 m .49405 .64092 L .49149 .63985 L F
.927 .974 .724 r
.49282 .63517 m .4917 .63865 L .49417 .63825 L F
.731 .633 .749 r
.49345 .63709 m .49317 .64078 L .49025 .64059 L F
.49317 .64078 m .49312 .64151 L .49025 .64059 L F
.727 .469 .536 r
.49399 .64083 m .49405 .64084 L .49417 .63825 L F
.939 .568 .241 r
.49383 .6409 m .49177 .6433 L .49405 .64092 L F
0 0 .408 r
.49318 .64085 m .49312 .64151 L .49317 .64078 L F
.939 .568 .241 r
.49318 .64085 m .49316 .64144 L .49383 .6409 L F
0 0 .408 r
.49324 .6413 m .49316 .64144 L .49318 .64085 L F
.49316 .64144 m .49312 .64151 L .49318 .64085 L F
.283 0 0 r
.49312 .64151 m .49294 .6415 L .49025 .64059 L F
.939 .568 .241 r
.49294 .6415 m .49147 .64277 L .49304 .64153 L F
.49025 .64059 m .49055 .64112 L .49294 .6415 L F
.49055 .64112 m .49147 .64277 L .49294 .6415 L F
.49025 .64059 m .49095 .64311 L .49177 .6433 L F
.748 .701 .806 r
.48787 .64144 m .48704 .64187 L .48695 .64122 L F
0 .283 .729 r
.49008 .64427 m .48981 .64385 L .48585 .64142 L F
.48981 .64385 m .48838 .64283 L .48585 .64142 L F
0 .346 .823 r
.48585 .64142 m .48682 .64196 L .48695 .64122 L F
.48682 .64196 m .48959 .6435 L .48745 .64166 L F
.48682 .64196 m .48745 .64166 L .48695 .64122 L F
.31 .778 .657 r
.48584 .64252 m .48465 .64309 L .48737 .6417 L F
.774 .519 .55 r
.48745 .64166 m .48959 .6435 L .48913 .64102 L F
.047 0 0 r
.48794 .64144 m .48777 .6415 L .48787 .64144 L F
.774 .519 .55 r
.48777 .6415 m .48913 .64102 L .48909 .64081 L F
.48745 .64166 m .48913 .64102 L .48777 .6415 L F
.047 0 0 r
.48977 .64126 m .48584 .64252 L .48777 .6415 L F
.48977 .64126 m .48777 .6415 L .48794 .64144 L F
.353 .738 .986 r
.48695 .64122 m .48977 .64126 L .48794 .64144 L F
.48695 .64122 m .48794 .64144 L .48787 .64144 L F
.774 .519 .55 r
.48909 .64081 m .48926 .64172 L .49025 .64059 L F
.48926 .64172 m .48959 .6435 L .48996 .64187 L F
.48926 .64172 m .48996 .64187 L .49025 .64059 L F
.31 .778 .657 r
.48777 .6415 m .48737 .6417 L .48787 .64144 L F
.48745 .64166 m .48737 .6417 L .48777 .6415 L F
.774 .519 .55 r
.48695 .64122 m .48745 .64166 L .48909 .64081 L F
.31 .778 .657 r
.4875 .64164 m .48745 .64166 L .48777 .6415 L F
.48584 .64252 m .48737 .6417 L .4875 .64164 L F
.748 .701 .806 r
.48704 .64187 m .48465 .64309 L .48657 .64153 L F
.48704 .64187 m .48657 .64153 L .48695 .64122 L F
0 .283 .729 r
.48981 .64385 m .48959 .6435 L .48838 .64283 L F
.674 .419 .528 r
.4904 .64114 m .48959 .6435 L .49095 .64311 L F
.49025 .64059 m .49013 .64109 L .4904 .64114 L F
.49013 .64109 m .48959 .6435 L .4904 .64114 L F
.283 0 0 r
.49201 .64143 m .49127 .64168 L .48977 .64126 L F
.49294 .6415 m .4926 .64153 L .49201 .64143 L F
.4926 .64153 m .49127 .64168 L .49201 .64143 L F
.49312 .64151 m .49306 .64152 L .49294 .6415 L F
.49306 .64152 m .49127 .64168 L .49294 .6415 L F
.49294 .6415 m .48977 .64126 L .49025 .64059 L F
.939 .568 .241 r
.49025 .64059 m .49304 .64153 L .49316 .64144 L F
.49025 .64059 m .49316 .64144 L .49318 .64085 L F
.791 .679 .741 r
.49316 .64144 m .49306 .64152 L .49312 .64151 L F
.939 .568 .241 r
.49147 .64277 m .49177 .6433 L .49383 .6409 L F
.791 .679 .741 r
.49324 .6413 m .49289 .64153 L .49306 .64152 L F
.49324 .6413 m .49306 .64152 L .49316 .64144 L F
0 0 .408 r
.49439 .63934 m .49324 .6413 L .49335 .6384 L F
.49324 .6413 m .49317 .64078 L .49335 .6384 L F
.52 .296 .514 r
.49417 .63825 m .49405 .64092 L .49555 .63924 L F
.791 .679 .741 r
.49439 .63934 m .49127 .64168 L .49289 .64153 L F
.49439 .63934 m .49289 .64153 L .49324 .6413 L F
.727 .469 .536 r
.49399 .64083 m .49405 .64092 L .49405 .64084 L F
0 0 .408 r
.49376 .63783 m .49335 .6384 L .49345 .63709 L F
.49439 .63934 m .49335 .6384 L .49376 .63783 L F
.937 .603 .166 r
.49106 .63834 m .49125 .63872 L .49119 .6384 L F
.927 .974 .724 r
.49282 .63517 m .49106 .63834 L .4917 .63865 L F
.116 0 0 r
.35606 .59892 m .35514 .59938 L .3529 .59975 L F
.033 0 0 r
.35778 .59862 m .35514 .59938 L .35606 .59892 L F
.107 .389 .846 r
.27892 .62487 m .28093 .62617 L .27907 .62341 L F
.609 .352 .503 r
.27892 .62487 m .27839 .62699 L .28093 .62617 L F
.859 .796 .788 r
.49438 .66454 m .49184 .66433 L .49355 .6616 L F
.792 .375 .257 r
.49438 .66454 m .49213 .66561 L .49184 .66433 L F
.603 .648 .867 r
.49648 .66326 m .49438 .66454 L .49355 .6616 L F
0 0 0 r
.49562 .66435 m .49438 .66454 L .49648 .66326 L F
.49562 .66435 m .49213 .66561 L .49438 .66454 L F
0 .375 .801 r
.46237 .69688 m .46359 .69785 L .46175 .69654 L F
.558 .082 .08 r
.54862 .61654 m .55069 .61776 L .5518 .61639 L F
.633 .959 .916 r
.55448 .61501 m .5518 .61639 L .55297 .61497 L F
0 0 0 r
.5518 .61639 m .55069 .61776 L .55297 .61497 L F
.435 .126 .341 r
.39154 .61363 m .39096 .61545 L .38875 .61591 L F
.485 .172 .361 r
.39154 .61363 m .39324 .61508 L .39096 .61545 L F
.433 .183 .432 r
.39364 .61297 m .39324 .61508 L .39154 .61363 L F
.626 .604 .809 r
.6399 .49339 m .64335 .4962 L .64061 .49273 L F
.614 .489 .686 r
.64061 .49273 m .64335 .4962 L .64369 .49383 L F
.973 .664 .349 r
.50981 .77661 m .50858 .77473 L .50858 .7725 L F
.725 .419 .462 r
.50858 .7725 m .51255 .77486 L .51115 .77401 L F
.50858 .7725 m .50858 .77473 L .51255 .77486 L F
.473 .891 .8 r
.5494 .59084 m .55056 .58993 L .55084 .58952 L F
.5494 .59084 m .54738 .59144 L .55056 .58993 L F
.548 .327 .531 r
.59408 .63328 m .59642 .63518 L .59414 .63567 L F
.59408 .63328 m .5965 .6329 L .59642 .63518 L F
.56 .371 .582 r
.59041 .61868 m .59277 .61584 L .59035 .61623 L F
.956 .839 .688 r
.62301 .57836 m .62538 .57622 L .62419 .57534 L F
.62301 .57836 m .62422 .57927 L .62538 .57622 L F
.623 .112 .012 r
.53129 .75404 m .53411 .75523 L .53192 .754 L F
.853 .753 .752 r
.72746 .49711 m .7239 .49886 L .72604 .49591 L F
.72746 .49711 m .72564 .5003 L .7239 .49886 L F
.835 .786 .804 r
.63739 .50073 m .63665 .50245 L .63855 .50007 L F
.301 .053 .361 r
.63665 .50245 m .63799 .50208 L .63855 .50007 L F
.463 .316 .596 r
.63666 .50485 m .63799 .50208 L .63665 .50245 L F
.248 0 0 r
.3494 .64076 m .35263 .63901 L .35158 .64027 L F
.385 0 .079 r
.35158 .64027 m .35263 .63901 L .35531 .63827 L F
.917 .572 .368 r
.5304 .65557 m .52844 .65482 L .52801 .65601 L F
.792 .713 .777 r
.71915 .50488 m .71886 .50811 L .71698 .50753 L F
.71915 .50488 m .72043 .50589 L .71886 .50811 L F
0 0 .522 r
.71886 .50811 m .71917 .5083 L .71698 .50753 L F
.71886 .50811 m .72037 .50986 L .71917 .5083 L F
.717 .602 .727 r
.63787 .49628 m .63855 .50007 L .64118 .49704 L F
.417 .188 .457 r
.64118 .49704 m .63855 .50007 L .64144 .49894 L F
.525 .259 .454 r
.63855 .50007 m .64124 .50139 L .64144 .49894 L F
.63855 .50007 m .63799 .50208 L .64124 .50139 L F
.454 .76 .995 r
.2727 .62886 m .27469 .62883 L .2745 .62971 L F
.896 .692 .619 r
.2727 .62886 m .2745 .62971 L .27469 .62883 L F
.2727 .62886 m .27402 .63311 L .2745 .62971 L F
.499 .338 .593 r
.36476 .61317 m .3668 .61268 L .36681 .61029 L F
.518 .359 .604 r
.36476 .616 m .3668 .61268 L .36476 .61317 L F
.789 .799 .861 r
.69009 .48902 m .68634 .48979 L .68878 .48749 L F
.804 .817 .861 r
.69189 .48729 m .69009 .48902 L .68878 .48749 L F
.825 .926 .543 r
.56694 .59528 m .56574 .59666 L .56561 .59791 L F
0 0 0 r
.56561 .59791 m .56574 .59666 L .56573 .59679 L F
.918 .973 .689 r
.56749 .59587 m .56561 .59791 L .56553 .59867 L F
0 0 0 r
.56561 .59791 m .56573 .59679 L .56553 .59902 L F
.918 .973 .689 r
.56553 .59867 m .56561 .59791 L .56528 .59902 L F
.56749 .59587 m .56694 .59528 L .56561 .59791 L F
.94 .949 .625 r
.56856 .59169 m .56694 .59528 L .56749 .59587 L F
.633 .677 .874 r
.7097 .49822 m .71121 .49558 L .70872 .49643 L F
0 0 0 r
.52374 .77992 m .52283 .78118 L .52414 .7781 L F
.52374 .77992 m .52414 .7781 L .52146 .77793 L F
.779 .845 .901 r
.6759 .51231 m .67401 .51357 L .67698 .51348 L F
.863 .853 .831 r
.6759 .51231 m .67698 .51348 L .67919 .51076 L F
0 0 0 r
.69422 .46849 m .69547 .46847 L .69661 .4679 L F
.69422 .46849 m .69338 .46973 L .69547 .46847 L F
.391 .384 .732 r
.6604 .49618 m .65939 .49993 L .65946 .49674 L F
.6604 .49618 m .66174 .49852 L .65939 .49993 L F
.442 .492 .816 r
.66174 .49852 m .66169 .50018 L .65939 .49993 L F
.953 .618 .34 r
.4701 .6619 m .46941 .66248 L .46816 .65907 L F
.557 .864 .565 r
.47158 .66028 m .4701 .6619 L .47203 .6614 L F
.47158 .66028 m .46941 .66248 L .4701 .6619 L F
.478 .311 .577 r
.40338 .60662 m .40134 .60471 L .40345 .60409 L F
.40338 .60662 m .40133 .60718 L .40134 .60471 L F
.838 .506 0 r
.56414 .66126 m .56537 .66452 L .56467 .66315 L F
0 .265 .773 r
.56537 .66452 m .56623 .66411 L .56467 .66315 L F
.573 .009 0 r
.56889 .66696 m .56774 .66643 L .56537 .66452 L F
0 .265 .773 r
.56537 .66452 m .56774 .66643 L .56623 .66411 L F
.767 .711 .799 r
.28416 .63588 m .28083 .63866 L .28452 .63895 L F
.335 .27 .633 r
.28452 .63895 m .28632 .64074 L .28551 .63844 L F
.383 .275 .607 r
.28452 .63895 m .2849 .64182 L .28632 .64074 L F
.5 .162 .326 r
.444 .65522 m .44636 .65497 L .44744 .65237 L F
.399 .036 .228 r
.44636 .65497 m .44963 .65222 L .44744 .65237 L F
.407 .465 .808 r
.75089 .49869 m .75219 .50215 L .75335 .50157 L F
0 0 0 r
.75335 .50157 m .75219 .50215 L .75091 .50363 L F
.424 .865 .904 r
.31839 .647 m .31488 .64764 L .31642 .64819 L F
.311 .789 .706 r
.69804 .47202 m .69757 .47208 L .69471 .47328 L F
.773 .361 .268 r
.70048 .4713 m .69757 .47208 L .69804 .47202 L F
.573 .414 .628 r
.59506 .61287 m .59729 .60998 L .59501 .61052 L F
.397 .777 .992 r
.57249 .67278 m .57593 .6734 L .57468 .6725 L F
.606 .066 0 r
.57593 .6734 m .57637 .67431 L .57468 .6725 L F
.57593 .6734 m .57812 .67551 L .57637 .67431 L F
.119 0 0 r
.45842 .66212 m .45708 .66378 L .45534 .66438 L F
.472 .049 .155 r
.46023 .66309 m .45842 .66212 L .46025 .66119 L F
.46023 .66309 m .45708 .66378 L .45842 .66212 L F
.633 .504 .688 r
.75634 .50846 m .75884 .50794 L .75605 .50965 L F
.869 .839 .373 r
.75634 .50846 m .75605 .50965 L .75563 .50998 L F
.514 .198 .369 r
.58429 .67303 m .58168 .67497 L .58203 .67332 L F
0 0 0 r
.75308 .50947 m .75634 .50846 L .75563 .50998 L F
.019 0 0 r
.34336 .64326 m .34734 .64113 L .34551 .64273 L F
.242 0 0 r
.34734 .64113 m .34748 .64231 L .34551 .64273 L F
.34734 .64113 m .3494 .64076 L .34748 .64231 L F
.338 0 0 r
.47629 .70457 m .47505 .70542 L .47288 .70483 L F
.539 0 0 r
.4784 .70569 m .47505 .70542 L .47629 .70457 L F
.531 .145 .255 r
.47888 .7045 m .4784 .70569 L .47629 .70457 L F
.764 .683 .773 r
.55742 .6204 m .55985 .62208 L .55559 .62174 L F
0 .566 .781 r
.51919 .78068 m .52283 .78118 L .52208 .78097 L F
.632 .962 .89 r
.52208 .78097 m .52283 .78118 L .52374 .77992 L F
.547 .44 .684 r
.56626 .62704 m .56428 .62524 L .56478 .62565 L F
.56626 .62704 m .56846 .62678 L .56849 .62451 L F
.503 .588 .872 r
.41569 .68916 m .41363 .68955 L .41341 .69011 L F
.623 .419 .585 r
.41341 .69011 m .41646 .69234 L .41569 .68916 L F
.41341 .69011 m .41417 .69284 L .41646 .69234 L F
.796 .729 .79 r
.36019 .59799 m .3643 .59871 L .36382 .59827 L F
.586 .215 .304 r
.67814 .47843 m .68053 .47868 L .68135 .47666 L F
.478 .113 .267 r
.68053 .47868 m .68369 .47633 L .68135 .47666 L F
.021 0 .099 r
.58146 .57631 m .58095 .57833 L .5791 .57921 L F
.075 0 0 r
.58146 .57631 m .58437 .57408 L .58346 .57531 L F
.169 0 .149 r
.5828 .57736 m .58146 .57631 L .58346 .57531 L F
.5828 .57736 m .58095 .57833 L .58146 .57631 L F
.634 .072 0 r
.42077 .70494 m .41884 .70436 L .41543 .70225 L F
.702 .967 .732 r
.42163 .70358 m .42077 .70494 L .42264 .70303 L F
.61 .877 .991 r
.42163 .70358 m .41884 .70436 L .42077 .70494 L F
.411 0 .076 r
.45864 .69795 m .46175 .69654 L .45969 .69638 L F
.729 .6 .713 r
.54979 .60965 m .54758 .6127 L .54783 .61039 L F
.518 .215 .392 r
.58349 .55865 m .58586 .55844 L .58617 .55666 L F
.502 .201 .387 r
.58586 .55844 m .58817 .55808 L .58617 .55666 L F
.536 .349 .575 r
.58617 .55666 m .5886 .55612 L .58847 .55364 L F
.482 .21 .425 r
.58817 .55808 m .5886 .55612 L .58617 .55666 L F
.565 .586 .834 r
.63776 .50797 m .63873 .50438 L .63666 .50485 L F
.63776 .50797 m .64009 .5077 L .63873 .50438 L F
.531 .533 .802 r
.75977 .48777 m .75829 .49138 L .75732 .48808 L F
.75977 .48777 m .76061 .49083 L .75829 .49138 L F
.523 .491 .762 r
.76061 .49083 m .76133 .49297 L .75829 .49138 L F
.26 .724 .948 r
.55512 .76678 m .55412 .76619 L .55188 .76618 L F
.984 .892 .648 r
.55542 .76299 m .55412 .76619 L .55512 .76678 L F
0 0 0 r
.56528 .59902 m .56439 .60159 L .56414 .60231 L F
0 0 .08 r
.56561 .59791 m .56439 .60159 L .56528 .59902 L F
.193 0 0 r
.66071 .48048 m .66389 .48056 L .66414 .47995 L F
.717 .319 .295 r
.66389 .48056 m .66649 .47938 L .66414 .47995 L F
0 .414 .752 r
.73531 .47428 m .73393 .474 L .73279 .47329 L F
.73531 .47428 m .73638 .47478 L .73393 .474 L F
.338 0 .14 r
.45786 .64705 m .45896 .64865 L .45979 .64628 L F
.45786 .64705 m .45676 .64914 L .45896 .64865 L F
.358 .336 .697 r
.57148 .65544 m .5708 .65879 L .57027 .65838 L F
.568 .309 .483 r
.5708 .65879 m .57172 .66077 L .57027 .65838 L F
.84 .735 .748 r
.73687 .50648 m .73921 .504 L .73641 .5045 L F
0 0 .148 r
.58095 .57833 m .57861 .58129 L .5791 .57921 L F
.419 .791 .994 r
.37093 .58855 m .36748 .58811 L .3696 .5878 L F
.374 .715 .987 r
.37179 .58745 m .37093 .58855 L .3696 .5878 L F
.37179 .58745 m .37325 .58857 L .37093 .58855 L F
.743 .798 .897 r
.72121 .50174 m .72043 .50589 L .71915 .50488 L F
.72121 .50174 m .72245 .50518 L .72043 .50589 L F
.39 .021 .212 r
.443 .67283 m .44411 .67448 L .44263 .67468 L F
.443 .67283 m .44506 .67217 L .44411 .67448 L F
.573 .041 0 r
.56392 .62931 m .56432 .62942 L .56167 .6256 L F
.56392 .62931 m .56542 .63048 L .56432 .62942 L F
.863 .853 .831 r
.6759 .51231 m .67919 .51076 L .67853 .50984 L F
.614 .874 .99 r
.67938 .50856 m .67919 .51076 L .68216 .50822 L F
.67938 .50856 m .67853 .50984 L .67919 .51076 L F
.886 .86 .81 r
.72464 .50193 m .72245 .50518 L .72121 .50174 L F
.642 .769 .94 r
.66784 .49713 m .66439 .49639 L .66676 .49583 L F
.66439 .49639 m .66784 .49713 L .66676 .49583 L F
.528 .714 .957 r
.66913 .49526 m .66784 .49713 L .66676 .49583 L F
.66913 .49526 m .67027 .49685 L .66784 .49713 L F
.66784 .49713 m .66913 .49526 L .66676 .49583 L F
.66784 .49713 m .67027 .49685 L .66913 .49526 L F
.495 .263 .492 r
.59061 .55531 m .58847 .55364 L .5886 .55612 L F
.59061 .55531 m .59082 .55316 L .58847 .55364 L F
0 0 0 r
.74523 .48925 m .74334 .49092 L .74606 .48801 L F
.414 .414 .751 r
.74523 .48925 m .74642 .49203 L .74334 .49092 L F
.694 .643 .794 r
.63787 .49628 m .64118 .49704 L .6399 .49339 L F
.626 .604 .809 r
.6399 .49339 m .64118 .49704 L .64335 .4962 L F
.795 .642 .693 r
.64144 .49894 m .64335 .4962 L .64118 .49704 L F
.446 .743 .991 r
.38116 .58928 m .38045 .5906 L .37903 .58953 L F
.38116 .58928 m .38257 .5904 L .38045 .5906 L F
.35 0 0 r
.6783 .49458 m .68089 .495 L .68185 .49393 L F
.279 0 0 r
.68185 .49393 m .68089 .495 L .68385 .49448 L F
.311 .21 .575 r
.59589 .6627 m .59723 .66666 L .59503 .66669 L F
.276 0 .256 r
.59723 .66666 m .59463 .6691 L .59503 .66669 L F
.574 .422 .638 r
.41314 .67275 m .41555 .67242 L .41535 .66994 L F
.495 .365 .633 r
.41365 .67613 m .41555 .67242 L .41314 .67275 L F
.373 .086 .342 r
.58599 .57282 m .58346 .57531 L .58437 .57408 L F
.33 .093 .396 r
.50123 .65591 m .5007 .65828 L .49894 .65879 L F
.799 .574 .597 r
.49845 .66004 m .49894 .65879 L .49892 .66121 L F
.51 .373 .63 r
.5007 .65828 m .49892 .66121 L .49894 .65879 L F
.799 .574 .597 r
.49845 .66004 m .5007 .65828 L .49894 .65879 L F
.33 .093 .396 r
.49894 .65879 m .5007 .65828 L .50123 .65591 L F
.431 .742 .992 r
.55332 .77252 m .55168 .7715 L .55105 .77267 L F
.55105 .77267 m .55168 .7715 L .55332 .77252 L F
.113 0 0 r
.30665 .58385 m .30883 .58356 L .31052 .58275 L F
.268 0 0 r
.31052 .58275 m .30883 .58356 L .31217 .58311 L F
.644 .485 .653 r
.50455 .64689 m .50225 .64968 L .50241 .64745 L F
0 0 0 r
.46232 .67077 m .46138 .67284 L .46206 .67164 L F
.249 0 0 r
.46388 .67135 m .46232 .67077 L .46206 .67164 L F
.651 .659 .845 r
.37225 .59827 m .37401 .60156 L .37503 .59884 L F
.562 .559 .808 r
.37401 .60156 m .3761 .60111 L .37503 .59884 L F
.587 .539 .768 r
.37401 .60156 m .37723 .6044 L .3761 .60111 L F
.769 .641 .72 r
.70196 .48584 m .7015 .48839 L .70038 .48517 L F
.071 .632 .78 r
.3529 .59975 m .35077 .59961 L .349 .59967 L F
.322 .796 .918 r
.3529 .59975 m .35326 .59915 L .35077 .59961 L F
.3529 .59975 m .35514 .59938 L .35326 .59915 L F
.886 .918 .84 r
.67371 .49722 m .67603 .49408 L .67586 .4947 L F
.67371 .49722 m .67273 .49604 L .67603 .49408 L F
.538 .376 .609 r
.67371 .49722 m .67603 .49408 L .67273 .49604 L F
0 .49 .763 r
.67603 .49408 m .6783 .49458 L .67586 .4947 L F
.538 .376 .609 r
.67371 .49722 m .6762 .49689 L .67603 .49408 L F
.747 .284 .149 r
.53608 .65335 m .53809 .65556 L .53705 .65443 L F
.749 .236 0 r
.53964 .65586 m .53809 .65556 L .53608 .65335 L F
.936 .814 .699 r
.7239 .49886 m .72464 .50193 L .72311 .50117 L F
.886 .86 .81 r
.72464 .50193 m .72121 .50174 L .72311 .50117 L F
.822 .761 .794 r
.72564 .5003 m .72464 .50193 L .7239 .49886 L F
.393 .519 .865 r
.42673 .70678 m .42675 .70386 L .42499 .70344 L F
.42673 .70678 m .42828 .70649 L .42675 .70386 L F
.881 .898 .838 r
.52136 .64907 m .52239 .65031 L .524 .64863 L F
.438 0 0 r
.66649 .47938 m .66892 .47938 L .67023 .47873 L F
.482 0 .009 r
.67023 .47873 m .66892 .47938 L .67232 .47912 L F
.388 .681 .976 r
.25667 .64741 m .25873 .64754 L .25718 .64608 L F
.25718 .64608 m .25873 .64754 L .25667 .64741 L F
.271 .283 .689 r
.55688 .64488 m .55985 .64584 L .55786 .64401 L F
.55688 .64488 m .558 .64723 L .55985 .64584 L F
.883 .748 .708 r
.62402 .56096 m .62517 .5644 L .62553 .56188 L F
.816 .863 .883 r
.66883 .51629 m .66903 .51879 L .67159 .51612 L F
.424 .785 .996 r
.67983 .49754 m .67884 .49653 L .6762 .49689 L F
.322 0 0 r
.68083 .49722 m .67884 .49653 L .67983 .49754 L F
.457 .324 .611 r
.27332 .60199 m .27528 .60151 L .27517 .5989 L F
.541 .372 .601 r
.27332 .60199 m .27556 .60395 L .27528 .60151 L F
.27332 .60199 m .27338 .60443 L .27556 .60395 L F
.166 .259 .716 r
.4933 .65204 m .49487 .65158 L .49442 .65176 L F
.25 .66 .964 r
.35079 .58642 m .35019 .5872 L .34868 .58645 L F
.35079 .58642 m .35227 .58743 L .35019 .5872 L F
.727 .549 .65 r
.62537 .5168 m .62519 .51937 L .62739 .51641 L F
.838 .702 .713 r
.62205 .5473 m .62339 .55082 L .62499 .54782 L F
.574 .641 .879 r
.71561 .49946 m .71766 .49651 L .71562 .49914 L F
.574 .802 .986 r
.33594 .6293 m .33212 .62891 L .33399 .62781 L F
.292 .609 .954 r
.33663 .62818 m .33594 .6293 L .33399 .62781 L F
.33663 .62818 m .33782 .62953 L .33594 .6293 L F
.436 .624 .932 r
.28615 .64643 m .2864 .64385 L .28389 .64418 L F
.28615 .64643 m .28761 .64633 L .2864 .64385 L F
.583 .342 .517 r
.59895 .548 m .60137 .54978 L .60223 .54772 L F
.569 .25 .389 r
.60137 .54978 m .60452 .54759 L .60223 .54772 L F
0 0 0 r
.49237 .65394 m .49229 .65363 L .4933 .65204 L F
.49237 .65394 m .49186 .6556 L .49229 .65363 L F
.968 .647 .284 r
.57675 .6364 m .57586 .63607 L .57543 .63553 L F
.608 .426 .61 r
.57132 .66442 m .57174 .6672 L .56889 .66696 L F
0 0 .311 r
.57172 .66077 m .57196 .66352 L .57132 .66442 L F
0 0 .498 r
.57132 .66442 m .57238 .66676 L .57174 .6672 L F
.57132 .66442 m .57196 .66352 L .57238 .66676 L F
.583 .342 .517 r
.59895 .548 m .59888 .55023 L .60137 .54978 L F
0 0 .513 r
.64958 .50024 m .65051 .50177 L .64911 .49864 L F
0 .095 .647 r
.57468 .6725 m .57598 .67324 L .57346 .67146 L F
.424 0 0 r
.57346 .67146 m .57473 .6724 L .57445 .67226 L F
.587 .068 0 r
.57346 .67146 m .57244 .67063 L .57249 .67278 L F
.457 .747 .991 r
.57249 .67278 m .57468 .6725 L .57346 .67146 L F
.424 0 0 r
.57346 .67146 m .57445 .67226 L .57205 .67108 L F
.587 .068 0 r
.57346 .67146 m .57243 .67013 L .57244 .67063 L F
.879 .681 .631 r
.62253 .5529 m .62438 .55627 L .62471 .55398 L F
.62253 .5529 m .62155 .55592 L .62438 .55627 L F
.683 .247 .207 r
.32194 .64738 m .32021 .64866 L .31839 .647 L F
.44 0 0 r
.32194 .64738 m .32193 .64784 L .32021 .64866 L F
.32194 .64738 m .32402 .64847 L .32193 .64784 L F
.39 0 0 r
.3277 .64753 m .3258 .64842 L .32402 .64847 L F
0 0 0 r
.32991 .6473 m .3258 .64842 L .3277 .64753 L F
.392 0 .034 r
.55855 .61219 m .56039 .61287 L .56235 .61061 L F
0 .317 .783 r
.56235 .61061 m .56522 .61229 L .56592 .61324 L F
.621 .183 .188 r
.56235 .61061 m .56039 .61287 L .56522 .61229 L F
.55 .099 .134 r
.47238 .69936 m .47368 .70013 L .47503 .69849 L F
.591 .145 .161 r
.47368 .70013 m .47755 .69984 L .47503 .69849 L F
.613 .185 .206 r
.47368 .70013 m .47624 .70168 L .47755 .69984 L F
.78 .328 .175 r
.47247 .69923 m .47559 .70126 L .47368 .70013 L F
.47559 .70126 m .47624 .70168 L .47368 .70013 L F
.55 .099 .134 r
.47161 .69961 m .47368 .70013 L .47238 .69936 L F
.62 .097 0 r
.57174 .6672 m .56774 .66643 L .56889 .66696 L F
.125 0 .3 r
.57732 .66446 m .57903 .66405 L .57919 .66141 L F
0 .07 .588 r
.57732 .66446 m .57812 .66496 L .57903 .66405 L F
.57732 .66446 m .57934 .66634 L .57812 .66496 L F
.476 .294 .554 r
.57721 .66685 m .57934 .66634 L .57732 .66446 L F
.54 .637 .895 r
.32111 .62447 m .32064 .62715 L .31872 .62454 L F
.32111 .62447 m .32392 .62792 L .32064 .62715 L F
.506 .396 .663 r
.4121 .68138 m .41416 .68094 L .41379 .67847 L F
.439 .409 .729 r
.4121 .68138 m .4147 .68362 L .41416 .68094 L F
.836 .771 .79 r
.69858 .46495 m .69661 .4679 L .69821 .46787 L F
.46 .888 .835 r
.69547 .46847 m .69821 .46787 L .69661 .4679 L F
.69547 .46847 m .69773 .46741 L .69821 .46787 L F
0 0 0 r
.69821 .46787 m .70229 .46392 L .69858 .46495 L F
.69821 .46787 m .70045 .46619 L .70229 .46392 L F
.491 .902 .826 r
.69821 .46787 m .69773 .46741 L .70045 .46619 L F
.385 0 .079 r
.35158 .64027 m .35531 .63827 L .35374 .63986 L F
.225 0 0 r
.35374 .63986 m .35531 .63827 L .35753 .6377 L F
0 0 0 r
.45064 .6983 m .45283 .69795 L .45447 .69754 L F
.396 0 0 r
.45447 .69754 m .45283 .69795 L .45627 .69801 L F
.882 .686 .632 r
.60544 .57312 m .60354 .5729 L .60393 .57038 L F
.897 .547 .372 r
.60652 .57592 m .60354 .5729 L .60544 .57312 L F
.504 .324 .57 r
.31335 .61262 m .31116 .61503 L .31158 .61337 L F
.18 0 .278 r
.61087 .61349 m .61011 .61549 L .60847 .61655 L F
.137 0 .211 r
.61011 .61549 m .60776 .61837 L .60847 .61655 L F
.496 .602 .888 r
.31803 .62294 m .31679 .62495 L .31554 .62336 L F
.31803 .62294 m .31872 .62454 L .31679 .62495 L F
.204 .189 .619 r
.61976 .5956 m .61841 .59857 L .61886 .59593 L F
.61976 .5956 m .62011 .59751 L .61841 .59857 L F
0 0 .162 r
.62011 .59751 m .61819 .60073 L .61841 .59857 L F
.774 .55 .595 r
.56327 .62058 m .56711 .6213 L .56752 .619 L F
.425 .699 .978 r
.56817 .61752 m .56752 .619 L .56595 .61834 L F
.56817 .61752 m .57007 .61882 L .56752 .619 L F
.177 .4 .841 r
.56752 .619 m .56817 .61752 L .56595 .61834 L F
.56752 .619 m .56937 .62029 L .56817 .61752 L F
.731 .725 .845 r
.56711 .6213 m .56937 .62029 L .56752 .619 L F
0 0 .451 r
.52687 .60745 m .52687 .60627 L .52605 .60489 L F
0 0 .448 r
.52687 .60745 m .52775 .60833 L .52687 .60627 L F
.52687 .60745 m .52811 .61003 L .52775 .60833 L F
.352 .79 .964 r
.34138 .58499 m .34059 .58584 L .33923 .58506 L F
.34138 .58499 m .34298 .58552 L .34059 .58584 L F
.16 0 .185 r
.35994 .61901 m .35749 .62169 L .3592 .62079 L F
.408 .088 .309 r
.35994 .61901 m .3614 .62023 L .36222 .61865 L F
.35994 .61901 m .3592 .62079 L .3614 .62023 L F
0 .269 .767 r
.46939 .65255 m .4716 .65492 L .47023 .65398 L F
.002 .579 .727 r
.32175 .82358 m .32054 .82352 L .31834 .82348 L F
.32175 .82358 m .32054 .82352 L .31834 .82348 L F
.432 .867 .916 r
.32175 .82358 m .32265 .82284 L .32411 .8233 L F
.32175 .82358 m .32054 .82352 L .32265 .82284 L F
.32175 .82358 m .32265 .82284 L .32411 .8233 L F
.32175 .82358 m .32054 .82352 L .32265 .82284 L F
.796 .843 .887 r
.51254 .77794 m .51381 .77892 L .51537 .77838 L F
.591 .262 .38 r
.47261 .66033 m .47431 .66308 L .47203 .6614 L F
.425 .277 .575 r
.47581 .65815 m .47261 .66033 L .47521 .65825 L F
.47581 .65815 m .47642 .66013 L .47261 .66033 L F
.412 .206 .487 r
.47642 .66013 m .47431 .66308 L .47261 .66033 L F
.667 .675 .849 r
.75067 .50947 m .75275 .50761 L .74917 .50548 L F
.75067 .50947 m .75308 .50947 L .75275 .50761 L F
.578 .468 .692 r
.2726 .61296 m .27517 .61264 L .27456 .61012 L F
.439 .51 .835 r
.2726 .61296 m .2759 .61578 L .27517 .61264 L F
.472 0 0 r
.67119 .48537 m .67034 .48636 L .66752 .48549 L F
.529 0 0 r
.67389 .48663 m .67119 .48537 L .67354 .48571 L F
.67389 .48663 m .67034 .48636 L .67119 .48537 L F
.489 0 0 r
.48981 .77671 m .48866 .77564 L .4878 .77662 L F
.986 .744 .485 r
.57427 .62693 m .57417 .62448 L .57446 .62463 L F
0 0 .476 r
.57042 .64032 m .57073 .64338 L .56975 .64452 L F
.064 .222 .716 r
.57073 .64338 m .57232 .64816 L .56975 .64452 L F
.573 .866 .551 r
.57348 .64759 m .5721 .64888 L .57099 .6502 L F
.152 .279 .741 r
.5721 .64888 m .57366 .65301 L .57099 .6502 L F
.793 .654 .708 r
.62253 .5529 m .62471 .55398 L .62339 .55082 L F
.449 .169 .395 r
.27517 .5989 m .27758 .59838 L .27795 .59605 L F
.519 .329 .563 r
.27795 .59605 m .28 .5957 L .28021 .59319 L F
.587 .289 .43 r
.27795 .59605 m .27983 .59798 L .28 .5957 L F
.27795 .59605 m .27758 .59838 L .27983 .59798 L F
.82 .598 .602 r
.56833 .63598 m .57143 .6361 L .56694 .63477 L F
.56833 .63598 m .57099 .63847 L .57143 .6361 L F
.567 .935 .915 r
.55448 .61501 m .55614 .61372 L .55641 .61176 L F
.55448 .61501 m .55297 .61497 L .55614 .61372 L F
.49 .572 .866 r
.43988 .69429 m .43856 .69662 L .43784 .69458 L F
.43988 .69429 m .44143 .69661 L .43856 .69662 L F
.256 .711 .954 r
.43856 .69662 m .44143 .69661 L .44258 .69714 L F
.799 .746 .803 r
.5242 .80128 m .52619 .79944 L .52311 .79983 L F
.5242 .80128 m .52619 .79944 L .52311 .79983 L F
.664 .578 .749 r
.59441 .6624 m .59142 .66138 L .59327 .66092 L F
.559 .331 .526 r
.50848 .67577 m .51072 .67775 L .51095 .67544 L F
.50848 .67577 m .51072 .67775 L .51095 .67544 L F
.533 .422 .673 r
.76214 .49872 m .75915 .49736 L .7615 .49532 L F
.76214 .49872 m .75985 .49937 L .75915 .49736 L F
.507 .046 .093 r
.54138 .65689 m .53964 .65586 L .54254 .65582 L F
0 0 0 r
.54494 .65545 m .54138 .65689 L .54254 .65582 L F
.321 0 .119 r
.54512 .65485 m .54494 .65545 L .54254 .65582 L F
.423 0 0 r
.28447 .59211 m .28684 .59207 L .28854 .59065 L F
.282 0 0 r
.28684 .59207 m .29077 .59033 L .28854 .59065 L F
.961 .626 .29 r
.62215 .58763 m .62166 .58931 L .62249 .58849 L F
0 0 0 r
.62286 .58353 m .62219 .58755 L .62215 .58763 L F
.62219 .58755 m .62166 .58931 L .62215 .58763 L F
.805 .816 .86 r
.69189 .48729 m .68878 .48749 L .69099 .48548 L F
.678 .781 .928 r
.69346 .4844 m .69189 .48729 L .69099 .48548 L F
.69346 .4844 m .69496 .486 L .69189 .48729 L F
.978 .9 .556 r
.26854 .6474 m .26702 .64928 L .26779 .64931 L F
.26854 .6474 m .26702 .64928 L .26779 .64931 L F
.497 .214 .414 r
.35628 .62386 m .3592 .62079 L .35749 .62169 L F
.934 .611 .405 r
.53964 .65586 m .53839 .65743 L .53809 .65556 L F
.507 .046 .093 r
.54138 .65689 m .53839 .65743 L .53964 .65586 L F
.211 .733 .845 r
.25873 .64754 m .26142 .6472 L .26246 .64734 L F
.25873 .64754 m .26142 .6472 L .26246 .64734 L F
.949 .95 .731 r
.26246 .64734 m .26142 .6472 L .2617 .64594 L F
.2617 .64594 m .26142 .6472 L .26246 .64734 L F
.552 .435 .674 r
.26562 .65086 m .26594 .65268 L .2637 .65302 L F
.26562 .65086 m .26594 .65268 L .2637 .65302 L F
.497 .883 .702 r
.4807 .64684 m .47771 .64883 L .48065 .64686 L F
.102 0 0 r
.48068 .64687 m .47771 .64883 L .4807 .64684 L F
.757 .735 .832 r
.47771 .64883 m .47997 .64783 L .48067 .64688 L F
.102 0 0 r
.47985 .64794 m .47771 .64883 L .48068 .64687 L F
.664 .601 .774 r
.47626 .64942 m .47923 .65041 L .47771 .64883 L F
.757 .735 .832 r
.47771 .64883 m .47923 .65041 L .48155 .64949 L F
.102 0 0 r
.47824 .65002 m .47771 .64883 L .47985 .64794 L F
.664 .601 .774 r
.47546 .64915 m .47626 .64942 L .47771 .64883 L F
.581 .823 .444 r
.47947 .64842 m .47824 .65002 L .48068 .64687 L F
.77 .972 .689 r
.48291 .64426 m .4809 .64658 L .48121 .64729 L F
.4809 .64658 m .48065 .64686 L .48067 .64688 L F
.581 .823 .444 r
.48069 .64686 m .48068 .64686 L .4807 .64684 L F
.77 .972 .689 r
.4809 .64658 m .48067 .64688 L .48121 .64729 L F
.581 .823 .444 r
.48068 .64687 m .48068 .64687 L .48068 .64686 L F
.48068 .64687 m .48068 .64686 L .48069 .64686 L F
.47947 .64842 m .48068 .64687 L .48068 .64687 L F
.757 .735 .832 r
.47997 .64783 m .48108 .64735 L .48067 .64688 L F
.47997 .64783 m .48067 .64688 L .48067 .64688 L F
.48108 .64735 m .48121 .64729 L .48072 .64692 L F
.48108 .64735 m .48072 .64692 L .48067 .64688 L F
.925 .92 .538 r
.48075 .6447 m .4807 .64684 L .48065 .64686 L F
.48075 .6447 m .4802 .64629 L .48054 .64667 L F
.917 .907 .507 r
.48065 .64686 m .48052 .64685 L .48075 .6447 L F
.925 .92 .538 r
.48075 .6447 m .48054 .64667 L .4807 .64683 L F
.4802 .64629 m .48068 .64687 L .4807 .64684 L F
.917 .907 .507 r
.48052 .64685 m .48014 .64683 L .48075 .6447 L F
.925 .92 .538 r
.48075 .6447 m .4807 .64683 L .4807 .64683 L F
.77 .972 .689 r
.48291 .64426 m .48014 .64683 L .48052 .64685 L F
.48068 .64684 m .48052 .64685 L .48065 .64686 L F
.48291 .64426 m .48052 .64685 L .48068 .64684 L F
.925 .92 .538 r
.4807 .64683 m .4807 .64683 L .4807 .64684 L F
.757 .735 .832 r
.47771 .64883 m .48067 .64688 L .48065 .64686 L F
.925 .92 .538 r
.4802 .64629 m .47947 .64842 L .48068 .64687 L F
.836 .687 .697 r
.74626 .52427 m .7456 .52574 L .7438 .52423 L F
.39 .064 .287 r
.58022 .56351 m .57846 .56245 L .57817 .56435 L F
.58022 .56351 m .58075 .56192 L .57846 .56245 L F
.653 .717 .895 r
.51339 .65178 m .51178 .65373 L .51625 .65289 L F
0 0 0 r
.51339 .65178 m .51197 .65382 L .51178 .65373 L F
.305 .041 .338 r
.56592 .61324 m .56526 .61555 L .56352 .61596 L F
.557 .446 .683 r
.56526 .61555 m .56356 .6185 L .56352 .61596 L F
.943 .842 .405 r
.56534 .61374 m .56592 .61324 L .56522 .61229 L F
.56534 .61374 m .56526 .61555 L .56592 .61324 L F
.396 .152 .423 r
.70291 .46836 m .70048 .4713 L .7001 .46813 L F
0 0 0 r
.57524 .64532 m .57348 .64759 L .57573 .64464 L F
.232 0 .25 r
.57749 .64345 m .57524 .64532 L .57573 .64464 L F
.672 .771 .293 r
.62118 .59151 m .62249 .58849 L .62166 .58931 L F
.62118 .59151 m .62053 .59316 L .62249 .58849 L F
0 .091 .638 r
.51467 .63163 m .51361 .63104 L .51256 .62959 L F
.51467 .63163 m .51559 .63315 L .51387 .63132 L F
0 .306 .676 r
.51561 .632 m .51467 .63163 L .51329 .63111 L F
.51588 .63211 m .51768 .63301 L .51467 .63163 L F
.51588 .63211 m .51467 .63163 L .51561 .632 L F
0 .091 .638 r
.51467 .63163 m .51387 .63132 L .51361 .63104 L F
.69 .708 .862 r
.59589 .6627 m .59441 .6624 L .59668 .66151 L F
.52 .466 .737 r
.59901 .66113 m .59589 .6627 L .59668 .66151 L F
.59901 .66113 m .59954 .66376 L .59589 .6627 L F
.435 .182 .43 r
.59954 .66376 m .59723 .66666 L .59589 .6627 L F
.484 .75 .988 r
.58836 .65477 m .58681 .65561 L .58619 .65528 L F
.58836 .65477 m .59023 .65554 L .58681 .65561 L F
.421 .749 .994 r
.49937 .77713 m .50168 .77799 L .49832 .77796 L F
.142 .227 .692 r
.49832 .77796 m .50043 .78048 L .49937 .77713 L F
.549 .874 .993 r
.53668 .60392 m .53531 .60323 L .53432 .60456 L F
.53432 .60456 m .53531 .60323 L .53668 .60392 L F
.321 0 .111 r
.3212 .60464 m .31983 .60673 L .31771 .6072 L F
.342 0 .123 r
.32356 .6045 m .3212 .60464 L .32325 .60393 L F
.32356 .6045 m .31983 .60673 L .3212 .60464 L F
.43 .526 .854 r
.75608 .48501 m .75413 .48505 L .75262 .48199 L F
.358 .598 .938 r
.6601 .4949 m .65946 .49674 L .65698 .49271 L F
.6601 .4949 m .6604 .49618 L .65946 .49674 L F
.924 .947 .791 r
.51986 .6519 m .52239 .65031 L .52136 .64907 L F
.587 .83 .99 r
.7182 .48496 m .71558 .48587 L .71455 .48464 L F
.341 .057 .328 r
.41535 .66994 m .41718 .66954 L .41782 .66747 L F
.295 .016 .308 r
.41782 .66747 m .41718 .66954 L .41976 .66663 L F
.269 .448 .853 r
.74529 .47642 m .74823 .47796 L .74699 .47925 L F
.363 .6 .938 r
.74823 .47796 m .74901 .47952 L .74699 .47925 L F
.903 .58 .425 r
.44645 .69779 m .44714 .70025 L .44826 .6985 L F
.18 0 0 r
.44714 .70025 m .45064 .6983 L .44826 .6985 L F
.603 .4 .579 r
.60689 .54492 m .60957 .54481 L .60957 .54199 L F
.436 .192 .444 r
.60957 .54199 m .61157 .54143 L .61187 .53963 L F
.549 .357 .573 r
.60957 .54199 m .61176 .544 L .61157 .54143 L F
.60957 .54199 m .60957 .54481 L .61176 .544 L F
.901 .864 .422 r
.60564 .59585 m .60492 .59906 L .60477 .59744 L F
.906 .603 .11 r
.60492 .59906 m .60444 .59994 L .60477 .59744 L F
.60492 .59906 m .60488 .60074 L .60444 .59994 L F
.546 .581 .841 r
.31477 .62259 m .3135 .62353 L .31192 .62063 L F
.31477 .62259 m .31554 .62336 L .3135 .62353 L F
0 0 .08 r
.56439 .60159 m .56313 .60386 L .56414 .60231 L F
.796 .729 .79 r
.36019 .59799 m .36382 .59827 L .3625 .59744 L F
.525 .857 .996 r
.3625 .59744 m .36382 .59827 L .36688 .59733 L F
.361 0 0 r
.44941 .70651 m .44568 .70807 L .44714 .70689 L F
.237 0 .279 r
.28 .5957 m .28245 .59288 L .28021 .59319 L F
.277 0 0 r
.57515 .64819 m .57348 .64759 L .57524 .64532 L F
.57515 .64819 m .5721 .64888 L .57348 .64759 L F
.224 .729 .897 r
.4926 .61908 m .49497 .61895 L .49604 .61925 L F
.035 0 0 r
.49497 .61895 m .49819 .61905 L .49604 .61925 L F
.4 .059 .268 r
.59204 .56844 m .59305 .5699 L .59084 .56989 L F
.59204 .56844 m .59463 .56729 L .59305 .5699 L F
.731 .725 .845 r
.56711 .6213 m .57056 .62171 L .56937 .62029 L F
.769 .607 .678 r
.56711 .6213 m .56849 .62451 L .57056 .62171 L F
.622 .643 .85 r
.50643 .65452 m .50947 .6545 L .50807 .65113 L F
.684 .498 .628 r
.61157 .54143 m .6148 .53907 L .61187 .53963 L F
0 .228 .747 r
.50981 .77661 m .51025 .77701 L .50858 .77473 L F
.376 .692 .981 r
.29185 .63885 m .29607 .64064 L .29493 .63854 L F
.776 .852 .908 r
.29493 .63854 m .29607 .64064 L .29812 .63845 L F
.304 .756 .957 r
.44348 .69656 m .44258 .69714 L .44143 .69661 L F
.725 .953 .949 r
.675 .50289 m .67623 .50091 L .67731 .50199 L F
.675 .50289 m .67427 .50224 L .67623 .50091 L F
.698 .448 .542 r
.58455 .62108 m .58796 .61884 L .58448 .61895 L F
.58455 .62108 m .58796 .62141 L .58796 .61884 L F
.685 .469 .588 r
.58796 .62141 m .59041 .61868 L .58796 .61884 L F
0 0 0 r
.74523 .48925 m .74606 .48801 L .74521 .4877 L F
.911 .524 .109 r
.74409 .48578 m .74606 .48801 L .74521 .4877 L F
.12 .663 .834 r
.74882 .48938 m .74409 .48578 L .74606 .48801 L F
.911 .524 .109 r
.74521 .4877 m .74606 .48801 L .74409 .48578 L F
.711 .905 .964 r
.55158 .75716 m .55105 .75898 L .54955 .75845 L F
.55158 .75716 m .55318 .75768 L .55105 .75898 L F
.834 .596 .579 r
.62063 .54391 m .62239 .54234 L .62064 .54186 L F
.62063 .54391 m .62222 .54472 L .62239 .54234 L F
.635 .415 .567 r
.71902 .47559 m .72134 .47324 L .71911 .47423 L F
.313 .338 .727 r
.48155 .64949 m .48232 .65335 L .48373 .65157 L F
.531 .335 .56 r
.48232 .65335 m .48507 .65412 L .48373 .65157 L F
.48232 .65335 m .48248 .65501 L .48507 .65412 L F
.784 .789 .856 r
.73028 .50817 m .73213 .50765 L .73057 .50481 L F
.781 .958 .926 r
.72994 .51076 m .73213 .50765 L .73028 .50817 L F
.686 .748 .898 r
.73057 .50481 m .73213 .50765 L .73446 .50649 L F
.586 .619 .851 r
.75275 .50761 m .75308 .50947 L .75478 .50652 L F
.415 .402 .737 r
.75308 .50947 m .75563 .50998 L .75478 .50652 L F
.54 .378 .61 r
.31562 .60969 m .31335 .61262 L .31372 .61046 L F
0 .078 .615 r
.30271 .64266 m .3037 .64327 L .30218 .64112 L F
.30271 .64266 m .3042 .64431 L .3037 .64327 L F
.97 .818 .636 r
.62303 .57195 m .62491 .57073 L .62339 .56964 L F
.62303 .57195 m .62429 .57289 L .62491 .57073 L F
.453 .209 .452 r
.39096 .61545 m .38839 .61825 L .38875 .61591 L F
.591 .714 .929 r
.70619 .49695 m .70761 .49496 L .70599 .49569 L F
.70619 .49695 m .70872 .49643 L .70761 .49496 L F
.555 .415 .645 r
.3668 .61268 m .36886 .60978 L .36681 .61029 L F
.585 .508 .735 r
.74078 .51949 m .74027 .5218 L .73918 .52199 L F
.518 .91 .926 r
.49095 .64311 m .48959 .6435 L .49008 .64427 L F
.658 .123 0 r
.4716 .65492 m .47364 .6565 L .47444 .65582 L F
.281 0 0 r
.47407 .65122 m .47319 .65013 L .47546 .64915 L F
.47407 .65122 m .47196 .65164 L .47319 .65013 L F
.052 .126 .622 r
.47444 .65582 m .47581 .65815 L .47521 .65825 L F
.726 .201 0 r
.47364 .6565 m .47581 .65815 L .47444 .65582 L F
.371 .702 .984 r
.50894 .80826 m .51024 .80947 L .50796 .80928 L F
.50796 .80928 m .51024 .80947 L .50894 .80826 L F
.50894 .80826 m .51024 .80947 L .50796 .80928 L F
.935 .686 .537 r
.51946 .65594 m .51547 .65499 L .51739 .65484 L F
.51946 .65594 m .51757 .65804 L .51547 .65499 L F
.716 .341 .337 r
.51946 .65594 m .52129 .65829 L .51757 .65804 L F
.177 .223 .672 r
.52021 .6552 m .52129 .65829 L .51946 .65594 L F
.52021 .6552 m .52129 .65829 L .51946 .65594 L F
.293 .473 .866 r
.39803 .59683 m .39711 .59805 L .39535 .59632 L F
.891 .8 .752 r
.74931 .49096 m .74642 .49203 L .74785 .49126 L F
.74931 .49096 m .74783 .49393 L .74642 .49203 L F
.971 .902 .694 r
.74931 .49096 m .74785 .49126 L .74882 .48938 L F
.695 .259 .211 r
.5026 .70586 m .49973 .70573 L .4996 .70462 L F
.495 .365 .633 r
.41365 .67613 m .41566 .67565 L .41555 .67242 L F
.428 .274 .568 r
.41379 .67847 m .41566 .67565 L .41365 .67613 L F
.295 .191 .563 r
.58037 .6609 m .5801 .66123 L .57919 .66141 L F
.124 0 .299 r
.57919 .66141 m .58068 .66267 L .58037 .6609 L F
.57919 .66141 m .57903 .66405 L .58068 .66267 L F
.569 .456 .685 r
.31179 .6187 m .30992 .62113 L .30977 .61944 L F
.261 .003 .32 r
.31771 .6072 m .31562 .60969 L .31618 .60771 L F
.454 .329 .62 r
.29185 .63885 m .29041 .64138 L .29031 .63836 L F
.963 .799 .632 r
.73005 .48774 m .72796 .48961 L .72886 .4865 L F
.73005 .48774 m .72931 .49065 L .72796 .48961 L F
.634 .419 .573 r
.53024 .75634 m .53411 .75523 L .53129 .75404 L F
.605 .335 .482 r
.41137 .69614 m .414 .69805 L .41434 .69559 L F
.398 .85 .783 r
.49042 .61988 m .49099 .61934 L .4926 .61908 L F
.49042 .61988 m .48886 .62027 L .49099 .61934 L F
.616 .791 .355 r
.41446 .70048 m .41461 .70021 L .41564 .69843 L F
.585 .491 .715 r
.41564 .69843 m .41664 .6956 L .41434 .69559 L F
.41564 .69843 m .41805 .6986 L .41664 .6956 L F
.997 .823 .473 r
.41564 .69843 m .41461 .70021 L .41489 .69763 L F
.556 .624 .875 r
.55412 .60472 m .5558 .60929 L .55654 .60602 L F
.591 .835 .991 r
.55457 .60872 m .55654 .60602 L .5558 .60929 L F
.245 0 0 r
.4531 .70598 m .45169 .70648 L .44941 .70651 L F
.339 0 0 r
.45541 .7059 m .45169 .70648 L .4531 .70598 L F
.891 .756 .707 r
.73839 .50194 m .73855 .49928 L .73691 .5021 L F
.834 .678 .689 r
.73641 .5045 m .73839 .50194 L .73691 .5021 L F
.569 .456 .685 r
.31179 .6187 m .31192 .62063 L .30992 .62113 L F
.839 .995 .755 r
.68288 .50612 m .68216 .50822 L .68447 .50536 L F
.816 .99 .874 r
.68288 .50612 m .67938 .50856 L .68216 .50822 L F
.352 .764 .981 r
.35227 .58743 m .35439 .58726 L .35596 .58796 L F
.205 .715 .896 r
.35439 .58726 m .35811 .58751 L .35596 .58796 L F
.519 .18 .332 r
.59 .67019 m .58946 .67168 L .58742 .67183 L F
.352 0 .158 r
.5925 .66991 m .58946 .67168 L .59 .67019 L F
.166 0 .014 r
.45255 .65054 m .45179 .65174 L .45461 .64969 L F
.707 .22 .086 r
.5018 .62142 m .50405 .62336 L .50477 .62219 L F
.764 .291 .119 r
.50477 .62219 m .50405 .62336 L .50592 .62336 L F
0 .49 .763 r
.67603 .49408 m .6782 .49452 L .6783 .49458 L F
.512 .366 .618 r
.6762 .49689 m .6782 .49452 L .67603 .49408 L F
.509 .374 .632 r
.41535 .66994 m .41765 .67193 L .41718 .66954 L F
.41535 .66994 m .41555 .67242 L .41765 .67193 L F
.137 .282 .749 r
.49964 .80047 m .50115 .80422 L .50202 .80279 L F
.691 .945 .665 r
.50202 .80279 m .50115 .80422 L .5025 .8027 L F
0 0 .065 r
.61203 .61209 m .61011 .61549 L .61087 .61349 L F
.963 .631 .285 r
.53752 .62185 m .538 .62408 L .53702 .6237 L F
0 0 .367 r
.53752 .62185 m .53813 .62054 L .53744 .61844 L F
0 .371 .815 r
.53752 .62185 m .53874 .62191 L .53813 .62054 L F
.53752 .62185 m .54042 .62343 L .53874 .62191 L F
.583 .013 0 r
.47755 .69984 m .47856 .70063 L .48019 .7012 L F
.823 .345 0 r
.47856 .70063 m .47961 .70225 L .48019 .7012 L F
.597 .856 .993 r
.48328 .70222 m .48205 .70346 L .48055 .70164 L F
.48328 .70222 m .48055 .70164 L .48019 .7012 L F
.48328 .70222 m .4847 .70328 L .48205 .70346 L F
0 .524 .74 r
.48328 .70222 m .4867 .70272 L .4847 .70328 L F
.393 0 0 r
.48328 .70222 m .48146 .70299 L .48478 .70254 L F
0 .524 .74 r
.48328 .70222 m .48528 .70247 L .4867 .70272 L F
.393 0 0 r
.48328 .70222 m .48478 .70254 L .48528 .70247 L F
.712 .309 .282 r
.47961 .70225 m .48328 .70222 L .48019 .7012 L F
.551 .523 .778 r
.58257 .63592 m .58363 .63232 L .5814 .63289 L F
.58257 .63592 m .58475 .63533 L .58363 .63232 L F
.509 .267 .483 r
.59901 .63034 m .5965 .6329 L .59637 .63033 L F
.297 .791 .867 r
.56269 .60602 m .56093 .60667 L .56313 .60386 L F
.56269 .60602 m .56043 .60646 L .56093 .60667 L F
.527 .271 .47 r
.56269 .60602 m .56217 .60811 L .56043 .60646 L F
.154 .242 .702 r
.56043 .60646 m .56217 .60811 L .56119 .60561 L F
.56043 .60646 m .56119 .60561 L .56086 .60478 L F
.619 .958 .842 r
.55935 .60767 m .56043 .60646 L .55895 .60792 L F
.56093 .60667 m .56043 .60646 L .55935 .60767 L F
.526 .854 .568 r
.56043 .60646 m .55756 .6091 L .55895 .60792 L F
.474 .035 .124 r
.52888 .70169 m .52767 .70335 L .52509 .70343 L F
.419 .016 .166 r
.53101 .70118 m .52767 .70335 L .52888 .70169 L F
.841 .873 .866 r
.74437 .53152 m .74694 .53168 L .74835 .52997 L F
.259 0 0 r
.43126 .66086 m .42728 .66288 L .43004 .66322 L F
.43126 .66086 m .42814 .66183 L .42728 .66288 L F
.421 .042 .21 r
.43226 .66277 m .43126 .66086 L .43004 .66322 L F
.43226 .66277 m .43346 .66057 L .43126 .66086 L F
.619 .693 .897 r
.69701 .49635 m .70085 .49743 L .69937 .49576 L F
.75 .734 .837 r
.69937 .49576 m .70085 .49743 L .70273 .49617 L F
.485 .269 .51 r
.43974 .67817 m .4377 .68059 L .438 .6787 L F
0 0 .128 r
.43868 .68638 m .43813 .68886 L .4372 .68977 L F
.101 .011 .456 r
.43864 .69111 m .4372 .68977 L .43813 .68886 L F
.43864 .69111 m .43707 .69257 L .4372 .68977 L F
.02 0 0 r
.47016 .63831 m .47204 .63777 L .47308 .6362 L F
0 0 0 r
.47553 .63336 m .47308 .6362 L .47458 .63471 L F
.231 0 0 r
.47308 .6362 m .47422 .63718 L .47458 .63471 L F
.47308 .6362 m .47204 .63777 L .47422 .63718 L F
.738 .859 .937 r
.66229 .51352 m .66028 .51441 L .65904 .51364 L F
.097 0 0 r
.34372 .62765 m .34416 .6285 L .34598 .62721 L F
.34372 .62765 m .34206 .62911 L .34416 .6285 L F
.689 .881 .5 r
.6855 .50349 m .68447 .50536 L .68655 .50227 L F
.822 .996 .763 r
.68752 .50001 m .68655 .50227 L .68895 .49945 L F
.76 .903 .512 r
.68752 .50001 m .6855 .50349 L .68655 .50227 L F
.664 .743 .91 r
.59668 .66151 m .59441 .6624 L .59327 .66092 L F
0 0 .073 r
.65342 .48794 m .65173 .49108 L .65248 .48992 L F
0 0 .122 r
.65342 .48794 m .65504 .48637 L .65551 .48453 L F
.491 .232 .449 r
.55245 .6136 m .54862 .61654 L .54758 .6127 L F
.55245 .6136 m .55143 .61632 L .54862 .61654 L F
.483 .205 .416 r
.55143 .61632 m .55069 .61776 L .54862 .61654 L F
.035 0 0 r
.47717 .63211 m .4799 .6298 L .47767 .63032 L F
.76 .987 .761 r
.68288 .50612 m .68447 .50536 L .6855 .50349 L F
.21 0 .157 r
.47016 .63831 m .47137 .63972 L .47204 .63777 L F
.47016 .63831 m .46951 .64044 L .47137 .63972 L F
.597 .569 .793 r
.57467 .65779 m .5708 .65879 L .57148 .65544 L F
0 0 0 r
.57467 .65779 m .57172 .66077 L .5708 .65879 L F
.712 .911 .964 r
.68634 .48979 m .68409 .49092 L .685 .48893 L F
0 0 .459 r
.68409 .49092 m .68549 .49161 L .685 .48893 L F
.424 .082 .279 r
.43861 .65835 m .44085 .65789 L .44175 .65567 L F
.475 .149 .334 r
.44085 .65789 m .444 .65522 L .44175 .65567 L F
.355 .201 .53 r
.41976 .66663 m .42159 .66347 L .42014 .66435 L F
.226 .164 .575 r
.71413 .47966 m .7155 .47575 L .71357 .476 L F
.623 .849 .986 r
.70038 .48517 m .6987 .48312 L .69932 .48162 L F
.70038 .48517 m .69704 .4848 L .6987 .48312 L F
.591 .597 .827 r
.70296 .48363 m .70038 .48517 L .69932 .48162 L F
.731 .721 .842 r
.46288 .67515 m .46417 .67755 L .46607 .67497 L F
.617 .951 .789 r
.27441 .64815 m .27176 .65007 L .27345 .6485 L F
.485 .562 .859 r
.27176 .65007 m .27408 .65025 L .27345 .6485 L F
.735 .574 .674 r
.61724 .53891 m .61964 .53626 L .61715 .5363 L F
.61724 .53891 m .62086 .53924 L .61964 .53626 L F
.189 0 .071 r
.57817 .56435 m .57605 .56527 L .57524 .5666 L F
.795 .642 .693 r
.64144 .49894 m .64482 .49958 L .64335 .4962 L F
.827 .619 .622 r
.64144 .49894 m .64422 .50132 L .64482 .49958 L F
.412 .19 .464 r
.38839 .61825 m .38606 .62093 L .38627 .61882 L F
.277 0 0 r
.33297 .64656 m .3323 .64709 L .32991 .6473 L F
.05 0 0 r
.33441 .64652 m .33297 .64656 L .3348 .64606 L F
.33441 .64652 m .3323 .64709 L .33297 .64656 L F
.585 .406 .606 r
.50697 .6464 m .50455 .64689 L .50462 .64441 L F
.794 .745 .807 r
.54156 .59661 m .5374 .59701 L .53991 .59625 L F
.54156 .59661 m .53885 .59887 L .5374 .59701 L F
.286 .787 .813 r
.53991 .59625 m .54347 .59556 L .54156 .59661 L F
.513 .644 .915 r
.39425 .5944 m .39321 .59647 L .39211 .59465 L F
.504 .633 .91 r
.39425 .5944 m .39535 .59632 L .39321 .59647 L F
.399 0 .043 r
.4867 .70272 m .48884 .70287 L .49018 .70122 L F
.149 .307 .769 r
.65782 .51919 m .65893 .51791 L .65653 .51596 L F
.357 .625 .954 r
.65782 .51919 m .66027 .51944 L .65893 .51791 L F
.837 .367 .016 r
.56542 .63048 m .56632 .63213 L .56782 .63295 L F
.961 .695 .486 r
.56644 .6343 m .56782 .63295 L .56632 .63213 L F
.56644 .6343 m .56694 .63477 L .56782 .63295 L F
.699 .556 .688 r
.49877 .65457 m .49711 .65235 L .50166 .65006 L F
.269 .182 .568 r
.50225 .64968 m .50294 .6508 L .50166 .65006 L F
.708 .459 .545 r
.5031 .65429 m .50166 .65006 L .50294 .6508 L F
.5031 .65429 m .49877 .65457 L .50166 .65006 L F
.531 .828 .999 r
.50282 .80066 m .49972 .79791 L .50279 .79784 L F
.50282 .80066 m .49964 .80047 L .49972 .79791 L F
0 0 .449 r
.50342 .79866 m .50282 .80066 L .50279 .79784 L F
.937 .827 .378 r
.50202 .80279 m .50282 .80066 L .50342 .79866 L F
.50202 .80279 m .5025 .8027 L .50282 .80066 L F
.337 .747 .98 r
.40392 .5987 m .40247 .59958 L .40114 .59897 L F
.40392 .5987 m .40563 .59973 L .40247 .59958 L F
0 0 .147 r
.62053 .59316 m .61976 .5956 L .61886 .59593 L F
.726 .421 .462 r
.4847 .70328 m .48073 .70582 L .48205 .70346 L F
.4847 .70328 m .48412 .7056 L .48073 .70582 L F
.521 .735 .971 r
.4847 .70328 m .48789 .70384 L .4867 .70272 L F
.445 .153 .374 r
.48633 .70512 m .4847 .70328 L .48789 .70384 L F
.48633 .70512 m .48412 .7056 L .4847 .70328 L F
.226 .164 .575 r
.71413 .47966 m .71615 .47826 L .7155 .47575 L F
.451 .601 .909 r
.71413 .47966 m .71618 .47938 L .71615 .47826 L F
0 0 .514 r
.72938 .5189 m .73173 .52226 L .73107 .52116 L F
.828 .484 0 r
.73173 .52226 m .73238 .52441 L .73107 .52116 L F
.635 .154 .093 r
.57887 .63332 m .57776 .63458 L .5814 .63488 L F
.62 .464 .649 r
.57887 .63332 m .5814 .63289 L .58119 .63012 L F
.569 .303 .474 r
.57887 .63332 m .5814 .63488 L .5814 .63289 L F
.575 .041 0 r
.51243 .7061 m .51107 .70635 L .50855 .70528 L F
.133 0 0 r
.51438 .70604 m .51107 .70635 L .51243 .7061 L F
.561 .529 .777 r
.37723 .6044 m .37831 .60064 L .3761 .60111 L F
.37723 .6044 m .37939 .60394 L .37831 .60064 L F
.511 .149 .29 r
.37652 .60625 m .37885 .60601 L .37723 .6044 L F
.442 .153 .377 r
.37723 .6044 m .37885 .60601 L .37939 .60394 L F
.769 .696 .781 r
.49799 .79565 m .49972 .79791 L .49622 .79768 L F
.713 .321 .304 r
.49622 .79768 m .49972 .79791 L .49841 .79958 L F
.63 .701 .896 r
.50019 .79566 m .49972 .79791 L .49799 .79565 L F
.50019 .79566 m .50279 .79784 L .49972 .79791 L F
.982 .765 .534 r
.49972 .79791 m .49964 .80047 L .49841 .79958 L F
.481 .847 .99 r
.76695 .50642 m .7672 .50729 L .76474 .50783 L F
.558 .423 .653 r
.7672 .50729 m .76521 .51095 L .76474 .50783 L F
.7672 .50729 m .76777 .51033 L .76521 .51095 L F
.853 .599 .553 r
.76711 .50698 m .76942 .5044 L .7672 .50729 L F
.425 0 0 r
.76653 .50627 m .76723 .50646 L .76695 .50642 L F
.853 .599 .553 r
.76695 .50642 m .76745 .50649 L .76711 .50698 L F
.541 .374 .604 r
.76942 .5044 m .7697 .50675 L .7672 .50729 L F
.853 .599 .553 r
.76825 .50536 m .7685 .50515 L .76796 .50603 L F
.7685 .50515 m .76942 .5044 L .768 .50598 L F
.7685 .50515 m .768 .50598 L .76796 .50603 L F
.76765 .50621 m .76796 .50603 L .76711 .50698 L F
.76825 .50536 m .76796 .50603 L .76765 .50621 L F
.425 0 0 r
.76723 .50646 m .76879 .50625 L .76774 .5066 L F
.76653 .50627 m .76765 .50621 L .76723 .50646 L F
.76765 .50621 m .76992 .5061 L .76723 .50646 L F
.702 .643 .787 r
.76911 .50413 m .76765 .50621 L .76653 .50627 L F
.853 .599 .553 r
.76695 .50642 m .76825 .50536 L .76745 .50649 L F
.702 .643 .787 r
.76825 .50536 m .76912 .50614 L .76765 .50621 L F
.853 .599 .553 r
.76792 .50654 m .7696 .50598 L .76942 .5044 L F
.702 .643 .787 r
.76911 .50413 m .76992 .5061 L .76912 .50614 L F
.853 .599 .553 r
.76825 .50536 m .76856 .50563 L .76942 .5044 L F
.702 .643 .787 r
.76911 .50413 m .76912 .50614 L .76825 .50536 L F
.853 .599 .553 r
.76695 .50642 m .76792 .50654 L .76856 .50563 L F
.76695 .50642 m .76856 .50563 L .76825 .50536 L F
.76792 .50654 m .7697 .50675 L .7696 .50598 L F
.425 0 0 r
.76778 .50659 m .76992 .5061 L .76784 .50663 L F
.76879 .50625 m .76992 .5061 L .76774 .5066 L F
.607 .593 .811 r
.77166 .50218 m .76992 .5061 L .76911 .50413 L F
.52 .397 .653 r
.7702 .50945 m .7672 .50729 L .7697 .50675 L F
.729 .259 .134 r
.76695 .50642 m .76873 .50803 L .76951 .50701 L F
.76792 .50654 m .76951 .50701 L .7697 .50675 L F
.425 0 0 r
.76774 .5066 m .76778 .50659 L .76783 .50662 L F
.76774 .5066 m .76783 .50662 L .76783 .50662 L F
.76723 .50646 m .76783 .50662 L .76695 .50642 L F
.729 .259 .134 r
.76695 .50642 m .76783 .50662 L .76792 .50654 L F
.76783 .50662 m .76951 .50701 L .76792 .50654 L F
.425 0 0 r
.76783 .50662 m .76783 .50662 L .76784 .50663 L F
.842 .88 .869 r
.76784 .50663 m .76992 .5061 L .77166 .50218 L F
.523 .46 .728 r
.77018 .50427 m .76902 .50729 L .76784 .50663 L F
.76902 .50729 m .76873 .50803 L .76784 .50663 L F
.607 .593 .811 r
.77061 .50163 m .76911 .50413 L .76737 .49992 L F
.77166 .50218 m .76911 .50413 L .77061 .50163 L F
.425 0 0 r
.76783 .50662 m .76784 .50663 L .76695 .50642 L F
.702 .643 .787 r
.76737 .49992 m .76911 .50413 L .76653 .50627 L F
.52 .397 .653 r
.7702 .50945 m .76777 .51033 L .7672 .50729 L F
.516 .361 .61 r
.76639 .50869 m .76796 .50824 L .76695 .50642 L F
.76796 .50824 m .76873 .50803 L .76748 .5069 L F
.76796 .50824 m .76748 .5069 L .76695 .50642 L F
.553 .822 .996 r
.76639 .50869 m .76873 .50803 L .76766 .50709 L F
.498 .183 .363 r
.76777 .51033 m .76487 .51232 L .76521 .51095 L F
.487 .285 .532 r
.76639 .50869 m .76643 .51092 L .76873 .50803 L F
.125 0 .229 r
.76931 .51064 m .76777 .51033 L .7702 .50945 L F
.498 .183 .363 r
.76777 .51033 m .7674 .51195 L .76487 .51232 L F
.125 0 .229 r
.76931 .51064 m .7674 .51195 L .76777 .51033 L F
.71 .589 .718 r
.76875 .50939 m .76643 .51092 L .76876 .51057 L F
.76873 .50803 m .76713 .51004 L .76875 .50939 L F
.76713 .51004 m .76643 .51092 L .76875 .50939 L F
.986 .713 .36 r
.76439 .51077 m .76399 .51148 L .76487 .51232 L F
.76393 .50924 m .76398 .51112 L .76439 .51077 L F
.76398 .51112 m .76399 .51148 L .76439 .51077 L F
.522 .313 .538 r
.76155 .51204 m .76399 .51148 L .76393 .50924 L F
.535 .351 .578 r
.76385 .51117 m .76399 .51148 L .76155 .51204 L F
0 0 0 r
.76357 .51146 m .76385 .51117 L .76348 .5115 L F
.521 .312 .537 r
.76399 .51148 m .76639 .50869 L .76393 .50924 L F
.76399 .51148 m .76643 .51092 L .76639 .50869 L F
.556 .417 .647 r
.76789 .5098 m .76399 .51148 L .76385 .51117 L F
0 0 0 r
.76677 .51018 m .76396 .51113 L .76357 .51146 L F
.76396 .51113 m .76385 .51117 L .76357 .51146 L F
.51 .808 .999 r
.76399 .51148 m .7674 .51195 L .76487 .51232 L F
.76399 .51148 m .7674 .51195 L .76487 .51232 L F
.556 .417 .647 r
.76789 .5098 m .76643 .51092 L .76399 .51148 L F
0 0 0 r
.76789 .5098 m .76677 .51018 L .76239 .51247 L F
.76677 .51018 m .76348 .5115 L .76239 .51247 L F
.71 .589 .718 r
.76873 .50803 m .76875 .50932 L .76766 .50709 L F
.76875 .50932 m .76876 .51057 L .76841 .50946 L F
.76875 .50932 m .76841 .50946 L .76766 .50709 L F
.529 .907 .743 r
.76707 .51003 m .76789 .5098 L .76523 .51122 L F
.76841 .50918 m .76804 .50962 L .76707 .51003 L F
.76804 .50962 m .76789 .5098 L .76707 .51003 L F
0 0 .287 r
.7683 .50911 m .76852 .50982 L .76841 .50918 L F
.76852 .50982 m .76876 .51057 L .76869 .51028 L F
.76852 .50982 m .76869 .51028 L .76841 .50918 L F
.714 .718 .853 r
.76876 .51057 m .76789 .5098 L .76841 .50918 L F
0 0 0 r
.76853 .50925 m .76841 .50918 L .76715 .51099 L F
0 0 .512 r
.77082 .50815 m .7702 .50945 L .7697 .50675 L F
.807 .707 .755 r
.76876 .51057 m .77082 .50815 L .76873 .50803 L F
.725 .886 .491 r
.76931 .51064 m .7702 .50945 L .77082 .50815 L F
.807 .707 .755 r
.76876 .51057 m .76931 .51064 L .77082 .50815 L F
.589 .094 .047 r
.76873 .50803 m .77082 .50815 L .7697 .50675 L F
.523 .46 .728 r
.77018 .50427 m .77178 .51009 L .76873 .50803 L F
.382 .464 .82 r
.76873 .50803 m .77178 .51009 L .77149 .5095 L F
.807 .707 .755 r
.76876 .51057 m .76873 .50803 L .77149 .5095 L F
0 0 0 r
.76967 .50781 m .76841 .50918 L .76853 .50925 L F
0 0 .287 r
.76766 .50709 m .7683 .50911 L .76841 .50918 L F
.583 .652 .884 r
.76662 .50654 m .76427 .5086 L .76768 .507 L F
.566 .515 .758 r
.76241 .50122 m .76315 .50659 L .76058 .50631 L F
.633 .592 .791 r
.765 .5008 m .76315 .50659 L .76241 .50122 L F
.765 .5008 m .76653 .50627 L .76315 .50659 L F
.124 0 0 r
.76315 .50659 m .76695 .50642 L .76313 .5086 L F
.76315 .50659 m .76653 .50627 L .76695 .50642 L F
.583 .652 .884 r
.76195 .5045 m .76399 .5081 L .76662 .50654 L F
.481 .847 .99 r
.76695 .50642 m .76474 .50783 L .76325 .50854 L F
.76695 .50642 m .76325 .50854 L .76368 .50829 L F
.583 .652 .884 r
.76399 .5081 m .76427 .5086 L .76662 .50654 L F
.481 .847 .99 r
.76368 .50829 m .76325 .50854 L .76313 .5086 L F
.424 .035 .193 r
.36563 .63276 m .36438 .63485 L .36219 .63514 L F
.513 .174 .33 r
.36794 .63228 m .36438 .63485 L .36563 .63276 L F
.428 .287 .585 r
.68972 .47826 m .68783 .48224 L .68758 .47954 L F
.812 .656 .689 r
.53047 .65308 m .5304 .65557 L .52936 .6527 L F
.878 .671 .619 r
.7304 .48086 m .72761 .48134 L .72812 .47878 L F
.988 .809 .573 r
.7304 .48086 m .72847 .48393 L .72761 .48134 L F
.7304 .48086 m .72962 .48461 L .72847 .48393 L F
.156 0 0 r
.29501 .58926 m .2988 .58735 L .29656 .58768 L F
.409 .124 .366 r
.37816 .62639 m .37605 .62703 L .37868 .62462 L F
.424 .138 .372 r
.38026 .62576 m .37868 .62462 L .38085 .62417 L F
.38026 .62576 m .37816 .62639 L .37868 .62462 L F
.509 .267 .483 r
.59901 .63034 m .59883 .63244 L .5965 .6329 L F
.54 .352 .575 r
.60145 .62756 m .60148 .62985 L .59901 .63034 L F
.521 .298 .516 r
.59901 .63034 m .60124 .63211 L .59883 .63244 L F
.59901 .63034 m .60148 .62985 L .60124 .63211 L F
.394 .807 .978 r
.35811 .58751 m .36022 .58717 L .3617 .58769 L F
.289 .747 .954 r
.36022 .58717 m .36381 .58759 L .3617 .58769 L F
.499 .514 .803 r
.41264 .68725 m .41363 .68955 L .41569 .68916 L F
.723 .73 .856 r
.7456 .52574 m .74185 .52508 L .7438 .52423 L F
.756 .603 .687 r
.70883 .46442 m .71068 .46231 L .7071 .46285 L F
.729 .6 .713 r
.54979 .60965 m .55245 .6136 L .54758 .6127 L F
.158 .349 .804 r
.55271 .61247 m .55245 .6136 L .54979 .60965 L F
.208 0 .304 r
.55297 .61497 m .55245 .6136 L .55271 .61247 L F
.55297 .61497 m .55143 .61632 L .55245 .6136 L F
.62 .686 .89 r
.48507 .65412 m .48628 .65636 L .48832 .65555 L F
.569 .369 .57 r
.48602 .65809 m .48832 .65555 L .48628 .65636 L F
.48602 .65809 m .48832 .65555 L .48628 .65636 L F
.62 .686 .89 r
.48507 .65412 m .48628 .65636 L .48832 .65555 L F
.164 .353 .806 r
.53595 .64119 m .53839 .64324 L .53757 .64396 L F
.25 .502 .9 r
.53839 .64324 m .5396 .64503 L .53757 .64396 L F
.502 .242 .453 r
.51333 .69824 m .5153 .69974 L .51574 .69818 L F
.51333 .69824 m .51285 .70038 L .5153 .69974 L F
.566 .202 .31 r
.68542 .48285 m .68761 .48408 L .68541 .48425 L F
.535 .247 .425 r
.68783 .48224 m .68761 .48408 L .68542 .48285 L F
0 0 0 r
.5293 .60067 m .53219 .59878 L .53282 .59815 L F
.53282 .59815 m .53421 .59778 L .53602 .59708 L F
.53282 .59815 m .53219 .59878 L .53421 .59778 L F
.539 .763 .98 r
.377 .58941 m .37325 .58857 L .37582 .58838 L F
.32 .665 .974 r
.37903 .58953 m .377 .58941 L .37582 .58838 L F
.109 .647 .853 r
.42988 .70934 m .43103 .70909 L .42828 .70649 L F
.42988 .70934 m .43201 .7094 L .43103 .70909 L F
.962 .821 .657 r
.62233 .58053 m .62422 .57927 L .62301 .57836 L F
.62233 .58053 m .62353 .58152 L .62422 .57927 L F
.623 .409 .571 r
.44285 .67767 m .44044 .67582 L .44263 .67468 L F
.44285 .67767 m .43974 .67817 L .44044 .67582 L F
.455 .151 .359 r
.58293 .56133 m .58586 .55844 L .58349 .55865 L F
.909 .789 .716 r
.73757 .49873 m .73855 .49928 L .73785 .49578 L F
.888 .784 .74 r
.73553 .50078 m .73855 .49928 L .73757 .49873 L F
.73553 .50078 m .73691 .5021 L .73855 .49928 L F
.726 .681 .806 r
.73785 .49578 m .73855 .49928 L .74156 .49677 L F
.522 .856 .577 r
.48884 .70287 m .48789 .70384 L .49025 .7039 L F
.48884 .70287 m .48633 .70512 L .48789 .70384 L F
.472 .468 .772 r
.65089 .50372 m .6516 .50564 L .65051 .50177 L F
0 0 .374 r
.6516 .50564 m .65294 .50099 L .65051 .50177 L F
.6516 .50564 m .65303 .50445 L .65294 .50099 L F
.337 .595 .941 r
.6516 .50564 m .65396 .5059 L .65303 .50445 L F
.133 0 0 r
.52037 .70376 m .51675 .70535 L .51719 .7046 L F
.52037 .70376 m .51903 .70511 L .51675 .70535 L F
.267 0 0 r
.52155 .70475 m .52037 .70376 L .52273 .70356 L F
.52155 .70475 m .51903 .70511 L .52037 .70376 L F
.146 0 .054 r
.47458 .63471 m .47717 .63211 L .47553 .63336 L F
.882 .626 .546 r
.6082 .57884 m .60574 .57841 L .60652 .57592 L F
.893 .707 .643 r
.60765 .58119 m .60574 .57841 L .6082 .57884 L F
.736 .877 .946 r
.53238 .63841 m .53017 .63964 L .52882 .63887 L F
.773 .754 .835 r
.57812 .62989 m .58119 .63012 L .58006 .62851 L F
.599 .576 .799 r
.58119 .63012 m .58205 .62641 L .58006 .62851 L F
.58119 .63012 m .58356 .62965 L .58205 .62641 L F
.561 .42 .646 r
.58119 .63012 m .58363 .63232 L .58356 .62965 L F
.58119 .63012 m .5814 .63289 L .58363 .63232 L F
.889 .983 .811 r
.72607 .48396 m .72377 .4869 L .72425 .48762 L F
.896 .851 .398 r
.72386 .487 m .72425 .48762 L .72377 .4869 L F
.72386 .487 m .72346 .49105 L .72425 .48762 L F
.889 .983 .811 r
.72607 .48396 m .72425 .48762 L .72766 .48399 L F
.364 .093 .363 r
.44506 .67217 m .44779 .66967 L .44636 .67154 L F
0 0 0 r
.44411 .67448 m .44506 .67217 L .44636 .67154 L F
.791 .687 .749 r
.42304 .65516 m .42688 .65532 L .42526 .65465 L F
.42304 .65516 m .42435 .65843 L .42688 .65532 L F
.36 .78 .976 r
.42526 .65465 m .4289 .65504 L .42688 .65532 L F
.42526 .65465 m .4289 .65504 L .42688 .65532 L F
.449 .455 .774 r
.59777 .64328 m .59613 .64565 L .59549 .64388 L F
.59777 .64328 m .59853 .64667 L .59613 .64565 L F
.732 .387 .395 r
.70229 .46392 m .70495 .4622 L .70129 .46297 L F
.70229 .46392 m .70356 .46418 L .70495 .4622 L F
.736 .391 .397 r
.70356 .46418 m .70589 .46404 L .70495 .4622 L F
.476 .169 .366 r
.46256 .6441 m .46486 .64372 L .46544 .64194 L F
.436 .132 .349 r
.46544 .64194 m .46708 .64323 L .46757 .64117 L F
.46544 .64194 m .46486 .64372 L .46708 .64323 L F
.509 .21 .394 r
.60679 .54695 m .60957 .54481 L .60689 .54492 L F
.334 .357 .735 r
.74763 .49529 m .74642 .49203 L .74783 .49393 L F
.68 .665 .829 r
.48658 .78044 m .4878 .77662 L .48545 .77706 L F
.48658 .78044 m .49015 .77954 L .4878 .77662 L F
.013 .053 .558 r
.49603 .65091 m .49732 .64858 L .49556 .65001 L F
.49603 .65091 m .49711 .65235 L .4978 .65145 L F
.532 .1 .165 r
.46685 .70472 m .46909 .70582 L .4667 .70577 L F
.687 .262 .233 r
.5296 .69549 m .53181 .69728 L .53308 .69577 L F
.441 0 .039 r
.53181 .69728 m .53546 .69601 L .53308 .69577 L F
.241 0 .05 r
.35189 .62484 m .35328 .62538 L .35425 .62444 L F
.35189 .62484 m .3511 .62611 L .35328 .62538 L F
.59 .855 .994 r
.41052 .70028 m .40631 .7001 L .40882 .70062 L F
.734 .967 .936 r
.40629 .70159 m .41052 .70028 L .40882 .70062 L F
.40629 .70159 m .40699 .70219 L .41052 .70028 L F
.26 0 0 r
.40882 .70062 m .41125 .70055 L .41052 .70028 L F
.40882 .70062 m .41125 .70055 L .41052 .70028 L F
0 0 .053 r
.65119 .49282 m .65248 .48992 L .65173 .49108 L F
.705 .295 .267 r
.51011 .64467 m .51173 .6464 L .50917 .64553 L F
.767 .968 .926 r
.68961 .49746 m .68895 .49945 L .69203 .49709 L F
.826 .996 .762 r
.68961 .49746 m .68752 .50001 L .68895 .49945 L F
.883 .748 .708 r
.62402 .56096 m .62234 .56393 L .62517 .5644 L F
.886 .737 .692 r
.62234 .56393 m .62373 .56725 L .62517 .5644 L F
.421 .743 .993 r
.33207 .58343 m .33139 .58463 L .32989 .58369 L F
.33207 .58343 m .33353 .58448 L .33139 .58463 L F
.989 .723 .381 r
.58366 .64223 m .58252 .64129 L .58246 .63821 L F
.513 .731 .972 r
.58366 .64223 m .58479 .64036 L .58252 .64129 L F
.58366 .64223 m .58635 .64189 L .58479 .64036 L F
.043 0 0 r
.50855 .70528 m .50753 .70527 L .50531 .70519 L F
.44 0 0 r
.50855 .70528 m .51107 .70635 L .50753 .70527 L F
.917 .572 .368 r
.5304 .65557 m .52874 .65657 L .52844 .65482 L F
.435 .8 .995 r
.53254 .65667 m .52874 .65657 L .5304 .65557 L F
.433 .003 .12 r
.53282 .65541 m .53254 .65667 L .5304 .65557 L F
.94 .613 .175 r
.53006 .65465 m .52905 .65448 L .52936 .6527 L F
0 0 0 r
.52936 .6527 m .52905 .65448 L .53006 .65338 L F
.52844 .65482 m .52905 .65448 L .52936 .6527 L F
.786 .428 .379 r
.5278 .6522 m .52905 .65448 L .52432 .6535 L F
.246 .222 .634 r
.53006 .65338 m .52905 .65448 L .5278 .6522 L F
.333 0 .021 r
.53006 .65338 m .52836 .65436 L .52905 .65448 L F
.719 .256 .151 r
.52905 .65448 m .5265 .65542 L .52432 .6535 L F
.333 0 .021 r
.52836 .65436 m .5265 .65542 L .52905 .65448 L F
.94 .613 .175 r
.5304 .65557 m .52905 .65448 L .53006 .65465 L F
.287 0 .101 r
.68895 .47166 m .68594 .47355 L .68847 .47281 L F
.497 .084 .187 r
.68847 .47281 m .69095 .47255 L .68895 .47166 L F
.738 .859 .937 r
.66229 .51352 m .65904 .51364 L .66079 .51293 L F
.43 0 0 r
.66079 .51293 m .66374 .51261 L .66229 .51352 L F
.304 .443 .836 r
.39037 .59212 m .38944 .59387 L .38813 .59073 L F
.406 .572 .904 r
.39037 .59212 m .39211 .59465 L .38944 .59387 L F
0 .093 .646 r
.72938 .5189 m .73107 .52116 L .72988 .51789 L F
.013 .318 .806 r
.50858 .77473 m .51025 .77701 L .51099 .77724 L F
0 .389 .768 r
.51025 .77701 m .51254 .77794 L .51099 .77724 L F
.505 .361 .619 r
.57427 .62693 m .57647 .62641 L .57417 .62448 L F
.638 .33 .434 r
.57417 .62448 m .57647 .62641 L .57603 .62454 L F
.505 .361 .619 r
.57427 .62693 m .57647 .62641 L .57417 .62448 L F
.986 .764 .366 r
.60798 .5874 m .60722 .58656 L .6073 .58406 L F
.986 .726 .445 r
.60798 .5874 m .6067 .58897 L .60722 .58656 L F
.60798 .5874 m .60805 .59003 L .6067 .58897 L F
.217 .741 .794 r
.32193 .58424 m .32408 .58382 L .32569 .58367 L F
.39 0 0 r
.32569 .58367 m .32408 .58382 L .32775 .58411 L F
.425 .085 .284 r
.38606 .62093 m .38301 .62369 L .38387 .62136 L F
.756 .603 .687 r
.70883 .46442 m .71108 .46572 L .71068 .46231 L F
.694 .798 .93 r
.69336 .48168 m .69154 .48305 L .68994 .4814 L F
.68994 .4814 m .69154 .48305 L .69336 .48168 L F
.622 .738 .93 r
.33108 .60086 m .33164 .60181 L .33557 .60062 L F
.592 .509 .73 r
.59164 .65068 m .59397 .64998 L .5931 .64656 L F
.297 .119 .462 r
.59227 .65388 m .59397 .64998 L .59164 .65068 L F
.533 .179 .313 r
.48205 .70346 m .4784 .70569 L .47888 .7045 L F
.404 .216 .509 r
.61345 .60712 m .61297 .6107 L .61181 .61018 L F
.346 .166 .489 r
.61638 .60869 m .61345 .60712 L .61579 .6059 L F
.61638 .60869 m .61297 .6107 L .61345 .60712 L F
.934 .968 .704 r
.42253 .70134 m .42264 .70303 L .42499 .70344 L F
.42253 .70134 m .42163 .70358 L .42264 .70303 L F
.329 .084 .382 r
.72109 .47091 m .72337 .47007 L .72338 .4681 L F
.422 .282 .585 r
.72109 .47091 m .7236 .47211 L .72337 .47007 L F
.72109 .47091 m .72134 .47324 L .7236 .47211 L F
.591 .711 .926 r
.72037 .50986 m .72198 .50687 L .71917 .5083 L F
.72037 .50986 m .72326 .51021 L .72198 .50687 L F
.891 .721 .665 r
.62186 .54965 m .62339 .55082 L .62205 .5473 L F
.891 .757 .707 r
.62186 .54965 m .62253 .5529 L .62339 .55082 L F
.658 .106 0 r
.46237 .69688 m .46457 .69897 L .46593 .69926 L F
.518 0 0 r
.46457 .69897 m .46779 .70002 L .46593 .69926 L F
.235 0 .11 r
.57273 .56952 m .57353 .56773 L .5706 .56984 L F
.416 .125 .359 r
.57273 .56952 m .57524 .5666 L .57353 .56773 L F
.895 .874 .808 r
.71989 .49284 m .72346 .49105 L .72153 .49107 L F
.71989 .49284 m .72097 .49405 L .72346 .49105 L F
.905 .923 .819 r
.72386 .487 m .72153 .49107 L .72346 .49105 L F
.349 .002 .226 r
.69858 .46495 m .70229 .46392 L .70129 .46297 L F
.009 .109 .622 r
.5484 .65884 m .54927 .6582 L .54765 .65463 L F
.587 .419 .621 r
.55127 .65808 m .54898 .66102 L .5484 .65884 L F
.417 .858 .919 r
.55127 .65808 m .54927 .6582 L .5484 .65884 L F
.587 .419 .621 r
.55127 .65808 m .54898 .66102 L .5484 .65884 L F
.634 .798 .961 r
.69349 .49584 m .69701 .49635 L .69595 .49561 L F
.603 .758 .953 r
.69595 .49561 m .69701 .49635 L .69937 .49576 L F
.7 .818 .366 r
.60564 .59585 m .60477 .59744 L .60627 .5943 L F
.404 .62 .939 r
.55247 .63701 m .5534 .63854 L .55454 .63713 L F
.284 .442 .843 r
.5534 .63854 m .55642 .64072 L .55454 .63713 L F
.752 .592 .678 r
.61754 .5414 m .62086 .53924 L .61724 .53891 L F
.61754 .5414 m .62064 .54186 L .62086 .53924 L F
.359 .405 .773 r
.54755 .6459 m .54593 .64804 L .54495 .64692 L F
.54755 .6459 m .54857 .64949 L .54593 .64804 L F
.535 .239 .412 r
.72338 .4681 m .72337 .47007 L .72587 .46942 L F
.655 .571 .749 r
.70971 .48767 m .70754 .48878 L .70611 .48652 L F
.509 .351 .603 r
.76214 .49872 m .76241 .50122 L .75985 .49937 L F
.379 .368 .722 r
.76241 .50122 m .76075 .50157 L .75985 .49937 L F
.685 .793 .932 r
.70158 .49474 m .69937 .49576 L .70273 .49617 L F
.63 .772 .948 r
.70158 .49474 m .70273 .49617 L .70599 .49569 L F
.216 .678 .945 r
.43564 .70889 m .43641 .70833 L .43425 .70842 L F
.43564 .70889 m .4378 .70901 L .43641 .70833 L F
.058 .353 .826 r
.51645 .63413 m .51791 .63494 L .51722 .63576 L F
.161 0 0 r
.51722 .63576 m .52011 .63617 L .51957 .63595 L F
.17 .521 .918 r
.51791 .63494 m .52011 .63617 L .51722 .63576 L F
.88 .813 .778 r
.71639 .50338 m .71915 .50488 L .71698 .50753 L F
.825 .347 .028 r
.71836 .50548 m .71915 .50488 L .71639 .50338 L F
.704 .912 .564 r
.72121 .50174 m .71915 .50488 L .71836 .50548 L F
.605 .79 .97 r
.33399 .62781 m .33212 .62891 L .33018 .62716 L F
.606 .777 .963 r
.36821 .59719 m .36999 .59886 L .37225 .59827 L F
.897 .547 .372 r
.60652 .57592 m .60406 .57504 L .60354 .5729 L F
.914 .667 .55 r
.60652 .57592 m .60402 .57751 L .60406 .57504 L F
.60652 .57592 m .60574 .57841 L .60402 .57751 L F
.784 .789 .856 r
.73028 .50817 m .73057 .50481 L .72937 .50718 L F
.996 .865 .563 r
.72918 .50978 m .73028 .50817 L .72937 .50718 L F
.72918 .50978 m .72994 .51076 L .73028 .50817 L F
.73 .751 .869 r
.73446 .50649 m .73687 .50648 L .73641 .5045 L F
.534 .38 .618 r
.60344 .62679 m .60148 .62985 L .60145 .62756 L F
.257 .707 .957 r
.31834 .82348 m .32054 .82352 L .31681 .82277 L F
.31681 .82277 m .32054 .82352 L .31834 .82348 L F
.31834 .82348 m .32054 .82352 L .31681 .82277 L F
.529 .785 .991 r
.387 .5899 m .38615 .59134 L .3848 .59025 L F
.387 .5899 m .38813 .59073 L .38615 .59134 L F
.41 .085 .302 r
.39876 .6096 m .3957 .61236 L .39602 .61043 L F
.446 .264 .54 r
.57508 .67 m .57716 .66937 L .57721 .66685 L F
.489 .299 .549 r
.57721 .66685 m .57716 .66937 L .57936 .66877 L F
.94 .924 .557 r
.57716 .66937 m .57676 .66867 L .57914 .66876 L F
.57716 .66937 m .57914 .66876 L .57936 .66877 L F
.446 .264 .54 r
.57489 .67029 m .57716 .66937 L .57508 .67 L F
.894 .837 .781 r
.66251 .51831 m .66381 .51958 L .66559 .51679 L F
.522 .727 .967 r
.66559 .51679 m .66724 .51489 L .66473 .51568 L F
.66559 .51679 m .66883 .51629 L .66724 .51489 L F
.685 .469 .588 r
.58796 .62141 m .59042 .62108 L .59041 .61868 L F
.56 .371 .582 r
.59041 .61868 m .5928 .61821 L .59277 .61584 L F
.59 .41 .606 r
.59042 .62108 m .5928 .61821 L .59041 .61868 L F
.667 .586 .756 r
.41417 .69284 m .41434 .69559 L .41646 .69234 L F
.681 .605 .765 r
.41434 .69559 m .41664 .6956 L .41646 .69234 L F
.597 .429 .625 r
.59277 .61584 m .59528 .61542 L .59506 .61287 L F
.61 .424 .605 r
.5928 .61821 m .59528 .61542 L .59277 .61584 L F
.783 .522 .542 r
.67727 .48504 m .67389 .48663 L .67354 .48571 L F
.67727 .48504 m .67711 .48719 L .67389 .48663 L F
.656 .41 .535 r
.67727 .48504 m .67953 .48732 L .67711 .48719 L F
.698 .402 .471 r
.67949 .48528 m .67953 .48732 L .67727 .48504 L F
.894 .774 .722 r
.6624 .50407 m .66412 .50534 L .66413 .50531 L F
.6633 .50351 m .66413 .50531 L .66592 .50187 L F
.6624 .50407 m .66413 .50531 L .6633 .50351 L F
.6624 .50407 m .66592 .50187 L .66438 .50296 L F
.629 .065 0 r
.66174 .49852 m .66481 .50028 L .66169 .50018 L F
.756 .663 .758 r
.66186 .50042 m .66438 .50296 L .66344 .5 L F
.66098 .50065 m .66242 .50163 L .66186 .50042 L F
.66242 .50163 m .66438 .50296 L .66186 .50042 L F
0 0 .463 r
.66481 .50028 m .66567 .50143 L .66592 .50187 L F
.783 .982 .719 r
.66567 .50143 m .66438 .50296 L .66592 .50187 L F
.534 .26 .446 r
.68202 .48496 m .67953 .48732 L .67949 .48528 L F
.234 .277 .703 r
.46138 .67284 m .46288 .67515 L .46206 .67164 L F
.272 .712 .963 r
.34298 .58552 m .34537 .58552 L .34668 .58626 L F
.428 0 0 r
.34537 .58552 m .34868 .58645 L .34668 .58626 L F
.961 .658 .413 r
.55399 .76196 m .55506 .76133 L .55374 .76054 L F
.55399 .76196 m .55542 .76299 L .55506 .76133 L F
.616 .636 .847 r
.27935 .61882 m .28304 .62159 L .28163 .6182 L F
.605 .599 .819 r
.28163 .6182 m .28304 .62159 L .28558 .62108 L F
.77 .49 .51 r
.28304 .62159 m .28608 .62408 L .28558 .62108 L F
.28304 .62159 m .28282 .62389 L .28608 .62408 L F
.571 .272 .422 r
.43346 .66057 m .43585 .6606 L .43629 .65871 L F
.521 .238 .425 r
.43585 .6606 m .43861 .65835 L .43629 .65871 L F
.269 0 0 r
.66071 .48048 m .65965 .4813 L .66389 .48056 L F
.466 .867 .964 r
.74063 .53312 m .74199 .53209 L .73971 .53195 L F
.74063 .53312 m .74279 .53251 L .74199 .53209 L F
0 0 0 r
.48465 .64309 m .4838 .64349 L .48585 .64142 L F
0 .346 .823 r
.48585 .64142 m .48695 .64122 L .48465 .64309 L F
.28 0 .228 r
.37816 .62639 m .37556 .6286 L .37605 .62703 L F
.294 .095 .43 r
.61297 .6107 m .61203 .61209 L .61181 .61018 L F
0 .351 .824 r
.73721 .53044 m .73971 .53195 L .73887 .53072 L F
.513 .249 .452 r
.40133 .60718 m .401 .60926 L .39876 .6096 L F
.482 .248 .483 r
.40338 .60662 m .401 .60926 L .40133 .60718 L F
.618 .602 .812 r
.2759 .61578 m .27674 .61194 L .27517 .61264 L F
.2759 .61578 m .27817 .61514 L .27674 .61194 L F
.079 0 0 r
.32964 .60203 m .32872 .60154 L .33108 .60086 L F
.32964 .60203 m .32758 .60283 L .32872 .60154 L F
.555 .36 .571 r
.51919 .78068 m .52208 .78097 L .52146 .77793 L F
.495 .321 .574 r
.52146 .77793 m .52208 .78097 L .52374 .77992 L F
.501 .543 .831 r
.75909 .48595 m .75732 .48808 L .75608 .48501 L F
.516 .564 .843 r
.75977 .48777 m .75732 .48808 L .75909 .48595 L F
.478 .113 .267 r
.68053 .47868 m .68302 .47849 L .68369 .47633 L F
.446 .246 .515 r
.68369 .47633 m .68586 .4756 L .68594 .47355 L F
.553 .267 .434 r
.68302 .47849 m .68586 .4756 L .68369 .47633 L F
.681 .517 .658 r
.7438 .52423 m .74027 .5218 L .74447 .52204 L F
.7438 .52423 m .74185 .52508 L .74027 .5218 L F
.573 .414 .628 r
.59506 .61287 m .59755 .61242 L .59729 .60998 L F
.567 .403 .619 r
.59528 .61542 m .59755 .61242 L .59506 .61287 L F
.518 .359 .604 r
.36476 .616 m .36701 .61549 L .3668 .61268 L F
.45 .193 .432 r
.36476 .616 m .36647 .6176 L .36701 .61549 L F
.36476 .616 m .36436 .61814 L .36647 .6176 L F
.134 0 0 r
.3494 .64076 m .34944 .64171 L .34748 .64231 L F
.3494 .64076 m .35158 .64027 L .34944 .64171 L F
.313 .789 .918 r
.34399 .60005 m .34379 .59982 L .34158 .60017 L F
.101 0 0 r
.34379 .59982 m .34282 .59998 L .34158 .60017 L F
.149 .678 .868 r
.34106 .60049 m .34158 .60017 L .34007 .60039 L F
.101 0 0 r
.34282 .59998 m .34001 .60044 L .34158 .60017 L F
.149 .678 .868 r
.34007 .60039 m .34158 .60017 L .33945 .60033 L F
.34106 .60049 m .34304 .60046 L .34158 .60017 L F
.68 .702 .864 r
.72414 .51103 m .72521 .50733 L .72326 .51021 L F
.72414 .51103 m .72708 .51001 L .72521 .50733 L F
.547 .326 .532 r
.37193 .60696 m .37359 .60844 L .37331 .6064 L F
.37193 .60696 m .37142 .60938 L .37359 .60844 L F
.468 .214 .445 r
.28207 .64455 m .28389 .64418 L .2849 .64182 L F
.126 0 .249 r
.2849 .64182 m .28389 .64418 L .28632 .64074 L F
.817 .48 .419 r
.71108 .46572 m .71071 .46721 L .70883 .46442 L F
.272 0 .252 r
.71071 .46721 m .71394 .46431 L .71108 .46572 L F
.372 0 0 r
.44779 .66967 m .44905 .67053 L .44636 .67154 L F
.44779 .66967 m .45024 .67008 L .44905 .67053 L F
.569 .25 .389 r
.60137 .54978 m .60424 .54955 L .60452 .54759 L F
.608 .378 .542 r
.60424 .54955 m .60679 .54695 L .60452 .54759 L F
.487 .57 .865 r
.74917 .50548 m .75275 .50761 L .75091 .50363 L F
.65 .633 .819 r
.65294 .50099 m .65643 .50192 L .65527 .49894 L F
.668 .422 .539 r
.65294 .50099 m .65601 .50371 L .65643 .50192 L F
.586 .271 .402 r
.65595 .50373 m .65476 .50402 L .6564 .50371 L F
.65476 .50402 m .65303 .50445 L .65428 .50418 L F
.65476 .50402 m .65428 .50418 L .6564 .50371 L F
.65697 .50331 m .65548 .50374 L .65654 .50368 L F
.701 .572 .707 r
.65697 .50331 m .65618 .50386 L .65626 .50354 L F
.711 .959 .947 r
.65682 .50292 m .65819 .50406 L .65643 .50192 L F
.65756 .50367 m .65819 .50406 L .65682 .50292 L F
.29 .349 .751 r
.65819 .50406 m .65882 .50092 L .65643 .50192 L F
.716 .668 .801 r
.65527 .49894 m .65643 .50192 L .65882 .50092 L F
.65527 .49894 m .65882 .50092 L .65734 .49919 L F
.701 .572 .707 r
.65697 .50331 m .65626 .50354 L .65734 .49919 L F
.586 .271 .402 r
.65644 .50376 m .65303 .50445 L .65396 .5059 L F
.65654 .50368 m .6564 .50371 L .65644 .50376 L F
.6564 .50371 m .65303 .50445 L .65644 .50376 L F
.668 .422 .539 r
.65601 .50371 m .6562 .5037 L .65643 .50192 L F
.934 .824 .712 r
.6565 .50259 m .65626 .50354 L .6551 .50118 L F
.586 .271 .402 r
.65697 .50331 m .65555 .50549 L .65479 .50518 L F
.668 .422 .539 r
.65601 .50371 m .65303 .50445 L .65618 .50386 L F
.65294 .50099 m .65303 .50445 L .65601 .50371 L F
.586 .271 .402 r
.65548 .50374 m .65303 .50445 L .65595 .50373 L F
.65625 .50352 m .65605 .50374 L .65303 .50445 L F
.694 .823 .944 r
.65605 .50374 m .65303 .50445 L .65421 .50197 L F
.65618 .50386 m .65303 .50445 L .65605 .50374 L F
.586 .271 .402 r
.65605 .50374 m .65479 .50518 L .65303 .50445 L F
.934 .824 .712 r
.65626 .50354 m .65618 .50386 L .65611 .50368 L F
.65626 .50354 m .65611 .50368 L .65625 .50352 L F
.586 .271 .402 r
.65638 .50369 m .6564 .50371 L .65654 .50368 L F
.65548 .50374 m .6564 .50371 L .65638 .50369 L F
.934 .824 .712 r
.65469 .50154 m .65618 .50386 L .65421 .50197 L F
.668 .422 .539 r
.65601 .50371 m .65618 .50386 L .6562 .5037 L F
.934 .824 .712 r
.65583 .50299 m .65618 .50386 L .65469 .50154 L F
.586 .271 .402 r
.65697 .50331 m .65479 .50518 L .65625 .50352 L F
.934 .824 .712 r
.65625 .50352 m .65611 .50368 L .65583 .50299 L F
.65626 .50354 m .65583 .50299 L .6551 .50118 L F
.6551 .50118 m .65583 .50299 L .65469 .50154 L F
.65734 .49919 m .6565 .50259 L .6551 .50118 L F
.711 .959 .947 r
.65697 .50331 m .65756 .50367 L .65698 .50308 L F
0 0 0 r
.65802 .50265 m .65694 .50388 L .65697 .50331 L F
.65694 .50388 m .65555 .50549 L .65697 .50331 L F
.711 .959 .947 r
.65697 .50331 m .65698 .50308 L .65682 .50292 L F
.29 .349 .751 r
.65819 .50406 m .65878 .50256 L .65882 .50092 L F
.65819 .50406 m .65974 .50492 L .65878 .50256 L F
.396 .152 .423 r
.70291 .46836 m .70263 .47024 L .70048 .4713 L F
.379 .168 .463 r
.70291 .46836 m .70467 .46943 L .70263 .47024 L F
.606 .578 .796 r
.53845 .69645 m .53922 .69802 L .53672 .69825 L F
.455 .298 .579 r
.5388 .70011 m .53672 .69825 L .53922 .69802 L F
.5388 .70011 m .53674 .70074 L .53672 .69825 L F
0 0 .115 r
.6611 .48761 m .65967 .48802 L .66178 .4867 L F
.6611 .48761 m .65899 .48993 L .65967 .48802 L F
.539 .328 .542 r
.59883 .63244 m .59642 .63518 L .5965 .6329 L F
.827 .619 .622 r
.64144 .49894 m .64124 .50139 L .64422 .50132 L F
.832 .702 .72 r
.64124 .50139 m .6425 .50487 L .64422 .50132 L F
.478 .61 .904 r
.32391 .62537 m .32392 .62792 L .32111 .62447 L F
.41 .55 .885 r
.32487 .62671 m .32392 .62792 L .32391 .62537 L F
.452 .789 .999 r
.32502 .62782 m .32392 .62792 L .32487 .62671 L F
.273 0 0 r
.47628 .65072 m .47546 .64915 L .47771 .64883 L F
.47628 .65072 m .47407 .65122 L .47546 .64915 L F
.533 .179 .313 r
.48205 .70346 m .48073 .70582 L .4784 .70569 L F
.566 .515 .758 r
.76241 .50122 m .76058 .50631 L .76075 .50157 L F
.572 .272 .421 r
.76058 .50631 m .76315 .50659 L .76313 .5086 L F
.493 .494 .786 r
.43973 .6804 m .4392 .68417 L .4377 .68059 L F
.43973 .6804 m .44087 .68347 L .4392 .68417 L F
.311 .08 .392 r
.44087 .68347 m .43868 .68638 L .4392 .68417 L F
.816 .863 .883 r
.66883 .51629 m .67159 .51612 L .67052 .51466 L F
.814 .825 .859 r
.67052 .51466 m .67159 .51612 L .67401 .51357 L F
.94 .822 .373 r
.3042 .64431 m .30376 .64425 L .3037 .64327 L F
.158 .349 .804 r
.55271 .61247 m .54979 .60965 L .55302 .6102 L F
0 0 .23 r
.55404 .61108 m .55302 .6102 L .55554 .60986 L F
.55404 .61108 m .55271 .61247 L .55302 .6102 L F
0 0 .08 r
.56439 .60159 m .5647 .60292 L .56313 .60386 L F
.56561 .59791 m .5656 .59907 L .56439 .60159 L F
0 0 .118 r
.56439 .60159 m .5656 .59907 L .5647 .60292 L F
.731 .471 .534 r
.59645 .56734 m .59305 .5699 L .59463 .56729 L F
.537 .385 .623 r
.27517 .5989 m .27742 .60098 L .27758 .59838 L F
.27517 .5989 m .27528 .60151 L .27742 .60098 L F
.56 .445 .68 r
.59642 .63518 m .5943 .63776 L .59414 .63567 L F
.555 .82 .995 r
.66913 .5046 m .6704 .50305 L .67138 .50402 L F
.655 .971 .867 r
.66913 .5046 m .66847 .50442 L .6704 .50305 L F
.803 .606 .636 r
.60393 .57038 m .60028 .57228 L .60051 .5699 L F
.60393 .57038 m .60354 .5729 L .60028 .57228 L F
.77 .446 .437 r
.52391 .69489 m .52625 .69745 L .52728 .69516 L F
.61 .263 .357 r
.52625 .69745 m .5296 .69549 L .52728 .69516 L F
.372 .064 .307 r
.56802 .57283 m .57017 .57221 L .5706 .56984 L F
.321 .093 .404 r
.57246 .57164 m .5706 .56984 L .57017 .57221 L F
.57246 .57164 m .57273 .56952 L .5706 .56984 L F
.547 .451 .698 r
.27377 .60714 m .27556 .60395 L .27338 .60443 L F
.27377 .60714 m .27608 .60677 L .27556 .60395 L F
.481 .396 .682 r
.27456 .61012 m .27608 .60677 L .27377 .60714 L F
.841 .873 .866 r
.74437 .53152 m .74835 .52997 L .74791 .52968 L F
.831 .987 .717 r
.74791 .52968 m .74835 .52997 L .75047 .52711 L F
.514 .198 .369 r
.58429 .67303 m .58405 .67475 L .58168 .67497 L F
.479 .155 .338 r
.58742 .67183 m .58405 .67475 L .58429 .67303 L F
.434 .276 .566 r
.49053 .65625 m .48832 .65555 L .49186 .6556 L F
.798 .987 .732 r
.49237 .65394 m .49053 .65625 L .49186 .6556 L F
.941 .919 .548 r
.46685 .67206 m .46607 .67497 L .4688 .67271 L F
.575 .522 .759 r
.47402 .6721 m .47146 .67287 L .47363 .66969 L F
.47 .192 .409 r
.47402 .6721 m .47098 .67454 L .47146 .67287 L F
.47402 .6721 m .47323 .67409 L .47098 .67454 L F
.572 .533 .773 r
.47098 .67454 m .47323 .67409 L .47225 .67166 L F
.798 .846 .887 r
.47363 .66969 m .47146 .67287 L .4697 .67128 L F
.572 .533 .773 r
.47162 .67165 m .47225 .67166 L .47185 .67066 L F
.442 .725 .986 r
.46948 .67163 m .47146 .67287 L .4688 .67271 L F
.584 .274 .408 r
.47146 .67287 m .47098 .67454 L .4688 .67271 L F
.572 .533 .773 r
.47098 .67454 m .47225 .67166 L .47162 .67165 L F
.442 .725 .986 r
.4697 .67128 m .47009 .67164 L .46948 .67163 L F
.47009 .67164 m .47146 .67287 L .46948 .67163 L F
.107 .275 .753 r
.4688 .67271 m .47098 .67454 L .4697 .67128 L F
0 0 0 r
.46325 .65941 m .46193 .66062 L .46025 .66119 L F
.637 .536 .723 r
.46193 .66062 m .46023 .66309 L .46025 .66119 L F
.033 0 0 r
.35778 .59862 m .35721 .59897 L .35514 .59938 L F
0 0 0 r
.36019 .59799 m .35924 .59826 L .35778 .59862 L F
.35924 .59826 m .35721 .59897 L .35778 .59862 L F
.24 0 0 r
.30087 .58673 m .303 .58623 L .30457 .58454 L F
.355 0 .101 r
.303 .58623 m .30665 .58385 L .30457 .58454 L F
.399 .036 .228 r
.44636 .65497 m .44858 .65454 L .44963 .65222 L F
.508 .185 .354 r
.44858 .65454 m .45179 .65174 L .44963 .65222 L F
.466 .274 .536 r
.48926 .79252 m .48658 .79529 L .48883 .7948 L F
.468 .28 .542 r
.48883 .7948 m .48658 .79529 L .48675 .79746 L F
.451 .79 .998 r
.3682 .58694 m .36748 .58811 L .36602 .58731 L F
.3682 .58694 m .3696 .5878 L .36748 .58811 L F
.409 0 0 r
.47288 .70483 m .47144 .70593 L .46909 .70582 L F
.363 0 0 r
.47505 .70542 m .47144 .70593 L .47288 .70483 L F
.488 .065 .163 r
.54711 .65581 m .54494 .65545 L .54512 .65485 L F
.879 .521 .366 r
.54768 .65469 m .54927 .6582 L .54711 .65581 L F
.488 .065 .163 r
.5473 .6559 m .54709 .65586 L .54711 .65581 L F
.54709 .65586 m .54494 .65545 L .54711 .65581 L F
.879 .521 .366 r
.54711 .65581 m .54927 .6582 L .54669 .65673 L F
.54765 .65463 m .54768 .65469 L .54711 .65581 L F
.488 .065 .163 r
.54709 .65586 m .54664 .6567 L .54494 .65545 L F
.879 .521 .366 r
.5471 .65583 m .54669 .65673 L .54664 .6567 L F
.488 .065 .163 r
.5473 .6559 m .54664 .6567 L .54709 .65586 L F
.488 .078 .189 r
.54765 .65463 m .54711 .65581 L .54512 .65485 L F
.879 .521 .366 r
.54765 .65463 m .5471 .65583 L .54664 .6567 L F
.488 .078 .189 r
.54765 .65463 m .5473 .6559 L .54711 .65581 L F
.807 .332 .083 r
.55188 .76618 m .55037 .76574 L .54858 .76331 L F
0 .114 .658 r
.54858 .76331 m .55037 .76574 L .54912 .76253 L F
.607 .634 .852 r
.27978 .64963 m .27749 .65032 L .2762 .64798 L F
.2762 .64798 m .27749 .65032 L .27978 .64963 L F
.333 .396 .778 r
.558 .64723 m .56065 .64903 L .55985 .64584 L F
.527 .623 .891 r
.75089 .49869 m .75162 .49563 L .74939 .49603 L F
.75089 .49869 m .75341 .4984 L .75162 .49563 L F
.407 .465 .808 r
.75089 .49869 m .75335 .50157 L .75341 .4984 L F
.424 .865 .904 r
.31839 .647 m .31605 .6473 L .31567 .64749 L F
0 .045 .536 r
.31839 .647 m .31896 .64748 L .31605 .6473 L F
.4 .663 .966 r
.31605 .6473 m .31896 .64748 L .31795 .64629 L F
.31605 .6473 m .31795 .64629 L .31726 .64549 L F
.424 .865 .904 r
.31567 .64749 m .31605 .6473 L .31488 .64764 L F
0 .045 .536 r
.31839 .647 m .32021 .64866 L .31896 .64748 L F
.359 0 0 r
.49834 .70201 m .50068 .70216 L .50182 .70086 L F
.621 .14 .089 r
.50068 .70216 m .5043 .70244 L .50182 .70086 L F
.601 .215 .284 r
.50182 .70086 m .5043 .70244 L .5043 .7013 L F
.866 .48 .31 r
.52011 .63617 m .52273 .63606 L .51957 .63595 L F
.52011 .63617 m .52177 .63764 L .52273 .63606 L F
.661 .218 .188 r
.52273 .63606 m .52177 .63764 L .52526 .63783 L F
.553 0 0 r
.52273 .63606 m .52526 .63783 L .52674 .63837 L F
.463 .316 .596 r
.63666 .50485 m .63873 .50438 L .63799 .50208 L F
.622 .466 .65 r
.5819 .62622 m .58233 .62392 L .57992 .6238 L F
.58205 .62641 m .58209 .62606 L .5819 .62622 L F
.58209 .62606 m .58233 .62392 L .5819 .62622 L F
.58205 .62641 m .5819 .62622 L .58175 .62592 L F
.5819 .62622 m .57992 .6238 L .58175 .62592 L F
.728 .643 .764 r
.57647 .62641 m .57956 .62822 L .58175 .62592 L F
.57956 .62822 m .58006 .62851 L .58112 .62689 L F
.57956 .62822 m .58112 .62689 L .58175 .62592 L F
.658 .343 .428 r
.57603 .62454 m .58175 .62592 L .57992 .6238 L F
.57603 .62454 m .57647 .62641 L .58175 .62592 L F
.891 .757 .707 r
.62186 .54965 m .62008 .55256 L .62253 .5529 L F
.86 .658 .628 r
.61974 .55493 m .62253 .5529 L .62008 .55256 L F
.61974 .55493 m .62155 .55592 L .62253 .5529 L F
.019 .513 .872 r
.30894 .6464 m .31222 .64785 L .31128 .64708 L F
.538 .672 .924 r
.31222 .64785 m .31325 .64584 L .31128 .64708 L F
.31222 .64785 m .31488 .64764 L .31325 .64584 L F
.481 .396 .682 r
.27456 .61012 m .27649 .60958 L .27608 .60677 L F
.474 .374 .661 r
.27456 .61012 m .27674 .61194 L .27649 .60958 L F
.434 .374 .691 r
.27517 .61264 m .27674 .61194 L .27456 .61012 L F
.091 .24 .726 r
.56467 .66315 m .56383 .66021 L .56414 .66126 L F
.587 .85 .5 r
.55646 .58504 m .55549 .58615 L .55772 .58349 L F
.313 .338 .727 r
.48155 .64949 m .48373 .65157 L .48457 .64929 L F
.082 .147 .633 r
.59074 .64722 m .59182 .64579 L .59086 .64404 L F
.585 .867 .995 r
.59074 .64722 m .5931 .64656 L .59182 .64579 L F
.605 .279 .391 r
.59293 .5524 m .5954 .55233 L .59632 .55011 L F
.671 .349 .42 r
.59632 .55011 m .59876 .55225 L .59888 .55023 L F
.59632 .55011 m .5954 .55233 L .59876 .55225 L F
0 .041 .557 r
.41646 .69234 m .41664 .6956 L .41783 .6942 L F
.42 .179 .44 r
.41805 .6986 m .41978 .69946 L .42029 .69763 L F
.41805 .6986 m .41978 .69946 L .42029 .69763 L F
.076 .19 .681 r
.41664 .6956 m .41832 .69884 L .41783 .6942 L F
.827 .924 .899 r
.55742 .6204 m .55559 .62174 L .55804 .6194 L F
.704 .738 .877 r
.56011 .61818 m .55742 .6204 L .55804 .6194 L F
.738 .508 .58 r
.60041 .56744 m .59666 .56961 L .59645 .56734 L F
.60041 .56744 m .60051 .5699 L .59666 .56961 L F
.717 .319 .295 r
.66389 .48056 m .66532 .48118 L .66649 .47938 L F
.616 .201 .234 r
.66649 .47938 m .66532 .48118 L .66894 .48094 L F
.587 .25 .366 r
.66649 .47938 m .66894 .48094 L .66892 .47938 L F
.71 .779 .907 r
.72198 .50687 m .72326 .51021 L .72521 .50733 L F
.738 .571 .667 r
.56167 .6256 m .5605 .62699 L .55897 .62429 L F
.903 .574 .089 r
.56257 .62572 m .56392 .62931 L .56167 .6256 L F
.434 .726 .987 r
.33766 .58365 m .33715 .5852 L .33565 .58409 L F
.33766 .58365 m .33923 .58506 L .33715 .5852 L F
.504 .324 .57 r
.31335 .61262 m .31335 .6147 L .31116 .61503 L F
.524 .437 .698 r
.31335 .6147 m .31179 .6187 L .31116 .61503 L F
.013 .318 .806 r
.50858 .77473 m .51099 .77724 L .51255 .77486 L F
.715 .497 .592 r
.51099 .77724 m .51254 .77794 L .51255 .77486 L F
.489 .07 .172 r
.45298 .66931 m .45271 .67009 L .45024 .67008 L F
.464 .403 .704 r
.45472 .66618 m .45497 .66904 L .45298 .66931 L F
.463 .15 .348 r
.45497 .66904 m .45271 .67009 L .45298 .66931 L F
.334 .357 .735 r
.74763 .49529 m .74785 .49126 L .74642 .49203 L F
.74763 .49529 m .74939 .49603 L .74785 .49126 L F
.743 .661 .769 r
.27943 .63534 m .28083 .63866 L .28416 .63588 L F
.772 .664 .743 r
.49652 .66152 m .49355 .6616 L .49495 .65899 L F
.603 .648 .867 r
.49648 .66326 m .49355 .6616 L .49652 .66152 L F
.705 .642 .784 r
.49892 .66121 m .49652 .66152 L .49495 .65899 L F
.633 .424 .581 r
.49892 .66121 m .49648 .66326 L .49652 .66152 L F
.635 .149 .081 r
.5026 .70586 m .50199 .70665 L .49973 .70573 L F
.145 0 0 r
.50531 .70519 m .50414 .706 L .5026 .70586 L F
.148 0 0 r
.50414 .706 m .50199 .70665 L .5026 .70586 L F
.516 .794 .996 r
.28207 .64455 m .28266 .6431 L .28055 .64411 L F
.28207 .64455 m .28389 .64418 L .28266 .6431 L F
.28207 .64455 m .28266 .6431 L .28055 .64411 L F
.28207 .64455 m .28389 .64418 L .28266 .6431 L F
.428 .274 .568 r
.41379 .67847 m .41574 .67798 L .41566 .67565 L F
.482 .391 .676 r
.41416 .68094 m .41574 .67798 L .41379 .67847 L F
.773 .361 .268 r
.70048 .4713 m .69953 .47264 L .69757 .47208 L F
.645 .362 .476 r
.70263 .47024 m .69953 .47264 L .70048 .4713 L F
.085 .554 .904 r
.52758 .63797 m .52674 .63837 L .52526 .63783 L F
.52758 .63797 m .52882 .63887 L .52674 .63837 L F
.833 .901 .887 r
.5292 .64975 m .52936 .6527 L .53107 .65122 L F
.5292 .64975 m .5278 .6522 L .52936 .6527 L F
0 0 0 r
.52936 .6527 m .53006 .65338 L .53107 .65122 L F
.906 .913 .814 r
.68634 .48979 m .68759 .48637 L .68878 .48749 L F
.68634 .48979 m .685 .48893 L .68759 .48637 L F
.71 .535 .65 r
.61754 .5414 m .62063 .54391 L .62064 .54186 L F
0 0 0 r
.62069 .59388 m .62053 .59316 L .62118 .59151 L F
.62069 .59388 m .61976 .5956 L .62053 .59316 L F
.532 .395 .639 r
.41555 .67242 m .41795 .67478 L .41765 .67193 L F
.41555 .67242 m .41566 .67565 L .41795 .67478 L F
.928 .793 .69 r
.62303 .57195 m .62419 .57534 L .62429 .57289 L F
.556 .4 .625 r
.49622 .79768 m .4962 .80051 L .49383 .80053 L F
0 0 0 r
.49622 .79768 m .49383 .80053 L .49515 .80003 L F
.227 .716 .924 r
.49383 .80053 m .4962 .80051 L .49515 .80003 L F
.618 .641 .851 r
.50807 .65113 m .50947 .6545 L .51197 .65382 L F
0 0 0 r
.3597 .63721 m .36052 .63628 L .36219 .63514 L F
.643 .849 .979 r
.66027 .51944 m .66381 .51958 L .66251 .51831 L F
.814 .947 .596 r
.29073 .63994 m .29041 .64138 L .29185 .63885 L F
.774 .839 .38 r
.28967 .64313 m .29041 .64138 L .29073 .63994 L F
.513 .289 .511 r
.3957 .61236 m .39324 .61508 L .39364 .61297 L F
.076 0 0 r
.27441 .64815 m .27345 .6485 L .2762 .64798 L F
.866 .759 .742 r
.28539 .63279 m .28228 .63346 L .28276 .63177 L F
.28539 .63279 m .28416 .63588 L .28228 .63346 L F
.123 .378 .835 r
.59086 .64404 m .58817 .64088 L .5889 .64207 L F
0 0 0 r
.55772 .58349 m .56034 .58075 L .55874 .58166 L F
.518 .393 .649 r
.41264 .68725 m .4147 .68687 L .4147 .68362 L F
.499 .514 .803 r
.41264 .68725 m .41569 .68916 L .4147 .68687 L F
0 0 .053 r
.65119 .49282 m .65259 .49141 L .65248 .48992 L F
0 0 0 r
.65248 .48992 m .65449 .48779 L .65504 .48637 L F
0 0 .052 r
.65248 .48992 m .65259 .49141 L .65449 .48779 L F
.826 .469 0 r
.49282 .63517 m .49417 .63825 L .49345 .63709 L F
0 .218 .714 r
.49417 .63825 m .49443 .63792 L .49345 .63709 L F
.49417 .63825 m .49555 .63924 L .49443 .63792 L F
.731 .25 .101 r
.41543 .70225 m .41884 .70436 L .41581 .70347 L F
.343 .769 .973 r
.53668 .60392 m .53885 .60364 L .53531 .60323 L F
.53531 .60323 m .53885 .60364 L .53668 .60392 L F
.86 .954 .871 r
.71766 .49651 m .71984 .49592 L .71885 .49465 L F
.909 .911 .81 r
.71885 .49465 m .71984 .49592 L .72097 .49405 L F
.705 .642 .784 r
.49892 .66121 m .49495 .65899 L .49706 .65892 L F
.633 .424 .581 r
.49892 .66121 m .49906 .66389 L .49648 .66326 L F
.985 .72 .341 r
.49932 .66392 m .49906 .66389 L .49892 .66121 L F
.919 .962 .792 r
.50107 .66077 m .49935 .66409 L .49892 .66121 L F
.985 .72 .341 r
.49935 .66409 m .49906 .66389 L .49932 .66392 L F
.919 .962 .792 r
.50107 .66077 m .49906 .66389 L .49935 .66409 L F
.101 0 .257 r
.50035 .66295 m .49906 .66389 L .50036 .66188 L F
.50035 .66295 m .50036 .66188 L .50107 .66077 L F
.625 .468 .649 r
.50256 .66654 m .50016 .6669 L .50244 .66402 L F
.50256 .66654 m .50016 .6669 L .50244 .66402 L F
.759 .552 .617 r
.50369 .6697 m .50016 .6669 L .50256 .66654 L F
.50369 .6697 m .5001 .66968 L .50016 .6669 L F
0 0 .32 r
.50016 .6669 m .50111 .66804 L .50256 .66654 L F
.50016 .6669 m .50011 .66918 L .50111 .66804 L F
.50011 .66918 m .5001 .66968 L .50111 .66804 L F
.115 .244 .721 r
.50256 .66654 m .50474 .66846 L .50369 .6697 L F
.662 .193 .129 r
.50111 .66804 m .50474 .66846 L .50256 .66654 L F
.875 .919 .853 r
.50111 .66804 m .50224 .66428 L .50251 .66696 L F
.651 .575 .756 r
.50196 .66706 m .50111 .66804 L .50251 .66696 L F
.875 .919 .853 r
.50111 .66804 m .49976 .66748 L .5009 .66601 L F
.50111 .66804 m .5009 .66601 L .5019 .66541 L F
.651 .575 .756 r
.49976 .66748 m .50111 .66804 L .50196 .66706 L F
.568 .208 .317 r
.50035 .66295 m .50153 .66563 L .50035 .66522 L F
0 0 .307 r
.50045 .6631 m .50151 .66557 L .50035 .66295 L F
.50151 .66557 m .50166 .66593 L .50153 .66563 L F
.50151 .66557 m .50153 .66563 L .50035 .66295 L F
.875 .919 .853 r
.5019 .66541 m .50153 .66563 L .50224 .66428 L F
.568 .208 .317 r
.50153 .66563 m .50133 .66575 L .50035 .66522 L F
.50035 .66295 m .49838 .66381 L .49906 .66389 L F
.158 .699 .758 r
.49906 .66389 m .49562 .66435 L .49648 .66326 L F
.568 .208 .317 r
.49838 .66381 m .49804 .66396 L .49906 .66389 L F
.50035 .66295 m .50035 .66522 L .49804 .66396 L F
.824 .421 .285 r
.49849 .66398 m .50112 .6656 L .50045 .6631 L F
.875 .919 .853 r
.50153 .66563 m .50122 .66559 L .50151 .66557 L F
.568 .208 .317 r
.50153 .66563 m .50166 .66593 L .50133 .66575 L F
.576 .432 .649 r
.50251 .66696 m .50235 .66699 L .50224 .66428 L F
.875 .919 .853 r
.50153 .66563 m .5009 .66601 L .50122 .66559 L F
0 .273 .695 r
.49804 .66396 m .50166 .66593 L .50134 .66574 L F
.49824 .66397 m .50134 .66574 L .49849 .66398 L F
.49804 .66396 m .50134 .66574 L .49824 .66397 L F
.576 .432 .649 r
.50235 .66699 m .49976 .66748 L .50118 .66565 L F
.50134 .66574 m .50118 .66565 L .50122 .66559 L F
.50235 .66699 m .50118 .66565 L .50134 .66574 L F
.824 .421 .285 r
.50122 .66559 m .50166 .66593 L .50151 .66557 L F
.50134 .66574 m .50166 .66593 L .50122 .66559 L F
.50112 .6656 m .50151 .66557 L .50045 .6631 L F
.875 .919 .853 r
.50151 .66557 m .50122 .66559 L .50142 .66534 L F
.50153 .66563 m .50142 .66534 L .50224 .66428 L F
.576 .432 .649 r
.50235 .66699 m .50122 .66559 L .50224 .66428 L F
.824 .421 .285 r
.50112 .6656 m .50134 .66574 L .50122 .66559 L F
.799 .574 .597 r
.49845 .66004 m .49839 .66056 L .49706 .65892 L F
.634 .292 .376 r
.49495 .65899 m .49845 .66004 L .49706 .65892 L F
.49495 .65899 m .49461 .66061 L .49845 .66004 L F
.245 0 0 r
.49413 .66235 m .49845 .66004 L .49461 .66061 L F
.49777 .6604 m .4963 .66195 L .49845 .66004 L F
.49413 .66235 m .4963 .66195 L .49777 .6604 L F
.91 .982 .734 r
.49355 .6616 m .49184 .66433 L .49233 .66268 L F
.733 .589 .695 r
.49233 .66268 m .49562 .66435 L .49413 .66235 L F
.535 .691 .94 r
.49562 .66435 m .4963 .66195 L .49413 .66235 L F
.838 .48 .377 r
.4963 .66195 m .49485 .66361 L .49481 .66352 L F
.322 .043 .326 r
.49233 .66268 m .49461 .66061 L .49355 .6616 L F
.49233 .66268 m .49413 .66235 L .49461 .66061 L F
.838 .48 .377 r
.4963 .66195 m .49481 .66352 L .49398 .66143 L F
.771 .966 .67 r
.49845 .66004 m .4963 .66195 L .49854 .65918 L F
.49845 .66004 m .49854 .65918 L .49857 .65914 L F
.799 .574 .597 r
.49845 .66004 m .49892 .66121 L .49839 .66056 L F
.51 .373 .63 r
.5007 .65828 m .50107 .66077 L .49892 .66121 L F
.601 .545 .764 r
.52127 .76356 m .52346 .76391 L .52477 .76243 L F
0 .536 .778 r
.52127 .76356 m .52381 .76391 L .52346 .76391 L F
.501 .274 .502 r
.52477 .76243 m .52381 .76391 L .52127 .76356 L F
.086 .255 .741 r
.56266 .65563 m .56368 .65447 L .56141 .65238 L F
0 .032 .591 r
.56266 .65563 m .56418 .65666 L .56368 .65447 L F
.56266 .65563 m .56382 .65818 L .56418 .65666 L F
.081 .465 .888 r
.50323 .79722 m .50279 .79784 L .50019 .79566 L F
0 0 .449 r
.50342 .79866 m .50279 .79784 L .50323 .79722 L F
.489 .151 .321 r
.37078 .6304 m .3701 .63198 L .36794 .63228 L F
.364 .031 .261 r
.37221 .63135 m .37078 .6304 L .3729 .62992 L F
.37221 .63135 m .3701 .63198 L .37078 .6304 L F
.175 0 .159 r
.45708 .66378 m .45472 .66618 L .45534 .66438 L F
.526 .423 .68 r
.56846 .62678 m .57078 .62636 L .56849 .62451 L F
.699 .509 .628 r
.6148 .53907 m .61494 .54157 L .61724 .53891 L F
.73 .556 .655 r
.61724 .53891 m .61494 .54157 L .61754 .5414 L F
.225 0 0 r
.35374 .63986 m .35753 .6377 L .35582 .63925 L F
.195 0 0 r
.35582 .63925 m .35753 .6377 L .3597 .63721 L F
.213 0 .133 r
.56549 .57554 m .56346 .57645 L .56275 .57784 L F
.684 .498 .628 r
.61157 .54143 m .61494 .54157 L .6148 .53907 L F
.489 .299 .549 r
.57721 .66685 m .57936 .66877 L .57934 .66634 L F
.347 .091 .377 r
.58817 .55808 m .59061 .55531 L .5886 .55612 L F
0 0 0 r
.55084 .58952 m .5528 .589 L .55404 .58751 L F
.55404 .58751 m .55452 .58773 L .55549 .58615 L F
.55404 .58751 m .5528 .589 L .55452 .58773 L F
.887 .554 .412 r
.56392 .62931 m .56632 .63213 L .56542 .63048 L F
.705 .264 .201 r
.56351 .62117 m .56418 .62075 L .56327 .62058 L F
.56351 .62117 m .56356 .6185 L .56595 .61834 L F
.56351 .62117 m .56327 .62058 L .56356 .6185 L F
.687 .962 .73 r
.56471 .61957 m .56216 .622 L .56351 .62117 L F
.56216 .622 m .56098 .62312 L .56351 .62117 L F
.705 .264 .201 r
.56351 .62117 m .56711 .6213 L .56418 .62075 L F
.824 .709 .738 r
.56358 .62347 m .56711 .6213 L .56351 .62117 L F
.56358 .62347 m .56428 .62524 L .56711 .6213 L F
.957 .646 .226 r
.57205 .67108 m .57137 .66925 L .57108 .66825 L F
.57137 .66925 m .57063 .66724 L .57108 .66825 L F
.62 .097 0 r
.57071 .667 m .57108 .66825 L .56774 .66643 L F
.57174 .6672 m .57108 .66825 L .57071 .667 L F
.83 .51 .447 r
.57238 .66676 m .57108 .66825 L .57174 .6672 L F
.647 .679 .866 r
.71346 .4952 m .71562 .49914 L .71766 .49651 L F
.747 .778 .281 r
.65119 .49282 m .65007 .49631 L .65052 .49449 L F
0 0 0 r
.65119 .49282 m .65052 .49449 L .65259 .49141 L F
.555 .415 .645 r
.3668 .61268 m .36904 .61236 L .36886 .60978 L F
.491 .338 .601 r
.3668 .61268 m .36905 .61479 L .36904 .61236 L F
.3668 .61268 m .36701 .61549 L .36905 .61479 L F
.485 .296 .549 r
.59755 .61242 m .59978 .60956 L .59729 .60998 L F
.068 .112 .6 r
.28551 .63844 m .28727 .63966 L .28546 .63718 L F
.28551 .63844 m .28632 .64074 L .28727 .63966 L F
.693 .167 0 r
.2768 .62629 m .28047 .62813 L .27839 .62699 L F
.669 .496 .642 r
.27839 .62699 m .28096 .62781 L .28093 .62617 L F
.588 .052 0 r
.27839 .62699 m .28047 .62813 L .28096 .62781 L F
.49 .275 .514 r
.40613 .60117 m .40583 .60357 L .40345 .60409 L F
.535 .36 .591 r
.40583 .60357 m .40338 .60662 L .40345 .60409 L F
0 0 0 r
.68586 .4756 m .68847 .47281 L .68594 .47355 L F
.947 .592 .219 r
.46816 .65907 m .46734 .65983 L .46507 .65826 L F
.46854 .66011 m .46941 .66248 L .46829 .66104 L F
.46816 .65907 m .46854 .66011 L .46734 .65983 L F
.46854 .66011 m .46829 .66104 L .46734 .65983 L F
.71 .768 .898 r
.46734 .65983 m .46941 .66248 L .47158 .66028 L F
.408 0 .064 r
.47158 .66028 m .46993 .66206 L .46796 .66224 L F
.46806 .66189 m .46796 .66224 L .46713 .66231 L F
.47158 .66028 m .46796 .66224 L .46806 .66189 L F
.526 .336 .566 r
.56327 .62058 m .56127 .62138 L .56356 .6185 L F
.071 0 0 r
.74937 .51373 m .74522 .51577 L .74716 .51419 L F
.673 .976 .865 r
.75026 .51255 m .74937 .51373 L .74716 .51419 L F
.75026 .51255 m .75047 .513 L .74937 .51373 L F
.151 0 0 r
.33949 .64506 m .3381 .64468 L .34115 .64367 L F
.103 0 0 r
.34194 .64436 m .34115 .64367 L .34336 .64326 L F
.34194 .64436 m .33949 .64506 L .34115 .64367 L F
.721 .842 .403 r
.52757 .60181 m .52625 .60449 L .52669 .60323 L F
0 0 .256 r
.52669 .60323 m .5273 .60383 L .52716 .60189 L F
0 0 0 r
.52757 .60181 m .52669 .60323 L .52793 .60155 L F
.809 .998 .791 r
.52793 .60155 m .52669 .60323 L .52714 .60162 L F
0 0 .256 r
.52669 .60323 m .52716 .60189 L .52714 .60162 L F
.721 .842 .403 r
.52625 .60449 m .52605 .60489 L .52669 .60323 L F
0 0 0 r
.52757 .60181 m .52793 .60155 L .5293 .60067 L F
.783 .73 .804 r
.5922 .6548 m .58836 .65477 L .59052 .65283 L F
.5922 .6548 m .59023 .65554 L .58836 .65477 L F
.297 .119 .462 r
.59227 .65388 m .59436 .65322 L .59397 .64998 L F
.59397 .64998 m .59436 .65322 L .59227 .65388 L F
.651 .41 .542 r
.59052 .65283 m .59436 .65322 L .5922 .6548 L F
.552 .061 .046 r
.66752 .48549 m .66667 .48667 L .66444 .48622 L F
.497 .004 .016 r
.67034 .48636 m .66667 .48667 L .66752 .48549 L F
.314 0 .231 r
.45979 .64628 m .46171 .64639 L .46256 .6441 L F
.388 .029 .23 r
.46171 .64639 m .46486 .64372 L .46256 .6441 L F
.449 .238 .5 r
.51301 .67487 m .51072 .67775 L .51095 .67544 L F
.51301 .67487 m .51072 .67775 L .51095 .67544 L F
0 .219 .723 r
.47203 .6614 m .47264 .66136 L .47158 .66028 L F
.47203 .6614 m .47431 .66308 L .47264 .66136 L F
.767 .692 .779 r
.63873 .50438 m .64009 .5077 L .6425 .50487 L F
.227 0 .062 r
.3614 .62023 m .36436 .61814 L .36222 .61865 L F
0 0 .278 r
.50111 .66804 m .50148 .66964 L .5025 .66967 L F
.023 .596 .732 r
.50331 .6697 m .5025 .66967 L .5001 .66968 L F
.191 0 0 r
.5025 .66967 m .50167 .67045 L .49954 .67081 L F
0 0 .278 r
.50148 .66964 m .50167 .67045 L .5025 .66967 L F
.023 .596 .732 r
.50369 .6697 m .5025 .66967 L .50331 .6697 L F
.587 .936 .939 r
.50474 .66846 m .5025 .66967 L .50369 .6697 L F
.443 .208 .462 r
.76273 .51757 m .76053 .51633 L .76279 .51563 L F
.76273 .51757 m .76041 .5184 L .76053 .51633 L F
.778 .511 .531 r
.53705 .65443 m .53254 .65667 L .53282 .65541 L F
.53705 .65443 m .53526 .65724 L .53254 .65667 L F
.703 .448 .535 r
.53809 .65556 m .53526 .65724 L .53705 .65443 L F
0 0 0 r
.32991 .6473 m .32678 .64823 L .3258 .64842 L F
.465 0 .028 r
.33028 .64794 m .32678 .64823 L .32991 .6473 L F
.212 0 0 r
.3323 .64709 m .33028 .64794 L .32991 .6473 L F
.255 .743 .922 r
.35077 .59961 m .34734 .59926 L .349 .59967 L F
.373 .086 .342 r
.58599 .57282 m .58596 .57454 L .58346 .57531 L F
.152 0 .019 r
.58599 .57282 m .58886 .57086 L .58765 .5724 L F
.28 .024 .335 r
.58765 .5724 m .58596 .57454 L .58599 .57282 L F
.56 .445 .68 r
.59642 .63518 m .59683 .6374 L .5943 .63776 L F
.579 .471 .695 r
.59683 .6374 m .59508 .64165 L .5943 .63776 L F
.831 .987 .717 r
.74791 .52968 m .75047 .52711 L .7497 .52823 L F
0 0 0 r
.75225 .52572 m .75047 .52711 L .75309 .5244 L F
.7497 .52823 m .75047 .52711 L .75225 .52572 L F
.524 .437 .698 r
.31335 .6147 m .31382 .61849 L .31179 .6187 L F
.522 .42 .679 r
.31382 .61849 m .31192 .62063 L .31179 .6187 L F
.417 .824 .977 r
.35514 .59938 m .35536 .59849 L .35326 .59915 L F
.35514 .59938 m .35721 .59897 L .35536 .59849 L F
.877 .482 .283 r
.56833 .63598 m .56981 .63948 L .57099 .63847 L F
.986 .728 .446 r
.56981 .63948 m .57042 .64032 L .57099 .63847 L F
.512 .297 .524 r
.66223 .48486 m .66444 .48622 L .66178 .4867 L F
.824 .352 0 r
.28546 .63718 m .28228 .63346 L .28416 .63588 L F
0 0 0 r
.56313 .60386 m .56368 .60447 L .56269 .60602 L F
.56313 .60386 m .5647 .60292 L .56368 .60447 L F
.03 0 .104 r
.56034 .58075 m .56275 .57784 L .56117 .57902 L F
.13 .622 .912 r
.25718 .64608 m .26142 .6472 L .25873 .64754 L F
.25718 .64608 m .26142 .6472 L .25873 .64754 L F
.736 .877 .946 r
.53238 .63841 m .52882 .63887 L .53118 .63906 L F
.678 .134 0 r
.53238 .63841 m .53496 .64092 L .53595 .64119 L F
0 .083 .609 r
.53347 .63919 m .53496 .64092 L .53486 .64082 L F
.53347 .63919 m .53486 .64082 L .53238 .63841 L F
.53347 .63919 m .53238 .63841 L .53118 .63906 L F
.515 .663 .928 r
.53197 .63741 m .53347 .63919 L .53118 .63906 L F
.53225 .63682 m .53347 .63919 L .53197 .63741 L F
.996 .841 .573 r
.62207 .58293 m .62353 .58152 L .62233 .58053 L F
.62207 .58293 m .62286 .58353 L .62353 .58152 L F
.428 .287 .585 r
.68972 .47826 m .68994 .4814 L .68783 .48224 L F
.327 .077 .373 r
.68994 .4814 m .68761 .48408 L .68783 .48224 L F
.113 0 0 r
.34416 .6285 m .34841 .62689 L .34598 .62721 L F
.605 .318 .455 r
.34911 .62651 m .34598 .62721 L .34841 .62689 L F
.893 .707 .643 r
.60765 .58119 m .60534 .58081 L .60574 .57841 L F
.933 .731 .606 r
.60765 .58119 m .60536 .58302 L .60534 .58081 L F
.60765 .58119 m .6073 .58406 L .60536 .58302 L F
.686 .748 .898 r
.73057 .50481 m .73446 .50649 L .73331 .50438 L F
.854 .962 .874 r
.73446 .50649 m .73579 .50333 L .73331 .50438 L F
.73446 .50649 m .73641 .5045 L .73579 .50333 L F
.582 .57 .805 r
.3761 .60111 m .37831 .60064 L .37503 .59884 L F
.731 .471 .534 r
.59645 .56734 m .59666 .56961 L .59305 .5699 L F
.569 .377 .581 r
.63799 .50208 m .63873 .50438 L .64124 .50139 L F
.642 .859 .982 r
.4962 .80051 m .49964 .80047 L .49841 .79958 L F
0 .167 .703 r
.49964 .80047 m .50042 .80042 L .49841 .79958 L F
.49964 .80047 m .50202 .80279 L .50042 .80042 L F
.985 .882 .534 r
.73579 .50333 m .73691 .5021 L .73553 .50078 L F
.73579 .50333 m .73641 .5045 L .73691 .5021 L F
.409 .191 .47 r
.59061 .55531 m .59293 .5524 L .59082 .55316 L F
0 0 .489 r
.52605 .60489 m .52687 .60627 L .52669 .60323 L F
.008 0 0 r
.57861 .58129 m .57783 .5825 L .57583 .58348 L F
0 0 .148 r
.58095 .57833 m .58043 .58005 L .57861 .58129 L F
0 0 0 r
.57861 .58129 m .58043 .58005 L .57783 .5825 L F
.557 .446 .683 r
.56526 .61555 m .56595 .61834 L .56356 .6185 L F
.484 .825 .998 r
.56011 .61818 m .56155 .6173 L .56356 .6185 L F
.282 0 0 r
.28684 .59207 m .28917 .5917 L .29077 .59033 L F
.128 0 0 r
.29077 .59033 m .29125 .59114 L .29302 .58996 L F
.29077 .59033 m .28917 .5917 L .29125 .59114 L F
.479 .155 .338 r
.58742 .67183 m .58644 .6744 L .58405 .67475 L F
.405 .084 .304 r
.58868 .67382 m .58742 .67183 L .58946 .67168 L F
.58868 .67382 m .58644 .6744 L .58742 .67183 L F
.65 .633 .82 r
.40701 .59785 m .40613 .60117 L .40563 .59973 L F
.40701 .59785 m .40861 .60144 L .40613 .60117 L F
.624 .392 .546 r
.40613 .60117 m .40823 .60345 L .40583 .60357 L F
.67 .391 .489 r
.40861 .60144 m .40823 .60345 L .40613 .60117 L F
0 .513 .772 r
.6782 .49452 m .68089 .495 L .6783 .49458 L F
.909 .911 .81 r
.71885 .49465 m .72097 .49405 L .71989 .49284 L F
0 .283 .734 r
.7415 .47224 m .7386 .47063 L .73926 .47321 L F
.624 .948 .942 r
.53595 .64119 m .53496 .64092 L .53706 .63979 L F
.219 .367 .8 r
.53706 .63979 m .53839 .64324 L .53595 .64119 L F
.618 .758 .946 r
.67273 .49604 m .67027 .49685 L .66913 .49526 L F
.67273 .49604 m .67027 .49685 L .66913 .49526 L F
.926 .829 .729 r
.72931 .49065 m .72693 .49192 L .72796 .48961 L F
.72931 .49065 m .7282 .49304 L .72693 .49192 L F
0 .269 .767 r
.46939 .65255 m .47161 .65401 L .4716 .65492 L F
0 .22 .735 r
.47161 .65401 m .47364 .6565 L .4716 .65492 L F
.928 .793 .69 r
.62303 .57195 m .62178 .57475 L .62419 .57534 L F
.951 .79 .647 r
.62155 .57736 m .62419 .57534 L .62178 .57475 L F
.62155 .57736 m .62301 .57836 L .62419 .57534 L F
.055 0 0 r
.33646 .64588 m .3348 .64606 L .3381 .64468 L F
.407 0 .148 r
.33949 .64506 m .33646 .64588 L .3381 .64468 L F
.61 .449 .639 r
.28093 .62617 m .28338 .62672 L .28282 .62389 L F
.28093 .62617 m .28096 .62781 L .28338 .62672 L F
.853 .839 .831 r
.2864 .64385 m .28761 .64633 L .28967 .64313 L F
.441 .712 .981 r
.51339 .65178 m .51625 .65289 L .51602 .65157 L F
.98 .712 .446 r
.51739 .65484 m .51602 .65157 L .51625 .65289 L F
.18 0 0 r
.44714 .70025 m .44909 .69986 L .45064 .6983 L F
.43 0 .11 r
.44909 .69986 m .45283 .69795 L .45064 .6983 L F
.411 .019 .182 r
.5153 .69974 m .51826 .69836 L .51574 .69818 L F
.237 0 .279 r
.28 .5957 m .2817 .5952 L .28245 .59288 L F
.414 .123 .358 r
.28245 .59288 m .28394 .59458 L .28447 .59211 L F
.28245 .59288 m .2817 .5952 L .28394 .59458 L F
.556 .162 .25 r
.66894 .48094 m .67232 .47912 L .66892 .47938 L F
.66894 .48094 m .67129 .48099 L .67232 .47912 L F
.578 .186 .262 r
.67232 .47912 m .67472 .48059 L .67464 .47891 L F
.67232 .47912 m .67129 .48099 L .67472 .48059 L F
.488 .296 .546 r
.54526 .64395 m .54321 .64533 L .5421 .64436 L F
.54526 .64395 m .54394 .6461 L .54321 .64533 L F
.557 .434 .668 r
.27983 .59798 m .2817 .5952 L .28 .5957 L F
.834 .537 .487 r
.55133 .75961 m .55318 .75768 L .55158 .75716 L F
.55133 .75961 m .55374 .76054 L .55318 .75768 L F
.672 .973 .903 r
.75273 .51077 m .75047 .513 L .75026 .51255 L F
.75273 .51077 m .75356 .51117 L .75047 .513 L F
.041 .24 .74 r
.49015 .77954 m .48981 .77671 L .4878 .77662 L F
.49015 .77954 m .49113 .77982 L .48981 .77671 L F
.427 .727 .988 r
.70621 .48474 m .70296 .48363 L .70511 .48373 L F
.535 .659 .915 r
.70751 .48286 m .70621 .48474 L .70511 .48373 L F
.70751 .48286 m .7088 .48474 L .70621 .48474 L F
.442 .548 .869 r
.52811 .61003 m .5297 .61279 L .53091 .61272 L F
.622 .464 .647 r
.57992 .6238 m .58233 .62392 L .5821 .62136 L F
.017 .591 .726 r
.26439 .64928 m .26702 .64928 L .26779 .64931 L F
.26439 .64928 m .26702 .64928 L .26779 .64931 L F
.088 0 0 r
.59084 .56989 m .58765 .5724 L .58886 .57086 L F
.41 .085 .302 r
.39876 .6096 m .39786 .61187 L .3957 .61236 L F
.506 .191 .367 r
.401 .60926 m .39786 .61187 L .39876 .6096 L F
.386 .037 .246 r
.45979 .64628 m .46117 .64814 L .46171 .64639 L F
.45979 .64628 m .45896 .64865 L .46117 .64814 L F
.034 .375 .841 r
.53349 .61542 m .53382 .61445 L .53091 .61272 L F
0 .284 .785 r
.53349 .61542 m .5361 .61731 L .53382 .61445 L F
.787 .924 .927 r
.40701 .59785 m .40563 .59973 L .40392 .5987 L F
.644 .485 .653 r
.50455 .64689 m .50481 .64996 L .50225 .64968 L F
.655 .493 .653 r
.50777 .6496 m .50455 .64689 L .50697 .6464 L F
.50777 .6496 m .50481 .64996 L .50455 .64689 L F
.715 .792 .912 r
.69704 .4848 m .69496 .486 L .69346 .4844 L F
.726 .681 .806 r
.73785 .49578 m .74156 .49677 L .74014 .49515 L F
.763 .778 .866 r
.74014 .49515 m .74156 .49677 L .74317 .49479 L F
.444 0 0 r
.51438 .70604 m .51352 .70683 L .51107 .70635 L F
.059 0 0 r
.51675 .70535 m .51575 .70613 L .51438 .70604 L F
.51575 .70613 m .51352 .70683 L .51438 .70604 L F
.393 .759 .993 r
.38333 .58941 m .38257 .5904 L .38116 .58928 L F
.38333 .58941 m .3848 .59025 L .38257 .5904 L F
.781 .884 .921 r
.67858 .49985 m .67731 .50199 L .67623 .50091 L F
.032 0 0 r
.75751 .52057 m .75558 .52169 L .75834 .51947 L F
.283 0 .19 r
.76041 .5184 m .75751 .52057 L .75834 .51947 L F
.627 .575 .777 r
.31382 .61849 m .31477 .62259 L .31192 .62063 L F
.49 .772 .994 r
.37395 .58711 m .37325 .58857 L .37179 .58745 L F
.37395 .58711 m .37582 .58838 L .37325 .58857 L F
.281 .384 .791 r
.54042 .62343 m .54172 .62673 L .54304 .62517 L F
.301 .415 .811 r
.54172 .62673 m .54433 .62809 L .54304 .62517 L F
.093 .648 .796 r
.2727 .62886 m .27087 .62873 L .27469 .62883 L F
.2727 .62886 m .27087 .62873 L .27469 .62883 L F
.565 .284 .448 r
.50225 .64968 m .5046 .65146 L .50294 .6508 L F
.614 .254 .336 r
.50481 .64996 m .5046 .65146 L .50225 .64968 L F
.411 0 .076 r
.45864 .69795 m .46096 .69782 L .46175 .69654 L F
.723 .302 .247 r
.46175 .69654 m .46096 .69782 L .46237 .69688 L F
.855 .68 .664 r
.55225 .76517 m .55542 .76299 L .55399 .76196 L F
.55225 .76517 m .55412 .76619 L .55542 .76299 L F
.155 0 0 r
.45024 .67008 m .45107 .67054 L .44905 .67053 L F
.45024 .67008 m .45271 .67009 L .45107 .67054 L F
.519 .795 .996 r
.51122 .80793 m .51024 .80947 L .50894 .80826 L F
.51122 .80793 m .51277 .80898 L .51024 .80947 L F
.51024 .80947 m .51122 .80793 L .50894 .80826 L F
.51024 .80947 m .51277 .80898 L .51122 .80793 L F
.713 .7 .836 r
.59538 .6591 m .59668 .66151 L .59327 .66092 L F
.573 .589 .831 r
.59772 .65781 m .59668 .66151 L .59538 .6591 L F
.59772 .65781 m .59901 .66113 L .59668 .66151 L F
.769 .738 .215 r
.60479 .60159 m .6043 .60382 L .60488 .60074 L F
.757 .523 .578 r
.49512 .79168 m .49492 .79494 L .49115 .79453 L F
.591 .381 .564 r
.49719 .7939 m .49492 .79494 L .49512 .79168 L F
0 .169 .707 r
.49608 .79153 m .49719 .7939 L .49512 .79168 L F
.559 .709 .941 r
.32675 .62629 m .32502 .62782 L .32487 .62671 L F
.32675 .62629 m .32796 .62782 L .32502 .62782 L F
.785 .773 .842 r
.56937 .62029 m .57007 .61882 L .56817 .61752 L F
.511 .381 .64 r
.57427 .62693 m .57601 .62899 L .57647 .62641 L F
.57427 .62693 m .57601 .62899 L .57647 .62641 L F
.454 .733 .987 r
.35289 .58597 m .35227 .58743 L .35079 .58642 L F
.35289 .58597 m .35439 .58726 L .35227 .58743 L F
.512 .366 .618 r
.6762 .49689 m .67884 .49653 L .6782 .49452 L F
0 0 .03 r
.75558 .52169 m .7551 .52347 L .75309 .5244 L F
0 0 0 r
.7551 .52347 m .75225 .52572 L .75309 .5244 L F
.382 .584 .922 r
.29812 .63845 m .30218 .64112 L .30024 .63809 L F
.815 .737 .778 r
.30024 .63809 m .30218 .64112 L .30413 .6381 L F
.822 .96 .629 r
.30413 .6381 m .30218 .64112 L .30234 .63984 L F
0 0 .566 r
.30218 .64112 m .3037 .64327 L .30234 .63984 L F
.509 .464 .742 r
.76271 .48895 m .76133 .49297 L .76061 .49083 L F
.76271 .48895 m .76354 .49253 L .76133 .49297 L F
.554 .449 .688 r
.76354 .49253 m .7615 .49532 L .76133 .49297 L F
0 0 0 r
.55084 .58952 m .55056 .58993 L .5528 .589 L F
.808 .835 .872 r
.74235 .51796 m .74078 .51949 L .73928 .51851 L F
.812 .638 .666 r
.62063 .54391 m .62205 .5473 L .62222 .54472 L F
.711 .463 .549 r
.55188 .76618 m .54808 .76862 L .55037 .76574 L F
.55188 .76618 m .55023 .7692 L .54808 .76862 L F
.244 .719 .939 r
.55188 .76618 m .55412 .76619 L .55037 .76574 L F
.314 .242 .613 r
.55023 .7692 m .55037 .76574 L .55188 .76618 L F
.063 0 .002 r
.28338 .62672 m .28608 .62408 L .28282 .62389 L F
.28338 .62672 m .28501 .62611 L .28608 .62408 L F
.254 .321 .74 r
.28608 .62408 m .28643 .62049 L .28558 .62108 L F
.28608 .62408 m .28752 .62332 L .28643 .62049 L F
0 0 0 r
.28608 .62408 m .28662 .62492 L .28752 .62332 L F
.28608 .62408 m .28501 .62611 L .28662 .62492 L F
.56 .568 .819 r
.43864 .69111 m .43784 .69458 L .43707 .69257 L F
.512 0 0 r
.41489 .69763 m .41832 .69884 L .41805 .6986 L F
.43 0 0 r
.66079 .51293 m .66367 .51352 L .66374 .51261 L F
0 0 0 r
.66374 .51261 m .66466 .511 L .66528 .50905 L F
.66374 .51261 m .66367 .51352 L .66466 .511 L F
.655 .48 .635 r
.55408 .65496 m .55369 .6582 L .55127 .65808 L F
.663 .331 0 r
.55277 .65163 m .55377 .6542 L .55408 .65496 L F
.899 .504 .077 r
.55377 .6542 m .55423 .65456 L .55408 .65496 L F
.603 .593 .814 r
.55423 .65456 m .55369 .6582 L .55408 .65496 L F
.701 .819 .938 r
.71198 .4849 m .7088 .48474 L .71078 .48361 L F
.71198 .4849 m .7088 .48474 L .71078 .48361 L F
.546 .522 .78 r
.71329 .48081 m .71198 .4849 L .71078 .48361 L F
.71329 .48081 m .71455 .48464 L .71198 .4849 L F
.53 .215 .378 r
.46507 .65826 m .46193 .66062 L .46325 .65941 L F
.773 .675 .755 r
.63873 .50438 m .6425 .50487 L .64124 .50139 L F
.814 .825 .859 r
.67052 .51466 m .67401 .51357 L .67285 .51208 L F
.767 .791 .873 r
.67285 .51208 m .67401 .51357 L .6759 .51231 L F
.88 .813 .778 r
.71639 .50338 m .71698 .50753 L .7184 .50591 L F
.378 .52 .873 r
.71698 .50753 m .71917 .5083 L .7184 .50591 L F
.63 .772 .948 r
.70158 .49474 m .70599 .49569 L .7039 .49336 L F
.55 .77 .979 r
.70599 .49569 m .70666 .49354 L .7039 .49336 L F
.70599 .49569 m .70761 .49496 L .70666 .49354 L F
.805 .836 .874 r
.27408 .66911 m .27181 .66869 L .27252 .6677 L F
.876 .613 .536 r
.27408 .66911 m .27146 .6707 L .27181 .66869 L F
.355 .672 .976 r
.27252 .6677 m .27586 .66826 L .27408 .66911 L F
0 0 0 r
.27586 .66826 m .27146 .6707 L .27408 .66911 L F
.558 .614 .864 r
.31619 .62002 m .31554 .62336 L .31477 .62259 L F
.31619 .62002 m .31803 .62294 L .31554 .62336 L F
.361 0 0 r
.44941 .70651 m .44796 .70793 L .44568 .70807 L F
.454 0 .039 r
.45169 .70648 m .44796 .70793 L .44941 .70651 L F
0 0 0 r
.75335 .50157 m .75091 .50363 L .75334 .50309 L F
.252 .265 .68 r
.75341 .4984 m .75335 .50157 L .75563 .50013 L F
0 0 .06 r
.75563 .50013 m .75335 .50157 L .75334 .50309 L F
.008 0 0 r
.34841 .62689 m .3511 .62611 L .34911 .62651 L F
.252 0 0 r
.53439 .70053 m .53307 .70156 L .53101 .70118 L F
.219 0 0 r
.53674 .70074 m .53307 .70156 L .53439 .70053 L F
.661 .108 0 r
.50405 .62336 m .50777 .62547 L .50592 .62336 L F
.32 .803 .886 r
.49099 .61934 m .49497 .61895 L .4926 .61908 L F
.815 .737 .778 r
.30024 .63809 m .30413 .6381 L .30242 .63707 L F
.438 .767 .997 r
.30242 .63707 m .30413 .6381 L .30518 .63748 L F
.739 .511 .582 r
.30234 .63984 m .30518 .63748 L .30413 .6381 L F
.59 .628 .858 r
.75091 .50363 m .75275 .50761 L .75478 .50652 L F
.576 .576 .816 r
.41396 .70258 m .41558 .70607 L .41233 .70338 L F
0 0 0 r
.41327 .70354 m .41396 .70258 L .41318 .70362 L F
.847 .696 .694 r
.41581 .70347 m .41558 .70607 L .41396 .70258 L F
0 0 0 r
.41491 .70196 m .41396 .70258 L .41327 .70354 L F
.867 .496 .343 r
.41446 .70048 m .41485 .70134 L .41396 .70258 L F
.41485 .70134 m .41581 .70347 L .41396 .70258 L F
0 0 0 r
.41446 .70048 m .41396 .70258 L .41461 .70021 L F
.54 .378 .61 r
.31562 .60969 m .31564 .61221 L .31335 .61262 L F
.463 .254 .51 r
.31564 .61221 m .31335 .6147 L .31335 .61262 L F
.119 0 .068 r
.75713 .5223 m .75558 .52169 L .75751 .52057 L F
.75713 .5223 m .7551 .52347 L .75558 .52169 L F
.673 .502 .646 r
.58233 .62392 m .58455 .62108 L .5821 .62136 L F
0 .202 .725 r
.50313 .62181 m .5018 .62142 L .50054 .62042 L F
.50313 .62181 m .50405 .62336 L .5018 .62142 L F
0 0 0 r
.72997 .51428 m .72825 .51519 L .72889 .51502 L F
0 0 .539 r
.72889 .51502 m .72825 .51519 L .72988 .51789 L F
.662 .438 .569 r
.59876 .55225 m .60137 .54978 L .59888 .55023 L F
.009 .516 .864 r
.3186 .58286 m .32043 .58336 L .32193 .58424 L F
.51 .802 .998 r
.32257 .58286 m .32193 .58424 L .32043 .58336 L F
.32257 .58286 m .32408 .58382 L .32193 .58424 L F
.482 .391 .676 r
.41416 .68094 m .41612 .6805 L .41574 .67798 L F
.471 .387 .679 r
.41416 .68094 m .41656 .68309 L .41612 .6805 L F
.41416 .68094 m .4147 .68362 L .41656 .68309 L F
.344 .029 .279 r
.58346 .57531 m .58513 .57686 L .5828 .57736 L F
.58346 .57531 m .58596 .57454 L .58513 .57686 L F
.823 .975 .891 r
.53702 .6237 m .538 .62408 L .53874 .62191 L F
.53702 .6237 m .538 .62408 L .53874 .62191 L F
.269 0 .135 r
.32548 .60336 m .32356 .6045 L .32325 .60393 L F
.425 .085 .284 r
.38606 .62093 m .38526 .62326 L .38301 .62369 L F
.412 .19 .464 r
.38839 .61825 m .38813 .62039 L .38606 .62093 L F
.345 .013 .251 r
.38732 .62262 m .38606 .62093 L .38813 .62039 L F
.38732 .62262 m .38526 .62326 L .38606 .62093 L F
.798 .88 .906 r
.48627 .77389 m .48602 .77639 L .48787 .77465 L F
0 0 .036 r
.48602 .77639 m .48787 .77465 L .48627 .77389 L F
.48602 .77639 m .48545 .77706 L .48787 .77465 L F
.066 .408 .86 r
.54518 .62957 m .54557 .62861 L .54433 .62809 L F
.935 .583 .163 r
.54616 .62951 m .54557 .62861 L .54518 .62957 L F
.681 .554 .704 r
.54518 .62957 m .54846 .63248 L .54616 .62951 L F
.54518 .62957 m .54703 .63374 L .54846 .63248 L F
.109 .628 .885 r
.50777 .62547 m .51129 .62621 L .50891 .62654 L F
.509 .21 .394 r
.60679 .54695 m .60919 .54654 L .60957 .54481 L F
.711 .521 .63 r
.60919 .54654 m .61176 .544 L .60957 .54481 L F
.485 .269 .51 r
.43974 .67817 m .43973 .6804 L .4377 .68059 L F
.596 .348 .511 r
.44285 .67767 m .43973 .6804 L .43974 .67817 L F
.68 .75 .904 r
.70761 .49496 m .70872 .49643 L .71121 .49558 L F
.577 .686 .915 r
.5421 .64436 m .5396 .64503 L .53839 .64324 L F
.826 .363 .11 r
.57231 .62903 m .57419 .63172 L .57171 .62896 L F
.335 .695 .981 r
.74174 .47193 m .74348 .47303 L .74286 .47304 L F
0 .14 .656 r
.74389 .47396 m .74263 .47326 L .7415 .47224 L F
.36 .132 .427 r
.73888 .47535 m .7415 .47224 L .73926 .47321 L F
.854 .861 .846 r
.73929 .47308 m .7415 .47224 L .73888 .47535 L F
0 .14 .656 r
.74392 .47398 m .74391 .47397 L .74389 .47396 L F
.74391 .47397 m .74263 .47326 L .74389 .47396 L F
.74392 .47398 m .74478 .47511 L .74464 .47499 L F
.74392 .47398 m .74464 .47499 L .74263 .47326 L F
.34 .693 .982 r
.73929 .47308 m .74261 .47304 L .7415 .47224 L F
.73929 .47308 m .74326 .47303 L .74392 .47398 L F
.74326 .47303 m .74348 .47303 L .74392 .47398 L F
.335 .695 .981 r
.74166 .47197 m .74286 .47304 L .73929 .47308 L F
.74174 .47193 m .74286 .47304 L .74166 .47197 L F
.391 0 0 r
.46096 .69782 m .46457 .69897 L .46237 .69688 L F
.718 .539 .647 r
.61498 .5441 m .61754 .5414 L .61494 .54157 L F
.61498 .5441 m .61847 .54439 L .61754 .5414 L F
.71 .535 .65 r
.61754 .5414 m .61847 .54439 L .62063 .54391 L F
.388 .412 .764 r
.31619 .62002 m .31477 .62259 L .31382 .61849 L F
.711 .543 .659 r
.61176 .544 m .61494 .54157 L .61157 .54143 L F
.453 .209 .452 r
.39096 .61545 m .39055 .61775 L .38839 .61825 L F
.465 .219 .456 r
.39271 .6172 m .39096 .61545 L .39324 .61508 L F
.39271 .6172 m .39055 .61775 L .39096 .61545 L F
.575 .591 .832 r
.40921 .59735 m .40861 .60144 L .40701 .59785 L F
.40921 .59735 m .41106 .60082 L .40861 .60144 L F
.537 .308 .515 r
.41106 .60082 m .40823 .60345 L .40861 .60144 L F
0 0 .289 r
.53744 .61844 m .53792 .6192 L .5361 .61731 L F
.53744 .61844 m .53813 .62054 L .53792 .6192 L F
.614 .047 0 r
.49937 .77713 m .50133 .77806 L .50168 .77799 L F
.525 .136 .246 r
.43471 .66268 m .43346 .66057 L .43226 .66277 L F
.43471 .66268 m .43585 .6606 L .43346 .66057 L F
.249 .709 .951 r
.34363 .58485 m .34298 .58552 L .34138 .58499 L F
.34363 .58485 m .34537 .58552 L .34298 .58552 L F
.045 .417 .864 r
.74742 .47666 m .74529 .47642 L .74478 .47511 L F
.74742 .47666 m .74823 .47796 L .74529 .47642 L F
.66 .563 .735 r
.27817 .61514 m .27935 .61882 L .28163 .6182 L F
.584 .568 .801 r
.76271 .48895 m .76061 .49083 L .75977 .48777 L F
.729 .683 .806 r
.49492 .79494 m .49622 .79768 L .49256 .79735 L F
0 0 0 r
.49622 .79768 m .49515 .80003 L .49256 .79735 L F
.773 .702 .784 r
.49799 .79565 m .49622 .79768 L .49492 .79494 L F
.538 .385 .622 r
.49841 .79958 m .4962 .80051 L .49622 .79768 L F
.205 .715 .896 r
.35439 .58726 m .35671 .58718 L .35811 .58751 L F
.398 .822 .966 r
.35671 .58718 m .36022 .58717 L .35811 .58751 L F
.232 0 .25 r
.57749 .64345 m .57707 .64561 L .57524 .64532 L F
.035 0 .213 r
.57707 .64561 m .57515 .64819 L .57524 .64532 L F
.61 .263 .357 r
.52625 .69745 m .52979 .69747 L .5296 .69549 L F
.657 .298 .352 r
.5296 .69549 m .52979 .69747 L .53181 .69728 L F
.062 .454 .881 r
.33663 .62818 m .33814 .6287 L .33782 .62953 L F
.208 .625 .951 r
.33814 .6287 m .33979 .62977 L .33782 .62953 L F
.113 0 0 r
.34416 .6285 m .34629 .62818 L .34841 .62689 L F
.034 0 0 r
.34841 .62689 m .34847 .62768 L .34949 .62709 L F
.34841 .62689 m .34657 .62801 L .34847 .62768 L F
.206 0 0 r
.34847 .62768 m .3527 .62581 L .34949 .62709 L F
.34847 .62768 m .35074 .62735 L .3527 .62581 L F
.239 .753 .853 r
.34641 .62761 m .35008 .62739 L .34847 .62768 L F
.35008 .62739 m .35074 .62735 L .34847 .62768 L F
.034 0 0 r
.34657 .62801 m .34629 .62818 L .34847 .62768 L F
.008 0 0 r
.34841 .62689 m .34949 .62709 L .3511 .62611 L F
.189 0 .168 r
.58037 .6609 m .58377 .65764 L .5801 .66123 L F
.968 .832 .655 r
.55023 .6667 m .54892 .66626 L .54921 .66357 L F
.534 .619 .883 r
.55094 .66375 m .55023 .6667 L .54921 .66357 L F
.855 .936 .877 r
.55094 .66375 m .54892 .66626 L .55023 .6667 L F
.488 .296 .546 r
.54526 .64395 m .5421 .64436 L .54396 .64303 L F
.54526 .64395 m .54495 .64692 L .54394 .6461 L F
.154 .692 .713 r
.54396 .64303 m .54685 .64248 L .54526 .64395 L F
.534 .335 .557 r
.54755 .6459 m .54495 .64692 L .54526 .64395 L F
.806 .905 .91 r
.54713 .64252 m .54526 .64395 L .54685 .64248 L F
.542 .334 .547 r
.54713 .64252 m .54755 .6459 L .54526 .64395 L F
.334 .092 .39 r
.60909 .61747 m .60776 .61837 L .61011 .61549 L F
.195 .053 .45 r
.60909 .61747 m .60811 .62086 L .60776 .61837 L F
.559 .404 .627 r
.48545 .77706 m .4878 .77662 L .48787 .77465 L F
.946 .725 .573 r
.72893 .50807 m .72937 .50718 L .7302 .50577 L F
.495 .622 .905 r
.72827 .50922 m .72786 .50993 L .72918 .50978 L F
.72521 .50733 m .72786 .50993 L .72827 .50922 L F
.72521 .50733 m .72794 .50901 L .72802 .50973 L F
.72794 .50901 m .72918 .50978 L .72802 .50973 L F
.946 .725 .573 r
.72802 .50973 m .72918 .50978 L .72937 .50718 L F
.638 .607 .802 r
.729 .5086 m .72837 .50975 L .72802 .50973 L F
0 0 0 r
.72967 .51358 m .72844 .51187 L .7282 .51021 L F
.528 .612 .88 r
.73061 .51154 m .72997 .51428 L .72967 .51358 L F
.72842 .51033 m .72967 .51358 L .7282 .51021 L F
.73061 .51154 m .72967 .51358 L .72842 .51033 L F
.947 .736 .586 r
.72802 .50973 m .72819 .50974 L .72778 .51094 L F
.72819 .50974 m .72918 .50978 L .72844 .51039 L F
.979 .702 .312 r
.7282 .51021 m .72794 .51352 L .72767 .51103 L F
.947 .736 .586 r
.72778 .51092 m .72844 .51039 L .72778 .51094 L F
.72842 .51033 m .72844 .51039 L .72812 .51065 L F
.72811 .51062 m .72812 .51065 L .72778 .51092 L F
.979 .702 .312 r
.7282 .51021 m .72844 .51187 L .72816 .51079 L F
.947 .736 .586 r
.72842 .51033 m .72812 .51065 L .72811 .51062 L F
.979 .702 .312 r
.72844 .51187 m .72889 .51502 L .72816 .51079 L F
.72816 .51079 m .72846 .51255 L .72811 .51142 L F
.64 .24 .27 r
.72767 .51103 m .73061 .51154 L .72842 .51033 L F
.638 .607 .802 r
.729 .5086 m .73061 .51154 L .728 .51109 L F
.947 .736 .586 r
.72772 .51086 m .72778 .51094 L .72767 .51103 L F
.638 .607 .802 r
.72787 .51067 m .728 .51109 L .72767 .51103 L F
.64 .24 .27 r
.72767 .51103 m .72842 .51033 L .7282 .51021 L F
.947 .736 .586 r
.72819 .50974 m .72842 .51033 L .72778 .51092 L F
.638 .607 .802 r
.729 .5086 m .728 .51109 L .72787 .51067 L F
.979 .702 .312 r
.72811 .51142 m .72889 .51502 L .72794 .51352 L F
.72846 .51255 m .72889 .51502 L .72811 .51142 L F
.947 .736 .586 r
.72802 .50973 m .72778 .51094 L .72772 .51086 L F
0 0 0 r
.72997 .51428 m .72889 .51502 L .72844 .51187 L F
.72997 .51428 m .72844 .51187 L .72967 .51358 L F
.638 .607 .802 r
.72837 .50975 m .72808 .51028 L .72802 .50973 L F
.72808 .51028 m .72767 .51103 L .72802 .50973 L F
.946 .725 .573 r
.72802 .50973 m .72851 .50881 L .72893 .50807 L F
.72851 .50881 m .72937 .50718 L .72893 .50807 L F
.495 .622 .905 r
.72521 .50733 m .72708 .51001 L .72786 .50993 L F
.526 .4 .651 r
.27556 .60395 m .27742 .60098 L .27528 .60151 L F
.352 0 .158 r
.5925 .66991 m .59153 .67122 L .58946 .67168 L F
.258 0 .121 r
.59463 .6691 m .59153 .67122 L .5925 .66991 L F
.974 .674 .295 r
.54542 .75504 m .54559 .75723 L .54435 .75402 L F
.796 .918 .921 r
.54549 .75427 m .54542 .75504 L .54435 .75402 L F
0 0 .175 r
.54549 .75427 m .54559 .75723 L .54542 .75504 L F
.471 .572 .875 r
.29825 .63775 m .29812 .63845 L .29636 .63528 L F
.776 .852 .908 r
.29822 .63776 m .29812 .63845 L .29825 .63775 L F
.488 .616 .904 r
.29812 .63845 m .29939 .63654 L .29845 .63615 L F
.29812 .63845 m .29822 .63776 L .29636 .63528 L F
.519 .312 .538 r
.29822 .63774 m .29822 .63776 L .29825 .63775 L F
.488 .616 .904 r
.29822 .63776 m .29822 .63774 L .29822 .63774 L F
.29822 .63776 m .29822 .63774 L .29636 .63528 L F
.519 .312 .538 r
.2952 .63636 m .29493 .63854 L .29822 .63776 L F
.2952 .63636 m .29822 .63776 L .29822 .63774 L F
.929 .641 .474 r
.2952 .63636 m .29822 .63774 L .29636 .63528 L F
.29822 .63774 m .29825 .63775 L .29636 .63528 L F
.488 .616 .904 r
.29822 .63774 m .29845 .63615 L .29636 .63528 L F
.776 .852 .908 r
.29493 .63854 m .29812 .63845 L .29822 .63776 L F
.488 .616 .904 r
.29812 .63845 m .30024 .63809 L .29939 .63654 L F
.879 .521 .366 r
.54765 .65463 m .54664 .6567 L .5473 .6559 L F
.055 .459 .882 r
.42499 .70344 m .42572 .70286 L .42253 .70134 L F
.114 .549 .917 r
.42499 .70344 m .42675 .70386 L .42572 .70286 L F
.67 .262 .263 r
.52509 .70343 m .52155 .70475 L .52273 .70356 L F
0 0 0 r
.48465 .64309 m .48291 .64426 L .4838 .64349 L F
.163 0 0 r
.44107 .70901 m .44139 .70969 L .44043 .70988 L F
.44107 .70901 m .44319 .70865 L .44139 .70969 L F
.61 .424 .605 r
.5928 .61821 m .59543 .6182 L .59528 .61542 L F
.567 .403 .619 r
.59528 .61542 m .59777 .61496 L .59755 .61242 L F
.566 .4 .615 r
.59576 .61635 m .59528 .61542 L .59543 .6182 L F
.59576 .61635 m .59777 .61496 L .59528 .61542 L F
.569 .434 .657 r
.76487 .51232 m .76279 .51563 L .76262 .51325 L F
.798 .473 .438 r
.60406 .57504 m .60028 .57228 L .60354 .5729 L F
.451 .141 .348 r
.58022 .56351 m .58293 .56133 L .58075 .56192 L F
.759 .983 .909 r
.4916 .79087 m .48926 .79252 L .49001 .79098 L F
.579 .546 .782 r
.48883 .7948 m .49001 .79098 L .48926 .79252 L F
.798 .81 .861 r
.65904 .51364 m .65653 .51596 L .65638 .51412 L F
.65904 .51364 m .65638 .51412 L .65738 .51362 L F
.212 .317 .755 r
.65653 .51596 m .65738 .51362 L .65638 .51412 L F
.65653 .51596 m .65893 .51791 L .65738 .51362 L F
.771 .96 .93 r
.69368 .49413 m .69349 .49584 L .69595 .49561 L F
.587 .746 .953 r
.69595 .49561 m .69666 .49291 L .69368 .49413 L F
.69595 .49561 m .69987 .49531 L .69666 .49291 L F
.603 .758 .953 r
.69595 .49561 m .69937 .49576 L .69987 .49531 L F
.455 .151 .359 r
.58293 .56133 m .58534 .5608 L .58586 .55844 L F
.362 .021 .246 r
.58534 .5608 m .58817 .55808 L .58586 .55844 L F
.419 .016 .166 r
.53101 .70118 m .53034 .70296 L .52767 .70335 L F
.203 0 .083 r
.53308 .70149 m .53101 .70118 L .53307 .70156 L F
.53308 .70149 m .53034 .70296 L .53101 .70118 L F
.858 .807 .799 r
.72604 .49591 m .72241 .4978 L .72473 .49472 L F
.72604 .49591 m .7239 .49886 L .72241 .4978 L F
.863 .834 .817 r
.7282 .49304 m .72604 .49591 L .72473 .49472 L F
.687 .39 .465 r
.59663 .65186 m .59397 .64998 L .59689 .64984 L F
.571 .455 .682 r
.59853 .64667 m .59939 .64934 L .59689 .64984 L F
.531 .282 .483 r
.59939 .64934 m .59663 .65186 L .59689 .64984 L F
.257 .075 .432 r
.61203 .61209 m .61181 .61414 L .61011 .61549 L F
.259 .041 .38 r
.61181 .61414 m .60909 .61747 L .61011 .61549 L F
.817 .957 .906 r
.6927 .49514 m .69203 .49709 L .69349 .49584 L F
.6927 .49514 m .68961 .49746 L .69203 .49709 L F
.832 .495 .417 r
.72748 .47048 m .72927 .4728 L .73128 .47306 L F
.598 .562 .785 r
.44411 .67448 m .44285 .67767 L .44263 .67468 L F
.534 .26 .446 r
.68202 .48496 m .68201 .48697 L .67953 .48732 L F
.697 .492 .607 r
.68541 .48425 m .68201 .48697 L .68202 .48496 L F
0 0 .266 r
.55641 .61176 m .55756 .6091 L .55855 .61219 L F
.16 .293 .752 r
.55928 .6093 m .56039 .61287 L .55855 .61219 L F
0 0 0 r
.65899 .48993 m .65834 .4911 L .65698 .49271 L F
.044 .347 .823 r
.65834 .49267 m .65698 .49271 L .65834 .4911 L F
.65834 .49267 m .6601 .4949 L .65698 .49271 L F
.475 .149 .334 r
.44085 .65789 m .44331 .65741 L .444 .65522 L F
.425 .104 .315 r
.444 .65522 m .4453 .65701 L .44636 .65497 L F
.444 .65522 m .44331 .65741 L .4453 .65701 L F
.635 .415 .567 r
.71902 .47559 m .72151 .47575 L .72134 .47324 L F
0 0 .414 r
.72134 .47324 m .72277 .47409 L .7236 .47211 L F
.72134 .47324 m .72151 .47575 L .72277 .47409 L F
.417 .005 .148 r
.28047 .62813 m .28338 .62672 L .28096 .62781 L F
.389 .537 .882 r
.39985 .59689 m .399 .59894 L .39803 .59683 L F
.478 .64 .927 r
.39985 .59689 m .40114 .59897 L .399 .59894 L F
.905 .741 .668 r
.62212 .56631 m .62373 .56725 L .62234 .56393 L F
.907 .719 .637 r
.62204 .56912 m .62373 .56725 L .62212 .56631 L F
.62204 .56912 m .62339 .56964 L .62373 .56725 L F
.271 .746 .936 r
.32408 .58382 m .3262 .58368 L .32775 .58411 L F
.247 .749 .895 r
.3262 .58368 m .32989 .58369 L .32775 .58411 L F
.26 .515 .906 r
.75612 .48223 m .75262 .48199 L .75218 .48049 L F
.75612 .48223 m .7558 .48327 L .75262 .48199 L F
.43 .526 .854 r
.75608 .48501 m .75262 .48199 L .7558 .48327 L F
.14 .285 .752 r
.51129 .62621 m .51358 .62828 L .51256 .62959 L F
.971 .75 .546 r
.51358 .62828 m .51467 .63163 L .51256 .62959 L F
.736 .641 .754 r
.58205 .62641 m .58356 .62965 L .58578 .62676 L F
.546 .376 .603 r
.58356 .62965 m .5859 .62917 L .58578 .62676 L F
.667 .559 .724 r
.58363 .63232 m .5859 .62917 L .58356 .62965 L F
.569 .427 .648 r
.54703 .63374 m .5463 .63538 L .54858 .63489 L F
.509 .846 .997 r
.45627 .69801 m .45283 .69795 L .45492 .69737 L F
.068 .614 .84 r
.45492 .69737 m .45864 .69795 L .45627 .69801 L F
.799 .574 .597 r
.49845 .66004 m .50107 .66077 L .5007 .65828 L F
.035 0 0 r
.49497 .61895 m .49703 .61903 L .49819 .61905 L F
.058 .551 .889 r
.49703 .61903 m .50054 .62042 L .49819 .61905 L F
.156 0 0 r
.29501 .58926 m .29709 .58877 L .2988 .58735 L F
.312 0 0 r
.29709 .58877 m .30087 .58673 L .2988 .58735 L F
.603 .413 .597 r
.36904 .61236 m .37142 .60938 L .36886 .60978 L F
.729 .582 .69 r
.58458 .62361 m .58455 .62108 L .58233 .62392 L F
.708 .574 .702 r
.58458 .62361 m .58796 .62141 L .58455 .62108 L F
.62 .686 .89 r
.48507 .65412 m .48832 .65555 L .48738 .65379 L F
.569 .369 .57 r
.48602 .65809 m .48864 .65773 L .48832 .65555 L F
.48602 .65809 m .48864 .65773 L .48832 .65555 L F
.369 .588 .928 r
.48738 .65379 m .48832 .65555 L .48925 .65389 L F
.434 .276 .566 r
.48832 .65555 m .49053 .65625 L .48925 .65389 L F
.48832 .65555 m .48864 .65773 L .49053 .65625 L F
.49053 .65625 m .48864 .65773 L .48832 .65555 L F
.639 .121 0 r
.56644 .6343 m .56833 .63598 L .56694 .63477 L F
.56644 .6343 m .56849 .63663 L .56833 .63598 L F
.699 .336 0 r
.56849 .63663 m .56981 .63948 L .56833 .63598 L F
.7 .949 .956 r
.55889 .61788 m .55804 .6194 L .56011 .61818 L F
.704 .738 .877 r
.56011 .61818 m .55804 .6194 L .55889 .61788 L F
.784 .378 .283 r
.55127 .65808 m .55047 .6607 L .54927 .6582 L F
.174 0 .088 r
.55235 .65925 m .55127 .65808 L .5529 .65952 L F
.55235 .65925 m .55047 .6607 L .55127 .65808 L F
.899 .685 .605 r
.55369 .6582 m .5529 .65952 L .55127 .65808 L F
.146 0 .054 r
.47458 .63471 m .47627 .63416 L .47717 .63211 L F
.035 0 0 r
.47717 .63211 m .47901 .63164 L .4799 .6298 L F
.055 0 .015 r
.47717 .63211 m .47791 .63323 L .47901 .63164 L F
.47717 .63211 m .47627 .63416 L .47791 .63323 L F
.767 .791 .873 r
.67285 .51208 m .6759 .51231 L .67498 .51106 L F
.821 .891 .893 r
.67498 .51106 m .6759 .51231 L .67853 .50984 L F
.863 .834 .817 r
.7282 .49304 m .72473 .49472 L .72693 .49192 L F
.461 .448 .758 r
.41569 .68916 m .41646 .69234 L .41814 .69169 L F
.413 .148 .399 r
.41646 .69234 m .41784 .69346 L .41814 .69169 L F
.41646 .69234 m .41783 .6942 L .41784 .69346 L F
.96 .671 .242 r
.5814 .63488 m .58246 .63821 L .58166 .63723 L F
.86 .595 .535 r
.58246 .63821 m .58011 .64004 L .58166 .63723 L F
.529 .307 .522 r
.58619 .65528 m .58377 .65764 L .58588 .657 L F
.96 .671 .242 r
.58166 .63723 m .58246 .63821 L .5814 .63488 L F
.483 .231 .456 r
.58588 .657 m .58836 .65477 L .58619 .65528 L F
.347 .506 .874 r
.31968 .62307 m .31872 .62454 L .31803 .62294 L F
.493 .702 .963 r
.31968 .62307 m .32111 .62447 L .31872 .62454 L F
.618 .953 .917 r
.75563 .50998 m .75356 .51117 L .75273 .51077 L F
.533 .354 .584 r
.41566 .67565 m .41797 .67745 L .41795 .67478 L F
.41566 .67565 m .41574 .67798 L .41797 .67745 L F
.579 .471 .695 r
.59683 .6374 m .59746 .64102 L .59508 .64165 L F
.546 .433 .677 r
.59746 .64102 m .59549 .64388 L .59508 .64165 L F
.771 .96 .93 r
.69368 .49413 m .6927 .49514 L .69349 .49584 L F
.731 .721 .842 r
.46288 .67515 m .46607 .67497 L .46569 .67495 L F
.941 .919 .548 r
.46685 .67206 m .46569 .67495 L .46607 .67497 L F
.472 .002 .056 r
.58168 .67497 m .58079 .67632 L .57812 .67551 L F
.639 .276 .339 r
.58405 .67475 m .58079 .67632 L .58168 .67497 L F
.063 .036 .512 r
.73836 .49572 m .73757 .49873 L .73785 .49578 L F
.916 .89 .791 r
.73478 .49926 m .73757 .49873 L .73836 .49572 L F
.73478 .49926 m .73553 .50078 L .73757 .49873 L F
.772 .567 .621 r
.52437 .65801 m .52021 .6552 L .52334 .65667 L F
.52437 .65801 m .52129 .65829 L .52021 .6552 L F
.668 .123 0 r
.52439 .66072 m .52129 .65829 L .52437 .65801 L F
.531 .751 .977 r
.52334 .65667 m .52674 .65758 L .52437 .65801 L F
0 0 .205 r
.52479 .65872 m .52437 .65801 L .52439 .65801 L F
.525 .65859 m .52439 .65801 L .52674 .65758 L F
.52479 .65872 m .52439 .65801 L .525 .65859 L F
.137 .239 .707 r
.52334 .65667 m .52479 .65872 L .52674 .65758 L F
0 0 .505 r
.52442 .65776 m .52535 .65893 L .52334 .65667 L F
.52535 .65893 m .5256 .65924 L .52519 .65877 L F
.52535 .65893 m .52519 .65877 L .52334 .65667 L F
0 0 .205 r
.52479 .65872 m .52439 .66072 L .52437 .65801 L F
.236 .556 .933 r
.7517 .47927 m .74901 .47952 L .74823 .47796 L F
.7517 .47927 m .75218 .48049 L .74901 .47952 L F
.478 .17 .364 r
.45179 .65174 m .45409 .65142 L .45461 .64969 L F
.45 .16 .38 r
.45409 .65142 m .45676 .64914 L .45461 .64969 L F
.773 .702 .784 r
.49799 .79565 m .49492 .79494 L .49719 .7939 L F
.535 .668 .923 r
.49936 .79374 m .49799 .79565 L .49719 .7939 L F
.49936 .79374 m .50019 .79566 L .49799 .79565 L F
.341 .344 .717 r
.5931 .64656 m .59397 .64998 L .5956 .64853 L F
.5931 .64656 m .5956 .64853 L .59558 .64849 L F
.446 .804 .996 r
.5931 .64656 m .59538 .64617 L .59182 .64579 L F
.341 .344 .717 r
.5931 .64656 m .59562 .64852 L .59538 .64617 L F
.692 .384 .449 r
.5943 .64605 m .59191 .64819 L .59182 .64579 L F
.59538 .64617 m .5946 .64662 L .5943 .64605 L F
.5946 .64662 m .59191 .64819 L .5943 .64605 L F
.341 .344 .717 r
.59558 .64849 m .5956 .64853 L .59562 .64852 L F
.687 .39 .465 r
.59397 .64998 m .59663 .65186 L .59562 .64852 L F
.59397 .64998 m .59436 .65322 L .59663 .65186 L F
.59663 .65186 m .59436 .65322 L .59397 .64998 L F
.569 .427 .648 r
.54703 .63374 m .54858 .63489 L .54846 .63248 L F
.901 .766 .703 r
.7239 .49886 m .72088 .50079 L .72241 .4978 L F
.7239 .49886 m .72311 .50117 L .72088 .50079 L F
.662 .367 .462 r
.51989 .6638 m .52023 .66407 L .52061 .66615 L F
.52023 .66407 m .52251 .66587 L .52145 .66603 L F
.52023 .66407 m .52145 .66603 L .52061 .66615 L F
.483 .311 .572 r
.52159 .66625 m .52152 .66626 L .52145 .66603 L F
.683 .423 .523 r
.5211 .66494 m .52145 .66603 L .52061 .66615 L F
.669 .408 .517 r
.52061 .66615 m .52159 .66625 L .5211 .66494 L F
.662 .367 .462 r
.52251 .66587 m .5232 .66642 L .52244 .66588 L F
.683 .423 .523 r
.52145 .66603 m .52214 .6682 L .52061 .66615 L F
.662 .367 .462 r
.5215 .66602 m .52159 .66625 L .52061 .66615 L F
.669 .408 .517 r
.52159 .66625 m .5232 .66642 L .5211 .66494 L F
.5 .744 .982 r
.52265 .66606 m .5232 .66642 L .52159 .66625 L F
.016 .369 .837 r
.5211 .66494 m .5232 .66642 L .52315 .66607 L F
.343 .678 .978 r
.52315 .66607 m .5232 .66642 L .52265 .66606 L F
.483 .311 .572 r
.52315 .66607 m .52243 .6676 L .52165 .66604 L F
.52315 .66607 m .52165 .66604 L .5211 .66494 L F
.343 .678 .978 r
.52315 .66607 m .52265 .66606 L .52089 .66493 L F
.483 .311 .572 r
.52243 .6676 m .52145 .66603 L .5211 .66494 L F
.5 .744 .982 r
.52089 .66493 m .52265 .66606 L .52061 .66615 L F
.52265 .66606 m .52159 .66625 L .52061 .66615 L F
.483 .311 .572 r
.52159 .66625 m .52214 .6682 L .52152 .66626 L F
.52243 .6676 m .52224 .668 L .52159 .66625 L F
.52224 .668 m .52214 .6682 L .52159 .66625 L F
.622 .738 .93 r
.33108 .60086 m .33557 .60062 L .33364 .6006 L F
.118 0 0 r
.33364 .6006 m .32964 .60203 L .33108 .60086 L F
.606 .777 .963 r
.36821 .59719 m .37225 .59827 L .37037 .59672 L F
.542 .79 .99 r
.37225 .59827 m .37401 .59674 L .37037 .59672 L F
.37225 .59827 m .3744 .59776 L .37401 .59674 L F
.651 .659 .845 r
.37225 .59827 m .37503 .59884 L .3744 .59776 L F
.479 .254 .494 r
.39055 .61775 m .38813 .62039 L .38839 .61825 L F
.534 .38 .618 r
.60344 .62679 m .60374 .62922 L .60148 .62985 L F
.565 .369 .574 r
.60374 .62922 m .60124 .63211 L .60148 .62985 L F
.899 .685 .605 r
.55369 .6582 m .55484 .66099 L .5529 .65952 L F
.606 .252 .342 r
.55484 .66099 m .55129 .66303 L .5529 .65952 L F
.55484 .66099 m .5538 .66333 L .55129 .66303 L F
.484 .488 .786 r
.55645 .66028 m .55484 .66099 L .55369 .6582 L F
.559 .202 .32 r
.5568 .6627 m .55484 .66099 L .55645 .66028 L F
.5568 .6627 m .5538 .66333 L .55484 .66099 L F
.808 .835 .872 r
.74235 .51796 m .73928 .51851 L .74215 .51587 L F
.783 .846 .899 r
.74408 .51456 m .74235 .51796 L .74215 .51587 L F
.74408 .51456 m .74522 .51577 L .74235 .51796 L F
.189 0 .168 r
.58037 .6609 m .58284 .66012 L .58377 .65764 L F
.489 .16 .336 r
.58284 .66012 m .58588 .657 L .58377 .65764 L F
.142 0 0 r
.5174 .66618 m .51692 .66649 L .51413 .66662 L F
.5174 .66618 m .51692 .66649 L .51413 .66662 L F
0 0 0 r
.5174 .66618 m .51692 .66649 L .51793 .66596 L F
.5174 .66618 m .51692 .66649 L .51793 .66596 L F
.375 .842 .843 r
.69206 .47751 m .69139 .47745 L .68972 .47826 L F
0 0 .453 r
.69124 .47955 m .68972 .47826 L .69139 .47745 L F
.69124 .47955 m .68994 .4814 L .68972 .47826 L F
.393 .09 .328 r
.38239 .62509 m .38085 .62417 L .38301 .62369 L F
.38239 .62509 m .38026 .62576 L .38085 .62417 L F
.766 .619 .696 r
.61854 .54687 m .62205 .5473 L .62063 .54391 L F
.767 .609 .682 r
.62186 .54965 m .62205 .5473 L .61854 .54687 L F
.219 0 0 r
.53674 .70074 m .53549 .70144 L .53307 .70156 L F
.631 .231 .268 r
.5388 .70011 m .53549 .70144 L .53674 .70074 L F
.612 .588 .802 r
.54967 .63655 m .55127 .63546 L .54858 .63489 L F
.54967 .63655 m .55247 .63701 L .55127 .63546 L F
.59 .41 .606 r
.59042 .62108 m .59314 .62089 L .5928 .61821 L F
.406 .16 .425 r
.59314 .62089 m .59543 .6182 L .5928 .61821 L F
.613 .935 .959 r
.69987 .49531 m .69937 .49576 L .70158 .49474 L F
.523 .55 .825 r
.27674 .61194 m .27817 .61514 L .28015 .61479 L F
.66 .563 .735 r
.27817 .61514 m .28163 .6182 L .28015 .61479 L F
.215 .516 .914 r
.27614 .64672 m .2765 .64552 L .27859 .64642 L F
.552 .4 .628 r
.27614 .64672 m .27797 .64745 L .2762 .64798 L F
.569 .375 .579 r
.27859 .64642 m .27797 .64745 L .27676 .64697 L F
.27698 .64662 m .27676 .64697 L .27614 .64672 L F
.27859 .64642 m .27676 .64697 L .27698 .64662 L F
.933 .966 .748 r
.2762 .64798 m .27658 .6462 L .27614 .64672 L F
.794 .74 .803 r
.27345 .6485 m .27408 .65025 L .2762 .64798 L F
.22 0 0 r
.2762 .64798 m .27446 .64875 L .27345 .6485 L F
.933 .966 .748 r
.27624 .64778 m .27446 .64875 L .27658 .6462 L F
.2762 .64798 m .27609 .64803 L .27624 .64778 L F
.27609 .64803 m .27446 .64875 L .27624 .64778 L F
.215 .516 .914 r
.27614 .64672 m .27658 .6462 L .2765 .64552 L F
.568 .547 .79 r
.37939 .60394 m .38055 .59996 L .37831 .60064 L F
.37939 .60394 m .38162 .60343 L .38055 .59996 L F
.44 .151 .376 r
.37939 .60394 m .37885 .60601 L .38162 .60343 L F
.931 .753 .64 r
.60805 .59003 m .60573 .59121 L .6067 .58897 L F
.60805 .59003 m .60722 .59216 L .60573 .59121 L F
.814 .947 .596 r
.29073 .63994 m .29185 .63885 L .29088 .63753 L F
.662 .188 .116 r
.29493 .63854 m .29088 .63753 L .29185 .63885 L F
.511 .284 .507 r
.41976 .66663 m .41718 .66954 L .41953 .66905 L F
.355 .201 .53 r
.41976 .66663 m .42152 .66618 L .42159 .66347 L F
.396 .326 .661 r
.41976 .66663 m .4219 .66861 L .42152 .66618 L F
.561 .326 .517 r
.41976 .66663 m .41953 .66905 L .4219 .66861 L F
0 0 .126 r
.49495 .65899 m .49355 .6616 L .49461 .66061 L F
.707 .573 .702 r
.5881 .62393 m .59042 .62108 L .58796 .62141 L F
.604 .428 .617 r
.5881 .62393 m .59084 .62366 L .59042 .62108 L F
.563 .302 .478 r
.59279 .62297 m .59042 .62108 L .59084 .62366 L F
.59279 .62297 m .59314 .62089 L .59042 .62108 L F
.913 .626 .486 r
.50613 .70354 m .5043 .7013 L .5043 .70244 L F
.50613 .70354 m .50617 .70119 L .5043 .7013 L F
.708 .574 .702 r
.58458 .62361 m .5881 .62393 L .58796 .62141 L F
0 0 .326 r
.73107 .52116 m .73238 .52441 L .73194 .52316 L F
0 0 .56 r
.73194 .52316 m .73238 .52441 L .73418 .52689 L F
.554 .552 .806 r
.53845 .69645 m .54147 .69754 L .53922 .69802 L F
.454 .197 .434 r
.54147 .69754 m .5388 .70011 L .53922 .69802 L F
.989 .779 .53 r
.48823 .6601 m .48864 .65773 L .48602 .65809 L F
.558 .332 .528 r
.48864 .65773 m .48823 .6601 L .48602 .65809 L F
.612 .242 .316 r
.67464 .47891 m .67728 .48055 L .67814 .47843 L F
.285 0 0 r
.67728 .48055 m .68053 .47868 L .67814 .47843 L F
.828 .704 .727 r
.68761 .48408 m .68878 .48749 L .68759 .48637 L F
.729 .654 .775 r
.69099 .48548 m .68878 .48749 L .68761 .48408 L F
0 0 0 r
.52346 .76391 m .52381 .76391 L .52553 .76286 L F
.408 .269 .579 r
.52553 .76286 m .52346 .76391 L .52477 .76243 L F
.52477 .76243 m .52346 .76391 L .52553 .76286 L F
0 .312 .795 r
.52381 .76391 m .52582 .76527 L .52346 .76391 L F
.362 .569 .917 r
.37503 .59884 m .37626 .59788 L .3744 .59776 L F
.37503 .59884 m .37831 .60064 L .37626 .59788 L F
.587 .83 .99 r
.7182 .48496 m .71455 .48464 L .71677 .48357 L F
.055 0 0 r
.33646 .64588 m .33441 .64652 L .3348 .64606 L F
0 0 .327 r
.49184 .66433 m .49213 .66561 L .49233 .66268 L F
.176 0 .375 r
.49213 .66561 m .49079 .66659 L .49184 .66433 L F
.49213 .66561 m .49079 .66659 L .49184 .66433 L F
.683 .498 .629 r
.58678 .63465 m .58363 .63232 L .58475 .63533 L F
0 0 .071 r
.58496 .63779 m .58678 .63465 L .58475 .63533 L F
.825 .68 .704 r
.57601 .62899 m .57812 .62989 L .57647 .62641 L F
.84 .735 .748 r
.57419 .63172 m .57812 .62989 L .57601 .62899 L F
.57419 .63172 m .57504 .6336 L .57812 .62989 L F
.728 .643 .764 r
.57647 .62641 m .57812 .62989 L .58006 .62851 L F
.497 .214 .414 r
.35628 .62386 m .35851 .62358 L .3592 .62079 L F
.447 .168 .396 r
.3592 .62079 m .36087 .62293 L .3614 .62023 L F
.3592 .62079 m .35851 .62358 L .36087 .62293 L F
.711 .543 .659 r
.61176 .544 m .61498 .5441 L .61494 .54157 L F
.006 .388 .846 r
.30665 .6442 m .30894 .6464 L .30929 .64556 L F
.133 .546 .922 r
.30894 .6464 m .31128 .64708 L .30929 .64556 L F
0 0 0 r
.3625 .59744 m .35924 .59826 L .36019 .59799 L F
.066 0 .164 r
.48219 .62682 m .4799 .6298 L .48135 .62848 L F
0 0 0 r
.4799 .6298 m .48044 .63047 L .48135 .62848 L F
.4799 .6298 m .47901 .63164 L .48044 .63047 L F
.708 .571 .698 r
.58578 .62676 m .5881 .62393 L .58458 .62361 L F
.589 .403 .597 r
.58578 .62676 m .58822 .62638 L .5881 .62393 L F
.588 .361 .539 r
.59071 .62597 m .5881 .62393 L .58822 .62638 L F
.59071 .62597 m .59084 .62366 L .5881 .62393 L F
.744 .588 .682 r
.58205 .62641 m .58458 .62361 L .58233 .62392 L F
.58205 .62641 m .58578 .62676 L .58458 .62361 L F
.407 0 .142 r
.35328 .62538 m .35628 .62386 L .35425 .62444 L F
.546 .433 .677 r
.59746 .64102 m .59777 .64328 L .59549 .64388 L F
.286 .787 .813 r
.53991 .59625 m .54259 .59558 L .54347 .59556 L F
0 0 0 r
.54347 .59556 m .54477 .5944 L .54593 .59277 L F
.532 .923 .857 r
.54347 .59556 m .54259 .59558 L .54477 .5944 L F
.521 .238 .425 r
.43585 .6606 m .43817 .66035 L .43861 .65835 L F
.506 .237 .441 r
.43817 .66035 m .44085 .65789 L .43861 .65835 L F
.289 .747 .954 r
.36022 .58717 m .36233 .58705 L .36381 .58759 L F
.376 .794 .977 r
.36233 .58705 m .36602 .58731 L .36381 .58759 L F
.565 .35 .547 r
.55043 .64344 m .54755 .6459 L .54713 .64252 L F
.3 0 0 r
.54685 .64248 m .55043 .64344 L .54713 .64252 L F
.068 0 .258 r
.48401 .62372 m .48219 .62682 L .48331 .62593 L F
0 0 0 r
.48135 .62848 m .48331 .62593 L .48219 .62682 L F
.481 .628 .917 r
.54616 .62951 m .54846 .63248 L .55001 .6309 L F
.614 .431 .612 r
.54846 .63248 m .55155 .63431 L .55001 .6309 L F
.54846 .63248 m .54858 .63489 L .55155 .63431 L F
0 .138 .684 r
.42675 .70386 m .42828 .70649 L .42785 .70508 L F
.59 .051 0 r
.42828 .70649 m .43103 .70909 L .42918 .70774 L F
.42828 .70649 m .42918 .70774 L .42785 .70508 L F
0 0 0 r
.66457 .50729 m .66738 .50309 L .66847 .50442 L F
0 0 .308 r
.66528 .50905 m .66457 .50729 L .66469 .50711 L F
0 0 .058 r
.66457 .50729 m .66499 .50803 L .66565 .50574 L F
.938 .777 .656 r
.66565 .50574 m .66499 .50803 L .66444 .50763 L F
0 0 0 r
.66457 .50729 m .66565 .50574 L .66613 .50499 L F
0 0 .308 r
.66469 .50711 m .66457 .50729 L .66441 .50621 L F
.938 .777 .656 r
.66565 .50574 m .66444 .50763 L .66353 .50698 L F
0 0 0 r
.66613 .50499 m .66565 .50574 L .66644 .50453 L F
.66457 .50729 m .66644 .50453 L .66738 .50309 L F
.485 .296 .549 r
.59755 .61242 m .59984 .61188 L .59978 .60956 L F
.498 .348 .608 r
.59777 .61496 m .59984 .61188 L .59755 .61242 L F
.229 0 .261 r
.58037 .6609 m .58068 .66267 L .58284 .66012 L F
.605 .599 .819 r
.28163 .6182 m .28558 .62108 L .2832 .61788 L F
.212 .422 .849 r
.28558 .62108 m .28591 .61938 L .2832 .61788 L F
.28558 .62108 m .28643 .62049 L .28591 .61938 L F
.15 0 .217 r
.31771 .6072 m .3171 .60903 L .31562 .60969 L F
.342 .265 .623 r
.3171 .60903 m .31747 .6116 L .31562 .60969 L F
.407 .273 .584 r
.31562 .60969 m .31747 .6116 L .31564 .61221 L F
.513 .174 .33 r
.36794 .63228 m .36684 .63472 L .36438 .63485 L F
.345 .011 .247 r
.36894 .63408 m .36794 .63228 L .3701 .63198 L F
.36894 .63408 m .36684 .63472 L .36794 .63228 L F
.327 0 .223 r
.57524 .5666 m .57757 .56581 L .57817 .56435 L F
.427 .14 .373 r
.57757 .56581 m .58022 .56351 L .57817 .56435 L F
0 0 0 r
.54593 .59277 m .54717 .59196 L .54738 .59144 L F
.54593 .59277 m .54477 .5944 L .54717 .59196 L F
.339 0 0 r
.45541 .7059 m .45393 .70649 L .45169 .70648 L F
.516 .02 .016 r
.45746 .70624 m .45393 .70649 L .45541 .7059 L F
.386 .287 .619 r
.4147 .68362 m .41665 .68549 L .41656 .68309 L F
.4147 .68362 m .4147 .68687 L .41665 .68549 L F
.51 .905 .774 r
.74441 .53121 m .74279 .53251 L .74437 .53152 L F
.529 .899 .964 r
.74199 .53209 m .74279 .53251 L .74441 .53121 L F
.415 0 0 r
.49001 .79098 m .49339 .79142 L .4916 .79087 L F
.448 .615 .921 r
.39617 .59441 m .39535 .59632 L .39425 .5944 L F
.39617 .59441 m .39803 .59683 L .39535 .59632 L F
.853 .839 .831 r
.2864 .64385 m .28967 .64313 L .28862 .64209 L F
.774 .839 .38 r
.28967 .64313 m .29073 .63994 L .28862 .64209 L F
.369 .168 .471 r
.40631 .7001 m .40415 .7032 L .40629 .70159 L F
.389 0 0 r
.44348 .69656 m .44528 .69744 L .44645 .69779 L F
.95 .596 .248 r
.44528 .69744 m .44714 .70025 L .44645 .69779 L F
.441 0 .039 r
.53181 .69728 m .53441 .69733 L .53546 .69601 L F
0 .563 .794 r
.53546 .69601 m .53841 .69632 L .53845 .69645 L F
.395 0 .013 r
.53546 .69601 m .53441 .69733 L .53841 .69632 L F
.554 .449 .688 r
.76354 .49253 m .7641 .49486 L .7615 .49532 L F
.535 .451 .707 r
.76426 .49813 m .7615 .49532 L .7641 .49486 L F
.76426 .49813 m .76214 .49872 L .7615 .49532 L F
.091 .24 .726 r
.56467 .66315 m .5656 .66207 L .56383 .66021 L F
.159 .347 .802 r
.56467 .66315 m .56623 .66411 L .5656 .66207 L F
.954 .841 .412 r
.72729 .48007 m .72761 .48134 L .72812 .47878 L F
.72729 .48007 m .72761 .48134 L .72812 .47878 L F
.56 .568 .819 r
.43864 .69111 m .43988 .69429 L .43784 .69458 L F
0 0 0 r
.6611 .48761 m .65834 .4911 L .65899 .48993 L F
.538 .878 .625 r
.59327 .66092 m .59442 .65976 L .59538 .6591 L F
.162 .297 .755 r
.59223 .65747 m .59442 .65976 L .59327 .66092 L F
.553 .36 .573 r
.5859 .62917 m .58822 .62638 L .58578 .62676 L F
.666 .565 .732 r
.58175 .62592 m .58006 .62851 L .58205 .62641 L F
.646 .874 .983 r
.4326 .70772 m .43201 .7094 L .43425 .70842 L F
.77 .985 .903 r
.43103 .70909 m .43201 .7094 L .4326 .70772 L F
.363 .109 .388 r
.46757 .64117 m .4691 .64248 L .46951 .64044 L F
.46757 .64117 m .46708 .64323 L .4691 .64248 L F
.679 .313 .346 r
.50807 .65113 m .50481 .64996 L .50777 .6496 L F
.212 0 0 r
.35374 .63986 m .34944 .64171 L .35158 .64027 L F
.526 .4 .651 r
.27556 .60395 m .27764 .60345 L .27742 .60098 L F
.527 .438 .698 r
.27556 .60395 m .2781 .60603 L .27764 .60345 L F
.27556 .60395 m .27608 .60677 L .2781 .60603 L F
0 0 0 r
.54494 .65545 m .54303 .65626 L .54138 .65689 L F
0 .175 .706 r
.54494 .65545 m .5451 .65363 L .54303 .65626 L F
.54494 .65545 m .54664 .6567 L .5451 .65363 L F
.943 .863 .439 r
.49954 .67081 m .49904 .67174 L .5001 .66968 L F
.191 0 0 r
.5025 .66967 m .49954 .67081 L .5001 .66968 L F
0 0 0 r
.5001 .66968 m .49904 .67174 L .50111 .66804 L F
.355 .817 .72 r
.53602 .59708 m .53676 .5966 L .5374 .59701 L F
.53602 .59708 m .53421 .59778 L .53676 .5966 L F
.603 .413 .597 r
.36904 .61236 m .37111 .61216 L .37142 .60938 L F
.65 .455 .606 r
.37142 .60938 m .37424 .61165 L .37359 .60844 L F
.37142 .60938 m .37111 .61216 L .37424 .61165 L F
.502 0 0 r
.33737 .60046 m .33364 .6006 L .33557 .60062 L F
.33737 .60046 m .33577 .60095 L .33364 .6006 L F
.176 0 0 r
.33945 .60033 m .33577 .60095 L .33737 .60046 L F
.516 .755 .983 r
.33424 .58288 m .33353 .58448 L .33207 .58343 L F
.33424 .58288 m .33565 .58409 L .33353 .58448 L F
.539 .328 .542 r
.59883 .63244 m .5988 .63471 L .59642 .63518 L F
.497 .262 .488 r
.60124 .63211 m .5988 .63471 L .59883 .63244 L F
.728 .699 .823 r
.27907 .62341 m .28092 .62526 L .28282 .62389 L F
.713 .544 .659 r
.61847 .54439 m .61854 .54687 L .62063 .54391 L F
.367 .066 .316 r
.31912 .6084 m .31771 .6072 L .31983 .60673 L F
.31912 .6084 m .3171 .60903 L .31771 .6072 L F
.595 .193 .251 r
.66444 .48622 m .6611 .48761 L .66178 .4867 L F
.767 .609 .682 r
.62186 .54965 m .61854 .54687 L .61861 .54941 L F
.78 .592 .645 r
.61861 .54941 m .62008 .55256 L .62186 .54965 L F
.956 .618 .235 r
.69309 .47211 m .69364 .47338 L .69471 .47328 L F
.37 0 0 r
.69757 .47208 m .69309 .47211 L .69471 .47328 L F
.402 .581 .913 r
.7575 .48353 m .75608 .48501 L .7558 .48327 L F
.7575 .48353 m .75909 .48595 L .75608 .48501 L F
0 0 .461 r
.73483 .52785 m .73533 .52821 L .73418 .52689 L F
.73483 .52785 m .73584 .53011 L .73533 .52821 L F
.397 .739 .992 r
.28163 .6182 m .2832 .61788 L .28023 .61714 L F
.561 .448 .682 r
.56817 .61752 m .56526 .61555 L .56534 .61374 L F
.56817 .61752 m .56595 .61834 L .56526 .61555 L F
.491 .324 .582 r
.49345 .63709 m .49106 .63834 L .49282 .63517 L F
.731 .633 .749 r
.49345 .63709 m .49025 .64059 L .49106 .63834 L F
.284 0 .165 r
.5907 .67312 m .58946 .67168 L .59153 .67122 L F
.5907 .67312 m .58868 .67382 L .58946 .67168 L F
.597 .569 .793 r
.57467 .65779 m .57148 .65544 L .57328 .65461 L F
.939 .572 .262 r
.57812 .67551 m .57712 .67653 L .57637 .67431 L F
.438 0 0 r
.58079 .67632 m .57712 .67653 L .57812 .67551 L F
.529 .003 0 r
.53676 .5966 m .53991 .59625 L .5374 .59701 L F
.28 0 .228 r
.37816 .62639 m .37716 .629 L .37556 .6286 L F
.402 .076 .294 r
.38026 .62576 m .37716 .629 L .37816 .62639 L F
0 0 0 r
.48401 .62372 m .4855 .62256 L .48665 .62096 L F
0 0 .134 r
.48331 .62593 m .4855 .62256 L .48401 .62372 L F
.554 .439 .677 r
.41765 .67193 m .41953 .66905 L .41718 .66954 L F
0 0 .271 r
.56382 .65818 m .56454 .65863 L .56418 .65666 L F
.56382 .65818 m .56383 .66021 L .56454 .65863 L F
.505 .669 .937 r
.39269 .59243 m .39211 .59465 L .39037 .59212 L F
.39269 .59243 m .39425 .5944 L .39211 .59465 L F
.687 .787 .926 r
.69932 .48162 m .69564 .4814 L .69727 .47953 L F
0 .232 .629 r
.6987 .48312 m .69564 .4814 L .69932 .48162 L F
.456 .515 .831 r
.70112 .47974 m .69932 .48162 L .69727 .47953 L F
.70112 .47974 m .70148 .4814 L .69932 .48162 L F
.591 .597 .827 r
.70296 .48363 m .69932 .48162 L .70148 .4814 L F
.741 .345 .302 r
.67711 .48719 m .6761 .48875 L .67389 .48663 L F
.535 .095 .15 r
.67953 .48732 m .6761 .48875 L .67711 .48719 L F
.921 .81 .719 r
.72962 .48461 m .72757 .48522 L .72847 .48393 L F
.72962 .48461 m .72886 .4865 L .72757 .48522 L F
.676 .872 .973 r
.67138 .50402 m .67231 .50204 L .67427 .50224 L F
.67138 .50402 m .6704 .50305 L .67231 .50204 L F
.284 0 0 r
.34551 .64273 m .34194 .64436 L .34336 .64326 L F
.293 0 .198 r
.37436 .63055 m .3729 .62992 L .37556 .6286 L F
.289 0 .061 r
.37716 .629 m .37436 .63055 L .37556 .6286 L F
.038 .114 .615 r
.51986 .6519 m .52142 .65457 L .52021 .6552 L F
.077 .468 .889 r
.52246 .65546 m .52021 .6552 L .52142 .65457 L F
.52246 .65546 m .52334 .65667 L .52021 .6552 L F
.626 .28 .364 r
.50988 .70067 m .51211 .70256 L .51285 .70038 L F
.375 .042 .266 r
.51285 .70038 m .5144 .70195 L .5153 .69974 L F
.51285 .70038 m .51211 .70256 L .5144 .70195 L F
.607 .634 .852 r
.27978 .64963 m .2762 .64798 L .27797 .64745 L F
.2762 .64798 m .27978 .64963 L .27797 .64745 L F
.8 .671 .722 r
.27797 .64745 m .27978 .64963 L .27859 .64642 L F
.81 .582 .594 r
.62101 .55828 m .62103 .56071 L .62402 .56096 L F
.902 .779 .715 r
.62109 .563 m .62402 .56096 L .62103 .56071 L F
.62109 .563 m .62234 .56393 L .62402 .56096 L F
.591 .835 .991 r
.55457 .60872 m .55554 .60986 L .55756 .6091 L F
.997 .841 .561 r
.55457 .60872 m .55404 .61108 L .55554 .60986 L F
0 0 .266 r
.55641 .61176 m .5568 .61208 L .55756 .6091 L F
.469 .289 .553 r
.55554 .60986 m .5568 .61208 L .55756 .6091 L F
.64 .966 .872 r
.73926 .47321 m .73638 .47478 L .73888 .47535 L F
.294 .095 .43 r
.61297 .6107 m .61424 .6118 L .61203 .61209 L F
.252 0 .256 r
.61203 .61209 m .61342 .6135 L .61181 .61414 L F
.61203 .61209 m .61424 .6118 L .61342 .6135 L F
.802 .472 .429 r
.60028 .57228 m .59666 .56961 L .60051 .5699 L F
0 0 0 r
.48665 .62096 m .4878 .62015 L .48886 .62027 L F
.48665 .62096 m .4855 .62256 L .4878 .62015 L F
.89 .886 .822 r
.28632 .64074 m .28389 .64418 L .28266 .6431 L F
.495 .531 .823 r
.28389 .64418 m .28514 .64215 L .28266 .6431 L F
.28389 .64418 m .2864 .64385 L .28514 .64215 L F
.715 .792 .912 r
.69704 .4848 m .69346 .4844 L .69593 .48367 L F
.829 .893 .887 r
.6987 .48312 m .69704 .4848 L .69593 .48367 L F
.725 .957 .674 r
.27469 .62883 m .27516 .62756 L .2768 .62629 L F
.7 .653 .8 r
.27909 .62852 m .27469 .62883 L .2768 .62629 L F
.416 0 0 r
.27909 .62852 m .27634 .62958 L .27469 .62883 L F
.007 .289 .786 r
.27469 .62883 m .27634 .62958 L .27516 .62756 L F
.522 .371 .617 r
.76426 .49813 m .76241 .50122 L .76214 .49872 L F
.605 .432 .621 r
.60618 .62378 m .60648 .62627 L .60344 .62679 L F
.565 .309 .487 r
.60344 .62679 m .60619 .62867 L .60374 .62922 L F
.60344 .62679 m .60648 .62627 L .60619 .62867 L F
.849 .785 .79 r
.51033 .65202 m .51339 .65178 L .51247 .65102 L F
.51033 .65202 m .51197 .65382 L .51339 .65178 L F
.487 .64 .923 r
.51339 .65178 m .51416 .64917 L .51247 .65102 L F
.51339 .65178 m .51602 .65157 L .51416 .64917 L F
.32 .665 .974 r
.37903 .58953 m .37582 .58838 L .37769 .58826 L F
.365 .677 .977 r
.37973 .58832 m .37903 .58953 L .37769 .58826 L F
.442 .769 .997 r
.37973 .58832 m .38116 .58928 L .37903 .58953 L F
.53 .215 .378 r
.46507 .65826 m .46477 .66041 L .46193 .66062 L F
.555 .236 .383 r
.46734 .65983 m .46477 .66041 L .46507 .65826 L F
.966 .718 .511 r
.6073 .58406 m .6055 .58544 L .60536 .58302 L F
.6073 .58406 m .60722 .58656 L .6055 .58544 L F
.086 .476 .893 r
.67884 .49653 m .68089 .495 L .6782 .49452 L F
.319 0 .019 r
.41884 .70436 m .41558 .70607 L .41581 .70347 L F
.41884 .70436 m .41793 .70573 L .41558 .70607 L F
.642 .826 .41 r
.41913 .70419 m .41884 .70436 L .42163 .70358 L F
.529 .359 .595 r
.42197 .70369 m .42058 .70616 L .42012 .70389 L F
.642 .826 .41 r
.41877 .70427 m .42163 .70358 L .42014 .70251 L F
.529 .359 .595 r
.42152 .70346 m .42012 .70389 L .41987 .7026 L F
.42197 .70369 m .42012 .70389 L .42152 .70346 L F
.642 .826 .41 r
.41877 .70427 m .41878 .70429 L .41913 .70419 L F
.41878 .70429 m .41884 .70436 L .41913 .70419 L F
.41877 .70427 m .41793 .70573 L .41884 .70436 L F
0 0 0 r
.27675 .64813 m .2762 .64798 L .27797 .64745 L F
.27675 .64813 m .27446 .64875 L .2762 .64798 L F
.519 .034 .044 r
.46101 .70599 m .45997 .70742 L .45746 .70624 L F
.607 .17 .184 r
.46329 .70613 m .45997 .70742 L .46101 .70599 L F
.916 .949 .805 r
.65904 .51364 m .65849 .51064 L .66079 .51293 L F
.65904 .51364 m .65738 .51362 L .65849 .51064 L F
.132 .233 .703 r
.56065 .64903 m .56141 .65238 L .56258 .65106 L F
.156 .271 .732 r
.56141 .65238 m .56368 .65447 L .56258 .65106 L F
.596 .348 .511 r
.44285 .67767 m .44219 .68067 L .43973 .6804 L F
.598 .562 .785 r
.44411 .67448 m .44519 .67755 L .44285 .67767 L F
.625 .375 .519 r
.44515 .67987 m .44285 .67767 L .44519 .67755 L F
.44515 .67987 m .44219 .68067 L .44285 .67767 L F
.855 .709 .701 r
.7065 .47316 m .70337 .47259 L .70467 .46943 L F
.758 .629 .717 r
.70624 .47533 m .70337 .47259 L .7065 .47316 L F
.512 .563 .845 r
.70745 .46979 m .7065 .47316 L .70467 .46943 L F
.70745 .46979 m .70818 .47224 L .7065 .47316 L F
.272 .074 .418 r
.70818 .47224 m .70624 .47533 L .7065 .47316 L F
.551 .849 .998 r
.73684 .49498 m .73785 .49578 L .73946 .49429 L F
.063 .036 .512 r
.73836 .49572 m .73785 .49578 L .73684 .49498 L F
.559 .865 .996 r
.73946 .49429 m .73789 .49575 L .74014 .49515 L F
.403 .852 .779 r
.73898 .4938 m .73684 .49498 L .73946 .49429 L F
.72 .987 .819 r
.73709 .4951 m .73695 .49486 L .73836 .49572 L F
.73695 .49486 m .7371 .49471 L .73836 .49572 L F
.73684 .49498 m .73681 .49487 L .73709 .4951 L F
.559 .865 .996 r
.73789 .49575 m .73785 .49578 L .73791 .49576 L F
.904 .873 .796 r
.73388 .49787 m .73836 .49572 L .7371 .49471 L F
.72 .987 .819 r
.73695 .49486 m .73664 .49433 L .7371 .49471 L F
.659 .798 .949 r
.73502 .49353 m .73719 .49461 L .73898 .4938 L F
.72 .987 .819 r
.73664 .49433 m .73663 .49433 L .73665 .49434 L F
.73664 .49433 m .73665 .49434 L .7371 .49471 L F
.659 .798 .949 r
.73485 .4932 m .73502 .49353 L .73898 .4938 L F
.72 .987 .819 r
.73684 .49498 m .73589 .4952 L .73663 .49433 L F
.659 .798 .949 r
.73638 .49463 m .73589 .4952 L .73666 .49485 L F
.73502 .49353 m .73589 .4952 L .73638 .49463 L F
.73502 .49353 m .73666 .49485 L .73665 .49434 L F
.72 .987 .819 r
.73663 .49433 m .73589 .4952 L .73663 .49433 L F
.904 .873 .796 r
.73607 .49505 m .73666 .49485 L .73663 .49433 L F
.72 .987 .819 r
.73681 .49487 m .73663 .49433 L .73709 .4951 L F
.904 .873 .796 r
.73666 .49485 m .7371 .49471 L .73665 .49434 L F
.73666 .49485 m .73665 .49434 L .73663 .49433 L F
.659 .798 .949 r
.73665 .49434 m .73666 .49485 L .73719 .49461 L F
.403 .852 .779 r
.73719 .49461 m .73589 .4952 L .73684 .49498 L F
.904 .873 .796 r
.73388 .49787 m .7371 .49471 L .73607 .49505 L F
.403 .852 .779 r
.73898 .4938 m .73719 .49461 L .7371 .49471 L F
.73769 .49451 m .7371 .49471 L .73684 .49498 L F
.73898 .4938 m .7371 .49471 L .73769 .49451 L F
.559 .865 .996 r
.73789 .49575 m .73791 .49576 L .74014 .49515 L F
.568 .294 .461 r
.52067 .69585 m .52231 .69675 L .52391 .69489 L F
.735 .456 .506 r
.52231 .69675 m .52625 .69745 L .52391 .69489 L F
.743 .642 .748 r
.68994 .4814 m .69099 .48548 L .68761 .48408 L F
.603 .555 .773 r
.69346 .4844 m .69099 .48548 L .68994 .4814 L F
.528 .532 .803 r
.44221 .69371 m .44143 .69661 L .43988 .69429 L F
.44221 .69371 m .44348 .69656 L .44143 .69661 L F
.462 .278 .545 r
.59984 .61188 m .60191 .60901 L .59978 .60956 L F
.531 .307 .52 r
.5952 .62017 m .59576 .61635 L .59543 .6182 L F
.5952 .62017 m .59761 .61965 L .59576 .61635 L F
.443 .169 .401 r
.59959 .61663 m .59777 .61496 L .59576 .61635 L F
.513 .371 .625 r
.59761 .61965 m .59959 .61663 L .59576 .61635 L F
.513 .287 .508 r
.36647 .6176 m .36905 .61479 L .36701 .61549 L F
0 0 0 r
.33441 .64652 m .33028 .64794 L .3323 .64709 L F
.205 .256 .695 r
.46206 .67164 m .46288 .67515 L .4641 .6734 L F
.539 .719 .956 r
.46288 .67515 m .46569 .67495 L .4641 .6734 L F
.005 .575 .777 r
.48528 .70247 m .48884 .70287 L .4867 .70272 L F
.299 .411 .808 r
.49525 .7956 m .49437 .7961 L .49572 .79594 L F
0 0 0 r
.49492 .79494 m .49301 .79688 L .49437 .7961 L F
.473 .8 1 r
.49115 .79453 m .49492 .79494 L .49319 .79408 L F
.94 .614 .387 r
.49319 .79408 m .49492 .79494 L .49437 .7961 L F
.299 .411 .808 r
.49319 .79408 m .49437 .7961 L .49525 .7956 L F
0 0 0 r
.49301 .79688 m .49256 .79735 L .49437 .7961 L F
.326 .316 .695 r
.49256 .79735 m .49515 .80003 L .49437 .7961 L F
.888 .802 .758 r
.72088 .50079 m .72311 .50117 L .72121 .50174 L F
.584 .446 .658 r
.50617 .70119 m .50938 .70308 L .50988 .70067 L F
.583 .298 .449 r
.50988 .70067 m .50938 .70308 L .51211 .70256 L F
.355 0 .101 r
.303 .58623 m .30526 .58582 L .30665 .58385 L F
.23 0 .027 r
.30665 .58385 m .3073 .58517 L .30883 .58356 L F
.30665 .58385 m .30526 .58582 L .3073 .58517 L F
.546 .199 .332 r
.51247 .65102 m .5112 .65194 L .51033 .65202 L F
.618 .641 .851 r
.50947 .6521 m .51197 .65382 L .51033 .65202 L F
.546 .199 .332 r
.5112 .65194 m .50903 .65353 L .51033 .65202 L F
.618 .641 .851 r
.50807 .65113 m .50947 .6521 L .51033 .65202 L F
.59 .273 .401 r
.67472 .48059 m .67728 .48055 L .67464 .47891 L F
.568 .422 .642 r
.59642 .63518 m .59904 .63701 L .59683 .6374 L F
.59642 .63518 m .5988 .63471 L .59904 .63701 L F
.718 .548 .659 r
.61524 .54677 m .61847 .54439 L .61498 .5441 L F
.61524 .54677 m .61854 .54687 L .61847 .54439 L F
0 .564 .781 r
.73149 .47303 m .73279 .47329 L .72927 .4728 L F
0 .403 .788 r
.73441 .47361 m .73279 .47329 L .73149 .47303 L F
.73441 .47361 m .73531 .47428 L .73279 .47329 L F
.662 .438 .569 r
.59876 .55225 m .60112 .55252 L .60137 .54978 L F
.647 .424 .567 r
.60137 .54978 m .60432 .5516 L .60424 .54955 L F
.60137 .54978 m .60112 .55252 L .60432 .5516 L F
.508 0 0 r
.53841 .69632 m .54147 .69754 L .53845 .69645 L F
.191 .432 .862 r
.56774 .66643 m .56868 .66533 L .56623 .66411 L F
.194 .437 .865 r
.56774 .66643 m .57108 .66825 L .56868 .66533 L F
.46 .787 .999 r
.37034 .58655 m .3696 .5878 L .3682 .58694 L F
.37034 .58655 m .37179 .58745 L .3696 .5878 L F
.154 .692 .713 r
.54538 .64276 m .54704 .64241 L .54685 .64248 L F
.54572 .64267 m .54704 .64241 L .54538 .64276 L F
.48 .79 .999 r
.54507 .64175 m .54704 .64241 L .54396 .64303 L F
0 .288 .766 r
.54507 .64175 m .54732 .6438 L .54704 .64241 L F
.54601 .6426 m .54742 .64331 L .54732 .6438 L F
.54507 .64175 m .54626 .64254 L .54601 .6426 L F
.54626 .64254 m .54742 .64331 L .54601 .6426 L F
.154 .692 .713 r
.54396 .64303 m .54572 .64267 L .54538 .64276 L F
0 .447 .741 r
.54704 .64241 m .55043 .64344 L .54685 .64248 L F
.525 .857 .996 r
.3625 .59744 m .36688 .59733 L .36477 .59716 L F
.049 .616 .756 r
.36821 .59719 m .36477 .59716 L .36688 .59733 L F
.603 .593 .814 r
.55423 .65456 m .55652 .65826 L .55369 .6582 L F
.484 .488 .786 r
.55645 .66028 m .55369 .6582 L .55652 .65826 L F
.581 .748 .956 r
.57749 .64345 m .58019 .64351 L .57871 .6422 L F
.109 .009 .448 r
.57749 .64345 m .57804 .64347 L .57871 .6422 L F
0 0 .122 r
.57871 .6422 m .5783 .64277 L .57749 .64345 L F
.624 .617 .822 r
.57464 .64134 m .57788 .64337 L .57871 .6422 L F
.57788 .64337 m .57804 .64347 L .57871 .6422 L F
0 0 .122 r
.57871 .6422 m .57853 .64258 L .5783 .64277 L F
.568 .619 .863 r
.57788 .64337 m .57804 .64347 L .57781 .64345 L F
0 0 .122 r
.57853 .64258 m .57707 .64561 L .5774 .64394 L F
.57853 .64258 m .5774 .64394 L .57749 .64345 L F
.568 .619 .863 r
.57464 .64134 m .57788 .64337 L .57413 .64311 L F
.57788 .64337 m .57781 .64345 L .57413 .64311 L F
0 .557 .755 r
.57413 .64311 m .57804 .64347 L .57749 .64345 L F
.965 .841 .424 r
.6601 .4949 m .65972 .49738 L .6604 .49618 L F
.905 .532 .315 r
.65972 .49738 m .66174 .49852 L .6604 .49618 L F
.965 .841 .424 r
.6601 .4949 m .65972 .49738 L .6604 .49618 L F
.608 .378 .542 r
.60424 .54955 m .60693 .54924 L .60679 .54695 L F
.559 .34 .54 r
.60679 .54695 m .60693 .54924 L .60919 .54654 L F
.647 .522 .697 r
.51029 .64918 m .50697 .6464 L .50917 .64553 L F
.51029 .64918 m .50777 .6496 L .50697 .6464 L F
.426 .166 .414 r
.56549 .57554 m .5677 .57484 L .56802 .57283 L F
.367 .095 .363 r
.5677 .57484 m .57017 .57221 L .56802 .57283 L F
.68 .75 .904 r
.70761 .49496 m .71121 .49558 L .71037 .4942 L F
.508 .726 .971 r
.71121 .49558 m .71242 .49389 L .71037 .4942 L F
.71121 .49558 m .71346 .4952 L .71242 .49389 L F
.008 0 .242 r
.65007 .49631 m .65089 .49672 L .65052 .49449 L F
.65007 .49631 m .64911 .49864 L .65089 .49672 L F
.015 .057 .561 r
.55786 .64401 m .55817 .64006 L .55642 .64072 L F
.55786 .64401 m .55831 .64364 L .55817 .64006 L F
.144 .293 .758 r
.55786 .64401 m .55985 .64584 L .55831 .64364 L F
.317 0 0 r
.46779 .70002 m .47039 .70009 L .47161 .69961 L F
.285 .767 .674 r
.47161 .69961 m .47247 .69923 L .47368 .70013 L F
.47161 .69961 m .47039 .70009 L .47247 .69923 L F
.111 0 .186 r
.55297 .61497 m .55069 .61776 L .55143 .61632 L F
.673 .792 .938 r
.58479 .64036 m .58635 .64189 L .58817 .64088 L F
.585 .337 .507 r
.40629 .70159 m .40882 .70062 L .40631 .7001 L F
.235 .031 .386 r
.60811 .62086 m .60762 .62319 L .60618 .62378 L F
.3 .205 .577 r
.60762 .62319 m .60648 .62627 L .60618 .62378 L F
.331 0 0 r
.49973 .70573 m .49835 .70632 L .49597 .70626 L F
.513 0 0 r
.50199 .70665 m .49835 .70632 L .49973 .70573 L F
.461 .448 .758 r
.41569 .68916 m .41814 .69169 L .41752 .68863 L F
.486 .479 .775 r
.4147 .68687 m .41569 .68916 L .41752 .68863 L F
.482 .248 .483 r
.40338 .60662 m .40317 .60887 L .401 .60926 L F
.535 .36 .591 r
.40583 .60357 m .40563 .60604 L .40338 .60662 L F
.472 .23 .465 r
.40563 .60604 m .40317 .60887 L .40338 .60662 L F
.755 .847 .399 r
.5675 .59349 m .56856 .59169 L .5679 .59137 L F
.735 .991 .858 r
.57068 .58922 m .5679 .59137 L .56856 .59169 L F
.563 .909 .694 r
.57068 .58922 m .56912 .59014 L .5679 .59137 L F
0 0 .062 r
.56912 .59014 m .5688 .59176 L .5675 .59349 L F
.647 .933 .669 r
.5688 .59176 m .56743 .59308 L .5675 .59349 L F
.56743 .59308 m .56583 .59462 L .5675 .59349 L F
.755 .847 .399 r
.5675 .59349 m .56694 .59528 L .56757 .59388 L F
.5675 .59349 m .56757 .59388 L .56856 .59169 L F
.735 .991 .858 r
.57068 .58922 m .56856 .59169 L .57119 .58885 L F
0 0 0 r
.57123 .58926 m .56987 .58982 L .57068 .58922 L F
.56987 .58982 m .56912 .59014 L .57068 .58922 L F
.735 .991 .858 r
.57068 .58922 m .57119 .58885 L .57134 .58869 L F
0 .117 .66 r
.51467 .63163 m .51645 .63413 L .51559 .63315 L F
.571 .46 .688 r
.27608 .60677 m .27865 .60911 L .2781 .60603 L F
.27608 .60677 m .27649 .60958 L .27865 .60911 L F
.403 .18 .458 r
.60191 .60901 m .60422 .60611 L .60216 .60684 L F
.646 .968 .862 r
.27874 .62804 m .27909 .62852 L .28047 .62813 L F
.27874 .62804 m .27634 .62958 L .27909 .62852 L F
.89 .886 .822 r
.28632 .64074 m .28266 .6431 L .28514 .64215 L F
.713 .64 .775 r
.28514 .64215 m .28727 .63966 L .28632 .64074 L F
.298 .759 .949 r
.26502 .69207 m .26348 .69159 L .26137 .69178 L F
.26137 .69178 m .26348 .69159 L .26502 .69207 L F
.547 .88 .989 r
.26502 .69207 m .26558 .69089 L .26348 .69159 L F
.26502 .69207 m .26558 .69089 L .26348 .69159 L F
.508 .185 .354 r
.44858 .65454 m .45094 .65423 L .45179 .65174 L F
.463 .139 .332 r
.45094 .65423 m .45409 .65142 L .45179 .65174 L F
.428 0 0 r
.34537 .58552 m .34718 .58628 L .34868 .58645 L F
.317 .778 .945 r
.34718 .58628 m .35079 .58642 L .34868 .58645 L F
.313 .789 .918 r
.34399 .60005 m .34158 .60017 L .34304 .60046 L F
.78 .506 .52 r
.72602 .47234 m .72748 .47048 L .72587 .46942 L F
.72602 .47234 m .72927 .4728 L .72748 .47048 L F
.338 0 .006 r
.51903 .70511 m .51575 .70613 L .51675 .70535 L F
.416 .125 .359 r
.57273 .56952 m .57495 .56896 L .57524 .5666 L F
.336 .06 .338 r
.57524 .5666 m .57698 .56815 L .57757 .56581 L F
.57524 .5666 m .57495 .56896 L .57698 .56815 L F
.505 .496 .78 r
.71618 .47938 m .71749 .48205 L .71917 .48076 L F
0 0 0 r
.49339 .78924 m .4936 .78879 L .49233 .79008 L F
.49466 .78778 m .4936 .78879 L .49339 .78924 L F
.165 0 0 r
.49339 .78924 m .49001 .79098 L .49233 .79008 L F
.815 .569 .566 r
.49331 .7891 m .49233 .79008 L .4921 .78712 L F
.49339 .78924 m .49233 .79008 L .49331 .7891 L F
.514 .472 .747 r
.49466 .78778 m .49339 .78924 L .49331 .7891 L F
0 0 0 r
.49331 .7891 m .4936 .78879 L .49403 .78837 L F
.514 .472 .747 r
.49466 .78778 m .49331 .7891 L .4921 .78712 L F
0 0 0 r
.49233 .79008 m .49289 .78951 L .49331 .7891 L F
.49289 .78951 m .4936 .78879 L .49331 .7891 L F
.49233 .79008 m .49403 .78837 L .49466 .78778 L F
.366 .685 .98 r
.41505 .6964 m .41832 .69884 L .41489 .69763 L F
.862 .801 .789 r
.41783 .6942 m .41832 .69884 L .41505 .6964 L F
0 0 0 r
.7302 .50577 m .72937 .50718 L .73057 .50481 L F
.954 .701 .516 r
.48627 .77389 m .48787 .77465 L .48631 .77139 L F
.645 .362 .476 r
.70263 .47024 m .70337 .47259 L .69953 .47264 L F
.448 .252 .521 r
.70467 .46943 m .70337 .47259 L .70263 .47024 L F
.653 .609 .792 r
.55277 .65163 m .55149 .653 L .54857 .64949 L F
.748 .618 .716 r
.601 .66161 m .59901 .66113 L .6013 .66062 L F
.601 .66161 m .59954 .66376 L .59901 .66113 L F
.45 .217 .467 r
.601 .66161 m .59932 .666 L .59954 .66376 L F
.601 .66161 m .60151 .66526 L .59932 .666 L F
.28 .372 .779 r
.6013 .66062 m .60372 .66231 L .601 .66161 L F
.388 .175 .465 r
.601 .66161 m .60372 .66231 L .60151 .66526 L F
.417 .005 .148 r
.28047 .62813 m .28243 .6282 L .28338 .62672 L F
.6 .382 .558 r
.28243 .6282 m .28501 .62611 L .28338 .62672 L F
.541 .396 .633 r
.27758 .59838 m .27956 .60048 L .27983 .59798 L F
.27758 .59838 m .27742 .60098 L .27956 .60048 L F
.499 .154 .313 r
.32356 .6045 m .32154 .60799 L .31983 .60673 L F
.269 0 .135 r
.32548 .60336 m .32393 .60576 L .32356 .6045 L F
.217 0 .147 r
.32393 .60576 m .32154 .60799 L .32356 .6045 L F
.593 .724 .935 r
.33018 .62716 m .32796 .62782 L .32675 .62629 L F
.562 .342 .539 r
.36905 .61479 m .37111 .61216 L .36904 .61236 L F
.294 0 0 r
.51107 .70635 m .50968 .70601 L .50753 .70527 L F
.53 0 0 r
.51352 .70683 m .50968 .70601 L .51107 .70635 L F
.982 .905 .648 r
.70443 .46573 m .70589 .46404 L .70356 .46418 L F
.315 .534 .906 r
.70244 .46606 m .70351 .46664 L .70443 .46573 L F
.982 .905 .648 r
.70443 .46573 m .70495 .46736 L .7058 .46438 L F
.159 .202 .657 r
.70443 .46573 m .7062 .46813 L .70467 .46943 L F
.315 .534 .906 r
.70351 .46664 m .7062 .46813 L .70443 .46573 L F
.982 .905 .648 r
.70443 .46573 m .7058 .46438 L .70589 .46404 L F
.604 .894 .989 r
.74199 .49484 m .74014 .49515 L .74317 .49479 L F
.749 .856 .929 r
.74504 .49211 m .74317 .49479 L .74642 .49203 L F
.74504 .49211 m .74199 .49484 L .74317 .49479 L F
.71 .521 .631 r
.61176 .544 m .61272 .54672 L .61498 .5441 L F
.74 .565 .657 r
.61498 .5441 m .61272 .54672 L .61524 .54677 L F
.667 .559 .724 r
.58363 .63232 m .58772 .63318 L .5859 .62917 L F
.683 .498 .629 r
.58678 .63465 m .58772 .63318 L .58363 .63232 L F
.388 .029 .23 r
.46171 .64639 m .46389 .646 L .46486 .64372 L F
.384 .026 .228 r
.46486 .64372 m .46623 .64535 L .46708 .64323 L F
.46486 .64372 m .46389 .646 L .46623 .64535 L F
.928 .713 .591 r
.62195 .57122 m .62339 .56964 L .62204 .56912 L F
.62195 .57122 m .62303 .57195 L .62339 .56964 L F
.691 .906 .557 r
.44087 .68347 m .43919 .68525 L .43868 .68638 L F
0 0 .17 r
.43935 .68756 m .43868 .68638 L .43919 .68525 L F
.43935 .68756 m .43813 .68886 L .43868 .68638 L F
.008 0 .426 r
.59996 .6428 m .59853 .64667 L .59777 .64328 L F
.59996 .6428 m .60001 .64526 L .59853 .64667 L F
.296 .412 .811 r
.60001 .64526 m .60133 .64851 L .59853 .64667 L F
.482 .402 .69 r
.59853 .64667 m .60133 .64851 L .59939 .64934 L F
.792 .989 .745 r
.55412 .60472 m .553 .60551 L .55267 .60666 L F
0 .181 .705 r
.553 .60551 m .55457 .60872 L .55267 .60666 L F
0 .316 .802 r
.54042 .62343 m .54077 .62264 L .53874 .62191 L F
.54042 .62343 m .54304 .62517 L .54077 .62264 L F
.227 .1 .491 r
.61548 .61046 m .61297 .6107 L .61638 .60869 L F
.61548 .61046 m .61424 .6118 L .61297 .6107 L F
.835 .694 .707 r
.61974 .55493 m .62101 .55828 L .62155 .55592 L F
.553 .267 .434 r
.68302 .47849 m .68607 .47867 L .68586 .4756 L F
0 0 0 r
.68586 .4756 m .68761 .47443 L .68847 .47281 L F
.512 .237 .433 r
.68586 .4756 m .68872 .47731 L .68761 .47443 L F
.68586 .4756 m .68607 .47867 L .68872 .47731 L F
.583 .915 .973 r
.49515 .80003 m .4962 .80051 L .49841 .79958 L F
.158 .699 .758 r
.49906 .66389 m .49804 .66396 L .49562 .66435 L F
.358 .246 .587 r
.7155 .47575 m .71701 .47652 L .71902 .47559 L F
.399 .851 .901 r
.71701 .47652 m .72151 .47575 L .71902 .47559 L F
.705 .782 .911 r
.65893 .51791 m .66027 .51944 L .66251 .51831 L F
.203 .43 .858 r
.38979 .59049 m .38813 .59073 L .387 .5899 L F
.38979 .59049 m .39037 .59212 L .38813 .59073 L F
.496 .361 .626 r
.54356 .69203 m .54392 .69505 L .54599 .69413 L F
.54356 .69203 m .54392 .69505 L .54599 .69413 L F
.535 .595 .861 r
.7041 .48078 m .70296 .48363 L .70148 .4814 L F
.7041 .48078 m .70511 .48373 L .70296 .48363 L F
.94 .924 .557 r
.57716 .66937 m .57587 .67082 L .57676 .66867 L F
.553 .584 .839 r
.48507 .65412 m .4872 .65271 L .48373 .65157 L F
.48507 .65412 m .48738 .65379 L .4872 .65271 L F
.704 .969 .739 r
.56092 .62317 m .56215 .62255 L .56351 .62117 L F
.839 .561 .518 r
.56011 .62529 m .56215 .62255 L .56092 .62317 L F
.56011 .62529 m .56257 .62572 L .56215 .62255 L F
.633 .554 .747 r
.56215 .62255 m .56358 .62347 L .56351 .62117 L F
0 0 0 r
.57467 .65779 m .57338 .65942 L .57172 .66077 L F
.143 .32 .783 r
.57328 .65461 m .57562 .65647 L .57467 .65779 L F
.586 .827 .45 r
.57562 .65647 m .57338 .65942 L .57467 .65779 L F
.711 .521 .63 r
.60919 .54654 m .61272 .54672 L .61176 .544 L F
.628 .631 .834 r
.64911 .49864 m .65294 .50099 L .65191 .49841 L F
.709 .749 .884 r
.65191 .49841 m .65294 .50099 L .65527 .49894 L F
.485 .579 .874 r
.55642 .64072 m .55638 .637 L .55454 .63713 L F
.55642 .64072 m .55817 .64006 L .55638 .637 L F
0 .52 .852 r
.33766 .58365 m .34138 .58499 L .33923 .58506 L F
.568 .294 .461 r
.52067 .69585 m .52039 .69748 L .52231 .69675 L F
.821 .891 .893 r
.67498 .51106 m .67853 .50984 L .67781 .50942 L F
.435 .635 .94 r
.67985 .50818 m .67853 .50984 L .67938 .50856 L F
.653 .955 .942 r
.67985 .50818 m .67781 .50942 L .67853 .50984 L F
.195 .053 .45 r
.60909 .61747 m .60967 .62022 L .60811 .62086 L F
.259 .041 .38 r
.61181 .61414 m .61188 .61664 L .60909 .61747 L F
.391 .172 .458 r
.61198 .61911 m .60909 .61747 L .61188 .61664 L F
.61198 .61911 m .60967 .62022 L .60909 .61747 L F
.12 .663 .834 r
.74882 .48938 m .74521 .4877 L .74409 .48578 L F
.74882 .48938 m .74523 .48925 L .74521 .4877 L F
.74882 .48938 m .74699 .48926 L .74523 .48925 L F
.814 .636 .662 r
.74882 .48938 m .74785 .49126 L .74699 .48926 L F
.654 .774 .937 r
.31488 .64764 m .31536 .64526 L .31325 .64584 L F
.31488 .64764 m .31605 .6473 L .31536 .64526 L F
.614 .059 0 r
.45271 .67009 m .45429 .67148 L .45107 .67054 L F
.463 .15 .348 r
.45497 .66904 m .45429 .67148 L .45271 .67009 L F
.364 .835 .837 r
.51032 .64474 m .50788 .64553 L .50917 .64553 L F
.523 .3 .517 r
.50788 .64553 m .51032 .64474 L .50917 .64553 L F
.695 .533 .664 r
.51173 .6464 m .51029 .64918 L .50917 .64553 L F
.854 .536 .45 r
.46388 .67135 m .46685 .67206 L .46611 .67219 L F
.916 .762 .676 r
.4641 .6734 m .46569 .67495 L .46685 .67206 L F
0 0 0 r
.56561 .59791 m .56553 .59902 L .5656 .59907 L F
.463 .254 .51 r
.31564 .61221 m .31547 .61434 L .31335 .6147 L F
.459 .372 .67 r
.31547 .61434 m .31382 .61849 L .31335 .6147 L F
.102 0 0 r
.47824 .65002 m .47628 .65072 L .47771 .64883 L F
.963 .807 .64 r
.72886 .4865 m .72669 .4886 L .72757 .48522 L F
.72886 .4865 m .72796 .48961 L .72669 .4886 L F
.564 .67 .91 r
.37626 .59788 m .37831 .60064 L .38055 .59996 L F
.629 .672 .872 r
.57586 .63607 m .57776 .63458 L .57543 .63553 L F
.57586 .63607 m .57936 .63644 L .57776 .63458 L F
.572 .54 .78 r
.57338 .65942 m .57196 .66352 L .57172 .66077 L F
.442 .548 .869 r
.52811 .61003 m .53091 .61272 L .53134 .61141 L F
.067 .383 .845 r
.53091 .61272 m .53326 .61307 L .53134 .61141 L F
.53091 .61272 m .53382 .61445 L .53326 .61307 L F
0 0 .308 r
.66528 .50905 m .66499 .50803 L .66457 .50729 L F
.064 .613 .832 r
.3258 .64842 m .32193 .64784 L .32402 .64847 L F
.293 0 .198 r
.37436 .63055 m .37221 .63135 L .3729 .62992 L F
.486 .479 .775 r
.4147 .68687 m .41752 .68863 L .41665 .68549 L F
.506 .191 .367 r
.401 .60926 m .40014 .61158 L .39786 .61187 L F
.604 .355 .512 r
.40317 .60887 m .40014 .61158 L .401 .60926 L F
.454 .185 .416 r
.36219 .63514 m .36184 .63678 L .3597 .63721 L F
.458 .16 .371 r
.36438 .63485 m .36184 .63678 L .36219 .63514 L F
.07 0 .131 r
.55549 .58615 m .55742 .58554 L .55772 .58349 L F
0 0 0 r
.55772 .58349 m .55963 .58255 L .56034 .58075 L F
0 0 .111 r
.55742 .58554 m .55963 .58255 L .55772 .58349 L F
.703 .448 .535 r
.53809 .65556 m .53839 .65743 L .53526 .65724 L F
.195 0 0 r
.35582 .63925 m .3597 .63721 L .35803 .6386 L F
.185 0 0 r
.3597 .63721 m .3602 .63815 L .35803 .6386 L F
.3597 .63721 m .36184 .63678 L .3602 .63815 L F
.513 .289 .511 r
.3957 .61236 m .39546 .61464 L .39324 .61508 L F
.489 .268 .505 r
.39786 .61187 m .39546 .61464 L .3957 .61236 L F
.557 .285 .459 r
.65735 .48352 m .65965 .4813 L .65762 .4818 L F
.554 .439 .677 r
.41765 .67193 m .4199 .67148 L .41953 .66905 L F
.517 .38 .634 r
.41795 .67478 m .4199 .67148 L .41765 .67193 L F
.285 .769 .918 r
.31455 .58284 m .31679 .58259 L .3186 .58286 L F
0 .484 .813 r
.31886 .58263 m .3186 .58286 L .31679 .58259 L F
.31886 .58263 m .32043 .58336 L .3186 .58286 L F
.049 .204 .705 r
.44168 .6821 m .44087 .68347 L .43973 .6804 L F
.663 .894 .546 r
.44168 .6821 m .43919 .68525 L .44087 .68347 L F
.539 0 0 r
.4784 .70569 m .47761 .70614 L .47505 .70542 L F
.287 .708 .971 r
.48073 .70582 m .47958 .70505 L .4784 .70569 L F
0 0 0 r
.4784 .70569 m .47958 .70505 L .47761 .70614 L F
.271 0 0 r
.73594 .51766 m .73928 .51851 L .73752 .518 L F
.435 .182 .43 r
.59954 .66376 m .59932 .666 L .59723 .66666 L F
.358 .246 .587 r
.7155 .47575 m .71615 .47826 L .71701 .47652 L F
.336 .698 .982 r
.37769 .58826 m .37582 .58838 L .37395 .58711 L F
.227 0 .062 r
.3614 .62023 m .3634 .61983 L .36436 .61814 L F
.202 0 0 r
.3634 .61983 m .36647 .6176 L .36436 .61814 L F
.978 .733 .495 r
.62155 .58491 m .62286 .58353 L .62207 .58293 L F
.62155 .58491 m .62219 .58755 L .62286 .58353 L F
.83 .51 .447 r
.57238 .66676 m .57363 .67 L .57108 .66825 L F
.513 .483 .761 r
.57453 .66279 m .57238 .66676 L .57196 .66352 L F
.57453 .66279 m .575 .6649 L .57238 .66676 L F
.644 .534 .714 r
.575 .6649 m .57363 .67 L .57238 .66676 L F
.913 .626 .486 r
.50613 .70354 m .50701 .70405 L .50617 .70119 L F
.584 .446 .658 r
.50617 .70119 m .50701 .70405 L .50938 .70308 L F
.629 .118 .011 r
.71618 .47938 m .71917 .48076 L .71558 .4799 L F
.764 .842 .911 r
.74716 .51419 m .74522 .51577 L .74408 .51456 L F
0 0 0 r
.55549 .58615 m .55452 .58773 L .55742 .58554 L F
.726 .201 0 r
.47364 .6565 m .47458 .65757 L .47581 .65815 L F
.894 .478 .09 r
.47458 .65757 m .47642 .66013 L .47581 .65815 L F
.442 .62 .927 r
.73778 .47366 m .73638 .47478 L .73531 .47428 L F
.73778 .47366 m .73888 .47535 L .73638 .47478 L F
.456 0 .04 r
.50753 .70527 m .50414 .706 L .50531 .70519 L F
.732 .753 .869 r
.50046 .76809 m .49793 .76877 L .49991 .76702 L F
.376 0 .02 r
.50046 .76809 m .49969 .76949 L .49793 .76877 L F
.188 .43 .861 r
.50142 .76751 m .50046 .76809 L .49991 .76702 L F
0 0 0 r
.50142 .76751 m .49969 .76949 L .50046 .76809 L F
.549 .879 .99 r
.35536 .59849 m .35721 .59897 L .35924 .59826 L F
.535 .095 .15 r
.67953 .48732 m .67844 .48909 L .6761 .48875 L F
.433 0 .096 r
.68177 .48806 m .67953 .48732 L .68201 .48697 L F
.68177 .48806 m .67844 .48909 L .67953 .48732 L F
.597 .407 .595 r
.51029 .64918 m .50807 .65113 L .50777 .6496 L F
.50807 .65113 m .51029 .64918 L .50777 .6496 L F
.51029 .64918 m .51033 .65202 L .50807 .65113 L F
.50807 .65113 m .51033 .65202 L .51029 .64918 L F
.625 .429 .597 r
.51029 .64918 m .51033 .65202 L .50777 .6496 L F
.978 .804 .599 r
.55919 .61496 m .56011 .61818 L .56155 .6173 L F
.55919 .61496 m .55889 .61788 L .56011 .61818 L F
.569 .265 .413 r
.55889 .61788 m .56155 .6173 L .56011 .61818 L F
.857 .702 .69 r
.618 .55795 m .62101 .55828 L .61974 .55493 L F
.84 .608 .586 r
.61773 .55985 m .62101 .55828 L .618 .55795 L F
.61773 .55985 m .62103 .56071 L .62101 .55828 L F
.975 .71 .465 r
.50942 .67937 m .51086 .6803 L .51072 .67775 L F
.51072 .67775 m .51086 .6803 L .50942 .67937 L F
0 0 0 r
.50107 .66077 m .50045 .6631 L .50035 .66295 L F
.50107 .66077 m .50045 .6631 L .50035 .66295 L F
.786 .423 .37 r
.49845 .66004 m .50045 .6631 L .50107 .66077 L F
.339 0 .091 r
.43471 .66268 m .43817 .66035 L .43585 .6606 L F
.205 .256 .695 r
.46206 .67164 m .4641 .6734 L .46388 .67135 L F
0 0 0 r
.49991 .76702 m .49793 .76877 L .49956 .76744 L F
.196 .187 .621 r
.49793 .76877 m .49969 .76949 L .49956 .76744 L F
.454 0 .039 r
.45169 .70648 m .45029 .708 L .44796 .70793 L F
.324 0 0 r
.45393 .70649 m .45029 .708 L .45169 .70648 L F
.298 0 0 r
.29125 .59114 m .29501 .58926 L .29302 .58996 L F
.469 .525 .833 r
.55247 .63701 m .55322 .63394 L .55127 .63546 L F
.55247 .63701 m .55454 .63713 L .55322 .63394 L F
.754 .388 .361 r
.47624 .70168 m .47856 .70063 L .47755 .69984 L F
.579 .546 .782 r
.48883 .7948 m .49115 .79453 L .49001 .79098 L F
.68 .722 .882 r
.71078 .48361 m .7088 .48474 L .70751 .48286 L F
.552 .423 .659 r
.27674 .61194 m .27865 .60911 L .27649 .60958 L F
.669 .756 .915 r
.55037 .76574 m .55412 .76619 L .55225 .76517 L F
.676 .475 .607 r
.57419 .63172 m .57601 .62899 L .57171 .62896 L F
.542 .455 .706 r
.59683 .6374 m .59962 .6405 L .59746 .64102 L F
.59683 .6374 m .59904 .63701 L .59962 .6405 L F
.099 0 .014 r
.56275 .57784 m .5648 .57683 L .56549 .57554 L F
.377 .017 .221 r
.5648 .57683 m .5677 .57484 L .56549 .57554 L F
.575 .166 .229 r
.49468 .70303 m .49707 .70324 L .49834 .70201 L F
.41 0 .097 r
.49834 .70201 m .49707 .70324 L .50068 .70216 L F
.088 0 0 r
.59084 .56989 m .59003 .5714 L .58765 .5724 L F
.27 0 0 r
.59305 .5699 m .59003 .5714 L .59084 .56989 L F
.459 .372 .67 r
.31547 .61434 m .31601 .61861 L .31382 .61849 L F
.456 .404 .71 r
.31601 .61861 m .31619 .62002 L .31382 .61849 L F
.697 .492 .607 r
.68541 .48425 m .68592 .48717 L .68201 .48697 L F
.79 .555 .581 r
.68759 .48637 m .68541 .48425 L .68761 .48408 L F
.68759 .48637 m .68592 .48717 L .68541 .48425 L F
.637 .534 .721 r
.74785 .49126 m .74523 .48925 L .74699 .48926 L F
.74785 .49126 m .74642 .49203 L .74523 .48925 L F
.74785 .49126 m .74642 .49203 L .74523 .48925 L F
.617 .876 .54 r
.56595 .61834 m .56471 .61957 L .56351 .62117 L F
.713 .915 .565 r
.56686 .61662 m .56595 .61834 L .56817 .61752 L F
.56686 .61662 m .56471 .61957 L .56595 .61834 L F
.257 .002 .322 r
.65551 .48453 m .65504 .48637 L .65735 .48352 L F
.763 .813 .892 r
.41044 .6993 m .41125 .70055 L .40882 .70062 L F
.41044 .6993 m .41125 .70055 L .40882 .70062 L F
.461 .668 .953 r
.41044 .6993 m .41125 .70055 L .4129 .69914 L F
.41044 .6993 m .41125 .70055 L .4129 .69914 L F
.605 .79 .97 r
.33399 .62781 m .33018 .62716 L .33269 .62684 L F
.308 .685 .977 r
.33528 .62703 m .33399 .62781 L .33269 .62684 L F
.33528 .62703 m .33663 .62818 L .33399 .62781 L F
.551 .305 .495 r
.71366 .46668 m .71319 .46885 L .71071 .46721 L F
.272 0 .252 r
.71071 .46721 m .71225 .46734 L .71394 .46431 L F
.234 .363 .791 r
.71071 .46721 m .71319 .46885 L .71225 .46734 L F
.488 .285 .53 r
.42152 .66618 m .42434 .66284 L .42159 .66347 L F
.45 .189 .426 r
.40823 .60345 m .40563 .60604 L .40583 .60357 L F
.357 0 .185 r
.32758 .60283 m .32393 .60576 L .32548 .60336 L F
.483 .231 .456 r
.58588 .657 m .58937 .65656 L .58836 .65477 L F
.741 .992 .861 r
.59052 .65283 m .58836 .65477 L .58954 .65278 L F
.622 .28 .37 r
.58836 .65477 m .5911 .65606 L .58954 .65278 L F
.58836 .65477 m .58937 .65656 L .5911 .65606 L F
0 .232 .629 r
.6987 .48312 m .69824 .48284 L .69564 .4814 L F
.829 .893 .887 r
.6987 .48312 m .69593 .48367 L .69824 .48284 L F
.618 .538 .742 r
.65974 .50492 m .6624 .50407 L .65878 .50256 L F
.404 .373 .711 r
.55614 .61372 m .5568 .61208 L .55641 .61176 L F
.831 .677 .692 r
.57936 .66877 m .57812 .66496 L .57934 .66634 L F
.569 .434 .657 r
.76487 .51232 m .76531 .5151 L .76279 .51563 L F
.528 .283 .487 r
.76531 .5151 m .76273 .51757 L .76279 .51563 L F
0 0 0 r
.53095 .60034 m .53219 .59878 L .5293 .60067 L F
.001 0 0 r
.53421 .59778 m .53219 .59878 L .53095 .60034 L F
.499 .268 .495 r
.49555 .63924 m .49405 .64092 L .49754 .63798 L F
.565 .461 .694 r
.49405 .64092 m .49645 .64311 L .49751 .63814 L F
.49712 .63833 m .49751 .63814 L .49754 .63798 L F
.49405 .64092 m .49751 .63814 L .49712 .63833 L F
.74 .851 .932 r
.49443 .63792 m .49548 .63915 L .49846 .63749 L F
.49548 .63915 m .49555 .63924 L .49674 .63852 L F
.546 .407 .643 r
.49754 .63798 m .49859 .64005 L .49846 .63749 L F
.49754 .63798 m .49846 .63749 L .49726 .63816 L F
.49647 .63866 m .49674 .63852 L .49555 .63924 L F
.74 .851 .932 r
.49548 .63915 m .49674 .63852 L .49846 .63749 L F
.598 .668 .889 r
.76152 .48553 m .75977 .48777 L .75909 .48595 L F
.76152 .48553 m .762 .48726 L .75977 .48777 L F
.584 .568 .801 r
.76271 .48895 m .75977 .48777 L .762 .48726 L F
.819 .782 .278 r
.60447 .60293 m .6043 .60382 L .60427 .60298 L F
.744 .622 .056 r
.60427 .60298 m .6043 .60382 L .60422 .60611 L F
.60427 .60298 m .60422 .60611 L .60472 .60449 L F
.883 .691 .638 r
.60472 .60449 m .60411 .60303 L .60427 .60298 L F
.60411 .60303 m .60333 .60115 L .60427 .60298 L F
.819 .782 .278 r
.60488 .60074 m .60447 .60293 L .60427 .60298 L F
.443 .581 .896 r
.75162 .49563 m .75341 .4984 L .75464 .49681 L F
.223 .265 .695 r
.75341 .4984 m .75563 .50013 L .75464 .49681 L F
.175 0 .159 r
.45708 .66378 m .45639 .66566 L .45472 .66618 L F
.312 0 .055 r
.46023 .66309 m .45639 .66566 L .45708 .66378 L F
.383 .846 .844 r
.69355 .47665 m .69206 .47751 L .69364 .47338 L F
.69355 .47665 m .69139 .47745 L .69206 .47751 L F
.407 .65 .957 r
.52988 .63747 m .52882 .63887 L .52758 .63797 L F
.52988 .63747 m .53118 .63906 L .52882 .63887 L F
.985 .742 .482 r
.71448 .46972 m .71433 .47224 L .71319 .46885 L F
.985 .772 .534 r
.71366 .46668 m .71319 .46885 L .71448 .46972 L F
.985 .742 .482 r
.71448 .46972 m .71433 .47224 L .71319 .46885 L F
.457 .273 .542 r
.47196 .65164 m .47161 .65401 L .46939 .65255 L F
.557 .434 .668 r
.27983 .59798 m .28198 .59753 L .2817 .5952 L F
.488 .266 .503 r
.27956 .60048 m .28198 .59753 L .27983 .59798 L F
0 0 0 r
.52793 .60155 m .53095 .60034 L .5293 .60067 L F
.606 .177 .201 r
.59666 .56961 m .59495 .57105 L .59305 .5699 L F
.827 .489 .416 r
.59666 .56961 m .59706 .57185 L .59495 .57105 L F
.802 .472 .429 r
.60028 .57228 m .59706 .57185 L .59666 .56961 L F
.865 .775 .76 r
.68759 .48637 m .685 .48893 L .68592 .48717 L F
.285 0 0 r
.67728 .48055 m .67969 .4801 L .68053 .47868 L F
.158 0 0 r
.68053 .47868 m .68195 .4793 L .68302 .47849 L F
.68053 .47868 m .67969 .4801 L .68195 .4793 L F
.475 .192 .404 r
.39497 .61663 m .39324 .61508 L .39546 .61464 L F
.39497 .61663 m .39271 .6172 L .39324 .61508 L F
.596 .407 .596 r
.37359 .60844 m .37652 .60625 L .37331 .6064 L F
.37359 .60844 m .37627 .60895 L .37652 .60625 L F
.534 .412 .66 r
.37359 .60844 m .37621 .61073 L .37627 .60895 L F
.37359 .60844 m .37424 .61165 L .37621 .61073 L F
.203 .354 .794 r
.51768 .63301 m .51645 .63413 L .51467 .63163 L F
.51768 .63301 m .51791 .63494 L .51645 .63413 L F
.618 .574 .783 r
.60021 .65702 m .59901 .66113 L .59772 .65781 L F
.60021 .65702 m .6013 .66062 L .59901 .66113 L F
.688 .371 .433 r
.68761 .47443 m .69095 .47255 L .68847 .47281 L F
.764 .591 .663 r
.6153 .54905 m .61854 .54687 L .61524 .54677 L F
.6153 .54905 m .61861 .54941 L .61854 .54687 L F
.701 .572 .707 r
.65697 .50331 m .65734 .49919 L .65878 .50256 L F
0 0 0 r
.65802 .50265 m .65697 .50331 L .65878 .50256 L F
.929 .604 .147 r
.65734 .49919 m .65802 .50265 L .65878 .50256 L F
.57 .566 .81 r
.65878 .50256 m .66098 .50065 L .65882 .50092 L F
.65878 .50256 m .6624 .50407 L .66098 .50065 L F
.905 .759 .689 r
.65734 .49919 m .65878 .50256 L .65882 .50092 L F
.489 .16 .336 r
.58284 .66012 m .58513 .65982 L .58588 .657 L F
.537 .205 .352 r
.58588 .657 m .58968 .65853 L .58937 .65656 L F
.58588 .657 m .58513 .65982 L .58968 .65853 L F
.32 .803 .886 r
.49099 .61934 m .4936 .61877 L .49497 .61895 L F
.437 0 0 r
.4936 .61877 m .49703 .61903 L .49497 .61895 L F
.74 .714 .827 r
.28203 .63091 m .28276 .63177 L .28243 .6282 L F
0 0 0 r
.28228 .63346 m .28274 .63268 L .28276 .63177 L F
.28276 .63177 m .28274 .63268 L .28493 .63119 L F
.386 .164 .45 r
.59061 .55531 m .59302 .55422 L .59293 .5524 L F
.284 0 .277 r
.58998 .55695 m .59302 .55422 L .59061 .55531 L F
.213 0 .251 r
.58998 .55695 m .59061 .55531 L .58817 .55808 L F
0 0 .503 r
.55352 .61259 m .55271 .61247 L .55404 .61108 L F
.55352 .61259 m .55297 .61497 L .55271 .61247 L F
.919 .683 .565 r
.57078 .62636 m .57166 .62931 L .57066 .62891 L F
.432 0 0 r
.48412 .7056 m .48309 .70616 L .48073 .70582 L F
.609 .258 .35 r
.48633 .70512 m .48309 .70616 L .48412 .7056 L F
.402 .325 .655 r
.50539 .65315 m .50294 .6508 L .5046 .65146 L F
.50539 .65315 m .5031 .65429 L .50294 .6508 L F
.67 .262 .263 r
.52509 .70343 m .5241 .70541 L .52155 .70475 L F
.132 0 .013 r
.52606 .70449 m .52509 .70343 L .52714 .70449 L F
.52606 .70449 m .5241 .70541 L .52509 .70343 L F
.485 .056 .15 r
.52767 .70335 m .52714 .70449 L .52509 .70343 L F
.582 .175 .235 r
.4667 .70577 m .46569 .70656 L .46329 .70613 L F
.469 .008 .073 r
.46909 .70582 m .46569 .70656 L .4667 .70577 L F
.355 .812 .936 r
.52442 .64849 m .52215 .64863 L .52136 .64907 L F
0 0 .033 r
.52116 .65076 m .52136 .64907 L .52215 .64863 L F
.52116 .65076 m .51986 .6519 L .52136 .64907 L F
.853 .665 .648 r
.60574 .57841 m .60329 .57994 L .60402 .57751 L F
.60574 .57841 m .60534 .58081 L .60329 .57994 L F
0 0 0 r
.74785 .49126 m .74504 .49211 L .74642 .49203 L F
.312 0 .055 r
.46023 .66309 m .45907 .6651 L .45639 .66566 L F
.637 .536 .723 r
.46193 .66062 m .46268 .66323 L .46023 .66309 L F
.584 .155 .192 r
.46142 .66501 m .46023 .66309 L .46268 .66323 L F
.46142 .66501 m .45907 .6651 L .46023 .66309 L F
.362 .021 .246 r
.58534 .5608 m .58763 .56017 L .58817 .55808 L F
.41 .127 .369 r
.58763 .56017 m .58998 .55695 L .58817 .55808 L F
.415 .273 .578 r
.60967 .62022 m .60762 .62319 L .60811 .62086 L F
.613 .935 .959 r
.69987 .49531 m .70158 .49474 L .70074 .49326 L F
.655 .796 .95 r
.70074 .49326 m .70158 .49474 L .7039 .49336 L F
.115 0 0 r
.3511 .62611 m .3527 .62581 L .35328 .62538 L F
.014 0 0 r
.3511 .62611 m .34949 .62709 L .3527 .62581 L F
.43 0 .11 r
.44909 .69986 m .45166 .69955 L .45283 .69795 L F
.327 0 .097 r
.45166 .69955 m .45492 .69737 L .45283 .69795 L F
.467 .125 .301 r
.4453 .65701 m .44858 .65454 L .44636 .65497 L F
0 .095 .647 r
.57468 .6725 m .57637 .67431 L .57598 .67324 L F
.391 .809 .974 r
.38592 .58935 m .3848 .59025 L .38333 .58941 L F
.38592 .58935 m .387 .5899 L .3848 .59025 L F
.406 .16 .425 r
.59314 .62089 m .5952 .62017 L .59543 .6182 L F
.575 .419 .632 r
.50043 .78048 m .50133 .77806 L .49937 .77713 L F
.50043 .78048 m .50273 .77982 L .50133 .77806 L F
.50133 .77806 m .50273 .77982 L .50043 .78048 L F
.76 .704 .799 r
.56039 .61287 m .56534 .61374 L .56522 .61229 L F
.168 .493 .904 r
.52811 .61003 m .53059 .61006 L .52775 .60833 L F
.52811 .61003 m .53134 .61141 L .53059 .61006 L F
.283 .108 .458 r
.31691 .61382 m .31564 .61221 L .31747 .6116 L F
.31691 .61382 m .31547 .61434 L .31564 .61221 L F
.109 .628 .885 r
.50777 .62547 m .50987 .62566 L .51129 .62621 L F
.592 .031 0 r
.50987 .62566 m .51358 .62828 L .51129 .62621 L F
.064 .613 .832 r
.3258 .64842 m .32292 .6478 L .32193 .64784 L F
.177 .508 .912 r
.3258 .64842 m .32609 .64617 L .32292 .6478 L F
.3258 .64842 m .32678 .64823 L .32609 .64617 L F
.945 .801 .67 r
.62155 .57736 m .62233 .58053 L .62301 .57836 L F
.265 .704 .962 r
.32257 .58286 m .3262 .58368 L .32408 .58382 L F
.818 .941 .907 r
.67427 .50224 m .67509 .49977 L .67623 .50091 L F
.67427 .50224 m .67231 .50204 L .67509 .49977 L F
.405 .749 .994 r
.35467 .58599 m .35439 .58726 L .35289 .58597 L F
.35467 .58599 m .35671 .58718 L .35439 .58726 L F
.466 .233 .476 r
.52553 .76286 m .52381 .76391 L .52477 .76243 L F
.306 0 0 r
.30883 .58356 m .3111 .58361 L .31217 .58311 L F
.09 0 0 r
.3111 .58361 m .31455 .58284 L .31217 .58311 L F
.496 .225 .432 r
.28447 .59211 m .28635 .59395 L .28684 .59207 L F
.28447 .59211 m .28394 .59458 L .28635 .59395 L F
.659 .487 .64 r
.7236 .47211 m .72587 .46942 L .72337 .47007 L F
0 0 0 r
.48465 .64309 m .48014 .64683 L .48291 .64426 L F
.129 .667 .849 r
.52129 .65829 m .52055 .65795 L .5192 .65815 L F
0 .052 .532 r
.52293 .66006 m .52055 .65795 L .52129 .65829 L F
.668 .123 0 r
.52439 .66072 m .52293 .66006 L .52129 .65829 L F
.136 .357 .817 r
.52055 .65795 m .52259 .65975 L .5214 .65783 L F
.52055 .65795 m .5214 .65783 L .5205 .65637 L F
.129 .667 .849 r
.5192 .65815 m .52055 .65795 L .51757 .65804 L F
.493 .363 .632 r
.41612 .6805 m .41797 .67745 L .41574 .67798 L F
.719 .581 .7 r
.49177 .6433 m .49417 .6436 L .49405 .64092 L F
.565 .461 .694 r
.49405 .64092 m .49417 .6436 L .49645 .64311 L F
.942 .739 .599 r
.54435 .75402 m .54559 .75723 L .54549 .75427 L F
.799 .921 .538 r
.5675 .59349 m .56574 .59666 L .56694 .59528 L F
.275 .535 .916 r
.50157 .79425 m .50019 .79566 L .49936 .79374 L F
.50157 .79425 m .50292 .79651 L .50019 .79566 L F
.081 .465 .888 r
.50323 .79722 m .50019 .79566 L .50292 .79651 L F
.791 .854 .897 r
.66944 .51326 m .66724 .51489 L .67052 .51466 L F
.822 .794 .825 r
.66724 .51489 m .66883 .51629 L .67052 .51466 L F
.843 .864 .858 r
.66944 .51326 m .67052 .51466 L .67285 .51208 L F
.283 0 .19 r
.76041 .5184 m .75986 .52039 L .75751 .52057 L F
.475 .16 .352 r
.76273 .51757 m .75986 .52039 L .76041 .5184 L F
.87 .652 .605 r
.71394 .46431 m .71225 .46734 L .71366 .46668 L F
.233 .224 .644 r
.45472 .66618 m .45655 .66821 L .45497 .66904 L F
.463 .149 .348 r
.4569 .67082 m .45497 .66904 L .45655 .66821 L F
.4569 .67082 m .45429 .67148 L .45497 .66904 L F
.653 .659 .843 r
.54858 .63489 m .55127 .63546 L .55155 .63431 L F
.406 0 0 r
.45746 .70624 m .45623 .70722 L .45393 .70649 L F
.536 .013 0 r
.45997 .70742 m .45623 .70722 L .45746 .70624 L F
.13 .622 .912 r
.25718 .64608 m .25944 .64633 L .26142 .6472 L F
.25718 .64608 m .25944 .64633 L .26142 .6472 L F
.727 .878 .951 r
.26142 .6472 m .26142 .64522 L .2617 .64594 L F
.26142 .6472 m .25944 .64633 L .26142 .64522 L F
.26142 .64522 m .26142 .6472 L .2617 .64594 L F
.26142 .64522 m .25944 .64633 L .26142 .6472 L F
.618 .953 .917 r
.75563 .50998 m .75273 .51077 L .7544 .51148 L F
.569 .504 .743 r
.75478 .50652 m .75563 .50998 L .75803 .50927 L F
.7 .289 .263 r
.7544 .51148 m .75794 .51167 L .75563 .50998 L F
.537 .402 .645 r
.75563 .50998 m .75794 .51167 L .75803 .50927 L F
.75563 .50998 m .75794 .51167 L .75803 .50927 L F
.498 .348 .608 r
.59777 .61496 m .60006 .61464 L .59984 .61188 L F
.443 .169 .401 r
.59959 .61663 m .60006 .61464 L .59777 .61496 L F
.068 .614 .84 r
.45492 .69737 m .45685 .69749 L .45864 .69795 L F
.415 0 0 r
.45685 .69749 m .46096 .69782 L .45864 .69795 L F
.474 .461 .763 r
.65882 .50092 m .65972 .49738 L .65734 .49919 L F
.65882 .50092 m .66098 .50065 L .65972 .49738 L F
.686 .768 .913 r
.69666 .49291 m .69987 .49531 L .70074 .49326 L F
.4 .663 .966 r
.31605 .6473 m .31726 .64549 L .31536 .64526 L F
.024 0 0 r
.44457 .70859 m .44319 .70865 L .44568 .70807 L F
.035 0 0 r
.44139 .70969 m .44319 .70865 L .44457 .70859 L F
.052 0 .125 r
.56034 .58075 m .5622 .57985 L .56275 .57784 L F
0 0 0 r
.55963 .58255 m .5622 .57985 L .56034 .58075 L F
.696 .519 .643 r
.61272 .54672 m .6153 .54905 L .61524 .54677 L F
.284 .597 .95 r
.66245 .51171 m .66079 .51293 L .65849 .51064 L F
.66245 .51171 m .66367 .51352 L .66079 .51293 L F
.287 0 .208 r
.75751 .52057 m .75961 .52164 L .75713 .5223 L F
.75751 .52057 m .75986 .52039 L .75961 .52164 L F
.346 .203 .54 r
.41489 .69763 m .41706 .69989 L .41505 .6964 L F
.41489 .69763 m .41461 .70021 L .41706 .69989 L F
.518 .531 .809 r
.64911 .49864 m .65191 .49841 L .65089 .49672 L F
.421 .422 .755 r
.55155 .63431 m .55127 .63546 L .55322 .63394 L F
.405 .211 .501 r
.59279 .62297 m .59084 .62366 L .59071 .62597 L F
.639 .276 .339 r
.58405 .67475 m .58335 .67708 L .58079 .67632 L F
.266 0 .205 r
.58546 .67613 m .58405 .67475 L .58644 .6744 L F
.58546 .67613 m .58335 .67708 L .58405 .67475 L F
.531 .395 .641 r
.27764 .60345 m .27956 .60048 L .27742 .60098 L F
.802 .864 .895 r
.51122 .80793 m .51277 .80898 L .51404 .80762 L F
.51122 .80793 m .51277 .80898 L .51404 .80762 L F
.72 .47 .548 r
.49177 .6433 m .494 .64589 L .49417 .6436 L F
.522 .301 .52 r
.49417 .6436 m .49632 .64541 L .49645 .64311 L F
.49417 .6436 m .494 .64589 L .49632 .64541 L F
.585 .551 .782 r
.57542 .65154 m .57366 .65301 L .5721 .64888 L F
.402 .18 .459 r
.57517 .65399 m .57366 .65301 L .57542 .65154 L F
.57517 .65399 m .57328 .65461 L .57366 .65301 L F
.365 .07 .325 r
.5622 .57985 m .5648 .57683 L .56275 .57784 L F
.887 .554 .412 r
.56392 .62931 m .56457 .63161 L .56632 .63213 L F
.868 .487 .32 r
.56457 .63161 m .56528 .63349 L .56632 .63213 L F
.988 .732 .444 r
.56632 .63213 m .56528 .63349 L .56644 .6343 L F
.588 .38 .567 r
.57936 .63644 m .5814 .63488 L .57776 .63458 L F
.57936 .63644 m .58166 .63723 L .5814 .63488 L F
.96 .671 .242 r
.5814 .63488 m .58166 .63723 L .57936 .63644 L F
.674 .379 .464 r
.59302 .55422 m .5953 .55468 L .59293 .5524 L F
.637 .386 .522 r
.59293 .5524 m .5953 .55468 L .5954 .55233 L F
.221 0 .081 r
.37094 .63333 m .3701 .63198 L .37221 .63135 L F
.37094 .63333 m .36894 .63408 L .3701 .63198 L F
.882 .869 .821 r
.42014 .70251 m .42163 .70358 L .42253 .70134 L F
.411 .019 .182 r
.5153 .69974 m .51777 .69932 L .51826 .69836 L F
.581 .305 .463 r
.51777 .69932 m .52039 .69748 L .51826 .69836 L F
.559 .872 .994 r
.5256 .65924 m .52439 .66072 L .52479 .65872 L F
.5256 .65924 m .52293 .66006 L .52439 .66072 L F
.451 .141 .348 r
.58022 .56351 m .58255 .56302 L .58293 .56133 L F
.457 .155 .364 r
.58492 .56254 m .58293 .56133 L .58255 .56302 L F
.58492 .56254 m .58534 .5608 L .58293 .56133 L F
.886 .803 .762 r
.2765 .64552 m .27797 .64745 L .27859 .64642 L F
.821 .969 .897 r
.74046 .49317 m .74014 .49515 L .74199 .49484 L F
.758 .887 .936 r
.74046 .49317 m .74199 .49484 L .74504 .49211 L F
.626 .687 .888 r
.7184 .50591 m .71917 .5083 L .72198 .50687 L F
.553 .36 .573 r
.5859 .62917 m .58828 .62863 L .58822 .62638 L F
.564 .381 .592 r
.58828 .62863 m .59071 .62597 L .58822 .62638 L F
.38 .822 .685 r
.74437 .53152 m .74663 .53023 L .74441 .53121 L F
.74437 .53152 m .74791 .52968 L .74663 .53023 L F
.516 .39 .647 r
.59962 .6405 m .59777 .64328 L .59746 .64102 L F
.758 .961 .661 r
.59538 .6591 m .59735 .65613 L .59772 .65781 L F
.59538 .6591 m .59442 .65976 L .59735 .65613 L F
.551 .482 .731 r
.58772 .63318 m .58828 .62863 L .5859 .62917 L F
.58772 .63318 m .58935 .63106 L .58828 .62863 L F
.208 .038 .418 r
.58844 .6343 m .58772 .63318 L .58678 .63465 L F
.58844 .6343 m .58935 .63106 L .58772 .63318 L F
.503 .04 .087 r
.54138 .65689 m .54129 .65769 L .53839 .65743 L F
0 0 .02 r
.54303 .65626 m .54129 .65769 L .54138 .65689 L F
.343 .246 .599 r
.45639 .66566 m .45655 .66821 L .45472 .66618 L F
.644 .479 .646 r
.59841 .57404 m .59706 .57185 L .60028 .57228 L F
.776 .459 .452 r
.60028 .57228 m .60094 .57467 L .59841 .57404 L F
.798 .473 .438 r
.60406 .57504 m .60094 .57467 L .60028 .57228 L F
.459 .274 .541 r
.59515 .62253 m .59314 .62089 L .59279 .62297 L F
.59515 .62253 m .5952 .62017 L .59314 .62089 L F
.968 .834 .657 r
.60722 .59216 m .60536 .59362 L .60573 .59121 L F
.60722 .59216 m .60627 .5943 L .60536 .59362 L F
.398 .822 .966 r
.35671 .58718 m .35894 .58675 L .36022 .58717 L F
.388 .796 .982 r
.35894 .58675 m .36233 .58705 L .36022 .58717 L F
.123 .378 .835 r
.59086 .64404 m .59067 .64249 L .58817 .64088 L F
0 0 .535 r
.59182 .64579 m .59067 .64249 L .59086 .64404 L F
.046 .603 .815 r
.49597 .70626 m .49483 .70597 L .49237 .70579 L F
.708 .27 .208 r
.49835 .70632 m .49483 .70597 L .49597 .70626 L F
.98 .712 .446 r
.51739 .65484 m .51612 .65399 L .51602 .65157 L F
.693 .545 .681 r
.51547 .65499 m .51612 .65399 L .51739 .65484 L F
.474 .286 .545 r
.50109 .65656 m .49877 .65457 L .5031 .65429 L F
.448 .034 .161 r
.50676 .65463 m .5031 .65429 L .50539 .65315 L F
.50676 .65463 m .50109 .65656 L .5031 .65429 L F
.531 .282 .483 r
.59939 .64934 m .59899 .65138 L .59663 .65186 L F
.597 .343 .503 r
.60162 .65102 m .59939 .64934 L .60133 .64851 L F
.60162 .65102 m .59899 .65138 L .59939 .64934 L F
.552 .423 .659 r
.27674 .61194 m .27897 .61157 L .27865 .60911 L F
.523 .55 .825 r
.27674 .61194 m .28015 .61479 L .27897 .61157 L F
0 0 .486 r
.62056 .59502 m .61976 .5956 L .62069 .59388 L F
.62056 .59502 m .62011 .59751 L .61976 .5956 L F
.249 0 .283 r
.5828 .57736 m .58043 .58005 L .58095 .57833 L F
.989 .779 .53 r
.48823 .6601 m .48702 .65929 L .48864 .65773 L F
.48823 .6601 m .48702 .65929 L .48864 .65773 L F
.631 .549 .744 r
.65972 .49738 m .66344 .5 L .66174 .49852 L F
.629 .065 0 r
.66174 .49852 m .66344 .5 L .66481 .50028 L F
.776 .852 .908 r
.73272 .5005 m .73553 .50078 L .73478 .49926 L F
.657 .611 .791 r
.73272 .5005 m .73579 .50333 L .73553 .50078 L F
.247 .749 .895 r
.3262 .58368 m .3285 .58345 L .32989 .58369 L F
.448 .84 .981 r
.3285 .58345 m .33207 .58343 L .32989 .58369 L F
.792 .611 .656 r
.49095 .64311 m .494 .64589 L .49177 .6433 L F
0 .136 .675 r
.72988 .51789 m .73107 .52116 L .7311 .51989 L F
0 0 .541 r
.73194 .52316 m .7311 .51989 L .73107 .52116 L F
.513 .335 .577 r
.37652 .60625 m .37845 .60833 L .37885 .60601 L F
.37652 .60625 m .37627 .60895 L .37845 .60833 L F
.564 .846 .512 r
.69727 .47953 m .69564 .4814 L .69718 .47958 L F
.507 .294 .525 r
.69824 .48284 m .69593 .48367 L .69564 .4814 L F
.651 .959 .768 r
.69564 .4814 m .69472 .48165 L .69718 .47958 L F
0 0 0 r
.48135 .62848 m .48284 .62771 L .48331 .62593 L F
.48135 .62848 m .48044 .63047 L .48284 .62771 L F
.586 .379 .568 r
.60432 .5516 m .60693 .54924 L .60424 .54955 L F
0 0 .071 r
.58496 .63779 m .58643 .63636 L .58678 .63465 L F
.302 .326 .72 r
.58708 .63955 m .58643 .63636 L .58496 .63779 L F
.541 .321 .529 r
.58479 .64036 m .58708 .63955 L .58496 .63779 L F
.37 .461 .823 r
.31829 .61977 m .31803 .62294 L .31619 .62002 L F
.31829 .61977 m .31968 .62307 L .31803 .62294 L F
0 0 0 r
.72377 .4869 m .72285 .48766 L .72386 .487 L F
0 0 .102 r
.72608 .4841 m .72377 .4869 L .72607 .48396 L F
.72608 .4841 m .72581 .4852 L .72377 .4869 L F
.453 .814 .546 r
.72581 .4852 m .72285 .48766 L .72377 .4869 L F
.312 0 0 r
.29709 .58877 m .2993 .58839 L .30087 .58673 L F
.351 0 .063 r
.2993 .58839 m .303 .58623 L .30087 .58673 L F
.403 .589 .918 r
.73584 .53011 m .73728 .52841 L .73533 .52821 L F
.73584 .53011 m .73887 .53072 L .73728 .52841 L F
0 0 .418 r
.52844 .65482 m .52874 .65657 L .52905 .65448 L F
.607 .17 .184 r
.46329 .70613 m .4619 .70782 L .45997 .70742 L F
.43 0 0 r
.46569 .70656 m .4619 .70782 L .46329 .70613 L F
.45 .43 .745 r
.74785 .49126 m .74939 .49603 L .75146 .49377 L F
.548 .581 .839 r
.74939 .49603 m .75162 .49563 L .75146 .49377 L F
.692 .343 .379 r
.50807 .65113 m .50671 .65359 L .5046 .65146 L F
.454 .01 .102 r
.51033 .65202 m .50671 .65359 L .50807 .65113 L F
.704 .969 .739 r
.56092 .62317 m .56351 .62117 L .56098 .62312 L F
.641 .579 .77 r
.71677 .48357 m .71455 .48464 L .71329 .48081 L F
.562 .342 .539 r
.36905 .61479 m .37127 .61456 L .37111 .61216 L F
.43 .125 .345 r
.37127 .61456 m .37424 .61165 L .37111 .61216 L F
.049 .204 .705 r
.44168 .6821 m .43973 .6804 L .44219 .68067 L F
0 0 .354 r
.72729 .48007 m .72607 .48396 L .72761 .48134 L F
.912 .535 .103 r
.72761 .48134 m .72732 .48262 L .72729 .48007 L F
.72761 .48134 m .72847 .48393 L .72732 .48262 L F
.393 .674 .972 r
.73971 .53195 m .74104 .53077 L .73887 .53072 L F
.73971 .53195 m .74199 .53209 L .74104 .53077 L F
.565 .369 .574 r
.60374 .62922 m .60411 .6317 L .60124 .63211 L F
.428 .188 .447 r
.60374 .62922 m .60551 .63073 L .60411 .6317 L F
.60374 .62922 m .60619 .62867 L .60551 .63073 L F
.953 .606 .288 r
.74409 .48578 m .74521 .4877 L .74375 .48606 L F
.74409 .48578 m .74521 .4877 L .74375 .48606 L F
.598 .745 .947 r
.32323 .62377 m .32111 .62447 L .31968 .62307 L F
.478 .61 .904 r
.32391 .62537 m .32111 .62447 L .32323 .62377 L F
.766 .775 .86 r
.49376 .77684 m .48981 .77671 L .49186 .77656 L F
.635 .446 .609 r
.49376 .77684 m .49396 .78022 L .49113 .77982 L F
.253 .75 .902 r
.4959 .7766 m .49376 .77684 L .49186 .77656 L F
.44 .298 .591 r
.49593 .77919 m .49376 .77684 L .4959 .7766 L F
.49593 .77919 m .49396 .78022 L .49376 .77684 L F
.399 .851 .901 r
.71701 .47652 m .71977 .47574 L .72151 .47575 L F
.672 .961 .938 r
.72151 .47575 m .71977 .47574 L .72277 .47409 L F
.59 .628 .858 r
.75091 .50363 m .75478 .50652 L .75334 .50309 L F
.576 .619 .858 r
.75334 .50309 m .75478 .50652 L .75703 .50568 L F
.569 .504 .743 r
.75478 .50652 m .75803 .50927 L .75703 .50568 L F
.977 .678 .368 r
.2765 .64552 m .27675 .64813 L .27797 .64745 L F
.537 .308 .515 r
.41106 .60082 m .41054 .60311 L .40823 .60345 L F
.006 .25 .756 r
.41134 .59924 m .41106 .60082 L .40921 .59735 L F
.38 .164 .456 r
.41249 .60256 m .41106 .60082 L .41134 .59924 L F
.41249 .60256 m .41054 .60311 L .41106 .60082 L F
0 0 0 r
.57466 .58515 m .57418 .58608 L .5729 .58766 L F
.296 0 .147 r
.57307 .5872 m .57418 .58608 L .5729 .58766 L F
.57307 .5872 m .5736 .58723 L .57418 .58608 L F
.5736 .58723 m .57464 .58729 L .57418 .58608 L F
0 0 0 r
.57583 .58348 m .57418 .58608 L .57466 .58515 L F
.57783 .5825 m .57418 .58608 L .57583 .58348 L F
.517 .38 .634 r
.41795 .67478 m .42015 .67437 L .4199 .67148 L F
.427 .286 .586 r
.41795 .67478 m .41993 .6764 L .42015 .67437 L F
.41795 .67478 m .41797 .67745 L .41993 .6764 L F
.827 .612 .613 r
.55133 .75961 m .55399 .76196 L .55374 .76054 L F
.765 .577 .644 r
.6153 .54905 m .61638 .55206 L .61861 .54941 L F
.773 .589 .651 r
.61638 .55206 m .62008 .55256 L .61861 .54941 L F
.144 .16 .617 r
.52116 .65076 m .52142 .65457 L .51986 .6519 L F
.653 .609 .792 r
.55277 .65163 m .54857 .64949 L .55194 .65076 L F
0 .36 .795 r
.55194 .65076 m .55248 .65095 L .55277 .65163 L F
.812 .416 0 r
.553 .6532 m .55277 .65163 L .55248 .65095 L F
.553 .6532 m .55377 .6542 L .55277 .65163 L F
.658 .225 .208 r
.67389 .48663 m .67275 .48808 L .67034 .48636 L F
.748 .337 .27 r
.67389 .48663 m .6761 .48875 L .67275 .48808 L F
.541 .739 .967 r
.69124 .47955 m .69208 .48105 L .68994 .4814 L F
.603 .555 .773 r
.69346 .4844 m .68994 .4814 L .69208 .48105 L F
.503 .713 .966 r
.40182 .59704 m .40114 .59897 L .39985 .59689 L F
.40182 .59704 m .40392 .5987 L .40114 .59897 L F
0 0 0 r
.59579 .66812 m .59463 .6691 L .59723 .66666 L F
.161 0 0 r
.59932 .666 m .59579 .66812 L .59723 .66666 L F
.407 0 .142 r
.35328 .62538 m .35547 .62515 L .35628 .62386 L F
.289 0 .008 r
.35547 .62515 m .35851 .62358 L .35628 .62386 L F
.903 .574 .089 r
.56257 .62572 m .5631 .62811 L .56392 .62931 L F
.98 .692 .387 r
.5631 .62811 m .56457 .63161 L .56392 .62931 L F
.76 .704 .799 r
.56039 .61287 m .56095 .61488 L .56534 .61374 L F
.418 .276 .579 r
.56095 .61488 m .56346 .61628 L .56534 .61374 L F
.729 .371 .372 r
.56346 .61628 m .56686 .61662 L .56534 .61374 L F
.561 .448 .682 r
.56817 .61752 m .56534 .61374 L .56686 .61662 L F
.506 .237 .441 r
.43817 .66035 m .44044 .65999 L .44085 .65789 L F
.559 .306 .488 r
.44044 .65999 m .44331 .65741 L .44085 .65789 L F
.258 0 .121 r
.59463 .6691 m .59392 .67111 L .59153 .67122 L F
0 0 0 r
.59521 .66997 m .59463 .6691 L .59579 .66812 L F
.59521 .66997 m .59392 .67111 L .59463 .6691 L F
.549 .488 .739 r
.76502 .48837 m .76354 .49253 L .76271 .48895 L F
.76502 .48837 m .76588 .49194 L .76354 .49253 L F
.507 .402 .669 r
.76588 .49194 m .7641 .49486 L .76354 .49253 L F
.136 .248 .716 r
.54976 .64807 m .54857 .64949 L .54755 .6459 L F
.306 .505 .888 r
.54976 .64807 m .55194 .65076 L .54857 .64949 L F
.549 .369 .59 r
.51247 .65102 m .51033 .65202 L .51029 .64918 L F
0 0 .354 r
.72729 .48007 m .72732 .48262 L .72607 .48396 L F
0 0 0 r
.72732 .48262 m .72608 .4841 L .72607 .48396 L F
.395 .067 .287 r
.38468 .62442 m .38301 .62369 L .38526 .62326 L F
.38468 .62442 m .38239 .62509 L .38301 .62369 L F
0 0 .075 r
.61639 .60392 m .61819 .60073 L .61775 .60204 L F
0 0 .209 r
.61579 .6059 m .61639 .60392 L .61775 .60204 L F
.596 .507 .724 r
.48373 .65157 m .4872 .65271 L .48575 .64866 L F
.73 .307 .243 r
.72602 .47234 m .72911 .47396 L .72927 .4728 L F
.073 0 0 r
.72911 .47396 m .73149 .47303 L .72927 .4728 L F
.4 .771 .993 r
.71037 .4942 m .70666 .49354 L .70761 .49496 L F
.555 .382 .602 r
.49645 .64311 m .49859 .64005 L .49754 .63798 L F
.45 .16 .38 r
.45409 .65142 m .45629 .65093 L .45676 .64914 L F
.431 .143 .373 r
.45676 .64914 m .45851 .65031 L .45896 .64865 L F
.45676 .64914 m .45629 .65093 L .45851 .65031 L F
.577 .686 .915 r
.5421 .64436 m .53839 .64324 L .54059 .64224 L F
.69 .666 .822 r
.54396 .64303 m .5421 .64436 L .54059 .64224 L F
.787 .924 .927 r
.40701 .59785 m .40392 .5987 L .40549 .59855 L F
.356 0 0 r
.40549 .59855 m .40921 .59735 L .40701 .59785 L F
.493 .363 .632 r
.41612 .6805 m .41817 .68007 L .41797 .67745 L F
.505 .411 .682 r
.41612 .6805 m .41863 .68258 L .41817 .68007 L F
.514 .41 .675 r
.41612 .6805 m .41656 .68309 L .41863 .68258 L F
.551 .379 .602 r
.52553 .76286 m .52582 .76527 L .52381 .76391 L F
.702 .643 .787 r
.76737 .49992 m .76653 .50627 L .765 .5008 L F
.67 .413 .524 r
.5954 .55233 m .59869 .55406 L .59876 .55225 L F
.575 .298 .458 r
.59869 .55406 m .60108 .55401 L .59876 .55225 L F
.629 .263 .33 r
.59876 .55225 m .60108 .55401 L .60112 .55252 L F
.472 .702 .969 r
.43425 .70842 m .43554 .70712 L .4326 .70772 L F
.43425 .70842 m .43641 .70833 L .43554 .70712 L F
.118 0 0 r
.33364 .6006 m .33214 .60153 L .32964 .60203 L F
.183 0 0 r
.33577 .60095 m .33214 .60153 L .33364 .6006 L F
.882 .871 .822 r
.5475 .7665 m .54808 .76862 L .54538 .7689 L F
.986 .753 .497 r
.54808 .76862 m .54679 .77019 L .54538 .7689 L F
.54808 .76862 m .54798 .77148 L .54679 .77019 L F
.925 .568 .333 r
.55087 .77094 m .55168 .7715 L .55023 .7692 L F
.891 .521 .333 r
.55023 .7692 m .55109 .77089 L .55077 .77065 L F
.55023 .7692 m .55077 .77065 L .54808 .76862 L F
.925 .568 .333 r
.55001 .77035 m .55087 .77094 L .55023 .7692 L F
.891 .521 .333 r
.55023 .7692 m .55001 .77035 L .55109 .77089 L F
0 0 .118 r
.55114 .76852 m .55001 .77035 L .55021 .7693 L F
.55029 .76915 m .55021 .7693 L .55023 .7692 L F
.55114 .76852 m .55021 .7693 L .55029 .76915 L F
.694 .486 .602 r
.54808 .76862 m .54983 .76994 L .54798 .77148 L F
.54983 .76994 m .55109 .77089 L .54906 .77127 L F
.54983 .76994 m .54906 .77127 L .54798 .77148 L F
.497 0 0 r
.5475 .7665 m .55037 .76574 L .54808 .76862 L F
.497 .262 .488 r
.60124 .63211 m .6011 .63423 L .5988 .63471 L F
.537 .281 .475 r
.60124 .63211 m .60372 .63377 L .6011 .63423 L F
.60124 .63211 m .60411 .6317 L .60372 .63377 L F
.374 .106 .373 r
.3614 .62023 m .36292 .62214 L .3634 .61983 L F
.3614 .62023 m .36087 .62293 L .36292 .62214 L F
.292 .606 .953 r
.3744 .59776 m .37491 .59655 L .37401 .59674 L F
.319 .638 .965 r
.3744 .59776 m .37626 .59788 L .37491 .59655 L F
0 0 .278 r
.50111 .66804 m .5025 .66967 L .50474 .66846 L F
.3 .205 .577 r
.60762 .62319 m .6079 .62558 L .60648 .62627 L F
.202 .008 .379 r
.60648 .62627 m .6079 .62558 L .60619 .62867 L F
0 0 0 r
.74785 .49126 m .74743 .49155 L .74504 .49211 L F
.09 .38 .842 r
.74785 .49126 m .7513 .49366 L .74973 .49111 L F
.7513 .49366 m .75146 .49377 L .74973 .49111 L F
.55 .664 .912 r
.74883 .48964 m .74973 .49111 L .74903 .48937 L F
.09 .38 .842 r
.74785 .49126 m .74973 .49111 L .74743 .49155 L F
.55 .664 .912 r
.74743 .49155 m .74973 .49111 L .74883 .48964 L F
.606 .756 .95 r
.31896 .64748 m .32021 .64866 L .32193 .64784 L F
.44 .151 .376 r
.38162 .60343 m .37885 .60601 L .3811 .60545 L F
.216 .313 .749 r
.38055 .59996 m .38162 .60343 L .38252 .6021 L F
.608 .513 .721 r
.3811 .60545 m .38252 .6021 L .38162 .60343 L F
.533 .526 .793 r
.44608 .67431 m .44519 .67755 L .44411 .67448 L F
.44608 .67431 m .44739 .67708 L .44519 .67755 L F
.587 .44 .649 r
.44739 .67708 m .44515 .67987 L .44519 .67755 L F
.244 0 0 r
.33945 .60033 m .33831 .6009 L .33577 .60095 L F
0 0 0 r
.34001 .60044 m .33945 .60033 L .34158 .60017 L F
.34001 .60044 m .33831 .6009 L .33945 .60033 L F
.528 .612 .88 r
.73061 .51154 m .73252 .51467 L .72997 .51428 L F
.705 .782 .911 r
.65893 .51791 m .66251 .51831 L .66137 .51724 L F
.87 .885 .843 r
.66137 .51724 m .66251 .51831 L .66473 .51568 L F
.774 .519 .55 r
.48695 .64122 m .49025 .64059 L .48977 .64126 L F
.821 .969 .897 r
.74046 .49317 m .73946 .49429 L .74014 .49515 L F
.522 .371 .617 r
.76426 .49813 m .765 .5008 L .76241 .50122 L F
.086 .476 .893 r
.67884 .49653 m .67964 .49598 L .68089 .495 L F
.322 0 0 r
.68083 .49722 m .68076 .49725 L .67884 .49653 L F
.086 .476 .893 r
.67884 .49653 m .68076 .49725 L .67964 .49598 L F
.693 .167 0 r
.2768 .62629 m .27874 .62804 L .28047 .62813 L F
.382 .8 .976 r
.27874 .62804 m .28243 .6282 L .28047 .62813 L F
.27874 .62804 m .28243 .6282 L .28047 .62813 L F
.74 .714 .827 r
.28203 .63091 m .28243 .6282 L .28047 .62813 L F
.695 .518 .643 r
.60939 .54929 m .61272 .54672 L .60919 .54654 L F
.60939 .54929 m .61269 .54925 L .61272 .54672 L F
.696 .519 .643 r
.61272 .54672 m .61269 .54925 L .6153 .54905 L F
.965 .639 .278 r
.7302 .50577 m .73057 .50481 L .72991 .5037 L F
.671 .696 .865 r
.73057 .50481 m .73331 .50438 L .72991 .5037 L F
.679 .238 .197 r
.27516 .62756 m .27874 .62804 L .2768 .62629 L F
.45 .189 .426 r
.40823 .60345 m .4078 .60562 L .40563 .60604 L F
.443 .151 .372 r
.41054 .60311 m .4078 .60562 L .40823 .60345 L F
.538 .412 .657 r
.76762 .51443 m .76487 .51232 L .7674 .51195 L F
.76762 .51443 m .76531 .5151 L .76487 .51232 L F
.824 .352 0 r
.28546 .63718 m .28398 .63623 L .28228 .63346 L F
0 .042 .61 r
.28546 .63718 m .28594 .63675 L .28398 .63623 L F
.28546 .63718 m .28727 .63966 L .28594 .63675 L F
.843 .864 .858 r
.66944 .51326 m .67285 .51208 L .6717 .5108 L F
.684 .818 .947 r
.6717 .5108 m .67285 .51208 L .67498 .51106 L F
.771 .804 .319 r
.49711 .65235 m .49672 .65288 L .4978 .65145 L F
.468 .804 .999 r
.4957 .65226 m .49681 .65231 L .49672 .65288 L F
.699 .556 .688 r
.49877 .65457 m .49636 .65467 L .49711 .65235 L F
.444 .108 .301 r
.49672 .65288 m .49998 .65082 L .4978 .65145 L F
.49672 .65288 m .4996 .65243 L .49998 .65082 L F
.468 .804 .999 r
.49681 .65231 m .4996 .65243 L .49672 .65288 L F
.771 .804 .319 r
.49711 .65235 m .49654 .65413 L .49672 .65288 L F
.49654 .65413 m .49636 .65467 L .49672 .65288 L F
.534 .208 .361 r
.55297 .61497 m .55537 .61635 L .55614 .61372 L F
.404 .373 .711 r
.55614 .61372 m .55739 .61385 L .5568 .61208 L F
.81 .613 .635 r
.55537 .61635 m .55739 .61385 L .55614 .61372 L F
.949 .784 .643 r
.62078 .56544 m .62234 .56393 L .62109 .563 L F
.62078 .56544 m .62212 .56631 L .62234 .56393 L F
.757 .695 .793 r
.54048 .64028 m .53839 .64324 L .53706 .63979 L F
.568 .434 .658 r
.54059 .64224 m .53839 .64324 L .54048 .64028 L F
0 .044 .598 r
.56065 .64903 m .56129 .64797 L .55985 .64584 L F
0 .181 .706 r
.56065 .64903 m .56258 .65106 L .56129 .64797 L F
.287 .322 .724 r
.48575 .64866 m .48787 .65019 L .48932 .64905 L F
.907 .966 .649 r
.48932 .64905 m .48787 .65019 L .48895 .64851 L F
.284 .769 .916 r
.48787 .65019 m .48794 .65017 L .48895 .64851 L F
.913 .958 .63 r
.48932 .64905 m .48895 .64851 L .49004 .64673 L F
.284 .769 .916 r
.48794 .65017 m .48985 .64964 L .48882 .64873 L F
.225 .654 .956 r
.48738 .65379 m .48787 .65019 L .4872 .65271 L F
.48752 .65274 m .48746 .65303 L .48787 .65019 L F
.48738 .65379 m .48746 .65303 L .48752 .65274 L F
.48738 .65379 m .48925 .65389 L .48746 .65303 L F
.748 .536 .608 r
.48689 .65386 m .48432 .65525 L .48452 .65255 L F
.48852 .65476 m .48597 .65506 L .48689 .65386 L F
.48597 .65506 m .48432 .65525 L .48689 .65386 L F
.48852 .65476 m .48689 .65386 L .48686 .65404 L F
.48689 .65386 m .48452 .65255 L .48686 .65404 L F
.837 .384 .14 r
.48746 .65303 m .48852 .65476 L .48686 .65404 L F
0 0 0 r
.48743 .65317 m .48686 .65404 L .48738 .65343 L F
.48746 .65303 m .4872 .65346 L .48743 .65317 L F
.4872 .65346 m .48686 .65404 L .48743 .65317 L F
.48746 .65303 m .48738 .65343 L .4889 .65161 L F
.287 .322 .724 r
.48575 .64866 m .48644 .65057 L .48787 .65019 L F
.48644 .65057 m .4872 .65271 L .48787 .65019 L F
.284 .769 .916 r
.48787 .65019 m .48678 .64989 L .48882 .64993 L F
.781 .756 .831 r
.48938 .65121 m .4933 .65204 L .49143 .64917 L F
.759 .749 .844 r
.49143 .64917 m .4933 .65204 L .49556 .65001 L F
.49143 .64917 m .49556 .65001 L .49383 .64812 L F
.3 0 0 r
.49383 .64812 m .49151 .64938 L .49143 .64917 L F
.49151 .64938 m .49045 .64996 L .49088 .64962 L F
.49151 .64938 m .49088 .64962 L .49143 .64917 L F
.993 .754 .395 r
.49296 .64496 m .49383 .64812 L .494 .64589 L F
.738 .602 .706 r
.49383 .64812 m .49632 .64541 L .494 .64589 L F
.49383 .64812 m .49732 .64858 L .49632 .64541 L F
.721 .678 .807 r
.49603 .6476 m .49296 .64496 L .49632 .64541 L F
.3 0 0 r
.49383 .64812 m .49257 .64988 L .49045 .64996 L F
.721 .678 .807 r
.49603 .6476 m .49383 .64812 L .49296 .64496 L F
.449 .047 .183 r
.49145 .64903 m .49367 .64859 L .49409 .64542 L F
.669 .733 .898 r
.49383 .64812 m .49556 .65001 L .49732 .64858 L F
.706 .342 .355 r
.49603 .6476 m .49295 .64964 L .49383 .64812 L F
.49295 .64964 m .49257 .64988 L .49283 .64953 L F
.49295 .64964 m .49283 .64953 L .49383 .64812 L F
.56 .49 .734 r
.49732 .64858 m .49875 .64471 L .49632 .64541 L F
.49732 .64858 m .4993 .64821 L .49875 .64471 L F
.633 .58 .777 r
.49645 .65075 m .4957 .65226 L .49739 .65101 L F
.845 .991 .731 r
.49636 .65467 m .49618 .65412 L .49672 .65288 L F
.707 .478 .575 r
.49877 .65457 m .49654 .65693 L .49636 .65467 L F
0 0 .081 r
.49618 .65412 m .4957 .65226 L .49672 .65288 L F
.662 .463 .605 r
.49651 .65503 m .4996 .65243 L .4957 .65226 L F
.633 .58 .777 r
.49645 .65075 m .49665 .65101 L .4957 .65226 L F
.661 .633 .812 r
.4957 .65226 m .49676 .65086 L .49739 .65101 L F
.633 .58 .777 r
.49804 .65131 m .49823 .65309 L .49645 .65075 L F
.706 .342 .355 r
.49603 .6476 m .49739 .65101 L .49277 .64976 L F
.547 .46 .709 r
.49732 .64858 m .49998 .65082 L .4993 .64821 L F
.49732 .64858 m .4978 .65145 L .49998 .65082 L F
0 0 .492 r
.49772 .64822 m .49739 .65101 L .49603 .6476 L F
.384 0 .145 r
.49419 .64944 m .49772 .64822 L .4945 .64843 L F
.661 .633 .812 r
.4957 .65226 m .49265 .64994 L .49676 .65086 L F
.49265 .64994 m .49272 .64992 L .49676 .65086 L F
.706 .342 .355 r
.49277 .64976 m .49645 .65075 L .49257 .64988 L F
.49645 .65075 m .49676 .65086 L .49257 .64988 L F
.384 0 .145 r
.49387 .65052 m .4975 .64835 L .49419 .64944 L F
.4975 .64835 m .49772 .64822 L .49419 .64944 L F
.661 .633 .812 r
.49265 .64994 m .49257 .64988 L .49272 .64992 L F
.633 .58 .777 r
.49665 .65101 m .49823 .65309 L .4957 .65226 L F
.706 .342 .355 r
.49645 .65075 m .49739 .65101 L .49676 .65086 L F
.633 .58 .777 r
.49772 .64822 m .49645 .65075 L .49739 .65101 L F
.49772 .64822 m .49804 .65131 L .49645 .65075 L F
.384 0 .145 r
.49367 .65116 m .49416 .65081 L .49387 .65052 L F
.49416 .65081 m .49772 .64822 L .49387 .65052 L F
.449 .047 .183 r
.49367 .64859 m .4945 .64843 L .49448 .6483 L F
.49367 .64859 m .49448 .6483 L .49409 .64542 L F
.392 .069 .295 r
.49045 .64996 m .49257 .64988 L .49145 .64903 L F
.49045 .64996 m .49145 .64903 L .49125 .64925 L F
.284 .769 .916 r
.48787 .65019 m .49045 .64996 L .49125 .64925 L F
.48787 .65019 m .48882 .64993 L .49045 .64996 L F
.991 .833 .587 r
.48787 .65019 m .48746 .65303 L .48678 .64989 L F
.574 0 0 r
.48787 .65019 m .48678 .64989 L .4848 .64837 L F
.67 .223 .181 r
.48678 .64989 m .4889 .65161 L .49034 .65008 L F
.4902 .64996 m .49034 .65008 L .49045 .64996 L F
.48678 .64989 m .49034 .65008 L .4902 .64996 L F
.284 .769 .916 r
.48882 .64873 m .49125 .64925 L .48895 .64851 L F
.48985 .64964 m .49125 .64925 L .48882 .64873 L F
.913 .958 .63 r
.49004 .64673 m .48895 .64851 L .49035 .64572 L F
.521 .51 .785 r
.49001 .79098 m .49319 .79408 L .49339 .79142 L F
0 .168 .691 r
.49565 .79189 m .49676 .79242 L .49667 .79229 L F
.522 .403 .659 r
.49921 .79155 m .49608 .79153 L .49807 .79034 L F
0 .168 .691 r
.49565 .79189 m .49807 .79034 L .49608 .79153 L F
.49565 .79189 m .4949 .78998 L .49807 .79034 L F
.49565 .79189 m .49667 .79229 L .4949 .78998 L F
.293 .083 .413 r
.49457 .79147 m .49565 .79189 L .49608 .79153 L F
.49339 .79142 m .49565 .79189 L .49457 .79147 L F
.49339 .79142 m .49319 .79408 L .49565 .79189 L F
.688 .371 .433 r
.68761 .47443 m .69107 .47471 L .69095 .47255 L F
.607 .308 .437 r
.69095 .47255 m .69345 .47433 L .69309 .47211 L F
.69095 .47255 m .69107 .47471 L .69345 .47433 L F
.526 .6 .871 r
.57134 .58869 m .57382 .5892 L .57307 .5872 L F
.479 .254 .494 r
.39055 .61775 m .39021 .62004 L .38813 .62039 L F
.473 .245 .488 r
.39271 .6172 m .39021 .62004 L .39055 .61775 L F
.733 .589 .695 r
.49233 .66268 m .49213 .66561 L .49562 .66435 L F
.535 .691 .94 r
.49562 .66435 m .49804 .66396 L .4963 .66195 L F
.62 .602 .811 r
.44221 .69371 m .43988 .69429 L .43864 .69111 L F
.303 .09 .416 r
.47458 .63471 m .47422 .63718 L .47627 .63416 L F
.984 .699 .373 r
.57419 .63172 m .57543 .63553 L .57432 .63413 L F
.639 .573 .765 r
.57776 .63458 m .57543 .63553 L .57419 .63172 L F
.68 .8 .939 r
.57432 .63413 m .57543 .63553 L .57776 .63458 L F
.606 .107 0 r
.42785 .70508 m .42572 .70286 L .42675 .70386 L F
.669 .396 .499 r
.5144 .70195 m .51777 .69932 L .5153 .69974 L F
.455 .139 .34 r
.39021 .62004 m .38732 .62262 L .38813 .62039 L F
.28 .024 .335 r
.58765 .5724 m .58768 .57428 L .58596 .57454 L F
.372 .194 .506 r
.58765 .5724 m .58991 .57382 L .58768 .57428 L F
.58765 .5724 m .59003 .5714 L .58991 .57382 L F
.482 .538 .838 r
.55804 .65677 m .55652 .65826 L .55423 .65456 L F
.291 .222 .604 r
.55804 .65677 m .55645 .66028 L .55652 .65826 L F
.712 .463 .547 r
.29023 .63212 m .29353 .63424 L .29134 .6314 L F
.29023 .63212 m .28955 .63425 L .29353 .63424 L F
.657 .56 .734 r
.28955 .63425 m .29134 .6314 L .29023 .63212 L F
.507 .463 .743 r
.5292 .64975 m .53105 .65136 L .5278 .6522 L F
0 0 0 r
.53107 .65122 m .53006 .65338 L .53105 .65136 L F
.246 .222 .634 r
.53006 .65338 m .5278 .6522 L .53105 .65136 L F
0 0 0 r
.54738 .59144 m .54917 .59096 L .55056 .58993 L F
.54738 .59144 m .54717 .59196 L .54917 .59096 L F
.668 .952 .952 r
.69547 .46847 m .69338 .46973 L .6946 .46805 L F
.37 0 0 r
.69757 .47208 m .69338 .46973 L .69309 .47211 L F
.69593 .47116 m .69657 .47155 L .69338 .46973 L F
.69757 .47208 m .69657 .47155 L .69593 .47116 L F
.775 .632 .703 r
.69928 .47431 m .69657 .47155 L .69757 .47208 L F
.69928 .47431 m .69588 .47417 L .69657 .47155 L F
.334 .247 .606 r
.69588 .47417 m .69691 .47176 L .69657 .47155 L F
.69691 .47176 m .69765 .47001 L .69657 .47155 L F
.259 .38 .796 r
.69338 .46973 m .69657 .47155 L .6946 .46805 L F
.706 .543 .665 r
.60693 .54924 m .60939 .54929 L .60919 .54654 L F
0 0 0 r
.57903 .66405 m .57812 .66496 L .58068 .66267 L F
.516 .39 .647 r
.59962 .6405 m .59996 .6428 L .59777 .64328 L F
.497 0 0 r
.5475 .7665 m .5497 .76695 L .55037 .76574 L F
.656 .608 .789 r
.54912 .76253 m .55037 .76574 L .55225 .76517 L F
.314 .242 .613 r
.55023 .7692 m .55114 .76852 L .55037 .76574 L F
.953 .603 .253 r
.5497 .76695 m .55114 .76852 L .55037 .76574 L F
.693 .753 .897 r
.3037 .64327 m .30665 .6442 L .30604 .64208 L F
.3037 .64327 m .30376 .64425 L .30665 .6442 L F
.514 .592 .87 r
.30604 .64208 m .30665 .6442 L .30816 .64198 L F
.363 .388 .753 r
.30665 .6442 m .30929 .64556 L .30816 .64198 L F
.767 .607 .681 r
.48938 .65121 m .49237 .65394 L .4933 .65204 L F
.513 0 0 r
.50199 .70665 m .50041 .70734 L .49835 .70632 L F
.553 .108 .148 r
.50414 .706 m .50041 .70734 L .50199 .70665 L F
.616 .643 .854 r
.32675 .62629 m .32487 .62671 L .32391 .62537 L F
.792 .56 .586 r
.60406 .57504 m .6005 .57687 L .60094 .57467 L F
.60406 .57504 m .60402 .57751 L .6005 .57687 L F
.927 .563 .309 r
.55352 .61259 m .55537 .61635 L .55297 .61497 L F
.51 .688 .948 r
.44834 .69826 m .44714 .70025 L .44528 .69744 L F
.44834 .69826 m .44909 .69986 L .44714 .70025 L F
0 0 0 r
.61968 .59823 m .61937 .59925 L .61819 .60073 L F
0 0 .223 r
.61819 .60073 m .61937 .59925 L .61906 .60154 L F
.807 .719 .186 r
.61916 .59995 m .61937 .59925 L .61943 .59578 L F
.61906 .60154 m .61937 .59925 L .61916 .59995 L F
0 0 0 r
.62011 .59751 m .61937 .59925 L .61968 .59823 L F
0 0 .223 r
.61819 .60073 m .61906 .60154 L .61775 .60204 L F
.993 .876 .596 r
.49048 .80672 m .49147 .80784 L .4905 .8085 L F
.908 .946 .816 r
.49179 .80621 m .49147 .80784 L .49048 .80672 L F
.938 .96 .665 r
.4905 .8085 m .49147 .80784 L .49179 .80621 L F
.143 .256 .722 r
.56383 .66021 m .5656 .66207 L .56454 .65863 L F
.044 0 .271 r
.65638 .51412 m .65738 .51362 L .65778 .51314 L F
.65638 .51412 m .65738 .51362 L .65778 .51314 L F
.376 .794 .977 r
.36233 .58705 m .36457 .58671 L .36602 .58731 L F
.484 .833 .997 r
.36457 .58671 m .3682 .58694 L .36602 .58731 L F
.255 .743 .922 r
.35077 .59961 m .34941 .59923 L .34734 .59926 L F
.5 .876 .976 r
.35155 .59858 m .35077 .59961 L .35326 .59915 L F
.35155 .59858 m .34941 .59923 L .35077 .59961 L F
.87 .885 .843 r
.66137 .51724 m .66473 .51568 L .66367 .51352 L F
.103 .565 .912 r
.66724 .51489 m .66367 .51352 L .66473 .51568 L F
.249 0 .082 r
.59392 .67111 m .5907 .67312 L .59153 .67122 L F
.332 .019 .275 r
.58643 .63636 m .58844 .6343 L .58678 .63465 L F
.437 .756 .995 r
.73877 .51748 m .73928 .51851 L .73594 .51766 L F
.821 .96 .902 r
.74215 .51587 m .73928 .51851 L .73877 .51748 L F
.779 .63 .695 r
.61632 .55455 m .62008 .55256 L .61638 .55206 L F
.61632 .55455 m .61974 .55493 L .62008 .55256 L F
0 0 0 r
.3625 .59744 m .36142 .59783 L .35924 .59826 L F
.36477 .59716 m .36142 .59783 L .3625 .59744 L F
.297 0 0 r
.34363 .58485 m .34718 .58628 L .34537 .58552 L F
.516 .522 .801 r
.27897 .61157 m .28015 .61479 L .28205 .61431 L F
.446 .272 .551 r
.28015 .61479 m .28023 .61714 L .28205 .61431 L F
.376 .764 .989 r
.28091 .78779 m .28254 .78858 L .28311 .78764 L F
.28091 .78779 m .28254 .78858 L .28311 .78764 L F
0 .544 .736 r
.33814 .6287 m .34206 .62911 L .33979 .62977 L F
.508 0 0 r
.53841 .69632 m .53996 .69715 L .54147 .69754 L F
0 0 0 r
.54066 .69881 m .5388 .70011 L .54014 .69882 L F
.492 .036 .096 r
.53925 .69911 m .54107 .69879 L .54066 .69881 L F
.449 .241 .505 r
.54244 .70117 m .54066 .69881 L .54236 .69857 L F
.492 .036 .096 r
.54107 .69879 m .54236 .69857 L .54066 .69881 L F
0 0 0 r
.54066 .69881 m .54014 .69882 L .54147 .69754 L F
.665 .968 .788 r
.59436 .65322 m .59466 .65278 L .59663 .65186 L F
.816 .543 .527 r
.59899 .65138 m .59562 .64852 L .59663 .65186 L F
.841 .995 .84 r
.59663 .65186 m .59608 .65127 L .59899 .65138 L F
.59663 .65186 m .59466 .65278 L .59608 .65127 L F
.55 .405 .636 r
.59899 .65138 m .59687 .6543 L .59663 .65186 L F
.692 .384 .449 r
.59538 .64617 m .59563 .64852 L .59191 .64819 L F
0 0 .306 r
.59649 .646 m .59538 .64617 L .59562 .64852 L F
.59649 .646 m .59563 .64852 L .59538 .64617 L F
.694 .404 .48 r
.70229 .46392 m .70443 .46573 L .70356 .46418 L F
.138 0 0 r
.54917 .59096 m .5528 .589 L .55056 .58993 L F
.67 .413 .524 r
.5954 .55233 m .5953 .55468 L .59869 .55406 L F
.402 .076 .294 r
.38026 .62576 m .37943 .62847 L .37716 .629 L F
.328 .01 .265 r
.38148 .62767 m .38026 .62576 L .38239 .62509 L F
.38148 .62767 m .37943 .62847 L .38026 .62576 L F
.469 .008 .073 r
.46909 .70582 m .46776 .70744 L .46569 .70656 L F
.616 .215 .26 r
.47144 .70593 m .46776 .70744 L .46909 .70582 L F
.049 .616 .756 r
.36783 .59718 m .36704 .59714 L .36477 .59716 L F
.975 .701 .443 r
.36704 .59714 m .36357 .59745 L .36477 .59716 L F
.36704 .59714 m .36571 .59699 L .36357 .59745 L F
.36704 .59714 m .36712 .59929 L .36576 .59707 L F
.36704 .59714 m .36576 .59707 L .36571 .59699 L F
.049 .616 .756 r
.36821 .59719 m .36704 .59714 L .36783 .59718 L F
.433 .851 .958 r
.37037 .59672 m .36704 .59714 L .36821 .59719 L F
.65 .738 .914 r
.26927 .66718 m .27181 .66869 L .2684 .66836 L F
.585 .096 .06 r
.27181 .66869 m .27146 .66973 L .2684 .66836 L F
.191 0 0 r
.26927 .66718 m .27252 .6677 L .27181 .66869 L F
0 0 .49 r
.27146 .6707 m .27146 .66973 L .27181 .66869 L F
.389 .536 .882 r
.39825 .59423 m .39803 .59683 L .39617 .59441 L F
.39825 .59423 m .39985 .59689 L .39803 .59683 L F
.284 0 0 r
.34551 .64273 m .34398 .64409 L .34194 .64436 L F
.315 0 0 r
.34748 .64231 m .34398 .64409 L .34551 .64273 L F
.291 .056 .375 r
.58596 .57454 m .58738 .57619 L .58513 .57686 L F
.58596 .57454 m .58768 .57428 L .58738 .57619 L F
.551 .921 .941 r
.48886 .62027 m .48987 .61914 L .49099 .61934 L F
.561 .931 .92 r
.48886 .62027 m .4878 .62015 L .48987 .61914 L F
.714 .802 .92 r
.55109 .77089 m .55001 .77035 L .54798 .77148 L F
.765 .797 .879 r
.55109 .77089 m .55168 .7715 L .55001 .77035 L F
.427 .816 .987 r
.29726 .85927 m .30112 .85947 L .29945 .85889 L F
.29726 .85927 m .30112 .85947 L .29945 .85889 L F
.513 .093 .18 r
.50613 .70354 m .50938 .70308 L .50701 .70405 L F
.976 .785 .581 r
.60722 .58656 m .60537 .58793 L .6055 .58544 L F
.60722 .58656 m .6067 .58897 L .60537 .58793 L F
0 .049 .608 r
.28228 .63346 m .28398 .63623 L .28274 .63268 L F
.673 .792 .938 r
.58479 .64036 m .58817 .64088 L .58708 .63955 L F
.446 .386 .697 r
.58817 .64088 m .59005 .64007 L .58708 .63955 L F
.58817 .64088 m .59067 .64249 L .59005 .64007 L F
.874 .448 .189 r
.66344 .5 m .66567 .50143 L .66481 .50028 L F
.8 .59 .027 r
.49636 .65467 m .49654 .65693 L .49618 .65412 L F
.49636 .65467 m .49654 .65693 L .49618 .65412 L F
.572 .44 .663 r
.6011 .63423 m .59904 .63701 L .5988 .63471 L F
.764 .842 .911 r
.74716 .51419 m .74408 .51456 L .74702 .51231 L F
.747 .801 .896 r
.74887 .51102 m .74716 .51419 L .74702 .51231 L F
.74887 .51102 m .75026 .51255 L .74716 .51419 L F
.868 .706 .678 r
.62001 .57402 m .62303 .57195 L .62195 .57122 L F
.62001 .57402 m .62178 .57475 L .62303 .57195 L F
.531 .395 .641 r
.27764 .60345 m .27975 .60295 L .27956 .60048 L F
.525 .43 .689 r
.27764 .60345 m .28005 .60549 L .27975 .60295 L F
.27764 .60345 m .2781 .60603 L .28005 .60549 L F
.81 .811 .325 r
.62056 .59502 m .61937 .59925 L .62011 .59751 L F
.497 .399 .674 r
.41953 .66905 m .42189 .67101 L .4219 .66861 L F
.41953 .66905 m .4199 .67148 L .42189 .67101 L F
.522 .403 .659 r
.49921 .79155 m .49719 .7939 L .49608 .79153 L F
.49921 .79155 m .49936 .79374 L .49719 .7939 L F
.557 .285 .459 r
.65735 .48352 m .65973 .48328 L .65965 .4813 L F
.604 .32 .459 r
.65973 .48328 m .66389 .48056 L .65965 .4813 L F
.473 .449 .75 r
.47552 .67121 m .47402 .6721 L .47363 .66969 L F
.172 0 .253 r
.47552 .67121 m .47323 .67409 L .47402 .6721 L F
.939 .855 .731 r
.5529 .65952 m .54976 .66194 L .55235 .65925 L F
.5529 .65952 m .55129 .66303 L .54976 .66194 L F
.589 .499 .721 r
.46477 .66041 m .46268 .66323 L .46193 .66062 L F
.46477 .66041 m .46524 .66324 L .46268 .66323 L F
.505 .087 .18 r
.46488 .6644 m .46268 .66323 L .46524 .66324 L F
.46488 .6644 m .46142 .66501 L .46268 .66323 L F
.529 .003 0 r
.53676 .5966 m .53882 .597 L .53991 .59625 L F
.165 0 0 r
.53882 .597 m .54259 .59558 L .53991 .59625 L F
.955 .803 .654 r
.62109 .57945 m .62233 .58053 L .62155 .57736 L F
.985 .763 .521 r
.62092 .58167 m .62233 .58053 L .62109 .57945 L F
.62092 .58167 m .62207 .58293 L .62233 .58053 L F
.494 .157 .324 r
.32154 .60799 m .31912 .6084 L .31983 .60673 L F
.849 .596 .556 r
.60534 .58081 m .60326 .58254 L .60329 .57994 L F
.60534 .58081 m .60536 .58302 L .60326 .58254 L F
0 0 0 r
.55339 .76328 m .55225 .76517 L .55399 .76196 L F
.827 .612 .613 r
.55133 .75961 m .55339 .76328 L .55399 .76196 L F
.843 .789 .799 r
.50292 .79651 m .50342 .79866 L .50323 .79722 L F
.84 .708 .718 r
.50042 .80042 m .50202 .80279 L .50342 .79866 L F
.50042 .80042 m .50342 .79866 L .50354 .79975 L F
0 0 .351 r
.50377 .79881 m .50342 .79866 L .50292 .79651 L F
0 0 .081 r
.50354 .79975 m .50342 .79866 L .50377 .79881 L F
.659 .487 .64 r
.7236 .47211 m .72602 .47234 L .72587 .46942 L F
.191 .708 .883 r
.52177 .63764 m .52423 .63754 L .52526 .63783 L F
.319 .684 .978 r
.52625 .63689 m .52526 .63783 L .52423 .63754 L F
.52625 .63689 m .52758 .63797 L .52526 .63783 L F
.568 .552 .797 r
.762 .48726 m .76502 .48837 L .76271 .48895 L F
.781 .884 .921 r
.67858 .49985 m .67623 .50091 L .67903 .49882 L F
.868 .986 .837 r
.68083 .49722 m .67858 .49985 L .67903 .49882 L F
.916 .76 .674 r
.62078 .56544 m .62204 .56912 L .62212 .56631 L F
.515 0 0 r
.42728 .66288 m .42637 .66302 L .43004 .66322 L F
.635 .172 .136 r
.42637 .66302 m .42866 .66468 L .43004 .66322 L F
.036 0 0 r
.43004 .66322 m .43072 .66392 L .43226 .66277 L F
.43004 .66322 m .42866 .66468 L .43072 .66392 L F
.271 .112 .473 r
.61342 .6135 m .61188 .61664 L .61181 .61414 L F
.819 .782 .278 r
.60488 .60074 m .60427 .60298 L .60444 .59994 L F
0 .009 .585 r
.49857 .65914 m .50045 .6631 L .49845 .66004 L F
.212 0 0 r
.35374 .63986 m .35283 .64064 L .34944 .64171 L F
.098 0 0 r
.35498 .64005 m .35374 .63986 L .35582 .63925 L F
.35498 .64005 m .35283 .64064 L .35374 .63986 L F
.518 0 0 r
.46457 .69897 m .46629 .69978 L .46779 .70002 L F
.502 0 0 r
.46629 .69978 m .47039 .70009 L .46779 .70002 L F
.16 0 0 r
.3073 .58517 m .3111 .58361 L .30883 .58356 L F
.469 .336 .616 r
.28198 .59753 m .28394 .59458 L .2817 .5952 L F
.707 .478 .575 r
.49877 .65457 m .49867 .65746 L .49654 .65693 L F
.474 .286 .545 r
.50109 .65656 m .49867 .65746 L .49877 .65457 L F
.978 .739 .507 r
.28002 .61988 m .28144 .62064 L .28023 .61714 L F
.28002 .61988 m .28144 .62064 L .28023 .61714 L F
.291 .222 .604 r
.55804 .65677 m .55851 .65914 L .55645 .66028 L F
.491 .416 .699 r
.55851 .65914 m .5568 .6627 L .55645 .66028 L F
.896 .988 .767 r
.62151 .58825 m .62166 .58931 L .62219 .58755 L F
.751 .677 .129 r
.62151 .58825 m .62118 .59151 L .62166 .58931 L F
.279 0 0 r
.42728 .66288 m .42434 .66284 L .42637 .66302 L F
.631 .231 .268 r
.5388 .70011 m .53779 .70211 L .53549 .70144 L F
.56 .336 .533 r
.54066 .69881 m .53779 .70211 L .5388 .70011 L F
.712 .309 .282 r
.47961 .70225 m .48146 .70299 L .48328 .70222 L F
.812 .351 .135 r
.58011 .64004 m .58252 .64129 L .58098 .6414 L F
.65 .854 .978 r
.58252 .64129 m .58196 .64019 L .58098 .6414 L F
.58252 .64129 m .58479 .64036 L .58196 .64019 L F
.472 .23 .465 r
.40563 .60604 m .40543 .60849 L .40317 .60887 L F
.525 .274 .476 r
.40767 .60784 m .40563 .60604 L .4078 .60562 L F
.40767 .60784 m .40543 .60849 L .40563 .60604 L F
.417 .157 .41 r
.57246 .57164 m .57495 .56896 L .57273 .56952 L F
.904 .873 .796 r
.73388 .49787 m .73478 .49926 L .73836 .49572 L F
.662 .188 .116 r
.29493 .63854 m .29247 .6388 L .29088 .63753 L F
.519 .312 .538 r
.2952 .63636 m .29247 .6388 L .29493 .63854 L F
.521 .693 .946 r
.33632 .58211 m .33565 .58409 L .33424 .58288 L F
.33632 .58211 m .33766 .58365 L .33565 .58409 L F
.303 .088 .412 r
.60147 .6114 m .60191 .60901 L .59984 .61188 L F
.388 .315 .653 r
.59984 .61188 m .60207 .61376 L .60147 .6114 L F
.452 .314 .602 r
.60006 .61464 m .60207 .61376 L .59984 .61188 L F
0 0 .134 r
.48331 .62593 m .48479 .62476 L .4855 .62256 L F
0 0 0 r
.48331 .62593 m .48284 .62771 L .48479 .62476 L F
0 .132 .675 r
.49113 .77982 m .49197 .77934 L .48981 .77671 L F
.28 0 0 r
.49396 .78022 m .49369 .78044 L .49113 .77982 L F
.069 .493 .895 r
.49113 .77982 m .49369 .78044 L .49197 .77934 L F
0 0 .408 r
.49439 .63934 m .49345 .63709 L .49443 .63792 L F
.647 .679 .866 r
.71346 .4952 m .71766 .49651 L .71587 .49454 L F
.791 .73 .796 r
.71587 .49454 m .71766 .49651 L .71885 .49465 L F
.421 .64 .947 r
.56981 .63948 m .57201 .63951 L .57042 .64032 L F
0 0 .085 r
.57201 .63951 m .57073 .64338 L .57042 .64032 L F
.507 .402 .669 r
.76588 .49194 m .76639 .49422 L .7641 .49486 L F
.528 .438 .697 r
.76639 .49422 m .76426 .49813 L .7641 .49486 L F
.43 .125 .345 r
.37127 .61456 m .37355 .61418 L .37424 .61165 L F
.32 .028 .303 r
.37424 .61165 m .37546 .61339 L .37621 .61073 L F
.37424 .61165 m .37355 .61418 L .37546 .61339 L F
.694 .404 .48 r
.70229 .46392 m .70045 .46619 L .70443 .46573 L F
.756 .663 .758 r
.66098 .50065 m .6624 .50407 L .66438 .50296 L F
.801 .761 .817 r
.66344 .5 m .66438 .50296 L .66567 .50143 L F
.556 .624 .875 r
.55412 .60472 m .55654 .60602 L .55632 .60341 L F
.398 0 .142 r
.55632 .60341 m .553 .60551 L .55412 .60472 L F
.55632 .60341 m .55527 .60538 L .553 .60551 L F
.652 .505 .671 r
.55861 .60052 m .55632 .60341 L .55868 .60284 L F
.704 .594 .73 r
.55654 .60602 m .55868 .60284 L .55632 .60341 L F
.201 0 0 r
.55868 .60284 m .55527 .60538 L .55632 .60341 L F
.652 .505 .671 r
.55861 .60052 m .55632 .60341 L .55868 .60284 L F
.591 .835 .991 r
.55457 .60872 m .55756 .6091 L .55654 .60602 L F
.706 .584 .716 r
.55654 .60602 m .55756 .6091 L .56043 .60646 L F
.486 .423 .711 r
.55739 .61385 m .5596 .6125 L .5568 .61208 L F
.64 .898 .984 r
.55739 .61385 m .55698 .61122 L .5568 .61208 L F
.529 .632 .897 r
.55698 .61122 m .55739 .61385 L .55404 .61108 L F
.914 .885 .79 r
.55739 .61385 m .55507 .6137 L .55698 .61122 L F
.483 0 0 r
.55698 .61122 m .55513 .61208 L .55677 .61195 L F
0 0 .553 r
.55698 .61122 m .55767 .61188 L .55739 .61385 L F
.64 .898 .984 r
.55739 .61385 m .55767 .61188 L .55698 .61122 L F
.483 0 0 r
.55698 .61122 m .55677 .61195 L .55767 .61188 L F
.528 .868 .605 r
.55698 .61122 m .55756 .6091 L .55727 .61026 L F
.55698 .61122 m .55727 .61026 L .5568 .61208 L F
.55698 .61122 m .55928 .6093 L .55756 .6091 L F
.808 .633 .665 r
.61626 .557 m .61974 .55493 L .61632 .55455 L F
.61626 .557 m .618 .55795 L .61974 .55493 L F
.724 .735 .859 r
.29939 .63654 m .30024 .63809 L .30242 .63707 L F
.611 .153 .141 r
.59305 .5699 m .59495 .57105 L .59185 .57106 L F
.27 0 0 r
.59305 .5699 m .59185 .57106 L .59003 .5714 L F
.616 .578 .789 r
.69593 .48367 m .69346 .4844 L .69208 .48105 L F
.805 .814 .859 r
.49515 .80003 m .49841 .79958 L .49709 .79875 L F
.39 .467 .819 r
.49841 .79958 m .50011 .79834 L .49709 .79875 L F
.49841 .79958 m .50042 .80042 L .50011 .79834 L F
.553 .108 .148 r
.50414 .706 m .50299 .70775 L .50041 .70734 L F
.113 0 0 r
.50753 .70527 m .50619 .70604 L .50414 .706 L F
.50619 .70604 m .50581 .70616 L .50414 .706 L F
.192 0 0 r
.50513 .70701 m .50414 .706 L .50595 .70618 L F
.50513 .70701 m .50299 .70775 L .50414 .706 L F
.609 .068 0 r
.49915 .70497 m .50513 .70701 L .505 .70433 L F
.49915 .70497 m .50305 .70693 L .50513 .70701 L F
.885 .644 .568 r
.505 .70433 m .50305 .70693 L .5034 .70694 L F
.5051 .70639 m .5034 .70694 L .50513 .70701 L F
.505 .70433 m .5034 .70694 L .5051 .70639 L F
.113 0 0 r
.50619 .70604 m .50595 .70618 L .50581 .70616 L F
.775 .349 .241 r
.50968 .70601 m .50595 .70618 L .50753 .70527 L F
.49 .436 .724 r
.41814 .69169 m .41965 .6882 L .41752 .68863 L F
.41814 .69169 m .42006 .69136 L .41965 .6882 L F
.408 .198 .48 r
.41784 .69346 m .42006 .69136 L .41814 .69169 L F
.427 .14 .373 r
.57757 .56581 m .58 .56522 L .58022 .56351 L F
.51 .234 .431 r
.58 .56522 m .58255 .56302 L .58022 .56351 L F
.856 .567 .5 r
.61773 .55985 m .62109 .563 L .62103 .56071 L F
.39 0 0 r
.49956 .76744 m .50142 .76751 L .49991 .76702 L F
.463 .139 .332 r
.45094 .65423 m .45337 .65381 L .45409 .65142 L F
.359 .025 .256 r
.45337 .65381 m .45629 .65093 L .45409 .65142 L F
.336 .622 .956 r
.4641 .6734 m .46569 .67495 L .46623 .67368 L F
.953 .662 .449 r
.5911 .65606 m .591 .65864 L .59223 .65747 L F
.677 .147 0 r
.59311 .65899 m .59223 .65747 L .591 .65864 L F
.127 0 .096 r
.591 .65864 m .59188 .65988 L .59311 .65899 L F
.478 .842 .593 r
.59311 .65899 m .59188 .65988 L .59274 .65919 L F
.885 .906 .837 r
.59711 .65617 m .59566 .65727 L .59519 .65641 L F
.59735 .65613 m .59684 .65647 L .59711 .65617 L F
.59684 .65647 m .59566 .65727 L .59711 .65617 L F
.731 .428 .467 r
.59735 .65613 m .59519 .65641 L .59385 .65466 L F
.116 .25 .726 r
.59564 .657 m .59668 .65454 L .59475 .65275 L F
.59572 .65737 m .59578 .65719 L .59564 .657 L F
.59578 .65719 m .59668 .65454 L .59564 .657 L F
.731 .428 .467 r
.59385 .65466 m .5931 .65669 L .5929 .65425 L F
.59519 .65641 m .5931 .65669 L .59385 .65466 L F
.711 .686 .824 r
.5931 .65669 m .59543 .65766 L .59557 .65733 L F
.677 .147 0 r
.59311 .65899 m .59442 .65976 L .59348 .65878 L F
.885 .906 .837 r
.59735 .65613 m .59465 .65947 L .59557 .65733 L F
.418 .27 .571 r
.59543 .65766 m .59497 .65783 L .59581 .65781 L F
.5931 .65669 m .59518 .65759 L .59543 .65766 L F
.885 .906 .837 r
.59557 .65733 m .59518 .65759 L .5931 .65669 L F
.59518 .65759 m .59311 .65899 L .5931 .65669 L F
.418 .27 .571 r
.5931 .65669 m .59413 .65732 L .59518 .65759 L F
.59413 .65732 m .59497 .65783 L .59543 .65766 L F
.885 .906 .837 r
.59518 .65759 m .59442 .65976 L .59311 .65899 L F
.59557 .65733 m .59541 .65765 L .59518 .65759 L F
.59541 .65765 m .59442 .65976 L .59518 .65759 L F
.59465 .65947 m .59442 .65976 L .59557 .65733 L F
.711 .686 .824 r
.59557 .65733 m .59581 .65781 L .59572 .65737 L F
.59543 .65766 m .59581 .65781 L .59557 .65733 L F
.116 .25 .726 r
.59581 .65781 m .59586 .65763 L .59572 .65737 L F
.59586 .65763 m .59668 .65454 L .59572 .65737 L F
.885 .906 .837 r
.59519 .65641 m .59557 .65733 L .5931 .65669 L F
.59566 .65727 m .59557 .65733 L .59519 .65641 L F
.711 .686 .824 r
.5931 .65669 m .59572 .65737 L .59475 .65275 L F
.836 .965 .64 r
.59497 .65783 m .59668 .65454 L .59586 .65763 L F
.5957 .65782 m .59586 .65763 L .59581 .65781 L F
.59497 .65783 m .59586 .65763 L .5957 .65782 L F
.418 .27 .571 r
.5931 .65669 m .59311 .65899 L .59497 .65783 L F
.478 .842 .593 r
.59311 .65899 m .59274 .65919 L .59467 .65766 L F
.677 .147 0 r
.59311 .65899 m .59348 .65878 L .59223 .65747 L F
.737 .663 .777 r
.29353 .63424 m .29636 .63528 L .2951 .63291 L F
.783 .394 .318 r
.29353 .63424 m .2952 .63636 L .29636 .63528 L F
.458 0 0 r
.29841 .63469 m .2951 .63291 L .29636 .63528 L F
.566 .513 .754 r
.29636 .63528 m .29939 .63654 L .29841 .63469 L F
.833 .895 .885 r
.72055 .49017 m .71989 .49284 L .72153 .49107 L F
.72055 .49017 m .71875 .4919 L .71989 .49284 L F
.928 .877 .765 r
.71875 .4919 m .71885 .49465 L .71989 .49284 L F
.35 .057 .32 r
.47204 .63777 m .47334 .63899 L .47422 .63718 L F
.47204 .63777 m .47137 .63972 L .47334 .63899 L F
.742 .879 .943 r
.6704 .50305 m .66847 .50442 L .66738 .50309 L F
.676 .681 .847 r
.70751 .48286 m .70511 .48373 L .7041 .48078 L F
.68 .722 .882 r
.71078 .48361 m .708 .48102 L .70991 .48092 L F
.71078 .48361 m .70751 .48286 L .708 .48102 L F
.72 .617 .742 r
.71329 .48081 m .71078 .48361 L .70991 .48092 L F
.929 .845 .739 r
.72796 .48961 m .72693 .49192 L .72669 .4886 L F
.029 .426 .865 r
.44416 .69606 m .44348 .69656 L .44221 .69371 L F
.44416 .69606 m .44528 .69744 L .44348 .69656 L F
.039 0 0 r
.41396 .70258 m .41233 .70338 L .41318 .70362 L F
.837 .438 .29 r
.41558 .70607 m .41405 .70641 L .41233 .70338 L F
0 .036 .597 r
.41233 .70338 m .41405 .70641 L .41318 .70362 L F
.313 .688 .978 r
.38182 .58833 m .38116 .58928 L .37973 .58832 L F
.38182 .58833 m .38333 .58941 L .38116 .58928 L F
.458 .16 .371 r
.36438 .63485 m .36394 .63647 L .36184 .63678 L F
.444 .148 .366 r
.3661 .63591 m .36438 .63485 L .36684 .63472 L F
.3661 .63591 m .36394 .63647 L .36438 .63485 L F
.774 .942 .935 r
.26927 .66718 m .2684 .66836 L .26862 .66748 L F
.294 .462 .856 r
.2684 .66836 m .27146 .66973 L .26862 .66748 L F
.56 .1 .117 r
.66532 .48118 m .6679 .48239 L .66894 .48094 L F
.593 .136 .137 r
.66894 .48094 m .6679 .48239 L .67149 .48229 L F
.577 .216 .32 r
.66894 .48094 m .67149 .48229 L .67129 .48099 L F
.73 .787 .898 r
.47614 .66925 m .47363 .66969 L .47422 .66783 L F
.681 .417 .516 r
.47614 .66925 m .47552 .67121 L .47363 .66969 L F
.613 .766 .953 r
.47422 .66783 m .47614 .66925 L .47781 .66832 L F
.268 .02 .34 r
.47781 .66832 m .47552 .67121 L .47614 .66925 L F
.532 .651 .911 r
.76152 .48553 m .75909 .48595 L .7575 .48353 L F
.528 .438 .697 r
.76639 .49422 m .76674 .49837 L .76426 .49813 L F
.649 .53 .705 r
.76674 .49837 m .765 .5008 L .76426 .49813 L F
.756 .802 .89 r
.30929 .64556 m .31128 .64708 L .31325 .64584 L F
.416 .02 .177 r
.33288 .64796 m .33028 .64794 L .33441 .64652 L F
.002 0 0 r
.33463 .64733 m .33441 .64652 L .33646 .64588 L F
.33463 .64733 m .33288 .64796 L .33441 .64652 L F
.864 .934 .868 r
.72285 .48766 m .72153 .49107 L .72386 .487 L F
.72285 .48766 m .72055 .49017 L .72153 .49107 L F
.45 .298 .583 r
.41656 .68309 m .41859 .68496 L .41863 .68258 L F
.41656 .68309 m .41665 .68549 L .41859 .68496 L F
.812 .7 .742 r
.68592 .48717 m .68177 .48806 L .68201 .48697 L F
.572 .533 .773 r
.47098 .67454 m .47185 .67066 L .4697 .67128 L F
.858 .712 .699 r
.72241 .4978 m .71934 .49943 L .72128 .49659 L F
.72241 .4978 m .72088 .50079 L .71934 .49943 L F
.886 .89 .829 r
.72473 .49472 m .72241 .4978 L .72128 .49659 L F
.388 .844 .901 r
.41793 .70573 m .41405 .70641 L .41558 .70607 L F
.595 .193 .251 r
.66444 .48622 m .66334 .48814 L .6611 .48761 L F
.481 .028 .097 r
.66667 .48667 m .66334 .48814 L .66444 .48622 L F
.74 .851 .932 r
.49443 .63792 m .49846 .63749 L .49733 .63634 L F
.173 0 0 r
.50091 .63678 m .49733 .63634 L .49846 .63749 L F
.556 .394 .616 r
.49859 .64005 m .50091 .63678 L .49846 .63749 L F
.716 .442 .509 r
.52238 .69872 m .52625 .69745 L .52231 .69675 L F
.52238 .69872 m .5261 .69963 L .52625 .69745 L F
.683 .448 .559 r
.5261 .69963 m .52979 .69747 L .52625 .69745 L F
.32 .075 .378 r
.46951 .64044 m .4691 .64248 L .47137 .63972 L F
.513 .287 .508 r
.36647 .6176 m .3687 .61718 L .36905 .61479 L F
.462 .198 .427 r
.3687 .61718 m .37127 .61456 L .36905 .61479 L F
.535 .253 .434 r
.55861 .60052 m .56013 .60163 L .56152 .60022 L F
.386 .296 .63 r
.55868 .60284 m .56013 .60163 L .55861 .60052 L F
.535 .253 .434 r
.55861 .60052 m .56013 .60163 L .56152 .60022 L F
.386 .296 .63 r
.55868 .60284 m .56013 .60163 L .55861 .60052 L F
.954 .769 .613 r
.41461 .70021 m .41396 .70258 L .4129 .69914 L F
.834 .693 .708 r
.28955 .63425 m .28778 .63737 L .29088 .63753 L F
.728 .5 .581 r
.28727 .63966 m .29088 .63753 L .28778 .63737 L F
.28727 .63966 m .29073 .63994 L .29088 .63753 L F
.199 .332 .775 r
.28955 .63425 m .29088 .63753 L .29198 .63624 L F
.174 .295 .748 r
.29088 .63753 m .29247 .6388 L .29198 .63624 L F
.704 .594 .73 r
.55654 .60602 m .56043 .60646 L .55868 .60284 L F
.269 .365 .777 r
.55868 .60284 m .56043 .60646 L .56086 .60478 L F
.658 .377 .482 r
.53034 .70296 m .52714 .70449 L .52767 .70335 L F
.658 .906 .98 r
.28266 .6431 m .28055 .64411 L .28125 .6425 L F
.28266 .6431 m .28055 .64411 L .28125 .6425 L F
.384 .424 .779 r
.60289 .65856 m .6013 .66062 L .60021 .65702 L F
.348 .373 .746 r
.60289 .65856 m .60372 .66231 L .6013 .66062 L F
.597 .256 .363 r
.28635 .59395 m .28872 .5938 L .28684 .59207 L F
.534 .27 .461 r
.28684 .59207 m .28872 .5938 L .28917 .5917 L F
.466 .097 .253 r
.60108 .55401 m .60432 .5516 L .60112 .55252 L F
.706 .316 .307 r
.50068 .70216 m .50284 .70436 L .5043 .70244 L F
.244 0 0 r
.50284 .70436 m .50613 .70354 L .5043 .70244 L F
.589 .929 .73 r
.74663 .53023 m .74791 .52968 L .7497 .52823 L F
.438 .767 .997 r
.30242 .63707 m .30518 .63748 L .30487 .6365 L F
.739 .511 .582 r
.30234 .63984 m .30585 .64105 L .30518 .63748 L F
.433 .624 .933 r
.30487 .6365 m .30518 .63748 L .30675 .63643 L F
.5 .351 .61 r
.30518 .63748 m .30737 .63975 L .30675 .63643 L F
.30518 .63748 m .30585 .64105 L .30737 .63975 L F
.434 .501 .829 r
.55155 .63431 m .55182 .63069 L .55001 .6309 L F
.55155 .63431 m .55322 .63394 L .55182 .63069 L F
.71 .779 .907 r
.72198 .50687 m .72521 .50733 L .72425 .50575 L F
.439 .467 .792 r
.72521 .50733 m .72682 .50518 L .72425 .50575 L F
.72521 .50733 m .72802 .50973 L .72682 .50518 L F
.32 .307 .688 r
.55817 .64006 m .55831 .64364 L .56031 .642 L F
.173 .209 .658 r
.55985 .64584 m .56031 .642 L .55831 .64364 L F
.407 .615 .935 r
.39496 .59272 m .39425 .5944 L .39269 .59243 L F
.39496 .59272 m .39617 .59441 L .39425 .5944 L F
.854 .861 .846 r
.73929 .47308 m .73888 .47535 L .73778 .47366 L F
.817 .368 0 r
.54927 .6582 m .54886 .65864 L .54664 .6567 L F
.54927 .6582 m .55047 .6607 L .54886 .65864 L F
.975 .713 .47 r
.50942 .67937 m .50952 .682 L .51086 .6803 L F
.51086 .6803 m .50952 .682 L .50942 .67937 L F
.754 .388 .361 r
.47624 .70168 m .47961 .70225 L .47856 .70063 L F
0 .105 .66 r
.56776 .63502 m .56644 .6343 L .56528 .63349 L F
.56776 .63502 m .56849 .63663 L .56644 .6343 L F
.365 .008 .219 r
.46708 .64323 m .46841 .64482 L .4691 .64248 L F
.46708 .64323 m .46623 .64535 L .46841 .64482 L F
.71 .648 .786 r
.72991 .5037 m .73331 .50438 L .73272 .5005 L F
.657 .611 .791 r
.73272 .5005 m .73331 .50438 L .73579 .50333 L F
.595 .462 .67 r
.53793 .65942 m .53526 .65724 L .53839 .65743 L F
.167 0 0 r
.54129 .65769 m .53793 .65942 L .53839 .65743 L F
.572 .078 0 r
.47347 .65646 m .47364 .6565 L .47161 .65401 L F
.47347 .65646 m .47458 .65757 L .47364 .6565 L F
.09 0 0 r
.3111 .58361 m .31335 .58331 L .31455 .58284 L F
.225 .745 .76 r
.31335 .58331 m .31679 .58259 L .31455 .58284 L F
.516 .439 .707 r
.27865 .60911 m .28005 .60549 L .2781 .60603 L F
.339 0 .091 r
.43471 .66268 m .43691 .66223 L .43817 .66035 L F
.407 .017 .184 r
.43915 .66208 m .43817 .66035 L .43691 .66223 L F
.43915 .66208 m .44044 .65999 L .43817 .66035 L F
.324 0 0 r
.45393 .70649 m .45254 .70782 L .45029 .708 L F
.426 0 0 r
.45393 .70649 m .45623 .70722 L .45254 .70782 L F
.758 .629 .717 r
.70624 .47533 m .70299 .47525 L .70337 .47259 L F
.392 .151 .425 r
.70524 .47456 m .70299 .47525 L .70624 .47533 L F
.106 0 0 r
.70712 .47465 m .70706 .47465 L .70734 .47389 L F
0 0 0 r
.70759 .47319 m .70734 .47389 L .70624 .47533 L F
.70764 .4731 m .70734 .47389 L .70759 .47319 L F
.582 .871 .994 r
.70734 .47389 m .70524 .47456 L .70624 .47533 L F
.106 0 0 r
.70706 .47465 m .70524 .47456 L .70734 .47389 L F
.883 .522 .038 r
.70628 .47223 m .7071 .47459 L .70734 .47389 L F
.7071 .47459 m .70712 .47465 L .70734 .47389 L F
.9 .537 .073 r
.70539 .47099 m .70712 .47465 L .70628 .47223 L F
.969 .648 .311 r
.70539 .47099 m .70559 .47347 L .70712 .47465 L F
.788 .467 .445 r
.70559 .47347 m .70808 .47474 L .70712 .47465 L F
.672 .471 .605 r
.70957 .47273 m .70734 .47389 L .70818 .47224 L F
.71017 .47294 m .70968 .47311 L .70957 .47273 L F
.70968 .47311 m .70734 .47389 L .70957 .47273 L F
.822 .489 .424 r
.71475 .47649 m .71137 .47674 L .71109 .47504 L F
0 0 .419 r
.71109 .47504 m .71137 .47674 L .71156 .4763 L F
.842 .376 .028 r
.70966 .47302 m .71109 .47504 L .71213 .4753 L F
.70955 .47292 m .70968 .47311 L .70966 .47302 L F
.70968 .47311 m .71109 .47504 L .70966 .47302 L F
.70966 .47302 m .71109 .47504 L .71068 .47397 L F
.70968 .47311 m .71109 .47504 L .70966 .47302 L F
.672 .471 .605 r
.71161 .47346 m .71109 .47504 L .70968 .47311 L F
.71161 .47346 m .71006 .47318 L .71017 .47294 L F
.842 .376 .028 r
.70955 .47292 m .70968 .47311 L .70966 .47302 L F
.672 .471 .605 r
.71161 .47346 m .70968 .47311 L .70955 .47292 L F
.71161 .47346 m .70984 .47364 L .71006 .47318 L F
0 .455 .759 r
.71109 .47504 m .70734 .47389 L .70968 .47311 L F
.672 .471 .605 r
.70984 .47364 m .70734 .47389 L .70968 .47311 L F
.70984 .47364 m .70968 .47311 L .71017 .47294 L F
.822 .489 .424 r
.71475 .47649 m .71109 .47504 L .71213 .4753 L F
0 0 .419 r
.71109 .47504 m .71156 .4763 L .71238 .47442 L F
.842 .376 .028 r
.71068 .47397 m .71109 .47504 L .71213 .4753 L F
0 .455 .759 r
.70968 .47311 m .70734 .47389 L .70955 .47292 L F
.696 .862 .961 r
.71225 .47777 m .70892 .47784 L .71137 .47674 L F
0 .455 .759 r
.71109 .47504 m .70998 .47458 L .70734 .47389 L F
.591 .607 .837 r
.70892 .47784 m .70998 .47458 L .71137 .47674 L F
.70892 .47784 m .71077 .47726 L .70998 .47458 L F
.785 .723 .794 r
.70998 .47458 m .71077 .47726 L .70712 .47465 L F
.70998 .47458 m .70848 .47462 L .70903 .47523 L F
.70848 .47462 m .70712 .47465 L .70903 .47523 L F
.788 .467 .445 r
.70559 .47347 m .70924 .47546 L .70903 .47523 L F
.70924 .47546 m .70951 .47561 L .70903 .47523 L F
.70808 .47474 m .70903 .47523 L .70712 .47465 L F
.106 0 0 r
.70712 .47465 m .70706 .47465 L .70706 .47465 L F
0 0 0 r
.70818 .47224 m .70734 .47389 L .70764 .4731 L F
.781 .867 .912 r
.67903 .49882 m .67623 .50091 L .67509 .49977 L F
.858 .859 .84 r
.72473 .49472 m .72239 .49457 L .72459 .49215 L F
.886 .89 .829 r
.72473 .49472 m .72128 .49659 L .72239 .49457 L F
.87 .867 .832 r
.72693 .49192 m .72473 .49472 L .72459 .49215 L F
.516 .439 .707 r
.27865 .60911 m .28065 .60858 L .28005 .60549 L F
.475 .355 .637 r
.27897 .61157 m .28065 .60858 L .27865 .60911 L F
.533 .093 .15 r
.48309 .70616 m .47938 .70755 L .48073 .70582 L F
0 0 0 r
.72277 .47409 m .72602 .47234 L .7236 .47211 L F
.593 .724 .935 r
.33018 .62716 m .32675 .62629 L .32894 .62568 L F
.561 .765 .974 r
.33078 .62562 m .33018 .62716 L .32894 .62568 L F
.33078 .62562 m .33269 .62684 L .33018 .62716 L F
.617 .819 .978 r
.46864 .66346 m .46524 .66324 L .46713 .66231 L F
.586 .379 .568 r
.60432 .5516 m .60696 .5515 L .60693 .54924 L F
.698 .469 .573 r
.60696 .5515 m .60939 .54929 L .60693 .54924 L F
.585 .551 .782 r
.57542 .65154 m .5721 .64888 L .57515 .64819 L F
.956 .618 .235 r
.69309 .47211 m .69345 .47433 L .69364 .47338 L F
.383 .846 .844 r
.69355 .47665 m .69364 .47338 L .69345 .47433 L F
.698 .469 .573 r
.60696 .5515 m .60939 .55155 L .60939 .54929 L F
.741 .558 .647 r
.60939 .55155 m .61269 .54925 L .60939 .54929 L F
.28 .731 .958 r
.37034 .58655 m .37395 .58711 L .37179 .58745 L F
.315 .534 .906 r
.70244 .46606 m .70547 .46643 L .7062 .46813 L F
.543 0 0 r
.70549 .46665 m .7062 .46813 L .70547 .46643 L F
.70566 .469 m .7062 .46813 L .70549 .46665 L F
.403 .635 .949 r
.7062 .46813 m .70745 .46979 L .70698 .46973 L F
.7062 .46813 m .70698 .46973 L .70467 .46943 L F
.697 .591 .733 r
.53572 .65977 m .53254 .65667 L .53526 .65724 L F
.595 .462 .67 r
.53793 .65942 m .53572 .65977 L .53526 .65724 L F
.916 .76 .674 r
.62078 .56544 m .61923 .56808 L .62204 .56912 L F
.898 .716 .647 r
.61923 .56808 m .62195 .57122 L .62204 .56912 L F
.014 .45 .869 r
.33684 .62746 m .33663 .62818 L .33528 .62703 L F
.33684 .62746 m .33814 .6287 L .33663 .62818 L F
.812 .7 .742 r
.68592 .48717 m .685 .48893 L .68177 .48806 L F
.367 .095 .363 r
.5677 .57484 m .56979 .57405 L .57017 .57221 L F
.433 .152 .385 r
.56979 .57405 m .57246 .57164 L .57017 .57221 L F
.357 0 .185 r
.32758 .60283 m .32644 .60532 L .32393 .60576 L F
.102 0 .065 r
.32823 .60425 m .32758 .60283 L .32964 .60203 L F
.32823 .60425 m .32644 .60532 L .32758 .60283 L F
.408 0 .064 r
.47158 .66028 m .46713 .66231 L .46734 .65983 L F
0 0 0 r
.47185 .66087 m .47158 .66028 L .47264 .66136 L F
.47185 .66087 m .46993 .66206 L .47158 .66028 L F
.497 .365 .631 r
.4199 .67148 m .42218 .67374 L .42189 .67101 L F
.4199 .67148 m .42015 .67437 L .42218 .67374 L F
.868 .986 .837 r
.68083 .49722 m .67903 .49882 L .68076 .49725 L F
.317 .778 .945 r
.34718 .58628 m .34934 .58603 L .35079 .58642 L F
.397 .824 .963 r
.34934 .58603 m .35289 .58597 L .35079 .58642 L F
.882 .869 .821 r
.42014 .70251 m .42253 .70134 L .42212 .6997 L F
.474 .48 .784 r
.42253 .70134 m .42443 .69909 L .42212 .6997 L F
.42253 .70134 m .42572 .70286 L .42443 .69909 L F
.581 .305 .463 r
.51777 .69932 m .52023 .69944 L .52039 .69748 L F
.651 .365 .472 r
.52039 .69748 m .52238 .69872 L .52231 .69675 L F
.52039 .69748 m .52023 .69944 L .52238 .69872 L F
0 0 .152 r
.52669 .60323 m .52687 .60627 L .52688 .60508 L F
0 0 .37 r
.52775 .60833 m .52688 .60508 L .52687 .60627 L F
.849 .6 .561 r
.71225 .46734 m .71319 .46885 L .71366 .46668 L F
.47 .344 .627 r
.57517 .65399 m .57562 .65647 L .57328 .65461 L F
.511 .225 .418 r
.57698 .56815 m .58 .56522 L .57757 .56581 L F
.466 .097 .253 r
.60108 .55401 m .60347 .55369 L .60432 .5516 L F
.7 .428 .509 r
.60347 .55369 m .60696 .5515 L .60432 .5516 L F
.628 .234 .278 r
.67034 .48636 m .66919 .48825 L .66667 .48667 L F
.645 .253 .287 r
.67275 .48808 m .66919 .48825 L .67034 .48636 L F
.492 .262 .493 r
.37845 .60833 m .3811 .60545 L .37885 .60601 L F
.521 .51 .785 r
.49001 .79098 m .49115 .79453 L .49319 .79408 L F
.783 .717 .791 r
.55919 .61496 m .56095 .61488 L .56039 .61287 L F
.978 .804 .599 r
.55919 .61496 m .56155 .6173 L .56095 .61488 L F
.418 .276 .579 r
.56095 .61488 m .56155 .6173 L .56346 .61628 L F
.55 .405 .636 r
.59899 .65138 m .59928 .6539 L .59687 .6543 L F
.791 .66 .718 r
.59928 .6539 m .59735 .65613 L .59687 .6543 L F
.549 .879 .99 r
.35536 .59849 m .35924 .59826 L .35747 .59818 L F
.157 .698 .777 r
.36142 .59783 m .35747 .59818 L .35924 .59826 L F
.473 .503 .809 r
.43935 .68756 m .43864 .69111 L .43813 .68886 L F
.393 .147 .418 r
.39749 .61395 m .39546 .61464 L .39786 .61187 L F
.465 .175 .387 r
.40014 .61158 m .39749 .61395 L .39786 .61187 L F
.267 .431 .839 r
.56623 .66411 m .56711 .66246 L .5656 .66207 L F
.56623 .66411 m .56868 .66533 L .56711 .66246 L F
.449 .486 .805 r
.59167 .65082 m .59052 .65283 L .58954 .65278 L F
.651 .41 .542 r
.59052 .65283 m .5929 .65425 L .59436 .65322 L F
.449 .486 .805 r
.59167 .65082 m .5929 .65425 L .59052 .65283 L F
.779 .689 .765 r
.47264 .66136 m .47431 .66308 L .47642 .66013 L F
.241 .384 .807 r
.54433 .62809 m .54446 .6254 L .54304 .62517 L F
.54433 .62809 m .54557 .62861 L .54446 .6254 L F
.774 .77 .849 r
.71875 .4919 m .71587 .49454 L .71885 .49465 L F
.349 .114 .41 r
.60191 .60901 m .60376 .60805 L .60422 .60611 L F
.895 .899 .484 r
.60257 .60999 m .60191 .60901 L .60147 .6114 L F
.60257 .60999 m .60376 .60805 L .60191 .60901 L F
.831 .677 .692 r
.57936 .66877 m .57676 .66867 L .57812 .66496 L F
.552 .369 .588 r
.58166 .66589 m .58191 .66852 L .57936 .66877 L F
.58166 .66589 m .58191 .66852 L .57936 .66877 L F
.912 .798 .721 r
.27658 .6462 m .27446 .64875 L .27261 .64785 L F
.861 .969 .864 r
.27658 .6462 m .27447 .64614 L .2765 .64552 L F
.27658 .6462 m .27261 .64785 L .27447 .64614 L F
.515 .597 .874 r
.51547 .65499 m .51757 .65804 L .51675 .65569 L F
.418 .606 .925 r
.51757 .65804 m .51838 .65595 L .51675 .65569 L F
.51757 .65804 m .52055 .65795 L .51838 .65595 L F
.458 .593 .899 r
.76359 .48572 m .762 .48726 L .76152 .48553 L F
.76359 .48572 m .76502 .48837 L .762 .48726 L F
.656 .608 .789 r
.54912 .76253 m .55225 .76517 L .55339 .76328 L F
.718 .643 .773 r
.71329 .48081 m .70998 .47893 L .71225 .47777 L F
.71329 .48081 m .70991 .48092 L .70998 .47893 L F
.682 .67 .832 r
.71558 .4799 m .71329 .48081 L .71225 .47777 L F
.641 .579 .77 r
.71677 .48357 m .71329 .48081 L .71558 .4799 L F
.723 .477 .554 r
.52979 .69747 m .53012 .70097 L .53181 .69728 L F
.786 .552 .583 r
.53181 .69728 m .53012 .70097 L .53197 .6998 L F
.399 .259 .572 r
.53181 .69728 m .5342 .69869 L .53441 .69733 L F
.53181 .69728 m .53197 .6998 L .5342 .69869 L F
.741 .558 .647 r
.60939 .55155 m .61281 .55178 L .61269 .54925 L F
.716 .553 .667 r
.61281 .55178 m .6153 .54905 L .61269 .54925 L F
.572 .54 .78 r
.57338 .65942 m .57453 .66279 L .57196 .66352 L F
.191 0 0 r
.26927 .66718 m .27214 .66774 L .27252 .6677 L F
.171 0 0 r
.27214 .66774 m .27586 .66826 L .27252 .6677 L F
.202 0 0 r
.3634 .61983 m .36507 .61947 L .36647 .6176 L F
.435 .039 .187 r
.36507 .61947 m .3687 .61718 L .36647 .6176 L F
.946 .854 .719 r
.72669 .4886 m .72693 .49192 L .72588 .49055 L F
.87 .867 .832 r
.72693 .49192 m .72459 .49215 L .72588 .49055 L F
.704 .912 .564 r
.72121 .50174 m .71836 .50548 L .72088 .50079 L F
.282 0 0 r
.36184 .63678 m .36249 .63798 L .3602 .63815 L F
.36184 .63678 m .36394 .63647 L .36249 .63798 L F
.684 .141 0 r
.74392 .47398 m .74742 .47666 L .74478 .47511 L F
.488 .266 .503 r
.27956 .60048 m .28167 .6 L .28198 .59753 L F
.469 .336 .616 r
.28198 .59753 m .28392 .59691 L .28394 .59458 L F
.475 .254 .499 r
.28198 .59753 m .28371 .59944 L .28392 .59691 L F
.28198 .59753 m .28167 .6 L .28371 .59944 L F
.798 .846 .887 r
.47363 .66969 m .4697 .67128 L .47185 .67066 L F
.411 .443 .784 r
.47363 .66969 m .47552 .67121 L .47422 .66783 L F
.72 .389 .418 r
.47185 .67066 m .47552 .67121 L .47363 .66969 L F
.882 .951 .848 r
.47363 .66969 m .47185 .67066 L .47422 .66783 L F
.748 .657 .761 r
.28023 .61714 m .2832 .61788 L .28205 .61431 L F
.508 .514 .797 r
.2832 .61788 m .28388 .61393 L .28205 .61431 L F
.2832 .61788 m .28497 .61737 L .28388 .61393 L F
.502 .488 .774 r
.2832 .61788 m .28591 .61938 L .28497 .61737 L F
.058 .551 .889 r
.49703 .61903 m .49925 .61961 L .50054 .62042 L F
.052 .406 .859 r
.50122 .61966 m .50054 .62042 L .49925 .61961 L F
.50122 .61966 m .50313 .62181 L .50054 .62042 L F
.801 .58 .602 r
.68549 .49161 m .68177 .48806 L .685 .48893 L F
.047 .611 .782 r
.31886 .58263 m .32257 .58286 L .32043 .58336 L F
.604 .355 .512 r
.40317 .60887 m .40247 .6117 L .40014 .61158 L F
.557 .31 .497 r
.40512 .61062 m .40317 .60887 L .40543 .60849 L F
.40512 .61062 m .40247 .6117 L .40317 .60887 L F
.488 .285 .53 r
.42152 .66618 m .42375 .66568 L .42434 .66284 L F
.529 .419 .673 r
.4219 .66861 m .42375 .66568 L .42152 .66618 L F
.716 .553 .667 r
.61281 .55178 m .61638 .55206 L .6153 .54905 L F
.171 .412 .852 r
.75671 .48208 m .7558 .48327 L .75612 .48223 L F
.27 .554 .929 r
.7575 .48353 m .7558 .48327 L .75671 .48208 L F
.757 .695 .793 r
.54048 .64028 m .53706 .63979 L .5405 .64194 L F
.619 .716 .916 r
.54277 .64223 m .54059 .64224 L .54048 .64028 L F
.569 .028 0 r
.54143 .64143 m .54048 .64028 L .5405 .64194 L F
.54143 .64143 m .54277 .64223 L .54048 .64028 L F
.528 .283 .487 r
.76531 .5151 m .76522 .51716 L .76273 .51757 L F
.549 .34 .549 r
.76762 .51443 m .76522 .51716 L .76531 .5151 L F
.538 .614 .876 r
.71458 .47323 m .71213 .4753 L .71109 .47504 L F
.71458 .47323 m .71454 .47495 L .71213 .4753 L F
.539 .527 .79 r
.71454 .47495 m .71475 .47649 L .71213 .4753 L F
.335 .259 .621 r
.31884 .61077 m .3171 .60903 L .31912 .6084 L F
.31884 .61077 m .31747 .6116 L .3171 .60903 L F
.463 .216 .454 r
.39749 .61395 m .39497 .61663 L .39546 .61464 L F
.671 .707 .875 r
.53706 .63979 m .53496 .64092 L .53347 .63919 L F
.717 .713 .845 r
.71531 .49469 m .71242 .49389 L .71346 .4952 L F
.71519 .49441 m .71242 .49389 L .71531 .49469 L F
.71587 .49454 m .71519 .49441 L .71531 .49469 L F
.71587 .49454 m .71452 .49487 L .71242 .49389 L F
.759 .856 .922 r
.71371 .49117 m .71452 .49487 L .71509 .49419 L F
.71381 .49116 m .71509 .49419 L .71766 .49116 L F
.71371 .49117 m .71509 .49419 L .71381 .49116 L F
.535 .845 .999 r
.68219 .50753 m .67938 .50856 L .68288 .50612 L F
0 0 0 r
.6855 .50349 m .68478 .50494 L .68288 .50612 L F
.207 0 0 r
.68459 .5068 m .68288 .50612 L .68478 .50494 L F
.68459 .5068 m .68219 .50753 L .68288 .50612 L F
.739 .342 .297 r
.30242 .63707 m .30069 .6387 L .29939 .63654 L F
0 0 0 r
.30369 .63682 m .30242 .63707 L .30487 .6365 L F
.30369 .63682 m .30069 .6387 L .30242 .63707 L F
0 0 .085 r
.57201 .63951 m .57155 .64223 L .57073 .64338 L F
.075 .305 .788 r
.57155 .64223 m .57298 .64551 L .57073 .64338 L F
.723 .795 .909 r
.75273 .51077 m .75026 .51255 L .74887 .51102 L F
.619 .716 .916 r
.54277 .64223 m .54396 .64303 L .54059 .64224 L F
.48 .79 .999 r
.54507 .64175 m .54396 .64303 L .54277 .64223 L F
.892 .908 .503 r
.60376 .60805 m .60472 .60449 L .60422 .60611 L F
.894 .478 .09 r
.47458 .65757 m .47544 .65967 L .47642 .66013 L F
.779 .689 .765 r
.47264 .66136 m .47642 .66013 L .47544 .65967 L F
.298 0 0 r
.29125 .59114 m .29354 .59072 L .29501 .58926 L F
.299 0 0 r
.29354 .59072 m .29709 .58877 L .29501 .58926 L F
.427 0 0 r
.68302 .47849 m .68195 .4793 L .6854 .47924 L F
.469 .017 .094 r
.68302 .47849 m .6854 .47924 L .68607 .47867 L F
0 .246 .761 r
.50557 .62363 m .50405 .62336 L .50313 .62181 L F
.50557 .62363 m .50633 .62525 L .50405 .62336 L F
.709 .749 .884 r
.65191 .49841 m .65527 .49894 L .65406 .49728 L F
.621 .536 .738 r
.65549 .49862 m .6559 .49755 L .65406 .49728 L F
.65565 .49876 m .65569 .49855 L .65549 .49862 L F
.65569 .49855 m .6559 .49755 L .65549 .49862 L F
.63 .526 .717 r
.65834 .49267 m .65569 .49855 L .65765 .49781 L F
.941 .963 .721 r
.6568 .4942 m .65569 .49855 L .65834 .49267 L F
.65656 .49444 m .6559 .49755 L .6568 .4942 L F
.6559 .49755 m .65569 .49855 L .6568 .4942 L F
.692 .7 .853 r
.6559 .49755 m .65556 .49885 L .65406 .49728 L F
.621 .536 .738 r
.65565 .49876 m .65765 .49781 L .6559 .49755 L F
.63 .526 .717 r
.65569 .49855 m .65556 .49885 L .65765 .49781 L F
.692 .7 .853 r
.65765 .49781 m .65556 .49885 L .6559 .49755 L F
.941 .963 .721 r
.65538 .49561 m .65556 .49885 L .65569 .49855 L F
.65538 .49561 m .65569 .49855 L .65656 .49444 L F
.621 .536 .738 r
.65527 .49894 m .65565 .49876 L .65406 .49728 L F
.65527 .49894 m .65734 .49919 L .65765 .49781 L F
.721 .614 .737 r
.71917 .48076 m .71677 .48357 L .71558 .4799 L F
.639 .573 .765 r
.57776 .63458 m .57419 .63172 L .57432 .63413 L F
.183 0 0 r
.33577 .60095 m .33412 .60156 L .33214 .60153 L F
.289 .789 .83 r
.33831 .6009 m .33412 .60156 L .33577 .60095 L F
.502 .308 .549 r
.44636 .67154 m .44608 .67431 L .44411 .67448 L F
.734 .527 .613 r
.57298 .64551 m .57707 .64561 L .57464 .64134 L F
.675 .508 .652 r
.57464 .64134 m .57707 .64561 L .57871 .6422 L F
.901 .828 .766 r
.41906 .69828 m .41978 .69946 L .41706 .69989 L F
.41906 .69828 m .41978 .69946 L .41706 .69989 L F
.371 .648 .964 r
.41978 .69946 m .4209 .69839 L .41906 .69828 L F
.41978 .69946 m .42212 .6997 L .4209 .69839 L F
.41978 .69946 m .4209 .69839 L .41906 .69828 L F
.41978 .69946 m .42212 .6997 L .4209 .69839 L F
.604 .32 .459 r
.65973 .48328 m .66225 .4831 L .66389 .48056 L F
.587 .3 .448 r
.66389 .48056 m .66582 .48229 L .66532 .48118 L F
.66389 .48056 m .66225 .4831 L .66582 .48229 L F
.091 .497 .901 r
.75069 .47801 m .74823 .47796 L .74742 .47666 L F
.75069 .47801 m .7517 .47927 L .74823 .47796 L F
.201 0 0 r
.55868 .60284 m .55752 .60471 L .55527 .60538 L F
.742 .307 .218 r
.56086 .60478 m .55868 .60284 L .56013 .60163 L F
.56086 .60478 m .55752 .60471 L .55868 .60284 L F
.269 .365 .777 r
.55868 .60284 m .56086 .60478 L .56013 .60163 L F
.022 0 .215 r
.68752 .50001 m .68741 .50245 L .6855 .50349 L F
0 0 0 r
.68741 .50245 m .68478 .50494 L .6855 .50349 L F
.706 .292 .259 r
.49954 .67081 m .49904 .67174 L .49655 .67076 L F
.49954 .67081 m .49904 .67174 L .49655 .67076 L F
0 0 0 r
.50078 .67067 m .49954 .67081 L .50167 .67045 L F
.50078 .67067 m .49904 .67174 L .49954 .67081 L F
.803 .472 .427 r
.69953 .47264 m .69928 .47431 L .69757 .47208 L F
.789 .657 .718 r
.70337 .47259 m .69928 .47431 L .69953 .47264 L F
.982 .726 .468 r
.50505 .76267 m .50367 .76459 L .50498 .76534 L F
.50505 .76267 m .50367 .76459 L .50498 .76534 L F
.6 .498 .709 r
.53702 .6237 m .53874 .62191 L .53813 .62054 L F
0 .189 .706 r
.52061 .66615 m .52214 .6682 L .52089 .66493 L F
.503 .053 .115 r
.4905 .70413 m .49468 .70303 L .49237 .70579 L F
.4905 .70413 m .49424 .70505 L .49468 .70303 L F
.629 .17 .143 r
.49468 .70303 m .49424 .70505 L .4969 .70468 L F
.594 .218 .299 r
.49468 .70303 m .4969 .70468 L .49707 .70324 L F
.56 .664 .907 r
.32538 .62474 m .32391 .62537 L .32323 .62377 L F
.32538 .62474 m .32675 .62629 L .32391 .62537 L F
.236 .455 .869 r
.38979 .59049 m .39124 .59076 L .39037 .59212 L F
.356 .617 .95 r
.39124 .59076 m .39269 .59243 L .39037 .59212 L F
.767 .692 .779 r
.71454 .47495 m .71615 .47826 L .71475 .47649 L F
.682 .67 .832 r
.71558 .4799 m .71475 .47649 L .71615 .47826 L F
.722 .672 .801 r
.71701 .47652 m .71615 .47826 L .71454 .47495 L F
.16 .698 .818 r
.35536 .59849 m .35155 .59858 L .35326 .59915 L F
.483 .896 .909 r
.34588 .59897 m .34399 .60005 L .34734 .59926 L F
.34588 .59897 m .34379 .59982 L .34399 .60005 L F
.546 .514 .771 r
.41665 .68549 m .41752 .68863 L .41965 .6882 L F
.37 .148 .441 r
.37621 .61073 m .37845 .60833 L .37627 .60895 L F
0 .349 .825 r
.7517 .47927 m .75287 .47986 L .75218 .48049 L F
.074 .477 .891 r
.75287 .47986 m .75612 .48223 L .75218 .48049 L F
.377 .017 .221 r
.5648 .57683 m .5669 .5763 L .5677 .57484 L F
.278 0 .176 r
.5669 .5763 m .56979 .57405 L .5677 .57484 L F
.321 .023 .293 r
.46171 .64639 m .46324 .64744 L .46389 .646 L F
.46171 .64639 m .46117 .64814 L .46324 .64744 L F
.559 .377 .591 r
.44905 .67053 m .44608 .67431 L .44636 .67154 L F
.798 .71 .768 r
.70991 .48092 m .708 .48102 L .70998 .47893 L F
.572 .44 .663 r
.6011 .63423 m .60151 .63656 L .59904 .63701 L F
.577 .465 .689 r
.59904 .63701 m .60136 .63977 L .59962 .6405 L F
.59904 .63701 m .60151 .63656 L .60136 .63977 L F
.78 .655 .725 r
.54921 .66357 m .54892 .66626 L .54521 .66544 L F
.593 .406 .598 r
.54741 .6669 m .54521 .66544 L .54892 .66626 L F
.447 .112 .304 r
.55094 .66375 m .54741 .6669 L .54892 .66626 L F
.415 0 0 r
.45685 .69749 m .45941 .69828 L .46096 .69782 L F
0 .334 .737 r
.46177 .69791 m .46096 .69782 L .45941 .69828 L F
.391 0 0 r
.46096 .69782 m .46304 .69874 L .46457 .69897 L F
0 .334 .737 r
.46177 .69791 m .46304 .69874 L .46096 .69782 L F
0 0 .508 r
.48528 .70247 m .48633 .70512 L .48884 .70287 L F
.451 .393 .701 r
.48884 .70287 m .49144 .70611 L .4905 .70413 L F
.447 .328 .624 r
.41817 .68007 m .41993 .6764 L .41797 .67745 L F
.027 0 .13 r
.68961 .49746 m .68946 .49924 L .68752 .50001 L F
0 0 .157 r
.68853 .50043 m .68752 .50001 L .68946 .49924 L F
.68853 .50043 m .68741 .50245 L .68752 .50001 L F
.521 .811 .999 r
.54976 .66194 m .55129 .66303 L .54769 .66255 L F
.744 .729 .838 r
.55129 .66303 m .54921 .66357 L .54769 .66255 L F
.566 .208 .32 r
.55129 .66303 m .55094 .66375 L .54921 .66357 L F
.55129 .66303 m .55094 .66375 L .54921 .66357 L F
.377 0 0 r
.55356 .66414 m .55094 .66375 L .55129 .66303 L F
.461 0 0 r
.5538 .66333 m .55356 .66414 L .55129 .66303 L F
.001 0 0 r
.53421 .59778 m .53095 .60034 L .53304 .5995 L F
.141 0 0 r
.53421 .59778 m .53519 .59865 L .53676 .5966 L F
.53421 .59778 m .53304 .5995 L .53519 .59865 L F
0 0 0 r
.58741 .67487 m .58644 .6744 L .58868 .67382 L F
.58741 .67487 m .58546 .67613 L .58644 .6744 L F
.467 .125 .301 r
.4453 .65701 m .44811 .65605 L .44858 .65454 L F
.456 .098 .267 r
.44811 .65605 m .45094 .65423 L .44858 .65454 L F
.829 .999 .827 r
.73053 .50218 m .72991 .5037 L .73272 .5005 L F
0 0 .383 r
.7302 .50577 m .72991 .5037 L .73053 .50218 L F
.756 .802 .89 r
.30929 .64556 m .31325 .64584 L .31317 .64434 L F
.544 .549 .81 r
.31325 .64584 m .3141 .64229 L .31317 .64434 L F
.31325 .64584 m .31536 .64526 L .3141 .64229 L F
.628 .912 .625 r
.68089 .495 m .6821 .49345 L .68311 .49548 L F
.68089 .495 m .67964 .49598 L .6821 .49345 L F
.564 .381 .592 r
.58828 .62863 m .59083 .62832 L .59071 .62597 L F
.35 .222 .562 r
.58935 .63106 m .59083 .62832 L .58828 .62863 L F
.43 0 0 r
.46569 .70656 m .46418 .70792 L .4619 .70782 L F
.469 0 .006 r
.46776 .70744 m .46418 .70792 L .46569 .70656 L F
.952 .802 .354 r
.60444 .59994 m .60431 .59658 L .60477 .59744 L F
.972 .919 .596 r
.60477 .59744 m .60536 .59362 L .60627 .5943 L F
.60477 .59744 m .60431 .59658 L .60536 .59362 L F
.592 .27 .393 r
.52929 .65883 m .53254 .65667 L .53279 .6605 L F
.52929 .65883 m .53089 .6602 L .53112 .6597 L F
.52929 .65883 m .53112 .6597 L .53254 .65667 L F
.435 .8 .995 r
.53254 .65667 m .53185 .65622 L .52874 .65657 L F
.99 .808 .564 r
.53254 .65667 m .53112 .6597 L .53185 .65622 L F
.53112 .6597 m .53089 .6602 L .53102 .65966 L F
.978 .701 .31 r
.53271 .66046 m .53112 .6597 L .52929 .65883 L F
.99 .808 .564 r
.53112 .6597 m .53102 .65966 L .53185 .65622 L F
.978 .701 .31 r
.53279 .6605 m .53161 .65994 L .53112 .6597 L F
.53279 .6605 m .53112 .6597 L .53271 .66046 L F
.929 .718 .596 r
.53185 .65622 m .53102 .65966 L .52962 .65823 L F
.53102 .65966 m .53089 .6602 L .53032 .65932 L F
.978 .701 .31 r
.53118 .65973 m .53042 .65937 L .52929 .65883 L F
.677 .495 .632 r
.53042 .65937 m .52962 .65823 L .52929 .65883 L F
.929 .718 .596 r
.53102 .65966 m .53042 .65937 L .52962 .65823 L F
.978 .701 .31 r
.53161 .65994 m .53105 .65967 L .53042 .65937 L F
.677 .495 .632 r
.53105 .65967 m .52962 .65823 L .53042 .65937 L F
.929 .718 .596 r
.53042 .65937 m .53032 .65932 L .52962 .65823 L F
.978 .701 .31 r
.53161 .65994 m .53042 .65937 L .53118 .65973 L F
.53279 .6605 m .53259 .66191 L .53105 .65967 L F
.697 .591 .733 r
.53572 .65977 m .53279 .6605 L .53254 .65667 L F
.655 .362 .463 r
.53572 .65977 m .53259 .66191 L .53279 .6605 L F
.609 .258 .35 r
.48633 .70512 m .48519 .70767 L .48309 .70616 L F
0 0 .508 r
.48528 .70247 m .48676 .705 L .48633 .70512 L F
.568 .433 .657 r
.48676 .705 m .48519 .70767 L .48633 .70512 L F
.197 .179 .61 r
.31701 .61606 m .31547 .61434 L .31691 .61382 L F
.31701 .61606 m .31601 .61861 L .31547 .61434 L F
.499 .529 .819 r
.70993 .46937 m .70818 .47224 L .70745 .46979 L F
.70993 .46937 m .71161 .47346 L .70818 .47224 L F
.734 .68 .797 r
.76039 .50857 m .76393 .50924 L .76427 .5086 L F
.522 .313 .538 r
.76155 .51204 m .76341 .50985 L .76109 .51066 L F
.733 .632 .746 r
.75794 .51167 m .76155 .51204 L .76039 .50857 L F
.728 .651 .772 r
.76152 .51057 m .76155 .51204 L .75794 .51167 L F
.309 0 0 r
.76152 .51057 m .76 .51104 L .75729 .51315 L F
.76 .51104 m .75794 .51167 L .7579 .51177 L F
.76 .51104 m .7579 .51177 L .75729 .51315 L F
.522 .313 .538 r
.76109 .51066 m .76393 .50924 L .76039 .50857 L F
.76341 .50985 m .76393 .50924 L .76109 .51066 L F
.597 .627 .852 r
.76393 .50924 m .76768 .507 L .76427 .5086 L F
.76393 .50924 m .76639 .50869 L .76768 .507 L F
0 0 .505 r
.52442 .65776 m .52334 .65667 L .52246 .65546 L F
.137 .239 .707 r
.52334 .65667 m .5256 .65924 L .52479 .65872 L F
.544 .405 .642 r
.27956 .60048 m .28191 .60246 L .28167 .6 L F
.27956 .60048 m .27975 .60295 L .28191 .60246 L F
.369 0 .052 r
.35328 .62538 m .3527 .62581 L .35547 .62515 L F
.608 .358 .513 r
.5046 .65146 m .50671 .65359 L .50539 .65315 L F
.159 .601 .934 r
.38789 .5893 m .387 .5899 L .38592 .58935 L F
.38789 .5893 m .38979 .59049 L .387 .5899 L F
.569 .788 .982 r
.79828 .52171 m .79669 .52346 L .7958 .52216 L F
.79828 .52171 m .79915 .52291 L .79669 .52346 L F
.79669 .52346 m .79828 .52171 L .7958 .52216 L F
.79669 .52346 m .79915 .52291 L .79828 .52171 L F
.826 .84 .858 r
.54732 .6438 m .54755 .6459 L .55043 .64344 L F
.028 .22 .725 r
.54898 .64571 m .54755 .6459 L .54732 .6438 L F
.54898 .64571 m .54976 .64807 L .54755 .6459 L F
.515 .07 .131 r
.47505 .70542 m .4738 .7069 L .47144 .70593 L F
.655 .236 .238 r
.47761 .70614 m .4738 .7069 L .47505 .70542 L F
.518 .313 .541 r
.42434 .66284 m .42613 .66508 L .42637 .66302 L F
.42434 .66284 m .42375 .66568 L .42613 .66508 L F
.53 0 0 r
.51352 .70683 m .51201 .70718 L .50968 .70601 L F
.314 0 0 r
.51575 .70613 m .51201 .70718 L .51352 .70683 L F
0 .294 .791 r
.71711 .50293 m .71836 .50548 L .71639 .50338 L F
0 .218 .739 r
.71639 .50338 m .7184 .50591 L .71711 .50293 L F
.134 .651 .89 r
.35467 .58599 m .35894 .58675 L .35671 .58718 L F
.826 .84 .858 r
.54732 .6438 m .55043 .64344 L .54704 .64241 L F
.259 0 0 r
.44568 .70807 m .44796 .70793 L .44457 .70859 L F
.918 .565 .352 r
.49237 .70579 m .49144 .70611 L .4905 .70413 L F
.958 .668 .445 r
.49237 .70579 m .49106 .70739 L .49144 .70611 L F
0 0 0 r
.49322 .70581 m .49237 .70579 L .49483 .70597 L F
.49322 .70581 m .49106 .70739 L .49237 .70579 L F
.564 .67 .91 r
.37626 .59788 m .38055 .59996 L .37847 .59841 L F
.443 .683 .966 r
.38055 .59996 m .38119 .59875 L .37847 .59841 L F
.38055 .59996 m .38225 .59964 L .38119 .59875 L F
.216 .313 .749 r
.38055 .59996 m .38252 .6021 L .38225 .59964 L F
.555 .382 .602 r
.49645 .64311 m .49882 .6428 L .49859 .64005 L F
.503 .291 .525 r
.49645 .64311 m .49875 .64471 L .49882 .6428 L F
.49645 .64311 m .49632 .64541 L .49875 .64471 L F
.627 .688 .887 r
.32894 .62568 m .32675 .62629 L .32538 .62474 L F
.821 .96 .902 r
.74215 .51587 m .73877 .51748 L .74121 .51461 L F
.763 .814 .893 r
.74277 .51329 m .74215 .51587 L .74121 .51461 L F
.74277 .51329 m .74408 .51456 L .74215 .51587 L F
.505 .134 .269 r
.44168 .6821 m .44219 .68067 L .44515 .67987 L F
.359 .216 .547 r
.60136 .63977 m .59996 .6428 L .59962 .6405 L F
.535 .351 .578 r
.76385 .51117 m .76155 .51204 L .76152 .51057 L F
.558 .921 .749 r
.54226 .77117 m .54331 .77007 L .54538 .7689 L F
.584 .504 .731 r
.54538 .7689 m .54503 .77147 L .54226 .77117 L F
.383 .693 .981 r
.54226 .77117 m .54503 .77147 L .54331 .77007 L F
.635 .285 .36 r
.67149 .48229 m .67472 .48059 L .67129 .48099 L F
.67149 .48229 m .67399 .48287 L .67472 .48059 L F
.505 .159 .313 r
.67472 .48059 m .67656 .48231 L .67728 .48055 L F
.67472 .48059 m .67399 .48287 L .67656 .48231 L F
.035 0 .213 r
.57707 .64561 m .57613 .6485 L .57515 .64819 L F
.512 .425 .694 r
.57767 .65068 m .57515 .64819 L .57613 .6485 L F
.57767 .65068 m .57542 .65154 L .57515 .64819 L F
.265 .704 .962 r
.32257 .58286 m .32457 .58288 L .3262 .58368 L F
.337 .759 .976 r
.32457 .58288 m .3285 .58345 L .3262 .58368 L F
.327 0 .097 r
.45166 .69955 m .45384 .69911 L .45492 .69737 L F
.403 0 .122 r
.45384 .69911 m .45685 .69749 L .45492 .69737 L F
.244 0 0 r
.50284 .70436 m .505 .70433 L .50613 .70354 L F
.484 0 0 r
.50613 .70354 m .505 .70433 L .50868 .70464 L F
.513 .093 .18 r
.50613 .70354 m .50868 .70464 L .50938 .70308 L F
.78 .655 .725 r
.54921 .66357 m .54521 .66544 L .54769 .66255 L F
.417 .604 .925 r
.51416 .64917 m .51602 .65157 L .5176 .65032 L F
0 0 .307 r
.51602 .65157 m .51694 .65254 L .5176 .65032 L F
.51602 .65157 m .51612 .65399 L .51694 .65254 L F
0 0 .219 r
.563 .62699 m .56257 .62572 L .56011 .62529 L F
.563 .62699 m .5631 .62811 L .56257 .62572 L F
.684 .818 .947 r
.6717 .5108 m .67498 .51106 L .6745 .50947 L F
.739 .841 .927 r
.6745 .50947 m .67498 .51106 L .67781 .50942 L F
.706 .741 .879 r
.59735 .65613 m .60021 .65702 L .59772 .65781 L F
.709 .578 .706 r
.54912 .76253 m .55339 .76328 L .55133 .75961 L F
.807 .518 .501 r
.54757 .75716 m .54814 .75958 L .55133 .75961 L F
.821 .752 .787 r
.54814 .75958 m .54912 .76253 L .55133 .75961 L F
.284 0 .277 r
.58998 .55695 m .59207 .55675 L .59302 .55422 L F
.594 .419 .614 r
.58974 .55941 m .59207 .55675 L .58998 .55695 L F
.41 .127 .369 r
.58763 .56017 m .58974 .55941 L .58998 .55695 L F
.533 .571 .839 r
.70301 .47913 m .70148 .4814 L .70112 .47974 L F
.611 .678 .889 r
.70301 .47913 m .7041 .48078 L .70148 .4814 L F
.559 .306 .488 r
.44044 .65999 m .44293 .65982 L .44331 .65741 L F
.457 .216 .459 r
.44331 .65741 m .44505 .65918 L .4453 .65701 L F
.44331 .65741 m .44293 .65982 L .44505 .65918 L F
.397 .596 .926 r
.65406 .49728 m .65556 .49885 L .65538 .49561 L F
.415 .273 .578 r
.60967 .62022 m .60956 .62272 L .60762 .62319 L F
.34 .196 .536 r
.60956 .62272 m .6079 .62558 L .60762 .62319 L F
.683 .448 .559 r
.5261 .69963 m .53012 .70097 L .52979 .69747 L F
0 0 0 r
.72277 .47409 m .72497 .47327 L .72602 .47234 L F
.744 .251 .062 r
.72497 .47327 m .72832 .47453 L .72602 .47234 L F
.73 .307 .243 r
.72602 .47234 m .72832 .47453 L .72911 .47396 L F
.532 .204 .357 r
.37436 .63055 m .37094 .63333 L .37221 .63135 L F
.556 .394 .616 r
.49859 .64005 m .501 .63973 L .50091 .63678 L F
.484 .295 .547 r
.49882 .6428 m .501 .63973 L .49859 .64005 L F
.41 .582 .911 r
.55454 .63713 m .55568 .63548 L .55322 .63394 L F
.55454 .63713 m .55638 .637 L .55568 .63548 L F
.56 .376 .589 r
.4921 .78712 m .49233 .79008 L .49466 .78778 L F
.34 .024 .275 r
.58492 .56254 m .58763 .56017 L .58534 .5608 L F
.331 .123 .44 r
.57767 .65068 m .57517 .65399 L .57542 .65154 L F
.405 .211 .501 r
.59279 .62297 m .59071 .62597 L .59263 .62511 L F
.434 .283 .576 r
.59071 .62597 m .5928 .62772 L .59263 .62511 L F
.59071 .62597 m .59083 .62832 L .5928 .62772 L F
.664 .619 .794 r
.75803 .50927 m .75938 .5051 L .75703 .50568 L F
.75803 .50927 m .76039 .50857 L .75938 .5051 L F
.733 .632 .746 r
.75794 .51167 m .76039 .50857 L .75803 .50927 L F
.475 .355 .637 r
.27897 .61157 m .28088 .61105 L .28065 .60858 L F
.516 .522 .801 r
.27897 .61157 m .28205 .61431 L .28088 .61105 L F
0 0 0 r
.65449 .48779 m .65429 .48848 L .65504 .48637 L F
.237 0 .304 r
.65504 .48637 m .65752 .48524 L .65735 .48352 L F
.372 .012 .219 r
.65504 .48637 m .65653 .48776 L .65752 .48524 L F
.65504 .48637 m .65429 .48848 L .65653 .48776 L F
.556 .161 .248 r
.66582 .48229 m .6679 .48239 L .66532 .48118 L F
.515 .663 .928 r
.53225 .63682 m .53118 .63906 L .52988 .63747 L F
.756 .707 .806 r
.48925 .65389 m .49053 .65625 L .49237 .65394 L F
.655 .362 .463 r
.53572 .65977 m .53492 .66237 L .53259 .66191 L F
.538 .247 .42 r
.53769 .66179 m .53572 .65977 L .53793 .65942 L F
.53769 .66179 m .53492 .66237 L .53572 .65977 L F
.62 .602 .811 r
.44221 .69371 m .43864 .69111 L .44055 .69088 L F
.431 .663 .958 r
.44384 .69243 m .44221 .69371 L .44055 .69088 L F
.44384 .69243 m .44476 .69367 L .44221 .69371 L F
.029 .426 .865 r
.44416 .69606 m .44221 .69371 L .44476 .69367 L F
.708 .27 .208 r
.49835 .70632 m .49681 .70762 L .49483 .70597 L F
.527 .046 .057 r
.50041 .70734 m .49681 .70762 L .49835 .70632 L F
.676 .681 .847 r
.70751 .48286 m .7041 .48078 L .70635 .47978 L F
.768 .698 .785 r
.708 .48102 m .70751 .48286 L .70635 .47978 L F
.715 .602 .729 r
.28514 .64215 m .2864 .64385 L .28862 .64209 L F
.475 .16 .352 r
.76273 .51757 m .76209 .51992 L .75986 .52039 L F
.529 .21 .371 r
.76582 .51864 m .76273 .51757 L .76522 .51716 L F
.76582 .51864 m .76209 .51992 L .76273 .51757 L F
.35 .222 .562 r
.58935 .63106 m .59108 .63072 L .59083 .62832 L F
.44 .288 .578 r
.58844 .6343 m .59108 .63072 L .58935 .63106 L F
0 0 .541 r
.73194 .52316 m .73257 .5225 L .7311 .51989 L F
0 .041 .606 r
.73194 .52316 m .73359 .52565 L .73257 .5225 L F
0 0 .56 r
.73194 .52316 m .73418 .52689 L .73359 .52565 L F
.557 .362 .572 r
.58011 .64004 m .58196 .64019 L .58166 .63723 L F
.535 .315 .528 r
.58479 .64036 m .58166 .63723 L .58196 .64019 L F
.971 .75 .546 r
.51358 .62828 m .51329 .63111 L .51467 .63163 L F
.519 .312 .538 r
.2952 .63636 m .29498 .639 L .29247 .6388 L F
.82 .346 .077 r
.29498 .639 m .29198 .63624 L .29247 .6388 L F
.29498 .639 m .29405 .63925 L .29198 .63624 L F
.099 .183 .664 r
.29198 .63624 m .29405 .63925 L .29377 .63841 L F
.199 .332 .775 r
.29035 .63425 m .29198 .63624 L .29353 .63424 L F
.065 0 0 r
.29396 .63478 m .29434 .63478 L .2952 .63636 L F
.29353 .63424 m .29391 .6345 L .29396 .63478 L F
.29391 .6345 m .29434 .63478 L .29396 .63478 L F
.767 .329 .213 r
.2951 .63291 m .29134 .6314 L .29353 .63424 L F
.065 0 0 r
.29353 .63424 m .29345 .63435 L .29364 .63431 L F
.29345 .63435 m .29198 .63624 L .29364 .63431 L F
.29364 .63431 m .29198 .63624 L .29434 .63478 L F
.657 .56 .734 r
.28955 .63425 m .29187 .63433 L .29134 .6314 L F
.767 .329 .213 r
.29458 .63271 m .29255 .6331 L .29134 .6314 L F
.2951 .63291 m .29351 .63443 L .29255 .6331 L F
.2951 .63291 m .29255 .6331 L .29458 .63271 L F
0 0 .575 r
.29134 .6314 m .29351 .63443 L .29247 .63195 L F
.29134 .6314 m .29247 .63195 L .29187 .63433 L F
.759 .983 .909 r
.29216 .63317 m .29042 .63396 L .29187 .63433 L F
.736 .525 .607 r
.28685 .63238 m .29083 .63372 L .29021 .63048 L F
.329 .253 .618 r
.29021 .63048 m .29083 .63372 L .29247 .63195 L F
.642 .596 .787 r
.28685 .63238 m .29042 .63396 L .29083 .63372 L F
.717 .987 .83 r
.29083 .63372 m .29042 .63396 L .29247 .63195 L F
.759 .983 .909 r
.29247 .63195 m .291 .63339 L .29216 .63317 L F
.291 .63339 m .29042 .63396 L .29216 .63317 L F
.223 .258 .687 r
.2951 .63291 m .29612 .6304 L .29383 .63395 L F
.29385 .63411 m .29383 .63395 L .29351 .63443 L F
.2951 .63291 m .29383 .63395 L .29385 .63411 L F
.728 .829 .928 r
.29239 .63443 m .29198 .63624 L .29434 .63478 L F
.099 .183 .664 r
.29198 .63624 m .29377 .63841 L .29239 .63443 L F
.199 .332 .775 r
.28955 .63425 m .29198 .63624 L .29035 .63425 L F
.529 .419 .673 r
.4219 .66861 m .42403 .66812 L .42375 .66568 L F
.514 .343 .587 r
.42189 .67101 m .42403 .66812 L .4219 .66861 L F
.723 .717 .843 r
.76039 .50857 m .76427 .5086 L .76195 .5045 L F
.218 .435 .858 r
.73354 .51338 m .73252 .51467 L .73061 .51154 L F
.351 0 .063 r
.2993 .58839 m .30159 .58804 L .303 .58623 L F
.284 0 .001 r
.30159 .58804 m .30526 .58582 L .303 .58623 L F
.161 0 0 r
.59932 .666 m .59823 .66777 L .59579 .66812 L F
.184 0 .054 r
.59823 .66777 m .59521 .66997 L .59579 .66812 L F
.577 .249 .377 r
.65752 .48524 m .65973 .48328 L .65735 .48352 L F
.935 .583 .163 r
.54616 .62951 m .54612 .63074 L .54557 .62861 L F
.363 0 .206 r
.54838 .62963 m .54616 .62951 L .55001 .6309 L F
.54838 .62963 m .54612 .63074 L .54616 .62951 L F
.652 .956 .941 r
.48575 .64866 m .4848 .64837 L .48538 .64791 L F
.48538 .64791 m .4848 .64837 L .48575 .64866 L F
.769 .608 .679 r
.61286 .55422 m .61638 .55206 L .61281 .55178 L F
.61286 .55422 m .61632 .55455 L .61638 .55206 L F
.454 .01 .102 r
.51033 .65202 m .50959 .65288 L .50671 .65359 L F
.50959 .65288 m .50735 .65357 L .50671 .65359 L F
.822 .654 .105 r
.50671 .65359 m .50676 .65463 L .50539 .65315 L F
.784 .718 .79 r
.50203 .65257 m .5071 .65365 L .50438 .64945 L F
.63 .34 .459 r
.50671 .6561 m .50334 .65835 L .50676 .65463 L F
.822 .654 .105 r
.50676 .65457 m .50671 .65553 L .50676 .65463 L F
.50671 .65474 m .50671 .65553 L .50676 .65457 L F
.50671 .65553 m .50671 .6561 L .50672 .6559 L F
.50671 .65553 m .50672 .6559 L .50676 .65463 L F
.669 .509 .659 r
.50903 .65353 m .50671 .6561 L .50671 .65474 L F
.822 .654 .105 r
.50671 .65359 m .50671 .65474 L .50676 .65457 L F
.669 .509 .659 r
.50723 .65358 m .50671 .65474 L .50671 .65359 L F
.50903 .65353 m .50671 .65474 L .50723 .65358 L F
0 0 0 r
.50719 .65367 m .5067 .65479 L .50701 .65449 L F
.5067 .65479 m .50602 .65632 L .50652 .65539 L F
.5067 .65479 m .50652 .65539 L .50701 .65449 L F
.563 .324 .511 r
.50334 .65835 m .50109 .65656 L .50676 .65463 L F
.832 .648 .654 r
.50204 .65526 m .50602 .65632 L .5067 .65479 L F
.50668 .65383 m .5067 .65479 L .50719 .65367 L F
.50204 .65526 m .5067 .65479 L .50668 .65383 L F
.784 .718 .79 r
.5071 .65365 m .50719 .65367 L .50717 .65363 L F
.5071 .65365 m .50717 .65363 L .50438 .64945 L F
.454 .01 .102 r
.50959 .65288 m .50903 .65353 L .50735 .65357 L F
0 .544 .736 r
.33814 .6287 m .34025 .62888 L .34206 .62911 L F
.393 .84 .929 r
.34206 .62911 m .34287 .62837 L .34416 .6285 L F
.34206 .62911 m .34025 .62888 L .34287 .62837 L F
.606 .246 .334 r
.50868 .70464 m .51211 .70256 L .50938 .70308 L F
.448 .84 .981 r
.3285 .58345 m .33057 .58296 L .33207 .58343 L F
.09 .648 .771 r
.33057 .58296 m .33424 .58288 L .33207 .58343 L F
0 .268 .775 r
.5361 .61731 m .53624 .61634 L .53382 .61445 L F
0 .183 .717 r
.5361 .61731 m .53792 .6192 L .53624 .61634 L F
.505 .134 .269 r
.44168 .6821 m .44515 .67987 L .44398 .68173 L F
.587 .44 .649 r
.44739 .67708 m .44754 .67957 L .44515 .67987 L F
.636 .307 .398 r
.44754 .67957 m .44398 .68173 L .44515 .67987 L F
.716 .828 .934 r
.54503 .77147 m .54798 .77148 L .54679 .77019 L F
.717 .828 .934 r
.54798 .77148 m .55001 .77035 L .54679 .77019 L F
.504 .472 .755 r
.28643 .62049 m .28752 .62332 L .28928 .62248 L F
.163 0 .122 r
.28752 .62332 m .28662 .62492 L .28928 .62248 L F
.289 0 .008 r
.35547 .62515 m .35771 .62463 L .35851 .62358 L F
.496 .143 .298 r
.35771 .62463 m .36087 .62293 L .35851 .62358 L F
.899 .504 .077 r
.55377 .6542 m .55464 .65637 L .55423 .65456 L F
.355 .774 .977 r
.55617 .65655 m .55804 .65677 L .55434 .65503 L F
.55464 .65637 m .55666 .65614 L .55804 .65677 L F
.102 .351 .819 r
.55666 .65614 m .55851 .65914 L .55804 .65677 L F
.55666 .65614 m .55917 .65791 L .55875 .65869 L F
.5577 .65782 m .55875 .65869 L .55851 .65914 L F
.55666 .65614 m .55875 .65869 L .5577 .65782 L F
.355 .774 .977 r
.55434 .65503 m .55804 .65677 L .55423 .65456 L F
.55464 .65637 m .55617 .65655 L .55434 .65503 L F
.862 .801 .789 r
.41783 .6942 m .41922 .69478 L .41784 .69346 L F
.408 .198 .48 r
.41784 .69346 m .41998 .69342 L .42006 .69136 L F
.595 .459 .665 r
.41922 .69478 m .41998 .69342 L .41784 .69346 L F
.713 .64 .775 r
.28514 .64215 m .28862 .64209 L .28727 .63966 L F
.72 .643 .771 r
.28727 .63966 m .28862 .64209 L .29073 .63994 L F
.636 .839 .978 r
.76931 .51064 m .7674 .51195 L .76876 .51057 L F
.76931 .51064 m .7674 .51195 L .76876 .51057 L F
.614 .531 .737 r
.76931 .51064 m .76762 .51443 L .7674 .51195 L F
.718 .654 .786 r
.51914 .79062 m .52045 .79387 L .51669 .79329 L F
.425 0 0 r
.51669 .79329 m .52045 .79387 L .51968 .79421 L F
.711 .305 .276 r
.51914 .79062 m .5215 .79291 L .52045 .79387 L F
.502 .884 .694 r
.51968 .79421 m .52045 .79387 L .5215 .79291 L F
.443 .151 .372 r
.41054 .60311 m .41001 .60513 L .4078 .60562 L F
.516 .291 .511 r
.41249 .60256 m .41001 .60513 L .41054 .60311 L F
.423 .58 .904 r
.69378 .47917 m .69208 .48105 L .69124 .47955 L F
.69378 .47917 m .69472 .48165 L .69208 .48105 L F
.616 .578 .789 r
.69593 .48367 m .69208 .48105 L .69472 .48165 L F
0 .095 .643 r
.73418 .52689 m .73533 .52821 L .73359 .52565 L F
.336 .698 .982 r
.37769 .58826 m .37395 .58711 L .3762 .58704 L F
.337 .686 .98 r
.37973 .58832 m .37769 .58826 L .3762 .58704 L F
0 .52 .852 r
.33766 .58365 m .33996 .58424 L .34138 .58499 L F
0 .481 .704 r
.33996 .58424 m .34363 .58485 L .34138 .58499 L F
0 0 0 r
.59466 .65278 m .5953 .65188 L .59608 .65127 L F
.816 .543 .527 r
.59754 .65015 m .59608 .65127 L .596 .65081 L F
.59684 .64955 m .596 .65081 L .59562 .64852 L F
.59754 .65015 m .596 .65081 L .59684 .64955 L F
0 0 .413 r
.59562 .64852 m .59608 .65127 L .59674 .64984 L F
0 0 0 r
.5953 .65188 m .59674 .64984 L .59608 .65127 L F
.5953 .65188 m .59475 .65275 L .59674 .64984 L F
.59466 .65278 m .59471 .65276 L .5953 .65188 L F
.59471 .65276 m .59475 .65275 L .5953 .65188 L F
.816 .543 .527 r
.59899 .65138 m .59608 .65127 L .59754 .65015 L F
.569 .378 .584 r
.60162 .65102 m .59928 .6539 L .59899 .65138 L F
.607 .565 .781 r
.65738 .51362 m .65893 .51791 L .66137 .51724 L F
.388 .796 .982 r
.35894 .58675 m .36105 .58629 L .36233 .58705 L F
.312 .763 .957 r
.36105 .58629 m .36457 .58671 L .36233 .58705 L F
0 .242 .757 r
.55817 .64006 m .55846 .63886 L .55638 .637 L F
0 .029 .596 r
.56031 .642 m .55846 .63886 L .55817 .64006 L F
0 0 .209 r
.61579 .6059 m .61775 .60204 L .61746 .60564 L F
.302 .229 .606 r
.61775 .60669 m .61579 .6059 L .61746 .60564 L F
.61775 .60669 m .61638 .60869 L .61579 .6059 L F
0 0 0 r
.57783 .5825 m .57692 .58452 L .57418 .58608 L F
.404 .15 .411 r
.58043 .58005 m .57996 .58151 L .57783 .5825 L F
.179 0 .044 r
.57996 .58151 m .57692 .58452 L .57783 .5825 L F
0 0 0 r
.36477 .59716 m .36357 .59745 L .36142 .59783 L F
.919 .65 .514 r
.59182 .64579 m .59191 .64819 L .59023 .64735 L F
0 0 .399 r
.59182 .64579 m .59182 .6457 L .59067 .64249 L F
.59182 .6457 m .59168 .64468 L .59067 .64249 L F
0 0 .456 r
.59067 .64249 m .59178 .6449 L .59168 .64355 L F
.891 .975 .674 r
.59023 .64735 m .5898 .64674 L .59155 .64377 L F
.59156 .64385 m .59155 .64377 L .59168 .64355 L F
.59023 .64735 m .59155 .64377 L .59156 .64385 L F
0 0 .399 r
.59182 .6457 m .59178 .6449 L .59168 .64468 L F
.818 .966 .648 r
.59023 .64735 m .59178 .6449 L .59182 .64579 L F
.724 .503 .591 r
.49593 .77919 m .49369 .78044 L .49396 .78022 L F
.616 .215 .26 r
.47144 .70593 m .47017 .70794 L .46776 .70744 L F
.514 .104 .201 r
.4738 .7069 m .47017 .70794 L .47144 .70593 L F
.408 .764 .995 r
.73765 .51656 m .73594 .51766 L .73492 .51668 L F
.73765 .51656 m .73877 .51748 L .73594 .51766 L F
.564 .254 .402 r
.42637 .66302 m .42613 .66508 L .42866 .66468 L F
.606 .107 0 r
.42785 .70508 m .42745 .70491 L .42572 .70286 L F
.731 .312 0 r
.42785 .70508 m .42918 .70774 L .42745 .70491 L F
.892 .592 .473 r
.60329 .57994 m .6005 .57687 L .60402 .57751 L F
.704 .611 .75 r
.55739 .61385 m .55919 .61496 L .56039 .61287 L F
.751 .585 .67 r
.55739 .61385 m .55889 .61788 L .55919 .61496 L F
.173 .209 .658 r
.55985 .64584 m .56063 .64534 L .56031 .642 L F
.142 .147 .603 r
.55985 .64584 m .56129 .64797 L .56063 .64534 L F
.537 .894 .677 r
.6927 .49514 m .69131 .49592 L .68961 .49746 L F
0 0 .092 r
.69131 .49592 m .68946 .49924 L .68961 .49746 L F
1 .811 .497 r
.66528 .50905 m .66434 .51019 L .66499 .50803 L F
.66528 .50905 m .66466 .511 L .66434 .51019 L F
.769 .943 .937 r
.69337 .49297 m .6927 .49514 L .69368 .49413 L F
.851 .984 .702 r
.69337 .49297 m .69131 .49592 L .6927 .49514 L F
.846 .767 .774 r
.48075 .6447 m .48014 .64683 L .48465 .64309 L F
.48212 .64414 m .48465 .64309 L .48269 .64397 L F
.31 .778 .657 r
.48584 .64252 m .48269 .64397 L .48465 .64309 L F
.602 .462 .663 r
.48408 .64318 m .48379 .64364 L .48269 .64397 L F
.48379 .64364 m .48198 .64653 L .48269 .64397 L F
.846 .767 .774 r
.48075 .6447 m .48212 .64414 L .48269 .64397 L F
.563 .401 .62 r
.59774 .62222 m .5952 .62017 L .59515 .62253 L F
.59774 .62222 m .59761 .61965 L .5952 .62017 L F
.669 .396 .499 r
.5144 .70195 m .51671 .70242 L .51777 .69932 L F
.732 .463 .522 r
.51777 .69932 m .52038 .70209 L .52023 .69944 L F
.51777 .69932 m .51671 .70242 L .52038 .70209 L F
.37 .012 .22 r
.38679 .62394 m .38526 .62326 L .38732 .62262 L F
.38679 .62394 m .38468 .62442 L .38526 .62326 L F
.63 .526 .717 r
.65834 .49267 m .65972 .49738 L .6601 .4949 L F
.436 .473 .8 r
.28643 .62049 m .28813 .61916 L .28591 .61938 L F
.28643 .62049 m .28928 .62248 L .28813 .61916 L F
.76 .533 .59 r
.60938 .55377 m .61281 .55178 L .60939 .55155 L F
.60938 .55377 m .61286 .55422 L .61281 .55178 L F
.789 .657 .718 r
.70337 .47259 m .70299 .47525 L .69928 .47431 L F
.932 .633 .453 r
.70299 .47525 m .7013 .47622 L .69928 .47431 L F
.70299 .47525 m .70285 .47705 L .7013 .47622 L F
.392 .151 .425 r
.70524 .47456 m .70285 .47705 L .70299 .47525 L F
.502 0 0 r
.46629 .69978 m .46863 .70088 L .47039 .70009 L F
.591 .188 .247 r
.46863 .70088 m .47247 .69923 L .47039 .70009 L F
.946 .754 .61 r
.62008 .57635 m .62178 .57475 L .62001 .57402 L F
.62008 .57635 m .62155 .57736 L .62178 .57475 L F
.473 .503 .809 r
.43935 .68756 m .44055 .69088 L .43864 .69111 L F
.481 .028 .097 r
.66667 .48667 m .66588 .488 L .66334 .48814 L F
.639 .194 .179 r
.66667 .48667 m .66919 .48825 L .66588 .488 L F
.192 .345 .79 r
.51768 .63301 m .51895 .63369 L .51791 .63494 L F
.255 .44 .851 r
.51895 .63369 m .52062 .63637 L .51791 .63494 L F
0 .279 .688 r
.51791 .63494 m .52062 .63637 L .52011 .63617 L F
.598 .745 .947 r
.32323 .62377 m .31968 .62307 L .32183 .62204 L F
.481 .546 .846 r
.32419 .62164 m .32323 .62377 L .32183 .62204 L F
.32419 .62164 m .32538 .62474 L .32323 .62377 L F
.446 .853 .966 r
.69547 .46847 m .6973 .46755 L .69773 .46741 L F
.69547 .46847 m .6946 .46805 L .6973 .46755 L F
.502 0 0 r
.46304 .69874 m .46629 .69978 L .46457 .69897 L F
0 .202 .696 r
.52062 .63637 m .52177 .63764 L .52011 .63617 L F
.479 .697 .964 r
.52276 .63592 m .52177 .63764 L .52062 .63637 L F
.52276 .63592 m .52423 .63754 L .52177 .63764 L F
.469 .105 .264 r
.60151 .66526 m .59823 .66777 L .59932 .666 L F
.634 .813 .968 r
.46819 .69299 m .46899 .69421 L .46528 .69377 L F
.719 .187 0 r
.46881 .69659 m .46528 .69377 L .46899 .69421 L F
.382 .667 .971 r
.46997 .69292 m .46899 .69421 L .46819 .69299 L F
0 0 .14 r
.46945 .69512 m .46899 .69421 L .46997 .69292 L F
.46945 .69512 m .46881 .69659 L .46899 .69421 L F
.586 .601 .834 r
.52874 .65657 m .53006 .65338 L .52905 .65448 L F
.52874 .65657 m .53185 .65622 L .53006 .65338 L F
.356 0 0 r
.40583 .59844 m .40775 .59856 L .40921 .59735 L F
.698 .239 .158 r
.40775 .59856 m .41134 .59924 L .40921 .59735 L F
.363 .644 .963 r
.40855 .59731 m .40974 .59869 L .40775 .59856 L F
.40974 .59869 m .40986 .59883 L .40775 .59856 L F
.356 0 0 r
.40549 .59855 m .40775 .59856 L .40583 .59844 L F
.933 .902 .772 r
.72757 .48522 m .72732 .48262 L .72847 .48393 L F
.72757 .48522 m .72581 .4852 L .72732 .48262 L F
.964 .794 .622 r
.72757 .48522 m .72539 .48758 L .72581 .4852 L F
.72757 .48522 m .72669 .4886 L .72539 .48758 L F
.178 0 .345 r
.60411 .6317 m .60551 .63073 L .60372 .63377 L F
.458 0 0 r
.29841 .63469 m .29786 .63465 L .29786 .63465 L F
.29841 .63469 m .29786 .63465 L .29783 .63437 L F
.616 .944 .754 r
.29966 .63336 m .29786 .63465 L .29841 .63469 L F
0 0 0 r
.29786 .63465 m .29966 .63336 L .29818 .63477 L F
.29786 .63465 m .29966 .63336 L .29786 .63465 L F
.616 .944 .754 r
.29966 .63336 m .29779 .63464 L .29786 .63465 L F
0 0 0 r
.29786 .63465 m .298 .6348 L .29966 .63336 L F
.29662 .63554 m .29786 .63465 L .2971 .63579 L F
.29662 .63554 m .29789 .63486 L .29786 .63465 L F
.29786 .63465 m .29818 .63477 L .2971 .63579 L F
.29789 .63486 m .298 .6348 L .29786 .63465 L F
.458 0 0 r
.29783 .63437 m .29786 .63465 L .2951 .63291 L F
.29786 .63465 m .29779 .63464 L .29771 .63459 L F
.29786 .63465 m .29771 .63459 L .2951 .63291 L F
.223 .258 .687 r
.2951 .63291 m .29779 .63464 L .29612 .6304 L F
.682 .67 .832 r
.71558 .4799 m .71225 .47777 L .71475 .47649 L F
.65 .904 .982 r
.28266 .6431 m .28321 .64156 L .28514 .64215 L F
.28266 .6431 m .28321 .64156 L .28514 .64215 L F
.898 .848 .785 r
.72088 .50079 m .71836 .50548 L .71711 .50293 L F
.165 0 0 r
.53882 .597 m .54136 .59653 L .54259 .59558 L F
0 0 0 r
.54259 .59558 m .54321 .59551 L .54477 .5944 L F
.54259 .59558 m .54136 .59653 L .54321 .59551 L F
0 0 .333 r
.61888 .60393 m .61775 .60204 L .61906 .60154 L F
.61888 .60393 m .61746 .60564 L .61775 .60204 L F
.781 .867 .912 r
.67903 .49882 m .67509 .49977 L .67787 .49764 L F
.813 .873 .89 r
.68076 .49725 m .67903 .49882 L .67787 .49764 L F
.382 .827 .943 r
.50007 .63668 m .50193 .63616 L .49966 .6367 L F
.50321 .63649 m .50193 .63616 L .50007 .63668 L F
.658 .773 .934 r
.50193 .63616 m .50462 .63632 L .50413 .63513 L F
.50193 .63616 m .50462 .63632 L .50413 .63513 L F
.268 0 .117 r
.50383 .63564 m .50193 .63616 L .50413 .63513 L F
.382 .827 .943 r
.50321 .63649 m .49966 .6367 L .50091 .63678 L F
.538 .383 .619 r
.501 .63973 m .50321 .63649 L .50091 .63678 L F
.501 .63973 m .50334 .6393 L .50321 .63649 L F
.163 .688 .873 r
.50321 .63649 m .50462 .63632 L .50193 .63616 L F
.268 0 .117 r
.50282 .63737 m .50193 .63616 L .50383 .63564 L F
.314 0 .138 r
.50193 .63616 m .50058 .63689 L .49966 .6367 L F
.50058 .63689 m .49767 .63845 L .49966 .6367 L F
.173 0 0 r
.49874 .63651 m .49966 .6367 L .49733 .63634 L F
.50091 .63678 m .49966 .6367 L .49874 .63651 L F
.96 .772 .605 r
.57363 .67 m .57205 .67108 L .57108 .66825 L F
.57363 .67 m .57346 .67146 L .57205 .67108 L F
.644 .534 .714 r
.575 .6649 m .57676 .66867 L .57363 .67 L F
.517 .302 .526 r
.57676 .66867 m .57346 .67146 L .57363 .67 L F
.426 .126 .352 r
.45851 .65031 m .46117 .64814 L .45896 .64865 L F
.073 0 0 r
.72911 .47396 m .73099 .47379 L .73149 .47303 L F
.381 0 0 r
.73149 .47303 m .73099 .47379 L .73441 .47361 L F
.351 .818 .913 r
.48987 .61914 m .4936 .61877 L .49099 .61934 L F
.633 .389 .531 r
.4907 .67388 m .49338 .67144 L .4911 .67131 L F
.741 .597 .697 r
.49323 .67304 m .49275 .67265 L .49338 .67144 L F
.49323 .67304 m .4907 .67388 L .49275 .67265 L F
.622 .315 .428 r
.49323 .67304 m .49311 .67416 L .4907 .67388 L F
.633 .389 .531 r
.4907 .67388 m .492 .67409 L .49203 .67403 L F
.625 .313 .422 r
.4907 .67388 m .49293 .67587 L .4936 .67435 L F
.622 .315 .428 r
.49311 .67416 m .49293 .67587 L .4907 .67388 L F
.633 .389 .531 r
.4907 .67388 m .49203 .67403 L .49275 .67265 L F
.4907 .67388 m .49275 .67265 L .49338 .67144 L F
.741 .597 .697 r
.49275 .67265 m .4907 .67388 L .4911 .67131 L F
.49275 .67265 m .4911 .67131 L .49338 .67144 L F
.394 .081 .313 r
.49655 .67076 m .49323 .67304 L .49338 .67144 L F
.615 .423 .598 r
.49655 .67076 m .49323 .67304 L .49338 .67144 L F
.394 .081 .313 r
.49655 .67076 m .49566 .67332 L .49371 .67309 L F
.659 .73 .902 r
.49655 .67076 m .49338 .67144 L .49521 .66902 L F
.398 .127 .383 r
.49329 .67385 m .49311 .67416 L .49323 .67304 L F
.633 .389 .531 r
.49267 .6742 m .49305 .67426 L .49352 .6733 L F
.49305 .67426 m .4936 .67435 L .49353 .67342 L F
.548 .499 .752 r
.4936 .67435 m .49368 .67397 L .49353 .67342 L F
.398 .127 .383 r
.49394 .67492 m .49293 .67587 L .49343 .67306 L F
.633 .389 .531 r
.49305 .67426 m .49353 .67342 L .49352 .6733 L F
.398 .127 .383 r
.49343 .67306 m .49329 .67385 L .49323 .67304 L F
.49329 .67385 m .49293 .67587 L .49311 .67416 L F
.49566 .67332 m .49368 .67397 L .49343 .67306 L F
.394 .081 .313 r
.49474 .672 m .49371 .67309 L .49343 .67306 L F
.49474 .672 m .49343 .67306 L .49338 .67293 L F
.49655 .67076 m .49371 .67309 L .49474 .672 L F
.548 .499 .752 r
.49368 .67397 m .49566 .67332 L .49447 .67034 L F
.4936 .67435 m .49566 .67332 L .49368 .67397 L F
.257 0 .236 r
.4936 .67435 m .49293 .67587 L .49566 .67332 L F
.398 .127 .383 r
.49566 .67332 m .49394 .67492 L .49368 .67397 L F
.548 .499 .752 r
.49353 .67342 m .49371 .67381 L .49352 .6733 L F
.49368 .67397 m .49371 .67381 L .49353 .67342 L F
.49352 .6733 m .49447 .67034 L .49338 .67144 L F
.49371 .67381 m .49447 .67034 L .49352 .6733 L F
.394 .081 .313 r
.49338 .67293 m .49343 .67306 L .49323 .67304 L F
.633 .389 .531 r
.492 .67409 m .49267 .6742 L .49338 .67144 L F
.49267 .6742 m .49352 .6733 L .49338 .67144 L F
0 0 0 r
.49521 .66902 m .49338 .67144 L .49447 .67034 L F
.813 .811 .849 r
.6704 .50305 m .66738 .50309 L .66906 .50152 L F
.672 .777 .929 r
.67231 .50204 m .6704 .50305 L .66906 .50152 L F
.984 .866 .64 r
.60573 .59121 m .60537 .58793 L .6067 .58897 L F
.467 .872 .957 r
.73685 .4732 m .73531 .47428 L .73441 .47361 L F
.73685 .4732 m .73778 .47366 L .73531 .47428 L F
.325 .065 .356 r
.59959 .61663 m .60207 .61376 L .60006 .61464 L F
.745 .635 .738 r
.57812 .66496 m .57453 .66279 L .57711 .6621 L F
.57812 .66496 m .575 .6649 L .57453 .66279 L F
.746 .578 .667 r
.57812 .66496 m .57676 .66867 L .575 .6649 L F
.699 .272 .229 r
.57711 .6621 m .58068 .66267 L .57812 .66496 L F
.699 .617 .761 r
.30234 .63984 m .3037 .64327 L .30604 .64208 L F
.655 .796 .95 r
.70074 .49326 m .7039 .49336 L .70353 .49237 L F
.381 .721 .989 r
.7039 .49336 m .70575 .49251 L .70353 .49237 L F
.7039 .49336 m .70666 .49354 L .70575 .49251 L F
.566 .767 .973 r
.52051 .7889 m .52154 .79013 L .51914 .79062 L F
.991 .745 .452 r
.52051 .7889 m .52063 .7894 L .52154 .79013 L F
.523 .818 .999 r
.52154 .79013 m .5226 .79099 L .51914 .79062 L F
.711 .305 .276 r
.51914 .79062 m .52268 .791 L .5215 .79291 L F
.991 .745 .452 r
.52063 .7894 m .5215 .79291 L .52154 .79013 L F
.523 .818 .999 r
.52154 .79013 m .52268 .791 L .5226 .79099 L F
.489 .801 1 r
.52154 .79013 m .52496 .79062 L .52268 .791 L F
.988 .74 .464 r
.5215 .79291 m .52268 .791 L .52154 .79013 L F
.712 .765 .894 r
.50195 .79072 m .49921 .79155 L .49807 .79034 L F
.667 .514 .667 r
.50195 .79072 m .49936 .79374 L .49921 .79155 L F
.58 .383 .578 r
.474 .65361 m .47196 .65164 L .47407 .65122 L F
.474 .65361 m .47161 .65401 L .47196 .65164 L F
.837 .562 .522 r
.60536 .58302 m .60344 .58485 L .60326 .58254 L F
.60536 .58302 m .6055 .58544 L .60344 .58485 L F
.633 .423 .58 r
.59263 .62511 m .59515 .62253 L .59279 .62297 L F
.064 0 0 r
.35803 .6386 m .35705 .6394 L .35582 .63925 L F
.062 0 0 r
.35705 .6394 m .35498 .64005 L .35582 .63925 L F
.498 .425 .704 r
.57158 .63708 m .56981 .63948 L .56849 .63663 L F
.57158 .63708 m .57201 .63951 L .56981 .63948 L F
0 0 .306 r
.59649 .646 m .59562 .64852 L .59701 .64742 L F
0 0 .413 r
.59562 .64852 m .59674 .64984 L .59701 .64742 L F
.396 .657 .964 r
.43554 .70712 m .43641 .70833 L .43737 .70708 L F
0 .406 .756 r
.43641 .70833 m .44043 .70988 L .43989 .71051 L F
.251 .448 .859 r
.43641 .70833 m .43989 .71051 L .43737 .70708 L F
.485 .572 .868 r
.75162 .49563 m .75337 .49353 L .75146 .49377 L F
.75162 .49563 m .75464 .49681 L .75337 .49353 L F
.529 .223 .392 r
.59302 .55422 m .59436 .55638 L .5953 .55468 L F
.59302 .55422 m .59207 .55675 L .59436 .55638 L F
.63 .805 .966 r
.74104 .53077 m .74199 .53209 L .74441 .53121 L F
.4 .771 .993 r
.71037 .4942 m .70893 .49332 L .70666 .49354 L F
.555 .81 .993 r
.71242 .49389 m .70893 .49332 L .71037 .4942 L F
.791 .66 .718 r
.59928 .6539 m .60021 .65702 L .59735 .65613 L F
.598 .544 .766 r
.60197 .65348 m .60021 .65702 L .59928 .6539 L F
.60197 .65348 m .60282 .65638 L .60021 .65702 L F
.384 .424 .779 r
.60289 .65856 m .60021 .65702 L .60282 .65638 L F
.898 .848 .785 r
.72088 .50079 m .71764 .5004 L .71934 .49943 L F
.72088 .50079 m .71711 .50293 L .71764 .5004 L F
.98 .692 .387 r
.5631 .62811 m .56335 .63082 L .56457 .63161 L F
.901 .49 .109 r
.56335 .63082 m .56528 .63349 L .56457 .63161 L F
0 .031 .597 r
.53813 .62054 m .53874 .62191 L .53792 .6192 L F
.511 .444 .717 r
.46713 .66231 m .46524 .66324 L .46477 .66041 L F
.665 .259 .265 r
.46524 .66324 m .46735 .66502 L .46488 .6644 L F
.456 .324 .611 r
.46713 .66231 m .46735 .66502 L .46524 .66324 L F
.906 .755 .682 r
.62092 .58167 m .62155 .58491 L .62207 .58293 L F
.473 .245 .488 r
.39271 .6172 m .39234 .61962 L .39021 .62004 L F
.446 .195 .438 r
.39497 .61663 m .39234 .61962 L .39271 .6172 L F
.309 0 0 r
.76152 .51057 m .75729 .51315 L .75994 .51298 L F
.525 0 0 r
.76239 .51247 m .76152 .51057 L .75994 .51298 L F
.76239 .51247 m .76385 .51117 L .76152 .51057 L F
.788 .694 .76 r
.70998 .47893 m .70635 .47978 L .70892 .47784 L F
.70998 .47893 m .708 .48102 L .70635 .47978 L F
.696 .862 .961 r
.71225 .47777 m .70998 .47893 L .70892 .47784 L F
.511 .499 .779 r
.31701 .61606 m .31619 .62002 L .31601 .61861 L F
.31701 .61606 m .31829 .61977 L .31619 .62002 L F
.898 .716 .647 r
.61923 .56808 m .61898 .57067 L .62195 .57122 L F
.889 .765 .719 r
.61898 .57067 m .62001 .57402 L .62195 .57122 L F
.546 .514 .771 r
.41665 .68549 m .41965 .6882 L .41859 .68496 L F
.683 .411 .505 r
.58968 .65853 m .5911 .65606 L .58937 .65656 L F
.58968 .65853 m .591 .65864 L .5911 .65606 L F
.747 .709 .816 r
.58954 .65278 m .5911 .65606 L .5929 .65425 L F
.934 .824 .712 r
.65734 .49919 m .65421 .50197 L .65608 .50132 L F
.706 .621 .76 r
.65765 .49781 m .65734 .49919 L .65972 .49738 L F
.894 .576 .437 r
.65608 .50132 m .65802 .50265 L .65734 .49919 L F
.536 .175 .301 r
.4969 .70468 m .50068 .70216 L .49707 .70324 L F
.4969 .70468 m .49916 .70477 L .50068 .70216 L F
.674 .329 .381 r
.50068 .70216 m .49916 .70477 L .50284 .70436 L F
.489 .298 .548 r
.41993 .6764 m .42218 .67374 L .42015 .67437 L F
.516 .354 .6 r
.46388 .67135 m .4641 .6734 L .46623 .67368 L F
.795 .548 .563 r
.61286 .55422 m .61626 .557 L .61632 .55455 L F
.516 .304 .531 r
.5828 .57736 m .58269 .57965 L .58043 .58005 L F
.491 .246 .47 r
.5828 .57736 m .58459 .57883 L .58269 .57965 L F
.5828 .57736 m .58513 .57686 L .58459 .57883 L F
.606 .756 .95 r
.31896 .64748 m .32193 .64784 L .32101 .64598 L F
.078 .395 .852 r
.32292 .6478 m .32101 .64598 L .32193 .64784 L F
.81 .613 .635 r
.55537 .61635 m .55889 .61788 L .55739 .61385 L F
.559 .399 .621 r
.55671 .61554 m .55507 .6137 L .55739 .61385 L F
.64 .898 .984 r
.55739 .61385 m .5596 .6125 L .55767 .61188 L F
.775 .778 .276 r
.55767 .61188 m .55671 .61554 L .55739 .61385 L F
.704 .611 .75 r
.55739 .61385 m .56039 .61287 L .5596 .6125 L F
.653 .22 .206 r
.49186 .77656 m .49508 .77876 L .4959 .7766 L F
.984 .734 .343 r
.4959 .7766 m .49593 .77919 L .49789 .77626 L F
.4959 .7766 m .49508 .77876 L .49593 .77919 L F
.465 .281 .546 r
.4959 .7766 m .49593 .77919 L .49789 .77626 L F
.463 .096 .256 r
.52442 .64849 m .52116 .65076 L .52215 .64863 L F
.52442 .64849 m .5226 .65058 L .52116 .65076 L F
.807 .54 .535 r
.52442 .64849 m .52529 .65131 L .5226 .65058 L F
.6 .382 .558 r
.28243 .6282 m .28499 .6281 L .28501 .62611 L F
0 0 0 r
.28499 .6281 m .28662 .62492 L .28501 .62611 L F
.462 .198 .427 r
.3687 .61718 m .37091 .61666 L .37127 .61456 L F
.311 .07 .378 r
.37127 .61456 m .37275 .61583 L .37355 .61418 L F
.37127 .61456 m .37091 .61666 L .37275 .61583 L F
.511 .444 .717 r
.46713 .66231 m .46477 .66041 L .46734 .65983 L F
0 0 .204 r
.56368 .60447 m .56217 .60811 L .56269 .60602 L F
.318 .763 .962 r
.54143 .64143 m .54507 .64175 L .54277 .64223 L F
.315 0 0 r
.34748 .64231 m .34609 .64377 L .34398 .64409 L F
.165 0 0 r
.34944 .64171 m .34916 .64235 L .34748 .64231 L F
.156 0 0 r
.34748 .64231 m .3482 .64319 L .34609 .64377 L F
.34748 .64231 m .34916 .64235 L .3482 .64319 L F
.754 .812 .898 r
.74702 .51231 m .74408 .51456 L .74277 .51329 L F
.825 .85 .866 r
.28792 .63473 m .28778 .63737 L .28955 .63425 L F
.22 .732 .688 r
.29042 .63396 m .28955 .63425 L .29187 .63433 L F
.29042 .63396 m .28792 .63473 L .28955 .63425 L F
.364 .186 .502 r
.31884 .61077 m .31691 .61382 L .31747 .6116 L F
.355 .035 .278 r
.58269 .57965 m .57996 .58151 L .58043 .58005 L F
.388 .454 .807 r
.72889 .51502 m .72988 .51789 L .7316 .51619 L F
0 0 .161 r
.7311 .51989 m .7316 .51619 L .72988 .51789 L F
.613 .122 .062 r
.75729 .51315 m .75794 .51167 L .7544 .51148 L F
.65 .904 .982 r
.28266 .6431 m .28125 .6425 L .28321 .64156 L F
.28266 .6431 m .28125 .6425 L .28321 .64156 L F
.399 .467 .814 r
.65303 .50445 m .65555 .50549 L .65421 .50197 L F
.905 .817 .75 r
.5497 .76695 m .55001 .77035 L .55114 .76852 L F
.512 .273 .489 r
.28872 .5938 m .29125 .59114 L .28917 .5917 L F
.533 .46 .719 r
.76761 .48765 m .76588 .49194 L .76502 .48837 L F
.76761 .48765 m .76821 .49125 L .76588 .49194 L F
.503 .365 .627 r
.76821 .49125 m .7685 .49376 L .76588 .49194 L F
.465 .373 .668 r
.76588 .49194 m .7685 .49376 L .76639 .49422 L F
.484 .167 .352 r
.38468 .62442 m .38148 .62767 L .38239 .62509 L F
.722 .672 .801 r
.71701 .47652 m .71454 .47495 L .71685 .47396 L F
.582 .847 .995 r
.71883 .47477 m .71701 .47652 L .71685 .47396 L F
.71883 .47477 m .71977 .47574 L .71701 .47652 L F
.508 .547 .831 r
.60001 .64526 m .60329 .64808 L .60133 .64851 L F
.507 .414 .684 r
.60329 .64808 m .60162 .65102 L .60133 .64851 L F
.728 .262 .142 r
.76695 .50642 m .76873 .50803 L .76784 .50663 L F
.842 .88 .869 r
.76784 .50663 m .77166 .50218 L .77018 .50427 L F
.365 .07 .325 r
.5622 .57985 m .56431 .57924 L .5648 .57683 L F
.332 .009 .259 r
.56431 .57924 m .5669 .5763 L .5648 .57683 L F
.813 .637 .663 r
.59706 .57185 m .59674 .57429 L .59495 .57105 L F
.644 .479 .646 r
.59841 .57404 m .59674 .57429 L .59706 .57185 L F
0 0 .37 r
.52775 .60833 m .5278 .60734 L .52688 .60508 L F
0 .347 .822 r
.52775 .60833 m .53059 .61006 L .5278 .60734 L F
.138 0 0 r
.54917 .59096 m .55145 .59033 L .5528 .589 L F
.286 0 .098 r
.55145 .59033 m .55452 .58773 L .5528 .589 L F
.455 .139 .34 r
.39021 .62004 m .38957 .62225 L .38732 .62262 L F
.397 .087 .318 r
.39172 .62162 m .39021 .62004 L .39234 .61962 L F
.39172 .62162 m .38957 .62225 L .39021 .62004 L F
.597 .244 .342 r
.5342 .69869 m .53841 .69632 L .53441 .69733 L F
.5342 .69869 m .53652 .69895 L .53841 .69632 L F
.75 .434 .448 r
.53841 .69632 m .54066 .69881 L .53996 .69715 L F
.53841 .69632 m .53652 .69895 L .54066 .69881 L F
.37 .148 .441 r
.37621 .61073 m .3784 .61068 L .37845 .60833 L F
.418 .107 .329 r
.37621 .61073 m .37763 .61284 L .3784 .61068 L F
.37621 .61073 m .37546 .61339 L .37763 .61284 L F
.976 .839 .438 r
.62118 .59151 m .62026 .59296 L .62069 .59388 L F
.751 .677 .129 r
.62151 .58825 m .62118 .59094 L .62118 .59151 L F
.806 .87 .431 r
.62118 .59094 m .62026 .59296 L .62118 .59151 L F
.484 .833 .997 r
.36457 .58671 m .3666 .58621 L .3682 .58694 L F
.419 .806 .989 r
.3666 .58621 m .37034 .58655 L .3682 .58694 L F
.55 .435 .675 r
.28005 .60549 m .28191 .60246 L .27975 .60295 L F
.545 .329 .537 r
.48981 .77671 m .49197 .77934 L .49186 .77656 L F
.665 .968 .788 r
.59436 .65322 m .5929 .65425 L .59466 .65278 L F
.489 .329 .59 r
.60372 .63377 m .60151 .63656 L .6011 .63423 L F
.705 .808 .345 r
.5656 .59907 m .56415 .60214 L .5647 .60292 L F
.5656 .59907 m .56553 .59902 L .56415 .60214 L F
.447 .328 .624 r
.41817 .68007 m .42004 .67974 L .41993 .6764 L F
.462 .381 .679 r
.41817 .68007 m .4205 .68202 L .42004 .67974 L F
.41817 .68007 m .41863 .68258 L .4205 .68202 L F
.168 0 0 r
.43072 .66392 m .43471 .66268 L .43226 .66277 L F
.892 .592 .473 r
.60329 .57994 m .60104 .57921 L .6005 .57687 L F
.917 .671 .552 r
.60329 .57994 m .60112 .58146 L .60104 .57921 L F
.60329 .57994 m .60326 .58254 L .60112 .58146 L F
.576 .619 .858 r
.75334 .50309 m .75703 .50568 L .75574 .50232 L F
.575 .53 .767 r
.75703 .50568 m .75899 .50169 L .75574 .50232 L F
.75703 .50568 m .75938 .5051 L .75899 .50169 L F
.119 0 .198 r
.57418 .58608 m .57692 .58452 L .57464 .58729 L F
.029 0 0 r
.35074 .62735 m .35384 .62629 L .3527 .62581 L F
.162 0 0 r
.3527 .62581 m .35384 .62629 L .35547 .62515 L F
.16 0 0 r
.3073 .58517 m .30942 .58478 L .3111 .58361 L F
.313 0 0 r
.30942 .58478 m .31335 .58331 L .3111 .58361 L F
.765 .833 .905 r
.42918 .70774 m .43103 .70909 L .4326 .70772 L F
.35 0 .207 r
.36894 .63408 m .3661 .63591 L .36684 .63472 L F
.82 .616 .627 r
.61626 .557 m .61773 .55985 L .618 .55795 L F
.777 .696 .774 r
.49654 .65693 m .49297 .65649 L .49618 .65412 L F
.546 .02 0 r
.49486 .65751 m .49611 .6575 L .49614 .65731 L F
.652 .163 .077 r
.49654 .65693 m .49638 .65732 L .49501 .65698 L F
.495 .65674 m .49501 .65698 L .49297 .65649 L F
.49654 .65693 m .49501 .65698 L .495 .65674 L F
.49638 .65732 m .49614 .65731 L .49297 .65649 L F
.699 .538 .665 r
.49297 .65649 m .49486 .65751 L .49501 .65711 L F
.652 .163 .077 r
.49614 .65731 m .4933 .65674 L .49297 .65649 L F
.699 .538 .665 r
.49297 .65649 m .49501 .65711 L .49618 .65412 L F
.652 .163 .077 r
.49477 .65703 m .49394 .65722 L .4933 .65674 L F
.49614 .65731 m .4956 .65728 L .49477 .65703 L F
.4956 .65728 m .49394 .65722 L .49477 .65703 L F
.175 0 .196 r
.49398 .66143 m .49426 .66134 L .49611 .6575 L F
.81 .788 .832 r
.4963 .66195 m .49595 .65944 L .49857 .65914 L F
.49595 .65944 m .49631 .65904 L .49857 .65914 L F
.262 0 .194 r
.49611 .6575 m .49631 .65904 L .49659 .65878 L F
.771 .301 .126 r
.49857 .65914 m .49784 .65901 L .4965 .65748 L F
.49857 .65914 m .4965 .65748 L .4965 .65745 L F
.49784 .65901 m .49642 .65742 L .49642 .65739 L F
.81 .788 .832 r
.49631 .65904 m .49659 .65878 L .49857 .65914 L F
.771 .301 .126 r
.49857 .65914 m .49637 .65735 L .49724 .65769 L F
.701 .356 .39 r
.49867 .65746 m .49857 .65914 L .49654 .65693 L F
.543 .308 .508 r
.50109 .65656 m .49857 .65914 L .49867 .65746 L F
.50109 .65656 m .50098 .65875 L .49857 .65914 L F
.563 .324 .511 r
.50334 .65835 m .50098 .65875 L .50109 .65656 L F
.262 0 .194 r
.4965 .6575 m .49767 .65972 L .50119 .6575 L F
.49611 .6575 m .4965 .65806 L .4965 .6575 L F
.771 .301 .126 r
.49784 .65901 m .49659 .65878 L .49642 .65742 L F
.262 0 .194 r
.4965 .65806 m .49767 .65972 L .4965 .6575 L F
.771 .301 .126 r
.4965 .65745 m .4965 .65748 L .49642 .65739 L F
.49724 .65769 m .49637 .65735 L .49654 .65693 L F
.425 .331 .646 r
.49636 .65735 m .50119 .6575 L .50051 .65497 L F
.175 0 .196 r
.49444 .66096 m .49631 .65904 L .49611 .6575 L F
.81 .788 .832 r
.4963 .66195 m .49398 .66143 L .49595 .65944 L F
.175 0 .196 r
.49426 .66134 m .49595 .65944 L .49444 .66096 L F
.49595 .65944 m .49631 .65904 L .49444 .66096 L F
.81 .788 .832 r
.49595 .65944 m .49398 .66143 L .49584 .65864 L F
.425 .331 .646 r
.49611 .6575 m .49636 .65735 L .49614 .65731 L F
0 0 .081 r
.49501 .65711 m .49486 .65751 L .49502 .65726 L F
.546 .02 0 r
.49486 .65751 m .49614 .65731 L .49502 .65726 L F
.175 0 .196 r
.49398 .66143 m .49611 .6575 L .49584 .65864 L F
.546 .02 0 r
.49486 .65751 m .49584 .65864 L .49611 .6575 L F
.609 .039 0 r
.49297 .65649 m .49584 .65864 L .49486 .65751 L F
.652 .163 .077 r
.49631 .65731 m .49584 .65864 L .49394 .65722 L F
.49638 .65732 m .49637 .65736 L .49631 .65731 L F
.425 .331 .646 r
.49611 .6575 m .4965 .6575 L .49637 .65736 L F
.49611 .6575 m .49637 .65736 L .49636 .65735 L F
.652 .163 .077 r
.49637 .65736 m .49584 .65864 L .49631 .65731 L F
.425 .331 .646 r
.49636 .65735 m .49637 .65736 L .49636 .65735 L F
.4965 .6575 m .50119 .6575 L .49636 .65735 L F
.262 0 .194 r
.4965 .65806 m .49659 .65878 L .49684 .65854 L F
.49611 .6575 m .49659 .65878 L .4965 .65806 L F
.771 .301 .126 r
.49642 .65739 m .49584 .65864 L .49637 .65735 L F
.49659 .65878 m .49584 .65864 L .49642 .65739 L F
.81 .788 .832 r
.49631 .65904 m .49654 .65877 L .49659 .65878 L F
.262 0 .194 r
.49684 .65854 m .49651 .66062 L .49767 .65972 L F
.49631 .65904 m .49651 .66062 L .49684 .65854 L F
.175 0 .196 r
.49426 .66134 m .49651 .66062 L .49631 .65904 L F
.81 .788 .832 r
.49595 .65944 m .49584 .65864 L .49654 .65877 L F
.425 .331 .646 r
.49614 .65726 m .50051 .65497 L .49651 .65503 L F
.49614 .65731 m .49619 .65728 L .49614 .65726 L F
.49619 .65728 m .50051 .65497 L .49614 .65726 L F
.49636 .65735 m .50051 .65497 L .49614 .65731 L F
0 0 .081 r
.49618 .65412 m .49501 .65711 L .49651 .65503 L F
.49501 .65711 m .49502 .65726 L .49651 .65503 L F
.546 .02 0 r
.49502 .65726 m .49614 .65731 L .49651 .65503 L F
.589 .929 .73 r
.74663 .53023 m .7497 .52823 L .74971 .52843 L F
0 0 0 r
.7497 .52823 m .75225 .52572 L .75147 .52713 L F
.75147 .52713 m .74971 .52843 L .7497 .52823 L F
.856 .567 .5 r
.61773 .55985 m .61798 .56248 L .62109 .563 L F
.835 .679 .69 r
.61798 .56248 m .62078 .56544 L .62109 .563 L F
.103 .565 .912 r
.66724 .51489 m .66622 .51407 L .66367 .51352 L F
.818 .92 .905 r
.6679 .51243 m .66724 .51489 L .66944 .51326 L F
.6679 .51243 m .66622 .51407 L .66724 .51489 L F
.373 .667 .972 r
.33271 .62647 m .33269 .62684 L .33078 .62562 L F
.33271 .62647 m .33528 .62703 L .33269 .62684 L F
.775 .349 .241 r
.50968 .70601 m .50851 .70736 L .50595 .70618 L F
.16 0 0 r
.51081 .70672 m .50851 .70736 L .50968 .70601 L F
.51081 .70672 m .50968 .70601 L .51086 .7066 L F
.713 .302 .265 r
.50725 .70629 m .51081 .70672 L .50868 .70464 L F
.061 .615 .823 r
.50725 .70629 m .50923 .70641 L .51081 .70672 L F
.62 .073 0 r
.50923 .70641 m .5108 .70678 L .51081 .70672 L F
.16 0 0 r
.51081 .70672 m .51086 .7066 L .51201 .70718 L F
.314 0 0 r
.51575 .70613 m .51438 .70713 L .51201 .70718 L F
.275 .741 .946 r
.51201 .70718 m .51438 .70713 L .51081 .70672 L F
.328 0 .047 r
.51438 .70713 m .5108 .70934 L .51081 .70672 L F
.62 .073 0 r
.5108 .70678 m .51325 .70735 L .51081 .70672 L F
.64 .966 .867 r
.56768 .62558 m .56558 .62674 L .5663 .62605 L F
.56558 .62674 m .5631 .62811 L .5663 .62605 L F
.569 .28 .437 r
.56687 .62603 m .56723 .62654 L .5631 .62811 L F
.56768 .62558 m .56734 .6263 L .56687 .62603 L F
.56734 .6263 m .56723 .62654 L .56687 .62603 L F
.059 0 .152 r
.5678 .62689 m .56549 .63031 L .56734 .6263 L F
.543 0 0 r
.5675 .6264 m .5678 .62689 L .56739 .62636 L F
.797 .792 .848 r
.56739 .62636 m .56891 .62564 L .5675 .6264 L F
.059 0 .152 r
.56772 .626 m .56734 .6263 L .56768 .62558 L F
.56739 .62636 m .56734 .6263 L .56772 .626 L F
.797 .792 .848 r
.5663 .62605 m .56772 .626 L .56739 .62636 L F
.5675 .6264 m .56891 .62564 L .56898 .62682 L F
.059 0 .152 r
.5678 .62689 m .56739 .62636 L .56772 .626 L F
.543 0 0 r
.56739 .62636 m .5678 .62689 L .5663 .62605 L F
.635 .167 .125 r
.5663 .62605 m .5678 .62689 L .56772 .626 L F
.5663 .62605 m .56772 .626 L .56768 .62558 L F
.797 .792 .848 r
.5663 .62605 m .56789 .6258 L .56772 .626 L F
.56789 .6258 m .56891 .62564 L .56739 .62636 L F
.543 0 0 r
.56898 .62682 m .5683 .62686 L .5675 .6264 L F
.5683 .62686 m .5678 .62689 L .5675 .6264 L F
.797 .792 .848 r
.5663 .62605 m .56882 .62417 L .56891 .62564 L F
.569 .28 .437 r
.56723 .62654 m .56549 .6303 L .56356 .62853 L F
.56549 .6303 m .56547 .6303 L .56356 .62853 L F
.56723 .62654 m .56356 .62853 L .5631 .62811 L F
.409 .82 .623 r
.5631 .62811 m .56468 .62704 L .5663 .62605 L F
.387 .676 .974 r
.563 .62699 m .56468 .62704 L .5631 .62811 L F
.569 .28 .437 r
.56549 .6303 m .56549 .63031 L .56547 .6303 L F
.187 .264 .711 r
.5631 .62811 m .56549 .63031 L .56468 .62704 L F
.504 .486 .77 r
.56468 .62704 m .56368 .62987 L .563 .62699 L F
.56368 .62987 m .56335 .63082 L .56325 .62977 L F
.705 .523 0 r
.563 .62699 m .56335 .63082 L .5631 .62811 L F
.504 .486 .77 r
.56368 .62987 m .56325 .62977 L .563 .62699 L F
.816 .868 .885 r
.56677 .62387 m .56882 .62417 L .5663 .62605 L F
.367 .422 .786 r
.5663 .62605 m .5678 .62689 L .56721 .62516 L F
.5663 .62605 m .56721 .62516 L .56677 .62387 L F
.392 .472 .822 r
.56898 .62682 m .57053 .62425 L .56882 .62417 L F
.781 .998 .826 r
.56898 .62682 m .57053 .62425 L .5678 .62689 L F
0 .071 .624 r
.41295 .69921 m .41396 .70258 L .41491 .70196 L F
.748 .328 .251 r
.41491 .70196 m .41438 .69901 L .4129 .69914 L F
.897 .48 .108 r
.41491 .70196 m .41438 .69901 L .41351 .70053 L F
.51 0 0 r
.41417 .69937 m .41438 .69901 L .41706 .69989 L F
.4129 .69914 m .41438 .69901 L .41417 .69937 L F
.897 .48 .108 r
.41351 .70053 m .41438 .69901 L .41349 .70051 L F
.484 0 0 r
.41703 .70059 m .41438 .69901 L .41385 .69991 L F
.41464 .70054 m .41385 .69991 L .41349 .70051 L F
.41703 .70059 m .41385 .69991 L .41464 .70054 L F
0 .071 .624 r
.4129 .69914 m .41291 .69918 L .41295 .69921 L F
.41291 .69918 m .41396 .70258 L .41295 .69921 L F
.034 .21 .714 r
.53792 .6192 m .53874 .62191 L .53999 .62139 L F
.138 .486 .901 r
.53999 .62139 m .53874 .62191 L .54077 .62264 L F
.359 .216 .547 r
.60136 .63977 m .602 .64227 L .59996 .6428 L F
.388 .305 .64 r
.59996 .6428 m .60227 .64512 L .60001 .64526 L F
.59996 .6428 m .602 .64227 L .60227 .64512 L F
.553 .308 .498 r
.58098 .6414 m .58196 .64019 L .58011 .64004 L F
.56 .875 .59 r
.29841 .63469 m .2971 .63579 L .29966 .63336 L F
.639 .779 .948 r
.31726 .64549 m .31896 .64748 L .32101 .64598 L F
.631 .549 .744 r
.65972 .49738 m .66098 .50065 L .66344 .5 L F
.51 .234 .431 r
.58 .56522 m .58234 .56493 L .58255 .56302 L F
.54 .285 .477 r
.58234 .56493 m .58492 .56254 L .58255 .56302 L F
0 0 .196 r
.27214 .66774 m .27146 .6707 L .27586 .66826 L F
.27214 .66774 m .27197 .67039 L .27146 .6707 L F
0 0 .49 r
.27146 .6707 m .27197 .67039 L .27146 .66973 L F
.382 .8 .976 r
.27874 .62804 m .28087 .62774 L .28243 .6282 L F
.27874 .62804 m .28087 .62774 L .28243 .6282 L F
.803 .41 0 r
.47472 .6588 m .47458 .65757 L .47347 .65646 L F
.47472 .6588 m .475 .65861 L .47458 .65757 L F
.092 .242 .727 r
.47536 .65748 m .47472 .6588 L .47325 .65531 L F
0 0 .148 r
.47536 .65748 m .47454 .65891 L .47472 .6588 L F
.47454 .65891 m .47374 .6603 L .47472 .6588 L F
.803 .41 0 r
.47472 .6588 m .47544 .65967 L .475 .65861 L F
.591 .585 .815 r
.56132 .61029 m .56039 .61287 L .55928 .6093 L F
.902 .943 .824 r
.5596 .6125 m .56039 .61287 L .56132 .61029 L F
.625 .305 .408 r
.5953 .55468 m .59772 .55653 L .59869 .55406 L F
.608 .287 .401 r
.59869 .55406 m .60114 .55598 L .60108 .55401 L F
.59869 .55406 m .59772 .55653 L .60114 .55598 L F
0 0 0 r
.51914 .79062 m .51669 .79329 L .5171 .793 L F
.51811 .79203 m .5171 .793 L .51774 .79254 L F
.51914 .79062 m .5171 .793 L .51811 .79203 L F
.51914 .79062 m .51774 .79254 L .518 .79225 L F
.794 .708 .77 r
.51898 .78649 m .51881 .78995 L .51663 .78913 L F
.51881 .78995 m .51873 .79143 L .51751 .7901 L F
.51881 .78995 m .51751 .7901 L .51663 .78913 L F
.774 .655 .732 r
.51786 .79246 m .5215 .79291 L .52071 .78972 L F
.51982 .78983 m .52071 .78972 L .52051 .7889 L F
.566 .767 .973 r
.52051 .7889 m .51914 .79062 L .51873 .79157 L F
0 0 0 r
.51873 .79157 m .51914 .79062 L .51786 .79246 L F
.794 .708 .77 r
.51898 .78649 m .52051 .7889 L .51873 .79157 L F
.915 .941 .807 r
.51889 .78892 m .51875 .79128 L .51663 .78913 L F
.794 .708 .77 r
.51873 .79143 m .51873 .79157 L .51867 .7915 L F
.915 .941 .807 r
.51873 .79144 m .51873 .79157 L .51867 .7915 L F
0 0 0 r
.518 .79225 m .51774 .79254 L .51786 .79246 L F
.832 .693 .71 r
.51663 .78913 m .51873 .79157 L .51786 .79246 L F
.914 .936 .808 r
.51786 .79246 m .51874 .79127 L .51873 .79157 L F
.51874 .79127 m .52051 .7889 L .51873 .79157 L F
.915 .941 .807 r
.51875 .79128 m .51873 .79144 L .51873 .79144 L F
.51874 .79127 m .51873 .79144 L .51777 .79039 L F
.51875 .79128 m .51873 .79144 L .51874 .79127 L F
.51875 .79128 m .51777 .79039 L .51663 .78913 L F
.774 .655 .732 r
.51874 .79127 m .52071 .78972 L .51982 .78983 L F
.51786 .79246 m .51892 .79144 L .51874 .79127 L F
.51892 .79144 m .52071 .78972 L .51874 .79127 L F
.794 .708 .77 r
.51873 .79143 m .51867 .7915 L .51663 .78913 L F
.915 .941 .807 r
.51873 .79144 m .51867 .7915 L .51663 .78913 L F
.192 .542 .928 r
.51669 .79329 m .51968 .79421 L .51786 .79246 L F
.53 .662 .92 r
.44888 .67558 m .44739 .67708 L .44608 .67431 L F
.44888 .67558 m .44907 .67718 L .44739 .67708 L F
.599 .45 .65 r
.44907 .67718 m .44754 .67957 L .44739 .67708 L F
.227 .567 .938 r
.37626 .59788 m .37688 .59688 L .37491 .59655 L F
.37626 .59788 m .37847 .59841 L .37688 .59688 L F
.701 .33 .342 r
.5568 .6627 m .55356 .66414 L .5538 .66333 L F
.969 .81 .629 r
.60536 .59362 m .60478 .59039 L .60573 .59121 L F
.984 .866 .64 r
.60573 .59121 m .60478 .59039 L .60537 .58793 L F
.712 .765 .894 r
.50195 .79072 m .49807 .79034 L .50023 .78778 L F
.679 .92 .602 r
.50054 .79192 m .49936 .79374 L .50195 .79072 L F
.359 .504 .867 r
.50308 .78948 m .50195 .79072 L .50023 .78778 L F
.956 .706 .519 r
.50308 .78948 m .50054 .79192 L .50195 .79072 L F
0 0 .256 r
.52669 .60323 m .52688 .60508 L .5273 .60383 L F
.465 .175 .387 r
.40014 .61158 m .39974 .6135 L .39749 .61395 L F
.503 .208 .399 r
.40014 .61158 m .40205 .61313 L .39974 .6135 L F
.559 .186 .29 r
.40247 .6117 m .40205 .61313 L .40014 .61158 L F
.71 .573 .699 r
.30069 .6387 m .2971 .63579 L .29939 .63654 L F
.787 .949 .926 r
.52582 .76527 m .52714 .76255 L .5273 .76438 L F
.52582 .76527 m .5245 .76487 L .52714 .76255 L F
.496 .016 .047 r
.5273 .76438 m .5245 .76487 L .52582 .76527 L F
.389 .835 .934 r
.47374 .6603 m .47264 .66136 L .47544 .65967 L F
.47374 .6603 m .47185 .66087 L .47264 .66136 L F
.188 0 0 r
.33674 .64698 m .33646 .64588 L .3387 .64563 L F
.33674 .64698 m .33463 .64733 L .33646 .64588 L F
.407 0 .148 r
.33949 .64506 m .3387 .64563 L .33646 .64588 L F
.626 .687 .888 r
.7184 .50591 m .72198 .50687 L .72074 .50566 L F
.699 .949 .956 r
.72198 .50687 m .72341 .50514 L .72074 .50566 L F
.72198 .50687 m .72425 .50575 L .72341 .50514 L F
.655 .236 .238 r
.47761 .70614 m .47699 .70701 L .4738 .7069 L F
.621 .198 .217 r
.47761 .70614 m .47938 .70755 L .47699 .70701 L F
.445 .271 .55 r
.47958 .70505 m .47938 .70755 L .47761 .70614 L F
.658 .377 .482 r
.53034 .70296 m .52968 .70504 L .52714 .70449 L F
.513 .27 .484 r
.53308 .70149 m .52968 .70504 L .53034 .70296 L F
.908 .946 .816 r
.49179 .80621 m .49048 .80672 L .49259 .80485 L F
.938 .96 .665 r
.4905 .8085 m .49179 .80621 L .49267 .80754 L F
.201 .093 .499 r
.49267 .80754 m .49179 .80621 L .49259 .80485 L F
.359 .025 .256 r
.45337 .65381 m .45546 .6533 L .45629 .65093 L F
.349 .016 .252 r
.45629 .65093 m .45755 .6527 L .45851 .65031 L F
.45629 .65093 m .45546 .6533 L .45755 .6527 L F
.606 .246 .334 r
.50868 .70464 m .51156 .70482 L .51211 .70256 L F
.115 0 .174 r
.51211 .70256 m .51314 .70388 L .5144 .70195 L F
.51211 .70256 m .51156 .70482 L .51314 .70388 L F
.359 .651 .967 r
.40549 .59855 m .40392 .5987 L .40182 .59704 L F
.162 .436 .87 r
.54304 .62517 m .54375 .62397 L .54077 .62264 L F
.54304 .62517 m .54446 .6254 L .54375 .62397 L F
0 .273 .695 r
.49804 .66396 m .49849 .66398 L .4963 .66195 L F
.767 .607 .681 r
.48938 .65121 m .48925 .65389 L .49237 .65394 L F
.699 .617 .761 r
.30234 .63984 m .30604 .64208 L .30585 .64105 L F
.528 .453 .715 r
.30604 .64208 m .30737 .63975 L .30585 .64105 L F
.30604 .64208 m .30816 .64198 L .30737 .63975 L F
.486 .105 .243 r
.44229 .66121 m .44293 .65982 L .44044 .65999 L F
.489 .102 .232 r
.44229 .66121 m .44044 .65999 L .43915 .66208 L F
.599 .714 .924 r
.76607 .48569 m .76502 .48837 L .76359 .48572 L F
.76607 .48569 m .76761 .48765 L .76502 .48837 L F
0 0 0 r
.41703 .70059 m .41706 .69989 L .41438 .69901 L F
.512 .371 .625 r
.28394 .59458 m .28609 .59623 L .28635 .59395 L F
.28394 .59458 m .28392 .59691 L .28609 .59623 L F
.723 .717 .843 r
.76039 .50857 m .76195 .5045 L .75938 .5051 L F
.517 .302 .526 r
.57676 .66867 m .57587 .67082 L .57346 .67146 L F
.424 0 0 r
.57346 .67146 m .57598 .67324 L .57473 .6724 L F
.651 .105 0 r
.53107 .65122 m .53105 .65136 L .5292 .64975 L F
.34 0 .162 r
.67728 .48055 m .67902 .4814 L .67969 .4801 L F
.67728 .48055 m .67656 .48231 L .67902 .4814 L F
.899 .521 .071 r
.55354 .60753 m .55457 .60872 L .553 .60551 L F
.983 .86 .485 r
.55357 .60991 m .55457 .60872 L .55354 .60753 L F
.55357 .60991 m .55404 .61108 L .55457 .60872 L F
.776 .58 .635 r
.60094 .57467 m .6005 .57687 L .59841 .57404 L F
0 .209 .735 r
.44834 .69826 m .44935 .69898 L .44909 .69986 L F
.912 .57 .381 r
.44935 .69898 m .45166 .69955 L .44909 .69986 L F
.649 .53 .705 r
.76674 .49837 m .76737 .49992 L .765 .5008 L F
.803 .382 .248 r
.55537 .61635 m .55773 .61902 L .55889 .61788 L F
.612 .134 .094 r
.55773 .61902 m .56109 .61915 L .55889 .61788 L F
.569 .265 .413 r
.55889 .61788 m .56109 .61915 L .56155 .6173 L F
.186 .61 .944 r
.34562 .58518 m .34718 .58628 L .34363 .58485 L F
.213 .68 .942 r
.34562 .58518 m .34934 .58603 L .34718 .58628 L F
.162 0 .07 r
.7544 .52465 m .75225 .52572 L .7551 .52347 L F
.225 0 .105 r
.75665 .52448 m .7551 .52347 L .75713 .5223 L F
.75665 .52448 m .7544 .52465 L .7551 .52347 L F
.7 .428 .509 r
.60347 .55369 m .60704 .55387 L .60696 .5515 L F
.72 .444 .508 r
.60696 .5515 m .60938 .55377 L .60939 .55155 L F
.60696 .5515 m .60704 .55387 L .60938 .55377 L F
.663 .631 .807 r
.32183 .62204 m .31968 .62307 L .31829 .61977 L F
.63 .526 .717 r
.65834 .49267 m .65765 .49781 L .65972 .49738 L F
.167 0 0 r
.54129 .65769 m .5403 .65888 L .53793 .65942 L F
.643 .211 .207 r
.54129 .65769 m .54301 .65909 L .5403 .65888 L F
.42 .292 .599 r
.54303 .65626 m .54301 .65909 L .54129 .65769 L F
.54303 .65626 m .54301 .65909 L .54129 .65769 L F
.727 .614 .731 r
.47185 .67066 m .47323 .67409 L .47552 .67121 L F
.394 0 0 r
.50035 .79525 m .50157 .79425 L .49936 .79374 L F
.50035 .79525 m .49936 .79374 L .50054 .79192 L F
.684 .6 .756 r
.65089 .49672 m .65191 .49841 L .65406 .49728 L F
.701 .33 .342 r
.5568 .6627 m .55636 .66469 L .55356 .66414 L F
.491 .416 .699 r
.55851 .65914 m .55801 .66267 L .5568 .6627 L F
.927 .971 .699 r
.55801 .66267 m .55636 .66469 L .5568 .6627 L F
.957 .646 .226 r
.57205 .67108 m .57106 .66969 L .57063 .66724 L F
0 0 .383 r
.57106 .66969 m .5708 .66723 L .57063 .66724 L F
.5708 .66723 m .57069 .66613 L .57063 .66724 L F
0 .093 .63 r
.57028 .66728 m .57063 .66724 L .56868 .66533 L F
.57108 .66825 m .57063 .66724 L .57028 .66728 L F
.119 0 0 r
.70045 .46619 m .70244 .46606 L .70443 .46573 L F
.952 .802 .354 r
.60444 .59994 m .60401 .59895 L .60431 .59658 L F
1 .808 .504 r
.60444 .59994 m .60333 .60115 L .60401 .59895 L F
.60444 .59994 m .60427 .60298 L .60333 .60115 L F
.887 .865 .812 r
.68549 .49161 m .68311 .49548 L .6821 .49345 L F
.551 .594 .85 r
.50389 .79319 m .50292 .79651 L .50157 .79425 L F
.50389 .79319 m .50527 .79655 L .50292 .79651 L F
0 0 .351 r
.50377 .79881 m .50292 .79651 L .50527 .79655 L F
.813 .873 .89 r
.68076 .49725 m .67787 .49764 L .67964 .49598 L F
.694 .38 0 r
.57637 .67431 m .57712 .67653 L .57598 .67324 L F
.671 .707 .875 r
.53706 .63979 m .53347 .63919 L .53692 .63895 L F
.503 .696 .956 r
.53853 .63831 m .53706 .63979 L .53692 .63895 L F
.344 .435 .811 r
.53853 .63831 m .5405 .64194 L .53706 .63979 L F
.511 .517 .799 r
.28205 .61431 m .28281 .61058 L .28088 .61105 L F
.28205 .61431 m .28388 .61393 L .28281 .61058 L F
.731 .452 .505 r
.53012 .70097 m .53308 .70149 L .53197 .6998 L F
.634 .091 0 r
.53549 .70144 m .53197 .6998 L .53307 .70156 L F
.53549 .70144 m .53419 .70153 L .53197 .6998 L F
.402 .265 .578 r
.53197 .6998 m .53419 .70153 L .5342 .69869 L F
.213 .271 .707 r
.53308 .70149 m .53419 .70153 L .53197 .6998 L F
.533 .093 .15 r
.48309 .70616 m .48293 .70713 L .47938 .70755 L F
.647 .198 .17 r
.48309 .70616 m .48519 .70767 L .48293 .70713 L F
.417 .157 .41 r
.57246 .57164 m .57464 .57091 L .57495 .56896 L F
.395 .138 .403 r
.57495 .56896 m .57678 .57019 L .57698 .56815 L F
.57495 .56896 m .57464 .57091 L .57678 .57019 L F
.225 .745 .76 r
.31335 .58331 m .3155 .58279 L .31679 .58259 L F
.317 .794 .915 r
.3155 .58279 m .31886 .58263 L .31679 .58259 L F
.796 .751 .812 r
.26875 .66512 m .26862 .66748 L .26927 .66718 L F
.559 .227 .364 r
.26862 .66748 m .27214 .66774 L .26927 .66718 L F
.447 .112 .304 r
.55094 .66375 m .55072 .66596 L .54741 .6669 L F
.609 .247 .331 r
.55362 .66629 m .55065 .66656 L .55094 .66375 L F
.447 .112 .304 r
.55072 .66596 m .55065 .66656 L .54762 .66688 L F
.55072 .66596 m .54762 .66688 L .54741 .6669 L F
.546 .497 .753 r
.54962 .66484 m .55065 .66656 L .54741 .6669 L F
.652 .967 .816 r
.55065 .66656 m .54973 .66666 L .55023 .66632 L F
.609 .247 .331 r
.55186 .66571 m .55094 .66375 L .55026 .66518 L F
.55268 .6654 m .55094 .66375 L .55186 .66571 L F
.55176 .66599 m .55026 .66518 L .55026 .66518 L F
.652 .967 .816 r
.55065 .66656 m .55149 .66585 L .5511 .66564 L F
.377 0 0 r
.55356 .66414 m .55121 .66518 L .55094 .66375 L F
.652 .967 .816 r
.55033 .66591 m .5511 .66564 L .55026 .66518 L F
.55033 .66591 m .55026 .66518 L .54997 .66518 L F
.609 .247 .331 r
.55176 .66599 m .55026 .66518 L .55001 .66571 L F
.377 0 0 r
.55121 .66518 m .55001 .66571 L .55026 .66518 L F
.55121 .66518 m .55026 .66518 L .55094 .66375 L F
.652 .967 .816 r
.54997 .66518 m .55026 .66518 L .54986 .66497 L F
.55065 .66656 m .5511 .66564 L .55033 .66591 L F
.609 .247 .331 r
.55176 .66599 m .55026 .66518 L .55176 .66599 L F
.712 .371 .4 r
.55423 .66427 m .55164 .66544 L .55356 .66414 L F
.609 .247 .331 r
.55362 .66629 m .55026 .66518 L .55176 .66599 L F
.652 .967 .816 r
.55149 .66585 m .55169 .66568 L .54986 .66497 L F
.609 .247 .331 r
.55362 .66629 m .55268 .6654 L .55186 .66571 L F
.733 .51 .589 r
.55636 .66469 m .55176 .66599 L .55164 .66544 L F
.652 .967 .816 r
.55169 .66568 m .55183 .66556 L .55166 .66551 L F
.55169 .66568 m .55166 .66551 L .54986 .66497 L F
.733 .51 .589 r
.55636 .66469 m .55362 .66629 L .55176 .66599 L F
.55169 .66568 m .55131 .66592 L .55001 .66571 L F
.652 .967 .816 r
.55169 .66568 m .55085 .66609 L .55183 .66556 L F
.55149 .66585 m .55131 .66592 L .55169 .66568 L F
.55131 .66592 m .55085 .66609 L .55169 .66568 L F
.733 .51 .589 r
.55164 .66544 m .55169 .66568 L .55001 .66571 L F
.55169 .66568 m .55176 .66599 L .55131 .66592 L F
.712 .371 .4 r
.55164 .66544 m .55121 .66518 L .55356 .66414 L F
.652 .967 .816 r
.55183 .66556 m .55374 .66395 L .55055 .66478 L F
.55183 .66556 m .55055 .66478 L .54986 .66497 L F
.712 .371 .4 r
.55164 .66544 m .55001 .66571 L .55121 .66518 L F
.456 .877 .929 r
.55221 .66524 m .55001 .66571 L .55164 .66544 L F
.712 .371 .4 r
.55222 .66535 m .55164 .66544 L .55423 .66427 L F
.456 .877 .929 r
.55349 .66479 m .5522 .66513 L .55221 .66524 L F
.5522 .66513 m .55001 .66571 L .55221 .66524 L F
.546 .497 .753 r
.54986 .66497 m .55065 .66656 L .54962 .66484 L F
.652 .967 .816 r
.55183 .66556 m .55023 .66632 L .55218 .665 L F
.55221 .66524 m .55218 .665 L .55374 .66395 L F
.55183 .66556 m .55218 .665 L .55221 .66524 L F
.55085 .66609 m .55023 .66632 L .55183 .66556 L F
.712 .371 .4 r
.55636 .66469 m .55222 .66535 L .55423 .66427 L F
.456 .877 .929 r
.55472 .66446 m .55349 .66479 L .55342 .66516 L F
.55349 .66479 m .55164 .66544 L .55342 .66516 L F
.652 .967 .816 r
.54986 .66497 m .55374 .66395 L .54974 .66473 L F
.55065 .66656 m .55023 .66632 L .55149 .66585 L F
.546 .497 .753 r
.54974 .66473 m .54986 .66497 L .54962 .66484 L F
.456 .877 .929 r
.55544 .66456 m .55342 .66516 L .55636 .66469 L F
.55472 .66446 m .55342 .66516 L .55544 .66456 L F
.327 .711 .982 r
.30487 .6365 m .30675 .63643 L .30521 .63547 L F
.673 .974 .821 r
.30521 .63547 m .30369 .63682 L .30487 .6365 L F
.327 .711 .982 r
.30487 .6365 m .30675 .63643 L .30521 .63547 L F
.81 .905 .907 r
.71475 .47649 m .71225 .47777 L .71137 .47674 L F
0 0 .159 r
.6079 .62558 m .60698 .6279 L .60619 .62867 L F
0 0 .174 r
.60619 .62867 m .60653 .62859 L .60551 .63073 L F
.60619 .62867 m .60698 .6279 L .60653 .62859 L F
.433 .851 .958 r
.37037 .59672 m .36937 .59653 L .36704 .59714 L F
.52 .89 .971 r
.37134 .59577 m .37037 .59672 L .37401 .59674 L F
.37134 .59577 m .36937 .59653 L .37037 .59672 L F
0 0 0 r
.58068 .66267 m .58173 .66172 L .58284 .66012 L F
.409 0 .09 r
.58173 .66172 m .58513 .65982 L .58284 .66012 L F
.837 .729 .746 r
.66003 .5155 m .66367 .51352 L .66245 .51171 L F
.66003 .5155 m .66137 .51724 L .66367 .51352 L F
.877 .886 .837 r
.66441 .51165 m .66367 .51352 L .66245 .51171 L F
.168 .576 .935 r
.66367 .51352 m .66505 .51293 L .66245 .51171 L F
.746 .706 .813 r
.6593 .51257 m .66003 .5155 L .66245 .51171 L F
.6593 .51257 m .66245 .51171 L .66143 .51173 L F
.608 .069 0 r
.66245 .51171 m .66505 .51293 L .66145 .51173 L F
.66245 .51171 m .66145 .51173 L .66143 .51173 L F
.877 .886 .837 r
.66466 .511 m .66441 .51165 L .66245 .51171 L F
.168 .576 .935 r
.66367 .51352 m .66622 .51407 L .66505 .51293 L F
.96 .856 .444 r
.72712 .51037 m .72802 .50973 L .72767 .51103 L F
.76 .673 .766 r
.72682 .50518 m .72802 .50973 L .7302 .50577 L F
.59 .886 .59 r
.729 .5086 m .72802 .50973 L .72712 .51037 L F
.661 .27 .293 r
.59436 .55638 m .59772 .55653 L .5953 .55468 L F
.437 0 0 r
.4936 .61877 m .4957 .61933 L .49703 .61903 L F
.442 0 0 r
.49703 .61903 m .4957 .61933 L .49925 .61961 L F
.416 .596 .919 r
.73728 .52841 m .73887 .53072 L .74104 .53077 L F
.029 0 0 r
.75147 .52713 m .75225 .52572 L .7544 .52465 L F
.529 .331 .556 r
.41001 .60513 m .40767 .60784 L .4078 .60562 L F
0 0 .024 r
.47627 .63416 m .47422 .63718 L .47542 .63609 L F
.219 0 .33 r
.47334 .63899 m .47542 .63609 L .47422 .63718 L F
.11 0 0 r
.33024 .60329 m .32964 .60203 L .33214 .60153 L F
.33024 .60329 m .32823 .60425 L .32964 .60203 L F
.735 .626 .738 r
.47422 .66783 m .47552 .67121 L .47781 .66832 L F
.453 0 0 r
.58079 .67632 m .5797 .67735 L .57712 .67653 L F
.35 0 0 r
.58335 .67708 m .5797 .67735 L .58079 .67632 L F
.374 .565 .911 r
.44635 .69571 m .44528 .69744 L .44416 .69606 L F
.44635 .69571 m .44834 .69826 L .44528 .69744 L F
.354 .518 .881 r
.71711 .50293 m .7184 .50591 L .71975 .50433 L F
.482 .712 .971 r
.7184 .50591 m .72074 .50566 L .71975 .50433 L F
.456 .098 .267 r
.44811 .65605 m .4504 .65579 L .45094 .65423 L F
.331 0 .217 r
.45094 .65423 m .45258 .6551 L .45337 .65381 L F
.45094 .65423 m .4504 .65579 L .45258 .6551 L F
.681 .192 .081 r
.6761 .48875 m .67523 .48993 L .67275 .48808 L F
.638 .141 .054 r
.6761 .48875 m .6787 .49044 L .67523 .48993 L F
.585 .278 .414 r
.67844 .48909 m .6787 .49044 L .6761 .48875 L F
.431 .456 .785 r
.56258 .65106 m .56368 .65447 L .56554 .65261 L F
.019 .06 .563 r
.56368 .65447 m .56528 .65524 L .56554 .65261 L F
.56368 .65447 m .56418 .65666 L .56528 .65524 L F
.789 .757 .824 r
.49515 .80003 m .49709 .79875 L .49572 .79594 L F
.581 .685 .912 r
.49709 .79875 m .49794 .79571 L .49572 .79594 L F
.49709 .79875 m .50011 .79834 L .49794 .79571 L F
.392 0 0 r
.51813 .70612 m .51438 .70713 L .51575 .70613 L F
.338 0 .006 r
.51903 .70511 m .51813 .70612 L .51575 .70613 L F
.083 0 0 r
.72832 .47453 m .73099 .47379 L .72911 .47396 L F
.378 .726 .989 r
.38396 .58831 m .38333 .58941 L .38182 .58833 L F
.38396 .58831 m .38592 .58935 L .38333 .58941 L F
.739 .841 .927 r
.6745 .50947 m .67781 .50942 L .67652 .50843 L F
.261 .767 .864 r
.67985 .50818 m .67652 .50843 L .67781 .50942 L F
.758 .887 .936 r
.74046 .49317 m .74504 .49211 L .74394 .49053 L F
.578 .726 .944 r
.74504 .49211 m .74743 .49155 L .74394 .49053 L F
.569 .378 .584 r
.60162 .65102 m .60197 .65348 L .59928 .6539 L F
.507 .414 .684 r
.60329 .64808 m .60416 .65065 L .60162 .65102 L F
.359 .161 .47 r
.60416 .65065 m .60197 .65348 L .60162 .65102 L F
.556 .799 .99 r
.52625 .63689 m .52988 .63747 L .52758 .63797 L F
.55 .435 .675 r
.28005 .60549 m .28234 .60517 L .28191 .60246 L F
.492 .392 .669 r
.28065 .60858 m .28234 .60517 L .28005 .60549 L F
.564 .727 .951 r
.71242 .49389 m .71452 .49487 L .71371 .49117 L F
.714 .772 .898 r
.71766 .49116 m .71452 .49487 L .71587 .49454 L F
.686 .768 .913 r
.69666 .49291 m .70074 .49326 L .70006 .49211 L F
.559 .787 .984 r
.70074 .49326 m .70193 .49143 L .70006 .49211 L F
.70074 .49326 m .70353 .49237 L .70193 .49143 L F
.995 .762 .464 r
.62008 .57635 m .62109 .57945 L .62155 .57736 L F
.157 .698 .777 r
.36142 .59783 m .35939 .59792 L .35747 .59818 L F
.281 .778 .882 r
.36142 .59783 m .36131 .5973 L .35939 .59792 L F
.36142 .59783 m .36357 .59745 L .36131 .5973 L F
.429 .819 .589 r
.69727 .47953 m .69933 .47802 L .70112 .47974 L F
.69727 .47953 m .69718 .47958 L .69933 .47802 L F
.188 .508 .911 r
.53059 .61006 m .53134 .61141 L .53149 .61011 L F
0 .234 .751 r
.53134 .61141 m .53326 .61307 L .53149 .61011 L F
.702 .481 .586 r
.49733 .63634 m .49439 .63934 L .49443 .63792 L F
.829 .999 .827 r
.73053 .50218 m .73272 .5005 L .73159 .4995 L F
.775 .848 .906 r
.73272 .5005 m .73388 .49787 L .73159 .4995 L F
.73272 .5005 m .73478 .49926 L .73388 .49787 L F
.435 .039 .187 r
.36507 .61947 m .36737 .61918 L .3687 .61718 L F
.366 0 .146 r
.3687 .61718 m .37007 .61805 L .37091 .61666 L F
.3687 .61718 m .36737 .61918 L .37007 .61805 L F
.32 .673 .976 r
.55182 .63069 m .54838 .62963 L .55001 .6309 L F
.033 0 .401 r
.27146 .66973 m .27214 .66774 L .26862 .66748 L F
.946 .938 .752 r
.56368 .60447 m .5647 .60292 L .56306 .60346 L F
.899 .98 .801 r
.5647 .60292 m .56415 .60214 L .56306 .60346 L F
0 0 0 r
.52072 .70411 m .51903 .70511 L .52155 .70475 L F
.52072 .70411 m .51813 .70612 L .51903 .70511 L F
.388 .844 .901 r
.41793 .70573 m .41678 .70557 L .41405 .70641 L F
.76 .989 .891 r
.41843 .70413 m .41793 .70573 L .41877 .70427 L F
.41843 .70413 m .41678 .70557 L .41793 .70573 L F
.568 .363 .563 r
.52038 .70209 m .52238 .69872 L .52023 .69944 L F
.52038 .70209 m .52249 .70273 L .52238 .69872 L F
.666 .44 .568 r
.52238 .69872 m .52592 .70197 L .5261 .69963 L F
.52238 .69872 m .52249 .70273 L .52592 .70197 L F
.51 .324 .564 r
.41863 .68258 m .42075 .6845 L .4205 .68202 L F
.41863 .68258 m .41859 .68496 L .42075 .6845 L F
.348 .67 .975 r
.32678 .64823 m .3297 .64751 L .32609 .64617 L F
.465 0 .028 r
.33028 .64794 m .33149 .64877 L .32678 .64823 L F
.848 .886 .866 r
.3323 .6485 m .3302 .65043 L .32876 .64968 L F
.465 0 .028 r
.33149 .64877 m .3315 .64877 L .33149 .64877 L F
.33149 .64877 m .33149 .64877 L .32678 .64823 L F
.487 .243 .47 r
.33288 .64796 m .33246 .65 L .3302 .65043 L F
.848 .886 .866 r
.33256 .64858 m .32868 .64964 L .33254 .64861 L F
.33288 .64796 m .3323 .6485 L .33148 .64876 L F
.416 .02 .177 r
.33288 .64796 m .3315 .64877 L .33028 .64794 L F
.848 .886 .866 r
.33288 .64796 m .33148 .64876 L .33147 .64875 L F
.69 .184 .033 r
.33288 .64796 m .3297 .64751 L .33147 .64875 L F
.848 .886 .866 r
.33288 .64796 m .33147 .64875 L .33133 .64858 L F
.69 .184 .033 r
.33288 .64796 m .33147 .64875 L .3315 .64877 L F
.848 .886 .866 r
.33288 .64796 m .33133 .64858 L .33256 .64858 L F
.3323 .6485 m .32876 .64968 L .32868 .64964 L F
.348 .67 .975 r
.33149 .64877 m .3315 .64877 L .33147 .64875 L F
.848 .886 .866 r
.33133 .64858 m .33148 .64876 L .32868 .64964 L F
.33133 .64858 m .32868 .64964 L .33256 .64858 L F
.348 .67 .975 r
.32678 .64823 m .32994 .64859 L .3297 .64751 L F
.32994 .64859 m .33149 .64877 L .33122 .64858 L F
.32994 .64859 m .33122 .64858 L .3297 .64751 L F
.33149 .64877 m .33147 .64875 L .3297 .64751 L F
.417 0 0 r
.48188 .70366 m .48528 .70247 L .48146 .70299 L F
.48188 .70366 m .48391 .70386 L .48528 .70247 L F
.796 .383 .267 r
.48391 .70386 m .48676 .705 L .48528 .70247 L F
.714 .772 .898 r
.71766 .49116 m .71587 .49454 L .71875 .4919 L F
.618 .618 .829 r
.47878 .6646 m .48092 .66846 L .47781 .66832 L F
.47847 .66577 m .47781 .66832 L .47803 .66679 L F
.612 .307 .428 r
.48092 .66846 m .48006 .67021 L .47781 .66832 L F
.943 .729 .585 r
.48006 .67021 m .47803 .66679 L .47781 .66832 L F
.779 .619 .682 r
.47722 .66749 m .47841 .66977 L .47515 .66927 L F
.47803 .66679 m .47818 .66793 L .47722 .66749 L F
.47818 .66793 m .47841 .66977 L .47722 .66749 L F
.47803 .66679 m .47515 .66927 L .47502 .66662 L F
.47803 .66679 m .47502 .66662 L .4777 .66722 L F
.444 .685 .968 r
.47608 .66535 m .4777 .66722 L .47561 .66675 L F
.4751 .66652 m .47561 .66675 L .47502 .66662 L F
.47608 .66535 m .47561 .66675 L .4751 .66652 L F
.527 0 0 r
.47782 .66728 m .47803 .66679 L .4777 .66722 L F
.943 .729 .585 r
.48006 .67021 m .47841 .66977 L .47803 .66679 L F
.527 0 0 r
.47959 .66822 m .47803 .66679 L .47782 .66728 L F
.618 .618 .829 r
.47878 .6646 m .47847 .66577 L .47803 .66679 L F
0 0 0 r
.5929 .65425 m .59475 .65275 L .59466 .65278 L F
.286 .38 .785 r
.59167 .65082 m .59475 .65275 L .5929 .65425 L F
.747 .709 .816 r
.58954 .65278 m .5929 .65425 L .59268 .65344 L F
.445 .676 .962 r
.5929 .65425 m .59475 .65275 L .59268 .65344 L F
.711 .686 .824 r
.5931 .65669 m .59475 .65275 L .5929 .65425 L F
.378 .458 .816 r
.50011 .79834 m .50042 .80042 L .50151 .79818 L F
.61 .739 .937 r
.50042 .80042 m .50354 .79975 L .50151 .79818 L F
.968 .731 .525 r
.26543 .68834 m .26396 .69002 L .26439 .68643 L F
.891 .52 .052 r
.26426 .68647 m .26543 .68834 L .26439 .68643 L F
.311 .547 .916 r
.26624 .68713 m .26543 .68834 L .26426 .68647 L F
.621 .864 .506 r
.26624 .68713 m .26396 .69002 L .26543 .68834 L F
.96 .71 .515 r
.26396 .69002 m .26558 .69089 L .26543 .68834 L F
.019 .292 .787 r
.53382 .61445 m .53585 .61506 L .53326 .61307 L F
.53382 .61445 m .53624 .61634 L .53585 .61506 L F
.28 .731 .958 r
.37034 .58655 m .37267 .58642 L .37395 .58711 L F
.222 .712 .924 r
.37469 .58657 m .37395 .58711 L .37267 .58642 L F
.37469 .58657 m .3762 .58704 L .37395 .58711 L F
.493 .36 .628 r
.45906 .66757 m .45639 .66566 L .45907 .6651 L F
.45906 .66757 m .45655 .66821 L .45639 .66566 L F
.418 .537 .87 r
.33851 .58165 m .33766 .58365 L .33632 .58211 L F
.33851 .58165 m .33996 .58424 L .33766 .58365 L F
.492 .262 .493 r
.37845 .60833 m .38107 .60792 L .3811 .60545 L F
.608 .513 .721 r
.3811 .60545 m .38346 .60531 L .38252 .6021 L F
.67 .404 .51 r
.3811 .60545 m .38345 .60778 L .38346 .60531 L F
.3811 .60545 m .38107 .60792 L .38345 .60778 L F
.89 .796 .75 r
.28778 .63737 m .28727 .63966 L .28594 .63675 L F
.011 0 .103 r
.47628 .65072 m .474 .65361 L .47407 .65122 L F
.627 .688 .887 r
.32894 .62568 m .32538 .62474 L .3279 .62401 L F
.483 .639 .924 r
.32983 .62389 m .32894 .62568 L .3279 .62401 L F
.457 .607 .911 r
.32983 .62389 m .33078 .62562 L .32894 .62568 L F
.789 .757 .824 r
.49515 .80003 m .49572 .79594 L .49437 .7961 L F
.862 .801 .789 r
.41783 .6942 m .41505 .6964 L .41922 .69478 L F
.788 .738 .807 r
.54679 .77019 m .55001 .77035 L .5497 .76695 L F
.498 .313 .56 r
.36937 .59653 m .36712 .59929 L .36704 .59714 L F
.16 .698 .818 r
.35536 .59849 m .35382 .59836 L .35155 .59858 L F
.387 .827 .948 r
.35747 .59818 m .35382 .59836 L .35536 .59849 L F
.397 .824 .963 r
.34934 .58603 m .35155 .58559 L .35289 .58597 L F
.237 .716 .935 r
.35155 .58559 m .35467 .58599 L .35289 .58597 L F
.594 .593 .82 r
.72425 .50575 m .72549 .50191 L .72341 .50514 L F
.72425 .50575 m .72682 .50518 L .72549 .50191 L F
.222 0 0 r
.44457 .70859 m .44796 .70793 L .44675 .70847 L F
.36 0 0 r
.44796 .70793 m .44858 .70921 L .44675 .70847 L F
.44796 .70793 m .45029 .708 L .44858 .70921 L F
.83 .64 .647 r
.59495 .57105 m .59674 .57429 L .59373 .57358 L F
.848 .442 .267 r
.59684 .57625 m .59373 .57358 L .59674 .57429 L F
.777 .581 .634 r
.59841 .57404 m .59684 .57625 L .59674 .57429 L F
.858 .893 .86 r
.6679 .51243 m .66944 .51326 L .6717 .5108 L F
.343 .086 .373 r
.54521 .66544 m .54697 .66531 L .54769 .66255 L F
.491 .22 .43 r
.54769 .66255 m .54974 .66473 L .54976 .66194 L F
.54769 .66255 m .54697 .66531 L .54974 .66473 L F
.27 .482 .88 r
.73359 .52565 m .73533 .52821 L .73653 .5269 L F
.334 .58 .933 r
.73653 .5269 m .73533 .52821 L .73728 .52841 L F
.33 0 .111 r
.37716 .629 m .37635 .63011 L .37436 .63055 L F
.32 0 .109 r
.37943 .62847 m .37635 .63011 L .37716 .629 L F
.485 .433 .723 r
.41965 .6882 m .42006 .69136 L .42221 .69048 L F
.436 .22 .486 r
.42006 .69136 m .42234 .6928 L .42221 .69048 L F
.42006 .69136 m .41998 .69342 L .42234 .6928 L F
.457 .188 .417 r
.54017 .66089 m .53793 .65942 L .5403 .65888 L F
.54017 .66089 m .53769 .66179 L .53793 .65942 L F
.762 .499 .537 r
.57331 .64741 m .57707 .64561 L .57298 .64551 L F
.57331 .64741 m .57613 .6485 L .57707 .64561 L F
.047 .611 .782 r
.31886 .58263 m .32123 .58269 L .32257 .58286 L F
.448 .822 .992 r
.32123 .58269 m .32457 .58288 L .32257 .58286 L F
.546 .199 .332 r
.51247 .65102 m .51182 .65322 L .50903 .65353 L F
.336 .16 .489 r
.51416 .64917 m .51464 .65019 L .51247 .65102 L F
.428 .09 .289 r
.51337 .65285 m .51247 .65102 L .51464 .65019 L F
.51337 .65285 m .51182 .65322 L .51247 .65102 L F
.75 .71 .814 r
.56109 .61915 m .56098 .62312 L .56471 .61957 L F
.137 .18 .643 r
.56191 .62135 m .56098 .62312 L .56109 .61915 L F
.775 .972 .687 r
.56092 .62317 m .56098 .62312 L .56191 .62135 L F
.728 .7 .824 r
.27516 .62756 m .27634 .62958 L .27874 .62804 L F
.456 .316 .602 r
.70285 .47705 m .70112 .47974 L .69933 .47802 L F
.70285 .47705 m .70301 .47913 L .70112 .47974 L F
.683 .603 .761 r
.65089 .49672 m .65341 .49391 L .65052 .49449 L F
.65089 .49672 m .65406 .49728 L .65341 .49391 L F
.629 .511 .7 r
.75334 .50309 m .75574 .50232 L .75563 .50013 L F
.75334 .50309 m .75574 .50232 L .75563 .50013 L F
.268 .19 .58 r
.55404 .61108 m .55507 .6137 L .55352 .61259 L F
.929 .564 .304 r
.55264 .6153 m .55427 .61618 L .55352 .61259 L F
.927 .563 .309 r
.55352 .61259 m .55427 .61618 L .55537 .61635 L F
.929 .564 .304 r
.55264 .6153 m .55352 .61259 L .55507 .6137 L F
.34 .196 .536 r
.60956 .62272 m .6096 .62522 L .6079 .62558 L F
.247 .003 .333 r
.6096 .62522 m .60698 .6279 L .6079 .62558 L F
0 .48 .763 r
.7498 .51004 m .75139 .51053 L .75019 .51021 L F
.7498 .51004 m .75019 .51021 L .74814 .50967 L F
0 .525 .836 r
.74847 .50941 m .7498 .51004 L .74814 .50967 L F
.34 0 0 r
.74921 .50978 m .7498 .51004 L .74847 .50941 L F
.723 .795 .909 r
.75245 .51078 m .74887 .51102 L .75139 .51053 L F
.74 .251 .076 r
.75367 .51276 m .7544 .51148 L .75139 .51053 L F
.55 .756 .973 r
.75139 .51053 m .74887 .51102 L .74814 .50967 L F
0 .074 .601 r
.75274 .51155 m .75367 .51276 L .75139 .51053 L F
.34 0 0 r
.75274 .51155 m .7498 .51004 L .74921 .50978 L F
0 .074 .601 r
.75023 .51026 m .75139 .51053 L .7498 .51004 L F
.75274 .51155 m .75139 .51053 L .75023 .51026 L F
.723 .795 .909 r
.75273 .51077 m .75245 .51078 L .75139 .51053 L F
.457 0 0 r
.75139 .51053 m .7544 .51148 L .75273 .51077 L F
.208 0 0 r
.36249 .63798 m .36394 .63647 L .3661 .63591 L F
0 0 0 r
.47901 .63164 m .47791 .63323 L .48044 .63047 L F
.576 .51 .744 r
.7685 .49376 m .76674 .49837 L .76639 .49422 L F
.96 .726 .54 r
.47796 .70441 m .47961 .70225 L .47624 .70168 L F
.47796 .70441 m .47958 .70505 L .47961 .70225 L F
.527 .361 .6 r
.47958 .70505 m .48188 .70366 L .47961 .70225 L F
.634 .101 0 r
.47961 .70225 m .48188 .70366 L .48146 .70299 L F
.527 .361 .6 r
.47958 .70505 m .48188 .70366 L .47961 .70225 L F
.492 .392 .669 r
.28065 .60858 m .28253 .60804 L .28234 .60517 L F
.469 .346 .629 r
.28088 .61105 m .28253 .60804 L .28065 .60858 L F
.332 .019 .275 r
.58643 .63636 m .58842 .63598 L .58844 .6343 L F
.44 .288 .578 r
.58844 .6343 m .59114 .63341 L .59108 .63072 L F
.642 .455 .615 r
.58842 .63598 m .59114 .63341 L .58844 .6343 L F
.699 .272 .229 r
.57711 .6621 m .57926 .66421 L .58068 .66267 L F
.494 .243 .462 r
.57926 .66421 m .58173 .66172 L .58068 .66267 L F
.299 0 0 r
.29354 .59072 m .2956 .59042 L .29709 .58877 L F
.379 0 .078 r
.2956 .59042 m .2993 .58839 L .29709 .58877 L F
.16 0 .194 r
.47542 .63609 m .47791 .63323 L .47627 .63416 L F
.285 0 .231 r
.57197 .57318 m .57246 .57164 L .56979 .57405 L F
.474 .186 .395 r
.57197 .57318 m .57464 .57091 L .57246 .57164 L F
.442 .524 .847 r
.40048 .59387 m .39985 .59689 L .39825 .59423 L F
.40048 .59387 m .40182 .59704 L .39985 .59689 L F
.538 .622 .884 r
.21005 .55897 m .21226 .55881 L .21069 .56001 L F
.76 .714 .809 r
.21226 .55881 m .21091 .56262 L .21069 .56001 L F
.489 .329 .59 r
.60372 .63377 m .60389 .63608 L .60151 .63656 L F
.478 .367 .649 r
.60389 .63608 m .60136 .63977 L .60151 .63656 L F
.577 .249 .377 r
.65752 .48524 m .66003 .48505 L .65973 .48328 L F
.698 .418 .497 r
.66003 .48505 m .66225 .4831 L .65973 .48328 L F
0 0 0 r
.61342 .6135 m .61424 .6118 L .61548 .61046 L F
0 0 .062 r
.56912 .59014 m .5675 .59349 L .5679 .59137 L F
.895 .899 .484 r
.60257 .60999 m .60349 .60771 L .60376 .60805 L F
.892 .908 .503 r
.60376 .60805 m .60349 .60771 L .60472 .60449 L F
.535 .845 .999 r
.68219 .50753 m .67985 .50818 L .67938 .50856 L F
.417 .198 .472 r
.69355 .47665 m .69124 .47955 L .69139 .47745 L F
.607 .331 .472 r
.5261 .69963 m .52592 .70197 L .52838 .70156 L F
.682 .287 .292 r
.5261 .69963 m .52838 .70156 L .53012 .70097 L F
.478 .367 .649 r
.60389 .63608 m .60441 .63871 L .60136 .63977 L F
.471 .347 .63 r
.60136 .63977 m .60408 .64177 L .602 .64227 L F
.60136 .63977 m .60441 .63871 L .60408 .64177 L F
.251 .151 .542 r
.59083 .62832 m .59267 .63 L .5928 .62772 L F
.59083 .62832 m .59108 .63072 L .59267 .63 L F
.801 .58 .602 r
.68549 .49161 m .68208 .49104 L .68177 .48806 L F
.887 .865 .812 r
.68549 .49161 m .6821 .49345 L .68208 .49104 L F
.394 .33 .667 r
.56191 .62135 m .56011 .62529 L .56092 .62317 L F
.593 .406 .598 r
.54521 .66544 m .54741 .6669 L .54697 .66531 L F
.54521 .66544 m .54547 .66801 L .54741 .6669 L F
.54741 .6669 m .54547 .66801 L .54521 .66544 L F
.502 .25 .465 r
.37845 .60833 m .38079 .60925 L .38107 .60792 L F
.37845 .60833 m .3784 .61068 L .38079 .60925 L F
.576 .51 .744 r
.7685 .49376 m .76982 .49793 L .76674 .49837 L F
.595 .502 .719 r
.76986 .49912 m .76674 .49837 L .76982 .49793 L F
.76986 .49912 m .76737 .49992 L .76674 .49837 L F
.549 .34 .549 r
.76762 .51443 m .7677 .51669 L .76522 .51716 L F
.614 .531 .737 r
.76931 .51064 m .77022 .51399 L .76762 .51443 L F
.605 .383 .553 r
.77033 .51634 m .76762 .51443 L .77022 .51399 L F
.77033 .51634 m .7677 .51669 L .76762 .51443 L F
.627 .47 .65 r
.65259 .49141 m .65052 .49449 L .65341 .49391 L F
0 0 .023 r
.65259 .49141 m .65429 .48848 L .65449 .48779 L F
.65259 .49141 m .65404 .48973 L .65429 .48848 L F
.158 .211 .668 r
.65259 .49141 m .6546 .49396 L .65404 .48973 L F
.23 .234 .656 r
.65341 .49391 m .6546 .49396 L .65259 .49141 L F
.313 0 0 r
.35384 .62629 m .35771 .62463 L .35547 .62515 L F
.614 .701 .906 r
.5343 .63593 m .53347 .63919 L .53225 .63682 L F
.5343 .63593 m .53692 .63895 L .53347 .63919 L F
.559 .377 .591 r
.44905 .67053 m .44936 .67508 L .44608 .67431 L F
.565 .345 .539 r
.44936 .67508 m .44888 .67558 L .44608 .67431 L F
.507 .307 .544 r
.4691 .64248 m .47132 .64195 L .47137 .63972 L F
.33 0 .234 r
.46841 .64482 m .47132 .64195 L .4691 .64248 L F
.768 .661 .744 r
.56109 .61915 m .56346 .61628 L .56155 .6173 L F
.265 .532 .916 r
.49521 .66902 m .49748 .67008 L .49655 .67076 L F
.307 .611 .954 r
.49748 .67008 m .49904 .67174 L .49655 .67076 L F
.49748 .67008 m .49904 .67174 L .49655 .67076 L F
0 0 .009 r
.49748 .67008 m .49566 .67332 L .49655 .67076 L F
.681 .656 .819 r
.58708 .63955 m .59005 .64007 L .58945 .63909 L F
.491 .57 .863 r
.59005 .64007 m .59207 .63888 L .58945 .63909 L F
0 0 .227 r
.59067 .64249 m .59207 .63888 L .59005 .64007 L F
.519 .536 .813 r
.28591 .61938 m .28673 .61595 L .28497 .61737 L F
.28591 .61938 m .28813 .61916 L .28673 .61595 L F
.231 .004 .348 r
.3634 .61983 m .36457 .62126 L .36507 .61947 L F
.3634 .61983 m .36292 .62214 L .36457 .62126 L F
.594 .615 .842 r
.3279 .62401 m .32538 .62474 L .32419 .62164 L F
.374 .477 .836 r
.54446 .6254 m .54557 .62861 L .54725 .62691 L F
.6 .395 .575 r
.54557 .62861 m .54838 .62963 L .54725 .62691 L F
.54557 .62861 m .54612 .63074 L .54838 .62963 L F
.251 .213 .619 r
.65778 .51314 m .65849 .51064 L .65738 .51362 L F
.387 .465 .818 r
.65738 .51362 m .6593 .51257 L .65778 .51314 L F
.65738 .51362 m .66003 .5155 L .6593 .51257 L F
.607 .565 .781 r
.65738 .51362 m .66137 .51724 L .66003 .5155 L F
.398 .131 .388 r
.32154 .60799 m .31884 .61077 L .31912 .6084 L F
.351 .776 .973 r
.34734 .59926 m .34808 .59864 L .34588 .59897 L F
.34734 .59926 m .34941 .59923 L .34808 .59864 L F
.397 .596 .926 r
.65406 .49728 m .6546 .49396 L .65341 .49391 L F
.65406 .49728 m .65538 .49561 L .6546 .49396 L F
.514 .343 .587 r
.42189 .67101 m .42405 .67058 L .42403 .66812 L F
.521 .389 .642 r
.42189 .67101 m .42437 .67317 L .42405 .67058 L F
.42189 .67101 m .42218 .67374 L .42437 .67317 L F
.341 .813 .744 r
.73952 .4728 m .73929 .47308 L .73778 .47366 L F
.335 .695 .981 r
.74174 .47193 m .73929 .47308 L .73952 .4728 L F
.812 .698 .739 r
.52089 .66493 m .52214 .6682 L .52315 .66607 L F
.536 .37 .603 r
.52315 .66607 m .52443 .66775 L .52214 .6682 L F
.52315 .66607 m .52443 .66775 L .52214 .6682 L F
.331 .123 .44 r
.57767 .65068 m .57735 .65345 L .57517 .65399 L F
.491 .359 .628 r
.57774 .65584 m .57517 .65399 L .57735 .65345 L F
.57774 .65584 m .57562 .65647 L .57517 .65399 L F
.892 .797 .749 r
.41706 .69989 m .41906 .69828 L .41922 .69478 L F
0 0 0 r
.41703 .70059 m .41906 .69828 L .41706 .69989 L F
.37 .492 .852 r
.41906 .69828 m .41999 .69759 L .41922 .69478 L F
.41906 .69828 m .4209 .69839 L .41999 .69759 L F
.305 0 0 r
.41923 .69986 m .41906 .69828 L .41703 .70059 L F
.41923 .69986 m .4209 .69839 L .41906 .69828 L F
.729 .923 .957 r
.69511 .49171 m .69368 .49413 L .69666 .49291 L F
.69511 .49171 m .69337 .49297 L .69368 .49413 L F
.693 .545 .681 r
.51547 .65499 m .51675 .65569 L .51612 .65399 L F
.102 .29 .768 r
.51612 .65399 m .51838 .65595 L .51694 .65254 L F
.313 .329 .717 r
.51675 .65569 m .51838 .65595 L .51612 .65399 L F
.496 .359 .624 r
.42403 .66812 m .42613 .66508 L .42375 .66568 L F
.397 .231 .537 r
.61198 .61911 m .60956 .62272 L .60967 .62022 L F
0 0 .234 r
.27707 .64648 m .27675 .64813 L .2765 .64552 L F
.27707 .64648 m .2765 .64552 L .27447 .64614 L F
.532 .651 .911 r
.76152 .48553 m .7575 .48353 L .76125 .48415 L F
.424 .609 .925 r
.76291 .48391 m .76152 .48553 L .76125 .48415 L F
.41 .587 .914 r
.76359 .48572 m .76152 .48553 L .76291 .48391 L F
.341 .813 .744 r
.73952 .4728 m .73778 .47366 L .73685 .4732 L F
.899 .521 .071 r
.55354 .60753 m .553 .60551 L .55527 .60538 L F
.511 .225 .418 r
.57698 .56815 m .57938 .56773 L .58 .56522 L F
.539 .265 .449 r
.57938 .56773 m .58234 .56493 L .58 .56522 L F
.484 .295 .547 r
.49882 .6428 m .50101 .64228 L .501 .63973 L F
0 0 0 r
.49875 .64471 m .50101 .64228 L .49882 .6428 L F
.215 .676 .945 r
.50633 .62525 m .50741 .62474 L .50872 .62548 L F
.499 0 0 r
.50741 .62474 m .50812 .62535 L .50872 .62548 L F
.50812 .62535 m .51045 .62734 L .50872 .62548 L F
0 .553 .753 r
.50922 .62558 m .50872 .62548 L .50987 .62566 L F
.50633 .62525 m .50872 .62548 L .50922 .62558 L F
.754 .263 .065 r
.50872 .62548 m .512 .62746 L .50987 .62566 L F
.592 .031 0 r
.50987 .62566 m .512 .62746 L .51358 .62828 L F
.464 .306 .581 r
.45119 .67251 m .44905 .67053 L .45107 .67054 L F
.45119 .67251 m .44936 .67508 L .44905 .67053 L F
0 0 .161 r
.7311 .51989 m .73154 .51969 L .7316 .51619 L F
0 .003 .56 r
.7311 .51989 m .73234 .5204 L .73154 .51969 L F
.7311 .51989 m .73257 .5225 L .73234 .5204 L F
.553 .822 .996 r
.76639 .50869 m .76766 .50709 L .76768 .507 L F
.767 .65 .734 r
.5451 .65363 m .54664 .6567 L .54303 .65626 L F
.697 .516 .64 r
.54735 .65879 m .54303 .65626 L .54664 .6567 L F
.593 .345 .509 r
.54664 .6567 m .54886 .65864 L .54735 .65879 L F
.29 .636 .965 r
.37401 .59674 m .37356 .59526 L .37134 .59577 L F
.37401 .59674 m .37491 .59655 L .37356 .59526 L F
.093 0 0 r
.5907 .67312 m .58741 .67487 L .58868 .67382 L F
.699 .655 .803 r
.71232 .46996 m .71458 .47323 L .71272 .4742 L F
.71132 .47407 m .71272 .4742 L .71109 .47504 L F
.672 .471 .605 r
.71161 .47346 m .70955 .47292 L .70769 .47373 L F
.71161 .47346 m .70769 .47373 L .7083 .47379 L F
.503 .531 .819 r
.70993 .46937 m .71232 .46996 L .71161 .47346 L F
.699 .655 .803 r
.71232 .46996 m .71109 .47504 L .71161 .47346 L F
.71232 .46996 m .71272 .4742 L .71132 .47407 L F
.672 .471 .605 r
.7083 .47379 m .70769 .47373 L .70734 .47389 L F
.61 .905 .621 r
.49045 .64996 m .48938 .65121 L .49143 .64917 L F
.58 .55 .785 r
.49045 .64996 m .48925 .65389 L .48938 .65121 L F
.568 .699 .93 r
.39721 .59234 m .39617 .59441 L .39496 .59272 L F
.505 .622 .901 r
.39721 .59234 m .39825 .59423 L .39617 .59441 L F
.223 0 .346 r
.47132 .64195 m .47334 .63899 L .47137 .63972 L F
.455 .313 .597 r
.28191 .60246 m .28371 .59944 L .28167 .6 L F
.636 .307 .398 r
.44754 .67957 m .44659 .68219 L .44398 .68173 L F
.684 .358 .417 r
.44993 .68194 m .44659 .68219 L .44754 .67957 L F
.614 .469 .661 r
.44907 .67718 m .4501 .67935 L .44754 .67957 L F
.594 .372 .549 r
.4501 .67935 m .44993 .68194 L .44754 .67957 L F
.477 .555 .857 r
.58945 .63909 m .58643 .63636 L .58708 .63955 L F
.518 .415 .677 r
.49319 .79408 m .49572 .79594 L .49565 .79189 L F
.941 .963 .721 r
.65538 .49561 m .65834 .49267 L .65794 .49533 L F
.131 .111 .566 r
.65967 .49066 m .65834 .49267 L .65834 .4911 L F
.309 0 .192 r
.66006 .4946 m .65834 .49267 L .65967 .49066 L F
.66006 .4946 m .65794 .49533 L .65834 .49267 L F
.858 .893 .86 r
.6679 .51243 m .6717 .5108 L .67046 .50979 L F
.687 .869 .968 r
.67046 .50979 m .6717 .5108 L .6745 .50947 L F
.989 .773 .52 r
.51209 .62992 m .51358 .62828 L .512 .62746 L F
.51209 .62992 m .51329 .63111 L .51358 .62828 L F
.415 .174 .437 r
.40767 .60784 m .40512 .61062 L .40543 .60849 L F
.448 .849 .974 r
.44043 .70988 m .44046 .70913 L .43989 .71051 L F
.44043 .70988 m .44139 .70969 L .44046 .70913 L F
.666 .594 .766 r
.57711 .6621 m .57453 .66279 L .57338 .65942 L F
.808 .613 .638 r
.61449 .55935 m .61773 .55985 L .61626 .557 L F
.803 .527 .52 r
.61449 .55935 m .61649 .56194 L .61773 .55985 L F
.61649 .56194 m .61798 .56248 L .61773 .55985 L F
0 0 .278 r
.50111 .66804 m .50174 .67008 L .50167 .67045 L F
.54 .92 .787 r
.50174 .67008 m .50078 .67067 L .50167 .67045 L F
.795 .548 .563 r
.61286 .55422 m .61287 .55657 L .61626 .557 L F
.798 .597 .63 r
.61287 .55657 m .61449 .55935 L .61626 .557 L F
.495 .208 .407 r
.44505 .65918 m .44811 .65605 L .4453 .65701 L F
.76 .714 .809 r
.21226 .55881 m .21334 .56205 L .21091 .56262 L F
.462 .882 .775 r
.21334 .56205 m .20965 .56362 L .21091 .56262 L F
.21334 .56205 m .21248 .56219 L .20965 .56362 L F
0 0 .329 r
.21276 .5597 m .21334 .56205 L .21226 .55881 L F
.952 .931 .59 r
.21276 .5597 m .21248 .56219 L .21334 .56205 L F
.438 .253 .531 r
.28392 .59691 m .28553 .59886 L .28609 .59623 L F
.28392 .59691 m .28371 .59944 L .28553 .59886 L F
.607 .593 .811 r
.77166 .50218 m .76737 .49992 L .76986 .49912 L F
.005 0 .302 r
.65964 .48865 m .65834 .4911 L .6611 .48761 L F
.65964 .48865 m .65996 .48992 L .65834 .4911 L F
.131 .111 .566 r
.65967 .49066 m .65834 .4911 L .65996 .48992 L F
0 0 .326 r
.60207 .61376 m .60257 .60999 L .60147 .6114 L F
.835 .679 .69 r
.61798 .56248 m .61767 .56492 L .62078 .56544 L F
.821 .616 .625 r
.61773 .56735 m .62078 .56544 L .61767 .56492 L F
.61773 .56735 m .61923 .56808 L .62078 .56544 L F
.45 .477 .795 r
.28388 .61393 m .28497 .61737 L .28673 .61595 L F
.569 .49 .727 r
.54503 .77147 m .54679 .77019 L .54538 .7689 L F
.714 .819 .93 r
.54503 .77147 m .54679 .77019 L .54331 .77007 L F
.448 .469 .788 r
.41859 .68496 m .41965 .6882 L .42137 .68782 L F
.441 .428 .748 r
.41965 .6882 m .42221 .69048 L .42137 .68782 L F
.534 0 0 r
.46304 .69874 m .46505 .69998 L .46629 .69978 L F
0 .363 .816 r
.46797 .70002 m .46629 .69978 L .46505 .69998 L F
.46797 .70002 m .46863 .70088 L .46629 .69978 L F
0 0 0 r
.34064 .64472 m .33949 .64506 L .34194 .64436 L F
.34064 .64472 m .3387 .64563 L .33949 .64506 L F
.404 .383 .722 r
.68761 .47443 m .69005 .4757 L .69107 .47471 L F
.988 .717 .398 r
.69236 .47524 m .69107 .47471 L .69005 .4757 L F
.69236 .47524 m .69345 .47433 L .69107 .47471 L F
.481 .408 .697 r
.4905 .70413 m .49144 .70611 L .49424 .70505 L F
.569 .272 .425 r
.46324 .64744 m .46623 .64535 L .46389 .646 L F
.463 .216 .454 r
.39749 .61395 m .39716 .61611 L .39497 .61663 L F
.494 .244 .464 r
.39974 .6135 m .39716 .61611 L .39749 .61395 L F
.77 .633 .71 r
.49956 .76744 m .49969 .76949 L .50142 .76751 L F
.093 .122 .6 r
.5656 .66207 m .56633 .65865 L .56454 .65863 L F
.5656 .66207 m .56689 .66067 L .56633 .65865 L F
.279 .413 .819 r
.5656 .66207 m .56711 .66246 L .56689 .66067 L F
.6 .295 .425 r
.76522 .51716 m .76782 .51889 L .76582 .51864 L F
.546 .331 .54 r
.7677 .51669 m .76782 .51889 L .76522 .51716 L F
.928 .964 .664 r
.42014 .70251 m .41843 .70413 L .41877 .70427 L F
0 0 .308 r
.42114 .70158 m .42106 .70136 L .41923 .69986 L F
.42156 .70197 m .42197 .70369 L .42106 .70136 L F
.42156 .70197 m .42106 .70136 L .42114 .70158 L F
0 0 0 r
.42106 .70136 m .42014 .70251 L .42102 .70125 L F
.42106 .70136 m .42102 .70125 L .42212 .6997 L F
.861 .972 .657 r
.41987 .7026 m .42014 .70251 L .42106 .70136 L F
.41987 .7026 m .41843 .70413 L .42014 .70251 L F
.732 .725 .845 r
.70635 .47978 m .7041 .48078 L .70301 .47913 L F
.995 .762 .464 r
.62008 .57635 m .61992 .5787 L .62109 .57945 L F
.991 .755 .476 r
.61994 .57967 m .62109 .57945 L .61992 .5787 L F
.61994 .57967 m .62092 .58167 L .62109 .57945 L F
.404 .383 .722 r
.68761 .47443 m .68872 .47731 L .69005 .4757 L F
.741 .275 .142 r
.45107 .67054 m .45429 .67148 L .45304 .67256 L F
.117 0 0 r
.45304 .67256 m .45429 .67148 L .4569 .67082 L F
.498 .294 .534 r
.50101 .64228 m .50334 .6393 L .501 .63973 L F
.473 0 0 r
.7062 .46813 m .70993 .46937 L .70745 .46979 L F
.825 .85 .866 r
.28792 .63473 m .28594 .63675 L .28778 .63737 L F
.289 .789 .83 r
.33831 .6009 m .33625 .60103 L .33412 .60156 L F
.416 .864 .876 r
.33838 .60028 m .33831 .6009 L .34001 .60044 L F
.33838 .60028 m .33625 .60103 L .33831 .6009 L F
.765 .833 .904 r
.43123 .70663 m .42918 .70774 L .4326 .70772 L F
.614 .8 .97 r
.43123 .70663 m .4326 .70772 L .43554 .70712 L F
0 .092 .65 r
.47325 .65531 m .47161 .65401 L .474 .65361 L F
.47325 .65531 m .47347 .65646 L .47161 .65401 L F
.821 .699 .73 r
.49484 .6419 m .49296 .64496 L .49454 .6449 L F
.49484 .6419 m .49454 .6449 L .49454 .64489 L F
.821 .698 .729 r
.49451 .64517 m .49372 .64372 L .49454 .64489 L F
.49454 .64489 m .49372 .64372 L .49484 .6419 L F
.821 .699 .73 r
.49484 .6419 m .49454 .64489 L .49343 .64192 L F
.495 .42 .701 r
.49454 .6449 m .49454 .6449 L .49454 .6449 L F
.237 .45 .865 r
.49454 .64489 m .49454 .6449 L .49454 .6449 L F
.821 .698 .729 r
.49632 .64541 m .49451 .64517 L .49484 .6419 L F
.596 .59 .815 r
.49875 .64471 m .49632 .64541 L .49484 .6419 L F
.237 .45 .865 r
.49343 .64192 m .49454 .64489 L .49578 .64295 L F
.49454 .64489 m .49454 .6449 L .49578 .64295 L F
.495 .42 .701 r
.49409 .64542 m .49578 .64295 L .49454 .6449 L F
.821 .698 .729 r
.49436 .64515 m .49296 .64496 L .49444 .64504 L F
.13 0 .39 r
.49296 .64496 m .49409 .64542 L .49454 .6449 L F
.495 .42 .701 r
.49409 .64542 m .49454 .6449 L .49454 .6449 L F
.821 .698 .729 r
.49444 .64504 m .49296 .64496 L .49372 .64372 L F
.49451 .64517 m .49436 .64515 L .49444 .64504 L F
.588 .877 .567 r
.49875 .64471 m .49603 .6476 L .49632 .64541 L F
.134 .651 .89 r
.35467 .58599 m .35713 .58611 L .35894 .58675 L F
.325 .78 .951 r
.35713 .58611 m .36105 .58629 L .35894 .58675 L F
.315 .768 .955 r
.27675 .64813 m .27261 .64785 L .27446 .64875 L F
.288 .611 .955 r
.33892 .62753 m .33814 .6287 L .33684 .62746 L F
.33892 .62753 m .34025 .62888 L .33814 .6287 L F
.718 .483 .57 r
.61066 .55672 m .61286 .55422 L .60938 .55377 L F
.61066 .55672 m .61287 .55657 L .61286 .55422 L F
.777 .581 .634 r
.59841 .57404 m .6005 .57687 L .59684 .57625 L F
.62 .767 .95 r
.4209 .69839 m .42212 .6997 L .42443 .69909 L F
.975 .738 .516 r
.4209 .69839 m .42106 .70136 L .42212 .6997 L F
.896 .988 .767 r
.62151 .58825 m .62219 .58755 L .62155 .58491 L F
.59 .886 .59 r
.729 .5086 m .72712 .51037 L .72916 .50705 L F
.834 .763 .783 r
.72916 .50705 m .72712 .51037 L .72636 .50808 L F
.76 .673 .766 r
.72682 .50518 m .72907 .50557 L .72916 .50705 L F
0 .216 .732 r
.72682 .50518 m .72916 .50705 L .72868 .50601 L F
.834 .763 .783 r
.72916 .50705 m .72636 .50808 L .72868 .50601 L F
.988 .737 .456 r
.72868 .50601 m .72922 .50804 L .72916 .50705 L F
0 .289 .668 r
.7294 .50873 m .729 .5086 L .72916 .50705 L F
.988 .737 .456 r
.72922 .50804 m .7294 .50873 L .72916 .50705 L F
.76 .673 .766 r
.72907 .50557 m .7302 .50577 L .72916 .50705 L F
0 0 .383 r
.7302 .50577 m .73053 .50218 L .72969 .50482 L F
.979 .864 .484 r
.72916 .50705 m .7302 .50577 L .72969 .50482 L F
.284 0 .001 r
.30159 .58804 m .30375 .58759 L .30526 .58582 L F
.304 0 .061 r
.30375 .58759 m .3073 .58517 L .30526 .58582 L F
.278 0 .176 r
.5669 .5763 m .56902 .57612 L .56979 .57405 L F
.311 .009 .281 r
.5713 .5756 m .56979 .57405 L .56902 .57612 L F
.5713 .5756 m .57197 .57318 L .56979 .57405 L F
.337 .759 .976 r
.32457 .58288 m .32676 .58272 L .3285 .58345 L F
.123 .664 .84 r
.32676 .58272 m .33057 .58296 L .3285 .58345 L F
.836 .451 0 r
.553 .6532 m .55464 .65637 L .55377 .6542 L F
0 0 0 r
.57123 .58926 m .57068 .58922 L .57307 .5872 L F
0 .3 .723 r
.45035 .67764 m .44907 .67718 L .44888 .67558 L F
.751 .861 .93 r
.4522 .67581 m .45157 .67798 L .45035 .67764 L F
.109 .175 .651 r
.45406 .67617 m .45157 .67798 L .4522 .67581 L F
.052 0 .123 r
.45215 .67742 m .45035 .67764 L .45157 .67798 L F
.45215 .67742 m .45147 .67804 L .45035 .67764 L F
0 .3 .723 r
.45035 .67764 m .45208 .6788 L .44911 .6772 L F
.51 .419 .689 r
.45208 .6788 m .4501 .67935 L .44907 .67718 L F
.452 .254 .52 r
.45208 .6788 m .44993 .68194 L .4501 .67935 L F
.885 .86 .81 r
.45066 .67807 m .44993 .68194 L .45208 .6788 L F
.316 .8 .758 r
.44993 .68194 m .44594 .68314 L .44659 .68219 L F
.928 .901 .779 r
.45066 .67807 m .44706 .68272 L .44993 .68194 L F
.885 .86 .81 r
.45066 .67807 m .45208 .6788 L .45035 .67764 L F
.93 .763 .653 r
.44963 .67905 m .45066 .67807 L .45035 .67764 L F
.927 .967 .768 r
.44939 .67938 m .44706 .68272 L .45066 .67807 L F
.44677 .68208 m .44702 .68263 L .44939 .67938 L F
.44702 .68263 m .44706 .68272 L .44939 .67938 L F
.93 .763 .653 r
.44904 .68024 m .45066 .67807 L .44963 .67905 L F
.052 0 .123 r
.45147 .67804 m .44904 .68024 L .44965 .67903 L F
.45059 .67773 m .44965 .67903 L .45035 .67764 L F
.45147 .67804 m .44965 .67903 L .45059 .67773 L F
.927 .967 .768 r
.44718 .68139 m .45066 .67807 L .44776 .68043 L F
.44677 .68208 m .45066 .67807 L .44718 .68139 L F
0 .3 .723 r
.45035 .67764 m .44911 .6772 L .44907 .67718 L F
.538 .219 .375 r
.6854 .47924 m .68872 .47731 L .68607 .47867 L F
.383 .387 .74 r
.26986 .83205 m .27156 .83297 L .27023 .83345 L F
0 0 0 r
.27023 .83345 m .27156 .83297 L .26974 .83376 L F
.61548 .61046 m .61638 .60869 L .61775 .60669 L F
0 .048 .587 r
.71483 .47314 m .71454 .47495 L .71458 .47323 L F
.677 .81 .946 r
.71685 .47396 m .71454 .47495 L .71483 .47314 L F
.711 .544 .662 r
.59185 .57106 m .58991 .57382 L .59003 .5714 L F
.513 .371 .625 r
.59761 .61965 m .59992 .61907 L .59959 .61663 L F
.503 .352 .609 r
.59774 .62222 m .59992 .61907 L .59761 .61965 L F
0 0 0 r
.6973 .46755 m .70045 .46619 L .69773 .46741 L F
.6973 .46755 m .69953 .46693 L .70045 .46619 L F
.321 .803 .752 r
.69953 .46693 m .70244 .46606 L .70045 .46619 L F
.946 .938 .752 r
.56368 .60447 m .56306 .60346 L .56086 .60478 L F
.721 .565 .677 r
.56086 .60478 m .56217 .60811 L .56368 .60447 L F
.209 .358 .795 r
.55182 .63069 m .55322 .63394 L .55431 .63258 L F
.242 .407 .827 r
.55322 .63394 m .55568 .63548 L .55431 .63258 L F
.759 .551 .616 r
.59185 .57106 m .59495 .57105 L .59373 .57358 L F
.909 .943 .585 r
.52293 .66006 m .52172 .66149 L .52259 .65975 L F
0 0 .054 r
.52172 .66149 m .52283 .65996 L .52259 .65975 L F
.768 .995 .802 r
.52293 .66006 m .52259 .65975 L .52442 .65776 L F
.52293 .66006 m .52259 .65975 L .52442 .65776 L F
0 0 .054 r
.52283 .65996 m .52442 .65776 L .52259 .65975 L F
0 .052 .532 r
.52199 .65923 m .52259 .65975 L .52055 .65795 L F
.52293 .66006 m .52259 .65975 L .52199 .65923 L F
.627 .198 .208 r
.52546 .66159 m .52293 .66006 L .5256 .65924 L F
.52546 .66159 m .52172 .66149 L .52293 .66006 L F
.672 .777 .929 r
.67231 .50204 m .66906 .50152 L .6722 .50005 L F
.808 .853 .883 r
.67509 .49977 m .67231 .50204 L .6722 .50005 L F
.09 .648 .771 r
.33057 .58296 m .33298 .58284 L .33424 .58288 L F
.38 0 0 r
.33298 .58284 m .33632 .58211 L .33424 .58288 L F
.885 .457 .151 r
.30099 .75022 m .30243 .7507 L .30262 .75079 L F
.30099 .75022 m .30243 .7507 L .30262 .75079 L F
.222 .578 .943 r
.31536 .64526 m .31575 .64404 L .31361 .64474 L F
.31536 .64526 m .31726 .64549 L .31575 .64404 L F
.497 .781 .995 r
.59191 .64819 m .59563 .64852 L .59351 .64693 L F
.306 0 0 r
.59649 .646 m .59351 .64693 L .59563 .64852 L F
.098 0 0 r
.35108 .64163 m .34944 .64171 L .35283 .64064 L F
.071 0 0 r
.35498 .64005 m .35108 .64163 L .35283 .64064 L F
.682 .945 .671 r
.54717 .59196 m .54477 .5944 L .54606 .59291 L F
0 0 0 r
.54606 .59291 m .54917 .59096 L .54717 .59196 L F
.788 .571 .606 r
.68177 .48806 m .6787 .49044 L .67844 .48909 L F
.68177 .48806 m .68208 .49104 L .6787 .49044 L F
.747 .379 .356 r
.6005 .57687 m .59893 .57863 L .59684 .57625 L F
.887 .589 .478 r
.60104 .57921 m .59893 .57863 L .6005 .57687 L F
.409 .839 .954 r
.34287 .62837 m .34629 .62818 L .34416 .6285 L F
0 0 .095 r
.54538 .7689 m .54543 .76491 L .5475 .7665 L F
.503 .006 .008 r
.5455 .76733 m .5475 .7665 L .54543 .76491 L F
.5455 .76733 m .5497 .76695 L .5475 .7665 L F
.956 .82 .383 r
.49048 .80672 m .4905 .8085 L .49035 .80695 L F
.61 .681 .892 r
.49035 .80695 m .4905 .8085 L .49267 .80754 L F
.391 .341 .682 r
.54066 .69881 m .54236 .69857 L .53996 .69715 L F
.54066 .69881 m .54236 .69857 L .53996 .69715 L F
.861 .677 .652 r
.59191 .64819 m .58866 .64962 L .59023 .64735 L F
.59191 .64819 m .59167 .65082 L .58866 .64962 L F
0 0 .227 r
.59067 .64249 m .59181 .64115 L .59207 .63888 L F
0 0 .456 r
.59067 .64249 m .59168 .64355 L .59181 .64115 L F
.079 0 .454 r
.5934 .64908 m .59191 .64819 L .59351 .64693 L F
.5934 .64908 m .59167 .65082 L .59191 .64819 L F
.449 .157 .377 r
.32393 .60576 m .32368 .60755 L .32154 .60799 L F
.284 0 .211 r
.32644 .60532 m .32368 .60755 L .32393 .60576 L F
.179 0 .044 r
.57996 .58151 m .57917 .58392 L .57692 .58452 L F
.355 .035 .278 r
.58269 .57965 m .58213 .58204 L .57996 .58151 L F
.329 0 .07 r
.58213 .58204 m .57917 .58392 L .57996 .58151 L F
.476 .208 .428 r
.58991 .57382 m .58738 .57619 L .58768 .57428 L F
.307 0 .229 r
.57307 .5872 m .57373 .58932 L .57123 .58926 L F
.57307 .5872 m .57464 .58729 L .57373 .58932 L F
.532 .204 .357 r
.37436 .63055 m .37328 .6332 L .37094 .63333 L F
.459 .143 .342 r
.37635 .63011 m .37328 .6332 L .37436 .63055 L F
.633 .423 .58 r
.59263 .62511 m .59518 .62494 L .59515 .62253 L F
.586 .372 .556 r
.59518 .62494 m .59774 .62222 L .59515 .62253 L F
.525 .345 .58 r
.48895 .64851 m .49125 .64925 L .49035 .64572 L F
.956 .939 .621 r
.49125 .64925 m .49296 .64496 L .49035 .64572 L F
.838 .383 .132 r
.48925 .65389 m .48852 .65476 L .48746 .65303 L F
.58 .55 .785 r
.49045 .64996 m .49151 .65343 L .48925 .65389 L F
.55 .128 .193 r
.49151 .65343 m .48852 .65476 L .48925 .65389 L F
.59 .226 .319 r
.26927 .83306 m .27156 .83297 L .26986 .83205 L F
.516 .324 .558 r
.27189 .83292 m .26986 .83205 L .27163 .83046 L F
.27189 .83292 m .27156 .83297 L .26986 .83205 L F
.26986 .83205 m .27189 .83292 L .27163 .83046 L F
.26986 .83205 m .27156 .83297 L .27189 .83292 L F
.638 .75 .93 r
.33203 .62345 m .33271 .62647 L .33078 .62562 L F
.447 .598 .908 r
.3341 .62315 m .33271 .62647 L .33203 .62345 L F
.3341 .62315 m .33492 .62528 L .33271 .62647 L F
.323 .54 .908 r
.33492 .62528 m .33528 .62703 L .33271 .62647 L F
.466 .654 .942 r
.33492 .62528 m .33528 .62703 L .33271 .62647 L F
.34 .024 .275 r
.58492 .56254 m .58712 .56196 L .58763 .56017 L F
.625 .387 .537 r
.58712 .56196 m .58974 .55941 L .58763 .56017 L F
.663 .631 .807 r
.32183 .62204 m .31829 .61977 L .32045 .61891 L F
.579 .563 .8 r
.32315 .6185 m .32183 .62204 L .32045 .61891 L F
.32315 .6185 m .32419 .62164 L .32183 .62204 L F
.988 .717 .398 r
.69236 .47524 m .69355 .47665 L .69345 .47433 L F
0 .168 .705 r
.46528 .69377 m .46683 .69477 L .46819 .69299 L F
.719 .187 0 r
.46881 .69659 m .46799 .69654 L .46528 .69377 L F
0 .168 .705 r
.46528 .69377 m .46799 .69654 L .46683 .69477 L F
.599 .642 .865 r
.75337 .49353 m .75464 .49681 L .75702 .49623 L F
.667 .59 .759 r
.75563 .50013 m .75702 .49623 L .75464 .49681 L F
.418 .666 .963 r
.75907 .48225 m .7575 .48353 L .75671 .48208 L F
.75907 .48225 m .76125 .48415 L .7575 .48353 L F
.496 .143 .298 r
.35771 .62463 m .36007 .6245 L .36087 .62293 L F
.494 .214 .418 r
.36007 .6245 m .36292 .62214 L .36087 .62293 L F
.446 .195 .438 r
.39497 .61663 m .39449 .61931 L .39234 .61962 L F
.486 .24 .467 r
.39716 .61611 m .39449 .61931 L .39497 .61663 L F
0 .367 .756 r
.72889 .51502 m .73004 .51528 L .72794 .51352 L F
.72889 .51502 m .7316 .51619 L .73004 .51528 L F
.689 .948 .676 r
.4878 .62015 m .4855 .62256 L .48633 .62116 L F
.768 .871 .443 r
.48479 .62476 m .48633 .62116 L .4855 .62256 L F
0 .186 .717 r
.57288 .64409 m .57298 .64551 L .57155 .64223 L F
.06 .14 .635 r
.57288 .64409 m .57331 .64741 L .57298 .64551 L F
.405 .045 .237 r
.40512 .61062 m .40205 .61313 L .40247 .6117 L F
.489 .298 .548 r
.41993 .6764 m .42203 .67602 L .42218 .67374 L F
.479 .353 .63 r
.41993 .6764 m .42226 .67847 L .42203 .67602 L F
.41993 .6764 m .42004 .67974 L .42226 .67847 L F
.105 .228 .708 r
.55177 .64761 m .55194 .65076 L .54976 .64807 L F
.55177 .64761 m .55248 .65095 L .55194 .65076 L F
.496 .359 .624 r
.42403 .66812 m .42613 .66769 L .42613 .66508 L F
.579 .441 .657 r
.42405 .67058 m .42613 .66769 L .42403 .66812 L F
.454 .593 .901 r
.3934 .59025 m .39269 .59243 L .39124 .59076 L F
.3934 .59025 m .39496 .59272 L .39269 .59243 L F
.867 .988 .719 r
.28662 .62492 m .28616 .62462 L .28764 .62241 L F
0 0 .112 r
.28662 .62492 m .28597 .62718 L .28726 .62628 L F
.28662 .62492 m .28726 .62628 L .28616 .62462 L F
.905 .981 .786 r
.28764 .62241 m .28616 .62462 L .286 .62301 L F
0 0 .535 r
.28616 .62462 m .28688 .6257 L .286 .62301 L F
.28688 .6257 m .28726 .62628 L .28704 .6257 L F
.867 .988 .719 r
.28662 .62492 m .28764 .62241 L .28928 .62248 L F
0 0 .535 r
.28688 .6257 m .28704 .6257 L .286 .62301 L F
0 0 0 r
.28499 .6281 m .28597 .62718 L .28639 .62571 L F
.28621 .62571 m .28639 .62571 L .28662 .62492 L F
.28499 .6281 m .28639 .62571 L .28621 .62571 L F
.061 .171 .667 r
.28499 .6281 m .28653 .63008 L .28597 .62718 L F
.432 .283 .577 r
.28499 .6281 m .28493 .63119 L .28653 .63008 L F
0 0 0 r
.54477 .5944 m .54491 .59466 L .54606 .59291 L F
.54477 .5944 m .54321 .59551 L .54491 .59466 L F
.394 .33 .667 r
.56191 .62135 m .56178 .62495 L .56011 .62529 L F
.408 .392 .73 r
.56178 .62495 m .563 .62699 L .56011 .62529 L F
0 0 0 r
.56131 .58135 m .5622 .57985 L .55963 .58255 L F
.213 0 .049 r
.56131 .58135 m .56431 .57924 L .5622 .57985 L F
.168 0 0 r
.43072 .66392 m .43302 .66365 L .43471 .66268 L F
.578 .128 .147 r
.43302 .66365 m .43609 .66363 L .43471 .66268 L F
.327 0 .066 r
.43609 .66363 m .43691 .66223 L .43471 .66268 L F
.443 .777 .998 r
.70301 .47913 m .70535 .47878 L .70635 .47978 L F
.692 .897 .971 r
.70635 .47978 m .71077 .47726 L .70892 .47784 L F
.70635 .47978 m .70535 .47878 L .71077 .47726 L F
.171 .285 .739 r
.56418 .65666 m .56633 .65865 L .56528 .65524 L F
.404 .32 .647 r
.56454 .65863 m .56633 .65865 L .56418 .65666 L F
.194 .664 .937 r
.70893 .49332 m .70575 .49251 L .70666 .49354 L F
.653 .433 .571 r
.60114 .55598 m .60347 .55369 L .60108 .55401 L F
0 0 .081 r
.49618 .65412 m .49651 .65503 L .4957 .65226 L F
0 .481 .704 r
.33996 .58424 m .34203 .58457 L .34363 .58485 L F
.432 .779 .997 r
.34203 .58457 m .34562 .58518 L .34363 .58485 L F
.912 .57 .381 r
.44935 .69898 m .44988 .7009 L .45166 .69955 L F
0 0 0 r
.45166 .69955 m .45178 .69971 L .45384 .69911 L F
.45166 .69955 m .44988 .7009 L .45178 .69971 L F
.496 .494 .785 r
.42443 .69909 m .42572 .70286 L .42665 .70153 L F
.753 .238 0 r
.42572 .70286 m .42707 .70191 L .42665 .70153 L F
.42572 .70286 m .42745 .70491 L .42595 .70442 L F
.42572 .70286 m .42595 .70442 L .42707 .70191 L F
.906 .755 .682 r
.62092 .58167 m .6196 .58496 L .62155 .58491 L F
.887 .71 .656 r
.6191 .58736 m .62155 .58491 L .6196 .58496 L F
.6191 .58736 m .62151 .58825 L .62155 .58491 L F
0 .083 .559 r
.49483 .70597 m .49424 .70505 L .49322 .70581 L F
.49483 .70597 m .4969 .70468 L .49424 .70505 L F
.49483 .70597 m .49577 .70671 L .4969 .70468 L F
.49483 .70597 m .49681 .70762 L .49577 .70671 L F
.369 0 0 r
.53793 .59757 m .53676 .5966 L .53519 .59865 L F
.53793 .59757 m .53882 .597 L .53676 .5966 L F
.403 0 .122 r
.45384 .69911 m .45581 .69902 L .45685 .69749 L F
.53 .115 .197 r
.45685 .69749 m .45581 .69902 L .45941 .69828 L F
.872 .814 .789 r
.50111 .66804 m .49904 .67174 L .49748 .67008 L F
.569 .744 .959 r
.49748 .67008 m .49904 .67174 L .50078 .67067 L F
.888 .608 .094 r
.72712 .51037 m .72767 .51103 L .72794 .51352 L F
.754 .812 .898 r
.74702 .51231 m .74277 .51329 L .74567 .51106 L F
.795 .877 .907 r
.74814 .50967 m .74702 .51231 L .74567 .51106 L F
.74814 .50967 m .74887 .51102 L .74702 .51231 L F
.251 .213 .619 r
.65778 .51314 m .6593 .51257 L .65849 .51064 L F
.612 .308 .43 r
.66334 .48814 m .65964 .48865 L .6611 .48761 L F
.811 .782 .826 r
.71934 .49943 m .71632 .49917 L .71842 .49631 L F
.71934 .49943 m .71764 .5004 L .71632 .49917 L F
.803 .743 .797 r
.72128 .49659 m .71934 .49943 L .71842 .49631 L F
.477 .555 .857 r
.58945 .63909 m .58842 .63598 L .58643 .63636 L F
.496 .52 .811 r
.58945 .63909 m .59033 .63608 L .58842 .63598 L F
.58945 .63909 m .59207 .63888 L .59033 .63608 L F
.492 0 0 r
.56086 .60478 m .56013 .60588 L .55752 .60471 L F
.56 .933 .903 r
.56086 .60478 m .56306 .60346 L .56207 .60342 L F
.618 .385 .541 r
.56207 .60342 m .56013 .60588 L .56086 .60478 L F
.421 .545 .876 r
.75146 .49377 m .75224 .49069 L .74973 .49111 L F
.75146 .49377 m .75337 .49353 L .75224 .49069 L F
.618 .931 .966 r
.44046 .70913 m .44139 .70969 L .44457 .70859 L F
.875 .804 .776 r
.72588 .49055 m .72539 .48758 L .72669 .4886 L F
.744 .993 .843 r
.46945 .69512 m .46799 .69654 L .46881 .69659 L F
.101 0 0 r
.34379 .59982 m .34199 .60033 L .34001 .60044 L F
.479 .898 .844 r
.34588 .59897 m .34199 .60033 L .34379 .59982 L F
.018 0 0 r
.49125 .80699 m .49259 .80485 L .49048 .80672 L F
.969 .702 .473 r
.49125 .80699 m .49267 .80754 L .49259 .80485 L F
.548 .331 .537 r
.49186 .77656 m .49197 .77934 L .49508 .77876 L F
.602 .52 .734 r
.52432 .6535 m .52142 .65457 L .52116 .65076 L F
0 0 0 r
.52432 .6535 m .52246 .65546 L .52142 .65457 L F
.772 .336 .217 r
.55357 .60991 m .55698 .61122 L .55404 .61108 L F
.415 .089 .302 r
.38937 .62314 m .38732 .62262 L .38957 .62225 L F
.38937 .62314 m .38679 .62394 L .38732 .62262 L F
.698 .418 .497 r
.66003 .48505 m .66238 .4855 L .66225 .4831 L F
.467 .159 .359 r
.66238 .4855 m .66582 .48229 L .66225 .4831 L F
.469 .105 .264 r
.60151 .66526 m .60066 .6675 L .59823 .66777 L F
.494 .305 .554 r
.60372 .66231 m .60372 .66464 L .60151 .66526 L F
.404 .061 .267 r
.60372 .66464 m .60066 .6675 L .60151 .66526 L F
.114 .52 .911 r
.38987 .5895 m .38979 .59049 L .38789 .5893 L F
.38987 .5895 m .39124 .59076 L .38979 .59049 L F
.388 .485 .838 r
.28398 .63623 m .28443 .63345 L .28274 .63268 L F
.28398 .63623 m .28594 .63675 L .28443 .63345 L F
.486 .338 .604 r
.45906 .66757 m .45871 .66997 L .45655 .66821 L F
.458 .34 .631 r
.45871 .66997 m .4569 .67082 L .45655 .66821 L F
.469 .346 .629 r
.28088 .61105 m .28281 .61058 L .28253 .60804 L F
.145 0 0 r
.74441 .53121 m .7435 .53114 L .74104 .53077 L F
.016 0 0 r
.74663 .53023 m .7435 .53114 L .74441 .53121 L F
.501 .535 .824 r
.77306 .50139 m .77166 .50218 L .76986 .49912 L F
0 0 0 r
.77018 .50427 m .77166 .50218 L .77306 .50139 L F
.128 .108 .564 r
.6039 .65295 m .60282 .65638 L .60197 .65348 L F
.6039 .65295 m .6043 .65551 L .60282 .65638 L F
0 0 .186 r
.6043 .65551 m .60289 .65856 L .60282 .65638 L F
.098 0 0 r
.35108 .64163 m .34916 .64235 L .34944 .64171 L F
.583 .081 .027 r
.69928 .47431 m .69825 .47537 L .69588 .47417 L F
.748 .285 .149 r
.69928 .47431 m .7013 .47622 L .69825 .47537 L F
.955 .785 .633 r
.61898 .57067 m .61908 .5742 L .62001 .57402 L F
.978 .725 .315 r
.61941 .57558 m .62001 .57402 L .61908 .5742 L F
.61941 .57558 m .62008 .57635 L .62001 .57402 L F
.104 .285 .763 r
.5007 .66159 m .50045 .6631 L .49857 .65914 L F
.824 .421 .285 r
.49849 .66398 m .50045 .6631 L .5007 .66159 L F
.473 .157 .349 r
.75986 .52039 m .7621 .52147 L .75961 .52164 L F
.75986 .52039 m .76209 .51992 L .7621 .52147 L F
.332 .009 .259 r
.56431 .57924 m .56643 .57854 L .5669 .5763 L F
.296 0 .247 r
.56849 .57772 m .5669 .5763 L .56643 .57854 L F
.56849 .57772 m .56902 .57612 L .5669 .5763 L F
.667 .59 .759 r
.75563 .50013 m .75815 .49954 L .75702 .49623 L F
.654 .531 .701 r
.75563 .50013 m .75574 .50232 L .75815 .49954 L F
.426 .126 .352 r
.45851 .65031 m .46078 .64973 L .46117 .64814 L F
.494 .259 .486 r
.46078 .64973 m .46324 .64744 L .46117 .64814 L F
.588 .877 .567 r
.49875 .64471 m .49579 .64753 L .49603 .6476 L F
0 0 .492 r
.49772 .64822 m .49603 .6476 L .49579 .64753 L F
.84 .944 .89 r
.71947 .4895 m .71875 .4919 L .72055 .49017 L F
.815 .921 .907 r
.71947 .4895 m .71766 .49116 L .71875 .4919 L F
.61 .098 .009 r
.75729 .51315 m .7544 .51148 L .75367 .51276 L F
.335 0 0 r
.52714 .70449 m .52968 .70504 L .52606 .70449 L F
.55 0 0 r
.51808 .70407 m .52038 .70209 L .51671 .70242 L F
.51808 .70407 m .52072 .70411 L .52038 .70209 L F
.291 .021 .32 r
.52072 .70411 m .52249 .70273 L .52038 .70209 L F
.408 .488 .83 r
.56129 .64797 m .56258 .65106 L .5645 .64946 L F
.394 .463 .813 r
.56258 .65106 m .56554 .65261 L .5645 .64946 L F
.969 .81 .629 r
.60536 .59362 m .60393 .59344 L .60478 .59039 L F
.975 .875 .673 r
.60536 .59362 m .60344 .59565 L .60393 .59344 L F
.60536 .59362 m .60431 .59658 L .60344 .59565 L F
.591 .188 .247 r
.46863 .70088 m .47103 .70122 L .47247 .69923 L F
.733 .358 .341 r
.47103 .70122 m .47451 .70163 L .47247 .69923 L F
.78 .328 .175 r
.47247 .69923 m .47451 .70163 L .47624 .70168 L F
.355 0 0 r
.35155 .59858 m .34808 .59864 L .34941 .59923 L F
.925 .632 .469 r
.60344 .58485 m .60112 .58146 L .60326 .58254 L F
.112 0 0 r
.3592 .63887 m .35803 .6386 L .3602 .63815 L F
.3592 .63887 m .35705 .6394 L .35803 .6386 L F
.452 .599 .907 r
.49685 .78746 m .49466 .78778 L .49449 .78406 L F
.538 .219 .375 r
.6854 .47924 m .68786 .47934 L .68872 .47731 L F
.383 .065 .298 r
.68872 .47731 m .69018 .47848 L .69005 .4757 L F
.68872 .47731 m .68786 .47934 L .69018 .47848 L F
.927 .971 .699 r
.55801 .66267 m .55632 .66507 L .55636 .66469 L F
.23 .177 .588 r
.5592 .66188 m .55801 .66267 L .55851 .65914 L F
.247 0 .237 r
.55873 .66395 m .55801 .66267 L .5592 .66188 L F
.55873 .66395 m .55632 .66507 L .55801 .66267 L F
.482 .677 .951 r
.52155 .70475 m .5241 .70541 L .52072 .70411 L F
.805 .589 .609 r
.52529 .65131 m .52432 .6535 L .5226 .65058 L F
.472 .655 .94 r
.438 .70618 m .44005 .70846 L .44276 .70825 L F
.464 0 0 r
.44276 .70825 m .443 .70843 L .44213 .70797 L F
.618 .931 .966 r
.44371 .70871 m .44319 .7085 L .44273 .70847 L F
.44371 .70871 m .44457 .70859 L .44319 .7085 L F
.23 0 0 r
.44457 .70859 m .44524 .70936 L .44273 .70847 L F
.618 .931 .966 r
.44046 .70913 m .44371 .70871 L .44273 .70847 L F
.416 0 0 r
.44273 .70847 m .4437 .70896 L .44276 .70825 L F
.464 0 0 r
.443 .70843 m .4437 .70896 L .44262 .70828 L F
.443 .70843 m .44262 .70828 L .44213 .70797 L F
.23 0 0 r
.44457 .70859 m .44675 .70847 L .44524 .70936 L F
.424 .142 .379 r
.58513 .57686 m .58715 .57743 L .58459 .57883 L F
.58513 .57686 m .58738 .57619 L .58715 .57743 L F
.512 .273 .489 r
.28872 .5938 m .29092 .59338 L .29125 .59114 L F
.508 .259 .472 r
.29092 .59338 m .29354 .59072 L .29125 .59114 L F
.313 0 0 r
.30942 .58478 m .3116 .58465 L .31335 .58331 L F
.101 0 0 r
.31335 .58331 m .31489 .58322 L .3155 .58279 L F
.31335 .58331 m .3116 .58465 L .31489 .58322 L F
.618 .478 .669 r
.75574 .50232 m .75899 .50169 L .75815 .49954 L F
.518 .713 .96 r
.38119 .59875 m .38225 .59964 L .38425 .59916 L F
.543 .454 .704 r
.38225 .59964 m .38454 .60145 L .38425 .59916 L F
.38225 .59964 m .38252 .6021 L .38454 .60145 L F
.663 .574 .745 r
.30816 .64198 m .30929 .64556 L .31317 .64434 L F
.502 .702 .96 r
.2111 .55726 m .21005 .55897 L .20851 .55673 L F
.2111 .55726 m .21226 .55881 L .21005 .55897 L F
.484 .167 .352 r
.38468 .62442 m .3836 .62741 L .38148 .62767 L F
.485 .187 .384 r
.38679 .62394 m .3836 .62741 L .38468 .62442 L F
.76 .899 .939 r
.69853 .48987 m .69666 .49291 L .70006 .49211 L F
.69853 .48987 m .69511 .49171 L .69666 .49291 L F
.354 0 .077 r
.53779 .70211 m .53445 .70413 L .53419 .70153 L F
.182 0 0 r
.53487 .70179 m .53494 .70253 L .53532 .70156 L F
.547 .304 .499 r
.53422 .70185 m .53308 .70149 L .53419 .70153 L F
.53445 .70413 m .53321 .70174 L .53422 .70185 L F
.53321 .70174 m .53308 .70149 L .53422 .70185 L F
.53445 .70413 m .532 .70466 L .53308 .70149 L F
.182 0 0 r
.5329 .70282 m .53491 .70253 L .53487 .70191 L F
.53468 .70189 m .53487 .70191 L .53487 .70179 L F
.5329 .70282 m .53487 .70191 L .53468 .70189 L F
.53491 .70253 m .53494 .70253 L .53487 .70179 L F
.454 0 0 r
.53549 .70144 m .53779 .70211 L .53486 .70164 L F
.53485 .70149 m .53486 .70164 L .53419 .70153 L F
.53549 .70144 m .53486 .70164 L .53485 .70149 L F
.872 .814 .789 r
.50111 .66804 m .49748 .67008 L .50078 .67067 L F
.50111 .66804 m .50078 .67067 L .49976 .66748 L F
.651 .575 .756 r
.49976 .66748 m .50174 .67008 L .50111 .66804 L F
.013 0 .462 r
.50251 .66696 m .50174 .67008 L .50111 .66804 L F
.589 .394 .584 r
.28635 .59395 m .28838 .59585 L .28872 .5938 L F
.28635 .59395 m .28609 .59623 L .28838 .59585 L F
.792 .754 .817 r
.49685 .78746 m .49807 .79034 L .4949 .78998 L F
.792 .753 .818 r
.50023 .78778 m .49807 .79034 L .49685 .78746 L F
.567 .704 .934 r
.58031 .64946 m .57767 .65068 L .57613 .6485 L F
.58031 .64946 m .58015 .6505 L .57767 .65068 L F
.589 .341 .509 r
.57985 .65279 m .57767 .65068 L .58015 .6505 L F
.57985 .65279 m .57735 .65345 L .57767 .65068 L F
.455 .313 .597 r
.28191 .60246 m .28379 .60191 L .28371 .59944 L F
.506 .404 .673 r
.28191 .60246 m .2843 .60454 L .28379 .60191 L F
.28191 .60246 m .28234 .60517 L .2843 .60454 L F
.733 .908 .955 r
.72277 .47409 m .71977 .47574 L .71883 .47477 L F
.702 .481 .586 r
.49733 .63634 m .49722 .64042 L .49439 .63934 L F
0 0 .337 r
.49767 .63845 m .49733 .63634 L .49966 .6367 L F
.49767 .63845 m .49722 .64042 L .49733 .63634 L F
.995 .855 .515 r
.62026 .59296 m .62056 .59502 L .62069 .59388 L F
.525 .243 .429 r
.58459 .57883 m .58213 .58204 L .58269 .57965 L F
.451 .683 .964 r
.53259 .66191 m .53357 .65981 L .53105 .65967 L F
.53259 .66191 m .53492 .66237 L .53357 .65981 L F
.651 .331 .417 r
.53492 .66237 m .53482 .66422 L .53259 .66191 L F
.53492 .66237 m .53482 .66422 L .53259 .66191 L F
.597 .55 .772 r
.50334 .6393 m .50462 .63632 L .50321 .63649 L F
.555 .81 .993 r
.71242 .49389 m .7112 .49283 L .70893 .49332 L F
.564 .727 .951 r
.71242 .49389 m .71371 .49117 L .7112 .49283 L F
.364 .186 .502 r
.31884 .61077 m .31866 .61339 L .31691 .61382 L F
.523 .416 .674 r
.31866 .61339 m .31701 .61606 L .31691 .61382 L F
.644 .535 .715 r
.38252 .6021 m .38581 .60475 L .38454 .60145 L F
.38252 .6021 m .38346 .60531 L .38581 .60475 L F
.357 .422 .791 r
.28813 .61916 m .28928 .62248 L .2907 .62135 L F
.405 .853 .909 r
.28928 .62248 m .28989 .62181 L .2907 .62135 L F
.28928 .62248 m .28764 .62241 L .28989 .62181 L F
.317 0 .164 r
.44505 .65918 m .44293 .65982 L .44229 .66121 L F
.337 .686 .98 r
.37973 .58832 m .3762 .58704 L .37837 .58703 L F
.356 .706 .985 r
.38045 .58726 m .37973 .58832 L .37837 .58703 L F
.38045 .58726 m .38182 .58833 L .37973 .58832 L F
0 0 .095 r
.54538 .7689 m .5455 .76733 L .54543 .76491 L F
.289 .433 .833 r
.54538 .7689 m .54679 .77019 L .5455 .76733 L F
.763 .455 .466 r
.54331 .77007 m .54679 .77019 L .54538 .7689 L F
.495 .208 .407 r
.44505 .65918 m .44734 .65885 L .44811 .65605 L F
.483 .19 .391 r
.44734 .65885 m .4504 .65579 L .44811 .65605 L F
.752 .78 .876 r
.69718 .47958 m .69472 .48165 L .69378 .47917 L F
.374 .491 .849 r
.48211 .66744 m .48092 .66846 L .47878 .6646 L F
0 0 0 r
.48211 .66744 m .48006 .67021 L .48092 .66846 L F
.565 .895 .643 r
.4878 .62015 m .48884 .619 L .48987 .61914 L F
.4878 .62015 m .48633 .62116 L .48884 .619 L F
.556 .593 .846 r
.41405 .70641 m .41554 .70355 L .41318 .70362 L F
.41405 .70641 m .41678 .70557 L .41554 .70355 L F
.936 .562 .204 r
.53185 .65622 m .53091 .65609 L .53006 .65338 L F
.929 .718 .596 r
.53185 .65622 m .52962 .65823 L .53091 .65609 L F
.808 .853 .883 r
.67509 .49977 m .6722 .50005 L .67382 .49852 L F
.773 .836 .901 r
.67787 .49764 m .67509 .49977 L .67382 .49852 L F
0 0 .447 r
.52688 .60508 m .5278 .60734 L .5273 .60383 L F
0 .483 .815 r
.29434 .63478 m .2971 .63579 L .2952 .63636 L F
.706 .571 .7 r
.2971 .63579 m .29498 .639 L .2952 .63636 L F
.187 0 .352 r
.60372 .63377 m .60551 .63073 L .60466 .63344 L F
.327 .225 .584 r
.60466 .63344 m .60389 .63608 L .60372 .63377 L F
.581 .736 .949 r
.52515 .63538 m .52423 .63754 L .52276 .63592 L F
.52515 .63538 m .52625 .63689 L .52423 .63754 L F
.456 .316 .602 r
.70285 .47705 m .69933 .47802 L .7013 .47622 L F
0 0 0 r
.70453 .47554 m .70285 .47705 L .70524 .47456 L F
.524 .492 .762 r
.70453 .47554 m .70301 .47913 L .70285 .47705 L F
.951 .651 .433 r
.72433 .48424 m .72581 .4852 L .72608 .4841 L F
.72433 .48424 m .72581 .4852 L .72608 .4841 L F
.508 .547 .831 r
.60001 .64526 m .60227 .64512 L .60329 .64808 L F
.195 0 .365 r
.60653 .62859 m .60466 .63344 L .60551 .63073 L F
.60653 .62859 m .6072 .63198 L .60466 .63344 L F
.226 0 .338 r
.6097 .62697 m .60653 .62859 L .60698 .6279 L F
.6097 .62697 m .60921 .62902 L .60653 .62859 L F
.217 .053 .433 r
.60653 .62859 m .60902 .63141 L .6072 .63198 L F
.60653 .62859 m .60921 .62902 L .60902 .63141 L F
.295 .375 .775 r
.60289 .65856 m .60516 .66179 L .60372 .66231 L F
.45 .309 .597 r
.60516 .66179 m .60372 .66464 L .60372 .66231 L F
.666 .594 .766 r
.57711 .6621 m .57338 .65942 L .57561 .6593 L F
.134 .365 .823 r
.57561 .6593 m .57806 .66103 L .57711 .6621 L F
.053 .235 .733 r
.57806 .66103 m .57926 .66421 L .57711 .6621 L F
.703 .323 .325 r
.53012 .70097 m .52838 .70156 L .53308 .70149 L F
.513 .27 .484 r
.52968 .70504 m .53308 .70149 L .52838 .70156 L F
.52968 .70504 m .532 .70466 L .53308 .70149 L F
.53308 .70149 m .532 .70466 L .52968 .70504 L F
0 0 0 r
.53308 .70149 m .5329 .70282 L .53419 .70153 L F
.53308 .70149 m .532 .70466 L .5329 .70282 L F
.312 .763 .957 r
.36105 .58629 m .3631 .58615 L .36457 .58671 L F
.255 .753 .902 r
.3631 .58615 m .3666 .58621 L .36457 .58671 L F
.836 .618 .608 r
.6055 .58544 m .60537 .58793 L .60344 .58485 L F
.549 .618 .874 r
.29096 .6396 m .29057 .64236 L .28895 .64176 L F
.29096 .6396 m .29284 .64214 L .29057 .64236 L F
.689 .263 .231 r
.29284 .64214 m .28895 .64176 L .29057 .64236 L F
.724 .503 .591 r
.49593 .77919 m .49574 .78176 L .49369 .78044 L F
.722 .202 0 r
.49369 .78044 m .49574 .78176 L .49503 .7822 L F
.993 .788 .414 r
.49503 .7822 m .49593 .77919 L .49508 .77876 L F
.49503 .7822 m .49574 .78176 L .49593 .77919 L F
.536 .013 0 r
.45997 .70742 m .45823 .70771 L .45623 .70722 L F
.534 .01 0 r
.45997 .70742 m .4619 .70782 L .45823 .70771 L F
.808 .904 .908 r
.7394 .49219 m .73946 .49429 L .74046 .49317 L F
.952 .924 .57 r
.7394 .49219 m .73898 .4938 L .73946 .49429 L F
.54 .285 .477 r
.58234 .56493 m .58486 .56458 L .58492 .56254 L F
.413 .185 .455 r
.58486 .56458 m .58712 .56196 L .58492 .56254 L F
.58486 .56458 m .58712 .56196 L .58492 .56254 L F
.788 .524 .538 r
.48855 .66515 m .48458 .66694 L .48704 .66477 L F
.48855 .66515 m .48803 .66758 L .48458 .66694 L F
.512 .889 .967 r
.48855 .66515 m .48856 .6642 L .4906 .66454 L F
.48855 .66515 m .48704 .66477 L .48856 .6642 L F
.362 .124 .413 r
.4906 .66454 m .48803 .66758 L .48855 .66515 L F
.421 .413 .745 r
.30675 .63643 m .30737 .63975 L .30941 .63845 L F
.523 .509 .782 r
.30816 .64198 m .30941 .63845 L .30737 .63975 L F
.554 .347 .555 r
.38345 .60778 m .38581 .60475 L .38346 .60531 L F
.868 .987 .835 r
.74121 .51461 m .73877 .51748 L .73941 .51518 L F
.784 .916 .928 r
.73941 .51518 m .73877 .51748 L .73765 .51656 L F
.337 0 .023 r
.34064 .64472 m .33674 .64698 L .3387 .64563 L F
.974 .761 .554 r
.61849 .58778 m .62151 .58825 L .6191 .58736 L F
.61849 .58778 m .62118 .59094 L .62151 .58825 L F
.351 .818 .913 r
.48987 .61914 m .49213 .61865 L .4936 .61877 L F
.3 0 0 r
.49213 .61865 m .4957 .61933 L .4936 .61877 L F
0 0 0 r
.55452 .58773 m .55641 .58706 L .55742 .58554 L F
.55883 .58406 m .55963 .58255 L .55742 .58554 L F
.55641 .58706 m .55883 .58406 L .55742 .58554 L F
.409 0 .09 r
.58173 .66172 m .58422 .66153 L .58513 .65982 L F
.522 .081 .143 r
.58513 .65982 m .58422 .66153 L .58741 .66099 L F
.502 .14 .284 r
.58513 .65982 m .58741 .66099 L .58968 .65853 L F
.35 0 0 r
.58335 .67708 m .58169 .67762 L .5797 .67735 L F
0 0 0 r
.58384 .67708 m .58335 .67708 L .58546 .67613 L F
.58384 .67708 m .58169 .67762 L .58335 .67708 L F
.526 .346 .58 r
.42203 .67602 m .42437 .67317 L .42218 .67374 L F
.286 0 .098 r
.55145 .59033 m .55368 .58967 L .55452 .58773 L F
.173 0 .051 r
.55452 .58773 m .55559 .58889 L .55641 .58706 L F
.55452 .58773 m .55368 .58967 L .55559 .58889 L F
.329 .468 .848 r
.56868 .66533 m .56999 .66385 L .56711 .66246 L F
.208 .282 .721 r
.57063 .66724 m .56999 .66385 L .56868 .66533 L F
0 .204 .731 r
.52962 .65823 m .53089 .6602 L .52929 .65883 L F
.504 .91 .871 r
.52897 .60059 m .53095 .60034 L .52793 .60155 L F
.414 .863 .846 r
.53304 .5995 m .53095 .60034 L .52897 .60059 L F
.504 .91 .871 r
.52897 .60059 m .52793 .60155 L .52714 .60162 L F
.608 .604 .821 r
.75938 .5051 m .76079 .50123 L .75899 .50169 L F
.75938 .5051 m .76195 .5045 L .76079 .50123 L F
.613 .393 .559 r
.27226 .83044 m .27189 .83292 L .27163 .83046 L F
.27163 .83046 m .27189 .83292 L .27226 .83044 L F
.516 .324 .558 r
.27189 .83292 m .27156 .83297 L .27163 .83046 L F
.768 .661 .744 r
.56109 .61915 m .56471 .61957 L .56346 .61628 L F
.759 .656 .748 r
.56346 .61628 m .56471 .61957 L .56686 .61662 L F
.641 .114 0 r
.48676 .705 m .49144 .70611 L .49106 .70739 L F
.48676 .705 m .48983 .70676 L .49144 .70611 L F
.48676 .705 m .49106 .70739 L .48765 .70738 L F
.442 0 0 r
.49106 .70739 m .48834 .70843 L .48765 .70738 L F
.974 .781 .581 r
.48983 .70676 m .48834 .70843 L .49037 .70663 L F
.48913 .70698 m .48834 .70843 L .48983 .70676 L F
.49037 .70663 m .48834 .70843 L .49106 .70739 L F
.82 .533 .503 r
.49056 .70718 m .48834 .70843 L .48906 .70711 L F
.719 .277 .2 r
.48942 .70689 m .48924 .70712 L .49056 .70718 L F
.568 .433 .657 r
.48676 .705 m .48765 .70738 L .48519 .70767 L F
.719 .277 .2 r
.48638 .70613 m .48807 .70773 L .48942 .70689 L F
.974 .781 .581 r
.48917 .70692 m .48913 .70698 L .48942 .70689 L F
.649 .135 .007 r
.48942 .70689 m .48983 .70676 L .48676 .705 L F
.974 .781 .581 r
.4895 .70684 m .48942 .70689 L .48983 .70676 L F
.48917 .70692 m .48942 .70689 L .4895 .70684 L F
.649 .135 .007 r
.48942 .70689 m .49056 .70718 L .48983 .70676 L F
.641 .114 0 r
.48983 .70676 m .48996 .70683 L .49037 .70663 L F
.974 .781 .581 r
.48972 .7059 m .48917 .70692 L .49037 .70663 L F
.82 .533 .503 r
.49056 .70718 m .48906 .70711 L .48972 .7059 L F
.719 .277 .2 r
.48924 .70712 m .48847 .70811 L .49056 .70718 L F
.48807 .70773 m .48847 .70811 L .48942 .70689 L F
.649 .135 .007 r
.48638 .70613 m .48942 .70689 L .48676 .705 L F
.641 .114 0 r
.48983 .70676 m .49037 .70663 L .49144 .70611 L F
.89 .466 .158 r
.49144 .70611 m .48972 .7059 L .49037 .70663 L F
.49144 .70611 m .49037 .70663 L .49106 .70739 L F
.641 .114 0 r
.48996 .70683 m .49056 .70718 L .49144 .70611 L F
.89 .466 .158 r
.49144 .70611 m .49322 .70581 L .49424 .70505 L F
.49144 .70611 m .49106 .70739 L .49322 .70581 L F
.49144 .70611 m .49056 .70718 L .48972 .7059 L F
.961 .813 .379 r
.49106 .70739 m .49056 .70718 L .49144 .70611 L F
.85 .839 .834 r
.72459 .49215 m .72239 .49457 L .72101 .49357 L F
.89 .827 .779 r
.72239 .49457 m .72128 .49659 L .72101 .49357 L F
.85 .839 .834 r
.72459 .49215 m .72101 .49357 L .72337 .49078 L F
.863 .845 .825 r
.72588 .49055 m .72459 .49215 L .72337 .49078 L F
.205 0 .268 r
.55883 .58406 m .56131 .58135 L .55963 .58255 L F
.493 .301 .548 r
.57562 .65647 m .57561 .6593 L .57338 .65942 L F
.944 .639 .191 r
.57598 .67324 m .57712 .67653 L .57631 .67538 L F
.727 .221 .026 r
.5797 .67735 m .57631 .67538 L .57712 .67653 L F
.557 .296 .476 r
.46993 .66206 m .46858 .66456 L .46713 .66231 L F
.312 .216 .583 r
.46713 .66231 m .46858 .66456 L .46735 .66502 L F
.875 .804 .776 r
.72588 .49055 m .72337 .49078 L .72539 .48758 L F
.504 .218 .413 r
.39449 .61931 m .39172 .62162 L .39234 .61962 L F
.287 .467 .863 r
.56625 .63216 m .56528 .63349 L .56335 .63082 L F
.273 .446 .85 r
.56625 .63216 m .56776 .63502 L .56528 .63349 L F
.979 .774 .559 r
.71764 .5004 m .7163 .50175 L .71632 .49917 L F
.71764 .5004 m .71711 .50293 L .7163 .50175 L F
.419 .806 .989 r
.3666 .58621 m .36883 .58578 L .37034 .58655 L F
.301 .732 .97 r
.37111 .58575 m .37034 .58655 L .36883 .58578 L F
.37111 .58575 m .37267 .58642 L .37034 .58655 L F
.397 .231 .537 r
.61198 .61911 m .61219 .6216 L .60956 .62272 L F
.316 .178 .53 r
.61195 .62382 m .60956 .62272 L .61219 .6216 L F
.61195 .62382 m .6096 .62522 L .60956 .62272 L F
0 0 .514 r
.53792 .6192 m .53758 .61813 L .53624 .61634 L F
.739 .235 .026 r
.53792 .6192 m .5383 .62113 L .53758 .61813 L F
.53792 .6192 m .53999 .62139 L .5383 .62113 L F
.793 .762 .825 r
.72128 .49659 m .71842 .49631 L .72101 .49357 L F
0 .084 .605 r
.50122 .61966 m .50344 .62177 L .50313 .62181 L F
0 .172 .652 r
.50344 .62177 m .50557 .62363 L .50313 .62181 L F
.951 .947 .731 r
.50377 .79881 m .50527 .79655 L .50408 .79672 L F
.149 .333 .792 r
.50615 .79514 m .50527 .79655 L .50389 .79319 L F
.672 .976 .863 r
.50408 .79672 m .50527 .79655 L .50615 .79514 L F
.271 .112 .473 r
.61342 .6135 m .61331 .61607 L .61188 .61664 L F
.423 .322 .636 r
.61331 .61607 m .61198 .61911 L .61188 .61664 L F
.35 0 .207 r
.36894 .63408 m .36819 .6354 L .3661 .63591 L F
.38 .058 .289 r
.37094 .63333 m .36819 .6354 L .36894 .63408 L F
.491 .634 .917 r
.55568 .63548 m .55638 .637 L .55788 .63534 L F
.295 .332 .73 r
.55638 .637 m .55846 .63886 L .55788 .63534 L F
0 .046 .604 r
.54742 .64331 m .54898 .64571 L .54732 .6438 L F
.48 .812 1 r
.54403 .65277 m .54757 .65316 L .5451 .65363 L F
.54403 .65277 m .54757 .65316 L .5451 .65363 L F
.903 .924 .821 r
.5451 .65363 m .54303 .65626 L .54403 .65277 L F
.373 .025 .24 r
.45851 .65031 m .45973 .65215 L .46078 .64973 L F
.45851 .65031 m .45755 .6527 L .45973 .65215 L F
.033 0 .401 r
.27146 .66973 m .27197 .67039 L .27214 .66774 L F
.728 .601 .714 r
.57117 .63597 m .57158 .63708 L .56849 .63663 L F
.432 .435 .762 r
.57117 .63597 m .57299 .63617 L .57158 .63708 L F
0 0 .383 r
.57299 .63617 m .57201 .63951 L .57158 .63708 L F
0 0 .326 r
.60207 .61376 m .60278 .61247 L .60257 .60999 L F
.259 .225 .63 r
.60154 .616 m .60278 .61247 L .60207 .61376 L F
.429 .192 .451 r
.60154 .616 m .60207 .61376 L .59959 .61663 L F
.273 0 0 r
.45029 .708 m .45105 .70901 L .44858 .70921 L F
.45029 .708 m .45254 .70782 L .45105 .70901 L F
.397 .094 .33 r
.37275 .61583 m .37546 .61339 L .37355 .61418 L F
.619 .342 .475 r
.67902 .4814 m .68195 .4793 L .67969 .4801 L F
0 .057 .615 r
.58954 .65278 m .58866 .64962 L .59167 .65082 L F
.326 .378 .763 r
.5934 .64908 m .59475 .65275 L .59167 .65082 L F
.517 .909 .782 r
.47958 .70505 m .47983 .70441 L .48188 .70366 L F
.163 .658 .916 r
.47796 .70441 m .47983 .70441 L .47958 .70505 L F
.589 .129 .129 r
.6679 .48239 m .67042 .48385 L .67149 .48229 L F
.601 .146 .143 r
.67042 .48385 m .67399 .48287 L .67149 .48229 L F
.516 .291 .511 r
.41249 .60256 m .41239 .60471 L .41001 .60513 L F
.637 .654 .849 r
.41337 .60006 m .41249 .60256 L .41134 .59924 L F
.41337 .60006 m .41487 .60205 L .41249 .60256 L F
.615 .372 .526 r
.4148 .60446 m .41249 .60256 L .41487 .60205 L F
.4148 .60446 m .41239 .60471 L .41249 .60256 L F
.421 .436 .77 r
.4415 .68746 m .44055 .69088 L .43935 .68756 L F
.4415 .68746 m .44241 .69074 L .44055 .69088 L F
.416 .521 .857 r
.44241 .69074 m .44384 .69243 L .44055 .69088 L F
.047 0 0 r
.48977 .64126 m .488 .6421 L .48584 .64252 L F
.343 0 0 r
.49127 .64168 m .488 .6421 L .48977 .64126 L F
.678 .596 .757 r
.32045 .61891 m .31829 .61977 L .31701 .61606 L F
.615 .113 0 r
.55648 .61788 m .55537 .61635 L .55427 .61618 L F
.559 .399 .621 r
.55507 .6137 m .55513 .61208 L .55264 .6153 L F
.55507 .6137 m .55427 .61618 L .55671 .61554 L F
.55671 .61554 m .55427 .61618 L .55507 .6137 L F
.615 .113 0 r
.55648 .61788 m .55701 .6182 L .55537 .61635 L F
.521 .298 .517 r
.55427 .61618 m .55648 .61788 L .55671 .61554 L F
.726 .201 0 r
.55264 .6153 m .55648 .61788 L .55427 .61618 L F
.521 .298 .517 r
.55427 .61618 m .55648 .61788 L .55671 .61554 L F
.726 .201 0 r
.55264 .6153 m .5566 .6188 L .55648 .61788 L F
.409 .4 .738 r
.5541 .61397 m .55602 .61767 L .55264 .6153 L F
.55585 .61785 m .5566 .6188 L .5557 .61801 L F
.796 .307 0 r
.55585 .61785 m .5566 .6188 L .55553 .61783 L F
.55648 .61788 m .5566 .6188 L .55585 .61785 L F
.409 .4 .738 r
.55602 .61767 m .5566 .6188 L .55585 .61785 L F
.55602 .61767 m .5557 .61801 L .55264 .6153 L F
.749 .669 .772 r
.55553 .61783 m .55592 .61754 L .55606 .61763 L F
.55585 .61785 m .55602 .61767 L .55648 .61788 L F
.55602 .61767 m .55607 .61763 L .55648 .61788 L F
.391 .189 .483 r
.55671 .61554 m .55648 .61788 L .55831 .61561 L F
.55671 .61554 m .55648 .61788 L .55831 .61561 L F
.749 .669 .772 r
.55592 .61754 m .55746 .61641 L .55648 .61788 L F
.615 .113 0 r
.55648 .61788 m .55773 .61902 L .55701 .6182 L F
0 .042 .57 r
.5587 .61972 m .55773 .61902 L .55648 .61788 L F
.803 .774 .826 r
.55831 .61561 m .56012 .61915 L .55648 .61788 L F
0 .042 .57 r
.5587 .61972 m .55648 .61788 L .56012 .61915 L F
.643 .887 .545 r
.55831 .61561 m .55648 .61788 L .55708 .61699 L F
.5578 .61609 m .55708 .61699 L .55746 .61641 L F
.55831 .61561 m .55708 .61699 L .5578 .61609 L F
.528 .868 .605 r
.55698 .61122 m .55786 .6104 L .55928 .6093 L F
.772 .336 .217 r
.55542 .61062 m .55513 .61208 L .55698 .61122 L F
.55357 .60991 m .55513 .61208 L .55542 .61062 L F
.559 .399 .621 r
.55507 .6137 m .55671 .61554 L .55513 .61208 L F
.814 .694 .732 r
.55513 .61208 m .55671 .61554 L .55767 .61188 L F
.665 .551 .716 r
.55717 .61079 m .55492 .61312 L .55513 .61208 L F
.55492 .61312 m .5541 .61397 L .55513 .61208 L F
.55717 .61079 m .55832 .61544 L .5541 .61397 L F
0 .157 .698 r
.55955 .61678 m .56012 .61915 L .55831 .61561 L F
.69 .185 .036 r
.55831 .61561 m .55746 .61641 L .55955 .61678 L F
.665 .551 .716 r
.55832 .61544 m .55851 .61619 L .55795 .61591 L F
.55832 .61544 m .55795 .61591 L .5541 .61397 L F
.55 .468 .715 r
.55746 .61641 m .55672 .61847 L .55602 .61767 L F
.55672 .61847 m .5566 .6188 L .55618 .61798 L F
.55672 .61847 m .55618 .61798 L .55602 .61767 L F
.55746 .61641 m .55602 .61767 L .5541 .61397 L F
.749 .669 .772 r
.55602 .61767 m .55606 .61763 L .55607 .61763 L F
.55553 .61783 m .55606 .61763 L .55585 .61785 L F
.766 .706 .796 r
.55553 .61783 m .5566 .6188 L .55746 .61641 L F
.778 .283 .03 r
.55736 .6196 m .55801 .61966 L .55553 .61783 L F
.55801 .61966 m .5587 .61972 L .55691 .61866 L F
.55801 .61966 m .55691 .61866 L .55553 .61783 L F
.86 .943 .872 r
.72189 .48702 m .72055 .49017 L .72285 .48766 L F
.72189 .48702 m .71947 .4895 L .72055 .49017 L F
.405 .045 .237 r
.40512 .61062 m .40429 .61268 L .40205 .61313 L F
.415 .174 .437 r
.40767 .60784 m .40721 .61065 L .40512 .61062 L F
.434 .094 .289 r
.40721 .61065 m .40429 .61268 L .40512 .61062 L F
.481 .267 .511 r
.44635 .69571 m .44476 .69367 L .44384 .69243 L F
.44635 .69571 m .44416 .69606 L .44476 .69367 L F
.33 .333 .712 r
.56063 .64534 m .56261 .64395 L .56031 .642 L F
.104 .122 .594 r
.56063 .64534 m .56262 .64637 L .56261 .64395 L F
.56063 .64534 m .56129 .64797 L .56262 .64637 L F
.774 .446 .431 r
.79491 .52107 m .79828 .52171 L .7958 .52216 L F
.79491 .52107 m .79828 .52171 L .7958 .52216 L F
.724 .531 .628 r
.60704 .55639 m .60938 .55377 L .60704 .55387 L F
.60704 .55639 m .61066 .55672 L .60938 .55377 L F
.465 .245 .495 r
.44168 .6821 m .44199 .68453 L .43919 .68525 L F
.583 .327 .494 r
.44381 .68414 m .44168 .6821 L .44398 .68173 L F
.44381 .68414 m .44199 .68453 L .44168 .6821 L F
.76 .652 .742 r
.54419 .76146 m .54543 .76491 L .54378 .76456 L F
.982 .692 .343 r
.54543 .76491 m .54232 .76521 L .54378 .76456 L F
.777 .493 .505 r
.54543 .76491 m .5455 .76733 L .54408 .76504 L F
.54543 .76491 m .54408 .76504 L .54378 .76456 L F
.982 .692 .343 r
.54543 .76491 m .54447 .76509 L .54243 .76521 L F
.54543 .76491 m .54243 .76521 L .54232 .76521 L F
.54543 .76491 m .5455 .76733 L .54447 .76509 L F
.979 .684 .334 r
.54419 .76146 m .54447 .76509 L .54543 .76491 L F
.982 .692 .343 r
.54447 .76509 m .5455 .76733 L .54543 .76491 L F
.448 .469 .788 r
.41859 .68496 m .42137 .68782 L .42075 .6845 L F
.329 .505 .879 r
.47451 .70163 m .47796 .70441 L .47624 .70168 L F
.745 .747 .854 r
.57117 .63597 m .56776 .63502 L .56953 .63521 L F
.57117 .63597 m .56849 .63663 L .56776 .63502 L F
.071 .595 .873 r
.56953 .63521 m .57299 .63617 L .57117 .63597 L F
.398 .131 .388 r
.32154 .60799 m .3211 .61017 L .31884 .61077 L F
.519 .237 .427 r
.32335 .60967 m .32154 .60799 L .32368 .60755 L F
.32335 .60967 m .3211 .61017 L .32154 .60799 L F
.213 .68 .942 r
.34562 .58518 m .34763 .58526 L .34934 .58603 L F
.373 .79 .977 r
.34763 .58526 m .35155 .58559 L .34934 .58603 L F
.602 .52 .734 r
.52432 .6535 m .52116 .65076 L .5226 .65058 L F
.268 0 0 r
.53652 .69895 m .53925 .69911 L .54066 .69881 L F
.56 .336 .533 r
.54066 .69881 m .54032 .70193 L .53779 .70211 L F
.449 .241 .505 r
.54244 .70117 m .54032 .70193 L .54066 .69881 L F
.667 .303 .346 r
.67275 .48808 m .67167 .49003 L .66919 .48825 L F
.649 .283 .336 r
.67523 .48993 m .67167 .49003 L .67275 .48808 L F
.529 .331 .556 r
.41001 .60513 m .40998 .60743 L .40767 .60784 L F
.516 .261 .467 r
.40954 .60931 m .40767 .60784 L .40998 .60743 L F
.40954 .60931 m .40721 .61065 L .40767 .60784 L F
.738 .328 .272 r
.55928 .6093 m .55786 .6104 L .56132 .61029 L F
.41 .217 .506 r
.57774 .65584 m .57561 .6593 L .57562 .65647 L F
.52 .376 .626 r
.5928 .62772 m .59509 .62716 L .59263 .62511 L F
.616 .358 .504 r
.59263 .62511 m .59509 .62716 L .59518 .62494 L F
.337 .178 .512 r
.59992 .61907 m .60154 .616 L .59959 .61663 L F
.261 .767 .864 r
.67985 .50818 m .67899 .50805 L .67652 .50843 L F
.198 .727 .77 r
.68219 .50753 m .67899 .50805 L .67985 .50818 L F
.247 .003 .333 r
.6096 .62522 m .6097 .62697 L .60698 .6279 L F
.482 .244 .476 r
.28838 .59585 m .29049 .59545 L .28872 .5938 L F
.5 .242 .455 r
.28872 .5938 m .29049 .59545 L .29092 .59338 L F
.658 .299 .352 r
.51416 .64917 m .5176 .65032 L .51464 .65019 L F
0 0 .383 r
.57299 .63617 m .57331 .63827 L .57201 .63951 L F
0 0 0 r
.57201 .64029 m .57201 .63951 L .57331 .63827 L F
.57201 .64029 m .57155 .64223 L .57201 .63951 L F
.37 .47 .832 r
.73233 .51021 m .73061 .51154 L .729 .5086 L F
.359 .45 .818 r
.73233 .51021 m .73354 .51338 L .73061 .51154 L F
.106 0 0 r
.70712 .47465 m .70453 .47554 L .70524 .47456 L F
.42 .053 .232 r
.45258 .6551 m .45546 .6533 L .45337 .65381 L F
.877 .886 .837 r
.66466 .511 m .66245 .51171 L .66434 .51019 L F
.79 .735 .801 r
.36571 .59699 m .36712 .59929 L .36937 .59653 L F
.489 .616 .903 r
.53658 .63556 m .53692 .63895 L .5343 .63593 L F
.53658 .63556 m .53853 .63831 L .53692 .63895 L F
.084 0 0 r
.53969 .59746 m .53882 .597 L .53793 .59757 L F
.53969 .59746 m .54136 .59653 L .53882 .597 L F
.575 .489 .72 r
.77074 .49062 m .76821 .49125 L .76761 .48765 L F
.535 .381 .618 r
.77074 .49062 m .7685 .49376 L .76821 .49125 L F
.314 .768 .954 r
.4957 .61933 m .49791 .61915 L .49925 .61961 L F
.293 0 0 r
.49791 .61915 m .50122 .61966 L .49925 .61961 L F
.605 .576 .795 r
.77123 .51016 m .77022 .51399 L .76931 .51064 L F
.77123 .51016 m .7731 .51333 L .77022 .51399 L F
.574 .386 .589 r
.7732 .51562 m .77022 .51399 L .7731 .51333 L F
.7732 .51562 m .77033 .51634 L .77022 .51399 L F
.684 .141 0 r
.74392 .47398 m .74602 .47603 L .74742 .47666 L F
0 .438 .811 r
.74602 .47603 m .75069 .47801 L .74742 .47666 L F
.467 .159 .359 r
.66238 .4855 m .66481 .48502 L .66582 .48229 L F
.553 .244 .398 r
.66582 .48229 m .66826 .48374 L .6679 .48239 L F
.66582 .48229 m .66481 .48502 L .66826 .48374 L F
.6 .124 .097 r
.51547 .70395 m .5144 .70195 L .51314 .70388 L F
.51547 .70395 m .51808 .70407 L .5144 .70195 L F
.6 .13 .111 r
.5144 .70195 m .51808 .70407 L .51671 .70242 L F
.321 .803 .752 r
.69953 .46693 m .70181 .46606 L .70244 .46606 L F
.106 0 0 r
.70181 .46606 m .70547 .46643 L .70244 .46606 L F
.902 .893 .811 r
.66738 .50309 m .66565 .50574 L .66443 .50489 L F
.938 .777 .656 r
.66565 .50574 m .66353 .50698 L .66443 .50489 L F
.351 0 0 r
.5241 .70541 m .5201 .7066 L .52072 .70411 L F
.5241 .70541 m .5225 .70659 L .5201 .7066 L F
.995 .84 .574 r
.52285 .70409 m .5241 .70541 L .52606 .70449 L F
.52285 .70409 m .5225 .70659 L .5241 .70541 L F
.362 .36 .722 r
.60438 .6446 m .60329 .64808 L .60227 .64512 L F
.60438 .6446 m .60539 .64677 L .60329 .64808 L F
.314 .264 .641 r
.60329 .64808 m .60521 .64936 L .60416 .65065 L F
.60329 .64808 m .60539 .64677 L .60521 .64936 L F
.935 .965 .747 r
.56544 .59532 m .56574 .59666 L .5675 .59349 L F
.97 .821 .401 r
.56544 .59532 m .56553 .59902 L .56574 .59666 L F
.317 .794 .915 r
.3155 .58279 m .31708 .58247 L .31886 .58263 L F
0 .551 .712 r
.31708 .58247 m .32123 .58269 L .31886 .58263 L F
.613 .916 .652 r
.26426 .68647 m .26439 .68643 L .26374 .68687 L F
.994 .77 .486 r
.26439 .68643 m .26396 .69002 L .26374 .68687 L F
.844 .598 .566 r
.74348 .47303 m .74602 .47603 L .74392 .47398 L F
.523 .509 .782 r
.30816 .64198 m .31013 .64159 L .30941 .63845 L F
.663 .574 .745 r
.30816 .64198 m .31317 .64434 L .31013 .64159 L F
.172 0 0 r
.33412 .60156 m .33024 .60329 L .33214 .60153 L F
.582 .403 .604 r
.41239 .60471 m .40998 .60743 L .41001 .60513 L F
.359 .161 .47 r
.60416 .65065 m .6039 .65295 L .60197 .65348 L F
.345 0 0 r
.51588 .63211 m .51895 .63369 L .51768 .63301 L F
.892 .797 .749 r
.41706 .69989 m .41922 .69478 L .41505 .6964 L F
.482 .648 .931 r
.76905 .48571 m .76761 .48765 L .76607 .48569 L F
.76905 .48571 m .76979 .48737 L .76761 .48765 L F
.575 .489 .72 r
.77074 .49062 m .76761 .48765 L .76979 .48737 L F
.711 .544 .662 r
.59185 .57106 m .59373 .57358 L .58991 .57382 L F
.556 .799 .99 r
.52625 .63689 m .52871 .63635 L .52988 .63747 L F
.574 .742 .956 r
.53088 .63545 m .52988 .63747 L .52871 .63635 L F
.53088 .63545 m .53225 .63682 L .52988 .63747 L F
.208 0 0 r
.36249 .63798 m .3661 .63591 L .36456 .63749 L F
.19 0 0 r
.3661 .63591 m .36675 .63693 L .36456 .63749 L F
.3661 .63591 m .36819 .6354 L .36675 .63693 L F
.544 .518 .777 r
.75702 .49623 m .75815 .49954 L .76042 .49902 L F
.452 .388 .695 r
.75815 .49954 m .76079 .50123 L .76042 .49902 L F
.75815 .49954 m .75899 .50169 L .76079 .50123 L F
.697 .516 .64 r
.54735 .65879 m .54301 .65909 L .54303 .65626 L F
.379 0 .078 r
.2956 .59042 m .29782 .59017 L .2993 .58839 L F
.322 0 .041 r
.2993 .58839 m .29782 .59017 L .30074 .58903 L F
.327 0 .012 r
.2993 .58839 m .30074 .58903 L .30159 .58804 L F
.5 .342 .598 r
.44199 .68453 m .43935 .68756 L .43919 .68525 L F
.902 .893 .811 r
.66738 .50309 m .66443 .50489 L .66598 .50185 L F
.816 .819 .852 r
.66906 .50152 m .66738 .50309 L .66598 .50185 L F
.36 .008 .225 r
.75904 .52374 m .75713 .5223 L .75961 .52164 L F
.75904 .52374 m .75665 .52448 L .75713 .5223 L F
.792 .753 .817 r
.49885 .78561 m .50023 .78778 L .49685 .78746 L F
.462 .608 .91 r
.50222 .78762 m .50023 .78778 L .49885 .78561 L F
.359 .504 .867 r
.50308 .78948 m .50023 .78778 L .50222 .78762 L F
.472 .363 .649 r
.28253 .60804 m .2843 .60454 L .28234 .60517 L F
.753 .505 .556 r
.54898 .66055 m .54301 .65909 L .54735 .65879 L F
.54898 .66055 m .54298 .66145 L .54301 .65909 L F
.621 .402 .564 r
.5455 .66318 m .54298 .66145 L .54898 .66055 L F
.978 .879 .666 r
.54886 .65864 m .54898 .66055 L .54735 .65879 L F
.54886 .65864 m .54734 .66071 L .54898 .66055 L F
.236 0 0 r
.54769 .66248 m .5455 .66318 L .54898 .66055 L F
.54769 .66248 m .54898 .66055 L .54734 .66071 L F
.523 .3 .517 r
.50788 .64553 m .51004 .64704 L .51032 .64474 L F
.50788 .64553 m .51004 .64704 L .51032 .64474 L F
0 0 .419 r
.71109 .47504 m .71238 .47442 L .70998 .47458 L F
.356 .042 .289 r
.37007 .61805 m .37275 .61583 L .37091 .61666 L F
.496 .016 .047 r
.5273 .76438 m .52611 .76524 L .5245 .76487 L F
.227 .116 .511 r
.52911 .76133 m .5273 .76438 L .52714 .76255 L F
.52911 .76133 m .52929 .76401 L .5273 .76438 L F
0 0 0 r
.52929 .76401 m .52611 .76524 L .5273 .76438 L F
.011 0 .103 r
.47628 .65072 m .4755 .65324 L .474 .65361 L F
.567 .379 .587 r
.4755 .65324 m .47325 .65531 L .474 .65361 L F
.935 .965 .747 r
.56544 .59532 m .5675 .59349 L .56583 .59462 L F
.586 .372 .556 r
.59518 .62494 m .59788 .62457 L .59774 .62222 L F
.503 .352 .609 r
.59774 .62222 m .60019 .62171 L .59992 .61907 L F
.469 .249 .497 r
.59999 .62396 m .59774 .62222 L .59788 .62457 L F
.59999 .62396 m .60019 .62171 L .59774 .62222 L F
.614 .8 .97 r
.43123 .70663 m .43554 .70712 L .43377 .70428 L F
.368 .68 .978 r
.43554 .70712 m .43608 .70583 L .43377 .70428 L F
.43554 .70712 m .43737 .70708 L .43608 .70583 L F
0 0 .043 r
.47706 .65146 m .47628 .65072 L .47824 .65002 L F
.47706 .65146 m .4755 .65324 L .47628 .65072 L F
.077 .373 .839 r
.50557 .62363 m .50741 .62474 L .50633 .62525 L F
.831 .958 .895 r
.74196 .51238 m .74121 .51461 L .73941 .51518 L F
.74196 .51238 m .74277 .51329 L .74121 .51461 L F
.313 0 0 r
.35384 .62629 m .35616 .62605 L .35771 .62463 L F
.259 0 0 r
.35616 .62605 m .36007 .6245 L .35771 .62463 L F
.293 .265 .656 r
.28388 .61393 m .28495 .61004 L .28281 .61058 L F
.28388 .61393 m .28545 .61249 L .28495 .61004 L F
.422 .475 .81 r
.28388 .61393 m .28673 .61595 L .28545 .61249 L F
.729 .641 .76 r
.74394 .49053 m .74743 .49155 L .74631 .48781 L F
.375 .418 .778 r
.74631 .48781 m .74743 .49155 L .74903 .48937 L F
.837 .778 .796 r
.7277 .50207 m .73053 .50218 L .73159 .4995 L F
.97 .776 .585 r
.72826 .50348 m .73053 .50218 L .7277 .50207 L F
.72826 .50348 m .72969 .50482 L .73053 .50218 L F
.975 .921 .663 r
.47472 .6588 m .47374 .6603 L .47544 .65967 L F
.326 .805 .899 r
.36131 .5973 m .36357 .59745 L .36571 .59699 L F
.872 .543 .424 r
.50783 .79544 m .51122 .79595 L .50969 .79797 L F
.787 .912 .522 r
.51063 .79635 m .51122 .79595 L .51136 .79506 L F
.50969 .79797 m .51122 .79595 L .51063 .79635 L F
.504 0 0 r
.51081 .79622 m .51122 .79595 L .50783 .79544 L F
.51088 .79624 m .51122 .79595 L .51081 .79622 L F
.781 .879 .453 r
.51136 .79506 m .51122 .79595 L .51088 .79624 L F
.376 .743 .99 r
.51136 .79506 m .5134 .79585 L .51122 .79595 L F
.51136 .79506 m .5134 .79585 L .51122 .79595 L F
.37 .741 .99 r
.55332 .64401 m .55499 .64515 L .55214 .64512 L F
.55332 .64401 m .55499 .64515 L .55214 .64512 L F
.445 .358 .664 r
.59114 .63341 m .59267 .63 L .59108 .63072 L F
.428 .809 .991 r
.77123 .51016 m .76931 .51064 L .76876 .51057 L F
.434 .236 .51 r
.3211 .61017 m .31866 .61339 L .31884 .61077 L F
.805 .959 .912 r
.26843 .81656 m .26651 .81895 L .26595 .81754 L F
.26843 .81656 m .26879 .81686 L .26651 .81895 L F
.613 .398 .567 r
.26879 .81686 m .2658 .81977 L .26651 .81895 L F
.75 .758 .859 r
.50151 .79818 m .50354 .79975 L .50377 .79881 L F
.654 .693 .874 r
.26974 .83376 m .27156 .83297 L .26927 .83306 L F
.287 0 0 r
.34398 .64409 m .34064 .64472 L .34194 .64436 L F
.545 .169 .278 r
.58741 .66099 m .591 .65864 L .58968 .65853 L F
.419 .311 .624 r
.4205 .68202 m .42226 .67847 L .42004 .67974 L F
.029 0 0 r
.75147 .52713 m .7544 .52465 L .75361 .52593 L F
.167 0 0 r
.75361 .52593 m .7544 .52465 L .75665 .52448 L F
.195 .542 .928 r
.75671 .48208 m .75612 .48223 L .75287 .47986 L F
.595 .459 .665 r
.41922 .69478 m .41999 .69759 L .41998 .69342 L F
.671 .3 .335 r
.41987 .7026 m .42058 .70616 L .41843 .70413 L F
.184 .059 .465 r
.42106 .70136 m .42197 .70369 L .41987 .7026 L F
.55 0 0 r
.51808 .70407 m .51884 .70422 L .52072 .70411 L F
.521 .226 .406 r
.52072 .70411 m .5201 .7066 L .51813 .70612 L F
.011 0 0 r
.51884 .70422 m .52285 .70409 L .52072 .70411 L F
.291 .021 .32 r
.52072 .70411 m .52285 .70409 L .52249 .70273 L F
.018 0 0 r
.49125 .80699 m .49048 .80672 L .49035 .80695 L F
.702 .764 .9 r
.31013 .64159 m .3141 .64229 L .3126 .64063 L F
.783 .641 .704 r
.31013 .64159 m .31317 .64434 L .3141 .64229 L F
.193 0 .369 r
.31317 .64434 m .31361 .64474 L .3141 .64229 L F
.562 .714 .943 r
.3126 .64063 m .3141 .64229 L .31605 .64163 L F
.397 .172 .451 r
.3141 .64229 m .31361 .64474 L .31605 .64163 L F
.756 .689 .787 r
.54886 .65864 m .55047 .6607 L .55235 .65925 L F
.365 .583 .926 r
.49794 .79571 m .50011 .79834 L .50151 .79818 L F
0 0 0 r
.52432 .6535 m .52333 .65522 L .52246 .65546 L F
.918 .683 .567 r
.5205 .65637 m .52259 .65975 L .52246 .65546 L F
.5205 .65637 m .52246 .65546 L .52333 .65522 L F
.865 .48 .312 r
.71483 .47314 m .71598 .47568 L .71685 .47396 L F
0 0 0 r
.71598 .47568 m .71883 .47477 L .71685 .47396 L F
.268 .392 .804 r
.72549 .50191 m .72682 .50518 L .72826 .50348 L F
0 .216 .732 r
.72682 .50518 m .72868 .50601 L .72826 .50348 L F
.808 .724 .772 r
.65653 .48776 m .65964 .48865 L .66003 .48505 L F
.563 .273 .434 r
.65404 .48973 m .65649 .48965 L .65653 .48776 L F
.415 .158 .413 r
.65653 .48776 m .65649 .48965 L .65876 .48874 L F
.599 .441 .639 r
.65404 .48973 m .65493 .49275 L .65649 .48965 L F
.657 .948 .708 r
.65649 .48965 m .65494 .4905 L .65724 .48843 L F
.415 .158 .413 r
.65653 .48776 m .65791 .48837 L .65845 .48831 L F
.657 .948 .708 r
.65744 .48841 m .65724 .48843 L .65782 .48791 L F
.65649 .48965 m .65724 .48843 L .65744 .48841 L F
.415 .158 .413 r
.65845 .48831 m .65876 .48874 L .65964 .48865 L F
.65791 .48837 m .65876 .48874 L .65845 .48831 L F
.002 0 .495 r
.66003 .48505 m .6598 .48716 L .66139 .48648 L F
0 0 0 r
.66004 .48673 m .66218 .48613 L .66139 .48648 L F
.006 0 0 r
.66238 .4855 m .66139 .48648 L .66363 .48573 L F
0 0 0 r
.66218 .48613 m .66363 .48573 L .66139 .48648 L F
.002 0 .495 r
.6598 .48716 m .65964 .48865 L .66139 .48648 L F
.642 .944 .712 r
.65964 .48865 m .65876 .48874 L .66139 .48648 L F
.643 .305 .384 r
.66334 .48814 m .65996 .48992 L .65964 .48865 L F
.85 .428 0 r
.65964 .48865 m .65876 .48874 L .65996 .48992 L F
.323 .54 .908 r
.33492 .62528 m .33684 .62746 L .33528 .62703 L F
.548 .499 .752 r
.4936 .67435 m .49566 .67332 L .49447 .67034 L F
0 .334 .799 r
.75183 .47865 m .7517 .47927 L .75069 .47801 L F
.75183 .47865 m .75287 .47986 L .7517 .47927 L F
.6 .029 0 r
.72497 .47327 m .72765 .47502 L .72832 .47453 L F
.583 .871 .556 r
.72832 .47453 m .72969 .47285 L .73099 .47379 L F
.72832 .47453 m .72765 .47502 L .72969 .47285 L F
.711 .5 .601 r
.46142 .66501 m .45906 .66757 L .45907 .6651 L F
.665 .434 .559 r
.46142 .66501 m .46141 .66776 L .45906 .66757 L F
.41 .091 .31 r
.46488 .6644 m .46141 .66776 L .46142 .66501 L F
.57 .325 .505 r
.57678 .57019 m .57938 .56773 L .57698 .56815 L F
.98 .719 .459 r
.50577 .75923 m .50609 .76197 L .50479 .76029 L F
.50594 .75905 m .50595 .75933 L .50577 .75923 L F
.50595 .75933 m .50609 .76197 L .50577 .75923 L F
.478 .322 .59 r
.50807 .76114 m .50609 .76197 L .50594 .75905 L F
.98 .719 .459 r
.50594 .75905 m .50577 .75923 L .5062 .76074 L F
.50577 .75923 m .50479 .76029 L .5062 .76074 L F
.867 .423 .054 r
.50515 .75929 m .50579 .76017 L .50534 .75974 L F
.886 .455 .124 r
.50594 .75905 m .5062 .76072 L .50376 .75738 L F
.613 .733 .931 r
.50479 .76029 m .50713 .76153 L .50608 .76062 L F
.886 .455 .124 r
.5062 .76072 m .5062 .76074 L .50617 .76069 L F
.5062 .76072 m .50617 .76069 L .50376 .75738 L F
.613 .733 .931 r
.50479 .76029 m .50609 .76197 L .50713 .76153 L F
.50608 .76062 m .50713 .76153 L .50807 .76114 L F
.98 .735 .491 r
.50705 .75809 m .50807 .76114 L .50594 .75905 L F
.465 .24 .488 r
.50534 .75975 m .50678 .76041 L .50705 .75809 L F
.50479 .76029 m .50544 .75997 L .50534 .75975 L F
.50479 .76029 m .50534 .75975 L .50334 .75786 L F
.664 .707 .879 r
.50334 .75786 m .50544 .75997 L .50479 .76029 L F
.184 .651 .936 r
.50609 .76062 m .50607 .76061 L .50479 .76029 L F
.664 .707 .879 r
.50544 .75997 m .50607 .76061 L .50479 .76029 L F
.184 .651 .936 r
.50607 .76061 m .50559 .76034 L .50479 .76029 L F
.664 .707 .879 r
.50607 .76061 m .5062 .76074 L .50479 .76029 L F
.465 .24 .488 r
.50479 .76029 m .50559 .76034 L .50544 .75997 L F
.50559 .76034 m .50678 .76041 L .50534 .75975 L F
.867 .423 .054 r
.50462 .75856 m .50515 .75929 L .50336 .75784 L F
.50515 .75929 m .50534 .75974 L .50336 .75784 L F
.50579 .76017 m .5062 .76074 L .50398 .75847 L F
.50579 .76017 m .50398 .75847 L .50336 .75784 L F
.50376 .75738 m .50462 .75856 L .50336 .75784 L F
.368 .677 .976 r
.50376 .75738 m .50705 .75809 L .50594 .75905 L F
.465 .24 .488 r
.50534 .75975 m .50705 .75809 L .50334 .75786 L F
.184 .651 .936 r
.50807 .76114 m .50678 .76041 L .50559 .76034 L F
.50807 .76114 m .50559 .76034 L .50609 .76062 L F
.867 .423 .054 r
.50336 .75784 m .50608 .76062 L .50334 .75786 L F
.50608 .76062 m .5062 .76074 L .50607 .76061 L F
.50608 .76062 m .50607 .76061 L .50334 .75786 L F
.969 .704 .475 r
.59268 .65344 m .59038 .65251 L .58954 .65278 L F
.59268 .65344 m .59074 .65493 L .59038 .65251 L F
0 0 0 r
.5932 .65384 m .59268 .65344 L .59475 .65275 L F
.5932 .65384 m .59074 .65493 L .59268 .65344 L F
.981 .758 .347 r
.60401 .59895 m .60344 .59565 L .60431 .59658 L F
.62 .767 .95 r
.4209 .69839 m .42443 .69909 L .42345 .69758 L F
.585 .733 .945 r
.42345 .69758 m .42443 .69909 L .42686 .69863 L F
.496 .494 .785 r
.42443 .69909 m .42665 .70153 L .42686 .69863 L F
.696 .335 .359 r
.47699 .70701 m .47576 .7093 L .4738 .7069 L F
.609 .223 .286 r
.47938 .70755 m .47576 .7093 L .47699 .70701 L F
.687 .869 .968 r
.67046 .50979 m .6745 .50947 L .67313 .50799 L F
.69 .815 .942 r
.67313 .50799 m .6745 .50947 L .67652 .50843 L F
.767 .701 .789 r
.5455 .76733 m .54679 .77019 L .5497 .76695 L F
.995 .855 .515 r
.62026 .59296 m .61979 .59551 L .62056 .59502 L F
.909 .878 .45 r
.61943 .59578 m .62056 .59502 L .61979 .59551 L F
.61943 .59578 m .61937 .59925 L .62056 .59502 L F
0 0 0 r
.48013 .64717 m .47947 .64842 L .48075 .6447 L F
.163 0 .175 r
.48269 .64397 m .48013 .64717 L .48075 .6447 L F
.774 .67 .749 r
.52606 .70449 m .52968 .70504 L .52838 .70156 L F
.773 .946 .934 r
.74567 .51106 m .74277 .51329 L .74196 .51238 L F
.196 .224 .663 r
.49875 .64471 m .4993 .64821 L .50063 .64672 L F
.349 .455 .828 r
.4993 .64821 m .50203 .65004 L .50129 .64828 L F
.612 .613 .828 r
.50063 .64672 m .50203 .65004 L .50438 .64945 L F
.784 .718 .79 r
.50203 .65257 m .50438 .64945 L .50203 .65004 L F
.704 .516 .632 r
.4996 .65243 m .50203 .65004 L .49998 .65082 L F
.4996 .65243 m .50203 .65257 L .50203 .65004 L F
.456 .088 .25 r
.50195 .65215 m .50161 .65012 L .50174 .64998 L F
.679 .191 .084 r
.50286 .64924 m .50278 .65065 L .50166 .64965 L F
.50151 .64905 m .50166 .64965 L .50089 .64896 L F
.50286 .64924 m .50166 .64965 L .50151 .64905 L F
.349 .455 .828 r
.4993 .64821 m .50129 .64828 L .49997 .64747 L F
.612 .613 .828 r
.50063 .64672 m .50438 .64945 L .50089 .64896 L F
.075 .242 .732 r
.50089 .64896 m .50278 .65065 L .50175 .64829 L F
.456 .088 .25 r
.50203 .65119 m .50174 .64998 L .50216 .64951 L F
.50195 .65215 m .50174 .64998 L .50203 .65119 L F
.679 .191 .084 r
.50438 .64945 m .50385 .64984 L .50286 .64924 L F
.50385 .64984 m .50278 .65065 L .50286 .64924 L F
.349 .455 .828 r
.49997 .64747 m .50129 .64828 L .50063 .64672 L F
.536 .448 .703 r
.4993 .64821 m .49998 .65082 L .50203 .65004 L F
.874 .948 .857 r
.72433 .48424 m .72285 .48766 L .72581 .4852 L F
.72433 .48424 m .72189 .48702 L .72285 .48766 L F
.97 .656 .351 r
.53492 .66237 m .53482 .66422 L .53367 .66311 L F
.628 .788 .959 r
.53357 .65981 m .53492 .66237 L .53769 .66179 L F
.642 .39 .522 r
.53769 .66179 m .53482 .66422 L .53492 .66237 L F
0 0 0 r
.53492 .66237 m .53545 .66241 L .53769 .66179 L F
.53492 .66237 m .53367 .66311 L .53545 .66241 L F
.545 .169 .278 r
.58741 .66099 m .58996 .66122 L .591 .65864 L F
.127 0 .096 r
.591 .65864 m .58996 .66122 L .59188 .65988 L F
.816 .819 .852 r
.66906 .50152 m .66598 .50185 L .66747 .50072 L F
.7 .87 .962 r
.66906 .50152 m .67108 .49895 L .6722 .50005 L F
.66906 .50152 m .66747 .50072 L .67108 .49895 L F
0 0 0 r
.48013 .64717 m .47824 .65002 L .47947 .64842 L F
.886 .881 .824 r
.55767 .61188 m .56132 .61029 L .55786 .6104 L F
.55767 .61188 m .5596 .6125 L .56132 .61029 L F
.64 .19 .166 r
.4619 .70782 m .4605 .70937 L .45823 .70771 L F
.515 .063 .116 r
.46418 .70792 m .4605 .70937 L .4619 .70782 L F
.585 .517 .744 r
.77209 .49721 m .76986 .49912 L .76982 .49793 L F
.77209 .49721 m .77236 .49867 L .76986 .49912 L F
.501 .535 .824 r
.77306 .50139 m .76986 .49912 L .77236 .49867 L F
.214 .297 .734 r
.54976 .66194 m .54886 .65864 L .55235 .65925 L F
.684 .98 .863 r
.28274 .63268 m .28279 .63187 L .28493 .63119 L F
0 .358 .827 r
.28274 .63268 m .28443 .63345 L .28279 .63187 L F
.41 .091 .31 r
.46488 .6644 m .46371 .66713 L .46141 .66776 L F
.303 0 .256 r
.46575 .66628 m .46488 .6644 L .46735 .66502 L F
.46575 .66628 m .46371 .66713 L .46488 .6644 L F
.539 .265 .449 r
.57938 .56773 m .58202 .56753 L .58234 .56493 L F
.456 .163 .378 r
.58202 .56753 m .58486 .56458 L .58234 .56493 L F
.052 .03 .51 r
.61893 .60612 m .61746 .60564 L .61888 .60393 L F
.61893 .60612 m .61775 .60669 L .61746 .60564 L F
0 0 .38 r
.55917 .65791 m .5592 .66188 L .55851 .65914 L F
.32 0 .109 r
.37943 .62847 m .37872 .62969 L .37635 .63011 L F
.358 0 .129 r
.38093 .62923 m .37943 .62847 L .38148 .62767 L F
.38093 .62923 m .37872 .62969 L .37943 .62847 L F
.832 .648 .654 r
.50204 .65526 m .50719 .65367 L .50203 .65257 L F
.582 .645 .878 r
.50438 .64945 m .50719 .65367 L .50828 .65241 L F
0 0 0 r
.50719 .65367 m .50701 .65449 L .50828 .65241 L F
.569 .272 .425 r
.46324 .64744 m .4657 .64725 L .46623 .64535 L F
.438 .151 .378 r
.46623 .64535 m .46792 .64674 L .46841 .64482 L F
.46623 .64535 m .4657 .64725 L .46792 .64674 L F
.047 0 0 r
.59392 .67111 m .59251 .67283 L .5907 .67312 L F
.166 0 0 r
.5947 .67213 m .59392 .67111 L .59521 .66997 L F
.5947 .67213 m .59251 .67283 L .59392 .67111 L F
0 .057 .615 r
.58954 .65278 m .59038 .65251 L .58866 .64962 L F
.759 .674 .768 r
.65421 .50197 m .65555 .50549 L .65802 .50265 L F
.513 .306 .536 r
.45806 .67878 m .45561 .68162 L .45565 .67921 L F
.45561 .68162 m .45806 .67878 L .45565 .67921 L F
.728 .508 .594 r
.68208 .49104 m .67849 .4932 L .6787 .49044 L F
.68208 .49104 m .6821 .49345 L .67849 .4932 L F
.33 0 .234 r
.46841 .64482 m .47046 .64428 L .47132 .64195 L F
.223 0 .346 r
.47132 .64195 m .47321 .64148 L .47334 .63899 L F
.271 0 .208 r
.47132 .64195 m .47253 .64345 L .47321 .64148 L F
.47132 .64195 m .47046 .64428 L .47253 .64345 L F
.117 0 0 r
.45304 .67256 m .4569 .67082 L .4558 .67278 L F
.115 0 .014 r
.4558 .67278 m .4569 .67082 L .45871 .66997 L F
.136 .357 .817 r
.52055 .65795 m .5205 .65637 L .51838 .65595 L F
.617 .394 .556 r
.77033 .51634 m .76782 .51889 L .7677 .51669 L F
.564 .821 .994 r
.30521 .63547 m .30675 .63643 L .30741 .63492 L F
.192 .383 .823 r
.30675 .63643 m .30941 .63845 L .30741 .63492 L F
.848 .442 .267 r
.59684 .57625 m .59533 .57617 L .59373 .57358 L F
.792 .339 .167 r
.59684 .57625 m .59626 .57764 L .59533 .57617 L F
.59684 .57625 m .59893 .57863 L .59626 .57764 L F
.79 .735 .801 r
.36571 .59699 m .36937 .59653 L .36768 .59718 L F
.525 .92 .861 r
.37134 .59577 m .36768 .59718 L .36937 .59653 L F
.518 .397 .654 r
.41998 .69342 m .42234 .69638 L .42234 .6928 L F
.41998 .69342 m .41999 .69759 L .42234 .69638 L F
.269 .05 .385 r
.61548 .61046 m .6154 .61224 L .61342 .6135 L F
.101 0 .312 r
.6154 .61224 m .61331 .61607 L .61342 .6135 L F
.435 .475 .802 r
.6946 .46805 m .69657 .47155 L .69765 .47001 L F
.535 .39 .631 r
.42613 .66508 m .42834 .66715 L .42866 .66468 L F
.42613 .66508 m .42613 .66769 L .42834 .66715 L F
.678 .596 .757 r
.32045 .61891 m .31701 .61606 L .3191 .61568 L F
.591 .648 .875 r
.32107 .61538 m .32045 .61891 L .3191 .61568 L F
.32107 .61538 m .32315 .6185 L .32045 .61891 L F
.541 .726 .96 r
.37847 .59841 m .38089 .5978 L .37688 .59688 L F
.37847 .59841 m .38119 .59875 L .38089 .5978 L F
0 .421 .837 r
.54077 .62264 m .54245 .62287 L .53999 .62139 L F
.54077 .62264 m .54375 .62397 L .54245 .62287 L F
.622 .183 .184 r
.68195 .4793 m .68441 .48089 L .6854 .47924 L F
.168 0 0 r
.6854 .47924 m .68664 .48007 L .68786 .47934 L F
.6854 .47924 m .68441 .48089 L .68664 .48007 L F
.638 .75 .93 r
.33203 .62345 m .33078 .62562 L .32983 .62389 L F
.157 .476 .896 r
.51517 .63086 m .51329 .63111 L .51209 .62992 L F
.51517 .63086 m .51588 .63211 L .51329 .63111 L F
.554 .347 .555 r
.38345 .60778 m .38574 .60742 L .38581 .60475 L F
.626 .569 .771 r
.38454 .60145 m .38581 .60475 L .38776 .60226 L F
.593 .522 .744 r
.38581 .60475 m .38819 .60459 L .38776 .60226 L F
.568 .358 .555 r
.38574 .60742 m .38819 .60459 L .38581 .60475 L F
.808 .904 .908 r
.7394 .49219 m .74046 .49317 L .74036 .49019 L F
.745 .686 .794 r
.74036 .49019 m .74046 .49317 L .74394 .49053 L F
.474 .186 .395 r
.57197 .57318 m .57432 .57268 L .57464 .57091 L F
.483 .241 .471 r
.57432 .57268 m .57678 .57019 L .57464 .57091 L F
.447 .299 .586 r
.28379 .60191 m .28553 .59886 L .28371 .59944 L F
.759 .574 .647 r
.60352 .55604 m .60704 .55387 L .60347 .55369 L F
.60352 .55604 m .60704 .55639 L .60704 .55387 L F
.704 .486 .59 r
.46683 .69477 m .46997 .69292 L .46819 .69299 L F
.84 .673 .676 r
.54378 .76456 m .54232 .76521 L .5424 .76244 L F
.76 .652 .742 r
.54419 .76146 m .54378 .76456 L .5424 .76244 L F
.448 .822 .992 r
.32123 .58269 m .32329 .58222 L .32457 .58288 L F
.335 .758 .975 r
.3245 .58196 m .32457 .58288 L .32329 .58222 L F
.3245 .58196 m .32676 .58272 L .32457 .58288 L F
.883 .723 .679 r
.61788 .58403 m .62092 .58167 L .61994 .57967 L F
.61788 .58403 m .6196 .58496 L .62092 .58167 L F
.5 .671 .94 r
.55615 .65462 m .55464 .65637 L .553 .6532 L F
.55615 .65462 m .55666 .65614 L .55464 .65637 L F
.55 .635 .888 r
.52171 .63378 m .52062 .63637 L .51895 .63369 L F
.52171 .63378 m .52276 .63592 L .52062 .63637 L F
.591 .768 .964 r
.72074 .50566 m .72341 .50514 L .71975 .50433 L F
.359 .651 .967 r
.40549 .59855 m .40182 .59704 L .40475 .59749 L F
.454 .696 .971 r
.40665 .59726 m .40549 .59855 L .40475 .59749 L F
.40665 .59726 m .40775 .59856 L .40549 .59855 L F
.472 .363 .649 r
.28253 .60804 m .28449 .60772 L .2843 .60454 L F
.542 .399 .636 r
.28253 .60804 m .28495 .61004 L .28449 .60772 L F
.28253 .60804 m .28281 .61058 L .28495 .61004 L F
.579 .441 .657 r
.42405 .67058 m .42646 .67025 L .42613 .66769 L F
.407 .213 .503 r
.42437 .67317 m .42646 .67025 L .42405 .67058 L F
.078 .395 .852 r
.32292 .6478 m .32303 .64729 L .32101 .64598 L F
.509 .842 .998 r
.32516 .64675 m .32292 .6478 L .32609 .64617 L F
.32516 .64675 m .32303 .64729 L .32292 .6478 L F
0 0 0 r
.41491 .70196 m .41318 .70362 L .41554 .70355 L F
.485 .794 .999 r
.3369 .58337 m .33756 .58347 L .33852 .58303 L F
.231 .619 .955 r
.33852 .58303 m .33996 .58424 L .33912 .58274 L F
.485 .794 .999 r
.33756 .58347 m .34046 .58392 L .33852 .58303 L F
.231 .619 .955 r
.33852 .58303 m .33912 .58274 L .33851 .58165 L F
.33852 .58303 m .34203 .58457 L .33996 .58424 L F
.494 .244 .464 r
.39974 .6135 m .39936 .61569 L .39716 .61611 L F
.46 .183 .405 r
.40205 .61313 m .39936 .61569 L .39974 .6135 L F
.733 .908 .955 r
.72277 .47409 m .71883 .47477 L .72177 .47373 L F
.467 0 0 r
.72177 .47373 m .7252 .47562 L .72277 .47409 L F
.5 .339 .594 r
.72277 .47409 m .7252 .47562 L .72497 .47327 L F
.714 .718 .853 r
.76876 .51057 m .76643 .51092 L .76789 .5098 L F
.428 .809 .991 r
.77123 .51016 m .76876 .51057 L .77149 .5095 L F
.736 .585 .687 r
.61066 .55672 m .61056 .55914 L .61287 .55657 L F
.732 .579 .683 r
.61056 .55914 m .61449 .55935 L .61287 .55657 L F
0 0 .082 r
.52446 .67023 m .52662 .66822 L .52443 .66775 L F
.641 .664 .856 r
.52662 .66822 m .52446 .67023 L .52443 .66775 L F
.439 0 0 r
.45254 .70782 m .45623 .70722 L .45505 .70876 L F
.593 .146 .157 r
.45623 .70722 m .45682 .70931 L .45505 .70876 L F
.45623 .70722 m .45823 .70771 L .45682 .70931 L F
.049 0 .081 r
.47791 .63323 m .47976 .63257 L .48044 .63047 L F
0 0 0 r
.48044 .63047 m .48203 .62956 L .48284 .62771 L F
.028 0 .072 r
.48044 .63047 m .4813 .63155 L .48203 .62956 L F
.48044 .63047 m .47976 .63257 L .4813 .63155 L F
.653 .433 .571 r
.60114 .55598 m .60352 .55604 L .60347 .55369 L F
.093 0 0 r
.5907 .67312 m .58953 .67423 L .58741 .67487 L F
.008 0 0 r
.5907 .67312 m .59251 .67283 L .58953 .67423 L F
.84 .633 .622 r
.60112 .58146 m .59893 .57863 L .60104 .57921 L F
.524 .492 .762 r
.70453 .47554 m .70535 .47878 L .70301 .47913 L F
.753 .44 .455 r
.59373 .57358 m .59533 .57617 L .59202 .57592 L F
.641 .299 .376 r
.58991 .57382 m .59373 .57358 L .59202 .57592 L F
.636 .171 .132 r
.5663 .62605 m .56468 .62704 L .5678 .62689 L F
.16 0 .194 r
.47542 .63609 m .47749 .63542 L .47791 .63323 L F
0 0 .125 r
.47791 .63323 m .47883 .6342 L .47976 .63257 L F
.47791 .63323 m .47749 .63542 L .47883 .6342 L F
.498 .3 .542 r
.69355 .47665 m .69378 .47917 L .69124 .47955 L F
.594 .615 .842 r
.3279 .62401 m .32419 .62164 L .32615 .6214 L F
.482 .64 .926 r
.32821 .62155 m .3279 .62401 L .32615 .6214 L F
.32821 .62155 m .32983 .62389 L .3279 .62401 L F
.167 .276 .733 r
.55299 .6497 m .55248 .65095 L .55177 .64761 L F
.191 .153 .582 r
.55482 .6516 m .55248 .65095 L .55299 .6497 L F
.55482 .6516 m .553 .6532 L .55248 .65095 L F
.434 .542 .867 r
.43737 .70708 m .43989 .71051 L .44046 .70913 L F
0 0 .186 r
.6043 .65551 m .60399 .65649 L .60289 .65856 L F
.334 .341 .718 r
.60399 .65649 m .60465 .65911 L .60289 .65856 L F
.295 .375 .775 r
.60289 .65856 m .60465 .65911 L .60516 .66179 L F
.791 .679 .741 r
.49439 .63934 m .49484 .6419 L .49127 .64168 L F
.282 .445 .846 r
.49343 .64192 m .49578 .64295 L .49538 .64221 L F
.605 .51 .72 r
.49722 .64042 m .49484 .6419 L .49439 .63934 L F
.49722 .64042 m .49772 .64127 L .49484 .6419 L F
.596 .59 .815 r
.49875 .64471 m .49484 .6419 L .49772 .64127 L F
.282 .445 .846 r
.49343 .64192 m .49538 .64221 L .49419 .63996 L F
.821 .699 .73 r
.49209 .64173 m .49343 .64192 L .49127 .64168 L F
.49484 .6419 m .49343 .64192 L .49209 .64173 L F
.219 0 .33 r
.47334 .63899 m .4754 .63833 L .47542 .63609 L F
.251 .018 .353 r
.47334 .63899 m .47488 .64058 L .4754 .63833 L F
.47334 .63899 m .47321 .64148 L .47488 .64058 L F
0 0 0 r
.61548 .61046 m .61775 .60669 L .61767 .6097 L F
.096 0 .132 r
.61548 .61046 m .61683 .61121 L .6154 .61224 L F
.61548 .61046 m .61767 .6097 L .61683 .61121 L F
.546 .497 .753 r
.54974 .66473 m .54741 .6669 L .54697 .66531 L F
.283 .4 .805 r
.73257 .5225 m .73359 .52565 L .73492 .52383 L F
.336 .473 .85 r
.73359 .52565 m .73653 .5269 L .73492 .52383 L F
.759 .674 .768 r
.65421 .50197 m .65802 .50265 L .65608 .50132 L F
.551 .334 .539 r
.45107 .67054 m .45304 .67256 L .45119 .67251 L F
.767 .689 .776 r
.73354 .51338 m .73492 .51668 L .7316 .51619 L F
.528 .544 .815 r
.73628 .51294 m .73492 .51668 L .73354 .51338 L F
.73628 .51294 m .73765 .51656 L .73492 .51668 L F
.579 .177 .244 r
.46505 .69998 m .46177 .69791 L .46304 .69874 L F
.722 .202 0 r
.49369 .78044 m .49503 .7822 L .49197 .77934 L F
.214 .297 .734 r
.54976 .66194 m .55112 .66084 L .54886 .65864 L F
.54 .464 .72 r
.54974 .66473 m .55112 .66084 L .54976 .66194 L F
.648 .158 .075 r
.28279 .63187 m .28685 .63238 L .28493 .63119 L F
.487 .377 .655 r
.28493 .63119 m .28685 .63238 L .28653 .63008 L F
0 0 0 r
.49875 .64471 m .49981 .64443 L .50101 .64228 L F
.109 .369 .832 r
.49921 .64334 m .49981 .64443 L .49875 .64471 L F
0 .059 .613 r
.49772 .64127 m .49921 .64334 L .49875 .64471 L F
.766 .96 .654 r
.49921 .64334 m .49579 .64753 L .49875 .64471 L F
0 .156 .688 r
.49875 .64471 m .50063 .64672 L .49921 .64334 L F
.774 .541 .582 r
.61084 .5613 m .61449 .55935 L .61056 .55914 L F
.61084 .5613 m .61303 .56155 L .61449 .55935 L F
.765 .529 .576 r
.61303 .56155 m .61649 .56194 L .61449 .55935 L F
.419 .311 .624 r
.4205 .68202 m .42229 .68168 L .42226 .67847 L F
.433 .371 .688 r
.4205 .68202 m .42284 .68403 L .42229 .68168 L F
.507 .372 .631 r
.4205 .68202 m .42075 .6845 L .42284 .68403 L F
.353 .714 .986 r
.38789 .5893 m .38592 .58935 L .38396 .58831 L F
.643 .305 .384 r
.66334 .48814 m .66383 .48993 L .65996 .48992 L F
.691 .333 .365 r
.66334 .48814 m .66594 .49015 L .66383 .48993 L F
.627 .379 .522 r
.66588 .488 m .66594 .49015 L .66334 .48814 L F
.602 .365 .531 r
.59509 .62716 m .59788 .62457 L .59518 .62494 L F
.459 .143 .342 r
.37635 .63011 m .37564 .63289 L .37328 .6332 L F
.336 .035 .298 r
.37764 .63216 m .37635 .63011 L .37872 .62969 L F
.37764 .63216 m .37564 .63289 L .37635 .63011 L F
.895 .736 .676 r
.56677 .62387 m .56882 .62417 L .56708 .62146 L F
.416 .223 .508 r
.57053 .62425 m .57078 .62192 L .56882 .62417 L F
.754 .712 .812 r
.56882 .62417 m .57078 .62192 L .56708 .62146 L F
.035 .596 .8 r
.56882 .62417 m .57053 .62425 L .56677 .62387 L F
.531 .208 .366 r
.76582 .51864 m .7621 .52147 L .76209 .51992 L F
.173 0 0 r
.49577 .70671 m .49916 .70477 L .4969 .70468 L F
.334 .247 .606 r
.69588 .47417 m .69788 .47301 L .69765 .47001 L F
.491 0 0 r
.69588 .47417 m .69825 .47537 L .69452 .47427 L F
.034 0 0 r
.69788 .47301 m .69452 .47427 L .69588 .47417 L F
.123 .664 .84 r
.32676 .58272 m .32891 .58265 L .33057 .58296 L F
.078 0 0 r
.32891 .58265 m .33298 .58284 L .33057 .58296 L F
.498 .294 .534 r
.50101 .64228 m .50315 .64178 L .50334 .6393 L F
.597 .55 .772 r
.50334 .6393 m .50592 .63874 L .50462 .63632 L F
.567 .368 .571 r
.50315 .64178 m .50592 .63874 L .50334 .6393 L F
.32 .673 .976 r
.55182 .63069 m .55224 .63016 L .54838 .62963 L F
.122 .341 .807 r
.55182 .63069 m .55431 .63258 L .5526 .62934 L F
0 0 .456 r
.5526 .62934 m .55224 .63016 L .55182 .63069 L F
.773 .836 .901 r
.67787 .49764 m .67382 .49852 L .67657 .49623 L F
.827 .853 .866 r
.67964 .49598 m .67787 .49764 L .67657 .49623 L F
.487 .276 .518 r
.28609 .59623 m .2884 .59654 L .28838 .59585 L F
.28609 .59623 m .28553 .59886 L .2884 .59654 L F
.304 0 .061 r
.30375 .58759 m .30583 .58713 L .3073 .58517 L F
.332 0 .079 r
.30583 .58713 m .30942 .58478 L .3073 .58517 L F
.36 .302 .657 r
.4848 .64837 m .48678 .64989 L .48538 .64791 L F
.237 .716 .935 r
.35155 .58559 m .35352 .58544 L .35467 .58599 L F
.104 .637 .864 r
.35572 .58572 m .35467 .58599 L .35352 .58544 L F
.35572 .58572 m .35713 .58611 L .35467 .58599 L F
.354 0 .077 r
.53779 .70211 m .53659 .70383 L .53445 .70413 L F
.522 .127 .234 r
.54032 .70193 m .53659 .70383 L .53779 .70211 L F
0 0 0 r
.48284 .62771 m .48422 .62671 L .48479 .62476 L F
.48284 .62771 m .48203 .62956 L .48422 .62671 L F
.068 .459 .884 r
.52157 .78919 m .52154 .79013 L .52051 .7889 L F
.991 .745 .452 r
.52051 .7889 m .52154 .79013 L .52157 .78919 L F
.441 .066 .23 r
.50101 .64228 m .50284 .64338 L .50315 .64178 L F
.50101 .64228 m .49981 .64443 L .50284 .64338 L F
.295 .746 .958 r
.37469 .58657 m .37837 .58703 L .3762 .58704 L F
.523 .416 .674 r
.31866 .61339 m .3191 .61568 L .31701 .61606 L F
.38 0 0 r
.33298 .58284 m .33478 .58327 L .33632 .58211 L F
.533 .033 .014 r
.33632 .58211 m .33852 .58303 L .33851 .58165 L F
.33632 .58211 m .33478 .58327 L .33852 .58303 L F
.63 .799 .964 r
.69452 .47427 m .69355 .47665 L .69236 .47524 L F
.481 .628 .917 r
.69452 .47427 m .69609 .47648 L .69355 .47665 L F
.483 .289 .541 r
.69609 .47648 m .69378 .47917 L .69355 .47665 L F
.69609 .47648 m .69378 .47917 L .69355 .47665 L F
.315 .768 .955 r
.27675 .64813 m .27519 .64764 L .27261 .64785 L F
.706 .923 .965 r
.27707 .64648 m .27519 .64764 L .27675 .64813 L F
.011 0 0 r
.26523 .81842 m .26843 .81656 L .26595 .81754 L F
.594 .419 .614 r
.58974 .55941 m .59224 .5591 L .59207 .55675 L F
.583 .358 .54 r
.58968 .56159 m .59224 .5591 L .58974 .55941 L F
.625 .387 .537 r
.58712 .56196 m .58968 .56159 L .58974 .55941 L F
.65 .396 .522 r
.66948 .48971 m .66588 .488 L .66919 .48825 L F
.68 .28 .281 r
.66919 .48825 m .67167 .49003 L .66948 .48971 L F
.476 .208 .428 r
.58991 .57382 m .58975 .57566 L .58738 .57619 L F
.641 .299 .376 r
.58991 .57382 m .59202 .57592 L .58975 .57566 L F
.416 .596 .919 r
.73728 .52841 m .74104 .53077 L .74023 .52953 L F
.303 .658 .972 r
.74104 .53077 m .74238 .52988 L .74023 .52953 L F
.74104 .53077 m .7435 .53114 L .74238 .52988 L F
0 0 .28 r
.52649 .66028 m .5256 .65924 L .52442 .65776 L F
.52649 .66028 m .52546 .66159 L .5256 .65924 L F
.511 .698 .954 r
.39918 .5924 m .39825 .59423 L .39721 .59234 L F
.39918 .5924 m .40048 .59387 L .39825 .59423 L F
.602 .54 .757 r
.77098 .49321 m .76982 .49793 L .7685 .49376 L F
.77098 .49321 m .77209 .49721 L .76982 .49793 L F
.486 .619 .908 r
.54838 .62963 m .54899 .6269 L .54725 .62691 L F
.54838 .62963 m .55224 .63016 L .54899 .6269 L F
.449 .529 .847 r
.40293 .59479 m .40182 .59704 L .40048 .59387 L F
.515 .609 .885 r
.40293 .59479 m .40475 .59749 L .40182 .59704 L F
.55 .128 .193 r
.49151 .65343 m .49006 .65528 L .48852 .65476 L F
.553 .576 .832 r
.49257 .64988 m .49151 .65343 L .49045 .64996 L F
.49257 .64988 m .49405 .65316 L .49151 .65343 L F
.786 .417 .359 r
.49444 .65551 m .49151 .65343 L .49405 .65316 L F
.49444 .65551 m .49006 .65528 L .49151 .65343 L F
.499 .141 .289 r
.43876 .66366 m .43691 .66223 L .43609 .66363 L F
.43876 .66366 m .43915 .66208 L .43691 .66223 L F
.808 .724 .772 r
.65653 .48776 m .66003 .48505 L .65752 .48524 L F
.852 .619 .585 r
.60344 .58485 m .60537 .58793 L .60338 .58729 L F
.896 .703 .633 r
.60478 .59039 m .60338 .58729 L .60537 .58793 L F
.639 .779 .948 r
.31726 .64549 m .32101 .64598 L .31949 .64449 L F
.585 .407 .607 r
.32101 .64598 m .32295 .64472 L .31949 .64449 L F
.32101 .64598 m .32303 .64729 L .32295 .64472 L F
.104 .285 .763 r
.5007 .66159 m .49857 .65914 L .50098 .65875 L F
.33 0 0 r
.50041 .70734 m .49921 .70818 L .49681 .70762 L F
.203 0 0 r
.50299 .70775 m .49921 .70818 L .50041 .70734 L F
0 0 0 r
.54606 .59291 m .54804 .59237 L .54917 .59096 L F
.54917 .59096 m .54993 .5912 L .55145 .59033 L F
.54917 .59096 m .54804 .59237 L .54993 .5912 L F
.013 .57 .815 r
.40775 .59856 m .40986 .59883 L .41134 .59924 L F
.02 .478 .876 r
.41258 .59904 m .41134 .59924 L .40986 .59883 L F
.41258 .59904 m .41337 .60006 L .41134 .59924 L F
.001 0 0 r
.54606 .59291 m .54491 .59466 L .54804 .59237 L F
.309 .336 .726 r
.28813 .61916 m .28856 .61537 L .28673 .61595 L F
.28813 .61916 m .28929 .61875 L .28856 .61537 L F
.357 .422 .791 r
.28813 .61916 m .2907 .62135 L .28929 .61875 L F
.785 .733 .804 r
.69718 .47958 m .69378 .47917 L .69609 .47648 L F
.682 .678 .84 r
.69933 .47802 m .69718 .47958 L .69609 .47648 L F
.732 .941 .62 r
.55527 .60538 m .55397 .60645 L .55354 .60753 L F
.089 0 0 r
.55752 .60471 m .55397 .60645 L .55527 .60538 L F
.071 0 0 r
.35498 .64005 m .35323 .64115 L .35108 .64163 L F
.029 0 0 r
.35537 .64058 m .35498 .64005 L .35705 .6394 L F
.35537 .64058 m .35323 .64115 L .35498 .64005 L F
.599 .642 .865 r
.75337 .49353 m .75702 .49623 L .75586 .49287 L F
.622 .622 .829 r
.75702 .49623 m .75836 .49215 L .75586 .49287 L F
.75702 .49623 m .76013 .49592 L .75836 .49215 L F
.623 .546 .747 r
.75702 .49623 m .75986 .49673 L .76013 .49592 L F
.544 .518 .777 r
.75702 .49623 m .76042 .49902 L .75986 .49673 L F
.612 .322 .453 r
.38079 .60925 m .38345 .60778 L .38107 .60792 L F
.582 .409 .613 r
.59207 .55675 m .59452 .55853 L .59436 .55638 L F
.59207 .55675 m .59224 .5591 L .59452 .55853 L F
.177 .058 .469 r
.60521 .64936 m .6039 .65295 L .60416 .65065 L F
.497 .531 .822 r
.3248 .61808 m .32419 .62164 L .32315 .6185 L F
.3248 .61808 m .32615 .6214 L .32419 .62164 L F
.243 .598 .951 r
.37491 .59655 m .37542 .59556 L .37356 .59526 L F
.37491 .59655 m .37688 .59688 L .37542 .59556 L F
0 .029 .596 r
.56031 .642 m .56015 .64123 L .55846 .63886 L F
.538 .857 .997 r
.56031 .642 m .56109 .64069 L .56015 .64123 L F
.098 .293 .772 r
.56031 .642 m .56261 .64395 L .56109 .64069 L F
.435 .475 .802 r
.6946 .46805 m .69765 .47001 L .6973 .46755 L F
.674 .576 .737 r
.58202 .64815 m .58292 .65075 L .58015 .6505 L F
0 0 .119 r
.58015 .6505 m .58133 .64986 L .58202 .64815 L F
.372 .513 .87 r
.58031 .64946 m .58133 .64986 L .58015 .6505 L F
.5 0 0 r
.58292 .65075 m .58241 .65149 L .58082 .6508 L F
.58091 .65057 m .58082 .6508 L .58015 .6505 L F
.58292 .65075 m .58082 .6508 L .58091 .65057 L F
0 0 0 r
.58071 .65109 m .58028 .65211 L .57985 .65279 L F
.3 .345 .741 r
.58015 .6505 m .58241 .65149 L .58133 .64986 L F
0 0 0 r
.58133 .64986 m .58045 .65174 L .58071 .65109 L F
.58045 .65174 m .58028 .65211 L .58071 .65109 L F
.58133 .64986 m .57985 .65279 L .58015 .6505 L F
.563 .206 .321 r
.66826 .48374 m .67042 .48385 L .6679 .48239 L F
.487 .206 .412 r
.50749 .64511 m .50438 .64945 L .50695 .6488 L F
.50749 .64511 m .50438 .64945 L .50695 .6488 L F
.375 .112 .381 r
.50749 .64511 m .50883 .64879 L .50695 .6488 L F
.50749 .64511 m .50883 .64879 L .50695 .6488 L F
.113 .626 .892 r
.52123 .77632 m .52187 .77591 L .51987 .77563 L F
.572 .183 .267 r
.52123 .77632 m .5236 .77665 L .52437 .77603 L F
.52123 .77632 m .5236 .77665 L .52437 .77603 L F
.113 .626 .892 r
.52123 .77632 m .5236 .77665 L .52187 .77591 L F
.52123 .77632 m .52187 .77591 L .51987 .77563 L F
.52123 .77632 m .5236 .77665 L .52187 .77591 L F
.508 .259 .472 r
.29092 .59338 m .2932 .59297 L .29354 .59072 L F
.342 .118 .421 r
.29354 .59072 m .29502 .5922 L .2956 .59042 L F
.29354 .59072 m .2932 .59297 L .29502 .5922 L F
.327 .225 .584 r
.60466 .63344 m .6053 .63583 L .60389 .63608 L F
.333 .253 .614 r
.6053 .63583 m .60578 .63811 L .60389 .63608 L F
.303 .248 .629 r
.60389 .63608 m .60578 .63811 L .60441 .63871 L F
.07 0 .296 r
.47542 .63609 m .47672 .63732 L .47749 .63542 L F
.47542 .63609 m .4754 .63833 L .47672 .63732 L F
.55 .757 .973 r
.38119 .59875 m .38276 .59661 L .38089 .5978 L F
.38119 .59875 m .38355 .59828 L .38276 .59661 L F
.518 .713 .96 r
.38119 .59875 m .38425 .59916 L .38355 .59828 L F
.5 .026 .059 r
.46776 .70744 m .46644 .70896 L .46418 .70792 L F
.671 .256 .248 r
.47017 .70794 m .46644 .70896 L .46776 .70744 L F
.629 .282 .363 r
.48293 .70713 m .48159 .70944 L .47938 .70755 L F
.624 .246 .307 r
.48519 .70767 m .48159 .70944 L .48293 .70713 L F
.595 .826 .988 r
.32754 .82095 m .3312 .82125 L .32946 .82205 L F
.32754 .82095 m .3312 .82125 L .32946 .82205 L F
.612 .322 .453 r
.38079 .60925 m .38316 .60939 L .38345 .60778 L F
.539 .256 .434 r
.38316 .60939 m .38541 .6095 L .38345 .60778 L F
.524 .259 .456 r
.38345 .60778 m .38541 .6095 L .38574 .60742 L F
.525 .215 .384 r
.36457 .62126 m .36737 .61918 L .36507 .61947 L F
.409 .839 .954 r
.34287 .62837 m .34498 .62784 L .34629 .62818 L F
.184 .716 .825 r
.34498 .62784 m .34847 .62768 L .34629 .62818 L F
.694 .939 .642 r
.46782 .66392 m .46735 .66502 L .46858 .66456 L F
.46782 .66392 m .46575 .66628 L .46735 .66502 L F
.386 .422 .776 r
.46858 .66456 m .46976 .66709 L .46735 .66502 L F
.491 .688 .955 r
.76511 .48401 m .76359 .48572 L .76291 .48391 L F
.76511 .48401 m .76607 .48569 L .76359 .48572 L F
.702 .292 .267 r
.4963 .66195 m .49849 .66398 L .49485 .66361 L F
.557 .743 .963 r
.55135 .64638 m .54976 .64807 L .54898 .64571 L F
.55135 .64638 m .55177 .64761 L .54976 .64807 L F
.811 .634 .662 r
.61773 .56735 m .61898 .57067 L .61923 .56808 L F
.884 .762 .724 r
.73485 .4932 m .73663 .49433 L .73589 .4952 L F
.746 .594 .686 r
.60702 .55892 m .61066 .55672 L .60704 .55639 L F
.60702 .55892 m .61056 .55914 L .61066 .55672 L F
.515 .363 .613 r
.59525 .62969 m .5928 .62772 L .59267 .63 L F
.59525 .62969 m .59509 .62716 L .5928 .62772 L F
.755 .655 .751 r
.74036 .49019 m .74394 .49053 L .74268 .48735 L F
.73 .643 .761 r
.74268 .48735 m .74394 .49053 L .74631 .48781 L F
.177 .219 .667 r
.44892 .69525 m .44834 .69826 L .44635 .69571 L F
.44892 .69525 m .44935 .69898 L .44834 .69826 L F
.652 .659 .844 r
.41734 .60137 m .41487 .60205 L .41337 .60006 L F
.535 .323 .538 r
.41734 .60137 m .4148 .60446 L .41487 .60205 L F
.829 .761 .787 r
.66434 .51019 m .66353 .50698 L .66499 .50803 L F
.204 .513 .913 r
.73728 .52841 m .73957 .5282 L .73653 .5269 L F
.73728 .52841 m .74023 .52953 L .73957 .5282 L F
.387 0 0 r
.49916 .70477 m .49915 .70497 L .50284 .70436 L F
.609 .068 0 r
.49915 .70497 m .505 .70433 L .50284 .70436 L F
.915 .723 .628 r
.67849 .4932 m .67964 .49598 L .67893 .49533 L F
.827 .853 .866 r
.67964 .49598 m .67657 .49623 L .67893 .49533 L F
.72 .649 .778 r
.6821 .49345 m .67964 .49598 L .67849 .4932 L F
.333 0 .021 r
.53006 .65338 m .52883 .65505 L .5265 .65542 L F
.897 .553 .387 r
.53006 .65338 m .53091 .65609 L .52883 .65505 L F
.423 .322 .636 r
.61331 .61607 m .61384 .61852 L .61198 .61911 L F
0 0 .212 r
.61384 .61852 m .61219 .6216 L .61198 .61911 L F
.964 .799 .628 r
.61941 .57558 m .61992 .5787 L .62008 .57635 L F
.662 .383 .487 r
.49447 .67034 m .49748 .67008 L .49521 .66902 L F
.355 0 0 r
.35155 .59858 m .35026 .59893 L .34808 .59864 L F
.048 0 0 r
.35382 .59836 m .35026 .59893 L .35155 .59858 L F
.809 .647 .682 r
.5424 .76244 m .54232 .76521 L .54087 .76346 L F
.681 .434 .541 r
.54087 .76346 m .54419 .76146 L .5424 .76244 L F
.54087 .76346 m .54447 .76509 L .54419 .76146 L F
.601 .146 .143 r
.67042 .48385 m .67289 .48403 L .67399 .48287 L F
.603 .148 .145 r
.67289 .48403 m .67628 .48417 L .67399 .48287 L F
.556 .264 .428 r
.67399 .48287 m .67628 .48417 L .67656 .48231 L F
.837 .778 .796 r
.7277 .50207 m .73159 .4995 L .73014 .49832 L F
.789 .883 .914 r
.73159 .4995 m .73324 .49636 L .73014 .49832 L F
.73159 .4995 m .73388 .49787 L .73324 .49636 L F
.778 .626 .691 r
.61649 .56194 m .61767 .56492 L .61798 .56248 L F
.583 .652 .884 r
.76195 .5045 m .76768 .507 L .76432 .50405 L F
.725 .456 0 r
.76768 .507 m .76678 .50354 L .76432 .50405 L F
.76768 .507 m .76766 .50709 L .76678 .50354 L F
.525 .421 .678 r
.49565 .79189 m .49794 .79571 L .49676 .79242 L F
.49565 .79189 m .49572 .79594 L .49794 .79571 L F
.624 .443 .617 r
.5342 .69869 m .53419 .70153 L .53652 .69895 L F
.486 .24 .467 r
.39716 .61611 m .39665 .61881 L .39449 .61931 L F
.52 .271 .477 r
.39902 .61796 m .39716 .61611 L .39936 .61569 L F
.39902 .61796 m .39665 .61881 L .39716 .61611 L F
.702 .773 .907 r
.51968 .79421 m .5215 .79291 L .51786 .79246 L F
.995 .76 .457 r
.46728 .681 m .46727 .68162 L .46648 .68101 L F
.46732 .67904 m .46729 .68075 L .46613 .68074 L F
.46729 .68075 m .46727 .68162 L .46613 .68074 L F
.22 .742 .782 r
.46284 .68131 m .46613 .68074 L .4637 .68072 L F
.46284 .68131 m .46613 .68074 L .4637 .68072 L F
.321 .809 .84 r
.46613 .68074 m .46403 .68103 L .46518 .68074 L F
.995 .76 .457 r
.46732 .67904 m .46728 .681 L .46613 .68074 L F
.321 .809 .84 r
.46613 .68074 m .46518 .68074 L .46754 .68013 L F
.015 0 0 r
.46763 .68101 m .46893 .68107 L .46507 .68104 L F
.46638 .68102 m .46507 .68104 L .46403 .68103 L F
.46763 .68101 m .46507 .68104 L .46638 .68102 L F
.995 .76 .457 r
.46728 .681 m .46648 .68101 L .46613 .68074 L F
.479 .898 .844 r
.34588 .59897 m .34477 .59913 L .34199 .60033 L F
.368 .833 .896 r
.34808 .59864 m .34477 .59913 L .34588 .59897 L F
.589 .124 .119 r
.73099 .47379 m .73357 .47506 L .73441 .47361 L F
.438 .012 .131 r
.73357 .47506 m .73685 .4732 L .73441 .47361 L F
.768 .871 .443 r
.48479 .62476 m .48469 .62457 L .48633 .62116 L F
.019 0 .069 r
.48479 .62476 m .48584 .62556 L .48469 .62457 L F
.48479 .62476 m .48422 .62671 L .48584 .62556 L F
.61 .681 .892 r
.49035 .80695 m .49267 .80754 L .49125 .80699 L F
.549 .366 .586 r
.65849 .51064 m .66143 .51173 L .66245 .51171 L F
.65849 .51064 m .6593 .51257 L .66143 .51173 L F
.486 .192 .391 r
.39172 .62162 m .38937 .62314 L .38957 .62225 L F
0 .133 .583 r
.57473 .6724 m .57106 .66969 L .57205 .67108 L F
.535 .381 .618 r
.77074 .49062 m .77098 .49321 L .7685 .49376 L F
.81 .888 .9 r
.66505 .51293 m .66622 .51407 L .6679 .51243 L F
.3 .263 .65 r
.42665 .70153 m .42877 .70074 L .42686 .69863 L F
.046 0 .014 r
.42665 .70153 m .42707 .70191 L .42877 .70074 L F
.925 .632 .469 r
.60344 .58485 m .60152 .5843 L .60112 .58146 L F
.895 .7 .631 r
.60338 .58729 m .60152 .5843 L .60344 .58485 L F
.337 .178 .512 r
.59992 .61907 m .60159 .61853 L .60154 .616 L F
.362 .242 .578 r
.59992 .61907 m .60175 .62081 L .60159 .61853 L F
.35 .241 .587 r
.60019 .62171 m .60175 .62081 L .59992 .61907 L F
.525 .914 .921 r
.48987 .61914 m .49069 .61816 L .49213 .61865 L F
.48987 .61914 m .48884 .619 L .49069 .61816 L F
.951 .947 .731 r
.50377 .79881 m .50408 .79672 L .50151 .79818 L F
.728 .483 .557 r
.54301 .65909 m .54017 .66089 L .5403 .65888 L F
.54301 .65909 m .54298 .66145 L .54017 .66089 L F
0 0 0 r
.45384 .69911 m .45432 .69908 L .45581 .69902 L F
.45384 .69911 m .45178 .69971 L .45432 .69908 L F
.573 .116 .128 r
.26374 .68687 m .26624 .68713 L .26426 .68647 L F
.35 .197 .529 r
.42221 .69048 m .42399 .69221 L .42448 .69002 L F
.42221 .69048 m .42234 .6928 L .42399 .69221 L F
.53 .483 .748 r
.42137 .68782 m .42221 .69048 L .42448 .69002 L F
.595 .243 .343 r
.4738 .7069 m .47218 .70955 L .47017 .70794 L F
.676 .336 .391 r
.4738 .7069 m .47576 .7093 L .47218 .70955 L F
0 0 0 r
.52499 .65246 m .52432 .6535 L .5265 .65542 L F
.52499 .65246 m .52333 .65522 L .52432 .6535 L F
.504 .486 .77 r
.56468 .62704 m .56549 .63031 L .56335 .63082 L F
.486 .408 .694 r
.56549 .63031 m .56625 .63216 L .56335 .63082 L F
.367 0 0 r
.44524 .70936 m .44675 .70847 L .44858 .70921 L F
.494 .214 .418 r
.36007 .6245 m .3623 .62416 L .36292 .62214 L F
.196 0 .285 r
.36292 .62214 m .3623 .62416 L .36457 .62126 L F
.693 .294 .287 r
.55773 .61902 m .55972 .62105 L .56109 .61915 L F
.9 .582 .436 r
.55972 .62105 m .56191 .62135 L .56109 .61915 L F
.447 .816 .557 r
.5236 .77665 m .5246 .77584 L .52437 .77603 L F
.52437 .77603 m .5246 .77584 L .5236 .77665 L F
.486 .668 .943 r
.70353 .49237 m .70441 .49069 L .70193 .49143 L F
.70353 .49237 m .70575 .49251 L .70441 .49069 L F
.829 .761 .787 r
.66434 .51019 m .66137 .5099 L .66353 .50698 L F
.842 .717 .726 r
.66434 .51019 m .66245 .51171 L .66137 .5099 L F
.451 .133 .335 r
.5713 .5756 m .57432 .57268 L .57197 .57318 L F
.525 .243 .429 r
.58459 .57883 m .58445 .58095 L .58213 .58204 L F
.323 .056 .345 r
.58715 .57743 m .58445 .58095 L .58459 .57883 L F
.357 .495 .86 r
.56129 .64797 m .5645 .64946 L .56262 .64637 L F
.209 .467 .883 r
.54446 .6254 m .5457 .62463 L .54375 .62397 L F
.54446 .6254 m .54725 .62691 L .5457 .62463 L F
0 .289 .668 r
.7294 .50873 m .73233 .51021 L .729 .5086 L F
.535 .392 .633 r
.60408 .64177 m .60227 .64512 L .602 .64227 L F
.526 .346 .58 r
.42203 .67602 m .42438 .67566 L .42437 .67317 L F
.447 .264 .538 r
.42226 .67847 m .42438 .67566 L .42203 .67602 L F
.483 .19 .391 r
.44734 .65885 m .44961 .65853 L .4504 .65579 L F
.409 .121 .361 r
.4504 .65579 m .45178 .65788 L .45258 .6551 L F
.4504 .65579 m .44961 .65853 L .45178 .65788 L F
.232 .704 .942 r
.28012 .64192 m .28125 .6425 L .27739 .64188 L F
.28012 .64192 m .28125 .6425 L .27739 .64188 L F
.64 .915 .98 r
.28321 .64156 m .28125 .6425 L .28012 .64192 L F
.28012 .64192 m .28125 .6425 L .28321 .64156 L F
.28321 .64156 m .28125 .6425 L .28012 .64192 L F
.572 .68 .913 r
.39558 .5901 m .39496 .59272 L .3934 .59025 L F
.39558 .5901 m .39721 .59234 L .39496 .59272 L F
.367 0 0 r
.5201 .7066 m .51948 .70727 L .51662 .70712 L F
.39 .701 .983 r
.51662 .70712 m .51948 .70727 L .51943 .70722 L F
.392 0 0 r
.51813 .70612 m .51662 .70712 L .51466 .70705 L F
.484 .003 .037 r
.5201 .7066 m .51662 .70712 L .51813 .70612 L F
.39 .701 .983 r
.51662 .70712 m .51943 .70722 L .51789 .70576 L F
.392 0 0 r
.51466 .70705 m .51662 .70712 L .51438 .70713 L F
.978 .869 .491 r
.49574 .78176 m .49449 .78404 L .49503 .7822 L F
.752 .464 .495 r
.55632 .66507 m .55596 .66709 L .55636 .66469 L F
.55632 .66507 m .55944 .66732 L .55596 .66709 L F
.144 .245 .711 r
.55873 .66395 m .55944 .66732 L .55632 .66507 L F
.752 .464 .495 r
.55632 .66507 m .55944 .66732 L .55596 .66709 L F
.531 .208 .366 r
.76582 .51864 m .76451 .52127 L .7621 .52147 L F
.614 .297 .41 r
.76793 .52052 m .76582 .51864 L .76782 .51889 L F
.76793 .52052 m .76451 .52127 L .76582 .51864 L F
0 0 .041 r
.71468 .46949 m .71458 .47323 L .71232 .46996 L F
.71468 .46949 m .71483 .47314 L .71458 .47323 L F
.261 0 0 r
.36249 .63798 m .3592 .63887 L .3602 .63815 L F
.439 .237 .508 r
.42834 .66715 m .43072 .66392 L .42866 .66468 L F
.133 0 0 r
.74971 .52843 m .74869 .52937 L .74663 .53023 L F
0 0 0 r
.75055 .52831 m .74971 .52843 L .75147 .52713 L F
.75055 .52831 m .74869 .52937 L .74971 .52843 L F
.961 .828 .666 r
.61909 .592 m .62118 .59094 L .61878 .58812 L F
.61909 .592 m .61878 .58812 L .61856 .5883 L F
.61909 .592 m .62026 .59296 L .62118 .59094 L F
.969 .795 .613 r
.61809 .58897 m .61909 .592 L .61856 .5883 L F
.61809 .58897 m .61856 .5883 L .61849 .58778 L F
.928 .705 .58 r
.61744 .58918 m .61767 .58956 L .61809 .58897 L F
.996 .801 .525 r
.61909 .592 m .61979 .59551 L .61995 .59465 L F
.61909 .592 m .61995 .59465 L .62026 .59296 L F
0 .031 .6 r
.61902 .59178 m .61902 .59178 L .61909 .592 L F
.61902 .59178 m .61968 .59287 L .61909 .592 L F
.928 .705 .58 r
.61767 .58956 m .61968 .59287 L .61809 .58897 L F
.61518 .58992 m .61591 .5904 L .61744 .58918 L F
.996 .801 .525 r
.61909 .592 m .61867 .59478 L .61979 .59551 L F
.109 0 .267 r
.61968 .59287 m .61867 .59478 L .61909 .592 L F
.928 .705 .58 r
.61591 .5904 m .61968 .59287 L .61744 .58918 L F
.961 .828 .666 r
.61856 .5883 m .61878 .58812 L .61849 .58778 L F
.611 .535 .744 r
.41999 .69759 m .42345 .69758 L .42234 .69638 L F
.41999 .69759 m .4209 .69839 L .42345 .69758 L F
.404 .061 .267 r
.60372 .66464 m .60325 .66698 L .60066 .6675 L F
.45 .309 .597 r
.60516 .66179 m .60517 .66352 L .60372 .66464 L F
.097 0 .16 r
.60517 .66352 m .60325 .66698 L .60372 .66464 L F
.473 0 0 r
.7062 .46813 m .70897 .46948 L .70993 .46937 L F
.313 0 0 r
.70897 .46948 m .71232 .46996 L .70993 .46937 L F
.315 0 0 r
.48188 .70366 m .47983 .70441 L .48391 .70386 L F
.705 .465 .559 r
.60702 .55892 m .61084 .5613 L .61056 .55914 L F
.896 .703 .633 r
.60478 .59039 m .60261 .5898 L .60338 .58729 L F
.967 .807 .63 r
.60478 .59039 m .60277 .59199 L .60261 .5898 L F
.60478 .59039 m .60393 .59344 L .60277 .59199 L F
.016 0 0 r
.74663 .53023 m .74616 .53058 L .7435 .53114 L F
0 0 0 r
.7486 .52968 m .74663 .53023 L .74869 .52937 L F
.7486 .52968 m .74616 .53058 L .74663 .53023 L F
.688 .269 .246 r
.505 .70433 m .50725 .70629 L .50868 .70464 L F
.631 .335 .45 r
.50868 .70464 m .51081 .70672 L .51156 .70482 L F
.609 .223 .286 r
.47938 .70755 m .47817 .7096 L .47576 .7093 L F
.65 .269 .31 r
.47938 .70755 m .48159 .70944 L .47817 .7096 L F
.194 .664 .937 r
.70893 .49332 m .70802 .4927 L .70575 .49251 L F
.649 .919 .978 r
.71014 .49171 m .70893 .49332 L .7112 .49283 L F
.71014 .49171 m .70802 .4927 L .70893 .49332 L F
.756 .577 .655 r
.60352 .55604 m .60702 .55892 L .60704 .55639 L F
.623 .574 .779 r
.38454 .60145 m .38649 .59868 L .38425 .59916 L F
.38454 .60145 m .38776 .60226 L .38649 .59868 L F
.317 0 .164 r
.44505 .65918 m .44229 .66121 L .44459 .66105 L F
.472 .151 .34 r
.44679 .66058 m .44505 .65918 L .44459 .66105 L F
.44679 .66058 m .44734 .65885 L .44505 .65918 L F
.961 .665 .425 r
.29268 .62753 m .29261 .63092 L .29161 .62812 L F
.485 .187 .384 r
.38679 .62394 m .38593 .62709 L .3836 .62741 L F
.492 .207 .408 r
.38937 .62314 m .38593 .62709 L .38679 .62394 L F
.501 .709 .964 r
.70734 .47389 m .70867 .47197 L .70628 .47223 L F
.357 .51 .873 r
.70734 .47389 m .70998 .47458 L .70867 .47197 L F
.735 .289 .193 r
.52249 .70273 m .52606 .70449 L .52592 .70197 L F
.52249 .70273 m .52285 .70409 L .52606 .70449 L F
.498 .437 .72 r
.42137 .68782 m .42284 .68403 L .42075 .6845 L F
.42137 .68782 m .42352 .68772 L .42284 .68403 L F
.53 .483 .748 r
.42137 .68782 m .42448 .69002 L .42352 .68772 L F
.721 .653 .781 r
.42745 .70491 m .42918 .70774 L .43123 .70663 L F
.866 .717 .695 r
.61578 .57231 m .61908 .5742 L .61898 .57067 L F
.858 .541 .449 r
.61578 .57231 m .61941 .57558 L .61908 .5742 L F
.527 .365 .605 r
.42613 .66769 m .42841 .66964 L .42834 .66715 L F
.477 .367 .65 r
.42613 .66769 m .42646 .67025 L .42841 .66964 L F
.41 .662 .963 r
.76291 .48391 m .76125 .48415 L .75907 .48225 L F
.07 0 .399 r
.55698 .61122 m .55767 .61188 L .55786 .6104 L F
.663 .507 .662 r
.52592 .70197 m .52606 .70449 L .52838 .70156 L F
0 .47 .86 r
.2111 .55726 m .21347 .55847 L .21226 .55881 L F
0 0 .329 r
.21276 .5597 m .21226 .55881 L .21347 .55847 L F
.45 .149 .362 r
.58738 .57619 m .58896 .57848 L .58715 .57743 L F
.58738 .57619 m .58975 .57566 L .58896 .57848 L F
.639 .949 .739 r
.52714 .76255 m .5245 .76487 L .52547 .76355 L F
.323 .57 .928 r
.5245 .76487 m .52611 .76524 L .52547 .76355 L F
.667 .374 .467 r
.47185 .66087 m .46858 .66456 L .46993 .66206 L F
.624 .246 .307 r
.48519 .70767 m .48391 .70978 L .48159 .70944 L F
0 0 .315 r
.48765 .70738 m .48834 .70843 L .48847 .70811 L F
.48765 .70738 m .48847 .70811 L .48694 .70773 L F
.141 .286 .752 r
.48694 .70773 m .48847 .70811 L .48812 .70778 L F
.48694 .70773 m .48812 .70778 L .48638 .70613 L F
.164 0 .045 r
.48694 .70773 m .48519 .70767 L .48532 .70766 L F
.48694 .70773 m .48532 .70766 L .48765 .70738 L F
.48694 .70773 m .48391 .70978 L .48519 .70767 L F
.669 .509 .659 r
.50903 .65353 m .50939 .65638 L .50671 .6561 L F
.66 .503 .659 r
.51222 .65557 m .50903 .65353 L .51182 .65322 L F
.51222 .65557 m .50939 .65638 L .50903 .65353 L F
.897 .67 .587 r
.61618 .56389 m .61767 .56492 L .61649 .56194 L F
.815 .67 .703 r
.61618 .56389 m .61773 .56735 L .61767 .56492 L F
.483 .215 .431 r
.37763 .61284 m .38079 .60925 L .3784 .61068 L F
.5 .342 .598 r
.44199 .68453 m .4415 .68746 L .43935 .68756 L F
.287 0 0 r
.34398 .64409 m .34289 .64462 L .34064 .64472 L F
.187 0 0 r
.34609 .64377 m .34289 .64462 L .34398 .64409 L F
.563 .273 .434 r
.65404 .48973 m .65653 .48776 L .65429 .48848 L F
0 0 .153 r
.55389 .6088 m .55354 .60753 L .55397 .60645 L F
.55389 .6088 m .55357 .60991 L .55354 .60753 L F
.293 .745 .957 r
.29021 .63048 m .28985 .63027 L .28653 .63008 L F
.736 .525 .607 r
.28685 .63238 m .29021 .63048 L .28653 .63008 L F
.395 .391 .737 r
.29021 .63048 m .29161 .62812 L .28985 .63027 L F
.29021 .63048 m .29261 .63092 L .29161 .62812 L F
.329 .253 .618 r
.29021 .63048 m .29247 .63195 L .29261 .63092 L F
.885 .602 .086 r
.57598 .67324 m .57573 .67485 L .57473 .6724 L F
.57598 .67324 m .57631 .67538 L .57573 .67485 L F
.595 .532 .753 r
.58546 .65021 m .58292 .65075 L .58202 .64815 L F
.715 .446 .518 r
.58546 .65021 m .58241 .65149 L .58292 .65075 L F
.56 .592 .843 r
.76195 .5045 m .76309 .50088 L .76079 .50123 L F
.76195 .5045 m .76432 .50405 L .76309 .50088 L F
.185 0 0 r
.31489 .58322 m .31708 .58247 L .3155 .58279 L F
.432 .779 .997 r
.34203 .58457 m .3442 .58431 L .34562 .58518 L F
.376 .666 .971 r
.34632 .58384 m .34562 .58518 L .3442 .58431 L F
.34632 .58384 m .34763 .58526 L .34562 .58518 L F
.729 .273 .168 r
.57331 .64741 m .57554 .64951 L .57613 .6485 L F
.598 .123 .099 r
.57613 .6485 m .57554 .64951 L .58031 .64946 L F
.212 0 .328 r
.61127 .62601 m .6096 .62522 L .61195 .62382 L F
.61127 .62601 m .6097 .62697 L .6096 .62522 L F
0 .483 .815 r
.29434 .63478 m .29662 .63554 L .2971 .63579 L F
.706 .571 .7 r
.2971 .63579 m .29836 .63917 L .29498 .639 L F
.71 .573 .699 r
.30069 .6387 m .29836 .63917 L .2971 .63579 L F
.433 0 0 r
.45105 .70901 m .45254 .70782 L .45505 .70876 L F
.69 .184 .033 r
.33288 .64796 m .33254 .64861 L .3297 .64751 L F
.374 .143 .43 r
.33463 .64733 m .33246 .65 L .33288 .64796 L F
.938 .759 .633 r
.72581 .4852 m .72539 .48758 L .72433 .48424 L F
.883 .691 .638 r
.60472 .60449 m .60254 .60434 L .60333 .60115 L F
.916 .807 .725 r
.60472 .60449 m .6019 .60665 L .60254 .60434 L F
.60472 .60449 m .60349 .60771 L .6019 .60665 L F
.857 .913 .869 r
.58866 .64962 m .5898 .64674 L .59023 .64735 L F
.891 .975 .674 r
.59023 .64735 m .59168 .64355 L .59178 .6449 L F
.443 .824 .989 r
.3302 .65043 m .33093 .64942 L .32868 .64964 L F
.3302 .65043 m .33246 .65 L .33093 .64942 L F
.167 .304 .76 r
.48746 .65303 m .4889 .65161 L .48678 .64989 L F
.601 .045 0 r
.53149 .61011 m .5278 .60734 L .53059 .61006 L F
.956 .939 .621 r
.49125 .64925 m .49145 .64903 L .49296 .64496 L F
.13 0 .39 r
.49296 .64496 m .49145 .64903 L .49409 .64542 L F
.617 .394 .556 r
.77033 .51634 m .77038 .51884 L .76782 .51889 L F
.627 .402 .557 r
.77349 .51665 m .77033 .51634 L .7732 .51562 L F
.77349 .51665 m .77038 .51884 L .77033 .51634 L F
.213 0 .049 r
.56131 .58135 m .56342 .58094 L .56431 .57924 L F
.297 0 .124 r
.56342 .58094 m .56643 .57854 L .56431 .57924 L F
.643 .813 .965 r
.2453 .68692 m .24341 .688 L .2414 .68659 L F
.788 .575 .612 r
.2435 .68827 m .2414 .68659 L .24341 .688 L F
.887 .806 .764 r
.2453 .68692 m .2435 .68827 L .24341 .688 L F
.684 .807 .941 r
.31949 .64449 m .32295 .64472 L .3217 .64274 L F
.52 .724 .966 r
.32373 .64371 m .32387 .64452 L .32495 .64428 L F
.3217 .64274 m .32387 .64452 L .32373 .64371 L F
.3217 .64274 m .32495 .64428 L .32438 .64448 L F
0 .237 .634 r
.32568 .64302 m .32339 .64174 L .32438 .64448 L F
.32339 .64174 m .32175 .64082 L .3237 .64353 L F
.32339 .64174 m .3237 .64353 L .32438 .64448 L F
.52 .724 .966 r
.3217 .64274 m .32295 .64472 L .32387 .64452 L F
.519 .356 .599 r
.32295 .64472 m .32516 .64675 L .32495 .64428 L F
.32295 .64472 m .32303 .64729 L .32516 .64675 L F
.439 .486 .811 r
.23722 .68739 m .23742 .68743 L .23726 .6875 L F
.239 .022 .369 r
.23726 .6875 m .23742 .68743 L .23718 .68788 L F
.689 .263 .231 r
.29284 .64214 m .29113 .6436 L .28895 .64176 L F
.732 .507 .586 r
.29405 .64088 m .29497 .64126 L .29355 .64185 L F
.29405 .64088 m .29338 .64224 L .29497 .64126 L F
.29096 .6396 m .29405 .64088 L .29284 .64214 L F
.29405 .64088 m .29355 .64185 L .29284 .64214 L F
.191 0 0 r
.29315 .64314 m .29284 .64214 L .29497 .64126 L F
.732 .507 .586 r
.29096 .6396 m .29338 .64224 L .29405 .64088 L F
0 0 0 r
.29498 .639 m .294 .64099 L .29406 .64086 L F
.29505 .63888 m .29406 .64086 L .29561 .63789 L F
.29498 .639 m .29406 .64086 L .29505 .63888 L F
.294 .64099 m .29338 .64224 L .29499 .6391 L F
.294 .64099 m .29499 .6391 L .29561 .63789 L F
.191 0 0 r
.29315 .64314 m .29113 .6436 L .29284 .64214 L F
.303 .47 .86 r
.56711 .66246 m .56833 .66093 L .56689 .66067 L F
.56711 .66246 m .56999 .66385 L .56833 .66093 L F
0 0 0 r
.76789 .5098 m .76239 .51247 L .76523 .51122 L F
.65 .396 .522 r
.66948 .48971 m .66594 .49015 L .66588 .488 L F
.083 .624 .849 r
.50224 .66428 m .50517 .66454 L .50584 .66486 L F
.88 .992 .764 r
.50517 .66454 m .50497 .66434 L .50584 .66486 L F
0 .236 .634 r
.50497 .66434 m .50525 .66448 L .50584 .66486 L F
.956 .921 .569 r
.50629 .66077 m .50517 .66454 L .50421 .66187 L F
.607 .474 .675 r
.50421 .66187 m .50517 .66454 L .50224 .66428 L F
.956 .921 .569 r
.50521 .6644 m .50497 .66434 L .50517 .66454 L F
.50629 .66077 m .50497 .66434 L .50521 .6644 L F
.728 .53 .623 r
.50906 .66295 m .50581 .66452 L .50497 .66434 L F
0 .444 .695 r
.50497 .66434 m .50581 .66452 L .50444 .66422 L F
.50497 .66434 m .50444 .66422 L .50306 .66392 L F
.485 .29 .541 r
.50906 .66295 m .50497 .66434 L .50629 .66077 L F
.637 .499 .678 r
.50334 .65835 m .50421 .66187 L .5007 .66159 L F
.607 .474 .675 r
.50421 .66187 m .50224 .66428 L .5007 .66159 L F
.6 .476 .683 r
.50629 .66077 m .50421 .66187 L .50383 .66037 L F
.50465 .65942 m .50383 .66037 L .50334 .65835 L F
.50629 .66077 m .50383 .66037 L .50465 .65942 L F
.63 .34 .459 r
.50671 .6561 m .50734 .65872 L .50334 .65835 L F
0 0 .208 r
.5056 .65832 m .50701 .65449 L .50602 .65632 L F
.6 .476 .683 r
.50629 .66077 m .50334 .65835 L .50734 .65872 L F
.492 .281 .522 r
.50444 .65952 m .50677 .65683 L .50569 .65821 L F
0 0 .208 r
.5056 .65832 m .50677 .65683 L .50701 .65449 L F
.492 .281 .522 r
.50552 .6584 m .50569 .65821 L .5056 .65832 L F
.369 0 0 r
.50334 .65835 m .50444 .65952 L .5056 .65832 L F
.492 .281 .522 r
.50444 .65952 m .50569 .65821 L .50552 .6584 L F
.813 .71 .751 r
.50179 .66216 m .50518 .66398 L .50444 .65952 L F
.418 0 0 r
.50306 .66392 m .50518 .66398 L .50179 .66216 L F
.50306 .66392 m .50475 .66429 L .50518 .66398 L F
.756 .947 .622 r
.50518 .66398 m .50464 .66438 L .50466 .66435 L F
.418 0 0 r
.50475 .66429 m .50581 .66452 L .50518 .66398 L F
.097 .187 .669 r
.50444 .65952 m .50518 .66398 L .50636 .66156 L F
.756 .947 .622 r
.50518 .66398 m .50466 .66435 L .50636 .66156 L F
0 .563 .788 r
.50525 .66477 m .50473 .66444 L .50224 .66428 L F
.756 .947 .622 r
.50464 .66438 m .50393 .66492 L .50442 .66424 L F
0 .444 .695 r
.50497 .66434 m .50306 .66392 L .50525 .66448 L F
.756 .947 .622 r
.50464 .66438 m .50442 .66424 L .50636 .66156 L F
0 .563 .788 r
.50584 .66486 m .50525 .66448 L .50473 .66444 L F
.50584 .66486 m .50473 .66444 L .50525 .66477 L F
.147 0 .142 r
.30069 .6387 m .29791 .64168 L .29836 .63917 L F
.30069 .6387 m .30027 .64147 L .29791 .64168 L F
.30027 .64147 m .30008 .64168 L .29791 .64168 L F
0 0 .09 r
.30125 .6401 m .30024 .64168 L .30046 .64023 L F
.30125 .6401 m .30046 .64023 L .30069 .6387 L F
.552 .923 .774 r
.3019 .63794 m .30073 .63813 L .30069 .6387 L F
.30369 .63682 m .30073 .63813 L .3019 .63794 L F
.612 .727 .927 r
.29984 .6367 m .30073 .63813 L .29782 .63748 L F
.962 .645 .248 r
.29984 .6367 m .30045 .63817 L .30073 .63813 L F
0 0 .09 r
.30125 .6401 m .30069 .6387 L .30073 .63813 L F
.962 .645 .248 r
.30045 .63817 m .30125 .6401 L .30073 .63813 L F
.92 .962 .79 r
.30358 .63416 m .30073 .63813 L .30369 .63682 L F
.875 .818 .79 r
.29984 .6367 m .30073 .63813 L .30151 .63704 L F
.30095 .63595 m .30151 .63704 L .30358 .63416 L F
.29984 .6367 m .30151 .63704 L .30095 .63595 L F
.75 .545 .618 r
.29612 .6304 m .29779 .63464 L .29966 .63336 L F
.29612 .6304 m .29966 .63336 L .29863 .63231 L F
.988 .853 .617 r
.29966 .63336 m .298 .6348 L .29863 .63231 L F
.85 .504 .397 r
.30057 .63522 m .29884 .633 L .29929 .63431 L F
.875 .818 .79 r
.29984 .6367 m .30358 .63416 L .30198 .63622 L F
.85 .504 .397 r
.30198 .63622 m .30008 .63427 L .30057 .63522 L F
.30008 .63427 m .29884 .633 L .30057 .63522 L F
.566 .569 .816 r
.30198 .63622 m .30359 .63981 L .30125 .6401 L F
.494 0 0 r
.30359 .63981 m .30186 .64 L .30125 .6401 L F
.30186 .64 m .29953 .64024 L .30125 .6401 L F
.789 .621 .673 r
.29836 .63917 m .29791 .64168 L .29497 .64126 L F
.743 .224 0 r
.29802 .64343 m .29497 .64126 L .29791 .64168 L F
0 0 0 r
.30008 .64168 m .29802 .64343 L .29791 .64168 L F
.30024 .64168 m .29999 .64188 L .30008 .64168 L F
.29999 .64188 m .29802 .64343 L .30008 .64168 L F
.29997 .6419 m .29895 .64289 L .29802 .64343 L F
.30024 .64168 m .29895 .64289 L .29997 .6419 L F
.702 .335 .349 r
.29497 .64126 m .29761 .64396 L .29315 .64314 L F
.743 .224 0 r
.29802 .64343 m .29761 .64396 L .29497 .64126 L F
.711 .599 .729 r
.29761 .64396 m .29444 .64671 L .29315 .64314 L F
.55 .339 .547 r
.2967 .64583 m .29444 .64671 L .29761 .64396 L F
.941 .885 .75 r
.29726 .64172 m .29681 .64499 L .29895 .64289 L F
.55 .339 .547 r
.2967 .64583 m .29761 .64396 L .29802 .64343 L F
0 0 0 r
.29895 .64289 m .2967 .64583 L .29802 .64343 L F
.941 .885 .75 r
.29681 .64499 m .2967 .64583 L .29895 .64289 L F
.835 .794 .812 r
.29726 .64172 m .29892 .64287 L .30024 .6413 L F
.30065 .64034 m .30024 .6413 L .30125 .6401 L F
.29726 .64172 m .30024 .6413 L .30065 .64034 L F
.29892 .64287 m .29895 .64289 L .29927 .6425 L F
.29892 .64287 m .29927 .6425 L .30125 .6401 L F
.147 0 .142 r
.30027 .64147 m .30024 .64168 L .30008 .64168 L F
0 0 .496 r
.47325 .65531 m .47472 .6588 L .47347 .65646 L F
.352 0 0 r
.23711 .68743 m .23742 .68743 L .23722 .68739 L F
.107 .631 .879 r
.49213 .61865 m .49435 .61884 L .4957 .61933 L F
.185 .7 .889 r
.49435 .61884 m .49791 .61915 L .4957 .61933 L F
0 0 0 r
.77018 .50427 m .77306 .50139 L .77251 .50345 L F
.556 .514 .763 r
.77508 .50098 m .77306 .50139 L .77236 .49867 L F
.612 .427 .608 r
.77508 .50098 m .77251 .50345 L .77306 .50139 L F
.514 .833 .999 r
.52742 .63559 m .52625 .63689 L .52515 .63538 L F
.52742 .63559 m .52871 .63635 L .52625 .63689 L F
.628 .788 .959 r
.53357 .65981 m .53769 .66179 L .53633 .65815 L F
.642 .39 .522 r
.53769 .66179 m .53732 .66421 L .53482 .66422 L F
0 0 .468 r
.53633 .65815 m .53769 .66179 L .5373 .65963 L F
.901 .984 .782 r
.53769 .66179 m .53545 .66241 L .5373 .65963 L F
.678 .423 .529 r
.54059 .66403 m .53769 .66179 L .54017 .66089 L F
.54059 .66403 m .53732 .66421 L .53769 .66179 L F
.971 .735 .523 r
.41923 .69986 m .42106 .70136 L .4209 .69839 L F
.919 .975 .705 r
.29662 .63554 m .29498 .639 L .29561 .63789 L F
.29662 .63554 m .29405 .63925 L .29498 .639 L F
.789 .621 .673 r
.29836 .63917 m .29497 .64126 L .29498 .639 L F
.449 .047 .183 r
.49145 .64903 m .49257 .64988 L .4945 .64843 L F
.613 .398 .567 r
.26879 .81686 m .26837 .81929 L .2658 .81977 L F
.623 .428 .598 r
.27079 .81595 m .26879 .81686 L .27021 .81609 L F
.27084 .81593 m .27149 .81732 L .26879 .81686 L F
.438 .24 .513 r
.27061 .81854 m .26879 .81686 L .27149 .81732 L F
.27061 .81854 m .26837 .81929 L .26879 .81686 L F
.57 .683 .917 r
.26704 .81769 m .27061 .81854 L .269 .81639 L F
.26865 .81647 m .269 .81639 L .26872 .81601 L F
.623 .428 .598 r
.27021 .81609 m .26879 .81686 L .26854 .81665 L F
.26894 .81642 m .26854 .81665 L .26843 .81656 L F
.27021 .81609 m .26854 .81665 L .26894 .81642 L F
.536 .361 .591 r
.26925 .81625 m .27061 .81854 L .27139 .81722 L F
.26872 .81601 m .269 .81639 L .26925 .81625 L F
.269 .81639 m .27061 .81854 L .26925 .81625 L F
.816 .556 .546 r
.26916 .81621 m .26872 .81601 L .27105 .81532 L F
.623 .428 .598 r
.27084 .81593 m .27079 .81595 L .27021 .81609 L F
.27084 .81593 m .26894 .81642 L .27105 .81532 L F
.26894 .81642 m .26843 .81656 L .26916 .81621 L F
.26894 .81642 m .26916 .81621 L .27105 .81532 L F
.331 .302 .676 r
.27105 .81532 m .27255 .81528 L .27084 .81593 L F
.743 .895 .502 r
.27255 .81528 m .27149 .81732 L .27084 .81593 L F
.536 .361 .591 r
.26953 .81586 m .27139 .81722 L .27255 .81528 L F
.26872 .81601 m .26916 .81621 L .26953 .81586 L F
.26916 .81621 m .27139 .81722 L .26953 .81586 L F
.816 .556 .546 r
.26866 .81645 m .26872 .81601 L .26916 .81621 L F
.26843 .81656 m .26872 .81601 L .26866 .81645 L F
.26843 .81656 m .26704 .81769 L .26872 .81601 L F
.57 .683 .917 r
.26813 .8166 m .26865 .81647 L .26872 .81601 L F
.26704 .81769 m .269 .81639 L .26813 .8166 L F
0 .237 .753 r
.53326 .61307 m .53373 .61208 L .53149 .61011 L F
.011 .325 .811 r
.53326 .61307 m .53585 .61506 L .53373 .61208 L F
.718 .487 .575 r
.59452 .55853 m .59772 .55653 L .59436 .55638 L F
.59452 .55853 m .59769 .55882 L .59772 .55653 L F
.691 .465 .575 r
.59772 .55653 m .60131 .55863 L .60114 .55598 L F
.59772 .55653 m .59769 .55882 L .60131 .55863 L F
.408 .219 .51 r
.45119 .67251 m .44888 .67558 L .44936 .67508 L F
.255 .753 .902 r
.3631 .58615 m .36518 .58592 L .3666 .58621 L F
.113 .666 .781 r
.36518 .58592 m .36883 .58578 L .3666 .58621 L F
.718 .674 .806 r
.74268 .48735 m .74631 .48781 L .74515 .48493 L F
.457 .526 .84 r
.74515 .48493 m .74631 .48781 L .74836 .48588 L F
.391 .416 .766 r
.74631 .48781 m .74903 .48937 L .74836 .48588 L F
.636 .344 .457 r
.50894 .65821 m .50734 .65872 L .50671 .6561 L F
.652 .34 .43 r
.50939 .65638 m .50894 .65821 L .50671 .6561 L F
.382 .137 .413 r
.29092 .59338 m .29241 .59475 L .2932 .59297 L F
.29092 .59338 m .29049 .59545 L .29241 .59475 L F
0 0 .304 r
.61893 .60612 m .61767 .6097 L .61775 .60669 L F
.284 0 .211 r
.32644 .60532 m .32562 .60695 L .32368 .60755 L F
.31 0 .225 r
.32766 .60625 m .32644 .60532 L .32823 .60425 L F
.32766 .60625 m .32562 .60695 L .32644 .60532 L F
.506 .832 .533 r
.68741 .50245 m .68632 .50343 L .68478 .50494 L F
.878 .993 .759 r
.68632 .50343 m .68459 .5068 L .68478 .50494 L F
.412 .709 .984 r
.38265 .58709 m .38182 .58833 L .38045 .58726 L F
.38265 .58709 m .38396 .58831 L .38182 .58833 L F
.387 .827 .948 r
.35747 .59818 m .35607 .5979 L .35382 .59836 L F
.034 .604 .739 r
.35939 .59792 m .35607 .5979 L .35747 .59818 L F
.574 .682 .913 r
.69853 .48987 m .70006 .49211 L .70193 .49143 L F
.303 .203 .572 r
.6072 .63198 m .6053 .63583 L .60466 .63344 L F
.721 .653 .781 r
.42745 .70491 m .43123 .70663 L .43009 .70562 L F
.819 .9 .898 r
.43009 .70562 m .43123 .70663 L .43377 .70428 L F
.619 .342 .475 r
.67902 .4814 m .68192 .48142 L .68195 .4793 L F
.547 .284 .469 r
.68195 .4793 m .68192 .48142 L .68441 .48089 L F
.561 .333 .527 r
.51032 .64474 m .51004 .64704 L .51241 .64666 L F
.893 .787 .737 r
.29247 .63195 m .29351 .63443 L .29612 .6304 L F
.29247 .63195 m .29612 .6304 L .2953 .63274 L F
.612 .261 .349 r
.29863 .63231 m .2953 .63274 L .29612 .6304 L F
.408 .219 .51 r
.45119 .67251 m .45019 .67637 L .44888 .67558 L F
.328 .254 .62 r
.45019 .67637 m .45035 .67764 L .44888 .67558 L F
.407 .213 .503 r
.42437 .67317 m .42628 .67259 L .42646 .67025 L F
.435 .274 .563 r
.42437 .67317 m .42632 .67505 L .42628 .67259 L F
.42437 .67317 m .42438 .67566 L .42632 .67505 L F
.71 .255 .168 r
.49444 .65551 m .49263 .65727 L .49006 .65528 L F
.459 .403 .708 r
.4957 .65226 m .49444 .65551 L .49405 .65316 L F
.4957 .65226 m .49651 .65503 L .49444 .65551 L F
.341 0 .007 r
.49651 .65503 m .49263 .65727 L .49444 .65551 L F
.69 .815 .942 r
.67313 .50799 m .67652 .50843 L .67535 .50706 L F
.546 .785 .987 r
.67652 .50843 m .67775 .50675 L .67535 .50706 L F
.67652 .50843 m .67899 .50805 L .67775 .50675 L F
.954 .95 .665 r
.56415 .60214 m .56553 .59902 L .56399 .59993 L F
.97 .821 .401 r
.56544 .59532 m .56502 .59836 L .56553 .59902 L F
.946 .957 .673 r
.56553 .59902 m .56502 .59836 L .56399 .59993 L F
0 0 0 r
.55641 .58706 m .55798 .58599 L .55883 .58406 L F
.205 0 .268 r
.55883 .58406 m .56083 .58383 L .56131 .58135 L F
.148 0 .022 r
.55798 .58599 m .56083 .58383 L .55883 .58406 L F
.5 0 0 r
.52911 .76133 m .5322 .76223 L .53271 .76168 L F
.421 .257 .552 r
.53201 .76185 m .52911 .76133 L .53271 .76168 L F
.663 .777 .934 r
.53272 .76192 m .5322 .76223 L .53182 .76183 L F
.421 .257 .552 r
.53198 .76186 m .53182 .76183 L .53201 .76185 L F
.53182 .76183 m .52911 .76133 L .53201 .76185 L F
0 0 0 r
.53271 .76168 m .53444 .76091 L .53508 .76133 L F
.706 .277 .228 r
.53508 .76133 m .53372 .76299 L .53241 .76224 L F
0 0 0 r
.53271 .76168 m .5322 .76223 L .53298 .76177 L F
.53271 .76168 m .53298 .76177 L .53309 .76168 L F
.706 .277 .228 r
.53309 .76168 m .53241 .76224 L .53181 .7619 L F
.53508 .76133 m .53241 .76224 L .53309 .76168 L F
0 0 0 r
.53309 .76168 m .53298 .76177 L .53314 .76168 L F
.53271 .76168 m .53314 .76168 L .53444 .76091 L F
.706 .277 .228 r
.53508 .76133 m .53309 .76168 L .53271 .76168 L F
.663 .777 .934 r
.53444 .76091 m .53314 .76168 L .53035 .76026 L F
.53314 .76168 m .53272 .76192 L .53251 .76178 L F
.706 .277 .228 r
.53309 .76168 m .53276 .76174 L .53271 .76168 L F
.53276 .76174 m .53201 .76185 L .53271 .76168 L F
.663 .777 .934 r
.53314 .76168 m .53251 .76178 L .53035 .76026 L F
.53272 .76192 m .53182 .76183 L .53035 .76026 L F
.706 .277 .228 r
.53276 .76174 m .53181 .7619 L .53201 .76185 L F
.275 .59 .947 r
.53035 .76026 m .53182 .76183 L .52911 .76133 L F
.53182 .76183 m .5322 .76223 L .52911 .76133 L F
.421 .257 .552 r
.53181 .7619 m .52911 .76133 L .53198 .76186 L F
.494 .259 .486 r
.46078 .64973 m .46293 .64945 L .46324 .64744 L F
.473 .135 .312 r
.45973 .65215 m .46293 .64945 L .46078 .64973 L F
.498 .517 .807 r
.54143 .64143 m .5405 .64194 L .53853 .63831 L F
.77 .535 .579 r
.61303 .56155 m .61618 .56389 L .61649 .56194 L F
.002 0 .495 r
.66003 .48505 m .66139 .48648 L .66238 .4855 L F
0 0 0 r
.58741 .67487 m .58384 .67708 L .58546 .67613 L F
.87 .911 .856 r
.73324 .49636 m .73388 .49787 L .73663 .49433 L F
.851 .651 .631 r
.61802 .56977 m .61898 .57067 L .61773 .56735 L F
.866 .717 .695 r
.61578 .57231 m .61898 .57067 L .61802 .56977 L F
.414 .863 .846 r
.53304 .5995 m .52897 .60059 L .53176 .59929 L F
.506 .899 .943 r
.53519 .59865 m .53304 .5995 L .53176 .59929 L F
.06 .14 .635 r
.57288 .64409 m .57438 .64621 L .57331 .64741 L F
.159 .297 .756 r
.57438 .64621 m .57554 .64951 L .57331 .64741 L F
.447 .299 .586 r
.28379 .60191 m .28568 .6013 L .28553 .59886 L F
.489 .416 .701 r
.28379 .60191 m .28627 .60384 L .28568 .6013 L F
.504 .416 .689 r
.28379 .60191 m .2843 .60454 L .28627 .60384 L F
.582 .403 .604 r
.41239 .60471 m .41236 .60703 L .40998 .60743 L F
.468 .187 .403 r
.41236 .60703 m .40954 .60931 L .40998 .60743 L F
.6 .468 .672 r
.71711 .50293 m .71956 .50178 L .7163 .50175 L F
.71711 .50293 m .71975 .50433 L .71956 .50178 L F
.743 .588 .683 r
.58133 .64986 m .58282 .64875 L .58202 .64815 L F
.595 .532 .753 r
.58546 .65021 m .58202 .64815 L .58282 .64875 L F
.499 .301 .543 r
.32562 .60695 m .32335 .60967 L .32368 .60755 L F
.741 .676 .788 r
.28443 .63345 m .28594 .63675 L .28792 .63473 L F
.71 .539 .656 r
.60131 .55863 m .60352 .55604 L .60114 .55598 L F
.642 .455 .615 r
.58842 .63598 m .59033 .63608 L .59114 .63341 L F
.445 .358 .664 r
.59114 .63341 m .5929 .63254 L .59267 .63 L F
.69 .608 .76 r
.59033 .63608 m .5929 .63254 L .59114 .63341 L F
.389 .216 .522 r
.44594 .68314 m .44381 .68414 L .44398 .68173 L F
.573 .108 .111 r
.44659 .68219 m .44594 .68314 L .44398 .68173 L F
0 0 0 r
.4949 .78998 m .49589 .78896 L .49685 .78746 L F
.198 .257 .698 r
.4949 .78998 m .49676 .79242 L .49589 .78896 L F
.575 .419 .633 r
.49197 .77934 m .49503 .7822 L .49508 .77876 L F
.543 0 0 r
.70566 .469 m .70897 .46948 L .7062 .46813 L F
.642 .419 .565 r
.51694 .65254 m .51464 .65019 L .5176 .65032 L F
.616 .336 .47 r
.51972 .65187 m .51694 .65254 L .5176 .65032 L F
.51972 .65187 m .51694 .65254 L .5176 .65032 L F
.722 .566 .678 r
.23718 .68788 m .23742 .68743 L .23711 .68743 L F
.497 .262 .487 r
.46324 .64744 m .46502 .64899 L .4657 .64725 L F
.46324 .64744 m .46293 .64945 L .46502 .64899 L F
.38 .058 .289 r
.37094 .63333 m .37025 .63495 L .36819 .6354 L F
.487 .162 .342 r
.37258 .63454 m .37025 .63495 L .37094 .63333 L F
.511 .149 .29 r
.37328 .6332 m .37258 .63454 L .37094 .63333 L F
.637 .197 .188 r
.45823 .70771 m .4605 .70937 L .45682 .70931 L F
.586 .707 .926 r
.38425 .59916 m .38554 .5975 L .38355 .59828 L F
.38425 .59916 m .38649 .59868 L .38554 .5975 L F
.642 .419 .565 r
.51694 .65254 m .51337 .65285 L .51464 .65019 L F
.325 .78 .951 r
.35713 .58611 m .35938 .58589 L .36105 .58629 L F
.123 0 0 r
.35938 .58589 m .3631 .58615 L .36105 .58629 L F
.299 0 0 r
.48006 .67021 m .48142 .67117 L .47841 .66977 L F
.48006 .67021 m .48241 .6703 L .48142 .67117 L F
.586 .471 .688 r
.48211 .66744 m .48221 .66836 L .48006 .67021 L F
.374 .491 .849 r
.48193 .66712 m .47878 .6646 L .4805 .66466 L F
.48211 .66744 m .48159 .66699 L .48193 .66712 L F
.48159 .66699 m .47878 .6646 L .48193 .66712 L F
.675 .643 .81 r
.48458 .66694 m .48211 .66744 L .4805 .66466 L F
.623 .498 .689 r
.4845 .66986 m .48211 .66744 L .48458 .66694 L F
.4845 .66986 m .48241 .6703 L .48211 .66744 L F
.527 0 0 r
.47959 .66822 m .48283 .66746 L .47803 .66679 L F
.48283 .66746 m .48323 .66737 L .4823 .66726 L F
.48283 .66746 m .4823 .66726 L .47803 .66679 L F
.746 .641 .744 r
.47803 .66679 m .48323 .66737 L .4805 .66466 L F
.675 .643 .81 r
.48458 .66694 m .4805 .66466 L .48349 .6659 L F
.327 .529 .898 r
.48349 .6659 m .48323 .66737 L .4805 .66466 L F
.834 .985 .872 r
.48349 .6659 m .48326 .66722 L .47959 .66822 L F
.48326 .66722 m .48323 .66737 L .48309 .6674 L F
.48326 .66722 m .48309 .6674 L .47959 .66822 L F
.586 .471 .688 r
.48221 .66836 m .48241 .6703 L .4805 .67023 L F
.48221 .66836 m .4805 .67023 L .48006 .67021 L F
.274 .691 .969 r
.47632 .66284 m .47944 .66343 L .47878 .6646 L F
0 0 0 r
.47878 .6646 m .47608 .66535 L .47632 .66284 L F
.47878 .6646 m .4784 .66495 L .47608 .66535 L F
.746 .641 .744 r
.47803 .66679 m .4805 .66466 L .47878 .6646 L F
.563 .936 .833 r
.47878 .6646 m .47944 .66343 L .48098 .66233 L F
.51 .821 .5 r
.48098 .66233 m .4784 .66495 L .47878 .6646 L F
.259 0 0 r
.35616 .62605 m .35851 .62575 L .36007 .6245 L F
.516 .078 .146 r
.35851 .62575 m .3623 .62416 L .36007 .6245 L F
.397 .094 .33 r
.37275 .61583 m .37487 .61532 L .37546 .61339 L F
.577 .327 .501 r
.37487 .61532 m .37763 .61284 L .37546 .61339 L F
.925 .892 .481 r
.60333 .60115 m .60296 .60044 L .60401 .59895 L F
.981 .758 .347 r
.60401 .59895 m .60328 .59801 L .60344 .59565 L F
.994 .825 .46 r
.60401 .59895 m .60296 .60044 L .60328 .59801 L F
.535 .711 .953 r
.65963 .50846 m .65907 .51029 L .65831 .50855 L F
.65963 .50846 m .66137 .5099 L .65907 .51029 L F
.65963 .50846 m .65907 .51029 L .65831 .50855 L F
.65963 .50846 m .66137 .5099 L .65907 .51029 L F
.645 .784 .948 r
.34287 .62837 m .34025 .62888 L .33892 .62753 L F
.57 .325 .505 r
.57678 .57019 m .57931 .56989 L .57938 .56773 L F
.519 .206 .377 r
.5815 .56925 m .57938 .56773 L .57931 .56989 L F
.5815 .56925 m .58202 .56753 L .57938 .56773 L F
.314 0 .03 r
.30074 .58903 m .30375 .58759 L .30159 .58804 L F
.373 .79 .977 r
.34763 .58526 m .35006 .58499 L .35155 .58559 L F
.298 .713 .974 r
.3524 .58472 m .35155 .58559 L .35006 .58499 L F
.3524 .58472 m .35352 .58544 L .35155 .58559 L F
.259 .225 .63 r
.60154 .616 m .60353 .61479 L .60278 .61247 L F
.165 .048 .463 r
.60159 .61853 m .60353 .61479 L .60154 .616 L F
.92 .962 .79 r
.30358 .63416 m .30369 .63682 L .30521 .63547 L F
.805 .937 .575 r
.68819 .50029 m .68741 .50245 L .68853 .50043 L F
.68819 .50029 m .68632 .50343 L .68741 .50245 L F
.648 .328 .416 r
.54886 .65864 m .55112 .66084 L .54734 .66071 L F
.606 .405 .583 r
.4148 .60446 m .41236 .60703 L .41239 .60471 L F
0 0 0 r
.54321 .59551 m .54136 .59653 L .53969 .59746 L F
.815 .67 .703 r
.61618 .56389 m .61419 .56686 L .61773 .56735 L F
.841 .608 .587 r
.61419 .56686 m .61802 .56977 L .61773 .56735 L F
.629 .563 .761 r
.77326 .49022 m .77074 .49062 L .76979 .48737 L F
.623 .445 .622 r
.77347 .49252 m .77074 .49062 L .77326 .49022 L F
.77347 .49252 m .77098 .49321 L .77074 .49062 L F
.337 0 .023 r
.34064 .64472 m .33887 .64681 L .33674 .64698 L F
.193 0 0 r
.34127 .64591 m .34064 .64472 L .34289 .64462 L F
.34127 .64591 m .33887 .64681 L .34064 .64472 L F
.866 .668 .634 r
.71842 .49631 m .71591 .49563 L .71663 .49534 L F
.905 .929 .819 r
.71842 .49631 m .71564 .49799 L .71591 .49563 L F
.71842 .49631 m .71632 .49917 L .71564 .49799 L F
.782 .741 .815 r
.72101 .49357 m .71842 .49631 L .71663 .49534 L F
.486 .567 .863 r
.54232 .76521 m .54447 .76509 L .54087 .76346 L F
.264 .404 .816 r
.77446 .51299 m .7731 .51333 L .77123 .51016 L F
.494 .459 .747 r
.77446 .51299 m .7732 .51562 L .7731 .51333 L F
.516 .265 .473 r
.27261 .64785 m .27519 .64764 L .27447 .64614 L F
.442 .233 .5 r
.27447 .64614 m .27519 .64764 L .27707 .64648 L F
.773 .946 .934 r
.74567 .51106 m .74196 .51238 L .74478 .51053 L F
.687 .961 .944 r
.74688 .50944 m .74567 .51106 L .74478 .51053 L F
.235 0 0 r
.74663 .5086 m .74688 .50944 L .74591 .508 L F
.74835 .51004 m .74688 .50944 L .74663 .5086 L F
.687 .961 .944 r
.74688 .50944 m .74814 .50967 L .74713 .51024 L F
.74688 .50944 m .74713 .51024 L .74567 .51106 L F
0 .181 .688 r
.71632 .49917 m .71742 .4996 L .71564 .49799 L F
.71632 .49917 m .71839 .50087 L .71742 .4996 L F
.991 .741 .447 r
.49681 .70762 m .49554 .70896 L .49577 .70671 L F
.234 .423 .844 r
.49681 .70762 m .49784 .70624 L .49577 .70671 L F
.49681 .70762 m .49921 .70818 L .49784 .70624 L F
.754 .263 .065 r
.50872 .62548 m .51045 .62734 L .512 .62746 L F
.38 .018 .22 r
.2884 .59654 m .29049 .59545 L .28838 .59585 L F
.198 .727 .77 r
.68219 .50753 m .68141 .50758 L .67899 .50805 L F
.299 .795 .804 r
.68376 .5069 m .68219 .50753 L .68459 .5068 L F
.68376 .5069 m .68141 .50758 L .68219 .50753 L F
.384 .588 .924 r
.20883 .5548 m .20851 .55673 L .20799 .55593 L F
.20883 .5548 m .2111 .55726 L .20851 .55673 L F
.527 .333 .56 r
.54143 .64143 m .54315 .64174 L .54507 .64175 L F
.714 .768 .894 r
.54639 .65168 m .54757 .65316 L .54403 .65277 L F
.54639 .65168 m .54757 .65316 L .54403 .65277 L F
0 .322 .802 r
.54648 .64208 m .54742 .64331 L .54507 .64175 L F
.54648 .64208 m .54507 .64175 L .54315 .64174 L F
.536 .696 .942 r
.54893 .6514 m .54757 .65316 L .54639 .65168 L F
.54893 .6514 m .54757 .65316 L .54639 .65168 L F
.399 .242 .55 r
.69765 .47001 m .69953 .46693 L .6973 .46755 L F
.638 .338 .446 r
.67656 .48231 m .68 .48354 L .67902 .4814 L F
.67656 .48231 m .67628 .48417 L .68 .48354 L F
.535 .392 .633 r
.60408 .64177 m .60438 .6446 L .60227 .64512 L F
.346 .413 .788 r
.60465 .65911 m .60695 .66054 L .60516 .66179 L F
.132 .042 .478 r
.60695 .66054 m .60517 .66352 L .60516 .66179 L F
.515 .063 .116 r
.46418 .70792 m .46298 .70951 L .4605 .70937 L F
.499 .047 .107 r
.46644 .70896 m .46298 .70951 L .46418 .70792 L F
.774 .446 .431 r
.79491 .52107 m .7966 .52211 L .79828 .52171 L F
.79491 .52107 m .7966 .52211 L .79828 .52171 L F
.117 .096 .556 r
.56311 .62372 m .56178 .62495 L .56191 .62135 L F
0 0 .285 r
.56311 .62372 m .563 .62699 L .56178 .62495 L F
.489 0 0 r
.45906 .66757 m .45985 .66885 L .45871 .66997 L F
.45906 .66757 m .46141 .66776 L .45985 .66885 L F
.456 .163 .378 r
.58202 .56753 m .58437 .567 L .58486 .56458 L F
.606 .161 .168 r
.58676 .56611 m .58486 .56458 L .58437 .567 L F
.58676 .56611 m .58719 .56583 L .58486 .56458 L F
.662 .52 .68 r
.5875 .56473 m .58712 .56196 L .58486 .56458 L F
.598 .208 .275 r
.58486 .56458 m .58719 .56583 L .5875 .56473 L F
.506 .586 .869 r
.55568 .63548 m .55571 .63212 L .55431 .63258 L F
.55568 .63548 m .55788 .63534 L .55571 .63212 L F
.792 .596 .636 r
.50035 .79525 m .50389 .79319 L .50157 .79425 L F
.728 .225 .035 r
.48391 .70386 m .48638 .70613 L .48676 .705 L F
.601 .308 .445 r
.50334 .65835 m .50602 .65632 L .50204 .65526 L F
.50334 .65835 m .5056 .65832 L .50602 .65632 L F
.006 0 0 r
.66238 .4855 m .66363 .48573 L .66483 .48528 L F
.188 0 0 r
.66238 .4855 m .66483 .48528 L .66481 .48502 L F
0 .551 .712 r
.31708 .58247 m .31934 .58258 L .32123 .58269 L F
.162 0 0 r
.31934 .58258 m .32329 .58222 L .32123 .58269 L F
.956 .706 .519 r
.50308 .78948 m .50239 .79249 L .50054 .79192 L F
.50308 .78948 m .50389 .79319 L .50239 .79249 L F
.53 .533 .803 r
.50222 .78762 m .50518 .78904 L .50308 .78948 L F
.655 .585 .764 r
.50416 .79234 m .50389 .79319 L .50369 .79226 L F
.50518 .78904 m .50625 .7925 L .50389 .79319 L F
.993 .75 .45 r
.50625 .7925 m .50239 .79249 L .50389 .79319 L F
.50524 .7925 m .50522 .79283 L .50239 .79249 L F
.50625 .7925 m .50593 .79261 L .50524 .7925 L F
.50593 .79261 m .50522 .79283 L .50524 .7925 L F
.655 .585 .764 r
.50518 .78904 m .50416 .79234 L .50308 .78948 L F
.50416 .79234 m .50369 .79226 L .50308 .78948 L F
.801 .61 .644 r
.67849 .4932 m .67523 .48993 L .6787 .49044 L F
.483 .215 .431 r
.37763 .61284 m .37988 .6124 L .38079 .60925 L F
.452 .185 .418 r
.38079 .60925 m .38201 .61189 L .38316 .60939 L F
.38079 .60925 m .37988 .6124 L .38201 .61189 L F
0 0 .502 r
.53624 .61634 m .53707 .6171 L .53585 .61506 L F
.53624 .61634 m .53758 .61813 L .53707 .6171 L F
.983 .907 .61 r
.60202 .60897 m .60349 .60771 L .60257 .60999 L F
.958 .679 .463 r
.6019 .60665 m .60349 .60771 L .60202 .60897 L F
.988 .716 .394 r
.51099 .62858 m .512 .62746 L .51045 .62734 L F
.51099 .62858 m .51209 .62992 L .512 .62746 L F
.025 0 0 r
.3482 .64319 m .34916 .64235 L .35108 .64163 L F
.711 .309 .284 r
.4253 .69777 m .42739 .69994 L .42392 .69995 L F
.4253 .69777 m .42392 .69995 L .42571 .69717 L F
.4253 .69777 m .42571 .69717 L .42602 .69668 L F
.585 .733 .945 r
.42345 .69758 m .42509 .69809 L .4253 .69777 L F
.42509 .69809 m .42686 .69863 L .4253 .69777 L F
.679 .145 0 r
.42686 .69863 m .42739 .69994 L .4253 .69777 L F
.42686 .69863 m .42877 .70074 L .42739 .69994 L F
.874 .958 .616 r
.68946 .49924 m .68819 .50029 L .68853 .50043 L F
.885 .972 .66 r
.69013 .4968 m .68946 .49924 L .69131 .49592 L F
.876 .958 .616 r
.69013 .4968 m .68819 .50029 L .68946 .49924 L F
.367 .822 .712 r
.48584 .64252 m .48408 .64318 L .48269 .64397 L F
.012 0 0 r
.488 .6421 m .48408 .64318 L .48584 .64252 L F
.641 .664 .856 r
.52662 .66822 m .52712 .66998 L .52446 .67023 L F
0 0 .082 r
.52446 .67023 m .52578 .6697 L .52662 .66822 L F
.678 .474 .603 r
.52596 .67159 m .52446 .67023 L .52712 .66998 L F
0 0 .356 r
.52446 .67023 m .52552 .67151 L .52578 .6697 L F
.678 .474 .603 r
.52596 .67159 m .52431 .67261 L .52446 .67023 L F
0 0 .356 r
.52446 .67023 m .52431 .67261 L .52552 .67151 L F
.568 .358 .555 r
.38574 .60742 m .38809 .60706 L .38819 .60459 L F
.571 .501 .737 r
.38819 .60459 m .38998 .60192 L .38776 .60226 L F
.38819 .60459 m .39066 .60422 L .38998 .60192 L F
.493 .296 .542 r
.38819 .60459 m .39036 .60645 L .39066 .60422 L F
.38819 .60459 m .38809 .60706 L .39036 .60645 L F
.316 .8 .758 r
.44993 .68194 m .44706 .68272 L .44594 .68314 L F
.733 .51 .589 r
.55636 .66469 m .55596 .66709 L .55362 .66629 L F
.651 .957 .937 r
.5569 .66341 m .55472 .66446 L .55636 .66469 L F
.5569 .66341 m .55472 .66446 L .55636 .66469 L F
.516 .391 .648 r
.56399 .59993 m .56306 .60346 L .56415 .60214 L F
.462 .605 .907 r
.33779 .62567 m .33684 .62746 L .33492 .62528 L F
.422 .555 .884 r
.33779 .62567 m .33892 .62753 L .33684 .62746 L F
.147 .209 .671 r
.31605 .64163 m .3174 .64394 L .31696 .64043 L F
.704 .804 .927 r
.31731 .64423 m .31726 .64549 L .31949 .64449 L F
.658 .169 .078 r
.31949 .64449 m .31787 .64476 L .31575 .64404 L F
.147 .209 .671 r
.3174 .64394 m .31787 .64476 L .31757 .64333 L F
.3174 .64394 m .31757 .64333 L .31696 .64043 L F
.704 .804 .927 r
.31575 .64404 m .31702 .64525 L .31731 .64423 L F
.31702 .64525 m .31726 .64549 L .31731 .64423 L F
.79 .7 .765 r
.7013 .47622 m .69933 .47802 L .69825 .47537 L F
.81 .888 .9 r
.66505 .51293 m .6679 .51243 L .66692 .51147 L F
.856 .888 .86 r
.66692 .51147 m .6679 .51243 L .67046 .50979 L F
.19 0 0 r
.36819 .6354 m .3689 .63633 L .36675 .63693 L F
.36819 .6354 m .37025 .63495 L .3689 .63633 L F
.188 .082 .494 r
.60578 .63811 m .60408 .64177 L .60441 .63871 L F
.309 0 .192 r
.7612 .52294 m .75961 .52164 L .7621 .52147 L F
.7612 .52294 m .75904 .52374 L .75961 .52164 L F
.57 .751 .963 r
.39214 .58886 m .39124 .59076 L .38987 .5895 L F
.39214 .58886 m .3934 .59025 L .39124 .59076 L F
.163 0 .175 r
.48269 .64397 m .48198 .64653 L .48013 .64717 L F
.504 .218 .413 r
.39449 .61931 m .39399 .62124 L .39172 .62162 L F
.49 .218 .428 r
.39665 .61881 m .39399 .62124 L .39449 .61931 L F
.506 .093 .191 r
.4889 .65161 m .49257 .64988 L .49045 .64996 L F
.41 .217 .506 r
.57774 .65584 m .57786 .65873 L .57561 .6593 L F
.465 .383 .679 r
.57786 .65873 m .57806 .66103 L .57561 .6593 L F
.708 .547 .669 r
.48774 .66895 m .48458 .66694 L .48803 .66758 L F
.187 .426 .858 r
.48856 .6642 m .48979 .66482 L .48939 .66582 L F
.755 .966 .68 r
.48939 .66582 m .48927 .66612 L .4906 .66454 L F
.187 .426 .858 r
.48979 .66482 m .49163 .66574 L .48939 .66582 L F
.755 .966 .68 r
.48939 .66582 m .48803 .66758 L .48927 .66612 L F
.455 .25 .511 r
.48939 .66582 m .48774 .66895 L .48803 .66758 L F
.834 .62 .614 r
.67893 .49533 m .67498 .49266 L .67849 .4932 L F
.67893 .49533 m .67485 .49464 L .67498 .49266 L F
.832 .656 .665 r
.67893 .49533 m .67657 .49623 L .67485 .49464 L F
.966 .834 .416 r
.51025 .7848 m .51084 .78439 L .50964 .78666 L F
.557 .874 .591 r
.51025 .7848 m .51184 .78327 L .51084 .78439 L F
.806 .644 .682 r
.51184 .78327 m .51098 .78459 L .51084 .78439 L F
.51098 .78459 m .51221 .78564 L .50964 .78666 L F
.51184 .78327 m .51215 .78521 L .51098 .78459 L F
.51215 .78521 m .51221 .78564 L .51098 .78459 L F
0 0 0 r
.50862 .78335 m .51025 .7848 L .50803 .78319 L F
.445 .392 .705 r
.51258 .78308 m .51221 .78564 L .51184 .78327 L F
.724 .446 .505 r
.51221 .78564 m .51084 .78799 L .50964 .78666 L F
.85 .691 .684 r
.51201 .78339 m .51084 .78799 L .51258 .78308 L F
0 0 0 r
.5113 .78432 m .51184 .78327 L .51025 .7848 L F
.51174 .78375 m .51184 .78327 L .5113 .78432 L F
.043 0 0 r
.51106 .78374 m .51184 .78327 L .51293 .78244 L F
0 0 0 r
.51061 .78408 m .51036 .78426 L .50862 .78335 L F
.043 0 0 r
.50993 .78452 m .51063 .78406 L .5108 .78393 L F
0 0 0 r
.51061 .78408 m .51065 .78442 L .51036 .78426 L F
.85 .691 .684 r
.51083 .78403 m .5113 .78432 L .51201 .78339 L F
0 0 0 r
.51107 .78401 m .51097 .78411 L .51083 .78403 L F
.043 0 0 r
.51083 .78403 m .51258 .78308 L .51063 .78406 L F
0 0 0 r
.51104 .784 m .51083 .78403 L .51059 .78388 L F
.51107 .78401 m .51083 .78403 L .51104 .784 L F
.85 .691 .684 r
.51174 .78375 m .51084 .78799 L .51201 .78339 L F
.5113 .78432 m .51138 .78437 L .51174 .78375 L F
.51036 .78616 m .51084 .78799 L .51174 .78375 L F
0 0 0 r
.51165 .78416 m .51174 .78375 L .5113 .78432 L F
.51165 .78416 m .5113 .78432 L .51144 .78411 L F
.5113 .78432 m .51119 .78437 L .51126 .78429 L F
.5113 .78432 m .51126 .78429 L .51144 .78411 L F
.85 .691 .684 r
.51024 .78572 m .51036 .78616 L .51138 .78437 L F
.51024 .78572 m .51138 .78437 L .5113 .78432 L F
0 0 0 r
.512 .78369 m .51191 .78344 L .51165 .78416 L F
.51191 .78344 m .51184 .78327 L .51174 .78375 L F
.51191 .78344 m .51174 .78375 L .51165 .78416 L F
.043 0 0 r
.5119 .78342 m .51258 .78308 L .51184 .78327 L F
0 0 0 r
.51293 .78244 m .51184 .78327 L .512 .78369 L F
.043 0 0 r
.51063 .78406 m .5119 .78342 L .51184 .78327 L F
.50993 .78452 m .51083 .78403 L .51063 .78406 L F
0 0 0 r
.51097 .78411 m .51065 .78442 L .51059 .78388 L F
.51144 .78411 m .51065 .78442 L .51107 .78401 L F
.51144 .78411 m .51078 .78449 L .51065 .78442 L F
.85 .691 .684 r
.50993 .78452 m .5113 .78432 L .51083 .78403 L F
.651 .371 .483 r
.5108 .78393 m .50993 .78452 L .51165 .78416 L F
0 0 0 r
.51059 .78388 m .51061 .78408 L .50862 .78335 L F
.51078 .78449 m .51025 .7848 L .50862 .78335 L F
.651 .371 .483 r
.50803 .78319 m .50993 .78452 L .5108 .78393 L F
.043 0 0 r
.50993 .78452 m .5108 .78393 L .51106 .78374 L F
.51063 .78406 m .51184 .78327 L .51106 .78374 L F
0 0 0 r
.51119 .78437 m .51025 .7848 L .51144 .78411 L F
.806 .644 .682 r
.51098 .78459 m .50964 .78666 L .51041 .78519 L F
.51098 .78459 m .51041 .78519 L .51084 .78439 L F
.85 .691 .684 r
.50993 .78452 m .51024 .78572 L .5113 .78432 L F
.317 0 .204 r
.59823 .66777 m .59805 .6689 L .59521 .66997 L F
.446 .071 .232 r
.59823 .66777 m .60007 .66862 L .59805 .6689 L F
.449 .063 .213 r
.60066 .6675 m .60007 .66862 L .59823 .66777 L F
.602 .365 .531 r
.59509 .62716 m .5978 .62701 L .59788 .62457 L F
.344 .056 .323 r
.59932 .62587 m .59788 .62457 L .5978 .62701 L F
.59932 .62587 m .59999 .62396 L .59788 .62457 L F
.485 .398 .683 r
.76013 .49592 m .75986 .49673 L .76226 .49516 L F
.451 .399 .709 r
.75986 .49673 m .76232 .49846 L .76226 .49516 L F
.75986 .49673 m .76042 .49902 L .76232 .49846 L F
.42 .053 .232 r
.45258 .6551 m .45486 .65468 L .45546 .6533 L F
.523 .236 .42 r
.45486 .65468 m .45755 .6527 L .45546 .6533 L F
.829 .885 .883 r
.67382 .49852 m .6722 .50005 L .67108 .49895 L F
.702 .76 .897 r
.72206 .5015 m .72549 .50191 L .72358 .49823 L F
.763 .652 .739 r
.72206 .5015 m .72341 .50514 L .72549 .50191 L F
.591 .653 .88 r
.72549 .50191 m .7268 .49829 L .72358 .49823 L F
.72549 .50191 m .7277 .50207 L .7268 .49829 L F
.594 .225 .313 r
.72826 .50348 m .7277 .50207 L .72549 .50191 L F
.733 .293 .208 r
.532 .70466 m .53063 .70609 L .5329 .70282 L F
.532 .70466 m .53411 .70684 L .53063 .70609 L F
.559 .336 .533 r
.53445 .70413 m .53411 .70684 L .532 .70466 L F
.671 .256 .248 r
.47017 .70794 m .46858 .70954 L .46644 .70896 L F
.635 .21 .218 r
.47017 .70794 m .47218 .70955 L .46858 .70954 L F
.46 .183 .405 r
.40205 .61313 m .40157 .61517 L .39936 .61569 L F
.502 .232 .438 r
.40429 .61268 m .40157 .61517 L .40205 .61313 L F
.172 0 0 r
.33412 .60156 m .33241 .60284 L .33024 .60329 L F
.035 0 0 r
.33454 .60216 m .33412 .60156 L .33625 .60103 L F
.33454 .60216 m .33241 .60284 L .33412 .60156 L F
.756 .577 .655 r
.60352 .55604 m .60348 .55868 L .60702 .55892 L F
.737 .491 .557 r
.60345 .56108 m .60702 .55892 L .60348 .55868 L F
.60345 .56108 m .6071 .5613 L .60702 .55892 L F
.705 .465 .559 r
.60702 .55892 m .6071 .5613 L .61084 .5613 L F
.192 .595 .944 r
.56849 .63418 m .56776 .63502 L .56625 .63216 L F
.56849 .63418 m .56953 .63521 L .56776 .63502 L F
.559 .387 .605 r
.5875 .56473 m .58968 .56159 L .58712 .56196 L F
.673 .609 .775 r
.30941 .63845 m .31013 .64159 L .3126 .64063 L F
.882 .725 .682 r
.61788 .58403 m .6191 .58736 L .6196 .58496 L F
0 0 0 r
.57985 .65279 m .57774 .65584 L .57735 .65345 L F
.57985 .65279 m .57912 .65476 L .57774 .65584 L F
.571 .338 .524 r
.58013 .65802 m .57774 .65584 L .57912 .65476 L F
.58013 .65802 m .57786 .65873 L .57774 .65584 L F
.226 .728 .904 r
.34001 .60044 m .34063 .59998 L .33838 .60028 L F
.34001 .60044 m .34199 .60033 L .34063 .59998 L F
.553 .452 .694 r
.77493 .49629 m .77236 .49867 L .77209 .49721 L F
.77493 .49629 m .77469 .49825 L .77236 .49867 L F
.556 .514 .763 r
.77508 .50098 m .77236 .49867 L .77469 .49825 L F
.064 .263 .755 r
.51694 .65254 m .51838 .65595 L .51902 .65413 L F
.356 .607 .944 r
.51838 .65595 m .5205 .65637 L .51902 .65413 L F
.51838 .65595 m .5205 .65637 L .51902 .65413 L F
.422 .226 .507 r
.42646 .67025 m .42628 .67259 L .42841 .66964 L F
.583 .358 .54 r
.58968 .56159 m .59203 .56142 L .59224 .5591 L F
.629 .435 .601 r
.59203 .56142 m .59452 .55853 L .59224 .5591 L F
.758 .649 .741 r
.71975 .50433 m .72341 .50514 L .72206 .5015 L F
.989 .722 .399 r
.69005 .4757 m .69018 .47848 L .68903 .47508 L F
.448 .825 .99 r
.69005 .4757 m .68903 .47508 L .69236 .47524 L F
.483 .372 .651 r
.2843 .60454 m .28664 .60628 L .28627 .60384 L F
.2843 .60454 m .28449 .60772 L .28664 .60628 L F
.858 .731 .722 r
.73925 .48681 m .73762 .48962 L .74036 .49019 L F
.881 .666 .606 r
.73762 .48962 m .7394 .49219 L .74036 .49019 L F
.778 .693 .769 r
.73925 .48681 m .74036 .49019 L .74268 .48735 L F
0 .11 .662 r
.49794 .63987 m .49722 .64042 L .49767 .63845 L F
.49794 .63987 m .49772 .64127 L .49722 .64042 L F
.434 .236 .51 r
.3211 .61017 m .32069 .6128 L .31866 .61339 L F
.48 .381 .665 r
.32069 .6128 m .3191 .61568 L .31866 .61339 L F
.384 .475 .829 r
.55482 .6516 m .55615 .65462 L .553 .6532 L F
.513 .306 .536 r
.45806 .67878 m .45785 .68118 L .45561 .68162 L F
.45561 .68162 m .45785 .68118 L .45806 .67878 L F
.643 .637 .829 r
.45971 .67932 m .45785 .68118 L .45806 .67878 L F
0 0 .137 r
.45806 .67878 m .45862 .6797 L .45971 .67932 L F
.45806 .67878 m .45785 .68118 L .45862 .6797 L F
.673 .872 .974 r
.55676 .64402 m .55499 .64515 L .55332 .64401 L F
.55332 .64401 m .55499 .64515 L .55676 .64402 L F
.652 .659 .844 r
.41734 .60137 m .41337 .60006 L .41639 .60016 L F
.535 .323 .538 r
.41734 .60137 m .41713 .60407 L .4148 .60446 L F
.542 .609 .87 r
.41816 .59902 m .41734 .60137 L .41639 .60016 L F
.41816 .59902 m .41948 .60094 L .41734 .60137 L F
.464 .263 .522 r
.41922 .60345 m .41734 .60137 L .41948 .60094 L F
.41922 .60345 m .41713 .60407 L .41734 .60137 L F
.624 .312 .421 r
.51206 .65765 m .50939 .65638 L .51222 .65557 L F
.51206 .65765 m .50894 .65821 L .50939 .65638 L F
.723 .591 .707 r
.53419 .70153 m .53532 .70156 L .53652 .69895 L F
0 0 .199 r
.53652 .69895 m .5375 .70004 L .53925 .69911 L F
.53652 .69895 m .53532 .70156 L .5375 .70004 L F
.567 .262 .41 r
.70998 .47458 m .71238 .47442 L .71137 .47674 L F
.653 .771 .935 r
.5343 .63593 m .53225 .63682 L .53088 .63545 L F
.06 0 .386 r
.59207 .63888 m .59327 .63566 L .59033 .63608 L F
.59207 .63888 m .59316 .63737 L .59327 .63566 L F
0 0 .162 r
.59296 .63981 m .59207 .63888 L .59181 .64115 L F
.59296 .63981 m .59316 .63737 L .59207 .63888 L F
.195 .542 .928 r
.75671 .48208 m .75287 .47986 L .75578 .4809 L F
.34 .677 .978 r
.75807 .48112 m .75671 .48208 L .75578 .4809 L F
.75807 .48112 m .75907 .48225 L .75671 .48208 L F
.856 .888 .86 r
.66692 .51147 m .67046 .50979 L .6695 .50908 L F
.785 .946 .928 r
.67213 .50711 m .67046 .50979 L .67313 .50799 L F
.67213 .50711 m .6695 .50908 L .67046 .50979 L F
.651 .575 .756 r
.49976 .66748 m .50078 .67067 L .50174 .67008 L F
.452 .242 .502 r
.57692 .58452 m .57681 .58666 L .57464 .58729 L F
.443 .139 .353 r
.57681 .58666 m .57373 .58932 L .57464 .58729 L F
.534 .544 .812 r
.28545 .61249 m .28673 .61595 L .28856 .61537 L F
.629 .642 .844 r
.75337 .49353 m .75463 .48977 L .75224 .49069 L F
.75337 .49353 m .75586 .49287 L .75463 .48977 L F
.995 .757 .417 r
.7316 .51619 m .73058 .51767 L .73004 .51528 L F
.7316 .51619 m .73154 .51969 L .73058 .51767 L F
.136 0 .208 r
.51156 .70482 m .51081 .70672 L .51314 .70388 L F
.173 0 0 r
.49577 .70671 m .49784 .70624 L .49916 .70477 L F
.139 0 0 r
.49916 .70477 m .49784 .70624 L .49915 .70497 L F
.767 .716 .804 r
.73925 .48681 m .74268 .48735 L .74175 .48398 L F
.729 .693 .816 r
.74175 .48398 m .74268 .48735 L .74515 .48493 L F
.566 .239 .375 r
.4413 .66364 m .43915 .66208 L .43876 .66366 L F
.4413 .66364 m .44229 .66121 L .43915 .66208 L F
.412 .52 .858 r
.44477 .69034 m .44384 .69243 L .44241 .69074 L F
.075 .117 .602 r
.44477 .69034 m .44498 .69284 L .44384 .69243 L F
.481 .267 .511 r
.44635 .69571 m .44384 .69243 L .44498 .69284 L F
.741 .676 .788 r
.28443 .63345 m .28792 .63473 L .28685 .63238 L F
.642 .596 .787 r
.28685 .63238 m .28792 .63473 L .29042 .63396 L F
.417 .086 .294 r
.38295 .62878 m .38148 .62767 L .3836 .62741 L F
.38295 .62878 m .38093 .62923 L .38148 .62767 L F
.326 .805 .899 r
.36131 .5973 m .36571 .59699 L .36459 .59675 L F
.042 .592 .831 r
.36571 .59699 m .3662 .59673 L .36459 .59675 L F
.36571 .59699 m .36768 .59718 L .3662 .59673 L F
.003 .486 .867 r
.51588 .63211 m .51789 .63277 L .51895 .63369 L F
.296 .702 .975 r
.51998 .63288 m .51895 .63369 L .51789 .63277 L F
.51998 .63288 m .52171 .63378 L .51895 .63369 L F
.659 .717 .891 r
.2658 .81977 m .26704 .81769 L .26523 .81842 L F
.2658 .81977 m .26837 .81929 L .26704 .81769 L F
.453 .554 .869 r
.32309 .61496 m .32315 .6185 L .32107 .61538 L F
.32309 .61496 m .3248 .61808 L .32315 .6185 L F
.443 .375 .686 r
.76042 .49902 m .76309 .50088 L .76232 .49846 L F
.497 .365 .631 r
.76042 .49902 m .76079 .50123 L .76309 .50088 L F
.516 .391 .648 r
.56399 .59993 m .56207 .60342 L .56306 .60346 L F
0 0 0 r
.68786 .47934 m .68954 .47834 L .69018 .47848 L F
.68786 .47934 m .68664 .48007 L .68954 .47834 L F
.894 .581 .081 r
.59701 .64742 m .59635 .64682 L .59649 .646 L F
.675 .208 .135 r
.59701 .64742 m .59532 .64843 L .59635 .64682 L F
.476 .269 .519 r
.59701 .64742 m .59674 .64984 L .59894 .64921 L F
.675 .208 .135 r
.59701 .64742 m .59894 .64921 L .59532 .64843 L F
0 .024 .541 r
.56554 .65261 m .5661 .64921 L .5645 .64946 L F
.56554 .65261 m .56658 .6515 L .5661 .64921 L F
0 0 .333 r
.56554 .65261 m .56652 .65371 L .56658 .6515 L F
.56554 .65261 m .56528 .65524 L .56652 .65371 L F
.182 0 0 r
.5329 .70282 m .53532 .70156 L .53419 .70153 L F
0 0 0 r
.53532 .70156 m .53494 .70253 L .5375 .70004 L F
.465 .215 .449 r
.56083 .58383 m .56342 .58094 L .56131 .58135 L F
.384 .106 .362 r
.46841 .64482 m .46792 .64674 L .47046 .64428 L F
.587 .477 .695 r
.51337 .65285 m .51222 .65557 L .51182 .65322 L F
.886 .986 .72 r
.55897 .66516 m .55761 .66715 L .55852 .66724 L F
0 .551 .721 r
.55917 .6673 m .55852 .66724 L .55596 .66709 L F
0 0 0 r
.55852 .66724 m .55507 .66873 L .55596 .66709 L F
.886 .986 .72 r
.55761 .66715 m .55699 .66806 L .55852 .66724 L F
0 .551 .721 r
.55944 .66732 m .55852 .66724 L .55917 .6673 L F
.144 .245 .711 r
.55873 .66395 m .56069 .66615 L .55944 .66732 L F
.551 .93 .897 r
.56069 .66615 m .55852 .66724 L .55944 .66732 L F
.792 .596 .636 r
.50035 .79525 m .50408 .79672 L .50389 .79319 L F
.517 .384 .639 r
.50408 .79672 m .50615 .79514 L .50389 .79319 L F
.757 .68 .776 r
.72433 .48424 m .72539 .48758 L .72189 .48702 L F
.906 .861 .785 r
.72539 .48758 m .72228 .48956 L .72189 .48702 L F
.72539 .48758 m .72337 .49078 L .72228 .48956 L F
.772 .686 .768 r
.49794 .63987 m .49921 .64334 L .49772 .64127 L F
.644 .1 0 r
.56953 .63521 m .57245 .63722 L .57299 .63617 L F
.923 .586 .13 r
.57245 .63722 m .57331 .63827 L .57299 .63617 L F
.71 .539 .656 r
.60131 .55863 m .60348 .55868 L .60352 .55604 L F
.841 .608 .587 r
.61419 .56686 m .6142 .56932 L .61802 .56977 L F
.842 .651 .644 r
.6142 .56932 m .61578 .57231 L .61802 .56977 L F
.587 .584 .816 r
.38776 .60226 m .38831 .59815 L .38649 .59868 L F
.38776 .60226 m .38998 .60192 L .38831 .59815 L F
0 0 .38 r
.55917 .65791 m .55967 .6605 L .5592 .66188 L F
.85 .871 .857 r
.55967 .6605 m .55873 .66395 L .5592 .66188 L F
.49 .695 .959 r
.74973 .49111 m .75154 .48949 L .74903 .48937 L F
.74973 .49111 m .75224 .49069 L .75154 .48949 L F
.801 .61 .644 r
.67849 .4932 m .67498 .49266 L .67523 .48993 L F
.786 .953 .624 r
.69207 .4942 m .69131 .49592 L .69337 .49297 L F
.795 .968 .662 r
.69207 .4942 m .69013 .4968 L .69131 .49592 L F
.678 .645 .81 r
.41554 .70355 m .41678 .70557 L .41843 .70413 L F
.592 .504 .724 r
.77347 .49252 m .77209 .49721 L .77098 .49321 L F
.77347 .49252 m .77493 .49629 L .77209 .49721 L F
0 0 .367 r
.57201 .64029 m .57288 .64409 L .57155 .64223 L F
.622 .073 0 r
.55972 .62105 m .56311 .62372 L .56191 .62135 L F
.569 .831 .995 r
.52335 .77516 m .5236 .77665 L .52187 .77591 L F
.52335 .77516 m .5246 .77584 L .5236 .77665 L F
.52335 .77516 m .5236 .77665 L .52187 .77591 L F
.52335 .77516 m .5246 .77584 L .5236 .77665 L F
.659 .103 0 r
.45581 .69902 m .45926 .70123 L .45941 .69828 L F
.571 .405 .617 r
.45941 .69828 m .45926 .70123 L .46177 .69791 L F
.572 .28 .434 r
.76782 .51889 m .7703 .52047 L .76793 .52052 L F
.584 .269 .402 r
.76782 .51889 m .77038 .51884 L .7703 .52047 L F
.515 .177 .332 r
.44378 .66334 m .44229 .66121 L .4413 .66364 L F
.44378 .66334 m .44459 .66105 L .44229 .66121 L F
.682 .678 .84 r
.69933 .47802 m .69609 .47648 L .69825 .47537 L F
.637 .499 .678 r
.50334 .65835 m .5007 .66159 L .50098 .65875 L F
.706 .581 .713 r
.49447 .67034 m .49566 .67332 L .49748 .67008 L F
.364 .646 .963 r
.40855 .59731 m .40775 .59856 L .40665 .59726 L F
.293 0 0 r
.49791 .61915 m .50054 .6198 L .50122 .61966 L F
.698 .157 0 r
.50054 .6198 m .50344 .62177 L .50122 .61966 L F
.203 0 0 r
.50252 .7078 m .50138 .70821 L .49921 .70818 L F
.597 .355 .521 r
.49921 .70818 m .49915 .70497 L .49784 .70624 L F
.49921 .70818 m .50138 .70821 L .49915 .70497 L F
.696 .166 0 r
.49784 .70624 m .50138 .70821 L .49856 .70914 L F
.49784 .70624 m .50057 .7085 L .50138 .70821 L F
.333 .056 .334 r
.50073 .70863 m .49856 .70914 L .50138 .70821 L F
.696 .166 0 r
.50057 .7085 m .50073 .70863 L .50138 .70821 L F
.203 0 0 r
.50299 .70775 m .50138 .70821 L .50252 .7078 L F
.739 .99 .811 r
.50305 .70693 m .50299 .70775 L .50513 .70701 L F
.50305 .70693 m .50138 .70821 L .50299 .70775 L F
.84 .633 .622 r
.60112 .58146 m .5987 .58118 L .59893 .57863 L F
.869 .591 .515 r
.60112 .58146 m .59911 .58334 L .5987 .58118 L F
.60112 .58146 m .60152 .5843 L .59911 .58334 L F
.888 .608 .094 r
.72712 .51037 m .72794 .51352 L .72697 .51229 L F
0 .149 .651 r
.72794 .51352 m .72781 .51307 L .72697 .51229 L F
.72794 .51352 m .73004 .51528 L .72781 .51307 L F
.656 .682 .862 r
.28653 .63008 m .28726 .62628 L .28597 .62718 L F
.28653 .63008 m .28985 .63027 L .28726 .62628 L F
.529 .538 .809 r
.76013 .49592 m .76089 .49172 L .75836 .49215 L F
.76013 .49592 m .76226 .49516 L .76089 .49172 L F
.536 .361 .591 r
.26872 .81601 m .27255 .81528 L .27105 .81532 L F
.2 .578 .941 r
.43608 .70583 m .43737 .70708 L .438 .70618 L F
.105 .449 .883 r
.43737 .70708 m .44005 .70846 L .438 .70618 L F
.434 .542 .867 r
.43737 .70708 m .44046 .70913 L .44005 .70846 L F
.368 .136 .426 r
.31605 .64163 m .31361 .64474 L .31575 .64404 L F
.679 .418 .52 r
.52544 .66145 m .52172 .66149 L .52546 .66159 L F
.219 .349 .783 r
.52649 .66028 m .52544 .66145 L .52546 .66159 L F
.668 .528 .685 r
.26374 .68687 m .26396 .69002 L .26624 .68713 L F
.817 .683 .716 r
.56468 .62704 m .56549 .63031 L .5678 .62689 L F
.708 .63 .767 r
.5678 .62689 m .57053 .62425 L .56677 .62387 L F
.522 .127 .234 r
.54032 .70193 m .53929 .704 L .53659 .70383 L F
.335 0 .186 r
.54244 .70117 m .53929 .704 L .54032 .70193 L F
.943 .86 .435 r
.60333 .60115 m .60231 .6026 L .60296 .60044 L F
.60333 .60115 m .60254 .60434 L .60231 .6026 L F
.119 0 .13 r
.59655 .67085 m .59521 .66997 L .59805 .6689 L F
.59655 .67085 m .5947 .67213 L .59521 .66997 L F
.506 0 0 r
.29239 .63443 m .29662 .63554 L .29434 .63478 L F
.525 .215 .384 r
.36457 .62126 m .36694 .62096 L .36737 .61918 L F
.409 .071 .278 r
.36694 .62096 m .37007 .61805 L .36737 .61918 L F
.562 .714 .943 r
.3126 .64063 m .31605 .64163 L .31452 .64029 L F
.485 .695 .961 r
.31452 .64029 m .31605 .64163 L .31696 .64043 L F
.715 .436 .502 r
.31575 .64404 m .31787 .64476 L .31605 .64163 L F
.31575 .64404 m .31787 .64476 L .31605 .64163 L F
.378 .142 .425 r
.45304 .67256 m .45019 .67637 L .45119 .67251 L F
.782 .741 .815 r
.72101 .49357 m .71663 .49534 L .71993 .49257 L F
.869 .894 .849 r
.72337 .49078 m .72101 .49357 L .71993 .49257 L F
.188 .082 .494 r
.60578 .63811 m .60585 .64053 L .60408 .64177 L F
.333 .274 .64 r
.60585 .64053 m .60438 .6446 L .60408 .64177 L F
.159 0 0 r
.46141 .66776 m .46286 .66827 L .45985 .66885 L F
.46141 .66776 m .46371 .66713 L .46286 .66827 L F
0 .552 .817 r
.37111 .58575 m .37469 .58657 L .37267 .58642 L F
.318 .12 .447 r
.57917 .58392 m .57681 .58666 L .57692 .58452 L F
.953 .72 .548 r
.49685 .78746 m .49589 .78896 L .49449 .78406 L F
.783 .734 .807 r
.49885 .78561 m .49685 .78746 L .49449 .78406 L F
0 .469 .851 r
.75475 .48007 m .75287 .47986 L .75183 .47865 L F
.75475 .48007 m .75578 .4809 L .75287 .47986 L F
.583 .335 .506 r
.38541 .6095 m .38809 .60706 L .38574 .60742 L F
0 0 0 r
.48013 .64717 m .47918 .64885 L .47824 .65002 L F
.555 .818 .453 r
.47918 .64885 m .47706 .65146 L .47824 .65002 L F
.525 .92 .861 r
.37134 .59577 m .37043 .59583 L .36768 .59718 L F
.495 .843 .995 r
.37356 .59526 m .37224 .59465 L .37134 .59577 L F
.595 .95 .866 r
.37224 .59465 m .37043 .59583 L .37134 .59577 L F
0 .042 .57 r
.5587 .61972 m .55876 .62007 L .55773 .61902 L F
.091 .574 .904 r
.55864 .6194 m .5587 .61972 L .55736 .6196 L F
.964 .914 .561 r
.55955 .61678 m .5587 .61972 L .56012 .61915 L F
.55955 .61678 m .5587 .61972 L .56012 .61915 L F
.091 .574 .904 r
.55942 .61928 m .5587 .61972 L .55864 .6194 L F
0 .042 .57 r
.5587 .61972 m .55972 .62105 L .55876 .62007 L F
.101 0 .312 r
.6154 .61224 m .61533 .61476 L .61331 .61607 L F
.197 .074 .477 r
.61331 .61607 m .61536 .61717 L .61384 .61852 L F
.61331 .61607 m .61533 .61476 L .61536 .61717 L F
.732 .624 .738 r
.71077 .47726 m .70453 .47554 L .70712 .47465 L F
.71077 .47726 m .70535 .47878 L .70453 .47554 L F
.786 .953 .624 r
.69207 .4942 m .69337 .49297 L .69269 .4922 L F
.858 .95 .874 r
.69525 .48946 m .69337 .49297 L .69511 .49171 L F
.69525 .48946 m .69269 .4922 L .69337 .49297 L F
.567 .368 .571 r
.50315 .64178 m .50603 .64154 L .50592 .63874 L F
.454 .48 .796 r
.50462 .63632 m .50592 .63874 L .50755 .63805 L F
.068 0 .455 r
.50592 .63874 m .507 .64052 L .50755 .63805 L F
.50592 .63874 m .50603 .64154 L .507 .64052 L F
.356 .042 .289 r
.37007 .61805 m .37182 .61812 L .37275 .61583 L F
.537 .218 .375 r
.37275 .61583 m .37455 .61731 L .37487 .61532 L F
.37275 .61583 m .37182 .61812 L .37455 .61731 L F
.92 .805 .715 r
.67291 .49544 m .67382 .49852 L .67251 .49706 L F
.829 .885 .883 r
.67382 .49852 m .67108 .49895 L .67251 .49706 L F
.713 .703 .839 r
.67657 .49623 m .67382 .49852 L .67291 .49544 L F
0 .335 .755 r
.73221 .47407 m .73099 .47379 L .72969 .47285 L F
.73221 .47407 m .73357 .47506 L .73099 .47379 L F
.078 0 0 r
.32986 .58269 m .33109 .5828 L .33298 .58284 L F
.294 .746 .957 r
.32954 .58255 m .33227 .58289 L .33109 .5828 L F
.242 0 0 r
.33109 .5828 m .33478 .58327 L .33298 .58284 L F
.294 .746 .957 r
.33227 .58289 m .33317 .58301 L .33109 .5828 L F
.078 0 0 r
.32891 .58265 m .33109 .5828 L .32986 .58269 L F
.393 .77 .992 r
.41423 .59888 m .41337 .60006 L .41258 .59904 L F
.41423 .59888 m .41639 .60016 L .41337 .60006 L F
.447 .264 .538 r
.42226 .67847 m .42422 .67803 L .42438 .67566 L F
.443 .33 .63 r
.42226 .67847 m .42439 .68035 L .42422 .67803 L F
.42226 .67847 m .42229 .68168 L .42439 .68035 L F
.332 0 .079 r
.30583 .58713 m .30816 .58665 L .30942 .58478 L F
.259 0 .038 r
.30942 .58478 m .31031 .586 L .3116 .58465 L F
.30942 .58478 m .30816 .58665 L .31031 .586 L F
.456 .266 .533 r
.28568 .6013 m .2884 .59654 L .28553 .59886 L F
.536 .365 .597 r
.7252 .47562 m .72765 .47502 L .72497 .47327 L F
.264 .082 .437 r
.59999 .62396 m .60175 .62081 L .60019 .62171 L F
0 0 .041 r
.71468 .46949 m .71479 .47181 L .71483 .47314 L F
.759 .445 .454 r
.71238 .47442 m .71483 .47314 L .71479 .47181 L F
.71238 .47442 m .71598 .47568 L .71483 .47314 L F
.462 .608 .91 r
.50222 .78762 m .49885 .78561 L .50111 .78524 L F
.487 .571 .866 r
.50416 .78634 m .50222 .78762 L .50111 .78524 L F
.476 .546 .849 r
.50416 .78634 m .50518 .78904 L .50222 .78762 L F
.895 .7 .631 r
.60338 .58729 m .60088 .58648 L .60152 .5843 L F
.942 .763 .631 r
.60338 .58729 m .60096 .58883 L .60088 .58648 L F
.60338 .58729 m .60261 .5898 L .60096 .58883 L F
.478 .842 .593 r
.59311 .65899 m .59467 .65766 L .59497 .65783 L F
.582 .645 .878 r
.50438 .64945 m .50828 .65241 L .50695 .6488 L F
.729 .305 .241 r
.50883 .64879 m .51272 .64934 L .51004 .64704 L F
.578 .388 .588 r
.51004 .64704 m .51272 .64934 L .51241 .64666 L F
.489 .137 .295 r
.51245 .6474 m .51041 .64872 L .50883 .64879 L F
0 .077 .602 r
.50828 .65241 m .50883 .64879 L .50698 .64888 L F
.50828 .65241 m .50925 .65088 L .50883 .64879 L F
.623 .296 .396 r
.50925 .65088 m .51272 .64934 L .50883 .64879 L F
.489 .137 .295 r
.51041 .64872 m .50757 .65055 L .50883 .64879 L F
0 .077 .602 r
.50698 .64888 m .50883 .64879 L .50695 .6488 L F
.432 0 .09 r
.50828 .65241 m .51203 .65298 L .50925 .65088 L F
.50828 .65241 m .50701 .65449 L .51203 .65298 L F
.115 0 .014 r
.4558 .67278 m .45871 .66997 L .45765 .67162 L F
0 0 0 r
.45765 .67162 m .45871 .66997 L .45985 .66885 L F
.819 .9 .898 r
.43009 .70562 m .43377 .70428 L .43235 .7035 L F
0 .275 .758 r
.43377 .70428 m .43407 .70383 L .43235 .7035 L F
.43377 .70428 m .43608 .70583 L .43407 .70383 L F
.075 .537 .901 r
.53861 .63759 m .53853 .63831 L .53658 .63556 L F
.53861 .63759 m .53947 .63823 L .53853 .63831 L F
.498 .517 .807 r
.54143 .64143 m .53853 .63831 L .53947 .63823 L F
.113 .354 .819 r
.55889 .6565 m .55666 .65614 L .55615 .65462 L F
.55889 .6565 m .55917 .65791 L .55666 .65614 L F
.479 .646 .931 r
.77131 .48559 m .76979 .48737 L .76905 .48571 L F
.492 .666 .94 r
.77214 .48719 m .76979 .48737 L .77131 .48559 L F
.629 .563 .761 r
.77326 .49022 m .76979 .48737 L .77214 .48719 L F
.661 .633 .812 r
.4957 .65226 m .49405 .65316 L .49257 .64988 L F
.381 0 .11 r
.49257 .64988 m .49367 .65116 L .4945 .64843 L F
.391 .697 .982 r
.4945 .64843 m .49579 .64753 L .49409 .64542 L F
.4945 .64843 m .49772 .64822 L .49579 .64753 L F
.462 0 0 r
.3245 .58196 m .32891 .58265 L .32676 .58272 L F
.759 .856 .922 r
.71371 .49117 m .71766 .49116 L .7166 .49029 L F
.814 .911 .906 r
.7166 .49029 m .71766 .49116 L .71947 .4895 L F
.74 .698 .811 r
.51972 .65187 m .52391 .65298 L .52172 .64925 L F
.801 .487 .457 r
.51902 .65413 m .52391 .65298 L .51972 .65187 L F
.51902 .65413 m .52333 .65522 L .52391 .65298 L F
.184 .274 .724 r
.52391 .65298 m .52402 .64883 L .52172 .64925 L F
.52391 .65298 m .52499 .65246 L .52402 .64883 L F
0 0 .15 r
.52391 .65298 m .52333 .65522 L .52499 .65246 L F
.503 .17 .335 r
.50284 .64338 m .50603 .64154 L .50315 .64178 L F
.187 0 0 r
.34609 .64377 m .34518 .64435 L .34289 .64462 L F
.022 0 0 r
.34733 .64378 m .34609 .64377 L .3482 .64319 L F
.34733 .64378 m .34518 .64435 L .34609 .64377 L F
.777 .543 .58 r
.50595 .70618 m .50851 .70736 L .50513 .70701 L F
.747 .393 .383 r
.50851 .70736 m .50499 .70861 L .50513 .70701 L F
.50851 .70736 m .5072 .70942 L .50499 .70861 L F
.662 .291 .33 r
.5108 .70934 m .5072 .70942 L .50851 .70736 L F
.508 .335 .582 r
.51081 .70672 m .5108 .70934 L .50851 .70736 L F
.343 0 0 r
.49127 .64168 m .48909 .64254 L .488 .6421 L F
.79 .999 .841 r
.49197 .64006 m .49127 .64168 L .49343 .64192 L F
.49197 .64006 m .48909 .64254 L .49127 .64168 L F
.559 .387 .605 r
.5875 .56473 m .58998 .56433 L .58968 .56159 L F
.441 .08 .255 r
.58951 .56551 m .5875 .56473 L .58719 .56583 L F
.58951 .56551 m .58998 .56433 L .5875 .56473 L F
.981 .864 .486 r
.72868 .50601 m .72969 .50482 L .72826 .50348 L F
.72868 .50601 m .72916 .50705 L .72969 .50482 L F
.64 .915 .98 r
.28321 .64156 m .28012 .64192 L .28164 .64069 L F
.28012 .64192 m .28321 .64156 L .28164 .64069 L F
.606 .405 .583 r
.4148 .60446 m .41474 .60699 L .41236 .60703 L F
.546 .356 .575 r
.41713 .60407 m .41474 .60699 L .4148 .60446 L F
.267 .46 .864 r
.52378 .63455 m .52276 .63592 L .52171 .63378 L F
.534 .832 .999 r
.52515 .63538 m .52276 .63592 L .52378 .63455 L F
.52515 .63538 m .52276 .63592 L .52378 .63455 L F
.434 .235 .51 r
.32285 .61144 m .3211 .61017 L .32335 .60967 L F
.32285 .61144 m .32069 .6128 L .3211 .61017 L F
.645 .784 .948 r
.34287 .62837 m .33892 .62753 L .34091 .62698 L F
.283 .715 .967 r
.34091 .62698 m .34498 .62784 L .34287 .62837 L F
.432 0 0 r
.47075 .70304 m .47451 .70163 L .47103 .70122 L F
.47075 .70304 m .47318 .70309 L .47451 .70163 L F
.329 .505 .879 r
.47451 .70163 m .47742 .70319 L .47796 .70441 L F
.685 .232 .17 r
.47318 .70309 m .47742 .70319 L .47451 .70163 L F
.868 .486 .317 r
.65538 .49561 m .65372 .49509 L .6546 .49396 L F
0 0 .538 r
.65404 .48973 m .6546 .49396 L .65493 .49275 L F
.824 .913 .513 r
.6546 .49396 m .65372 .49509 L .65493 .49275 L F
.868 .486 .317 r
.65538 .49561 m .65372 .49509 L .6546 .49396 L F
.783 .734 .807 r
.49885 .78561 m .49449 .78406 L .49729 .78672 L F
.515 .435 .703 r
.49752 .78845 m .49849 .78662 L .49729 .78672 L F
.447 0 .064 r
.49775 .78654 m .49849 .78662 L .50111 .78524 L F
.49749 .78658 m .50111 .78524 L .49885 .78561 L F
.49729 .78672 m .49775 .78654 L .49749 .78658 L F
.49775 .78654 m .50111 .78524 L .49749 .78658 L F
.515 .435 .703 r
.49849 .78662 m .49961 .78451 L .49729 .78672 L F
.447 0 .064 r
.49849 .78662 m .49979 .78676 L .50001 .7865 L F
.49849 .78662 m .50001 .7865 L .50111 .78524 L F
.515 .435 .703 r
.49752 .78845 m .49975 .78628 L .49859 .78643 L F
.447 0 .064 r
.49729 .78672 m .49979 .78676 L .49775 .78654 L F
.515 .435 .703 r
.4993 .78671 m .49979 .78676 L .49975 .78628 L F
.49752 .78845 m .49979 .78676 L .4993 .78671 L F
.49859 .78643 m .49975 .78628 L .49961 .78451 L F
.763 .656 .1 r
.61906 .60154 m .61886 .60324 L .61888 .60393 L F
.807 .719 .186 r
.61906 .60154 m .61943 .59578 L .61931 .60087 L F
0 0 0 r
.61931 .60087 m .61886 .60324 L .61906 .60154 L F
.49 .337 .6 r
.505 .70433 m .50513 .70701 L .50725 .70629 L F
.075 0 0 r
.35752 .64003 m .35705 .6394 L .3592 .63887 L F
.35752 .64003 m .35537 .64058 L .35705 .6394 L F
.975 .679 .298 r
.61812 .58635 m .6191 .58736 L .61788 .58403 L F
.61812 .58635 m .6191 .58736 L .61788 .58403 L F
.681 .444 .556 r
.61812 .58635 m .61849 .58778 L .6191 .58736 L F
.505 .491 .776 r
.4446 .68945 m .44241 .69074 L .4415 .68746 L F
.412 .52 .858 r
.44477 .69034 m .44241 .69074 L .4446 .68945 L F
.582 .666 .896 r
.33036 .62079 m .32983 .62389 L .32821 .62155 L F
.33036 .62079 m .33203 .62345 L .32983 .62389 L F
.163 0 0 r
.54993 .5912 m .55368 .58967 L .55145 .59033 L F
.483 .241 .471 r
.57432 .57268 m .57666 .57212 L .57678 .57019 L F
.552 .297 .483 r
.57666 .57212 m .57904 .57196 L .57678 .57019 L F
.56 .295 .471 r
.57678 .57019 m .57904 .57196 L .57931 .56989 L F
.23 .403 .828 r
.207 .554 m .20868 .55483 L .20799 .55593 L F
.384 .588 .924 r
.20883 .5548 m .20799 .55593 L .20868 .55483 L F
.184 .716 .825 r
.34498 .62784 m .34641 .62761 L .34847 .62768 L F
.884 .762 .724 r
.73485 .4932 m .73426 .49462 L .73663 .49433 L F
.87 .911 .856 r
.73324 .49636 m .73663 .49433 L .73426 .49462 L F
.587 .477 .695 r
.51337 .65285 m .51454 .6553 L .51222 .65557 L F
.593 .373 .551 r
.51454 .6553 m .51206 .65765 L .51222 .65557 L F
.097 0 .16 r
.60517 .66352 m .60489 .6658 L .60325 .66698 L F
.132 .042 .478 r
.60695 .66054 m .60709 .66278 L .60517 .66352 L F
.01 0 .138 r
.60517 .66352 m .60709 .66278 L .60489 .6658 L F
.295 .746 .958 r
.37469 .58657 m .37685 .58646 L .37837 .58703 L F
.317 .725 .978 r
.37685 .58646 m .38045 .58726 L .37837 .58703 L F
.474 .593 .892 r
.70575 .49251 m .70715 .49111 L .70441 .49069 L F
.70575 .49251 m .70802 .4927 L .70715 .49111 L F
.551 .818 .995 r
.7435 .53114 m .74477 .52942 L .74238 .52988 L F
.7435 .53114 m .74616 .53058 L .74477 .52942 L F
.563 .639 .884 r
.73537 .51121 m .73354 .51338 L .73233 .51021 L F
.73537 .51121 m .73628 .51294 L .73354 .51338 L F
0 .057 .619 r
.55389 .6088 m .55513 .61208 L .55357 .60991 L F
.031 0 0 r
.21248 .56219 m .2088 .56388 L .20965 .56362 L F
.946 .732 .583 r
.46976 .66709 m .4704 .66958 L .46909 .6698 L F
.83 .423 .274 r
.46909 .6698 m .4704 .66958 L .46908 .67096 L F
.463 .448 .756 r
.47298 .66916 m .4704 .66958 L .46976 .66709 L F
.164 0 0 r
.46908 .67096 m .4704 .66958 L .47298 .66916 L F
.683 .692 .853 r
.28726 .62628 m .28985 .63027 L .29161 .62812 L F
.365 .583 .926 r
.49794 .79571 m .50151 .79818 L .50035 .79525 L F
.716 .687 .82 r
.50151 .79818 m .50408 .79672 L .50035 .79525 L F
.674 .517 .664 r
.58998 .56433 m .59203 .56142 L .58968 .56159 L F
.515 .356 .603 r
.4436 .6869 m .44199 .68453 L .44381 .68414 L F
.4436 .6869 m .4415 .68746 L .44199 .68453 L F
.964 .799 .628 r
.61941 .57558 m .61879 .57807 L .61992 .5787 L F
.859 .685 .665 r
.61679 .5807 m .61992 .5787 L .61879 .57807 L F
.61679 .5807 m .61994 .57967 L .61992 .5787 L F
.472 .562 .866 r
.40505 .59446 m .40475 .59749 L .40293 .59479 L F
.40505 .59446 m .40665 .59726 L .40475 .59749 L F
.492 .036 .096 r
.53925 .69911 m .54108 .70024 L .54236 .69857 L F
.978 .714 .46 r
.54108 .70024 m .54244 .70117 L .54236 .69857 L F
.258 .346 .763 r
.56633 .65865 m .56779 .65747 L .56528 .65524 L F
.194 .232 .673 r
.56833 .66093 m .56779 .65747 L .56633 .65865 L F
.308 .26 .641 r
.56689 .66067 m .56833 .66093 L .56633 .65865 L F
.577 .495 .725 r
.77398 .50691 m .77178 .51009 L .77107 .50752 L F
.77086 .50474 m .77107 .50752 L .77018 .50427 L F
.77398 .50691 m .77107 .50752 L .77086 .50474 L F
.529 .405 .655 r
.77398 .50691 m .77149 .5095 L .77178 .51009 L F
.083 .345 .817 r
.77392 .51158 m .77128 .51019 L .77149 .5095 L F
.77128 .51019 m .77123 .51016 L .77127 .51007 L F
.77128 .51019 m .77127 .51007 L .77149 .5095 L F
.77392 .51158 m .77446 .51299 L .77123 .51016 L F
.536 .218 .376 r
.55233 .64514 m .54898 .64571 L .54742 .64331 L F
.55233 .64514 m .55135 .64638 L .54898 .64571 L F
.69 .608 .76 r
.59033 .63608 m .59327 .63566 L .5929 .63254 L F
.857 .913 .869 r
.58866 .64962 m .58724 .64936 L .5898 .64674 L F
.752 .43 .44 r
.58866 .64962 m .58723 .65189 L .58724 .64936 L F
.58866 .64962 m .59038 .65251 L .58723 .65189 L F
.089 0 0 r
.55752 .60471 m .55619 .60587 L .55397 .60645 L F
.524 .016 0 r
.56013 .60588 m .55619 .60587 L .55752 .60471 L F
.316 0 0 r
.33852 .58303 m .34046 .58392 L .34203 .58457 L F
.258 .735 .937 r
.34046 .58392 m .3442 .58431 L .34203 .58457 L F
.409 .071 .278 r
.36694 .62096 m .36913 .62047 L .37007 .61805 L F
.511 .225 .417 r
.36913 .62047 m .37182 .61812 L .37007 .61805 L F
.869 .894 .849 r
.72337 .49078 m .71993 .49257 L .72228 .48956 L F
.48 .381 .665 r
.32069 .6128 m .32107 .61538 L .3191 .61568 L F
.973 .665 .354 r
.55135 .64638 m .55299 .6497 L .55177 .64761 L F
.519 0 0 r
.42745 .70491 m .42652 .70489 L .42595 .70442 L F
.401 0 0 r
.43009 .70562 m .42652 .70489 L .42745 .70491 L F
.704 .486 .59 r
.46683 .69477 m .46945 .69512 L .46997 .69292 L F
.494 .243 .462 r
.57926 .66421 m .58159 .66375 L .58173 .66172 L F
.471 .187 .399 r
.58159 .66375 m .58422 .66153 L .58173 .66172 L F
0 .525 .836 r
.74847 .50941 m .74814 .50967 L .74688 .50944 L F
.837 .469 .357 r
.50755 .63805 m .50413 .63513 L .50462 .63632 L F
.422 .17 .425 r
.40157 .61517 m .39902 .61796 L .39936 .61569 L F
.953 .926 .738 r
.66598 .50185 m .66426 .50246 L .66528 .50107 L F
.66598 .50185 m .66443 .50489 L .66426 .50246 L F
.914 .96 .802 r
.66598 .50185 m .66573 .49881 L .66747 .50072 L F
.66598 .50185 m .66528 .50107 L .66573 .49881 L F
0 0 0 r
.58028 .65211 m .57912 .65476 L .57985 .65279 L F
.871 .74 .715 r
.61679 .5807 m .61788 .58403 L .61994 .57967 L F
0 0 .255 r
.55788 .63534 m .55846 .63886 L .55835 .63751 L F
.081 .334 .81 r
.56109 .64069 m .55846 .63886 L .56015 .64123 L F
.56109 .64069 m .55835 .63751 L .55846 .63886 L F
.177 .058 .469 r
.60521 .64936 m .60578 .65173 L .6039 .65295 L F
.273 .235 .632 r
.60578 .65173 m .60584 .65495 L .6039 .65295 L F
.318 .242 .611 r
.6039 .65295 m .60584 .65495 L .6043 .65551 L F
.782 .54 .569 r
.61089 .56394 m .61303 .56155 L .61084 .5613 L F
.61089 .56394 m .61441 .56448 L .61303 .56155 L F
.77 .535 .579 r
.61303 .56155 m .61441 .56448 L .61618 .56389 L F
.227 0 .119 r
.46502 .64899 m .46792 .64674 L .4657 .64725 L F
.434 .094 .289 r
.40721 .61065 m .40654 .61226 L .40429 .61268 L F
.47 .158 .354 r
.40954 .60931 m .40654 .61226 L .40721 .61065 L F
.368 .833 .896 r
.34808 .59864 m .34598 .59879 L .34477 .59913 L F
.058 0 0 r
.34846 .59881 m .34808 .59864 L .35026 .59893 L F
.34846 .59881 m .34598 .59879 L .34808 .59864 L F
.972 .88 .501 r
.60393 .59344 m .60297 .59414 L .60277 .59199 L F
.60393 .59344 m .60344 .59565 L .60297 .59414 L F
.353 .714 .986 r
.38789 .5893 m .38396 .58831 L .38661 .58823 L F
.29 .651 .969 r
.38852 .58833 m .38789 .5893 L .38661 .58823 L F
.38852 .58833 m .38987 .5895 L .38789 .5893 L F
.494 .197 .391 r
.7703 .52047 m .77349 .51665 L .77288 .51998 L F
.7703 .52047 m .77038 .51884 L .77349 .51665 L F
.465 .415 .717 r
.7752 .5148 m .77349 .51665 L .7732 .51562 L F
.7752 .5148 m .77562 .51708 L .77349 .51665 L F
.646 .389 .515 r
.77562 .51708 m .77288 .51998 L .77349 .51665 L F
0 0 .285 r
.56311 .62372 m .56343 .62617 L .563 .62699 L F
.284 .698 .971 r
.56343 .62617 m .56468 .62704 L .563 .62699 L F
.692 .466 .575 r
.71371 .49117 m .71014 .49171 L .7112 .49283 L F
0 0 0 r
.75055 .52831 m .7486 .52968 L .74869 .52937 L F
.667 .653 .827 r
.46683 .69477 m .46799 .69654 L .46945 .69512 L F
.582 .923 .716 r
.52714 .76255 m .52856 .7612 L .52911 .76133 L F
.275 .59 .947 r
.53035 .76026 m .52911 .76133 L .52856 .7612 L F
.421 .257 .552 r
.53181 .7619 m .52929 .76401 L .52911 .76133 L F
.579 .774 .972 r
.38276 .59661 m .38355 .59828 L .38554 .5975 L F
.451 .133 .335 r
.5713 .5756 m .57366 .5751 L .57432 .57268 L F
.459 .153 .358 r
.57366 .5751 m .57666 .57212 L .57432 .57268 L F
.506 .418 .69 r
.28495 .61004 m .28664 .60628 L .28449 .60772 L F
.404 .058 .261 r
.29502 .5922 m .29782 .59017 L .2956 .59042 L F
.308 .389 .783 r
.73234 .5204 m .73257 .5225 L .73386 .52061 L F
.314 .397 .788 r
.73257 .5225 m .73492 .52383 L .73386 .52061 L F
0 0 .502 r
.57063 .66724 m .57069 .66613 L .56999 .66385 L F
.011 0 0 r
.26523 .81842 m .26704 .81769 L .26843 .81656 L F
.759 .984 .743 r
.29096 .6396 m .28895 .64176 L .28949 .64029 L F
.061 .287 .776 r
.28895 .64176 m .29113 .6436 L .28949 .64029 L F
.531 .414 .665 r
.529 .66684 m .52712 .66998 L .52662 .66822 L F
.529 .66684 m .52933 .66982 L .52712 .66998 L F
.4 .122 .373 r
.52933 .66982 m .52596 .67159 L .52712 .66998 L F
.486 .192 .391 r
.39172 .62162 m .39156 .62306 L .38937 .62314 L F
.527 .244 .428 r
.39399 .62124 m .39156 .62306 L .39172 .62162 L F
.839 .807 .819 r
.7268 .49829 m .7277 .50207 L .73014 .49832 L F
.356 .7 .984 r
.46797 .70002 m .47103 .70122 L .46863 .70088 L F
.268 .672 .968 r
.52837 .77778 m .52704 .77846 L .52571 .77835 L F
.592 .282 .413 r
.52967 .77885 m .52959 .77807 L .52704 .77846 L F
.52704 .77846 m .52959 .77807 L .52967 .77885 L F
.52967 .77885 m .52959 .77807 L .52704 .77846 L F
.268 .672 .968 r
.52837 .77778 m .52967 .77885 L .52704 .77846 L F
.52837 .77778 m .52704 .77846 L .52571 .77835 L F
.52837 .77778 m .52967 .77885 L .52704 .77846 L F
.143 .653 .9 r
.49069 .61816 m .49435 .61884 L .49213 .61865 L F
.7 .761 .899 r
.7163 .50175 m .71956 .50178 L .71839 .50087 L F
.743 .664 .773 r
.72206 .5015 m .71839 .50087 L .71956 .50178 L F
.674 .524 .673 r
.71956 .50178 m .7196 .50237 L .72206 .5015 L F
.7196 .50237 m .72051 .50259 L .72206 .5015 L F
.743 .664 .773 r
.72206 .5015 m .72065 .5027 L .72051 .50259 L F
.72206 .5015 m .72051 .50259 L .71839 .50087 L F
.803 .86 .891 r
.72126 .49808 m .72066 .50262 L .72322 .49806 L F
.72066 .50262 m .72065 .5027 L .72071 .50259 L F
.72066 .50262 m .72071 .50259 L .72322 .49806 L F
.674 .524 .673 r
.72051 .50259 m .72066 .50262 L .72206 .5015 L F
.72066 .50262 m .72106 .50272 L .72174 .50188 L F
.72066 .50262 m .72174 .50188 L .72206 .5015 L F
.574 .652 .889 r
.71839 .50087 m .72051 .50259 L .72126 .49808 L F
.72051 .50259 m .72065 .5027 L .72066 .50262 L F
.72051 .50259 m .72066 .50262 L .72126 .49808 L F
.674 .524 .673 r
.7196 .50237 m .71975 .50433 L .72106 .50272 L F
.768 .58 .644 r
.29239 .63443 m .29405 .63925 L .29662 .63554 L F
.52 .32 .549 r
.29561 .63789 m .298 .6348 L .29662 .63554 L F
.673 .609 .775 r
.30941 .63845 m .3126 .64063 L .31043 .63865 L F
.557 .624 .874 r
.3126 .64063 m .31307 .63744 L .31043 .63865 L F
.3126 .64063 m .31452 .64029 L .31307 .63744 L F
.438 .012 .131 r
.73357 .47506 m .73593 .47484 L .73685 .4732 L F
.597 .175 .212 r
.73685 .4732 m .73593 .47484 L .73944 .47467 L F
.544 .273 .455 r
.73685 .4732 m .73944 .47467 L .73952 .4728 L F
.493 .334 .594 r
.52694 .67482 m .52431 .67261 L .52596 .67159 L F
.4 .122 .373 r
.52933 .66982 m .52898 .67172 L .52596 .67159 L F
.412 .218 .505 r
.52898 .67172 m .52694 .67482 L .52596 .67159 L F
.471 .689 .962 r
.76753 .48402 m .76607 .48569 L .76511 .48401 L F
.76753 .48402 m .76905 .48571 L .76607 .48569 L F
.743 .895 .502 r
.27255 .81528 m .27061 .81854 L .27149 .81732 L F
.722 .363 .369 r
.27386 .81849 m .27061 .81854 L .27149 .81732 L F
.889 .898 .83 r
.31979 .64099 m .31949 .64449 L .3217 .64274 L F
.31979 .64099 m .31787 .64476 L .31949 .64449 L F
0 .136 .683 r
.45691 .69907 m .45581 .69902 L .45432 .69908 L F
.659 .103 0 r
.45851 .70075 m .45763 .70076 L .45926 .70123 L F
.45581 .69902 m .45763 .70076 L .45851 .70075 L F
0 .136 .683 r
.45691 .69907 m .45763 .70076 L .45581 .69902 L F
.999 .798 .478 r
.45691 .69907 m .45673 .70077 L .45763 .70076 L F
.45673 .70077 m .45652 .70271 L .45763 .70076 L F
.644 .436 .587 r
.66383 .48993 m .65967 .49066 L .65996 .48992 L F
.66383 .48993 m .6636 .49272 L .65967 .49066 L F
.771 .621 .693 r
.6636 .49272 m .66006 .4946 L .65967 .49066 L F
.398 .563 .901 r
.39826 .59067 m .39721 .59234 L .39558 .5901 L F
.39826 .59067 m .39918 .5924 L .39721 .59234 L F
.606 .138 .116 r
.57554 .64951 m .57827 .65096 L .58031 .64946 L F
.87 .608 .54 r
.57827 .65096 m .58133 .64986 L .58031 .64946 L F
.776 .695 .773 r
.46177 .69791 m .45926 .70123 L .46212 .69965 L F
.589 .31 .461 r
.45926 .70123 m .46149 .70327 L .46212 .69965 L F
.579 .177 .244 r
.46505 .69998 m .46212 .69965 L .46177 .69791 L F
.46505 .69998 m .46449 .70095 L .46212 .69965 L F
.545 .244 .408 r
.46379 .70288 m .46212 .69965 L .46149 .70327 L F
.46379 .70288 m .46449 .70095 L .46212 .69965 L F
.274 .211 .602 r
.42234 .6928 m .42406 .6947 L .42399 .69221 L F
.42234 .6928 m .42234 .69638 L .42406 .6947 L F
.494 .459 .747 r
.77446 .51299 m .7752 .5148 L .7732 .51562 L F
.389 .001 .177 r
.38201 .61189 m .38541 .6095 L .38316 .60939 L F
.427 .059 .236 r
.44892 .66006 m .44734 .65885 L .44679 .66058 L F
.44892 .66006 m .44961 .65853 L .44734 .65885 L F
0 0 .304 r
.52714 .60162 m .52798 .60245 L .52897 .60059 L F
.52714 .60162 m .5273 .60383 L .52798 .60245 L F
.353 .714 .986 r
.37688 .59688 m .38089 .5978 L .37671 .59534 L F
.545 .795 .991 r
.37671 .59534 m .38089 .5978 L .38276 .59661 L F
.492 .207 .408 r
.38937 .62314 m .38827 .62672 L .38593 .62709 L F
.43 .148 .383 r
.39043 .62609 m .38937 .62314 L .39156 .62306 L F
.39043 .62609 m .38827 .62672 L .38937 .62314 L F
.61 .393 .563 r
.54298 .66145 m .54059 .66403 L .54017 .66089 L F
.54298 .66145 m .543 .66382 L .54059 .66403 L F
.621 .402 .564 r
.5455 .66318 m .543 .66382 L .54298 .66145 L F
.468 .187 .403 r
.41236 .60703 m .41192 .6089 L .40954 .60931 L F
.462 .118 .297 r
.41474 .60699 m .41192 .6089 L .41236 .60703 L F
.814 .669 .703 r
.61441 .56448 m .61419 .56686 L .61618 .56389 L F
0 0 .279 r
.61683 .61121 m .61533 .61476 L .6154 .61224 L F
.314 0 .138 r
.50193 .63616 m .50107 .63805 L .49767 .63845 L F
.272 0 .12 r
.50041 .63891 m .49767 .63845 L .50107 .63805 L F
.50041 .63891 m .49794 .63987 L .49767 .63845 L F
.606 .62 .839 r
.7746 .48681 m .77326 .49022 L .77214 .48719 L F
.7746 .48681 m .77575 .48968 L .77326 .49022 L F
.624 .462 .642 r
.77598 .49186 m .77326 .49022 L .77575 .48968 L F
.77598 .49186 m .77347 .49252 L .77326 .49022 L F
.323 .056 .345 r
.58715 .57743 m .58656 .58069 L .58445 .58095 L F
.46 .188 .414 r
.58896 .57848 m .58656 .58069 L .58715 .57743 L F
.388 .267 .592 r
.59525 .62969 m .59703 .62896 L .59509 .62716 L F
.569 .257 .4 r
.59703 .62896 m .5978 .62701 L .59509 .62716 L F
.388 .267 .592 r
.59525 .62969 m .59703 .62896 L .59509 .62716 L F
.875 .437 .127 r
.57831 .67738 m .57573 .67485 L .57631 .67538 L F
.727 .221 .026 r
.5797 .67735 m .57831 .67738 L .57631 .67538 L F
.411 .476 .817 r
.42345 .69758 m .42406 .6947 L .42234 .69638 L F
.42345 .69758 m .4253 .69777 L .42406 .6947 L F
.1 0 0 r
.56849 .57772 m .5713 .5756 L .56902 .57612 L F
0 0 .367 r
.57201 .64029 m .57297 .64301 L .57288 .64409 L F
0 0 .574 r
.57297 .64301 m .57438 .64621 L .57288 .64409 L F
.328 0 .047 r
.51438 .70713 m .51321 .70892 L .5108 .70934 L F
.606 .807 .393 r
.51518 .70706 m .51438 .70713 L .51662 .70712 L F
.391 .225 .534 r
.51325 .70735 m .5156 .70718 L .51559 .70706 L F
.39 .701 .983 r
.51662 .70712 m .51789 .70576 L .51735 .70596 L F
.391 .225 .534 r
.51342 .70709 m .51518 .70706 L .51547 .70395 L F
.51518 .70706 m .51558 .70686 L .51547 .70395 L F
.437 .26 .542 r
.51547 .70395 m .51558 .70686 L .51789 .70576 L F
.39 .701 .983 r
.51662 .70712 m .51735 .70596 L .51518 .70706 L F
.437 .26 .542 r
.51558 .70686 m .5156 .70718 L .51789 .70576 L F
.39 .701 .983 r
.51516 .70706 m .51735 .70596 L .51441 .70703 L F
.51518 .70706 m .51558 .70686 L .51516 .70706 L F
.51558 .70686 m .51735 .70596 L .51516 .70706 L F
.391 .225 .534 r
.51518 .70706 m .51559 .70706 L .51558 .70686 L F
.606 .807 .393 r
.5144 .70707 m .51438 .70713 L .51518 .70706 L F
.391 .225 .534 r
.51325 .70735 m .51559 .70706 L .51342 .70709 L F
.606 .807 .393 r
.51441 .70703 m .5144 .70707 L .51518 .70706 L F
.804 .867 .895 r
.51165 .70797 m .51321 .70892 L .51414 .70745 L F
.51165 .70797 m .51409 .70747 L .51325 .70735 L F
.51413 .70747 m .51427 .70727 L .51325 .70735 L F
.51165 .70797 m .51414 .70745 L .51441 .70703 L F
.51165 .70797 m .51413 .70747 L .51409 .70747 L F
.51413 .70747 m .5156 .70718 L .51427 .70727 L F
.606 .807 .393 r
.51439 .70711 m .51321 .70892 L .51438 .70713 L F
.51441 .70703 m .51414 .70745 L .51439 .70711 L F
.51414 .70745 m .51321 .70892 L .51439 .70711 L F
.351 .773 .976 r
.52929 .76401 m .52547 .76355 L .52611 .76524 L F
.824 .421 .285 r
.49849 .66398 m .5007 .66159 L .50224 .66428 L F
.887 .806 .764 r
.2453 .68692 m .24494 .68863 L .2435 .68827 L F
.905 .6 .457 r
.24494 .68863 m .24475 .69187 L .2435 .68827 L F
.335 .263 .626 r
.2453 .68692 m .24703 .68897 L .24494 .68863 L F
.358 .128 .422 r
.24548 .68872 m .2448 .69094 L .24494 .68863 L F
.2456 .68874 m .24525 .68971 L .24548 .68872 L F
.24525 .68971 m .2448 .69094 L .24548 .68872 L F
.81 .56 .56 r
.24525 .68971 m .24475 .69187 L .24572 .6901 L F
.2435 .68827 m .24475 .69187 L .24525 .68971 L F
.788 .575 .612 r
.2435 .68827 m .24525 .68971 L .2453 .68692 L F
.24525 .68971 m .24572 .6901 L .24556 .68887 L F
.24525 .68971 m .24556 .68887 L .2453 .68692 L F
0 0 .016 r
.24703 .68897 m .24475 .69187 L .24572 .6901 L F
.358 .128 .422 r
.24703 .68897 m .24475 .69187 L .2448 .69094 L F
.358 .269 .616 r
.24703 .68897 m .24572 .6901 L .24556 .68887 L F
.358 .128 .422 r
.24703 .68897 m .24556 .68887 L .2456 .68874 L F
.358 .269 .616 r
.24703 .68897 m .24556 .68887 L .2453 .68692 L F
.358 .128 .422 r
.24703 .68897 m .2448 .69094 L .24556 .68887 L F
.978 .679 .349 r
.52172 .66149 m .52185 .66399 L .52063 .66279 L F
0 0 .054 r
.52172 .66149 m .52303 .66093 L .52442 .65776 L F
.679 .418 .52 r
.52544 .66145 m .52185 .66399 L .52172 .66149 L F
.311 0 .159 r
.52063 .66279 m .52303 .66093 L .52172 .66149 L F
0 0 0 r
.75361 .52593 m .75329 .52631 L .75147 .52713 L F
.75329 .52631 m .75055 .52831 L .75147 .52713 L F
.486 0 0 r
.50631 .6244 m .50557 .62363 L .50344 .62177 L F
.50631 .6244 m .50741 .62474 L .50557 .62363 L F
.213 .439 .862 r
.53947 .63823 m .54248 .6402 L .54143 .64143 L F
.527 .333 .56 r
.54315 .64174 m .54143 .64143 L .54248 .6402 L F
.54315 .64174 m .5415 .64397 L .54143 .64143 L F
.54143 .64143 m .5415 .64397 L .54315 .64174 L F
.577 .495 .725 r
.77398 .50691 m .77018 .50427 L .77251 .50345 L F
.743 .588 .683 r
.58133 .64986 m .58546 .65021 L .58282 .64875 L F
.715 .446 .518 r
.58241 .65149 m .58546 .65021 L .58133 .64986 L F
.58241 .65149 m .585 .65233 L .58546 .65021 L F
.58546 .65021 m .585 .65233 L .58241 .65149 L F
.545 .642 .896 r
.58282 .64875 m .58546 .65021 L .58724 .64936 L F
.575 .41 .62 r
.585 .65233 m .58724 .64936 L .58546 .65021 L F
.545 .642 .896 r
.58724 .64936 m .58546 .65021 L .58282 .64875 L F
.575 .41 .62 r
.585 .65233 m .58724 .64936 L .58546 .65021 L F
.569 .726 .948 r
.3217 .64274 m .32438 .64448 L .32175 .64082 L F
.565 .861 .996 r
.32568 .64302 m .32438 .64448 L .32495 .64428 L F
0 0 .226 r
.5273 .60383 m .5278 .60734 L .52773 .60608 L F
0 .119 .625 r
.5278 .60734 m .52914 .60822 L .52773 .60608 L F
.601 .045 0 r
.53149 .61011 m .53026 .60947 L .5278 .60734 L F
0 .119 .625 r
.5278 .60734 m .53026 .60947 L .52914 .60822 L F
.438 .845 .662 r
.45406 .67617 m .45215 .67742 L .45157 .67798 L F
.757 .522 .577 r
.59986 .56081 m .60348 .55868 L .60131 .55863 L F
.59986 .56081 m .60345 .56108 L .60348 .55868 L F
.655 .739 .912 r
.2907 .62135 m .29351 .62147 L .2911 .62042 L F
.847 .613 .584 r
.29152 .62322 m .29351 .62147 L .2907 .62135 L F
.29152 .62322 m .29324 .6239 L .29351 .62147 L F
.508 .682 .944 r
.29351 .62147 m .29419 .62018 L .2911 .62042 L F
.29351 .62147 m .29521 .62087 L .29419 .62018 L F
.581 .37 .559 r
.29351 .62147 m .2958 .62332 L .29521 .62087 L F
.29351 .62147 m .29324 .6239 L .2958 .62332 L F
.774 .687 .767 r
.28279 .63187 m .28443 .63345 L .28685 .63238 L F
.167 0 0 r
.3116 .58465 m .31389 .58412 L .31489 .58322 L F
.185 0 0 r
.31489 .58322 m .31586 .5836 L .31708 .58247 L F
.441 .1 .29 r
.31389 .58412 m .31586 .5836 L .31489 .58322 L F
.57 .683 .917 r
.26704 .81769 m .26837 .81929 L .27061 .81854 L F
.393 .543 .886 r
.40129 .59205 m .40048 .59387 L .39918 .5924 L F
.40129 .59205 m .40293 .59479 L .40048 .59387 L F
0 0 0 r
.71598 .47568 m .71852 .47496 L .71883 .47477 L F
.71883 .47477 m .72097 .47363 L .72177 .47373 L F
.71883 .47477 m .71852 .47496 L .72097 .47363 L F
.423 .061 .243 r
.37564 .63289 m .37258 .63454 L .37328 .6332 L F
.152 0 0 r
.36249 .63798 m .36138 .6386 L .3592 .63887 L F
.165 0 0 r
.36456 .63749 m .36138 .6386 L .36249 .63798 L F
.439 .237 .508 r
.42834 .66715 m .43027 .66669 L .43072 .66392 L F
.497 .341 .6 r
.42834 .66715 m .43055 .66903 L .43027 .66669 L F
.42834 .66715 m .42841 .66964 L .43055 .66903 L F
0 0 .212 r
.61384 .61852 m .61322 .62055 L .61219 .6216 L F
.066 0 .345 r
.61219 .6216 m .61322 .62055 L .61195 .62382 L F
.804 .634 .67 r
.53473 .66628 m .53367 .66311 L .53482 .66422 L F
.677 .387 .474 r
.53482 .66422 m .53716 .66645 L .53473 .66628 L F
.643 .394 .527 r
.53732 .66421 m .53716 .66645 L .53482 .66422 L F
.608 .526 .736 r
.59424 .63508 m .5929 .63254 L .59327 .63566 L F
.263 .073 .424 r
.59316 .63737 m .59424 .63508 L .59327 .63566 L F
.844 .598 .566 r
.74348 .47303 m .74312 .47538 L .74602 .47603 L F
.819 .728 .765 r
.74312 .47538 m .74412 .47897 L .74602 .47603 L F
.748 .689 .795 r
.74051 .47823 m .74412 .47897 L .74312 .47538 L F
.925 .936 .792 r
.74602 .47603 m .74327 .47798 L .74446 .47623 L F
.74602 .47603 m .74515 .47739 L .74489 .47683 L F
0 .438 .811 r
.74602 .47603 m .74911 .47709 L .75069 .47801 L F
.327 .622 .957 r
.74703 .47522 m .74781 .47653 L .74463 .47625 L F
.121 .626 .9 r
.74446 .47623 m .74911 .47709 L .74602 .47603 L F
.327 .622 .957 r
.7446 .47618 m .74463 .47625 L .74446 .47623 L F
.74703 .47522 m .74463 .47625 L .7446 .47618 L F
.925 .936 .792 r
.74489 .47683 m .74412 .47897 L .74327 .47798 L F
.74515 .47739 m .74412 .47897 L .74489 .47683 L F
.738 .461 .509 r
.59795 .5606 m .60131 .55863 L .59769 .55882 L F
.59795 .5606 m .59986 .56081 L .60131 .55863 L F
.656 .494 .652 r
.68 .48354 m .68192 .48142 L .67902 .4814 L F
.667 .374 .467 r
.47185 .66087 m .46782 .66392 L .46858 .66456 L F
.47185 .66087 m .47211 .66432 L .46782 .66392 L F
.47211 .66432 m .47168 .66465 L .46782 .66392 L F
0 0 .237 r
.47247 .6625 m .47214 .66474 L .47194 .6621 L F
.47247 .6625 m .47194 .6621 L .47185 .66087 L F
.637 .778 .949 r
.47169 .66608 m .46976 .66709 L .46858 .66456 L F
.333 0 0 r
.47024 .66543 m .47169 .66608 L .46858 .66456 L F
.542 .601 .862 r
.47247 .6625 m .47207 .66435 L .4717 .66456 L F
.595 .635 .861 r
.46782 .66392 m .46909 .66416 L .46926 .66043 L F
.46909 .66416 m .47168 .66465 L .47091 .6633 L F
.46909 .66416 m .47091 .6633 L .46926 .66043 L F
.542 .601 .862 r
.47247 .6625 m .4717 .66456 L .47179 .66422 L F
.663 .662 .839 r
.4694 .66052 m .47179 .66422 L .47247 .6625 L F
.46926 .66043 m .46934 .66055 L .4694 .66052 L F
.46934 .66055 m .47179 .66422 L .4694 .66052 L F
0 0 .148 r
.47508 .65797 m .47475 .65969 L .47374 .6603 L F
.47536 .65748 m .47475 .65969 L .47508 .65797 L F
0 0 .237 r
.47247 .6625 m .47185 .66087 L .47374 .6603 L F
.748 .641 .742 r
.47475 .65969 m .47247 .6625 L .47374 .6603 L F
.47475 .65969 m .47632 .66284 L .47247 .6625 L F
.511 .496 .776 r
.47114 .6592 m .47439 .66152 L .47475 .65969 L F
.47439 .66152 m .47451 .66161 L .47475 .65969 L F
.528 .776 .988 r
.47114 .6592 m .47121 .65921 L .47338 .65855 L F
.47121 .65921 m .47475 .65969 L .47338 .65855 L F
.092 .242 .727 r
.47536 .65748 m .47325 .65531 L .47536 .65516 L F
.312 .138 .476 r
.47676 .65649 m .47536 .65748 L .47536 .65516 L F
.232 .012 .36 r
.47676 .65649 m .47475 .65969 L .47536 .65748 L F
.886 .846 .799 r
.47338 .65855 m .47475 .65969 L .47676 .65649 L F
.021 .057 .558 r
.47537 .65795 m .47338 .65855 L .47542 .65776 L F
.442 .718 .983 r
.47701 .66142 m .47632 .66284 L .47475 .65969 L F
.54 .254 .43 r
.47451 .66161 m .47701 .66142 L .47475 .65969 L F
.021 .057 .558 r
.47473 .66035 m .47338 .65855 L .47537 .65795 L F
.773 .591 .653 r
.47338 .65855 m .47309 .6588 L .47114 .6592 L F
.663 .662 .839 r
.46926 .66043 m .47247 .6625 L .47114 .6592 L F
.511 .496 .776 r
.47114 .6592 m .47247 .6625 L .47451 .66161 L F
.773 .591 .653 r
.47309 .6588 m .47006 .66134 L .47081 .65986 L F
.47309 .6588 m .47081 .65986 L .47114 .6592 L F
.542 .601 .862 r
.47247 .6625 m .47179 .66422 L .47214 .66293 L F
.663 .662 .839 r
.47179 .66422 m .47214 .66474 L .47247 .6625 L F
.595 .635 .861 r
.47168 .66465 m .47179 .66422 L .47146 .66372 L F
.47127 .66394 m .47146 .66372 L .46926 .66043 L F
.47168 .66465 m .47146 .66372 L .47127 .66394 L F
.542 .601 .862 r
.47214 .66293 m .4717 .66456 L .47105 .66495 L F
.47089 .66457 m .47105 .66495 L .47024 .66543 L F
.47214 .66293 m .47105 .66495 L .47089 .66457 L F
.595 .635 .861 r
.46782 .66392 m .46926 .66043 L .46679 .66257 L F
.396 .394 .74 r
.47059 .66385 m .46782 .66392 L .46679 .66257 L F
.47139 .66412 m .47069 .66408 L .47059 .66385 L F
.47069 .66408 m .46782 .66392 L .47059 .66385 L F
0 0 0 r
.47233 .66271 m .47024 .66543 L .47139 .66412 L F
.47247 .6625 m .47214 .66293 L .47233 .66271 L F
.47214 .66293 m .47024 .66543 L .47233 .66271 L F
.689 .552 .695 r
.47203 .66634 m .47502 .66662 L .47293 .66702 L F
.47169 .66608 m .47246 .66621 L .47203 .66634 L F
.47246 .66621 m .47502 .66662 L .47203 .66634 L F
.47422 .66742 m .47426 .66745 L .47502 .66662 L F
.702 .537 .662 r
.47502 .66662 m .47441 .66738 L .47429 .66735 L F
.47502 .66662 m .47429 .66735 L .47293 .66702 L F
.689 .552 .695 r
.47169 .66608 m .47422 .66742 L .47502 .66662 L F
.542 .601 .862 r
.47247 .6625 m .47425 .66742 L .47169 .66608 L F
.47425 .66742 m .47426 .66745 L .47422 .66742 L F
.47425 .66742 m .47422 .66742 L .47169 .66608 L F
.702 .537 .662 r
.47441 .66738 m .4744 .6674 L .47436 .66739 L F
.47441 .66738 m .47436 .66739 L .47293 .66702 L F
.489 .568 .862 r
.47429 .66741 m .47426 .66745 L .47425 .66742 L F
.702 .537 .662 r
.4744 .6674 m .47298 .66916 L .47294 .66758 L F
.4744 .6674 m .47294 .66758 L .47293 .66702 L F
.489 .568 .862 r
.47608 .66535 m .47429 .66741 L .47368 .66584 L F
.47429 .66741 m .47425 .66742 L .47368 .66584 L F
.47588 .66519 m .47368 .66584 L .47247 .6625 L F
.47608 .66535 m .47368 .66584 L .47588 .66519 L F
0 0 0 r
.47247 .6625 m .47139 .66412 L .4712 .66394 L F
.229 0 .007 r
.4712 .66394 m .47284 .66278 L .47253 .66254 L F
.47236 .66262 m .47253 .66254 L .47247 .6625 L F
.4712 .66394 m .47253 .66254 L .47236 .66262 L F
.542 .601 .862 r
.47207 .66435 m .47169 .66608 L .47051 .66555 L F
.667 .374 .467 r
.47211 .66432 m .47214 .66474 L .47168 .66465 L F
.595 .635 .861 r
.47168 .66465 m .47214 .66474 L .47179 .66422 L F
.489 .568 .862 r
.47608 .66535 m .47247 .6625 L .47632 .66284 L F
.229 0 .007 r
.47374 .66215 m .47451 .66161 L .47316 .66219 L F
.021 .057 .558 r
.47412 .66231 m .47402 .66265 L .47395 .66224 L F
.773 .591 .653 r
.47338 .65855 m .47395 .66224 L .47006 .66134 L F
.47395 .66224 m .47402 .66265 L .47357 .6625 L F
.085 0 0 r
.47402 .66265 m .4712 .66394 L .47357 .6625 L F
.47402 .66265 m .47364 .66327 L .4712 .66394 L F
.743 .632 .736 r
.47412 .66231 m .47364 .66327 L .47402 .66265 L F
.229 0 .007 r
.4712 .66394 m .47411 .66233 L .47398 .66225 L F
.47411 .66233 m .47412 .66231 L .47398 .66225 L F
.47374 .66215 m .47414 .66231 L .47451 .66161 L F
.021 .057 .558 r
.47418 .66212 m .47412 .66231 L .47394 .66213 L F
.47473 .66035 m .47418 .66212 L .47338 .65855 L F
.743 .632 .736 r
.47473 .66035 m .47364 .66327 L .47412 .66231 L F
.229 0 .007 r
.47411 .66233 m .47414 .66231 L .47412 .66231 L F
.4712 .66394 m .47398 .66225 L .47374 .66215 L F
.47284 .66278 m .47374 .66215 L .47247 .6625 L F
.085 0 0 r
.47357 .6625 m .4712 .66394 L .47006 .66134 L F
.229 0 .007 r
.47374 .66215 m .47316 .66219 L .47247 .6625 L F
.773 .591 .653 r
.47395 .66224 m .47357 .6625 L .47006 .66134 L F
.229 0 .007 r
.4725 .66322 m .47364 .66327 L .47414 .66231 L F
.4712 .66394 m .47159 .66383 L .4725 .66322 L F
.47159 .66383 m .47364 .66327 L .4725 .66322 L F
.021 .057 .558 r
.47412 .66231 m .47395 .66224 L .47394 .66213 L F
.47418 .66212 m .47394 .66213 L .47338 .65855 L F
.542 .601 .862 r
.47207 .66435 m .47051 .66555 L .47024 .66543 L F
.582 .923 .716 r
.52714 .76255 m .52547 .76355 L .52856 .7612 L F
.475 .181 .387 r
.45178 .65788 m .45486 .65468 L .45258 .6551 L F
.602 .421 .609 r
.59452 .55853 m .59795 .5606 L .59769 .55882 L F
.496 .335 .591 r
.42422 .67803 m .42632 .67505 L .42438 .67566 L F
0 0 0 r
.35382 .59836 m .35256 .59866 L .35026 .59893 L F
.35607 .5979 m .35256 .59866 L .35382 .59836 L F
.655 .739 .912 r
.2907 .62135 m .2911 .62042 L .28929 .61875 L F
.847 .613 .584 r
.29152 .62322 m .2907 .62135 L .28989 .62181 L F
.832 .903 .889 r
.72322 .49806 m .72065 .5027 L .72206 .5015 L F
.654 .195 .15 r
.59533 .57617 m .5942 .57749 L .59202 .57592 L F
.782 .358 .243 r
.59626 .57764 m .5942 .57749 L .59533 .57617 L F
.461 .109 .281 r
.59202 .57592 m .58896 .57848 L .58975 .57566 L F
.319 0 0 r
.70897 .46948 m .71129 .47 L .71232 .46996 L F
.498 .014 .037 r
.71129 .47 m .71468 .46949 L .71232 .46996 L F
.282 0 .218 r
.37962 .63135 m .37872 .62969 L .38093 .62923 L F
.37962 .63135 m .37764 .63216 L .37872 .62969 L F
.426 .519 .85 r
.32706 .61952 m .32615 .6214 L .3248 .61808 L F
.32706 .61952 m .32821 .62155 L .32615 .6214 L F
.486 .133 .293 r
.52544 .66145 m .5243 .6639 L .52185 .66399 L F
.219 .349 .783 r
.52649 .66028 m .52774 .66356 L .52544 .66145 L F
.419 0 0 r
.52774 .66356 m .5243 .6639 L .52544 .66145 L F
.831 .633 .636 r
.46858 .66456 m .46976 .66709 L .46575 .66628 L F
0 0 0 r
.46976 .66709 m .46909 .6698 L .46912 .67004 L F
.46976 .66709 m .46912 .67004 L .46575 .66628 L F
.637 .778 .949 r
.47169 .66608 m .47293 .66702 L .46976 .66709 L F
.463 .448 .756 r
.47298 .66916 m .46976 .66709 L .47293 .66702 L F
.543 .796 .992 r
.67899 .50805 m .68003 .50636 L .67775 .50675 L F
.67899 .50805 m .68141 .50758 L .68003 .50636 L F
.774 .755 .836 r
.49855 .79007 m .49676 .79242 L .50054 .79192 L F
.564 .381 .591 r
.49794 .79571 m .50054 .79192 L .49676 .79242 L F
.49794 .79571 m .50035 .79525 L .50054 .79192 L F
.376 .492 .849 r
.50054 .79192 m .50096 .78966 L .49855 .79007 L F
.50054 .79192 m .50239 .79249 L .50096 .78966 L F
.993 .75 .45 r
.50625 .7925 m .50615 .79514 L .50522 .79283 L F
.326 .248 .614 r
.50764 .78857 m .50625 .7925 L .50518 .78904 L F
.50764 .78857 m .50787 .79203 L .50625 .7925 L F
.286 .135 .493 r
.50787 .79203 m .50615 .79514 L .50625 .7925 L F
.455 .25 .511 r
.48939 .66582 m .49004 .66909 L .48774 .66895 L F
0 0 .063 r
.49095 .66577 m .49004 .66909 L .48939 .66582 L F
.49078 .66754 m .49004 .66909 L .49095 .66577 L F
.708 .547 .669 r
.48774 .66895 m .4845 .66986 L .48458 .66694 L F
.775 .569 .62 r
.48774 .66895 m .48447 .67194 L .4845 .66986 L F
.48774 .66895 m .48663 .67255 L .48447 .67194 L F
.531 .316 .533 r
.49024 .67121 m .48774 .66895 L .49004 .66909 L F
.49024 .67121 m .48663 .67255 L .48774 .66895 L F
0 0 .037 r
.49048 .66848 m .49052 .66878 L .49163 .66574 L F
0 0 .063 r
.49163 .66574 m .49052 .66878 L .49032 .66891 L F
.49078 .66754 m .49032 .66891 L .49004 .66909 L F
.49163 .66574 m .49046 .6685 L .49078 .66754 L F
.49163 .66574 m .49078 .66754 L .49095 .66577 L F
0 .291 .691 r
.49006 .6648 m .49163 .66574 L .49021 .66503 L F
.49006 .6648 m .49021 .66503 L .48856 .6642 L F
.234 .356 .783 r
.49103 .66289 m .49006 .6648 L .48865 .66147 L F
.719 .902 .531 r
.4899 .66457 m .49006 .6648 L .49103 .66289 L F
0 0 .037 r
.49048 .66848 m .49006 .6648 L .48778 .66521 L F
0 .291 .691 r
.49006 .6648 m .48856 .6642 L .48778 .66521 L F
.922 .935 .572 r
.48963 .66451 m .49006 .6648 L .4887 .66635 L F
.719 .902 .531 r
.4887 .66635 m .49006 .6648 L .4899 .66457 L F
0 0 .037 r
.49048 .66846 m .49163 .66574 L .49006 .6648 L F
.49048 .66848 m .49163 .66574 L .49048 .66846 L F
0 0 .063 r
.49163 .66574 m .49032 .66891 L .49046 .6685 L F
.793 .627 .676 r
.49051 .67029 m .49109 .67056 L .49063 .66901 L F
.49051 .67029 m .49063 .66901 L .49048 .66848 L F
0 0 .447 r
.49109 .67056 m .49052 .66878 L .49048 .66848 L F
.49109 .67056 m .49134 .67043 L .49052 .66878 L F
.376 .727 .989 r
.49134 .67043 m .49047 .66953 L .49052 .66878 L F
.49047 .66953 m .49004 .66909 L .49032 .66891 L F
.793 .627 .676 r
.49046 .66848 m .49049 .6696 L .49048 .66848 L F
.49049 .6696 m .4905 .66962 L .49048 .66848 L F
.49044 .66855 m .49051 .67029 L .49046 .66848 L F
.376 .727 .989 r
.49043 .66949 m .49024 .67121 L .49004 .66909 L F
.49047 .66953 m .49045 .66973 L .49043 .66949 L F
.49045 .66973 m .49024 .67121 L .49043 .66949 L F
.728 .356 .345 r
.48663 .67255 m .48687 .67418 L .48464 .67414 L F
.605 .376 .543 r
.49024 .67121 m .48687 .67418 L .48663 .67255 L F
.49024 .67121 m .48997 .67392 L .48687 .67418 L F
.376 .727 .989 r
.49134 .67043 m .49278 .67147 L .4907 .67125 L F
.229 0 0 r
.49109 .67056 m .49097 .67091 L .49134 .67043 L F
.497 .283 .519 r
.49224 .67301 m .49024 .67121 L .49278 .67147 L F
.49224 .67301 m .48997 .67392 L .49024 .67121 L F
.229 0 0 r
.49097 .67091 m .4882 .6733 L .49034 .67268 L F
.49109 .67056 m .49069 .67095 L .49097 .67091 L F
.376 .727 .989 r
.49059 .67096 m .4907 .67125 L .49024 .67121 L F
.49097 .67091 m .4907 .67125 L .49059 .67096 L F
.229 0 0 r
.49069 .67095 m .4882 .6733 L .49097 .67091 L F
.376 .727 .989 r
.49134 .67043 m .49097 .67091 L .49059 .67096 L F
.229 0 0 r
.49097 .67091 m .49034 .67268 L .49134 .67043 L F
.386 0 .079 r
.48537 .67362 m .4882 .6733 L .49065 .67098 L F
.49052 .67087 m .49065 .67098 L .49109 .67056 L F
.48537 .67362 m .49065 .67098 L .49052 .67087 L F
.376 .727 .989 r
.4905 .67029 m .49037 .67074 L .49047 .66953 L F
.49037 .67074 m .49024 .67121 L .49031 .67069 L F
.49037 .67074 m .49031 .67069 L .49047 .66953 L F
.49052 .67101 m .4905 .67102 L .4905 .67029 L F
.4905 .67102 m .49024 .67121 L .4905 .67029 L F
.793 .627 .676 r
.48567 .66804 m .48541 .67062 L .4905 .67057 L F
.4905 .67029 m .4905 .67057 L .49109 .67056 L F
.48567 .66804 m .4905 .67057 L .4905 .67029 L F
.728 .356 .345 r
.48663 .67255 m .48464 .67414 L .48447 .67194 L F
.386 0 .079 r
.48537 .67362 m .49052 .67087 L .48541 .67062 L F
.49052 .67087 m .49109 .67056 L .4905 .67057 L F
.49052 .67087 m .4905 .67057 L .48541 .67062 L F
.793 .627 .676 r
.48995 .67003 m .4905 .67029 L .49044 .66855 L F
.4905 .67029 m .49051 .67029 L .49044 .66855 L F
.49049 .6696 m .49051 .67029 L .4905 .66962 L F
.376 .727 .989 r
.49134 .67043 m .49052 .67101 L .49047 .66953 L F
.49047 .66953 m .49032 .66891 L .49052 .66878 L F
.793 .627 .676 r
.48567 .66804 m .48995 .67003 L .49046 .66848 L F
.686 .633 .791 r
.73941 .51518 m .73765 .51656 L .73628 .51294 L F
.233 0 .212 r
.2932 .59297 m .29241 .59475 L .29502 .5922 L F
.031 0 0 r
.21248 .56219 m .20932 .56303 L .2088 .56388 L F
.21248 .56219 m .21 .56294 L .20932 .56303 L F
.902 .966 .816 r
.21212 .56018 m .21248 .56219 L .21276 .5597 L F
.21212 .56018 m .21 .56294 L .21248 .56219 L F
.506 .418 .69 r
.28495 .61004 m .28686 .60951 L .28664 .60628 L F
.488 .36 .632 r
.28495 .61004 m .2871 .61199 L .28686 .60951 L F
.427 .357 .676 r
.28495 .61004 m .28545 .61249 L .2871 .61199 L F
.353 .714 .986 r
.37688 .59688 m .37671 .59534 L .37542 .59556 L F
.299 0 0 r
.31708 .58247 m .31586 .5836 L .31934 .58258 L F
.612 .427 .608 r
.77508 .50098 m .77634 .50454 L .77251 .50345 L F
.534 .412 .659 r
.77719 .498 m .77508 .50098 L .77469 .49825 L F
.77719 .498 m .77769 .50157 L .77508 .50098 L F
.641 .502 .677 r
.77769 .50157 m .77634 .50454 L .77508 .50098 L F
.82 .614 .624 r
.59893 .57863 m .5956 .58047 L .59626 .57764 L F
.59893 .57863 m .5987 .58118 L .5956 .58047 L F
.62 .36 .503 r
.49915 .70497 m .50138 .70821 L .50305 .70693 L F
.749 .677 .782 r
.77634 .50454 m .77398 .50691 L .77251 .50345 L F
.441 .77 .997 r
.74327 .47798 m .74412 .47897 L .74051 .47823 L F
.393 .369 .714 r
.47906 .70056 m .47796 .70441 L .47742 .70319 L F
.47906 .70056 m .47983 .70441 L .47796 .70441 L F
.368 .819 .94 r
.53508 .76133 m .53444 .76091 L .53732 .76087 L F
.969 .906 .552 r
.53444 .76091 m .53508 .76133 L .53732 .76087 L F
.53444 .76091 m .53372 .76299 L .53508 .76133 L F
.782 .594 .645 r
.67523 .48993 m .67167 .49218 L .67167 .49003 L F
.67523 .48993 m .67498 .49266 L .67167 .49218 L F
.034 .604 .739 r
.35939 .59792 m .3583 .59788 L .35607 .5979 L F
.362 .832 .874 r
.36046 .59725 m .35939 .59792 L .36131 .5973 L F
.36046 .59725 m .3583 .59788 L .35939 .59792 L F
.185 .7 .889 r
.49435 .61884 m .49683 .61881 L .49791 .61915 L F
.101 .547 .912 r
.49936 .6188 m .49791 .61915 L .49683 .61881 L F
.49936 .6188 m .50054 .6198 L .49791 .61915 L F
.815 .891 .898 r
.5222 .67497 m .52353 .67266 L .52431 .67261 L F
.722 .512 .604 r
.52431 .67261 m .52445 .67574 L .5222 .67497 L F
.493 .334 .594 r
.52694 .67482 m .52445 .67574 L .52431 .67261 L F
.905 .686 .595 r
.52503 .67404 m .52431 .67261 L .52353 .67266 L F
.52503 .67404 m .52552 .67151 L .52431 .67261 L F
.542 .924 .811 r
.52431 .67261 m .52353 .67266 L .52552 .67151 L F
.659 .798 .949 r
.73485 .4932 m .73898 .4938 L .7374 .49212 L F
.871 .801 .778 r
.7374 .49212 m .73898 .4938 L .7394 .49219 L F
.399 .242 .55 r
.69765 .47001 m .69962 .46922 L .69953 .46693 L F
.684 .51 .645 r
.69765 .47001 m .70065 .47258 L .69962 .46922 L F
.69765 .47001 m .69788 .47301 L .70065 .47258 L F
.264 .307 .72 r
.30941 .63845 m .30967 .63435 L .30741 .63492 L F
.30941 .63845 m .31109 .63837 L .30967 .63435 L F
.673 .609 .775 r
.30941 .63845 m .31043 .63865 L .31109 .63837 L F
.268 0 .117 r
.50282 .63737 m .50107 .63805 L .50193 .63616 L F
.894 .776 .723 r
.66443 .50489 m .66184 .50603 L .66426 .50246 L F
.66443 .50489 m .66353 .50698 L .66184 .50603 L F
.578 .51 .743 r
.42284 .68403 m .42439 .68035 L .42229 .68168 L F
.193 .16 .59 r
.49398 .66143 m .4965 .6623 L .49651 .66062 L F
.49398 .66143 m .49485 .66361 L .4965 .6623 L F
.659 .121 0 r
.48241 .6703 m .48447 .67194 L .48142 .67117 L F
.551 .282 .461 r
.4845 .66986 m .48447 .67194 L .48241 .6703 L F
.576 .533 .771 r
.57998 .66036 m .57926 .66421 L .57806 .66103 L F
.57998 .66036 m .58159 .66375 L .57926 .66421 L F
.891 .961 .834 r
.3325 .64757 m .33246 .65 L .33463 .64733 L F
.37 .663 .971 r
.3297 .64751 m .33254 .64861 L .32749 .64603 L F
.331 .646 .967 r
.32609 .64617 m .3297 .64751 L .32749 .64603 L F
.538 .608 .871 r
.32868 .64964 m .32749 .64603 L .33254 .64861 L F
.814 .918 .907 r
.33093 .64942 m .33246 .65 L .3325 .64757 L F
.158 .016 .425 r
.44557 .68493 m .44381 .68414 L .44594 .68314 L F
.44557 .68493 m .4436 .6869 L .44381 .68414 L F
.832 .903 .889 r
.72322 .49806 m .72206 .5015 L .72358 .49823 L F
.547 .327 .533 r
.57123 .58926 m .5688 .59176 L .56912 .59014 L F
.701 .318 .318 r
.47983 .70441 m .48258 .70594 L .48391 .70386 L F
.693 .307 .313 r
.48391 .70386 m .48258 .70594 L .48638 .70613 L F
.486 .865 .98 r
.52742 .63559 m .53088 .63545 L .52871 .63635 L F
0 .106 .642 r
.29168 .63973 m .29338 .64224 L .29096 .6396 L F
.29168 .63973 m .29096 .6396 L .28949 .64029 L F
.24 .065 .432 r
.43072 .66392 m .43191 .66491 L .43302 .66365 L F
.43072 .66392 m .43027 .66669 L .43191 .66491 L F
.629 .435 .601 r
.59203 .56142 m .5961 .56279 L .59452 .55853 L F
.602 .421 .609 r
.59452 .55853 m .5961 .56279 L .59795 .5606 L F
.863 .743 .729 r
.53091 .65609 m .52962 .65823 L .52883 .65505 L F
.649 .88 .983 r
.41816 .59902 m .41639 .60016 L .41423 .59888 L F
.306 0 0 r
.59649 .646 m .59635 .64682 L .59351 .64693 L F
.513 0 0 r
.5375 .70004 m .54108 .70024 L .53925 .69911 L F
.47 .158 .354 r
.40954 .60931 m .40882 .61187 L .40654 .61226 L F
.473 .17 .37 r
.41192 .6089 m .40882 .61187 L .40954 .60931 L F
.831 .633 .636 r
.46858 .66456 m .46575 .66628 L .46782 .66392 L F
.333 0 0 r
.47024 .66543 m .46858 .66456 L .46782 .66392 L F
.953 .683 .488 r
.60344 .59565 m .60175 .59712 L .60297 .59414 L F
.60344 .59565 m .60328 .59801 L .60175 .59712 L F
.401 .147 .411 r
.53182 .77801 m .52959 .77807 L .52967 .77885 L F
.52967 .77885 m .52959 .77807 L .53182 .77801 L F
.558 .463 .703 r
.51685 .65479 m .51337 .65285 L .51694 .65254 L F
.51685 .65479 m .51454 .6553 L .51337 .65285 L F
.814 .911 .906 r
.7166 .49029 m .71947 .4895 L .71851 .48871 L F
.882 .934 .849 r
.72098 .48582 m .71947 .4895 L .72189 .48702 L F
.72098 .48582 m .71851 .48871 L .71947 .4895 L F
.477 .265 .512 r
.5365 .70606 m .53445 .70413 L .53659 .70383 L F
.5365 .70606 m .53411 .70684 L .53445 .70413 L F
.927 .674 .189 r
.60257 .60999 m .60278 .61247 L .60202 .60897 L F
.73 .713 .834 r
.50806 .79446 m .51088 .79624 L .50783 .79544 L F
.707 .716 .856 r
.51136 .79506 m .51088 .79624 L .50806 .79446 L F
0 0 .331 r
.44942 .6976 m .44935 .69898 L .44892 .69525 L F
.459 .305 .584 r
.45178 .69971 m .44935 .69898 L .44942 .6976 L F
.45178 .69971 m .44988 .7009 L .44935 .69898 L F
.658 .841 .97 r
.79491 .52107 m .79143 .52096 L .79396 .51993 L F
.662 .218 .187 r
.79491 .52107 m .79405 .52276 L .79143 .52096 L F
.325 .553 .917 r
.79617 .51982 m .79491 .52107 L .79396 .51993 L F
.79617 .51982 m .7966 .52211 L .79491 .52107 L F
0 0 0 r
.79617 .51982 m .79491 .52107 L .7966 .52211 L F
.79617 .51982 m .79405 .52276 L .79491 .52107 L F
.288 .059 .383 r
.42614 .68928 m .42448 .69002 L .42399 .69221 L F
.475 .472 .775 r
.42352 .68772 m .42448 .69002 L .42614 .68928 L F
.362 .636 .959 r
.44005 .70846 m .44046 .70913 L .44273 .70847 L F
.609 .944 .938 r
.54403 .65277 m .54509 .65145 L .54639 .65168 L F
.54639 .65168 m .54509 .65145 L .54403 .65277 L F
.088 0 0 r
.7564 .51307 m .75729 .51315 L .75367 .51276 L F
.071 .634 .734 r
.75879 .513 m .75729 .51315 L .7564 .51307 L F
.75879 .513 m .75994 .51298 L .75729 .51315 L F
.201 .715 .885 r
.35572 .58572 m .35938 .58589 L .35713 .58611 L F
.851 .711 .708 r
.52002 .6784 m .5168 .67851 L .51856 .67506 L F
.82 .835 .86 r
.52002 .6784 m .5173 .68 L .51687 .67872 L F
.51731 .67849 m .51687 .67872 L .5168 .67851 L F
.52002 .6784 m .51687 .67872 L .51731 .67849 L F
.851 .711 .708 r
.52002 .6784 m .5194 .67697 L .51947 .67677 L F
0 0 .49 r
.52084 .67468 m .52002 .67661 L .51912 .67574 L F
.52084 .67468 m .51912 .67574 L .51856 .67506 L F
0 0 .495 r
.52001 .67662 m .52084 .67468 L .51856 .67506 L F
.52023 .67686 m .52084 .67468 L .52001 .67662 L F
0 0 .49 r
.52084 .67468 m .52035 .67693 L .52002 .67661 L F
.52013 .67692 m .52002 .6784 L .51952 .6769 L F
.795 .635 .684 r
.52001 .67662 m .52012 .67691 L .52023 .67686 L F
.661 .404 .52 r
.52017 .67692 m .52032 .67693 L .52023 .67686 L F
0 0 .49 r
.52035 .67693 m .51952 .6769 L .51912 .67574 L F
.851 .711 .708 r
.51947 .67677 m .51856 .67506 L .51912 .67574 L F
.5194 .67697 m .51856 .67506 L .51947 .67677 L F
.795 .635 .684 r
.51856 .67506 m .5168 .67851 L .52012 .67691 L F
.51856 .67506 m .52012 .67691 L .52001 .67662 L F
0 0 .49 r
.52035 .67693 m .52027 .6773 L .52013 .67692 L F
.52027 .6773 m .52002 .6784 L .52013 .67692 L F
.661 .404 .52 r
.51993 .67715 m .52034 .67695 L .52032 .67693 L F
.51993 .67715 m .52032 .67693 L .52017 .67692 L F
0 0 .49 r
.52084 .67468 m .52122 .67768 L .52002 .6784 L F
.661 .404 .52 r
.51744 .6796 m .52122 .67768 L .52034 .67695 L F
.51744 .6796 m .52034 .67695 L .51993 .67715 L F
.029 0 .392 r
.5168 .67851 m .51744 .6796 L .51902 .67805 L F
.51927 .67732 m .51902 .67805 L .52023 .67686 L F
.5168 .67851 m .51902 .67805 L .51927 .67732 L F
.671 .448 .574 r
.52002 .6784 m .51999 .68112 L .5173 .68 L F
0 0 .264 r
.52081 .67958 m .52002 .6784 L .52122 .67768 L F
.52081 .67958 m .51999 .68112 L .52002 .6784 L F
.529 .405 .655 r
.77398 .50691 m .77379 .50921 L .77149 .5095 L F
.083 .345 .817 r
.77392 .51158 m .77149 .5095 L .77379 .50921 L F
.123 0 0 r
.35938 .58589 m .36156 .58611 L .3631 .58615 L F
.166 .704 .811 r
.3631 .58615 m .36156 .58611 L .36518 .58592 L F
0 .211 .736 r
.53149 .61011 m .53301 .6106 L .53026 .60947 L F
.53149 .61011 m .53373 .61208 L .53301 .6106 L F
.519 .68 .939 r
.38649 .59868 m .38783 .597 L .38554 .5975 L F
.38649 .59868 m .38831 .59815 L .38783 .597 L F
.54 .464 .72 r
.54974 .66473 m .55374 .66395 L .55112 .66084 L F
.7 .871 .962 r
.67108 .49895 m .66747 .50072 L .66573 .49881 L F
.618 .956 .906 r
.33534 .64611 m .33463 .64733 L .33674 .64698 L F
.33534 .64611 m .3325 .64757 L .33463 .64733 L F
.729 .693 .816 r
.74175 .48398 m .74515 .48493 L .74419 .48345 L F
.471 .668 .949 r
.74515 .48493 m .74623 .48322 L .74419 .48345 L F
.74515 .48493 m .74703 .48477 L .74623 .48322 L F
.457 .526 .84 r
.74515 .48493 m .74836 .48588 L .74703 .48477 L F
.516 .078 .146 r
.35851 .62575 m .36087 .62591 L .3623 .62416 L F
.432 .224 .495 r
.36457 .62126 m .3623 .62416 L .36432 .62358 L F
.403 .008 .172 r
.36087 .62591 m .36432 .62358 L .3623 .62416 L F
.478 .233 .465 r
.33024 .60329 m .32766 .60625 L .32823 .60425 L F
.689 .626 .78 r
.41554 .70355 m .41843 .70413 L .41703 .70059 L F
.785 .442 0 r
.41703 .70059 m .41843 .70413 L .41783 .70299 L F
.572 .035 0 r
.41843 .70413 m .41928 .70523 L .41783 .70299 L F
.41843 .70413 m .42058 .70616 L .41928 .70523 L F
0 .495 .801 r
.34632 .58384 m .35006 .58499 L .34763 .58526 L F
.57 .574 .818 r
.76432 .50405 m .76555 .50022 L .76309 .50088 L F
.76432 .50405 m .76678 .50354 L .76555 .50022 L F
.547 .804 .993 r
.5111 .64547 m .51004 .64704 L .51241 .64666 L F
.729 .305 .241 r
.50883 .64879 m .51004 .64704 L .5111 .64547 L F
.951 .685 .496 r
.28764 .62241 m .286 .62301 L .28627 .62103 L F
.64 .738 .92 r
.28989 .62181 m .28764 .62241 L .28627 .62103 L F
.073 0 0 r
.48198 .64653 m .47918 .64885 L .48013 .64717 L F
0 0 0 r
.58741 .67487 m .58527 .67656 L .58384 .67708 L F
.144 0 0 r
.58953 .67423 m .58923 .67497 L .58741 .67487 L F
.139 0 0 r
.58923 .67497 m .58527 .67656 L .58741 .67487 L F
.689 .626 .78 r
.41554 .70355 m .41703 .70059 L .41491 .70196 L F
.915 .941 .807 r
.51889 .78892 m .52051 .7889 L .51873 .79157 L F
.2 .257 .698 r
.28856 .61537 m .28929 .61875 L .29054 .61729 L F
.32 .437 .824 r
.28929 .61875 m .2911 .62042 L .29054 .61729 L F
0 0 0 r
.34315 .64503 m .34289 .64462 L .34518 .64435 L F
.34315 .64503 m .34127 .64591 L .34289 .64462 L F
.878 .993 .759 r
.68632 .50343 m .68376 .5069 L .68459 .5068 L F
.735 .736 .851 r
.69825 .47537 m .69609 .47648 L .69452 .47427 L F
.843 .966 .882 r
.71591 .49563 m .71533 .49465 L .71663 .49534 L F
.817 .966 .902 r
.71663 .49534 m .71905 .49149 L .71993 .49257 L F
.71663 .49534 m .71533 .49465 L .71905 .49149 L F
.721 .206 0 r
.53999 .62139 m .53916 .62216 L .5383 .62113 L F
.465 0 0 r
.54245 .62287 m .53916 .62216 L .53999 .62139 L F
.435 .722 .986 r
.3848 .58695 m .38396 .58831 L .38265 .58709 L F
.3848 .58695 m .38661 .58823 L .38396 .58831 L F
.449 .147 .36 r
.58382 .56873 m .58202 .56753 L .5815 .56925 L F
.58382 .56873 m .58437 .567 L .58202 .56753 L F
.747 .397 .389 r
.55065 .66656 m .54904 .66856 L .54973 .66666 L F
.55065 .66656 m .55222 .66923 L .54904 .66856 L F
.659 .373 .475 r
.55362 .66629 m .55222 .66923 L .55065 .66656 L F
.053 0 0 r
.52214 .70645 m .5201 .7066 L .5225 .70659 L F
.52214 .70645 m .51948 .70727 L .5201 .7066 L F
.456 .266 .533 r
.28568 .6013 m .28759 .60083 L .2884 .59654 L F
.38 .018 .22 r
.2884 .59654 m .28963 .59696 L .29049 .59545 L F
.373 .192 .502 r
.2884 .59654 m .29037 .59849 L .28963 .59696 L F
.2884 .59654 m .28759 .60083 L .29037 .59849 L F
.434 .74 .992 r
.54245 .62287 m .54375 .62397 L .54472 .62273 L F
.24 .466 .876 r
.54375 .62397 m .5457 .62463 L .54472 .62273 L F
.297 0 .124 r
.56342 .58094 m .56557 .58032 L .56643 .57854 L F
.415 .079 .286 r
.56557 .58032 m .56849 .57772 L .56643 .57854 L F
.688 .406 .49 r
.55507 .66873 m .55362 .66629 L .55596 .66709 L F
.55507 .66873 m .55222 .66923 L .55362 .66629 L F
.584 .185 .252 r
.76451 .52127 m .7612 .52294 L .7621 .52147 L F
.618 .065 0 r
.4601 .70254 m .45926 .70123 L .45763 .70076 L F
.4601 .70254 m .46149 .70327 L .45926 .70123 L F
.651 .442 .588 r
.66584 .49214 m .66383 .48993 L .66594 .49015 L F
.691 .456 .562 r
.66948 .48971 m .66584 .49214 L .66594 .49015 L F
.506 .899 .943 r
.53519 .59865 m .53176 .59929 L .53397 .59901 L F
.297 .782 .711 r
.53793 .59757 m .53519 .59865 L .53397 .59901 L F
.652 .663 .848 r
.44892 .69525 m .44635 .69571 L .44498 .69284 L F
.321 .809 .84 r
.46613 .68074 m .46754 .68013 L .46763 .68101 L F
.22 .742 .782 r
.46284 .68131 m .46403 .68103 L .46613 .68074 L F
.46284 .68131 m .46403 .68103 L .46613 .68074 L F
.015 0 0 r
.46763 .68101 m .46403 .68103 L .46613 .68074 L F
.428 .071 .255 r
.46403 .68103 m .46596 .68105 L .46754 .68013 L F
.617 .957 .836 r
.46763 .68101 m .46754 .68013 L .46876 .67942 L F
0 0 .181 r
.4691 .67894 m .46893 .68107 L .46763 .68101 L F
.428 .071 .255 r
.46596 .68105 m .46893 .68107 L .46754 .68013 L F
.617 .957 .836 r
.46876 .67942 m .46754 .68013 L .4691 .67894 L F
.577 .327 .501 r
.37487 .61532 m .37731 .61505 L .37763 .61284 L F
.474 .224 .455 r
.37731 .61505 m .37988 .6124 L .37763 .61284 L F
.473 .135 .312 r
.45973 .65215 m .46211 .65183 L .46293 .64945 L F
.333 0 .211 r
.46211 .65183 m .46502 .64899 L .46293 .64945 L F
.314 0 .03 r
.30074 .58903 m .30286 .58868 L .30375 .58759 L F
.323 0 .063 r
.30286 .58868 m .30583 .58713 L .30375 .58759 L F
.921 .552 .302 r
.50051 .65497 m .50334 .65835 L .50204 .65526 L F
.50051 .65497 m .50204 .65822 L .50334 .65835 L F
.931 .577 .33 r
.50204 .65822 m .50183 .65968 L .50334 .65835 L F
.369 0 0 r
.50334 .65835 m .50183 .65968 L .50444 .65952 L F
.225 0 0 r
.58169 .67762 m .57831 .67738 L .5797 .67735 L F
.574 .682 .913 r
.69853 .48987 m .70193 .49143 L .70099 .4891 L F
.6 .653 .874 r
.70193 .49143 m .7034 .48858 L .70099 .4891 L F
.70193 .49143 m .70441 .49069 L .7034 .48858 L F
.486 .355 .627 r
.32495 .64428 m .32749 .64603 L .32568 .64302 L F
.331 .646 .967 r
.32609 .64617 m .32749 .64603 L .32516 .64675 L F
.486 .355 .627 r
.32495 .64428 m .32516 .64675 L .32749 .64603 L F
.318 .547 .915 r
.54899 .6269 m .55224 .63016 L .5526 .62934 L F
.788 .575 .612 r
.2435 .68827 m .2453 .68692 L .2414 .68659 L F
.505 .491 .776 r
.4446 .68945 m .4415 .68746 L .4436 .6869 L F
.839 .903 .883 r
.48704 .66477 m .48458 .66694 L .48349 .6659 L F
.303 .203 .572 r
.6072 .63198 m .60741 .63438 L .6053 .63583 L F
.289 .206 .585 r
.60741 .63438 m .60578 .63811 L .6053 .63583 L F
.333 .274 .64 r
.60585 .64053 m .60653 .64304 L .60438 .6446 L F
0 0 .447 r
.60653 .64304 m .60539 .64677 L .60438 .6446 L F
.302 0 .039 r
.60066 .6675 m .60217 .66795 L .60007 .66862 L F
.60066 .6675 m .60325 .66698 L .60217 .66795 L F
.942 .705 .549 r
.74174 .47193 m .74312 .47538 L .74348 .47303 L F
.753 .697 .799 r
.52244 .78674 m .52051 .7889 L .51898 .78649 L F
.275 0 0 r
.51889 .78892 m .52051 .7889 L .52157 .78919 L F
.248 .308 .728 r
.56688 .62866 m .56549 .63031 L .56468 .62704 L F
0 0 .35 r
.56688 .62866 m .56625 .63216 L .56549 .63031 L F
.662 .463 .605 r
.49651 .65503 m .50051 .65497 L .4996 .65243 L F
.75 .546 .62 r
.50051 .65497 m .50203 .65257 L .4996 .65243 L F
.973 .665 .354 r
.55135 .64638 m .55155 .64897 L .55299 .6497 L F
.68 .143 0 r
.55155 .64897 m .55482 .6516 L .55299 .6497 L F
.662 .521 .681 r
.5929 .63254 m .59525 .62969 L .59267 .63 L F
0 0 .293 r
.61536 .61717 m .61322 .62055 L .61384 .61852 L F
.374 0 .062 r
.66483 .48528 m .66826 .48374 L .66481 .48502 L F
.992 .776 .507 r
.48308 .6542 m .48432 .65525 L .48452 .65255 L F
.687 .253 .214 r
.48452 .65255 m .48308 .6542 L .48686 .65404 L F
.144 .654 .9 r
.30741 .63492 m .30358 .63416 L .30521 .63547 L F
.658 .658 .838 r
.75463 .48977 m .75586 .49287 L .75836 .49215 L F
.696 .173 0 r
.61821 .59465 m .61979 .59551 L .61867 .59478 L F
.61862 .59487 m .61943 .59578 L .61979 .59551 L F
.61881 .5952 m .61943 .59578 L .61862 .59487 L F
.109 0 .267 r
.61968 .59287 m .61918 .59584 L .61867 .59478 L F
.966 .861 .686 r
.6177 .60011 m .61943 .59578 L .61886 .59525 L F
.6177 .60011 m .61886 .59525 L .61881 .59522 L F
.109 0 .267 r
.61881 .5952 m .6188 .59522 L .61878 .59516 L F
.966 .861 .686 r
.61801 .59688 m .61874 .59535 L .61821 .59465 L F
.749 .255 .058 r
.6186 .59493 m .6188 .59522 L .61854 .59508 L F
.696 .173 0 r
.61849 .5948 m .61878 .59516 L .61862 .59487 L F
.749 .255 .058 r
.61867 .59478 m .61878 .59516 L .6186 .59493 L F
.61878 .59516 m .6188 .59522 L .6186 .59493 L F
.696 .173 0 r
.61821 .59465 m .61881 .5952 L .61878 .59516 L F
.61821 .59465 m .6186 .59493 L .61849 .5948 L F
.749 .255 .058 r
.61867 .59478 m .6186 .59493 L .61821 .59465 L F
.6186 .59493 m .61854 .59508 L .61821 .59465 L F
.696 .173 0 r
.61821 .59465 m .61878 .59516 L .6186 .59493 L F
.966 .861 .686 r
.61874 .59535 m .61881 .5952 L .61821 .59465 L F
.749 .255 .058 r
.61854 .59508 m .61818 .59596 L .61821 .59465 L F
.966 .861 .686 r
.6177 .60011 m .61881 .5952 L .61801 .59688 L F
.749 .255 .058 r
.61854 .59508 m .61911 .59623 L .61818 .59596 L F
.6188 .59522 m .61911 .59623 L .61854 .59508 L F
.966 .861 .686 r
.61881 .59522 m .61886 .59525 L .61881 .5952 L F
.109 0 .267 r
.61918 .59584 m .61911 .59623 L .6188 .59522 L F
.61918 .59584 m .6188 .59522 L .61881 .5952 L F
.61918 .59584 m .61878 .59516 L .61867 .59478 L F
.393 .577 .913 r
.5457 .62463 m .54725 .62691 L .54847 .62534 L F
.39 .573 .911 r
.54725 .62691 m .54899 .6269 L .54847 .62534 L F
.449 .317 .608 r
.49508 .77876 m .49503 .7822 L .49667 .78058 L F
.525 .457 .721 r
.42284 .68403 m .42352 .68772 L .42581 .68623 L F
.475 .472 .775 r
.42352 .68772 m .42614 .68928 L .42581 .68623 L F
.75 .546 .62 r
.50051 .65497 m .50204 .65526 L .50203 .65257 L F
.969 .65 .334 r
.72189 .48702 m .72103 .48842 L .72098 .48582 L F
.72189 .48702 m .72228 .48956 L .72103 .48842 L F
.329 0 .07 r
.58213 .58204 m .58159 .58309 L .57917 .58392 L F
.398 .007 .177 r
.58445 .58095 m .58159 .58309 L .58213 .58204 L F
.746 .663 .769 r
.65794 .49533 m .65892 .49829 L .65576 .49791 L F
.67 .227 .188 r
.65892 .49829 m .65781 .49977 L .65576 .49791 L F
.559 .546 .797 r
.66006 .4946 m .65892 .49829 L .65794 .49533 L F
.66006 .4946 m .66125 .49791 L .65892 .49829 L F
.6 .242 .334 r
.66125 .49791 m .65781 .49977 L .65892 .49829 L F
.461 .04 .153 r
.48852 .65476 m .48412 .65719 L .48432 .65525 L F
.48852 .65476 m .48657 .65705 L .48412 .65719 L F
0 0 0 r
.48907 .6552 m .48852 .65476 L .49006 .65528 L F
.727 .472 .542 r
.48866 .65522 m .4889 .65955 L .4868 .65851 L F
.4868 .65849 m .4868 .65851 L .48679 .65851 L F
.48866 .65522 m .4868 .65851 L .4868 .65849 L F
.48679 .65851 m .4889 .65955 L .48866 .65522 L F
.716 .464 .543 r
.49257 .65952 m .48866 .65522 L .4911 .65612 L F
.49257 .65952 m .4889 .65955 L .48866 .65522 L F
.654 .56 .737 r
.4889 .65955 m .4911 .65612 L .48866 .65522 L F
0 0 0 r
.48907 .6552 m .48657 .65705 L .48852 .65476 L F
.477 .242 .479 r
.48686 .65404 m .48657 .65705 L .48714 .65663 L F
.48754 .6544 m .48714 .65663 L .48907 .6552 L F
.48686 .65404 m .48714 .65663 L .48754 .6544 L F
.674 .866 .972 r
.67213 .50711 m .67313 .50799 L .67535 .50706 L F
.653 .771 .935 r
.5343 .63593 m .53088 .63545 L .53317 .63501 L F
.691 .244 .184 r
.53317 .63501 m .53658 .63556 L .5343 .63593 L F
.711 .397 .445 r
.6071 .5613 m .60963 .56315 L .61084 .5613 L F
.787 .537 .559 r
.60963 .56315 m .61089 .56394 L .61084 .5613 L F
.49 .218 .428 r
.39665 .61881 m .39626 .62087 L .39399 .62124 L F
.441 .154 .379 r
.39902 .61796 m .39626 .62087 L .39665 .61881 L F
.749 .965 .682 r
.56583 .59462 m .5655 .59461 L .56544 .59532 L F
.998 .809 .526 r
.56391 .59684 m .56544 .59532 L .5655 .59461 L F
.56391 .59684 m .56502 .59836 L .56544 .59532 L F
.014 .585 .768 r
.50224 .66428 m .50064 .6641 L .49849 .66398 L F
.104 .564 .913 r
.50224 .66428 m .50306 .66392 L .50064 .6641 L F
.50224 .66428 m .50525 .66448 L .50306 .66392 L F
.438 .136 .354 r
.28963 .59696 m .29241 .59475 L .29049 .59545 L F
.707 .467 .559 r
.67167 .49218 m .66948 .48971 L .67167 .49003 L F
.979 .726 .481 r
.72712 .51037 m .7258 .51198 L .72636 .50808 L F
.72712 .51037 m .72697 .51229 L .7258 .51198 L F
.307 .125 .462 r
.7294 .50873 m .72697 .51229 L .72712 .51037 L F
.7294 .50873 m .72697 .51229 L .72712 .51037 L F
.494 .238 .455 r
.36432 .62358 m .36694 .62096 L .36457 .62126 L F
.456 .415 .723 r
.60399 .65649 m .60695 .66054 L .60465 .65911 L F
.651 .442 .588 r
.66584 .49214 m .6636 .49272 L .66383 .48993 L F
.029 0 0 r
.35074 .62735 m .35283 .62684 L .35384 .62629 L F
.223 0 0 r
.35384 .62629 m .35283 .62684 L .35616 .62605 L F
.639 .342 .45 r
.52442 .65776 m .52303 .66093 L .52649 .66028 L F
.374 0 .062 r
.66483 .48528 m .66717 .48528 L .66826 .48374 L F
.769 .494 .517 r
.66717 .48528 m .67042 .48385 L .66826 .48374 L F
.688 .433 .532 r
.541 .66587 m .53732 .66421 L .54059 .66403 L F
.541 .66587 m .53716 .66645 L .53732 .66421 L F
0 .47 .86 r
.2111 .55726 m .21238 .5576 L .21347 .55847 L F
.985 .758 .512 r
.21238 .5576 m .21276 .5597 L .21347 .55847 L F
.407 .075 .287 r
.44679 .66058 m .44459 .66105 L .44378 .66334 L F
.578 .51 .743 r
.42284 .68403 m .42515 .68359 L .42439 .68035 L F
.525 .457 .721 r
.42284 .68403 m .42581 .68623 L .42515 .68359 L F
.322 0 .101 r
.38593 .62709 m .38295 .62878 L .3836 .62741 L F
.147 .469 .892 r
.51517 .63086 m .51668 .63129 L .51588 .63211 L F
.182 .524 .919 r
.51668 .63129 m .51789 .63277 L .51588 .63211 L F
.502 .232 .438 r
.40429 .61268 m .40378 .61479 L .40157 .61517 L F
.397 .1 .339 r
.40654 .61226 m .40378 .61479 L .40429 .61268 L F
.499 .301 .543 r
.32562 .60695 m .32539 .60915 L .32335 .60967 L F
.423 .129 .359 r
.32539 .60915 m .32285 .61144 L .32335 .60967 L F
.839 .807 .819 r
.7268 .49829 m .73014 .49832 L .72909 .49715 L F
.749 .869 .935 r
.72909 .49715 m .73014 .49832 L .73324 .49636 L F
.653 .458 .608 r
.543 .66382 m .541 .66587 L .54059 .66403 L F
.583 .335 .506 r
.38541 .6095 m .38781 .60935 L .38809 .60706 L F
.518 .301 .523 r
.38781 .60935 m .39036 .60645 L .38809 .60706 L F
.839 .903 .883 r
.48704 .66477 m .48349 .6659 L .4867 .66548 L F
0 0 0 r
.4867 .66548 m .48856 .6642 L .48704 .66477 L F
.461 .728 .984 r
.39418 .58883 m .3934 .59025 L .39214 .58886 L F
.39418 .58883 m .39558 .5901 L .3934 .59025 L F
.117 .093 .552 r
.60539 .64677 m .60663 .64868 L .60521 .64936 L F
.174 .094 .519 r
.60663 .64868 m .60578 .65173 L .60521 .64936 L F
0 0 0 r
.34477 .59913 m .34063 .59998 L .34199 .60033 L F
.824 .752 .784 r
.66353 .50698 m .65963 .50846 L .66184 .50603 L F
.66353 .50698 m .66137 .5099 L .65963 .50846 L F
.061 .531 .895 r
.51376 .62967 m .51209 .62992 L .51099 .62858 L F
.51376 .62967 m .51517 .63086 L .51209 .62992 L F
.459 0 0 r
.50376 .75738 m .50334 .75786 L .50705 .75809 L F
.534 .544 .812 r
.28545 .61249 m .28856 .61537 L .2871 .61199 L F
.165 .048 .463 r
.60159 .61853 m .6035 .61729 L .60353 .61479 L F
.749 .885 .477 r
.60175 .62081 m .6035 .61729 L .60159 .61853 L F
.41 .662 .963 r
.76291 .48391 m .75907 .48225 L .76217 .4825 L F
.345 .613 .949 r
.76419 .48272 m .76291 .48391 L .76217 .4825 L F
.374 .661 .969 r
.76419 .48272 m .76511 .48401 L .76291 .48391 L F
.403 .64 .952 r
.33587 .62343 m .33492 .62528 L .3341 .62315 L F
.33587 .62343 m .33779 .62567 L .33492 .62528 L F
.522 .47 .74 r
.38998 .60192 m .39066 .60422 L .39265 .60359 L F
.445 .234 .498 r
.39036 .60645 m .39265 .60359 L .39066 .60422 L F
.881 .666 .606 r
.73762 .48962 m .7374 .49212 L .7394 .49219 L F
.98 .735 .491 r
.50705 .75809 m .50678 .76041 L .50807 .76114 L F
.451 .43 .744 r
.60584 .65495 m .60399 .65649 L .6043 .65551 L F
.60584 .65495 m .60651 .65683 L .60399 .65649 L F
.456 .415 .723 r
.60399 .65649 m .60651 .65683 L .60695 .66054 L F
0 0 0 r
.34934 .64295 m .3482 .64319 L .35108 .64163 L F
.055 0 0 r
.35147 .64232 m .35108 .64163 L .35323 .64115 L F
.35147 .64232 m .34934 .64295 L .35108 .64163 L F
.431 .152 .387 r
.58422 .66153 m .58671 .66118 L .58741 .66099 L F
.526 .908 .756 r
.58741 .66099 m .58671 .66118 L .58855 .65994 L F
.39 .7 .983 r
.58855 .65994 m .58996 .66122 L .58741 .66099 L F
.664 .542 .706 r
.77702 .49539 m .77347 .49252 L .77598 .49186 L F
.77702 .49539 m .77493 .49629 L .77347 .49252 L F
.126 .441 .878 r
.66137 .5099 m .66236 .50959 L .65963 .50846 L F
.66137 .5099 m .66376 .51126 L .66236 .50959 L F
.577 .644 .88 r
.66143 .51173 m .66376 .51126 L .66137 .5099 L F
.87 .608 .54 r
.57827 .65096 m .58028 .65211 L .58133 .64986 L F
.113 .666 .781 r
.36518 .58592 m .36736 .58576 L .36883 .58578 L F
.485 .85 .99 r
.36736 .58576 m .37111 .58575 L .36883 .58578 L F
0 0 0 r
.33668 .60123 m .33625 .60103 L .33838 .60028 L F
.33668 .60123 m .33454 .60216 L .33625 .60103 L F
.378 .142 .425 r
.45304 .67256 m .4522 .67581 L .45019 .67637 L F
.582 .332 .503 r
.45526 .67461 m .4522 .67581 L .45304 .67256 L F
.629 .323 .432 r
.4558 .67278 m .45526 .67461 L .45304 .67256 L F
.453 .367 .669 r
.28627 .60384 m .28759 .60083 L .28568 .6013 L F
.691 .456 .562 r
.66948 .48971 m .66998 .49268 L .66584 .49214 L F
.707 .467 .559 r
.67167 .49218 m .66998 .49268 L .66948 .48971 L F
.2 0 0 r
.33478 .58327 m .3369 .58337 L .33852 .58303 L F
.468 .612 .91 r
.59351 .64693 m .59635 .64682 L .595 .64539 L F
.283 .316 .72 r
.595 .64539 m .59532 .64843 L .59351 .64693 L F
.465 .319 .598 r
.59351 .64693 m .59532 .64843 L .5934 .64908 L F
.432 .495 .825 r
.38831 .59815 m .38998 .60192 L .39099 .59977 L F
.538 .623 .884 r
.38998 .60192 m .39192 .60137 L .39099 .59977 L F
.522 .47 .74 r
.38998 .60192 m .39265 .60359 L .39192 .60137 L F
.603 .492 .7 r
.49848 .6545 m .4957 .65226 L .49823 .65309 L F
.49848 .6545 m .49651 .65503 L .4957 .65226 L F
.215 .399 .829 r
.73653 .5269 m .73767 .52559 L .73492 .52383 L F
.275 .49 .885 r
.73653 .5269 m .73957 .5282 L .73767 .52559 L F
0 0 .003 r
.69018 .47848 m .69236 .47524 L .68903 .47508 L F
.69018 .47848 m .69169 .47738 L .69236 .47524 L F
.504 .91 .879 r
.69018 .47848 m .68954 .47834 L .69169 .47738 L F
.695 .439 .532 r
.60345 .56108 m .60723 .56337 L .6071 .5613 L F
.711 .397 .445 r
.6071 .5613 m .60723 .56337 L .60963 .56315 L F
.997 .771 .444 r
.45785 .68118 m .45785 .68396 L .45711 .68308 L F
.643 .637 .829 r
.45971 .67932 m .46194 .68121 L .45785 .68118 L F
.468 .324 .601 r
.45997 .68308 m .45785 .68118 L .46194 .68121 L F
.45997 .68308 m .45785 .68396 L .45785 .68118 L F
.077 0 .079 r
.45785 .68118 m .45871 .68236 L .45862 .6797 L F
.45785 .68118 m .45711 .68308 L .45871 .68236 L F
.467 0 0 r
.72177 .47373 m .72358 .47486 L .7252 .47562 L F
.944 .663 .475 r
.7238 .47693 m .7252 .47562 L .72358 .47486 L F
.7238 .47693 m .72535 .47792 L .7252 .47562 L F
.526 .336 .566 r
.7252 .47562 m .72535 .47792 L .72765 .47502 L F
.28 .48 .876 r
.20749 .55248 m .207 .554 L .20542 .55216 L F
.20749 .55248 m .20868 .55483 L .207 .554 L F
.751 .756 .856 r
.69525 .48946 m .69511 .49171 L .69853 .48987 L F
.012 0 0 r
.488 .6421 m .48636 .64276 L .48408 .64318 L F
.342 0 0 r
.48909 .64254 m .48636 .64276 L .488 .6421 L F
.438 .191 .44 r
.57904 .57196 m .5815 .56925 L .57931 .56989 L F
.674 .517 .664 r
.58998 .56433 m .59275 .56396 L .59203 .56142 L F
.661 .509 .667 r
.59203 .56142 m .59532 .56375 L .5961 .56279 L F
.59203 .56142 m .59275 .56396 L .59532 .56375 L F
0 0 0 r
.54321 .59551 m .53969 .59746 L .54217 .59735 L F
.082 0 0 r
.54321 .59551 m .54417 .59632 L .54491 .59466 L F
.54321 .59551 m .54217 .59735 L .54417 .59632 L F
.234 .005 .347 r
.42628 .67259 m .42781 .67199 L .42841 .66964 L F
.365 .239 .573 r
.42632 .67505 m .42781 .67199 L .42628 .67259 L F
.231 .412 .835 r
.55431 .63258 m .55538 .63121 L .5526 .62934 L F
.466 .751 .991 r
.55431 .63258 m .55571 .63212 L .55538 .63121 L F
.122 .66 .853 r
.5093 .76934 m .51286 .76967 L .51184 .76939 L F
.51184 .76939 m .51286 .76967 L .5093 .76934 L F
.269 .341 .753 r
.76678 .50354 m .76766 .50709 L .76923 .50539 L F
.165 .153 .598 r
.76766 .50709 m .76967 .50781 L .76923 .50539 L F
.76766 .50709 m .76841 .50918 L .76967 .50781 L F
.849 .511 .415 r
.46797 .70002 m .47075 .70304 L .47103 .70122 L F
.256 .552 .929 r
.73957 .5282 m .74023 .52953 L .74138 .52854 L F
.282 .595 .949 r
.74138 .52854 m .74023 .52953 L .74238 .52988 L F
.976 .92 .664 r
.73818 .48574 m .73762 .48962 L .73925 .48681 L F
.858 .913 .869 r
.73818 .48574 m .73925 .48681 L .74175 .48398 L F
.85 .871 .857 r
.55967 .6605 m .5569 .66341 L .55873 .66395 L F
.722 .194 0 r
.55897 .66516 m .55873 .66395 L .5569 .66341 L F
.55897 .66516 m .56069 .66615 L .55873 .66395 L F
.67 .558 .72 r
.77702 .49539 m .77469 .49825 L .77493 .49629 L F
.663 .548 .714 r
.77702 .49539 m .77719 .498 L .77469 .49825 L F
0 .228 .629 r
.74911 .47709 m .75183 .47865 L .75069 .47801 L F
.658 .772 .934 r
.51902 .65413 m .5205 .65637 L .52333 .65522 L F
0 0 0 r
.50513 .70701 m .50584 .70757 L .50725 .70629 L F
.708 .352 .371 r
.50513 .70701 m .50499 .70861 L .50138 .70821 L F
.697 .319 .327 r
.50499 .70861 m .50392 .70933 L .50138 .70821 L F
.694 .31 .316 r
.50499 .70861 m .50386 .71065 L .50391 .70979 L F
0 0 0 r
.50386 .71065 m .50393 .70932 L .50392 .70933 L F
.694 .31 .316 r
.50499 .70861 m .50347 .71026 L .50431 .70853 L F
.748 .402 .396 r
.5072 .70942 m .50721 .71109 L .50499 .70861 L F
.765 .395 .354 r
.50499 .70861 m .50721 .71109 L .50386 .71065 L F
0 0 0 r
.50386 .71065 m .50584 .70757 L .50393 .70932 L F
.697 .309 .309 r
.50392 .70933 m .50386 .71065 L .50138 .70821 L F
.694 .31 .316 r
.50391 .70979 m .50386 .71065 L .50347 .71026 L F
0 0 0 r
.50403 .70911 m .50392 .70933 L .50393 .70932 L F
.601 .046 0 r
.50138 .70821 m .50392 .70933 L .50385 .70932 L F
.694 .31 .316 r
.50392 .70935 m .50347 .71026 L .50138 .70821 L F
.601 .046 0 r
.50138 .70821 m .50385 .70932 L .50073 .70863 L F
.694 .31 .316 r
.50431 .70853 m .50392 .70935 L .50138 .70821 L F
0 0 0 r
.50513 .70701 m .50403 .70911 L .50584 .70757 L F
.50403 .70911 m .50393 .70932 L .50584 .70757 L F
.369 .191 .504 r
.32712 .60853 m .32562 .60695 L .32766 .60625 L F
.32712 .60853 m .32539 .60915 L .32562 .60695 L F
.398 .007 .177 r
.58445 .58095 m .5837 .58268 L .58159 .58309 L F
.258 0 .116 r
.58445 .58095 m .58656 .58069 L .5837 .58268 L F
.607 .671 .885 r
.55051 .64297 m .55233 .64514 L .54742 .64331 L F
.663 .836 .966 r
.55223 .64294 m .55233 .64514 L .55051 .64297 L F
.55223 .64294 m .55332 .64401 L .55233 .64514 L F
0 0 0 r
.55332 .64401 m .55135 .64638 L .55233 .64514 L F
.523 .236 .42 r
.45486 .65468 m .45714 .65449 L .45755 .6527 L F
.47 .201 .424 r
.45714 .65449 m .45973 .65215 L .45755 .6527 L F
.585 .413 .615 r
.5929 .63254 m .59556 .63212 L .59525 .62969 L F
.608 .526 .736 r
.59424 .63508 m .59556 .63212 L .5929 .63254 L F
.487 0 0 r
.72097 .47363 m .72358 .47486 L .72177 .47373 L F
.944 .836 .707 r
.42595 .70442 m .42559 .70085 L .42707 .70191 L F
.707 .883 .962 r
.42877 .70074 m .42707 .70191 L .42559 .70085 L F
.734 .616 .727 r
.59674 .64984 m .59475 .65275 L .5934 .64908 L F
.668 .249 .239 r
.59475 .65275 m .59668 .65454 L .5932 .65384 L F
.966 .899 .529 r
.6019 .60665 m .60231 .6026 L .60254 .60434 L F
.686 .633 .791 r
.73941 .51518 m .73628 .51294 L .7387 .51212 L F
.78 .706 .782 r
.74196 .51238 m .73941 .51518 L .7387 .51212 L F
.306 0 0 r
.3689 .63633 m .37025 .63495 L .37258 .63454 L F
.713 .703 .839 r
.67657 .49623 m .67291 .49544 L .67485 .49464 L F
.673 .872 .974 r
.55676 .64402 m .55332 .64401 L .55553 .64315 L F
.55332 .64401 m .55676 .64402 L .55553 .64315 L F
.463 .597 .9 r
.5645 .64946 m .56427 .64633 L .56262 .64637 L F
.5645 .64946 m .5661 .64921 L .56427 .64633 L F
.302 0 .184 r
.69236 .47524 m .69395 .47633 L .69452 .47427 L F
.69236 .47524 m .69169 .47738 L .69395 .47633 L F
.577 .644 .88 r
.66143 .51173 m .66505 .51293 L .66376 .51126 L F
.734 .616 .727 r
.59674 .64984 m .5934 .64908 L .59532 .64843 L F
.578 .748 .957 r
.59894 .64921 m .59674 .64984 L .59532 .64843 L F
.162 0 0 r
.31934 .58258 m .32154 .58261 L .32329 .58222 L F
.284 0 0 r
.32154 .58261 m .3245 .58196 L .32329 .58222 L F
.656 .494 .652 r
.68 .48354 m .68211 .48414 L .68192 .48142 L F
.549 .29 .475 r
.68192 .48142 m .6841 .48281 L .68441 .48089 L F
.45 .338 .634 r
.68192 .48142 m .68211 .48414 L .6841 .48281 L F
.507 .174 .337 r
.50416 .78634 m .5078 .78788 L .50518 .78904 L F
.629 .622 .824 r
.50764 .78857 m .50518 .78904 L .5078 .78788 L F
.945 .611 .363 r
.52962 .65823 m .53072 .66145 L .52869 .66004 L F
.677 .495 .632 r
.53105 .65967 m .53072 .66145 L .52962 .65823 L F
.365 .423 .788 r
.52883 .65505 m .52962 .65823 L .53155 .65694 L F
.332 .178 .516 r
.53233 .66021 m .53105 .65967 L .53357 .65981 L F
.67 .239 .215 r
.52962 .65823 m .53233 .66021 L .53155 .65694 L F
.332 .178 .516 r
.53233 .66021 m .53072 .66145 L .53105 .65967 L F
.67 .239 .215 r
.52962 .65823 m .52869 .66004 L .53233 .66021 L F
.945 .672 .49 r
.60277 .59199 m .60096 .58883 L .60261 .5898 L F
.307 .355 .748 r
.56528 .65524 m .56779 .65747 L .56652 .65371 L F
.541 .586 .849 r
.53545 .66241 m .53367 .66311 L .53233 .66021 L F
.281 .773 .716 r
.53437 .6595 m .53233 .66021 L .53357 .65981 L F
.541 .586 .849 r
.53545 .66241 m .53233 .66021 L .53437 .6595 L F
0 0 .215 r
.53233 .66021 m .53337 .66134 L .53437 .6595 L F
.842 .844 .379 r
.53437 .6595 m .53337 .66134 L .53374 .66024 L F
.281 .773 .716 r
.53437 .6595 m .53357 .65981 L .53467 .65915 L F
.842 .844 .379 r
.53437 .6595 m .53374 .66024 L .53412 .6591 L F
.281 .773 .716 r
.53437 .6595 m .53467 .65915 L .53633 .65815 L F
.576 .135 .165 r
.53633 .65815 m .5373 .65963 L .53437 .6595 L F
.766 .809 .887 r
.5173 .68 m .51396 .68092 L .5168 .67851 L F
.476 .04 .132 r
.5173 .68 m .51627 .68106 L .51396 .68092 L F
.295 .771 .928 r
.51999 .68112 m .51627 .68106 L .5173 .68 L F
.195 .616 .947 r
.37356 .59526 m .37404 .59452 L .37224 .59465 L F
.37356 .59526 m .37542 .59556 L .37404 .59452 L F
.239 .096 .477 r
.59181 .64115 m .59341 .64315 L .59296 .63981 L F
.59181 .64115 m .59168 .64355 L .59341 .64315 L F
0 .552 .817 r
.37111 .58575 m .3732 .58608 L .37469 .58657 L F
.267 .739 .94 r
.37469 .58657 m .3732 .58608 L .37685 .58646 L F
.754 .352 .29 r
.55682 .63444 m .55536 .63608 L .55617 .63465 L F
.88 .468 .035 r
.55571 .63212 m .5572 .63432 L .55682 .63444 L F
0 .008 .584 r
.55682 .63444 m .55538 .63121 L .55571 .63212 L F
.55682 .63444 m .5569 .63335 L .55538 .63121 L F
.754 .352 .29 r
.55682 .63444 m .55617 .63465 L .5569 .63335 L F
.88 .468 .035 r
.5572 .63432 m .55788 .63534 L .55682 .63444 L F
0 0 .531 r
.55835 .63751 m .55682 .63444 L .55788 .63534 L F
.593 .373 .551 r
.51454 .6553 m .51441 .65758 L .51206 .65765 L F
.459 .238 .49 r
.51685 .65479 m .51441 .65758 L .51454 .6553 L F
.858 .541 .449 r
.61578 .57231 m .61621 .57482 L .61941 .57558 L F
.863 .675 .647 r
.61566 .57723 m .61941 .57558 L .61621 .57482 L F
.61566 .57723 m .61879 .57807 L .61941 .57558 L F
.778 .637 .705 r
.61068 .56643 m .61441 .56448 L .61089 .56394 L F
.61068 .56643 m .61419 .56686 L .61441 .56448 L F
.517 .074 .137 r
.50608 .64919 m .50278 .65065 L .50638 .64895 L F
.50638 .64895 m .50278 .65065 L .50438 .64945 L F
.50695 .6488 m .5052 .65081 L .50278 .65065 L F
.973 .676 .391 r
.5052 .65081 m .50556 .64932 L .50175 .64829 L F
.50375 .65071 m .50175 .64829 L .50278 .65065 L F
.5052 .65081 m .50428 .65013 L .50375 .65071 L F
.50428 .65013 m .50175 .64829 L .50375 .65071 L F
.802 .637 .677 r
.50175 .64829 m .50556 .64932 L .50518 .64578 L F
.059 .082 .569 r
.50518 .64578 m .50556 .64932 L .50688 .64728 L F
.792 .675 .735 r
.50472 .64964 m .50688 .64728 L .50556 .64932 L F
.50382 .64999 m .50681 .64733 L .50472 .64964 L F
.50681 .64733 m .50688 .64728 L .50472 .64964 L F
.973 .676 .391 r
.50547 .64968 m .50382 .64999 L .50556 .64932 L F
.5052 .65081 m .50455 .65042 L .50547 .64968 L F
.50455 .65042 m .50382 .64999 L .50547 .64968 L F
.517 .074 .137 r
.50695 .6488 m .50608 .64919 L .50638 .64895 L F
.462 .118 .297 r
.41474 .60699 m .41421 .6086 L .41192 .6089 L F
.396 .166 .444 r
.4168 .60623 m .41474 .60699 L .41713 .60407 L F
.528 .274 .473 r
.4168 .60623 m .41421 .6086 L .41474 .60699 L F
.563 .732 .954 r
.5265 .65542 m .52799 .65353 L .52499 .65246 L F
.5265 .65542 m .52883 .65505 L .52799 .65353 L F
.75 .573 .656 r
.52578 .6697 m .529 .66684 L .52662 .66822 L F
.52578 .6697 m .52933 .66982 L .529 .66684 L F
.555 .51 .761 r
.53135 .6668 m .52933 .66982 L .529 .66684 L F
.53086 .66753 m .53182 .66971 L .52933 .66982 L F
.53135 .6668 m .53154 .66797 L .53086 .66753 L F
.53154 .66797 m .53182 .66971 L .53086 .66753 L F
.323 0 .188 r
.53182 .66971 m .52898 .67172 L .52933 .66982 L F
.53182 .66971 m .53178 .67188 L .52898 .67172 L F
.671 .592 .759 r
.53477 .66885 m .53182 .66971 L .53135 .6668 L F
.617 .188 .205 r
.53334 .67075 m .53182 .66971 L .53477 .66885 L F
.53334 .67075 m .53178 .67188 L .53182 .66971 L F
.826 .495 .429 r
.53055 .66816 m .53178 .67188 L .53334 .67075 L F
.53055 .66816 m .5324 .66987 L .53253 .67081 L F
.5324 .66987 m .53334 .67075 L .53253 .67081 L F
.53055 .66816 m .53253 .67081 L .53371 .6694 L F
.53055 .66816 m .53371 .6694 L .53284 .66882 L F
.804 .634 .67 r
.53473 .66628 m .53135 .6668 L .53367 .66311 L F
.73 .683 .805 r
.53055 .66816 m .53392 .66914 L .53381 .66862 L F
.671 .592 .759 r
.53471 .66882 m .53135 .6668 L .53477 .66883 L F
.693 .452 .553 r
.53716 .66645 m .53477 .66885 L .53473 .66628 L F
.74 .633 .741 r
.53253 .67081 m .53525 .66762 L .53405 .669 L F
.53363 .66949 m .53405 .669 L .53392 .66914 L F
.53253 .67081 m .53405 .669 L .53363 .66949 L F
.671 .592 .759 r
.53476 .66815 m .53344 .66804 L .53473 .66628 L F
.53477 .66883 m .53438 .6686 L .53476 .66815 L F
.53438 .6686 m .53344 .66804 L .53476 .66815 L F
.53344 .66804 m .53135 .6668 L .53254 .66662 L F
.53344 .66804 m .53254 .66662 L .53473 .66628 L F
.169 .282 .737 r
.53298 .66478 m .53381 .66862 L .53525 .66762 L F
.53381 .66862 m .53392 .66914 L .53405 .669 L F
.53381 .66862 m .53405 .669 L .53525 .66762 L F
.73 .683 .805 r
.53071 .66794 m .53381 .66862 L .53298 .66478 L F
.53055 .66816 m .53381 .66862 L .53071 .66794 L F
.671 .592 .759 r
.53477 .66885 m .53471 .66882 L .53477 .66883 L F
.693 .452 .553 r
.53716 .66645 m .53713 .66881 L .53477 .66885 L F
.669 .415 .527 r
.53708 .67042 m .53477 .66885 L .53713 .66881 L F
.53708 .67042 m .53334 .67075 L .53477 .66885 L F
.536 .892 .977 r
.53133 .67358 m .53253 .67081 L .53334 .67075 L F
.733 .587 .693 r
.53334 .67075 m .53483 .67409 L .53133 .67358 L F
.113 .244 .722 r
.53587 .6728 m .53334 .67075 L .53708 .67042 L F
.74 .633 .741 r
.5339 .6692 m .53588 .67138 L .53525 .66762 L F
.113 .244 .722 r
.53489 .67201 m .53483 .67409 L .53334 .67075 L F
.74 .633 .741 r
.53253 .67081 m .53459 .67116 L .5339 .6692 L F
.53459 .67116 m .53588 .67138 L .5339 .6692 L F
.113 .244 .722 r
.53587 .6728 m .53539 .6734 L .53489 .67201 L F
.53539 .6734 m .53483 .67409 L .53489 .67201 L F
.822 .484 .415 r
.53259 .67199 m .53588 .67138 L .53253 .67081 L F
.359 .31 .666 r
.53342 .66846 m .53266 .67171 L .53253 .67081 L F
.53266 .67171 m .53259 .67199 L .53253 .67081 L F
.826 .495 .429 r
.53284 .66882 m .53371 .6694 L .53392 .66914 L F
.122 .111 .572 r
.529 .66684 m .53055 .66816 L .53135 .6668 L F
.529 .66684 m .52933 .66982 L .53055 .66816 L F
.917 .519 .154 r
.65576 .49791 m .65372 .49509 L .65538 .49561 L F
.746 .663 .769 r
.65794 .49533 m .65576 .49791 L .65538 .49561 L F
.457 .258 .521 r
.51902 .65413 m .51694 .65254 L .51972 .65187 L F
.51902 .65413 m .51685 .65479 L .51694 .65254 L F
.064 .263 .755 r
.51694 .65254 m .51902 .65413 L .51972 .65187 L F
.004 0 .12 r
.59703 .62896 m .59932 .62587 L .5978 .62701 L F
.403 .83 .96 r
.54509 .65145 m .54893 .6514 L .54639 .65168 L F
.54509 .65145 m .54893 .6514 L .54639 .65168 L F
.517 .157 .295 r
.6763 .48594 m .68 .48354 L .67628 .48417 L F
.6763 .48594 m .67877 .48579 L .68 .48354 L F
.324 0 0 r
.67877 .48579 m .68211 .48414 L .68 .48354 L F
.578 .575 .813 r
.28856 .61537 m .28942 .61137 L .2871 .61199 L F
.28856 .61537 m .29112 .61509 L .28942 .61137 L F
.2 .257 .698 r
.28856 .61537 m .29054 .61729 L .29112 .61509 L F
0 0 .077 r
.48633 .62116 m .48469 .62457 L .48577 .62309 L F
0 0 0 r
.48884 .619 m .48633 .62116 L .488 .61986 L F
.472 .32 .593 r
.48577 .62309 m .488 .61986 L .48633 .62116 L F
.012 0 0 r
.46286 .66827 m .46371 .66713 L .46575 .66628 L F
.453 .367 .669 r
.28627 .60384 m .28807 .60335 L .28759 .60083 L F
.38 .267 .599 r
.28664 .60628 m .28807 .60335 L .28627 .60384 L F
.658 .828 .965 r
.74088 .51124 m .74196 .51238 L .7387 .51212 L F
.738 .743 .856 r
.74347 .50853 m .74196 .51238 L .74088 .51124 L F
.74347 .50853 m .74478 .51053 L .74196 .51238 L F
.496 .276 .51 r
.41922 .60345 m .4168 .60623 L .41713 .60407 L F
.263 .073 .424 r
.59316 .63737 m .59536 .63698 L .59424 .63508 L F
.101 .051 .509 r
.59424 .63508 m .59618 .63116 L .59556 .63212 L F
.59424 .63508 m .5963 .63409 L .59618 .63116 L F
.571 .518 .757 r
.59536 .63698 m .5963 .63409 L .59424 .63508 L F
.704 .773 .283 r
.59618 .63116 m .59703 .62896 L .59525 .62969 L F
0 0 .413 r
.59556 .63212 m .59618 .63116 L .59525 .62969 L F
.954 .765 .608 r
.61679 .5807 m .61631 .58391 L .61788 .58403 L F
.864 .433 .012 r
.61631 .58391 m .61812 .58635 L .61788 .58403 L F
.789 .565 .597 r
.6107 .56886 m .61419 .56686 L .61068 .56643 L F
.6107 .56886 m .6142 .56932 L .61419 .56686 L F
.778 .631 .698 r
.67498 .49266 m .67291 .49544 L .67167 .49218 L F
.665 .472 .613 r
.67485 .49464 m .67291 .49544 L .67498 .49266 L F
.386 .642 .958 r
.41058 .5973 m .40986 .59883 L .40855 .59731 L F
.41058 .5973 m .41258 .59904 L .40986 .59883 L F
.266 0 0 r
.31031 .586 m .31389 .58412 L .3116 .58465 L F
.055 .47 .885 r
.21105 .55626 m .2111 .55726 L .20883 .5548 L F
.21105 .55626 m .21238 .5576 L .2111 .55726 L F
.295 0 .094 r
.4656 .69998 m .46645 .70042 L .46797 .70002 L F
.4654 .69998 m .46645 .70042 L .4656 .69998 L F
.815 .497 .452 r
.46606 .70244 m .46797 .70002 L .46645 .70042 L F
.46606 .70244 m .46914 .7031 L .46797 .70002 L F
.82 .422 .296 r
.46791 .70136 m .46645 .70042 L .46784 .70101 L F
.46791 .70136 m .46753 .70098 L .46645 .70042 L F
.46784 .70101 m .46645 .70042 L .46738 .69859 L F
.388 .627 .948 r
.46738 .69859 m .46645 .70042 L .46506 .69854 L F
.82 .422 .296 r
.46753 .70098 m .46506 .69854 L .46645 .70042 L F
.295 0 .094 r
.46505 .69998 m .46645 .70042 L .4654 .69998 L F
.46505 .69998 m .46449 .70095 L .46645 .70042 L F
.751 .861 .93 r
.4522 .67581 m .45035 .67764 L .45019 .67637 L F
.264 .744 .932 r
.52146 .78631 m .52244 .78674 L .51898 .78649 L F
.99 .877 .62 r
.52157 .78919 m .52244 .78674 L .52146 .78631 L F
.065 0 .143 r
.55641 .58706 m .55559 .58889 L .55798 .58599 L F
.177 .646 .934 r
.52629 .63491 m .52515 .63538 L .52378 .63455 L F
.52629 .63491 m .52742 .63559 L .52515 .63538 L F
.762 .512 .555 r
.49904 .6645 m .49485 .66361 L .49849 .66398 L F
.327 .81 .877 r
.50064 .6641 m .49904 .6645 L .49849 .66398 L F
.45 .271 .545 r
.69962 .46922 m .70181 .46606 L .69953 .46693 L F
.182 .1 .521 r
.48469 .62457 m .48584 .62556 L .48577 .62309 L F
.484 .582 .878 r
.42042 .60022 m .41948 .60094 L .41816 .59902 L F
.323 .173 .517 r
.42042 .60022 m .41922 .60345 L .41948 .60094 L F
.835 .794 .813 r
.58951 .56551 m .59275 .56396 L .58998 .56433 L F
.241 .749 .88 r
.35026 .59893 m .35079 .5984 L .34846 .59881 L F
.35026 .59893 m .35256 .59866 L .35079 .5984 L F
.2 0 .265 r
.47321 .64148 m .47253 .64345 L .47488 .64058 L F
.034 0 0 r
.69788 .47301 m .69682 .47369 L .69452 .47427 L F
0 0 0 r
.69788 .47301 m .69994 .47239 L .70065 .47258 L F
.69788 .47301 m .69682 .47369 L .69994 .47239 L F
0 0 .447 r
.60653 .64304 m .60667 .64534 L .60539 .64677 L F
.064 .075 .559 r
.60539 .64677 m .60667 .64534 L .60663 .64868 L F
.419 .169 .426 r
.42841 .66964 m .43029 .67128 L .43055 .66903 L F
.42841 .66964 m .42781 .67199 L .43029 .67128 L F
.443 .139 .353 r
.57681 .58666 m .57626 .58927 L .57373 .58932 L F
.318 .12 .447 r
.57917 .58392 m .57852 .58593 L .57681 .58666 L F
.265 0 .305 r
.57852 .58593 m .57626 .58927 L .57681 .58666 L F
.489 .583 .875 r
.33233 .62028 m .33203 .62345 L .33036 .62079 L F
.33233 .62028 m .3341 .62315 L .33203 .62345 L F
.592 .49 .706 r
.67289 .48403 m .6763 .48594 L .67628 .48417 L F
.397 .156 .429 r
.73952 .4728 m .73944 .47467 L .74174 .47193 L F
0 0 .35 r
.56688 .62866 m .56706 .63109 L .56625 .63216 L F
.038 .251 .75 r
.56706 .63109 m .56849 .63418 L .56625 .63216 L F
.802 .368 0 r
.53373 .61208 m .53585 .61506 L .53448 .61349 L F
.709 .25 0 r
.53707 .6171 m .53448 .61349 L .53585 .61506 L F
.031 0 .192 r
.5213 .65106 m .51972 .65187 L .52172 .64925 L F
0 0 0 r
.52039 .65251 m .51972 .65187 L .5213 .65106 L F
.52039 .65251 m .51902 .65413 L .51972 .65187 L F
.755 .768 .864 r
.41491 .70196 m .41703 .70059 L .41349 .70051 L F
0 .061 .599 r
.71564 .49799 m .71533 .49465 L .71591 .49563 L F
.897 .66 .573 r
.60088 .58648 m .59911 .58334 L .60152 .5843 L F
.295 0 0 r
.55785 .64532 m .56227 .64361 L .56029 .6451 L F
.55785 .64532 m .56227 .64361 L .56029 .6451 L F
0 0 .3 r
.56261 .64395 m .56219 .64306 L .56215 .64296 L F
.077 .171 .66 r
.56262 .64637 m .56226 .6436 L .56261 .64395 L F
.56226 .6436 m .56219 .64306 L .56232 .64334 L F
.56226 .6436 m .56232 .64334 L .56261 .64395 L F
.418 .132 .37 r
.56227 .64361 m .56371 .64503 L .56227 .64361 L F
.077 .171 .66 r
.56226 .6436 m .56371 .64503 L .56219 .64306 L F
.56262 .64637 m .56371 .64503 L .56226 .6436 L F
.418 .132 .37 r
.56226 .64362 m .56371 .64503 L .56227 .64361 L F
.56029 .6451 m .56194 .64507 L .56226 .64362 L F
.56194 .64507 m .56371 .64503 L .56226 .64362 L F
.552 .869 .995 r
.56371 .64503 m .56029 .6451 L .56227 .64361 L F
.418 .132 .37 r
.56029 .6451 m .56219 .64306 L .56371 .64503 L F
.56029 .6451 m .56227 .64321 L .56219 .64306 L F
.56227 .64321 m .56303 .64248 L .56219 .64306 L F
0 0 .3 r
.56215 .64296 m .56219 .64306 L .56109 .64069 L F
.414 0 0 r
.28884 .64656 m .28517 .64576 L .28658 .6468 L F
.28884 .64656 m .28517 .64576 L .28658 .6468 L F
.341 0 .007 r
.49651 .65503 m .49495 .65702 L .49263 .65727 L F
.213 0 0 r
.49732 .65633 m .49651 .65503 L .49848 .6545 L F
.49732 .65633 m .49495 .65702 L .49651 .65503 L F
.492 .37 .641 r
.32285 .61144 m .32107 .61538 L .32069 .6128 L F
.527 .244 .428 r
.39399 .62124 m .39352 .62314 L .39156 .62306 L F
.419 .146 .39 r
.39557 .62244 m .39399 .62124 L .39626 .62087 L F
.39557 .62244 m .39352 .62314 L .39399 .62124 L F
.556 .933 .888 r
.36768 .59718 m .36836 .59612 L .3662 .59673 L F
.36768 .59718 m .37043 .59583 L .36836 .59612 L F
.574 .652 .889 r
.71839 .50087 m .72126 .49808 L .71742 .4996 L F
.125 .392 .845 r
.73154 .51969 m .73234 .5204 L .73058 .51767 L F
.335 0 .186 r
.54244 .70117 m .54153 .70339 L .53929 .704 L F
.486 .342 .61 r
.54338 .6998 m .54244 .70117 L .54108 .70024 L F
.54338 .6998 m .54153 .70339 L .54244 .70117 L F
0 0 0 r
.34477 .59913 m .34279 .59962 L .34063 .59998 L F
.11 0 0 r
.34598 .59879 m .34279 .59962 L .34477 .59913 L F
.672 .248 .232 r
.4867 .66548 m .48349 .6659 L .48567 .66804 L F
0 0 0 r
.4867 .66548 m .48778 .66521 L .48856 .6642 L F
.796 .677 .733 r
.48567 .66804 m .48778 .66521 L .4867 .66548 L F
.361 .685 .98 r
.76111 .48128 m .75907 .48225 L .75807 .48112 L F
.76111 .48128 m .76217 .4825 L .75907 .48225 L F
.746 .763 .867 r
.69738 .48829 m .69525 .48946 L .69853 .48987 L F
.653 .73 .906 r
.69738 .48829 m .69853 .48987 L .70099 .4891 L F
.75 .558 .636 r
.59911 .58334 m .5956 .58047 L .5987 .58118 L F
.576 .735 .951 r
.70998 .47458 m .71114 .4726 L .70867 .47197 L F
.70998 .47458 m .71238 .47442 L .71114 .4726 L F
.599 .048 0 r
.70903 .47523 m .71249 .47631 L .70998 .47458 L F
.567 .262 .41 r
.70998 .47458 m .71249 .47631 L .71238 .47442 L F
.503 .17 .335 r
.50284 .64338 m .5055 .64315 L .50603 .64154 L F
0 0 .009 r
.50603 .64154 m .5055 .64315 L .507 .64052 L F
.067 0 0 r
.35965 .63949 m .3592 .63887 L .36138 .6386 L F
.35965 .63949 m .35752 .64003 L .3592 .63887 L F
0 0 0 r
.34934 .64295 m .34733 .64378 L .3482 .64319 L F
.613 .843 .987 r
.74477 .52942 m .74616 .53058 L .7486 .52968 L F
.363 .572 .919 r
.52096 .77423 m .52187 .77591 L .51987 .77563 L F
.52096 .77423 m .52187 .77591 L .51987 .77563 L F
.734 .261 .124 r
.45971 .67932 m .4637 .68072 L .46194 .68121 L F
.204 0 .044 r
.46284 .68131 m .46194 .68121 L .4637 .68072 L F
.891 .912 .833 r
.46059 .68088 m .45871 .68236 L .45997 .68308 L F
.734 .261 .124 r
.45971 .67932 m .46197 .68075 L .46341 .68062 L F
0 .387 .838 r
.461 .67946 m .46284 .68131 L .45971 .67932 L F
.891 .912 .833 r
.461 .67946 m .45983 .68095 L .46059 .68088 L F
.45983 .68095 m .45871 .68236 L .46059 .68088 L F
.734 .261 .124 r
.46341 .68062 m .46284 .68131 L .4637 .68072 L F
.46197 .68075 m .46284 .68131 L .46341 .68062 L F
0 .167 .706 r
.56999 .66385 m .57016 .66272 L .56833 .66093 L F
0 0 .171 r
.57069 .66613 m .57016 .66272 L .56999 .66385 L F
0 0 .495 r
.52023 .67686 m .52122 .67768 L .52084 .67468 L F
.166 0 0 r
.50111 .78524 m .50247 .78577 L .50416 .78634 L F
.50111 .78524 m .49979 .78676 L .50247 .78577 L F
.577 .381 .58 r
.59296 .63981 m .59536 .63698 L .59316 .63737 L F
.76 .611 .693 r
.50969 .79797 m .51136 .79506 L .50806 .79446 L F
.239 .753 .853 r
.34641 .62761 m .3492 .62719 L .35074 .62735 L F
.225 0 0 r
.3492 .62719 m .35283 .62684 L .35074 .62735 L F
.593 .593 .821 r
.70065 .47258 m .70306 .472 L .7019 .46854 L F
.578 .131 .154 r
.69994 .47239 m .70306 .472 L .70065 .47258 L F
.69994 .47239 m .70198 .47334 L .70292 .47216 L F
.70254 .47206 m .70292 .47216 L .70306 .472 L F
.69994 .47239 m .70292 .47216 L .70254 .47206 L F
.593 .593 .821 r
.70032 .47149 m .7019 .46854 L .69962 .46922 L F
.70065 .47258 m .70094 .47165 L .70032 .47149 L F
.70094 .47165 m .7019 .46854 L .70032 .47149 L F
.163 0 0 r
.54993 .5912 m .55232 .59075 L .55368 .58967 L F
0 0 0 r
.55368 .58967 m .5544 .59004 L .55559 .58889 L F
.55368 .58967 m .55232 .59075 L .5544 .59004 L F
.75 .461 .493 r
.7019 .46854 m .70547 .46643 L .70181 .46606 L F
.7019 .46854 m .70566 .469 L .70547 .46643 L F
.655 .139 .002 r
.59202 .57592 m .5942 .57749 L .59263 .5767 L F
.461 .109 .281 r
.59202 .57592 m .59263 .5767 L .58896 .57848 L F
0 0 0 r
.47046 .64428 m .46792 .64674 L .46955 .64573 L F
.113 0 0 r
.46955 .64573 m .47253 .64345 L .47046 .64428 L F
0 .491 .751 r
.54648 .64208 m .55051 .64297 L .54742 .64331 L F
.567 .379 .587 r
.4755 .65324 m .47536 .65516 L .47325 .65531 L F
.652 .663 .848 r
.44892 .69525 m .44498 .69284 L .44718 .69286 L F
.447 0 0 r
.44718 .69286 m .45087 .69475 L .44892 .69525 L F
0 0 .331 r
.44942 .6976 m .44892 .69525 L .45087 .69475 L F
0 0 0 r
.59999 .62396 m .60122 .62268 L .60175 .62081 L F
0 0 .081 r
.6006 .62478 m .59999 .62396 L .59932 .62587 L F
.6006 .62478 m .60122 .62268 L .59999 .62396 L F
.582 .542 .775 r
.50161 .65012 m .49823 .65309 L .49772 .64822 L F
.634 .857 .48 r
.50161 .65012 m .49848 .6545 L .49823 .65309 L F
.676 .695 .86 r
.58248 .65784 m .58422 .66153 L .57998 .66036 L F
.471 .187 .399 r
.58422 .66153 m .58159 .66375 L .57998 .66036 L F
.58422 .66153 m .58391 .6633 L .58159 .66375 L F
.58159 .66375 m .58391 .6633 L .58422 .66153 L F
.517 .52 .798 r
.58494 .65706 m .58422 .66153 L .58248 .65784 L F
.58494 .65706 m .58671 .66118 L .58422 .66153 L F
.431 .152 .387 r
.58671 .66118 m .58391 .6633 L .58422 .66153 L F
.58422 .66153 m .58391 .6633 L .58671 .66118 L F
.434 .217 .483 r
.37487 .61532 m .37656 .61667 L .37731 .61505 L F
.37487 .61532 m .37455 .61731 L .37656 .61667 L F
.865 .86 .834 r
.29561 .63789 m .29338 .64224 L .29168 .63973 L F
.446 .08 .25 r
.29719 .59173 m .30074 .58903 L .29782 .59017 L F
.29719 .59173 m .29945 .59138 L .30074 .58903 L F
.49 .151 .319 r
.29945 .59138 m .30286 .58868 L .30074 .58903 L F
.642 .276 .335 r
.51884 .70422 m .52214 .70645 L .52285 .70409 L F
.906 .805 .329 r
.52285 .70409 m .52214 .70645 L .5225 .70659 L F
.404 .058 .261 r
.29502 .5922 m .29719 .59173 L .29782 .59017 L F
.754 .599 .685 r
.72972 .512 m .7329 .51155 L .73233 .51021 L F
.107 0 0 r
.73188 .51197 m .7329 .51155 L .72972 .512 L F
.961 .628 .314 r
.73233 .51021 m .7329 .51155 L .73188 .51197 L F
.422 .17 .425 r
.40157 .61517 m .40122 .61774 L .39902 .61796 L F
.529 .261 .453 r
.40351 .61688 m .40157 .61517 L .40378 .61479 L F
.40351 .61688 m .40122 .61774 L .40157 .61517 L F
.754 .599 .685 r
.72972 .512 m .73233 .51021 L .7294 .50873 L F
.961 .628 .314 r
.73233 .51021 m .73417 .50999 L .73537 .51121 L F
.73233 .51021 m .73188 .51197 L .73417 .50999 L F
0 0 .383 r
.57106 .66969 m .57157 .66879 L .57069 .66613 L F
0 .295 .792 r
.57106 .66969 m .57334 .67055 L .57157 .66879 L F
.57106 .66969 m .57363 .67157 L .57334 .67055 L F
0 0 .441 r
.57382 .67324 m .57362 .67154 L .57363 .67157 L F
0 0 .458 r
.57363 .67157 m .57353 .67075 L .57334 .67055 L F
0 0 .441 r
.57362 .67154 m .57353 .67075 L .57363 .67157 L F
0 .133 .583 r
.57364 .6716 m .57363 .67157 L .57106 .66969 L F
.57473 .6724 m .57363 .67157 L .57364 .6716 L F
.762 .512 .555 r
.49904 .6645 m .49494 .66617 L .49485 .66361 L F
.327 0 0 r
.49904 .6645 m .49721 .66601 L .49494 .66617 L F
.553 .496 .746 r
.49494 .66617 m .49721 .66601 L .49691 .66445 L F
.49549 .6648 m .49691 .66445 L .4965 .6623 L F
.49494 .66617 m .49691 .66445 L .49549 .6648 L F
.327 .81 .877 r
.50064 .6641 m .49717 .66439 L .49904 .6645 L F
.971 .756 .556 r
.4965 .6623 m .49721 .66601 L .49654 .66444 L F
.327 .81 .877 r
.49717 .66439 m .49654 .66444 L .49692 .66445 L F
.49717 .66439 m .49692 .66445 L .49904 .6645 L F
.97 .756 .56 r
.49654 .66444 m .49721 .66601 L .49904 .6645 L F
.677 .536 .686 r
.51081 .70672 m .51325 .70735 L .51314 .70388 L F
.596 .849 .992 r
.52837 .77778 m .52967 .77885 L .53182 .77801 L F
.52837 .77778 m .52967 .77885 L .53182 .77801 L F
.007 .279 .779 r
.56568 .62653 m .56468 .62704 L .56343 .62617 L F
.56568 .62653 m .56688 .62866 L .56468 .62704 L F
.752 .699 .802 r
.66376 .51126 m .66505 .51293 L .66692 .51147 L F
.732 .658 .777 r
.77945 .49278 m .77786 .4954 L .77702 .49539 L F
.634 .5 .681 r
.77786 .4954 m .77719 .498 L .77702 .49539 L F
.77786 .4954 m .78124 .49837 L .77719 .498 L F
.68 .605 .765 r
.78176 .49186 m .77786 .4954 L .77945 .49278 L F
.78176 .49186 m .7824 .4964 L .77786 .4954 L F
.703 .365 .4 r
.77786 .4954 m .78302 .49762 L .78124 .49837 L F
.77786 .4954 m .7824 .4964 L .78302 .49762 L F
.282 .445 .846 r
.49343 .64192 m .49419 .63996 L .49197 .64006 L F
.578 .128 .147 r
.43302 .66365 m .4355 .66414 L .43609 .66363 L F
.51 .047 .09 r
.43609 .66363 m .4355 .66414 L .43876 .66366 L F
.597 .643 .867 r
.2911 .62042 m .29261 .61681 L .29054 .61729 L F
.2911 .62042 m .29419 .62018 L .29261 .61681 L F
.595 .644 .869 r
.33779 .62567 m .34091 .62698 L .33892 .62753 L F
.749 .677 .782 r
.77398 .50691 m .77605 .50703 L .77667 .50588 L F
.444 .306 .597 r
.77667 .50588 m .7784 .50344 L .77903 .50509 L F
.77667 .50588 m .77605 .50703 L .77669 .50605 L F
.77667 .50588 m .77669 .50605 L .7784 .50344 L F
.555 .365 .578 r
.77903 .50509 m .77692 .5084 L .77667 .50588 L F
.77692 .5084 m .77635 .50928 L .77667 .50588 L F
.694 .628 .778 r
.7784 .50344 m .77661 .50617 L .77634 .50454 L F
.77661 .50617 m .77605 .50703 L .77614 .50625 L F
.749 .677 .782 r
.77616 .50608 m .77605 .50703 L .77398 .50691 L F
.634 .45 .615 r
.77645 .50614 m .77635 .50928 L .77379 .50921 L F
.77667 .50588 m .77665 .50607 L .77645 .50614 L F
.77665 .50607 m .77635 .50928 L .77645 .50614 L F
.694 .628 .778 r
.77645 .50614 m .77614 .50625 L .77616 .50608 L F
.77661 .50617 m .77614 .50625 L .77645 .50614 L F
.634 .45 .615 r
.77667 .50588 m .77667 .50589 L .77616 .50608 L F
.77667 .50588 m .77616 .50608 L .77615 .50608 L F
.694 .628 .778 r
.77661 .50617 m .77616 .50608 L .77634 .50454 L F
.634 .45 .615 r
.77615 .50608 m .77616 .50608 L .77398 .50691 L F
.77667 .50589 m .77379 .50921 L .77398 .50691 L F
.749 .677 .782 r
.77634 .50454 m .77616 .50608 L .77398 .50691 L F
.566 .6 .847 r
.31452 .64029 m .31559 .63709 L .31307 .63744 L F
.31452 .64029 m .31696 .64043 L .31559 .63709 L F
.917 .519 .154 r
.65576 .49791 m .65429 .49695 L .65372 .49509 L F
0 .31 .784 r
.65781 .49977 m .65429 .49695 L .65576 .49791 L F
.391 .225 .534 r
.51325 .70735 m .51547 .70395 L .51314 .70388 L F
.215 0 .334 r
.61127 .62601 m .60921 .62902 L .6097 .62697 L F
.62 .459 .643 r
.78124 .49837 m .77769 .50157 L .77719 .498 L F
.079 0 0 r
.60007 .66862 m .59655 .67085 L .59805 .6689 L F
.283 .715 .967 r
.34091 .62698 m .34331 .62695 L .34498 .62784 L F
.606 .067 0 r
.34331 .62695 m .34641 .62761 L .34498 .62784 L F
.836 .965 .64 r
.59497 .65783 m .59467 .65766 L .59668 .65454 L F
.639 .372 .499 r
.45765 .67162 m .45526 .67461 L .4558 .67278 L F
.45765 .67162 m .4578 .67473 L .45526 .67461 L F
0 0 0 r
.45765 .67162 m .45985 .66885 L .46047 .67138 L F
.619 .357 .499 r
.46063 .67443 m .45765 .67162 L .46047 .67138 L F
.46063 .67443 m .4578 .67473 L .45765 .67162 L F
0 0 .191 r
.52773 .60608 m .52798 .60245 L .5273 .60383 L F
.514 .557 .837 r
.77756 .48755 m .77575 .48968 L .7746 .48681 L F
.77756 .48755 m .77811 .48938 L .77575 .48968 L F
.633 .609 .809 r
.77811 .48938 m .77598 .49186 L .77575 .48968 L F
.245 0 .004 r
.488 .61986 m .49069 .61816 L .48884 .619 L F
.066 0 .29 r
.4754 .63833 m .47488 .64058 L .47672 .63732 L F
.621 .306 .415 r
.51206 .65765 m .51125 .66013 L .50894 .65821 L F
.587 .284 .422 r
.51441 .65758 m .51125 .66013 L .51206 .65765 L F
.979 .78 .566 r
.65831 .50855 m .65679 .50839 L .65754 .50663 L F
.537 .228 .391 r
.65754 .50663 m .65948 .50674 L .65859 .50598 L F
.824 .805 .833 r
.66184 .50603 m .66045 .50756 L .65951 .50676 L F
.65946 .50599 m .65951 .50676 L .65859 .50598 L F
.66184 .50603 m .65951 .50676 L .65946 .50599 L F
.738 .973 .928 r
.65954 .5071 m .65831 .50855 L .65963 .50846 L F
.824 .805 .833 r
.66045 .50756 m .65963 .50846 L .65914 .50728 L F
.537 .228 .391 r
.65754 .50663 m .65679 .50839 L .65713 .5082 L F
.824 .805 .833 r
.65978 .50699 m .65903 .50702 L .65948 .50674 L F
.481 .618 .909 r
.65859 .50598 m .65848 .50698 L .65754 .50663 L F
.65848 .50698 m .65831 .50855 L .65754 .50663 L F
.537 .228 .391 r
.65948 .50674 m .65887 .50712 L .65983 .50675 L F
.738 .973 .928 r
.65954 .5071 m .65913 .50729 L .65831 .50855 L F
.481 .618 .909 r
.65848 .50698 m .65895 .50758 L .65831 .50855 L F
.65903 .50702 m .65914 .50728 L .65848 .50698 L F
.65914 .50728 m .65963 .50846 L .65895 .50758 L F
.65914 .50728 m .65895 .50758 L .65848 .50698 L F
.738 .973 .928 r
.65983 .50675 m .6593 .50704 L .65954 .5071 L F
.6593 .50704 m .65713 .5082 L .65914 .50728 L F
.824 .805 .833 r
.65978 .50699 m .65914 .50728 L .65903 .50702 L F
.738 .973 .928 r
.6593 .50704 m .65914 .50728 L .65954 .5071 L F
.65913 .50729 m .65679 .50839 L .65831 .50855 L F
.481 .618 .909 r
.65895 .50758 m .65963 .50846 L .65831 .50855 L F
.537 .228 .391 r
.65747 .50689 m .65903 .50702 L .65948 .50674 L F
.481 .618 .909 r
.65859 .50598 m .65903 .50702 L .65848 .50698 L F
.537 .228 .391 r
.65754 .50663 m .65747 .50689 L .65948 .50674 L F
.65747 .50689 m .65713 .5082 L .65903 .50702 L F
.65887 .50712 m .65713 .5082 L .65904 .50718 L F
.65887 .50712 m .65904 .50718 L .65983 .50675 L F
.824 .805 .833 r
.65948 .50674 m .65903 .50702 L .65859 .50598 L F
.66045 .50756 m .65914 .50728 L .65978 .50699 L F
.738 .973 .928 r
.65713 .5082 m .65679 .50839 L .65954 .5071 L F
.65983 .50675 m .65954 .5071 L .65963 .50846 L F
.537 .228 .391 r
.65948 .50674 m .65983 .50675 L .65859 .50598 L F
.64 .738 .92 r
.28989 .62181 m .28835 .62148 L .2891 .62078 L F
0 0 0 r
.2891 .62078 m .28797 .6225 L .28995 .62 L F
.83 .783 .807 r
.29026 .6196 m .28989 .62181 L .2891 .62078 L F
0 0 0 r
.2891 .62078 m .28995 .62 L .29026 .6196 L F
.64 .738 .92 r
.28835 .62148 m .28627 .62103 L .2891 .62078 L F
.83 .783 .807 r
.29026 .6196 m .29152 .62322 L .28989 .62181 L F
.876 .442 .147 r
.57473 .6724 m .57382 .67324 L .57363 .67157 L F
.57473 .6724 m .57573 .67485 L .57382 .67324 L F
.514 .108 .208 r
.76793 .52052 m .76722 .52241 L .76451 .52127 L F
.654 .311 .378 r
.7703 .52047 m .76722 .52241 L .76793 .52052 L F
.835 .794 .813 r
.58951 .56551 m .59127 .56444 L .59275 .56396 L F
.815 .576 .578 r
.59263 .56513 m .59275 .56396 L .59127 .56444 L F
.59263 .56513 m .59532 .56375 L .59275 .56396 L F
.736 .351 .323 r
.73944 .47467 m .74158 .47644 L .74312 .47538 L F
.497 .848 .994 r
.74104 .47549 m .74182 .47548 L .74158 .47644 L F
.764 .985 .748 r
.74158 .47644 m .74136 .4773 L .74312 .47538 L F
.908 .658 .548 r
.74312 .47538 m .74327 .47798 L .74158 .47644 L F
.286 .514 .9 r
.74614 .47545 m .74446 .47623 L .74312 .47538 L F
.696 .491 .607 r
.74446 .47623 m .74327 .47798 L .74312 .47538 L F
.286 .514 .9 r
.74614 .47545 m .74312 .47538 L .74158 .47644 L F
.497 .848 .994 r
.74182 .47548 m .74614 .47545 L .74158 .47644 L F
.764 .985 .748 r
.74158 .47644 m .74051 .47823 L .74136 .4773 L F
.534 .674 .928 r
.74158 .47644 m .74327 .47798 L .74051 .47823 L F
.276 0 0 r
.3524 .58472 m .35572 .58572 L .35352 .58544 L F
.795 .455 .414 r
.47357 .70454 m .47742 .70319 L .47318 .70309 L F
.47357 .70454 m .47548 .70574 L .47742 .70319 L F
.327 .323 .702 r
.48129 .70259 m .47983 .70441 L .47906 .70056 L F
.469 .368 .658 r
.47742 .70319 m .47997 .70402 L .47906 .70056 L F
.769 .586 .651 r
.47548 .70574 m .47997 .70402 L .47742 .70319 L F
.718 .723 .854 r
.50284 .64338 m .49981 .64443 L .49921 .64334 L F
.683 .621 .78 r
.49921 .64334 m .50063 .64672 L .50415 .64458 L F
0 0 0 r
.50089 .64896 m .50415 .64458 L .50063 .64672 L F
.826 .78 .275 r
.61888 .60393 m .61835 .60549 L .61893 .60612 L F
.61888 .60393 m .61886 .60324 L .61835 .60549 L F
.755 .475 .508 r
.59986 .56081 m .6036 .5634 L .60345 .56108 L F
.695 .439 .532 r
.60345 .56108 m .6036 .5634 L .60723 .56337 L F
.258 .735 .937 r
.34046 .58392 m .34257 .58378 L .3442 .58431 L F
.223 .734 .884 r
.34257 .58378 m .34632 .58384 L .3442 .58431 L F
.67 .557 .719 r
.77945 .49278 m .77702 .49539 L .77598 .49186 L F
.513 .327 .566 r
.70628 .47223 m .70566 .469 L .70539 .47099 L F
.70628 .47223 m .70897 .46948 L .70566 .469 L F
.70628 .47223 m .70867 .47197 L .70897 .46948 L F
.496 .335 .591 r
.42422 .67803 m .42633 .67756 L .42632 .67505 L F
.459 .301 .578 r
.42439 .68035 m .42633 .67756 L .42422 .67803 L F
.642 .556 .743 r
.49589 .78896 m .49676 .79242 L .49855 .79007 L F
.51 .492 .773 r
.50783 .79544 m .50969 .79797 L .50806 .79446 L F
.326 0 .188 r
.45178 .65788 m .44961 .65853 L .44892 .66006 L F
.475 .181 .387 r
.45178 .65788 m .45409 .65743 L .45486 .65468 L F
.454 .14 .342 r
.45409 .65743 m .45714 .65449 L .45486 .65468 L F
.654 .655 .839 r
.28931 .62543 m .29324 .6239 L .29152 .62322 L F
.28931 .62543 m .29297 .62606 L .29324 .6239 L F
.53 .283 .485 r
.29297 .62606 m .2952 .62573 L .29324 .6239 L F
.546 .281 .465 r
.29324 .6239 m .2952 .62573 L .2958 .62332 L F
.293 .415 .815 r
.73234 .5204 m .73384 .51881 L .73058 .51767 L F
.73234 .5204 m .73386 .52061 L .73384 .51881 L F
.005 0 0 r
.75563 .52565 m .75361 .52593 L .75665 .52448 L F
.397 0 .081 r
.75904 .52374 m .75563 .52565 L .75665 .52448 L F
.206 .278 .717 r
.74836 .48588 m .74903 .48937 L .75032 .48768 L F
.426 .592 .912 r
.74903 .48937 m .75154 .48949 L .75032 .48768 L F
.227 0 .119 r
.46502 .64899 m .4669 .64886 L .46792 .64674 L F
.332 0 .171 r
.46792 .64674 m .46906 .64833 L .46955 .64573 L F
.46792 .64674 m .4669 .64886 L .46906 .64833 L F
.459 .153 .358 r
.57366 .5751 m .57596 .57464 L .57666 .57212 L F
.551 .238 .39 r
.57666 .57212 m .5791 .57341 L .57904 .57196 L F
.57666 .57212 m .57596 .57464 L .5791 .57341 L F
.524 .333 .564 r
.47753 .67813 m .4799 .68016 L .4776 .68061 L F
.47753 .67813 m .4799 .68016 L .4776 .68061 L F
.541 .351 .573 r
.50896 .66023 m .50734 .65872 L .50894 .65821 L F
.602 .314 .451 r
.50894 .65821 m .51125 .66013 L .50896 .66023 L F
.781 .821 .884 r
.73899 .48356 m .74175 .48398 L .74112 .48242 L F
.858 .913 .869 r
.73818 .48574 m .74175 .48398 L .73899 .48356 L F
.485 .65 .932 r
.74112 .48242 m .74175 .48398 L .74322 .48217 L F
.568 .776 .977 r
.74175 .48398 m .74419 .48345 L .74322 .48217 L F
.538 .608 .871 r
.32868 .64964 m .32976 .64677 L .32749 .64603 L F
.32868 .64964 m .33093 .64942 L .32976 .64677 L F
.666 .692 .865 r
.70715 .49111 m .70802 .4927 L .71014 .49171 L F
0 0 0 r
.53064 .60021 m .53176 .59929 L .52897 .60059 L F
.02 0 0 r
.53064 .60021 m .52897 .60059 L .52798 .60245 L F
.658 .658 .838 r
.75463 .48977 m .75836 .49215 L .75704 .48915 L F
.604 .685 .899 r
.75836 .49215 m .75913 .48884 L .75704 .48915 L F
.75836 .49215 m .76089 .49172 L .75913 .48884 L F
.486 .865 .98 r
.52742 .63559 m .52952 .63506 L .53088 .63545 L F
.439 0 0 r
.52952 .63506 m .53317 .63501 L .53088 .63545 L F
.633 .609 .809 r
.77811 .48938 m .77945 .49278 L .77598 .49186 L F
.286 0 .116 r
.38173 .63073 m .38093 .62923 L .38295 .62878 L F
.38173 .63073 m .37962 .63135 L .38093 .62923 L F
.653 .458 .608 r
.543 .66382 m .54284 .66664 L .541 .66587 L F
.745 .597 .692 r
.5455 .66318 m .54284 .66664 L .543 .66382 L F
.389 .001 .177 r
.38201 .61189 m .38432 .61145 L .38541 .6095 L F
.406 .018 .186 r
.38541 .6095 m .3868 .6108 L .38781 .60935 L F
.38541 .6095 m .38432 .61145 L .3868 .6108 L F
.543 .542 .804 r
.21 .56294 m .2088 .56388 L .20932 .56303 L F
.21 .56294 m .20921 .56661 L .2088 .56388 L F
.528 .05 .063 r
.47576 .7093 m .47472 .71081 L .47218 .70955 L F
.687 .218 .133 r
.47576 .7093 m .47664 .71162 L .47472 .71081 L F
.47576 .7093 m .47804 .71116 L .47664 .71162 L F
.629 .29 .379 r
.47817 .7096 m .47804 .71116 L .47576 .7093 L F
.499 0 0 r
.50741 .62474 m .50925 .62639 L .51045 .62734 L F
.83 .388 0 r
.50925 .62639 m .51099 .62858 L .51045 .62734 L F
.317 .725 .978 r
.37685 .58646 m .37894 .58643 L .38045 .58726 L F
.369 .759 .988 r
.37894 .58643 m .38265 .58709 L .38045 .58726 L F
.704 .491 .597 r
.55112 .66084 m .54769 .66248 L .54734 .66071 L F
.881 .55 .048 r
.73004 .51528 m .72963 .51534 L .72781 .51307 L F
.73004 .51528 m .73058 .51767 L .72963 .51534 L F
.485 .788 .998 r
.51241 .64666 m .51331 .64523 L .5111 .64547 L F
.51241 .64666 m .51489 .64635 L .51331 .64523 L F
.441 .29 .579 r
.51241 .64666 m .51458 .64853 L .51489 .64635 L F
.51241 .64666 m .51272 .64934 L .51458 .64853 L F
0 .481 .852 r
.54248 .6402 m .54648 .64208 L .54315 .64174 L F
.349 .426 .799 r
.32517 .61456 m .3248 .61808 L .32309 .61496 L F
.32517 .61456 m .32681 .61867 L .3248 .61808 L F
.31 .451 .841 r
.32681 .61867 m .32706 .61952 L .3248 .61808 L F
.792 .585 .621 r
.67074 .48604 m .67289 .48403 L .67042 .48385 L F
.67074 .48604 m .67408 .48692 L .67289 .48403 L F
.592 .49 .706 r
.67289 .48403 m .67408 .48692 L .6763 .48594 L F
.725 .671 .797 r
.28726 .62628 m .29161 .62812 L .28931 .62543 L F
.654 .655 .839 r
.28931 .62543 m .29161 .62812 L .29297 .62606 L F
.737 .445 0 r
.29161 .62812 m .29136 .62774 L .29297 .62606 L F
.29161 .62812 m .2922 .63036 L .29136 .62774 L F
.898 .554 .074 r
.29161 .62812 m .29261 .63092 L .2922 .63036 L F
.441 .154 .379 r
.39902 .61796 m .39846 .62041 L .39626 .62087 L F
.421 .136 .372 r
.40061 .6198 m .39902 .61796 L .40122 .61774 L F
.40061 .6198 m .39846 .62041 L .39902 .61796 L F
.674 .866 .972 r
.67213 .50711 m .67535 .50706 L .67439 .50613 L F
.538 .71 .951 r
.67535 .50706 m .67671 .50515 L .67439 .50613 L F
.67535 .50706 m .67775 .50675 L .67671 .50515 L F
0 .23 .707 r
.57122 .63601 m .56953 .63521 L .56849 .63418 L F
.57122 .63601 m .57245 .63722 L .56953 .63521 L F
.413 .011 .164 r
.43302 .66365 m .43425 .66452 L .4355 .66414 L F
.43302 .66365 m .43191 .66491 L .43425 .66452 L F
.391 0 0 r
.58169 .67762 m .58071 .67791 L .57831 .67738 L F
0 0 0 r
.58384 .67708 m .58071 .67791 L .58169 .67762 L F
.005 0 0 r
.75563 .52565 m .75329 .52631 L .75361 .52593 L F
.815 .891 .898 r
.5222 .67497 m .52084 .67468 L .52353 .67266 L F
.472 .338 .616 r
.52312 .67668 m .5222 .67497 L .52445 .67574 L F
.52312 .67668 m .52084 .67468 L .5222 .67497 L F
.693 .243 .178 r
.47515 .66927 m .47841 .66977 L .47734 .67125 L F
.544 .073 .088 r
.47734 .67125 m .47841 .66977 L .48142 .67117 L F
.506 .093 .191 r
.4889 .65161 m .49128 .65158 L .49257 .64988 L F
.381 0 .11 r
.49257 .64988 m .49128 .65158 L .49367 .65116 L F
.464 .427 .731 r
.76226 .49516 m .76361 .49139 L .76089 .49172 L F
.76226 .49516 m .76424 .49453 L .76361 .49139 L F
.483 .395 .68 r
.76226 .49516 m .76484 .49695 L .76424 .49453 L F
.76226 .49516 m .76232 .49846 L .76484 .49695 L F
.524 .492 .763 r
.7853 .49575 m .7824 .4964 L .78176 .49186 L F
.628 .537 .732 r
.7853 .49575 m .78302 .49762 L .7824 .4964 L F
.752 .699 .802 r
.66376 .51126 m .66692 .51147 L .66688 .50894 L F
.817 .872 .887 r
.66688 .50894 m .66692 .51147 L .6695 .50908 L F
.411 .175 .443 r
.49503 .7822 m .49651 .78308 L .49667 .78058 L F
.49503 .7822 m .49449 .78404 L .49651 .78308 L F
.49651 .78308 m .49503 .7822 L .49667 .78058 L F
.49651 .78308 m .49449 .78404 L .49503 .7822 L F
0 .435 .835 r
.52255 .63358 m .52171 .63378 L .51998 .63288 L F
.52255 .63358 m .52378 .63455 L .52171 .63378 L F
.584 .185 .252 r
.76451 .52127 m .76461 .52255 L .7612 .52294 L F
.511 .131 .256 r
.76451 .52127 m .76722 .52241 L .76461 .52255 L F
.536 .827 .999 r
.51547 .70395 m .51884 .70422 L .51808 .70407 L F
.112 0 0 r
.51547 .70395 m .51725 .70414 L .51884 .70422 L F
.667 .187 .103 r
.51789 .70576 m .51884 .70422 L .51725 .70414 L F
.51789 .70576 m .52214 .70645 L .51884 .70422 L F
.66 .53 .695 r
.57998 .66036 m .57786 .65873 L .58013 .65802 L F
.57998 .66036 m .57806 .66103 L .57786 .65873 L F
.289 .206 .585 r
.60741 .63438 m .60777 .63703 L .60578 .63811 L F
.242 .12 .506 r
.60777 .63703 m .60585 .64053 L .60578 .63811 L F
.548 .744 .968 r
.77364 .48543 m .77214 .48719 L .77131 .48559 L F
.77364 .48543 m .7746 .48681 L .77214 .48719 L F
.351 .773 .976 r
.52929 .76401 m .52786 .76329 L .52547 .76355 L F
.741 .855 .933 r
.5287 .76207 m .52929 .76401 L .53181 .7619 L F
.901 .923 .825 r
.5287 .76207 m .52786 .76329 L .52929 .76401 L F
.685 .347 .397 r
.48159 .70944 m .47804 .71116 L .47817 .7096 L F
.48159 .70944 m .48066 .71201 L .47804 .71116 L F
.622 .281 .372 r
.48383 .71132 m .48066 .71201 L .48159 .70944 L F
.633 .276 .348 r
.48391 .70978 m .48383 .71132 L .48159 .70944 L F
.538 .355 .581 r
.47786 .654 m .4755 .65324 L .47706 .65146 L F
.47786 .654 m .47536 .65516 L .4755 .65324 L F
.362 .636 .959 r
.44005 .70846 m .44273 .70847 L .44276 .70825 L F
.601 .532 .749 r
.76309 .50088 m .76484 .49695 L .76232 .49846 L F
.143 .653 .9 r
.49133 .61828 m .49302 .61833 L .49435 .61884 L F
.1 .639 .853 r
.49302 .61833 m .49683 .61881 L .49435 .61884 L F
.592 .876 .993 r
.49169 .61865 m .49545 .61839 L .49302 .61833 L F
.1 .639 .853 r
.49302 .61833 m .49556 .61839 L .49683 .61881 L F
.592 .876 .993 r
.49545 .61839 m .49556 .61839 L .49302 .61833 L F
.143 .653 .9 r
.49069 .61816 m .49302 .61833 L .49133 .61828 L F
.713 .404 .453 r
.52552 .67151 m .52933 .66982 L .52578 .6697 L F
.52552 .67151 m .52898 .67172 L .52933 .66982 L F
.352 .236 .579 r
.52898 .67172 m .53055 .66816 L .52933 .66982 L F
.769 .494 .517 r
.66717 .48528 m .67074 .48604 L .67042 .48385 L F
0 0 0 r
.35607 .5979 m .35485 .59821 L .35256 .59866 L F
.235 .745 .715 r
.35687 .59759 m .35607 .5979 L .3583 .59788 L F
.35687 .59759 m .35485 .59821 L .35607 .5979 L F
.768 .351 .257 r
.4182 .70386 m .41783 .70299 L .41928 .70523 L F
0 0 .388 r
.41703 .70059 m .4182 .70386 L .41923 .69986 L F
.41703 .70059 m .41783 .70299 L .4182 .70386 L F
.589 .802 .981 r
.38852 .58833 m .39214 .58886 L .38987 .5895 L F
.93 .763 .653 r
.44904 .68024 m .44776 .68043 L .45066 .67807 L F
.446 .797 .998 r
.68376 .5069 m .68003 .50636 L .68141 .50758 L F
0 .18 .697 r
.57611 .64807 m .57554 .64951 L .57438 .64621 L F
.803 .665 .711 r
.57611 .64807 m .57827 .65096 L .57554 .64951 L F
.681 .763 .913 r
.73771 .51054 m .73628 .51294 L .73537 .51121 L F
.73771 .51054 m .7387 .51212 L .73628 .51294 L F
.1 0 0 r
.56849 .57772 m .57076 .57666 L .5713 .5756 L F
.473 .096 .242 r
.57076 .57666 m .57366 .5751 L .5713 .5756 L F
.785 .468 .452 r
.50413 .63513 m .50596 .63806 L .50282 .63737 L F
.837 .469 .357 r
.50755 .63805 m .50596 .63806 L .50413 .63513 L F
.324 0 0 r
.67877 .48579 m .68122 .48543 L .68211 .48414 L F
.357 0 0 r
.68211 .48414 m .68393 .48498 L .6841 .48281 L F
.68211 .48414 m .68122 .48543 L .68393 .48498 L F
0 0 .392 r
.29247 .63195 m .2922 .63036 L .29261 .63092 L F
.562 .419 .645 r
.51396 .68092 m .51627 .68106 L .5168 .67851 L F
.804 .962 .64 r
.52503 .67404 m .52445 .67574 L .52694 .67482 L F
.52503 .67404 m .52312 .67668 L .52445 .67574 L F
.529 .626 .892 r
.40364 .59188 m .40293 .59479 L .40129 .59205 L F
.40364 .59188 m .40505 .59446 L .40293 .59479 L F
.401 0 0 r
.43009 .70562 m .42863 .70558 L .42652 .70489 L F
.312 .801 .867 r
.43084 .70507 m .43009 .70562 L .43235 .7035 L F
.43084 .70507 m .42863 .70558 L .43009 .70562 L F
.165 0 0 r
.36456 .63749 m .36354 .63821 L .36138 .6386 L F
.11 0 0 r
.36551 .63809 m .36456 .63749 L .36675 .63693 L F
.36551 .63809 m .36354 .63821 L .36456 .63749 L F
0 0 .066 r
.47749 .63542 m .47672 .63732 L .47883 .6342 L F
.895 .658 .572 r
.6142 .56932 m .61421 .57202 L .61578 .57231 L F
.88 .561 .443 r
.61421 .57202 m .61433 .574 L .61578 .57231 L F
.874 .552 .438 r
.61433 .574 m .61621 .57482 L .61578 .57231 L F
.431 .1 .302 r
.39352 .62314 m .39043 .62609 L .39156 .62306 L F
.494 .238 .455 r
.36432 .62358 m .36656 .62312 L .36694 .62096 L F
.506 .249 .458 r
.36656 .62312 m .36881 .62271 L .36694 .62096 L F
.489 .25 .479 r
.36694 .62096 m .36881 .62271 L .36913 .62047 L F
.273 0 0 r
.58676 .56611 m .58951 .56551 L .58719 .56583 L F
.299 .792 .869 r
.76142 .51225 m .75994 .51298 L .75879 .513 L F
.76142 .51225 m .76239 .51247 L .75994 .51298 L F
.201 .715 .885 r
.35572 .58572 m .35791 .58561 L .35938 .58589 L F
0 .564 .779 r
.35791 .58561 m .36156 .58611 L .35938 .58589 L F
.966 .899 .529 r
.6019 .60665 m .60143 .60595 L .60231 .6026 L F
.958 .931 .598 r
.60049 .60824 m .6019 .60665 L .60202 .60897 L F
.60049 .60824 m .60143 .60595 L .6019 .60665 L F
.659 .838 .969 r
.79396 .51993 m .79143 .52096 L .7904 .51986 L F
0 .182 .634 r
.79143 .52096 m .79226 .52143 L .7904 .51986 L F
.79143 .52096 m .79405 .52276 L .79226 .52143 L F
.62 .073 0 r
.50923 .70641 m .51165 .70797 L .51325 .70735 L F
.492 .37 .641 r
.32285 .61144 m .32309 .61496 L .32107 .61538 L F
.216 0 0 r
.37564 .63289 m .37453 .63408 L .37258 .63454 L F
.268 0 .079 r
.37764 .63216 m .37453 .63408 L .37564 .63289 L F
.454 .232 .485 r
.50907 .75761 m .50678 .76041 L .50705 .75809 L F
.50907 .75761 m .50678 .76041 L .50705 .75809 L F
.976 .92 .664 r
.73818 .48574 m .73687 .48909 L .73762 .48962 L F
.798 .588 .617 r
.73526 .49119 m .73762 .48962 L .73687 .48909 L F
.73526 .49119 m .7374 .49212 L .73762 .48962 L F
.541 .351 .573 r
.50896 .66023 m .50629 .66077 L .50734 .65872 L F
.749 .885 .477 r
.60175 .62081 m .60219 .6195 L .6035 .61729 L F
0 0 0 r
.60122 .62268 m .60219 .6195 L .60175 .62081 L F
.59105 .67376 m .58953 .67423 L .59251 .67283 L F
.59105 .67376 m .58923 .67497 L .58953 .67423 L F
.78 .732 .808 r
.50522 .79283 m .50615 .79514 L .50787 .79203 L F
.204 0 .044 r
.46284 .68131 m .45997 .68308 L .46194 .68121 L F
.993 .761 .398 r
.60202 .60897 m .60278 .61247 L .60148 .61007 L F
.716 .4 0 r
.60278 .61247 m .60312 .61378 L .60148 .61007 L F
.60278 .61247 m .60353 .61479 L .60312 .61378 L F
.299 .627 .962 r
.7564 .51307 m .75367 .51276 L .75274 .51155 L F
.999 .809 .515 r
.50755 .63805 m .5062 .63969 L .50596 .63806 L F
.50755 .63805 m .507 .64052 L .5062 .63969 L F
.736 .62 .73 r
.66677 .49513 m .66349 .4953 L .66584 .49214 L F
.48 0 0 r
.66677 .49513 m .6664 .49607 L .66349 .4953 L F
.62 .553 .758 r
.66956 .49452 m .66677 .49513 L .66584 .49214 L F
.424 0 .09 r
.66956 .49452 m .6664 .49607 L .66677 .49513 L F
.442 .546 .867 r
.40855 .59731 m .40665 .59726 L .40505 .59446 L F
0 0 .019 r
.47976 .63257 m .47883 .6342 L .4813 .63155 L F
.769 .67 .754 r
.48412 .65719 m .48308 .6542 L .48432 .65525 L F
.333 .129 .446 r
.53837 .70492 m .53659 .70383 L .53929 .704 L F
.53837 .70492 m .5365 .70606 L .53659 .70383 L F
.579 .774 .972 r
.38276 .59661 m .38554 .5975 L .38438 .59589 L F
.486 .765 .993 r
.38438 .59589 m .38554 .5975 L .38783 .597 L F
.598 .822 .985 r
.45711 .68308 m .45785 .68396 L .45997 .68308 L F
.38 .267 .599 r
.28664 .60628 m .28829 .60577 L .28807 .60335 L F
.408 .343 .672 r
.28686 .60951 m .28829 .60577 L .28664 .60628 L F
.693 .803 .934 r
.75154 .48949 m .75224 .49069 L .75463 .48977 L F
.174 0 0 r
.71249 .47631 m .71598 .47568 L .71238 .47442 L F
0 0 0 r
.71479 .47623 m .7139 .47754 L .7146 .47681 L F
.174 0 0 r
.7149 .47587 m .71479 .47623 L .71598 .47568 L F
.477 .871 .689 r
.71598 .47568 m .71479 .47623 L .71753 .47445 L F
0 0 0 r
.71479 .47623 m .7146 .47681 L .7167 .47462 L F
.174 0 0 r
.71249 .47631 m .71479 .47623 L .7149 .47587 L F
.477 .871 .689 r
.71598 .47568 m .71753 .47445 L .71852 .47496 L F
.749 .869 .935 r
.72909 .49715 m .73324 .49636 L .73159 .49453 L F
.822 .767 .801 r
.73159 .49453 m .73324 .49636 L .73426 .49462 L F
.565 .514 .757 r
.49449 .78406 m .49589 .78896 L .49752 .78845 L F
.642 .556 .743 r
.49589 .78896 m .49855 .79007 L .49752 .78845 L F
0 .061 .599 r
.71564 .49799 m .71633 .49661 L .71533 .49465 L F
.081 .268 .755 r
.71564 .49799 m .71742 .4996 L .71633 .49661 L F
.333 0 .211 r
.46211 .65183 m .46424 .65122 L .46502 .64899 L F
.283 0 .19 r
.46502 .64899 m .46627 .65051 L .4669 .64886 L F
.46502 .64899 m .46424 .65122 L .46627 .65051 L F
.543 .542 .804 r
.21 .56294 m .21118 .56603 L .20921 .56661 L F
.447 .266 .542 r
.21118 .56603 m .20908 .56903 L .20921 .56661 L F
.498 .014 .037 r
.71129 .47 m .71409 .47093 L .71468 .46949 L F
.966 .712 .278 r
.71468 .46949 m .71409 .47093 L .71479 .47181 L F
.769 .928 .566 r
.57331 .63827 m .57211 .63951 L .57201 .64029 L F
1 .826 .519 r
.57245 .63722 m .57211 .63951 L .57331 .63827 L F
.691 .495 .617 r
.50119 .6575 m .50204 .65822 L .50051 .65497 L F
.144 .654 .9 r
.30741 .63492 m .30604 .63441 L .30358 .63416 L F
.572 .887 .99 r
.30795 .63359 m .30741 .63492 L .30967 .63435 L F
.30795 .63359 m .30604 .63441 L .30741 .63492 L F
.689 .725 .878 r
.74688 .50944 m .74478 .51053 L .74347 .50853 L F
.575 .41 .62 r
.585 .65233 m .58723 .65189 L .58724 .64936 L F
.664 .435 .562 r
.58739 .6542 m .585 .65233 L .58723 .65189 L F
.58739 .6542 m .58497 .65468 L .585 .65233 L F
0 0 0 r
.58497 .65468 m .58723 .65189 L .585 .65233 L F
.575 .41 .62 r
.585 .65233 m .58723 .65189 L .58724 .64936 L F
0 0 .288 r
.61322 .62055 m .61351 .62272 L .61195 .62382 L F
.094 0 .354 r
.61351 .62272 m .61127 .62601 L .61195 .62382 L F
0 0 .365 r
.57211 .63951 m .57297 .64301 L .57201 .64029 L F
.776 .63 .699 r
.67167 .49218 m .67291 .49544 L .66956 .49452 L F
.843 .608 .583 r
.67251 .49706 m .66956 .49452 L .67291 .49544 L F
.362 .824 .917 r
.36459 .59675 m .36046 .59725 L .36131 .5973 L F
.843 .608 .583 r
.67251 .49706 m .66965 .49756 L .66956 .49452 L F
.862 .824 .809 r
.67251 .49706 m .67108 .49895 L .66965 .49756 L F
.831 .733 .756 r
.73374 .49148 m .73426 .49462 L .73485 .4932 L F
.69 .716 .869 r
.73374 .49148 m .73485 .4932 L .7374 .49212 L F
.458 .68 .96 r
.77047 .48413 m .76905 .48571 L .76753 .48402 L F
.77047 .48413 m .77131 .48559 L .76905 .48571 L F
.294 0 0 r
.35283 .62684 m .35497 .62676 L .35616 .62605 L F
.112 0 0 r
.35497 .62676 m .35851 .62575 L .35616 .62605 L F
.589 .482 .699 r
.43055 .66903 m .43191 .66491 L .43027 .66669 L F
.408 .343 .672 r
.28686 .60951 m .28876 .60925 L .28829 .60577 L F
.567 .418 .639 r
.28686 .60951 m .28942 .61137 L .28876 .60925 L F
.28686 .60951 m .2871 .61199 L .28942 .61137 L F
0 0 .171 r
.57069 .66613 m .57061 .66507 L .57016 .66272 L F
.684 .373 0 r
.57069 .66613 m .57109 .66744 L .57061 .66507 L F
.57069 .66613 m .57157 .66879 L .57109 .66744 L F
0 0 0 r
.59316 .67276 m .59251 .67283 L .5947 .67213 L F
.59316 .67276 m .59105 .67376 L .59251 .67283 L F
.323 0 .063 r
.30286 .58868 m .30504 .58828 L .30583 .58713 L F
.447 .064 .218 r
.30504 .58828 m .30816 .58665 L .30583 .58713 L F
.745 .597 .692 r
.5455 .66318 m .54713 .66722 L .54284 .66664 L F
.846 .544 .477 r
.54713 .66722 m .54492 .66872 L .54284 .66664 L F
.54713 .66722 m .5467 .66902 L .54492 .66872 L F
.543 .461 .713 r
.54769 .66248 m .54713 .66722 L .5455 .66318 L F
.54769 .66248 m .54973 .66666 L .54713 .66722 L F
.62 .312 .427 r
.54904 .66856 m .54713 .66722 L .54973 .66666 L F
.54904 .66856 m .5467 .66902 L .54713 .66722 L F
.815 .576 .578 r
.59263 .56513 m .59553 .56626 L .59532 .56375 L F
.461 .277 .544 r
.59532 .56375 m .59795 .5606 L .5961 .56279 L F
.59532 .56375 m .59788 .56311 L .59795 .5606 L F
.456 .309 .592 r
.59532 .56375 m .5975 .56527 L .59788 .56311 L F
.59532 .56375 m .59553 .56626 L .5975 .56527 L F
.7 .871 .962 r
.67108 .49895 m .66573 .49881 L .66965 .49756 L F
.474 .224 .455 r
.37731 .61505 m .37949 .61455 L .37988 .6124 L F
.467 .219 .454 r
.37949 .61455 m .38201 .61189 L .37988 .6124 L F
.283 .062 .391 r
.68441 .48089 m .68606 .48172 L .68664 .48007 L F
.68441 .48089 m .6841 .48281 L .68606 .48172 L F
.561 .132 .184 r
.4355 .66414 m .43759 .66559 L .43876 .66366 L F
.737 .332 .283 r
.43876 .66366 m .43759 .66559 L .44107 .66586 L F
.638 .378 .509 r
.44107 .66586 m .4413 .66364 L .43876 .66366 L F
.646 .376 .496 r
.541 .66587 m .53713 .66881 L .53716 .66645 L F
.541 .66587 m .5412 .66931 L .53713 .66881 L F
.608 .347 .497 r
.54445 .66836 m .541 .66587 L .54284 .66664 L F
.54445 .66836 m .5412 .66931 L .541 .66587 L F
.691 .244 .184 r
.53317 .63501 m .53546 .63687 L .53658 .63556 L F
.747 .315 .225 r
.53546 .63687 m .53861 .63759 L .53658 .63556 L F
.522 .575 .85 r
.50096 .78966 m .50239 .79249 L .50394 .79089 L F
.537 .601 .865 r
.50239 .79249 m .50522 .79283 L .50394 .79089 L F
.612 .347 .491 r
.58382 .56873 m .58676 .56611 L .58437 .567 L F
.473 .17 .37 r
.41192 .6089 m .4111 .61143 L .40882 .61187 L F
.497 .196 .385 r
.41421 .6086 m .4111 .61143 L .41192 .6089 L F
.1 .656 .76 r
.36156 .58611 m .36379 .58594 L .36518 .58592 L F
.337 .818 .865 r
.36518 .58592 m .36592 .58537 L .36736 .58576 L F
.36518 .58592 m .36379 .58594 L .36592 .58537 L F
.851 .542 .012 r
.79745 .52322 m .79854 .52659 L .79817 .52618 L F
.546 .134 .212 r
.79745 .52322 m .79895 .52413 L .79854 .52659 L F
.913 .955 .621 r
.79817 .52618 m .79854 .52659 L .79895 .52413 L F
.683 .621 .78 r
.49921 .64334 m .50415 .64458 L .50284 .64338 L F
.426 .261 .553 r
.50415 .64458 m .5055 .64315 L .50284 .64338 L F
.704 .491 .597 r
.55112 .66084 m .55374 .66395 L .54769 .66248 L F
.295 .771 .928 r
.51999 .68112 m .51916 .68072 L .51627 .68106 L F
.7 .974 .921 r
.52081 .67958 m .51916 .68072 L .51999 .68112 L F
0 0 .293 r
.61536 .61717 m .61494 .61942 L .61322 .62055 L F
0 0 .224 r
.61494 .61942 m .61351 .62272 L .61322 .62055 L F
.126 .307 .776 r
.55701 .65344 m .55615 .65462 L .55482 .6516 L F
.18 .385 .828 r
.55701 .65344 m .55889 .6565 L .55615 .65462 L F
.244 .301 .724 r
.56391 .59684 m .56399 .59993 L .56502 .59836 L F
0 0 .045 r
.48422 .62671 m .48203 .62956 L .48341 .62845 L F
.057 0 .21 r
.4813 .63155 m .48341 .62845 L .48203 .62956 L F
.841 .739 .752 r
.61679 .5807 m .61879 .57807 L .61566 .57723 L F
.974 .667 .311 r
.53758 .61813 m .53709 .62013 L .53707 .6171 L F
.53758 .61813 m .5383 .62113 L .53709 .62013 L F
.702 .625 .768 r
.7294 .50873 m .72697 .51229 L .72972 .512 L F
.347 0 0 r
.72972 .512 m .72939 .51234 L .72697 .51229 L F
.568 .445 .673 r
.7294 .50873 m .72939 .51234 L .72697 .51229 L F
.534 0 0 r
.72781 .51307 m .7258 .51198 L .72697 .51229 L F
.933 .965 .677 r
.65649 .48965 m .65493 .49275 L .65494 .4905 L F
.657 .948 .708 r
.65649 .48965 m .65782 .48791 L .65876 .48874 L F
.051 0 0 r
.66363 .48573 m .66717 .48528 L .66483 .48528 L F
.478 .233 .465 r
.33024 .60329 m .32967 .60579 L .32766 .60625 L F
.319 .027 .302 r
.33241 .60284 m .32967 .60579 L .33024 .60329 L F
.462 0 0 r
.3245 .58196 m .3274 .58286 L .32891 .58265 L F
.195 0 0 r
.32891 .58265 m .3274 .58286 L .33109 .5828 L F
0 .175 .61 r
.50224 .62093 m .50344 .62177 L .50054 .6198 L F
0 .056 .551 r
.50429 .62243 m .50344 .62177 L .50224 .62093 L F
.50429 .62243 m .50631 .6244 L .50344 .62177 L F
.877 .702 .661 r
.59626 .57764 m .5956 .58047 L .5942 .57749 L F
0 0 .003 r
.46912 .67004 m .46909 .6698 L .46908 .67096 L F
.443 .408 .724 r
.50824 .788 m .50778 .78797 L .5078 .78788 L F
.554 .418 .65 r
.50764 .78857 m .50954 .79036 L .51056 .78816 L F
.50764 .78857 m .51056 .78816 L .50966 .7891 L F
.797 .68 .735 r
.5098 .78811 m .51056 .78816 L .51013 .78813 L F
.5098 .78811 m .51013 .78813 L .50998 .78812 L F
.5098 .78811 m .50998 .78812 L .5097 .7881 L F
.455 .418 .728 r
.51017 .78922 m .50954 .79036 L .50957 .78908 L F
.554 .418 .65 r
.50957 .78908 m .50966 .7891 L .50966 .7891 L F
.50764 .78857 m .50966 .7891 L .50957 .78908 L F
.443 .408 .724 r
.50871 .78885 m .50954 .79036 L .50764 .78857 L F
.50959 .78809 m .50954 .79036 L .50824 .788 L F
.797 .68 .735 r
.50959 .78809 m .50966 .7891 L .51056 .78816 L F
.443 .408 .724 r
.5096 .78809 m .5096 .78819 L .50959 .78809 L F
.5096 .78819 m .50954 .79036 L .50959 .78809 L F
.554 .418 .65 r
.50764 .78857 m .50719 .79169 L .50787 .79203 L F
.50764 .78857 m .50966 .7891 L .50719 .79169 L F
.797 .68 .735 r
.50589 .78783 m .50719 .79169 L .50966 .7891 L F
.50966 .7891 m .50966 .7891 L .50966 .7891 L F
.443 .408 .724 r
.50824 .788 m .50871 .78885 L .50764 .78857 L F
.797 .68 .735 r
.50589 .78783 m .50966 .7891 L .50966 .7891 L F
.455 .418 .728 r
.50966 .7891 m .50957 .78908 L .5096 .78819 L F
.443 .408 .724 r
.50824 .788 m .50764 .78857 L .50778 .78797 L F
.797 .68 .735 r
.50589 .78783 m .50966 .7891 L .50959 .78809 L F
.455 .418 .728 r
.51017 .78922 m .50966 .7891 L .5096 .78809 L F
.50966 .7891 m .5096 .78819 L .5096 .78809 L F
.50994 .78812 m .5096 .78809 L .50964 .78666 L F
.797 .68 .735 r
.50959 .78809 m .5098 .78811 L .5097 .7881 L F
.455 .418 .728 r
.51017 .78922 m .5096 .78809 L .50994 .78812 L F
.797 .68 .735 r
.5096 .78809 m .5097 .7881 L .50969 .7881 L F
.50959 .78809 m .5097 .7881 L .5096 .78809 L F
.443 .408 .724 r
.50964 .78666 m .5096 .78809 L .50824 .788 L F
.797 .68 .735 r
.5097 .7881 m .50998 .78812 L .50817 .78799 L F
.455 .418 .728 r
.51084 .78799 m .51073 .78818 L .50964 .78666 L F
0 0 0 r
.51056 .78816 m .50954 .79036 L .51084 .78799 L F
.455 .418 .728 r
.51073 .78818 m .51017 .78922 L .50994 .78812 L F
.51073 .78818 m .50994 .78812 L .50964 .78666 L F
.797 .68 .735 r
.50589 .78783 m .50959 .78809 L .50817 .78799 L F
.50959 .78809 m .50969 .7881 L .50817 .78799 L F
.443 .408 .724 r
.50964 .78666 m .50824 .788 L .5078 .78788 L F
.656 .293 .344 r
.57373 .58932 m .57336 .59124 L .57123 .58926 L F
.387 0 .14 r
.57373 .58932 m .57528 .59065 L .57336 .59124 L F
.57373 .58932 m .57626 .58927 L .57528 .59065 L F
0 0 .312 r
.77392 .51158 m .7752 .5148 L .77446 .51299 L F
.413 .392 .726 r
.44557 .68493 m .44602 .68866 L .4436 .6869 L F
.394 .392 .739 r
.44602 .68866 m .4446 .68945 L .4436 .6869 L F
.944 .836 .707 r
.42595 .70442 m .42444 .70363 L .42559 .70085 L F
.495 0 0 r
.42595 .70442 m .42652 .70489 L .42444 .70363 L F
.191 0 0 r
.76495 .5119 m .76523 .51122 L .76239 .51247 L F
.529 .907 .743 r
.76841 .50918 m .76523 .51122 L .76715 .51099 L F
.05 0 0 r
.76715 .51099 m .76523 .51122 L .76495 .5119 L F
.646 .389 .515 r
.77562 .51708 m .77531 .5199 L .77288 .51998 L F
.533 .484 .748 r
.77751 .51445 m .77562 .51708 L .7752 .5148 L F
.77751 .51445 m .77806 .51738 L .77562 .51708 L F
.643 .441 .594 r
.77806 .51738 m .77531 .5199 L .77562 .51708 L F
0 .495 .801 r
.34632 .58384 m .34846 .58433 L .35006 .58499 L F
.394 .774 .991 r
.35076 .58393 m .35006 .58499 L .34846 .58433 L F
.35076 .58393 m .3524 .58472 L .35006 .58499 L F
.669 .629 .8 r
.78176 .49186 m .77945 .49278 L .77811 .48938 L F
.118 0 0 r
.53397 .59901 m .53176 .59929 L .53064 .60021 L F
.623 .544 .745 r
.31696 .64043 m .31787 .64476 L .31979 .64099 L F
.545 .767 .98 r
.67309 .48645 m .67408 .48692 L .67074 .48604 L F
.443 0 .074 r
.67309 .48645 m .6763 .48594 L .67408 .48692 L F
.229 .657 .957 r
.75807 .48112 m .75578 .4809 L .75475 .48007 L F
0 0 0 r
.34535 .64453 m .34518 .64435 L .34733 .64378 L F
.34535 .64453 m .34315 .64503 L .34518 .64435 L F
.397 .753 .993 r
.33674 .64698 m .33667 .64593 L .33534 .64611 L F
.33674 .64698 m .33887 .64681 L .33667 .64593 L F
.502 .292 .527 r
.51889 .78892 m .51898 .78649 L .51663 .78913 L F
.771 .621 .693 r
.6636 .49272 m .66349 .4953 L .66006 .4946 L F
.685 .547 .692 r
.66584 .49214 m .66349 .4953 L .6636 .49272 L F
.237 .753 .772 r
.56783 .59405 m .56583 .59462 L .5688 .59176 L F
.56783 .59405 m .5655 .59461 L .56583 .59462 L F
.55 .044 .005 r
.45682 .70931 m .4605 .70937 L .4594 .71035 L F
.566 .088 .079 r
.4605 .70937 m .46113 .71123 L .4594 .71035 L F
.4605 .70937 m .46273 .71068 L .46113 .71123 L F
.55 .143 .223 r
.46298 .70951 m .46273 .71068 L .4605 .70937 L F
.365 .239 .573 r
.42632 .67505 m .42796 .6746 L .42781 .67199 L F
.522 .416 .675 r
.42633 .67756 m .42796 .6746 L .42632 .67505 L F
.495 .42 .701 r
.49409 .64542 m .49579 .64753 L .49578 .64295 L F
.306 0 0 r
.3689 .63633 m .37258 .63454 L .3709 .63583 L F
.277 0 0 r
.37453 .63408 m .3709 .63583 L .37258 .63454 L F
.424 .407 .736 r
.42439 .68035 m .42515 .68359 L .42686 .6832 L F
.41 .35 .679 r
.42515 .68359 m .42738 .6856 L .42686 .6832 L F
.408 .35 .68 r
.42515 .68359 m .42581 .68623 L .42738 .6856 L F
.709 .729 .21 r
.55223 .64294 m .55135 .64638 L .55332 .64401 L F
.55223 .64294 m .55157 .64534 L .55135 .64638 L F
0 0 .317 r
.55222 .64763 m .55135 .64638 L .55157 .64534 L F
.55222 .64763 m .55155 .64897 L .55135 .64638 L F
.445 0 0 r
.49006 .65528 m .4911 .65612 L .48907 .6552 L F
.49006 .65528 m .49263 .65727 L .4911 .65612 L F
.485 .85 .99 r
.36736 .58576 m .36956 .58522 L .37111 .58575 L F
.223 .625 .955 r
.37177 .58497 m .37111 .58575 L .36956 .58522 L F
.37177 .58497 m .3732 .58608 L .37111 .58575 L F
.397 .1 .339 r
.40654 .61226 m .40594 .61427 L .40378 .61479 L F
.451 .138 .343 r
.40882 .61187 m .40594 .61427 L .40654 .61226 L F
.498 .425 .705 r
.77618 .51063 m .7752 .5148 L .77392 .51158 L F
.77618 .51063 m .77751 .51445 L .7752 .5148 L F
.135 .661 .875 r
.50629 .62429 m .50741 .62474 L .50631 .6244 L F
0 .138 .67 r
.50823 .62484 m .50741 .62474 L .50629 .62429 L F
.50823 .62484 m .50925 .62639 L .50741 .62474 L F
0 .249 .747 r
.74703 .48477 m .74827 .48509 L .74623 .48322 L F
.74703 .48477 m .74836 .48588 L .74827 .48509 L F
.107 0 0 r
.73188 .51197 m .72972 .512 L .72939 .51234 L F
.661 .136 0 r
.5243 .6639 m .52063 .66279 L .52185 .66399 L F
.669 .166 .041 r
.53411 .70684 m .53277 .70787 L .53063 .70609 L F
.215 0 0 r
.5365 .70606 m .53277 .70787 L .53411 .70684 L F
.423 .129 .359 r
.32539 .60915 m .32473 .61124 L .32285 .61144 L F
.548 .336 .545 r
.32712 .60853 m .32473 .61124 L .32539 .60915 L F
.547 .327 .533 r
.57123 .58926 m .57118 .59202 L .5688 .59176 L F
.536 .319 .532 r
.57123 .58926 m .57336 .59124 L .57118 .59202 L F
.707 .511 .621 r
.77635 .50928 m .77392 .51158 L .77379 .50921 L F
.529 .211 .373 r
.50181 .64972 m .50195 .65215 L .50216 .64951 L F
.50072 .65038 m .50103 .65083 L .50181 .64972 L F
.634 .857 .48 r
.50161 .65012 m .50073 .65125 L .49848 .6545 L F
.50073 .65125 m .49926 .65315 L .49867 .65418 L F
.50073 .65125 m .49867 .65418 L .49848 .6545 L F
.456 .088 .25 r
.50195 .65215 m .49926 .65315 L .50161 .65012 L F
.529 .211 .373 r
.50103 .65083 m .50195 .65215 L .50181 .64972 L F
.702 .516 .633 r
.50446 .65555 m .49926 .65315 L .50195 .65215 L F
.50446 .65555 m .49927 .65562 L .49926 .65315 L F
.424 .049 .221 r
.49942 .65395 m .50069 .6549 L .50195 .65215 L F
.1 0 0 r
.49927 .65562 m .49848 .6545 L .49924 .65318 L F
.49927 .65562 m .49924 .65318 L .49926 .65326 L F
.49927 .65562 m .49732 .65633 L .49848 .6545 L F
.424 .049 .221 r
.49725 .65548 m .49968 .65507 L .49942 .65395 L F
.49968 .65507 m .50069 .6549 L .49942 .65395 L F
.1 0 0 r
.49926 .65326 m .49924 .65318 L .49926 .65315 L F
.395 .717 .988 r
.5093 .76934 m .51184 .76939 L .51029 .76824 L F
.51029 .76824 m .51184 .76939 L .5093 .76934 L F
.312 .547 .916 r
.43608 .70583 m .43693 .70456 L .43407 .70383 L F
.43608 .70583 m .438 .70618 L .43693 .70456 L F
.206 0 .184 r
.29502 .5922 m .29241 .59475 L .29442 .59367 L F
.094 0 .129 r
.29502 .5922 m .29632 .59238 L .29719 .59173 L F
.29502 .5922 m .29442 .59367 L .29632 .59238 L F
.485 .29 .541 r
.50906 .66295 m .50629 .66077 L .50896 .66023 L F
.254 0 0 r
.34063 .59998 m .33668 .60123 L .33838 .60028 L F
.507 .818 .497 r
.58724 .64936 m .58851 .64806 L .5898 .64674 L F
0 0 .062 r
.58723 .65189 m .58851 .64806 L .58724 .64936 L F
.495 .216 .42 r
.70867 .47197 m .71129 .47 L .70897 .46948 L F
.397 .751 .993 r
.52146 .78631 m .51898 .78649 L .51992 .7854 L F
0 0 .257 r
.51992 .7854 m .51898 .78649 L .51889 .78892 L F
0 0 0 r
.61846 .60799 m .61767 .6097 L .61893 .60612 L F
.677 .823 .386 r
.61683 .61121 m .61767 .6097 L .61846 .60799 L F
.565 .851 .522 r
.47502 .66662 m .47426 .66745 L .47608 .66535 L F
.496 .405 .681 r
.58248 .65784 m .57998 .66036 L .58013 .65802 L F
0 0 .468 r
.65372 .49509 m .65494 .4905 L .65493 .49275 L F
.548 .561 .819 r
.76555 .50022 m .76678 .50354 L .769 .50299 L F
.489 .331 .593 r
.76678 .50354 m .76923 .50539 L .769 .50299 L F
.799 .825 .872 r
.71114 .4726 m .71238 .47442 L .71479 .47181 L F
.466 .272 .533 r
.42614 .68928 m .42399 .69221 L .42605 .69169 L F
.415 .266 .569 r
.42399 .69221 m .42582 .69418 L .42605 .69169 L F
.42399 .69221 m .42406 .6947 L .42582 .69418 L F
0 .171 .697 r
.42406 .6947 m .4253 .69777 L .42602 .69668 L F
.753 .641 .737 r
.73944 .47467 m .74312 .47538 L .74174 .47193 L F
.322 0 .101 r
.38593 .62709 m .3853 .62832 L .38295 .62878 L F
.399 0 .138 r
.38593 .62709 m .38748 .62798 L .3853 .62832 L F
.393 0 .156 r
.38827 .62672 m .38748 .62798 L .38593 .62709 L F
.979 .801 .592 r
.69139 .49114 m .69207 .4942 L .69269 .4922 L F
.827 .838 .856 r
.69139 .49114 m .69269 .4922 L .69525 .48946 L F
.702 .537 .662 r
.47502 .66662 m .47515 .66927 L .47298 .66916 L F
.148 0 .205 r
.48341 .62845 m .48584 .62556 L .48422 .62671 L F
.433 .503 .832 r
.29521 .62087 m .29541 .61732 L .29419 .62018 L F
.29521 .62087 m .29687 .62045 L .29541 .61732 L F
.418 .425 .76 r
.29521 .62087 m .29773 .62274 L .29687 .62045 L F
.496 .423 .704 r
.2958 .62332 m .29773 .62274 L .29521 .62087 L F
.73 .838 .931 r
.59188 .65988 m .58996 .66122 L .58855 .65994 L F
.573 .665 .901 r
.70441 .49069 m .70565 .48825 L .7034 .48858 L F
.70441 .49069 m .70715 .49111 L .70565 .48825 L F
.831 .733 .756 r
.73374 .49148 m .73159 .49453 L .73426 .49462 L F
.948 .743 .594 r
.60328 .59801 m .60296 .60044 L .60175 .59712 L F
.538 .689 .937 r
.40023 .59043 m .39918 .5924 L .39826 .59067 L F
.40023 .59043 m .40129 .59205 L .39918 .5924 L F
.323 0 .208 r
.286 .62301 m .2891 .62078 L .28627 .62103 L F
.618 .385 .541 r
.56207 .60342 m .56235 .60609 L .56013 .60588 L F
.516 .391 .648 r
.56399 .59993 m .56472 .60281 L .56207 .60342 L F
.482 .286 .538 r
.56207 .60342 m .56472 .60281 L .56235 .60609 L F
.296 .792 .85 r
.29863 .63231 m .29473 .63296 L .2953 .63274 L F
.29863 .63231 m .29649 .63253 L .29612 .63273 L F
.452 .656 .948 r
.298 .6348 m .29649 .63253 L .29863 .63231 L F
.722 .212 .014 r
.29884 .633 m .29714 .63217 L .29649 .63253 L F
.29714 .63217 m .29483 .63104 L .29649 .63253 L F
.296 .792 .85 r
.29612 .63273 m .29649 .63253 L .29473 .63296 L F
.445 .129 .334 r
.52402 .64883 m .5213 .65106 L .52172 .64925 L F
.941 .595 .337 r
.53072 .66145 m .53049 .6622 L .52869 .66004 L F
.764 .698 .789 r
.53233 .66021 m .53049 .6622 L .53072 .66145 L F
.465 .215 .449 r
.56083 .58383 m .56309 .58317 L .56342 .58094 L F
.488 .251 .481 r
.56309 .58317 m .56557 .58032 L .56342 .58094 L F
.89 .917 .835 r
.72228 .48956 m .71993 .49257 L .71905 .49149 L F
0 .348 .756 r
.75086 .47794 m .75183 .47865 L .74911 .47709 L F
0 .287 .668 r
.75371 .4795 m .75183 .47865 L .75086 .47794 L F
.75371 .4795 m .75475 .48007 L .75183 .47865 L F
.11 0 0 r
.34598 .59879 m .345 .5994 L .34279 .59962 L F
0 0 0 r
.34713 .59869 m .34598 .59879 L .34846 .59881 L F
.34713 .59869 m .345 .5994 L .34598 .59879 L F
.553 .496 .746 r
.49494 .66617 m .4965 .6623 L .49485 .66361 L F
.407 .075 .287 r
.44679 .66058 m .44378 .66334 L .44598 .66287 L F
.38 .058 .289 r
.44892 .66006 m .44679 .66058 L .44598 .66287 L F
.805 .581 .599 r
.61076 .57125 m .6142 .56932 L .6107 .56886 L F
.61076 .57125 m .61421 .57202 L .6142 .56932 L F
.569 .726 .948 r
.3217 .64274 m .32175 .64082 L .31979 .64099 L F
.803 .552 .559 r
.72213 .47981 m .72535 .47792 L .7238 .47693 L F
.72213 .47981 m .72546 .48025 L .72535 .47792 L F
.847 .814 .818 r
.72765 .47502 m .72535 .47792 L .7238 .47693 L F
.931 .674 .525 r
.72546 .48025 m .7238 .47693 L .72535 .47792 L F
.742 .992 .82 r
.48847 .70811 m .48834 .70843 L .49056 .70718 L F
.548 .54 .798 r
.66204 .49591 m .66006 .4946 L .66349 .4953 L F
.494 .013 .041 r
.66349 .4953 m .6664 .49607 L .66204 .49591 L F
.568 .143 .196 r
.47218 .70955 m .46856 .71111 L .46858 .70954 L F
.47218 .70955 m .4709 .71145 L .46856 .71111 L F
.524 .096 .17 r
.47218 .70955 m .47472 .71081 L .4709 .71145 L F
.403 .008 .172 r
.36087 .62591 m .36313 .62558 L .36432 .62358 L F
.338 0 .136 r
.36432 .62358 m .36533 .62505 L .36656 .62312 L F
.36432 .62358 m .36313 .62558 L .36533 .62505 L F
.24 .106 .49 r
.44602 .68866 m .44477 .69034 L .4446 .68945 L F
0 .55 .757 r
.33109 .5828 m .33317 .58301 L .33478 .58327 L F
.349 .776 .973 r
.33317 .58301 m .3369 .58337 L .33478 .58327 L F
.75 .588 .676 r
.67167 .49218 m .66956 .49452 L .66998 .49268 L F
.59 .24 .344 r
.48745 .71038 m .48391 .70978 L .48694 .70773 L F
.48745 .71038 m .48383 .71132 L .48391 .70978 L F
.415 .079 .286 r
.56557 .58032 m .56791 .5799 L .56849 .57772 L F
.334 .066 .35 r
.5702 .57932 m .56849 .57772 L .56791 .5799 L F
.5702 .57932 m .57076 .57666 L .56849 .57772 L F
.728 .591 .702 r
.60963 .56315 m .61068 .56643 L .61089 .56394 L F
.6 .242 .334 r
.66125 .49791 m .66032 .49991 L .65781 .49977 L F
.548 .54 .798 r
.66204 .49591 m .66125 .49791 L .66006 .4946 L F
.689 .499 .625 r
.66204 .49591 m .66032 .49991 L .66125 .49791 L F
.62 .553 .758 r
.66956 .49452 m .66584 .49214 L .66998 .49268 L F
.137 .253 .721 r
.57912 .65476 m .58135 .65722 L .58013 .65802 L F
.496 .405 .681 r
.58248 .65784 m .58013 .65802 L .58135 .65722 L F
.649 .88 .983 r
.41816 .59902 m .41423 .59888 L .41687 .59841 L F
.678 .198 .104 r
.41687 .59841 m .42022 .59914 L .41816 .59902 L F
.484 .582 .878 r
.42042 .60022 m .41816 .59902 L .42022 .59914 L F
.707 .883 .962 r
.42877 .70074 m .42559 .70085 L .42739 .69994 L F
.641 .502 .677 r
.77769 .50157 m .7784 .50344 L .77634 .50454 L F
.99 .877 .62 r
.52157 .78919 m .52146 .78631 L .51889 .78892 L F
.622 .958 .898 r
.36836 .59612 m .37043 .59583 L .37224 .59465 L F
.279 0 .138 r
.37656 .61667 m .37949 .61455 L .37731 .61505 L F
0 .372 .831 r
.55843 .63681 m .56026 .63716 L .55864 .6365 L F
0 0 .531 r
.55819 .63719 m .55843 .63681 L .55682 .63444 L F
.754 .352 .29 r
.55682 .63444 m .55843 .63681 L .55536 .63608 L F
0 .372 .831 r
.55843 .63681 m .55864 .6365 L .55736 .63597 L F
0 0 .531 r
.55835 .63751 m .55843 .63681 L .55819 .63719 L F
0 .23 .737 r
.55835 .63751 m .56149 .64005 L .55843 .63681 L F
.081 .334 .81 r
.56109 .64069 m .56149 .64005 L .55835 .63751 L F
.027 .588 .806 r
.50907 .75761 m .512 .75786 L .51291 .75814 L F
.50907 .75761 m .512 .75786 L .51291 .75814 L F
.811 .997 .856 r
.51291 .75814 m .512 .75786 L .51341 .7564 L F
.51341 .7564 m .512 .75786 L .51291 .75814 L F
.511 .225 .417 r
.36913 .62047 m .37143 .62016 L .37182 .61812 L F
.47 .149 .338 r
.37143 .62016 m .37455 .61731 L .37182 .61812 L F
.499 .148 .302 r
.58951 .56551 m .59263 .56513 L .59127 .56444 L F
.817 .872 .887 r
.66688 .50894 m .6695 .50908 L .66844 .50786 L F
.784 .866 .91 r
.66844 .50786 m .6695 .50908 L .67213 .50711 L F
.62 .459 .643 r
.78124 .49837 m .78072 .50066 L .77769 .50157 L F
.633 .498 .679 r
.78072 .50066 m .7784 .50344 L .77769 .50157 L F
.601 .532 .749 r
.76309 .50088 m .76555 .50022 L .76484 .49695 L F
.954 .62 .34 r
.72636 .50808 m .72482 .50789 L .72479 .50611 L F
.932 .796 .33 r
.72636 .50808 m .7256 .50984 L .72482 .50789 L F
.72636 .50808 m .7258 .51198 L .7256 .50984 L F
.713 .712 .848 r
.72868 .50601 m .72636 .50808 L .72479 .50611 L F
.653 .73 .906 r
.69738 .48829 m .70099 .4891 L .70012 .48638 L F
.583 .615 .85 r
.70099 .4891 m .70214 .48555 L .70012 .48638 L F
.70099 .4891 m .7034 .48858 L .70214 .48555 L F
.32 .544 .912 r
.38783 .597 m .38831 .59815 L .38942 .59704 L F
.282 .484 .878 r
.38831 .59815 m .39099 .59977 L .38942 .59704 L F
.692 .466 .575 r
.71371 .49117 m .7138 .49364 L .71014 .49171 L F
.148 .053 .482 r
.71526 .48893 m .71371 .49117 L .7166 .49029 L F
.71526 .48893 m .7138 .49364 L .71371 .49117 L F
.764 .698 .789 r
.53233 .66021 m .53367 .66311 L .53049 .6622 L F
0 0 0 r
.53367 .66311 m .53191 .66348 L .53049 .6622 L F
.53367 .66311 m .53135 .6668 L .53298 .66478 L F
.53367 .66311 m .53298 .66478 L .53191 .66348 L F
.727 .601 .716 r
.59168 .64355 m .5898 .64674 L .59149 .64454 L F
0 0 0 r
.5898 .64674 m .59128 .64607 L .59149 .64454 L F
0 0 .393 r
.59168 .64355 m .59149 .64454 L .59305 .64478 L F
.029 0 .015 r
.59305 .64478 m .59149 .64454 L .59128 .64607 L F
.931 .642 .473 r
.50803 .78319 m .51025 .7848 L .50964 .78666 L F
.099 0 0 r
.54491 .59466 m .54697 .59413 L .54804 .59237 L F
.226 0 .015 r
.54804 .59237 m .54907 .59349 L .54993 .5912 L F
.54804 .59237 m .54697 .59413 L .54907 .59349 L F
.615 .614 .827 r
.33036 .62079 m .32821 .62155 L .32706 .61952 L F
.39 .625 .947 r
.39636 .58854 m .39558 .5901 L .39418 .58883 L F
.39636 .58854 m .39826 .59067 L .39558 .5901 L F
.897 .66 .573 r
.60088 .58648 m .59898 .58583 L .59911 .58334 L F
.938 .581 .31 r
.60096 .58883 m .59898 .58583 L .60088 .58648 L F
.74 .413 .43 r
.2953 .63274 m .29473 .63296 L .29247 .63195 L F
.775 .592 .652 r
.57118 .59202 m .56783 .59405 L .5688 .59176 L F
.518 .301 .523 r
.38781 .60935 m .39013 .60889 L .39036 .60645 L F
.445 .234 .498 r
.39036 .60645 m .39238 .60589 L .39265 .60359 L F
.45 .243 .506 r
.39036 .60645 m .39219 .60823 L .39238 .60589 L F
.39036 .60645 m .39013 .60889 L .39219 .60823 L F
.89 .917 .835 r
.72228 .48956 m .71905 .49149 L .72103 .48842 L F
0 0 0 r
.61846 .60799 m .61893 .60612 L .61835 .60549 L F
.827 .585 .574 r
.60723 .56337 m .61068 .56643 L .60963 .56315 L F
.60723 .56337 m .60737 .56577 L .61068 .56643 L F
.819 .591 .593 r
.60737 .56577 m .6107 .56886 L .61068 .56643 L F
0 0 .393 r
.59168 .64355 m .59305 .64478 L .59341 .64315 L F
.741 .551 .636 r
.59038 .65251 m .58739 .6542 L .58723 .65189 L F
.59038 .65251 m .59074 .65493 L .58739 .6542 L F
.847 .814 .818 r
.72765 .47502 m .7238 .47693 L .72698 .47449 L F
.682 .942 .664 r
.72969 .47285 m .72765 .47502 L .7295 .47252 L F
.728 .972 .929 r
.72765 .47502 m .72698 .47449 L .7295 .47252 L F
.438 .136 .354 r
.28963 .59696 m .29199 .59692 L .29241 .59475 L F
.385 .123 .389 r
.29199 .59692 m .29442 .59367 L .29241 .59475 L F
.609 .392 .562 r
.49788 .67762 m .49514 .68031 L .49517 .67786 L F
.49514 .68031 m .49788 .67762 L .49517 .67786 L F
.49788 .67762 m .49781 .68023 L .49514 .68031 L F
.49514 .68031 m .49781 .68023 L .49788 .67762 L F
.49788 .67762 m .49781 .68023 L .49514 .68031 L F
.611 .403 .575 r
.49517 .67786 m .49781 .68023 L .49514 .68031 L F
.777 .841 .901 r
.71526 .48893 m .7166 .49029 L .71851 .48871 L F
0 0 0 r
.5541 .61397 m .55264 .6153 L .55513 .61208 L F
.423 .005 .139 r
.50883 .64879 m .5052 .65081 L .50695 .6488 L F
.238 0 0 r
.35537 .64058 m .35147 .64232 L .35323 .64115 L F
.315 .3 .683 r
.42581 .68623 m .42614 .68928 L .42755 .68906 L F
.277 .122 .483 r
.42755 .68906 m .42614 .68928 L .42605 .69169 L F
0 0 0 r
.55852 .66724 m .55699 .66806 L .55507 .66873 L F
.886 .986 .72 r
.55897 .66516 m .55852 .66724 L .56069 .66615 L F
.858 .904 .865 r
.55963 .65464 m .55917 .65791 L .55889 .6565 L F
.89 .593 .085 r
.55879 .65863 m .55917 .65791 L .55963 .65464 L F
.55879 .65863 m .55967 .6605 L .55917 .65791 L F
0 0 0 r
.43291 .70393 m .43235 .7035 L .43407 .70383 L F
.43291 .70393 m .43084 .70507 L .43235 .7035 L F
.945 .672 .49 r
.60277 .59199 m .60111 .5914 L .60096 .58883 L F
.872 .665 .62 r
.60297 .59414 m .60111 .5914 L .60277 .59199 L F
0 0 0 r
.5898 .64674 m .58851 .64806 L .59128 .64607 L F
.739 .462 .511 r
.59795 .5606 m .60006 .56323 L .59986 .56081 L F
.755 .475 .508 r
.59986 .56081 m .60006 .56323 L .6036 .5634 L F
.849 .511 .415 r
.46797 .70002 m .46914 .7031 L .47075 .70304 L F
.349 .641 .963 r
.38734 .58696 m .38661 .58823 L .3848 .58695 L F
.38734 .58696 m .38852 .58833 L .38661 .58823 L F
.419 0 0 r
.52774 .66356 m .52641 .66464 L .5243 .6639 L F
.649 .617 .803 r
.53049 .6622 m .52774 .66356 L .52649 .66028 L F
.466 .049 .163 r
.53049 .6622 m .52641 .66464 L .52774 .66356 L F
.459 .301 .578 r
.42439 .68035 m .42634 .67987 L .42633 .67756 L F
.424 .407 .736 r
.42439 .68035 m .42686 .6832 L .42634 .67987 L F
.71 .584 .713 r
.55619 .60587 m .55389 .6088 L .55397 .60645 L F
0 0 0 r
.60325 .66698 m .60489 .6658 L .60217 .66795 L F
0 .311 .802 r
.52883 .65505 m .52899 .65417 L .52799 .65353 L F
.777 .459 .449 r
.53023 .65509 m .52899 .65417 L .52909 .65506 L F
.365 .423 .788 r
.52883 .65505 m .53155 .65694 L .53023 .65509 L F
.726 .637 .758 r
.53184 .65 m .52899 .65417 L .53212 .65402 L F
.542 .077 .1 r
.52899 .65417 m .53144 .65508 L .53212 .65402 L F
.777 .459 .449 r
.53023 .65509 m .52989 .65615 L .52899 .65417 L F
.887 .905 .834 r
.52856 .65249 m .52899 .65417 L .53184 .65 L F
.631 .583 .782 r
.52856 .65249 m .53144 .65508 L .52899 .65417 L F
0 0 .419 r
.52899 .65417 m .52989 .65615 L .52891 .65346 L F
.52899 .65417 m .52891 .65346 L .52856 .65249 L F
.777 .459 .449 r
.52909 .65506 m .52899 .65417 L .52883 .65505 L F
.965 .65 .371 r
.73221 .47407 m .73258 .47637 L .73357 .47506 L F
.472 0 .02 r
.73357 .47506 m .73258 .47637 L .73609 .47604 L F
.472 .08 .214 r
.73357 .47506 m .73609 .47604 L .73593 .47484 L F
.45 .271 .545 r
.69962 .46922 m .7019 .46854 L .70181 .46606 L F
.966 .861 .686 r
.6177 .60011 m .61931 .60087 L .61943 .59578 L F
.984 .783 .552 r
.61749 .60219 m .61931 .60087 L .6177 .60011 L F
.61749 .60219 m .61886 .60324 L .61931 .60087 L F
.336 .09 .385 r
.2958 .62332 m .29764 .62433 L .29773 .62274 L F
.2958 .62332 m .2952 .62573 L .29764 .62433 L F
.727 .642 .763 r
.72868 .50601 m .72657 .50339 L .72826 .50348 L F
.926 .635 .157 r
.72798 .50493 m .72826 .50348 L .72657 .50339 L F
.72798 .50493 m .72868 .50601 L .72826 .50348 L F
.555 .365 .578 r
.77903 .50509 m .77894 .50884 L .77635 .50928 L F
.631 .478 .657 r
.78126 .50374 m .77903 .50509 L .7784 .50344 L F
.78126 .50374 m .78227 .50534 L .77903 .50509 L F
.617 .415 .586 r
.78303 .50741 m .77903 .50509 L .78227 .50534 L F
.78303 .50741 m .77894 .50884 L .77903 .50509 L F
.621 .606 .814 r
.49855 .79007 m .50096 .78966 L .49752 .78845 L F
.033 .245 .747 r
.56096 .62008 m .55972 .62105 L .5587 .61972 L F
.622 .073 0 r
.55972 .62105 m .56194 .62313 L .56311 .62372 L F
.033 .245 .747 r
.56096 .62008 m .56194 .62313 L .55972 .62105 L F
.612 .347 .491 r
.58382 .56873 m .5866 .56877 L .58676 .56611 L F
.421 .113 .335 r
.5866 .56877 m .58951 .56551 L .58676 .56611 L F
.532 .244 .422 r
.57917 .58392 m .58046 .58552 L .57852 .58593 L F
.57917 .58392 m .58159 .58309 L .58046 .58552 L F
.587 .284 .422 r
.51441 .65758 m .51376 .66013 L .51125 .66013 L F
.459 .238 .49 r
.51685 .65479 m .51672 .65714 L .51441 .65758 L F
.542 .242 .407 r
.51679 .65949 m .51441 .65758 L .51672 .65714 L F
.51679 .65949 m .51376 .66013 L .51441 .65758 L F
.182 .044 .446 r
.28807 .60335 m .29037 .59849 L .28759 .60083 L F
.661 .754 .919 r
.74088 .51124 m .7387 .51212 L .73771 .51054 L F
.654 .311 .378 r
.7703 .52047 m .76955 .52274 L .76722 .52241 L F
.687 .448 .556 r
.77288 .51998 m .76955 .52274 L .7703 .52047 L F
.47 .201 .424 r
.45714 .65449 m .45934 .65406 L .45973 .65215 L F
.413 .102 .325 r
.45934 .65406 m .46211 .65183 L .45973 .65215 L F
.531 .486 .75 r
.39192 .60137 m .39265 .60359 L .39465 .60285 L F
.491 .301 .549 r
.39238 .60589 m .39465 .60285 L .39265 .60359 L F
.549 .826 .997 r
.44594 .68314 m .44706 .68272 L .44677 .68208 L F
0 0 .024 r
.44677 .68208 m .44557 .68493 L .44594 .68314 L F
.312 .138 .476 r
.47676 .65649 m .47536 .65516 L .47786 .654 L F
0 0 .392 r
.29247 .63195 m .29271 .63117 L .2922 .63036 L F
.196 .568 .938 r
.29247 .63195 m .29473 .63296 L .29271 .63117 L F
0 .387 .838 r
.461 .67946 m .45971 .67932 L .45862 .6797 L F
.571 .321 .499 r
.48412 .65719 m .48686 .65404 L .48308 .6542 L F
.48412 .65719 m .48657 .65705 L .48686 .65404 L F
.429 .28 .576 r
.48686 .65404 m .48907 .6552 L .4889 .65161 L F
.471 .753 .991 r
.4459 .6917 m .44498 .69284 L .44477 .69034 L F
.4459 .6917 m .44718 .69286 L .44498 .69284 L F
.539 .277 .467 r
.44339 .66548 m .4413 .66364 L .44107 .66586 L F
.44339 .66548 m .44378 .66334 L .4413 .66364 L F
.079 0 0 r
.60007 .66862 m .59964 .66935 L .59655 .67085 L F
.01 0 0 r
.60217 .66795 m .60182 .66845 L .60007 .66862 L F
.036 0 0 r
.60007 .66862 m .60182 .66845 L .59964 .66935 L F
.507 .174 .337 r
.50416 .78634 m .50589 .78783 L .5078 .78788 L F
.495 .063 .148 r
.50589 .78783 m .50964 .78666 L .5078 .78788 L F
.519 .296 .516 r
.57904 .57196 m .58149 .57151 L .5815 .56925 L F
.628 .443 .613 r
.58149 .57151 m .58382 .56873 L .5815 .56925 L F
.669 .711 .879 r
.66236 .50959 m .66376 .51126 L .66688 .50894 L F
.503 .067 .143 r
.3868 .6108 m .38947 .61061 L .38781 .60935 L F
.434 .1 .297 r
.38781 .60935 m .38947 .61061 L .39013 .60889 L F
.565 .514 .757 r
.49449 .78406 m .49752 .78845 L .49729 .78672 L F
.724 .209 0 r
.51668 .63129 m .51998 .63288 L .51789 .63277 L F
.511 .31 .544 r
.51902 .65413 m .51672 .65714 L .51685 .65479 L F
.466 .226 .465 r
.32967 .60579 m .32712 .60853 L .32766 .60625 L F
.416 0 0 r
.44273 .70847 m .44524 .70936 L .4437 .70896 L F
0 .2 .729 r
.44524 .70936 m .44664 .70974 L .4437 .70896 L F
.626 .272 .349 r
.44858 .70921 m .44743 .71132 L .44524 .70936 L F
0 .2 .729 r
.44524 .70936 m .44743 .71132 L .44664 .70974 L F
.197 .316 .76 r
.73492 .52383 m .7362 .52246 L .73386 .52061 L F
.251 .402 .82 r
.73492 .52383 m .73767 .52559 L .7362 .52246 L F
.666 .692 .865 r
.70715 .49111 m .71014 .49171 L .70892 .49033 L F
.511 .559 .841 r
.71014 .49171 m .71211 .48862 L .70892 .49033 L F
.71014 .49171 m .7138 .49364 L .71211 .48862 L F
.475 .517 .821 r
.55717 .61079 m .55513 .61208 L .55389 .6088 L F
.306 .515 .895 r
.56262 .64637 m .56427 .64633 L .56371 .64503 L F
.772 .686 .768 r
.49794 .63987 m .49578 .64295 L .49921 .64334 L F
.781 .653 .722 r
.49578 .64295 m .49579 .64753 L .49921 .64334 L F
.83 .783 .807 r
.29026 .6196 m .28797 .6225 L .29152 .62322 L F
.838 .772 .789 r
.28797 .6225 m .28931 .62543 L .29152 .62322 L F
.327 .622 .957 r
.74703 .47522 m .74446 .47623 L .74614 .47545 L F
.404 0 0 r
.74785 .4761 m .74781 .47653 L .74703 .47522 L F
.121 .626 .9 r
.74778 .47685 m .74781 .47653 L .74911 .47709 L F
.404 0 0 r
.74896 .47733 m .74781 .47653 L .74785 .4761 L F
.121 .626 .9 r
.74446 .47623 m .74781 .47653 L .74778 .47685 L F
.766 .48 .5 r
.50584 .70757 m .50923 .70641 L .50725 .70629 L F
0 0 0 r
.50089 .64896 m .50175 .64829 L .50415 .64458 L F
.426 .261 .553 r
.50415 .64458 m .50518 .64578 L .5055 .64315 L F
.802 .637 .677 r
.50175 .64829 m .50518 .64578 L .50415 .64458 L F
.58 .013 0 r
.53861 .63759 m .54248 .6402 L .53947 .63823 L F
.464 .021 .111 r
.5108 .70934 m .50721 .71109 L .5072 .70942 L F
.5108 .70934 m .50965 .71115 L .50721 .71109 L F
.097 0 0 r
.5116 .7103 m .5108 .70934 L .51321 .70892 L F
.5116 .7103 m .50965 .71115 L .5108 .70934 L F
.864 .433 .012 r
.61631 .58391 m .61653 .58448 L .61812 .58635 L F
.181 .051 .456 r
.61649 .58452 m .61631 .58391 L .61679 .5807 L F
.61646 .5844 m .61679 .5807 L .61541 .57973 L F
.794 .394 .296 r
.61381 .58469 m .61631 .58391 L .61649 .58452 L F
.61458 .58445 m .61574 .58448 L .61631 .58391 L F
.61571 .58451 m .61653 .58448 L .61631 .58391 L F
.865 .564 .478 r
.61624 .5845 m .61649 .58452 L .61645 .5845 L F
.794 .394 .296 r
.6152 .58502 m .61649 .5845 L .61571 .58451 L F
.61649 .5845 m .61653 .58448 L .61571 .58451 L F
.865 .564 .478 r
.61209 .58412 m .61624 .5845 L .61218 .58163 L F
.61624 .5845 m .61645 .5845 L .61218 .58163 L F
.877 .672 .622 r
.61218 .58163 m .61645 .5845 L .61541 .57973 L F
.61645 .5845 m .61649 .58452 L .61648 .5845 L F
.61645 .5845 m .61648 .5845 L .61541 .57973 L F
.794 .394 .296 r
.61381 .58469 m .6152 .58502 L .61574 .58448 L F
.61381 .58469 m .61574 .58448 L .61458 .58445 L F
.181 .051 .456 r
.61649 .58452 m .61649 .5845 L .61648 .5845 L F
.794 .394 .296 r
.6152 .58502 m .61688 .58542 L .61653 .58448 L F
.181 .051 .456 r
.61648 .5845 m .6165 .58444 L .61646 .5844 L F
.61649 .5845 m .6165 .58444 L .61648 .5845 L F
.6165 .58444 m .61679 .5807 L .61646 .5844 L F
.864 .433 .012 r
.61653 .58448 m .61688 .58542 L .61795 .58622 L F
.61653 .58448 m .61795 .58622 L .61812 .58635 L F
.99 .73 .421 r
.61688 .58542 m .61809 .58897 L .61812 .58635 L F
.681 .444 .556 r
.61812 .58635 m .61809 .58897 L .61849 .58778 L F
.376 .46 .819 r
.28942 .61137 m .29112 .61509 L .29234 .61422 L F
.51 .267 .482 r
.29112 .61509 m .29261 .61681 L .29234 .61422 L F
.29112 .61509 m .29054 .61729 L .29261 .61681 L F
.513 .473 .75 r
.49767 .65972 m .50044 .6632 L .50179 .66216 L F
.694 .935 .965 r
.50132 .66296 m .50036 .66326 L .50064 .6641 L F
.513 .473 .75 r
.50044 .6632 m .50099 .66389 L .50179 .66216 L F
.694 .935 .965 r
.50036 .66326 m .49654 .66444 L .4991 .66423 L F
.50036 .66326 m .4991 .66423 L .50064 .6641 L F
.746 .52 .587 r
.4965 .6623 m .49965 .66341 L .49974 .66232 L F
.49965 .66341 m .50044 .6632 L .49974 .66232 L F
.971 .756 .556 r
.49965 .66341 m .49654 .66444 L .50099 .66389 L F
.4965 .6623 m .49654 .66444 L .49965 .66341 L F
.694 .935 .965 r
.50179 .66216 m .49769 .66395 L .49965 .66341 L F
.50139 .66284 m .49965 .66341 L .50132 .66296 L F
.50179 .66216 m .49965 .66341 L .50139 .66284 L F
.49769 .66395 m .49654 .66444 L .50132 .66296 L F
.746 .52 .587 r
.49965 .66341 m .50099 .66389 L .50044 .6632 L F
.497 .66121 m .49974 .66232 L .49767 .65972 L F
.4965 .6623 m .49974 .66232 L .497 .66121 L F
.694 .935 .965 r
.50281 .66357 m .50064 .6641 L .50306 .66392 L F
.50179 .66216 m .50132 .66296 L .50281 .66357 L F
.50132 .66296 m .50064 .6641 L .50281 .66357 L F
.368 .782 .979 r
.3732 .58608 m .37537 .58585 L .37685 .58646 L F
.304 .739 .968 r
.37537 .58585 m .37894 .58643 L .37685 .58646 L F
.177 .269 .721 r
.52402 .64883 m .52499 .65246 L .5259 .65113 L F
.52407 .64887 m .5259 .65113 L .52579 .65019 L F
.52402 .64883 m .52404 .64886 L .52407 .64887 L F
.52404 .64886 m .5259 .65113 L .52407 .64887 L F
.52402 .64883 m .52629 .65057 L .52662 .64845 L F
.592 .591 .82 r
.52461 .65056 m .52629 .65057 L .52459 .65059 L F
.5257 .64948 m .52629 .65057 L .52372 .65056 L F
.959 .674 .452 r
.52662 .64845 m .52629 .65057 L .52565 .64939 L F
0 0 0 r
.52545 .64962 m .5257 .64933 L .52591 .64901 L F
.52577 .6492 m .52577 .6492 L .52568 .64918 L F
.959 .674 .452 r
.52629 .64838 m .52577 .6492 L .526 .64833 L F
0 0 0 r
.52577 .6492 m .52591 .64901 L .5258 .64909 L F
.52577 .6492 m .5258 .64909 L .52568 .64918 L F
.681 .665 .827 r
.52564 .64888 m .52568 .64918 L .5258 .64909 L F
.959 .674 .452 r
.52577 .6492 m .52565 .64939 L .526 .64833 L F
.681 .665 .827 r
.52567 .6489 m .5258 .64909 L .52591 .64901 L F
.52564 .64888 m .5258 .64909 L .52567 .6489 L F
0 0 0 r
.5259 .64542 m .52402 .64883 L .52662 .64845 L F
.5259 .64542 m .52508 .64782 L .52402 .64883 L F
.52508 .64782 m .52497 .64814 L .52486 .64822 L F
.52508 .64782 m .52486 .64822 L .52402 .64883 L F
.681 .665 .827 r
.52464 .64861 m .52379 .65026 L .52568 .64918 L F
.52379 .65026 m .52379 .65052 L .52568 .64918 L F
.5215 .64687 m .52475 .64845 L .52497 .64814 L F
.52475 .64845 m .52567 .6489 L .52497 .64814 L F
.52475 .64845 m .52568 .64918 L .52564 .64888 L F
.5215 .64687 m .52466 .64862 L .52475 .64845 L F
.52466 .64862 m .52568 .64918 L .52475 .64845 L F
.592 .591 .82 r
.52475 .64845 m .5237 .6506 L .52386 .64968 L F
.52497 .64814 m .52379 .65043 L .52475 .64845 L F
.52379 .65043 m .5237 .6506 L .52475 .64845 L F
.52497 .64814 m .52386 .64968 L .52402 .64883 L F
0 0 0 r
.52545 .64962 m .52577 .6492 L .52386 .65049 L F
.52577 .6492 m .52568 .64918 L .52357 .65068 L F
.592 .591 .82 r
.52497 .64814 m .5257 .64948 L .52379 .65052 L F
.52379 .65043 m .52379 .65052 L .52372 .65056 L F
.52497 .64814 m .52379 .65052 L .52379 .65043 L F
.445 .129 .334 r
.52402 .64883 m .5237 .65058 L .5213 .65106 L F
.5237 .65058 m .5237 .6506 L .52366 .65061 L F
.5237 .65058 m .52366 .65061 L .5213 .65106 L F
.78 .703 .779 r
.5194 .6499 m .52356 .65068 L .5215 .64687 L F
.52356 .65068 m .52357 .65068 L .52357 .65067 L F
.52356 .65068 m .52357 .65067 L .5215 .64687 L F
.681 .665 .827 r
.52379 .65026 m .52357 .65068 L .52379 .65052 L F
.5215 .64687 m .52353 .65061 L .52464 .64861 L F
.52353 .65061 m .52357 .65068 L .52464 .64861 L F
.959 .674 .452 r
.52576 .64904 m .52565 .64939 L .52522 .64818 L F
.681 .665 .827 r
.52567 .6489 m .52591 .64901 L .52497 .64814 L F
.959 .674 .452 r
.52522 .64818 m .52534 .64854 L .52497 .64814 L F
.52534 .64854 m .52565 .64939 L .52497 .64814 L F
.526 .64833 m .52576 .64904 L .52522 .64818 L F
.52662 .64845 m .52565 .64939 L .52629 .64838 L F
.52 .205 .374 r
.52532 .6525 m .52418 .65117 L .52629 .65057 L F
.52418 .65117 m .5237 .6506 L .52459 .65059 L F
.177 .269 .721 r
.52579 .65019 m .5259 .65113 L .52629 .65057 L F
.52 .205 .374 r
.52418 .65117 m .52459 .65059 L .52629 .65057 L F
.365 .53 .887 r
.52499 .65246 m .52799 .65353 L .52629 .65057 L F
.52 .205 .374 r
.52532 .6525 m .52285 .653 L .5237 .6506 L F
0 0 0 r
.52316 .65262 m .52376 .65227 L .52536 .64986 L F
.52285 .653 m .52293 .65294 L .52316 .65262 L F
.52293 .65294 m .52376 .65227 L .52316 .65262 L F
.52562 .64944 m .52536 .64986 L .5257 .64933 L F
.52285 .653 m .52536 .64986 L .52562 .64944 L F
.52285 .653 m .5257 .64933 L .52545 .64962 L F
.592 .591 .82 r
.52372 .65056 m .52461 .65056 L .5237 .6506 L F
.52461 .65056 m .52459 .65059 L .5237 .6506 L F
0 0 0 r
.52285 .653 m .52545 .64962 L .52357 .65068 L F
.52545 .64962 m .52386 .65049 L .52357 .65068 L F
.693 .803 .934 r
.75154 .48949 m .75463 .48977 L .75376 .48837 L F
.619 .744 .936 r
.75376 .48837 m .75463 .48977 L .75704 .48915 L F
.565 .611 .858 r
.31696 .64043 m .31754 .63648 L .31559 .63709 L F
.31696 .64043 m .32012 .64 L .31754 .63648 L F
.563 .623 .87 r
.31696 .64043 m .31979 .64099 L .32012 .64 L F
.485 .497 .795 r
.39192 .60137 m .39334 .59918 L .39099 .59977 L F
.39192 .60137 m .39465 .60285 L .39334 .59918 L F
.086 .507 .902 r
.65963 .50846 m .66112 .50836 L .65983 .50675 L F
.65963 .50846 m .66236 .50959 L .66112 .50836 L F
.562 .154 .226 r
.46644 .70896 m .46273 .71068 L .46298 .70951 L F
.46644 .70896 m .46496 .71096 L .46273 .71068 L F
.707 .325 .324 r
.46644 .70896 m .46856 .71111 L .46496 .71096 L F
.69 .333 .365 r
.46858 .70954 m .46856 .71111 L .46644 .70896 L F
.371 0 .105 r
.45105 .70901 m .44743 .71132 L .44858 .70921 L F
.513 .159 .305 r
.69452 .47427 m .69655 .4758 L .69682 .47369 L F
.69452 .47427 m .69395 .47633 L .69655 .4758 L F
.581 .607 .843 r
.28949 .64029 m .29113 .6436 L .29315 .64314 L F
.16 .689 .863 r
.37542 .59556 m .3762 .59513 L .37404 .59452 L F
.37542 .59556 m .37671 .59534 L .3762 .59513 L F
.708 .785 .912 r
.77887 .5276 m .78108 .5292 L .77765 .52893 L F
.984 .706 .399 r
.78108 .5292 m .78012 .53068 L .77765 .52893 L F
.78108 .5292 m .78123 .53155 L .78012 .53068 L F
.418 .698 .979 r
.77887 .5276 m .78238 .52793 L .78108 .5292 L F
.363 .607 .942 r
.78238 .52793 m .78326 .52951 L .78108 .5292 L F
.698 .607 .75 r
.7822 .53057 m .78123 .53155 L .78116 .53043 L F
.785 .902 .924 r
.78266 .5306 m .78123 .53155 L .78335 .53058 L F
.698 .607 .75 r
.78326 .52951 m .7835 .53004 L .78123 .53155 L F
.785 .902 .924 r
.78012 .53068 m .78123 .53155 L .78266 .5306 L F
.705 .51 .622 r
.78123 .53155 m .78429 .53179 L .78335 .53058 L F
.698 .607 .75 r
.78378 .53066 m .78429 .53179 L .78286 .53074 L F
.7833 .53064 m .78286 .53074 L .78266 .5306 L F
.78378 .53066 m .78286 .53074 L .7833 .53064 L F
.597 .582 .807 r
.78429 .53179 m .78612 .53046 L .78335 .53058 L F
.78612 .53046 m .78684 .52993 L .7858 .53012 L F
.78612 .53046 m .7858 .53012 L .78335 .53058 L F
.595 .599 .826 r
.7861 .52898 m .78528 .53025 L .78326 .52951 L F
.78528 .53025 m .78429 .53179 L .78372 .53054 L F
0 0 0 r
.78335 .53058 m .7858 .53012 L .78575 .53016 L F
.597 .582 .807 r
.78429 .53179 m .78642 .53168 L .78684 .52993 L F
.595 .599 .826 r
.78623 .53007 m .78642 .53168 L .78528 .53025 L F
0 0 0 r
.78548 .53021 m .78575 .53016 L .78573 .53017 L F
.78335 .53058 m .78575 .53016 L .78548 .53021 L F
.595 .599 .826 r
.78528 .53025 m .78642 .53168 L .78429 .53179 L F
.7861 .52898 m .78623 .53007 L .78528 .53025 L F
0 0 0 r
.78335 .53058 m .78573 .53017 L .78345 .53059 L F
.595 .599 .826 r
.78528 .53025 m .78372 .53054 L .78326 .52951 L F
0 0 0 r
.78345 .53059 m .78573 .53017 L .78494 .53071 L F
.7858 .53012 m .78684 .52993 L .78666 .53001 L F
.7858 .53012 m .78666 .53001 L .78494 .53071 L F
.251 .235 .645 r
.78642 .53168 m .7881 .52991 L .78684 .52993 L F
.382 .434 .791 r
.78645 .53003 m .7881 .52991 L .78685 .53123 L F
.396 .43 .778 r
.78794 .52883 m .78721 .52949 L .7861 .52898 L F
.248 .093 .465 r
.79028 .52625 m .78935 .5278 L .78762 .52678 L F
.78935 .5278 m .7881 .52991 L .78794 .52883 L F
.78935 .5278 m .78794 .52883 L .78762 .52678 L F
.25 .191 .593 r
.78802 .52877 m .78865 .52828 L .78823 .52856 L F
.78684 .52993 m .7885 .52842 L .78802 .52877 L F
.7885 .52842 m .78865 .52828 L .78802 .52877 L F
.78797 .5288 m .78823 .52856 L .78816 .5286 L F
.382 .434 .791 r
.7861 .52898 m .78721 .52949 L .78645 .53003 L F
.78721 .52949 m .78666 .53001 L .78645 .53003 L F
.7861 .52898 m .78685 .53123 L .7863 .53065 L F
.25 .191 .593 r
.78666 .53001 m .78816 .5286 L .78494 .53071 L F
.78684 .52993 m .78823 .52856 L .78797 .5288 L F
.78684 .52993 m .7881 .52991 L .78865 .52828 L F
.396 .43 .778 r
.78794 .52883 m .7881 .52991 L .78721 .52949 L F
.25 .191 .593 r
.78684 .52993 m .78816 .5286 L .78666 .53001 L F
.382 .434 .791 r
.78721 .52949 m .78794 .52983 L .78666 .53001 L F
.248 .093 .465 r
.79028 .52625 m .79061 .5284 L .7881 .52991 L F
.367 .313 .665 r
.7881 .52991 m .79061 .5284 L .78865 .52828 L F
.275 0 0 r
.78865 .52828 m .78943 .52978 L .78683 .52988 L F
.212 .722 .89 r
.78683 .52988 m .7889 .52948 L .78807 .52939 L F
0 0 0 r
.78523 .53052 m .78823 .52856 L .78683 .52988 L F
.78823 .52856 m .78848 .52843 L .78683 .52988 L F
.78494 .53071 m .78523 .53052 L .78683 .52988 L F
.52 .741 .975 r
.78535 .52783 m .78326 .52951 L .78238 .52793 L F
.78535 .52783 m .7861 .52898 L .78326 .52951 L F
.353 .752 .984 r
.78386 .5271 m .78535 .52783 L .78238 .52793 L F
0 0 0 r
.78494 .53071 m .78683 .52988 L .78403 .52727 L F
.396 .43 .778 r
.78762 .52678 m .78792 .52871 L .7861 .52898 L F
.78792 .52871 m .78765 .52885 L .7861 .52898 L F
.78762 .52678 m .7861 .52898 L .78535 .52783 L F
.2 .316 .759 r
.78403 .52727 m .78683 .52988 L .78619 .52742 L F
.904 .773 .707 r
.78619 .52742 m .78683 .52988 L .78552 .52911 L F
.212 .722 .89 r
.78683 .52988 m .78807 .52939 L .78552 .52911 L F
0 0 0 r
.78823 .52856 m .78865 .52828 L .78848 .52843 L F
.396 .43 .778 r
.78792 .52871 m .78794 .52883 L .78765 .52885 L F
.382 .434 .791 r
.78794 .52983 m .7881 .52991 L .78645 .53003 L F
.7863 .53065 m .78685 .53123 L .78642 .53168 L F
0 0 0 r
.7833 .53064 m .78494 .53071 L .78289 .53115 L F
.78335 .53058 m .7835 .53059 L .7833 .53064 L F
.7835 .53059 m .78494 .53071 L .7833 .53064 L F
.785 .902 .924 r
.78245 .53061 m .78266 .5306 L .78324 .53071 L F
.78266 .5306 m .78335 .53058 L .7833 .53064 L F
.78266 .5306 m .7833 .53064 L .78324 .53071 L F
.698 .607 .75 r
.78266 .5306 m .78429 .53179 L .78123 .53155 L F
.7835 .53004 m .78378 .53066 L .78266 .5306 L F
.785 .902 .924 r
.78012 .53068 m .78245 .53061 L .78289 .53115 L F
.78245 .53061 m .78324 .53071 L .78289 .53115 L F
.698 .607 .75 r
.78326 .52951 m .7822 .53057 L .78108 .5292 L F
.7822 .53057 m .78116 .53043 L .78108 .5292 L F
.5 .279 .51 r
.40594 .61427 m .40351 .61688 L .40378 .61479 L F
.586 .071 0 r
.43425 .66452 m .43759 .66559 L .4355 .66414 L F
.496 .376 .645 r
.32473 .61124 m .32309 .61496 L .32285 .61144 L F
.971 .661 .356 r
.56194 .62313 m .56343 .62617 L .56311 .62372 L F
0 0 .178 r
.55051 .64297 m .55055 .64168 L .55223 .64294 L F
.55051 .64297 m .55069 .64289 L .55055 .64168 L F
.919 .752 .657 r
.55068 .64282 m .55223 .64294 L .55055 .64168 L F
0 0 .178 r
.55069 .64289 m .55069 .64288 L .55055 .64168 L F
.919 .752 .657 r
.55056 .64281 m .55068 .64282 L .55055 .64168 L F
.804 .638 .675 r
.55055 .64168 m .55069 .64288 L .55056 .64283 L F
.55055 .64168 m .55056 .64283 L .5472 .64149 L F
.919 .752 .657 r
.55032 .64279 m .55056 .64281 L .55055 .64168 L F
0 .491 .751 r
.54648 .64208 m .54958 .64267 L .55051 .64297 L F
.54958 .64267 m .55065 .64288 L .55051 .64297 L F
.54958 .64267 m .55051 .64297 L .55051 .64297 L F
.101 .578 .909 r
.5472 .64149 m .54937 .64235 L .54648 .64208 L F
.55066 .64287 m .55069 .64288 L .54958 .64267 L F
.883 .695 .643 r
.5475 .64295 m .54994 .64466 L .55034 .64272 L F
.54927 .64221 m .55034 .64272 L .55055 .64168 L F
.101 .578 .909 r
.54937 .64235 m .55066 .64287 L .54958 .64267 L F
.54937 .64235 m .54958 .64267 L .54648 .64208 L F
.883 .695 .643 r
.5475 .64295 m .55034 .64272 L .54927 .64221 L F
.919 .752 .657 r
.55189 .64319 m .55223 .64294 L .55032 .64279 L F
.101 .578 .909 r
.55066 .64287 m .55069 .64288 L .55069 .64288 L F
.883 .695 .643 r
.54903 .64185 m .55055 .64168 L .54956 .64146 L F
.54841 .6423 m .54918 .64208 L .54903 .64185 L F
.54918 .64208 m .55055 .64168 L .54903 .64185 L F
.5475 .64295 m .54879 .64242 L .54841 .6423 L F
.54879 .64242 m .55055 .64168 L .54841 .6423 L F
0 .491 .751 r
.55065 .64288 m .55069 .64289 L .55051 .64297 L F
.919 .752 .657 r
.54994 .64466 m .55189 .64319 L .55032 .64279 L F
0 .491 .751 r
.55065 .64288 m .55069 .64288 L .55069 .64289 L F
.09 .442 .878 r
.54899 .6269 m .55142 .62725 L .54847 .62534 L F
.54899 .6269 m .55187 .62837 L .55142 .62725 L F
.318 .547 .915 r
.54899 .6269 m .5526 .62934 L .55187 .62837 L F
.51 0 0 r
.47298 .66916 m .47321 .67055 L .47158 .67032 L F
.436 .441 .766 r
.47158 .67032 m .47321 .67055 L .47312 .6701 L F
.164 0 0 r
.46996 .67055 m .47298 .66916 L .47158 .67032 L F
.436 .441 .766 r
.47158 .67032 m .47312 .6701 L .47259 .6677 L F
.164 0 0 r
.46908 .67096 m .46996 .67055 L .47158 .67032 L F
.51 0 0 r
.47298 .66916 m .47515 .66927 L .47321 .67055 L F
.614 .957 .848 r
.56109 .64069 m .56164 .63965 L .56149 .64005 L F
.02 .187 .697 r
.56219 .64306 m .56164 .63965 L .56109 .64069 L F
.411 .701 .981 r
.76654 .48282 m .76511 .48401 L .76419 .48272 L F
.76654 .48282 m .76753 .48402 L .76511 .48401 L F
.815 .515 .481 r
.48258 .70594 m .48694 .70773 L .48638 .70613 L F
.48258 .70594 m .48253 .70801 L .48694 .70773 L F
.764 .516 .559 r
.48417 .71155 m .48526 .7108 L .48382 .71044 L F
.639 .157 .091 r
.48302 .70798 m .48543 .71053 L .48694 .70773 L F
.4842 .70947 m .48543 .71053 L .48302 .70798 L F
.138 0 0 r
.48694 .70773 m .48543 .71053 L .48699 .70962 L F
.579 .201 .291 r
.48382 .71044 m .48543 .71053 L .48253 .70801 L F
.617 .335 .466 r
.48699 .70962 m .48543 .71053 L .48382 .71044 L F
.764 .516 .559 r
.48526 .7108 m .48699 .70962 L .48478 .7102 L F
.48526 .7108 m .48478 .7102 L .48382 .71044 L F
.639 .157 .091 r
.48253 .70801 m .4842 .70947 L .48302 .70798 L F
.571 .56 .803 r
.48847 .70811 m .48745 .71038 L .48694 .70773 L F
.138 0 0 r
.48694 .70773 m .48699 .70962 L .48847 .70811 L F
.315 .3 .683 r
.42581 .68623 m .42755 .68906 L .42738 .6856 L F
.343 .026 .274 r
.39799 .62138 m .39626 .62087 L .39846 .62041 L F
.39799 .62138 m .39557 .62244 L .39626 .62087 L F
.414 0 0 r
.28884 .64656 m .28733 .64653 L .28517 .64576 L F
.28884 .64656 m .28733 .64653 L .28517 .64576 L F
.512 .907 .926 r
.28884 .64656 m .29042 .64557 L .29062 .64471 L F
.604 .332 .478 r
.29062 .64471 m .28733 .64653 L .28884 .64656 L F
.512 .907 .926 r
.28884 .64656 m .28733 .64653 L .29042 .64557 L F
.898 .763 .704 r
.61541 .57973 m .61679 .5807 L .61566 .57723 L F
.47 .149 .338 r
.37143 .62016 m .37371 .61984 L .37455 .61731 L F
.466 .179 .393 r
.37371 .61984 m .37656 .61667 L .37455 .61731 L F
.225 0 0 r
.3492 .62719 m .35115 .62729 L .35283 .62684 L F
0 0 0 r
.35115 .62729 m .35497 .62676 L .35283 .62684 L F
.661 .607 .783 r
.50394 .79089 m .50574 .78806 L .50391 .78841 L F
.507 .174 .337 r
.50416 .78634 m .50555 .78793 L .50589 .78783 L F
.661 .607 .783 r
.50574 .78806 m .50589 .78783 L .50555 .78793 L F
.507 .174 .337 r
.50555 .78793 m .50578 .7882 L .50589 .78783 L F
.661 .607 .783 r
.50555 .78793 m .50589 .78783 L .50554 .78793 L F
.50574 .78806 m .50554 .78793 L .50391 .78841 L F
.678 .131 0 r
.50247 .78577 m .50435 .78715 L .50416 .78634 L F
.661 .607 .783 r
.50394 .79089 m .50719 .79169 L .50589 .78783 L F
.685 .594 .749 r
.50247 .78577 m .50391 .78841 L .50554 .78793 L F
.678 .131 0 r
.50435 .78715 m .50555 .78793 L .50416 .78634 L F
.685 .594 .749 r
.50247 .78577 m .50554 .78793 L .50589 .78783 L F
.678 .131 0 r
.50435 .78715 m .50578 .7882 L .50555 .78794 L F
.50554 .78793 m .50555 .78794 L .50555 .78793 L F
.50435 .78715 m .50555 .78794 L .50554 .78793 L F
.437 .26 .542 r
.51547 .70395 m .51789 .70576 L .51725 .70414 L F
.416 .291 .602 r
.60902 .63141 m .60741 .63438 L .6072 .63198 L F
.558 .651 .897 r
.33987 .62516 m .34091 .62698 L .33779 .62567 L F
.588 .666 .893 r
.34218 .6248 m .34091 .62698 L .33987 .62516 L F
.493 .544 .837 r
.34218 .6248 m .34331 .62695 L .34091 .62698 L F
.012 0 0 r
.46286 .66827 m .46575 .66628 L .46497 .6667 L F
.815 .416 .296 r
.46575 .66628 m .467 .67008 L .46497 .6667 L F
.46575 .66628 m .46912 .67004 L .467 .67008 L F
.827 .838 .856 r
.69139 .49114 m .69525 .48946 L .69397 .4879 L F
.745 .762 .867 r
.69397 .4879 m .69525 .48946 L .69738 .48829 L F
.544 .752 .973 r
.3383 .62376 m .33779 .62567 L .33587 .62343 L F
.3383 .62376 m .33987 .62516 L .33779 .62567 L F
.7 .16 0 r
.54284 .66664 m .54492 .66872 L .54445 .66836 L F
.698 .234 .146 r
.47515 .66927 m .47734 .67125 L .47321 .67055 L F
.266 0 0 r
.31031 .586 m .3123 .58563 L .31389 .58412 L F
.486 .036 .107 r
.31389 .58412 m .3123 .58563 L .31551 .58504 L F
.441 .1 .29 r
.31389 .58412 m .31551 .58504 L .31586 .5836 L F
.685 .46 .574 r
.59788 .56311 m .60006 .56323 L .59795 .5606 L F
.042 0 0 r
.55798 .58599 m .55992 .58529 L .56083 .58383 L F
.381 0 .152 r
.55992 .58529 m .56309 .58317 L .56083 .58383 L F
.544 .772 .983 r
.52571 .77835 m .52837 .77778 L .52451 .77706 L F
.52571 .77835 m .52837 .77778 L .52451 .77706 L F
.731 .362 .351 r
.55412 .67084 m .55222 .66923 L .55507 .66873 L F
.402 .215 .51 r
.55699 .66806 m .55412 .67084 L .55507 .66873 L F
.284 0 0 r
.32154 .58261 m .32379 .5826 L .3245 .58196 L F
.506 0 0 r
.3245 .58196 m .32379 .5826 L .3274 .58286 L F
0 .105 .631 r
.74836 .48588 m .74932 .48634 L .74827 .48509 L F
.74836 .48588 m .75032 .48768 L .74932 .48634 L F
.496 .276 .51 r
.41922 .60345 m .41904 .60573 L .4168 .60623 L F
.323 .173 .517 r
.42042 .60022 m .421 .60304 L .41922 .60345 L F
.37 .336 .69 r
.421 .60304 m .42141 .60545 L .41922 .60345 L F
.57 .338 .525 r
.41922 .60345 m .42141 .60545 L .41904 .60573 L F
.279 .491 .885 r
.5661 .64921 m .56712 .6479 L .56427 .64633 L F
.143 .196 .659 r
.56658 .6515 m .56712 .6479 L .5661 .64921 L F
.485 .794 .999 r
.3369 .58337 m .33898 .58297 L .34046 .58392 L F
.196 .669 .936 r
.33898 .58297 m .34257 .58378 L .34046 .58392 L F
.692 .584 .729 r
.78072 .50066 m .78126 .50374 L .7784 .50344 L F
.403 .83 .96 r
.54509 .65145 m .54739 .65098 L .54893 .6514 L F
.54509 .65145 m .54739 .65098 L .54893 .6514 L F
.16 .681 .882 r
.551 .65136 m .54739 .65098 L .54893 .6514 L F
.551 .65136 m .54739 .65098 L .54893 .6514 L F
.54 .362 .588 r
.58149 .57381 m .57904 .57196 L .5791 .57341 L F
.58149 .57381 m .58149 .57151 L .57904 .57196 L F
.245 0 .004 r
.488 .61986 m .48997 .61961 L .49069 .61816 L F
0 0 0 r
.49069 .61816 m .49169 .61865 L .49302 .61833 L F
.49069 .61816 m .48997 .61961 L .49169 .61865 L F
.624 .114 0 r
.5383 .62113 m .53916 .62216 L .53709 .62013 L F
.888 .984 .71 r
.66426 .50246 m .66378 .50202 L .66528 .50107 L F
.899 .949 .828 r
.66573 .49881 m .66528 .50107 L .66534 .49893 L F
.717 .444 .512 r
.66378 .50202 m .66032 .49991 L .66476 .50013 L F
.716 .84 .4 r
.66534 .49893 m .66378 .50202 L .66476 .50013 L F
.949 .956 .684 r
.66528 .50107 m .66378 .50202 L .66534 .49893 L F
.69 .367 .424 r
.47983 .70441 m .47958 .70603 L .48258 .70594 L F
0 0 .169 r
.48129 .70259 m .47958 .70603 L .47983 .70441 L F
.06 .373 .84 r
.5526 .62934 m .55525 .6302 L .55187 .62837 L F
.5526 .62934 m .55538 .63121 L .55525 .6302 L F
0 0 .449 r
.4215 .59997 m .42042 .60022 L .42022 .59914 L F
.4215 .59997 m .421 .60304 L .42042 .60022 L F
.299 .79 .882 r
.35256 .59866 m .35288 .59809 L .35079 .5984 L F
.35256 .59866 m .35485 .59821 L .35288 .59809 L F
.454 .243 .502 r
.29037 .59849 m .29199 .59692 L .28963 .59696 L F
0 .292 .775 r
.47959 .66822 m .4777 .66722 L .47608 .66535 L F
.595 .415 .607 r
.78302 .49762 m .78072 .50066 L .78124 .49837 L F
.588 .706 .925 r
.76089 .49172 m .76424 .48996 L .75913 .48884 L F
.76089 .49172 m .76361 .49139 L .76424 .48996 L F
.758 .605 .688 r
.70539 .47099 m .7019 .46854 L .70306 .472 L F
.687 .406 .491 r
.70198 .47334 m .70539 .47099 L .70306 .472 L F
.667 .117 0 r
.54847 .62534 m .54472 .62273 L .5457 .62463 L F
.454 .14 .342 r
.45409 .65743 m .45636 .65699 L .45714 .65449 L F
.468 .164 .365 r
.45636 .65699 m .45934 .65406 L .45714 .65449 L F
.78 .732 .808 r
.50522 .79283 m .50787 .79203 L .50719 .79169 L F
.125 0 0 r
.36354 .63821 m .35965 .63949 L .36138 .6386 L F
.617 .653 .863 r
.29261 .61681 m .29419 .62018 L .29541 .61732 L F
.827 .99 .729 r
.2567 .66643 m .25525 .66837 L .25537 .66745 L F
.689 .952 .954 r
.25537 .66745 m .2535 .6684 L .25525 .66837 L F
.582 .444 .658 r
.2567 .66643 m .25737 .6691 L .25525 .66837 L F
.256 .566 .937 r
.25525 .66837 m .25737 .6691 L .25537 .66745 L F
.689 .952 .954 r
.25537 .66745 m .2535 .6684 L .25525 .66837 L F
.723 .675 .803 r
.73374 .49148 m .7374 .49212 L .73526 .49119 L F
.52 .776 .99 r
.29473 .63296 m .29483 .63104 L .29271 .63117 L F
.29473 .63296 m .29649 .63253 L .29483 .63104 L F
0 0 .191 r
.52773 .60608 m .52809 .60484 L .52798 .60245 L F
0 .025 .591 r
.52773 .60608 m .52914 .60822 L .52809 .60484 L F
.613 .843 .987 r
.74477 .52942 m .7486 .52968 L .74744 .52927 L F
.702 .961 .945 r
.74744 .52927 m .7486 .52968 L .75055 .52831 L F
.447 0 0 r
.44718 .69286 m .45085 .69497 L .45087 .69475 L F
.077 .128 .614 r
.44921 .69163 m .44879 .69315 L .44674 .69096 L F
.752 .255 .045 r
.44652 .69227 m .45045 .69471 L .44718 .69286 L F
.44709 .69249 m .45045 .69471 L .44652 .69227 L F
.45045 .69471 m .45047 .69475 L .44718 .69286 L F
.4459 .6917 m .44709 .69249 L .44652 .69227 L F
.45045 .69471 m .45085 .69497 L .45047 .69475 L F
.4459 .6917 m .44797 .69381 L .45085 .69497 L F
.44797 .69381 m .44847 .69433 L .45004 .69475 L F
.44797 .69381 m .45004 .69475 L .45085 .69497 L F
.83 .93 .55 r
.44982 .69596 m .44942 .6976 L .45063 .69522 L F
.44982 .69596 m .45063 .69522 L .45058 .69508 L F
.705 .913 .967 r
.45144 .69525 m .44942 .6976 L .44982 .69596 L F
.459 .305 .584 r
.45161 .69747 m .44942 .6976 L .45144 .69525 L F
.45178 .69971 m .45147 .69943 L .45161 .69747 L F
.45147 .69943 m .44942 .6976 L .45161 .69747 L F
.83 .93 .55 r
.45058 .69508 m .45063 .69522 L .45087 .69475 L F
.44982 .69596 m .45087 .69475 L .45085 .69497 L F
.923 .674 .542 r
.45161 .69747 m .45432 .69908 L .45178 .69971 L F
.45144 .69525 m .45197 .69639 L .45161 .69747 L F
.715 .693 .828 r
.44982 .69596 m .45197 .69639 L .45144 .69525 L F
.45197 .69639 m .45325 .69665 L .45144 .69525 L F
.923 .674 .542 r
.45144 .69525 m .45207 .69609 L .45197 .69639 L F
.45207 .69609 m .45288 .69717 L .45161 .69747 L F
.45288 .69717 m .45345 .69792 L .45254 .6977 L F
.45288 .69717 m .45254 .6977 L .45161 .69747 L F
.45345 .69792 m .45366 .69869 L .45161 .69747 L F
.687 .72 .874 r
.45212 .69594 m .45325 .69665 L .45248 .69649 L F
.45207 .69609 m .45248 .69649 L .45197 .69639 L F
.45212 .69594 m .45248 .69649 L .45207 .69609 L F
.923 .674 .542 r
.45345 .69792 m .45432 .69908 L .45366 .69869 L F
.45207 .69609 m .45284 .69947 L .45432 .69908 L F
.45144 .69525 m .45154 .69558 L .45207 .69609 L F
.687 .72 .874 r
.45173 .6957 m .45212 .69594 L .45168 .69633 L F
.45212 .69594 m .45197 .69639 L .45168 .69633 L F
.4506 .69501 m .45173 .6957 L .44982 .69596 L F
.45173 .6957 m .45168 .69633 L .44982 .69596 L F
.923 .674 .542 r
.45154 .69558 m .45284 .69947 L .45207 .69609 L F
.687 .72 .874 r
.45069 .69504 m .45325 .69665 L .4506 .69501 L F
.852 .646 .624 r
.45325 .69665 m .45154 .69558 L .45144 .69525 L F
.687 .72 .874 r
.45304 .6961 m .45325 .69665 L .45069 .69504 L F
.852 .646 .624 r
.45325 .69665 m .45284 .69947 L .45154 .69558 L F
.182 0 .007 r
.45195 .69337 m .45407 .69508 L .45268 .69452 L F
.481 .727 .979 r
.45407 .69508 m .45195 .69337 L .45268 .69452 L F
.45407 .69508 m .45325 .69665 L .45298 .69595 L F
.45407 .69508 m .45298 .69595 L .45195 .69337 L F
.182 0 .007 r
.45195 .69337 m .45247 .69412 L .45407 .69508 L F
.422 .755 .995 r
.45247 .69412 m .4548 .6945 L .45407 .69508 L F
.4548 .6945 m .4564 .69476 L .45407 .69508 L F
.7 .903 .543 r
.45407 .69508 m .45164 .69843 L .45313 .69678 L F
.4534 .69636 m .45313 .69678 L .45325 .69665 L F
.45407 .69508 m .45313 .69678 L .4534 .69636 L F
.995 .811 .545 r
.45164 .69843 m .45284 .69947 L .4532 .69702 L F
.45313 .69678 m .4532 .69702 L .45325 .69665 L F
.45164 .69843 m .4532 .69702 L .45313 .69678 L F
.687 .72 .874 r
.45195 .69337 m .45304 .6961 L .4506 .69501 L F
.077 .128 .614 r
.44879 .69315 m .44847 .69433 L .44764 .6927 L F
.44879 .69315 m .44764 .6927 L .44674 .69096 L F
.682 .942 .664 r
.72969 .47285 m .7295 .47252 L .72895 .47104 L F
0 .326 .727 r
.7295 .47252 m .72969 .47285 L .72895 .47104 L F
.7295 .47252 m .73221 .47407 L .72969 .47285 L F
.979 .801 .592 r
.69139 .49114 m .69097 .49352 L .69207 .4942 L F
.947 .957 .716 r
.69097 .49352 m .69013 .4968 L .69207 .4942 L F
.669 .629 .8 r
.78176 .49186 m .77811 .48938 L .78065 .48887 L F
.661 .665 .844 r
.78447 .49122 m .78176 .49186 L .78065 .48887 L F
.524 .492 .763 r
.7853 .49575 m .78176 .49186 L .78447 .49122 L F
.858 .537 .443 r
.46914 .7031 m .46951 .70527 L .47075 .70304 L F
.569 .206 .312 r
.46951 .70527 m .47318 .70309 L .47075 .70304 L F
.433 0 0 r
.45105 .70901 m .45505 .70876 L .45337 .70921 L F
.71 .357 .378 r
.45505 .70876 m .45682 .70931 L .45337 .70921 L F
.927 .949 .614 r
.68934 .49627 m .68819 .50029 L .69013 .4968 L F
.947 .957 .716 r
.69097 .49352 m .68934 .49627 L .69013 .4968 L F
.573 .665 .901 r
.70565 .48825 m .70715 .49111 L .70892 .49033 L F
.589 .482 .699 r
.43055 .66903 m .4329 .66877 L .43191 .66491 L F
.576 .296 .454 r
.43055 .66903 m .43272 .67092 L .4329 .66877 L F
.43055 .66903 m .43029 .67128 L .43272 .67092 L F
.49 .151 .319 r
.29945 .59138 m .3018 .59111 L .30286 .58868 L F
.394 .05 .259 r
.3018 .59111 m .30504 .58828 L .30286 .58868 L F
0 0 .468 r
.65372 .49509 m .65537 .49332 L .65494 .4905 L F
.523 .552 .827 r
.65429 .49695 m .65537 .49332 L .65372 .49509 L F
0 .163 .591 r
.50095 .62007 m .50054 .6198 L .49936 .6188 L F
.50095 .62007 m .50224 .62093 L .50054 .6198 L F
.676 .84 .962 r
.55223 .64294 m .55332 .64401 L .55553 .64315 L F
.55553 .64315 m .55332 .64401 L .55223 .64294 L F
.528 .274 .473 r
.4168 .60623 m .41654 .6082 L .41421 .6086 L F
.524 .292 .506 r
.41904 .60573 m .41654 .6082 L .4168 .60623 L F
.07 0 0 r
.54606 .59523 m .54491 .59466 L .54417 .59632 L F
.54606 .59523 m .54697 .59413 L .54491 .59466 L F
.696 .53 .659 r
.55374 .66395 m .54973 .66666 L .54769 .66248 L F
.689 .725 .878 r
.74688 .50944 m .74347 .50853 L .74591 .508 L F
.235 0 0 r
.74835 .51004 m .74847 .50941 L .74688 .50944 L F
.8 .401 .297 r
.49286 .76345 m .491 .76391 L .49149 .76405 L F
0 0 0 r
.49286 .76345 m .49403 .76325 L .49346 .76227 L F
.49286 .76345 m .49149 .76405 L .49403 .76325 L F
.587 .459 .674 r
.49361 .76197 m .49113 .76189 L .49348 .76158 L F
.38 .842 .802 r
.49337 .76243 m .49286 .76345 L .49346 .76227 L F
.49335 .76247 m .49333 .76251 L .49337 .76243 L F
.49333 .76251 m .49286 .76345 L .49337 .76243 L F
.587 .459 .674 r
.49234 .76343 m .49144 .76378 L .49113 .76189 L F
.831 .625 .624 r
.49144 .76378 m .491 .76391 L .49113 .76189 L F
.38 .842 .802 r
.49137 .7638 m .491 .76391 L .49128 .76384 L F
.831 .625 .624 r
.49149 .76405 m .491 .76391 L .49144 .76378 L F
.38 .842 .802 r
.49305 .76303 m .491 .76391 L .49137 .7638 L F
.49298 .76319 m .49128 .76384 L .49286 .76345 L F
.587 .459 .674 r
.49316 .76284 m .49234 .76343 L .49113 .76189 L F
.38 .842 .802 r
.49305 .76303 m .49128 .76384 L .49298 .76319 L F
.587 .459 .674 r
.49234 .76343 m .49149 .76405 L .49144 .76378 L F
.38 .842 .802 r
.49298 .7632 m .49286 .76345 L .49335 .76247 L F
.587 .459 .674 r
.49403 .76325 m .49274 .76366 L .49316 .76284 L F
.49274 .76366 m .49149 .76405 L .49316 .76284 L F
.49403 .76325 m .49335 .76247 L .49374 .76236 L F
.38 .842 .802 r
.49305 .76303 m .49298 .7632 L .49335 .76247 L F
.413 .296 .61 r
.49346 .76227 m .49403 .76325 L .49591 .76189 L F
.498 .446 .729 r
.49591 .76189 m .49403 .76325 L .49374 .76236 L F
.191 0 0 r
.49486 .76205 m .49374 .76236 L .49346 .76227 L F
.49591 .76189 m .49335 .76247 L .49486 .76205 L F
.498 .446 .729 r
.49591 .76189 m .49374 .76236 L .49348 .76158 L F
.191 0 0 r
.49374 .76236 m .49335 .76247 L .49336 .76245 L F
.49374 .76236 m .49336 .76245 L .49346 .76227 L F
.49591 .76189 m .49305 .76303 L .49335 .76247 L F
.587 .459 .674 r
.49403 .76325 m .49316 .76284 L .49335 .76247 L F
.49374 .76236 m .49335 .76247 L .49361 .76197 L F
.49316 .76284 m .49113 .76189 L .49361 .76197 L F
.28 .48 .876 r
.20749 .55248 m .20883 .5548 L .20868 .55483 L F
.405 .016 .185 r
.3853 .62832 m .38173 .63073 L .38295 .62878 L F
.96 .631 .338 r
.65578 .5036 m .65754 .50663 L .65576 .50392 L F
.34 .506 .877 r
.65754 .50663 m .65859 .50598 L .65576 .50392 L F
0 0 0 r
.58384 .67708 m .58192 .67781 L .58071 .67791 L F
.58527 .67656 m .5856 .67677 L .58384 .67708 L F
.5856 .67677 m .58192 .67781 L .58384 .67708 L F
.985 .758 .512 r
.21238 .5576 m .21212 .56018 L .21276 .5597 L F
.079 0 0 r
.66948 .4865 m .67309 .48645 L .67074 .48604 L F
.66948 .4865 m .67201 .48659 L .67203 .48647 L F
.501 .852 .993 r
.6684 .48665 m .67201 .48659 L .66948 .4865 L F
.6684 .48665 m .6707 .48608 L .67201 .48659 L F
.318 0 0 r
.6707 .48608 m .67199 .48668 L .67201 .48659 L F
.67199 .48668 m .67493 .48805 L .67201 .48659 L F
.079 0 0 r
.67203 .48647 m .67201 .48659 L .67309 .48645 L F
.379 0 0 r
.67201 .48659 m .67533 .48748 L .67309 .48645 L F
.443 0 .074 r
.67309 .48645 m .67533 .48748 L .6763 .48594 L F
.257 .204 .605 r
.60846 .65682 m .60695 .66054 L .60651 .65683 L F
.60846 .65682 m .60896 .65934 L .60695 .66054 L F
.187 .078 .489 r
.60896 .65934 m .60709 .66278 L .60695 .66054 L F
.816 .355 .13 r
.51376 .62967 m .51668 .63129 L .51517 .63086 L F
.412 .332 .656 r
.47906 .70056 m .47997 .70402 L .48129 .70259 L F
.716 .889 .959 r
.66184 .50603 m .65859 .50598 L .6609 .50485 L F
.85 .925 .879 r
.66184 .50603 m .66378 .50202 L .66426 .50246 L F
.66184 .50603 m .6609 .50485 L .66378 .50202 L F
.884 .703 .652 r
.5942 .57749 m .5956 .58047 L .59364 .5794 L F
.86 .653 .62 r
.5956 .58047 m .59265 .58217 L .59364 .5794 L F
.5956 .58047 m .59552 .58342 L .59265 .58217 L F
.75 .558 .636 r
.59911 .58334 m .59552 .58342 L .5956 .58047 L F
.601 .521 .736 r
.78345 .50181 m .78126 .50374 L .78072 .50066 L F
.634 .532 .721 r
.78345 .50181 m .78227 .50534 L .78126 .50374 L F
.409 .223 .514 r
.42156 .70197 m .41923 .69986 L .4182 .70386 L F
.887 .587 .473 r
.72097 .47363 m .7238 .47693 L .72358 .47486 L F
.029 0 .392 r
.5168 .67851 m .51627 .68106 L .51744 .6796 L F
.707 .511 .621 r
.77635 .50928 m .77618 .51063 L .77392 .51158 L F
.624 .496 .686 r
.77894 .50884 m .77618 .51063 L .77635 .50928 L F
.714 .631 .763 r
.286 .62301 m .28726 .62628 L .28931 .62543 L F
.557 .191 .301 r
.49767 .65972 m .50204 .65822 L .50119 .6575 L F
.242 .12 .506 r
.60777 .63703 m .60782 .63921 L .60585 .64053 L F
.196 .134 .556 r
.60782 .63921 m .60653 .64304 L .60585 .64053 L F
.193 0 .042 r
.58897 .56826 m .59263 .56513 L .58951 .56551 L F
.421 .113 .335 r
.5866 .56877 m .58897 .56826 L .58951 .56551 L F
.384 0 .145 r
.49367 .65116 m .49591 .65083 L .49772 .64822 L F
.325 .679 .978 r
.49772 .64822 m .49951 .64805 L .49579 .64753 L F
.582 .542 .775 r
.50161 .65012 m .49772 .64822 L .49951 .64805 L F
.379 .568 .911 r
.49951 .64805 m .50161 .65012 L .49772 .64822 L F
.702 .334 .347 r
.49772 .64822 m .50072 .65038 L .49951 .64805 L F
.49772 .64822 m .49591 .65083 L .50072 .65038 L F
.325 .679 .978 r
.49772 .64822 m .49951 .64805 L .49579 .64753 L F
.49579 .64753 m .49951 .64805 L .49772 .64822 L F
.439 0 0 r
.52952 .63506 m .53203 .6358 L .53317 .63501 L F
.695 .187 .023 r
.53203 .6358 m .53546 .63687 L .53317 .63501 L F
.631 .069 0 r
.53301 .6106 m .52914 .60822 L .53026 .60947 L F
.52 .32 .549 r
.29561 .63789 m .29782 .63748 L .298 .6348 L F
.452 .656 .948 r
.298 .6348 m .29884 .633 L .29649 .63253 L F
.298 .6348 m .29929 .63431 L .29884 .633 L F
.334 .263 .626 r
.298 .6348 m .29984 .6367 L .29929 .63431 L F
.468 .277 .538 r
.298 .6348 m .29782 .63748 L .29984 .6367 L F
.417 .12 .351 r
.46645 .70042 m .46449 .70095 L .46379 .70288 L F
.553 .77 .979 r
.74238 .52988 m .74363 .52819 L .74138 .52854 L F
.74238 .52988 m .74477 .52942 L .74363 .52819 L F
.24 .106 .49 r
.44602 .68866 m .4459 .6917 L .44477 .69034 L F
.559 .293 .47 r
.5837 .58268 m .58046 .58552 L .58159 .58309 L F
.397 0 .081 r
.75904 .52374 m .75809 .5254 L .75563 .52565 L F
.413 0 .089 r
.76118 .5244 m .75904 .52374 L .7612 .52294 L F
.76118 .5244 m .75809 .5254 L .75904 .52374 L F
.875 .437 .127 r
.57831 .67738 m .57703 .67693 L .57573 .67485 L F
.683 .184 .053 r
.58071 .67791 m .57703 .67693 L .57831 .67738 L F
.327 .44 .823 r
.57297 .64301 m .57599 .64503 L .57438 .64621 L F
.221 .241 .669 r
.57599 .64503 m .57611 .64807 L .57438 .64621 L F
.463 .759 .994 r
.74419 .48345 m .74525 .48218 L .74322 .48217 L F
.74419 .48345 m .74623 .48322 L .74525 .48218 L F
.276 0 0 r
.3524 .58472 m .35426 .58536 L .35572 .58572 L F
.23 .728 .91 r
.35572 .58572 m .35426 .58536 L .35791 .58561 L F
.066 0 .143 r
.55559 .58889 m .55732 .58829 L .55798 .58599 L F
0 0 0 r
.5544 .59004 m .55732 .58829 L .55559 .58889 L F
.459 .189 .416 r
.52547 .76355 m .52786 .76329 L .52856 .7612 L F
.93 .735 .252 r
.6035 .61729 m .60312 .61378 L .60353 .61479 L F
0 0 0 r
.58497 .65468 m .5864 .65343 L .58723 .65189 L F
0 0 .062 r
.58725 .65183 m .58807 .65041 L .58851 .64806 L F
.64 .955 .936 r
.58807 .65041 m .58768 .64988 L .58879 .64916 L F
.58902 .64853 m .58932 .64882 L .58966 .64726 L F
.58807 .65041 m .58932 .64882 L .58902 .64853 L F
.58807 .65041 m .58879 .64916 L .58932 .64882 L F
.102 0 0 r
.58813 .64998 m .58957 .64907 L .58932 .64882 L F
.58957 .64907 m .59153 .64783 L .58932 .64882 L F
0 0 .062 r
.58723 .65189 m .58807 .65041 L .58725 .65183 L F
0 0 0 r
.58723 .65189 m .5864 .65343 L .58807 .65041 L F
.609 .613 .83 r
.49752 .78845 m .50096 .78966 L .49979 .78676 L F
.424 0 .09 r
.66956 .49452 m .66831 .49609 L .6664 .49607 L F
.969 .716 .497 r
.66956 .49452 m .66965 .49756 L .66831 .49609 L F
.659 .838 .969 r
.79396 .51993 m .7904 .51986 L .79275 .5171 L F
.529 .43 .687 r
.79618 .5174 m .79396 .51993 L .79275 .5171 L F
.79618 .5174 m .79617 .51982 L .79396 .51993 L F
.182 .044 .446 r
.28807 .60335 m .28935 .60285 L .29037 .59849 L F
.25 .21 .616 r
.28807 .60335 m .28981 .60538 L .28935 .60285 L F
.323 .226 .587 r
.28829 .60577 m .28981 .60538 L .28807 .60335 L F
.595 .415 .607 r
.78302 .49762 m .78325 .49994 L .78072 .50066 L F
.628 .537 .732 r
.7853 .49575 m .78556 .497 L .78302 .49762 L F
.517 .357 .604 r
.78564 .4994 m .78302 .49762 L .78556 .497 L F
.78564 .4994 m .78325 .49994 L .78302 .49762 L F
.839 .607 .588 r
.59911 .58334 m .59608 .58493 L .59552 .58342 L F
.59911 .58334 m .59898 .58583 L .59608 .58493 L F
.495 .216 .42 r
.70867 .47197 m .7115 .47197 L .71129 .47 L F
.504 .222 .42 r
.71129 .47 m .7115 .47197 L .71409 .47093 L F
.544 .292 .484 r
.59074 .65493 m .58843 .65748 L .58739 .6542 L F
.59074 .65493 m .59083 .65709 L .58843 .65748 L F
.772 .598 .663 r
.5932 .65384 m .59083 .65709 L .59074 .65493 L F
0 0 0 r
.31109 .63837 m .31043 .63865 L .31307 .63744 L F
.623 .296 .396 r
.50925 .65088 m .51243 .65085 L .51272 .64934 L F
.296 .013 .302 r
.51272 .64934 m .51243 .65085 L .51458 .64853 L F
.209 .699 .924 r
.39062 .58833 m .39214 .58886 L .38852 .58833 L F
.321 .718 .98 r
.39281 .58796 m .39214 .58886 L .39062 .58833 L F
.39281 .58796 m .39418 .58883 L .39214 .58886 L F
.865 .86 .834 r
.29561 .63789 m .29168 .63973 L .29374 .63992 L F
0 0 0 r
.29561 .63789 m .29575 .63881 L .29782 .63748 L F
.29561 .63789 m .29374 .63992 L .29575 .63881 L F
.326 0 .188 r
.45178 .65788 m .44892 .66006 L .45125 .65964 L F
.486 .208 .417 r
.45367 .65942 m .45178 .65788 L .45125 .65964 L F
.45367 .65942 m .45409 .65743 L .45178 .65788 L F
.556 .819 .995 r
.51331 .64523 m .51489 .64635 L .51688 .64563 L F
.394 .17 .452 r
.51489 .64635 m .51458 .64853 L .51688 .64563 L F
.534 .014 0 r
.45337 .70921 m .45682 .70931 L .45536 .7105 L F
.459 0 0 r
.45682 .70931 m .45779 .71039 L .45536 .7105 L F
.45682 .70931 m .4594 .71035 L .45779 .71039 L F
.369 .759 .988 r
.37894 .58643 m .38113 .5863 L .38265 .58709 L F
.404 .738 .992 r
.38336 .5859 m .38265 .58709 L .38113 .5863 L F
.38336 .5859 m .3848 .58695 L .38265 .58709 L F
.323 .583 .936 r
.20579 .55059 m .20542 .55216 L .2051 .55174 L F
.20579 .55059 m .20749 .55248 L .20542 .55216 L F
.472 .32 .593 r
.48577 .62309 m .48786 .62285 L .488 .61986 L F
.047 0 .211 r
.48584 .62556 m .48786 .62285 L .48577 .62309 L F
.784 .866 .91 r
.66844 .50786 m .67213 .50711 L .67124 .50627 L F
.696 .911 .97 r
.67332 .50511 m .67213 .50711 L .67439 .50613 L F
.67332 .50511 m .67124 .50627 L .67213 .50711 L F
.473 .096 .242 r
.57076 .57666 m .57317 .57648 L .57366 .5751 L F
.439 .082 .261 r
.57317 .57648 m .57596 .57464 L .57366 .5751 L F
.457 .294 .571 r
.42796 .6746 m .43029 .67128 L .42781 .67199 L F
.666 .652 .826 r
.55657 .60337 m .55725 .59965 L .55536 .60163 L F
.55657 .60337 m .55872 .60267 L .55725 .59965 L F
.569 0 0 r
.55536 .60163 m .55872 .60267 L .55657 .60337 L F
0 0 .395 r
.2922 .63036 m .29271 .63117 L .29136 .62774 L F
.714 .631 .763 r
.286 .62301 m .28931 .62543 L .28797 .6225 L F
.113 0 0 r
.46955 .64573 m .47154 .6452 L .47253 .64345 L F
0 0 0 r
.47488 .64058 m .47253 .64345 L .47403 .64211 L F
.151 0 .007 r
.47253 .64345 m .47341 .64453 L .47403 .64211 L F
.47253 .64345 m .47154 .6452 L .47341 .64453 L F
.745 .762 .867 r
.69397 .4879 m .69738 .48829 L .69639 .4854 L F
.672 .703 .871 r
.69639 .4854 m .69738 .48829 L .70012 .48638 L F
.61 .191 .223 r
.73609 .47604 m .73944 .47467 L .73593 .47484 L F
.73609 .47604 m .73869 .47635 L .73944 .47467 L F
.516 .832 1 r
.74067 .47472 m .74104 .47549 L .73955 .47511 L F
.219 0 .056 r
.73944 .47467 m .74104 .47549 L .74145 .47634 L F
.73944 .47467 m .73869 .47635 L .74104 .47549 L F
0 .501 .714 r
.73991 .47294 m .74414 .47354 L .73955 .47511 L F
.516 .832 1 r
.74128 .47452 m .74104 .47549 L .74067 .47472 L F
.7418 .47501 m .74104 .47549 L .74128 .47452 L F
.483 .313 .574 r
.73869 .47635 m .74118 .47781 L .74104 .47549 L F
.497 .848 .994 r
.74104 .47549 m .74519 .47417 L .74614 .47545 L F
.74519 .47417 m .74532 .4742 L .74614 .47545 L F
.74528 .47414 m .74536 .47417 L .74614 .47545 L F
.543 .876 .991 r
.74614 .47545 m .74536 .47417 L .74583 .47432 L F
.956 .657 .426 r
.74438 .47341 m .74446 .47383 L .74583 .47432 L F
.543 .876 .991 r
.74536 .47417 m .74534 .47412 L .74583 .47432 L F
.956 .657 .426 r
.74528 .47414 m .74536 .47417 L .74518 .47409 L F
.516 .832 1 r
.74414 .47354 m .74534 .47412 L .74528 .47414 L F
.843 .918 .884 r
.74414 .47354 m .74391 .47222 L .74438 .47341 L F
.813 .762 .805 r
.74391 .47222 m .74412 .47302 L .74438 .47341 L F
.516 .832 1 r
.74409 .47357 m .74444 .47374 L .74104 .47549 L F
.74444 .47374 m .74471 .47432 L .74104 .47549 L F
.813 .762 .805 r
.74412 .47302 m .74474 .47532 L .74444 .47374 L F
.74412 .47302 m .74444 .47374 L .74438 .47341 L F
.516 .832 1 r
.74444 .47374 m .74528 .47414 L .74471 .47432 L F
.74414 .47354 m .74528 .47414 L .74409 .47357 L F
.956 .657 .426 r
.74518 .47409 m .74536 .47417 L .74583 .47432 L F
.74446 .47383 m .74528 .47414 L .74518 .47409 L F
.74536 .47417 m .74581 .47434 L .74583 .47432 L F
.908 .557 .363 r
.74474 .47532 m .74641 .47675 L .74583 .47435 L F
.74581 .47434 m .74583 .47435 L .74583 .47432 L F
.74474 .47532 m .74583 .47435 L .74581 .47434 L F
.497 .848 .994 r
.74519 .47417 m .74528 .47414 L .74532 .4742 L F
.74528 .47414 m .74534 .47412 L .74536 .47417 L F
.956 .657 .426 r
.74446 .47383 m .74474 .47532 L .74581 .47434 L F
.814 .616 .06 r
.74104 .47549 m .7409 .47641 L .73955 .47511 L F
0 .089 .629 r
.7409 .47641 m .7415 .47508 L .73991 .47294 L F
.637 .157 0 r
.74025 .47356 m .7415 .47508 L .74053 .47408 L F
.73991 .47294 m .74065 .47393 L .74025 .47356 L F
.74065 .47393 m .7415 .47508 L .74025 .47356 L F
.516 .832 1 r
.74414 .47354 m .7418 .47501 L .74128 .47452 L F
.219 0 .056 r
.74145 .47634 m .74104 .47549 L .74158 .47644 L F
.431 .1 .302 r
.39352 .62314 m .39261 .62565 L .39043 .62609 L F
.445 .136 .346 r
.39557 .62244 m .39261 .62565 L .39352 .62314 L F
.988 .737 .456 r
.72868 .50601 m .7286 .50831 L .7294 .50873 L F
0 0 .429 r
.73047 .51059 m .72939 .51234 L .72939 .51193 L F
.73047 .51059 m .72939 .51193 L .7294 .50873 L F
.73047 .51059 m .7294 .50873 L .7286 .50831 L F
.637 .141 0 r
.72937 .50958 m .73047 .51059 L .72995 .50996 L F
.72937 .50958 m .72995 .50996 L .7286 .50831 L F
.72937 .50958 m .7286 .50831 L .72847 .50742 L F
.781 .419 .371 r
.72647 .50827 m .72937 .50958 L .72847 .50742 L F
.742 .993 .849 r
.72937 .50958 m .72871 .50932 L .72883 .50922 L F
.72937 .50958 m .72883 .50922 L .73127 .50721 L F
.287 .469 .865 r
.73163 .50916 m .73047 .51059 L .72937 .50958 L F
.73185 .50912 m .73047 .51059 L .73163 .50916 L F
.223 .734 .884 r
.34257 .58378 m .34469 .58358 L .34632 .58384 L F
0 .524 .852 r
.34698 .58356 m .34632 .58384 L .34469 .58358 L F
.34698 .58356 m .34846 .58433 L .34632 .58384 L F
.758 .532 0 r
.56833 .66093 m .56805 .65942 L .56779 .65747 L F
.045 .229 .729 r
.56833 .66093 m .56916 .65969 L .56805 .65942 L F
.56833 .66093 m .57016 .66272 L .56916 .65969 L F
0 0 .147 r
.21292 .5582 m .21238 .5576 L .21105 .55626 L F
.21292 .5582 m .21212 .56018 L .21238 .5576 L F
.155 0 0 r
.36675 .63693 m .36755 .63782 L .36551 .63809 L F
.36675 .63693 m .3689 .63633 L .36755 .63782 L F
.53 .859 .996 r
.52823 .63441 m .52742 .63559 L .52629 .63491 L F
.52823 .63441 m .52952 .63506 L .52742 .63559 L F
.447 .266 .542 r
.21118 .56603 m .21074 .56847 L .20908 .56903 L F
.353 .188 .513 r
.21074 .56847 m .20908 .57028 L .20908 .56903 L F
.415 .622 .937 r
.77574 .48532 m .7746 .48681 L .77364 .48543 L F
.77574 .48532 m .77756 .48755 L .7746 .48681 L F
.813 .575 .578 r
.60402 .56519 m .60723 .56337 L .6036 .5634 L F
.60402 .56519 m .60737 .56577 L .60723 .56337 L F
.465 0 0 r
.54245 .62287 m .5412 .62295 L .53916 .62216 L F
.045 .613 .707 r
.54472 .62273 m .5412 .62295 L .54245 .62287 L F
.287 .784 .871 r
.36046 .59725 m .35687 .59759 L .3583 .59788 L F
.466 .073 .208 r
.31551 .58504 m .31934 .58258 L .31586 .5836 L F
.31551 .58504 m .31781 .58492 L .31934 .58258 L F
.329 0 .053 r
.31781 .58492 m .32154 .58261 L .31934 .58258 L F
.585 .811 .986 r
.73771 .51054 m .73537 .51121 L .73417 .50999 L F
.396 .394 .74 r
.47139 .66412 m .47024 .66543 L .46782 .66392 L F
.234 .058 .426 r
.47672 .63732 m .47488 .64058 L .47635 .63952 L F
.234 0 .273 r
.47403 .64211 m .47635 .63952 L .47488 .64058 L F
.612 .63 .845 r
.50294 .77704 m .50515 .78036 L .50238 .78051 L F
.50294 .77704 m .50238 .78051 L .5035 .78002 L F
.592 .349 .517 r
.50515 .78036 m .50471 .78274 L .50238 .78051 L F
.009 .248 .754 r
.50238 .78051 m .50471 .78274 L .5035 .78002 L F
.472 .281 .54 r
.49995 .67954 m .49788 .67762 L .49999 .67711 L F
.49995 .67954 m .49781 .68023 L .49788 .67762 L F
.49788 .67762 m .49995 .67954 L .49999 .67711 L F
.49788 .67762 m .49781 .68023 L .49995 .67954 L F
.49995 .67954 m .49781 .68023 L .49788 .67762 L F
.458 .209 .447 r
.55732 .58829 m .55992 .58529 L .55798 .58599 L F
.95 .696 .518 r
.60202 .60897 m .60047 .61082 L .60049 .60824 L F
.372 0 .072 r
.60148 .61007 m .60047 .61082 L .60202 .60897 L F
.556 0 0 r
.59263 .56513 m .59411 .56604 L .59553 .56626 L F
.367 0 0 r
.59411 .56604 m .5975 .56527 L .59553 .56626 L F
.939 .582 .306 r
.57773 .65354 m .57816 .65617 L .57912 .65476 L F
.861 .777 .768 r
.57773 .65354 m .57912 .65476 L .58028 .65211 L F
.757 .301 .169 r
.57816 .65617 m .58135 .65722 L .57912 .65476 L F
.244 .301 .724 r
.56391 .59684 m .56547 .59888 L .56399 .59993 L F
0 0 .421 r
.56547 .59888 m .56472 .60281 L .56399 .59993 L F
.7 .696 .843 r
.32976 .64677 m .33093 .64942 L .3325 .64757 L F
.777 .841 .901 r
.71526 .48893 m .71851 .48871 L .71749 .48772 L F
.9 .904 .818 r
.72015 .48423 m .71851 .48871 L .72098 .48582 L F
.72015 .48423 m .71749 .48772 L .71851 .48871 L F
.522 .416 .675 r
.42633 .67756 m .42845 .67706 L .42796 .6746 L F
.525 .368 .61 r
.42634 .67987 m .42845 .67706 L .42633 .67756 L F
.45 .582 .894 r
.20749 .55248 m .20989 .55299 L .20883 .5548 L F
.287 .371 .775 r
.20989 .55299 m .21105 .55626 L .20883 .5548 L F
.415 .187 .457 r
.36913 .62047 m .37082 .62203 L .37143 .62016 L F
.36913 .62047 m .36881 .62271 L .37082 .62203 L F
.534 .766 .982 r
.67775 .50675 m .67892 .50513 L .67671 .50515 L F
.67775 .50675 m .68003 .50636 L .67892 .50513 L F
.803 .388 .26 r
.48142 .67117 m .48447 .67194 L .48211 .67267 L F
.86 .495 .356 r
.48447 .67194 m .48464 .67414 L .48211 .67267 L F
.109 .175 .651 r
.45406 .67617 m .4522 .67581 L .45526 .67461 L F
.541 .651 .906 r
.51627 .68106 m .51916 .68072 L .51744 .6796 L F
.018 0 .164 r
.61122 .62767 m .60921 .62902 L .61127 .62601 L F
.166 .013 .414 r
.60902 .63141 m .60921 .62902 L .61122 .62767 L F
.983 .734 .477 r
.60175 .59712 m .60296 .60044 L .60171 .59954 L F
.974 .807 .614 r
.60171 .59954 m .60296 .60044 L .60231 .6026 L F
.64 .438 .593 r
.59263 .5767 m .59364 .5794 L .59252 .57985 L F
.59263 .5767 m .5942 .57749 L .59364 .5794 L F
.64 .412 .557 r
.58896 .57848 m .59263 .5767 L .59252 .57985 L F
.218 0 .236 r
.52856 .7612 m .5287 .76207 L .53035 .76026 L F
.092 0 .237 r
.52856 .7612 m .52786 .76329 L .5287 .76207 L F
.446 .797 .998 r
.68376 .5069 m .6825 .50608 L .68003 .50636 L F
.82 .978 .687 r
.68482 .50447 m .68376 .5069 L .68632 .50343 L F
.749 .909 .947 r
.68482 .50447 m .6825 .50608 L .68376 .5069 L F
.601 .521 .736 r
.78345 .50181 m .78072 .50066 L .78325 .49994 L F
.584 .796 .98 r
.51789 .70576 m .51948 .70727 L .52214 .70645 L F
.777 .692 .77 r
.59532 .64843 m .59635 .64682 L .595 .64539 L F
.328 .495 .871 r
.33504 .62162 m .3341 .62315 L .33233 .62028 L F
.293 .448 .845 r
.33504 .62162 m .33587 .62343 L .3341 .62315 L F
.351 0 0 r
.67533 .48748 m .67877 .48579 L .6763 .48594 L F
.57 .754 .965 r
.78693 .49058 m .78765 .49183 L .78447 .49122 L F
.566 .466 .7 r
.78768 .49479 m .78447 .49122 L .78765 .49183 L F
.538 .736 .967 r
.78927 .4901 m .78765 .49183 L .78693 .49058 L F
.502 .28 .509 r
.79041 .49404 m .78765 .49183 L .78927 .4901 L F
.79041 .49404 m .78768 .49479 L .78765 .49183 L F
.114 .414 .862 r
.50925 .62639 m .51177 .62768 L .51099 .62858 L F
.127 .434 .873 r
.51177 .62768 m .51376 .62967 L .51099 .62858 L F
.725 .772 .89 r
.52096 .77423 m .52187 .77591 L .52335 .77516 L F
.52335 .77516 m .52187 .77591 L .52096 .77423 L F
.994 .746 .422 r
.52187 .77591 m .52094 .77674 L .52096 .77423 L F
.725 .772 .89 r
.52335 .77516 m .52187 .77591 L .52096 .77423 L F
.927 .97 .756 r
.68621 .50126 m .68632 .50343 L .68819 .50029 L F
.946 .955 .661 r
.68621 .50126 m .68482 .50447 L .68632 .50343 L F
.297 .782 .711 r
.53793 .59757 m .53397 .59901 L .53636 .59962 L F
.301 0 0 r
.53821 .59825 m .53793 .59757 L .53636 .59962 L F
.53821 .59825 m .53969 .59746 L .53793 .59757 L F
.703 .286 .252 r
.60006 .56323 m .60402 .56519 L .6036 .5634 L F
.902 .633 .521 r
.25537 .66745 m .25737 .6691 L .2567 .66643 L F
.606 .063 0 r
.48869 .63739 m .49197 .64006 L .49211 .63835 L F
.48869 .63739 m .49064 .63929 L .49197 .64006 L F
.065 .01 .478 r
.49064 .63929 m .48909 .64254 L .49197 .64006 L F
.456 .451 .764 r
.49197 .64006 m .49419 .63996 L .49211 .63835 L F
.112 0 0 r
.35497 .62676 m .3571 .62644 L .35851 .62575 L F
.164 0 0 r
.3571 .62644 m .36087 .62591 L .35851 .62575 L F
.353 .12 .415 r
.56304 .6799 m .56074 .6828 L .56118 .68069 L F
.56304 .6799 m .56074 .6828 L .56118 .68069 L F
.265 0 .305 r
.57852 .58593 m .57823 .58825 L .57626 .58927 L F
.583 .339 .512 r
.58046 .58552 m .57823 .58825 L .57852 .58593 L F
.799 .825 .872 r
.71114 .4726 m .71479 .47181 L .71409 .47093 L F
.928 .744 .634 r
.55349 .66292 m .55411 .6655 L .55472 .66446 L F
.741 .744 .854 r
.55349 .66292 m .55472 .66446 L .5569 .66341 L F
.518 .225 .409 r
.55411 .6655 m .5569 .66341 L .55472 .66446 L F
.613 .661 .873 r
.32886 .61782 m .32706 .61952 L .32681 .61867 L F
.615 .614 .827 r
.33036 .62079 m .32706 .61952 L .32886 .61782 L F
.802 .738 .793 r
.42444 .70363 m .4228 .70573 L .42156 .70197 L F
0 0 .358 r
.42244 .70463 m .4228 .70573 L .42236 .70465 L F
.529 .359 .595 r
.42197 .70369 m .4228 .70573 L .42058 .70616 L F
.889 .926 .839 r
.42156 .7051 m .4228 .70573 L .42444 .70363 L F
.42259 .7046 m .42444 .70363 L .42495 .70346 L F
.42156 .7051 m .4225 .70462 L .42259 .7046 L F
.4225 .70462 m .42444 .70363 L .42259 .7046 L F
0 0 .358 r
.42156 .70197 m .42244 .70463 L .42197 .70369 L F
.42244 .70463 m .42236 .70465 L .42197 .70369 L F
.704 .773 .283 r
.59618 .63116 m .59634 .63066 L .59703 .62896 L F
0 0 0 r
.59703 .62896 m .59844 .62778 L .59932 .62587 L F
.59634 .63066 m .59844 .62778 L .59703 .62896 L F
.545 .795 .991 r
.37671 .59534 m .38276 .59661 L .37932 .59492 L F
.2 0 0 r
.38438 .59589 m .37932 .59492 L .38276 .59661 L F
.183 .713 .725 r
.76369 .51211 m .76239 .51247 L .76142 .51225 L F
.76369 .51211 m .76495 .5119 L .76239 .51247 L F
.572 .021 0 r
.66717 .48528 m .66948 .4865 L .67074 .48604 L F
.391 .071 .3 r
.48198 .64653 m .48159 .6485 L .47918 .64885 L F
.552 .211 .344 r
.48399 .648 m .48159 .6485 L .48198 .64653 L F
.602 .462 .663 r
.48408 .64318 m .48488 .64613 L .48198 .64653 L F
.528 .225 .396 r
.48488 .64613 m .48399 .648 L .48198 .64653 L F
.137 0 .389 r
.61683 .61121 m .61662 .61395 L .61533 .61476 L F
0 0 .339 r
.61662 .61395 m .61536 .61717 L .61533 .61476 L F
.371 0 .105 r
.45105 .70901 m .44968 .71102 L .44743 .71132 L F
.264 0 0 r
.45284 .71042 m .44968 .71102 L .45105 .70901 L F
.522 .045 .064 r
.45337 .70921 m .45284 .71042 L .45105 .70901 L F
.372 0 0 r
.49556 .61839 m .49936 .6188 L .49683 .61881 L F
.861 .777 .768 r
.57773 .65354 m .58028 .65211 L .57827 .65096 L F
.396 0 .071 r
.29136 .62774 m .2952 .62573 L .29297 .62606 L F
.52 .499 .773 r
.70867 .47197 m .71114 .4726 L .7115 .47197 L F
.557 .191 .301 r
.49767 .65972 m .50183 .65968 L .50204 .65822 L F
.455 .827 .992 r
.42058 .70616 m .42156 .7051 L .41928 .70523 L F
.42058 .70616 m .4228 .70573 L .42156 .7051 L F
.927 .97 .756 r
.68621 .50126 m .68819 .50029 L .68778 .49977 L F
.927 .949 .614 r
.68934 .49627 m .68778 .49977 L .68819 .50029 L F
.906 .6 .455 r
.61591 .59232 m .61968 .59287 L .61518 .58992 L F
.993 .811 .557 r
.61679 .59903 m .6177 .60011 L .61821 .59465 L F
.61679 .59903 m .61821 .59465 L .61818 .59596 L F
.906 .6 .455 r
.61591 .59232 m .61911 .59623 L .61968 .59287 L F
.592 .274 .4 r
.55222 .66923 m .54926 .67138 L .54904 .66856 L F
.55222 .66923 m .55267 .67103 L .54926 .67138 L F
.731 .362 .351 r
.55412 .67084 m .55267 .67103 L .55222 .66923 L F
.36 .725 .988 r
.30967 .63435 m .31011 .63324 L .30795 .63359 L F
.30967 .63435 m .31126 .6341 L .31011 .63324 L F
.699 .564 .699 r
.30967 .63435 m .31307 .63744 L .31126 .6341 L F
.30967 .63435 m .31109 .63837 L .31307 .63744 L F
.793 .726 .79 r
.59188 .65988 m .58855 .65994 L .59083 .65709 L F
.742 .701 .813 r
.59467 .65766 m .59188 .65988 L .59083 .65709 L F
0 0 0 r
.59844 .62778 m .6006 .62478 L .59932 .62587 L F
.717 .59 .713 r
.55886 .60712 m .55619 .60587 L .56013 .60588 L F
.594 .253 .361 r
.56013 .60588 m .56179 .6075 L .55886 .60712 L F
.56013 .60588 m .56235 .60609 L .56179 .6075 L F
.385 .603 .934 r
.72098 .48582 m .72211 .48436 L .72015 .48423 L F
.917 .917 .8 r
.72103 .48842 m .72211 .48436 L .72098 .48582 L F
.377 .823 .697 r
.54153 .70339 m .53837 .70492 L .53929 .704 L F
.094 0 .354 r
.61351 .62272 m .61317 .625 L .61127 .62601 L F
.011 0 .173 r
.61127 .62601 m .61232 .62716 L .61122 .62767 L F
.61127 .62601 m .61317 .625 L .61232 .62716 L F
.282 .634 .964 r
.76419 .48272 m .76217 .4825 L .76111 .48128 L F
.319 .027 .302 r
.33241 .60284 m .33142 .60535 L .32967 .60579 L F
.208 0 .245 r
.33343 .60443 m .33241 .60284 L .33454 .60216 L F
.33343 .60443 m .33142 .60535 L .33241 .60284 L F
.964 .634 .309 r
.79745 .52322 m .79817 .52618 L .79668 .52456 L F
.565 .677 .915 r
.7996 .52144 m .80039 .52337 L .79745 .52322 L F
.546 .134 .212 r
.79745 .52322 m .80039 .52337 L .79895 .52413 L F
.853 .793 .792 r
.79668 .52456 m .7996 .52144 L .79745 .52322 L F
.293 .506 .891 r
.45909 .69974 m .45763 .70076 L .45691 .69907 L F
.645 .238 .257 r
.45763 .70076 m .45652 .70271 L .4601 .70254 L F
.293 .506 .891 r
.45909 .69974 m .45763 .70076 L .45691 .69907 L F
0 0 .364 r
.53448 .61349 m .53301 .6106 L .53373 .61208 L F
.497 .196 .385 r
.41421 .6086 m .41344 .61103 L .4111 .61143 L F
.491 .187 .378 r
.41654 .6082 m .41344 .61103 L .41421 .6086 L F
.542 .533 .795 r
.60716 .65092 m .60584 .65495 L .60578 .65173 L F
.60716 .65092 m .60791 .65441 L .60584 .65495 L F
.511 .408 .674 r
.60791 .65441 m .60846 .65682 L .60584 .65495 L F
.428 .417 .744 r
.60584 .65495 m .60846 .65682 L .60651 .65683 L F
.237 .716 .935 r
.35791 .58561 m .36009 .58558 L .36156 .58611 L F
.396 .794 .986 r
.36009 .58558 m .36379 .58594 L .36156 .58611 L F
.41 .253 .555 r
.42582 .69418 m .42406 .6947 L .42602 .69668 L F
.776 .679 .757 r
.48589 .68009 m .48435 .67661 L .48575 .67755 L F
.348 .327 .694 r
.48734 .67723 m .48575 .67755 L .48435 .67661 L F
.48734 .67723 m .48798 .67955 L .48575 .67755 L F
.484 .334 .601 r
.48575 .67755 m .48798 .67955 L .48589 .68009 L F
.834 .985 .872 r
.48349 .6659 m .47959 .66822 L .48196 .66782 L F
.66 .254 .264 r
.48567 .66804 m .48349 .6659 L .48196 .66782 L F
.051 .288 .779 r
.32749 .64603 m .32796 .64494 L .32568 .64302 L F
.321 .785 .662 r
.32976 .64677 m .32796 .64494 L .32749 .64603 L F
.419 .591 .914 r
.59635 .64682 m .59663 .64507 L .595 .64539 L F
.444 .71 .98 r
.41326 .59773 m .41258 .59904 L .41058 .5973 L F
.41326 .59773 m .41423 .59888 L .41258 .59904 L F
.744 .57 .658 r
.58739 .6542 m .58494 .65706 L .58497 .65468 L F
0 0 .202 r
.58494 .65706 m .5864 .65343 L .58497 .65468 L F
.471 .284 .545 r
.47918 .64885 m .47933 .65123 L .47706 .65146 L F
.29 .192 .567 r
.47933 .65123 m .47786 .654 L .47706 .65146 L F
.447 .064 .218 r
.30504 .58828 m .30732 .58802 L .30816 .58665 L F
.491 .168 .347 r
.30732 .58802 m .31031 .586 L .30816 .58665 L F
.708 .512 .62 r
.5055 .64315 m .5084 .64531 L .50792 .64356 L F
.5055 .64315 m .50518 .64578 L .5084 .64531 L F
.609 .468 .664 r
.5055 .64315 m .50792 .64356 L .507 .64052 L F
.366 .663 .971 r
.51007 .7564 m .512 .75786 L .50907 .75761 L F
.51007 .7564 m .512 .75786 L .50907 .75761 L F
0 .481 .852 r
.54248 .6402 m .54493 .64089 L .54648 .64208 L F
.101 .578 .909 r
.5472 .64149 m .54648 .64208 L .54493 .64089 L F
.68 .143 0 r
.55155 .64897 m .55333 .65079 L .55482 .6516 L F
0 .182 .7 r
.55608 .65206 m .55482 .6516 L .55333 .65079 L F
.55608 .65206 m .55701 .65344 L .55482 .6516 L F
.984 .901 .638 r
.51258 .78308 m .51084 .78799 L .51221 .78564 L F
.061 .254 .747 r
.52411 .6729 m .52503 .67404 L .52353 .67266 L F
.324 .003 .257 r
.52353 .67266 m .52084 .67468 L .52411 .6729 L F
.472 .338 .616 r
.52084 .67468 m .52312 .67668 L .52411 .6729 L F
.52084 .67468 m .52122 .67768 L .52312 .67668 L F
.52312 .67668 m .52122 .67768 L .52084 .67468 L F
.268 0 .079 r
.37764 .63216 m .37632 .63421 L .37453 .63408 L F
.348 0 .192 r
.37962 .63135 m .37632 .63421 L .37764 .63216 L F
.518 .06 .104 r
.72909 .49715 m .72585 .49799 L .7268 .49829 L F
.377 .795 .976 r
.72358 .49823 m .7268 .49829 L .72585 .49799 L F
.518 .06 .104 r
.72909 .49715 m .72946 .49975 L .72645 .49828 L F
.72644 .49784 m .72645 .49828 L .72585 .49799 L F
0 .349 .813 r
.72585 .49799 m .72946 .49975 L .72704 .49802 L F
0 0 .075 r
.72674 .49941 m .72652 .50004 L .72704 .49802 L F
.72652 .49998 m .72629 .50057 L .72651 .49982 L F
.676 .572 .73 r
.72592 .50192 m .72364 .50507 L .72302 .5019 L F
.494 .742 .983 r
.72491 .49979 m .72589 .50125 L .72302 .5019 L F
.72589 .50125 m .72589 .50126 L .72302 .5019 L F
.7259 .50126 m .72587 .50148 L .72302 .5019 L F
.417 .792 .993 r
.72302 .5019 m .72587 .50148 L .72592 .50192 L F
.867 .933 .554 r
.72674 .49941 m .72559 .5024 L .72592 .50192 L F
.417 .792 .993 r
.72587 .50148 m .72603 .50146 L .72592 .50192 L F
.867 .933 .554 r
.72587 .50148 m .72489 .50339 L .72584 .50175 L F
.494 .742 .983 r
.72589 .50125 m .7259 .50126 L .72589 .50126 L F
.867 .933 .554 r
.7259 .50122 m .72585 .50133 L .72587 .50148 L F
.72585 .50133 m .72489 .50339 L .72587 .50148 L F
.72674 .49941 m .7259 .50126 L .72584 .50175 L F
0 0 .075 r
.72652 .50004 m .72603 .50146 L .72629 .50057 L F
.72652 .50004 m .72629 .50057 L .72652 .49998 L F
.933 .897 .769 r
.72674 .49941 m .72603 .50146 L .7259 .50126 L F
.72674 .49941 m .7259 .50126 L .72491 .49979 L F
.867 .933 .554 r
.72674 .49941 m .7259 .50122 L .7259 .50126 L F
.494 .742 .983 r
.72491 .49979 m .72415 .50064 L .7221 .50127 L F
.375 .156 .448 r
.72491 .49979 m .72225 .50154 L .7221 .50127 L F
.72491 .49979 m .7221 .50127 L .72062 .4987 L F
.494 .742 .983 r
.72491 .49979 m .7221 .50127 L .72187 .50134 L F
.72415 .50064 m .72302 .5019 L .72187 .50134 L F
.784 .699 .77 r
.72187 .50134 m .72225 .50154 L .7221 .50127 L F
.72187 .50134 m .7221 .50127 L .72062 .4987 L F
.992 .739 .394 r
.72302 .5019 m .72364 .50507 L .72265 .50346 L F
.975 .779 .356 r
.72302 .5019 m .72265 .50346 L .72225 .50154 L F
.581 .753 .96 r
.72265 .50346 m .72387 .5024 L .72225 .50154 L F
.975 .779 .356 r
.72302 .5019 m .72225 .50154 L .72196 .50138 L F
.581 .753 .96 r
.72387 .5024 m .7258 .50071 L .72225 .50154 L F
.7258 .50071 m .72577 .50068 L .72225 .50154 L F
.72265 .50346 m .72489 .50339 L .72586 .50065 L F
.375 .156 .448 r
.72491 .49979 m .72578 .50058 L .72225 .50154 L F
.72578 .50058 m .72586 .50065 L .72577 .50068 L F
.72578 .50058 m .72577 .50068 L .72225 .50154 L F
0 0 .491 r
.72721 .50405 m .72657 .50339 L .72592 .50192 L F
.746 .941 .611 r
.72473 .50408 m .72592 .50192 L .72657 .50339 L F
.72473 .50408 m .72364 .50507 L .72592 .50192 L F
.809 .485 .441 r
.72489 .50339 m .72721 .50405 L .72592 .50192 L F
.806 .325 0 r
.72661 .50363 m .72557 .50244 L .7265 .50135 L F
.645 .636 .827 r
.72491 .49979 m .72187 .50134 L .72062 .4987 L F
.831 .609 .602 r
.72357 .50016 m .72492 .5017 L .72538 .5016 L F
.72357 .50016 m .72464 .50176 L .72492 .5017 L F
.72357 .50016 m .72538 .5016 L .72568 .50102 L F
.754 .856 .417 r
.72586 .50066 m .72489 .50339 L .7259 .50122 L F
.72585 .50068 m .72489 .50339 L .72586 .50066 L F
.727 .785 .297 r
.72592 .50192 m .72603 .50146 L .72674 .49941 L F
.867 .933 .554 r
.72584 .50175 m .72489 .50339 L .72559 .5024 L F
.727 .642 .763 r
.72868 .50601 m .72473 .50408 L .72657 .50339 L F
.806 .325 0 r
.72661 .50363 m .72532 .50281 L .72439 .5014 L F
.72485 .50162 m .72475 .50157 L .72357 .50016 L F
.72568 .50149 m .72357 .50016 L .72573 .50104 L F
.72485 .50162 m .72357 .50016 L .72568 .50149 L F
.337 .437 .816 r
.72525 .49884 m .7247 .50151 L .72357 .50016 L F
.7247 .50151 m .72464 .50176 L .72357 .50016 L F
.806 .325 0 r
.72475 .50157 m .72439 .5014 L .72357 .50016 L F
.737 .95 .948 r
.72485 .50162 m .72464 .50176 L .72475 .50164 L F
.72499 .50169 m .72464 .50176 L .72485 .50162 L F
.806 .325 0 r
.72661 .50363 m .72439 .5014 L .72485 .50162 L F
.494 .742 .983 r
.7259 .50126 m .72603 .50146 L .72587 .50148 L F
.831 .609 .602 r
.72568 .50102 m .72538 .5016 L .72652 .50136 L F
.737 .95 .948 r
.72652 .50136 m .72499 .50169 L .72485 .50162 L F
.806 .325 0 r
.72652 .50137 m .7265 .50135 L .72652 .50136 L F
.581 .753 .96 r
.7258 .50071 m .72586 .50065 L .72577 .50068 L F
.754 .856 .417 r
.72586 .50065 m .72585 .50068 L .72586 .50066 L F
.72626 .5001 m .7259 .50122 L .72674 .49941 L F
.72586 .50065 m .7259 .50122 L .72626 .5001 L F
.737 .95 .948 r
.72652 .50136 m .72475 .50164 L .72638 .49968 L F
.806 .325 0 r
.72557 .50244 m .72485 .50162 L .72568 .50149 L F
.72557 .50244 m .72573 .50104 L .7265 .50135 L F
.72661 .50363 m .7265 .50135 L .72652 .50137 L F
.975 .779 .356 r
.72196 .50138 m .72225 .50154 L .72187 .50134 L F
0 0 .075 r
.72652 .50004 m .72651 .49982 L .72704 .49802 L F
.518 .06 .104 r
.72909 .49715 m .72645 .49828 L .72644 .49784 L F
.834 .995 .849 r
.72946 .49533 m .72909 .49715 L .73159 .49453 L F
0 0 .126 r
.72946 .49533 m .72946 .49975 L .72909 .49715 L F
.744 .57 .658 r
.58739 .6542 m .58843 .65748 L .58494 .65706 L F
.764 .466 .48 r
.61082 .57359 m .61421 .57202 L .61076 .57125 L F
.61082 .57359 m .61433 .574 L .61421 .57202 L F
.401 0 0 r
.75058 .47805 m .74911 .47709 L .74781 .47653 L F
.75058 .47805 m .75086 .47794 L .74911 .47709 L F
.46 .188 .414 r
.58896 .57848 m .58862 .58005 L .58656 .58069 L F
.64 .412 .557 r
.58896 .57848 m .59252 .57985 L .58862 .58005 L F
.402 0 .068 r
.49423 .70817 m .49784 .70624 L .49554 .70896 L F
.655 .499 .66 r
.49554 .70896 m .49856 .70914 L .49784 .70624 L F
.402 0 .068 r
.49423 .70817 m .49656 .70801 L .49784 .70624 L F
.696 .277 .247 r
.49656 .70801 m .50073 .70863 L .49784 .70624 L F
.537 .094 .145 r
.71753 .47445 m .72097 .47363 L .71852 .47496 L F
.547 .611 .868 r
.40554 .59119 m .40505 .59446 L .40364 .59188 L F
.40554 .59119 m .40719 .59407 L .40505 .59446 L F
.442 .546 .867 r
.40855 .59731 m .40505 .59446 L .40719 .59407 L F
.63 .641 .842 r
.50522 .79283 m .50719 .79169 L .50394 .79089 L F
.624 .496 .686 r
.77894 .50884 m .77968 .51224 L .77618 .51063 L F
.699 .618 .763 r
.77968 .51224 m .77751 .51445 L .77618 .51063 L F
.041 .611 .717 r
.54054 .5974 m .53969 .59746 L .53821 .59825 L F
.54054 .5974 m .54217 .59735 L .53969 .59746 L F
.326 .518 .891 r
.73767 .52559 m .73957 .5282 L .74138 .52854 L F
.467 .219 .454 r
.37949 .61455 m .38166 .61403 L .38201 .61189 L F
.502 .249 .463 r
.38166 .61403 m .38432 .61145 L .38201 .61189 L F
.451 .138 .343 r
.40882 .61187 m .40836 .61378 L .40594 .61427 L F
.563 .284 .451 r
.4111 .61143 m .40836 .61378 L .40882 .61187 L F
.992 .829 .58 r
.32711 .64803 m .32574 .64825 L .32618 .64613 L F
.321 .785 .662 r
.32976 .64677 m .32711 .64803 L .32618 .64613 L F
.32976 .64677 m .32789 .64761 L .32711 .64803 L F
.275 .777 .769 r
.32789 .64761 m .32574 .64825 L .32711 .64803 L F
.429 .227 .502 r
.48789 .6435 m .48822 .64715 L .4862 .64752 L F
.567 .074 .045 r
.48909 .64254 m .48853 .64369 L .48757 .64328 L F
.4875 .64324 m .48757 .64328 L .48748 .64324 L F
.48909 .64254 m .48757 .64328 L .4875 .64324 L F
.27 0 .197 r
.48894 .64344 m .49076 .64171 L .4906 .64376 L F
0 0 0 r
.49076 .64171 m .48975 .64266 L .48909 .64254 L F
.48983 .64268 m .48846 .64384 L .48909 .64254 L F
.27 0 .197 r
.488 .64325 m .49076 .64171 L .48894 .64344 L F
0 0 0 r
.49076 .64171 m .48983 .64268 L .48975 .64266 L F
.456 .247 .506 r
.49048 .64512 m .48861 .64371 L .4906 .64376 L F
.48861 .64371 m .48894 .64344 L .4906 .64376 L F
.49035 .64658 m .48838 .64379 L .49048 .64512 L F
.48838 .64379 m .488 .64325 L .49048 .64512 L F
.49035 .64658 m .48822 .64715 L .48801 .64358 L F
.567 .074 .045 r
.48853 .64369 m .48809 .64363 L .48787 .6435 L F
.48853 .64369 m .48777 .64347 L .48636 .64276 L F
.456 .247 .506 r
.48838 .64379 m .48801 .64358 L .488 .64325 L F
.49035 .64658 m .48801 .64358 L .48838 .64379 L F
.567 .074 .045 r
.48853 .64369 m .48847 .64381 L .48809 .64363 L F
.429 .227 .502 r
.48801 .64358 m .48822 .64715 L .48789 .6435 L F
.567 .074 .045 r
.48787 .6435 m .48809 .64363 L .48777 .64347 L F
0 0 0 r
.48983 .64268 m .48817 .64442 L .48846 .64384 L F
.456 .247 .506 r
.48861 .64371 m .488 .64325 L .48894 .64344 L F
.429 .227 .502 r
.488 .64325 m .48801 .64358 L .48789 .6435 L F
.567 .074 .045 r
.48668 .64274 m .48748 .64324 L .48636 .64276 L F
.48909 .64254 m .48748 .64324 L .48668 .64274 L F
.429 .227 .502 r
.48777 .64347 m .4862 .64752 L .48611 .64508 L F
.488 .64325 m .48789 .6435 L .48777 .64347 L F
.48789 .6435 m .4862 .64752 L .48777 .64347 L F
.515 .091 .173 r
.48636 .64276 m .488 .64325 L .48777 .64347 L F
.48636 .64276 m .48777 .64347 L .48611 .64508 L F
.567 .074 .045 r
.48847 .64381 m .48817 .64442 L .48636 .64276 L F
.065 .01 .478 r
.49064 .63929 m .49076 .64171 L .48909 .64254 L F
.541 .767 .981 r
.73047 .51059 m .73188 .51197 L .72939 .51234 L F
.294 .778 .914 r
.3274 .58286 m .32954 .58255 L .33109 .5828 L F
.163 .302 .759 r
.72213 .47981 m .72315 .48315 L .7238 .48107 L F
0 0 .357 r
.72213 .47981 m .72314 .48258 L .72315 .48315 L F
.807 .912 .516 r
.72315 .48315 m .72211 .48436 L .72314 .48236 L F
.72315 .48315 m .72314 .48236 L .7238 .48107 L F
0 0 .357 r
.72314 .48258 m .72314 .48258 L .72315 .48315 L F
.806 .912 .516 r
.72315 .48315 m .72211 .48436 L .72314 .48258 L F
.174 .094 .519 r
.60663 .64868 m .60716 .65092 L .60578 .65173 L F
.754 .671 .77 r
.49545 .71112 m .49423 .70817 L .49554 .70896 L F
.562 .27 .43 r
.49856 .70914 m .49545 .71112 L .49554 .70896 L F
.345 .063 .334 r
.46955 .64573 m .4712 .64749 L .47154 .6452 L F
.46955 .64573 m .46906 .64833 L .4712 .64749 L F
.601 .566 .787 r
.58855 .65994 m .58671 .66118 L .58494 .65706 L F
.68 .904 .975 r
.65876 .48874 m .65963 .48738 L .66139 .48648 L F
.591 .277 .405 r
.65839 .48829 m .65818 .48991 L .66017 .48949 L F
.65782 .48791 m .65795 .48861 L .65839 .48829 L F
.65795 .48861 m .65818 .48991 L .65839 .48829 L F
.68 .904 .975 r
.65963 .48738 m .66004 .48673 L .66067 .48661 L F
.65963 .48738 m .66067 .48661 L .66139 .48648 L F
.602 .675 .892 r
.77983 .4871 m .77811 .48938 L .77756 .48755 L F
.77983 .4871 m .78065 .48887 L .77811 .48938 L F
.644 .437 .588 r
.53181 .7619 m .53035 .76026 L .5287 .76207 L F
.53181 .7619 m .53444 .76091 L .53035 .76026 L F
.53181 .7619 m .53372 .76299 L .53444 .76091 L F
0 .152 .686 r
.20395 .54898 m .20534 .55056 L .2051 .55174 L F
.323 .583 .936 r
.20579 .55059 m .2051 .55174 L .20534 .55056 L F
.772 .91 .934 r
.73442 .48935 m .73374 .49148 L .73526 .49119 L F
.837 .891 .879 r
.73442 .48935 m .73526 .49119 L .73687 .48909 L F
.587 .601 .833 r
.49979 .78676 m .50096 .78966 L .50391 .78841 L F
.522 .575 .85 r
.50096 .78966 m .50394 .79089 L .50391 .78841 L F
.741 .744 .854 r
.55349 .66292 m .5569 .66341 L .556 .66183 L F
.518 .225 .409 r
.55411 .6655 m .55691 .66557 L .5569 .66341 L F
.838 .84 .847 r
.556 .66183 m .5569 .66341 L .55967 .6605 L F
.62 .305 .415 r
.5569 .66341 m .55691 .66557 L .55897 .66516 L F
.534 0 0 r
.72781 .51307 m .72834 .5138 L .7258 .51198 L F
.576 .106 0 r
.72781 .51307 m .72963 .51534 L .72834 .5138 L F
.23 .744 .864 r
.36592 .58537 m .36956 .58522 L .36736 .58576 L F
.383 .181 .478 r
.53063 .70609 m .53253 .70585 L .5329 .70282 L F
.41 .292 .607 r
.53063 .70609 m .53277 .70787 L .53253 .70585 L F
.483 .285 .535 r
.53277 .70787 m .53041 .70884 L .53063 .70609 L F
.736 .37 .358 r
.4601 .70254 m .46379 .70288 L .46149 .70327 L F
0 0 0 r
.34739 .64391 m .34733 .64378 L .34934 .64295 L F
.34739 .64391 m .34535 .64453 L .34733 .64378 L F
.496 .376 .645 r
.32473 .61124 m .32517 .61456 L .32309 .61496 L F
.799 .682 .735 r
.72964 .49411 m .73374 .49148 L .73276 .49046 L F
.72964 .49411 m .73159 .49453 L .73374 .49148 L F
.772 .91 .934 r
.73442 .48935 m .73276 .49046 L .73374 .49148 L F
0 .264 .713 r
.31559 .63709 m .31126 .6341 L .31307 .63744 L F
.677 .823 .386 r
.61683 .61121 m .61846 .60799 L .61745 .61009 L F
0 0 .215 r
.61743 .61284 m .61683 .61121 L .61745 .61009 L F
.61743 .61284 m .61662 .61395 L .61683 .61121 L F
.143 .196 .659 r
.56658 .6515 m .56803 .65012 L .56712 .6479 L F
.155 .215 .674 r
.56658 .6515 m .56852 .65359 L .56803 .65012 L F
.374 .259 .592 r
.56652 .65371 m .56852 .65359 L .56658 .6515 L F
0 0 .074 r
.32012 .64 m .31979 .64099 L .32041 .63972 L F
.434 .674 .964 r
.31979 .64099 m .32175 .64082 L .32041 .63972 L F
.938 .581 .31 r
.60096 .58883 m .59949 .588 L .59898 .58583 L F
.967 .692 .459 r
.60096 .58883 m .59968 .59053 L .59949 .588 L F
.60096 .58883 m .60111 .5914 L .59968 .59053 L F
.68 .904 .975 r
.65876 .48874 m .65782 .48791 L .66004 .48673 L F
.594 .484 .699 r
.4329 .66877 m .43425 .66452 L .43191 .66491 L F
.269 0 0 r
.29632 .59238 m .29945 .59138 L .29719 .59173 L F
.177 0 0 r
.59655 .67085 m .59316 .67276 L .5947 .67213 L F
.397 .031 .221 r
.39043 .62609 m .38748 .62798 L .38827 .62672 L F
.671 .615 .783 r
.21278 .56453 m .21118 .56603 L .21 .56294 L F
0 0 0 r
.21278 .56453 m .21074 .56847 L .21118 .56603 L F
.932 .598 .152 r
.29332 .64363 m .29393 .6453 L .29353 .64494 L F
.29393 .6453 m .29444 .64671 L .29381 .64549 L F
.29393 .6453 m .29381 .64549 L .29353 .64494 L F
.677 .716 .878 r
.29353 .64494 m .29444 .64671 L .2967 .64583 L F
.29353 .64494 m .29627 .64571 L .29537 .64515 L F
.29627 .64571 m .2967 .64583 L .29537 .64515 L F
.976 .906 .676 r
.2945 .64431 m .29439 .64455 L .29537 .64515 L F
.007 0 0 r
.29537 .64515 m .29348 .64657 L .29321 .64651 L F
.29537 .64515 m .29321 .64651 L .29365 .64577 L F
.29537 .64515 m .29365 .64577 L .29353 .64494 L F
.976 .906 .676 r
.29439 .64455 m .29348 .64657 L .29537 .64515 L F
.007 0 0 r
.29365 .64577 m .29321 .64651 L .29224 .64627 L F
.29365 .64577 m .29224 .64627 L .29353 .64494 L F
.932 .598 .152 r
.29315 .64314 m .29332 .64363 L .29353 .64494 L F
.758 .605 .688 r
.70539 .47099 m .70566 .469 L .7019 .46854 L F
.265 0 .106 r
.68664 .48007 m .68903 .4795 L .68954 .47834 L F
.638 .461 .628 r
.68606 .48172 m .68903 .4795 L .68664 .48007 L F
.905 .686 .595 r
.52503 .67404 m .52694 .67482 L .52552 .67151 L F
.734 .625 .737 r
.52552 .67151 m .52694 .67482 L .52898 .67172 L F
.634 .532 .721 r
.78345 .50181 m .78441 .50574 L .78227 .50534 L F
.631 .39 .533 r
.78441 .50574 m .78303 .50741 L .78227 .50534 L F
.661 .754 .919 r
.74088 .51124 m .73771 .51054 L .73999 .50816 L F
.768 .703 .79 r
.74347 .50853 m .74088 .51124 L .73999 .50816 L F
.261 .406 .819 r
.507 .64052 m .50835 .6393 L .5062 .63969 L F
.507 .64052 m .50966 .6422 L .50835 .6393 L F
.477 .389 .677 r
.507 .64052 m .50792 .64356 L .50966 .6422 L F
.713 .271 .198 r
.45526 .67461 m .45756 .67667 L .45406 .67617 L F
.629 .331 .446 r
.4578 .67473 m .45756 .67667 L .45526 .67461 L F
.814 .622 .643 r
.72069 .47869 m .72314 .48258 L .72213 .47981 L F
.742 .829 .919 r
.71889 .48287 m .72015 .48423 L .72285 .48274 L F
.72294 .4826 m .72285 .48274 L .72314 .48258 L F
.71889 .48287 m .72285 .48274 L .72294 .4826 L F
.814 .622 .643 r
.72069 .47869 m .71945 .48195 L .72314 .48258 L F
.742 .829 .919 r
.71889 .48287 m .72314 .48258 L .71945 .48195 L F
0 0 .224 r
.72211 .48436 m .72364 .48167 L .72376 .48122 L F
.72351 .48165 m .72376 .48122 L .7238 .48107 L F
.72211 .48436 m .72376 .48122 L .72351 .48165 L F
.72364 .48167 m .72432 .48048 L .7238 .48107 L F
.648 .147 .043 r
.72408 .48007 m .7238 .48107 L .72546 .48025 L F
.72213 .47981 m .7238 .48107 L .72408 .48007 L F
.931 .674 .525 r
.72546 .48025 m .72421 .48037 L .7238 .47693 L F
.823 .402 .243 r
.72546 .48025 m .7238 .48107 L .72421 .48037 L F
.572 .613 .855 r
.33233 .62028 m .33036 .62079 L .32886 .61782 L F
.819 .591 .593 r
.60737 .56577 m .60733 .56828 L .6107 .56886 L F
.781 .54 .571 r
.60725 .57079 m .6107 .56886 L .60733 .56828 L F
.60725 .57079 m .61076 .57125 L .6107 .56886 L F
.606 .563 .78 r
.76555 .50022 m .767 .49628 L .76484 .49695 L F
.76555 .50022 m .76802 .4996 L .767 .49628 L F
.548 .561 .819 r
.76555 .50022 m .769 .50299 L .76802 .4996 L F
.354 0 .113 r
.36533 .62505 m .36881 .62271 L .36656 .62312 L F
.353 .188 .513 r
.21074 .56847 m .20967 .5713 L .20908 .57028 L F
.301 .222 .598 r
.20908 .57028 m .20967 .5713 L .20917 .57158 L F
.646 .477 .641 r
.68393 .48498 m .68606 .48172 L .6841 .48281 L F
0 0 0 r
.30299 .63527 m .30358 .63416 L .30604 .63441 L F
.30299 .63527 m .30198 .63622 L .30358 .63416 L F
.727 .642 .763 r
.72868 .50601 m .72479 .50611 L .72473 .50408 L F
0 0 .157 r
.72798 .50493 m .7286 .50831 L .72868 .50601 L F
.323 0 .208 r
.286 .62301 m .28797 .6225 L .2891 .62078 L F
.488 .829 .998 r
.45871 .68236 m .45711 .68308 L .45997 .68308 L F
.891 .912 .833 r
.461 .67946 m .45997 .68308 L .46284 .68131 L F
.58 .485 .71 r
.49729 .78672 m .49979 .78676 L .49961 .78451 L F
.525 .292 .504 r
.48636 .64276 m .48611 .64508 L .48408 .64318 L F
.322 .285 .661 r
.48611 .64508 m .48488 .64613 L .48408 .64318 L F
.525 .292 .504 r
.48636 .64276 m .48611 .64508 L .48408 .64318 L F
.661 .136 0 r
.5243 .6639 m .52293 .66472 L .52063 .66279 L F
.403 0 0 r
.52641 .66464 m .52293 .66472 L .5243 .6639 L F
.783 .863 .909 r
.73779 .48261 m .74112 .48242 L .7399 .48107 L F
.73779 .48261 m .73899 .48356 L .74112 .48242 L F
.478 .668 .947 r
.74112 .48242 m .74243 .48063 L .7399 .48107 L F
.74112 .48242 m .74322 .48217 L .74243 .48063 L F
.931 .835 .728 r
.73779 .48261 m .73818 .48574 L .73899 .48356 L F
.661 .665 .844 r
.78447 .49122 m .78065 .48887 L .78307 .48826 L F
.579 .659 .892 r
.78551 .48801 m .78447 .49122 L .78307 .48826 L F
.78551 .48801 m .78693 .49058 L .78447 .49122 L F
.566 .466 .7 r
.78768 .49479 m .7853 .49575 L .78447 .49122 L F
.202 .725 .853 r
.45921 .68895 m .45966 .68886 L .4613 .6889 L F
.632 .192 .187 r
.4613 .6889 m .4599 .69057 L .45786 .68899 L F
.215 0 0 r
.45966 .68886 m .46355 .68845 L .4613 .6889 L F
.448 .676 .961 r
.46085 .68682 m .46184 .68795 L .45966 .68886 L F
.215 0 0 r
.46141 .68868 m .4614 .68868 L .46355 .68845 L F
.625 .857 .487 r
.46093 .68916 m .4599 .69057 L .4614 .68868 L F
.4614 .68868 m .4613 .6889 L .46355 .68845 L F
.215 0 0 r
.45975 .68886 m .46264 .68886 L .46355 .68845 L F
.625 .857 .487 r
.46196 .68823 m .4614 .68868 L .46355 .68845 L F
.448 .676 .961 r
.46184 .68795 m .46206 .6882 L .46157 .68834 L F
.625 .857 .487 r
.46165 .68818 m .46157 .68834 L .46196 .68823 L F
.46157 .68834 m .4614 .68868 L .46196 .68823 L F
.448 .676 .961 r
.46157 .68834 m .46264 .68886 L .46123 .68886 L F
.46206 .6882 m .46264 .68886 L .46157 .68834 L F
.215 0 0 r
.45966 .68886 m .45975 .68886 L .4614 .68868 L F
.45966 .68886 m .4614 .68868 L .46141 .68868 L F
.448 .676 .961 r
.46184 .68795 m .46123 .68886 L .45966 .68886 L F
.625 .857 .487 r
.4614 .68868 m .46107 .6891 L .4613 .6889 L F
.46107 .6891 m .4599 .69057 L .46085 .68942 L F
.46107 .6891 m .46085 .68942 L .4613 .6889 L F
.46165 .68818 m .46093 .68916 L .4614 .68868 L F
.174 0 .363 r
.45966 .68886 m .4599 .69057 L .46141 .68851 L F
.45966 .68886 m .46141 .68851 L .46165 .68818 L F
.202 .725 .853 r
.45786 .68899 m .45966 .68886 L .45921 .68895 L F
.742 .373 .352 r
.50596 .63806 m .50264 .63919 L .50282 .63737 L F
.50596 .63806 m .5062 .63969 L .50264 .63919 L F
.606 .067 0 r
.34331 .62695 m .3454 .62803 L .34641 .62761 L F
.053 0 0 r
.3454 .62803 m .3492 .62719 L .34641 .62761 L F
.29 .192 .567 r
.47933 .65123 m .4793 .65369 L .47786 .654 L F
.204 0 .255 r
.4793 .65369 m .47676 .65649 L .47786 .654 L F
.313 .439 .829 r
.72963 .51534 m .73058 .51767 L .7319 .51604 L F
.383 .543 .89 r
.73058 .51767 m .73384 .51881 L .7319 .51604 L F
.188 .212 .654 r
.56779 .65747 m .56852 .65359 L .56652 .65371 L F
.56779 .65747 m .56873 .65672 L .56852 .65359 L F
.186 .127 .554 r
.56805 .65942 m .56873 .65672 L .56779 .65747 L F
.492 .511 .805 r
.40932 .59368 m .40855 .59731 L .40719 .59407 L F
.40932 .59368 m .41058 .5973 L .40855 .59731 L F
.597 .344 .504 r
.51105 .6622 m .50896 .66023 L .51125 .66013 L F
.51105 .6622 m .50906 .66295 L .50896 .66023 L F
.254 0 0 r
.34063 .59998 m .33912 .60112 L .33668 .60123 L F
.478 .025 .095 r
.34279 .59962 m .33912 .60112 L .34063 .59998 L F
.453 .101 .277 r
.50677 .65683 m .51203 .65298 L .50701 .65449 L F
.50677 .65683 m .50918 .65653 L .51203 .65298 L F
.336 .572 .926 r
.50925 .65088 m .51203 .65298 L .51217 .65201 L F
.363 .002 .211 r
.51203 .65298 m .50918 .65653 L .51154 .65579 L F
.51203 .65298 m .51154 .65579 L .51217 .65201 L F
.772 .598 .663 r
.5932 .65384 m .59467 .65766 L .59083 .65709 L F
.7 .563 .697 r
.59668 .65454 m .59467 .65766 L .5932 .65384 L F
.543 .239 .402 r
.68903 .4795 m .69169 .47738 L .68954 .47834 L F
.649 .617 .803 r
.53049 .6622 m .52649 .66028 L .52869 .66004 L F
.466 .049 .163 r
.53049 .6622 m .52872 .66453 L .52641 .66464 L F
.449 0 0 r
.53191 .66348 m .52872 .66453 L .53049 .6622 L F
.592 .323 .478 r
.49781 .68023 m .49738 .68231 L .49514 .68031 L F
.49514 .68031 m .49738 .68231 L .49781 .68023 L F
.49781 .68023 m .49738 .68231 L .49514 .68031 L F
.327 .579 .934 r
.42652 .70489 m .42792 .70427 L .42444 .70363 L F
.42652 .70489 m .42863 .70558 L .42792 .70427 L F
.019 0 0 r
.37404 .59452 m .37278 .59513 L .37043 .59552 L F
.236 .752 .844 r
.37278 .59513 m .37169 .59523 L .37043 .59552 L F
.622 .958 .898 r
.36915 .59582 m .37224 .59465 L .37043 .59552 L F
.236 .752 .844 r
.37169 .59523 m .36933 .59545 L .37043 .59552 L F
.622 .958 .898 r
.36836 .59612 m .36915 .59582 L .37043 .59552 L F
.019 0 0 r
.37404 .59452 m .37043 .59552 L .37224 .59465 L F
.801 .727 .783 r
.71211 .48862 m .7138 .49364 L .71526 .48893 L F
.387 .156 .437 r
.53514 .7075 m .53734 .70754 L .53735 .70737 L F
.215 0 0 r
.5365 .70606 m .53514 .7075 L .53332 .70761 L F
.605 .944 .935 r
.53837 .70492 m .53746 .70466 L .5365 .70606 L F
.387 .156 .437 r
.53746 .70466 m .53514 .7075 L .5365 .70606 L F
.53514 .7075 m .53735 .70737 L .53746 .70466 L F
.215 0 0 r
.53332 .70761 m .53514 .7075 L .53277 .70787 L F
.488 .251 .481 r
.56309 .58317 m .56544 .58263 L .56557 .58032 L F
.391 .13 .394 r
.56544 .58263 m .56791 .5799 L .56557 .58032 L F
.416 .291 .602 r
.60902 .63141 m .60929 .63386 L .60741 .63438 L F
.389 .265 .588 r
.60929 .63386 m .60777 .63703 L .60741 .63438 L F
.405 .012 .176 r
.52303 .66093 m .52515 .66177 L .52649 .66028 L F
.558 .322 .515 r
.52737 .66081 m .5284 .65983 L .52813 .65991 L F
.248 .402 .821 r
.52975 .65855 m .52869 .66004 L .52813 .65991 L F
.558 .322 .515 r
.5284 .65983 m .52975 .65855 L .52813 .65991 L F
0 0 0 r
.52707 .66022 m .52813 .65991 L .52869 .66004 L F
.52649 .66028 m .52813 .65991 L .52707 .66022 L F
.52649 .66028 m .52515 .66177 L .52813 .65991 L F
.352 .236 .579 r
.52898 .67172 m .53178 .67188 L .53055 .66816 L F
.86 .678 .654 r
.61433 .574 m .61566 .57723 L .61621 .57482 L F
.41 .08 .293 r
.58656 .58069 m .58646 .58233 L .5837 .58268 L F
.49 .143 .305 r
.58656 .58069 m .58861 .58192 L .58646 .58233 L F
.454 .175 .4 r
.58862 .58005 m .58861 .58192 L .58656 .58069 L F
.838 .84 .847 r
.556 .66183 m .55967 .6605 L .55754 .66187 L F
.968 .899 .7 r
.55879 .65863 m .55754 .66187 L .55967 .6605 L F
.642 .807 .962 r
.31629 .64509 m .31817 .64646 L .31997 .64549 L F
.31629 .64509 m .31817 .64646 L .31997 .64549 L F
.545 .234 .391 r
.50282 .63737 m .50041 .63891 L .50107 .63805 L F
.447 .64 .938 r
.40222 .59034 m .40129 .59205 L .40023 .59043 L F
.481 .682 .954 r
.40222 .59034 m .40364 .59188 L .40129 .59205 L F
.279 0 .138 r
.37656 .61667 m .37854 .61635 L .37949 .61455 L F
.366 0 .184 r
.37949 .61455 m .38051 .61578 L .38166 .61403 L F
.37949 .61455 m .37854 .61635 L .38051 .61578 L F
.377 .795 .976 r
.72358 .49823 m .72585 .49799 L .72322 .49806 L F
.643 .441 .594 r
.77806 .51738 m .77917 .51997 L .77531 .5199 L F
.609 .537 .748 r
.78078 .5156 m .77806 .51738 L .77751 .51445 L F
.631 .435 .599 r
.78124 .51938 m .77806 .51738 L .78078 .5156 L F
.78124 .51938 m .77917 .51997 L .77806 .51738 L F
.235 0 .252 r
.47883 .6342 m .48097 .63352 L .4813 .63155 L F
.057 0 .21 r
.4813 .63155 m .48308 .63064 L .48341 .62845 L F
.34 .138 .453 r
.48097 .63352 m .48308 .63064 L .4813 .63155 L F
.48 .697 .964 r
.46284 .68131 m .46403 .68103 L .461 .67946 L F
.46284 .68131 m .46403 .68103 L .461 .67946 L F
.481 .327 .595 r
.46286 .66827 m .46047 .67138 L .45985 .66885 L F
.495 .247 .468 r
.44566 .66507 m .44378 .66334 L .44339 .66548 L F
.44566 .66507 m .44598 .66287 L .44378 .66334 L F
.687 .406 .491 r
.70198 .47334 m .70559 .47347 L .70539 .47099 L F
.473 .178 .384 r
.40351 .61688 m .40061 .6198 L .40122 .61774 L F
.047 0 0 r
.34127 .64591 m .33667 .64593 L .33887 .64681 L F
.481 .327 .595 r
.46286 .66827 m .46248 .67091 L .46047 .67138 L F
.548 .397 .629 r
.46288 .67389 m .46047 .67138 L .46248 .67091 L F
.46288 .67389 m .46063 .67443 L .46047 .67138 L F
.569 0 0 r
.55536 .60163 m .55697 .60292 L .55872 .60267 L F
.403 .758 .994 r
.55872 .60267 m .55958 .60155 L .55725 .59965 L F
.55872 .60267 m .56079 .60245 L .55958 .60155 L F
.58 .944 .861 r
.55872 .60267 m .55958 .60155 L .56079 .60245 L F
.467 .31 .584 r
.55725 .59965 m .55786 .60258 L .55536 .60163 L F
.58 .944 .861 r
.55872 .60267 m .55741 .60286 L .55755 .60278 L F
.5589 .60244 m .55755 .60278 L .55958 .60155 L F
.55872 .60267 m .55755 .60278 L .5589 .60244 L F
.564 .028 0 r
.55754 .60278 m .55697 .60292 L .55536 .60163 L F
.55794 .60299 m .55697 .60292 L .55754 .60278 L F
.467 .31 .584 r
.55786 .60258 m .55794 .60299 L .55754 .60278 L F
.55786 .60258 m .55754 .60278 L .55536 .60163 L F
.507 .335 .583 r
.55958 .60155 m .55794 .60299 L .55786 .60258 L F
.55958 .60155 m .55786 .60258 L .55725 .59965 L F
.58 .944 .861 r
.55786 .60258 m .55697 .60292 L .55912 .60179 L F
.55741 .60286 m .55738 .60286 L .55786 .60258 L F
.55738 .60286 m .55697 .60292 L .55786 .60258 L F
.55741 .60286 m .55912 .60179 L .55958 .60155 L F
.512 .445 .718 r
.76424 .49453 m .76617 .49062 L .76361 .49139 L F
.76424 .49453 m .76641 .49399 L .76617 .49062 L F
.526 .445 .707 r
.76424 .49453 m .767 .49628 L .76641 .49399 L F
.76424 .49453 m .76484 .49695 L .767 .49628 L F
.471 .232 .469 r
.53253 .70585 m .53494 .70253 L .5329 .70282 L F
.45 .253 .521 r
.47883 .6342 m .47672 .63732 L .47866 .63647 L F
.192 0 .288 r
.47635 .63952 m .47866 .63647 L .47672 .63732 L F
0 0 .257 r
.51992 .7854 m .51889 .78892 L .52146 .78631 L F
.413 .102 .325 r
.45934 .65406 m .46151 .65355 L .46211 .65183 L F
.325 .02 .286 r
.46211 .65183 m .46348 .65279 L .46424 .65122 L F
.46211 .65183 m .46151 .65355 L .46348 .65279 L F
.694 .173 0 r
.45632 .68016 m .45566 .68037 L .45289 .67827 L F
.45632 .68016 m .45566 .68037 L .45289 .67827 L F
.816 .823 .855 r
.45491 .67893 m .45566 .68037 L .45706 .67859 L F
.45491 .67893 m .45566 .68037 L .45706 .67859 L F
.537 .254 .433 r
.45555 .67903 m .45549 .67909 L .45491 .67893 L F
.007 .321 .809 r
.4531 .67843 m .45566 .68037 L .45491 .67893 L F
.45491 .67893 m .45566 .68037 L .45289 .67827 L F
.45289 .67827 m .45566 .68037 L .45491 .67893 L F
.537 .254 .433 r
.45549 .67909 m .4537 .6808 L .45491 .67893 L F
.007 .321 .809 r
.45289 .67827 m .4531 .67843 L .45491 .67893 L F
.216 .319 .755 r
.73386 .52061 m .73631 .52083 L .73384 .51881 L F
.73386 .52061 m .7362 .52246 L .73631 .52083 L F
.437 .666 .959 r
.77275 .48412 m .77131 .48559 L .77047 .48413 L F
.466 .715 .977 r
.77275 .48412 m .77364 .48543 L .77131 .48559 L F
.769 .67 .754 r
.48412 .65719 m .48077 .65703 L .48308 .6542 L F
.687 .274 .258 r
.48412 .65719 m .48275 .65915 L .48077 .65703 L F
.571 .321 .499 r
.48412 .65719 m .48308 .6542 L .48476 .65651 L F
.603 .177 .206 r
.48679 .65851 m .48412 .65719 L .48476 .65651 L F
.48679 .65851 m .48275 .65915 L .48412 .65719 L F
.983 .792 .571 r
.61835 .60549 m .61886 .60324 L .61749 .60219 L F
.758 .888 .937 r
.77887 .5276 m .77765 .52893 L .77701 .52765 L F
.637 .083 0 r
.77765 .52893 m .7771 .52973 L .77701 .52765 L F
.77765 .52893 m .78012 .53068 L .7771 .52973 L F
.556 .667 .912 r
.48869 .63739 m .49211 .63835 L .49078 .63682 L F
.466 .283 .548 r
.49078 .63682 m .49064 .63929 L .48869 .63739 L F
.702 .721 .864 r
.75032 .48768 m .75154 .48949 L .75376 .48837 L F
.485 .323 .585 r
.4889 .65161 m .48907 .6552 L .49112 .65354 L F
.585 .307 .461 r
.4889 .65161 m .49112 .65354 L .49128 .65158 L F
.343 .171 .499 r
.47866 .63647 m .48097 .63352 L .47883 .6342 L F
.603 .665 .883 r
.38942 .59704 m .39099 .59977 L .39334 .59918 L F
.619 .744 .936 r
.75376 .48837 m .75704 .48915 L .75618 .488 L F
.462 .759 .994 r
.75704 .48915 m .75823 .48795 L .75618 .488 L F
.75704 .48915 m .75913 .48884 L .75823 .48795 L F
.202 .522 .918 r
.28558 .6446 m .28733 .64653 L .28517 .64576 L F
.28558 .6446 m .28733 .64653 L .28517 .64576 L F
.828 .473 .384 r
.59608 .58493 m .59265 .58217 L .59552 .58342 L F
.307 .715 .977 r
.37177 .58497 m .37537 .58585 L .3732 .58608 L F
.784 .703 .775 r
.49419 .63996 m .49578 .64295 L .49794 .63987 L F
.458 .08 .233 r
.69682 .47369 m .69982 .4738 L .69994 .47239 L F
.576 .177 .248 r
.69994 .47239 m .69982 .4738 L .70198 .47334 L F
.626 .4 .555 r
.48187 .65077 m .47918 .64885 L .48159 .6485 L F
.48187 .65077 m .47933 .65123 L .47918 .64885 L F
.349 .776 .973 r
.33317 .58301 m .33529 .58278 L .3369 .58337 L F
.088 .641 .81 r
.33529 .58278 m .33898 .58297 L .3369 .58337 L F
.277 .122 .483 r
.42755 .68906 m .42605 .69169 L .42798 .69109 L F
.455 .263 .529 r
.42798 .69109 m .42605 .69169 L .42582 .69418 L F
.859 .794 .786 r
.73677 .48454 m .73818 .48574 L .73779 .48261 L F
.947 .848 .712 r
.7365 .48574 m .73818 .48574 L .73677 .48454 L F
.7365 .48574 m .73687 .48909 L .73818 .48574 L F
.238 0 0 r
.35537 .64058 m .35372 .64197 L .35147 .64232 L F
.124 0 0 r
.35586 .64142 m .35537 .64058 L .35752 .64003 L F
.35586 .64142 m .35372 .64197 L .35537 .64058 L F
.239 .748 .876 r
.51056 .78816 m .51084 .78799 L .50817 .78799 L F
.717 .59 .713 r
.55886 .60712 m .55576 .60987 L .55619 .60587 L F
.717 .515 .616 r
.55886 .60712 m .55717 .61079 L .55576 .60987 L F
.55886 .60712 m .56051 .61299 L .55717 .61079 L F
.277 .246 .643 r
.56167 .61006 m .55886 .60712 L .56179 .6075 L F
.56167 .61006 m .56051 .61299 L .55886 .60712 L F
.464 .65 .94 r
.39817 .58822 m .39826 .59067 L .39636 .58854 L F
.39817 .58822 m .40023 .59043 L .39826 .59067 L F
.536 .564 .83 r
.7034 .48858 m .70444 .48496 L .70214 .48555 L F
.7034 .48858 m .70565 .48825 L .70444 .48496 L F
.689 .499 .625 r
.66204 .49591 m .66476 .50013 L .66032 .49991 L F
.569 .461 .691 r
.66534 .49893 m .66204 .49591 L .6664 .49607 L F
.66534 .49893 m .66476 .50013 L .66204 .49591 L F
.108 .612 .899 r
.52479 .63419 m .52378 .63455 L .52255 .63358 L F
.52479 .63419 m .52629 .63491 L .52378 .63455 L F
.38 .058 .289 r
.44892 .66006 m .44598 .66287 L .44835 .66244 L F
.492 .237 .455 r
.45087 .66144 m .44892 .66006 L .44835 .66244 L F
.45087 .66144 m .45125 .65964 L .44892 .66006 L F
.628 .443 .613 r
.58149 .57151 m .58411 .57129 L .58382 .56873 L F
.599 .296 .426 r
.5862 .57057 m .58382 .56873 L .58411 .57129 L F
.5862 .57057 m .5866 .56877 L .58382 .56873 L F
.362 .824 .917 r
.36459 .59675 m .36263 .59676 L .36046 .59725 L F
.277 .768 .905 r
.3662 .59673 m .36263 .59676 L .36459 .59675 L F
.738 .756 .867 r
.74212 .50567 m .74347 .50853 L .73999 .50816 L F
.583 .669 .898 r
.74437 .50517 m .74347 .50853 L .74212 .50567 L F
.74437 .50517 m .74591 .508 L .74347 .50853 L F
.687 .448 .556 r
.77288 .51998 m .77309 .52245 L .76955 .52274 L F
.699 .487 .597 r
.77531 .5199 m .77309 .52245 L .77288 .51998 L F
.311 0 .159 r
.52063 .66279 m .52283 .66244 L .52303 .66093 L F
.405 .012 .176 r
.52303 .66093 m .52283 .66244 L .52515 .66177 L F
.466 .226 .465 r
.32967 .60579 m .32944 .60792 L .32712 .60853 L F
.49 .246 .471 r
.33137 .6074 m .32967 .60579 L .33142 .60535 L F
.33137 .6074 m .32944 .60792 L .32967 .60579 L F
.004 0 0 r
.60489 .6658 m .60182 .66845 L .60217 .66795 L F
.71 .584 .713 r
.55619 .60587 m .55576 .60987 L .55389 .6088 L F
.475 .517 .821 r
.55717 .61079 m .55389 .6088 L .55576 .60987 L F
.601 .566 .787 r
.58855 .65994 m .58494 .65706 L .58843 .65748 L F
.583 .417 .622 r
.59083 .65709 m .58855 .65994 L .58843 .65748 L F
.277 0 0 r
.37453 .63408 m .37405 .63478 L .3709 .63583 L F
.249 0 0 r
.37453 .63408 m .37551 .63506 L .37405 .63478 L F
.37453 .63408 m .37632 .63421 L .37551 .63506 L F
.442 .286 .573 r
.44892 .68133 m .44776 .68043 L .44904 .68024 L F
.013 0 .076 r
.45151 .67884 m .44904 .68024 L .45215 .67742 L F
.482 .275 .522 r
.45151 .67884 m .44892 .68133 L .44904 .68024 L F
.145 .293 .758 r
.26764 .841 m .26939 .84251 L .26852 .8432 L F
0 0 0 r
.26852 .8432 m .26939 .84251 L .26744 .84411 L F
.572 .314 .486 r
.53713 .66881 m .53945 .6708 L .53708 .67042 L F
.63 .294 .382 r
.5412 .66931 m .53945 .6708 L .53713 .66881 L F
.634 .451 .618 r
.54904 .66856 m .54653 .67155 L .5467 .66902 L F
.54904 .66856 m .54926 .67138 L .54653 .67155 L F
.333 .006 .252 r
.39013 .60889 m .38947 .61061 L .39219 .60823 L F
.041 .482 .884 r
.3528 .58411 m .3524 .58472 L .35076 .58393 L F
.3528 .58411 m .35426 .58536 L .3524 .58472 L F
.229 .657 .957 r
.75807 .48112 m .75475 .48007 L .75696 .48021 L F
.249 .692 .959 r
.75985 .48048 m .75807 .48112 L .75696 .48021 L F
.75985 .48048 m .76111 .48128 L .75807 .48112 L F
.554 .532 .785 r
.76802 .4996 m .769 .50299 L .77131 .50229 L F
.463 .312 .59 r
.769 .50299 m .77141 .50484 L .77131 .50229 L F
.769 .50299 m .76923 .50539 L .77141 .50484 L F
.486 .435 .725 r
.28942 .61137 m .29048 .60864 L .28876 .60925 L F
.28942 .61137 m .29133 .61097 L .29048 .60864 L F
.376 .46 .819 r
.28942 .61137 m .29234 .61422 L .29133 .61097 L F
.486 .765 .993 r
.38438 .59589 m .38783 .597 L .38786 .59603 L F
.291 .583 .942 r
.38783 .597 m .38831 .59564 L .38786 .59603 L F
.38783 .597 m .38942 .59704 L .38831 .59564 L F
.581 .607 .843 r
.28949 .64029 m .29315 .64314 L .29168 .63973 L F
.562 .671 .911 r
.29315 .64314 m .29374 .63992 L .29168 .63973 L F
.29315 .64314 m .29643 .64238 L .29374 .63992 L F
.363 0 .049 r
.29135 .64435 m .29643 .64238 L .29315 .64314 L F
.534 .014 0 r
.45337 .70921 m .45536 .7105 L .45284 .71042 L F
.543 .441 .688 r
.28829 .60577 m .29048 .60864 L .28981 .60538 L F
.28829 .60577 m .28876 .60925 L .29048 .60864 L F
.73 .683 .805 r
.53055 .66816 m .53298 .66478 L .53135 .6668 L F
.329 .271 .64 r
.20967 .5713 m .2095 .57427 L .20917 .57158 L F
.872 .665 .62 r
.60297 .59414 m .60067 .59379 L .60111 .5914 L F
.864 .735 .718 r
.60297 .59414 m .60175 .59712 L .60067 .59379 L F
.519 .53 .807 r
.32795 .61585 m .32681 .61867 L .32517 .61456 L F
.613 .661 .873 r
.32886 .61782 m .32681 .61867 L .32795 .61585 L F
.766 .48 .5 r
.50584 .70757 m .51136 .70923 L .50923 .70641 L F
.342 .373 .749 r
.50923 .70641 m .51136 .70923 L .51165 .70797 L F
.163 .315 .772 r
.54641 .67334 m .54627 .67182 L .54653 .67155 L F
0 0 .509 r
.54651 .67117 m .54653 .67155 L .54635 .67092 L F
.87 .433 .15 r
.54635 .67092 m .54651 .67117 L .54632 .67106 L F
.54635 .67092 m .54651 .67117 L .54635 .67092 L F
.828 .474 .386 r
.54653 .66899 m .54635 .67092 L .54492 .66872 L F
0 0 .509 r
.54651 .67117 m .54635 .67092 L .54611 .67011 L F
.163 .315 .772 r
.54627 .67182 m .54624 .6715 L .54635 .67092 L F
.87 .433 .15 r
.54492 .66872 m .54635 .67092 L .54544 .67042 L F
.163 .315 .772 r
.54632 .67106 m .54611 .67011 L .54635 .67092 L F
.87 .433 .15 r
.54492 .66872 m .54544 .67042 L .54449 .66915 L F
.54635 .67092 m .54632 .67106 L .54401 .66963 L F
.387 .708 .986 r
.54401 .66963 m .54632 .67106 L .54611 .67011 L F
.163 .315 .772 r
.54624 .6715 m .54611 .67011 L .54632 .67106 L F
.387 .708 .986 r
.54632 .67106 m .54651 .67117 L .54611 .67011 L F
.163 .315 .772 r
.54624 .6715 m .54635 .67092 L .54635 .67092 L F
.54627 .67182 m .54635 .67092 L .54653 .67155 L F
.746 .646 .086 r
.5467 .66902 m .54653 .67155 L .54651 .67117 L F
.5467 .66902 m .54653 .67155 L .54651 .67117 L F
.69 .453 .558 r
.54926 .67138 m .54641 .67334 L .54653 .67155 L F
.54926 .67138 m .54897 .67395 L .54641 .67334 L F
.163 .315 .772 r
.54624 .6715 m .54747 .67274 L .54611 .67011 L F
.54641 .67334 m .54725 .67286 L .54624 .6715 L F
.54725 .67286 m .54747 .67274 L .54624 .6715 L F
.87 .433 .15 r
.54449 .66915 m .54544 .67042 L .54401 .66963 L F
.828 .474 .386 r
.5467 .66902 m .54651 .67117 L .54635 .67092 L F
.5467 .66902 m .54635 .67092 L .54653 .66899 L F
.615 .135 .089 r
.52869 .66004 m .53289 .66241 L .53233 .66021 L F
.702 .614 .756 r
.53155 .65694 m .53233 .66021 L .53437 .6595 L F
.37 0 0 r
.53337 .66134 m .53411 .66179 L .53398 .66174 L F
0 0 .215 r
.53247 .66075 m .53289 .66241 L .53337 .66134 L F
.721 .555 .665 r
.53337 .66134 m .53289 .66241 L .52975 .65855 L F
.248 .402 .821 r
.52894 .65969 m .53264 .66223 L .52869 .66004 L F
.53264 .66223 m .53262 .66225 L .52869 .66004 L F
.53156 .66077 m .53289 .66241 L .52894 .65969 L F
.782 .373 .277 r
.53024 .66047 m .5321 .66294 L .53337 .66134 L F
.37 0 0 r
.53205 .66097 m .53328 .66148 L .53024 .66047 L F
.53328 .66148 m .53361 .66162 L .53326 .6615 L F
.53328 .66148 m .53326 .6615 L .53024 .66047 L F
.705 .851 .952 r
.53299 .66182 m .53329 .66146 L .53337 .66134 L F
.702 .614 .756 r
.53155 .65694 m .53437 .6595 L .53297 .65673 L F
.059 0 .272 r
.53337 .66134 m .53411 .66179 L .53412 .6591 L F
0 0 .478 r
.53443 .6601 m .53411 .66179 L .53337 .66134 L F
.248 .402 .821 r
.52975 .65855 m .53156 .66077 L .52894 .65969 L F
.37 0 0 r
.53337 .66134 m .53361 .66162 L .53328 .66148 L F
.53337 .66134 m .53328 .66148 L .53205 .66097 L F
.705 .851 .952 r
.5321 .66294 m .5332 .6616 L .53299 .66182 L F
.37 0 0 r
.53337 .66134 m .53398 .66174 L .53361 .66162 L F
.554 .582 .837 r
.53326 .6615 m .53411 .66179 L .5336 .6611 L F
.705 .851 .952 r
.53329 .66146 m .53438 .66017 L .53337 .66134 L F
.53438 .66017 m .53443 .6601 L .53442 .66012 L F
.53438 .66017 m .53442 .66012 L .53337 .66134 L F
.53386 .66079 m .53443 .6601 L .53299 .66182 L F
.278 .514 .902 r
.53155 .65694 m .53297 .65673 L .53023 .65509 L F
.753 .529 .592 r
.53297 .65673 m .52975 .65855 L .52989 .65615 L F
.53297 .65673 m .53412 .6591 L .52975 .65855 L F
0 0 .215 r
.53233 .66021 m .53247 .66075 L .53337 .66134 L F
.721 .555 .665 r
.53337 .66134 m .52975 .65855 L .53412 .6591 L F
.548 .579 .838 r
.53074 .65728 m .5336 .6611 L .53443 .6601 L F
.5336 .6611 m .53411 .66179 L .53443 .6601 L F
.705 .851 .952 r
.5332 .6616 m .53386 .66079 L .53344 .66129 L F
.53326 .6615 m .53344 .66129 L .53328 .66148 L F
.5332 .6616 m .53344 .66129 L .53326 .6615 L F
.5332 .6616 m .53328 .66148 L .53299 .66182 L F
.554 .582 .837 r
.53024 .66047 m .53326 .6615 L .53074 .65728 L F
.53326 .6615 m .5336 .6611 L .53074 .65728 L F
.248 .402 .821 r
.53264 .66223 m .53289 .66241 L .53262 .66225 L F
.674 .249 .228 r
.5375 .70004 m .53956 .70218 L .54108 .70024 L F
.49 .085 .199 r
.53956 .70218 m .54338 .6998 L .54108 .70024 L F
.146 .055 .486 r
.488 .61986 m .48936 .62164 L .48997 .61961 L F
.488 .61986 m .48786 .62285 L .48936 .62164 L F
.591 .521 .745 r
.78768 .49479 m .78556 .497 L .7853 .49575 L F
.78768 .49479 m .78804 .49645 L .78556 .497 L F
.617 .426 .601 r
.78804 .49645 m .78564 .4994 L .78556 .497 L F
.196 .134 .556 r
.60782 .63921 m .60778 .64269 L .60653 .64304 L F
.196 .133 .555 r
.60778 .64269 m .60813 .64523 L .60653 .64304 L F
.25 .148 .538 r
.60653 .64304 m .60813 .64523 L .60667 .64534 L F
.998 .841 .556 r
.72473 .50408 m .72479 .50611 L .72364 .50507 L F
.967 .662 .264 r
.72479 .50611 m .72482 .50789 L .72364 .50507 L F
.569 .206 .312 r
.46951 .70527 m .47219 .70551 L .47318 .70309 L F
.716 .362 .375 r
.47318 .70309 m .47219 .70551 L .47357 .70454 L F
.433 .782 .997 r
.72807 .49401 m .73159 .49453 L .72964 .49411 L F
.834 .995 .849 r
.72946 .49533 m .73159 .49453 L .72807 .49401 L F
.803 .86 .891 r
.72126 .49808 m .72322 .49806 L .72208 .49676 L F
.573 0 0 r
.72585 .49799 m .72208 .49676 L .72322 .49806 L F
.557 .432 .665 r
.65841 .5028 m .65624 .50133 L .65781 .49977 L F
.65624 .50133 m .65614 .50126 L .65628 .50113 L F
.65624 .50133 m .65628 .50113 L .65781 .49977 L F
.529 .318 .538 r
.65576 .50392 m .65841 .5028 L .65578 .5036 L F
.533 .663 .92 r
.65576 .50392 m .65576 .50389 L .65578 .5036 L F
.557 .432 .665 r
.65841 .5028 m .65578 .5036 L .65614 .50126 L F
.533 .663 .92 r
.65576 .50389 m .65677 .50118 L .65585 .50341 L F
.65576 .50389 m .65585 .50341 L .65578 .5036 L F
.555 .316 .509 r
.65874 .49943 m .66156 .49997 L .6618 .49873 L F
.65704 .49981 m .65822 .49985 L .65874 .49943 L F
.65822 .49985 m .66156 .49997 L .65874 .49943 L F
0 0 .162 r
.65614 .50126 m .65661 .5012 L .65781 .49977 L F
.65661 .5012 m .65677 .50118 L .65698 .50089 L F
.65661 .5012 m .65698 .50089 L .65781 .49977 L F
.65614 .50126 m .65578 .5036 L .65677 .50118 L F
.491 .301 .549 r
.39238 .60589 m .3945 .60538 L .39465 .60285 L F
.425 .224 .501 r
.39238 .60589 m .39422 .60754 L .3945 .60538 L F
.39238 .60589 m .39219 .60823 L .39422 .60754 L F
0 0 0 r
.75329 .52631 m .75246 .52759 L .75055 .52831 L F
.75465 .52648 m .75329 .52631 L .75563 .52565 L F
.75465 .52648 m .75246 .52759 L .75329 .52631 L F
.472 .655 .94 r
.43973 .70693 m .44276 .70825 L .44016 .70606 L F
.464 0 0 r
.44276 .70825 m .44213 .70797 L .44016 .70606 L F
.117 .252 .728 r
.44016 .70606 m .44213 .70797 L .44083 .70466 L F
.44016 .70606 m .44083 .70466 L .44081 .70459 L F
.472 .655 .94 r
.438 .70618 m .43973 .70693 L .44016 .70606 L F
.775 .592 .652 r
.57118 .59202 m .5716 .59454 L .56783 .59405 L F
.216 .039 .413 r
.57336 .59124 m .5716 .59454 L .57118 .59202 L F
.724 .209 0 r
.51668 .63129 m .51894 .63341 L .51998 .63288 L F
.409 0 0 r
.51998 .63288 m .51894 .63341 L .52255 .63358 L F
.594 .484 .699 r
.4329 .66877 m .43525 .66841 L .43425 .66452 L F
.599 .345 .503 r
.43272 .67092 m .43513 .6709 L .4329 .66877 L F
.56 .348 .55 r
.4329 .66877 m .43513 .6709 L .43525 .66841 L F
.562 .805 .99 r
.76361 .49139 m .76633 .4892 L .76424 .48996 L F
.76361 .49139 m .76617 .49062 L .76633 .4892 L F
.148 0 .205 r
.48341 .62845 m .4854 .62783 L .48584 .62556 L F
.047 0 .211 r
.48584 .62556 m .48758 .62484 L .48786 .62285 L F
0 0 .089 r
.48584 .62556 m .48647 .62656 L .48758 .62484 L F
.48584 .62556 m .4854 .62783 L .48647 .62656 L F
0 0 .003 r
.46912 .67004 m .46908 .67096 L .46789 .67077 L F
.899 .66 .569 r
.467 .67008 m .46912 .67004 L .46789 .67077 L F
.591 .621 .85 r
.46908 .67096 m .47021 .668 L .46789 .67077 L F
.46908 .67096 m .47158 .67032 L .47021 .668 L F
.385 .123 .389 r
.29199 .59692 m .29365 .59645 L .29442 .59367 L F
.481 .211 .427 r
.29442 .59367 m .29578 .59592 L .29632 .59238 L F
.29442 .59367 m .29365 .59645 L .29578 .59592 L F
.683 .571 .723 r
.5373 .65963 m .53545 .66241 L .53437 .6595 L F
.511 0 0 r
.75008 .51029 m .74847 .50941 L .74835 .51004 L F
.34 0 0 r
.75274 .51155 m .74847 .50941 L .75008 .51029 L F
.572 .206 .309 r
.48745 .71038 m .48606 .71294 L .48383 .71132 L F
.571 .56 .803 r
.48847 .70811 m .4896 .71117 L .48745 .71038 L F
.657 .289 .336 r
.4896 .71117 m .48606 .71294 L .48745 .71038 L F
.177 0 .248 r
.48341 .62845 m .48469 .62982 L .4854 .62783 L F
.48341 .62845 m .48308 .63064 L .48469 .62982 L F
.02 .187 .697 r
.56219 .64306 m .56303 .64248 L .56164 .63965 L F
.602 .531 .747 r
.78564 .4994 m .78345 .50181 L .78325 .49994 L F
.548 .336 .545 r
.32712 .60853 m .32716 .61109 L .32473 .61124 L F
.515 .321 .556 r
.32944 .60792 m .32716 .61109 L .32712 .60853 L F
.86 .858 .838 r
.49588 .64031 m .49328 .64135 L .49442 .63999 L F
.784 .703 .775 r
.49419 .63996 m .49662 .63992 L .49625 .63993 L F
.49419 .63996 m .49794 .63987 L .49662 .63992 L F
0 0 0 r
.49565 .6385 m .49419 .63996 L .4964 .63993 L F
.86 .858 .838 r
.49583 .63995 m .49442 .63999 L .49565 .6385 L F
.49588 .64031 m .49442 .63999 L .49583 .63995 L F
.784 .703 .775 r
.49625 .63993 m .49662 .63992 L .4964 .63993 L F
.944 .687 .221 r
.49771 .63758 m .49808 .63888 L .49904 .63911 L F
.413 .863 .844 r
.49957 .63924 m .49904 .63911 L .49794 .63987 L F
.411 .862 .858 r
.49904 .63911 m .4964 .63993 L .49794 .63987 L F
.486 .142 .308 r
.49904 .63911 m .49588 .64031 L .4964 .63993 L F
.49904 .63911 m .49883 .64153 L .49876 .6415 L F
.49904 .63911 m .49876 .6415 L .49827 .6404 L F
.49857 .63929 m .49784 .64112 L .49588 .64031 L F
.49904 .63911 m .49784 .64112 L .49857 .63929 L F
.944 .687 .221 r
.49808 .63888 m .49883 .64153 L .49904 .63911 L F
0 0 .354 r
.49771 .63758 m .49852 .64089 L .49883 .64153 L F
.49771 .63758 m .49976 .64373 L .49852 .64089 L F
.49976 .64373 m .49993 .64424 L .49906 .64217 L F
.49976 .64373 m .49906 .64217 L .49852 .64089 L F
.486 .142 .308 r
.49827 .6404 m .49876 .6415 L .49784 .64112 L F
.512 .215 .4 r
.49775 .64135 m .495 .64517 L .49632 .6422 L F
.44 .189 .435 r
.49852 .64089 m .49588 .64031 L .49883 .64153 L F
.512 .215 .4 r
.49852 .64089 m .49738 .64228 L .49775 .64135 L F
.49738 .64228 m .495 .64517 L .49775 .64135 L F
.413 .863 .844 r
.50041 .63891 m .49904 .63911 L .49957 .63924 L F
.616 .815 .977 r
.66112 .50836 m .66236 .50959 L .66525 .50802 L F
.669 .711 .879 r
.66236 .50959 m .66688 .50894 L .66525 .50802 L F
.513 .056 .105 r
.7612 .52294 m .76461 .52255 L .76384 .52397 L F
.439 0 .074 r
.76461 .52255 m .7663 .52393 L .76384 .52397 L F
.76461 .52255 m .76722 .52241 L .7663 .52393 L F
.097 0 0 r
.5116 .7103 m .51321 .70892 L .51165 .70797 L F
.004 0 0 r
.60489 .6658 m .60382 .66737 L .60182 .66845 L F
.057 0 .18 r
.60709 .66278 m .60678 .66508 L .60489 .6658 L F
0 0 0 r
.60489 .6658 m .60678 .66508 L .60382 .66737 L F
.559 .293 .47 r
.5837 .58268 m .58398 .58441 L .58046 .58552 L F
.559 .371 .583 r
.58646 .58233 m .58398 .58441 L .5837 .58268 L F
.121 .268 .742 r
.55222 .64763 m .55333 .65079 L .55155 .64897 L F
.515 .35 .595 r
.55333 .65079 m .551 .65136 L .55155 .64897 L F
.711 .605 .737 r
.69655 .4758 m .69982 .4738 L .69682 .47369 L F
.769 .586 .651 r
.47548 .70574 m .47958 .70603 L .47997 .70402 L F
.243 .097 .475 r
.47997 .70402 m .47958 .70603 L .48129 .70259 L F
.49 .186 .378 r
.5702 .57932 m .57317 .57648 L .57076 .57666 L F
.059 .082 .569 r
.50518 .64578 m .50688 .64728 L .5084 .64531 L F
0 0 0 r
.5084 .64531 m .50966 .6422 L .50792 .64356 L F
.5084 .64531 m .50906 .64417 L .50966 .6422 L F
.051 0 0 r
.5084 .64531 m .50881 .64649 L .50906 .64417 L F
.5084 .64531 m .50688 .64728 L .50881 .64649 L F
.125 0 0 r
.36354 .63821 m .36191 .63914 L .35965 .63949 L F
0 0 0 r
.36398 .6386 m .36354 .63821 L .36551 .63809 L F
.36398 .6386 m .36191 .63914 L .36354 .63821 L F
.851 .704 .7 r
.42559 .70085 m .42156 .70197 L .42392 .69995 L F
.42559 .70085 m .42444 .70363 L .42156 .70197 L F
.7 .859 .958 r
.42739 .69994 m .42559 .70085 L .42392 .69995 L F
.051 0 0 r
.66363 .48573 m .66587 .48555 L .66717 .48528 L F
.453 0 0 r
.66587 .48555 m .66948 .4865 L .66717 .48528 L F
.426 .264 .557 r
.59788 .56311 m .59939 .56454 L .60006 .56323 L F
.59788 .56311 m .5975 .56527 L .59939 .56454 L F
.511 .662 .929 r
.43693 .70456 m .438 .70618 L .4392 .70437 L F
.464 .597 .9 r
.438 .70618 m .44016 .70606 L .4392 .70437 L F
.381 0 .152 r
.55992 .58529 m .56236 .58501 L .56309 .58317 L F
.145 0 0 r
.56236 .58501 m .56544 .58263 L .56309 .58317 L F
0 0 .038 r
.56235 .60609 m .56472 .60281 L .56328 .60525 L F
.249 0 .318 r
.56328 .60525 m .56179 .6075 L .56235 .60609 L F
.742 .337 .285 r
.49211 .63835 m .49064 .63929 L .49078 .63682 L F
.49211 .63835 m .49419 .63996 L .49064 .63929 L F
.661 .285 0 r
.53437 .6595 m .53412 .6591 L .53297 .65673 L F
.831 .695 .713 r
.55349 .66292 m .55194 .66564 L .55411 .6655 L F
.715 .443 .513 r
.55208 .66758 m .55411 .6655 L .55194 .66564 L F
.55208 .66758 m .55361 .66846 L .55411 .6655 L F
.683 .413 .507 r
.55411 .6655 m .55699 .66806 L .55691 .66557 L F
.55411 .6655 m .55361 .66846 L .55699 .66806 L F
.702 .961 .945 r
.74744 .52927 m .75055 .52831 L .75018 .52863 L F
0 0 0 r
.75055 .52831 m .75246 .52759 L .75018 .52863 L F
.562 .27 .43 r
.49856 .70914 m .49793 .71113 L .49545 .71112 L F
.333 .056 .334 r
.50073 .70863 m .49793 .71113 L .49856 .70914 L F
.512 .494 .774 r
.39465 .60285 m .39554 .59876 L .39334 .59918 L F
.39465 .60285 m .39663 .60237 L .39554 .59876 L F
.596 .453 .657 r
.3945 .60538 m .39663 .60237 L .39465 .60285 L F
.525 .368 .61 r
.42634 .67987 m .42854 .67941 L .42845 .67706 L F
.466 .369 .661 r
.42686 .6832 m .42854 .67941 L .42634 .67987 L F
0 .281 .78 r
.50294 .77704 m .50578 .77976 L .50515 .78036 L F
0 0 .204 r
.50578 .77976 m .50471 .78274 L .50515 .78036 L F
.686 .766 .913 r
.71742 .4996 m .7192 .49627 L .71633 .49661 L F
.71742 .4996 m .72126 .49808 L .7192 .49627 L F
.699 .618 .763 r
.77968 .51224 m .77984 .51427 L .77751 .51445 L F
.609 .537 .748 r
.78078 .5156 m .77751 .51445 L .77984 .51427 L F
.428 .16 .403 r
.46001 .67565 m .4578 .67473 L .46063 .67443 L F
.46001 .67565 m .45756 .67667 L .4578 .67473 L F
.152 .512 .913 r
.53087 .63454 m .52952 .63506 L .52823 .63441 L F
.53087 .63454 m .53203 .6358 L .52952 .63506 L F
.713 .549 .665 r
.79275 .5171 m .78898 .51725 L .79173 .51371 L F
.79275 .5171 m .79074 .5177 L .78898 .51725 L F
.731 .611 .723 r
.79275 .5171 m .7904 .51986 L .79074 .5177 L F
.755 .693 .793 r
.79515 .51416 m .79275 .5171 L .79173 .51371 L F
.675 .57 .729 r
.79515 .51416 m .79618 .5174 L .79275 .5171 L F
.746 .52 .587 r
.4965 .6623 m .49767 .65972 L .49651 .66062 L F
.712 .416 .473 r
.47958 .70603 m .48253 .70801 L .48258 .70594 L F
0 0 0 r
.35115 .62729 m .35337 .62709 L .35497 .62676 L F
.121 .668 .697 r
.35337 .62709 m .3571 .62644 L .35497 .62676 L F
.686 .505 .636 r
.78441 .50574 m .7868 .50597 L .78795 .50477 L F
.626 .371 .512 r
.78795 .50477 m .78706 .50561 L .78679 .50562 L F
.7855 .50544 m .78679 .50562 L .78441 .50574 L F
.78795 .50477 m .78679 .50562 L .7855 .50544 L F
.625 .571 .774 r
.78935 .50266 m .78704 .50565 L .78675 .50342 L F
.78704 .50565 m .7868 .50597 L .78679 .50562 L F
.78704 .50565 m .78679 .50562 L .78675 .50342 L F
.672 .609 .777 r
.78675 .50342 m .78679 .50562 L .78441 .50574 L F
.626 .371 .512 r
.78706 .50561 m .78711 .50787 L .78459 .5079 L F
.78795 .50477 m .78775 .50553 L .78706 .50561 L F
.78775 .50553 m .78711 .50787 L .78706 .50561 L F
.672 .609 .777 r
.78679 .50562 m .78679 .50564 L .78441 .50574 L F
.78679 .50564 m .7868 .50597 L .7852 .50582 L F
.78679 .50564 m .7852 .50582 L .78441 .50574 L F
.626 .371 .512 r
.78706 .50561 m .78459 .5079 L .78441 .50574 L F
.798 .993 .757 r
.78795 .50477 m .78935 .50266 L .79016 .50515 L F
.78795 .50477 m .7868 .50597 L .78935 .50266 L F
.647 .392 .519 r
.79093 .50734 m .78795 .50477 L .79016 .50515 L F
.79093 .50734 m .78711 .50787 L .78795 .50477 L F
.418 .404 .737 r
.29773 .62274 m .29889 .61928 L .29687 .62045 L F
.29773 .62274 m .29948 .62246 L .29889 .61928 L F
.326 .052 .335 r
.29773 .62274 m .29764 .62433 L .29948 .62246 L F
0 .185 .713 r
.56307 .62452 m .56343 .62617 L .56194 .62313 L F
.808 .324 .042 r
.56307 .62452 m .56568 .62653 L .56343 .62617 L F
.607 .357 .513 r
.58387 .5735 m .58149 .57151 L .58149 .57381 L F
.58387 .5735 m .58411 .57129 L .58149 .57151 L F
.631 .39 .533 r
.78441 .50574 m .78459 .5079 L .78303 .50741 L F
.672 .609 .777 r
.78675 .50342 m .78441 .50574 L .78345 .50181 L F
.372 0 .176 r
.40016 .62105 m .39846 .62041 L .40061 .6198 L F
.40016 .62105 m .39799 .62138 L .39846 .62041 L F
0 0 .421 r
.56547 .59888 m .5657 .60169 L .56472 .60281 L F
.13 0 .384 r
.5657 .60169 m .56328 .60525 L .56472 .60281 L F
.407 0 0 r
.53546 .63687 m .53847 .63798 L .53861 .63759 L F
.58 .013 0 r
.53861 .63759 m .54115 .63961 L .54248 .6402 L F
0 .234 .748 r
.54016 .63803 m .54115 .63961 L .53861 .63759 L F
.54016 .63803 m .53861 .63759 L .53847 .63798 L F
.304 .739 .968 r
.37537 .58585 m .37752 .58577 L .37894 .58643 L F
.344 .761 .978 r
.37752 .58577 m .38113 .5863 L .37894 .58643 L F
.223 .288 .72 r
.56894 .6306 m .56849 .63418 L .56706 .63109 L F
.56894 .6306 m .56978 .6327 L .56849 .63418 L F
.282 .376 .782 r
.56978 .6327 m .57122 .63601 L .56849 .63418 L F
.602 .531 .747 r
.78564 .4994 m .78675 .50342 L .78345 .50181 L F
.305 .614 .956 r
.38919 .58714 m .38852 .58833 L .38734 .58696 L F
.378 .705 .985 r
.38919 .58714 m .39062 .58833 L .38852 .58833 L F
.457 .294 .571 r
.42796 .6746 m .43009 .67411 L .43029 .67128 L F
.488 .397 .678 r
.42796 .6746 m .43049 .67654 L .43009 .67411 L F
.493 .396 .674 r
.42845 .67706 m .43049 .67654 L .42796 .6746 L F
.466 .369 .661 r
.42686 .6832 m .42876 .68313 L .42854 .67941 L F
.523 .425 .686 r
.42686 .6832 m .42951 .68518 L .42876 .68313 L F
.42686 .6832 m .42738 .6856 L .42951 .68518 L F
.385 .018 .214 r
.54907 .59349 m .55232 .59075 L .54993 .5912 L F
.851 .526 .437 r
.59898 .58583 m .59739 .5873 L .59608 .58493 L F
.59898 .58583 m .59949 .588 L .59739 .5873 L F
.125 .443 .879 r
.49951 .64805 m .50216 .64951 L .50161 .65012 L F
.81 .588 .602 r
.60402 .56519 m .60733 .56828 L .60737 .56577 L F
.869 .498 .343 r
.7904 .51986 m .78712 .5168 L .79074 .5177 L F
.7904 .51986 m .78913 .51975 L .78712 .5168 L F
.726 .223 .036 r
.7904 .51986 m .79027 .52089 L .78913 .51975 L F
0 .122 .614 r
.7904 .51986 m .79226 .52143 L .79174 .52077 L F
.7904 .51986 m .79174 .52077 L .79027 .52089 L F
.187 .078 .489 r
.60896 .65934 m .60906 .66209 L .60709 .66278 L F
.042 0 .084 r
.60709 .66278 m .60807 .66382 L .60678 .66508 L F
.60709 .66278 m .60906 .66209 L .60807 .66382 L F
.468 .164 .365 r
.45636 .65699 m .45876 .65665 L .45934 .65406 L F
.375 .082 .334 r
.45934 .65406 m .46082 .65598 L .46151 .65355 L F
.45934 .65406 m .45876 .65665 L .46082 .65598 L F
.814 .972 .899 r
.71905 .49149 m .71533 .49465 L .71501 .49362 L F
0 0 .403 r
.71533 .49465 m .71633 .49661 L .71501 .49362 L F
.513 .473 .75 r
.49767 .65972 m .50179 .66216 L .50183 .65968 L F
.511 .31 .544 r
.51902 .65413 m .51903 .65681 L .51672 .65714 L F
.375 .204 .518 r
.52112 .65554 m .51902 .65413 L .52039 .65251 L F
.52112 .65554 m .51903 .65681 L .51902 .65413 L F
.699 .487 .597 r
.77531 .5199 m .77542 .5223 L .77309 .52245 L F
.669 .492 .636 r
.77917 .51997 m .77542 .5223 L .77531 .5199 L F
.91 .742 .66 r
.61682 .58789 m .61809 .58897 L .61688 .58542 L F
.928 .705 .58 r
.61518 .58992 m .61809 .58897 L .61682 .58789 L F
.351 0 0 r
.67533 .48748 m .67781 .48719 L .67877 .48579 L F
.301 0 0 r
.67877 .48579 m .68009 .48665 L .68122 .48543 L F
.67877 .48579 m .67781 .48719 L .68009 .48665 L F
.164 0 0 r
.35825 .62628 m .35956 .62646 L .36087 .62591 L F
0 .501 .81 r
.35814 .62585 m .36042 .62659 L .35956 .62646 L F
.497 .002 .01 r
.35956 .62646 m .36143 .62691 L .36313 .62558 L F
0 .501 .81 r
.36042 .62659 m .36143 .62691 L .35956 .62646 L F
.164 0 0 r
.3571 .62644 m .35956 .62646 L .35825 .62628 L F
.497 .002 .01 r
.35956 .62646 m .36313 .62558 L .36087 .62591 L F
.857 .744 .737 r
.6905 .48772 m .68857 .49056 L .69139 .49114 L F
.871 .677 .637 r
.68857 .49056 m .69097 .49352 L .69139 .49114 L F
.779 .701 .778 r
.6905 .48772 m .69139 .49114 L .69397 .4879 L F
.427 .126 .349 r
.32302 .64316 m .32425 .64217 L .32475 .64248 L F
.643 .804 .96 r
.3229 .64125 m .32475 .64248 L .32597 .64079 L F
.427 .126 .349 r
.32444 .64229 m .32597 .64079 L .32475 .64248 L F
.32494 .64162 m .32597 .64079 L .32444 .64229 L F
.643 .804 .96 r
.32494 .64162 m .32597 .64079 L .32632 .64188 L F
.3229 .64125 m .32597 .64079 L .32494 .64162 L F
.427 .126 .349 r
.32495 .64161 m .32597 .64079 L .32494 .64162 L F
.555 .659 .905 r
.3229 .64125 m .32494 .64162 L .32361 .63898 L F
.233 0 0 r
.32636 .6414 m .32874 .64117 L .32597 .64079 L F
.424 .34 .657 r
.32767 .64125 m .32658 .64176 L .32597 .64079 L F
.32658 .64176 m .32632 .64188 L .32597 .64079 L F
.233 0 0 r
.32568 .64146 m .32636 .6414 L .32597 .64079 L F
.3257 .64146 m .32636 .6414 L .32568 .64146 L F
.32726 .64196 m .32874 .64117 L .32568 .64146 L F
.424 .34 .657 r
.32767 .64125 m .32597 .64079 L .32874 .64117 L F
0 .237 .634 r
.32518 .64274 m .32475 .64248 L .32175 .64082 L F
0 .301 .721 r
.32175 .64082 m .32475 .64248 L .3229 .64125 L F
.848 .688 .683 r
.32475 .64248 m .32618 .64613 L .32395 .6453 L F
.969 .841 .66 r
.32475 .64248 m .32395 .6453 L .32302 .64316 L F
.427 .126 .349 r
.32302 .64316 m .32493 .6432 L .32568 .64146 L F
.32499 .64158 m .32568 .64146 L .32597 .64079 L F
.32425 .64217 m .32495 .64161 L .32444 .64229 L F
.32302 .64316 m .32568 .64146 L .32499 .64158 L F
.54 .653 .909 r
.32749 .64115 m .32604 .64158 L .32767 .64125 L F
.32361 .63898 m .32589 .64142 L .32749 .64115 L F
.32589 .64142 m .32604 .64158 L .32749 .64115 L F
.32604 .64158 m .32632 .64188 L .32658 .64176 L F
.32604 .64158 m .32658 .64176 L .32767 .64125 L F
.233 0 0 r
.32568 .64146 m .3257 .64146 L .32568 .64146 L F
.555 .659 .905 r
.32494 .64162 m .32632 .64188 L .32604 .64158 L F
0 .237 .634 r
.32568 .64302 m .32475 .64248 L .32518 .64274 L F
.971 .659 .292 r
.32568 .64302 m .32618 .64613 L .32475 .64248 L F
.32568 .64302 m .32618 .64613 L .32475 .64248 L F
.233 0 0 r
.32493 .6432 m .32726 .64196 L .32568 .64146 L F
.555 .659 .905 r
.32518 .6413 m .32604 .64158 L .32545 .64095 L F
.32494 .64162 m .32604 .64158 L .32518 .6413 L F
.32494 .64162 m .32545 .64095 L .32361 .63898 L F
.517 .344 .586 r
.32796 .64494 m .32618 .64613 L .32568 .64302 L F
.394 .05 .259 r
.3018 .59111 m .30395 .59063 L .30504 .58828 L F
.38 .037 .252 r
.30504 .58828 m .30605 .5901 L .30732 .58802 L F
.30504 .58828 m .30395 .59063 L .30605 .5901 L F
.738 .792 .896 r
.46506 .69854 m .46645 .70042 L .46271 .69892 L F
.46506 .69854 m .46645 .70042 L .46271 .69892 L F
.417 .12 .351 r
.46645 .70042 m .46379 .70288 L .46606 .70244 L F
.399 .848 .914 r
.35288 .59809 m .35485 .59821 L .35687 .59759 L F
0 0 0 r
.65983 .50675 m .6609 .50485 L .65859 .50598 L F
.65983 .50675 m .66045 .50623 L .6609 .50485 L F
0 .028 .599 r
.65983 .50675 m .66112 .50836 L .66045 .50623 L F
.671 .597 .764 r
.78224 .51095 m .77984 .51427 L .77968 .51224 L F
.654 .573 .752 r
.783 .51382 m .77984 .51427 L .78224 .51095 L F
.657 .474 .625 r
.783 .51382 m .78078 .5156 L .77984 .51427 L F
0 0 .364 r
.53448 .61349 m .53425 .61286 L .53301 .6106 L F
.764 .289 0 r
.53448 .61349 m .53512 .61531 L .53425 .61286 L F
.53448 .61349 m .53624 .61627 L .53512 .61531 L F
.709 .25 0 r
.53707 .6171 m .53624 .61627 L .53448 .61349 L F
.319 .77 .957 r
.595 .64539 m .59663 .64507 L .59305 .64478 L F
.173 0 0 r
.43776 .66801 m .44107 .66586 L .43759 .66559 L F
.43776 .66801 m .43966 .6675 L .44107 .66586 L F
.506 .059 .123 r
.44107 .66586 m .43966 .6675 L .44282 .6671 L F
.448 .098 .278 r
.44107 .66586 m .44282 .6671 L .44339 .66548 L F
.193 0 .042 r
.58897 .56826 m .59082 .56744 L .59263 .56513 L F
.518 .143 .267 r
.59263 .56513 m .59429 .56646 L .59411 .56604 L F
.59263 .56513 m .59082 .56744 L .59429 .56646 L F
.611 .457 .649 r
.78303 .50741 m .77968 .51224 L .77894 .50884 L F
.466 .179 .393 r
.37371 .61984 m .37593 .61942 L .37656 .61667 L F
.501 .264 .486 r
.37593 .61942 m .37854 .61635 L .37656 .61667 L F
.476 .229 .459 r
.51125 .66013 m .51325 .66178 L .51105 .6622 L F
.56 .202 .319 r
.51376 .66013 m .51325 .66178 L .51125 .66013 L F
.532 .401 .648 r
.32729 .6139 m .32473 .61124 L .32716 .61109 L F
.32729 .6139 m .32517 .61456 L .32473 .61124 L F
.524 .292 .506 r
.41904 .60573 m .41881 .60787 L .41654 .6082 L F
.502 .239 .448 r
.42141 .60545 m .41881 .60787 L .41904 .60573 L F
.887 .587 .473 r
.72097 .47363 m .72141 .47661 L .7238 .47693 L F
.871 .753 .729 r
.72069 .47869 m .7238 .47693 L .72141 .47661 L F
.72069 .47869 m .72213 .47981 L .7238 .47693 L F
.531 .89 .672 r
.7238 .47693 m .72573 .47519 L .72698 .47449 L F
.029 .024 .515 r
.7238 .47693 m .72601 .47743 L .72573 .47519 L F
.7238 .47693 m .72421 .48037 L .72601 .47743 L F
.14 0 0 r
.75203 .51255 m .75465 .51275 L .75544 .51266 L F
.261 .768 .768 r
.75544 .51266 m .75465 .51275 L .75527 .51258 L F
.75544 .51266 m .75527 .51258 L .75715 .51205 L F
.299 .627 .962 r
.7564 .51307 m .75559 .51273 L .75544 .51266 L F
.75559 .51273 m .75274 .51155 L .75544 .51266 L F
.266 .738 .941 r
.75789 .51253 m .7564 .51307 L .75544 .51266 L F
.75789 .51253 m .75879 .513 L .7564 .51307 L F
.574 .723 .944 r
.34073 .62272 m .33987 .62516 L .3383 .62376 L F
.34073 .62272 m .34218 .6248 L .33987 .62516 L F
.658 .859 .976 r
.67332 .50511 m .67439 .50613 L .67671 .50515 L F
.671 .615 .783 r
.21278 .56453 m .21 .56294 L .21268 .5623 L F
0 0 0 r
.21278 .56453 m .2115 .56726 L .21074 .56847 L F
0 0 .447 r
.21268 .5623 m .2135 .56399 L .21278 .56453 L F
0 0 0 r
.2135 .56399 m .2115 .56726 L .21278 .56453 L F
.686 .305 .32 r
.59939 .56454 m .6022 .56512 L .60006 .56323 L F
.703 .286 .252 r
.60006 .56323 m .6022 .56512 L .60402 .56519 L F
.974 .807 .614 r
.60171 .59954 m .60231 .6026 L .6022 .60205 L F
.972 .9 .545 r
.60231 .6026 m .60104 .60412 L .6022 .60205 L F
.60231 .6026 m .60143 .60595 L .60104 .60412 L F
0 0 .553 r
.57573 .67485 m .57642 .67542 L .57382 .67324 L F
.57573 .67485 m .57703 .67693 L .57642 .67542 L F
.707 .356 .379 r
.48019 .71309 m .47664 .71162 L .47804 .71116 L F
.663 .227 .203 r
.48066 .71201 m .48019 .71309 L .47804 .71116 L F
.504 .544 .831 r
.29541 .61732 m .29687 .62045 L .29889 .61928 L F
.614 .147 .122 r
.58135 .65722 m .58494 .65706 L .58248 .65784 L F
.271 0 .303 r
.5655 .59461 m .56514 .59671 L .56391 .59684 L F
.504 .21 .401 r
.56783 .59405 m .56514 .59671 L .5655 .59461 L F
.499 .188 .37 r
.76118 .5244 m .7612 .52294 L .76384 .52397 L F
.5 .279 .51 r
.40594 .61427 m .40574 .61637 L .40351 .61688 L F
.497 .267 .496 r
.40836 .61378 m .40574 .61637 L .40594 .61427 L F
.719 .668 .799 r
.7882 .51309 m .78898 .51725 L .78712 .5168 L F
.296 0 0 r
.78898 .51725 m .79074 .5177 L .78712 .5168 L F
.706 .659 .801 r
.79173 .51371 m .78898 .51725 L .7882 .51309 L F
.607 .369 .53 r
.51923 .65921 m .51672 .65714 L .51903 .65681 L F
.51923 .65921 m .51679 .65949 L .51672 .65714 L F
.828 .987 .873 r
.66573 .49881 m .66831 .49609 L .66965 .49756 L F
.038 0 0 r
.57626 .58927 m .57823 .58825 L .57528 .59065 L F
.64 .837 .976 r
.80148 .5211 m .80039 .52337 L .7996 .52144 L F
.80148 .5211 m .80253 .52223 L .80039 .52337 L F
0 0 0 r
.80039 .52337 m .80253 .52223 L .79895 .52413 L F
.473 .178 .384 r
.40351 .61688 m .40289 .6194 L .40061 .6198 L F
.392 .107 .356 r
.40498 .61874 m .40351 .61688 L .40574 .61637 L F
.40498 .61874 m .40289 .6194 L .40351 .61688 L F
.864 .738 .722 r
.61432 .57638 m .61541 .57973 L .61566 .57723 L F
.61432 .57638 m .61229 .57916 L .61541 .57973 L F
.877 .672 .622 r
.61218 .58163 m .61541 .57973 L .61229 .57916 L F
.7 .696 .843 r
.32976 .64677 m .3325 .64757 L .33182 .64539 L F
.709 .758 .891 r
.33534 .64611 m .33354 .64625 L .33182 .64539 L F
.429 .717 .985 r
.33182 .64539 m .33354 .64625 L .33349 .64616 L F
.734 .739 .856 r
.33182 .64539 m .33207 .64621 L .3335 .64617 L F
.33182 .64539 m .33349 .64616 L .33534 .64611 L F
.626 .839 .982 r
.33252 .64431 m .33349 .64616 L .33596 .6444 L F
.33349 .64616 m .33354 .64625 L .33366 .64616 L F
.33349 .64616 m .33366 .64616 L .33596 .6444 L F
.734 .739 .856 r
.33349 .64616 m .3335 .64617 L .33366 .64616 L F
.33349 .64616 m .33366 .64616 L .33534 .64611 L F
.429 .717 .985 r
.33182 .64539 m .33349 .64616 L .33252 .64431 L F
.627 .842 .982 r
.33596 .6444 m .33366 .64616 L .33534 .64611 L F
.33366 .64616 m .33354 .64625 L .33534 .64611 L F
.734 .739 .856 r
.33207 .64621 m .3325 .64757 L .33534 .64611 L F
.492 .227 .441 r
.45601 .65908 m .45409 .65743 L .45367 .65942 L F
.45601 .65908 m .45636 .65699 L .45409 .65743 L F
.683 .184 .053 r
.58071 .67791 m .57938 .6788 L .57703 .67693 L F
.978 .913 .597 r
.57984 .67774 m .58071 .67791 L .58192 .67781 L F
.57984 .67774 m .57938 .6788 L .58071 .67791 L F
.941 .885 .75 r
.29726 .64172 m .29537 .64515 L .2967 .64583 L F
.311 .298 .683 r
.60813 .64523 m .60663 .64868 L .60667 .64534 L F
.60813 .64523 m .60864 .64741 L .60663 .64868 L F
.61 .363 .518 r
.60968 .65049 m .60663 .64868 L .60864 .64741 L F
.60968 .65049 m .60716 .65092 L .60663 .64868 L F
.8 .325 .096 r
.75203 .51255 m .75274 .51155 L .75008 .51029 L F
.54 .011 0 r
.75544 .51266 m .75274 .51155 L .75203 .51255 L F
.776 .679 .757 r
.48589 .68009 m .48207 .67995 L .48435 .67661 L F
.487 0 0 r
.48589 .68265 m .48207 .67995 L .48589 .68009 L F
.464 .277 .541 r
.48798 .67955 m .48589 .68265 L .48589 .68009 L F
.536 .416 .663 r
.41928 .70523 m .42156 .70197 L .4182 .70386 L F
.379 .074 .316 r
.37143 .62016 m .37296 .62133 L .37371 .61984 L F
.37143 .62016 m .37082 .62203 L .37296 .62133 L F
.851 .67 .134 r
.53707 .6171 m .53684 .61831 L .53624 .61627 L F
.53707 .6171 m .53709 .62013 L .53684 .61831 L F
0 0 .501 r
.44557 .68493 m .44675 .68757 L .44602 .68866 L F
.596 .394 .578 r
.44674 .69096 m .44602 .68866 L .44675 .68757 L F
.44674 .69096 m .4459 .6917 L .44602 .68866 L F
.611 .299 .416 r
.57557 .57611 m .5791 .57341 L .57596 .57464 L F
.57557 .57611 m .57816 .57614 L .5791 .57341 L F
.608 .223 .288 r
.58054 .57574 m .5791 .57341 L .57816 .57614 L F
.58054 .57574 m .58149 .57381 L .5791 .57341 L F
.421 .705 .981 r
.76946 .48287 m .76753 .48402 L .76654 .48282 L F
.76946 .48287 m .77047 .48413 L .76753 .48402 L F
.44 .762 .996 r
.74477 .52942 m .74626 .52832 L .74363 .52819 L F
.74477 .52942 m .74744 .52927 L .74626 .52832 L F
.359 .402 .769 r
.57456 .64134 m .57297 .64301 L .57211 .63951 L F
.386 .443 .797 r
.57456 .64134 m .57599 .64503 L .57297 .64301 L F
0 .178 .7 r
.4564 .68526 m .45668 .68685 L .45632 .68775 L F
.4564 .68526 m .45786 .68899 L .45668 .68685 L F
.905 .498 .111 r
.45668 .68685 m .45786 .68899 L .45632 .68775 L F
.329 .271 .64 r
.20967 .5713 m .21103 .57338 L .2095 .57427 L F
.325 .153 .488 r
.21103 .57338 m .2091 .57654 L .2095 .57427 L F
.336 .572 .926 r
.50925 .65088 m .51217 .65201 L .51243 .65085 L F
.266 .543 .923 r
.56568 .62653 m .56834 .62811 L .56688 .62866 L F
.415 .284 .593 r
.56834 .62811 m .56706 .63109 L .56688 .62866 L F
.439 .082 .261 r
.57317 .57648 m .57557 .57611 L .57596 .57464 L F
.842 .933 .556 r
.6035 .61729 m .60219 .6195 L .60221 .6187 L F
.93 .735 .252 r
.6035 .61729 m .60305 .61654 L .60312 .61378 L F
.959 .911 .549 r
.60221 .6187 m .60305 .61654 L .6035 .61729 L F
.641 .321 .413 r
.52039 .65251 m .52357 .65068 L .52352 .65067 L F
.642 .327 .423 r
.52361 .65062 m .52039 .65251 L .5213 .65106 L F
.641 .321 .413 r
.52039 .65251 m .52352 .65067 L .5194 .6499 L F
.642 .327 .423 r
.5237 .6506 m .52039 .65251 L .52361 .65062 L F
.445 .136 .346 r
.39557 .62244 m .39497 .62516 L .39261 .62565 L F
.379 .079 .324 r
.39698 .6245 m .39557 .62244 L .39799 .62138 L F
.39698 .6245 m .39497 .62516 L .39557 .62244 L F
.319 0 0 r
.29575 .63881 m .29984 .6367 L .29782 .63748 L F
.636 .143 .066 r
.5716 .59454 m .57006 .59567 L .56783 .59405 L F
.216 .039 .413 r
.57336 .59124 m .57318 .59335 L .5716 .59454 L F
.751 .992 .801 r
.57318 .59335 m .57219 .59378 L .57006 .59567 L F
.27 0 0 r
.57219 .59378 m .57238 .59394 L .57186 .59419 L F
.57238 .59394 m .57312 .59457 L .57196 .59423 L F
.57238 .59394 m .57196 .59423 L .57186 .59419 L F
.751 .992 .801 r
.57274 .59368 m .57006 .59567 L .5716 .59454 L F
.57318 .59335 m .57265 .59375 L .57274 .59368 L F
.57265 .59375 m .57006 .59567 L .57274 .59368 L F
0 .093 .609 r
.74623 .48322 m .74656 .48323 L .74525 .48218 L F
.74623 .48322 m .74827 .48509 L .74656 .48323 L F
.195 0 0 r
.3709 .63583 m .37024 .6367 L .3689 .63633 L F
.197 0 0 r
.3689 .63633 m .37024 .6367 L .36755 .63782 L F
.614 .147 .122 r
.58135 .65722 m .58363 .65869 L .58494 .65706 L F
0 0 .202 r
.58494 .65706 m .58607 .65578 L .5864 .65343 L F
0 0 0 r
.58494 .65706 m .58363 .65869 L .58607 .65578 L F
.396 0 .071 r
.29136 .62774 m .29299 .62804 L .2952 .62573 L F
.648 .931 .971 r
.29764 .62433 m .2952 .62573 L .29579 .6243 L F
.746 .936 .598 r
.2952 .62573 m .29299 .62804 L .29579 .6243 L F
.461 .248 .502 r
.30125 .6401 m .29895 .64289 L .30024 .64168 L F
.837 .891 .879 r
.73442 .48935 m .73687 .48909 L .7365 .48574 L F
.316 .608 .952 r
.20437 .54907 m .20395 .54898 L .20225 .5483 L F
.20437 .54907 m .20534 .55056 L .20395 .54898 L F
0 .31 .784 r
.65691 .49905 m .6574 .49891 L .65672 .4989 L F
.65781 .49977 m .65741 .49893 L .65691 .49905 L F
.65741 .49893 m .6574 .49891 L .65691 .49905 L F
.546 .438 .683 r
.65749 .49891 m .66038 .49402 L .65905 .49581 L F
.954 .869 .459 r
.65781 .49977 m .65734 .4991 L .65741 .49893 L F
.546 .438 .683 r
.65715 .49961 m .6618 .49873 L .66038 .49402 L F
.538 .338 .558 r
.65677 .50118 m .65704 .49981 L .6574 .49891 L F
.546 .438 .683 r
.65704 .49981 m .65712 .49979 L .65715 .49961 L F
.65712 .49979 m .6618 .49873 L .65715 .49961 L F
.954 .869 .459 r
.65781 .49977 m .65692 .50097 L .65734 .4991 L F
.65692 .50097 m .65677 .50118 L .65707 .50008 L F
.65692 .50097 m .65707 .50008 L .65734 .4991 L F
.65741 .49893 m .65734 .4991 L .6574 .49891 L F
.546 .438 .683 r
.65719 .4995 m .65756 .4989 L .65749 .49891 L F
.65704 .49981 m .65715 .49961 L .65719 .4995 L F
.65715 .49961 m .65756 .4989 L .65719 .4995 L F
.65756 .4989 m .66038 .49402 L .65749 .49891 L F
0 0 .086 r
.6574 .49891 m .65704 .49981 L .65749 .49891 L F
.6574 .49891 m .65749 .49891 L .65905 .49581 L F
0 .31 .784 r
.65672 .4989 m .6574 .49891 L .65429 .49695 L F
.515 .381 .637 r
.66019 .50201 m .65781 .49977 L .66032 .49991 L F
.66019 .50201 m .65841 .5028 L .65781 .49977 L F
.252 0 0 r
.45432 .69908 m .45284 .69947 L .45691 .69907 L F
0 0 .028 r
.48611 .64508 m .48399 .648 L .48488 .64613 L F
.38 .774 .988 r
.43693 .70456 m .43291 .70393 L .43407 .70383 L F
.599 .048 0 r
.70903 .47523 m .71164 .47666 L .71249 .47631 L F
.429 0 0 r
.71164 .47666 m .71479 .47623 L .71249 .47631 L F
.921 .755 .66 r
.60175 .59712 m .60008 .59655 L .60067 .59379 L F
.992 .747 .447 r
.60175 .59712 m .60061 .5986 L .60008 .59655 L F
.60175 .59712 m .60171 .59954 L .60061 .5986 L F
.529 .318 .538 r
.65576 .50392 m .65876 .50368 L .65841 .5028 L F
.533 .663 .92 r
.65576 .50392 m .65876 .50368 L .65677 .50118 L F
.353 .188 .513 r
.21074 .56847 m .21065 .57099 L .20967 .5713 L F
.087 0 .425 r
.21215 .56927 m .21074 .56847 L .2115 .56726 L F
.21215 .56927 m .21065 .57099 L .21074 .56847 L F
.573 .665 .901 r
.70565 .48825 m .70892 .49033 L .70821 .48799 L F
.66 .754 .919 r
.70821 .48799 m .70892 .49033 L .71211 .48862 L F
.491 .187 .378 r
.41654 .6082 m .41573 .61075 L .41344 .61103 L F
.52 .229 .413 r
.41881 .60787 m .41573 .61075 L .41654 .6082 L F
.768 .734 .822 r
.69301 .48483 m .6905 .48772 L .69397 .4879 L F
.739 .718 .832 r
.69301 .48483 m .69397 .4879 L .69639 .4854 L F
.534 .834 .999 r
.35791 .58561 m .35426 .58536 L .35643 .58479 L F
.383 .723 .989 r
.35851 .58445 m .35791 .58561 L .35643 .58479 L F
.35851 .58445 m .36009 .58558 L .35791 .58561 L F
.196 .669 .936 r
.33898 .58297 m .34079 .583 L .34257 .58378 L F
.078 .621 .846 r
.34079 .583 m .34469 .58358 L .34257 .58378 L F
.796 .718 .778 r
.79226 .52143 m .79405 .52276 L .79617 .51982 L F
.599 .428 .622 r
.21268 .5623 m .21 .56294 L .21212 .56018 L F
.136 .189 .654 r
.21292 .5582 m .21268 .5623 L .21212 .56018 L F
.287 .784 .871 r
.36046 .59725 m .3591 .59717 L .35687 .59759 L F
.112 .664 .728 r
.36263 .59676 m .3591 .59717 L .36046 .59725 L F
.716 .464 .543 r
.49257 .65952 m .4911 .65612 L .49263 .65727 L F
0 0 0 r
.49495 .65702 m .49257 .65952 L .49263 .65727 L F
.796 .677 .733 r
.48567 .66804 m .49048 .66848 L .48778 .66521 L F
.585 .811 .986 r
.73771 .51054 m .73417 .50999 L .7372 .50774 L F
.802 .804 .853 r
.73999 .50816 m .73771 .51054 L .7372 .50774 L F
.91 .692 .594 r
.61432 .57638 m .61566 .57723 L .61433 .574 L F
.835 .794 .812 r
.299 .64102 m .30125 .6401 L .29953 .64024 L F
.566 .569 .816 r
.30077 .63649 m .30125 .6401 L .29984 .6367 L F
.30198 .63622 m .30163 .63807 L .30077 .63649 L F
.30163 .63807 m .30125 .6401 L .30077 .63649 L F
.85 .504 .397 r
.30198 .63622 m .29929 .63431 L .29984 .6367 L F
.276 0 0 r
.29984 .6367 m .30037 .63785 L .30198 .63622 L F
.85 .504 .397 r
.30198 .63622 m .30112 .63684 L .29884 .633 L F
0 0 .458 r
.29886 .63296 m .30112 .63684 L .29897 .63275 L F
.29884 .633 m .29929 .63376 L .29886 .63296 L F
.29929 .63376 m .30112 .63684 L .29886 .63296 L F
.494 0 0 r
.30359 .63981 m .30169 .64107 L .29953 .64024 L F
.302 .387 .784 r
.29953 .64024 m .30169 .64107 L .30067 .63858 L F
.29953 .64024 m .30067 .63858 L .30037 .63785 L F
.835 .794 .812 r
.29726 .64172 m .299 .64102 L .29953 .64024 L F
0 0 .491 r
.72721 .50405 m .72798 .50493 L .72657 .50339 L F
.639 .263 .315 r
.48383 .71132 m .48019 .71309 L .48066 .71201 L F
.48383 .71132 m .48247 .71347 L .48019 .71309 L F
.516 .079 .148 r
.48606 .71294 m .48247 .71347 L .48383 .71132 L F
.329 0 .053 r
.31781 .58492 m .32 .58454 L .32154 .58261 L F
.419 0 .093 r
.32 .58454 m .32379 .5826 L .32154 .58261 L F
.803 .665 .711 r
.57611 .64807 m .57461 .6512 L .57827 .65096 L F
.543 0 0 r
.57461 .6512 m .57773 .65354 L .57827 .65096 L F
.588 .41 .608 r
.51245 .6474 m .50883 .64879 L .5111 .64547 L F
.392 .24 .553 r
.51331 .64523 m .51245 .6474 L .5111 .64547 L F
.519 .685 .942 r
.77903 .48548 m .77756 .48755 L .77574 .48532 L F
.77903 .48548 m .77983 .4871 L .77756 .48755 L F
.828 .997 .774 r
.45632 .68016 m .45566 .68037 L .45706 .67859 L F
.45632 .68016 m .45566 .68037 L .45706 .67859 L F
.611 .767 .954 r
.75032 .48768 m .75376 .48837 L .75288 .48691 L F
.477 .692 .962 r
.75376 .48837 m .75521 .48677 L .75288 .48691 L F
.52 .761 .984 r
.75376 .48837 m .75618 .488 L .75521 .48677 L F
.186 .522 .918 r
.53916 .62216 m .53993 .62136 L .53709 .62013 L F
.53916 .62216 m .5412 .62295 L .53993 .62136 L F
.131 .323 .789 r
.7258 .51198 m .72786 .51181 L .7256 .50984 L F
.7258 .51198 m .72834 .5138 L .72786 .51181 L F
.865 .564 .478 r
.61209 .58412 m .61381 .58469 L .61649 .58452 L F
.454 .243 .502 r
.29037 .59849 m .29171 .59926 L .29199 .59692 L F
.4 .245 .552 r
.29037 .59849 m .29152 .6011 L .29171 .59926 L F
.29037 .59849 m .28935 .60285 L .29152 .6011 L F
0 .264 .713 r
.31559 .63709 m .31461 .63603 L .31126 .6341 L F
.7 .906 .969 r
.31666 .63634 m .31586 .63583 L .31461 .63603 L F
.31754 .63648 m .31586 .63583 L .31666 .63634 L F
.31627 .63628 m .31461 .63603 L .31672 .63673 L F
.77 .853 .912 r
.31461 .63603 m .31586 .63583 L .31427 .63471 L F
.671 .212 0 r
.31586 .63583 m .31613 .63665 L .31455 .635 L F
.31586 .63583 m .31455 .635 L .31427 .63471 L F
.67 .211 0 r
.31787 .63856 m .31721 .63792 L .31607 .63615 L F
.31787 .63856 m .31607 .63615 L .31606 .63612 L F
.31787 .63856 m .31595 .63597 L .31599 .63601 L F
.7 .906 .969 r
.31672 .63673 m .31461 .63603 L .31559 .63709 L F
.31754 .63648 m .31627 .63628 L .31672 .63673 L F
.67 .211 0 r
.31787 .63856 m .31586 .63583 L .31754 .63648 L F
.671 .212 0 r
.31586 .63583 m .31721 .63792 L .31613 .63665 L F
0 0 0 r
.31796 .63511 m .31613 .63665 L .31814 .63531 L F
.31613 .63665 m .31613 .63665 L .31613 .63665 L F
.31613 .63665 m .31613 .63665 L .31814 .63531 L F
.67 .211 0 r
.31606 .63612 m .31607 .63615 L .31595 .63597 L F
.31599 .63601 m .31595 .63597 L .31586 .63583 L F
.277 .768 .905 r
.3662 .59673 m .36477 .59648 L .36263 .59676 L F
.438 .859 .95 r
.36836 .59612 m .36477 .59648 L .3662 .59673 L F
.92 .556 .32 r
.55815 .6533 m .55889 .6565 L .55701 .65344 L F
.55815 .6533 m .55963 .65464 L .55889 .6565 L F
.405 .016 .185 r
.3853 .62832 m .38399 .63037 L .38173 .63073 L F
.479 .108 .256 r
.38748 .62798 m .38399 .63037 L .3853 .62832 L F
.011 0 0 r
.3071 .63459 m .30604 .63441 L .30795 .63359 L F
0 0 0 r
.3035 .63529 m .30112 .63684 L .30198 .63622 L F
.30422 .63485 m .30344 .63535 L .3035 .63529 L F
.30344 .63535 m .30112 .63684 L .3035 .63529 L F
.011 0 0 r
.3071 .63459 m .30362 .63517 L .30604 .63441 L F
.30362 .63517 m .30299 .63527 L .30372 .63507 L F
.30362 .63517 m .30372 .63507 L .30604 .63441 L F
.322 .715 .981 r
.6825 .50608 m .67892 .50513 L .68003 .50636 L F
.117 .499 .906 r
.54442 .64012 m .54248 .6402 L .54115 .63961 L F
.54442 .64012 m .54493 .64089 L .54248 .6402 L F
.661 .404 .52 r
.51744 .6796 m .52081 .67958 L .52122 .67768 L F
.849 .53 .449 r
.46615 .70412 m .46914 .7031 L .46606 .70244 L F
.46615 .70412 m .46951 .70527 L .46914 .7031 L F
0 0 0 r
.58737 .67562 m .58738 .67571 L .58923 .67497 L F
.193 0 0 r
.59105 .67376 m .58737 .67562 L .58923 .67497 L F
.59105 .67376 m .58956 .67516 L .58737 .67562 L F
.185 .716 .742 r
.58956 .67516 m .58737 .67558 L .58737 .67562 L F
.58737 .67558 m .58615 .67581 L .58737 .67562 L F
0 0 0 r
.58737 .67562 m .58527 .67656 L .58738 .67571 L F
0 .192 .676 r
.50629 .62429 m .50631 .6244 L .50429 .62243 L F
.543 .239 .402 r
.68903 .4795 m .69167 .4791 L .69169 .47738 L F
.633 .31 .407 r
.69169 .47738 m .69405 .47856 L .69395 .47633 L F
.69169 .47738 m .69167 .4791 L .69405 .47856 L F
.75 .712 .817 r
.58822 .63616 m .59223 .63943 L .58825 .63853 L F
.58822 .63616 m .59172 .63675 L .59223 .63943 L F
.749 .25 .042 r
.58825 .63853 m .59223 .63943 L .59014 .64077 L F
.442 0 .003 r
.59172 .63675 m .5938 .63793 L .59223 .63943 L F
0 0 .048 r
.59223 .63943 m .59301 .64038 L .59014 .64077 L F
.577 .381 .58 r
.59296 .63981 m .59545 .63936 L .59536 .63698 L F
.565 .44 .669 r
.59341 .64315 m .59545 .63936 L .59296 .63981 L F
0 0 .048 r
.59223 .63943 m .5938 .63793 L .59301 .64038 L F
.667 .271 .286 r
.26646 .84239 m .26939 .84251 L .26764 .841 L F
.141 .601 .926 r
.32012 .64 m .31787 .63856 L .31754 .63648 L F
.32012 .64 m .32041 .63972 L .31787 .63856 L F
.682 .574 .728 r
.79851 .51677 m .79618 .5174 L .79515 .51416 L F
.141 .113 .563 r
.79783 .51803 m .79618 .5174 L .79851 .51677 L F
.79783 .51803 m .79617 .51982 L .79618 .5174 L F
.46 .381 .681 r
.42738 .6856 m .42984 .6879 L .42951 .68518 L F
.42738 .6856 m .42755 .68906 L .42984 .6879 L F
.499 .238 .449 r
.49781 .68023 m .49969 .68188 L .49995 .67954 L F
.49781 .68023 m .49738 .68231 L .49969 .68188 L F
.49969 .68188 m .49781 .68023 L .49995 .67954 L F
.49969 .68188 m .49738 .68231 L .49781 .68023 L F
.609 .494 .697 r
.43425 .66452 m .43525 .66841 L .43759 .66559 L F
0 .202 .726 r
.50341 .62109 m .50224 .62093 L .50095 .62007 L F
.50341 .62109 m .50429 .62243 L .50224 .62093 L F
.796 .718 .778 r
.79226 .52143 m .79617 .51982 L .79608 .52064 L F
0 0 0 r
.79783 .51803 m .79608 .52064 L .79617 .51982 L F
0 .155 .672 r
.57122 .63601 m .57211 .63951 L .57245 .63722 L F
.667 .117 0 r
.54847 .62534 m .54695 .62479 L .54472 .62273 L F
0 .31 .791 r
.54847 .62534 m .54905 .62497 L .54695 .62479 L F
.54847 .62534 m .55142 .62725 L .54905 .62497 L F
.294 0 .162 r
.33668 .60123 m .33343 .60443 L .33454 .60216 L F
.804 .867 .895 r
.51165 .70797 m .51441 .70703 L .5156 .70718 L F
.687 .859 .964 r
.5156 .70718 m .51441 .70703 L .51789 .70576 L F
.768 .475 .491 r
.47534 .7077 m .47958 .70603 L .47548 .70574 L F
.47534 .7077 m .47893 .70809 L .47958 .70603 L F
.712 .416 .473 r
.47958 .70603 m .47893 .70809 L .48253 .70801 L F
.562 .382 .595 r
.27665 .81438 m .27638 .81746 L .27436 .81743 L F
.27665 .81438 m .27638 .81746 L .27436 .81743 L F
.55 .468 .715 r
.55746 .61641 m .5541 .61397 L .55851 .61619 L F
.523 .552 .827 r
.65429 .49695 m .65654 .49749 L .65537 .49332 L F
.609 .316 .447 r
.65429 .49695 m .6574 .49891 L .65654 .49749 L F
.36 .288 .64 r
.42755 .68906 m .43009 .69064 L .42984 .6879 L F
.42755 .68906 m .42798 .69109 L .43009 .69064 L F
.718 .519 .619 r
.27964 .81654 m .27665 .81438 L .27919 .81382 L F
.27964 .81654 m .27638 .81746 L .27665 .81438 L F
.003 0 .393 r
.27665 .81438 m .27793 .81569 L .27919 .81382 L F
.27665 .81438 m .27638 .81746 L .27793 .81569 L F
.409 .455 .797 r
.34419 .62461 m .34331 .62695 L .34218 .6248 L F
.34419 .62461 m .3454 .62803 L .34331 .62695 L F
.785 .718 .789 r
.52342 .70633 m .52472 .70853 L .52172 .70761 L F
.706 .195 .014 r
.52472 .70853 m .52405 .7092 L .52172 .70761 L F
.456 0 0 r
.52342 .70633 m .52724 .70835 L .52472 .70853 L F
0 0 0 r
.52639 .70809 m .52472 .70853 L .52724 .70835 L F
.52639 .70809 m .52405 .7092 L .52472 .70853 L F
.975 .733 .507 r
.51458 .64853 m .51326 .64847 L .51331 .64523 L F
.615 .426 .603 r
.51243 .65085 m .51466 .65099 L .51458 .64853 L F
.972 .718 .489 r
.51458 .64853 m .51466 .65099 L .51326 .64847 L F
.768 .678 .763 r
.51688 .64563 m .51458 .64853 L .51331 .64523 L F
.269 0 0 r
.29632 .59238 m .29766 .59272 L .29945 .59138 L F
.561 .075 .06 r
.29945 .59138 m .29766 .59272 L .30073 .59214 L F
.29945 .59138 m .30073 .59214 L .30086 .59242 L F
.423 .008 .146 r
.29945 .59138 m .30086 .59242 L .3018 .59111 L F
.803 .724 .778 r
.78712 .5168 m .78411 .51662 L .78603 .51398 L F
.65 .335 .425 r
.78712 .5168 m .78366 .51895 L .78411 .51662 L F
.78712 .5168 m .78597 .51894 L .78366 .51895 L F
.719 .668 .799 r
.7882 .51309 m .78712 .5168 L .78603 .51398 L F
.798 .513 .506 r
.78712 .5168 m .78913 .51975 L .78597 .51894 L F
.776 .464 .46 r
.55412 .67084 m .5548 .67382 L .55267 .67103 L F
.402 .215 .51 r
.55699 .66806 m .55678 .6706 L .55412 .67084 L F
.542 .394 .629 r
.55678 .6706 m .5548 .67382 L .55412 .67084 L F
.149 .692 .794 r
.54472 .62273 m .54313 .62274 L .5412 .62295 L F
.663 .112 0 r
.54472 .62273 m .54551 .62422 L .54313 .62274 L F
.54472 .62273 m .54695 .62479 L .54551 .62422 L F
.97 .928 .623 r
.60104 .60412 m .60143 .60595 L .60049 .60824 L F
0 0 .339 r
.61662 .61395 m .617 .61591 L .61536 .61717 L F
0 0 .233 r
.61536 .61717 m .61644 .61821 L .61494 .61942 L F
.61536 .61717 m .617 .61591 L .61644 .61821 L F
.563 .284 .451 r
.4111 .61143 m .41073 .61345 L .40836 .61378 L F
.548 .271 .447 r
.4111 .61143 m .41311 .61321 L .41073 .61345 L F
.529 .275 .474 r
.41344 .61103 m .41311 .61321 L .4111 .61143 L F
.491 .168 .347 r
.30732 .58802 m .3096 .58774 L .31031 .586 L F
.39 .07 .298 r
.31031 .586 m .31172 .58718 L .3123 .58563 L F
.31031 .586 m .3096 .58774 L .31172 .58718 L F
.495 .063 .148 r
.50589 .78783 m .50817 .78799 L .50964 .78666 L F
.418 .432 .768 r
.50964 .78666 m .50993 .78452 L .50803 .78319 L F
.382 .398 .753 r
.50964 .78666 m .51084 .78799 L .50993 .78452 L F
.777 .431 .4 r
.50817 .78799 m .51084 .78799 L .50964 .78666 L F
.394 .295 .624 r
.21065 .57099 m .21103 .57338 L .20967 .5713 L F
.749 .551 .628 r
.59252 .57985 m .59364 .5794 L .59265 .58217 L F
.224 .723 .91 r
.32379 .5826 m .32591 .58247 L .3274 .58286 L F
.373 0 0 r
.32591 .58247 m .32954 .58255 L .3274 .58286 L F
.637 .417 .568 r
.49112 .65354 m .49367 .65116 L .49128 .65158 L F
.434 .778 .997 r
.39636 .58854 m .39418 .58883 L .39281 .58796 L F
.399 0 .153 r
.46288 .67389 m .46001 .67565 L .46063 .67443 L F
.423 .005 .139 r
.50883 .64879 m .50757 .65055 L .5052 .65081 L F
.849 .819 .819 r
.79668 .52456 m .79817 .52618 L .79895 .52413 L F
.914 .896 .797 r
.72103 .48842 m .718 .49039 L .7201 .48742 L F
.72103 .48842 m .71905 .49149 L .718 .49039 L F
.917 .917 .8 r
.72103 .48842 m .7201 .48742 L .72211 .48436 L F
.482 .334 .604 r
.42845 .67706 m .43064 .67894 L .43049 .67654 L F
.42845 .67706 m .42854 .67941 L .43064 .67894 L F
.533 .804 .996 r
.45632 .68775 m .45786 .68899 L .4564 .68526 L F
.45632 .68775 m .45966 .68886 L .45786 .68899 L F
.575 .242 .367 r
.45786 .68899 m .45966 .68886 L .45632 .68775 L F
.45786 .68899 m .4599 .69057 L .45966 .68886 L F
.402 .708 .984 r
.38596 .58574 m .3848 .58695 L .38336 .5859 L F
.38596 .58574 m .38734 .58696 L .3848 .58695 L F
.402 0 0 r
.33667 .64593 m .33596 .6444 L .33534 .64611 L F
.33667 .64593 m .33367 .6473 L .33596 .6444 L F
.745 .95 .638 r
.33596 .6444 m .33367 .6473 L .33443 .64571 L F
.702 .782 .914 r
.33443 .64571 m .33479 .64605 L .33814 .64571 L F
.402 0 0 r
.33667 .64593 m .3361 .64732 L .33367 .6473 L F
.047 0 0 r
.34127 .64591 m .33982 .64603 L .33894 .646 L F
.33794 .64592 m .33894 .646 L .33667 .64593 L F
.34127 .64591 m .33894 .646 L .33794 .64592 L F
.111 .619 .897 r
.33937 .64604 m .34019 .646 L .33814 .64571 L F
.34159 .64662 m .33975 .64605 L .33937 .64604 L F
.857 .51 .394 r
.33967 .64603 m .34159 .64662 L .33957 .64605 L F
.34315 .64503 m .33957 .64605 L .34127 .64591 L F
.34315 .64503 m .34159 .64662 L .33967 .64603 L F
.111 .619 .897 r
.34159 .64662 m .34035 .64607 L .33975 .64605 L F
.047 0 0 r
.33982 .64603 m .33966 .64605 L .33928 .64604 L F
.111 .619 .897 r
.34035 .64607 m .34019 .646 L .33937 .64604 L F
.047 0 0 r
.33928 .64604 m .33957 .64605 L .33914 .64604 L F
.33966 .64605 m .33957 .64605 L .33928 .64604 L F
.111 .619 .897 r
.34159 .64662 m .33937 .64604 L .33957 .64605 L F
.33937 .64604 m .33814 .64571 L .33957 .64605 L F
.047 0 0 r
.33982 .64603 m .33914 .64604 L .33667 .64593 L F
0 0 0 r
.33814 .64571 m .33667 .64593 L .33957 .64605 L F
.33814 .64571 m .3361 .64732 L .33667 .64593 L F
.702 .782 .914 r
.33479 .64605 m .3361 .64732 L .33773 .64604 L F
.33479 .64605 m .33773 .64604 L .33814 .64571 L F
.298 0 0 r
.75371 .4795 m .75696 .48021 L .75475 .48007 L F
.564 0 0 r
.70951 .47561 m .71164 .47666 L .70903 .47523 L F
.433 0 0 r
.75058 .47805 m .75371 .4795 L .75086 .47794 L F
.383 .843 .79 r
.76715 .51099 m .76495 .5119 L .76369 .51211 L F
.376 .019 .226 r
.58835 .56985 m .5866 .56877 L .5862 .57057 L F
.58835 .56985 m .58897 .56826 L .5866 .56877 L F
.502 .249 .463 r
.38166 .61403 m .3839 .61361 L .38432 .61145 L F
.56 .308 .492 r
.3839 .61361 m .3868 .6108 L .38432 .61145 L F
.545 .234 .391 r
.50282 .63737 m .50264 .63919 L .50041 .63891 L F
.78 .892 .924 r
.46075 .66755 m .46286 .66827 L .46497 .6667 L F
0 .47 .764 r
.46492 .66872 m .46286 .66827 L .46075 .66755 L F
.622 .624 .832 r
.46492 .66872 m .46248 .67091 L .46286 .66827 L F
.166 .013 .414 r
.60902 .63141 m .61122 .62767 L .61041 .63072 L F
.322 .223 .585 r
.61056 .63344 m .60902 .63141 L .61041 .63072 L F
.61056 .63344 m .60929 .63386 L .60902 .63141 L F
.367 0 0 r
.59411 .56604 m .59674 .56643 L .5975 .56527 L F
.635 .297 .382 r
.59674 .56643 m .59939 .56454 L .5975 .56527 L F
.9 .878 .804 r
.55219 .66311 m .55194 .66564 L .55349 .66292 L F
.451 0 .074 r
.556 .66183 m .55219 .66311 L .55349 .66292 L F
.073 .33 .808 r
.52799 .65353 m .52856 .65249 L .52629 .65057 L F
.52799 .65353 m .52899 .65417 L .52856 .65249 L F
.513 .781 .993 r
.4153 .59739 m .41423 .59888 L .41326 .59773 L F
.4153 .59739 m .41687 .59841 L .41423 .59888 L F
.657 .289 .336 r
.4896 .71117 m .48833 .71337 L .48606 .71294 L F
.576 .643 .88 r
.49046 .70894 m .4896 .71117 L .48847 .70811 L F
.49046 .70894 m .49195 .71135 L .4896 .71117 L F
.58 .203 .293 r
.49173 .71272 m .4896 .71117 L .49195 .71135 L F
.49173 .71272 m .48833 .71337 L .4896 .71117 L F
.376 .138 .42 r
.48077 .65703 m .48286 .65648 L .48308 .6542 L F
.647 .364 .477 r
.48286 .65648 m .48476 .65651 L .48308 .6542 L F
.633 .44 .605 r
.52411 .6729 m .52312 .67668 L .52503 .67404 L F
.611 .457 .649 r
.78303 .50741 m .78224 .51095 L .77968 .51224 L F
.557 .65 .897 r
.78226 .48667 m .78065 .48887 L .77983 .4871 L F
.624 .748 .935 r
.78307 .48826 m .78065 .48887 L .78226 .48667 L F
.437 .273 .559 r
.52063 .66279 m .52293 .66472 L .52283 .66244 L F
.515 .031 .045 r
.73047 .51059 m .73417 .50999 L .73188 .51197 L F
.391 .248 .564 r
.49113 .76189 m .49305 .76303 L .49348 .76158 L F
.49113 .76189 m .491 .76391 L .49305 .76303 L F
.762 .876 .929 r
.66723 .5068 m .66525 .50802 L .66844 .50786 L F
.808 .827 .866 r
.66525 .50802 m .66688 .50894 L .66844 .50786 L F
.73 .869 .946 r
.66723 .5068 m .66844 .50786 L .67124 .50627 L F
0 0 0 r
.58737 .67562 m .5856 .67677 L .58527 .67656 L F
.431 .279 .574 r
.48077 .65703 m .48275 .65915 L .48286 .65648 L F
.741 .718 .83 r
.79421 .51134 m .79515 .51416 L .79173 .51371 L F
.683 .685 .846 r
.7982 .5135 m .79515 .51416 L .79421 .51134 L F
.682 .574 .728 r
.79851 .51677 m .79515 .51416 L .7982 .5135 L F
.389 .265 .588 r
.60929 .63386 m .60956 .63635 L .60777 .63703 L F
.338 .181 .515 r
.60956 .63635 m .60782 .63921 L .60777 .63703 L F
.222 0 0 r
.42444 .70363 m .42589 .70413 L .42495 .70346 L F
.42444 .70363 m .42792 .70427 L .42589 .70413 L F
.611 .567 .78 r
.767 .49628 m .76802 .4996 L .77055 .49899 L F
.554 .532 .785 r
.76802 .4996 m .77131 .50229 L .77055 .49899 L F
0 0 0 r
.50245 .67793 m .50301 .6773 L .50231 .67725 L F
.796 .75 .81 r
.5053 .67715 m .50231 .67725 L .50429 .67587 L F
0 0 0 r
.50301 .6773 m .50429 .67587 L .50231 .67725 L F
.796 .75 .81 r
.5053 .67715 m .50506 .67746 L .50301 .6773 L F
.5053 .67715 m .50301 .6773 L .50308 .67722 L F
.74 .504 .572 r
.50245 .67793 m .49999 .67711 L .50231 .67725 L F
.50271 .67923 m .50174 .67848 L .50245 .67793 L F
.50174 .67848 m .49999 .67711 L .50245 .67793 L F
.50334 .67973 m .50271 .67923 L .50245 .67793 L F
.50334 .67973 m .50245 .67793 L .50256 .67785 L F
.796 .75 .81 r
.50506 .67746 m .50334 .67973 L .50256 .67785 L F
0 0 0 r
.50245 .67793 m .50256 .67785 L .50301 .6773 L F
.796 .75 .81 r
.50301 .6773 m .50256 .67785 L .50231 .67725 L F
.50506 .67746 m .50256 .67785 L .50301 .6773 L F
.74 .504 .572 r
.50334 .67973 m .49995 .67954 L .49999 .67711 L F
0 0 0 r
.50149 .67914 m .5032 .67796 L .50306 .67747 L F
.50256 .67785 m .50306 .67747 L .50301 .6773 L F
.50149 .67914 m .50306 .67747 L .50256 .67785 L F
.50118 .67936 m .50149 .67914 L .50256 .67785 L F
.50118 .67936 m .50256 .67785 L .50245 .67793 L F
.74 .504 .572 r
.50256 .67785 m .50245 .67793 L .50231 .67725 L F
0 0 0 r
.50301 .6773 m .5032 .67796 L .50429 .67587 L F
.796 .75 .81 r
.50308 .67722 m .50301 .6773 L .50231 .67725 L F
0 0 0 r
.50118 .67936 m .50245 .67793 L .50231 .67725 L F
.704 .473 .572 r
.49999 .67711 m .50118 .67936 L .50231 .67725 L F
.49999 .67711 m .49995 .67954 L .50118 .67936 L F
.396 .794 .986 r
.36009 .58558 m .36241 .58527 L .36379 .58594 L F
.636 .898 .985 r
.36379 .58594 m .36439 .58436 L .36592 .58537 L F
.36379 .58594 m .36241 .58527 L .36439 .58436 L F
.377 .823 .697 r
.54153 .70339 m .54021 .70398 L .53837 .70492 L F
.486 .342 .61 r
.54338 .6998 m .5436 .70258 L .54153 .70339 L F
0 0 0 r
.5436 .70258 m .54021 .70398 L .54153 .70339 L F
.628 .081 0 r
.50823 .62484 m .51177 .62768 L .50925 .62639 L F
.54 .925 .901 r
.54417 .59632 m .54217 .59735 L .54054 .5974 L F
.354 0 .113 r
.36533 .62505 m .3675 .62466 L .36881 .62271 L F
.453 .102 .279 r
.3675 .62466 m .37082 .62203 L .36881 .62271 L F
.701 .73 .873 r
.7115 .47197 m .71114 .4726 L .71409 .47093 L F
.543 0 0 r
.57461 .6512 m .57673 .65303 L .57773 .65354 L F
.936 .598 .162 r
.57673 .65303 m .57816 .65617 L .57773 .65354 L F
.23 .744 .864 r
.36592 .58537 m .36814 .58509 L .36956 .58522 L F
.243 .751 .875 r
.36814 .58509 m .37177 .58497 L .36956 .58522 L F
.754 .507 .559 r
.60739 .57328 m .61076 .57125 L .60725 .57079 L F
.60739 .57328 m .61082 .57359 L .61076 .57125 L F
.442 .718 .983 r
.47701 .66142 m .47944 .66343 L .47632 .66284 L F
.604 .235 .316 r
.58862 .58005 m .5903 .58151 L .58861 .58192 L F
.58862 .58005 m .59252 .57985 L .5903 .58151 L F
.419 .45 .786 r
.52662 .64845 m .5272 .64464 L .5259 .64542 L F
.52662 .64845 m .52879 .64743 L .5272 .64464 L F
.959 .674 .452 r
.52662 .64845 m .52785 .64793 L .52879 .64743 L F
.52662 .64845 m .52497 .64814 L .52785 .64793 L F
.865 .922 .864 r
.72958 .49027 m .72807 .49401 L .72964 .49411 L F
.72958 .49027 m .72675 .4936 L .72807 .49401 L F
0 .291 .729 r
.72675 .4936 m .72946 .49533 L .72807 .49401 L F
.754 .671 .77 r
.49545 .71112 m .49195 .71135 L .49423 .70817 L F
.586 .142 .161 r
.49545 .71112 m .49414 .71285 L .49195 .71135 L F
.565 .118 .147 r
.49708 .71282 m .49545 .71112 L .49793 .71113 L F
.49708 .71282 m .49414 .71285 L .49545 .71112 L F
.515 .091 .173 r
.48636 .64276 m .48817 .64442 L .488 .64325 L F
0 .019 .563 r
.7295 .47252 m .73258 .47637 L .73221 .47407 L F
.471 .232 .469 r
.53253 .70585 m .53495 .70537 L .53494 .70253 L F
.664 .942 .681 r
.5375 .70004 m .53494 .70253 L .53621 .70094 L F
.542 .287 .478 r
.53494 .70253 m .53746 .70466 L .53621 .70094 L F
.53494 .70253 m .53495 .70537 L .53746 .70466 L F
.577 .736 .951 r
.42792 .70427 m .42863 .70558 L .43084 .70507 L F
.536 .215 .371 r
.51217 .65201 m .51466 .65099 L .51243 .65085 L F
.672 .703 .871 r
.69639 .4854 m .70012 .48638 L .69881 .48454 L F
.657 .631 .813 r
.69881 .48454 m .70012 .48638 L .70214 .48555 L F
.814 .972 .899 r
.71905 .49149 m .71501 .49362 L .718 .49039 L F
.736 .37 .358 r
.4601 .70254 m .46274 .70489 L .46379 .70288 L F
.569 .245 .38 r
.46274 .70489 m .46606 .70244 L .46379 .70288 L F
.963 .77 .595 r
.60111 .5914 m .60067 .59379 L .59968 .59053 L F
.72 .536 .641 r
.48687 .67418 m .48435 .67661 L .48464 .67414 L F
.48687 .67418 m .48734 .67723 L .48435 .67661 L F
.557 .378 .595 r
.48997 .67392 m .48734 .67723 L .48687 .67418 L F
0 0 0 r
.66004 .48673 m .66267 .4861 L .66363 .48573 L F
.625 .142 .086 r
.66267 .4861 m .66587 .48555 L .66363 .48573 L F
.28 0 .232 r
.4669 .64886 m .46828 .64965 L .46906 .64833 L F
.4669 .64886 m .46627 .65051 L .46828 .64965 L F
.816 .355 .13 r
.51376 .62967 m .51511 .63106 L .51668 .63129 L F
.489 0 0 r
.51511 .63106 m .51894 .63341 L .51668 .63129 L F
.118 0 0 r
.53397 .59901 m .53064 .60021 L .53291 .59989 L F
.622 .224 .268 r
.53291 .59989 m .53636 .59962 L .53397 .59901 L F
.434 .226 .497 r
.57528 .59065 m .57318 .59335 L .57336 .59124 L F
.234 0 .273 r
.47403 .64211 m .47604 .64185 L .47635 .63952 L F
.299 0 .249 r
.47403 .64211 m .47539 .6438 L .47604 .64185 L F
.47403 .64211 m .47341 .64453 L .47539 .6438 L F
.186 .127 .554 r
.56805 .65942 m .56916 .65969 L .56873 .65672 L F
.801 .727 .783 r
.71211 .48862 m .71526 .48893 L .71407 .48717 L F
.71 .747 .881 r
.71407 .48717 m .71526 .48893 L .71749 .48772 L F
.781 .949 .929 r
.59441 .63456 m .59482 .63694 L .59279 .63497 L F
.59557 .63428 m .59533 .63512 L .59441 .63456 L F
.59533 .63512 m .59482 .63694 L .59441 .63456 L F
.571 .518 .757 r
.59536 .63698 m .59783 .6365 L .5963 .63409 L F
.781 .949 .929 r
.59557 .63428 m .59657 .63512 L .59482 .63694 L F
.733 .989 .813 r
.59482 .63694 m .59657 .63512 L .59503 .63577 L F
.59473 .63616 m .59503 .63577 L .5947 .63591 L F
.59482 .63694 m .59503 .63577 L .59473 .63616 L F
0 0 .059 r
.59599 .63421 m .59618 .63116 L .5963 .63409 L F
.004 0 .353 r
.59581 .63478 m .59684 .63346 L .59557 .63428 L F
.722 .23 .071 r
.59637 .63574 m .59584 .63543 L .59657 .63512 L F
.779 .338 0 r
.5963 .63409 m .59657 .63512 L .59599 .63421 L F
.5963 .63409 m .59783 .6365 L .59657 .63512 L F
.004 0 .353 r
.59638 .63599 m .59684 .63346 L .59581 .63478 L F
.59684 .63346 m .59684 .63346 L .59581 .63478 L F
.722 .23 .071 r
.59633 .63587 m .5947 .63591 L .59584 .63543 L F
.701 .973 .761 r
.59536 .63698 m .59657 .63512 L .59482 .63694 L F
.59536 .63698 m .59657 .63512 L .59482 .63694 L F
.722 .23 .071 r
.59633 .63587 m .59584 .63543 L .59637 .63574 L F
.733 .989 .813 r
.59482 .63694 m .5947 .63591 L .59426 .63688 L F
0 .55 .717 r
.59172 .63675 m .59482 .63694 L .59524 .63698 L F
.59172 .63675 m .59482 .63694 L .59536 .63698 L F
.442 0 .003 r
.59172 .63675 m .59394 .63688 L .5938 .63793 L F
.59394 .63688 m .59482 .63694 L .5938 .63793 L F
.733 .989 .813 r
.59482 .63694 m .59426 .63688 L .5938 .63793 L F
.466 .682 .959 r
.59279 .63497 m .59482 .63694 L .59172 .63675 L F
.724 .633 .756 r
.5947 .63591 m .59371 .63853 L .5938 .63793 L F
.59371 .63853 m .59301 .64038 L .5938 .63793 L F
0 .55 .717 r
.59524 .63698 m .59482 .63694 L .59536 .63698 L F
.506 .314 .554 r
.59545 .63936 m .59783 .6365 L .59536 .63698 L F
.78 .775 .848 r
.72958 .49027 m .72964 .49411 L .73276 .49046 L F
.397 .031 .221 r
.39043 .62609 m .38968 .62761 L .38748 .62798 L F
.353 0 .199 r
.39192 .62693 m .39043 .62609 L .39261 .62565 L F
.39192 .62693 m .38968 .62761 L .39043 .62609 L F
.542 .354 .576 r
.58387 .5735 m .5862 .57057 L .58411 .57129 L F
.615 .511 .712 r
.49961 .78451 m .49979 .78676 L .50247 .78577 L F
.50247 .78577 m .49979 .78676 L .49961 .78451 L F
.587 .601 .833 r
.49979 .78676 m .50391 .78841 L .50247 .78577 L F
.348 0 .192 r
.37962 .63135 m .37847 .63368 L .37632 .63421 L F
.472 .102 .255 r
.38126 .63247 m .37962 .63135 L .38173 .63073 L F
.38126 .63247 m .37847 .63368 L .37962 .63135 L F
.441 .425 .745 r
.79974 .51311 m .79851 .51677 L .7982 .5135 L F
.79974 .51311 m .80066 .51607 L .79851 .51677 L F
.067 0 0 r
.80052 .51662 m .79851 .51677 L .80066 .51607 L F
.80052 .51662 m .79783 .51803 L .79851 .51677 L F
0 0 .179 r
.48786 .62285 m .48758 .62484 L .48936 .62164 L F
0 .367 .803 r
.7319 .51604 m .72834 .5138 L .72963 .51534 L F
0 .066 .619 r
.49134 .67043 m .49224 .67301 L .49278 .67147 L F
.936 .607 .163 r
.5314 .64725 m .53255 .64868 L .53173 .64686 L F
0 0 .54 r
.5314 .64725 m .53184 .65 L .53255 .64868 L F
.551 .604 .86 r
.53173 .64686 m .53255 .64868 L .53443 .64784 L F
.164 0 .099 r
.53255 .64868 m .53184 .65 L .53443 .64784 L F
.572 .613 .855 r
.33233 .62028 m .32886 .61782 L .33144 .61858 L F
.26 .492 .89 r
.33323 .61901 m .33233 .62028 L .33144 .61858 L F
.33323 .61901 m .33504 .62162 L .33233 .62028 L F
0 .384 .831 r
.55187 .62837 m .55418 .62881 L .55142 .62725 L F
.55187 .62837 m .55525 .6302 L .55418 .62881 L F
.398 .309 .637 r
.60968 .65049 m .60791 .65441 L .60716 .65092 L F
.60968 .65049 m .61043 .65352 L .60791 .65441 L F
0 0 0 r
.61043 .65352 m .60846 .65682 L .60791 .65441 L F
.44 .235 .504 r
.29171 .59926 m .29365 .59645 L .29199 .59692 L F
0 0 .157 r
.72798 .50493 m .72847 .50742 L .7286 .50831 L F
.177 0 0 r
.59655 .67085 m .59539 .67223 L .59316 .67276 L F
0 0 0 r
.59964 .66935 m .59838 .67045 L .59655 .67085 L F
.59655 .67085 m .59838 .67045 L .59539 .67223 L F
.573 0 0 r
.72585 .49799 m .72602 .4991 L .72208 .49676 L F
0 .349 .813 r
.72585 .49799 m .72704 .49802 L .72602 .4991 L F
.874 .585 .495 r
.52172 .70761 m .51997 .70768 L .52214 .70645 L F
.038 0 0 r
.51997 .70768 m .52342 .70633 L .52214 .70645 L F
.389 .421 .773 r
.29133 .61097 m .29234 .61422 L .29372 .61279 L F
.432 .358 .673 r
.29234 .61422 m .29398 .61396 L .29372 .61279 L F
.29234 .61422 m .29261 .61681 L .29398 .61396 L F
.532 .339 .565 r
.66831 .49609 m .66534 .49893 L .6664 .49607 L F
.604 .332 .478 r
.29062 .64471 m .29029 .64553 L .28733 .64653 L F
.737 .766 .876 r
.29026 .64554 m .28733 .64653 L .28558 .6446 L F
.29042 .64557 m .28733 .64653 L .29026 .64554 L F
.61 .329 .466 r
.28733 .64653 m .28934 .64793 L .29042 .64557 L F
.604 .332 .478 r
.29029 .64553 m .28934 .64793 L .28733 .64653 L F
0 0 .211 r
.29062 .64471 m .29135 .64435 L .29353 .64494 L F
.803 .553 .561 r
.29224 .64627 m .29062 .64471 L .29353 .64494 L F
0 0 .211 r
.29062 .64471 m .29042 .64557 L .29135 .64435 L F
.61 .329 .466 r
.28733 .64653 m .29042 .64557 L .28989 .64547 L F
.28576 .6448 m .28989 .64547 L .28558 .6446 L F
.28733 .64653 m .28989 .64547 L .28576 .6448 L F
.803 .553 .561 r
.29171 .64576 m .29029 .64553 L .29062 .64471 L F
.651 .769 .298 r
.29042 .64557 m .29041 .64558 L .29043 .64556 L F
.803 .553 .561 r
.29224 .64627 m .29029 .64553 L .29171 .64576 L F
.651 .769 .298 r
.29043 .64556 m .28996 .64654 L .29135 .64435 L F
.803 .553 .561 r
.29224 .64627 m .29007 .64609 L .29041 .64558 L F
.29018 .64609 m .28934 .64793 L .29007 .64609 L F
.651 .769 .298 r
.29041 .64558 m .28934 .64793 L .28996 .64654 L F
.29042 .64557 m .28934 .64793 L .29041 .64558 L F
.803 .553 .561 r
.29224 .64627 m .28934 .64793 L .29018 .64609 L F
.651 .769 .298 r
.29041 .64558 m .28996 .64654 L .29043 .64556 L F
.803 .553 .561 r
.29041 .64558 m .29007 .64609 L .29029 .64553 L F
.537 .094 .145 r
.71753 .47445 m .71987 .4753 L .72097 .47363 L F
.944 .629 .409 r
.71987 .4753 m .72141 .47661 L .72097 .47363 L F
.294 .746 .957 r
.32954 .58255 m .33163 .58243 L .33317 .58301 L F
0 .552 .741 r
.33163 .58243 m .33529 .58278 L .33317 .58301 L F
.415 .599 .922 r
.20777 .55039 m .20749 .55248 L .20579 .55059 L F
.20777 .55039 m .20989 .55299 L .20749 .55248 L F
.192 0 .288 r
.47635 .63952 m .47836 .63895 L .47866 .63647 L F
.208 0 .265 r
.47635 .63952 m .47775 .64094 L .47836 .63895 L F
.47635 .63952 m .47604 .64185 L .47775 .64094 L F
.691 .24 .177 r
.53621 .70094 m .53956 .70218 L .5375 .70004 L F
.074 0 0 r
.35147 .64232 m .34739 .64391 L .34934 .64295 L F
.263 0 .039 r
.54165 .67022 m .5412 .66931 L .54445 .66836 L F
.54165 .67022 m .53945 .6708 L .5412 .66931 L F
.519 .346 .586 r
.43029 .67128 m .43232 .67345 L .43272 .67092 L F
.43029 .67128 m .43009 .67411 L .43232 .67345 L F
.546 .636 .891 r
.40761 .59117 m .40719 .59407 L .40554 .59119 L F
.40761 .59117 m .40932 .59368 L .40719 .59407 L F
0 0 0 r
.29224 .64627 m .28844 .64853 L .28934 .64793 L F
.29224 .64627 m .28922 .64815 L .28844 .64853 L F
.023 0 0 r
.29348 .64657 m .28922 .64815 L .29224 .64627 L F
.653 .419 .552 r
.55236 .67343 m .54926 .67138 L .55267 .67103 L F
.55236 .67343 m .54897 .67395 L .54926 .67138 L F
.511 .361 .614 r
.78465 .51048 m .78303 .50741 L .78459 .5079 L F
.78465 .51048 m .78224 .51095 L .78303 .50741 L F
.339 .336 .709 r
.56514 .59671 m .56547 .59888 L .56391 .59684 L F
.321 .785 .662 r
.32976 .64677 m .32618 .64613 L .32796 .64494 L F
0 0 0 r
.33003 .64703 m .32976 .64677 L .33182 .64539 L F
.33003 .64703 m .32789 .64761 L .32976 .64677 L F
.469 .33 .609 r
.44677 .68208 m .44683 .68721 L .44557 .68493 L F
.854 .401 .019 r
.44683 .68721 m .44675 .68757 L .44557 .68493 L F
.583 .339 .512 r
.58046 .58552 m .58084 .58799 L .57823 .58825 L F
.536 .246 .422 r
.58046 .58552 m .5831 .58742 L .58084 .58799 L F
.58046 .58552 m .58398 .58441 L .5831 .58742 L F
.186 .709 .685 r
.46264 .68886 m .4658 .68801 L .46355 .68845 L F
.575 .742 .956 r
.46206 .6882 m .4631 .68638 L .46085 .68682 L F
0 0 0 r
.46227 .68816 m .46193 .68822 L .46355 .68845 L F
.575 .742 .956 r
.46264 .68886 m .46279 .68806 L .46206 .6882 L F
.46279 .68806 m .4631 .68638 L .46206 .6882 L F
0 0 0 r
.4658 .68801 m .46227 .68816 L .46355 .68845 L F
.46227 .68816 m .46165 .68818 L .46193 .68822 L F
.979 .706 .436 r
.61717 .60699 m .61835 .60549 L .61707 .6046 L F
.983 .792 .571 r
.61835 .60549 m .61749 .60219 L .61707 .6046 L F
.981 .711 .439 r
.61717 .60699 m .61846 .60799 L .61835 .60549 L F
.449 0 0 r
.53191 .66348 m .53127 .66467 L .52872 .66453 L F
.813 .354 .14 r
.53298 .66478 m .53127 .66467 L .53191 .66348 L F
.501 .442 .722 r
.76923 .50539 m .77197 .50713 L .77141 .50484 L F
.535 .433 .685 r
.76923 .50539 m .76967 .50781 L .77197 .50713 L F
.384 .815 .963 r
.34912 .58351 m .34846 .58433 L .34698 .58356 L F
.34912 .58351 m .35076 .58393 L .34846 .58433 L F
.015 .423 .862 r
.56427 .64633 m .56649 .64687 L .56371 .64503 L F
.836 .454 0 r
.56712 .6479 m .56707 .64893 L .56649 .64687 L F
.803 .695 .154 r
.56707 .64893 m .56716 .64657 L .56649 .64687 L F
.56716 .64657 m .56719 .64566 L .56649 .64687 L F
.015 .423 .862 r
.56427 .64633 m .5658 .64717 L .56649 .64687 L F
.5658 .64717 m .56712 .6479 L .56649 .64687 L F
.538 .289 .485 r
.44801 .6648 m .44598 .66287 L .44566 .66507 L F
.44801 .6648 m .44835 .66244 L .44598 .66287 L F
0 0 .572 r
.55538 .63121 m .55567 .63041 L .55525 .6302 L F
0 .001 .578 r
.55538 .63121 m .5569 .63335 L .55567 .63041 L F
.603 .573 .793 r
.79167 .50168 m .79016 .50515 L .78935 .50266 L F
.79167 .50168 m .79262 .50504 L .79016 .50515 L F
.73 .567 .67 r
.79262 .50504 m .79093 .50734 L .79016 .50515 L F
.657 .474 .625 r
.783 .51382 m .78411 .51662 L .78078 .5156 L F
.599 .569 .792 r
.78465 .51048 m .783 .51382 L .78224 .51095 L F
.78465 .51048 m .78603 .51398 L .783 .51382 L F
.612 .451 .64 r
.78603 .51398 m .78411 .51662 L .783 .51382 L F
.871 .439 .034 r
.72895 .47104 m .72925 .47186 L .72835 .47153 L F
.36 .696 .983 r
.72835 .47153 m .7295 .47252 L .72925 .47186 L F
.72835 .47153 m .72925 .47186 L .72895 .47104 L F
.078 .623 .843 r
.72835 .47153 m .73048 .47169 L .72766 .47129 L F
.72835 .47153 m .72766 .47129 L .72702 .47119 L F
.72835 .47153 m .73048 .47169 L .72766 .47129 L F
.72835 .47153 m .72766 .47129 L .72702 .47119 L F
.871 .439 .034 r
.72925 .47186 m .7295 .47252 L .72835 .47153 L F
0 0 0 r
.6003 .66943 m .59964 .66935 L .60182 .66845 L F
.6003 .66943 m .59838 .67045 L .59964 .66935 L F
.636 .19 .175 r
.76722 .52241 m .76983 .52399 L .7663 .52393 L F
.628 .225 .259 r
.76722 .52241 m .76955 .52274 L .76983 .52399 L F
.749 .551 .628 r
.59252 .57985 m .59265 .58217 L .5903 .58151 L F
0 .166 .705 r
.56149 .64005 m .56128 .63842 L .55843 .63681 L F
.56149 .64005 m .56164 .63965 L .56128 .63842 L F
.282 .634 .964 r
.76419 .48272 m .76111 .48128 L .7633 .4814 L F
.359 .69 .981 r
.76558 .48169 m .76419 .48272 L .7633 .4814 L F
.76558 .48169 m .76654 .48282 L .76419 .48272 L F
.871 .677 .637 r
.68857 .49056 m .68835 .49301 L .69097 .49352 L F
.86 .736 .725 r
.68835 .49301 m .68934 .49627 L .69097 .49352 L F
.758 .888 .937 r
.77887 .5276 m .77701 .52765 L .77887 .52496 L F
.56 .59 .841 r
.78122 .52445 m .77887 .5276 L .77887 .52496 L F
.78122 .52445 m .78238 .52793 L .77887 .5276 L F
.592 .47 .682 r
.43759 .66559 m .43525 .66841 L .43776 .66801 L F
.552 .338 .543 r
.43513 .6709 m .43776 .66801 L .43525 .66841 L F
.717 .444 .512 r
.66378 .50202 m .66019 .50201 L .66032 .49991 L F
.671 .654 .825 r
.51744 .6796 m .51916 .68072 L .52081 .67958 L F
.478 .025 .095 r
.34279 .59962 m .34128 .60133 L .33912 .60112 L F
0 0 0 r
.34336 .60012 m .34279 .59962 L .345 .5994 L F
.34336 .60012 m .34128 .60133 L .34279 .59962 L F
.817 .787 .824 r
.73905 .50553 m .73999 .50816 L .7372 .50774 L F
.732 .744 .862 r
.74212 .50567 m .73999 .50816 L .73905 .50553 L F
.806 .56 .567 r
.61082 .57359 m .61432 .57638 L .61433 .574 L F
.836 .709 .723 r
.55746 .61641 m .5587 .61972 L .55955 .61678 L F
.343 .171 .499 r
.47866 .63647 m .48096 .6363 L .48097 .63352 L F
.218 0 .296 r
.47866 .63647 m .48006 .63804 L .48096 .6363 L F
.47866 .63647 m .47836 .63895 L .48006 .63804 L F
.603 .665 .883 r
.38942 .59704 m .39334 .59918 L .39091 .59672 L F
.505 .798 .998 r
.39334 .59918 m .39399 .59757 L .39091 .59672 L F
.39334 .59918 m .39554 .59876 L .39399 .59757 L F
.712 .34 .341 r
.46856 .71111 m .46718 .71325 L .46496 .71096 L F
.582 .188 .26 r
.4709 .71145 m .46718 .71325 L .46856 .71111 L F
.191 0 0 r
.35079 .5984 m .34713 .59869 L .34846 .59881 L F
.388 .627 .948 r
.46738 .69859 m .46692 .69605 L .46834 .697 L F
.321 .484 .866 r
.46842 .69497 m .46834 .697 L .46692 .69605 L F
.46842 .69497 m .46885 .69569 L .46838 .69599 L F
.526 .895 .699 r
.46692 .69605 m .46792 .69506 L .46842 .69497 L F
.591 .394 .583 r
.46692 .69605 m .46907 .69555 L .46792 .69506 L F
0 0 0 r
.46996 .69534 m .46834 .697 L .46925 .69635 L F
.46996 .69534 m .46959 .6958 L .46834 .697 L F
.46959 .6958 m .46738 .69859 L .46834 .69701 L F
.46959 .6958 m .46916 .69621 L .46834 .697 L F
.321 .484 .866 r
.46838 .69599 m .46909 .69629 L .46834 .697 L F
.46909 .69629 m .46925 .69635 L .46834 .697 L F
0 0 0 r
.46916 .69621 m .46834 .69701 L .46834 .697 L F
.21 .136 .549 r
.46925 .69635 m .47124 .6956 L .46996 .69534 L F
.331 .491 .867 r
.46916 .69621 m .47124 .6956 L .46925 .69635 L F
.46885 .69569 m .46933 .69567 L .46916 .69621 L F
.46933 .69567 m .46959 .6958 L .46916 .69621 L F
.321 .484 .866 r
.46885 .69569 m .46925 .69635 L .46838 .69599 L F
.591 .394 .583 r
.46692 .69605 m .46738 .69859 L .46959 .6958 L F
.46908 .69555 m .46959 .6958 L .46996 .69534 L F
.46692 .69605 m .46959 .6958 L .46908 .69555 L F
.331 .491 .867 r
.46933 .69567 m .46974 .69565 L .46959 .6958 L F
.46974 .69565 m .47124 .6956 L .46916 .69621 L F
.46842 .69497 m .46959 .69523 L .46885 .69569 L F
.591 .394 .583 r
.46908 .69555 m .46996 .69534 L .46951 .69528 L F
.154 0 0 r
.46951 .69528 m .47124 .6956 L .46996 .69534 L F
.331 .491 .867 r
.46951 .69528 m .47124 .6956 L .46885 .69569 L F
.154 0 0 r
.46792 .69506 m .47124 .6956 L .46951 .69528 L F
.331 .491 .867 r
.46959 .69523 m .47124 .6956 L .46951 .69528 L F
.591 .394 .583 r
.46907 .69555 m .46908 .69555 L .46949 .69527 L F
.46908 .69555 m .46951 .69528 L .46949 .69527 L F
.46907 .69555 m .46949 .69527 L .46792 .69506 L F
.431 .083 .273 r
.51573 .66125 m .51376 .66013 L .51679 .65949 L F
.51573 .66125 m .51325 .66178 L .51376 .66013 L F
.437 .517 .842 r
.7362 .52246 m .73767 .52559 L .73961 .52382 L F
.443 .527 .849 r
.73767 .52559 m .74088 .52697 L .73961 .52382 L F
.326 .518 .891 r
.73767 .52559 m .74138 .52854 L .74088 .52697 L F
.762 .698 .791 r
.52163 .76831 m .52349 .77156 L .51969 .77101 L F
.803 .99 .882 r
.52349 .77156 m .52096 .77423 L .51969 .77101 L F
.964 .736 .546 r
.51969 .77101 m .52096 .77423 L .51951 .77383 L F
.803 .99 .882 r
.52349 .77156 m .51951 .77383 L .52096 .77423 L F
.52349 .77156 m .52149 .77209 L .51951 .77383 L F
.16 .38 .83 r
.52163 .76831 m .52428 .77024 L .52349 .77156 L F
.762 .698 .791 r
.52163 .76831 m .52349 .77156 L .51969 .77101 L F
.657 .971 .883 r
.52349 .77156 m .52428 .77024 L .52149 .77209 L F
.694 .52 .648 r
.49591 .65083 m .49926 .65315 L .50072 .65038 L F
.437 .46 .786 r
.49951 .64805 m .50072 .65038 L .50216 .64951 L F
.529 .211 .373 r
.50072 .65038 m .49926 .65315 L .50195 .65215 L F
.455 .263 .529 r
.42798 .69109 m .42582 .69418 L .42766 .69523 L F
.646 .603 .792 r
.42602 .69668 m .42766 .69523 L .42582 .69418 L F
.02 0 0 r
.53064 .60021 m .52798 .60245 L .53011 .60172 L F
.435 .074 .251 r
.5323 .6012 m .53064 .60021 L .53011 .60172 L F
.5323 .6012 m .53291 .59989 L .53064 .60021 L F
.174 0 .363 r
.45966 .68886 m .46165 .68818 L .46085 .68682 L F
.553 .246 .401 r
.38051 .61578 m .3839 .61361 L .38166 .61403 L F
.919 .752 .657 r
.54994 .64466 m .55157 .64534 L .55223 .64294 L F
.961 .706 .504 r
.52096 .77423 m .52094 .77674 L .51951 .77383 L F
.52096 .77423 m .52094 .77674 L .51951 .77383 L F
.635 .595 .792 r
.29398 .61396 m .29261 .61681 L .29539 .61628 L F
.617 .653 .863 r
.29261 .61681 m .29541 .61732 L .29539 .61628 L F
.318 .787 .931 r
.3762 .59513 m .37278 .59513 L .37404 .59452 L F
.566 .509 .751 r
.32729 .6139 m .32795 .61585 L .32517 .61456 L F
.437 .065 .232 r
.58306 .57538 m .58149 .57381 L .58054 .57574 L F
.58306 .57538 m .58387 .5735 L .58149 .57381 L F
.669 .492 .636 r
.77917 .51997 m .77866 .52234 L .77542 .5223 L F
.492 .263 .495 r
.78124 .51938 m .77866 .52234 L .77917 .51997 L F
.828 .987 .873 r
.66573 .49881 m .66534 .49893 L .66831 .49609 L F
.323 0 0 r
.35965 .63949 m .35586 .64142 L .35752 .64003 L F
.611 .787 .966 r
.48098 .66233 m .47944 .66343 L .47701 .66142 L F
.565 .039 0 r
.53483 .67409 m .53318 .67526 L .53133 .67358 L F
.599 .904 .63 r
.53587 .6728 m .53318 .67526 L .53483 .67409 L F
.558 .387 .606 r
.78411 .51662 m .78124 .51938 L .78078 .5156 L F
.595 .061 0 r
.50721 .71109 m .50531 .71197 L .50386 .71065 L F
.138 0 0 r
.51047 .71213 m .50846 .71282 L .50965 .71115 L F
.462 .303 .58 r
.51032 .71191 m .50846 .71282 L .51047 .71213 L F
.693 .274 .247 r
.50965 .71115 m .50725 .71161 L .50721 .71109 L F
.50965 .71115 m .50846 .71282 L .50531 .71197 L F
.462 .303 .58 r
.50906 .70998 m .50869 .71175 L .51032 .71191 L F
.50869 .71175 m .50846 .71282 L .51032 .71191 L F
.693 .274 .247 r
.50725 .71161 m .50531 .71197 L .5063 .71151 L F
.50725 .71161 m .5063 .71151 L .50721 .71109 L F
.625 .551 .751 r
.4215 .59997 m .42141 .60545 L .421 .60304 L F
.833 .982 .696 r
.72698 .47449 m .72835 .47153 L .7295 .47252 L F
.72698 .47449 m .72573 .47519 L .72835 .47153 L F
0 .332 .815 r
.31126 .6341 m .31202 .63367 L .31011 .63324 L F
.31126 .6341 m .31461 .63603 L .31202 .63367 L F
.452 .01 .105 r
.27964 .81654 m .27925 .81756 L .27638 .81746 L F
.023 .166 .675 r
.2798 .81456 m .27964 .81654 L .27919 .81382 L F
.2798 .81456 m .28072 .8162 L .27964 .81654 L F
0 0 0 r
.28072 .8162 m .27925 .81756 L .27964 .81654 L F
.617 .426 .601 r
.78804 .49645 m .78811 .49886 L .78564 .4994 L F
.605 .531 .744 r
.79072 .49577 m .78804 .49645 L .78768 .49479 L F
.627 .473 .654 r
.79072 .49577 m .78811 .49886 L .78804 .49645 L F
.87 .433 .15 r
.54492 .66872 m .54165 .67022 L .54445 .66836 L F
.747 .404 .402 r
.46496 .71096 m .46113 .71123 L .46273 .71068 L F
.749 .669 .772 r
.55553 .61783 m .5587 .61972 L .55746 .61641 L F
.091 .574 .904 r
.55942 .61928 m .56096 .62008 L .5587 .61972 L F
.611 .519 .725 r
.78811 .49886 m .78675 .50342 L .78564 .4994 L F
.78811 .49886 m .78935 .50266 L .78675 .50342 L F
.522 .502 .775 r
.54401 .66963 m .54625 .66987 L .54609 .6692 L F
.87 .433 .15 r
.54492 .66872 m .54401 .66963 L .54206 .67003 L F
.522 .502 .775 r
.54401 .66963 m .54609 .6692 L .54534 .66608 L F
.87 .433 .15 r
.54206 .67003 m .54401 .66963 L .54165 .67022 L F
.113 .244 .722 r
.53587 .6728 m .53708 .67042 L .53588 .67138 L F
.525 .863 .595 r
.53793 .66947 m .53708 .67042 L .53945 .6708 L F
.53793 .66947 m .53588 .67138 L .53708 .67042 L F
.536 .215 .37 r
.45306 .66113 m .45125 .65964 L .45087 .66144 L F
.45306 .66113 m .45367 .65942 L .45125 .65964 L F
.307 .715 .977 r
.37177 .58497 m .37385 .58496 L .37537 .58585 L F
.325 .731 .98 r
.37385 .58496 m .37752 .58577 L .37537 .58585 L F
.839 .543 .489 r
.45284 .69947 m .45427 .70074 L .45691 .69907 L F
.738 .519 .596 r
.45427 .70074 m .45652 .70271 L .45691 .69907 L F
.293 .506 .891 r
.45909 .69974 m .45691 .69907 L .45866 .6972 L F
0 0 0 r
.45691 .69907 m .4581 .69813 L .45866 .6972 L F
.226 .518 .914 r
.45691 .69907 m .45909 .69974 L .4581 .69813 L F
.423 .536 .866 r
.56096 .62008 m .56354 .62113 L .56194 .62313 L F
0 0 .458 r
.56354 .62113 m .56307 .62452 L .56194 .62313 L F
.502 .239 .448 r
.42141 .60545 m .42116 .60738 L .41881 .60787 L F
.625 .551 .751 r
.4215 .59997 m .42381 .60526 L .42141 .60545 L F
.576 .303 .465 r
.42141 .60545 m .42353 .60737 L .42116 .60738 L F
.577 .303 .465 r
.42381 .60526 m .42353 .60737 L .42141 .60545 L F
.446 .563 .879 r
.32967 .61577 m .32886 .61782 L .32795 .61585 L F
.32967 .61577 m .33144 .61858 L .32886 .61782 L F
.544 .073 .088 r
.47734 .67125 m .48142 .67117 L .47959 .66822 L F
.946 .59 .291 r
.47959 .66822 m .48142 .67117 L .48005 .67013 L F
0 0 .479 r
.48142 .67117 m .48204 .6709 L .48005 .67013 L F
.48142 .67117 m .48211 .67267 L .48204 .6709 L F
.391 .13 .394 r
.56544 .58263 m .56756 .58185 L .56791 .5799 L F
.455 .189 .42 r
.56986 .5813 m .56791 .5799 L .56756 .58185 L F
.56986 .5813 m .5702 .57932 L .56791 .5799 L F
.353 .034 .277 r
.46348 .65279 m .46627 .65051 L .46424 .65122 L F
.554 .65 .898 r
.788 .48783 m .78693 .49058 L .78551 .48801 L F
.788 .48783 m .78927 .4901 L .78693 .49058 L F
.442 .286 .573 r
.44892 .68133 m .44677 .68208 L .44776 .68043 L F
.131 .066 .509 r
.44822 .68503 m .44677 .68208 L .44892 .68133 L F
.44822 .68503 m .44683 .68721 L .44677 .68208 L F
.81 .588 .602 r
.60402 .56519 m .60398 .56773 L .60733 .56828 L F
.806 .615 .644 r
.60398 .56773 m .60725 .57079 L .60733 .56828 L F
.49 .186 .378 r
.5702 .57932 m .57271 .57873 L .57317 .57648 L F
.63 .313 .416 r
.57317 .57648 m .57553 .57852 L .57557 .57611 L F
.57317 .57648 m .57271 .57873 L .57553 .57852 L F
0 0 .059 r
.59599 .63421 m .59634 .63066 L .59618 .63116 L F
.11 0 .147 r
.48187 .65077 m .4793 .65369 L .47933 .65123 L F
.25 .097 .469 r
.42798 .69109 m .42977 .69267 L .43009 .69064 L F
.42798 .69109 m .42766 .69523 L .42977 .69267 L F
.722 .297 .239 r
.5436 .70258 m .54062 .70228 L .54021 .70398 L F
.54062 .70228 m .53956 .70218 L .53978 .70281 L F
.54062 .70228 m .53978 .70281 L .54021 .70398 L F
.504 .355 .612 r
.54579 .70194 m .54338 .6998 L .54568 .69937 L F
.54579 .70194 m .5436 .70258 L .54338 .6998 L F
.722 .297 .239 r
.5436 .70258 m .54231 .70412 L .53956 .70218 L F
.066 0 0 r
.5445 .69984 m .54114 .70238 L .5449 .69985 L F
.54338 .6998 m .54195 .70144 L .5445 .69984 L F
.54195 .70144 m .54114 .70238 L .5445 .69984 L F
.49 .085 .199 r
.53956 .70218 m .54114 .70238 L .54338 .6998 L F
.066 0 0 r
.54338 .6998 m .5449 .69985 L .54568 .69937 L F
.499 .616 .899 r
.74088 .52697 m .74138 .52854 L .74301 .52657 L F
.557 .705 .939 r
.74301 .52657 m .74138 .52854 L .74363 .52819 L F
.781 .615 .674 r
.77542 .5223 m .7732 .52479 L .77309 .52245 L F
.77542 .5223 m .77643 .52528 L .7732 .52479 L F
.526 .361 .601 r
.77866 .52234 m .77643 .52528 L .77542 .5223 L F
.088 .641 .81 r
.33529 .58278 m .33767 .58279 L .33898 .58297 L F
.351 .78 .971 r
.33767 .58279 m .34079 .583 L .33898 .58297 L F
.502 .511 .799 r
.41124 .59334 m .41058 .5973 L .40932 .59368 L F
.41124 .59334 m .41288 .59762 L .41058 .5973 L F
.156 .629 .927 r
.41288 .59762 m .41326 .59773 L .41058 .5973 L F
.579 .497 .726 r
.56033 .61314 m .55717 .61079 L .56051 .61299 L F
.56033 .61314 m .55851 .61619 L .55717 .61079 L F
.059 0 0 r
.75563 .52565 m .75704 .52585 L .75465 .52648 L F
.75563 .52565 m .75809 .5254 L .75704 .52585 L F
.405 .568 .902 r
.74745 .50642 m .74591 .508 L .74437 .50517 L F
0 .132 .629 r
.74723 .50884 m .74835 .51004 L .74591 .508 L F
.978 .689 .394 r
.74603 .50766 m .74722 .51082 L .74723 .50884 L F
.74722 .51082 m .74753 .51162 L .74723 .50884 L F
0 .132 .629 r
.74723 .50884 m .74591 .508 L .74723 .50664 L F
.74723 .50884 m .74723 .50664 L .74745 .50642 L F
.588 .86 .524 r
.56033 .61314 m .55746 .61641 L .55851 .61619 L F
.642 .184 .149 r
.68009 .48665 m .68352 .487 L .68122 .48543 L F
.575 .283 .435 r
.68122 .48543 m .68352 .487 L .68393 .48498 L F
.854 .579 .52 r
.77643 .52528 m .77426 .52725 L .7732 .52479 L F
.77643 .52528 m .77701 .52765 L .77426 .52725 L F
.526 .361 .601 r
.77866 .52234 m .77887 .52496 L .77643 .52528 L F
.531 .38 .622 r
.77887 .52496 m .77701 .52765 L .77643 .52528 L F
0 .301 .721 r
.32175 .64082 m .3229 .64125 L .32041 .63972 L F
.683 .685 .846 r
.7982 .5135 m .79421 .51134 L .79648 .51037 L F
.381 .425 .782 r
.79887 .50968 m .7982 .5135 L .79648 .51037 L F
.79887 .50968 m .79974 .51311 L .7982 .5135 L F
.631 .069 0 r
.53301 .6106 m .53151 .61015 L .52914 .60822 L F
.844 .416 .215 r
.53425 .61286 m .53151 .61015 L .53301 .6106 L F
.053 0 0 r
.34572 .62796 m .34762 .6277 L .3492 .62719 L F
.323 0 0 r
.3492 .62719 m .34762 .6277 L .35115 .62729 L F
0 .284 .644 r
.34682 .62605 m .34977 .62742 L .34762 .6277 L F
0 0 0 r
.34762 .6277 m .34985 .62745 L .35115 .62729 L F
0 .284 .644 r
.34977 .62742 m .34985 .62745 L .34762 .6277 L F
.053 0 0 r
.3454 .62803 m .34762 .6277 L .34572 .62796 L F
.668 .967 .778 r
.46926 .66043 m .4676 .66129 L .46679 .66257 L F
.331 .598 .944 r
.4676 .66129 m .47139 .66412 L .46679 .66257 L F
.565 .44 .669 r
.59341 .64315 m .59646 .64354 L .59545 .63936 L F
.53 .545 .815 r
.59663 .64507 m .59341 .64315 L .59305 .64478 L F
.59583 .6446 m .59646 .64354 L .59341 .64315 L F
.103 0 .43 r
.59646 .64354 m .59788 .6389 L .59545 .63936 L F
.59646 .64354 m .59783 .64131 L .59788 .6389 L F
.774 .956 .637 r
.59578 .64406 m .59762 .6416 L .59646 .64354 L F
.59762 .6416 m .59783 .64131 L .59646 .64354 L F
.53 .545 .815 r
.59663 .64507 m .59646 .64354 L .59583 .6446 L F
.622 .624 .832 r
.46492 .66872 m .46537 .6707 L .46248 .67091 L F
.453 .259 .526 r
.46537 .6707 m .46288 .67389 L .46248 .67091 L F
.929 .676 .534 r
.60049 .60824 m .59887 .61016 L .59916 .60742 L F
.60049 .60824 m .60047 .61082 L .59887 .61016 L F
.97 .928 .623 r
.60104 .60412 m .60049 .60824 L .59916 .60742 L F
0 0 0 r
.76967 .50781 m .76715 .51099 L .76953 .51075 L F
.759 .639 .728 r
.76953 .51075 m .77197 .50713 L .76967 .50781 L F
.686 .196 .079 r
.50584 .70757 m .50906 .70998 L .51136 .70923 L F
.681 .189 .073 r
.51136 .70923 m .5116 .7103 L .51165 .70797 L F
.51136 .70923 m .50906 .70998 L .5116 .7103 L F
.605 .794 .972 r
.74932 .48634 m .75032 .48768 L .75288 .48691 L F
.505 .397 .665 r
.28981 .60538 m .29152 .6011 L .28935 .60285 L F
.8 .569 .589 r
.77309 .52245 m .76983 .52399 L .76955 .52274 L F
.77309 .52245 m .7732 .52479 L .76983 .52399 L F
.658 .859 .976 r
.67332 .50511 m .67671 .50515 L .67562 .50412 L F
.396 .716 .987 r
.67671 .50515 m .67792 .50403 L .67562 .50412 L F
.67671 .50515 m .67892 .50513 L .67792 .50403 L F
.249 0 .318 r
.56328 .60525 m .56404 .60698 L .56179 .6075 L F
.424 .198 .465 r
.56785 .60105 m .56748 .60352 L .5655 .60394 L F
.468 .783 .998 r
.5655 .60394 m .56748 .60352 L .56657 .60336 L F
.13 0 .384 r
.5657 .60169 m .5655 .60394 L .56339 .60508 L F
.424 .198 .465 r
.56785 .60105 m .5655 .60394 L .5657 .60169 L F
.468 .783 .998 r
.5655 .60394 m .56657 .60336 L .56424 .60296 L F
.13 0 .384 r
.56339 .60508 m .5655 .60394 L .56328 .60525 L F
0 0 .379 r
.56446 .6063 m .56328 .60525 L .5655 .60394 L F
.56446 .6063 m .56404 .60698 L .56328 .60525 L F
.385 .018 .214 r
.54907 .59349 m .55138 .59301 L .55232 .59075 L F
.035 0 .055 r
.55232 .59075 m .55319 .5918 L .5544 .59004 L F
.55232 .59075 m .55138 .59301 L .55319 .5918 L F
.449 .722 .983 r
.77482 .48408 m .77364 .48543 L .77275 .48412 L F
.77482 .48408 m .77574 .48532 L .77364 .48543 L F
.457 .448 .76 r
.28981 .60538 m .29048 .60864 L .29244 .60728 L F
.303 .268 .652 r
.29133 .61097 m .29244 .60728 L .29048 .60864 L F
.605 .531 .744 r
.79072 .49577 m .78768 .49479 L .79041 .49404 L F
.482 .318 .582 r
.48907 .6552 m .4911 .65612 L .49112 .65354 L F
.78 .892 .924 r
.46075 .66755 m .46497 .6667 L .46342 .66808 L F
0 .47 .764 r
.46349 .6681 m .46075 .66755 L .46317 .66796 L F
.46492 .66872 m .46075 .66755 L .46349 .6681 L F
.78 .892 .924 r
.46075 .66755 m .46342 .66808 L .46324 .66824 L F
0 0 .457 r
.46497 .6667 m .46514 .66699 L .46574 .66759 L F
.46514 .66699 m .467 .67008 L .46574 .66759 L F
.567 .373 .577 r
.46823 .66662 m .46589 .66774 L .46574 .66759 L F
.44 .601 .913 r
.46574 .66759 m .467 .67008 L .46492 .66872 L F
.567 .373 .577 r
.46589 .66774 m .46539 .66798 L .46574 .66759 L F
0 0 .457 r
.46497 .6667 m .46574 .66759 L .46324 .66824 L F
.193 0 .251 r
.53956 .70218 m .53837 .70492 L .54021 .70398 L F
.53956 .70218 m .53746 .70466 L .53837 .70492 L F
.462 .658 .946 r
.74322 .48217 m .74475 .48055 L .74243 .48063 L F
.461 .657 .945 r
.74322 .48217 m .74525 .48218 L .74475 .48055 L F
.136 .189 .654 r
.21292 .5582 m .21385 .56183 L .21268 .5623 L F
.063 0 .452 r
.21385 .56183 m .2135 .56399 L .21268 .5623 L F
.372 0 0 r
.49556 .61839 m .49758 .61888 L .49936 .6188 L F
.283 0 0 r
.49758 .61888 m .50095 .62007 L .49936 .6188 L F
.391 0 .158 r
.30605 .5901 m .3096 .58774 L .30732 .58802 L F
.259 0 0 r
.50041 .63891 m .50264 .63919 L .49904 .63911 L F
.89 .876 .815 r
.71668 .48625 m .72015 .48423 L .71889 .48287 L F
.71668 .48625 m .71749 .48772 L .72015 .48423 L F
.69 .22 .13 r
.49419 .63996 m .49328 .64135 L .49064 .63929 L F
0 0 0 r
.49565 .6385 m .49328 .64135 L .49419 .63996 L F
.532 .268 .46 r
.39219 .60823 m .38947 .61061 L .3917 .61008 L F
.29 .047 .362 r
.39219 .60823 m .3938 .60915 L .39422 .60754 L F
.39219 .60823 m .3917 .61008 L .3938 .60915 L F
.596 .453 .657 r
.3945 .60538 m .39686 .60506 L .39663 .60237 L F
.578 .334 .511 r
.39422 .60754 m .39686 .60506 L .3945 .60538 L F
.9 .878 .804 r
.55219 .66311 m .55049 .66525 L .55194 .66564 L F
.951 .709 .535 r
.55049 .66525 m .55208 .66758 L .55194 .66564 L F
.773 .778 .857 r
.51341 .7564 m .512 .75786 L .51007 .7564 L F
.51007 .7564 m .512 .75786 L .51341 .7564 L F
.081 .578 .895 r
.76424 .48996 m .75823 .48795 L .75913 .48884 L F
.394 .579 .914 r
.57642 .67542 m .57703 .67693 L .57836 .67548 L F
.232 .325 .754 r
.57703 .67693 m .57938 .6788 L .57836 .67548 L F
.415 .284 .593 r
.56834 .62811 m .56894 .6306 L .56706 .63109 L F
.508 .91 .899 r
.7238 .48107 m .72601 .47743 L .72421 .48037 L F
0 .155 .672 r
.57122 .63601 m .57294 .6383 L .57211 .63951 L F
.145 .368 .823 r
.57294 .6383 m .57456 .64134 L .57211 .63951 L F
.784 .779 .848 r
.7192 .49627 m .72126 .49808 L .72208 .49676 L F
0 0 0 r
.61043 .65352 m .60969 .65546 L .60846 .65682 L F
.2 .22 .657 r
.60969 .65546 m .60896 .65934 L .60846 .65682 L F
.612 .737 .934 r
.40554 .59119 m .40364 .59188 L .40222 .59034 L F
.489 0 0 r
.53203 .6358 m .53408 .63672 L .53546 .63687 L F
0 .457 .846 r
.53801 .63724 m .53847 .63798 L .53546 .63687 L F
.53801 .63724 m .53546 .63687 L .53408 .63672 L F
.627 .362 .498 r
.44282 .6671 m .44566 .66507 L .44339 .66548 L F
.441 .313 .611 r
.50786 .674 m .51018 .67379 L .50998 .67204 L F
.50786 .674 m .51018 .67379 L .50998 .67204 L F
.472 .613 .909 r
.34234 .62232 m .34218 .6248 L .34073 .62272 L F
.34234 .62232 m .34419 .62461 L .34218 .6248 L F
.853 .793 .792 r
.79668 .52456 m .79895 .52413 L .7996 .52144 L F
.753 .876 .935 r
.79895 .52413 m .80148 .5211 L .7996 .52144 L F
.79895 .52413 m .80253 .52223 L .80148 .5211 L F
.551 0 0 r
.4594 .71035 m .46113 .71123 L .45779 .71039 L F
.822 .836 .367 r
.60221 .6187 m .60122 .62268 L .60107 .62093 L F
.60221 .6187 m .60219 .6195 L .60122 .62268 L F
.936 .895 .493 r
.60015 .62405 m .60122 .62268 L .6006 .62478 L F
.60015 .62405 m .60107 .62093 L .60122 .62268 L F
.492 .537 .831 r
.70444 .48496 m .70565 .48825 L .70701 .48623 L F
.528 .586 .856 r
.70565 .48825 m .70821 .48799 L .70701 .48623 L F
.768 .466 0 r
.52809 .60484 m .52914 .60822 L .52865 .60696 L F
.48 0 0 r
.52914 .60822 m .53022 .6092 L .52865 .60696 L F
.52914 .60822 m .53151 .61015 L .53022 .6092 L F
0 0 .306 r
.61743 .61284 m .617 .61591 L .61662 .61395 L F
0 .258 .768 r
.57157 .66879 m .57334 .67055 L .57109 .66744 L F
.114 .572 .917 r
.4437 .70896 m .44388 .70825 L .44213 .70797 L F
.4437 .70896 m .44664 .70974 L .44388 .70825 L F
.272 .546 .924 r
.29168 .63973 m .29374 .63992 L .2924 .63837 L F
.2924 .63837 m .29374 .63992 L .29168 .63973 L F
.504 .21 .401 r
.56783 .59405 m .56757 .59623 L .56514 .59671 L F
.554 .253 .412 r
.56783 .59405 m .57006 .59567 L .56757 .59623 L F
.737 .741 .854 r
.50099 .66389 m .49654 .66444 L .50179 .66216 L F
.436 .441 .766 r
.47158 .67032 m .47259 .6677 L .47021 .668 L F
.772 .647 .724 r
.69301 .48483 m .69639 .4854 L .69516 .48196 L F
.716 .619 .747 r
.69516 .48196 m .69639 .4854 L .69881 .48454 L F
.112 0 0 r
.36313 .62558 m .36361 .62636 L .36533 .62505 L F
.286 0 0 r
.36361 .62636 m .3675 .62466 L .36533 .62505 L F
.36361 .62636 m .36583 .62617 L .3675 .62466 L F
.224 .726 .905 r
.36227 .62594 m .36514 .62612 L .36361 .62636 L F
.36514 .62612 m .36583 .62617 L .36361 .62636 L F
.112 0 0 r
.36313 .62558 m .36176 .62665 L .36361 .62636 L F
.36176 .62665 m .36143 .62691 L .36361 .62636 L F
0 0 0 r
.52809 .60484 m .53011 .60172 L .52798 .60245 L F
.462 .406 .709 r
.76617 .49062 m .76641 .49399 L .76858 .49217 L F
.531 .524 .793 r
.76641 .49399 m .76942 .4956 L .76858 .49217 L F
.596 .501 .717 r
.767 .49628 m .76942 .4956 L .76641 .49399 L F
.387 .458 .812 r
.2112 .55285 m .21105 .55626 L .20989 .55299 L F
.2112 .55285 m .21251 .55604 L .21105 .55626 L F
.366 .294 .642 r
.21251 .55604 m .21292 .5582 L .21105 .55626 L F
.887 .937 .843 r
.47615 .67053 m .47959 .66822 L .4764 .66767 L F
.47615 .67053 m .47734 .67125 L .47959 .66822 L F
0 .292 .775 r
.47959 .66822 m .47748 .66649 L .4784 .66495 L F
.47748 .66649 m .47608 .66535 L .4784 .66495 L F
.739 .919 .559 r
.47878 .66433 m .4784 .66495 L .47887 .66422 L F
.47698 .6665 m .4784 .66495 L .47878 .66433 L F
.787 .673 .738 r
.4764 .66767 m .47959 .66822 L .4784 .66495 L F
.701 .905 .547 r
.4764 .66767 m .4784 .66495 L .47698 .6665 L F
.612 .597 .811 r
.47698 .6665 m .47827 .66978 L .47615 .67053 L F
.627 .78 .329 r
.47689 .66911 m .47658 .66971 L .47615 .67053 L F
.333 .755 .976 r
.47321 .67055 m .47591 .67101 L .47615 .67053 L F
0 0 0 r
.47615 .67053 m .47537 .67203 L .47354 .67321 L F
.627 .78 .329 r
.47658 .66971 m .47537 .67203 L .47615 .67053 L F
.333 .755 .976 r
.47591 .67101 m .47734 .67125 L .47615 .67053 L F
.523 .737 .972 r
.44743 .71132 m .44882 .70975 L .44664 .70974 L F
.44743 .71132 m .44968 .71102 L .44882 .70975 L F
.492 .263 .495 r
.78124 .51938 m .78109 .52172 L .77866 .52234 L F
.558 .387 .606 r
.78411 .51662 m .78366 .51895 L .78124 .51938 L F
.581 .365 .552 r
.78366 .51895 m .78109 .52172 L .78124 .51938 L F
.813 .71 .751 r
.50179 .66216 m .50444 .65952 L .50183 .65968 L F
.775 .562 .612 r
.50334 .67973 m .49969 .68188 L .49995 .67954 L F
.50334 .67973 m .49989 .6819 L .49999 .6817 L F
.585 .421 .626 r
.50109 .68122 m .5032 .67796 L .50123 .67932 L F
.50118 .67942 m .50123 .67932 L .50118 .67936 L F
.50109 .68122 m .50123 .67932 L .50118 .67942 L F
.775 .562 .612 r
.50334 .67973 m .50324 .68224 L .49989 .6819 L F
.49999 .6817 m .49989 .6819 L .49969 .68188 L F
.664 .549 .715 r
.5053 .67715 m .5064 .68005 L .50334 .67973 L F
.546 .369 .593 r
.50559 .68179 m .50334 .67973 L .5064 .68005 L F
.50559 .68179 m .50324 .68224 L .50334 .67973 L F
.408 .207 .492 r
.66019 .50201 m .65876 .50368 L .65841 .5028 L F
.502 .545 .832 r
.29541 .61732 m .29711 .61573 L .29539 .61628 L F
.29541 .61732 m .29889 .61928 L .29711 .61573 L F
.678 .788 .933 r
.38503 .60232 m .38136 .60206 L .38358 .60117 L F
.38358 .60117 m .38136 .60206 L .38503 .60232 L F
.63 .777 .951 r
.38758 .60171 m .38503 .60232 L .38358 .60117 L F
.38758 .60171 m .38358 .60117 L .38598 .60057 L F
0 0 .211 r
.38503 .60232 m .38598 .60057 L .38358 .60117 L F
.165 0 0 r
.38758 .60171 m .38531 .60261 L .38503 .60232 L F
0 0 .211 r
.38503 .60232 m .38531 .60261 L .38598 .60057 L F
.145 0 0 r
.56236 .58501 m .56422 .58431 L .56544 .58263 L F
.43 .061 .234 r
.56422 .58431 m .56756 .58185 L .56544 .58263 L F
.481 .727 .979 r
.45407 .69508 m .4553 .69634 L .45325 .69665 L F
.7 .903 .543 r
.45407 .69508 m .45325 .69665 L .4553 .69634 L F
.627 .467 .646 r
.45862 .6797 m .45871 .68236 L .461 .67946 L F
.491 .386 .662 r
.42876 .68313 m .43064 .67894 L .42854 .67941 L F
.937 .627 .428 r
.60148 .61007 m .60116 .61283 L .60047 .61082 L F
.60148 .61007 m .60312 .61378 L .60116 .61283 L F
.716 .619 .747 r
.69516 .48196 m .69881 .48454 L .69854 .48265 L F
.654 .612 .794 r
.69854 .48265 m .69881 .48454 L .70098 .48199 L F
.663 .626 .802 r
.69881 .48454 m .70214 .48555 L .70098 .48199 L F
.998 .786 .474 r
.53133 .67358 m .53002 .6754 L .53023 .67304 L F
.536 .892 .977 r
.53133 .67358 m .53259 .67199 L .53253 .67081 L F
.53133 .67358 m .53023 .67304 L .53259 .67199 L F
.514 .057 .105 r
.53318 .67526 m .53002 .6754 L .53133 .67358 L F
.515 .321 .556 r
.32944 .60792 m .32921 .61039 L .32716 .61109 L F
.209 .067 .458 r
.33084 .6096 m .32944 .60792 L .33137 .6074 L F
.33084 .6096 m .32921 .61039 L .32944 .60792 L F
.79 .727 .793 r
.49423 .70817 m .49195 .71135 L .49046 .70894 L F
.556 .183 .289 r
.49195 .71135 m .49414 .71285 L .49173 .71272 L F
.68 .46 .58 r
.55267 .67103 m .5548 .67382 L .55236 .67343 L F
.56 .308 .492 r
.3839 .61361 m .38625 .61341 L .3868 .6108 L F
.44 .112 .312 r
.38625 .61341 m .38947 .61061 L .3868 .6108 L F
.676 .522 .669 r
.69405 .47856 m .69655 .4758 L .69395 .47633 L F
.419 .067 .259 r
.40289 .6194 m .40016 .62105 L .40061 .6198 L F
.504 .656 .928 r
.33669 .62154 m .33587 .62343 L .33504 .62162 L F
.33669 .62154 m .3383 .62376 L .33587 .62343 L F
.557 .485 .73 r
.77131 .50229 m .77305 .49837 L .77055 .49899 L F
.77131 .50229 m .77365 .50159 L .77305 .49837 L F
.494 .314 .566 r
.77141 .50484 m .77365 .50159 L .77131 .50229 L F
.895 .638 .543 r
.61381 .58469 m .61682 .58789 L .61688 .58542 L F
.167 .319 .774 r
.56916 .65969 m .57016 .66272 L .57055 .66169 L F
.14 .11 .56 r
.57016 .66272 m .57226 .66373 L .57055 .66169 L F
.57016 .66272 m .57061 .66507 L .57226 .66373 L F
.24 0 0 r
.3709 .63583 m .37236 .63626 L .37024 .6367 L F
.3709 .63583 m .37405 .63478 L .37236 .63626 L F
.44 .019 .142 r
.31172 .58718 m .31551 .58504 L .3123 .58563 L F
.31172 .58718 m .31405 .58699 L .31551 .58504 L F
.329 0 .015 r
.31405 .58699 m .31781 .58492 L .31551 .58504 L F
.646 .477 .641 r
.68393 .48498 m .68704 .48481 L .68606 .48172 L F
.638 .461 .628 r
.68606 .48172 m .68934 .48205 L .68903 .4795 L F
.637 .473 .643 r
.68606 .48172 m .68704 .48481 L .68934 .48205 L F
.611 .567 .78 r
.767 .49628 m .77055 .49899 L .76942 .4956 L F
.479 .108 .256 r
.38748 .62798 m .38628 .63021 L .38399 .63037 L F
.535 .209 .362 r
.38968 .62761 m .38628 .63021 L .38748 .62798 L F
0 0 .224 r
.61494 .61942 m .61457 .62144 L .61351 .62272 L F
0 0 .294 r
.61457 .62144 m .61317 .625 L .61351 .62272 L F
.577 .544 .781 r
.70214 .48555 m .70345 .4813 L .70098 .48199 L F
.70214 .48555 m .70444 .48496 L .70345 .4813 L F
.344 .761 .978 r
.37752 .58577 m .37979 .58548 L .38113 .5863 L F
.367 .788 .975 r
.37979 .58548 m .38336 .5859 L .38113 .5863 L F
.355 .826 .89 r
.52721 .6342 m .52629 .63491 L .52479 .63419 L F
.52721 .6342 m .52823 .63441 L .52629 .63491 L F
.886 .846 .799 r
.47338 .65855 m .47676 .65649 L .47621 .65666 L F
0 0 0 r
.4793 .65369 m .47812 .65552 L .47676 .65649 L F
.443 .859 .707 r
.47812 .65552 m .47621 .65666 L .47676 .65649 L F
.44 .096 .284 r
.45802 .65828 m .45636 .65699 L .45601 .65908 L F
.45802 .65828 m .45876 .65665 L .45636 .65699 L F
.167 0 .338 r
.57611 .64807 m .57593 .65044 L .57461 .6512 L F
0 0 .437 r
.57742 .64426 m .57611 .64807 L .57599 .64503 L F
.57742 .64426 m .57768 .64708 L .57611 .64807 L F
.586 .568 .8 r
.57768 .64708 m .57593 .65044 L .57611 .64807 L F
.294 0 .162 r
.33668 .60123 m .33543 .60389 L .33343 .60443 L F
.562 .239 .378 r
.33912 .60112 m .33543 .60389 L .33668 .60123 L F
.678 .198 .104 r
.41687 .59841 m .41852 .59942 L .42022 .59914 L F
.181 .432 .865 r
.41688 .59839 m .41852 .59942 L .41687 .59841 L F
.41763 .59737 m .41834 .59901 L .41688 .59839 L F
.41834 .59901 m .41852 .59942 L .41688 .59839 L F
.807 .962 .91 r
.41852 .59942 m .41803 .59907 L .41857 .59909 L F
.41852 .59942 m .41857 .59909 L .42022 .59914 L F
.358 .56 .912 r
.41881 .59743 m .41852 .59942 L .41763 .59737 L F
.41934 .59745 m .41852 .59942 L .41881 .59743 L F
.515 0 0 r
.42094 .59999 m .42022 .59914 L .41853 .59908 L F
.41987 .59965 m .41853 .59908 L .41803 .59907 L F
.42094 .59999 m .41853 .59908 L .41987 .59965 L F
.42094 .59999 m .4215 .59997 L .42022 .59914 L F
.416 .293 .604 r
.32928 .61243 m .32716 .61109 L .32921 .61039 L F
.32928 .61243 m .32729 .6139 L .32716 .61109 L F
.121 .668 .697 r
.35337 .62709 m .35552 .62671 L .3571 .62644 L F
.314 .802 .783 r
.3571 .62644 m .35814 .62585 L .35956 .62646 L F
.3571 .62644 m .35552 .62671 L .35814 .62585 L F
.068 .307 .791 r
.48467 .67636 m .48583 .67788 L .48468 .67636 L F
.804 .672 .719 r
.48464 .67414 m .48435 .67661 L .48211 .67267 L F
.068 .307 .791 r
.4839 .67638 m .48437 .67674 L .48467 .67636 L F
.48437 .67674 m .48583 .67788 L .48467 .67636 L F
0 0 0 r
.48396 .67725 m .48207 .67995 L .48306 .6787 L F
.48435 .67661 m .48368 .67759 L .48396 .67725 L F
.48368 .67759 m .48207 .67995 L .48396 .67725 L F
.487 0 0 r
.48589 .68265 m .48535 .68237 L .48207 .67995 L F
.151 .394 .842 r
.48207 .67995 m .48535 .68237 L .48306 .6787 L F
.501 .266 .49 r
.43272 .67092 m .43455 .67295 L .43513 .6709 L F
.43272 .67092 m .43232 .67345 L .43455 .67295 L F
.743 .874 .458 r
.73779 .48261 m .73705 .48359 L .73677 .48454 L F
.916 .971 .677 r
.73705 .48359 m .7365 .48574 L .73677 .48454 L F
.369 .055 .295 r
.46151 .65355 m .46293 .65538 L .46348 .65279 L F
.46151 .65355 m .46082 .65598 L .46293 .65538 L F
.303 .268 .652 r
.29133 .61097 m .29278 .61087 L .29244 .60728 L F
.306 .411 .806 r
.29133 .61097 m .29372 .61279 L .29278 .61087 L F
.2 0 0 r
.38438 .59589 m .38335 .59578 L .37932 .59492 L F
.218 .741 .826 r
.38673 .59551 m .38438 .59589 L .38786 .59603 L F
.38673 .59551 m .38335 .59578 L .38438 .59589 L F
.374 .004 .201 r
.37371 .61984 m .37517 .62083 L .37593 .61942 L F
.37371 .61984 m .37296 .62133 L .37517 .62083 L F
.516 .368 .618 r
.53277 .70787 m .53495 .70537 L .53253 .70585 L F
0 .06 .597 r
.51866 .76598 m .51911 .76982 L .51849 .76637 L F
.644 .615 .806 r
.52047 .76516 m .51969 .76782 L .51866 .76598 L F
.51969 .76782 m .51911 .76982 L .51879 .76707 L F
.51969 .76782 m .51879 .76707 L .51866 .76598 L F
.52047 .76516 m .52163 .76831 L .51911 .76982 L F
0 0 0 r
.52063 .76978 m .52163 .76831 L .51969 .77101 L F
.004 0 0 r
.51911 .76982 m .52163 .76831 L .52063 .76978 L F
0 0 .438 r
.51911 .76982 m .51969 .76991 L .51849 .76637 L F
.896 .536 .351 r
.51817 .76656 m .51969 .76991 L .51699 .76726 L F
.51849 .76637 m .5187 .767 L .51817 .76656 L F
.5187 .767 m .51969 .76991 L .51817 .76656 L F
0 0 .515 r
.51911 .76982 m .51969 .77101 L .51969 .76991 L F
.004 0 0 r
.51911 .76982 m .52063 .76978 L .51969 .76991 L F
.808 .324 .042 r
.56307 .62452 m .5646 .62689 L .56568 .62653 L F
.266 .543 .923 r
.56568 .62653 m .56852 .62729 L .56834 .62811 L F
.22 .714 .918 r
.5646 .62689 m .56852 .62729 L .56568 .62653 L F
.454 .627 .927 r
.40127 .58875 m .40023 .59043 L .39817 .58822 L F
.40127 .58875 m .40222 .59034 L .40023 .59043 L F
.451 0 .074 r
.556 .66183 m .55472 .66376 L .55219 .66311 L F
.803 .536 .534 r
.55754 .66187 m .55472 .66376 L .556 .66183 L F
.968 .646 .294 r
.6022 .60205 m .60061 .5986 L .60171 .59954 L F
0 0 .441 r
.57382 .67324 m .5743 .67297 L .57353 .67075 L F
0 .251 .754 r
.57382 .67324 m .57642 .67542 L .5743 .67297 L F
.312 .151 .496 r
.33343 .60443 m .33137 .6074 L .33142 .60535 L F
.557 .378 .595 r
.48997 .67392 m .48964 .67716 L .48734 .67723 L F
.53 .444 .702 r
.48957 .67832 m .48734 .67723 L .48964 .67716 L F
.48957 .67832 m .48798 .67955 L .48734 .67723 L F
.71 .747 .881 r
.71407 .48717 m .71749 .48772 L .71668 .48625 L F
.248 .755 .879 r
.37671 .59534 m .37817 .59491 L .3762 .59513 L F
.37671 .59534 m .37932 .59492 L .37817 .59491 L F
.895 .638 .543 r
.61381 .58469 m .61384 .58711 L .61682 .58789 L F
.917 .688 .577 r
.61403 .58979 m .61682 .58789 L .61384 .58711 L F
.61403 .58979 m .61518 .58992 L .61682 .58789 L F
.498 .564 .853 r
.29271 .63117 m .29371 .62914 L .29136 .62774 L F
.29271 .63117 m .29483 .63104 L .29371 .62914 L F
.497 .267 .496 r
.40836 .61378 m .40798 .61603 L .40574 .61637 L F
.386 .054 .275 r
.40798 .61603 m .40498 .61874 L .40574 .61637 L F
.404 0 0 r
.74896 .47733 m .75058 .47805 L .74781 .47653 L F
.031 .521 .879 r
.50696 .62397 m .50629 .62429 L .50429 .62243 L F
.50696 .62397 m .50823 .62484 L .50629 .62429 L F
.494 .872 .977 r
.76142 .51225 m .75879 .513 L .75789 .51253 L F
.429 0 0 r
.71164 .47666 m .7139 .47754 L .71479 .47623 L F
.525 .904 .738 r
.71479 .47623 m .7167 .47462 L .71753 .47445 L F
.571 .783 .979 r
.35643 .58479 m .35426 .58536 L .3528 .58411 L F
.536 .215 .371 r
.51217 .65201 m .51463 .65257 L .51466 .65099 L F
.597 .642 .865 r
.51326 .64847 m .51466 .65099 L .51699 .6505 L F
.641 .3 .378 r
.51463 .65257 m .51681 .65309 L .51466 .65099 L F
.527 .314 .534 r
.51466 .65099 m .51681 .65309 L .51699 .6505 L F
.287 0 0 r
.59429 .56646 m .59674 .56643 L .59411 .56604 L F
.458 .173 .392 r
.41073 .61345 m .40798 .61603 L .40836 .61378 L F
.801 .394 0 r
.48435 .67661 m .4839 .67638 L .48211 .67267 L F
.932 .884 .47 r
.48306 .6787 m .4839 .67638 L .48435 .67661 L F
.283 .745 .95 r
.5259 .64542 m .5254 .64485 L .52123 .64498 L F
.75 .487 .534 r
.5215 .64687 m .5259 .64542 L .52123 .64498 L F
.5215 .64687 m .52497 .64814 L .5259 .64542 L F
.824 1 .813 r
.52632 .6435 m .5259 .64542 L .5272 .64464 L F
.52632 .6435 m .5254 .64485 L .5259 .64542 L F
.316 .212 .575 r
.61107 .63574 m .60929 .63386 L .61056 .63344 L F
.61107 .63574 m .60956 .63635 L .60929 .63386 L F
.788 .467 .445 r
.70559 .47347 m .70819 .4763 L .70951 .47561 L F
.495 .198 .392 r
.70819 .4763 m .70832 .47785 L .70951 .47561 L F
0 0 0 r
.70832 .47785 m .71164 .47666 L .70951 .47561 L F
.593 .259 .373 r
.78711 .50787 m .78726 .50895 L .78459 .5079 L F
.78726 .50895 m .78732 .50939 L .78675 .50908 L F
.78726 .50895 m .78675 .50908 L .78459 .5079 L F
.805 .648 .688 r
.79093 .50734 m .78878 .50856 L .78711 .50787 L F
.458 .882 .914 r
.78771 .50883 m .78793 .50884 L .788 .50876 L F
.975 .839 .644 r
.78732 .50939 m .78793 .50884 L .78771 .50883 L F
.805 .648 .688 r
.78771 .50883 m .78732 .50939 L .78726 .50895 L F
.975 .839 .644 r
.78732 .50939 m .78771 .50883 L .78625 .50878 L F
.732 .639 .756 r
.78752 .51025 m .78465 .51048 L .78732 .50939 L F
.7882 .51309 m .78634 .51172 L .78752 .51025 L F
.78634 .51172 m .78465 .51048 L .78752 .51025 L F
.763 .72 .812 r
.79058 .51029 m .7882 .51309 L .78752 .51025 L F
.142 0 .362 r
.7873 .51053 m .78752 .51025 L .78793 .50884 L F
.78717 .51088 m .78793 .50884 L .78732 .50939 L F
.763 .72 .812 r
.78794 .50956 m .78752 .51025 L .78732 .50939 L F
.79058 .51029 m .78752 .51025 L .78794 .50956 L F
.142 0 .362 r
.78752 .51025 m .78809 .50954 L .78805 .50938 L F
.805 .648 .688 r
.79093 .50734 m .78794 .50956 L .78808 .50917 L F
.654 .551 .725 r
.78808 .50917 m .78826 .50871 L .78793 .50884 L F
.805 .648 .688 r
.78818 .5089 m .78808 .50917 L .78818 .50891 L F
.79093 .50734 m .78808 .50917 L .78818 .5089 L F
.78908 .50871 m .79058 .51029 L .78794 .50956 L F
.79093 .50734 m .79076 .50872 L .78908 .50871 L F
.79076 .50872 m .79058 .51029 L .78908 .50871 L F
.78878 .50856 m .78818 .50891 L .78815 .50872 L F
.73 .579 .685 r
.79282 .50748 m .79058 .51029 L .79093 .50734 L F
.654 .551 .725 r
.78904 .51125 m .79124 .50748 L .78826 .50871 L F
.78904 .51125 m .78826 .50871 L .78808 .50917 L F
.4 .826 .963 r
.78874 .50794 m .78805 .5087 L .79124 .50748 L F
.805 .648 .688 r
.788 .50876 m .78732 .50939 L .78771 .50883 L F
.78815 .50872 m .78812 .50875 L .788 .50876 L F
.4 .826 .963 r
.788 .50876 m .78793 .50884 L .78817 .50874 L F
.805 .648 .688 r
.78812 .50875 m .78732 .50939 L .788 .50876 L F
.78878 .50856 m .78726 .50895 L .78711 .50787 L F
.4 .826 .963 r
.78805 .5087 m .788 .50876 L .78826 .50871 L F
.142 0 .362 r
.78752 .51025 m .78794 .50956 L .78793 .50884 L F
.805 .648 .688 r
.78818 .50891 m .78732 .50939 L .78815 .50872 L F
.4 .826 .963 r
.788 .50876 m .78817 .50874 L .78826 .50871 L F
.78805 .5087 m .78826 .50871 L .79124 .50748 L F
.142 0 .362 r
.78794 .50956 m .78804 .5093 L .78793 .50884 L F
.805 .648 .688 r
.78818 .50891 m .78794 .50956 L .78732 .50939 L F
.142 0 .362 r
.78794 .50956 m .78805 .50938 L .78804 .5093 L F
.78717 .51088 m .78847 .51114 L .78809 .50954 L F
.78717 .51088 m .78809 .50954 L .7873 .51053 L F
.78847 .51114 m .78904 .51125 L .78826 .50957 L F
.78847 .51114 m .78826 .50957 L .78793 .50884 L F
.458 .882 .914 r
.78771 .50883 m .78771 .50883 L .788 .50876 L F
.78771 .50883 m .788 .50876 L .788 .50876 L F
.78625 .50878 m .78771 .50883 L .78874 .50794 L F
.78771 .50883 m .788 .50876 L .78874 .50794 L F
0 .239 .636 r
.78459 .5079 m .78732 .50939 L .78625 .50878 L F
.732 .639 .756 r
.7882 .51309 m .78603 .51398 L .78465 .51048 L F
.637 .893 .986 r
.78465 .51048 m .78732 .50939 L .78625 .50878 L F
.913 .511 .163 r
.78581 .50989 m .78659 .51304 L .78717 .51088 L F
.78532 .50953 m .78656 .51295 L .78581 .50989 L F
.78656 .51295 m .78659 .51304 L .78581 .50989 L F
0 .239 .636 r
.78459 .5079 m .78543 .50835 L .78465 .51048 L F
.78543 .50835 m .78625 .50878 L .78568 .50938 L F
.78543 .50835 m .78568 .50938 L .78465 .51048 L F
.863 .476 .308 r
.47358 .70748 m .47357 .70454 L .47219 .70551 L F
.47358 .70748 m .47534 .7077 L .47357 .70454 L F
.791 .471 .447 r
.47357 .70454 m .47534 .7077 L .47548 .70574 L F
.612 .443 .629 r
.68903 .4795 m .68934 .48205 L .69167 .4791 L F
.461 0 0 r
.48699 .70962 m .49046 .70894 L .48847 .70811 L F
.138 .173 .635 r
.53184 .65 m .53302 .6536 L .53212 .65402 L F
0 0 0 r
.53212 .65402 m .53144 .65508 L .53302 .6536 L F
.111 .384 .842 r
.73384 .51881 m .73451 .51765 L .7319 .51604 L F
.052 .302 .79 r
.73384 .51881 m .73631 .52083 L .73451 .51765 L F
.266 0 0 r
.37236 .63626 m .37405 .63478 L .37551 .63506 L F
.636 .923 .975 r
.50578 .77976 m .5035 .78002 L .50471 .78274 L F
.63 .3 .394 r
.47472 .71081 m .4731 .71337 L .4709 .71145 L F
.57 .181 .266 r
.47664 .71162 m .4731 .71337 L .47472 .71081 L F
.481 .188 .391 r
.40016 .62105 m .39698 .6245 L .39799 .62138 L F
.515 .259 .465 r
.51154 .65579 m .51463 .65257 L .51217 .65201 L F
.52 .229 .413 r
.41881 .60787 m .41813 .61034 L .41573 .61075 L F
.446 .16 .385 r
.42022 .60967 m .41881 .60787 L .42116 .60738 L F
.42022 .60967 m .41813 .61034 L .41881 .60787 L F
.11 0 .147 r
.48187 .65077 m .4811 .6532 L .4793 .65369 L F
.378 .172 .47 r
.48399 .648 m .48187 .65077 L .48159 .6485 L F
.48399 .648 m .48378 .65028 L .48187 .65077 L F
.171 0 .172 r
.48298 .65212 m .48187 .65077 L .48378 .65028 L F
.48298 .65212 m .4811 .6532 L .48187 .65077 L F
.419 0 .093 r
.32 .58454 m .32229 .58445 L .32379 .5826 L F
.324 0 .032 r
.32379 .5826 m .32559 .5829 L .32591 .58247 L F
.32379 .5826 m .32229 .58445 L .32559 .5829 L F
.68 .776 .923 r
.50264 .63919 m .5062 .63969 L .50535 .63812 L F
.151 .444 .877 r
.5062 .63969 m .50678 .63869 L .50535 .63812 L F
.441 .802 .996 r
.5062 .63969 m .50835 .6393 L .50678 .63869 L F
.453 .856 .968 r
.79174 .52077 m .79226 .52143 L .79608 .52064 L F
.509 .769 .99 r
.39281 .58796 m .39062 .58833 L .38919 .58714 L F
.755 .627 .718 r
.68704 .48481 m .6905 .48772 L .68944 .48447 L F
.68704 .48481 m .68693 .48751 L .6905 .48772 L F
.757 .593 .673 r
.68693 .48751 m .68857 .49056 L .6905 .48772 L F
.704 .627 .769 r
.68944 .48447 m .6905 .48772 L .69301 .48483 L F
.781 .821 .883 r
.73662 .48104 m .73779 .48261 L .7399 .48107 L F
.982 .692 .355 r
.73662 .48104 m .73705 .48359 L .73779 .48261 L F
.073 .454 .883 r
.53709 .62013 m .53915 .62015 L .53684 .61831 L F
.53709 .62013 m .53993 .62136 L .53915 .62015 L F
.559 .371 .583 r
.58646 .58233 m .58639 .58397 L .58398 .58441 L F
.496 .2 .393 r
.58398 .58441 m .5853 .58703 L .5831 .58742 L F
.58398 .58441 m .58639 .58397 L .5853 .58703 L F
.742 .453 .492 r
.59265 .58217 m .59063 .58465 L .5903 .58151 L F
.59265 .58217 m .59402 .5847 L .59063 .58465 L F
.828 .473 .384 r
.59608 .58493 m .59402 .5847 L .59265 .58217 L F
.319 0 0 r
.29575 .63881 m .29815 .63845 L .29984 .6367 L F
.276 0 0 r
.29984 .6367 m .29815 .63845 L .30037 .63785 L F
.66 .18 .102 r
.27793 .81569 m .2798 .81456 L .27919 .81382 L F
.536 .416 .663 r
.41928 .70523 m .42156 .7051 L .42156 .70197 L F
.49 .643 .924 r
.27638 .81746 m .27925 .81756 L .27793 .81569 L F
.42 .181 .443 r
.41523 .61258 m .41344 .61103 L .41573 .61075 L F
.41523 .61258 m .41311 .61321 L .41344 .61103 L F
.73 .869 .946 r
.66723 .5068 m .67124 .50627 L .67013 .50504 L F
.704 .851 .952 r
.67013 .50504 m .67124 .50627 L .67332 .50511 L F
.492 .316 .571 r
.78109 .52172 m .77887 .52496 L .77866 .52234 L F
.819 .545 0 r
.50266 .77663 m .5035 .78002 L .50294 .77704 L F
0 .281 .78 r
.50294 .77704 m .50564 .77905 L .50578 .77976 L F
.544 .364 .587 r
.5035 .78002 m .50564 .77905 L .50294 .77704 L F
.638 .627 .823 r
.65537 .49332 m .65654 .49749 L .65905 .49581 L F
0 0 .086 r
.6574 .49891 m .65905 .49581 L .65654 .49749 L F
.19 .581 .94 r
.55608 .65206 m .55815 .6533 L .55701 .65344 L F
.458 .209 .447 r
.55732 .58829 m .55969 .58767 L .55992 .58529 L F
.397 .159 .432 r
.55992 .58529 m .56176 .58678 L .56236 .58501 L F
.55992 .58529 m .55969 .58767 L .56176 .58678 L F
.761 .432 .427 r
.6022 .56512 m .60246 .56696 L .60402 .56519 L F
.917 .682 .568 r
.60246 .56696 m .60398 .56773 L .60402 .56519 L F
.683 .282 .282 r
.78913 .51975 m .78635 .52079 L .78597 .51894 L F
.78913 .51975 m .79027 .52089 L .78635 .52079 L F
.307 0 .074 r
.30086 .59242 m .30395 .59063 L .3018 .59111 L F
.849 .495 .383 r
.48583 .67788 m .48778 .67977 L .48666 .67982 L F
.48778 .67977 m .48743 .68028 L .48635 .67984 L F
.34 .51 .879 r
.487 .68062 m .48714 .68069 L .48583 .67788 L F
.577 .93 .944 r
.48716 .68065 m .48696 .68097 L .48798 .67955 L F
.48696 .68097 m .48589 .68265 L .48623 .68214 L F
.48696 .68097 m .48623 .68214 L .48798 .67955 L F
.664 .114 0 r
.48673 .67999 m .48748 .68076 L .48635 .67984 L F
0 .259 .769 r
.48635 .67984 m .48722 .68055 L .4864 .67872 L F
.577 .93 .944 r
.48714 .68069 m .48712 .68072 L .48716 .68065 L F
.55 0 0 r
.48893 .6809 m .48714 .68069 L .48798 .67955 L F
.849 .495 .383 r
.48685 .68008 m .48714 .68069 L .48893 .6809 L F
.664 .114 0 r
.48786 .6808 m .48748 .68076 L .48679 .68005 L F
.48685 .68008 m .48679 .68005 L .48673 .67999 L F
.48786 .6808 m .48679 .68005 L .48685 .68008 L F
.849 .495 .383 r
.48778 .67977 m .48893 .6809 L .48743 .68028 L F
.48583 .67788 m .48685 .68008 L .48893 .6809 L F
0 .259 .769 r
.48722 .68055 m .48748 .68076 L .4873 .68042 L F
.48722 .68055 m .4873 .68042 L .4864 .67872 L F
.664 .114 0 r
.48893 .6809 m .48786 .6808 L .48673 .67999 L F
.34 .51 .879 r
.48306 .6787 m .487 .68062 L .48673 .67999 L F
.48437 .67832 m .48673 .67999 L .48583 .67788 L F
.48306 .6787 m .48673 .67999 L .48437 .67832 L F
.849 .495 .383 r
.48583 .67788 m .48666 .67982 L .48635 .67984 L F
.577 .93 .944 r
.48712 .68072 m .48589 .68265 L .48716 .68065 L F
.48714 .68069 m .48535 .68237 L .48589 .68265 L F
.515 .031 .045 r
.73047 .51059 m .73442 .51196 L .73417 .50999 L F
.141 0 .115 r
.73417 .50999 m .73655 .50945 L .7372 .50774 L F
.994 .796 .534 r
.73582 .51169 m .73417 .50999 L .73442 .51196 L F
.73582 .51169 m .73655 .50945 L .73417 .50999 L F
.641 .321 .413 r
.52039 .65251 m .52285 .653 L .52357 .65068 L F
.715 .641 .773 r
.79058 .51029 m .79173 .51371 L .7882 .51309 L F
.693 .628 .78 r
.79421 .51134 m .79173 .51371 L .79058 .51029 L F
.637 .417 .568 r
.49112 .65354 m .49353 .65345 L .49367 .65116 L F
.611 .443 .629 r
.49353 .65345 m .49591 .65083 L .49367 .65116 L F
.568 .351 .547 r
.44674 .69096 m .44847 .69433 L .4459 .6917 L F
.136 .215 .682 r
.4478 .68962 m .44674 .69096 L .44675 .68757 L F
.077 .128 .614 r
.44921 .69163 m .44674 .69096 L .4478 .68962 L F
.806 .56 .567 r
.61082 .57359 m .61086 .57598 L .61432 .57638 L F
.807 .646 .683 r
.61086 .57598 m .61229 .57916 L .61432 .57638 L F
.497 .384 .654 r
.29578 .59592 m .29766 .59272 L .29632 .59238 L F
.403 .484 .829 r
.71501 .49362 m .71633 .49661 L .71775 .49475 L F
.525 .659 .921 r
.71633 .49661 m .7192 .49627 L .71775 .49475 L F
.341 .633 .961 r
.76617 .49062 m .76679 .48919 L .76633 .4892 L F
.76617 .49062 m .76739 .49031 L .76679 .48919 L F
.462 .406 .709 r
.76617 .49062 m .76858 .49217 L .76739 .49031 L F
.112 .664 .728 r
.36263 .59676 m .3611 .5969 L .3591 .59717 L F
.052 0 0 r
.36477 .59648 m .3611 .5969 L .36263 .59676 L F
.487 .303 .557 r
.49224 .67301 m .48964 .67716 L .48997 .67392 L F
.642 .327 .423 r
.5237 .6506 m .52285 .653 L .52039 .65251 L F
.819 .559 .546 r
.59949 .588 m .59658 .58991 L .59739 .5873 L F
.59949 .588 m .59968 .59053 L .59658 .58991 L F
.561 .459 .695 r
.52112 .65554 m .51923 .65921 L .51903 .65681 L F
.503 .456 .738 r
.21215 .56927 m .21103 .57338 L .21065 .57099 L F
.829 .475 .385 r
.59608 .58493 m .59459 .58671 L .59402 .5847 L F
.843 .495 .397 r
.59739 .5873 m .59459 .58671 L .59608 .58493 L F
.515 .473 .748 r
.39663 .60237 m .39798 .5983 L .39554 .59876 L F
.39663 .60237 m .39873 .60219 L .39798 .5983 L F
.609 .516 .724 r
.39686 .60506 m .39873 .60219 L .39663 .60237 L F
.518 .698 .951 r
.78463 .48647 m .78307 .48826 L .78226 .48667 L F
.78463 .48647 m .78551 .48801 L .78307 .48826 L F
.517 .858 .994 r
.74744 .52927 m .74894 .52795 L .74626 .52832 L F
.74744 .52927 m .75018 .52863 L .74894 .52795 L F
.399 .848 .914 r
.35288 .59809 m .35687 .59759 L .35518 .59748 L F
.25 .762 .834 r
.35687 .59759 m .35735 .59717 L .35518 .59748 L F
.35687 .59759 m .3591 .59717 L .35735 .59717 L F
.38 .774 .988 r
.43693 .70456 m .43527 .70376 L .43291 .70393 L F
.419 .756 .995 r
.43693 .70456 m .43797 .70333 L .43527 .70376 L F
.43693 .70456 m .4392 .70437 L .43797 .70333 L F
.764 .649 .735 r
.69982 .4738 m .69979 .47634 L .70198 .47334 L F
.654 .494 .655 r
.70198 .47334 m .69979 .47634 L .70291 .47578 L F
.606 .365 .525 r
.70291 .47578 m .70559 .47347 L .70198 .47334 L F
.728 .53 .623 r
.50906 .66295 m .50681 .66508 L .50581 .66452 L F
.296 0 .132 r
.51105 .6622 m .50681 .66508 L .50906 .66295 L F
.957 .769 .607 r
.68798 .49542 m .68934 .49627 L .68835 .49301 L F
.961 .925 .718 r
.68769 .49725 m .68934 .49627 L .68798 .49542 L F
.68769 .49725 m .68778 .49977 L .68934 .49627 L F
.041 .092 .589 r
.56873 .65672 m .56983 .65571 L .56852 .65359 L F
.022 .013 .505 r
.56873 .65672 m .57024 .65816 L .56983 .65571 L F
.56873 .65672 m .56916 .65969 L .57024 .65816 L F
.606 .365 .525 r
.70291 .47578 m .70584 .47591 L .70559 .47347 L F
.758 .477 .507 r
.70584 .47591 m .70819 .4763 L .70559 .47347 L F
.173 0 0 r
.53416 .60012 m .53636 .59962 L .53291 .59989 L F
.608 .95 .802 r
.53821 .59825 m .53636 .59962 L .53738 .59838 L F
.602 .952 .876 r
.53738 .59838 m .53636 .59962 L .53416 .60012 L F
.489 .137 .295 r
.51245 .6474 m .51016 .65027 L .50757 .65055 L F
.392 .24 .553 r
.51331 .64523 m .51326 .64847 L .51245 .6474 L F
.386 0 .112 r
.51326 .64847 m .51016 .65027 L .51245 .6474 L F
.846 .729 .734 r
.59968 .59053 m .60067 .59379 L .59868 .59314 L F
.896 .728 .665 r
.60067 .59379 m .59784 .59499 L .59868 .59314 L F
.60067 .59379 m .60008 .59655 L .59784 .59499 L F
.736 .651 .765 r
.66378 .50202 m .6609 .50485 L .66019 .50201 L F
0 0 .269 r
.6609 .50485 m .66078 .5039 L .66019 .50201 L F
.844 .748 .231 r
.6609 .50485 m .66045 .50623 L .66078 .5039 L F
.276 .414 .821 r
.72364 .50507 m .72482 .50789 L .72662 .50654 L F
.052 .13 .627 r
.72482 .50789 m .72647 .50827 L .72662 .50654 L F
.72482 .50789 m .7256 .50984 L .72647 .50827 L F
.322 .715 .981 r
.6825 .50608 m .68114 .50512 L .67892 .50513 L F
.746 .895 .945 r
.68385 .50349 m .6825 .50608 L .68482 .50447 L F
.68385 .50349 m .68114 .50512 L .6825 .50608 L F
.191 0 0 r
.54907 .59349 m .54697 .59413 L .54606 .59523 L F
.995 .8 .533 r
.61749 .60219 m .6177 .60011 L .61679 .59903 L F
.948 .697 .524 r
.60312 .61378 m .60121 .61547 L .60116 .61283 L F
.60312 .61378 m .60305 .61654 L .60121 .61547 L F
.685 .594 .749 r
.50247 .78577 m .50589 .78783 L .50578 .7882 L F
.71 .564 .687 r
.55691 .66557 m .55699 .66806 L .55897 .66516 L F
.615 .642 .854 r
.29897 .63275 m .30112 .63684 L .30228 .6361 L F
.504 0 0 r
.30425 .63507 m .30422 .63485 L .30299 .63527 L F
.3071 .63459 m .30422 .63485 L .30425 .63507 L F
.3071 .63459 m .30507 .63525 L .30422 .63485 L F
0 .323 .745 r
.30422 .63485 m .30507 .63525 L .30419 .63464 L F
.30422 .63485 m .30419 .63464 L .30304 .63384 L F
0 0 0 r
.30422 .63485 m .30198 .63622 L .30299 .63527 L F
.615 .642 .854 r
.30131 .63368 m .30228 .6361 L .30422 .63485 L F
.29897 .63275 m .30228 .6361 L .30131 .63368 L F
0 0 .548 r
.30292 .63767 m .30359 .63981 L .30198 .63622 L F
.3035 .63856 m .30355 .63922 L .30292 .63767 L F
.30355 .63922 m .30359 .63981 L .30292 .63767 L F
.695 .249 .188 r
.30359 .63981 m .30538 .64171 L .30169 .64107 L F
.627 .093 0 r
.30384 .6406 m .30359 .63981 L .3035 .63856 L F
.30384 .6406 m .30538 .64171 L .30359 .63981 L F
0 0 .079 r
.56404 .60698 m .56167 .61006 L .56179 .6075 L F
0 0 0 r
.49495 .65702 m .49403 .65859 L .49265 .65946 L F
.49263 .65946 m .49265 .65946 L .49257 .65952 L F
.49495 .65702 m .49265 .65946 L .49263 .65946 L F
.49403 .65859 m .49339 .65916 L .49257 .65952 L F
0 .108 .66 r
.49161 .65704 m .49297 .65953 L .49294 .65815 L F
.49297 .65953 m .49308 .65956 L .49294 .65815 L F
.699 .399 .465 r
.49257 .65952 m .48865 .66147 L .4889 .65955 L F
.49257 .65952 m .4921 .66163 L .48865 .66147 L F
.225 0 .31 r
.49446 .65896 m .4921 .66163 L .49257 .65952 L F
.654 .56 .737 r
.4889 .65955 m .49275 .65974 L .49241 .65899 L F
.48956 .65851 m .49241 .65899 L .4911 .65612 L F
.4889 .65955 m .49241 .65899 L .48956 .65851 L F
.225 0 .31 r
.49446 .65896 m .49363 .6592 L .49379 .65899 L F
.49363 .6592 m .49257 .65952 L .49339 .65916 L F
.49363 .6592 m .49339 .65916 L .49379 .65899 L F
.654 .56 .737 r
.49275 .65974 m .49297 .65953 L .4911 .65612 L F
.059 0 0 r
.4889 .65955 m .49005 .65975 L .4931 .65976 L F
0 .108 .66 r
.49297 .65953 m .4931 .65976 L .49308 .65956 L F
.654 .56 .737 r
.49275 .65974 m .4931 .65976 L .49297 .65953 L F
.456 .139 .338 r
.49005 .65975 m .49294 .65815 L .4931 .65976 L F
.801 .634 .676 r
.49232 .66017 m .49362 .65872 L .49294 .65815 L F
.49362 .65872 m .49466 .65755 L .49294 .65815 L F
0 .108 .66 r
.4911 .65612 m .49161 .65704 L .49294 .65815 L F
0 0 0 r
.49403 .65859 m .49379 .65899 L .49339 .65916 L F
.585 .236 .345 r
.49698 .65869 m .49495 .65702 L .49732 .65633 L F
.49698 .65869 m .49379 .65899 L .49495 .65702 L F
.492 .281 .522 r
.50444 .65952 m .50675 .65915 L .50677 .65683 L F
.097 .187 .669 r
.50444 .65952 m .50636 .66156 L .50675 .65915 L F
.432 .075 .258 r
.73281 .47849 m .73609 .47604 L .73258 .47637 L F
.73281 .47849 m .73517 .47812 L .73609 .47604 L F
.716 .412 .461 r
.73517 .47812 m .73869 .47635 L .73609 .47604 L F
.461 .162 .37 r
.4811 .6532 m .47812 .65552 L .4793 .65369 L F
.362 .282 .63 r
.56167 .61006 m .56033 .61314 L .56051 .61299 L F
.451 .765 .996 r
.5412 .62295 m .54191 .62167 L .53993 .62136 L F
.5412 .62295 m .54313 .62274 L .54191 .62167 L F
.823 .478 .403 r
.57863 .6577 m .58135 .65722 L .57816 .65617 L F
.57863 .6577 m .58058 .65903 L .58135 .65722 L F
.586 .213 .301 r
.58058 .65903 m .58363 .65869 L .58135 .65722 L F
.92 .556 .32 r
.55815 .6533 m .55877 .65524 L .55963 .65464 L F
.819 .68 .136 r
.55877 .65524 m .55879 .65863 L .55963 .65464 L F
.325 .153 .488 r
.21103 .57338 m .21081 .57578 L .2091 .57654 L F
.383 .234 .552 r
.21081 .57578 m .20897 .57897 L .2091 .57654 L F
.922 .581 .377 r
.54994 .64466 m .55222 .64763 L .55157 .64534 L F
.857 .662 .638 r
.32618 .64613 m .32574 .64825 L .32395 .6453 L F
.787 .488 .482 r
.68393 .48498 m .68693 .48751 L .68704 .48481 L F
.68393 .48498 m .68352 .487 L .68693 .48751 L F
.338 .181 .515 r
.60956 .63635 m .60951 .63875 L .60782 .63921 L F
.309 .225 .597 r
.60976 .64105 m .60782 .63921 L .60951 .63875 L F
.60976 .64105 m .60778 .64269 L .60782 .63921 L F
0 0 0 r
.36836 .59612 m .36722 .59625 L .36477 .59648 L F
.364 .832 .887 r
.37043 .59552 m .36933 .59545 L .36836 .59612 L F
.384 .846 .826 r
.36933 .59545 m .36722 .59625 L .36836 .59612 L F
.321 .601 .947 r
.38831 .59564 m .38942 .59704 L .39013 .59569 L F
.4 .697 .981 r
.38942 .59704 m .39091 .59672 L .39013 .59569 L F
.593 .534 .759 r
.77055 .49899 m .77247 .49633 L .76942 .4956 L F
.77055 .49899 m .77305 .49837 L .77247 .49633 L F
.399 0 .153 r
.46288 .67389 m .462 .67557 L .46001 .67565 L F
.453 .259 .526 r
.46537 .6707 m .46486 .67344 L .46288 .67389 L F
.708 .475 .569 r
.46486 .67344 m .462 .67557 L .46288 .67389 L F
.603 .16 .17 r
.47893 .70809 m .48136 .70959 L .48253 .70801 L F
.579 .201 .291 r
.48382 .71044 m .48253 .70801 L .48136 .70959 L F
.806 .615 .644 r
.60398 .56773 m .6038 .5703 L .60725 .57079 L F
.772 .598 .663 r
.6038 .5703 m .60739 .57328 L .60725 .57079 L F
.604 .258 .358 r
.51923 .65921 m .51573 .66125 L .51679 .65949 L F
.355 .688 .981 r
.76236 .4803 m .76111 .48128 L .75985 .48048 L F
.76236 .4803 m .7633 .4814 L .76111 .48128 L F
0 .068 .63 r
.49656 .70801 m .49793 .71113 L .50073 .70863 L F
.49656 .70801 m .49812 .71045 L .49793 .71113 L F
.759 .471 .497 r
.49292 .70973 m .4983 .71072 L .49656 .70801 L F
.4983 .71072 m .49872 .71079 L .49656 .70801 L F
0 0 .468 r
.49656 .70801 m .49872 .71079 L .49822 .7101 L F
0 .068 .63 r
.49656 .70801 m .49822 .7101 L .49812 .71045 L F
.689 .312 .328 r
.49793 .71113 m .5001 .71319 L .49708 .71282 L F
0 .211 .736 r
.49812 .71047 m .5001 .71319 L .49793 .71113 L F
.499 .71139 m .5001 .71319 L .49832 .71074 L F
.49851 .71088 m .49832 .71074 L .49812 .71047 L F
.499 .71139 m .49832 .71074 L .49851 .71088 L F
.819 .552 .534 r
.49966 .71175 m .5001 .71319 L .49882 .71109 L F
.526 .056 .082 r
.49943 .71151 m .49937 .71152 L .49966 .71175 L F
.49872 .71079 m .49851 .71088 L .49943 .71151 L F
.49872 .71079 m .49966 .71175 L .49822 .7101 L F
.819 .552 .534 r
.49966 .71175 m .49882 .71109 L .49822 .7101 L F
.526 .056 .082 r
.49937 .71152 m .49503 .71227 L .49966 .71175 L F
.49851 .71088 m .49503 .71227 L .49943 .71151 L F
.741 .383 .375 r
.49292 .70973 m .49503 .71227 L .49851 .71088 L F
.49837 .71073 m .49851 .71088 L .49872 .71079 L F
.49292 .70973 m .49851 .71088 L .49837 .71073 L F
0 .211 .736 r
.49822 .7101 m .499 .71139 L .49812 .71047 L F
0 0 .03 r
.49969 .68188 m .50118 .67936 L .49995 .67954 L F
.49969 .68188 m .50109 .68122 L .50118 .67936 L F
.79 .727 .793 r
.49423 .70817 m .49046 .70894 L .49292 .70973 L F
.759 .471 .497 r
.49292 .70973 m .49656 .70801 L .49423 .70817 L F
.55 0 0 r
.48893 .6809 m .48798 .67955 L .48957 .67832 L F
.467 .262 .517 r
.50677 .65683 m .50873 .65849 L .50918 .65653 L F
.50677 .65683 m .50675 .65915 L .50873 .65849 L F
.276 .711 .965 r
.35851 .58445 m .36241 .58527 L .36009 .58558 L F
0 0 0 r
.59108 .67439 m .59105 .67376 L .59316 .67276 L F
.59108 .67439 m .58956 .67516 L .59105 .67376 L F
0 .276 .734 r
.51207 .64196 m .50835 .6393 L .50966 .6422 L F
.001 0 0 r
.50906 .64417 m .51207 .64196 L .50966 .6422 L F
.366 .444 .809 r
.50666 .67548 m .5053 .67715 L .50429 .67587 L F
.50666 .67548 m .50806 .67902 L .5053 .67715 L F
.472 .442 .744 r
.50806 .67902 m .5064 .68005 L .5053 .67715 L F
.828 .522 0 r
.56848 .62956 m .56834 .62811 L .56852 .62729 L F
.56848 .62956 m .56872 .62968 L .56834 .62811 L F
.22 .714 .918 r
.5646 .62689 m .56795 .62686 L .56852 .62729 L F
.875 .878 .834 r
.56925 .62592 m .56848 .62956 L .56852 .62729 L F
.56925 .62592 m .56694 .62883 L .56848 .62956 L F
0 .065 .622 r
.56817 .6294 m .56848 .62956 L .56694 .62883 L F
.5697 .63012 m .56848 .62956 L .56817 .6294 L F
.828 .522 0 r
.56848 .62956 m .56894 .6306 L .56872 .62968 L F
.296 0 .132 r
.51051 .66257 m .50869 .66461 L .50681 .66508 L F
.7 .316 .317 r
.50739 .6664 m .50402 .66659 L .50581 .66452 L F
.755 .295 .156 r
.50681 .66508 m .50739 .6664 L .50581 .66452 L F
.401 .125 .375 r
.51 .66428 m .50739 .6664 L .50681 .66508 L F
.782 .425 .381 r
.50581 .66452 m .50402 .66659 L .50393 .66492 L F
.543 .394 .629 r
.50393 .66492 m .50772 .66508 L .50636 .66156 L F
.296 0 .132 r
.50874 .66456 m .51 .66428 L .50869 .66461 L F
.51105 .6622 m .51 .66428 L .50874 .66456 L F
.401 .025 .205 r
.51325 .66178 m .51229 .66394 L .51 .66428 L F
.987 .75 .489 r
.51229 .66394 m .51188 .66386 L .51 .66428 L F
.296 0 .132 r
.51105 .6622 m .50869 .66461 L .51051 .66257 L F
.401 .025 .205 r
.51325 .66178 m .51 .66428 L .51105 .6622 L F
.987 .75 .489 r
.51188 .66386 m .50861 .66323 L .51 .66428 L F
.891 .981 .7 r
.50938 .66381 m .50739 .6664 L .51 .66428 L F
.50861 .66323 m .50807 .66464 L .50938 .66381 L F
.50806 .66467 m .50739 .6664 L .50933 .66387 L F
.50746 .6654 m .50657 .66651 L .5069 .66646 L F
.507 .198 .377 r
.50612 .66587 m .50745 .66541 L .50739 .66506 L F
.891 .981 .7 r
.50746 .6654 m .50745 .66541 L .50746 .6654 L F
.50861 .66323 m .50705 .66644 L .50735 .66611 L F
.50861 .66323 m .50735 .66611 L .50762 .66581 L F
.361 .317 .673 r
.50636 .66156 m .50804 .66454 L .50861 .66323 L F
.50804 .66454 m .50835 .6651 L .50861 .66323 L F
.507 .198 .377 r
.50745 .66541 m .50835 .6651 L .50772 .66508 L F
.50745 .66541 m .50772 .66508 L .50739 .66506 L F
.543 .394 .629 r
.50772 .66508 m .50804 .66454 L .50636 .66156 L F
.021 0 0 r
.50739 .6664 m .50657 .66651 L .50402 .66659 L F
.891 .981 .7 r
.50861 .66323 m .50657 .66651 L .50745 .66541 L F
.50861 .66323 m .50745 .66541 L .50746 .6654 L F
.507 .198 .377 r
.50745 .66541 m .50657 .66651 L .50835 .6651 L F
.50612 .66587 m .50657 .66651 L .50745 .66541 L F
.50402 .66659 m .50501 .66656 L .50612 .66587 L F
.50501 .66656 m .50657 .66651 L .50612 .66587 L F
.891 .981 .7 r
.50807 .66464 m .50806 .66467 L .50938 .66381 L F
.50806 .66467 m .50933 .66387 L .50938 .66381 L F
.507 .198 .377 r
.50402 .66659 m .50612 .66587 L .50393 .66492 L F
.50612 .66587 m .50739 .66506 L .50393 .66492 L F
.543 .394 .629 r
.50772 .66508 m .50835 .6651 L .50804 .66454 L F
.891 .981 .7 r
.50768 .66514 m .5069 .66646 L .50705 .66644 L F
.50861 .66323 m .5069 .66646 L .50768 .66514 L F
.50762 .66581 m .50705 .66644 L .50739 .6664 L F
.816 .729 .769 r
.55049 .66525 m .54885 .66808 L .55208 .66758 L F
.701 .336 .352 r
.54885 .66808 m .54991 .66976 L .55208 .66758 L F
.716 .356 .365 r
.54991 .66976 m .55311 .66968 L .55208 .66758 L F
.739 .365 .342 r
.55208 .66758 m .55311 .66968 L .55361 .66846 L F
.63 .073 0 r
.75823 .48795 m .75521 .48677 L .75618 .488 L F
.491 .386 .662 r
.42876 .68313 m .43065 .6827 L .43064 .67894 L F
.403 .39 .731 r
.42876 .68313 m .43111 .68476 L .43065 .6827 L F
.42876 .68313 m .42951 .68518 L .43111 .68476 L F
.078 .621 .846 r
.34079 .583 m .34326 .58317 L .34469 .58358 L F
.041 .602 .799 r
.34326 .58317 m .34698 .58356 L .34469 .58358 L F
.456 0 0 r
.52342 .70633 m .52639 .70809 L .52724 .70835 L F
.663 .968 .915 r
.52724 .70835 m .52639 .70809 L .52809 .70697 L F
.52724 .70835 m .52639 .70809 L .52809 .70697 L F
.636 .923 .975 r
.50578 .77976 m .50564 .77905 L .5035 .78002 L F
.727 .78 .895 r
.51165 .78416 m .50993 .78452 L .51293 .78244 L F
.51165 .78416 m .50993 .78452 L .51293 .78244 L F
.594 .203 .271 r
.47114 .6592 m .4676 .66129 L .46926 .66043 L F
.47114 .6592 m .47006 .66134 L .4676 .66129 L F
.711 .605 .737 r
.69655 .4758 m .69979 .47634 L .69982 .4738 L F
.643 .502 .676 r
.69655 .4758 m .69992 .47843 L .69979 .47634 L F
.64 .406 .549 r
.69979 .47634 m .70226 .47744 L .70291 .47578 L F
.69979 .47634 m .69992 .47843 L .70226 .47744 L F
.685 .532 .672 r
.45406 .67617 m .45151 .67884 L .45215 .67742 L F
.117 .252 .728 r
.44016 .70606 m .44081 .70459 L .4392 .70437 L F
.44 .112 .312 r
.38625 .61341 m .38857 .61296 L .38947 .61061 L F
.433 .106 .309 r
.38947 .61061 m .39088 .61244 L .3917 .61008 L F
.38947 .61061 m .38857 .61296 L .39088 .61244 L F
.552 0 0 r
.53173 .64686 m .53443 .64784 L .5314 .64725 L F
.155 .058 .484 r
.61041 .63072 m .61232 .62716 L .61255 .62956 L F
.61041 .63072 m .61122 .62767 L .61232 .62716 L F
.2 .095 .503 r
.61264 .63202 m .61041 .63072 L .61255 .62956 L F
.61264 .63202 m .61056 .63344 L .61041 .63072 L F
.419 .281 .586 r
.43049 .67654 m .43232 .67345 L .43009 .67411 L F
.383 .843 .79 r
.76715 .51099 m .76569 .51146 L .76645 .51128 L F
.09 .579 .901 r
.76538 .51055 m .767 .51114 L .76645 .51128 L F
.237 0 0 r
.76862 .51172 m .76715 .51099 L .76645 .51128 L F
.09 .579 .901 r
.767 .51114 m .76862 .51172 L .76645 .51128 L F
.383 .843 .79 r
.76569 .51146 m .76369 .51211 L .76645 .51128 L F
.237 0 0 r
.76862 .51172 m .76953 .51075 L .76715 .51099 L F
0 0 .361 r
.80407 .51795 m .80253 .52223 L .80148 .5211 L F
.80407 .51795 m .80402 .52059 L .80253 .52223 L F
.543 .792 .991 r
.80253 .52223 m .80402 .52059 L .80148 .5211 L F
0 0 .13 r
.6156 .61994 m .61494 .61942 L .61644 .61821 L F
.6156 .61994 m .61457 .62144 L .61494 .61942 L F
.081 .578 .895 r
.76424 .48996 m .76137 .48847 L .75823 .48795 L F
.239 .714 .939 r
.76633 .4892 m .76137 .48847 L .76424 .48996 L F
.566 .354 .552 r
.48005 .67013 m .48196 .66782 L .47959 .66822 L F
.582 .188 .26 r
.4709 .71145 m .46957 .71346 L .46718 .71325 L F
.664 .281 .311 r
.4709 .71145 m .4731 .71337 L .46957 .71346 L F
0 .362 .832 r
.53298 .66478 m .53341 .66394 L .53127 .66467 L F
.53298 .66478 m .53454 .66542 L .53341 .66394 L F
.169 .282 .737 r
.53298 .66478 m .53525 .66762 L .53454 .66542 L F
.625 .142 .086 r
.66267 .4861 m .66447 .4866 L .66587 .48555 L F
.522 .019 .001 r
.66587 .48555 m .66447 .4866 L .6684 .48665 L F
.453 0 0 r
.66587 .48555 m .6684 .48665 L .66948 .4865 L F
.73 .567 .67 r
.79262 .50504 m .79282 .50748 L .79093 .50734 L F
.541 .501 .761 r
.79416 .50104 m .79262 .50504 L .79167 .50168 L F
.79416 .50104 m .795 .5048 L .79262 .50504 L F
.636 .566 .758 r
.795 .5048 m .79282 .50748 L .79262 .50504 L F
0 0 0 r
.58851 .64806 m .58966 .64726 L .59128 .64607 L F
.64 .955 .936 r
.58807 .65041 m .58966 .64726 L .58851 .64806 L F
.967 .646 .33 r
.52123 .64498 m .5215 .64687 L .51919 .6452 L F
.609 .384 .549 r
.52123 .64498 m .5215 .64687 L .51919 .6452 L F
.301 0 0 r
.45652 .70271 m .45936 .70323 L .4601 .70254 L F
.575 .032 0 r
.46142 .7041 m .4601 .70254 L .45936 .70323 L F
.46142 .7041 m .46274 .70489 L .4601 .70254 L F
.434 .669 .961 r
.7719 .48268 m .77047 .48413 L .76946 .48287 L F
.7719 .48268 m .77275 .48412 L .77047 .48413 L F
.527 .256 .447 r
.45037 .66441 m .44835 .66244 L .44801 .6648 L F
.45037 .66441 m .45087 .66144 L .44835 .66244 L F
.038 0 0 r
.51997 .70768 m .52236 .70713 L .52342 .70633 L F
.627 .098 0 r
.52236 .70713 m .52639 .70809 L .52342 .70633 L F
.786 .777 .845 r
.72126 .49492 m .7192 .49627 L .72208 .49676 L F
.539 .506 .768 r
.72208 .49676 m .72366 .49253 L .72126 .49492 L F
.72208 .49676 m .72459 .49708 L .72366 .49253 L F
.56 .299 .476 r
.72208 .49676 m .72602 .4991 L .72459 .49708 L F
.506 .314 .554 r
.59545 .63936 m .59788 .6389 L .59783 .6365 L F
.099 0 .148 r
.50806 .67902 m .50559 .68179 L .5064 .68005 L F
.639 .213 .218 r
.51154 .77397 m .51023 .77577 L .50799 .7741 L F
.169 0 0 r
.50799 .7741 m .51108 .77418 L .51154 .77397 L F
.582 .567 .802 r
.5092 .77003 m .51112 .77405 L .50799 .7741 L F
.876 .919 .523 r
.5116 .77254 m .51108 .77418 L .51154 .77397 L F
.582 .567 .802 r
.51112 .77405 m .51119 .77419 L .51108 .77418 L F
.51112 .77405 m .51108 .77418 L .50799 .7741 L F
.876 .919 .523 r
.5116 .77253 m .51112 .77405 L .5116 .77254 L F
.576 .564 .803 r
.5116 .77253 m .51119 .77419 L .51112 .77405 L F
.5116 .77253 m .51112 .77405 L .5092 .77003 L F
.876 .919 .523 r
.5116 .77253 m .51108 .77418 L .51112 .77405 L F
.5116 .77253 m .51086 .77429 L .51108 .77418 L F
.51086 .77429 m .51023 .77577 L .51154 .77397 L F
.169 0 0 r
.51108 .77418 m .51119 .77419 L .51154 .77397 L F
.858 .868 .422 r
.51154 .77397 m .51119 .77419 L .5116 .77253 L F
.519 .067 .118 r
.31011 .63324 m .3071 .63459 L .30795 .63359 L F
.373 0 0 r
.32591 .58247 m .32778 .58304 L .32954 .58255 L F
.344 0 0 r
.32778 .58304 m .33163 .58243 L .32954 .58255 L F
.971 .675 .278 r
.55222 .64763 m .55244 .64994 L .55333 .65079 L F
.49 0 0 r
.55244 .64994 m .55608 .65206 L .55333 .65079 L F
.863 .496 .352 r
.45706 .67859 m .45406 .67617 L .45756 .67667 L F
.306 .045 .344 r
.46001 .67565 m .45706 .67859 L .45756 .67667 L F
.037 0 0 r
.57823 .58825 m .57709 .58992 L .57528 .59065 L F
.524 .119 .215 r
.57823 .58825 m .58021 .5893 L .57709 .58992 L F
.511 .148 .287 r
.57823 .58825 m .58084 .58799 L .58021 .5893 L F
.651 .217 .205 r
.54897 .67395 m .54883 .67486 L .54641 .67334 L F
.199 .397 .833 r
.54641 .67334 m .54883 .67486 L .54747 .67274 L F
.505 .397 .665 r
.28981 .60538 m .29181 .6048 L .29152 .6011 L F
.52 .444 .711 r
.28981 .60538 m .29244 .60728 L .29181 .6048 L F
.635 .556 .748 r
.42571 .60213 m .42381 .60526 L .4215 .59997 L F
.65 .575 .758 r
.4272 .6042 m .42381 .60526 L .42571 .60213 L F
.592 .316 .468 r
.42662 .6052 m .42381 .60526 L .4272 .6042 L F
.42662 .6052 m .42353 .60737 L .42381 .60526 L F
0 .019 .563 r
.7295 .47252 m .73192 .47528 L .73258 .47637 L F
.818 .733 .771 r
.73192 .47528 m .73281 .47849 L .73258 .47637 L F
.232 0 .314 r
.48997 .61961 m .48936 .62164 L .49169 .61865 L F
.729 .692 .815 r
.26744 .84411 m .26939 .84251 L .26646 .84239 L F
.909 .938 .815 r
.68621 .50126 m .68778 .49977 L .6856 .50055 L F
.923 .91 .789 r
.6856 .50055 m .68778 .49977 L .68769 .49725 L F
.676 .522 .669 r
.69405 .47856 m .69746 .47913 L .69655 .4758 L F
.643 .502 .676 r
.69655 .4758 m .69746 .47913 L .69992 .47843 L F
.362 .325 .683 r
.57593 .65044 m .57673 .65303 L .57461 .6512 L F
.204 .685 .932 r
.36439 .58436 m .36814 .58509 L .36592 .58537 L F
.479 .525 .827 r
.29398 .61396 m .29539 .61628 L .29711 .61573 L F
.436 .176 .42 r
.65494 .4905 m .65818 .48991 L .65782 .48791 L F
.516 .329 .566 r
.65494 .4905 m .65783 .49248 L .65818 .48991 L F
.65494 .4905 m .65537 .49332 L .65783 .49248 L F
.766 .682 .77 r
.58822 .63616 m .59052 .6332 L .59172 .63675 L F
.466 .682 .959 r
.59279 .63497 m .59172 .63675 L .59052 .6332 L F
.382 .313 .654 r
.42951 .68518 m .43165 .6872 L .43111 .68476 L F
.417 .316 .632 r
.42951 .68518 m .42984 .6879 L .43165 .6872 L F
.65 .913 .606 r
.33252 .64431 m .33003 .64703 L .33182 .64539 L F
.521 .347 .586 r
.48611 .64508 m .4862 .64752 L .48399 .648 L F
.514 .295 .519 r
.4862 .64752 m .48378 .65028 L .48399 .648 L F
.577 .736 .951 r
.42792 .70427 m .43084 .70507 L .42956 .70422 L F
.693 .882 .968 r
.42956 .70422 m .43084 .70507 L .43291 .70393 L F
.672 .333 .393 r
.55311 .66968 m .55699 .66806 L .55361 .66846 L F
.55311 .66968 m .55617 .66978 L .55699 .66806 L F
.386 .002 .183 r
.39497 .62516 m .39192 .62693 L .39261 .62565 L F
.753 .516 .574 r
.60732 .57567 m .61082 .57359 L .60739 .57328 L F
.60732 .57567 m .61086 .57598 L .61082 .57359 L F
.569 .245 .38 r
.46274 .70489 m .46615 .70412 L .46606 .70244 L F
.781 .821 .883 r
.73662 .48104 m .7399 .48107 L .73855 .47844 L F
.589 .62 .85 r
.7399 .48107 m .74118 .47781 L .73855 .47844 L F
.7399 .48107 m .74243 .48063 L .74118 .47781 L F
.579 .025 0 r
.29579 .6243 m .29953 .62492 L .29764 .62433 L F
.694 .561 .7 r
.29764 .62433 m .29953 .62492 L .29948 .62246 L F
.747 .404 .402 r
.46496 .71096 m .46347 .71338 L .46113 .71123 L F
.46496 .71096 m .46546 .71256 L .46347 .71338 L F
.66 .355 .445 r
.46496 .71096 m .46718 .71325 L .46546 .71256 L F
.764 .383 .332 r
.7486 .51184 m .75008 .51029 L .74835 .51004 L F
.7486 .51184 m .75203 .51255 L .75008 .51029 L F
.738 .598 .7 r
.69156 .48155 m .69516 .48196 L .69405 .47856 L F
.738 .597 .699 r
.69156 .48155 m .69301 .48483 L .69516 .48196 L F
.667 .559 .723 r
.69405 .47856 m .69516 .48196 L .69746 .47913 L F
.691 .595 .743 r
.69516 .48196 m .69854 .48265 L .69746 .47913 L F
.256 0 0 r
.76118 .5244 m .7598 .52556 L .75809 .5254 L F
0 0 0 r
.76384 .52397 m .7598 .52556 L .76118 .5244 L F
.503 .827 1 r
.7355 .51634 m .73519 .51555 L .7319 .51604 L F
.644 .168 .107 r
.7319 .51604 m .73451 .51765 L .7355 .51634 L F
.951 .88 .477 r
.7355 .51634 m .73451 .51765 L .73519 .51555 L F
.441 .076 .248 r
.45517 .66061 m .45367 .65942 L .45306 .66113 L F
.45517 .66061 m .45601 .65908 L .45367 .65942 L F
0 0 0 r
.50386 .71065 m .50489 .70999 L .50584 .70757 L F
.644 .299 .373 r
.50489 .70999 m .50906 .70998 L .50584 .70757 L F
.54 .925 .901 r
.54417 .59632 m .54054 .5974 L .54348 .5965 L F
.411 .84 .694 r
.54545 .59548 m .54606 .59523 L .54417 .59632 L F
.419 .855 .745 r
.54545 .59548 m .54417 .59632 L .54348 .5965 L F
.006 .372 .838 r
.52172 .70761 m .52236 .70713 L .51997 .70768 L F
.52172 .70761 m .52405 .7092 L .52236 .70713 L F
.363 0 .049 r
.29135 .64435 m .2945 .64431 L .29643 .64238 L F
.748 .705 .811 r
.29374 .63992 m .29643 .64238 L .29726 .64172 L F
.982 .897 .654 r
.29643 .64238 m .29537 .64515 L .29726 .64172 L F
.29643 .64238 m .2945 .64431 L .29537 .64515 L F
.762 .666 .755 r
.42689 .69783 m .42961 .69951 L .42843 .69614 L F
0 0 0 r
.42823 .69969 m .42852 .69937 L .42781 .69998 L F
.572 .56 .801 r
.42843 .69614 m .42961 .69951 L .43184 .69907 L F
.42843 .69614 m .43051 .69792 L .43069 .69799 L F
.43051 .69792 m .43184 .69907 L .43069 .69799 L F
.305 .793 .886 r
.43184 .69907 m .42961 .69951 L .42852 .69937 L F
.722 .191 0 r
.42852 .69937 m .42961 .69951 L .42884 .69903 L F
.305 .793 .886 r
.43184 .69907 m .42852 .69937 L .43069 .69799 L F
0 0 0 r
.43089 .69805 m .43069 .69799 L .4293 .69985 L F
.4331 .69554 m .43069 .69799 L .43089 .69805 L F
.43069 .69799 m .42852 .69937 L .42823 .69969 L F
.722 .191 0 r
.42852 .69937 m .42884 .69903 L .42689 .69783 L F
.607 .418 .601 r
.58861 .58192 m .58639 .58397 L .58646 .58233 L F
.596 .529 .75 r
.29889 .61928 m .29948 .62246 L .30171 .62191 L F
.61 .509 .714 r
.29953 .62492 m .30171 .62191 L .29948 .62246 L F
.552 .338 .543 r
.43513 .6709 m .43757 .67071 L .43776 .66801 L F
.456 .258 .522 r
.43776 .66801 m .43963 .66997 L .43966 .6675 L F
.43776 .66801 m .43757 .67071 L .43963 .66997 L F
.591 .277 .405 r
.65782 .48791 m .66017 .48949 L .66004 .48673 L F
.791 .755 .821 r
.73108 .48779 m .72958 .49027 L .73276 .49046 L F
.741 .74 .851 r
.73108 .48779 m .73276 .49046 L .73442 .48935 L F
.512 .222 .411 r
.49348 .76158 m .49305 .76303 L .49591 .76189 L F
.372 0 0 r
.71753 .47445 m .7167 .47462 L .71987 .4753 L F
.81 .464 .402 r
.46796 .7074 m .46951 .70527 L .46615 .70412 L F
.46796 .7074 m .46908 .70657 L .46951 .70527 L F
.528 .17 .303 r
.46908 .70657 m .47179 .70662 L .46951 .70527 L F
.547 .141 .223 r
.47179 .70662 m .47219 .70551 L .46951 .70527 L F
.729 .407 .434 r
.53023 .65509 m .53297 .65673 L .52989 .65615 L F
.247 .761 .809 r
.48527 .65862 m .48275 .65915 L .48679 .65851 L F
.9 .526 .317 r
.48476 .65651 m .48527 .65862 L .48679 .65851 L F
.954 .761 .306 r
.48865 .66147 m .4889 .65955 L .48679 .65851 L F
.739 .436 .47 r
.4889 .65955 m .48865 .66147 L .48679 .65851 L F
.663 .126 0 r
.48679 .65851 m .4889 .65955 L .48527 .65862 L F
.576 .603 .843 r
.34582 .62423 m .3454 .62803 L .34419 .62461 L F
.34582 .62423 m .34762 .6277 L .3454 .62803 L F
.627 .473 .654 r
.79072 .49577 m .7908 .49865 L .78811 .49886 L F
.631 .53 .721 r
.79167 .50168 m .78811 .49886 L .7908 .49865 L F
.79167 .50168 m .78935 .50266 L .78811 .49886 L F
.738 .598 .7 r
.69156 .48155 m .69405 .47856 L .69167 .4791 L F
0 0 0 r
.3434 .64571 m .34315 .64503 L .34535 .64453 L F
.44 0 .103 r
.34739 .64391 m .346 .64565 L .3434 .64571 L F
.264 .738 .939 r
.3434 .64571 m .346 .64565 L .34426 .64548 L F
.44 0 .103 r
.34739 .64391 m .3434 .64571 L .34535 .64453 L F
.264 .738 .939 r
.3434 .64571 m .34426 .64548 L .34232 .64528 L F
0 0 0 r
.3434 .64571 m .34159 .64662 L .34214 .64606 L F
.3434 .64571 m .34214 .64606 L .34315 .64503 L F
.803 .83 .872 r
.44847 .69433 m .44982 .69596 L .45085 .69497 L F
.542 .166 .278 r
.45195 .69337 m .44847 .69433 L .44982 .69596 L F
.962 .827 .664 r
.61745 .61009 m .61846 .60799 L .61717 .60699 L F
.203 .691 .926 r
.55785 .64532 m .55673 .64478 L .55431 .64471 L F
.55785 .64532 m .55673 .64478 L .55431 .64471 L F
.468 .756 .993 r
.55785 .64532 m .55897 .64394 L .55673 .64478 L F
.55785 .64532 m .56029 .6451 L .55897 .64394 L F
.55785 .64532 m .55897 .64394 L .55673 .64478 L F
.55785 .64532 m .56029 .6451 L .55897 .64394 L F
.243 .751 .875 r
.36814 .58509 m .37033 .58481 L .37177 .58497 L F
.219 .726 .896 r
.37033 .58481 m .37385 .58496 L .37177 .58497 L F
.645 .568 .753 r
.69746 .47913 m .69854 .48265 L .70098 .48199 L F
.434 .778 .997 r
.39636 .58854 m .39281 .58796 L .39505 .58771 L F
.431 .777 .997 r
.39817 .58822 m .39636 .58854 L .39505 .58771 L F
.074 0 0 r
.35147 .64232 m .34962 .64347 L .34739 .64391 L F
.316 0 0 r
.35372 .64197 m .34962 .64347 L .35147 .64232 L F
.883 .992 .781 r
.29726 .62594 m .29953 .62492 L .29579 .6243 L F
.29726 .62594 m .29719 .62767 L .29953 .62492 L F
.715 .541 .652 r
.29953 .62492 m .29719 .62767 L .29964 .62764 L F
.61 .509 .714 r
.29953 .62492 m .30235 .62479 L .30171 .62191 L F
.422 .2 .47 r
.29964 .62764 m .30235 .62479 L .29953 .62492 L F
.511 0 0 r
.59305 .64478 m .59676 .64755 L .59663 .64507 L F
.774 .956 .637 r
.59578 .64406 m .59646 .64354 L .59663 .64507 L F
.989 .767 .509 r
.59676 .64755 m .59578 .64406 L .59663 .64507 L F
.616 .357 .501 r
.58835 .56985 m .59082 .56744 L .58897 .56826 L F
.241 0 .029 r
.55625 .58958 m .55732 .58829 L .5544 .59004 L F
.202 0 0 r
.55849 .58918 m .55732 .58829 L .55625 .58958 L F
.55849 .58918 m .55969 .58767 L .55732 .58829 L F
.348 .465 .837 r
.65876 .50368 m .65951 .50098 L .65677 .50118 L F
.408 .207 .492 r
.66019 .50201 m .66078 .5039 L .65876 .50368 L F
.348 .465 .837 r
.65876 .50368 m .66078 .5039 L .65951 .50098 L F
0 0 .458 r
.56354 .62113 m .56398 .62349 L .56307 .62452 L F
0 .08 .61 r
.56307 .62452 m .56398 .62349 L .5646 .62689 L F
.381 0 0 r
.59128 .64607 m .59423 .64667 L .59305 .64478 L F
.59128 .64607 m .58966 .64726 L .59423 .64667 L F
.44 .235 .504 r
.29171 .59926 m .29339 .59879 L .29365 .59645 L F
.503 .289 .522 r
.29365 .59645 m .29579 .59821 L .29578 .59592 L F
.29365 .59645 m .29339 .59879 L .29579 .59821 L F
.443 .879 .839 r
.73776 .51328 m .73969 .51213 L .7402 .5128 L F
.73776 .51328 m .7371 .51327 L .73969 .51213 L F
.73776 .51328 m .73969 .51213 L .7402 .5128 L F
.73776 .51328 m .7371 .51327 L .73969 .51213 L F
.224 0 0 r
.51894 .63341 m .52122 .63369 L .52255 .63358 L F
.307 0 0 r
.52122 .63369 m .52479 .63419 L .52255 .63358 L F
.298 0 .025 r
.54579 .70194 m .54231 .70412 L .5436 .70258 L F
.759 .639 .728 r
.76953 .51075 m .77296 .51055 L .77197 .50713 L F
.616 .191 .212 r
.77217 .51234 m .77296 .51055 L .76953 .51075 L F
.52 .494 .768 r
.77197 .50713 m .77296 .51055 L .77513 .50826 L F
0 0 0 r
.77513 .50826 m .77296 .51055 L .77217 .51234 L F
.54 .726 .96 r
.78142 .48519 m .77983 .4871 L .77903 .48548 L F
.78142 .48519 m .78226 .48667 L .77983 .4871 L F
.32 .516 .891 r
.59788 .6389 m .59657 .63512 L .59783 .6365 L F
.943 .627 .408 r
.72662 .50654 m .72798 .50493 L .72721 .50405 L F
.72662 .50654 m .72847 .50742 L .72798 .50493 L F
.363 .142 .438 r
.47154 .6452 m .4712 .64749 L .47341 .64453 L F
.473 .191 .405 r
.38363 .6318 m .38173 .63073 L .38399 .63037 L F
.38363 .6318 m .38126 .63247 L .38173 .63073 L F
.497 .317 .566 r
.29171 .59926 m .29378 .60042 L .29339 .59879 L F
.29171 .59926 m .29152 .6011 L .29378 .60042 L F
.899 .66 .569 r
.467 .67008 m .46537 .6707 L .46492 .66872 L F
.467 .67008 m .46677 .66972 L .46537 .6707 L F
.452 .258 .526 r
.46671 .6718 m .46537 .6707 L .46677 .66972 L F
.46671 .6718 m .46486 .67344 L .46537 .6707 L F
.748 .705 .811 r
.29374 .63992 m .29726 .64172 L .29575 .63881 L F
.725 .723 .848 r
.29575 .63881 m .29726 .64172 L .29953 .64024 L F
.716 .412 .461 r
.73517 .47812 m .73855 .47844 L .73869 .47635 L F
.546 .268 .444 r
.73855 .47844 m .74118 .47781 L .73869 .47635 L F
.186 .709 .685 r
.46264 .68886 m .46513 .68819 L .4658 .68801 L F
.575 .742 .956 r
.46264 .68886 m .46513 .68819 L .465 .68807 L F
0 0 0 r
.4658 .68801 m .46433 .68809 L .46224 .68816 L F
.556 .929 .918 r
.46686 .68687 m .46521 .68763 L .4658 .68801 L F
.46515 .68759 m .46433 .68809 L .4658 .68801 L F
.686 .775 .919 r
.46686 .68687 m .46513 .68819 L .46474 .68784 L F
.46686 .68687 m .46474 .68784 L .4631 .68638 L F
.556 .929 .918 r
.46686 .68687 m .46515 .68759 L .46521 .68763 L F
.575 .742 .956 r
.46433 .68809 m .46474 .68784 L .4631 .68638 L F
.556 .929 .918 r
.46515 .68759 m .46391 .68812 L .46433 .68809 L F
.575 .742 .956 r
.46277 .68814 m .46433 .68809 L .4631 .68638 L F
.46433 .68809 m .465 .68807 L .46474 .68784 L F
.46264 .68886 m .465 .68807 L .46277 .68814 L F
0 0 0 r
.46224 .68816 m .46391 .68812 L .46165 .68818 L F
.46433 .68809 m .46391 .68812 L .46224 .68816 L F
.568 .925 .751 r
.4658 .68801 m .46513 .68819 L .46686 .68687 L F
.016 .552 .847 r
.7771 .52973 m .78012 .53068 L .77918 .53021 L F
0 .54 .839 r
.77918 .53021 m .78012 .53068 L .78289 .53115 L F
.207 0 .078 r
.46906 .64833 m .46828 .64965 L .4712 .64749 L F
.976 .717 .307 r
.77187 .52749 m .77229 .52624 L .7719 .52769 L F
.742 .307 .218 r
.76983 .52399 m .77281 .5247 L .77229 .52624 L F
0 .129 .649 r
.7709 .52472 m .77229 .52624 L .77149 .52513 L F
.76983 .52399 m .77119 .52524 L .7709 .52472 L F
.77119 .52524 m .77229 .52624 L .7709 .52472 L F
.383 0 0 r
.76983 .52399 m .76869 .52429 L .7663 .52393 L F
.374 .439 .8 r
.76869 .52429 m .77068 .52435 L .76763 .52326 L F
.77068 .52435 m .77224 .52439 L .77046 .52396 L F
.77068 .52435 m .77046 .52396 L .76763 .52326 L F
.976 .717 .307 r
.77149 .52513 m .77229 .52624 L .77187 .52749 L F
.742 .307 .218 r
.77281 .5247 m .7732 .52479 L .77229 .52624 L F
.863 .471 .295 r
.77229 .52624 m .7732 .52479 L .77426 .52725 L F
.453 .102 .279 r
.3675 .62466 m .36988 .6244 L .37082 .62203 L F
.294 0 .208 r
.37082 .62203 m .37191 .62361 L .37296 .62133 L F
.37082 .62203 m .36988 .6244 L .37191 .62361 L F
.31 .125 .46 r
.46754 .68013 m .46893 .68107 L .4691 .67894 L F
.553 .246 .401 r
.38051 .61578 m .38342 .6154 L .3839 .61361 L F
.491 .188 .379 r
.38342 .6154 m .38571 .61508 L .3839 .61361 L F
.514 .179 .337 r
.3839 .61361 m .38571 .61508 L .38625 .61341 L F
.41 .357 .689 r
.32928 .61243 m .32795 .61585 L .32729 .6139 L F
.32928 .61243 m .32967 .61577 L .32795 .61585 L F
.434 .226 .497 r
.57528 .59065 m .5753 .59235 L .57318 .59335 L F
.304 0 .027 r
.5753 .59235 m .57219 .59378 L .57318 .59335 L F
.57 .181 .266 r
.47664 .71162 m .47701 .71292 L .4731 .71337 L F
.743 .294 .185 r
.47664 .71162 m .47915 .71377 L .47701 .71292 L F
.707 .356 .379 r
.48019 .71309 m .47915 .71377 L .47664 .71162 L F
.419 .281 .586 r
.43049 .67654 m .43238 .67608 L .43232 .67345 L F
.439 .346 .653 r
.43049 .67654 m .43273 .67855 L .43238 .67608 L F
.49 .347 .613 r
.43064 .67894 m .43273 .67855 L .43049 .67654 L F
.787 .486 .478 r
.77701 .52765 m .77479 .52885 L .77426 .52725 L F
.77479 .52885 m .77389 .52856 L .77426 .52725 L F
.77701 .52765 m .7771 .52973 L .77363 .52948 L F
.871 .651 .603 r
.77229 .52624 m .77426 .52725 L .77389 .52856 L F
.77314 .5283 m .77389 .52856 L .77363 .52948 L F
.77229 .52624 m .77389 .52856 L .77314 .5283 L F
.291 .353 .754 r
.77229 .52624 m .77363 .52948 L .77292 .52828 L F
.043 .569 .865 r
.77273 .52817 m .77312 .5283 L .77314 .5283 L F
.77277 .52818 m .77314 .5283 L .77591 .52855 L F
.978 .689 .312 r
.77229 .52624 m .77292 .52828 L .7719 .52769 L F
.043 .569 .865 r
.77273 .52817 m .77314 .5283 L .77277 .52818 L F
.7719 .52769 m .77273 .52817 L .77591 .52855 L F
.77273 .52817 m .77292 .52828 L .77312 .5283 L F
.787 .486 .478 r
.77479 .52885 m .77363 .52948 L .77389 .52856 L F
.783 .772 .843 r
.51951 .77383 m .52063 .76978 L .51969 .77101 L F
.27 0 .197 r
.488 .64325 m .48817 .64442 L .49076 .64171 L F
.299 .499 .885 r
.21049 .55118 m .20989 .55299 L .20777 .55039 L F
.21049 .55118 m .2112 .55285 L .20989 .55299 L F
.516 .368 .618 r
.53277 .70787 m .53514 .7075 L .53495 .70537 L F
.725 .572 .682 r
.79282 .50748 m .79421 .51134 L .79058 .51029 L F
.636 .566 .758 r
.795 .5048 m .79636 .50837 L .79282 .50748 L F
.612 .479 .675 r
.79636 .50837 m .79421 .51134 L .79282 .50748 L F
.635 .297 .382 r
.59674 .56643 m .59904 .56689 L .59939 .56454 L F
.719 .375 .395 r
.59939 .56454 m .60246 .56696 L .6022 .56512 L F
.59939 .56454 m .59904 .56689 L .60246 .56696 L F
.173 0 0 r
.53416 .60012 m .53291 .59989 L .5323 .6012 L F
.296 .618 .958 r
.38793 .58579 m .38734 .58696 L .38596 .58574 L F
.38793 .58579 m .38919 .58714 L .38734 .58696 L F
.578 .334 .511 r
.39422 .60754 m .39661 .60735 L .39686 .60506 L F
.609 .516 .724 r
.39686 .60506 m .39963 .60491 L .39873 .60219 L F
.517 .245 .441 r
.39661 .60735 m .39963 .60491 L .39686 .60506 L F
.34 .138 .453 r
.48097 .63352 m .48283 .63293 L .48308 .63064 L F
.263 .111 .478 r
.48097 .63352 m .48241 .6352 L .48283 .63293 L F
.48097 .63352 m .48096 .6363 L .48241 .6352 L F
.501 .264 .486 r
.37593 .61942 m .37812 .61898 L .37854 .61635 L F
.488 .244 .47 r
.37812 .61898 m .38051 .61578 L .37854 .61635 L F
.2 .22 .657 r
.60969 .65546 m .61015 .65836 L .60896 .65934 L F
0 0 .352 r
.61015 .65836 m .60906 .66209 L .60896 .65934 L F
.483 .335 .603 r
.6095 .64451 m .60778 .64269 L .60976 .64105 L F
.6095 .64451 m .60813 .64523 L .60778 .64269 L F
.293 .791 .801 r
.35115 .62729 m .35198 .62684 L .35337 .62709 L F
.35115 .62729 m .34985 .62745 L .35198 .62684 L F
.191 0 0 r
.35079 .5984 m .34938 .59876 L .34713 .59869 L F
.146 .686 .706 r
.35288 .59809 m .34938 .59876 L .35079 .5984 L F
0 0 0 r
.33229 .58296 m .33392 .58256 L .33364 .58257 L F
.507 .848 .996 r
.33364 .58257 m .3361 .58203 L .33767 .58279 L F
0 0 0 r
.33392 .58256 m .3361 .58203 L .33364 .58257 L F
0 .552 .741 r
.33329 .58259 m .33364 .58257 L .33529 .58278 L F
.33163 .58243 m .33364 .58257 L .33329 .58259 L F
.507 .848 .996 r
.33364 .58257 m .33767 .58279 L .33529 .58278 L F
.181 .432 .865 r
.41763 .59737 m .41687 .59841 L .4153 .59739 L F
0 0 0 r
.60182 .66845 m .60197 .66869 L .6003 .66943 L F
.60182 .66845 m .60382 .66737 L .60197 .66869 L F
.961 .668 .244 r
.73281 .47849 m .73298 .48004 L .73337 .48029 L F
.103 .05 .507 r
.73389 .48196 m .73517 .47812 L .73281 .47849 L F
.758 .497 .538 r
.72982 .48006 m .73312 .48135 L .73281 .47849 L F
.75 .446 .468 r
.73517 .47812 m .73225 .47956 L .73419 .47776 L F
.73225 .47956 m .73185 .47976 L .73215 .4795 L F
.73225 .47956 m .73215 .4795 L .73419 .47776 L F
.961 .668 .244 r
.73337 .48029 m .73312 .48135 L .73389 .48196 L F
.73298 .48004 m .73312 .48135 L .73337 .48029 L F
.103 .05 .507 r
.73389 .48196 m .73568 .4802 L .73517 .47812 L F
.618 .919 .977 r
.73389 .48196 m .73312 .48135 L .73568 .4802 L F
.505 .401 .67 r
.79247 .4931 m .79072 .49577 L .79041 .49404 L F
.79247 .4931 m .79295 .49539 L .79072 .49577 L F
.647 .563 .746 r
.79295 .49539 m .7908 .49865 L .79072 .49577 L F
.766 .706 .796 r
.55553 .61783 m .55746 .61641 L .55738 .61723 L F
.365 .408 .773 r
.55738 .61723 m .55736 .6196 L .55553 .61783 L F
.283 .732 .959 r
.34912 .58351 m .3528 .58411 L .35076 .58393 L F
.839 .543 .489 r
.45284 .69947 m .4529 .70174 L .45427 .70074 L F
.292 0 0 r
.4529 .70174 m .45652 .70271 L .45427 .70074 L F
.824 .868 .878 r
.38598 .60057 m .38531 .60261 L .38758 .60171 L F
.431 .588 .907 r
.4248 .60001 m .42571 .60213 L .4215 .59997 L F
.014 0 0 r
.4248 .60001 m .4215 .59997 L .42094 .59999 L F
0 0 0 r
.42259 .70152 m .42392 .69995 L .42156 .70197 L F
.581 .417 .624 r
.42392 .69995 m .42689 .69783 L .42602 .69668 L F
.199 0 .138 r
.42487 .70086 m .42392 .69995 L .42259 .70152 L F
.42487 .70086 m .42689 .69783 L .42392 .69995 L F
.458 .173 .392 r
.41073 .61345 m .41035 .61554 L .40798 .61603 L F
.534 .24 .414 r
.41276 .61508 m .41073 .61345 L .41311 .61321 L F
.41276 .61508 m .41035 .61554 L .41073 .61345 L F
.588 .86 .524 r
.56033 .61314 m .55855 .61501 L .55746 .61641 L F
.299 .189 .556 r
.55855 .61501 m .55738 .61723 L .55746 .61641 L F
.552 .869 .995 r
.56371 .64503 m .56253 .64438 L .56029 .6451 L F
0 .302 .787 r
.56371 .64503 m .56418 .64462 L .56253 .64438 L F
.56371 .64503 m .56649 .64687 L .56418 .64462 L F
.498 .384 .654 r
.29766 .59272 m .30041 .5952 L .30073 .59214 L F
.254 0 .245 r
.30073 .59214 m .30206 .59432 L .30305 .59191 L F
.156 0 0 r
.30073 .59214 m .30305 .59191 L .30086 .59242 L F
.254 0 .245 r
.30073 .59214 m .30041 .5952 L .30206 .59432 L F
.622 .418 .585 r
.4911 .65612 m .49353 .65345 L .49112 .65354 L F
.429 .077 .264 r
.58575 .57451 m .58387 .5735 L .58306 .57538 L F
.58575 .57451 m .58626 .57305 L .58387 .5735 L F
.542 .354 .576 r
.58387 .5735 m .58626 .57305 L .5862 .57057 L F
0 .142 .672 r
.51411 .62952 m .51376 .62967 L .51177 .62768 L F
.51411 .62952 m .51511 .63106 L .51376 .62967 L F
.409 .112 .346 r
.43513 .6709 m .43678 .67241 L .43757 .67071 L F
.43513 .6709 m .43455 .67295 L .43678 .67241 L F
.66 .754 .919 r
.70821 .48799 m .71211 .48862 L .7107 .48705 L F
.781 .774 .847 r
.7107 .48705 m .71211 .48862 L .71407 .48717 L F
.138 0 0 r
.51047 .71213 m .50965 .71115 L .5116 .7103 L F
.05 0 0 r
.34713 .59869 m .34336 .60012 L .345 .5994 L F
.608 .248 .333 r
.55236 .67343 m .54883 .67486 L .54897 .67395 L F
.61 .535 .746 r
.56757 .59623 m .56547 .59888 L .56514 .59671 L F
.56757 .59623 m .56821 .59837 L .56547 .59888 L F
.451 .236 .495 r
.56821 .59837 m .5657 .60169 L .56547 .59888 L F
.522 .582 .856 r
.41088 .5916 m .40932 .59368 L .40761 .59117 L F
.41088 .5916 m .41124 .59334 L .40932 .59368 L F
.316 .608 .952 r
.20437 .54907 m .20579 .55059 L .20534 .55056 L F
.732 .475 .54 r
.50324 .68224 m .49966 .68447 L .49969 .68188 L F
.50324 .68224 m .50315 .68456 L .49966 .68447 L F
.784 .683 .752 r
.50559 .68179 m .50315 .68456 L .50324 .68224 L F
.546 .757 .975 r
.39554 .59876 m .39648 .5967 L .39399 .59757 L F
.39554 .59876 m .39798 .5983 L .39648 .5967 L F
.762 .666 .755 r
.42689 .69783 m .42843 .69614 L .42602 .69668 L F
.646 .603 .792 r
.42602 .69668 m .42843 .69614 L .42766 .69523 L F
.93 .558 .162 r
.60008 .59655 m .5995 .59763 L .59784 .59499 L F
.60008 .59655 m .60061 .5986 L .5995 .59763 L F
.916 .971 .677 r
.73705 .48359 m .73598 .48518 L .7365 .48574 L F
.938 .953 .761 r
.73451 .48697 m .7365 .48574 L .73598 .48518 L F
.73451 .48697 m .73442 .48935 L .7365 .48574 L F
.827 .558 .532 r
.68352 .487 m .68687 .48984 L .68693 .48751 L F
.836 .615 .603 r
.68687 .48984 m .68857 .49056 L .68693 .48751 L F
.367 .394 .757 r
.57656 .64105 m .57599 .64503 L .57456 .64134 L F
.57656 .64105 m .57742 .64426 L .57599 .64503 L F
.385 .747 .992 r
.55536 .63608 m .55843 .63681 L .55736 .63597 L F
0 .372 .831 r
.55843 .63681 m .56128 .63842 L .56026 .63716 L F
.06 .568 .883 r
.75809 .5254 m .75915 .52504 L .75704 .52585 L F
.75809 .5254 m .7598 .52556 L .75915 .52504 L F
.382 .53 .879 r
.7362 .52246 m .73796 .52081 L .73631 .52083 L F
.7362 .52246 m .73961 .52382 L .73796 .52081 L F
.566 .412 .631 r
.59634 .63066 m .59878 .63033 L .59844 .62778 L F
.627 .847 .463 r
.59599 .63421 m .59878 .63033 L .59634 .63066 L F
.566 .412 .631 r
.59634 .63066 m .59878 .63033 L .59844 .62778 L F
.667 .523 .679 r
.70226 .47744 m .70584 .47591 L .70291 .47578 L F
.626 .746 .933 r
.3389 .62117 m .3383 .62376 L .33669 .62154 L F
.3389 .62117 m .34073 .62272 L .3383 .62376 L F
.44 .311 .608 r
.58843 .57227 m .58835 .56985 L .5862 .57057 L F
.477 .304 .567 r
.58626 .57305 m .58843 .57227 L .5862 .57057 L F
.323 0 0 r
.35965 .63949 m .35815 .64113 L .35586 .64142 L F
.059 0 0 r
.36016 .64034 m .35965 .63949 L .36191 .63914 L F
.36016 .64034 m .35815 .64113 L .35965 .63949 L F
.66 .254 .264 r
.48567 .66804 m .48196 .66782 L .48486 .66679 L F
.989 .821 .583 r
.48418 .66981 m .48567 .66804 L .48486 .66679 L F
.48418 .66981 m .48541 .67062 L .48567 .66804 L F
.943 .807 .681 r
.71987 .4753 m .71914 .47872 L .72069 .47869 L F
.907 .74 .664 r
.71771 .48063 m .72069 .47869 L .71914 .47872 L F
.71771 .48063 m .71945 .48195 L .72069 .47869 L F
.855 .769 .766 r
.71987 .4753 m .72069 .47869 L .72141 .47661 L F
.391 0 .158 r
.30605 .5901 m .30827 .58975 L .3096 .58774 L F
.312 0 .111 r
.3096 .58774 m .31053 .58916 L .31172 .58718 L F
.3096 .58774 m .30827 .58975 L .31053 .58916 L F
.257 .077 .436 r
.57709 .58992 m .5753 .59235 L .57528 .59065 L F
.298 0 0 r
.75371 .4795 m .75648 .48034 L .75696 .48021 L F
.137 0 0 r
.75696 .48021 m .75648 .48034 L .75985 .48048 L F
.713 .585 .711 r
.68944 .48447 m .69301 .48483 L .69156 .48155 L F
.995 .8 .533 r
.61749 .60219 m .61679 .59903 L .61621 .60117 L F
.997 .77 .428 r
.61621 .60117 m .61707 .6046 L .61749 .60219 L F
.817 .626 .645 r
.68509 .49221 m .68857 .49056 L .68687 .48984 L F
.68509 .49221 m .68835 .49301 L .68857 .49056 L F
0 0 .324 r
.57334 .67055 m .57398 .66947 L .57109 .66744 L F
.57334 .67055 m .57353 .67075 L .57398 .66947 L F
.899 .66 .569 r
.467 .67008 m .46789 .67077 L .46677 .66972 L F
.887 .958 .841 r
.46789 .67077 m .46876 .6681 L .46677 .66972 L F
.46789 .67077 m .47021 .668 L .46876 .6681 L F
.698 .564 .699 r
.69167 .4791 m .68934 .48205 L .69156 .48155 L F
.847 .492 0 r
.48865 .66147 m .49006 .6648 L .48963 .66451 L F
.234 .356 .783 r
.49103 .66289 m .48865 .66147 L .4921 .66163 L F
.872 .552 .441 r
.48865 .66147 m .48697 .66283 L .48807 .66086 L F
.48865 .66147 m .48963 .66451 L .48697 .66283 L F
.723 .54 .643 r
.48819 .66161 m .49103 .66289 L .49005 .65975 L F
.48697 .66283 m .48817 .66285 L .48819 .66161 L F
.48817 .66285 m .49103 .66289 L .48819 .66161 L F
.954 .761 .306 r
.48865 .66147 m .48819 .66099 L .4889 .65955 L F
.48819 .66099 m .48807 .66086 L .48819 .66066 L F
.48819 .66099 m .48819 .66066 L .4889 .65955 L F
.059 0 0 r
.4889 .65955 m .48807 .66086 L .49005 .65975 L F
.543 .876 .991 r
.74614 .47545 m .74583 .47432 L .74703 .47522 L F
.647 .786 .948 r
.66045 .50623 m .66112 .50836 L .66402 .50675 L F
.616 .815 .977 r
.66112 .50836 m .66525 .50802 L .66402 .50675 L F
.092 .167 .649 r
.56803 .65012 m .56852 .65359 L .56971 .65223 L F
0 0 .561 r
.56852 .65359 m .56999 .65471 L .56971 .65223 L F
.56852 .65359 m .56983 .65571 L .56999 .65471 L F
.706 .571 .701 r
.68934 .48205 m .68704 .48481 L .68944 .48447 L F
.713 .585 .711 r
.68944 .48447 m .69156 .48155 L .68934 .48205 L F
.61 .394 .563 r
.57553 .57852 m .57806 .57836 L .57557 .57611 L F
.635 .39 .53 r
.57557 .57611 m .57806 .57836 L .57816 .57614 L F
.981 .691 .341 r
.45164 .69843 m .4529 .70174 L .45284 .69947 L F
.604 .258 .358 r
.51923 .65921 m .51813 .66153 L .51573 .66125 L F
.561 .459 .695 r
.52112 .65554 m .52123 .65883 L .51923 .65921 L F
.52 .199 .364 r
.52123 .65883 m .51813 .66153 L .51923 .65921 L F
.52 .352 .593 r
.49064 .63929 m .49328 .64135 L .49076 .64171 L F
.437 0 0 r
.47534 .7077 m .47772 .70861 L .47893 .70809 L F
0 .222 .662 r
.48022 .70873 m .47893 .70809 L .47772 .70861 L F
.48022 .70873 m .48136 .70959 L .47893 .70809 L F
.312 .151 .496 r
.33343 .60443 m .33337 .60696 L .33137 .6074 L F
.231 0 .245 r
.33264 .60885 m .33137 .6074 L .33337 .60696 L F
.33264 .60885 m .33084 .6096 L .33137 .6074 L F
.245 .697 .954 r
.38831 .59564 m .38673 .59551 L .38786 .59603 L F
.784 .683 .752 r
.50559 .68179 m .50679 .68507 L .50315 .68456 L F
.715 .278 .213 r
.50315 .68456 m .50679 .68507 L .5054 .68657 L F
.023 .203 .711 r
.50733 .68376 m .50679 .68507 L .50559 .68179 L F
.74 .917 .554 r
.5054 .68657 m .50679 .68507 L .50733 .68376 L F
.522 .8 .996 r
.50733 .68376 m .50679 .68507 L .50907 .68462 L F
.912 .561 .362 r
.60047 .61082 m .59935 .6123 L .59887 .61016 L F
.864 .483 .322 r
.60047 .61082 m .60116 .61283 L .59935 .6123 L F
.732 .744 .862 r
.74212 .50567 m .73905 .50553 L .74122 .50463 L F
.559 .803 .99 r
.74365 .50447 m .74212 .50567 L .74122 .50463 L F
.74365 .50447 m .74437 .50517 L .74212 .50567 L F
.741 .74 .851 r
.73108 .48779 m .73442 .48935 L .73451 .48697 L F
.444 .801 .997 r
.5052 .65081 m .50757 .65055 L .50382 .64999 L F
.503 .456 .738 r
.21215 .56927 m .21284 .57279 L .21103 .57338 L F
.421 .233 .518 r
.21284 .57279 m .21081 .57578 L .21103 .57338 L F
.477 .209 .428 r
.45263 .66395 m .45087 .66144 L .45037 .66441 L F
.45263 .66395 m .45306 .66113 L .45087 .66144 L F
.362 .282 .63 r
.56167 .61006 m .56137 .61299 L .56033 .61314 L F
.236 0 0 r
.56137 .61299 m .55855 .61501 L .56033 .61314 L F
.857 .461 .29 r
.31787 .63856 m .32041 .63972 L .31921 .64096 L F
.636 .162 .109 r
.32041 .63972 m .3229 .64125 L .31921 .64096 L F
.967 .646 .33 r
.52123 .64498 m .52016 .64654 L .5215 .64687 L F
.416 .754 .995 r
.52123 .64498 m .5254 .64485 L .52307 .64409 L F
.55 .268 .44 r
.52307 .64409 m .52016 .64654 L .52123 .64498 L F
.836 .454 0 r
.56712 .6479 m .56803 .65012 L .56707 .64893 L F
.459 .666 .952 r
.74363 .52819 m .74522 .52656 L .74301 .52657 L F
.74363 .52819 m .74626 .52832 L .74522 .52656 L F
.854 .574 .514 r
.54165 .67022 m .53793 .66947 L .53945 .6708 L F
.113 .233 .71 r
.53184 .65 m .5314 .64725 L .53443 .64784 L F
.223 .404 .831 r
.5449 .69985 m .54579 .70194 L .54568 .69937 L F
.147 .117 .564 r
.57061 .66507 m .57274 .66609 L .57226 .66373 L F
.57061 .66507 m .57109 .66744 L .57274 .66609 L F
.012 .186 .698 r
.60864 .64741 m .61054 .64934 L .60968 .65049 L F
0 .103 .633 r
.61054 .64934 m .61117 .65243 L .60968 .65049 L F
.197 .178 .61 r
.61117 .65243 m .61043 .65352 L .60968 .65049 L F
.113 .233 .71 r
.53184 .65 m .53316 .64941 L .5314 .64725 L F
0 0 .54 r
.53215 .64989 m .5322 .65006 L .53184 .65 L F
.887 .905 .834 r
.53167 .65041 m .53184 .65 L .5322 .65006 L F
.925 .571 .135 r
.53167 .65041 m .53302 .6536 L .53139 .6511 L F
.53184 .65 m .53201 .65053 L .53167 .65041 L F
.53201 .65053 m .53302 .6536 L .53167 .65041 L F
.71 .986 .87 r
.53112 .64995 m .53091 .65016 L .5322 .65006 L F
.887 .905 .834 r
.53 .65153 m .53184 .65 L .53167 .65041 L F
.52856 .65249 m .52975 .65159 L .53 .65153 L F
.52975 .65159 m .53184 .65 L .53 .65153 L F
.72 .402 .439 r
.52856 .65249 m .52532 .6525 L .52629 .65057 L F
.863 .614 .561 r
.52848 .64807 m .52666 .65182 L .52782 .65202 L F
.71 .986 .87 r
.52991 .65115 m .52856 .65249 L .53162 .65044 L F
.53091 .65016 m .52991 .65115 L .53167 .65041 L F
.52991 .65115 m .53162 .65044 L .53167 .65041 L F
.631 .583 .782 r
.52856 .65249 m .52989 .65615 L .53144 .65508 L F
.199 0 .188 r
.52931 .65405 m .52917 .65377 L .53112 .64995 L F
.5296 .65226 m .52856 .65249 L .52991 .65115 L F
.863 .614 .561 r
.52848 .64807 m .5296 .65226 L .53071 .64741 L F
.5296 .65226 m .52961 .65232 L .52964 .65222 L F
.5296 .65226 m .52964 .65222 L .53071 .64741 L F
.199 0 .188 r
.52917 .65377 m .52885 .65311 L .5296 .65226 L F
.52885 .65311 m .52856 .65249 L .5296 .65226 L F
.863 .614 .561 r
.5296 .65226 m .52958 .65232 L .52961 .65232 L F
.199 0 .188 r
.52917 .65377 m .52991 .65115 L .53112 .64995 L F
.863 .614 .561 r
.52936 .65138 m .52782 .65202 L .52958 .65232 L F
.52936 .65138 m .52958 .65232 L .5296 .65226 L F
.52848 .64807 m .52782 .65202 L .52936 .65138 L F
.71 .986 .87 r
.53188 .65008 m .53167 .65041 L .5322 .65006 L F
.925 .571 .135 r
.53184 .65 m .53139 .6511 L .53109 .65065 L F
.71 .986 .87 r
.53145 .65034 m .53167 .65041 L .53188 .65008 L F
.925 .571 .135 r
.53228 .64985 m .53109 .65065 L .53263 .64973 L F
.53184 .65 m .53145 .65034 L .53228 .64985 L F
.53145 .65034 m .53109 .65065 L .53228 .64985 L F
.71 .986 .87 r
.53091 .65016 m .53145 .65034 L .53188 .65008 L F
.163 .266 .725 r
.53144 .65508 m .53109 .65065 L .53302 .6536 L F
.53144 .65508 m .53437 .65368 L .53165 .65117 L F
.53114 .65128 m .53165 .65117 L .53109 .65065 L F
.53144 .65508 m .53165 .65117 L .53114 .65128 L F
.925 .571 .135 r
.53184 .65 m .53263 .64973 L .53316 .64941 L F
0 0 .54 r
.5314 .64725 m .53215 .64989 L .53184 .65 L F
.112 .12 .588 r
.50386 .71065 m .50531 .71197 L .50489 .70999 L F
.374 .466 .826 r
.33523 .61829 m .33504 .62162 L .33323 .61901 L F
.33523 .61829 m .33669 .62154 L .33504 .62162 L F
.245 .313 .736 r
.29889 .61928 m .29899 .61523 L .29711 .61573 L F
.29889 .61928 m .30003 .61868 L .29899 .61523 L F
.596 .529 .75 r
.29889 .61928 m .30171 .62191 L .30003 .61868 L F
.769 .794 .874 r
.71322 .48548 m .7107 .48705 L .71407 .48717 L F
.644 .736 .915 r
.71322 .48548 m .71407 .48717 L .71668 .48625 L F
.173 .326 .779 r
.78386 .5271 m .78238 .52793 L .78122 .52445 L F
.612 .737 .934 r
.40554 .59119 m .40222 .59034 L .40435 .59014 L F
.337 .713 .984 r
.40639 .59036 m .40554 .59119 L .40435 .59014 L F
.40639 .59036 m .40761 .59117 L .40554 .59119 L F
.537 .294 .494 r
.57231 .58119 m .5702 .57932 L .56986 .5813 L F
.57231 .58119 m .57271 .57873 L .5702 .57932 L F
.612 .479 .675 r
.79636 .50837 m .79648 .51037 L .79421 .51134 L F
.494 .524 .816 r
.29398 .61396 m .29577 .6124 L .29372 .61279 L F
.29398 .61396 m .29711 .61573 L .29577 .6124 L F
.545 .292 .484 r
.47021 .668 m .47048 .66834 L .46876 .6681 L F
.47021 .668 m .47263 .67008 L .47048 .66834 L F
.47021 .668 m .47259 .6677 L .47263 .67008 L F
.627 .362 .498 r
.44282 .6671 m .44538 .66725 L .44566 .66507 L F
.535 .267 .455 r
.4477 .66688 m .44566 .66507 L .44538 .66725 L F
.4477 .66688 m .44801 .6648 L .44566 .66507 L F
.589 .579 .81 r
.32395 .6453 m .32574 .64825 L .32789 .64761 L F
0 0 0 r
.52809 .60484 m .5295 .60363 L .53011 .60172 L F
0 0 .052 r
.52865 .60696 m .5295 .60363 L .52809 .60484 L F
.667 .878 .977 r
.46506 .69854 m .46271 .69892 L .4616 .69851 L F
.47 .312 .585 r
.46506 .69854 m .46738 .69859 L .46692 .69605 L F
.866 .419 .074 r
.46506 .69854 m .46566 .69876 L .46738 .69859 L F
.46506 .69854 m .46667 .70185 L .46485 .70036 L F
.82 .422 .296 r
.46791 .70136 m .46667 .70185 L .46506 .69854 L F
.866 .419 .074 r
.46506 .69854 m .46485 .70036 L .46566 .69876 L F
.388 .627 .948 r
.46738 .69859 m .46506 .69854 L .46692 .69605 L F
.812 .336 0 r
.74932 .48634 m .74656 .48323 L .74827 .48509 L F
.402 .662 .965 r
.53087 .63454 m .53317 .63466 L .53203 .6358 L F
.314 .518 .894 r
.53317 .63466 m .53408 .63672 L .53203 .6358 L F
.313 .653 .97 r
.42792 .70427 m .4285 .70307 L .42589 .70413 L F
.42792 .70427 m .42956 .70422 L .4285 .70307 L F
.349 .43 .804 r
.33171 .61531 m .33144 .61858 L .32967 .61577 L F
.33171 .61531 m .33323 .61901 L .33144 .61858 L F
.352 .22 .557 r
.33084 .6096 m .32928 .61243 L .32921 .61039 L F
.672 .57 .732 r
.52624 .66665 m .52293 .66472 L .52641 .66464 L F
.478 .188 .394 r
.52872 .66453 m .52624 .66665 L .52641 .66464 L F
.599 .57 .793 r
.76858 .49217 m .76942 .4956 L .77141 .49335 L F
.608 .584 .801 r
.76942 .4956 m .77247 .49633 L .77141 .49335 L F
.417 .708 .983 r
.76841 .48161 m .76654 .48282 L .76558 .48169 L F
.76841 .48161 m .76946 .48287 L .76654 .48282 L F
.325 .731 .98 r
.37385 .58496 m .37596 .58488 L .37752 .58577 L F
.379 .752 .991 r
.3783 .58461 m .37752 .58577 L .37596 .58488 L F
.3783 .58461 m .37979 .58548 L .37752 .58577 L F
.463 0 0 r
.67201 .48659 m .67493 .48805 L .67533 .48748 L F
.831 .681 .697 r
.67493 .48805 m .67781 .48719 L .67533 .48748 L F
.605 .794 .972 r
.74932 .48634 m .75288 .48691 L .75185 .48588 L F
.304 .709 .977 r
.75521 .48677 m .75185 .48588 L .75288 .48691 L F
.608 .248 .333 r
.55236 .67343 m .55116 .67549 L .54883 .67486 L F
0 0 0 r
.5534 .67381 m .55236 .67343 L .55256 .67346 L F
.55364 .67382 m .55256 .67346 L .5548 .67382 L F
.5534 .67381 m .55256 .67346 L .55364 .67382 L F
.542 .394 .629 r
.55678 .6706 m .55691 .67352 L .5548 .67382 L F
.306 .794 .886 r
.55691 .67352 m .5539 .67375 L .5548 .67382 L F
.719 .523 .624 r
.55303 .67376 m .5534 .67381 L .55311 .66968 L F
.306 .794 .886 r
.55381 .67377 m .5534 .67381 L .55364 .67382 L F
.719 .523 .624 r
.5534 .67381 m .55382 .67388 L .55381 .67377 L F
.5534 .67381 m .55381 .67377 L .55311 .66968 L F
.306 .794 .886 r
.5539 .67375 m .55309 .67381 L .5534 .67381 L F
.5539 .67375 m .5534 .67381 L .55381 .67377 L F
.5539 .67375 m .55364 .67382 L .5548 .67382 L F
.117 .107 .569 r
.55311 .66968 m .55381 .67377 L .55503 .67088 L F
.55381 .67377 m .55382 .67388 L .55387 .67376 L F
.55381 .67377 m .55387 .67376 L .55503 .67088 L F
.55382 .67388 m .55385 .67405 L .55391 .67391 L F
.306 .794 .886 r
.55691 .67352 m .55613 .67331 L .55422 .67362 L F
.117 .107 .569 r
.55387 .67376 m .55398 .67372 L .55503 .67088 L F
.719 .523 .624 r
.55303 .67376 m .55385 .67405 L .55382 .67388 L F
0 0 0 r
.55309 .67381 m .55297 .67375 L .5534 .67381 L F
.738 .799 .901 r
.55503 .67088 m .55398 .67372 L .55309 .67381 L F
.306 .794 .886 r
.5539 .67375 m .55398 .67372 L .55309 .67381 L F
.117 .107 .569 r
.55382 .67388 m .55391 .67391 L .55398 .67372 L F
.55382 .67388 m .55398 .67372 L .55387 .67376 L F
.738 .799 .901 r
.55398 .67372 m .55385 .67405 L .55309 .67381 L F
.306 .794 .886 r
.55398 .67372 m .55422 .67362 L .55309 .67381 L F
.55691 .67352 m .55422 .67362 L .5539 .67375 L F
0 0 0 r
.55297 .67375 m .55236 .67343 L .5534 .67381 L F
.55297 .67375 m .55116 .67549 L .55236 .67343 L F
.55309 .67381 m .55237 .67444 L .55297 .67375 L F
.55237 .67444 m .55116 .67549 L .55297 .67375 L F
.719 .523 .624 r
.54993 .67265 m .55298 .67374 L .55311 .66968 L F
.55298 .67374 m .55303 .67376 L .55304 .67368 L F
.55298 .67374 m .55304 .67368 L .55311 .66968 L F
.581 .365 .552 r
.78366 .51895 m .7838 .52134 L .78109 .52172 L F
.65 .417 .553 r
.78635 .52079 m .78366 .51895 L .78597 .51894 L F
.78635 .52079 m .7838 .52134 L .78366 .51895 L F
.645 .568 .753 r
.69746 .47913 m .70098 .48199 L .69992 .47843 L F
.554 .381 .601 r
.48286 .65648 m .48527 .65862 L .48476 .65651 L F
.48286 .65648 m .48275 .65915 L .48527 .65862 L F
.329 0 .015 r
.31405 .58699 m .31627 .58666 L .31781 .58492 L F
.369 0 .071 r
.31627 .58666 m .32 .58454 L .31781 .58492 L F
.367 .231 .561 r
.61107 .63574 m .60951 .63875 L .60956 .63635 L F
.189 0 0 r
.45706 .67859 m .45555 .67903 L .45491 .67893 L F
.863 .496 .352 r
.45706 .67859 m .45555 .67903 L .45406 .67617 L F
.841 .451 .311 r
.45706 .67859 m .45596 .68077 L .45555 .67903 L F
.306 .045 .344 r
.46001 .67565 m .45982 .67888 L .45706 .67859 L F
.359 0 .081 r
.45826 .68016 m .45706 .67859 L .45982 .67888 L F
.45826 .68016 m .45596 .68077 L .45706 .67859 L F
.972 .863 .469 r
.5996 .62636 m .60015 .62405 L .6006 .62478 L F
0 0 .176 r
.59861 .62969 m .59844 .62778 L .59878 .63033 L F
.59861 .62969 m .5996 .62636 L .59844 .62778 L F
.892 .863 .417 r
.59868 .62796 m .59876 .62773 L .5996 .62636 L F
0 0 0 r
.59844 .62778 m .5996 .62636 L .6004 .62506 L F
.892 .863 .417 r
.59876 .62773 m .59939 .62574 L .5996 .62636 L F
0 0 0 r
.6004 .62506 m .5996 .62636 L .6006 .62478 L F
.18 .298 .749 r
.7256 .50984 m .72786 .51181 L .72647 .50827 L F
.756 .819 .901 r
.66402 .50675 m .66525 .50802 L .66723 .5068 L F
.215 0 0 r
.37632 .63421 m .37752 .63456 L .37551 .63506 L F
.37632 .63421 m .37847 .63368 L .37752 .63456 L F
.338 0 0 r
.52721 .6342 m .53087 .63454 L .52823 .63441 L F
.745 .623 .724 r
.79027 .52089 m .79144 .52517 L .78715 .52454 L F
.638 .364 .486 r
.79028 .52625 m .79144 .52517 L .79093 .52601 L F
.789 .52555 m .78715 .52454 L .78985 .52493 L F
.79028 .52625 m .78762 .52678 L .78715 .52454 L F
.761 .485 0 r
.78715 .52454 m .78745 .52644 L .78386 .5271 L F
.78745 .52644 m .78706 .52667 L .78386 .5271 L F
.78715 .52454 m .78762 .52678 L .78745 .52644 L F
.699 .983 .841 r
.78828 .52595 m .78762 .52678 L .78677 .52693 L F
.78706 .52667 m .78677 .52693 L .78657 .52696 L F
.78828 .52595 m .78677 .52693 L .78706 .52667 L F
.771 .658 .738 r
.78635 .52079 m .78715 .52454 L .78396 .52451 L F
.761 .485 0 r
.78715 .52454 m .78386 .5271 L .78396 .52451 L F
.629 .625 .828 r
.78386 .5271 m .78694 .52669 L .78586 .52303 L F
.78694 .52669 m .78704 .5266 L .78586 .52303 L F
.78706 .52667 m .78738 .52638 L .78586 .52303 L F
.699 .983 .841 r
.78906 .52497 m .78828 .52595 L .78744 .52641 L F
.765 .655 .74 r
.79027 .52089 m .78715 .52454 L .78635 .52079 L F
.671 .646 .817 r
.78586 .52303 m .78738 .52638 L .78906 .52497 L F
.699 .983 .841 r
.78906 .52497 m .78744 .52641 L .78741 .52635 L F
.671 .646 .817 r
.78738 .52638 m .78748 .52661 L .78906 .52497 L F
.699 .983 .841 r
.78906 .52497 m .78741 .52635 L .78737 .52626 L F
0 0 0 r
.78641 .52699 m .78838 .52504 L .78899 .52498 L F
.78836 .5255 m .78899 .52498 L .78906 .52497 L F
.78641 .52699 m .78899 .52498 L .78836 .5255 L F
.629 .625 .828 r
.78694 .52669 m .78706 .52667 L .78704 .5266 L F
.761 .485 0 r
.78745 .52644 m .78748 .52661 L .78706 .52667 L F
.629 .625 .828 r
.78706 .52667 m .78748 .52661 L .78738 .52638 L F
.761 .485 0 r
.78745 .52644 m .78762 .52678 L .78748 .52661 L F
.699 .983 .841 r
.78737 .52626 m .78744 .52641 L .78641 .52699 L F
.78828 .52595 m .78657 .52696 L .78641 .52699 L F
.654 .936 .672 r
.78748 .52661 m .7875 .52663 L .78906 .52497 L F
.7875 .52663 m .78762 .52678 L .78805 .52623 L F
.7875 .52663 m .78805 .52623 L .78906 .52497 L F
.638 .364 .486 r
.79028 .52625 m .789 .52555 L .79144 .52517 L F
.789 .52555 m .78985 .52493 L .79144 .52517 L F
.252 .305 .723 r
.79199 .52539 m .79144 .52517 L .79027 .52089 L F
.45 0 .015 r
.79093 .52601 m .79144 .52517 L .79199 .52539 L F
.248 .506 .903 r
.29194 .62637 m .29299 .62804 L .29136 .62774 L F
.212 .462 .88 r
.29136 .62774 m .29371 .62914 L .29194 .62637 L F
.704 .851 .952 r
.67013 .50504 m .67332 .50511 L .67212 .50368 L F
.67 .792 .94 r
.67212 .50368 m .67332 .50511 L .67562 .50412 L F
.91 .711 .621 r
.60246 .56696 m .6038 .5703 L .60398 .56773 L F
.592 .876 .993 r
.49169 .61865 m .49419 .61778 L .49556 .61839 L F
0 .515 .826 r
.49419 .61778 m .49758 .61888 L .49556 .61839 L F
.404 .718 .988 r
.77785 .48422 m .77574 .48532 L .77482 .48408 L F
.77785 .48422 m .77903 .48548 L .77574 .48532 L F
0 0 0 r
.44867 .68618 m .44683 .68721 L .44822 .68503 L F
.44867 .68618 m .44675 .68757 L .44683 .68721 L F
.075 .634 .784 r
.50264 .63919 m .5013 .63908 L .49904 .63911 L F
.271 0 0 r
.50535 .63812 m .5013 .63908 L .50264 .63919 L F
.635 .701 .894 r
.45768 .69558 m .45866 .6972 L .4553 .69634 L F
.67 .188 .098 r
.45866 .6972 m .4581 .69813 L .4553 .69634 L F
.375 .561 .907 r
.45999 .69598 m .45866 .6972 L .45768 .69558 L F
.707 .544 .666 r
.46271 .69892 m .45909 .69974 L .45866 .6972 L F
.46271 .69892 m .4624 .69879 L .4616 .69851 L F
.4624 .69879 m .45866 .6972 L .4616 .69851 L F
.352 .521 .884 r
.45999 .69598 m .4616 .69851 L .45866 .6972 L F
.244 .457 .868 r
.46122 .6966 m .4616 .69851 L .45999 .69598 L F
.9 .913 .822 r
.46122 .6966 m .45996 .69792 L .4616 .69851 L F
.45996 .69792 m .45974 .69815 L .4616 .69851 L F
0 0 0 r
.45866 .6972 m .4581 .69813 L .45999 .69598 L F
.352 .521 .884 r
.45999 .69598 m .45866 .6972 L .4581 .69813 L F
.36 .696 .983 r
.72835 .47153 m .73048 .47169 L .7295 .47252 L F
.732 .41 .435 r
.72841 .47473 m .73192 .47528 L .7295 .47252 L F
.72841 .47473 m .7295 .47252 L .73048 .47169 L F
.978 .74 .509 r
.51849 .76637 m .51716 .76457 L .51866 .76598 L F
.51849 .76637 m .51699 .76726 L .51716 .76457 L F
0 0 .433 r
.74656 .48323 m .74475 .48055 L .74525 .48218 L F
.722 .212 .014 r
.29884 .633 m .29686 .63286 L .29483 .63104 L F
0 0 .458 r
.29884 .633 m .29897 .63275 L .29686 .63286 L F
.353 .034 .277 r
.46348 .65279 m .4655 .65285 L .46627 .65051 L F
.477 .199 .413 r
.4655 .65285 m .46828 .64965 L .46627 .65051 L F
.155 0 0 r
.55319 .5918 m .55625 .58958 L .5544 .59004 L F
.507 .56 .844 r
.41393 .59472 m .41326 .59773 L .41288 .59762 L F
.41393 .59472 m .4153 .59739 L .41326 .59773 L F
.499 .562 .851 r
.73961 .52382 m .74088 .52697 L .74301 .52657 L F
.368 .028 .251 r
.3917 .61008 m .39305 .61185 L .3938 .60915 L F
.3917 .61008 m .39088 .61244 L .39305 .61185 L F
0 0 .492 r
.56164 .63965 m .56303 .64248 L .56128 .63842 L F
.828 .625 .628 r
.61591 .59232 m .61818 .59596 L .61911 .59623 L F
.494 .314 .566 r
.77141 .50484 m .77405 .5044 L .77365 .50159 L F
.584 .536 .768 r
.77197 .50713 m .77405 .5044 L .77141 .50484 L F
.124 0 .186 r
.52293 .66472 m .52515 .66177 L .52283 .66244 L F
.261 .768 .768 r
.75544 .51266 m .75715 .51205 L .75789 .51253 L F
.419 .067 .259 r
.40289 .6194 m .40229 .62063 L .40016 .62105 L F
.424 .113 .331 r
.40498 .61874 m .40229 .62063 L .40289 .6194 L F
.38 .7 .984 r
.67892 .50513 m .68011 .50396 L .67792 .50403 L F
.67892 .50513 m .68114 .50512 L .68011 .50396 L F
.669 .382 .477 r
.57984 .67774 m .5856 .67677 L .58437 .67639 L F
.57984 .67774 m .58192 .67781 L .5856 .67677 L F
.632 .942 .956 r
.58437 .67639 m .5856 .67677 L .58737 .67562 L F
.936 .903 .767 r
.6856 .50055 m .68482 .50447 L .68621 .50126 L F
.6856 .50055 m .68385 .50349 L .68482 .50447 L F
.247 .563 .936 r
.44882 .70975 m .44968 .71102 L .44985 .70982 L F
.264 0 0 r
.45284 .71042 m .45198 .71075 L .44968 .71102 L F
0 0 0 r
.44968 .71102 m .45039 .71107 L .44985 .70982 L F
.44968 .71102 m .45198 .71075 L .45039 .71107 L F
.363 .24 .576 r
.42984 .6879 m .43168 .68973 L .43165 .6872 L F
.42984 .6879 m .43009 .69064 L .43168 .68973 L F
0 0 0 r
.70832 .47785 m .71069 .47731 L .71164 .47666 L F
.405 0 0 r
.71069 .47731 m .7139 .47754 L .71164 .47666 L F
.657 .309 .373 r
.29719 .62767 m .29925 .62971 L .29964 .62764 L F
.422 .2 .47 r
.29964 .62764 m .30194 .62735 L .30235 .62479 L F
.21 0 .25 r
.29964 .62764 m .3012 .62861 L .30194 .62735 L F
.29964 .62764 m .29925 .62971 L .3012 .62861 L F
.366 .211 .535 r
.52591 .64901 m .52785 .64793 L .52497 .64814 L F
.52591 .64901 m .52848 .64807 L .52785 .64793 L F
.518 .212 .388 r
.52376 .65227 m .52848 .64807 L .52591 .64901 L F
.492 .316 .571 r
.78109 .52172 m .78122 .52445 L .77887 .52496 L F
.584 .536 .768 r
.77197 .50713 m .77445 .50649 L .77405 .5044 L F
.52 .494 .768 r
.77197 .50713 m .77513 .50826 L .77445 .50649 L F
.731 .266 .145 r
.45779 .71039 m .46113 .71123 L .45991 .7125 L F
.717 .248 .135 r
.46113 .71123 m .46347 .71338 L .45991 .7125 L F
.628 .531 .725 r
.79247 .4931 m .79041 .49404 L .78927 .4901 L F
.544 .592 .853 r
.7913 .48837 m .78927 .4901 L .788 .48783 L F
.7913 .48837 m .79167 .48971 L .78927 .4901 L F
.628 .531 .725 r
.79247 .4931 m .78927 .4901 L .79167 .48971 L F
.772 .598 .663 r
.6038 .5703 m .60354 .57303 L .60739 .57328 L F
.824 .581 .572 r
.60387 .57494 m .60739 .57328 L .60354 .57303 L F
.60387 .57494 m .60732 .57567 L .60739 .57328 L F
.448 .479 .798 r
.41393 .59472 m .41288 .59762 L .41124 .59334 L F
.804 .638 .675 r
.55055 .64168 m .5472 .64149 L .54956 .64146 L F
.447 .875 .919 r
.55055 .64168 m .54956 .64146 L .55207 .64065 L F
.55055 .64168 m .54956 .64146 L .55207 .64065 L F
.597 .642 .865 r
.51326 .64847 m .51699 .6505 L .51618 .64851 L F
.745 .782 .883 r
.51618 .64851 m .51699 .6505 L .51907 .64794 L F
.666 .654 .828 r
.51907 .64794 m .51699 .6505 L .5194 .6499 L F
.728 .486 .56 r
.51699 .6505 m .52039 .65251 L .5194 .6499 L F
.51699 .6505 m .51681 .65309 L .52039 .65251 L F
.607 .418 .601 r
.58861 .58192 m .58875 .58422 L .58639 .58397 L F
.587 .287 .427 r
.58875 .58422 m .5853 .58703 L .58639 .58397 L F
.799 .93 .92 r
.48211 .67267 m .48541 .67062 L .48418 .66981 L F
.663 .48 .627 r
.48211 .67267 m .48537 .67362 L .48541 .67062 L F
.507 .393 .658 r
.42156 .70197 m .42495 .70346 L .42259 .70152 L F
.42156 .70197 m .42156 .7051 L .42495 .70346 L F
.278 .087 .433 r
.48308 .63064 m .48283 .63293 L .48469 .62982 L F
.629 .435 .601 r
.58861 .58192 m .5903 .58151 L .58875 .58422 L F
.292 0 0 r
.4529 .70174 m .45551 .70261 L .45652 .70271 L F
.127 .545 .92 r
.45841 .7024 m .45652 .70271 L .45551 .70261 L F
.45841 .7024 m .45936 .70323 L .45652 .70271 L F
0 0 .573 r
.52057 .76501 m .52163 .76831 L .52047 .76516 L F
.997 .783 .484 r
.52063 .76978 m .52163 .76831 L .52057 .76501 L F
.699 .282 .252 r
.52063 .76978 m .52428 .77024 L .52163 .76831 L F
.332 .811 .772 r
.54054 .5974 m .53821 .59825 L .53738 .59838 L F
.551 .217 .355 r
.42116 .60738 m .42296 .60919 L .42022 .60967 L F
.42116 .60738 m .42353 .60737 L .42296 .60919 L F
0 0 .414 r
.53624 .61627 m .53721 .61737 L .53512 .61531 L F
.53624 .61627 m .53684 .61831 L .53721 .61737 L F
.812 .648 .679 r
.60911 .57851 m .61229 .57916 L .61086 .57598 L F
.85 .644 .624 r
.60916 .58097 m .61229 .57916 L .60911 .57851 L F
.60916 .58097 m .61218 .58163 L .61229 .57916 L F
.586 .607 .841 r
.49354 .67671 m .48957 .67832 L .48963 .67733 L F
.49354 .67671 m .48963 .67733 L .48964 .67716 L F
.487 .303 .557 r
.49341 .67635 m .49354 .67671 L .49326 .67674 L F
.171 .129 .565 r
.49408 .67535 m .49354 .67671 L .49224 .67301 L F
0 0 .07 r
.49408 .67535 m .49325 .67675 L .49354 .67671 L F
.49325 .67675 m .49217 .67859 L .49354 .67671 L F
.49326 .67675 m .49323 .67681 L .49217 .67859 L F
.586 .607 .841 r
.49322 .67684 m .49217 .67859 L .48957 .67832 L F
.49354 .67671 m .49217 .67859 L .49322 .67684 L F
0 0 .07 r
.49323 .67681 m .49274 .67806 L .49217 .67859 L F
.49408 .67535 m .49349 .67738 L .49274 .67806 L F
.49408 .67535 m .49274 .67806 L .49326 .67675 L F
.487 .303 .557 r
.49224 .67301 m .49341 .67635 L .48964 .67716 L F
.49341 .67635 m .49326 .67674 L .48964 .67716 L F
.433 .672 .963 r
.20626 .54893 m .20579 .55059 L .20437 .54907 L F
.46 .699 .971 r
.20626 .54893 m .20777 .55039 L .20579 .55059 L F
.081 .247 .735 r
.56978 .6327 m .57199 .63487 L .57122 .63601 L F
.026 .166 .674 r
.57199 .63487 m .57294 .6383 L .57122 .63601 L F
.819 .68 .136 r
.55877 .65524 m .55857 .65918 L .55879 .65863 L F
.314 .356 .745 r
.55857 .65918 m .55754 .66187 L .55879 .65863 L F
.449 .092 .266 r
.37517 .62083 m .37812 .61898 L .37593 .61942 L F
0 .066 .619 r
.49134 .67043 m .49305 .67283 L .49224 .67301 L F
.171 .129 .565 r
.49408 .67535 m .49224 .67301 L .49305 .67283 L F
.437 .606 .918 r
.54239 .63778 m .54115 .63961 L .54016 .63803 L F
.54239 .63778 m .54442 .64012 L .54115 .63961 L F
.503 .419 .693 r
.70444 .48496 m .70617 .48079 L .70345 .4813 L F
.70444 .48496 m .70662 .48418 L .70617 .48079 L F
.538 .525 .789 r
.70444 .48496 m .70701 .48623 L .70662 .48418 L F
.535 .209 .362 r
.38968 .62761 m .38859 .6302 L .38628 .63021 L F
.31 0 .253 r
.39078 .62928 m .38968 .62761 L .39192 .62693 L F
.39078 .62928 m .38859 .6302 L .38968 .62761 L F
.585 .322 .484 r
.29687 .62984 m .29719 .62767 L .29726 .62594 L F
.29687 .62984 m .29925 .62971 L .29719 .62767 L F
.351 0 .206 r
.58084 .58799 m .5831 .58742 L .58021 .5893 L F
.725 .723 .848 r
.29575 .63881 m .29953 .64024 L .29815 .63845 L F
.302 .387 .784 r
.29953 .64024 m .30037 .63785 L .29815 .63845 L F
.571 .783 .979 r
.35643 .58479 m .3528 .58411 L .35495 .58383 L F
.472 .785 .998 r
.35706 .5835 m .35643 .58479 L .35495 .58383 L F
.35706 .5835 m .35851 .58445 L .35643 .58479 L F
.859 .897 .861 r
.47887 .66422 m .4784 .66495 L .48098 .66233 L F
.628 .547 .744 r
.69992 .47843 m .70098 .48199 L .70345 .4813 L F
0 0 0 r
.718 .49039 m .71501 .49362 L .71677 .49195 L F
.472 .454 .757 r
.71501 .49362 m .71775 .49475 L .71677 .49195 L F
.622 .418 .585 r
.4911 .65612 m .4935 .65641 L .49353 .65345 L F
.611 .443 .629 r
.49353 .65345 m .49546 .65343 L .49591 .65083 L F
.462 .232 .478 r
.4935 .65641 m .49546 .65343 L .49353 .65345 L F
.453 .856 .968 r
.79174 .52077 m .79608 .52064 L .79445 .51772 L F
.746 .736 .842 r
.79445 .51772 m .79608 .52064 L .79783 .51803 L F
.872 .711 .68 r
.6022 .60205 m .59864 .60415 L .60103 .60113 L F
.6022 .60205 m .60104 .60412 L .59864 .60415 L F
.968 .646 .294 r
.6022 .60205 m .60103 .60113 L .60061 .5986 L F
.799 .93 .92 r
.48211 .67267 m .48418 .66981 L .48204 .6709 L F
.664 .477 .622 r
.48211 .67267 m .4839 .67638 L .48537 .67362 L F
.611 .864 .514 r
.48046 .66946 m .48196 .66782 L .48005 .67013 L F
.037 0 0 r
.48486 .66679 m .48196 .66782 L .48046 .66946 L F
.582 .3 .454 r
.41813 .61034 m .41523 .61258 L .41573 .61075 L F
.431 .066 .243 r
.5295 .60363 m .5323 .6012 L .53011 .60172 L F
.383 .234 .552 r
.21081 .57578 m .21083 .5783 L .20897 .57897 L F
.237 0 .338 r
.21083 .5783 m .20881 .58139 L .20897 .57897 L F
.057 0 .363 r
.61457 .62144 m .61443 .62318 L .61317 .625 L F
0 0 0 r
.61317 .625 m .61367 .62578 L .61232 .62716 L F
.61317 .625 m .61443 .62318 L .61367 .62578 L F
.591 .315 .467 r
.42662 .6052 m .42604 .6076 L .42353 .60737 L F
.58 .362 .55 r
.42908 .60419 m .42662 .6052 L .4272 .6042 L F
.42908 .60419 m .42898 .60552 L .42662 .6052 L F
.381 .123 .393 r
.42784 .60846 m .42662 .6052 L .42898 .60552 L F
.42784 .60846 m .42604 .6076 L .42662 .6052 L F
.647 .563 .746 r
.79295 .49539 m .79403 .49871 L .7908 .49865 L F
.593 .505 .725 r
.79416 .50104 m .7908 .49865 L .79403 .49871 L F
.79416 .50104 m .79167 .50168 L .7908 .49865 L F
.568 .931 .932 r
.75018 .52863 m .75104 .52742 L .74894 .52795 L F
.75018 .52863 m .75246 .52759 L .75104 .52742 L F
.43 .061 .234 r
.56422 .58431 m .56665 .58403 L .56756 .58185 L F
.394 .052 .263 r
.569 .58361 m .56756 .58185 L .56665 .58403 L F
.569 .58361 m .56986 .5813 L .56756 .58185 L F
.484 .16 .342 r
.39422 .60754 m .3962 .60862 L .39661 .60735 L F
.39422 .60754 m .3938 .60915 L .3962 .60862 L F
.532 .455 .714 r
.77365 .50159 m .77547 .49783 L .77305 .49837 L F
.77365 .50159 m .77602 .50116 L .77547 .49783 L F
.569 .366 .566 r
.77365 .50159 m .77655 .50371 L .77602 .50116 L F
.77365 .50159 m .77405 .5044 L .77655 .50371 L F
.321 0 .225 r
.46082 .65598 m .45876 .65665 L .45802 .65828 L F
0 .424 .798 r
.20265 .54807 m .20225 .5483 L .20053 .54788 L F
.20265 .54807 m .20437 .54907 L .20225 .5483 L F
.19 .581 .94 r
.55608 .65206 m .55789 .65241 L .55815 .6533 L F
.852 .758 .759 r
.55789 .65241 m .55877 .65524 L .55815 .6533 L F
.513 .403 .666 r
.29152 .6011 m .29366 .60423 L .29378 .60042 L F
.29152 .6011 m .29181 .6048 L .29366 .60423 L F
.896 .672 .591 r
.47321 .67055 m .47148 .67274 L .47263 .67008 L F
.47321 .67055 m .47354 .67321 L .47148 .67274 L F
.95 .688 .231 r
.47259 .6677 m .47321 .67055 L .47263 .67008 L F
.333 .755 .976 r
.47321 .67055 m .47615 .67053 L .47354 .67321 L F
.514 .343 .588 r
.50216 .64951 m .50424 .65159 L .50382 .64999 L F
.50216 .64951 m .50195 .65215 L .50424 .65159 L F
.50216 .64951 m .50424 .65159 L .50382 .64999 L F
.50216 .64951 m .50195 .65215 L .50424 .65159 L F
.582 .567 .802 r
.5092 .77003 m .50799 .7741 L .50697 .77235 L F
.099 .307 .784 r
.50799 .7741 m .50895 .77296 L .50697 .77235 L F
.50799 .7741 m .51023 .77577 L .50895 .77296 L F
0 .418 .717 r
.44882 .70975 m .44388 .70825 L .44664 .70974 L F
.863 .994 .82 r
.73905 .50553 m .7372 .50774 L .73778 .50564 L F
0 0 .163 r
.73655 .50945 m .73778 .50564 L .7372 .50774 L F
.609 .075 0 r
.76862 .51172 m .77217 .51234 L .76953 .51075 L F
0 .291 .729 r
.72675 .4936 m .72921 .49494 L .72946 .49533 L F
.745 .493 .549 r
.72704 .49802 m .72946 .49533 L .72921 .49494 L F
.72704 .49802 m .72946 .49975 L .72946 .49533 L F
.553 .103 .137 r
.45536 .7105 m .45198 .71075 L .45284 .71042 L F
.405 .105 .338 r
.46348 .65279 m .46506 .65482 L .4655 .65285 L F
.46348 .65279 m .46293 .65538 L .46506 .65482 L F
.67 .878 .976 r
.4616 .69851 m .45909 .69974 L .46271 .69892 L F
.859 .897 .861 r
.47887 .66422 m .48098 .66233 L .47701 .66142 L F
.643 .249 .283 r
.29135 .64435 m .29348 .64657 L .2945 .64431 L F
.29135 .64435 m .28996 .64654 L .29348 .64657 L F
.633 .627 .827 r
.42784 .60177 m .4272 .6042 L .42571 .60213 L F
.42784 .60177 m .42908 .60419 L .4272 .6042 L F
.751 .371 .335 r
.30037 .63785 m .3035 .63856 L .30198 .63622 L F
.30037 .63785 m .3035 .63856 L .30198 .63622 L F
.386 .054 .275 r
.40798 .61603 m .40713 .61817 L .40498 .61874 L F
.488 .176 .364 r
.41035 .61554 m .40713 .61817 L .40798 .61603 L F
.494 .872 .977 r
.76142 .51225 m .75789 .51253 L .76035 .51164 L F
.374 .774 .985 r
.7628 .51142 m .76142 .51225 L .76035 .51164 L F
.7628 .51142 m .76369 .51211 L .76142 .51225 L F
.694 .52 .648 r
.49591 .65083 m .49546 .65343 L .49926 .65315 L F
.283 0 0 r
.49758 .61888 m .50024 .61989 L .50095 .62007 L F
.698 .178 0 r
.50024 .61989 m .50341 .62109 L .50095 .62007 L F
.482 .275 .522 r
.45151 .67884 m .4511 .68141 L .44892 .68133 L F
.625 .386 .535 r
.45144 .68406 m .44892 .68133 L .4511 .68141 L F
.45144 .68406 m .44822 .68503 L .44892 .68133 L F
0 .276 .734 r
.51207 .64196 m .51121 .64107 L .50835 .6393 L F
.001 0 0 r
.50906 .64417 m .51079 .64351 L .51207 .64196 L F
1 .832 .52 r
.51207 .64196 m .51079 .64351 L .51121 .64107 L F
.201 .724 .855 r
.3591 .59717 m .35956 .59676 L .35735 .59717 L F
.3591 .59717 m .3611 .5969 L .35956 .59676 L F
.758 .6 .68 r
.70584 .47591 m .70577 .47838 L .70819 .4763 L F
.495 .198 .392 r
.70819 .4763 m .70577 .47838 L .70832 .47785 L F
.733 .737 .854 r
.72366 .49253 m .72675 .4936 L .72712 .48995 L F
.627 .069 0 r
.72366 .49253 m .72606 .49419 L .72675 .4936 L F
.823 .815 .842 r
.72712 .48995 m .72675 .4936 L .72958 .49027 L F
.929 .927 .785 r
.72602 .4991 m .72606 .49419 L .72459 .49708 L F
.72602 .4991 m .72704 .49802 L .72599 .49698 L F
1 .816 .509 r
.72599 .49698 m .72704 .49802 L .72674 .49941 L F
.745 .493 .549 r
.72704 .49802 m .72921 .49494 L .73018 .49744 L F
.538 .302 .506 r
.72679 .4992 m .73018 .49744 L .72704 .49802 L F
.72674 .49941 m .72717 .49916 L .72679 .4992 L F
.72717 .49916 m .73018 .49744 L .72679 .4992 L F
.548 0 0 r
.72648 .49383 m .72909 .49491 L .72675 .4936 L F
.72606 .49419 m .72856 .49479 L .72648 .49383 L F
.72856 .49479 m .72909 .49491 L .72648 .49383 L F
.482 .383 .667 r
.72921 .49494 m .73018 .49744 L .73216 .49649 L F
.368 .155 .453 r
.73018 .49744 m .72994 .49895 L .73216 .49649 L F
.563 .418 .641 r
.73173 .49624 m .72993 .49889 L .73216 .49649 L F
.548 0 0 r
.72909 .49491 m .72921 .49494 L .72917 .49492 L F
.578 .435 .651 r
.72704 .49802 m .73018 .49744 L .72921 .49494 L F
.077 .414 .864 r
.72893 .49458 m .73216 .49649 L .72921 .49494 L F
.563 .418 .641 r
.72893 .49458 m .72903 .495 L .73173 .49624 L F
.538 .302 .506 r
.72674 .49941 m .72994 .49895 L .73018 .49744 L F
.563 .418 .641 r
.72903 .495 m .72993 .49889 L .73173 .49624 L F
.72993 .49889 m .72994 .49895 L .73 .49889 L F
.72993 .49889 m .73 .49889 L .73216 .49649 L F
.929 .927 .785 r
.72602 .4991 m .72599 .49698 L .72606 .49419 L F
.572 .423 .641 r
.72674 .49941 m .72879 .49489 L .72599 .49698 L F
.772 .541 .585 r
.72606 .49419 m .72893 .49458 L .72921 .49494 L F
.572 .423 .641 r
.72879 .49489 m .72893 .49458 L .72856 .49488 L F
.72879 .49489 m .72856 .49488 L .72599 .49698 L F
.548 0 0 r
.72909 .49491 m .72917 .49492 L .72675 .4936 L F
.468 .063 .188 r
.49217 .67859 m .48893 .6809 L .48957 .67832 L F
.637 .455 .621 r
.50998 .67204 m .51018 .67379 L .51243 .67309 L F
.51243 .67309 m .51018 .67379 L .50998 .67204 L F
.307 0 .074 r
.30086 .59242 m .30305 .59191 L .30395 .59063 L F
.442 .075 .244 r
.30305 .59191 m .30605 .5901 L .30395 .59063 L F
.035 0 0 r
.59539 .67223 m .59108 .67439 L .59316 .67276 L F
.367 .788 .975 r
.37979 .58548 m .38204 .58524 L .38336 .5859 L F
.218 .71 .921 r
.38204 .58524 m .38596 .58574 L .38336 .5859 L F
.902 .862 .791 r
.58807 .65041 m .5864 .65343 L .58491 .65251 L F
0 .158 .684 r
.58607 .65578 m .58491 .65251 L .5864 .65343 L F
.412 0 0 r
.51619 .63184 m .51511 .63106 L .51411 .62952 L F
.51619 .63184 m .51756 .63276 L .51511 .63106 L F
.489 0 0 r
.51511 .63106 m .51756 .63276 L .51894 .63341 L F
.63 .793 .96 r
.45407 .69508 m .4553 .69634 L .45768 .69558 L F
.45768 .69558 m .4553 .69634 L .45407 .69508 L F
.45407 .69508 m .45768 .69558 L .4564 .69476 L F
.239 .411 .832 r
.4553 .69634 m .4564 .69476 L .45407 .69508 L F
.4553 .69634 m .4581 .69813 L .4564 .69476 L F
.877 .827 .795 r
.72211 .48436 m .7201 .48742 L .71884 .4861 L F
.508 .91 .899 r
.7238 .48107 m .7259 .47978 L .72601 .47743 L F
.7238 .48107 m .72432 .48048 L .7259 .47978 L F
0 0 .224 r
.72211 .48436 m .72373 .48281 L .72432 .48048 L F
.684 .499 .631 r
.72141 .48488 m .72373 .48281 L .72211 .48436 L F
.72141 .48488 m .72368 .48524 L .72373 .48281 L F
.03 .582 .828 r
.72141 .48488 m .72368 .48524 L .72161 .48483 L F
.72141 .48488 m .72161 .48483 L .72024 .48456 L F
.877 .827 .795 r
.72211 .48436 m .72084 .48503 L .72141 .48488 L F
.72084 .48503 m .71884 .4861 L .72141 .48488 L F
.351 .78 .971 r
.33767 .58279 m .33977 .58245 L .34079 .583 L F
.197 .67 .936 r
.34185 .5825 m .34079 .583 L .33977 .58245 L F
.34185 .5825 m .34326 .58317 L .34079 .583 L F
.509 .769 .99 r
.39281 .58796 m .38919 .58714 L .3914 .58667 L F
.468 .759 .994 r
.39357 .58655 m .39281 .58796 L .3914 .58667 L F
.39357 .58655 m .39505 .58771 L .39281 .58796 L F
0 .184 .718 r
.50975 .62522 m .50823 .62484 L .50696 .62397 L F
.628 .081 0 r
.50823 .62484 m .51036 .62688 L .51177 .62768 L F
0 .184 .718 r
.50975 .62522 m .51036 .62688 L .50823 .62484 L F
0 .321 .803 r
.54313 .62274 m .54457 .62281 L .54191 .62167 L F
.54313 .62274 m .54551 .62422 L .54457 .62281 L F
.632 .563 .759 r
.79868 .50763 m .79636 .50837 L .795 .5048 L F
.573 .448 .672 r
.79887 .50968 m .79636 .50837 L .79868 .50763 L F
.79887 .50968 m .79648 .51037 L .79636 .50837 L F
.922 .581 .377 r
.54994 .64466 m .55048 .64707 L .55222 .64763 L F
.954 .669 .226 r
.55167 .64855 m .55222 .64763 L .55048 .64707 L F
.55167 .64855 m .55244 .64994 L .55222 .64763 L F
.855 .632 .599 r
.59739 .5873 m .59435 .58928 L .59459 .58671 L F
.59739 .5873 m .59658 .58991 L .59435 .58928 L F
.636 .47 .642 r
.49927 .65562 m .49698 .65869 L .49732 .65633 L F
0 0 .437 r
.57055 .66169 m .57024 .65816 L .56916 .65969 L F
.129 .317 .785 r
.57673 .65303 m .579 .65503 L .57816 .65617 L F
.128 .171 .637 r
.579 .65503 m .57863 .6577 L .57816 .65617 L F
.08 .477 .893 r
.57836 .67548 m .5743 .67297 L .57642 .67542 L F
.052 0 0 r
.36477 .59648 m .36309 .59681 L .3611 .5969 L F
.256 .767 .823 r
.36722 .59625 m .36309 .59681 L .36477 .59648 L F
.569 .344 .534 r
.57806 .57836 m .58054 .57574 L .57816 .57614 L F
0 0 .05 r
.4854 .62783 m .48469 .62982 L .48647 .62656 L F
.589 .39 .58 r
.7838 .52134 m .78122 .52445 L .78109 .52172 L F
.46 .36 .655 r
.43064 .67894 m .43303 .68109 L .43273 .67855 L F
.43064 .67894 m .43065 .6827 L .43303 .68109 L F
.923 .731 .624 r
.68639 .49445 m .68835 .49301 L .68509 .49221 L F
.68639 .49445 m .68798 .49542 L .68835 .49301 L F
.909 .684 .586 r
.59868 .59314 m .59658 .58991 L .59968 .59053 L F
.807 .819 .861 r
.3831 .59373 m .38673 .59551 L .38379 .5938 L F
.3831 .59373 m .38335 .59578 L .38673 .59551 L F
.268 .633 .963 r
.38673 .59551 m .38559 .59342 L .38379 .5938 L F
.327 .595 .943 r
.38831 .59564 m .39013 .59569 L .38915 .59429 L F
.38831 .59564 m .38915 .59429 L .38895 .5951 L F
.268 .633 .963 r
.38673 .59551 m .38895 .5951 L .38559 .59342 L F
.245 .697 .954 r
.38831 .59564 m .38895 .5951 L .38673 .59551 L F
.418 .132 .37 r
.56029 .6451 m .56253 .64438 L .56303 .64248 L F
.227 .373 .803 r
.56128 .63842 m .56303 .64248 L .56414 .64058 L F
0 0 .042 r
.56253 .64438 m .56414 .64058 L .56303 .64248 L F
.881 .992 .76 r
.55085 .66354 m .55049 .66525 L .55219 .66311 L F
.355 0 0 r
.55219 .66311 m .55472 .66376 L .55085 .66354 L F
.312 0 0 r
.36755 .63782 m .36398 .6386 L .36551 .63809 L F
.461 0 0 r
.48699 .70962 m .48922 .70979 L .49046 .70894 L F
.462 0 0 r
.49046 .70894 m .48922 .70979 L .49292 .70973 L F
.628 .547 .744 r
.69992 .47843 m .70345 .4813 L .70226 .47744 L F
.667 .523 .679 r
.70226 .47744 m .70577 .47838 L .70584 .47591 L F
.668 .521 .675 r
.70226 .47744 m .70345 .4813 L .70577 .47838 L F
.481 .188 .391 r
.40016 .62105 m .39923 .62419 L .39698 .6245 L F
.405 .101 .332 r
.40229 .62063 m .39923 .62419 L .40016 .62105 L F
.565 .516 .759 r
.77305 .49837 m .77489 .49576 L .77247 .49633 L F
.77305 .49837 m .77547 .49783 L .77489 .49576 L F
.756 .819 .901 r
.66402 .50675 m .66723 .5068 L .66627 .50437 L F
.723 .772 .892 r
.66627 .50437 m .66723 .5068 L .67013 .50504 L F
.497 0 0 r
.43291 .70393 m .43164 .70469 L .42956 .70422 L F
.157 .695 .827 r
.43527 .70376 m .43395 .70363 L .43291 .70393 L F
0 0 0 r
.43395 .70363 m .43164 .70469 L .43291 .70393 L F
.776 .304 .119 r
.75058 .47805 m .75285 .48031 L .75371 .4795 L F
.462 0 0 r
.75285 .48031 m .75648 .48034 L .75371 .4795 L F
.445 .581 .895 r
.34517 .62259 m .34419 .62461 L .34234 .62232 L F
.34517 .62259 m .34582 .62423 L .34419 .62461 L F
.065 .618 .82 r
.4616 .69851 m .4581 .69813 L .45909 .69974 L F
.32 .513 .889 r
.42654 .60072 m .42571 .60213 L .4248 .60001 L F
.512 .758 .985 r
.42654 .60072 m .42784 .60177 L .42571 .60213 L F
.869 .821 .798 r
.7201 .48742 m .71654 .48936 L .71884 .4861 L F
.7201 .48742 m .718 .49039 L .71654 .48936 L F
.662 .476 .622 r
.5903 .58151 m .59063 .58465 L .58875 .58422 L F
.932 .765 .653 r
.60121 .61547 m .60305 .61654 L .60221 .6187 L F
.902 .862 .791 r
.58807 .65041 m .58491 .65251 L .58768 .64988 L F
0 .509 .764 r
.54905 .62497 m .54551 .62422 L .54695 .62479 L F
.199 .425 .855 r
.42766 .69523 m .42843 .69614 L .42982 .69635 L F
.262 .318 .733 r
.42982 .69635 m .42843 .69614 L .43069 .69799 L F
.485 .259 .495 r
.59082 .56744 m .59329 .56901 L .59429 .56646 L F
.287 0 0 r
.59429 .56646 m .59525 .56695 L .59674 .56643 L F
.15 0 .15 r
.59429 .56646 m .59329 .56901 L .59525 .56695 L F
.387 .156 .437 r
.53514 .7075 m .53746 .70466 L .53495 .70537 L F
.762 .788 .875 r
.55958 .60155 m .55697 .60292 L .55794 .60299 L F
.757 .293 .143 r
.42781 .69998 m .42689 .69783 L .42487 .70086 L F
.42781 .69998 m .42852 .69937 L .42689 .69783 L F
.741 .221 0 r
.51036 .62688 m .51411 .62952 L .51177 .62768 L F
0 .378 .825 r
.72364 .50507 m .72489 .50339 L .72265 .50346 L F
.72364 .50507 m .7252 .50524 L .72489 .50339 L F
.72364 .50507 m .72662 .50654 L .7252 .50524 L F
.386 0 .112 r
.51326 .64847 m .51226 .65015 L .51016 .65027 L F
.452 .03 .147 r
.51618 .64851 m .51226 .65015 L .51326 .64847 L F
.859 .607 .557 r
.6122 .58658 m .61381 .58469 L .61209 .58412 L F
.6122 .58658 m .61384 .58711 L .61381 .58469 L F
.707 .355 .378 r
.48019 .71309 m .47884 .7153 L .47915 .71377 L F
.625 .259 .329 r
.48237 .71503 m .48019 .71309 L .48247 .71347 L F
.48237 .71503 m .47884 .7153 L .48019 .71309 L F
.652 .636 .822 r
.70701 .48623 m .70821 .48799 L .7107 .48705 L F
.359 .137 .434 r
.59038 .63543 m .59052 .6332 L .58822 .63616 L F
.234 .033 .389 r
.58825 .63853 m .59038 .63543 L .58822 .63616 L F
.287 .469 .865 r
.73185 .50912 m .73442 .51196 L .73047 .51059 L F
.625 .428 .595 r
.50873 .65849 m .51154 .65579 L .50918 .65653 L F
.06 0 0 r
.54795 .59493 m .54907 .59349 L .54606 .59523 L F
.008 0 0 r
.54964 .59384 m .54907 .59349 L .54795 .59493 L F
.54964 .59384 m .55138 .59301 L .54907 .59349 L F
.252 .305 .723 r
.79199 .52539 m .79027 .52089 L .79174 .52077 L F
.425 .532 .863 r
.30003 .61868 m .30171 .62191 L .30292 .62024 L F
.346 .421 .797 r
.30171 .62191 m .30424 .62362 L .30292 .62024 L F
.471 .416 .715 r
.30171 .62191 m .30235 .62479 L .30424 .62362 L F
.612 .597 .811 r
.47698 .6665 m .47615 .67053 L .4764 .66767 L F
0 .153 .606 r
.4712 .66394 m .47139 .66412 L .4676 .66129 L F
.803 .536 .534 r
.55754 .66187 m .55807 .66434 L .55472 .66376 L F
.314 .356 .745 r
.55857 .65918 m .5596 .66061 L .55754 .66187 L F
.158 .12 .562 r
.55976 .66299 m .55754 .66187 L .55949 .66067 L F
.55976 .66299 m .55807 .66434 L .55754 .66187 L F
.699 .589 .73 r
.55976 .66299 m .5566 .66589 L .55807 .66434 L F
.55976 .66299 m .5594 .66703 L .5566 .66589 L F
.026 0 .486 r
.55976 .66299 m .5601 .66554 L .5594 .66703 L F
.902 .522 .077 r
.55814 .66199 m .56006 .66547 L .55976 .66299 L F
.56006 .66547 m .5601 .66554 L .55976 .66299 L F
.158 .12 .562 r
.55976 .66299 m .55949 .66067 L .5596 .66061 L F
.607 .038 0 r
.51121 .64107 m .50678 .63869 L .50835 .6393 L F
.945 .667 .481 r
.47696 .66401 m .47887 .66422 L .47701 .66142 L F
.956 .756 .592 r
.47696 .66401 m .47698 .6665 L .47887 .66422 L F
.488 .244 .47 r
.37812 .61898 m .38044 .61856 L .38051 .61578 L F
.383 .07 .305 r
.38044 .61856 m .38342 .6154 L .38051 .61578 L F
.638 .627 .823 r
.65537 .49332 m .65905 .49581 L .65783 .49248 L F
.492 .553 .846 r
.65783 .49248 m .65905 .49581 L .66038 .49402 L F
.169 .246 .701 r
.8014 .5154 m .80066 .51607 L .79974 .51311 L F
0 0 0 r
.8014 .5154 m .80052 .51662 L .80066 .51607 L F
.616 .357 .501 r
.58835 .56985 m .59094 .56964 L .59082 .56744 L F
.485 .259 .495 r
.59082 .56744 m .59094 .56964 L .59329 .56901 L F
.793 .367 .236 r
.54442 .64012 m .5472 .64149 L .54493 .64089 L F
.489 .312 .567 r
.43238 .67608 m .43455 .67295 L .43232 .67345 L F
.358 .085 .355 r
.46069 .678 m .46001 .67565 L .462 .67557 L F
.46069 .678 m .45982 .67888 L .46001 .67565 L F
.618 .621 .831 r
.29371 .62914 m .29483 .63104 L .29687 .62984 L F
.493 .355 .622 r
.29483 .63104 m .29686 .63286 L .29687 .62984 L F
.512 .332 .573 r
.66004 .48673 m .66017 .48949 L .66267 .4861 L F
.512 .674 .937 r
.40351 .58848 m .40222 .59034 L .40127 .58875 L F
.40351 .58848 m .40435 .59014 L .40222 .59034 L F
.863 .476 .308 r
.47358 .70748 m .47219 .70551 L .47179 .70662 L F
.818 .733 .771 r
.73192 .47528 m .72934 .47797 L .73281 .47849 L F
.758 .497 .538 r
.72982 .48006 m .73281 .47849 L .72934 .47797 L F
.909 .684 .586 r
.59868 .59314 m .59636 .5923 L .59658 .58991 L F
.947 .761 .618 r
.59868 .59314 m .59643 .59459 L .59636 .5923 L F
.59868 .59314 m .59784 .59499 L .59643 .59459 L F
.875 .986 .714 r
.28934 .64793 m .28844 .64853 L .28841 .64811 L F
.354 .244 .588 r
.28844 .64853 m .28996 .64654 L .28934 .64793 L F
0 0 0 r
.76384 .52397 m .76311 .52431 L .7598 .52556 L F
.76536 .52363 m .76384 .52397 L .7663 .52393 L F
.76536 .52363 m .76311 .52431 L .76384 .52397 L F
.808 .998 .847 r
.73905 .50553 m .74019 .50345 L .74122 .50463 L F
.73905 .50553 m .73778 .50564 L .74019 .50345 L F
.484 .633 .919 r
.55431 .64471 m .55673 .64478 L .55564 .64303 L F
.55564 .64303 m .55673 .64478 L .55431 .64471 L F
.158 .592 .934 r
.4392 .70437 m .44081 .70459 L .43797 .70333 L F
.089 .479 .895 r
.48005 .67013 m .48204 .6709 L .48046 .66946 L F
.18 .488 .901 r
.55142 .62725 m .55177 .62606 L .54905 .62497 L F
.063 .35 .824 r
.55142 .62725 m .55418 .62881 L .55177 .62606 L F
.516 .708 .958 r
.78703 .48629 m .78551 .48801 L .78463 .48647 L F
.78703 .48629 m .788 .48783 L .78551 .48801 L F
.812 .648 .679 r
.60728 .57806 m .61086 .57598 L .60732 .57567 L F
.60728 .57806 m .60911 .57851 L .61086 .57598 L F
.437 0 .022 r
.32559 .5829 m .32778 .58304 L .32591 .58247 L F
.493 .262 .492 r
.30235 .62479 m .30424 .62673 L .30424 .62362 L F
.30235 .62479 m .30194 .62735 L .30424 .62673 L F
0 .006 .582 r
.56848 .62956 m .56978 .6327 L .56894 .6306 L F
.428 .094 .296 r
.38571 .61508 m .38857 .61296 L .38625 .61341 L F
.218 0 .125 r
.45802 .65828 m .45601 .65908 L .45517 .66061 L F
.746 .554 .635 r
.50873 .65849 m .51289 .66139 L .51173 .65844 L F
.51289 .66139 m .51348 .66179 L .51323 .66133 L F
.51289 .66139 m .51323 .66133 L .51173 .65844 L F
.498 .843 .996 r
.51573 .66125 m .51515 .661 L .51325 .66178 L F
.51515 .661 m .5145 .66071 L .51392 .66121 L F
.51515 .661 m .51392 .66121 L .51325 .66178 L F
.351 0 .182 r
.51453 .66333 m .51325 .66178 L .5145 .66071 L F
.51453 .66333 m .51229 .66394 L .51325 .66178 L F
0 .115 .641 r
.55525 .6302 m .55478 .62923 L .55418 .62881 L F
.55525 .6302 m .55567 .63041 L .55478 .62923 L F
0 .367 .803 r
.7319 .51604 m .7309 .51508 L .72834 .5138 L F
.484 .831 .997 r
.73519 .51555 m .73339 .51505 L .73365 .51578 L F
.912 .709 .615 r
.73519 .51555 m .73451 .51765 L .73339 .51505 L F
.114 .348 .814 r
.73431 .51627 m .73313 .51434 L .73339 .51505 L F
.73313 .51434 m .73246 .51325 L .73339 .51505 L F
.484 .831 .997 r
.73365 .51578 m .73339 .51505 L .7319 .51604 L F
.463 .771 .997 r
.7319 .51604 m .73339 .51505 L .7309 .51508 L F
.168 .679 .898 r
.73187 .5015 m .73086 .50112 L .72842 .50103 L F
.73187 .5015 m .73086 .50112 L .72842 .50103 L F
.199 .718 .875 r
.73086 .50112 m .73458 .5012 L .73187 .5015 L F
.73086 .50112 m .73458 .5012 L .73187 .5015 L F
.827 .558 .532 r
.68352 .487 m .68361 .4892 L .68687 .48984 L F
.827 .65 .663 r
.68361 .4892 m .68509 .49221 L .68687 .48984 L F
.664 .309 .361 r
.49034 .67268 m .49305 .67283 L .49134 .67043 L F
.497 .384 .654 r
.29578 .59592 m .29832 .59589 L .29766 .59272 L F
.445 .211 .463 r
.29579 .59821 m .29832 .59589 L .29578 .59592 L F
.318 .415 .804 r
.21367 .55438 m .21251 .55604 L .2112 .55285 L F
.473 .48 .784 r
.21367 .55438 m .21292 .5582 L .21251 .55604 L F
.519 .067 .118 r
.31011 .63324 m .30869 .63497 L .3071 .63459 L F
0 0 0 r
.31085 .63278 m .31011 .63324 L .31202 .63367 L F
.31085 .63278 m .30869 .63497 L .31011 .63324 L F
.44 .601 .913 r
.46574 .66759 m .46492 .66872 L .46317 .66796 L F
.778 .571 .62 r
.46414 .6954 m .46451 .69664 L .46692 .69605 L F
.811 .746 .791 r
.46692 .69605 m .46451 .69664 L .46422 .69725 L F
.904 .603 .465 r
.46692 .69605 m .46566 .69876 L .46738 .69859 L F
.987 .723 .353 r
.61707 .6046 m .61612 .60373 L .61717 .60699 L F
.997 .77 .428 r
.61621 .60117 m .61612 .60373 L .61707 .6046 L F
.987 .723 .353 r
.61707 .6046 m .61612 .60373 L .61717 .60699 L F
.614 .219 .271 r
.45536 .7105 m .45412 .71252 L .45198 .71075 L F
.23 0 .057 r
.45626 .71173 m .45536 .7105 L .45779 .71039 L F
.45626 .71173 m .45412 .71252 L .45536 .7105 L F
.322 0 0 r
.76236 .4803 m .76558 .48169 L .7633 .4814 L F
0 0 0 r
.52975 .65855 m .53144 .65508 L .52989 .65615 L F
0 .48 .755 r
.51756 .63276 m .52122 .63369 L .51894 .63341 L F
.021 .113 .621 r
.39798 .5983 m .39873 .60219 L .39969 .60068 L F
.423 .66 .959 r
.39969 .60068 m .39873 .60219 L .40032 .60173 L F
.547 .48 .732 r
.39873 .60219 m .40166 .60407 L .40032 .60173 L F
.39873 .60219 m .39963 .60491 L .40166 .60407 L F
.515 .519 .799 r
.29372 .61279 m .29433 .60904 L .29278 .61087 L F
.29372 .61279 m .29577 .6124 L .29433 .60904 L F
.199 .425 .855 r
.42766 .69523 m .42982 .69635 L .42977 .69267 L F
.962 .827 .664 r
.61745 .61009 m .61717 .60699 L .61679 .6094 L F
.986 .761 .365 r
.61671 .61192 m .61745 .61009 L .61679 .6094 L F
.61671 .61192 m .61743 .61284 L .61745 .61009 L F
.443 .632 .935 r
.32395 .6453 m .32493 .6432 L .32302 .64316 L F
.32395 .6453 m .32716 .64573 L .32493 .6432 L F
.589 .579 .81 r
.32395 .6453 m .32789 .64761 L .32716 .64573 L F
.559 .831 .996 r
.5492 .60778 m .55016 .60619 L .54781 .60663 L F
.5492 .60778 m .55154 .60717 L .55016 .60619 L F
.55016 .60619 m .5492 .60778 L .54781 .60663 L F
.55016 .60619 m .55154 .60717 L .5492 .60778 L F
.913 .711 .617 r
.60215 .56932 m .6038 .5703 L .60246 .56696 L F
.948 .731 .576 r
.60215 .56932 m .60354 .57303 L .6038 .5703 L F
.9 .84 .777 r
.59864 .60415 m .59916 .60742 L .59766 .60655 L F
.953 .742 .579 r
.59916 .60742 m .59712 .60898 L .59766 .60655 L F
.59916 .60742 m .59887 .61016 L .59712 .60898 L F
.855 .815 .81 r
.60104 .60412 m .59916 .60742 L .59864 .60415 L F
.563 .341 .536 r
.41523 .61258 m .41276 .61508 L .41311 .61321 L F
.41 .106 .335 r
.56236 .58501 m .56402 .58617 L .56422 .58431 L F
.56236 .58501 m .56176 .58678 L .56402 .58617 L F
.63 .073 0 r
.75823 .48795 m .75779 .48856 L .75521 .48677 L F
.33 0 0 r
.76137 .48847 m .75779 .48856 L .75823 .48795 L F
.124 0 .186 r
.52293 .66472 m .52447 .66421 L .52515 .66177 L F
.143 0 0 r
.52813 .65991 m .52515 .66177 L .52737 .66081 L F
.439 .153 .38 r
.52447 .66421 m .52737 .66081 L .52515 .66177 L F
.135 .246 .716 r
.80084 .51143 m .79974 .51311 L .79887 .50968 L F
0 .163 .686 r
.80139 .51339 m .79974 .51311 L .80084 .51143 L F
.80139 .51339 m .8014 .5154 L .79974 .51311 L F
.204 .685 .932 r
.36439 .58436 m .36645 .58443 L .36814 .58509 L F
.23 .722 .92 r
.36645 .58443 m .37033 .58481 L .36814 .58509 L F
.822 .484 .415 r
.53259 .67199 m .53587 .6728 L .53588 .67138 L F
.398 .391 .735 r
.53525 .66762 m .53588 .67138 L .53767 .66878 L F
.334 .308 .68 r
.53767 .66878 m .53588 .67138 L .53793 .66947 L F
.779 .445 .422 r
.59402 .5847 m .59124 .58613 L .59063 .58465 L F
.59402 .5847 m .59459 .58671 L .59124 .58613 L F
.767 .504 .536 r
.47397 .66263 m .47701 .66142 L .47451 .66161 L F
.47485 .6626 m .47701 .66142 L .47397 .66263 L F
.47485 .6626 m .47696 .66401 L .47701 .66142 L F
.47364 .66327 m .47649 .66391 L .47485 .6626 L F
.47649 .66391 m .47696 .66401 L .47485 .6626 L F
.554 .547 .801 r
.47807 .66252 m .47687 .66421 L .47588 .66258 L F
.841 .66 .657 r
.47483 .66567 m .47698 .6665 L .47697 .66451 L F
.47678 .66415 m .47697 .66451 L .47696 .66401 L F
.554 .547 .801 r
.47683 .66426 m .47678 .66433 L .47676 .66413 L F
.767 .504 .536 r
.47364 .66327 m .47485 .6626 L .47397 .66263 L F
.841 .66 .657 r
.47687 .66408 m .47696 .66401 L .47364 .66327 L F
.743 .632 .736 r
.47473 .66035 m .47662 .66402 L .47364 .66327 L F
.47662 .66402 m .47678 .66433 L .47364 .66327 L F
.841 .66 .657 r
.47678 .66415 m .47687 .66408 L .47662 .66402 L F
.554 .547 .801 r
.47676 .66413 m .47677 .66414 L .47661 .664 L F
.47677 .66414 m .47678 .66433 L .47662 .66402 L F
.47677 .66414 m .47662 .66402 L .47661 .664 L F
.841 .66 .657 r
.47483 .66567 m .47697 .66451 L .47691 .66439 L F
.47657 .66432 m .4767 .66435 L .47678 .66415 L F
.637 .094 0 r
.47364 .66327 m .47678 .66433 L .4767 .66435 L F
.841 .66 .657 r
.47483 .66567 m .47691 .66439 L .47657 .66432 L F
.637 .094 0 r
.47657 .66432 m .4767 .66435 L .47667 .66435 L F
.47364 .66327 m .4767 .66435 L .47657 .66432 L F
.841 .66 .657 r
.47481 .66564 m .47657 .66432 L .47364 .66327 L F
.47483 .66567 m .47539 .66523 L .47481 .66564 L F
.47539 .66523 m .47657 .66432 L .47481 .66564 L F
.637 .094 0 r
.47364 .66327 m .47431 .66481 L .47483 .66567 L F
.47364 .66327 m .47557 .66396 L .47431 .66481 L F
.841 .66 .657 r
.47657 .66432 m .47678 .66415 L .47364 .66327 L F
.47678 .66415 m .47662 .66402 L .47364 .66327 L F
.554 .547 .801 r
.47687 .66421 m .47661 .664 L .47588 .66258 L F
.47841 .66205 m .47807 .66252 L .47473 .66035 L F
.47807 .66252 m .47588 .66258 L .47473 .66035 L F
.816 .999 .839 r
.47431 .66481 m .47667 .66435 L .47841 .66205 L F
.47667 .66435 m .4767 .66435 L .47672 .66431 L F
.47667 .66435 m .47672 .66431 L .47841 .66205 L F
.4767 .66435 m .47678 .66433 L .47683 .66426 L F
.841 .66 .657 r
.4767 .66435 m .47683 .66426 L .47678 .66415 L F
.554 .547 .801 r
.47687 .66421 m .47683 .66426 L .47676 .66413 L F
.816 .999 .839 r
.4767 .66435 m .47683 .66426 L .47841 .66205 L F
.841 .66 .657 r
.4767 .66435 m .47691 .66439 L .47683 .66426 L F
.654 .485 .643 r
.50636 .66156 m .50873 .65849 L .50675 .65915 L F
.288 .194 .57 r
.6132 .63464 m .61056 .63344 L .61264 .63202 L F
.6132 .63464 m .61107 .63574 L .61056 .63344 L F
.685 .532 .672 r
.45406 .67617 m .45491 .67893 L .45151 .67884 L F
.189 .226 .669 r
.45406 .67617 m .45555 .67903 L .45491 .67893 L F
.522 .358 .6 r
.55536 .63608 m .55736 .63597 L .5569 .63335 L F
.208 .441 .865 r
.72834 .5138 m .7303 .51331 L .72786 .51181 L F
.72834 .5138 m .7309 .51508 L .7303 .51331 L F
0 0 .405 r
.34682 .62605 m .34762 .6277 L .34582 .62423 L F
.562 .239 .378 r
.33912 .60112 m .33811 .60383 L .33543 .60389 L F
.152 0 .19 r
.33979 .60284 m .33912 .60112 L .34128 .60133 L F
.33979 .60284 m .33811 .60383 L .33912 .60112 L F
.686 .731 .884 r
.27793 .81569 m .27925 .81756 L .28072 .8162 L F
.822 .443 .338 r
.74475 .48055 m .74118 .47781 L .74243 .48063 L F
.514 .295 .519 r
.4862 .64752 m .48623 .6498 L .48378 .65028 L F
.619 .377 .528 r
.48896 .64927 m .4862 .64752 L .48822 .64715 L F
.48896 .64927 m .48623 .6498 L .4862 .64752 L F
.625 .293 .39 r
.59423 .64667 m .59555 .64679 L .59305 .64478 L F
.314 .784 .676 r
.58932 .64882 m .59423 .64667 L .58966 .64726 L F
.58932 .64882 m .59153 .64783 L .59423 .64667 L F
.303 .796 .785 r
.59153 .64783 m .59555 .64679 L .59423 .64667 L F
0 0 0 r
.59524 .64677 m .59555 .64679 L .59441 .64694 L F
.511 0 0 r
.59577 .64681 m .59555 .64679 L .59676 .64755 L F
.59305 .64478 m .59555 .64679 L .59577 .64681 L F
.989 .767 .509 r
.59676 .64755 m .59555 .64679 L .59578 .64406 L F
0 0 0 r
.59632 .64655 m .59716 .64585 L .59601 .64653 L F
.59632 .64655 m .59601 .64653 L .59555 .64679 L F
0 .021 .564 r
.59632 .64655 m .59693 .64694 L .59658 .64657 L F
.067 0 .401 r
.59555 .64679 m .59727 .64289 L .59578 .64406 L F
.59555 .64679 m .59716 .64585 L .59727 .64289 L F
0 0 0 r
.59632 .64655 m .59891 .64481 L .59716 .64585 L F
.409 .246 .547 r
.59716 .64585 m .59888 .64237 L .59727 .64289 L F
.59716 .64585 m .59891 .64481 L .59888 .64237 L F
.752 .683 .785 r
.59515 .64505 m .59891 .64481 L .59632 .64655 L F
0 .021 .564 r
.59632 .64655 m .59658 .64657 L .59515 .64505 L F
0 0 0 r
.59632 .64655 m .59555 .64679 L .59524 .64677 L F
.276 .711 .965 r
.35851 .58445 m .36082 .58446 L .36241 .58527 L F
.536 .841 .999 r
.36241 .58527 m .36297 .58398 L .36439 .58436 L F
.36241 .58527 m .36082 .58446 L .36297 .58398 L F
.914 .734 .646 r
.57836 .67548 m .57984 .67774 L .58008 .67595 L F
.57836 .67548 m .57938 .6788 L .57984 .67774 L F
.207 .461 .879 r
.57955 .67457 m .58037 .6761 L .57836 .67548 L F
.08 .477 .893 r
.57836 .67548 m .58037 .6761 L .57991 .67587 L F
.193 .434 .863 r
.57836 .67548 m .5799 .67586 L .57955 .67457 L F
.08 .477 .893 r
.57836 .67548 m .57991 .67587 L .5743 .67297 L F
.193 .434 .863 r
.57836 .67548 m .57991 .6759 L .5799 .67586 L F
.304 .54 .913 r
.57991 .67587 m .5801 .67596 L .57991 .67577 L F
.5801 .67596 m .58014 .67598 L .58009 .67594 L F
.5801 .67596 m .58009 .67594 L .57991 .67577 L F
.58014 .67598 m .58015 .67591 L .57869 .67459 L F
.57862 .67459 m .57869 .67459 L .57542 .67165 L F
.58014 .67598 m .57869 .67459 L .57862 .67459 L F
.5743 .67297 m .57575 .67372 L .57542 .67165 L F
.57575 .67372 m .57991 .67587 L .57825 .67431 L F
.57575 .67372 m .57825 .67431 L .57542 .67165 L F
.193 .434 .863 r
.57991 .6759 m .58008 .67595 L .5799 .6755 L F
.57991 .6759 m .57991 .67569 L .57955 .67457 L F
.359 .562 .914 r
.57542 .67165 m .57991 .67569 L .57955 .67457 L F
.57991 .67569 m .58014 .67589 L .57955 .67457 L F
.525 0 0 r
.58016 .67594 m .57955 .67457 L .58008 .67595 L F
.58275 .67585 m .57955 .67457 L .58016 .67594 L F
.359 .562 .914 r
.58014 .67589 m .58037 .6761 L .57955 .67457 L F
.193 .434 .863 r
.57991 .67569 m .5799 .67548 L .57955 .67457 L F
.5799 .6755 m .58008 .67595 L .5799 .67548 L F
.304 .54 .913 r
.57991 .67587 m .57991 .67577 L .57883 .67478 L F
.57876 .67479 m .57883 .67478 L .57542 .67165 L F
.57991 .67587 m .57883 .67478 L .57876 .67479 L F
.592 .827 .989 r
.58008 .67595 m .57996 .67687 L .58013 .67603 L F
.893 .605 .097 r
.58008 .67595 m .58011 .6775 L .57966 .67514 L F
.58008 .67595 m .57966 .67514 L .57956 .67466 L F
.592 .827 .989 r
.58008 .67595 m .58013 .67603 L .58014 .67595 L F
.893 .605 .097 r
.5799 .67548 m .57956 .67466 L .57955 .67457 L F
.58008 .67595 m .57956 .67466 L .5799 .67548 L F
.592 .827 .989 r
.58014 .67595 m .57984 .67774 L .58437 .67639 L F
.304 .54 .913 r
.58014 .67598 m .58037 .6761 L .58015 .67591 L F
.592 .827 .989 r
.58008 .67595 m .58437 .67639 L .58275 .67585 L F
.274 .22 .613 r
.5811 .67563 m .58011 .6775 L .57956 .67466 L F
.57966 .67464 m .57956 .67466 L .57955 .67457 L F
.5811 .67563 m .57956 .67466 L .57966 .67464 L F
.592 .827 .989 r
.57996 .67687 m .57984 .67774 L .58014 .67595 L F
.592 .584 .813 r
.57845 .67569 m .57801 .67697 L .57921 .67645 L F
.602 .617 .839 r
.57801 .67697 m .58011 .6775 L .57921 .67645 L F
.888 .628 .539 r
.57968 .677 m .58011 .6775 L .57968 .6771 L F
.57955 .67457 m .58011 .6775 L .57968 .677 L F
.57955 .67457 m .57968 .6771 L .57865 .67569 L F
.602 .617 .839 r
.57921 .67645 m .58011 .6775 L .5811 .67563 L F
.592 .584 .813 r
.57865 .67569 m .57921 .67645 L .5811 .67563 L F
.57845 .67569 m .57921 .67645 L .57865 .67569 L F
.888 .628 .539 r
.57865 .67569 m .57968 .6771 L .57845 .67594 L F
.507 .123 .247 r
.57845 .67569 m .57865 .67569 L .57909 .67513 L F
.57845 .67569 m .57966 .67464 L .57951 .67461 L F
.888 .628 .539 r
.57955 .67457 m .57845 .67594 L .5784 .67589 L F
.507 .123 .247 r
.57909 .67513 m .5811 .67563 L .57966 .67464 L F
.57865 .67569 m .5811 .67563 L .57909 .67513 L F
.57951 .67461 m .57966 .67464 L .57955 .67457 L F
.294 0 .077 r
.57951 .67461 m .5784 .67589 L .57845 .67569 L F
.57955 .67457 m .57951 .67461 L .57951 .67461 L F
.57951 .67461 m .5784 .67589 L .57951 .67461 L F
.517 .245 .441 r
.39661 .60735 m .39897 .60699 L .39963 .60491 L F
.511 .239 .438 r
.39963 .60491 m .40106 .60638 L .40166 .60407 L F
.39963 .60491 m .39897 .60699 L .40106 .60638 L F
.569 .53 .772 r
.77247 .49633 m .77452 .49419 L .77141 .49335 L F
.77247 .49633 m .77489 .49576 L .77452 .49419 L F
.604 .122 0 r
.56803 .65012 m .56872 .6512 L .56707 .64893 L F
.56803 .65012 m .56971 .65223 L .56872 .6512 L F
0 .108 .66 r
.4911 .65612 m .49294 .65815 L .4935 .65641 L F
.403 .322 .65 r
.43065 .6827 m .43322 .6837 L .43303 .68109 L F
.43065 .6827 m .43111 .68476 L .43322 .6837 L F
.418 .735 .991 r
.57546 .63998 m .57456 .64134 L .57294 .6383 L F
.57546 .63998 m .57656 .64105 L .57456 .64134 L F
0 0 0 r
.48647 .62656 m .48655 .62644 L .48758 .62484 L F
.705 .856 .437 r
.48936 .62164 m .48758 .62484 L .48827 .62325 L F
0 0 0 r
.48758 .62484 m .48803 .62557 L .48827 .62325 L F
.48758 .62484 m .48655 .62644 L .48803 .62557 L F
.386 .002 .183 r
.39497 .62516 m .39414 .62654 L .39192 .62693 L F
.431 .096 .295 r
.39698 .6245 m .39414 .62654 L .39497 .62516 L F
.562 .301 .477 r
.59038 .63543 m .59279 .63497 L .59052 .6332 L F
.381 .291 .627 r
.6095 .64451 m .60864 .64741 L .60813 .64523 L F
0 0 .296 r
.49969 .68188 m .50059 .68301 L .50109 .68122 L F
.49969 .68188 m .49966 .68447 L .50059 .68301 L F
.708 .475 .569 r
.46486 .67344 m .46561 .67549 L .462 .67557 L F
.689 .541 .681 r
.46671 .6718 m .46561 .67549 L .46486 .67344 L F
.78 .703 .779 r
.5194 .6499 m .5215 .64687 L .51907 .64794 L F
.93 .968 .752 r
.54895 .66696 m .54885 .66808 L .55049 .66525 L F
0 .062 .601 r
.54895 .66696 m .54991 .66976 L .54885 .66808 L F
.51 .534 .817 r
.55782 .66764 m .55678 .6706 L .55617 .66978 L F
.55782 .66764 m .5591 .67042 L .55678 .6706 L F
.706 .52 .636 r
.56029 .67289 m .55678 .6706 L .5591 .67042 L F
.56029 .67289 m .55691 .67352 L .55678 .6706 L F
.543 .098 .142 r
.51681 .65309 m .51921 .65409 L .52039 .65251 L F
.35 .172 .494 r
.52285 .653 m .52112 .65554 L .52039 .65251 L F
.17 0 0 r
.51921 .65409 m .52285 .653 L .52039 .65251 L F
.665 .737 .904 r
.52236 .70713 m .52405 .7092 L .52639 .70809 L F
.415 .061 .254 r
.38628 .63021 m .38363 .6318 L .38399 .63037 L F
.828 .625 .628 r
.61591 .59232 m .61582 .59556 L .61818 .59596 L F
.886 .776 .735 r
.61494 .59787 m .61818 .59596 L .61582 .59556 L F
.61494 .59787 m .61679 .59903 L .61818 .59596 L F
.66 .581 .755 r
.52013 .66802 m .52063 .67051 L .51833 .67034 L F
.573 .521 .76 r
.5231 .66997 m .52063 .67051 L .52013 .66802 L F
.417 .253 .549 r
.52013 .66802 m .51833 .67034 L .52116 .66916 L F
.182 0 0 r
.52063 .67051 m .52091 .67069 L .51833 .67034 L F
.432 .285 .581 r
.51833 .67034 m .52091 .67069 L .52116 .66916 L F
.741 .764 .872 r
.51656 .77361 m .51951 .77383 L .51818 .77238 L F
.783 .772 .843 r
.51951 .77383 m .52149 .77209 L .52063 .76978 L F
.349 .371 .743 r
.72366 .49253 m .72459 .49708 L .72606 .49419 L F
.115 .316 .787 r
.5569 .63335 m .55732 .63245 L .55567 .63041 L F
.183 .204 .647 r
.55736 .63597 m .55732 .63245 L .5569 .63335 L F
.344 0 0 r
.32778 .58304 m .33008 .5832 L .33163 .58243 L F
.035 0 0 r
.33008 .5832 m .33364 .58257 L .33163 .58243 L F
.516 .079 .148 r
.48606 .71294 m .48516 .71363 L .48247 .71347 L F
.643 .243 .269 r
.48833 .71337 m .48516 .71363 L .48606 .71294 L F
.458 .43 .74 r
.46075 .66755 m .46324 .66824 L .46317 .66796 L F
.316 0 0 r
.35372 .64197 m .35198 .64325 L .34962 .64347 L F
.474 .037 .128 r
.35586 .64142 m .35198 .64325 L .35372 .64197 L F
.59 .647 .875 r
.4304 .60176 m .42908 .60419 L .42784 .60177 L F
.4304 .60176 m .43126 .60386 L .42908 .60419 L F
.486 .242 .47 r
.43126 .60386 m .42898 .60552 L .42908 .60419 L F
0 .129 .649 r
.76983 .52399 m .77149 .52513 L .76869 .52429 L F
0 .006 .582 r
.56848 .62956 m .57024 .63213 L .56978 .6327 L F
0 .15 .692 r
.57024 .63213 m .57199 .63487 L .56978 .6327 L F
.488 .597 .888 r
.41934 .59745 m .41803 .59907 L .41852 .59942 L F
0 0 .22 r
.61471 .62381 m .61457 .62144 L .6156 .61994 L F
.61471 .62381 m .61443 .62318 L .61457 .62144 L F
.399 .309 .637 r
.29244 .60728 m .29366 .60423 L .29181 .6048 L F
.955 .641 .221 r
.79157 .52108 m .79174 .52077 L .79076 .52006 L F
.081 .554 .902 r
.7925 .52064 m .79157 .52108 L .7902 .5207 L F
.7936 .52062 m .79205 .52097 L .7925 .52064 L F
.252 .305 .723 r
.79176 .52117 m .79174 .52077 L .7918 .52115 L F
.081 .554 .902 r
.79205 .52097 m .79157 .52108 L .7925 .52064 L F
.252 .305 .723 r
.79199 .52539 m .79176 .52117 L .79212 .52321 L F
.79176 .52117 m .7918 .52115 L .79212 .52321 L F
.704 .655 .798 r
.79212 .52321 m .79093 .52601 L .79199 .52539 L F
.792 .629 .679 r
.47354 .67321 m .47052 .67572 L .47148 .67274 L F
.47354 .67321 m .47159 .67619 L .47052 .67572 L F
.706 .511 .623 r
.47373 .67597 m .47159 .67619 L .47354 .67321 L F
.283 .467 .865 r
.47537 .67203 m .47716 .67518 L .47354 .67321 L F
.612 .6 .814 r
.47716 .67518 m .47373 .67597 L .47354 .67321 L F
.814 .679 .715 r
.54643 .66155 m .55049 .66525 L .54848 .66176 L F
.852 .664 .647 r
.54643 .66155 m .54895 .66696 L .55049 .66525 L F
.25 .414 .831 r
.54848 .66176 m .55049 .66525 L .55085 .66354 L F
.679 .51 .65 r
.49328 .64135 m .4906 .64376 L .49076 .64171 L F
.193 0 .251 r
.53746 .70466 m .53956 .70218 L .53621 .70094 L F
.041 .602 .799 r
.34326 .58317 m .34545 .58329 L .34698 .58356 L F
.139 .675 .851 r
.34698 .58356 m .34545 .58329 L .34912 .58351 L F
.451 .236 .495 r
.56821 .59837 m .56785 .60105 L .5657 .60169 L F
.336 .156 .483 r
.57006 .59567 m .56821 .59837 L .56757 .59623 L F
.57006 .59567 m .57013 .59791 L .56821 .59837 L F
.315 .121 .45 r
.56969 .60018 m .56821 .59837 L .57013 .59791 L F
.56969 .60018 m .56785 .60105 L .56821 .59837 L F
.672 .504 .649 r
.49632 .6422 m .49328 .64135 L .49588 .64031 L F
.44 .189 .435 r
.49852 .64089 m .49632 .6422 L .49588 .64031 L F
.766 .799 .88 r
.49565 .6385 m .4964 .63993 L .49588 .64031 L F
.431 0 0 r
.56189 .62078 m .56096 .62008 L .55942 .61928 L F
.56189 .62078 m .56354 .62113 L .56096 .62008 L F
.545 .525 .783 r
.79506 .49281 m .79247 .4931 L .79167 .48971 L F
.599 .463 .668 r
.7954 .49473 m .79247 .4931 L .79506 .49281 L F
.7954 .49473 m .79295 .49539 L .79247 .4931 L F
.561 .345 .545 r
.4537 .6808 m .45151 .67884 L .45491 .67893 L F
.4537 .6808 m .4511 .68141 L .45151 .67884 L F
.504 .476 .759 r
.79741 .50276 m .795 .5048 L .79416 .50104 L F
.536 .532 .798 r
.79741 .50276 m .79747 .50472 L .795 .5048 L F
.632 .563 .759 r
.79868 .50763 m .795 .5048 L .79747 .50472 L F
.486 .629 .916 r
.55879 .61751 m .55736 .6196 L .55738 .61723 L F
.55879 .61751 m .55942 .61928 L .55736 .6196 L F
.431 .034 .183 r
.28117 .81365 m .28174 .81589 L .28097 .8159 L F
.955 .94 .725 r
.28072 .8162 m .28108 .81462 L .28117 .81365 L F
.66 .18 .102 r
.27793 .81569 m .28072 .8162 L .2798 .81456 L F
.686 .731 .884 r
.27793 .81569 m .28072 .8162 L .27757 .81595 L F
.431 .034 .183 r
.28117 .81365 m .27796 .8157 L .28072 .8162 L F
.66 .18 .102 r
.27793 .81569 m .27805 .81579 L .28072 .8162 L F
.431 .034 .183 r
.27805 .81579 m .27829 .816 L .28072 .8162 L F
0 .169 .672 r
.27793 .81568 m .27805 .81579 L .27793 .81569 L F
.27792 .81567 m .27796 .8157 L .27793 .81568 L F
.27796 .8157 m .27805 .81579 L .27793 .81568 L F
.66 .18 .102 r
.27805 .81579 m .27845 .8161 L .28072 .8162 L F
.431 .034 .183 r
.27796 .8157 m .27805 .81579 L .28072 .8162 L F
.28117 .81365 m .28108 .81462 L .2783 .81594 L F
.955 .94 .725 r
.28072 .8162 m .27996 .81575 L .28108 .81462 L F
.431 .034 .183 r
.28108 .81462 m .28097 .8159 L .27979 .81592 L F
.28108 .81462 m .27996 .81575 L .2783 .81594 L F
.28117 .81365 m .2783 .81594 L .27796 .8157 L F
.882 .79 .754 r
.28156 .81256 m .27996 .81575 L .27928 .8155 L F
.28156 .81256 m .27954 .81515 L .27822 .81451 L F
.27954 .81515 m .27928 .8155 L .2788 .81505 L F
.27954 .81515 m .2788 .81505 L .27822 .81451 L F
.436 .685 .969 r
.27802 .81562 m .27968 .81588 L .2788 .81505 L F
0 .169 .672 r
.27802 .81562 m .27845 .8161 L .27817 .81588 L F
.431 .034 .183 r
.27796 .8157 m .27757 .81595 L .27829 .816 L F
.27796 .8157 m .2783 .81594 L .27757 .81595 L F
.436 .685 .969 r
.27768 .81587 m .27824 .81587 L .27802 .81562 L F
.431 .034 .183 r
.27996 .81575 m .27972 .81592 L .2783 .81594 L F
.436 .685 .969 r
.27824 .81587 m .27968 .81588 L .27802 .81562 L F
.27792 .81594 m .27972 .81592 L .27768 .81587 L F
.882 .79 .754 r
.27996 .81575 m .27983 .81602 L .27972 .81592 L F
.436 .685 .969 r
.27972 .81592 m .28174 .81589 L .27968 .81588 L F
.27972 .81592 m .27968 .81588 L .27768 .81587 L F
.66 .18 .102 r
.27845 .8161 m .27941 .81685 L .28 .81656 L F
.882 .79 .754 r
.27972 .81592 m .27941 .81685 L .27901 .81642 L F
.66 .18 .102 r
.27845 .8161 m .28 .81656 L .28072 .8162 L F
.882 .79 .754 r
.27983 .81602 m .27941 .81685 L .27972 .81592 L F
0 .169 .672 r
.27757 .81488 m .27941 .81685 L .27845 .8161 L F
.436 .685 .969 r
.27802 .81562 m .2788 .81505 L .27757 .81488 L F
0 .169 .672 r
.27757 .81488 m .27845 .8161 L .27802 .81562 L F
.27757 .81488 m .27817 .81588 L .27805 .81579 L F
.27757 .81488 m .27805 .81579 L .27792 .81567 L F
.777 .996 .795 r
.27793 .81569 m .27757 .81595 L .27757 .81488 L F
.436 .685 .969 r
.27757 .81595 m .27802 .81562 L .27757 .81488 L F
.882 .79 .754 r
.27822 .81451 m .27928 .8155 L .27757 .81488 L F
.436 .685 .969 r
.2788 .81505 m .27967 .81442 L .27757 .81488 L F
.5 .169 .338 r
.28156 .81256 m .28331 .81389 L .28117 .81365 L F
.955 .94 .725 r
.28108 .81462 m .28156 .81256 L .28117 .81365 L F
.28108 .81462 m .27996 .81575 L .28156 .81256 L F
.436 .685 .969 r
.2788 .81505 m .28174 .81589 L .27967 .81442 L F
.431 .034 .183 r
.27996 .81575 m .27979 .81592 L .27972 .81592 L F
.436 .685 .969 r
.27968 .81588 m .28174 .81589 L .2788 .81505 L F
.882 .79 .754 r
.27996 .81575 m .27901 .81642 L .27757 .81488 L F
.955 .94 .725 r
.28072 .8162 m .27941 .81685 L .27996 .81575 L F
.436 .685 .969 r
.27757 .81595 m .27792 .81594 L .27768 .81587 L F
.059 0 .237 r
.28117 .81365 m .28331 .81389 L .28174 .81589 L F
.857 .865 .845 r
.78532 .50953 m .78717 .51088 L .78625 .50878 L F
.659 .376 .48 r
.78659 .51304 m .78904 .51125 L .78717 .51088 L F
.32 .516 .891 r
.59788 .6389 m .59633 .63587 L .59671 .63553 L F
.59788 .6389 m .59922 .63769 L .59633 .63587 L F
.722 .23 .071 r
.59633 .63587 m .59734 .6371 L .59574 .63638 L F
.59633 .63587 m .59574 .63638 L .5947 .63591 L F
.32 .516 .891 r
.59671 .63553 m .59633 .63587 L .59657 .63512 L F
0 0 .236 r
.59884 .63994 m .59788 .6389 L .59783 .64131 L F
.59884 .63994 m .59922 .63769 L .59788 .6389 L F
.456 .263 .529 r
.43966 .6675 m .44174 .66934 L .44282 .6671 L F
.615 .261 .348 r
.44174 .66934 m .44538 .66725 L .44282 .6671 L F
.946 .593 .302 r
.74753 .51162 m .74835 .51004 L .74723 .50884 L F
.74753 .51162 m .7486 .51184 L .74835 .51004 L F
0 0 .437 r
.57055 .66169 m .57094 .66043 L .57024 .65816 L F
0 .114 .661 r
.57055 .66169 m .57226 .66373 L .57094 .66043 L F
0 0 .522 r
.57353 .67075 m .5743 .67297 L .57398 .66947 L F
.515 .259 .465 r
.51154 .65579 m .51394 .65546 L .51463 .65257 L F
.486 .233 .455 r
.51463 .65257 m .5163 .65467 L .51681 .65309 L F
.51463 .65257 m .51394 .65546 L .5163 .65467 L F
.49 .308 .562 r
.29378 .60042 m .29579 .59821 L .29339 .59879 L F
.618 .28 .375 r
.49173 .71272 m .49059 .71528 L .48833 .71337 L F
.501 .133 .273 r
.49414 .71285 m .49059 .71528 L .49173 .71272 L F
.781 .419 .371 r
.72647 .50827 m .72847 .50742 L .72662 .50654 L F
.861 .631 .589 r
.60916 .58097 m .61209 .58412 L .61218 .58163 L F
.078 0 .045 r
.48477 .65111 m .48378 .65028 L .48623 .6498 L F
.48477 .65111 m .48298 .65212 L .48378 .65028 L F
.768 .648 .73 r
.52293 .66768 m .52013 .66802 L .52293 .66472 L F
.573 .521 .76 r
.5231 .66997 m .52013 .66802 L .52293 .66768 L F
.672 .57 .732 r
.52624 .66665 m .52293 .66768 L .52293 .66472 L F
.512 .244 .445 r
.52624 .66665 m .5231 .66997 L .52293 .66768 L F
.449 .813 .995 r
.50429 .67587 m .50525 .67478 L .50666 .67548 L F
.436 .054 .215 r
.50429 .67587 m .50554 .6774 L .50525 .67478 L F
.50429 .67587 m .5032 .67796 L .50554 .6774 L F
.35 .172 .494 r
.52285 .653 m .52272 .65531 L .52112 .65554 L F
.312 .239 .612 r
.52272 .65531 m .52123 .65883 L .52112 .65554 L F
.596 .814 .983 r
.56029 .6451 m .56253 .64438 L .55897 .64394 L F
.56029 .6451 m .56253 .64438 L .55897 .64394 L F
.792 .772 .835 r
.71771 .48063 m .71527 .48334 L .71889 .48287 L F
.798 .693 .75 r
.71527 .48334 m .71668 .48625 L .71889 .48287 L F
.824 .783 .814 r
.71771 .48063 m .71889 .48287 L .71945 .48195 L F
.478 .188 .394 r
.52872 .66453 m .52883 .66612 L .52624 .66665 L F
.655 .378 .489 r
.53127 .66467 m .52883 .66612 L .52872 .66453 L F
.631 .362 .492 r
.57231 .58119 m .57553 .57852 L .57271 .57873 L F
0 0 0 r
.60382 .66737 m .60678 .66508 L .60538 .66664 L F
.60382 .66737 m .60538 .66664 L .60197 .66869 L F
.462 .232 .478 r
.4935 .65641 m .49593 .65588 L .49546 .65343 L F
.573 .304 .47 r
.49546 .65343 m .49725 .65548 L .49926 .65315 L F
.49546 .65343 m .49593 .65588 L .49725 .65548 L F
.456 .263 .529 r
.43966 .6675 m .43963 .66997 L .44174 .66934 L F
.865 .481 .314 r
.47358 .70748 m .47395 .70907 L .47534 .7077 L F
.405 0 0 r
.47395 .70907 m .47772 .70861 L .47534 .7077 L F
.381 .291 .627 r
.6095 .64451 m .61019 .64688 L .60864 .64741 L F
.367 .253 .59 r
.61019 .64688 m .61054 .64934 L .60864 .64741 L F
.52 .199 .364 r
.52123 .65883 m .52112 .66131 L .51813 .66153 L F
.312 .239 .612 r
.52272 .65531 m .52322 .65829 L .52123 .65883 L F
.002 0 .254 r
.52234 .65978 m .52123 .65883 L .52322 .65829 L F
.52234 .65978 m .52112 .66131 L .52123 .65883 L F
0 0 0 r
.60807 .66382 m .60538 .66664 L .60678 .66508 L F
.49169 .61865 m .48936 .62164 L .4906 .62052 L F
.4906 .62052 m .48936 .62164 L .48827 .62325 L F
.498 .2 .39 r
.43678 .67241 m .43963 .66997 L .43757 .67071 L F
.792 .675 .735 r
.50382 .64999 m .50757 .65055 L .50688 .64728 L F
.6 .58 .803 r
.50757 .65055 m .50881 .64649 L .50688 .64728 L F
.50757 .65055 m .51016 .65027 L .50881 .64649 L F
.473 .101 .252 r
.51016 .65027 m .50954 .6518 L .50757 .65055 L F
.51016 .65027 m .50954 .6518 L .50757 .65055 L F
.792 .675 .735 r
.50382 .64999 m .50757 .65055 L .50688 .64728 L F
.392 .643 .956 r
.77406 .48279 m .77275 .48412 L .7719 .48268 L F
.426 .697 .977 r
.77482 .48408 m .77275 .48412 L .77406 .48279 L F
.479 .192 .399 r
.58575 .57451 m .58843 .57227 L .58626 .57305 L F
.793 .99 .747 r
.50607 .68033 m .50559 .68179 L .50806 .67902 L F
.76 .251 0 r
.50541 .68296 m .50559 .68179 L .50607 .68033 L F
.50541 .68296 m .50733 .68376 L .50559 .68179 L F
.042 .322 .806 r
.5272 .64464 m .52939 .64522 L .52632 .6435 L F
.666 .56 .726 r
.5272 .64464 m .52879 .64743 L .5314 .64725 L F
.5272 .64464 m .52805 .64517 L .52971 .64647 L F
.52805 .64517 m .5314 .64725 L .52971 .64647 L F
.94 .632 .181 r
.53071 .64741 m .53077 .6474 L .52879 .64743 L F
.585 .046 0 r
.53111 .64765 m .53076 .64736 L .5314 .64725 L F
.94 .632 .181 r
.53096 .64785 m .5322 .65006 L .5314 .64725 L F
.53075 .64748 m .53096 .64785 L .53111 .64765 L F
.71 .986 .87 r
.53112 .64995 m .5322 .65006 L .53071 .64741 L F
.997 .77 .431 r
.53071 .64741 m .53112 .64995 L .5322 .65006 L F
.842 .739 .751 r
.53316 .64941 m .53112 .64995 L .53072 .64746 L F
.585 .046 0 r
.53316 .64941 m .53102 .6477 L .53082 .64752 L F
.842 .739 .751 r
.53316 .64941 m .53072 .64746 L .53071 .64741 L F
0 0 0 r
.53071 .64741 m .5304 .64979 L .5319 .64854 L F
.701 .936 .628 r
.5319 .64854 m .5304 .64979 L .53147 .64851 L F
.585 .046 0 r
.53209 .64856 m .5319 .64854 L .53102 .6477 L F
.53316 .64941 m .53082 .64752 L .53111 .64765 L F
.53316 .64941 m .53111 .64765 L .5314 .64725 L F
.53316 .64941 m .5319 .64854 L .53209 .64856 L F
.842 .739 .751 r
.53316 .64941 m .53071 .64741 L .5319 .64854 L F
.94 .632 .181 r
.53055 .64739 m .5314 .64725 L .52959 .64738 L F
.005 .26 .764 r
.5319 .64854 m .53246 .64732 L .53043 .64571 L F
.701 .936 .628 r
.5319 .64854 m .53147 .64851 L .53246 .64732 L F
.585 .046 0 r
.53111 .64765 m .53082 .64752 L .52971 .64647 L F
0 .232 .747 r
.53016 .64599 m .53158 .64792 L .53043 .64571 L F
.52971 .64647 m .5307 .64723 L .53016 .64599 L F
.94 .632 .181 r
.53077 .6474 m .5308 .64747 L .5314 .64725 L F
.53075 .64748 m .53111 .64765 L .5314 .64725 L F
.585 .046 0 r
.53076 .64736 m .52971 .64647 L .5314 .64725 L F
.94 .632 .181 r
.53077 .6474 m .5314 .64725 L .53055 .64739 L F
0 .232 .747 r
.5307 .64723 m .53158 .64792 L .53016 .64599 L F
.94 .632 .181 r
.53071 .64741 m .53075 .64748 L .5308 .64747 L F
0 .232 .747 r
.53069 .64739 m .5319 .64854 L .53091 .6474 L F
.94 .632 .181 r
.53071 .64741 m .5308 .64747 L .53077 .6474 L F
.53077 .6474 m .52959 .64738 L .52879 .64743 L F
0 .232 .747 r
.53091 .6474 m .5319 .64854 L .53158 .64792 L F
.52971 .64647 m .53069 .64739 L .53091 .6474 L F
.042 .322 .806 r
.5272 .64464 m .52971 .64647 L .52939 .64522 L F
.306 0 .187 r
.37296 .62133 m .374 .62293 L .37517 .62083 L F
.37296 .62133 m .37191 .62361 L .374 .62293 L F
.481 .804 1 r
.35405 .62588 m .35552 .62671 L .35337 .62709 L F
.596 .926 .965 r
.35337 .62709 m .35198 .62684 L .35405 .62588 L F
.05 0 0 r
.34713 .59869 m .34552 .59964 L .34336 .60012 L F
.042 0 0 r
.34938 .59876 m .34552 .59964 L .34713 .59869 L F
.312 .404 .796 r
.57109 .66744 m .57398 .66947 L .57274 .66609 L F
.823 .815 .842 r
.72712 .48995 m .72958 .49027 L .72852 .48914 L F
.87 .881 .842 r
.72852 .48914 m .72958 .49027 L .73108 .48779 L F
.561 .19 .295 r
.48247 .71347 m .48482 .71506 L .48237 .71503 L F
.56 .191 .298 r
.48516 .71363 m .48482 .71506 L .48247 .71347 L F
.304 0 .027 r
.5753 .59235 m .5745 .59417 L .57219 .59378 L F
.257 .077 .436 r
.57709 .58992 m .57735 .59201 L .5753 .59235 L F
.127 0 0 r
.5753 .59235 m .57735 .59201 L .5745 .59417 L F
.627 .847 .463 r
.59599 .63421 m .59761 .6318 L .59878 .63033 L F
.876 .916 .518 r
.59761 .6318 m .59861 .62969 L .59878 .63033 L F
.768 .723 .811 r
.71775 .49475 m .7192 .49627 L .72126 .49492 L F
.94 .632 .181 r
.53071 .64741 m .52879 .64743 L .52785 .64793 L F
.715 .225 .076 r
.5038 .6389 m .50347 .63957 L .50313 .63946 L F
.271 0 0 r
.5045 .63832 m .5038 .6389 L .5013 .63908 L F
.715 .225 .076 r
.5038 .6389 m .49771 .63758 L .5013 .63908 L F
.5038 .6389 m .50313 .63946 L .49771 .63758 L F
.271 0 0 r
.50535 .63812 m .5038 .6389 L .5045 .63832 L F
.432 0 0 r
.50678 .63869 m .5038 .6389 L .50535 .63812 L F
.638 .159 .099 r
.46546 .71256 m .46585 .71458 L .46347 .71338 L F
.46546 .71256 m .46718 .71325 L .46585 .71458 L F
.768 .723 .811 r
.71775 .49475 m .72126 .49492 L .72038 .49212 L F
.775 .77 .849 r
.72038 .49212 m .72126 .49492 L .72366 .49253 L F
.274 .564 .934 r
.74668 .50498 m .74437 .50517 L .74365 .50447 L F
.74668 .50498 m .74745 .50642 L .74437 .50517 L F
0 .084 .558 r
.45198 .71075 m .45276 .71135 L .45039 .71107 L F
.45198 .71075 m .45412 .71252 L .45276 .71135 L F
.399 .309 .637 r
.29244 .60728 m .29408 .60667 L .29366 .60423 L F
.4 .341 .676 r
.29244 .60728 m .29433 .60904 L .29408 .60667 L F
.29244 .60728 m .29278 .61087 L .29433 .60904 L F
.465 .162 .367 r
.44981 .66632 m .44801 .6648 L .4477 .66688 L F
.44981 .66632 m .45037 .66441 L .44801 .6648 L F
.634 .42 .575 r
.51716 .76457 m .52047 .76516 L .51866 .76598 L F
.649 .577 .761 r
.7954 .49473 m .79403 .49871 L .79295 .49539 L F
.7954 .49473 m .79647 .49817 L .79403 .49871 L F
.625 .473 .656 r
.79647 .49817 m .79416 .50104 L .79403 .49871 L F
.812 .336 0 r
.74932 .48634 m .74826 .48583 L .74656 .48323 L F
.404 .82 .973 r
.75185 .48588 m .74826 .48583 L .74932 .48634 L F
.291 0 .064 r
.55849 .58918 m .56176 .58678 L .55969 .58767 L F
.231 .718 .926 r
.3361 .58203 m .33977 .58245 L .33767 .58279 L F
.146 .686 .706 r
.35288 .59809 m .35155 .59833 L .34938 .59876 L F
.229 .746 .746 r
.35376 .59775 m .35288 .59809 L .35518 .59748 L F
.35376 .59775 m .35155 .59833 L .35288 .59809 L F
.219 .726 .896 r
.37033 .58481 m .37246 .58467 L .37385 .58496 L F
.283 .754 .939 r
.37246 .58467 m .37596 .58488 L .37385 .58496 L F
.431 .777 .997 r
.39817 .58822 m .39505 .58771 L .39721 .58736 L F
.384 .676 .975 r
.39917 .587 m .39817 .58822 L .39721 .58736 L F
.39917 .587 m .40127 .58875 L .39817 .58822 L F
.298 0 .025 r
.54579 .70194 m .54469 .70369 L .54231 .70412 L F
.223 .404 .831 r
.5449 .69985 m .54704 .70085 L .54579 .70194 L F
0 0 0 r
.54579 .70194 m .54704 .70085 L .54469 .70369 L F
.61117 .65243 m .60969 .65546 L .61043 .65352 L F
.108 .208 .687 r
.46738 .69859 m .46917 .70069 L .46791 .70136 L F
.341 .804 .696 r
.46917 .70069 m .46667 .70185 L .46791 .70136 L F
.424 .049 .221 r
.49725 .65548 m .50195 .65215 L .49926 .65315 L F
.982 .693 .35 r
.50301 .67033 m .50207 .67002 L .50174 .66705 L F
.135 .293 .761 r
.504 .66904 m .50301 .67033 L .50174 .66705 L F
.6 .936 .95 r
.504 .66904 m .50207 .67002 L .50301 .67033 L F
.491 .55 .844 r
.39091 .59672 m .39256 .59477 L .39013 .59569 L F
.39091 .59672 m .39399 .59757 L .39256 .59477 L F
.357 .669 .974 r
.53913 .63683 m .53847 .63798 L .53801 .63724 L F
.53913 .63683 m .54016 .63803 L .53847 .63798 L F
.627 .807 .969 r
.67485 .50292 m .67212 .50368 L .67562 .50412 L F
.525 .752 .979 r
.67485 .50292 m .67562 .50412 L .67696 .50248 L F
.48 .686 .957 r
.67562 .50412 m .67792 .50403 L .67696 .50248 L F
0 .242 .758 r
.53684 .61831 m .53915 .62015 L .53721 .61737 L F
.831 .681 .697 r
.67493 .48805 m .67781 .48857 L .67781 .48719 L F
.66 .268 .293 r
.67781 .48857 m .68022 .48894 L .67781 .48719 L F
.578 .335 .512 r
.67781 .48719 m .68022 .48894 L .68009 .48665 L F
.34 .51 .879 r
.4854 .67984 m .48535 .68237 L .48714 .68069 L F
.48374 .6798 m .48535 .68237 L .4854 .67984 L F
.11 0 0 r
.48604 .67986 m .4843 .68016 L .48175 .68021 L F
.48635 .67984 m .48617 .67987 L .48604 .67986 L F
.48617 .67987 m .4843 .68016 L .48604 .67986 L F
.34 .51 .879 r
.48306 .6787 m .48374 .6798 L .4854 .67984 L F
.523 .511 .784 r
.76858 .49217 m .77089 .49155 L .76739 .49031 L F
.599 .57 .793 r
.76858 .49217 m .77141 .49335 L .77089 .49155 L F
.424 .829 .977 r
.37817 .59491 m .37716 .59444 L .37499 .59487 L F
.004 0 0 r
.37716 .59444 m .37675 .59455 L .37499 .59487 L F
.318 .787 .931 r
.3762 .59513 m .37499 .59487 L .37357 .59513 L F
.004 0 0 r
.37675 .59455 m .37345 .59543 L .37499 .59487 L F
.318 .787 .931 r
.37357 .59513 m .37499 .59487 L .37278 .59513 L F
.424 .829 .977 r
.37817 .59491 m .37499 .59487 L .3762 .59513 L F
.761 .476 .501 r
.68009 .48665 m .68361 .4892 L .68352 .487 L F
.192 .556 .933 r
.76739 .49031 m .76988 .4902 L .76679 .48919 L F
.76739 .49031 m .77089 .49155 L .76988 .4902 L F
.139 0 0 r
.49264 .61952 m .49169 .61865 L .4906 .62052 L F
.49264 .61952 m .49419 .61778 L .49169 .61865 L F
.68 .91 .975 r
.52016 .64654 m .51907 .64794 L .5215 .64687 L F
.286 .131 .488 r
.33492 .60606 m .33343 .60443 L .33543 .60389 L F
.33492 .60606 m .33337 .60696 L .33343 .60443 L F
.075 .249 .739 r
.50666 .67548 m .50889 .67771 L .50806 .67902 L F
.667 .952 .713 r
.50889 .67771 m .50607 .68033 L .50806 .67902 L F
.39 .197 .494 r
.21284 .57279 m .21257 .57514 L .21081 .57578 L F
.235 .121 .512 r
.21205 .57739 m .21081 .57578 L .21257 .57514 L F
.21205 .57739 m .21083 .5783 L .21081 .57578 L F
.055 0 .216 r
.48537 .67362 m .4839 .67638 L .48468 .67636 L F
.306 .031 .321 r
.48759 .67467 m .48537 .67362 L .48468 .67636 L F
.376 0 .055 r
.48759 .67467 m .4882 .6733 L .48537 .67362 L F
.049 0 0 r
.36232 .63976 m .36191 .63914 L .36398 .6386 L F
.36232 .63976 m .36016 .64034 L .36191 .63914 L F
.138 0 0 r
.51047 .71213 m .5116 .7103 L .50906 .70998 L F
.944 .687 .221 r
.49771 .63758 m .49904 .63911 L .5013 .63908 L F
.256 0 0 r
.37752 .63456 m .38126 .63247 L .37982 .63411 L F
.37752 .63456 m .37847 .63368 L .38126 .63247 L F
.246 0 0 r
.37982 .63411 m .38126 .63247 L .38363 .6318 L F
.224 0 .118 r
.47542 .65776 m .47338 .65855 L .47621 .65666 L F
.631 .362 .492 r
.57231 .58119 m .57548 .58037 L .57553 .57852 L F
.582 .293 .442 r
.57779 .57998 m .57553 .57852 L .57548 .58037 L F
.57779 .57998 m .57806 .57836 L .57553 .57852 L F
.64 .481 .652 r
.70577 .47838 m .70345 .4813 L .70617 .48079 L F
.506 .342 .593 r
.70617 .48079 m .70832 .47785 L .70577 .47838 L F
.89 .463 .105 r
.5475 .64295 m .55048 .64707 L .54994 .64466 L F
.486 .71 .969 r
.78376 .48507 m .78226 .48667 L .78142 .48519 L F
.78376 .48507 m .78463 .48647 L .78226 .48667 L F
.587 .287 .427 r
.58875 .58422 m .58896 .58577 L .5853 .58703 L F
.612 .305 .425 r
.58875 .58422 m .59124 .58613 L .58896 .58577 L F
.653 .272 .31 r
.59063 .58465 m .59124 .58613 L .58875 .58422 L F
0 0 .352 r
.61015 .65836 m .6104 .66088 L .60906 .66209 L F
0 0 0 r
.6104 .66088 m .60807 .66382 L .60906 .66209 L F
.644 .736 .915 r
.71322 .48548 m .71668 .48625 L .71527 .48334 L F
.527 .097 .167 r
.42353 .60737 m .42542 .60875 L .42296 .60919 L F
.42353 .60737 m .42604 .6076 L .42542 .60875 L F
.713 .736 .87 r
.52149 .77209 m .52428 .77024 L .52063 .76978 L F
.891 .725 .67 r
.61403 .58979 m .61591 .59232 L .61518 .58992 L F
.61403 .58979 m .61357 .59195 L .61591 .59232 L F
.922 .707 .596 r
.61366 .59236 m .61591 .59232 L .61357 .59195 L F
.61366 .59236 m .61582 .59556 L .61591 .59232 L F
.36 .562 .913 r
.53506 .63492 m .53408 .63672 L .53317 .63466 L F
.53506 .63492 m .53801 .63724 L .53408 .63672 L F
.297 0 .112 r
.31172 .58718 m .31251 .58862 L .31405 .58699 L F
.31172 .58718 m .31053 .58916 L .31251 .58862 L F
.814 .616 .06 r
.74104 .47549 m .74118 .47781 L .7409 .47641 L F
0 0 .507 r
.54031 .66374 m .5405 .66459 L .53977 .66288 L F
.287 0 .071 r
.53737 .66687 m .5405 .66459 L .54031 .66374 L F
.717 .685 .819 r
.53899 .66867 m .54058 .66699 L .5398 .66632 L F
0 0 .036 r
.54058 .66699 m .54037 .66685 L .5398 .66632 L F
.287 0 .071 r
.53737 .66687 m .5398 .66632 L .53907 .66564 L F
.53737 .66687 m .54031 .66374 L .53723 .66457 L F
.505 .358 .615 r
.53767 .66878 m .5398 .66632 L .53737 .66687 L F
.53767 .66878 m .53899 .66867 L .5398 .66632 L F
0 0 .036 r
.54037 .66685 m .53833 .66551 L .5398 .66632 L F
.287 0 .071 r
.53907 .66564 m .5398 .66632 L .5405 .66459 L F
.501 .828 .999 r
.54031 .66374 m .54279 .6641 L .5405 .66459 L F
.897 .819 .347 r
.5405 .66459 m .54031 .66374 L .54279 .6641 L F
.5405 .66459 m .5398 .66632 L .54031 .66374 L F
0 .239 .65 r
.50564 .62314 m .50429 .62243 L .50341 .62109 L F
.50564 .62314 m .50696 .62397 L .50429 .62243 L F
.732 .458 .514 r
.5231 .66997 m .52091 .67069 L .52063 .67051 L F
0 .415 .854 r
.39798 .5983 m .39811 .5974 L .39648 .5967 L F
0 0 .553 r
.39798 .5983 m .39969 .60068 L .39811 .5974 L F
.199 0 0 r
.37024 .6367 m .36622 .63853 L .36755 .63782 L F
.37024 .6367 m .36856 .63809 L .36622 .63853 L F
.191 0 0 r
.37178 .63677 m .36856 .63809 L .37024 .6367 L F
.193 0 0 r
.37024 .6367 m .37236 .63626 L .37178 .63677 L F
.933 .724 .597 r
.68639 .49445 m .68769 .49725 L .68798 .49542 L F
.51 .533 .816 r
.29711 .61573 m .29766 .6119 L .29577 .6124 L F
.29711 .61573 m .29899 .61523 L .29766 .6119 L F
.582 .634 .868 r
.32716 .64573 m .32789 .64761 L .33003 .64703 L F
.322 0 .206 r
.4712 .64749 m .46828 .64965 L .47036 .64901 L F
.125 0 .23 r
.47341 .64453 m .4712 .64749 L .47274 .64651 L F
.369 .112 .386 r
.47036 .64901 m .47274 .64651 L .4712 .64749 L F
.218 0 .284 r
.47604 .64185 m .47539 .6438 L .47775 .64094 L F
.06 0 0 r
.54795 .59493 m .54606 .59523 L .54545 .59548 L F
.538 .338 .558 r
.65677 .50118 m .65951 .50098 L .65704 .49981 L F
.555 .316 .509 r
.65704 .49981 m .65951 .50098 L .66156 .49997 L F
.583 .846 .994 r
.26715 .67249 m .2648 .67315 L .26321 .67231 L F
.26715 .67249 m .2648 .67315 L .26321 .67231 L F
.997 .77 .445 r
.46236 .70698 m .46274 .70489 L .46142 .7041 L F
.372 0 .01 r
.46477 .7049 m .46274 .70489 L .46236 .70698 L F
.46477 .7049 m .46615 .70412 L .46274 .70489 L F
.236 0 0 r
.56137 .61299 m .56125 .61419 L .55855 .61501 L F
0 0 .309 r
.56318 .60915 m .56137 .61299 L .56167 .61006 L F
.56318 .60915 m .56263 .61192 L .56137 .61299 L F
0 0 0 r
.56263 .61192 m .56125 .61419 L .56137 .61299 L F
.586 .568 .8 r
.57768 .64708 m .57894 .65049 L .57593 .65044 L F
.677 .513 .656 r
.57949 .65236 m .57593 .65044 L .57894 .65049 L F
.57949 .65236 m .57673 .65303 L .57593 .65044 L F
0 0 .052 r
.52865 .60696 m .5292 .60582 L .5295 .60363 L F
0 .09 .633 r
.52865 .60696 m .53022 .6092 L .5292 .60582 L F
.283 .732 .959 r
.34912 .58351 m .3513 .58346 L .3528 .58411 L F
.458 .768 .996 r
.35347 .5828 m .35495 .58383 L .3528 .58411 L F
.544 .863 .996 r
.3528 .58411 m .3513 .58346 L .35347 .5828 L F
.458 .768 .996 r
.35347 .5828 m .35495 .58383 L .3528 .58411 L F
.684 .309 .332 r
.48823 .71502 m .48516 .71363 L .48833 .71337 L F
.625 .277 .361 r
.48833 .71337 m .49059 .71528 L .48823 .71502 L F
.53 .157 .277 r
.3962 .60862 m .39851 .60884 L .39661 .60735 L F
.489 .175 .36 r
.39661 .60735 m .39851 .60884 L .39897 .60699 L F
.927 .561 .144 r
.73517 .47812 m .73662 .48104 L .73855 .47844 L F
.73517 .47812 m .73568 .4802 L .73628 .48036 L F
.75 .446 .468 r
.73517 .47812 m .73568 .4802 L .73185 .47976 L F
0 0 .45 r
.7365 .47833 m .73568 .4802 L .73517 .47812 L F
.915 .685 .577 r
.73491 .48 m .73568 .4802 L .7365 .47833 L F
.666 .776 .932 r
.73568 .4802 m .73312 .48135 L .73185 .47976 L F
.915 .685 .577 r
.73387 .4811 m .73568 .4802 L .73491 .48 L F
.927 .561 .144 r
.73628 .48036 m .73568 .4802 L .73662 .48104 L F
.972 .747 .54 r
.73568 .4802 m .73705 .48359 L .73662 .48104 L F
.948 .731 .576 r
.60215 .56932 m .60179 .57218 L .60354 .57303 L F
.919 .588 .4 r
.60179 .57218 m .60387 .57494 L .60354 .57303 L F
.524 .804 .997 r
.54509 .65875 m .54877 .65893 L .54691 .6587 L F
.826 .626 .633 r
.54744 .65987 m .54877 .65893 L .54509 .65875 L F
.54744 .65987 m .54848 .66176 L .54877 .65893 L F
.677 .695 .859 r
.54877 .65893 m .54964 .65632 L .54691 .6587 L F
.54877 .65893 m .55135 .65895 L .54964 .65632 L F
.402 .251 .56 r
.54877 .65893 m .54848 .66176 L .54919 .66118 L F
.686 .439 .543 r
.54877 .65893 m .54919 .66118 L .55135 .65895 L F
.43 .514 .843 r
.41261 .59146 m .41124 .59334 L .41088 .5916 L F
.409 .485 .827 r
.41261 .59146 m .41393 .59472 L .41124 .59334 L F
.534 .497 .76 r
.50488 .65431 m .50195 .65215 L .50424 .65159 L F
.50488 .65431 m .50446 .65555 L .50195 .65215 L F
.343 0 .183 r
.50195 .65215 m .50266 .65435 L .50424 .65159 L F
.50195 .65215 m .50069 .6549 L .50266 .65435 L F
.071 0 .113 r
.52293 .66472 m .52013 .66802 L .52247 .66622 L F
.169 0 .195 r
.52247 .66622 m .52447 .66421 L .52293 .66472 L F
.473 .48 .784 r
.21367 .55438 m .21472 .55788 L .21292 .5582 L F
.286 .237 .626 r
.21472 .55788 m .21385 .56183 L .21292 .5582 L F
.225 0 0 r
.46792 .69506 m .47124 .6956 L .46842 .69497 L F
.923 .727 .62 r
.61621 .60117 m .61679 .59903 L .61494 .59787 L F
.367 .231 .561 r
.61107 .63574 m .611 .63799 L .60951 .63875 L F
.232 .095 .479 r
.611 .63799 m .60976 .64105 L .60951 .63875 L F
.387 .156 .437 r
.53746 .70466 m .53734 .70754 L .53514 .7075 L F
.395 .371 .714 r
.53734 .70754 m .53732 .70949 L .53514 .7075 L F
.825 .541 .509 r
.50315 .68456 m .49899 .68561 L .49966 .68447 L F
.50315 .68456 m .50303 .68634 L .49899 .68561 L F
.602 .345 .5 r
.50315 .68456 m .5054 .68657 L .50303 .68634 L F
.524 .159 .288 r
.47037 .70902 m .46908 .70657 L .46796 .7074 L F
.47037 .70902 m .47179 .70662 L .46908 .70657 L F
.72 .746 .873 r
.29575 .63881 m .29374 .63992 L .2924 .63837 L F
.29575 .63881 m .29374 .63992 L .2924 .63837 L F
.448 .184 .42 r
.45517 .66061 m .45306 .66113 L .45263 .66395 L F
.224 0 0 r
.49419 .61778 m .4961 .61841 L .49758 .61888 L F
.617 .072 0 r
.4961 .61841 m .50024 .61989 L .49758 .61888 L F
.582 .3 .454 r
.41813 .61034 m .41766 .61238 L .41523 .61258 L F
.606 .383 .551 r
.42022 .60967 m .41766 .61238 L .41813 .61034 L F
.49 .742 .984 r
.74275 .50312 m .74122 .50463 L .74019 .50345 L F
.74275 .50312 m .74365 .50447 L .74122 .50463 L F
.896 .764 .708 r
.53057 .66713 m .53253 .67081 L .53054 .66936 L F
.571 .843 .996 r
.53259 .67199 m .53054 .66936 L .53253 .67081 L F
.655 .378 .489 r
.53127 .66467 m .53057 .66713 L .52883 .66612 L F
.872 .818 .34 r
.53069 .6656 m .53057 .66713 L .53127 .66467 L F
.845 .381 .059 r
.53069 .6656 m .53342 .66846 L .53057 .66713 L F
.368 .524 .88 r
.53342 .66846 m .53148 .66884 L .53057 .66713 L F
.845 .381 .059 r
.53069 .6656 m .53201 .66805 L .53342 .66846 L F
.271 .753 .926 r
.53342 .66846 m .53201 .66805 L .53455 .66823 L F
.53342 .66846 m .53455 .66823 L .53608 .66835 L F
.368 .524 .88 r
.53342 .66846 m .53253 .67081 L .53148 .66884 L F
.55 .535 .792 r
.80068 .50507 m .79868 .50763 L .79747 .50472 L F
.80068 .50507 m .80088 .50724 L .79868 .50763 L F
.425 .256 .547 r
.80088 .50724 m .79887 .50968 L .79868 .50763 L F
.592 .563 .791 r
.70662 .48418 m .70701 .48623 L .70968 .48315 L F
.645 .644 .835 r
.70701 .48623 m .7107 .48705 L .70968 .48315 L F
.586 .938 .932 r
.75104 .52742 m .75246 .52759 L .75465 .52648 L F
.909 .598 .11 r
.74701 .48978 m .74683 .49143 L .74672 .48991 L F
.842 .886 .456 r
.74701 .48978 m .74826 .48583 L .74887 .488 L F
.74701 .48978 m .74672 .48991 L .74826 .48583 L F
.399 0 .064 r
.74863 .49044 m .74701 .48978 L .74887 .488 L F
.74863 .49044 m .74683 .49143 L .74701 .48978 L F
.468 .063 .188 r
.49217 .67859 m .49149 .68086 L .48893 .6809 L F
.247 0 .117 r
.49357 .68001 m .49217 .67859 L .49349 .67738 L F
.49357 .68001 m .49149 .68086 L .49217 .67859 L F
.554 .637 .887 r
.37932 .59492 m .3831 .59373 L .37817 .59491 L F
.37932 .59492 m .38335 .59578 L .3831 .59373 L F
.735 .694 .812 r
.53796 .65784 m .54421 .65968 L .54004 .6552 L F
.649 .549 .727 r
.53796 .65784 m .54154 .66081 L .54421 .65968 L F
.657 .679 .86 r
.53715 .65248 m .54133 .65641 L .53798 .65175 L F
0 0 .096 r
.54004 .6552 m .53796 .65784 L .53822 .65565 L F
.735 .694 .812 r
.53796 .65784 m .54004 .6552 L .53822 .65565 L F
0 0 .096 r
.54004 .6552 m .53988 .65594 L .53796 .65784 L F
.53988 .65594 m .53962 .65714 L .53819 .65774 L F
.53988 .65594 m .53819 .65774 L .53796 .65784 L F
.657 .679 .86 r
.53564 .65382 m .54001 .65581 L .53715 .65248 L F
.774 .391 .329 r
.54004 .6552 m .5414 .65756 L .53962 .65714 L F
.657 .679 .86 r
.54001 .65581 m .54041 .65599 L .54013 .65568 L F
.54001 .65581 m .54013 .65568 L .53715 .65248 L F
.54041 .65599 m .54133 .65641 L .53715 .65248 L F
.815 .346 0 r
.54004 .6552 m .54421 .65968 L .54299 .65876 L F
.6 .542 .76 r
.53564 .65382 m .53962 .65714 L .54083 .65663 L F
.815 .346 0 r
.54004 .6552 m .54129 .65671 L .54063 .65623 L F
.54129 .65671 m .54299 .65876 L .54104 .65666 L F
.54129 .65671 m .54104 .65666 L .54063 .65623 L F
.438 .582 .9 r
.53798 .65175 m .54133 .65641 L .54017 .65341 L F
.684 .98 .848 r
.54133 .65641 m .54083 .65663 L .54105 .65545 L F
.54083 .65663 m .53962 .65714 L .54016 .65651 L F
.6 .542 .76 r
.54041 .65599 m .54083 .65663 L .54133 .65641 L F
.53564 .65382 m .54083 .65663 L .54041 .65599 L F
.684 .98 .848 r
.54083 .65663 m .54016 .65651 L .54105 .65545 L F
.815 .346 0 r
.54063 .65623 m .54299 .65876 L .54148 .65762 L F
.5411 .65705 m .54148 .65762 L .5414 .65756 L F
.54063 .65623 m .54148 .65762 L .5411 .65705 L F
.108 .23 .709 r
.54154 .66081 m .5414 .65756 L .54421 .65968 L F
.217 0 .294 r
.47836 .63895 m .47775 .64094 L .48006 .63804 L F
.635 .154 0 r
.53315 .61272 m .53022 .6092 L .53151 .61015 L F
.844 .416 .215 r
.53425 .61286 m .53315 .61272 L .53151 .61015 L F
.369 0 .071 r
.31627 .58666 m .31854 .58634 L .32 .58454 L F
.307 0 0 r
.31854 .58634 m .32229 .58445 L .32 .58454 L F
.178 0 0 r
.7486 .51184 m .75106 .51238 L .75203 .51255 L F
.287 .701 .972 r
.75385 .5119 m .75203 .51255 L .75106 .51238 L F
.75385 .5119 m .75465 .51275 L .75203 .51255 L F
.265 .064 .409 r
.43168 .68973 m .43009 .69064 L .42977 .69267 L F
.412 0 0 r
.55318 .65807 m .54964 .65632 L .55135 .65895 L F
.093 0 .012 r
.55135 .65895 m .5493 .66106 L .55145 .65941 L F
.55193 .65867 m .55145 .65941 L .55318 .65807 L F
.55135 .65895 m .55145 .65941 L .55193 .65867 L F
.5493 .66106 m .54919 .66118 L .54936 .66104 L F
.5493 .66106 m .54936 .66104 L .55318 .65807 L F
.439 0 0 r
.54534 .66608 m .54895 .66696 L .54745 .66373 L F
.934 .783 .671 r
.54532 .66207 m .54624 .66337 L .54643 .66155 L F
.54624 .66337 m .54677 .66412 L .54655 .66247 L F
.54624 .66337 m .54655 .66247 L .54643 .66155 L F
.663 .322 .385 r
.54592 .66411 m .54534 .66608 L .54677 .66412 L F
.077 0 .442 r
.54595 .66426 m .54557 .6653 L .54587 .66443 L F
.54557 .6653 m .54553 .66542 L .54558 .66526 L F
.54557 .6653 m .54558 .66526 L .54587 .66443 L F
.622 .629 .836 r
.54279 .6641 m .54571 .66476 L .54569 .66461 L F
.663 .322 .385 r
.54516 .66411 m .54577 .66462 L .54592 .66411 L F
.54279 .6641 m .54569 .66461 L .54516 .66411 L F
.54569 .66461 m .54577 .66462 L .54516 .66411 L F
.674 .741 .9 r
.54578 .66272 m .54279 .6641 L .54677 .66412 L F
.439 0 0 r
.54595 .66426 m .54643 .66155 L .54655 .66247 L F
.202 .303 .745 r
.54576 .66467 m .54571 .66476 L .54569 .66461 L F
.677 .308 .339 r
.54571 .66476 m .54534 .66608 L .54279 .6641 L F
.663 .322 .385 r
.54279 .6641 m .54534 .66608 L .54577 .66462 L F
.077 0 .442 r
.54588 .66447 m .54553 .66542 L .54595 .66426 L F
.54572 .66496 m .54553 .66542 L .54599 .66418 L F
.54587 .66443 m .54553 .66542 L .54571 .66476 L F
.439 0 0 r
.54534 .66608 m .54587 .66388 L .54595 .66426 L F
.54587 .66388 m .54643 .66155 L .54595 .66426 L F
.674 .741 .9 r
.54532 .66207 m .54506 .66229 L .54578 .66272 L F
.54506 .66229 m .54279 .6641 L .54578 .66272 L F
.202 .303 .745 r
.54549 .66216 m .54576 .66467 L .54532 .66207 L F
.54667 .66277 m .54595 .66426 L .54549 .66216 L F
.54595 .66426 m .54576 .66467 L .54549 .66216 L F
.54576 .66467 m .54569 .66461 L .54532 .66207 L F
.622 .629 .836 r
.54279 .6641 m .54569 .66461 L .54532 .66207 L F
.439 0 0 r
.54534 .66608 m .54655 .66247 L .54677 .66412 L F
.077 0 .442 r
.54599 .66418 m .54588 .66447 L .54595 .66426 L F
.439 0 0 r
.5461 .66292 m .54637 .66308 L .54643 .66155 L F
.54637 .66308 m .54745 .66373 L .5467 .66211 L F
.54637 .66308 m .5467 .66211 L .54643 .66155 L F
.54534 .66608 m .54745 .66373 L .54637 .66308 L F
.077 0 .442 r
.54572 .66496 m .54534 .66608 L .54553 .66542 L F
.439 0 0 r
.54534 .66608 m .54637 .66308 L .5461 .66292 L F
.077 0 .442 r
.54667 .66277 m .54534 .66608 L .54572 .66496 L F
.54667 .66277 m .54572 .66496 L .54599 .66418 L F
.934 .783 .671 r
.54532 .66207 m .54643 .66155 L .54848 .66176 L F
.54532 .66207 m .54848 .66176 L .54744 .65987 L F
.516 .436 .703 r
.54848 .66176 m .55085 .66354 L .54919 .66118 L F
0 0 0 r
.55143 .65943 m .55204 .65981 L .55318 .65807 L F
.54936 .66104 m .55041 .66059 L .55143 .65943 L F
.686 .68 .838 r
.5461 .65514 m .54691 .6587 L .54964 .65632 L F
.384 .547 .893 r
.54829 .65718 m .5508 .66045 L .54744 .65987 L F
0 0 .351 r
.55085 .66354 m .5515 .66148 L .54919 .66118 L F
.5515 .66148 m .55121 .66113 L .54919 .66118 L F
.55162 .66112 m .55112 .6609 L .54919 .66118 L F
.55112 .6609 m .55041 .66059 L .54919 .66118 L F
.55112 .6609 m .54919 .66118 L .54919 .66118 L F
.55085 .66354 m .55205 .66226 L .55204 .65981 L F
.318 .08 .387 r
.55205 .66226 m .55032 .66345 L .55103 .66091 L F
.55114 .6609 m .55103 .66091 L .55107 .66079 L F
0 0 .351 r
.5515 .66148 m .55162 .66112 L .55121 .66113 L F
.318 .08 .387 r
.55205 .66226 m .55103 .66091 L .55114 .6609 L F
.708 .453 .537 r
.55097 .66083 m .55032 .66345 L .54667 .66277 L F
.55107 .66079 m .55103 .66091 L .55097 .66083 L F
.55103 .66091 m .55032 .66345 L .55097 .66083 L F
.55062 .66068 m .55061 .66068 L .55058 .66067 L F
.384 .547 .893 r
.5507 .66065 m .55107 .66079 L .55062 .66068 L F
0 0 .351 r
.55094 .66063 m .55204 .65981 L .55058 .66067 L F
.499 .602 .886 r
.55204 .65981 m .55107 .66079 L .55094 .66063 L F
0 0 .351 r
.55181 .66054 m .55204 .65981 L .5514 .66058 L F
.384 .547 .893 r
.55094 .66063 m .55107 .66079 L .5507 .66065 L F
0 0 .351 r
.55162 .66112 m .55181 .66054 L .55058 .66067 L F
.318 .08 .387 r
.55205 .66226 m .55114 .6609 L .55204 .65981 L F
.55114 .6609 m .55107 .66079 L .55204 .65981 L F
0 0 .351 r
.5514 .66058 m .55204 .65981 L .55094 .66063 L F
.55058 .66067 m .55204 .65981 L .55041 .66059 L F
0 0 0 r
.55041 .66059 m .55204 .65981 L .55143 .65943 L F
.499 .602 .886 r
.55204 .65981 m .55094 .66063 L .54829 .65718 L F
.384 .547 .893 r
.55091 .66059 m .55094 .66063 L .5507 .66065 L F
.708 .453 .537 r
.55058 .66067 m .55009 .66096 L .55039 .66062 L F
.55061 .66068 m .55009 .66096 L .55058 .66067 L F
.384 .547 .893 r
.5508 .66045 m .55091 .66059 L .5506 .66053 L F
.5508 .66045 m .5506 .66053 L .54744 .65987 L F
0 0 0 r
.54919 .66118 m .55016 .66071 L .54936 .66104 L F
.55016 .66071 m .55041 .66059 L .54936 .66104 L F
.708 .453 .537 r
.55039 .66062 m .54667 .66277 L .54744 .65987 L F
.55009 .66096 m .54667 .66277 L .55039 .66062 L F
.55107 .66079 m .55033 .66112 L .55062 .66068 L F
.55033 .66112 m .54667 .66277 L .55062 .66068 L F
.384 .547 .893 r
.55091 .66059 m .55062 .66068 L .54744 .65987 L F
.233 0 .228 r
.47274 .64651 m .47539 .6438 L .47341 .64453 L F
.673 .387 .479 r
.53889 .70599 m .53734 .70754 L .53746 .70466 L F
.53985 .70688 m .5385 .70724 L .53889 .70599 L F
.5385 .70724 m .53734 .70754 L .53889 .70599 L F
.53746 .70466 m .53734 .70754 L .53985 .70688 L F
.767 .68 .767 r
.53985 .70688 m .53732 .70949 L .53734 .70754 L F
.53985 .70688 m .53732 .70949 L .53734 .70754 L F
0 0 .064 r
.53906 .70663 m .53857 .70852 L .53793 .70901 L F
.53828 .70791 m .53793 .70901 L .53732 .70949 L F
.53906 .70663 m .53793 .70901 L .53828 .70791 L F
.673 .387 .479 r
.53985 .70688 m .53746 .70466 L .53703 .70586 L F
.53746 .70466 m .53985 .70688 L .53703 .70586 L F
.193 0 .251 r
.53746 .70466 m .53703 .70586 L .53956 .70218 L F
.53956 .70218 m .53703 .70586 L .53746 .70466 L F
.774 .304 .125 r
.74641 .47675 m .74703 .47522 L .74583 .47432 L F
.74641 .47675 m .74896 .47733 L .74703 .47522 L F
.094 0 0 r
.3675 .62466 m .36801 .62548 L .36988 .6244 L F
.3675 .62466 m .36583 .62617 L .36801 .62548 L F
.854 .574 .514 r
.54165 .67022 m .53971 .67107 L .53793 .66947 L F
.849 .998 .784 r
.54298 .66726 m .54165 .67022 L .54401 .66963 L F
.54298 .66726 m .54121 .66977 L .54165 .67022 L F
.766 .995 .863 r
.54121 .66977 m .53971 .67107 L .54165 .67022 L F
.682 .975 .905 r
.56852 .62729 m .56795 .62686 L .56925 .62592 L F
.791 .554 .578 r
.60376 .57762 m .60732 .57567 L .60387 .57494 L F
.60376 .57762 m .60728 .57806 L .60732 .57567 L F
.547 .52 .776 r
.53454 .66542 m .53525 .66762 L .53737 .66687 L F
.398 .391 .735 r
.53525 .66762 m .53767 .66878 L .53737 .66687 L F
.372 0 0 r
.7771 .52973 m .77751 .52989 L .77363 .52948 L F
.202 .637 .949 r
.7771 .52973 m .77918 .53021 L .77819 .52929 L F
.7771 .52973 m .77819 .52929 L .77751 .52989 L F
.347 .29 .65 r
.43111 .68476 m .43317 .68677 L .43322 .6837 L F
.43111 .68476 m .43165 .6872 L .43317 .68677 L F
.04 .006 .486 r
.44867 .68618 m .4478 .68962 L .44675 .68757 L F
.384 .67 .972 r
.38793 .58579 m .38994 .58582 L .38919 .58714 L F
.509 .819 1 r
.38919 .58714 m .38994 .58582 L .3914 .58667 L F
0 .248 .722 r
.53956 .70218 m .54157 .70334 L .54114 .70238 L F
.53956 .70218 m .54231 .70412 L .54157 .70334 L F
0 0 .042 r
.48096 .6363 m .48006 .63804 L .48241 .6352 L F
.634 .42 .575 r
.51716 .76457 m .51915 .76648 L .52047 .76516 L F
.579 .865 .543 r
.52047 .76516 m .51915 .76648 L .52057 .76501 L F
.796 .833 .88 r
.46414 .6954 m .45999 .69598 L .46221 .69461 L F
.46414 .6954 m .4612 .69678 L .45999 .69598 L F
.733 .579 .682 r
.46414 .6954 m .46422 .69725 L .4612 .69678 L F
.572 .453 .679 r
.46414 .6954 m .46451 .69664 L .46422 .69725 L F
.95 .649 .429 r
.46221 .69461 m .46451 .69664 L .46414 .6954 L F
.618 .744 .936 r
.34234 .62232 m .34073 .62272 L .3389 .62117 L F
0 0 .079 r
.56404 .60698 m .56318 .60915 L .56167 .61006 L F
.506 .207 .393 r
.49446 .65896 m .49103 .66289 L .4921 .66163 L F
.992 .791 .533 r
.5995 .59763 m .60061 .5986 L .59924 .6 L F
.927 .614 .43 r
.60061 .5986 m .60103 .60113 L .59924 .6 L F
.992 .791 .533 r
.5995 .59763 m .60061 .5986 L .59924 .6 L F
.463 .694 .967 r
.33367 .6473 m .3361 .64732 L .33443 .64571 L F
.332 .811 .772 r
.54054 .5974 m .53738 .59838 L .53948 .59706 L F
.346 .824 .815 r
.54176 .59672 m .54054 .5974 L .53948 .59706 L F
.54176 .59672 m .54348 .5965 L .54054 .5974 L F
.868 .805 .785 r
.29579 .6243 m .29299 .62804 L .29194 .62637 L F
.632 .699 .894 r
.29371 .62914 m .29558 .62702 L .29194 .62637 L F
.29371 .62914 m .29646 .62911 L .29558 .62702 L F
.618 .621 .831 r
.29371 .62914 m .29687 .62984 L .29646 .62911 L F
.431 .066 .243 r
.5295 .60363 m .53177 .60346 L .5323 .6012 L F
.559 .935 .857 r
.5323 .6012 m .5336 .59997 L .53416 .60012 L F
0 0 .079 r
.5323 .6012 m .53325 .60195 L .5336 .59997 L F
.5323 .6012 m .53177 .60346 L .53325 .60195 L F
.585 .22 .316 r
.56029 .67289 m .5593 .67505 L .55691 .67352 L F
0 .319 .758 r
.5591 .67042 m .56288 .6729 L .56029 .67289 L F
.781 .542 .575 r
.56277 .6729 m .5593 .67505 L .56029 .67289 L F
.56275 .67298 m .5593 .67505 L .56277 .6729 L F
0 .319 .758 r
.5591 .67042 m .56184 .67196 L .56288 .6729 L F
.781 .542 .575 r
.56288 .6729 m .5629 .67535 L .5593 .67505 L F
.985 .718 .346 r
.56184 .67196 m .56188 .67457 L .56234 .67493 L F
.56251 .67412 m .56234 .67493 L .5629 .67535 L F
.56184 .67196 m .56234 .67493 L .56251 .67412 L F
.781 .542 .575 r
.56288 .6729 m .56275 .67298 L .56277 .6729 L F
.474 .134 .308 r
.39414 .62654 m .39078 .62928 L .39192 .62693 L F
.664 .462 .601 r
.54691 .6587 m .54744 .65987 L .54509 .65875 L F
.205 .243 .68 r
.21414 .57146 m .21284 .57279 L .21215 .56927 L F
.119 0 .393 r
.21404 .57402 m .21284 .57279 L .21414 .57146 L F
.21404 .57402 m .21257 .57514 L .21284 .57279 L F
.536 .704 .948 r
.74626 .52832 m .74755 .52613 L .74522 .52656 L F
.74626 .52832 m .74894 .52795 L .74755 .52613 L F
.449 .092 .266 r
.37517 .62083 m .37742 .62054 L .37812 .61898 L F
.223 0 .155 r
.37812 .61898 m .37949 .61958 L .38044 .61856 L F
.37812 .61898 m .37742 .62054 L .37949 .61958 L F
.237 0 .338 r
.21083 .5783 m .21002 .58056 L .20881 .58139 L F
.217 .133 .541 r
.21017 .5805 m .20881 .58139 L .21002 .58056 L F
.21017 .5805 m .20888 .58394 L .20881 .58139 L F
.383 .07 .305 r
.38044 .61856 m .38251 .61797 L .38342 .6154 L F
.454 .136 .335 r
.38342 .6154 m .3848 .61747 L .38571 .61508 L F
.38342 .6154 m .38251 .61797 L .3848 .61747 L F
.716 .569 .688 r
.7838 .52134 m .78396 .52451 L .78122 .52445 L F
.771 .658 .738 r
.78635 .52079 m .78396 .52451 L .7838 .52134 L F
.286 .503 .892 r
.73631 .52083 m .73719 .51929 L .73451 .51765 L F
.73631 .52083 m .73796 .52081 L .73719 .51929 L F
.868 .805 .785 r
.29579 .6243 m .29194 .62637 L .29558 .62702 L F
.532 .267 .459 r
.29579 .6243 m .29558 .62702 L .29726 .62594 L F
.569 .344 .534 r
.57806 .57836 m .58055 .57812 L .58054 .57574 L F
.513 .27 .483 r
.58055 .57812 m .58306 .57538 L .58054 .57574 L F
.687 .912 .576 r
.59557 .63428 m .59761 .6318 L .59599 .63421 L F
.093 .596 .896 r
.53993 .62136 m .5404 .62098 L .53915 .62015 L F
.54075 .62149 m .54191 .62167 L .5404 .62098 L F
.663 .132 0 r
.54457 .62281 m .5404 .62098 L .54191 .62167 L F
.54457 .62281 m .54275 .62265 L .5404 .62098 L F
.497 0 0 r
.54275 .62265 m .54013 .62059 L .5404 .62098 L F
.54013 .62059 m .53893 .61965 L .5404 .62098 L F
.093 .596 .896 r
.53993 .62136 m .54075 .62149 L .5404 .62098 L F
.609 .856 .99 r
.76035 .51164 m .75789 .51253 L .7594 .51075 L F
.665 .953 .951 r
.7594 .51075 m .75789 .51253 L .75715 .51205 L F
0 0 0 r
.57219 .59378 m .57186 .59419 L .57006 .59567 L F
.27 0 0 r
.57219 .59378 m .5745 .59417 L .57312 .59457 L F
.271 .695 .967 r
.40894 .59049 m .40761 .59117 L .40639 .59036 L F
.40894 .59049 m .41088 .5916 L .40761 .59117 L F
.548 .579 .838 r
.53074 .65728 m .53443 .6601 L .53328 .65698 L F
0 0 0 r
.53328 .65698 m .53076 .65773 L .53074 .65728 L F
.52975 .65855 m .53074 .65728 L .53069 .65661 L F
.53076 .65773 m .52924 .65818 L .53074 .65728 L F
.53069 .65661 m .53074 .65728 L .53144 .65508 L F
.53144 .65508 m .53074 .65728 L .53437 .65368 L F
.742 .704 .816 r
.70968 .48315 m .7107 .48705 L .71322 .48548 L F
.745 .95 .638 r
.33596 .6444 m .33443 .64571 L .33252 .64431 L F
.286 .237 .626 r
.21472 .55788 m .21501 .56124 L .21385 .56183 L F
0 0 0 r
.21501 .56124 m .2135 .56399 L .21385 .56183 L F
.512 .244 .445 r
.52624 .66665 m .52529 .66967 L .5231 .66997 L F
.583 .313 .474 r
.52789 .66929 m .52624 .66665 L .52883 .66612 L F
.52789 .66929 m .52529 .66967 L .52624 .66665 L F
.117 .107 .569 r
.55311 .66968 m .55503 .67088 L .55617 .66978 L F
.741 .972 .711 r
.55782 .66764 m .55617 .66978 L .55644 .66843 L F
.762 .914 .535 r
.55617 .66978 m .55503 .67088 L .55644 .66843 L F
.723 .772 .892 r
.66627 .50437 m .67013 .50504 L .66872 .50349 L F
.746 .799 .895 r
.66872 .50349 m .67013 .50504 L .67212 .50368 L F
.828 .393 0 r
.4664 .70593 m .46615 .70412 L .46477 .7049 L F
.46627 .70497 m .46796 .7074 L .46615 .70412 L F
.499 .34 .596 r
.46667 .70185 m .4671 .70483 L .46621 .70486 L F
.46558 .7036 m .46621 .70486 L .46477 .7049 L F
.46667 .70185 m .46621 .70486 L .46558 .7036 L F
.828 .393 0 r
.4664 .70593 m .46707 .70656 L .46627 .70497 L F
.46707 .70656 m .46796 .7074 L .46627 .70497 L F
.548 .87 .994 r
.76645 .51128 m .76369 .51211 L .7628 .51142 L F
.633 .57 .766 r
.77405 .5044 m .77445 .50649 L .77655 .50371 L F
.581 .497 .725 r
.77445 .50649 m .77695 .50603 L .77655 .50371 L F
.532 .403 .65 r
.77513 .50826 m .77695 .50603 L .77445 .50649 L F
.689 .541 .681 r
.46671 .6718 m .46795 .67594 L .46561 .67549 L F
.508 .539 .823 r
.46897 .67001 m .46671 .6718 L .46677 .66972 L F
.46897 .67001 m .47022 .67279 L .46671 .6718 L F
.691 .639 .793 r
.47022 .67279 m .46795 .67594 L .46671 .6718 L F
.49 0 0 r
.55244 .64994 m .55473 .65149 L .55608 .65206 L F
0 .527 .821 r
.55473 .65149 m .55789 .65241 L .55608 .65206 L F
.438 .238 .51 r
.2135 .56399 m .21332 .56686 L .2115 .56726 L F
0 0 0 r
.21501 .56124 m .21434 .56262 L .2135 .56399 L F
0 0 .24 r
.21427 .565 m .2135 .56399 L .21434 .56262 L F
.21427 .565 m .21332 .56686 L .2135 .56399 L F
.489 .312 .567 r
.43238 .67608 m .43452 .67557 L .43455 .67295 L F
.478 .354 .633 r
.43273 .67855 m .43452 .67557 L .43238 .67608 L F
.09 .584 .9 r
.4564 .69476 m .45999 .69598 L .45768 .69558 L F
.619 .265 .349 r
.49698 .65869 m .49446 .65896 L .49379 .65899 L F
.498 .247 .464 r
.47812 .65552 m .47542 .65776 L .47621 .65666 L F
.949 .632 .399 r
.54883 .67486 m .54784 .67545 L .54747 .67274 L F
.55 .503 .756 r
.54883 .67486 m .54993 .67265 L .54747 .67274 L F
.54883 .67486 m .55116 .67549 L .54993 .67265 L F
.577 .409 .616 r
.79647 .49817 m .79673 .50053 L .79416 .50104 L F
.504 .476 .759 r
.79741 .50276 m .79416 .50104 L .79673 .50053 L F
.86 .738 .727 r
.60121 .61547 m .60221 .6187 L .5999 .61779 L F
.924 .833 .737 r
.60221 .6187 m .5993 .62083 L .5999 .61779 L F
.60221 .6187 m .60107 .62093 L .5993 .62083 L F
.424 .113 .331 r
.40498 .61874 m .40467 .62016 L .40229 .62063 L F
.499 .223 .426 r
.40713 .61817 m .40467 .62016 L .40498 .61874 L F
0 .153 .684 r
.45164 .69843 m .45355 .70061 L .4529 .70174 L F
.201 .508 .91 r
.45355 .70061 m .45551 .70261 L .4529 .70174 L F
.723 .279 .197 r
.45779 .71039 m .45991 .7125 L .45626 .71173 L F
.352 .22 .557 r
.33084 .6096 m .33085 .61186 L .32928 .61243 L F
.53 .485 .75 r
.33085 .61186 m .32967 .61577 L .32928 .61243 L F
.486 .242 .47 r
.43126 .60386 m .4312 .60553 L .42898 .60552 L F
.58 .276 .417 r
.4312 .60553 m .42784 .60846 L .42898 .60552 L F
.155 0 0 r
.55319 .5918 m .55544 .5914 L .55625 .58958 L F
.135 0 0 r
.55625 .58958 m .55544 .5914 L .55849 .58918 L F
.645 .729 .91 r
.4612 .69678 m .46422 .69725 L .46221 .69461 L F
.838 .781 .798 r
.46422 .69725 m .46451 .69664 L .46221 .69461 L F
.477 .199 .413 r
.4655 .65285 m .46781 .65223 L .46828 .64965 L F
.455 .18 .406 r
.46828 .64965 m .46964 .65091 L .47036 .64901 L F
.46828 .64965 m .46781 .65223 L .46964 .65091 L F
.307 0 0 r
.52122 .63369 m .52351 .6343 L .52479 .63419 L F
.009 0 0 r
.52351 .6343 m .52721 .6342 L .52479 .63419 L F
.714 .775 .901 r
.79445 .51772 m .79783 .51803 L .79699 .51652 L F
.714 .776 .9 r
.79699 .51652 m .79783 .51803 L .80052 .51662 L F
.523 .314 .537 r
.80407 .51795 m .80402 .52059 L .80148 .5211 L F
.048 .014 .493 r
.57006 .59567 m .57161 .59716 L .57013 .59791 L F
.57006 .59567 m .57186 .59419 L .57161 .59716 L F
.627 .78 .329 r
.47689 .66911 m .47615 .67053 L .47827 .66978 L F
.53 .485 .75 r
.33085 .61186 m .33171 .61531 L .32967 .61577 L F
.17 0 0 r
.51921 .65409 m .52162 .65376 L .52285 .653 L F
.451 .842 .628 r
.52285 .653 m .52162 .65376 L .52376 .65227 L F
.632 .43 .591 r
.52532 .6525 m .52272 .65531 L .52285 .653 L F
.852 .758 .759 r
.55789 .65241 m .55598 .65517 L .55877 .65524 L F
.878 .63 .56 r
.55584 .65732 m .55877 .65524 L .55598 .65517 L F
.55584 .65732 m .55857 .65918 L .55877 .65524 L F
.407 .058 .257 r
.52856 .65249 m .52559 .65542 L .52532 .6525 L F
.52856 .65249 m .52793 .65501 L .52559 .65542 L F
.199 0 .188 r
.52931 .65405 m .52793 .65501 L .52856 .65249 L F
.304 .709 .977 r
.75521 .48677 m .75424 .48596 L .75185 .48588 L F
0 .278 .77 r
.75521 .48677 m .75683 .48725 L .75424 .48596 L F
.75521 .48677 m .75779 .48856 L .75683 .48725 L F
.897 .885 .813 r
.55016 .60619 m .55154 .60717 L .55312 .60518 L F
.55148 .60554 m .55312 .60518 L .55371 .60444 L F
.55016 .60619 m .55312 .60518 L .55148 .60554 L F
.872 .597 .519 r
.54901 .60212 m .55105 .6047 L .55017 .60118 L F
.54776 .60313 m .54924 .60384 L .54901 .60212 L F
.54924 .60384 m .55105 .6047 L .54901 .60212 L F
0 0 .252 r
.54926 .60397 m .54926 .60399 L .54924 .60384 L F
.858 .659 .631 r
.54924 .60384 m .54926 .60399 L .54776 .60313 L F
0 0 0 r
.54926 .60398 m .54924 .60406 L .54926 .60399 L F
.871 .492 .324 r
.54926 .60399 m .54924 .60406 L .54776 .60313 L F
.872 .597 .519 r
.54926 .60384 m .5512 .60529 L .55105 .6047 L F
0 0 0 r
.54926 .60398 m .54926 .60399 L .54926 .60397 L F
.872 .597 .519 r
.54776 .60313 m .54927 .60408 L .54926 .60384 L F
.55007 .60458 m .5512 .60529 L .55001 .60441 L F
.54924 .60406 m .55128 .60558 L .5512 .60529 L F
.54922 .60415 m .55128 .60558 L .54924 .60406 L F
.55128 .60558 m .55135 .60564 L .55138 .60556 L F
.55135 .60564 m .55141 .60567 L .55139 .60561 L F
.897 .885 .813 r
.55016 .60619 m .55148 .60554 L .55057 .60623 L F
.872 .597 .519 r
.55135 .60564 m .55139 .60561 L .55138 .60556 L F
.234 0 .275 r
.55371 .60444 m .55154 .60717 L .55341 .60623 L F
.591 .844 .993 r
.55341 .60623 m .55154 .60717 L .55016 .60619 L F
.55341 .60623 m .55208 .60621 L .55261 .60645 L F
.55208 .60621 m .55016 .60619 L .55261 .60645 L F
.897 .885 .813 r
.55057 .60623 m .55371 .60444 L .55261 .60645 L F
.55148 .60554 m .55371 .60444 L .55057 .60623 L F
.138 0 0 r
.54781 .60663 m .55141 .60567 L .55013 .60478 L F
.54874 .60563 m .55013 .60478 L .54922 .60415 L F
0 0 0 r
.54955 .6034 m .54886 .60542 L .54922 .60412 L F
.54925 .60404 m .54922 .60412 L .54924 .60406 L F
.54955 .6034 m .54922 .60412 L .54925 .60404 L F
.138 0 0 r
.54781 .6062 m .54874 .60563 L .54776 .60313 L F
.54874 .60563 m .54922 .60415 L .54776 .60313 L F
.54781 .60663 m .55013 .60478 L .54781 .6062 L F
.872 .597 .519 r
.55128 .60558 m .55138 .60556 L .55017 .60118 L F
.329 .273 .642 r
.55017 .60118 m .55141 .60567 L .55212 .60272 L F
.138 0 0 r
.54926 .60625 m .55016 .60619 L .55141 .60567 L F
.54781 .60663 m .55016 .60619 L .54926 .60625 L F
.596 .447 .649 r
.55016 .60619 m .55212 .60272 L .55141 .60567 L F
.55016 .60619 m .55057 .60623 L .55042 .60573 L F
.705 .336 .346 r
.54886 .60542 m .55137 .60611 L .55016 .60619 L F
.596 .447 .649 r
.55057 .60623 m .55261 .60645 L .55042 .60573 L F
.705 .336 .346 r
.55137 .60611 m .55261 .60645 L .55055 .60617 L F
.55055 .60617 m .55261 .60645 L .55016 .60619 L F
.596 .447 .649 r
.55042 .60573 m .55261 .60645 L .55222 .60351 L F
.55139 .60402 m .55222 .60351 L .55212 .60272 L F
.55042 .60573 m .55222 .60351 L .55139 .60402 L F
.705 .336 .346 r
.54886 .60542 m .5532 .60672 L .55261 .60645 L F
.566 .933 .8 r
.55341 .60623 m .55472 .605 L .55261 .60645 L F
.55341 .60623 m .55472 .605 L .55261 .60645 L F
.456 .315 .6 r
.55261 .60645 m .55476 .6075 L .55472 .605 L F
.55261 .60645 m .55476 .6075 L .55472 .605 L F
.036 .395 .852 r
.55387 .60692 m .55476 .6075 L .55261 .60645 L F
.705 .336 .346 r
.5532 .60672 m .55387 .60692 L .55261 .60645 L F
.872 .597 .519 r
.54927 .60408 m .55007 .60458 L .54926 .60384 L F
.55007 .60458 m .55001 .60441 L .54926 .60384 L F
.54776 .60313 m .55017 .60118 L .54882 .59983 L F
0 0 0 r
.54955 .6034 m .54926 .60398 L .54949 .60129 L F
.54926 .60398 m .54926 .60397 L .54949 .60129 L F
.54955 .6034 m .54924 .60406 L .54926 .60398 L F
.872 .597 .519 r
.54776 .60313 m .54922 .60415 L .54924 .60406 L F
.871 .492 .324 r
.54924 .60406 m .54886 .60542 L .54776 .60313 L F
0 0 .252 r
.54949 .60129 m .54926 .60397 L .54882 .59983 L F
.54926 .60397 m .54924 .60384 L .54882 .59983 L F
.858 .659 .631 r
.54882 .59983 m .54924 .60384 L .54776 .60313 L F
.981 .688 .361 r
.55256 .60178 m .55371 .60444 L .55212 .60272 L F
.962 .653 .393 r
.55341 .60623 m .55261 .60645 L .55371 .60444 L F
.719 .523 .624 r
.54993 .67265 m .55311 .66968 L .54991 .66976 L F
.798 .313 .055 r
.59904 .56689 m .60215 .56932 L .60246 .56696 L F
.709 .449 .53 r
.49985 .71522 m .49708 .71282 L .5001 .71319 L F
.819 .552 .534 r
.49966 .71175 m .50217 .71075 L .5001 .71319 L F
.698 .609 .753 r
.50303 .71262 m .5001 .71319 L .50217 .71075 L F
.493 .846 .587 r
.50303 .71262 m .49985 .71522 L .5001 .71319 L F
.615 .261 .348 r
.44174 .66934 m .44425 .66929 L .44538 .66725 L F
.537 .177 .305 r
.44538 .66725 m .44728 .6688 L .4477 .66688 L F
.44538 .66725 m .44425 .66929 L .44728 .6688 L F
.179 .346 .795 r
.55691 .67352 m .55843 .67227 L .55613 .67331 L F
.55691 .67352 m .5593 .67505 L .55843 .67227 L F
.542 .166 .278 r
.45195 .69337 m .45033 .69516 L .44847 .69433 L F
.182 0 .007 r
.45195 .69337 m .45033 .69516 L .45247 .69412 L F
.363 .036 .271 r
.4935 .65641 m .49466 .65755 L .49593 .65588 L F
.4935 .65641 m .49294 .65815 L .49466 .65755 L F
.793 .367 .236 r
.54442 .64012 m .54654 .64258 L .5472 .64149 L F
0 0 0 r
.5472 .64149 m .5484 .64051 L .54956 .64146 L F
.5472 .64149 m .54654 .64258 L .5484 .64051 L F
.767 .662 .746 r
.52116 .66916 m .52247 .66622 L .52013 .66802 L F
.668 .317 .37 r
.47915 .71377 m .47519 .71552 L .47701 .71292 L F
.47915 .71377 m .47884 .7153 L .47519 .71552 L F
.405 .101 .332 r
.40229 .62063 m .40131 .6236 L .39923 .62419 L F
.467 .171 .378 r
.40467 .62016 m .40131 .6236 L .40229 .62063 L F
.541 .161 .27 r
.51681 .65309 m .5163 .65467 L .51921 .65409 L F
.942 .846 .411 r
.61664 .61383 m .617 .61591 L .61743 .61284 L F
.939 .839 .398 r
.61644 .61821 m .617 .61591 L .61664 .61383 L F
.466 .745 .989 r
.78039 .484 m .77903 .48548 L .77785 .48422 L F
.78039 .484 m .78142 .48519 L .77903 .48548 L F
.962 .701 .493 r
.60116 .61283 m .59975 .61444 L .59935 .6123 L F
.60116 .61283 m .60121 .61547 L .59975 .61444 L F
.921 .636 .486 r
.74896 .47733 m .74939 .48001 L .75058 .47805 L F
.736 .376 .37 r
.74939 .48001 m .75285 .48031 L .75058 .47805 L F
.477 .11 .263 r
.569 .58361 m .57231 .58119 L .56986 .5813 L F
.082 .236 .725 r
.5461 .65514 m .54829 .65718 L .54691 .6587 L F
.384 .547 .893 r
.54829 .65718 m .54744 .65987 L .54691 .6587 L F
.042 .574 .859 r
.35706 .5835 m .36082 .58446 L .35851 .58445 L F
.192 0 0 r
.37178 .63677 m .37551 .63506 L .37408 .63641 L F
.37178 .63677 m .37236 .63626 L .37551 .63506 L F
.125 0 0 r
.37408 .63641 m .37551 .63506 L .37752 .63456 L F
.797 .554 .57 r
.60746 .58061 m .60911 .57851 L .60728 .57806 L F
.60746 .58061 m .60916 .58097 L .60911 .57851 L F
.312 0 0 r
.36755 .63782 m .36622 .63853 L .36398 .6386 L F
.447 .879 .816 r
.78641 .52699 m .78535 .52783 L .78386 .5271 L F
.78641 .52699 m .78762 .52678 L .78535 .52783 L F
.442 .075 .244 r
.30305 .59191 m .30531 .5916 L .30605 .5901 L F
.4 .025 .207 r
.30531 .5916 m .30827 .58975 L .30605 .5901 L F
0 0 0 r
.48469 .62982 m .48283 .63293 L .48414 .63165 L F
.121 .004 .434 r
.48241 .6352 m .48414 .63165 L .48283 .63293 L F
.761 .476 .501 r
.68009 .48665 m .68022 .48894 L .68361 .4892 L F
.07 0 .125 r
.58363 .65869 m .5856 .65796 L .58607 .65578 L F
0 .158 .684 r
.58607 .65578 m .58665 .6545 L .58491 .65251 L F
.796 .724 .193 r
.58607 .65578 m .58582 .65575 L .58665 .6545 L F
.58607 .65578 m .5856 .65796 L .58582 .65575 L F
.691 .402 .48 r
.78122 .52445 m .78396 .52451 L .78386 .5271 L F
.938 .601 .363 r
.7462 .48261 m .7454 .48378 L .74599 .48222 L F
0 .092 .63 r
.74475 .48055 m .7462 .48261 L .74643 .48105 L F
.938 .601 .363 r
.7462 .48261 m .74599 .48222 L .74643 .48105 L F
0 0 .433 r
.74644 .48306 m .7462 .48261 L .74475 .48055 L F
.74656 .48323 m .7462 .48261 L .74644 .48306 L F
.805 .329 0 r
.74656 .48323 m .74688 .48473 L .7462 .48261 L F
.74656 .48323 m .74826 .48583 L .74688 .48473 L F
.25 .216 .623 r
.61056 .64352 m .6095 .64451 L .60976 .64105 L F
.008 0 .489 r
.61056 .64352 m .61019 .64688 L .6095 .64451 L F
.735 .302 0 r
.31787 .63856 m .31921 .64096 L .31721 .63792 L F
.856 .711 .701 r
.71651 .47713 m .71987 .4753 L .7167 .47462 L F
.71651 .47713 m .71914 .47872 L .71987 .4753 L F
.31 0 .015 r
.32229 .58445 m .32452 .58406 L .32559 .5829 L F
.295 0 0 r
.32452 .58406 m .32778 .58304 L .32559 .5829 L F
.495 .43 .713 r
.21332 .56686 m .21394 .56902 L .2115 .56726 L F
.465 .432 .736 r
.2115 .56726 m .21394 .56902 L .21215 .56927 L F
.179 .412 .85 r
.21166 .55127 m .2112 .55285 L .21049 .55118 L F
.171 .403 .845 r
.21166 .55127 m .21367 .55438 L .2112 .55285 L F
.625 .428 .595 r
.50873 .65849 m .51173 .65844 L .51154 .65579 L F
.488 .326 .586 r
.51154 .65579 m .51357 .65777 L .51394 .65546 L F
.51154 .65579 m .51173 .65844 L .51357 .65777 L F
.253 0 .09 r
.5831 .58742 m .58252 .58865 L .58021 .5893 L F
.344 0 .077 r
.5831 .58742 m .5841 .58884 L .58252 .58865 L F
.5831 .58742 m .5853 .58703 L .5841 .58884 L F
.338 0 0 r
.52721 .6342 m .52941 .63471 L .53087 .63454 L F
.328 .796 .93 r
.52941 .63471 m .53317 .63466 L .53087 .63454 L F
.548 .619 .875 r
.77141 .49335 m .77316 .49117 L .77089 .49155 L F
.77141 .49335 m .77452 .49419 L .77316 .49117 L F
.268 .671 .968 r
.7663 .52393 m .76763 .52326 L .76536 .52363 L F
.7663 .52393 m .76869 .52429 L .76763 .52326 L F
.49 .723 .975 r
.77092 .48131 m .76946 .48287 L .76841 .48161 L F
.77092 .48131 m .7719 .48268 L .76946 .48287 L F
.621 .537 .737 r
.79859 .49565 m .79647 .49817 L .7954 .49473 L F
.79859 .49565 m .79909 .49776 L .79647 .49817 L F
.514 .311 .542 r
.79909 .49776 m .79673 .50053 L .79647 .49817 L F
.945 .586 .211 r
.59887 .61016 m .59809 .61124 L .59712 .60898 L F
.59887 .61016 m .59935 .6123 L .59809 .61124 L F
.85 .6 .561 r
.6122 .58897 m .61384 .58711 L .6122 .58658 L F
.6122 .58897 m .61403 .58979 L .61384 .58711 L F
.205 .243 .68 r
.21414 .57146 m .21215 .56927 L .21394 .56902 L F
.861 .631 .589 r
.60916 .58097 m .60906 .58335 L .61209 .58412 L F
.86 .617 .57 r
.60906 .58335 m .6122 .58658 L .61209 .58412 L F
.506 .342 .593 r
.70617 .48079 m .70838 .48025 L .70832 .47785 L F
.464 .39 .688 r
.70617 .48079 m .70805 .48291 L .70838 .48025 L F
.70617 .48079 m .70662 .48418 L .70805 .48291 L F
.321 0 .225 r
.46082 .65598 m .45802 .65828 L .46023 .65772 L F
.378 .072 .314 r
.46293 .65538 m .46082 .65598 L .46023 .65772 L F
.309 .581 .938 r
.20812 .54892 m .20777 .55039 L .20626 .54893 L F
.20812 .54892 m .21049 .55118 L .20777 .55039 L F
.49 .308 .562 r
.29378 .60042 m .29586 .60065 L .29579 .59821 L F
.4 .301 .625 r
.29378 .60042 m .29586 .60254 L .29586 .60065 L F
.29378 .60042 m .29366 .60423 L .29586 .60254 L F
.563 .673 .913 r
.4631 .68638 m .46165 .68818 L .46085 .68682 L F
.4631 .68638 m .46391 .68812 L .46165 .68818 L F
.525 .629 .897 r
.72994 .49895 m .73086 .50112 L .72842 .50103 L F
.72842 .50103 m .73086 .50112 L .72994 .49895 L F
.72842 .50103 m .73086 .50112 L .72994 .49895 L F
.555 .06 .033 r
.59674 .56643 m .59525 .56695 L .59904 .56689 L F
.43 .177 .428 r
.58843 .57227 m .59094 .56964 L .58835 .56985 L F
.488 .176 .364 r
.41035 .61554 m .40938 .61788 L .40713 .61817 L F
.516 .203 .375 r
.41276 .61508 m .40938 .61788 L .41035 .61554 L F
.621 .66 .867 r
.53454 .66542 m .53551 .66341 L .53341 .66394 L F
.53454 .66542 m .53723 .66457 L .53551 .66341 L F
.547 .52 .776 r
.53454 .66542 m .53737 .66687 L .53723 .66457 L F
.87 .881 .842 r
.72852 .48914 m .73108 .48779 L .73086 .48604 L F
.664 .692 .866 r
.73086 .48604 m .73108 .48779 L .73451 .48697 L F
.507 .399 .666 r
.47369 .67819 m .47159 .67619 L .47373 .67597 L F
.612 .6 .814 r
.47716 .67518 m .47782 .67635 L .47373 .67597 L F
.769 .681 .767 r
.47782 .67635 m .47722 .67842 L .47369 .67819 L F
.47782 .67635 m .4772 .67662 L .47714 .67628 L F
0 .025 .595 r
.47731 .67523 m .47782 .67635 L .47716 .67518 L F
0 0 .346 r
.47731 .67523 m .47722 .67842 L .47782 .67635 L F
.47726 .6769 m .47753 .67822 L .47722 .67842 L F
.47731 .67523 m .47753 .67822 L .47726 .6769 L F
.103 0 0 r
.47722 .67842 m .47661 .67844 L .47369 .67819 L F
.307 .798 .785 r
.47722 .67842 m .4778 .67805 L .47661 .67844 L F
.813 .554 .546 r
.4778 .67805 m .47866 .67993 L .4745 .67918 L F
.4778 .67805 m .4745 .67918 L .4781 .6785 L F
.901 .575 .418 r
.47947 .67804 m .47866 .67993 L .4778 .67805 L F
.813 .554 .546 r
.4778 .67805 m .4781 .6785 L .47873 .67838 L F
0 0 .346 r
.47748 .67757 m .4778 .67805 L .47753 .67822 L F
.47731 .67523 m .4778 .67805 L .47748 .67757 L F
.769 .681 .767 r
.47714 .67628 m .47369 .67819 L .47373 .67597 L F
.4772 .67662 m .47369 .67819 L .47714 .67628 L F
.498 .384 .654 r
.29766 .59272 m .29832 .59589 L .30041 .5952 L F
.543 .551 .812 r
.41634 .59416 m .4153 .59739 L .41393 .59472 L F
.41634 .59416 m .41763 .59737 L .4153 .59739 L F
.256 .767 .823 r
.36722 .59625 m .36537 .59633 L .36309 .59681 L F
0 0 0 r
.36933 .59545 m .36537 .59633 L .36722 .59625 L F
.065 .618 .82 r
.4616 .69851 m .45974 .69815 L .4581 .69813 L F
.617 .134 .083 r
.46718 .71325 m .46951 .71482 L .46585 .71458 L F
.588 .204 .283 r
.46957 .71346 m .46951 .71482 L .46718 .71325 L F
.942 .846 .411 r
.61664 .61383 m .61743 .61284 L .61671 .61192 L F
.636 .47 .642 r
.49927 .65562 m .49952 .65873 L .49698 .65869 L F
.491 .173 .355 r
.50446 .65555 m .49952 .65873 L .49927 .65562 L F
.776 .769 .847 r
.72283 .49155 m .72038 .49212 L .72366 .49253 L F
.743 .763 .868 r
.72283 .49155 m .72366 .49253 L .72712 .48995 L F
.747 .876 .939 r
.68011 .50396 m .68114 .50512 L .68385 .50349 L F
.624 .439 .611 r
.49318 .68506 m .49365 .68695 L .49144 .68975 L F
.562 .233 .369 r
.49319 .68876 m .49477 .68787 L .49368 .68741 L F
.49144 .68975 m .49429 .68952 L .49477 .68787 L F
.23 0 .243 r
.49477 .68787 m .49429 .68952 L .496 .68886 L F
.403 .3 .623 r
.496 .68886 m .49429 .68952 L .49373 .68726 L F
.879 .669 .615 r
.49267 .687 m .49361 .68739 L .49365 .6868 L F
.49382 .68519 m .49477 .68787 L .49394 .68497 L F
.49361 .68739 m .49473 .68785 L .49381 .68517 L F
.49473 .68785 m .49477 .68787 L .49381 .68517 L F
.49359 .68561 m .49365 .6868 L .49378 .68439 L F
.49361 .68739 m .49386 .68467 L .49378 .68439 L F
.456 .376 .678 r
.49394 .68497 m .49605 .68394 L .49378 .68439 L F
.49477 .68787 m .49553 .68554 L .49394 .68497 L F
.49553 .68554 m .49605 .68394 L .49394 .68497 L F
.673 .392 .488 r
.49965 .68838 m .49904 .68846 L .49769 .68695 L F
.49755 .68657 m .49769 .68695 L .49665 .6858 L F
.49965 .68838 m .49769 .68695 L .49755 .68657 L F
.49904 .68846 m .49852 .68853 L .4978 .68748 L F
.49904 .68846 m .4978 .68748 L .49665 .6858 L F
.539 .429 .677 r
.4968 .68668 m .49697 .68731 L .49725 .68704 L F
.456 .376 .678 r
.49477 .68787 m .49697 .68731 L .4968 .68668 L F
.49477 .68787 m .4968 .68668 L .49674 .68663 L F
.49477 .68787 m .49677 .68661 L .49553 .68554 L F
.23 0 .243 r
.49477 .68787 m .496 .68886 L .49697 .68731 L F
.673 .392 .488 r
.49754 .68748 m .496 .68886 L .49652 .68639 L F
.49852 .68853 m .49826 .68856 L .49754 .68748 L F
.669 .353 .429 r
.49697 .68731 m .49821 .68872 L .49825 .68855 L F
.49697 .68731 m .49825 .68855 L .49725 .68704 L F
.49697 .68731 m .496 .68886 L .49821 .68872 L F
.673 .392 .488 r
.49826 .68856 m .496 .68886 L .49754 .68748 L F
.49852 .68853 m .49652 .68639 L .49665 .6858 L F
.815 .489 .437 r
.50303 .68634 m .50187 .68879 L .49899 .68561 L F
.657 .51 .672 r
.49899 .68561 m .50187 .68879 L .49965 .68838 L F
.49899 .68561 m .49965 .68838 L .49901 .68537 L F
.673 .392 .488 r
.49965 .68838 m .49665 .6858 L .49901 .68537 L F
.669 .353 .429 r
.49725 .68704 m .49825 .68855 L .49901 .68537 L F
.593 .524 .747 r
.49825 .68855 m .5013 .68429 L .49901 .68537 L F
.141 0 .102 r
.49597 .69133 m .49821 .68872 L .496 .68886 L F
.655 .404 .528 r
.49825 .68857 m .49597 .69133 L .496 .68886 L F
.49965 .68838 m .49885 .68902 L .49825 .68857 L F
.492 .101 .226 r
.5054 .68657 m .50187 .68879 L .50303 .68634 L F
.5054 .68657 m .50436 .68872 L .50187 .68879 L F
.655 .404 .528 r
.49965 .68838 m .49829 .69175 L .49597 .69133 L F
.489 .23 .448 r
.50174 .68947 m .49965 .68838 L .50187 .68879 L F
.50146 .69093 m .50008 .68898 L .50174 .68947 L F
.50008 .68898 m .49965 .68838 L .50174 .68947 L F
.50146 .69093 m .49829 .69175 L .49933 .68919 L F
.50008 .68898 m .49933 .68919 L .49965 .68838 L F
.50146 .69093 m .49933 .68919 L .50008 .68898 L F
.593 .524 .747 r
.49837 .68849 m .50099 .68874 L .5013 .68429 L F
0 0 .43 r
.5013 .68429 m .50307 .68828 L .5029 .68753 L F
.593 .524 .747 r
.50267 .68829 m .50307 .68828 L .50303 .68819 L F
.117 0 .397 r
.5029 .68753 m .50227 .6883 L .5038 .68826 L F
0 0 .43 r
.50307 .68828 m .50338 .68897 L .5029 .68753 L F
.117 0 .397 r
.5038 .68826 m .50311 .68845 L .50436 .68872 L F
.50311 .68845 m .50187 .68879 L .50318 .68875 L F
.50311 .68845 m .50318 .68875 L .50436 .68872 L F
.50227 .6883 m .50187 .68879 L .5038 .68826 L F
.593 .524 .747 r
.50219 .68848 m .50338 .68897 L .50307 .68828 L F
.50202 .68884 m .50338 .68897 L .50219 .68848 L F
.50099 .68874 m .50307 .68828 L .50267 .68829 L F
.50099 .68874 m .50303 .68819 L .5013 .68429 L F
.117 0 .397 r
.5021 .68851 m .50174 .68947 L .50187 .68879 L F
.50227 .6883 m .50199 .68891 L .5021 .68851 L F
.50199 .68891 m .50174 .68947 L .5021 .68851 L F
.628 .205 .221 r
.50199 .68891 m .50146 .69093 L .50338 .68897 L F
.655 .404 .528 r
.49844 .68871 m .49826 .68864 L .49825 .68857 L F
.49885 .68902 m .4984 .68873 L .49844 .68871 L F
.4984 .68873 m .49826 .68864 L .49844 .68871 L F
.628 .205 .221 r
.4984 .68873 m .50146 .69093 L .50199 .68891 L F
.49821 .68872 m .49831 .68879 L .4984 .68873 L F
.49831 .68879 m .50146 .69093 L .4984 .68873 L F
.593 .524 .747 r
.49909 .6887 m .50338 .68897 L .49837 .68849 L F
.4984 .68873 m .50338 .68897 L .49826 .68864 L F
.117 0 .397 r
.5029 .68753 m .50146 .69093 L .50174 .68947 L F
.5029 .68753 m .50174 .68947 L .50227 .6883 L F
.593 .524 .747 r
.50099 .68874 m .50202 .68884 L .50219 .68848 L F
.49826 .68864 m .49909 .6887 L .49837 .68849 L F
.49821 .68872 m .4984 .68873 L .49826 .68864 L F
.655 .404 .528 r
.49885 .68902 m .49833 .68944 L .49827 .68879 L F
.628 .205 .221 r
.49831 .68879 m .4977 .69113 L .50146 .69093 L F
.49821 .68872 m .49819 .68878 L .49831 .68879 L F
.593 .524 .747 r
.49821 .68872 m .49826 .68864 L .49825 .68855 L F
.49826 .68864 m .49825 .68857 L .49825 .68855 L F
.141 0 .102 r
.49597 .69133 m .49819 .68878 L .49821 .68872 L F
.655 .404 .528 r
.49826 .6887 m .49597 .69133 L .49825 .68857 L F
.49833 .68944 m .49597 .69133 L .49826 .6887 L F
.141 0 .102 r
.49597 .69133 m .4977 .69113 L .49819 .68878 L F
.628 .205 .221 r
.49819 .68878 m .4977 .69113 L .49831 .68879 L F
.655 .404 .528 r
.49852 .68881 m .49827 .68879 L .49826 .68864 L F
.49885 .68902 m .49827 .68879 L .49852 .68881 L F
.593 .524 .747 r
.49826 .68864 m .49827 .68862 L .49825 .68857 L F
.49827 .68862 m .5013 .68429 L .49825 .68855 L F
.403 .3 .623 r
.49359 .68561 m .49382 .68519 L .49665 .6858 L F
.486 .458 .751 r
.49605 .68394 m .49901 .68537 L .49665 .6858 L F
.539 .429 .677 r
.49605 .68394 m .4968 .68668 L .49901 .68537 L F
.4968 .68668 m .49725 .68704 L .49901 .68537 L F
.456 .376 .678 r
.49674 .68663 m .4968 .68668 L .49677 .68661 L F
.403 .3 .623 r
.49615 .68607 m .49577 .68574 L .49617 .68577 L F
.49662 .68593 m .49617 .68577 L .49665 .6858 L F
.496 .68886 m .49617 .68577 L .49662 .68593 L F
.602 .527 .743 r
.49605 .68394 m .49665 .6858 L .49556 .68556 L F
.456 .376 .678 r
.49553 .68554 m .49556 .68556 L .49605 .68394 L F
.602 .527 .743 r
.49605 .68394 m .49556 .68556 L .49382 .68519 L F
.456 .376 .678 r
.49556 .68556 m .49677 .68661 L .49605 .68394 L F
.403 .3 .623 r
.496 .68886 m .49359 .68561 L .49577 .68574 L F
.496 .68886 m .49577 .68574 L .49615 .68607 L F
.49359 .68561 m .49318 .68506 L .49382 .68519 L F
.879 .669 .615 r
.49381 .68517 m .49382 .68519 L .49386 .68467 L F
.49382 .68519 m .49394 .68497 L .49386 .68467 L F
.602 .527 .743 r
.4937 .68486 m .49382 .68519 L .49318 .68506 L F
.49605 .68394 m .49382 .68519 L .4937 .68486 L F
.49605 .68394 m .4937 .68486 L .49378 .68439 L F
.4937 .68486 m .49318 .68506 L .49378 .68439 L F
.879 .669 .615 r
.49355 .68491 m .49359 .68561 L .49378 .68439 L F
.403 .3 .623 r
.49359 .68561 m .49365 .68695 L .49318 .68506 L F
.879 .669 .615 r
.49267 .687 m .49365 .6868 L .49355 .68491 L F
.403 .3 .623 r
.49408 .68628 m .49373 .68726 L .49365 .68695 L F
.49408 .68628 m .49365 .68695 L .49359 .68561 L F
.496 .68886 m .49373 .68726 L .49408 .68628 L F
.562 .233 .369 r
.49144 .68975 m .49319 .68876 L .49361 .68739 L F
.49319 .68876 m .49368 .68741 L .49361 .68739 L F
.49144 .68975 m .49361 .68739 L .49267 .687 L F
.624 .439 .611 r
.49361 .68739 m .49429 .68952 L .49342 .68959 L F
.49365 .68695 m .49373 .68726 L .49361 .68739 L F
.49373 .68726 m .49429 .68952 L .49361 .68739 L F
.49365 .68695 m .49342 .68959 L .49144 .68975 L F
.265 .006 .32 r
.49318 .68506 m .49267 .687 L .49378 .68439 L F
.624 .439 .611 r
.49318 .68506 m .49144 .68975 L .49267 .687 L F
.096 .238 .721 r
.44081 .70459 m .44213 .70797 L .44294 .70682 L F
.383 .642 .958 r
.44213 .70797 m .44388 .70825 L .44294 .70682 L F
.428 0 0 r
.22209 .56119 m .22041 .56161 L .21835 .56074 L F
.336 0 0 r
.21835 .56074 m .22081 .56122 L .22209 .56119 L F
.161 .309 .766 r
.22207 .55828 m .22209 .56119 L .22081 .56122 L F
.22207 .55828 m .22426 .56164 L .22209 .56119 L F
.658 .313 .378 r
.22426 .56164 m .22041 .56161 L .22209 .56119 L F
.819 .496 .442 r
.57863 .6577 m .5803 .66093 L .58058 .65903 L F
.776 .559 .606 r
.5803 .66093 m .58363 .65869 L .58058 .65903 L F
.577 .318 .488 r
.48306 .6787 m .48583 .67788 L .4839 .67638 L F
.742 .704 .816 r
.70968 .48315 m .71322 .48548 L .71179 .48293 L F
.744 .696 .805 r
.71179 .48293 m .71322 .48548 L .71527 .48334 L F
.035 .001 .483 r
.61398 .62822 m .61232 .62716 L .61367 .62578 L F
.61398 .62822 m .61255 .62956 L .61232 .62716 L F
.491 .173 .355 r
.50446 .65555 m .50233 .65915 L .49952 .65873 L F
.753 .477 .515 r
.50689 .65795 m .50446 .65555 L .50488 .65431 L F
.50689 .65795 m .50233 .65915 L .50446 .65555 L F
.654 .665 .848 r
.79434 .48892 m .79167 .48971 L .7913 .48837 L F
.545 .525 .783 r
.79506 .49281 m .79167 .48971 L .79434 .48892 L F
.474 .291 .552 r
.43452 .67557 m .43678 .67241 L .43455 .67295 L F
.012 .442 .867 r
.4285 .70307 m .42956 .70422 L .43006 .70366 L F
.119 .585 .918 r
.42956 .70422 m .43164 .70469 L .43006 .70366 L F
.321 .405 .792 r
.50272 .71097 m .50303 .71262 L .50217 .71075 L F
.819 .552 .534 r
.49966 .71175 m .50181 .71265 L .50217 .71075 L F
.942 .82 .696 r
.50263 .71191 m .50049 .71464 L .50253 .71302 L F
.50181 .71265 m .50049 .71464 L .50263 .71191 L F
0 0 .369 r
.49966 .71175 m .50049 .71464 L .50181 .71265 L F
.942 .82 .696 r
.50157 .71286 m .50049 .71464 L .50181 .71265 L F
.493 .846 .587 r
.50229 .71322 m .50049 .71464 L .49985 .71522 L F
.50253 .71302 m .50049 .71464 L .50229 .71322 L F
0 0 .369 r
.50181 .71265 m .50049 .71464 L .50315 .71321 L F
.493 .846 .587 r
.50303 .71262 m .50253 .71302 L .50229 .71322 L F
.819 .552 .534 r
.50181 .71265 m .50315 .71321 L .50263 .71191 L F
.50181 .71265 m .50263 .71191 L .50217 .71075 L F
.942 .82 .696 r
.50272 .71097 m .50157 .71286 L .50263 .71191 L F
.50272 .71097 m .50253 .71302 L .50303 .71262 L F
.413 .348 .675 r
.50217 .71075 m .50263 .71191 L .50272 .71097 L F
.50263 .71191 m .50294 .71267 L .50272 .71097 L F
.50294 .71267 m .50315 .71321 L .50303 .71259 L F
.50294 .71267 m .50303 .71259 L .50272 .71097 L F
.677 .298 .32 r
.4731 .71337 m .46951 .71482 L .46957 .71346 L F
.4731 .71337 m .47349 .71498 L .46951 .71482 L F
.713 .322 .306 r
.4731 .71337 m .47519 .71552 L .47349 .71498 L F
.641 .342 .448 r
.4731 .71337 m .47701 .71292 L .47519 .71552 L F
.61 .82 .418 r
.49966 .68447 m .49901 .68537 L .50059 .68301 L F
.875 .857 .405 r
.49966 .68447 m .49899 .68561 L .49901 .68537 L F
.941 .579 .194 r
.53425 .61286 m .53399 .61435 L .53315 .61272 L F
.53425 .61286 m .53512 .61531 L .53399 .61435 L F
.171 .684 .895 r
.58802 .67612 m .58518 .67583 L .58615 .67581 L F
.647 .952 .945 r
.58353 .67434 m .58275 .67585 L .58243 .67556 L F
.58353 .67434 m .58207 .67512 L .58248 .67557 L F
.58289 .67558 m .58248 .67557 L .58275 .67585 L F
.58353 .67434 m .58248 .67557 L .58289 .67558 L F
.463 .857 .974 r
.58615 .67581 m .58248 .67557 L .58275 .67585 L F
.171 .684 .895 r
.58518 .67583 m .58246 .67556 L .58615 .67581 L F
.463 .857 .974 r
.58248 .67557 m .58243 .67556 L .58275 .67585 L F
.171 .684 .895 r
.58246 .67556 m .58243 .67556 L .58248 .67557 L F
.58246 .67556 m .58248 .67557 L .58615 .67581 L F
.647 .952 .945 r
.58207 .67512 m .5811 .67563 L .58275 .67585 L F
.632 .942 .956 r
.58437 .67639 m .58667 .6758 L .58615 .67581 L F
.58667 .6758 m .58737 .67562 L .58615 .67581 L F
.377 .827 .934 r
.43797 .70333 m .43395 .70363 L .43527 .70376 L F
.927 .768 .665 r
.53002 .6754 m .52888 .67207 L .53023 .67304 L F
.571 .843 .996 r
.53259 .67199 m .53023 .67304 L .52888 .67207 L F
.631 .245 .293 r
.46561 .67549 m .4638 .67605 L .462 .67557 L F
.518 .067 .12 r
.46652 .67722 m .46561 .67549 L .46795 .67594 L F
.46652 .67722 m .4638 .67605 L .46561 .67549 L F
.44 .563 .883 r
.73796 .52081 m .73961 .52382 L .74126 .52215 L F
.385 .474 .828 r
.73961 .52382 m .74221 .52516 L .74126 .52215 L F
.499 .562 .851 r
.73961 .52382 m .74301 .52657 L .74221 .52516 L F
.623 .362 .502 r
.57949 .65236 m .579 .65503 L .57673 .65303 L F
.766 .383 .33 r
.55807 .66434 m .5566 .66589 L .55472 .66376 L F
.627 .461 .638 r
.65818 .48991 m .6603 .49183 L .66017 .48949 L F
.65818 .48991 m .65783 .49248 L .6603 .49183 L F
.511 .759 .986 r
.39575 .58605 m .39505 .58771 L .39357 .58655 L F
.39575 .58605 m .39721 .58736 L .39505 .58771 L F
.645 .729 .91 r
.4612 .69678 m .46221 .69461 L .45999 .69598 L F
.101 .64 .854 r
.36297 .58398 m .36645 .58443 L .36439 .58436 L F
.688 .43 .526 r
.49708 .71282 m .49661 .7159 L .49414 .71285 L F
.709 .449 .53 r
.49985 .71522 m .49661 .7159 L .49708 .71282 L F
.542 .787 .989 r
.30169 .64107 m .30538 .64171 L .30384 .6406 L F
.519 .778 .991 r
.30538 .64171 m .30792 .64148 L .30384 .6406 L F
.30538 .64171 m .30792 .64148 L .30384 .6406 L F
.511 .169 .324 r
.30538 .64171 m .30691 .64324 L .30792 .64148 L F
.425 .256 .547 r
.80088 .50724 m .80088 .50905 L .79887 .50968 L F
.341 .269 .629 r
.80144 .51049 m .79887 .50968 L .80088 .50905 L F
.80144 .51049 m .80084 .51143 L .79887 .50968 L F
.776 .559 .606 r
.5803 .66093 m .58398 .6613 L .58363 .65869 L F
0 0 .412 r
.58363 .65869 m .58456 .65907 L .5856 .65796 L F
.58363 .65869 m .58398 .6613 L .58456 .65907 L F
.626 .477 .661 r
.72835 .47153 m .72573 .47519 L .72841 .47473 L F
.783 .621 .679 r
.72601 .47743 m .72841 .47473 L .72573 .47519 L F
.501 .133 .273 r
.49414 .71285 m .4929 .71516 L .49059 .71528 L F
.763 .426 .415 r
.49414 .71285 m .49661 .7159 L .4929 .71516 L F
.111 0 0 r
.59838 .67045 m .59737 .67206 L .59539 .67223 L F
0 0 0 r
.6003 .66943 m .59737 .67206 L .59838 .67045 L F
.745 .782 .883 r
.51618 .64851 m .51907 .64794 L .51819 .64758 L F
.68 .91 .975 r
.52016 .64654 m .51819 .64758 L .51907 .64794 L F
.68 .708 .869 r
.47052 .67572 m .47159 .67619 L .46795 .67594 L F
.95 .759 .612 r
.47159 .67619 m .47015 .67822 L .46795 .67594 L F
.47159 .67619 m .47161 .67881 L .47015 .67822 L F
.507 .399 .666 r
.47369 .67819 m .47161 .67881 L .47159 .67619 L F
.492 .434 .72 r
.51597 .65763 m .51524 .66079 L .51931 .65995 L F
.385 0 .029 r
.51813 .66153 m .51479 .66077 L .51573 .66125 L F
.51479 .66077 m .5145 .66071 L .51463 .66077 L F
.555 .306 .494 r
.51453 .66333 m .51506 .66155 L .5145 .66071 L F
.385 0 .029 r
.51479 .66077 m .51453 .66333 L .5145 .66071 L F
.51479 .66077 m .51463 .66077 L .51573 .66125 L F
.608 .549 .762 r
.5145 .66071 m .51506 .66155 L .51509 .66142 L F
.385 0 .029 r
.51813 .66153 m .51604 .66258 L .51509 .66122 L F
.51504 .66083 m .51509 .66122 L .51479 .66077 L F
.51813 .66153 m .51509 .66122 L .51504 .66083 L F
.51604 .66258 m .51509 .66142 L .51479 .66077 L F
.51813 .66153 m .51694 .6631 L .51453 .66333 L F
.517 .412 .674 r
.51694 .6631 m .51931 .65995 L .51514 .66152 L F
.51515 .66162 m .51514 .66152 L .51506 .66155 L F
.51694 .6631 m .51514 .66152 L .51515 .66162 L F
.608 .549 .762 r
.5145 .66071 m .51509 .66142 L .51597 .65763 L F
.385 0 .029 r
.51604 .66258 m .51571 .66274 L .51516 .66158 L F
.51604 .66258 m .51516 .66158 L .51518 .66154 L F
.555 .306 .494 r
.51453 .66333 m .51515 .66162 L .51506 .66155 L F
.492 .434 .72 r
.51509 .66142 m .51506 .66155 L .51514 .66152 L F
.385 0 .029 r
.51571 .66274 m .51453 .66333 L .51479 .66077 L F
.555 .306 .494 r
.51453 .66333 m .51694 .6631 L .51515 .66162 L F
.385 0 .029 r
.51518 .66154 m .51516 .66158 L .51509 .66142 L F
.492 .434 .72 r
.51524 .66079 m .51509 .66142 L .51688 .66086 L F
.51509 .66142 m .51514 .66152 L .51688 .66086 L F
.51524 .66079 m .51688 .66086 L .51931 .65995 L F
.234 .033 .389 r
.58825 .63853 m .59006 .63801 L .59038 .63543 L F
.309 .242 .617 r
.58825 .63853 m .59014 .64077 L .58825 .64063 L F
.58825 .63853 m .59006 .63801 L .59014 .64077 L F
.749 .25 .042 r
.58825 .63853 m .59014 .64077 L .58825 .64063 L F
.933 .724 .597 r
.68639 .49445 m .68566 .49759 L .68769 .49725 L F
.872 .804 .78 r
.68411 .49948 m .68769 .49725 L .68566 .49759 L F
.68411 .49948 m .6856 .50055 L .68769 .49725 L F
.786 .777 .845 r
.29558 .62702 m .29646 .62911 L .29726 .62594 L F
.585 .322 .484 r
.29687 .62984 m .29726 .62594 L .29646 .62911 L F
.419 0 0 r
.55351 .65074 m .55244 .64994 L .55167 .64855 L F
.55351 .65074 m .55473 .65149 L .55244 .64994 L F
0 0 .45 r
.7365 .47833 m .73517 .47812 L .73419 .47776 L F
.035 0 0 r
.59539 .67223 m .5938 .67363 L .59108 .67439 L F
.054 0 0 r
.59737 .67206 m .5938 .67363 L .59539 .67223 L F
.465 .431 .736 r
.66078 .5039 m .66156 .49997 L .65951 .50098 L F
.66078 .5039 m .66347 .50423 L .66156 .49997 L F
.486 .328 .592 r
.66078 .5039 m .66248 .50549 L .66347 .50423 L F
.53 .327 .55 r
.66078 .5039 m .66045 .50623 L .66248 .50549 L F
.66078 .5039 m .66045 .50623 L .66248 .50549 L F
.474 0 0 r
.42654 .60072 m .4304 .60176 L .42784 .60177 L F
.525 .896 .703 r
.43364 .60198 m .43126 .60386 L .4304 .60176 L F
.829 .892 .886 r
.43172 .60302 m .43266 .60256 L .43054 .60247 L F
.525 .896 .703 r
.43333 .60222 m .43266 .60256 L .43126 .60386 L F
.312 .304 .69 r
.43266 .60256 m .4312 .60553 L .43126 .60386 L F
.43266 .60256 m .43315 .60533 L .4312 .60553 L F
.097 .147 .626 r
.43368 .60546 m .43315 .60533 L .43266 .60256 L F
.43368 .60546 m .43266 .60256 L .43365 .60259 L F
.43595 .60386 m .43365 .60259 L .43591 .60266 L F
.43368 .60546 m .43365 .60259 L .43595 .60386 L F
.525 .896 .703 r
.43364 .60198 m .43266 .60256 L .43333 .60222 L F
.539 .083 .117 r
.43266 .60256 m .43759 .60271 L .43364 .60198 L F
.43266 .60256 m .43759 .60271 L .43364 .60198 L F
.507 .312 .55 r
.436 .60308 m .43699 .60186 L .43608 .60301 L F
.43548 .60354 m .43591 .60306 L .436 .60308 L F
.43591 .60306 m .43699 .60186 L .436 .60308 L F
.097 .147 .626 r
.43595 .60386 m .43591 .60266 L .43658 .60342 L F
.727 .674 .798 r
.43608 .60301 m .43626 .60318 L .43548 .60354 L F
.097 .147 .626 r
.43658 .60342 m .43591 .60266 L .43759 .60271 L F
.829 .892 .886 r
.43638 .60306 m .43626 .60318 L .43759 .60271 L F
.43626 .60318 m .43575 .60371 L .43658 .60342 L F
.43575 .60371 m .43595 .60386 L .43658 .60342 L F
.727 .674 .798 r
.43626 .60318 m .43856 .60544 L .43575 .60371 L F
0 .335 .757 r
.43562 .60361 m .43639 .6041 L .43712 .60435 L F
.727 .674 .798 r
.43626 .60318 m .43575 .60371 L .43548 .60354 L F
0 .335 .757 r
.43548 .60354 m .43575 .60371 L .43562 .60361 L F
.43575 .60371 m .43639 .6041 L .43562 .60361 L F
.829 .892 .886 r
.43575 .60371 m .43486 .60463 L .43595 .60386 L F
.43626 .60318 m .43658 .60342 L .43759 .60271 L F
.704 .198 0 r
.43788 .60493 m .43699 .6039 L .43626 .60318 L F
.43621 .60315 m .43626 .60318 L .43608 .60301 L F
.43788 .60493 m .43626 .60318 L .43621 .60315 L F
.829 .892 .886 r
.43353 .60387 m .43368 .60546 L .43486 .60463 L F
.704 .198 0 r
.43712 .60435 m .43788 .60493 L .43616 .60309 L F
.43712 .60435 m .43616 .60309 L .43619 .60315 L F
.829 .892 .886 r
.43618 .60312 m .43682 .60293 L .43591 .60266 L F
.43682 .60293 m .43759 .60271 L .43669 .60269 L F
.43682 .60293 m .43669 .60269 L .43591 .60266 L F
0 0 .35 r
.43801 .60288 m .43734 .60399 L .43699 .60186 L F
.43734 .60399 m .43712 .60435 L .43708 .60345 L F
.43734 .60399 m .43708 .60345 L .43699 .60186 L F
.829 .892 .886 r
.43618 .60312 m .43591 .60266 L .43266 .60256 L F
.704 .198 0 r
.43619 .60315 m .43616 .60309 L .43608 .60301 L F
.43712 .60435 m .43608 .60301 L .43699 .60186 L F
.507 .312 .55 r
.43646 .60349 m .43712 .60435 L .43708 .60345 L F
.43571 .60353 m .43712 .60435 L .43646 .60349 L F
.43548 .60354 m .43562 .60361 L .43571 .60353 L F
.829 .892 .886 r
.43613 .60313 m .43486 .60463 L .43638 .60306 L F
.507 .312 .55 r
.43562 .60361 m .43712 .60435 L .43571 .60353 L F
.829 .892 .886 r
.43353 .60387 m .43467 .60452 L .43613 .60313 L F
.43467 .60452 m .43486 .60463 L .43613 .60313 L F
.43613 .60313 m .43613 .60313 L .43612 .60313 L F
.43613 .60313 m .43618 .60312 L .43603 .60309 L F
.507 .312 .55 r
.43591 .60306 m .43708 .60345 L .43699 .60186 L F
.43548 .60354 m .43708 .60345 L .43591 .60306 L F
.829 .892 .886 r
.43353 .60387 m .43613 .60313 L .43266 .60256 L F
.43613 .60313 m .43612 .60313 L .43266 .60256 L F
.43613 .60313 m .43603 .60309 L .43266 .60256 L F
.704 .198 0 r
.43788 .60493 m .43856 .60544 L .43699 .6039 L F
0 .335 .757 r
.43639 .6041 m .43856 .60544 L .43788 .60493 L F
0 0 .316 r
.43835 .60425 m .43812 .60463 L .43712 .60435 L F
0 .335 .757 r
.43653 .60418 m .43788 .60493 L .43712 .60435 L F
0 0 .316 r
.43812 .60463 m .43668 .60698 L .43712 .60435 L F
0 .335 .757 r
.43639 .6041 m .43653 .60418 L .43712 .60435 L F
.829 .892 .886 r
.43353 .60387 m .43266 .60256 L .43172 .60302 L F
.376 .022 .232 r
.57779 .57998 m .58055 .57812 L .57806 .57836 L F
.952 .771 .623 r
.61717 .60699 m .61612 .60373 L .6158 .6061 L F
.958 .749 .578 r
.61679 .6094 m .61717 .60699 L .6158 .6061 L F
0 .366 .808 r
.73185 .50912 m .73517 .51104 L .73582 .51169 L F
.73517 .51104 m .73599 .51151 L .73582 .51169 L F
.994 .796 .534 r
.73582 .51169 m .7371 .51327 L .73705 .51292 L F
.73582 .51169 m .73705 .51292 L .73655 .50945 L F
.589 .54 .767 r
.73655 .50945 m .7371 .51327 L .73969 .51213 L F
.645 .814 .964 r
.73969 .51213 m .7371 .51327 L .73582 .51169 L F
.428 .094 .296 r
.38571 .61508 m .38796 .61468 L .38857 .61296 L F
.573 .297 .46 r
.38796 .61468 m .39088 .61244 L .38857 .61296 L F
.415 .061 .254 r
.38628 .63021 m .38604 .63129 L .38363 .6318 L F
.442 .085 .262 r
.38628 .63021 m .3882 .63103 L .38604 .63129 L F
.459 .02 .116 r
.38628 .63021 m .38859 .6302 L .3882 .63103 L F
.872 .818 .34 r
.53069 .6656 m .53127 .66467 L .53341 .66394 L F
.824 .946 .902 r
.77819 .52929 m .77918 .53021 L .77989 .52839 L F
0 .54 .839 r
.77918 .53021 m .78289 .53115 L .77989 .52839 L F
.469 .87 .699 r
.55319 .5918 m .55138 .59301 L .54964 .59384 L F
.322 .392 .779 r
.44921 .69163 m .45033 .69516 L .44847 .69433 L F
.643 .615 .806 r
.77547 .49783 m .77687 .49369 L .77489 .49576 L F
.77547 .49783 m .77761 .49778 L .77687 .49369 L F
.589 .495 .716 r
.77547 .49783 m .77844 .49927 L .77761 .49778 L F
.77547 .49783 m .77602 .50116 L .77844 .49927 L F
0 0 .218 r
.29687 .62984 m .2974 .63092 L .29925 .62971 L F
.29687 .62984 m .29686 .63286 L .2974 .63092 L F
.619 .265 .349 r
.49698 .65869 m .4972 .66015 L .49446 .65896 L F
.4972 .66015 m .49688 .66029 L .49446 .65896 L F
.506 .207 .393 r
.49446 .65896 m .49326 .66285 L .49103 .66289 L F
.626 .323 .438 r
.49648 .6613 m .49446 .65896 L .49726 .6605 L F
.49648 .6613 m .49326 .66285 L .49446 .65896 L F
.801 .634 .676 r
.49232 .66017 m .49613 .66062 L .49466 .65755 L F
.49613 .66062 m .49636 .66064 L .4963 .66054 L F
.49613 .66062 m .4963 .66054 L .49466 .65755 L F
.619 .265 .349 r
.4972 .66015 m .49726 .6605 L .49688 .66029 L F
.639 .279 .345 r
.49698 .65869 m .49919 .66059 L .49726 .6605 L F
.603 .296 .422 r
.49952 .65873 m .49919 .66059 L .49698 .65869 L F
0 0 0 r
.77513 .50826 m .77217 .51234 L .77553 .51066 L F
.532 .403 .65 r
.77513 .50826 m .77757 .50857 L .77695 .50603 L F
.576 .475 .703 r
.77553 .51066 m .77757 .50857 L .77513 .50826 L F
.985 .718 .346 r
.56184 .67196 m .5629 .67535 L .56288 .6729 L F
.582 .569 .804 r
.33523 .61829 m .33323 .61901 L .33171 .61531 L F
.511 .34 .586 r
.6603 .49183 m .66264 .49128 L .66017 .48949 L F
.608 .456 .65 r
.66017 .48949 m .66282 .48916 L .66267 .4861 L F
.571 .318 .494 r
.66017 .48949 m .66264 .49128 L .66282 .48916 L F
.511 .34 .586 r
.6603 .49183 m .66264 .49128 L .66017 .48949 L F
.523 .385 .635 r
.77602 .50116 m .77874 .50317 L .77844 .49927 L F
.77602 .50116 m .77655 .50371 L .77874 .50317 L F
.519 .917 .863 r
.54545 .59548 m .54348 .5965 L .54176 .59672 L F
.947 .723 .568 r
.59658 .58991 m .5948 .59145 L .59435 .58928 L F
.59658 .58991 m .59636 .5923 L .5948 .59145 L F
.592 .563 .791 r
.70662 .48418 m .70968 .48315 L .70805 .48291 L F
.856 .658 .634 r
.68361 .4892 m .68354 .49234 L .68509 .49221 L F
.784 .426 .379 r
.68354 .49234 m .68379 .49402 L .68509 .49221 L F
.842 .507 .42 r
.68509 .49221 m .68379 .49402 L .68639 .49445 L F
.572 .61 .852 r
.33717 .61797 m .33669 .62154 L .33523 .61829 L F
.33717 .61797 m .3389 .62117 L .33669 .62154 L F
.82 .444 .343 r
.59784 .59499 m .5975 .59757 L .59643 .59459 L F
.59784 .59499 m .5995 .59763 L .5975 .59757 L F
.218 .71 .921 r
.38204 .58524 m .3842 .58519 L .38596 .58574 L F
0 .558 .783 r
.3842 .58519 m .38793 .58579 L .38596 .58574 L F
.781 .653 .721 r
.72982 .48006 m .72711 .48326 L .73055 .48374 L F
.753 .559 .635 r
.72711 .48326 m .73086 .48604 L .73055 .48374 L F
.211 .257 .692 r
.72982 .48006 m .73055 .48374 L .73222 .48172 L F
0 0 .414 r
.73086 .48604 m .73222 .48172 L .73055 .48374 L F
.558 .322 .515 r
.52737 .66081 m .53024 .66047 L .52975 .65855 L F
.554 .582 .837 r
.53024 .66047 m .53074 .65728 L .52975 .65855 L F
0 .48 .755 r
.51849 .63299 m .51995 .63325 L .52122 .63369 L F
.189 .722 .79 r
.51871 .63367 m .52087 .63342 L .51995 .63325 L F
.072 .506 .898 r
.52235 .63324 m .52122 .63369 L .51995 .63325 L F
.189 .722 .79 r
.52087 .63342 m .52235 .63324 L .51995 .63325 L F
0 .48 .755 r
.51756 .63276 m .51995 .63325 L .51849 .63299 L F
.072 .506 .898 r
.52235 .63324 m .52351 .6343 L .52122 .63369 L F
.454 .583 .892 r
.74301 .52657 m .74442 .52485 L .74221 .52516 L F
.74301 .52657 m .74522 .52656 L .74442 .52485 L F
.601 .245 .339 r
.75657 .48267 m .75985 .48048 L .75648 .48034 L F
.75657 .48267 m .75913 .48258 L .75985 .48048 L F
.483 .124 .281 r
.75913 .48258 m .76236 .4803 L .75985 .48048 L F
.199 .718 .875 r
.73086 .50112 m .73376 .50094 L .73458 .5012 L F
.73086 .50112 m .73376 .50094 L .73458 .5012 L F
.53 .915 .928 r
.73458 .5012 m .73595 .50006 L .73376 .50094 L F
.73376 .50094 m .73595 .50006 L .73458 .5012 L F
.766 .809 .887 r
.54882 .59983 m .55017 .60118 L .55258 .59888 L F
.621 .54 .741 r
.55017 .60118 m .55256 .60178 L .55258 .59888 L F
.622 .178 .175 r
.55017 .60118 m .55212 .60272 L .55256 .60178 L F
.038 0 .123 r
.61367 .62578 m .61443 .62318 L .61471 .62381 L F
.386 .35 .695 r
.57844 .64096 m .57742 .64426 L .57656 .64105 L F
.57844 .64096 m .57966 .64323 L .57742 .64426 L F
.602 .391 .567 r
.58004 .64652 m .57742 .64426 L .57966 .64323 L F
.58004 .64652 m .57768 .64708 L .57742 .64426 L F
.128 .171 .637 r
.579 .65503 m .57969 .65728 L .57863 .6577 L F
.14 .202 .667 r
.57969 .65728 m .5803 .66093 L .57863 .6577 L F
0 0 0 r
.58021 .5893 m .57735 .59201 L .57709 .58992 L F
.58021 .5893 m .57927 .59073 L .57735 .59201 L F
.246 0 .076 r
.58021 .5893 m .58159 .59048 L .57927 .59073 L F
.58021 .5893 m .58252 .58865 L .58159 .59048 L F
.652 .784 .944 r
.66045 .50623 m .66402 .50675 L .66248 .50549 L F
.777 .804 .875 r
.66248 .50549 m .66402 .50675 L .66627 .50437 L F
.139 0 0 r
.34336 .60012 m .33979 .60284 L .34128 .60133 L F
.339 .083 .371 r
.56422 .58431 m .56615 .58524 L .56665 .58403 L F
.56422 .58431 m .56402 .58617 L .56615 .58524 L F
.898 .822 .763 r
.73547 .48257 m .73598 .48518 L .73705 .48359 L F
.972 .747 .54 r
.73568 .4802 m .73547 .48257 L .73705 .48359 L F
.385 .783 .986 r
.77363 .52948 m .77751 .52989 L .77591 .52855 L F
.345 .758 .98 r
.77591 .52855 m .77751 .52989 L .77819 .52929 L F
.348 .643 .964 r
.40498 .58883 m .40435 .59014 L .40351 .58848 L F
.40498 .58883 m .40639 .59036 L .40435 .59014 L F
.859 .708 .694 r
.71651 .47713 m .71771 .48063 L .71914 .47872 L F
.654 .485 .643 r
.50636 .66156 m .50899 .66168 L .50873 .65849 L F
.746 .554 .635 r
.50873 .65849 m .50899 .66168 L .51348 .66179 L F
.416 .285 .593 r
.58129 .64996 m .57949 .65236 L .57894 .65049 L F
.58129 .64996 m .58137 .65211 L .57949 .65236 L F
.378 .143 .427 r
.58137 .65211 m .579 .65503 L .57949 .65236 L F
.35 .298 .658 r
.43317 .68677 m .43165 .6872 L .43372 .68919 L F
.47 .308 .578 r
.43165 .6872 m .43168 .68973 L .43372 .68919 L F
.23 .722 .92 r
.36645 .58443 m .36876 .58424 L .37033 .58481 L F
.273 .749 .936 r
.36876 .58424 m .37246 .58467 L .37033 .58481 L F
.932 .802 .694 r
.5993 .62083 m .60107 .62093 L .60015 .62405 L F
.478 .354 .633 r
.43273 .67855 m .43477 .67805 L .43452 .67557 L F
.422 .309 .62 r
.43273 .67855 m .43483 .68055 L .43477 .67805 L F
.43273 .67855 m .43303 .68109 L .43483 .68055 L F
.726 .2 0 r
.46773 .69997 m .46738 .69859 L .46566 .69876 L F
.46773 .69997 m .46917 .70069 L .46738 .69859 L F
0 0 .088 r
.48647 .62656 m .48469 .62982 L .48612 .62863 L F
.177 0 .143 r
.48469 .62982 m .48584 .63102 L .48612 .62863 L F
.48469 .62982 m .48414 .63165 L .48584 .63102 L F
.51 .701 .956 r
.78954 .48604 m .788 .48783 L .78703 .48629 L F
.78954 .48604 m .7913 .48837 L .788 .48783 L F
.363 .761 .986 r
.3783 .58461 m .38204 .58524 L .37979 .58548 L F
.691 .639 .793 r
.47022 .67279 m .47052 .67572 L .46795 .67594 L F
.765 .319 .192 r
.46795 .67594 m .47015 .67822 L .46652 .67722 L F
0 .509 .764 r
.54905 .62497 m .5494 .62488 L .54551 .62422 L F
0 .434 .798 r
.55177 .62606 m .5494 .62488 L .54905 .62497 L F
.717 .777 .9 r
.52307 .64409 m .5254 .64485 L .52632 .6435 L F
.618 .191 .208 r
.462 .67557 m .46438 .67731 L .46069 .678 L F
.462 .67557 m .4638 .67605 L .46438 .67731 L F
.373 .182 .489 r
.52848 .64807 m .53071 .64741 L .52785 .64793 L F
.435 .27 .557 r
.50881 .64649 m .51079 .64351 L .50906 .64417 L F
.684 .309 .332 r
.48823 .71502 m .48482 .71506 L .48516 .71363 L F
.634 .42 .575 r
.51716 .76457 m .51699 .76726 L .51915 .76648 L F
.732 .41 .435 r
.72841 .47473 m .73048 .47169 L .72835 .47153 L F
0 0 .417 r
.61236 .63689 m .61107 .63574 L .6132 .63464 L F
.61236 .63689 m .611 .63799 L .61107 .63574 L F
.431 .096 .295 r
.39698 .6245 m .39636 .62609 L .39414 .62654 L F
.394 .061 .278 r
.39857 .62549 m .39698 .6245 L .39923 .62419 L F
.39857 .62549 m .39636 .62609 L .39698 .6245 L F
.04 .582 .845 r
.34185 .5825 m .34545 .58329 L .34326 .58317 L F
.904 .713 .634 r
.61494 .59787 m .61582 .59556 L .61366 .59236 L F
.183 .204 .647 r
.55736 .63597 m .55884 .63415 L .55732 .63245 L F
.373 .479 .839 r
.55736 .63597 m .56026 .63716 L .55884 .63415 L F
.501 0 0 r
.47369 .67819 m .47015 .67822 L .47161 .67881 L F
0 0 0 r
.50861 .66323 m .51348 .66179 L .50899 .66168 L F
.50861 .66323 m .51098 .66274 L .51348 .66179 L F
.415 .48 .819 r
.51173 .65844 m .51348 .66179 L .5145 .66071 L F
.795 .567 .591 r
.51098 .66274 m .5145 .66071 L .51348 .66179 L F
.618 .744 .936 r
.34234 .62232 m .3389 .62117 L .34104 .62054 L F
.286 .679 .973 r
.3435 .62145 m .34234 .62232 L .34104 .62054 L F
.3435 .62145 m .34517 .62259 L .34234 .62232 L F
.792 .693 .755 r
.55525 .60993 m .55341 .61284 L .55481 .61273 L F
.711 .532 .645 r
.55341 .61284 m .55587 .61514 L .55481 .61273 L F
.536 .451 .706 r
.55525 .60993 m .55481 .61273 L .55757 .61161 L F
.677 .589 .75 r
.55587 .61514 m .55757 .61161 L .55481 .61273 L F
.524 .539 .813 r
.51016 .65027 m .5108 .64594 L .50881 .64649 L F
.51016 .65027 m .51226 .65015 L .5108 .64594 L F
.411 .827 .643 r
.50954 .6518 m .51226 .65015 L .51016 .65027 L F
.668 .427 .546 r
.51226 .65015 m .50954 .6518 L .51016 .65027 L F
.823 .818 .844 r
.68411 .49948 m .68305 .49975 L .6856 .50055 L F
.968 .739 .303 r
.68305 .49975 m .68385 .50349 L .6856 .50055 L F
.494 .766 .992 r
.4728 .70137 m .47182 .70011 L .47051 .70149 L F
.4728 .70137 m .47182 .70011 L .47051 .70149 L F
0 .301 .796 r
.56128 .63842 m .56185 .63769 L .56026 .63716 L F
.56128 .63842 m .56414 .64058 L .56185 .63769 L F
.534 .555 .823 r
.40032 .60173 m .40166 .60407 L .40343 .60316 L F
.646 .535 .714 r
.40106 .60638 m .40343 .60316 L .40166 .60407 L F
.647 .566 .75 r
.42495 .70346 m .42487 .70086 L .42259 .70152 L F
.518 .861 .993 r
.37817 .59491 m .37898 .59369 L .37716 .59444 L F
.37817 .59491 m .3831 .59373 L .37898 .59369 L F
.629 .706 .901 r
.55564 .64303 m .55673 .64478 L .55897 .64394 L F
.55897 .64394 m .55673 .64478 L .55564 .64303 L F
.433 .342 .653 r
.29408 .60667 m .29586 .60254 L .29366 .60423 L F
.74 .596 .697 r
.72841 .47473 m .72934 .47797 L .73192 .47528 L F
0 .389 .827 r
.31202 .63367 m .31187 .63264 L .31085 .63278 L F
.31202 .63367 m .31427 .63471 L .31187 .63264 L F
.77 .853 .912 r
.31461 .63603 m .31427 .63471 L .31202 .63367 L F
.474 .037 .128 r
.35586 .64142 m .3543 .64322 L .35198 .64325 L F
.154 0 0 r
.35653 .64248 m .35586 .64142 L .35815 .64113 L F
.35653 .64248 m .3543 .64322 L .35586 .64142 L F
.746 .799 .895 r
.66872 .50349 m .67212 .50368 L .67091 .50252 L F
.624 .813 .973 r
.67091 .50252 m .67212 .50368 L .67485 .50292 L F
.357 .034 .274 r
.39305 .61185 m .3962 .60862 L .3938 .60915 L F
0 .284 .644 r
.34682 .62605 m .34818 .62668 L .34985 .62745 L F
.333 .786 .951 r
.34818 .62668 m .35198 .62684 L .34985 .62745 L F
.682 .341 .392 r
.66267 .4861 m .66492 .48834 L .66447 .4866 L F
.474 .353 .634 r
.66267 .4861 m .66282 .48916 L .66492 .48834 L F
.515 .393 .652 r
.45432 .6832 m .4511 .68141 L .4537 .6808 L F
.45432 .6832 m .45144 .68406 L .4511 .68141 L F
.545 .514 .772 r
.77489 .49576 m .77687 .49369 L .77452 .49419 L F
.355 .731 .987 r
.20265 .54807 m .20626 .54893 L .20437 .54907 L F
0 0 0 r
.56446 .6063 m .56318 .60915 L .56404 .60698 L F
.239 .714 .939 r
.76633 .4892 m .76364 .48861 L .76137 .48847 L F
.053 .598 .842 r
.76633 .4892 m .76679 .48919 L .76364 .48861 L F
.145 0 0 r
.66492 .48834 m .6684 .48665 L .66447 .4866 L F
.66492 .48834 m .66744 .48787 L .6684 .48665 L F
.219 0 0 r
.6684 .48665 m .66994 .4871 L .6707 .48608 L F
.6684 .48665 m .66744 .48787 L .66994 .4871 L F
.209 .267 .705 r
.53259 .67199 m .53318 .67526 L .53587 .6728 L F
0 .418 .717 r
.44882 .70975 m .44818 .70948 L .44388 .70825 L F
.207 .589 .945 r
.44882 .70975 m .44917 .70875 L .44818 .70948 L F
.44882 .70975 m .44985 .70982 L .44917 .70875 L F
.326 0 .003 r
.31251 .58862 m .31627 .58666 L .31405 .58699 L F
.202 .303 .745 r
.54667 .66277 m .54532 .66207 L .54744 .65987 L F
.662 .962 .762 r
.46677 .66972 m .46876 .6681 L .46795 .66827 L F
.384 .523 .873 r
.46795 .66827 m .46897 .67001 L .46677 .66972 L F
0 .154 .681 r
.54534 .66608 m .54773 .66823 L .5467 .66696 L F
.439 0 0 r
.54534 .66608 m .54632 .66672 L .54895 .66696 L F
.077 0 .442 r
.54667 .66277 m .54627 .66665 L .54534 .66608 L F
0 .154 .681 r
.54534 .66608 m .5467 .66696 L .54661 .66685 L F
.439 0 0 r
.54534 .66608 m .54627 .66671 L .54632 .66672 L F
.077 0 .442 r
.54627 .66665 m .54627 .66671 L .54534 .66608 L F
0 .154 .681 r
.54534 .66608 m .54661 .66685 L .54608 .6662 L F
.843 .974 .876 r
.54895 .66696 m .55032 .66345 L .55085 .66354 L F
.54895 .66696 m .54627 .66671 L .55032 .66345 L F
.496 .402 .678 r
.55085 .66354 m .55116 .66657 L .54895 .66696 L F
0 0 .36 r
.55116 .66657 m .54991 .66976 L .54895 .66696 L F
.8 .718 .774 r
.47148 .67274 m .47052 .67572 L .47022 .67279 L F
.633 .549 .742 r
.71677 .49195 m .71775 .49475 L .72038 .49212 L F
.237 0 .338 r
.21083 .5783 m .21017 .5805 L .21002 .58056 L F
.259 .06 .409 r
.21205 .57739 m .21017 .5805 L .21083 .5783 L F
.461 .162 .37 r
.4811 .6532 m .48037 .65508 L .47812 .65552 L F
.607 .423 .607 r
.48298 .65212 m .48037 .65508 L .4811 .6532 L F
0 .198 .722 r
.54502 .6395 m .54442 .64012 L .54239 .63778 L F
.54502 .6395 m .54654 .64258 L .54442 .64012 L F
.246 0 0 r
.37982 .63411 m .38363 .6318 L .38205 .63362 L F
.269 0 0 r
.38363 .6318 m .38438 .63303 L .38205 .63362 L F
.38363 .6318 m .38604 .63129 L .38438 .63303 L F
.444 .015 .127 r
.42542 .60875 m .42604 .6076 L .42784 .60846 L F
0 0 0 r
.59578 .64406 m .59727 .64289 L .59783 .64131 L F
.958 .628 .344 r
.59783 .64131 m .59727 .64289 L .59648 .64054 L F
0 0 .236 r
.59884 .63994 m .59783 .64131 L .59648 .64054 L F
.958 .628 .344 r
.59783 .64131 m .59727 .64289 L .59648 .64054 L F
.466 .716 .978 r
.40226 .58708 m .40127 .58875 L .39917 .587 L F
.40226 .58708 m .40351 .58848 L .40127 .58875 L F
.217 .133 .541 r
.21017 .5805 m .21033 .58302 L .20888 .58394 L F
0 0 .128 r
.21033 .58302 m .20889 .58645 L .20888 .58394 L F
.512 .14 .271 r
.34962 .64347 m .346 .64565 L .34739 .64391 L F
.218 0 .125 r
.45802 .65828 m .45517 .66061 L .45743 .66065 L F
.423 .116 .337 r
.46023 .65772 m .45802 .65828 L .45743 .66065 L F
.598 .414 .603 r
.70832 .47785 m .71058 .47944 L .71069 .47731 L F
.70832 .47785 m .70838 .48025 L .71058 .47944 L F
0 0 .042 r
.56253 .64438 m .56351 .64303 L .56414 .64058 L F
.352 .604 .943 r
.56253 .64438 m .56418 .64462 L .56351 .64303 L F
0 .055 .621 r
.54611 .67011 m .54747 .67274 L .54625 .66987 L F
.579 .365 .554 r
.54528 .67531 m .54784 .67545 L .54747 .67274 L F
.54528 .67531 m .54784 .67545 L .54747 .67274 L F
.775 .718 .799 r
.54625 .66987 m .54747 .67274 L .54991 .66976 L F
.652 .529 .7 r
.54747 .67274 m .54993 .67265 L .54991 .66976 L F
.488 .597 .888 r
.41934 .59745 m .42094 .59999 L .41803 .59907 L F
.421 0 0 r
.37278 .59513 m .37152 .59567 L .36933 .59545 L F
0 0 0 r
.37499 .59487 m .37152 .59567 L .37278 .59513 L F
.275 0 0 r
.78865 .52828 m .79061 .5284 L .78943 .52978 L F
.922 .616 .141 r
.56317 .62228 m .56354 .62113 L .56189 .62078 L F
.56317 .62228 m .56398 .62349 L .56354 .62113 L F
.928 .728 .611 r
.61465 .60043 m .61621 .60117 L .61494 .59787 L F
.951 .711 .539 r
.61468 .60269 m .61621 .60117 L .61465 .60043 L F
.61468 .60269 m .61612 .60373 L .61621 .60117 L F
.598 .301 .437 r
.3012 .62861 m .30424 .62673 L .30194 .62735 L F
.704 .655 .798 r
.79212 .52321 m .79028 .52625 L .79093 .52601 L F
.563 .341 .536 r
.41523 .61258 m .41506 .61485 L .41276 .61508 L F
.553 .333 .535 r
.41523 .61258 m .41741 .61452 L .41506 .61485 L F
.59 .327 .485 r
.41766 .61238 m .41741 .61452 L .41523 .61258 L F
.848 .656 .642 r
.51915 .76648 m .52063 .76978 L .52057 .76501 L F
.32 0 .086 r
.374 .62293 m .37742 .62054 L .37517 .62083 L F
.497 .334 .59 r
.50174 .66705 m .50207 .67002 L .504 .66904 L F
.523 .332 .563 r
.50174 .66705 m .504 .66904 L .50402 .66659 L F
.50174 .66705 m .504 .66904 L .50402 .66659 L F
.445 .211 .463 r
.29579 .59821 m .29784 .59782 L .29832 .59589 L F
.427 .239 .521 r
.29586 .60065 m .29784 .59782 L .29579 .59821 L F
.209 0 0 r
.48721 .65055 m .48623 .6498 L .48896 .64927 L F
.48721 .65055 m .48477 .65111 L .48623 .6498 L F
.558 .241 .388 r
.51618 .64851 m .51204 .65201 L .51226 .65015 L F
.51618 .64851 m .51453 .65177 L .51204 .65201 L F
.015 0 0 r
.51819 .64758 m .51701 .64885 L .51618 .64851 L F
.322 .002 .257 r
.51696 .651 m .51618 .64851 L .51701 .64885 L F
.51696 .651 m .51453 .65177 L .51618 .64851 L F
.377 .792 .978 r
.31921 .64096 m .3229 .64125 L .32161 .64066 L F
.555 .659 .905 r
.3229 .64125 m .32361 .63898 L .32161 .64066 L F
.59 .847 .993 r
.35814 .62585 m .35552 .62671 L .35405 .62588 L F
.431 .438 .765 r
.29899 .61523 m .30003 .61868 L .30186 .6174 L F
.501 .578 .864 r
.30003 .61868 m .30169 .61812 L .30186 .6174 L F
.425 .532 .863 r
.30003 .61868 m .30292 .62024 L .30169 .61812 L F
.604 .241 .327 r
.50636 .66156 m .50861 .66323 L .50899 .66168 L F
.941 .743 .607 r
.7252 .50524 m .72721 .50405 L .72489 .50339 L F
.7252 .50524 m .72662 .50654 L .72721 .50405 L F
.247 .443 .856 r
.74118 .47781 m .74294 .47666 L .7409 .47641 L F
.822 .443 .338 r
.74475 .48055 m .74425 .48061 L .74118 .47781 L F
.247 .443 .856 r
.74118 .47781 m .74425 .48061 L .74294 .47666 L F
.664 .322 .383 r
.50554 .6774 m .50666 .67548 L .50525 .67478 L F
.50554 .6774 m .50889 .67771 L .50666 .67548 L F
.606 .383 .551 r
.42022 .60967 m .42025 .61237 L .41766 .61238 L F
.504 .264 .484 r
.42296 .60919 m .42025 .61237 L .42022 .60967 L F
.04 .006 .486 r
.44867 .68618 m .44845 .69021 L .4478 .68962 L F
0 .022 .591 r
.44845 .69021 m .44921 .69163 L .4478 .68962 L F
.43 .177 .428 r
.58843 .57227 m .5908 .57159 L .59094 .56964 L F
.617 .33 .46 r
.5908 .57159 m .59345 .57161 L .59094 .56964 L F
.524 .359 .599 r
.59094 .56964 m .59345 .57161 L .59329 .56901 L F
.687 .149 0 r
.43797 .70333 m .44081 .70459 L .44013 .70524 L F
.386 0 0 r
.44294 .70682 m .44013 .70524 L .44081 .70459 L F
.495 .466 .754 r
.29577 .6124 m .29684 .60876 L .29433 .60904 L F
.29577 .6124 m .29766 .6119 L .29684 .60876 L F
0 0 .088 r
.48647 .62656 m .48612 .62863 L .48655 .62644 L F
.191 .213 .654 r
.61134 .65714 m .61015 .65836 L .60969 .65546 L F
0 0 .358 r
.61121 .65857 m .61015 .65836 L .61134 .65714 L F
.61121 .65857 m .6104 .66088 L .61015 .65836 L F
.582 .515 .745 r
.79732 .4923 m .7954 .49473 L .79506 .49281 L F
.636 .593 .789 r
.79732 .4923 m .79859 .49565 L .7954 .49473 L F
.337 .79 .649 r
.48204 .6709 m .48265 .67055 L .48046 .66946 L F
.48204 .6709 m .48418 .66981 L .48265 .67055 L F
.233 0 0 r
.46876 .6681 m .47048 .66834 L .46795 .66827 L F
.439 .153 .38 r
.52447 .66421 m .52674 .6637 L .52737 .66081 L F
.422 .096 .305 r
.52674 .6637 m .53024 .66047 L .52737 .66081 L F
.632 .43 .591 r
.52532 .6525 m .52559 .65542 L .52272 .65531 L F
.249 .514 .908 r
.56649 .64687 m .56719 .64566 L .56418 .64462 L F
0 .153 .606 r
.4712 .66394 m .4676 .66129 L .47006 .66134 L F
.385 .54 .887 r
.34696 .62268 m .34582 .62423 L .34517 .62259 L F
.219 .303 .737 r
.34696 .62268 m .34682 .62605 L .34582 .62423 L F
.981 .756 .525 r
.74603 .50766 m .74745 .50642 L .74668 .50498 L F
.74603 .50766 m .74723 .50884 L .74745 .50642 L F
.168 .693 .87 r
.34545 .58329 m .34761 .58323 L .34912 .58351 L F
.4 .805 .982 r
.34761 .58323 m .3513 .58346 L .34912 .58351 L F
.605 .933 .959 r
.7598 .52556 m .76173 .52425 L .75915 .52504 L F
.7598 .52556 m .76311 .52431 L .76173 .52425 L F
.425 .732 .99 r
.56668 .62559 m .5646 .62689 L .56398 .62349 L F
.56668 .62559 m .56795 .62686 L .5646 .62689 L F
.561 .103 .122 r
.49264 .61952 m .4961 .61841 L .49419 .61778 L F
.654 .406 .532 r
.39851 .60884 m .40106 .60638 L .39897 .60699 L F
.751 .68 .783 r
.71179 .48293 m .71527 .48334 L .71416 .48001 L F
.735 .672 .788 r
.71416 .48001 m .71527 .48334 L .71771 .48063 L F
.824 .707 .736 r
.74391 .49789 m .74608 .50076 L .74303 .4996 L F
.841 .463 .334 r
.74608 .50076 m .74419 .50273 L .74303 .4996 L F
.74419 .50273 m .74361 .50205 L .74303 .4996 L F
.873 .777 .752 r
.74391 .49789 m .74134 .49946 L .74221 .49687 L F
.74391 .49789 m .74303 .4996 L .74134 .49946 L F
.841 .463 .334 r
.74419 .50273 m .74385 .50307 L .74361 .50205 L F
0 0 .428 r
.74303 .4996 m .74385 .50307 L .7442 .50101 L F
.072 0 .449 r
.74275 .50312 m .74385 .50307 L .74303 .4996 L F
0 0 .428 r
.74303 .4996 m .7442 .50101 L .74134 .49946 L F
.338 .409 .789 r
.74138 .49942 m .7442 .50101 L .74309 .4976 L F
.74134 .49946 m .74148 .49954 L .74138 .49942 L F
.74148 .49954 m .7442 .50101 L .74138 .49942 L F
.23 .359 .788 r
.7466 .49815 m .74561 .49983 L .74391 .49789 L F
.984 .906 .606 r
.74561 .49934 m .74561 .49983 L .7466 .49815 L F
0 .067 .611 r
.74561 .49983 m .74561 .50014 L .74391 .49789 L F
.984 .906 .606 r
.7442 .50101 m .74561 .49983 L .74561 .49934 L F
0 .067 .611 r
.74561 .49983 m .74608 .50076 L .74561 .50014 L F
.97 .92 .592 r
.74561 .49983 m .74385 .50307 L .74608 .50076 L F
.299 .189 .556 r
.55855 .61501 m .55879 .61751 L .55738 .61723 L F
.232 .095 .479 r
.611 .63799 m .611 .64043 L .60976 .64105 L F
0 0 .326 r
.611 .64043 m .61056 .64352 L .60976 .64105 L F
.798 .313 .055 r
.59904 .56689 m .60039 .56876 L .60215 .56932 L F
.977 .766 .552 r
.60029 .5706 m .60215 .56932 L .60039 .56876 L F
.60029 .5706 m .60179 .57218 L .60215 .56932 L F
.429 .109 .32 r
.45197 .66579 m .45037 .66441 L .44981 .66632 L F
.45197 .66579 m .45263 .66395 L .45037 .66441 L F
.042 0 0 r
.34938 .59876 m .34767 .59936 L .34552 .59964 L F
0 0 0 r
.34997 .59866 m .34938 .59876 L .35155 .59833 L F
.34997 .59866 m .34767 .59936 L .34938 .59876 L F
.492 .553 .846 r
.65783 .49248 m .66038 .49402 L .6603 .49183 L F
.852 .655 .635 r
.68035 .49096 m .68361 .4892 L .68022 .48894 L F
.68035 .49096 m .68354 .49234 L .68361 .4892 L F
.21 0 0 r
.35735 .59717 m .35376 .59775 L .35518 .59748 L F
.498 .2 .39 r
.43678 .67241 m .43923 .67219 L .43963 .66997 L F
.568 .262 .409 r
.43963 .66997 m .44169 .67178 L .44174 .66934 L F
.43963 .66997 m .43923 .67219 L .44169 .67178 L F
.621 .602 .81 r
.71677 .49195 m .71917 .48896 L .71654 .48936 L F
.71677 .49195 m .72038 .49212 L .71917 .48896 L F
.537 .254 .433 r
.45555 .67903 m .45596 .68077 L .4537 .6808 L F
0 0 .19 r
.61135 .65414 m .60969 .65546 L .61117 .65243 L F
.202 .215 .65 r
.61135 .65414 m .61134 .65714 L .60969 .65546 L F
.043 0 0 r
.36622 .63853 m .36232 .63976 L .36398 .6386 L F
.644 .615 .806 r
.77687 .49369 m .77761 .49778 L .7802 .49487 L F
.652 .627 .813 r
.77761 .49778 m .78117 .49759 L .7802 .49487 L F
.61 .391 .559 r
.77844 .49927 m .78117 .49759 L .77761 .49778 L F
.714 .776 .9 r
.79699 .51652 m .80052 .51662 L .79964 .51499 L F
.87 .863 .83 r
.79964 .51499 m .80052 .51662 L .8014 .5154 L F
.448 .761 .996 r
.54117 .63677 m .54016 .63803 L .53913 .63683 L F
.54117 .63677 m .54239 .63778 L .54016 .63803 L F
.955 .641 .221 r
.79157 .52108 m .79212 .52321 L .79174 .52077 L F
.876 .933 .855 r
.79076 .52006 m .79174 .52077 L .79445 .51772 L F
.003 .077 .589 r
.5743 .67297 m .57542 .67165 L .57398 .66947 L F
.513 .27 .483 r
.58055 .57812 m .58299 .57766 L .58306 .57538 L F
.431 .14 .368 r
.58299 .57766 m .58575 .57451 L .58306 .57538 L F
0 .092 .63 r
.74475 .48055 m .74643 .48105 L .74549 .48048 L F
0 0 0 r
.74475 .48055 m .74549 .48048 L .74425 .48061 L F
.335 .702 .983 r
.77662 .48315 m .77482 .48408 L .77406 .48279 L F
.77662 .48315 m .77785 .48422 L .77482 .48408 L F
.711 .541 .658 r
.50531 .71197 m .50906 .70998 L .50489 .70999 L F
.831 .787 .81 r
.32862 .64547 m .33003 .64703 L .33252 .64431 L F
.32862 .64547 m .33252 .64431 L .33063 .64499 L F
.079 .287 .771 r
.33252 .64431 m .33295 .6426 L .33063 .64499 L F
.33252 .64431 m .33443 .64571 L .33295 .6426 L F
.524 .508 .78 r
.51969 .76991 m .51915 .76648 L .51699 .76726 L F
.51969 .76991 m .52063 .76978 L .51915 .76648 L F
.158 0 .01 r
.5449 .69985 m .54114 .70238 L .54422 .70091 L F
.549 .147 .232 r
.54422 .70091 m .54704 .70085 L .5449 .69985 L F
.229 .737 .887 r
.36309 .59681 m .35956 .59676 L .3611 .5969 L F
.431 .382 .702 r
.50637 .65141 m .50488 .65431 L .50424 .65159 L F
.427 .768 .996 r
.50847 .65107 m .50954 .6518 L .50637 .65141 L F
.62 .5 .695 r
.50951 .65414 m .50932 .65398 L .50956 .65417 L F
.50932 .65398 m .50637 .65141 L .50933 .65397 L F
.50932 .65398 m .50933 .65397 L .50956 .65417 L F
.50956 .65418 m .50914 .65426 L .50929 .65394 L F
0 0 0 r
.50921 .65411 m .50921 .65412 L .50925 .65402 L F
.50918 .65417 m .50919 .65416 L .50921 .65411 L F
.50919 .65416 m .50921 .65412 L .50921 .65411 L F
.62 .5 .695 r
.50898 .65404 m .507 .65369 L .50637 .65141 L F
.599 .554 .775 r
.50703 .65358 m .50825 .65391 L .50912 .65391 L F
.50825 .65391 m .50918 .65417 L .50916 .65408 L F
.50825 .65391 m .50916 .65408 L .50912 .65391 L F
.62 .5 .695 r
.50929 .65394 m .50907 .65401 L .50637 .65141 L F
.50955 .6533 m .50637 .65141 L .50954 .6518 L F
.50929 .65393 m .50637 .65141 L .50955 .6533 L F
.668 .427 .546 r
.51226 .65015 m .51204 .65201 L .50954 .6518 L F
.411 .827 .643 r
.50954 .6518 m .51075 .65098 L .51226 .65015 L F
.658 .368 .468 r
.51204 .65201 m .51195 .65404 L .51001 .65223 L F
.51016 .65185 m .51001 .65223 L .50954 .6518 L F
.51204 .65201 m .51001 .65223 L .51016 .65185 L F
.175 .324 .776 r
.51075 .65098 m .51195 .65404 L .51001 .65223 L F
.51075 .65098 m .51001 .65223 L .50954 .6518 L F
.612 .6 .814 r
.51075 .65098 m .50956 .65418 L .50954 .6518 L F
0 0 0 r
.50948 .65356 m .51002 .65295 L .51075 .65098 L F
.62 .5 .695 r
.50956 .65417 m .50929 .65393 L .50955 .6533 L F
0 0 0 r
.50925 .65402 m .50935 .65388 L .50948 .65356 L F
.50935 .65388 m .51002 .65295 L .50948 .65356 L F
.612 .6 .814 r
.51075 .65098 m .50954 .6518 L .50847 .65107 L F
0 0 0 r
.50916 .65408 m .51075 .65098 L .50847 .65107 L F
.50918 .65417 m .50921 .65411 L .50916 .65408 L F
.50921 .65411 m .51075 .65098 L .50916 .65408 L F
.62 .5 .695 r
.50907 .65401 m .50898 .65404 L .50866 .65372 L F
.50907 .65401 m .50866 .65372 L .50637 .65141 L F
.599 .554 .775 r
.50684 .65427 m .50918 .65417 L .50703 .65358 L F
.62 .5 .695 r
.50898 .65404 m .50726 .65462 L .507 .65369 L F
.50911 .65427 m .50726 .65462 L .50906 .65419 L F
.286 0 0 r
.50915 .65418 m .50918 .65417 L .50656 .65438 L F
.62 .5 .695 r
.50917 .65418 m .50906 .65419 L .50919 .65416 L F
.50911 .65427 m .50907 .6542 L .50917 .65418 L F
0 0 .469 r
.50726 .65462 m .50689 .65795 L .50488 .65431 L F
.50726 .65462 m .50739 .6573 L .50689 .65795 L F
.502 .421 .697 r
.50954 .65567 m .50739 .6573 L .50736 .65658 L F
.50842 .65516 m .50736 .65658 L .50726 .65462 L F
.50954 .65567 m .50736 .65658 L .50842 .65516 L F
.50954 .65567 m .50726 .65462 L .50956 .65418 L F
.286 0 0 r
.50523 .65636 m .50766 .65603 L .50917 .65418 L F
.62 .5 .695 r
.50907 .6542 m .50906 .65419 L .50915 .65418 L F
.50907 .6542 m .50915 .65418 L .50917 .65418 L F
.431 .382 .702 r
.507 .65369 m .50676 .65456 L .50488 .65431 L F
.286 0 0 r
.50656 .65438 m .50717 .65433 L .50662 .65428 L F
.50717 .65433 m .50918 .65417 L .50684 .65427 L F
.431 .382 .702 r
.50718 .65433 m .50726 .65462 L .50684 .65427 L F
.286 0 0 r
.50717 .65433 m .50684 .65427 L .50662 .65428 L F
.431 .382 .702 r
.50684 .65427 m .50726 .65462 L .50676 .65456 L F
.507 .65369 m .50718 .65433 L .50684 .65427 L F
0 0 0 r
.50921 .65412 m .51002 .65295 L .50925 .65402 L F
.471 .256 .505 r
.50766 .65603 m .51002 .65295 L .50937 .65389 L F
.62 .5 .695 r
.50919 .65416 m .50726 .65462 L .50929 .65394 L F
.471 .256 .505 r
.50902 .65436 m .50937 .65389 L .50921 .65412 L F
.50766 .65603 m .50937 .65389 L .50902 .65436 L F
.286 0 0 r
.50915 .65418 m .50917 .65418 L .50918 .65417 L F
.50523 .65636 m .50917 .65418 L .50915 .65418 L F
.50523 .65636 m .50915 .65418 L .50656 .65438 L F
.471 .256 .505 r
.5091 .65427 m .50921 .65412 L .50919 .65416 L F
.50917 .65418 m .50919 .65416 L .50918 .65417 L F
.5091 .65427 m .50919 .65416 L .50917 .65418 L F
.62 .5 .695 r
.50914 .65426 m .50911 .65427 L .50919 .65416 L F
.471 .256 .505 r
.50766 .65603 m .50921 .65412 L .5091 .65427 L F
.62 .5 .695 r
.50956 .65418 m .50951 .65414 L .50956 .65417 L F
.599 .554 .775 r
.50742 .65291 m .50912 .65391 L .50847 .65107 L F
.50703 .65358 m .50912 .65391 L .50742 .65291 L F
.50662 .65428 m .50684 .65427 L .50703 .65358 L F
.431 .382 .702 r
.50637 .65141 m .507 .65369 L .50488 .65431 L F
0 .454 .73 r
.40894 .59049 m .41261 .59146 L .41088 .5916 L F
.482 .229 .453 r
.58818 .57414 m .5908 .57159 L .58843 .57227 L F
.479 .192 .399 r
.58575 .57451 m .58818 .57414 L .58843 .57227 L F
.557 .642 .89 r
.79926 .50235 m .79747 .50472 L .79741 .50276 L F
.79926 .50235 m .80068 .50507 L .79747 .50472 L F
.392 .2 .497 r
.56969 .60018 m .56748 .60352 L .56785 .60105 L F
.522 .502 .775 r
.54401 .66963 m .54534 .66608 L .54298 .66726 L F
0 .055 .621 r
.54611 .67011 m .54625 .66987 L .54401 .66963 L F
.586 .938 .932 r
.75104 .52742 m .75465 .52648 L .75404 .5265 L F
.259 .768 .779 r
.75404 .5265 m .75465 .52648 L .75704 .52585 L F
.291 0 .064 r
.55849 .58918 m .56065 .58858 L .56176 .58678 L F
.487 .127 .281 r
.56065 .58858 m .56402 .58617 L .56176 .58678 L F
.322 0 0 r
.76236 .4803 m .76468 .48137 L .76558 .48169 L F
.446 .832 .986 r
.76468 .48137 m .76841 .48161 L .76558 .48169 L F
.679 .51 .65 r
.49328 .64135 m .49296 .64425 L .4906 .64376 L F
.672 .504 .649 r
.49632 .6422 m .49296 .64425 L .49328 .64135 L F
0 .065 .622 r
.5697 .63012 m .57024 .63213 L .56848 .62956 L F
.705 .458 .547 r
.56217 .60567 m .5655 .60394 L .56424 .60296 L F
.56217 .60567 m .56446 .6063 L .5655 .60394 L F
0 .312 .803 r
.28844 .64853 m .28954 .64853 L .28841 .64811 L F
.354 .244 .588 r
.28844 .64853 m .28922 .64815 L .28996 .64654 L F
0 .312 .803 r
.28841 .64811 m .28954 .64853 L .28844 .64853 L F
.783 .634 .696 r
.72601 .47743 m .72982 .48006 L .72934 .47797 L F
.72601 .47743 m .7259 .47978 L .72982 .48006 L F
.782 .654 .721 r
.7259 .47978 m .72711 .48326 L .72982 .48006 L F
.211 .257 .692 r
.72982 .48006 m .73222 .48172 L .73185 .47976 L F
.416 .864 .864 r
.53416 .60012 m .53602 .59906 L .53738 .59838 L F
.53416 .60012 m .5336 .59997 L .53602 .59906 L F
.871 .659 .613 r
.59459 .58671 m .59169 .58855 L .59124 .58613 L F
.59459 .58671 m .59435 .58928 L .59169 .58855 L F
.233 0 0 r
.32493 .6432 m .32698 .64283 L .32874 .64117 L F
.574 .939 .903 r
.32953 .64013 m .32767 .64125 L .32874 .64117 L F
.591 .876 .561 r
.32874 .64117 m .32698 .64283 L .32953 .64013 L F
.876 .834 .801 r
.45105 .69627 m .45407 .69508 L .45247 .69412 L F
.45105 .69627 m .45164 .69843 L .45407 .69508 L F
.422 .755 .995 r
.45407 .69508 m .4564 .69476 L .45247 .69412 L F
0 0 .538 r
.30424 .62362 m .30465 .61995 L .30292 .62024 L F
0 0 .432 r
.3063 .62616 m .30646 .62178 L .30469 .62129 L F
.391 0 0 r
.30646 .62178 m .30484 .62166 L .30469 .62129 L F
0 0 .538 r
.30424 .62362 m .30469 .62129 L .30454 .62091 L F
.30424 .62362 m .30491 .62334 L .30469 .62129 L F
.391 0 0 r
.30484 .62166 m .30283 .62151 L .30469 .62129 L F
0 0 .538 r
.30454 .62091 m .30469 .62129 L .30465 .61995 L F
.473 .463 .767 r
.30424 .62673 m .30491 .62334 L .30424 .62362 L F
.393 .549 .891 r
.32716 .64573 m .32698 .64283 L .32493 .6432 L F
.32716 .64573 m .32862 .64547 L .32698 .64283 L F
.582 .634 .868 r
.32716 .64573 m .33003 .64703 L .32862 .64547 L F
.485 .419 .707 r
.50424 .65159 m .50637 .65141 L .50382 .64999 L F
.50424 .65159 m .50637 .65141 L .50382 .64999 L F
.775 .529 0 r
.56983 .65571 m .56992 .65702 L .56999 .65471 L F
.56983 .65571 m .57024 .65816 L .56992 .65702 L F
.572 .087 .066 r
.59525 .56695 m .59777 .56813 L .59904 .56689 L F
.771 .338 .223 r
.59777 .56813 m .60039 .56876 L .59904 .56689 L F
.814 .585 .591 r
.60384 .57994 m .60728 .57806 L .60376 .57762 L F
.60384 .57994 m .60746 .58061 L .60728 .57806 L F
.387 .295 .628 r
.49035 .64658 m .48896 .64927 L .48822 .64715 L F
0 0 0 r
.54157 .70334 m .54422 .70091 L .54114 .70238 L F
.104 0 .178 r
.33492 .60606 m .33264 .60885 L .33337 .60696 L F
.251 .63 .96 r
.75009 .51123 m .7486 .51184 L .74753 .51162 L F
.75009 .51123 m .75106 .51238 L .7486 .51184 L F
.614 .352 .498 r
.54534 .66608 m .54298 .66726 L .54279 .6641 L F
.258 0 .011 r
.49034 .67268 m .4882 .6733 L .48759 .67467 L F
.932 .802 .694 r
.5993 .62083 m .60015 .62405 L .59934 .62294 L F
.982 .77 .362 r
.59939 .62574 m .60015 .62405 L .5996 .62636 L F
.59939 .62574 m .59934 .62294 L .60015 .62405 L F
.382 .434 .79 r
.50697 .77235 m .50772 .76938 L .5092 .77003 L F
.50697 .77235 m .50895 .77296 L .50772 .76938 L F
.413 .026 .192 r
.77467 .51284 m .77553 .51066 L .77217 .51234 L F
.576 .475 .703 r
.77553 .51066 m .77797 .51158 L .77757 .50857 L F
.551 .111 .157 r
.77467 .51284 m .77797 .51158 L .77553 .51066 L F
.517 .497 .774 r
.71654 .48936 m .71786 .48519 L .71884 .4861 L F
.564 .849 .997 r
.71884 .4861 m .71987 .48496 L .72141 .48488 L F
.71884 .4861 m .71786 .48519 L .72024 .48456 L F
.693 .599 .746 r
.71813 .48539 m .71917 .48896 L .72147 .48793 L F
.71786 .48519 m .71795 .48544 L .71813 .48539 L F
.71795 .48544 m .71917 .48896 L .71813 .48539 L F
.564 .849 .997 r
.71987 .48496 m .72024 .48456 L .72082 .48472 L F
.71987 .48496 m .72082 .48472 L .72141 .48488 L F
.645 .594 .782 r
.58004 .64652 m .57894 .65049 L .57768 .64708 L F
.58004 .64652 m .58129 .64996 L .57894 .65049 L F
.72 .383 .408 r
.47037 .70902 m .47358 .70748 L .47179 .70662 L F
.4 .274 .592 r
.33264 .60885 m .33273 .61142 L .33084 .6096 L F
.423 .275 .575 r
.33084 .6096 m .33273 .61142 L .33085 .61186 L F
.307 0 0 r
.31854 .58634 m .32078 .58599 L .32229 .58445 L F
.244 0 0 r
.32229 .58445 m .3238 .58476 L .32452 .58406 L F
.32229 .58445 m .32078 .58599 L .3238 .58476 L F
.551 .691 .932 r
.77452 .49419 m .77515 .49149 L .77316 .49117 L F
.77452 .49419 m .77687 .49369 L .77515 .49149 L F
.409 .477 .818 r
.55782 .66764 m .56094 .66896 L .5591 .67042 L F
.398 .456 .804 r
.56094 .66896 m .56184 .67196 L .5591 .67042 L F
.318 0 .233 r
.30305 .59191 m .30407 .59366 L .30531 .5916 L F
.30305 .59191 m .30206 .59432 L .30407 .59366 L F
.513 .453 .727 r
.79719 .49025 m .79506 .49281 L .79434 .48892 L F
.582 .515 .745 r
.79732 .4923 m .79506 .49281 L .79719 .49025 L F
.613 .134 0 r
.55567 .63041 m .55598 .63097 L .55478 .62923 L F
.55567 .63041 m .55732 .63245 L .55598 .63097 L F
.235 .625 .957 r
.74385 .50307 m .74365 .50447 L .74275 .50312 L F
.74385 .50307 m .74668 .50498 L .74365 .50447 L F
.432 0 0 r
.50678 .63869 m .50587 .63963 L .5038 .6389 L F
.327 .729 .981 r
.50927 .64047 m .50587 .63963 L .50678 .63869 L F
.607 .038 0 r
.51121 .64107 m .50927 .64047 L .50678 .63869 L F
.87 .863 .83 r
.79964 .51499 m .8014 .5154 L .80139 .51339 L F
.409 0 0 r
.35814 .62585 m .36016 .6267 L .36143 .62691 L F
.49 .889 .946 r
.36143 .62691 m .36227 .62594 L .36361 .62636 L F
.36143 .62691 m .36016 .6267 L .36227 .62594 L F
.473 .616 .911 r
.67792 .50403 m .67931 .50203 L .67696 .50248 L F
.67792 .50403 m .68011 .50396 L .67931 .50203 L F
.589 .404 .598 r
.75122 .48597 m .74887 .488 L .74826 .48583 L F
.75122 .48597 m .74942 .48588 L .75185 .48588 L F
.74942 .48588 m .74941 .48584 L .75185 .48588 L F
0 0 0 r
.74998 .48412 m .74887 .488 L .75122 .48597 L F
.018 0 .463 r
.74907 .48774 m .74914 .48739 L .74822 .48564 L F
.09 .578 .902 r
.74914 .48739 m .7508 .48815 L .74887 .488 L F
.561 .672 .913 r
.7508 .48815 m .74863 .49044 L .74887 .488 L F
.018 0 .463 r
.74933 .4884 m .74857 .48953 L .74914 .48739 L F
.092 0 0 r
.74933 .4884 m .74931 .4884 L .74857 .48953 L F
.003 0 .452 r
.74889 .48834 m .74932 .48838 L .74914 .48739 L F
.96 .871 .704 r
.74672 .48991 m .74688 .48473 L .74826 .48583 L F
.621 .092 0 r
.74526 .48866 m .74532 .48894 L .74672 .48991 L F
.74331 .487 m .74532 .48894 L .74526 .48866 L F
.94 .572 .208 r
.74672 .48991 m .74532 .48894 L .74331 .487 L F
.96 .871 .704 r
.74677 .48825 m .74532 .48894 L .74688 .48473 L F
.74672 .48991 m .74532 .48894 L .74677 .48825 L F
.003 0 .452 r
.74857 .48953 m .74931 .4884 L .74889 .48834 L F
.092 0 0 r
.74931 .4884 m .74532 .48894 L .74857 .48953 L F
.94 .572 .208 r
.74672 .48991 m .74683 .49143 L .74532 .48894 L F
.566 .659 .9 r
.74683 .49143 m .74857 .48953 L .74532 .48894 L F
.092 0 0 r
.74931 .4884 m .74546 .48956 L .74532 .48894 L F
.74546 .48956 m .74273 .49039 L .74532 .48894 L F
.879 .753 .719 r
.74688 .48473 m .74532 .48894 L .74433 .48473 L F
.864 .687 .661 r
.74557 .48498 m .74932 .48839 L .74822 .48564 L F
.74932 .48839 m .74933 .4884 L .74932 .48837 L F
.74932 .48839 m .74932 .48837 L .74822 .48564 L F
.003 0 .452 r
.74932 .48838 m .74932 .48838 L .74932 .48837 L F
.74932 .48838 m .74932 .48837 L .74914 .48739 L F
.74931 .4884 m .74932 .48838 L .74889 .48834 L F
.74932 .48838 m .74932 .48838 L .74889 .48834 L F
.412 .453 .794 r
.74433 .48473 m .74331 .487 L .74141 .48746 L F
.74433 .48473 m .74532 .48894 L .74331 .487 L F
.738 .276 .153 r
.74532 .48894 m .74141 .48746 L .74331 .487 L F
.74532 .48894 m .74273 .49039 L .74141 .48746 L F
.816 .908 .903 r
.74433 .48473 m .74141 .48746 L .74096 .48597 L F
.81 .323 0 r
.74141 .48746 m .74039 .48786 L .74096 .48597 L F
.74039 .48786 m .7399 .48805 L .74036 .48715 L F
.74039 .48786 m .74036 .48715 L .74096 .48597 L F
.927 .925 .787 r
.74096 .48597 m .74012 .48483 L .74199 .48191 L F
0 0 0 r
.74096 .48597 m .7399 .48805 L .74084 .48698 L F
.74096 .48597 m .74084 .48698 L .74012 .48483 L F
.714 .887 .499 r
.74012 .48483 m .74085 .4829 L .74199 .48191 L F
.933 .925 .777 r
.74051 .48565 m .74085 .4829 L .74023 .48453 L F
.74084 .48698 m .74023 .48453 L .74027 .48528 L F
.74084 .48698 m .74084 .48519 L .74051 .48565 L F
.74084 .48519 m .74085 .4829 L .74051 .48565 L F
.74027 .48528 m .74023 .48453 L .74012 .48483 L F
.74084 .4862 m .73974 .48614 L .74085 .4829 L F
.74084 .48698 m .73974 .48614 L .74084 .4862 L F
.703 .652 .796 r
.74085 .4829 m .73974 .48614 L .7376 .48559 L F
.67 .962 .936 r
.74086 .485 m .73915 .48611 L .73974 .48614 L F
.751 .458 .488 r
.73974 .48614 m .7385 .48653 L .7376 .48559 L F
.67 .962 .936 r
.73915 .48611 m .7385 .48653 L .73974 .48614 L F
.559 .88 .604 r
.74086 .485 m .73974 .48614 L .74095 .48505 L F
.927 .925 .787 r
.74096 .48597 m .74199 .48191 L .74289 .48355 L F
.661 .107 0 r
.74199 .48191 m .74473 .4833 L .74289 .48355 L F
.872 .839 .81 r
.7454 .48378 m .74289 .48355 L .74473 .4833 L F
.661 .107 0 r
.74199 .48191 m .7441 .48375 L .74473 .4833 L F
.329 0 0 r
.74199 .48191 m .74345 .48278 L .7441 .48375 L F
.559 .88 .604 r
.7412 .48471 m .74095 .48505 L .74345 .48278 L F
.74086 .485 m .74095 .48505 L .7412 .48471 L F
.81 .323 0 r
.74141 .48746 m .74273 .49039 L .7399 .48805 L F
.78 .65 .719 r
.7399 .48805 m .74932 .48839 L .74557 .48498 L F
.74932 .48839 m .74933 .4884 L .74932 .48839 L F
.74932 .48839 m .74932 .48839 L .74557 .48498 L F
.003 0 .452 r
.74932 .48838 m .74932 .48838 L .74932 .48838 L F
.092 0 0 r
.74933 .4884 m .74932 .4884 L .74931 .4884 L F
.74932 .4884 m .74273 .49039 L .74931 .4884 L F
.003 0 .452 r
.74857 .48953 m .74941 .48883 L .74932 .48838 L F
.018 0 .463 r
.74933 .4884 m .74914 .48739 L .74932 .48837 L F
.003 0 .452 r
.74941 .48883 m .74956 .4887 L .74914 .48739 L F
.018 0 .463 r
.74932 .48837 m .74914 .48739 L .74907 .48774 L F
0 0 0 r
.74936 .48626 m .74914 .48739 L .74887 .488 L F
.74945 .48597 m .74914 .48739 L .74936 .48626 L F
.74998 .48412 m .74948 .48606 L .74945 .48597 L F
.74948 .48606 m .74914 .48739 L .74945 .48597 L F
.589 .404 .598 r
.74942 .48588 m .74826 .48583 L .74941 .48584 L F
.504 .903 .782 r
.75337 .48466 m .75185 .48588 L .75424 .48596 L F
.75337 .48466 m .75122 .48597 L .75185 .48588 L F
.516 .203 .375 r
.41276 .61508 m .41172 .61771 L .40938 .61788 L F
.553 .24 .392 r
.41463 .61683 m .41276 .61508 L .41506 .61485 L F
.41463 .61683 m .41172 .61771 L .41276 .61508 L F
.711 .541 .658 r
.50531 .71197 m .50846 .71282 L .50906 .70998 L F
.235 .318 .746 r
.57432 .63688 m .57294 .6383 L .57199 .63487 L F
.274 .38 .79 r
.57432 .63688 m .57546 .63998 L .57294 .6383 L F
.994 .774 .493 r
.51954 .68152 m .51823 .68332 L .51834 .68041 L F
.624 .693 .894 r
.52062 .67802 m .51954 .68152 L .51834 .68041 L F
.662 .57 .741 r
.51954 .68152 m .52199 .68158 L .52241 .68008 L F
.555 .461 .703 r
.52241 .68008 m .52445 .67904 L .52505 .68077 L F
.52241 .68008 m .52199 .68158 L .52295 .68059 L F
.688 .449 .556 r
.52483 .68237 m .52295 .68059 L .52505 .68077 L F
.52295 .68059 m .52241 .68008 L .52406 .68051 L F
.52295 .68059 m .52406 .68051 L .52505 .68077 L F
.731 .753 .87 r
.52242 .68063 m .52199 .68158 L .52176 .68099 L F
.555 .461 .703 r
.52241 .68008 m .52295 .68059 L .52445 .67904 L F
.688 .449 .556 r
.52477 .68282 m .52285 .6806 L .52483 .68237 L F
.52285 .6806 m .52241 .68008 L .52295 .68059 L F
.52285 .6806 m .52295 .68059 L .52483 .68237 L F
.537 .31 .517 r
.52241 .68008 m .5223 .6807 L .51954 .68152 L F
.731 .753 .87 r
.52295 .68059 m .52199 .68158 L .52242 .68063 L F
.688 .449 .556 r
.52477 .68282 m .5218 .68346 L .5223 .6807 L F
.52285 .6806 m .5223 .6807 L .52241 .68008 L F
.52477 .68282 m .5223 .6807 L .52285 .6806 L F
.731 .753 .87 r
.52346 .68006 m .52296 .68058 L .52242 .68063 L F
.52296 .68058 m .52295 .68059 L .52285 .6806 L F
.52296 .68058 m .52285 .6806 L .52242 .68063 L F
.52346 .68006 m .52242 .68063 L .52062 .67802 L F
.52242 .68063 m .52176 .68099 L .52165 .68068 L F
.52242 .68063 m .52165 .68068 L .52062 .67802 L F
.52445 .67904 m .52346 .68006 L .52062 .67802 L F
.537 .31 .517 r
.5223 .6807 m .52227 .68087 L .52176 .68099 L F
.5223 .6807 m .52176 .68099 L .51954 .68152 L F
.624 .693 .894 r
.52176 .68099 m .52199 .68158 L .51954 .68152 L F
.537 .31 .517 r
.52227 .68087 m .5218 .68346 L .51954 .68152 L F
.624 .693 .894 r
.52062 .67802 m .52176 .68099 L .51954 .68152 L F
.672 .249 .232 r
.51954 .68152 m .5218 .68346 L .51823 .68332 L F
.994 .774 .493 r
.51954 .68152 m .51823 .68332 L .51834 .68041 L F
.907 .974 .679 r
.55459 .6094 m .55341 .61284 L .55525 .60993 L F
.516 .907 .933 r
.5575 .60921 m .55634 .60901 L .55525 .60993 L F
.503 .883 .97 r
.55525 .60993 m .55634 .60901 L .55459 .6094 L F
.536 .451 .706 r
.55525 .60993 m .55757 .61161 L .5575 .60921 L F
0 0 0 r
.59006 .63801 m .59279 .63497 L .59038 .63543 L F
.517 .497 .774 r
.71654 .48936 m .71917 .48896 L .71786 .48519 L F
.747 .876 .939 r
.68011 .50396 m .68385 .50349 L .68321 .50274 L F
.968 .739 .303 r
.68305 .49975 m .68321 .50274 L .68385 .50349 L F
.014 0 0 r
.4248 .60001 m .42094 .59999 L .42312 .59977 L F
0 .408 .792 r
.42523 .59986 m .4248 .60001 L .42312 .59977 L F
.42523 .59986 m .42654 .60072 L .4248 .60001 L F
.278 0 .101 r
.45144 .68406 m .44867 .68618 L .44822 .68503 L F
.674 .144 0 r
.57546 .63998 m .57844 .64096 L .57656 .64105 L F
.767 .662 .746 r
.52116 .66916 m .5231 .66997 L .52247 .66622 L F
.732 .458 .514 r
.52091 .67069 m .5231 .66997 L .52116 .66916 L F
.52091 .67069 m .52287 .67211 L .5231 .66997 L F
.5231 .66997 m .52287 .67211 L .52091 .67069 L F
.581 .606 .842 r
.5231 .66997 m .52384 .66597 L .52247 .66622 L F
.5231 .66997 m .52529 .66967 L .52384 .66597 L F
.484 .224 .443 r
.52529 .66967 m .52287 .67211 L .5231 .66997 L F
.52529 .66967 m .52287 .67211 L .5231 .66997 L F
.876 .933 .855 r
.79076 .52006 m .79445 .51772 L .79344 .51671 L F
.71 .881 .96 r
.79344 .51671 m .79445 .51772 L .79699 .51652 L F
.016 .149 .66 r
.61054 .64934 m .61209 .65113 L .61117 .65243 L F
0 0 .16 r
.61209 .65113 m .61135 .65414 L .61117 .65243 L F
.385 .783 .986 r
.77363 .52948 m .77591 .52855 L .77292 .52828 L F
.448 .184 .42 r
.45517 .66061 m .45263 .66395 L .45477 .6634 L F
.423 .16 .407 r
.45743 .66065 m .45517 .66061 L .45477 .6634 L F
.907 .974 .679 r
.55459 .6094 m .55315 .61179 L .55341 .61284 L F
.365 .403 .767 r
.55315 .61179 m .55266 .61518 L .55341 .61284 L F
.711 .532 .645 r
.55341 .61284 m .55266 .61518 L .55587 .61514 L F
.514 .311 .542 r
.79909 .49776 m .79921 .50006 L .79673 .50053 L F
.327 .148 .479 r
.79921 .50006 m .79741 .50276 L .79673 .50053 L F
.568 .229 .355 r
.57231 .58119 m .57455 .58275 L .57548 .58037 L F
.271 0 .099 r
.57455 .58275 m .57779 .57998 L .57548 .58037 L F
.477 .11 .263 r
.569 .58361 m .57207 .58249 L .57231 .58119 L F
.589 .208 .288 r
.57207 .58249 m .57455 .58275 L .57231 .58119 L F
.704 .655 .798 r
.79212 .52321 m .79342 .52645 L .79028 .52625 L F
.869 .983 .842 r
.79342 .52645 m .79061 .5284 L .79028 .52625 L F
.79342 .52645 m .79266 .52598 L .79061 .5284 L F
.305 .418 .812 r
.79502 .52502 m .79342 .52645 L .79212 .52321 L F
.572 .912 .972 r
.79502 .52502 m .79266 .52598 L .79342 .52645 L F
.5 .191 .374 r
.3848 .61747 m .38796 .61468 L .38571 .61508 L F
.711 .614 .747 r
.72647 .50827 m .72786 .51181 L .72937 .50958 L F
0 0 .057 r
.72786 .51181 m .72871 .50932 L .72937 .50958 L F
.72786 .51181 m .72848 .51075 L .72871 .50932 L F
.078 .362 .83 r
.72786 .51181 m .7303 .51331 L .72848 .51075 L F
.783 .621 .679 r
.72601 .47743 m .72934 .47797 L .72841 .47473 L F
.668 .232 .204 r
.48136 .70959 m .48417 .71155 L .48382 .71044 L F
.797 .443 .386 r
.48022 .70873 m .48417 .71155 L .48136 .70959 L F
.621 .438 .614 r
.50233 .65915 m .49919 .66059 L .49952 .65873 L F
0 0 0 r
.6104 .66088 m .60933 .66269 L .60807 .66382 L F
.60807 .66382 m .60933 .66269 L .60718 .66544 L F
.60807 .66382 m .60718 .66544 L .60538 .66664 L F
.633 .603 .802 r
.78289 .53115 m .78403 .52727 L .77989 .52839 L F
.78289 .53115 m .78494 .53071 L .78403 .52727 L F
.93 .742 .627 r
.50386 .76588 m .50558 .76732 L .50443 .76383 L F
.944 .603 .344 r
.50386 .76588 m .50558 .76732 L .50561 .76829 L F
.541 .742 .968 r
.50558 .76732 m .50771 .76681 L .50386 .76588 L F
.368 0 0 r
.5092 .77003 m .50558 .76732 L .50771 .76681 L F
.5092 .77003 m .50561 .76829 L .50558 .76732 L F
.546 .025 0 r
.53512 .61531 m .53606 .61641 L .53399 .61435 L F
.803 .311 0 r
.53606 .61641 m .53655 .61807 L .5359 .61639 L F
.546 .025 0 r
.53512 .61531 m .53625 .61643 L .53606 .61641 L F
0 .215 .733 r
.53399 .61435 m .53606 .61641 L .53448 .61311 L F
.803 .311 0 r
.53606 .61641 m .5359 .61639 L .53542 .61516 L F
.546 .025 0 r
.53625 .61643 m .53721 .61737 L .53606 .61641 L F
.532 .853 .997 r
.75715 .51205 m .75465 .51275 L .75385 .5119 L F
.283 .754 .939 r
.37246 .58467 m .37454 .58437 L .37596 .58488 L F
.419 .812 .986 r
.37454 .58437 m .3783 .58461 L .37596 .58488 L F
.277 .39 .798 r
.47941 .6685 m .47827 .66978 L .47698 .6665 L F
.511 .753 .983 r
.47941 .6685 m .47827 .66978 L .48046 .66946 L F
.598 .892 .989 r
.47689 .66911 m .47827 .66978 L .47941 .6685 L F
.511 .753 .983 r
.47941 .6685 m .47827 .66978 L .48046 .66946 L F
.265 .064 .409 r
.43168 .68973 m .42977 .69267 L .4314 .69212 L F
.513 .42 .687 r
.42977 .69267 m .4324 .69535 L .4314 .69212 L F
.42977 .69267 m .42982 .69635 L .4324 .69535 L F
.559 .757 .97 r
.7938 .48636 m .7913 .48837 L .78954 .48604 L F
.7938 .48636 m .79403 .48751 L .7913 .48837 L F
.654 .665 .848 r
.79434 .48892 m .7913 .48837 L .79403 .48751 L F
.764 .428 .416 r
.50424 .65159 m .50662 .65428 L .50637 .65141 L F
.50424 .65159 m .50266 .65435 L .50662 .65428 L F
.277 .718 .963 r
.35347 .5828 m .35706 .5835 L .35495 .58383 L F
.58 .51 .741 r
.80066 .49531 m .79909 .49776 L .79859 .49565 L F
.80066 .49531 m .80177 .49731 L .79909 .49776 L F
.441 .202 .454 r
.80177 .49731 m .79921 .50006 L .79909 .49776 L F
.401 .171 .446 r
.29832 .59589 m .2997 .5972 L .30041 .5952 L F
.29832 .59589 m .29784 .59782 L .2997 .5972 L F
.488 .429 .717 r
.55258 .59888 m .55256 .60178 L .55466 .6001 L F
0 0 0 r
.55256 .60178 m .55212 .60272 L .55466 .6001 L F
.458 .665 .951 r
.29686 .63286 m .29897 .63275 L .2974 .63092 L F
.54 .455 .708 r
.42982 .69635 m .4331 .69554 L .4324 .69535 L F
.42982 .69635 m .43069 .69799 L .4331 .69554 L F
.209 0 0 r
.51869 .66179 m .51694 .6631 L .51813 .66153 L F
.39 0 .024 r
.52112 .66131 m .51869 .66179 L .51813 .66153 L F
.664 .692 .866 r
.73086 .48604 m .73451 .48697 L .73361 .48579 L F
.877 .904 .846 r
.73361 .48579 m .73451 .48697 L .73598 .48518 L F
.179 0 0 r
.36801 .62548 m .37191 .62361 L .36988 .6244 L F
.498 .247 .464 r
.47812 .65552 m .47764 .65885 L .47542 .65776 L F
.441 .198 .448 r
.48057 .65718 m .47812 .65552 L .48037 .65508 L F
.48057 .65718 m .47764 .65885 L .47812 .65552 L F
.382 .025 .229 r
.33811 .60383 m .33492 .60606 L .33543 .60389 L F
.421 .719 .986 r
.39216 .58534 m .3914 .58667 L .38994 .58582 L F
.39216 .58534 m .39357 .58655 L .3914 .58667 L F
.648 .548 .728 r
.47764 .65885 m .47473 .66035 L .47542 .65776 L F
.35 .144 .453 r
.4581 .69813 m .45974 .69815 L .45999 .69598 L F
.731 .683 .804 r
.4564 .69476 m .4581 .69813 L .45999 .69598 L F
.629 .621 .824 r
.39256 .59477 m .39399 .59757 L .39648 .5967 L F
.664 .139 0 r
.55848 .61988 m .56189 .62078 L .55942 .61928 L F
.999 .808 .469 r
.55879 .61751 m .55848 .61988 L .55942 .61928 L F
.483 .719 .975 r
.78615 .48494 m .78463 .48647 L .78376 .48507 L F
.78615 .48494 m .78703 .48629 L .78463 .48647 L F
.387 .295 .628 r
.49035 .64658 m .49064 .64908 L .48896 .64927 L F
.291 0 0 r
.49064 .64908 m .48721 .65055 L .48896 .64927 L F
.145 0 .345 r
.21382 .57632 m .21257 .57514 L .21404 .57402 L F
.21382 .57632 m .21205 .57739 L .21257 .57514 L F
.965 .837 .666 r
.53488 .70845 m .53316 .71034 L .53497 .70897 L F
.867 .615 .555 r
.53488 .70845 m .53481 .7087 L .53456 .70895 L F
.53488 .70845 m .53456 .70895 L .5344 .70898 L F
.967 .894 .702 r
.53467 .70896 m .53316 .71034 L .53456 .70895 L F
.53497 .70897 m .53443 .70938 L .53467 .70896 L F
.53443 .70938 m .53316 .71034 L .53467 .70896 L F
.458 .199 .433 r
.53498 .70884 m .53475 .70892 L .53481 .7087 L F
.53493 .70849 m .53481 .7087 L .53488 .70845 L F
.867 .615 .555 r
.53456 .70895 m .53395 .71185 L .53316 .71034 L F
.53481 .7087 m .53475 .70892 L .53456 .70895 L F
.53475 .70892 m .53395 .71185 L .53456 .70895 L F
.487 .898 .913 r
.53502 .70882 m .53264 .70888 L .53527 .7081 L F
.606 .608 .828 r
.53652 .70717 m .53488 .70845 L .53497 .70897 L F
.487 .898 .913 r
.535 .70889 m .53485 .70889 L .53502 .70882 L F
.53485 .70889 m .53264 .70888 L .53502 .70882 L F
.458 .199 .433 r
.53706 .71041 m .53395 .71185 L .53475 .70892 L F
.487 .898 .913 r
.53497 .70897 m .53456 .70895 L .535 .70889 L F
.458 .199 .433 r
.53706 .71041 m .53475 .70892 L .53498 .70884 L F
.487 .898 .913 r
.53564 .70819 m .53564 .70819 L .53652 .70717 L F
.606 .608 .828 r
.53652 .70717 m .53732 .70949 L .53527 .70861 L F
.53652 .70717 m .53527 .70861 L .53488 .70845 L F
.487 .898 .913 r
.53564 .70819 m .53527 .7081 L .53652 .70717 L F
.458 .199 .433 r
.53706 .71041 m .53515 .70869 L .53732 .70949 L F
.53515 .70869 m .53488 .70845 L .53527 .70861 L F
.53515 .70869 m .53527 .70861 L .53732 .70949 L F
.487 .898 .913 r
.53497 .70897 m .53502 .70882 L .53515 .70869 L F
.53528 .70861 m .53515 .70869 L .53564 .70819 L F
.53497 .70897 m .53515 .70869 L .53528 .70861 L F
.53502 .70882 m .53527 .7081 L .53564 .70819 L F
.458 .199 .433 r
.53515 .70869 m .53481 .7087 L .53493 .70849 L F
.53706 .71041 m .535 .70885 L .53515 .70869 L F
.535 .70885 m .53481 .7087 L .53515 .70869 L F
.487 .898 .913 r
.53456 .70895 m .53264 .70888 L .535 .70889 L F
.867 .615 .555 r
.5344 .70898 m .53456 .70895 L .53316 .71034 L F
.967 .894 .702 r
.53456 .70895 m .53316 .71034 L .53264 .70888 L F
0 .111 .664 r
.45221 .69782 m .45164 .69843 L .45105 .69627 L F
.45221 .69782 m .45355 .70061 L .45164 .69843 L F
.713 .754 .884 r
.4631 .68638 m .46391 .68812 L .46686 .68687 L F
.517 .51 .787 r
.80302 .5049 m .80088 .50724 L .80068 .50507 L F
.453 .354 .652 r
.80302 .5049 m .80088 .50905 L .80088 .50724 L F
.015 .583 .783 r
.5449 .64682 m .54395 .64663 L .54134 .64643 L F
.5449 .64682 m .54395 .64663 L .54134 .64643 L F
.943 .949 .751 r
.54584 .64307 m .5449 .64682 L .54608 .64568 L F
.54584 .64307 m .54395 .64663 L .5449 .64682 L F
.54 .917 .937 r
.5449 .64682 m .54395 .64663 L .54608 .64568 L F
.775 .718 .799 r
.54625 .66987 m .54991 .66976 L .54883 .67013 L F
0 0 .36 r
.55116 .66657 m .55111 .66932 L .54991 .66976 L F
.268 0 .033 r
.55111 .66932 m .54883 .67013 L .54991 .66976 L F
.637 .548 .737 r
.54993 .67265 m .55116 .67549 L .55309 .67381 L F
.406 .579 .909 r
.79575 .48723 m .79434 .48892 L .79403 .48751 L F
.79575 .48723 m .79618 .48898 L .79434 .48892 L F
.513 .453 .727 r
.79719 .49025 m .79434 .48892 L .79618 .48898 L F
.698 .178 0 r
.50024 .61989 m .50187 .62099 L .50341 .62109 L F
.818 .381 .2 r
.50187 .62099 m .50227 .62226 L .50341 .62109 L F
.718 .242 .117 r
.50227 .62226 m .50564 .62314 L .50341 .62109 L F
.507 .312 .55 r
.30169 .64107 m .3035 .63856 L .30037 .63785 L F
.30169 .64107 m .30384 .6406 L .3035 .63856 L F
.819 .619 .633 r
.50315 .71321 m .50049 .71464 L .50272 .71097 L F
.064 .619 .816 r
.5803 .66093 m .58331 .66108 L .58398 .6613 L F
.879 .99 .739 r
.58398 .6613 m .58331 .66108 L .58456 .65907 L F
.474 .134 .308 r
.39414 .62654 m .39315 .62901 L .39078 .62928 L F
.366 .013 .227 r
.39636 .62609 m .39315 .62901 L .39414 .62654 L F
.532 .335 .559 r
.49278 .64593 m .4906 .64376 L .49296 .64425 L F
.49278 .64593 m .49035 .64658 L .4906 .64376 L F
.79 .77 .835 r
.4634 .70301 m .46477 .7049 L .46142 .7041 L F
.808 .75 .799 r
.46477 .7049 m .46236 .70698 L .46142 .7041 L F
.499 .34 .596 r
.46667 .70185 m .46477 .7049 L .4634 .70301 L F
.375 0 .076 r
.46477 .7049 m .4671 .70483 L .4664 .70593 L F
.602 .927 .965 r
.29925 .62971 m .29948 .62847 L .3012 .62861 L F
.503 .332 .582 r
.2974 .63092 m .29948 .62847 L .29925 .62971 L F
.509 .14 .275 r
.46438 .67731 m .4638 .67605 L .46652 .67722 L F
.89 .463 .105 r
.5475 .64295 m .54916 .64633 L .55048 .64707 L F
0 .094 .578 r
.54916 .64633 m .55167 .64855 L .55048 .64707 L F
.576 .564 .803 r
.5116 .77253 m .5092 .77003 L .51135 .7723 L F
.845 .733 .74 r
.50895 .77296 m .5116 .77253 L .51135 .7723 L F
.50895 .77296 m .51023 .77577 L .5116 .77253 L F
.373 0 0 r
.45991 .7125 m .46347 .71338 L .46309 .7137 L F
.516 0 0 r
.46347 .71338 m .46428 .71466 L .46309 .7137 L F
.46347 .71338 m .46585 .71458 L .46428 .71466 L F
.374 .439 .8 r
.76869 .52429 m .77149 .52513 L .77224 .52439 L F
.515 .267 .476 r
.44728 .6688 m .44981 .66632 L .4477 .66688 L F
.463 .775 .997 r
.76183 .51045 m .76035 .51164 L .7594 .51075 L F
.76183 .51045 m .7628 .51142 L .76035 .51164 L F
.533 .464 .724 r
.77655 .50371 m .77695 .50603 L .77939 .50548 L F
.55 .435 .675 r
.77757 .50857 m .77939 .50548 L .77695 .50603 L F
.522 .559 .834 r
.40032 .60173 m .4019 .59983 L .39969 .60068 L F
.40032 .60173 m .40343 .60316 L .4019 .59983 L F
.637 .548 .737 r
.54993 .67265 m .55309 .67381 L .55385 .67405 L F
.429 .861 .931 r
.76173 .52425 m .76311 .52431 L .76536 .52363 L F
.86 .617 .57 r
.60906 .58335 m .60884 .58582 L .6122 .58658 L F
.836 .631 .626 r
.60884 .58582 m .6122 .58897 L .6122 .58658 L F
.287 .549 .923 r
.44388 .70825 m .44572 .70743 L .44294 .70682 L F
.44388 .70825 m .44818 .70948 L .44572 .70743 L F
.008 0 .489 r
.61056 .64352 m .61152 .64573 L .61019 .64688 L F
.2 .137 .557 r
.61246 .64774 m .61019 .64688 L .61152 .64573 L F
.61246 .64774 m .61054 .64934 L .61019 .64688 L F
.575 .33 .508 r
.46506 .65482 m .46781 .65223 L .4655 .65285 L F
.803 .684 .734 r
.47148 .67274 m .47048 .66834 L .47263 .67008 L F
.47148 .67274 m .46897 .67001 L .47048 .66834 L F
.47148 .67274 m .47022 .67279 L .46897 .67001 L F
.898 .822 .763 r
.73547 .48257 m .73361 .48579 L .73598 .48518 L F
.433 .01 .134 r
.50689 .65795 m .50173 .66058 L .50233 .65915 L F
.50689 .65795 m .50444 .6603 L .50173 .66058 L F
.207 0 0 r
.50677 .65957 m .50689 .65795 L .50739 .6573 L F
.50677 .65957 m .50444 .6603 L .50689 .65795 L F
.583 .549 .782 r
.80077 .4931 m .79859 .49565 L .79732 .4923 L F
.80077 .4931 m .80066 .49531 L .79859 .49565 L F
.309 0 0 r
.50821 .62458 m .50696 .62397 L .50564 .62314 L F
.50821 .62458 m .50975 .62522 L .50696 .62397 L F
.278 0 .101 r
.45144 .68406 m .45049 .68598 L .44867 .68618 L F
.494 .168 .344 r
.45432 .6832 m .45049 .68598 L .45144 .68406 L F
.219 .303 .737 r
.34696 .62268 m .34818 .62668 L .34682 .62605 L F
.404 0 .12 r
.58896 .58577 m .5875 .58788 L .5853 .58703 L F
.56 .117 .154 r
.58896 .58577 m .58983 .58778 L .5875 .58788 L F
.58896 .58577 m .59124 .58613 L .58983 .58778 L F
0 0 .163 r
.73655 .50945 m .73727 .50883 L .73778 .50564 L F
.496 .827 .53 r
.73582 .51169 m .73599 .51151 L .7374 .51018 L F
.589 .54 .767 r
.73655 .50945 m .73743 .5102 L .73742 .51019 L F
.73743 .5102 m .73969 .51212 L .73742 .51019 L F
.73655 .50945 m .7383 .51095 L .73727 .50883 L F
.496 .827 .53 r
.7374 .51018 m .7374 .51018 L .73757 .51002 L F
.73582 .51169 m .7374 .51018 L .7374 .51018 L F
.645 .814 .964 r
.73969 .51213 m .73582 .51169 L .7383 .51095 L F
.425 .056 .232 r
.73647 .51227 m .73863 .51123 L .7383 .51095 L F
.589 .54 .767 r
.73767 .51041 m .73969 .51212 L .7383 .51095 L F
.425 .056 .232 r
.73863 .51123 m .74069 .51024 L .7383 .51095 L F
.589 .54 .767 r
.73742 .51019 m .73767 .51041 L .7383 .51095 L F
.73969 .51212 m .73969 .51213 L .7383 .51095 L F
.496 .827 .53 r
.73582 .51169 m .7374 .51018 L .7383 .51095 L F
.7374 .51018 m .73757 .51002 L .7383 .51095 L F
.089 0 0 r
.5596 .60637 m .55634 .60901 L .5575 .60921 L F
.614 .499 .699 r
.5575 .60921 m .55984 .60935 L .5596 .60637 L F
.572 .35 .541 r
.55757 .61161 m .55984 .60935 L .5575 .60921 L F
.773 .681 .762 r
.71917 .48896 m .72283 .49155 L .72147 .48793 L F
.71917 .48896 m .72038 .49212 L .72283 .49155 L F
.73 .696 .818 r
.72147 .48793 m .72283 .49155 L .72486 .4885 L F
.743 .763 .868 r
.72283 .49155 m .72712 .48995 L .72486 .4885 L F
.78 .56 .601 r
.53054 .66936 m .52883 .66612 L .53057 .66713 L F
.53054 .66936 m .52789 .66929 L .52883 .66612 L F
.037 0 .413 r
.61249 .63932 m .611 .63799 L .61236 .63689 L F
.61249 .63932 m .611 .64043 L .611 .63799 L F
.368 0 0 r
.5092 .77003 m .50772 .76938 L .50561 .76829 L F
.972 .712 .482 r
.50771 .76681 m .50772 .76938 L .5092 .77003 L F
.609 .575 .79 r
.50772 .76938 m .51135 .7723 L .5092 .77003 L F
.439 .309 .606 r
.43303 .68109 m .43507 .68306 L .43483 .68055 L F
.43303 .68109 m .43322 .6837 L .43507 .68306 L F
.539 .606 .868 r
.29899 .61523 m .29935 .61157 L .29766 .6119 L F
.29899 .61523 m .30095 .61469 L .29935 .61157 L F
.431 .438 .765 r
.29899 .61523 m .30186 .6174 L .30095 .61469 L F
.303 0 .045 r
.37949 .61958 m .38251 .61797 L .38044 .61856 L F
.233 0 .228 r
.47274 .64651 m .47491 .64586 L .47539 .6438 L F
.028 0 .107 r
.47539 .6438 m .47713 .64298 L .47775 .64094 L F
.256 0 .236 r
.47539 .6438 m .47676 .64517 L .47713 .64298 L F
.47539 .6438 m .47491 .64586 L .47676 .64517 L F
.499 .223 .426 r
.40713 .61817 m .40669 .6201 L .40467 .62016 L F
.45 .179 .409 r
.40891 .61945 m .40713 .61817 L .40938 .61788 L F
.40891 .61945 m .40669 .6201 L .40713 .61817 L F
.544 .461 .712 r
.77655 .50371 m .77939 .50548 L .77874 .50317 L F
.433 .342 .653 r
.29408 .60667 m .29592 .60632 L .29586 .60254 L F
.581 .54 .773 r
.29433 .60904 m .29592 .60632 L .29408 .60667 L F
.77 .674 .756 r
.58386 .64911 m .58491 .65251 L .58137 .65211 L F
.691 .252 .204 r
.58491 .65251 m .58374 .65409 L .58137 .65211 L F
.286 .001 .293 r
.58491 .65251 m .58664 .65185 L .58768 .64988 L F
.981 .703 .321 r
.58491 .65251 m .58382 .65164 L .58386 .64911 L F
1 .808 .482 r
.58491 .65251 m .58374 .65409 L .58382 .65164 L F
.971 .754 .323 r
.58665 .6545 m .58664 .65185 L .58491 .65251 L F
.981 .703 .321 r
.58386 .64911 m .58382 .65164 L .58491 .65251 L F
.225 .738 .873 r
.58411 .64076 m .58642 .64075 L .5824 .64104 L F
.602 .334 .482 r
.58642 .64075 m .58476 .64303 L .5824 .64104 L F
.393 .352 .694 r
.5824 .64104 m .58476 .64303 L .58411 .64076 L F
.586 .338 .508 r
.5824 .64104 m .58476 .64303 L .58247 .64348 L F
.5824 .64104 m .58476 .64303 L .58247 .64348 L F
.45 .335 .631 r
.52512 .65759 m .52272 .65531 L .52559 .65542 L F
.52512 .65759 m .52322 .65829 L .52272 .65531 L F
.39 .168 .453 r
.66282 .48916 m .66264 .49128 L .66492 .48834 L F
.825 .599 .596 r
.60735 .58286 m .60916 .58097 L .60746 .58061 L F
.60735 .58286 m .60906 .58335 L .60916 .58097 L F
.035 0 0 r
.33008 .5832 m .33229 .58296 L .33364 .58257 L F
.879 .847 .808 r
.60103 .60113 m .59751 .60303 L .59924 .6 L F
.60103 .60113 m .59864 .60415 L .59751 .60303 L F
.415 .48 .819 r
.51173 .65844 m .5145 .66071 L .51357 .65777 L F
.023 .556 .852 r
.54551 .62422 m .54732 .62409 L .54457 .62281 L F
.54551 .62422 m .5494 .62488 L .54732 .62409 L F
.4 .025 .207 r
.30531 .5916 m .30755 .59115 L .30827 .58975 L F
.48 .155 .337 r
.30755 .59115 m .31053 .58916 L .30827 .58975 L F
.705 .921 .966 r
.30996 .64002 m .30792 .64148 L .30822 .63962 L F
0 0 0 r
.30792 .64148 m .308 .64208 L .30822 .63962 L F
.457 .203 .439 r
.30996 .64002 m .30691 .64324 L .30792 .64148 L F
0 0 0 r
.30792 .64148 m .30691 .64324 L .308 .64208 L F
.935 .965 .681 r
.60121 .61547 m .5999 .61779 L .59959 .61684 L F
.96 .727 .54 r
.60121 .61547 m .59959 .61684 L .59975 .61444 L F
.733 .574 .675 r
.21835 .56074 m .21472 .55788 L .21696 .55737 L F
.21835 .56074 m .21501 .56124 L .21472 .55788 L F
.158 0 .099 r
.21634 .56128 m .21501 .56124 L .21835 .56074 L F
.56 .611 .86 r
.21875 .55708 m .21835 .56074 L .21696 .55737 L F
.21875 .55708 m .22081 .56122 L .21835 .56074 L F
0 .363 .792 r
.21835 .56074 m .21925 .5607 L .21634 .56128 L F
.21835 .56074 m .22041 .56161 L .21925 .5607 L F
.053 0 .45 r
.61419 .6307 m .61255 .62956 L .61398 .62822 L F
.61419 .6307 m .61264 .63202 L .61255 .62956 L F
.927 .768 .665 r
.53002 .6754 m .52811 .67503 L .52888 .67207 L F
.909 .509 .114 r
.53009 .678 m .53002 .6754 L .5277 .67823 L F
.583 .39 .585 r
.53002 .6754 m .53009 .678 L .5277 .67823 L F
.712 .62 .753 r
.52517 .67166 m .52676 .67346 L .5229 .67468 L F
.52676 .67346 m .52847 .67539 L .52572 .67504 L F
.52676 .67346 m .52572 .67504 L .5229 .67468 L F
.64 .149 0 r
.52811 .67503 m .52847 .67539 L .52676 .67346 L F
.52681 .67354 m .52676 .67346 L .52517 .67166 L F
.52811 .67503 m .52676 .67346 L .52681 .67354 L F
.128 0 0 r
.52847 .67539 m .5227 .67678 L .5229 .67468 L F
.52847 .67539 m .52564 .6764 L .5227 .67678 L F
.52543 .67643 m .52515 .67657 L .523 .67676 L F
.52564 .6764 m .523 .67676 L .5227 .67678 L F
.381 .496 .851 r
.52515 .67657 m .52445 .67904 L .5227 .67678 L F
.561 .894 .984 r
.5227 .67678 m .52227 .67586 L .5229 .67468 L F
.73 .259 .13 r
.52227 .67586 m .52369 .67733 L .52515 .67657 L F
.52369 .67733 m .52417 .67783 L .52515 .67657 L F
.128 0 0 r
.52564 .6764 m .52515 .67657 L .52543 .67643 L F
.909 .509 .114 r
.53009 .678 m .52879 .67604 L .53002 .6754 L F
.52879 .67604 m .52811 .67503 L .52901 .6752 L F
.52879 .67604 m .52901 .6752 L .53002 .6754 L F
.492 0 0 r
.52878 .67605 m .52515 .67657 L .52847 .67539 L F
.46 .057 .188 r
.53009 .678 m .52935 .67935 L .5277 .67823 L F
.5277 .67823 m .52935 .67935 L .53009 .678 L F
.53009 .678 m .52935 .67935 L .5277 .67823 L F
.492 0 0 r
.52988 .67832 m .52834 .67775 L .52878 .67605 L F
.52834 .67775 m .52515 .67657 L .52878 .67605 L F
.52988 .67832 m .52847 .67539 L .52811 .67503 L F
.909 .509 .114 r
.53009 .678 m .52988 .67832 L .52811 .67503 L F
.629 .254 .313 r
.52611 .67613 m .52659 .67627 L .53014 .67391 L F
.52659 .67627 m .52945 .67707 L .52972 .67584 L F
.52659 .67627 m .52972 .67584 L .53014 .67391 L F
.016 0 .2 r
.52603 .67515 m .52611 .67613 L .52699 .67383 L F
.64 .149 0 r
.52811 .67503 m .52681 .67354 L .52888 .67207 L F
.52681 .67354 m .52517 .67166 L .52758 .67193 L F
.52681 .67354 m .52758 .67193 L .52888 .67207 L F
.016 0 .2 r
.52685 .67361 m .52699 .67383 L .52764 .67212 L F
.52603 .67515 m .52699 .67383 L .52685 .67361 L F
.52759 .67219 m .52764 .67212 L .52767 .67205 L F
.52603 .67515 m .52764 .67212 L .52759 .67219 L F
.565 .3 .474 r
.53318 .67526 m .53009 .678 L .53002 .6754 L F
.653 .302 .365 r
.53602 .59906 m .53948 .59706 L .53738 .59838 L F
.647 .566 .75 r
.42495 .70346 m .42589 .70413 L .42487 .70086 L F
.724 .719 .192 r
.48441 .66854 m .48418 .66981 L .48486 .66679 L F
.808 .991 .742 r
.48265 .67055 m .48418 .66981 L .48441 .66854 L F
.948 .919 .748 r
.59864 .60415 m .59766 .60655 L .59661 .60549 L F
.867 .653 .122 r
.59712 .60898 m .59661 .60549 L .59766 .60655 L F
.595 .627 .853 r
.41467 .59109 m .41393 .59472 L .41261 .59146 L F
.41467 .59109 m .41634 .59416 L .41393 .59472 L F
.83 .66 .672 r
.6122 .58897 m .61357 .59195 L .61403 .58979 L F
.405 0 .11 r
.5853 .58703 m .5875 .58788 L .5841 .58884 L F
.518 .212 .388 r
.52376 .65227 m .52666 .65182 L .52848 .64807 L F
.564 .871 .995 r
.34232 .64528 m .34159 .64662 L .3434 .64571 L F
.34232 .64528 m .34019 .646 L .34159 .64662 L F
.26 .682 .965 r
.77316 .49117 m .76988 .4902 L .77089 .49155 L F
.352 0 0 r
.46324 .66824 m .46539 .66798 L .46317 .66796 L F
.46324 .66824 m .46574 .66759 L .46539 .66798 L F
.231 .718 .926 r
.3361 .58203 m .33817 .58195 L .33977 .58245 L F
.198 .693 .918 r
.33817 .58195 m .34185 .5825 L .33977 .58245 L F
.72 .708 .838 r
.72486 .4885 m .72712 .48995 L .72852 .48914 L F
.768 .647 .728 r
.72373 .48281 m .7259 .47978 L .72432 .48048 L F
.105 0 .192 r
.47775 .64094 m .47962 .64024 L .48006 .63804 L F
.224 0 .185 r
.47775 .64094 m .47904 .64224 L .47962 .64024 L F
.47775 .64094 m .47713 .64298 L .47904 .64224 L F
.971 .711 .48 r
.59636 .5923 m .59502 .59377 L .5948 .59145 L F
.59636 .5923 m .59643 .59459 L .59502 .59377 L F
.44 .601 .913 r
.46574 .66759 m .46317 .66796 L .46539 .66798 L F
.597 .558 .782 r
.21696 .55737 m .21472 .55788 L .21367 .55438 L F
.431 .14 .368 r
.58299 .57766 m .58518 .57707 L .58575 .57451 L F
.523 .242 .43 r
.58518 .57707 m .58818 .57414 L .58575 .57451 L F
.567 .373 .577 r
.46539 .66798 m .46823 .66662 L .46574 .66759 L F
.548 .87 .994 r
.76645 .51128 m .7628 .51142 L .76538 .51055 L F
.376 .022 .232 r
.57779 .57998 m .58012 .5795 L .58055 .57812 L F
.428 .069 .251 r
.58012 .5795 m .5825 .57914 L .58055 .57812 L F
.427 .071 .257 r
.58055 .57812 m .5825 .57914 L .58299 .57766 L F
.613 .392 .557 r
.49144 .68975 m .49417 .69219 L .49429 .68952 L F
.49144 .68975 m .49417 .69219 L .49429 .68952 L F
.476 .639 .928 r
.7303 .51331 m .7309 .51508 L .73246 .51325 L F
.539 .737 .967 r
.7309 .51508 m .73339 .51505 L .73246 .51325 L F
.742 .993 .849 r
.72937 .50958 m .73127 .50721 L .73185 .50912 L F
.476 .673 .951 r
.51149 .62537 m .51036 .62688 L .50975 .62522 L F
.741 .221 0 r
.51036 .62688 m .51245 .629 L .51411 .62952 L F
.988 .759 .5 r
.51149 .62537 m .51245 .629 L .51036 .62688 L F
.369 .112 .386 r
.47036 .64901 m .47244 .64898 L .47274 .64651 L F
.428 .211 .481 r
.46964 .65091 m .47244 .64898 L .47036 .64901 L F
.958 .749 .578 r
.61679 .6094 m .6158 .6061 L .61564 .60844 L F
.968 .714 .496 r
.61578 .61141 m .61679 .6094 L .61564 .60844 L F
.61578 .61141 m .61671 .61192 L .61679 .6094 L F
.554 .355 .565 r
.51357 .65777 m .5163 .65467 L .51394 .65546 L F
.616 .548 .755 r
.66038 .49402 m .66264 .49128 L .6603 .49183 L F
.295 0 0 r
.32452 .58406 m .32598 .58455 L .32778 .58304 L F
.264 0 0 r
.32598 .58455 m .33008 .5832 L .32778 .58304 L F
.609 .514 .721 r
.42589 .70413 m .42781 .69998 L .42487 .70086 L F
.42589 .70413 m .4285 .70307 L .42781 .69998 L F
.125 0 0 r
.37408 .63641 m .37752 .63456 L .3764 .63585 L F
.178 0 0 r
.37752 .63456 m .37876 .63515 L .3764 .63585 L F
.37752 .63456 m .37982 .63411 L .37876 .63515 L F
.474 .291 .552 r
.43452 .67557 m .43697 .67521 L .43678 .67241 L F
.556 .412 .64 r
.43452 .67557 m .43705 .6776 L .43697 .67521 L F
.43452 .67557 m .43477 .67805 L .43705 .6776 L F
.171 .348 .799 r
.51079 .64351 m .50927 .64047 L .51121 .64107 L F
.744 .653 .759 r
.71416 .48001 m .71771 .48063 L .71651 .47713 L F
.681 .135 0 r
.51245 .629 m .51619 .63184 L .51411 .62952 L F
.517 .217 .396 r
.42025 .61237 m .41741 .61452 L .41766 .61238 L F
.36 .395 .762 r
.74425 .48061 m .74474 .47532 L .74294 .47666 L F
.74425 .48061 m .74549 .48048 L .74474 .47532 L F
.973 .778 .581 r
.68437 .49651 m .68639 .49445 L .68379 .49402 L F
.68437 .49651 m .68566 .49759 L .68639 .49445 L F
.995 .76 .455 r
.46677 .70874 m .46796 .7074 L .4664 .70593 L F
.637 .164 .113 r
.46677 .70874 m .47037 .70902 L .46796 .7074 L F
.905 .931 .556 r
.61644 .61821 m .61517 .61965 L .6156 .61994 L F
.939 .839 .398 r
.61644 .61821 m .61664 .61383 L .61603 .61381 L F
.988 .878 .534 r
.61603 .61381 m .61517 .61965 L .61644 .61821 L F
.617 .744 .937 r
.4827 .66496 m .48486 .66679 L .48219 .66647 L F
.037 0 0 r
.48486 .66679 m .48046 .66946 L .48219 .66647 L F
.313 .62 .958 r
.48529 .66598 m .48486 .66679 L .4827 .66496 L F
.724 .719 .192 r
.48441 .66854 m .48486 .66679 L .48529 .66598 L F
.355 .636 .96 r
.20121 .54656 m .20053 .54788 L .19889 .54647 L F
.20121 .54656 m .20265 .54807 L .20053 .54788 L F
.158 0 0 r
.3882 .63103 m .38859 .6302 L .39078 .62928 L F
.425 .157 .401 r
.47274 .64651 m .47475 .64827 L .47491 .64586 L F
.47274 .64651 m .47244 .64898 L .47475 .64827 L F
.548 .626 .881 r
.73086 .50112 m .73235 .4985 L .72994 .49895 L F
.73086 .50112 m .73376 .50094 L .73235 .4985 L F
.73086 .50112 m .73235 .4985 L .72994 .49895 L F
.73086 .50112 m .73376 .50094 L .73235 .4985 L F
.3 .741 .965 r
.77117 .5116 m .77217 .51234 L .76862 .51172 L F
.005 .52 .858 r
.77467 .51284 m .77217 .51234 L .77117 .5116 L F
.694 .359 .404 r
.48922 .70979 m .49137 .71215 L .49292 .70973 L F
.717 .387 .418 r
.49292 .70973 m .49137 .71215 L .49503 .71227 L F
.616 .548 .755 r
.66038 .49402 m .66599 .49542 L .66264 .49128 L F
.591 .465 .677 r
.66038 .49402 m .66405 .49726 L .66599 .49542 L F
.66038 .49402 m .6618 .49873 L .66405 .49726 L F
.412 0 0 r
.55318 .65807 m .5531 .65814 L .54964 .65632 L F
.506 .824 .513 r
.55435 .6569 m .5531 .65814 L .55318 .65807 L F
0 0 0 r
.55318 .65807 m .55204 .65981 L .55435 .6569 L F
0 .039 .608 r
.73339 .51505 m .73451 .51765 L .73431 .51627 L F
.156 .4 .845 r
.73451 .51765 m .73581 .51647 L .73431 .51627 L F
.73451 .51765 m .73719 .51929 L .73581 .51647 L F
.848 .939 .883 r
.5484 .64051 m .5475 .64295 L .54956 .64146 L F
.599 .85 .992 r
.55207 .64065 m .54956 .64146 L .5484 .64051 L F
.5484 .64051 m .54956 .64146 L .55207 .64065 L F
.55207 .64065 m .54956 .64146 L .5484 .64051 L F
.504 .479 .763 r
.33273 .61142 m .33171 .61531 L .33085 .61186 L F
.33273 .61142 m .33376 .61493 L .33171 .61531 L F
.582 .569 .804 r
.33523 .61829 m .33171 .61531 L .33376 .61493 L F
.204 0 .266 r
.48241 .6352 m .48006 .63804 L .48153 .63698 L F
.153 0 .209 r
.48006 .63804 m .48123 .63936 L .48153 .63698 L F
.48006 .63804 m .47962 .64024 L .48123 .63936 L F
.289 0 0 r
.58956 .67516 m .58802 .67612 L .58615 .67581 L F
.389 .841 .751 r
.59108 .67439 m .59115 .67427 L .58956 .67516 L F
0 0 0 r
.59115 .67427 m .58802 .67612 L .58956 .67516 L F
.581 .54 .773 r
.29433 .60904 m .29684 .60876 L .29592 .60632 L F
.919 .588 .4 r
.60179 .57218 m .60226 .57438 L .60387 .57494 L F
.882 .715 .669 r
.60226 .57438 m .60376 .57762 L .60387 .57494 L F
.637 .856 .983 r
.43006 .70366 m .43164 .70469 L .43395 .70363 L F
.592 .47 .682 r
.4314 .69212 m .43372 .68919 L .43168 .68973 L F
.777 .804 .875 r
.66248 .50549 m .66627 .50437 L .66527 .50287 L F
.699 .751 .892 r
.66527 .50287 m .66627 .50437 L .66872 .50349 L F
.72 .383 .408 r
.47037 .70902 m .47395 .70907 L .47358 .70748 L F
.563 .494 .735 r
.53985 .70688 m .54157 .70334 L .54231 .70412 L F
.498 .27 .499 r
.54231 .70412 m .54213 .70641 L .53985 .70688 L F
.483 .258 .496 r
.54231 .70412 m .54469 .70369 L .54213 .70641 L F
.566 .719 .944 r
.74755 .52613 m .74894 .52795 L .75104 .52742 L F
.58 .59 .828 r
.47374 .69735 m .4728 .70137 L .47182 .70011 L F
.47374 .69735 m .47589 .70132 L .4728 .70137 L F
.587 .437 .645 r
.4728 .70137 m .47589 .70132 L .4731 .70275 L F
.307 .255 .634 r
.47374 .69735 m .47427 .69818 L .47589 .70132 L F
.691 .7 .854 r
.47336 .70174 m .47589 .70132 L .4745 .69862 L F
.47336 .70174 m .4745 .69862 L .47421 .69843 L F
.47393 .70233 m .47415 .70221 L .47361 .70189 L F
.47393 .70233 m .47361 .70189 L .47357 .70196 L F
.47415 .70221 m .47347 .70173 L .47336 .70174 L F
.4731 .70275 m .47393 .70233 L .47336 .70174 L F
.368 .294 .64 r
.4731 .70275 m .4747 .70246 L .47363 .70185 L F
.4731 .70275 m .47363 .70185 L .4728 .70137 L F
.691 .7 .854 r
.47357 .70196 m .47361 .70189 L .47336 .70174 L F
.47415 .70221 m .47589 .70132 L .47347 .70173 L F
.387 .389 .74 r
.47338 .70166 m .4747 .70246 L .4731 .70275 L F
.47427 .69818 m .4747 .70246 L .47338 .70166 L F
0 .261 .708 r
.4728 .70137 m .47363 .70185 L .47338 .70166 L F
.47295 .70141 m .47338 .70166 L .47306 .70144 L F
.4728 .70137 m .47338 .70166 L .47295 .70141 L F
.47306 .70144 m .4747 .70246 L .4738 .70163 L F
.47363 .70185 m .4747 .70246 L .47306 .70144 L F
.902 .769 .706 r
.4745 .69862 m .4747 .70246 L .47589 .70132 L F
.691 .7 .854 r
.47421 .69843 m .4745 .69862 L .47427 .69818 L F
.902 .769 .706 r
.47427 .69818 m .47431 .69859 L .4745 .69862 L F
.47431 .69859 m .4747 .70246 L .4745 .69862 L F
0 .032 .563 r
.47504 .70051 m .4747 .70246 L .47437 .69919 L F
.47504 .70051 m .47437 .69919 L .47427 .69818 L F
.582 .315 .477 r
.47504 .70051 m .47599 .70207 L .47581 .70203 L F
1 .812 .482 r
.4738 .70163 m .4747 .70246 L .47431 .69859 L F
.873 .525 .387 r
.47422 .69876 m .47425 .69858 L .47419 .69858 L F
.47426 .69869 m .47425 .69858 L .47422 .69876 L F
.307 .255 .634 r
.47374 .69735 m .47428 .69865 L .47427 .69818 L F
1 .812 .482 r
.47428 .69865 m .47431 .69859 L .47427 .69818 L F
.307 .255 .634 r
.47428 .69865 m .47504 .70051 L .47427 .69818 L F
1 .812 .482 r
.47418 .69882 m .47428 .69865 L .47427 .69818 L F
.4738 .70163 m .47431 .69859 L .47418 .69882 L F
.4738 .70163 m .47418 .69882 L .47504 .70051 L F
.873 .525 .387 r
.47423 .69891 m .47426 .69869 L .47422 .69876 L F
.47428 .69901 m .47426 .69869 L .47423 .69891 L F
1 .812 .482 r
.47418 .69882 m .47427 .69818 L .47504 .70051 L F
.873 .525 .387 r
.47438 .70015 m .47428 .69901 L .47423 .69891 L F
.582 .315 .477 r
.47504 .70051 m .47581 .70203 L .4738 .70163 L F
.873 .525 .387 r
.47438 .70015 m .47504 .70051 L .47425 .69858 L F
.47419 .69858 m .47425 .69858 L .47417 .6984 L F
.47395 .69825 m .47417 .6984 L .47374 .69735 L F
.47438 .70015 m .47417 .6984 L .47395 .69825 L F
0 .261 .708 r
.47202 .70037 m .4738 .70163 L .47182 .70011 L F
.4728 .70137 m .47306 .70144 L .47202 .70037 L F
.47306 .70144 m .4738 .70163 L .47202 .70037 L F
0 0 0 r
.36933 .59545 m .36759 .59597 L .36537 .59633 L F
.37152 .59567 m .36759 .59597 L .36933 .59545 L F
.652 .625 .81 r
.54502 .6395 m .54654 .64258 L .5484 .64051 L F
.848 .939 .883 r
.5484 .64051 m .54584 .64307 L .5475 .64295 L F
.79 .474 .454 r
.54608 .64568 m .5475 .64295 L .54584 .64307 L F
.54608 .64568 m .54916 .64633 L .5475 .64295 L F
.402 .065 .275 r
.49632 .6422 m .495 .64517 L .49296 .64425 L F
.357 .034 .274 r
.39305 .61185 m .3951 .61133 L .3962 .60862 L F
.439 .112 .313 r
.3962 .60862 m .39728 .61087 L .39851 .60884 L F
.3962 .60862 m .3951 .61133 L .39728 .61087 L F
.121 .004 .434 r
.48241 .6352 m .48407 .63415 L .48414 .63165 L F
.167 0 .242 r
.48241 .6352 m .48376 .63649 L .48407 .63415 L F
.48241 .6352 m .48153 .63698 L .48376 .63649 L F
.483 .124 .281 r
.75913 .48258 m .76196 .48197 L .76236 .4803 L F
.503 .142 .287 r
.76236 .4803 m .76196 .48197 L .76468 .48137 L F
.392 .083 .317 r
.495 .64517 m .49278 .64593 L .49296 .64425 L F
.463 .857 .974 r
.58615 .67581 m .58275 .67585 L .58437 .67639 L F
.519 .917 .863 r
.54545 .59548 m .54176 .59672 L .54409 .59649 L F
.007 0 0 r
.54642 .59569 m .54545 .59548 L .54409 .59649 L F
.54642 .59569 m .54795 .59493 L .54545 .59548 L F
.654 .406 .532 r
.39851 .60884 m .40103 .60901 L .40106 .60638 L F
.646 .535 .714 r
.40106 .60638 m .40408 .60603 L .40343 .60316 L F
.615 .374 .529 r
.40106 .60638 m .40394 .60788 L .40408 .60603 L F
.40106 .60638 m .40103 .60901 L .40394 .60788 L F
0 0 0 r
.43069 .69799 m .42781 .69998 L .4293 .69985 L F
.673 .199 .12 r
.39256 .59477 m .38915 .59429 L .39013 .59569 L F
.825 .457 .36 r
.68067 .49309 m .68354 .49234 L .68035 .49096 L F
.68067 .49309 m .68379 .49402 L .68354 .49234 L F
.536 .062 .077 r
.55266 .61518 m .55583 .61641 L .55587 .61514 L F
.677 .589 .75 r
.55587 .61514 m .55855 .61501 L .55757 .61161 L F
.92 .646 .504 r
.55694 .61675 m .55587 .61514 L .55583 .61641 L F
.55694 .61675 m .55855 .61501 L .55587 .61514 L F
.753 .559 .635 r
.72711 .48326 m .72693 .4858 L .73086 .48604 L F
.75 .631 .728 r
.72693 .4858 m .72852 .48914 L .73086 .48604 L F
0 0 .414 r
.73086 .48604 m .73222 .48436 L .73208 .48217 L F
.331 0 0 r
.73361 .48579 m .73222 .48436 L .73086 .48604 L F
.73361 .48579 m .72992 .48705 L .73222 .48436 L F
.73361 .48579 m .73255 .48678 L .72992 .48705 L F
.885 .99 .796 r
.73222 .48436 m .72992 .48705 L .73008 .48587 L F
.845 .58 .538 r
.73008 .48587 m .73236 .48672 L .73222 .48436 L F
.73236 .48672 m .73255 .48678 L .73222 .48436 L F
0 0 .414 r
.73208 .48217 m .73222 .48436 L .73222 .48172 L F
.675 .659 .826 r
.53551 .66341 m .53723 .66457 L .54031 .66374 L F
.499 .34 .596 r
.46667 .70185 m .4634 .70301 L .46485 .70036 L F
.114 .072 .528 r
.4684 .70255 m .46667 .70185 L .46917 .70069 L F
.4684 .70255 m .4671 .70483 L .46667 .70185 L F
.794 .623 .669 r
.53605 .661 m .53977 .66288 L .53796 .65784 L F
.684 .401 .488 r
.53551 .66341 m .53977 .66288 L .53605 .661 L F
.53551 .66341 m .54031 .66374 L .53977 .66288 L F
.649 .549 .727 r
.53796 .65784 m .53977 .66288 L .54154 .66081 L F
0 0 .483 r
.53977 .66288 m .5398 .66234 L .54154 .66081 L F
.53977 .66288 m .54031 .66374 L .5398 .66234 L F
.768 .647 .728 r
.72373 .48281 m .72711 .48326 L .7259 .47978 L F
.779 .583 .634 r
.72368 .48524 m .72711 .48326 L .72373 .48281 L F
.72368 .48524 m .72693 .4858 L .72711 .48326 L F
.139 0 0 r
.34336 .60012 m .34173 .6022 L .33979 .60284 L F
.304 0 .035 r
.34396 .60173 m .34336 .60012 L .34552 .59964 L F
.34396 .60173 m .34173 .6022 L .34336 .60012 L F
.865 .995 .809 r
.4827 .66496 m .48219 .66647 L .48205 .6656 L F
.914 .965 .652 r
.48205 .6656 m .48219 .66647 L .48046 .66946 L F
0 0 .128 r
.21033 .58302 m .20983 .5853 L .20889 .58645 L F
0 0 .172 r
.20983 .5853 m .20848 .58874 L .20889 .58645 L F
.877 .801 .772 r
.55434 .65446 m .55789 .65241 L .55473 .65149 L F
.55434 .65446 m .55598 .65517 L .55789 .65241 L F
.431 .811 .991 r
.5629 .67535 m .56188 .67457 L .5593 .67505 L F
.573 .297 .46 r
.38796 .61468 m .3904 .61451 L .39088 .61244 L F
.491 .242 .464 r
.3904 .61451 m .39305 .61185 L .39088 .61244 L F
.766 .809 .887 r
.54882 .59983 m .55258 .59888 L .55184 .59846 L F
.354 .447 .818 r
.55258 .59888 m .55351 .59706 L .55184 .59846 L F
.55258 .59888 m .55466 .6001 L .55351 .59706 L F
.565 .3 .474 r
.53318 .67526 m .53253 .6781 L .53009 .678 L F
.209 .267 .705 r
.53259 .67199 m .5346 .67492 L .53318 .67526 L F
.179 .19 .633 r
.53583 .67232 m .5346 .67492 L .53419 .6716 L F
.828 .982 .695 r
.53583 .67232 m .53549 .67279 L .5346 .67492 L F
.626 .358 .492 r
.53406 .67621 m .53318 .67526 L .5346 .67492 L F
.5353 .67756 m .53253 .6781 L .53318 .67526 L F
.364 .33 .686 r
.53419 .6716 m .5346 .67492 L .53259 .67199 L F
.828 .982 .695 r
.53549 .67279 m .53328 .6759 L .5346 .67492 L F
.626 .358 .492 r
.5353 .67756 m .53406 .67621 L .5346 .67492 L F
0 0 .521 r
.50541 .68296 m .5054 .68657 L .50733 .68376 L F
.407 .455 .798 r
.41819 .59397 m .41763 .59737 L .41634 .59416 L F
.41819 .59397 m .41934 .59745 L .41763 .59737 L F
0 .047 .61 r
.55732 .63245 m .55826 .63297 L .55598 .63097 L F
.55732 .63245 m .55884 .63415 L .55826 .63297 L F
.621 .098 0 r
.76679 .48919 m .76629 .49024 L .76364 .48861 L F
.513 0 0 r
.76988 .4902 m .76629 .49024 L .76679 .48919 L F
.434 .854 .954 r
.57161 .59716 m .57281 .59742 L .5728 .59742 L F
.57082 .59756 m .5728 .59742 L .57013 .59791 L F
.57161 .59716 m .5728 .59742 L .57082 .59756 L F
.639 .417 .565 r
.57281 .59742 m .56969 .60018 L .57013 .59791 L F
.57281 .59742 m .57291 .60009 L .57032 .60016 L F
.57029 .59964 m .57032 .60016 L .56969 .60018 L F
.57281 .59742 m .57032 .60016 L .57029 .59964 L F
.164 .064 .487 r
.57155 .59945 m .57161 .59716 L .57019 .59788 L F
.5702 .59798 m .57019 .59788 L .57013 .59791 L F
.57155 .59945 m .57019 .59788 L .5702 .59798 L F
.57155 .59945 m .57013 .59791 L .56969 .60018 L F
0 0 .083 r
.57053 .5972 m .56969 .60018 L .57013 .59791 L F
.8 .692 .746 r
.56716 .60035 m .56969 .60018 L .57042 .59759 L F
.57008 .59761 m .57042 .59759 L .57053 .5972 L F
.56716 .60035 m .57042 .59759 L .57008 .59761 L F
.366 .54 .894 r
.57013 .59791 m .57161 .59716 L .57053 .5972 L F
.467 .171 .378 r
.40467 .62016 m .40363 .62336 L .40131 .6236 L F
.463 .167 .377 r
.40582 .62282 m .40467 .62016 L .40669 .6201 L F
.40582 .62282 m .40363 .62336 L .40467 .62016 L F
.772 .528 .565 r
.75317 .48221 m .75648 .48034 L .75285 .48031 L F
.75317 .48221 m .75657 .48267 L .75648 .48034 L F
.891 .768 .719 r
.53443 .6601 m .53605 .661 L .53796 .65784 L F
.53443 .6601 m .53796 .65784 L .53672 .65956 L F
0 0 0 r
.53962 .65714 m .53672 .65956 L .53796 .65784 L F
.673 .163 .02 r
.51619 .63184 m .51995 .63325 L .51756 .63276 L F
.61 .391 .559 r
.77844 .49927 m .7814 .49959 L .78117 .49759 L F
.649 .621 .808 r
.78117 .49759 m .78265 .49403 L .7802 .49487 L F
.78117 .49759 m .78371 .49726 L .78265 .49403 L F
.656 .458 .604 r
.7814 .49959 m .78371 .49726 L .78117 .49759 L F
.446 .326 .623 r
.77844 .49927 m .78168 .50136 L .7814 .49959 L F
.77844 .49927 m .77874 .50317 L .78168 .50136 L F
0 0 0 r
.58768 .64988 m .58813 .64998 L .58932 .64882 L F
.58768 .64988 m .58664 .65185 L .58813 .64998 L F
.368 .657 .968 r
.77322 .48152 m .7719 .48268 L .77092 .48131 L F
.77322 .48152 m .77406 .48279 L .7719 .48268 L F
.714 .573 .695 r
.70838 .48025 m .71179 .48293 L .71058 .47944 L F
.70838 .48025 m .70805 .48291 L .71179 .48293 L F
.735 .582 .684 r
.45596 .68077 m .45432 .6832 L .4537 .6808 L F
.497 .524 .815 r
.33592 .6145 m .33523 .61829 L .33376 .61493 L F
.33592 .6145 m .33717 .61797 L .33523 .61829 L F
.686 .68 .838 r
.5461 .65514 m .54964 .65632 L .54935 .65534 L F
.464 .496 .807 r
.54964 .65632 m .55149 .6542 L .54935 .65534 L F
.54964 .65632 m .5531 .65814 L .55149 .6542 L F
.948 .919 .748 r
.59864 .60415 m .59661 .60549 L .59751 .60303 L F
.361 .05 .296 r
.46234 .65707 m .46293 .65538 L .46023 .65772 L F
.393 .079 .31 r
.46506 .65482 m .46293 .65538 L .46234 .65707 L F
.516 .547 .826 r
.21427 .565 m .21394 .56902 L .21332 .56686 L F
.474 .742 .987 r
.39917 .587 m .39721 .58736 L .39575 .58605 L F
.223 .731 .676 r
.30738 .6345 m .3071 .63459 L .30869 .63497 L F
.30738 .6345 m .30507 .63525 L .3071 .63459 L F
.174 0 0 r
.49838 .71598 m .49661 .7159 L .49985 .71522 L F
0 0 .369 r
.49966 .71175 m .49985 .71522 L .50049 .71464 L F
.49966 .71175 m .50021 .71455 L .49985 .71522 L F
.643 .948 .729 r
.50021 .71455 m .49838 .71598 L .49985 .71522 L F
.365 .403 .767 r
.55315 .61179 m .55474 .61393 L .55266 .61518 L F
.373 .42 .781 r
.55474 .61393 m .55583 .61641 L .55266 .61518 L F
.871 .729 .702 r
.46795 .66827 m .47048 .66834 L .46897 .67001 L F
.195 0 0 r
.46969 .66854 m .47048 .66834 L .46795 .66827 L F
.831 .681 .697 r
.67493 .48805 m .67636 .48872 L .67781 .48857 L F
.774 .455 .449 r
.67636 .48872 m .67679 .49081 L .67781 .48857 L F
.72 .393 .424 r
.67781 .48857 m .68035 .49096 L .68022 .48894 L F
.67781 .48857 m .67679 .49081 L .68035 .49096 L F
.59 .339 .504 r
.55472 .66376 m .55116 .66657 L .55085 .66354 L F
.55472 .66376 m .55498 .66599 L .55116 .66657 L F
.68 .403 .495 r
.55472 .66376 m .5566 .66589 L .55498 .66599 L F
.622 .222 .264 r
.70805 .48291 m .70968 .48315 L .71179 .48293 L F
.703 .605 .745 r
.71058 .47944 m .71179 .48293 L .71416 .48001 L F
0 0 0 r
.37499 .59487 m .37345 .59543 L .37152 .59567 L F
.608 .627 .845 r
.34104 .62054 m .3389 .62117 L .33717 .61797 L F
.624 .813 .973 r
.67091 .50252 m .67485 .50292 L .67343 .50202 L F
.548 .647 .899 r
.67485 .50292 m .67565 .49991 L .67343 .50202 L F
.67485 .50292 m .67696 .50248 L .67565 .49991 L F
.415 .154 .406 r
.52499 .64552 m .52307 .64409 L .52632 .6435 L F
0 0 0 r
.52662 .6441 m .52632 .6435 L .52939 .64522 L F
.52662 .6441 m .52499 .64552 L .52632 .6435 L F
0 .027 .548 r
.58129 .64996 m .58214 .64836 L .58156 .64709 L F
.169 .294 .749 r
.58085 .64766 m .58115 .6475 L .58119 .64813 L F
.58004 .64652 m .58119 .64813 L .5811 .64944 L F
.946 .956 .73 r
.58124 .64742 m .58123 .64756 L .58156 .64709 L F
.58123 .64756 m .58122 .64773 L .58124 .64769 L F
.58123 .64756 m .58124 .64769 L .58156 .64709 L F
.031 .261 .76 r
.58099 .64589 m .5811 .64613 L .58004 .64652 L F
0 0 0 r
.58208 .64698 m .58156 .64709 L .58214 .64836 L F
.094 .304 .783 r
.58208 .64698 m .58214 .64836 L .58161 .64724 L F
0 0 0 r
.58208 .64698 m .58172 .64718 L .58124 .64742 L F
.58208 .64698 m .58124 .64742 L .58188 .64702 L F
.094 .304 .783 r
.58208 .64698 m .58161 .64724 L .58099 .64589 L F
0 0 0 r
.58208 .64698 m .58203 .64702 L .58172 .64718 L F
.841 .741 .754 r
.58122 .64773 m .5815 .64879 L .58156 .64709 L F
.031 .261 .76 r
.58122 .64744 m .58214 .64836 L .58123 .64756 L F
.58161 .64724 m .58214 .64836 L .58122 .64744 L F
.946 .956 .73 r
.57874 .64995 m .58122 .64773 L .58124 .64742 L F
.169 .294 .749 r
.58115 .6475 m .58214 .64836 L .58163 .64931 L F
.58115 .6475 m .58163 .64931 L .58129 .64996 L F
0 0 0 r
.58203 .64702 m .57874 .64995 L .58122 .64744 L F
.58203 .64702 m .58122 .64744 L .58124 .64742 L F
.58188 .64702 m .58124 .64742 L .58156 .64709 L F
.031 .261 .76 r
.5811 .64613 m .58161 .64724 L .58122 .64744 L F
.5811 .64613 m .58123 .64756 L .58004 .64652 L F
.169 .294 .749 r
.58004 .64652 m .58114 .64748 L .58085 .64766 L F
.58114 .64748 m .58115 .6475 L .58085 .64766 L F
.5811 .64944 m .58119 .64813 L .58129 .64996 L F
.946 .956 .73 r
.57874 .64995 m .57913 .65162 L .58122 .64773 L F
.641 .882 .985 r
.58214 .64836 m .58386 .64911 L .58297 .6494 L F
.58163 .64931 m .58297 .6494 L .58129 .64996 L F
.58214 .64836 m .58297 .6494 L .58163 .64931 L F
.77 .674 .756 r
.58386 .64911 m .58137 .65211 L .58129 .64996 L F
.841 .741 .754 r
.57913 .65162 m .58137 .65211 L .58148 .6493 L F
.58109 .64927 m .58148 .6493 L .5815 .64879 L F
.57913 .65162 m .58148 .6493 L .58109 .64927 L F
.57913 .65162 m .5815 .64879 L .58122 .64773 L F
.496 .506 .797 r
.58137 .65211 m .58214 .64836 L .58129 .64996 L F
.58 .276 .417 r
.4312 .60553 m .43035 .60843 L .42784 .60846 L F
.534 .336 .558 r
.43315 .60533 m .43035 .60843 L .4312 .60553 L F
0 0 .064 r
.53906 .70663 m .53732 .70949 L .53652 .70717 L F
.507 .319 .56 r
.53857 .70852 m .53706 .71041 L .53732 .70949 L F
.757 .634 .724 r
.72486 .4885 m .72852 .48914 L .72693 .4858 L F
.138 0 0 r
.54781 .60663 m .54776 .60313 L .54886 .60542 L F
.493 .821 1 r
.54886 .60542 m .55016 .60619 L .54781 .60663 L F
.504 .264 .484 r
.42296 .60919 m .42239 .61202 L .42025 .61237 L F
.534 .291 .493 r
.42508 .61118 m .42296 .60919 L .42542 .60875 L F
.42508 .61118 m .42239 .61202 L .42296 .60919 L F
.563 .494 .735 r
.53985 .70688 m .54213 .70641 L .54157 .70334 L F
.84 .645 .639 r
.4887 .66635 m .48963 .66451 L .48697 .66283 L F
.009 0 0 r
.52351 .6343 m .52582 .63426 L .52721 .6342 L F
.32 0 0 r
.52582 .63426 m .52941 .63471 L .52721 .6342 L F
.377 .827 .934 r
.43697 .7034 m .43618 .70314 L .43395 .70363 L F
.486 .834 .997 r
.43395 .70363 m .43618 .70314 L .43487 .70246 L F
.727 .199 0 r
.43618 .70314 m .43723 .70526 L .43516 .70281 L F
.43618 .70314 m .43516 .70281 L .43487 .70246 L F
.377 .827 .934 r
.43797 .70333 m .43618 .70314 L .43697 .7034 L F
.696 .204 .073 r
.43797 .70333 m .43828 .70542 L .43618 .70314 L F
.43797 .70333 m .44013 .70524 L .43828 .70542 L F
.101 .64 .854 r
.36297 .58398 m .36514 .58397 L .36645 .58443 L F
.287 0 0 r
.36514 .58397 m .36876 .58424 L .36645 .58443 L F
.71 .881 .96 r
.79344 .51671 m .79699 .51652 L .79587 .51386 L F
.662 .687 .863 r
.79587 .51386 m .79699 .51652 L .79964 .51499 L F
.635 .154 0 r
.53315 .61272 m .53212 .61169 L .53022 .6092 L F
.768 .326 0 r
.53315 .61272 m .53399 .61435 L .53212 .61169 L F
.526 .205 .367 r
.49466 .65755 m .49789 .65714 L .49593 .65588 L F
.525 .206 .369 r
.49593 .65588 m .49789 .65714 L .49725 .65548 L F
0 0 0 r
.6003 .66943 m .59914 .67078 L .59737 .67206 L F
.021 0 0 r
.60197 .66869 m .60225 .66895 L .6003 .66943 L F
.097 0 0 r
.60225 .66895 m .59914 .67078 L .6003 .66943 L F
.632 .409 .562 r
.43678 .67241 m .43928 .67464 L .43923 .67219 L F
.43678 .67241 m .43697 .67521 L .43928 .67464 L F
.764 .516 .559 r
.48417 .71155 m .48637 .71175 L .48699 .70962 L F
.572 .32 .496 r
.48699 .70962 m .48934 .71132 L .48922 .70979 L F
.48699 .70962 m .48637 .71175 L .48934 .71132 L F
.5 .674 .943 r
.422 .5983 m .42094 .59999 L .41934 .59745 L F
.422 .5983 m .42312 .59977 L .42094 .59999 L F
.954 .755 .596 r
.61465 .60043 m .61494 .59787 L .61348 .59698 L F
.904 .713 .634 r
.61494 .59787 m .61366 .59236 L .61348 .59698 L F
.042 .574 .859 r
.35706 .5835 m .35902 .58376 L .36082 .58446 L F
.543 .003 0 r
.35902 .58376 m .36297 .58398 L .36082 .58446 L F
.725 .652 .776 r
.48169 .676 m .48306 .6787 L .47947 .67804 L F
.709 .304 .279 r
.48306 .6787 m .48175 .68021 L .47947 .67804 L F
.615 .897 .987 r
.48371 .67743 m .48306 .6787 L .48169 .676 L F
.608 .455 .649 r
.47947 .67804 m .4822 .67832 L .48169 .676 L F
.4822 .67832 m .48408 .67852 L .48348 .67789 L F
.4822 .67832 m .48348 .67789 L .48169 .676 L F
.692 .316 .33 r
.47947 .67804 m .48175 .68021 L .47866 .67993 L F
.459 0 0 r
.4778 .67805 m .48089 .67828 L .47947 .67804 L F
.48089 .67828 m .48408 .67852 L .4822 .67832 L F
.48089 .67828 m .4822 .67832 L .47947 .67804 L F
.615 .897 .987 r
.48348 .67789 m .48583 .67788 L .48413 .67839 L F
.48324 .67836 m .48413 .67839 L .48306 .6787 L F
.48348 .67789 m .48413 .67839 L .48324 .67836 L F
.48371 .67743 m .48439 .67758 L .48348 .67789 L F
.48439 .67758 m .48583 .67788 L .48348 .67789 L F
.598 .169 .197 r
.48635 .67984 m .48306 .6787 L .48583 .67788 L F
.48635 .67984 m .48175 .68021 L .48306 .6787 L F
.451 .706 .976 r
.78284 .48376 m .78142 .48519 L .78039 .484 L F
.78284 .48376 m .78376 .48507 L .78142 .48519 L F
.328 .796 .93 r
.52941 .63471 m .53166 .63436 L .53317 .63466 L F
.137 .653 .891 r
.53166 .63436 m .53506 .63492 L .53317 .63466 L F
.912 .744 .66 r
.47453 .6743 m .47716 .67518 L .47537 .67203 L F
.237 0 0 r
.47453 .6743 m .47731 .67523 L .47716 .67518 L F
.912 .744 .66 r
.47453 .6743 m .47716 .67518 L .47537 .67203 L F
0 0 0 r
.59006 .63801 m .59174 .6367 L .59279 .63497 L F
.45 .249 .514 r
.5947 .63591 m .59279 .63497 L .59174 .6367 L F
.5947 .63591 m .59557 .63428 L .59279 .63497 L F
.731 .44 .486 r
.48823 .71502 m .48714 .71787 L .48482 .71506 L F
.471 .107 .264 r
.49059 .71528 m .48714 .71787 L .48823 .71502 L F
.952 .604 .232 r
.59935 .6123 m .59864 .61349 L .59809 .61124 L F
.59935 .6123 m .59975 .61444 L .59864 .61349 L F
.158 0 .099 r
.21634 .56128 m .21434 .56262 L .21501 .56124 L F
0 .089 .629 r
.7409 .47641 m .73991 .47294 L .73955 .47511 L F
.363 .761 .986 r
.3783 .58461 m .38063 .58445 L .38204 .58524 L F
0 .474 .722 r
.38063 .58445 m .3842 .58519 L .38204 .58524 L F
.549 .612 .868 r
.31921 .64096 m .31967 .63719 L .31721 .63792 L F
.31921 .64096 m .32161 .64066 L .31967 .63719 L F
.651 .478 .636 r
.7167 .47462 m .7139 .47754 L .71651 .47713 L F
.7167 .47462 m .71651 .47713 L .71535 .47371 L F
.946 .746 .601 r
.71535 .47371 m .71651 .47713 L .7167 .47462 L F
.435 .27 .557 r
.50881 .64649 m .5108 .64594 L .51079 .64351 L F
.754 .856 .417 r
.72586 .50065 m .72674 .49941 L .72491 .49979 L F
.572 .423 .641 r
.72674 .49941 m .72994 .49895 L .72893 .49458 L F
.936 .755 .632 r
.6158 .6061 m .61612 .60373 L .61468 .60269 L F
.689 .644 .799 r
.48615 .69123 m .48879 .69266 L .48558 .6922 L F
.718 .542 .651 r
.48924 .69514 m .48558 .6922 L .48879 .69266 L F
.385 .634 .953 r
.48863 .69165 m .48879 .69266 L .48615 .69123 L F
.298 .531 .908 r
.49008 .69369 m .48879 .69266 L .48863 .69165 L F
.49008 .69369 m .48924 .69514 L .48879 .69266 L F
.42 .078 .277 r
.40131 .6236 m .39857 .62549 L .39923 .62419 L F
.503 .275 .501 r
.5295 .60363 m .5292 .60582 L .53177 .60346 L F
.931 .679 .534 r
.6122 .58897 m .61224 .59199 L .61357 .59195 L F
.879 .514 .351 r
.61224 .59199 m .61253 .5939 L .61357 .59195 L F
.782 .383 .298 r
.61357 .59195 m .61253 .5939 L .61366 .59236 L F
.132 .492 .904 r
.21053 .54992 m .21049 .55118 L .20812 .54892 L F
.21053 .54992 m .21166 .55127 L .21049 .55118 L F
0 0 0 r
.51901 .64795 m .51819 .64758 L .52016 .64654 L F
.51901 .64795 m .51701 .64885 L .51819 .64758 L F
.55 .268 .44 r
.52307 .64409 m .52277 .64639 L .52016 .64654 L F
.415 .154 .406 r
.52499 .64552 m .52277 .64639 L .52307 .64409 L F
.692 .479 .593 r
.74549 .48048 m .74896 .47733 L .74641 .47675 L F
.74549 .48048 m .74939 .48001 L .74896 .47733 L F
.598 .201 .261 r
.48237 .71503 m .4812 .7168 L .47884 .7153 L F
.719 .425 .479 r
.48482 .71506 m .4812 .7168 L .48237 .71503 L F
.228 .348 .778 r
.57398 .66947 m .57523 .66824 L .57274 .66609 L F
.079 .104 .586 r
.57398 .66947 m .57542 .67165 L .57523 .66824 L F
.741 .972 .711 r
.55782 .66764 m .55644 .66843 L .5566 .66589 L F
.477 .447 .746 r
.5594 .66703 m .55782 .66764 L .5566 .66589 L F
.5594 .66703 m .56094 .66896 L .55782 .66764 L F
.644 .805 .96 r
.31427 .63471 m .31796 .63511 L .31708 .63409 L F
.689 .252 .207 r
.31427 .63471 m .31613 .63665 L .31796 .63511 L F
.387 .675 .974 r
.31796 .63511 m .31909 .63364 L .31708 .63409 L F
0 0 0 r
.31796 .63511 m .31814 .63531 L .31909 .63364 L F
.582 .34 .515 r
.45999 .69598 m .45974 .69815 L .46122 .6966 L F
.544 .379 .608 r
.45999 .69598 m .46122 .6966 L .46221 .69461 L F
.772 .541 .585 r
.72606 .49419 m .72599 .49698 L .72893 .49458 L F
.271 0 .099 r
.57455 .58275 m .57683 .58206 L .57779 .57998 L F
.405 .083 .302 r
.57933 .58187 m .57779 .57998 L .57683 .58206 L F
.57933 .58187 m .58012 .5795 L .57779 .57998 L F
.327 .148 .479 r
.79921 .50006 m .79926 .50235 L .79741 .50276 L F
.821 .507 .457 r
.59435 .58928 m .59167 .59062 L .59169 .58855 L F
.59435 .58928 m .5948 .59145 L .59167 .59062 L F
0 0 .225 r
.57024 .65816 m .57094 .66043 L .56992 .65702 L F
.516 .547 .826 r
.21427 .565 m .21595 .56853 L .21394 .56902 L F
.117 0 .313 r
.21595 .56853 m .21414 .57146 L .21394 .56902 L F
.72 .664 .793 r
.28996 .64654 m .28922 .64815 L .29348 .64657 L F
.65 .136 .006 r
.56451 .62535 m .56398 .62349 L .56317 .62228 L F
.56451 .62535 m .56668 .62559 L .56398 .62349 L F
.805 .964 .645 r
.48558 .6922 m .48405 .6933 L .48456 .69164 L F
.48558 .6922 m .48334 .69522 L .48405 .6933 L F
.717 .542 .652 r
.48558 .6922 m .48757 .69542 L .48334 .69522 L F
0 0 0 r
.48456 .69164 m .48615 .69123 L .48558 .6922 L F
.718 .542 .651 r
.48924 .69514 m .48757 .69542 L .48558 .6922 L F
.488 .122 .272 r
.56615 .58524 m .569 .58361 L .56665 .58403 L F
.169 0 .195 r
.52247 .66622 m .52384 .66597 L .52447 .66421 L F
.474 0 0 r
.42654 .60072 m .4294 .60193 L .4304 .60176 L F
.676 .269 .266 r
.4294 .60193 m .43364 .60198 L .4304 .60176 L F
0 0 0 r
.35819 .64151 m .35815 .64113 L .36016 .64034 L F
.35819 .64151 m .35653 .64248 L .35815 .64113 L F
.941 .843 .406 r
.59959 .61684 m .5999 .61779 L .5993 .62083 L F
.92 .646 .504 r
.55694 .61675 m .55879 .61751 L .55855 .61501 L F
.595 .52 .74 r
.55855 .61501 m .55976 .61104 L .55757 .61161 L F
.55855 .61501 m .56125 .61419 L .55976 .61104 L F
.326 0 .003 r
.31251 .58862 m .31478 .58827 L .31627 .58666 L F
.372 0 .033 r
.31627 .58666 m .31478 .58827 L .31794 .58733 L F
.368 0 .069 r
.31627 .58666 m .31794 .58733 L .31854 .58634 L F
.303 .796 .785 r
.59153 .64783 m .59441 .64694 L .59555 .64679 L F
.32 0 .086 r
.374 .62293 m .3762 .62245 L .37742 .62054 L F
0 0 0 r
.37742 .62054 m .37884 .62022 L .37949 .61958 L F
.259 0 .052 r
.37742 .62054 m .37832 .62185 L .37884 .62022 L F
.37742 .62054 m .3762 .62245 L .37832 .62185 L F
.381 .62 .946 r
.40702 .58864 m .40639 .59036 L .40498 .58883 L F
.40702 .58864 m .40894 .59049 L .40639 .59036 L F
.451 .508 .826 r
.30292 .62024 m .30465 .61995 L .30169 .61812 L F
.391 .493 .844 r
.52445 .67904 m .52694 .67999 L .52505 .68077 L F
.209 .021 .392 r
.52694 .67999 m .52477 .68282 L .52505 .68077 L F
.273 .749 .936 r
.36876 .58424 m .37097 .58406 L .37246 .58467 L F
.328 0 0 r
.37097 .58406 m .37454 .58437 L .37246 .58467 L F
.573 .098 .09 r
.66994 .4871 m .67386 .48758 L .6707 .48608 L F
.318 0 0 r
.6707 .48608 m .67386 .48758 L .67493 .48805 L F
.813 .568 .568 r
.60384 .57994 m .60735 .58286 L .60746 .58061 L F
.874 .863 .414 r
.59861 .62969 m .59868 .62796 L .5996 .62636 L F
.738 .799 .901 r
.55503 .67088 m .55309 .67381 L .55613 .67331 L F
.641 .912 .612 r
.59329 .56901 m .59434 .56751 L .59525 .56695 L F
.509 0 0 r
.59525 .56695 m .59434 .56751 L .59777 .56813 L F
.04 .582 .845 r
.34185 .5825 m .3439 .58277 L .34545 .58329 L F
.111 .647 .859 r
.3439 .58277 m .34761 .58323 L .34545 .58329 L F
0 0 .573 r
.57226 .66373 m .5725 .66271 L .57094 .66043 L F
0 0 .501 r
.57226 .66373 m .57373 .66463 L .5725 .66271 L F
.57226 .66373 m .57274 .66609 L .57373 .66463 L F
.087 .488 .897 r
.45971 .70272 m .45936 .70323 L .45841 .7024 L F
.45971 .70272 m .46142 .7041 L .45936 .70323 L F
.785 .61 .663 r
.53054 .66936 m .52888 .67207 L .52789 .66929 L F
.571 .843 .996 r
.53259 .67199 m .52888 .67207 L .53054 .66936 L F
.296 0 0 r
.38604 .63129 m .38654 .6326 L .38438 .63303 L F
.38604 .63129 m .3882 .63103 L .38654 .6326 L F
.842 .739 .751 r
.53316 .64941 m .53109 .65065 L .53112 .64995 L F
.626 .62 .824 r
.53793 .66947 m .53971 .67107 L .53899 .66867 L F
.728 .681 .804 r
.53899 .66867 m .53971 .67107 L .54121 .66977 L F
.427 .239 .521 r
.29586 .60065 m .29757 .60012 L .29784 .59782 L F
.44 .27 .553 r
.29586 .60254 m .29757 .60012 L .29586 .60065 L F
.524 .238 .423 r
.49789 .65714 m .50069 .6549 L .49725 .65548 L F
.36 .491 .856 r
.56418 .64462 m .56545 .64254 L .56351 .64303 L F
.56418 .64462 m .56719 .64566 L .56545 .64254 L F
.814 .488 0 r
.56999 .65471 m .56872 .6512 L .56971 .65223 L F
.598 .301 .437 r
.3012 .62861 m .30366 .62881 L .30424 .62673 L F
.473 .463 .767 r
.30424 .62673 m .3063 .62616 L .30491 .62334 L F
.323 .049 .333 r
.30424 .62673 m .30366 .62881 L .3063 .62616 L F
.333 .786 .951 r
.34818 .62668 m .35043 .62642 L .35198 .62684 L F
.699 .931 .965 r
.35198 .62684 m .35261 .62511 L .35405 .62588 L F
.35198 .62684 m .35043 .62642 L .35261 .62511 L F
0 .278 .779 r
.52971 .64647 m .53043 .64571 L .52939 .64522 L F
0 .16 .699 r
.57024 .63213 m .57242 .6343 L .57199 .63487 L F
0 .209 .732 r
.57242 .6343 m .57432 .63688 L .57199 .63487 L F
.779 .447 .426 r
.74979 .48161 m .75285 .48031 L .74939 .48001 L F
.74979 .48161 m .75317 .48221 L .75285 .48031 L F
0 0 .265 r
.73778 .50564 m .73727 .50883 L .73788 .50796 L F
.487 .247 .476 r
.73778 .50564 m .73995 .5052 L .74019 .50345 L F
.124 0 .305 r
.73778 .50564 m .73938 .50646 L .73995 .5052 L F
.73778 .50564 m .73788 .50796 L .73938 .50646 L F
.742 .358 0 r
.44985 .70982 m .45039 .71107 L .44917 .70875 L F
0 .558 .783 r
.3842 .58519 m .38631 .58544 L .38793 .58579 L F
.109 .649 .85 r
.38793 .58579 m .38631 .58544 L .38994 .58582 L F
.423 .116 .337 r
.46023 .65772 m .45743 .66065 L .45942 .66001 L F
.342 .014 .256 r
.46234 .65707 m .46023 .65772 L .45942 .66001 L F
0 0 .521 r
.50541 .68296 m .50636 .68549 L .5054 .68657 L F
.521 .36 .604 r
.50636 .68549 m .50436 .68872 L .5054 .68657 L F
.089 0 0 r
.5596 .60637 m .55865 .608 L .55634 .60901 L F
.701 .607 .748 r
.56217 .60567 m .56179 .60361 L .5596 .60637 L F
0 0 0 r
.5596 .60637 m .56179 .60361 L .56078 .60518 L F
.653 .509 .675 r
.55984 .60935 m .56217 .60567 L .5596 .60637 L F
0 0 0 r
.5596 .60637 m .56078 .60518 L .55865 .608 L F
.712 .568 .69 r
.71058 .47944 m .7139 .47754 L .71069 .47731 L F
.71058 .47944 m .71416 .48001 L .7139 .47754 L F
.663 .531 .693 r
.7139 .47754 m .71416 .48001 L .71651 .47713 L F
.422 .096 .305 r
.52674 .6637 m .52828 .66343 L .53024 .66047 L F
.667 .377 .471 r
.53024 .66047 m .52828 .66343 L .5321 .66294 L F
.691 .376 .438 r
.76137 .48847 m .75814 .49036 L .75779 .48856 L F
.76137 .48847 m .76045 .49094 L .75814 .49036 L F
.597 .279 .401 r
.76399 .48997 m .76137 .48847 L .76364 .48861 L F
.76399 .48997 m .76045 .49094 L .76137 .48847 L F
.903 .511 .088 r
.7902 .5207 m .79157 .52108 L .79076 .52006 L F
.081 .554 .902 r
.7936 .52062 m .79464 .52161 L .79157 .52108 L F
.395 .344 .683 r
.79464 .52161 m .79212 .52321 L .79157 .52108 L F
.446 0 0 r
.5038 .6389 m .50587 .63963 L .50347 .63957 L F
.915 .685 .577 r
.73387 .4811 m .73547 .48257 L .73568 .4802 L F
.566 .659 .9 r
.74683 .49143 m .74875 .49177 L .74868 .49089 L F
.057 0 0 r
.74851 .49094 m .74683 .49143 L .74863 .49044 L F
.566 .659 .9 r
.74683 .49143 m .74868 .49089 L .74857 .48953 L F
.057 0 0 r
.74846 .49116 m .74683 .49143 L .74851 .49094 L F
.319 .696 .98 r
.74846 .49116 m .74875 .49177 L .74683 .49143 L F
.351 .426 .799 r
.74846 .49116 m .74736 .49442 L .74683 .49143 L F
.008 .153 .667 r
.74683 .49143 m .74727 .49391 L .74751 .49282 L F
.74727 .49391 m .74736 .49442 L .74751 .49282 L F
.339 .337 .71 r
.74683 .49143 m .74751 .49282 L .74846 .49116 L F
.787 .303 .07 r
.74544 .49337 m .74776 .49167 L .74751 .49282 L F
.74776 .49167 m .74846 .49116 L .74751 .49282 L F
.921 .865 .768 r
.74482 .49674 m .74751 .49282 L .74736 .49442 L F
.74482 .49674 m .74431 .49448 L .74751 .49282 L F
.74482 .49674 m .74391 .49789 L .74431 .49448 L F
.23 .359 .788 r
.7466 .49815 m .74391 .49789 L .74482 .49674 L F
0 0 0 r
.74719 .49488 m .74482 .49674 L .74736 .49442 L F
.08 .011 .47 r
.74719 .49488 m .7466 .49815 L .74482 .49674 L F
.516 .534 .813 r
.80188 .5017 m .80068 .50507 L .79926 .50235 L F
.80188 .5017 m .80302 .5049 L .80068 .50507 L F
.312 .402 .794 r
.5108 .64594 m .51226 .65015 L .51336 .6478 L F
.806 .98 .699 r
.51226 .65015 m .51075 .65098 L .51336 .6478 L F
.995 .767 .475 r
.51226 .65015 m .51204 .65201 L .51075 .65098 L F
.69 .339 .376 r
.47884 .7153 m .47538 .71693 L .47519 .71552 L F
.47884 .7153 m .47777 .71765 L .47538 .71693 L F
.583 .224 .326 r
.4812 .7168 m .47777 .71765 L .47884 .7153 L F
0 0 .326 r
.611 .64043 m .6109 .64359 L .61056 .64352 L F
0 0 .458 r
.6109 .64359 m .61152 .64573 L .61056 .64352 L F
.874 .529 .394 r
.55584 .65732 m .5596 .66061 L .55857 .65918 L F
0 0 .275 r
.74019 .50345 m .74186 .50325 L .74275 .50312 L F
.74019 .50345 m .73995 .5052 L .74186 .50325 L F
.526 .62 .888 r
.74221 .52516 m .74312 .52198 L .74126 .52215 L F
.74221 .52516 m .74442 .52485 L .74312 .52198 L F
.514 .225 .413 r
.41741 .61452 m .41463 .61683 L .41506 .61485 L F
.55 .435 .675 r
.77757 .50857 m .77949 .50819 L .77939 .50548 L F
.648 .566 .749 r
.77797 .51158 m .77949 .50819 L .77757 .50857 L F
.501 0 0 r
.47369 .67819 m .47211 .67943 L .47015 .67822 L F
.139 0 0 r
.47661 .67844 m .47211 .67943 L .47369 .67819 L F
.723 .54 .643 r
.48697 .66283 m .49005 .65975 L .48807 .66086 L F
.456 .139 .338 r
.49005 .65975 m .49232 .66017 L .49294 .65815 L F
.544 .504 .762 r
.49103 .66289 m .49232 .66017 L .49005 .65975 L F
.743 .707 .818 r
.66527 .50287 m .66872 .50349 L .66743 .50217 L F
.678 .696 .86 r
.66743 .50217 m .66872 .50349 L .67091 .50252 L F
.878 .562 .446 r
.59867 .57351 m .60179 .57218 L .60029 .5706 L F
.59867 .57351 m .60226 .57438 L .60179 .57218 L F
.453 .354 .652 r
.80302 .5049 m .80378 .50804 L .80088 .50905 L F
.32 .097 .41 r
.80378 .50804 m .80144 .51049 L .80088 .50905 L F
.801 .577 .598 r
.48998 .67442 m .49305 .67283 L .49034 .67268 L F
.48998 .67442 m .49408 .67535 L .49305 .67283 L F
.487 .421 .709 r
.49305 .67283 m .49408 .67535 L .4958 .67447 L F
.49305 .67283 m .49408 .67535 L .4958 .67447 L F
.164 .31 .766 r
.55434 .65446 m .55584 .65732 L .55598 .65517 L F
.705 .851 .952 r
.5321 .66294 m .53551 .66341 L .53443 .6601 L F
.5321 .66294 m .53341 .66394 L .53551 .66341 L F
.861 .793 .783 r
.53443 .6601 m .53551 .66341 L .53605 .661 L F
.382 .025 .229 r
.33811 .60383 m .33716 .60555 L .33492 .60606 L F
.578 .356 .542 r
.33979 .60284 m .33716 .60555 L .33811 .60383 L F
.707 .955 .951 r
.5727 .59628 m .57281 .59742 L .57161 .59716 L F
.746 .583 .008 r
.5727 .59628 m .57291 .60009 L .57281 .59742 L F
.258 0 .011 r
.49034 .67268 m .48759 .67467 L .48998 .67442 L F
.726 .227 .049 r
.59633 .63587 m .59922 .63769 L .59734 .6371 L F
.544 .351 .569 r
.50771 .76681 m .50561 .76829 L .50386 .76588 L F
.50771 .76681 m .50772 .76938 L .50561 .76829 L F
.872 .818 .34 r
.53069 .6656 m .53341 .66394 L .5321 .66294 L F
.043 0 0 r
.36622 .63853 m .36453 .63935 L .36232 .63976 L F
.168 0 0 r
.36856 .63809 m .36453 .63935 L .36622 .63853 L F
.572 .35 .541 r
.55757 .61161 m .55976 .61104 L .55984 .60935 L F
.653 .509 .675 r
.55984 .60935 m .56318 .60915 L .56217 .60567 L F
.705 .543 .666 r
.55976 .61104 m .56318 .60915 L .55984 .60935 L F
.414 .209 .491 r
.43483 .68055 m .43705 .6776 L .43477 .67805 L F
.574 .937 .801 r
.55085 .66354 m .55032 .66345 L .55205 .66226 L F
.154 .297 .758 r
.59329 .56901 m .59553 .5708 L .59434 .56751 L F
.455 .307 .59 r
.59329 .56901 m .59345 .57161 L .59553 .5708 L F
.39 .126 .388 r
.52728 .6567 m .52559 .65542 L .52793 .65501 L F
.52728 .6567 m .52512 .65759 L .52559 .65542 L F
.469 .87 .699 r
.55319 .5918 m .54964 .59384 L .55275 .594 L F
.196 0 .025 r
.55451 .59272 m .55319 .5918 L .55275 .594 L F
.55451 .59272 m .55544 .5914 L .55319 .5918 L F
.723 .351 .345 r
.48934 .71132 m .49137 .71215 L .48922 .70979 L F
.653 .59 .771 r
.6618 .49873 m .66156 .49997 L .66405 .49726 L F
.642 .573 .761 r
.66405 .49726 m .66156 .49997 L .66433 .49956 L F
.647 .524 .699 r
.66156 .49997 m .66527 .50287 L .66433 .49956 L F
.66156 .49997 m .66347 .50423 L .66527 .50287 L F
0 0 0 r
.30531 .5916 m .30532 .59285 L .30755 .59115 L F
.30531 .5916 m .30407 .59366 L .30532 .59285 L F
.43 .115 .327 r
.52384 .66597 m .52674 .6637 L .52447 .66421 L F
.405 0 0 r
.47395 .70907 m .47633 .7092 L .47772 .70861 L F
.387 0 0 r
.47772 .70861 m .47633 .7092 L .48022 .70873 L F
.77 .668 .75 r
.56263 .61192 m .56447 .61498 L .56125 .61419 L F
.744 .314 .229 r
.56447 .61498 m .56321 .61645 L .56125 .61419 L F
0 0 .371 r
.56263 .61192 m .56409 .61432 L .56447 .61498 L F
.945 .921 .556 r
.56447 .61498 m .56409 .61432 L .56321 .61645 L F
.722 .69 .819 r
.22207 .55828 m .22081 .56122 L .21875 .55708 L F
0 0 0 r
.74719 .49488 m .74736 .49442 L .74846 .49116 L F
.626 .62 .824 r
.53793 .66947 m .53899 .66867 L .53767 .66878 L F
0 0 .354 r
.5292 .60582 m .53022 .6092 L .52999 .60805 L F
0 .091 .646 r
.53022 .6092 m .53174 .60993 L .52999 .60805 L F
.53022 .6092 m .53212 .61169 L .53174 .60993 L F
.443 .337 .64 r
.43322 .6837 m .43545 .68575 L .43507 .68306 L F
.43322 .6837 m .43317 .68677 L .43545 .68575 L F
.897 .568 .416 r
.59124 .58613 m .59169 .58855 L .58983 .58778 L F
.65 .769 .936 r
.78281 .50814 m .78625 .50878 L .78538 .50725 L F
.768 .636 .716 r
.78532 .50953 m .78625 .50878 L .78281 .50814 L F
.647 .768 .937 r
.78538 .50725 m .78625 .50878 L .78874 .50794 L F
.561 .103 .122 r
.49264 .61952 m .49492 .6197 L .4961 .61841 L F
.635 .189 .175 r
.49492 .6197 m .49846 .6199 L .4961 .61841 L F
.617 .072 0 r
.4961 .61841 m .49846 .6199 L .50024 .61989 L F
.108 .23 .709 r
.54154 .66081 m .54262 .65953 L .5414 .65756 L F
.573 .875 .576 r
.54154 .66081 m .5398 .66234 L .54262 .65953 L F
.705 .458 .547 r
.56217 .60567 m .56424 .60296 L .56179 .60361 L F
.689 .53 .666 r
.56217 .60567 m .56318 .60915 L .56446 .6063 L F
.259 .06 .409 r
.21205 .57739 m .21167 .58023 L .21017 .5805 L F
.326 .214 .57 r
.21164 .58207 m .21017 .5805 L .21167 .58023 L F
.21164 .58207 m .21033 .58302 L .21017 .5805 L F
.17 0 0 r
.37178 .63677 m .37074 .63766 L .36856 .63809 L F
.174 0 0 r
.37408 .63641 m .37304 .63719 L .37178 .63677 L F
.173 0 0 r
.37178 .63677 m .37304 .63719 L .37074 .63766 L F
.551 .111 .157 r
.77467 .51284 m .77713 .51323 L .77797 .51158 L F
.648 .566 .749 r
.77797 .51158 m .78054 .51144 L .77949 .50819 L F
.7 .272 .227 r
.77797 .51158 m .77713 .51323 L .78065 .51357 L F
.617 .366 .514 r
.77797 .51158 m .78065 .51357 L .78054 .51144 L F
.496 .785 .997 r
.75385 .5119 m .75106 .51238 L .75009 .51123 L F
.558 .611 .862 r
.79925 .49007 m .79732 .4923 L .79719 .49025 L F
.79925 .49007 m .80077 .4931 L .79732 .4923 L F
.484 .224 .443 r
.52529 .66967 m .52517 .67166 L .52287 .67211 L F
.52529 .66967 m .52517 .67166 L .52287 .67211 L F
.356 .466 .835 r
.52384 .66597 m .52529 .66967 L .52635 .66767 L F
.772 .603 .671 r
.52789 .66929 m .52609 .67086 L .52529 .66967 L F
.52609 .67086 m .52517 .67166 L .52523 .67078 L F
.52609 .67086 m .52523 .67078 L .52529 .66967 L F
.52789 .66929 m .52888 .67207 L .52517 .67166 L F
.558 .564 .815 r
.52635 .66767 m .52734 .67097 L .53168 .66932 L F
.52734 .67097 m .52767 .67205 L .52902 .67113 L F
.52734 .67097 m .52902 .67113 L .53168 .66932 L F
.705 .653 .796 r
.52517 .67166 m .52635 .66767 L .52529 .66967 L F
.391 .074 .303 r
.45477 .6634 m .45263 .66395 L .45197 .66579 L F
.59 .847 .993 r
.35814 .62585 m .35405 .62588 L .35685 .6248 L F
.016 .479 .874 r
.35685 .6248 m .3584 .62529 L .35814 .62585 L F
0 .449 .861 r
.3584 .62529 m .36016 .6267 L .35814 .62585 L F
.187 0 0 r
.35376 .59775 m .34997 .59866 L .35155 .59833 L F
.389 .209 .512 r
.49429 .68952 m .49597 .69133 L .496 .68886 L F
.49429 .68952 m .49417 .69219 L .49597 .69133 L F
.49429 .68952 m .49597 .69133 L .496 .68886 L F
.49429 .68952 m .49417 .69219 L .49597 .69133 L F
.209 0 0 r
.51869 .66179 m .51942 .66261 L .51694 .6631 L F
0 0 .067 r
.52175 .65988 m .51869 .66179 L .52234 .65978 L F
.687 .754 .902 r
.52234 .65978 m .51869 .66179 L .52112 .66131 L F
0 0 .067 r
.52175 .65988 m .51942 .66261 L .51869 .66179 L F
.259 .768 .779 r
.75404 .5265 m .75704 .52585 L .75654 .52547 L F
.621 .879 .989 r
.75829 .52419 m .75704 .52585 L .75915 .52504 L F
.688 .978 .893 r
.75654 .52547 m .75704 .52585 L .75829 .52419 L F
.512 .14 .271 r
.34962 .64347 m .34833 .64569 L .346 .64565 L F
.342 0 .091 r
.35198 .64325 m .34833 .64569 L .34962 .64347 L F
.844 .875 .864 r
.48368 .6627 m .4856 .6637 L .4827 .66496 L F
.313 .62 .958 r
.48529 .66598 m .4827 .66496 L .4856 .6637 L F
.701 .876 .963 r
.48697 .66283 m .4856 .6637 L .48368 .6627 L F
.359 .125 .418 r
.48529 .66598 m .4856 .6637 L .48697 .66283 L F
.104 .465 .89 r
.42716 .59979 m .42654 .60072 L .42523 .59986 L F
.42716 .59979 m .4294 .60193 L .42654 .60072 L F
.4 .805 .982 r
.34761 .58323 m .3499 .58287 L .3513 .58346 L F
.614 .898 .987 r
.3513 .58346 m .35201 .58197 L .35347 .5828 L F
.3513 .58346 m .3499 .58287 L .35201 .58197 L F
.709 .176 0 r
.74583 .47432 m .74414 .47354 L .74438 .47341 L F
.74583 .47432 m .74534 .47412 L .74414 .47354 L F
.931 .859 .426 r
.6156 .61994 m .61458 .62187 L .61471 .62381 L F
.6156 .61994 m .61517 .61965 L .61458 .62187 L F
.21 0 0 r
.35735 .59717 m .35597 .59772 L .35376 .59775 L F
.006 0 0 r
.35956 .59676 m .35597 .59772 L .35735 .59717 L F
.306 .031 .321 r
.48759 .67467 m .48468 .67636 L .48598 .67406 L F
0 .255 .764 r
.48468 .67636 m .48626 .67666 L .48598 .67406 L F
.48468 .67636 m .48583 .67788 L .48626 .67666 L F
.882 .715 .669 r
.60226 .57438 m .60075 .5769 L .60376 .57762 L F
.809 .548 .544 r
.60046 .57933 m .60376 .57762 L .60075 .5769 L F
.60046 .57933 m .60384 .57994 L .60376 .57762 L F
.412 .543 .878 r
.2145 .5524 m .21367 .55438 L .21166 .55127 L F
.277 .383 .792 r
.2145 .5524 m .2151 .55487 L .21367 .55438 L F
.597 .558 .782 r
.21696 .55737 m .21367 .55438 L .2151 .55487 L F
.708 .203 .033 r
.49846 .6199 m .50187 .62099 L .50024 .61989 L F
.558 .602 .853 r
.74522 .52656 m .7472 .52442 L .74442 .52485 L F
.74522 .52656 m .74755 .52613 L .7472 .52442 L F
.674 .144 0 r
.57546 .63998 m .57812 .64208 L .57844 .64096 L F
.876 .447 .047 r
.57812 .64208 m .57966 .64323 L .57844 .64096 L F
.592 .47 .682 r
.4314 .69212 m .43442 .69192 L .43372 .68919 L F
.63 .512 .7 r
.4324 .69535 m .43442 .69192 L .4314 .69212 L F
.542 .506 .766 r
.40343 .60316 m .40466 .59961 L .4019 .59983 L F
.40343 .60316 m .40551 .60262 L .40466 .59961 L F
.603 .541 .757 r
.40408 .60603 m .40551 .60262 L .40343 .60316 L F
.188 .239 .684 r
.58149 .65989 m .5803 .66093 L .57969 .65728 L F
.439 .68 .966 r
.58149 .65989 m .58331 .66108 L .5803 .66093 L F
.206 .671 .942 r
.20453 .54814 m .20626 .54893 L .20265 .54807 L F
.256 .701 .959 r
.20812 .54892 m .20626 .54893 L .20453 .54814 L F
.607 .423 .607 r
.48298 .65212 m .48295 .655 L .48037 .65508 L F
.545 .373 .599 r
.4852 .65441 m .48298 .65212 L .48477 .65111 L F
.4852 .65441 m .48295 .655 L .48298 .65212 L F
0 0 0 r
.59858 .63037 m .59861 .62969 L .59761 .6318 L F
.59858 .63037 m .59868 .62796 L .59861 .62969 L F
.249 .644 .962 r
.34546 .62156 m .34517 .62259 L .3435 .62145 L F
.34546 .62156 m .34696 .62268 L .34517 .62259 L F
.229 .737 .887 r
.36309 .59681 m .36173 .59656 L .35956 .59676 L F
.255 0 0 r
.36537 .59633 m .36173 .59656 L .36309 .59681 L F
.88 .669 .614 r
.59924 .6 m .5975 .59757 L .5995 .59763 L F
.338 0 .145 r
.5841 .58884 m .58159 .59048 L .58252 .58865 L F
.514 .543 .823 r
.73796 .52081 m .73985 .51863 L .73719 .51929 L F
.73796 .52081 m .74126 .52215 L .73985 .51863 L F
.293 0 0 r
.3238 .58476 m .32598 .58455 L .32452 .58406 L F
.985 .823 .599 r
.54031 .66374 m .53833 .66551 L .5398 .66234 L F
.54031 .66374 m .5398 .66632 L .53833 .66551 L F
.598 .169 .197 r
.48635 .67984 m .48583 .67788 L .48371 .67743 L F
0 0 .308 r
.48583 .67788 m .4864 .67872 L .48626 .67666 L F
.48583 .67788 m .48635 .67984 L .4864 .67872 L F
.487 .29 .539 r
.29784 .59782 m .29962 .59953 L .2997 .5972 L F
.29784 .59782 m .29757 .60012 L .29962 .59953 L F
.165 0 .336 r
.48655 .62644 m .48612 .62863 L .48803 .62557 L F
0 0 0 r
.48456 .69164 m .48746 .69113 L .48615 .69123 L F
.022 .566 .838 r
.48615 .69123 m .48746 .69113 L .48863 .69165 L F
.567 .373 .577 r
.46823 .66662 m .46795 .66827 L .46539 .66798 L F
.46539 .66798 m .46795 .66827 L .46823 .66662 L F
.681 .541 .688 r
.5461 .65514 m .54935 .65534 L .54862 .65198 L F
0 0 0 r
.5476 .6538 m .5461 .65514 L .54862 .65198 L F
.301 .274 .662 r
.5476 .6538 m .54829 .65718 L .5461 .65514 L F
.629 .621 .824 r
.39256 .59477 m .39648 .5967 L .39502 .59559 L F
.027 .421 .863 r
.39648 .5967 m .39694 .59603 L .39502 .59559 L F
.39648 .5967 m .39811 .5974 L .39694 .59603 L F
.656 .458 .604 r
.7814 .49959 m .7839 .49972 L .78371 .49726 L F
.635 .606 .803 r
.78371 .49726 m .78514 .49316 L .78265 .49403 L F
.78371 .49726 m .78635 .49682 L .78514 .49316 L F
.603 .419 .605 r
.7839 .49972 m .78635 .49682 L .78371 .49726 L F
.987 .75 .489 r
.51229 .66394 m .51098 .66274 L .50861 .66323 L F
.51229 .66394 m .51091 .66529 L .51098 .66274 L F
.263 0 0 r
.51313 .66486 m .51229 .66394 L .51453 .66333 L F
.51313 .66486 m .51091 .66529 L .51229 .66394 L F
.526 .351 .587 r
.51453 .66333 m .51229 .66394 L .5145 .66071 L F
.854 .589 .536 r
.47689 .66911 m .47698 .6665 L .47483 .66567 L F
.631 .397 .545 r
.47689 .66911 m .47941 .6685 L .47698 .6665 L F
.603 .541 .757 r
.40408 .60603 m .40633 .60571 L .40551 .60262 L F
.501 .253 .47 r
.40394 .60788 m .40633 .60571 L .40408 .60603 L F
.826 .585 .574 r
.60735 .58286 m .60884 .58582 L .60906 .58335 L F
.331 .778 .958 r
.45684 .70207 m .45551 .70261 L .45355 .70061 L F
.45684 .70207 m .45841 .7024 L .45551 .70261 L F
.225 0 .151 r
.52512 .65759 m .52234 .65978 L .52322 .65829 L F
.487 .127 .281 r
.56065 .58858 m .5632 .58833 L .56402 .58617 L F
.445 .149 .367 r
.5632 .58833 m .56615 .58524 L .56402 .58617 L F
.801 .723 .192 r
.61246 .64774 m .61209 .65113 L .61054 .64934 L F
0 0 0 r
.48793 .69583 m .48757 .69542 L .48924 .69514 L F
.298 .531 .908 r
.49008 .69369 m .49046 .69436 L .48924 .69514 L F
.698 .963 .719 r
.49008 .69369 m .48924 .69514 L .49046 .69436 L F
.49008 .69369 m .48793 .69583 L .48924 .69514 L F
.767 .649 .732 r
.72368 .48524 m .72486 .4885 L .72693 .4858 L F
.882 .79 .754 r
.28156 .81256 m .27757 .81488 L .27967 .81442 L F
0 0 .047 r
.28156 .81256 m .2822 .80903 L .2843 .81265 L F
.28156 .81256 m .28198 .81177 L .2822 .80903 L F
0 .193 .722 r
.28331 .81389 m .28156 .81256 L .27967 .81442 L F
.5 .169 .338 r
.28156 .81256 m .2843 .81265 L .28331 .81389 L F
0 .193 .722 r
.28331 .81389 m .28198 .81177 L .28156 .81256 L F
0 .234 .703 r
.53915 .62015 m .5404 .62098 L .53893 .61965 L F
.51 0 0 r
.53893 .61965 m .54028 .62095 L .53965 .62041 L F
0 0 .475 r
.53915 .62015 m .53893 .61965 L .53844 .61914 L F
.51 0 0 r
.53893 .61965 m .53965 .62041 L .53762 .61866 L F
0 0 .475 r
.53844 .61914 m .53893 .61965 L .53721 .61737 L F
.7 .625 .769 r
.66347 .50423 m .66248 .50549 L .66527 .50287 L F
.476 .406 .699 r
.54862 .65198 m .54935 .65534 L .55149 .6542 L F
.688 .334 .369 r
.54862 .65198 m .55149 .6542 L .5476 .6538 L F
.673 .199 .12 r
.39256 .59477 m .39113 .59584 L .38915 .59429 L F
0 0 0 r
.39347 .59455 m .39256 .59477 L .39502 .59559 L F
.39347 .59455 m .39113 .59584 L .39256 .59477 L F
.512 .215 .4 r
.49852 .64089 m .49753 .64507 L .495 .64517 L F
.585 .283 .423 r
.49998 .64477 m .49852 .64089 L .49993 .64424 L F
.49998 .64477 m .49753 .64507 L .49852 .64089 L F
.836 .631 .626 r
.60884 .58582 m .60881 .58837 L .6122 .58897 L F
.798 .565 .585 r
.60875 .59096 m .6122 .58897 L .60881 .58837 L F
.60875 .59096 m .61224 .59199 L .6122 .58897 L F
.488 .466 .76 r
.80297 .49289 m .80066 .49531 L .80077 .4931 L F
.518 .498 .774 r
.80297 .49289 m .80177 .49731 L .80066 .49531 L F
.517 .217 .396 r
.42025 .61237 m .41979 .61426 L .41741 .61452 L F
.428 .118 .336 r
.42239 .61202 m .41979 .61426 L .42025 .61237 L F
.996 .779 .489 r
.61366 .59236 m .61253 .5939 L .61348 .59698 L F
.471 .107 .264 r
.49059 .71528 m .49003 .7176 L .48714 .71787 L F
0 0 0 r
.49105 .71596 m .49059 .71528 L .4929 .71516 L F
.49105 .71596 m .49003 .7176 L .49059 .71528 L F
.779 .308 .122 r
.78386 .5271 m .78291 .52716 L .78078 .52551 L F
.563 .515 .759 r
.78078 .52551 m .78291 .52716 L .78286 .5268 L F
.59 .017 0 r
.78305 .52691 m .78386 .5271 L .78078 .52551 L F
.67 .593 .76 r
.78223 .52163 m .78286 .5268 L .78586 .52303 L F
.78286 .5268 m .78291 .52716 L .78308 .52692 L F
.59 .017 0 r
.7826 .52681 m .78305 .52691 L .78286 .5268 L F
.78157 .52607 m .78286 .5268 L .78078 .52551 L F
.7826 .52681 m .78286 .5268 L .78157 .52607 L F
0 .206 .687 r
.78236 .52633 m .78331 .52732 L .78157 .52607 L F
.78104 .52564 m .78157 .52607 L .78078 .52551 L F
.563 .515 .759 r
.78078 .52551 m .78286 .5268 L .78223 .52163 L F
0 .206 .687 r
.78236 .52633 m .78157 .52607 L .78104 .52564 L F
.67 .593 .76 r
.78291 .52716 m .78291 .52716 L .78291 .52716 L F
.78291 .52716 m .78291 .52716 L .78308 .52692 L F
.78286 .5268 m .78308 .52692 L .78586 .52303 L F
.629 .625 .828 r
.78386 .5271 m .78586 .52303 L .78308 .52692 L F
.78386 .5271 m .78308 .52692 L .78291 .52716 L F
.59 .017 0 r
.78331 .52732 m .78386 .5271 L .7826 .52681 L F
.249 0 0 r
.78331 .52732 m .78641 .52699 L .78386 .5271 L F
.717 .685 .819 r
.53899 .66867 m .54121 .66977 L .54298 .66726 L F
.761 .808 .89 r
.5868 .64008 m .58642 .64075 L .58411 .64076 L F
.771 .932 .575 r
.5868 .64008 m .58476 .64303 L .58642 .64075 L F
.265 .323 .736 r
.54534 .66608 m .54625 .66987 L .54773 .66823 L F
.484 .663 .941 r
.54625 .66987 m .54883 .67013 L .54773 .66823 L F
.575 .33 .508 r
.46506 .65482 m .46746 .65467 L .46781 .65223 L F
.431 .205 .468 r
.46781 .65223 m .46974 .654 L .46964 .65091 L F
.46781 .65223 m .46746 .65467 L .46974 .654 L F
.654 .604 .786 r
.45247 .69412 m .45033 .69516 L .44921 .69163 L F
.078 .359 .829 r
.55418 .62881 m .55482 .62818 L .55177 .62606 L F
.55418 .62881 m .55478 .62923 L .55482 .62818 L F
0 0 0 r
.54882 .59983 m .55184 .59846 L .55061 .59934 L F
0 0 .252 r
.54949 .60129 m .54882 .59983 L .55061 .59934 L F
.936 .755 .632 r
.6158 .6061 m .61468 .60269 L .61429 .60506 L F
.953 .718 .545 r
.61564 .60844 m .6158 .6061 L .61429 .60506 L F
.746 .651 .755 r
.78054 .51144 m .78532 .50953 L .78281 .50814 L F
.568 .282 .441 r
.78065 .51357 m .78532 .50953 L .78054 .51144 L F
.78065 .51357 m .78322 .51344 L .78532 .50953 L F
.68 .409 .505 r
.78532 .50953 m .78322 .51344 L .78659 .51304 L F
.671 .125 0 r
.54117 .63677 m .54502 .6395 L .54239 .63778 L F
.176 0 .245 r
.58137 .65211 m .58102 .65432 L .579 .65503 L F
.336 .285 .651 r
.58102 .65432 m .58142 .657 L .579 .65503 L F
.307 .284 .67 r
.579 .65503 m .58142 .657 L .57969 .65728 L F
.637 .399 .541 r
.44169 .67178 m .44425 .66929 L .44174 .66934 L F
.951 .643 .416 r
.58214 .64836 m .58382 .65164 L .58386 .64911 L F
.529 .225 .395 r
.48263 .65664 m .48057 .65718 L .48037 .65508 L F
.549 .21 .345 r
.48295 .655 m .48263 .65664 L .48037 .65508 L F
.366 .013 .227 r
.39636 .62609 m .39534 .62848 L .39315 .62901 L F
.309 0 .172 r
.39857 .62549 m .39534 .62848 L .39636 .62609 L F
.585 .421 .626 r
.50109 .68122 m .50259 .68093 L .5032 .67796 L F
.579 .291 .442 r
.50059 .68301 m .50259 .68093 L .50109 .68122 L F
.171 .348 .799 r
.51079 .64351 m .51174 .64215 L .50927 .64047 L F
.473 .476 .78 r
.5108 .64594 m .51174 .64215 L .51079 .64351 L F
.429 .411 .737 r
.79464 .52161 m .79502 .52502 L .79212 .52321 L F
.612 .806 .974 r
.45276 .71135 m .45412 .71252 L .45626 .71173 L F
.148 .652 .906 r
.4929 .71516 m .49661 .7159 L .49409 .71494 L F
.079 .603 .874 r
.49409 .71494 m .49661 .7159 L .49838 .71598 L F
.5 .191 .374 r
.3848 .61747 m .38714 .61716 L .38796 .61468 L F
.405 .046 .239 r
.38714 .61716 m .3904 .61451 L .38796 .61468 L F
.912 .557 .353 r
.59643 .59459 m .59525 .5961 L .59502 .59377 L F
.59643 .59459 m .5975 .59757 L .59525 .5961 L F
.423 .508 .841 r
.30169 .61812 m .30312 .61666 L .30186 .6174 L F
.30169 .61812 m .30465 .61995 L .30312 .61666 L F
.76 .294 .14 r
.57913 .65162 m .58105 .65361 L .58137 .65211 L F
.496 .506 .797 r
.58137 .65211 m .58382 .65164 L .58214 .64836 L F
.464 .343 .63 r
.58137 .65211 m .58374 .65409 L .58382 .65164 L F
.173 .375 .822 r
.57874 .64995 m .58107 .65179 L .58105 .65361 L F
.801 .708 .17 r
.58105 .65361 m .58104 .65421 L .58137 .65211 L F
.173 .375 .822 r
.58107 .65179 m .58184 .65241 L .58105 .65361 L F
.801 .708 .17 r
.58105 .65361 m .58102 .65432 L .58104 .65421 L F
.348 .316 .68 r
.29766 .6119 m .29868 .60795 L .29684 .60876 L F
.29766 .6119 m .29935 .61157 L .29868 .60795 L F
.706 .538 .658 r
.5032 .67796 m .50607 .68033 L .50554 .6774 L F
.5032 .67796 m .50259 .68093 L .50607 .68033 L F
.75 .6 .69 r
.55498 .66599 m .55111 .66932 L .55116 .66657 L F
.807 .843 .877 r
.68437 .49651 m .68305 .49975 L .68411 .49948 L F
.83 .864 .871 r
.68437 .49651 m .68411 .49948 L .68566 .49759 L F
.803 .695 .154 r
.56707 .64893 m .56696 .64809 L .56719 .64566 L F
0 0 .569 r
.56707 .64893 m .56872 .6512 L .56696 .64809 L F
.31 .628 .961 r
.40226 .58708 m .40396 .58721 L .40351 .58848 L F
.184 .482 .897 r
.40396 .58721 m .40498 .58883 L .40351 .58848 L F
.359 .31 .666 r
.53342 .66846 m .53419 .6716 L .53259 .67199 L F
.795 .567 .591 r
.51098 .66274 m .51453 .66333 L .5145 .66071 L F
.608 .549 .762 r
.5145 .66071 m .51597 .65763 L .51357 .65777 L F
.563 .053 0 r
.49149 .68086 m .48748 .68076 L .48893 .6809 L F
.356 .141 .443 r
.21323 .57921 m .21205 .57739 L .21382 .57632 L F
.21323 .57921 m .21167 .58023 L .21205 .57739 L F
.914 .965 .652 r
.48205 .6656 m .48046 .66946 L .48156 .66936 L F
.059 .38 .844 r
.48046 .66946 m .48265 .67055 L .48156 .66936 L F
.434 .119 .331 r
.41119 .61884 m .40938 .61788 L .41172 .61771 L F
.41119 .61884 m .40891 .61945 L .40938 .61788 L F
.677 .338 .393 r
.48757 .69542 m .48553 .69726 L .48334 .69522 L F
0 0 0 r
.48793 .69583 m .48553 .69726 L .48757 .69542 L F
.282 0 .234 r
.52666 .65182 m .52746 .65256 L .52961 .65232 L F
0 0 0 r
.53071 .64741 m .52961 .65232 L .5304 .64979 L F
.792 .997 .859 r
.52961 .65232 m .52746 .65256 L .5304 .64979 L F
.277 .718 .963 r
.35347 .5828 m .35543 .58274 L .35706 .5835 L F
.14 .597 .926 r
.35762 .58278 m .35706 .5835 L .35543 .58274 L F
.35762 .58278 m .35902 .58376 L .35706 .5835 L F
0 0 0 r
.33229 .58296 m .33451 .58248 L .3361 .58203 L F
.223 .735 .694 r
.3361 .58203 m .33657 .58185 L .33817 .58195 L F
.3361 .58203 m .33451 .58248 L .33657 .58185 L F
.179 0 0 r
.36801 .62548 m .3702 .62504 L .37191 .62361 L F
.385 0 .071 r
.3702 .62504 m .374 .62293 L .37191 .62361 L F
.653 .302 .365 r
.53602 .59906 m .53842 .59974 L .53948 .59706 L F
.405 .054 .252 r
.53842 .59974 m .54176 .59672 L .53948 .59706 L F
.509 0 0 r
.45626 .71173 m .45991 .7125 L .45831 .71253 L F
.307 0 0 r
.45991 .7125 m .4609 .71306 L .45831 .71253 L F
.45991 .7125 m .46309 .7137 L .4609 .71306 L F
.428 .211 .481 r
.46964 .65091 m .47242 .65133 L .47244 .64898 L F
.306 .083 .402 r
.46964 .65091 m .47152 .65306 L .47242 .65133 L F
.46964 .65091 m .46974 .654 L .47152 .65306 L F
.07 .031 .501 r
.44996 .68817 m .44867 .68618 L .45049 .68598 L F
.44996 .68817 m .44845 .69021 L .44867 .68618 L F
.449 .34 .638 r
.49253 .64839 m .49035 .64658 L .49278 .64593 L F
.49253 .64839 m .49064 .64908 L .49035 .64658 L F
.554 .355 .565 r
.51357 .65777 m .51597 .65763 L .5163 .65467 L F
.613 .377 .535 r
.51597 .65763 m .51921 .65409 L .5163 .65467 L F
0 .094 .578 r
.54916 .64633 m .55139 .64818 L .55167 .64855 L F
0 0 .461 r
.55139 .64818 m .55351 .65074 L .55167 .64855 L F
.666 .27 .286 r
.47349 .71498 m .47178 .71669 L .46951 .71482 L F
.701 .311 .306 r
.47519 .71552 m .47178 .71669 L .47349 .71498 L F
.441 .202 .454 r
.80177 .49731 m .80154 .49936 L .79921 .50006 L F
.518 .498 .774 r
.80297 .49289 m .80379 .49629 L .80177 .49731 L F
.328 .109 .422 r
.80379 .49629 m .80154 .49936 L .80177 .49731 L F
.335 0 0 r
.67386 .48758 m .67636 .48872 L .67493 .48805 L F
.816 .484 .427 r
.67348 .49 m .67636 .48872 L .67386 .48758 L F
.67348 .49 m .67679 .49081 L .67636 .48872 L F
.518 .44 .708 r
.43372 .68919 m .43545 .68575 L .43317 .68677 L F
.426 .563 .889 r
.21795 .5556 m .21696 .55737 L .2151 .55487 L F
.21795 .5556 m .21875 .55708 L .21696 .55737 L F
.735 .622 .733 r
.75814 .49036 m .75683 .48725 L .75779 .48856 L F
.462 .25 .505 r
.80154 .49936 m .79926 .50235 L .79921 .50006 L F
.81 .766 .812 r
.74431 .49448 m .74391 .49789 L .74221 .49687 L F
.482 .229 .453 r
.58818 .57414 m .59071 .57363 L .5908 .57159 L F
.563 .257 .407 r
.59071 .57363 m .59345 .57161 L .5908 .57159 L F
.601 .845 .99 r
.76538 .51055 m .7628 .51142 L .76183 .51045 L F
.508 .321 .561 r
.56301 .60204 m .56179 .60361 L .56424 .60296 L F
.56301 .60204 m .56078 .60518 L .56179 .60361 L F
.549 .771 .981 r
.49058 .63711 m .49455 .63833 L .49358 .63669 L F
.979 .712 .449 r
.49378 .63866 m .49455 .63833 L .49309 .63788 L F
.49297 .639 m .49414 .63994 L .49455 .63833 L F
.49283 .63906 m .49293 .63913 L .49297 .639 L F
.49293 .63913 m .49414 .63994 L .49297 .639 L F
.014 .133 .644 r
.49414 .63994 m .49377 .63777 L .49455 .63833 L F
.49377 .63777 m .49358 .63669 L .49393 .63727 L F
.49377 .63777 m .49393 .63727 L .49455 .63833 L F
.49414 .63994 m .49448 .63946 L .49396 .63886 L F
.654 .475 .629 r
.49146 .63987 m .49116 .6414 L .49059 .64195 L F
.796 .56 .581 r
.49174 .64086 m .49414 .63994 L .49331 .63938 L F
.49168 .64115 m .49414 .63994 L .49174 .64086 L F
.4908 .64182 m .49414 .63994 L .49116 .6414 L F
.49143 .64093 m .49331 .63938 L .49293 .63913 L F
.49059 .64195 m .49088 .64167 L .49143 .64093 L F
.49088 .64167 m .49331 .63938 L .49143 .64093 L F
.49243 .63957 m .49293 .63913 L .49283 .63906 L F
.367 .024 .245 r
.49506 .63866 m .49248 .63953 L .49283 .63906 L F
.49248 .63953 m .49146 .63987 L .49283 .63906 L F
.796 .56 .581 r
.4908 .64182 m .4943 .64258 L .49414 .63994 L F
.49059 .64195 m .49084 .64199 L .4908 .64182 L F
.49084 .64199 m .4943 .64258 L .4908 .64182 L F
.849 .649 .633 r
.49192 .64217 m .4944 .64479 L .4943 .64258 L F
.49193 .64284 m .4944 .64479 L .49192 .64217 L F
.49075 .64207 m .4944 .64479 L .49084 .64199 L F
.49059 .64195 m .49054 .64462 L .4944 .64479 L F
0 0 .04 r
.49411 .64079 m .49329 .64468 L .49191 .64104 L F
.4919 .6407 m .49191 .64104 L .49177 .64069 L F
.49411 .64079 m .49191 .64104 L .4919 .6407 L F
.849 .649 .633 r
.49084 .64199 m .49193 .64284 L .49192 .64217 L F
.49059 .64195 m .49075 .64207 L .49084 .64199 L F
.654 .475 .629 r
.49119 .64168 m .49329 .64468 L .49151 .64464 L F
.49116 .6414 m .49129 .64159 L .49119 .64168 L F
.49129 .64159 m .49329 .64468 L .49119 .64168 L F
.49096 .64245 m .49151 .64464 L .49054 .64462 L F
.49116 .6414 m .49151 .64464 L .49096 .64245 L F
0 0 .04 r
.49185 .64031 m .49177 .64069 L .49146 .63987 L F
.654 .475 .629 r
.49146 .63987 m .49177 .64069 L .49116 .6414 L F
.501 .295 .532 r
.49146 .63987 m .49059 .64195 L .49185 .64031 L F
.367 .024 .245 r
.49248 .63953 m .49243 .63957 L .49146 .63987 L F
.501 .295 .532 r
.49146 .63987 m .49185 .64031 L .49243 .63957 L F
.367 .024 .245 r
.49243 .63957 m .49191 .64003 L .49146 .63987 L F
.501 .295 .532 r
.49146 .63987 m .49243 .63957 L .49283 .63906 L F
0 0 .04 r
.49191 .64003 m .49185 .64031 L .49146 .63987 L F
.796 .56 .581 r
.49059 .64195 m .49293 .63913 L .49243 .63957 L F
0 0 .04 r
.49411 .64079 m .49177 .64069 L .49191 .64003 L F
.796 .56 .581 r
.49116 .6414 m .49168 .64115 L .49174 .64086 L F
.49059 .64195 m .4908 .64182 L .49116 .6414 L F
.654 .475 .629 r
.49177 .64069 m .49329 .64468 L .49116 .6414 L F
.49116 .6414 m .49054 .64462 L .49059 .64195 L F
.367 .024 .245 r
.49283 .63941 m .49255 .64025 L .49191 .64003 L F
.49283 .63941 m .49191 .64003 L .49248 .63953 L F
.339 .214 .56 r
.49414 .63994 m .49561 .64135 L .49506 .63866 L F
.49414 .63994 m .4943 .64258 L .49561 .64135 L F
.367 .024 .245 r
.49506 .63866 m .49411 .64079 L .49294 .64038 L F
.49309 .6399 m .49294 .64038 L .49255 .64025 L F
.49506 .63866 m .49294 .64038 L .49309 .6399 L F
.014 .133 .644 r
.49448 .63946 m .49506 .63866 L .49396 .63886 L F
.367 .024 .245 r
.49506 .63866 m .49255 .64025 L .49283 .63941 L F
.014 .133 .644 r
.49396 .63886 m .49506 .63866 L .49358 .63669 L F
.979 .712 .449 r
.49283 .63906 m .49378 .63866 L .49058 .63711 L F
.49378 .63866 m .49309 .63788 L .49058 .63711 L F
.394 .369 .713 r
.42781 .69998 m .43006 .70366 L .4293 .69985 L F
.42781 .69998 m .4285 .70307 L .43006 .70366 L F
.532 .853 .997 r
.75715 .51205 m .75385 .5119 L .75596 .51067 L F
.707 .827 .939 r
.7594 .51075 m .75715 .51205 L .75596 .51067 L F
.994 .762 .473 r
.75683 .48725 m .75669 .48484 L .75337 .48466 L F
.75683 .48725 m .75401 .48514 L .75424 .48596 L F
.75683 .48725 m .75571 .48668 L .75669 .48484 L F
.628 .231 .271 r
.75669 .48484 m .75599 .48616 L .75947 .48626 L F
.75599 .48616 m .75571 .48668 L .75677 .48656 L F
.75599 .48616 m .75677 .48656 L .75947 .48626 L F
.994 .762 .473 r
.75401 .48514 m .75337 .48466 L .75352 .48489 L F
.75401 .48514 m .75352 .48489 L .75424 .48596 L F
.602 .258 .359 r
.53253 .6781 m .52935 .67935 L .53009 .678 L F
.62 .548 .752 r
.52935 .67935 m .53131 .67649 L .53009 .678 L F
0 0 0 r
.53131 .67649 m .52988 .67832 L .53009 .678 L F
.751 .861 .427 r
.61392 .62473 m .61471 .62381 L .61458 .62187 L F
.61392 .62473 m .61367 .62578 L .61471 .62381 L F
.875 .553 .438 r
.47577 .67709 m .47731 .67523 L .47453 .6743 L F
.47577 .67709 m .4778 .67805 L .47731 .67523 L F
.613 .377 .535 r
.51597 .65763 m .51979 .65926 L .51921 .65409 L F
.69 .432 .528 r
.51921 .65409 m .52307 .65889 L .52162 .65376 L F
.51921 .65409 m .51979 .65926 L .52307 .65889 L F
.561 .672 .913 r
.7508 .48815 m .75236 .48979 L .74863 .49044 L F
.609 .252 .338 r
.75236 .48979 m .74914 .49092 L .74909 .49086 L F
.75077 .49007 m .74909 .49086 L .74863 .49044 L F
.75236 .48979 m .74909 .49086 L .75077 .49007 L F
.74914 .49092 m .74852 .49091 L .74863 .49044 L F
.245 .39 .811 r
.74868 .49091 m .74898 .49091 L .74956 .4887 L F
.74868 .49091 m .74875 .49177 L .74898 .49091 L F
.609 .252 .338 r
.74914 .49092 m .74846 .49116 L .74852 .49091 L F
.841 .986 .865 r
.74956 .4887 m .74898 .49091 L .74846 .49116 L F
.74898 .49091 m .74875 .49177 L .74846 .49116 L F
.245 .39 .811 r
.74857 .48953 m .74868 .49091 L .74956 .4887 L F
.755 .643 .737 r
.72147 .48793 m .72486 .4885 L .72368 .48524 L F
0 0 0 r
.37152 .59567 m .36978 .59584 L .36759 .59597 L F
.37345 .59543 m .36978 .59584 L .37152 .59567 L F
.824 .946 .902 r
.77819 .52929 m .77989 .52839 L .78138 .52884 L F
.246 .372 .794 r
.78501 .52622 m .78509 .52664 L .78331 .52732 L F
.2 .316 .759 r
.78403 .52727 m .78619 .52742 L .78331 .52732 L F
.249 0 0 r
.78331 .52732 m .78619 .52742 L .78641 .52699 L F
.246 .372 .794 r
.78509 .52664 m .78552 .52911 L .78331 .52732 L F
.373 .138 .424 r
.78331 .52732 m .77989 .52839 L .78199 .52782 L F
.78331 .52732 m .78199 .52782 L .78403 .52727 L F
.78331 .52732 m .78138 .52884 L .77989 .52839 L F
.954 .755 .596 r
.61465 .60043 m .61348 .59698 L .61335 .59994 L F
.939 .677 .513 r
.61352 .60206 m .61465 .60043 L .61335 .59994 L F
.61352 .60206 m .61468 .60269 L .61465 .60043 L F
.745 .687 .795 r
.56424 .60296 m .56748 .60352 L .56716 .60035 L F
.392 .2 .497 r
.56748 .60352 m .56969 .60018 L .56716 .60035 L F
.386 .178 .47 r
.56748 .60352 m .56953 .6033 L .56825 .60437 L F
.713 .729 .863 r
.56825 .60437 m .56839 .60431 L .56913 .60364 L F
.66 .423 .549 r
.57291 .60009 m .57005 .60301 L .56969 .60018 L F
.57291 .60009 m .57265 .60252 L .57005 .60301 L F
.713 .729 .863 r
.56987 .60304 m .57265 .60252 L .57119 .60192 L F
.56931 .60352 m .57265 .60252 L .56987 .60304 L F
.66 .423 .549 r
.57005 .60301 m .57265 .60252 L .56979 .60327 L F
.57005 .60301 m .56979 .60327 L .56979 .60307 L F
.57005 .60301 m .56979 .60307 L .56969 .60018 L F
.713 .729 .863 r
.56979 .60307 m .57119 .60192 L .57112 .60189 L F
.56953 .6033 m .56981 .60307 L .56979 .60307 L F
.56981 .60307 m .57119 .60192 L .56979 .60307 L F
.312 .172 .524 r
.57106 .60187 m .56969 .60018 L .56979 .60307 L F
.713 .729 .863 r
.56839 .60431 m .57119 .60192 L .56953 .6033 L F
.312 .172 .524 r
.57106 .60187 m .56979 .60307 L .56979 .60327 L F
.713 .729 .863 r
.56839 .60431 m .56856 .60424 L .56931 .60352 L F
.56856 .60424 m .57265 .60252 L .56931 .60352 L F
.386 .178 .47 r
.56748 .60352 m .56953 .6033 L .56825 .60437 L F
.56953 .6033 m .56979 .60327 L .56825 .60437 L F
.56953 .6033 m .56979 .60327 L .56825 .60437 L F
.392 .2 .497 r
.56748 .60352 m .56953 .6033 L .56969 .60018 L F
.56969 .60018 m .56979 .60327 L .56748 .60352 L F
.713 .729 .863 r
.56825 .60437 m .56913 .60364 L .57106 .60187 L F
.56839 .60431 m .57112 .60189 L .57106 .60187 L F
.392 .2 .497 r
.56953 .6033 m .56979 .60327 L .56979 .60307 L F
.56953 .6033 m .56979 .60307 L .56969 .60018 L F
.597 .254 .36 r
.76364 .48861 m .76629 .49024 L .76399 .48997 L F
0 0 .481 r
.61396 .63305 m .61264 .63202 L .61419 .6307 L F
.61396 .63305 m .6132 .63464 L .61264 .63202 L F
.582 .705 .927 r
.77515 .49149 m .77687 .49369 L .7792 .49311 L F
.644 .615 .806 r
.77687 .49369 m .7802 .49487 L .7792 .49311 L F
.719 .425 .479 r
.48482 .71506 m .48486 .71692 L .4812 .7168 L F
.736 .439 .477 r
.48482 .71506 m .48714 .71787 L .48486 .71692 L F
0 .007 .546 r
.57966 .64323 m .58091 .64573 L .58004 .64652 L F
.848 .389 .082 r
.5784 .64356 m .57966 .64323 L .57812 .64208 L F
.57975 .64477 m .58073 .64566 L .58004 .64408 L F
.58073 .64566 m .58091 .64573 L .57966 .64323 L F
0 .007 .546 r
.58091 .64573 m .58099 .64589 L .58093 .64593 L F
.58091 .64573 m .58093 .64593 L .58004 .64652 L F
.865 .424 .145 r
.5784 .64356 m .58007 .6466 L .58099 .64589 L F
0 0 .487 r
.58088 .64477 m .57955 .64524 L .58095 .64347 L F
.57955 .64524 m .57954 .64524 L .57956 .64521 L F
.57955 .64524 m .57956 .64521 L .58095 .64347 L F
.848 .389 .082 r
.5784 .64356 m .57975 .64477 L .57966 .64323 L F
.57975 .64477 m .58004 .64408 L .57966 .64323 L F
.58073 .64566 m .58099 .64589 L .58091 .64573 L F
.957 .8 .645 r
.58063 .643 m .57956 .64521 L .57918 .64091 L F
.57956 .64521 m .57954 .64524 L .57953 .6452 L F
.57956 .64521 m .57953 .6452 L .57918 .64091 L F
.58095 .64347 m .58071 .64378 L .58063 .643 L F
.58071 .64378 m .57954 .64524 L .58063 .643 L F
.85 .602 .564 r
.49074 .67648 m .49408 .67535 L .48998 .67442 L F
.49074 .67648 m .49349 .67738 L .49408 .67535 L F
.293 .049 .362 r
.49408 .67535 m .49349 .67738 L .4958 .67447 L F
.4958 .67447 m .49349 .67738 L .49408 .67535 L F
.49408 .67535 m .49349 .67738 L .4958 .67447 L F
.235 .718 .931 r
.3831 .59373 m .38379 .5938 L .38174 .59315 L F
.076 .632 .808 r
.38559 .59342 m .38174 .59315 L .38379 .5938 L F
.789 .556 .584 r
.72606 .49419 m .72289 .4963 L .72507 .49315 L F
.72606 .49419 m .72599 .49698 L .72289 .4963 L F
.988 .762 .373 r
.72606 .49419 m .72524 .49553 L .72507 .49315 L F
.72606 .49419 m .72599 .49698 L .72524 .49553 L F
.1 0 .188 r
.48153 .63698 m .48275 .63823 L .48376 .63649 L F
.48153 .63698 m .48123 .63936 L .48275 .63823 L F
.701 .311 .306 r
.47519 .71552 m .47538 .71693 L .47178 .71669 L F
.068 0 0 r
.57735 .59201 m .5762 .59376 L .5745 .59417 L F
0 0 0 r
.57735 .59201 m .57817 .59271 L .5762 .59376 L F
.57735 .59201 m .57927 .59073 L .57817 .59271 L F
.867 .653 .122 r
.59712 .60898 m .59673 .60802 L .59661 .60549 L F
.696 .331 0 r
.59712 .60898 m .59765 .61044 L .59673 .60802 L F
.59712 .60898 m .59809 .61124 L .59765 .61044 L F
.421 .444 .779 r
.44996 .68817 m .44921 .69163 L .44845 .69021 L F
.446 .832 .986 r
.76497 .48139 m .76725 .48098 L .76841 .48161 L F
.506 .833 .999 r
.76725 .48098 m .77092 .48131 L .76841 .48161 L F
.76725 .48098 m .76977 .48048 L .77092 .48131 L F
.596 .35 .514 r
.76725 .48098 m .76995 .48323 L .76977 .48053 L F
.76725 .48098 m .76977 .48053 L .76977 .48048 L F
.446 .832 .986 r
.76468 .48137 m .76725 .48098 L .76497 .48139 L F
.709 .308 .287 r
.47015 .67822 m .46666 .6795 L .46652 .67722 L F
.47015 .67822 m .46879 .6801 L .46666 .6795 L F
.47 .039 .136 r
.47211 .67943 m .46879 .6801 L .47015 .67822 L F
.303 0 .045 r
.37949 .61958 m .38184 .61911 L .38251 .61797 L F
.592 .268 .39 r
.38184 .61911 m .3848 .61747 L .38251 .61797 L F
.714 .314 .289 r
.48334 .69522 m .48211 .69641 L .48405 .6933 L F
.48334 .69522 m .48553 .69726 L .48211 .69641 L F
0 0 0 r
.54157 .70334 m .54311 .70268 L .54422 .70091 L F
.52 .816 .999 r
.54311 .70268 m .54704 .70085 L .54422 .70091 L F
.637 .399 .541 r
.44169 .67178 m .44428 .67177 L .44425 .66929 L F
.501 .293 .529 r
.44425 .66929 m .44651 .67127 L .44728 .6688 L F
.44425 .66929 m .44428 .67177 L .44651 .67127 L F
.429 .861 .931 r
.76173 .52425 m .76536 .52363 L .76456 .52275 L F
.516 .745 .978 r
.76536 .52363 m .76679 .52195 L .76456 .52275 L F
.76536 .52363 m .76763 .52326 L .76679 .52195 L F
.633 .509 .693 r
.52517 .67166 m .5229 .67468 L .52287 .67211 L F
.712 .62 .753 r
.52517 .67166 m .5229 .67468 L .52287 .67211 L F
.729 .866 .946 r
.56925 .62592 m .56795 .62686 L .56668 .62559 L F
.503 .722 .971 r
.78865 .48465 m .78703 .48629 L .78615 .48494 L F
.78865 .48465 m .78954 .48604 L .78703 .48629 L F
.44 .545 .867 r
.41819 .59397 m .41634 .59416 L .41467 .59109 L F
.264 0 0 r
.32598 .58455 m .32831 .58435 L .33008 .5832 L F
.018 0 0 r
.32831 .58435 m .33229 .58296 L .33008 .5832 L F
.326 0 0 r
.33814 .64571 m .33663 .64603 L .33443 .64571 L F
.315 .803 .783 r
.33878 .6453 m .33814 .64571 L .34019 .646 L F
.33878 .6453 m .33663 .64603 L .33814 .64571 L F
.48 .155 .337 r
.30755 .59115 m .30982 .59088 L .31053 .58916 L F
.392 .073 .301 r
.30982 .59088 m .31251 .58862 L .31053 .58916 L F
.004 0 .435 r
.61248 .64173 m .611 .64043 L .61249 .63932 L F
.61248 .64173 m .6109 .64359 L .611 .64043 L F
.484 .171 .359 r
.5825 .57914 m .58518 .57707 L .58299 .57766 L F
.411 .172 .439 r
.30041 .5952 m .30168 .59653 L .30206 .59432 L F
.30041 .5952 m .2997 .5972 L .30168 .59653 L F
.683 .741 .895 r
.67931 .50203 m .68011 .50396 L .68321 .50274 L F
.874 .529 .394 r
.55584 .65732 m .55756 .66017 L .5596 .66061 L F
.973 .7 .452 r
.55814 .66199 m .5596 .66061 L .55756 .66017 L F
.55814 .66199 m .55976 .66299 L .5596 .66061 L F
.615 .642 .854 r
.29897 .63275 m .30422 .63485 L .30108 .63244 L F
0 .323 .745 r
.30422 .63485 m .30304 .63384 L .30108 .63244 L F
.616 .374 .527 r
.46069 .678 m .45826 .68016 L .45982 .67888 L F
.46069 .678 m .4607 .68027 L .45826 .68016 L F
.602 .363 .526 r
.46384 .67943 m .46069 .678 L .46438 .67731 L F
.46384 .67943 m .4607 .68027 L .46069 .678 L F
.235 .718 .931 r
.3831 .59373 m .38174 .59315 L .37898 .59369 L F
.155 .337 .794 r
.48169 .676 m .48408 .67852 L .48371 .67743 L F
.556 .764 .975 r
.39434 .58476 m .39357 .58655 L .39216 .58534 L F
.39434 .58476 m .39575 .58605 L .39357 .58655 L F
0 .454 .73 r
.40894 .59049 m .41106 .591 L .41261 .59146 L F
.492 .869 .979 r
.41261 .59146 m .41327 .59035 L .41467 .59109 L F
.41261 .59146 m .41106 .591 L .41327 .59035 L F
.725 .605 .723 r
.48697 .66283 m .4887 .66635 L .49103 .66289 L F
0 .434 .798 r
.55177 .62606 m .55039 .62526 L .5494 .62488 L F
.462 0 0 r
.55177 .62606 m .55301 .62711 L .55039 .62526 L F
.55177 .62606 m .55482 .62818 L .55301 .62711 L F
.469 .413 .713 r
.77874 .50317 m .7816 .50499 L .78168 .50136 L F
.77874 .50317 m .77939 .50548 L .7816 .50499 L F
.871 .826 .801 r
.2562 .68349 m .25411 .68689 L .25225 .68557 L F
.366 .173 .481 r
.25602 .68612 m .25411 .68689 L .2562 .68349 L F
.552 .788 .987 r
.25225 .68557 m .25411 .68689 L .25602 .68612 L F
.678 .346 .406 r
.49503 .71227 m .49728 .71417 L .49966 .71175 L F
.805 .532 .525 r
.49728 .71417 m .50021 .71455 L .49966 .71175 L F
.525 .684 .939 r
.29897 .63275 m .29963 .63047 L .2974 .63092 L F
.29897 .63275 m .30108 .63244 L .29963 .63047 L F
.599 .85 .992 r
.55207 .64065 m .5484 .64051 L .55059 .63966 L F
.5484 .64051 m .55207 .64065 L .55059 .63966 L F
.957 .686 .483 r
.61583 .61331 m .61671 .61192 L .61578 .61141 L F
.61583 .61331 m .61664 .61383 L .61671 .61192 L F
.512 0 0 r
.55848 .61988 m .56117 .62129 L .56189 .62078 L F
.733 .206 0 r
.56117 .62129 m .56317 .62228 L .56189 .62078 L F
.238 .397 .82 r
.56026 .63716 m .56194 .63633 L .55884 .63415 L F
.56026 .63716 m .56185 .63769 L .56194 .63633 L F
.515 .267 .476 r
.44728 .6688 m .44947 .66843 L .44981 .66632 L F
.477 .233 .465 r
.44981 .66632 m .45172 .66787 L .45197 .66579 L F
.44981 .66632 m .44947 .66843 L .45172 .66787 L F
.625 .337 .461 r
.49326 .66285 m .49636 .66064 L .49232 .66017 L F
.624 .321 .436 r
.49648 .6613 m .49593 .66344 L .49326 .66285 L F
.625 .337 .461 r
.49326 .66285 m .49593 .66344 L .49636 .66064 L F
.126 .303 .773 r
.49466 .65755 m .49636 .66064 L .4969 .65935 L F
.569 .462 .693 r
.49593 .66344 m .4969 .65935 L .49636 .66064 L F
.543 .003 0 r
.35902 .58376 m .36141 .58469 L .36297 .58398 L F
0 0 0 r
.36297 .58398 m .36352 .58392 L .36514 .58397 L F
.36297 .58398 m .36141 .58469 L .36352 .58392 L F
0 .016 .575 r
.55351 .65074 m .55434 .65446 L .55473 .65149 L F
.544 .504 .762 r
.49103 .66289 m .49326 .66285 L .49232 .66017 L F
.726 .626 .746 r
.45826 .68016 m .45955 .68355 L .45628 .68362 L F
.737 .507 .58 r
.45955 .68355 m .45607 .68588 L .45628 .68362 L F
.45955 .68355 m .4595 .68601 L .45607 .68588 L F
.255 .347 .766 r
.46103 .68262 m .45955 .68355 L .45826 .68016 L F
0 0 .379 r
.46073 .68484 m .45955 .68355 L .46103 .68262 L F
.46073 .68484 m .4595 .68601 L .45955 .68355 L F
.666 .685 .858 r
.7802 .49487 m .78265 .49403 L .7792 .49311 L F
.948 .946 .627 r
.46485 .70036 m .46423 .69988 L .46566 .69876 L F
.573 .071 .023 r
.46566 .69876 m .46423 .69988 L .46773 .69997 L F
.511 .499 .78 r
.29592 .60632 m .29684 .60876 L .29868 .60795 L F
.496 .23 .441 r
.58778 .57671 m .59071 .57363 L .58818 .57414 L F
.523 .242 .43 r
.58518 .57707 m .58778 .57671 L .58818 .57414 L F
.144 0 0 r
.37876 .63515 m .37982 .63411 L .38205 .63362 L F
.324 0 0 r
.52219 .64652 m .52016 .64654 L .52277 .64639 L F
.52219 .64652 m .51901 .64795 L .52016 .64654 L F
.484 .28 .527 r
.5593 .67505 m .56004 .67108 L .55843 .67227 L F
.5593 .67505 m .56184 .67196 L .56004 .67108 L F
.5593 .67505 m .56188 .67457 L .56184 .67196 L F
0 .366 .808 r
.73185 .50912 m .73582 .51169 L .73442 .51196 L F
.392 0 0 r
.53527 .7081 m .53906 .70663 L .53652 .70717 L F
.941 .843 .406 r
.59959 .61684 m .5993 .62083 L .5977 .61981 L F
.923 .645 .496 r
.5993 .62083 m .59762 .62199 L .5977 .61981 L F
.5993 .62083 m .59934 .62294 L .59762 .62199 L F
.476 .757 .992 r
.77936 .48283 m .77785 .48422 L .77662 .48315 L F
.77936 .48283 m .78039 .484 L .77785 .48422 L F
.712 .603 .733 r
.77949 .50819 m .78054 .51144 L .78281 .50814 L F
.608 .627 .845 r
.34104 .62054 m .33717 .61797 L .34034 .61878 L F
.191 .416 .85 r
.34169 .61909 m .34104 .62054 L .34034 .61878 L F
.254 .494 .893 r
.34169 .61909 m .3435 .62145 L .34104 .62054 L F
.539 .346 .568 r
.33492 .60606 m .33489 .60847 L .33264 .60885 L F
.437 .248 .524 r
.33489 .60847 m .33273 .61142 L .33264 .60885 L F
.705 .543 .666 r
.55976 .61104 m .56263 .61192 L .56318 .60915 L F
.655 .625 .808 r
.39811 .5974 m .39969 .60068 L .4019 .59983 L F
.505 .017 .031 r
.78269 .50124 m .7814 .49959 L .78168 .50136 L F
.78269 .50124 m .7839 .49972 L .7814 .49959 L F
.57 .215 .327 r
.49919 .66059 m .49648 .6613 L .49726 .6605 L F
.5 .788 .997 r
.32862 .64547 m .32991 .64382 L .32698 .64283 L F
.32862 .64547 m .33063 .64499 L .32991 .64382 L F
.834 .959 .892 r
.30939 .63307 m .30869 .63497 L .31085 .63278 L F
.30939 .63307 m .30738 .6345 L .30869 .63497 L F
.735 .582 .684 r
.45596 .68077 m .45628 .68362 L .45432 .6832 L F
.726 .626 .746 r
.45826 .68016 m .45628 .68362 L .45596 .68077 L F
.571 .197 .293 r
.39851 .60884 m .39728 .61087 L .40057 .61024 L F
.587 .176 .23 r
.40057 .61024 m .40103 .60901 L .39851 .60884 L F
.75 .513 .571 r
.75317 .48221 m .75669 .48484 L .75657 .48267 L F
.599 .366 .534 r
.75669 .48484 m .75913 .48458 L .75657 .48267 L F
.636 .346 .461 r
.75657 .48267 m .75913 .48458 L .75913 .48258 L F
.529 .347 .578 r
.33716 .60555 m .33489 .60847 L .33492 .60606 L F
.648 .548 .728 r
.47764 .65885 m .47799 .6603 L .47473 .66035 L F
.554 .547 .801 r
.47841 .66205 m .47473 .66035 L .47799 .6603 L F
.435 0 .065 r
.50256 .6565 m .50662 .65428 L .50266 .65435 L F
.50256 .6565 m .50523 .65636 L .50662 .65428 L F
.599 .554 .775 r
.50662 .65428 m .50847 .65107 L .50637 .65141 L F
.678 .696 .86 r
.66743 .50217 m .67091 .50252 L .66987 .49926 L F
.709 .658 .798 r
.66987 .49926 m .67091 .50252 L .67343 .50202 L F
.402 .433 .779 r
.30095 .61469 m .30146 .6109 L .29935 .61157 L F
.30095 .61469 m .30231 .6141 L .30146 .6109 L F
.365 .34 .697 r
.30095 .61469 m .30312 .61666 L .30231 .6141 L F
.34 .337 .709 r
.30186 .6174 m .30312 .61666 L .30095 .61469 L F
.144 .608 .926 r
.76766 .51096 m .76862 .51172 L .76538 .51055 L F
.341 .742 .983 r
.77117 .5116 m .76862 .51172 L .76766 .51096 L F
.312 .172 .524 r
.57106 .60187 m .57155 .59945 L .56969 .60018 L F
.4 .511 .856 r
.79809 .4871 m .79618 .48898 L .79575 .48723 L F
.79809 .4871 m .79925 .49007 L .79618 .48898 L F
.459 .484 .797 r
.79618 .48898 m .79925 .49007 L .79719 .49025 L F
.736 .561 .656 r
.58411 .64076 m .58476 .64303 L .5868 .64008 L F
.419 .812 .986 r
.37454 .58437 m .37678 .58402 L .3783 .58461 L F
.157 .677 .885 r
.37678 .58402 m .38063 .58445 L .3783 .58461 L F
.44 .27 .553 r
.29586 .60254 m .29743 .60215 L .29757 .60012 L F
.508 .41 .68 r
.29592 .60632 m .29743 .60215 L .29586 .60254 L F
.575 .311 .478 r
.31179 .64281 m .30917 .64357 L .30996 .64002 L F
.691 .674 .829 r
.30869 .64384 m .30912 .64492 L .31085 .64263 L F
.575 .311 .478 r
.31179 .64281 m .30909 .64394 L .30917 .64357 L F
.691 .674 .829 r
.31085 .64263 m .31041 .64321 L .31179 .64281 L F
.31041 .64321 m .30912 .64492 L .31179 .64281 L F
.457 .203 .439 r
.30933 .64068 m .30917 .64357 L .30691 .64324 L F
.30996 .64002 m .30979 .6408 L .30933 .64068 L F
.30979 .6408 m .30917 .64357 L .30933 .64068 L F
.575 .311 .478 r
.31179 .64281 m .30996 .64002 L .3123 .64096 L F
.988 .858 .494 r
.31145 .64206 m .31179 .64281 L .3123 .64096 L F
.468 .228 .466 r
.31412 .63987 m .31179 .64281 L .3123 .64096 L F
.988 .858 .494 r
.31145 .64206 m .31179 .64281 L .3123 .64096 L F
.913 .934 .809 r
.31244 .64133 m .31179 .64281 L .31412 .63987 L F
.921 .948 .796 r
.31145 .64206 m .31179 .64281 L .31244 .64133 L F
.572 .188 .275 r
.31244 .64133 m .31217 .64357 L .31145 .64206 L F
0 0 .323 r
.31145 .64206 m .31217 .64357 L .31194 .64304 L F
.442 0 .022 r
.31118 .64151 m .31145 .64206 L .31199 .64137 L F
.308 .64208 m .31199 .64137 L .31136 .64121 L F
.308 .64208 m .3123 .64096 L .30996 .64002 L F
.31136 .64121 m .31199 .64137 L .3123 .64096 L F
.88 .691 .643 r
.31244 .64133 m .31145 .64206 L .31153 .63856 L F
0 0 .323 r
.31145 .64206 m .31194 .64304 L .31098 .64079 L F
.442 0 .022 r
.308 .64208 m .31145 .64206 L .31118 .64151 L F
.457 .203 .439 r
.30917 .64357 m .30872 .64382 L .30691 .64324 L F
.691 .674 .829 r
.308 .64208 m .30869 .64384 L .31085 .64263 L F
.457 .203 .439 r
.30917 .64357 m .30909 .64394 L .30872 .64382 L F
.442 0 .022 r
.308 .64208 m .30996 .64002 L .30822 .63962 L F
.835 .756 .775 r
.50835 .6651 m .50657 .66651 L .50861 .66323 L F
.446 .855 .683 r
.54964 .59384 m .54795 .59493 L .54642 .59569 L F
.791 .453 .416 r
.50259 .68093 m .50541 .68296 L .50607 .68033 L F
.689 .582 .73 r
.50554 .6774 m .50607 .68033 L .50889 .67771 L F
0 0 .45 r
.55598 .63097 m .55482 .62818 L .55478 .62923 L F
.871 .826 .801 r
.2562 .68349 m .25225 .68557 L .25602 .68612 L F
.49 .274 .512 r
.25833 .68309 m .25602 .68612 L .2562 .68349 L F
.25833 .68309 m .25602 .68612 L .2562 .68349 L F
.609 .575 .79 r
.50772 .76938 m .50895 .77296 L .51135 .7723 L F
.59 .422 .622 r
.66492 .48834 m .66264 .49128 L .66512 .49064 L F
.657 .557 .731 r
.66264 .49128 m .66612 .4941 L .66512 .49064 L F
.66264 .49128 m .66599 .49542 L .66612 .4941 L F
.198 .693 .918 r
.33817 .58195 m .34028 .58197 L .34185 .5825 L F
.039 .582 .845 r
.34028 .58197 m .3439 .58277 L .34185 .5825 L F
.576 .306 .47 r
.42542 .60875 m .42755 .61068 L .42508 .61118 L F
.42542 .60875 m .42784 .60846 L .42755 .61068 L F
.703 .711 .854 r
.38559 .59342 m .38895 .5951 L .38915 .59429 L F
.61 .8 .972 r
.55613 .67331 m .55693 .67123 L .55503 .67088 L F
.55613 .67331 m .55843 .67227 L .55693 .67123 L F
.566 .719 .944 r
.74755 .52613 m .75104 .52742 L .75014 .52636 L F
.641 .889 .985 r
.75104 .52742 m .75261 .52564 L .75014 .52636 L F
.75104 .52742 m .75404 .5265 L .75261 .52564 L F
.344 0 .208 r
.39078 .62928 m .39038 .63056 L .3882 .63103 L F
.444 .076 .244 r
.39078 .62928 m .39245 .63029 L .39038 .63056 L F
.447 .073 .234 r
.39315 .62901 m .39245 .63029 L .39078 .62928 L F
.701 .685 .832 r
.77949 .50819 m .7816 .50499 L .77939 .50548 L F
.628 .939 .712 r
.73185 .47976 m .73327 .4781 L .73419 .47776 L F
.626 .36 .495 r
.73185 .47976 m .73387 .4811 L .73327 .4781 L F
.73185 .47976 m .73222 .48172 L .73387 .4811 L F
.865 .737 .719 r
.56004 .67108 m .56184 .67196 L .56094 .66896 L F
.54 .653 .909 r
.32361 .63898 m .32767 .64125 L .32579 .63792 L F
.602 .675 .892 r
.32579 .63792 m .32767 .64125 L .32953 .64013 L F
.43 .726 .988 r
.52459 .63309 m .52351 .6343 L .52235 .63324 L F
.52459 .63309 m .52582 .63426 L .52351 .6343 L F
.575 .463 .688 r
.66433 .49956 m .66634 .49649 L .66405 .49726 L F
.66433 .49956 m .66638 .49898 L .66634 .49649 L F
.711 .571 .694 r
.66433 .49956 m .66743 .50217 L .66638 .49898 L F
.66433 .49956 m .66527 .50287 L .66743 .50217 L F
.971 .754 .323 r
.58665 .6545 m .58608 .65362 L .58664 .65185 L F
0 0 0 r
.58664 .65185 m .58608 .65362 L .58813 .64998 L F
.538 .316 .525 r
.49038 .62519 m .48827 .62325 L .48803 .62557 L F
.376 .137 .42 r
.4906 .62052 m .48827 .62325 L .49056 .62285 L F
.43 .318 .625 r
.49056 .62285 m .48827 .62325 L .49038 .62519 L F
.538 .316 .525 r
.49038 .62519 m .48827 .62325 L .48803 .62557 L F
.095 .503 .903 r
.31427 .63471 m .31467 .63407 L .31187 .63264 L F
.419 .855 .933 r
.31708 .63409 m .31467 .63407 L .31427 .63471 L F
.807 .843 .877 r
.68437 .49651 m .6816 .49909 L .68305 .49975 L F
.854 .641 .613 r
.68112 .50136 m .68305 .49975 L .6816 .49909 L F
.68112 .50136 m .68321 .50274 L .68305 .49975 L F
.452 .049 .183 r
.34767 .59936 m .34396 .60173 L .34552 .59964 L F
0 .533 .709 r
.3012 .62861 m .29948 .62847 L .30366 .62881 L F
.507 .198 .377 r
.40858 .62135 m .40669 .6201 L .40891 .61945 L F
.40858 .62135 m .40582 .62282 L .40669 .6201 L F
.491 .242 .464 r
.3904 .61451 m .39266 .61407 L .39305 .61185 L F
.425 .185 .443 r
.39305 .61185 m .39266 .61407 L .3951 .61133 L F
.117 0 .313 r
.21595 .56853 m .21537 .57082 L .21414 .57146 L F
.403 .275 .59 r
.21591 .57317 m .21414 .57146 L .21537 .57082 L F
.21591 .57317 m .21404 .57402 L .21414 .57146 L F
.59 .463 .675 r
.4684 .70255 m .4664 .70593 L .4671 .70483 L F
.57 .215 .327 r
.49919 .66059 m .49881 .66225 L .49648 .6613 L F
.621 .438 .614 r
.50233 .65915 m .50173 .66058 L .49919 .66059 L F
.541 .155 .258 r
.50173 .66058 m .50138 .66219 L .50079 .66176 L F
.50122 .66058 m .50079 .66176 L .49919 .66059 L F
.50173 .66058 m .50079 .66176 L .50122 .66058 L F
.837 .598 .577 r
.50138 .66219 m .49674 .66315 L .49881 .66225 L F
.666 .518 .674 r
.50057 .66237 m .50198 .65925 L .50065 .66215 L F
.837 .598 .577 r
.50138 .66219 m .49977 .66442 L .49674 .66315 L F
.666 .518 .674 r
.50032 .663 m .50041 .66281 L .50057 .66237 L F
.50041 .66281 m .50198 .65925 L .50057 .66237 L F
.49977 .66442 m .49991 .66409 L .50032 .663 L F
.52 .169 .313 r
.50079 .66176 m .50138 .66219 L .50062 .66221 L F
.666 .518 .674 r
.49991 .66409 m .50198 .65925 L .50032 .663 L F
.52 .169 .313 r
.49919 .66059 m .50079 .66176 L .49881 .66225 L F
.50079 .66176 m .50062 .66221 L .49881 .66225 L F
.709 .658 .798 r
.66987 .49926 m .67343 .50202 L .67252 .4986 L F
.587 .613 .846 r
.67252 .4986 m .67343 .50202 L .67565 .49991 L F
.637 .856 .983 r
.43006 .70366 m .43395 .70363 L .4328 .70347 L F
.486 .834 .997 r
.43395 .70363 m .43487 .70246 L .4328 .70347 L F
.246 0 .016 r
.55544 .5914 m .55716 .59102 L .55849 .58918 L F
.469 .044 .149 r
.55716 .59102 m .56037 .5902 L .55849 .58918 L F
.423 .109 .327 r
.55849 .58918 m .56037 .5902 L .56065 .58858 L F
.731 .753 .87 r
.52445 .67904 m .52062 .67802 L .5227 .67678 L F
.381 .496 .851 r
.52515 .67657 m .52694 .67999 L .52445 .67904 L F
.188 .239 .684 r
.58149 .65989 m .57969 .65728 L .58142 .657 L F
.181 .337 .786 r
.57274 .66609 m .57523 .66824 L .57373 .66463 L F
.528 .296 .507 r
.53109 .65065 m .52931 .65405 L .53112 .64995 L F
.53109 .65065 m .53437 .65368 L .52931 .65405 L F
.114 .072 .528 r
.4684 .70255 m .46917 .70069 L .46773 .69997 L F
.397 .335 .671 r
.59014 .64077 m .59174 .6367 L .59006 .63801 L F
.837 .59 .565 r
.59734 .6371 m .59922 .63769 L .59884 .63994 L F
.004 0 0 r
.37716 .59444 m .37574 .59502 L .37345 .59543 L F
.056 0 0 r
.37898 .59369 m .37574 .59502 L .37716 .59444 L F
.801 .537 .538 r
.59777 .56813 m .60029 .5706 L .60039 .56876 L F
.678 .618 .782 r
.66638 .49898 m .66743 .50217 L .66987 .49926 L F
.577 .412 .621 r
.66492 .48834 m .6675 .4901 L .66744 .48787 L F
.66492 .48834 m .66512 .49064 L .6675 .4901 L F
.579 .291 .442 r
.50059 .68301 m .50275 .68304 L .50259 .68093 L F
.791 .453 .416 r
.50259 .68093 m .50275 .68304 L .50541 .68296 L F
.448 .329 .625 r
.4906 .62052 m .49269 .62224 L .49264 .61952 L F
.589 .303 .45 r
.49056 .62285 m .49269 .62224 L .4906 .62052 L F
.63 .512 .7 r
.4324 .69535 m .43445 .69518 L .43442 .69192 L F
.641 .53 .712 r
.4331 .69554 m .43445 .69518 L .4324 .69535 L F
.488 .122 .272 r
.56615 .58524 m .56863 .585 L .569 .58361 L F
.516 .163 .307 r
.56863 .585 m .57207 .58249 L .569 .58361 L F
.75 .374 .342 r
.74643 .48105 m .74939 .48001 L .74549 .48048 L F
.74643 .48105 m .74979 .48161 L .74939 .48001 L F
.503 .872 .982 r
.73918 .4998 m .73595 .50006 L .73888 .49915 L F
.73918 .4998 m .73595 .50006 L .73888 .49915 L F
.42 .816 .984 r
.73918 .4998 m .73888 .49915 L .74134 .49946 L F
.74134 .49946 m .73888 .49915 L .73918 .4998 L F
.724 .633 .756 r
.5947 .63591 m .59648 .64054 L .59301 .64038 L F
.679 .324 .365 r
.59301 .64038 m .59648 .64054 L .59506 .64224 L F
.57 .494 .729 r
.59734 .6371 m .59648 .64054 L .5947 .63591 L F
.59734 .6371 m .59884 .63994 L .59648 .64054 L F
.393 .348 .689 r
.59727 .64289 m .59888 .64237 L .59648 .64054 L F
.64 .274 .334 r
.59648 .64054 m .59888 .64237 L .59506 .64224 L F
.424 .014 .155 r
.31794 .58733 m .32078 .58599 L .31854 .58634 L F
.76 .489 .522 r
.45607 .68588 m .45432 .6832 L .45628 .68362 L F
.531 .197 .346 r
.46709 .65629 m .46746 .65467 L .46506 .65482 L F
.393 .079 .31 r
.46506 .65482 m .46234 .65707 L .46467 .65664 L F
.521 .203 .369 r
.46709 .65629 m .46506 .65482 L .46467 .65664 L F
.342 0 .091 r
.35198 .64325 m .3505 .64529 L .34833 .64569 L F
.41 0 .088 r
.3543 .64322 m .3505 .64529 L .35198 .64325 L F
0 0 0 r
.55184 .59846 m .5523 .59822 L .55061 .59934 L F
.55184 .59846 m .55351 .59706 L .5523 .59822 L F
.978 .762 .544 r
.55711 .619 m .55879 .61751 L .55694 .61675 L F
.55711 .619 m .55848 .61988 L .55879 .61751 L F
.26 .682 .965 r
.77316 .49117 m .77213 .49036 L .76988 .4902 L F
.141 .592 .927 r
.77316 .49117 m .77488 .49083 L .77213 .49036 L F
.77316 .49117 m .77515 .49149 L .77488 .49083 L F
.356 .288 .642 r
.80144 .51049 m .80139 .51339 L .80084 .51143 L F
.76 .739 .833 r
.73222 .48172 m .73547 .48257 L .73387 .4811 L F
.884 .798 .759 r
.73222 .48436 m .73547 .48257 L .73222 .48172 L F
.73222 .48436 m .73361 .48579 L .73547 .48257 L F
.784 .747 .819 r
.4634 .70301 m .45971 .70272 L .46134 .70208 L F
.4634 .70301 m .46142 .7041 L .45971 .70272 L F
.886 .857 .808 r
.46485 .70036 m .4634 .70301 L .46134 .70208 L F
.445 .771 .997 r
.5374 .67399 m .54052 .67469 L .53824 .67492 L F
.5374 .67399 m .53824 .67492 L .53765 .67419 L F
.726 .273 .174 r
.54052 .67469 m .53765 .67419 L .53824 .67492 L F
.863 .884 .851 r
.54213 .70641 m .54311 .70268 L .54157 .70334 L F
.54213 .70641 m .54469 .70369 L .54311 .70268 L F
.516 .163 .307 r
.56863 .585 m .57109 .58481 L .57207 .58249 L F
.52 .133 .247 r
.57109 .58481 m .57455 .58275 L .57207 .58249 L F
.701 .876 .963 r
.48697 .66283 m .48368 .6627 L .48649 .66233 L F
0 0 0 r
.48529 .66598 m .48697 .66283 L .48616 .66447 L F
.832 .943 .582 r
.48649 .66233 m .48697 .66283 L .48807 .66086 L F
.885 .81 .329 r
.48616 .66447 m .48697 .66283 L .48649 .66233 L F
.518 .44 .708 r
.43372 .68919 m .43577 .6887 L .43545 .68575 L F
.492 .351 .617 r
.43372 .68919 m .436 .69124 L .43577 .6887 L F
.401 .347 .682 r
.43372 .68919 m .43442 .69192 L .436 .69124 L F
.682 .261 .238 r
.46951 .71482 m .46798 .71645 L .46585 .71458 L F
.426 0 0 r
.47178 .71669 m .46798 .71645 L .46951 .71482 L F
0 0 .172 r
.20983 .5853 m .20927 .58778 L .20848 .58874 L F
0 0 .236 r
.20927 .58778 m .20807 .59102 L .20848 .58874 L F
.52 .816 .999 r
.54311 .70268 m .54469 .70369 L .54704 .70085 L F
.54311 .70268 m .54551 .70227 L .54469 .70369 L F
.54311 .70268 m .54551 .70227 L .54469 .70369 L F
.684 .892 .973 r
.35405 .62588 m .35544 .62371 L .35685 .6248 L F
.35405 .62588 m .35261 .62511 L .35544 .62371 L F
.42 .078 .277 r
.40131 .6236 m .40073 .6251 L .39857 .62549 L F
.225 0 .024 r
.40363 .62336 m .40073 .6251 L .40131 .6236 L F
.414 .209 .491 r
.43483 .68055 m .43675 .68012 L .43705 .6776 L F
.486 .369 .646 r
.43507 .68306 m .43675 .68012 L .43483 .68055 L F
.806 .703 .752 r
.56486 .59686 m .57053 .5972 L .56708 .59679 L F
.56486 .59686 m .56716 .60035 L .57053 .5972 L F
.285 0 0 r
.57161 .59716 m .56708 .59679 L .57053 .5972 L F
.096 .393 .85 r
.56414 .64058 m .56455 .6393 L .56185 .63769 L F
.546 .55 .81 r
.56351 .64303 m .56455 .6393 L .56414 .64058 L F
.701 .685 .832 r
.77949 .50819 m .78281 .50814 L .7816 .50499 L F
.64 .652 .846 r
.7816 .50499 m .78281 .50814 L .78538 .50725 L F
.233 .625 .957 r
.746 .504 m .74668 .50498 L .74385 .50307 L F
0 0 .198 r
.746 .504 m .74603 .50766 L .74668 .50498 L F
.434 .253 .534 r
.46823 .66662 m .46969 .66854 L .46795 .66827 L F
.813 .568 .568 r
.60384 .57994 m .60385 .58235 L .60735 .58286 L F
.836 .607 .591 r
.60392 .58469 m .60735 .58286 L .60385 .58235 L F
.60392 .58469 m .60769 .58555 L .60735 .58286 L F
.791 .575 .608 r
.60769 .58555 m .60884 .58582 L .60735 .58286 L F
.676 .769 .921 r
.73376 .50094 m .73489 .49807 L .73235 .4985 L F
.73376 .50094 m .73595 .50006 L .73489 .49807 L F
.73489 .49807 m .73376 .50094 L .73235 .4985 L F
.73489 .49807 m .73595 .50006 L .73376 .50094 L F
.694 .566 .706 r
.55976 .61104 m .56125 .61419 L .56263 .61192 L F
.78 .702 .777 r
.74474 .47532 m .74549 .48048 L .74641 .47675 L F
.773 .796 .871 r
.53899 .66867 m .53608 .66835 L .53833 .66551 L F
.89 .695 .633 r
.53899 .66867 m .53606 .67117 L .53608 .66835 L F
.53899 .66867 m .5374 .67399 L .53606 .67117 L F
0 0 .036 r
.54058 .66699 m .53899 .66867 L .53833 .66551 L F
.717 .685 .819 r
.53899 .66867 m .54298 .66726 L .54058 .66699 L F
0 0 .036 r
.54058 .66699 m .54063 .66796 L .53899 .66867 L F
0 0 0 r
.5394 .66908 m .53899 .66867 L .54063 .66796 L F
.53899 .66867 m .5374 .67399 L .53899 .66867 L F
.5384 .67154 m .5374 .67399 L .53899 .66867 L F
.53813 .67243 m .5374 .67399 L .5394 .66908 L F
.16 .323 .78 r
.53606 .67117 m .5374 .67399 L .53813 .67243 L F
.608 .223 .289 r
.53821 .67249 m .5367 .67454 L .53813 .67243 L F
.726 .273 .174 r
.54052 .67469 m .53923 .67597 L .53765 .67419 L F
.084 0 0 r
.5374 .67399 m .54296 .67459 L .54052 .67469 L F
.64 .886 .546 r
.54066 .67435 m .53923 .67597 L .54052 .67469 L F
.426 .599 .917 r
.54028 .67222 m .54114 .67356 L .5374 .67399 L F
.64 .886 .546 r
.54078 .67408 m .54059 .67435 L .54066 .67435 L F
.54066 .67435 m .54052 .67469 L .54296 .67459 L F
.084 0 0 r
.54059 .67435 m .54173 .67447 L .54103 .67439 L F
.54066 .67435 m .54103 .67439 L .54073 .67435 L F
.54059 .67435 m .54103 .67439 L .54066 .67435 L F
.64 .886 .546 r
.54137 .67399 m .54066 .67435 L .54296 .67459 L F
.426 .599 .917 r
.54078 .67408 m .54173 .67447 L .54059 .67435 L F
.944 .918 .757 r
.54214 .67239 m .54151 .67358 L .54296 .67459 L F
.54125 .6734 m .54137 .67399 L .54296 .67459 L F
.868 .778 .759 r
.54214 .67239 m .54173 .67447 L .54135 .67388 L F
.54214 .67239 m .54135 .67388 L .54028 .67222 L F
.944 .918 .757 r
.54214 .67239 m .54125 .6734 L .54151 .67358 L F
.426 .599 .917 r
.54114 .67356 m .54135 .67388 L .54078 .67408 L F
.944 .918 .757 r
.54125 .6734 m .54089 .67381 L .54137 .67399 L F
.426 .599 .917 r
.54135 .67388 m .54142 .67399 L .54137 .67399 L F
.54135 .67388 m .54137 .67399 L .54078 .67408 L F
.64 .886 .546 r
.54078 .67408 m .54066 .67435 L .54137 .67399 L F
.426 .599 .917 r
.54142 .67399 m .54173 .67447 L .54078 .67408 L F
.64 .886 .546 r
.54089 .67381 m .54078 .67408 L .54137 .67399 L F
.084 0 0 r
.53746 .674 m .54059 .67435 L .54073 .67435 L F
.5374 .67399 m .53749 .674 L .53746 .674 L F
.53749 .674 m .54059 .67435 L .53746 .674 L F
.042 .185 .688 r
.53765 .67419 m .53923 .67597 L .53866 .67414 L F
.426 .599 .917 r
.54114 .67356 m .54059 .67435 L .5374 .67399 L F
.54028 .67222 m .5374 .67399 L .53813 .67243 L F
.042 .185 .688 r
.53769 .67403 m .53866 .67414 L .53813 .67243 L F
.53765 .67419 m .53866 .67414 L .53769 .67403 L F
.64 .886 .546 r
.54089 .67381 m .54048 .67434 L .54059 .67435 L F
.54089 .67381 m .54059 .67435 L .54078 .67408 L F
.54048 .67434 m .53923 .67597 L .54066 .67435 L F
.084 0 0 r
.54073 .67435 m .54173 .67447 L .54296 .67459 L F
.543 .526 .787 r
.53813 .67243 m .53923 .67597 L .54089 .67381 L F
.608 .223 .289 r
.54083 .67442 m .53779 .67451 L .53821 .67249 L F
.145 .303 .767 r
.5374 .67399 m .53765 .67419 L .53813 .67243 L F
.608 .223 .289 r
.53779 .67451 m .5367 .67454 L .53821 .67249 L F
0 0 0 r
.5394 .66908 m .5384 .67154 L .53899 .66867 L F
.36 .094 .367 r
.55466 .6001 m .55212 .60272 L .55376 .60166 L F
.051 .238 .735 r
.55466 .6001 m .55556 .59906 L .55351 .59706 L F
.515 .557 .837 r
.55376 .60166 m .55556 .59906 L .55466 .6001 L F
.514 .225 .413 r
.41741 .61452 m .41687 .6165 L .41463 .61683 L F
.385 .045 .261 r
.41979 .61426 m .41687 .6165 L .41741 .61452 L F
.345 .63 .959 r
.20121 .54656 m .20307 .54664 L .20265 .54807 L F
.355 .642 .963 r
.20307 .54664 m .20453 .54814 L .20265 .54807 L F
.602 .384 .558 r
.66599 .49542 m .66634 .49649 L .66612 .4941 L F
.66599 .49542 m .66405 .49726 L .66634 .49649 L F
.464 .329 .611 r
.55261 .60645 m .55376 .60166 L .55212 .60272 L F
.451 .257 .525 r
.45247 .69412 m .45221 .69782 L .45105 .69627 L F
.574 .389 .593 r
.43928 .67464 m .44169 .67178 L .43923 .67219 L F
.291 0 0 r
.49064 .64908 m .48941 .65037 L .48721 .65055 L F
.472 .086 .226 r
.49253 .64839 m .48941 .65037 L .49064 .64908 L F
.552 .272 .445 r
.44651 .67127 m .44947 .66843 L .44728 .6688 L F
.749 .44 .461 r
.48417 .71155 m .48584 .71447 L .48637 .71175 L F
.401 .122 .371 r
.48637 .71175 m .48792 .71373 L .48934 .71132 L F
.48637 .71175 m .48584 .71447 L .48792 .71373 L F
.296 .665 .973 r
.45039 .71107 m .45158 .71027 L .44917 .70875 L F
.45039 .71107 m .45276 .71135 L .45158 .71027 L F
.205 .008 .377 r
.21164 .58207 m .20983 .5853 L .21033 .58302 L F
.754 .774 .869 r
.53734 .63493 m .53913 .63683 L .53801 .63724 L F
.371 .711 .987 r
.53999 .63571 m .53913 .63683 L .53734 .63493 L F
.53999 .63571 m .54117 .63677 L .53913 .63683 L F
.618 .356 .5 r
.51453 .65177 m .51195 .65404 L .51204 .65201 L F
.654 .604 .786 r
.45247 .69412 m .44921 .69163 L .45103 .69215 L F
.065 .391 .851 r
.45103 .69215 m .45347 .69347 L .45247 .69412 L F
.07 0 .397 r
.45403 .69542 m .45247 .69412 L .45347 .69347 L F
.45403 .69542 m .45221 .69782 L .45247 .69412 L F
.88 .669 .614 r
.59924 .6 m .59661 .59973 L .5975 .59757 L F
.895 .813 .76 r
.59924 .6 m .59591 .60207 L .59661 .59973 L F
.59924 .6 m .59751 .60303 L .59591 .60207 L F
0 0 0 r
.59557 .63428 m .59684 .63346 L .59761 .6318 L F
.59684 .63346 m .59858 .63037 L .59761 .6318 L F
.325 0 0 r
.73419 .47776 m .73327 .4781 L .7365 .47833 L F
0 0 0 r
.60197 .66869 m .60538 .66664 L .60375 .66762 L F
.60538 .66664 m .60536 .6669 L .60375 .66762 L F
.60538 .66664 m .60718 .66544 L .60536 .6669 L F
.938 .802 .684 r
.7793 .52536 m .78078 .52551 L .77988 .52214 L F
.563 .515 .759 r
.78078 .52551 m .78223 .52163 L .77988 .52214 L F
0 .206 .687 r
.78236 .52633 m .78078 .52551 L .7793 .52536 L F
.761 .286 .117 r
.49846 .6199 m .50227 .62226 L .50187 .62099 L F
.126 .303 .773 r
.49466 .65755 m .4969 .65935 L .49789 .65714 L F
.662 .432 .562 r
.75913 .48458 m .76196 .48197 L .75913 .48258 L F
.567 .633 .876 r
.67696 .50248 m .67818 .49949 L .67565 .49991 L F
.67696 .50248 m .67931 .50203 L .67818 .49949 L F
.475 .512 .815 r
.73366 .50678 m .73185 .50912 L .73127 .50721 L F
.73366 .50678 m .73599 .51151 L .73185 .50912 L F
.657 .233 .227 r
.47259 .71085 m .47395 .70907 L .47037 .70902 L F
.667 .302 .344 r
.47259 .71085 m .47633 .7092 L .47395 .70907 L F
.662 .687 .863 r
.79587 .51386 m .79964 .51499 L .79815 .51381 L F
.787 .838 .891 r
.79815 .51381 m .79964 .51499 L .80139 .51339 L F
.508 .41 .68 r
.29592 .60632 m .29794 .60585 L .29743 .60215 L F
.527 .496 .765 r
.29592 .60632 m .29868 .60795 L .29794 .60585 L F
.603 .419 .605 r
.7839 .49972 m .78661 .49972 L .78635 .49682 L F
.574 .566 .807 r
.78635 .49682 m .78764 .49264 L .78514 .49316 L F
.78635 .49682 m .78878 .49618 L .78764 .49264 L F
.567 .416 .635 r
.78661 .49972 m .78878 .49618 L .78635 .49682 L F
.563 .257 .407 r
.59071 .57363 m .59302 .5734 L .59345 .57161 L F
.328 .048 .327 r
.59345 .57161 m .59302 .5734 L .59553 .5708 L F
.84 .999 .799 r
.79061 .5284 m .79266 .52598 L .79129 .52628 L F
.804 .913 .519 r
.78943 .52978 m .79061 .5284 L .79129 .52628 L F
.558 .533 .784 r
.33469 .61096 m .33376 .61493 L .33273 .61142 L F
.33469 .61096 m .33592 .6145 L .33376 .61493 L F
0 .519 .721 r
.52582 .63426 m .52848 .63457 L .52941 .63471 L F
.581 .892 .989 r
.52848 .63457 m .53166 .63436 L .52941 .63471 L F
.556 .274 .443 r
.49648 .6613 m .49674 .66315 L .49593 .66344 L F
.49648 .6613 m .49881 .66225 L .49674 .66315 L F
.754 .774 .869 r
.53734 .63493 m .53801 .63724 L .53506 .63492 L F
.688 .899 .973 r
.75915 .52504 m .76173 .52425 L .75945 .52243 L F
.636 .88 .986 r
.75945 .52243 m .76173 .52425 L .76456 .52275 L F
.232 0 0 r
.3882 .63103 m .38896 .63233 L .38654 .6326 L F
.3882 .63103 m .39038 .63056 L .38896 .63233 L F
0 0 0 r
.53177 .60346 m .5292 .60582 L .53121 .60433 L F
0 0 .221 r
.52999 .60805 m .53121 .60433 L .5292 .60582 L F
0 0 0 r
.73757 .51002 m .73582 .51169 L .7383 .51095 L F
.73757 .51002 m .73489 .51281 L .73582 .51169 L F
.342 0 0 r
.73582 .51169 m .73647 .51227 L .7383 .51095 L F
.73582 .51169 m .73489 .51281 L .73647 .51227 L F
0 .138 .665 r
.57094 .66043 m .57166 .65924 L .56992 .65702 L F
0 .079 .618 r
.57094 .66043 m .5725 .66271 L .57166 .65924 L F
.611 .799 .374 r
.56125 .61419 m .56184 .61321 L .56263 .61192 L F
0 .159 .693 r
.56125 .61419 m .56321 .61645 L .56184 .61321 L F
.439 .657 .953 r
.79509 .48604 m .79403 .48751 L .7938 .48636 L F
.79509 .48604 m .79575 .48723 L .79403 .48751 L F
.688 .899 .973 r
.75915 .52504 m .75945 .52243 L .75829 .52419 L F
.488 .507 .803 r
.8019 .48949 m .80077 .4931 L .79925 .49007 L F
.8019 .48949 m .80297 .49289 L .80077 .4931 L F
.496 .442 .727 r
.31721 .63792 m .31814 .63531 L .31613 .63665 L F
.31721 .63792 m .31967 .63719 L .31814 .63531 L F
.494 .168 .344 r
.45432 .6832 m .45248 .68597 L .45049 .68598 L F
.76 .489 .522 r
.45607 .68588 m .45248 .68597 L .45432 .6832 L F
.844 .825 .829 r
.7887 .5189 m .79076 .52006 L .79026 .51691 L F
.903 .511 .088 r
.7902 .5207 m .79076 .52006 L .7887 .5189 L F
.847 .827 .827 r
.79026 .51691 m .79076 .52006 L .79344 .51671 L F
.751 .452 .477 r
.4763 .71085 m .48022 .70873 L .47633 .7092 L F
.4763 .71085 m .47839 .7112 L .48022 .70873 L F
.735 .431 .466 r
.47839 .7112 m .48185 .71148 L .48022 .70873 L F
.797 .443 .386 r
.48022 .70873 m .48185 .71148 L .48417 .71155 L F
.791 .809 .867 r
.54058 .66699 m .54298 .66726 L .54534 .66608 L F
.54058 .66699 m .54534 .66608 L .54393 .66684 L F
0 .154 .681 r
.54534 .66608 m .54608 .6662 L .54393 .66684 L F
.789 .698 .764 r
.72024 .48456 m .72147 .48793 L .72368 .48524 L F
.647 .768 .937 r
.78538 .50725 m .78874 .50794 L .78774 .50686 L F
.55 .78 .984 r
.78874 .50794 m .79018 .50623 L .78774 .50686 L F
.78874 .50794 m .79124 .50748 L .79018 .50623 L F
.814 .488 0 r
.56999 .65471 m .56947 .65383 L .56872 .6512 L F
0 .104 .628 r
.56992 .65702 m .56947 .65383 L .56999 .65471 L F
.446 .466 .786 r
.74938 .50958 m .74753 .51162 L .74603 .50766 L F
.546 .62 .877 r
.75009 .51123 m .74753 .51162 L .74938 .50958 L F
.299 0 .239 r
.50865 .65889 m .50739 .6573 L .50954 .65567 L F
.50865 .65889 m .50677 .65957 L .50739 .6573 L F
.397 .335 .671 r
.59014 .64077 m .59242 .63972 L .59174 .6367 L F
.806 .527 .515 r
.59301 .64038 m .5907 .64274 L .59014 .64077 L F
.122 0 .121 r
.59168 .64135 m .59014 .64077 L .5907 .64274 L F
.59168 .64135 m .59242 .63972 L .59014 .64077 L F
.308 0 0 r
.56184 .61321 m .56409 .61432 L .56263 .61192 L F
.034 .172 .678 r
.34882 .6249 m .34818 .62668 L .34696 .62268 L F
.523 .738 .973 r
.34882 .6249 m .35043 .62642 L .34818 .62668 L F
.345 .758 .98 r
.77591 .52855 m .77819 .52929 L .77797 .52712 L F
.259 0 0 r
.77819 .52929 m .78015 .5299 L .77769 .53046 L F
.77819 .52929 m .78138 .52884 L .78015 .5299 L F
.599 .421 .611 r
.30912 .64492 m .30691 .64324 L .30909 .64394 L F
.30691 .64324 m .30912 .64492 L .308 .64208 L F
.30691 .64324 m .30721 .64618 L .30912 .64492 L F
.30912 .64492 m .30721 .64618 L .30691 .64324 L F
0 0 0 r
.4331 .69554 m .4293 .69985 L .43156 .69985 L F
.641 .53 .712 r
.4331 .69554 m .43516 .6973 L .43445 .69518 L F
.802 .457 .403 r
.43369 .6992 m .4331 .69554 L .43156 .69985 L F
.43369 .6992 m .43516 .6973 L .4331 .69554 L F
.392 0 0 r
.53527 .7081 m .53722 .70807 L .53906 .70663 L F
.349 .029 .274 r
.53857 .70852 m .54125 .70624 L .53906 .70663 L F
.515 .116 .223 r
.53722 .70807 m .54125 .70624 L .53906 .70663 L F
0 0 0 r
.73995 .5052 m .73938 .50646 L .74186 .50325 L F
.405 .046 .239 r
.38714 .61716 m .38926 .61676 L .3904 .61451 L F
.382 .024 .227 r
.3904 .61451 m .39168 .61609 L .39266 .61407 L F
.3904 .61451 m .38926 .61676 L .39168 .61609 L F
.295 .566 .932 r
.7409 .47641 m .74294 .47666 L .7415 .47508 L F
.501 .253 .47 r
.40394 .60788 m .40625 .60758 L .40633 .60571 L F
.46 .375 .673 r
.40633 .60571 m .40785 .60215 L .40551 .60262 L F
.40633 .60571 m .40877 .60505 L .40785 .60215 L F
.479 .29 .546 r
.40625 .60758 m .40877 .60505 L .40633 .60571 L F
.051 0 0 r
.36232 .63976 m .35819 .64151 L .36016 .64034 L F
0 .474 .722 r
.38063 .58445 m .38265 .58484 L .3842 .58519 L F
0 .564 .793 r
.38265 .58484 m .38631 .58544 L .3842 .58519 L F
.906 .945 .589 r
.61121 .65857 m .60933 .66269 L .6104 .66088 L F
.292 .136 .49 r
.48414 .63165 m .48563 .63333 L .48584 .63102 L F
.48414 .63165 m .48407 .63415 L .48563 .63333 L F
.474 .742 .987 r
.39917 .587 m .39575 .58605 L .39796 .58585 L F
.39 .735 .991 r
.4008 .58624 m .39917 .587 L .39796 .58585 L F
.4008 .58624 m .40226 .58708 L .39917 .587 L F
.118 .663 .83 r
.31085 .63278 m .31056 .63251 L .30939 .63307 L F
.31085 .63278 m .31187 .63264 L .31056 .63251 L F
.598 .54 .761 r
.66512 .49064 m .66612 .4941 L .66854 .49352 L F
.598 .45 .652 r
.66612 .4941 m .66888 .49597 L .66854 .49352 L F
.66612 .4941 m .66634 .49649 L .66888 .49597 L F
.284 .385 .791 r
.3382 .61624 m .33717 .61797 L .33592 .6145 L F
.46 .617 .917 r
.3382 .61624 m .34034 .61878 L .33717 .61797 L F
.649 .343 .439 r
.40057 .61024 m .40394 .60788 L .40103 .60901 L F
.753 .702 .804 r
.31967 .63719 m .32161 .64066 L .32361 .63898 L F
.423 .16 .407 r
.45743 .66065 m .45477 .6634 L .45696 .66287 L F
.409 .159 .421 r
.45942 .66001 m .45743 .66065 L .45696 .66287 L F
.491 .056 .14 r
.30532 .59285 m .30982 .59088 L .30755 .59115 L F
.472 .613 .909 r
.42414 .59802 m .42312 .59977 L .422 .5983 L F
.42414 .59802 m .42523 .59986 L .42312 .59977 L F
.873 .871 .832 r
.5664 .62697 m .56694 .62883 L .56925 .62592 L F
.114 .482 .898 r
.56791 .62823 m .56694 .62883 L .5664 .62697 L F
.56791 .62823 m .5697 .63012 L .56694 .62883 L F
.335 0 0 r
.78599 .50095 m .7839 .49972 L .78269 .50124 L F
.78607 .50092 m .7839 .49972 L .78599 .50095 L F
.78596 .50086 m .78661 .49972 L .7839 .49972 L F
.519 .679 .938 r
.78475 .49946 m .7831 .50089 L .78213 .49989 L F
.7831 .50089 m .78269 .50124 L .78254 .50089 L F
.7831 .50089 m .78254 .50089 L .78213 .49989 L F
.335 0 0 r
.78607 .50092 m .7861 .50086 L .78596 .50086 L F
.7861 .50086 m .78661 .49972 L .78596 .50086 L F
.762 .765 .856 r
.78514 .50121 m .78539 .50238 L .78702 .5008 L F
.349 0 0 r
.78959 .50032 m .78661 .49972 L .78615 .50081 L F
.78677 .5008 m .78615 .50081 L .7861 .50092 L F
.78959 .50032 m .78615 .50081 L .78677 .5008 L F
.648 .56 .741 r
.78539 .50238 m .78904 .50262 L .78839 .50077 L F
.349 0 0 r
.78959 .50032 m .7861 .50092 L .7865 .50087 L F
.414 .026 .192 r
.78959 .50032 m .7892 .49929 L .78661 .49972 L F
.349 0 0 r
.78959 .50032 m .7865 .50087 L .78805 .4998 L F
.762 .765 .856 r
.78607 .50092 m .7865 .50087 L .7867 .50073 L F
.78514 .50121 m .78702 .5008 L .78607 .50092 L F
.349 0 0 r
.7865 .50087 m .7861 .50092 L .7861 .50094 L F
.762 .765 .856 r
.7859 .50084 m .78728 .50055 L .78805 .4998 L F
.519 .679 .938 r
.78475 .49946 m .78599 .50095 L .78269 .50124 L F
.762 .765 .856 r
.78558 .50099 m .78595 .5009 L .7859 .50084 L F
.78595 .5009 m .78728 .50055 L .7859 .50084 L F
.335 0 0 r
.7861 .50092 m .78661 .49972 L .78607 .50092 L F
.567 .416 .635 r
.78661 .49972 m .7892 .49929 L .78878 .49618 L F
.762 .765 .856 r
.78475 .49946 m .78514 .50121 L .78805 .4998 L F
.335 0 0 r
.7861 .50094 m .78607 .50092 L .78599 .50095 L F
.519 .679 .938 r
.78475 .49946 m .7861 .50094 L .78599 .50095 L F
.762 .765 .856 r
.78607 .50092 m .78728 .50055 L .78558 .50099 L F
.349 0 0 r
.7865 .50087 m .7861 .50094 L .78805 .4998 L F
.762 .765 .856 r
.7867 .50073 m .78702 .5008 L .78728 .50055 L F
.7865 .50087 m .78702 .5008 L .7867 .50073 L F
.648 .56 .741 r
.78702 .5008 m .78839 .50077 L .78805 .4998 L F
.78539 .50238 m .78839 .50077 L .78702 .5008 L F
.335 0 0 r
.7861 .50094 m .7861 .50092 L .78607 .50092 L F
.762 .765 .856 r
.78514 .50121 m .78607 .50092 L .78558 .50099 L F
.623 .371 .516 r
.4852 .65441 m .48263 .65664 L .48295 .655 L F
.938 .601 .363 r
.7462 .48261 m .74688 .48473 L .7454 .48378 L F
0 .295 .666 r
.77322 .48152 m .77662 .48315 L .77406 .48279 L F
.543 .449 .698 r
.43697 .67521 m .43705 .6776 L .43914 .677 L F
.357 .161 .473 r
.43705 .6776 m .43864 .67939 L .43914 .677 L F
.43705 .6776 m .43675 .68012 L .43864 .67939 L F
0 0 0 r
.53177 .60346 m .53212 .60377 L .53325 .60195 L F
.53177 .60346 m .53121 .60433 L .53212 .60377 L F
.806 .527 .515 r
.59301 .64038 m .59344 .64276 L .5907 .64274 L F
.679 .324 .365 r
.59301 .64038 m .59506 .64224 L .59344 .64276 L F
.693 .599 .746 r
.71786 .48519 m .72147 .48793 L .72024 .48456 L F
.543 .449 .698 r
.43697 .67521 m .43914 .677 L .43928 .67464 L F
.111 .647 .859 r
.3439 .58277 m .34612 .58285 L .34761 .58323 L F
.333 .792 .943 r
.34612 .58285 m .3499 .58287 L .34761 .58323 L F
.323 0 .236 r
.52162 .65376 m .52345 .65358 L .52376 .65227 L F
.52345 .65358 m .52373 .65341 L .52376 .65227 L F
.517 .135 .255 r
.52373 .65356 m .52473 .65353 L .52376 .65227 L F
.52473 .65353 m .52474 .65351 L .52376 .65227 L F
.52476 .65353 m .52431 .65256 L .52376 .65227 L F
.509 .365 .621 r
.52162 .65376 m .52397 .65816 L .52373 .65356 L F
.52162 .65376 m .52307 .65889 L .52397 .65816 L F
.86 .554 .469 r
.52452 .65542 m .52475 .6535 L .52476 .65353 L F
.034 .03 .52 r
.52476 .65353 m .52452 .65542 L .52601 .6535 L F
.86 .554 .469 r
.52452 .65542 m .52476 .65353 L .52489 .6538 L F
.034 .03 .52 r
.52473 .65353 m .52452 .65542 L .52476 .65353 L F
.52373 .65356 m .52452 .65542 L .52473 .65353 L F
.517 .135 .255 r
.52476 .65353 m .52492 .65353 L .52431 .65256 L F
.52492 .65353 m .52601 .6535 L .52499 .65294 L F
.52492 .65353 m .52499 .65294 L .52431 .65256 L F
.498 .165 .333 r
.52376 .65227 m .52601 .6535 L .52666 .65182 L F
0 0 0 r
.52632 .65167 m .52476 .65491 L .52491 .6537 L F
.52476 .65491 m .52452 .65542 L .52489 .6538 L F
.52476 .65491 m .52489 .6538 L .52491 .6537 L F
.86 .554 .469 r
.52475 .6535 m .52473 .65351 L .52481 .65296 L F
.034 .03 .52 r
.52373 .65356 m .52397 .65816 L .52452 .65542 L F
.86 .554 .469 r
.52473 .65351 m .52153 .6555 L .52479 .65298 L F
.52473 .65351 m .52479 .65298 L .52481 .65296 L F
.52452 .65542 m .5235 .65545 L .52475 .6535 L F
.5235 .65545 m .52153 .6555 L .52475 .6535 L F
.517 .135 .255 r
.52473 .65353 m .52476 .65353 L .52474 .65351 L F
.86 .554 .469 r
.52489 .6538 m .52481 .65296 L .52491 .6537 L F
.52475 .6535 m .52481 .65296 L .52489 .6538 L F
.793 .6 .64 r
.52481 .65296 m .51891 .65319 L .51891 .65029 L F
.52431 .65277 m .51891 .65029 L .51969 .65099 L F
.52481 .65296 m .52428 .65272 L .52431 .65277 L F
.52428 .65272 m .51891 .65029 L .52431 .65277 L F
.796 .532 0 r
.52393 .64941 m .52477 .65277 L .51969 .65099 L F
.52477 .65277 m .52459 .65288 L .51969 .65099 L F
.505 .052 .109 r
.52481 .65296 m .51891 .65534 L .51891 .65319 L F
.323 0 .236 r
.52345 .65358 m .52373 .65356 L .52373 .65341 L F
.505 .052 .109 r
.52445 .65311 m .52153 .6555 L .51891 .65534 L F
.52481 .65296 m .52453 .65318 L .52445 .65311 L F
.52453 .65318 m .52153 .6555 L .52445 .65311 L F
.023 .15 .659 r
.52597 .65134 m .52502 .65355 L .52393 .64941 L F
.796 .532 0 r
.52477 .65277 m .52481 .65296 L .52459 .65288 L F
.52393 .64941 m .52491 .6537 L .52481 .65296 L F
.023 .15 .659 r
.52502 .65355 m .52487 .65343 L .52393 .64941 L F
.52492 .65368 m .5249 .65365 L .52393 .64941 L F
.709 .624 .761 r
.52393 .64941 m .51969 .65099 L .52082 .6475 L F
.52393 .64941 m .52082 .6475 L .52287 .64721 L F
.495 .675 .945 r
.52634 .6483 m .52393 .64941 L .52287 .64721 L F
.52634 .6483 m .52705 .64972 L .52393 .64941 L F
.023 .15 .659 r
.52632 .65167 m .52393 .64941 L .52705 .64972 L F
.85 .732 .733 r
.52107 .64789 m .52116 .65061 L .52555 .64939 L F
.52551 .64918 m .52555 .64939 L .52589 .64929 L F
.52107 .64789 m .52555 .64939 L .52551 .64918 L F
.023 .15 .659 r
.52632 .65167 m .5261 .65198 L .52597 .65134 L F
.5261 .65198 m .52502 .65355 L .52597 .65134 L F
.52502 .65355 m .52492 .65368 L .52487 .65343 L F
.52492 .65368 m .52491 .6537 L .5249 .65365 L F
.906 .632 .131 r
.5601 .66554 m .56094 .66896 L .5594 .66703 L F
.826 .998 .784 r
.49241 .71456 m .4929 .71516 L .49409 .71494 L F
.49241 .71456 m .49105 .71596 L .4929 .71516 L F
.459 .711 .977 r
.78284 .48376 m .78522 .48364 L .78376 .48507 L F
.461 .715 .978 r
.78522 .48364 m .78615 .48494 L .78376 .48507 L F
.489 .212 .419 r
.58209 .58168 m .58012 .5795 L .57933 .58187 L F
.58209 .58168 m .5825 .57914 L .58012 .5795 L F
.51 .335 .579 r
.29743 .60215 m .29962 .59953 L .29757 .60012 L F
.242 .247 .665 r
.55644 .66843 m .55498 .66599 L .5566 .66589 L F
.099 0 0 r
.52477 .68282 m .52292 .68362 L .5218 .68346 L F
.209 .021 .392 r
.52694 .67999 m .5265 .68251 L .52477 .68282 L F
0 0 0 r
.5265 .68251 m .52292 .68362 L .52477 .68282 L F
.756 .678 .775 r
.33295 .6426 m .33443 .64571 L .33689 .64331 L F
.535 .329 .547 r
.33443 .64571 m .33663 .64603 L .33689 .64331 L F
.253 0 0 r
.37949 .61958 m .37884 .62022 L .38184 .61911 L F
.788 .421 .361 r
.50275 .68304 m .50636 .68549 L .50541 .68296 L F
.741 .514 .586 r
.68067 .49309 m .68239 .49465 L .68379 .49402 L F
.867 .53 .411 r
.68239 .49465 m .68437 .49651 L .68379 .49402 L F
.187 0 0 r
.35376 .59775 m .35203 .59857 L .34997 .59866 L F
0 0 0 r
.35424 .59787 m .35376 .59775 L .35564 .59804 L F
.35424 .59787 m .35203 .59857 L .35376 .59775 L F
.221 0 0 r
.35597 .59772 m .35564 .59804 L .35376 .59775 L F
.472 .497 .803 r
.4211 .59572 m .41934 .59745 L .41819 .59397 L F
.485 .52 .818 r
.4211 .59572 m .422 .5983 L .41934 .59745 L F
.421 .444 .779 r
.44996 .68817 m .45103 .69215 L .44921 .69163 L F
.168 0 0 r
.36856 .63809 m .36678 .63909 L .36453 .63935 L F
.152 0 0 r
.37074 .63766 m .36678 .63909 L .36856 .63809 L F
.729 .866 .946 r
.56925 .62592 m .56668 .62559 L .56803 .62503 L F
.873 .871 .832 r
.5664 .62697 m .56925 .62592 L .56803 .62503 L F
.827 .899 .892 r
.56301 .60204 m .56424 .60296 L .56716 .60035 L F
.649 .343 .439 r
.40057 .61024 m .40306 .6107 L .40394 .60788 L F
.426 .113 .33 r
.40306 .6107 m .40625 .60758 L .40394 .60788 L F
.633 .509 .693 r
.52517 .67166 m .52603 .67515 L .5229 .67468 L F
.81 .48 .431 r
.52227 .67586 m .52603 .67515 L .5229 .67468 L F
.986 .728 .348 r
.59959 .61684 m .59864 .61349 L .59975 .61444 L F
.386 0 0 r
.44286 .70678 m .44166 .70614 L .44013 .70524 L F
.505 .643 .918 r
.44166 .70614 m .44297 .70413 L .43953 .70502 L F
.627 .102 0 r
.44013 .70524 m .44166 .70614 L .43828 .70542 L F
.205 0 0 r
.43828 .70542 m .44166 .70614 L .43793 .70543 L F
.505 .643 .918 r
.44166 .70614 m .43953 .70502 L .43793 .70543 L F
.386 0 0 r
.44294 .70682 m .44166 .70614 L .44286 .70678 L F
.281 .591 .947 r
.44294 .70682 m .44424 .70581 L .44166 .70614 L F
.44294 .70682 m .44572 .70743 L .44424 .70581 L F
.953 .718 .545 r
.61564 .60844 m .61429 .60506 L .61432 .60827 L F
.965 .727 .529 r
.61486 .61031 m .61564 .60844 L .61432 .60827 L F
.61486 .61031 m .61578 .61141 L .61564 .60844 L F
.282 .784 .814 r
.59341 .67368 m .59108 .67439 L .5938 .67363 L F
.59341 .67368 m .59115 .67427 L .59108 .67439 L F
.676 .269 .266 r
.4294 .60193 m .43266 .60256 L .43364 .60198 L F
0 .164 .689 r
.57432 .63688 m .57641 .63916 L .57546 .63998 L F
.038 .293 .785 r
.57641 .63916 m .57812 .64208 L .57546 .63998 L F
.75 .6 .69 r
.55498 .66599 m .55561 .66934 L .55111 .66932 L F
.242 .247 .665 r
.55644 .66843 m .55561 .66934 L .55498 .66599 L F
.886 .857 .808 r
.46485 .70036 m .46134 .70208 L .46423 .69988 L F
.255 .347 .766 r
.46103 .68262 m .45826 .68016 L .4607 .68027 L F
.342 .014 .256 r
.46234 .65707 m .45942 .66001 L .46162 .65962 L F
.423 .123 .348 r
.46467 .65664 m .46234 .65707 L .46162 .65962 L F
.851 .529 .443 r
.59502 .59377 m .59167 .59062 L .5948 .59145 L F
.984 .906 .606 r
.7442 .50101 m .74385 .50307 L .74561 .49983 L F
.602 .896 .988 r
.75404 .5265 m .75559 .52477 L .75261 .52564 L F
.75404 .5265 m .75654 .52547 L .75559 .52477 L F
.948 .702 .533 r
.59867 .57351 m .60075 .5769 L .60226 .57438 L F
.703 .711 .854 r
.38559 .59342 m .38915 .59429 L .38779 .59321 L F
0 .207 .719 r
.38915 .59429 m .3902 .59449 L .38779 .59321 L F
.38915 .59429 m .39113 .59584 L .3902 .59449 L F
.606 .861 .992 r
.35347 .5828 m .35201 .58197 L .3543 .58119 L F
.429 .651 .952 r
.3543 .58119 m .35543 .58274 L .35347 .5828 L F
.606 .861 .992 r
.35347 .5828 m .35201 .58197 L .3543 .58119 L F
.847 .827 .827 r
.79026 .51691 m .79344 .51671 L .79279 .51599 L F
.931 .638 .167 r
.79247 .51355 m .79279 .51599 L .79344 .51671 L F
.76 .675 .768 r
.79247 .51355 m .79344 .51671 L .79587 .51386 L F
.671 .794 .94 r
.74998 .48412 m .75122 .48597 L .75337 .48466 L F
.149 0 0 r
.35755 .59775 m .35597 .59772 L .35956 .59676 L F
0 0 0 r
.36016 .59698 m .35956 .59676 L .36173 .59656 L F
.36016 .59698 m .35755 .59775 L .35956 .59676 L F
.572 .331 .512 r
.46652 .67722 m .46384 .67943 L .46438 .67731 L F
0 0 .039 r
.61134 .65714 m .61129 .65934 L .61121 .65857 L F
0 0 .391 r
.61135 .65414 m .61177 .65676 L .61134 .65714 L F
0 0 .103 r
.61177 .65676 m .61129 .65934 L .61134 .65714 L F
.514 .525 .806 r
.55149 .6542 m .5531 .65814 L .55435 .6569 L F
.967 .669 .407 r
.73222 .48436 m .73255 .48678 L .73361 .48579 L F
.684 .98 .848 r
.54133 .65641 m .54105 .65545 L .54017 .65341 L F
.722 .69 .819 r
.22207 .55828 m .21875 .55708 L .22079 .55665 L F
.27 .523 .91 r
.22273 .55677 m .22207 .55828 L .22079 .55665 L F
.7 .536 .663 r
.22595 .55906 m .22426 .56164 L .22207 .55828 L F
.22595 .55906 m .22207 .55828 L .22524 .55999 L F
.22595 .55906 m .22524 .55999 L .22581 .56029 L F
.628 .962 .849 r
.22526 .55994 m .22524 .55999 L .22595 .55906 L F
.22424 .5613 m .22426 .56164 L .22476 .56088 L F
.22512 .56014 m .22476 .56088 L .22595 .55906 L F
.22424 .5613 m .22476 .56088 L .22512 .56014 L F
0 0 .255 r
.22595 .55906 m .22581 .56029 L .227 .55884 L F
.27 .523 .91 r
.22526 .55994 m .22581 .56029 L .22524 .55999 L F
0 0 0 r
.227 .55884 m .22516 .56006 L .22595 .55906 L F
.27 .523 .91 r
.22532 .55973 m .22545 .55987 L .22526 .55994 L F
.22545 .55987 m .22581 .56029 L .22526 .55994 L F
.628 .962 .849 r
.22424 .56124 m .22424 .5613 L .22524 .55999 L F
.22424 .56124 m .22524 .55999 L .22526 .55994 L F
0 0 0 r
.22545 .55987 m .22424 .56124 L .22516 .56006 L F
.6 .675 .893 r
.227 .55884 m .22581 .56029 L .22545 .55987 L F
0 0 0 r
.227 .55884 m .22607 .55964 L .22545 .55987 L F
.22607 .55964 m .22424 .56124 L .22545 .55987 L F
.6 .675 .893 r
.227 .55884 m .22545 .55987 L .22532 .55973 L F
.22474 .55776 m .22532 .55973 L .22495 .5593 L F
.22472 .55775 m .22495 .5593 L .22279 .55684 L F
.22474 .55776 m .22495 .5593 L .22472 .55775 L F
.227 .55884 m .22279 .55684 L .22273 .55677 L F
.27 .523 .91 r
.22273 .55678 m .22495 .55931 L .22207 .55828 L F
.22495 .55931 m .22532 .55973 L .22508 .55963 L F
.22495 .55931 m .22508 .55963 L .22207 .55828 L F
.22279 .55684 m .22532 .55973 L .22273 .55678 L F
.22532 .55973 m .22524 .55999 L .22207 .55828 L F
.927 .827 .727 r
.22476 .55761 m .22473 .55774 L .22474 .55776 L F
.22476 .55761 m .22474 .55776 L .227 .55884 L F
.6 .675 .893 r
.227 .55884 m .22473 .55774 L .22476 .55761 L F
.22473 .55774 m .22273 .55677 L .22476 .55761 L F
.927 .827 .727 r
.22476 .55761 m .22471 .55768 L .22473 .55774 L F
.712 .715 .188 r
.22273 .55677 m .22297 .55556 L .22476 .55761 L F
.914 .865 .777 r
.22324 .55602 m .2227 .56039 L .22443 .55806 L F
.22291 .55666 m .2227 .56039 L .22324 .55602 L F
.658 .313 .378 r
.22426 .56164 m .22251 .56249 L .22041 .56161 L F
0 .415 .798 r
.22041 .56161 m .22251 .56249 L .22069 .56139 L F
.714 .854 .949 r
.22069 .56139 m .22251 .56249 L .22424 .56124 L F
.22069 .56139 m .22424 .56124 L .2227 .56039 L F
.041 0 .368 r
.22114 .55958 m .22069 .56139 L .2227 .56039 L F
.27 .523 .91 r
.22273 .55677 m .22279 .55684 L .22273 .55678 L F
.698 .165 0 r
.21985 .55517 m .22273 .55677 L .22079 .55665 L F
.914 .865 .777 r
.22278 .55897 m .22114 .55958 L .2227 .56039 L F
.698 .165 0 r
.21985 .55517 m .22237 .5576 L .22273 .55677 L F
.914 .865 .777 r
.22285 .55767 m .22237 .5576 L .22278 .55897 L F
.698 .165 0 r
.22237 .5576 m .22247 .5577 L .22249 .55762 L F
.22237 .5576 m .22249 .55762 L .22273 .55677 L F
.914 .865 .777 r
.22297 .55556 m .22232 .55746 L .22237 .5576 L F
.22297 .55556 m .22237 .5576 L .22249 .55762 L F
.712 .715 .188 r
.22273 .55677 m .22249 .55762 L .22297 .55556 L F
.914 .865 .777 r
.22297 .55556 m .22249 .55762 L .22285 .55767 L F
.712 .715 .188 r
.22249 .55762 m .22247 .5577 L .22297 .55556 L F
.647 .558 .74 r
.22297 .55556 m .22247 .5577 L .22232 .55746 L F
.22297 .55556 m .22232 .55746 L .22001 .55366 L F
.914 .865 .777 r
.22297 .55556 m .22224 .55717 L .22232 .55746 L F
0 .184 .714 r
.22001 .55366 m .22232 .55746 L .21985 .55517 L F
.22232 .55746 m .22237 .5576 L .21985 .55517 L F
.914 .865 .777 r
.22224 .55717 m .22114 .55958 L .22278 .55897 L F
0 .184 .714 r
.22232 .55746 m .22247 .5577 L .22237 .5576 L F
.463 .258 .516 r
.22312 .55915 m .22091 .56201 L .22108 .56018 L F
.22142 .55952 m .22108 .56018 L .22114 .55958 L F
.22312 .55915 m .22108 .56018 L .22142 .55952 L F
.914 .865 .777 r
.22297 .55556 m .22291 .55666 L .22324 .55602 L F
.22384 .55662 m .22443 .55806 L .22471 .55768 L F
.22297 .55556 m .22443 .55806 L .22384 .55662 L F
.22469 .55753 m .22471 .55768 L .22476 .55761 L F
.22297 .55556 m .22471 .55768 L .22469 .55753 L F
.927 .827 .727 r
.22474 .55776 m .2227 .56039 L .22424 .56124 L F
.22471 .55768 m .2227 .56039 L .22474 .55776 L F
.6 .675 .893 r
.226 .55836 m .22541 .55955 L .22474 .55776 L F
.22541 .55955 m .22532 .55973 L .22474 .55776 L F
.227 .55884 m .22532 .55973 L .226 .55836 L F
.927 .827 .727 r
.22474 .55776 m .22464 .55842 L .227 .55884 L F
.22464 .55842 m .22424 .56124 L .22607 .55964 L F
.22464 .55842 m .22607 .55964 L .227 .55884 L F
.327 .729 .981 r
.50927 .64047 m .50768 .63961 L .50587 .63963 L F
.64 .116 0 r
.50927 .64047 m .50819 .64144 L .50768 .63961 L F
.50927 .64047 m .51174 .64215 L .50819 .64144 L F
.473 .476 .78 r
.5108 .64594 m .5127 .64544 L .51174 .64215 L F
.312 .402 .794 r
.5108 .64594 m .51336 .6478 L .5127 .64544 L F
.805 .498 .469 r
.67733 .49232 m .68035 .49096 L .67679 .49081 L F
.67733 .49232 m .68067 .49309 L .68035 .49096 L F
.897 .811 .755 r
.57155 .59945 m .57291 .60009 L .5727 .59628 L F
.832 .581 .559 r
.57106 .60187 m .57291 .60009 L .57155 .59945 L F
.57106 .60187 m .57265 .60252 L .57291 .60009 L F
.748 .352 .302 r
.51098 .66274 m .51313 .66486 L .51453 .66333 L F
.766 .321 .194 r
.55503 .67088 m .55111 .66932 L .55561 .66934 L F
0 0 .087 r
.55644 .66843 m .55503 .67088 L .55561 .66934 L F
.068 .343 .819 r
.53399 .61435 m .53448 .61311 L .53212 .61169 L F
.143 .212 .676 r
.21615 .56451 m .21595 .56853 L .21427 .565 L F
.21615 .56451 m .21676 .56782 L .21595 .56853 L F
.366 .239 .573 r
.21676 .56782 m .21537 .57082 L .21595 .56853 L F
.133 0 0 r
.5513 .67003 m .54753 .67056 L .54883 .67013 L F
.268 0 .033 r
.55111 .66932 m .5513 .67003 L .54883 .67013 L F
.492 .324 .58 r
.54608 .64568 m .54395 .64663 L .54584 .64307 L F
.948 .907 .527 r
.47389 .66793 m .47483 .66567 L .47431 .66481 L F
.854 .589 .536 r
.47689 .66911 m .47483 .66567 L .47389 .66793 L F
.868 .614 .554 r
.6008 .58108 m .60384 .57994 L .60046 .57933 L F
.6008 .58108 m .60385 .58235 L .60384 .57994 L F
.681 .76 .911 r
.33295 .6426 m .33689 .64331 L .33587 .64177 L F
.502 .673 .941 r
.33587 .64177 m .33689 .64331 L .33793 .64232 L F
.469 .273 .531 r
.33689 .64331 m .33878 .6453 L .33793 .64232 L F
.33689 .64331 m .33663 .64603 L .33878 .6453 L F
.43 .115 .327 r
.52384 .66597 m .52608 .66561 L .52674 .6637 L F
.486 .185 .38 r
.52608 .66561 m .52828 .66343 L .52674 .6637 L F
0 0 0 r
.53325 .60195 m .53602 .59906 L .5336 .59997 L F
.457 .667 .953 r
.7303 .51331 m .73162 .51173 L .72848 .51075 L F
.7303 .51331 m .73246 .51325 L .73162 .51173 L F
0 .429 .699 r
.45814 .7023 m .45841 .7024 L .45684 .70207 L F
.45814 .7023 m .45971 .70272 L .45841 .7024 L F
.428 .118 .336 r
.42239 .61202 m .42198 .61374 L .41979 .61426 L F
.585 .318 .478 r
.42508 .61118 m .42198 .61374 L .42239 .61202 L F
.365 .831 .774 r
.79129 .52628 m .79266 .52598 L .79502 .52502 L F
.986 .736 .464 r
.54502 .6395 m .54444 .64234 L .54584 .64307 L F
.492 .324 .58 r
.54608 .64568 m .54584 .64307 L .54444 .64234 L F
.688 .581 .73 r
.54502 .6395 m .54584 .64307 L .5484 .64051 L F
.427 .801 .993 r
.38631 .58544 m .3885 .58511 L .38994 .58582 L F
.558 .859 .997 r
.38994 .58582 m .39069 .58442 L .39216 .58534 L F
.38994 .58582 m .3885 .58511 L .39069 .58442 L F
.741 .403 .409 r
.74186 .50325 m .74385 .50307 L .74275 .50312 L F
.029 .045 .54 r
.61273 .64421 m .6109 .64359 L .61248 .64173 L F
.61273 .64421 m .61152 .64573 L .6109 .64359 L F
.102 0 0 r
.58813 .64998 m .59108 .64903 L .59153 .64783 L F
.317 .806 .801 r
.59364 .64708 m .59441 .64694 L .59153 .64783 L F
.843 .638 .624 r
.59108 .64903 m .59364 .64708 L .59153 .64783 L F
.308 .106 .434 r
.21591 .57317 m .21382 .57632 L .21404 .57402 L F
0 0 0 r
.61236 .63689 m .6132 .63464 L .61396 .63305 L F
.357 .291 .644 r
.43442 .69192 m .43644 .6937 L .436 .69124 L F
.43442 .69192 m .43445 .69518 L .43644 .6937 L F
.64 .854 .981 r
.7594 .51075 m .75596 .51067 L .75842 .50975 L F
.499 .769 .992 r
.76085 .50933 m .7594 .51075 L .75842 .50975 L F
.76085 .50933 m .76183 .51045 L .7594 .51075 L F
.753 .702 .804 r
.31967 .63719 m .32361 .63898 L .32223 .63655 L F
.562 .655 .898 r
.32223 .63655 m .32361 .63898 L .32579 .63792 L F
.345 .759 .979 r
.31909 .63364 m .31709 .63309 L .31708 .63409 L F
.532 .903 .96 r
.31709 .63309 m .31467 .63407 L .31708 .63409 L F
.324 .152 .487 r
.49901 .68537 m .5013 .68429 L .50059 .68301 L F
.857 .649 .621 r
.6075 .58761 m .60884 .58582 L .60769 .58555 L F
.6075 .58761 m .60881 .58837 L .60884 .58582 L F
.492 .563 .856 r
.57189 .62997 m .57024 .63213 L .5697 .63012 L F
.318 .32 .703 r
.57189 .62997 m .57242 .6343 L .57024 .63213 L F
.637 .702 .893 r
.7792 .49311 m .78265 .49403 L .78166 .49232 L F
.667 .756 .917 r
.78265 .49403 m .78428 .49152 L .78166 .49232 L F
.78265 .49403 m .78514 .49316 L .78428 .49152 L F
.391 .074 .303 r
.45477 .6634 m .45197 .66579 L .45409 .66524 L F
.395 .07 .293 r
.45477 .6634 m .45409 .66524 L .45696 .66287 L F
.541 .094 .139 r
.5745 .59417 m .57342 .59544 L .57312 .59457 L F
.043 0 0 r
.5762 .59376 m .57342 .59544 L .5745 .59417 L F
.655 .625 .808 r
.39811 .5974 m .4019 .59983 L .40041 .5974 L F
.728 .756 .875 r
.40041 .5974 m .4019 .59983 L .40355 .59776 L F
.653 .638 .823 r
.4019 .59983 m .40466 .59961 L .40355 .59776 L F
.776 .598 .659 r
.52931 .65405 m .52728 .6567 L .52793 .65501 L F
.427 .041 .202 r
.41172 .61771 m .41361 .61856 L .41119 .61884 L F
.432 .029 .172 r
.41463 .61683 m .41361 .61856 L .41172 .61771 L F
.255 0 0 r
.36537 .59633 m .36396 .59671 L .36173 .59656 L F
0 0 0 r
.36759 .59597 m .36396 .59671 L .36537 .59633 L F
.725 .224 0 r
.53721 .61737 m .53762 .61866 L .53606 .61641 L F
.53721 .61737 m .53893 .61965 L .53762 .61866 L F
.976 .8 .601 r
.59661 .60549 m .59591 .60207 L .59751 .60303 L F
.359 .18 .497 r
.48057 .65718 m .47799 .6603 L .47764 .65885 L F
.48057 .65718 m .47991 .65968 L .47799 .6603 L F
0 0 .084 r
.47991 .65968 m .47841 .66205 L .47799 .6603 L F
.139 0 0 r
.47661 .67844 m .4745 .67918 L .47211 .67943 L F
.962 .879 .705 r
.47577 .67709 m .47661 .67844 L .4778 .67805 L F
.47577 .67709 m .4745 .67918 L .47661 .67844 L F
.611 .788 .966 r
.36227 .62594 m .36016 .6267 L .3584 .62529 L F
.646 .089 0 r
.50991 .62724 m .50996 .62728 L .51118 .6281 L F
.988 .759 .5 r
.51244 .62895 m .51118 .6281 L .51245 .629 L F
0 .089 .618 r
.51375 .62985 m .51245 .629 L .51118 .6281 L F
.646 .089 0 r
.50996 .62728 m .51375 .62985 L .51118 .6281 L F
.988 .759 .5 r
.51149 .62537 m .51118 .6281 L .51244 .62895 L F
.681 .135 0 r
.51245 .629 m .51497 .63143 L .51619 .63184 L F
0 .089 .618 r
.51375 .62985 m .51497 .63143 L .51245 .629 L F
.574 .389 .593 r
.43928 .67464 m .44165 .6743 L .44169 .67178 L F
.339 .185 .52 r
.43928 .67464 m .44093 .676 L .44165 .6743 L F
.43928 .67464 m .43914 .677 L .44093 .676 L F
.6 .659 .879 r
.74442 .52485 m .74555 .52139 L .74312 .52198 L F
.74442 .52485 m .7472 .52442 L .74555 .52139 L F
.519 .459 .728 r
.43445 .69518 m .43736 .69675 L .43644 .6937 L F
.43445 .69518 m .43516 .6973 L .43736 .69675 L F
.486 .223 .44 r
.44165 .6743 m .44428 .67177 L .44169 .67178 L F
0 0 0 r
.60197 .66869 m .60375 .66762 L .60225 .66895 L F
.309 0 .172 r
.39857 .62549 m .39745 .62784 L .39534 .62848 L F
.304 0 .126 r
.40073 .6251 m .39745 .62784 L .39857 .62549 L F
.437 .248 .524 r
.33489 .60847 m .33469 .61096 L .33273 .61142 L F
.942 .91 .758 r
.5856 .65796 m .58456 .65907 L .58582 .65575 L F
.585 .294 .441 r
.42784 .60846 m .42995 .61042 L .42755 .61068 L F
.42784 .60846 m .43035 .60843 L .42995 .61042 L F
.413 .676 .97 r
.19916 .54486 m .19889 .54647 L .19724 .54517 L F
.19916 .54486 m .20121 .54656 L .19889 .54647 L F
.028 0 0 r
.49597 .69133 m .49316 .69351 L .49417 .69219 L F
.49597 .69133 m .49316 .69351 L .49417 .69219 L F
.685 .63 .788 r
.48205 .6656 m .48368 .6627 L .4827 .66496 L F
.928 .74 .628 r
.61429 .60506 m .61468 .60269 L .61352 .60206 L F
.723 .396 .425 r
.60883 .59334 m .61224 .59199 L .60875 .59096 L F
.60883 .59334 m .61253 .5939 L .61224 .59199 L F
.395 .488 .836 r
.74126 .52215 m .74173 .51901 L .73985 .51863 L F
.74126 .52215 m .74312 .52198 L .74173 .51901 L F
.524 .238 .423 r
.49789 .65714 m .50028 .65683 L .50069 .6549 L F
.544 .297 .491 r
.50028 .65683 m .50266 .65435 L .50069 .6549 L F
.137 .653 .891 r
.53166 .63436 m .53486 .63421 L .53506 .63492 L F
.455 0 0 r
.53486 .63421 m .53734 .63493 L .53506 .63492 L F
.416 .22 .504 r
.21634 .56128 m .21427 .565 L .21434 .56262 L F
.633 .349 .469 r
.49137 .71215 m .49378 .71381 L .49503 .71227 L F
.707 .321 .316 r
.49378 .71381 m .49728 .71417 L .49503 .71227 L F
.768 .636 .716 r
.79247 .51355 m .79587 .51386 L .79481 .51096 L F
.512 .36 .611 r
.79587 .51386 m .79801 .51083 L .79481 .51096 L F
.79587 .51386 m .79815 .51381 L .79801 .51083 L F
.684 .178 .032 r
.50227 .62226 m .50441 .62403 L .50564 .62314 L F
.602 .075 0 r
.50441 .62403 m .50821 .62458 L .50564 .62314 L F
.073 0 0 r
.51823 .68332 m .5218 .68346 L .52044 .68345 L F
.507 .023 .041 r
.52292 .68362 m .52044 .68345 L .5218 .68346 L F
.685 .49 .618 r
.51834 .68041 m .5164 .68037 L .51714 .67982 L F
.51834 .68041 m .51601 .68253 L .51454 .68033 L F
.565 .298 .47 r
.51578 .68165 m .51783 .6793 L .51714 .67982 L F
.892 .933 .837 r
.51834 .68041 m .51714 .67982 L .51943 .67677 L F
.565 .298 .47 r
.51783 .6793 m .51848 .67856 L .51714 .67982 L F
.685 .49 .618 r
.5164 .68037 m .51454 .68033 L .51714 .67982 L F
.51834 .68041 m .51823 .68332 L .51601 .68253 L F
.892 .933 .837 r
.51834 .68041 m .51943 .67677 L .52062 .67802 L F
.487 .295 .545 r
.49515 .64758 m .49278 .64593 L .495 .64517 L F
.49515 .64758 m .49253 .64839 L .49278 .64593 L F
.164 .31 .766 r
.55434 .65446 m .55667 .65643 L .55584 .65732 L F
.132 .259 .729 r
.55667 .65643 m .55756 .66017 L .55584 .65732 L F
.76 .443 .449 r
.48196 .71389 m .48417 .71155 L .48185 .71148 L F
.48196 .71389 m .48584 .71447 L .48417 .71155 L F
.612 .806 .974 r
.45276 .71135 m .45626 .71173 L .45499 .71096 L F
0 .407 .772 r
.45626 .71173 m .45809 .71212 L .45499 .71096 L F
.45626 .71173 m .45831 .71253 L .45809 .71212 L F
.556 .636 .885 r
.30465 .61995 m .30504 .61663 L .30312 .61666 L F
.30465 .61995 m .30674 .61948 L .30504 .61663 L F
.501 .267 .492 r
.30469 .62129 m .30674 .61948 L .30465 .61995 L F
.683 .741 .895 r
.67931 .50203 m .68321 .50274 L .68112 .50136 L F
.614 .552 .762 r
.40466 .59961 m .40551 .60262 L .40785 .60215 L F
.807 .622 .652 r
.48746 .69113 m .49008 .69369 L .48863 .69165 L F
.632 .787 .956 r
.54846 .64483 m .54916 .64633 L .54608 .64568 L F
0 .239 .754 r
.55098 .64674 m .54916 .64633 L .54846 .64483 L F
.55098 .64674 m .55139 .64818 L .54916 .64633 L F
.224 .726 .905 r
.36227 .62594 m .36418 .62583 L .36583 .62617 L F
.277 0 0 r
.36418 .62583 m .36801 .62548 L .36583 .62617 L F
.578 .356 .542 r
.33979 .60284 m .33956 .60524 L .33716 .60555 L F
.547 .384 .611 r
.34173 .6022 m .33956 .60524 L .33979 .60284 L F
0 0 .356 r
.47389 .66793 m .47537 .67203 L .47689 .66911 L F
.47389 .66793 m .47533 .67134 L .47537 .67203 L F
.298 .082 .408 r
.47639 .67348 m .47537 .67203 L .47533 .67134 L F
.47639 .67348 m .47453 .6743 L .47537 .67203 L F
.246 .22 .631 r
.80431 .50118 m .80302 .5049 L .80188 .5017 L F
.80431 .50118 m .80504 .50348 L .80302 .5049 L F
.277 .277 .679 r
.80504 .50348 m .80525 .50677 L .80302 .5049 L F
.338 .279 .643 r
.80302 .5049 m .80525 .50677 L .80378 .50804 L F
.535 .585 .851 r
.7472 .52442 m .74755 .52613 L .74939 .52391 L F
.541 .594 .856 r
.74755 .52613 m .75014 .52636 L .74939 .52391 L F
.602 .258 .359 r
.53253 .6781 m .53227 .67963 L .52935 .67935 L F
.065 .627 .776 r
.53572 .6797 m .53253 .6781 L .5353 .67756 L F
.53572 .6797 m .53227 .67963 L .53253 .6781 L F
.787 .336 .175 r
.54457 .62281 m .54322 .62372 L .54275 .62265 L F
.109 .647 .855 r
.54732 .62409 m .54322 .62372 L .54457 .62281 L F
.518 .364 .611 r
.29962 .59953 m .30168 .59653 L .2997 .5972 L F
.659 .376 .48 r
.78659 .51304 m .78902 .51331 L .78904 .51125 L F
.654 .551 .725 r
.78904 .51125 m .79273 .511 L .79124 .50748 L F
.75 .452 .479 r
.78904 .51125 m .79247 .51355 L .79273 .511 L F
.78904 .51125 m .78902 .51331 L .79247 .51355 L F
.451 .246 .509 r
.43736 .69675 m .43516 .6973 L .43717 .69952 L F
.64 .248 .285 r
.43717 .69952 m .43516 .6973 L .43369 .6992 L F
.794 .545 .562 r
.74998 .48412 m .75317 .48221 L .74979 .48161 L F
.74998 .48412 m .75337 .48466 L .75317 .48221 L F
.75 .513 .571 r
.75317 .48221 m .75337 .48466 L .75669 .48484 L F
.705 .653 .796 r
.52517 .67166 m .52767 .67205 L .52635 .66767 L F
.016 0 .2 r
.52603 .67515 m .52767 .67205 L .52517 .67166 L F
.343 .093 .383 r
.52767 .67205 m .53014 .67391 L .53168 .66932 L F
.52767 .67205 m .52611 .67613 L .53014 .67391 L F
.592 .268 .39 r
.38184 .61911 m .38424 .61926 L .3848 .61747 L F
.514 .203 .378 r
.38424 .61926 m .38714 .61716 L .3848 .61747 L F
.702 .442 .527 r
.50444 .6603 m .50138 .66219 L .50173 .66058 L F
.618 .716 .916 r
.73719 .51929 m .73864 .51622 L .73581 .51647 L F
.73719 .51929 m .73985 .51863 L .73864 .51622 L F
.598 .54 .761 r
.66512 .49064 m .66854 .49352 L .6675 .4901 L F
.154 .47 .893 r
.4864 .67872 m .48635 .67984 L .48371 .67743 L F
.74 .973 .927 r
.4864 .67872 m .4843 .68016 L .48635 .67984 L F
.114 .348 .814 r
.73431 .51627 m .73503 .51504 L .73246 .51325 L F
.17 .423 .86 r
.73431 .51627 m .73581 .51647 L .73503 .51504 L F
.563 .053 0 r
.49149 .68086 m .48983 .68192 L .48748 .68076 L F
.689 .954 .695 r
.49201 .67994 m .49149 .68086 L .49357 .68001 L F
.49201 .67994 m .48983 .68192 L .49149 .68086 L F
.787 .838 .891 r
.79815 .51381 m .80139 .51339 L .80148 .51343 L F
.352 .262 .612 r
.80348 .50987 m .80139 .51339 L .80144 .51049 L F
.80348 .50987 m .80386 .51286 L .80139 .51339 L F
.651 .327 .41 r
.80386 .51286 m .80148 .51343 L .80139 .51339 L F
.569 .867 .996 r
.33878 .6453 m .34019 .646 L .34232 .64528 L F
.492 .434 .72 r
.51597 .65763 m .51931 .65995 L .51979 .65926 L F
.232 .064 .436 r
.47244 .64898 m .47394 .65019 L .47475 .64827 L F
.47244 .64898 m .47242 .65133 L .47394 .65019 L F
.41 .229 .522 r
.53608 .66835 m .53419 .6716 L .53342 .66846 L F
.549 .872 .993 r
.79801 .51083 m .80144 .51049 L .801 .50956 L F
.416 .286 .595 r
.79801 .51083 m .80056 .51077 L .80144 .51049 L F
0 .247 .742 r
.80144 .51049 m .80194 .51007 L .801 .50956 L F
.386 .375 .725 r
.80056 .51077 m .80194 .51007 L .80144 .51049 L F
.32 .097 .41 r
.80378 .50804 m .80348 .50987 L .80144 .51049 L F
.486 .369 .646 r
.43507 .68306 m .43715 .68259 L .43675 .68012 L F
.449 .337 .634 r
.43507 .68306 m .43738 .68502 L .43715 .68259 L F
.43507 .68306 m .43545 .68575 L .43738 .68502 L F
.598 .04 0 r
.46773 .69997 m .47003 .70041 L .4684 .70255 L F
.626 .411 .57 r
.47003 .70041 m .46893 .70561 L .4684 .70255 L F
.47003 .70041 m .47138 .70524 L .46893 .70561 L F
0 0 .474 r
.47213 .70218 m .47138 .70524 L .47003 .70041 L F
.598 .04 0 r
.46773 .69997 m .47073 .70154 L .47003 .70041 L F
.468 0 0 r
.47073 .70154 m .47213 .70218 L .47003 .70041 L F
0 0 .299 r
.55476 .6075 m .55459 .6094 L .55634 .60901 L F
.55462 .6091 m .55315 .61179 L .55459 .6094 L F
.55401 .6095 m .55315 .61179 L .55462 .6091 L F
.55476 .6075 m .55401 .6095 L .55462 .6091 L F
.55476 .6075 m .55455 .61025 L .55315 .61179 L F
.398 0 0 r
.55138 .61178 m .55455 .61025 L .55382 .60963 L F
.55229 .61064 m .55382 .60963 L .5534 .60926 L F
.55138 .61178 m .55382 .60963 L .55229 .61064 L F
.201 .679 .934 r
.50821 .62458 m .51149 .62537 L .50975 .62522 L F
.683 .6 .756 r
.66638 .49898 m .66888 .49597 L .66634 .49649 L F
.432 .211 .476 r
.30206 .59432 m .30368 .59593 L .30407 .59366 L F
.30206 .59432 m .30168 .59653 L .30368 .59593 L F
.52 .133 .247 r
.57109 .58481 m .57362 .58478 L .57455 .58275 L F
.602 .317 .456 r
.57362 .58478 m .57683 .58206 L .57455 .58275 L F
.563 .784 .982 r
.30304 .63384 m .30507 .63525 L .30738 .6345 L F
.671 .125 0 r
.54117 .63677 m .54351 .63904 L .54502 .6395 L F
.991 .748 .457 r
.54351 .63904 m .54444 .64234 L .54502 .6395 L F
.652 .625 .81 r
.54502 .6395 m .5484 .64051 L .54702 .63926 L F
.688 .581 .73 r
.54502 .6395 m .5484 .64051 L .54702 .63926 L F
.464 .329 .611 r
.55261 .60645 m .55472 .605 L .55376 .60166 L F
.515 .557 .837 r
.55376 .60166 m .55717 .60169 L .55556 .59906 L F
.415 .224 .511 r
.55472 .605 m .55717 .60169 L .55376 .60166 L F
.774 .737 .82 r
.58582 .65575 m .58608 .65362 L .58665 .6545 L F
.463 .074 .216 r
.41687 .6165 m .41361 .61856 L .41463 .61683 L F
.946 .684 .506 r
.59169 .58855 m .59017 .59008 L .58983 .58778 L F
.59169 .58855 m .59167 .59062 L .59017 .59008 L F
.256 .701 .959 r
.20812 .54892 m .20453 .54814 L .20651 .54807 L F
.078 .464 .888 r
.20906 .54836 m .20812 .54892 L .20651 .54807 L F
.20906 .54836 m .21053 .54992 L .20812 .54892 L F
.385 0 .071 r
.3702 .62504 m .37236 .62492 L .374 .62293 L F
.21 0 0 r
.374 .62293 m .37461 .62421 L .3762 .62245 L F
.374 .62293 m .37236 .62492 L .37461 .62421 L F
.661 .45 .588 r
.29948 .62847 m .30201 .63008 L .30366 .62881 L F
.581 .151 .189 r
.30264 .62752 m .3063 .62616 L .30366 .62881 L F
.531 .473 .736 r
.30201 .63008 m .30264 .62752 L .30366 .62881 L F
.814 .741 .783 r
.61348 .59698 m .61253 .5939 L .61257 .59524 L F
.947 .758 .615 r
.61335 .59994 m .61348 .59698 L .61257 .59524 L F
0 0 .519 r
.53316 .71034 m .53395 .71185 L .53264 .70888 L F
.618 .356 .5 r
.51453 .65177 m .51432 .65428 L .51195 .65404 L F
.463 .227 .47 r
.51663 .65351 m .51453 .65177 L .51696 .651 L F
.51663 .65351 m .51432 .65428 L .51453 .65177 L F
0 .016 .575 r
.55351 .65074 m .55496 .65327 L .55434 .65446 L F
.03 .277 .773 r
.55496 .65327 m .55667 .65643 L .55434 .65446 L F
.601 .845 .99 r
.76538 .51055 m .76183 .51045 L .76432 .50996 L F
.568 .881 .992 r
.76676 .50919 m .76538 .51055 L .76432 .50996 L F
.402 .596 .924 r
.76676 .50919 m .76766 .51096 L .76538 .51055 L F
.568 .881 .992 r
.76676 .50919 m .76538 .51055 L .76432 .50996 L F
.112 0 .291 r
.48803 .62557 m .48612 .62863 L .4877 .62755 L F
.131 0 .398 r
.48612 .62863 m .4873 .62995 L .4877 .62755 L F
.48612 .62863 m .48584 .63102 L .4873 .62995 L F
.607 .777 .962 r
.72289 .4963 m .72599 .49698 L .72524 .49553 L F
.799 .702 .758 r
.56366 .59973 m .56716 .60035 L .56486 .59686 L F
.827 .899 .892 r
.56301 .60204 m .56716 .60035 L .56366 .59973 L F
.37 .694 .982 r
.21209 .5501 m .21166 .55127 L .21053 .54992 L F
.21209 .5501 m .21298 .55089 L .21166 .55127 L F
.412 .543 .878 r
.2145 .5524 m .21166 .55127 L .21298 .55089 L F
.004 0 .353 r
.59638 .63599 m .59557 .63428 L .5947 .63591 L F
.685 .63 .788 r
.48205 .6656 m .48529 .66598 L .48368 .6627 L F
.723 .511 .602 r
.48205 .6656 m .48441 .66854 L .48529 .66598 L F
.48205 .6656 m .48156 .66936 L .48441 .66854 L F
.417 0 .024 r
.59737 .67206 m .59341 .67368 L .5938 .67363 L F
.59737 .67206 m .59611 .6736 L .59341 .67368 L F
0 0 0 r
.59785 .67248 m .59737 .67206 L .59914 .67078 L F
.59785 .67248 m .59611 .6736 L .59737 .67206 L F
.701 .897 .528 r
.48867 .6688 m .48657 .67165 L .48737 .67026 L F
.811 .628 .654 r
.48867 .6688 m .48897 .67155 L .48657 .67165 L F
.51 .408 .675 r
.49149 .67143 m .48867 .6688 L .49101 .66835 L F
.49149 .67143 m .48897 .67155 L .48867 .6688 L F
.69 .365 .422 r
.48737 .67026 m .49101 .66835 L .48867 .6688 L F
.211 .659 .949 r
.76977 .48048 m .77322 .48152 L .77092 .48131 L F
.525 0 0 r
.58275 .67585 m .5811 .67563 L .57955 .67457 L F
.429 .85 .956 r
.48721 .65055 m .48586 .65024 L .48477 .65111 L F
.48721 .65055 m .48586 .65024 L .48477 .65111 L F
.549 .42 .656 r
.48721 .65055 m .4852 .65441 L .48477 .65111 L F
.405 .054 .252 r
.53842 .59974 m .54102 .59914 L .54176 .59672 L F
0 0 0 r
.54102 .59914 m .54409 .59649 L .54176 .59672 L F
.86 .938 .872 r
.52243 .64332 m .52277 .64639 L .52499 .64552 L F
.52243 .64332 m .52219 .64652 L .52277 .64639 L F
.41 .425 .765 r
.53715 .67629 m .5353 .67756 L .5346 .67492 L F
.627 .599 .802 r
.53715 .67629 m .53572 .6797 L .5353 .67756 L F
.36 0 .092 r
.52397 .65816 m .52445 .65823 L .52452 .65542 L F
.216 0 0 r
.52598 .65845 m .52369 .65886 L .52512 .65759 L F
.36 0 .092 r
.52445 .65823 m .52598 .65845 L .5255 .65745 L F
.52445 .65823 m .5255 .65745 L .52452 .65542 L F
0 0 0 r
.52254 .65962 m .52369 .65886 L .52234 .65978 L F
.52512 .65759 m .52417 .65843 L .52254 .65962 L F
.52417 .65843 m .52369 .65886 L .52254 .65962 L F
.436 .867 .764 r
.52369 .65886 m .52175 .65988 L .52234 .65978 L F
.442 .52 .842 r
.45531 .69912 m .45355 .70061 L .45221 .69782 L F
.462 .555 .865 r
.45531 .69912 m .45684 .70207 L .45355 .70061 L F
.082 0 0 r
.37518 .63662 m .37408 .63641 L .3764 .63585 L F
.37518 .63662 m .37304 .63719 L .37408 .63641 L F
.662 .432 .562 r
.75913 .48458 m .76183 .48464 L .76196 .48197 L F
.595 .377 .554 r
.76196 .48197 m .76488 .48406 L .76468 .48137 L F
.76196 .48197 m .76183 .48464 L .76488 .48406 L F
0 0 .25 r
.61398 .62822 m .61367 .62578 L .61392 .62473 L F
.597 .728 .936 r
.73888 .49915 m .73595 .50006 L .73489 .49807 L F
.73888 .49915 m .73595 .50006 L .73489 .49807 L F
.496 .785 .997 r
.75385 .5119 m .75009 .51123 L .75266 .51043 L F
.715 .832 .938 r
.75596 .51067 m .75385 .5119 L .75266 .51043 L F
0 0 .432 r
.3063 .62616 m .30469 .62129 L .30491 .62334 L F
.683 .6 .756 r
.66638 .49898 m .66987 .49926 L .66888 .49597 L F
.392 .073 .301 r
.30982 .59088 m .31194 .59036 L .31251 .58862 L F
.486 .168 .352 r
.31194 .59036 m .31478 .58827 L .31251 .58862 L F
.672 .422 .533 r
.61583 .61331 m .61603 .61381 L .61664 .61383 L F
.827 .6 .595 r
.60392 .58469 m .6075 .58761 L .60769 .58555 L F
0 0 0 r
.77224 .52439 m .77149 .52513 L .77318 .52348 L F
.368 .459 .823 r
.77149 .52513 m .77418 .52684 L .77318 .52348 L F
.976 .717 .307 r
.77149 .52513 m .7719 .52769 L .77418 .52684 L F
.667 .677 .85 r
.53264 .70888 m .53395 .71185 L .53706 .71041 L F
.096 .243 .726 r
.52939 .64522 m .5293 .64212 L .52662 .6441 L F
.52939 .64522 m .53043 .64571 L .5293 .64212 L F
.484 .171 .359 r
.5825 .57914 m .58491 .57872 L .58518 .57707 L F
.515 .222 .406 r
.58739 .57856 m .58518 .57707 L .58491 .57872 L F
.58739 .57856 m .58778 .57671 L .58518 .57707 L F
.41 0 .088 r
.3543 .64322 m .3528 .64511 L .3505 .64529 L F
.097 0 0 r
.35506 .64419 m .3543 .64322 L .35653 .64248 L F
.35506 .64419 m .3528 .64511 L .3543 .64322 L F
.673 .163 .02 r
.51619 .63184 m .51871 .63367 L .51995 .63325 L F
.287 0 0 r
.36514 .58397 m .36716 .58433 L .36876 .58424 L F
.118 .67 .765 r
.36716 .58433 m .37097 .58406 L .36876 .58424 L F
.462 .283 .552 r
.45819 .68764 m .45607 .68588 L .4595 .68601 L F
.525 .317 .541 r
.46073 .68484 m .45819 .68764 L .4595 .68601 L F
.581 .151 .189 r
.30264 .62752 m .30363 .62823 L .3063 .62616 L F
0 0 .432 r
.3063 .62616 m .30699 .62497 L .3064 .62343 L F
.672 .944 .679 r
.3063 .62616 m .30363 .62823 L .30699 .62497 L F
.836 .803 .819 r
.30699 .62497 m .30363 .62823 L .30253 .62637 L F
.654 .292 .345 r
.30476 .6258 m .30736 .62596 L .30699 .62497 L F
.438 .598 .912 r
.30979 .62652 m .31191 .62716 L .31143 .62663 L F
.654 .292 .345 r
.30707 .62519 m .3099 .62601 L .30699 .62497 L F
.3099 .62601 m .31038 .62615 L .3099 .62598 L F
.3099 .62601 m .3099 .62598 L .30699 .62497 L F
.313 .551 .918 r
.30822 .62423 m .31038 .62615 L .31015 .62522 L F
.438 .598 .912 r
.31024 .62624 m .31015 .62522 L .31038 .62615 L F
.654 .292 .345 r
.30988 .62612 m .31038 .62615 L .30707 .62519 L F
.409 .59 .917 r
.30699 .62497 m .31038 .62615 L .30822 .62423 L F
.30699 .62497 m .31038 .62615 L .30822 .62423 L F
0 0 .107 r
.3115 .62704 m .31015 .62522 L .31191 .62716 L F
.438 .598 .912 r
.30979 .62652 m .30989 .62613 L .31024 .62624 L F
.695 .498 .617 r
.31018 .62629 m .30979 .62652 L .31038 .62615 L F
.701 .561 .693 r
.30988 .62612 m .30989 .62613 L .31038 .62615 L F
0 0 .107 r
.30979 .62652 m .31018 .62629 L .3115 .62704 L F
.438 .598 .912 r
.30979 .62652 m .31143 .62663 L .30989 .62612 L F
.695 .498 .617 r
.30984 .62652 m .30979 .62652 L .31018 .62629 L F
.30652 .62877 m .30893 .63005 L .30979 .62652 L F
.30652 .62877 m .30979 .62652 L .30984 .62652 L F
0 0 .107 r
.30979 .62652 m .30989 .62613 L .31018 .62629 L F
.438 .598 .912 r
.30989 .62613 m .31023 .62614 L .31024 .62624 L F
.701 .561 .693 r
.3048 .62587 m .30652 .62877 L .30984 .62652 L F
.30989 .62613 m .30984 .62652 L .31038 .62615 L F
0 0 .107 r
.30979 .62652 m .3098 .62683 L .30989 .62613 L F
.701 .561 .693 r
.3048 .62587 m .30984 .62652 L .30989 .62613 L F
0 0 .107 r
.30989 .62613 m .30986 .62796 L .30989 .62612 L F
.3098 .62683 m .30986 .62796 L .30989 .62613 L F
.438 .598 .912 r
.30989 .62613 m .31015 .62522 L .31023 .62614 L F
0 0 .107 r
.30989 .62613 m .31015 .62522 L .3115 .62704 L F
.438 .598 .912 r
.30989 .62612 m .31143 .62663 L .31015 .62522 L F
0 0 .107 r
.30989 .62612 m .30989 .62652 L .31015 .62522 L F
0 .459 .781 r
.3137 .62794 m .31191 .62716 L .30979 .62652 L F
.3137 .62794 m .31191 .62716 L .30979 .62652 L F
0 0 .107 r
.30989 .62652 m .30989 .62864 L .31005 .62652 L F
.30989 .62652 m .31005 .62652 L .31015 .62522 L F
.701 .561 .693 r
.30476 .6258 m .3048 .62587 L .30989 .62613 L F
.30476 .6258 m .30989 .62613 L .30988 .62612 L F
0 0 .107 r
.30986 .62796 m .30989 .62864 L .30989 .62612 L F
.654 .292 .345 r
.30736 .62596 m .30988 .62612 L .30707 .62519 L F
0 0 .432 r
.3064 .62343 m .30699 .62497 L .30646 .62178 L F
.862 .883 .85 r
.74431 .49448 m .74221 .49687 L .74168 .49526 L F
0 0 .251 r
.74221 .49687 m .74309 .4976 L .74168 .49526 L F
.74221 .49687 m .74134 .49946 L .74309 .4976 L F
.582 .705 .927 r
.77515 .49149 m .7792 .49311 L .77815 .49165 L F
.629 .807 .968 r
.7792 .49311 m .78063 .49092 L .77815 .49165 L F
.7792 .49311 m .78166 .49232 L .78063 .49092 L F
.445 .149 .367 r
.5632 .58833 m .56545 .5878 L .56615 .58524 L F
.543 .244 .41 r
.56545 .5878 m .56863 .585 L .56615 .58524 L F
0 0 .198 r
.746 .504 m .74625 .50708 L .74603 .50766 L F
.094 .432 .873 r
.74758 .50716 m .74785 .50753 L .74603 .50766 L F
.74785 .50753 m .74938 .50958 L .7465 .50793 L F
.74785 .50753 m .7465 .50793 L .74603 .50766 L F
.484 .702 .965 r
.74998 .5078 m .74938 .50958 L .74758 .50716 L F
.74998 .5078 m .75197 .50981 L .74938 .50958 L F
.723 .734 .86 r
.755 .50928 m .75266 .51043 L .75197 .50981 L F
.688 .829 .951 r
.755 .50928 m .75197 .50981 L .75397 .50777 L F
.659 .771 .933 r
.75397 .50777 m .75197 .50981 L .74998 .5078 L F
.6 .651 .872 r
.75266 .51043 m .75009 .51123 L .74938 .50958 L F
.75266 .51043 m .74938 .50958 L .75197 .50981 L F
.631 .438 .603 r
.75148 .51056 m .75397 .50777 L .74998 .5078 L F
.715 .832 .938 r
.75596 .51067 m .75266 .51043 L .755 .50928 L F
.631 .438 .603 r
.75148 .51056 m .75409 .51082 L .75397 .50777 L F
.162 .643 .925 r
.74812 .50745 m .74938 .50719 L .74998 .5078 L F
.74938 .50719 m .74969 .50724 L .74998 .5078 L F
.74751 .50734 m .74924 .50712 L .74812 .50745 L F
.094 .432 .873 r
.74758 .50716 m .74603 .50766 L .74603 .5078 L F
.74738 .50738 m .74603 .5078 L .74603 .50888 L F
.74758 .50716 m .74603 .5078 L .74738 .50738 L F
0 0 0 r
.74625 .50708 m .74603 .50888 L .74603 .50766 L F
.981 .759 .53 r
.74484 .50534 m .74603 .50888 L .74625 .50708 L F
.74484 .50534 m .74603 .50888 L .74625 .50708 L F
.755 .493 0 r
.74603 .50888 m .74558 .50697 L .74758 .50716 L F
.162 .643 .925 r
.74558 .50697 m .74751 .50734 L .74758 .50716 L F
.74558 .50697 m .74832 .50708 L .74751 .50734 L F
.74832 .50708 m .74924 .50712 L .74751 .50734 L F
.74751 .50734 m .74998 .5078 L .74758 .50716 L F
.945 .895 .747 r
.74717 .50986 m .74998 .5078 L .74964 .50713 L F
.74717 .50986 m .74814 .5114 L .74998 .5078 L F
.718 .564 .679 r
.74998 .5078 m .74814 .5114 L .75148 .51056 L F
.622 .549 .751 r
.75008 .50731 m .75321 .50995 L .74922 .50812 L F
.75135 .5061 m .7521 .50765 L .75008 .50731 L F
.7521 .50765 m .75321 .50995 L .75008 .50731 L F
.162 .643 .925 r
.74938 .50719 m .74964 .50713 L .74969 .50724 L F
.74924 .50712 m .74964 .50713 L .74812 .50745 L F
.492 0 0 r
.52988 .67832 m .52639 .6773 L .52515 .67657 L F
.563 .859 .997 r
.52945 .67707 m .52988 .67832 L .53131 .67649 L F
.52945 .67707 m .52639 .6773 L .52988 .67832 L F
.529 .347 .578 r
.33716 .60555 m .33709 .608 L .33489 .60847 L F
.479 .282 .535 r
.33678 .61042 m .33489 .60847 L .33709 .608 L F
.33678 .61042 m .33469 .61096 L .33489 .60847 L F
.352 .04 .289 r
.46974 .654 m .46746 .65467 L .46709 .65629 L F
.018 0 0 r
.32831 .58435 m .33049 .58387 L .33229 .58296 L F
.252 0 0 r
.33049 .58387 m .33451 .58248 L .33229 .58296 L F
.77 .721 .807 r
.58456 .65907 m .58331 .66108 L .58149 .65989 L F
.453 .285 .562 r
.47475 .64827 m .47676 .64517 L .47491 .64586 L F
0 0 0 r
.48529 .66598 m .48616 .66447 L .48368 .6627 L F
.646 .806 .96 r
.54702 .63926 m .5484 .64051 L .55059 .63966 L F
.54702 .63926 m .5484 .64051 L .55059 .63966 L F
.274 0 .071 r
.32078 .58599 m .32224 .58654 L .3238 .58476 L F
.38 0 .066 r
.32224 .58654 m .32598 .58455 L .3238 .58476 L F
0 .179 .714 r
.57874 .64995 m .58105 .65361 L .57913 .65162 L F
.433 .58 .9 r
.21581 .5526 m .2151 .55487 L .2145 .5524 L F
.21581 .5526 m .21795 .5556 L .2151 .55487 L F
.216 0 0 r
.52598 .65845 m .52512 .65759 L .52728 .6567 L F
.87 .607 .538 r
.49074 .67648 m .49357 .68001 L .49349 .67738 L F
0 .134 .583 r
.51735 .63265 m .51619 .63184 L .51497 .63143 L F
.51735 .63265 m .51871 .63367 L .51619 .63184 L F
.031 .601 .755 r
.33817 .58195 m .33657 .58185 L .34028 .58197 L F
.193 0 0 r
.346 .64565 m .34451 .64561 L .34232 .64528 L F
.031 0 0 r
.34675 .64569 m .346 .64565 L .34833 .64569 L F
.34675 .64569 m .34451 .64561 L .346 .64565 L F
.136 0 0 r
.76988 .4902 m .76878 .49035 L .76629 .49024 L F
.134 0 0 r
.76988 .4902 m .7715 .49053 L .76878 .49035 L F
.76988 .4902 m .77213 .49036 L .7715 .49053 L F
.916 .558 .112 r
.59939 .62574 m .59762 .62199 L .59934 .62294 L F
.816 .999 .839 r
.47431 .66481 m .47841 .66205 L .4762 .66376 L F
0 0 .084 r
.47991 .65968 m .47934 .66206 L .47841 .66205 L F
0 0 0 r
.47841 .66205 m .47934 .66206 L .4762 .66376 L F
.86 .427 .181 r
.52828 .66343 m .53069 .6656 L .5321 .66294 L F
.52828 .66343 m .52873 .66509 L .53069 .6656 L F
.685 .354 .409 r
.52861 .66768 m .53069 .6656 L .52873 .66509 L F
.52861 .66768 m .53201 .66805 L .53069 .6656 L F
.452 .775 .998 r
.39655 .58486 m .39575 .58605 L .39434 .58476 L F
.39655 .58486 m .39796 .58585 L .39575 .58605 L F
.704 .587 .722 r
.48897 .67155 m .48759 .67467 L .48598 .67406 L F
.48897 .67155 m .48998 .67442 L .48759 .67467 L F
.357 .679 .978 r
.39811 .5974 m .39925 .59631 L .39694 .59603 L F
.39811 .5974 m .40041 .5974 L .39925 .59631 L F
0 0 .221 r
.52999 .60805 m .53105 .60681 L .53121 .60433 L F
.031 .166 .673 r
.52999 .60805 m .53174 .60993 L .53105 .60681 L F
.619 .78 .958 r
.55634 .60901 m .55865 .608 L .55476 .6075 L F
.709 .538 .656 r
.50222 .64329 m .49771 .63758 L .50347 .63957 L F
.551 .287 .468 r
.50561 .64156 m .50347 .63957 L .50587 .63963 L F
.50561 .64156 m .50222 .64329 L .50347 .63957 L F
.94 .756 .626 r
.5975 .59757 m .59517 .59871 L .59525 .5961 L F
.5975 .59757 m .59661 .59973 L .59517 .59871 L F
0 .122 .67 r
.55884 .63415 m .559 .6333 L .55826 .63297 L F
0 .18 .638 r
.55884 .63415 m .5605 .63513 L .559 .6333 L F
.55884 .63415 m .56194 .63633 L .5605 .63513 L F
.043 .569 .865 r
.7719 .52769 m .77591 .52855 L .77418 .52684 L F
.291 .669 .973 r
.34546 .62156 m .34738 .62165 L .34696 .62268 L F
0 .105 .657 r
.34738 .62165 m .34882 .6249 L .34696 .62268 L F
.612 .6 .814 r
.51075 .65098 m .51195 .65404 L .50956 .65418 L F
.564 .339 .533 r
.51153 .65525 m .50956 .65418 L .51195 .65404 L F
.51153 .65525 m .50954 .65567 L .50956 .65418 L F
.328 0 0 r
.37097 .58406 m .37313 .5845 L .37454 .58437 L F
0 0 0 r
.37313 .5845 m .37678 .58402 L .37454 .58437 L F
.617 .448 .631 r
.80188 .5017 m .79926 .50235 L .80154 .49936 L F
.453 .26 .527 r
.8042 .49872 m .80154 .49936 L .80379 .49629 L F
.497 .393 .667 r
.8042 .49872 m .80431 .50118 L .80154 .49936 L F
.526 .384 .631 r
.80154 .49936 m .80431 .50118 L .80188 .5017 L F
.392 .379 .726 r
.73727 .50883 m .7383 .51095 L .73788 .50796 L F
0 0 0 r
.78641 .52699 m .78619 .52742 L .78838 .52504 L F
.357 .576 .924 r
.40995 .58929 m .40894 .59049 L .40702 .58864 L F
.40995 .58929 m .41106 .591 L .40894 .59049 L F
.53 .826 .999 r
.46911 .70812 m .47037 .70902 L .46677 .70874 L F
.658 .231 .221 r
.4691 .71073 m .47259 .71085 L .47037 .70902 L F
.689 .269 .242 r
.4691 .71073 m .47037 .70902 L .46677 .70874 L F
.753 .689 .791 r
.79273 .511 m .79481 .51096 L .7937 .50698 L F
.768 .636 .716 r
.79247 .51355 m .79481 .51096 L .79273 .511 L F
.641 .622 .815 r
.7937 .50698 m .79481 .51096 L .79723 .50843 L F
.678 .685 .849 r
.79481 .51096 m .79801 .51083 L .79723 .50843 L F
.939 .677 .513 r
.2822 .80903 m .28198 .81177 L .2843 .81265 L F
.926 .78 .679 r
.2843 .81265 m .28198 .81177 L .28331 .81389 L F
.906 .632 .131 r
.5601 .66554 m .56022 .66806 L .56084 .66853 L F
.038 .18 .684 r
.55892 .66441 m .56022 .66806 L .5601 .66554 L F
.55892 .66441 m .56047 .66658 L .56022 .66806 L F
.765 .692 .782 r
.56047 .66658 m .56 .66789 L .56022 .66806 L F
.56 .66789 m .55914 .67023 L .56022 .66806 L F
.906 .632 .131 r
.56084 .66853 m .56022 .66806 L .56094 .66896 L F
.938 .954 .758 r
.56022 .66806 m .56004 .67108 L .56094 .66896 L F
0 .014 .581 r
.49038 .67231 m .48998 .67442 L .48897 .67155 L F
.849 .495 .383 r
.48858 .67617 m .48998 .67442 L .49038 .67231 L F
.48858 .67617 m .49074 .67648 L .48998 .67442 L F
.454 0 0 r
.56708 .60423 m .56825 .60437 L .5688 .6052 L F
.293 0 0 r
.56708 .60423 m .56825 .60437 L .56957 .6049 L F
.128 .067 .513 r
.56957 .6049 m .56825 .60437 L .57039 .60394 L F
.713 .729 .863 r
.56825 .60437 m .57106 .60187 L .56979 .60327 L F
.782 .715 .789 r
.56899 .6047 m .57039 .60394 L .56957 .6049 L F
0 0 0 r
.56899 .6047 m .56825 .60437 L .57039 .60394 L F
.56861 .60491 m .56843 .60465 L .56899 .6047 L F
.56843 .60465 m .56825 .60437 L .56899 .6047 L F
0 .478 .77 r
.56708 .60408 m .56899 .6047 L .56708 .60423 L F
.56899 .6047 m .56957 .6049 L .56877 .60468 L F
.56899 .6047 m .56877 .60468 L .56708 .60423 L F
.717 .837 .939 r
.56979 .60327 m .57265 .60252 L .56825 .60437 L F
.782 .715 .789 r
.56708 .60408 m .57039 .60394 L .56899 .6047 L F
0 0 0 r
.5688 .6052 m .56861 .60491 L .57039 .60394 L F
.667 .302 .344 r
.47259 .71085 m .4763 .71085 L .47633 .7092 L F
.517 .193 .357 r
.56037 .5902 m .5632 .58833 L .56065 .58858 L F
.753 .283 .13 r
.46585 .71458 m .46485 .71578 L .46428 .71466 L F
.702 .218 .094 r
.46585 .71458 m .46798 .71645 L .46485 .71578 L F
.356 .466 .835 r
.52384 .66597 m .52635 .66767 L .52608 .66561 L F
.342 0 .177 r
.39534 .62848 m .39245 .63029 L .39315 .62901 L F
.46 .657 .946 r
.76763 .52326 m .76926 .52168 L .76679 .52195 L F
.76763 .52326 m .77224 .52439 L .76926 .52168 L F
.721 .388 .415 r
.48792 .71373 m .49137 .71215 L .48934 .71132 L F
.865 .616 .56 r
.31413 .63714 m .31413 .63844 L .31153 .63856 L F
.31413 .63844 m .31412 .63987 L .31345 .63953 L F
.31413 .63844 m .31345 .63953 L .31153 .63856 L F
.88 .691 .643 r
.31244 .64133 m .31153 .63856 L .31412 .63987 L F
.78 .897 .49 r
.314 .63801 m .31263 .64012 L .31247 .64111 L F
.31276 .64064 m .31247 .64111 L .31244 .64133 L F
.314 .63801 m .31247 .64111 L .31276 .64064 L F
.865 .616 .56 r
.31413 .63714 m .31153 .63856 L .31348 .63812 L F
.516 .328 .565 r
.31608 .63754 m .31412 .63987 L .31413 .63714 L F
.158 .693 .693 r
.31348 .63812 m .31608 .63754 L .31413 .63714 L F
.564 .387 .6 r
.48371 .67743 m .48402 .67887 L .4864 .67872 L F
.48402 .67887 m .4843 .68016 L .48561 .67926 L F
.48402 .67887 m .48561 .67926 L .4864 .67872 L F
0 .445 .757 r
.47873 .67838 m .48103 .67905 L .4778 .67805 L F
.459 0 0 r
.4778 .67805 m .48103 .67905 L .48253 .6786 L F
0 .445 .757 r
.47873 .67838 m .47905 .67832 L .48103 .67905 L F
.998 .804 .515 r
.47942 .67954 m .48103 .67905 L .47905 .67832 L F
.189 0 0 r
.48175 .68021 m .47832 .68259 L .47866 .67993 L F
.998 .804 .515 r
.47985 .68101 m .48103 .67905 L .47942 .67954 L F
.459 0 0 r
.48253 .6786 m .48103 .67905 L .4832 .67867 L F
.48189 .67835 m .4832 .67867 L .48408 .67852 L F
.4778 .67805 m .4832 .67867 L .48189 .67835 L F
.815 .548 .534 r
.48103 .67905 m .48371 .67743 L .48408 .67852 L F
.107 0 .184 r
.59242 .63972 m .5947 .63591 L .59174 .6367 L F
.59242 .63972 m .59412 .63866 L .5947 .63591 L F
.163 0 .203 r
.59412 .63866 m .59638 .63599 L .5947 .63591 L F
.116 .504 .907 r
.74081 .47184 m .74216 .47323 L .73991 .47294 L F
.741 .47197 m .74216 .47323 L .74081 .47184 L F
0 .501 .714 r
.73991 .47294 m .74206 .47322 L .74414 .47354 L F
.74206 .47322 m .74216 .47323 L .74245 .47328 L F
.74206 .47322 m .74245 .47328 L .74414 .47354 L F
.813 .762 .805 r
.74426 .47355 m .7415 .47508 L .74474 .47532 L F
.843 .918 .884 r
.74414 .47354 m .74216 .47323 L .74391 .47222 L F
.813 .762 .805 r
.74391 .47222 m .74295 .47335 L .74426 .47355 L F
.74295 .47335 m .7415 .47508 L .74426 .47355 L F
.936 .616 .167 r
.74079 .47201 m .74053 .47408 L .7418 .47254 L F
.637 .157 0 r
.73991 .47294 m .74053 .47408 L .74081 .47184 L F
.936 .616 .167 r
.73946 .47131 m .7418 .47254 L .74002 .47128 L F
.637 .157 0 r
.74081 .47184 m .74053 .47408 L .74084 .4718 L F
.936 .616 .167 r
.73946 .47131 m .74053 .47408 L .74079 .47201 L F
.848 .851 .845 r
.74391 .47222 m .74113 .47184 L .74297 .47112 L F
.936 .616 .167 r
.74002 .47128 m .74092 .47192 L .74297 .47112 L F
.848 .851 .845 r
.74113 .47184 m .74084 .4718 L .74297 .47112 L F
.74391 .47222 m .74216 .47323 L .741 .47197 L F
.936 .616 .167 r
.74092 .47192 m .741 .47197 L .74113 .47184 L F
.848 .851 .845 r
.74113 .47184 m .741 .47197 L .74084 .4718 L F
.74391 .47222 m .741 .47197 L .74113 .47184 L F
.936 .616 .167 r
.74113 .47184 m .7418 .47254 L .74297 .47112 L F
.741 .47197 m .7418 .47254 L .74113 .47184 L F
.116 .504 .907 r
.74084 .4718 m .741 .47197 L .74081 .47184 L F
0 .056 .615 r
.74168 .49526 m .74309 .4976 L .7427 .4965 L F
.862 .883 .85 r
.74431 .49448 m .74168 .49526 L .7427 .4965 L F
.648 .602 .788 r
.74298 .49655 m .74309 .4976 L .74464 .49687 L F
.7427 .4965 m .74279 .49676 L .74298 .49655 L F
.74279 .49676 m .74309 .4976 L .74298 .49655 L F
0 0 0 r
.74431 .49448 m .74544 .49337 L .74751 .49282 L F
.74431 .49448 m .74298 .49655 L .74544 .49337 L F
.648 .602 .788 r
.74338 .49649 m .74464 .49687 L .74553 .49645 L F
.7427 .4965 m .74348 .49665 L .74338 .49649 L F
.74348 .49665 m .74464 .49687 L .74338 .49649 L F
0 0 0 r
.74298 .49655 m .74323 .49626 L .74544 .49337 L F
.862 .883 .85 r
.74431 .49448 m .7427 .4965 L .74298 .49655 L F
.836 .647 .648 r
.74544 .49337 m .74323 .49626 L .74196 .49436 L F
0 0 0 r
.74298 .49655 m .74281 .49681 L .74323 .49626 L F
.862 .883 .85 r
.74298 .49655 m .7427 .4965 L .74288 .49671 L F
.648 .602 .788 r
.74196 .49436 m .7427 .4965 L .74553 .49645 L F
.836 .647 .648 r
.74323 .49626 m .74281 .49681 L .74196 .49436 L F
0 .056 .615 r
.74168 .49526 m .7427 .4965 L .74196 .49436 L F
.862 .883 .85 r
.74288 .49671 m .74168 .49526 L .74281 .49681 L F
.682 .313 .341 r
.48486 .71692 m .48356 .7178 L .4812 .7168 L F
.04 0 0 r
.48714 .71787 m .48356 .7178 L .48486 .71692 L F
.312 .33 .719 r
.30108 .63244 m .30201 .63008 L .29963 .63047 L F
.30108 .63244 m .30304 .63384 L .30201 .63008 L F
.561 .894 .984 r
.5227 .67678 m .51943 .67677 L .52227 .67586 L F
.827 .827 .848 r
.5227 .67678 m .52062 .67802 L .51943 .67677 L F
.144 0 0 r
.37876 .63515 m .38205 .63362 L .38079 .63498 L F
.154 0 0 r
.38079 .63498 m .38205 .63362 L .38438 .63303 L F
.435 .27 .558 r
.33903 .6073 m .33716 .60555 L .33956 .60524 L F
.33903 .6073 m .33709 .608 L .33716 .60555 L F
.566 .621 .866 r
.43006 .70366 m .43134 .70135 L .4293 .69985 L F
.43006 .70366 m .4328 .70347 L .43134 .70135 L F
.482 .251 .487 r
.45197 .66579 m .45397 .66723 L .45409 .66524 L F
.45197 .66579 m .45172 .66787 L .45397 .66723 L F
.628 .962 .849 r
.22424 .56124 m .22251 .56249 L .22426 .56164 L F
0 .376 .839 r
.55875 .61887 m .55848 .61988 L .55711 .619 L F
.55875 .61887 m .56117 .62129 L .55848 .61988 L F
.532 .721 .96 r
.79116 .48419 m .78954 .48604 L .78865 .48465 L F
.79116 .48419 m .7938 .48636 L .78954 .48604 L F
.369 .08 .337 r
.41119 .61884 m .40858 .62135 L .40891 .61945 L F
.752 .751 .851 r
.28174 .81589 m .28331 .81389 L .27967 .81442 L F
.583 .608 .843 r
.40355 .59776 m .40466 .59961 L .40661 .59853 L F
.614 .552 .762 r
.40466 .59961 m .40785 .60215 L .40661 .59853 L F
.73 .979 .75 r
.51267 .68325 m .50995 .68609 L .51082 .68443 L F
.705 .917 .575 r
.50995 .68609 m .50816 .68799 L .51082 .68443 L F
.667 .267 .278 r
.51001 .68744 m .50816 .68799 L .50995 .68609 L F
.715 .677 .812 r
.51252 .68502 m .50995 .68609 L .51267 .68325 L F
.7 .438 .523 r
.51252 .68502 m .51001 .68744 L .50995 .68609 L F
.486 .223 .44 r
.44165 .6743 m .44392 .67387 L .44428 .67177 L F
.477 .214 .437 r
.44428 .67177 m .44617 .6734 L .44651 .67127 L F
.44428 .67177 m .44392 .67387 L .44617 .6734 L F
.645 .577 .764 r
.66888 .49597 m .66987 .49926 L .67252 .4986 L F
.385 .045 .261 r
.41979 .61426 m .41915 .61602 L .41687 .6165 L F
.452 .128 .324 r
.42198 .61374 m .41915 .61602 L .41979 .61426 L F
.64 .652 .846 r
.7816 .50499 m .78538 .50725 L .78384 .5046 L F
.543 .689 .934 r
.78538 .50725 m .78704 .50525 L .78384 .5046 L F
.78538 .50725 m .78774 .50686 L .78704 .50525 L F
.735 .622 .733 r
.75814 .49036 m .75445 .49063 L .75683 .48725 L F
.632 .256 .313 r
.75814 .49036 m .75703 .4924 L .75445 .49063 L F
.639 .264 .316 r
.75814 .49036 m .76069 .492 L .75703 .4924 L F
.654 .219 .203 r
.75814 .49036 m .76045 .49094 L .76069 .492 L F
.424 .014 .155 r
.31794 .58733 m .32003 .58716 L .32078 .58599 L F
.274 0 .071 r
.32078 .58599 m .32003 .58716 L .32224 .58654 L F
.51 .335 .579 r
.29743 .60215 m .29961 .60162 L .29962 .59953 L F
.515 .406 .668 r
.29794 .60585 m .29961 .60162 L .29743 .60215 L F
.483 .749 .988 r
.78188 .48255 m .78039 .484 L .77936 .48283 L F
.78188 .48255 m .78284 .48376 L .78039 .484 L F
.445 .253 .525 r
.47182 .70011 m .47438 .70015 L .47374 .69735 L F
.449 .29 .573 r
.47182 .70011 m .4738 .70163 L .47438 .70015 L F
.879 .753 .719 r
.74688 .48473 m .74433 .48473 L .7454 .48378 L F
.551 .325 .525 r
.49358 .63669 m .49283 .63906 L .49058 .63711 L F
.368 .143 .435 r
.47713 .64298 m .47868 .64454 L .47904 .64224 L F
.47713 .64298 m .47676 .64517 L .47868 .64454 L F
.452 .049 .183 r
.34767 .59936 m .3464 .60144 L .34396 .60173 L F
.275 0 .086 r
.34851 .60086 m .34767 .59936 L .34997 .59866 L F
.34851 .60086 m .3464 .60144 L .34767 .59936 L F
0 .415 .798 r
.22041 .56161 m .22069 .56139 L .21925 .5607 L F
.87 .625 .566 r
.61266 .61287 m .61578 .61141 L .61486 .61031 L F
.61266 .61287 m .61583 .61331 L .61578 .61141 L F
.327 .167 .506 r
.46269 .6818 m .4607 .68027 L .46384 .67943 L F
.46269 .6818 m .46103 .68262 L .4607 .68027 L F
.474 .668 .948 r
.40702 .58864 m .40498 .58883 L .40396 .58721 L F
.786 .659 .723 r
.51601 .68253 m .51267 .68325 L .51454 .68033 L F
.597 .365 .536 r
.51601 .68253 m .51252 .68502 L .51267 .68325 L F
.51601 .68253 m .5155 .68493 L .51252 .68502 L F
.699 .315 .316 r
.51601 .68253 m .51769 .68439 L .5155 .68493 L F
.51601 .68253 m .51823 .68332 L .51769 .68439 L F
.727 .199 0 r
.43618 .70314 m .43828 .70542 L .43723 .70526 L F
.484 .556 .854 r
.55455 .61025 m .55474 .61393 L .55315 .61179 L F
.704 .587 .722 r
.48897 .67155 m .48598 .67406 L .48657 .67165 L F
0 .014 .581 r
.49038 .67231 m .48897 .67155 L .49149 .67143 L F
1 .809 .488 r
.72871 .50932 m .72764 .50969 L .7276 .50698 L F
.72871 .50932 m .72848 .51075 L .72764 .50969 L F
.759 .731 .827 r
.73127 .50721 m .72871 .50932 L .7276 .50698 L F
.552 .272 .445 r
.44651 .67127 m .44903 .67108 L .44947 .66843 L F
.426 .163 .41 r
.44947 .66843 m .45118 .67039 L .45172 .66787 L F
.44947 .66843 m .44903 .67108 L .45118 .67039 L F
.342 .676 .977 r
.52459 .63309 m .52671 .63315 L .52582 .63426 L F
.337 .67 .976 r
.52671 .63315 m .52848 .63457 L .52582 .63426 L F
.496 .23 .441 r
.58778 .57671 m .59017 .57611 L .59071 .57363 L F
.474 .211 .434 r
.59071 .57363 m .59235 .57549 L .59302 .5734 L F
.59071 .57363 m .59017 .57611 L .59235 .57549 L F
.628 .231 .271 r
.75669 .48484 m .75947 .48626 L .75913 .48458 L F
.413 0 .126 r
.57927 .59073 m .58051 .59235 L .57817 .59271 L F
.57927 .59073 m .58159 .59048 L .58051 .59235 L F
.654 .477 .633 r
.67348 .49 m .67602 .49213 L .67679 .49081 L F
.722 .298 .24 r
.67679 .49081 m .67602 .49213 L .67733 .49232 L F
.609 .301 .423 r
.5013 .68429 m .50275 .68304 L .50059 .68301 L F
.851 .66 .644 r
.6075 .58761 m .60875 .59096 L .60881 .58837 L F
.805 .679 .725 r
.49728 .71417 m .49838 .71598 L .50021 .71455 L F
.503 .189 .368 r
.46892 .68877 m .47068 .69013 L .47173 .6885 L F
.46892 .68877 m .47068 .69013 L .47173 .6885 L F
.787 .287 0 r
.57312 .59457 m .57161 .59716 L .57186 .59419 L F
.57312 .59457 m .57213 .59491 L .57161 .59716 L F
.57312 .59457 m .57342 .59544 L .57213 .59491 L F
.526 .278 .483 r
.49005 .62732 m .48803 .62557 L .4877 .62755 L F
.49005 .62732 m .49038 .62519 L .48803 .62557 L F
.776 .598 .659 r
.52931 .65405 m .53074 .65728 L .52728 .6567 L F
.56 .497 .741 r
.53437 .65368 m .53074 .65728 L .52931 .65405 L F
.776 .598 .659 r
.52931 .65405 m .53074 .65728 L .52728 .6567 L F
0 0 0 r
.61023 .66125 m .61121 .65857 L .61129 .65934 L F
.61023 .66125 m .60933 .66269 L .61121 .65857 L F
.56 .527 .775 r
.80627 .49582 m .80379 .49629 L .80297 .49289 L F
.672 .509 .656 r
.80627 .49582 m .8042 .49872 L .80379 .49629 L F
.947 .758 .615 r
.61335 .59994 m .61257 .59524 L .61083 .59897 L F
.89 .647 .565 r
.61032 .60129 m .61335 .59994 L .61083 .59897 L F
.61032 .60129 m .61352 .60206 L .61335 .59994 L F
.656 .891 .982 r
.41467 .59109 m .41327 .59035 L .41562 .58933 L F
.45 .638 .937 r
.41562 .58933 m .41664 .59096 L .41467 .59109 L F
.44 .545 .867 r
.41819 .59397 m .41467 .59109 L .41664 .59096 L F
.549 .872 .993 r
.79801 .51083 m .801 .50956 L .79723 .50843 L F
.416 .286 .595 r
.79801 .51083 m .79815 .51381 L .80056 .51077 L F
.076 .632 .808 r
.38559 .59342 m .38382 .59319 L .38174 .59315 L F
.223 .734 .883 r
.38779 .59321 m .38382 .59319 L .38559 .59342 L F
.976 .8 .601 r
.59661 .60549 m .59536 .60481 L .59591 .60207 L F
.941 .697 .227 r
.59661 .60549 m .59614 .60685 L .59536 .60481 L F
.59661 .60549 m .59673 .60802 L .59614 .60685 L F
.57 .312 .486 r
.4969 .65935 m .50013 .6591 L .49789 .65714 L F
.551 .316 .512 r
.49789 .65714 m .50013 .6591 L .50028 .65683 L F
.81 .48 .431 r
.52227 .67586 m .52515 .67657 L .52603 .67515 L F
.535 .194 .337 r
.52515 .67657 m .52611 .67613 L .52603 .67515 L F
.897 .811 .755 r
.57155 .59945 m .5727 .59628 L .57161 .59716 L F
.718 .509 .606 r
.57043 .59742 m .57268 .59953 L .57031 .60073 L F
0 0 .361 r
.57135 .60003 m .57103 .59789 L .57043 .59742 L F
.285 0 0 r
.57161 .59716 m .57043 .59742 L .56991 .59702 L F
.867 .983 .697 r
.57161 .59716 m .57213 .59491 L .57043 .59742 L F
.711 .573 .698 r
.57213 .59491 m .57281 .5978 L .57043 .59742 L F
0 0 .361 r
.57103 .59789 m .57088 .59688 L .57043 .59742 L F
.285 0 0 r
.56991 .59702 m .57043 .59742 L .56708 .59679 L F
0 .456 .826 r
.35694 .62439 m .35685 .6248 L .35544 .62371 L F
.35694 .62439 m .3584 .62529 L .35685 .6248 L F
.766 .321 .194 r
.55503 .67088 m .5513 .67003 L .55111 .66932 L F
.444 .811 .995 r
.77713 .51323 m .77933 .51272 L .78065 .51357 L F
.274 0 0 r
.77933 .51272 m .78322 .51344 L .78065 .51357 L F
.766 .321 .194 r
.55503 .67088 m .55299 .67123 L .5513 .67003 L F
.203 .53 .922 r
.55503 .67088 m .55693 .67123 L .55564 .66977 L F
.596 .948 .906 r
.55564 .66977 m .55299 .67123 L .55503 .67088 L F
.628 .801 .368 r
.55564 .66977 m .55503 .67088 L .55644 .66843 L F
.157 .677 .885 r
.37678 .58402 m .37904 .58405 L .38063 .58445 L F
0 .489 .745 r
.37904 .58405 m .38265 .58484 L .38063 .58445 L F
.928 .74 .628 r
.61429 .60506 m .61352 .60206 L .612 .60459 L F
.913 .692 .589 r
.61165 .60725 m .61429 .60506 L .612 .60459 L F
.61165 .60725 m .61432 .60827 L .61429 .60506 L F
.04 0 0 r
.48714 .71787 m .48665 .71789 L .48356 .7178 L F
.679 .39 .477 r
.48471 .71634 m .48584 .71757 L .48799 .716 L F
.516 .905 .939 r
.48645 .71742 m .48636 .71779 L .48559 .71788 L F
.04 0 0 r
.48372 .7178 m .48545 .71788 L .48356 .7178 L F
.48665 .71789 m .48609 .71789 L .48372 .7178 L F
.48609 .71789 m .48545 .71788 L .48372 .7178 L F
.387 .026 .225 r
.48627 .71789 m .48666 .72046 L .48455 .71989 L F
.48636 .71779 m .48638 .7179 L .48627 .71789 L F
.48638 .7179 m .48666 .72046 L .48627 .71789 L F
.516 .905 .939 r
.48723 .717 m .48559 .71788 L .48484 .71788 L F
.679 .39 .477 r
.48584 .71757 m .48615 .71791 L .48668 .71736 L F
.48584 .71757 m .48668 .71736 L .48799 .716 L F
0 0 0 r
.48667 .71751 m .48636 .71779 L .48799 .716 L F
.75 .959 .66 r
.48799 .716 m .4868 .71724 L .48684 .71731 L F
.48799 .716 m .48684 .71731 L .48714 .71787 L F
0 0 0 r
.48723 .717 m .48667 .71751 L .48799 .716 L F
.75 .959 .66 r
.4868 .71724 m .48672 .71741 L .48714 .71787 L F
.48668 .71736 m .48665 .71789 L .48714 .71787 L F
.308 0 0 r
.49003 .7176 m .48858 .71829 L .48714 .71787 L F
.75 .959 .66 r
.48799 .716 m .48714 .71787 L .48858 .71829 L F
.809 .764 .811 r
.48799 .716 m .48858 .71829 L .49105 .71596 L F
.189 .355 .799 r
.48723 .717 m .48882 .71743 L .48655 .71776 L F
.48667 .71751 m .48655 .71776 L .48636 .71779 L F
.48723 .717 m .48655 .71776 L .48667 .71751 L F
.75 .959 .66 r
.4868 .71724 m .48668 .71736 L .48672 .71741 L F
.516 .905 .939 r
.48689 .71731 m .48636 .71779 L .48645 .71742 L F
.75 .959 .66 r
.48668 .71736 m .48615 .71791 L .48665 .71789 L F
.516 .905 .939 r
.48723 .717 m .48689 .71731 L .48668 .71736 L F
.48668 .71729 m .48668 .71736 L .48645 .71742 L F
.48723 .717 m .48668 .71736 L .48668 .71729 L F
0 0 0 r
.48446 .71802 m .48356 .7178 L .48545 .71788 L F
.516 .905 .939 r
.48545 .71788 m .48559 .71788 L .48446 .71802 L F
.387 .026 .225 r
.48559 .71788 m .48455 .71989 L .48446 .71802 L F
.04 0 0 r
.48665 .71789 m .48652 .7179 L .48559 .71788 L F
.387 .026 .225 r
.48636 .71779 m .48627 .71789 L .48559 .71788 L F
.48627 .71789 m .48455 .71989 L .48559 .71788 L F
.04 0 0 r
.48559 .71788 m .48615 .71791 L .48545 .71788 L F
.48652 .7179 m .48615 .71791 L .48559 .71788 L F
0 0 0 r
.48446 .71802 m .48545 .71788 L .48615 .71791 L F
.516 .905 .939 r
.48484 .71788 m .48545 .71788 L .48446 .71802 L F
.803 .694 .745 r
.59434 .56751 m .59553 .5708 L .59777 .56813 L F
.591 .382 .567 r
.59553 .5708 m .59801 .57047 L .59777 .56813 L F
.801 .537 .538 r
.59777 .56813 m .59801 .57047 L .60029 .5706 L F
.446 .855 .683 r
.54964 .59384 m .54642 .59569 L .54874 .59547 L F
.513 .058 .108 r
.55164 .59567 m .54964 .59384 L .54874 .59547 L F
.55164 .59567 m .55275 .594 L .54964 .59384 L F
.859 .948 .873 r
.32991 .64382 m .33063 .64499 L .33295 .6426 L F
.593 .237 .335 r
.76399 .48997 m .76069 .492 L .76045 .49094 L F
.76399 .48997 m .76304 .49234 L .76069 .492 L F
.407 0 .128 r
.76629 .49024 m .76304 .49234 L .76399 .48997 L F
.572 .432 .652 r
.21241 .58123 m .21167 .58023 L .21323 .57921 L F
.21241 .58123 m .21164 .58207 L .21167 .58023 L F
.807 .638 .672 r
.53328 .65698 m .53756 .65825 L .53564 .65382 L F
.425 .088 .287 r
.53443 .6601 m .53756 .65825 L .53328 .65698 L F
.53443 .6601 m .53672 .65956 L .53756 .65825 L F
.6 .542 .76 r
.53564 .65382 m .53756 .65825 L .53962 .65714 L F
.229 0 .16 r
.53756 .65825 m .53672 .65956 L .53962 .65714 L F
0 0 .39 r
.56719 .64566 m .56682 .64489 L .56545 .64254 L F
0 .032 .563 r
.56696 .64809 m .56682 .64489 L .56719 .64566 L F
0 .104 .628 r
.56992 .65702 m .57078 .65582 L .56947 .65383 L F
.01 .155 .668 r
.56992 .65702 m .57166 .65924 L .57078 .65582 L F
.572 .331 .512 r
.46652 .67722 m .46666 .6795 L .46384 .67943 L F
.718 .25 .138 r
.55351 .59706 m .55556 .59906 L .5523 .59822 L F
.862 .735 .722 r
.55072 .60693 m .5534 .60926 L .55387 .60692 L F
.55072 .60693 m .54893 .60999 L .5534 .60926 L F
.549 .044 .007 r
.54893 .60999 m .55138 .61178 L .5534 .60926 L F
.075 0 .382 r
.5534 .60926 m .55476 .6075 L .55387 .60692 L F
.5534 .60926 m .55455 .61025 L .55476 .6075 L F
.207 0 .302 r
.48123 .63936 m .47962 .64024 L .47904 .64224 L F
.813 .507 0 r
.59809 .61124 m .59864 .61349 L .59765 .61044 L F
.59809 .61124 m .59864 .61349 L .59765 .61044 L F
.194 0 0 r
.38174 .59315 m .3799 .5943 L .3779 .59456 L F
.35 .802 .947 r
.3799 .5943 m .37929 .59431 L .3779 .59456 L F
.056 0 0 r
.37898 .59369 m .3779 .59456 L .37608 .59488 L F
.194 0 0 r
.38174 .59315 m .3779 .59456 L .37898 .59369 L F
.35 .802 .947 r
.37929 .59431 m .37638 .59433 L .3779 .59456 L F
.056 0 0 r
.37608 .59488 m .3779 .59456 L .37574 .59502 L F
.093 .616 .879 r
.34028 .58197 m .34209 .58216 L .3439 .58277 L F
.22 0 0 r
.34209 .58216 m .34612 .58285 L .3439 .58277 L F
0 0 .159 r
.61206 .65042 m .61135 .65414 L .61209 .65113 L F
.61206 .65042 m .61195 .65287 L .61135 .65414 L F
0 0 .515 r
.61195 .65287 m .61177 .65676 L .61135 .65414 L F
.643 .144 .049 r
.53074 .65728 m .52924 .65818 L .52728 .6567 L F
.56 .411 .636 r
.66854 .49352 m .67105 .49072 L .6675 .4901 L F
.66854 .49352 m .67098 .49295 L .67105 .49072 L F
.609 .479 .678 r
.66854 .49352 m .67153 .49542 L .67098 .49295 L F
.66854 .49352 m .66888 .49597 L .67153 .49542 L F
.545 .311 .512 r
.76488 .48406 m .76725 .48098 L .76468 .48137 L F
.765 .752 .841 r
.73327 .4781 m .73387 .4811 L .7365 .47833 L F
.721 .388 .415 r
.48792 .71373 m .49241 .71456 L .49137 .71215 L F
.633 .349 .469 r
.49137 .71215 m .49241 .71456 L .49378 .71381 L F
.623 .371 .516 r
.4852 .65441 m .48507 .65664 L .48263 .65664 L F
.549 .42 .656 r
.48721 .65055 m .48786 .65401 L .4852 .65441 L F
.398 .127 .383 r
.48786 .65401 m .48507 .65664 L .4852 .65441 L F
0 .418 .799 r
.35992 .58376 m .35902 .58376 L .35762 .58278 L F
.35992 .58376 m .36141 .58469 L .35902 .58376 L F
0 .034 .541 r
.559 .6333 m .55821 .63245 L .55604 .63035 L F
.493 0 0 r
.55604 .63035 m .55712 .6314 L .55677 .63108 L F
0 0 .45 r
.55598 .63097 m .55604 .63035 L .55549 .6298 L F
.493 0 0 r
.55604 .63035 m .55677 .63108 L .55495 .62942 L F
0 0 .45 r
.55549 .6298 m .55604 .63035 L .55482 .62818 L F
0 .224 .732 r
.55598 .63097 m .55826 .63297 L .55604 .63035 L F
0 .196 .725 r
.56872 .6512 m .56919 .65022 L .56696 .64809 L F
0 0 .519 r
.56872 .6512 m .57026 .65253 L .56919 .65022 L F
.56872 .6512 m .56947 .65383 L .57026 .65253 L F
.502 .458 .74 r
.29868 .60795 m .29998 .6053 L .29794 .60585 L F
.29868 .60795 m .30066 .60752 L .29998 .6053 L F
.6 .491 .701 r
.29868 .60795 m .30146 .6109 L .30066 .60752 L F
.29868 .60795 m .29935 .61157 L .30146 .6109 L F
.827 .825 .846 r
.55693 .67123 m .56004 .67108 L .55914 .67023 L F
.55693 .67123 m .55843 .67227 L .56004 .67108 L F
.938 .954 .758 r
.56022 .66806 m .55914 .67023 L .56004 .67108 L F
.631 .163 .123 r
.53328 .6759 m .53715 .67629 L .5346 .67492 L F
.274 .627 .961 r
.31814 .63531 m .32142 .63524 L .31909 .63364 L F
.31814 .63531 m .32223 .63655 L .32142 .63524 L F
.659 .479 .63 r
.31814 .63531 m .31967 .63719 L .32223 .63655 L F
.581 .892 .989 r
.52848 .63457 m .52997 .63391 L .53166 .63436 L F
.124 .652 .873 r
.53264 .634 m .53166 .63436 L .52997 .63391 L F
.53264 .634 m .53486 .63421 L .53166 .63436 L F
.546 .55 .81 r
.56351 .64303 m .56545 .64254 L .56455 .6393 L F
.491 .056 .14 r
.30532 .59285 m .30826 .59268 L .30982 .59088 L F
.478 .096 .236 r
.30826 .59268 m .31194 .59036 L .30982 .59088 L F
.519 .259 .461 r
.45248 .68597 m .44996 .68817 L .45049 .68598 L F
.005 .52 .858 r
.77467 .51284 m .77117 .5116 L .77429 .51179 L F
.539 .596 .859 r
.7774 .51138 m .77467 .51284 L .77429 .51179 L F
.7774 .51138 m .77713 .51323 L .77467 .51284 L F
.578 .709 .932 r
.78428 .49152 m .78514 .49316 L .78764 .49264 L F
.802 .96 .914 r
.5956 .61886 m .59959 .61684 L .5977 .61981 L F
.5956 .61886 m .59873 .61614 L .59959 .61684 L F
.986 .728 .348 r
.59959 .61684 m .59873 .61614 L .59864 .61349 L F
0 0 0 r
.3951 .61133 m .39266 .61407 L .39409 .61295 L F
.508 .14 .276 r
.39409 .61295 m .39684 .6127 L .3951 .61133 L F
.46 .158 .365 r
.3951 .61133 m .39684 .6127 L .39728 .61087 L F
.564 .275 .435 r
.43035 .60843 m .43237 .6102 L .42995 .61042 L F
.534 .336 .558 r
.43315 .60533 m .43266 .60788 L .43035 .60843 L F
.515 .285 .504 r
.43035 .60843 m .43266 .60788 L .43237 .6102 L F
.416 .22 .504 r
.21634 .56128 m .21615 .56451 L .21427 .565 L F
.465 .227 .469 r
.21925 .5607 m .21615 .56451 L .21634 .56128 L F
.585 .318 .478 r
.42508 .61118 m .42441 .61368 L .42198 .61374 L F
.545 .284 .47 r
.42755 .61068 m .42441 .61368 L .42508 .61118 L F
.968 .682 .437 r
.45607 .68588 m .45447 .68728 L .45248 .68597 L F
.45607 .68588 m .4562 .68818 L .45447 .68728 L F
.462 .283 .552 r
.45819 .68764 m .4562 .68818 L .45607 .68588 L F
.787 .399 .32 r
.5591 .60388 m .56068 .60254 L .55717 .60169 L F
.607 .055 0 r
.55717 .60169 m .56068 .60254 L .55884 .60228 L F
.574 .525 .762 r
.56068 .60254 m .56167 .59877 L .55884 .60228 L F
.56068 .60254 m .56301 .60204 L .56167 .59877 L F
.75 .515 .575 r
.5591 .60388 m .56301 .60204 L .56068 .60254 L F
.725 .659 .785 r
.44572 .70743 m .44818 .70948 L .44917 .70875 L F
.613 .666 .877 r
.22079 .55665 m .21875 .55708 L .21795 .5556 L F
0 0 0 r
.60933 .66269 m .60857 .66439 L .60718 .66544 L F
.60718 .66544 m .60857 .66439 L .60536 .6669 L F
.7 .438 .523 r
.51252 .68502 m .51254 .68833 L .51001 .68744 L F
.506 .284 .511 r
.51486 .68782 m .51252 .68502 L .5155 .68493 L F
.51486 .68782 m .51254 .68833 L .51252 .68502 L F
.584 .671 .899 r
.4189 .59106 m .41819 .59397 L .41664 .59096 L F
.4189 .59106 m .4204 .59345 L .41819 .59397 L F
.472 .497 .803 r
.4211 .59572 m .41819 .59397 L .4204 .59345 L F
.705 .802 .925 r
.35261 .62511 m .35043 .62642 L .34882 .6249 L F
.393 0 .151 r
.49517 .62213 m .49846 .6199 L .49492 .6197 L F
.49517 .62213 m .49738 .62185 L .49846 .6199 L F
.718 .335 .322 r
.49738 .62185 m .50075 .62231 L .49846 .6199 L F
.761 .286 .117 r
.49846 .6199 m .50075 .62231 L .50227 .62226 L F
.686 .53 .668 r
.6675 .4901 m .66994 .4871 L .66744 .48787 L F
.6675 .4901 m .67105 .49072 L .66994 .4871 L F
.623 .494 .683 r
.66994 .4871 m .67348 .49 L .67386 .48758 L F
.66994 .4871 m .67105 .49072 L .67348 .49 L F
.578 .732 .948 r
.79124 .50748 m .79277 .50539 L .79018 .50623 L F
.79124 .50748 m .7937 .50698 L .79277 .50539 L F
.753 .689 .791 r
.79273 .511 m .7937 .50698 L .79124 .50748 L F
0 .123 .663 r
.57242 .6343 m .57463 .63643 L .57432 .63688 L F
.162 .387 .834 r
.57463 .63643 m .57641 .63916 L .57432 .63688 L F
.41 .229 .522 r
.53575 .66891 m .53606 .67117 L .53419 .6716 L F
.53608 .66892 m .53606 .67117 L .53575 .66891 L F
.506 .274 .496 r
.53211 .6727 m .53428 .67244 L .53453 .67011 L F
.937 .959 .754 r
.53428 .67244 m .5335 .67177 L .53384 .67123 L F
.265 0 0 r
.53453 .67011 m .53586 .67006 L .53724 .66927 L F
.53453 .67011 m .53806 .66901 L .53735 .66898 L F
.717 .289 .23 r
.53201 .66805 m .53453 .67011 L .53608 .66835 L F
.41 .229 .522 r
.53608 .66835 m .53608 .66892 L .53575 .66891 L F
.265 0 0 r
.53453 .67011 m .53887 .66837 L .53608 .66835 L F
.179 .19 .633 r
.53583 .67232 m .53419 .6716 L .53606 .67117 L F
.16 .323 .78 r
.53606 .67117 m .53813 .67243 L .53583 .67232 L F
.517 .6 .876 r
.53583 .67232 m .53677 .67002 L .53453 .67011 L F
.937 .959 .754 r
.53496 .67058 m .53384 .67123 L .53592 .66795 L F
.53428 .67244 m .53384 .67123 L .53496 .67058 L F
.265 0 0 r
.53724 .66927 m .53677 .67002 L .53806 .66901 L F
.53586 .67006 m .53677 .67002 L .53724 .66927 L F
.53735 .66898 m .53806 .66901 L .53887 .66837 L F
.602 .675 .892 r
.32579 .63792 m .32953 .64013 L .32754 .63669 L F
0 0 0 r
.32953 .64013 m .32698 .64283 L .32882 .64149 L F
.608 .684 .896 r
.32754 .63669 m .32953 .64013 L .33193 .63949 L F
.663 .207 .159 r
.32882 .64149 m .33147 .64187 L .32953 .64013 L F
.501 .269 .494 r
.32953 .64013 m .33147 .64187 L .33193 .63949 L F
.55 .414 .649 r
.58374 .65409 m .58608 .65362 L .58382 .65164 L F
.063 0 .344 r
.20948 .58762 m .20927 .58778 L .20983 .5853 L F
.205 .008 .377 r
.21164 .58207 m .21109 .58502 L .20983 .5853 L F
.407 .197 .479 r
.21114 .58704 m .20983 .5853 L .21109 .58502 L F
.21114 .58704 m .20948 .58762 L .20983 .5853 L F
.445 .464 .785 r
.3375 .6129 m .33592 .6145 L .33469 .61096 L F
.401 .396 .738 r
.3375 .6129 m .3382 .61624 L .33592 .6145 L F
0 0 0 r
.51901 .64795 m .52076 .64435 L .52219 .64652 L F
.419 .105 .323 r
.52243 .64332 m .52076 .64435 L .52219 .64652 L F
.766 .682 .77 r
.58456 .65907 m .58149 .65989 L .58386 .65639 L F
.765 .681 .77 r
.58582 .65575 m .58456 .65907 L .58386 .65639 L F
.486 .185 .38 r
.52608 .66561 m .52873 .66509 L .52828 .66343 L F
.506 .269 .489 r
.39168 .61609 m .39409 .61295 L .39266 .61407 L F
.671 .646 .817 r
.78586 .52303 m .78906 .52497 L .78793 .52182 L F
.392 .743 .992 r
.79224 .51969 m .7936 .52062 L .7902 .5207 L F
.786 .757 .827 r
.79005 .52219 m .79224 .51969 L .7902 .5207 L F
.345 .464 .838 r
.78958 .52248 m .78906 .52497 L .79154 .52351 L F
.79146 .52324 m .79154 .52351 L .79178 .52337 L F
.78958 .52248 m .79154 .52351 L .79146 .52324 L F
.786 .757 .827 r
.79102 .5216 m .79303 .52284 L .79224 .51969 L F
.345 .464 .838 r
.78793 .52182 m .78842 .52318 L .78958 .52248 L F
.78842 .52318 m .78906 .52497 L .78958 .52248 L F
.44 .135 .35 r
.78993 .5233 m .78793 .52182 L .78903 .52226 L F
.78993 .5233 m .78903 .52226 L .79178 .52337 L F
.632 .928 .972 r
.79178 .52337 m .78838 .52504 L .78733 .52462 L F
.79178 .52337 m .79089 .52362 L .79026 .52402 L F
.79089 .52362 m .78733 .52462 L .79026 .52402 L F
.583 .713 .932 r
.78847 .52224 m .79026 .52402 L .78733 .52462 L F
.999 .789 .474 r
.78932 .52463 m .79026 .52402 L .78954 .52314 L F
.418 .858 .762 r
.79178 .52337 m .78906 .52497 L .78838 .52504 L F
.999 .789 .474 r
.78908 .52628 m .79026 .52402 L .78932 .52463 L F
.632 .928 .972 r
.79178 .52337 m .79026 .52402 L .78993 .5233 L F
.919 .846 .756 r
.79026 .52402 m .79048 .52393 L .78993 .5233 L F
.79048 .52393 m .79303 .52284 L .78993 .5233 L F
.786 .757 .827 r
.78993 .5233 m .79142 .52308 L .79102 .5216 L F
.79142 .52308 m .79303 .52284 L .79102 .5216 L F
.78993 .5233 m .79102 .5216 L .79005 .52219 L F
.79102 .5216 m .79224 .51969 L .79005 .52219 L F
0 0 .236 r
.20927 .58778 m .20879 .59025 L .20807 .59102 L F
.348 .272 .628 r
.20879 .59025 m .20795 .59348 L .20807 .59102 L F
.409 .334 .66 r
.43577 .6887 m .43738 .68502 L .43545 .68575 L F
.43577 .6887 m .43731 .68844 L .43738 .68502 L F
.484 .345 .616 r
.43577 .6887 m .43802 .69074 L .43731 .68844 L F
.43577 .6887 m .436 .69124 L .43802 .69074 L F
.207 .403 .836 r
.34006 .616 m .34034 .61878 L .3382 .61624 L F
.34006 .616 m .34169 .61909 L .34034 .61878 L F
.807 .524 .511 r
.78945 .51501 m .79247 .51355 L .78902 .51331 L F
.78945 .51501 m .79279 .51599 L .79247 .51355 L F
.225 0 .024 r
.40363 .62336 m .40301 .62446 L .40073 .6251 L F
.43 .043 .202 r
.40582 .62282 m .40301 .62446 L .40363 .62336 L F
.995 .773 .416 r
.73788 .50796 m .7383 .51095 L .73757 .51002 L F
.517 .412 .674 r
.51694 .6631 m .51942 .66261 L .51931 .65995 L F
.543 .29 .482 r
.55149 .6542 m .54829 .65718 L .5476 .6538 L F
.55149 .6542 m .55132 .65692 L .54829 .65718 L F
.514 .525 .806 r
.55149 .6542 m .55435 .6569 L .55132 .65692 L F
.051 0 0 r
.36232 .63976 m .36031 .64102 L .35819 .64151 L F
.089 0 0 r
.36262 .64049 m .36232 .63976 L .36453 .63935 L F
.36262 .64049 m .36031 .64102 L .36232 .63976 L F
.822 .758 .792 r
.67818 .49949 m .67931 .50203 L .6816 .49909 L F
.666 .519 .675 r
.6816 .49909 m .67931 .50203 L .68112 .50136 L F
.22 0 0 r
.45499 .71096 m .45158 .71027 L .45276 .71135 L F
.796 .561 .581 r
.59797 .57294 m .60029 .5706 L .59801 .57047 L F
.59797 .57294 m .59867 .57351 L .60029 .5706 L F
.389 .449 .802 r
.32698 .64283 m .32991 .64382 L .32882 .64149 L F
.885 .784 .744 r
.68012 .49777 m .6816 .49909 L .68075 .49589 L F
.822 .758 .792 r
.67818 .49949 m .6816 .49909 L .68012 .49777 L F
.751 .712 .816 r
.68075 .49589 m .6816 .49909 L .68437 .49651 L F
.644 .655 .845 r
.75333 .48732 m .75445 .49063 L .75236 .48979 L F
.762 .368 .309 r
.75236 .48979 m .75445 .49063 L .75357 .49247 L F
.819 .749 .786 r
.75683 .48725 m .75445 .49063 L .75333 .48732 L F
.644 .235 .253 r
.75445 .49063 m .75703 .4924 L .75357 .49247 L F
.109 .468 .892 r
.42976 .60096 m .4294 .60193 L .42716 .59979 L F
.45 0 0 r
.4294 .60193 m .43054 .60247 L .43266 .60256 L F
.004 .337 .819 r
.42976 .60096 m .43054 .60247 L .4294 .60193 L F
0 0 0 r
.61023 .66125 m .60857 .66439 L .60933 .66269 L F
.397 .211 .509 r
.4346 .60721 m .43315 .60533 L .43368 .60546 L F
.4346 .60721 m .43266 .60788 L .43315 .60533 L F
.359 .562 .914 r
.57542 .67165 m .57955 .67457 L .57765 .67309 L F
.304 .379 .775 r
.57955 .67457 m .58089 .67295 L .57765 .67309 L F
.57955 .67457 m .58118 .67464 L .58089 .67295 L F
.324 .209 .564 r
.57955 .67457 m .5811 .67563 L .58118 .67464 L F
.916 .558 .112 r
.59939 .62574 m .59853 .62502 L .59762 .62199 L F
.97 .923 .689 r
.5975 .62707 m .59939 .62574 L .59868 .62796 L F
.5975 .62707 m .59853 .62502 L .59939 .62574 L F
.065 .627 .776 r
.53572 .6797 m .53435 .67965 L .53227 .67963 L F
.842 .522 .446 r
.53572 .6797 m .5348 .68222 L .53435 .67965 L F
.627 .599 .802 r
.53715 .67629 m .53863 .67988 L .53572 .6797 L F
.717 .377 .402 r
.53817 .68218 m .5348 .68222 L .53572 .6797 L F
.636 .394 .535 r
.53863 .67988 m .53817 .68218 L .53572 .6797 L F
.985 .754 .505 r
.50991 .62724 m .51149 .62537 L .50821 .62458 L F
.50991 .62724 m .51118 .6281 L .51149 .62537 L F
.732 .397 .414 r
.47538 .71693 m .47381 .7194 L .47178 .71669 L F
.669 .32 .374 r
.47748 .71912 m .47381 .7194 L .47538 .71693 L F
.686 .315 .338 r
.47777 .71765 m .47748 .71912 L .47538 .71693 L F
.307 .576 .935 r
.39502 .59559 m .39574 .59438 L .39347 .59455 L F
.39502 .59559 m .39694 .59603 L .39574 .59438 L F
.341 .742 .983 r
.77117 .5116 m .76766 .51096 L .77017 .51028 L F
.482 .685 .956 r
.77293 .50988 m .77117 .5116 L .77017 .51028 L F
.77293 .50988 m .77429 .51179 L .77117 .5116 L F
.456 .132 .327 r
.44093 .676 m .44392 .67387 L .44165 .6743 L F
.482 .508 .808 r
.78764 .49264 m .78878 .49618 L .7909 .49568 L F
.588 .431 .636 r
.78878 .49618 m .79153 .49817 L .7909 .49568 L F
.78878 .49618 m .7892 .49929 L .79153 .49817 L F
.906 .502 .206 r
.56287 .6246 m .56317 .62228 L .56117 .62129 L F
.56287 .6246 m .56451 .62535 L .56317 .62228 L F
.369 .112 .388 r
.43914 .677 m .44087 .67854 L .44093 .676 L F
.43914 .677 m .43864 .67939 L .44087 .67854 L F
0 0 .24 r
.47639 .67348 m .47577 .67709 L .47453 .6743 L F
.363 .042 .281 r
.37884 .62022 m .38044 .62124 L .38184 .61911 L F
.37884 .62022 m .37832 .62185 L .38044 .62124 L F
.338 0 .145 r
.5841 .58884 m .58391 .58997 L .58159 .59048 L F
.39 0 .086 r
.5841 .58884 m .58654 .5895 L .58391 .58997 L F
.5841 .58884 m .5875 .58788 L .58654 .5895 L F
.725 .659 .785 r
.44572 .70743 m .44917 .70875 L .44838 .70751 L F
.205 .533 .924 r
.44838 .70751 m .44917 .70875 L .44971 .70765 L F
.073 .363 .832 r
.44917 .70875 m .45158 .71027 L .44971 .70765 L F
.333 .367 .747 r
.40785 .60215 m .40859 .59836 L .40661 .59853 L F
.40785 .60215 m .40957 .602 L .40859 .59836 L F
.586 .556 .788 r
.40877 .60505 m .40957 .602 L .40785 .60215 L F
0 0 .509 r
.5576 .65875 m .55756 .66017 L .55667 .65643 L F
.826 .592 .04 r
.5576 .65875 m .55814 .66199 L .55756 .66017 L F
.308 .742 .969 r
.38265 .58484 m .38484 .58476 L .38631 .58544 L F
.405 .803 .985 r
.38705 .5845 m .38631 .58544 L .38484 .58476 L F
.38705 .5845 m .3885 .58511 L .38631 .58544 L F
.245 .049 .404 r
.48563 .63333 m .48407 .63415 L .48376 .63649 L F
.282 0 .234 r
.52666 .65182 m .52601 .6535 L .52746 .65256 L F
.859 .948 .873 r
.32991 .64382 m .33295 .6426 L .33147 .64187 L F
.673 .627 .795 r
.33193 .63949 m .33295 .6426 L .33587 .64177 L F
.515 .406 .668 r
.29794 .60585 m .29998 .6053 L .29961 .60162 L F
.518 .364 .611 r
.29962 .59953 m .30185 .59901 L .30168 .59653 L F
.5 .322 .571 r
.29961 .60162 m .30185 .59901 L .29962 .59953 L F
.366 0 .047 r
.52044 .68345 m .51769 .68439 L .51823 .68332 L F
.411 .439 .78 r
.30146 .6109 m .30231 .6141 L .30414 .61298 L F
.249 .266 .683 r
.30231 .6141 m .30443 .61486 L .30414 .61298 L F
.30231 .6141 m .30312 .61666 L .30443 .61486 L F
.45 .271 .546 r
.51891 .65029 m .51701 .64885 L .51901 .64795 L F
.51891 .65029 m .51696 .651 L .51701 .64885 L F
.659 .613 .792 r
.53608 .66835 m .53887 .66837 L .53833 .66551 L F
.656 .331 .411 r
.4812 .7168 m .47748 .71912 L .47777 .71765 L F
.4812 .7168 m .47976 .71936 L .47748 .71912 L F
.47 .128 .304 r
.48255 .71888 m .4812 .7168 L .48356 .7178 L F
.48255 .71888 m .47976 .71936 L .4812 .7168 L F
.481 .165 .353 r
.58424 .58109 m .5825 .57914 L .58209 .58168 L F
.58424 .58109 m .58491 .57872 L .5825 .57914 L F
.819 .749 .786 r
.75683 .48725 m .75333 .48732 L .75571 .48668 L F
.312 .099 .42 r
.21328 .58387 m .21164 .58207 L .21241 .58123 L F
.21328 .58387 m .21109 .58502 L .21164 .58207 L F
.144 .585 .929 r
.55491 .61558 m .55583 .61641 L .55474 .61393 L F
.056 0 .405 r
.5578 .61184 m .55581 .61574 L .55617 .61325 L F
.144 .585 .929 r
.55524 .61587 m .55694 .61675 L .55583 .61641 L F
.55491 .61558 m .55537 .61584 L .55524 .61587 L F
.55537 .61584 m .55694 .61675 L .55524 .61587 L F
.821 .386 0 r
.55491 .61558 m .55711 .619 L .55694 .61675 L F
.55547 .61645 m .5561 .61804 L .55711 .619 L F
.5554 .61633 m .55546 .61649 L .55547 .61645 L F
.55546 .61649 m .5561 .61804 L .55547 .61645 L F
0 0 0 r
.55544 .6166 m .55761 .61439 L .55628 .61618 L F
.55535 .61664 m .55545 .61654 L .55544 .6166 L F
.55545 .61654 m .55761 .61439 L .55544 .6166 L F
.821 .386 0 r
.55543 .61648 m .5561 .61804 L .55536 .61628 L F
.55559 .61698 m .55568 .61716 L .55543 .61648 L F
.55568 .61716 m .5561 .61804 L .55543 .61648 L F
.056 0 .405 r
.5578 .61184 m .55761 .61439 L .55545 .61654 L F
.55543 .61648 m .55545 .61654 L .55535 .61664 L F
.5578 .61184 m .55545 .61654 L .55543 .61648 L F
0 0 0 r
.55535 .61664 m .55572 .61788 L .5561 .61804 L F
.55553 .61724 m .55628 .61618 L .55572 .61788 L F
0 0 .44 r
.55535 .61664 m .5561 .61804 L .55545 .61669 L F
0 0 0 r
.55535 .61664 m .55544 .6166 L .55545 .61669 L F
.821 .386 0 r
.55536 .61628 m .5554 .61638 L .5554 .61633 L F
.55491 .61558 m .5554 .61641 L .55536 .61628 L F
.689 .53 .667 r
.55617 .61325 m .5554 .61641 L .55491 .61558 L F
.5554 .61641 m .55535 .61664 L .55491 .61558 L F
.056 0 .405 r
.55543 .61648 m .55535 .61664 L .5554 .61641 L F
.821 .386 0 r
.55491 .61558 m .55559 .61698 L .5554 .61641 L F
0 0 .44 r
.55535 .61664 m .55545 .61669 L .55491 .61558 L F
0 0 0 r
.55535 .61664 m .55545 .61669 L .55553 .61724 L F
.821 .386 0 r
.5554 .61638 m .5561 .61804 L .5554 .61633 L F
0 0 0 r
.55544 .6166 m .55628 .61618 L .55553 .61724 L F
.056 0 .405 r
.55581 .61574 m .55543 .61648 L .55555 .6158 L F
.55543 .61648 m .5554 .61641 L .55555 .6158 L F
.55581 .61574 m .55555 .6158 L .55617 .61325 L F
.452 .502 .82 r
.42661 .59766 m .42523 .59986 L .42414 .59802 L F
.42661 .59766 m .42716 .59979 L .42523 .59986 L F
.1 0 .324 r
.80378 .50804 m .80525 .50677 L .80348 .50987 L F
.515 .888 .971 r
.46134 .70208 m .45971 .70272 L .45814 .7023 L F
0 .19 .722 r
.54252 .63709 m .54117 .63677 L .53999 .63571 L F
.54252 .63709 m .54351 .63904 L .54117 .63677 L F
0 0 0 r
.78015 .5299 m .78138 .52884 L .78331 .52732 L F
.716 .791 .91 r
.73127 .50721 m .7276 .50698 L .73057 .50553 L F
.547 .72 .953 r
.73264 .5052 m .73127 .50721 L .73057 .50553 L F
.73264 .5052 m .73366 .50678 L .73127 .50721 L F
.668 .77 .927 r
.5956 .61886 m .5977 .61981 L .59386 .61938 L F
.759 .525 .579 r
.59386 .61938 m .5977 .61981 L .59762 .62199 L F
.409 .159 .421 r
.45942 .66001 m .45696 .66287 L .45918 .66231 L F
.487 .235 .457 r
.46138 .66178 m .45942 .66001 L .45918 .66231 L F
.46138 .66178 m .46162 .65962 L .45942 .66001 L F
.522 .289 .502 r
.59344 .64276 m .59077 .64558 L .5907 .64274 L F
.59344 .64276 m .59315 .64522 L .59077 .64558 L F
.527 .294 .505 r
.59506 .64224 m .59315 .64522 L .59344 .64276 L F
.62 .548 .752 r
.52935 .67935 m .53227 .67963 L .53131 .67649 L F
.189 0 0 r
.48175 .68021 m .48075 .68183 L .47832 .68259 L F
.992 .816 .441 r
.48103 .67905 m .48175 .68021 L .4843 .68016 L F
.48103 .67905 m .48075 .68183 L .48175 .68021 L F
.264 .642 .964 r
.40261 .58612 m .40226 .58708 L .4008 .58624 L F
.40261 .58612 m .40396 .58721 L .40226 .58708 L F
.152 0 0 r
.37074 .63766 m .36904 .63873 L .36678 .63909 L F
.068 0 0 r
.37304 .63719 m .36904 .63873 L .37074 .63766 L F
.851 .529 .443 r
.59502 .59377 m .59295 .59339 L .59167 .59062 L F
.846 .508 .414 r
.59502 .59377 m .59338 .59547 L .59295 .59339 L F
.909 .617 .48 r
.59525 .5961 m .59338 .59547 L .59502 .59377 L F
0 .267 .774 r
.53448 .61311 m .53174 .60993 L .53212 .61169 L F
.604 .337 .485 r
.50768 .63961 m .50561 .64156 L .50587 .63963 L F
.946 .67 .483 r
.60228 .58371 m .60385 .58235 L .6008 .58108 L F
.60228 .58371 m .60392 .58469 L .60385 .58235 L F
.744 .802 .899 r
.31179 .64281 m .30912 .64492 L .30909 .64394 L F
.233 .669 .957 r
.55039 .62526 m .54732 .62409 L .5494 .62488 L F
.601 .242 .332 r
.46486 .68159 m .46384 .67943 L .46666 .6795 L F
.46486 .68159 m .46269 .6818 L .46384 .67943 L F
0 .317 .781 r
.56185 .63769 m .56345 .63815 L .56194 .63633 L F
.56185 .63769 m .5639 .63891 L .56345 .63815 L F
.692 .158 0 r
.56345 .63815 m .56416 .63966 L .56298 .63737 L F
0 0 .532 r
.56194 .63633 m .56345 .63815 L .56273 .6369 L F
.692 .158 0 r
.56345 .63815 m .56298 .63737 L .56273 .6369 L F
0 .317 .781 r
.5639 .63891 m .56455 .6393 L .56345 .63815 L F
.851 .66 .644 r
.6075 .58761 m .60552 .59041 L .60875 .59096 L F
.771 .53 .57 r
.60522 .59295 m .60875 .59096 L .60552 .59041 L F
.60522 .59295 m .60883 .59334 L .60875 .59096 L F
.245 .495 .896 r
.58993 .67582 m .58802 .67612 L .58903 .67552 L F
.58993 .67582 m .58903 .67552 L .59115 .67427 L F
0 .35 .683 r
.58784 .675 m .58996 .67584 L .58993 .67582 L F
.485 .31 .567 r
.59228 .6767 m .58993 .67582 L .59226 .67533 L F
0 .35 .683 r
.59001 .67585 m .59002 .67586 L .58993 .67582 L F
.485 .31 .567 r
.59229 .67779 m .58993 .67582 L .59228 .6767 L F
0 .35 .683 r
.58996 .67584 m .59001 .67585 L .58993 .67582 L F
.245 .495 .896 r
.58993 .67582 m .59002 .67586 L .58802 .67612 L F
.369 .739 .989 r
.58243 .67556 m .58993 .67585 L .58784 .675 L F
.99 .731 .428 r
.58993 .67582 m .58991 .67585 L .58971 .67574 L F
.369 .739 .989 r
.58993 .67585 m .59002 .67586 L .5897 .67573 L F
0 .35 .683 r
.58784 .675 m .58993 .67582 L .58971 .67574 L F
.369 .739 .989 r
.58993 .67585 m .58971 .67574 L .58784 .675 L F
0 .35 .683 r
.58791 .67502 m .58971 .67574 L .58825 .67516 L F
.543 .749 .972 r
.58825 .67516 m .59117 .67466 L .59012 .67343 L F
.369 .739 .989 r
.58971 .67574 m .5897 .67573 L .58784 .675 L F
.99 .731 .428 r
.58971 .67574 m .58991 .67585 L .58825 .67516 L F
.58991 .67585 m .58991 .67585 L .58971 .67574 L F
.171 .684 .895 r
.58802 .67612 m .58996 .67586 L .58243 .67556 L F
.58996 .67586 m .58993 .67585 L .58243 .67556 L F
.99 .731 .428 r
.58991 .67585 m .58874 .67741 L .5883 .67541 L F
.58991 .67585 m .5883 .67541 L .58825 .67516 L F
.171 .684 .895 r
.58996 .67586 m .59002 .67586 L .58999 .67586 L F
.485 .31 .567 r
.58997 .67586 m .58993 .67586 L .58993 .67582 L F
.171 .684 .895 r
.58994 .67586 m .58999 .67586 L .58993 .67585 L F
.58996 .67586 m .58999 .67586 L .58994 .67586 L F
.485 .31 .567 r
.59106 .67678 m .58997 .67814 L .58993 .67586 L F
.59229 .67779 m .58993 .67586 L .58997 .67586 L F
.243 0 0 r
.59341 .67368 m .58993 .67582 L .59115 .67427 L F
.59341 .67368 m .59226 .67533 L .58993 .67582 L F
.99 .731 .428 r
.58993 .67582 m .58998 .67853 L .58874 .67741 L F
.779 .539 .574 r
.58874 .67741 m .59221 .67536 L .59117 .67466 L F
.59221 .67536 m .59226 .67533 L .59224 .67532 L F
.59221 .67536 m .59224 .67532 L .59117 .67466 L F
.485 .31 .567 r
.59229 .67779 m .58998 .67853 L .58997 .67814 L F
.59229 .67779 m .58997 .67814 L .59106 .67678 L F
.524 .331 .562 r
.58825 .67516 m .58874 .67741 L .59117 .67466 L F
.543 .749 .972 r
.58825 .67516 m .59012 .67343 L .58885 .67541 L F
.58825 .67516 m .58885 .67541 L .5887 .67564 L F
0 .35 .683 r
.58784 .675 m .58791 .67502 L .58825 .67516 L F
.581 .379 .572 r
.49269 .62224 m .49492 .6197 L .49264 .61952 L F
.317 .458 .844 r
.52778 .67974 m .52694 .67999 L .52515 .67657 L F
.47 .245 .489 r
.52871 .68187 m .52694 .67999 L .52778 .67974 L F
.52871 .68187 m .52654 .68229 L .52694 .67999 L F
.416 .816 .982 r
.52762 .68129 m .52871 .68187 L .5283 .68092 L F
.52762 .68129 m .5283 .68092 L .52778 .67974 L F
.752 .615 .707 r
.52984 .68064 m .52693 .68167 L .52762 .68129 L F
.375 .812 .656 r
.52548 .68218 m .52418 .68297 L .52762 .68129 L F
.752 .615 .707 r
.52693 .68167 m .52548 .68218 L .52762 .68129 L F
.416 .816 .982 r
.52762 .68129 m .53073 .68148 L .52871 .68187 L F
.53073 .68148 m .53104 .6815 L .52871 .68187 L F
.47 .245 .489 r
.52871 .68187 m .5265 .68251 L .52654 .68229 L F
.905 .982 .717 r
.53366 .65491 m .53564 .65382 L .53433 .65366 L F
.53366 .65491 m .53328 .65698 L .53564 .65382 L F
.385 .841 .909 r
.53663 .653 m .53564 .65382 L .53798 .65175 L F
.53663 .653 m .53433 .65366 L .53564 .65382 L F
.225 .104 .497 r
.43715 .68259 m .43864 .67939 L .43675 .68012 L F
.385 .721 .989 r
.20483 .54693 m .20453 .54814 L .20307 .54664 L F
.20483 .54693 m .20651 .54807 L .20453 .54814 L F
.544 .297 .491 r
.50028 .65683 m .50256 .6565 L .50266 .65435 L F
.426 .113 .33 r
.40306 .6107 m .4053 .61019 L .40625 .60758 L F
.479 .29 .546 r
.40625 .60758 m .40838 .60715 L .40877 .60505 L F
.35 .042 .295 r
.40625 .60758 m .40738 .60947 L .40838 .60715 L F
.40625 .60758 m .4053 .61019 L .40738 .60947 L F
.365 .831 .774 r
.79129 .52628 m .79502 .52502 L .79434 .5246 L F
.156 .198 .655 r
.79649 .52372 m .79502 .52502 L .79464 .52161 L F
.556 .918 .953 r
.79434 .5246 m .79502 .52502 L .79649 .52372 L F
.333 .792 .943 r
.34612 .58285 m .34839 .58252 L .3499 .58287 L F
.062 0 0 r
.34839 .58252 m .35201 .58197 L .3499 .58287 L F
.376 0 .08 r
.39038 .63056 m .39108 .63217 L .38896 .63233 L F
.39038 .63056 m .39245 .63029 L .39108 .63217 L F
.308 0 0 r
.56184 .61321 m .56357 .61291 L .56409 .61432 L F
.56357 .61291 m .56321 .61645 L .56409 .61432 L F
.609 .252 .338 r
.75236 .48979 m .7513 .49181 L .74846 .49116 L F
.644 .655 .845 r
.75333 .48732 m .75236 .48979 L .7508 .48815 L F
.762 .368 .309 r
.75236 .48979 m .75357 .49247 L .7513 .49181 L F
.645 .577 .764 r
.66888 .49597 m .67252 .4986 L .67153 .49542 L F
.234 .229 .649 r
.57523 .66824 m .57542 .67165 L .57708 .67012 L F
.353 .425 .796 r
.57542 .67165 m .57765 .67309 L .57708 .67012 L F
.072 .59 .879 r
.48553 .69726 m .48476 .69674 L .48211 .69641 L F
.934 .966 .745 r
.48657 .69348 m .48553 .69726 L .48793 .69583 L F
.48657 .69348 m .48476 .69674 L .48553 .69726 L F
.149 0 0 r
.35755 .59775 m .35564 .59804 L .35597 .59772 L F
.587 .397 .591 r
.51098 .66274 m .51091 .66529 L .51313 .66486 L F
.507 .277 .5 r
.59302 .5734 m .59554 .57297 L .59553 .5708 L F
.654 .393 .512 r
.59554 .57297 m .59797 .57294 L .59553 .5708 L F
.597 .405 .592 r
.59553 .5708 m .59797 .57294 L .59801 .57047 L F
.619 .627 .837 r
.54846 .64483 m .54608 .64568 L .54444 .64234 L F
.591 .885 .991 r
.56102 .68613 m .56204 .68424 L .563 .68521 L F
.997 .828 .48 r
.563 .68521 m .56204 .68424 L .56102 .68613 L F
.472 .086 .226 r
.49253 .64839 m .49178 .65023 L .48941 .65037 L F
.558 .169 .261 r
.49477 .65005 m .49253 .64839 L .49515 .64758 L F
.49477 .65005 m .49178 .65023 L .49253 .64839 L F
.463 0 .046 r
.49045 .64686 m .4944 .64479 L .49054 .64462 L F
.49045 .64686 m .49308 .64679 L .4944 .64479 L F
0 0 .347 r
.4944 .64479 m .49561 .64135 L .4943 .64258 L F
.4944 .64479 m .49594 .64401 L .49561 .64135 L F
.53 .311 .526 r
.49308 .64679 m .49594 .64401 L .4944 .64479 L F
.892 .884 .818 r
.72507 .49315 m .72289 .4963 L .72177 .49504 L F
.578 .042 0 r
.72524 .49553 m .72177 .49504 L .72289 .4963 L F
0 .419 .726 r
.4609 .71306 m .45809 .71212 L .45831 .71253 L F
.743 .945 .948 r
.75559 .52477 m .75654 .52547 L .75829 .52419 L F
.503 .332 .582 r
.2974 .63092 m .29963 .63047 L .29948 .62847 L F
.344 0 .009 r
.38044 .62124 m .38424 .61926 L .38184 .61911 L F
.654 .787 .945 r
.75842 .50975 m .75596 .51067 L .755 .50928 L F
.316 .719 .979 r
.77515 .49149 m .77721 .49078 L .77488 .49083 L F
.77515 .49149 m .77815 .49165 L .77721 .49078 L F
.948 .702 .533 r
.59867 .57351 m .5995 .57644 L .60075 .5769 L F
.938 .784 .663 r
.5995 .57644 m .60046 .57933 L .60075 .5769 L F
0 0 0 r
.61236 .63689 m .61396 .63305 L .61351 .6353 L F
0 0 .266 r
.61298 .63817 m .61236 .63689 L .61351 .6353 L F
.61298 .63817 m .61249 .63932 L .61236 .63689 L F
.766 .656 .741 r
.48156 .66936 m .48265 .67055 L .48441 .66854 L F
.524 .302 .519 r
.48263 .65664 m .47991 .65968 L .48057 .65718 L F
.463 .074 .216 r
.41687 .6165 m .41587 .61847 L .41361 .61856 L F
.526 .199 .356 r
.41915 .61602 m .41587 .61847 L .41687 .6165 L F
.514 .203 .378 r
.38424 .61926 m .3866 .61897 L .38714 .61716 L F
.431 .119 .333 r
.3866 .61897 m .38926 .61676 L .38714 .61716 L F
.798 .322 .093 r
.54262 .65953 m .53962 .65714 L .5414 .65756 L F
.15 .693 .783 r
.36396 .59671 m .36016 .59698 L .36173 .59656 L F
.537 .626 .888 r
.74555 .52139 m .7472 .52442 L .74939 .52391 L F
.277 .675 .971 r
.34403 .62055 m .3435 .62145 L .34169 .61909 L F
.34403 .62055 m .34546 .62156 L .3435 .62145 L F
.296 0 .098 r
.55451 .59272 m .55716 .59102 L .55544 .5914 L F
.704 .527 .645 r
.55032 .66345 m .54627 .66671 L .54667 .66277 L F
.702 .442 .527 r
.50444 .6603 m .50389 .66239 L .50138 .66219 L F
.541 .319 .526 r
.50677 .65957 m .50389 .66239 L .50444 .6603 L F
0 0 0 r
.53325 .60195 m .53475 .60111 L .53602 .59906 L F
.53325 .60195 m .53212 .60377 L .53475 .60111 L F
.611 .788 .966 r
.36227 .62594 m .3584 .62529 L .3606 .62513 L F
.342 .754 .98 r
.36261 .62507 m .36227 .62594 L .3606 .62513 L F
.36261 .62507 m .36418 .62583 L .36227 .62594 L F
.815 .548 .534 r
.48103 .67905 m .4843 .68016 L .48371 .67743 L F
.539 .409 .652 r
.48371 .67743 m .4864 .67872 L .48626 .67666 L F
.184 0 0 r
.36759 .59597 m .36588 .5968 L .36396 .59671 L F
.015 0 0 r
.36978 .59584 m .36588 .5968 L .36759 .59597 L F
.563 .353 .554 r
.48405 .6933 m .48746 .69113 L .48456 .69164 L F
.277 0 0 r
.36418 .62583 m .36629 .62617 L .36801 .62548 L F
.516 .041 .066 r
.36629 .62617 m .3702 .62504 L .36801 .62548 L F
.511 .734 .974 r
.78771 .48328 m .78615 .48494 L .78522 .48364 L F
.78771 .48328 m .78865 .48465 L .78615 .48494 L F
.425 .389 .715 r
.4293 .69985 m .43134 .70135 L .43156 .69985 L F
.801 .723 .192 r
.61246 .64774 m .61206 .65042 L .61209 .65113 L F
.304 0 .126 r
.40073 .6251 m .39954 .62724 L .39745 .62784 L F
.54 .23 .391 r
.40301 .62446 m .39954 .62724 L .40073 .6251 L F
.7 .202 .055 r
.50075 .62231 m .50441 .62403 L .50227 .62226 L F
0 0 0 r
.37876 .63515 m .37518 .63662 L .3764 .63585 L F
.079 .603 .874 r
.49409 .71494 m .49838 .71598 L .49728 .71417 L F
.634 .457 .626 r
.49753 .64507 m .49515 .64758 L .495 .64517 L F
.429 .701 .979 r
.57078 .62856 m .5697 .63012 L .56791 .62823 L F
.57078 .62856 m .57189 .62997 L .5697 .63012 L F
.153 .692 .712 r
.59364 .64708 m .59632 .64655 L .59441 .64694 L F
.256 .737 .932 r
.39069 .58442 m .39434 .58476 L .39216 .58534 L F
.411 0 .144 r
.51432 .65428 m .51153 .65525 L .51195 .65404 L F
.552 .584 .84 r
.42285 .59528 m .422 .5983 L .4211 .59572 L F
.42285 .59528 m .42414 .59802 L .422 .5983 L F
.552 .779 .983 r
.76329 .50874 m .76183 .51045 L .76085 .50933 L F
.76329 .50874 m .76432 .50996 L .76183 .51045 L F
.617 .814 .401 r
.51454 .68033 m .51267 .68325 L .51342 .68202 L F
.427 .016 .155 r
.51342 .68202 m .51714 .67982 L .51454 .68033 L F
0 0 .345 r
.61273 .64421 m .61246 .64774 L .61152 .64573 L F
.861 .598 .539 r
.74804 .48348 m .74979 .48161 L .74643 .48105 L F
.74804 .48348 m .74998 .48412 L .74979 .48161 L F
.78 .504 .518 r
.58983 .58778 m .58654 .5895 L .5875 .58788 L F
.584 .578 .812 r
.7816 .50499 m .78269 .50124 L .78168 .50136 L F
.7816 .50499 m .78384 .5046 L .78269 .50124 L F
.892 .884 .818 r
.72507 .49315 m .72177 .49504 L .7241 .49212 L F
.961 .675 .449 r
.72393 .49513 m .72507 .49315 L .7241 .49212 L F
.72393 .49513 m .72524 .49553 L .72507 .49315 L F
.322 .182 .531 r
.21549 .57812 m .21241 .58123 L .21323 .57921 L F
.21549 .57812 m .21545 .58075 L .21241 .58123 L F
.358 .158 .466 r
.21545 .58075 m .21328 .58387 L .21241 .58123 L F
0 0 .25 r
.61398 .62822 m .61392 .62473 L .61391 .62607 L F
.779 .579 .01 r
.614 .62994 m .61398 .62822 L .61391 .62607 L F
.614 .62994 m .61419 .6307 L .61398 .62822 L F
.366 .239 .573 r
.21676 .56782 m .2169 .57019 L .21537 .57082 L F
.384 .28 .612 r
.2169 .57019 m .21721 .57266 L .21537 .57082 L F
.295 .268 .658 r
.21537 .57082 m .21721 .57266 L .21591 .57317 L F
.473 .615 .91 r
.79741 .48562 m .79575 .48723 L .79509 .48604 L F
.79741 .48562 m .79809 .4871 L .79575 .48723 L F
.858 .531 .432 r
.59167 .59062 m .59012 .59245 L .59017 .59008 L F
.59167 .59062 m .59295 .59339 L .59012 .59245 L F
.612 .644 .858 r
.80055 .48655 m .79925 .49007 L .79809 .4871 L F
.80055 .48655 m .8019 .48949 L .79925 .49007 L F
.628 .381 .524 r
.59235 .57549 m .59554 .57297 L .59302 .5734 L F
.359 .024 .254 r
.45409 .66524 m .45632 .6647 L .45696 .66287 L F
.466 .122 .299 r
.45696 .66287 m .45632 .6647 L .45858 .66431 L F
.425 .129 .356 r
.45696 .66287 m .45858 .66431 L .45918 .66231 L F
.499 .602 .886 r
.55204 .65981 m .54829 .65718 L .55132 .65692 L F
.605 .441 .633 r
.55435 .6569 m .55527 .65972 L .55204 .65981 L F
.815 .755 .797 r
.55435 .6569 m .55204 .65981 L .55132 .65692 L F
.58 .315 .479 r
.55204 .65981 m .55396 .66211 L .55527 .65972 L F
.605 .441 .633 r
.55435 .6569 m .55527 .65972 L .55204 .65981 L F
.58 .315 .479 r
.55204 .65981 m .55396 .66211 L .55527 .65972 L F
.575 .534 .771 r
.67252 .4986 m .67423 .49603 L .67153 .49542 L F
.67252 .4986 m .67486 .49789 L .67423 .49603 L F
.587 .613 .846 r
.67252 .4986 m .67565 .49991 L .67486 .49789 L F
.484 .556 .854 r
.55455 .61025 m .55617 .61325 L .55474 .61393 L F
.144 .585 .929 r
.55491 .61558 m .55474 .61393 L .55617 .61325 L F
.36 .534 .892 r
.72848 .51075 m .73158 .51051 L .72764 .50969 L F
.72848 .51075 m .73162 .51173 L .73158 .51051 L F
.948 .907 .527 r
.47389 .66793 m .47431 .66481 L .472 .66783 L F
0 0 .418 r
.47409 .66742 m .47389 .66793 L .472 .66783 L F
.47409 .66742 m .47533 .67134 L .47389 .66793 L F
0 .245 .759 r
.73985 .51863 m .74074 .51825 L .73864 .51622 L F
0 .168 .616 r
.74173 .51901 m .74074 .51825 L .73985 .51863 L F
.487 .2 .404 r
.51153 .65525 m .50865 .65889 L .50954 .65567 L F
.646 .366 .481 r
.75947 .48626 m .76183 .48464 L .75913 .48458 L F
.676 .686 .852 r
.5402 .70943 m .54321 .70803 L .54159 .70815 L F
.349 .029 .274 r
.53857 .70852 m .54037 .70877 L .54125 .70624 L F
.54037 .70877 m .54053 .70868 L .54125 .70624 L F
.5405 .70879 m .54056 .70877 L .54125 .70624 L F
.612 .382 .544 r
.54059 .70865 m .5432 .70518 L .54125 .70624 L F
.676 .686 .852 r
.5402 .70943 m .54159 .70815 L .54014 .70888 L F
.612 .382 .544 r
.54056 .70879 m .54074 .70855 L .54059 .70865 L F
.54074 .70855 m .5432 .70518 L .54059 .70865 L F
.676 .686 .852 r
.54014 .70888 m .54059 .70865 L .54007 .70826 L F
.612 .382 .544 r
.54074 .70855 m .54321 .70803 L .5432 .70518 L F
.676 .686 .852 r
.54059 .70865 m .54085 .70852 L .54074 .70855 L F
.612 .382 .544 r
.54056 .70879 m .54321 .70803 L .54074 .70855 L F
.676 .686 .852 r
.54074 .70855 m .54159 .70815 L .54123 .70818 L F
.54085 .70852 m .54159 .70815 L .54074 .70855 L F
.54059 .70865 m .54123 .70818 L .54007 .70826 L F
.349 .029 .274 r
.54037 .70877 m .5405 .70879 L .54053 .70868 L F
.5405 .70879 m .54056 .70879 L .54056 .70877 L F
.633 .545 .737 r
.53722 .70807 m .53942 .70907 L .54007 .70826 L F
.441 .268 .549 r
.53857 .70852 m .5402 .70943 L .54056 .70879 L F
.633 .545 .737 r
.53942 .70907 m .5402 .70943 L .54014 .70888 L F
.53942 .70907 m .54014 .70888 L .54007 .70826 L F
.515 .116 .223 r
.53722 .70807 m .54007 .70826 L .54125 .70624 L F
.657 .418 .546 r
.54007 .70826 m .5432 .70518 L .54125 .70624 L F
.406 .266 .577 r
.54125 .70624 m .5432 .70518 L .54311 .70268 L F
.728 .756 .875 r
.40041 .5974 m .40355 .59776 L .40265 .59642 L F
.452 .663 .952 r
.40355 .59776 m .4046 .59633 L .40265 .59642 L F
.40355 .59776 m .40661 .59853 L .4046 .59633 L F
.546 .549 .809 r
.73757 .51002 m .73599 .51151 L .73366 .50678 L F
.287 0 .025 r
.54279 .66728 m .54058 .66699 L .54393 .66684 L F
.54279 .66728 m .54063 .66796 L .54058 .66699 L F
.605 .635 .854 r
.74939 .52391 m .75014 .52636 L .75261 .52564 L F
.176 .272 .725 r
.45215 .69028 m .45103 .69215 L .44996 .68817 L F
.275 .403 .812 r
.45215 .69028 m .45347 .69347 L .45103 .69215 L F
.367 0 .156 r
.31422 .59004 m .31794 .58733 L .31478 .58827 L F
.31422 .59004 m .31644 .5896 L .31794 .58733 L F
.364 0 .118 r
.31644 .5896 m .32003 .58716 L .31794 .58733 L F
.885 .768 .728 r
.5995 .57644 m .59869 .57883 L .60046 .57933 L F
.893 .573 .434 r
.59869 .57883 m .59905 .581 L .60046 .57933 L F
.828 .47 .377 r
.60046 .57933 m .59905 .581 L .6008 .58108 L F
.911 .527 .276 r
.48265 .67055 m .48144 .67049 L .48156 .66936 L F
.555 .81 .993 r
.77418 .52684 m .77797 .52712 L .77704 .52592 L F
.747 .586 .676 r
.77591 .52855 m .77797 .52712 L .77418 .52684 L F
.976 .756 .54 r
.77797 .52712 m .77769 .53046 L .7763 .52809 L F
.985 .879 .64 r
.77704 .52592 m .77797 .52712 L .7763 .52809 L F
.391 0 0 r
.30646 .62178 m .30283 .62151 L .30469 .62129 L F
.501 .267 .492 r
.30469 .62129 m .30646 .62178 L .30674 .61948 L F
.723 .652 .778 r
.77988 .52214 m .78223 .52163 L .78118 .51824 L F
.595 .58 .806 r
.78223 .52163 m .78357 .51762 L .78118 .51824 L F
.78223 .52163 m .78459 .52093 L .78357 .51762 L F
.67 .593 .76 r
.78223 .52163 m .78586 .52303 L .78459 .52093 L F
.457 .338 .63 r
.48211 .69641 m .48476 .69674 L .48405 .6933 L F
.569 .867 .996 r
.33878 .6453 m .34232 .64528 L .34065 .64411 L F
.384 .633 .953 r
.34232 .64528 m .34185 .64257 L .34065 .64411 L F
.34232 .64528 m .34451 .64561 L .34185 .64257 L F
.71 .66 .799 r
.61257 .59524 m .60883 .59334 L .6088 .5958 L F
.61257 .59524 m .61253 .5939 L .60883 .59334 L F
.861 .649 .613 r
.60889 .59806 m .61257 .59524 L .6088 .5958 L F
.60889 .59806 m .61083 .59897 L .61257 .59524 L F
.827 .6 .595 r
.60392 .58469 m .60385 .58717 L .6075 .58761 L F
.828 .626 .629 r
.60385 .58717 m .60552 .59041 L .6075 .58761 L F
.543 .244 .41 r
.56545 .5878 m .56846 .5869 L .56863 .585 L F
.553 .254 .415 r
.56846 .5869 m .57109 .58481 L .56863 .585 L F
.884 .667 .603 r
.61262 .61532 m .61583 .61331 L .61266 .61287 L F
.61262 .61532 m .61464 .61658 L .61583 .61331 L F
.672 .422 .533 r
.61583 .61331 m .61464 .61658 L .61603 .61381 L F
.89 .667 .593 r
.612 .60459 m .61352 .60206 L .61032 .60129 L F
.87 .607 .538 r
.49074 .67648 m .49201 .67994 L .49357 .68001 L F
.744 .228 0 r
.49407 .68053 m .49573 .68226 L .49407 .68143 L F
.54 .341 .559 r
.49591 .67941 m .49573 .68226 L .49357 .68001 L F
.396 0 .16 r
.49933 .67977 m .49573 .68226 L .49591 .67941 L F
.744 .228 0 r
.49357 .68001 m .49267 .68073 L .49402 .68203 L F
.764 .262 .016 r
.49267 .68073 m .49391 .68135 L .49402 .68203 L F
.49391 .68135 m .49573 .68226 L .49402 .68203 L F
.744 .228 0 r
.49391 .68135 m .49402 .68203 L .49406 .68196 L F
.49357 .68001 m .49402 .68203 L .49391 .68135 L F
.104 0 0 r
.49591 .67941 m .49406 .68196 L .49682 .68051 L F
.49406 .68196 m .49402 .68203 L .49406 .682 L F
.49406 .68196 m .49406 .682 L .49682 .68051 L F
.744 .228 0 r
.49357 .68001 m .49407 .68053 L .49391 .68135 L F
.49407 .68053 m .49407 .68143 L .49391 .68135 L F
.49357 .68001 m .49391 .68135 L .49267 .68073 L F
.49357 .68001 m .49406 .68196 L .49591 .67941 L F
.454 .295 .576 r
.55032 .66345 m .55208 .66478 L .55205 .66226 L F
.55032 .66345 m .55208 .66478 L .55205 .66226 L F
.723 .652 .778 r
.77988 .52214 m .7794 .51824 L .7792 .52108 L F
.77988 .52214 m .78118 .51824 L .7794 .51824 L F
.918 .84 .387 r
.77941 .52307 m .77988 .52214 L .7792 .52108 L F
.77941 .52307 m .7793 .52536 L .77988 .52214 L F
.331 .385 .768 r
.48748 .68076 m .48857 .67854 L .4864 .67872 L F
.48748 .68076 m .48983 .68192 L .48857 .67854 L F
.814 .758 .8 r
.7415 .47508 m .74294 .47666 L .74474 .47532 L F
.655 .341 .429 r
.78322 .51344 m .78587 .51533 L .78659 .51304 L F
.65 .334 .422 r
.78945 .51501 m .78659 .51304 L .78587 .51533 L F
.78945 .51501 m .78902 .51331 L .78659 .51304 L F
.677 .727 .888 r
.73603 .50601 m .73788 .50796 L .73366 .50678 L F
.546 .549 .809 r
.73757 .51002 m .73366 .50678 L .73788 .50796 L F
.667 .724 .892 r
.73938 .50646 m .73788 .50796 L .73603 .50601 L F
.147 0 .333 r
.73938 .50646 m .73757 .51002 L .73788 .50796 L F
.73938 .50646 m .73757 .51002 L .73788 .50796 L F
.422 .326 .642 r
.48368 .6627 m .48616 .66447 L .48649 .66233 L F
.423 .123 .348 r
.46467 .65664 m .46162 .65962 L .46427 .65945 L F
.476 .104 .255 r
.46614 .65851 m .46467 .65664 L .46427 .65945 L F
.46614 .65851 m .46709 .65629 L .46467 .65664 L F
.189 .722 .79 r
.51871 .63367 m .52101 .63329 L .52235 .63324 L F
.062 .627 .726 r
.52235 .63324 m .52101 .63329 L .52459 .63309 L F
.376 .107 .373 r
.34104 .60666 m .33956 .60524 L .3418 .60484 L F
.34104 .60666 m .33903 .6073 L .33956 .60524 L F
.547 .384 .611 r
.34173 .6022 m .3418 .60484 L .33956 .60524 L F
.46 .489 .802 r
.80512 .49276 m .80297 .49289 L .8019 .48949 L F
.56 .527 .775 r
.80627 .49582 m .80297 .49289 L .80512 .49276 L F
.902 .522 .077 r
.55814 .66199 m .55892 .66441 L .5601 .66554 L F
.443 .736 .99 r
.48721 .65055 m .48797 .64931 L .48586 .65024 L F
.48721 .65055 m .48941 .65037 L .48797 .64931 L F
.024 .174 .683 r
.48797 .64931 m .48721 .65055 L .48586 .65024 L F
.48797 .64931 m .48915 .6529 L .48721 .65055 L F
.325 .266 .636 r
.48915 .6529 m .48786 .65401 L .48721 .65055 L F
.804 .732 .785 r
.59077 .64558 m .58836 .64518 L .59006 .64293 L F
.699 .367 .411 r
.59077 .64558 m .5873 .6474 L .58836 .64518 L F
.59077 .64558 m .59024 .64724 L .5873 .6474 L F
.793 .726 .79 r
.5907 .64274 m .59077 .64558 L .59006 .64293 L F
.358 0 .203 r
.59315 .64522 m .59024 .64724 L .59077 .64558 L F
.308 .106 .434 r
.21591 .57317 m .21546 .57569 L .21382 .57632 L F
.363 .225 .555 r
.21549 .57812 m .21382 .57632 L .21546 .57569 L F
.21549 .57812 m .21323 .57921 L .21382 .57632 L F
.598 .285 .41 r
.49977 .66442 m .49837 .66302 L .49674 .66315 L F
.249 0 0 r
.49593 .66344 m .49674 .66315 L .49837 .66302 L F
0 0 .294 r
.46712 .70848 m .46677 .70874 L .4664 .70593 L F
.59 .463 .675 r
.4684 .70255 m .46893 .70561 L .4664 .70593 L F
.899 .689 .61 r
.46893 .70561 m .46712 .70848 L .4664 .70593 L F
0 0 0 r
.53667 .60002 m .5364 .60038 L .53642 .60036 L F
.041 0 0 r
.53713 .59938 m .53667 .60002 L .53842 .59974 L F
.12 0 0 r
.53667 .60002 m .54102 .59914 L .53842 .59974 L F
.53667 .60002 m .5382 .60017 L .54102 .59914 L F
.5382 .60017 m .53861 .60021 L .53877 .60013 L F
.5382 .60017 m .53877 .60013 L .54102 .59914 L F
.345 0 0 r
.54399 .6015 m .54121 .59999 L .54181 .6017 L F
.54121 .59999 m .5401 .59939 L .54058 .60003 L F
.54121 .59999 m .54058 .60003 L .54181 .6017 L F
.115 .31 .782 r
.53784 .5992 m .53861 .60021 L .53667 .60002 L F
0 0 0 r
.53667 .60002 m .53642 .60036 L .53784 .5992 L F
.041 0 0 r
.53602 .59906 m .53667 .60002 L .53713 .59938 L F
.53602 .59906 m .53475 .60111 L .53667 .60002 L F
.203 .724 .707 r
.37253 .59539 m .37163 .59564 L .37198 .59559 L F
0 0 0 r
.37198 .59559 m .37035 .59598 L .36831 .59638 L F
.203 .724 .707 r
.37163 .59564 m .37035 .59598 L .37198 .59559 L F
0 0 0 r
.37217 .59557 m .37198 .59559 L .36978 .59584 L F
.37345 .59543 m .37198 .59559 L .37217 .59557 L F
.3 .795 .812 r
.37417 .59498 m .37345 .59543 L .37574 .59502 L F
.37417 .59498 m .37198 .59559 L .37345 .59543 L F
.605 .82 .982 r
.78166 .49232 m .78332 .49023 L .78063 .49092 L F
.78166 .49232 m .78428 .49152 L .78332 .49023 L F
.419 0 0 r
.3543 .58119 m .35762 .58278 L .35543 .58274 L F
.706 .226 .106 r
.46543 .71003 m .4691 .71073 L .46677 .70874 L F
0 0 0 r
.46543 .71003 m .46677 .70874 L .46712 .70848 L F
.952 .768 .618 r
.61458 .62187 m .61517 .61965 L .61373 .61851 L F
.728 .838 .392 r
.61603 .61381 m .61373 .61851 L .61517 .61965 L F
.69 .365 .422 r
.48737 .67026 m .48964 .67101 L .49101 .66835 L F
.641 .31 .395 r
.49101 .66835 m .49332 .67037 L .49323 .66789 L F
.459 .34 .63 r
.49332 .67037 m .49149 .67143 L .49101 .66835 L F
.641 .31 .395 r
.49101 .66835 m .48964 .67101 L .49332 .67037 L F
.459 .34 .63 r
.49332 .67037 m .49101 .66835 L .49323 .66789 L F
.486 .168 .352 r
.31194 .59036 m .31422 .59004 L .31478 .58827 L F
.443 .658 .952 r
.73162 .51173 m .73246 .51325 L .73391 .51169 L F
.54 .815 .997 r
.73246 .51325 m .73489 .51281 L .73391 .51169 L F
.551 .333 .536 r
.73246 .51325 m .73503 .51504 L .73489 .51281 L F
.484 .505 .803 r
.45403 .69542 m .45531 .69912 L .45221 .69782 L F
.57 .317 .493 r
.58739 .57856 m .59017 .57611 L .58778 .57671 L F
.609 .301 .423 r
.5013 .68429 m .50317 .68504 L .50275 .68304 L F
.788 .421 .361 r
.50275 .68304 m .50317 .68504 L .50636 .68549 L F
.581 .379 .572 r
.49269 .62224 m .49517 .62213 L .49492 .6197 L F
.416 .496 .834 r
.30312 .61666 m .30504 .61663 L .30443 .61486 L F
.39 .546 .89 r
.30504 .61663 m .30674 .61948 L .30716 .61772 L F
.294 .444 .841 r
.30674 .61948 m .30813 .61919 L .30716 .61772 L F
.196 .015 .395 r
.30674 .61948 m .30646 .62178 L .30813 .61919 L F
.30674 .61948 m .30646 .62178 L .30813 .61919 L F
.725 .624 .744 r
.58386 .65639 m .58149 .65989 L .58142 .657 L F
.863 .604 .545 r
.47866 .67993 m .47495 .6816 L .4745 .67918 L F
.47866 .67993 m .47832 .68259 L .47495 .6816 L F
0 0 .512 r
.53833 .66551 m .53887 .66837 L .53943 .66634 L F
.155 0 0 r
.53887 .66837 m .5394 .66908 L .53943 .66634 L F
.53887 .66837 m .53677 .67002 L .5394 .66908 L F
.778 .389 .318 r
.67733 .49232 m .67941 .49465 L .68067 .49309 L F
.966 .704 .485 r
.67941 .49465 m .68075 .49589 L .68067 .49309 L F
.741 .514 .586 r
.68067 .49309 m .68075 .49589 L .68239 .49465 L F
.774 .737 .82 r
.58582 .65575 m .58386 .65639 L .58608 .65362 L F
.61 .452 .644 r
.67105 .49072 m .67098 .49295 L .67348 .49 L F
.337 0 .063 r
.37461 .62421 m .37832 .62185 L .3762 .62245 L F
.845 .898 .874 r
.30768 .63174 m .30738 .6345 L .30939 .63307 L F
.428 .764 .996 r
.30768 .63174 m .30939 .63307 L .31056 .63251 L F
.384 .456 .811 r
.78236 .52633 m .7793 .52536 L .77941 .52307 L F
.132 0 .4 r
.4873 .62995 m .48584 .63102 L .48563 .63333 L F
.366 .614 .946 r
.20189 .54504 m .20121 .54656 L .19916 .54486 L F
.20189 .54504 m .20307 .54664 L .20121 .54656 L F
.96 .825 .666 r
.53993 .65163 m .54017 .65341 L .54116 .65153 L F
.438 .582 .9 r
.53798 .65175 m .54017 .65341 L .53995 .65178 L F
.53966 .65164 m .53995 .65178 L .53993 .65163 L F
.53798 .65175 m .53995 .65178 L .53966 .65164 L F
.13 0 .364 r
.54105 .65545 m .54116 .65153 L .54017 .65341 L F
.54106 .65539 m .54256 .65458 L .54116 .65153 L F
.54105 .65545 m .54256 .65458 L .54106 .65539 L F
.797 .686 .742 r
.54256 .65458 m .54598 .65526 L .54476 .65193 L F
.316 .043 .331 r
.54476 .65193 m .54424 .65405 L .54256 .65458 L F
.952 .685 .493 r
.54356 .65404 m .54256 .65458 L .54424 .65405 L F
.423 0 0 r
.54256 .65458 m .53895 .65274 L .54037 .65196 L F
.54256 .65458 m .54037 .65196 L .54162 .65253 L F
.952 .685 .493 r
.54115 .654 m .54256 .65458 L .54356 .65404 L F
.423 0 0 r
.54162 .65253 m .54037 .65196 L .54116 .65153 L F
.838 .413 .224 r
.54116 .65153 m .53895 .65274 L .53993 .65163 L F
.707 .274 .219 r
.3505 .64529 m .34675 .64569 L .34833 .64569 L F
.233 .669 .957 r
.55039 .62526 m .54907 .62443 L .54732 .62409 L F
0 .194 .668 r
.55039 .62526 m .54925 .62453 L .54919 .6245 L F
.278 .727 .959 r
.54987 .62482 m .54675 .62433 L .54771 .62435 L F
0 .28 .723 r
.54907 .62443 m .55184 .62602 L .55053 .62496 L F
.278 .727 .959 r
.55053 .62496 m .54999 .62487 L .54987 .62482 L F
.54999 .62487 m .54675 .62433 L .54987 .62482 L F
0 .194 .668 r
.55039 .62526 m .55184 .62602 L .54925 .62453 L F
.54919 .6245 m .54925 .62453 L .54907 .62443 L F
.55039 .62526 m .55301 .62711 L .55184 .62602 L F
0 0 0 r
.54102 .59914 m .54289 .59803 L .54409 .59649 L F
.54409 .59649 m .54486 .59701 L .54642 .59569 L F
.54409 .59649 m .54289 .59803 L .54486 .59701 L F
.47 .322 .597 r
.30185 .59901 m .30368 .59593 L .30168 .59653 L F
.707 .548 .67 r
.58386 .65639 m .58102 .65432 L .58105 .65361 L F
.58386 .65639 m .58142 .657 L .58102 .65432 L F
0 0 0 r
.5784 .67589 m .57801 .67697 L .57845 .67569 L F
.557 .646 .893 r
.5784 .67589 m .58011 .6775 L .57801 .67697 L F
.862 .421 .021 r
.55139 .64818 m .55237 .65002 L .55351 .65074 L F
.836 .366 .041 r
.55367 .65262 m .55351 .65074 L .55237 .65002 L F
.55367 .65262 m .55496 .65327 L .55351 .65074 L F
.455 .647 .941 r
.7936 .48379 m .7938 .48636 L .79116 .48419 L F
.7936 .48379 m .79509 .48604 L .7938 .48636 L F
.635 .646 .844 r
.78459 .52093 m .78586 .52303 L .78793 .52182 L F
.667 .677 .85 r
.53264 .70888 m .53706 .71041 L .53527 .7081 L F
.372 .406 .766 r
.53706 .71041 m .53722 .70807 L .53527 .7081 L F
.507 .319 .56 r
.53857 .70852 m .53861 .71113 L .53706 .71041 L F
.372 .406 .766 r
.53706 .71041 m .53861 .71113 L .53722 .70807 L F
.682 .536 .681 r
.49038 .62519 m .49269 .62224 L .49056 .62285 L F
.517 .193 .357 r
.56037 .5902 m .56281 .59 L .5632 .58833 L F
.433 .12 .333 r
.56281 .59 m .56545 .5878 L .5632 .58833 L F
.385 .174 .466 r
.33903 .6073 m .33678 .61042 L .33709 .608 L F
.573 .096 .084 r
.49829 .69175 m .49788 .69242 L .49605 .69138 L F
.49604 .69134 m .49605 .69138 L .49597 .69133 L F
.49829 .69175 m .49605 .69138 L .49604 .69134 L F
.464 .278 .543 r
.49656 .69259 m .49514 .69583 L .49546 .69358 L F
.49739 .69185 m .49674 .69301 L .49656 .69259 L F
.49674 .69301 m .49514 .69583 L .49656 .69259 L F
.245 .34 .763 r
.49597 .69133 m .49788 .69242 L .4977 .69113 L F
.569 .462 .693 r
.49593 .66344 m .49837 .66302 L .4969 .65935 L F
.116 .312 .784 r
.45648 .69897 m .45684 .70207 L .45531 .69912 L F
.45648 .69897 m .45814 .7023 L .45684 .70207 L F
.972 .885 .686 r
.48657 .67165 m .48598 .67406 L .4853 .67284 L F
.604 .656 .874 r
.48626 .67666 m .4853 .67284 L .48598 .67406 L F
.737 .817 .914 r
.52243 .64332 m .52499 .64552 L .52662 .6441 L F
.407 0 .128 r
.76629 .49024 m .76561 .49198 L .76304 .49234 L F
.421 0 0 r
.76629 .49024 m .76814 .49145 L .76561 .49198 L F
.76629 .49024 m .76878 .49035 L .76814 .49145 L F
.374 .681 .978 r
.39871 .58459 m .39796 .58585 L .39655 .58486 L F
.39871 .58459 m .4008 .58624 L .39796 .58585 L F
.344 .488 .86 r
.57523 .66824 m .57497 .66511 L .57373 .66463 L F
.57523 .66824 m .57629 .6678 L .57497 .66511 L F
.234 .229 .649 r
.57523 .66824 m .57708 .67012 L .57629 .6678 L F
.742 .486 .543 r
.47839 .7112 m .48196 .71389 L .48185 .71148 L F
.751 .712 .816 r
.68075 .49589 m .68437 .49651 L .68239 .49465 L F
.453 .285 .562 r
.47475 .64827 m .4768 .64763 L .47676 .64517 L F
.317 0 .249 r
.47475 .64827 m .47394 .65019 L .4768 .64763 L F
.445 .464 .785 r
.3375 .6129 m .33469 .61096 L .33678 .61042 L F
.872 .71 .678 r
.61165 .60725 m .61486 .61031 L .61432 .60827 L F
.054 0 0 r
.60134 .66974 m .601 .67055 L .59914 .67078 L F
0 0 0 r
.601 .67055 m .59785 .67248 L .59914 .67078 L F
.097 0 0 r
.60225 .66895 m .60134 .66974 L .59914 .67078 L F
.42 .266 .564 r
.30368 .59593 m .30532 .59285 L .30407 .59366 L F
.252 0 0 r
.33049 .58387 m .33278 .58364 L .33451 .58248 L F
.385 0 .028 r
.33278 .58364 m .33657 .58185 L .33451 .58248 L F
.274 0 0 r
.77933 .51272 m .78278 .5136 L .78322 .51344 L F
.546 0 0 r
.78278 .5136 m .78587 .51533 L .78322 .51344 L F
.535 .447 .702 r
.79815 .51381 m .80148 .51343 L .80056 .51077 L F
.455 0 0 r
.53486 .63421 m .53623 .63475 L .53734 .63493 L F
.093 .612 .883 r
.53623 .63475 m .53999 .63571 L .53734 .63493 L F
.475 .823 .542 r
.60225 .66895 m .60375 .66762 L .60134 .66974 L F
.113 .476 .896 r
.56451 .62535 m .56803 .62503 L .56668 .62559 L F
.673 .627 .795 r
.33193 .63949 m .33587 .64177 L .33411 .64033 L F
.492 0 0 r
.33796 .64168 m .33411 .64033 L .33587 .64177 L F
.502 .673 .941 r
.33587 .64177 m .33793 .64232 L .33796 .64168 L F
.61 .664 .878 r
.67565 .49991 m .67714 .49738 L .67486 .49789 L F
.67565 .49991 m .67818 .49949 L .67714 .49738 L F
.369 .08 .337 r
.41119 .61884 m .41058 .62176 L .40858 .62135 L F
.455 .143 .346 r
.41361 .61856 m .41058 .62176 L .41119 .61884 L F
.704 .97 .743 r
.51267 .68325 m .51082 .68443 L .51342 .68202 L F
.521 .36 .604 r
.50636 .68549 m .50662 .6883 L .50436 .68872 L F
.506 .786 .995 r
.50436 .68872 m .50662 .6883 L .5029 .68753 L F
.369 .739 .989 r
.58243 .67556 m .58784 .675 L .58353 .67434 L F
0 0 0 r
.55337 .59425 m .55275 .594 L .55164 .59567 L F
.55337 .59425 m .55451 .59272 L .55275 .594 L F
.636 .88 .986 r
.75945 .52243 m .76456 .52275 L .76362 .52185 L F
.613 .865 .99 r
.76362 .52185 m .76456 .52275 L .76679 .52195 L F
0 0 0 r
.37313 .5845 m .37535 .58429 L .37678 .58402 L F
.129 0 0 r
.37678 .58402 m .37535 .58429 L .37904 .58405 L F
.546 .352 .57 r
.49038 .62519 m .4928 .62487 L .49269 .62224 L F
.447 .277 .556 r
.49269 .62224 m .49482 .62403 L .49517 .62213 L F
.49269 .62224 m .4928 .62487 L .49482 .62403 L F
.441 .268 .549 r
.53857 .70852 m .53861 .71113 L .5402 .70943 L F
.5402 .70943 m .53861 .71113 L .53857 .70852 L F
.776 .304 0 r
.55482 .62818 m .55495 .62942 L .55301 .62711 L F
.55482 .62818 m .55604 .63035 L .55495 .62942 L F
.524 .302 .519 r
.48263 .65664 m .48267 .65941 L .47991 .65968 L F
.617 .374 .527 r
.48481 .65891 m .48263 .65664 L .48507 .65664 L F
.48481 .65891 m .48267 .65941 L .48263 .65664 L F
.584 .434 .644 r
.34396 .60173 m .3418 .60484 L .34173 .6022 L F
.705 .336 .346 r
.54886 .60542 m .55072 .60693 L .55387 .60692 L F
.861 .76 .75 r
.54955 .6034 m .55072 .60693 L .54886 .60542 L F
.527 .294 .505 r
.59506 .64224 m .59515 .64505 L .59315 .64522 L F
.734 .502 .577 r
.59888 .64237 m .59515 .64505 L .59506 .64224 L F
.141 .442 .877 r
.21298 .55089 m .21581 .5526 L .2145 .5524 L F
.162 0 0 r
.46423 .69988 m .46627 .70006 L .46773 .69997 L F
.486 0 0 r
.46902 .70109 m .46773 .69997 L .46627 .70006 L F
.46902 .70109 m .47073 .70154 L .46773 .69997 L F
.475 .663 .944 r
.76926 .52168 m .77224 .52439 L .77318 .52348 L F
.602 .317 .456 r
.57362 .58478 m .57673 .58395 L .57683 .58206 L F
.646 .354 .461 r
.57673 .58395 m .5793 .58418 L .57683 .58206 L F
.608 .366 .525 r
.57683 .58206 m .5793 .58418 L .57933 .58187 L F
.623 .198 .214 r
.52924 .65818 m .52598 .65845 L .52728 .6567 L F
.046 .233 .732 r
.53931 .67842 m .53863 .67988 L .53715 .67629 L F
.042 0 .306 r
.5398 .681 m .53863 .67988 L .53931 .67842 L F
.5398 .681 m .53817 .68218 L .53863 .67988 L F
.646 .366 .481 r
.75947 .48626 m .76171 .48688 L .76183 .48464 L F
.587 .317 .475 r
.76183 .48464 m .76559 .4849 L .76488 .48406 L F
.76183 .48464 m .76171 .48688 L .76559 .4849 L F
.592 .701 .918 r
.76939 .50855 m .76766 .51096 L .76676 .50919 L F
.76939 .50855 m .77017 .51028 L .76766 .51096 L F
.728 .838 .392 r
.61603 .61381 m .61464 .61658 L .61373 .61851 L F
.456 .193 .426 r
.58159 .59048 m .58356 .59181 L .58051 .59235 L F
.58159 .59048 m .58391 .58997 L .58356 .59181 L F
.337 .154 .478 r
.43882 .69721 m .43736 .69675 L .43717 .69952 L F
.198 .297 .741 r
.43644 .6937 m .43736 .69675 L .43869 .69561 L F
.21 .317 .756 r
.43869 .69561 m .43736 .69675 L .43882 .69721 L F
.337 .154 .478 r
.43882 .69721 m .43736 .69675 L .43717 .69952 L F
0 .055 .607 r
.5127 .64544 m .51328 .64484 L .51174 .64215 L F
.004 .103 .616 r
.5127 .64544 m .51406 .64604 L .51328 .64484 L F
.5127 .64544 m .51336 .6478 L .51406 .64604 L F
0 .295 .666 r
.77322 .48152 m .77573 .48268 L .77662 .48315 L F
.485 .843 .993 r
.77573 .48268 m .77936 .48283 L .77662 .48315 L F
.555 .321 .516 r
.50013 .6591 m .50256 .6565 L .50028 .65683 L F
.547 .808 .994 r
.29824 .6276 m .29948 .62847 L .30042 .62705 L F
.29824 .6276 m .29948 .62847 L .30042 .62705 L F
.661 .45 .588 r
.29948 .62847 m .29963 .63047 L .30201 .63008 L F
.96 .851 .688 r
.59661 .59973 m .59469 .60116 L .59517 .59871 L F
.59661 .59973 m .59591 .60207 L .59469 .60116 L F
.545 .311 .512 r
.76488 .48406 m .76737 .48358 L .76725 .48098 L F
.596 .35 .514 r
.76725 .48098 m .76737 .48358 L .76995 .48323 L F
.972 .885 .686 r
.48657 .67165 m .4853 .67284 L .48737 .67026 L F
.797 .681 .736 r
.73938 .50646 m .73757 .51002 L .74069 .51024 L F
.425 .056 .232 r
.73647 .51227 m .74 .51239 L .74069 .51024 L F
.594 .701 .918 r
.74069 .51024 m .74249 .50852 L .73938 .50646 L F
.74069 .51024 m .74313 .50968 L .74249 .50852 L F
.601 .221 .294 r
.74069 .51024 m .74344 .51188 L .74313 .50968 L F
.74069 .51024 m .74 .51239 L .74344 .51188 L F
.72 .721 .85 r
.49676 .67763 m .49933 .67977 L .49591 .67941 L F
.396 0 .16 r
.49933 .67977 m .49854 .68182 L .49573 .68226 L F
.352 .613 .948 r
.50031 .67849 m .49933 .67977 L .49676 .67763 L F
0 0 0 r
.50031 .67849 m .49854 .68182 L .49933 .67977 L F
.613 .666 .877 r
.22079 .55665 m .21795 .5556 L .21985 .55517 L F
.38 0 .066 r
.32224 .58654 m .32448 .58631 L .32598 .58455 L F
.331 0 0 r
.32448 .58631 m .32831 .58435 L .32598 .58455 L F
.227 .048 .418 r
.21721 .57266 m .21546 .57569 L .21591 .57317 L F
.363 .282 .629 r
.436 .69124 m .43802 .69321 L .43802 .69074 L F
.436 .69124 m .43644 .6937 L .43802 .69321 L F
.448 .087 .26 r
.49176 .62641 m .49038 .62519 L .49005 .62732 L F
.49176 .62641 m .4928 .62487 L .49038 .62519 L F
.519 .658 .923 r
.44572 .70743 m .44617 .70515 L .44424 .70581 L F
.44572 .70743 m .44838 .70751 L .44617 .70515 L F
.158 .693 .693 r
.31348 .63812 m .314 .63801 L .31608 .63754 L F
.78 .897 .49 r
.314 .63801 m .31412 .63987 L .31608 .63754 L F
.314 .63801 m .31244 .64133 L .31412 .63987 L F
.872 .71 .678 r
.61165 .60725 m .61139 .6096 L .61486 .61031 L F
.874 .692 .652 r
.61139 .6096 m .61266 .61287 L .61486 .61031 L F
.545 .284 .47 r
.42755 .61068 m .42668 .61348 L .42441 .61368 L F
.593 .331 .489 r
.42975 .61261 m .42755 .61068 L .42995 .61042 L F
.42975 .61261 m .42668 .61348 L .42755 .61068 L F
.249 0 0 r
.36352 .58392 m .36716 .58433 L .36514 .58397 L F
.237 0 0 r
.33657 .58185 m .33872 .5821 L .34028 .58197 L F
.446 0 0 r
.33872 .5821 m .34209 .58216 L .34028 .58197 L F
.529 .169 .301 r
.39684 .6127 m .40057 .61024 L .39728 .61087 L F
.39684 .6127 m .39929 .61261 L .40057 .61024 L F
.236 0 0 r
.39929 .61261 m .40306 .6107 L .40057 .61024 L F
.225 .104 .497 r
.43715 .68259 m .43865 .68209 L .43864 .67939 L F
.269 .226 .624 r
.43715 .68259 m .43897 .68463 L .43865 .68209 L F
.346 .241 .589 r
.43738 .68502 m .43897 .68463 L .43715 .68259 L F
.452 .128 .324 r
.42198 .61374 m .42151 .6156 L .41915 .61602 L F
.519 .188 .346 r
.42393 .61526 m .42151 .6156 L .42198 .61374 L F
.539 .178 .303 r
.42441 .61368 m .42393 .61526 L .42198 .61374 L F
.981 .903 .657 r
.54296 .67459 m .54173 .67447 L .54214 .67239 L F
.707 .548 .67 r
.58386 .65639 m .58105 .65361 L .5821 .65397 L F
.81 .802 .844 r
.58608 .65362 m .58386 .65639 L .5821 .65397 L F
.341 0 .174 r
.39534 .62848 m .39445 .6299 L .39245 .63029 L F
.283 0 .133 r
.39745 .62784 m .39445 .6299 L .39534 .62848 L F
.263 0 0 r
.77213 .49036 m .77381 .49101 L .7715 .49053 L F
.77213 .49036 m .77488 .49083 L .77381 .49101 L F
.585 .492 .715 r
.52635 .66767 m .52873 .66509 L .52608 .66561 L F
.52635 .66767 m .52861 .66768 L .52873 .66509 L F
.558 .564 .815 r
.52635 .66767 m .53168 .66932 L .52861 .66768 L F
0 .32 .754 r
.79492 .52155 m .79464 .52161 L .7936 .52062 L F
.156 .198 .655 r
.79649 .52372 m .79464 .52161 L .79492 .52155 L F
.586 .556 .788 r
.40877 .60505 m .41056 .60487 L .40957 .602 L F
.62 .451 .631 r
.40838 .60715 m .41056 .60487 L .40877 .60505 L F
.154 0 0 r
.38079 .63498 m .38438 .63303 L .38279 .63478 L F
.253 0 0 r
.38438 .63303 m .38501 .63435 L .38279 .63478 L F
.38438 .63303 m .38654 .6326 L .38501 .63435 L F
.28 .115 .471 r
.20948 .58762 m .20879 .59025 L .20927 .58778 L F
.113 .476 .896 r
.56451 .62535 m .5664 .62697 L .56803 .62503 L F
.56451 .62535 m .5669 .62623 L .5664 .62697 L F
0 .245 .759 r
.5669 .62623 m .56791 .62823 L .5664 .62697 L F
.118 .67 .765 r
.36716 .58433 m .36946 .58411 L .37097 .58406 L F
.321 0 0 r
.37097 .58406 m .36946 .58411 L .37313 .5845 L F
.798 .322 .093 r
.54081 .65808 m .54095 .65894 L .53962 .65714 L F
.54262 .65953 m .54095 .65894 L .54081 .65808 L F
.936 .956 .76 r
.5398 .66234 m .54095 .65894 L .54262 .65953 L F
.204 .145 .565 r
.54099 .66077 m .54119 .66034 L .54095 .65894 L F
.54119 .66034 m .5426 .65728 L .54095 .65894 L F
.211 .225 .656 r
.53962 .65714 m .54095 .65894 L .54105 .65545 L F
.426 0 0 r
.47178 .71669 m .47034 .71694 L .46798 .71645 L F
.805 .383 .243 r
.47178 .71669 m .47046 .71853 L .47034 .71694 L F
.47178 .71669 m .47381 .7194 L .47046 .71853 L F
.544 .279 .465 r
.44651 .67127 m .44855 .67305 L .44903 .67108 L F
.44651 .67127 m .44617 .6734 L .44855 .67305 L F
.597 .707 .921 r
.41327 .59035 m .41106 .591 L .40995 .58929 L F
.12 0 0 r
.35037 .60012 m .34997 .59866 L .35203 .59857 L F
.35037 .60012 m .34851 .60086 L .34997 .59866 L F
.753 .646 .743 r
.56167 .59877 m .56366 .59973 L .56486 .59686 L F
.775 .625 .694 r
.56167 .59877 m .56301 .60204 L .56366 .59973 L F
0 0 0 r
.35705 .64307 m .35653 .64248 L .35819 .64151 L F
.35705 .64307 m .35506 .64419 L .35653 .64248 L F
.734 .502 .577 r
.59888 .64237 m .59891 .64481 L .59515 .64505 L F
.807 .787 .834 r
.59267 .61848 m .5956 .61886 L .59386 .61938 L F
0 .29 .777 r
.59562 .62116 m .59267 .61848 L .59386 .61938 L F
.848 .995 .753 r
.59304 .62324 m .59442 .62151 L .59562 .62116 L F
.759 .525 .579 r
.59386 .61938 m .59619 .621 L .59562 .62116 L F
0 .29 .777 r
.59562 .62116 m .59538 .6203 L .59267 .61848 L F
.848 .995 .753 r
.59442 .62151 m .59538 .6203 L .59562 .62116 L F
.759 .525 .579 r
.59619 .621 m .59762 .62199 L .59562 .62116 L F
.499 .452 .736 r
.77834 .50897 m .77713 .51323 L .7774 .51138 L F
.77834 .50897 m .77933 .51272 L .77713 .51323 L F
.709 .538 .656 r
.50222 .64329 m .49993 .64424 L .49771 .63758 L F
.5 .322 .571 r
.29961 .60162 m .30175 .60113 L .30185 .59901 L F
.495 .379 .65 r
.29998 .6053 m .30175 .60113 L .29961 .60162 L F
0 0 0 r
.78015 .5299 m .78331 .52732 L .78249 .52918 L F
.714 .297 .254 r
.78331 .52732 m .78552 .52911 L .78249 .52918 L F
.246 .372 .794 r
.78501 .52622 m .78331 .52732 L .78236 .52633 L F
.418 0 0 r
.32416 .63682 m .32142 .63524 L .32223 .63655 L F
.562 .655 .898 r
.32223 .63655 m .32579 .63792 L .32416 .63682 L F
.411 .124 .363 r
.45118 .67039 m .45397 .66723 L .45172 .66787 L F
.78 .504 .518 r
.58983 .58778 m .59017 .59008 L .58654 .5895 L F
0 0 .033 r
.47242 .65133 m .47152 .65306 L .47394 .65019 L F
.452 .178 .406 r
.51707 .68725 m .5155 .68493 L .51769 .68439 L F
.51707 .68725 m .51486 .68782 L .5155 .68493 L F
0 .032 .563 r
.56696 .64809 m .56795 .64683 L .56682 .64489 L F
.08 .245 .733 r
.56696 .64809 m .56919 .65022 L .56795 .64683 L F
.632 .649 .848 r
.43134 .70135 m .4328 .70347 L .43487 .70246 L F
.705 .802 .925 r
.35261 .62511 m .34882 .6249 L .35109 .6239 L F
.694 .821 .944 r
.35544 .62371 m .35261 .62511 L .35109 .6239 L F
.503 .278 .505 r
.49358 .63669 m .49506 .63866 L .49283 .63906 L F
.436 .247 .525 r
.73489 .51281 m .73686 .51391 L .73647 .51227 L F
.426 .06 .237 r
.73647 .51227 m .73686 .51391 L .74 .51239 L F
.563 .784 .982 r
.30304 .63384 m .30738 .6345 L .30575 .63376 L F
.83 .885 .883 r
.30768 .63174 m .30575 .63376 L .30738 .6345 L F
0 .034 .541 r
.559 .6333 m .55604 .63035 L .55826 .63297 L F
.453 .094 .265 r
.40858 .62135 m .40527 .62412 L .40582 .62282 L F
.40858 .62135 m .40754 .6238 L .40527 .62412 L F
.353 0 .219 r
.4097 .62322 m .40858 .62135 L .41058 .62176 L F
.4097 .62322 m .40754 .6238 L .40858 .62135 L F
.473 .611 .907 r
.21772 .55249 m .21795 .5556 L .21581 .5526 L F
.21772 .55249 m .21985 .55517 L .21795 .5556 L F
.729 .495 .574 r
.76977 .48048 m .77322 .48264 L .77322 .48152 L F
.557 .193 .307 r
.77322 .48264 m .77573 .48268 L .77322 .48152 L F
.464 .449 .757 r
.30146 .6109 m .30243 .60716 L .30066 .60752 L F
.30146 .6109 m .3033 .61057 L .30243 .60716 L F
.463 .443 .751 r
.30146 .6109 m .30414 .61298 L .3033 .61057 L F
.415 .224 .511 r
.55472 .605 m .55705 .60461 L .55717 .60169 L F
.467 .45 .755 r
.55707 .6066 m .55472 .605 L .55476 .6075 L F
.55707 .6066 m .55705 .60461 L .55472 .605 L F
0 0 0 r
.48446 .71802 m .48255 .71888 L .48356 .7178 L F
.187 0 .219 r
.51336 .6478 m .51075 .65098 L .5126 .64949 L F
.29 0 .277 r
.51336 .6478 m .5161 .64707 L .51406 .64604 L F
.51336 .6478 m .5126 .64949 L .5161 .64707 L F
.761 .264 .037 r
.46309 .7137 m .46428 .71466 L .4609 .71306 L F
.758 .589 .667 r
.49378 .71381 m .49409 .71494 L .49728 .71417 L F
.75 .513 .573 r
.78959 .50032 m .79153 .49817 L .7892 .49929 L F
0 0 .535 r
.33793 .64232 m .3383 .64126 L .33796 .64168 L F
.62 .478 .666 r
.33793 .64232 m .34065 .64411 L .3383 .64126 L F
.33793 .64232 m .33878 .6453 L .34065 .64411 L F
.836 .593 .572 r
.48857 .67854 m .49074 .67648 L .48858 .67617 L F
.48857 .67854 m .49201 .67994 L .49074 .67648 L F
.794 .562 .586 r
.5029 .68753 m .50636 .68549 L .50317 .68504 L F
.5029 .68753 m .50662 .6883 L .50636 .68549 L F
.537 .372 .605 r
.50662 .6883 m .50816 .68799 L .50636 .68549 L F
.50662 .6883 m .50816 .68799 L .50636 .68549 L F
0 0 0 r
.5398 .66234 m .53833 .66551 L .5391 .66402 L F
.5398 .66234 m .5391 .66402 L .53701 .66218 L F
.213 0 0 r
.53678 .66209 m .53731 .66219 L .5398 .66234 L F
0 0 0 r
.5398 .66234 m .53663 .66184 L .53678 .66209 L F
.5398 .66234 m .53731 .66219 L .53663 .66184 L F
.463 .41 .713 r
.53663 .66184 m .53835 .6624 L .53731 .66219 L F
.53663 .66184 m .53731 .66219 L .53678 .66209 L F
0 0 0 r
.53731 .66219 m .53701 .66218 L .53663 .66184 L F
.213 0 0 r
.53731 .66219 m .53835 .6624 L .5398 .66234 L F
.936 .956 .76 r
.5398 .66234 m .53835 .6624 L .54095 .65894 L F
.628 .229 .269 r
.32754 .63669 m .32416 .63682 L .32579 .63792 L F
.215 0 .258 r
.48116 .66097 m .47991 .65968 L .48267 .65941 L F
.48116 .66097 m .47934 .66206 L .47991 .65968 L F
.557 .587 .84 r
.77318 .52348 m .77418 .52684 L .77704 .52592 L F
.989 .751 .482 r
.5975 .62707 m .59868 .62796 L .59858 .63037 L F
.782 .758 .831 r
.48657 .69348 m .48793 .69583 L .49008 .69369 L F
.348 .272 .628 r
.20879 .59025 m .2096 .59259 L .20795 .59348 L F
.306 .196 .562 r
.2096 .59259 m .20802 .59604 L .20795 .59348 L F
.487 .275 .518 r
.45409 .66524 m .45622 .66663 L .45632 .6647 L F
.45409 .66524 m .45397 .66723 L .45622 .66663 L F
.686 .639 .797 r
.53227 .67963 m .53328 .6759 L .53131 .67649 L F
.53227 .67963 m .53435 .67965 L .53328 .6759 L F
.65 .517 .688 r
.4346 .60721 m .43237 .6102 L .43266 .60788 L F
.16 0 .087 r
.46898 .65532 m .46974 .654 L .46709 .65629 L F
.099 0 .053 r
.47152 .65306 m .46974 .654 L .46898 .65532 L F
.445 .722 .984 r
.78428 .48243 m .78284 .48376 L .78188 .48255 L F
.78428 .48243 m .78522 .48364 L .78284 .48376 L F
.591 .427 .627 r
.67348 .49 m .67098 .49295 L .67348 .49239 L F
.616 .512 .713 r
.67153 .49542 m .67348 .49239 L .67098 .49295 L F
.738 .385 0 r
.59673 .60802 m .59765 .61044 L .59614 .60685 L F
.497 0 0 r
.54268 .62259 m .54148 .62176 L .53893 .61965 L F
0 .312 .749 r
.54148 .62176 m .543 .62222 L .5404 .62101 L F
.51 0 0 r
.53893 .61965 m .54148 .62176 L .54028 .62095 L F
0 .312 .749 r
.54148 .62176 m .5404 .62101 L .54028 .62095 L F
.497 0 0 r
.54275 .62265 m .54148 .62176 L .54268 .62259 L F
.821 .361 0 r
.54275 .62265 m .54322 .62372 L .54148 .62176 L F
.688 .74 .891 r
.55476 .6075 m .55865 .608 L .55707 .6066 L F
.837 .789 .805 r
.55865 .608 m .5591 .60388 L .55707 .6066 L F
.55865 .608 m .56078 .60518 L .5591 .60388 L F
.43 .043 .202 r
.40582 .62282 m .40527 .62412 L .40301 .62446 L F
.42 .806 .989 r
.26897 .70842 m .26733 .70772 L .26522 .70811 L F
.26897 .70842 m .26733 .70772 L .26522 .70811 L F
.998 .851 .527 r
.59591 .60207 m .5946 .60362 L .59469 .60116 L F
.59591 .60207 m .59536 .60481 L .5946 .60362 L F
.75 .861 .93 r
.3902 .59449 m .39113 .59584 L .39347 .59455 L F
.759 .661 .754 r
.49837 .66302 m .50013 .6591 L .4969 .65935 L F
.344 0 .009 r
.38044 .62124 m .38277 .62091 L .38424 .61926 L F
.457 .023 .126 r
.38277 .62091 m .3866 .61897 L .38424 .61926 L F
.871 .885 .842 r
.78732 .51858 m .7887 .5189 L .79026 .51691 L F
.595 .414 .606 r
.78793 .52182 m .7887 .5189 L .78732 .51858 L F
.78793 .52182 m .7902 .5207 L .7887 .5189 L F
.601 .775 .963 r
.78774 .50686 m .78914 .50483 L .78704 .50525 L F
.78774 .50686 m .79018 .50623 L .78914 .50483 L F
.308 0 0 r
.56357 .61291 m .56184 .61321 L .56321 .61645 L F
.505 .643 .918 r
.44166 .70614 m .44424 .70581 L .44297 .70413 L F
.406 .107 .341 r
.45248 .68597 m .45274 .68796 L .44996 .68817 L F
.498 .168 .338 r
.45447 .68728 m .45274 .68796 L .45248 .68597 L F
.743 .945 .948 r
.75559 .52477 m .75829 .52419 L .75765 .52343 L F
.733 .952 .948 r
.75765 .52343 m .75829 .52419 L .75945 .52243 L F
.236 .694 .95 r
.37904 .58405 m .38117 .58414 L .38265 .58484 L F
.336 .743 .981 r
.38336 .58397 m .38265 .58484 L .38117 .58414 L F
.38336 .58397 m .38484 .58476 L .38265 .58484 L F
.487 .2 .404 r
.51153 .65525 m .51102 .65852 L .50865 .65889 L F
.411 0 .144 r
.51432 .65428 m .51377 .65525 L .51153 .65525 L F
.497 .217 .419 r
.51377 .65525 m .51102 .65852 L .51153 .65525 L F
.38 .387 .742 r
.21869 .56655 m .21676 .56782 L .21615 .56451 L F
0 0 .43 r
.21795 .5688 m .21676 .56782 L .21869 .56655 L F
.21795 .5688 m .2169 .57019 L .21676 .56782 L F
.597 .728 .936 r
.73888 .49915 m .73489 .49807 L .73702 .49593 L F
.73888 .49915 m .73489 .49807 L .73764 .49842 L F
.366 .523 .88 r
.73939 .49638 m .73888 .49915 L .73702 .49593 L F
.796 .93 .922 r
.73764 .49842 m .73888 .49915 L .73939 .49638 L F
0 0 .345 r
.61273 .64421 m .61307 .64663 L .61246 .64774 L F
0 0 .125 r
.61307 .64663 m .61206 .65042 L .61246 .64774 L F
.397 .242 .551 r
.47676 .64517 m .47864 .64698 L .47868 .64454 L F
.47676 .64517 m .4768 .64763 L .47864 .64698 L F
0 0 .515 r
.61195 .65287 m .61265 .65565 L .61177 .65676 L F
.706 .681 .138 r
.6116 .6575 m .61177 .65676 L .61265 .65565 L F
.6116 .6575 m .61129 .65934 L .61177 .65676 L F
.423 .62 .933 r
.40661 .59853 m .40738 .59671 L .4046 .59633 L F
.40661 .59853 m .40859 .59836 L .40738 .59671 L F
.753 .646 .743 r
.56167 .59877 m .56486 .59686 L .56402 .5959 L F
.402 .786 .991 r
.56486 .59686 m .56633 .59622 L .56402 .5959 L F
.56486 .59686 m .56708 .59679 L .56633 .59622 L F
.581 .36 .546 r
.51891 .65319 m .51696 .651 L .51891 .65029 L F
.51891 .65319 m .51663 .65351 L .51696 .651 L F
.616 .512 .713 r
.67153 .49542 m .67423 .49603 L .67348 .49239 L F
.508 .321 .561 r
.56301 .60204 m .56302 .60445 L .56078 .60518 L F
.612 .768 .955 r
.56078 .60518 m .56302 .60445 L .5591 .60388 L F
.534 .239 .413 r
.51663 .65351 m .51377 .65525 L .51432 .65428 L F
.783 .481 .476 r
.53435 .67965 m .5348 .68222 L .53104 .6815 L F
.53435 .67965 m .53104 .6815 L .53348 .68138 L F
.566 .42 .643 r
.53435 .67965 m .53715 .67629 L .53328 .6759 L F
.53435 .67965 m .53903 .68022 L .53715 .67629 L F
.325 .792 .933 r
.53504 .68222 m .53691 .68186 L .5348 .68222 L F
.53817 .68218 m .53691 .68186 L .53504 .68222 L F
.608 .383 .549 r
.5398 .681 m .53691 .68186 L .53817 .68218 L F
.5398 .681 m .53935 .68372 L .53691 .68186 L F
.476 .408 .7 r
.53691 .68186 m .53935 .68372 L .5386 .68153 L F
.53691 .68186 m .5386 .68153 L .53824 .68049 L F
.134 0 0 r
.53435 .67965 m .53476 .67993 L .53903 .68022 L F
.53476 .67993 m .53744 .68036 L .53903 .68022 L F
.53476 .67993 m .53565 .68052 L .53744 .68036 L F
.851 .892 .867 r
.53903 .68022 m .53565 .68052 L .5379 .6795 L F
.476 .408 .7 r
.53754 .68038 m .53824 .68049 L .5379 .6795 L F
.53691 .68186 m .53824 .68049 L .53754 .68038 L F
.134 0 0 r
.53435 .67965 m .53348 .68138 L .53565 .68052 L F
.731 .345 .319 r
.48196 .71389 m .48471 .71634 L .48584 .71447 L F
.584 .177 .235 r
.48584 .71447 m .48471 .71634 L .48799 .716 L F
.464 .251 .504 r
.48584 .71447 m .48799 .716 L .48792 .71373 L F
.093 0 0 r
.38382 .59319 m .3799 .5943 L .38174 .59315 L F
.811 .579 .587 r
.4562 .68818 m .45215 .69028 L .45447 .68728 L F
.4562 .68818 m .45606 .69135 L .45215 .69028 L F
.456 .281 .553 r
.45835 .69051 m .4562 .68818 L .45819 .68764 L F
.45835 .69051 m .45606 .69135 L .4562 .68818 L F
.649 .376 .493 r
.51931 .65995 m .52307 .65889 L .51979 .65926 L F
.51931 .65995 m .52175 .65988 L .52307 .65889 L F
0 0 0 r
.52307 .65889 m .52369 .65886 L .52397 .65816 L F
.52307 .65889 m .52175 .65988 L .52369 .65886 L F
.608 .684 .896 r
.32996 .63823 m .33193 .63949 L .32998 .63858 L F
.055 .415 .863 r
.33193 .63949 m .3323 .63838 L .32998 .63858 L F
0 0 0 r
.33072 .63735 m .32998 .63858 L .3323 .63838 L F
.33072 .63735 m .33001 .63927 L .32998 .63858 L F
.33001 .63927 m .32953 .64059 L .32998 .63858 L F
.608 .684 .896 r
.32754 .63669 m .32996 .63823 L .32998 .63858 L F
.055 .415 .863 r
.33193 .63949 m .33411 .64033 L .3323 .63838 L F
.48 .287 .54 r
.53715 .67629 m .53923 .67597 L .53765 .67419 L F
.806 .475 .429 r
.74385 .50307 m .74363 .50377 L .746 .504 L F
.984 .713 .427 r
.74484 .50534 m .746 .504 L .74363 .50377 L F
.74484 .50534 m .74625 .50708 L .746 .504 L F
.851 .978 .866 r
.49105 .71596 m .48858 .71829 L .49003 .7176 L F
.79 .52 .528 r
.59762 .62199 m .59853 .62502 L .59594 .62421 L F
.875 .649 .593 r
.59562 .62116 m .59762 .62199 L .59594 .62421 L F
.569 .392 .602 r
.5432 .70518 m .54551 .70227 L .54311 .70268 L F
0 .282 .782 r
.54773 .66823 m .54925 .6683 L .54608 .6662 L F
.133 0 0 r
.54963 .67026 m .54992 .6704 L .54753 .67056 L F
.5513 .67003 m .54992 .6704 L .54963 .67026 L F
.271 0 0 r
.54992 .6704 m .55299 .67123 L .5504 .67064 L F
.789 .5 .498 r
.5504 .67064 m .55039 .67063 L .54992 .6704 L F
.55039 .67063 m .54971 .66923 L .54992 .6704 L F
.519 .688 .944 r
.54753 .67056 m .54992 .6704 L .54936 .66863 L F
.549 .66863 m .54936 .66863 L .54925 .6683 L F
.54753 .67056 m .54936 .66863 L .549 .66863 L F
.54753 .67056 m .549 .66863 L .54773 .66823 L F
.973 .671 .382 r
.54753 .67056 m .54788 .67315 L .547 .6724 L F
.54669 .67147 m .547 .6724 L .54635 .67184 L F
.54753 .67056 m .547 .6724 L .54669 .67147 L F
.545 .365 .589 r
.54992 .6704 m .54788 .67315 L .54753 .67056 L F
.874 .857 .822 r
.5469 .67123 m .54992 .6704 L .54753 .67056 L F
.752 .597 .684 r
.54782 .67116 m .54797 .67149 L .54687 .67142 L F
.874 .857 .822 r
.547 .6724 m .54788 .67315 L .5483 .67173 L F
.54767 .67177 m .5483 .67173 L .54852 .67097 L F
.547 .6724 m .5483 .67173 L .54767 .67177 L F
.54669 .67147 m .54687 .67142 L .5469 .67123 L F
.54687 .67142 m .54782 .67116 L .54712 .67122 L F
.54687 .67142 m .54712 .67122 L .5469 .67123 L F
.761 .463 .48 r
.54635 .67184 m .54267 .66957 L .54687 .67142 L F
.54635 .67184 m .54687 .67142 L .54767 .67177 L F
.752 .597 .684 r
.54797 .67149 m .54767 .67177 L .54687 .67142 L F
.874 .857 .822 r
.54635 .67184 m .547 .6724 L .54797 .67149 L F
.5481 .67114 m .54797 .67149 L .54852 .67097 L F
.579 .515 .747 r
.5481 .67114 m .54797 .67149 L .54782 .67116 L F
.874 .857 .822 r
.54635 .67184 m .54797 .67149 L .5481 .67114 L F
.579 .515 .747 r
.54817 .67113 m .54801 .67159 L .54797 .67149 L F
.54817 .67113 m .54797 .67149 L .5481 .67114 L F
.761 .463 .48 r
.54635 .67184 m .54767 .67177 L .5482 .672 L F
.752 .597 .684 r
.54797 .67149 m .5482 .672 L .54767 .67177 L F
.874 .857 .822 r
.54852 .67097 m .54788 .67315 L .54992 .6704 L F
.54635 .67184 m .5481 .67114 L .54782 .67116 L F
.54635 .67184 m .54782 .67116 L .54669 .67147 L F
.5481 .67114 m .54992 .6704 L .5469 .67123 L F
.752 .597 .684 r
.54578 .66659 m .54782 .67116 L .54664 .67131 L F
.54782 .67116 m .54687 .67142 L .54664 .67131 L F
.54524 .66711 m .54664 .67131 L .54267 .66957 L F
.54578 .66659 m .54664 .67131 L .54524 .66711 L F
.579 .515 .747 r
.54897 .66873 m .54817 .67113 L .5467 .66865 L F
.54817 .67113 m .54782 .67116 L .5467 .66865 L F
.54882 .66863 m .5467 .66865 L .54578 .66659 L F
.54897 .66873 m .5467 .66865 L .54882 .66863 L F
.54971 .66923 m .5482 .672 L .54801 .67159 L F
0 .055 .621 r
.54925 .6683 m .54992 .6704 L .54971 .66923 L F
.579 .515 .747 r
.54971 .66923 m .54801 .67159 L .54897 .66873 L F
.519 .688 .944 r
.549 .66863 m .54925 .6683 L .54911 .6683 L F
.549 .66863 m .54911 .6683 L .54773 .66823 L F
.75 .515 .575 r
.5591 .60388 m .56302 .60445 L .56301 .60204 L F
.448 .53 .848 r
.42196 .59153 m .4204 .59345 L .4189 .59106 L F
.42196 .59153 m .42222 .5931 L .4204 .59345 L F
.485 .462 .756 r
.42222 .5931 m .4211 .59572 L .4204 .59345 L F
.814 .719 .759 r
.59765 .61044 m .59864 .61349 L .59547 .61305 L F
.799 .554 .567 r
.59864 .61349 m .59523 .61557 L .59547 .61305 L F
.59864 .61349 m .59873 .61614 L .59523 .61557 L F
.59 .882 .992 r
.52908 .63319 m .52848 .63457 L .52671 .63315 L F
.52908 .63319 m .52997 .63391 L .52848 .63457 L F
.016 .591 .725 r
.38779 .59321 m .38593 .59318 L .38382 .59319 L F
.337 0 0 r
.38779 .59321 m .38847 .59358 L .38593 .59318 L F
.38779 .59321 m .3902 .59449 L .38847 .59358 L F
.614 .352 .498 r
.50146 .69093 m .49788 .69242 L .49829 .69175 L F
.672 .509 .656 r
.80627 .49582 m .80695 .49849 L .8042 .49872 L F
.376 .329 .679 r
.80668 .49496 m .80695 .49849 L .80627 .49582 L F
.80672 .49548 m .80785 .4977 L .80695 .49849 L F
.80668 .49496 m .80688 .49542 L .80672 .49548 L F
.80688 .49542 m .80785 .4977 L .80672 .49548 L F
.126 .19 .659 r
.80812 .49736 m .80785 .4977 L .80688 .49542 L F
.8069 .49532 m .80688 .49542 L .80668 .49496 L F
.80812 .49736 m .80688 .49542 L .8069 .49532 L F
.299 .266 .653 r
.80677 .49511 m .80668 .49496 L .80654 .49525 L F
.80719 .49366 m .80668 .49549 L .80512 .49276 L F
.80834 .49417 m .80654 .49525 L .80627 .49582 L F
.80834 .49417 m .80668 .49496 L .80677 .49511 L F
.80834 .49417 m .8069 .49532 L .80719 .49366 L F
.8069 .49532 m .80668 .49549 L .80719 .49366 L F
.126 .19 .659 r
.80876 .49657 m .80812 .49736 L .80668 .49496 L F
.299 .266 .653 r
.80668 .49549 m .80627 .49582 L .80621 .49566 L F
.80668 .49549 m .80621 .49566 L .80512 .49276 L F
0 0 .532 r
.43353 .60387 m .4346 .60721 L .43368 .60546 L F
.443 .095 .278 r
.58424 .58109 m .58739 .57856 L .58491 .57872 L F
.474 .668 .948 r
.40702 .58864 m .40396 .58721 L .40593 .58717 L F
.409 .619 .937 r
.40813 .58697 m .40702 .58864 L .40593 .58717 L F
.40813 .58697 m .40995 .58929 L .40702 .58864 L F
.629 .757 .939 r
.7937 .50698 m .79522 .50458 L .79277 .50539 L F
.7937 .50698 m .79617 .50635 L .79522 .50458 L F
.641 .622 .815 r
.7937 .50698 m .79723 .50843 L .79617 .50635 L F
.606 .651 .868 r
.74312 .52198 m .74519 .51953 L .74173 .51901 L F
.74312 .52198 m .74555 .52139 L .74519 .51953 L F
.573 .568 .81 r
.5293 .64212 m .53043 .64571 L .53133 .64342 L F
.331 .299 .671 r
.53043 .64571 m .53246 .64732 L .53133 .64342 L F
.251 0 0 r
.39245 .63029 m .39334 .6315 L .39108 .63217 L F
.39245 .63029 m .39445 .6299 L .39334 .6315 L F
.594 .379 .558 r
.51096 .6675 m .51313 .66486 L .51091 .66529 L F
.51096 .6675 m .51313 .66486 L .51091 .66529 L F
.018 .175 .685 r
.56545 .64254 m .56658 .64175 L .56455 .6393 L F
.139 .233 .699 r
.56545 .64254 m .56786 .64355 L .56658 .64175 L F
.56545 .64254 m .56682 .64489 L .56786 .64355 L F
.547 .756 .974 r
.53212 .70775 m .53264 .70888 L .52912 .70823 L F
.458 .377 .677 r
.53178 .7101 m .52912 .70823 L .53264 .70888 L F
.996 .831 .476 r
.53212 .70775 m .53178 .7101 L .53264 .70888 L F
.506 .339 .588 r
.72896 .48874 m .72701 .48722 L .72992 .48705 L F
.64 .691 .882 r
.72755 .48405 m .72987 .4864 L .72701 .48722 L F
.863 .882 .447 r
.72988 .48638 m .72971 .48712 L .72992 .48705 L F
.614 .4 .567 r
.73255 .48678 m .73232 .48911 L .72992 .48705 L F
.168 .355 .806 r
.72992 .48705 m .73232 .48911 L .73008 .48587 L F
.044 0 0 r
.72971 .48712 m .73056 .48709 L .72992 .48705 L F
.033 .212 .716 r
.72992 .48705 m .73056 .48709 L .73008 .48587 L F
.64 .691 .882 r
.72987 .4864 m .73056 .48709 L .72971 .48712 L F
.044 0 0 r
.72701 .48722 m .72971 .48712 L .72992 .48705 L F
.64 .691 .882 r
.72987 .4864 m .72971 .48712 L .72701 .48722 L F
.863 .882 .447 r
.73008 .48587 m .72988 .48638 L .72992 .48705 L F
.863 .702 .681 r
.73008 .48587 m .73056 .48709 L .72987 .4864 L F
.73008 .48587 m .72987 .4864 L .72755 .48405 L F
.863 .882 .447 r
.73008 .48587 m .72988 .48638 L .72988 .48638 L F
.72988 .48638 m .72958 .48716 L .72971 .48712 L F
.72958 .48716 m .72896 .48874 L .72992 .48705 L F
.465 .227 .469 r
.21925 .5607 m .21818 .56399 L .21615 .56451 L F
.007 0 .231 r
.21993 .56241 m .21925 .5607 L .22069 .56139 L F
.21993 .56241 m .21818 .56399 L .21925 .5607 L F
.22 0 0 r
.34209 .58216 m .34453 .58272 L .34612 .58285 L F
.201 0 0 r
.34453 .58272 m .34839 .58252 L .34612 .58285 L F
.578 .709 .932 r
.78428 .49152 m .78764 .49264 L .7869 .49105 L F
.429 .633 .94 r
.7869 .49105 m .78764 .49264 L .78913 .4911 L F
.386 .564 .905 r
.78913 .4911 m .78764 .49264 L .78944 .49278 L F
.482 .508 .808 r
.78764 .49264 m .7909 .49568 L .78944 .49278 L F
.428 0 0 r
.31187 .63264 m .31375 .63366 L .31056 .63251 L F
.31187 .63264 m .31467 .63407 L .31375 .63366 L F
.478 .096 .236 r
.30826 .59268 m .31044 .59265 L .31194 .59036 L F
.459 .083 .239 r
.31044 .59265 m .31422 .59004 L .31194 .59036 L F
.245 .573 .941 r
.21071 .54861 m .21053 .54992 L .20906 .54836 L F
.262 .59 .948 r
.21071 .54861 m .21209 .5501 L .21053 .54992 L F
.212 .722 .89 r
.78683 .52988 m .78943 .52978 L .7889 .52948 L F
.076 0 0 r
.36678 .63909 m .36262 .64049 L .36453 .63935 L F
.28 .115 .471 r
.20948 .58762 m .20924 .59013 L .20879 .59025 L F
.403 .211 .503 r
.21114 .58704 m .20924 .59013 L .20948 .58762 L F
.654 .477 .633 r
.67348 .49 m .67348 .49239 L .67602 .49213 L F
0 0 .24 r
.47639 .67348 m .47616 .67671 L .47577 .67709 L F
.208 .585 .944 r
.47616 .67671 m .47873 .67838 L .47577 .67709 L F
.735 .511 .589 r
.47873 .67838 m .4745 .67918 L .47577 .67709 L F
.5 .716 .969 r
.19765 .54331 m .19724 .54517 L .19558 .54393 L F
.19765 .54331 m .19916 .54486 L .19724 .54517 L F
.554 .597 .851 r
.79723 .50843 m .7992 .50776 L .79617 .50635 L F
.79723 .50843 m .801 .50956 L .7992 .50776 L F
.871 .885 .842 r
.78732 .51858 m .79026 .51691 L .78945 .51501 L F
.725 .723 .848 r
.78945 .51501 m .79026 .51691 L .79279 .51599 L F
.709 .896 .964 r
.73057 .50553 m .7276 .50698 L .72715 .50575 L F
0 0 .406 r
.7276 .50698 m .72927 .50783 L .72715 .50575 L F
.7276 .50698 m .72764 .50969 L .72927 .50783 L F
.456 .132 .327 r
.44093 .676 m .44361 .67577 L .44392 .67387 L F
.637 .388 .525 r
.44361 .67577 m .44617 .6734 L .44392 .67387 L F
.604 .337 .485 r
.50768 .63961 m .50819 .64144 L .50561 .64156 L F
.757 .499 .542 r
.4763 .71085 m .47835 .71383 L .47839 .7112 L F
.742 .486 .543 r
.47839 .7112 m .47835 .71383 L .48196 .71389 L F
.068 .189 .682 r
.57166 .65924 m .5725 .66271 L .57279 .66137 L F
0 .131 .66 r
.57373 .66463 m .57279 .66137 L .5725 .66271 L F
.485 .462 .756 r
.42222 .5931 m .42285 .59528 L .4211 .59572 L F
.042 0 .079 r
.59168 .64135 m .59412 .63866 L .59242 .63972 L F
.062 0 0 r
.34839 .58252 m .35047 .58244 L .35201 .58197 L F
.325 0 0 r
.35047 .58244 m .3543 .58119 L .35201 .58197 L F
.181 0 .12 r
.46898 .65532 m .46709 .65629 L .46614 .65851 L F
.654 .787 .945 r
.75842 .50975 m .755 .50928 L .75723 .50868 L F
.54 .767 .982 r
.75976 .50813 m .75842 .50975 L .75723 .50868 L F
.75976 .50813 m .76085 .50933 L .75842 .50975 L F
.017 .121 .631 r
.56947 .65383 m .57078 .65582 L .57026 .65253 L F
.782 .558 .596 r
.60507 .59536 m .60883 .59334 L .60522 .59295 L F
.60507 .59536 m .6088 .5958 L .60883 .59334 L F
.021 .403 .855 r
.21469 .55114 m .21298 .55089 L .21209 .5501 L F
.21469 .55114 m .21581 .5526 L .21298 .55089 L F
.261 .709 .958 r
.35694 .62439 m .3606 .62513 L .3584 .62529 L F
.22 0 0 r
.45499 .71096 m .45358 .71075 L .45158 .71027 L F
.326 0 0 r
.45499 .71096 m .45626 .71168 L .45358 .71075 L F
.45499 .71096 m .45809 .71212 L .45626 .71168 L F
.398 .127 .383 r
.48786 .65401 m .48721 .65606 L .48507 .65664 L F
.006 0 .194 r
.48915 .6529 m .48721 .65606 L .48786 .65401 L F
.936 .574 .301 r
.53542 .61516 m .53424 .61653 L .53494 .61433 L F
.678 .309 0 r
.53448 .61311 m .53565 .61556 L .53542 .61516 L F
0 0 .557 r
.53448 .61311 m .53542 .61516 L .53543 .61276 L F
.936 .574 .301 r
.53542 .61516 m .53494 .61433 L .53543 .61276 L F
.678 .309 0 r
.53565 .61556 m .53606 .61641 L .53542 .61516 L F
.803 .311 0 r
.53606 .61641 m .53762 .61866 L .53655 .61807 L F
.691 .674 .829 r
.308 .64208 m .31179 .64281 L .31145 .64206 L F
.937 .967 .721 r
.57396 .62981 m .57242 .6343 L .57189 .62997 L F
.716 .19 0 r
.57064 .63169 m .57166 .63256 L .57249 .63274 L F
.937 .967 .721 r
.57292 .63284 m .57249 .63274 L .57242 .6343 L F
0 .215 .731 r
.57405 .6346 m .57242 .6343 L .57249 .63274 L F
.716 .19 0 r
.57166 .63256 m .57405 .6346 L .57249 .63274 L F
.937 .967 .721 r
.57396 .62981 m .57249 .63274 L .57292 .63284 L F
0 .215 .731 r
.57405 .6346 m .57463 .63643 L .57334 .63519 L F
.235 .414 .836 r
.57405 .6346 m .57584 .63756 L .57463 .63643 L F
.581 .543 .778 r
.57405 .6346 m .57687 .63788 L .57584 .63756 L F
.411 .797 .99 r
.57495 .63379 m .57686 .6343 L .57405 .6346 L F
.581 .543 .778 r
.57405 .6346 m .57686 .6343 L .57687 .63788 L F
.523 .258 .455 r
.5728 .63623 m .57477 .63399 L .57405 .6346 L F
.57477 .63399 m .57495 .63379 L .57405 .6346 L F
0 .215 .731 r
.57405 .6346 m .57334 .63519 L .57242 .6343 L F
.969 .933 .67 r
.74643 .48105 m .74473 .4833 L .7454 .48378 L F
.753 .458 .484 r
.74643 .48105 m .74473 .4833 L .74804 .48348 L F
.711 .835 .941 r
.39925 .59631 m .40041 .5974 L .40265 .59642 L F
.408 .623 .94 r
.4175 .58938 m .41664 .59096 L .41562 .58933 L F
.4175 .58938 m .4189 .59106 L .41664 .59096 L F
.553 .254 .415 r
.56846 .5869 m .57091 .58662 L .57109 .58481 L F
.49 .202 .403 r
.57091 .58662 m .57326 .58626 L .57109 .58481 L F
.534 .168 .291 r
.57109 .58481 m .57326 .58626 L .57362 .58478 L F
.515 .888 .971 r
.46134 .70208 m .45814 .7023 L .46073 .70276 L F
0 0 0 r
.46134 .70208 m .46282 .7012 L .46423 .69988 L F
.763 .694 .786 r
.46098 .70395 m .46134 .70208 L .46073 .70276 L F
.46098 .70395 m .46282 .7012 L .46134 .70208 L F
.875 .896 .844 r
.53211 .6727 m .53131 .67649 L .53328 .6759 L F
.53211 .6727 m .52945 .67707 L .53131 .67649 L F
.435 .212 .474 r
.48721 .65606 m .48481 .65891 L .48507 .65664 L F
.407 .237 .535 r
.46269 .6818 m .46073 .68484 L .46103 .68262 L F
0 0 0 r
.56402 .5959 m .56167 .59877 L .56171 .59641 L F
.753 .646 .743 r
.56167 .59877 m .56402 .5959 L .56171 .59641 L F
.055 .207 .706 r
.58184 .65241 m .5821 .65397 L .58105 .65361 L F
.843 .638 .624 r
.59108 .64903 m .59428 .65063 L .59364 .64708 L F
0 0 0 r
.59428 .65063 m .59632 .64655 L .59364 .64708 L F
.37876 .63515 m .37723 .63596 L .37518 .63662 L F
.365 0 0 r
.38079 .63498 m .37723 .63596 L .37876 .63515 L F
0 0 0 r
.54578 .66659 m .54393 .66684 L .54608 .6662 L F
.54578 .66659 m .54279 .66728 L .54393 .66684 L F
.068 0 0 r
.37304 .63719 m .37123 .63826 L .36904 .63873 L F
.163 0 0 r
.37518 .63662 m .37123 .63826 L .37304 .63719 L F
.92 .707 .598 r
.60228 .58371 m .60385 .58717 L .60392 .58469 L F
0 0 0 r
.48123 .63936 m .47904 .64224 L .4804 .64074 L F
.032 0 .318 r
.4804 .64074 m .47904 .64224 L .47868 .64454 L F
.468 .11 .273 r
.46337 .66096 m .46162 .65962 L .46138 .66178 L F
.46337 .66096 m .46427 .65945 L .46162 .65962 L F
0 0 .359 r
.47802 .67447 m .47873 .67838 L .47616 .67671 L F
.47802 .67447 m .47905 .67832 L .47873 .67838 L F
.306 .116 .45 r
.27493 .83695 m .27339 .83821 L .27532 .83473 L F
.117 0 .397 r
.50146 .69093 m .5029 .68753 L .50338 .68897 L F
0 0 .111 r
.61268 .64082 m .61249 .63932 L .61298 .63817 L F
.61268 .64082 m .61248 .64173 L .61249 .63932 L F
.749 .747 .85 r
.59523 .61557 m .59873 .61614 L .5956 .61886 L F
.807 .787 .834 r
.59267 .61848 m .59523 .61557 L .5956 .61886 L F
.573 .674 .908 r
.55717 .60169 m .55884 .60228 L .55603 .59849 L F
.407 0 0 r
.56167 .59877 m .55603 .59849 L .55884 .60228 L F
.926 .865 .761 r
.72638 .49968 m .72661 .50363 L .72652 .50136 L F
.545 .867 .995 r
.39069 .58442 m .3885 .58511 L .38705 .5845 L F
.279 .112 .468 r
.80525 .50677 m .80533 .5093 L .80348 .50987 L F
.367 .368 .728 r
.80533 .5093 m .80615 .5117 L .80348 .50987 L F
.477 .352 .63 r
.80615 .5117 m .80386 .51286 L .80348 .50987 L F
.484 .062 .163 r
.55685 .59224 m .56037 .5902 L .55716 .59102 L F
.55685 .59224 m .55929 .59203 L .56037 .5902 L F
.138 0 0 r
.55929 .59203 m .56281 .59 L .56037 .5902 L F
0 0 .474 r
.54789 .64288 m .54813 .64378 L .5476 .64394 L F
.829 .374 .142 r
.5476 .64394 m .55098 .64674 L .54846 .64483 L F
.54792 .64421 m .5488 .64637 L .55098 .64674 L F
.5476 .64394 m .5488 .64637 L .54792 .64421 L F
.75 .691 .795 r
.5488 .64637 m .55108 .64905 L .55098 .64674 L F
.5488 .64637 m .54704 .64903 L .55108 .64905 L F
.507 .475 .757 r
.55019 .64494 m .54932 .64766 L .5488 .64637 L F
.54932 .64766 m .54905 .64852 L .5488 .64637 L F
0 0 .474 r
.54813 .64378 m .5488 .64637 L .5476 .64394 L F
.619 .627 .837 r
.54846 .64483 m .54722 .64406 L .5476 .64394 L F
.54722 .64406 m .54444 .64234 L .5476 .64394 L F
.872 .839 .81 r
.7454 .48378 m .74433 .48473 L .74289 .48355 L F
.442 .379 .692 r
.30066 .60752 m .30187 .60474 L .29998 .6053 L F
.30066 .60752 m .30243 .60716 L .30187 .60474 L F
.42 .643 .95 r
.39574 .59438 m .39694 .59603 L .3977 .59442 L F
.373 .587 .926 r
.39694 .59603 m .39925 .59631 L .3977 .59442 L F
.576 .303 .465 r
.58176 .58386 m .57933 .58187 L .5793 .58418 L F
.58176 .58386 m .58209 .58168 L .57933 .58187 L F
.459 .315 .598 r
.45274 .68796 m .45215 .69028 L .44996 .68817 L F
.95 .776 .32 r
.61351 .6322 m .61419 .6307 L .614 .62994 L F
.61351 .6322 m .61396 .63305 L .61419 .6307 L F
.47 .322 .597 r
.30185 .59901 m .30379 .59844 L .30368 .59593 L F
.487 .325 .587 r
.30175 .60113 m .30379 .59844 L .30185 .59901 L F
.613 .682 .892 r
.77521 .50871 m .77429 .51179 L .77293 .50988 L F
.77521 .50871 m .7774 .51138 L .77429 .51179 L F
.407 0 0 r
.56167 .59877 m .56076 .59949 L .55603 .59849 L F
0 0 0 r
.56402 .5959 m .56325 .59734 L .56167 .59877 L F
.641 .425 .573 r
.56325 .59734 m .56076 .59949 L .56167 .59877 L F
.314 0 0 r
.74914 .48739 m .75333 .48732 L .7508 .48815 L F
.877 .633 .567 r
.59525 .5961 m .5931 .59799 L .59338 .59547 L F
.59525 .5961 m .59517 .59871 L .5931 .59799 L F
.807 .622 .652 r
.48746 .69113 m .48657 .69348 L .49008 .69369 L F
.536 .354 .581 r
.49008 .69369 m .49235 .69624 L .49232 .69319 L F
.49008 .69369 m .49235 .69624 L .49232 .69319 L F
0 0 .43 r
.5013 .68429 m .5029 .68753 L .50317 .68504 L F
.65 .351 .45 r
.46666 .6795 m .46867 .68182 L .46486 .68159 L F
.717 .343 .34 r
.46879 .6801 m .46867 .68182 L .46666 .6795 L F
.431 .119 .333 r
.3866 .61897 m .38879 .61849 L .38926 .61676 L F
.539 .265 .447 r
.38879 .61849 m .39168 .61609 L .38926 .61676 L F
.952 .768 .618 r
.61458 .62187 m .61373 .61851 L .61341 .62109 L F
.977 .784 .578 r
.61392 .62473 m .61458 .62187 L .61341 .62109 L F
.573 .674 .908 r
.55717 .60169 m .55603 .59849 L .55556 .59906 L F
.661 .425 .552 r
.55705 .60461 m .5591 .60388 L .55717 .60169 L F
.496 .119 .255 r
.48932 .62937 m .4877 .62755 L .4873 .62995 L F
.48932 .62937 m .49005 .62732 L .4877 .62755 L F
.495 .379 .65 r
.29998 .6053 m .30187 .60474 L .30175 .60113 L F
.792 .305 0 r
.46428 .71466 m .46359 .71498 L .4609 .71306 L F
.46428 .71466 m .46485 .71578 L .46359 .71498 L F
.378 .034 .251 r
.51075 .65098 m .51222 .65246 L .5126 .64949 L F
.51075 .65098 m .51002 .65295 L .51222 .65246 L F
.678 .538 .687 r
.51931 .65995 m .51942 .66261 L .52175 .65988 L F
0 0 0 r
.49038 .67231 m .49149 .67143 L .49332 .67037 L F
.676 .533 .683 r
.80695 .49849 m .80431 .50118 L .8042 .49872 L F
.704 .418 .488 r
.47211 .67943 m .46867 .68182 L .46879 .6801 L F
.787 .303 .07 r
.74544 .49337 m .74719 .49488 L .74846 .49116 L F
.841 .986 .865 r
.74956 .4887 m .74846 .49116 L .7513 .49181 L F
.364 0 .118 r
.31644 .5896 m .31867 .5892 L .32003 .58716 L F
.397 .016 .194 r
.31867 .5892 m .32224 .58654 L .32003 .58716 L F
.236 0 0 r
.39929 .61261 m .40154 .61218 L .40306 .6107 L F
.316 0 0 r
.40154 .61218 m .4053 .61019 L .40306 .6107 L F
.511 .533 .815 r
.78269 .50124 m .78384 .5046 L .78539 .50238 L F
.534 .565 .832 r
.78384 .5046 m .78704 .50525 L .78539 .50238 L F
.607 .583 .8 r
.49676 .67763 m .49591 .67941 L .49897 .6789 L F
.104 0 0 r
.49591 .67941 m .49682 .68051 L .49897 .6789 L F
.711 .244 .14 r
.51174 .64215 m .51062 .64345 L .50819 .64144 L F
.845 .428 .244 r
.51174 .64215 m .51328 .64484 L .51062 .64345 L F
.651 .504 .671 r
.52681 .71113 m .5298 .71133 L .52912 .70823 L F
.628 .317 .424 r
.5298 .71133 m .5291 .71319 L .52681 .71113 L F
.651 .504 .671 r
.52681 .71113 m .5298 .71133 L .52912 .70823 L F
.628 .317 .424 r
.5298 .71133 m .5291 .71319 L .52681 .71113 L F
.961 .725 .535 r
.27375 .83403 m .27532 .83473 L .27357 .83666 L F
.539 .342 .562 r
.27375 .83403 m .27357 .83666 L .27532 .83473 L F
0 0 .512 r
.53833 .66551 m .53943 .66634 L .5391 .66402 L F
.577 .023 0 r
.36261 .62507 m .36629 .62617 L .36418 .62583 L F
0 0 .569 r
.74196 .49436 m .74281 .49681 L .74168 .49526 L F
.75 .861 .93 r
.3902 .59449 m .39347 .59455 L .39164 .59422 L F
.446 .863 .951 r
.39415 .59358 m .39347 .59455 L .39574 .59438 L F
.39415 .59358 m .39164 .59422 L .39347 .59455 L F
.706 .843 .948 r
.7794 .51824 m .78118 .51824 L .78025 .5165 L F
.53 .846 .999 r
.78118 .51824 m .78247 .5167 L .78025 .5165 L F
.78118 .51824 m .78357 .51762 L .78247 .5167 L F
.759 .661 .754 r
.49837 .66302 m .50065 .66215 L .50013 .6591 L F
.598 .285 .41 r
.49977 .66442 m .50065 .66215 L .49837 .66302 L F
.525 .499 .769 r
.50013 .6591 m .50065 .66215 L .50198 .65925 L F
.659 .173 .086 r
.50441 .62403 m .50688 .62581 L .50821 .62458 L F
.819 .389 .222 r
.50688 .62581 m .50991 .62724 L .50821 .62458 L F
.85 .925 .88 r
.73391 .51169 m .73489 .51281 L .73757 .51002 L F
.436 .247 .525 r
.73489 .51281 m .73503 .51504 L .73686 .51391 L F
.15 .693 .783 r
.36396 .59671 m .36229 .59673 L .36016 .59698 L F
.387 .807 .973 r
.36588 .5968 m .36229 .59673 L .36396 .59671 L F
.462 .538 .849 r
.8023 .48657 m .8019 .48949 L .80055 .48655 L F
.8023 .48657 m .80391 .4893 L .8019 .48949 L F
.46 .489 .802 r
.80512 .49276 m .8019 .48949 L .80391 .4893 L F
.256 .737 .932 r
.39069 .58442 m .3929 .58432 L .39434 .58476 L F
.272 .728 .954 r
.3929 .58432 m .39655 .58486 L .39434 .58476 L F
.736 .78 .888 r
.54702 .63926 m .54351 .63904 L .54579 .63787 L F
.363 .106 .385 r
.54702 .63926 m .54444 .64234 L .54351 .63904 L F
.54702 .63926 m .54653 .64192 L .54444 .64234 L F
.266 .682 .967 r
.54579 .63787 m .54934 .63878 L .54702 .63926 L F
.086 0 .28 r
.54839 .64044 m .54702 .63926 L .54934 .63878 L F
.54839 .64044 m .54653 .64192 L .54702 .63926 L F
.704 .418 .488 r
.47211 .67943 m .47078 .68195 L .46867 .68182 L F
.418 .066 .258 r
.4745 .67918 m .47078 .68195 L .47211 .67943 L F
0 0 0 r
.53328 .65698 m .53077 .65785 L .52924 .65818 L F
.876 .979 .838 r
.53366 .65491 m .53077 .65785 L .53328 .65698 L F
.958 .777 .616 r
.74822 .48564 m .74998 .48412 L .74804 .48348 L F
.74822 .48564 m .74914 .48739 L .74998 .48412 L F
.899 .689 .61 r
.46893 .70561 m .46911 .70812 L .46712 .70848 L F
.649 .499 .667 r
.46893 .70561 m .47138 .70524 L .46911 .70812 L F
.541 .319 .526 r
.50677 .65957 m .50647 .66228 L .50389 .66239 L F
.492 .276 .514 r
.5087 .6616 m .50677 .65957 L .50865 .65889 L F
.5087 .6616 m .50647 .66228 L .50677 .65957 L F
.198 .297 .741 r
.43644 .6937 m .43869 .69561 L .43802 .69321 L F
.535 .194 .337 r
.52515 .67657 m .52639 .6773 L .52611 .67613 L F
.629 .254 .313 r
.52611 .67613 m .52639 .6773 L .52945 .67707 L F
.675 .783 .931 r
.73603 .50601 m .73366 .50678 L .73264 .5052 L F
.059 .603 .845 r
.28322 .82293 m .28492 .82342 L .28183 .82287 L F
.775 .504 .527 r
.28492 .82342 m .28412 .82475 L .28183 .82287 L F
.506 .834 .999 r
.28513 .82208 m .28492 .82342 L .28322 .82293 L F
.28513 .82208 m .28673 .8228 L .28492 .82342 L F
.259 0 .207 r
.28673 .8228 m .28412 .82475 L .28492 .82342 L F
0 0 0 r
.48275 .63823 m .48123 .63936 L .4804 .64074 L F
.249 .652 .963 r
.20729 .54723 m .20651 .54807 L .20483 .54693 L F
.20729 .54723 m .20906 .54836 L .20651 .54807 L F
.366 0 .047 r
.52044 .68345 m .51993 .6846 L .51769 .68439 L F
.507 .023 .041 r
.52292 .68362 m .52085 .68483 L .52044 .68345 L F
0 0 .212 r
.52044 .68345 m .52085 .68483 L .52136 .68361 L F
.52044 .68345 m .52136 .68361 L .51993 .6846 L F
.684 .329 .367 r
.5762 .59376 m .57213 .59491 L .57342 .59544 L F
.5762 .59376 m .57533 .59484 L .57213 .59491 L F
.416 .113 .342 r
.57817 .59271 m .57533 .59484 L .5762 .59376 L F
.745 .656 .762 r
.43487 .70246 m .43722 .70304 L .43717 .69952 L F
.745 .345 .295 r
.43723 .70526 m .43722 .70304 L .43487 .70246 L F
.382 .359 .709 r
.43717 .69952 m .43722 .70304 L .4393 .70157 L F
.08 0 .244 r
.4393 .70157 m .43722 .70304 L .43723 .70526 L F
.598 .844 .991 r
.36352 .58392 m .36141 .58469 L .35992 .58376 L F
.317 .458 .844 r
.52778 .67974 m .52515 .67657 L .52826 .67864 L F
.416 .816 .982 r
.52762 .68129 m .52778 .67974 L .52826 .67864 L F
.662 .315 .374 r
.72736 .49697 m .72704 .4985 L .72478 .49665 L F
.854 .41 .147 r
.72704 .4985 m .72616 .4976 L .72478 .49665 L F
.578 .042 0 r
.72524 .49553 m .72478 .49665 L .72266 .49517 L F
.818 .337 .035 r
.72393 .49513 m .72478 .49665 L .72524 .49553 L F
.845 .9 .876 r
.72683 .49438 m .7254 .49316 L .72566 .49255 L F
.168 .119 .554 r
.72566 .49255 m .72429 .49578 L .72393 .49513 L F
.612 .709 .913 r
.72566 .49255 m .72393 .49513 L .72491 .49273 L F
.845 .9 .876 r
.7254 .49316 m .72413 .49552 L .72491 .49273 L F
.72683 .49438 m .72551 .49494 L .7254 .49316 L F
.168 .119 .554 r
.7254 .49316 m .72478 .49665 L .72429 .49578 L F
.72543 .49362 m .72478 .49665 L .7254 .49316 L F
.845 .9 .876 r
.72551 .49494 m .72413 .49552 L .7254 .49316 L F
.168 .119 .554 r
.72566 .49255 m .72543 .49362 L .7254 .49316 L F
.845 .9 .876 r
.7254 .49316 m .72491 .49273 L .72566 .49255 L F
.72683 .49438 m .72478 .49665 L .72413 .49552 L F
.677 .581 .741 r
.72683 .49438 m .72736 .49697 L .72478 .49665 L F
.854 .41 .147 r
.72616 .4976 m .72413 .49552 L .72478 .49665 L F
.578 .042 0 r
.72266 .49517 m .72478 .49665 L .72177 .49504 L F
.516 .041 .066 r
.36629 .62617 m .36865 .6265 L .3702 .62504 L F
.104 0 0 r
.36865 .6265 m .37236 .62492 L .3702 .62504 L F
.81 .802 .844 r
.58608 .65362 m .5821 .65397 L .58614 .65311 L F
.025 .061 .561 r
.58608 .65362 m .58659 .65015 L .58813 .64998 L F
.58608 .65362 m .58734 .65241 L .58659 .65015 L F
.548 .922 .778 r
.58608 .65362 m .58614 .65311 L .58734 .65241 L F
0 0 0 r
.51901 .64795 m .51989 .64648 L .51982 .64628 L F
.51989 .64648 m .51834 .64783 L .51998 .64674 L F
.585 .749 .955 r
.52224 .64584 m .52082 .6475 L .51989 .64648 L F
0 0 0 r
.51989 .64648 m .51998 .64674 L .52104 .64604 L F
.51982 .64628 m .51989 .64648 L .52076 .64435 L F
.438 .71 .981 r
.51989 .64648 m .52082 .6475 L .51901 .64795 L F
.582 .489 .714 r
.52082 .6475 m .51891 .65029 L .51901 .64795 L F
.957 .8 .645 r
.58095 .64347 m .57918 .64091 L .58089 .64046 L F
0 .141 .679 r
.58089 .64046 m .58251 .64224 L .58095 .64347 L F
0 0 0 r
.58251 .64224 m .58088 .64477 L .58095 .64347 L F
.296 0 .098 r
.55451 .59272 m .55685 .59224 L .55716 .59102 L F
.57 .317 .493 r
.58739 .57856 m .58989 .57844 L .59017 .57611 L F
.556 .305 .49 r
.59017 .57611 m .59219 .57804 L .59235 .57549 L F
.59017 .57611 m .58989 .57844 L .59219 .57804 L F
.427 .016 .155 r
.51342 .68202 m .51578 .68165 L .51714 .67982 L F
0 0 .059 r
.51943 .67677 m .51714 .67982 L .51848 .67856 L F
0 0 0 r
.60375 .66762 m .601 .67055 L .60134 .66974 L F
.36 0 .092 r
.52397 .65816 m .52369 .65886 L .52598 .65845 L F
.779 .289 .055 r
.58099 .64589 m .58007 .6466 L .58208 .64698 L F
.582 .4 .6 r
.76559 .4849 m .76737 .48358 L .76488 .48406 L F
.793 .726 .79 r
.5907 .64274 m .59006 .64293 L .59168 .64135 L F
.82 .703 .736 r
.47438 .70015 m .4738 .70163 L .47504 .70051 L F
.458 .377 .677 r
.52912 .70823 m .53178 .7101 L .53212 .70775 L F
.52912 .70823 m .5298 .71133 L .53178 .7101 L F
.53178 .7101 m .5298 .71133 L .52912 .70823 L F
.563 .353 .554 r
.48405 .6933 m .48657 .69348 L .48746 .69113 L F
.565 .41 .63 r
.48405 .6933 m .48476 .69674 L .48657 .69348 L F
.071 .339 .815 r
.31909 .63364 m .31923 .63238 L .31709 .63309 L F
.31909 .63364 m .32142 .63524 L .31923 .63238 L F
.332 0 .13 r
.34416 .6046 m .34104 .60666 L .3418 .60484 L F
.584 .434 .644 r
.34396 .60173 m .34416 .6046 L .3418 .60484 L F
.626 .811 .971 r
.76576 .50793 m .76432 .50996 L .76329 .50874 L F
.76576 .50793 m .76676 .50919 L .76432 .50996 L F
.381 .31 .652 r
.43738 .68502 m .43731 .68844 L .43951 .68708 L F
.359 .295 .648 r
.43802 .69074 m .43951 .68708 L .43731 .68844 L F
.725 .479 .554 r
.43699 .60186 m .43712 .60435 L .43353 .60387 L F
.43699 .60186 m .43353 .60387 L .43688 .60347 L F
0 0 .35 r
.43801 .60288 m .43699 .60186 L .43688 .60347 L F
.584 .587 .821 r
.42532 .59456 m .42414 .59802 L .42285 .59528 L F
.42532 .59456 m .42661 .59766 L .42414 .59802 L F
0 0 0 r
.48563 .63333 m .48376 .63649 L .48508 .63508 L F
.48508 .63508 m .48376 .63649 L .48275 .63823 L F
.737 .817 .914 r
.52243 .64332 m .52662 .6441 L .5261 .64244 L F
.773 .876 .922 r
.5261 .64244 m .52662 .6441 L .5293 .64212 L F
0 0 0 r
.52418 .68297 m .52292 .68362 L .5265 .68251 L F
.258 .766 .761 r
.52418 .68297 m .5265 .68251 L .52871 .68187 L F
.757 .684 .781 r
.55208 .66478 m .55562 .66509 L .55396 .66211 L F
.989 .727 .422 r
.55208 .66478 m .55093 .66639 L .55206 .66716 L F
.705 .91 .967 r
.55206 .66716 m .55093 .66639 L .55185 .66598 L F
.335 .17 .503 r
.55208 .66478 m .55366 .66591 L .55562 .66509 L F
.55208 .66478 m .55206 .66716 L .55369 .66593 L F
.55366 .66591 m .55369 .66593 L .55375 .6659 L F
.378 .501 .856 r
.55562 .66509 m .55803 .66262 L .55396 .66211 L F
.754 .809 .897 r
.55381 .66445 m .55445 .66535 L .55369 .66593 L F
.55384 .66395 m .55445 .66535 L .55381 .66445 L F
.58 .358 .543 r
.55458 .66476 m .55379 .66468 L .55392 .66461 L F
.341 .605 .946 r
.55381 .66445 m .55458 .66476 L .55392 .66461 L F
.754 .809 .897 r
.55381 .66445 m .55379 .66468 L .55458 .66476 L F
.55379 .66468 m .55369 .66593 L .55458 .66476 L F
.58 .358 .543 r
.55458 .66476 m .55099 .66614 L .55379 .66468 L F
.55458 .66476 m .55093 .66639 L .55099 .66614 L F
.893 .984 .802 r
.55151 .66404 m .55208 .66478 L .55396 .66211 L F
.98 .86 .479 r
.55151 .66404 m .55093 .66639 L .55208 .66478 L F
.58 .358 .543 r
.55392 .66461 m .55099 .66614 L .55151 .66404 L F
.754 .809 .897 r
.55409 .66452 m .55803 .66262 L .55445 .66535 L F
.55384 .66395 m .55453 .66429 L .55409 .66452 L F
.55384 .66395 m .55381 .66445 L .55458 .66476 L F
.908 .6 .449 r
.55384 .66395 m .55458 .66476 L .55324 .66366 L F
.893 .984 .802 r
.55151 .66404 m .55396 .66211 L .55277 .66263 L F
.814 .989 .733 r
.55277 .66263 m .55189 .66255 L .55151 .66404 L F
.908 .6 .449 r
.55384 .66395 m .55324 .66366 L .55189 .66255 L F
.754 .809 .897 r
.55384 .66395 m .55721 .66288 L .55453 .66429 L F
.55721 .66288 m .55803 .66262 L .55409 .66452 L F
.341 .605 .946 r
.55163 .66356 m .55381 .66445 L .55151 .66404 L F
.55381 .66445 m .55392 .66461 L .55151 .66404 L F
.55189 .66255 m .55458 .66476 L .55163 .66356 L F
.705 .91 .967 r
.55337 .66592 m .55185 .66598 L .55458 .66476 L F
.55206 .66716 m .55185 .66598 L .55337 .66592 L F
.335 .17 .503 r
.55366 .66591 m .55375 .6659 L .55562 .66509 L F
.61 .945 .769 r
.55369 .66593 m .55803 .66262 L .55562 .66509 L F
.326 .679 .978 r
.40261 .58612 m .40456 .58609 L .40396 .58721 L F
.345 .701 .983 r
.40456 .58609 m .40593 .58717 L .40396 .58721 L F
.565 .312 .491 r
.43237 .6102 m .42975 .61261 L .42995 .61042 L F
.814 .487 .435 r
.59295 .59339 m .59023 .59478 L .59012 .59245 L F
.59295 .59339 m .59338 .59547 L .59023 .59478 L F
.612 .886 .99 r
.31437 .62629 m .31191 .62716 L .3137 .62794 L F
.3137 .62794 m .31191 .62716 L .31437 .62629 L F
.31437 .62629 m .31191 .62716 L .3137 .62794 L F
.044 .054 .543 r
.57879 .6384 m .57812 .64208 L .57641 .63916 L F
.57879 .6384 m .57918 .64091 L .57812 .64208 L F
.315 .32 .706 r
.57918 .64091 m .5784 .64356 L .57812 .64208 L F
.672 .627 .796 r
.78357 .51762 m .78459 .52093 L .78732 .51858 L F
.666 .616 .789 r
.78459 .52093 m .78793 .52182 L .78732 .51858 L F
.62 .451 .631 r
.40838 .60715 m .41068 .60708 L .41056 .60487 L F
.523 .174 .317 r
.40738 .60947 m .41068 .60708 L .40838 .60715 L F
.542 .869 .994 r
.77815 .49165 m .77972 .49014 L .77721 .49078 L F
.77815 .49165 m .78063 .49092 L .77972 .49014 L F
.593 .637 .863 r
.73581 .51647 m .73686 .51391 L .73503 .51504 L F
.73581 .51647 m .73864 .51622 L .73686 .51391 L F
.703 .404 .468 r
.47259 .71085 m .475 .71325 L .4763 .71085 L F
.782 .501 .511 r
.475 .71325 m .47835 .71383 L .4763 .71085 L F
.294 0 0 r
.51254 .68833 m .50816 .68799 L .51001 .68744 L F
.741 .403 .409 r
.74186 .50325 m .74363 .50377 L .74385 .50307 L F
.542 .336 .55 r
.58965 .65646 m .59203 .65844 L .59211 .65604 L F
.58965 .65646 m .59203 .65844 L .59211 .65604 L F
.419 .123 .354 r
.45918 .66231 m .45858 .66431 L .46138 .66178 L F
.605 .635 .854 r
.74939 .52391 m .75261 .52564 L .75161 .52358 L F
.634 .797 .961 r
.75261 .52564 m .75428 .52335 L .75161 .52358 L F
.75261 .52564 m .75559 .52477 L .75428 .52335 L F
.604 .826 .985 r
.31375 .63366 m .31467 .63407 L .31529 .63211 L F
.614 .835 .985 r
.31529 .63211 m .31467 .63407 L .31709 .63309 L F
.413 .52 .857 r
.43197 .60051 m .43054 .60247 L .42976 .60096 L F
.43197 .60051 m .43353 .60387 L .43054 .60247 L F
.696 .407 .481 r
.50389 .66239 m .50372 .66448 L .50138 .66219 L F
.297 .078 .402 r
.50577 .66339 m .50389 .66239 L .50647 .66228 L F
.50577 .66339 m .50372 .66448 L .50389 .66239 L F
.381 .31 .652 r
.43738 .68502 m .43951 .68708 L .43897 .68463 L F
.358 0 .203 r
.59315 .64522 m .59334 .64739 L .59024 .64724 L F
.855 .949 .594 r
.59515 .64505 m .59404 .64649 L .59315 .64522 L F
.59515 .64505 m .59426 .64536 L .59334 .64739 L F
.46 .679 .959 r
.59693 .64694 m .59426 .64536 L .59515 .64505 L F
.59608 .64644 m .59658 .64551 L .59426 .64536 L F
.59693 .64694 m .5968 .64642 L .59608 .64644 L F
.5968 .64642 m .59658 .64551 L .59608 .64644 L F
.855 .949 .594 r
.59404 .64649 m .59334 .64739 L .59327 .64651 L F
.59404 .64649 m .59327 .64651 L .59315 .64522 L F
.655 .298 .354 r
.59611 .6736 m .59226 .67533 L .59341 .67368 L F
.071 0 .109 r
.5523 .59822 m .54949 .60129 L .55061 .59934 L F
.826 .998 .784 r
.49241 .71456 m .49409 .71494 L .49378 .71381 L F
.676 .193 .095 r
.52417 .67783 m .52826 .67864 L .52515 .67657 L F
.872 .994 .766 r
.59006 .64293 m .58836 .64518 L .58835 .64365 L F
.95 .797 .656 r
.58836 .64518 m .58594 .64635 L .58835 .64365 L F
.58836 .64518 m .5873 .6474 L .58594 .64635 L F
.634 .457 .626 r
.49753 .64507 m .49749 .64761 L .49515 .64758 L F
.548 .387 .615 r
.4998 .64708 m .49753 .64507 L .49998 .64477 L F
.4998 .64708 m .49749 .64761 L .49753 .64507 L F
.308 0 0 r
.56184 .61321 m .56486 .61318 L .56357 .61291 L F
.56357 .61291 m .56486 .61318 L .56184 .61321 L F
.349 .125 .427 r
.56357 .61291 m .56486 .61318 L .56663 .61213 L F
.56663 .61213 m .56486 .61318 L .56357 .61291 L F
.837 .598 .577 r
.50138 .66219 m .50112 .66423 L .49977 .66442 L F
.642 .416 .56 r
.50138 .66219 m .50372 .66448 L .50112 .66423 L F
.553 .224 .364 r
.42668 .61348 m .42393 .61526 L .42441 .61368 L F
.015 0 0 r
.36978 .59584 m .36831 .59638 L .36588 .5968 L F
0 0 0 r
.37198 .59559 m .36831 .59638 L .36978 .59584 L F
.389 .132 .399 r
.80695 .49849 m .80654 .5004 L .80431 .50118 L F
0 0 .186 r
.80654 .5004 m .80504 .50348 L .80431 .50118 L F
.389 .132 .399 r
.80695 .49849 m .80654 .5004 L .80431 .50118 L F
.405 .853 .907 r
.37638 .59433 m .37574 .59502 L .3779 .59456 L F
.37638 .59433 m .37417 .59498 L .37574 .59502 L F
.584 .674 .902 r
.7763 .52809 m .77769 .53046 L .78015 .5299 L F
.527 .445 .706 r
.67486 .49789 m .67675 .49372 L .67423 .49603 L F
.67486 .49789 m .67714 .49738 L .67675 .49372 L F
.544 .531 .791 r
.40957 .602 m .41056 .60487 L .41256 .60407 L F
.374 .22 .541 r
.41068 .60708 m .41256 .60407 L .41056 .60487 L F
.366 .623 .951 r
.34185 .64257 m .34451 .64561 L .34486 .64385 L F
.283 .536 .915 r
.34486 .64385 m .34451 .64561 L .34675 .64569 L F
0 0 0 r
.73702 .49593 m .73489 .49807 L .73611 .49686 L F
.346 .63 .959 r
.73489 .49807 m .73764 .49842 L .73611 .49686 L F
.997 .828 .48 r
.563 .68521 m .56184 .68687 L .56204 .68424 L F
.56204 .68424 m .56184 .68687 L .563 .68521 L F
.75 .513 .573 r
.78959 .50032 m .79269 .49995 L .79153 .49817 L F
.591 .526 .751 r
.79153 .49817 m .79378 .4972 L .7909 .49568 L F
.66 .566 .738 r
.79269 .49995 m .79378 .4972 L .79153 .49817 L F
0 .087 .646 r
.55649 .6554 m .55667 .65643 L .55496 .65327 L F
.827 .517 0 r
.55649 .6554 m .5576 .65875 L .55667 .65643 L F
.498 .194 .381 r
.51948 .6868 m .51769 .68439 L .51993 .6846 L F
.51948 .6868 m .51707 .68725 L .51769 .68439 L F
.521 .776 .99 r
.78332 .49023 m .78428 .49152 L .7869 .49105 L F
.604 .656 .874 r
.48626 .67666 m .48772 .67398 L .4853 .67284 L F
.48626 .67666 m .48858 .67617 L .48772 .67398 L F
.557 .415 .643 r
.4864 .67872 m .48858 .67617 L .48626 .67666 L F
.38 .387 .742 r
.21869 .56655 m .21615 .56451 L .21818 .56399 L F
.794 .75 .812 r
.67714 .49738 m .67818 .49949 L .68012 .49777 L F
.813 .657 .689 r
.48857 .67854 m .48983 .68192 L .49201 .67994 L F
.555 .321 .516 r
.50013 .6591 m .50251 .65881 L .50256 .6565 L F
.56 .309 .493 r
.50251 .65881 m .50523 .65636 L .50256 .6565 L F
0 0 .095 r
.53105 .60681 m .53212 .60377 L .53121 .60433 L F
.556 .734 .958 r
.79017 .48269 m .78865 .48465 L .78771 .48328 L F
.79017 .48269 m .79116 .48419 L .78865 .48465 L F
.526 .199 .356 r
.41915 .61602 m .4182 .61837 L .41587 .61847 L F
.589 .314 .468 r
.42151 .6156 m .4182 .61837 L .41915 .61602 L F
.164 0 0 r
.46282 .7012 m .46627 .70006 L .46423 .69988 L F
.628 .381 .524 r
.59235 .57549 m .59585 .57534 L .59554 .57297 L F
.754 .471 .503 r
.59554 .57297 m .59766 .57515 L .59797 .57294 L F
.59554 .57297 m .59585 .57534 L .59766 .57515 L F
.326 .339 .721 r
.30201 .63008 m .30304 .63384 L .3041 .63177 L F
.542 .602 .864 r
.30304 .63384 m .30575 .63376 L .3041 .63177 L F
.796 .747 .807 r
.67941 .49465 m .68012 .49777 L .68075 .49589 L F
.67941 .49465 m .67714 .49738 L .68012 .49777 L F
.707 .274 .219 r
.3505 .64529 m .34893 .64671 L .34675 .64569 L F
.333 0 0 r
.3514 .64628 m .3505 .64529 L .3528 .64511 L F
.3514 .64628 m .34893 .64671 L .3505 .64529 L F
.408 .021 .189 r
.49714 .62315 m .49517 .62213 L .49482 .62403 L F
.49714 .62315 m .49738 .62185 L .49517 .62213 L F
.243 .672 .961 r
.34599 .62079 m .34546 .62156 L .34403 .62055 L F
.34599 .62079 m .34738 .62165 L .34546 .62156 L F
.613 .865 .99 r
.76362 .52185 m .76679 .52195 L .76583 .52109 L F
.418 .788 .994 r
.76679 .52195 m .76824 .52092 L .76583 .52109 L F
.76679 .52195 m .76926 .52168 L .76824 .52092 L F
.525 .049 .068 r
.75571 .48668 m .75863 .4878 L .75947 .48626 L F
.65 .201 .172 r
.75863 .4878 m .76171 .48688 L .75947 .48626 L F
.452 .867 .723 r
.59006 .64293 m .58972 .64281 L .59168 .64135 L F
.59006 .64293 m .58835 .64365 L .58972 .64281 L F
.816 .908 .903 r
.74433 .48473 m .74096 .48597 L .74289 .48355 L F
.352 .154 .466 r
.80785 .4977 m .80654 .5004 L .80695 .49849 L F
0 .123 .585 r
.51375 .62985 m .51735 .63265 L .51497 .63143 L F
0 .525 .759 r
.51735 .63265 m .52101 .63329 L .51871 .63367 L F
.455 .477 .792 r
.33886 .61238 m .3382 .61624 L .3375 .6129 L F
.33886 .61238 m .34006 .616 L .3382 .61624 L F
.301 .78 .689 r
.54486 .59701 m .54874 .59547 L .54642 .59569 L F
.331 0 0 r
.32448 .58631 m .32674 .58601 L .32831 .58435 L F
.149 0 0 r
.32831 .58435 m .32887 .58535 L .33049 .58387 L F
.32831 .58435 m .32674 .58601 L .32887 .58535 L F
.203 .623 .949 r
.56708 .59679 m .56906 .59645 L .56633 .59622 L F
.56708 .59679 m .57043 .59742 L .56906 .59645 L F
.306 .196 .562 r
.2096 .59259 m .20968 .59508 L .20802 .59604 L F
.055 0 .311 r
.20968 .59508 m .20783 .59846 L .20802 .59604 L F
.461 .444 .754 r
.54653 .64192 m .5476 .64394 L .54444 .64234 L F
.44 .135 .35 r
.78993 .5233 m .7902 .5207 L .78793 .52182 L F
.448 .132 .336 r
.49749 .64761 m .49477 .65005 L .49515 .64758 L F
.341 0 0 r
.76814 .49145 m .76878 .49035 L .7715 .49053 L F
.433 .12 .333 r
.56281 .59 m .56515 .58945 L .56545 .5878 L F
.514 .189 .354 r
.56761 .58931 m .56545 .5878 L .56515 .58945 L F
.56761 .58931 m .56846 .5869 L .56545 .5878 L F
.516 .547 .826 r
.42872 .59739 m .42716 .59979 L .42661 .59766 L F
.444 .451 .772 r
.42872 .59739 m .42976 .60096 L .42716 .59979 L F
.86 .419 .014 r
.55108 .64905 m .55139 .64818 L .55098 .64674 L F
.55108 .64905 m .55237 .65002 L .55139 .64818 L F
.509 .03 .054 r
.75703 .4924 m .76069 .492 L .75957 .49347 L F
.477 0 0 r
.76069 .492 m .76217 .49342 L .75957 .49347 L F
.76069 .492 m .76304 .49234 L .76217 .49342 L F
.666 .409 .523 r
.49323 .66789 m .49617 .67027 L .49332 .67037 L F
.49323 .66789 m .49607 .66781 L .49617 .67027 L F
.49617 .67027 m .49323 .66789 L .49332 .67037 L F
.49617 .67027 m .49607 .66781 L .49323 .66789 L F
.667 .724 .892 r
.73938 .50646 m .73603 .50601 L .73898 .50275 L F
0 0 0 r
.73938 .50646 m .73875 .50883 L .73757 .51002 L F
.825 .817 .842 r
.74186 .50325 m .73938 .50646 L .73898 .50275 L F
.732 .358 .342 r
.74249 .50852 m .73875 .50883 L .73938 .50646 L F
.531 .473 .736 r
.30201 .63008 m .30363 .62823 L .30264 .62752 L F
.30201 .63008 m .30435 .63008 L .30363 .62823 L F
.326 .339 .721 r
.30201 .63008 m .3041 .63177 L .30435 .63008 L F
.467 .181 .395 r
.51848 .67856 m .52227 .67586 L .51943 .67677 L F
.826 .592 .04 r
.5576 .65875 m .5579 .66157 L .55814 .66199 L F
.917 .597 .122 r
.5579 .66157 m .55892 .66441 L .55814 .66199 L F
.406 0 0 r
.59108 .64903 m .5931 .65014 L .59428 .65063 L F
0 0 0 r
.59428 .65063 m .59544 .6493 L .59632 .64655 L F
.577 .912 .973 r
.5931 .65014 m .59544 .6493 L .59428 .65063 L F
.032 .285 .78 r
.34006 .616 m .34208 .61761 L .34169 .61909 L F
.102 .368 .832 r
.34208 .61761 m .34403 .62055 L .34169 .61909 L F
.352 .67 .975 r
.40261 .58612 m .4008 .58624 L .39871 .58459 L F
.497 .267 .495 r
.44087 .67854 m .44361 .67577 L .44093 .676 L F
.528 .742 .973 r
.57765 .67309 m .5803 .67155 L .57708 .67012 L F
.57765 .67309 m .58089 .67295 L .5803 .67155 L F
.075 .637 .737 r
.52101 .63329 m .52322 .63314 L .52459 .63309 L F
.607 .144 .128 r
.52322 .63314 m .52671 .63315 L .52459 .63309 L F
.781 .4 .334 r
.46798 .71645 m .46657 .7184 L .46485 .71578 L F
.646 .257 .294 r
.47034 .71694 m .46657 .7184 L .46798 .71645 L F
.768 .355 .267 r
.5513 .67003 m .55299 .67123 L .54992 .6704 L F
.33 .262 .627 r
.20924 .59013 m .2096 .59259 L .20879 .59025 L F
0 .233 .751 r
.30253 .62637 m .30363 .62823 L .30264 .62752 L F
.558 .864 .996 r
.30253 .62637 m .30042 .62705 L .30264 .62752 L F
0 .233 .751 r
.30253 .62637 m .30363 .62823 L .30264 .62752 L F
.558 .864 .996 r
.30253 .62637 m .30042 .62705 L .30264 .62752 L F
.711 .835 .941 r
.39925 .59631 m .40265 .59642 L .40136 .59491 L F
.588 .744 .951 r
.40136 .59491 m .40265 .59642 L .40362 .59437 L F
.456 .585 .893 r
.40265 .59642 m .4046 .59633 L .40362 .59437 L F
.719 .411 .456 r
.67675 .49372 m .67733 .49232 L .67602 .49213 L F
.67675 .49372 m .67941 .49465 L .67733 .49232 L F
.132 0 .4 r
.4873 .62995 m .48563 .63333 L .48738 .63245 L F
0 0 .038 r
.48738 .63245 m .48563 .63333 L .48508 .63508 L F
.307 .293 .68 r
.53715 .67629 m .53903 .68022 L .53931 .67842 L F
.537 .626 .888 r
.74555 .52139 m .74939 .52391 L .74794 .52111 L F
.511 .622 .898 r
.74939 .52391 m .75117 .52181 L .74794 .52111 L F
.74939 .52391 m .75161 .52358 L .75117 .52181 L F
.126 .19 .659 r
.80876 .49657 m .80668 .49496 L .80834 .49417 L F
.312 0 .245 r
.52601 .6535 m .52787 .65323 L .52746 .65256 L F
.52601 .6535 m .52452 .65542 L .52787 .65323 L F
.337 0 .063 r
.37461 .62421 m .37687 .62385 L .37832 .62185 L F
.294 0 .038 r
.37832 .62185 m .37909 .62333 L .38044 .62124 L F
.37832 .62185 m .37687 .62385 L .37909 .62333 L F
.503 .259 .477 r
.53168 .66932 m .53201 .66805 L .52861 .66768 L F
.489 .753 .988 r
.48941 .65037 m .49023 .64898 L .48797 .64931 L F
.48941 .65037 m .49178 .65023 L .49023 .64898 L F
.37 .777 .983 r
.36352 .58392 m .36578 .58371 L .36716 .58433 L F
.334 .768 .969 r
.36578 .58371 m .36946 .58411 L .36716 .58433 L F
.674 .765 .919 r
.55564 .66977 m .55693 .67123 L .55914 .67023 L F
.532 .302 .511 r
.44855 .67305 m .45118 .67039 L .44903 .67108 L F
.506 .269 .489 r
.39168 .61609 m .39395 .6156 L .39409 .61295 L F
.406 .189 .468 r
.39409 .61295 m .39606 .61482 L .39684 .6127 L F
.39409 .61295 m .39395 .6156 L .39606 .61482 L F
.836 .647 .648 r
.74544 .49337 m .74196 .49436 L .74415 .49409 L F
.747 .282 .145 r
.74415 .49409 m .74618 .49491 L .74544 .49337 L F
.787 .303 .07 r
.74544 .49337 m .74618 .49491 L .74719 .49488 L F
.385 0 .028 r
.33278 .58364 m .33508 .58351 L .33657 .58185 L F
.435 0 .06 r
.33657 .58185 m .33866 .58245 L .33872 .5821 L F
.33657 .58185 m .33508 .58351 L .33866 .58245 L F
.842 .606 .581 r
.73008 .48587 m .73232 .48911 L .73255 .48678 L F
.59 .495 .715 r
.67348 .49239 m .67675 .49372 L .67602 .49213 L F
.67348 .49239 m .67423 .49603 L .67675 .49372 L F
.228 .743 .864 r
.35755 .59775 m .35424 .59787 L .35564 .59804 L F
.271 0 0 r
.53993 .65163 m .53663 .653 L .53798 .65175 L F
.095 0 .316 r
.21328 .58387 m .21114 .58704 L .21109 .58502 L F
.832 .635 .636 r
.59766 .57515 m .5995 .57644 L .59797 .57294 L F
.848 .723 .726 r
.59578 .57784 m .5995 .57644 L .59766 .57515 L F
.59578 .57784 m .59869 .57883 L .5995 .57644 L F
.724 .592 .708 r
.59797 .57294 m .5995 .57644 L .59867 .57351 L F
.375 .276 .614 r
.3459 .60355 m .34396 .60173 L .3464 .60144 L F
.3459 .60355 m .34416 .6046 L .34396 .60173 L F
.745 .323 .247 r
.5561 .61804 m .55875 .61887 L .55711 .619 L F
0 0 0 r
.31263 .64012 m .31217 .64357 L .31244 .64133 L F
.676 .182 .068 r
.47533 .67134 m .47897 .67261 L .47639 .67348 L F
.284 .149 .514 r
.47802 .67447 m .47639 .67348 L .47897 .67261 L F
.47802 .67447 m .47616 .67671 L .47639 .67348 L F
.503 .259 .477 r
.53168 .66932 m .5325 .67059 L .53201 .66805 L F
.652 .356 .457 r
.53201 .66805 m .5325 .67059 L .53453 .67011 L F
.314 0 0 r
.74914 .48739 m .75283 .48795 L .75333 .48732 L F
.62 .175 .171 r
.75283 .48795 m .75571 .48668 L .75333 .48732 L F
.935 .76 .641 r
.58813 .64998 m .58659 .65015 L .5873 .6474 L F
.525 .355 .593 r
.59024 .64724 m .58813 .64998 L .5873 .6474 L F
.59024 .64724 m .59108 .64903 L .58813 .64998 L F
.381 .787 .983 r
.36946 .58411 m .37162 .58386 L .37313 .5845 L F
.203 .704 .911 r
.37162 .58386 m .37535 .58429 L .37313 .5845 L F
.2 .727 .744 r
.46911 .70812 m .4683 .70822 L .46712 .70848 L F
.822 .988 .724 r
.46911 .70812 m .47138 .70524 L .46944 .70654 L F
.817 .995 .76 r
.46911 .70812 m .46944 .70654 L .4683 .70822 L F
.729 .495 .574 r
.76977 .48048 m .76995 .48323 L .77322 .48264 L F
0 0 .532 r
.56194 .63633 m .56273 .6369 L .5605 .63513 L F
.789 .416 0 r
.59536 .60481 m .59614 .60685 L .5946 .60362 L F
.502 .318 .564 r
.43864 .67939 m .44082 .68134 L .44087 .67854 L F
.43864 .67939 m .43865 .68209 L .44082 .68134 L F
.455 .143 .346 r
.41361 .61856 m .41247 .62144 L .41058 .62176 L F
.486 .173 .36 r
.41551 .6205 m .41361 .61856 L .41587 .61847 L F
.41551 .6205 m .41247 .62144 L .41361 .61856 L F
.21 0 0 r
.43723 .70526 m .43828 .70542 L .43793 .70543 L F
.536 .256 .438 r
.50222 .64329 m .49998 .64477 L .49993 .64424 L F
.50222 .64329 m .50235 .64456 L .49998 .64477 L F
.537 .26 .443 r
.50561 .64156 m .50235 .64456 L .50222 .64329 L F
.594 .379 .558 r
.51096 .6675 m .51336 .66776 L .51313 .66486 L F
.51096 .6675 m .51336 .66776 L .51313 .66486 L F
.652 .542 .717 r
.51313 .66486 m .51553 .66541 L .51572 .66262 L F
.467 .165 .369 r
.51546 .66549 m .51553 .66541 L .51313 .66486 L F
.752 .497 .546 r
.51675 .6676 m .51477 .6661 L .51664 .66581 L F
.51477 .6661 m .51313 .66486 L .51549 .6655 L F
.51477 .6661 m .51549 .6655 L .51664 .66581 L F
.51675 .6676 m .51336 .66776 L .51313 .66486 L F
0 0 .503 r
.51776 .66629 m .51675 .6676 L .51659 .66488 L F
.334 .074 .362 r
.51557 .66543 m .51569 .6674 L .51776 .66629 L F
.51553 .66541 m .51553 .66546 L .51557 .66543 L F
.51553 .66546 m .51569 .6674 L .51557 .66543 L F
.467 .165 .369 r
.51336 .66776 m .51569 .6674 L .51553 .66546 L F
.51546 .66549 m .51553 .66546 L .51553 .66541 L F
.51336 .66776 m .51553 .66546 L .51546 .66549 L F
.285 .226 .613 r
.51572 .66262 m .51553 .66541 L .51558 .66536 L F
.752 .497 .546 r
.51561 .66499 m .51562 .66487 L .51659 .66488 L F
.285 .226 .613 r
.51572 .66262 m .51558 .66536 L .51562 .66487 L F
.643 .528 .708 r
.51572 .66262 m .51589 .66308 L .51562 .66487 L F
.51589 .66308 m .51659 .66488 L .51567 .66487 L F
.51589 .66308 m .51567 .66487 L .51562 .66487 L F
.752 .497 .546 r
.51546 .66549 m .51313 .66486 L .51565 .66499 L F
.51557 .66545 m .51565 .66499 L .5166 .66504 L F
.51546 .66549 m .51565 .66499 L .51557 .66545 L F
.5166 .66504 m .51561 .66499 L .51659 .66488 L F
.51664 .66581 m .51546 .66549 L .5166 .66504 L F
.155 .241 .702 r
.51733 .66373 m .51659 .66488 L .51572 .66262 L F
0 0 .503 r
.51776 .66629 m .51659 .66488 L .51733 .66373 L F
.334 .074 .362 r
.51561 .66534 m .51776 .66629 L .51733 .66373 L F
.51553 .66541 m .51559 .66544 L .51561 .66534 L F
.51559 .66544 m .51776 .66629 L .51561 .66534 L F
.285 .226 .613 r
.51572 .66262 m .51562 .66487 L .51582 .66269 L F
.643 .528 .708 r
.51572 .66262 m .51562 .66487 L .51313 .66486 L F
.285 .226 .613 r
.51582 .66269 m .51558 .66536 L .51733 .66373 L F
.752 .497 .546 r
.51561 .66499 m .51313 .66486 L .51562 .66487 L F
.467 .165 .369 r
.51336 .66776 m .51546 .66549 L .51313 .66486 L F
.4 .667 .968 r
.7936 .48379 m .79741 .48562 L .79509 .48604 L F
.485 .843 .993 r
.77573 .48268 m .77835 .48213 L .77936 .48283 L F
.287 .749 .95 r
.77835 .48213 m .78188 .48255 L .77936 .48283 L F
.436 .5 .827 r
.78944 .49278 m .7909 .49568 L .79272 .49393 L F
.468 .552 .859 r
.7909 .49568 m .79378 .4972 L .79272 .49393 L F
.567 .268 .421 r
.30646 .62178 m .30822 .62423 L .30899 .62168 L F
.614 .52 .724 r
.30646 .62178 m .30899 .62168 L .30813 .61919 L F
.217 .175 .594 r
.30699 .62497 m .30822 .62423 L .30646 .62178 L F
.567 .268 .421 r
.30646 .62178 m .30822 .62423 L .30899 .62168 L F
.42 .266 .564 r
.30368 .59593 m .30553 .59529 L .30532 .59285 L F
.432 .294 .592 r
.30368 .59593 m .30563 .59788 L .30553 .59529 L F
.434 .294 .591 r
.30379 .59844 m .30563 .59788 L .30368 .59593 L F
.398 .582 .915 r
.55557 .61063 m .55617 .61325 L .55476 .61064 L F
.55557 .61063 m .5578 .61184 L .55617 .61325 L F
.297 .568 .932 r
.55759 .61037 m .5578 .61184 L .55557 .61063 L F
.006 0 0 r
.5536 .61137 m .5566 .61062 L .55557 .61063 L F
.5566 .61062 m .55759 .61037 L .55557 .61063 L F
.398 .582 .915 r
.55557 .61063 m .55476 .61064 L .55455 .61025 L F
.358 .733 .988 r
.57274 .62892 m .57189 .62997 L .57078 .62856 L F
.57274 .62892 m .57396 .62981 L .57189 .62997 L F
.014 .015 .511 r
.21827 .57122 m .2169 .57019 L .21795 .5688 L F
.21827 .57122 m .21721 .57266 L .2169 .57019 L F
.54 .23 .391 r
.40301 .62446 m .40195 .62713 L .39954 .62724 L F
.45 .126 .325 r
.40527 .62412 m .40195 .62713 L .40301 .62446 L F
.385 .174 .466 r
.33903 .6073 m .33872 .6098 L .33678 .61042 L F
.441 .311 .607 r
.33872 .6098 m .33886 .61238 L .33678 .61042 L F
.281 .294 .696 r
.33678 .61042 m .33886 .61238 L .3375 .6129 L F
0 0 .022 r
.59632 .64655 m .59544 .6493 L .59693 .64694 L F
0 .131 .66 r
.57373 .66463 m .57452 .66352 L .57279 .66137 L F
.091 .33 .805 r
.57373 .66463 m .57497 .66511 L .57452 .66352 L F
0 0 .474 r
.47213 .70218 m .47247 .70415 L .47138 .70524 L F
.533 .883 .648 r
.47138 .70524 m .47247 .70415 L .46944 .70654 L F
.207 0 .104 r
.49482 .62403 m .4928 .62487 L .49176 .62641 L F
.981 .711 .438 r
.53861 .71113 m .5379 .7133 L .5374 .71052 L F
.633 .545 .737 r
.53722 .70807 m .53861 .71113 L .5402 .70943 L F
.481 0 0 r
.5638 .62523 m .56451 .62535 L .56287 .6246 L F
.476 0 0 r
.5638 .62523 m .5669 .62623 L .56451 .62535 L F
.775 .718 .799 r
.43134 .70135 m .43369 .6992 L .43156 .69985 L F
.632 .649 .848 r
.43134 .70135 m .43487 .70246 L .43369 .6992 L F
.85 .925 .88 r
.73391 .51169 m .73757 .51002 L .73622 .50873 L F
.456 .723 .983 r
.73757 .51002 m .73875 .50883 L .73622 .50873 L F
.457 .023 .126 r
.38277 .62091 m .38522 .62077 L .3866 .61897 L F
.444 .046 .19 r
.38522 .62077 m .38879 .61849 L .3866 .61897 L F
.636 .723 .91 r
.74249 .50852 m .74313 .50968 L .74603 .50888 L F
.793 .691 .753 r
.74344 .51188 m .74603 .50888 L .74313 .50968 L F
.54 .142 .235 r
.49784 .6685 m .49861 .6674 L .49815 .66863 L F
.501 .283 .515 r
.49854 .66776 m .49784 .6685 L .49784 .66945 L F
.49784 .6685 m .49617 .67027 L .49784 .66945 L F
.54 .142 .235 r
.49607 .66781 m .49783 .66753 L .49784 .6685 L F
.49783 .66753 m .49861 .6674 L .49784 .6685 L F
.501 .283 .515 r
.49784 .6685 m .49607 .66781 L .49617 .67027 L F
.54 .142 .235 r
.49607 .66781 m .49815 .66863 L .49784 .66945 L F
.501 .283 .515 r
.49854 .66776 m .49607 .66781 L .49784 .6685 L F
.249 0 0 r
.49854 .66776 m .49861 .6674 L .49607 .66781 L F
.54 .142 .235 r
.49607 .66781 m .49784 .66945 L .49617 .67027 L F
.79 .7 .766 r
.2821 .82377 m .28138 .82268 L .28183 .82287 L F
.2821 .82377 m .2785 .82573 L .28138 .82268 L F
.578 .274 .416 r
.2821 .82377 m .28087 .82615 L .2785 .82573 L F
.292 .487 .877 r
.28322 .82293 m .28412 .82475 L .28183 .82287 L F
.414 .565 .895 r
.28322 .82293 m .2821 .82377 L .28183 .82287 L F
.28322 .82293 m .28412 .82475 L .2821 .82377 L F
.297 0 0 r
.28412 .82475 m .28087 .82615 L .2821 .82377 L F
.207 .22 .653 r
.80504 .50348 m .80691 .50524 L .80525 .50677 L F
0 0 .281 r
.80525 .50677 m .8064 .50731 L .80533 .5093 L F
.80525 .50677 m .80691 .50524 L .8064 .50731 L F
.824 .533 .497 r
.59905 .581 m .60228 .58371 L .6008 .58108 L F
.989 .751 .482 r
.5975 .62707 m .59858 .63037 L .59739 .62947 L F
.922 .885 .779 r
.59739 .62947 m .59858 .63037 L .59684 .63346 L F
.691 .575 .72 r
.43369 .6992 m .43487 .70246 L .43717 .69952 L F
0 .189 .638 r
.44971 .70765 m .44617 .70515 L .44838 .70751 L F
.702 .332 .344 r
.47154 .71266 m .47259 .71085 L .4691 .71073 L F
.746 .385 .369 r
.47154 .71266 m .475 .71325 L .47259 .71085 L F
.795 .51 .505 r
.48792 .71373 m .49105 .71596 L .49241 .71456 L F
.834 .531 .476 r
.59581 .58026 m .59869 .57883 L .59578 .57784 L F
.59581 .58026 m .59905 .581 L .59869 .57883 L F
.709 .896 .964 r
.73057 .50553 m .72715 .50575 L .72942 .50364 L F
.512 .665 .931 r
.73145 .50312 m .73057 .50553 L .72942 .50364 L F
.73145 .50312 m .73264 .5052 L .73057 .50553 L F
.015 0 .029 r
.49784 .66945 m .49861 .6674 L .50018 .66685 L F
0 0 0 r
.50018 .66685 m .49861 .6674 L .49854 .66776 L F
.657 .418 .546 r
.54007 .70826 m .54321 .70803 L .5432 .70518 L F
.441 .229 .493 r
.5432 .70518 m .54536 .70471 L .54551 .70227 L F
.478 .337 .611 r
.54536 .70471 m .54512 .70687 L .5432 .70518 L F
.548 .332 .538 r
.5432 .70518 m .54512 .70687 L .54321 .70803 L F
.441 .229 .493 r
.5432 .70518 m .54536 .70471 L .54551 .70227 L F
.478 .337 .611 r
.54536 .70471 m .54512 .70687 L .5432 .70518 L F
.548 .332 .538 r
.54321 .70803 m .54512 .70687 L .5432 .70518 L F
.5432 .70518 m .54512 .70687 L .54321 .70803 L F
.694 .821 .944 r
.35544 .62371 m .35109 .6239 L .35376 .62267 L F
0 .261 .652 r
.35376 .62267 m .35694 .62439 L .35544 .62371 L F
0 0 0 r
.60375 .66762 m .60278 .66939 L .601 .67055 L F
.089 0 0 r
.60536 .6669 m .60592 .66712 L .60375 .66762 L F
.083 0 0 r
.60375 .66762 m .60468 .66847 L .60278 .66939 L F
.60375 .66762 m .60592 .66712 L .60468 .66847 L F
.717 .317 .288 r
.34185 .64257 m .3383 .64126 L .34065 .64411 L F
.446 0 0 r
.33872 .5821 m .34081 .5829 L .34209 .58216 L F
.059 .624 .729 r
.34081 .5829 m .34453 .58272 L .34209 .58216 L F
.698 .341 .368 r
.47872 .71548 m .48196 .71389 L .47835 .71383 L F
.47872 .71548 m .48302 .71596 L .48196 .71389 L F
.726 .351 .341 r
.48302 .71596 m .48471 .71634 L .48196 .71389 L F
.294 0 0 r
.51254 .68833 m .5113 .68871 L .50816 .68799 L F
.708 .306 .283 r
.51486 .68782 m .5113 .68871 L .51254 .68833 L F
.356 .417 .788 r
.49561 .64135 m .49791 .64073 L .49506 .63866 L F
.296 .088 .418 r
.49561 .64135 m .49754 .64314 L .49791 .64073 L F
.49561 .64135 m .49594 .64401 L .49754 .64314 L F
.386 0 0 r
.56708 .60423 m .56809 .6049 L .56708 .60408 L F
.56708 .60423 m .5688 .6052 L .56809 .6049 L F
.557 .415 .643 r
.4864 .67872 m .48857 .67854 L .48858 .67617 L F
.646 .62 .809 r
.35109 .6239 m .34882 .6249 L .34738 .62165 L F
.679 .72 .204 r
.79129 .52628 m .79076 .52805 L .78943 .52978 L F
.79129 .52628 m .79139 .52596 L .79076 .52805 L F
.731 .74 .859 r
.79129 .52628 m .79303 .52284 L .79139 .52596 L F
.79129 .52628 m .79434 .5246 L .79303 .52284 L F
0 0 0 r
.52418 .68297 m .52085 .68483 L .52292 .68362 L F
.402 .181 .461 r
.34104 .60666 m .33872 .6098 L .33903 .6073 L F
.806 .836 .874 r
.79522 .50458 m .79617 .50635 L .79729 .50356 L F
.583 .577 .812 r
.79617 .50635 m .7992 .50776 L .79729 .50356 L F
.769 .678 .762 r
.53178 .7101 m .5291 .71319 L .5298 .71133 L F
0 0 0 r
.5298 .71133 m .53021 .71193 L .53178 .7101 L F
.5298 .71133 m .5291 .71319 L .53021 .71193 L F
.76 .669 .761 r
.74309 .4976 m .7442 .50101 L .7466 .49815 L F
.793 .691 .753 r
.74344 .51188 m .74671 .51251 L .74603 .50888 L F
.008 .568 .808 r
.74344 .51188 m .74561 .51211 L .74671 .51251 L F
.211 .279 .716 r
.74671 .51251 m .74814 .5114 L .74603 .50888 L F
.525 .909 .939 r
.74561 .51211 m .74814 .5114 L .74671 .51251 L F
.861 .76 .75 r
.54955 .6034 m .54774 .60669 L .55072 .60693 L F
.866 .741 .723 r
.54774 .60669 m .54893 .60999 L .55072 .60693 L F
.604 .725 .93 r
.79988 .48496 m .79809 .4871 L .79741 .48562 L F
.79988 .48496 m .80055 .48655 L .79809 .4871 L F
.597 .707 .921 r
.41327 .59035 m .40995 .58929 L .41179 .58888 L F
.677 .776 .925 r
.41562 .58933 m .41327 .59035 L .41179 .58888 L F
.227 .566 .938 r
.45578 .69788 m .45531 .69912 L .45403 .69542 L F
.45578 .69788 m .45648 .69897 L .45531 .69912 L F
.411 .124 .363 r
.45118 .67039 m .45339 .66988 L .45397 .66723 L F
.366 .066 .316 r
.45339 .66988 m .45622 .66663 L .45397 .66723 L F
.095 0 0 r
.47832 .68259 m .4749 .68403 L .47495 .6816 L F
.47832 .68259 m .4783 .68343 L .4749 .68403 L F
.166 0 0 r
.47898 .68325 m .4783 .68352 L .47832 .68259 L F
.809 .877 .895 r
.47825 .68202 m .47615 .68326 L .4788 .68325 L F
.47895 .6832 m .4788 .68325 L .47898 .68325 L F
.166 0 0 r
.47898 .68325 m .47832 .68259 L .47853 .68252 L F
.47988 .68253 m .47853 .68252 L .48075 .68183 L F
.47898 .68325 m .47853 .68252 L .47988 .68253 L F
.998 .804 .515 r
.47985 .68101 m .48075 .68183 L .48103 .67905 L F
.099 .133 .609 r
.48081 .68035 m .48121 .68254 L .47985 .68101 L F
.48121 .68254 m .48126 .6828 L .48105 .68254 L F
.48121 .68254 m .48105 .68254 L .47985 .68101 L F
.809 .877 .895 r
.47825 .68202 m .4788 .68325 L .47895 .6832 L F
.536 .416 .663 r
.4777 .68391 m .4765 .6866 L .47436 .68609 L F
.47773 .68393 m .4765 .6866 L .4777 .68391 L F
.637 .308 .397 r
.47774 .68393 m .47898 .68325 L .47777 .68384 L F
.536 .416 .663 r
.4783 .68352 m .47693 .68586 L .47776 .68387 L F
.47693 .68586 m .4765 .6866 L .47776 .68387 L F
.47754 .68364 m .47436 .68609 L .4749 .68403 L F
.4777 .68391 m .47436 .68609 L .47754 .68364 L F
.637 .308 .397 r
.47523 .68531 m .47778 .68384 L .47561 .68446 L F
.47778 .68384 m .4788 .68325 L .47795 .68358 L F
.536 .416 .663 r
.47795 .68358 m .4777 .68391 L .47754 .68364 L F
.47776 .68387 m .4777 .68391 L .47795 .68358 L F
.637 .308 .397 r
.47778 .68384 m .47795 .68358 L .47561 .68446 L F
.536 .416 .663 r
.4783 .68352 m .47776 .68387 L .47795 .68358 L F
.762 .705 .799 r
.47975 .6859 m .47811 .68625 L .47861 .68472 L F
.47975 .6859 m .47798 .68407 L .47855 .68394 L F
.483 .225 .446 r
.47985 .68101 m .47898 .68325 L .48075 .68183 L F
.47985 .68101 m .48126 .6828 L .47898 .68325 L F
.637 .308 .397 r
.47777 .68384 m .47898 .68325 L .4788 .68325 L F
.762 .705 .799 r
.47975 .6859 m .4783 .68352 L .47898 .68325 L F
.539 .489 .749 r
.48126 .6828 m .47975 .6859 L .47898 .68325 L F
.458 .366 .664 r
.47862 .68572 m .47971 .68226 L .47917 .68299 L F
.47889 .68386 m .47917 .68299 L .47898 .68325 L F
.47862 .68572 m .47917 .68299 L .47889 .68386 L F
.762 .705 .799 r
.47861 .68472 m .4765 .6866 L .47798 .68407 L F
.47811 .68625 m .4765 .6866 L .47861 .68472 L F
.637 .308 .397 r
.47774 .68393 m .4788 .6845 L .47898 .68325 L F
.762 .705 .799 r
.47855 .68394 m .47798 .68407 L .4783 .68352 L F
.637 .308 .397 r
.47772 .68395 m .47796 .68407 L .47774 .68393 L F
.47796 .68407 m .4788 .6845 L .47798 .68407 L F
.47796 .68407 m .47798 .68407 L .47774 .68393 L F
.47523 .68531 m .47812 .68466 L .47772 .68395 L F
.47812 .68466 m .4788 .6845 L .47772 .68395 L F
.47523 .68531 m .47862 .68572 L .4788 .6845 L F
.536 .416 .663 r
.47776 .68387 m .47773 .68393 L .4777 .68391 L F
.637 .308 .397 r
.47523 .68531 m .47774 .68393 L .47777 .68384 L F
.095 0 0 r
.4783 .68343 m .4783 .68344 L .4778 .6836 L F
.4783 .68344 m .47795 .68358 L .4778 .6836 L F
.4783 .68343 m .4778 .6836 L .4749 .68403 L F
.637 .308 .397 r
.47561 .68446 m .4788 .68325 L .47615 .68326 L F
.095 0 0 r
.4783 .68344 m .4783 .68352 L .47795 .68358 L F
.495 .762 .99 r
.77177 .50888 m .77017 .51028 L .76939 .50855 L F
.77177 .50888 m .77293 .50988 L .77017 .51028 L F
.485 .185 .38 r
.58391 .58997 m .58456 .59184 L .58356 .59181 L F
.58391 .58997 m .58654 .5895 L .58456 .59184 L F
.268 .769 .878 r
.37535 .58429 m .37751 .58394 L .37904 .58405 L F
.096 .638 .846 r
.37984 .58381 m .37904 .58405 L .37751 .58394 L F
.37984 .58381 m .38117 .58414 L .37904 .58405 L F
.476 .259 .504 r
.50214 .64642 m .4998 .64708 L .49998 .64477 L F
.53 .24 .419 r
.50235 .64456 m .50214 .64642 L .49998 .64477 L F
.093 0 0 r
.38382 .59319 m .38209 .59398 L .3799 .5943 L F
.004 .581 .71 r
.38382 .59319 m .38454 .59318 L .38209 .59398 L F
.38382 .59319 m .38593 .59318 L .38454 .59318 L F
.584 .396 .592 r
.54536 .70471 m .54773 .70179 L .54551 .70227 L F
.54536 .70471 m .54773 .70179 L .54551 .70227 L F
.996 .837 .564 r
.77835 .51961 m .7794 .51824 L .78025 .5165 L F
.77835 .51961 m .7792 .52108 L .7794 .51824 L F
.537 .26 .443 r
.50561 .64156 m .50452 .64432 L .50235 .64456 L F
.575 .3 .462 r
.50796 .64357 m .50561 .64156 L .50819 .64144 L F
.50796 .64357 m .50452 .64432 L .50561 .64156 L F
.969 .873 .686 r
.72701 .48722 m .72514 .4883 L .72513 .48592 L F
.72701 .48722 m .72622 .48958 L .72514 .4883 L F
.64 .691 .882 r
.72755 .48405 m .72701 .48722 L .72513 .48592 L F
.506 .339 .588 r
.72896 .48874 m .72622 .48958 L .72701 .48722 L F
.675 .783 .931 r
.73603 .50601 m .73264 .5052 L .73506 .50277 L F
.633 .639 .839 r
.73898 .50275 m .73603 .50601 L .73506 .50277 L F
.314 0 .246 r
.4768 .64763 m .47394 .65019 L .476 .6494 L F
.251 0 .213 r
.4768 .64763 m .47778 .6485 L .47864 .64698 L F
.4768 .64763 m .476 .6494 L .47778 .6485 L F
.134 .465 .89 r
.20189 .54504 m .20332 .54542 L .20307 .54664 L F
.242 .584 .945 r
.20332 .54542 m .20483 .54693 L .20307 .54664 L F
.922 .885 .779 r
.59739 .62947 m .59684 .63346 L .59654 .63175 L F
.9 .954 .826 r
.5957 .63301 m .59684 .63346 L .59638 .63599 L F
.5957 .63301 m .59654 .63175 L .59684 .63346 L F
.41 .022 .189 r
.58675 .58071 m .58989 .57844 L .58739 .57856 L F
.443 .095 .278 r
.58424 .58109 m .58675 .58071 L .58739 .57856 L F
.283 0 .133 r
.39745 .62784 m .3964 .62938 L .39445 .6299 L F
.383 .007 .196 r
.39931 .62863 m .39745 .62784 L .39954 .62724 L F
.39931 .62863 m .3964 .62938 L .39745 .62784 L F
.572 .774 .974 r
.75723 .50868 m .755 .50928 L .75397 .50777 L F
.227 .048 .418 r
.21721 .57266 m .21689 .57502 L .21546 .57569 L F
.273 .153 .528 r
.21689 .57502 m .21549 .57812 L .21546 .57569 L F
.167 .282 .738 r
.78007 .51994 m .7792 .52108 L .77835 .51961 L F
.78007 .51994 m .77941 .52307 L .7792 .52108 L F
.855 .632 .599 r
.60369 .58959 m .60552 .59041 L .60385 .58717 L F
.903 .707 .627 r
.60369 .58959 m .60522 .59295 L .60552 .59041 L F
.24 0 0 r
.55576 .59372 m .55451 .59272 L .55337 .59425 L F
.55576 .59372 m .55685 .59224 L .55451 .59272 L F
.644 .66 .851 r
.79018 .50623 m .79156 .50233 L .78914 .50483 L F
.79018 .50623 m .79277 .50539 L .79156 .50233 L F
0 0 .208 r
.53174 .60993 m .53185 .60575 L .53105 .60681 L F
.53174 .60993 m .53219 .60897 L .53185 .60575 L F
.545 .037 0 r
.53174 .60993 m .53258 .61093 L .53219 .60897 L F
0 .267 .774 r
.53448 .61311 m .53472 .61296 L .53174 .60993 L F
.545 .037 0 r
.53174 .60993 m .53472 .61296 L .53258 .61093 L F
.342 .67 .975 r
.53125 .63281 m .52997 .63391 L .52908 .63319 L F
.53125 .63281 m .53264 .634 L .52997 .63391 L F
.525 .499 .769 r
.50013 .6591 m .50198 .65925 L .50251 .65881 L F
.312 0 0 r
.38654 .6326 m .38738 .63386 L .38501 .63435 L F
.38654 .6326 m .38896 .63233 L .38738 .63386 L F
.796 .951 .92 r
.55717 .5973 m .55506 .59801 L .55486 .5984 L F
.24 .687 .955 r
.55463 .59882 m .55486 .5984 L .5523 .59822 L F
0 0 0 r
.55271 .59881 m .5523 .59822 L .55486 .5984 L F
.796 .951 .92 r
.55506 .59801 m .55271 .59881 L .55486 .5984 L F
.24 .687 .955 r
.55556 .59906 m .55486 .5984 L .55463 .59882 L F
.701 .762 .899 r
.55603 .59849 m .55486 .5984 L .55556 .59906 L F
.88 .918 .847 r
.74053 .47408 m .7415 .47508 L .74391 .47222 L F
.47 .815 .998 r
.24227 .75053 m .2446 .75113 L .24136 .75102 L F
.24227 .75053 m .2446 .75113 L .24136 .75102 L F
.432 .776 .997 r
.24677 .75092 m .24509 .74999 L .2446 .75113 L F
.2446 .75113 m .24509 .74999 L .24677 .75092 L F
.24677 .75092 m .24509 .74999 L .2446 .75113 L F
.669 .726 .892 r
.4949 .6923 m .49546 .69358 L .49232 .69319 L F
.623 .422 .59 r
.49514 .69583 m .49232 .69319 L .49546 .69358 L F
.616 .697 .902 r
.49739 .69185 m .49546 .69358 L .4949 .6923 L F
.138 0 .113 r
.49176 .62641 m .49005 .62732 L .48932 .62937 L F
.69 .76 .906 r
.74309 .4976 m .7466 .49815 L .74553 .49645 L F
.93 .815 .711 r
.74553 .49645 m .7466 .49815 L .74719 .49488 L F
.723 .656 .783 r
.43717 .69952 m .43999 .6991 L .43882 .69721 L F
.382 .359 .709 r
.43717 .69952 m .4393 .70157 L .43999 .6991 L F
.206 .401 .834 r
.43882 .69721 m .43999 .6991 L .4411 .69884 L F
.764 .678 .767 r
.4393 .70157 m .4411 .69884 L .43999 .6991 L F
.903 .707 .627 r
.60369 .58959 m .60323 .59236 L .60522 .59295 L F
.924 .679 .548 r
.60322 .59477 m .60522 .59295 L .60323 .59236 L F
.60322 .59477 m .60507 .59536 L .60522 .59295 L F
.487 .325 .587 r
.30175 .60113 m .30388 .60087 L .30379 .59844 L F
.43 .328 .637 r
.30175 .60113 m .30385 .60324 L .30388 .60087 L F
.30175 .60113 m .30187 .60474 L .30385 .60324 L F
.502 .529 .817 r
.58089 .67295 m .58118 .67464 L .58303 .67258 L F
.574 .421 .636 r
.58118 .67464 m .58353 .67434 L .58303 .67258 L F
.58118 .67464 m .5811 .67563 L .58353 .67434 L F
.526 .167 .3 r
.57575 .58611 m .57362 .58478 L .57326 .58626 L F
.57575 .58611 m .57673 .58395 L .57362 .58478 L F
0 0 .387 r
.57078 .65582 m .57166 .65924 L .57154 .65802 L F
0 .181 .702 r
.57279 .66137 m .57154 .65802 L .57166 .65924 L F
.651 .327 .41 r
.80386 .51286 m .8035 .51454 L .80148 .51343 L F
.776 .684 .762 r
.80615 .5117 m .8035 .51454 L .80386 .51286 L F
.359 .295 .648 r
.43802 .69074 m .43956 .69043 L .43951 .68708 L F
.492 .31 .562 r
.43802 .69074 m .44015 .69287 L .43956 .69043 L F
.43802 .69074 m .43802 .69321 L .44015 .69287 L F
.49 .464 .755 r
.59334 .64739 m .59108 .64903 L .59024 .64724 L F
.804 .511 .493 r
.60547 .59731 m .6088 .5958 L .60507 .59536 L F
.60547 .59731 m .60889 .59806 L .6088 .5958 L F
.129 0 0 r
.3525 .59954 m .35203 .59857 L .35424 .59787 L F
.3525 .59954 m .35037 .60012 L .35203 .59857 L F
.681 .979 .873 r
.7889 .52948 m .78943 .52978 L .79076 .52805 L F
.2 0 0 r
.45158 .71027 m .45079 .71016 L .44971 .70765 L F
.45158 .71027 m .45358 .71075 L .45079 .71016 L F
0 .218 .733 r
.801 .50956 m .80142 .50505 L .7992 .50776 L F
.801 .50956 m .80131 .50774 L .80142 .50505 L F
.801 .50956 m .80194 .51007 L .80131 .50774 L F
.968 .769 .582 r
.31153 .63856 m .31145 .64206 L .30962 .64034 L F
.31153 .63856 m .31127 .63883 L .31348 .63812 L F
.31153 .63856 m .30962 .64034 L .31127 .63883 L F
.484 .149 .322 r
.76171 .48688 m .76432 .48776 L .76559 .4849 L F
.582 .4 .6 r
.76559 .4849 m .76746 .48549 L .76737 .48358 L F
.489 .113 .253 r
.76432 .48776 m .76746 .48549 L .76559 .4849 L F
0 .282 .771 r
.55875 .61887 m .56118 .62053 L .56117 .62129 L F
0 0 .48 r
.56231 .62266 m .56117 .62129 L .56118 .62053 L F
.56231 .62266 m .56287 .6246 L .56117 .62129 L F
.459 .083 .239 r
.31044 .59265 m .31254 .59294 L .31422 .59004 L F
.262 0 .127 r
.31422 .59004 m .31463 .59225 L .31644 .5896 L F
.31422 .59004 m .31254 .59294 L .31463 .59225 L F
.39 .022 .214 r
.56761 .58931 m .57091 .58662 L .56846 .5869 L F
.651 .203 .175 r
.49714 .62315 m .50075 .62231 L .49738 .62185 L F
.49714 .62315 m .49957 .6237 L .50075 .62231 L F
.692 .254 .204 r
.50075 .62231 m .49957 .6237 L .50301 .62417 L F
.7 .202 .055 r
.50075 .62231 m .50301 .62417 L .50441 .62403 L F
.479 .28 .531 r
.47409 .66742 m .472 .66783 L .47431 .66481 L F
.978 .724 .481 r
.58882 .59162 m .59017 .59008 L .59012 .59245 L F
.718 .292 .237 r
.58654 .5895 m .59017 .59008 L .58882 .59162 L F
.694 .359 .404 r
.79156 .50233 m .79269 .49995 L .78959 .50032 L F
.66 .566 .738 r
.79269 .49995 m .79496 .50089 L .79378 .4972 L F
.674 .169 .035 r
.7941 .50194 m .79269 .49995 L .79156 .50233 L F
.7941 .50194 m .79496 .50089 L .79269 .49995 L F
.821 .886 .891 r
.78838 .52504 m .78619 .52742 L .78501 .52622 L F
.959 .859 .698 r
.78619 .52742 m .78552 .52911 L .78501 .52622 L F
.145 .612 .926 r
.28138 .82268 m .28322 .82293 L .28183 .82287 L F
.92 .707 .598 r
.60228 .58371 m .60202 .5865 L .60385 .58717 L F
.95 .723 .56 r
.60197 .58862 m .60385 .58717 L .60202 .5865 L F
.60197 .58862 m .60369 .58959 L .60385 .58717 L F
.386 .375 .725 r
.80056 .51077 m .80266 .51063 L .80194 .51007 L F
.474 .459 .761 r
.80148 .51343 m .80266 .51063 L .80056 .51077 L F
.48 .235 .465 r
.58176 .58386 m .58424 .58109 L .58209 .58168 L F
.026 .065 .566 r
.56682 .64489 m .56795 .64683 L .56786 .64355 L F
.325 0 0 r
.35047 .58244 m .35255 .58244 L .3543 .58119 L F
.469 0 0 r
.35255 .58244 m .35542 .5819 L .3543 .58119 L F
0 0 0 r
.35542 .5819 m .35495 .58272 L .3558 .58227 L F
.419 0 0 r
.35507 .58156 m .35542 .5819 L .35762 .58278 L F
0 0 0 r
.35542 .5819 m .35702 .58162 L .35867 .58234 L F
.35542 .5819 m .3558 .58227 L .35702 .58162 L F
.419 0 0 r
.3543 .58119 m .35542 .5819 L .35507 .58156 L F
.719 .399 .437 r
.5126 .64949 m .51538 .65161 L .5161 .64707 L F
.5126 .64949 m .51222 .65246 L .51538 .65161 L F
.492 0 0 r
.33796 .64168 m .33593 .64124 L .33411 .64033 L F
.29 .763 .936 r
.33796 .64168 m .3383 .64126 L .33593 .64124 L F
.523 .174 .317 r
.40738 .60947 m .40973 .60936 L .41068 .60708 L F
.374 .22 .541 r
.41068 .60708 m .4123 .60643 L .41256 .60407 L F
.6 .356 .519 r
.40973 .60936 m .4123 .60643 L .41068 .60708 L F
.418 .066 .258 r
.4745 .67918 m .47329 .68145 L .47078 .68195 L F
.763 .443 .445 r
.4745 .67918 m .47495 .6816 L .47329 .68145 L F
.795 .51 .505 r
.48792 .71373 m .48799 .716 L .49105 .71596 L F
.772 .878 .455 r
.61129 .65934 m .61032 .6607 L .61023 .66125 L F
.839 .89 .465 r
.6116 .6575 m .61032 .6607 L .61129 .65934 L F
.367 .427 .791 r
.80671 .49089 m .80512 .49276 L .80391 .4893 L F
.412 .493 .833 r
.80671 .49089 m .80834 .49417 L .80512 .49276 L F
.093 .612 .883 r
.53623 .63475 m .53863 .63514 L .53999 .63571 L F
.417 0 0 r
.53863 .63514 m .54252 .63709 L .53999 .63571 L F
.22 0 .255 r
.52746 .65256 m .52964 .6527 L .5304 .64979 L F
.245 .051 .407 r
.52787 .65323 m .52964 .6527 L .52746 .65256 L F
0 0 .279 r
.58007 .6466 m .57874 .64995 L .58208 .64698 L F
.348 .46 .832 r
.74519 .51953 m .74555 .52139 L .74701 .51978 L F
.509 .712 .963 r
.74555 .52139 m .74794 .52111 L .74701 .51978 L F
0 .168 .616 r
.74173 .51901 m .74097 .5184 L .74074 .51825 L F
.352 .682 .979 r
.74173 .51901 m .74392 .51814 L .74097 .5184 L F
.74173 .51901 m .74519 .51953 L .74392 .51814 L F
.88 .918 .847 r
.74053 .47408 m .74391 .47222 L .74297 .47112 L F
.534 .239 .413 r
.51663 .65351 m .51658 .65538 L .51377 .65525 L F
.6 .292 .42 r
.51663 .65351 m .51891 .65534 L .51658 .65538 L F
.563 .307 .485 r
.51891 .65319 m .51891 .65534 L .51663 .65351 L F
.111 .21 .688 r
.40859 .59836 m .40957 .602 L .41049 .60049 L F
.334 .508 .88 r
.40957 .602 m .41256 .60407 L .41049 .60049 L F
.749 .681 .785 r
.55707 .6066 m .5591 .60388 L .55705 .60461 L F
.56 .368 .577 r
.30532 .59285 m .30793 .59482 L .30826 .59268 L F
.30532 .59285 m .30553 .59529 L .30793 .59482 L F
0 .245 .755 r
.57497 .66511 m .57629 .6678 L .57668 .66685 L F
0 0 .377 r
.57708 .67012 m .57668 .66685 L .57629 .6678 L F
.258 .768 .812 r
.36016 .59698 m .35864 .59709 L .35644 .59759 L F
.249 0 0 r
.35864 .59709 m .35815 .59733 L .35644 .59759 L F
.35815 .59733 m .35468 .59899 L .35644 .59759 L F
.228 .743 .864 r
.35477 .59785 m .35644 .59759 L .35424 .59787 L F
.35755 .59775 m .35644 .59759 L .35477 .59785 L F
.258 .768 .812 r
.36016 .59698 m .35644 .59759 L .35755 .59775 L F
0 0 .473 r
.56455 .6393 m .56548 .64034 L .56345 .63815 L F
.56455 .6393 m .56658 .64175 L .56548 .64034 L F
.227 .714 .927 r
.47597 .6651 m .47574 .66574 L .47543 .66452 L F
0 0 0 r
.47542 .66452 m .47505 .66439 L .4762 .66376 L F
.717 .753 .247 r
.47541 .66427 m .47593 .66271 L .47602 .66211 L F
.955 .777 .622 r
.47498 .66278 m .47539 .66437 L .4753 .66464 L F
.717 .753 .247 r
.4753 .66464 m .47538 .66439 L .47539 .66437 L F
.955 .777 .622 r
.47539 .66437 m .47574 .66574 L .4753 .66464 L F
.717 .753 .247 r
.4753 .66464 m .47539 .66437 L .47541 .66427 L F
.47538 .66439 m .47593 .66271 L .47541 .66427 L F
.227 .714 .927 r
.47578 .66465 m .47543 .66452 L .47539 .66437 L F
.47541 .66427 m .47539 .66437 L .47498 .66278 L F
.717 .753 .247 r
.4753 .66464 m .47541 .66427 L .47498 .66278 L F
.47541 .66427 m .47602 .66211 L .47498 .66278 L F
.227 .714 .927 r
.47547 .66393 m .47541 .66427 L .47498 .66278 L F
.832 .681 .696 r
.4762 .66376 m .47593 .66271 L .4753 .66464 L F
.227 .714 .927 r
.47578 .66465 m .47539 .66437 L .47547 .66393 L F
.47597 .6651 m .47543 .66452 L .47578 .66465 L F
0 0 0 r
.4753 .66464 m .47431 .66481 L .47505 .66439 L F
.4753 .66464 m .47505 .66439 L .47542 .66452 L F
0 0 .232 r
.47409 .66742 m .47431 .66481 L .4753 .66464 L F
.832 .725 .746 r
.61373 .61851 m .61464 .61658 L .61262 .61532 L F
.584 .158 .2 r
.57826 .58584 m .57673 .58395 L .57575 .58611 L F
.57826 .58584 m .5793 .58418 L .57673 .58395 L F
.413 .547 .881 r
.30504 .61663 m .30588 .61477 L .30443 .61486 L F
.30504 .61663 m .30716 .61772 L .30588 .61477 L F
.12 .49 .902 r
.35867 .58234 m .35762 .58278 L .35542 .5819 L F
.35867 .58234 m .35992 .58376 L .35762 .58278 L F
.425 0 0 r
.55564 .66977 m .5504 .67064 L .55299 .67123 L F
.565 .312 .491 r
.43237 .6102 m .43215 .61236 L .42975 .61261 L F
.65 .517 .688 r
.4346 .60721 m .43495 .61008 L .43237 .6102 L F
.653 .409 .537 r
.43495 .61008 m .43215 .61236 L .43237 .6102 L F
.167 .282 .738 r
.78007 .51994 m .78086 .52344 L .77941 .52307 L F
.384 .456 .811 r
.78236 .52633 m .77941 .52307 L .78086 .52344 L F
.448 .132 .336 r
.49749 .64761 m .49554 .64999 L .49477 .65005 L F
.568 .276 .432 r
.49973 .6492 m .49749 .64761 L .4998 .64708 L F
.49973 .6492 m .49554 .64999 L .49749 .64761 L F
.138 0 0 r
.55929 .59203 m .56154 .59142 L .56281 .59 L F
.294 0 0 r
.56154 .59142 m .56515 .58945 L .56281 .59 L F
.892 .882 .817 r
.59637 .60938 m .59765 .61044 L .59547 .61305 L F
.977 .68 .371 r
.59614 .60685 m .59765 .61044 L .59637 .60938 L F
.076 0 0 r
.36678 .63909 m .36499 .64005 L .36262 .64049 L F
.254 0 0 r
.36904 .63873 m .36499 .64005 L .36678 .63909 L F
0 0 .125 r
.61307 .64663 m .61279 .64904 L .61206 .65042 L F
0 0 .073 r
.61279 .64904 m .61195 .65287 L .61206 .65042 L F
.271 0 0 r
.53993 .65163 m .53895 .65274 L .53663 .653 L F
.403 .211 .503 r
.21114 .58704 m .21119 .58972 L .20924 .59013 L F
.361 .245 .584 r
.21119 .58972 m .2096 .59259 L .20924 .59013 L F
.706 .268 .208 r
.74186 .50325 m .74484 .50534 L .74363 .50377 L F
.621 .217 .255 r
.47748 .71912 m .4761 .7211 L .47381 .7194 L F
.789 .424 .366 r
.47748 .71912 m .47962 .72186 L .4761 .7211 L F
.674 .428 .542 r
.47976 .71936 m .47962 .72186 L .47748 .71912 L F
0 0 0 r
.56502 .59612 m .56402 .5959 L .56633 .59622 L F
.56502 .59612 m .56325 .59734 L .56402 .5959 L F
0 0 .279 r
.58007 .6466 m .57984 .64904 L .57874 .64995 L F
.957 .614 .28 r
.57984 .64904 m .58184 .65241 L .57874 .64995 L F
.411 .784 .993 r
.38336 .58397 m .38705 .5845 L .38484 .58476 L F
.773 .876 .922 r
.5261 .64244 m .5293 .64212 L .52811 .64105 L F
.716 .362 .377 r
.53169 .64144 m .52811 .64105 L .5293 .64212 L F
.573 .568 .81 r
.5293 .64212 m .53133 .64342 L .53169 .64144 L F
.952 .764 .612 r
.61229 .6175 m .61373 .61851 L .61262 .61532 L F
.951 .739 .581 r
.6126 .62046 m .61373 .61851 L .61229 .6175 L F
.6126 .62046 m .61341 .62109 L .61373 .61851 L F
.397 0 0 r
.54561 .6238 m .54148 .62176 L .54322 .62372 L F
.109 .647 .855 r
.54732 .62409 m .54561 .6238 L .54322 .62372 L F
.646 .181 .134 r
.75703 .4924 m .75487 .49315 L .75357 .49247 L F
.75487 .49315 m .75411 .49342 L .75383 .49293 L F
.75487 .49315 m .75383 .49293 L .75357 .49247 L F
.75703 .4924 m .75648 .49385 L .75384 .49351 L F
.411 .846 .943 r
.75957 .49347 m .75648 .49385 L .75703 .4924 L F
.552 .487 .736 r
.75656 .49351 m .75927 .49313 L .75749 .48975 L F
.75648 .49385 m .75722 .49366 L .75656 .49351 L F
.75722 .49366 m .75927 .49313 L .75656 .49351 L F
.75635 .49351 m .75749 .48975 L .75507 .49008 L F
.75648 .49385 m .75656 .49351 L .75635 .49351 L F
.75656 .49351 m .75749 .48975 L .75635 .49351 L F
.646 .181 .134 r
.75411 .49342 m .75384 .49351 L .75381 .4934 L F
.75411 .49342 m .75381 .4934 L .75357 .49247 L F
0 0 0 r
.45486 .69239 m .45347 .69347 L .45606 .69135 L F
.775 .692 .771 r
.45606 .69135 m .45347 .69347 L .45215 .69028 L F
.012 0 0 r
.45835 .69051 m .45486 .69239 L .45606 .69135 L F
.93 .815 .711 r
.74553 .49645 m .74719 .49488 L .74618 .49491 L F
.582 .489 .714 r
.52082 .6475 m .51969 .65099 L .51891 .65029 L F
.315 .32 .706 r
.57918 .64091 m .57954 .64524 L .5784 .64356 L F
.857 .432 .211 r
.57954 .64524 m .58007 .6466 L .5784 .64356 L F
.512 .76 .986 r
.78676 .48207 m .78522 .48364 L .78428 .48243 L F
.78676 .48207 m .78771 .48328 L .78522 .48364 L F
.888 .798 .755 r
.48541 .70216 m .48217 .70155 L .48371 .69991 L F
.497 0 0 r
.48541 .70216 m .48349 .70211 L .48217 .70155 L F
.033 .021 .508 r
.4864 .69844 m .48541 .70216 L .48371 .69991 L F
.4864 .69844 m .48673 .70128 L .48541 .70216 L F
.439 .875 .897 r
.48673 .70128 m .48349 .70211 L .48541 .70216 L F
.733 .699 .819 r
.72849 .48562 m .72695 .48856 L .72896 .48874 L F
.578 .808 .987 r
.72523 .4884 m .72622 .48958 L .72873 .48881 L F
.72695 .48856 m .72873 .48881 L .72896 .48874 L F
.72523 .4884 m .72873 .48881 L .72695 .48856 L F
.748 .719 .825 r
.72514 .4883 m .7269 .48865 L .72695 .48856 L F
.72514 .4883 m .72695 .48856 L .72849 .48562 L F
.733 .699 .819 r
.72695 .48856 m .7269 .48865 L .72896 .48874 L F
.578 .808 .987 r
.72514 .4883 m .72523 .4884 L .72896 .48874 L F
.791 .725 .791 r
.53211 .6727 m .53328 .6759 L .53583 .67232 L F
.477 .605 .9 r
.73162 .51173 m .73315 .50985 L .73158 .51051 L F
.73162 .51173 m .73391 .51169 L .73315 .50985 L F
.637 .388 .525 r
.44361 .67577 m .44608 .67562 L .44617 .6734 L F
.622 .412 .576 r
.44608 .67562 m .44855 .67305 L .44617 .6734 L F
.745 .632 .735 r
.32882 .64149 m .32991 .64382 L .33147 .64187 L F
.821 .732 .767 r
.77834 .50897 m .7774 .51138 L .77521 .50871 L F
.175 0 0 r
.54732 .62409 m .54907 .62443 L .54561 .6238 L F
.095 0 .316 r
.21328 .58387 m .21295 .58595 L .21114 .58704 L F
.372 .187 .497 r
.21265 .58892 m .21114 .58704 L .21295 .58595 L F
.21265 .58892 m .21119 .58972 L .21114 .58704 L F
.79 .565 .596 r
.48481 .65891 m .48116 .66097 L .48267 .65941 L F
.59 .027 0 r
.54608 .6662 m .54925 .6683 L .54578 .66659 L F
.848 .995 .753 r
.59304 .62324 m .59562 .62116 L .59399 .62401 L F
.875 .649 .593 r
.59562 .62116 m .59594 .62421 L .59399 .62401 L F
.443 .587 .901 r
.49897 .6789 m .50031 .67849 L .49676 .67763 L F
.572 .251 .386 r
.77001 .48533 m .77322 .48264 L .76995 .48323 L F
.77001 .48533 m .77267 .48534 L .77322 .48264 L F
.459 .102 .271 r
.77267 .48534 m .77573 .48268 L .77322 .48264 L F
.497 .269 .498 r
.45622 .66663 m .45858 .66431 L .45632 .6647 L F
.784 .535 .559 r
.4663 .68336 m .46486 .68159 L .46639 .68305 L F
.4663 .68336 m .46269 .6818 L .46486 .68159 L F
.4663 .68336 m .46273 .68423 L .46269 .6818 L F
.345 0 0 r
.46668 .68549 m .46273 .68423 L .4663 .68336 L F
.538 .624 .885 r
.46639 .68305 m .46702 .68368 L .4663 .68336 L F
.708 .527 .643 r
.46702 .68368 m .46668 .68549 L .4663 .68336 L F
.825 .817 .842 r
.74186 .50325 m .73898 .50275 L .74139 .50252 L F
0 .306 .79 r
.74349 .50383 m .74186 .50325 L .74139 .50252 L F
.74349 .50383 m .74484 .50534 L .74186 .50325 L F
.65 .201 .172 r
.75863 .4878 m .76085 .48828 L .76171 .48688 L F
.483 .023 .084 r
.76171 .48688 m .76085 .48828 L .76432 .48776 L F
.524 .898 .712 r
.54102 .59914 m .542 .59815 L .54289 .59803 L F
.54102 .59914 m .53861 .60021 L .542 .59815 L F
.04 .603 .794 r
.45819 .68764 m .45748 .68744 L .45447 .68728 L F
.45819 .68764 m .45748 .68744 L .45447 .68728 L F
.525 .317 .541 r
.46073 .68484 m .46058 .68757 L .45819 .68764 L F
.527 .331 .558 r
.46058 .68757 m .45835 .69051 L .45819 .68764 L F
.623 .422 .59 r
.49232 .69319 m .49514 .69583 L .4949 .6923 L F
.49232 .69319 m .49235 .69624 L .49514 .69583 L F
.49514 .69583 m .49235 .69624 L .49232 .69319 L F
.455 .673 .957 r
.31056 .63251 m .31375 .63366 L .31001 .6311 L F
0 .504 .754 r
.31529 .63211 m .31001 .6311 L .31375 .63366 L F
.428 .764 .996 r
.30768 .63174 m .31056 .63251 L .3085 .63158 L F
.455 .673 .957 r
.31056 .63251 m .31001 .6311 L .3085 .63158 L F
.52 .479 .751 r
.30414 .61298 m .30554 .60933 L .3033 .61057 L F
.30414 .61298 m .30615 .61239 L .30554 .60933 L F
.294 .116 .461 r
.30443 .61486 m .30615 .61239 L .30414 .61298 L F
.577 .459 .682 r
.48789 .67019 m .4855 .66968 L .48766 .66937 L F
.665 .115 0 r
.48839 .67191 m .48737 .67026 L .48599 .67246 L F
.48839 .67191 m .49 .67265 L .48943 .67213 L F
.48802 .67131 m .48943 .67213 L .48737 .67026 L F
.48839 .67191 m .48943 .67213 L .48858 .67163 L F
.774 .748 .829 r
.48772 .67398 m .49024 .67261 L .49007 .67251 L F
.48772 .67398 m .49038 .67231 L .49 .67265 L F
.686 .32 .346 r
.48737 .67026 m .49 .67265 L .48964 .67101 L F
.676 .393 .485 r
.48964 .67101 m .49038 .67231 L .49332 .67037 L F
.838 .428 .264 r
.48964 .67101 m .49 .67265 L .49038 .67231 L F
.703 .787 .916 r
.48599 .67246 m .48688 .6725 L .48839 .67191 L F
.48688 .6725 m .49 .67265 L .48839 .67191 L F
.599 .854 .992 r
.48839 .67191 m .49 .67265 L .49046 .67105 L F
.48839 .67191 m .49 .67265 L .49046 .67105 L F
.743 .402 .405 r
.49046 .67105 m .49021 .67119 L .48839 .67191 L F
.49021 .67119 m .48806 .6724 L .48839 .67191 L F
.703 .787 .916 r
.48599 .67246 m .48772 .67398 L .49 .67265 L F
.743 .402 .405 r
.48806 .6724 m .48727 .67284 L .48839 .67191 L F
.665 .115 0 r
.48839 .67191 m .48858 .67163 L .48802 .67131 L F
.774 .748 .829 r
.48772 .67398 m .48858 .67617 L .49024 .67261 L F
.49007 .67251 m .49024 .67261 L .49038 .67231 L F
.577 .459 .682 r
.48839 .67191 m .4872 .671 L .48789 .67019 L F
0 0 0 r
.4853 .67284 m .48592 .6725 L .48737 .67026 L F
.48592 .6725 m .48609 .6723 L .48737 .67026 L F
.577 .459 .682 r
.4872 .671 m .4855 .66968 L .48789 .67019 L F
0 0 0 r
.48592 .6725 m .48599 .67246 L .48609 .6723 L F
0 .421 .852 r
.4853 .67284 m .48772 .67398 L .48599 .67246 L F
.587 .768 .965 r
.76232 .5074 m .76085 .50933 L .75976 .50813 L F
.76232 .5074 m .76329 .50874 L .76085 .50933 L F
.407 .237 .535 r
.46269 .6818 m .46273 .68423 L .46073 .68484 L F
.407 .222 .514 r
.46256 .6865 m .46073 .68484 L .46273 .68423 L F
.46256 .6865 m .46058 .68757 L .46073 .68484 L F
.87 .679 .641 r
.59517 .59871 m .59469 .60116 L .5931 .59799 L F
.428 .652 .953 r
.24088 .7505 m .24227 .75053 L .24136 .75102 L F
.36 .808 .671 r
.24136 .75102 m .24227 .75053 L .24082 .75127 L F
.099 0 .053 r
.47152 .65306 m .46898 .65532 L .471 .65549 L F
.215 0 .273 r
.47394 .65019 m .47152 .65306 L .47309 .6522 L F
.307 .009 .284 r
.47152 .65306 m .47298 .65472 L .47309 .6522 L F
.47152 .65306 m .471 .65549 L .47298 .65472 L F
.539 .265 .447 r
.38879 .61849 m .39122 .61816 L .39168 .61609 L F
.495 .229 .44 r
.39122 .61816 m .39395 .6156 L .39168 .61609 L F
.545 .867 .995 r
.39069 .58442 m .38705 .5845 L .38933 .58414 L F
.234 .729 .915 r
.39157 .58393 m .39069 .58442 L .38933 .58414 L F
.39157 .58393 m .3929 .58432 L .39069 .58442 L F
.575 .4 .607 r
.72177 .49504 m .72393 .49513 L .7241 .49212 L F
.554 .265 .431 r
.72177 .49504 m .72478 .49665 L .72393 .49513 L F
.564 .346 .542 r
.76746 .48549 m .76995 .48323 L .76737 .48358 L F
.523 .652 .916 r
.41018 .58653 m .40995 .58929 L .40813 .58697 L F
.41018 .58653 m .41179 .58888 L .40995 .58929 L F
.62 .175 .171 r
.75283 .48795 m .75506 .4881 L .75571 .48668 L F
.53 .082 .133 r
.75571 .48668 m .75506 .4881 L .75863 .4878 L F
.58 .494 .723 r
.79496 .50089 m .79589 .49873 L .79378 .4972 L F
.79496 .50089 m .79751 .50029 L .79589 .49873 L F
.153 0 0 r
.79662 .50137 m .79496 .50089 L .7941 .50194 L F
.79662 .50137 m .79751 .50029 L .79496 .50089 L F
.581 .375 .567 r
.2785 .82573 m .28087 .82615 L .28138 .82268 L F
.524 .338 .571 r
.28087 .82615 m .28322 .82293 L .28138 .82268 L F
.495 .55 .842 r
.56957 .62603 m .56791 .62823 L .5669 .62623 L F
.56957 .62603 m .57078 .62856 L .56791 .62823 L F
.261 .709 .958 r
.35694 .62439 m .35906 .62442 L .3606 .62513 L F
.021 .594 .707 r
.36136 .62511 m .3606 .62513 L .35906 .62442 L F
.36136 .62511 m .36261 .62507 L .3606 .62513 L F
.332 0 .13 r
.34416 .6046 m .34326 .60609 L .34104 .60666 L F
.212 0 .176 r
.3459 .60355 m .34326 .60609 L .34416 .6046 L F
.746 .615 .714 r
.78554 .51652 m .78945 .51501 L .78587 .51533 L F
.78554 .51652 m .78732 .51858 L .78945 .51501 L F
.181 0 .12 r
.46898 .65532 m .46614 .65851 L .46818 .6579 L F
.321 0 .252 r
.471 .65549 m .46898 .65532 L .46818 .6579 L F
.355 0 0 r
.46902 .70109 m .47213 .70218 L .47073 .70154 L F
.262 0 .088 r
.39445 .6299 m .39556 .63121 L .39334 .6315 L F
.39445 .6299 m .3964 .62938 L .39556 .63121 L F
.582 .515 .745 r
.46867 .68182 m .46702 .68368 L .46639 .68305 L F
.46867 .68182 m .46941 .6836 L .46702 .68368 L F
.453 .206 .448 r
.46941 .6836 m .46668 .68549 L .46702 .68368 L F
.201 0 0 r
.34453 .58272 m .34668 .58286 L .34839 .58252 L F
0 0 0 r
.34668 .58286 m .35047 .58244 L .34839 .58252 L F
.89 .667 .593 r
.612 .60459 m .61032 .60129 L .61021 .60382 L F
.883 .694 .642 r
.61021 .60382 m .61165 .60725 L .612 .60459 L F
.597 .7 .915 r
.72638 .49968 m .72464 .50176 L .72525 .49884 L F
.586 .222 .318 r
.36031 .64102 m .35705 .64307 L .35819 .64151 L F
.484 .635 .921 r
.19968 .54262 m .19916 .54486 L .19765 .54331 L F
.19968 .54262 m .20189 .54504 L .19916 .54486 L F
.891 .804 .323 r
.61351 .6353 m .61396 .63305 L .61328 .63471 L F
.952 .783 .331 r
.61328 .63471 m .61396 .63305 L .61351 .6322 L F
.777 .598 .657 r
.59594 .62421 m .59853 .62502 L .5975 .62707 L F
.68 .445 .559 r
.59235 .57549 m .59578 .57784 L .59585 .57534 L F
.59235 .57549 m .59219 .57804 L .59578 .57784 L F
.296 .783 .902 r
.51675 .6676 m .51569 .6674 L .51336 .66776 L F
.599 .937 .947 r
.51776 .66629 m .51569 .6674 L .51675 .6676 L F
.522 .487 .759 r
.30243 .60716 m .3033 .61057 L .30554 .60933 L F
.497 .351 .613 r
.7815 .50903 m .77933 .51272 L .77834 .50897 L F
.7815 .50903 m .78176 .51225 L .77933 .51272 L F
.529 .492 .759 r
.78176 .51225 m .78278 .5136 L .77933 .51272 L F
.463 .41 .713 r
.53663 .66184 m .5391 .66402 L .53835 .6624 L F
0 0 .332 r
.45486 .69239 m .45403 .69542 L .45347 .69347 L F
0 0 .186 r
.80654 .5004 m .80639 .50283 L .80504 .50348 L F
.192 0 .072 r
.80639 .50283 m .80691 .50524 L .80504 .50348 L F
.258 0 .297 r
.47394 .65019 m .47531 .65176 L .476 .6494 L F
.47394 .65019 m .47309 .6522 L .47531 .65176 L F
.589 .778 .97 r
.76852 .50715 m .76676 .50919 L .76576 .50793 L F
.76852 .50715 m .76939 .50855 L .76676 .50919 L F
.45 .551 .867 r
.78269 .50124 m .78475 .49946 L .78213 .49989 L F
.78269 .50124 m .78539 .50238 L .78475 .49946 L F
.443 .797 .997 r
.79993 .52377 m .80173 .52264 L .79899 .52357 L F
.80173 .52264 m .79993 .52377 L .79899 .52357 L F
0 0 0 r
.8002 .5233 m .79899 .52357 L .80173 .52264 L F
.199 .719 .87 r
.79899 .52357 m .79993 .52377 L .79823 .52375 L F
.79899 .52357 m .79993 .52377 L .79649 .52372 L F
0 0 0 r
.79829 .52412 m .79899 .52357 L .8002 .5233 L F
.199 .719 .87 r
.79899 .52357 m .79823 .52375 L .79649 .52372 L F
.443 .797 .997 r
.79993 .52377 m .80257 .52345 L .80173 .52264 L F
.80173 .52264 m .80257 .52345 L .79993 .52377 L F
.553 .224 .364 r
.42668 .61348 m .42632 .61514 L .42393 .61526 L F
.608 .274 .379 r
.42947 .61477 m .42668 .61348 L .42975 .61261 L F
.42947 .61477 m .42632 .61514 L .42668 .61348 L F
.87 .945 .862 r
.78247 .5167 m .78587 .51533 L .78278 .5136 L F
.78247 .5167 m .78357 .51762 L .78587 .51533 L F
.553 .337 .541 r
.78357 .51762 m .78554 .51652 L .78587 .51533 L F
.297 0 0 r
.28412 .82475 m .28296 .82592 L .28087 .82615 L F
0 .03 .563 r
.28513 .82208 m .28745 .82455 L .28613 .8234 L F
.28745 .82455 m .2875 .8246 L .28613 .8234 L F
.202 0 .139 r
.28604 .82332 m .28613 .8234 L .28412 .82475 L F
.28673 .8228 m .28613 .8234 L .28604 .82332 L F
.114 0 0 r
.28507 .82527 m .28412 .82475 L .28613 .8234 L F
.28507 .82527 m .28296 .82592 L .28412 .82475 L F
.695 .798 .928 r
.54056 .70879 m .54321 .70803 L .5402 .70943 L F
.785 .583 .626 r
.59585 .57534 m .59578 .57784 L .59766 .57515 L F
.56 .309 .493 r
.50251 .65881 m .50508 .65868 L .50523 .65636 L F
.464 .231 .475 r
.50523 .65636 m .50733 .65808 L .50766 .65603 L F
.50523 .65636 m .50508 .65868 L .50733 .65808 L F
.279 0 .216 r
.49824 .6911 m .49981 .69047 L .50146 .69093 L F
0 0 0 r
.49857 .69106 m .50015 .69079 L .50106 .68973 L F
.49857 .69106 m .50152 .68918 L .49981 .69047 L F
.49936 .69055 m .50106 .68973 L .50152 .68918 L F
.49857 .69106 m .50106 .68973 L .49936 .69055 L F
.279 0 .216 r
.4977 .69113 m .49905 .69071 L .49824 .6911 L F
.49905 .69071 m .49981 .69047 L .49824 .6911 L F
.614 .352 .498 r
.50146 .69093 m .50054 .69307 L .49788 .69242 L F
.117 0 .397 r
.50146 .69093 m .5026 .69022 L .5029 .68753 L F
.709 .935 .961 r
.50146 .69093 m .49981 .69047 L .50152 .68918 L F
.117 0 .397 r
.5029 .68753 m .5026 .69022 L .50146 .69093 L F
.486 .76 .991 r
.50152 .68918 m .5026 .69022 L .50146 .69093 L F
.653 .548 .722 r
.5026 .69022 m .50054 .69307 L .50146 .69093 L F
.841 .986 .865 r
.74956 .4887 m .7513 .49181 L .75002 .4914 L F
.727 .32 .278 r
.75384 .49351 m .75002 .4914 L .7513 .49181 L F
.58 .046 0 r
.75357 .49247 m .75384 .49351 L .7513 .49181 L F
.113 0 0 r
.78249 .52918 m .78552 .52911 L .78508 .52928 L F
.235 .66 .959 r
.78552 .52911 m .7889 .52948 L .78803 .5286 L F
.78552 .52911 m .78803 .5286 L .78508 .52928 L F
.163 0 0 r
.37518 .63662 m .37346 .63785 L .37123 .63826 L F
.218 0 0 r
.37723 .63596 m .37346 .63785 L .37518 .63662 L F
.625 .427 .593 r
.53168 .66932 m .53211 .6727 L .5325 .67059 L F
.53168 .66932 m .53014 .67391 L .53211 .6727 L F
.827 .517 0 r
.55649 .6554 m .55708 .65821 L .5576 .65875 L F
0 0 .341 r
.55708 .65821 m .5579 .66157 L .5576 .65875 L F
.461 .252 .509 r
.43712 .60435 m .4346 .60721 L .43353 .60387 L F
.43712 .60435 m .43668 .60698 L .4346 .60721 L F
.636 .507 .689 r
.43803 .60926 m .4346 .60721 L .43668 .60698 L F
.43803 .60926 m .43495 .61008 L .4346 .60721 L F
.727 .738 .86 r
.54579 .63787 m .54351 .63904 L .54252 .63709 L F
.926 .865 .761 r
.72638 .49968 m .72532 .50281 L .72661 .50363 L F
.228 .241 .666 r
.72357 .50016 m .72532 .50281 L .72525 .49884 L F
0 0 .255 r
.61294 .64317 m .61248 .64173 L .61268 .64082 L F
.61294 .64317 m .61273 .64421 L .61248 .64173 L F
.475 .64 .928 r
.72764 .50969 m .73158 .51051 L .72927 .50783 L F
.858 .483 .336 r
.50301 .62417 m .50305 .62561 L .50441 .62403 L F
.653 .206 .176 r
.50441 .62403 m .50305 .62561 L .50688 .62581 L F
.497 .217 .419 r
.51377 .65525 m .51338 .65811 L .51102 .65852 L F
.603 .309 .443 r
.51687 .65755 m .51377 .65525 L .51658 .65538 L F
.51687 .65755 m .51338 .65811 L .51377 .65525 L F
.33 .04 .312 r
.54095 .65894 m .53835 .6624 L .54099 .66077 L F
0 0 .372 r
.54095 .65894 m .54256 .65458 L .54105 .65545 L F
.54095 .65894 m .5426 .65728 L .54256 .65458 L F
0 0 0 r
.50018 .66685 m .49977 .66442 L .50112 .66423 L F
.612 .261 .351 r
.50112 .66423 m .50192 .66524 L .50059 .66572 L F
.50112 .66423 m .50372 .66448 L .50299 .66658 L F
.666 .518 .674 r
.49977 .66442 m .50361 .66463 L .50198 .65925 L F
.157 0 .164 r
.50299 .66658 m .50372 .66448 L .50463 .66399 L F
.50547 .66373 m .50463 .66399 L .50577 .66339 L F
.50299 .66658 m .50463 .66399 L .50547 .66373 L F
.50299 .66658 m .50528 .66394 L .50513 .66614 L F
.50528 .66394 m .50577 .66339 L .50564 .66391 L F
.50528 .66394 m .50564 .66391 L .50513 .66614 L F
.58 .344 .523 r
.50791 .66316 m .50714 .66399 L .50696 .66391 L F
.50791 .66316 m .50696 .66391 L .50682 .66327 L F
.227 0 0 r
.50577 .66339 m .5087 .6616 L .50791 .66316 L F
.58 .344 .523 r
.50791 .66316 m .50799 .66481 L .50513 .66614 L F
.576 .378 .577 r
.51044 .66282 m .50799 .66481 L .50791 .66316 L F
.553 .168 .267 r
.51227 .66465 m .51117 .66282 L .51052 .66288 L F
.567 .173 .255 r
.51052 .66281 m .51117 .66282 L .51227 .66465 L F
.51127 .66282 m .51291 .66285 L .51272 .66339 L F
.625 .345 .473 r
.5133 .66065 m .51294 .66266 L .51119 .66277 L F
.51294 .66266 m .51291 .66285 L .51127 .66282 L F
.51126 .66281 m .51127 .66282 L .51117 .66282 L F
.51294 .66266 m .51127 .66282 L .51126 .66281 L F
.433 .418 .743 r
.51114 .66277 m .51126 .66281 L .51053 .66252 L F
.51126 .66281 m .51218 .66314 L .5112 .66277 L F
.51126 .66281 m .5112 .66277 L .51053 .66252 L F
.4 .05 .252 r
.5087 .6616 m .51059 .66252 L .51007 .6625 L F
.433 .418 .743 r
.51051 .66252 m .51053 .66252 L .51001 .66232 L F
.51114 .66277 m .51053 .66252 L .51051 .66252 L F
.4 .05 .252 r
.5087 .6616 m .51092 .66114 L .51059 .66252 L F
.553 .168 .267 r
.51052 .66288 m .51126 .66281 L .51045 .66252 L F
.4 .05 .252 r
.51007 .6625 m .51045 .66252 L .51044 .66275 L F
.553 .168 .267 r
.51044 .66279 m .51045 .66252 L .51001 .66236 L F
.51052 .66288 m .51045 .66252 L .51044 .66279 L F
.4 .05 .252 r
.51044 .66275 m .51059 .66252 L .51052 .66281 L F
.51045 .66252 m .51059 .66252 L .51044 .66275 L F
.625 .345 .473 r
.51085 .66255 m .51119 .66277 L .51052 .66281 L F
.5133 .66065 m .51119 .66277 L .51085 .66255 L F
.51294 .66266 m .51117 .66282 L .51052 .66281 L F
.51 .308 .542 r
.51102 .65852 m .5087 .6616 L .50865 .65889 L F
.51102 .65852 m .51092 .66114 L .5087 .6616 L F
.544 .338 .552 r
.51338 .65811 m .51092 .66114 L .51102 .65852 L F
.51338 .65811 m .5133 .66065 L .51092 .66114 L F
.625 .345 .473 r
.5133 .66065 m .51085 .66255 L .51092 .66114 L F
.51085 .66255 m .51052 .66281 L .51059 .66252 L F
.51085 .66255 m .51059 .66252 L .51092 .66114 L F
.433 .418 .743 r
.51004 .66202 m .51109 .66257 L .51029 .65877 L F
.51109 .66257 m .51218 .66314 L .51197 .66266 L F
.51109 .66257 m .51197 .66266 L .51029 .65877 L F
.51001 .66232 m .5112 .66277 L .51004 .66202 L F
.5112 .66277 m .51218 .66314 L .51004 .66202 L F
.51001 .66236 m .51114 .66277 L .51001 .66232 L F
.567 .173 .255 r
.51117 .66282 m .51127 .66282 L .51227 .66465 L F
.51127 .66282 m .51272 .66339 L .51227 .66465 L F
.553 .168 .267 r
.51227 .66465 m .51126 .66281 L .51117 .66282 L F
.51227 .66465 m .51218 .66314 L .51126 .66281 L F
.576 .378 .577 r
.51052 .66281 m .51048 .66284 L .51044 .66282 L F
.51048 .66284 m .50799 .66481 L .51044 .66282 L F
.51052 .66281 m .50968 .66449 L .50799 .66481 L F
.497 .179 .358 r
.50799 .66481 m .50968 .66449 L .50938 .66741 L F
.567 .173 .255 r
.51052 .66281 m .51227 .66465 L .50968 .66449 L F
.377 .083 .333 r
.50938 .66741 m .50968 .66449 L .51227 .66465 L F
.553 .168 .267 r
.51227 .66465 m .5105 .66286 L .50854 .66473 L F
.4 .05 .252 r
.5087 .6616 m .51042 .66274 L .50791 .66316 L F
.51042 .66274 m .51052 .66281 L .51044 .66282 L F
.51042 .66274 m .51044 .66282 L .50791 .66316 L F
.553 .168 .267 r
.51044 .66282 m .51001 .66236 L .50991 .66252 L F
.5105 .66286 m .51043 .66278 L .51044 .66282 L F
.51043 .66278 m .51001 .66236 L .51044 .66282 L F
.5105 .66286 m .50991 .66252 L .50854 .66473 L F
.267 .043 .376 r
.50733 .66574 m .50513 .66614 L .50736 .66621 L F
.482 .171 .362 r
.50513 .66614 m .50714 .6652 L .50712 .66577 L F
.493 .034 .091 r
.50744 .66611 m .50742 .66602 L .50736 .66621 L F
.50742 .66602 m .50733 .66574 L .50736 .66621 L F
.512 .163 .313 r
.50703 .66777 m .50736 .66621 L .50513 .66614 L F
.482 .171 .362 r
.50714 .6652 m .50751 .66628 L .50703 .66777 L F
.58 .344 .523 r
.50682 .66327 m .50696 .66391 L .50577 .66339 L F
.50714 .66399 m .50513 .66614 L .50564 .66391 L F
.50714 .66399 m .50564 .66391 L .50577 .66339 L F
.267 .043 .376 r
.50713 .66257 m .50513 .66614 L .50733 .66574 L F
.482 .171 .362 r
.50513 .66614 m .50712 .66577 L .50703 .66777 L F
.50714 .6652 m .50799 .66481 L .50751 .66628 L F
.493 .034 .091 r
.50742 .66602 m .50731 .66551 L .50733 .66574 L F
.50854 .66473 m .50713 .66257 L .50731 .66551 L F
.497 .179 .358 r
.50799 .66481 m .50938 .66741 L .50796 .66762 L F
.50751 .66628 m .50796 .66762 L .50703 .66777 L F
.50799 .66481 m .50796 .66762 L .50751 .66628 L F
.493 .034 .091 r
.50854 .66473 m .50731 .66551 L .50742 .66601 L F
.50745 .6661 m .50742 .66601 L .50744 .66611 L F
.50854 .66473 m .50742 .66601 L .50745 .6661 L F
.512 .432 .702 r
.50198 .65925 m .50357 .6638 L .50581 .66366 L F
.50357 .6638 m .50367 .66409 L .50478 .66386 L F
.50357 .6638 m .50478 .66386 L .50581 .66366 L F
.50367 .66409 m .50386 .66464 L .50524 .66394 L F
.50367 .66409 m .50524 .66394 L .50581 .66366 L F
.50198 .65925 m .50579 .66363 L .50476 .66026 L F
.50579 .66363 m .50581 .66366 L .5058 .66362 L F
.50579 .66363 m .5058 .66362 L .50476 .66026 L F
.666 .518 .674 r
.50361 .66463 m .50386 .66464 L .50383 .66455 L F
.50361 .66463 m .50383 .66455 L .50198 .65925 L F
.612 .261 .351 r
.50059 .66572 m .50299 .66658 L .50018 .66685 L F
.50192 .66524 m .50299 .66658 L .50059 .66572 L F
.847 .681 .676 r
.60889 .59806 m .61032 .60129 L .61083 .59897 L F
.63 .602 .802 r
.79729 .50356 m .7992 .50776 L .80142 .50505 L F
.475 .663 .944 r
.76926 .52168 m .77318 .52348 L .77214 .52234 L F
0 .134 .63 r
.77214 .52234 m .77318 .52348 L .77554 .5254 L F
.557 .587 .84 r
.77318 .52348 m .77704 .52592 L .77554 .5254 L F
.655 .714 .891 r
.79303 .52284 m .79434 .5246 L .79649 .52372 L F
.77 .304 .136 r
.74473 .4833 m .74822 .48564 L .74804 .48348 L F
0 0 0 r
.49329 .64468 m .49045 .64686 L .49054 .64462 L F
.316 0 0 r
.40154 .61218 m .40383 .61183 L .4053 .61019 L F
.518 .152 .284 r
.40383 .61183 m .40738 .60947 L .4053 .61019 L F
.26 0 0 r
.76304 .49234 m .76468 .49304 L .76217 .49342 L F
.76304 .49234 m .76561 .49198 L .76468 .49304 L F
.214 .478 .89 r
.21242 .54844 m .21209 .5501 L .21071 .54861 L F
.21242 .54844 m .21469 .55114 L .21209 .5501 L F
0 0 .557 r
.53448 .61311 m .53543 .61276 L .53598 .61201 L F
0 0 0 r
.53598 .61201 m .53472 .61296 L .53448 .61311 L F
.761 .389 .349 r
.32998 .63858 m .32953 .64059 L .3264 .6379 L F
.406 .447 .791 r
.3264 .6379 m .32953 .64059 L .32887 .63914 L F
.628 .229 .269 r
.32754 .63669 m .3264 .6379 L .32426 .63682 L F
.77 .417 .387 r
.32754 .63669 m .32998 .63858 L .3264 .6379 L F
.406 .447 .791 r
.3264 .6379 m .32887 .63914 L .32703 .63511 L F
.628 .229 .269 r
.32426 .63682 m .3264 .6379 L .32416 .63682 L F
.639 .587 .779 r
.53133 .64342 m .53411 .64094 L .53169 .64144 L F
.53133 .64342 m .53526 .64429 L .53411 .64094 L F
.549 .434 .675 r
.53133 .64342 m .53479 .64615 L .53526 .64429 L F
.53133 .64342 m .53246 .64732 L .53479 .64615 L F
.578 .364 .553 r
.48255 .71888 m .47962 .72186 L .47976 .71936 L F
.681 .861 .967 r
.77815 .50754 m .77834 .50897 L .77521 .50871 L F
.531 .75 .976 r
.78154 .5075 m .77834 .50897 L .77815 .50754 L F
.532 .77 .985 r
.78154 .5075 m .7815 .50903 L .77834 .50897 L F
.889 .835 .787 r
.49682 .68051 m .50031 .67849 L .49897 .6789 L F
.032 0 .318 r
.4804 .64074 m .47868 .64454 L .48065 .64392 L F
.425 .253 .542 r
.47868 .64454 m .48016 .64658 L .48065 .64392 L F
.47868 .64454 m .47864 .64698 L .48016 .64658 L F
.472 .406 .702 r
.21827 .57122 m .21689 .57502 L .21721 .57266 L F
.474 .459 .761 r
.80148 .51343 m .8035 .51454 L .80266 .51063 L F
.598 .844 .991 r
.36352 .58392 m .35992 .58376 L .36211 .58312 L F
.267 .724 .954 r
.36211 .58312 m .36578 .58371 L .36352 .58392 L F
.266 .682 .967 r
.54579 .63787 m .54909 .63809 L .54934 .63878 L F
.918 .871 .439 r
.54909 .63809 m .54839 .64044 L .54934 .63878 L F
.672 .627 .796 r
.78357 .51762 m .78732 .51858 L .78554 .51652 L F
.163 .444 .876 r
.21772 .55249 m .22001 .55366 L .21985 .55517 L F
.593 .53 .753 r
.42532 .59456 m .42285 .59528 L .42222 .5931 L F
.58 .379 .574 r
.59229 .6776 m .59476 .67793 L .59229 .67779 L F
.59226 .67533 m .59336 .67647 L .59229 .6776 L F
.59336 .67647 m .59476 .67793 L .59229 .6776 L F
.655 .298 .354 r
.59611 .6736 m .59302 .67683 L .59226 .67533 L F
.518 .821 .494 r
.59717 .67247 m .59302 .67683 L .59364 .67618 L F
.597 .67264 m .59364 .67618 L .59611 .6736 L F
.59717 .67247 m .59364 .67618 L .597 .67264 L F
.59717 .67247 m .59611 .6736 L .59785 .67248 L F
.732 .83 .925 r
.75428 .52335 m .75559 .52477 L .75765 .52343 L F
.964 .638 .265 r
.30813 .61919 m .30963 .61733 L .30716 .61772 L F
.30813 .61919 m .30899 .62168 L .3076 .62012 L F
.30813 .61919 m .3076 .62012 L .30963 .61733 L F
.79 .565 .596 r
.48481 .65891 m .48535 .66224 L .48116 .66097 L F
0 0 .038 r
.48649 .6578 m .48481 .65891 L .48721 .65606 L F
.359 .327 .687 r
.48649 .6578 m .48705 .6609 L .48481 .65891 L F
.45 .332 .627 r
.48705 .6609 m .48535 .66224 L .48481 .65891 L F
.63 .203 .213 r
.49854 .68182 m .49402 .68203 L .49573 .68226 L F
.397 .016 .194 r
.31867 .5892 m .32093 .5888 L .32224 .58654 L F
.32 0 .151 r
.32224 .58654 m .32307 .58822 L .32448 .58631 L F
.32224 .58654 m .32093 .5888 L .32307 .58822 L F
.138 0 .078 r
.46614 .65851 m .46427 .65945 L .46337 .66096 L F
0 .104 .626 r
.73864 .51622 m .73989 .51709 L .73686 .51391 L F
.73864 .51622 m .74074 .51825 L .73989 .51709 L F
.437 .362 .674 r
.30243 .60716 m .30385 .60324 L .30187 .60474 L F
.892 .882 .817 r
.59637 .60938 m .59547 .61305 L .59463 .61184 L F
0 0 .422 r
.59523 .61557 m .59463 .61184 L .59547 .61305 L F
.314 0 .233 r
.39684 .6127 m .39808 .61419 L .39929 .61261 L F
.39684 .6127 m .39606 .61482 L .39808 .61419 L F
.197 0 0 r
.35506 .64419 m .3514 .64628 L .3528 .64511 L F
.301 .536 .911 r
.78944 .49278 m .79203 .49235 L .78913 .4911 L F
.78944 .49278 m .79272 .49393 L .79203 .49235 L F
.197 .61 .947 r
.49788 .69242 m .50054 .69307 L .49739 .69185 L F
.999 .837 .514 r
.4977 .69113 m .49788 .69242 L .49739 .69185 L F
.516 .546 .825 r
.42737 .5941 m .42661 .59766 L .42532 .59456 L F
.42737 .5941 m .42872 .59739 L .42661 .59766 L F
.421 .157 .405 r
.34851 .60086 m .3459 .60355 L .3464 .60144 L F
.977 .784 .578 r
.61392 .62473 m .61341 .62109 L .61313 .62356 L F
.962 .689 .469 r
.61357 .62699 m .61392 .62473 L .61313 .62356 L F
.61357 .62699 m .61391 .62607 L .61392 .62473 L F
.608 .792 .969 r
.55564 .66977 m .55914 .67023 L .5586 .66892 L F
.765 .692 .782 r
.56047 .66658 m .5586 .66892 L .55914 .67023 L F
.769 .678 .762 r
.53178 .7101 m .53268 .71355 L .5291 .71319 L F
.672 .122 0 r
.53265 .71559 m .5291 .71319 L .53268 .71355 L F
.083 .211 .699 r
.53373 .71233 m .53268 .71355 L .53178 .7101 L F
.487 .276 .518 r
.53508 .71309 m .53265 .71559 L .53268 .71355 L F
.922 .971 .769 r
.53373 .71233 m .53265 .71559 L .53268 .71355 L F
.307 .106 .436 r
.48932 .62937 m .4873 .62995 L .48738 .63245 L F
.721 .468 .542 r
.475 .71325 m .47872 .71548 L .47835 .71383 L F
.876 .591 .502 r
.30315 .65229 m .30295 .65524 L .302 .65214 L F
.848 .49 .374 r
.30328 .65309 m .30394 .65357 L .30315 .65229 L F
.425 .375 .699 r
.30315 .65229 m .30394 .65357 L .30534 .65239 L F
.422 .198 .467 r
.30353 .65455 m .30295 .65524 L .30308 .6534 L F
.30332 .65329 m .30308 .6534 L .30315 .65229 L F
.30353 .65455 m .30308 .6534 L .30332 .65329 L F
.632 .753 .935 r
.30534 .65239 m .30394 .65357 L .30353 .6532 L F
.422 .198 .467 r
.30534 .65239 m .30436 .65356 L .30315 .65229 L F
.30436 .65356 m .30328 .65309 L .30315 .65229 L F
.848 .49 .374 r
.302 .65214 m .30328 .65309 L .30315 .65229 L F
.632 .753 .935 r
.30534 .65239 m .30353 .6532 L .30195 .65175 L F
0 .368 .82 r
.30195 .65175 m .30353 .6532 L .302 .65214 L F
.30353 .6532 m .30394 .65357 L .30328 .65309 L F
.30353 .6532 m .30328 .65309 L .302 .65214 L F
.422 .198 .467 r
.30436 .65356 m .30353 .65455 L .30328 .65309 L F
0 0 .323 r
.31145 .64206 m .31098 .64079 L .30962 .64034 L F
.354 .703 .984 r
.21626 .55147 m .21581 .5526 L .21469 .55114 L F
.21626 .55147 m .21772 .55249 L .21581 .5526 L F
.822 .516 .472 r
.46527 .71182 m .4691 .71073 L .46543 .71003 L F
.46527 .71182 m .46885 .71272 L .4691 .71073 L F
.702 .332 .344 r
.47154 .71266 m .4691 .71073 L .46885 .71272 L F
.306 0 0 r
.54907 .62443 m .54771 .62435 L .54561 .6238 L F
0 .28 .723 r
.54907 .62443 m .55053 .62496 L .54771 .62435 L F
.646 .257 .294 r
.47034 .71694 m .46982 .71887 L .46657 .7184 L F
.603 .216 .282 r
.47046 .71853 m .46982 .71887 L .47034 .71694 L F
.283 .444 .845 r
.26477 .85972 m .26545 .86002 L .26505 .86024 L F
.242 .149 .545 r
.26545 .86002 m .26503 .86288 L .26505 .86024 L F
.636 .335 .443 r
.51062 .64345 m .50796 .64357 L .50819 .64144 L F
.932 .706 .573 r
.61139 .6096 m .61246 .61369 L .61266 .61287 L F
.92 .701 .589 r
.60859 .61132 m .61246 .61369 L .61225 .61291 L F
.60976 .61061 m .61225 .61291 L .61139 .6096 L F
.60859 .61132 m .61225 .61291 L .60976 .61061 L F
.927 .671 .531 r
.61129 .61436 m .61246 .61369 L .60859 .61132 L F
.929 .687 .552 r
.61129 .61436 m .61262 .61532 L .61265 .61327 L F
.61129 .61436 m .61266 .61287 L .61246 .61369 L F
.61246 .61309 m .61265 .61327 L .61266 .61287 L F
.61129 .61436 m .61265 .61327 L .61246 .61309 L F
.459 .317 .599 r
.30388 .60087 m .30563 .59788 L .30379 .59844 L F
.4 .111 .355 r
.30899 .62168 m .30981 .62227 L .3076 .62012 L F
.30899 .62168 m .31041 .62338 L .30981 .62227 L F
.30899 .62168 m .30822 .62423 L .31041 .62338 L F
.104 0 0 r
.36865 .6265 m .37084 .62601 L .37236 .62492 L F
0 0 0 r
.37236 .62492 m .37293 .62489 L .37461 .62421 L F
.37236 .62492 m .37084 .62601 L .37293 .62489 L F
.461 .858 .972 r
.78063 .49092 m .78227 .48973 L .77972 .49014 L F
.78063 .49092 m .78332 .49023 L .78227 .48973 L F
.757 .712 .809 r
.53014 .67391 m .52945 .67707 L .53211 .6727 L F
.632 .658 .857 r
.79272 .49393 m .79378 .4972 L .79583 .49557 L F
.576 .549 .787 r
.79378 .4972 m .79589 .49873 L .79583 .49557 L F
.151 0 .314 r
.48945 .65472 m .48721 .65606 L .48915 .6529 L F
.459 .261 .523 r
.48945 .65472 m .48649 .6578 L .48721 .65606 L F
.61 .37 .528 r
.49332 .67037 m .49568 .67258 L .49317 .6728 L F
.49332 .67037 m .49617 .67027 L .49568 .67258 L F
.49568 .67258 m .49332 .67037 L .49317 .6728 L F
.49568 .67258 m .49617 .67027 L .49332 .67037 L F
.509 .232 .43 r
.74914 .48739 m .74956 .4887 L .75283 .48795 L F
.945 .714 .557 r
.31201 .63979 m .31348 .63812 L .31127 .63883 L F
.31201 .63979 m .314 .63801 L .31348 .63812 L F
.776 .684 .762 r
.80615 .5117 m .80692 .51498 L .8035 .51454 L F
.508 0 0 r
.80692 .51498 m .80732 .51599 L .8035 .51454 L F
.634 .595 .792 r
.80963 .51425 m .80692 .51498 L .80615 .5117 L F
.447 .106 .293 r
.80963 .51425 m .8079 .51595 L .80692 .51498 L F
.098 0 0 r
.81145 .51348 m .8079 .51595 L .80963 .51425 L F
.004 0 0 r
.80892 .51593 m .8079 .51595 L .81145 .51348 L F
.016 .092 .6 r
.80692 .51498 m .8079 .51595 L .80892 .51593 L F
.80692 .51498 m .80892 .51593 L .80732 .51599 L F
.162 .387 .834 r
.57463 .63643 m .57584 .63756 L .57641 .63916 L F
.215 .427 .853 r
.57584 .63756 m .57687 .63788 L .57641 .63916 L F
.832 .394 .193 r
.57687 .63788 m .57879 .6384 L .57641 .63916 L F
.503 .498 .783 r
.47716 .66948 m .47533 .67134 L .47409 .66742 L F
.676 .182 .068 r
.47533 .67134 m .47885 .67303 L .47897 .67261 L F
.532 .544 .813 r
.47716 .66948 m .47885 .67303 L .47533 .67134 L F
.397 0 .116 r
.58058 .58562 m .5793 .58418 L .57826 .58584 L F
.58058 .58562 m .58176 .58386 L .5793 .58418 L F
.658 .614 .793 r
.46867 .68182 m .46639 .68305 L .46486 .68159 L F
.666 .952 .952 r
.73629 .51338 m .73503 .51504 L .73686 .51391 L F
.73629 .51338 m .73503 .51504 L .73686 .51391 L F
.601 .928 .964 r
.48681 .6489 m .48586 .65024 L .48797 .64931 L F
.48681 .6489 m .48586 .65024 L .48797 .64931 L F
.817 .398 0 r
.53428 .67244 m .53514 .67451 L .5339 .67245 L F
.53428 .67244 m .5339 .67245 L .5335 .67177 L F
.107 .661 .732 r
.53459 .67244 m .53428 .67244 L .53211 .6727 L F
.53583 .67232 m .53428 .67244 L .53459 .67244 L F
.517 .6 .876 r
.53583 .67232 m .53813 .67243 L .53677 .67002 L F
0 0 0 r
.51082 .68443 m .50816 .68799 L .51031 .68626 L F
.36 .424 .792 r
.50816 .68799 m .5113 .68871 L .51031 .68626 L F
.796 .754 .815 r
.59345 .63525 m .5957 .63301 L .59638 .63599 L F
.975 .672 .364 r
.59638 .63599 m .59528 .6373 L .59345 .63525 L F
.498 .274 .505 r
.59412 .63866 m .59649 .6384 L .59638 .63599 L F
.975 .672 .364 r
.59638 .63599 m .59649 .6384 L .59528 .6373 L F
.416 .113 .342 r
.57817 .59271 m .57795 .59421 L .57533 .59484 L F
.543 .255 .428 r
.58051 .59235 m .57795 .59421 L .57817 .59271 L F
.055 0 .311 r
.20968 .59508 m .20925 .59735 L .20783 .59846 L F
.436 .289 .581 r
.20925 .59735 m .20729 .60068 L .20783 .59846 L F
.541 .568 .831 r
.78539 .50238 m .78704 .50525 L .78914 .50483 L F
.352 .154 .466 r
.80785 .4977 m .8086 .49951 L .80654 .5004 L F
0 0 .485 r
.80946 .4988 m .80785 .4977 L .80876 .49657 L F
.80946 .4988 m .8086 .49951 L .80785 .4977 L F
.091 0 0 r
.53663 .653 m .53366 .65491 L .53433 .65366 L F
.995 .776 .413 r
.58659 .65015 m .58594 .64635 L .5873 .6474 L F
.258 .766 .761 r
.52418 .68297 m .52871 .68187 L .52762 .68129 L F
.416 .816 .982 r
.52871 .68187 m .53104 .6815 L .52762 .68129 L F
.467 .181 .395 r
.51848 .67856 m .5213 .67817 L .52227 .67586 L F
.592 .31 .457 r
.52227 .67586 m .5213 .67817 L .52417 .67783 L F
.627 .787 .959 r
.44424 .70581 m .44511 .70388 L .44297 .70413 L F
.44424 .70581 m .44617 .70515 L .44511 .70388 L F
.836 .803 .819 r
.30699 .62497 m .30253 .62637 L .30476 .6258 L F
0 0 0 r
.48275 .63823 m .4804 .64074 L .48253 .64049 L F
.48508 .63508 m .48275 .63823 L .48471 .63794 L F
.294 .03 .332 r
.48471 .63794 m .48275 .63823 L .48253 .64049 L F
.167 .392 .837 r
.43882 .69721 m .44035 .69543 L .43869 .69561 L F
.43882 .69721 m .44093 .69748 L .44035 .69543 L F
.43882 .69721 m .4411 .69884 L .44093 .69748 L F
.406 0 .087 r
.55396 .66211 m .55384 .66395 L .55277 .66263 L F
.55396 .66211 m .55803 .66262 L .55384 .66395 L F
.589 .314 .468 r
.42151 .6156 m .42068 .61822 L .4182 .61837 L F
.537 .263 .447 r
.42353 .61723 m .42151 .6156 L .42393 .61526 L F
.42353 .61723 m .42068 .61822 L .42151 .6156 L F
0 0 .339 r
.21993 .56241 m .21869 .56655 L .21818 .56399 L F
.565 .298 .47 r
.51578 .68165 m .51826 .68137 L .51848 .67856 L F
.564 .337 .53 r
.51826 .68137 m .5213 .67817 L .51848 .67856 L F
.492 .45 .738 r
.54611 .61034 m .54803 .6114 L .54893 .60999 L F
.54611 .61034 m .54893 .60999 L .54895 .61039 L F
.784 .462 0 r
.54774 .60669 m .54895 .61039 L .54893 .60999 L F
.556 0 0 r
.5498 .61142 m .54893 .60999 L .54803 .6114 L F
.5498 .61142 m .55026 .61096 L .54893 .60999 L F
.577 .109 .106 r
.54774 .60669 m .54637 .60733 L .54895 .61039 L F
.54637 .60733 m .54728 .60957 L .54895 .61039 L F
0 0 0 r
.54633 .61038 m .54611 .61034 L .54646 .61035 L F
.5478 .61039 m .54646 .61035 L .54895 .61039 L F
.54633 .61038 m .54646 .61035 L .5478 .61039 L F
.4 .411 .756 r
.54849 .61041 m .5498 .61142 L .54845 .6114 L F
.54862 .60762 m .5495 .61044 L .54849 .61041 L F
.5495 .61044 m .5498 .61142 L .54849 .61041 L F
0 0 0 r
.54633 .61038 m .5478 .61039 L .54451 .60819 L F
.5478 .61039 m .54895 .61039 L .54728 .60957 L F
.5478 .61039 m .54728 .60957 L .54451 .60819 L F
.4 .411 .756 r
.54811 .61088 m .54845 .6114 L .54803 .6114 L F
.54862 .60762 m .54845 .6114 L .54811 .61088 L F
.54803 .61139 m .54803 .6114 L .54803 .6114 L F
.54862 .60762 m .54803 .6114 L .54803 .61139 L F
.577 .109 .106 r
.54637 .60733 m .54451 .60819 L .54728 .60957 L F
.54774 .60669 m .54766 .6085 L .54451 .60819 L F
.54766 .6085 m .54664 .60873 L .54451 .60819 L F
.54664 .60873 m .5466 .60874 L .54647 .60871 L F
.54664 .60873 m .54647 .60871 L .54451 .60819 L F
.644 .966 .835 r
.5442 .61107 m .54307 .61249 L .54611 .61034 L F
0 0 0 r
.54633 .61038 m .5442 .61107 L .54611 .61034 L F
.46 .59 .896 r
.54451 .60819 m .5466 .60874 L .54401 .60656 L F
.94 .853 .729 r
.54401 .60656 m .54633 .61038 L .54451 .60819 L F
.54521 .60855 m .5442 .61107 L .54633 .61038 L F
.54401 .60656 m .54408 .6084 L .54521 .60855 L F
.54408 .6084 m .5442 .61107 L .54521 .60855 L F
.4 .411 .756 r
.54795 .60843 m .54803 .6114 L .54716 .61088 L F
.54686 .60974 m .54716 .61088 L .54633 .61038 L F
.54795 .60843 m .54716 .61088 L .54686 .60974 L F
.54862 .60762 m .54852 .6083 L .54795 .60843 L F
.54852 .6083 m .54803 .6114 L .54795 .60843 L F
.134 .233 .702 r
.55011 .60887 m .5498 .61142 L .54862 .60762 L F
.371 .24 .57 r
.54862 .60762 m .54763 .61075 L .55011 .60887 L F
.255 0 .023 r
.5498 .61142 m .54756 .61075 L .54803 .6114 L F
.54756 .61075 m .54633 .61038 L .54696 .61076 L F
.54756 .61075 m .54696 .61076 L .54803 .6114 L F
.706 .586 .719 r
.54633 .61038 m .54745 .61129 L .54756 .61094 L F
.255 0 .023 r
.54756 .61075 m .54752 .61092 L .54633 .61038 L F
.706 .586 .719 r
.54633 .61038 m .54756 .61094 L .54763 .61075 L F
.492 .45 .738 r
.54611 .61034 m .5462 .61224 L .54803 .6114 L F
.465 .342 .628 r
.5462 .61224 m .54888 .61196 L .54803 .6114 L F
.5462 .61224 m .54634 .61363 L .54888 .61196 L F
.255 0 .023 r
.54741 .61137 m .54696 .61329 L .54649 .61115 L F
.54736 .61132 m .54649 .61115 L .54633 .61038 L F
.54741 .61137 m .54649 .61115 L .54736 .61132 L F
.371 .24 .57 r
.54756 .61094 m .54745 .61129 L .54757 .61118 L F
.255 0 .023 r
.54762 .61286 m .54696 .61329 L .54756 .61075 L F
.661 .583 .757 r
.54307 .61249 m .5462 .61224 L .54611 .61034 L F
.774 .569 .622 r
.54348 .61387 m .5462 .61224 L .54307 .61249 L F
.54348 .61387 m .54634 .61363 L .5462 .61224 L F
.627 .457 .633 r
.54527 .61073 m .54421 .61374 L .5442 .61107 L F
.54633 .61038 m .54595 .61099 L .54527 .61073 L F
.54595 .61099 m .54421 .61374 L .54527 .61073 L F
.54595 .61099 m .54696 .61329 L .54421 .61374 L F
.54633 .61038 m .54649 .61115 L .54595 .61099 L F
.54649 .61115 m .54696 .61329 L .54595 .61099 L F
.512 0 0 r
.54718 .61136 m .54745 .61133 L .54736 .61132 L F
.54528 .61188 m .54725 .61138 L .54718 .61136 L F
.54725 .61138 m .54745 .61133 L .54718 .61136 L F
.54528 .61188 m .54751 .61234 L .54747 .61157 L F
.54709 .61142 m .54747 .61157 L .54745 .61133 L F
.54528 .61188 m .54747 .61157 L .54709 .61142 L F
.54736 .61132 m .54745 .61133 L .54745 .61129 L F
.54528 .61188 m .54736 .61132 L .54633 .61038 L F
.54736 .61132 m .54745 .61129 L .54633 .61038 L F
.255 0 .023 r
.54752 .61092 m .54741 .61137 L .54633 .61038 L F
.455 .542 .857 r
.54888 .61196 m .5498 .61142 L .54803 .6114 L F
.255 0 .023 r
.5498 .61142 m .54762 .61286 L .54757 .61118 L F
.5498 .61142 m .54757 .61118 L .54784 .61083 L F
.896 .759 .703 r
.54751 .61234 m .55011 .60887 L .54757 .61118 L F
.54745 .61133 m .54757 .61118 L .54745 .61129 L F
.54751 .61234 m .54757 .61118 L .54745 .61133 L F
.255 0 .023 r
.54784 .61083 m .54757 .61118 L .54756 .61075 L F
.371 .24 .57 r
.54763 .61075 m .54756 .61094 L .54806 .61074 L F
.54756 .61094 m .54757 .61118 L .54806 .61074 L F
.54763 .61075 m .54806 .61074 L .55011 .60887 L F
0 0 .006 r
.54857 .60498 m .5482 .60656 L .54774 .60669 L F
.5482 .60656 m .54763 .60902 L .54766 .60841 L F
.5482 .60656 m .54766 .60841 L .54774 .60669 L F
.706 .586 .719 r
.54749 .60898 m .54763 .61075 L .54862 .60762 L F
.54633 .61038 m .54702 .61058 L .54749 .60898 L F
.54702 .61058 m .54763 .61075 L .54749 .60898 L F
.46 .59 .896 r
.5466 .60874 m .54763 .60902 L .54646 .60822 L F
.5466 .60874 m .54646 .60822 L .54401 .60656 L F
.577 .109 .106 r
.54766 .6085 m .54763 .60902 L .5466 .60874 L F
.318 .075 .379 r
.54634 .61363 m .54793 .61563 L .54888 .61196 L F
.455 .542 .857 r
.54888 .61196 m .55126 .61421 L .5498 .61142 L F
.751 .44 .458 r
.54793 .61563 m .55126 .61421 L .54888 .61196 L F
.255 0 .023 r
.5498 .61142 m .54904 .61293 L .54696 .61329 L F
.881 .851 .394 r
.55011 .60887 m .54931 .61191 L .5498 .61142 L F
.54931 .61191 m .54904 .61293 L .5498 .61142 L F
.556 0 0 r
.5498 .61142 m .55138 .61178 L .55026 .61096 L F
.653 .409 .537 r
.43495 .61008 m .43467 .61255 L .43215 .61236 L F
.604 .365 .528 r
.43852 .61163 m .43495 .61008 L .43803 .60926 L F
.43852 .61163 m .43467 .61255 L .43495 .61008 L F
.164 0 0 r
.46282 .7012 m .46515 .70092 L .46627 .70006 L F
.519 0 0 r
.46515 .70092 m .46902 .70109 L .46627 .70006 L F
.6 .519 .736 r
.4802 .672 m .47802 .67447 L .47897 .67261 L F
0 0 0 r
.47897 .67261 m .47885 .67303 L .4802 .672 L F
.31 .381 .774 r
.40859 .59836 m .40981 .59649 L .40738 .59671 L F
.40859 .59836 m .40994 .59791 L .40981 .59649 L F
.27 .252 .655 r
.40859 .59836 m .41049 .60049 L .40994 .59791 L F
.272 .728 .954 r
.3929 .58432 m .39511 .58426 L .39655 .58486 L F
.353 .787 .967 r
.39709 .584 m .39655 .58486 L .39511 .58426 L F
.39709 .584 m .39871 .58459 L .39655 .58486 L F
0 .419 .726 r
.4609 .71306 m .45958 .71257 L .45809 .71212 L F
.747 .252 .055 r
.46359 .71498 m .45958 .71257 L .4609 .71306 L F
0 0 .507 r
.55356 .65126 m .55237 .65002 L .55108 .64905 L F
.55356 .65126 m .55367 .65262 L .55237 .65002 L F
0 0 .316 r
.43835 .60425 m .43712 .60435 L .43801 .60288 L F
.463 .205 .437 r
.57533 .59484 m .57281 .5978 L .57213 .59491 L F
.57533 .59484 m .57536 .59767 L .57281 .5978 L F
.418 .156 .407 r
.57795 .59421 m .57536 .59767 L .57533 .59484 L F
.069 0 0 r
.77488 .49083 m .77721 .49078 L .77381 .49101 L F
.322 .741 .976 r
.53348 .68138 m .5348 .68222 L .53104 .6815 L F
.493 .739 .981 r
.5348 .68222 m .53565 .68052 L .53348 .68138 L F
.5348 .68222 m .53691 .68186 L .53565 .68052 L F
.497 .264 .491 r
.49178 .65023 m .48797 .64931 L .49023 .64898 L F
.49178 .65023 m .48915 .6529 L .48797 .64931 L F
.49178 .65023 m .49172 .6525 L .48915 .6529 L F
.681 .447 .56 r
.49477 .65005 m .49172 .6525 L .49178 .65023 L F
.67 .395 .496 r
.54279 .66728 m .5394 .66908 L .54063 .66796 L F
.45 .126 .325 r
.40527 .62412 m .40432 .62684 L .40195 .62713 L F
.379 .06 .294 r
.40643 .62625 m .40527 .62412 L .40754 .6238 L F
.40643 .62625 m .40432 .62684 L .40527 .62412 L F
.203 .724 .707 r
.37253 .59539 m .37198 .59559 L .37417 .59498 L F
.334 .768 .969 r
.36578 .58371 m .36799 .58352 L .36946 .58411 L F
.389 .787 .986 r
.37015 .58317 m .36946 .58411 L .36799 .58352 L F
.37015 .58317 m .37162 .58386 L .36946 .58411 L F
.228 0 0 r
.32887 .58535 m .33278 .58364 L .33049 .58387 L F
.287 .403 .806 r
.42341 .59172 m .42222 .5931 L .42196 .59153 L F
.456 .659 .949 r
.42341 .59172 m .42432 .59304 L .42222 .5931 L F
.593 .53 .753 r
.42532 .59456 m .42222 .5931 L .42432 .59304 L F
.451 0 0 r
.33866 .58245 m .34081 .5829 L .33872 .5821 L F
.956 .821 .67 r
.77554 .5254 m .77704 .52592 L .7763 .52809 L F
.646 .62 .809 r
.35109 .6239 m .34738 .62165 L .34985 .62241 L F
.652 .776 .939 r
.35376 .62267 m .35109 .6239 L .34985 .62241 L F
.347 .031 .28 r
.45858 .66431 m .46054 .66372 L .46138 .66178 L F
.351 .056 .317 r
.46054 .66372 m .46337 .66096 L .46138 .66178 L F
.227 0 0 r
.50577 .66339 m .50647 .66228 L .5087 .6616 L F
.361 .245 .584 r
.21119 .58972 m .21117 .59198 L .2096 .59259 L F
.404 .289 .607 r
.21117 .59198 m .20968 .59508 L .2096 .59259 L F
.408 0 .135 r
.52339 .65631 m .52153 .6555 L .52452 .65542 L F
0 0 0 r
.52632 .65167 m .52575 .65375 L .52452 .65542 L F
.59 .872 .552 r
.52575 .65375 m .52339 .65631 L .52452 .65542 L F
0 0 .132 r
.52598 .65845 m .52787 .65323 L .52452 .65542 L F
.584 .674 .902 r
.7763 .52809 m .78015 .5299 L .77905 .52895 L F
.567 .849 .997 r
.77905 .52895 m .78015 .5299 L .78249 .52918 L F
.345 0 0 r
.46668 .68549 m .46256 .6865 L .46273 .68423 L F
.46668 .68549 m .46485 .68649 L .46256 .6865 L F
.587 .089 .038 r
.46668 .68549 m .46853 .68681 L .46485 .68649 L F
.453 .206 .448 r
.46941 .6836 m .46853 .68681 L .46668 .68549 L F
.573 .314 .487 r
.43215 .61236 m .42947 .61477 L .42975 .61261 L F
.041 0 .368 r
.22114 .55958 m .21993 .56241 L .22069 .56139 L F
.361 .688 .98 r
.4206 .59017 m .4189 .59106 L .4175 .58938 L F
.4206 .59017 m .42196 .59153 L .4189 .59106 L F
.212 .374 .809 r
.45648 .69897 m .45924 .70106 L .45814 .7023 L F
.358 .599 .939 r
.45924 .70106 m .46073 .70276 L .45814 .7023 L F
.843 .494 .393 r
.47381 .7194 m .47247 .7213 L .47046 .71853 L F
.623 .214 .246 r
.4761 .7211 m .47247 .7213 L .47381 .7194 L F
.301 .78 .689 r
.54486 .59701 m .54729 .59601 L .54874 .59547 L F
.325 0 0 r
.54981 .59636 m .54874 .59547 L .54729 .59601 L F
.54981 .59636 m .55164 .59567 L .54874 .59547 L F
.718 .492 .582 r
.49172 .6525 m .48945 .65472 L .48915 .6529 L F
.677 .776 .925 r
.41562 .58933 m .41179 .58888 L .41455 .58807 L F
.379 .623 .948 r
.41654 .58787 m .41562 .58933 L .41455 .58807 L F
.41654 .58787 m .4175 .58938 L .41562 .58933 L F
.424 .778 .996 r
.58089 .67295 m .58219 .67169 L .5803 .67155 L F
.58089 .67295 m .58303 .67258 L .58219 .67169 L F
0 .525 .759 r
.51735 .63265 m .51951 .63297 L .52101 .63329 L F
.119 0 0 r
.51951 .63297 m .52322 .63314 L .52101 .63329 L F
0 0 0 r
.73702 .49593 m .73611 .49686 L .7363 .49497 L F
.435 .446 .772 r
.73848 .49371 m .73702 .49593 L .7363 .49497 L F
.73848 .49371 m .73939 .49638 L .73702 .49593 L F
.474 .228 .46 r
.30826 .59268 m .30793 .59482 L .31011 .59426 L F
.521 .218 .393 r
.30826 .59268 m .31011 .59426 L .31044 .59265 L F
.681 .865 .969 r
.75925 .5216 m .76362 .52185 L .76165 .52144 L F
.75925 .5216 m .75945 .52243 L .76362 .52185 L F
.615 .94 .951 r
.76495 .52039 m .76362 .52185 L .76583 .52109 L F
.76495 .52039 m .76165 .52144 L .76362 .52185 L F
.39 .022 .214 r
.56761 .58931 m .56998 .58875 L .57091 .58662 L F
.498 .151 .308 r
.56998 .58875 m .57326 .58626 L .57091 .58662 L F
.949 .951 .73 r
.59223 .64019 m .59412 .63866 L .59168 .64135 L F
.59223 .64019 m .59323 .63826 L .59412 .63866 L F
.594 .93 .957 r
.59323 .63826 m .59528 .6373 L .59412 .63866 L F
.467 .747 .99 r
.59528 .6373 m .59649 .6384 L .59412 .63866 L F
.844 .38 .059 r
.55367 .65262 m .55438 .65404 L .55496 .65327 L F
.854 .396 .068 r
.55438 .65404 m .55649 .6554 L .55496 .65327 L F
.764 .529 .578 r
.79303 .52284 m .79492 .52155 L .7936 .52062 L F
.79303 .52284 m .79649 .52372 L .79492 .52155 L F
.574 .169 .237 r
.26451 .86004 m .26545 .86002 L .26477 .85972 L F
.437 .362 .674 r
.30243 .60716 m .30427 .60685 L .30385 .60324 L F
.522 .487 .759 r
.30243 .60716 m .30554 .60933 L .30427 .60685 L F
.521 .332 .566 r
.52832 .66044 m .52598 .65845 L .52924 .65818 L F
.376 .751 .99 r
.53077 .65785 m .53145 .65753 L .52924 .65818 L F
.627 .437 .605 r
.53145 .65753 m .52832 .66044 L .52924 .65818 L F
.773 .682 .762 r
.48535 .66224 m .48616 .66447 L .48292 .66426 L F
.77 .503 .531 r
.48292 .66426 m .48616 .66447 L .48587 .66667 L F
.62 .365 .51 r
.48616 .66447 m .48837 .66672 L .48587 .66667 L F
.581 .413 .619 r
.48746 .66251 m .4892 .66445 L .48616 .66447 L F
.736 .618 .727 r
.48649 .66233 m .48746 .66251 L .48616 .66447 L F
.574 .367 .561 r
.4892 .66445 m .48837 .66672 L .48616 .66447 L F
.83 .708 .729 r
.48649 .66233 m .48616 .66447 L .48535 .66224 L F
.552 .726 .955 r
.7927 .48225 m .79116 .48419 L .79017 .48269 L F
.7927 .48225 m .7936 .48379 L .79116 .48419 L F
.615 .75 .942 r
.48705 .6609 m .48746 .66251 L .48649 .66233 L F
0 .076 .624 r
.48819 .66279 m .48746 .66251 L .48705 .6609 L F
.48819 .66279 m .4892 .66445 L .48746 .66251 L F
.97 .7 .463 r
.46273 .68423 m .46136 .68359 L .46269 .6818 L F
.46273 .68423 m .46136 .68359 L .46269 .6818 L F
.747 .971 .703 r
.58972 .64281 m .59223 .64019 L .59168 .64135 L F
0 .03 .563 r
.28513 .82208 m .28613 .8234 L .28673 .8228 L F
.727 .738 .86 r
.54579 .63787 m .54252 .63709 L .54452 .6375 L F
.059 .61 .828 r
.54452 .6375 m .54909 .63809 L .54579 .63787 L F
.742 .432 .457 r
.31923 .63238 m .31529 .63211 L .31709 .63309 L F
.483 .156 .336 r
.41787 .61997 m .41587 .61847 L .4182 .61837 L F
.41787 .61997 m .41551 .6205 L .41587 .61847 L F
.418 0 0 r
.32416 .63682 m .32303 .63626 L .32142 .63524 L F
.031 .437 .87 r
.32416 .63682 m .32504 .63645 L .32303 .63626 L F
.32416 .63682 m .3264 .6379 L .32504 .63645 L F
.054 .545 .888 r
.76824 .52092 m .76926 .52168 L .77214 .52234 L F
.291 .066 .389 r
.5304 .64979 m .5315 .65047 L .53246 .64732 L F
.655 .329 .409 r
.5304 .64979 m .53293 .65209 L .5315 .65047 L F
.5304 .64979 m .52964 .6527 L .53293 .65209 L F
.863 .702 .681 r
.73008 .48587 m .72755 .48405 L .72849 .48562 L F
.733 .699 .819 r
.72849 .48562 m .72896 .48874 L .73008 .48587 L F
0 .181 .702 r
.57279 .66137 m .57346 .66016 L .57154 .65802 L F
0 .123 .658 r
.57279 .66137 m .57452 .66352 L .57346 .66016 L F
.812 .397 .258 r
.46485 .71578 m .46381 .71747 L .46359 .71498 L F
.46485 .71578 m .46657 .7184 L .46381 .71747 L F
.369 0 0 r
.24065 .7507 m .24227 .75053 L .24088 .7505 L F
.273 .153 .528 r
.21689 .57502 m .21687 .57746 L .21549 .57812 L F
.264 .137 .513 r
.21682 .5799 m .21549 .57812 L .21687 .57746 L F
.21682 .5799 m .21545 .58075 L .21549 .57812 L F
.547 .584 .843 r
.30716 .61772 m .30834 .6149 L .30588 .61477 L F
.30716 .61772 m .30963 .61733 L .30834 .6149 L F
.852 .682 .671 r
.60891 .60071 m .61032 .60129 L .60889 .59806 L F
.822 .605 .609 r
.60677 .60312 m .61032 .60129 L .60891 .60071 L F
.60677 .60312 m .61021 .60382 L .61032 .60129 L F
.636 .723 .91 r
.74249 .50852 m .74603 .50888 L .74484 .50534 L F
.755 .493 0 r
.74603 .50888 m .7457 .50779 L .74558 .50697 L F
0 0 .545 r
.74603 .50888 m .74717 .50986 L .7457 .50779 L F
.74603 .50888 m .74814 .5114 L .74717 .50986 L F
.532 .302 .511 r
.44855 .67305 m .45101 .67269 L .45118 .67039 L F
.419 .209 .485 r
.45118 .67039 m .45305 .6721 L .45339 .66988 L F
.45118 .67039 m .45101 .67269 L .45305 .6721 L F
.699 .719 .865 r
.43425 .59991 m .43353 .60387 L .43197 .60051 L F
.43425 .59991 m .43688 .60347 L .43353 .60387 L F
.143 0 0 r
.74249 .50852 m .74076 .50887 L .73875 .50883 L F
.576 .814 .428 r
.74484 .50534 m .74358 .50703 L .74249 .50852 L F
.624 .579 .783 r
.74358 .50703 m .74076 .50887 L .74249 .50852 L F
0 0 .029 r
.5523 .59822 m .55162 .60021 L .54949 .60129 L F
.665 .868 .486 r
.55162 .60021 m .54955 .6034 L .54949 .60129 L F
.62 .372 .519 r
.78904 .50262 m .78959 .50032 L .78805 .4998 L F
.78904 .50262 m .79156 .50233 L .78959 .50032 L F
.41 .022 .189 r
.58675 .58071 m .58897 .58027 L .58989 .57844 L F
.616 .231 .29 r
.58989 .57844 m .58897 .58027 L .59214 .58008 L F
.547 .28 .463 r
.58989 .57844 m .59214 .58008 L .59219 .57804 L F
.203 .704 .911 r
.37162 .58386 m .37378 .58383 L .37535 .58429 L F
.48 .839 .994 r
.37378 .58383 m .37751 .58394 L .37535 .58429 L F
.442 .704 .977 r
.40679 .58573 m .40593 .58717 L .40456 .58609 L F
.40679 .58573 m .40813 .58697 L .40593 .58717 L F
.582 .646 .879 r
.41049 .60049 m .41134 .60197 L .41333 .60116 L F
.41049 .60049 m .41394 .6013 L .41223 .60125 L F
.767 .918 .939 r
.41223 .60125 m .4143 .60076 L .41564 .60015 L F
.4143 .60076 m .41662 .60022 L .41578 .60016 L F
.4143 .60076 m .41578 .60016 L .41564 .60015 L F
.582 .646 .879 r
.41333 .60116 m .41256 .60407 L .41394 .6013 L F
.41134 .60197 m .41256 .60407 L .41333 .60116 L F
.612 .683 .892 r
.41394 .6013 m .41256 .60407 L .41474 .60337 L F
.621 .481 .671 r
.4123 .60643 m .41474 .60337 L .41256 .60407 L F
0 0 .492 r
.55301 .62711 m .55394 .62809 L .55184 .62602 L F
.55301 .62711 m .55495 .62942 L .55394 .62809 L F
.524 .624 .892 r
.78377 .52432 m .78236 .52633 L .78086 .52344 L F
.78377 .52432 m .78501 .52622 L .78236 .52633 L F
0 0 0 r
.5941 .61718 m .59523 .61557 L .59267 .61848 L F
.243 .381 .803 r
.59267 .61848 m .59538 .6203 L .5941 .61718 L F
.318 .163 .508 r
.43897 .68463 m .44082 .68134 L .43865 .68209 L F
.601 .34 .493 r
.50452 .64432 m .50214 .64642 L .50235 .64456 L F
.415 .862 .887 r
.79277 .50539 m .79428 .50442 L .79156 .50233 L F
.79277 .50539 m .79522 .50458 L .79428 .50442 L F
.675 .555 .71 r
.67675 .49372 m .67714 .49738 L .67941 .49465 L F
.521 .776 .99 r
.78332 .49023 m .7869 .49105 L .78581 .48999 L F
.323 .693 .98 r
.78581 .48999 m .7869 .49105 L .78913 .4911 L F
.821 .886 .891 r
.78838 .52504 m .78501 .52622 L .78733 .52462 L F
.717 .654 .786 r
.3041 .63177 m .30575 .63376 L .30768 .63174 L F
0 0 .332 r
.45486 .69239 m .4553 .69501 L .45403 .69542 L F
.001 .11 .625 r
.4553 .69501 m .45578 .69788 L .45403 .69542 L F
.732 .735 .854 r
.3977 .59442 m .39925 .59631 L .40136 .59491 L F
.509 .181 .348 r
.50198 .65925 m .50508 .65868 L .50251 .65881 L F
.594 .521 .742 r
.30363 .62823 m .30476 .6258 L .30253 .62637 L F
.30363 .62823 m .30652 .62877 L .30476 .6258 L F
.599 .51 .725 r
.30363 .62823 m .30435 .63008 L .30652 .62877 L F
.716 .362 .377 r
.53169 .64144 m .52824 .64299 L .52811 .64105 L F
.53169 .64144 m .53064 .64373 L .52824 .64299 L F
.308 0 .183 r
.53304 .64274 m .53169 .64144 L .53411 .64094 L F
.53304 .64274 m .53064 .64373 L .53169 .64144 L F
.564 .346 .542 r
.76746 .48549 m .77001 .48533 L .76995 .48323 L F
.709 .855 .952 r
.48705 .6609 m .48649 .66233 L .48535 .66224 L F
.928 .733 .62 r
.60109 .59131 m .60369 .58959 L .60197 .58862 L F
.60109 .59131 m .60323 .59236 L .60369 .58959 L F
.462 .675 .956 r
.80173 .48491 m .80055 .48655 L .79988 .48496 L F
.80173 .48491 m .8023 .48657 L .80055 .48655 L F
.347 .073 .349 r
.8086 .49951 m .80639 .50283 L .80654 .5004 L F
.414 .415 .751 r
.79583 .49557 m .79589 .49873 L .79823 .4964 L F
.399 .46 .808 r
.79589 .49873 m .8001 .499 L .79823 .4964 L F
.79589 .49873 m .79951 .50007 L .8001 .499 L F
.79589 .49873 m .79751 .50029 L .79951 .50007 L F
.867 .618 .559 r
.59594 .62421 m .59428 .62583 L .59399 .62401 L F
.59594 .62421 m .5975 .62707 L .59428 .62583 L F
.364 0 .1 r
.37909 .62333 m .38277 .62091 L .38044 .62124 L F
.813 .609 .626 r
.59338 .59547 m .58993 .5974 L .59023 .59478 L F
.59338 .59547 m .5931 .59799 L .58993 .5974 L F
.444 .046 .19 r
.38522 .62077 m .38762 .62059 L .38879 .61849 L F
.3 0 .021 r
.38762 .62059 m .39028 .61949 L .38879 .61849 L F
.418 0 .135 r
.38879 .61849 m .39028 .61949 L .39122 .61816 L F
.554 .789 .986 r
.78382 .50765 m .7815 .50903 L .78154 .5075 L F
.449 .316 .607 r
.78424 .51062 m .7815 .50903 L .78382 .50765 L F
.78424 .51062 m .78176 .51225 L .7815 .50903 L F
0 0 0 r
.49329 .64468 m .49194 .64612 L .49045 .64686 L F
0 0 .04 r
.49411 .64079 m .49384 .64328 L .49329 .64468 L F
.522 .82 .487 r
.49382 .64409 m .49329 .64468 L .49384 .64328 L F
.49382 .64409 m .49194 .64612 L .49329 .64468 L F
.142 .586 .928 r
.21071 .54861 m .20906 .54836 L .20729 .54723 L F
.12 .196 .668 r
.43741 .60061 m .43688 .60347 L .43425 .59991 L F
.43741 .60061 m .43801 .60288 L .43688 .60347 L F
0 0 0 r
.55271 .59881 m .55162 .60021 L .5523 .59822 L F
.365 0 0 r
.38079 .63498 m .37954 .63579 L .37723 .63596 L F
.299 0 0 r
.38279 .63478 m .37954 .63579 L .38079 .63498 L F
.294 .116 .461 r
.30443 .61486 m .30588 .61477 L .30615 .61239 L F
.887 .695 .637 r
.61007 .60639 m .61165 .60725 L .61021 .60382 L F
.944 .78 .648 r
.60975 .60836 m .61165 .60725 L .61007 .60639 L F
.60975 .60836 m .61139 .6096 L .61165 .60725 L F
.678 .339 .394 r
.49791 .64073 m .49411 .64079 L .49506 .63866 L F
.287 .749 .95 r
.77835 .48213 m .78084 .48203 L .78188 .48255 L F
.281 .745 .948 r
.78188 .48255 m .78084 .48203 L .78428 .48243 L F
.317 .542 .911 r
.34819 .62014 m .34738 .62165 L .34599 .62079 L F
.34819 .62014 m .34985 .62241 L .34738 .62165 L F
.398 0 0 r
.55138 .61178 m .5536 .61137 L .55455 .61025 L F
.006 0 0 r
.5536 .61137 m .55557 .61063 L .55455 .61025 L F
.189 .383 .824 r
.80484 .48795 m .80391 .4893 L .8023 .48657 L F
.088 .407 .859 r
.80626 .48959 m .80391 .4893 L .80484 .48795 L F
.80626 .48959 m .80671 .49089 L .80391 .4893 L F
.866 .628 .576 r
.59428 .62583 m .5975 .62707 L .59739 .62947 L F
.764 .678 .767 r
.4393 .70157 m .44294 .70188 L .4411 .69884 L F
.799 .562 .579 r
.43917 .70404 m .44294 .70188 L .4393 .70157 L F
.43917 .70404 m .44297 .70413 L .44294 .70188 L F
.386 .801 .977 r
.44294 .70188 m .44426 .70098 L .4411 .69884 L F
.44294 .70188 m .44545 .70163 L .44426 .70098 L F
.561 .309 .492 r
.44511 .70388 m .44294 .70188 L .44297 .70413 L F
.44511 .70388 m .44545 .70163 L .44294 .70188 L F
.42 .652 .955 r
.58353 .67434 m .58458 .67316 L .58303 .67258 L F
.58353 .67434 m .58784 .675 L .58458 .67316 L F
.286 0 .057 r
.28613 .8234 m .2875 .8246 L .28507 .82527 L F
.493 0 0 r
.55604 .63035 m .55821 .63245 L .55712 .6314 L F
.824 .533 .497 r
.59905 .581 m .59929 .58324 L .60228 .58371 L F
.886 .673 .609 r
.59945 .58557 m .60228 .58371 L .59929 .58324 L F
.59945 .58557 m .60202 .5865 L .60228 .58371 L F
.721 .622 .747 r
.3041 .63177 m .30652 .62877 L .30435 .63008 L F
0 0 .377 r
.57708 .67012 m .57742 .66928 L .57668 .66685 L F
.071 .471 .889 r
.57708 .67012 m .5803 .67155 L .57742 .66928 L F
.489 .113 .253 r
.76432 .48776 m .76683 .4876 L .76746 .48549 L F
.505 .136 .274 r
.76683 .4876 m .77001 .48533 L .76746 .48549 L F
.708 .306 .283 r
.51486 .68782 m .51329 .6896 L .5113 .68871 L F
.466 .021 .107 r
.51684 .6889 m .51486 .68782 L .51707 .68725 L F
.51684 .6889 m .51329 .6896 L .51486 .68782 L F
.951 .675 .48 r
.5931 .59799 m .59469 .60116 L .59312 .60029 L F
.917 .703 .597 r
.5946 .60362 m .59312 .60029 L .59469 .60116 L F
0 .541 .806 r
.38593 .59318 m .38673 .59304 L .38454 .59318 L F
.38593 .59318 m .38847 .59358 L .38673 .59304 L F
.509 .181 .348 r
.50198 .65925 m .50476 .66026 L .50508 .65868 L F
0 0 .402 r
.57078 .65582 m .57116 .65478 L .57026 .65253 L F
0 .133 .661 r
.57154 .65802 m .57116 .65478 L .57078 .65582 L F
.459 .102 .271 r
.77267 .48534 m .77532 .48492 L .77573 .48268 L F
.337 .001 .239 r
.77573 .48268 m .77766 .48404 L .77835 .48213 L F
.77573 .48268 m .77532 .48492 L .77766 .48404 L F
.099 .623 .878 r
.39164 .59422 m .38847 .59358 L .3902 .59449 L F
.377 .674 .974 r
.39574 .59438 m .39635 .5931 L .39415 .59358 L F
.39574 .59438 m .3977 .59442 L .39635 .5931 L F
.101 0 0 r
.35644 .59759 m .3525 .59954 L .35424 .59787 L F
.53 .832 .508 r
.60857 .66439 m .60592 .66712 L .60536 .6669 L F
.60857 .66439 m .60719 .66577 L .60592 .66712 L F
0 0 .363 r
.61032 .6607 m .60857 .66439 L .61023 .66125 L F
.61032 .6607 m .6101 .66335 L .60857 .66439 L F
0 0 0 r
.6101 .66335 m .60719 .66577 L .60857 .66439 L F
.897 .854 .791 r
.57064 .63169 m .57249 .63274 L .57396 .62981 L F
.613 .345 .487 r
.58654 .5895 m .58882 .59162 L .58456 .59184 L F
.464 .278 .543 r
.49514 .69583 m .49739 .69185 L .4949 .6923 L F
.342 .231 .579 r
.4804 .64074 m .48119 .64169 L .48253 .64049 L F
.4804 .64074 m .48065 .64392 L .48119 .64169 L F
.838 .476 .369 r
.60362 .59678 m .60507 .59536 L .60322 .59477 L F
.60362 .59678 m .60547 .59731 L .60507 .59536 L F
.94 .593 .176 r
.59614 .60685 m .59517 .60598 L .5946 .60362 L F
.923 .63 .471 r
.59614 .60685 m .59456 .60826 L .59517 .60598 L F
.59614 .60685 m .59637 .60938 L .59456 .60826 L F
.681 .447 .56 r
.49477 .65005 m .49474 .65291 L .49172 .6525 L F
.404 .225 .521 r
.49661 .65186 m .49477 .65005 L .49554 .64999 L F
.27 .742 .94 r
.49554 .64999 m .49263 .64949 L .49477 .65005 L F
.869 .647 .599 r
.49308 .64679 m .49554 .64999 L .49553 .6464 L F
.49308 .64679 m .49263 .64949 L .49554 .64999 L F
.496 .104 .227 r
.49263 .64949 m .49485 .65056 L .49554 .64999 L F
0 .032 .565 r
.49553 .6464 m .49554 .64999 L .49683 .64743 L F
.694 .877 .488 r
.4956 .64988 m .49485 .65056 L .49683 .64743 L F
.49554 .64999 m .49551 .65002 L .4956 .64988 L F
.49551 .65002 m .49485 .65056 L .4956 .64988 L F
.404 .225 .521 r
.49661 .65186 m .49474 .65291 L .49476 .65119 L F
.49522 .65048 m .49476 .65119 L .49477 .65005 L F
.49661 .65186 m .49476 .65119 L .49522 .65048 L F
.491 .305 .556 r
.43802 .69321 m .44035 .69543 L .44015 .69287 L F
.345 .296 .659 r
.43802 .69321 m .43869 .69561 L .44035 .69543 L F
0 0 .095 r
.53105 .60681 m .53185 .60575 L .53212 .60377 L F
.834 .713 .73 r
.54748 .67546 m .54635 .67184 L .54788 .67315 L F
.533 .554 .822 r
.54896 .67202 m .54788 .67315 L .54635 .67184 L F
.54896 .67202 m .54748 .67546 L .54788 .67315 L F
.622 .412 .576 r
.44608 .67562 m .44856 .67561 L .44855 .67305 L F
.481 .265 .509 r
.44856 .67561 m .45101 .67269 L .44855 .67305 L F
.555 .537 .79 r
.53411 .64094 m .53526 .64429 L .53733 .64363 L F
.385 .112 .373 r
.53479 .64615 m .53733 .64363 L .53526 .64429 L F
.275 .777 .769 r
.19563 .54369 m .19558 .54393 L .19383 .54368 L F
.19563 .54369 m .19765 .54331 L .19558 .54393 L F
.461 .11 .283 r
.39954 .62724 m .40121 .62828 L .39931 .62863 L F
.484 .088 .214 r
.40195 .62713 m .40121 .62828 L .39954 .62724 L F
.589 .109 0 r
.559 .6333 m .5605 .63513 L .55821 .63245 L F
0 0 0 r
.51082 .68443 m .5123 .68404 L .51342 .68202 L F
0 0 .025 r
.51082 .68443 m .512 .68522 L .5123 .68404 L F
.51082 .68443 m .51031 .68626 L .512 .68522 L F
.308 .758 .958 r
.38197 .58341 m .38117 .58414 L .37984 .58381 L F
.38197 .58341 m .38336 .58397 L .38117 .58414 L F
.098 0 .222 r
.48882 .71743 m .48666 .72046 L .48636 .71779 L F
.207 0 .104 r
.49482 .62403 m .49176 .62641 L .49388 .62614 L F
.233 0 .138 r
.49714 .62315 m .49482 .62403 L .49388 .62614 L F
.925 .544 .252 r
.59399 .62401 m .59326 .6253 L .59304 .62324 L F
.59399 .62401 m .59428 .62583 L .59326 .6253 L F
.934 .703 .564 r
.61114 .62286 m .61341 .62109 L .6126 .62046 L F
.61114 .62286 m .61313 .62356 L .61341 .62109 L F
.917 .597 .122 r
.5579 .66157 m .55816 .66371 L .55892 .66441 L F
.668 .197 0 r
.55816 .66371 m .56047 .66658 L .55892 .66441 L F
.366 .066 .316 r
.45339 .66988 m .45541 .66936 L .45622 .66663 L F
.497 .269 .498 r
.45622 .66663 m .45827 .66612 L .45858 .66431 L F
.419 .109 .33 r
.45541 .66936 m .45827 .66612 L .45622 .66663 L F
.973 .686 .42 r
.59012 .59245 m .59023 .59478 L .58882 .59162 L F
.49 .464 .755 r
.59334 .64739 m .5931 .65014 L .59108 .64903 L F
.54 .617 .878 r
.4046 .59633 m .40591 .59397 L .40362 .59437 L F
.4046 .59633 m .40738 .59671 L .40591 .59397 L F
.535 .819 .998 r
.24883 .75038 m .24509 .74999 L .24677 .75092 L F
.24677 .75092 m .24509 .74999 L .24883 .75038 L F
.799 .513 .506 r
.59592 .5827 m .59905 .581 L .59581 .58026 L F
.59592 .5827 m .59929 .58324 L .59905 .581 L F
.4 .667 .968 r
.7936 .48379 m .79794 .48508 L .79741 .48562 L F
.569 .929 .769 r
.79741 .48562 m .79981 .48364 L .79988 .48496 L F
.79741 .48562 m .79794 .48508 L .79981 .48364 L F
.476 .872 .965 r
.74 .51239 m .74237 .51159 L .74344 .51188 L F
.335 .569 .925 r
.74476 .51074 m .74344 .51188 L .74237 .51159 L F
.74476 .51074 m .74561 .51211 L .74344 .51188 L F
.607 .144 .128 r
.52322 .63314 m .52562 .63453 L .52671 .63315 L F
.089 0 0 r
.52671 .63315 m .5278 .6337 L .52908 .63319 L F
.52671 .63315 m .52562 .63453 L .5278 .6337 L F
0 0 .487 r
.58088 .64477 m .58007 .6466 L .57954 .64524 L F
.265 0 .067 r
.31644 .5896 m .31695 .59128 L .31867 .5892 L F
.31644 .5896 m .31463 .59225 L .31695 .59128 L F
.259 .767 .848 r
.36229 .59673 m .35864 .59709 L .36016 .59698 L F
.92 .701 .589 r
.60859 .61132 m .61139 .6096 L .60975 .60836 L F
.342 .094 .387 r
.45827 .66612 m .46054 .66372 L .45858 .66431 L F
.532 .138 .24 r
.51342 .68202 m .5123 .68404 L .51567 .68315 L F
.511 .186 .354 r
.51342 .68202 m .51567 .68315 L .51578 .68165 L F
.623 .556 .758 r
.24082 .75127 m .24227 .75053 L .24065 .7507 L F
.457 .478 .793 r
.34161 .61438 m .34006 .616 L .33886 .61238 L F
.36 .331 .69 r
.34161 .61438 m .34208 .61761 L .34006 .616 L F
.572 .774 .974 r
.75723 .50868 m .75397 .50777 L .75599 .50557 L F
.597 .756 .954 r
.75817 .50686 m .75723 .50868 L .75599 .50557 L F
.75817 .50686 m .75976 .50813 L .75723 .50868 L F
.832 .681 .696 r
.4762 .66376 m .47934 .66206 L .47593 .66271 L F
.716 .352 .358 r
.47593 .66271 m .47934 .66206 L .479 .66403 L F
.822 .672 .698 r
.48116 .66097 m .479 .66403 L .47934 .66206 L F
.388 .531 .879 r
.75117 .52181 m .75161 .52358 L .75312 .52196 L F
.504 .717 .968 r
.75161 .52358 m .75428 .52335 L .75312 .52196 L F
.497 .267 .495 r
.44087 .67854 m .44306 .67815 L .44361 .67577 L F
.495 .193 .383 r
.44306 .67815 m .44608 .67562 L .44361 .67577 L F
.81 .322 0 r
.53762 .61866 m .53721 .61959 L .53655 .61807 L F
.701 .17 0 r
.53762 .61866 m .54028 .62095 L .53721 .61959 L F
0 .261 .652 r
.35376 .62267 m .35538 .62352 L .35694 .62439 L F
.226 .701 .938 r
.35748 .62382 m .35694 .62439 L .35538 .62352 L F
.35748 .62382 m .35906 .62442 L .35694 .62439 L F
.585 .749 .955 r
.52224 .64584 m .52287 .64721 L .52082 .6475 L F
.279 0 .216 r
.4977 .69113 m .49739 .69185 L .49981 .69047 L F
.613 .513 .717 r
.5688 .6052 m .56923 .60952 L .56661 .6097 L F
0 0 0 r
.56776 .60833 m .5688 .6052 L .56661 .6097 L F
.419 0 .044 r
.56923 .60952 m .56829 .61057 L .56661 .6097 L F
.102 .209 .691 r
.56661 .6097 m .56829 .61057 L .56776 .60833 L F
.565 .383 .593 r
.50214 .64642 m .49973 .6492 L .4998 .64708 L F
.584 .396 .592 r
.54536 .70471 m .54782 .70438 L .54773 .70179 L F
.54536 .70471 m .54782 .70438 L .54773 .70179 L F
.365 .145 .441 r
.30563 .59788 m .30793 .59482 L .30553 .59529 L F
.295 0 0 r
.39108 .63217 m .38738 .63386 L .38896 .63233 L F
.602 .128 .101 r
.73145 .50312 m .73506 .50277 L .73264 .5052 L F
0 .484 .708 r
.58184 .65241 m .58614 .65311 L .5821 .65397 L F
.73 .79 .9 r
.73611 .49686 m .73764 .49842 L .73939 .49638 L F
.46 .283 .553 r
.44082 .68134 m .44306 .67815 L .44087 .67854 L F
.961 .743 .564 r
.6111 .62521 m .61357 .62699 L .61313 .62356 L F
.959 .647 .391 r
.61282 .62795 m .61357 .62699 L .6111 .62521 L F
.999 .789 .464 r
.61282 .62795 m .61391 .62607 L .61357 .62699 L F
.61282 .62795 m .614 .62994 L .61391 .62607 L F
0 .128 .582 r
.51406 .64604 m .51062 .64345 L .51328 .64484 L F
.402 .181 .461 r
.34104 .60666 m .34048 .60938 L .33872 .6098 L F
.336 .123 .435 r
.34294 .60741 m .34104 .60666 L .34326 .60609 L F
.34294 .60741 m .34048 .60938 L .34104 .60666 L F
.945 .714 .557 r
.31201 .63979 m .31263 .64012 L .314 .63801 L F
.318 .163 .508 r
.43897 .68463 m .44063 .68414 L .44082 .68134 L F
.369 .313 .663 r
.43897 .68463 m .4412 .68671 L .44063 .68414 L F
.373 .313 .661 r
.43951 .68708 m .4412 .68671 L .43897 .68463 L F
.425 0 0 r
.55564 .66977 m .55436 .67118 L .5504 .67064 L F
.453 .004 .093 r
.5586 .66892 m .55436 .67118 L .55564 .66977 L F
.543 .338 .552 r
.47078 .68195 m .46941 .6836 L .46867 .68182 L F
.47078 .68195 m .47252 .68354 L .46941 .6836 L F
0 0 .214 r
.47329 .68145 m .47252 .68354 L .47078 .68195 L F
.633 .293 .378 r
.58356 .59181 m .5829 .59425 L .58051 .59235 L F
.581 .289 .438 r
.58456 .59184 m .5829 .59425 L .58356 .59181 L F
0 0 .073 r
.61279 .64904 m .61249 .65166 L .61195 .65287 L F
0 0 .455 r
.61309 .65387 m .61195 .65287 L .61249 .65166 L F
.61309 .65387 m .61265 .65565 L .61195 .65287 L F
.732 .83 .925 r
.75428 .52335 m .75765 .52343 L .75656 .52226 L F
.735 .859 .939 r
.75656 .52226 m .75765 .52343 L .75925 .5216 L F
.733 .952 .948 r
.75765 .52343 m .75945 .52243 L .75925 .5216 L F
.756 .476 .509 r
.26356 .86232 m .26545 .86002 L .26451 .86004 L F
.83 .704 .725 r
.54748 .67546 m .54869 .67874 L .54532 .67823 L F
.589 .21 .291 r
.54869 .67874 m .5451 .68067 L .54532 .67823 L F
.54869 .67874 m .54754 .68099 L .5451 .68067 L F
.386 .392 .744 r
.54971 .67506 m .54869 .67874 L .54748 .67546 L F
.54971 .67506 m .55024 .67838 L .54869 .67874 L F
.665 .292 .329 r
.55102 .68076 m .54869 .67874 L .55024 .67838 L F
.55102 .68076 m .54754 .68099 L .54869 .67874 L F
.851 .892 .867 r
.53903 .68022 m .5379 .6795 L .53876 .67885 L F
.5392 .67913 m .53876 .67885 L .53931 .67842 L F
.53903 .68022 m .53876 .67885 L .5392 .67913 L F
.439 .355 .665 r
.53931 .67842 m .54165 .6804 L .5398 .681 L F
.646 .319 .405 r
.5379 .6795 m .54165 .6804 L .53931 .67842 L F
.877 .705 .666 r
.5367 .67454 m .53837 .67738 L .53501 .67678 L F
.53837 .67738 m .53935 .67904 L .53722 .67793 L F
.53837 .67738 m .53722 .67793 L .53501 .67678 L F
0 .475 .841 r
.53638 .67733 m .53763 .67805 L .53733 .67771 L F
.53763 .67805 m .53935 .67904 L .53733 .67771 L F
0 .23 .748 r
.53927 .67667 m .53935 .67904 L .5367 .67454 L F
.876 .993 .764 r
.53773 .67547 m .53662 .67691 L .53733 .67771 L F
0 .475 .841 r
.53501 .67678 m .53777 .67822 L .53638 .67733 L F
.53777 .67822 m .53935 .67904 L .53638 .67733 L F
.456 .872 .739 r
.53733 .67771 m .53447 .67928 L .5328 .67603 L F
.53733 .67771 m .5328 .67603 L .53501 .67678 L F
.876 .993 .764 r
.53662 .67691 m .53544 .67844 L .53733 .67771 L F
.456 .872 .739 r
.53733 .67771 m .53544 .67844 L .53458 .67918 L F
.5351 .67894 m .53458 .67918 L .53447 .67928 L F
.53733 .67771 m .53458 .67918 L .5351 .67894 L F
.78 .65 .719 r
.7399 .48805 m .74273 .49039 L .74933 .4884 L F
.088 .25 .736 r
.56795 .64683 m .56919 .65022 L .56998 .64884 L F
0 0 .483 r
.57026 .65253 m .56998 .64884 L .56919 .65022 L F
.802 .321 0 r
.7441 .48375 m .74557 .48498 L .74473 .4833 L F
.77 .304 .136 r
.74473 .4833 m .74557 .48498 L .74822 .48564 L F
.354 0 .166 r
.41247 .62144 m .4097 .62322 L .41058 .62176 L F
.48 .235 .465 r
.58176 .58386 m .5841 .58325 L .58424 .58109 L F
.489 .203 .406 r
.58633 .5826 m .58424 .58109 L .5841 .58325 L F
.58633 .5826 m .58675 .58071 L .58424 .58109 L F
.454 .301 .584 r
.49977 .66442 m .49854 .66776 L .50018 .66685 L F
0 0 0 r
.50018 .66685 m .49854 .66776 L .49977 .66442 L F
.646 .353 .46 r
.50299 .66658 m .49977 .66442 L .50018 .66685 L F
.50299 .66658 m .50386 .66464 L .49977 .66442 L F
.222 0 0 r
.45358 .71075 m .44994 .71249 L .45079 .71016 L F
.45358 .71075 m .4522 .7121 L .44994 .71249 L F
.024 0 0 r
.45456 .71118 m .45358 .71075 L .45626 .71168 L F
.45456 .71118 m .4522 .7121 L .45358 .71075 L F
.936 .574 .301 r
.53542 .61516 m .53655 .61807 L .53424 .61653 L F
.53 .411 .662 r
.34048 .60938 m .33886 .61238 L .33872 .6098 L F
.718 .509 .606 r
.57043 .59742 m .57281 .5978 L .57268 .59953 L F
.471 .233 .471 r
.57281 .5978 m .57498 .60009 L .57268 .59953 L F
.57281 .5978 m .57536 .59767 L .57498 .60009 L F
.976 .725 .312 r
.72513 .48592 m .72514 .4883 L .72436 .48706 L F
.532 .409 .657 r
.72513 .48592 m .72849 .48562 L .72755 .48405 L F
.748 .719 .825 r
.72514 .4883 m .72513 .48592 L .72436 .48706 L F
.72514 .4883 m .72849 .48562 L .72513 .48592 L F
0 0 .107 r
.30979 .62652 m .30893 .63005 L .30989 .62864 L F
.956 .821 .67 r
.77554 .5254 m .7763 .52809 L .77822 .52692 L F
.371 .513 .87 r
.7763 .52809 m .77905 .52895 L .77822 .52692 L F
.897 .854 .791 r
.57064 .63169 m .57396 .62981 L .57274 .62892 L F
.375 .143 .429 r
.53246 .64732 m .53454 .64845 L .53479 .64615 L F
.08 .152 .64 r
.53454 .64845 m .53632 .65035 L .53656 .64821 L F
.59 .945 .909 r
.53656 .64821 m .53636 .64827 L .53454 .64845 L F
.375 .143 .429 r
.53204 .64869 m .5315 .65047 L .53454 .64845 L F
.566 .492 .731 r
.53293 .65209 m .53454 .64845 L .5315 .65047 L F
.53293 .65209 m .53525 .65162 L .53454 .64845 L F
.08 .152 .64 r
.53508 .64903 m .53525 .65162 L .53632 .65035 L F
.53454 .64845 m .53475 .64939 L .53508 .64903 L F
.53475 .64939 m .53525 .65162 L .53508 .64903 L F
.59 .945 .909 r
.53636 .64827 m .53219 .64944 L .53454 .64845 L F
.53558 .64849 m .53521 .64829 L .53219 .64944 L F
.53656 .64821 m .5358 .64826 L .53558 .64849 L F
.5358 .64826 m .53521 .64829 L .53558 .64849 L F
.375 .143 .429 r
.53246 .64732 m .53204 .64869 L .53454 .64845 L F
.294 0 0 r
.56154 .59142 m .56394 .59099 L .56515 .58945 L F
.436 .009 .129 r
.56655 .59093 m .56515 .58945 L .56394 .59099 L F
.56655 .59093 m .56761 .58931 L .56515 .58945 L F
.633 .42 .576 r
.5161 .64707 m .51759 .64695 L .51406 .64604 L F
.5161 .64707 m .51757 .6494 L .51759 .64695 L F
0 0 .01 r
.51538 .65161 m .51757 .6494 L .5161 .64707 L F
.254 0 0 r
.36904 .63873 m .36729 .63984 L .36499 .64005 L F
.067 0 0 r
.37123 .63826 m .36729 .63984 L .36904 .63873 L F
.073 .537 .9 r
.57043 .59742 m .57088 .59688 L .56906 .59645 L F
0 0 .361 r
.57135 .60003 m .57043 .59742 L .57031 .60073 L F
.352 .67 .975 r
.40261 .58612 m .39871 .58459 L .40162 .58475 L F
.399 .614 .937 r
.40358 .5845 m .40261 .58612 L .40162 .58475 L F
.40358 .5845 m .40456 .58609 L .40261 .58612 L F
.909 .821 .354 r
.61272 .63705 m .61351 .6353 L .61328 .63471 L F
.61272 .63705 m .61298 .63817 L .61351 .6353 L F
.155 0 0 r
.79649 .52372 m .79899 .52357 L .79829 .52412 L F
0 .026 .521 r
.79783 .52369 m .79829 .52412 L .79787 .52372 L F
.761 .692 .786 r
.79713 .51855 m .79783 .52369 L .79489 .52108 L F
0 .026 .521 r
.79783 .52369 m .79787 .52372 L .79671 .52259 L F
0 0 0 r
.79783 .52369 m .79899 .52357 L .79777 .52365 L F
.79783 .52369 m .79777 .52365 L .79649 .52372 L F
.155 0 0 r
.79649 .52372 m .79829 .52412 L .79783 .52369 L F
.301 .091 .418 r
.49784 .66945 m .49617 .67027 L .49568 .67258 L F
.49784 .66945 m .49617 .67027 L .49568 .67258 L F
.67 .395 .496 r
.54279 .66728 m .54267 .66957 L .5394 .66908 L F
.752 .597 .684 r
.54578 .66659 m .54267 .66957 L .54279 .66728 L F
.57 .582 .826 r
.43059 .59725 m .42976 .60096 L .42872 .59739 L F
.43059 .59725 m .43197 .60051 L .42976 .60096 L F
0 0 0 r
.53212 .60377 m .53305 .60293 L .53475 .60111 L F
.224 0 .285 r
.53212 .60377 m .53359 .60467 L .53305 .60293 L F
.53212 .60377 m .53185 .60575 L .53359 .60467 L F
.138 0 .113 r
.49176 .62641 m .48932 .62937 L .49125 .62861 L F
.26 0 .207 r
.49388 .62614 m .49176 .62641 L .49125 .62861 L F
0 0 0 r
.53475 .60111 m .5364 .60038 L .53667 .60002 L F
.53475 .60111 m .53305 .60293 L .5364 .60038 L F
.122 0 0 r
.39808 .61419 m .40154 .61218 L .39929 .61261 L F
0 0 .422 r
.59523 .61557 m .59517 .61377 L .59463 .61184 L F
.953 .899 .516 r
.5941 .61718 m .59517 .61377 L .59523 .61557 L F
.595 .83 .988 r
.56906 .59645 m .56502 .59612 L .56633 .59622 L F
.012 0 0 r
.45835 .69051 m .45708 .69188 L .45486 .69239 L F
.085 0 .357 r
.45646 .69383 m .45486 .69239 L .45708 .69188 L F
.45646 .69383 m .4553 .69501 L .45486 .69239 L F
.242 .149 .545 r
.26545 .86002 m .26599 .86249 L .26503 .86288 L F
.756 .476 .509 r
.26356 .86232 m .26599 .86249 L .26545 .86002 L F
0 0 .232 r
.47409 .66742 m .4753 .66464 L .47574 .66574 L F
.469 .553 .86 r
.47574 .66574 m .4766 .66708 L .47409 .66742 L F
.503 .498 .783 r
.47716 .66948 m .47409 .66742 L .4766 .66708 L F
.749 .636 .735 r
.47252 .68354 m .46853 .68681 L .46941 .6836 L F
.763 .694 .786 r
.46098 .70395 m .46424 .70464 L .46282 .7012 L F
.998 .795 .451 r
.46309 .706 m .46424 .70464 L .46098 .70395 L F
.46309 .706 m .46379 .70704 L .46424 .70464 L F
.84 .571 .531 r
.46379 .70704 m .46712 .70848 L .46424 .70464 L F
.617 .645 .855 r
.46424 .70464 m .46515 .70092 L .46282 .7012 L F
.46424 .70464 m .46693 .70428 L .46515 .70092 L F
.36 .446 .814 r
.46424 .70464 m .46686 .70642 L .46693 .70428 L F
.46424 .70464 m .46712 .70848 L .46686 .70642 L F
.595 .44 .642 r
.54782 .70438 m .54512 .70687 L .54536 .70471 L F
.54782 .70438 m .54512 .70687 L .54536 .70471 L F
.214 .569 .939 r
.74519 .51953 m .7461 .51856 L .74392 .51814 L F
.74519 .51953 m .74701 .51978 L .7461 .51856 L F
.605 .745 .944 r
.80142 .50505 m .80585 .50604 L .80382 .50436 L F
.752 .425 .43 r
.80369 .50778 m .80585 .50604 L .80142 .50505 L F
.192 0 .072 r
.80639 .50283 m .80585 .50604 L .80691 .50524 L F
.80639 .50283 m .80382 .50436 L .80585 .50604 L F
.08 0 .353 r
.8064 .50731 m .80585 .50604 L .80369 .50778 L F
.8064 .50731 m .80691 .50524 L .80585 .50604 L F
.584 .587 .822 r
.43911 .60694 m .43803 .60926 L .43668 .60698 L F
.43911 .60694 m .44034 .60934 L .43803 .60926 L F
.643 .447 .603 r
.44034 .60934 m .43852 .61163 L .43803 .60926 L F
.239 0 .236 r
.50018 .66685 m .49854 .66776 L .49784 .66945 L F
.499 .727 .974 r
.27508 .68288 m .27644 .68434 L .27406 .68446 L F
.27508 .68288 m .27644 .68434 L .27406 .68446 L F
0 0 .366 r
.61294 .64317 m .61307 .64663 L .61273 .64421 L F
0 0 0 r
.54839 .64044 m .5476 .64394 L .54653 .64192 L F
.495 .229 .44 r
.39122 .61816 m .3935 .61771 L .39395 .6156 L F
.441 .181 .422 r
.39395 .6156 m .39571 .61712 L .39606 .61482 L F
.39395 .6156 m .3935 .61771 L .39571 .61712 L F
.527 .215 .382 r
.42632 .61514 m .42353 .61723 L .42393 .61526 L F
.292 .642 .967 r
.20496 .54552 m .20483 .54693 L .20332 .54542 L F
.20496 .54552 m .20729 .54723 L .20483 .54693 L F
.832 .394 .193 r
.57687 .63788 m .5778 .63961 L .57879 .6384 L F
.533 .279 .476 r
.57879 .6384 m .58121 .63804 L .58089 .64046 L F
.354 .273 .625 r
.57879 .6384 m .58089 .64046 L .57918 .64091 L F
.7 .216 .095 r
.5778 .63961 m .58089 .64046 L .57879 .6384 L F
.533 .279 .476 r
.57879 .6384 m .58121 .63804 L .58089 .64046 L F
.326 .789 .94 r
.49023 .64898 m .48681 .6489 L .48797 .64931 L F
.48797 .64931 m .48681 .6489 L .49023 .64898 L F
.397 0 0 r
.54561 .6238 m .5442 .62322 L .54148 .62176 L F
0 .312 .749 r
.54148 .62176 m .5442 .62322 L .543 .62222 L F
.411 .784 .993 r
.38336 .58397 m .38554 .5837 L .38705 .5845 L F
.399 .792 .988 r
.38554 .5837 m .38933 .58414 L .38705 .5845 L F
.52 .832 1 r
.27457 .83277 m .27375 .83403 L .27265 .83325 L F
.046 .194 .695 r
.27457 .83277 m .27586 .83668 L .27375 .83403 L F
.539 .342 .562 r
.27375 .83403 m .27586 .83668 L .27357 .83666 L F
0 0 .127 r
.27375 .83403 m .27357 .83666 L .27409 .8357 L F
.27375 .83403 m .27409 .8357 L .27265 .83325 L F
.425 .463 .796 r
.33411 .64033 m .3345 .6375 L .3323 .63838 L F
.33411 .64033 m .33593 .64124 L .3345 .6375 L F
.435 .233 .506 r
.51222 .65246 m .51405 .65422 L .51538 .65161 L F
0 0 .01 r
.51538 .65161 m .5168 .65122 L .51757 .6494 L F
.567 .338 .528 r
.51405 .65422 m .5168 .65122 L .51538 .65161 L F
.721 .622 .747 r
.3041 .63177 m .30768 .63174 L .30652 .62877 L F
.647 .626 .814 r
.30768 .63174 m .30893 .63005 L .30652 .62877 L F
.30768 .63174 m .3085 .63158 L .30893 .63005 L F
0 .189 .638 r
.44971 .70765 m .44911 .70715 L .44617 .70515 L F
.997 .849 .514 r
.44971 .70765 m .44852 .70959 L .44882 .70691 L F
.524 .435 .697 r
.44617 .70515 m .44911 .70715 L .4483 .70524 L F
.997 .849 .514 r
.44971 .70765 m .44916 .70719 L .44922 .70534 L F
.44916 .70719 m .44911 .70715 L .44914 .70667 L F
.44916 .70719 m .44914 .70667 L .44922 .70534 L F
.343 .355 .728 r
.4483 .70524 m .44914 .70667 L .44908 .70475 L F
.44914 .70667 m .44962 .7075 L .44908 .70466 L F
.997 .849 .514 r
.44922 .70534 m .44882 .70691 L .44905 .70487 L F
.343 .355 .728 r
.4483 .70524 m .45017 .70406 L .45029 .7034 L F
.4483 .70524 m .44908 .70475 L .44908 .70466 L F
.997 .849 .514 r
.44909 .70471 m .44905 .70487 L .44908 .70466 L F
.44922 .70534 m .44905 .70487 L .44909 .70471 L F
.343 .355 .728 r
.44908 .70475 m .44978 .70617 L .45017 .70406 L F
.4483 .70524 m .44885 .70558 L .44908 .70475 L F
.903 .74 .67 r
.44908 .70466 m .44905 .70487 L .44902 .70489 L F
.524 .435 .697 r
.44911 .70715 m .44914 .70667 L .4483 .70524 L F
.903 .74 .67 r
.44905 .70487 m .44852 .70959 L .44809 .70829 L F
.343 .355 .728 r
.44885 .70558 m .44889 .70561 L .44905 .70487 L F
.44885 .70558 m .44905 .70487 L .44908 .70475 L F
.44889 .70561 m .44926 .70584 L .44908 .70475 L F
.744 .501 0 r
.44909 .70474 m .44962 .7075 L .44909 .70471 L F
.343 .355 .728 r
.44926 .70584 m .44978 .70617 L .4491 .70479 L F
.44926 .70584 m .4491 .70479 L .44908 .70475 L F
.744 .501 0 r
.44909 .70471 m .44962 .7075 L .44971 .70765 L F
.44908 .70466 m .44909 .70474 L .44909 .70471 L F
.343 .355 .728 r
.44885 .70558 m .44908 .70466 L .44978 .70617 L F
.4483 .70524 m .44908 .70466 L .44885 .70558 L F
.903 .74 .67 r
.44908 .70466 m .44902 .70489 L .44731 .70593 L F
.44905 .70487 m .44809 .70829 L .44731 .70593 L F
.524 .435 .697 r
.44911 .70715 m .44962 .7075 L .44914 .70667 L F
.997 .849 .514 r
.44911 .70715 m .44882 .70691 L .44922 .70534 L F
0 .189 .638 r
.44971 .70765 m .44962 .7075 L .44911 .70715 L F
.858 .511 .395 r
.44971 .70765 m .45079 .71016 L .44852 .70959 L F
0 0 0 r
.26503 .86288 m .26599 .86249 L .26451 .86361 L F
.677 .531 .679 r
.45447 .68728 m .45215 .69028 L .45274 .68796 L F
0 0 .132 r
.52598 .65845 m .52724 .65715 L .52787 .65323 L F
.245 .051 .407 r
.52787 .65323 m .53105 .65345 L .52964 .6527 L F
.243 0 .318 r
.52787 .65323 m .52733 .65661 L .52938 .65487 L F
.53065 .65343 m .52938 .65487 L .53105 .65345 L F
.52787 .65323 m .52938 .65487 L .53065 .65343 L F
.033 0 0 r
.53366 .65491 m .53145 .65753 L .53077 .65785 L F
.53366 .65491 m .53268 .65741 L .53145 .65753 L F
.383 0 .116 r
.53524 .65653 m .53268 .65741 L .53366 .65491 L F
.691 .567 .71 r
.53309 .65491 m .53268 .65741 L .53524 .65653 L F
.53163 .65382 m .53207 .65529 L .53309 .65491 L F
.53207 .65529 m .53268 .65741 L .53309 .65491 L F
0 .096 .621 r
.53264 .65672 m .53268 .65741 L .53249 .65676 L F
.53264 .65672 m .53249 .65676 L .53207 .65529 L F
.5326 .65615 m .53264 .65672 L .53207 .65529 L F
.886 .491 .272 r
.5326 .656 m .53454 .65837 L .53268 .65741 L F
.59 .329 .489 r
.53022 .65598 m .52869 .65792 L .53291 .65664 L F
.243 0 .318 r
.52733 .65661 m .52724 .65715 L .52867 .65576 L F
.59 .329 .489 r
.52873 .65561 m .53291 .65664 L .53289 .65661 L F
.243 0 .318 r
.52733 .65661 m .52867 .65576 L .52879 .65544 L F
.59 .329 .489 r
.52847 .65555 m .52873 .65561 L .52873 .65561 L F
.52873 .65561 m .53291 .65664 L .52873 .65561 L F
.243 0 .318 r
.52883 .65533 m .52994 .65453 L .53105 .65345 L F
.52733 .65661 m .52879 .65544 L .52883 .65533 L F
.52879 .65544 m .52994 .65453 L .52883 .65533 L F
.59 .329 .489 r
.52875 .65558 m .53289 .65661 L .5326 .656 L F
.52847 .65555 m .52873 .65561 L .52875 .65558 L F
.52873 .65561 m .53289 .65661 L .52875 .65558 L F
0 .096 .621 r
.5326 .656 m .5326 .65615 L .5318 .65439 L F
.5326 .65615 m .53207 .65529 L .5318 .65439 L F
.5326 .656 m .5318 .65439 L .53163 .65382 L F
.579 .425 .637 r
.52907 .65523 m .5326 .656 L .53163 .65382 L F
.243 0 .318 r
.52895 .65532 m .52867 .65576 L .52994 .65453 L F
.52879 .65544 m .52873 .65561 L .52895 .65532 L F
.579 .425 .637 r
.52875 .65558 m .5326 .656 L .52907 .65523 L F
.243 0 .318 r
.52873 .65561 m .52867 .65576 L .52895 .65532 L F
.579 .425 .637 r
.52847 .65555 m .52875 .65558 L .52907 .65523 L F
.491 .327 .586 r
.53105 .65345 m .52994 .65453 L .52847 .65555 L F
.831 .455 .342 r
.53105 .65345 m .53293 .65209 L .53085 .65248 L F
.53025 .65303 m .53085 .65248 L .52964 .6527 L F
.53105 .65345 m .53085 .65248 L .53025 .65303 L F
.579 .425 .637 r
.52847 .65555 m .52916 .65496 L .52952 .654 L F
.491 .327 .586 r
.53105 .65345 m .52847 .65555 L .53051 .65381 L F
.53105 .65345 m .53051 .65381 L .52966 .65353 L F
.53051 .65381 m .52925 .65406 L .52966 .65353 L F
.66 .385 .493 r
.53105 .65345 m .52632 .65167 L .52805 .65096 L F
.53105 .65345 m .52575 .65375 L .52632 .65167 L F
.036 .467 .88 r
.53008 .65247 m .53163 .65382 L .53105 .65345 L F
.53008 .65247 m .53105 .65345 L .52842 .65126 L F
.53008 .65247 m .52842 .65126 L .52805 .65096 L F
.831 .455 .342 r
.53105 .65345 m .53163 .65382 L .53293 .65209 L F
.501 .055 .121 r
.53293 .65209 m .53163 .65382 L .53415 .65352 L F
.091 0 0 r
.53663 .653 m .53554 .65463 L .53366 .65491 L F
.383 0 .116 r
.53524 .65653 m .53366 .65491 L .53554 .65463 L F
.691 .567 .71 r
.53163 .65382 m .53524 .65653 L .53415 .65352 L F
.501 .055 .121 r
.53293 .65209 m .53415 .65352 L .53525 .65162 L F
.44 .299 .592 r
.53415 .65352 m .53632 .65035 L .53525 .65162 L F
.53415 .65352 m .53652 .65325 L .53632 .65035 L F
.729 .46 .521 r
.53895 .65274 m .53554 .65463 L .53663 .653 L F
.53895 .65274 m .54194 .65672 L .53554 .65463 L F
.201 .268 .709 r
.53415 .65352 m .53677 .6545 L .53652 .65325 L F
.73 .695 .817 r
.53953 .65655 m .53882 .65692 L .54194 .65672 L F
.698 .782 .916 r
.54194 .65672 m .53944 .65665 L .53953 .65655 L F
.54194 .65672 m .53529 .65625 L .53554 .65463 L F
.73 .695 .817 r
.54107 .65574 m .53953 .65655 L .54194 .65672 L F
.698 .782 .916 r
.53944 .65665 m .53882 .65692 L .53524 .65653 L F
.54194 .65672 m .53882 .65692 L .53944 .65665 L F
.385 0 0 r
.54012 .65809 m .53904 .65712 L .54024 .6563 L F
.54097 .65598 m .54024 .6563 L .54107 .65574 L F
.54012 .65809 m .54024 .6563 L .54097 .65598 L F
.53904 .65712 m .53882 .65692 L .53953 .65655 L F
.53904 .65712 m .53953 .65655 L .54107 .65574 L F
.847 .996 .765 r
.53454 .65837 m .53524 .65653 L .53754 .65848 L F
.53454 .65837 m .53479 .65793 L .53524 .65653 L F
.698 .782 .916 r
.53953 .65655 m .53524 .65653 L .53533 .65625 L F
.53944 .65665 m .53524 .65653 L .53953 .65655 L F
.683 .236 .184 r
.53882 .65692 m .53754 .65848 L .53578 .65699 L F
.53635 .65665 m .53578 .65699 L .53524 .65653 L F
.53882 .65692 m .53578 .65699 L .53635 .65665 L F
.735 .534 .621 r
.53419 .66031 m .53145 .65753 L .53268 .65741 L F
.53419 .66031 m .53112 .6605 L .53145 .65753 L F
.287 .484 .877 r
.53454 .65837 m .53419 .66031 L .5341 .66013 L F
.53454 .65837 m .5341 .66013 L .53268 .65741 L F
.627 .437 .605 r
.53145 .65753 m .53112 .6605 L .52832 .66044 L F
.472 .18 .388 r
.53112 .6605 m .52828 .66284 L .52832 .66044 L F
0 0 0 r
.52978 .66118 m .53293 .65666 L .52869 .65792 L F
.886 .491 .272 r
.53277 .65622 m .5336 .65874 L .53454 .65837 L F
0 0 0 r
.53293 .65666 m .53295 .65662 L .53291 .65664 L F
.53293 .65666 m .53291 .65664 L .52869 .65792 L F
.53097 .65947 m .53182 .65891 L .53247 .6576 L F
.53259 .65715 m .53247 .6576 L .53292 .65669 L F
.53097 .65947 m .53247 .6576 L .53259 .65715 L F
.52978 .66118 m .53292 .65669 L .53293 .65666 L F
.752 .694 .795 r
.53182 .65891 m .53282 .65904 L .53295 .65662 L F
.53108 .66043 m .53276 .65909 L .53182 .65891 L F
.53276 .65909 m .53277 .65908 L .53182 .65891 L F
.53277 .65908 m .53276 .65904 L .53182 .65891 L F
.628 .192 .194 r
.53277 .65909 m .53184 .65984 L .53216 .65869 L F
.429 .141 .372 r
.53284 .66184 m .53112 .6605 L .53419 .66031 L F
.866 .938 .565 r
.53454 .65837 m .53284 .66184 L .53419 .66031 L F
.386 .205 .509 r
.53555 .6607 m .53284 .66184 L .53454 .65837 L F
.573 .41 .622 r
.53555 .6607 m .53285 .66321 L .53284 .66184 L F
.752 .694 .795 r
.53108 .66043 m .53498 .66108 L .53282 .65904 L F
.628 .192 .194 r
.53352 .65959 m .53289 .65968 L .53277 .65909 L F
.53289 .65968 m .53184 .65984 L .53277 .65909 L F
.752 .694 .795 r
.53277 .65908 m .53282 .65904 L .53276 .65904 L F
.886 .491 .272 r
.53277 .65718 m .53282 .65904 L .53289 .6568 L F
0 0 0 r
.53293 .65666 m .53292 .65669 L .53295 .65662 L F
.886 .491 .272 r
.53276 .65645 m .53277 .65718 L .53289 .6568 L F
.5326 .656 m .53261 .65627 L .53276 .65645 L F
.53261 .65627 m .53282 .65904 L .53276 .65645 L F
.59 .329 .489 r
.53289 .65661 m .53291 .65664 L .53291 .65664 L F
.5329 .65661 m .53291 .65664 L .53295 .65662 L F
.53289 .65661 m .53291 .65664 L .5329 .65661 L F
.53289 .65661 m .5329 .65661 L .5326 .656 L F
.886 .491 .272 r
.5326 .656 m .5329 .65661 L .53277 .65622 L F
.59 .329 .489 r
.5329 .65661 m .53295 .65662 L .5326 .656 L F
.886 .491 .272 r
.5326 .656 m .5336 .65874 L .5329 .65661 L F
.861 .465 .287 r
.53295 .65662 m .53282 .65904 L .5326 .656 L F
.886 .491 .272 r
.53289 .6568 m .53282 .65904 L .5336 .65874 L F
.847 .996 .765 r
.53479 .65793 m .53677 .6545 L .53524 .65653 L F
.698 .782 .916 r
.53533 .65625 m .53524 .65653 L .53529 .65625 L F
.201 .268 .709 r
.53517 .65634 m .53524 .65653 L .53677 .6545 L F
.53415 .65352 m .53517 .65634 L .53677 .6545 L F
.579 .425 .637 r
.52952 .654 m .53125 .65349 L .53008 .65247 L F
.52911 .65511 m .53095 .65372 L .52952 .654 L F
.53095 .65372 m .53125 .65349 L .52952 .654 L F
.52847 .65555 m .52952 .654 L .52925 .65406 L F
.52847 .65555 m .52925 .65406 L .52837 .6552 L F
.491 .327 .586 r
.53051 .65381 m .52837 .6552 L .52925 .65406 L F
.53051 .65381 m .52847 .65555 L .52837 .6552 L F
.579 .425 .637 r
.52994 .65453 m .53125 .65349 L .52911 .65511 L F
.52907 .65523 m .53163 .65382 L .53125 .65349 L F
.518 .887 .974 r
.53295 .65456 m .53066 .65591 L .5301 .65259 L F
.53021 .65256 m .5301 .65259 L .53008 .65247 L F
.53295 .65456 m .5301 .65259 L .53021 .65256 L F
.392 .231 .54 r
.53219 .64944 m .53382 .65289 L .53008 .65247 L F
.774 .72 .802 r
.5343 .65215 m .53382 .6535 L .53382 .65289 L F
0 .033 .553 r
.53383 .651 m .53382 .65289 L .53219 .64944 L F
.392 .231 .54 r
.53382 .65289 m .53342 .65353 L .53008 .65247 L F
.774 .72 .802 r
.53383 .651 m .5343 .65215 L .53353 .65336 L F
0 .033 .553 r
.53383 .651 m .53425 .65378 L .53382 .65289 L F
.774 .72 .802 r
.5343 .65215 m .53508 .65409 L .53382 .6535 L F
.53382 .65289 m .53382 .6535 L .53353 .65336 L F
.53508 .65409 m .53561 .65542 L .53435 .65418 L F
.53508 .65409 m .53435 .65418 L .53353 .65336 L F
.518 .887 .974 r
.53337 .6543 m .53229 .65444 L .53066 .65591 L F
.53229 .65444 m .53192 .65457 L .53066 .65591 L F
.579 .425 .637 r
.52847 .65555 m .52907 .65523 L .52916 .65496 L F
.52925 .65406 m .52952 .654 L .53008 .65247 L F
.491 .327 .586 r
.52966 .65353 m .52925 .65406 L .52575 .65375 L F
.52925 .65406 m .52837 .6552 L .52709 .65449 L F
.52925 .65406 m .52709 .65449 L .52575 .65375 L F
.579 .425 .637 r
.52925 .65406 m .52937 .65383 L .52837 .6552 L F
.52937 .65383 m .53008 .65247 L .52903 .65415 L F
.52937 .65383 m .52903 .65415 L .52837 .6552 L F
.52907 .65523 m .52994 .65453 L .52911 .65511 L F
.491 .327 .586 r
.52994 .65453 m .52867 .65576 L .52847 .65555 L F
.639 .55 .737 r
.53008 .65247 m .53066 .65591 L .52837 .6552 L F
.59 .329 .489 r
.52873 .65561 m .5287 .65578 L .53022 .65598 L F
.5287 .65578 m .52924 .65634 L .53022 .65598 L F
.52857 .65659 m .52869 .65792 L .53022 .65598 L F
.772 .36 .271 r
.53122 .65806 m .52837 .6552 L .53066 .65591 L F
.491 .327 .586 r
.52867 .65576 m .52724 .65715 L .52847 .65555 L F
.59 .329 .489 r
.5287 .65578 m .52857 .65659 L .52924 .65634 L F
.52847 .65555 m .52853 .65615 L .52873 .65561 L F
.52853 .65615 m .52857 .65659 L .52873 .65561 L F
.487 .276 .519 r
.52515 .65932 m .52724 .65715 L .52598 .65845 L F
.987 .743 .357 r
.52598 .65845 m .526 .66098 L .52515 .65932 L F
.521 .332 .566 r
.52832 .66044 m .526 .66098 L .52598 .65845 L F
.487 .276 .519 r
.52515 .65932 m .52701 .65953 L .52724 .65715 L F
.361 .171 .484 r
.52724 .65715 m .52869 .65792 L .52847 .65555 L F
.52724 .65715 m .52701 .65953 L .52869 .65792 L F
.772 .36 .271 r
.53122 .65806 m .52677 .65736 L .52837 .6552 L F
0 0 .466 r
.5323 .65654 m .53066 .65591 L .532 .65448 L F
.5323 .65654 m .53122 .65806 L .53066 .65591 L F
.505 .313 .554 r
.53019 .65514 m .52998 .65739 L .5323 .65654 L F
.52981 .65489 m .52984 .65526 L .53019 .65514 L F
.52984 .65526 m .52998 .65739 L .53019 .65514 L F
.518 .887 .974 r
.53229 .65444 m .532 .65448 L .53192 .65457 L F
.774 .72 .802 r
.53353 .65336 m .53561 .65542 L .53334 .65483 L F
.518 .887 .974 r
.53342 .65353 m .53295 .65456 L .53008 .65247 L F
.53337 .6543 m .53295 .65456 L .53342 .65353 L F
.774 .72 .802 r
.53356 .65152 m .53334 .65483 L .532 .65448 L F
.53383 .651 m .53334 .65483 L .53356 .65152 L F
.518 .887 .974 r
.53425 .65378 m .532 .65448 L .53337 .6543 L F
.392 .231 .54 r
.53382 .65289 m .53425 .65378 L .53342 .65353 L F
0 0 0 r
.53213 .65196 m .53383 .651 L .53215 .65168 L F
.532 .65448 m .53356 .65152 L .53213 .65196 L F
.53356 .65152 m .53383 .651 L .53213 .65196 L F
.88 .6 .509 r
.53511 .65629 m .532 .65448 L .53561 .65542 L F
.53482 .65679 m .53472 .65671 L .53511 .65629 L F
.53472 .65671 m .532 .65448 L .53511 .65629 L F
.847 .996 .765 r
.5351 .6574 m .53332 .65847 L .53664 .65465 L F
.53675 .65452 m .53664 .65465 L .53677 .6545 L F
.5351 .6574 m .53664 .65465 L .53675 .65452 L F
0 0 0 r
.53677 .6545 m .53549 .65597 L .53482 .65679 L F
.53549 .65597 m .53282 .65904 L .53482 .65679 L F
.847 .996 .765 r
.53454 .65837 m .53332 .65847 L .53473 .65762 L F
.53454 .65837 m .53282 .65904 L .53332 .65847 L F
.53454 .65837 m .53473 .65762 L .5351 .6574 L F
.667 .442 .569 r
.53754 .65848 m .53555 .6607 L .53454 .65837 L F
.583 .539 .772 r
.53498 .66108 m .53482 .65679 L .53282 .65904 L F
0 0 0 r
.53482 .65679 m .53352 .65959 L .53319 .65878 L F
.53482 .65679 m .53319 .65878 L .5323 .65654 L F
.628 .192 .194 r
.53336 .65921 m .53216 .65869 L .53295 .65817 L F
.53352 .65959 m .53277 .65909 L .53336 .65921 L F
.53277 .65909 m .53216 .65869 L .53336 .65921 L F
.53216 .65869 m .52949 .6602 L .53122 .65806 L F
0 0 0 r
.52978 .66118 m .53108 .66043 L .53182 .65891 L F
.52978 .66118 m .53182 .65891 L .53097 .65947 L F
.628 .192 .194 r
.53184 .65984 m .52949 .6602 L .53216 .65869 L F
.53295 .65817 m .53122 .65806 L .5323 .65654 L F
.53216 .65869 m .53122 .65806 L .53295 .65817 L F
.518 .887 .974 r
.53425 .65378 m .53337 .6543 L .53342 .65353 L F
.547 .809 .994 r
.3977 .59442 m .40136 .59491 L .39985 .59389 L F
.556 .812 .993 r
.39985 .59389 m .40136 .59491 L .40362 .59437 L F
.634 .79 .957 r
.76576 .50793 m .76329 .50874 L .76232 .5074 L F
.397 0 0 r
.76468 .49304 m .76561 .49198 L .76785 .4927 L F
.406 .016 .183 r
.76561 .49198 m .76814 .49145 L .76785 .4927 L F
0 0 .339 r
.21993 .56241 m .21953 .56573 L .21869 .56655 L F
.439 .334 .639 r
.21953 .56573 m .21795 .5688 L .21869 .56655 L F
.459 .317 .599 r
.30388 .60087 m .30577 .60032 L .30563 .59788 L F
.495 .338 .597 r
.30388 .60087 m .30591 .60246 L .30577 .60032 L F
.30388 .60087 m .30385 .60324 L .30591 .60246 L F
.984 .897 .572 r
.8064 .50731 m .80615 .5117 L .80533 .5093 L F
.541 .568 .831 r
.78539 .50238 m .78914 .50483 L .78904 .50262 L F
0 0 .274 r
.302 .65214 m .30295 .65524 L .30195 .65175 L F
.705 .91 .967 r
.55206 .66716 m .55458 .66476 L .55369 .66593 L F
0 0 .548 r
.32142 .63524 m .32106 .63446 L .31923 .63238 L F
0 .247 .732 r
.32142 .63524 m .32303 .63626 L .32106 .63446 L F
.907 .765 .693 r
.60804 .6164 m .60916 .6197 L .61148 .61596 L F
.61057 .61577 m .61148 .61596 L .61179 .61546 L F
.60804 .6164 m .61148 .61596 L .61057 .61577 L F
.914 .722 .629 r
.61183 .61604 m .61262 .61532 L .61129 .61436 L F
.61229 .6175 m .61249 .61618 L .61183 .61604 L F
.61249 .61618 m .61262 .61532 L .61183 .61604 L F
0 0 .352 r
.5442 .61107 m .54348 .61387 L .54307 .61249 L F
.745 .323 .247 r
.5561 .61804 m .55851 .62044 L .55875 .61887 L F
.661 .24 .236 r
.55851 .62044 m .56118 .62053 L .55875 .61887 L F
.724 .845 .939 r
.77521 .50871 m .77293 .50988 L .77177 .50888 L F
.612 .044 0 r
.50688 .62581 m .50934 .62764 L .50991 .62724 L F
.656 .101 0 r
.50934 .62764 m .51234 .62934 L .50991 .62724 L F
.646 .089 0 r
.50991 .62724 m .51234 .62934 L .51375 .62985 L F
.699 .448 .54 r
.4731 .71529 m .475 .71325 L .47154 .71266 L F
.4731 .71529 m .47483 .71562 L .475 .71325 L F
.721 .468 .542 r
.475 .71325 m .47483 .71562 L .47872 .71548 L F
.634 .595 .792 r
.80963 .51425 m .80615 .5117 L .80853 .5124 L F
.488 .693 .959 r
.80853 .5124 m .81145 .51348 L .80963 .51425 L F
.58 .765 .966 r
.53258 .61093 m .53472 .61296 L .53598 .61201 L F
.471 .256 .505 r
.50766 .65603 m .5099 .65546 L .51002 .65295 L F
.488 .275 .516 r
.5099 .65546 m .51222 .65246 L .51002 .65295 L F
.591 .324 .481 r
.49514 .69583 m .49476 .6982 L .49235 .69624 L F
0 .146 .646 r
.49235 .69624 m .49419 .69751 L .49514 .69583 L F
.49235 .69624 m .49476 .6982 L .49419 .69751 L F
.398 .436 .784 r
.79751 .50029 m .80018 .50195 L .79951 .50007 L F
.806 .836 .874 r
.79522 .50458 m .79729 .50356 L .79823 .50151 L F
.616 .611 .823 r
.79729 .50356 m .80018 .50195 L .79823 .50151 L F
.78 .998 .844 r
.79428 .50442 m .79522 .50458 L .79823 .50151 L F
.79428 .50442 m .79823 .50151 L .797 .50432 L F
.616 .611 .823 r
.79729 .50356 m .80142 .50505 L .80018 .50195 L F
.44 0 0 r
.79823 .50151 m .79991 .50392 L .797 .50432 L F
.79824 .50152 m .79813 .50165 L .79991 .50392 L F
.38 0 .116 r
.797 .50432 m .79991 .50392 L .79803 .50505 L F
.557 .35 .556 r
.79803 .50505 m .79966 .50403 L .79682 .50172 L F
.44 0 0 r
.79812 .50164 m .79787 .50193 L .79878 .50295 L F
.79787 .50193 m .79862 .50281 L .79878 .50295 L F
.79812 .50164 m .79878 .50295 L .79991 .50392 L F
.594 .582 .809 r
.80142 .50505 m .80281 .50117 L .80018 .50195 L F
.563 .58 .828 r
.80177 .50271 m .79991 .50392 L .79862 .50281 L F
.557 .35 .556 r
.79862 .50281 m .80177 .50271 L .79787 .50193 L F
.79966 .50403 m .79787 .50193 L .79682 .50172 L F
.44 0 0 r
.79787 .50193 m .79775 .50206 L .79862 .50281 L F
.563 .58 .828 r
.80177 .50271 m .79862 .50281 L .79775 .50206 L F
.557 .35 .556 r
.79966 .50403 m .80177 .50271 L .79862 .50281 L F
.353 0 0 r
.79682 .50172 m .79787 .50193 L .79775 .50206 L F
.79787 .50193 m .80177 .50271 L .79775 .50206 L F
.44 0 0 r
.79823 .50151 m .79812 .50164 L .79813 .50165 L F
.79823 .50151 m .79813 .50165 L .79824 .50152 L F
.668 .166 .042 r
.79747 .50034 m .80018 .50195 L .79751 .50029 L F
.79662 .50137 m .79811 .50161 L .79747 .50034 L F
.44 0 0 r
.79823 .50151 m .80018 .50195 L .79805 .50149 L F
.79805 .50149 m .80018 .50195 L .79662 .50137 L F
.668 .166 .042 r
.79811 .50161 m .80018 .50195 L .79747 .50034 L F
.303 .646 .968 r
.74794 .52111 m .75004 .52048 L .74701 .51978 L F
.74794 .52111 m .75117 .52181 L .75004 .52048 L F
.995 .776 .413 r
.58659 .65015 m .58573 .64935 L .58594 .64635 L F
.89 .515 .051 r
.58659 .65015 m .58734 .65241 L .58573 .64935 L F
.705 .98 .79 r
.72715 .50575 m .72813 .50413 L .72942 .50364 L F
.118 .256 .732 r
.72715 .50575 m .72927 .50783 L .72813 .50413 L F
.218 0 0 r
.37723 .63596 m .37569 .63742 L .37346 .63785 L F
.155 0 0 r
.37885 .63649 m .37569 .63742 L .37723 .63596 L F
.355 0 0 r
.37723 .63596 m .37954 .63579 L .37885 .63649 L F
.404 .289 .607 r
.21117 .59198 m .21131 .59445 L .20968 .59508 L F
.295 .077 .403 r
.21131 .59445 m .20925 .59735 L .20968 .59508 L F
.827 .992 .863 r
.73686 .51391 m .73883 .51073 L .74 .51239 L F
.55 .573 .831 r
.74076 .50887 m .74 .51239 L .73883 .51073 L F
.74076 .50887 m .74237 .51159 L .74 .51239 L F
.283 .73 .96 r
.39376 .5835 m .3929 .58432 L .39157 .58393 L F
.39376 .5835 m .39511 .58426 L .3929 .58432 L F
.391 .66 .966 r
.36062 .58233 m .35992 .58376 L .35867 .58234 L F
.554 .847 .998 r
.36211 .58312 m .35992 .58376 L .36062 .58233 L F
.36211 .58312 m .35992 .58376 L .36062 .58233 L F
.575 .026 0 r
.5291 .71319 m .53168 .71548 L .53014 .71446 L F
.672 .122 0 r
.53265 .71559 m .53168 .71548 L .5291 .71319 L F
.575 .026 0 r
.5291 .71319 m .53014 .71446 L .53021 .71193 L F
.759 .653 .744 r
.48116 .66097 m .48535 .66224 L .48292 .66426 L F
.524 .435 .697 r
.44617 .70515 m .4483 .70524 L .44511 .70388 L F
.358 .158 .466 r
.21545 .58075 m .21495 .58344 L .21328 .58387 L F
0 0 0 r
.21495 .58344 m .21295 .58595 L .21328 .58387 L F
.805 .644 .682 r
.60514 .60012 m .60889 .59806 L .60547 .59731 L F
.60514 .60012 m .60891 .60071 L .60889 .59806 L F
.577 .78 .975 r
.78924 .48142 m .78771 .48328 L .78676 .48207 L F
.78924 .48142 m .79017 .48269 L .78771 .48328 L F
.146 0 .073 r
.47778 .6485 m .48016 .64658 L .47864 .64698 L F
.387 .807 .973 r
.36588 .5968 m .36456 .5964 L .36229 .59673 L F
.419 .829 .974 r
.36831 .59638 m .36456 .5964 L .36588 .5968 L F
.81 .747 .794 r
.51901 .64401 m .51692 .64403 L .52076 .64435 L F
.478 .214 .434 r
.51759 .64695 m .52076 .64435 L .51692 .64403 L F
.51759 .64695 m .51989 .64648 L .52076 .64435 L F
.077 .234 .724 r
.52076 .64435 m .52098 .64135 L .51901 .64401 L F
.419 .105 .323 r
.52243 .64332 m .52279 .64558 L .52076 .64435 L F
.077 .234 .724 r
.52076 .64435 m .52279 .64558 L .52219 .64417 L F
.52082 .64391 m .52219 .64417 L .52112 .64169 L F
.52076 .64435 m .52219 .64417 L .52082 .64391 L F
.52076 .64435 m .52112 .64169 L .52097 .64144 L F
.676 .515 .66 r
.52743 .64441 m .52453 .64553 L .52774 .64487 L F
.52479 .64498 m .52453 .64553 L .52743 .64441 L F
.665 .502 .654 r
.52672 .64511 m .52767 .64518 L .52453 .64553 L F
.779 .538 .571 r
.52773 .64487 m .52833 .64636 L .52774 .64487 L F
.52755 .64496 m .5279 .64558 L .52773 .64487 L F
.62 .476 .664 r
.53035 .64795 m .52949 .64808 L .52936 .64783 L F
.52992 .64747 m .52936 .64783 L .52815 .64551 L F
.53035 .64795 m .52936 .64783 L .52992 .64747 L F
.751 .639 .078 r
.52604 .64236 m .5261 .64244 L .52811 .64105 L F
.812 .49 .445 r
.52811 .64105 m .52824 .64299 L .52604 .64236 L F
.779 .538 .571 r
.52755 .64496 m .52774 .64487 L .52453 .64553 L F
.202 .273 .714 r
.52774 .64487 m .52774 .64483 L .52604 .64236 L F
.653 .373 .483 r
.52646 .64249 m .52748 .64445 L .52604 .64236 L F
.52824 .64299 m .52788 .64509 L .52646 .64249 L F
.202 .273 .714 r
.52774 .64487 m .52783 .64499 L .52774 .64483 L F
.653 .373 .483 r
.52788 .64509 m .52786 .64519 L .52646 .64249 L F
.202 .273 .714 r
.52774 .64483 m .52825 .64109 L .52604 .64236 L F
.227 0 .039 r
.5261 .64244 m .52309 .64529 L .52243 .64332 L F
.52302 .64536 m .52587 .64474 L .52279 .64558 L F
.676 .515 .66 r
.52598 .64367 m .52479 .64498 L .52592 .64474 L F
.52521 .64411 m .52479 .64498 L .52598 .64367 L F
.227 0 .039 r
.5261 .64244 m .52598 .64367 L .52521 .64411 L F
.751 .639 .078 r
.52604 .64236 m .52598 .64367 L .5261 .64244 L F
.676 .515 .66 r
.52604 .64236 m .52592 .64474 L .52743 .64441 L F
.52604 .64236 m .52521 .64411 L .52598 .64367 L F
.751 .639 .078 r
.52604 .64236 m .52598 .64368 L .52598 .64367 L F
.665 .502 .654 r
.52604 .64236 m .52665 .64331 L .52521 .64411 L F
.52665 .64331 m .52741 .6445 L .52521 .64411 L F
.751 .639 .078 r
.52604 .64236 m .52587 .64474 L .52598 .64368 L F
.665 .502 .654 r
.52521 .64411 m .52595 .64424 L .52479 .64498 L F
.52595 .64424 m .52741 .6445 L .52592 .64477 L F
.52595 .64424 m .52592 .64477 L .52479 .64498 L F
.227 0 .039 r
.52309 .64529 m .52521 .64411 L .52302 .64536 L F
.5261 .64244 m .52521 .64411 L .52309 .64529 L F
.52598 .64367 m .52587 .64474 L .52302 .64536 L F
.653 .373 .483 r
.52748 .64445 m .52786 .64519 L .52604 .64236 L F
.202 .273 .714 r
.52774 .64483 m .528 .64523 L .52775 .64475 L F
.52783 .64499 m .528 .64523 L .52774 .64483 L F
.653 .373 .483 r
.52824 .64299 m .53041 .64533 L .52797 .6452 L F
.52824 .64299 m .52797 .6452 L .52788 .64509 L F
.716 .362 .376 r
.53064 .64373 m .53041 .64533 L .52824 .64299 L F
.077 .221 .711 r
.52817 .64586 m .52774 .64487 L .52847 .64671 L F
.779 .538 .571 r
.52788 .64551 m .52833 .64636 L .52773 .64487 L F
.62 .476 .664 r
.52819 .64593 m .52788 .64551 L .52786 .64519 L F
.52918 .64812 m .52847 .64671 L .52819 .64593 L F
.779 .538 .571 r
.52806 .64586 m .52833 .64636 L .52788 .64551 L F
.62 .476 .664 r
.52847 .64671 m .52788 .64551 L .52819 .64593 L F
.52913 .64803 m .52805 .64829 L .52788 .64551 L F
.52918 .64812 m .52815 .64828 L .52913 .64803 L F
.52815 .64828 m .52805 .64829 L .52913 .64803 L F
.337 .259 .619 r
.52782 .64527 m .52805 .64829 L .52634 .6483 L F
.52788 .64551 m .52805 .64829 L .52782 .64527 L F
.289 .538 .915 r
.52634 .6483 m .52792 .64829 L .52705 .64972 L F
.52792 .64829 m .52805 .64829 L .52802 .64834 L F
.52792 .64829 m .52802 .64834 L .52705 .64972 L F
.376 .245 .571 r
.52794 .64845 m .52632 .65167 L .52705 .64972 L F
.5277 .64896 m .52632 .65167 L .52794 .64845 L F
.52743 .6495 m .52632 .65167 L .52769 .64899 L F
.52768 .64901 m .52769 .64899 L .52802 .64834 L F
.52743 .6495 m .52769 .64899 L .52768 .64901 L F
.693 .829 .389 r
.52763 .64911 m .5277 .64903 L .52767 .64904 L F
.376 .245 .571 r
.52763 .64911 m .52805 .65096 L .52632 .65167 L F
.693 .829 .389 r
.52738 .64965 m .52765 .64914 L .52763 .64911 L F
.52765 .64914 m .5277 .64903 L .52763 .64911 L F
.376 .245 .571 r
.52767 .64903 m .52773 .64932 L .52763 .64911 L F
.52773 .64932 m .52805 .65096 L .52763 .64911 L F
.571 .452 .678 r
.52786 .64866 m .5277 .64903 L .52839 .64849 L F
.52767 .64904 m .5277 .64903 L .52786 .64866 L F
.52811 .64837 m .52839 .64849 L .52871 .64823 L F
.52811 .64837 m .52871 .64823 L .52854 .64819 L F
.52854 .64819 m .5286 .64817 L .52815 .64828 L F
.52854 .64819 m .52815 .64828 L .52557 .64893 L F
.548 .381 .607 r
.52866 .64826 m .52806 .6483 L .52862 .64821 L F
.399 .361 .7 r
.52798 .64862 m .52866 .64826 L .52865 .64828 L F
.548 .381 .607 r
.53039 .65036 m .52862 .64821 L .53036 .64864 L F
.729 .313 .258 r
.5277 .64903 m .52769 .64906 L .52827 .64976 L F
.548 .381 .607 r
.53039 .65036 m .52967 .65051 L .52872 .64889 L F
.538 .353 .577 r
.53039 .65036 m .53008 .65247 L .52805 .65096 L F
.392 .231 .54 r
.53219 .64944 m .53008 .65247 L .53039 .65036 L F
.729 .313 .258 r
.52827 .64976 m .52843 .65008 L .53038 .65229 L F
.52769 .64906 m .52805 .64956 L .52827 .64976 L F
.399 .361 .7 r
.5277 .64903 m .52856 .64938 L .52814 .64895 L F
.729 .313 .258 r
.5277 .64903 m .52827 .64976 L .52839 .64987 L F
.5277 .64903 m .52839 .64987 L .52856 .64938 L F
.376 .245 .571 r
.52802 .64834 m .5277 .64896 L .52794 .64845 L F
.571 .452 .678 r
.52589 .64929 m .52839 .64849 L .52811 .64837 L F
.548 .381 .607 r
.52825 .64847 m .52805 .64862 L .52805 .64829 L F
.399 .361 .7 r
.52788 .64877 m .52791 .64872 L .52865 .64828 L F
.52791 .64872 m .52822 .6485 L .52865 .64828 L F
.548 .381 .607 r
.52872 .64889 m .52805 .64862 L .52825 .64847 L F
.376 .245 .571 r
.52805 .64829 m .52805 .64862 L .52774 .64891 L F
.399 .361 .7 r
.52791 .64872 m .52798 .64862 L .52811 .64855 L F
.52805 .64862 m .52811 .64855 L .52822 .6485 L F
.52791 .64872 m .52811 .64855 L .52805 .64862 L F
.376 .245 .571 r
.52805 .64862 m .52779 .6489 L .52774 .64891 L F
.399 .361 .7 r
.5277 .64903 m .52788 .64877 L .52865 .64828 L F
.376 .245 .571 r
.52805 .64862 m .52805 .64886 L .52779 .6489 L F
.548 .381 .607 r
.53039 .65036 m .52872 .64889 L .52866 .64826 L F
.52872 .64889 m .52825 .64847 L .52858 .6483 L F
.52872 .64889 m .52858 .6483 L .52866 .64826 L F
.52825 .64847 m .52806 .6483 L .52866 .64826 L F
.571 .452 .678 r
.52752 .64861 m .52854 .64819 L .52771 .6484 L F
.548 .381 .607 r
.52806 .6483 m .52815 .64828 L .52862 .64821 L F
.457 .559 .871 r
.52453 .64553 m .52634 .6483 L .52287 .64721 L F
.337 .259 .619 r
.52769 .64521 m .52634 .6483 L .52453 .64553 L F
.52786 .64519 m .52782 .64527 L .52769 .64521 L F
.52782 .64527 m .52634 .6483 L .52769 .64521 L F
.779 .538 .571 r
.52367 .6468 m .52833 .64636 L .52769 .64521 L F
.665 .502 .654 r
.52741 .6445 m .52786 .64519 L .52479 .64498 L F
.779 .538 .571 r
.52734 .64506 m .52769 .64521 L .52755 .64496 L F
.665 .502 .654 r
.52767 .64518 m .52769 .64521 L .52453 .64553 L F
.779 .538 .571 r
.52367 .6468 m .52769 .64521 L .52734 .64506 L F
.571 .452 .678 r
.52557 .64893 m .52899 .648 L .52367 .6468 L F
.548 .381 .607 r
.52806 .6483 m .52805 .64829 L .52815 .64828 L F
.571 .452 .678 r
.5286 .64817 m .52899 .648 L .52557 .64893 L F
.077 .221 .711 r
.52904 .64787 m .52817 .64586 L .52899 .648 L F
.52817 .64586 m .52847 .64671 L .52899 .648 L F
.62 .476 .664 r
.53037 .64727 m .52808 .64538 L .53041 .64533 L F
.52808 .64538 m .52795 .64526 L .52802 .64527 L F
.52808 .64538 m .52802 .64527 L .53041 .64533 L F
.52992 .64747 m .52786 .64519 L .53037 .64727 L F
.52795 .64526 m .52792 .6452 L .53041 .64533 L F
.202 .273 .714 r
.52775 .64475 m .52855 .64589 L .52825 .64109 L F
.52855 .64589 m .52981 .64767 L .52971 .64727 L F
.52855 .64589 m .52971 .64727 L .52825 .64109 L F
.528 .64523 m .52981 .64767 L .52775 .64475 L F
.077 .221 .711 r
.5278 .64491 m .52795 .64516 L .52774 .64487 L F
.653 .373 .483 r
.52788 .64509 m .52797 .6452 L .52792 .6452 L F
.52788 .64509 m .52792 .6452 L .52787 .64513 L F
.077 .221 .711 r
.5278 .64491 m .52774 .64487 L .52817 .64586 L F
.62 .476 .664 r
.52815 .64551 m .52918 .64812 L .52819 .64593 L F
.077 .221 .711 r
.52797 .64531 m .52817 .64586 L .52904 .64787 L F
.5278 .64491 m .52817 .64586 L .52797 .64531 L F
.62 .476 .664 r
.52797 .64531 m .52819 .64593 L .52786 .64519 L F
.52815 .64551 m .52819 .64593 L .52797 .64531 L F
.653 .373 .483 r
.52787 .64513 m .52792 .6452 L .52786 .64519 L F
.077 .221 .711 r
.52906 .6478 m .52793 .64522 L .52904 .64787 L F
.52793 .64522 m .5278 .64491 L .52792 .6452 L F
.52793 .64522 m .52792 .6452 L .52904 .64787 L F
.671 .458 .589 r
.53304 .64274 m .53041 .64533 L .53064 .64373 L F
.461 .456 .766 r
.52884 .6417 m .52967 .64682 L .53097 .64391 L F
.52967 .64682 m .52981 .64767 L .53047 .64551 L F
.52967 .64682 m .53047 .64551 L .53097 .64391 L F
.077 .221 .711 r
.52962 .64616 m .52981 .64767 L .52951 .64728 L F
.461 .456 .766 r
.52892 .64393 m .52981 .64767 L .52884 .6417 L F
.077 .221 .711 r
.52962 .64616 m .52951 .64728 L .52795 .64516 L F
.62 .476 .664 r
.52949 .64808 m .52918 .64812 L .52815 .64551 L F
.077 .221 .711 r
.52962 .64616 m .52899 .64573 L .52906 .6478 L F
.399 .361 .7 r
.52878 .64799 m .52962 .64616 L .52906 .6478 L F
.52901 .64788 m .52906 .6478 L .52904 .64787 L F
.52878 .64799 m .52906 .6478 L .52901 .64788 L F
.077 .221 .711 r
.52962 .64616 m .52795 .64516 L .5278 .64491 L F
.52899 .64573 m .5278 .64491 L .52906 .6478 L F
.461 .456 .766 r
.52825 .64109 m .52892 .64393 L .52884 .6417 L F
.779 .538 .571 r
.52756 .64643 m .52899 .648 L .52833 .64636 L F
.52367 .6468 m .5282 .64782 L .52756 .64643 L F
.5282 .64782 m .52899 .648 L .52756 .64643 L F
.399 .361 .7 r
.52798 .64862 m .52962 .64616 L .52866 .64826 L F
.52833 .6481 m .5287 .64816 L .52961 .64617 L F
.548 .381 .607 r
.53036 .64864 m .52862 .64821 L .53035 .64795 L F
.571 .452 .678 r
.52854 .64819 m .52871 .64823 L .52899 .648 L F
.399 .361 .7 r
.52865 .64828 m .52878 .64799 L .52899 .648 L F
.52878 .64799 m .52904 .64787 L .52899 .648 L F
.671 .458 .589 r
.53304 .64274 m .53285 .64524 L .53041 .64533 L F
.809 .7 .745 r
.53285 .64524 m .53035 .64795 L .53041 .64533 L F
.357 .268 .617 r
.52962 .64616 m .53097 .64391 L .52981 .64767 L F
.399 .361 .7 r
.5287 .64816 m .53055 .64849 L .52961 .64617 L F
.52961 .64617 m .53055 .64849 L .52962 .64616 L F
.52791 .64872 m .52859 .64866 L .52833 .6481 L F
.37 .203 .52 r
.53219 .64944 m .53039 .65036 L .53035 .64795 L F
.399 .361 .7 r
.52859 .64866 m .53055 .64849 L .52833 .6481 L F
.52779 .6489 m .52805 .64886 L .52791 .64872 L F
.52805 .64886 m .53055 .64849 L .52791 .64872 L F
.548 .381 .607 r
.52872 .64889 m .52856 .64938 L .52805 .64862 L F
.52839 .64987 m .52805 .65085 L .52805 .64956 L F
.52921 .65061 m .52805 .65085 L .52839 .64987 L F
.52921 .65061 m .52805 .65096 L .52805 .65085 L F
.52925 .65065 m .52805 .65096 L .52921 .65061 L F
.376 .245 .571 r
.52805 .64956 m .52805 .65096 L .52767 .64903 L F
.729 .313 .258 r
.52764 .64919 m .52659 .65205 L .53038 .65229 L F
.52762 .64917 m .52762 .64917 L .52764 .64919 L F
.52762 .64917 m .52659 .65205 L .52764 .64919 L F
.548 .381 .607 r
.52856 .64938 m .52839 .64987 L .52805 .64886 L F
.52839 .64987 m .52805 .64956 L .52805 .64886 L F
.52856 .64938 m .52805 .64886 L .52805 .64862 L F
.729 .313 .258 r
.52805 .64956 m .52843 .65008 L .52827 .64976 L F
.548 .381 .607 r
.52967 .65051 m .52921 .65061 L .52856 .64938 L F
.52921 .65061 m .52839 .64987 L .52856 .64938 L F
.52967 .65051 m .52856 .64938 L .52872 .64889 L F
.399 .361 .7 r
.52814 .64895 m .53135 .65051 L .53055 .64849 L F
.52856 .64938 m .53135 .65051 L .52814 .64895 L F
.729 .313 .258 r
.52839 .64987 m .52827 .64976 L .53038 .65229 L F
.548 .381 .607 r
.53039 .65036 m .52925 .65065 L .52921 .65061 L F
.729 .313 .258 r
.52856 .64938 m .52921 .65086 L .52887 .6495 L F
.52839 .64987 m .52921 .65086 L .52856 .64938 L F
.52887 .6495 m .53038 .65229 L .53135 .65051 L F
.52921 .65086 m .53038 .65229 L .52887 .6495 L F
.399 .361 .7 r
.5296 .64618 m .52962 .64616 L .52962 .64616 L F
.52779 .6489 m .52962 .64616 L .5296 .64618 L F
.571 .452 .678 r
.52589 .64929 m .52752 .64861 L .52557 .64893 L F
.52752 .64861 m .52771 .6484 L .52557 .64893 L F
.399 .361 .7 r
.5277 .64903 m .53055 .64849 L .52779 .6489 L F
.376 .245 .571 r
.52774 .64891 m .52805 .64956 L .52767 .64903 L F
.52805 .64886 m .52805 .64956 L .52774 .64891 L F
.729 .313 .258 r
.52769 .64906 m .52762 .64917 L .52843 .65008 L F
.693 .829 .389 r
.52534 .65354 m .52738 .64965 L .52589 .64929 L F
.52534 .65354 m .52595 .65201 L .5277 .64903 L F
.729 .313 .258 r
.52762 .64917 m .52595 .65201 L .52659 .65205 L F
.693 .829 .389 r
.52738 .64965 m .52767 .64904 L .52589 .64929 L F
.376 .245 .571 r
.52805 .64829 m .52743 .6495 L .52802 .64834 L F
.571 .452 .678 r
.52589 .64929 m .52767 .64904 L .52786 .64866 L F
.62 .476 .664 r
.52795 .64526 m .52786 .64519 L .52792 .6452 L F
.53035 .64795 m .52992 .64747 L .53037 .64727 L F
.779 .538 .571 r
.5279 .64558 m .52806 .64586 L .52788 .64551 L F
.337 .259 .619 r
.52786 .64519 m .52788 .64551 L .52782 .64527 L F
.665 .502 .654 r
.52767 .64518 m .52786 .64519 L .52769 .64521 L F
.779 .538 .571 r
.52367 .6468 m .52755 .64496 L .52453 .64553 L F
.665 .502 .654 r
.52479 .64498 m .52672 .64511 L .52453 .64553 L F
.227 0 .039 r
.52309 .64529 m .52302 .64536 L .523 .64531 L F
.52309 .64529 m .523 .64531 L .52243 .64332 L F
.52302 .64536 m .52279 .64558 L .52277 .64542 L F
.52302 .64536 m .52277 .64542 L .52243 .64332 L F
.502 .443 .723 r
.52293 .64424 m .5233 .6406 L .52219 .64417 L F
.153 0 0 r
.52305 .64371 m .52271 .64427 L .52208 .64325 L F
.52438 .64434 m .52362 .6443 L .52305 .64371 L F
.793 .701 .764 r
.5233 .6406 m .52438 .64434 L .52302 .6437 L F
.502 .443 .723 r
.52299 .64365 m .52303 .64366 L .5233 .6406 L F
.52219 .64417 m .52251 .64314 L .52112 .64169 L F
.52251 .64314 m .5233 .6406 L .52112 .64169 L F
.578 .857 .996 r
.51968 .64212 m .51901 .64401 L .52098 .64135 L F
.793 .701 .764 r
.5233 .6406 m .52302 .6437 L .51968 .64212 L F
.884 .529 .369 r
.5233 .6406 m .52604 .64236 L .52539 .63962 L F
.52506 .64173 m .52599 .64309 L .52604 .64236 L F
.5233 .6406 m .52487 .64205 L .52506 .64173 L F
.52487 .64205 m .52599 .64309 L .52506 .64173 L F
.911 .889 .47 r
.52539 .63962 m .52487 .64205 L .5233 .6406 L F
.52487 .64205 m .52438 .64434 L .5233 .6406 L F
.52487 .64205 m .52454 .6426 L .52438 .64434 L F
.502 .443 .723 r
.52392 .64302 m .52454 .6426 L .5233 .6406 L F
.52419 .6441 m .5243 .64363 L .52392 .64302 L F
.5243 .64363 m .52454 .6426 L .52392 .64302 L F
.911 .889 .47 r
.52454 .6426 m .52424 .64309 L .5243 .64363 L F
.52454 .6426 m .5243 .64363 L .52438 .64434 L F
.538 .926 .874 r
.52452 .64398 m .52438 .64434 L .5243 .64363 L F
.502 .443 .723 r
.52419 .6441 m .52587 .64474 L .52454 .6426 L F
.52303 .64366 m .52419 .6441 L .5233 .6406 L F
.52279 .64558 m .524 .64525 L .52356 .64454 L F
.52286 .64494 m .5234 .6443 L .52293 .64424 L F
.153 0 0 r
.5234 .6443 m .52326 .64437 L .52271 .64427 L F
.52362 .6443 m .52357 .64432 L .5234 .6443 L F
.502 .443 .723 r
.52286 .64494 m .52356 .64454 L .5234 .6443 L F
.153 0 0 r
.52357 .64432 m .52326 .64437 L .5234 .6443 L F
.502 .443 .723 r
.52293 .64424 m .5234 .6443 L .52299 .64365 L F
.52279 .64558 m .52356 .64454 L .52286 .64494 L F
.153 0 0 r
.52438 .64434 m .52406 .64435 L .52362 .6443 L F
.538 .926 .874 r
.52452 .64398 m .52388 .64435 L .52438 .64434 L F
.153 0 0 r
.52362 .6443 m .5234 .6443 L .52305 .64371 L F
.5234 .6443 m .52304 .64373 L .52305 .64371 L F
.502 .443 .723 r
.524 .64525 m .52587 .64474 L .52529 .64452 L F
.153 0 0 r
.52406 .64435 m .52388 .64435 L .52362 .6443 L F
.52388 .64435 m .52357 .64432 L .52362 .6443 L F
.502 .443 .723 r
.5234 .6443 m .52529 .64452 L .52299 .64365 L F
.524 .64525 m .52529 .64452 L .5234 .6443 L F
.153 0 0 r
.52388 .64435 m .52326 .64437 L .52357 .64432 L F
.502 .443 .723 r
.52279 .64558 m .52293 .64424 L .52219 .64417 L F
.153 0 0 r
.52326 .64437 m .52244 .6444 L .52271 .64427 L F
.538 .926 .874 r
.52463 .64371 m .52244 .6444 L .52388 .64435 L F
.52463 .64371 m .52388 .64435 L .52452 .64398 L F
.884 .529 .369 r
.5233 .6406 m .52517 .64361 L .52599 .64309 L F
.911 .889 .47 r
.52493 .641 m .52408 .64157 L .52424 .64309 L F
.52539 .63962 m .52475 .64057 L .52493 .641 L F
.52475 .64057 m .52408 .64157 L .52493 .641 L F
.767 .703 .791 r
.52433 .63956 m .5264 .63987 L .52503 .63927 L F
.52349 .63991 m .52447 .6399 L .52433 .63956 L F
.911 .889 .47 r
.52539 .63962 m .52424 .64309 L .52487 .64205 L F
.356 .485 .852 r
.52604 .64236 m .52825 .64109 L .52539 .63962 L F
.767 .703 .791 r
.52447 .6399 m .5264 .63987 L .52433 .63956 L F
.538 .926 .874 r
.52489 .64305 m .52463 .64371 L .52408 .64157 L F
.52463 .64371 m .52452 .64398 L .5244 .64335 L F
.52463 .64371 m .5244 .64335 L .52408 .64157 L F
.52452 .64398 m .5243 .64363 L .52408 .64157 L F
.52489 .64305 m .52321 .64398 L .52463 .64371 L F
.153 0 0 r
.5234 .6443 m .52271 .64427 L .52304 .64373 L F
.538 .926 .874 r
.52321 .64398 m .52244 .6444 L .52463 .64371 L F
.884 .529 .369 r
.52517 .64361 m .52587 .64474 L .52596 .64346 L F
.52517 .64361 m .52596 .64346 L .52599 .64309 L F
.502 .443 .723 r
.52112 .64169 m .5233 .6406 L .52098 .64135 L F
.153 0 0 r
.52271 .64427 m .52244 .6444 L .51969 .64415 L F
.52208 .64325 m .51969 .64415 L .51968 .64212 L F
.52271 .64427 m .51969 .64415 L .52208 .64325 L F
.077 .234 .724 r
.52097 .64144 m .52112 .64169 L .52098 .64135 L F
.497 .233 .443 r
.52076 .64435 m .51989 .64648 L .52224 .64584 L F
.52076 .64435 m .51989 .64648 L .52224 .64584 L F
.723 .308 .26 r
.53021 .71193 m .53373 .71233 L .53178 .7101 L F
.578 .364 .553 r
.48255 .71888 m .48223 .72167 L .47962 .72186 L F
.577 .362 .553 r
.48455 .71989 m .48255 .71888 L .48446 .71802 L F
.48455 .71989 m .48223 .72167 L .48255 .71888 L F
.347 .631 .959 r
.76852 .50715 m .77068 .50737 L .76939 .50855 L F
.334 .61 .95 r
.77068 .50737 m .77177 .50888 L .76939 .50855 L F
.602 .128 .101 r
.73145 .50312 m .73406 .50428 L .73506 .50277 L F
0 0 0 r
.73506 .50277 m .73632 .50247 L .73721 .5027 L F
.633 .639 .839 r
.73898 .50275 m .73506 .50277 L .73721 .5027 L F
0 0 0 r
.73506 .50277 m .73406 .50428 L .73632 .50247 L F
.984 .897 .572 r
.8064 .50731 m .8054 .51092 L .80615 .5117 L F
0 .44 .761 r
.80724 .51182 m .80615 .5117 L .8054 .51092 L F
.80724 .51182 m .80853 .5124 L .80615 .5117 L F
.188 0 0 r
.32448 .58631 m .32512 .58755 L .32674 .58601 L F
.32448 .58631 m .32307 .58822 L .32512 .58755 L F
.495 .193 .383 r
.44306 .67815 m .44559 .67775 L .44608 .67562 L F
.62 .309 .421 r
.44559 .67775 m .4481 .67763 L .44608 .67562 L F
.6 .311 .451 r
.4481 .67763 m .44856 .67561 L .44608 .67562 L F
.514 0 0 r
.36136 .62511 m .3649 .62632 L .36261 .62507 L F
.577 .023 0 r
.36261 .62507 m .3649 .62632 L .36629 .62617 L F
.39 0 0 r
.54771 .62435 m .5442 .62322 L .54561 .6238 L F
.6 .356 .519 r
.40973 .60936 m .4123 .60933 L .4123 .60643 L F
.621 .481 .671 r
.4123 .60643 m .41526 .60623 L .41474 .60337 L F
.59 .348 .518 r
.4123 .60643 m .41509 .60848 L .41526 .60623 L F
.4123 .60643 m .4123 .60933 L .41509 .60848 L F
.573 .314 .487 r
.43215 .61236 m .43188 .61454 L .42947 .61477 L F
.582 .323 .489 r
.43215 .61236 m .43446 .61433 L .43188 .61454 L F
.632 .305 .4 r
.43467 .61255 m .43446 .61433 L .43215 .61236 L F
.821 .62 .63 r
.55576 .59372 m .55929 .59203 L .55685 .59224 L F
.426 .207 .476 r
.49867 .65119 m .49554 .64999 L .49973 .6492 L F
.49867 .65119 m .49661 .65186 L .49554 .64999 L F
0 .23 .748 r
.57497 .66511 m .57666 .66557 L .57452 .66352 L F
.57497 .66511 m .57668 .66685 L .57666 .66557 L F
.376 .715 .987 r
.53554 .63398 m .53623 .63475 L .53486 .63421 L F
.507 0 0 r
.53554 .63398 m .53863 .63514 L .53623 .63475 L F
.885 .877 .822 r
.46414 .70939 m .46712 .70848 L .46379 .70704 L F
.46414 .70939 m .46543 .71003 L .46712 .70848 L F
.605 .637 .856 r
.46712 .70848 m .4683 .70822 L .46686 .70642 L F
0 .123 .585 r
.51571 .63137 m .5161 .63164 L .51735 .63265 L F
.51375 .62985 m .5161 .63164 L .51571 .63137 L F
.578 .035 0 r
.51471 .63133 m .51658 .63196 L .5161 .63164 L F
.26 0 0 r
.5161 .63164 m .51951 .63297 L .51735 .63265 L F
.578 .035 0 r
.51658 .63196 m .51891 .63274 L .5161 .63164 L F
.658 .103 0 r
.51234 .62934 m .5161 .63164 L .51375 .62985 L F
.827 .992 .863 r
.73686 .51391 m .73629 .51338 L .73883 .51073 L F
.063 .259 .752 r
.73686 .51391 m .73925 .51485 L .73629 .51338 L F
.73686 .51391 m .73989 .51709 L .73925 .51485 L F
0 0 0 r
.54839 .64044 m .54789 .64288 L .54775 .6433 L F
.957 .737 .564 r
.54673 .63964 m .54789 .64288 L .54839 .64044 L F
0 .155 .683 r
.54792 .64201 m .5481 .64226 L .54789 .64288 L F
.5481 .64226 m .55019 .64494 L .54789 .64288 L F
0 0 0 r
.54775 .6433 m .54789 .64288 L .5476 .64394 L F
.523 .573 .848 r
.42432 .59304 m .42737 .5941 L .42532 .59456 L F
.74 .612 .716 r
.5325 .67059 m .53211 .6727 L .53453 .67011 L F
.647 .669 .857 r
.51406 .64604 m .51759 .64695 L .51692 .64403 L F
0 0 .248 r
.51759 .64695 m .51834 .64783 L .51989 .64648 L F
.51759 .64695 m .51757 .6494 L .51834 .64783 L F
.259 0 .227 r
.47778 .6485 m .476 .6494 L .47531 .65176 L F
.334 .086 .381 r
.50766 .65603 m .50925 .65723 L .5099 .65546 L F
.50766 .65603 m .50733 .65808 L .50925 .65723 L F
.42 .857 .753 r
.54289 .59803 m .54403 .59724 L .54486 .59701 L F
.421 .865 .809 r
.54289 .59803 m .542 .59815 L .54403 .59724 L F
.73 .495 .572 r
.59214 .58008 m .59578 .57784 L .59219 .57804 L F
.293 0 0 r
.36629 .62617 m .3649 .62632 L .36865 .6265 L F
.543 .255 .428 r
.58051 .59235 m .58055 .59414 L .57795 .59421 L F
.61 .307 .431 r
.58051 .59235 m .5829 .59425 L .58055 .59414 L F
.621 .599 .806 r
.30893 .63005 m .3085 .63158 L .31001 .6311 L F
.782 .715 .789 r
.56708 .60408 m .57031 .60073 L .57039 .60394 L F
.715 .503 .601 r
.57039 .60394 m .57131 .60629 L .5688 .6052 L F
0 0 .335 r
.57031 .60073 m .57088 .602 L .57039 .60394 L F
0 0 0 r
.57039 .60394 m .57013 .60546 L .57131 .60629 L F
.57039 .60394 m .57088 .602 L .57013 .60546 L F
.708 .796 .322 r
.54882 .60412 m .54851 .60494 L .54857 .60498 L F
.675 .827 .394 r
.54857 .60498 m .54774 .60669 L .54866 .60502 L F
.773 .542 .584 r
.54401 .60656 m .54857 .60498 L .54749 .60756 L F
.693 .763 .905 r
.54401 .60656 m .54749 .60756 L .54746 .60703 L F
.773 .542 .584 r
.54401 .60656 m .54746 .60703 L .54843 .60503 L F
.693 .763 .905 r
.54401 .60656 m .54746 .60703 L .54729 .60404 L F
.979 .916 .614 r
.54746 .60703 m .54621 .6058 L .54729 .60404 L F
.54749 .60756 m .54732 .60733 L .54746 .60703 L F
.803 .843 .881 r
.54746 .60703 m .54749 .60756 L .54772 .60697 L F
.773 .542 .584 r
.54401 .60656 m .54703 .60861 L .54768 .60706 L F
.979 .916 .614 r
.54732 .60733 m .54621 .6058 L .54746 .60703 L F
.773 .542 .584 r
.54843 .60503 m .54746 .60703 L .54857 .60498 L F
.54746 .60703 m .54768 .60706 L .54772 .60697 L F
.54746 .60703 m .54772 .60697 L .54857 .60498 L F
.803 .843 .881 r
.54729 .60404 m .54746 .60703 L .54882 .60412 L F
.54746 .60703 m .54772 .60697 L .54882 .60412 L F
.708 .796 .322 r
.54772 .60697 m .54749 .60756 L .54857 .60498 L F
.773 .542 .584 r
.54703 .60861 m .54763 .60902 L .54857 .60498 L F
.708 .796 .322 r
.54851 .60494 m .54772 .60697 L .54857 .60498 L F
.675 .827 .394 r
.54857 .60498 m .54866 .60502 L .54955 .6034 L F
.665 .868 .486 r
.55162 .60021 m .55033 .60194 L .54955 .6034 L F
.638 .811 .383 r
.55033 .60194 m .54857 .60498 L .54955 .6034 L F
.77 .956 .64 r
.45899 .68892 m .45835 .69051 L .46058 .68757 L F
.153 0 0 r
.46256 .6865 m .45899 .68892 L .46058 .68757 L F
.92 .947 .799 r
.80173 .52264 m .80257 .52345 L .80351 .51982 L F
.80173 .52264 m .80257 .52345 L .80351 .51982 L F
.647 .709 .892 r
.41455 .58807 m .41179 .58888 L .41018 .58653 L F
.548 .547 .805 r
.8035 .51454 m .8054 .51092 L .80266 .51063 L F
.8035 .51454 m .80556 .51491 L .8054 .51092 L F
.589 .244 .352 r
.8035 .51454 m .80732 .51599 L .80556 .51491 L F
0 .205 .728 r
.55438 .65404 m .55708 .65821 L .55649 .6554 L F
.586 .222 .318 r
.36031 .64102 m .35935 .64319 L .35705 .64307 L F
.072 0 .073 r
.36103 .64218 m .36031 .64102 L .36262 .64049 L F
.36103 .64218 m .35935 .64319 L .36031 .64102 L F
.342 .239 .59 r
.52006 .68451 m .51948 .6868 L .51993 .6846 L F
.5204 .68523 m .51948 .6868 L .52006 .68451 L F
.754 .966 .932 r
.52136 .68361 m .52085 .68483 L .52418 .68297 L F
.342 .239 .59 r
.52136 .68361 m .52124 .68614 L .51948 .6868 L F
.695 .153 0 r
.51797 .68362 m .51997 .68565 L .52073 .68594 L F
.52059 .68564 m .52073 .68594 L .52124 .68614 L F
.51797 .68362 m .52073 .68594 L .52059 .68564 L F
.342 .239 .59 r
.52136 .68361 m .5204 .68523 L .52006 .68451 L F
.704 .477 .577 r
.4999 .69445 m .49739 .69185 L .50054 .69307 L F
.358 0 .05 r
.50276 .69389 m .4999 .69445 L .50054 .69307 L F
.653 .548 .722 r
.5026 .69022 m .50366 .69295 L .50054 .69307 L F
.492 .042 .11 r
.50366 .69295 m .50276 .69389 L .50054 .69307 L F
.897 .547 .372 r
.60677 .60312 m .61007 .60639 L .61021 .60382 L F
.27 .018 .336 r
.47531 .65176 m .47309 .6522 L .47298 .65472 L F
.425 .083 .28 r
.4097 .62322 m .40643 .62625 L .40754 .6238 L F
.533 .185 .323 r
.58058 .58562 m .5841 .58325 L .58176 .58386 L F
.308 0 0 r
.37293 .62489 m .37687 .62385 L .37461 .62421 L F
.346 0 .125 r
.39556 .63121 m .3964 .62938 L .39931 .62863 L F
.996 .844 .502 r
.61282 .63113 m .614 .62994 L .61282 .62795 L F
.61282 .63113 m .61351 .6322 L .614 .62994 L F
0 0 0 r
.53835 .6624 m .54076 .66195 L .54099 .66077 L F
.53835 .6624 m .53704 .66354 L .54076 .66195 L F
.60008 .67127 m .60278 .66939 L .60132 .67074 L F
.60008 .67127 m .60132 .67074 L .60083 .6709 L F
.601 .67055 m .60008 .67127 L .59887 .67186 L F
.60008 .67127 m .60083 .6709 L .59924 .6714 L F
.59887 .67186 m .60008 .67127 L .59785 .67248 L F
.601 .67055 m .60278 .66939 L .60008 .67127 L F
.436 .491 .817 r
.4802 .672 m .47885 .67303 L .47716 .66948 L F
.808 .608 .632 r
.60514 .60012 m .60677 .60312 L .60891 .60071 L F
.411 .574 .904 r
.34502 .61892 m .34403 .62055 L .34208 .61761 L F
.34502 .61892 m .34599 .62079 L .34403 .62055 L F
.298 .413 .811 r
.74594 .50378 m .74558 .50697 L .74484 .50534 L F
.836 .471 0 r
.74558 .50697 m .7457 .50779 L .74484 .50534 L F
.413 .313 .631 r
.74977 .50483 m .74558 .50697 L .74594 .50378 L F
.74977 .50483 m .74964 .50713 L .74558 .50697 L F
.267 .724 .954 r
.36211 .58312 m .36425 .5831 L .36578 .58371 L F
.24 .722 .932 r
.36425 .5831 m .36799 .58352 L .36578 .58371 L F
.524 .338 .571 r
.28087 .82615 m .28296 .82592 L .28322 .82293 L F
.196 .182 .615 r
.30615 .61239 m .30708 .60852 L .30554 .60933 L F
.30615 .61239 m .30729 .6121 L .30708 .60852 L F
.232 .328 .757 r
.30615 .61239 m .30834 .6149 L .30729 .6121 L F
.659 .429 .56 r
.30588 .61477 m .30834 .6149 L .30615 .61239 L F
.929 .654 .498 r
.5931 .59799 m .59134 .59929 L .58993 .5974 L F
.5931 .59799 m .59312 .60029 L .59134 .59929 L F
.606 .443 .635 r
.53508 .71309 m .53516 .71579 L .53265 .71559 L F
.922 .971 .769 r
.53373 .71233 m .53168 .71548 L .53265 .71559 L F
.606 .443 .635 r
.53508 .71309 m .53516 .71579 L .53265 .71559 L F
0 .542 .723 r
.53516 .71579 m .53168 .71548 L .53265 .71559 L F
.648 .602 .788 r
.74196 .49436 m .74553 .49645 L .74415 .49409 L F
.736 .638 .75 r
.74415 .49409 m .74553 .49645 L .74618 .49491 L F
.228 0 0 r
.32887 .58535 m .33111 .585 L .33278 .58364 L F
.281 0 0 r
.33111 .585 m .33508 .58351 L .33278 .58364 L F
.755 .923 .561 r
.45899 .68892 m .45708 .69188 L .45835 .69051 L F
.058 0 0 r
.51692 .64403 m .51278 .64505 L .51406 .64604 L F
.684 .489 .617 r
.51499 .64473 m .51389 .64587 L .51278 .64505 L F
.51389 .64587 m .5127 .6471 L .51278 .64505 L F
0 .128 .582 r
.51142 .64405 m .51278 .64505 L .51062 .64345 L F
.51406 .64604 m .51278 .64505 L .51142 .64405 L F
.73 .495 .572 r
.59214 .58008 m .59581 .58026 L .59578 .57784 L F
.822 .672 .698 r
.48116 .66097 m .48292 .66426 L .479 .66403 L F
.821 .612 .62 r
.479 .66403 m .48292 .66426 L .48243 .66669 L F
.77 .503 .531 r
.48292 .66426 m .48587 .66667 L .48243 .66669 L F
.518 .152 .284 r
.40383 .61183 m .40622 .61173 L .40738 .60947 L F
.507 .14 .278 r
.40738 .60947 m .4094 .61085 L .40973 .60936 L F
.40738 .60947 m .40622 .61173 L .4094 .61085 L F
.472 .406 .702 r
.21827 .57122 m .21863 .57446 L .21689 .57502 L F
.425 .273 .57 r
.21863 .57446 m .21687 .57746 L .21689 .57502 L F
.134 .341 .804 r
.80194 .51007 m .80266 .51063 L .80131 .50774 L F
.954 .81 .663 r
.45656 .68304 m .45909 .68145 L .45911 .68084 L F
.45656 .68304 m .45741 .68595 L .45909 .68145 L F
.45741 .68595 m .45769 .68602 L .45909 .68145 L F
.52 .329 .561 r
.45909 .68145 m .45755 .68645 L .46136 .68359 L F
.881 .786 .752 r
.45572 .68609 m .45755 .68645 L .45656 .68304 L F
.779 .876 .918 r
.46136 .68359 m .45652 .68574 L .4601 .68304 L F
.45652 .68574 m .45572 .68609 L .4563 .68569 L F
.45652 .68574 m .4563 .68569 L .4601 .68304 L F
.954 .81 .663 r
.45741 .68595 m .45755 .68645 L .45769 .68602 L F
.708 .593 .02 r
.45911 .68084 m .45909 .68145 L .45911 .68069 L F
.52 .329 .561 r
.45909 .68145 m .46136 .68359 L .45911 .68069 L F
.518 .646 .914 r
.73158 .51051 m .73162 .50751 L .72927 .50783 L F
.73158 .51051 m .73315 .50985 L .73162 .50751 L F
.008 .477 .87 r
.20171 .54421 m .20158 .5447 L .19968 .54262 L F
.667 .188 .106 r
.19786 .54361 m .20171 .54421 L .19968 .54262 L F
.059 .566 .883 r
.20184 .54373 m .20171 .54421 L .19994 .54356 L F
.20196 .54374 m .20171 .54421 L .20184 .54373 L F
.008 .477 .87 r
.20171 .54421 m .20189 .54504 L .20158 .5447 L F
.20171 .54421 m .20332 .54542 L .20189 .54504 L F
.484 .304 .561 r
.28322 .82293 m .28507 .82527 L .28513 .82208 L F
.28322 .82293 m .28296 .82592 L .28507 .82527 L F
.601 .34 .493 r
.50452 .64432 m .50466 .64641 L .50214 .64642 L F
.387 .059 .282 r
.50796 .64357 m .50466 .64641 L .50452 .64432 L F
.696 .763 .904 r
.72896 .48874 m .7269 .48865 L .72514 .4883 L F
.408 .78 .993 r
.76824 .52092 m .76495 .52039 L .76583 .52109 L F
.847 .803 .808 r
.73315 .50985 m .73391 .51169 L .73622 .50873 L F
.132 .546 .922 r
.4221 .59054 m .42196 .59153 L .4206 .59017 L F
.4221 .59054 m .42341 .59172 L .42196 .59153 L F
.909 .642 .521 r
.60095 .59377 m .60323 .59236 L .60109 .59131 L F
.60095 .59377 m .60322 .59477 L .60323 .59236 L F
.467 .382 .677 r
.43951 .68708 m .44191 .68934 L .4412 .68671 L F
.43951 .68708 m .43956 .69043 L .44191 .68934 L F
.847 .803 .808 r
.73315 .50985 m .73622 .50873 L .73558 .50962 L F
.776 .429 .399 r
.73875 .50883 m .73558 .50962 L .73622 .50873 L F
.58 .332 .505 r
.49568 .67258 m .49546 .67485 L .49317 .6728 L F
.49568 .67258 m .49546 .67485 L .49317 .6728 L F
.284 0 .118 r
.5256 .68019 m .5262 .67982 L .52651 .67899 L F
.3 .098 .43 r
.52984 .68064 m .52762 .68129 L .52826 .67864 L F
.52984 .68064 m .52826 .67864 L .52651 .67899 L F
.52984 .68064 m .52651 .67899 L .52896 .67809 L F
.284 0 .118 r
.5262 .67982 m .52896 .67809 L .52651 .67899 L F
.672 .184 .084 r
.52675 .67835 m .52651 .67899 L .52826 .67864 L F
.52417 .67783 m .52651 .67899 L .52675 .67835 L F
.49 .131 .284 r
.42032 .61941 m .41787 .61997 L .4182 .61837 L F
.503 .098 .205 r
.42068 .61822 m .42032 .61941 L .4182 .61837 L F
.78 .717 .793 r
.53813 .67243 m .53428 .67244 L .53677 .67002 L F
.721 .359 .362 r
.53813 .67243 m .5367 .67454 L .53428 .67244 L F
.543 .526 .787 r
.53813 .67243 m .54089 .67381 L .54028 .67222 L F
.608 .223 .289 r
.54083 .67442 m .53813 .67243 L .54028 .67222 L F
.497 .386 .658 r
.43956 .69043 m .44213 .69265 L .44191 .68934 L F
.43956 .69043 m .44015 .69287 L .44213 .69265 L F
.942 .83 .705 r
.79224 .51969 m .79303 .52284 L .7936 .52062 L F
.476 0 0 r
.5638 .62523 m .56549 .62605 L .5669 .62623 L F
.442 .789 .998 r
.56633 .62488 m .56807 .62583 L .56549 .62605 L F
.546 0 0 r
.56633 .62488 m .56748 .62561 L .56807 .62583 L F
.2 .722 .862 r
.5669 .62623 m .56807 .62583 L .56877 .62609 L F
.546 0 0 r
.56748 .62561 m .57018 .62731 L .56807 .62583 L F
.2 .722 .862 r
.56877 .62609 m .56807 .62583 L .56957 .62603 L F
.202 .725 .856 r
.56549 .62605 m .56807 .62583 L .5669 .62623 L F
.763 .525 .573 r
.48302 .71596 m .48446 .71802 L .48471 .71634 L F
.555 .537 .79 r
.53411 .64094 m .53733 .64363 L .53631 .64049 L F
.239 .345 .771 r
.53733 .64363 m .53773 .64281 L .53684 .64211 L F
.673 .267 .269 r
.53773 .64281 m .53304 .64274 L .53411 .64094 L F
.53793 .64291 m .53786 .64291 L .53773 .64281 L F
.53793 .64291 m .53773 .64281 L .53631 .64049 L F
.214 .341 .777 r
.53631 .64049 m .53879 .6425 L .53793 .64291 L F
.239 .345 .771 r
.53721 .64196 m .53879 .6425 L .53631 .64049 L F
.53794 .64316 m .538 .64311 L .53721 .64196 L F
.459 .037 .151 r
.53793 .64291 m .53788 .64294 L .53786 .64291 L F
.239 .345 .771 r
.538 .64311 m .53879 .6425 L .53721 .64196 L F
.459 .037 .151 r
.53786 .64291 m .53285 .64524 L .53304 .64274 L F
.53788 .64294 m .53285 .64524 L .53786 .64291 L F
.673 .267 .269 r
.53786 .64291 m .53304 .64274 L .53773 .64281 L F
.239 .345 .771 r
.53733 .64363 m .53794 .64316 L .53773 .64281 L F
.53684 .64211 m .53773 .64281 L .53631 .64049 L F
.673 .267 .269 r
.53773 .64281 m .53411 .64094 L .53631 .64049 L F
.868 .778 .759 r
.54214 .67239 m .54028 .67222 L .5427 .67183 L F
.879 .725 .687 r
.54028 .67222 m .54214 .67239 L .5427 .67183 L F
.54028 .67222 m .54089 .67381 L .54214 .67239 L F
.056 0 0 r
.37638 .59433 m .37253 .59539 L .37417 .59498 L F
.415 .149 .399 r
.34797 .60299 m .3459 .60355 L .34851 .60086 L F
.333 .076 .366 r
.3498 .60235 m .34851 .60086 L .35037 .60012 L F
.3498 .60235 m .34797 .60299 L .34851 .60086 L F
.774 .662 .739 r
.49932 .68247 m .49685 .68504 L .49689 .68341 L F
0 0 .303 r
.49685 .68504 m .49696 .6846 L .49689 .68341 L F
.63 .203 .213 r
.49854 .68182 m .49689 .68341 L .49681 .6819 L F
.064 0 0 r
.49932 .68247 m .49689 .68341 L .49854 .68182 L F
.49932 .68247 m .49689 .68341 L .49854 .68182 L F
0 0 .303 r
.49696 .6846 m .49764 .68176 L .49689 .68341 L F
.63 .203 .213 r
.49681 .6819 m .49689 .68341 L .49402 .68203 L F
.889 .835 .787 r
.49682 .68051 m .49854 .68182 L .50031 .67849 L F
.064 0 0 r
.49932 .68247 m .49854 .68182 L .49682 .68051 L F
.348 0 .093 r
.39122 .61816 m .39028 .61949 L .3935 .61771 L F
.983 .863 .491 r
.50187 .68928 m .50066 .68918 L .50132 .68664 L F
.527 .686 .939 r
.50154 .6856 m .50187 .68928 L .50132 .68664 L F
.774 .662 .739 r
.49932 .68247 m .50132 .68664 L .49685 .68504 L F
.968 .781 .597 r
.50132 .68664 m .49908 .68793 L .49685 .68504 L F
.967 .912 .561 r
.50154 .6856 m .50066 .68918 L .50187 .68928 L F
.222 .744 .806 r
.50152 .68918 m .50066 .68918 L .50187 .68928 L F
.50187 .68928 m .50066 .68918 L .50152 .68918 L F
0 0 0 r
.55212 .59592 m .55164 .59567 L .54981 .59636 L F
.55212 .59592 m .55337 .59425 L .55164 .59567 L F
.919 .846 .756 r
.79026 .52402 m .79139 .52596 L .79303 .52284 L F
.443 .149 .37 r
.31044 .59265 m .3122 .59376 L .31254 .59294 L F
.31044 .59265 m .31011 .59426 L .3122 .59376 L F
0 .128 .59 r
.45783 .69992 m .45648 .69897 L .45578 .69788 L F
.45783 .69992 m .45924 .70106 L .45648 .69897 L F
.785 .412 .35 r
.47962 .72186 m .4781 .72356 L .4761 .7211 L F
.52 .081 .147 r
.4816 .72316 m .4781 .72356 L .47962 .72186 L F
.491 .113 .25 r
.48223 .72167 m .4816 .72316 L .47962 .72186 L F
.435 .305 .604 r
.21265 .58892 m .21117 .59198 L .21119 .58972 L F
.621 .407 .569 r
.49023 .64898 m .49308 .64679 L .49045 .64686 L F
.069 0 .433 r
.49194 .64612 m .49023 .64898 L .49045 .64686 L F
.378 .175 .474 r
.21681 .58262 m .21545 .58075 L .21682 .5799 L F
.21681 .58262 m .21495 .58344 L .21545 .58075 L F
.417 0 0 r
.54064 .63615 m .54131 .63665 L .54252 .63709 L F
0 .493 .773 r
.54131 .63665 m .54452 .6375 L .54252 .63709 L F
.763 .348 .263 r
.54131 .63665 m .54328 .63911 L .54452 .6375 L F
0 .012 .576 r
.54169 .6365 m .54216 .63727 L .54131 .63665 L F
.54216 .63727 m .54328 .63911 L .54131 .63665 L F
.417 0 0 r
.53863 .63514 m .54131 .63665 L .54064 .63615 L F
.308 .769 .948 r
.78227 .48973 m .78332 .49023 L .78581 .48999 L F
.584 .33 .498 r
.51891 .65534 m .51687 .65755 L .51658 .65538 L F
.879 .627 .554 r
.59945 .58557 m .60197 .58862 L .60202 .5865 L F
0 .334 .795 r
.80397 .48695 m .8023 .48657 L .80173 .48491 L F
.80397 .48695 m .80484 .48795 L .8023 .48657 L F
.342 .034 .289 r
.46614 .65851 m .46337 .66096 L .46545 .66026 L F
.314 0 .247 r
.46545 .66026 m .46818 .6579 L .46614 .65851 L F
.573 .56 .801 r
.43835 .60425 m .43911 .60694 L .43668 .60698 L F
.498 .151 .308 r
.56998 .58875 m .57233 .58857 L .57326 .58626 L F
.602 .279 .395 r
.57233 .58857 m .57575 .58611 L .57326 .58626 L F
.119 0 0 r
.51951 .63297 m .52214 .63321 L .52322 .63314 L F
0 .242 .668 r
.52427 .63359 m .52322 .63314 L .52214 .63321 L F
.52427 .63359 m .52562 .63453 L .52322 .63314 L F
.394 .185 .474 r
.4393 .70157 m .43723 .70526 L .43917 .70404 L F
.669 .517 .669 r
.5374 .71052 m .5379 .7133 L .53508 .71309 L F
0 0 0 r
.53508 .71309 m .5365 .71204 L .5374 .71052 L F
.435 .272 .56 r
.5398 .70961 m .5379 .7133 L .5374 .71052 L F
0 0 0 r
.5365 .71204 m .5398 .70961 L .5374 .71052 L F
.351 .737 .986 r
.39948 .58364 m .39871 .58459 L .39709 .584 L F
.39948 .58364 m .40162 .58475 L .39871 .58459 L F
.996 .769 .466 r
.44511 .70388 m .44545 .70163 L .44426 .70098 L F
.498 .86 .988 r
.44426 .70098 m .44545 .70163 L .4475 .70096 L F
.996 .769 .466 r
.44511 .70388 m .44545 .70163 L .44426 .70098 L F
.737 .623 .732 r
.44511 .70388 m .4475 .70096 L .44545 .70163 L F
.525 .668 .927 r
.53395 .63175 m .53264 .634 L .53125 .63281 L F
.53395 .63175 m .53554 .63398 L .53264 .634 L F
.376 .715 .987 r
.53554 .63398 m .53486 .63421 L .53264 .634 L F
.765 .798 .88 r
.43793 .70543 m .44297 .70413 L .43917 .70404 L F
0 0 .341 r
.55708 .65821 m .5577 .66003 L .5579 .66157 L F
.705 .504 0 r
.5579 .66157 m .5577 .66003 L .55816 .66371 L F
.181 0 0 r
.77381 .49101 m .77721 .49078 L .77671 .49127 L F
0 0 0 r
.77972 .49014 m .77918 .49046 L .77721 .49078 L F
.77721 .49078 m .7784 .49117 L .77671 .49127 L F
.77721 .49078 m .77918 .49046 L .7784 .49117 L F
.43 .016 .149 r
.57031 .60073 m .57268 .59953 L .57088 .602 L F
.408 0 .135 r
.57268 .59953 m .57498 .60009 L .57088 .602 L F
.404 .771 .994 r
.37015 .58317 m .37378 .58383 L .37162 .58386 L F
.26 0 .259 r
.50581 .66366 m .50386 .66464 L .50299 .66658 L F
.457 .559 .871 r
.52453 .64553 m .52287 .64721 L .52224 .64584 L F
.567 .849 .997 r
.77905 .52895 m .78249 .52918 L .78158 .52843 L F
.405 .7 .982 r
.78249 .52918 m .78403 .52791 L .78158 .52843 L F
.78249 .52918 m .78508 .52928 L .78403 .52791 L F
.505 .907 .907 r
.59785 .67248 m .59924 .6714 L .59717 .67247 L F
.59785 .67248 m .60008 .67127 L .59924 .6714 L F
.745 .322 .245 r
.55502 .61954 m .5561 .61804 L .55572 .61788 L F
.55502 .61954 m .55851 .62044 L .5561 .61804 L F
.364 0 .1 r
.37909 .62333 m .38139 .62294 L .38277 .62091 L F
.547 .133 .208 r
.38277 .62091 m .38139 .62294 L .38457 .62222 L F
.518 .155 .289 r
.38277 .62091 m .38457 .62222 L .38522 .62077 L F
0 .174 .684 r
.74074 .51825 m .74097 .5184 L .73989 .51709 L F
.651 .348 .446 r
.53508 .71309 m .5379 .7133 L .53733 .7152 L F
.504 .363 .622 r
.53508 .71309 m .53733 .7152 L .5365 .71204 L F
.53508 .71309 m .53516 .71579 L .53733 .7152 L F
.651 .348 .446 r
.53508 .71309 m .53733 .7152 L .53516 .71579 L F
.496 .217 .421 r
.50476 .66026 m .50733 .65808 L .50508 .65868 L F
.317 .233 .6 r
.78424 .51062 m .78278 .5136 L .78176 .51225 L F
.447 .002 .096 r
.76814 .49145 m .7715 .49053 L .77042 .49236 L F
.446 0 0 r
.7715 .49053 m .77294 .49183 L .77042 .49236 L F
.7715 .49053 m .77381 .49101 L .77294 .49183 L F
.613 .326 .458 r
.51567 .68315 m .51826 .68137 L .51578 .68165 L F
.429 .484 .815 r
.42927 .59384 m .42872 .59739 L .42737 .5941 L F
.42927 .59384 m .43059 .59725 L .42872 .59739 L F
.464 .278 .543 r
.49514 .69583 m .49724 .69542 L .49739 .69185 L F
.49739 .69185 m .49724 .69542 L .49514 .69583 L F
.323 .017 .281 r
.49981 .69047 m .49739 .69185 L .49857 .69106 L F
.704 .477 .577 r
.4999 .69445 m .49724 .69542 L .49739 .69185 L F
0 0 .162 r
.49739 .69185 m .49789 .69381 L .49857 .69106 L F
.49739 .69185 m .49728 .69464 L .49789 .69381 L F
.324 .772 .958 r
.49789 .69381 m .4967 .69329 L .49815 .69346 L F
.588 .431 .636 r
.49789 .69381 m .49996 .69369 L .50015 .69079 L F
.324 .772 .958 r
.49789 .69381 m .49815 .69346 L .49996 .69369 L F
0 0 .162 r
.49728 .69464 m .49724 .69542 L .49789 .69381 L F
.662 .564 .734 r
.78904 .50262 m .78914 .50483 L .79156 .50233 L F
.866 .628 .576 r
.59428 .62583 m .59739 .62947 L .59612 .62863 L F
.961 .84 .678 r
.59612 .62863 m .59739 .62947 L .59654 .63175 L F
.577 .491 .721 r
.41474 .60337 m .41662 .60022 L .41394 .6013 L F
.41474 .60337 m .4169 .60347 L .41662 .60022 L F
.506 .364 .622 r
.41526 .60623 m .4169 .60347 L .41474 .60337 L F
.31 .376 .769 r
.49267 .68073 m .49402 .68203 L .49381 .67964 L F
.49267 .68073 m .49402 .68203 L .49381 .67964 L F
.197 0 0 r
.35506 .64419 m .35369 .64584 L .3514 .64628 L F
0 0 0 r
.35531 .64463 m .35506 .64419 L .35705 .64307 L F
.35531 .64463 m .35369 .64584 L .35506 .64419 L F
.727 .469 .537 r
.47872 .71548 m .48045 .71849 L .48302 .71596 L F
.763 .525 .573 r
.48302 .71596 m .48045 .71849 L .48446 .71802 L F
.973 .736 .52 r
.46273 .68423 m .46256 .6865 L .46136 .68359 L F
.46273 .68423 m .46256 .6865 L .46136 .68359 L F
.911 .685 .583 r
.47495 .6816 m .47308 .68332 L .47329 .68145 L F
.47495 .6816 m .4749 .68403 L .47308 .68332 L F
.769 .387 0 r
.80756 .49292 m .80834 .49417 L .80702 .49152 L F
.766 .516 0 r
.80835 .49507 m .80834 .49417 L .80756 .49292 L F
0 0 .353 r
.80827 .49478 m .80756 .49292 L .80739 .49132 L F
.80835 .49507 m .80756 .49292 L .80827 .49478 L F
.769 .387 0 r
.80756 .49292 m .80702 .49152 L .80671 .49089 L F
.766 .516 0 r
.80835 .49507 m .80876 .49657 L .80834 .49417 L F
.12 0 0 r
.33508 .58351 m .33726 .58316 L .33866 .58245 L F
.357 0 0 r
.33726 .58316 m .34081 .5829 L .33866 .58245 L F
.473 .295 .557 r
.75002 .4914 m .75283 .48795 L .74956 .4887 L F
.077 .573 .894 r
.57117 .62812 m .57078 .62856 L .56957 .62603 L F
.353 .818 .917 r
.56957 .62603 m .56807 .62583 L .5713 .62552 L F
.077 .573 .894 r
.57117 .62812 m .56957 .62603 L .5713 .62552 L F
0 .161 .616 r
.56807 .62583 m .57117 .62812 L .5713 .62552 L F
.57057 .62767 m .57018 .62731 L .57117 .62812 L F
.56807 .62583 m .57018 .62731 L .57057 .62767 L F
.546 0 0 r
.56633 .62488 m .5694 .62711 L .57018 .62731 L F
.235 .601 .951 r
.56913 .62704 m .57018 .62731 L .56856 .62731 L F
.546 0 0 r
.5694 .62711 m .56949 .62717 L .57018 .62731 L F
.235 .601 .951 r
.56964 .62679 m .57018 .62731 L .56913 .62704 L F
.57087 .62619 m .57018 .62731 L .56964 .62679 L F
.982 .707 .331 r
.57018 .62731 m .57021 .62741 L .57117 .62812 L F
.077 .573 .894 r
.57117 .62812 m .57274 .62892 L .57208 .6288 L F
.57117 .62812 m .57208 .6288 L .57078 .62856 L F
0 0 .141 r
.57117 .62812 m .57064 .63169 L .57274 .62892 L F
.57117 .62812 m .57115 .63048 L .57064 .63169 L F
.982 .707 .331 r
.57021 .62741 m .57115 .63048 L .57117 .62812 L F
.643 .109 0 r
.45958 .71257 m .45626 .71168 L .45809 .71212 L F
0 0 .483 r
.57026 .65253 m .57072 .65117 L .56998 .64884 L F
0 0 .374 r
.57026 .65253 m .57107 .65352 L .57072 .65117 L F
.57026 .65253 m .57116 .65478 L .57107 .65352 L F
.654 .861 .978 r
.74139 .50252 m .73721 .5027 L .74045 .50098 L F
.74139 .50252 m .73898 .50275 L .73721 .5027 L F
0 .325 .799 r
.74189 .50197 m .74139 .50252 L .74045 .50098 L F
.74189 .50197 m .74349 .50383 L .74139 .50252 L F
.409 .209 .495 r
.78007 .51994 m .77835 .51961 L .78025 .5165 L F
.78007 .51994 m .78025 .5165 L .77903 .51622 L F
.025 .587 .802 r
.78025 .5165 m .78247 .5167 L .77903 .51622 L F
.301 0 0 r
.37885 .63649 m .38279 .63478 L .38128 .63607 L F
.37885 .63649 m .37954 .63579 L .38279 .63478 L F
.256 0 0 r
.38501 .63435 m .38128 .63607 L .38279 .63478 L F
.46 .283 .553 r
.44082 .68134 m .44325 .68078 L .44306 .67815 L F
.417 .244 .537 r
.44082 .68134 m .44298 .68277 L .44325 .68078 L F
.44082 .68134 m .44063 .68414 L .44298 .68277 L F
.765 .692 .782 r
.56047 .66658 m .5599 .66965 L .5586 .66892 L F
.79 .304 .062 r
.5599 .66965 m .56067 .67158 L .5586 .66892 L F
.247 .196 .601 r
.56047 .66658 m .56118 .66921 L .5599 .66965 L F
.166 0 .374 r
.5599 .66965 m .56118 .66921 L .56067 .67158 L F
.692 .158 0 r
.56345 .63815 m .56548 .64034 L .56416 .63966 L F
0 0 .163 r
.61272 .63705 m .61268 .64082 L .61298 .63817 L F
.675 .437 .552 r
.43852 .61163 m .43446 .61433 L .43467 .61255 L F
.53 .411 .662 r
.34048 .60938 m .34107 .61184 L .33886 .61238 L F
.547 .476 .728 r
.34107 .61184 m .34161 .61438 L .33886 .61238 L F
.265 0 0 r
.40195 .62713 m .40361 .6274 L .40121 .62828 L F
.40195 .62713 m .40432 .62684 L .40361 .6274 L F
.594 .582 .809 r
.80142 .50505 m .80382 .50436 L .80281 .50117 L F
.752 .425 .43 r
.80369 .50778 m .80142 .50505 L .80131 .50774 L F
.528 .656 .917 r
.79522 .48162 m .7936 .48379 L .7927 .48225 L F
.79522 .48162 m .79794 .48508 L .7936 .48379 L F
.632 .658 .857 r
.79272 .49393 m .79583 .49557 L .79496 .494 L F
.184 .491 .903 r
.79583 .49557 m .79778 .49521 L .79496 .494 L F
.79583 .49557 m .79823 .4964 L .79778 .49521 L F
.899 .539 .351 r
.53943 .66634 m .53704 .66354 L .5391 .66402 L F
.35 .802 .947 r
.3799 .5943 m .3786 .59396 L .37638 .59433 L F
.091 0 0 r
.38209 .59398 m .3786 .59396 L .3799 .5943 L F
.914 .722 .629 r
.61229 .6175 m .61129 .61436 L .61179 .61546 L F
.869 .691 .659 r
.60916 .6197 m .61229 .6175 L .61179 .61546 L F
.60916 .6197 m .6126 .62046 L .61229 .6175 L F
.742 .432 .457 r
.31923 .63238 m .31791 .6361 L .31529 .63211 L F
0 0 0 r
.32017 .63152 m .31923 .63238 L .32106 .63446 L F
.32017 .63152 m .31791 .6361 L .31923 .63238 L F
0 .133 .661 r
.57154 .65802 m .57224 .65687 L .57116 .65478 L F
0 .189 .704 r
.57154 .65802 m .57346 .66016 L .57224 .65687 L F
.365 .145 .441 r
.30563 .59788 m .30751 .59732 L .30793 .59482 L F
.487 .365 .64 r
.30577 .60032 m .30751 .59732 L .30563 .59788 L F
.701 .762 .899 r
.55603 .59849 m .55717 .5973 L .55486 .5984 L F
.243 .648 .961 r
.55603 .59849 m .55971 .59863 L .55717 .5973 L F
.55603 .59849 m .56076 .59949 L .55971 .59863 L F
.724 .845 .939 r
.77521 .50871 m .77177 .50888 L .77428 .50822 L F
.6 .926 .966 r
.77664 .50729 m .77815 .50754 L .77521 .50871 L F
.591 .908 .981 r
.77664 .50729 m .77521 .50871 L .77428 .50822 L F
.505 .136 .274 r
.76683 .4876 m .7694 .48739 L .77001 .48533 L F
.39 .033 .234 r
.77001 .48533 m .77193 .48682 L .77267 .48534 L F
.77001 .48533 m .7694 .48739 L .77193 .48682 L F
.212 0 .176 r
.3459 .60355 m .34486 .60603 L .34326 .60609 L F
.462 .118 .296 r
.34748 .60486 m .3459 .60355 L .34797 .60299 L F
.34748 .60486 m .34486 .60603 L .3459 .60355 L F
.48 .839 .994 r
.37378 .58383 m .37595 .58328 L .37751 .58394 L F
.251 .737 .925 r
.37801 .58325 m .37751 .58394 L .37595 .58328 L F
.37801 .58325 m .37984 .58381 L .37751 .58394 L F
.652 .776 .939 r
.35376 .62267 m .34985 .62241 L .35179 .62223 L F
.071 .407 .86 r
.35433 .62193 m .35376 .62267 L .35179 .62223 L F
.35433 .62193 m .35538 .62352 L .35376 .62267 L F
.33 0 .015 r
.49514 .69583 m .49632 .69669 L .49724 .69542 L F
.133 0 .331 r
.49613 .69655 m .49476 .6982 L .49514 .69583 L F
.705 .287 .249 r
.49928 .6973 m .49692 .69701 L .49632 .69669 L F
.49692 .69701 m .49548 .69684 L .49632 .69669 L F
.133 0 .331 r
.49632 .69669 m .49532 .69766 L .49611 .69657 L F
.49632 .69669 m .49611 .69657 L .49613 .69655 L F
.49532 .69766 m .49476 .6982 L .49613 .69655 L F
.33 0 .015 r
.49514 .69583 m .49419 .69751 L .49632 .69669 L F
.133 0 .331 r
.49632 .69669 m .49514 .69583 L .49724 .69542 L F
.755 .957 .651 r
.4976 .69453 m .49548 .69684 L .49789 .69381 L F
.49724 .69542 m .49654 .69599 L .4976 .69453 L F
.49654 .69599 m .49548 .69684 L .4976 .69453 L F
.715 .503 .602 r
.5688 .6052 m .57022 .6072 L .56919 .60913 L F
.5688 .6052 m .57131 .60629 L .57142 .60889 L F
.884 .918 .842 r
.56776 .60833 m .57131 .60629 L .5688 .6052 L F
.03 .526 .877 r
.57131 .60629 m .56809 .6049 L .5688 .6052 L F
.57131 .60629 m .57013 .60546 L .56809 .6049 L F
.884 .918 .842 r
.56776 .60833 m .57013 .60546 L .57087 .60598 L F
.57043 .6068 m .57087 .60598 L .57131 .60629 L F
.56776 .60833 m .57087 .60598 L .57043 .6068 L F
.715 .503 .602 r
.56919 .60913 m .57142 .60889 L .56923 .60952 L F
.57022 .6072 m .57142 .60889 L .56919 .60913 L F
.163 0 0 r
.57142 .60889 m .56829 .61057 L .56923 .60952 L F
.977 .858 .655 r
.48738 .66547 m .4892 .66445 L .48819 .66279 L F
.48738 .66547 m .48837 .66672 L .4892 .66445 L F
.476 .408 .7 r
.53691 .68186 m .5379 .6795 L .53565 .68052 L F
.871 .611 .544 r
.61114 .62286 m .6126 .62046 L .60916 .6197 L F
.46 .491 .804 r
.30427 .60685 m .30554 .60933 L .30708 .60852 L F
.917 .703 .597 r
.5946 .60362 m .59288 .60305 L .59312 .60029 L F
.91 .595 .439 r
.5946 .60362 m .59315 .60494 L .59288 .60305 L F
.897 .572 .424 r
.5946 .60362 m .59517 .60598 L .59315 .60494 L F
.421 .6 .92 r
.42554 .59165 m .42432 .59304 L .42341 .59172 L F
.42554 .59165 m .42737 .5941 L .42432 .59304 L F
.656 .654 .836 r
.4683 .70822 m .46944 .70654 L .46686 .70642 L F
.053 .301 .789 r
.56231 .62266 m .5638 .62523 L .56287 .6246 L F
.37 .578 .921 r
.34675 .64569 m .34752 .64491 L .34486 .64385 L F
.34675 .64569 m .34893 .64671 L .34752 .64491 L F
.65 .675 .861 r
.31015 .62522 m .31191 .62716 L .31437 .62629 L F
.69 .248 .197 r
.31015 .62522 m .31437 .62629 L .31191 .62716 L F
.059 .624 .729 r
.34081 .5829 m .34302 .58277 L .34453 .58272 L F
.112 0 0 r
.34453 .58272 m .34302 .58277 L .34668 .58286 L F
.436 .289 .581 r
.20925 .59735 m .20954 .59982 L .20729 .60068 L F
.47 .387 .68 r
.20954 .59982 m .20773 .60346 L .20729 .60068 L F
.749 .405 .401 r
.50301 .62417 m .49947 .62549 L .50305 .62561 L F
.50301 .62417 m .49957 .6237 L .49947 .62549 L F
.295 0 0 r
.39108 .63217 m .38954 .63363 L .38738 .63386 L F
.253 0 0 r
.39334 .6315 m .38954 .63363 L .39108 .63217 L F
.351 .056 .317 r
.46054 .66372 m .46273 .66351 L .46337 .66096 L F
.439 .159 .389 r
.46273 .66351 m .46545 .66026 L .46337 .66096 L F
.527 .215 .382 r
.42632 .61514 m .426 .61694 L .42353 .61723 L F
.561 .246 .391 r
.42632 .61514 m .42844 .61682 L .426 .61694 L F
.589 .231 .33 r
.42947 .61477 m .42844 .61682 L .42632 .61514 L F
.956 .646 .401 r
.46527 .71182 m .46543 .71003 L .46414 .70939 L F
.115 .437 .876 r
.21832 .55168 m .21772 .55249 L .21626 .55147 L F
.21832 .55168 m .22001 .55366 L .21772 .55249 L F
.232 .091 .475 r
.48065 .64392 m .4824 .64552 L .48119 .64169 L F
.48065 .64392 m .48016 .64658 L .4824 .64552 L F
.897 .547 .372 r
.60677 .60312 m .60829 .60611 L .61007 .60639 L F
.955 .713 .532 r
.60811 .60757 m .61007 .60639 L .60829 .60611 L F
.60811 .60757 m .60975 .60836 L .61007 .60639 L F
.419 .109 .33 r
.45541 .66936 m .45768 .66886 L .45827 .66612 L F
.342 .094 .387 r
.45827 .66612 m .4604 .66637 L .46054 .66372 L F
.212 0 .261 r
.45827 .66612 m .45948 .66783 L .4604 .66637 L F
.45827 .66612 m .45768 .66886 L .45948 .66783 L F
.821 .62 .63 r
.55576 .59372 m .55923 .59455 L .55929 .59203 L F
.578 .815 .43 r
.55923 .59455 m .56154 .59142 L .55929 .59203 L F
.319 .526 .899 r
.44093 .69748 m .4411 .69884 L .44237 .69737 L F
.232 .393 .819 r
.4411 .69884 m .44426 .70098 L .44237 .69737 L F
.525 .684 .939 r
.40738 .59671 m .40779 .59415 L .40591 .59397 L F
.40738 .59671 m .40981 .59649 L .40779 .59415 L F
.628 .279 .36 r
.51707 .68725 m .51924 .68914 L .51684 .6889 L F
.543 .305 .504 r
.51948 .6868 m .51924 .68914 L .51707 .68725 L F
.513 .418 .684 r
.30385 .60324 m .30631 .60619 L .30591 .60246 L F
.30385 .60324 m .30427 .60685 L .30631 .60619 L F
.82 .999 .832 r
.59305 .6342 m .59345 .63525 L .59272 .6344 L F
.59305 .6342 m .5957 .63301 L .59345 .63525 L F
0 .037 .587 r
.59345 .63525 m .59327 .6346 L .59272 .6344 L F
.82 .999 .832 r
.59305 .6342 m .59272 .6344 L .59272 .6344 L F
.898 .596 .096 r
.59327 .6346 m .59305 .6342 L .59272 .6344 L F
.102 0 0 r
.59058 .63641 m .59327 .6346 L .59183 .6372 L F
.63 .62 .822 r
.59327 .6346 m .59323 .63826 L .59183 .6372 L F
.102 0 0 r
.59058 .63641 m .59297 .6356 L .59327 .6346 L F
.898 .596 .096 r
.59327 .6346 m .59297 .6356 L .59305 .6342 L F
0 0 .03 r
.59297 .6356 m .59358 .63388 L .59305 .6342 L F
.922 .942 .796 r
.59305 .6342 m .59564 .63093 L .59654 .63175 L F
0 0 .03 r
.59358 .63388 m .59377 .63337 L .59305 .6342 L F
0 .037 .587 r
.59345 .63525 m .59528 .6373 L .59327 .6346 L F
.418 .156 .407 r
.57795 .59421 m .57733 .59701 L .57536 .59767 L F
.545 .263 .438 r
.57795 .59421 m .57931 .59716 L .57733 .59701 L F
.57795 .59421 m .58055 .59414 L .57931 .59716 L F
.718 .492 .582 r
.49172 .6525 m .49151 .65475 L .48945 .65472 L F
.496 .299 .543 r
.49172 .6525 m .49387 .65443 L .49151 .65475 L F
.645 .263 .307 r
.49474 .65291 m .49387 .65443 L .49172 .6525 L F
.317 .233 .6 r
.78424 .51062 m .78514 .5127 L .78278 .5136 L F
.44 .274 .559 r
.78463 .51589 m .78278 .5136 L .78514 .5127 L F
.78463 .51589 m .78247 .5167 L .78278 .5136 L F
.481 .667 .945 r
.74594 .50378 m .74484 .50534 L .74349 .50383 L F
.896 .554 .39 r
.74484 .50534 m .7457 .50779 L .74358 .50703 L F
.259 .767 .848 r
.36229 .59673 m .36084 .59668 L .35864 .59709 L F
.111 .664 .752 r
.36456 .5964 m .36084 .59668 L .36229 .59673 L F
.579 .515 .747 r
.54971 .66923 m .54578 .66659 L .54925 .6683 L F
.768 .54 .589 r
.48587 .66667 m .48314 .669 L .48243 .66669 L F
.48587 .66667 m .4855 .66968 L .48314 .669 L F
.477 .208 .426 r
.48837 .66672 m .4855 .66968 L .48587 .66667 L F
0 0 .038 r
.48738 .63245 m .48508 .63508 L .48679 .63452 L F
.382 .235 .554 r
.48508 .63508 m .48692 .6369 L .48679 .63452 L F
.48508 .63508 m .48471 .63794 L .48692 .6369 L F
.581 .918 .701 r
.54971 .66923 m .54635 .67184 L .5482 .672 L F
.936 .616 .167 r
.74053 .47408 m .73946 .47131 L .74084 .4718 L F
.74053 .47408 m .73974 .47327 L .73946 .47131 L F
.73946 .47131 m .73974 .47327 L .74053 .47408 L F
.821 .507 .458 r
.46527 .71182 m .46748 .71497 L .46885 .71272 L F
.819 .504 .457 r
.46748 .71497 m .47151 .71635 L .46885 .71272 L F
.761 .554 .617 r
.47151 .71635 m .47154 .71266 L .46885 .71272 L F
.311 0 .028 r
.77766 .48404 m .78084 .48203 L .77835 .48213 L F
.401 .175 .453 r
.30793 .59482 m .30948 .59668 L .31011 .59426 L F
.30793 .59482 m .30751 .59732 L .30948 .59668 L F
0 0 0 r
.52908 .63319 m .53006 .63306 L .53125 .63281 L F
.52908 .63319 m .5278 .6337 L .53006 .63306 L F
.481 .265 .509 r
.44856 .67561 m .45082 .67507 L .45101 .67269 L F
.422 .217 .494 r
.45101 .67269 m .45082 .67507 L .45305 .6721 L F
.15 .606 .93 r
.46902 .70109 m .47135 .70151 L .47213 .70218 L F
.47213 .70218 m .47135 .70151 L .46902 .70109 L F
.754 .51 .562 r
.46886 .70367 m .47213 .70218 L .46902 .70109 L F
.46886 .70367 m .47247 .70415 L .47213 .70218 L F
.659 .903 .98 r
.47213 .70218 m .47135 .70151 L .47331 .7004 L F
.47213 .70218 m .47135 .70151 L .47331 .7004 L F
.961 .743 .564 r
.6111 .62521 m .61313 .62356 L .61114 .62286 L F
.957 .614 .28 r
.57984 .64904 m .57989 .65271 L .58184 .65241 L F
.57989 .65271 m .57989 .65282 L .57996 .6528 L F
.57989 .65271 m .57996 .6528 L .58184 .65241 L F
.857 .491 .358 r
.57859 .65084 m .57989 .65281 L .57984 .64904 L F
.715 .689 .824 r
.57989 .65281 m .57989 .65282 L .57886 .65301 L F
.61 .878 .991 r
.57886 .65301 m .57989 .65282 L .57989 .65281 L F
.57886 .65301 m .57989 .65281 L .57859 .65084 L F
.715 .689 .824 r
.57962 .6524 m .57989 .65281 L .57886 .65301 L F
.61 .878 .991 r
.57886 .65301 m .5787 .65402 L .57989 .65282 L F
.715 .689 .824 r
.57989 .65282 m .58016 .65324 L .57886 .65301 L F
.61 .878 .991 r
.57886 .65301 m .57989 .65282 L .57989 .65282 L F
.857 .491 .358 r
.57989 .65281 m .57989 .65282 L .57989 .65282 L F
.57989 .65281 m .57989 .65282 L .57984 .64904 L F
.715 .689 .824 r
.58104 .65127 m .58025 .65304 L .57962 .6524 L F
.019 0 0 r
.58106 .65455 m .58184 .65241 L .58011 .65277 L F
.58106 .65455 m .58011 .65277 L .58003 .65302 L F
.58106 .65455 m .57989 .65282 L .57989 .65282 L F
.58106 .65455 m .5839 .65273 L .58184 .65241 L F
.568 .798 .986 r
.5787 .65402 m .58106 .65455 L .57989 .65282 L F
.019 0 0 r
.58106 .65455 m .58301 .65376 L .5839 .65273 L F
.634 .587 .784 r
.58148 .65426 m .57987 .65349 L .58301 .65376 L F
.57987 .65349 m .57886 .65301 L .57996 .65321 L F
.57987 .65349 m .57996 .65321 L .58301 .65376 L F
.019 0 0 r
.58003 .65302 m .58011 .65277 L .57989 .65282 L F
.57989 .65282 m .57989 .65282 L .57989 .65282 L F
.715 .689 .824 r
.58025 .65304 m .58016 .65324 L .57989 .65282 L F
.58025 .65304 m .57989 .65282 L .57962 .6524 L F
.989 .72 .384 r
.57986 .64927 m .58104 .65127 L .57962 .6524 L F
.57916 .65187 m .57962 .6524 L .57886 .65301 L F
.57986 .64927 m .57962 .6524 L .57916 .65187 L F
0 .484 .708 r
.58545 .653 m .5839 .65273 L .58614 .65311 L F
.58184 .65241 m .5839 .65273 L .58545 .653 L F
.959 .924 .723 r
.5839 .65273 m .58301 .65376 L .58355 .65266 L F
.5839 .65273 m .58355 .65266 L .58456 .65063 L F
.715 .689 .824 r
.58104 .65127 m .58301 .65376 L .58016 .65324 L F
.424 .129 .359 r
.45004 .67704 m .44856 .67561 L .4481 .67763 L F
.45004 .67704 m .45082 .67507 L .44856 .67561 L F
.643 .447 .603 r
.44034 .60934 m .44026 .61171 L .43852 .61163 L F
.66 .709 .884 r
.44122 .60677 m .44034 .60934 L .43911 .60694 L F
.44122 .60677 m .44278 .60907 L .44034 .60934 L F
.632 .428 .588 r
.44278 .60907 m .44026 .61171 L .44034 .60934 L F
.205 .514 .914 r
.50377 .68948 m .5026 .69022 L .50152 .68918 L F
.50377 .68948 m .50556 .69162 L .5026 .69022 L F
.547 .49 .743 r
.50556 .69162 m .50366 .69295 L .5026 .69022 L F
.617 .762 .948 r
.76232 .5074 m .75976 .50813 L .75817 .50686 L F
.989 .811 .572 r
.79076 .52805 m .79139 .52596 L .79026 .52402 L F
.439 .03 .165 r
.31695 .59128 m .32093 .5888 L .31867 .5892 L F
.564 .337 .53 r
.51826 .68137 m .52109 .68101 L .5213 .67817 L F
.537 .274 .464 r
.52109 .68101 m .52417 .67783 L .5213 .67817 L F
.761 .554 .617 r
.47151 .71635 m .4731 .71529 L .47154 .71266 L F
.418 .182 .447 r
.45339 .66988 m .45305 .6721 L .45541 .66936 L F
.653 .611 .795 r
.59426 .64536 m .5931 .65014 L .59334 .64739 L F
.59426 .64536 m .59544 .6493 L .5931 .65014 L F
.52 .243 .435 r
.48466 .64258 m .48253 .64049 L .48119 .64169 L F
.288 .143 .503 r
.48119 .64169 m .48383 .64444 L .48466 .64258 L F
.48119 .64169 m .4824 .64552 L .48383 .64444 L F
.621 .599 .806 r
.30893 .63005 m .31001 .6311 L .30989 .62864 L F
.456 .43 .741 r
.31001 .6311 m .31251 .62716 L .30989 .62864 L F
.31001 .6311 m .3138 .63174 L .31251 .62716 L F
0 .504 .754 r
.31529 .63211 m .3138 .63174 L .31066 .63122 L F
.841 .531 .465 r
.31791 .6361 m .3138 .63174 L .31529 .63211 L F
.31791 .6361 m .31485 .63589 L .3138 .63174 L F
.446 .29 .576 r
.3138 .63174 m .31485 .63589 L .31604 .63211 L F
.3138 .63174 m .31604 .63211 L .31617 .63169 L F
0 .504 .754 r
.31066 .63122 m .3138 .63174 L .31001 .6311 L F
0 0 0 r
.50556 .69162 m .50276 .69389 L .50366 .69295 L F
.354 0 .166 r
.41247 .62144 m .412 .62272 L .4097 .62322 L F
.497 .15 .307 r
.41551 .6205 m .412 .62272 L .41247 .62144 L F
.588 .431 .636 r
.49789 .69381 m .50015 .69079 L .49857 .69106 L F
.783 .716 .789 r
.46693 .70428 m .46902 .70109 L .46515 .70092 L F
.436 .263 .547 r
.46886 .70367 m .46902 .70109 L .46693 .70428 L F
.512 .486 .765 r
.46944 .70654 m .46693 .70428 L .46686 .70642 L F
.46944 .70654 m .46886 .70367 L .46693 .70428 L F
.653 .359 .461 r
.43188 .61454 m .42844 .61682 L .42947 .61477 L F
.782 .825 .886 r
.32504 .63645 m .3264 .6379 L .32703 .63511 L F
.304 .577 .937 r
.41835 .58806 m .4175 .58938 L .41654 .58787 L F
.41835 .58806 m .4206 .59017 L .4175 .58938 L F
.099 .623 .878 r
.39164 .59422 m .39035 .59372 L .38847 .59358 L F
.481 .854 .986 r
.39256 .59314 m .39164 .59422 L .39415 .59358 L F
.39256 .59314 m .39035 .59372 L .39164 .59422 L F
.857 .754 .748 r
.46918 .68895 m .46712 .6896 L .46853 .68681 L F
.69 .319 .339 r
.46918 .68895 m .46848 .6914 L .46712 .6896 L F
.546 .344 .558 r
.47219 .68652 m .46918 .68895 L .46853 .68681 L F
.47219 .68652 m .4716 .68922 L .46918 .68895 L F
.633 .262 .322 r
.47171 .69137 m .46918 .68895 L .4716 .68922 L F
.47171 .69137 m .46848 .6914 L .46918 .68895 L F
.581 .289 .438 r
.58456 .59184 m .58475 .59397 L .5829 .59425 L F
.638 .45 .612 r
.58456 .59184 m .58729 .5941 L .58475 .59397 L F
.58456 .59184 m .58882 .59162 L .58729 .5941 L F
.875 .964 .634 r
.61309 .65387 m .6116 .6575 L .61265 .65565 L F
.768 .757 .843 r
.78475 .49946 m .78805 .4998 L .7861 .50094 L F
.834 .713 .73 r
.54748 .67546 m .54492 .6755 L .54635 .67184 L F
.85 .739 .74 r
.54748 .67546 m .54376 .67736 L .54492 .6755 L F
.54748 .67546 m .54532 .67823 L .54376 .67736 L F
.533 .554 .822 r
.54896 .67202 m .54971 .67506 L .54748 .67546 L F
.828 .909 .504 r
.75397 .50777 m .75527 .50436 L .75599 .50557 L F
.75397 .50777 m .75379 .50753 L .75527 .50436 L F
1 .83 .525 r
.75409 .51082 m .75379 .50753 L .75397 .50777 L F
.714 .47 .555 r
.47483 .71562 m .4794 .7174 L .47872 .71548 L F
.768 .48 .498 r
.4794 .7174 m .48045 .71849 L .47872 .71548 L F
0 0 0 r
.30963 .61733 m .3076 .62012 L .30894 .61904 L F
.38 .429 .786 r
.30963 .61733 m .31034 .6138 L .30834 .6149 L F
.30963 .61733 m .31142 .61718 L .31034 .6138 L F
.691 .457 .563 r
.30894 .61904 m .31142 .61718 L .30963 .61733 L F
.561 .922 .748 r
.78339 .48197 m .78221 .48237 L .78365 .48138 L F
.78339 .48197 m .78365 .48138 L .78517 .48033 L F
.254 .732 .936 r
.78325 .48231 m .78339 .48197 L .78428 .48243 L F
.78084 .48203 m .78339 .48197 L .78325 .48231 L F
.519 .846 .998 r
.78339 .48197 m .78676 .48207 L .78428 .48243 L F
0 0 0 r
.19786 .54361 m .19765 .54331 L .19563 .54369 L F
.19786 .54361 m .19968 .54262 L .19765 .54331 L F
0 0 .289 r
.56786 .64355 m .56795 .64683 L .56818 .64597 L F
.863 .431 .011 r
.56998 .64884 m .56818 .64597 L .56795 .64683 L F
.922 .942 .796 r
.59305 .6342 m .59654 .63175 L .5957 .63301 L F
.763 .606 .683 r
.73946 .47131 m .74297 .47112 L .74084 .4718 L F
.21 0 0 r
.43723 .70526 m .43793 .70543 L .43917 .70404 L F
.483 .442 .735 r
.80266 .51063 m .80369 .50778 L .80131 .50774 L F
.80266 .51063 m .8054 .51092 L .80369 .50778 L F
.74 .784 .888 r
.78637 .52257 m .78501 .52622 L .78377 .52432 L F
.78637 .52257 m .78733 .52462 L .78501 .52622 L F
.419 .829 .974 r
.36831 .59638 m .36687 .59592 L .36456 .5964 L F
.157 .692 .844 r
.37035 .59598 m .36687 .59592 L .36831 .59638 L F
.435 .272 .56 r
.5398 .70961 m .53992 .71258 L .5379 .7133 L F
.326 .043 .321 r
.5379 .7133 m .53992 .71258 L .53733 .7152 L F
.101 0 0 r
.35644 .59759 m .35468 .59899 L .3525 .59954 L F
.507 0 0 r
.53554 .63398 m .53716 .63485 L .53863 .63514 L F
0 .261 .685 r
.53993 .63569 m .53863 .63514 L .53716 .63485 L F
.53993 .63569 m .54131 .63665 L .53863 .63514 L F
.18 0 .142 r
.34486 .60603 m .34294 .60741 L .34326 .60609 L F
.07 0 .245 r
.46282 .7012 m .46098 .70395 L .46073 .70276 L F
.46282 .7012 m .46207 .70394 L .46098 .70395 L F
.08 .238 .726 r
.46207 .70394 m .46309 .706 L .46098 .70395 L F
.81 .677 .718 r
.58882 .59162 m .59023 .59478 L .58729 .5941 L F
.821 .631 .646 r
.58729 .5941 m .59023 .59478 L .58993 .5974 L F
.47 .387 .68 r
.20954 .59982 m .20908 .60269 L .20773 .60346 L F
.373 .143 .432 r
.20908 .60269 m .20718 .60569 L .20773 .60346 L F
0 .346 .675 r
.58303 .67258 m .58334 .67266 L .58219 .67169 L F
.58303 .67258 m .58458 .67316 L .58334 .67266 L F
.675 .139 0 r
.55277 .66263 m .55384 .66395 L .55189 .66255 L F
.363 .834 .837 r
.80173 .52264 m .79899 .52357 L .79783 .52369 L F
.762 .328 0 r
.53655 .61807 m .53621 .61835 L .53424 .61653 L F
.53655 .61807 m .53721 .61959 L .53621 .61835 L F
.518 .46 .731 r
.48115 .67772 m .47905 .67832 L .47802 .67447 L F
.098 .131 .607 r
.48081 .68035 m .47905 .67832 L .48115 .67772 L F
.48081 .68035 m .47985 .68101 L .47905 .67832 L F
.435 .305 .604 r
.21265 .58892 m .21305 .59159 L .21117 .59198 L F
.533 .387 .629 r
.21351 .59386 m .21117 .59198 L .21305 .59159 L F
.21351 .59386 m .21131 .59445 L .21117 .59198 L F
.385 .112 .373 r
.53479 .64615 m .53678 .64544 L .53733 .64363 L F
.597 .207 .275 r
.53862 .64491 m .53805 .64326 L .53879 .6425 L F
.53805 .64326 m .53793 .64291 L .53879 .6425 L F
.178 .037 .439 r
.53805 .64326 m .53807 .64306 L .53733 .64363 L F
.597 .207 .275 r
.53805 .64326 m .53525 .64521 L .53793 .64291 L F
.53862 .64491 m .538 .64365 L .53805 .64326 L F
.178 .037 .439 r
.538 .64365 m .53862 .64491 L .53879 .6425 L F
.53678 .64544 m .53862 .64491 L .538 .64365 L F
.597 .207 .275 r
.53862 .64491 m .53786 .64498 L .538 .64365 L F
.178 .037 .439 r
.53717 .64414 m .53805 .64326 L .53733 .64363 L F
.53678 .64544 m .53879 .6425 L .53717 .64414 L F
.597 .207 .275 r
.53786 .64498 m .53525 .64521 L .53805 .64326 L F
.178 .037 .439 r
.53805 .64326 m .53879 .6425 L .53807 .64306 L F
.569 .821 .993 r
.58874 .67741 m .58998 .67853 L .59229 .67779 L F
.749 .472 .513 r
.54348 .61387 m .5456 .61699 L .54634 .61363 L F
.318 .075 .379 r
.54634 .61363 m .5456 .61699 L .54793 .61563 L F
.864 .761 .748 r
.59456 .60826 m .59637 .60938 L .59463 .61184 L F
.6 .519 .736 r
.4802 .672 m .48082 .67515 L .47802 .67447 L F
.518 .46 .731 r
.48115 .67772 m .47802 .67447 L .48082 .67515 L F
.569 .767 .972 r
.39635 .5931 m .3977 .59442 L .39985 .59389 L F
.497 .126 .265 r
.56655 .59093 m .56998 .58875 L .56761 .58931 L F
.478 .748 .989 r
.74097 .5184 m .7429 .51708 L .73989 .51709 L F
.74097 .5184 m .74392 .51814 L .7429 .51708 L F
.387 .059 .282 r
.50796 .64357 m .50685 .64587 L .50466 .64641 L F
.567 .217 .336 r
.51062 .64345 m .50685 .64587 L .50796 .64357 L F
.584 .33 .498 r
.51891 .65534 m .51874 .65756 L .51687 .65755 L F
.396 .175 .458 r
.52087 .65682 m .51891 .65534 L .52153 .6555 L F
.52087 .65682 m .51874 .65756 L .51891 .65534 L F
.07 0 .245 r
.46282 .7012 m .46073 .70276 L .45924 .70106 L F
.565 .383 .593 r
.50214 .64642 m .50208 .64904 L .49973 .6492 L F
.256 0 0 r
.50208 .64904 m .49867 .65119 L .49973 .6492 L F
.447 .002 .096 r
.76814 .49145 m .77042 .49236 L .76785 .4927 L F
.441 .269 .551 r
.44306 .67815 m .44533 .68011 L .44559 .67775 L F
.44306 .67815 m .44325 .68078 L .44533 .68011 L F
.745 .937 .949 r
.78803 .5286 m .7889 .52948 L .79076 .52805 L F
0 0 .366 r
.61294 .64317 m .6136 .64542 L .61307 .64663 L F
0 0 .075 r
.6136 .64542 m .61279 .64904 L .61307 .64663 L F
.739 .736 .849 r
.26451 .86361 m .26599 .86249 L .26356 .86232 L F
.465 .481 .79 r
.19824 .56024 m .19988 .55934 L .19778 .55896 L F
.454 .224 .474 r
.19756 .56149 m .19988 .55934 L .19824 .56024 L F
.646 .504 .675 r
.44035 .69543 m .44213 .69265 L .44015 .69287 L F
.389 .787 .986 r
.38407 .58295 m .38336 .58397 L .38197 .58341 L F
.38407 .58295 m .38554 .5837 L .38336 .58397 L F
.506 .364 .622 r
.41526 .60623 m .41733 .60578 L .4169 .60347 L F
.579 .388 .588 r
.41509 .60848 m .41733 .60578 L .41526 .60623 L F
.323 .693 .98 r
.78581 .48999 m .78913 .4911 L .78813 .49021 L F
.211 .494 .901 r
.78913 .4911 m .7906 .49005 L .78813 .49021 L F
.78913 .4911 m .79203 .49235 L .7906 .49005 L F
.541 .793 .991 r
.40907 .58552 m .40813 .58697 L .40679 .58573 L F
.40907 .58552 m .41018 .58653 L .40813 .58697 L F
.239 0 .236 r
.50018 .66685 m .49784 .66945 L .50011 .66931 L F
.015 0 .029 r
.49784 .66945 m .50018 .66685 L .50011 .66931 L F
.581 .365 .553 r
.50169 .6683 m .50018 .66685 L .50011 .66931 L F
.50169 .6683 m .50299 .66658 L .50018 .66685 L F
.612 .405 .577 r
.50299 .66658 m .50291 .66753 L .50169 .6683 L F
.50291 .66753 m .50276 .6693 L .50011 .66931 L F
.5 .301 .541 r
.50513 .66614 m .50299 .66658 L .50323 .6691 L F
.50513 .66614 m .50323 .6691 L .50507 .66874 L F
.424 .246 .534 r
.50507 .66874 m .50323 .66919 L .50323 .6691 L F
.5 .301 .541 r
.50315 .66921 m .50296 .66952 L .50507 .66874 L F
.424 .246 .534 r
.50323 .66919 m .50276 .6693 L .50299 .66658 L F
.5 .301 .541 r
.50323 .6691 m .50299 .66658 L .50296 .66928 L F
.50315 .66921 m .50296 .66928 L .50296 .66952 L F
.50323 .6691 m .50296 .66928 L .50315 .66921 L F
.581 .365 .553 r
.50279 .66935 m .50299 .66658 L .50169 .6683 L F
.50296 .66952 m .50296 .66928 L .50279 .66935 L F
.153 0 0 r
.50269 .66937 m .50275 .66931 L .50315 .66921 L F
.581 .365 .553 r
.50296 .66928 m .50299 .66658 L .50279 .66935 L F
0 0 0 r
.50507 .66874 m .50296 .66952 L .50178 .6702 L F
.153 0 0 r
.50178 .6702 m .50264 .66941 L .50507 .66874 L F
.581 .365 .553 r
.50249 .66948 m .50169 .6683 L .50011 .66931 L F
.50296 .66952 m .50279 .66935 L .50249 .66948 L F
.153 0 0 r
.50264 .66941 m .50269 .66937 L .50284 .66933 L F
.50264 .66941 m .50284 .66933 L .50279 .66935 L F
.581 .365 .553 r
.50279 .66935 m .50169 .6683 L .50249 .66948 L F
.153 0 0 r
.50279 .66935 m .50284 .66933 L .50284 .66933 L F
.50264 .66941 m .50284 .66933 L .50507 .66874 L F
.50269 .66937 m .50315 .66921 L .50507 .66874 L F
.50275 .66931 m .50276 .6693 L .50507 .66874 L F
.5 .301 .541 r
.50323 .6691 m .50315 .66921 L .50507 .66874 L F
.424 .246 .534 r
.50507 .66874 m .50323 .6691 L .50299 .66658 L F
.612 .405 .577 r
.50299 .66658 m .50169 .6683 L .50011 .66931 L F
.50299 .66658 m .50011 .66931 L .50018 .66685 L F
.562 .234 .371 r
.42353 .61723 m .42032 .61941 L .42068 .61822 L F
.966 .643 .331 r
.53897 .67018 m .5394 .66908 L .53677 .67002 L F
.53897 .67018 m .54028 .67222 L .5394 .66908 L F
.254 .247 .658 r
.5394 .66908 m .54134 .66846 L .53943 .66634 L F
.966 .643 .331 r
.5394 .66908 m .54028 .67222 L .53897 .67018 L F
.669 .387 .486 r
.54267 .66957 m .5427 .67183 L .5394 .66908 L F
.966 .643 .331 r
.5394 .66908 m .53897 .67018 L .54134 .66846 L F
0 0 .376 r
.563 .68562 m .56204 .68424 L .56297 .68308 L F
.563 .68562 m .56184 .68687 L .56204 .68424 L F
.915 .934 .807 r
.56239 .68503 m .56184 .68687 L .56201 .68466 L F
.56297 .68308 m .56239 .68503 L .56204 .68424 L F
.56239 .68503 m .56201 .68466 L .56204 .68424 L F
.56297 .68308 m .56085 .68625 L .56184 .68687 L F
.487 .202 .406 r
.56135 .68705 m .56181 .68974 L .56049 .68989 L F
0 0 0 r
.56135 .68705 m .56096 .68833 L .56098 .68827 L F
.487 .202 .406 r
.56135 .68705 m .55931 .69003 L .56096 .68833 L F
.56135 .68705 m .56098 .68827 L .55931 .69003 L F
0 0 0 r
.56135 .68705 m .56098 .68827 L .56126 .68747 L F
.56135 .68705 m .56155 .68604 L .56299 .68562 L F
.56299 .68562 m .56299 .68562 L .563 .68562 L F
.56135 .68705 m .56299 .68562 L .56299 .68562 L F
.231 .138 .538 r
.56235 .68437 m .56135 .68705 L .563 .68562 L F
.56235 .68437 m .56244 .68742 L .56135 .68705 L F
0 0 0 r
.56135 .68705 m .56126 .68747 L .56235 .68437 L F
.56135 .68705 m .56085 .68625 L .56155 .68604 L F
.56297 .68308 m .56182 .6848 L .56235 .68437 L F
.56182 .6848 m .56085 .68625 L .56235 .68437 L F
.841 .596 .567 r
.56298 .68061 m .56297 .68308 L .56021 .68241 L F
0 0 0 r
.56297 .68308 m .56235 .68437 L .56021 .68241 L F
.961 .733 .287 r
.56235 .68437 m .56297 .68308 L .56298 .68158 L F
0 0 .076 r
.56315 .6813 m .56277 .68403 L .56235 .68437 L F
.961 .733 .287 r
.56235 .68437 m .563 .68562 L .56297 .68308 L F
0 0 .076 r
.56277 .68403 m .56276 .68414 L .56235 .68437 L F
0 0 0 r
.56135 .68705 m .56235 .68437 L .56085 .68625 L F
.918 .825 .738 r
.56235 .68437 m .56098 .68827 L .55917 .68691 L F
.56098 .68827 m .56096 .68833 L .56094 .68832 L F
.56098 .68827 m .56094 .68832 L .55917 .68691 L F
.487 .202 .406 r
.56098 .68827 m .56049 .68989 L .55966 .68999 L F
.56098 .68827 m .55966 .68999 L .55931 .69003 L F
.508 .343 .592 r
.57142 .60889 m .57131 .60629 L .57013 .60546 L F
.57142 .60889 m .57368 .6083 L .57131 .60629 L F
.57131 .60629 m .57368 .6083 L .57142 .60889 L F
.789 .699 .766 r
.72525 .49884 m .72532 .50281 L .72638 .49968 L F
.31 .071 .379 r
.46054 .66372 m .4622 .66546 L .46273 .66351 L F
.46054 .66372 m .4604 .66637 L .4622 .66546 L F
.692 .35 .393 r
.5426 .65728 m .54598 .65526 L .54256 .65458 L F
.5426 .65728 m .54496 .65753 L .54598 .65526 L F
.645 .607 .796 r
.54476 .65193 m .54598 .65526 L .54779 .65397 L F
.44 .143 .363 r
.54496 .65753 m .54779 .65397 L .54598 .65526 L F
.067 .213 .707 r
.55356 .65126 m .55438 .65404 L .55367 .65262 L F
.53 .311 .526 r
.49308 .64679 m .49553 .6464 L .49594 .64401 L F
.422 .214 .49 r
.49594 .64401 m .49757 .64559 L .49754 .64314 L F
.49594 .64401 m .49553 .6464 L .49757 .64559 L F
.634 .79 .957 r
.76576 .50793 m .76232 .5074 L .76485 .50666 L F
.603 .798 .974 r
.76852 .50715 m .76576 .50793 L .76485 .50666 L F
.899 .712 .641 r
.60829 .61388 m .61179 .61546 L .61129 .61436 L F
.60829 .61388 m .60804 .6164 L .61179 .61546 L F
.532 .479 .742 r
.30427 .60685 m .30708 .60852 L .30631 .60619 L F
0 0 .163 r
.61272 .63705 m .6129 .63956 L .61268 .64082 L F
0 .082 .605 r
.6129 .63956 m .61294 .64317 L .61268 .64082 L F
.621 .407 .569 r
.49023 .64898 m .49263 .64949 L .49308 .64679 L F
.635 .783 .953 r
.33593 .64124 m .3383 .64126 L .33797 .64035 L F
.714 .259 .169 r
.3383 .64126 m .3382 .64262 L .33797 .64035 L F
.3383 .64126 m .34153 .6432 L .3382 .64262 L F
.717 .317 .288 r
.34185 .64257 m .34153 .6432 L .3383 .64126 L F
0 0 0 r
.34668 .58286 m .34888 .58263 L .35047 .58244 L F
.097 0 0 r
.35047 .58244 m .34888 .58263 L .35255 .58244 L F
.142 .586 .928 r
.21071 .54861 m .20729 .54723 L .20932 .54707 L F
.37 .639 .959 r
.21115 .54708 m .21071 .54861 L .20932 .54707 L F
.396 .666 .968 r
.21115 .54708 m .21242 .54844 L .21071 .54861 L F
.754 .966 .932 r
.52136 .68361 m .52418 .68297 L .52376 .68314 L F
.375 .812 .656 r
.52548 .68218 m .52376 .68314 L .52418 .68297 L F
.529 .547 .818 r
.78309 .52148 m .78086 .52344 L .78007 .51994 L F
.538 .564 .829 r
.78309 .52148 m .78377 .52432 L .78086 .52344 L F
.469 0 0 r
.35255 .58244 m .35495 .58272 L .35542 .5819 L F
0 .326 .811 r
.21242 .54844 m .2147 .54998 L .21469 .55114 L F
.175 .545 .928 r
.2147 .54998 m .21626 .55147 L .21469 .55114 L F
.425 0 .126 r
.4826 .70068 m .4864 .69844 L .48371 .69991 L F
.767 .971 .689 r
.48371 .69991 m .48217 .70155 L .4826 .70068 L F
.425 0 .126 r
.4826 .70068 m .48609 .70057 L .4864 .69844 L F
.418 .297 .608 r
.48849 .70036 m .48673 .70128 L .4864 .69844 L F
.133 0 .074 r
.4864 .69844 m .48732 .69968 L .48849 .70036 L F
.4864 .69844 m .48609 .70057 L .48732 .69968 L F
.122 0 0 r
.39808 .61419 m .40008 .61365 L .40154 .61218 L F
.239 0 0 r
.40154 .61218 m .40254 .61307 L .40383 .61183 L F
.40154 .61218 m .40008 .61365 L .40254 .61307 L F
.64 .884 .985 r
.51766 .6428 m .51692 .64403 L .51901 .64401 L F
.578 .857 .996 r
.51968 .64212 m .51766 .6428 L .51901 .64401 L F
0 0 0 r
.72942 .50364 m .73092 .50319 L .73145 .50312 L F
.72942 .50364 m .72813 .50413 L .73092 .50319 L F
0 0 .214 r
.47329 .68145 m .47308 .68332 L .47252 .68354 L F
.706 .63 .067 r
.57994 .64797 m .57984 .64904 L .58007 .6466 L F
.57994 .64797 m .58007 .6466 L .58088 .64477 L F
.602 .773 .962 r
.27508 .68288 m .27644 .68434 L .27834 .68357 L F
.27834 .68357 m .27644 .68434 L .27508 .68288 L F
.743 .64 .745 r
.30195 .65175 m .30295 .65524 L .30534 .65239 L F
.413 .155 .411 r
.53454 .64845 m .53678 .64544 L .53479 .64615 L F
.067 0 0 r
.37123 .63826 m .3695 .63934 L .36729 .63984 L F
.224 0 0 r
.37346 .63785 m .3695 .63934 L .37123 .63826 L F
.778 .51 .531 r
.59591 .58509 m .59929 .58324 L .59592 .5827 L F
.59591 .58509 m .59945 .58557 L .59929 .58324 L F
0 .423 .744 r
.3598 .62448 m .35906 .62442 L .35748 .62382 L F
.3598 .62448 m .36136 .62511 L .35906 .62442 L F
.307 .106 .436 r
.48932 .62937 m .48738 .63245 L .4889 .63151 L F
.169 0 .305 r
.4889 .63151 m .48738 .63245 L .48679 .63452 L F
.631 .146 0 r
.5605 .63513 m .56006 .63485 L .55821 .63245 L F
.799 .306 0 r
.56273 .6369 m .56006 .63485 L .5605 .63513 L F
.339 .723 .984 r
.27357 .83666 m .27586 .83668 L .27409 .8357 L F
.599 .374 .547 r
.5398 .681 m .54184 .68361 L .53935 .68372 L F
.617 .479 .671 r
.54165 .6804 m .53935 .68372 L .5398 .681 L F
.566 .303 .476 r
.58633 .5826 m .58897 .58027 L .58675 .58071 L F
.454 .138 .339 r
.48045 .71849 m .48288 .71831 L .48446 .71802 L F
.619 .466 .652 r
.48615 .71791 m .48455 .71989 L .48446 .71802 L F
.525 .303 .519 r
.48446 .71802 m .48743 .71823 L .48723 .717 L F
.568 .087 .073 r
.48288 .71831 m .48743 .71823 L .48446 .71802 L F
.565 .176 .263 r
.49625 .65424 m .49474 .65291 L .49661 .65186 L F
.49625 .65424 m .49387 .65443 L .49474 .65291 L F
.556 .812 .993 r
.39985 .59389 m .40362 .59437 L .40213 .59314 L F
.529 .759 .981 r
.40362 .59437 m .40466 .59268 L .40213 .59314 L F
.40362 .59437 m .40591 .59397 L .40466 .59268 L F
.476 .656 .939 r
.79203 .49235 m .79272 .49393 L .79429 .49223 L F
.429 .581 .902 r
.79429 .49223 m .79272 .49393 L .79496 .494 L F
.468 .304 .575 r
.50409 .64807 m .50214 .64642 L .50466 .64641 L F
.50409 .64807 m .50208 .64904 L .50214 .64642 L F
.399 .792 .988 r
.38554 .5837 m .38777 .58342 L .38933 .58414 L F
.302 .767 .944 r
.38987 .58336 m .38933 .58414 L .38777 .58342 L F
.38987 .58336 m .39157 .58393 L .38933 .58414 L F
.604 .601 .821 r
.43425 .59991 m .43197 .60051 L .43059 .59725 L F
.357 .389 .758 r
.8054 .51092 m .80556 .51491 L .80724 .51182 L F
.527 .524 .795 r
.80732 .51599 m .80724 .51182 L .80556 .51491 L F
.234 0 .285 r
.58594 .64635 m .58755 .64556 L .58835 .64365 L F
.822 .949 .598 r
.58573 .64935 m .58755 .64556 L .58594 .64635 L F
.129 0 0 r
.3649 .62632 m .36745 .62654 L .36865 .6265 L F
.406 .859 .865 r
.36865 .6265 m .36954 .62577 L .37084 .62601 L F
.36865 .6265 m .36745 .62654 L .36954 .62577 L F
.961 .84 .678 r
.59612 .62863 m .59654 .63175 L .59564 .63093 L F
0 .039 .605 r
.3345 .6375 m .33593 .64124 L .33602 .63974 L F
.626 .861 .987 r
.33602 .63974 m .33593 .64124 L .33797 .64035 L F
0 0 0 r
.5365 .71204 m .53794 .71127 L .5398 .70961 L F
.478 .236 .468 r
.53985 .71085 m .54167 .71162 L .53992 .71258 L F
.5398 .70961 m .54051 .71037 L .53985 .71085 L F
.54051 .71037 m .54167 .71162 L .53985 .71085 L F
.5398 .70961 m .54205 .70943 L .54167 .71162 L F
.616 .958 .863 r
.53834 .71091 m .54205 .70943 L .5398 .70961 L F
.53794 .71127 m .53911 .71075 L .53834 .71091 L F
.53911 .71075 m .54205 .70943 L .53834 .71091 L F
.5414 .70972 m .54184 .7094 L .54205 .70943 L F
0 0 0 r
.54205 .70943 m .54383 .70892 L .54394 .70867 L F
.249 .762 .837 r
.54128 .70932 m .54383 .70892 L .54205 .70943 L F
0 0 0 r
.54144 .71026 m .54383 .70892 L .54128 .70932 L F
.54167 .71162 m .54302 .70993 L .54144 .71026 L F
.54167 .71162 m .54318 .71071 L .54394 .70867 L F
.54394 .70867 m .54318 .71071 L .54167 .71162 L F
.54394 .70867 m .54318 .71071 L .54167 .71162 L F
.54167 .71162 m .54394 .70867 L .54383 .70892 L F
.54302 .70993 m .54383 .70892 L .54144 .71026 L F
.616 .958 .863 r
.53794 .71127 m .54128 .70932 L .54184 .7094 L F
.53794 .71127 m .54184 .7094 L .5414 .70972 L F
.473 .295 .557 r
.75002 .4914 m .75272 .49066 L .75283 .48795 L F
.727 .32 .278 r
.75384 .49351 m .75253 .4939 L .75002 .4914 L F
.496 .357 .621 r
.75002 .4914 m .75253 .4939 L .75272 .49066 L F
.453 .004 .093 r
.5586 .66892 m .55708 .67091 L .55436 .67118 L F
.746 .341 .284 r
.5586 .66892 m .56027 .67106 L .55708 .67091 L F
.56027 .67106 m .56013 .67148 L .55708 .67091 L F
0 .212 .737 r
.55887 .67124 m .55962 .67437 L .56067 .67158 L F
.55708 .67091 m .55798 .67213 L .55887 .67124 L F
.55798 .67213 m .55962 .67437 L .55887 .67124 L F
.69 .432 .527 r
.55762 .67249 m .55333 .67361 L .55436 .67118 L F
0 .212 .737 r
.55708 .67091 m .55949 .67324 L .55962 .67437 L F
.69 .432 .527 r
.5587 .67293 m .55697 .67315 L .55762 .67249 L F
.55697 .67315 m .55333 .67361 L .55762 .67249 L F
.888 .797 .311 r
.55992 .67083 m .55949 .67324 L .5595 .67334 L F
.55978 .67252 m .5595 .67334 L .55962 .67437 L F
.55992 .67083 m .5595 .67334 L .55978 .67252 L F
.746 .341 .284 r
.56027 .67106 m .56067 .67158 L .56013 .67148 L F
.301 .091 .418 r
.49784 .66945 m .49568 .67258 L .49801 .67208 L F
.487 .255 .487 r
.49546 .67485 m .49801 .67208 L .49568 .67258 L F
.301 .091 .418 r
.49784 .66945 m .49568 .67258 L .49801 .67208 L F
.487 .255 .487 r
.49801 .67208 m .49546 .67485 L .49568 .67258 L F
.605 .592 .811 r
.4791 .66863 m .47716 .66948 L .4766 .66708 L F
.436 .491 .817 r
.4802 .672 m .47716 .66948 L .4791 .66863 L F
.467 .602 .903 r
.3502 .61979 m .34985 .62241 L .34819 .62014 L F
.3502 .61979 m .35179 .62223 L .34985 .62241 L F
.632 .753 .935 r
.30534 .65239 m .30195 .65175 L .30375 .6515 L F
.743 .64 .745 r
.30195 .65175 m .30534 .65239 L .30375 .6515 L F
.58 .203 .291 r
.4094 .61085 m .41179 .61093 L .40973 .60936 L F
.559 .216 .344 r
.40973 .60936 m .41179 .61093 L .4123 .60933 L F
.632 .428 .588 r
.44278 .60907 m .44272 .61161 L .44026 .61171 L F
.617 .839 .985 r
.44351 .60718 m .44278 .60907 L .44122 .60677 L F
.44351 .60718 m .44536 .60833 L .44278 .60907 L F
.613 .413 .586 r
.44546 .61115 m .44278 .60907 L .44536 .60833 L F
.44546 .61115 m .44272 .61161 L .44278 .60907 L F
.425 .273 .57 r
.21863 .57446 m .21856 .57689 L .21687 .57746 L F
.42 .259 .556 r
.21856 .57689 m .21682 .5799 L .21687 .57746 L F
.619 .695 .898 r
.79981 .48364 m .79794 .48508 L .79522 .48162 L F
.647 .709 .892 r
.41455 .58807 m .41018 .58653 L .41243 .58638 L F
.401 .728 .99 r
.41512 .58671 m .41455 .58807 L .41243 .58638 L F
.41512 .58671 m .41654 .58787 L .41455 .58807 L F
.566 .374 .581 r
.79156 .50233 m .79428 .50442 L .7941 .50194 L F
.821 .612 .62 r
.479 .66403 m .48243 .66669 L .47876 .66654 L F
.689 .447 .552 r
.48243 .66669 m .4791 .66863 L .47876 .66654 L F
.48243 .66669 m .48314 .669 L .4791 .66863 L F
.702 .802 .927 r
.75312 .52196 m .75428 .52335 L .75656 .52226 L F
.425 .556 .884 r
.80185 .48331 m .79988 .48496 L .79981 .48364 L F
.80185 .48331 m .80173 .48491 L .79988 .48496 L F
.929 .626 .158 r
.72514 .4883 m .7248 .48939 L .72436 .48706 L F
.72436 .48706 m .7248 .48939 L .72514 .4883 L F
.72514 .4883 m .7248 .48939 L .72436 .48706 L F
.018 .592 .72 r
.3627 .58309 m .36211 .58312 L .36062 .58233 L F
.3627 .58309 m .36425 .5831 L .36211 .58312 L F
.459 .261 .523 r
.48945 .65472 m .48861 .65752 L .48649 .6578 L F
.361 .329 .687 r
.48841 .65996 m .48649 .6578 L .48861 .65752 L F
.48841 .65996 m .48705 .6609 L .48649 .6578 L F
.567 .217 .336 r
.51062 .64345 m .50924 .64618 L .50685 .64587 L F
.645 .302 .377 r
.51278 .64505 m .50924 .64618 L .51062 .64345 L F
.439 .334 .639 r
.21953 .56573 m .21979 .56819 L .21795 .5688 L F
.434 .321 .625 r
.21979 .56819 m .21997 .57066 L .21795 .5688 L F
.417 .32 .637 r
.21795 .5688 m .21997 .57066 L .21827 .57122 L F
.645 .406 .542 r
.52 .66371 m .5201 .66591 L .51733 .66373 L F
.52 .66371 m .5201 .66591 L .51733 .66373 L F
.607 .418 .6 r
.5201 .66591 m .51776 .66629 L .51733 .66373 L F
0 0 0 r
.36266 .64125 m .36262 .64049 L .36499 .64005 L F
.36266 .64125 m .36103 .64218 L .36262 .64049 L F
.39 0 .099 r
.32512 .58755 m .32887 .58535 L .32674 .58601 L F
.602 .279 .395 r
.57233 .58857 m .5758 .58729 L .57575 .58611 L F
.617 .29 .394 r
.5758 .58729 m .57811 .58807 L .57575 .58611 L F
.572 .308 .478 r
.57575 .58611 m .57811 .58807 L .57826 .58584 L F
.662 .711 .884 r
.34752 .64491 m .34893 .64671 L .3514 .64628 L F
.706 .203 .04 r
.56708 .60408 m .56697 .60534 L .56649 .60404 L F
.56708 .60408 m .56809 .6049 L .56697 .60534 L F
.861 .901 .861 r
.56794 .6011 m .56708 .60408 L .56649 .60404 L F
.56794 .6011 m .57031 .60073 L .56708 .60408 L F
.39 0 0 r
.54771 .62435 m .54675 .62433 L .5442 .62322 L F
.645 .189 0 r
.56658 .64175 m .56786 .64355 L .56548 .64034 L F
.204 0 0 r
.74814 .5114 m .75093 .5111 L .75148 .51056 L F
0 0 0 r
.75148 .51056 m .75321 .50995 L .75409 .51082 L F
.75148 .51056 m .75093 .5111 L .75321 .50995 L F
.956 .785 .337 r
.6128 .63393 m .61351 .6322 L .61282 .63113 L F
.6128 .63393 m .61328 .63471 L .61351 .6322 L F
.675 .437 .552 r
.43852 .61163 m .43684 .61461 L .43446 .61433 L F
.626 .379 .523 r
.44083 .6135 m .43852 .61163 L .44026 .61171 L F
.44083 .6135 m .43684 .61461 L .43852 .61163 L F
.779 .539 .574 r
.58874 .67741 m .59229 .67779 L .59226 .67533 L F
.48 .228 .454 r
.59226 .67533 m .59255 .67527 L .59117 .67466 L F
.59226 .67533 m .59302 .67683 L .59255 .67527 L F
.313 .551 .918 r
.30822 .62423 m .31015 .62522 L .31041 .62338 L F
.308 0 0 r
.74206 .49655 m .74209 .49729 L .73857 .49679 L F
.793 .309 .067 r
.74209 .49729 m .74173 .49706 L .73857 .49679 L F
.73 .79 .9 r
.7373 .49669 m .73939 .49638 L .73857 .49679 L F
.64 .63 .824 r
.74108 .49351 m .73939 .49638 L .73848 .49371 L F
.74108 .49351 m .74206 .49655 L .73939 .49638 L F
.308 0 0 r
.74206 .49655 m .73857 .49679 L .73939 .49638 L F
.793 .309 .067 r
.74173 .49706 m .73815 .49469 L .73857 .49679 L F
.73 .79 .9 r
.73611 .49686 m .7373 .49669 L .73857 .49679 L F
.468 .509 .817 r
.40981 .59649 m .40994 .59791 L .41184 .59643 L F
0 0 .528 r
.40994 .59791 m .41128 .59887 L .41184 .59643 L F
.40994 .59791 m .41049 .60049 L .41128 .59887 L F
.259 0 .227 r
.47778 .6485 m .47531 .65176 L .47744 .65118 L F
.146 0 .073 r
.47778 .6485 m .47976 .64825 L .48016 .64658 L F
.276 0 .291 r
.47778 .6485 m .47933 .6504 L .47976 .64825 L F
.47778 .6485 m .47744 .65118 L .47933 .6504 L F
.306 .595 .946 r
.19778 .55896 m .19838 .5577 L .19614 .5575 L F
.19778 .55896 m .19988 .55934 L .19838 .5577 L F
.927 .671 .531 r
.61129 .61436 m .60859 .61132 L .60829 .61388 L F
.347 .073 .349 r
.8086 .49951 m .80868 .50156 L .80639 .50283 L F
.521 .391 .645 r
.80946 .4988 m .80868 .50156 L .8086 .49951 L F
.374 0 .147 r
.47151 .71635 m .47129 .71746 L .4731 .71529 L F
.801 .546 .552 r
.47129 .71746 m .47483 .71562 L .4731 .71529 L F
.524 .446 .709 r
.5168 .65122 m .51834 .64783 L .51757 .6494 L F
.749 .636 .735 r
.47252 .68354 m .47219 .68652 L .46853 .68681 L F
.629 .613 .815 r
.47308 .68332 m .47219 .68652 L .47252 .68354 L F
.47308 .68332 m .47436 .68609 L .47219 .68652 L F
0 0 0 r
.47436 .68609 m .4716 .68922 L .47219 .68652 L F
.776 .429 .399 r
.73875 .50883 m .73883 .51073 L .73558 .50962 L F
.501 .214 .409 r
.74076 .50887 m .73883 .51073 L .73875 .50883 L F
.627 .473 .654 r
.34348 .61143 m .34048 .60938 L .34294 .60741 L F
.34348 .61143 m .34107 .61184 L .34048 .60938 L F
.349 .111 .405 r
.49125 .62861 m .48932 .62937 L .4889 .63151 L F
.069 0 .433 r
.49194 .64612 m .49196 .64783 L .49023 .64898 L F
.594 .179 .225 r
.49023 .64898 m .49245 .65153 L .49263 .64949 L F
.49245 .65153 m .49273 .65185 L .4927 .65126 L F
.49245 .65153 m .4927 .65126 L .49263 .64949 L F
.809 .659 .109 r
.48945 .65472 m .48927 .65083 L .48709 .65173 L F
.48938 .65315 m .48921 .65397 L .48927 .65083 L F
.48945 .65472 m .48921 .65397 L .48938 .65315 L F
.757 .747 .844 r
.48709 .65173 m .48446 .65427 L .48945 .65472 L F
.27 0 0 r
.48446 .65691 m .48945 .65472 L .48446 .65427 L F
.48446 .65691 m .48677 .65662 L .48945 .65472 L F
.763 .981 .729 r
.48945 .65472 m .48677 .65662 L .48921 .65397 L F
.084 0 0 r
.48905 .65473 m .48921 .65397 L .48776 .65517 L F
.49115 .65401 m .48921 .65397 L .48905 .65473 L F
.824 .37 .148 r
.49265 .65373 m .48927 .65083 L .48921 .65397 L F
.067 0 0 r
.48921 .65397 m .49148 .65392 L .49265 .65373 L F
.824 .37 .148 r
.49265 .65373 m .49148 .65392 L .48927 .65083 L F
.985 .826 .602 r
.49222 .65178 m .49148 .65392 L .49265 .65373 L F
.148 .127 .576 r
.49132 .64826 m .49273 .65185 L .49023 .64898 L F
.49196 .64783 m .4924 .65015 L .49132 .64826 L F
.4924 .65015 m .49273 .65185 L .49132 .64826 L F
.496 .104 .227 r
.49263 .64949 m .49273 .65185 L .49485 .65056 L F
.776 .548 .589 r
.49485 .65056 m .49273 .65185 L .49196 .64783 L F
.985 .826 .602 r
.49272 .6507 m .49421 .65279 L .49485 .65056 L F
.49199 .65075 m .49359 .65222 L .49272 .6507 L F
.49359 .65222 m .49421 .65279 L .49272 .6507 L F
.49199 .65075 m .49174 .6523 L .49222 .65178 L F
.49174 .6523 m .49148 .65392 L .49222 .65178 L F
.204 .145 .565 r
.54099 .66077 m .54261 .66003 L .5426 .65728 L F
0 0 0 r
.54099 .66077 m .54076 .66195 L .54261 .66003 L F
.847 .996 .829 r
.30962 .64034 m .30922 .63937 L .31127 .63883 L F
.679 .168 .017 r
.31127 .63883 m .30922 .63937 L .31201 .63979 L F
.539 .77 .983 r
.79178 .48101 m .79017 .48269 L .78924 .48142 L F
.79178 .48101 m .7927 .48225 L .79017 .48269 L F
.905 .72 .641 r
.4749 .68403 m .47436 .68609 L .47308 .68332 L F
.643 .109 0 r
.45958 .71257 m .45773 .71262 L .45626 .71168 L F
.711 .176 0 r
.45958 .71257 m .4601 .71409 L .45773 .71262 L F
.45958 .71257 m .46174 .71478 L .4601 .71409 L F
.747 .252 .055 r
.46359 .71498 m .46174 .71478 L .45958 .71257 L F
.265 .627 .961 r
.75117 .52181 m .75215 .52084 L .75004 .52048 L F
.75117 .52181 m .75312 .52196 L .75215 .52084 L F
.613 .326 .458 r
.51567 .68315 m .51797 .68362 L .51826 .68137 L F
.687 .485 .608 r
.51797 .68362 m .52109 .68101 L .51826 .68137 L F
.577 .941 .902 r
.58835 .64365 m .58959 .64236 L .58972 .64281 L F
0 0 0 r
.58755 .64556 m .58959 .64236 L .58835 .64365 L F
.243 0 .098 r
.48016 .64658 m .48183 .64759 L .4824 .64552 L F
.48016 .64658 m .47976 .64825 L .48183 .64759 L F
0 0 .425 r
.48834 .6628 m .48705 .6609 L .48841 .65996 L F
.48834 .6628 m .48819 .66279 L .48705 .6609 L F
.563 .549 .796 r
.52536 .66274 m .52515 .65932 L .526 .66098 L F
.602 .34 .492 r
.52587 .66454 m .52583 .66467 L .52569 .66466 L F
.634 .262 .322 r
.52652 .6614 m .52681 .66164 L .52694 .66279 L F
.52681 .66164 m .52828 .66284 L .52704 .6628 L F
.52681 .66164 m .52704 .6628 L .52694 .66279 L F
.513 .309 .541 r
.52832 .66044 m .52828 .66284 L .526 .66098 L F
.602 .34 .492 r
.52828 .66284 m .52569 .66466 L .52536 .66274 L F
.54 .334 .55 r
.52724 .66376 m .52978 .66118 L .52742 .66214 L F
.602 .34 .492 r
.52828 .66284 m .52822 .6636 L .52583 .66467 L F
.52822 .6636 m .52665 .66471 L .52583 .66467 L F
.634 .262 .322 r
.52652 .6614 m .52694 .66279 L .52536 .66274 L F
.547 .39 .62 r
.52536 .66274 m .52569 .66466 L .52376 .66532 L F
.52331 .66529 m .52376 .66532 L .52311 .66555 L F
.52536 .66274 m .52376 .66532 L .52331 .66529 L F
.52536 .66274 m .52311 .66555 L .52303 .66357 L F
.192 0 .241 r
.52569 .66466 m .52277 .66779 L .52311 .66555 L F
.52492 .66549 m .5249 .66587 L .52277 .66779 L F
.476 .292 .551 r
.52296 .66525 m .5249 .66587 L .52536 .66274 L F
.5249 .66587 m .52527 .666 L .52529 .66551 L F
.5249 .66587 m .52529 .66551 L .52536 .66274 L F
.192 0 .241 r
.5249 .66587 m .52483 .66744 L .52289 .66777 L F
.5249 .66587 m .52289 .66777 L .52277 .66779 L F
.625 .153 .112 r
.5249 .66587 m .52483 .66744 L .52527 .666 L F
.373 .116 .39 r
.52528 .66569 m .52588 .66469 L .5258 .66469 L F
.192 0 .241 r
.52569 .66466 m .52557 .66506 L .52492 .66549 L F
.373 .116 .39 r
.52529 .66551 m .5258 .66469 L .52531 .66467 L F
.52528 .66569 m .5258 .66469 L .52529 .66551 L F
.192 0 .241 r
.52557 .66506 m .52483 .66744 L .52489 .66614 L F
.52557 .66506 m .52489 .66614 L .52492 .66549 L F
.625 .153 .112 r
.52303 .66527 m .52483 .66744 L .5249 .66587 L F
.72 .688 .819 r
.5201 .66591 m .52296 .66525 L .52296 .66524 L F
.66 .434 .567 r
.52303 .66357 m .52309 .66519 L .5201 .66591 L F
.52309 .66519 m .5231 .66521 L .52296 .66524 L F
.52309 .66519 m .52296 .66524 L .5201 .66591 L F
.765 .995 .861 r
.52271 .66109 m .52 .66371 L .5211 .66179 L F
.658 .619 .798 r
.52271 .66109 m .52303 .66357 L .52 .66371 L F
.66 .434 .567 r
.52303 .66357 m .5201 .66591 L .52 .66371 L F
.563 .549 .796 r
.52536 .66274 m .52303 .66357 L .52271 .66109 L F
.476 .292 .551 r
.52296 .66524 m .52536 .66274 L .5211 .66179 L F
.52296 .66525 m .52298 .66523 L .52296 .66524 L F
.52298 .66523 m .52536 .66274 L .52296 .66524 L F
.72 .688 .819 r
.5201 .66591 m .52296 .66524 L .5211 .66179 L F
.66 .434 .567 r
.5231 .66521 m .5231 .66522 L .5201 .66591 L F
.52304 .66524 m .52311 .66555 L .52171 .66571 L F
0 0 .282 r
.5201 .66591 m .52296 .66526 L .52296 .66525 L F
.625 .153 .112 r
.52296 .66525 m .52297 .66526 L .52298 .66526 L F
.66 .434 .567 r
.5231 .66522 m .52171 .66571 L .5201 .66591 L F
.505 .502 .787 r
.52277 .66779 m .52134 .66914 L .5201 .66591 L F
.52277 .66779 m .5201 .66591 L .52311 .66555 L F
0 0 .282 r
.5201 .66591 m .52109 .66722 L .52296 .66526 L F
.66 .434 .567 r
.5231 .66522 m .5231 .66523 L .52304 .66524 L F
.5231 .66523 m .52311 .66555 L .52304 .66524 L F
.625 .153 .112 r
.52298 .66526 m .52298 .66527 L .52303 .66527 L F
.52297 .66526 m .52298 .66527 L .52298 .66526 L F
.52298 .66527 m .52483 .66744 L .52303 .66527 L F
.373 .116 .39 r
.52531 .66467 m .52742 .66214 L .52536 .66274 L F
.52588 .66469 m .52742 .66214 L .52531 .66467 L F
.602 .34 .492 r
.52828 .66284 m .52583 .66467 L .52587 .66454 L F
.373 .116 .39 r
.526 .66469 m .52724 .66376 L .52698 .66292 L F
.52527 .666 m .52637 .66475 L .526 .66469 L F
0 0 .134 r
.52624 .6647 m .52586 .66467 L .52623 .66469 L F
.373 .116 .39 r
.52637 .66475 m .52724 .66376 L .526 .66469 L F
0 0 .134 r
.52586 .66467 m .52569 .66466 L .52583 .66467 L F
.52586 .66467 m .52583 .66467 L .52623 .66469 L F
.52575 .66469 m .52569 .66466 L .52624 .6647 L F
.373 .116 .39 r
.52555 .6655 m .52742 .66214 L .52528 .66569 L F
0 0 .134 r
.52679 .66508 m .52575 .66469 L .52624 .6647 L F
.373 .116 .39 r
.52545 .66579 m .52701 .66578 L .52711 .66485 L F
0 0 .134 r
.52711 .66485 m .52623 .66469 L .52756 .66492 L F
.373 .116 .39 r
.52637 .66475 m .52711 .66485 L .52724 .66376 L F
.52545 .66579 m .52711 .66485 L .52637 .66475 L F
0 0 .134 r
.52756 .66492 m .52623 .66469 L .52812 .66479 L F
.52752 .66493 m .52711 .66485 L .52756 .66492 L F
.52679 .66508 m .52623 .66469 L .52752 .66493 L F
.54 .334 .55 r
.52701 .66578 m .52748 .66499 L .52747 .66492 L F
.602 .34 .492 r
.52822 .6636 m .52812 .66479 L .52665 .66471 L F
.54 .334 .55 r
.52711 .66485 m .52747 .66492 L .52724 .66376 L F
.52701 .66578 m .52747 .66492 L .52711 .66485 L F
.472 .18 .388 r
.53112 .6605 m .53062 .66239 L .52828 .66284 L F
.586 .326 .489 r
.52828 .66284 m .53061 .66486 L .52812 .66479 L F
.53 .335 .56 r
.53062 .66239 m .53061 .66486 L .52828 .66284 L F
.54 .334 .55 r
.52748 .66499 m .52978 .66118 L .52724 .66376 L F
.373 .116 .39 r
.52527 .666 m .52555 .6655 L .52528 .66569 L F
.52527 .666 m .52539 .66598 L .52545 .66579 L F
.52539 .66598 m .52701 .66578 L .52545 .66579 L F
.52698 .66292 m .52724 .66376 L .52742 .66214 L F
.634 .262 .322 r
.526 .66098 m .52652 .6614 L .52536 .66274 L F
.334 0 .093 r
.38457 .62222 m .38762 .62059 L .38522 .62077 L F
.794 .945 .923 r
.58614 .65311 m .58628 .65176 L .58734 .65241 L F
.959 .622 .259 r
.58734 .65241 m .58628 .65176 L .58573 .64935 L F
.233 0 .138 r
.49714 .62315 m .49388 .62614 L .49616 .6256 L F
.696 .358 .4 r
.49947 .62549 m .49714 .62315 L .49616 .6256 L F
.49947 .62549 m .49957 .6237 L .49714 .62315 L F
.727 .253 .121 r
.55576 .59372 m .55806 .5959 L .55923 .59455 L F
.767 .675 .762 r
.5604 .59293 m .55806 .5959 L .55684 .59248 L F
.192 .716 .859 r
.55924 .59391 m .55967 .59391 L .5604 .59293 L F
.578 .815 .43 r
.55923 .59455 m .5604 .59293 L .56127 .5918 L F
.593 .841 .476 r
.55923 .59455 m .55806 .5959 L .5604 .59293 L F
.522 .331 .563 r
.5604 .59293 m .5604 .59539 L .55806 .5959 L F
.192 .716 .859 r
.55967 .59391 m .56334 .59391 L .5604 .59293 L F
.578 .815 .43 r
.56127 .5918 m .5604 .59293 L .56154 .59142 L F
.662 .223 .197 r
.50305 .62561 m .50542 .62748 L .50688 .62581 L F
.62 .138 .088 r
.50542 .62748 m .50934 .62764 L .50688 .62581 L F
.014 0 .291 r
.57088 .602 m .57135 .60003 L .57031 .60073 L F
.749 .233 0 r
.56926 .60056 m .57031 .60073 L .56794 .6011 L F
.56926 .60056 m .57088 .602 L .57031 .60073 L F
.846 .678 .674 r
.60209 .59954 m .60547 .59731 L .60362 .59678 L F
.60209 .59954 m .60514 .60012 L .60547 .59731 L F
0 0 0 r
.51989 .64648 m .52104 .64604 L .52224 .64584 L F
.295 .077 .403 r
.21131 .59445 m .21086 .59679 L .20925 .59735 L F
0 0 .25 r
.21086 .59679 m .20954 .59982 L .20925 .59735 L F
.705 .555 .681 r
.73828 .49115 m .73495 .49368 L .73733 .48998 L F
.73828 .49115 m .7363 .49497 L .73495 .49368 L F
.73828 .49115 m .73848 .49371 L .7363 .49497 L F
.677 .734 .893 r
.74088 .49075 m .73828 .49115 L .73733 .48998 L F
.672 .53 .683 r
.74088 .49075 m .73848 .49371 L .73828 .49115 L F
.734 .337 .297 r
.34185 .64257 m .34486 .64385 L .34153 .6432 L F
.869 .709 .68 r
.45079 .71016 m .44994 .71249 L .44852 .70959 L F
.477 .208 .426 r
.48837 .66672 m .48766 .66937 L .4855 .66968 L F
.096 0 .262 r
.48962 .66741 m .48837 .66672 L .48738 .66547 L F
.48962 .66741 m .48766 .66937 L .48837 .66672 L F
.488 .275 .516 r
.5099 .65546 m .51216 .655 L .51222 .65246 L F
.435 .233 .506 r
.51222 .65246 m .51216 .655 L .51405 .65422 L F
.704 .304 .286 r
.54452 .6375 m .54673 .63964 L .54909 .63809 L F
.948 .781 .641 r
.54909 .63809 m .54673 .63964 L .54839 .64044 L F
.713 .813 .927 r
.46153 .70018 m .46282 .7012 L .45924 .70106 L F
.482 .749 .988 r
.46153 .70018 m .46515 .70092 L .46282 .7012 L F
.077 0 .027 r
.46515 .70092 m .46207 .70394 L .46282 .7012 L F
.668 .197 0 r
.55816 .66371 m .55946 .66551 L .56047 .66658 L F
.926 .574 .137 r
.55946 .66551 m .56118 .66921 L .56047 .66658 L F
.281 0 0 r
.33111 .585 m .33337 .58478 L .33508 .58351 L F
.357 0 0 r
.33337 .58478 m .33726 .58316 L .33508 .58351 L F
.161 0 .103 r
.48316 .7225 m .48223 .72167 L .48455 .71989 L F
.48316 .7225 m .4816 .72316 L .48223 .72167 L F
.507 .308 .546 r
.51425 .65985 m .51338 .65811 L .51687 .65755 L F
.51425 .65985 m .5133 .66065 L .51338 .65811 L F
.801 .546 .552 r
.47129 .71746 m .47472 .7181 L .47483 .71562 L F
.714 .47 .555 r
.47483 .71562 m .47472 .7181 L .4794 .7174 L F
0 0 0 r
.54486 .59701 m .54659 .59668 L .54729 .59601 L F
.54486 .59701 m .54403 .59724 L .54659 .59668 L F
.791 .504 .502 r
.47046 .71853 m .46876 .72067 L .46982 .71887 L F
.47046 .71853 m .47247 .7213 L .46876 .72067 L F
.363 .725 .988 r
.40194 .58341 m .40162 .58475 L .39948 .58364 L F
.40194 .58341 m .40358 .5845 L .40162 .58475 L F
.801 .569 .586 r
.59217 .58197 m .59581 .58026 L .59214 .58008 L F
.59217 .58197 m .59592 .5827 L .59581 .58026 L F
.654 .898 .982 r
.59117 .67466 m .59255 .67527 L .59205 .67298 L F
.421 .526 .859 r
.59255 .67527 m .59495 .67093 L .59205 .67298 L F
.47 .222 .456 r
.59255 .67527 m .59302 .67683 L .59717 .67247 L F
.59255 .67527 m .59717 .67247 L .59578 .67358 L F
.421 .526 .859 r
.59255 .67527 m .59578 .67358 L .59495 .67093 L F
.331 .76 .972 r
.39709 .584 m .39511 .58426 L .39376 .5835 L F
.537 .274 .464 r
.52109 .68101 m .52351 .68064 L .52417 .67783 L F
.29 0 .015 r
.52351 .68064 m .52651 .67899 L .52417 .67783 L F
.533 .185 .323 r
.58058 .58562 m .58378 .58469 L .5841 .58325 L F
.511 .23 .424 r
.58378 .58469 m .58633 .5826 L .5841 .58325 L F
.637 .872 .986 r
.53733 .67771 m .53935 .67904 L .53927 .67667 L F
.737 .623 .732 r
.44511 .70388 m .4483 .70524 L .4475 .70096 L F
.425 .407 .736 r
.4475 .70096 m .4483 .70524 L .45029 .7034 L F
.671 .278 .292 r
.54704 .64903 m .54937 .651 L .55108 .64905 L F
.229 0 0 r
.55108 .64905 m .55218 .65014 L .55356 .65126 L F
.55108 .64905 m .54937 .651 L .55218 .65014 L F
.487 .365 .64 r
.30577 .60032 m .30775 .59983 L .30751 .59732 L F
.526 .408 .661 r
.30591 .60246 m .30775 .59983 L .30577 .60032 L F
.201 .718 .877 r
.78013 .50737 m .77815 .50754 L .77664 .50729 L F
.531 .75 .976 r
.78154 .5075 m .77815 .50754 L .78013 .50737 L F
.458 .306 .587 r
.50004 .67143 m .49784 .66945 L .50011 .66931 L F
.50004 .67143 m .49801 .67208 L .49784 .66945 L F
.50004 .67143 m .49784 .66945 L .50011 .66931 L F
.50004 .67143 m .49801 .67208 L .49784 .66945 L F
.824 .739 .77 r
.31098 .64079 m .31217 .64357 L .31263 .64012 L F
.458 .232 .482 r
.39606 .61482 m .39787 .61656 L .39808 .61419 L F
.39606 .61482 m .39571 .61712 L .39787 .61656 L F
.294 .03 .332 r
.48471 .63794 m .48253 .64049 L .48487 .64047 L F
.722 .639 .766 r
.48487 .64047 m .48692 .6369 L .48471 .63794 L F
.744 .486 .541 r
.49754 .64314 m .49411 .64079 L .49791 .64073 L F
.557 .415 .644 r
.49754 .64314 m .49966 .64007 L .49791 .64073 L F
.49754 .64314 m .49966 .64007 L .49791 .64073 L F
.346 0 .125 r
.39556 .63121 m .39931 .62863 L .3977 .63056 L F
.337 0 .018 r
.39931 .62863 m .39994 .63004 L .3977 .63056 L F
.39931 .62863 m .40121 .62828 L .39994 .63004 L F
.388 .012 .199 r
.48666 .72046 m .48316 .7225 L .48455 .71989 L F
.648 .645 .833 r
.49682 .68051 m .49402 .68203 L .49381 .67964 L F
.543 .402 .639 r
.49682 .68051 m .49402 .68203 L .49381 .67964 L F
.49682 .68051 m .49689 .68341 L .49402 .68203 L F
.527 .146 .262 r
.76102 .4899 m .76432 .48776 L .76085 .48828 L F
.76102 .4899 m .76353 .48959 L .76432 .48776 L F
.689 .415 .503 r
.76353 .48959 m .76683 .4876 L .76432 .48776 L F
.308 0 0 r
.37293 .62489 m .37521 .62488 L .37687 .62385 L F
.221 0 0 r
.37521 .62488 m .37909 .62333 L .37687 .62385 L F
.525 .011 0 r
.55184 .62602 m .55286 .62712 L .55053 .62496 L F
.55184 .62602 m .55394 .62809 L .55286 .62712 L F
.321 0 .252 r
.471 .65549 m .46818 .6579 L .4703 .65727 L F
.296 0 .262 r
.47298 .65472 m .471 .65549 L .4703 .65727 L F
.726 .856 .943 r
.74717 .50986 m .74814 .5114 L .74561 .51211 L F
.542 .533 .795 r
.74922 .50812 m .74814 .5114 L .74717 .50986 L F
.74922 .50812 m .75093 .5111 L .74814 .5114 L F
.689 .156 0 r
.46657 .7184 m .46555 .71863 L .46381 .71747 L F
.67 .347 .419 r
.46982 .71887 m .46876 .72067 L .46657 .7184 L F
.07 .252 .743 r
.46657 .7184 m .46876 .72067 L .46824 .71809 L F
.46657 .7184 m .46824 .71809 L .46555 .71863 L F
.425 .083 .28 r
.4097 .62322 m .40869 .62582 L .40643 .62625 L F
.432 .1 .3 r
.412 .62272 m .40869 .62582 L .4097 .62322 L F
.906 .692 .602 r
.59312 .60029 m .59058 .60199 L .59134 .59929 L F
.59312 .60029 m .59288 .60305 L .59058 .60199 L F
.234 0 0 r
.39028 .61949 m .39211 .61946 L .3935 .61771 L F
.394 0 .051 r
.3935 .61771 m .39211 .61946 L .39499 .61875 L F
.334 0 .184 r
.3935 .61771 m .39499 .61875 L .39571 .61712 L F
.876 .449 .179 r
.59428 .62583 m .59446 .62778 L .59326 .6253 L F
.59428 .62583 m .59612 .62863 L .59446 .62778 L F
.674 .127 0 r
.58825 .67516 m .58458 .67316 L .58784 .675 L F
.52 .243 .435 r
.48466 .64258 m .48487 .64047 L .48253 .64049 L F
.495 .428 .711 r
.41662 .60022 m .4169 .60347 L .41927 .60251 L F
.425 .31 .618 r
.4169 .60347 m .41969 .6048 L .41927 .60251 L F
.4169 .60347 m .41733 .60578 L .41969 .6048 L F
.411 .846 .943 r
.75957 .49347 m .75927 .49313 L .75648 .49385 L F
.263 .743 .932 r
.75957 .49347 m .76217 .49342 L .75927 .49313 L F
0 .134 .63 r
.77214 .52234 m .77554 .5254 L .77462 .52425 L F
.173 .445 .875 r
.77554 .5254 m .77663 .52446 L .77462 .52425 L F
.77554 .5254 m .77822 .52692 L .77663 .52446 L F
.922 .583 .378 r
.46381 .71747 m .46174 .71478 L .46359 .71498 L F
.323 0 0 r
.77193 .48682 m .77532 .48492 L .77267 .48534 L F
.056 0 0 r
.37638 .59433 m .3747 .59508 L .37253 .59539 L F
0 0 0 r
.37715 .59443 m .37638 .59433 L .3786 .59396 L F
.37715 .59443 m .3747 .59508 L .37638 .59433 L F
0 0 .252 r
.57668 .66685 m .5771 .66791 L .57666 .66557 L F
.57668 .66685 m .57742 .66928 L .5771 .66791 L F
.223 .619 .954 r
.5803 .67155 m .58074 .67061 L .57742 .66928 L F
.5803 .67155 m .58219 .67169 L .58074 .67061 L F
.735 .859 .939 r
.75656 .52226 m .75925 .5216 L .75854 .52099 L F
.494 .554 .846 r
.75925 .5216 m .76103 .52013 L .75854 .52099 L F
.75925 .5216 m .76165 .52144 L .76103 .52013 L F
.794 .945 .923 r
.58614 .65311 m .5839 .65273 L .58628 .65176 L F
.343 .029 .28 r
.5099 .65546 m .51133 .65652 L .51216 .655 L F
.5099 .65546 m .50925 .65723 L .51133 .65652 L F
.761 .463 .48 r
.54635 .67184 m .5427 .67183 L .54267 .66957 L F
.09 .591 .896 r
.47602 .66211 m .47593 .66271 L .47954 .66313 L F
.716 .352 .358 r
.47593 .66271 m .479 .66403 L .47954 .66313 L F
.775 .681 .76 r
.59693 .64694 m .59544 .6493 L .59426 .64536 L F
.701 .866 .96 r
.33072 .63735 m .3323 .63838 L .3345 .6375 L F
.26 0 0 r
.5161 .63164 m .51891 .63274 L .51951 .63297 L F
.579 .02 0 r
.51891 .63274 m .52214 .63321 L .51951 .63297 L F
.24 .722 .932 r
.36425 .5831 m .36656 .58299 L .36799 .58352 L F
.532 .88 .986 r
.36799 .58352 m .36887 .58229 L .37015 .58317 L F
.36799 .58352 m .36656 .58299 L .36887 .58229 L F
0 0 0 r
.60592 .66712 m .60719 .66577 L .60468 .66847 L F
.47625 .66514 m .47747 .66559 L .47597 .6651 L F
.976 .872 .667 r
.479 .66403 m .4788 .66609 L .47747 .66559 L F
.602 .491 .699 r
.47747 .66559 m .47954 .66313 L .479 .66403 L F
.47747 .66559 m .47982 .66534 L .47954 .66313 L F
0 0 0 r
.47898 .66552 m .47747 .66559 L .47625 .66514 L F
.976 .872 .667 r
.4788 .66609 m .47876 .66654 L .47747 .66559 L F
.29 .71 .972 r
.47747 .66559 m .47876 .66654 L .47574 .66574 L F
.777 .676 .752 r
.47574 .66574 m .47876 .66654 L .4766 .66708 L F
.29 .71 .972 r
.47747 .66559 m .47876 .66654 L .47574 .66574 L F
.605 .592 .811 r
.4791 .66863 m .4766 .66708 L .47876 .66654 L F
.159 .275 .735 r
.46309 .706 m .46414 .70939 L .46379 .70704 L F
.227 .698 .941 r
.39035 .59372 m .38673 .59304 L .38847 .59358 L F
.054 .545 .888 r
.76824 .52092 m .77214 .52234 L .77071 .5219 L F
0 .232 .734 r
.77214 .52234 m .77364 .52294 L .77071 .5219 L F
.77214 .52234 m .77462 .52425 L .77364 .52294 L F
.864 .761 .748 r
.59456 .60826 m .59463 .61184 L .5934 .61129 L F
.907 .623 .495 r
.59463 .61184 m .59312 .61366 L .5934 .61129 L F
.59463 .61184 m .59517 .61377 L .59312 .61366 L F
.096 .041 .499 r
.21404 .58762 m .21265 .58892 L .21295 .58595 L F
.508 .356 .609 r
.2152 .59093 m .21265 .58892 L .21404 .58762 L F
.2152 .59093 m .21305 .59159 L .21265 .58892 L F
.912 .598 .436 r
.60095 .59377 m .60362 .59678 L .60322 .59477 L F
0 0 0 r
.21495 .58344 m .21392 .58524 L .21295 .58595 L F
.096 .041 .499 r
.21404 .58762 m .21295 .58595 L .21392 .58524 L F
.708 .369 .4 r
.58993 .5974 m .59134 .59929 L .59088 .5997 L F
.821 .631 .646 r
.58729 .5941 m .58993 .5974 L .58655 .59691 L F
.679 .355 .419 r
.58993 .5974 m .58644 .59939 L .58655 .59691 L F
.58993 .5974 m .59088 .5997 L .58644 .59939 L F
.153 0 0 r
.46256 .6865 m .46128 .68825 L .45899 .68892 L F
.712 .277 .217 r
.46494 .68865 m .46128 .68825 L .46256 .6865 L F
.586 .341 .512 r
.46485 .68649 m .46494 .68865 L .46256 .6865 L F
.438 0 0 r
.22845 .56287 m .22685 .56262 L .22487 .5618 L F
.22487 .5618 m .22685 .56262 L .22845 .56287 L F
.912 .897 .799 r
.22845 .56287 m .22914 .55895 L .23056 .56234 L F
.22845 .56287 m .22685 .56262 L .22914 .55895 L F
.447 .86 .958 r
.22909 .56201 m .22845 .56287 L .23056 .56234 L F
.22909 .56201 m .22685 .56262 L .22845 .56287 L F
.514 .573 .852 r
.44036 .60456 m .43911 .60694 L .43835 .60425 L F
.44036 .60456 m .44122 .60677 L .43911 .60694 L F
.33 .571 .927 r
.40535 .58466 m .40456 .58609 L .40358 .5845 L F
.503 .784 .996 r
.40535 .58466 m .40679 .58573 L .40456 .58609 L F
.646 .38 .503 r
.75506 .4881 m .75749 .48975 L .75863 .4878 L F
.655 .359 .458 r
.75749 .48975 m .76102 .4899 L .75863 .4878 L F
.694 .338 .368 r
.75863 .4878 m .76102 .4899 L .76085 .48828 L F
.796 .951 .92 r
.55717 .5973 m .55582 .59677 L .55271 .59881 L F
.179 .387 .83 r
.55717 .5973 m .55806 .5959 L .55582 .59677 L F
.55717 .5973 m .55971 .59863 L .55806 .5959 L F
.251 0 0 r
.77294 .49183 m .77381 .49101 L .77671 .49127 L F
.726 .197 0 r
.28609 .8243 m .28513 .82208 L .28507 .82527 L F
.28609 .8243 m .2875 .8246 L .28513 .82208 L F
.937 .959 .754 r
.53428 .67244 m .53592 .66795 L .53677 .67002 L F
.714 .365 .385 r
.5367 .67454 m .53514 .67451 L .53428 .67244 L F
.817 .398 0 r
.53428 .67244 m .53514 .67451 L .5335 .67177 L F
.879 .627 .554 r
.59945 .58557 m .59949 .58807 L .60197 .58862 L F
.868 .677 .643 r
.59907 .59068 m .60197 .58862 L .59949 .58807 L F
.59907 .59068 m .60109 .59131 L .60197 .58862 L F
0 .142 .672 r
.55495 .62942 m .55633 .63011 L .55394 .62809 L F
.55495 .62942 m .55712 .6314 L .55633 .63011 L F
.694 .189 0 r
.55821 .63245 m .55851 .63339 L .55712 .6314 L F
.55821 .63245 m .56006 .63485 L .55851 .63339 L F
.562 .234 .371 r
.42353 .61723 m .42251 .61963 L .42032 .61941 L F
.608 .319 .452 r
.426 .61694 m .42251 .61963 L .42353 .61723 L F
.441 .203 .456 r
.21288 .59623 m .21131 .59445 L .21351 .59386 L F
.21288 .59623 m .21086 .59679 L .21131 .59445 L F
0 0 .222 r
.80946 .4988 m .80876 .49657 L .80835 .49507 L F
.65 .675 .861 r
.31065 .62535 m .31437 .62629 L .31354 .62448 L F
.268 0 0 r
.31272 .62532 m .31472 .62508 L .3162 .62369 L F
.31542 .62392 m .3162 .62369 L .3166 .62331 L F
.31272 .62532 m .3162 .62369 L .31542 .62392 L F
.65 .675 .861 r
.31015 .62522 m .31065 .62535 L .31284 .62298 L F
.31065 .62535 m .31354 .62448 L .31284 .62298 L F
.69 .248 .197 r
.31015 .62522 m .31251 .62716 L .31437 .62629 L F
.794 .345 0 r
.56548 .64034 m .56786 .64355 L .56663 .64243 L F
.812 .459 0 r
.56818 .64597 m .56663 .64243 L .56786 .64355 L F
0 0 .426 r
.80739 .49132 m .80671 .49089 L .80626 .48959 L F
.80739 .49132 m .80756 .49292 L .80671 .49089 L F
.262 .744 .928 r
.20733 .5466 m .20729 .54723 L .20496 .54552 L F
.20733 .5466 m .20932 .54707 L .20729 .54723 L F
.041 0 .368 r
.22114 .55958 m .22091 .56201 L .21993 .56241 L F
.32 .191 .544 r
.22126 .56424 m .21993 .56241 L .22091 .56201 L F
.22126 .56424 m .21953 .56573 L .21993 .56241 L F
.532 .338 .564 r
.74088 .49075 m .74108 .49351 L .73848 .49371 L F
.86 .853 .834 r
.74328 .49255 m .74466 .49371 L .74206 .49655 L F
.613 .261 .35 r
.74466 .49371 m .74209 .49729 L .74206 .49655 L F
.74466 .49371 m .7434 .49729 L .74209 .49729 L F
0 .343 .781 r
.74788 .49533 m .74466 .49371 L .74328 .49255 L F
.737 .539 .625 r
.74788 .49533 m .7434 .49729 L .74466 .49371 L F
.408 .78 .993 r
.76824 .52092 m .76837 .5198 L .76495 .52039 L F
.171 .491 .903 r
.76824 .52092 m .77 .52045 L .76837 .5198 L F
.76824 .52092 m .77071 .5219 L .77 .52045 L F
.714 .436 .503 r
.75283 .48795 m .75507 .49008 L .75506 .4881 L F
.646 .38 .503 r
.75506 .4881 m .75507 .49008 L .75749 .48975 L F
.653 .359 .461 r
.43188 .61454 m .43084 .61713 L .42844 .61682 L F
.625 .33 .449 r
.43416 .6166 m .43188 .61454 L .43446 .61433 L F
.43416 .6166 m .43084 .61713 L .43188 .61454 L F
.716 .19 0 r
.57064 .63169 m .57359 .63469 L .57405 .6346 L F
.913 .906 .503 r
.57405 .6346 m .57359 .63469 L .5728 .63623 L F
.726 .856 .943 r
.74717 .50986 m .74561 .51211 L .74476 .51074 L F
.077 0 .434 r
.19965 .5686 m .20096 .56528 L .1989 .56626 L F
.19965 .5686 m .20188 .56845 L .20096 .56528 L F
.633 .922 .649 r
.19963 .57111 m .20188 .56845 L .19965 .5686 L F
.497 .15 .307 r
.41551 .6205 m .41432 .62253 L .412 .62272 L F
.564 .256 .404 r
.41787 .61997 m .41432 .62253 L .41551 .6205 L F
.631 .288 .372 r
.4999 .69445 m .49632 .69669 L .49724 .69542 L F
.4999 .69445 m .49928 .6973 L .49632 .69669 L F
.358 0 .05 r
.50276 .69389 m .5021 .6949 L .4999 .69445 L F
.21 0 .242 r
.50128 .69609 m .4999 .69445 L .5021 .6949 L F
.50128 .69609 m .49928 .6973 L .4999 .69445 L F
.583 .713 .932 r
.78847 .52224 m .78733 .52462 L .78637 .52257 L F
.779 .876 .918 r
.46136 .68359 m .45755 .68645 L .45572 .68609 L F
.539 .923 .914 r
.60468 .66847 m .60412 .66819 L .60278 .66939 L F
.913 .973 .789 r
.60136 .67071 m .60301 .66749 L .60075 .66851 L F
.889 .938 .841 r
.60412 .66819 m .60153 .67133 L .60132 .67074 L F
.913 .973 .789 r
.60153 .67133 m .60199 .67013 L .60136 .67071 L F
.60199 .67013 m .60301 .66749 L .60136 .67071 L F
0 0 0 r
.60278 .66939 m .60383 .66845 L .60132 .67074 L F
.60383 .66845 m .60412 .66819 L .60301 .6692 L F
.60383 .66845 m .60301 .6692 L .60132 .67074 L F
.899 .539 .351 r
.53943 .66634 m .53719 .6658 L .53704 .66354 L F
.926 .643 .487 r
.53943 .66634 m .53746 .66787 L .53719 .6658 L F
0 .087 .645 r
.53943 .66634 m .53981 .66557 L .53746 .66787 L F
.53943 .66634 m .54134 .66846 L .53981 .66557 L F
.553 .515 .767 r
.55293 .67685 m .55024 .67838 L .54971 .67506 L F
.492 .409 .69 r
.55313 .67997 m .55024 .67838 L .55293 .67685 L F
.55313 .67997 m .55102 .68076 L .55024 .67838 L F
.617 .479 .671 r
.54165 .6804 m .54184 .68361 L .53935 .68372 L F
.188 .231 .676 r
.5379 .6795 m .54083 .68227 L .54165 .6804 L F
.5379 .6795 m .53935 .68372 L .54083 .68227 L F
.651 .414 .547 r
.44272 .61161 m .44083 .6135 L .44026 .61171 L F
.589 .677 .901 r
.34819 .62014 m .34599 .62079 L .34502 .61892 L F
.754 .655 .752 r
.34153 .6432 m .34486 .64385 L .34384 .64028 L F
.693 .408 0 r
.34384 .64028 m .34486 .64385 L .34447 .64254 L F
.325 .575 .931 r
.34486 .64385 m .34604 .64242 L .34447 .64254 L F
.34486 .64385 m .34752 .64491 L .34604 .64242 L F
.181 .371 .816 r
.41049 .60049 m .41223 .60125 L .41128 .59887 L F
.881 .702 .656 r
.54532 .67823 m .5451 .68067 L .54376 .67736 L F
.18 0 0 r
.55407 .59503 m .55337 .59425 L .55212 .59592 L F
.55407 .59503 m .55576 .59372 L .55337 .59425 L F
.775 .681 .76 r
.59693 .64694 m .59426 .64536 L .59658 .64551 L F
.72 .688 .819 r
.5201 .66591 m .5211 .66179 L .52 .66371 L F
.453 .566 .879 r
.42845 .59198 m .42737 .5941 L .42554 .59165 L F
.42845 .59198 m .42927 .59384 L .42737 .5941 L F
.488 .693 .959 r
.80853 .5124 m .81146 .51234 L .81145 .51348 L F
.004 0 0 r
.80892 .51593 m .81145 .51348 L .81146 .51234 L F
.69 .859 .963 r
.81234 .51119 m .81146 .51234 L .81145 .51348 L F
.81145 .51348 m .81146 .51234 L .81234 .51119 L F
.594 .47 .681 r
.52124 .68614 m .51924 .68914 L .51948 .6868 L F
.677 .734 .893 r
.74088 .49075 m .73733 .48998 L .74041 .48901 L F
.231 .448 .864 r
.74041 .48901 m .74222 .48953 L .74088 .49075 L F
.558 .358 .566 r
.74328 .49255 m .74108 .49351 L .74088 .49075 L F
.178 .356 .804 r
.74222 .48953 m .74328 .49255 L .74088 .49075 L F
.767 .918 .939 r
.41223 .60125 m .41394 .6013 L .41662 .60022 L F
.683 .978 .887 r
.41739 .59881 m .41662 .60022 L .41827 .59982 L F
.41739 .59881 m .41564 .60015 L .41662 .60022 L F
.495 .428 .711 r
.41662 .60022 m .41927 .60251 L .41827 .59982 L F
.846 .744 .751 r
.53696 .60531 m .53819 .6087 L .5379 .60639 L F
.53696 .60531 m .53508 .60823 L .53819 .6087 L F
.903 .89 .809 r
.53464 .61069 m .53819 .6087 L .53508 .60823 L F
.53464 .61069 m .53598 .61201 L .53819 .6087 L F
.591 .425 .626 r
.53598 .61201 m .53896 .61196 L .53819 .6087 L F
.566 .449 .679 r
.53819 .6087 m .54034 .60578 L .5379 .60639 L F
.53819 .6087 m .54123 .60808 L .54034 .60578 L F
.544 .391 .623 r
.53896 .61196 m .54123 .60808 L .53819 .6087 L F
.58 .765 .966 r
.53258 .61093 m .53598 .61201 L .53464 .61069 L F
.563 .142 .201 r
.53543 .61276 m .53896 .61196 L .53598 .61201 L F
.297 .568 .932 r
.55759 .61037 m .55826 .61037 L .5578 .61184 L F
0 0 .23 r
.55826 .61037 m .55761 .61439 L .5578 .61184 L F
.521 .392 .645 r
.57536 .59767 m .57745 .59933 L .57498 .60009 L F
.57536 .59767 m .57733 .59701 L .57745 .59933 L F
.745 .643 .748 r
.46944 .70654 m .47247 .70415 L .46886 .70367 L F
.398 .463 .811 r
.3076 .62012 m .30981 .62227 L .30894 .61904 L F
.397 .561 .899 r
.53592 .66795 m .53677 .67002 L .53746 .66787 L F
.977 .677 .354 r
.53746 .66787 m .53897 .67018 L .53677 .67002 L F
.841 .704 .711 r
.7363 .49497 m .73611 .49686 L .73495 .49368 L F
.474 .504 .808 r
.73495 .49368 m .73611 .49686 L .73815 .49469 L F
.567 .653 .893 r
.73611 .49686 m .73857 .49679 L .73815 .49469 L F
.084 0 0 r
.38304 .59319 m .38007 .59416 L .38089 .59406 L F
.127 0 0 r
.38089 .59406 m .37922 .59443 L .37715 .59443 L F
.084 0 0 r
.38007 .59416 m .37922 .59443 L .38089 .59406 L F
.091 0 0 r
.38161 .59398 m .38089 .59406 L .3786 .59396 L F
.38209 .59398 m .38089 .59406 L .38161 .59398 L F
.439 .877 .859 r
.38304 .59319 m .38209 .59398 L .38454 .59318 L F
.38304 .59319 m .38089 .59406 L .38209 .59398 L F
.357 0 0 r
.33726 .58316 m .33905 .58374 L .34081 .5829 L F
.476 0 0 r
.33905 .58374 m .34302 .58277 L .34081 .5829 L F
.464 .879 .937 r
.73721 .5027 m .73968 .50137 L .74045 .50098 L F
.73721 .5027 m .73632 .50247 L .73968 .50137 L F
.703 .652 .796 r
.74085 .4829 m .7376 .48559 L .73764 .48315 L F
.948 .715 .552 r
.73909 .48356 m .74086 .485 L .74098 .4829 L F
.485 .328 .591 r
.7395 .48046 m .74085 .4829 L .73764 .48315 L F
.73985 .47994 m .74035 .48141 L .7395 .48046 L F
.74035 .48141 m .74085 .4829 L .7395 .48046 L F
.891 .93 .838 r
.73985 .47994 m .73764 .48315 L .73709 .48131 L F
.329 0 0 r
.74199 .48191 m .74085 .4829 L .74099 .4829 L F
.74302 .48252 m .74099 .4829 L .74345 .48278 L F
.74199 .48191 m .74099 .4829 L .74302 .48252 L F
.811 .503 .469 r
.74345 .48278 m .74085 .4829 L .74035 .48141 L F
.74143 .48119 m .74035 .48141 L .73985 .47994 L F
.74345 .48278 m .74035 .48141 L .74143 .48119 L F
.725 .324 .291 r
.73904 .48169 m .73909 .48356 L .74091 .48204 L F
.73709 .48131 m .73767 .48197 L .73904 .48169 L F
.73767 .48197 m .73909 .48356 L .73904 .48169 L F
.74078 .4819 m .74091 .48204 L .74104 .48194 L F
.73709 .48131 m .74091 .48204 L .74078 .4819 L F
.948 .715 .552 r
.73957 .48316 m .74098 .4829 L .74104 .48194 L F
.73909 .48356 m .74098 .4829 L .73957 .48316 L F
.756 .669 .766 r
.31521 .61993 m .31284 .62298 L .3166 .62331 L F
.268 0 0 r
.31272 .62532 m .3166 .62331 L .31284 .62298 L F
.024 .221 .727 r
.31521 .61993 m .3166 .62331 L .3172 .6219 L F
.737 .942 .619 r
.3166 .62331 m .31472 .62508 L .3172 .6219 L F
.207 0 .158 r
.21681 .58262 m .21392 .58524 L .21495 .58344 L F
.662 .711 .884 r
.34752 .64491 m .3514 .64628 L .34971 .64314 L F
.484 .572 .869 r
.3514 .64628 m .35132 .64233 L .34971 .64314 L F
.3514 .64628 m .35369 .64584 L .35132 .64233 L F
.345 0 0 r
.54729 .59601 m .54659 .59668 L .54981 .59636 L F
.86 .853 .834 r
.74328 .49255 m .74206 .49655 L .74108 .49351 L F
.633 .471 .645 r
.50502 .6751 m .50531 .67787 L .5026 .67803 L F
0 0 0 r
.5026 .67803 m .50318 .67739 L .50502 .6751 L F
.554 .318 .512 r
.50531 .67787 m .50258 .68056 L .5026 .67803 L F
.57 .623 .866 r
.50258 .68056 m .50318 .67739 L .5026 .67803 L F
0 0 0 r
.50502 .6751 m .50594 .67403 L .50751 .67723 L F
.50502 .6751 m .50318 .67739 L .50594 .67403 L F
.478 .358 .637 r
.50751 .67723 m .50531 .67787 L .50502 .6751 L F
.641 .425 .573 r
.56325 .59734 m .5631 .60012 L .56076 .59949 L F
.672 .952 .953 r
.56502 .59612 m .56464 .59557 L .56325 .59734 L F
.206 .267 .706 r
.56464 .59557 m .56527 .59928 L .56325 .59734 L F
.49 .298 .547 r
.56325 .59734 m .56527 .59928 L .5631 .60012 L F
.592 .592 .822 r
.74076 .50887 m .74476 .51074 L .74237 .51159 L F
.472 .406 .702 r
.2204 .57355 m .21863 .57446 L .21827 .57122 L F
.303 .175 .535 r
.22055 .57532 m .21863 .57446 L .2204 .57355 L F
.22055 .57532 m .21856 .57689 L .21863 .57446 L F
.918 .713 .61 r
.60209 .59954 m .6035 .60268 L .60514 .60012 L F
.776 .599 .659 r
.6035 .60268 m .60677 .60312 L .60514 .60012 L F
.944 .747 .606 r
.5172 .72301 m .51881 .72445 L .5175 .72083 L F
.577 .755 .962 r
.5172 .72301 m .51881 .72445 L .52094 .7238 L F
.5172 .72301 m .51881 .72445 L .52094 .7238 L F
.557 .437 .672 r
.44063 .68414 m .44335 .68621 L .44298 .68277 L F
.44063 .68414 m .4412 .68671 L .44335 .68621 L F
0 0 0 r
.78227 .48973 m .77918 .49046 L .77972 .49014 L F
.939 .919 .766 r
.59274 .62189 m .59538 .6203 L .59304 .62324 L F
.966 .77 .332 r
.59326 .6253 m .59274 .62189 L .59304 .62324 L F
.566 .297 .468 r
.49151 .65475 m .48861 .65752 L .48945 .65472 L F
.49151 .65475 m .49231 .65729 L .48861 .65752 L F
.673 .357 .431 r
.49394 .65705 m .49151 .65475 L .49387 .65443 L F
.49394 .65705 m .49231 .65729 L .49151 .65475 L F
0 .356 .775 r
.5642 .62505 m .5638 .62523 L .56231 .62266 L F
.5642 .62505 m .56549 .62605 L .5638 .62523 L F
.985 .705 .387 r
.59538 .6203 m .59424 .61966 L .5941 .61718 L F
.939 .919 .766 r
.59274 .62189 m .59424 .61966 L .59538 .6203 L F
.492 .25 .476 r
.78247 .5167 m .78007 .51994 L .77903 .51622 L F
.78247 .5167 m .78247 .51926 L .78007 .51994 L F
.561 .372 .582 r
.78463 .51589 m .78247 .51926 L .78247 .5167 L F
.404 .771 .994 r
.37015 .58317 m .37221 .58288 L .37378 .58383 L F
.259 .737 .935 r
.37221 .58288 m .37595 .58328 L .37378 .58383 L F
.064 .49 .892 r
.30962 .64034 m .31098 .64079 L .30922 .63937 L F
.817 .555 .542 r
.60387 .60485 m .60677 .60312 L .6035 .60268 L F
.60387 .60485 m .60696 .60543 L .60677 .60312 L F
.781 .527 .552 r
.60696 .60543 m .60829 .60611 L .60677 .60312 L F
.314 0 .247 r
.46545 .66026 m .4673 .65982 L .46818 .6579 L F
.355 .032 .272 r
.4673 .65982 m .4703 .65727 L .46818 .6579 L F
.913 .852 .769 r
.59183 .6372 m .59323 .63826 L .59223 .64019 L F
.63 .62 .822 r
.59327 .6346 m .59528 .6373 L .59323 .63826 L F
.472 .406 .702 r
.2204 .57355 m .21827 .57122 L .21997 .57066 L F
0 0 .503 r
.57711 .63733 m .5778 .63961 L .57687 .63788 L F
0 0 .245 r
.57714 .6335 m .57687 .63788 L .57686 .6343 L F
.57714 .6335 m .57734 .63566 L .57687 .63788 L F
0 0 .087 r
.57734 .63566 m .57711 .63733 L .57687 .63788 L F
0 0 .503 r
.57711 .63733 m .5778 .63961 L .57687 .63788 L F
.587 .733 .945 r
.77905 .52895 m .78058 .52673 L .77822 .52692 L F
.77905 .52895 m .78158 .52843 L .78058 .52673 L F
.694 .632 .783 r
.31041 .62338 m .31015 .62522 L .31284 .62298 L F
.469 .261 .515 r
.31015 .62522 m .31272 .62532 L .31284 .62298 L F
.577 .328 .503 r
.31015 .62522 m .30989 .62864 L .31251 .62716 L F
.473 .345 .625 r
.31015 .62522 m .31251 .62716 L .31272 .62532 L F
.276 .333 .741 r
.54115 .654 m .54194 .65672 L .53895 .65274 L F
.423 0 0 r
.54256 .65458 m .54115 .654 L .53895 .65274 L F
.608 .348 .497 r
.51874 .65756 m .51425 .65985 L .51687 .65755 L F
.659 .448 .587 r
.75283 .48795 m .75272 .49066 L .75507 .49008 L F
.256 0 0 r
.38501 .63435 m .38352 .63576 L .38128 .63607 L F
.24 0 0 r
.38738 .63386 m .38352 .63576 L .38501 .63435 L F
.337 .314 .685 r
.34386 .61644 m .34208 .61761 L .34161 .61438 L F
.443 .527 .848 r
.34386 .61644 m .34502 .61892 L .34208 .61761 L F
.181 .584 .94 r
.74701 .51978 m .74878 .51936 L .7461 .51856 L F
.74701 .51978 m .75004 .52048 L .74878 .51936 L F
.649 .374 .489 r
.58897 .58027 m .59217 .58197 L .59214 .58008 L F
.192 0 .072 r
.80382 .50436 m .80639 .50283 L .80281 .50117 L F
.80382 .50436 m .80561 .50342 L .80639 .50283 L F
.80639 .50283 m .80561 .50342 L .80382 .50436 L F
.496 .217 .421 r
.50476 .66026 m .5069 .66001 L .50733 .65808 L F
.507 .295 .526 r
.5069 .66001 m .50925 .65723 L .50733 .65808 L F
.682 .345 .398 r
.4761 .7211 m .47543 .72369 L .47247 .7213 L F
.553 .836 .497 r
.4761 .7211 m .4794 .7174 L .47472 .7181 L F
.075 .268 .756 r
.47472 .7181 m .4769 .72014 L .4761 .7211 L F
.873 .718 .686 r
.47565 .71927 m .47628 .7208 L .4769 .72014 L F
.755 .42 .417 r
.4781 .72356 m .47543 .72369 L .4761 .7211 L F
.873 .718 .686 r
.47628 .7208 m .47698 .72249 L .4769 .72014 L F
.553 .836 .497 r
.4779 .71908 m .4769 .72014 L .4794 .7174 L F
.4761 .7211 m .4769 .72014 L .4779 .71908 L F
.6 .819 .984 r
.77318 .50704 m .77177 .50888 L .77068 .50737 L F
.77318 .50704 m .77428 .50822 L .77177 .50888 L F
0 .239 .63 r
.53574 .63407 m .53554 .63398 L .53395 .63175 L F
.53574 .63407 m .53716 .63485 L .53554 .63398 L F
.49 .49 .785 r
.30729 .6121 m .30834 .6149 L .31034 .6138 L F
.634 .705 .898 r
.80018 .50195 m .80114 .49823 L .79951 .50007 L F
.80018 .50195 m .80281 .50117 L .80114 .49823 L F
.54 .489 .748 r
.7295 .49563 m .72736 .49697 L .72683 .49438 L F
.754 .634 .727 r
.7295 .49563 m .72704 .4985 L .72736 .49697 L F
.22 .33 .765 r
.57452 .66352 m .57587 .6623 L .57346 .66016 L F
.19 .28 .726 r
.57452 .66352 m .57666 .66557 L .57587 .6623 L F
.641 .539 .724 r
.34348 .61143 m .34161 .61438 L .34107 .61184 L F
.451 .303 .587 r
.34348 .61143 m .34358 .61393 L .34161 .61438 L F
.337 .314 .685 r
.34386 .61644 m .34161 .61438 L .34358 .61393 L F
.448 .672 .959 r
.73315 .50985 m .73475 .50825 L .73162 .50751 L F
.73315 .50985 m .73558 .50962 L .73475 .50825 L F
.45 0 0 r
.73092 .50319 m .73406 .50428 L .73145 .50312 L F
0 0 .352 r
.5442 .61107 m .54421 .61374 L .54348 .61387 L F
.148 .262 .726 r
.54571 .6147 m .54348 .61387 L .54421 .61374 L F
.54571 .6147 m .5456 .61699 L .54348 .61387 L F
.408 .832 .963 r
.39635 .5931 m .39256 .59314 L .39415 .59358 L F
.505 .306 .543 r
.5427 .67183 m .54083 .67442 L .54028 .67222 L F
.393 .553 .894 r
.48217 .70155 m .48349 .70211 L .4826 .70068 L F
.858 .756 .749 r
.46853 .68681 m .46494 .68865 L .46485 .68649 L F
.46853 .68681 m .46712 .6896 L .46494 .68865 L F
.26 0 .259 r
.50581 .66366 m .50299 .66658 L .50513 .66614 L F
.576 .524 .76 r
.50476 .66026 m .50581 .66366 L .50713 .66257 L F
.267 .043 .376 r
.50713 .66257 m .50581 .66366 L .50513 .66614 L F
.416 .118 .349 r
.50685 .64587 m .50409 .64807 L .50466 .64641 L F
.765 .836 .377 r
.61066 .65926 m .61032 .6607 L .6116 .6575 L F
.76 .661 .107 r
.61011 .66154 m .61032 .6607 L .61066 .65926 L F
.61011 .66154 m .6101 .66335 L .61032 .6607 L F
.744 .486 .541 r
.49754 .64314 m .49384 .64328 L .49411 .64079 L F
.913 .852 .769 r
.59183 .6372 m .59223 .64019 L .59046 .64007 L F
.842 .87 .426 r
.58972 .64281 m .59046 .64007 L .59223 .64019 L F
.865 .906 .859 r
.47942 .70967 m .47984 .70657 L .48095 .70912 L F
.47942 .70967 m .47788 .70936 L .47984 .70657 L F
.654 .208 .178 r
.48109 .70991 m .47942 .70967 L .48095 .70912 L F
.48109 .70991 m .47788 .70936 L .47942 .70967 L F
.768 .663 .747 r
.46813 .67193 m .47187 .67509 L .47064 .67148 L F
.46813 .67193 m .46827 .67476 L .47187 .67509 L F
.594 .083 .007 r
.46827 .67476 m .47038 .67627 L .47187 .67509 L F
.056 0 .355 r
.47187 .67509 m .47366 .67167 L .47064 .67148 L F
.47187 .67509 m .47333 .67427 L .47366 .67167 L F
.672 .418 .528 r
.47038 .67627 m .47333 .67427 L .47187 .67509 L F
.645 .607 .796 r
.54476 .65193 m .54779 .65397 L .54722 .65146 L F
.44 .143 .363 r
.54496 .65753 m .54775 .65702 L .54779 .65397 L F
0 0 0 r
.54779 .65397 m .54937 .651 L .54722 .65146 L F
0 0 .379 r
.54843 .65365 m .5493 .65587 L .5486 .65374 L F
0 0 0 r
.54806 .65346 m .54843 .65365 L .54937 .651 L F
.792 .569 .599 r
.54937 .651 m .54843 .65365 L .54587 .65329 L F
0 0 .379 r
.54843 .65365 m .5486 .65374 L .5482 .65252 L F
0 0 0 r
.54779 .65397 m .54843 .65365 L .54806 .65346 L F
.162 0 .313 r
.54779 .65397 m .5493 .65587 L .54843 .65365 L F
.54779 .65397 m .54775 .65702 L .5493 .65587 L F
.546 .781 .986 r
.78403 .52791 m .78508 .52928 L .78803 .5286 L F
.831 .627 .627 r
.60677 .61075 m .60975 .60836 L .60811 .60757 L F
.60677 .61075 m .60859 .61132 L .60975 .60836 L F
.628 .353 .483 r
.5829 .59425 m .57931 .59716 L .58055 .59414 L F
.765 .836 .377 r
.61066 .65926 m .6116 .6575 L .61134 .65699 L F
.875 .964 .634 r
.61309 .65387 m .61134 .65699 L .6116 .6575 L F
.196 .716 .872 r
.34302 .58277 m .34522 .58262 L .34668 .58286 L F
.096 .651 .789 r
.34522 .58262 m .34888 .58263 L .34668 .58286 L F
.308 .769 .948 r
.78227 .48973 m .78581 .48999 L .78485 .49006 L F
.155 0 0 r
.78581 .48999 m .78813 .49021 L .78485 .49006 L F
.595 .83 .988 r
.56906 .59645 m .56824 .59535 L .56502 .59612 L F
0 .481 .787 r
.56906 .59645 m .56954 .59635 L .56824 .59535 L F
.56906 .59645 m .57088 .59688 L .56954 .59635 L F
.408 0 .135 r
.52339 .65631 m .52087 .65682 L .52153 .6555 L F
.905 .857 .784 r
.75507 .49008 m .75384 .49351 L .75648 .49385 L F
.46 .188 .413 r
.30948 .59668 m .3122 .59376 L .31011 .59426 L F
.54 .479 .736 r
.48247 .67478 m .48082 .67515 L .4802 .672 L F
.532 .41 .659 r
.48334 .67722 m .48082 .67515 L .48247 .67478 L F
.48334 .67722 m .48115 .67772 L .48082 .67515 L F
.702 .802 .927 r
.75312 .52196 m .75656 .52226 L .75555 .52112 L F
.725 .865 .948 r
.75555 .52112 m .75656 .52226 L .75854 .52099 L F
.498 .86 .988 r
.44426 .70098 m .4475 .70096 L .44719 .69994 L F
.342 .641 .964 r
.44719 .69994 m .4475 .70096 L .4483 .69972 L F
.143 .371 .826 r
.4483 .69972 m .4475 .70096 L .44866 .70083 L F
.425 .407 .736 r
.4475 .70096 m .45029 .7034 L .44866 .70083 L F
.617 .762 .948 r
.76232 .5074 m .75817 .50686 L .76108 .50607 L F
.614 .712 .915 r
.7638 .50449 m .76232 .5074 L .76108 .50607 L F
.7638 .50449 m .76485 .50666 L .76232 .5074 L F
.311 0 .028 r
.77766 .48404 m .78025 .48352 L .78084 .48203 L F
0 0 0 r
.78025 .48352 m .78082 .48362 L .78221 .48237 L F
.486 .823 .532 r
.78221 .48237 m .78082 .48362 L .78181 .48272 L F
.78221 .48237 m .78181 .48272 L .78384 .48086 L F
.014 0 0 r
.78266 .48199 m .78221 .48237 L .78339 .48197 L F
.78084 .48203 m .78221 .48237 L .78266 .48199 L F
.78084 .48203 m .78025 .48352 L .78221 .48237 L F
.439 .03 .165 r
.31695 .59128 m .31917 .5912 L .32093 .5888 L F
.384 0 .171 r
.31917 .5912 m .32307 .58822 L .32093 .5888 L F
.111 .664 .752 r
.36456 .5964 m .36311 .59646 L .36084 .59668 L F
.311 0 0 r
.36687 .59592 m .36311 .59646 L .36456 .5964 L F
.483 .697 .963 r
.81042 .51074 m .80853 .5124 L .80724 .51182 L F
.81042 .51074 m .81146 .51234 L .80853 .5124 L F
.858 .608 .071 r
.53704 .66354 m .53719 .6658 L .5365 .6623 L F
.577 .862 .996 r
.54076 .66195 m .53704 .66354 L .5365 .6623 L F
.099 0 0 r
.40361 .6274 m .40432 .62684 L .40643 .62625 L F
.526 .408 .661 r
.30591 .60246 m .30804 .602 L .30775 .59983 L F
.549 .436 .678 r
.30591 .60246 m .3084 .60562 L .30804 .602 L F
.30591 .60246 m .30631 .60619 L .3084 .60562 L F
.701 .866 .96 r
.33072 .63735 m .3345 .6375 L .33313 .63614 L F
.396 0 0 r
.33683 .63739 m .33313 .63614 L .3345 .6375 L F
0 .039 .605 r
.3345 .6375 m .33602 .63974 L .33683 .63739 L F
.234 .698 .946 r
.35702 .58162 m .36062 .58233 L .35867 .58234 L F
.581 .918 .701 r
.54971 .66923 m .54725 .67075 L .54635 .67184 L F
.778 .689 .765 r
.55093 .66639 m .54971 .66923 L .54925 .6683 L F
.789 .5 .498 r
.5504 .67064 m .54896 .67202 L .54971 .66923 L F
0 0 0 r
.54971 .66923 m .54896 .67202 L .54958 .67039 L F
.54971 .66923 m .54958 .67039 L .54725 .67075 L F
.778 .689 .765 r
.55093 .66639 m .54971 .66923 L .54925 .6683 L F
.624 .28 .367 r
.4123 .60933 m .41464 .61077 L .41509 .60848 L F
.4123 .60933 m .41179 .61093 L .41464 .61077 L F
.253 0 0 r
.39334 .6315 m .39176 .6332 L .38954 .63363 L F
.241 0 0 r
.39556 .63121 m .39176 .6332 L .39334 .6315 L F
.877 .706 .666 r
.59517 .60598 m .59456 .60826 L .59315 .60494 L F
.234 0 .23 r
.3525 .59954 m .3498 .60235 L .35037 .60012 L F
.783 .367 .26 r
.46748 .71497 m .47129 .71746 L .47151 .71635 L F
.211 0 .238 r
.3498 .60235 m .34748 .60486 L .34797 .60299 L F
.056 .27 .763 r
.24027 .75878 m .24223 .76045 L .24155 .76149 L F
.638 .928 .663 r
.24155 .76149 m .24223 .76045 L .23998 .76264 L F
.44 0 0 r
.79823 .50151 m .79662 .50137 L .79775 .50206 L F
.662 .764 .925 r
.1989 .56626 m .20096 .56528 L .19753 .56486 L F
.719 .403 .443 r
.4794 .7174 m .4803 .72004 L .48045 .71849 L F
.4794 .7174 m .4769 .72014 L .4803 .72004 L F
.566 .303 .476 r
.58633 .5826 m .58878 .58238 L .58897 .58027 L F
.649 .374 .489 r
.58897 .58027 m .58878 .58238 L .59217 .58197 L F
.623 .579 .783 r
.74717 .50986 m .74358 .50703 L .7457 .50779 L F
.701 .25 .178 r
.48673 .70128 m .4826 .70068 L .48349 .70211 L F
.48673 .70128 m .48513 .70268 L .4826 .70068 L F
.772 .953 .629 r
.48732 .69968 m .48673 .70128 L .48849 .70036 L F
.48732 .69968 m .48513 .70268 L .48673 .70128 L F
.78 .698 .774 r
.57142 .60889 m .57013 .60546 L .56776 .60833 L F
.786 .681 .748 r
.56776 .60833 m .56829 .61057 L .57142 .60889 L F
.745 .937 .949 r
.78803 .5286 m .79076 .52805 L .79002 .52722 L F
.989 .811 .572 r
.79076 .52805 m .79026 .52402 L .79002 .52722 L F
1 .83 .525 r
.75409 .51082 m .75321 .50995 L .75379 .50753 L F
.195 .715 .872 r
.37801 .58325 m .38197 .58341 L .37984 .58381 L F
.434 .145 .373 r
.57811 .58807 m .58058 .58562 L .57826 .58584 L F
0 0 0 r
.47436 .68609 m .47318 .68829 L .4716 .68922 L F
.265 .594 .949 r
.47436 .68609 m .4765 .6866 L .47523 .68531 L F
0 0 0 r
.47523 .68531 m .47318 .68829 L .47436 .68609 L F
.81 .683 .724 r
.54635 .67184 m .54272 .67477 L .5427 .67183 L F
.54635 .67184 m .54492 .6755 L .54272 .67477 L F
.941 .728 .588 r
.54725 .67075 m .54896 .67202 L .54635 .67184 L F
.179 .593 .941 r
.20496 .54552 m .20332 .54542 L .20171 .54421 L F
0 0 0 r
.54722 .65146 m .54424 .65405 L .54476 .65193 L F
.058 0 0 r
.51692 .64403 m .51499 .64473 L .51278 .64505 L F
0 0 0 r
.5174 .64389 m .51692 .64403 L .51766 .6428 L F
.5174 .64389 m .51499 .64473 L .51692 .64403 L F
.424 .246 .534 r
.50507 .66874 m .50299 .66658 L .50513 .66614 L F
.758 .654 .747 r
.54376 .67736 m .5451 .68067 L .54165 .6804 L F
.642 .499 .672 r
.54551 .68236 m .54165 .6804 L .5451 .68067 L F
.585 .197 .273 r
.5451 .68067 m .54779 .68212 L .54551 .68236 L F
.5451 .68067 m .54754 .68099 L .54779 .68212 L F
.568 .658 .897 r
.44994 .71249 m .45126 .71047 L .44852 .70959 L F
.44994 .71249 m .4522 .7121 L .45126 .71047 L F
.674 .127 0 r
.58825 .67516 m .5887 .67564 L .58458 .67316 L F
.232 .644 .958 r
.35574 .62271 m .35538 .62352 L .35433 .62193 L F
.35574 .62271 m .35748 .62382 L .35538 .62352 L F
.373 .143 .432 r
.20908 .60269 m .20879 .60485 L .20718 .60569 L F
.066 .023 .494 r
.21035 .5993 m .20908 .60269 L .20954 .59982 L F
.21035 .5993 m .21052 .60166 L .20908 .60269 L F
.354 .264 .614 r
.21052 .60166 m .20879 .60485 L .20908 .60269 L F
.442 .77 .997 r
.44727 .60791 m .44536 .60833 L .44351 .60718 L F
.541 .386 .619 r
.44819 .61029 m .44536 .60833 L .44727 .60791 L F
.44819 .61029 m .44546 .61115 L .44536 .60833 L F
.44 .603 .915 r
.40981 .59649 m .41018 .59412 L .40779 .59415 L F
.40981 .59649 m .41184 .59643 L .41018 .59412 L F
.256 0 0 r
.50208 .64904 m .50087 .65073 L .49867 .65119 L F
0 0 0 r
.50379 .64826 m .50208 .64904 L .50409 .64807 L F
.50379 .64826 m .50087 .65073 L .50208 .64904 L F
.391 .705 .984 r
.32303 .63626 m .32297 .63534 L .32106 .63446 L F
.32303 .63626 m .32504 .63645 L .32297 .63534 L F
.898 .604 .481 r
.53185 .60575 m .53219 .60897 L .53203 .60846 L F
.2 .079 .482 r
.53185 .60575 m .53338 .60734 L .53359 .60467 L F
.53185 .60575 m .53203 .60846 L .53338 .60734 L F
.789 .5 .498 r
.5504 .67064 m .55144 .67262 L .54896 .67202 L F
.552 .413 .645 r
.55436 .67118 m .55144 .67262 L .5504 .67064 L F
0 .082 .605 r
.6129 .63956 m .61382 .64205 L .61294 .64317 L F
0 0 .41 r
.61382 .64205 m .6136 .64542 L .61294 .64317 L F
.869 .654 .608 r
.4855 .66968 m .48371 .67184 L .48314 .669 L F
.4855 .66968 m .48599 .67246 L .48371 .67184 L F
.577 .459 .682 r
.48839 .67191 m .48599 .67246 L .4855 .66968 L F
.439 .159 .389 r
.46273 .66351 m .46495 .66301 L .46545 .66026 L F
.482 .234 .461 r
.46495 .66301 m .4673 .65982 L .46545 .66026 L F
.497 .126 .265 r
.56655 .59093 m .57043 .59016 L .56998 .58875 L F
.457 .103 .277 r
.57043 .59016 m .57185 .5899 L .56998 .58875 L F
.472 .089 .231 r
.57185 .5899 m .57233 .58857 L .56998 .58875 L F
.644 .207 .195 r
.55851 .62044 m .5607 .62215 L .56118 .62053 L F
.912 .527 .272 r
.56118 .62053 m .5607 .62215 L .56231 .62266 L F
.99 .782 .529 r
.56809 .6049 m .56776 .60833 L .56697 .60534 L F
.459 0 0 r
.56809 .6049 m .57013 .60546 L .56697 .60534 L F
.68 .185 0 r
.46712 .6896 m .46735 .69039 L .46494 .68865 L F
.46712 .6896 m .46848 .6914 L .46735 .69039 L F
.393 .039 .24 r
.44533 .68011 m .4481 .67763 L .44559 .67775 L F
.45 .728 .986 r
.4111 .58515 m .41018 .58653 L .40907 .58552 L F
.4111 .58515 m .41243 .58638 L .41018 .58653 L F
.319 .166 .51 r
.48723 .717 m .48743 .71823 L .48882 .71743 L F
.623 .621 .828 r
.78637 .52257 m .78377 .52432 L .78309 .52148 L F
.921 .769 .676 r
.59312 .61366 m .59517 .61377 L .5941 .61718 L F
.805 .591 .612 r
.5604 .59293 m .56394 .59099 L .56154 .59142 L F
.092 0 .205 r
.45305 .6721 m .45082 .67507 L .45229 .67407 L F
.295 .057 .373 r
.45004 .67704 m .45229 .67407 L .45082 .67507 L F
.42 .259 .556 r
.21856 .57689 m .2186 .57932 L .21682 .5799 L F
.422 .265 .562 r
.2186 .57932 m .21859 .58171 L .21682 .5799 L F
.42 .265 .563 r
.21859 .58171 m .21681 .58262 L .21682 .5799 L F
0 .426 .742 r
.36326 .62568 m .3649 .62632 L .36136 .62511 L F
.033 .593 .809 r
.36562 .62612 m .3649 .62632 L .36326 .62568 L F
.36562 .62612 m .36745 .62654 L .3649 .62632 L F
.693 .651 .804 r
.72913 .49328 m .72683 .49438 L .72566 .49255 L F
.54 .489 .748 r
.7295 .49563 m .72683 .49438 L .72913 .49328 L F
.355 .368 .736 r
.48129 .67102 m .4802 .672 L .4791 .66863 L F
.42 .478 .813 r
.48129 .67102 m .48291 .6734 L .4802 .672 L F
.54 .479 .736 r
.48247 .67478 m .4802 .672 L .48291 .6734 L F
0 0 .075 r
.6136 .64542 m .61335 .64776 L .61279 .64904 L F
0 0 .144 r
.61297 .65055 m .61279 .64904 L .61335 .64776 L F
.61297 .65055 m .61249 .65166 L .61279 .64904 L F
.768 .457 .459 r
.55102 .68076 m .54779 .68212 L .54754 .68099 L F
.55102 .68076 m .55034 .68186 L .54779 .68212 L F
.502 .259 .478 r
.55313 .67997 m .55034 .68186 L .55102 .68076 L F
.249 0 0 r
.35864 .59709 m .35696 .59859 L .35468 .59899 L F
.111 0 0 r
.36084 .59668 m .35696 .59859 L .35864 .59709 L F
.233 0 0 r
.50389 .69436 m .50276 .69389 L .50556 .69162 L F
0 .229 .625 r
.50377 .68948 m .50757 .69161 L .50556 .69162 L F
.55 .186 .303 r
.50717 .69373 m .50556 .69162 L .50757 .69161 L F
.50717 .69373 m .50389 .69436 L .50556 .69162 L F
.319 0 .239 r
.31254 .59294 m .3122 .59376 L .31463 .59225 L F
.569 .767 .972 r
.39635 .5931 m .39985 .59389 L .39805 .5927 L F
.637 .793 .957 r
.39805 .5927 m .39985 .59389 L .40213 .59314 L F
.435 .849 .964 r
.27269 .83247 m .27457 .83277 L .27265 .83325 L F
0 0 .484 r
.27269 .83247 m .27265 .83325 L .27409 .8357 L F
.433 .832 .98 r
.40254 .61307 m .40572 .61288 L .40383 .61183 L F
.465 .035 .138 r
.40383 .61183 m .40572 .61288 L .40622 .61173 L F
.44 .413 .733 r
.43983 .60233 m .43801 .60288 L .43741 .60061 L F
.453 .399 .707 r
.43983 .60233 m .43835 .60425 L .43801 .60288 L F
.422 .701 .98 r
.42426 .59034 m .42341 .59172 L .4221 .59054 L F
.42426 .59034 m .42554 .59165 L .42341 .59172 L F
.604 .601 .821 r
.43425 .59991 m .43059 .59725 L .43279 .59717 L F
.647 .679 .866 r
.43668 .59913 m .43425 .59991 L .43279 .59717 L F
.645 .661 .852 r
.43668 .59913 m .43741 .60061 L .43425 .59991 L F
.816 .901 .49 r
.57994 .64797 m .57859 .65084 L .57984 .64904 L F
.472 .861 .663 r
.52676 .72111 m .52923 .71928 L .52927 .72084 L F
.52676 .72111 m .5266 .72109 L .52923 .71928 L F
.742 .85 .411 r
.52676 .72111 m .52563 .72308 L .5266 .72109 L F
.453 .052 .188 r
.52927 .72084 m .52563 .72308 L .52676 .72111 L F
.705 .976 .918 r
.74084 .48698 m .74557 .48498 L .7441 .48375 L F
.74084 .48698 m .7399 .48805 L .74557 .48498 L F
.355 .368 .736 r
.48129 .67102 m .4791 .66863 L .48314 .669 L F
0 0 .505 r
.5718 .63284 m .57064 .63169 L .57115 .63048 L F
.416 .372 .701 r
.57115 .63048 m .57191 .63295 L .5718 .63284 L F
.57115 .63048 m .57167 .63028 L .57201 .63306 L F
.57191 .63295 m .57201 .63306 L .57206 .63346 L F
.57115 .63048 m .57201 .63306 L .57191 .63295 L F
0 0 .505 r
.57191 .63295 m .57359 .63469 L .57264 .63372 L F
.5718 .63284 m .57201 .63306 L .57191 .63295 L F
.57201 .63306 m .57359 .63469 L .57191 .63295 L F
.416 .372 .701 r
.57191 .63295 m .57206 .63346 L .5718 .63284 L F
.97 .761 .566 r
.57304 .63577 m .57359 .63469 L .5718 .63284 L F
0 0 .505 r
.57163 .63268 m .57264 .63372 L .57064 .63169 L F
.5718 .63284 m .57191 .63295 L .57163 .63268 L F
.57191 .63295 m .57264 .63372 L .57163 .63268 L F
.416 .372 .701 r
.57206 .63346 m .57215 .6332 L .57232 .63429 L F
.57215 .6332 m .57346 .62957 L .5725 .63355 L F
.57215 .6332 m .5725 .63355 L .57232 .63429 L F
.57167 .63028 m .57346 .62957 L .57206 .63346 L F
.97 .761 .566 r
.5728 .63623 m .57304 .63577 L .57206 .63346 L F
.57212 .63392 m .57206 .63346 L .5718 .63284 L F
.5728 .63623 m .57206 .63346 L .57212 .63392 L F
.416 .372 .701 r
.57206 .63346 m .57232 .63429 L .5718 .63284 L F
.651 .414 .547 r
.44272 .61161 m .44257 .61394 L .44083 .6135 L F
.633 .398 .545 r
.44534 .61347 m .44272 .61161 L .44546 .61115 L F
.44534 .61347 m .44257 .61394 L .44272 .61161 L F
.521 .585 .859 r
.74538 .50049 m .74349 .50383 L .74189 .50197 L F
.74538 .50049 m .74594 .50378 L .74349 .50383 L F
.184 0 0 r
.39994 .63004 m .40121 .62828 L .40361 .6274 L F
.076 .011 .473 r
.8001 .499 m .79951 .50007 L .80114 .49823 L F
.228 0 0 r
.1927 .54443 m .19563 .54369 L .19383 .54368 L F
0 .032 .565 r
.49553 .6464 m .49683 .64743 L .49757 .64559 L F
.877 .78 .751 r
.45656 .68304 m .45911 .68084 L .45636 .67978 L F
0 .433 .755 r
.45636 .67978 m .45911 .68084 L .45911 .68069 L F
.035 0 0 r
.34888 .58263 m .35117 .58257 L .35255 .58244 L F
.093 0 0 r
.35117 .58257 m .35495 .58272 L .35255 .58244 L F
.569 .622 .865 r
.43888 .5987 m .43741 .60061 L .43668 .59913 L F
.44 .413 .733 r
.43983 .60233 m .43741 .60061 L .43888 .5987 L F
.008 .533 .854 r
.56076 .59949 m .56187 .59942 L .55971 .59863 L F
.56076 .59949 m .5631 .60012 L .56187 .59942 L F
.519 .846 .998 r
.78339 .48197 m .78596 .4813 L .78676 .48207 L F
.655 .91 .98 r
.78676 .48207 m .78829 .48022 L .78924 .48142 L F
.78676 .48207 m .78596 .4813 L .78829 .48022 L F
.605 .216 .279 r
.512 .68522 m .51567 .68315 L .5123 .68404 L F
.512 .68522 m .51434 .68535 L .51567 .68315 L F
.585 .19 .261 r
.51434 .68535 m .51797 .68362 L .51567 .68315 L F
.298 .177 .541 r
.7941 .50194 m .79629 .50351 L .79662 .50137 L F
.7941 .50194 m .79428 .50442 L .79629 .50351 L F
.405 .244 .547 r
.5488 .64637 m .54905 .64852 L .54704 .64903 L F
.436 .339 .646 r
.54905 .64852 m .54937 .651 L .54704 .64903 L F
.489 .337 .6 r
.54704 .64903 m .54937 .651 L .54722 .65146 L F
.54704 .64903 m .54937 .651 L .54722 .65146 L F
.719 .291 .233 r
.54328 .63911 m .54673 .63964 L .54452 .6375 L F
.136 .583 .926 r
.54028 .62095 m .53964 .6201 L .53721 .61959 L F
.015 .419 .86 r
.54028 .62095 m .54223 .62106 L .53964 .6201 L F
.54028 .62095 m .543 .62222 L .54223 .62106 L F
.97 .653 .29 r
.5113 .68871 m .51047 .6887 L .51031 .68626 L F
.54 .1 .152 r
.51329 .6896 m .51047 .6887 L .5113 .68871 L F
.576 .524 .76 r
.50476 .66026 m .50713 .66257 L .5069 .66001 L F
.769 .594 .662 r
.58475 .59397 m .58729 .5941 L .58655 .59691 L F
.467 .372 .665 r
.44191 .68934 m .44335 .68621 L .4412 .68671 L F
.224 0 0 r
.37346 .63785 m .37178 .63905 L .3695 .63934 L F
.156 0 0 r
.37569 .63742 m .37178 .63905 L .37346 .63785 L F
.704 .534 .656 r
.80369 .50778 m .8054 .51092 L .8064 .50731 L F
.819 .665 .692 r
.54492 .6755 m .54376 .67736 L .54272 .67477 L F
.969 .851 .447 r
.61272 .63705 m .61328 .63471 L .6128 .63393 L F
.315 .199 .558 r
.47318 .68829 m .47171 .69137 L .4716 .68922 L F
.732 .353 0 r
.25923 .84423 m .25946 .84476 L .25959 .84496 L F
.799 .989 .886 r
.25959 .84496 m .25946 .84476 L .25918 .84501 L F
.471 .352 .635 r
.30775 .59983 m .30948 .59668 L .30751 .59732 L F
.511 .441 .714 r
.78382 .50765 m .78675 .51005 L .78424 .51062 L F
.207 .007 .373 r
.78675 .51005 m .78514 .5127 L .78424 .51062 L F
.603 .798 .974 r
.76852 .50715 m .76485 .50666 L .76731 .506 L F
.385 .609 .938 r
.76978 .50579 m .76852 .50715 L .76731 .506 L F
.76978 .50579 m .77068 .50737 L .76852 .50715 L F
0 0 0 r
.45541 .66936 m .45305 .6721 L .45448 .67104 L F
.33 0 .157 r
.45448 .67104 m .45768 .66886 L .45541 .66936 L F
.148 0 0 r
.35935 .64319 m .35531 .64463 L .35705 .64307 L F
.467 .372 .665 r
.44191 .68934 m .44395 .68876 L .44335 .68621 L F
.354 .297 .655 r
.44191 .68934 m .44413 .69135 L .44395 .68876 L F
.44191 .68934 m .44213 .69265 L .44413 .69135 L F
.824 .739 .77 r
.31098 .64079 m .31263 .64012 L .31201 .63979 L F
.514 .432 .701 r
.22126 .56424 m .21979 .56819 L .21953 .56573 L F
.599 .028 0 r
.54675 .62433 m .543 .62222 L .5442 .62322 L F
.466 .394 .692 r
.30708 .60852 m .30729 .6121 L .30961 .61093 L F
.49 .49 .785 r
.30729 .6121 m .31034 .6138 L .30961 .61093 L F
.337 .144 .465 r
.45229 .67407 m .45448 .67104 L .45305 .6721 L F
.626 .861 .987 r
.33602 .63974 m .33797 .64035 L .33631 .64198 L F
.919 .614 .449 r
.33797 .64035 m .3382 .64262 L .33631 .64198 L F
.442 .492 .816 r
.43194 .59545 m .43059 .59725 L .42927 .59384 L F
.483 .55 .848 r
.43194 .59545 m .43279 .59717 L .43059 .59725 L F
.905 .857 .784 r
.75507 .49008 m .75253 .4939 L .75384 .49351 L F
.416 .791 .993 r
.38593 .58255 m .38554 .5837 L .38407 .58295 L F
.38593 .58255 m .38777 .58342 L .38554 .5837 L F
.8 .699 .754 r
.75927 .49313 m .76217 .49342 L .76102 .4899 L F
.624 .58 .784 r
.76217 .49342 m .76353 .48959 L .76102 .4899 L F
.76217 .49342 m .76468 .49304 L .76353 .48959 L F
.646 .262 .304 r
.76217 .49342 m .76479 .4952 L .76172 .49508 L F
.57 .333 .517 r
.76217 .49342 m .76468 .49304 L .76479 .4952 L F
.526 .197 .353 r
.76785 .4927 m .76479 .4952 L .76468 .49304 L F
.1 0 0 r
.7652 .49331 m .76217 .49342 L .76101 .49403 L F
.7652 .49331 m .76468 .49304 L .76217 .49342 L F
.42 .781 .995 r
.2792 .84515 m .27896 .84447 L .28107 .84543 L F
.2792 .84515 m .27896 .84447 L .28107 .84543 L F
.657 .861 .977 r
.28249 .84443 m .27896 .84447 L .28107 .84543 L F
.28249 .84443 m .27896 .84447 L .28107 .84543 L F
.999 .789 .465 r
.45483 .69694 m .45578 .69788 L .4553 .69501 L F
.532 .02 0 r
.45652 .69873 m .45578 .69788 L .45483 .69694 L F
.45652 .69873 m .45783 .69992 L .45578 .69788 L F
.413 .155 .411 r
.53454 .64845 m .53656 .64821 L .53678 .64544 L F
.484 .212 .426 r
.53678 .64544 m .53893 .6476 L .53862 .64491 L F
.53678 .64544 m .53656 .64821 L .53893 .6476 L F
.09 .639 .828 r
.78013 .50737 m .78382 .50765 L .78154 .5075 L F
.096 0 0 r
.78013 .50737 m .78259 .50759 L .78382 .50765 L F
.121 .367 .827 r
.78522 .50736 m .78382 .50765 L .78259 .50759 L F
.78522 .50736 m .78675 .51005 L .78382 .50765 L F
.193 0 0 r
.27834 .68357 m .2772 .68338 L .27508 .68288 L F
.27834 .68357 m .2772 .68338 L .27508 .68288 L F
.65 .957 .937 r
.27834 .68357 m .2772 .68338 L .2789 .68229 L F
.27834 .68357 m .2772 .68338 L .2789 .68229 L F
.646 .504 .675 r
.44035 .69543 m .4427 .69477 L .44213 .69265 L F
.65 .519 .689 r
.44035 .69543 m .44093 .69748 L .4427 .69477 L F
.615 .294 .402 r
.52104 .64604 m .52453 .64553 L .52224 .64584 L F
.381 .181 .48 r
.44325 .68078 m .44483 .68235 L .44533 .68011 L F
.44325 .68078 m .44298 .68277 L .44483 .68235 L F
.579 .388 .588 r
.41509 .60848 m .41745 .60822 L .41733 .60578 L F
.561 .453 .688 r
.41745 .60822 m .41969 .6048 L .41733 .60578 L F
.171 .709 .781 r
.37253 .59539 m .37114 .59546 L .36894 .59579 L F
.029 0 0 r
.37114 .59546 m .37034 .59566 L .36894 .59579 L F
.157 .692 .844 r
.37035 .59598 m .36894 .59579 L .36747 .59593 L F
.029 0 0 r
.37034 .59566 m .36778 .59631 L .36894 .59579 L F
.157 .692 .844 r
.36747 .59593 m .36894 .59579 L .36687 .59592 L F
.171 .709 .781 r
.37253 .59539 m .36894 .59579 L .37035 .59598 L F
.645 .301 .373 r
.49937 .62761 m .50305 .62561 L .49947 .62549 L F
.49937 .62761 m .5019 .62805 L .50305 .62561 L F
.618 .271 .359 r
.50305 .62561 m .5019 .62805 L .50542 .62748 L F
.533 .907 .954 r
.37084 .62601 m .37153 .62498 L .37293 .62489 L F
.37084 .62601 m .36954 .62577 L .37153 .62498 L F
.733 .921 .955 r
.49419 .69751 m .49476 .6982 L .49632 .69669 L F
.5 .055 .123 r
.50178 .6702 m .50011 .66931 L .50004 .67143 L F
.50178 .6702 m .50296 .66952 L .50011 .66931 L F
.498 .063 .144 r
.50011 .66931 m .50178 .6702 L .50004 .67143 L F
.50011 .66931 m .50276 .6693 L .50178 .6702 L F
.653 .097 0 r
.50934 .62764 m .51174 .62968 L .51234 .62934 L F
.642 .083 0 r
.51174 .62968 m .51471 .63133 L .51234 .62934 L F
.658 .103 0 r
.51234 .62934 m .51471 .63133 L .5161 .63164 L F
.469 .578 .881 r
.58458 .67316 m .58633 .67092 L .58334 .67266 L F
.58458 .67316 m .5887 .67564 L .58633 .67092 L F
.065 0 0 r
.53006 .63306 m .53395 .63175 L .53125 .63281 L F
.706 .74 .878 r
.53696 .60531 m .5379 .60639 L .54034 .60578 L F
.29 0 .015 r
.52351 .68064 m .5256 .68019 L .52651 .67899 L F
.849 .601 .564 r
.59431 .58416 m .59592 .5827 L .59217 .58197 L F
.59431 .58416 m .59591 .58509 L .59592 .5827 L F
.688 .58 .729 r
.30981 .62227 m .31041 .62338 L .31284 .62298 L F
.633 .621 .821 r
.55232 .67444 m .54971 .67506 L .54896 .67202 L F
.553 .515 .767 r
.55293 .67685 m .54971 .67506 L .55232 .67444 L F
.488 .41 .694 r
.30708 .60852 m .3084 .60562 L .30631 .60619 L F
.30708 .60852 m .30897 .60801 L .3084 .60562 L F
.466 .394 .692 r
.30708 .60852 m .30961 .61093 L .30897 .60801 L F
.459 .037 .151 r
.53793 .64291 m .53525 .64521 L .53285 .64524 L F
.864 .561 .475 r
.59288 .60305 m .59066 .60474 L .59058 .60199 L F
.59288 .60305 m .59315 .60494 L .59066 .60474 L F
.566 0 0 r
.45626 .71168 m .45773 .71262 L .45456 .71118 L F
.956 .646 .401 r
.46527 .71182 m .46414 .70939 L .46438 .71043 L F
.84 .378 0 r
.46595 .71406 m .46527 .71182 L .46438 .71043 L F
.46595 .71406 m .46748 .71497 L .46527 .71182 L F
.383 .425 .781 r
.27725 .83635 m .27586 .83668 L .27457 .83277 L F
.374 .741 .99 r
.27409 .8357 m .27586 .83668 L .27725 .83635 L F
.357 .312 .67 r
.27725 .83635 m .2775 .83891 L .27586 .83668 L F
.243 .599 .951 r
.40591 .59397 m .4065 .59285 L .40466 .59268 L F
.235 .59 .948 r
.40591 .59397 m .40779 .59415 L .4065 .59285 L F
0 0 0 r
.36729 .63984 m .36266 .64125 L .36499 .64005 L F
.658 .158 .048 r
.47247 .7213 m .47111 .72243 L .46876 .72067 L F
.725 .244 .104 r
.47247 .7213 m .47543 .72369 L .47111 .72243 L F
.454 .138 .339 r
.48045 .71849 m .4803 .72004 L .48288 .71831 L F
.638 .62 .815 r
.75782 .50372 m .75817 .50686 L .75599 .50557 L F
.625 .608 .813 r
.76035 .50328 m .75817 .50686 L .75782 .50372 L F
.76035 .50328 m .76108 .50607 L .75817 .50686 L F
.779 .649 .719 r
.5201 .66591 m .52134 .66914 L .51775 .66872 L F
.661 .189 .12 r
.52134 .66914 m .52003 .67045 L .51775 .66872 L F
.591 .282 .413 r
.52277 .66779 m .52003 .67045 L .52134 .66914 L F
.921 .701 .588 r
.52134 .66914 m .5198 .669 L .5201 .66591 L F
.554 .318 .512 r
.50531 .67787 m .5051 .68042 L .50258 .68056 L F
.351 .151 .462 r
.50682 .67935 m .50531 .67787 L .50751 .67723 L F
.50682 .67935 m .5051 .68042 L .50531 .67787 L F
.453 .399 .707 r
.43983 .60233 m .44036 .60456 L .43835 .60425 L F
.072 .409 .861 r
.21832 .55168 m .22024 .55246 L .22001 .55366 L F
.158 .507 .912 r
.22024 .55246 m .22202 .55429 L .22001 .55366 L F
.647 .558 .74 r
.22297 .55556 m .22001 .55366 L .22202 .55429 L F
.662 .43 .558 r
.34067 .64489 m .3382 .64262 L .34153 .6432 L F
.894 .972 .823 r
.34205 .6415 m .34176 .64291 L .34384 .64028 L F
.34129 .64202 m .34384 .64028 L .34223 .64059 L F
.321 .489 .869 r
.34447 .64254 m .34223 .64059 L .34384 .64028 L F
.34447 .64254 m .3439 .63957 L .34224 .64058 L F
.34224 .64059 m .34224 .64058 L .34223 .64059 L F
.34447 .64254 m .34224 .64058 L .34224 .64059 L F
.894 .972 .823 r
.34129 .64202 m .34153 .6432 L .34176 .64291 L F
.34129 .64202 m .34176 .64291 L .34205 .6415 L F
.265 .123 .494 r
.34129 .64202 m .34067 .64489 L .34153 .6432 L F
.687 .485 .608 r
.51797 .68362 m .52136 .68361 L .52109 .68101 L F
.646 .455 .611 r
.52109 .68101 m .52376 .68314 L .52351 .68064 L F
.52109 .68101 m .52136 .68361 L .52376 .68314 L F
.79 .552 .578 r
.5959 .58755 m .59945 .58557 L .59591 .58509 L F
.5959 .58755 m .59949 .58807 L .59945 .58557 L F
.591 .548 .776 r
.32703 .63511 m .32953 .64059 L .33072 .63735 L F
.625 .616 .822 r
.30894 .61904 m .30981 .62227 L .31123 .61959 L F
.688 .58 .729 r
.30981 .62227 m .31284 .62298 L .31123 .61959 L F
.375 .804 .967 r
.38987 .58336 m .39376 .5835 L .39157 .58393 L F
.551 .468 .715 r
.72927 .50783 m .73092 .50319 L .72813 .50413 L F
.72927 .50783 m .73162 .50751 L .73092 .50319 L F
.952 .685 .493 r
.54256 .65458 m .5426 .65728 L .54115 .654 L F
.54115 .654 m .5426 .65728 L .54256 .65458 L F
.537 .252 .43 r
.54184 .68361 m .53922 .68584 L .53935 .68372 L F
.582 .537 .77 r
.53922 .68584 m .54083 .68227 L .53935 .68372 L F
.26 0 .207 r
.49388 .62614 m .49125 .62861 L .4935 .62801 L F
.643 .405 .543 r
.4935 .62801 m .49616 .6256 L .49388 .62614 L F
.507 .418 .689 r
.44213 .69265 m .4448 .69438 L .44413 .69135 L F
.44213 .69265 m .4427 .69477 L .4448 .69438 L F
.393 .039 .24 r
.44533 .68011 m .44719 .67979 L .4481 .67763 L F
.427 .102 .309 r
.44719 .67979 m .45004 .67704 L .4481 .67763 L F
0 0 0 r
.73629 .51338 m .73801 .5118 L .73883 .51073 L F
.35 .467 .838 r
.73629 .51338 m .73925 .51485 L .73801 .5118 L F
.667 .855 .972 r
.73733 .48998 m .73388 .48985 L .73641 .48879 L F
.802 .698 .751 r
.73733 .48998 m .73495 .49368 L .73388 .48985 L F
.104 .652 .823 r
.73641 .48879 m .74041 .48901 L .73733 .48998 L F
.794 .534 .543 r
.542 .59815 m .53861 .60021 L .53784 .5992 L F
.542 .59815 m .53784 .5992 L .5401 .59939 L F
0 0 0 r
.542 .59815 m .54354 .59821 L .54403 .59724 L F
.542 .59815 m .5401 .59939 L .54354 .59821 L F
.587 .339 .508 r
.43446 .61433 m .43661 .61635 L .43416 .6166 L F
.656 .324 .399 r
.43684 .61461 m .43661 .61635 L .43446 .61433 L F
.542 .321 .529 r
.48334 .67722 m .48081 .68035 L .48115 .67772 L F
.587 .437 .645 r
.49867 .65119 m .49625 .65424 L .49661 .65186 L F
.564 .256 .404 r
.41787 .61997 m .41685 .62258 L .41432 .62253 L F
.431 .125 .343 r
.41893 .62202 m .41787 .61997 L .42032 .61941 L F
.41893 .62202 m .41685 .62258 L .41787 .61997 L F
.312 .104 .428 r
.4889 .63151 m .48679 .63452 L .48862 .63375 L F
.24 .132 .524 r
.48679 .63452 m .48852 .6366 L .48862 .63375 L F
.48679 .63452 m .48692 .6369 L .48852 .6366 L F
.636 .424 .577 r
.41464 .61077 m .41745 .60822 L .41509 .60848 L F
.35 0 0 r
.19678 .56191 m .19942 .56177 L .19756 .56149 L F
.454 .224 .474 r
.19756 .56149 m .19942 .56177 L .19988 .55934 L F
.722 .468 .542 r
.48314 .669 m .48371 .67184 L .48129 .67102 L F
.356 .327 .689 r
.4846 .67366 m .48371 .67184 L .48599 .67246 L F
.159 0 0 r
.4846 .67366 m .48599 .67246 L .48839 .67191 L F
.487 .255 .487 r
.49546 .67485 m .49772 .67435 L .49801 .67208 L F
.49801 .67208 m .49772 .67435 L .49546 .67485 L F
.407 .186 .464 r
.50004 .67143 m .49772 .67435 L .49801 .67208 L F
.50004 .67143 m .49772 .67435 L .49801 .67208 L F
.3 0 .021 r
.38762 .62059 m .38989 .62013 L .39028 .61949 L F
.234 0 0 r
.39028 .61949 m .38989 .62013 L .39211 .61946 L F
0 0 .25 r
.21086 .59679 m .21035 .5993 L .20954 .59982 L F
.194 .725 .785 r
.56602 .60134 m .56794 .6011 L .56649 .60404 L F
0 0 .316 r
.56649 .60404 m .56697 .60534 L .56602 .60134 L F
0 0 0 r
.53738 .71516 m .53992 .71258 L .53908 .71412 L F
.54167 .71162 m .53885 .71454 L .53992 .71258 L F
.54167 .71162 m .54058 .71341 L .53885 .71454 L F
.336 .352 .729 r
.54043 .71329 m .54011 .7111 L .53794 .71127 L F
.54058 .71341 m .54055 .71322 L .54043 .71329 L F
.54055 .71322 m .54011 .7111 L .54043 .71329 L F
0 0 0 r
.53733 .7152 m .53738 .71516 L .53885 .71454 L F
.53738 .71516 m .53908 .71412 L .53885 .71454 L F
.842 .87 .426 r
.58972 .64281 m .58959 .64236 L .59046 .64007 L F
.054 .621 .737 r
.36484 .583 m .36425 .5831 L .3627 .58309 L F
.36484 .583 m .36656 .58299 L .36425 .5831 L F
.351 0 .015 r
.57431 .58929 m .5758 .58729 L .57233 .58857 L F
.583 .094 .06 r
.57685 .58934 m .5758 .58729 L .57431 .58929 L F
.57685 .58934 m .57811 .58807 L .5758 .58729 L F
.912 .598 .436 r
.60095 .59377 m .60138 .5964 L .60362 .59678 L F
.901 .762 .698 r
.60039 .59883 m .60362 .59678 L .60138 .5964 L F
.60039 .59883 m .60209 .59954 L .60362 .59678 L F
.39 0 .099 r
.32512 .58755 m .32738 .58725 L .32887 .58535 L F
.483 .093 .223 r
.32738 .58725 m .33111 .585 L .32887 .58535 L F
.649 .904 .584 r
.47039 .66967 m .46953 .67098 L .47145 .66876 L F
.145 .316 .778 r
.47039 .66967 m .47044 .6698 L .46953 .67098 L F
.576 .915 .969 r
.4689 .6718 m .47064 .67148 L .46953 .67098 L F
.781 .976 .913 r
.46953 .67098 m .47064 .67148 L .47212 .66992 L F
.611 .603 .819 r
.47064 .67148 m .47366 .67167 L .47212 .66992 L F
.781 .976 .913 r
.46953 .67098 m .47212 .66992 L .47145 .66876 L F
.145 .316 .778 r
.47044 .6698 m .47169 .67288 L .46953 .67098 L F
.576 .915 .969 r
.46813 .67193 m .4689 .6718 L .46953 .67098 L F
.883 .837 .795 r
.53014 .71446 m .53373 .71233 L .53021 .71193 L F
.53014 .71446 m .53168 .71548 L .53373 .71233 L F
.608 .348 .497 r
.51874 .65756 m .51804 .65958 L .51425 .65985 L F
.658 .525 .691 r
.52087 .65682 m .51804 .65958 L .51874 .65756 L F
.493 .348 .613 r
.22297 .55556 m .22312 .55915 L .22114 .55958 L F
.463 .258 .516 r
.22312 .55915 m .22091 .56201 L .22114 .55958 L F
.425 0 0 r
.49754 .64314 m .49382 .64409 L .49384 .64328 L F
.49754 .64314 m .49611 .64439 L .49382 .64409 L F
.557 .415 .644 r
.49754 .64314 m .5 .64272 L .49966 .64007 L F
.526 .33 .558 r
.49757 .64559 m .5 .64272 L .49754 .64314 L F
.806 .559 .565 r
.5 .64272 m .49611 .64439 L .49754 .64314 L F
.557 .415 .644 r
.49754 .64314 m .5 .64272 L .49966 .64007 L F
.519 .225 .408 r
.20096 .56528 m .20188 .56845 L .20364 .56744 L F
.697 .685 .834 r
.20135 .5665 m .20213 .56817 L .19904 .56876 L F
.633 .922 .649 r
.19963 .57111 m .20046 .56988 L .20188 .56845 L F
.20046 .56988 m .20049 .56984 L .20089 .56944 L F
.20046 .56988 m .20089 .56944 L .20188 .56845 L F
.707 .637 .776 r
.20188 .56845 m .20049 .56984 L .20271 .56943 L F
.697 .685 .834 r
.20213 .56817 m .20271 .56943 L .20118 .56915 L F
.20213 .56817 m .20118 .56915 L .19904 .56876 L F
.603 .84 .465 r
.19833 .57275 m .20049 .56984 L .19963 .57111 L F
.608 .319 .452 r
.426 .61694 m .425 .61987 L .42251 .61963 L F
.611 .322 .454 r
.42826 .61894 m .426 .61694 L .42844 .61682 L F
.42826 .61894 m .425 .61987 L .426 .61694 L F
.628 .353 .483 r
.5829 .59425 m .58338 .59637 L .57931 .59716 L F
.816 .603 .615 r
.58475 .59397 m .58338 .59637 L .5829 .59425 L F
.229 .051 .42 r
.20879 .60485 m .20713 .6082 L .20718 .60569 L F
.689 .415 .503 r
.76353 .48959 m .76922 .49083 L .76683 .4876 L F
.424 .352 .671 r
.76683 .4876 m .76922 .49083 L .76955 .48842 L F
.494 .112 .244 r
.76955 .48842 m .7694 .48739 L .76683 .4876 L F
.611 .619 .834 r
.7248 .48939 m .72491 .49273 L .72375 .49145 L F
.7248 .48939 m .72566 .49255 L .72491 .49273 L F
.994 .857 .593 r
.72491 .49273 m .72351 .49387 L .72375 .49145 L F
.72491 .49273 m .72413 .49552 L .72351 .49387 L F
.5 .532 .821 r
.34415 .60764 m .34348 .61143 L .34294 .60741 L F
.34415 .60764 m .3453 .61089 L .34348 .61143 L F
.44 .322 .622 r
.3453 .61089 m .34565 .61332 L .34348 .61143 L F
.476 .321 .591 r
.34565 .61332 m .34358 .61393 L .34348 .61143 L F
.334 0 .093 r
.38457 .62222 m .38687 .62174 L .38762 .62059 L F
.473 .11 .268 r
.38687 .62174 m .38989 .62013 L .38762 .62059 L F
.638 .62 .815 r
.75782 .50372 m .75599 .50557 L .75527 .50436 L F
.579 .665 .897 r
.80281 .50117 m .80639 .50283 L .80508 .50046 L F
.624 .599 .805 r
.80639 .50283 m .80733 .49791 L .80508 .50046 L F
.80639 .50283 m .80868 .50156 L .80733 .49791 L F
.067 0 0 r
.80639 .50283 m .80868 .50156 L .80561 .50342 L F
.80639 .50283 m .80868 .50156 L .80561 .50342 L F
.736 .726 .842 r
.53104 .68645 m .52766 .68662 L .5294 .68431 L F
.358 0 0 r
.53104 .68645 m .52737 .68827 L .52766 .68662 L F
.53104 .68645 m .52974 .68806 L .52737 .68827 L F
.836 .703 .718 r
.53283 .68009 m .5305 .68503 L .5294 .68431 L F
0 0 .077 r
.53108 .68436 m .53062 .68506 L .5305 .68503 L F
0 .385 .802 r
.5305 .68503 m .53062 .68506 L .5294 .68431 L F
.634 .693 .887 r
.53059 .68505 m .53057 .68503 L .53071 .68484 L F
.53365 .68603 m .53037 .68545 L .53075 .68486 L F
0 0 .077 r
.53078 .68487 m .53145 .68531 L .53062 .68506 L F
.634 .693 .887 r
.53163 .68537 m .53075 .68486 L .53145 .68531 L F
.53365 .68603 m .53119 .68504 L .53163 .68537 L F
.53119 .68504 m .53075 .68486 L .53163 .68537 L F
.53365 .68603 m .53104 .68645 L .53026 .68543 L F
.587 .36 .538 r
.53365 .68603 m .53346 .68883 L .53104 .68645 L F
.734 .308 .238 r
.53104 .68645 m .53346 .68883 L .52974 .68806 L F
.908 .825 .753 r
.53156 .68718 m .52974 .68806 L .53145 .68531 L F
.791 .537 .553 r
.52974 .68806 m .53164 .68708 L .53145 .68531 L F
.53164 .68699 m .53365 .68603 L .53163 .68537 L F
.53164 .68708 m .53163 .68537 L .53145 .68531 L F
0 0 .498 r
.53293 .68377 m .53164 .68699 L .53145 .68531 L F
.53164 .68699 m .53156 .68718 L .53145 .68531 L F
.791 .537 .553 r
.53164 .68708 m .53165 .68707 L .53164 .68699 L F
.53165 .68707 m .53365 .68603 L .53164 .68699 L F
.53177 .68701 m .53346 .68883 L .53365 .68603 L F
.53168 .68711 m .53346 .68883 L .53177 .68701 L F
.462 .212 .449 r
.53165 .68714 m .5315 .68733 L .53156 .68718 L F
0 0 .498 r
.53165 .68712 m .53165 .68714 L .53164 .68715 L F
.53164 .68699 m .53164 .68715 L .53156 .68718 L F
.791 .537 .553 r
.52974 .68806 m .53196 .68852 L .53168 .68726 L F
.127 0 .058 r
.5315 .68733 m .52974 .68806 L .53156 .68718 L F
.791 .537 .553 r
.52974 .68806 m .53168 .68726 L .53164 .68708 L F
.127 0 .058 r
.53075 .6892 m .52974 .68806 L .5315 .68733 L F
.791 .537 .553 r
.53196 .68852 m .53346 .68883 L .53164 .68708 L F
.462 .212 .449 r
.53336 .68651 m .53075 .6892 L .5315 .68733 L F
.53336 .68651 m .5315 .68733 L .53165 .68714 L F
.791 .537 .553 r
.53164 .68708 m .53168 .68711 L .53177 .68701 L F
0 0 .498 r
.53214 .68574 m .53323 .68656 L .53165 .68714 L F
.53214 .68574 m .53165 .68714 L .53165 .68712 L F
.53214 .68574 m .53164 .68715 L .53164 .68699 L F
.53293 .68377 m .53336 .68651 L .53323 .68656 L F
.53293 .68377 m .53323 .68656 L .53214 .68574 L F
0 0 .077 r
.53348 .68156 m .53145 .68531 L .53078 .68487 L F
.634 .693 .887 r
.53075 .68486 m .53071 .68484 L .53145 .68531 L F
0 0 .077 r
.53348 .68156 m .53062 .68506 L .53108 .68436 L F
0 0 .095 r
.53108 .68436 m .5305 .68503 L .53338 .68133 L F
.53068 .68481 m .5305 .68503 L .53063 .68476 L F
.634 .693 .887 r
.53071 .68484 m .53026 .68543 L .5294 .68431 L F
0 .385 .802 r
.53062 .68506 m .53145 .68531 L .5294 .68431 L F
.634 .693 .887 r
.53075 .68486 m .53059 .68505 L .53071 .68484 L F
.53059 .68505 m .53026 .68543 L .53057 .68503 L F
.53037 .68545 m .53026 .68543 L .53075 .68486 L F
.53071 .68484 m .5294 .68431 L .53089 .68504 L F
.53071 .68484 m .53089 .68504 L .53145 .68531 L F
0 0 .095 r
.53338 .68133 m .53068 .68481 L .53283 .68009 L F
.53068 .68481 m .53063 .68476 L .53283 .68009 L F
.53348 .68156 m .53108 .68436 L .53338 .68133 L F
.831 .694 .711 r
.56166 .67709 m .56298 .68061 L .56008 .68008 L F
.841 .596 .567 r
.56298 .68061 m .56021 .68241 L .56008 .68008 L F
0 .11 .654 r
.56166 .67709 m .56301 .67874 L .56298 .68061 L F
.779 .695 .771 r
.55962 .67437 m .56166 .67709 L .558 .67694 L F
.861 .735 .723 r
.56166 .67709 m .55798 .67967 L .558 .67694 L F
.56166 .67709 m .56008 .68008 L .55798 .67967 L F
.754 .466 .496 r
.55962 .67437 m .56341 .67664 L .56166 .67709 L F
.973 .769 .343 r
.56341 .67664 m .56339 .67921 L .56166 .67709 L F
.522 .731 .97 r
.55932 .67559 m .5633 .67745 L .55962 .67437 L F
.973 .769 .343 r
.56341 .67729 m .56285 .67843 L .56339 .67921 L F
.522 .731 .97 r
.5633 .67745 m .5634 .67751 L .56331 .67743 L F
.5633 .67745 m .56331 .67743 L .55962 .67437 L F
.754 .466 .496 r
.55962 .67437 m .56331 .67743 L .56341 .67664 L F
.973 .769 .343 r
.56341 .67664 m .56331 .67743 L .56341 .67729 L F
.754 .466 .496 r
.56331 .67743 m .5634 .67751 L .56341 .67664 L F
.522 .731 .97 r
.55932 .67559 m .56203 .6754 L .56317 .67714 L F
.973 .769 .343 r
.56325 .67733 m .5633 .67745 L .56331 .67743 L F
.56341 .67664 m .56321 .67728 L .56331 .67743 L F
.522 .731 .97 r
.5633 .67745 m .56322 .67726 L .5634 .67751 L F
.55932 .67559 m .56317 .67714 L .5633 .67745 L F
.973 .769 .343 r
.56321 .67728 m .56327 .67749 L .5633 .67745 L F
.56321 .67728 m .5633 .67745 L .56325 .67733 L F
.984 .699 .357 r
.5634 .67751 m .56321 .67728 L .56322 .67726 L F
.5634 .67751 m .56322 .67726 L .56341 .67664 L F
.522 .731 .97 r
.56322 .67726 m .56317 .67714 L .5634 .67751 L F
.886 .873 .819 r
.5634 .67751 m .56317 .67714 L .56321 .67728 L F
.5634 .67751 m .56321 .67728 L .56328 .67751 L F
.973 .769 .343 r
.56333 .6774 m .56285 .67843 L .56341 .67729 L F
.886 .873 .819 r
.5634 .67751 m .56328 .67751 L .56285 .67843 L F
.56328 .67751 m .56025 .67762 L .56285 .67843 L F
.973 .769 .343 r
.56304 .67784 m .56285 .67843 L .56333 .6774 L F
.56321 .67728 m .56304 .67784 L .56327 .67749 L F
.984 .699 .357 r
.5634 .67751 m .56285 .67843 L .56321 .67728 L F
.886 .873 .819 r
.56328 .67751 m .56259 .67626 L .56281 .67753 L F
.56317 .67714 m .56259 .67626 L .56328 .67751 L F
.56281 .67753 m .56203 .6754 L .56025 .67762 L F
.56259 .67626 m .56203 .6754 L .56281 .67753 L F
0 .11 .654 r
.56301 .67874 m .56339 .67921 L .5632 .67987 L F
.56301 .67874 m .5632 .67987 L .56298 .68061 L F
.804 .74 .215 r
.56339 .67921 m .56297 .68308 L .56298 .68061 L F
.589 .528 .754 r
.78247 .51926 m .78309 .52148 L .78007 .51994 L F
0 0 .393 r
.5577 .66003 m .55832 .66249 L .55816 .66371 L F
0 0 0 r
.55816 .66371 m .55819 .66454 L .55946 .66551 L F
.55816 .66371 m .55832 .66249 L .55819 .66454 L F
.067 .213 .707 r
.55356 .65126 m .55546 .65328 L .55438 .65404 L F
.089 .259 .744 r
.55546 .65328 m .55678 .65666 L .55438 .65404 L F
0 .205 .728 r
.55438 .65404 m .55678 .65666 L .55708 .65821 L F
0 0 0 r
.55271 .59881 m .55033 .60194 L .55162 .60021 L F
.624 .579 .783 r
.74358 .50703 m .74476 .51074 L .74076 .50887 L F
.374 .59 .928 r
.74392 .51814 m .74574 .5171 L .7429 .51708 L F
.74392 .51814 m .7461 .51856 L .74574 .5171 L F
.822 .949 .598 r
.58573 .64935 m .58766 .64549 L .58755 .64556 L F
.58573 .64935 m .58576 .64865 L .58766 .64549 L F
.823 .942 .58 r
.58573 .64935 m .58456 .65063 L .58576 .64865 L F
.525 .91 .939 r
.58456 .65063 m .58117 .65106 L .58236 .65063 L F
0 0 0 r
.58456 .65063 m .58627 .64743 L .58576 .64865 L F
.58456 .65063 m .58607 .64928 L .58627 .64743 L F
.525 .91 .939 r
.58456 .65063 m .58236 .65063 L .58607 .64928 L F
.918 .602 .429 r
.58573 .64935 m .58602 .65064 L .58456 .65063 L F
.58602 .65064 m .58628 .65176 L .58456 .65063 L F
.731 .71 .831 r
.53696 .60531 m .54034 .60578 L .53934 .60274 L F
.477 .424 .719 r
.54034 .60578 m .54181 .6017 L .53934 .60274 L F
.54034 .60578 m .5422 .60505 L .54181 .6017 L F
.266 .188 .579 r
.54123 .60808 m .5422 .60505 L .54034 .60578 L F
.777 .702 .781 r
.31123 .61959 m .31284 .62298 L .31521 .61993 L F
.709 .836 .943 r
.46153 .70018 m .45924 .70106 L .45783 .69992 L F
.373 .224 .546 r
.22007 .57864 m .21856 .57689 L .22055 .57532 L F
.22007 .57864 m .2186 .57932 L .21856 .57689 L F
.233 0 0 r
.50389 .69436 m .5021 .6949 L .50276 .69389 L F
.736 .458 0 r
.53733 .7152 m .53709 .71454 L .5365 .71204 L F
.334 .75 .978 r
.53733 .7152 m .53885 .71454 L .53709 .71454 L F
.3 .094 .424 r
.4427 .69477 m .44093 .69748 L .44237 .69737 L F
.4427 .69477 m .44093 .69748 L .44237 .69737 L F
.227 .714 .927 r
.47597 .6651 m .47747 .66559 L .47574 .66574 L F
.159 .275 .735 r
.46309 .706 m .46519 .70824 L .46414 .70939 L F
.149 .179 .637 r
.46519 .70824 m .46438 .71043 L .46414 .70939 L F
.879 .707 .665 r
.59315 .60494 m .59456 .60826 L .59232 .60808 L F
.877 .734 .701 r
.59232 .60808 m .59456 .60826 L .5934 .61129 L F
.344 .654 .969 r
.21663 .55006 m .21626 .55147 L .2147 .54998 L F
.21663 .55006 m .21832 .55168 L .21626 .55147 L F
.363 .834 .837 r
.80173 .52264 m .79783 .52369 L .80048 .51873 L F
0 0 0 r
.79829 .52412 m .80173 .52264 L .80103 .52194 L F
.738 .632 .741 r
.80351 .51982 m .80173 .52264 L .80048 .51873 L F
.919 .97 .78 r
.80103 .52194 m .80173 .52264 L .80351 .51982 L F
0 0 0 r
.58755 .64556 m .58766 .64549 L .58959 .64236 L F
.633 .377 .513 r
.25912 .84478 m .25946 .84476 L .25923 .84423 L F
.391 .269 .592 r
.2152 .59093 m .21351 .59386 L .21305 .59159 L F
.59 .742 .949 r
.79421 .48013 m .7927 .48225 L .79178 .48101 L F
.79421 .48013 m .79522 .48162 L .7927 .48225 L F
.903 .74 .67 r
.44908 .70466 m .44944 .70819 L .44978 .70617 L F
.44908 .70466 m .44731 .70593 L .44944 .70819 L F
.926 .574 .137 r
.55946 .66551 m .56023 .66838 L .56118 .66921 L F
1 .805 .474 r
.56118 .66921 m .55992 .67083 L .56067 .67158 L F
.56118 .66921 m .56023 .66838 L .55992 .67083 L F
.76 .676 .768 r
.73388 .48985 m .73495 .49368 L .73153 .49352 L F
.609 .564 .778 r
.73229 .49473 m .73496 .49673 L .73171 .49581 L F
.605 .122 .08 r
.73495 .49368 m .73477 .49536 L .73153 .49352 L F
.648 .582 .767 r
.73564 .49555 m .73496 .49673 L .73422 .49524 L F
.605 .122 .08 r
.73477 .49536 m .73477 .49539 L .7347 .49535 L F
.73477 .49536 m .7347 .49535 L .73153 .49352 L F
.039 0 .017 r
.73657 .49394 m .73495 .49368 L .73815 .49469 L F
.648 .582 .767 r
.73657 .49394 m .73564 .49555 L .73515 .49506 L F
.039 0 .017 r
.73657 .49394 m .73477 .49536 L .73495 .49368 L F
.605 .122 .08 r
.73477 .49539 m .73442 .49529 L .73153 .49352 L F
.648 .582 .767 r
.73564 .49555 m .73422 .49524 L .73316 .4931 L F
.039 0 .017 r
.73657 .49394 m .73475 .4955 L .73477 .49536 L F
.648 .582 .767 r
.73657 .49394 m .73515 .49506 L .73316 .4931 L F
.605 .122 .08 r
.73477 .49539 m .73475 .4955 L .73442 .49529 L F
.198 .352 .793 r
.73153 .49352 m .73475 .4955 L .73316 .4931 L F
.609 .564 .778 r
.73316 .4931 m .73422 .49524 L .73229 .49473 L F
.73422 .49524 m .73496 .49673 L .73229 .49473 L F
.657 .69 .869 r
.72791 .49148 m .72913 .49328 L .72566 .49255 L F
.596 .568 .793 r
.73037 .48927 m .72913 .49328 L .72791 .49148 L F
.73037 .48927 m .73153 .49352 L .72913 .49328 L F
.618 .445 .626 r
.73153 .49352 m .7295 .49563 L .72913 .49328 L F
.73153 .49352 m .7295 .49563 L .72913 .49328 L F
.323 0 0 r
.77193 .48682 m .77436 .48648 L .77532 .48492 L F
.591 .13 .128 r
.77436 .48648 m .77775 .48633 L .77532 .48492 L F
.488 .286 .532 r
.77532 .48492 m .77775 .48633 L .77766 .48404 L F
.918 .713 .61 r
.60209 .59954 m .60183 .6021 L .6035 .60268 L F
.908 .523 .277 r
.60183 .6021 m .60387 .60485 L .6035 .60268 L F
.826 .731 .759 r
.53091 .67677 m .53283 .68009 L .52984 .68064 L F
.836 .703 .718 r
.53283 .68009 m .5294 .68431 L .52984 .68064 L F
.459 .571 .88 r
.53447 .67928 m .53283 .68009 L .53091 .67677 L F
0 0 .095 r
.53348 .68156 m .53283 .68009 L .53447 .67928 L F
.656 .886 .982 r
.59717 .67247 m .59805 .67065 L .59578 .67358 L F
.59717 .67247 m .59924 .6714 L .59805 .67065 L F
.221 0 0 r
.37521 .62488 m .37746 .62457 L .37909 .62333 L F
.303 0 0 r
.37746 .62457 m .38139 .62294 L .37909 .62333 L F
.482 .749 .988 r
.46153 .70018 m .46582 .70039 L .46515 .70092 L F
.077 0 .027 r
.46515 .70092 m .46426 .70289 L .46207 .70394 L F
.379 .696 .982 r
.46475 .69839 m .4665 .69972 L .46582 .70039 L F
.538 .926 .876 r
.46582 .70039 m .4665 .69972 L .46515 .70092 L F
0 0 .071 r
.46515 .70092 m .46575 .70191 L .46426 .70289 L F
.46515 .70092 m .4665 .69972 L .46575 .70191 L F
.928 .698 .57 r
.59924 .59299 m .60109 .59131 L .59907 .59068 L F
.59924 .59299 m .60095 .59377 L .60109 .59131 L F
.773 .693 .775 r
.76103 .52013 m .76495 .52039 L .76392 .51898 L F
.76103 .52013 m .76165 .52144 L .76495 .52039 L F
.489 .664 .94 r
.76495 .52039 m .7661 .51834 L .76392 .51898 L F
.76495 .52039 m .76837 .5198 L .7661 .51834 L F
.694 .782 .919 r
.34604 .64242 m .34752 .64491 L .34971 .64314 L F
.722 .639 .766 r
.48487 .64047 m .48787 .64022 L .48692 .6369 L F
.194 0 .24 r
.48657 .64128 m .48466 .64258 L .48383 .64444 L F
.399 0 0 r
.48632 .64108 m .48787 .64022 L .48547 .64042 L F
.48582 .64136 m .48632 .64108 L .48487 .64047 L F
.48632 .64108 m .48547 .64042 L .48487 .64047 L F
.059 .193 .69 r
.48692 .6369 m .48756 .63913 L .48874 .63874 L F
.48756 .63913 m .48787 .64022 L .48874 .63874 L F
.704 .974 .758 r
.48874 .63874 m .4887 .63881 L .48582 .64136 L F
.4887 .63881 m .48787 .64022 L .48615 .64117 L F
.4887 .63881 m .48615 .64117 L .48582 .64136 L F
.194 0 .24 r
.48781 .63985 m .48383 .64444 L .48587 .64557 L F
.184 0 .331 r
.48781 .63985 m .48587 .64557 L .4882 .64266 L F
.48781 .63985 m .4882 .64266 L .48743 .64053 L F
.594 .342 .505 r
.48743 .64053 m .48987 .63837 L .48874 .63874 L F
.48987 .63837 m .49039 .6379 L .48874 .63874 L F
.194 0 .24 r
.48781 .63985 m .48635 .64111 L .48657 .64128 L F
.48635 .64111 m .48466 .64258 L .48657 .64128 L F
.514 .763 .986 r
.55502 .61954 m .5572 .61907 L .55851 .62044 L F
0 .143 .631 r
.55939 .62082 m .55851 .62044 L .5572 .61907 L F
.55939 .62082 m .5607 .62215 L .55851 .62044 L F
.392 .139 .407 r
.51513 .66189 m .5133 .66065 L .51425 .65985 L F
.51513 .66189 m .51291 .66285 L .5133 .66065 L F
.028 .343 .822 r
.21265 .54741 m .21242 .54844 L .21115 .54708 L F
.21265 .54741 m .2147 .54998 L .21242 .54844 L F
.734 .29 .197 r
.5778 .63961 m .58 .64214 L .58089 .64046 L F
.704 .255 .182 r
.58089 .64046 m .58 .64214 L .58251 .64224 L F
.518 .108 .203 r
.51684 .6889 m .51565 .69079 L .51329 .6896 L F
.654 .258 .282 r
.51919 .69078 m .51684 .6889 L .51924 .68914 L F
.51919 .69078 m .51565 .69079 L .51684 .6889 L F
.718 .672 .804 r
.75253 .4939 m .75352 .49589 L .75041 .49597 L F
.673 .473 .607 r
.75334 .49711 m .75041 .49597 L .75352 .49589 L F
.27 .426 .834 r
.75253 .4939 m .75532 .49533 L .75352 .49589 L F
.492 .504 .798 r
.75532 .49533 m .75334 .49711 L .75352 .49589 L F
.357 0 0 r
.33337 .58478 m .33565 .58463 L .33726 .58316 L F
.377 0 0 r
.33726 .58316 m .33565 .58463 L .33905 .58374 L F
0 .072 .631 r
.79823 .4964 m .8001 .499 L .79778 .49521 L F
.155 0 0 r
.37885 .63649 m .37785 .63711 L .37569 .63742 L F
.129 0 0 r
.38128 .63607 m .37785 .63711 L .37885 .63649 L F
.594 .275 .398 r
.51216 .72411 m .51096 .72585 L .50908 .72381 L F
.613 .423 .601 r
.50908 .72381 m .51216 .72411 L .51198 .72289 L F
.547 .275 .454 r
.51198 .72289 m .51096 .72585 L .50908 .72381 L F
.998 .802 .51 r
.28464 .66203 m .28367 .66272 L .28509 .66038 L F
.332 .568 .925 r
.45911 .68069 m .46136 .68359 L .46221 .68219 L F
.598 .899 .987 r
.46221 .68219 m .46136 .68359 L .4601 .68304 L F
.565 .275 .435 r
.58616 .58448 m .58865 .58435 L .58633 .5826 L F
.558 .279 .447 r
.58633 .5826 m .58865 .58435 L .58878 .58238 L F
.511 .23 .424 r
.58378 .58469 m .58616 .58448 L .58633 .5826 L F
.571 .668 .904 r
.35265 .61955 m .35179 .62223 L .3502 .61979 L F
.35265 .61955 m .35433 .62193 L .35179 .62223 L F
0 0 .34 r
.55678 .65666 m .5577 .66003 L .55708 .65821 L F
.966 .741 .547 r
.3192 .63728 m .31905 .64 L .31724 .63895 L F
0 .141 .685 r
.31984 .63627 m .32098 .63903 L .3192 .63728 L F
.32098 .63903 m .32119 .63955 L .32074 .63904 L F
.32098 .63903 m .32074 .63904 L .3192 .63728 L F
.587 .641 .871 r
.32323 .63879 m .32119 .63955 L .31984 .63627 L F
.489 .321 .579 r
.3192 .63728 m .32119 .63955 L .31905 .64 L F
0 0 0 r
.32323 .63879 m .31949 .63925 L .32119 .63955 L F
.79 .755 .821 r
.32297 .63534 m .32504 .63645 L .32719 .63421 L F
.291 .5 .888 r
.32106 .63446 m .32297 .63534 L .32233 .63341 L F
.79 .755 .821 r
.32297 .63534 m .32719 .63421 L .32555 .63447 L F
.9 .871 .8 r
.32297 .63534 m .31984 .63627 L .32233 .63341 L F
.587 .641 .871 r
.32323 .63879 m .31984 .63627 L .32297 .63534 L F
0 0 0 r
.32555 .63447 m .32409 .6355 L .32297 .63534 L F
.933 .96 .763 r
.32409 .6355 m .32323 .63879 L .32297 .63534 L F
.641 .892 .56 r
.32226 .63347 m .31984 .63627 L .32136 .63427 L F
.32233 .63341 m .32228 .63347 L .32226 .63347 L F
.32228 .63347 m .31984 .63627 L .32226 .63347 L F
0 0 .395 r
.32106 .63446 m .32199 .631 L .32017 .63152 L F
.32106 .63446 m .32233 .63341 L .32199 .631 L F
.666 .139 0 r
.32149 .63309 m .32188 .63363 L .3209 .63324 L F
.189 .01 .393 r
.32136 .63427 m .32149 .63309 L .32233 .63341 L F
.32136 .63427 m .3223 .6342 L .32149 .63309 L F
.666 .139 0 r
.32188 .63363 m .3223 .6342 L .32161 .63373 L F
.32188 .63363 m .32161 .63373 L .3209 .63324 L F
.771 .658 .737 r
.32136 .63427 m .32186 .639 L .32409 .6355 L F
.32186 .639 m .32188 .63918 L .322 .63899 L F
.32186 .639 m .322 .63899 L .32409 .6355 L F
0 0 0 r
.32323 .63879 m .322 .63899 L .32142 .63902 L F
.322 .63899 m .32196 .63899 L .32194 .63899 L F
.322 .63899 m .32194 .63899 L .32142 .63902 L F
.32196 .63899 m .32192 .639 L .32189 .639 L F
.32196 .63899 m .32189 .639 L .32142 .63902 L F
.589 .523 .749 r
.31949 .63925 m .32188 .63918 L .32186 .639 L F
0 0 0 r
.32142 .63902 m .32196 .639 L .31949 .63925 L F
.589 .523 .749 r
.31949 .63925 m .32186 .639 L .32136 .63427 L F
.933 .96 .763 r
.32409 .6355 m .322 .63899 L .32323 .63879 L F
.322 .63899 m .32188 .63918 L .32323 .63879 L F
0 0 0 r
.32323 .63879 m .32196 .639 L .32192 .639 L F
.32323 .63879 m .32246 .63895 L .32196 .639 L F
.966 .741 .547 r
.3192 .63728 m .31724 .63895 L .31984 .63695 L F
0 .074 .633 r
.3192 .63728 m .31984 .63695 L .31984 .63627 L F
.927 .731 .618 r
.59446 .62778 m .59612 .62863 L .59564 .63093 L F
.751 .44 .458 r
.54793 .61563 m .55143 .61621 L .55126 .61421 L F
.78 .727 .804 r
.5498 .61142 m .5536 .61137 L .55138 .61178 L F
.54 .345 .566 r
.55126 .61421 m .5536 .61137 L .5498 .61142 L F
.55126 .61421 m .55361 .61379 L .5536 .61137 L F
.722 .555 .664 r
.55143 .61621 m .55361 .61379 L .55126 .61421 L F
.578 .395 .598 r
.55361 .61379 m .55759 .61037 L .5536 .61137 L F
.969 .918 .698 r
.2875 .8246 m .28609 .8243 L .28507 .82527 L F
.686 .65 .809 r
.50713 .66257 m .50879 .6593 L .5069 .66001 L F
.50713 .66257 m .51001 .66236 L .50879 .6593 L F
.493 .034 .091 r
.50854 .66473 m .51001 .66236 L .50713 .66257 L F
.18 0 .142 r
.34486 .60603 m .34415 .60764 L .34294 .60741 L F
.738 .632 .741 r
.80351 .51982 m .80048 .51873 L .80289 .51824 L F
.80351 .51982 m .80307 .51869 L .80289 .519 L F
.80307 .51869 m .80289 .51824 L .80289 .519 L F
.604 .305 .435 r
.80289 .51824 m .80556 .52005 L .80289 .519 L F
0 .222 .693 r
.80473 .51918 m .80556 .52005 L .80289 .51824 L F
0 .467 .864 r
.80289 .519 m .80556 .52005 L .80473 .51918 L F
.80289 .519 m .80473 .51918 L .80249 .5197 L F
.904 .915 .818 r
.80002 .52098 m .80103 .52194 L .80289 .519 L F
0 .467 .864 r
.80289 .519 m .80249 .5197 L .80213 .51979 L F
.919 .97 .78 r
.80103 .52194 m .80351 .51982 L .80289 .519 L F
0 0 .23 r
.55826 .61037 m .55827 .6128 L .55761 .61439 L F
.757 .994 .816 r
.55761 .61439 m .55556 .61528 L .55628 .61618 L F
.578 .395 .598 r
.55361 .61379 m .55681 .61431 L .55759 .61037 L F
.35 .197 .528 r
.55716 .614 m .55826 .61037 L .55759 .61037 L F
.757 .994 .816 r
.55761 .61439 m .55803 .61338 L .55677 .61441 L F
.35 .197 .528 r
.55712 .61436 m .55725 .6139 L .55716 .614 L F
.55725 .6139 m .55826 .61037 L .55716 .614 L F
.757 .994 .816 r
.55625 .61498 m .55677 .61441 L .55592 .61512 L F
.55761 .61439 m .55677 .61441 L .55625 .61498 L F
.35 .197 .528 r
.55725 .6139 m .55827 .6128 L .55826 .61037 L F
.757 .994 .816 r
.55803 .61338 m .55814 .61311 L .55716 .614 L F
.55803 .61338 m .55716 .614 L .55701 .61416 L F
.35 .197 .528 r
.55712 .61436 m .55827 .6128 L .55725 .6139 L F
.757 .994 .816 r
.55701 .61416 m .55716 .614 L .55681 .61431 L F
.55803 .61338 m .55681 .61431 L .55592 .61512 L F
.577 .285 .435 r
.55556 .61528 m .55712 .61436 L .55681 .61431 L F
.55556 .61528 m .55681 .61431 L .55361 .61379 L F
.578 .395 .598 r
.55681 .61431 m .55712 .61436 L .55716 .614 L F
.55681 .61431 m .55716 .614 L .55759 .61037 L F
.757 .994 .816 r
.55592 .61512 m .55827 .6128 L .55556 .61528 L F
.55814 .61311 m .55827 .6128 L .55592 .61512 L F
.429 0 .03 r
.50152 .68918 m .50263 .69054 L .50377 .68948 L F
.50152 .68918 m .50015 .69079 L .50263 .69054 L F
.515 0 0 r
.47129 .71746 m .47421 .71918 L .47472 .7181 L F
.57 .032 0 r
.47565 .71927 m .47472 .7181 L .47421 .71918 L F
.47565 .71927 m .4769 .72014 L .47472 .7181 L F
.799 .306 0 r
.56273 .6369 m .56116 .63623 L .56006 .63485 L F
.766 .334 0 r
.56273 .6369 m .56315 .63848 L .56116 .63623 L F
.56273 .6369 m .56416 .63966 L .56315 .63848 L F
.54 .1 .152 r
.51329 .6896 m .50969 .69114 L .51047 .6887 L F
.51329 .6896 m .51266 .69118 L .50969 .69114 L F
.523 .084 .146 r
.51565 .69079 m .51266 .69118 L .51329 .6896 L F
.666 .402 .512 r
.44083 .6135 m .43661 .61635 L .43684 .61461 L F
.342 .695 .982 r
.41512 .58671 m .41711 .58675 L .41654 .58787 L F
.257 .595 .95 r
.41711 .58675 m .41835 .58806 L .41654 .58787 L F
.553 .875 .993 r
.51031 .68626 m .51074 .68492 L .512 .68522 L F
0 0 .121 r
.51031 .68626 m .51048 .68724 L .51074 .68492 L F
.51031 .68626 m .51047 .6887 L .51048 .68724 L F
.432 .1 .3 r
.412 .62272 m .41099 .62528 L .40869 .62582 L F
.424 .091 .296 r
.4131 .62479 m .412 .62272 L .41432 .62253 L F
.4131 .62479 m .41099 .62528 L .412 .62272 L F
.592 .877 .993 r
.73149 .47621 m .73301 .47461 L .7303 .47548 L F
.73149 .47621 m .73301 .47461 L .7303 .47548 L F
.77 .677 .761 r
.22487 .5618 m .22091 .56201 L .22312 .55915 L F
.345 0 .143 r
.22487 .5618 m .22126 .56424 L .22091 .56201 L F
.22487 .5618 m .22346 .56382 L .22126 .56424 L F
.44 .506 .831 r
.22544 .55883 m .22487 .5618 L .22312 .55915 L F
.22544 .55883 m .22685 .56262 L .22487 .5618 L F
.29 .777 .709 r
.22685 .56262 m .22346 .56382 L .22487 .5618 L F
0 0 .307 r
.49682 .68051 m .49764 .68176 L .49932 .68247 L F
.49682 .68051 m .49689 .68341 L .49764 .68176 L F
.375 0 0 r
.52427 .63359 m .5278 .6337 L .52562 .63453 L F
.586 .909 .663 r
.60719 .66577 m .60412 .66819 L .60468 .66847 L F
.382 .15 .434 r
.49099 .63081 m .49125 .62861 L .4889 .63151 L F
.39 .169 .453 r
.49099 .63081 m .4889 .63151 L .48862 .63375 L F
0 0 .521 r
.23074 .5587 m .2306 .56158 L .22914 .55895 L F
.2306 .56158 m .2303 .56172 L .22914 .55895 L F
.2306 .56158 m .23121 .56126 L .23056 .56234 L F
.23074 .5587 m .23121 .56126 L .2306 .56158 L F
.55 .495 .747 r
.23318 .56041 m .23121 .56126 L .23074 .5587 L F
.229 0 0 r
.23231 .56079 m .23154 .56109 L .23121 .56126 L F
.806 .714 .763 r
.22914 .55895 m .22685 .56262 L .22544 .55883 L F
0 0 0 r
.23121 .56126 m .22681 .56253 L .22909 .56201 L F
.23121 .56126 m .22904 .56206 L .22681 .56253 L F
.229 0 0 r
.23154 .56109 m .22904 .56206 L .23121 .56126 L F
.23318 .56041 m .23273 .56059 L .23231 .56079 L F
.23273 .56059 m .22932 .56195 L .23231 .56079 L F
0 0 .521 r
.2306 .56158 m .23056 .56234 L .2303 .56172 L F
.531 .891 .976 r
.23121 .56126 m .22909 .56201 L .23056 .56234 L F
.229 0 0 r
.22932 .56195 m .22904 .56206 L .22924 .56199 L F
.22932 .56195 m .22924 .56199 L .23231 .56079 L F
.23318 .56041 m .2313 .56172 L .22904 .56206 L F
.445 .497 .818 r
.23126 .5577 m .23318 .56041 L .23074 .5587 L F
.2317 .55686 m .23209 .55781 L .23126 .5577 L F
.23209 .55781 m .23318 .56041 L .23126 .5577 L F
.761 .667 .759 r
.23294 .55707 m .23318 .56041 L .2317 .55686 L F
.497 .246 .465 r
.23294 .55707 m .23265 .55789 L .23312 .55956 L F
.23265 .55789 m .2313 .56172 L .23312 .55956 L F
.23312 .55956 m .2313 .56172 L .23318 .56041 L F
.23265 .55789 m .23332 .56026 L .23155 .56101 L F
.23294 .55707 m .23304 .55794 L .23265 .55789 L F
.23304 .55794 m .23332 .56026 L .23265 .55789 L F
.23155 .56101 m .23345 .56136 L .2313 .56172 L F
.23332 .56026 m .23345 .56136 L .23155 .56101 L F
.544 .757 .975 r
.19988 .55934 m .20039 .55744 L .19838 .5577 L F
.19988 .55934 m .20192 .55883 L .20039 .55744 L F
.447 .218 .472 r
.19988 .55934 m .19942 .56177 L .20192 .55883 L F
.205 .302 .743 r
.22449 .55492 m .22297 .55556 L .22202 .55429 L F
.22449 .55492 m .22406 .55648 L .22297 .55556 L F
.493 .359 .627 r
.22406 .55648 m .22312 .55915 L .22297 .55556 L F
.449 .218 .47 r
.4448 .69438 m .4427 .69477 L .44237 .69737 L F
.399 0 0 r
.48582 .64136 m .48487 .64047 L .48466 .64258 L F
.071 .116 .603 r
.54165 .6804 m .54222 .67728 L .54376 .67736 L F
.54165 .6804 m .54283 .67944 L .54222 .67728 L F
.642 .499 .672 r
.54551 .68236 m .54184 .68361 L .54165 .6804 L F
.438 .239 .512 r
.54083 .68227 m .54283 .67944 L .54165 .6804 L F
.754 .474 .509 r
.60696 .60543 m .60811 .60757 L .60829 .60611 L F
.391 .269 .592 r
.2152 .59093 m .21512 .59341 L .21351 .59386 L F
.314 .072 .378 r
.21512 .59341 m .21288 .59623 L .21351 .59386 L F
.546 .409 .646 r
.49078 .65938 m .48861 .65752 L .49231 .65729 L F
.49078 .65938 m .48841 .65996 L .48861 .65752 L F
.413 .772 .995 r
.40776 .58464 m .40679 .58573 L .40535 .58466 L F
.40776 .58464 m .40907 .58552 L .40679 .58573 L F
.62 .363 .507 r
.39499 .61875 m .39787 .61656 L .39571 .61712 L F
.443 0 .035 r
.47975 .6859 m .47893 .68703 L .4765 .6866 L F
.539 .489 .749 r
.48126 .6828 m .48194 .68571 L .47975 .6859 L F
.521 .12 .223 r
.48194 .68571 m .47893 .68703 L .47975 .6859 L F
.687 .18 0 r
.56304 .62416 m .56231 .62266 L .5607 .62215 L F
.56304 .62416 m .5642 .62505 L .56231 .62266 L F
.127 0 0 r
.38089 .59406 m .37715 .59443 L .3786 .59396 L F
.777 .702 .781 r
.31294 .61953 m .31521 .61993 L .31403 .61948 L F
.31251 .6197 m .31521 .61993 L .31294 .61953 L F
.724 .957 .947 r
.31598 .61827 m .31403 .61948 L .31521 .61993 L F
.124 .248 .721 r
.31521 .61993 m .3172 .6219 L .31598 .61827 L F
.741 .807 .905 r
.31209 .61815 m .31403 .61948 L .31598 .61827 L F
.145 .404 .851 r
.3159 .61936 m .31562 .62236 L .31441 .61891 L F
.31466 .61881 m .31441 .61891 L .31433 .61867 L F
.3159 .61936 m .31441 .61891 L .31466 .61881 L F
.777 .702 .781 r
.31123 .61959 m .31251 .6197 L .31294 .61953 L F
.527 .524 .795 r
.80732 .51599 m .80892 .51593 L .80724 .51182 L F
.971 .812 .628 r
.4669 .67387 m .46827 .67476 L .46813 .67193 L F
.074 .253 .743 r
.46913 .67343 m .46827 .67476 L .4669 .67387 L F
.46913 .67343 m .47038 .67627 L .46827 .67476 L F
.725 .865 .948 r
.75555 .52112 m .75854 .52099 L .75777 .52003 L F
.664 .879 .978 r
.76082 .51866 m .75854 .52099 L .76103 .52013 L F
.76082 .51866 m .75777 .52003 L .75854 .52099 L F
.57 .623 .866 r
.50258 .68056 m .5051 .68042 L .50318 .67739 L F
.514 .432 .701 r
.22126 .56424 m .22171 .56769 L .21979 .56819 L F
.52 .397 .652 r
.22171 .56769 m .21997 .57066 L .21979 .56819 L F
.274 .497 .89 r
.42132 .58889 m .4206 .59017 L .41835 .58806 L F
.42132 .58889 m .4221 .59054 L .4206 .59017 L F
.647 .839 .974 r
.77664 .50729 m .77428 .50822 L .77318 .50704 L F
.642 .639 .831 r
.72791 .49148 m .72566 .49255 L .7248 .48939 L F
.45 .207 .453 r
.4935 .62801 m .49125 .62861 L .49099 .63081 L F
.023 0 .087 r
.57931 .59716 m .57745 .59933 L .57733 .59701 L F
.403 .833 .956 r
.38673 .59304 m .38304 .59319 L .38454 .59318 L F
.481 .697 .964 r
.37107 .58147 m .37015 .58317 L .36887 .58229 L F
.37107 .58147 m .37221 .58288 L .37015 .58317 L F
.52 .627 .897 r
.73989 .51709 m .74148 .51471 L .73925 .51485 L F
.73989 .51709 m .7429 .51708 L .74148 .51471 L F
.883 .48 .255 r
.54376 .67736 m .54083 .67442 L .54272 .67477 L F
.54376 .67736 m .54222 .67728 L .54083 .67442 L F
0 .227 .748 r
.80354 .48557 m .80173 .48491 L .80185 .48331 L F
.80354 .48557 m .80397 .48695 L .80173 .48491 L F
.551 .625 .878 r
.58633 .67092 m .5887 .67564 L .59012 .67343 L F
.471 .352 .635 r
.30775 .59983 m .30974 .59936 L .30948 .59668 L F
.528 .437 .696 r
.30804 .602 m .30974 .59936 L .30775 .59983 L F
.804 .802 .849 r
.74941 .49426 m .75041 .49597 L .74788 .49533 L F
.83 .641 .646 r
.75063 .49822 m .74788 .49533 L .75041 .49597 L F
.779 .793 .864 r
.75253 .4939 m .75041 .49597 L .74941 .49426 L F
.673 .473 .607 r
.75334 .49711 m .75063 .49822 L .75041 .49597 L F
.4 .486 .832 r
.79496 .494 m .79655 .49176 L .79429 .49223 L F
.79496 .494 m .79778 .49521 L .79655 .49176 L F
.816 .603 .615 r
.58475 .59397 m .58655 .59691 L .58338 .59637 L F
.563 .142 .201 r
.53543 .61276 m .53806 .61309 L .53896 .61196 L F
.544 .391 .623 r
.53896 .61196 m .54127 .61143 L .54123 .60808 L F
.496 .137 .287 r
.53806 .61309 m .54127 .61143 L .53896 .61196 L F
.407 .209 .496 r
.39808 .61419 m .39982 .61592 L .40008 .61365 L F
.39808 .61419 m .39787 .61656 L .39982 .61592 L F
.627 .482 .665 r
.44819 .61029 m .44534 .61347 L .44546 .61115 L F
.25 .314 .734 r
.55019 .64494 m .5488 .64637 L .54789 .64288 L F
.816 .596 .605 r
.58338 .59637 m .58655 .59691 L .58644 .59939 L F
.812 .459 0 r
.56818 .64597 m .5675 .64518 L .56663 .64243 L F
0 0 .259 r
.56818 .64597 m .56853 .64686 L .5675 .64518 L F
.863 .431 .011 r
.56998 .64884 m .56906 .64822 L .56818 .64597 L F
0 0 .259 r
.56818 .64597 m .56906 .64822 L .56853 .64686 L F
.897 .732 .669 r
.48576 .66332 m .48738 .66547 L .48819 .66279 L F
.48576 .66332 m .48819 .66279 L .48834 .6628 L F
.619 .695 .898 r
.79981 .48364 m .79522 .48162 L .79767 .48075 L F
.464 .504 .815 r
.8003 .47984 m .79981 .48364 L .79767 .48075 L F
.8003 .47984 m .80185 .48331 L .79981 .48364 L F
.455 0 .075 r
.51425 .65985 m .51731 .66113 L .51513 .66189 L F
.51425 .65985 m .51804 .65958 L .51731 .66113 L F
.782 .825 .886 r
.32504 .63645 m .32703 .63511 L .32719 .63421 L F
.499 .217 .418 r
.51133 .65652 m .51405 .65422 L .51216 .655 L F
.578 .895 .627 r
.55407 .59503 m .55684 .59248 L .55576 .59372 L F
.137 .283 .75 r
.55684 .59248 m .55806 .5959 L .55576 .59372 L F
.514 .339 .581 r
.55576 .59372 m .55806 .5959 L .55582 .59677 L F
.148 0 0 r
.35935 .64319 m .35743 .64432 L .35531 .64463 L F
.47 .86 .659 r
.36049 .64224 m .35935 .64319 L .36103 .64218 L F
.36049 .64224 m .35743 .64432 L .35935 .64319 L F
.476 0 0 r
.33905 .58374 m .34138 .584 L .34302 .58277 L F
.241 0 0 r
.34138 .584 m .34522 .58262 L .34302 .58277 L F
.691 .457 .563 r
.30894 .61904 m .31123 .61959 L .31142 .61718 L F
0 .122 .655 r
.31142 .61718 m .31202 .61576 L .31034 .6138 L F
0 0 .209 r
.31142 .61718 m .31209 .61815 L .31202 .61576 L F
.31142 .61718 m .31123 .61959 L .31209 .61815 L F
.27 .018 .336 r
.47531 .65176 m .47298 .65472 L .47497 .65398 L F
.43 .193 .452 r
.47531 .65176 m .47497 .65398 L .47744 .65118 L F
.256 0 0 r
.77664 .50729 m .77883 .50753 L .78013 .50737 L F
.034 .593 .808 r
.78114 .50723 m .78013 .50737 L .77883 .50753 L F
.78114 .50723 m .78259 .50759 L .78013 .50737 L F
.512 .536 .818 r
.53258 .61093 m .53338 .60734 L .53203 .60846 L F
0 0 .398 r
.53219 .60897 m .53258 .61093 L .53203 .60846 L F
.512 .536 .818 r
.53258 .61093 m .53464 .61069 L .53338 .60734 L F
.818 .569 .563 r
.60387 .60485 m .60522 .6075 L .60696 .60543 L F
.754 .474 .509 r
.60696 .60543 m .60522 .6075 L .60811 .60757 L F
.296 0 .262 r
.47298 .65472 m .4703 .65727 L .47228 .65649 L F
.306 .003 .276 r
.47298 .65472 m .47228 .65649 L .47497 .65398 L F
.581 .723 .94 r
.80281 .50117 m .80434 .49862 L .80114 .49823 L F
.80281 .50117 m .80508 .50046 L .80434 .49862 L F
.589 .677 .901 r
.34819 .62014 m .34502 .61892 L .3464 .61677 L F
.516 .589 .866 r
.3502 .61979 m .34819 .62014 L .3464 .61677 L F
.24 0 0 r
.38738 .63386 m .3856 .63543 L .38352 .63576 L F
.244 0 0 r
.38738 .63386 m .38802 .63493 L .3856 .63543 L F
.38738 .63386 m .38954 .63363 L .38802 .63493 L F
.662 .554 .722 r
.25918 .84501 m .25946 .84476 L .25912 .84478 L F
.891 .466 .134 r
.56548 .64034 m .56494 .64154 L .56416 .63966 L F
.866 .422 .116 r
.56548 .64034 m .56663 .64243 L .56494 .64154 L F
0 .127 .649 r
.55384 .66395 m .55572 .66571 L .55458 .66476 L F
.682 .515 .654 r
.75272 .49066 m .75253 .4939 L .75507 .49008 L F
.128 .657 .871 r
.20733 .5466 m .21115 .54708 L .20932 .54707 L F
.507 .832 .999 r
.57714 .6335 m .57686 .6343 L .57495 .63379 L F
.811 .793 .836 r
.30922 .63937 m .31098 .64079 L .31201 .63979 L F
.634 .437 .597 r
.51775 .66872 m .5198 .669 L .5201 .66591 L F
0 0 .282 r
.5201 .66591 m .5198 .669 L .52109 .66722 L F
.709 .836 .943 r
.46153 .70018 m .45783 .69992 L .46021 .69897 L F
.449 .755 .994 r
.4624 .69867 m .46153 .70018 L .46021 .69897 L F
.4624 .69867 m .46582 .70039 L .46153 .70018 L F
0 0 .5 r
.57346 .66016 m .57385 .65953 L .57224 .65687 L F
0 0 .417 r
.57587 .6623 m .57385 .65953 L .57346 .66016 L F
.473 .66 .943 r
.7906 .49005 m .79203 .49235 L .79429 .49223 L F
.545 .198 .331 r
.42229 .62108 m .42032 .61941 L .42251 .61963 L F
.42229 .62108 m .41893 .62202 L .42032 .61941 L F
.356 .327 .689 r
.4846 .67366 m .48247 .67478 L .48291 .6734 L F
.337 .302 .672 r
.48517 .67538 m .48247 .67478 L .4846 .67366 L F
.48517 .67538 m .48334 .67722 L .48247 .67478 L F
.408 .832 .963 r
.39635 .5931 m .39478 .59268 L .39256 .59314 L F
.439 .847 .968 r
.39701 .59214 m .39635 .5931 L .39805 .5927 L F
.39701 .59214 m .39478 .59268 L .39635 .5931 L F
.754 .634 .727 r
.7295 .49563 m .73028 .49895 L .72704 .4985 L F
.71 .173 0 r
.73079 .50117 m .72704 .4985 L .73028 .49895 L F
.653 .683 .866 r
.73171 .49581 m .73028 .49895 L .7295 .49563 L F
.73171 .49581 m .73302 .49862 L .73028 .49895 L F
.65 .521 .692 r
.73302 .49862 m .73079 .50117 L .73028 .49895 L F
.666 .402 .512 r
.44083 .6135 m .43889 .61659 L .43661 .61635 L F
.691 .433 .528 r
.44248 .61632 m .44083 .6135 L .44257 .61394 L F
.44248 .61632 m .43889 .61659 L .44083 .6135 L F
.433 .418 .743 r
.51001 .66236 m .51029 .65877 L .50879 .6593 L F
.451 .494 .812 r
.4424 .60423 m .44122 .60677 L .44036 .60456 L F
.4424 .60423 m .44351 .60718 L .44122 .60677 L F
.442 .789 .998 r
.56633 .62488 m .56549 .62605 L .5642 .62505 L F
.563 .721 .947 r
.78058 .52673 m .78158 .52843 L .78403 .52791 L F
.921 .769 .676 r
.59312 .61366 m .5941 .61718 L .59294 .61614 L F
.934 .654 .486 r
.5941 .61718 m .59247 .61862 L .59294 .61614 L F
.5941 .61718 m .59424 .61966 L .59247 .61862 L F
.922 .583 .378 r
.46381 .71747 m .46215 .71695 L .46174 .71478 L F
.451 0 0 r
.46555 .71863 m .46215 .71695 L .46381 .71747 L F
.966 .77 .332 r
.59326 .6253 m .59275 .62453 L .59274 .62189 L F
.863 .489 .336 r
.59326 .6253 m .5924 .62767 L .59275 .62453 L F
.59326 .6253 m .59446 .62778 L .5924 .62767 L F
.568 .087 .073 r
.48288 .71831 m .48523 .71964 L .48743 .71823 L F
.891 .89 .823 r
.48523 .71964 m .48882 .71743 L .48743 .71823 L F
.628 .13 0 r
.80521 .48863 m .80484 .48795 L .80397 .48695 L F
.80521 .48863 m .80626 .48959 L .80484 .48795 L F
.633 .621 .821 r
.55232 .67444 m .54896 .67202 L .55144 .67262 L F
0 0 .003 r
.55436 .67118 m .55232 .67444 L .55144 .67262 L F
.625 .153 .112 r
.52296 .66525 m .52109 .66722 L .52483 .66744 L F
.741 .664 .775 r
.19753 .56486 m .20096 .56528 L .19942 .56177 L F
0 .074 .634 r
.20096 .56528 m .20108 .56384 L .19942 .56177 L F
.208 .522 .918 r
.20149 .56536 m .2015 .56435 L .20108 .56384 L F
.519 .225 .408 r
.20096 .56528 m .20364 .56744 L .20244 .56551 L F
.839 .941 .891 r
.20135 .5665 m .2014 .56449 L .2015 .56408 L F
.218 .511 .91 r
.20244 .56551 m .20151 .56406 L .20108 .56384 L F
.839 .941 .891 r
.2015 .56415 m .2015 .56408 L .20151 .56406 L F
.20135 .5665 m .2015 .56408 L .2015 .56415 L F
.208 .522 .918 r
.20096 .56528 m .20149 .56536 L .20108 .56384 L F
.20149 .56536 m .20244 .56551 L .2015 .56435 L F
.61 .856 .99 r
.5631 .60012 m .56399 .59831 L .56187 .59942 L F
.5631 .60012 m .56527 .59928 L .56399 .59831 L F
.493 .834 .998 r
.51624 .72008 m .5175 .72083 L .51396 .72077 L F
.381 .139 .417 r
.51624 .72008 m .51396 .72077 L .5175 .72083 L F
.51624 .72008 m .5175 .72083 L .5172 .72301 L F
.987 .8 .565 r
.51624 .72008 m .5172 .72301 L .5175 .72083 L F
.586 .909 .663 r
.60719 .66577 m .60598 .66653 L .60412 .66819 L F
.536 .877 .625 r
.6101 .66335 m .60849 .66449 L .60719 .66577 L F
.543 .889 .653 r
.60849 .66449 m .60598 .66653 L .60719 .66577 L F
.526 .197 .353 r
.76785 .4927 m .76742 .49491 L .76479 .4952 L F
.452 .112 .296 r
.77042 .49236 m .76742 .49491 L .76785 .4927 L F
.396 0 0 r
.33683 .63739 m .335 .63702 L .33313 .63614 L F
.706 .956 .949 r
.33743 .63564 m .335 .63702 L .33683 .63739 L F
.977 .816 .617 r
.33683 .63739 m .33878 .63887 L .33743 .63564 L F
.33683 .63739 m .33659 .63815 L .33878 .63887 L F
.33683 .63739 m .33602 .63974 L .335 .63702 L F
.33683 .63739 m .335 .63702 L .33659 .63815 L F
.46 .188 .413 r
.30948 .59668 m .31183 .59615 L .3122 .59376 L F
.436 .847 .67 r
.31463 .59225 m .3122 .59376 L .31398 .59262 L F
.5 .223 .424 r
.3122 .59376 m .31413 .59562 L .31398 .59262 L F
.3122 .59376 m .31183 .59615 L .31413 .59562 L F
.48 .36 .639 r
.49966 .64007 m .5 .64272 L .50207 .64211 L F
.50207 .64211 m .5 .64272 L .49966 .64007 L F
.49966 .64007 m .5 .64272 L .50207 .64211 L F
.871 .611 .544 r
.61114 .62286 m .60916 .6197 L .6093 .62218 L F
.859 .603 .55 r
.60917 .62465 m .61114 .62286 L .6093 .62218 L F
.60917 .62465 m .6111 .62521 L .61114 .62286 L F
.682 .227 .165 r
.23871 .76007 m .24027 .75878 L .23849 .7599 L F
.23871 .76007 m .24223 .76045 L .24027 .75878 L F
.676 .368 .445 r
.40572 .61288 m .4094 .61085 L .40622 .61173 L F
0 .026 .521 r
.79783 .52369 m .79671 .52259 L .79489 .52108 L F
.816 .729 .769 r
.80048 .51873 m .79783 .52369 L .79713 .51855 L F
.856 .545 .46 r
.52766 .68662 m .52376 .68314 L .52548 .68218 L F
.52766 .68662 m .52431 .6859 L .52376 .68314 L F
.72 .626 .752 r
.52737 .68827 m .52431 .6859 L .52766 .68662 L F
.686 .649 .808 r
.5294 .68431 m .52766 .68662 L .52548 .68218 L F
.902 .976 .683 r
.61011 .66154 m .60849 .66449 L .6101 .66335 L F
.792 .712 .776 r
.75527 .50436 m .75195 .50397 L .75419 .50105 L F
.817 .713 .751 r
.75527 .50436 m .75135 .5061 L .75195 .50397 L F
.75527 .50436 m .75379 .50753 L .75135 .5061 L F
.653 .635 .82 r
.75782 .50372 m .75527 .50436 L .75419 .50105 L F
.647 .679 .866 r
.43668 .59913 m .43279 .59717 L .43507 .59664 L F
.566 .677 .914 r
.43717 .59601 m .43668 .59913 L .43507 .59664 L F
.43717 .59601 m .43888 .5987 L .43668 .59913 L F
.809 .7 .745 r
.53285 .64524 m .53454 .64845 L .53035 .64795 L F
.356 .257 .604 r
.53038 .65229 m .53183 .64972 L .53135 .65051 L F
.53183 .64972 m .53237 .64877 L .53188 .64961 L F
.53183 .64972 m .53188 .64961 L .53135 .65051 L F
.37 .203 .52 r
.53219 .64944 m .532 .64929 L .53454 .64845 L F
.532 .64929 m .53035 .64795 L .53244 .6482 L F
.532 .64929 m .53244 .6482 L .53454 .64845 L F
.477 .51 .813 r
.53525 .64521 m .53454 .64845 L .53285 .64524 L F
.53525 .64521 m .53656 .64821 L .53454 .64845 L F
.434 .145 .373 r
.57811 .58807 m .58042 .58742 L .58058 .58562 L F
.533 .186 .325 r
.58282 .58718 m .58058 .58562 L .58042 .58742 L F
.58282 .58718 m .58378 .58469 L .58058 .58562 L F
.988 .742 .464 r
.44731 .70593 m .44852 .70959 L .44723 .70863 L F
.313 .575 .933 r
.44852 .70959 m .44944 .70819 L .44723 .70863 L F
.44852 .70959 m .45126 .71047 L .44944 .70819 L F
.827 .505 0 r
.56409 .5935 m .56464 .59557 L .56502 .59612 L F
.637 .648 .844 r
.56502 .59612 m .56722 .59348 L .56409 .5935 L F
.56502 .59612 m .56824 .59535 L .56722 .59348 L F
.874 .643 .587 r
.75379 .50753 m .75321 .50995 L .75135 .5061 L F
.63 .835 .979 r
.75215 .52084 m .75312 .52196 L .75555 .52112 L F
.623 .579 .783 r
.74717 .50986 m .74476 .51074 L .74358 .50703 L F
.959 .647 .391 r
.61282 .62795 m .6111 .62521 L .61088 .62785 L F
.918 .717 .615 r
.61071 .63034 m .61282 .62795 L .61088 .62785 L F
.61071 .63034 m .61282 .63113 L .61282 .62795 L F
.293 .036 .342 r
.21288 .59623 m .21035 .5993 L .21086 .59679 L F
.669 .374 .463 r
.5127 .6471 m .50924 .64618 L .51278 .64505 L F
.778 .617 .681 r
.5211 .66179 m .52515 .65932 L .52271 .66109 L F
.563 .549 .796 r
.52536 .66274 m .52271 .66109 L .52515 .65932 L F
.795 .447 .399 r
.5787 .65402 m .58017 .6564 L .58106 .65455 L F
0 0 0 r
.58106 .65455 m .58148 .65426 L .58301 .65376 L F
.58106 .65455 m .58017 .6564 L .58148 .65426 L F
.035 .331 .813 r
.79033 .52213 m .78954 .52314 L .78847 .52224 L F
.953 .747 .589 r
.78964 .52288 m .78954 .52314 L .79033 .52213 L F
.78788 .52482 m .78954 .52314 L .78964 .52288 L F
0 .149 .648 r
.78954 .52314 m .79026 .52402 L .78949 .52326 L F
.78954 .52314 m .78949 .52326 L .78847 .52224 L F
.999 .789 .474 r
.78908 .52628 m .79002 .52722 L .79026 .52402 L F
0 0 0 r
.78227 .48973 m .78128 .49003 L .77918 .49046 L F
.379 0 0 r
.78227 .48973 m .78485 .49006 L .78128 .49003 L F
.637 .793 .957 r
.39805 .5927 m .40213 .59314 L .40049 .59117 L F
.564 .69 .925 r
.40213 .59314 m .40249 .59023 L .40049 .59117 L F
.40213 .59314 m .40466 .59268 L .40249 .59023 L F
.618 .067 0 r
.53574 .63407 m .53993 .63569 L .53716 .63485 L F
.351 0 .015 r
.57431 .58929 m .57233 .58857 L .57185 .5899 L F
.977 .677 .354 r
.53746 .66787 m .53777 .67046 L .53897 .67018 L F
.782 .542 .574 r
.53777 .67046 m .54134 .66846 L .53897 .67018 L F
0 0 0 r
.54722 .65146 m .54587 .65329 L .54424 .65405 L F
.792 .569 .599 r
.54937 .651 m .54587 .65329 L .54722 .65146 L F
.092 0 .331 r
.49007 .66172 m .48841 .65996 L .49078 .65938 L F
.49007 .66172 m .48834 .6628 L .48841 .65996 L F
.096 .651 .789 r
.34522 .58262 m .34741 .58254 L .34888 .58263 L F
.296 0 0 r
.34741 .58254 m .35117 .58257 L .34888 .58263 L F
.385 .548 .894 r
.32703 .63511 m .32977 .63551 L .32719 .63421 L F
.32703 .63511 m .33072 .63735 L .32977 .63551 L F
.982 .772 .547 r
.6078 .61897 m .60916 .6197 L .60804 .6164 L F
.974 .682 .406 r
.6078 .61897 m .6093 .62218 L .60916 .6197 L F
.586 .244 .357 r
.51924 .68914 m .52147 .69091 L .51919 .69078 L F
.594 .47 .681 r
.52124 .68614 m .5218 .68884 L .51924 .68914 L F
.539 .265 .447 r
.5218 .68884 m .52147 .69091 L .51924 .68914 L F
.999 .789 .465 r
.45483 .69694 m .4553 .69501 L .45646 .69383 L F
.259 .737 .935 r
.37221 .58288 m .37454 .58273 L .37595 .58328 L F
.257 .721 .949 r
.37454 .58273 m .37801 .58325 L .37595 .58328 L F
.941 .58 .198 r
.56998 .64884 m .57072 .65117 L .56906 .64822 L F
.331 .76 .972 r
.39709 .584 m .39376 .5835 L .39593 .58324 L F
.279 .748 .943 r
.39593 .58324 m .39948 .58364 L .39709 .584 L F
.489 .039 .109 r
.38139 .62294 m .38323 .62384 L .38457 .62222 L F
.367 0 .076 r
.38323 .62384 m .38687 .62174 L .38457 .62222 L F
.266 .188 .579 r
.54123 .60808 m .54287 .60774 L .5422 .60505 L F
.847 .5 .397 r
.5442 .61107 m .54123 .60808 L .54127 .61143 L F
.249 0 0 r
.54045 .61297 m .5442 .61107 L .54127 .61143 L F
.847 .5 .397 r
.5442 .61107 m .54271 .61153 L .54123 .60808 L F
.277 .233 .628 r
.54123 .60808 m .54271 .61153 L .54287 .60774 L F
.135 .567 .925 r
.27508 .68288 m .2772 .68338 L .27514 .68199 L F
.27508 .68288 m .2772 .68338 L .27514 .68199 L F
.678 .541 .691 r
.75749 .48975 m .75927 .49313 L .76102 .4899 L F
.355 .032 .272 r
.4673 .65982 m .46942 .65957 L .4703 .65727 L F
.45 .163 .385 r
.46942 .65957 m .47228 .65649 L .4703 .65727 L F
.601 .56 .78 r
.75321 .50995 m .75093 .5111 L .74922 .50812 L F
.227 .698 .941 r
.39035 .59372 m .38888 .59308 L .38673 .59304 L F
.537 .861 .996 r
.39113 .59242 m .39035 .59372 L .39256 .59314 L F
.39113 .59242 m .38888 .59308 L .39035 .59372 L F
.326 .392 .777 r
.76353 .48959 m .76468 .49304 L .76686 .49154 L F
0 0 0 r
.76686 .49154 m .76468 .49304 L .7652 .49331 L F
.458 .833 .591 r
.50559 .64687 m .50518 .6472 L .50685 .64587 L F
.2 .667 .94 r
.50909 .64773 m .50559 .64687 L .50685 .64587 L F
.121 .64 .886 r
.50559 .64687 m .50771 .64702 L .50584 .64666 L F
.639 .602 .796 r
.5019 .64449 m .50379 .64826 L .50559 .64687 L F
.5019 .64449 m .50559 .64687 L .50418 .64635 L F
.121 .64 .886 r
.50559 .64687 m .50584 .64666 L .50418 .64635 L F
.458 .833 .591 r
.50559 .64687 m .50409 .64807 L .50518 .6472 L F
.582 .298 .451 r
.50924 .64618 m .50909 .64773 L .50685 .64587 L F
.585 .19 .261 r
.51434 .68535 m .51678 .68539 L .51797 .68362 L F
.67 .288 .314 r
.51678 .68539 m .51997 .68565 L .51797 .68362 L F
.695 .153 0 r
.51797 .68362 m .52124 .68614 L .52136 .68361 L F
.493 .179 .363 r
.58535 .58717 m .58378 .58469 L .58282 .58718 L F
.58535 .58717 m .58616 .58448 L .58378 .58469 L F
.136 0 .086 r
.21681 .58262 m .21556 .58469 L .21392 .58524 L F
.268 0 .165 r
.21786 .5836 m .21681 .58262 L .21859 .58171 L F
.21786 .5836 m .21556 .58469 L .21681 .58262 L F
.597 .673 .893 r
.76607 .50371 m .76485 .50666 L .7638 .50449 L F
.76607 .50371 m .76731 .506 L .76485 .50666 L F
.241 0 0 r
.39556 .63121 m .394 .63276 L .39176 .6332 L F
.341 0 .046 r
.3977 .63056 m .394 .63276 L .39556 .63121 L F
.71 .173 0 r
.73079 .50117 m .72925 .50071 L .72704 .4985 L F
.443 .236 .502 r
.73302 .49862 m .73305 .50073 L .73079 .50117 L F
.73302 .49862 m .73305 .50073 L .73079 .50117 L F
.564 .065 .028 r
.73305 .50073 m .72925 .50071 L .73079 .50117 L F
.184 0 0 r
.39994 .63004 m .40361 .6274 L .40218 .6296 L F
.212 0 0 r
.40361 .6274 m .40643 .62625 L .40584 .62715 L F
.284 0 .11 r
.40361 .6274 m .40441 .62925 L .40218 .6296 L F
.40361 .6274 m .40584 .62715 L .40441 .62925 L F
.631 .631 .832 r
.3464 .61677 m .34502 .61892 L .34386 .61644 L F
.234 .549 .93 r
.47898 .68325 m .47971 .68226 L .47825 .68202 L F
0 .289 .687 r
.32719 .63421 m .32746 .63417 L .32555 .63447 L F
.32719 .63421 m .32977 .63551 L .32746 .63417 L F
.805 .591 .612 r
.5604 .59293 m .56409 .5935 L .56394 .59099 L F
.592 .388 .574 r
.56409 .5935 m .56655 .59093 L .56394 .59099 L F
.826 .652 .666 r
.55332 .61628 m .55572 .61788 L .55361 .61379 L F
.785 .62 .677 r
.55124 .61917 m .55572 .61788 L .55332 .61628 L F
.55124 .61917 m .55502 .61954 L .55572 .61788 L F
0 .177 .672 r
.55628 .61618 m .55361 .61379 L .55572 .61788 L F
.467 .266 .523 r
.55502 .61954 m .5572 .61907 L .55572 .61788 L F
.467 .624 .92 r
.77663 .52446 m .77822 .52692 L .78058 .52673 L F
.396 .108 .353 r
.46273 .66351 m .46435 .66481 L .46495 .66301 L F
.46273 .66351 m .4622 .66546 L .46435 .66481 L F
.384 0 .171 r
.31917 .5912 m .32154 .59076 L .32307 .58822 L F
.331 0 .141 r
.32307 .58822 m .32374 .5902 L .32512 .58755 L F
.32307 .58822 m .32154 .59076 L .32374 .5902 L F
.101 .535 .911 r
.36184 .62448 m .36136 .62511 L .3598 .62448 L F
.36184 .62448 m .36326 .62568 L .36136 .62511 L F
.728 .267 .154 r
.73883 .51073 m .73801 .5118 L .73558 .50962 L F
.675 .662 .829 r
.44426 .70098 m .44473 .69687 L .44237 .69737 L F
.44426 .70098 m .44719 .69994 L .44473 .69687 L F
.537 .252 .43 r
.54184 .68361 m .54161 .68572 L .53922 .68584 L F
.562 .289 .46 r
.54551 .68236 m .54161 .68572 L .54184 .68361 L F
.877 .734 .701 r
.59232 .60808 m .5934 .61129 L .59165 .61038 L F
.944 .71 .553 r
.59165 .61038 m .5934 .61129 L .59312 .61366 L F
.499 .586 .873 r
.57498 .60009 m .57088 .59688 L .57135 .60003 L F
.57498 .60009 m .57344 .59682 L .57088 .59688 L F
.706 .481 .58 r
.57088 .602 m .57498 .60009 L .57135 .60003 L F
.023 0 .087 r
.57931 .59716 m .5777 .59943 L .57745 .59933 L F
.694 .666 .818 r
.5777 .59943 m .57818 .59497 L .57595 .59609 L F
.06 0 0 r
.57818 .59497 m .57775 .5952 L .57595 .59609 L F
.57 .597 .841 r
.57498 .60009 m .57595 .59609 L .57363 .59723 L F
.532 .187 .329 r
.57745 .59933 m .57705 .60143 L .57498 .60009 L F
0 0 .05 r
.5777 .59943 m .57705 .60143 L .57745 .59933 L F
.57 .597 .841 r
.57498 .60009 m .5777 .59943 L .57595 .59609 L F
.06 0 0 r
.57775 .5952 m .57453 .59695 L .57595 .59609 L F
.57 .597 .841 r
.57363 .59723 m .57595 .59609 L .57344 .59682 L F
.468 .232 .472 r
.57498 .60009 m .57705 .60143 L .5777 .59943 L F
.85 .732 .733 r
.52107 .64789 m .52589 .64929 L .52367 .6468 L F
.825 .541 .509 r
.52116 .65061 m .52534 .65354 L .52589 .64929 L F
.851 .64 .616 r
.60648 .61313 m .60859 .61132 L .60677 .61075 L F
.60648 .61313 m .60829 .61388 L .60859 .61132 L F
.944 .723 .573 r
.27409 .8357 m .27457 .83277 L .27269 .83247 L F
.383 .425 .781 r
.27725 .83635 m .27457 .83277 L .27409 .8357 L F
.302 0 .009 r
.40643 .62625 m .40804 .62687 L .40584 .62715 L F
.40643 .62625 m .40869 .62582 L .40804 .62687 L F
.676 .368 .445 r
.40572 .61288 m .40818 .61342 L .4094 .61085 L F
.719 .418 .467 r
.4094 .61085 m .41171 .61337 L .41179 .61093 L F
.4094 .61085 m .40818 .61342 L .41171 .61337 L F
.561 .922 .748 r
.78339 .48197 m .78517 .48033 L .78596 .4813 L F
.347 .484 .855 r
.48269 .70798 m .48095 .70912 L .47984 .70657 L F
.42 .244 .535 r
.48227 .70879 m .48095 .70912 L .48269 .70798 L F
.48227 .70879 m .48109 .70991 L .48095 .70912 L F
.149 .179 .637 r
.46519 .70824 m .46559 .71121 L .46438 .71043 L F
.216 .162 .578 r
.46559 .71121 m .46595 .71406 L .46438 .71043 L F
.541 .32 .528 r
.49625 .65424 m .49394 .65705 L .49387 .65443 L F
.911 .714 .624 r
.59088 .5997 m .59134 .59929 L .59058 .60199 L F
.632 .689 .885 r
.45126 .71047 m .4522 .7121 L .45456 .71118 L F
.323 .471 .853 r
.79778 .49521 m .8001 .499 L .80114 .49823 L F
.04 .48 .883 r
.57742 .66928 m .5794 .66951 L .5771 .66791 L F
.57742 .66928 m .58074 .67061 L .5794 .66951 L F
.718 .584 .705 r
.5427 .67183 m .54272 .67477 L .54083 .67442 L F
.528 .437 .696 r
.30804 .602 m .31029 .60166 L .30974 .59936 L F
.467 .383 .678 r
.30804 .602 m .31098 .60355 L .31029 .60166 L F
.30804 .602 m .3084 .60562 L .31098 .60355 L F
.702 .858 .957 r
.79993 .5174 m .80048 .51873 L .79713 .51855 L F
.478 .818 .999 r
.80164 .51754 m .80048 .51873 L .79993 .5174 L F
.80164 .51754 m .80289 .51824 L .80048 .51873 L F
.215 .102 .502 r
.22205 .57014 m .2204 .57355 L .21997 .57066 L F
.22205 .57014 m .22204 .57261 L .2204 .57355 L F
.257 .119 .494 r
.22204 .57261 m .22055 .57532 L .2204 .57355 L F
.884 .718 .671 r
.5367 .67454 m .5328 .67603 L .53514 .67451 L F
.5367 .67454 m .53501 .67678 L .5328 .67603 L F
0 .23 .748 r
.53927 .67667 m .5367 .67454 L .54083 .67442 L F
0 0 .003 r
.55436 .67118 m .55333 .67361 L .55232 .67444 L F
.193 .324 .769 r
.55333 .67361 m .55483 .67655 L .55232 .67444 L F
.388 .35 .695 r
.55483 .67655 m .55293 .67685 L .55232 .67444 L F
.832 .482 0 r
.54647 .5985 m .54753 .601 L .54738 .59994 L F
.593 .571 .799 r
.54659 .59668 m .54738 .59994 L .55033 .59915 L F
.648 .395 .522 r
.54753 .601 m .55033 .59915 L .54738 .59994 L F
.512 .163 .313 r
.50703 .66777 m .50513 .66614 L .50507 .66874 L F
.482 .171 .362 r
.50513 .66614 m .50703 .66777 L .50507 .66874 L F
.614 .351 .495 r
.42844 .61682 m .43067 .61899 L .42826 .61894 L F
.65 .345 .441 r
.43084 .61713 m .43067 .61899 L .42844 .61682 L F
.234 0 .23 r
.3525 .59954 m .352 .60174 L .3498 .60235 L F
.477 .135 .307 r
.35401 .60125 m .3525 .59954 L .35468 .59899 L F
.35401 .60125 m .352 .60174 L .3525 .59954 L F
.184 0 .342 r
.45879 .69074 m .45708 .69188 L .45899 .68892 L F
.504 .333 .583 r
.45879 .69074 m .45646 .69383 L .45708 .69188 L F
.546 .377 .602 r
.51198 .72289 m .51216 .72411 L .51396 .72077 L F
.17 0 .339 r
.51396 .72077 m .51216 .72411 L .51361 .72282 L F
.51396 .72077 m .51216 .72411 L .51361 .72282 L F
.369 .253 .588 r
.51361 .72282 m .51216 .72411 L .51198 .72289 L F
0 0 0 r
.51216 .72411 m .51096 .72585 L .51361 .72282 L F
.338 .074 .358 r
.51198 .72289 m .51096 .72585 L .51361 .72282 L F
.51361 .72282 m .51096 .72585 L .51198 .72289 L F
.199 .713 .885 r
.78485 .49006 m .78813 .49021 L .7878 .48991 L F
.179 .698 .881 r
.7878 .48991 m .78813 .49021 L .7906 .49005 L F
0 .012 .576 r
.54169 .6365 m .54131 .63665 L .53993 .63569 L F
.127 .605 .917 r
.19838 .5577 m .19446 .55643 L .19614 .5575 L F
.093 0 0 r
.35117 .58257 m .35321 .58274 L .35495 .58272 L F
.535 .079 .115 r
.35321 .58274 m .35702 .58162 L .35495 .58272 L F
.76 .509 .554 r
.53696 .6888 m .53365 .68603 L .53613 .68541 L F
.53696 .6888 m .53346 .68883 L .53365 .68603 L F
.531 .333 .557 r
.53346 .68883 m .53613 .68541 L .53365 .68603 L F
.507 .295 .526 r
.5069 .66001 m .50879 .6593 L .50925 .65723 L F
.616 .397 .561 r
.50925 .65723 m .51029 .65877 L .51133 .65652 L F
.50925 .65723 m .50879 .6593 L .51029 .65877 L F
.05 .507 .89 r
.35839 .62338 m .35748 .62382 L .35574 .62271 L F
.35839 .62338 m .3598 .62448 L .35748 .62382 L F
.931 .904 .507 r
.45632 .68226 m .45572 .68609 L .45656 .68304 L F
.877 .78 .751 r
.45656 .68304 m .45636 .67978 L .45632 .68226 L F
.705 .718 .859 r
.4601 .68304 m .45572 .68609 L .45632 .68226 L F
.311 0 0 r
.36687 .59592 m .36554 .59649 L .36311 .59646 L F
.168 0 0 r
.36894 .59579 m .36554 .59649 L .36687 .59592 L F
.643 .405 .543 r
.4935 .62801 m .49608 .62804 L .49616 .6256 L F
.686 .448 .556 r
.49608 .62804 m .49947 .62549 L .49616 .6256 L F
.631 .704 .898 r
.53359 .60467 m .53696 .60531 L .53554 .60373 L F
.876 .793 .765 r
.53338 .60734 m .53696 .60531 L .53359 .60467 L F
.53338 .60734 m .53508 .60823 L .53696 .60531 L F
.744 .733 .842 r
.53554 .60373 m .53696 .60531 L .53934 .60274 L F
.458 .833 .591 r
.50559 .64687 m .50379 .64826 L .50409 .64807 L F
.236 .617 .956 r
.40399 .58347 m .40358 .5845 L .40194 .58341 L F
.40399 .58347 m .40535 .58466 L .40358 .5845 L F
0 .298 .78 r
.53721 .61959 m .53748 .61905 L .53621 .61835 L F
.081 .568 .899 r
.53721 .61959 m .53964 .6201 L .53748 .61905 L F
.533 .454 .713 r
.49046 .67105 m .48766 .66937 L .48962 .66741 L F
.49046 .67105 m .48839 .67191 L .48766 .66937 L F
0 0 0 r
.36729 .63984 m .36526 .64065 L .36266 .64125 L F
.063 0 0 r
.3695 .63934 m .36526 .64065 L .36729 .63984 L F
.429 .141 .372 r
.53284 .66184 m .53062 .66239 L .53112 .6605 L F
.453 .052 .188 r
.52927 .72084 m .52844 .72275 L .52563 .72308 L F
.267 .466 .868 r
.53033 .71949 m .52927 .72084 L .52923 .71928 L F
.108 0 .039 r
.53017 .72198 m .52927 .72084 L .53033 .71949 L F
.53017 .72198 m .52844 .72275 L .52927 .72084 L F
0 .039 .604 r
.57116 .65478 m .57224 .65687 L .57107 .65352 L F
.524 .577 .851 r
.47212 .66992 m .47366 .67167 L .47559 .67099 L F
.472 .26 .509 r
.47366 .67167 m .47574 .67343 L .47559 .67099 L F
.47366 .67167 m .47333 .67427 L .47574 .67343 L F
.67 .246 .231 r
.55034 .68186 m .54989 .6831 L .54779 .68212 L F
.502 .259 .478 r
.55313 .67997 m .55259 .68184 L .55034 .68186 L F
.356 0 .061 r
.55259 .68184 m .54989 .6831 L .55034 .68186 L F
.971 .812 .628 r
.4669 .67387 m .46813 .67193 L .46953 .67098 L F
.432 .462 .791 r
.4765 .6866 m .47862 .68572 L .47523 .68531 L F
.4765 .6866 m .47893 .68703 L .47862 .68572 L F
.66 .505 .663 r
.52376 .68314 m .52124 .68614 L .52136 .68361 L F
.52376 .68314 m .52124 .68614 L .52136 .68361 L F
.733 .58 .004 r
.61297 .65055 m .61309 .65387 L .61249 .65166 L F
.35 .283 .64 r
.44335 .68621 m .44483 .68235 L .44298 .68277 L F
.44335 .68621 m .44487 .68562 L .44483 .68235 L F
.332 .237 .595 r
.44335 .68621 m .44506 .68825 L .44487 .68562 L F
.223 .211 .634 r
.44395 .68876 m .44506 .68825 L .44335 .68621 L F
.541 .547 .81 r
.41927 .60251 m .4207 .59933 L .41827 .59982 L F
.41927 .60251 m .4215 .60211 L .4207 .59933 L F
.009 0 .18 r
.41969 .6048 m .4215 .60211 L .41927 .60251 L F
.601 .302 .434 r
.79428 .50442 m .797 .50432 L .79699 .50638 L F
.378 .36 .713 r
.79629 .50351 m .79428 .50442 L .79699 .50638 L F
.508 .403 .669 r
.52351 .68064 m .52548 .68218 L .5256 .68019 L F
.52351 .68064 m .52376 .68314 L .52548 .68218 L F
.542 .362 .586 r
.4826 .70068 m .48513 .70268 L .48609 .70057 L F
.798 .465 .425 r
.54083 .67442 m .54222 .67728 L .53927 .67667 L F
.701 .981 .809 r
.5364 .60038 m .53305 .60293 L .53446 .60111 L F
.542 .002 0 r
.5364 .60038 m .53446 .60111 L .5384 .60113 L F
.485 .456 .75 r
.5364 .60038 m .5384 .60113 L .53784 .5992 L F
.615 .294 .402 r
.52104 .64604 m .52367 .6468 L .52453 .64553 L F
.561 .372 .582 r
.78463 .51589 m .7852 .5184 L .78247 .51926 L F
.543 .498 .756 r
.78633 .51217 m .78463 .51589 L .78514 .5127 L F
.78633 .51217 m .78735 .51571 L .78463 .51589 L F
.698 .586 .727 r
.78735 .51571 m .7852 .5184 L .78463 .51589 L F
.111 0 0 r
.36084 .59668 m .35915 .59805 L .35696 .59859 L F
.273 0 0 r
.36311 .59646 m .35915 .59805 L .36084 .59668 L F
.636 .424 .577 r
.41464 .61077 m .41741 .61045 L .41745 .60822 L F
.561 .453 .688 r
.41745 .60822 m .4197 .60778 L .41969 .6048 L F
.587 .416 .616 r
.41741 .61045 m .4197 .60778 L .41745 .60822 L F
.551 .745 .967 r
.58324 .62372 m .58332 .6256 L .58352 .62389 L F
.58358 .62389 m .58637 .62529 L .58527 .6254 L F
.58356 .62402 m .58527 .6254 L .58332 .6256 L F
.58358 .62389 m .58527 .6254 L .58356 .62402 L F
.648 .113 0 r
.58332 .6256 m .58531 .62723 L .58457 .62749 L F
.532 .243 .421 r
.58332 .6256 m .58637 .62529 L .58531 .62723 L F
.648 .113 0 r
.58332 .6256 m .58457 .62749 L .58356 .62402 L F
.58332 .6256 m .58356 .62402 L .58352 .62389 L F
.94 .594 .34 r
.58352 .62389 m .58356 .62402 L .58343 .62392 L F
.551 .745 .967 r
.58324 .62372 m .58358 .62389 L .58332 .6256 L F
.94 .594 .34 r
.58343 .62392 m .58457 .62749 L .58188 .62446 L F
.58356 .62402 m .58457 .62749 L .58343 .62392 L F
.388 .037 .242 r
.34635 .60703 m .34486 .60603 L .34748 .60486 L F
.34635 .60703 m .34415 .60764 L .34486 .60603 L F
.532 .755 .978 r
.79079 .47971 m .78924 .48142 L .78829 .48022 L F
.79079 .47971 m .79178 .48101 L .78924 .48142 L F
.631 .703 .898 r
.54793 .61563 m .5456 .61699 L .54571 .6147 L F
.705 .72 .197 r
.53709 .71454 m .53794 .71127 L .5365 .71204 L F
.776 .724 .804 r
.56697 .60534 m .57013 .60546 L .5688 .60377 L F
.675 .597 .761 r
.57013 .60546 m .56926 .60056 L .5688 .60377 L F
.57013 .60546 m .57088 .602 L .56926 .60056 L F
.447 .209 .459 r
.73153 .49352 m .73171 .49581 L .7295 .49563 L F
.398 .049 .252 r
.77193 .48682 m .7694 .48739 L .76955 .48842 L F
.52 .397 .652 r
.22171 .56769 m .22205 .57014 L .21997 .57066 L F
.913 .664 .549 r
.5442 .61107 m .54421 .61374 L .54299 .61194 L F
.5442 .61107 m .54299 .61194 L .54271 .61153 L F
.249 0 0 r
.54045 .61297 m .54173 .61286 L .5442 .61107 L F
.54173 .61286 m .54375 .61268 L .5442 .61107 L F
.94 .853 .729 r
.54401 .60656 m .54271 .61153 L .5442 .61107 L F
.11 0 0 r
.5442 .61107 m .54528 .61188 L .54633 .61038 L F
.5442 .61107 m .54375 .61268 L .54528 .61188 L F
.229 .051 .42 r
.20879 .60485 m .20895 .60729 L .20713 .6082 L F
.192 .034 .425 r
.20895 .60729 m .20697 .61065 L .20713 .6082 L F
.357 .237 .576 r
.21556 .58469 m .21404 .58762 L .21392 .58524 L F
0 0 0 r
.46426 .70289 m .46309 .706 L .46207 .70394 L F
.661 .558 .728 r
.34565 .61332 m .34386 .61644 L .34358 .61393 L F
.518 .596 .871 r
.43067 .59165 m .42927 .59384 L .42845 .59198 L F
.43067 .59165 m .43131 .59342 L .42927 .59384 L F
.442 .492 .816 r
.43194 .59545 m .42927 .59384 L .43131 .59342 L F
.58 .539 .774 r
.53305 .60293 m .53359 .60467 L .53554 .60373 L F
.874 .769 .743 r
.57696 .63986 m .5778 .63961 L .57711 .63733 L F
.783 .476 .469 r
.5745 .64165 m .5778 .63961 L .57696 .63986 L F
.5745 .64165 m .57674 .64245 L .5778 .63961 L F
.63 .309 .41 r
.5778 .63961 m .57674 .64245 L .58 .64214 L F
.32 .675 .977 r
.58219 .67169 m .5828 .67056 L .58074 .67061 L F
0 .187 .713 r
.58219 .67169 m .58334 .67266 L .5828 .67056 L F
.789 .541 .562 r
.59246 .58691 m .59591 .58509 L .59431 .58416 L F
.59246 .58691 m .5959 .58755 L .59591 .58509 L F
.614 .517 .72 r
.79629 .50351 m .79803 .50505 L .79682 .50172 L F
.262 .19 .584 r
.79682 .50172 m .79803 .50505 L .79775 .50206 L F
.364 .061 .311 r
.79775 .50206 m .79629 .50351 L .79682 .50172 L F
.79775 .50206 m .79662 .50137 L .79629 .50351 L F
.535 .323 .538 r
.48096 .72552 m .4781 .72356 L .4816 .72316 L F
.788 .565 .599 r
.47698 .72249 m .47999 .72312 L .4803 .72004 L F
.482 .887 .942 r
.48262 .72273 m .48195 .72283 L .4816 .72316 L F
0 0 0 r
.48195 .72283 m .4818 .72324 L .4816 .72316 L F
.4818 .72324 m .48102 .72529 L .48145 .72372 L F
.4818 .72324 m .48145 .72372 L .4816 .72316 L F
.265 .31 .722 r
.4803 .72004 m .4818 .72324 L .48242 .72239 L F
.4818 .72324 m .48193 .72353 L .48242 .72239 L F
.84 .555 .505 r
.4781 .72356 m .47498 .72505 L .47543 .72369 L F
.4781 .72356 m .47829 .72606 L .47498 .72505 L F
.535 .323 .538 r
.48096 .72552 m .47829 .72606 L .4781 .72356 L F
.863 .649 .611 r
.47871 .72511 m .48165 .72367 L .47698 .72249 L F
.48165 .72367 m .48193 .72353 L .48171 .72348 L F
.48165 .72367 m .48171 .72348 L .47698 .72249 L F
.48165 .72367 m .48096 .72552 L .48193 .72353 L F
0 0 0 r
.48113 .72508 m .48096 .72552 L .48102 .72529 L F
.863 .649 .611 r
.47871 .72511 m .48096 .72552 L .48165 .72367 L F
0 0 0 r
.48139 .72453 m .48096 .72552 L .48113 .72508 L F
.48242 .72239 m .48133 .72473 L .48139 .72453 L F
.48133 .72473 m .48096 .72552 L .48139 .72453 L F
.788 .565 .599 r
.48171 .72348 m .48193 .72353 L .4818 .72324 L F
0 0 0 r
.48242 .72239 m .48102 .72529 L .48195 .72283 L F
.788 .565 .599 r
.47999 .72312 m .48171 .72348 L .48163 .72288 L F
.48171 .72348 m .4818 .72324 L .48163 .72288 L F
.47999 .72312 m .48163 .72288 L .4803 .72004 L F
.482 .887 .942 r
.48316 .7225 m .48242 .72239 L .48195 .72283 L F
.48316 .7225 m .48195 .72283 L .48262 .72273 L F
.752 .664 .764 r
.73388 .48985 m .73153 .49352 L .73037 .48927 L F
.198 .352 .793 r
.73153 .49352 m .73316 .4931 L .73171 .49581 L F
.686 .448 .556 r
.49608 .62804 m .49937 .62761 L .49947 .62549 L F
.156 0 0 r
.37569 .63742 m .37402 .63863 L .37178 .63905 L F
.105 0 0 r
.37785 .63711 m .37402 .63863 L .37569 .63742 L F
.969 .851 .447 r
.61272 .63705 m .6128 .63393 L .6122 .6359 L F
.831 .621 .072 r
.61262 .63849 m .61272 .63705 L .6122 .6359 L F
.61262 .63849 m .6129 .63956 L .61272 .63705 L F
.778 .617 .681 r
.5211 .66179 m .52536 .66274 L .52515 .65932 L F
.711 .566 .69 r
.52515 .65932 m .52742 .66214 L .52701 .65953 L F
.52515 .65932 m .52536 .66274 L .52742 .66214 L F
.541 .32 .528 r
.49625 .65424 m .49631 .65696 L .49394 .65705 L F
.587 .437 .645 r
.49867 .65119 m .49896 .65406 L .49625 .65424 L F
.518 .302 .525 r
.49859 .6564 m .49625 .65424 L .49896 .65406 L F
.49859 .6564 m .49631 .65696 L .49625 .65424 L F
.509 .401 .667 r
.7852 .5184 m .78309 .52148 L .78247 .51926 L F
.7852 .5184 m .78536 .52074 L .78309 .52148 L F
.623 .621 .828 r
.78637 .52257 m .78309 .52148 L .78536 .52074 L F
.195 .715 .872 r
.37801 .58325 m .38024 .58312 L .38197 .58341 L F
.462 .871 .954 r
.38197 .58341 m .38246 .58247 L .38407 .58295 L F
.38197 .58341 m .38024 .58312 L .38246 .58247 L F
.658 .122 0 r
.55409 .65247 m .55356 .65126 L .55218 .65014 L F
.55409 .65247 m .55546 .65328 L .55356 .65126 L F
.574 .654 .89 r
.56527 .59928 m .56809 .59874 L .56794 .6011 L F
.431 0 0 r
.56794 .6011 m .56769 .60099 L .56527 .59928 L F
.194 .725 .785 r
.56602 .60134 m .56769 .60099 L .56794 .6011 L F
.841 .768 .26 r
.56794 .6011 m .56809 .59874 L .56769 .60099 L F
.36 .828 .772 r
.56769 .60099 m .56926 .60056 L .56794 .6011 L F
.613 .263 .354 r
.5198 .669 m .52003 .67045 L .51775 .66872 L F
.552 0 0 r
.52003 .67045 m .51861 .6698 L .51775 .66872 L F
0 0 0 r
.46426 .70289 m .46362 .70546 L .46309 .706 L F
0 .145 .689 r
.46362 .70546 m .46519 .70824 L .46309 .706 L F
.304 .499 .883 r
.77071 .5219 m .7723 .52047 L .77 .52045 L F
.77071 .5219 m .77364 .52294 L .7723 .52047 L F
.363 .651 .966 r
.41455 .58593 m .41243 .58638 L .4111 .58515 L F
.41455 .58593 m .41512 .58671 L .41243 .58638 L F
.117 0 .052 r
.4604 .66637 m .45948 .66783 L .4622 .66546 L F
.263 .234 .637 r
.48852 .6366 m .48692 .6369 L .48874 .63874 L F
.689 .486 .608 r
.44534 .61347 m .44248 .61632 L .44257 .61394 L F
.266 .724 .953 r
.57088 .59688 m .572 .59631 L .56954 .59635 L F
.57088 .59688 m .57344 .59682 L .572 .59631 L F
.815 .638 .662 r
.59585 .59001 m .59949 .58807 L .5959 .58755 L F
.59585 .59001 m .59907 .59068 L .59949 .58807 L F
.211 0 .238 r
.3498 .60235 m .34919 .60475 L .34748 .60486 L F
.184 0 .095 r
.34919 .60475 m .34635 .60703 L .34748 .60486 L F
.581 .033 0 r
.35702 .58162 m .35905 .58286 L .36062 .58233 L F
.243 .737 .913 r
.35905 .58286 m .3627 .58309 L .36062 .58233 L F
.799 .337 .137 r
.46716 .71689 m .46748 .71497 L .46595 .71406 L F
.46716 .71689 m .46996 .71788 L .46748 .71497 L F
.783 .367 .26 r
.46748 .71497 m .46996 .71788 L .47129 .71746 L F
.665 .248 0 r
.72413 .49552 m .72468 .49673 L .72351 .49387 L F
.72413 .49552 m .72559 .4981 L .72468 .49673 L F
.854 .41 .147 r
.72704 .4985 m .72559 .4981 L .72413 .49552 L F
.945 .895 .747 r
.74717 .50986 m .74964 .50713 L .74922 .50812 L F
.622 .549 .751 r
.75135 .5061 m .74922 .50812 L .74964 .50713 L F
.321 .489 .869 r
.34447 .64254 m .34604 .64242 L .3439 .63957 L F
.258 0 .255 r
.35112 .6037 m .3498 .60235 L .352 .60174 L F
.35112 .6037 m .34919 .60475 L .3498 .60235 L F
.656 .181 .114 r
.81146 .51234 m .80724 .51182 L .80892 .51593 L F
.81146 .51234 m .80928 .5132 L .80724 .51182 L F
0 .528 .794 r
.81234 .51119 m .81042 .51074 L .81146 .51234 L F
.514 .908 .782 r
.81282 .51116 m .81146 .51234 L .81234 .51119 L F
.81282 .51116 m .80928 .5132 L .81146 .51234 L F
0 .177 .672 r
.55628 .61618 m .55556 .61528 L .55361 .61379 L F
.383 .371 .722 r
.73496 .49673 m .73302 .49862 L .73171 .49581 L F
.73496 .49673 m .73485 .49838 L .73302 .49862 L F
.389 .449 .801 r
.73485 .49838 m .73554 .49993 L .73302 .49862 L F
.586 .346 .52 r
.73554 .49993 m .73305 .50073 L .73302 .49862 L F
.73554 .49993 m .73305 .50073 L .73302 .49862 L F
.883 .712 .665 r
.59066 .60474 m .59315 .60494 L .59232 .60808 L F
.516 .889 .969 r
.36954 .62577 m .36745 .62654 L .36562 .62612 L F
.52 .45 .718 r
.30897 .60801 m .31098 .60355 L .3084 .60562 L F
.159 0 0 r
.4846 .67366 m .48839 .67191 L .48746 .67268 L F
.4846 .67366 m .48746 .67268 L .48686 .67297 L F
.395 .843 .923 r
.48727 .67284 m .4858 .67288 L .4846 .67366 L F
.856 .955 .874 r
.4858 .67288 m .48517 .67538 L .4846 .67366 L F
.48563 .67355 m .48334 .67517 L .48517 .67538 L F
.4858 .67288 m .48449 .67409 L .48563 .67355 L F
.48449 .67409 m .48334 .67517 L .48563 .67355 L F
.159 0 0 r
.48686 .67297 m .48746 .67268 L .48727 .67284 L F
.509 .411 .679 r
.55543 .67896 m .55293 .67685 L .55483 .67655 L F
.55543 .67896 m .55313 .67997 L .55293 .67685 L F
.598 .59 .815 r
.7638 .50449 m .76108 .50607 L .76035 .50328 L F
.194 0 .293 r
.53592 .66795 m .5335 .67177 L .53526 .6706 L F
.408 .274 .586 r
.53592 .66795 m .53746 .66787 L .53719 .6658 L F
.623 .413 .577 r
.53526 .6706 m .53746 .66787 L .53592 .66795 L F
.408 .274 .586 r
.53592 .66795 m .53746 .66787 L .53719 .6658 L F
.779 .793 .864 r
.75253 .4939 m .74941 .49426 L .75254 .49353 L F
0 .379 .829 r
.75424 .49413 m .75253 .4939 L .75254 .49353 L F
.75424 .49413 m .75532 .49533 L .75253 .4939 L F
.567 .338 .528 r
.51405 .65422 m .51663 .6539 L .5168 .65122 L F
.524 .446 .709 r
.5168 .65122 m .51896 .6507 L .51834 .64783 L F
.567 .383 .591 r
.51663 .6539 m .51896 .6507 L .5168 .65122 L F
0 0 .379 r
.54673 .63964 m .54792 .64201 L .54789 .64288 L F
.632 .34 .457 r
.58878 .58238 m .59104 .58408 L .59217 .58197 L F
.58878 .58238 m .58865 .58435 L .59104 .58408 L F
.354 .264 .614 r
.21052 .60166 m .21095 .60445 L .20879 .60485 L F
.077 0 .386 r
.21002 .60649 m .20879 .60485 L .21095 .60445 L F
.21002 .60649 m .20895 .60729 L .20879 .60485 L F
.922 .605 .425 r
.59957 .59528 m .60095 .59377 L .59924 .59299 L F
.59957 .59528 m .60138 .5964 L .60095 .59377 L F
.381 0 .151 r
.31398 .59262 m .31695 .59128 L .31463 .59225 L F
.546 .781 .986 r
.78403 .52791 m .78803 .5286 L .7867 .52727 L F
.75 .834 .916 r
.7867 .52727 m .78803 .5286 L .79002 .52722 L F
.991 .794 .544 r
.60068 .60113 m .60209 .59954 L .60039 .59883 L F
.60068 .60113 m .60183 .6021 L .60209 .59954 L F
.734 .986 .785 r
.48511 .65287 m .48446 .65427 L .48709 .65173 L F
.75 .608 .039 r
.4844 .65506 m .48446 .65427 L .48511 .65287 L F
.4844 .65506 m .48446 .65691 L .48446 .65427 L F
.927 .731 .618 r
.59446 .62778 m .59564 .63093 L .59314 .63018 L F
.846 .743 .75 r
.59314 .63018 m .59564 .63093 L .59305 .6342 L F
.028 .515 .878 r
.45456 .71118 m .45773 .71262 L .45658 .71175 L F
0 .345 .823 r
.45773 .71262 m .45951 .71282 L .45658 .71175 L F
.45773 .71262 m .4601 .71409 L .45951 .71282 L F
.66 .525 .688 r
.75419 .50105 m .75063 .49822 L .75334 .49711 L F
.492 .504 .798 r
.75532 .49533 m .7565 .49838 L .75334 .49711 L F
.575 .442 .662 r
.7565 .49838 m .75419 .50105 L .75334 .49711 L F
.482 .675 .95 r
.42645 .58977 m .42554 .59165 L .42426 .59034 L F
.42645 .58977 m .42845 .59198 L .42554 .59165 L F
0 .532 .785 r
.38593 .58255 m .38987 .58336 L .38777 .58342 L F
.528 0 0 r
.55124 .61917 m .55481 .62073 L .55502 .61954 L F
.834 .508 .437 r
.55481 .62073 m .5572 .61907 L .55502 .61954 L F
.941 .621 .399 r
.46174 .71478 m .46069 .71635 L .4601 .71409 L F
.92 .581 .382 r
.46174 .71478 m .46215 .71695 L .46069 .71635 L F
.447 .418 .734 r
.52742 .66214 m .52869 .65792 L .52701 .65953 L F
.52742 .66214 m .52978 .66118 L .52869 .65792 L F
.654 .898 .982 r
.59117 .67466 m .59205 .67298 L .59012 .67343 L F
.526 .33 .558 r
.49757 .64559 m .49999 .64515 L .5 .64272 L F
.552 .266 .434 r
.49683 .64743 m .49999 .64515 L .49757 .64559 L F
.456 .712 .978 r
.77364 .52294 m .77462 .52425 L .77603 .52282 L F
.369 .569 .915 r
.77603 .52282 m .77462 .52425 L .77663 .52446 L F
.227 .714 .927 r
.47597 .6651 m .47498 .66278 L .47602 .66211 L F
.935 .685 .535 r
.61081 .63284 m .61282 .63113 L .61071 .63034 L F
.61081 .63284 m .6128 .63393 L .61282 .63113 L F
.259 0 0 r
.3747 .59508 m .37114 .59546 L .37253 .59539 L F
.33 0 .157 r
.45448 .67104 m .45691 .67066 L .45768 .66886 L F
.282 0 .225 r
.45691 .67066 m .45948 .66783 L .45768 .66886 L F
.56 .352 .555 r
.47442 .70618 m .47448 .70901 L .47219 .70894 L F
0 0 0 r
.47219 .70894 m .47378 .70819 L .47442 .70618 L F
.653 .214 .194 r
.47442 .70618 m .4766 .70771 L .47554 .70625 L F
.53 .328 .552 r
.47442 .70618 m .47448 .70901 L .4766 .70771 L F
.653 .214 .194 r
.47442 .70618 m .47378 .70819 L .4766 .70771 L F
.53 .328 .552 r
.47442 .70618 m .4766 .70771 L .47554 .70625 L F
.069 .256 .747 r
.72704 .4985 m .72877 .49863 L .72559 .4981 L F
.72704 .4985 m .72925 .50071 L .72877 .49863 L F
.706 .789 .311 r
.54992 .6014 m .54857 .60498 L .55033 .60194 L F
.54992 .6014 m .54882 .60412 L .54857 .60498 L F
.741 .664 .775 r
.19753 .56486 m .19942 .56177 L .19731 .56431 L F
.336 .197 .54 r
.22003 .58039 m .2186 .57932 L .22007 .57864 L F
.22003 .58039 m .21859 .58171 L .2186 .57932 L F
.566 .37 .575 r
.46128 .68825 m .45879 .69074 L .45899 .68892 L F
.104 .652 .823 r
.73641 .48879 m .73883 .48878 L .74041 .48901 L F
.252 0 0 r
.73883 .48878 m .74222 .48953 L .74041 .48901 L F
.805 .732 .783 r
.48433 .6653 m .48738 .66547 L .48576 .66332 L F
.764 .398 .362 r
.48433 .6653 m .48564 .66748 L .48738 .66547 L F
.067 .63 .751 r
.48564 .66748 m .48962 .66741 L .48738 .66547 L F
.278 .727 .959 r
.55053 .62496 m .54911 .62431 L .54675 .62433 L F
.817 .397 .246 r
.55286 .62712 m .54911 .62431 L .55053 .62496 L F
.065 .629 .746 r
.37153 .62498 m .37521 .62488 L .37293 .62489 L F
.518 .397 .655 r
.5426 .65728 m .54483 .65932 L .54496 .65753 L F
.156 0 .059 r
.54483 .65932 m .54775 .65702 L .54496 .65753 L F
.967 .72 .511 r
.31905 .64 m .31868 .64214 L .31724 .63895 L F
.447 .202 .448 r
.32119 .63955 m .31868 .64214 L .31905 .64 L F
.482 .234 .461 r
.46495 .66301 m .4673 .66255 L .4673 .65982 L F
.395 .168 .447 r
.4673 .65982 m .46931 .66173 L .46942 .65957 L F
.4673 .65982 m .4673 .66255 L .46931 .66173 L F
.62 .138 .088 r
.50542 .62748 m .50763 .62811 L .50934 .62764 L F
.664 .16 .039 r
.50763 .62811 m .51174 .62968 L .50934 .62764 L F
.804 .74 .215 r
.56339 .67921 m .56298 .68158 L .56297 .68308 L F
.483 .093 .223 r
.32738 .58725 m .32982 .58713 L .33111 .585 L F
.377 0 .13 r
.32982 .58713 m .33337 .58478 L .33111 .585 L F
.884 .652 .582 r
.5335 .67177 m .53514 .67451 L .53265 .67379 L F
0 0 0 r
.53514 .67451 m .53091 .67677 L .53265 .67379 L F
.53514 .67451 m .5328 .67603 L .53091 .67677 L F
.762 .844 .913 r
.54354 .59821 m .54647 .5985 L .54403 .59724 L F
.516 .193 .358 r
.54403 .59724 m .54647 .5985 L .54659 .59668 L F
.662 .43 .558 r
.3382 .64262 m .33854 .64154 L .33631 .64198 L F
.3382 .64262 m .34067 .64489 L .33854 .64154 L F
.3382 .64262 m .3379 .64503 L .34067 .64489 L F
.34067 .64489 m .3379 .64503 L .3382 .64262 L F
.786 .518 .531 r
.59217 .58197 m .59104 .58408 L .59431 .58416 L F
.953 .68 .232 r
.55678 .65666 m .55699 .65896 L .5577 .66003 L F
0 0 .33 r
.55699 .65896 m .55832 .66249 L .5577 .66003 L F
.753 .749 .849 r
.74846 .50125 m .74594 .50378 L .74538 .50049 L F
.654 .574 .752 r
.74846 .50125 m .74977 .50483 L .74594 .50378 L F
.085 .265 .75 r
.46824 .71809 m .46876 .72067 L .4701 .71894 L F
.989 .836 .601 r
.47111 .72243 m .4701 .71894 L .46876 .72067 L F
.381 .139 .417 r
.51396 .72077 m .51361 .72282 L .51624 .72008 L F
.51624 .72008 m .51361 .72282 L .51396 .72077 L F
.226 .234 .659 r
.73092 .50319 m .73324 .5055 L .73406 .50428 L F
.823 .918 .901 r
.73632 .50247 m .73406 .50428 L .7332 .5032 L F
.989 .743 .364 r
.73406 .50428 m .73324 .5055 L .7332 .5032 L F
.69 .425 .516 r
.53702 .63156 m .53574 .63407 L .53395 .63175 L F
.63 .262 .327 r
.53395 .63175 m .53665 .63188 L .53702 .63156 L F
.097 0 .166 r
.53857 .63077 m .53574 .63407 L .53702 .63156 L F
0 0 0 r
.53702 .63156 m .53665 .63188 L .53857 .63077 L F
.968 .781 .597 r
.50132 .68664 m .50066 .68918 L .49908 .68793 L F
.213 .359 .795 r
.50154 .6856 m .50132 .68664 L .49932 .68247 L F
.584 .617 .851 r
.35132 .64233 m .35369 .64584 L .35531 .64463 L F
.868 .691 .661 r
.27725 .83635 m .2781 .83889 L .2775 .83891 L F
.834 .53 .475 r
.2781 .83889 m .27756 .84119 L .2775 .83891 L F
.67 .66 .831 r
.28003 .83633 m .2781 .83889 L .27725 .83635 L F
.28003 .83633 m .28106 .83833 L .2781 .83889 L F
.062 0 0 r
.28106 .83833 m .27756 .84119 L .2781 .83889 L F
0 0 .473 r
.52376 .68314 m .52526 .68461 L .52548 .68218 L F
.52376 .68314 m .52431 .6859 L .52526 .68461 L F
.041 0 0 r
.57685 .58934 m .58042 .58742 L .57811 .58807 L F
.83 .641 .646 r
.75063 .49822 m .74718 .49774 L .74788 .49533 L F
.825 .686 .71 r
.75063 .49822 m .74846 .50125 L .74718 .49774 L F
.745 .567 .654 r
.75063 .49822 m .7519 .5015 L .74846 .50125 L F
.66 .525 .688 r
.75419 .50105 m .7519 .5015 L .75063 .49822 L F
.941 .728 .588 r
.54725 .67075 m .54727 .67341 L .54896 .67202 L F
.609 .48 .68 r
.54727 .67341 m .54958 .67039 L .54896 .67202 L F
0 .28 .782 r
.41184 .59643 m .41186 .59524 L .41018 .59412 L F
0 0 0 r
.41184 .59643 m .41202 .59636 L .41186 .59524 L F
.41184 .59643 m .41128 .59887 L .41202 .59636 L F
.427 .102 .309 r
.44719 .67979 m .44939 .67941 L .45004 .67704 L F
.295 .057 .373 r
.45004 .67704 m .45199 .67671 L .45229 .67407 L F
.489 .243 .468 r
.44939 .67941 m .45199 .67671 L .45004 .67704 L F
.521 .391 .645 r
.80868 .50156 m .80946 .4988 L .80733 .49791 L F
.80868 .50156 m .81098 .50074 L .80946 .4988 L F
.80946 .4988 m .81098 .50074 L .80868 .50156 L F
.592 .388 .574 r
.56409 .5935 m .56722 .59348 L .56655 .59093 L F
.486 .105 .242 r
.56852 .5922 m .56655 .59093 L .56722 .59348 L F
.56852 .5922 m .57043 .59016 L .56655 .59093 L F
.537 0 0 r
.55394 .62809 m .55497 .62923 L .55286 .62712 L F
.55394 .62809 m .55633 .63011 L .55497 .62923 L F
.473 .11 .268 r
.38687 .62174 m .38919 .62157 L .38989 .62013 L F
.523 .226 .405 r
.38919 .62157 m .39211 .61946 L .38989 .62013 L F
.63 .661 .861 r
.7462 .49208 m .74328 .49255 L .74222 .48953 L F
0 .343 .781 r
.74788 .49533 m .74328 .49255 L .7462 .49208 L F
.518 .397 .655 r
.5426 .65728 m .54261 .66003 L .54483 .65932 L F
.806 .559 .565 r
.5 .64272 m .49999 .64515 L .49611 .64439 L F
.388 .199 .498 r
.49999 .64515 m .50207 .64211 L .5 .64272 L F
.50207 .64211 m .49999 .64515 L .5 .64272 L F
.166 0 0 r
.77918 .49046 m .7792 .49117 L .7784 .49117 L F
.7792 .49117 m .7792 .49139 L .77877 .49127 L F
.7792 .49117 m .77877 .49127 L .7784 .49117 L F
.77918 .49046 m .78128 .49003 L .7792 .49139 L F
.261 .061 .409 r
.7784 .49117 m .7792 .49139 L .78033 .49027 L F
.7784 .49117 m .78033 .49027 L .77832 .49138 L F
.601 .94 .941 r
.77731 .49108 m .77831 .49138 L .78033 .49027 L F
.77831 .49138 m .77832 .49138 L .77836 .49137 L F
.77831 .49138 m .77836 .49137 L .78033 .49027 L F
0 .014 .588 r
.55819 .66454 m .56023 .66838 L .55946 .66551 L F
.542 .321 .529 r
.48334 .67722 m .48341 .67967 L .48081 .68035 L F
.656 .575 .752 r
.48517 .67538 m .48341 .67967 L .48334 .67722 L F
.442 .607 .917 r
.47212 .66992 m .47376 .66837 L .47145 .66876 L F
.47212 .66992 m .47559 .67099 L .47376 .66837 L F
.58 .539 .774 r
.53305 .60293 m .53554 .60373 L .53446 .60111 L F
.568 .682 .917 r
.78757 .52045 m .78637 .52257 L .78536 .52074 L F
.78757 .52045 m .78847 .52224 L .78637 .52257 L F
.049 .349 .825 r
.52249 .68581 m .52124 .68614 L .51997 .68565 L F
.52171 .68601 m .52382 .6883 L .52124 .68614 L F
.52339 .68749 m .52382 .6883 L .52227 .68662 L F
.52202 .68628 m .52227 .68662 L .52171 .68601 L F
.587 .465 .681 r
.52382 .6883 m .5218 .68884 L .52124 .68614 L F
.571 .173 .249 r
.51645 .68938 m .52226 .68649 L .51669 .68776 L F
.52226 .68649 m .52252 .68637 L .5222 .68644 L F
.52226 .68649 m .5222 .68644 L .51669 .68776 L F
.51645 .68938 m .519 .68965 L .52234 .68653 L F
.52226 .68649 m .52234 .68653 L .52252 .68637 L F
.51645 .68938 m .52234 .68653 L .52226 .68649 L F
.804 .962 .64 r
.52252 .68637 m .52248 .6859 L .51997 .68565 L F
.52248 .6859 m .52248 .68581 L .52052 .68569 L F
.52248 .6859 m .52052 .68569 L .51997 .68565 L F
.541 .219 .371 r
.52243 .68605 m .52255 .68592 L .52234 .68653 L F
.52245 .68593 m .52255 .68592 L .52243 .68605 L F
.52245 .68593 m .52261 .68577 L .52255 .68592 L F
.049 .349 .825 r
.52249 .68581 m .52195 .68622 L .52171 .68601 L F
.804 .962 .64 r
.52248 .68582 m .52249 .68581 L .52248 .68581 L F
.52252 .68637 m .52249 .68581 L .52248 .68582 L F
.541 .219 .371 r
.52234 .68653 m .5225 .68608 L .52252 .68637 L F
.737 .462 .513 r
.52202 .68628 m .52252 .68637 L .52196 .68621 L F
.52202 .68628 m .5222 .68644 L .52252 .68637 L F
.049 .349 .825 r
.52238 .68589 m .52339 .68749 L .52195 .68622 L F
.52233 .68659 m .52227 .68662 L .52211 .6864 L F
.52219 .68645 m .52211 .6864 L .52205 .68633 L F
.5222 .68644 m .52205 .68633 L .52202 .68628 L F
.737 .462 .513 r
.51678 .68539 m .51669 .68776 L .5222 .68644 L F
.51678 .68539 m .5222 .68644 L .52202 .68628 L F
.541 .219 .371 r
.519 .68965 m .52245 .68593 L .52234 .68653 L F
.049 .349 .825 r
.52231 .68665 m .52227 .68662 L .52233 .68659 L F
.52339 .68749 m .52211 .6864 L .52219 .68645 L F
.52339 .68749 m .52205 .68633 L .5222 .68644 L F
.541 .219 .371 r
.519 .68965 m .5215 .68943 L .52254 .68598 L F
.804 .962 .64 r
.52249 .6859 m .52261 .68577 L .52249 .68581 L F
.541 .219 .371 r
.5225 .68608 m .52261 .68577 L .52252 .68637 L F
.804 .962 .64 r
.52252 .68637 m .52261 .68577 L .52249 .6859 L F
.541 .219 .371 r
.52194 .68657 m .52254 .68598 L .52251 .68596 L F
.519 .68965 m .52168 .68688 L .52194 .68657 L F
.52168 .68688 m .52254 .68598 L .52194 .68657 L F
.52251 .68596 m .52254 .68598 L .52256 .68591 L F
.049 .349 .825 r
.52254 .68598 m .52339 .68749 L .52238 .68589 L F
.676 .351 .418 r
.52261 .68577 m .52254 .68598 L .52261 .68603 L F
.918 .827 .74 r
.52431 .6859 m .52382 .6883 L .5228 .68638 L F
.52273 .68602 m .5228 .68638 L .52261 .68603 L F
.52431 .6859 m .5228 .68638 L .52273 .68602 L F
.72 .626 .752 r
.52737 .68827 m .52382 .6883 L .52431 .6859 L F
.423 .051 .226 r
.52737 .68827 m .5241 .69071 L .52382 .6883 L F
.676 .351 .418 r
.5227 .68585 m .52485 .68929 L .52353 .68657 L F
.52261 .68577 m .52272 .68595 L .5227 .68585 L F
.52272 .68595 m .52485 .68929 L .5227 .68585 L F
.52272 .68595 m .52261 .68603 L .52292 .68626 L F
.52261 .68577 m .52261 .68603 L .52272 .68595 L F
.541 .219 .371 r
.52248 .6859 m .52256 .68591 L .52261 .68577 L F
.918 .827 .74 r
.52287 .68583 m .52261 .68603 L .52249 .68581 L F
.52431 .6859 m .52261 .68603 L .52287 .68583 L F
.049 .349 .825 r
.5226 .68602 m .52261 .68603 L .52254 .68598 L F
.52261 .68603 m .52339 .68749 L .52254 .68598 L F
.52339 .68749 m .52231 .68665 L .52233 .68659 L F
.621 .392 .548 r
.52382 .6883 m .52147 .69091 L .5218 .68884 L F
.52382 .6883 m .5241 .69071 L .52147 .69091 L F
.676 .351 .418 r
.52292 .68626 m .5215 .68943 L .52485 .68929 L F
.52254 .68598 m .5215 .68943 L .52292 .68626 L F
.541 .219 .371 r
.519 .68965 m .52256 .68591 L .52248 .6859 L F
.049 .349 .825 r
.52249 .68581 m .5226 .68602 L .52238 .68589 L F
.737 .462 .513 r
.51678 .68539 m .52202 .68628 L .51997 .68565 L F
.52202 .68628 m .52196 .68621 L .51997 .68565 L F
.959 .924 .723 r
.5839 .65273 m .58456 .65063 L .58628 .65176 L F
.579 .02 0 r
.51891 .63274 m .52062 .63335 L .52214 .63321 L F
.293 0 0 r
.52214 .63321 m .52062 .63335 L .52427 .63359 L F
.226 .234 .659 r
.73092 .50319 m .73162 .50751 L .73324 .5055 L F
.592 .276 .403 r
.43416 .6166 m .43067 .61899 L .43084 .61713 L F
.444 .548 .867 r
.73162 .50751 m .73475 .50825 L .73324 .5055 L F
.303 0 0 r
.37746 .62457 m .37971 .62438 L .38139 .62294 L F
.492 .006 .029 r
.38139 .62294 m .37971 .62438 L .38323 .62384 L F
.888 .797 .311 r
.55992 .67083 m .55962 .67437 L .56067 .67158 L F
.675 .577 .737 r
.48371 .67184 m .48291 .6734 L .48129 .67102 L F
.356 .327 .689 r
.4846 .67366 m .48291 .6734 L .48371 .67184 L F
.866 .942 .866 r
.74345 .48278 m .74084 .48698 L .7441 .48375 L F
.987 .743 .477 r
.55483 .67655 m .55468 .67917 L .55543 .67896 L F
0 0 .221 r
.55552 .67774 m .55468 .67917 L .55483 .67655 L F
.674 .904 .564 r
.55446 .67907 m .55468 .67917 L .55552 .67774 L F
0 0 .134 r
.55468 .67917 m .55313 .67997 L .55481 .67923 L F
.55468 .67917 m .55259 .68184 L .55313 .67997 L F
.674 .904 .564 r
.55319 .68067 m .55468 .67917 L .55446 .67907 L F
0 0 .134 r
.55468 .67917 m .55481 .67923 L .55543 .67896 L F
.918 .736 .641 r
.53338 .60734 m .53464 .61069 L .53508 .60823 L F
.709 .706 .845 r
.41128 .59887 m .41223 .60125 L .41564 .60015 L F
.658 .525 .691 r
.52087 .65682 m .52003 .66134 L .51804 .65958 L F
.278 .77 .901 r
.52003 .66134 m .51731 .66113 L .51804 .65958 L F
.816 .596 .605 r
.58338 .59637 m .58644 .59939 L .58319 .59817 L F
.077 .33 .807 r
.58609 .60191 m .58319 .59817 L .58644 .59939 L F
.707 .517 .63 r
.58644 .59939 m .59058 .60199 L .58609 .60191 L F
.58644 .59939 m .59088 .5997 L .59058 .60199 L F
0 0 .222 r
.80946 .4988 m .80835 .49507 L .80733 .49791 L F
.207 .007 .373 r
.78675 .51005 m .78633 .51217 L .78554 .51203 L F
.991 .779 .52 r
.78524 .51097 m .78633 .51217 L .78675 .51005 L F
.009 .433 .864 r
.78763 .5124 m .78633 .51217 L .78524 .51097 L F
.7891 .51329 m .78633 .51217 L .78763 .5124 L F
.207 .007 .373 r
.78554 .51203 m .78633 .51217 L .78514 .5127 L F
.141 .464 .89 r
.73558 .50962 m .73647 .50889 L .73475 .50825 L F
.039 .281 .775 r
.73558 .50962 m .73801 .5118 L .73647 .50889 L F
.484 .116 .264 r
.41623 .62379 m .41432 .62253 L .41685 .62258 L F
.41623 .62379 m .4131 .62479 L .41432 .62253 L F
.52 .388 .641 r
.30948 .59668 m .31187 .59878 L .31183 .59615 L F
.30948 .59668 m .30974 .59936 L .31187 .59878 L F
.337 .144 .465 r
.45229 .67407 m .45442 .67353 L .45448 .67104 L F
.452 .241 .501 r
.45199 .67671 m .45442 .67353 L .45229 .67407 L F
.442 .77 .997 r
.44727 .60791 m .44351 .60718 L .44573 .60669 L F
.437 .526 .851 r
.4489 .60642 m .44727 .60791 L .44573 .60669 L F
.4489 .60642 m .44794 .60786 L .44727 .60791 L F
.429 .283 .58 r
.44794 .60786 m .44937 .61009 L .44727 .60791 L F
.181 .24 .689 r
.44727 .60791 m .44937 .61009 L .44819 .61029 L F
.654 .208 .178 r
.48109 .70991 m .47889 .71057 L .47788 .70936 L F
.799 .46 .414 r
.48109 .70991 m .48021 .71332 L .47889 .71057 L F
.12 0 .192 r
.48224 .71027 m .48109 .70991 L .48227 .70879 L F
.48168 .71088 m .48109 .70991 L .48224 .71027 L F
.48221 .71175 m .48021 .71332 L .48052 .71211 L F
.211 0 .313 r
.48083 .71178 m .48221 .71175 L .48295 .71153 L F
.564 .417 .64 r
.48083 .71178 m .48085 .71178 L .48086 .71175 L F
.48085 .71178 m .48295 .71153 L .48287 .71041 L F
.177 0 0 r
.48425 .71021 m .48287 .71041 L .48227 .70879 L F
0 0 .435 r
.48287 .71041 m .48295 .71153 L .48317 .71102 L F
.177 0 0 r
.48522 .71091 m .48521 .71091 L .48227 .70879 L F
.609 .603 .819 r
.48221 .71175 m .48317 .71102 L .48295 .71153 L F
.177 0 0 r
.48521 .71091 m .48221 .71175 L .48224 .71027 L F
.171 .263 .718 r
.48441 .70825 m .48522 .71091 L .48227 .70879 L F
0 0 .435 r
.48287 .71041 m .48317 .71102 L .48399 .70912 L F
.609 .603 .819 r
.48221 .71175 m .48399 .70912 L .48317 .71102 L F
.177 0 0 r
.48521 .71091 m .48374 .71059 L .48425 .71021 L F
.48374 .71059 m .48287 .71041 L .48425 .71021 L F
.48287 .71041 m .48224 .71027 L .48226 .70919 L F
.48287 .71041 m .48226 .70919 L .48227 .70879 L F
.171 .263 .718 r
.48441 .70825 m .48227 .70879 L .48269 .70798 L F
0 0 .435 r
.48269 .70798 m .48287 .71041 L .48399 .70912 L F
.564 .417 .64 r
.48224 .71027 m .48287 .71041 L .48281 .70966 L F
.48085 .71178 m .48287 .71041 L .48224 .71027 L F
.12 0 .192 r
.48221 .71175 m .48052 .71211 L .48168 .71088 L F
.211 0 .313 r
.48036 .71184 m .48221 .71175 L .48083 .71178 L F
.12 0 .192 r
.48168 .71088 m .48083 .71178 L .48109 .70991 L F
.48083 .71178 m .48052 .71211 L .48061 .71179 L F
.48083 .71178 m .48061 .71179 L .48109 .70991 L F
.564 .417 .64 r
.48036 .71184 m .48083 .71178 L .48269 .70798 L F
.48083 .71178 m .48086 .71175 L .48269 .70798 L F
.48085 .71178 m .48281 .70966 L .48269 .70798 L F
.12 0 .192 r
.48221 .71175 m .48168 .71088 L .48224 .71027 L F
.665 .55 .715 r
.19731 .56431 m .19942 .56177 L .19678 .56191 L F
.653 .635 .82 r
.75782 .50372 m .75419 .50105 L .75644 .50037 L F
.684 .614 .772 r
.76007 .50102 m .75782 .50372 L .75644 .50037 L F
.617 .515 .715 r
.76007 .50102 m .76035 .50328 L .75782 .50372 L F
.164 .141 .584 r
.31034 .6138 m .3113 .61004 L .30961 .61093 L F
.31034 .6138 m .31148 .61325 L .3113 .61004 L F
.184 .188 .628 r
.31034 .6138 m .31202 .61576 L .31148 .61325 L F
.565 .289 .456 r
.41171 .61337 m .41464 .61077 L .41179 .61093 L F
.451 0 0 r
.46555 .71863 m .46409 .71808 L .46215 .71695 L F
.359 0 0 r
.46824 .71809 m .46409 .71808 L .46555 .71863 L F
.957 .875 .714 r
.53543 .61276 m .53424 .61653 L .53317 .61554 L F
.88 .484 .276 r
.53621 .61835 m .53317 .61554 L .53424 .61653 L F
.783 .556 .591 r
.60132 .67074 m .5986 .67066 L .59924 .6714 L F
.60132 .67074 m .60153 .67133 L .59805 .67065 L F
.913 .973 .789 r
.60153 .67133 m .60075 .66851 L .6 .66868 L F
.59956 .6693 m .6 .66868 L .59915 .66888 L F
.60153 .67133 m .6 .66868 L .59956 .6693 L F
.783 .556 .591 r
.5986 .67066 m .59805 .67065 L .59843 .67089 L F
.5986 .67066 m .59843 .67089 L .59924 .6714 L F
.593 .571 .799 r
.54659 .59668 m .55033 .59915 L .54981 .59636 L F
.529 .138 .243 r
.54858 .59797 m .55212 .59592 L .54981 .59636 L F
.351 .595 .938 r
.75004 .52048 m .75103 .51927 L .74878 .51936 L F
.75004 .52048 m .75215 .52084 L .75103 .51927 L F
.652 .835 .971 r
.76082 .51866 m .76103 .52013 L .76392 .51898 L F
.522 .312 .536 r
.77766 .48404 m .77775 .48633 L .78025 .48352 L F
0 .229 .625 r
.50377 .68948 m .50609 .69077 L .50757 .69161 L F
.468 .812 .999 r
.50609 .69077 m .50969 .69114 L .50757 .69161 L F
0 .132 .666 r
.50609 .69077 m .50757 .69161 L .50969 .69114 L F
.50609 .69077 m .50712 .69358 L .50757 .69161 L F
.50712 .69358 m .5072 .69357 L .50757 .69161 L F
.50609 .69077 m .50697 .69242 L .50715 .69357 L F
.50609 .69077 m .50715 .69357 L .50712 .69358 L F
.50712 .69358 m .50717 .69373 L .5072 .69357 L F
.507 .6926 m .50749 .6937 L .50717 .69373 L F
.628 .599 .802 r
.50721 .69285 m .50804 .69328 L .50609 .69077 L F
0 .132 .666 r
.50691 .69197 m .5072 .69284 L .507 .6926 L F
.5072 .69284 m .50749 .6937 L .507 .6926 L F
.50712 .69358 m .50715 .69357 L .50717 .69373 L F
.628 .599 .802 r
.50263 .69054 m .50389 .69436 L .5074 .69344 L F
.50721 .69285 m .5074 .69344 L .50804 .69328 L F
0 0 .034 r
.5074 .69344 m .50763 .69334 L .50804 .69328 L F
.823 .417 .28 r
.50775 .69349 m .50804 .69328 L .50763 .69334 L F
0 .132 .666 r
.50691 .69197 m .50804 .69364 L .50749 .6937 L F
0 0 .034 r
.50389 .69436 m .50441 .69388 L .50671 .69363 L F
.50441 .69388 m .50449 .6938 L .50619 .69367 L F
.50619 .69368 m .50619 .69367 L .50671 .69363 L F
.50441 .69388 m .50619 .69367 L .50619 .69368 L F
.657 .323 .397 r
.50692 .69605 m .50389 .69436 L .50717 .69373 L F
.823 .417 .28 r
.50639 .69451 m .50775 .69349 L .50449 .6938 L F
.628 .599 .802 r
.50263 .69054 m .5074 .69344 L .50721 .69285 L F
0 0 .034 r
.50671 .69363 m .50449 .6938 L .50763 .69334 L F
.50671 .69363 m .50763 .69334 L .5074 .69344 L F
.823 .417 .28 r
.50775 .69349 m .50763 .69334 L .50449 .6938 L F
.628 .599 .802 r
.50263 .69054 m .50721 .69285 L .50609 .69077 L F
.708 .698 .839 r
.50558 .6912 m .50639 .69451 L .50449 .6938 L F
.688 .425 0 r
.50612 .69341 m .50632 .69423 L .50639 .69451 L F
.50558 .6912 m .50609 .69328 L .50612 .69341 L F
.50609 .69328 m .50632 .69423 L .50612 .69341 L F
0 .132 .666 r
.50609 .69077 m .50691 .69197 L .50697 .69242 L F
.493 .359 .627 r
.22406 .55648 m .22544 .55883 L .22312 .55915 L F
.52 .45 .718 r
.30897 .60801 m .31098 .60749 L .31098 .60355 L F
.459 .379 .679 r
.30897 .60801 m .3113 .61004 L .31098 .60749 L F
.30897 .60801 m .30961 .61093 L .3113 .61004 L F
.722 .555 .664 r
.55143 .61621 m .55332 .61628 L .55361 .61379 L F
.689 .486 .608 r
.44534 .61347 m .44568 .61696 L .44248 .61632 L F
.627 .482 .665 r
.44819 .61029 m .44846 .61305 L .44534 .61347 L F
.611 .429 .611 r
.44892 .61552 m .44534 .61347 L .44846 .61305 L F
.44892 .61552 m .44568 .61696 L .44534 .61347 L F
.695 .687 .839 r
.73554 .49993 m .73632 .50247 L .73305 .50073 L F
.823 .918 .901 r
.73632 .50247 m .7332 .5032 L .73305 .50073 L F
.577 .614 .853 r
.73803 .4994 m .73632 .50247 L .73554 .49993 L F
.612 .66 .872 r
.73968 .50137 m .73632 .50247 L .73803 .4994 L F
.801 .832 .875 r
.4799 .66799 m .4774 .67042 L .48129 .67102 L F
.634 .204 .209 r
.47662 .67307 m .48129 .67102 L .4774 .67042 L F
.47662 .67307 m .48195 .67278 L .48129 .67102 L F
.396 .432 .78 r
.48129 .67102 m .48186 .66683 L .4799 .66799 L F
.48129 .67102 m .48585 .67261 L .48186 .66683 L F
.38 0 0 r
.48311 .67205 m .48129 .67102 L .48195 .67278 L F
.48311 .67205 m .48585 .67261 L .48129 .67102 L F
.691 .746 .894 r
.73302 .48811 m .73388 .48985 L .73037 .48927 L F
.67 .736 .9 r
.73641 .48879 m .73388 .48985 L .73302 .48811 L F
.973 .718 .486 r
.53543 .61276 m .53463 .6133 L .53464 .61069 L F
.219 .72 .907 r
.53397 .6131 m .53463 .6133 L .53307 .61322 L F
.957 .875 .714 r
.53543 .61276 m .53492 .61339 L .53463 .6133 L F
.219 .72 .907 r
.53596 .61284 m .53463 .6133 L .53397 .6131 L F
.957 .875 .714 r
.53492 .61339 m .53317 .61554 L .53463 .6133 L F
.472 0 0 r
.53543 .61276 m .53463 .6133 L .53806 .61309 L F
.642 .639 .831 r
.72791 .49148 m .7248 .48939 L .72702 .4893 L F
.778 .812 .88 r
.73037 .48927 m .72791 .49148 L .72702 .4893 L F
.571 .72 .943 r
.77225 .5053 m .77068 .50737 L .76978 .50579 L F
.554 .695 .933 r
.77225 .5053 m .77318 .50704 L .77068 .50737 L F
.065 0 0 r
.53006 .63306 m .53267 .63251 L .53395 .63175 L F
.675 .423 .533 r
.53395 .63175 m .53574 .63407 L .53665 .63188 L F
.823 .396 .228 r
.53267 .63251 m .53574 .63407 L .53395 .63175 L F
.793 .701 .764 r
.5233 .6406 m .51968 .64212 L .52098 .64135 L F
.474 .753 .991 r
.41827 .59982 m .41973 .59871 L .41739 .59881 L F
.41827 .59982 m .4207 .59933 L .41973 .59871 L F
.706 .223 0 r
.80739 .49132 m .80626 .48959 L .80521 .48863 L F
.806 .714 .763 r
.22914 .55895 m .22544 .55883 L .22758 .55763 L F
.388 .695 .981 r
.22758 .55763 m .22954 .55755 L .22914 .55895 L F
.258 .554 .93 r
.22954 .55755 m .23074 .5587 L .22914 .55895 L F
.763 .274 0 r
.55712 .6314 m .55723 .63244 L .55633 .63011 L F
.55712 .6314 m .55851 .63339 L .55723 .63244 L F
.216 0 0 r
.53696 .6888 m .536 .68908 L .53346 .68883 L F
.76 .488 0 r
.53613 .68541 m .53669 .68816 L .53696 .6888 L F
.827 .991 .734 r
.53669 .68816 m .536 .68908 L .53696 .6888 L F
.59 .439 .645 r
.50173 .65348 m .49867 .65119 L .50087 .65073 L F
.50173 .65348 m .49896 .65406 L .49867 .65119 L F
.384 .047 .265 r
.49394 .65705 m .49078 .65938 L .49231 .65729 L F
.49394 .65705 m .49278 .65951 L .49078 .65938 L F
.333 0 .147 r
.49631 .65696 m .49278 .65951 L .49394 .65705 L F
.592 .276 .403 r
.43416 .6166 m .43297 .61913 L .43067 .61899 L F
.606 .291 .409 r
.4364 .61848 m .43416 .6166 L .43661 .61635 L F
.4364 .61848 m .43297 .61913 L .43416 .6166 L F
.647 .839 .974 r
.77664 .50729 m .77318 .50704 L .77568 .50628 L F
.404 .689 .977 r
.77798 .506 m .77664 .50729 L .77568 .50628 L F
.77798 .506 m .77883 .50753 L .77664 .50729 L F
.73 .695 .817 r
.54107 .65574 m .54194 .65672 L .54115 .654 L F
0 .242 .737 r
.46494 .68865 m .46735 .69039 L .46632 .6891 L F
.46494 .68865 m .46632 .6891 L .46321 .68975 L F
.671 .197 .118 r
.46494 .68865 m .46321 .68975 L .46264 .6884 L F
.463 .859 .972 r
.46321 .68975 m .46394 .6896 L .46409 .6888 L F
.46394 .6896 m .46632 .6891 L .46409 .6888 L F
0 0 .48 r
.46632 .6891 m .4667 .68625 L .46409 .6888 L F
.693 .691 .844 r
.46689 .69005 m .46611 .69207 L .46409 .6888 L F
.46689 .69005 m .46409 .6888 L .46678 .69016 L F
.343 .052 .319 r
.46409 .6888 m .4667 .68625 L .46581 .68967 L F
0 .266 .771 r
.46423 .68808 m .46409 .6888 L .46581 .68967 L F
.46239 .68623 m .46409 .6888 L .46423 .68808 L F
.701 .694 .84 r
.46409 .6888 m .46372 .69095 L .46321 .68975 L F
.504 .333 .583 r
.45879 .69074 m .45883 .69318 L .45646 .69383 L F
.658 .511 .672 r
.4609 .6908 m .45883 .69318 L .45879 .69074 L F
.4609 .6908 m .46149 .69326 L .45883 .69318 L F
.574 .169 .237 r
.45883 .69318 m .46149 .69326 L .45996 .69545 L F
.425 .289 .591 r
.46321 .68975 m .46149 .69326 L .4609 .6908 L F
.46321 .68975 m .46338 .69293 L .46149 .69326 L F
.66 .381 .487 r
.46338 .69293 m .45996 .69545 L .46149 .69326 L F
.46338 .69293 m .46341 .69569 L .45996 .69545 L F
.701 .694 .84 r
.46409 .6888 m .46611 .69207 L .46338 .69293 L F
.635 .361 .486 r
.46338 .69293 m .46567 .69497 L .46341 .69569 L F
.602 .369 .535 r
.46611 .69207 m .46567 .69497 L .46338 .69293 L F
.774 .364 .275 r
.46092 .69456 m .46361 .69291 L .45838 .69173 L F
.46361 .69291 m .46363 .6929 L .4636 .69289 L F
.46361 .69291 m .4636 .69289 L .45838 .69173 L F
.701 .694 .84 r
.46372 .69095 m .46347 .69241 L .46321 .68975 L F
.46347 .69241 m .46338 .69293 L .46333 .69189 L F
.46347 .69241 m .46333 .69189 L .46321 .68975 L F
.671 .197 .118 r
.46264 .6884 m .46321 .68975 L .46128 .68825 L F
.404 .765 .994 r
.31472 .62508 m .31348 .62422 L .31272 .62532 L F
.31472 .62508 m .31348 .62422 L .31272 .62532 L F
.579 .492 .721 r
.31251 .62716 m .31472 .62508 L .31272 .62532 L F
.161 .444 .876 r
.31272 .62532 m .31348 .62422 L .31202 .62377 L F
0 .191 .668 r
.21404 .58762 m .21761 .59047 L .2152 .59093 L F
.591 .855 .509 r
.21761 .59047 m .21512 .59341 L .2152 .59093 L F
.29 .777 .709 r
.22685 .56262 m .22485 .56326 L .22346 .56382 L F
.276 .768 .703 r
.22681 .56253 m .22685 .56262 L .22909 .56201 L F
.22681 .56253 m .22485 .56326 L .22685 .56262 L F
.452 .365 .667 r
.3138 .63174 m .3158 .62728 L .31251 .62716 L F
.3138 .63174 m .31617 .63169 L .3158 .62728 L F
.649 .77 .937 r
.79767 .48075 m .79522 .48162 L .79421 .48013 L F
.374 .474 .834 r
.44866 .70083 m .45029 .7034 L .45147 .70254 L F
.451 .247 .51 r
.45029 .7034 m .45205 .705 L .45147 .70254 L F
.45029 .7034 m .44978 .70617 L .45205 .705 L F
.734 .777 .887 r
.4766 .70771 m .47448 .70901 L .47788 .70936 L F
.806 .795 .842 r
.47891 .70689 m .47788 .70936 L .47743 .70878 L F
.47724 .70748 m .47743 .70878 L .4766 .70771 L F
.47891 .70689 m .47743 .70878 L .47724 .70748 L F
.47984 .70657 m .47934 .70728 L .47891 .70689 L F
.47934 .70728 m .47788 .70936 L .47891 .70689 L F
.47984 .70657 m .4766 .70771 L .47905 .70747 L F
.553 .052 .02 r
.47984 .70657 m .47905 .70747 L .47862 .70648 L F
.47812 .70644 m .47905 .70747 L .47554 .70625 L F
.525 .725 .965 r
.47772 .70435 m .47999 .70647 L .4785 .70652 L F
.634 .144 .072 r
.47905 .70747 m .48269 .70798 L .47984 .70657 L F
.192 0 0 r
.47981 .70664 m .48021 .70667 L .47984 .70657 L F
.023 0 .309 r
.47984 .70657 m .48021 .70667 L .48168 .70484 L F
.525 .725 .965 r
.47999 .70647 m .48021 .70667 L .47981 .70664 L F
.192 0 0 r
.47554 .70625 m .47981 .70664 L .47984 .70657 L F
.525 .725 .965 r
.47999 .70647 m .47981 .70664 L .4785 .70652 L F
.678 .778 .926 r
.48168 .70484 m .48021 .70667 L .47999 .70647 L F
0 0 0 r
.48168 .70484 m .48044 .70603 L .47984 .70657 L F
.48081 .70571 m .47981 .70664 L .47984 .70657 L F
.678 .778 .926 r
.48168 .70484 m .47999 .70647 L .47772 .70435 L F
0 0 0 r
.48168 .70484 m .48081 .70571 L .48044 .70603 L F
.48081 .70571 m .47976 .70676 L .47981 .70664 L F
.47976 .70676 m .47905 .70747 L .47984 .70657 L F
.525 .725 .965 r
.4769 .70507 m .4785 .70652 L .47554 .70625 L F
.47772 .70435 m .4785 .70652 L .4769 .70507 L F
.402 .499 .843 r
.4769 .70507 m .4783 .70663 L .47772 .70435 L F
.4783 .70663 m .47905 .70747 L .47872 .70669 L F
.4783 .70663 m .47872 .70669 L .47772 .70435 L F
.47554 .70625 m .47715 .70681 L .4769 .70507 L F
.47715 .70681 m .47905 .70747 L .4769 .70507 L F
.526 .521 .793 r
.47889 .71057 m .4766 .70771 L .47788 .70936 L F
.565 .289 .456 r
.41171 .61337 m .41413 .61333 L .41464 .61077 L F
.489 .168 .348 r
.41413 .61333 m .41741 .61045 L .41464 .61077 L F
.15 .402 .848 r
.21865 .5499 m .21832 .55168 L .21663 .55006 L F
.21865 .5499 m .22024 .55246 L .21832 .55168 L F
0 0 .068 r
.49208 .64674 m .49194 .64612 L .49382 .64409 L F
.49208 .64674 m .49196 .64783 L .49194 .64612 L F
.454 .218 .465 r
.44483 .68235 m .44719 .67979 L .44533 .68011 L F
.331 .514 .886 r
.32977 .63551 m .33072 .63735 L .33135 .63579 L F
.726 .949 .951 r
.33135 .63579 m .33072 .63735 L .33313 .63614 L F
.33135 .63579 m .33072 .63735 L .33313 .63614 L F
0 0 0 r
.28545 .66151 m .28367 .66272 L .28464 .66203 L F
.28464 .66203 m .28367 .66272 L .28545 .66151 L F
.952 .685 .493 r
.54115 .654 m .54424 .65405 L .54412 .65453 L F
0 0 0 r
.54587 .65329 m .54412 .65453 L .54424 .65405 L F
0 .329 .814 r
.35471 .62094 m .35433 .62193 L .35265 .61955 L F
.011 .349 .826 r
.35471 .62094 m .35574 .62271 L .35433 .62193 L F
.335 .723 .983 r
.47219 .70894 m .47448 .70901 L .47378 .70819 L F
.524 0 0 r
.49548 .69684 m .49789 .69887 L .49649 .69792 L F
.49548 .69684 m .49649 .69792 L .4954 .69658 L F
.894 .946 .835 r
.49789 .69381 m .49548 .69684 L .49475 .69578 L F
.524 0 0 r
.49548 .69684 m .4954 .69658 L .49475 .69578 L F
.408 .858 .798 r
.49548 .69684 m .49419 .69751 L .49553 .69699 L F
.49548 .69684 m .49553 .69699 L .49632 .69669 L F
.94 .582 .185 r
.56334 .59391 m .56409 .5935 L .5604 .59293 L F
.192 .716 .859 r
.55924 .59391 m .56157 .59369 L .56334 .59391 L F
.163 0 0 r
.56157 .59369 m .56258 .59385 L .56334 .59391 L F
.94 .582 .185 r
.56334 .59391 m .56464 .59557 L .56422 .59399 L F
.241 .545 .927 r
.56334 .59391 m .56512 .59425 L .56464 .59557 L F
.163 0 0 r
.56258 .59385 m .56512 .59425 L .56334 .59391 L F
.94 .582 .185 r
.56334 .59391 m .56422 .59399 L .56409 .5935 L F
.562 .289 .46 r
.54551 .68236 m .54442 .68563 L .54161 .68572 L F
.321 .059 .352 r
.54633 .68466 m .54551 .68236 L .54779 .68212 L F
.322 0 .183 r
.54853 .68405 m .54633 .68466 L .54779 .68212 L F
.517 .838 .999 r
.54853 .68405 m .54813 .68401 L .54633 .68466 L F
.321 .059 .352 r
.54633 .68466 m .54452 .68531 L .54551 .68236 L F
.517 .838 .999 r
.54813 .68401 m .54519 .68377 L .54633 .68466 L F
.321 .059 .352 r
.54633 .68466 m .54442 .68563 L .54452 .68531 L F
.969 .918 .698 r
.2875 .8246 m .28533 .82623 L .28609 .8243 L F
.724 .978 .918 r
.28609 .8243 m .28765 .82331 L .2875 .8246 L F
.822 .989 .725 r
.28765 .82331 m .28533 .82623 L .2875 .8246 L F
0 0 0 r
.4803 .72004 m .48156 .71926 L .48288 .71831 L F
.562 .029 0 r
.48156 .71926 m .48523 .71964 L .48288 .71831 L F
.591 .282 .413 r
.52277 .66779 m .52267 .67069 L .52003 .67045 L F
0 0 .267 r
.52383 .66921 m .52277 .66779 L .52483 .66744 L F
.52383 .66921 m .52267 .67069 L .52277 .66779 L F
.196 .444 .87 r
.7461 .51856 m .74728 .51746 L .74574 .5171 L F
.254 .541 .923 r
.7461 .51856 m .74878 .51936 L .74728 .51746 L F
.58 .603 .839 r
.43194 .59545 m .43507 .59664 L .43279 .59717 L F
.324 .212 .569 r
.44395 .68876 m .44564 .69067 L .44506 .68825 L F
.44395 .68876 m .44413 .69135 L .44564 .69067 L F
.602 .638 .859 r
.50318 .67739 m .5051 .68042 L .50682 .67935 L F
.349 .529 .891 r
.44473 .69687 m .44719 .69994 L .4483 .69972 L F
0 .12 .648 r
.2258 .55706 m .22406 .55648 L .22449 .55492 L F
.2258 .55706 m .22544 .55883 L .22406 .55648 L F
.942 .876 .742 r
.59058 .63641 m .59183 .6372 L .59046 .64007 L F
.38 0 .116 r
.797 .50432 m .79803 .50505 L .79699 .50638 L F
.493 .874 .975 r
.39914 .59145 m .39805 .5927 L .40049 .59117 L F
.39914 .59145 m .39701 .59214 L .39805 .5927 L F
.52 .452 .72 r
.44124 .5984 m .43983 .60233 L .43888 .5987 L F
.44124 .5984 m .44198 .60182 L .43983 .60233 L F
.516 .435 .703 r
.44198 .60182 m .4424 .60423 L .43983 .60233 L F
.508 .436 .71 r
.4424 .60423 m .44036 .60456 L .43983 .60233 L F
.507 .157 .307 r
.42251 .61963 m .42449 .62087 L .42229 .62108 L F
.543 .108 .164 r
.425 .61987 m .42449 .62087 L .42251 .61963 L F
.549 .026 0 r
.46996 .71788 m .4701 .71894 L .47129 .71746 L F
.526 .042 .05 r
.47222 .71914 m .47129 .71746 L .4701 .71894 L F
.47222 .71914 m .47421 .71918 L .47129 .71746 L F
.326 .392 .777 r
.76353 .48959 m .76686 .49154 L .76922 .49083 L F
.249 0 0 r
.38128 .63607 m .38016 .63683 L .37785 .63711 L F
.209 0 0 r
.38352 .63576 m .38016 .63683 L .38128 .63607 L F
.379 .696 .982 r
.46475 .69839 m .46582 .70039 L .4624 .69867 L F
.582 .537 .77 r
.53922 .68584 m .54161 .68572 L .54083 .68227 L F
.365 .092 .361 r
.55162 .70048 m .54899 .70322 L .55101 .70237 L F
.55162 .70048 m .54899 .70322 L .55101 .70237 L F
.326 .057 .343 r
.55356 .69972 m .55101 .70237 L .55162 .70048 L F
.55356 .69972 m .55101 .70237 L .55162 .70048 L F
0 .069 .626 r
.57886 .65301 m .58017 .6564 L .5787 .65402 L F
.375 0 0 r
.52427 .63359 m .52658 .634 L .5278 .6337 L F
.444 0 .05 r
.52658 .634 m .53006 .63306 L .5278 .6337 L F
.702 .386 0 r
.57107 .65352 m .57224 .65687 L .57178 .65565 L F
0 0 .52 r
.57224 .65687 m .57344 .65793 L .57178 .65565 L F
.57224 .65687 m .57385 .65953 L .57344 .65793 L F
.18 .363 .809 r
.33313 .63614 m .33399 .63541 L .33135 .63579 L F
.33313 .63614 m .335 .63702 L .33399 .63541 L F
.878 .772 .741 r
.57307 .63647 m .5728 .63623 L .57318 .63812 L F
.57696 .63986 m .5754 .63566 L .5728 .63623 L F
0 0 .212 r
.57299 .63615 m .57318 .63812 L .5728 .63623 L F
0 0 .19 r
.57299 .63615 m .57324 .63898 L .57318 .63812 L F
.57324 .63898 m .57341 .64095 L .57318 .63812 L F
.878 .772 .741 r
.57696 .63986 m .57307 .63647 L .57318 .63812 L F
.57696 .63986 m .57711 .63733 L .5754 .63566 L F
.928 .794 .691 r
.57341 .64095 m .57696 .63986 L .57318 .63812 L F
.57341 .64095 m .5745 .64165 L .57696 .63986 L F
.153 .355 .81 r
.50827 .67607 m .50751 .67723 L .50606 .67428 L F
.50827 .67607 m .50606 .67428 L .50625 .6743 L F
.50827 .67607 m .50594 .67403 L .50857 .67356 L F
.205 0 0 r
.50501 .6754 m .50731 .67509 L .50781 .67449 L F
.50697 .67439 m .50781 .67449 L .50857 .67356 L F
.50501 .6754 m .50781 .67449 L .50697 .67439 L F
.153 .355 .81 r
.50625 .6743 m .50606 .67428 L .50594 .67403 L F
.529 .299 .51 r
.50827 .67607 m .50682 .67935 L .50751 .67723 L F
.496 .137 .287 r
.53806 .61309 m .54045 .61297 L .54127 .61143 L F
.83 .369 .115 r
.59585 .59001 m .59924 .59299 L .59907 .59068 L F
.023 0 .087 r
.57931 .59716 m .57954 .59764 L .5777 .59943 L F
.444 0 .096 r
.57931 .59716 m .58171 .59805 L .57954 .59764 L F
.57931 .59716 m .58338 .59637 L .58171 .59805 L F
.773 .652 .728 r
.60522 .6075 m .60677 .61075 L .60811 .60757 L F
.39 .341 .682 r
.22353 .5659 m .22126 .56424 L .22346 .56382 L F
.22353 .5659 m .22171 .56769 L .22126 .56424 L F
.452 .112 .296 r
.77042 .49236 m .76993 .49454 L .76742 .49491 L F
.178 0 .208 r
.77206 .49329 m .77042 .49236 L .77294 .49183 L F
.77206 .49329 m .76993 .49454 L .77042 .49236 L F
.333 .789 .947 r
.78128 .49003 m .78485 .49006 L .78432 .48944 L F
.441 .729 .988 r
.78485 .49006 m .78662 .48856 L .78432 .48944 L F
.78485 .49006 m .7878 .48991 L .78662 .48856 L F
.531 .259 .448 r
.54076 .66195 m .54234 .66201 L .54261 .66003 L F
.572 .295 .458 r
.54234 .66201 m .54492 .66178 L .54261 .66003 L F
.489 .321 .58 r
.54261 .66003 m .54492 .66178 L .54483 .65932 L F
.179 .593 .941 r
.20496 .54552 m .20171 .54421 L .20354 .54452 L F
0 .422 .841 r
.2059 .54538 m .20496 .54552 L .20354 .54452 L F
.2059 .54538 m .20733 .5466 L .20496 .54552 L F
.752 .615 .707 r
.52984 .68064 m .5294 .68431 L .52548 .68218 L F
.826 .731 .759 r
.53091 .67677 m .52984 .68064 L .52896 .67809 L F
.654 .315 .387 r
.47171 .69137 m .47066 .69347 L .46848 .6914 L F
.657 .558 .731 r
.4746 .69164 m .4733 .69082 L .47291 .69024 L F
.4766 .69329 m .4733 .69082 L .4746 .69164 L F
.315 .199 .558 r
.47228 .69017 m .4733 .69082 L .47171 .69137 L F
.47318 .68829 m .4733 .69082 L .47228 .69017 L F
.703 .371 .412 r
.47414 .6936 m .47171 .69137 L .4733 .69082 L F
.47414 .6936 m .47066 .69347 L .47171 .69137 L F
.254 .453 .862 r
.78767 .50851 m .78675 .51005 L .78522 .50736 L F
.991 .779 .52 r
.78524 .51097 m .78675 .51005 L .78767 .50851 L F
0 0 0 r
.54167 .71162 m .54318 .71071 L .54058 .71341 L F
.424 .756 .995 r
.78476 .50639 m .78259 .50759 L .78114 .50723 L F
.78476 .50639 m .78522 .50736 L .78259 .50759 L F
.507 .475 .757 r
.55019 .64494 m .55109 .64832 L .54905 .64852 L F
.555 .424 .657 r
.55218 .65014 m .54905 .64852 L .55109 .64832 L F
.55218 .65014 m .54937 .651 L .54905 .64852 L F
.645 .919 .628 r
.5198 .669 m .51861 .6698 L .52109 .66722 L F
.579 .492 .721 r
.31251 .62716 m .3158 .62728 L .31472 .62508 L F
0 .113 .644 r
.46848 .6914 m .46959 .69205 L .46735 .69039 L F
.46848 .6914 m .47066 .69347 L .46959 .69205 L F
.256 0 .317 r
.53665 .63188 m .53574 .63407 L .53857 .63077 L F
.363 .444 .81 r
.34654 .60908 m .3453 .61089 L .34415 .60764 L F
.429 .407 .733 r
.34654 .60908 m .34565 .61332 L .3453 .61089 L F
.497 .726 .974 r
.40982 .58377 m .40907 .58552 L .40776 .58464 L F
.40982 .58377 m .4111 .58515 L .40907 .58552 L F
.378 0 0 r
.39176 .6332 m .38802 .63493 L .38954 .63363 L F
0 0 .394 r
.27725 .83635 m .27819 .83757 L .28003 .83633 L F
.27725 .83635 m .2775 .83891 L .27819 .83757 L F
.848 .677 .67 r
.60522 .6075 m .60347 .61017 L .60677 .61075 L F
.814 .587 .596 r
.6032 .61269 m .60677 .61075 L .60347 .61017 L F
.6032 .61269 m .60648 .61313 L .60677 .61075 L F
.12 .029 .468 r
.52233 .65856 m .52087 .65682 L .52339 .65631 L F
.52233 .65856 m .52003 .66134 L .52039 .65941 L F
.52233 .65856 m .52039 .65941 L .52085 .65692 L F
.404 .057 .259 r
.52544 .65504 m .5247 .65808 L .52233 .65856 L F
.592 .413 .608 r
.52544 .65504 m .52339 .65631 L .52575 .65375 L F
.404 .057 .259 r
.52544 .65504 m .52233 .65856 L .52339 .65631 L F
.571 .573 .816 r
.52233 .65856 m .5247 .65808 L .52316 .6545 L F
.363 .819 .933 r
.52233 .65856 m .5247 .65808 L .52293 .6583 L F
.12 .029 .468 r
.52233 .65856 m .52085 .65692 L .52105 .65703 L F
.663 .221 .191 r
.51852 .65811 m .52233 .65856 L .52205 .65727 L F
.363 .819 .933 r
.52233 .65856 m .52293 .6583 L .52145 .65848 L F
.663 .221 .191 r
.51852 .65811 m .52165 .65736 L .52087 .657 L F
.52165 .65736 m .52205 .65727 L .52107 .65705 L F
.52165 .65736 m .52107 .65705 L .52087 .657 L F
.12 .029 .468 r
.52105 .65703 m .52085 .65692 L .52087 .65682 L F
.798 .588 .618 r
.59104 .58408 m .59246 .58691 L .59431 .58416 L F
.4 .853 .891 r
.36887 .58229 m .36656 .58299 L .36484 .583 L F
.499 .217 .418 r
.51133 .65652 m .51389 .65617 L .51405 .65422 L F
.606 .348 .501 r
.51389 .65617 m .51663 .6539 L .51405 .65422 L F
.63 .835 .979 r
.75215 .52084 m .75555 .52112 L .75462 .52028 L F
.75 .928 .948 r
.75665 .51904 m .75555 .52112 L .75777 .52003 L F
.75665 .51904 m .75462 .52028 L .75555 .52112 L F
.007 0 .068 r
.19942 .56177 m .20062 .56119 L .20192 .55883 L F
.909 .504 .134 r
.20192 .55883 m .20002 .55791 L .20039 .55744 L F
.468 .537 .845 r
.20062 .56119 m .20002 .55791 L .20192 .55883 L F
.844 .66 .653 r
.60648 .61313 m .60804 .6164 L .60829 .61388 L F
0 0 .515 r
.57072 .65117 m .57046 .65033 L .56906 .64822 L F
.891 .613 .101 r
.57072 .65117 m .57053 .6526 L .57046 .65033 L F
.57072 .65117 m .57107 .65352 L .57053 .6526 L F
.279 .748 .943 r
.39593 .58324 m .39806 .58308 L .39948 .58364 L F
.253 .737 .927 r
.39806 .58308 m .40194 .58341 L .39948 .58364 L F
.008 0 0 r
.19198 .54436 m .19563 .54369 L .1927 .54443 L F
.19198 .54436 m .19411 .54409 L .19407 .54398 L F
.252 .756 .883 r
.19233 .54381 m .19411 .54409 L .19198 .54436 L F
.011 0 0 r
.19421 .54436 m .19411 .54409 L .19233 .54381 L F
.19429 .54438 m .19411 .54409 L .19421 .54436 L F
.008 0 0 r
.19407 .54398 m .19411 .54409 L .19563 .54369 L F
.116 .667 .724 r
.19411 .54409 m .19786 .54361 L .19563 .54369 L F
.637 .65 .847 r
.27756 .84119 m .27819 .83757 L .2775 .83891 L F
.716 .986 .883 r
.55271 .59881 m .55582 .59677 L .55387 .59705 L F
.311 .793 .727 r
.55582 .59677 m .55724 .59607 L .55387 .59705 L F
.55582 .59677 m .55806 .5959 L .55724 .59607 L F
.693 .595 .742 r
.75195 .50397 m .74846 .50125 L .7519 .5015 L F
.657 .512 .675 r
.75419 .50105 m .75195 .50397 L .7519 .5015 L F
.448 .236 .499 r
.53265 .67379 m .53526 .6706 L .5335 .67177 L F
.521 .12 .223 r
.48194 .68571 m .48084 .68696 L .47893 .68703 L F
.583 .606 .841 r
.48301 .68284 m .48194 .68571 L .48126 .6828 L F
.48301 .68284 m .48363 .68543 L .48194 .68571 L F
0 0 0 r
.48363 .68543 m .48084 .68696 L .48194 .68571 L F
.403 .833 .956 r
.38673 .59304 m .38525 .5927 L .38304 .59319 L F
.115 .653 .853 r
.38673 .59304 m .38888 .59308 L .38525 .5927 L F
0 .019 .561 r
.56021 .68241 m .55798 .67967 L .56008 .68008 L F
.49 .745 .985 r
.31123 .61959 m .31403 .61948 L .31209 .61815 L F
.323 .552 .917 r
.22229 .5525 m .22202 .55429 L .22024 .55246 L F
.22229 .5525 m .22449 .55492 L .22202 .55429 L F
.62 .363 .507 r
.39499 .61875 m .39749 .61883 L .39787 .61656 L F
.383 .154 .438 r
.39787 .61656 m .39749 .61883 L .39982 .61592 L F
.771 .674 .757 r
.55033 .59915 m .55033 .60194 L .55271 .59881 L F
.968 .814 .389 r
.55033 .59915 m .54992 .6014 L .55033 .60194 L F
.428 .36 .678 r
.22353 .5659 m .22205 .57014 L .22171 .56769 L F
.438 .463 .788 r
.55971 .59863 m .5604 .59539 L .55806 .5959 L F
.55971 .59863 m .56187 .59942 L .5604 .59539 L F
0 0 0 r
.5455 .70793 m .54318 .71071 L .54394 .70867 L F
.54394 .70867 m .54383 .70892 L .5455 .70793 L F
.114 0 0 r
.54128 .70932 m .54383 .70892 L .54394 .70867 L F
.709 .706 .845 r
.41128 .59887 m .41564 .60015 L .41389 .59874 L F
.724 .841 .937 r
.41389 .59874 m .41564 .60015 L .41739 .59881 L F
.488 .425 .712 r
.5422 .60505 m .54399 .6015 L .54181 .6017 L F
.5422 .60505 m .54458 .605 L .54399 .6015 L F
.555 .369 .583 r
.5422 .60505 m .54401 .60656 L .54458 .605 L F
.5422 .60505 m .54287 .60774 L .54401 .60656 L F
.835 .808 .824 r
.31884 .63089 m .31791 .6361 L .32017 .63152 L F
.31884 .63089 m .31485 .63589 L .31791 .6361 L F
.188 .053 .455 r
.56821 .59532 m .56824 .59535 L .56954 .59635 L F
.56821 .59532 m .56722 .59348 L .56824 .59535 L F
.52 .797 .996 r
.56633 .59773 m .56527 .59928 L .56464 .59557 L F
.56633 .59773 m .56809 .59874 L .56527 .59928 L F
.188 .344 .79 r
.56527 .59928 m .56633 .59773 L .56399 .59831 L F
.56527 .59928 m .56769 .60099 L .56633 .59773 L F
.116 .666 .715 r
.55271 .59881 m .55249 .59882 L .55033 .59915 L F
.716 .986 .883 r
.55271 .59881 m .55387 .59705 L .55249 .59882 L F
.267 .726 .953 r
.19786 .54361 m .19994 .54356 L .20171 .54421 L F
.059 .566 .883 r
.20196 .54374 m .20354 .54452 L .20171 .54421 L F
.782 .542 .574 r
.53777 .67046 m .54135 .67093 L .54134 .66846 L F
.437 .568 .888 r
.53981 .66557 m .54134 .66846 L .54306 .66752 L F
.216 .094 .491 r
.54134 .66846 m .54314 .66987 L .54306 .66752 L F
.54134 .66846 m .54135 .67093 L .54314 .66987 L F
.385 0 0 r
.54012 .65809 m .53754 .65848 L .53882 .65692 L F
.967 .818 .644 r
.33602 .63974 m .33425 .6389 L .335 .63702 L F
0 0 .097 r
.33602 .63974 m .33602 .63963 L .33425 .6389 L F
.33602 .63974 m .33631 .64198 L .33602 .63963 L F
.241 0 0 r
.34138 .584 m .34366 .58377 L .34522 .58262 L F
.105 0 0 r
.34366 .58377 m .34741 .58254 L .34522 .58262 L F
.693 .595 .742 r
.75195 .50397 m .74977 .50483 L .74846 .50125 L F
.671 .532 .686 r
.75195 .50397 m .74964 .50713 L .74977 .50483 L F
.263 .226 .627 r
.19942 .56177 m .20108 .56384 L .20062 .56119 L F
.385 .217 .527 r
.48341 .67967 m .48126 .6828 L .48081 .68035 L F
.788 .565 .599 r
.47698 .72249 m .4803 .72004 L .4769 .72014 L F
.265 .31 .722 r
.4803 .72004 m .48242 .72239 L .48156 .71926 L F
.859 .627 .586 r
.60917 .62465 m .61088 .62785 L .6111 .62521 L F
.45 .207 .453 r
.4935 .62801 m .49099 .63081 L .49343 .63046 L F
.633 .361 .488 r
.49587 .63018 m .4935 .62801 L .49343 .63046 L F
.49587 .63018 m .49608 .62804 L .4935 .62801 L F
.662 .661 .839 r
.44937 .61009 m .44846 .61305 L .44819 .61029 L F
.278 .77 .901 r
.52003 .66134 m .51978 .66086 L .51731 .66113 L F
.763 .956 .643 r
.52145 .65848 m .52003 .66134 L .52233 .65856 L F
.52145 .65848 m .51978 .66086 L .52003 .66134 L F
.8 .638 .681 r
.34604 .64242 m .34971 .64314 L .34775 .6421 L F
.633 .703 .896 r
.34775 .6421 m .34971 .64314 L .35132 .64233 L F
.504 .498 .784 r
.5365 .6623 m .53719 .6658 L .53981 .66557 L F
.486 .33 .594 r
.53719 .6658 m .53746 .66787 L .53981 .66557 L F
.881 .783 .749 r
.59247 .61862 m .59424 .61966 L .59274 .62189 L F
.39 .169 .453 r
.49099 .63081 m .48862 .63375 L .49066 .63325 L F
.488 .27 .508 r
.48862 .63375 m .49062 .63562 L .49066 .63325 L F
.48862 .63375 m .48852 .6366 L .49062 .63562 L F
.767 .272 0 r
.56116 .63623 m .55851 .63339 L .56006 .63485 L F
.915 .638 .502 r
.58338 .59637 m .58319 .59817 L .58171 .59805 L F
.901 .628 .123 r
.57587 .6623 m .57666 .66557 L .57613 .66468 L F
.938 .625 .174 r
.57666 .66557 m .57623 .66667 L .57613 .66468 L F
.57666 .66557 m .5771 .66791 L .57623 .66667 L F
.627 .806 .968 r
.64218 .44215 m .64243 .44341 L .63876 .44277 L F
.784 .685 .756 r
.64243 .44341 m .63996 .44622 L .63876 .44277 L F
.6 .409 .594 r
.64276 .44563 m .63996 .44622 L .64243 .44341 L F
.524 .349 .586 r
.6447 .44015 m .64243 .44341 L .64218 .44215 L F
.6447 .44015 m .64502 .44285 L .64243 .44341 L F
.067 0 .173 r
.64502 .44285 m .64276 .44563 L .64243 .44341 L F
.062 0 0 r
.28106 .83833 m .27976 .84003 L .27756 .84119 L F
.636 .735 .92 r
.28157 .83608 m .28106 .83833 L .28003 .83633 L F
.28157 .83608 m .28286 .83702 L .28106 .83833 L F
0 0 0 r
.28286 .83702 m .27976 .84003 L .28106 .83833 L F
.284 0 .118 r
.5256 .68019 m .52779 .67977 L .52896 .67809 L F
.264 0 .105 r
.52896 .67809 m .53005 .67926 L .53091 .67677 L F
.52896 .67809 m .52779 .67977 L .53005 .67926 L F
0 0 .374 r
.49506 .73204 m .4955 .73057 L .49759 .73175 L F
.792 .926 .553 r
.4955 .73057 m .49506 .73204 L .49759 .73175 L F
0 0 .374 r
.49506 .73204 m .49557 .73183 L .4955 .73057 L F
.09 .629 .854 r
.49133 .73145 m .49487 .73177 L .49506 .73204 L F
.483 .306 .564 r
.49358 .73365 m .49133 .73145 L .49506 .73204 L F
.792 .926 .553 r
.49481 .73168 m .49358 .73365 L .49506 .73204 L F
.09 .629 .854 r
.49487 .73177 m .49557 .73183 L .49506 .73204 L F
.483 .306 .564 r
.49487 .73177 m .49358 .73365 L .49557 .73183 L F
.49133 .73145 m .49358 .73365 L .49487 .73177 L F
.792 .926 .553 r
.4955 .73057 m .49481 .73168 L .49487 .73177 L F
.49535 .73107 m .49487 .73177 L .49506 .73204 L F
.4955 .73057 m .49487 .73177 L .49535 .73107 L F
.449 .218 .47 r
.4448 .69438 m .44237 .69737 L .44473 .69687 L F
.388 .406 .757 r
.44413 .69135 m .4448 .69438 L .44643 .69419 L F
.384 .364 .713 r
.4448 .69438 m .44715 .69666 L .44643 .69419 L F
.588 .381 .568 r
.44473 .69687 m .44715 .69666 L .4448 .69438 L F
.44473 .69687 m .44715 .69666 L .4448 .69438 L F
.381 0 .151 r
.31398 .59262 m .31595 .59289 L .31695 .59128 L F
.54 .145 .242 r
.31695 .59128 m .31595 .59289 L .31894 .5924 L F
.504 .199 .382 r
.31695 .59128 m .31894 .5924 L .31917 .5912 L F
.722 .562 .673 r
.55143 .61621 m .55124 .61917 L .55332 .61628 L F
.669 .374 .463 r
.5127 .6471 m .50909 .64773 L .50924 .64618 L F
.75 .834 .916 r
.7867 .52727 m .79002 .52722 L .78908 .52628 L F
.908 .523 .277 r
.60183 .6021 m .60287 .60488 L .60387 .60485 L F
.831 .573 .548 r
.60191 .6069 m .60387 .60485 L .60287 .60488 L F
.60191 .6069 m .60522 .6075 L .60387 .60485 L F
.384 .572 .912 r
.42305 .58885 m .4221 .59054 L .42132 .58889 L F
.484 .699 .964 r
.42305 .58885 m .42426 .59034 L .4221 .59054 L F
.502 .312 .556 r
.44723 .70863 m .44944 .70819 L .44731 .70593 L F
.667 .692 .864 r
.54412 .65453 m .54107 .65574 L .54115 .654 L F
.866 .942 .866 r
.74345 .48278 m .73974 .48614 L .74084 .48698 L F
.661 .558 .728 r
.34565 .61332 m .3464 .61677 L .34386 .61644 L F
.604 .393 .568 r
.39982 .61592 m .40254 .61307 L .40008 .61365 L F
.942 .876 .742 r
.59058 .63641 m .59046 .64007 L .58862 .63877 L F
.952 .689 .236 r
.58959 .64236 m .58862 .63877 L .59046 .64007 L F
.841 .973 .879 r
.48523 .71964 m .48316 .7225 L .48666 .72046 L F
.891 .89 .823 r
.48523 .71964 m .48666 .72046 L .48882 .71743 L F
.577 .656 .891 r
.43939 .59535 m .43888 .5987 L .43717 .59601 L F
.43939 .59535 m .44124 .5984 L .43888 .5987 L F
.69 .432 .527 r
.5587 .67293 m .55436 .67118 L .55708 .67091 L F
.375 .804 .967 r
.38987 .58336 m .39222 .58303 L .39376 .5835 L F
.228 .73 .903 r
.39222 .58303 m .39593 .58324 L .39376 .5835 L F
0 0 0 r
.61309 .65387 m .61237 .65579 L .61134 .65699 L F
.733 .58 .004 r
.61297 .65055 m .61306 .65367 L .61309 .65387 L F
.754 .78 .283 r
.61306 .65367 m .61237 .65579 L .61309 .65387 L F
.725 .989 .862 r
.7603 .49348 m .76101 .49403 L .75937 .49474 L F
.823 .518 .473 r
.75937 .49474 m .76172 .49508 L .76101 .49403 L F
.374 .821 .944 r
.76279 .49295 m .76101 .49403 L .7603 .49348 L F
.76279 .49295 m .7652 .49331 L .76101 .49403 L F
.915 .523 .24 r
.60112 .60373 m .60183 .6021 L .60068 .60113 L F
.60112 .60373 m .60287 .60488 L .60183 .6021 L F
.531 .671 .927 r
.40779 .59415 m .40883 .59215 L .4065 .59285 L F
.40779 .59415 m .41018 .59412 L .40883 .59215 L F
.416 .8 .99 r
.52389 .7223 m .52563 .72308 L .52319 .7233 L F
.52389 .7223 m .52563 .72308 L .52319 .7233 L F
.367 0 .076 r
.38323 .62384 m .38551 .62357 L .38687 .62174 L F
.422 0 .115 r
.38551 .62357 m .38919 .62157 L .38687 .62174 L F
.744 .733 .842 r
.53554 .60373 m .53934 .60274 L .5384 .60113 L F
.718 .624 .752 r
.5384 .60113 m .53934 .60274 L .54181 .6017 L F
.621 .171 .161 r
.50263 .69054 m .50609 .69077 L .50377 .68948 L F
.384 .049 .268 r
.49078 .65938 m .49254 .6611 L .49007 .66172 L F
.49078 .65938 m .49278 .65951 L .49254 .6611 L F
.74 .848 .931 r
.31988 .62959 m .32017 .63152 L .32199 .631 L F
.395 .731 .991 r
.32199 .631 m .32326 .62961 L .31988 .62959 L F
.944 .957 .732 r
.32233 .63341 m .32326 .62961 L .32199 .631 L F
.296 0 0 r
.34741 .58254 m .34943 .58298 L .35117 .58257 L F
.159 0 0 r
.34943 .58298 m .35321 .58274 L .35117 .58257 L F
.423 .718 .986 r
.37302 .58171 m .37221 .58288 L .37107 .58147 L F
.37302 .58171 m .37454 .58273 L .37221 .58288 L F
.577 .323 .495 r
.51183 .67129 m .51412 .6733 L .51421 .67109 L F
.51183 .67129 m .51412 .6733 L .51421 .67109 L F
.658 .514 .677 r
.75135 .5061 m .74964 .50713 L .75195 .50397 L F
.274 .003 .307 r
.47744 .65118 m .47497 .65398 L .47692 .65294 L F
.452 .222 .473 r
.47692 .65294 m .47933 .6504 L .47744 .65118 L F
.235 0 .13 r
.51227 .66465 m .51291 .66285 L .51513 .66189 L F
.357 .237 .576 r
.21556 .58469 m .21547 .58768 L .21404 .58762 L F
.341 .39 .767 r
.21547 .58768 m .21694 .58974 L .21404 .58762 L F
0 .191 .668 r
.21404 .58762 m .21694 .58974 L .21761 .59047 L F
.883 .712 .665 r
.59066 .60474 m .59232 .60808 L .58978 .60726 L F
.847 .644 .627 r
.58978 .60726 m .59232 .60808 L .59165 .61038 L F
.85 .91 .875 r
.61237 .65579 m .61066 .65926 L .61134 .65699 L F
.956 .808 .657 r
.5688 .60377 m .56926 .60056 L .56769 .60099 L F
.702 .224 .113 r
.56926 .60056 m .56994 .60301 L .56769 .60099 L F
.084 0 .266 r
.56982 .6016 m .56994 .60301 L .56926 .60056 L F
.593 .072 0 r
.56769 .60099 m .56982 .6016 L .56926 .60056 L F
.944 .71 .553 r
.59165 .61038 m .59312 .61366 L .59095 .61292 L F
.87 .649 .6 r
.59095 .61292 m .59312 .61366 L .59294 .61614 L F
.834 .855 .862 r
.80434 .49862 m .8071 .49796 L .80462 .49774 L F
.8071 .49796 m .80733 .49791 L .80711 .49789 L F
.8071 .49796 m .80711 .49789 L .80462 .49774 L F
.95 .859 .716 r
.80743 .49441 m .80835 .49507 L .80755 .494 L F
.752 .311 .204 r
.80462 .49774 m .80711 .49789 L .80635 .4982 L F
.80711 .49789 m .80733 .49791 L .80635 .4982 L F
.95 .859 .716 r
.80635 .4982 m .80721 .49685 L .80743 .49441 L F
.80721 .49685 m .80835 .49507 L .80743 .49441 L F
.753 .72 .822 r
.80462 .49774 m .80507 .49786 L .80552 .49364 L F
.80507 .49786 m .80635 .4982 L .80604 .4965 L F
.80507 .49786 m .80604 .4965 L .80552 .49364 L F
.834 .855 .862 r
.80456 .49857 m .80508 .50046 L .80733 .49791 L F
.80434 .49862 m .80441 .49878 L .80456 .49857 L F
.80441 .49878 m .80508 .50046 L .80456 .49857 L F
.849 .675 .665 r
.54834 .61835 m .55143 .61621 L .54793 .61563 L F
.54834 .61835 m .55124 .61917 L .55143 .61621 L F
.371 .24 .57 r
.54862 .60762 m .55011 .60887 L .55138 .6073 L F
.134 .233 .702 r
.55011 .60887 m .54862 .60762 L .55138 .6073 L F
.293 .036 .342 r
.21288 .59623 m .212 .59879 L .21035 .5993 L F
.331 .091 .392 r
.2145 .59532 m .21288 .59623 L .21512 .59341 L F
.161 0 .275 r
.21397 .59742 m .21288 .59623 L .2145 .59532 L F
.21397 .59742 m .212 .59879 L .21288 .59623 L F
.563 .721 .947 r
.78058 .52673 m .78403 .52791 L .78312 .5261 L F
.596 .715 .927 r
.78403 .52791 m .78557 .52559 L .78312 .5261 L F
.78403 .52791 m .7867 .52727 L .78557 .52559 L F
.564 .289 .458 r
.51968 .64212 m .5174 .64389 L .51766 .6428 L F
.489 .168 .348 r
.41413 .61333 m .41661 .61311 L .41741 .61045 L F
.587 .416 .616 r
.41741 .61045 m .41986 .61024 L .4197 .60778 L F
.422 .106 .322 r
.41741 .61045 m .4188 .61255 L .41986 .61024 L F
.41741 .61045 m .41661 .61311 L .4188 .61255 L F
0 0 0 r
.47898 .66552 m .47982 .66534 L .47747 .66559 L F
.537 .334 .552 r
.31398 .59262 m .31617 .59506 L .31595 .59289 L F
.31398 .59262 m .31413 .59562 L .31617 .59506 L F
0 0 .043 r
.52527 .666 m .52679 .66508 L .52701 .66578 L F
.52527 .666 m .52483 .66744 L .52679 .66508 L F
0 0 .134 r
.52679 .66508 m .52483 .66744 L .52569 .66466 L F
.491 .312 .566 r
.51029 .65877 m .51389 .65617 L .51133 .65652 L F
.51029 .65877 m .51489 .65915 L .51389 .65617 L F
.168 .263 .718 r
.51029 .65877 m .51334 .66138 L .51489 .65915 L F
.51029 .65877 m .51218 .66314 L .51334 .66138 L F
.62 .329 .455 r
.58535 .58717 m .58865 .58435 L .58616 .58448 L F
.846 .743 .75 r
.59314 .63018 m .59305 .6342 L .59377 .63337 L F
.448 .541 .859 r
.45056 .60598 m .44794 .60786 L .4489 .60642 L F
.553 .323 .52 r
.45169 .60936 m .44794 .60786 L .45056 .60598 L F
.45169 .60936 m .44937 .61009 L .44794 .60786 L F
.516 .841 .999 r
.39336 .59186 m .39256 .59314 L .39478 .59268 L F
.39336 .59186 m .39113 .59242 L .39256 .59314 L F
.373 .517 .872 r
.5688 .60377 m .56602 .60134 L .56697 .60534 L F
.5688 .60377 m .56769 .60099 L .56602 .60134 L F
.869 .691 .165 r
.72375 .49145 m .72344 .48835 L .7248 .48939 L F
.531 .337 .563 r
.72344 .48835 m .72702 .4893 L .7248 .48939 L F
.407 .181 .456 r
.45442 .67353 m .45691 .67066 L .45448 .67104 L F
.127 .434 .873 r
.44866 .70083 m .45086 .70135 L .4483 .69972 L F
.44866 .70083 m .45147 .70254 L .45086 .70135 L F
.265 0 .234 r
.47497 .65398 m .47228 .65649 L .47415 .65563 L F
.115 0 .106 r
.47415 .65563 m .47692 .65294 L .47497 .65398 L F
.527 .408 .661 r
.30974 .59936 m .31221 .60127 L .31187 .59878 L F
.489 .411 .696 r
.31029 .60166 m .31221 .60127 L .30974 .59936 L F
.516 .589 .866 r
.3502 .61979 m .3464 .61677 L .34922 .61807 L F
.581 .656 .889 r
.35138 .61772 m .3502 .61979 L .34922 .61807 L F
.553 .621 .873 r
.35138 .61772 m .35265 .61955 L .3502 .61979 L F
.394 .145 .413 r
.47976 .64825 m .47933 .6504 L .48183 .64759 L F
.385 .217 .527 r
.48341 .67967 m .48301 .68284 L .48126 .6828 L F
.652 .715 .894 r
.5384 .60113 m .54181 .6017 L .5401 .59939 L F
.798 .72 .777 r
.51637 .65604 m .52087 .657 L .51928 .65347 L F
.513 .368 .621 r
.51637 .65604 m .51852 .65811 L .52087 .657 L F
.35 .408 .781 r
.52087 .657 m .52119 .65282 L .51928 .65347 L F
.52087 .657 m .52205 .65727 L .52119 .65282 L F
0 0 .522 r
.21742 .58709 m .21774 .59011 L .21694 .58974 L F
.029 0 0 r
.21788 .59142 m .21761 .59047 L .21694 .58974 L F
0 0 .522 r
.21774 .59011 m .21788 .59142 L .2174 .59056 L F
.21774 .59011 m .2174 .59056 L .21694 .58974 L F
.591 .855 .509 r
.21645 .59184 m .21606 .59216 L .21512 .59341 L F
.21761 .59047 m .21686 .59128 L .21645 .59184 L F
.21686 .59128 m .21606 .59216 L .21645 .59184 L F
.084 0 .44 r
.21606 .59216 m .2145 .59532 L .21512 .59341 L F
.415 .293 .604 r
.212 .59879 m .21052 .60166 L .21035 .5993 L F
.341 0 .046 r
.3977 .63056 m .39628 .63242 L .394 .63276 L F
.298 0 .032 r
.39994 .63004 m .39628 .63242 L .3977 .63056 L F
.524 .223 .398 r
.49306 .63265 m .49099 .63081 L .49066 .63325 L F
.49306 .63265 m .49343 .63046 L .49099 .63081 L F
.557 .932 .904 r
.36266 .64125 m .36207 .64108 L .36103 .64218 L F
.565 .929 .774 r
.36207 .64108 m .36049 .64224 L .36103 .64218 L F
.371 0 .043 r
.40804 .62687 m .40869 .62582 L .41044 .62641 L F
.365 0 .156 r
.40869 .62582 m .41099 .62528 L .41044 .62641 L F
.64 .937 .965 r
.48709 .65173 m .48927 .65083 L .4891 .65003 L F
.697 .966 .937 r
.4891 .65003 m .48927 .65083 L .48842 .65057 L F
.4891 .65003 m .48842 .65057 L .48777 .65037 L F
.64 .937 .965 r
.48647 .65208 m .48842 .65057 L .48511 .65287 L F
.48842 .65057 m .48831 .65059 L .48511 .65287 L F
.48709 .65173 m .4891 .65003 L .48647 .65208 L F
.441 .16 .39 r
.48511 .65287 m .48831 .65059 L .48928 .65223 L F
.714 .23 0 r
.48927 .65083 m .48907 .6516 L .4884 .6507 L F
.48927 .65083 m .48807 .65065 L .48842 .65057 L F
.64 .937 .965 r
.48842 .65057 m .4891 .65003 L .48831 .65059 L F
.441 .16 .39 r
.48831 .65059 m .4891 .65003 L .48925 .65184 L F
.48831 .65059 m .48907 .6516 L .48928 .65223 L F
.75 .391 .373 r
.48928 .65223 m .48777 .65037 L .48907 .6516 L F
.48928 .65223 m .48907 .6516 L .48957 .65208 L F
.714 .23 0 r
.48927 .65083 m .4901 .65259 L .48907 .6516 L F
.441 .16 .39 r
.48907 .6516 m .48925 .65184 L .48928 .65223 L F
.714 .23 0 r
.4884 .6507 m .48907 .6516 L .48807 .65065 L F
.48842 .65057 m .48807 .65065 L .48777 .65037 L F
.75 .391 .373 r
.48928 .65223 m .4891 .65003 L .48777 .65037 L F
.92 .972 .771 r
.48862 .65256 m .48928 .65223 L .48972 .65133 L F
.626 .541 .739 r
.48928 .65223 m .48482 .6565 L .48511 .65287 L F
.92 .972 .771 r
.48705 .65431 m .48928 .65223 L .48862 .65256 L F
.75 .391 .373 r
.48928 .65223 m .48957 .65208 L .4901 .65259 L F
.632 .689 .885 r
.45126 .71047 m .45456 .71118 L .45294 .70912 L F
.387 .504 .855 r
.45456 .71118 m .45499 .70847 L .45294 .70912 L F
.45456 .71118 m .45658 .71175 L .45499 .70847 L F
.863 .615 .563 r
.58806 .60368 m .59058 .60199 L .59066 .60474 L F
.681 .306 .33 r
.58609 .60191 m .59058 .60199 L .58806 .60368 L F
.823 .615 .622 r
.6447 .44015 m .64218 .44215 L .64115 .44216 L F
.6447 .44015 m .64115 .44216 L .64355 .44154 L F
.507 .337 .585 r
.64701 .43974 m .64502 .44285 L .6447 .44015 L F
.882 .856 .812 r
.64355 .44154 m .64701 .43974 L .6447 .44015 L F
.136 0 .285 r
.4824 .64552 m .48183 .64759 L .48383 .64444 L F
.716 .602 .728 r
.63996 .44622 m .63622 .44336 L .63876 .44277 L F
.63996 .44622 m .6375 .44628 L .63622 .44336 L F
.715 .508 .609 r
.63996 .44622 m .63778 .44856 L .6375 .44628 L F
.63996 .44622 m .64005 .44866 L .63778 .44856 L F
.622 .447 .624 r
.64276 .44563 m .64005 .44866 L .63996 .44622 L F
.009 0 .18 r
.41969 .6048 m .4209 .60408 L .4215 .60211 L F
.547 .517 .774 r
.4197 .60778 m .4209 .60408 L .41969 .6048 L F
.233 0 0 r
.56852 .5922 m .57185 .5899 L .57043 .59016 L F
.029 0 0 r
.21788 .59142 m .21606 .59216 L .21761 .59047 L F
.667 .692 .864 r
.54412 .65453 m .54326 .65545 L .54107 .65574 L F
.509 .107 .215 r
.54326 .65545 m .54012 .65809 L .54107 .65574 L F
.48 .574 .872 r
.73925 .51485 m .74021 .51187 L .73801 .5118 L F
.73925 .51485 m .74148 .51471 L .74021 .51187 L F
0 0 .015 r
.50854 .66473 m .50736 .66621 L .50703 .66777 L F
.557 .645 .893 r
.76837 .50327 m .76731 .506 L .76607 .50371 L F
.76837 .50327 m .76978 .50579 L .76731 .506 L F
.149 .569 .929 r
.36562 .62612 m .36326 .62568 L .36184 .62448 L F
.535 .079 .115 r
.35321 .58274 m .35535 .58329 L .35702 .58162 L F
.586 .138 .154 r
.35702 .58162 m .35535 .58329 L .35905 .58286 L F
.504 .652 .925 r
.7429 .51708 m .74378 .51484 L .74148 .51471 L F
.7429 .51708 m .74574 .5171 L .74378 .51484 L F
.343 .524 .89 r
.40466 .59268 m .40457 .59004 L .40249 .59023 L F
.40466 .59268 m .4065 .59285 L .40457 .59004 L F
.033 0 .158 r
.52548 .68218 m .52779 .67977 L .5256 .68019 L F
.473 .66 .943 r
.7906 .49005 m .79429 .49223 L .79299 .48923 L F
.505 .599 .881 r
.79299 .48923 m .79429 .49223 L .79655 .49176 L F
.192 .034 .425 r
.20895 .60729 m .20869 .60985 L .20697 .61065 L F
0 0 .235 r
.20869 .60985 m .20669 .61304 L .20697 .61065 L F
.898 .519 .304 r
.56663 .64243 m .5654 .64378 L .56494 .64154 L F
.56663 .64243 m .5675 .64518 L .5654 .64378 L F
.597 .72 .93 r
.45126 .71047 m .45294 .70912 L .44944 .70819 L F
.719 .658 .789 r
.75644 .50037 m .75419 .50105 L .7565 .49838 L F
.803 .914 .915 r
.79829 .52412 m .80002 .52098 L .79671 .52259 L F
.79829 .52412 m .80103 .52194 L .80002 .52098 L F
.682 .226 .162 r
.54421 .61374 m .54303 .61511 L .54571 .6147 L F
0 .307 .696 r
.54793 .61563 m .54421 .61374 L .54696 .61329 L F
.54793 .61563 m .54742 .61526 L .54421 .61374 L F
.631 .703 .898 r
.54793 .61563 m .54571 .6147 L .54742 .61526 L F
.42 0 0 r
.54303 .61511 m .54742 .61526 L .54571 .6147 L F
.572 .096 .087 r
.54421 .61374 m .54742 .61526 L .54303 .61511 L F
.734 .33 .282 r
.54328 .63911 m .54558 .64148 L .54673 .63964 L F
.648 .227 .232 r
.54558 .64148 m .54792 .64201 L .54673 .63964 L F
.684 .489 .617 r
.51499 .64473 m .51509 .64764 L .5127 .6471 L F
.561 .393 .611 r
.51819 .64623 m .51499 .64473 L .5174 .64389 L F
.51819 .64623 m .51509 .64764 L .51499 .64473 L F
.463 .574 .881 r
.41955 .58603 m .41835 .58806 L .41711 .58675 L F
.41955 .58603 m .42132 .58889 L .41835 .58806 L F
.23 .716 .929 r
.20936 .54659 m .21115 .54708 L .20733 .5466 L F
.067 .549 .895 r
.21134 .54654 m .21115 .54708 L .20936 .54659 L F
.21134 .54654 m .21265 .54741 L .21115 .54708 L F
.422 .111 .33 r
.46495 .66301 m .46659 .6643 L .4673 .66255 L F
.46495 .66301 m .46435 .66481 L .46659 .6643 L F
.918 .802 .716 r
.5924 .62767 m .59446 .62778 L .59314 .63018 L F
.563 .244 .385 r
.50389 .69436 m .50128 .69609 L .5021 .6949 L F
.384 0 0 r
.73815 .49469 m .73845 .49491 L .73657 .49394 L F
.793 .309 .067 r
.74209 .49729 m .73845 .49491 L .73815 .49469 L F
.977 .751 .531 r
.60784 .62348 m .60917 .62465 L .6093 .62218 L F
.868 .502 .008 r
.6078 .61897 m .60862 .62149 L .6093 .62218 L F
.977 .92 .633 r
.60862 .62149 m .60784 .62348 L .6093 .62218 L F
0 0 .384 r
.63778 .44856 m .63555 .44486 L .6375 .44628 L F
.839 .739 .754 r
.63426 .44493 m .63699 .44726 L .63306 .44726 L F
.722 .378 .396 r
.63285 .44271 m .63441 .44301 L .63508 .44473 L F
.63285 .44271 m .63508 .44473 L .63481 .44479 L F
.63441 .44301 m .63555 .44485 L .63533 .44534 L F
.839 .739 .754 r
.63542 .44465 m .63699 .44726 L .63426 .44493 L F
.722 .378 .396 r
.63481 .44479 m .63508 .44473 L .63533 .44534 L F
.839 .739 .754 r
.63487 .44373 m .63542 .44465 L .63481 .44479 L F
.63487 .44373 m .63481 .44479 L .63453 .4444 L F
.63487 .44373 m .63453 .4444 L .63543 .44545 L F
.63453 .4444 m .63481 .44479 L .63426 .44493 L F
.63453 .4444 m .63306 .44726 L .63543 .44545 L F
0 .093 .637 r
.63285 .44271 m .63481 .44479 L .63453 .4444 L F
.63327 .44293 m .63453 .4444 L .6336 .44311 L F
.63285 .44271 m .63453 .4444 L .63327 .44293 L F
.6336 .44311 m .63543 .44545 L .63417 .44342 L F
.63481 .44479 m .63543 .44545 L .6336 .44311 L F
.722 .378 .396 r
.63441 .44301 m .63622 .44336 L .63555 .44485 L F
0 0 .384 r
.63555 .44486 m .63569 .44453 L .6375 .44628 L F
.943 .671 .491 r
.63622 .44336 m .6375 .44628 L .63569 .44453 L F
.588 .091 .039 r
.63615 .44583 m .63897 .44563 L .63625 .44575 L F
0 0 .384 r
.63569 .44509 m .63542 .44465 L .63555 .44486 L F
.63778 .44856 m .63562 .44499 L .63569 .44509 L F
.63562 .44499 m .63542 .44465 L .63569 .44509 L F
.626 .147 .096 r
.63806 .44712 m .63897 .44563 L .63633 .44607 L F
.588 .091 .039 r
.6363 .44607 m .63897 .44563 L .63615 .44583 L F
.141 0 0 r
.64032 .44635 m .63897 .44563 L .63806 .44712 L F
.266 0 0 r
.63625 .44575 m .63897 .44563 L .64032 .44635 L F
.63634 .44572 m .64032 .44635 L .64106 .44466 L F
.63625 .44575 m .63634 .44576 L .63634 .44572 L F
.63634 .44576 m .64032 .44635 L .63634 .44572 L F
.626 .147 .096 r
.63633 .44609 m .63633 .44607 L .6363 .44607 L F
.63806 .44712 m .63633 .44607 L .63633 .44609 L F
0 0 .384 r
.63778 .44856 m .63566 .44506 L .6357 .44512 L F
.626 .147 .096 r
.63658 .44651 m .6363 .44607 L .63575 .44616 L F
.63806 .44712 m .6363 .44607 L .63658 .44651 L F
.588 .091 .039 r
.63575 .44616 m .6363 .44607 L .63615 .44583 L F
0 0 .384 r
.63778 .44856 m .63699 .44726 L .63566 .44506 L F
.6357 .44512 m .63566 .44506 L .63542 .44465 L F
.63555 .44486 m .63542 .44465 L .63487 .44373 L F
.63555 .44486 m .63487 .44373 L .63569 .44453 L F
.722 .378 .396 r
.63534 .44536 m .63622 .44336 L .63543 .44545 L F
.63533 .44534 m .63569 .44453 L .63534 .44536 L F
.63569 .44453 m .63622 .44336 L .63534 .44536 L F
.943 .671 .491 r
.63622 .44336 m .63569 .44453 L .63487 .44373 L F
.547 .517 .774 r
.4197 .60778 m .42205 .60744 L .4209 .60408 L F
.521 .366 .611 r
.4197 .60778 m .41986 .61024 L .42205 .60744 L F
.273 0 0 r
.36311 .59646 m .3615 .59775 L .35915 .59805 L F
.489 .012 .048 r
.36554 .59649 m .3615 .59775 L .36311 .59646 L F
.354 .221 .557 r
.53091 .67677 m .5328 .67603 L .53265 .67379 L F
.459 .571 .88 r
.53447 .67928 m .53091 .67677 L .5328 .67603 L F
.166 0 .11 r
.53091 .67677 m .5318 .67828 L .5328 .67603 L F
.53091 .67677 m .53005 .67926 L .5318 .67828 L F
.45 .163 .385 r
.46942 .65957 m .47197 .65915 L .47228 .65649 L F
.32 .058 .351 r
.47228 .65649 m .47396 .65823 L .47415 .65563 L F
.47228 .65649 m .47197 .65915 L .47396 .65823 L F
.86 .917 .867 r
.31988 .62959 m .31884 .63089 L .32017 .63152 L F
.996 .768 .425 r
.58 .64214 m .57987 .64615 L .58088 .64477 L F
0 .073 .626 r
.57987 .64615 m .57994 .64797 L .58088 .64477 L F
.815 .767 .808 r
.58 .64214 m .58088 .64477 L .58251 .64224 L F
.947 .651 .202 r
.61262 .63849 m .61382 .64205 L .6129 .63956 L F
.275 0 .075 r
.32374 .5902 m .32738 .58725 L .32512 .58755 L F
.342 .026 .277 r
.21961 .58307 m .21859 .58171 L .22003 .58039 L F
.21961 .58307 m .21786 .5836 L .21859 .58171 L F
.567 .324 .507 r
.50173 .65348 m .49859 .6564 L .49896 .65406 L F
.677 .628 .793 r
.75898 .49762 m .75644 .50037 L .7565 .49838 L F
.75898 .49762 m .76007 .50102 L .75644 .50037 L F
.604 .241 .326 r
.49824 .62978 m .49937 .62761 L .49608 .62804 L F
.62 .209 .242 r
.50065 .62968 m .49937 .62761 L .49824 .62978 L F
.50065 .62968 m .5019 .62805 L .49937 .62761 L F
.063 0 0 r
.3695 .63934 m .3684 .64021 L .36526 .64065 L F
.338 0 0 r
.3702 .64023 m .3695 .63934 L .37178 .63905 L F
.3702 .64023 m .3684 .64021 L .3695 .63934 L F
.599 .028 0 r
.54675 .62433 m .54541 .624 L .543 .62222 L F
.761 .25 0 r
.54541 .624 m .54223 .62106 L .543 .62222 L F
.812 .794 .835 r
.53446 .60111 m .53554 .60373 L .5384 .60113 L F
0 0 0 r
.61353 .64679 m .61335 .64776 L .6136 .64542 L F
.6137 .6444 m .6136 .64542 L .61382 .64205 L F
.6137 .6444 m .61353 .64679 L .6136 .64542 L F
.699 .982 .817 r
.48582 .64136 m .48466 .64258 L .48781 .63985 L F
.417 .101 .319 r
.35696 .59859 m .35401 .60125 L .35468 .59899 L F
.322 0 .183 r
.54853 .68405 m .54779 .68212 L .54989 .6831 L F
.694 .764 .906 r
.5754 .63566 m .57711 .63733 L .57734 .63566 L F
.66 .822 .961 r
.46021 .69897 m .45783 .69992 L .45652 .69873 L F
.692 .441 .54 r
.76479 .4952 m .76145 .49627 L .76172 .49508 L F
.76479 .4952 m .76487 .49747 L .76145 .49627 L F
.537 .322 .535 r
.76741 .49691 m .76479 .4952 L .76742 .49491 L F
.76741 .49691 m .76487 .49747 L .76479 .4952 L F
.628 .347 .473 r
.43661 .61635 m .43872 .61851 L .4364 .61848 L F
.655 .344 .433 r
.43661 .61635 m .43889 .61659 L .43872 .61851 L F
.523 .258 .455 r
.5728 .63623 m .5754 .63566 L .57495 .63379 L F
.726 .491 .571 r
.5754 .63566 m .57714 .6335 L .57495 .63379 L F
.777 .719 .799 r
.74865 .49111 m .74941 .49426 L .74788 .49533 L F
.532 .56 .83 r
.75254 .49353 m .74941 .49426 L .74865 .49111 L F
.829 .688 .707 r
.74718 .49774 m .74846 .50125 L .74677 .50011 L F
.753 .749 .849 r
.74846 .50125 m .74538 .50049 L .74677 .50011 L F
.161 .685 .876 r
.54911 .62431 m .54541 .624 L .54675 .62433 L F
.747 .922 .949 r
.78596 .4813 m .7873 .47897 L .78829 .48022 L F
.78596 .4813 m .78517 .48033 L .7873 .47897 L F
.805 .732 .783 r
.79391 .51829 m .79489 .52108 L .79232 .52011 L F
.78 .306 .113 r
.79232 .52011 m .79489 .52108 L .7937 .52154 L F
.775 .717 .798 r
.79713 .51855 m .79489 .52108 L .79391 .51829 L F
0 .143 .641 r
.79489 .52108 m .79565 .52144 L .7937 .52154 L F
.79489 .52108 m .79671 .52259 L .79565 .52144 L F
.082 .377 .84 r
.21265 .54741 m .21504 .54868 L .2147 .54998 L F
.318 .643 .967 r
.21504 .54868 m .21663 .55006 L .2147 .54998 L F
.845 .66 .652 r
.60648 .61313 m .6045 .6158 L .60804 .6164 L F
.858 .644 .612 r
.60473 .6181 m .60804 .6164 L .6045 .6158 L F
.60473 .6181 m .6078 .61897 L .60804 .6164 L F
.434 .715 .983 r
.58324 .62372 m .58662 .62365 L .58637 .62529 L F
0 0 .303 r
.58637 .62529 m .58693 .62596 L .58531 .62723 L F
.58637 .62529 m .58662 .62365 L .58693 .62596 L F
.63 .661 .861 r
.7462 .49208 m .74222 .48953 L .74467 .4888 L F
.776 .73 .809 r
.74818 .48905 m .7462 .49208 L .74467 .4888 L F
.509 .373 .631 r
.74865 .49111 m .7462 .49208 L .74818 .48905 L F
.777 .719 .799 r
.74865 .49111 m .74788 .49533 L .7462 .49208 L F
.64 .555 .742 r
.76258 .50041 m .76035 .50328 L .76007 .50102 L F
.76258 .50041 m .7638 .50449 L .76035 .50328 L F
.793 .394 .296 r
.47498 .72505 m .47111 .72243 L .47543 .72369 L F
.853 .634 .605 r
.59281 .5891 m .5959 .58755 L .59246 .58691 L F
.59281 .5891 m .59585 .59001 L .5959 .58755 L F
.838 .835 .843 r
.33854 .64154 m .34129 .64202 L .34223 .64059 L F
.265 .123 .494 r
.34067 .64489 m .34129 .64202 L .33854 .64154 L F
.34067 .64489 m .34209 .64429 L .34129 .64202 L F
.34129 .64202 m .34209 .64429 L .34067 .64489 L F
.778 .812 .88 r
.73037 .48927 m .72702 .4893 L .72948 .48831 L F
.875 .942 .857 r
.73037 .48927 m .73162 .48544 L .73302 .48811 L F
.73037 .48927 m .72948 .48831 L .73162 .48544 L F
.816 .867 .885 r
.52104 .64604 m .51834 .64783 L .51819 .64623 L F
.52104 .64604 m .51819 .64623 L .5196 .6462 L F
.913 .557 .349 r
.5196 .6462 m .52107 .64789 L .52104 .64604 L F
.615 .294 .402 r
.52104 .64604 m .52107 .64789 L .52367 .6468 L F
.603 .583 .804 r
.44462 .60352 m .44351 .60718 L .4424 .60423 L F
.44462 .60352 m .44573 .60669 L .44351 .60718 L F
.773 .651 .728 r
.76145 .49627 m .75937 .49474 L .76172 .49508 L F
.663 .798 .947 r
.80956 .50908 m .80724 .51182 L .80663 .51133 L F
.80956 .50908 m .81042 .51074 L .80724 .51182 L F
.503 0 0 r
.80724 .51182 m .80728 .51217 L .80663 .51133 L F
.80724 .51182 m .80928 .5132 L .80728 .51217 L F
.775 .836 .899 r
.31433 .61867 m .31562 .62236 L .31192 .62075 L F
.278 .7 .969 r
.31562 .62236 m .31466 .62088 L .31192 .62075 L F
.817 .991 .871 r
.3159 .61936 m .31466 .62088 L .31562 .62236 L F
0 0 .353 r
.80835 .49507 m .80739 .49132 L .80755 .494 L F
.95 .859 .716 r
.80635 .4982 m .80733 .49791 L .80835 .49507 L F
.737 .539 .625 r
.74788 .49533 m .74718 .49774 L .7434 .49729 L F
.625 .597 .802 r
.76258 .50041 m .76007 .50102 L .75898 .49762 L F
.127 .605 .917 r
.19838 .5577 m .19676 .55676 L .19446 .55643 L F
.603 .068 0 r
.20039 .55744 m .19676 .55676 L .19838 .5577 L F
.652 .715 .894 r
.5384 .60113 m .5401 .59939 L .53784 .5992 L F
.513 .7 .954 r
.42886 .58956 m .42845 .59198 L .42645 .58977 L F
.42886 .58956 m .43067 .59165 L .42845 .59198 L F
.961 .634 .345 r
.80289 .519 m .80289 .51824 L .80164 .51754 L F
0 .222 .693 r
.80473 .51918 m .80289 .51824 L .80164 .51754 L F
.349 .263 .616 r
.55978 .67815 m .56025 .67762 L .55932 .67559 L F
0 .167 .693 r
.56025 .67762 m .55914 .67632 L .55932 .67559 L F
0 0 0 r
.55961 .6744 m .558 .67694 L .55932 .67559 L F
.21 .168 .589 r
.55798 .67967 m .55932 .67559 L .558 .67694 L F
0 .167 .693 r
.55914 .67632 m .55785 .67481 L .55932 .67559 L F
0 0 0 r
.55962 .67437 m .55961 .6744 L .55932 .67559 L F
.69 .486 .606 r
.558 .67694 m .55798 .67967 L .55543 .67896 L F
.662 .661 .839 r
.44937 .61009 m .4509 .6134 L .44846 .61305 L F
.685 .456 .569 r
.4509 .6134 m .44892 .61552 L .44846 .61305 L F
.105 0 0 r
.37785 .63711 m .37625 .63818 L .37402 .63863 L F
0 0 0 r
.38016 .63683 m .37625 .63818 L .37785 .63711 L F
0 .014 .587 r
.79655 .49176 m .79778 .49521 L .79764 .49386 L F
.753 .69 .791 r
.80036 .49515 m .80301 .49636 L .80552 .49364 L F
.705 .985 .858 r
.80036 .49502 m .80436 .49205 L .80363 .49183 L F
.186 .44 .869 r
.79764 .49386 m .80025 .49527 L .80032 .49511 L F
.79764 .49386 m .79778 .49521 L .8006 .49547 L F
.79764 .49386 m .80032 .49511 L .79913 .49524 L F
.705 .985 .858 r
.80017 .49521 m .80028 .49513 L .80023 .49515 L F
.186 .44 .869 r
.80032 .49511 m .80031 .49531 L .80033 .49511 L F
.80025 .49527 m .80031 .49531 L .80032 .49511 L F
.80031 .49531 m .8006 .49547 L .80052 .49535 L F
.80031 .4953 m .80052 .49535 L .80034 .49512 L F
.80031 .49531 m .80052 .49535 L .80031 .4953 L F
.753 .69 .791 r
.80052 .49535 m .80301 .49636 L .80036 .49515 L F
0 .473 .816 r
.80122 .49552 m .80301 .49636 L .80052 .49535 L F
.186 .44 .869 r
.80033 .49511 m .8006 .49547 L .80122 .49552 L F
0 .473 .816 r
.80122 .49552 m .80052 .49535 L .80017 .49521 L F
.186 .44 .869 r
.80031 .49531 m .80034 .49512 L .80033 .49511 L F
.753 .69 .791 r
.80017 .49521 m .80052 .49535 L .80036 .49515 L F
0 .473 .816 r
.80122 .49552 m .80017 .49521 L .79913 .49524 L F
.186 .44 .869 r
.80032 .49511 m .80122 .49552 L .79985 .49534 L F
.80032 .49511 m .79985 .49534 L .79913 .49524 L F
.705 .985 .858 r
.80023 .49515 m .80033 .49509 L .80036 .49502 L F
.80028 .49513 m .80033 .49509 L .80023 .49515 L F
.80033 .49509 m .80436 .49205 L .80036 .49502 L F
.80017 .49521 m .80036 .49502 L .80015 .49397 L F
0 0 0 r
.79952 .48927 m .79863 .49047 L .79777 .49269 L F
.755 .866 .436 r
.79952 .48927 m .79777 .49269 L .79858 .49083 L F
0 .153 .693 r
.79858 .49083 m .8006 .49302 L .79907 .49027 L F
.705 .985 .858 r
.80093 .49446 m .80363 .49183 L .80073 .49361 L F
.74 .945 .948 r
.80015 .49397 m .80363 .49183 L .80242 .49026 L F
.80015 .49397 m .80242 .49026 L .8013 .49379 L F
0 .153 .693 r
.8006 .49302 m .8013 .49379 L .80047 .49248 L F
.8006 .49302 m .80047 .49248 L .79907 .49027 L F
.705 .985 .858 r
.80036 .49502 m .80093 .49446 L .80056 .49372 L F
.80093 .49446 m .80073 .49361 L .80056 .49372 L F
.80036 .49502 m .80056 .49372 L .80015 .49397 L F
.323 .471 .853 r
.79778 .49521 m .80114 .49823 L .80122 .49552 L F
.39 .244 .56 r
.31098 .60355 m .31221 .60127 L .31029 .60166 L F
.698 .586 .727 r
.78735 .51571 m .78764 .51841 L .7852 .5184 L F
.507 .399 .666 r
.78757 .52045 m .78536 .52074 L .7852 .5184 L F
.667 .373 .464 r
.78764 .51841 m .78757 .52045 L .7852 .5184 L F
.507 .399 .666 r
.78757 .52045 m .78536 .52074 L .7852 .5184 L F
.217 0 .096 r
.53543 .68088 m .53447 .67928 L .53544 .67844 L F
.53543 .68088 m .53348 .68156 L .53447 .67928 L F
.588 .599 .83 r
.43356 .59289 m .43194 .59545 L .43131 .59342 L F
.43356 .59289 m .43507 .59664 L .43194 .59545 L F
.543 .517 .777 r
.34738 .61288 m .3464 .61677 L .34565 .61332 L F
.34738 .61288 m .34855 .61598 L .3464 .61677 L F
.55 .541 .797 r
.34855 .61598 m .34922 .61807 L .3464 .61677 L F
.672 .418 .528 r
.47038 .67627 m .47283 .67661 L .47333 .67427 L F
.598 .41 .598 r
.47283 .67661 m .47574 .67343 L .47333 .67427 L F
.152 0 0 r
.48448 .65694 m .48677 .65662 L .48446 .65691 L F
.4853 .6579 m .4862 .65712 L .48448 .65694 L F
.4862 .65712 m .48677 .65662 L .48448 .65694 L F
0 0 0 r
.48482 .6565 m .48626 .65695 L .4853 .6579 L F
.48626 .65695 m .48769 .6574 L .4853 .6579 L F
.642 .889 .551 r
.48658 .65665 m .48677 .65662 L .4862 .65712 L F
.48776 .65517 m .48711 .65612 L .48658 .65665 L F
.48711 .65612 m .48677 .65662 L .48658 .65665 L F
.48636 .65673 m .4862 .65712 L .4853 .6579 L F
.48776 .65517 m .4862 .65712 L .48636 .65673 L F
0 0 0 r
.48482 .6565 m .48619 .65619 L .48648 .65643 L F
.665 .925 .626 r
.48921 .65397 m .48677 .65662 L .48776 .65517 L F
.642 .889 .551 r
.48776 .65517 m .48636 .65673 L .48769 .6574 L F
0 0 0 r
.48628 .65691 m .48636 .65673 L .48727 .65719 L F
.4871 .65722 m .48751 .65726 L .48769 .6574 L F
.48482 .6565 m .48751 .65726 L .4871 .65722 L F
.642 .889 .551 r
.48636 .65673 m .4853 .6579 L .48769 .6574 L F
0 0 0 r
.48727 .65719 m .48648 .65643 L .48751 .65726 L F
.48636 .65673 m .48648 .65643 L .48727 .65719 L F
.48482 .6565 m .48648 .65643 L .48628 .65691 L F
.626 .541 .739 r
.48928 .65223 m .48776 .65517 L .48482 .6565 L F
0 0 .233 r
.4853 .6579 m .4844 .65506 L .48482 .6565 L F
.152 0 0 r
.4853 .6579 m .48446 .65691 L .4844 .65506 L F
.428 .36 .678 r
.22353 .5659 m .22378 .56957 L .22205 .57014 L F
.29 .128 .481 r
.22378 .56957 m .22204 .57261 L .22205 .57014 L F
.604 .241 .326 r
.49824 .62978 m .49608 .62804 L .49587 .63018 L F
.146 0 0 r
.36894 .59579 m .36778 .59631 L .36554 .59649 L F
.662 .537 .702 r
.50969 .69114 m .51048 .68724 L .51047 .6887 L F
.681 .808 .943 r
.27514 .68199 m .2772 .68338 L .2789 .68229 L F
.2789 .68229 m .2772 .68338 L .27514 .68199 L F
.054 .063 .55 r
.80268 .47948 m .80185 .48331 L .8003 .47984 L F
.80268 .47948 m .80323 .48183 L .80185 .48331 L F
.13 .183 .65 r
.80323 .48183 m .80354 .48557 L .80185 .48331 L F
.251 0 0 r
.77294 .49183 m .77671 .49127 L .77549 .49143 L F
.329 0 0 r
.7784 .49117 m .77549 .49143 L .77671 .49127 L F
.377 0 .13 r
.32982 .58713 m .33224 .58672 L .33337 .58478 L F
.255 0 .066 r
.33337 .58478 m .33438 .58605 L .33565 .58463 L F
.33337 .58478 m .33224 .58672 L .33438 .58605 L F
.733 .47 .53 r
.44248 .61632 m .43872 .61851 L .43889 .61659 L F
.44248 .61632 m .44244 .6184 L .43872 .61851 L F
.686 .377 .446 r
.44248 .61632 m .44475 .61886 L .44244 .6184 L F
.44248 .61632 m .44568 .61696 L .44475 .61886 L F
.323 .136 .466 r
.45646 .69383 m .45584 .69739 L .45483 .69694 L F
.161 .256 .715 r
.45584 .69739 m .45652 .69873 L .45483 .69694 L F
.257 .119 .494 r
.22204 .57261 m .22195 .57486 L .22055 .57532 L F
.405 .315 .641 r
.22195 .57486 m .22007 .57864 L .22055 .57532 L F
.218 .511 .91 r
.20244 .56551 m .20502 .5665 L .20151 .56406 L F
.573 .317 .49 r
.20244 .56551 m .20364 .56744 L .20502 .5665 L F
0 0 .29 r
.45742 .69548 m .45646 .69383 L .45883 .69318 L F
.45742 .69548 m .45584 .69739 L .45646 .69383 L F
.531 .333 .557 r
.53346 .68883 m .53649 .68864 L .53613 .68541 L F
.124 .047 .49 r
.53613 .68541 m .53649 .68864 L .53669 .68816 L F
.648 .395 .522 r
.54753 .601 m .54992 .6014 L .55033 .59915 L F
.4 .792 .988 r
.55033 .59915 m .55059 .5982 L .54858 .59797 L F
.55033 .59915 m .55249 .59882 L .55059 .5982 L F
0 0 .182 r
.51334 .66138 m .51218 .66314 L .51227 .66465 L F
.504 .498 .784 r
.5365 .6623 m .53981 .66557 L .54076 .66195 L F
.557 .353 .559 r
.53981 .66557 m .54234 .66201 L .54076 .66195 L F
.736 .983 .908 r
.76922 .49083 m .76766 .49062 L .76955 .48842 L F
.76922 .49083 m .76686 .49154 L .76755 .4906 L F
0 0 0 r
.76753 .4909 m .76775 .49184 L .76862 .48987 L F
.76686 .49154 m .76719 .49165 L .76753 .4909 L F
.76719 .49165 m .76775 .49184 L .76753 .4909 L F
.736 .983 .908 r
.76766 .49062 m .76755 .4906 L .76779 .49034 L F
.76766 .49062 m .76779 .49034 L .76955 .48842 L F
.837 .476 .371 r
.54834 .61835 m .54998 .62102 L .55124 .61917 L F
.159 0 0 r
.55124 .61917 m .5524 .62012 L .55481 .62073 L F
.55124 .61917 m .54998 .62102 L .5524 .62012 L F
.685 .456 .569 r
.4509 .6134 m .45069 .61583 L .44892 .61552 L F
.577 .617 .855 r
.45307 .61275 m .4509 .6134 L .44937 .61009 L F
.668 .532 .689 r
.45307 .61275 m .45069 .61583 L .4509 .6134 L F
.647 .811 .962 r
.79421 .48013 m .79178 .48101 L .79079 .47971 L F
0 0 0 r
.53862 .64491 m .53656 .64821 L .53525 .64521 L F
.53862 .64491 m .53752 .64684 L .53656 .64821 L F
.605 .95 .911 r
.53752 .64684 m .53521 .64829 L .53656 .64821 L F
.595 .389 .572 r
.53632 .65035 m .53893 .6476 L .53656 .64821 L F
.041 0 0 r
.53645 .61319 m .53686 .61323 L .53806 .61309 L F
0 .401 .832 r
.53808 .61336 m .53686 .61323 L .53596 .61284 L F
0 .394 .82 r
.53686 .61323 m .54022 .61512 L .54045 .61297 L F
0 .401 .832 r
.53946 .6137 m .53686 .61323 L .53808 .61336 L F
.041 0 0 r
.53463 .6133 m .53686 .61323 L .53645 .61319 L F
0 .394 .82 r
.53686 .61323 m .54045 .61297 L .53806 .61309 L F
.459 .048 .171 r
.41685 .62258 m .41874 .62364 L .41623 .62379 L F
.417 .097 .312 r
.41893 .62202 m .41874 .62364 L .41685 .62258 L F
.146 0 0 r
.77126 .48841 m .77193 .48682 L .76955 .48842 L F
.276 0 0 r
.77369 .48769 m .77193 .48682 L .77126 .48841 L F
.77369 .48769 m .77436 .48648 L .77193 .48682 L F
.714 .23 0 r
.48927 .65083 m .49148 .65392 L .4901 .65259 L F
.75 .236 0 r
.51174 .62968 m .51359 .63179 L .51471 .63133 L F
.552 0 0 r
.51359 .63179 m .5171 .63266 L .51471 .63133 L F
.578 .035 0 r
.51471 .63133 m .5171 .63266 L .51891 .63274 L F
.764 .725 .816 r
.23998 .76264 m .23871 .76007 L .23846 .76036 L F
.23998 .76264 m .24223 .76045 L .23871 .76007 L F
.625 .533 .73 r
.78974 .51535 m .78764 .51841 L .78735 .51571 L F
.688 .619 .774 r
.78974 .51535 m .79091 .51839 L .78764 .51841 L F
.586 .252 .37 r
.79091 .51839 m .78757 .52045 L .78764 .51841 L F
.891 .679 .163 r
.49182 .65016 m .49199 .65075 L .49196 .64783 L F
.49182 .65016 m .49196 .64783 L .49208 .64674 L F
.776 .548 .589 r
.49485 .65056 m .49196 .64783 L .49199 .65075 L F
.713 .771 .898 r
.74173 .49993 m .74189 .50197 L .74045 .50098 L F
.683 .748 .901 r
.74538 .50049 m .74189 .50197 L .74173 .49993 L F
.742 .969 .932 r
.52923 .71928 m .5266 .72109 L .52668 .71924 L F
.94 .846 .723 r
.5266 .72109 m .52405 .72223 L .52668 .71924 L F
.52405 .72223 m .52438 .72176 L .52668 .71924 L F
.5266 .72109 m .52563 .72308 L .52389 .7223 L F
.52405 .72223 m .52389 .7223 L .52438 .72176 L F
.588 .487 .707 r
.52668 .71924 m .52389 .7223 L .52652 .72159 L F
.52668 .71924 m .52652 .72159 L .52534 .71856 L F
.588 .6 .832 r
.52613 .71933 m .52652 .72159 L .52805 .72117 L F
.52534 .71856 m .52581 .71977 L .52613 .71933 L F
.52581 .71977 m .52652 .72159 L .52613 .71933 L F
.932 .709 .578 r
.61081 .63284 m .6122 .6359 L .6128 .63393 L F
.311 0 0 r
.42826 .61894 m .42449 .62087 L .425 .61987 L F
.42826 .61894 m .42691 .62061 L .42449 .62087 L F
.359 0 0 r
.43067 .61899 m .42691 .62061 L .42826 .61894 L F
0 0 .299 r
.55546 .65328 m .55632 .65533 L .55642 .65574 L F
0 .217 .741 r
.55409 .65247 m .55632 .65533 L .55546 .65328 L F
.55409 .65247 m .55639 .65451 L .55632 .65533 L F
.802 .836 .369 r
.55632 .65533 m .55639 .65451 L .55623 .65495 L F
.55632 .65533 m .55623 .65495 L .55527 .65758 L F
0 0 .299 r
.55642 .65574 m .55632 .65533 L .55678 .65666 L F
.899 .711 .203 r
.55678 .65666 m .55638 .65796 L .55699 .65896 L F
.55678 .65666 m .55632 .65533 L .55638 .65796 L F
.705 .474 .572 r
.63425 .45092 m .63699 .44726 L .63778 .44856 L F
.843 .675 .675 r
.63306 .44726 m .63699 .44726 L .63425 .45092 L F
.881 .783 .749 r
.59247 .61862 m .59274 .62189 L .59095 .62149 L F
.918 .718 .617 r
.59274 .62189 m .59056 .62393 L .59095 .62149 L F
.59274 .62189 m .59275 .62453 L .59056 .62393 L F
.58 .573 .81 r
.4207 .59933 m .4215 .60211 L .4234 .60129 L F
.716 .557 .672 r
.4209 .60408 m .4234 .60129 L .4215 .60211 L F
.423 .051 .226 r
.52737 .68827 m .52641 .69047 L .5241 .69071 L F
.383 0 .163 r
.52974 .68806 m .52641 .69047 L .52737 .68827 L F
.356 0 .061 r
.55259 .68184 m .5517 .68351 L .54989 .6831 L F
0 0 .134 r
.55468 .67917 m .55285 .68246 L .55259 .68184 L F
.239 0 .009 r
.55285 .68246 m .5517 .68351 L .55259 .68184 L F
.509 .107 .215 r
.54326 .65545 m .5424 .65824 L .54012 .65809 L F
0 0 0 r
.54587 .65329 m .54326 .65545 L .54412 .65453 L F
.54527 .65379 m .54476 .65451 L .54326 .65545 L F
.156 0 .059 r
.54604 .65837 m .54701 .65829 L .54707 .65819 L F
.54743 .65728 m .54707 .65819 L .54775 .65702 L F
.54604 .65837 m .54707 .65819 L .54743 .65728 L F
.73 .327 .286 r
.54703 .65829 m .5424 .65824 L .54326 .65545 L F
.54707 .65833 m .54702 .65832 L .54703 .65829 L F
.54702 .65832 m .5424 .65824 L .54703 .65829 L F
.54705 .65829 m .54326 .65545 L .54476 .65451 L F
.54707 .65833 m .54703 .65829 L .54705 .65829 L F
.54703 .65829 m .54326 .65545 L .54705 .65829 L F
.413 .277 .585 r
.54492 .66178 m .54676 .65871 L .54483 .65932 L F
.81 .52 .499 r
.54586 .65979 m .54702 .65832 L .54707 .65833 L F
.413 .277 .585 r
.54676 .65871 m .54681 .65863 L .54676 .65865 L F
.54676 .65871 m .54676 .65865 L .54483 .65932 L F
.81 .52 .499 r
.54712 .66035 m .5471 .66034 L .54707 .65833 L F
.5471 .66034 m .54697 .65978 L .54707 .65833 L F
.54694 .66027 m .54676 .6587 L .54707 .65833 L F
.574 .352 .541 r
.54815 .65715 m .54919 .65684 L .5493 .65587 L F
.54774 .65761 m .54797 .65748 L .54815 .65715 L F
.54797 .65748 m .54919 .65684 L .54815 .65715 L F
.54757 .65779 m .549 .65842 L .54919 .65684 L F
.54763 .65855 m .549 .65842 L .54757 .65779 L F
0 .086 .558 r
.55171 .65545 m .5482 .65252 L .5493 .65587 L F
0 0 0 r
.549 .65842 m .55171 .65545 L .5493 .65587 L F
.355 .113 .403 r
.55017 .65541 m .54986 .65758 L .5476 .65818 L F
.54797 .65748 m .5476 .65818 L .54707 .65833 L F
.574 .352 .541 r
.54757 .65779 m .54919 .65684 L .54774 .65761 L F
.355 .113 .403 r
.55017 .65541 m .5476 .65818 L .54797 .65748 L F
0 0 0 r
.54775 .65702 m .54698 .65834 L .5493 .65587 L F
.355 .113 .403 r
.54797 .65748 m .54707 .65833 L .5469 .65804 L F
0 0 0 r
.54698 .65834 m .54681 .65863 L .54774 .65761 L F
.54698 .65834 m .54774 .65761 L .5493 .65587 L F
.355 .113 .403 r
.55017 .65541 m .54797 .65748 L .54792 .65743 L F
.55002 .65539 m .54792 .65743 L .54476 .65451 L F
.55017 .65541 m .54792 .65743 L .55002 .65539 L F
.54797 .65748 m .5469 .65804 L .54476 .65451 L F
.505 .376 .638 r
.5476 .65818 m .54712 .66035 L .54707 .65833 L F
.574 .352 .541 r
.54681 .65863 m .54763 .65855 L .54757 .65779 L F
.505 .376 .638 r
.54774 .65815 m .54763 .65854 L .5476 .65818 L F
.54763 .65854 m .54712 .66035 L .5476 .65818 L F
.621 .452 .631 r
.54752 .65897 m .549 .65842 L .54763 .65855 L F
.505 .376 .638 r
.54717 .66031 m .54712 .66035 L .54774 .65815 L F
.621 .452 .631 r
.54704 .66009 m .549 .65842 L .54685 .65922 L F
.505 .376 .638 r
.54717 .66031 m .54718 .66034 L .54712 .66035 L F
.621 .452 .631 r
.54721 .66085 m .54736 .66065 L .54718 .66034 L F
.54721 .66085 m .54718 .66034 L .5471 .66036 L F
.54736 .66065 m .549 .65842 L .54704 .66009 L F
.644 .419 .562 r
.54234 .66201 m .54517 .66413 L .54492 .66178 L F
.413 .277 .585 r
.54492 .66178 m .54698 .66117 L .54693 .66042 L F
.5456 .66065 m .54685 .65922 L .54676 .65871 L F
.81 .52 .499 r
.54694 .66027 m .54586 .65979 L .54676 .6587 L F
.54676 .65871 m .54676 .6587 L .54676 .6587 L F
.54694 .66027 m .54676 .6587 L .54676 .65871 L F
.413 .277 .585 r
.5456 .66065 m .54693 .66042 L .54685 .65922 L F
.54676 .65871 m .54685 .65922 L .54681 .65863 L F
.54492 .66178 m .54693 .66042 L .5456 .66065 L F
.97 .651 .307 r
.54951 .65946 m .54976 .66172 L .55067 .66178 L F
.549 .65842 m .54929 .6597 L .54951 .65946 L F
.54929 .6597 m .54976 .66172 L .54951 .65946 L F
.244 .402 .823 r
.55067 .66178 m .55193 .66044 L .549 .65842 L F
.621 .452 .631 r
.54741 .6609 m .54976 .66172 L .54929 .6597 L F
.5477 .66019 m .54929 .6597 L .549 .65842 L F
.914 .687 .188 r
.55047 .65704 m .55033 .65846 L .54986 .65758 L F
.505 .376 .638 r
.54986 .65758 m .55033 .65846 L .54951 .65796 L F
.299 .409 .806 r
.5495 .65795 m .55135 .65909 L .55047 .65704 L F
.549 .65842 m .55135 .65909 L .5495 .65795 L F
.914 .687 .188 r
.55047 .65704 m .55087 .65949 L .55033 .65846 L F
.299 .409 .806 r
.5503 .65879 m .55193 .66044 L .55135 .65909 L F
.549 .65842 m .55025 .65928 L .5503 .65879 L F
.55025 .65928 m .55193 .66044 L .5503 .65879 L F
.505 .376 .638 r
.54951 .65796 m .55087 .65949 L .54729 .66032 L F
.55033 .65846 m .55087 .65949 L .54951 .65796 L F
.54728 .66025 m .54729 .66032 L .54718 .66034 L F
.54986 .65758 m .54729 .66032 L .54728 .66025 L F
.621 .452 .631 r
.54698 .66117 m .54749 .66127 L .54741 .6609 L F
.54749 .66127 m .54976 .66172 L .54741 .6609 L F
.54698 .66117 m .54929 .6597 L .5477 .66019 L F
.422 0 .079 r
.54909 .65991 m .54895 .66005 L .54718 .66035 L F
.54724 .66033 m .54718 .66035 L .54712 .66036 L F
.54909 .65991 m .54718 .66035 L .54724 .66033 L F
.55087 .65949 m .54997 .65988 L .54895 .66005 L F
.55087 .65949 m .54895 .66005 L .54909 .65991 L F
.41 .269 .577 r
.54492 .66178 m .54697 .66372 L .54698 .66117 L F
.382 .267 .597 r
.54517 .66413 m .54697 .66372 L .54492 .66178 L F
.422 0 .079 r
.54997 .65988 m .54838 .66056 L .54781 .66026 L F
.54997 .65988 m .54708 .66039 L .54712 .66036 L F
.55087 .65949 m .54712 .66036 L .54718 .66034 L F
.505 .376 .638 r
.54986 .65758 m .54718 .66034 L .54717 .66031 L F
.54986 .65758 m .54717 .66031 L .54774 .65815 L F
0 0 0 r
.54947 .6579 m .55047 .65704 L .55171 .65545 L F
.54988 .65755 m .55047 .65704 L .54986 .65758 L F
.549 .65842 m .55047 .65704 L .54947 .6579 L F
.5513 .65508 m .55047 .65704 L .54988 .65755 L F
.406 .106 .341 r
.54697 .66372 m .54976 .66172 L .54698 .66117 L F
.422 0 .079 r
.54974 .65998 m .54721 .66203 L .54469 .66214 L F
.55087 .65949 m .54999 .6601 L .54974 .65998 L F
.54999 .6601 m .54721 .66203 L .54974 .65998 L F
.593 .948 .886 r
.54976 .66172 m .55193 .66044 L .55067 .66178 L F
.315 .029 .31 r
.55042 .66281 m .55193 .66044 L .54976 .66172 L F
.204 .212 .645 r
.55042 .66281 m .55053 .6603 L .55193 .66044 L F
.55053 .6603 m .55056 .65945 L .55114 .65987 L F
.55053 .6603 m .55114 .65987 L .55193 .66044 L F
.886 .891 .467 r
.55087 .65949 m .5502 .66054 L .54721 .66203 L F
.5502 .66054 m .54926 .66198 L .54812 .66201 L F
.5502 .66054 m .54812 .66201 L .54721 .66203 L F
.204 .212 .645 r
.55042 .66281 m .55139 .66183 L .55095 .66055 L F
.55053 .66035 m .55095 .66055 L .55056 .65945 L F
.55042 .66281 m .55095 .66055 L .55053 .66035 L F
.004 .06 .569 r
.54891 .66084 m .54967 .65742 L .54864 .65998 L F
.54926 .66198 m .54934 .66107 L .54891 .66084 L F
.54934 .66107 m .54967 .65742 L .54891 .66084 L F
.621 .452 .631 r
.54698 .66117 m .54721 .66085 L .5471 .66034 L F
.54688 .65975 m .5471 .66034 L .54685 .65922 L F
.557 .353 .559 r
.53981 .66557 m .54248 .66502 L .54234 .66201 L F
.644 .419 .562 r
.54234 .66201 m .54248 .66502 L .54517 .66413 L F
.215 0 0 r
.54711 .66036 m .54469 .66214 L .54226 .66253 L F
.54712 .66035 m .54712 .66036 L .54711 .66036 L F
.54712 .66036 m .54469 .66214 L .54711 .66036 L F
.621 .452 .631 r
.54693 .66039 m .5471 .66034 L .54688 .65975 L F
.54698 .66117 m .5471 .66036 L .54693 .66039 L F
.5471 .66036 m .5471 .66034 L .54693 .66039 L F
.81 .52 .499 r
.5471 .66034 m .54212 .6602 L .5424 .65824 L F
.54712 .66035 m .5471 .66035 L .5471 .66034 L F
.5471 .66035 m .54212 .6602 L .5471 .66034 L F
.422 0 .079 r
.54781 .66026 m .54469 .66214 L .54708 .66039 L F
.54838 .66056 m .54469 .66214 L .54781 .66026 L F
.54718 .66034 m .54712 .66036 L .54712 .66035 L F
.621 .452 .631 r
.5471 .66036 m .54718 .66034 L .54704 .66009 L F
.54685 .65922 m .54752 .65897 L .54681 .65863 L F
.54752 .65897 m .54763 .65855 L .54681 .65863 L F
.81 .52 .499 r
.5471 .66034 m .54694 .66027 L .54697 .65978 L F
.156 0 .059 r
.54483 .65932 m .54676 .65865 L .54701 .65829 L F
.54676 .65865 m .54691 .65845 L .54701 .65829 L F
.54483 .65932 m .54701 .65829 L .54604 .65837 L F
.81 .52 .499 r
.54586 .65979 m .5424 .65824 L .54702 .65832 L F
.156 0 .059 r
.54676 .65865 m .54681 .65863 L .54691 .65845 L F
.462 .356 .649 r
.54087 .6543 m .54349 .65631 L .54476 .65451 L F
.54349 .65631 m .54372 .65648 L .54476 .65451 L F
0 0 0 r
.54587 .65329 m .54476 .65451 L .54527 .65379 L F
.687 .473 .591 r
.45636 .67978 m .45806 .68178 L .45632 .68226 L F
.45636 .67978 m .45911 .68069 L .45806 .68178 L F
.333 .789 .947 r
.78128 .49003 m .78432 .48944 L .7792 .49139 L F
.516 .889 .969 r
.36954 .62577 m .36562 .62612 L .3677 .62588 L F
.449 .882 .877 r
.37153 .62498 m .36954 .62577 L .3677 .62588 L F
.065 .629 .746 r
.37153 .62498 m .37379 .62488 L .37521 .62488 L F
.195 .725 .816 r
.37379 .62488 m .37746 .62457 L .37521 .62488 L F
.629 .719 .912 r
.63538 .44182 m .63622 .44336 L .63285 .44271 L F
.936 .647 .469 r
.63543 .44545 m .63622 .44336 L .63487 .44373 L F
.615 .818 .978 r
.6376 .44158 m .63622 .44336 L .63538 .44182 L F
.6376 .44158 m .63876 .44277 L .63622 .44336 L F
.894 .857 .798 r
.58766 .64549 m .58576 .64865 L .58627 .64743 L F
.869 .691 .165 r
.72375 .49145 m .72341 .49074 L .72344 .48835 L F
0 0 .33 r
.72351 .49387 m .72341 .49074 L .72375 .49145 L F
.391 .68 .975 r
.78114 .50723 m .77883 .50753 L .77798 .506 L F
.035 .331 .813 r
.79033 .52213 m .78847 .52224 L .78757 .52045 L F
.67 .736 .9 r
.73641 .48879 m .73302 .48811 L .73561 .48747 L F
0 .475 .823 r
.73561 .48747 m .73883 .48878 L .73641 .48879 L F
.82 .455 .364 r
.49761 .68422 m .49932 .68247 L .49764 .68176 L F
.49761 .68422 m .50049 .68521 L .49932 .68247 L F
.213 .359 .795 r
.50154 .6856 m .49932 .68247 L .50049 .68521 L F
.687 .777 .92 r
.51819 .64623 m .51509 .64764 L .51834 .64783 L F
.51819 .64623 m .51509 .64764 L .51834 .64783 L F
.494 .572 .863 r
.51834 .64783 m .5196 .6462 L .51819 .64623 L F
.51834 .64783 m .52107 .64789 L .5196 .6462 L F
.572 .513 .751 r
.51896 .6507 m .52107 .64789 L .51834 .64783 L F
.033 0 .158 r
.52548 .68218 m .52732 .68151 L .52779 .67977 L F
.047 0 .198 r
.52548 .68218 m .52526 .68461 L .52732 .68151 L F
.694 .666 .818 r
.5777 .59943 m .57954 .59764 L .57818 .59497 L F
.831 .651 .659 r
.60191 .6069 m .60347 .61017 L .60522 .6075 L F
.509 .245 .45 r
.53346 .68883 m .536 .68908 L .53649 .68864 L F
.523 .226 .405 r
.38919 .62157 m .39154 .62138 L .39211 .61946 L F
.497 .157 .321 r
.39154 .62138 m .39499 .61875 L .39211 .61946 L F
.841 .973 .879 r
.48523 .71964 m .48242 .72239 L .48316 .7225 L F
.93 .836 .73 r
.49908 .68793 m .50066 .68918 L .50154 .6856 L F
.594 .222 .306 r
.50542 .62748 m .5019 .62805 L .50402 .62967 L F
.515 .075 .142 r
.50402 .62967 m .50763 .62811 L .50542 .62748 L F
.705 .72 .197 r
.53709 .71454 m .53736 .71338 L .53794 .71127 L F
.224 0 .072 r
.53794 .71127 m .54011 .7111 L .54128 .70932 L F
.336 .352 .729 r
.54058 .71341 m .53794 .71127 L .53736 .71338 L F
.429 .407 .733 r
.34654 .60908 m .34738 .61288 L .34565 .61332 L F
0 0 .33 r
.55699 .65896 m .55801 .66132 L .55832 .66249 L F
0 0 .417 r
.55801 .66132 m .55819 .66454 L .55832 .66249 L F
.705 .287 .249 r
.49928 .6973 m .49789 .69887 L .49548 .69684 L F
.449 0 .069 r
.50054 .69864 m .49928 .6973 L .50128 .69609 L F
.50054 .69864 m .49789 .69887 L .49928 .6973 L F
.724 .89 .499 r
.58766 .64549 m .58838 .64388 L .58959 .64236 L F
.787 .953 .623 r
.58766 .64549 m .58705 .64532 L .58838 .64388 L F
.58766 .64549 m .58627 .64743 L .58705 .64532 L F
.952 .689 .236 r
.58959 .64236 m .58891 .64143 L .58862 .63877 L F
.993 .861 .52 r
.58959 .64236 m .58838 .64388 L .58891 .64143 L F
.552 .266 .434 r
.49999 .64515 m .49535 .64695 L .49611 .64439 L F
.49999 .64515 m .49683 .64743 L .49535 .64695 L F
.49999 .64515 m .49961 .64719 L .49683 .64743 L F
.49683 .64743 m .49961 .64719 L .49999 .64515 L F
.388 .199 .498 r
.49999 .64515 m .5019 .64449 L .50207 .64211 L F
.329 .072 .365 r
.49999 .64515 m .49961 .64719 L .5019 .64449 L F
.388 .199 .498 r
.50207 .64211 m .5019 .64449 L .49999 .64515 L F
.329 .072 .365 r
.5019 .64449 m .49961 .64719 L .49999 .64515 L F
.743 .722 .832 r
.57884 .60658 m .57606 .60741 L .57799 .60503 L F
.574 .245 .373 r
.57884 .60658 m .57783 .61081 L .57606 .60741 L F
.586 .5 .724 r
.58067 .60426 m .57884 .60658 L .57799 .60503 L F
.58067 .60426 m .58166 .60664 L .57884 .60658 L F
.574 .613 .854 r
.57911 .61037 m .58095 .61156 L .57853 .61223 L F
.534 .204 .355 r
.58166 .60664 m .57824 .61037 L .57884 .60658 L F
.574 .613 .854 r
.57912 .61035 m .58048 .61037 L .57911 .61037 L F
.58048 .61037 m .58095 .61156 L .57911 .61037 L F
0 0 .051 r
.58186 .60786 m .58095 .61156 L .5805 .61041 L F
.58186 .60786 m .5805 .61041 L .58063 .61004 L F
.58186 .60786 m .58047 .61033 L .58142 .60798 L F
.58186 .60786 m .58192 .60922 L .58095 .61156 L F
.58192 .60922 m .58197 .61034 L .58168 .61069 L F
.58192 .60922 m .58168 .61069 L .58095 .61156 L F
0 0 0 r
.58069 .61035 m .58186 .60786 L .58139 .60798 L F
.162 0 0 r
.58111 .60873 m .58119 .60866 L .58069 .61035 L F
0 0 .051 r
.58063 .61004 m .5805 .61041 L .58047 .61033 L F
.534 .204 .355 r
.58166 .60664 m .58116 .60857 L .57824 .61037 L F
.58116 .60857 m .5807 .61033 L .57912 .61035 L F
.58116 .60857 m .57912 .61035 L .57824 .61037 L F
.574 .613 .854 r
.57729 .61195 m .57853 .61223 L .57707 .61227 L F
.57912 .61035 m .57853 .61223 L .57813 .61214 L F
.57876 .61066 m .57813 .61214 L .57729 .61195 L F
.57912 .61035 m .57813 .61214 L .57876 .61066 L F
.534 .204 .355 r
.57824 .61037 m .57889 .61036 L .57783 .61081 L F
.57889 .61036 m .58046 .61035 L .57783 .61081 L F
.574 .613 .854 r
.58047 .61033 m .58048 .61037 L .57912 .61035 L F
.534 .204 .355 r
.5807 .61033 m .58069 .61035 L .57824 .61037 L F
.651 .648 .834 r
.57783 .61081 m .57876 .61066 L .57972 .60842 L F
.534 .204 .355 r
.58046 .61035 m .58069 .61035 L .58044 .61039 L F
.58046 .61035 m .58044 .61039 L .57783 .61081 L F
.574 .613 .854 r
.57972 .60842 m .58047 .61033 L .57912 .61035 L F
.651 .648 .834 r
.57876 .61066 m .58069 .61035 L .57972 .60842 L F
.574 .613 .854 r
.57972 .60842 m .57912 .61035 L .57729 .61195 L F
0 0 .051 r
.58142 .60798 m .58047 .61033 L .57972 .60842 L F
0 0 0 r
.58069 .61035 m .58139 .60798 L .57972 .60842 L F
.162 0 0 r
.5831 .60692 m .58451 .60706 L .58216 .60671 L F
.58227 .60676 m .58216 .60671 L .58166 .60664 L F
.5831 .60692 m .58216 .60671 L .58227 .60676 L F
0 0 0 r
.58204 .60843 m .5831 .60692 L .58186 .60786 L F
.162 0 0 r
.58216 .60777 m .5831 .60692 L .58206 .6084 L F
.58187 .60668 m .5831 .60692 L .58128 .60828 L F
.58166 .60664 m .5832 .60687 L .5831 .60692 L F
.5832 .60687 m .58451 .60706 L .5831 .60692 L F
.089 0 0 r
.5831 .60692 m .58655 .6042 L .58451 .60706 L F
.58556 .60498 m .58533 .60606 L .58655 .6042 L F
.5831 .60692 m .58533 .60606 L .58556 .60498 L F
.707 .563 .689 r
.58655 .6042 m .5882 .60746 L .58451 .60706 L F
.663 .279 .308 r
.58451 .60706 m .58589 .60721 L .58642 .60895 L F
.58589 .60721 m .5882 .60746 L .58642 .60895 L F
.471 .299 .566 r
.58537 .61061 m .58425 .60956 L .58412 .61187 L F
.58537 .61061 m .58642 .60895 L .58425 .60956 L F
.795 .717 .779 r
.58642 .60895 m .58675 .60923 L .58537 .61061 L F
.58675 .60923 m .5884 .61066 L .58412 .61187 L F
.214 0 0 r
.58412 .61187 m .58531 .61154 L .58645 .61162 L F
.58531 .61154 m .5884 .61066 L .58645 .61162 L F
0 .153 .625 r
.58994 .61441 m .58645 .61162 L .5884 .61066 L F
.283 .375 .781 r
.58891 .61347 m .58839 .61176 L .58645 .61162 L F
.58839 .61176 m .58787 .61006 L .58645 .61162 L F
.471 .299 .566 r
.58645 .61162 m .58642 .60895 L .58537 .61061 L F
.795 .717 .779 r
.58642 .60895 m .58537 .61061 L .58412 .61187 L F
.471 .299 .566 r
.58645 .61162 m .58537 .61061 L .58412 .61187 L F
.027 0 .469 r
.58645 .61162 m .58683 .61031 L .58642 .60895 L F
.776 .547 .589 r
.5882 .60746 m .58754 .6095 L .58642 .60895 L F
.914 .545 .314 r
.58754 .6095 m .5884 .61066 L .58642 .60895 L F
.027 0 .469 r
.58683 .61031 m .58761 .60767 L .58642 .60895 L F
.546 .58 .84 r
.58642 .60895 m .58451 .60706 L .58425 .60956 L F
.663 .279 .308 r
.58451 .60706 m .58642 .60895 L .58425 .60956 L F
.546 .58 .84 r
.58642 .60895 m .5831 .60692 L .58451 .60706 L F
.58642 .60895 m .58533 .60606 L .5831 .60692 L F
.245 .384 .806 r
.58642 .60895 m .58761 .60767 L .58533 .60606 L F
.807 .704 .752 r
.58761 .60767 m .58512 .60708 L .58533 .60606 L F
0 .315 .691 r
.58141 .60418 m .58533 .60606 L .5831 .60692 L F
.294 .781 .718 r
.5831 .60692 m .58533 .60606 L .58335 .60665 L F
.807 .704 .752 r
.58512 .60708 m .58335 .60665 L .58533 .60606 L F
.294 .781 .718 r
.5831 .60692 m .58335 .60665 L .58292 .607 L F
.5831 .60692 m .58292 .607 L .58215 .60763 L F
.5831 .60692 m .58215 .60763 L .58186 .60786 L F
0 0 0 r
.58069 .61035 m .58204 .60843 L .58186 .60786 L F
.162 0 0 r
.58128 .60828 m .5831 .60692 L .58111 .60873 L F
0 0 .05 r
.58215 .60763 m .58292 .607 L .58213 .60875 L F
.58204 .60843 m .58213 .60875 L .58192 .60922 L F
.162 0 0 r
.58213 .60781 m .58216 .60777 L .58212 .60785 L F
0 0 .05 r
.58215 .60763 m .58213 .60875 L .58204 .60843 L F
.58292 .607 m .58335 .60665 L .58311 .60708 L F
.58292 .607 m .58311 .60708 L .58192 .60922 L F
.58192 .60922 m .58335 .60665 L .58197 .61034 L F
.58186 .60786 m .58215 .60763 L .58192 .60922 L F
.162 0 0 r
.58119 .60866 m .58213 .60781 L .58069 .61035 L F
.58213 .60781 m .58212 .60785 L .58069 .61035 L F
.58216 .60777 m .58206 .6084 L .58069 .61035 L F
.58166 .60664 m .58187 .60668 L .58111 .60873 L F
.534 .204 .355 r
.57824 .61037 m .57783 .61081 L .57793 .61037 L F
.57824 .61037 m .57793 .61037 L .57884 .60658 L F
.564 .065 .028 r
.73305 .50073 m .73222 .50194 L .72925 .50071 L F
.986 .714 .351 r
.73305 .50073 m .7332 .5032 L .73222 .50194 L F
.743 .402 .405 r
.49046 .67105 m .49049 .67341 L .48727 .67284 L F
.583 .482 .705 r
.4925 .66827 m .49046 .67105 L .48962 .66741 L F
.4925 .66827 m .49285 .67075 L .49046 .67105 L F
.482 .195 .401 r
.49243 .67286 m .49046 .67105 L .49285 .67075 L F
.49243 .67286 m .49049 .67341 L .49046 .67105 L F
.842 .713 .183 r
.55949 .67324 m .55932 .67559 L .55962 .67437 L F
.55949 .67324 m .55932 .67559 L .55962 .67437 L F
0 .216 .739 r
.55708 .67091 m .55949 .67324 L .5587 .67293 L F
.805 .665 .709 r
.3439 .63957 m .34775 .6421 L .34633 .63949 L F
.3439 .63957 m .34604 .64242 L .34775 .6421 L F
.371 .773 .985 r
.34775 .6421 m .34707 .64018 L .34633 .63949 L F
.241 .465 .875 r
.35132 .64233 m .35392 .64358 L .35237 .64108 L F
.233 .453 .868 r
.35237 .64108 m .352 .64181 L .35132 .64233 L F
.371 .773 .985 r
.34775 .6421 m .352 .64181 L .34707 .64018 L F
.633 .703 .896 r
.34775 .6421 m .35132 .64233 L .352 .64181 L F
.358 .227 .563 r
.50546 .72591 m .50579 .72868 L .50521 .72795 L F
.50546 .72591 m .50579 .72868 L .50521 .72795 L F
.7 .742 .884 r
.7967 .47904 m .79767 .48075 L .79421 .48013 L F
.677 .731 .891 r
.8003 .47984 m .79767 .48075 L .7967 .47904 L F
.388 .406 .757 r
.44413 .69135 m .44643 .69419 L .44564 .69067 L F
.041 0 0 r
.57685 .58934 m .57907 .58867 L .58042 .58742 L F
.049 0 0 r
.57907 .58867 m .58282 .58718 L .58042 .58742 L F
.702 .816 .361 r
.48193 .72353 m .48096 .72552 L .48242 .72239 L F
.195 0 0 r
.40818 .61342 m .41004 .61377 L .41171 .61337 L F
.563 .046 0 r
.41004 .61377 m .41413 .61333 L .41171 .61337 L F
.138 0 .074 r
.4622 .66546 m .45948 .66783 L .46152 .66693 L F
.407 .065 .269 r
.46152 .66693 m .46435 .66481 L .4622 .66546 L F
.618 .439 .617 r
.52575 .65375 m .52837 .6552 L .52544 .65504 L F
.801 .387 .263 r
.47829 .72606 m .47687 .72756 L .47498 .72505 L F
.534 .32 .535 r
.47829 .72606 m .47871 .72511 L .47687 .72756 L F
.47829 .72606 m .48096 .72552 L .47871 .72511 L F
.47829 .72606 m .48061 .72805 L .48096 .72552 L F
.48096 .72552 m .48061 .72805 L .47829 .72606 L F
.775 .717 .798 r
.79713 .51855 m .79391 .51829 L .79594 .51711 L F
.492 .904 .874 r
.80052 .51667 m .79713 .51855 L .79594 .51711 L F
.80052 .51667 m .79993 .5174 L .79713 .51855 L F
.262 .754 .909 r
.38246 .58247 m .38593 .58255 L .38407 .58295 L F
0 .053 .619 r
.80354 .48557 m .80521 .48863 L .80397 .48695 L F
.497 .615 .899 r
.47559 .67099 m .47606 .66821 L .47376 .66837 L F
.47559 .67099 m .4774 .67042 L .47606 .66821 L F
0 0 .447 r
.47559 .67099 m .47662 .67307 L .4774 .67042 L F
.47559 .67099 m .47574 .67343 L .47662 .67307 L F
.259 0 0 r
.3747 .59508 m .37338 .59552 L .37114 .59546 L F
.37715 .59443 m .37338 .59552 L .3747 .59508 L F
.497 .157 .321 r
.39154 .62138 m .39394 .62115 L .39499 .61875 L F
.313 0 .057 r
.39394 .62115 m .39749 .61883 L .39499 .61875 L F
.504 .587 .871 r
.43253 .59153 m .43131 .59342 L .43067 .59165 L F
.513 .598 .876 r
.43253 .59153 m .43356 .59289 L .43131 .59342 L F
.699 .168 0 r
.79232 .52011 m .7937 .52154 L .79334 .52155 L F
.79317 .52142 m .79334 .52155 L .79326 .52156 L F
.79232 .52011 m .79334 .52155 L .79317 .52142 L F
.586 .252 .37 r
.79269 .52065 m .79319 .52129 L .79302 .52127 L F
.699 .168 0 r
.79232 .52011 m .79326 .52156 L .79278 .52098 L F
.586 .252 .37 r
.79269 .52065 m .79302 .52127 L .79278 .52098 L F
.059 .131 .625 r
.79273 .51919 m .79391 .51829 L .79302 .51932 L F
.79273 .51919 m .79302 .51932 L .79232 .52011 L F
.699 .168 0 r
.79246 .51981 m .79269 .52048 L .79273 .51919 L F
.79232 .52011 m .79278 .52098 L .79246 .51981 L F
.059 .131 .625 r
.79273 .51919 m .79269 .52065 L .79091 .51839 L F
.597 .617 .842 r
.79275 .51536 m .79391 .51829 L .79091 .51839 L F
.059 .131 .625 r
.79273 .51919 m .79091 .51839 L .79391 .51829 L F
.725 .686 .813 r
.79594 .51711 m .79391 .51829 L .79275 .51536 L F
.527 .619 .886 r
.79273 .51919 m .79409 .51698 L .79197 .5189 L F
.222 0 0 r
.79242 .51905 m .79273 .51919 L .79197 .5189 L F
.545 .639 .894 r
.7937 .52154 m .79463 .51985 L .79309 .52157 L F
.79463 .51985 m .79516 .51891 L .79447 .51979 L F
.79463 .51985 m .79447 .51979 L .79309 .52157 L F
0 0 0 r
.79467 .51983 m .79309 .52157 L .79516 .51891 L F
.222 0 0 r
.79467 .51983 m .79516 .51891 L .79273 .51919 L F
.79401 .5196 m .79273 .51919 L .79242 .51905 L F
.79467 .51983 m .79414 .51966 L .79401 .5196 L F
.79414 .51966 m .79273 .51919 L .79401 .5196 L F
.059 .131 .625 r
.79273 .51919 m .79319 .52129 L .79269 .52065 L F
.699 .168 0 r
.79269 .52048 m .79289 .52101 L .79273 .51919 L F
.844 .661 .656 r
.79289 .52108 m .79319 .52129 L .79273 .51919 L F
.586 .252 .37 r
.79278 .52098 m .79302 .52127 L .79285 .52124 L F
.699 .168 0 r
.79278 .52098 m .79326 .52156 L .79309 .52157 L F
.586 .252 .37 r
.79091 .51839 m .79269 .52065 L .78757 .52045 L F
.79269 .52065 m .79285 .52124 L .78757 .52045 L F
.282 .671 .971 r
.78757 .52045 m .78852 .5206 L .78943 .51965 L F
.78757 .52045 m .78927 .51971 L .78846 .51847 L F
.626 .798 .965 r
.78982 .51961 m .78923 .5198 L .7894 .51947 L F
.282 .671 .971 r
.78927 .51971 m .78943 .51965 L .78935 .51955 L F
.78927 .51971 m .78935 .51955 L .78846 .51847 L F
.626 .798 .965 r
.7894 .51947 m .78909 .51985 L .78873 .51925 L F
.78923 .5198 m .78909 .51985 L .7894 .51947 L F
.133 .332 .796 r
.78909 .51985 m .78757 .52045 L .78846 .51847 L F
.641 .432 .585 r
.79273 .51919 m .78931 .51981 L .78996 .51959 L F
.79273 .51919 m .79149 .52071 L .78931 .51981 L F
.282 .671 .971 r
.78852 .5206 m .79275 .52123 L .78931 .51981 L F
.641 .432 .585 r
.79149 .52071 m .79309 .52157 L .79033 .52213 L F
.79273 .51919 m .79213 .52083 L .79149 .52071 L F
.844 .661 .656 r
.78946 .51966 m .79213 .52083 L .79066 .51949 L F
.79213 .52083 m .79275 .5211 L .79219 .52067 L F
.79213 .52083 m .79219 .52067 L .79066 .51949 L F
.699 .168 0 r
.79289 .52101 m .79292 .52112 L .79273 .51919 L F
.79292 .52112 m .793 .52099 L .79273 .51919 L F
.79278 .52098 m .79309 .52157 L .79246 .51981 L F
.844 .661 .656 r
.79064 .51948 m .79289 .52108 L .79273 .51919 L F
.79275 .5211 m .79319 .52129 L .79064 .51948 L F
.641 .432 .585 r
.79273 .51919 m .793 .52099 L .79213 .52083 L F
.282 .671 .971 r
.79157 .52072 m .79285 .52124 L .79185 .52078 L F
.79275 .52123 m .79285 .52124 L .78931 .51981 L F
.79285 .52124 m .79319 .52129 L .7929 .52117 L F
.844 .661 .656 r
.78943 .51965 m .79273 .51919 L .79197 .5189 L F
.641 .432 .585 r
.78931 .51981 m .78936 .51976 L .79197 .5189 L F
.282 .671 .971 r
.79285 .52124 m .7929 .52117 L .78943 .51965 L F
.699 .168 0 r
.79292 .52112 m .79309 .52157 L .793 .52099 L F
.641 .432 .585 r
.793 .52099 m .79309 .52157 L .79149 .52071 L F
.282 .671 .971 r
.78931 .51981 m .79157 .52072 L .78946 .51966 L F
.79157 .52072 m .79185 .52078 L .78946 .51966 L F
.641 .432 .585 r
.78931 .51981 m .79033 .52213 L .78909 .51985 L F
.79149 .52071 m .79033 .52213 L .78931 .51981 L F
.282 .671 .971 r
.78852 .5206 m .78946 .51966 L .78943 .51965 L F
.133 .332 .796 r
.78909 .51985 m .79033 .52213 L .78757 .52045 L F
.73 .339 0 r
.78909 .51985 m .78846 .51847 L .78815 .51828 L F
.78824 .51845 m .78815 .51828 L .78813 .51826 L F
.78909 .51985 m .78815 .51828 L .78824 .51845 L F
.773 .846 .907 r
.78737 .52312 m .78788 .52482 L .79033 .52213 L F
.78737 .52312 m .79033 .52213 L .79023 .52255 L F
.609 .593 .81 r
.78737 .52312 m .79023 .52255 L .78954 .52093 L F
.78837 .51868 m .78954 .52093 L .78844 .51835 L F
.78737 .52312 m .78954 .52093 L .78837 .51868 L F
.78737 .52312 m .78843 .51838 L .78529 .52015 L F
.588 .1 0 r
.78833 .51847 m .78846 .51847 L .78935 .51955 L F
.78813 .51826 m .78816 .51828 L .78833 .51847 L F
.78816 .51828 m .78846 .51847 L .78833 .51847 L F
.597 .617 .842 r
.79275 .51536 m .79091 .51839 L .78974 .51535 L F
.422 .597 .917 r
.7891 .51329 m .79192 .51435 L .78974 .51535 L F
.445 .688 .968 r
.79192 .51435 m .79275 .51536 L .78974 .51535 L F
.649 .593 .778 r
.78949 .51941 m .79061 .5148 L .78813 .51826 L F
.626 .798 .965 r
.78824 .51828 m .7884 .51842 L .78813 .51826 L F
.649 .593 .778 r
.78949 .51941 m .79197 .5189 L .79061 .5148 L F
.626 .798 .965 r
.78957 .5194 m .78982 .51961 L .78956 .5194 L F
.355 .372 .74 r
.78845 .51838 m .78849 .51834 L .78844 .51835 L F
.609 .593 .81 r
.78843 .51838 m .78844 .51835 L .78841 .51837 L F
.626 .798 .965 r
.79197 .5189 m .79043 .51941 L .78841 .51837 L F
.053 0 0 r
.78844 .51835 m .78845 .51835 L .78844 .51836 L F
.626 .798 .965 r
.78851 .51833 m .78841 .51837 L .78824 .51828 L F
.79197 .5189 m .78841 .51837 L .78851 .51833 L F
.7884 .51842 m .78957 .5194 L .78836 .51845 L F
.79043 .51941 m .78982 .51961 L .78824 .51828 L F
.79197 .5189 m .78813 .51826 L .79115 .51801 L F
.78957 .5194 m .78956 .5194 L .78836 .51845 L F
.641 .432 .585 r
.78931 .51981 m .78909 .51985 L .78936 .51976 L F
.355 .372 .74 r
.79023 .52255 m .79067 .52112 L .78865 .51883 L F
.649 .593 .778 r
.78943 .51965 m .79197 .5189 L .78949 .51941 L F
.626 .798 .965 r
.78965 .51955 m .78922 .51941 L .78813 .51826 L F
.78922 .51941 m .78873 .51925 L .78813 .51826 L F
.588 .1 0 r
.78829 .51843 m .78935 .51955 L .78943 .51965 L F
.78813 .51826 m .78828 .51842 L .78829 .51843 L F
.78828 .51842 m .78935 .51955 L .78829 .51843 L F
.844 .661 .656 r
.78978 .5196 m .78981 .51961 L .79064 .51948 L F
.78946 .51966 m .79066 .51949 L .79064 .51948 L F
.641 .432 .585 r
.79273 .51919 m .78996 .51959 L .79197 .5189 L F
.415 .492 .83 r
.79381 .51329 m .79275 .51536 L .79192 .51435 L F
.795 .747 .809 r
.79197 .5189 m .79274 .51426 L .79061 .5148 L F
.725 .686 .813 r
.79594 .51711 m .79275 .51536 L .79507 .51625 L F
.415 .492 .83 r
.79381 .51329 m .79507 .51625 L .79275 .51536 L F
.795 .747 .809 r
.79197 .5189 m .79409 .51698 L .79274 .51426 L F
.527 .619 .886 r
.79273 .51919 m .79516 .51891 L .79409 .51698 L F
.762 .681 .773 r
.79161 .51809 m .79162 .51823 L .79467 .51983 L F
0 .415 .762 r
.79193 .51845 m .79197 .5189 L .79115 .51801 L F
.79232 .51873 m .79197 .5189 L .79193 .51845 L F
.79295 .51906 m .79197 .5189 L .79237 .5187 L F
.327 0 0 r
.79033 .52213 m .79309 .52157 L .7921 .52292 L F
0 0 0 r
.7921 .52292 m .79309 .52157 L .79467 .51983 L F
.762 .681 .773 r
.79193 .51845 m .7921 .52292 L .79436 .5202 L F
.79164 .51838 m .7921 .52292 L .79193 .51845 L F
.79162 .51823 m .79272 .51902 L .79467 .51983 L F
0 .415 .762 r
.79272 .51902 m .79467 .51983 L .79197 .5189 L F
.762 .681 .773 r
.79272 .51902 m .79436 .5202 L .79467 .51983 L F
0 .415 .762 r
.79303 .51907 m .79467 .51983 L .79272 .51902 L F
.79237 .5187 m .79232 .51873 L .79193 .51845 L F
.79303 .51907 m .79295 .51906 L .79237 .5187 L F
.355 .372 .74 r
.79067 .52112 m .79154 .51832 L .78946 .51863 L F
.622 .081 0 r
.79101 .51807 m .79193 .51845 L .79115 .51801 L F
.355 .372 .74 r
.79138 .51824 m .79125 .51818 L .78946 .51863 L F
.622 .081 0 r
.79078 .51816 m .79172 .5184 L .79101 .51807 L F
.327 0 0 r
.79033 .52213 m .7921 .52292 L .79023 .52255 L F
.355 .372 .74 r
.79023 .52255 m .7921 .52292 L .79164 .51838 L F
.622 .081 0 r
.79172 .5184 m .79142 .51824 L .79154 .51832 L F
.355 .372 .74 r
.79154 .51832 m .79164 .51838 L .79161 .51809 L F
.79023 .52255 m .79164 .51838 L .79154 .51832 L F
.622 .081 0 r
.79172 .5184 m .79193 .51845 L .79142 .51824 L F
.79154 .51832 m .79142 .51824 L .79101 .51807 L F
.355 .372 .74 r
.79157 .51821 m .79145 .51813 L .79125 .51818 L F
.79157 .51821 m .79125 .51818 L .79138 .51824 L F
.79154 .51832 m .79157 .51821 L .79138 .51824 L F
.79154 .51832 m .79138 .51824 L .78946 .51863 L F
.622 .081 0 r
.79003 .51846 m .79303 .51907 L .79237 .5187 L F
.79183 .51845 m .79237 .5187 L .79193 .51845 L F
.79003 .51846 m .79237 .5187 L .79183 .51845 L F
.355 .372 .74 r
.78946 .51863 m .79131 .51817 L .79061 .51821 L F
.622 .081 0 r
.79003 .51846 m .79193 .51845 L .79078 .51816 L F
.762 .681 .773 r
.79162 .51823 m .79164 .51838 L .79193 .51845 L F
.355 .372 .74 r
.79157 .51821 m .79161 .51809 L .79145 .51813 L F
.78871 .5189 m .78946 .51863 L .78865 .51883 L F
.649 .593 .778 r
.78943 .51965 m .78949 .51941 L .78813 .51826 L F
.626 .798 .965 r
.78982 .51961 m .78965 .51955 L .78813 .51826 L F
.844 .661 .656 r
.78943 .51965 m .78946 .51966 L .78981 .51961 L F
.78943 .51965 m .78981 .51961 L .78978 .5196 L F
.355 .372 .74 r
.79067 .52112 m .78946 .51863 L .78871 .5189 L F
0 0 0 r
.78801 .5192 m .79003 .51846 L .79101 .51807 L F
.78801 .5192 m .79101 .51807 L .79074 .51817 L F
.355 .372 .74 r
.78865 .51883 m .78946 .51863 L .78849 .51834 L F
.78946 .51863 m .79061 .51821 L .78849 .51834 L F
.79131 .51817 m .79071 .51817 L .78849 .51834 L F
0 0 0 r
.78801 .5192 m .79069 .51817 L .78876 .51837 L F
.355 .372 .74 r
.79131 .51817 m .79161 .51809 L .79071 .51817 L F
.053 0 0 r
.78876 .51837 m .79161 .51809 L .79003 .51846 L F
.78844 .51835 m .79071 .51817 L .78876 .51837 L F
.79071 .51817 m .79161 .51809 L .78876 .51837 L F
0 0 0 r
.78801 .5192 m .79074 .51817 L .79069 .51817 L F
.78876 .51837 m .79069 .51817 L .78888 .51824 L F
.355 .372 .74 r
.78865 .51883 m .78849 .51834 L .78845 .51838 L F
.053 0 0 r
.78844 .51836 m .78875 .51838 L .78853 .51863 L F
.78835 .51853 m .78864 .51897 L .78801 .5192 L F
.78844 .51836 m .78864 .51897 L .78835 .51853 L F
.626 .798 .965 r
.7884 .51842 m .78836 .51845 L .78813 .51826 L F
0 0 0 r
.78801 .5192 m .78888 .51824 L .78813 .51826 L F
.053 0 0 r
.78853 .51863 m .79003 .51846 L .78864 .51897 L F
.78875 .51838 m .79003 .51846 L .78853 .51863 L F
0 0 0 r
.79074 .51817 m .79101 .51807 L .79115 .51801 L F
.79074 .51817 m .79115 .51801 L .78938 .51816 L F
.79074 .51817 m .78938 .51816 L .78813 .51826 L F
.053 0 0 r
.78845 .51835 m .79003 .51846 L .78844 .51836 L F
.609 .593 .81 r
.78843 .51838 m .78841 .51837 L .78529 .52015 L F
0 0 0 r
.48363 .68543 m .48394 .68545 L .48084 .68696 L F
.24 .358 .783 r
.48301 .68284 m .48542 .68404 L .48363 .68543 L F
0 0 0 r
.48363 .68543 m .48394 .68545 L .48542 .68404 L F
.615 .73 .928 r
.7891 .51329 m .78735 .51571 L .78633 .51217 L F
.7891 .51329 m .78974 .51535 L .78735 .51571 L F
0 0 .472 r
.49485 .65056 m .49535 .64695 L .49683 .64743 L F
.49485 .65056 m .49594 .64947 L .49535 .64695 L F
0 0 0 r
.49485 .65056 m .49421 .65279 L .49594 .64947 L F
.567 .383 .591 r
.51663 .6539 m .51928 .65347 L .51896 .6507 L F
.572 .513 .751 r
.51896 .6507 m .52116 .65061 L .52107 .64789 L F
.478 .319 .586 r
.51896 .6507 m .52119 .65282 L .52116 .65061 L F
.51896 .6507 m .51928 .65347 L .52119 .65282 L F
.468 .325 .604 r
.57799 .60503 m .57606 .60741 L .57849 .60526 L F
.354 .158 .47 r
.57606 .60741 m .57783 .61081 L .57849 .60526 L F
.413 .709 .984 r
.40614 .58331 m .40535 .58466 L .40399 .58347 L F
.40614 .58331 m .40776 .58464 L .40535 .58466 L F
.5 .311 .555 r
.53284 .66184 m .53061 .66486 L .53062 .66239 L F
.676 .153 0 r
.54223 .62106 m .53748 .61905 L .53964 .6201 L F
.985 .826 .602 r
.49199 .65075 m .49265 .65373 L .49421 .65279 L F
0 0 0 r
.49265 .65373 m .49371 .65364 L .49421 .65279 L F
.49265 .65373 m .49148 .65392 L .49371 .65364 L F
.896 .983 .711 r
.54904 .61293 m .54793 .61563 L .54696 .61329 L F
.54904 .61293 m .54742 .61526 L .54793 .61563 L F
.922 .748 .649 r
.54742 .61526 m .54834 .61835 L .54793 .61563 L F
.233 0 0 r
.56852 .5922 m .57088 .59152 L .57185 .5899 L F
.386 0 .15 r
.57088 .59152 m .57431 .58929 L .57185 .5899 L F
.876 .993 .764 r
.53773 .67547 m .53733 .67771 L .53927 .67667 L F
.405 .315 .641 r
.22195 .57486 m .22236 .57778 L .22007 .57864 L F
.331 .161 .493 r
.22236 .57778 m .22003 .58039 L .22007 .57864 L F
.751 .577 .66 r
.49611 .64439 m .49208 .64674 L .49382 .64409 L F
.467 .624 .92 r
.77663 .52446 m .78058 .52673 L .7798 .52494 L F
.623 .691 .893 r
.78058 .52673 m .78139 .52374 L .7798 .52494 L F
.78058 .52673 m .78312 .5261 L .78139 .52374 L F
.7 .668 .815 r
.19904 .56876 m .19833 .57275 L .19681 .56991 L F
.19904 .56876 m .20049 .56984 L .19833 .57275 L F
0 .528 .794 r
.81234 .51119 m .81282 .51116 L .81042 .51074 L F
.067 .63 .751 r
.48671 .66746 m .48807 .66739 L .48962 .66741 L F
.593 .379 .56 r
.48772 .66934 m .48965 .66731 L .48807 .66739 L F
.431 .87 .901 r
.48962 .66741 m .48807 .66739 L .49035 .66657 L F
.593 .379 .56 r
.48965 .66731 m .49035 .66657 L .48807 .66739 L F
.067 .63 .751 r
.48564 .66748 m .48807 .66739 L .48671 .66746 L F
.431 .87 .901 r
.48962 .66741 m .49035 .66657 L .49146 .66591 L F
.573 .575 .817 r
.49146 .66591 m .4925 .66827 L .48962 .66741 L F
.714 .663 .798 r
.47982 .66534 m .48433 .6653 L .482 .66239 L F
.668 .335 .4 r
.47982 .66534 m .48186 .66683 L .48433 .6653 L F
.767 .673 .758 r
.482 .66239 m .48433 .6653 L .48576 .66332 L F
.699 .384 .439 r
.48186 .66683 m .48564 .66748 L .48433 .6653 L F
.838 .835 .843 r
.33854 .64154 m .34223 .64059 L .34105 .63858 L F
.567 .632 .875 r
.34105 .63858 m .34223 .64059 L .3439 .63957 L F
.827 .416 0 r
.56416 .63966 m .56494 .64154 L .56315 .63848 L F
.615 .835 .984 r
.63385 .44079 m .63538 .44182 L .63285 .44271 L F
0 .093 .637 r
.63285 .44271 m .63417 .44342 L .63385 .44079 L F
0 .249 .674 r
.46215 .71695 m .46217 .71678 L .46069 .71635 L F
.46215 .71695 m .46409 .71808 L .46217 .71678 L F
.526 .381 .627 r
.31183 .59615 m .31402 .59815 L .31413 .59562 L F
.31183 .59615 m .31187 .59878 L .31402 .59815 L F
.316 0 0 r
.52062 .63335 m .52268 .63376 L .52427 .63359 L F
.588 .075 0 r
.52268 .63376 m .52658 .634 L .52427 .63359 L F
.437 .637 .94 r
.41676 .58664 m .41512 .58671 L .41455 .58593 L F
.41676 .58664 m .41711 .58675 L .41512 .58671 L F
.202 .703 .91 r
.51074 .68492 m .51434 .68535 L .512 .68522 L F
.454 .218 .465 r
.44483 .68235 m .44691 .68204 L .44719 .67979 L F
.427 .195 .457 r
.44719 .67979 m .449 .68146 L .44939 .67941 L F
.44719 .67979 m .44691 .68204 L .449 .68146 L F
.566 .8 .987 r
.60153 .67133 m .59687 .66967 L .59805 .67065 L F
.60153 .67133 m .59915 .66888 L .59687 .66967 L F
.889 .938 .841 r
.60412 .66819 m .60301 .66749 L .60153 .67133 L F
.705 .718 .859 r
.4601 .68304 m .45632 .68226 L .45806 .68178 L F
.635 .68 .875 r
.46221 .68219 m .4601 .68304 L .45806 .68178 L F
.771 .682 .765 r
.31724 .63895 m .32119 .63955 L .31949 .63925 L F
.31724 .63895 m .31868 .64214 L .32119 .63955 L F
.834 .508 .437 r
.55481 .62073 m .55687 .62133 L .5572 .61907 L F
.498 .232 .441 r
.55687 .62133 m .55939 .62082 L .5572 .61907 L F
0 0 0 r
.58627 .64743 m .58607 .64928 L .58705 .64532 L F
.652 .835 .971 r
.76082 .51866 m .76392 .51898 L .76292 .51744 L F
.607 .702 .911 r
.76392 .51898 m .76537 .51656 L .76292 .51744 L F
.76392 .51898 m .7661 .51834 L .76537 .51656 L F
.674 .843 .964 r
.75665 .51904 m .75777 .52003 L .76082 .51866 L F
.871 .758 .735 r
.59957 .59528 m .60039 .59883 L .60138 .5964 L F
.049 .156 .656 r
.54083 .68227 m .54161 .68572 L .54261 .68412 L F
.374 0 0 r
.54442 .68563 m .54333 .68671 L .54161 .68572 L F
.008 .099 .611 r
.54161 .68572 m .54333 .68671 L .54261 .68412 L F
.219 0 .326 r
.47523 .68531 m .47505 .68773 L .47318 .68829 L F
.813 .997 .78 r
.47825 .68202 m .47523 .68531 L .47615 .68326 L F
.47825 .68202 m .47629 .68326 L .47523 .68531 L F
.422 .138 .374 r
.47668 .68616 m .47523 .68531 L .47629 .68326 L F
.47668 .68616 m .47505 .68773 L .47523 .68531 L F
.728 .445 .499 r
.51919 .69078 m .51577 .69313 L .51565 .69079 L F
.51919 .69078 m .51792 .69344 L .51577 .69313 L F
.572 .272 .42 r
.52113 .69284 m .51919 .69078 L .52147 .69091 L F
.52113 .69284 m .51792 .69344 L .51919 .69078 L F
.991 .886 .584 r
.47448 .70901 m .47306 .71054 L .47378 .70819 L F
.738 .938 .951 r
.47378 .70819 m .47448 .70901 L .4766 .70771 L F
.606 .348 .501 r
.51389 .65617 m .51637 .65604 L .51663 .6539 L F
.798 .72 .777 r
.51637 .65604 m .51928 .65347 L .51663 .6539 L F
.533 .068 .095 r
.47161 .68993 m .47291 .69024 L .47318 .68829 L F
.865 .659 .127 r
.4732 .68884 m .47291 .69024 L .4733 .69082 L F
.47318 .68829 m .47307 .68908 L .4732 .68884 L F
.47307 .68908 m .47291 .69024 L .4732 .68884 L F
0 0 0 r
.47381 .6891 m .47269 .68992 L .4726 .68992 L F
.47286 .68946 m .4726 .68992 L .47161 .68993 L F
.47381 .6891 m .4726 .68992 L .47286 .68946 L F
.533 .068 .095 r
.47161 .68993 m .47318 .68829 L .47505 .68773 L F
.436 .535 .86 r
.55059 .5982 m .55275 .59871 L .5527 .59864 L F
.529 .138 .243 r
.54883 .59783 m .55059 .5982 L .55212 .59592 L F
.128 0 0 r
.55059 .5982 m .55303 .59597 L .55212 .59592 L F
.55303 .59597 m .55407 .59503 L .55275 .59563 L F
.55303 .59597 m .55275 .59563 L .55212 .59592 L F
.529 .138 .243 r
.54858 .59797 m .55059 .5982 L .55212 .59592 L F
.634 .631 .83 r
.55387 .59705 m .55416 .59658 L .55395 .5963 L F
.596 .228 .314 r
.55387 .59705 m .55521 .59673 L .55275 .59871 L F
.872 .668 .624 r
.55392 .59777 m .55421 .59663 L .55333 .59655 L F
.512 0 0 r
.55421 .59663 m .55391 .59704 L .55351 .59656 L F
0 0 0 r
.55521 .59673 m .5538 .59706 L .55387 .59705 L F
.634 .631 .83 r
.55426 .59641 m .55724 .59607 L .55571 .59409 L F
.55387 .59705 m .55459 .59684 L .55426 .59641 L F
.872 .668 .624 r
.55461 .59687 m .55521 .59673 L .55445 .59666 L F
.55412 .59699 m .55461 .59687 L .55421 .59663 L F
.55461 .59687 m .55445 .59666 L .55421 .59663 L F
.512 0 0 r
.55445 .59666 m .55444 .59692 L .55421 .59663 L F
.55521 .59673 m .55494 .59679 L .55445 .59666 L F
.634 .631 .83 r
.55459 .59684 m .55484 .59677 L .55445 .59666 L F
.512 0 0 r
.55494 .59679 m .55444 .59692 L .55445 .59666 L F
.634 .631 .83 r
.55445 .59666 m .55724 .59607 L .55426 .59641 L F
.55484 .59677 m .55724 .59607 L .55445 .59666 L F
.872 .668 .624 r
.55392 .59777 m .55521 .59673 L .55412 .59699 L F
0 0 0 r
.55521 .59673 m .55363 .59711 L .5538 .59706 L F
.512 0 0 r
.55444 .59692 m .55391 .59704 L .55421 .59663 L F
.634 .631 .83 r
.55395 .5963 m .55426 .59641 L .55407 .59503 L F
.55416 .59658 m .55426 .59641 L .55395 .5963 L F
.55426 .59641 m .55571 .59409 L .55471 .59466 L F
.55426 .59641 m .55471 .59466 L .55407 .59503 L F
0 0 0 r
.55249 .59882 m .55387 .59705 L .55275 .59871 L F
.872 .668 .624 r
.55289 .59821 m .55392 .59777 L .55333 .59655 L F
.55275 .59871 m .55333 .59655 L .5521 .59778 L F
.128 0 0 r
.55059 .5982 m .55363 .59711 L .55303 .59597 L F
.872 .668 .624 r
.5521 .59778 m .55333 .59655 L .55108 .59632 L F
.527 .631 .897 r
.55108 .59632 m .55363 .59711 L .55229 .59759 L F
.55108 .59632 m .55229 .59759 L .55059 .5982 L F
.872 .668 .624 r
.55275 .59871 m .5531 .59843 L .55289 .59821 L F
.5531 .59843 m .55392 .59777 L .55289 .59821 L F
.128 0 0 r
.55303 .59597 m .55333 .59655 L .55407 .59503 L F
.512 0 0 r
.55351 .59656 m .55363 .59711 L .55333 .59655 L F
.128 0 0 r
.55333 .59655 m .55363 .59711 L .55386 .59601 L F
.55333 .59655 m .55386 .59601 L .55407 .59503 L F
.512 0 0 r
.55333 .59655 m .55363 .59711 L .55108 .59632 L F
.55391 .59704 m .55363 .59711 L .55351 .59656 L F
.436 .535 .86 r
.55059 .5982 m .5527 .59864 L .55108 .59632 L F
.529 .138 .243 r
.54858 .59797 m .55059 .5982 L .54883 .59783 L F
.623 .413 .577 r
.53526 .6706 m .53777 .67046 L .53746 .66787 L F
.333 0 .147 r
.49631 .65696 m .49534 .65879 L .49278 .65951 L F
.367 0 .164 r
.4977 .65808 m .49631 .65696 L .49859 .6564 L F
.4977 .65808 m .49534 .65879 L .49631 .65696 L F
.26 .21 .61 r
.44483 .68235 m .44665 .68444 L .44691 .68204 L F
.44483 .68235 m .44487 .68562 L .44665 .68444 L F
.767 .673 .758 r
.482 .66239 m .48576 .66332 L .48447 .66148 L F
.574 .847 .996 r
.48576 .66332 m .48621 .66187 L .48447 .66148 L F
.48576 .66332 m .48834 .6628 L .48621 .66187 L F
.681 .464 .585 r
.44892 .61552 m .44475 .61886 L .44568 .61696 L F
.828 .633 .639 r
.60306 .6152 m .60648 .61313 L .6032 .61269 L F
.60306 .6152 m .6045 .6158 L .60648 .61313 L F
.455 0 .036 r
.5127 .6471 m .51106 .64802 L .50909 .64773 L F
.491 0 0 r
.51509 .64764 m .51106 .64802 L .5127 .6471 L F
.755 .821 .904 r
.41973 .59871 m .42349 .59884 L .42185 .59762 L F
.41973 .59871 m .4207 .59933 L .42349 .59884 L F
.58 .573 .81 r
.4207 .59933 m .4234 .60129 L .42349 .59884 L F
.55 .804 .992 r
.42185 .59762 m .42349 .59884 L .42563 .59823 L F
.578 .395 .597 r
.42349 .59884 m .42579 .60082 L .42563 .59823 L F
.42349 .59884 m .4234 .60129 L .42579 .60082 L F
.188 .053 .455 r
.56821 .59532 m .56852 .5922 L .56722 .59348 L F
.282 0 .225 r
.45691 .67066 m .45882 .67013 L .45948 .66783 L F
.212 0 .199 r
.45948 .66783 m .46062 .66936 L .46152 .66693 L F
.45948 .66783 m .45882 .67013 L .46062 .66936 L F
0 0 0 r
.5264 .63987 m .52539 .63962 L .52825 .64109 L F
.52549 .63964 m .52408 .64157 L .52539 .63962 L F
.52509 .64083 m .52408 .64157 L .52549 .63964 L F
.5264 .63987 m .52509 .64083 L .52549 .63964 L F
.767 .703 .791 r
.52349 .63991 m .52408 .64157 L .5264 .63987 L F
.83 .731 .205 r
.52503 .63927 m .52489 .64305 L .52408 .64157 L F
.52503 .63927 m .52471 .64166 L .52474 .64188 L F
.52496 .64122 m .52474 .64188 L .52489 .64305 L F
.52503 .63927 m .52474 .64188 L .52496 .64122 L F
.584 .617 .851 r
.35132 .64233 m .35531 .64463 L .35392 .64358 L F
.515 .746 .979 r
.35531 .64463 m .35638 .64306 L .35392 .64358 L F
.35531 .64463 m .35743 .64432 L .35638 .64306 L F
.614 .202 .238 r
.50402 .62967 m .5019 .62805 L .50065 .62968 L F
.973 .661 .326 r
.55994 .68172 m .55937 .68327 L .55995 .6815 L F
0 0 .449 r
.55978 .67815 m .55994 .68172 L .56046 .67992 L F
.973 .661 .326 r
.55994 .68172 m .55995 .6815 L .56046 .67992 L F
0 .019 .561 r
.55992 .68206 m .55994 .68172 L .55798 .67967 L F
.56021 .68241 m .55994 .68172 L .55992 .68206 L F
.929 .656 .501 r
.56235 .68437 m .55994 .68172 L .56021 .68241 L F
0 .084 .635 r
.56512 .59425 m .56633 .59773 L .56464 .59557 L F
.748 .515 .577 r
.47971 .68226 m .47629 .68326 L .47825 .68202 L F
.626 .734 .925 r
.77225 .5053 m .77568 .50628 L .77318 .50704 L F
.446 .745 .992 r
.53736 .71338 m .53885 .71454 L .53709 .71454 L F
.141 0 0 r
.76955 .48842 m .76755 .4906 L .77126 .48841 L F
0 0 .303 r
.49685 .68504 m .49761 .68422 L .49764 .68176 L F
.008 .193 .706 r
.49685 .68504 m .49908 .68793 L .49761 .68422 L F
.555 .814 .994 r
.56242 .62073 m .5607 .62215 L .55939 .62082 L F
.293 .318 .717 r
.56242 .62073 m .56304 .62416 L .5607 .62215 L F
0 0 0 r
.78025 .48352 m .77775 .48633 L .77928 .48467 L F
.78025 .48352 m .77928 .48467 L .78082 .48362 L F
.754 .961 .936 r
.60598 .66653 m .60301 .66749 L .60412 .66819 L F
.601 .436 .63 r
.51412 .6733 m .51644 .67037 L .51421 .67109 L F
.51644 .67037 m .51412 .6733 L .51421 .67109 L F
0 0 .417 r
.57587 .6623 m .57559 .66191 L .57385 .65953 L F
.094 .62 .874 r
.57587 .6623 m .57666 .662 L .57559 .66191 L F
.933 .618 .42 r
.57587 .6623 m .57613 .66468 L .57432 .66386 L F
.57587 .6623 m .57432 .66386 L .57666 .662 L F
.09 .591 .896 r
.47602 .66211 m .47954 .66313 L .47867 .66154 L F
.626 .707 .904 r
.47867 .66154 m .47954 .66313 L .482 .66239 L F
.714 .663 .798 r
.47982 .66534 m .482 .66239 L .47954 .66313 L F
.971 .812 .628 r
.4669 .67387 m .46953 .67098 L .46913 .67343 L F
.4 .853 .891 r
.36887 .58229 m .36484 .583 L .36699 .58248 L F
.427 .871 .866 r
.37107 .58147 m .36887 .58229 L .36699 .58248 L F
.74 .595 .695 r
.44944 .70819 m .45205 .705 L .44978 .70617 L F
.433 .832 .98 r
.40254 .61307 m .40439 .61252 L .40572 .61288 L F
.555 .172 .27 r
.40471 .61498 m .40572 .61288 L .40439 .61252 L F
.40471 .61498 m .40818 .61342 L .40572 .61288 L F
.834 .707 .724 r
.58456 .65063 m .58104 .65127 L .58117 .65106 L F
.58456 .65063 m .58301 .65376 L .58104 .65127 L F
0 0 0 r
.77764 .48596 m .77737 .48615 L .77635 .48697 L F
.625 .956 .798 r
.77928 .48467 m .77775 .48633 L .77737 .48615 L F
0 0 0 r
.77928 .48467 m .77737 .48615 L .77764 .48596 L F
.195 .722 .839 r
.77737 .48615 m .77775 .48633 L .77707 .48636 L F
.77737 .48615 m .77707 .48636 L .77436 .48648 L F
.767 .272 0 r
.56116 .63623 m .55992 .63541 L .55851 .63339 L F
0 .035 .588 r
.56116 .63623 m .56249 .63728 L .55992 .63541 L F
.56116 .63623 m .56315 .63848 L .56249 .63728 L F
.077 .33 .807 r
.58609 .60191 m .5859 .60059 L .58319 .59817 L F
0 .182 .716 r
.58806 .60368 m .58609 .60191 L .58655 .6042 L F
.58806 .60368 m .5859 .60059 L .58609 .60191 L F
.681 .306 .33 r
.58609 .60191 m .58806 .60368 L .58655 .6042 L F
.257 .721 .949 r
.37454 .58273 m .37676 .58272 L .37801 .58325 L F
.089 0 0 r
.37676 .58272 m .38024 .58312 L .37801 .58325 L F
.566 .37 .575 r
.46128 .68825 m .4609 .6908 L .45879 .69074 L F
.93 .836 .73 r
.49908 .68793 m .50154 .6856 L .50049 .68521 L F
.917 .537 .121 r
.57046 .65033 m .56853 .64686 L .56906 .64822 L F
.726 .491 .571 r
.5754 .63566 m .57734 .63566 L .57714 .6335 L F
0 0 0 r
.57344 .59682 m .57453 .59695 L .572 .59631 L F
.57344 .59682 m .57595 .59609 L .57453 .59695 L F
.77294 .49183 m .77365 .49185 L .77206 .49329 L F
.329 0 0 r
.7784 .49117 m .77832 .49138 L .77549 .49143 L F
.178 .7 .874 r
.77549 .49143 m .77559 .49142 L .77731 .49108 L F
.77559 .49142 m .77832 .49138 L .77731 .49108 L F
.601 .94 .941 r
.77731 .49108 m .78033 .49027 L .77991 .49002 L F
0 0 0 r
.77864 .49082 m .77731 .49108 L .77991 .49002 L F
.715 .749 .879 r
.78113 .49023 m .77788 .4918 L .77785 .49157 L F
0 0 0 r
.77647 .49218 m .77731 .49108 L .77864 .49082 L F
.759 .856 .922 r
.78033 .49027 m .78432 .48944 L .78366 .48848 L F
.621 .943 .949 r
.78195 .48861 m .78033 .49027 L .78366 .48848 L F
.62 .959 .847 r
.77991 .49002 m .78033 .49027 L .78195 .48861 L F
0 0 0 r
.77588 .49255 m .77607 .49236 L .77647 .49218 L F
.77607 .49236 m .77731 .49108 L .77647 .49218 L F
.197 0 0 r
.7768 .49119 m .77731 .49108 L .77588 .49255 L F
.77365 .49185 m .7768 .49119 L .77588 .49255 L F
.178 .7 .874 r
.77549 .49143 m .77731 .49108 L .77365 .49185 L F
0 0 0 r
.77588 .49255 m .77991 .49002 L .77861 .48852 L F
.83 .638 .644 r
.77561 .48797 m .77588 .49255 L .77861 .48852 L F
.715 .749 .879 r
.78095 .49019 m .77785 .49157 L .77763 .48961 L F
.759 .856 .922 r
.78033 .49027 m .7792 .49139 L .78432 .48944 L F
.715 .749 .879 r
.78113 .49023 m .77785 .49157 L .78095 .49019 L F
.197 0 0 r
.77365 .49185 m .77588 .49255 L .77415 .49187 L F
.77365 .49185 m .77415 .49187 L .77294 .49139 L F
0 0 0 r
.77294 .49183 m .77297 .49182 L .77365 .49185 L F
.77297 .49182 m .77549 .49143 L .77365 .49185 L F
.89 .644 .56 r
.59275 .62453 m .59034 .62644 L .59056 .62393 L F
.59275 .62453 m .5924 .62767 L .59034 .62644 L F
.509 .818 1 r
.31472 .62508 m .31658 .62419 L .3172 .6219 L F
.566 .534 .778 r
.3172 .6219 m .31822 .61792 L .31598 .61827 L F
.3172 .6219 m .31938 .62141 L .31822 .61792 L F
.434 .118 .328 r
.3172 .6219 m .3189 .62331 L .31938 .62141 L F
.3172 .6219 m .31658 .62419 L .3189 .62331 L F
.489 .54 .836 r
.43619 .5946 m .43507 .59664 L .43356 .59289 L F
.562 .632 .879 r
.43619 .5946 m .43717 .59601 L .43507 .59664 L F
.656 .575 .752 r
.48517 .67538 m .48588 .67948 L .48341 .67967 L F
.37 .205 .522 r
.48509 .68152 m .48341 .67967 L .48588 .67948 L F
.48509 .68152 m .48301 .68284 L .48341 .67967 L F
.54 .334 .55 r
.52975 .66542 m .53006 .66542 L .53006 .66538 L F
.52701 .66578 m .52969 .66546 L .52975 .66542 L F
.52969 .66546 m .53006 .66542 L .52975 .66542 L F
.196 0 .298 r
.53285 .66321 m .53061 .66486 L .53284 .66184 L F
.577 .361 .552 r
.52978 .66118 m .53199 .66382 L .53108 .66043 L F
.657 .365 .466 r
.53285 .66321 m .53223 .66364 L .53154 .66418 L F
.53223 .66364 m .53203 .66379 L .53199 .66382 L F
.53223 .66364 m .53199 .66382 L .53154 .66418 L F
.577 .361 .552 r
.53199 .66382 m .53006 .66542 L .5325 .66442 L F
.466 0 0 r
.53061 .66486 m .52988 .66533 L .52864 .66498 L F
.53061 .66486 m .52864 .66498 L .52812 .66479 L F
.577 .361 .552 r
.52978 .66118 m .53005 .66521 L .53199 .66382 L F
.657 .365 .466 r
.53154 .66418 m .53181 .66393 L .53061 .66486 L F
.53203 .66379 m .53181 .66393 L .53154 .66418 L F
.53181 .66393 m .52988 .66533 L .53061 .66486 L F
.577 .361 .552 r
.53005 .66521 m .53006 .66542 L .53199 .66382 L F
.54 .334 .55 r
.52701 .66578 m .53006 .66538 L .52941 .66519 L F
.657 .365 .466 r
.53181 .66393 m .53027 .66502 L .52988 .66533 L F
.466 0 0 r
.52988 .66533 m .52928 .66571 L .52864 .66498 L F
.657 .365 .466 r
.53027 .66502 m .52928 .66571 L .52981 .66537 L F
.54 .334 .55 r
.52941 .66519 m .53006 .66538 L .53004 .66504 L F
.657 .365 .466 r
.53027 .66502 m .52981 .66537 L .52988 .66533 L F
.54 .334 .55 r
.52701 .66578 m .53004 .66504 L .52752 .66493 L F
.453 0 0 r
.52679 .66508 m .52978 .66539 L .52701 .66578 L F
.52978 .66539 m .53006 .66542 L .52969 .66546 L F
.52978 .66539 m .52969 .66546 L .52701 .66578 L F
.52679 .66508 m .52928 .66571 L .53006 .66542 L F
.655 .351 .444 r
.52937 .66567 m .5325 .66442 L .53006 .66542 L F
.52928 .66571 m .5309 .66506 L .52937 .66567 L F
.5309 .66506 m .5325 .66442 L .52937 .66567 L F
.746 .698 .806 r
.5345 .66482 m .53402 .66549 L .53367 .66469 L F
.5357 .665 m .53421 .66544 L .5345 .66482 L F
.53421 .66544 m .53402 .66549 L .5345 .66482 L F
.53612 .66506 m .53161 .6662 L .5357 .665 L F
.714 .527 .634 r
.53161 .6662 m .53273 .66425 L .5325 .66442 L F
.746 .698 .806 r
.53612 .66506 m .53232 .66449 L .53395 .66383 L F
.573 .41 .622 r
.53477 .66143 m .53612 .66506 L .53285 .66321 L F
.53555 .6607 m .53564 .66138 L .53477 .66143 L F
.53564 .66138 m .53612 .66506 L .53477 .66143 L F
.667 .442 .569 r
.53754 .65848 m .53767 .66086 L .53555 .6607 L F
.438 .314 .613 r
.53691 .66109 m .53555 .6607 L .53767 .66086 L F
.583 .539 .772 r
.53598 .66105 m .53674 .66131 L .53662 .66104 L F
.53498 .66108 m .53584 .66119 L .53598 .66105 L F
.53584 .66119 m .53674 .66131 L .53598 .66105 L F
.53674 .66131 m .53737 .6614 L .53733 .66133 L F
.74 .382 .372 r
.53767 .66086 m .53915 .66237 L .53691 .66109 L F
.583 .539 .772 r
.53725 .66128 m .53733 .66133 L .5373 .66128 L F
.53674 .66131 m .53733 .66133 L .53725 .66128 L F
.53674 .66131 m .5373 .66128 L .53482 .65679 L F
.74 .382 .372 r
.53691 .66109 m .53963 .66305 L .53661 .66118 L F
.53963 .66305 m .53951 .66303 L .53661 .66118 L F
.53915 .66237 m .54026 .66351 L .53883 .66248 L F
.539 .66229 m .53883 .66248 L .53691 .66109 L F
.53915 .66237 m .53883 .66248 L .539 .66229 L F
.649 .488 .652 r
.54026 .66351 m .53773 .66587 L .53661 .66118 L F
.101 0 0 r
.53805 .66323 m .53835 .66306 L .53838 .66293 L F
.864 .79 .777 r
.54012 .65809 m .54094 .66258 L .53767 .66086 L F
.743 .22 0 r
.54094 .66258 m .54026 .66351 L .53903 .66225 L F
.53905 .66158 m .53903 .66225 L .53767 .66086 L F
.54094 .66258 m .53903 .66225 L .53905 .66158 L F
.101 0 0 r
.53835 .66306 m .53901 .66266 L .53853 .66284 L F
.064 .206 .701 r
.54212 .6602 m .54094 .66258 L .54012 .65809 L F
.101 0 0 r
.53901 .66266 m .54183 .661 L .53902 .66257 L F
.53901 .66266 m .53902 .66257 L .53853 .66284 L F
.53835 .66306 m .53853 .66284 L .53838 .66293 L F
.604 .585 .805 r
.5384 .6628 m .54094 .65892 L .53916 .65915 L F
.53838 .66293 m .53845 .66281 L .5384 .6628 L F
.53845 .66281 m .54094 .65892 L .5384 .6628 L F
.74 .382 .372 r
.53963 .66305 m .54026 .66351 L .53951 .66303 L F
.525 .344 .578 r
.53584 .66119 m .53661 .66118 L .53737 .6614 L F
.438 .314 .613 r
.5361 .66095 m .53564 .66138 L .53555 .6607 L F
.525 .344 .578 r
.53498 .66108 m .53661 .66118 L .53584 .66119 L F
.438 .314 .613 r
.53661 .66118 m .53564 .66138 L .53584 .66119 L F
.53661 .66118 m .53584 .66119 L .5361 .66095 L F
.53661 .66118 m .53612 .66506 L .53564 .66138 L F
.53661 .66118 m .5361 .66095 L .53691 .66109 L F
.5361 .66095 m .53555 .6607 L .53691 .66109 L F
.583 .539 .772 r
.53497 .66075 m .53662 .66104 L .53482 .65679 L F
.53498 .66108 m .53662 .66104 L .53497 .66075 L F
.746 .698 .806 r
.53612 .66506 m .53519 .66639 L .53369 .66631 L F
.53612 .66506 m .53369 .66631 L .53416 .66556 L F
.683 .418 .515 r
.53581 .66799 m .53161 .6662 L .53519 .66639 L F
0 0 0 r
.53361 .66655 m .5341 .66568 L .53406 .66558 L F
.53394 .6657 m .53406 .66558 L .53402 .66549 L F
.746 .698 .806 r
.53402 .66568 m .53369 .66631 L .53333 .66629 L F
.53416 .66556 m .53409 .66566 L .53402 .66568 L F
.53409 .66566 m .53369 .66631 L .53402 .66568 L F
.53406 .66558 m .53333 .66629 L .53161 .6662 L F
.53416 .66556 m .53333 .66629 L .53406 .66558 L F
.714 .527 .634 r
.53161 .6662 m .53361 .66655 L .53394 .6657 L F
.53161 .6662 m .53394 .6657 L .53402 .66549 L F
0 0 0 r
.53361 .66655 m .53406 .66558 L .53394 .6657 L F
.5341 .66568 m .53525 .66489 L .53622 .66224 L F
.53427 .66538 m .53622 .66224 L .53661 .66118 L F
.5341 .66568 m .53622 .66224 L .53427 .66538 L F
.53361 .66655 m .53377 .6664 L .5341 .66568 L F
.53377 .6664 m .53525 .66489 L .5341 .66568 L F
.53402 .66549 m .53661 .66118 L .53513 .66259 L F
.5341 .66568 m .53661 .66118 L .53402 .66549 L F
.746 .698 .806 r
.53367 .66469 m .53161 .6662 L .53258 .66452 L F
.53402 .66549 m .53161 .6662 L .53367 .66469 L F
.714 .527 .634 r
.53161 .6662 m .53402 .66549 L .53513 .66259 L F
.746 .698 .806 r
.53395 .66383 m .53295 .66423 L .53285 .66321 L F
.697 .615 .761 r
.53245 .66428 m .5325 .66442 L .53273 .66425 L F
.746 .698 .806 r
.53295 .66423 m .53232 .66449 L .53241 .66429 L F
.53295 .66423 m .53241 .66429 L .53285 .66321 L F
.657 .365 .466 r
.53285 .66321 m .53242 .66425 L .53203 .66379 L F
.697 .615 .761 r
.53108 .66043 m .53245 .66428 L .53513 .66259 L F
.53245 .66428 m .53273 .66425 L .53513 .66259 L F
.714 .527 .634 r
.53161 .6662 m .53513 .66259 L .53273 .66425 L F
.655 .351 .444 r
.52928 .66571 m .53161 .6662 L .5325 .66442 L F
.746 .698 .806 r
.53258 .66452 m .53161 .6662 L .53232 .66449 L F
.657 .365 .466 r
.53203 .66379 m .53161 .6662 L .52928 .66571 L F
.577 .361 .552 r
.53199 .66382 m .5325 .66442 L .53245 .66428 L F
.53199 .66382 m .53245 .66428 L .53203 .66379 L F
.657 .365 .466 r
.53242 .66425 m .53161 .6662 L .53203 .66379 L F
.577 .361 .552 r
.53203 .66379 m .53245 .66428 L .53222 .66363 L F
.53199 .66382 m .53222 .66363 L .53108 .66043 L F
.466 0 0 r
.52864 .66498 m .52928 .66571 L .52679 .66508 L F
.52864 .66498 m .52752 .66493 L .52812 .66479 L F
.54 .334 .55 r
.52752 .66493 m .53004 .66504 L .52978 .66118 L F
.466 0 0 r
.52864 .66498 m .52679 .66508 L .52752 .66493 L F
.741 .784 .887 r
.5828 .67056 m .58334 .67266 L .58633 .67092 L F
.052 .093 .586 r
.61353 .64679 m .61297 .65055 L .61335 .64776 L F
.61353 .64679 m .61349 .64996 L .61297 .65055 L F
.925 .822 .363 r
.61349 .64996 m .61306 .65367 L .61297 .65055 L F
.341 .244 .597 r
.44487 .68562 m .44724 .68698 L .44665 .68444 L F
.44487 .68562 m .44506 .68825 L .44724 .68698 L F
.209 0 0 r
.38352 .63576 m .38234 .6369 L .38016 .63683 L F
.285 0 0 r
.3856 .63543 m .38234 .6369 L .38352 .63576 L F
.799 .733 .79 r
.41588 .5954 m .41389 .59874 L .41739 .59881 L F
.509 .492 .773 r
.41739 .59881 m .41842 .59478 L .41588 .5954 L F
.41739 .59881 m .41973 .59871 L .41842 .59478 L F
.435 .385 .704 r
.31098 .60749 m .31219 .60341 L .31098 .60355 L F
.31098 .60749 m .31267 .60704 L .31219 .60341 L F
.429 .365 .684 r
.31098 .60749 m .31331 .60948 L .31267 .60704 L F
.48 .366 .646 r
.3113 .61004 m .31331 .60948 L .31098 .60749 L F
.622 .447 .624 r
.64276 .44563 m .6428 .44832 L .64005 .44866 L F
.067 0 .173 r
.64502 .44285 m .64402 .4458 L .64276 .44563 L F
.561 .398 .618 r
.64529 .44764 m .64276 .44563 L .64402 .4458 L F
.64529 .44764 m .6428 .44832 L .64276 .44563 L F
0 .014 .588 r
.55819 .66454 m .55991 .66688 L .56023 .66838 L F
.753 .62 .054 r
.55991 .66688 m .55992 .67083 L .56023 .66838 L F
.667 .604 .775 r
.75898 .49762 m .7565 .49838 L .75532 .49533 L F
.709 .6 .733 r
.54287 .60774 m .54271 .61153 L .54401 .60656 L F
.995 .844 .576 r
.54157 .60916 m .54271 .61153 L .54287 .60774 L F
.17 0 0 r
.28034 .83744 m .28003 .83633 L .27819 .83757 L F
.28034 .83744 m .28157 .83608 L .28003 .83633 L F
.773 .808 .881 r
.26724 .85122 m .26845 .85275 L .26475 .85268 L F
.716 .3 .258 r
.26475 .85268 m .26845 .85275 L .26611 .8542 L F
.149 .488 .902 r
.2689 .85171 m .26845 .85275 L .26724 .85122 L F
.679 .963 .74 r
.26611 .8542 m .26845 .85275 L .2689 .85171 L F
.846 .997 .775 r
.26598 .85567 m .26845 .85275 L .26611 .8542 L F
.62 .329 .455 r
.58535 .58717 m .58882 .58627 L .58865 .58435 L F
.799 .588 .617 r
.58882 .58627 m .59104 .58408 L .58865 .58435 L F
.308 0 .228 r
.52677 .65736 m .52544 .65504 L .52837 .6552 L F
.52642 .65675 m .5247 .65808 L .52544 .65504 L F
.825 .541 .509 r
.52116 .65061 m .52119 .65282 L .52534 .65354 L F
.105 .22 .7 r
.52119 .65282 m .52316 .6545 L .52534 .65354 L F
.783 .654 .72 r
.52316 .6545 m .52595 .65201 L .52534 .65354 L F
.52316 .6545 m .52733 .65592 L .52595 .65201 L F
.52733 .65592 m .52752 .65598 L .52745 .6558 L F
.52733 .65592 m .52745 .6558 L .52595 .65201 L F
.308 0 .228 r
.52677 .65736 m .52513 .65793 L .52642 .65675 L F
.52513 .65793 m .5247 .65808 L .52642 .65675 L F
.773 .651 .728 r
.76145 .49627 m .75898 .49762 L .75937 .49474 L F
.625 .597 .802 r
.76258 .50041 m .75898 .49762 L .76145 .49627 L F
.655 .527 .696 r
.76487 .49747 m .76258 .50041 L .76145 .49627 L F
.578 .528 .762 r
.54283 .67944 m .54495 .67662 L .54222 .67728 L F
.615 .074 0 r
.54222 .67728 m .54266 .67816 L .53927 .67667 L F
.811 .9 .905 r
.54495 .67662 m .54266 .67816 L .54222 .67728 L F
0 0 .287 r
.57178 .65565 m .57053 .6526 L .57107 .65352 L F
.908 .645 .528 r
.59095 .61292 m .59294 .61614 L .59104 .61535 L F
.9 .706 .63 r
.59104 .61535 m .59294 .61614 L .59247 .61862 L F
.252 .756 .883 r
.19233 .54381 m .19198 .54436 L .19024 .54386 L F
.602 .638 .859 r
.50318 .67739 m .50682 .67935 L .50604 .67828 L F
.529 .299 .51 r
.50827 .67607 m .50604 .67828 L .50682 .67935 L F
.116 .667 .724 r
.19411 .54409 m .19623 .54379 L .19786 .54361 L F
.129 0 0 r
.19792 .5441 m .19786 .54361 L .19623 .54379 L F
.19792 .5441 m .19994 .54356 L .19786 .54361 L F
.604 .393 .568 r
.39982 .61592 m .40229 .61559 L .40254 .61307 L F
.587 .378 .564 r
.40254 .61307 m .40471 .61498 L .40439 .61252 L F
.40254 .61307 m .40229 .61559 L .40471 .61498 L F
.444 0 .05 r
.52658 .634 m .52904 .63491 L .53006 .63306 L F
.405 0 .033 r
.53006 .63306 m .53129 .63449 L .53267 .63251 L F
.53006 .63306 m .52904 .63491 L .53129 .63449 L F
.02 0 0 r
.55806 .5959 m .55919 .59613 L .55724 .59607 L F
.55806 .5959 m .5604 .59539 L .55919 .59613 L F
.555 .814 .994 r
.56242 .62073 m .56209 .61749 L .56311 .61899 L F
0 0 .319 r
.56449 .61644 m .56311 .61899 L .56209 .61749 L F
.56449 .61644 m .56471 .61772 L .56311 .61899 L F
.141 0 .047 r
.56423 .62003 m .56311 .61899 L .56471 .61772 L F
.56423 .62003 m .56242 .62073 L .56311 .61899 L F
.415 .293 .604 r
.212 .59879 m .21216 .60108 L .21052 .60166 L F
.366 .177 .486 r
.21216 .60108 m .21202 .60325 L .21052 .60166 L F
.202 .158 .582 r
.21202 .60325 m .21095 .60445 L .21052 .60166 L F
.419 0 0 r
.48083 .66609 m .47982 .66534 L .47898 .66552 L F
.354 .436 .807 r
.48083 .66609 m .47898 .66552 L .47791 .66308 L F
.48083 .66609 m .47791 .66308 L .47921 .66295 L F
.109 .319 .792 r
.48126 .66432 m .48083 .66609 L .47921 .66295 L F
.776 .982 .906 r
.48001 .6655 m .48083 .66609 L .48126 .66432 L F
.47956 .66592 m .48083 .66609 L .48001 .6655 L F
.419 0 0 r
.48083 .66609 m .48186 .66683 L .48186 .66683 L F
.48083 .66609 m .48186 .66683 L .47982 .66534 L F
.707 .193 .003 r
.52563 .72308 m .5254 .7247 L .52389 .7223 L F
.52563 .72308 m .52783 .72513 L .5254 .7247 L F
.558 .302 .483 r
.52844 .72275 m .52783 .72513 L .52563 .72308 L F
.509 .32 .559 r
.46128 .68825 m .46321 .68975 L .4609 .6908 L F
.509 .818 1 r
.31472 .62508 m .31348 .62422 L .31658 .62419 L F
.345 .281 .641 r
.31472 .62508 m .31658 .62419 L .31348 .62422 L F
.31472 .62508 m .3167 .62691 L .31658 .62419 L F
.125 .249 .722 r
.3158 .62728 m .3167 .62691 L .31472 .62508 L F
.987 .798 .566 r
.59917 .59785 m .60039 .59883 L .59957 .59528 L F
.966 .651 .367 r
.59933 .60022 m .60039 .59883 L .59917 .59785 L F
.59933 .60022 m .60068 .60113 L .60039 .59883 L F
.551 .551 .806 r
.41128 .59887 m .41389 .59874 L .41202 .59636 L F
.538 .357 .583 r
.48609 .70057 m .48513 .70268 L .48732 .69968 L F
.595 .638 .864 r
.75215 .52084 m .7537 .5174 L .75103 .51927 L F
.75215 .52084 m .75462 .52028 L .7537 .5174 L F
.662 .537 .702 r
.50969 .69114 m .51266 .69118 L .51048 .68724 L F
.504 .215 .409 r
.51266 .69118 m .50968 .69362 L .50969 .69114 L F
.51266 .69118 m .50968 .69362 L .50969 .69114 L F
.825 .873 .88 r
.50078 .64885 m .50087 .65073 L .50379 .64826 L F
0 .324 .81 r
.50217 .65063 m .50087 .65073 L .50078 .64885 L F
.50217 .65063 m .50362 .65269 L .50087 .65073 L F
.44 .395 .712 r
.50362 .65269 m .50173 .65348 L .50087 .65073 L F
.964 .773 .595 r
.26475 .85268 m .26598 .85567 L .26421 .85515 L F
0 .148 .689 r
.26475 .85268 m .26598 .85567 L .26611 .8542 L F
.681 .924 .971 r
.26421 .85515 m .26598 .85567 L .26611 .8542 L F
.363 .444 .81 r
.34654 .60908 m .34415 .60764 L .34635 .60703 L F
.71 .247 .151 r
.56304 .62416 m .56633 .62488 L .5642 .62505 L F
.608 .535 .747 r
.76607 .50371 m .7638 .50449 L .76258 .50041 L F
.674 .456 .581 r
.64005 .44866 m .63824 .44969 L .63778 .44856 L F
.64005 .44866 m .6401 .45116 L .63824 .44969 L F
.589 .374 .557 r
.6428 .44832 m .6401 .45116 L .64005 .44866 L F
0 0 .077 r
.53348 .68156 m .53293 .68377 L .53195 .68439 L F
.357 .1 .38 r
.53543 .68088 m .53293 .68377 L .53348 .68156 L F
.652 .411 .542 r
.52958 .68024 m .53318 .68092 L .53273 .68036 L F
.52958 .68024 m .53287 .68113 L .53318 .68092 L F
0 0 .53 r
.53318 .68092 m .53293 .68377 L .53426 .68224 L F
.652 .411 .542 r
.53274 .6811 m .53277 .68118 L .53287 .68113 L F
0 0 .53 r
.53273 .68036 m .53278 .68119 L .53318 .68092 L F
.53278 .68119 m .53293 .68377 L .53318 .68094 L F
.53287 .68113 m .53318 .68094 L .53318 .68092 L F
.53278 .68119 m .53318 .68094 L .53287 .68113 L F
.646 .356 .465 r
.53329 .68094 m .53295 .68154 L .53516 .68458 L F
0 0 .53 r
.53325 .6822 m .53372 .68328 L .53357 .68337 L F
.53278 .68119 m .53357 .68337 L .53293 .68377 L F
.53378 .68325 m .53384 .68342 L .53293 .68377 L F
0 0 .077 r
.53195 .68439 m .53293 .68377 L .53145 .68531 L F
0 .287 .786 r
.53516 .68458 m .53293 .68377 L .53379 .68344 L F
.53516 .68458 m .53542 .68584 L .53293 .68377 L F
.646 .356 .465 r
.53295 .68154 m .53435 .68472 L .53516 .68458 L F
0 .287 .786 r
.53516 .68458 m .53379 .68344 L .53384 .68342 L F
.486 .376 .653 r
.53542 .68584 m .53336 .68651 L .53293 .68377 L F
.646 .356 .465 r
.53379 .68344 m .53086 .68535 L .53435 .68472 L F
.53295 .68154 m .5325 .68237 L .53379 .68344 L F
.5325 .68237 m .53086 .68535 L .53379 .68344 L F
0 0 .53 r
.53313 .68179 m .53378 .68325 L .53372 .68328 L F
.53313 .68179 m .53372 .68328 L .53325 .6822 L F
.627 .334 .454 r
.53279 .68121 m .53329 .68094 L .53287 .68113 L F
.53285 .68131 m .53329 .68094 L .53279 .68121 L F
.52825 .68524 m .53086 .68535 L .53295 .68154 L F
.53285 .68131 m .53295 .68154 L .53329 .68094 L F
.52825 .68524 m .53295 .68154 L .53285 .68131 L F
.5281 .68401 m .53278 .68119 L .52803 .68338 L F
.53278 .68119 m .53287 .68113 L .53277 .68118 L F
.53278 .68119 m .53277 .68118 L .52803 .68338 L F
0 0 .53 r
.53278 .68119 m .53357 .68337 L .53278 .68119 L F
.627 .334 .454 r
.52825 .68524 m .53279 .68121 L .5281 .68401 L F
.53279 .68121 m .53287 .68113 L .53278 .68119 L F
.53279 .68121 m .53278 .68119 L .5281 .68401 L F
0 0 .53 r
.53323 .68213 m .53357 .68337 L .53281 .68124 L F
.53285 .68131 m .53281 .68124 L .53277 .68115 L F
.53323 .68213 m .53281 .68124 L .53285 .68131 L F
.53277 .68115 m .53281 .68124 L .53278 .68119 L F
.53281 .68124 m .53357 .68337 L .53278 .68119 L F
.53273 .68036 m .53323 .68213 L .53277 .68115 L F
.53273 .68036 m .53344 .68232 L .53313 .68179 L F
.53344 .68232 m .53378 .68325 L .53313 .68179 L F
.627 .334 .454 r
.52825 .68524 m .53285 .68131 L .53279 .68121 L F
.652 .411 .542 r
.52958 .68024 m .52803 .68338 L .53277 .68118 L F
.52958 .68024 m .53277 .68118 L .53274 .6811 L F
.53318 .68092 m .53287 .68113 L .53329 .68094 L F
0 0 .53 r
.53273 .68036 m .53426 .68224 L .53543 .68088 L F
.652 .411 .542 r
.53318 .68092 m .53329 .68094 L .53273 .68036 L F
.68 .388 .472 r
.54011 .7111 m .54383 .70892 L .54128 .70932 L F
.401 .586 .917 r
.58074 .67061 m .5823 .66938 L .5794 .66951 L F
.58074 .67061 m .5828 .67056 L .5823 .66938 L F
.686 .471 .59 r
.45911 .68069 m .46221 .68219 L .45806 .68178 L F
.483 .673 .948 r
.77663 .52446 m .77882 .52281 L .77603 .52282 L F
.77663 .52446 m .7798 .52494 L .77882 .52281 L F
.084 0 0 r
.38304 .59319 m .38133 .59409 L .37922 .59443 L F
0 0 0 r
.38345 .59323 m .38304 .59319 L .38525 .5927 L F
.38345 .59323 m .38133 .59409 L .38304 .59319 L F
.847 .644 .627 r
.58978 .60726 m .59165 .61038 L .58947 .6097 L F
.855 .693 .681 r
.58947 .6097 m .59165 .61038 L .59095 .61292 L F
.01 0 0 r
.32625 .63489 m .32555 .63447 L .32746 .63417 L F
.32625 .63489 m .32409 .6355 L .32555 .63447 L F
.88 .484 .276 r
.53621 .61835 m .5344 .61848 L .53317 .61554 L F
.637 .112 0 r
.53748 .61905 m .5344 .61848 L .53621 .61835 L F
.579 .359 .546 r
.46953 .67098 m .47169 .67288 L .46913 .67343 L F
.46953 .67098 m .47169 .67288 L .46913 .67343 L F
.572 .562 .804 r
.7365 .49628 m .73554 .49993 L .73485 .49838 L F
.7365 .49628 m .73803 .4994 L .73554 .49993 L F
.514 0 0 r
.55543 .67896 m .55798 .67967 L .55468 .67917 L F
.346 .502 .87 r
.32977 .63551 m .33012 .63315 L .32746 .63417 L F
.32977 .63551 m .33135 .63579 L .33012 .63315 L F
.751 .394 .378 r
.53777 .67046 m .53978 .67276 L .54135 .67093 L F
.625 .431 .6 r
.53978 .67276 m .54314 .66987 L .54135 .67093 L F
.5 .161 .324 r
.49553 .63201 m .49343 .63046 L .49306 .63265 L F
.49553 .63201 m .49587 .63018 L .49343 .63046 L F
.81 .616 .64 r
.60897 .62733 m .61088 .62785 L .60917 .62465 L F
.808 .629 .66 r
.61071 .63034 m .61088 .62785 L .60897 .62733 L F
.508 .811 1 r
.79142 .51087 m .79485 .51142 L .7923 .5119 L F
.79142 .51087 m .79485 .51142 L .7923 .5119 L F
.513 .146 .28 r
.41986 .61024 m .4188 .61255 L .42182 .61146 L F
.618 .496 .692 r
.41986 .61024 m .42246 .61014 L .42205 .60744 L F
.52 .137 .255 r
.41986 .61024 m .42182 .61146 L .42246 .61014 L F
.322 0 0 r
.33565 .58463 m .33743 .5851 L .33905 .58374 L F
.347 0 0 r
.33743 .5851 m .34138 .584 L .33905 .58374 L F
.801 .425 .346 r
.59121 .63028 m .59314 .63018 L .59199 .63226 L F
.918 .802 .716 r
.5924 .62767 m .59314 .63018 L .59121 .63028 L F
.966 .683 .445 r
.59314 .63018 m .59377 .63337 L .59199 .63226 L F
.79 .671 .733 r
.47956 .68544 m .47952 .68541 L .48055 .68438 L F
.623 .638 .845 r
.47874 .68621 m .4795 .68543 L .47862 .68572 L F
.4795 .68543 m .47948 .68543 L .47862 .68572 L F
.346 0 .067 r
.47954 .68544 m .47617 .68871 L .47668 .68616 L F
.47956 .68544 m .47955 .68545 L .47954 .68544 L F
.47955 .68545 m .47617 .68871 L .47954 .68544 L F
.623 .638 .845 r
.4795 .68543 m .47952 .68541 L .47948 .68543 L F
.47952 .68541 m .48055 .68438 L .47943 .68516 L F
.47952 .68541 m .47943 .68516 L .47862 .68572 L F
.458 .366 .664 r
.47862 .68572 m .47943 .68516 L .47971 .68226 L F
.47943 .68516 m .47981 .68489 L .47978 .68244 L F
.47981 .68489 m .48055 .68438 L .48028 .68372 L F
.47981 .68489 m .48028 .68372 L .47978 .68244 L F
.47943 .68516 m .47978 .68244 L .47971 .68226 L F
.79 .671 .733 r
.47952 .68541 m .47629 .68326 L .48055 .68438 L F
.623 .638 .845 r
.47893 .68703 m .48084 .68696 L .48055 .68438 L F
.748 .515 .577 r
.47971 .68226 m .48028 .68372 L .47629 .68326 L F
.48028 .68372 m .48055 .68438 L .48013 .68427 L F
.48028 .68372 m .48013 .68427 L .47629 .68326 L F
0 0 .036 r
.48108 .68313 m .48053 .68536 L .47982 .68542 L F
.623 .638 .845 r
.47893 .68703 m .48055 .68438 L .47987 .68507 L F
.47893 .68703 m .47987 .68507 L .47958 .68542 L F
0 0 0 r
.48053 .68536 m .47839 .68841 L .47956 .68544 L F
.47956 .68544 m .47956 .68544 L .47956 .68544 L F
.48053 .68536 m .47956 .68544 L .47956 .68544 L F
.623 .638 .845 r
.47958 .68541 m .47987 .68507 L .47962 .68532 L F
.47962 .68536 m .47987 .68507 L .47958 .68541 L F
0 0 .036 r
.48108 .68313 m .47957 .68542 L .48055 .68438 L F
.47957 .68542 m .47956 .68544 L .48055 .68438 L F
.623 .638 .845 r
.47958 .68542 m .47962 .68536 L .47958 .68541 L F
0 0 .036 r
.47957 .68542 m .47956 .68544 L .47956 .68544 L F
.79 .671 .733 r
.47956 .68544 m .47954 .68544 L .47952 .68541 L F
.623 .638 .845 r
.47889 .68689 m .47956 .68544 L .47874 .68621 L F
.47893 .68703 m .47962 .68532 L .47889 .68689 L F
.346 0 .067 r
.47955 .68545 m .47839 .68841 L .47617 .68871 L F
.47956 .68544 m .47956 .68544 L .47955 .68545 L F
.47956 .68544 m .47839 .68841 L .47955 .68545 L F
.623 .638 .845 r
.47956 .68544 m .47962 .68532 L .47948 .68545 L F
.47956 .68544 m .47948 .68545 L .47874 .68621 L F
0 0 .036 r
.47965 .6853 m .4796 .68543 L .47956 .68544 L F
.47965 .6853 m .47956 .68544 L .47957 .68542 L F
.47997 .68485 m .47982 .68542 L .4796 .68543 L F
.48108 .68313 m .47982 .68542 L .47997 .68485 L F
.48108 .68313 m .4796 .68543 L .47965 .6853 L F
.79 .671 .733 r
.4794 .68533 m .47668 .68616 L .47629 .68326 L F
.47952 .68541 m .47939 .68545 L .4794 .68533 L F
.47939 .68545 m .47668 .68616 L .4794 .68533 L F
.47954 .68544 m .47668 .68616 L .47952 .68541 L F
.26 .158 .544 r
.2173 .58606 m .21556 .58469 L .21786 .5836 L F
.2173 .58606 m .21547 .58768 L .21556 .58469 L F
.378 0 0 r
.39176 .6332 m .39024 .63475 L .38802 .63493 L F
.301 0 0 r
.394 .63276 m .39024 .63475 L .39176 .6332 L F
.64 .148 .067 r
.55684 .59248 m .55924 .59391 L .5604 .59293 L F
0 .222 .693 r
.5771 .66791 m .57765 .66792 L .57623 .66667 L F
.5771 .66791 m .5794 .66951 L .57765 .66792 L F
.582 .323 .489 r
.51048 .68724 m .51434 .68535 L .51074 .68492 L F
.51048 .68724 m .51441 .68762 L .51434 .68535 L F
.617 .519 .721 r
.51048 .68724 m .51476 .6909 L .51441 .68762 L F
.51048 .68724 m .51266 .69118 L .51476 .6909 L F
.83 .369 .115 r
.59585 .59001 m .59759 .59247 L .59924 .59299 L F
.935 .617 .412 r
.59793 .59447 m .59924 .59299 L .59759 .59247 L F
.59793 .59447 m .59957 .59528 L .59924 .59299 L F
.947 .651 .202 r
.61262 .63849 m .61291 .64098 L .61382 .64205 L F
.997 .779 .434 r
.61291 .64098 m .6137 .6444 L .61382 .64205 L F
.49 0 0 r
.53267 .63251 m .53539 .63424 L .53574 .63407 L F
0 .192 .626 r
.53706 .63483 m .53574 .63407 L .53539 .63424 L F
.618 .067 0 r
.53574 .63407 m .53837 .63576 L .53993 .63569 L F
0 .192 .626 r
.53706 .63483 m .53837 .63576 L .53574 .63407 L F
.26 .646 .965 r
.35839 .62338 m .36041 .62358 L .3598 .62448 L F
.313 .711 .979 r
.36041 .62358 m .36184 .62448 L .3598 .62448 L F
.705 .474 .572 r
.63425 .45092 m .63778 .44856 L .63824 .44969 L F
.468 .595 .897 r
.76837 .5198 m .7687 .51798 L .7661 .51834 L F
.76837 .5198 m .77 .52045 L .7687 .51798 L F
.776 .73 .809 r
.74818 .48905 m .74467 .4888 L .74678 .48865 L F
.719 .454 0 r
.74833 .48993 m .74818 .48905 L .74678 .48865 L F
.74833 .48993 m .74865 .49111 L .74818 .48905 L F
.35 .024 .264 r
.52261 .68577 m .52526 .68461 L .52249 .68581 L F
.52261 .68577 m .52269 .68584 L .52526 .68461 L F
.918 .827 .74 r
.52431 .6859 m .52273 .68582 L .52526 .68461 L F
.35 .024 .264 r
.52269 .68584 m .52353 .68657 L .52526 .68461 L F
.918 .827 .74 r
.52273 .68582 m .52249 .68581 L .52526 .68461 L F
0 0 .261 r
.46737 .7079 m .46559 .71121 L .46519 .70824 L F
.46737 .7079 m .46704 .7102 L .46559 .71121 L F
0 0 .435 r
.46704 .7102 m .46595 .71406 L .46559 .71121 L F
.387 0 .122 r
.40584 .62715 m .40662 .62876 L .40441 .62925 L F
.40584 .62715 m .40804 .62687 L .40662 .62876 L F
.388 0 0 r
.53837 .63576 m .54169 .6365 L .53993 .63569 L F
0 0 .33 r
.72351 .49387 m .72389 .49303 L .72341 .49074 L F
0 0 .438 r
.72351 .49387 m .72468 .49673 L .72389 .49303 L F
.696 .963 .721 r
.5587 .67293 m .55483 .67655 L .55333 .67361 L F
.5587 .67293 m .55551 .67526 L .55483 .67655 L F
.979 .766 .547 r
.55949 .67324 m .55551 .67526 L .5587 .67293 L F
.904 .915 .818 r
.80002 .52098 m .80289 .519 L .80213 .51979 L F
.799 .588 .617 r
.58882 .58627 m .59246 .58691 L .59104 .58408 L F
.972 .771 .573 r
.60897 .62733 m .60917 .62465 L .60784 .62348 L F
.515 .075 .142 r
.50402 .62967 m .50772 .62901 L .50763 .62811 L F
.66 .189 .123 r
.50772 .62901 m .50982 .62983 L .50763 .62811 L F
.664 .16 .039 r
.50763 .62811 m .50982 .62983 L .51174 .62968 L F
.666 .402 .511 r
.51441 .68762 m .51678 .68539 L .51434 .68535 L F
.159 .025 .436 r
.22485 .56326 m .22353 .5659 L .22346 .56382 L F
.349 .529 .891 r
.44473 .69687 m .4483 .69972 L .44672 .69932 L F
.579 .346 .528 r
.44473 .69687 m .44672 .69932 L .44715 .69666 L F
.783 .686 .757 r
.49996 .69369 m .50389 .69436 L .50263 .69054 L F
.563 .244 .385 r
.50128 .69609 m .50389 .69436 L .49996 .69369 L F
.50128 .69609 m .50375 .69618 L .50389 .69436 L F
.50389 .69436 m .50375 .69618 L .50128 .69609 L F
.657 .323 .397 r
.50692 .69605 m .50375 .69618 L .50389 .69436 L F
0 0 .034 r
.50389 .69436 m .50383 .69514 L .50449 .6938 L F
.50383 .69514 m .50375 .69618 L .50419 .69478 L F
.50383 .69514 m .50419 .69478 L .50449 .6938 L F
.582 .297 .448 r
.50692 .69605 m .50373 .6987 L .50375 .69618 L F
.50692 .69605 m .50611 .6988 L .50373 .6987 L F
.615 .329 .46 r
.50926 .69831 m .50611 .6988 L .50692 .69605 L F
.335 0 0 r
.50342 .69609 m .50286 .69611 L .50375 .69618 L F
.50083 .69538 m .50286 .69611 L .50342 .69609 L F
.706 .483 .584 r
.50375 .69618 m .50054 .69864 L .50128 .69609 L F
.947 .958 .706 r
.50196 .69462 m .50286 .69611 L .50083 .69538 L F
.50218 .69447 m .50232 .6948 L .50196 .69462 L F
.50232 .6948 m .50286 .69611 L .50196 .69462 L F
.50232 .6948 m .50115 .69725 L .50286 .69611 L F
.50218 .69447 m .50115 .69725 L .50232 .6948 L F
.618 .475 .665 r
.50115 .69725 m .50223 .69613 L .50286 .69611 L F
.50223 .69613 m .50449 .6938 L .50286 .69611 L F
.807 1 .825 r
.50344 .69615 m .50286 .69611 L .50329 .69549 L F
.50344 .69615 m .50329 .69549 L .50449 .6938 L F
.50375 .69618 m .50344 .69615 L .50449 .6938 L F
.706 .483 .584 r
.50375 .69618 m .50373 .6987 L .50054 .69864 L F
.618 .475 .665 r
.50115 .69725 m .50373 .69746 L .50324 .69526 L F
.50115 .69725 m .50309 .69458 L .50449 .6938 L F
.50277 .69502 m .50324 .69526 L .50309 .69458 L F
.50115 .69725 m .50324 .69526 L .50277 .69502 L F
.786 .582 .624 r
.50309 .69458 m .50713 .69712 L .50639 .69451 L F
0 0 .12 r
.50609 .69424 m .50692 .69516 L .5055 .69482 L F
.235 .038 .396 r
.5089 .69511 m .50717 .69373 L .50804 .69364 L F
.823 .417 .28 r
.50639 .69451 m .50804 .69364 L .50804 .69328 L F
.777 .295 0 r
.50804 .69328 m .50804 .69364 L .50609 .69077 L F
.786 .582 .624 r
.50441 .69455 m .50639 .69451 L .50454 .69442 L F
.328 0 0 r
.50449 .6938 m .50632 .69423 L .50309 .69458 L F
.786 .582 .624 r
.50454 .69442 m .50529 .69446 L .50602 .69426 L F
.50529 .69446 m .50639 .69451 L .50602 .69426 L F
.50309 .69458 m .50441 .69455 L .50454 .69442 L F
.602 .465 .667 r
.5055 .69482 m .50309 .69458 L .50632 .69423 L F
.36 .269 .615 r
.50768 .69268 m .50632 .69423 L .50558 .6912 L F
0 0 .12 r
.50768 .69268 m .5055 .69482 L .50632 .69423 L F
.50768 .69268 m .5073 .69391 L .50609 .69424 L F
.786 .582 .624 r
.50602 .69426 m .50639 .69451 L .50632 .69423 L F
.235 .038 .396 r
.5089 .69511 m .50692 .69605 L .50717 .69373 L F
.823 .417 .28 r
.50639 .69451 m .5089 .69511 L .50804 .69364 L F
.615 .329 .46 r
.50926 .69831 m .50692 .69605 L .5089 .69511 L F
.537 .633 .893 r
.51143 .69705 m .50926 .69831 L .5089 .69511 L F
.729 .495 .573 r
.50639 .69451 m .51143 .69705 L .5089 .69511 L F
.50639 .69451 m .50713 .69712 L .51143 .69705 L F
0 0 .12 r
.5073 .69391 m .50692 .69516 L .50609 .69424 L F
.998 .796 .507 r
.60961 .65842 m .61011 .66154 L .61066 .65926 L F
.85 .91 .875 r
.61237 .65579 m .60961 .65842 L .61066 .65926 L F
.639 .831 .974 r
.80114 .49823 m .80301 .49636 L .80122 .49552 L F
.535 .64 .901 r
.80114 .49823 m .80434 .49862 L .80301 .49636 L F
.555 .436 .672 r
.53893 .6476 m .54095 .64443 L .53862 .64491 L F
.187 0 .009 r
.53968 .64601 m .53862 .64491 L .54095 .64443 L F
.53968 .64601 m .53752 .64684 L .53862 .64491 L F
.953 .747 .589 r
.78788 .52482 m .78908 .52628 L .78954 .52314 L F
.568 .656 .896 r
.4418 .59508 m .44124 .5984 L .43939 .59535 L F
.4418 .59508 m .44352 .598 L .44124 .5984 L F
.55 .469 .716 r
.44352 .598 m .44198 .60182 L .44124 .5984 L F
.026 .298 .791 r
.41018 .59412 m .41133 .59372 L .40883 .59215 L F
.41018 .59412 m .41186 .59524 L .41133 .59372 L F
.551 .625 .878 r
.58633 .67092 m .59012 .67343 L .5884 .6708 L F
.53 .654 .914 r
.59012 .67343 m .59088 .67056 L .5884 .6708 L F
.59012 .67343 m .59205 .67298 L .59088 .67056 L F
.815 .407 .275 r
.59281 .5891 m .59467 .59151 L .59585 .59001 L F
.808 .397 .27 r
.59467 .59151 m .59759 .59247 L .59585 .59001 L F
.105 0 0 r
.34366 .58377 m .34589 .58341 L .34741 .58254 L F
.355 0 0 r
.34741 .58254 m .34589 .58341 L .34943 .58298 L F
.422 0 .115 r
.38551 .62357 m .38778 .62348 L .38919 .62157 L F
.42 0 .113 r
.38778 .62348 m .39154 .62138 L .38919 .62157 L F
.359 0 0 r
.43067 .61899 m .42917 .62041 L .42691 .62061 L F
.583 .107 .091 r
.43067 .61899 m .43256 .62064 L .42917 .62041 L F
.542 .128 .206 r
.43297 .61913 m .43256 .62064 L .43067 .61899 L F
.55 .469 .716 r
.44352 .598 m .44422 .60139 L .44198 .60182 L F
.586 .507 .732 r
.44422 .60139 m .4424 .60423 L .44198 .60182 L F
0 .514 .849 r
.3569 .62257 m .35574 .62271 L .35471 .62094 L F
.3569 .62257 m .35839 .62338 L .35574 .62271 L F
0 0 .08 r
.57232 .63429 m .57242 .63394 L .5718 .63284 L F
0 .1 .64 r
.5718 .63284 m .57242 .63394 L .5728 .63623 L F
0 0 .212 r
.57299 .63615 m .5728 .63623 L .57242 .63394 L F
0 .073 .626 r
.57987 .64615 m .58013 .64681 L .57994 .64797 L F
0 0 0 r
.57986 .64927 m .57994 .64797 L .58013 .64681 L F
.57986 .64927 m .57859 .65084 L .57994 .64797 L F
.491 0 0 r
.51509 .64764 m .5136 .64887 L .51421 .64772 L F
.2 0 0 r
.51819 .64623 m .5136 .64887 L .51509 .64764 L F
.51819 .64623 m .51591 .64815 L .5136 .64887 L F
.652 .787 .946 r
.5136 .64887 m .51591 .64815 L .51608 .64589 L F
0 0 0 r
.51608 .64589 m .51298 .65001 L .5136 .64887 L F
.51298 .65001 m .51237 .65083 L .5136 .64887 L F
.491 0 0 r
.51421 .64772 m .5136 .64887 L .51106 .64802 L F
.425 .837 .654 r
.80177 .50271 m .79991 .50392 L .79803 .50505 L F
.448 .139 .347 r
.31894 .5924 m .32154 .59076 L .31917 .5912 L F
.763 .586 .657 r
.74677 .50011 m .7434 .49729 L .74718 .49774 L F
0 .532 .785 r
.38593 .58255 m .38849 .58297 L .38987 .58336 L F
.386 .813 .967 r
.38849 .58297 m .39222 .58303 L .38987 .58336 L F
.564 .289 .458 r
.51968 .64212 m .51969 .64415 L .5174 .64389 L F
.57 .612 .855 r
.73417 .48473 m .73302 .48811 L .73162 .48544 L F
.73417 .48473 m .73561 .48747 L .73302 .48811 L F
.358 0 .153 r
.41044 .62641 m .41099 .62528 L .4131 .62479 L F
.751 .673 .775 r
.42677 .60398 m .42473 .60715 L .42813 .60737 L F
.494 .249 .472 r
.42473 .60715 m .42668 .60885 L .42813 .60737 L F
.608 .585 .802 r
.42813 .60737 m .42917 .6032 L .42677 .60398 L F
.42813 .60737 m .43071 .60708 L .42917 .6032 L F
.629 .173 .152 r
.42813 .60737 m .42668 .60885 L .43009 .60903 L F
.53 .226 .395 r
.42813 .60737 m .43009 .60903 L .43071 .60708 L F
0 .142 .652 r
.58319 .59817 m .58374 .59836 L .58171 .59805 L F
.58319 .59817 m .5859 .60059 L .58374 .59836 L F
.333 .124 .439 r
.76943 .49599 m .76742 .49491 L .76993 .49454 L F
.76943 .49599 m .76741 .49691 L .76742 .49491 L F
.737 .916 .954 r
.22758 .55763 m .22544 .55883 L .2258 .55706 L F
.084 0 .44 r
.21606 .59216 m .21602 .5945 L .2145 .59532 L F
.397 .218 .518 r
.21602 .5945 m .21397 .59742 L .2145 .59532 L F
.818 .509 .467 r
.60485 .62041 m .6078 .61897 L .60473 .6181 L F
.60485 .62041 m .60862 .62149 L .6078 .61897 L F
.688 .211 0 r
.55851 .63339 m .55893 .63445 L .55723 .63244 L F
.55851 .63339 m .55992 .63541 L .55893 .63445 L F
0 .503 .795 r
.19676 .55676 m .19274 .55565 L .19446 .55643 L F
.761 .655 .744 r
.49961 .64719 m .50379 .64826 L .5019 .64449 L F
.825 .873 .88 r
.50078 .64885 m .50379 .64826 L .49961 .64719 L F
.746 .671 .777 r
.54647 .5985 m .54399 .6015 L .54753 .601 L F
.526 .452 .715 r
.54399 .6015 m .54729 .60404 L .54753 .601 L F
.857 .708 .696 r
.54729 .60404 m .54992 .6014 L .54753 .601 L F
.051 .372 .839 r
.4483 .69972 m .44884 .69872 L .44672 .69932 L F
.4483 .69972 m .45086 .70135 L .44884 .69872 L F
.408 .791 .991 r
.55587 .69642 m .55755 .69613 L .55618 .69707 L F
.55587 .69642 m .55755 .69613 L .55618 .69707 L F
.327 .767 .965 r
.38888 .59308 m .38739 .59251 L .38525 .5927 L F
.153 0 0 r
.39113 .59242 m .38739 .59251 L .38888 .59308 L F
.228 .73 .903 r
.39222 .58303 m .39444 .58289 L .39593 .58324 L F
.014 .587 .75 r
.39444 .58289 m .39806 .58308 L .39593 .58324 L F
.179 .698 .881 r
.7878 .48991 m .7906 .49005 L .78972 .48845 L F
.643 .705 .892 r
.7906 .49005 m .79223 .48764 L .78972 .48845 L F
.7906 .49005 m .79299 .48923 L .79223 .48764 L F
.495 .897 .932 r
.52923 .71928 m .52853 .71878 L .53033 .71949 L F
.52923 .71928 m .52668 .71924 L .52853 .71878 L F
.989 .72 .384 r
.57986 .64927 m .57886 .65301 L .57859 .65084 L F
.489 .012 .048 r
.36554 .59649 m .36403 .59796 L .3615 .59775 L F
.209 0 0 r
.36626 .59743 m .36554 .59649 L .36778 .59631 L F
.36626 .59743 m .36403 .59796 L .36554 .59649 L F
0 0 0 r
.50594 .67403 m .50318 .67739 L .50501 .6754 L F
.455 .501 .817 r
.50318 .67739 m .50604 .67828 L .50501 .6754 L F
.412 .598 .922 r
.54998 .64349 m .55019 .64494 L .54792 .64201 L F
.92 .589 .398 r
.55076 .64554 m .55013 .64384 L .54998 .64349 L F
.55086 .64582 m .55121 .64625 L .55013 .64384 L F
.827 .42 0 r
.54998 .64349 m .55082 .6456 L .55076 .64554 L F
.54998 .64349 m .55076 .64554 L .55019 .64494 L F
.92 .589 .398 r
.55086 .64582 m .55076 .64554 L .54998 .64349 L F
.54824 .64253 m .55086 .64582 L .54998 .64349 L F
0 0 .389 r
.55076 .64554 m .55109 .64832 L .55019 .64494 L F
.55082 .6456 m .55084 .64574 L .55076 .64554 L F
.55084 .64574 m .55109 .64832 L .55076 .64554 L F
.934 .683 .205 r
.55083 .64573 m .55218 .65014 L .55109 .64832 L F
.55089 .64583 m .55218 .65014 L .55083 .64573 L F
.55089 .64583 m .55161 .64942 L .55218 .65014 L F
.55082 .6456 m .55089 .64583 L .55083 .64573 L F
.55082 .6456 m .55089 .64593 L .55089 .64583 L F
.55089 .64593 m .55161 .64942 L .55089 .64583 L F
.989 .788 .542 r
.5505 .64801 m .55161 .64942 L .55089 .64593 L F
.92 .589 .398 r
.54824 .64253 m .55108 .64618 L .55093 .6459 L F
.989 .788 .542 r
.5505 .64801 m .55089 .64593 L .55077 .64601 L F
.5505 .64801 m .55077 .64601 L .55121 .64625 L F
.92 .589 .398 r
.55108 .64618 m .55111 .64622 L .55109 .64619 L F
.55108 .64618 m .55109 .64619 L .55093 .6459 L F
.989 .788 .542 r
.55077 .64601 m .55089 .64593 L .55082 .6456 L F
.92 .589 .398 r
.55089 .64594 m .55089 .64615 L .55111 .64622 L F
.55093 .6459 m .55111 .64622 L .55121 .64625 L F
.989 .788 .542 r
.55077 .64601 m .55082 .6456 L .55121 .64625 L F
.92 .589 .398 r
.54824 .64253 m .54867 .64544 L .55067 .64608 L F
.55078 .646 m .55067 .64608 L .55089 .64615 L F
.54824 .64253 m .55067 .64608 L .55078 .646 L F
.54824 .64253 m .55089 .64615 L .55089 .64594 L F
.321 0 0 r
.5517 .68351 m .54853 .68405 L .54989 .6831 L F
.634 .587 .784 r
.58148 .65426 m .58017 .6564 L .57886 .65301 L F
.259 .662 .966 r
.80164 .51754 m .79993 .5174 L .80052 .51667 L F
.978 .819 .617 r
.48714 .68784 m .48846 .69093 L .48686 .68965 L F
.789 .558 .588 r
.48846 .69093 m .48478 .69305 L .48686 .68965 L F
.48846 .69093 m .48844 .69366 L .48478 .69305 L F
.57 .554 .798 r
.49018 .68764 m .48846 .69093 L .48714 .68784 L F
.49018 .68764 m .49077 .69052 L .48846 .69093 L F
.581 .414 .62 r
.49077 .69052 m .48844 .69366 L .48846 .69093 L F
.665 .153 .012 r
.572 .59631 m .56821 .59532 L .56954 .59635 L F
.382 .152 .437 r
.46942 .65957 m .47126 .66106 L .47197 .65915 L F
.46942 .65957 m .46931 .66173 L .47126 .66106 L F
.661 .675 .853 r
.74173 .49993 m .73968 .50137 L .73803 .4994 L F
.713 .771 .898 r
.74173 .49993 m .74045 .50098 L .73968 .50137 L F
.627 .806 .968 r
.64218 .44215 m .63876 .44277 L .64115 .44216 L F
.592 .743 .948 r
.64024 .44056 m .63876 .44277 L .6376 .44158 L F
.64024 .44056 m .64115 .44216 L .63876 .44277 L F
.456 .677 .96 r
.41189 .58344 m .4111 .58515 L .40982 .58377 L F
.41189 .58344 m .41455 .58593 L .4111 .58515 L F
.448 .236 .499 r
.53265 .67379 m .53493 .67333 L .53526 .6706 L F
.527 .38 .625 r
.5328 .67603 m .53493 .67333 L .53265 .67379 L F
.275 0 .075 r
.32374 .5902 m .32571 .58973 L .32738 .58725 L F
0 0 0 r
.32571 .58973 m .329 .58805 L .32738 .58725 L F
.385 0 0 r
.32738 .58725 m .329 .58805 L .32982 .58713 L F
.835 .692 .155 r
.53317 .61554 m .53307 .61322 L .53463 .6133 L F
.219 .72 .907 r
.53596 .61284 m .53686 .61323 L .53463 .6133 L F
.763 .586 .657 r
.74677 .50011 m .74538 .50049 L .7434 .49729 L F
.648 .603 .79 r
.31617 .63169 m .3167 .62691 L .3158 .62728 L F
.243 .737 .913 r
.35905 .58286 m .36128 .58273 L .3627 .58309 L F
.017 .588 .767 r
.36128 .58273 m .36484 .583 L .3627 .58309 L F
.018 .301 .794 r
.54169 .6365 m .544 .63833 L .54328 .63911 L F
0 .221 .738 r
.544 .63833 m .54558 .64148 L .54328 .63911 L F
.66 .822 .961 r
.46021 .69897 m .45652 .69873 L .4588 .69856 L F
.315 .781 .939 r
.46021 .69897 m .4588 .69856 L .4624 .69867 L F
.831 .702 .721 r
.58806 .60368 m .59066 .60474 L .58978 .60726 L F
.586 .507 .732 r
.44422 .60139 m .44462 .60352 L .4424 .60423 L F
.2 .667 .94 r
.50909 .64773 m .50771 .64702 L .50559 .64687 L F
.663 .139 0 r
.51106 .64802 m .50771 .64702 L .50909 .64773 L F
.571 .739 .955 r
.78968 .47826 m .78829 .48022 L .7873 .47897 L F
.78968 .47826 m .79079 .47971 L .78829 .48022 L F
.806 .701 .748 r
.57369 .61549 m .57491 .61882 L .57151 .61804 L F
.443 0 0 r
.57151 .61804 m .57491 .61882 L .57323 .61883 L F
.334 .426 .807 r
.57369 .61549 m .5763 .61719 L .57491 .61882 L F
.64 .393 .529 r
.5763 .61719 m .57323 .61883 L .57491 .61882 L F
.144 0 0 r
.47039 .66967 m .47145 .66876 L .47376 .66837 L F
.567 .324 .507 r
.50173 .65348 m .50122 .65618 L .49859 .6564 L F
.421 .194 .461 r
.5033 .65544 m .50173 .65348 L .50362 .65269 L F
.5033 .65544 m .50122 .65618 L .50173 .65348 L F
.555 .172 .27 r
.40471 .61498 m .40753 .61484 L .40818 .61342 L F
0 0 0 r
.40753 .61484 m .41004 .61377 L .40818 .61342 L F
.575 .621 .861 r
.46362 .70546 m .46737 .7079 L .46519 .70824 L F
.382 0 .127 r
.47602 .66211 m .47791 .66308 L .47597 .6651 L F
.47602 .66211 m .47867 .66154 L .47791 .66308 L F
.62 .347 .481 r
.63824 .44969 m .63422 .45334 L .63425 .45092 L F
.63824 .44969 m .63668 .45326 L .63422 .45334 L F
.622 .304 .411 r
.6401 .45116 m .63668 .45326 L .63824 .44969 L F
.825 .872 .88 r
.55556 .61528 m .55827 .6128 L .55712 .61436 L F
.632 .495 .677 r
.76536 .49991 m .76258 .50041 L .76487 .49747 L F
.608 .535 .747 r
.76607 .50371 m .76258 .50041 L .76536 .49991 L F
.523 .831 1 r
.39701 .59214 m .39336 .59186 L .39478 .59268 L F
.354 .739 .987 r
.2075 .5456 m .20733 .5466 L .2059 .54538 L F
.2075 .5456 m .20936 .54659 L .20733 .5466 L F
.483 .306 .564 r
.49133 .73145 m .49128 .73397 L .49358 .73365 L F
.49358 .73365 m .49128 .73397 L .49133 .73145 L F
.674 .384 .473 r
.51577 .69313 m .51266 .69118 L .51565 .69079 L F
.583 .588 .823 r
.35023 .61446 m .34922 .61807 L .34855 .61598 L F
.35023 .61446 m .35138 .61772 L .34922 .61807 L F
.302 .438 .832 r
.73475 .50825 m .73521 .50582 L .73324 .5055 L F
.73475 .50825 m .73647 .50889 L .73521 .50582 L F
.333 .633 .962 r
.72559 .4981 m .72719 .49698 L .72468 .49673 L F
.72559 .4981 m .72877 .49863 L .72719 .49698 L F
.511 .484 .763 r
.7365 .49628 m .73485 .49838 L .73496 .49673 L F
.624 .744 .933 r
.74157 .48799 m .74222 .48953 L .73883 .48878 L F
.74157 .48799 m .74222 .48953 L .73883 .48878 L F
.51 0 0 r
.74157 .48799 m .74467 .4888 L .74222 .48953 L F
.313 0 .057 r
.39394 .62115 m .39617 .6207 L .39749 .61883 L F
.326 0 .045 r
.39617 .6207 m .39982 .61845 L .39749 .61883 L F
.55 .365 .584 r
.39749 .61883 m .39982 .61845 L .39982 .61592 L F
0 0 0 r
.54226 .66253 m .54094 .66258 L .54212 .6602 L F
.54226 .66253 m .54026 .66351 L .54094 .66258 L F
.417 .101 .319 r
.35696 .59859 m .35627 .60073 L .35401 .60125 L F
.483 .191 .393 r
.35915 .59805 m .35627 .60073 L .35696 .59859 L F
.205 0 0 r
.50501 .6754 m .50857 .67356 L .50594 .67403 L F
.636 .629 .826 r
.44757 .6024 m .44573 .60669 L .44462 .60352 L F
.44757 .6024 m .4489 .60642 L .44573 .60669 L F
.609 .48 .68 r
.54958 .67039 m .54727 .67341 L .54725 .67075 L F
.677 .731 .891 r
.8003 .47984 m .7967 .47904 L .79977 .4781 L F
.481 .755 .99 r
.80176 .47831 m .8003 .47984 L .79977 .4781 L F
.80176 .47831 m .80268 .47948 L .8003 .47984 L F
.882 .856 .812 r
.64355 .44154 m .64502 .44285 L .64701 .43974 L F
.98 .747 .512 r
.64355 .44154 m .64402 .4458 L .64502 .44285 L F
.298 0 .032 r
.39994 .63004 m .39852 .63195 L .39628 .63242 L F
.433 .032 .178 r
.40218 .6296 m .39852 .63195 L .39994 .63004 L F
.105 .22 .7 r
.52119 .65282 m .52205 .65727 L .52316 .6545 L F
.571 .573 .816 r
.52233 .65856 m .52316 .6545 L .52205 .65727 L F
0 0 .221 r
.55552 .67774 m .55483 .67655 L .55551 .67526 L F
.149 0 .308 r
.46426 .70289 m .46575 .70191 L .46362 .70546 L F
.21 .168 .589 r
.55798 .67967 m .55978 .67815 L .55932 .67559 L F
.223 .19 .608 r
.55798 .67967 m .55994 .68172 L .55978 .67815 L F
.556 .557 .81 r
.58171 .59805 m .57818 .59497 L .57954 .59764 L F
.57 .742 .957 r
.42645 .58977 m .42426 .59034 L .42305 .58885 L F
.673 .745 .905 r
.7867 .52727 m .78788 .52482 L .78557 .52559 L F
.7867 .52727 m .78908 .52628 L .78788 .52482 L F
.773 .418 .383 r
.58882 .58627 m .591 .58884 L .59246 .58691 L F
.854 .533 .444 r
.59246 .58691 m .591 .58884 L .59281 .5891 L F
.526 .521 .793 r
.47889 .71057 m .47905 .70747 L .4766 .70771 L F
.651 .21 .19 r
.47378 .70819 m .47548 .70977 L .4766 .70771 L F
.363 .438 .805 r
.78671 .50488 m .78522 .50736 L .78476 .50639 L F
.78671 .50488 m .78767 .50851 L .78522 .50736 L F
.29 .128 .481 r
.22378 .56957 m .22363 .57183 L .22204 .57261 L F
.258 .104 .473 r
.22363 .57183 m .22195 .57486 L .22204 .57261 L F
.658 .576 .751 r
.48846 .67773 m .48588 .67948 L .48517 .67538 L F
.604 .255 .352 r
.48818 .68133 m .48509 .68152 L .48588 .67948 L F
.6 .465 .668 r
.48846 .67773 m .48847 .67948 L .48588 .67948 L F
.568 .273 .427 r
.48847 .67948 m .48818 .68133 L .48588 .67948 L F
.379 .228 .547 r
.31221 .60127 m .31402 .59815 L .31187 .59878 L F
.51 .814 1 r
.56516 .59744 m .56357 .59724 L .5627 .59749 L F
.181 .296 .747 r
.56131 .59788 m .5627 .59749 L .5604 .59539 L F
.716 .207 .019 r
.5604 .59539 m .5627 .59749 L .55919 .59613 L F
.51 .814 1 r
.56357 .59724 m .56155 .597 L .5627 .59749 L F
.181 .296 .747 r
.56187 .59942 m .5627 .59749 L .56131 .59788 L F
.687 .888 .972 r
.56187 .59942 m .56399 .59831 L .5627 .59749 L F
.793 .309 .067 r
.74209 .49729 m .74037 .49678 L .73845 .49491 L F
.396 .793 .986 r
.7434 .49729 m .74037 .49678 L .74209 .49729 L F
.56 .595 .845 r
.33602 .63963 m .33631 .64198 L .33854 .64154 L F
.488 .49 .785 r
.81181 .50763 m .81042 .51074 L .80956 .50908 L F
.81181 .50763 m .81282 .51116 L .81042 .51074 L F
.235 0 .13 r
.51227 .66465 m .51513 .66189 L .51421 .66407 L F
.4 .855 .873 r
.51603 .66119 m .51513 .66189 L .51731 .66113 L F
0 0 0 r
.51421 .66407 m .51513 .66189 L .51603 .66119 L F
.036 0 .361 r
.20974 .60887 m .20895 .60729 L .21002 .60649 L F
.20974 .60887 m .20869 .60985 L .20895 .60729 L F
.941 .74 .603 r
.56769 .60099 m .56809 .59874 L .56633 .59773 L F
.155 0 0 r
.37402 .63863 m .3702 .64023 L .37178 .63905 L F
.39 .244 .56 r
.31098 .60355 m .31219 .60341 L .31221 .60127 L F
.58 .657 .89 r
.77225 .5053 m .76978 .50579 L .76837 .50327 L F
.519 .609 .882 r
.77364 .52294 m .7747 .52001 L .7723 .52047 L F
.77364 .52294 m .77603 .52282 L .7747 .52001 L F
.563 .271 .43 r
.39982 .61592 m .40187 .61774 L .40229 .61559 L F
.448 .285 .566 r
.39982 .61592 m .39982 .61845 L .40187 .61774 L F
.681 .464 .585 r
.44892 .61552 m .4486 .61731 L .44475 .61886 L F
.642 .396 .531 r
.45069 .61583 m .4486 .61731 L .44892 .61552 L F
0 0 .235 r
.20869 .60985 m .20811 .61186 L .20669 .61304 L F
.286 .206 .588 r
.20811 .61186 m .20668 .61558 L .20669 .61304 L F
.693 .763 .905 r
.54401 .60656 m .54729 .60404 L .54458 .605 L F
.454 .27 .541 r
.49066 .63325 m .4928 .63476 L .49306 .63265 L F
.49066 .63325 m .49062 .63562 L .4928 .63476 L F
.81 .547 .54 r
.73764 .48315 m .73417 .48473 L .73709 .48131 L F
.73764 .48315 m .7376 .48559 L .73417 .48473 L F
.253 .737 .927 r
.39806 .58308 m .4003 .58296 L .40194 .58341 L F
.453 .797 .998 r
.4003 .58296 m .40399 .58347 L .40194 .58341 L F
.422 .368 .692 r
.35453 .61812 m .35471 .62094 L .35265 .61955 L F
.585 .585 .818 r
.35351 .61694 m .35453 .61812 L .35138 .61772 L F
.422 .368 .692 r
.35453 .61812 m .35393 .61858 L .3538 .61803 L F
0 0 .374 r
.35351 .61694 m .35471 .62094 L .35453 .61812 L F
.35367 .61748 m .35476 .61975 L .35471 .62094 L F
.35351 .61694 m .35358 .6171 L .35367 .61748 L F
.35358 .6171 m .35476 .61975 L .35367 .61748 L F
.422 .368 .692 r
.3538 .61803 m .35265 .61955 L .35138 .61772 L F
.35393 .61858 m .35265 .61955 L .3538 .61803 L F
.845 .995 .754 r
.49322 .69961 m .4909 .70253 L .49089 .70164 L F
.589 .42 .62 r
.49322 .69961 m .4935 .70233 L .4909 .70253 L F
.458 .045 .167 r
.4935 .70233 m .49256 .70365 L .4909 .70253 L F
.855 .464 .301 r
.49256 .70365 m .49089 .70164 L .4909 .70253 L F
.501 .227 .43 r
.53493 .67333 m .53777 .67046 L .53526 .6706 L F
.359 0 0 r
.46824 .71809 m .46649 .71871 L .46409 .71808 L F
.987 .793 .555 r
.46716 .71689 m .46824 .71809 L .46996 .71788 L F
.46716 .71689 m .46649 .71871 L .46824 .71809 L F
.42 0 0 r
.46824 .71809 m .4701 .71894 L .46996 .71788 L F
.247 0 0 r
.36526 .64065 m .36207 .64108 L .36266 .64125 L F
.964 .635 .303 r
.58356 .64478 m .58244 .64596 L .58233 .64382 L F
.602 .84 .989 r
.58233 .64382 m .58485 .64328 L .58356 .64478 L F
.737 .526 .607 r
.58485 .64328 m .58244 .64596 L .58356 .64478 L F
.683 .798 .936 r
.79421 .48013 m .79079 .47971 L .79311 .47872 L F
.705 .806 .928 r
.7967 .47904 m .79421 .48013 L .79311 .47872 L F
.457 .491 .805 r
.57263 .62769 m .57115 .63048 L .57018 .62731 L F
.57263 .62769 m .57346 .62957 L .57115 .63048 L F
0 0 .494 r
.4601 .71409 m .46137 .71504 L .45951 .71282 L F
.4601 .71409 m .46069 .71635 L .46137 .71504 L F
.438 .239 .512 r
.54083 .68227 m .54285 .68181 L .54283 .67944 L F
.049 .156 .656 r
.54083 .68227 m .54261 .68412 L .54285 .68181 L F
.808 .629 .66 r
.61071 .63034 m .60897 .62733 L .6089 .62984 L F
.928 .66 .51 r
.60911 .63202 m .61071 .63034 L .6089 .62984 L F
.60911 .63202 m .61081 .63284 L .61071 .63034 L F
.666 .402 .511 r
.51441 .68762 m .51669 .68776 L .51678 .68539 L F
.517 .828 1 r
.48621 .66187 m .48834 .6628 L .49007 .66172 L F
.288 .282 .678 r
.49024 .66408 m .48834 .6628 L .49007 .66172 L F
.799 .691 .745 r
.58806 .60368 m .58978 .60726 L .5882 .60746 L F
.776 .547 .589 r
.5882 .60746 m .58978 .60726 L .58754 .6095 L F
.792 .574 .605 r
.58754 .6095 m .58978 .60726 L .58947 .6097 L F
.648 .605 .793 r
.47169 .67288 m .47038 .67627 L .46913 .67343 L F
.47169 .67288 m .47283 .67661 L .47038 .67627 L F
0 .361 .83 r
.21374 .54709 m .21265 .54741 L .21134 .54654 L F
.21374 .54709 m .21504 .54868 L .21265 .54741 L F
.667 .604 .775 r
.75898 .49762 m .75532 .49533 L .75805 .49466 L F
.889 .762 .715 r
.75937 .49474 m .75898 .49762 L .75805 .49466 L F
0 0 0 r
.55407 .59503 m .55571 .59409 L .55684 .59248 L F
.504 .215 .409 r
.51266 .69118 m .51199 .69332 L .50968 .69362 L F
.51266 .69118 m .51199 .69332 L .50968 .69362 L F
.674 .384 .473 r
.51577 .69313 m .51199 .69332 L .51266 .69118 L F
.664 .428 .552 r
.51199 .69332 m .51476 .6909 L .51266 .69118 L F
.611 .295 .409 r
.42229 .62108 m .41874 .62364 L .41893 .62202 L F
.446 .361 .666 r
.3113 .61004 m .31337 .61209 L .31331 .60948 L F
.3113 .61004 m .31148 .61325 L .31337 .61209 L F
.506 .193 .371 r
.52333 .69225 m .52147 .69091 L .5241 .69071 L F
.52333 .69225 m .52113 .69284 L .52147 .69091 L F
.526 .521 .793 r
.47889 .71057 m .48036 .71184 L .47905 .70747 L F
.795 .459 .419 r
.47889 .71057 m .48021 .71332 L .48036 .71184 L F
.637 .65 .847 r
.27756 .84119 m .27976 .84003 L .27819 .83757 L F
.741 .866 .938 r
.78662 .48856 m .7878 .48991 L .78972 .48845 L F
.471 .531 .837 r
.77 .52045 m .7719 .51874 L .7687 .51798 L F
.77 .52045 m .7723 .52047 L .7719 .51874 L F
.595 .389 .572 r
.53632 .65035 m .53906 .65012 L .53893 .6476 L F
.555 .436 .672 r
.53893 .6476 m .54166 .6472 L .54095 .64443 L F
.475 .265 .514 r
.53906 .65012 m .54166 .6472 L .53893 .6476 L F
0 0 0 r
.28286 .83702 m .28107 .83916 L .27976 .84003 L F
.403 .641 .953 r
.28304 .83602 m .28286 .83702 L .28157 .83608 L F
.28304 .83602 m .28571 .83813 L .28286 .83702 L F
.465 .889 .898 r
.28571 .83813 m .28107 .83916 L .28286 .83702 L F
.115 0 .106 r
.47415 .65563 m .47604 .65523 L .47692 .65294 L F
.218 0 .317 r
.47415 .65563 m .47562 .65752 L .47604 .65523 L F
.47415 .65563 m .47396 .65823 L .47562 .65752 L F
.325 0 0 r
.33565 .58463 m .33438 .58605 L .33743 .5851 L F
.311 0 0 r
.20388 .54487 m .20354 .54452 L .20196 .54374 L F
.20388 .54487 m .2059 .54538 L .20354 .54452 L F
.685 .825 .386 r
.54145 .61258 m .54045 .61297 L .54375 .61268 L F
.54145 .61258 m .54022 .61512 L .54045 .61297 L F
.4 .081 .305 r
.4673 .66255 m .46877 .66373 L .46931 .66173 L F
.4673 .66255 m .46659 .6643 L .46877 .66373 L F
.837 .688 .697 r
.58947 .6097 m .59095 .61292 L .5884 .61066 L F
.881 .476 .035 r
.59104 .61535 m .5884 .61066 L .59095 .61292 L F
.759 .776 .867 r
.31202 .62377 m .30746 .62336 L .31017 .62196 L F
.683 .221 .149 r
.31202 .62377 m .30928 .62449 L .30746 .62336 L F
0 .201 .692 r
.31017 .62196 m .31148 .62291 L .31202 .62377 L F
.753 .985 .904 r
.31148 .62291 m .30928 .62449 L .31202 .62377 L F
0 .457 .856 r
.31202 .62377 m .31348 .62422 L .31148 .62291 L F
.512 .894 .96 r
.3677 .62588 m .36867 .62484 L .37007 .62498 L F
.329 0 0 r
.36867 .62484 m .36932 .62498 L .37007 .62498 L F
.449 .882 .877 r
.37148 .62499 m .3677 .62588 L .37007 .62498 L F
.329 0 0 r
.36932 .62498 m .37219 .62559 L .37007 .62498 L F
.449 .882 .877 r
.37153 .62498 m .37148 .62499 L .37007 .62498 L F
.18 0 0 r
.37219 .62559 m .37153 .62498 L .37007 .62498 L F
.37219 .62559 m .37379 .62488 L .37153 .62498 L F
.371 0 .025 r
.49113 .70038 m .49162 .70021 L .49228 .69999 L F
.845 .995 .754 r
.49322 .69961 m .49311 .69971 L .49228 .69999 L F
0 .112 .638 r
.49447 .69922 m .49482 .70138 L .49428 .70078 L F
.49447 .69922 m .49428 .70078 L .49322 .69961 L F
.49447 .69922 m .49322 .69961 L .49228 .69999 L F
.243 .168 .568 r
.49482 .70138 m .4935 .70233 L .49322 .69961 L F
.371 0 .025 r
.49162 .70021 m .49447 .69922 L .49228 .69999 L F
.845 .995 .754 r
.49311 .69971 m .49089 .70164 L .49228 .69999 L F
.853 .997 .81 r
.49228 .69999 m .49089 .70164 L .49113 .70038 L F
.371 0 .025 r
.49113 .70038 m .49318 .70058 L .49447 .69922 L F
.918 .957 .63 r
.49447 .69922 m .49318 .70058 L .49364 .69956 L F
.49447 .69922 m .49364 .69956 L .49474 .6971 L F
.49447 .69922 m .49474 .6971 L .49478 .69702 L F
0 0 0 r
.38016 .63683 m .37841 .63762 L .37625 .63818 L F
.304 0 0 r
.38234 .6369 m .37841 .63762 L .38016 .63683 L F
.68 .388 .472 r
.54011 .7111 m .54318 .71071 L .54383 .70892 L F
.191 0 .249 r
.54383 .70892 m .54318 .71071 L .5455 .70793 L F
.611 .295 .409 r
.42229 .62108 m .42111 .6238 L .41874 .62364 L F
.418 .066 .259 r
.42449 .62087 m .42111 .6238 L .42229 .62108 L F
.452 .222 .473 r
.47692 .65294 m .47921 .65223 L .47933 .6504 L F
.193 0 .14 r
.47692 .65294 m .47789 .65447 L .47921 .65223 L F
.47692 .65294 m .47604 .65523 L .47789 .65447 L F
.747 .564 .647 r
.7434 .49729 m .73913 .49937 L .74037 .49678 L F
.7434 .49729 m .74173 .49993 L .73913 .49937 L F
.764 .586 .657 r
.7434 .49729 m .74538 .50049 L .74173 .49993 L F
.473 .572 .874 r
.72877 .49863 m .72925 .50071 L .73101 .49855 L F
.388 .447 .8 r
.72925 .50071 m .73222 .50194 L .73101 .49855 L F
.643 .13 .012 r
.5171 .63266 m .52062 .63335 L .51891 .63274 L F
.583 .945 .858 r
.40176 .59005 m .40049 .59117 L .40249 .59023 L F
.40176 .59005 m .39914 .59145 L .40049 .59117 L F
.729 .289 .205 r
.51021 .63115 m .51174 .62968 L .50982 .62983 L F
.51021 .63115 m .51359 .63179 L .51174 .62968 L F
.331 .161 .493 r
.22236 .57778 m .2223 .58017 L .22003 .58039 L F
.326 .11 .424 r
.2223 .58017 m .21961 .58307 L .22003 .58039 L F
.707 .809 .928 r
.58455 .66965 m .5828 .67056 L .58633 .67092 L F
.415 .616 .934 r
.58633 .67092 m .5884 .6708 L .58799 .66902 L F
.58765 .6691 m .58799 .66902 L .58792 .66873 L F
.58633 .67092 m .58799 .66902 L .58765 .6691 L F
.595 .75 .951 r
.58792 .66873 m .5884 .6708 L .58979 .66904 L F
.524 0 0 r
.58792 .66873 m .58979 .66904 L .58622 .66865 L F
.352 .776 .975 r
.5885 .6689 m .58879 .66843 L .58622 .66865 L F
.58956 .66902 m .5892 .66874 L .5885 .6689 L F
.5892 .66874 m .58879 .66843 L .5885 .6689 L F
.58979 .66904 m .58974 .66901 L .58956 .66902 L F
.58974 .66901 m .58879 .66843 L .58956 .66902 L F
.415 .616 .934 r
.58633 .67092 m .58765 .6691 L .58455 .66965 L F
.58765 .6691 m .58792 .66873 L .58637 .66915 L F
.58765 .6691 m .58637 .66915 L .58455 .66965 L F
.67 .496 .642 r
.52191 .67178 m .52007 .67047 L .52267 .67069 L F
.52007 .67047 m .52008 .67045 L .52267 .67069 L F
.52007 .67047 m .51861 .6698 L .52003 .67045 L F
.52191 .67178 m .52033 .67083 L .52007 .67047 L F
.52033 .67083 m .51861 .6698 L .52007 .67047 L F
.52191 .67178 m .51893 .67274 L .51861 .6698 L F
0 0 0 r
.51952 .67199 m .52012 .67213 L .52065 .67126 L F
.52038 .6709 m .52065 .67126 L .52254 .66814 L F
.51952 .67199 m .52065 .67126 L .52038 .6709 L F
.51893 .67274 m .51933 .67254 L .51952 .67199 L F
.51933 .67254 m .52012 .67213 L .51952 .67199 L F
.67 .496 .642 r
.52007 .67047 m .52003 .67045 L .52008 .67045 L F
.799 .614 .652 r
.54958 .67039 m .55333 .67361 L .55218 .66995 L F
.54958 .67039 m .54998 .67343 L .55333 .67361 L F
.776 .54 .578 r
.54944 .67484 m .55333 .67361 L .54998 .67343 L F
.54944 .67484 m .55082 .67792 L .55333 .67361 L F
.151 .167 .622 r
.55333 .67361 m .55435 .66931 L .55218 .66995 L F
.55333 .67361 m .55519 .67227 L .55435 .66931 L F
.466 .176 .388 r
.55333 .67361 m .55551 .67526 L .55519 .67227 L F
.55333 .67361 m .55082 .67792 L .55551 .67526 L F
.776 .54 .578 r
.54944 .67484 m .55082 .67792 L .55333 .67361 L F
.614 .517 .72 r
.79629 .50351 m .79699 .50638 L .79803 .50505 L F
.971 .716 .49 r
.53885 .71454 m .53713 .71574 L .53736 .71338 L F
.649 .826 .968 r
.53885 .71454 m .54058 .71341 L .53736 .71338 L F
.588 .63 .86 r
.49426 .66643 m .4925 .66827 L .49146 .66591 L F
.49426 .66643 m .49517 .66803 L .4925 .66827 L F
.591 .488 .705 r
.49517 .66803 m .49285 .67075 L .4925 .66827 L F
.654 .82 .963 r
.48084 .68696 m .48174 .68455 L .48055 .68438 L F
.48084 .68696 m .48394 .68545 L .48174 .68455 L F
.578 .528 .762 r
.54283 .67944 m .54523 .67941 L .54495 .67662 L F
.426 .23 .51 r
.54283 .67944 m .54499 .68114 L .54523 .67941 L F
.54283 .67944 m .54285 .68181 L .54499 .68114 L F
.563 .046 0 r
.41004 .61377 m .41244 .61438 L .41413 .61333 L F
.433 0 0 r
.41244 .61438 m .41661 .61311 L .41413 .61333 L F
.329 .064 .352 r
.47933 .6504 m .48128 .64981 L .48183 .64759 L F
.482 .299 .556 r
.48383 .64444 m .48183 .64759 L .48397 .64685 L F
.245 0 .237 r
.48128 .64981 m .48397 .64685 L .48183 .64759 L F
.532 .382 .623 r
.31724 .63895 m .31984 .63627 L .31984 .63695 L F
.397 .538 .88 r
.42305 .58885 m .42132 .58889 L .41955 .58603 L F
.714 .434 .499 r
.51489 .65915 m .51672 .65881 L .51389 .65617 L F
.629 .451 .623 r
.51389 .65617 m .51672 .65881 L .51637 .65604 L F
.741 .807 .905 r
.31209 .61815 m .31598 .61827 L .31435 .61538 L F
.575 .597 .837 r
.31598 .61827 m .31661 .61458 L .31435 .61538 L F
.31598 .61827 m .31822 .61792 L .31661 .61458 L F
.651 .648 .834 r
.57783 .61081 m .57922 .60584 L .57849 .60526 L F
.307 0 0 r
.57922 .60584 m .57799 .60503 L .57849 .60526 L F
.57922 .60584 m .58067 .60426 L .57799 .60503 L F
0 .12 .668 r
.58141 .60418 m .5831 .60692 L .58067 .60426 L F
.162 0 0 r
.5831 .60692 m .58166 .60664 L .58067 .60426 L F
0 .12 .668 r
.58141 .60418 m .58067 .60426 L .57922 .60584 L F
.68 .308 .334 r
.47414 .6936 m .47288 .69555 L .47066 .69347 L F
.657 .558 .731 r
.4766 .69329 m .47414 .6936 L .4733 .69082 L F
.516 .126 .239 r
.4766 .69329 m .47288 .69555 L .47414 .6936 L F
.379 .305 .647 r
.44564 .69067 m .44724 .68698 L .44506 .68825 L F
.328 .555 .917 r
.22477 .55318 m .22449 .55492 L .22229 .5525 L F
0 .003 .567 r
.22477 .55318 m .2258 .55706 L .22449 .55492 L F
.438 .855 .956 r
.7569 .49425 m .75532 .49533 L .75424 .49413 L F
.7569 .49425 m .75805 .49466 L .75532 .49533 L F
.76 .888 .936 r
.58089 .62363 m .58324 .62372 L .58352 .62389 L F
.94 .594 .34 r
.58352 .62389 m .58188 .62446 L .58089 .62363 L F
.545 .649 .903 r
.74878 .51936 m .75029 .51679 L .74728 .51746 L F
.74878 .51936 m .75103 .51927 L .75029 .51679 L F
.642 .396 .531 r
.45069 .61583 m .4506 .61815 L .4486 .61731 L F
.668 .532 .689 r
.45307 .61275 m .45398 .61578 L .45069 .61583 L F
.697 .442 .534 r
.45431 .61754 m .45069 .61583 L .45398 .61578 L F
.45431 .61754 m .4506 .61815 L .45069 .61583 L F
.483 .561 .859 r
.45499 .70847 m .45658 .71175 L .45846 .70989 L F
.434 .48 .808 r
.45658 .71175 m .45951 .71282 L .45846 .70989 L F
.38 .617 .944 r
.45086 .70135 m .45147 .70254 L .45272 .70137 L F
.245 .388 .809 r
.45147 .70254 m .45417 .70462 L .45272 .70137 L F
.498 .406 .682 r
.45205 .705 m .45417 .70462 L .45147 .70254 L F
.685 .597 .751 r
.4209 .60408 m .42205 .60744 L .42473 .60715 L F
.64 .379 .507 r
.42205 .60744 m .4244 .60935 L .42473 .60715 L F
.49 .405 .687 r
.42205 .60744 m .42246 .61014 L .4244 .60935 L F
.64 .379 .507 r
.42205 .60744 m .4244 .60935 L .42473 .60715 L F
.513 .374 .629 r
.76741 .49691 m .76536 .49991 L .76487 .49747 L F
.883 .885 .83 r
.59578 .67358 m .59687 .66967 L .59495 .67093 L F
.59578 .67358 m .59805 .67065 L .59687 .66967 L F
.889 .762 .715 r
.75937 .49474 m .75805 .49466 L .7603 .49348 L F
.791 .745 .811 r
.48874 .63874 m .48781 .63985 L .48743 .64053 L F
.48874 .63874 m .48582 .64136 L .48781 .63985 L F
.578 .594 .833 r
.48397 .64685 m .48587 .64557 L .48383 .64444 L F
.599 .094 .025 r
.54911 .62431 m .54815 .62555 L .54541 .624 L F
.829 .386 .18 r
.54911 .62431 m .55096 .62695 L .54815 .62555 L F
.817 .397 .246 r
.55286 .62712 m .55096 .62695 L .54911 .62431 L F
.259 0 0 r
.37715 .59443 m .37581 .59528 L .37338 .59552 L F
.313 0 0 r
.37922 .59443 m .37581 .59528 L .37715 .59443 L F
.683 .854 .964 r
.79565 .52144 m .79671 .52259 L .80002 .52098 L F
.464 .152 .35 r
.35401 .60125 m .35112 .6037 L .352 .60174 L F
.487 .139 .302 r
.49492 .67092 m .49243 .67286 L .49285 .67075 L F
.592 .489 .706 r
.49517 .66803 m .49492 .67092 L .49285 .67075 L F
.383 0 .163 r
.52974 .68806 m .52895 .68999 L .52641 .69047 L F
.127 0 .058 r
.53075 .6892 m .52895 .68999 L .52974 .68806 L F
.754 .961 .936 r
.60598 .66653 m .60486 .66609 L .60301 .66749 L F
.75 .96 .938 r
.60769 .6643 m .60598 .66653 L .60849 .66449 L F
.60769 .6643 m .60486 .66609 L .60598 .66653 L F
.085 0 0 r
.58531 .62723 m .58251 .62987 L .58457 .62749 L F
.58531 .62723 m .58451 .62893 L .58251 .62987 L F
.792 .65 .704 r
.58693 .62596 m .58451 .62893 L .58531 .62723 L F
.557 .308 .494 r
.47933 .6504 m .48166 .65078 L .48128 .64981 L F
.47933 .6504 m .47921 .65223 L .48166 .65078 L F
.825 .359 0 r
.55161 .64942 m .55409 .65247 L .55218 .65014 L F
.811 .998 .846 r
.54203 .60046 m .54269 .6008 L .542 .60049 L F
.345 0 0 r
.5433 .60113 m .54269 .6008 L .5401 .59939 L F
.53 .385 .628 r
.5401 .59939 m .54269 .6008 L .54354 .59821 L F
.811 .998 .846 r
.54294 .59938 m .54269 .6008 L .54203 .60046 L F
.345 0 0 r
.54399 .6015 m .54269 .6008 L .5433 .60113 L F
.762 .844 .913 r
.54354 .59821 m .54443 .59828 L .54647 .5985 L F
.805 .438 .362 r
.54443 .59828 m .54504 .60019 L .54647 .5985 L F
.873 .477 .28 r
.54294 .59938 m .54354 .59821 L .54269 .6008 L F
.54294 .59938 m .54504 .60019 L .54443 .59828 L F
.595 .451 .655 r
.54552 .59958 m .54504 .60019 L .54294 .59938 L F
.557 .824 .465 r
.54647 .5985 m .54504 .60019 L .54459 .60077 L F
.595 .451 .655 r
.54637 .59965 m .54504 .60019 L .54552 .59958 L F
.557 .824 .465 r
.54459 .60077 m .54504 .60019 L .54399 .6015 L F
.532 .852 .997 r
.54399 .6015 m .54504 .60019 L .54269 .6008 L F
.526 .452 .715 r
.54399 .6015 m .54458 .605 L .54729 .60404 L F
.415 .518 .855 r
.73647 .50889 m .73801 .5118 L .73945 .50993 L F
.423 .53 .861 r
.73801 .5118 m .74021 .51187 L .73945 .50993 L F
.881 .493 .031 r
.55638 .65796 m .55801 .66132 L .55699 .65896 L F
.648 .603 .79 r
.31617 .63169 m .31884 .63089 L .3167 .62691 L F
.604 .451 .647 r
.31617 .63169 m .31485 .63589 L .31884 .63089 L F
.224 .204 .625 r
.48852 .6366 m .49039 .6379 L .49062 .63562 L F
.48852 .6366 m .48874 .63874 L .49039 .6379 L F
.894 .946 .835 r
.49789 .69381 m .49475 .69578 L .4967 .69329 L F
.233 .715 .932 r
.2258 .55706 m .22954 .55755 L .22758 .55763 L F
.716 .557 .672 r
.4209 .60408 m .42423 .60446 L .4234 .60129 L F
.668 .527 .684 r
.4234 .60129 m .42677 .60398 L .42579 .60082 L F
.4234 .60129 m .42423 .60446 L .42677 .60398 L F
.35 .731 .986 r
.37532 .58176 m .37454 .58273 L .37302 .58171 L F
.37532 .58176 m .37676 .58272 L .37454 .58273 L F
0 0 .417 r
.55801 .66132 m .55865 .66367 L .55819 .66454 L F
0 .075 .634 r
.55865 .66367 m .55991 .66688 L .55819 .66454 L F
.084 0 0 r
.49115 .65401 m .49148 .65392 L .48921 .65397 L F
.224 .424 .848 r
.74574 .5171 m .74651 .51567 L .74378 .51484 L F
.74574 .5171 m .74728 .51746 L .74651 .51567 L F
.448 .244 .509 r
.31402 .59815 m .31617 .59506 L .31413 .59562 L F
.195 .725 .816 r
.37379 .62488 m .37597 .62457 L .37746 .62457 L F
.032 0 0 r
.37746 .62457 m .37799 .62463 L .37971 .62438 L F
.37746 .62457 m .37597 .62457 L .37799 .62463 L F
.029 0 0 r
.37114 .59546 m .37045 .596 L .36778 .59631 L F
.136 0 0 r
.37338 .59552 m .37045 .596 L .37114 .59546 L F
.129 .257 .728 r
.73324 .5055 m .73222 .50194 L .7332 .5032 L F
.56 .595 .845 r
.33602 .63963 m .33878 .63887 L .33659 .63815 L F
.33602 .63963 m .33854 .64154 L .33878 .63887 L F
.687 .62 .776 r
.33743 .63564 m .33878 .63887 L .34105 .63858 L F
.838 .835 .843 r
.33854 .64154 m .34105 .63858 L .33878 .63887 L F
.192 0 0 r
.77635 .48697 m .77436 .48648 L .77369 .48769 L F
.77635 .48697 m .77737 .48615 L .77436 .48648 L F
.503 .425 .701 r
.31202 .61576 m .31337 .61209 L .31148 .61325 L F
.589 .374 .557 r
.6428 .44832 m .64275 .45091 L .6401 .45116 L F
.59 .375 .557 r
.64593 .44958 m .6428 .44832 L .64529 .44764 L F
.64593 .44958 m .64275 .45091 L .6428 .44832 L F
0 0 0 r
.76686 .49154 m .7652 .49331 L .76598 .49298 L F
.287 .772 .915 r
.76598 .49298 m .7652 .49331 L .76279 .49295 L F
.633 .213 .229 r
.44244 .6184 m .44099 .62024 L .43872 .61851 L F
.491 .024 .072 r
.44475 .61886 m .44099 .62024 L .44244 .6184 L F
.489 .243 .468 r
.44939 .67941 m .45181 .67893 L .45199 .67671 L F
.452 .241 .501 r
.45199 .67671 m .4544 .67613 L .45442 .67353 L F
.379 .153 .441 r
.45199 .67671 m .45379 .67814 L .4544 .67613 L F
.45199 .67671 m .45181 .67893 L .45379 .67814 L F
0 0 .204 r
.51936 .64334 m .5174 .64389 L .51969 .64415 L F
.51778 .64269 m .5174 .64389 L .51936 .64334 L F
.51835 .64093 m .51778 .64269 L .51936 .64334 L F
.951 .725 .561 r
.51969 .64415 m .5181 .6434 L .51835 .64093 L F
.572 .009 0 r
.52244 .6444 m .5181 .6434 L .51969 .64415 L F
.52126 .64413 m .5205 .64487 L .5181 .6434 L F
.52244 .6444 m .52211 .64448 L .52126 .64413 L F
.52211 .64448 m .5205 .64487 L .52126 .64413 L F
.782 .477 .472 r
.5205 .64487 m .51855 .64353 L .5181 .6434 L F
0 0 .204 r
.51835 .64093 m .5181 .6434 L .51761 .64325 L F
.997 .787 .494 r
.51835 .64093 m .51704 .6425 L .5181 .6434 L F
.51835 .64093 m .51704 .6425 L .5181 .6434 L F
.782 .477 .472 r
.51855 .64353 m .51704 .6425 L .5181 .6434 L F
0 0 .204 r
.51761 .64325 m .5181 .6434 L .5174 .64389 L F
.92 .789 .701 r
.5181 .6434 m .51819 .64623 L .5174 .64389 L F
.049 0 0 r
.57907 .58867 m .58154 .5881 L .58282 .58718 L F
.382 0 0 r
.58378 .58835 m .58282 .58718 L .58154 .5881 L F
.58378 .58835 m .58535 .58717 L .58282 .58718 L F
.906 .707 .624 r
.61041 .63541 m .6122 .6359 L .61081 .63284 L F
.886 .54 .385 r
.61041 .63541 m .61093 .63755 L .6122 .6359 L F
.965 .689 .46 r
.61093 .63755 m .61262 .63849 L .6122 .6359 L F
.407 .181 .456 r
.45442 .67353 m .45656 .67312 L .45691 .67066 L F
.289 .116 .465 r
.45442 .67353 m .45598 .67522 L .45656 .67312 L F
.45442 .67353 m .4544 .67613 L .45598 .67522 L F
.49 .643 .924 r
.25741 .84664 m .25976 .84671 L .25753 .8468 L F
.398 0 .118 r
.25739 .84699 m .25976 .84671 L .25753 .8468 L F
.598 .41 .598 r
.47283 .67661 m .47572 .67654 L .47574 .67343 L F
.491 .427 .712 r
.47572 .67654 m .47662 .67307 L .47574 .67343 L F
.9 .706 .63 r
.59104 .61535 m .59247 .61862 L .59006 .61835 L F
.877 .76 .73 r
.59006 .61835 m .59247 .61862 L .59095 .62149 L F
.302 .034 .33 r
.53307 .61322 m .53261 .61574 L .53283 .61562 L F
.835 .692 .155 r
.53317 .61554 m .53284 .61557 L .53307 .61322 L F
.302 .034 .33 r
.53307 .61322 m .53283 .61562 L .53479 .61454 L F
.835 .692 .155 r
.53284 .61557 m .53283 .61557 L .53307 .61322 L F
0 0 .28 r
.53317 .61554 m .53373 .61683 L .53283 .61557 L F
.53317 .61554 m .5344 .61848 L .53373 .61683 L F
.705 .482 .583 r
.51163 .67577 m .50857 .67356 L .51064 .67284 L F
.51163 .67577 m .50827 .67607 L .50857 .67356 L F
.85 .66 .644 r
.50731 .67509 m .51064 .67284 L .50857 .67356 L F
0 0 .364 r
.56285 .67843 m .56298 .68158 L .56339 .67921 L F
.972 .771 .573 r
.60897 .62733 m .60784 .62348 L .60665 .62651 L F
.929 .668 .52 r
.60667 .62869 m .60897 .62733 L .60665 .62651 L F
.60667 .62869 m .6089 .62984 L .60897 .62733 L F
.465 .889 .898 r
.28571 .83813 m .28282 .8384 L .28107 .83916 L F
.208 .549 .931 r
.28304 .83602 m .28628 .83715 L .28571 .83813 L F
.56 .93 .921 r
.28571 .83813 m .28628 .83715 L .28282 .8384 L F
0 .119 .671 r
.80513 .48757 m .80521 .48863 L .80354 .48557 L F
0 .23 .749 r
.80722 .49031 m .80521 .48863 L .80513 .48757 L F
.706 .223 0 r
.80739 .49132 m .80521 .48863 L .80722 .49031 L F
.66 .208 0 r
.46735 .69039 m .46689 .69005 L .46632 .6891 L F
.672 .667 .837 r
.46909 .69177 m .46735 .69039 L .46959 .69205 L F
.46909 .69177 m .46689 .69005 L .46735 .69039 L F
.578 .672 .904 r
.78139 .52374 m .78312 .5261 L .78557 .52559 L F
.468 .537 .845 r
.20062 .56119 m .20255 .56023 L .20002 .55791 L F
0 0 .323 r
.20062 .56119 m .20128 .56209 L .20255 .56023 L F
.20062 .56119 m .20108 .56384 L .20128 .56209 L F
.79 .343 .184 r
.55286 .62712 m .55165 .62853 L .55096 .62695 L F
.733 .267 .141 r
.55286 .62712 m .55497 .62923 L .55165 .62853 L F
.577 .617 .855 r
.45307 .61275 m .44937 .61009 L .45169 .60936 L F
.455 .504 .82 r
.45518 .61256 m .45307 .61275 L .45169 .60936 L F
.666 .637 .811 r
.45518 .61256 m .45398 .61578 L .45307 .61275 L F
.324 .204 .558 r
.21397 .59742 m .21216 .60108 L .212 .59879 L F
.307 .375 .77 r
.21742 .58709 m .21547 .58768 L .2173 .58606 L F
.21742 .58709 m .21694 .58974 L .21547 .58768 L F
0 0 .387 r
.24354 .78305 m .24361 .7832 L .24362 .78326 L F
.824 1 .805 r
.24362 .78326 m .24361 .7832 L .24352 .7833 L F
.094 .622 .872 r
.5171 .63266 m .51914 .63285 L .52062 .63335 L F
.335 0 0 r
.51914 .63285 m .52268 .63376 L .52062 .63335 L F
.739 .287 0 r
.55723 .63244 m .55497 .62923 L .55633 .63011 L F
.373 .388 .747 r
.44564 .69067 m .44643 .69419 L .44818 .69259 L F
.36 .349 .711 r
.44643 .69419 m .44846 .69608 L .44818 .69259 L F
.44643 .69419 m .44715 .69666 L .44846 .69608 L F
.845 .655 .646 r
.60155 .60952 m .60347 .61017 L .60191 .6069 L F
.873 .672 .627 r
.60155 .60952 m .6032 .61269 L .60347 .61017 L F
.534 .37 .605 r
.53632 .65035 m .539 .65256 L .53906 .65012 L F
.53632 .65035 m .53652 .65325 L .539 .65256 L F
.905 .679 .586 r
.80552 .49364 m .80739 .49132 L .80722 .49031 L F
.80552 .49364 m .80755 .494 L .80739 .49132 L F
.226 .451 .868 r
.22074 .55085 m .22024 .55246 L .21865 .5499 L F
.418 .666 .964 r
.22074 .55085 m .22229 .5525 L .22024 .55246 L F
.959 .781 .619 r
.59199 .63226 m .59377 .63337 L .59297 .6356 L F
.63 .263 .33 r
.23838 .76007 m .23871 .76007 L .23849 .7599 L F
.499 .606 .891 r
.43098 .58869 m .43067 .59165 L .42886 .58956 L F
.43098 .58869 m .43253 .59153 L .43067 .59165 L F
.857 .708 .696 r
.54729 .60404 m .54882 .60412 L .54992 .6014 L F
.532 .56 .83 r
.75254 .49353 m .74865 .49111 L .75117 .49271 L F
.857 .489 .354 r
.74833 .48993 m .75117 .49271 L .74865 .49111 L F
.437 .568 .888 r
.53981 .66557 m .54306 .66752 L .54248 .66502 L F
0 0 0 r
.21202 .60325 m .21002 .60649 L .21095 .60445 L F
.903 .792 .728 r
.60112 .60373 m .60191 .6069 L .60287 .60488 L F
.293 .65 .969 r
.46475 .69839 m .46662 .69846 L .4665 .69972 L F
.267 .282 .69 r
.46662 .69846 m .46575 .70191 L .4665 .69972 L F
.799 .691 .745 r
.58806 .60368 m .5882 .60746 L .58655 .6042 L F
.249 0 .003 r
.58533 .60606 m .58806 .60368 L .58655 .6042 L F
.574 .169 .237 r
.45883 .69318 m .45996 .69545 L .45742 .69548 L F
0 0 .547 r
.47326 .67539 m .47268 .67612 L .47169 .67288 L F
.47326 .67539 m .47169 .67288 L .4738 .67262 L F
.516 .557 .835 r
.4738 .67262 m .47169 .67288 L .47039 .66967 L F
.846 .597 .562 r
.47326 .67539 m .47367 .67328 L .47159 .67259 L F
.47326 .67539 m .47159 .67259 L .47165 .67313 L F
.47367 .67328 m .4738 .67262 L .47115 .67244 L F
.835 .48 .383 r
.47115 .67244 m .47155 .67234 L .47159 .67259 L F
.516 .557 .835 r
.4715 .6723 m .47039 .66967 L .47115 .67244 L F
.4738 .67262 m .47166 .67077 L .47158 .67247 L F
.47166 .67077 m .47127 .67043 L .47155 .67232 L F
.47166 .67077 m .47155 .67232 L .47158 .67247 L F
0 0 .023 r
.4719 .67098 m .47155 .67232 L .472 .66914 L F
.47155 .67232 m .47155 .67234 L .47156 .67228 L F
.47155 .67232 m .47156 .67228 L .472 .66914 L F
0 0 .267 r
.47159 .67259 m .47155 .67234 L .47156 .6723 L F
.516 .557 .835 r
.47127 .67043 m .47039 .66967 L .47158 .67247 L F
.927 .857 .753 r
.472 .66914 m .47156 .67228 L .47115 .67244 L F
.47156 .67228 m .47155 .67234 L .47115 .67244 L F
.516 .557 .835 r
.47158 .67247 m .4715 .6723 L .47115 .67244 L F
.846 .597 .562 r
.47326 .67539 m .47115 .67244 L .47006 .67459 L F
0 0 .267 r
.47198 .67486 m .47164 .67286 L .4719 .67098 L F
.47164 .67286 m .47159 .67259 L .47159 .67257 L F
.47164 .67286 m .47159 .67257 L .4719 .67098 L F
.47159 .67259 m .47156 .6723 L .4719 .67098 L F
.846 .597 .562 r
.47165 .67313 m .47159 .67259 L .47115 .67244 L F
.835 .48 .383 r
.47115 .67244 m .47159 .67259 L .47198 .67486 L F
.257 .686 .964 r
.47368 .67486 m .47326 .67539 L .47198 .67486 L F
.47488 .67485 m .47326 .67539 L .47368 .67486 L F
0 0 .547 r
.47326 .67539 m .47283 .67661 L .47268 .67612 L F
.536 .184 .317 r
.47283 .67661 m .47483 .6781 L .47572 .67654 L F
0 .229 .748 r
.47326 .67539 m .47483 .6781 L .47283 .67661 L F
.564 .417 .64 r
.48036 .71184 m .48269 .70798 L .47905 .70747 L F
.211 0 .313 r
.48036 .71184 m .48021 .71332 L .48221 .71175 L F
.788 .43 .378 r
.24343 .78318 m .24361 .7832 L .24354 .78305 L F
.495 .583 .872 r
.74021 .51187 m .74148 .51471 L .74329 .51277 L F
.471 .545 .85 r
.74148 .51471 m .74378 .51484 L .74329 .51277 L F
.474 .267 .518 r
.48278 .72749 m .48061 .72805 L .48096 .72552 L F
.48278 .72749 m .48061 .72805 L .48096 .72552 L F
.379 .069 .308 r
.34919 .60475 m .3486 .60664 L .34635 .60703 L F
.465 .147 .342 r
.3508 .60598 m .3486 .60664 L .34919 .60475 L F
.386 .171 .461 r
.35112 .6037 m .3508 .60598 L .34919 .60475 L F
.588 .075 0 r
.52268 .63376 m .52516 .63497 L .52658 .634 L F
.431 0 0 r
.52658 .634 m .52516 .63497 L .52904 .63491 L F
.727 .638 .759 r
.54314 .6727 m .54673 .6741 L .54528 .66922 L F
.73 .52 .607 r
.54727 .67341 m .54495 .67662 L .54783 .67538 L F
.605 .83 .442 r
.54661 .67426 m .54495 .67662 L .54647 .67452 L F
.54679 .67403 m .54647 .67452 L .54727 .67341 L F
.54661 .67426 m .54647 .67452 L .54679 .67403 L F
.144 .281 .746 r
.54528 .66922 m .54698 .67375 L .54771 .67165 L F
.475 .252 .496 r
.54783 .67538 m .54998 .67343 L .54727 .67341 L F
.54783 .67538 m .54944 .67484 L .54998 .67343 L F
.687 .218 .131 r
.54944 .67484 m .54778 .6749 L .54727 .67341 L F
.54778 .6749 m .54608 .67496 L .54679 .67403 L F
.54778 .6749 m .54679 .67403 L .54727 .67341 L F
.144 .281 .746 r
.54698 .67375 m .54718 .67427 L .54742 .6731 L F
.54698 .67375 m .54742 .6731 L .54771 .67165 L F
.727 .638 .759 r
.54673 .6741 m .54718 .67427 L .54698 .67375 L F
.54673 .6741 m .54698 .67375 L .54528 .66922 L F
.605 .83 .442 r
.54608 .67496 m .54516 .67631 L .54661 .67426 L F
.54516 .67631 m .54495 .67662 L .54661 .67426 L F
.609 .48 .68 r
.54958 .67039 m .54998 .67343 L .54727 .67341 L F
.687 .218 .131 r
.54944 .67484 m .54727 .67341 L .54998 .67343 L F
.609 .48 .68 r
.54727 .67341 m .54998 .67343 L .54958 .67039 L F
.379 .228 .547 r
.31221 .60127 m .31391 .60071 L .31402 .59815 L F
.41 .308 .628 r
.31221 .60127 m .31421 .60315 L .31391 .60071 L F
.474 .311 .579 r
.31219 .60341 m .31421 .60315 L .31221 .60127 L F
0 0 0 r
.55249 .59882 m .55275 .59871 L .55059 .5982 L F
.196 0 .099 r
.42246 .61014 m .42182 .61146 L .4244 .60935 L F
.455 .026 .133 r
.25734 .84673 m .25976 .84671 L .25741 .84664 L F
.531 .337 .563 r
.72344 .48835 m .72605 .48819 L .72702 .4893 L F
.662 .845 .97 r
.72948 .48831 m .72702 .4893 L .72605 .48819 L F
.503 .494 .779 r
.35023 .61446 m .34855 .61598 L .34738 .61288 L F
.559 .627 .876 r
.7661 .51834 m .76791 .516 L .76537 .51656 L F
.7661 .51834 m .7687 .51798 L .76791 .516 L F
.427 .871 .866 r
.37107 .58147 m .36699 .58248 L .36911 .58167 L F
.444 0 0 r
.36911 .58167 m .37302 .58171 L .37107 .58147 L F
.508 .122 .244 r
.49859 .6564 m .50044 .65769 L .4977 .65808 L F
.497 .131 .275 r
.50122 .65618 m .50044 .65769 L .49859 .6564 L F
.685 .597 .751 r
.4209 .60408 m .42473 .60715 L .42423 .60446 L F
.676 .57 .728 r
.42423 .60446 m .42473 .60715 L .42677 .60398 L F
.494 .249 .472 r
.42473 .60715 m .4244 .60935 L .42668 .60885 L F
.474 .066 .186 r
.43505 .62026 m .43297 .61913 L .4364 .61848 L F
.43505 .62026 m .43256 .62064 L .43297 .61913 L F
0 0 0 r
.54633 .68466 m .54333 .68671 L .54442 .68563 L F
.603 .068 0 r
.20039 .55744 m .19843 .5576 L .19676 .55676 L F
.604 .083 0 r
.20002 .55791 m .19843 .5576 L .20039 .55744 L F
.989 .836 .601 r
.47111 .72243 m .46996 .72251 L .4701 .71894 L F
.88 .445 .13 r
.47127 .72473 m .46926 .7237 L .47147 .72421 L F
.682 .979 .853 r
.47174 .72413 m .47146 .72424 L .47127 .72473 L F
.635 .125 0 r
.47111 .72243 m .47226 .72406 L .46996 .72251 L F
.47226 .72406 m .47254 .72446 L .47206 .72409 L F
.47226 .72406 m .47206 .72409 L .46996 .72251 L F
.72 .286 .217 r
.47302 .72593 m .47405 .72569 L .47498 .72505 L F
.732 .723 .842 r
.47127 .72473 m .47373 .72549 L .47279 .72459 L F
.47127 .72473 m .47279 .72459 L .47254 .72446 L F
.635 .125 0 r
.47111 .72243 m .4733 .72486 L .47293 .72466 L F
.47232 .72414 m .47316 .72494 L .47254 .72446 L F
.47111 .72243 m .47316 .72494 L .47232 .72414 L F
0 .136 .677 r
.47498 .72505 m .4739 .72553 L .47391 .72553 L F
.793 .394 .296 r
.47498 .72505 m .47405 .72569 L .4739 .72553 L F
.47498 .72505 m .4739 .72553 L .47111 .72243 L F
0 .136 .677 r
.47498 .72505 m .47373 .72549 L .4739 .72553 L F
.732 .723 .842 r
.47279 .72459 m .47557 .72432 L .47254 .72446 L F
.635 .125 0 r
.47293 .72466 m .4739 .72553 L .47316 .72494 L F
.4733 .72486 m .4739 .72553 L .47293 .72466 L F
.893 .905 .827 r
.47254 .72446 m .4733 .72508 L .47302 .72593 L F
0 .136 .677 r
.47391 .72553 m .47383 .72551 L .47302 .72593 L F
.893 .905 .827 r
.4733 .72508 m .47383 .72551 L .47302 .72593 L F
0 .136 .677 r
.47383 .72551 m .47373 .72549 L .47302 .72593 L F
.893 .905 .827 r
.47383 .72551 m .47405 .72569 L .47302 .72593 L F
.732 .723 .842 r
.47322 .72533 m .47302 .72593 L .47373 .72549 L F
.47127 .72473 m .47302 .72593 L .47322 .72533 L F
.635 .125 0 r
.4739 .72553 m .47383 .72551 L .47254 .72446 L F
.732 .723 .842 r
.47279 .72459 m .47373 .72549 L .47557 .72432 L F
.635 .125 0 r
.4739 .72553 m .47405 .72569 L .47383 .72551 L F
0 .136 .677 r
.47498 .72505 m .47557 .72432 L .47373 .72549 L F
.649 .111 0 r
.46996 .72251 m .47254 .72446 L .46947 .72334 L F
.793 .513 .514 r
.47198 .72141 m .47254 .72446 L .47557 .72432 L F
0 0 .347 r
.47287 .72271 m .47254 .72446 L .47198 .72141 L F
.682 .979 .853 r
.47287 .72271 m .47172 .72416 L .47254 .72446 L F
.47172 .72416 m .47127 .72473 L .47254 .72446 L F
.649 .111 0 r
.46947 .72334 m .47254 .72446 L .46926 .7237 L F
.88 .445 .13 r
.47127 .72473 m .47147 .72421 L .47254 .72446 L F
.47127 .72473 m .47003 .7248 L .46926 .7237 L F
.682 .979 .853 r
.47146 .72424 m .47003 .7248 L .47127 .72473 L F
.47287 .72271 m .47078 .72425 L .47174 .72413 L F
.47078 .72425 m .47003 .7248 L .47174 .72413 L F
.689 .179 .019 r
.5745 .64165 m .57683 .64287 L .57674 .64245 L F
.45 0 .022 r
.57683 .64287 m .58 .64214 L .57674 .64245 L F
.884 .8 .761 r
.80552 .49364 m .80635 .4982 L .80755 .494 L F
.157 0 0 r
.57734 .63566 m .5775 .63579 L .5754 .63566 L F
.524 .914 .79 r
.4967 .69329 m .49772 .69233 L .49913 .69189 L F
.249 0 0 r
.49913 .69189 m .49772 .69233 L .49813 .6923 L F
1 .811 .502 r
.50011 .69148 m .49996 .69369 L .49913 .69189 L F
.783 .686 .757 r
.49996 .69369 m .50263 .69054 L .50015 .69079 L F
.752 .812 .9 r
.49996 .69369 m .4967 .69329 L .49913 .69189 L F
.411 .614 .933 r
.50129 .69206 m .49996 .69369 L .49913 .69189 L F
.249 0 0 r
.49913 .69189 m .49813 .6923 L .50129 .69206 L F
1 .811 .502 r
.50015 .69079 m .50011 .69148 L .49913 .69189 L F
.687 .62 .776 r
.33743 .63564 m .34105 .63858 L .33894 .63567 L F
.551 .666 .913 r
.33894 .63567 m .34105 .63858 L .34361 .6379 L F
.55 .637 .89 r
.34105 .63858 m .3439 .63957 L .34361 .6379 L F
0 .475 .823 r
.73561 .48747 m .73777 .48812 L .73883 .48878 L F
.988 .854 .617 r
.73883 .48878 m .7385 .48653 L .74157 .48799 L F
.73883 .48878 m .73777 .48812 L .7385 .48653 L F
.511 .484 .763 r
.7365 .49628 m .73496 .49673 L .73657 .49394 L F
.758 .702 .799 r
.48156 .71926 m .48242 .72239 L .48523 .71964 L F
.322 0 0 r
.37971 .62438 m .38211 .62445 L .38323 .62384 L F
.087 0 0 r
.38323 .62384 m .38356 .62448 L .38551 .62357 L F
.38323 .62384 m .38211 .62445 L .38356 .62448 L F
.558 .489 .734 r
.7679 .49932 m .76607 .50371 L .76536 .49991 L F
.7679 .49932 m .76837 .50327 L .76607 .50371 L F
0 0 .435 r
.46704 .7102 m .46712 .71277 L .46595 .71406 L F
0 0 .341 r
.46712 .71277 m .46716 .71689 L .46595 .71406 L F
.678 .605 .767 r
.33399 .63541 m .335 .63702 L .33743 .63564 L F
.641 .409 .55 r
.335 .63702 m .33425 .6389 L .33659 .63815 L F
.857 .804 .798 r
.5893 .63488 m .59058 .63641 L .58862 .63877 L F
.636 .752 .932 r
.5893 .63488 m .59297 .6356 L .59058 .63641 L F
.347 0 0 r
.33743 .5851 m .33969 .58513 L .34138 .584 L F
.409 0 0 r
.33969 .58513 m .34366 .58377 L .34138 .584 L F
.262 .754 .909 r
.38246 .58247 m .38486 .58222 L .38593 .58255 L F
.254 .706 .955 r
.38486 .58222 m .38849 .58297 L .38593 .58255 L F
.491 .903 .845 r
.48078 .66165 m .483 .6606 L .4823 .66054 L F
.48078 .66165 m .4823 .66054 L .48154 .66113 L F
.626 .707 .904 r
.48033 .66196 m .482 .66239 L .48078 .66165 L F
.491 .903 .845 r
.48078 .66165 m .48154 .66113 L .47921 .66295 L F
.626 .707 .904 r
.47867 .66154 m .48033 .66196 L .48078 .66165 L F
.674 .877 .975 r
.482 .66239 m .483 .6606 L .48078 .66165 L F
.482 .66239 m .48447 .66148 L .483 .6606 L F
.615 .737 .933 r
.77471 .50464 m .77568 .50628 L .77225 .5053 L F
.546 .612 .87 r
.77753 .50397 m .77568 .50628 L .77471 .50464 L F
.77753 .50397 m .77798 .506 L .77568 .50628 L F
.79 .744 .811 r
.24352 .7833 m .24361 .7832 L .24343 .78318 L F
.316 .105 .426 r
.45691 .67066 m .45832 .67229 L .45882 .67013 L F
.45691 .67066 m .45656 .67312 L .45832 .67229 L F
.407 .065 .269 r
.46152 .66693 m .46351 .66722 L .46435 .66481 L F
.375 .03 .246 r
.46351 .66722 m .46659 .6643 L .46435 .66481 L F
.423 .209 .482 r
.44715 .69666 m .44884 .69872 L .44846 .69608 L F
.44715 .69666 m .44672 .69932 L .44884 .69872 L F
.274 .067 .407 r
.56244 .68742 m .56181 .68974 L .56135 .68705 L F
.423 .756 .995 r
.6376 .44158 m .63538 .44182 L .63385 .44079 L F
.45 .683 .965 r
.21703 .54837 m .21663 .55006 L .21504 .54868 L F
.21703 .54837 m .21865 .5499 L .21663 .55006 L F
.648 .274 .321 r
.43872 .61851 m .43505 .62026 L .4364 .61848 L F
.648 .294 .358 r
.49553 .63201 m .49814 .63213 L .49587 .63018 L F
.55 .327 .53 r
.49814 .63213 m .49824 .62978 L .49587 .63018 L F
.532 .382 .623 r
.31724 .63895 m .31949 .63925 L .31984 .63627 L F
.492 .681 .95 r
.41419 .58315 m .41455 .58593 L .41189 .58344 L F
.41419 .58315 m .41676 .58664 L .41455 .58593 L F
0 0 0 r
.57905 .64316 m .5777 .64359 L .57774 .64358 L F
.988 .75 .486 r
.57905 .64316 m .57987 .64615 L .57998 .64286 L F
.57905 .64316 m .57998 .64286 L .58 .64214 L F
.705 .264 .202 r
.58 .64214 m .58233 .64382 L .57905 .64316 L F
0 .24 .725 r
.58113 .64255 m .58233 .64382 L .58 .64214 L F
0 0 0 r
.57905 .64316 m .57774 .64358 L .58113 .64255 L F
.45 0 .022 r
.57683 .64287 m .57905 .64316 L .58 .64214 L F
0 .24 .725 r
.58113 .64255 m .58 .64214 L .57905 .64316 L F
0 0 .224 r
.52957 .72267 m .52844 .72275 L .53017 .72198 L F
.52957 .72267 m .52783 .72513 L .52844 .72275 L F
.753 .62 .054 r
.55991 .66688 m .55984 .66989 L .55992 .67083 L F
.248 .303 .723 r
.55984 .66989 m .55949 .67324 L .55992 .67083 L F
.505 .599 .881 r
.79299 .48923 m .79655 .49176 L .79542 .4888 L F
.593 .604 .832 r
.79542 .4888 m .79655 .49176 L .79863 .49047 L F
0 0 .545 r
.79655 .49176 m .79777 .49269 L .79863 .49047 L F
.79655 .49176 m .79764 .49386 L .79777 .49269 L F
.089 0 0 r
.37676 .58272 m .37894 .58298 L .38024 .58312 L F
.458 .878 .93 r
.38024 .58312 m .38112 .58224 L .38246 .58247 L F
.38024 .58312 m .37894 .58298 L .38112 .58224 L F
.658 .576 .751 r
.48846 .67773 m .48517 .67538 L .487 .67626 L F
.738 .298 .207 r
.48334 .67517 m .487 .67626 L .48517 .67538 L F
.695 .782 .918 r
.28172 .66112 m .28367 .66272 L .28545 .66151 L F
.28172 .66112 m .28367 .66272 L .28545 .66151 L F
.334 .021 .277 r
.52779 .67977 m .52732 .68151 L .53005 .67926 L F
.513 .374 .629 r
.76741 .49691 m .7679 .49932 L .76536 .49991 L F
.573 .477 .707 r
.25739 .84699 m .25976 .84671 L .25734 .84673 L F
.891 .93 .838 r
.73985 .47994 m .73709 .48131 L .74104 .48194 L F
.811 .503 .469 r
.74345 .48278 m .73985 .47994 L .74104 .48194 L F
.634 .765 .942 r
.77882 .52281 m .7798 .52494 L .78139 .52374 L F
.681 .71 .87 r
.19904 .56876 m .19677 .56947 L .19527 .56716 L F
.19904 .56876 m .197 .56947 L .19677 .56947 L F
.705 .53 .649 r
.19677 .56947 m .197 .56947 L .19681 .56991 L F
.7 .668 .815 r
.19904 .56876 m .19681 .56991 L .197 .56947 L F
0 0 .255 r
.57242 .63394 m .5731 .63687 L .57299 .63615 L F
.57242 .63394 m .57276 .63392 L .5731 .63687 L F
0 0 .08 r
.57232 .63429 m .57276 .63392 L .57242 .63394 L F
.949 .701 .527 r
.57121 .63351 m .57178 .63367 L .57131 .6307 L F
.278 .762 .668 r
.57346 .62957 m .57342 .62959 L .57232 .63429 L F
.57342 .62959 m .57287 .63097 L .57232 .63429 L F
0 0 .105 r
.57232 .63429 m .57255 .6329 L .57276 .63392 L F
.57255 .6329 m .57307 .62971 L .57276 .63392 L F
.727 .268 0 r
.57302 .63517 m .57276 .63392 L .57121 .63351 L F
.018 .124 .634 r
.57276 .63392 m .57448 .63672 L .5731 .63687 L F
.727 .268 0 r
.57336 .63549 m .57276 .63392 L .57302 .63517 L F
.949 .701 .527 r
.57178 .63367 m .57276 .63392 L .57219 .63266 L F
.57178 .63367 m .57219 .63266 L .57131 .6307 L F
.278 .762 .668 r
.57342 .62959 m .57307 .62971 L .57287 .63097 L F
.674 .843 .964 r
.75665 .51904 m .76082 .51866 L .75959 .51707 L F
.724 .786 .902 r
.75959 .51707 m .76082 .51866 L .76292 .51744 L F
.873 .718 .686 r
.47565 .71927 m .47497 .72262 L .47698 .72249 L F
.765 .364 .293 r
.47497 .72262 m .47557 .72432 L .47698 .72249 L F
.839 .468 .349 r
.47557 .72432 m .47871 .72511 L .47698 .72249 L F
.472 .341 .621 r
.3486 .60664 m .34858 .60895 L .34635 .60703 L F
.47 .341 .622 r
.34635 .60703 m .34858 .60895 L .34654 .60908 L F
.701 .59 .728 r
.23846 .76036 m .23871 .76007 L .23838 .76007 L F
.519 .553 .83 r
.45742 .69548 m .45652 .69873 L .45584 .69739 L F
.636 .666 .862 r
.40457 .59004 m .4065 .59285 L .40883 .59215 L F
.709 .668 .807 r
.20271 .56943 m .20049 .56984 L .19904 .56876 L F
.159 .025 .436 r
.22485 .56326 m .22466 .5658 L .22353 .5659 L F
.469 .456 .761 r
.22466 .5658 m .22378 .56957 L .22353 .5659 L F
.481 .21 .426 r
.449 .68146 m .45181 .67893 L .44939 .67941 L F
.416 .284 .592 r
.48509 .68152 m .48542 .68404 L .48301 .68284 L F
.597 .732 .939 r
.41902 .58518 m .41676 .58664 L .41419 .58315 L F
.611 .557 .77 r
.41955 .58603 m .41676 .58664 L .41902 .58518 L F
.41955 .58603 m .41711 .58675 L .41676 .58664 L F
.751 .577 .66 r
.49611 .64439 m .49535 .64695 L .49208 .64674 L F
.467 0 0 r
.79507 .51625 m .80052 .51667 L .79594 .51711 L F
.492 .001 .016 r
.36049 .64224 m .35638 .64306 L .35743 .64432 L F
.516 .56 .839 r
.55724 .59607 m .55919 .59613 L .55864 .59499 L F
.441 .851 .964 r
.55578 .59399 m .55924 .59391 L .55684 .59248 L F
.55602 .59407 m .55924 .59391 L .55578 .59399 L F
.55571 .59409 m .55791 .59347 L .55924 .59391 L F
.516 .56 .839 r
.55761 .59463 m .55864 .59499 L .55791 .59347 L F
.55724 .59607 m .55864 .59499 L .55761 .59463 L F
.441 .851 .964 r
.55571 .59409 m .55602 .59407 L .55578 .59399 L F
0 .105 .636 r
.47066 .69347 m .47023 .6925 L .46959 .69205 L F
.916 .605 .44 r
.47288 .69555 m .47023 .6925 L .47066 .69347 L F
.74 .595 .695 r
.44944 .70819 m .45294 .70912 L .45205 .705 L F
.568 .505 .744 r
.45294 .70912 m .45417 .70462 L .45205 .705 L F
.322 .801 .738 r
.32323 .63879 m .32188 .63918 L .32246 .63895 L F
.747 .357 .313 r
.32323 .63879 m .32575 .64146 L .32365 .64038 L F
.677 .278 0 r
.50083 .69538 m .50128 .69609 L .49996 .69369 L F
.501 .227 .43 r
.53493 .67333 m .53729 .67303 L .53777 .67046 L F
.694 .404 .479 r
.53777 .67046 m .53729 .67303 L .53978 .67276 L F
.554 .273 .444 r
.40187 .61774 m .40471 .61498 L .40229 .61559 L F
.657 .558 .731 r
.4766 .69329 m .47291 .69024 L .47559 .69233 L F
.516 .126 .239 r
.4766 .69329 m .4757 .69566 L .47288 .69555 L F
.399 .753 .993 r
.47559 .69233 m .47882 .69316 L .4766 .69329 L F
.994 .752 .412 r
.47559 .69233 m .4766 .69329 L .47882 .69316 L F
.47559 .69233 m .4757 .69566 L .4766 .69329 L F
.386 0 .18 r
.52641 .69047 m .52333 .69225 L .5241 .69071 L F
.76 .888 .936 r
.58089 .62363 m .58228 .62263 L .58324 .62372 L F
.341 .711 .984 r
.58228 .62263 m .58662 .62365 L .58324 .62372 L F
.469 .456 .761 r
.22466 .5658 m .22564 .56915 L .22378 .56957 L F
.438 .248 .524 r
.22534 .57104 m .22378 .56957 L .22564 .56915 L F
.22534 .57104 m .22363 .57183 L .22378 .56957 L F
0 0 0 r
.50852 .66754 m .50896 .66752 L .50703 .66777 L F
.50938 .66741 m .50896 .66752 L .50852 .66754 L F
.50896 .66752 m .50809 .66927 L .5092 .66751 L F
.50896 .66752 m .5092 .66751 L .51026 .66582 L F
0 0 .015 r
.50854 .66473 m .50703 .66777 L .50896 .66752 L F
.666 .637 .811 r
.45518 .61256 m .4565 .61578 L .45398 .61578 L F
.677 .504 .645 r
.4565 .61578 m .45431 .61754 L .45398 .61578 L F
.925 .822 .363 r
.61349 .64996 m .61267 .65206 L .61306 .65367 L F
0 0 0 r
.61331 .65423 m .61306 .65367 L .61267 .65206 L F
.61331 .65423 m .61237 .65579 L .61306 .65367 L F
.547 .858 .997 r
.54714 .59733 m .54858 .59797 L .54647 .5985 L F
.54714 .59733 m .54858 .59797 L .54647 .5985 L F
.944 .957 .732 r
.32233 .63341 m .32149 .63309 L .32326 .62961 L F
.559 .88 .604 r
.74086 .485 m .74345 .48278 L .74104 .48194 L F
.705 .806 .928 r
.7967 .47904 m .79311 .47872 L .79575 .47674 L F
.632 .764 .942 r
.79977 .4781 m .7967 .47904 L .79575 .47674 L F
.707 .637 .776 r
.20188 .56845 m .20271 .56943 L .20364 .56744 L F
.768 .677 .762 r
.20364 .56744 m .20271 .56943 L .20502 .5665 L F
.8 .729 .786 r
.20502 .5665 m .20271 .56943 L .20135 .5665 L F
.493 .557 .85 r
.53927 .67667 m .54039 .67485 L .53773 .67547 L F
.53927 .67667 m .54266 .67816 L .54039 .67485 L F
.285 0 0 r
.3856 .63543 m .38427 .6367 L .38234 .6369 L F
.272 0 0 r
.38802 .63493 m .38427 .6367 L .3856 .63543 L F
.622 .304 .411 r
.6401 .45116 m .64004 .45286 L .63668 .45326 L F
.526 .227 .402 r
.6401 .45116 m .64253 .45255 L .64004 .45286 L F
.537 .214 .369 r
.64275 .45091 m .64253 .45255 L .6401 .45116 L F
.592 .326 .482 r
.49534 .65879 m .49254 .6611 L .49278 .65951 L F
.575 .576 .817 r
.31938 .62141 m .32016 .61756 L .31822 .61792 L F
.31938 .62141 m .32158 .62095 L .32016 .61756 L F
.48 .825 .542 r
.3189 .62331 m .32158 .62095 L .31938 .62141 L F
.568 .505 .744 r
.45294 .70912 m .45499 .70847 L .45417 .70462 L F
.011 0 0 r
.19429 .54438 m .19623 .54379 L .19411 .54409 L F
.306 .049 .35 r
.21901 .58541 m .21786 .5836 L .21961 .58307 L F
.21901 .58541 m .2173 .58606 L .21786 .5836 L F
.8 .923 .541 r
.60908 .66265 m .60849 .66449 L .61011 .66154 L F
.812 .999 .844 r
.60908 .66265 m .60769 .6643 L .60849 .66449 L F
.535 .19 .329 r
.4486 .61731 m .4469 .62019 L .44475 .61886 L F
.651 .319 .398 r
.45096 .62014 m .4486 .61731 L .4506 .61815 L F
.45096 .62014 m .4469 .62019 L .4486 .61731 L F
.469 .504 .812 r
.42917 .6032 m .43071 .60708 L .43237 .60623 L F
.164 0 .238 r
.43071 .60708 m .43009 .60903 L .43237 .60623 L F
0 0 .287 r
.57178 .65565 m .57151 .65491 L .57053 .6526 L F
0 0 .492 r
.57178 .65565 m .57344 .65793 L .57151 .65491 L F
.593 .76 .958 r
.49053 .67682 m .48846 .67773 L .487 .67626 L F
.573 .443 .665 r
.4908 .67804 m .48846 .67773 L .49053 .67682 L F
.4908 .67804 m .48847 .67948 L .48846 .67773 L F
.639 .801 .961 r
.40982 .58377 m .40776 .58464 L .40614 .58331 L F
.738 .611 .717 r
.54523 .67941 m .54929 .67955 L .54783 .67538 L F
.805 .582 .6 r
.54521 .67953 m .54929 .67955 L .54523 .67941 L F
.54672 .6805 m .54929 .67955 L .54521 .67953 L F
.54499 .68114 m .54673 .68168 L .54929 .67955 L F
.375 .399 .758 r
.54792 .6755 m .54929 .67955 L .55025 .6784 L F
.54783 .67538 m .55025 .6784 L .55002 .67784 L F
.54783 .67538 m .55038 .67824 L .54944 .67484 L F
.59 .555 .783 r
.55038 .67824 m .55082 .67792 L .54944 .67484 L F
.289 0 .195 r
.551 .67686 m .54889 .67772 L .54934 .67539 L F
.54984 .67536 m .54934 .67539 L .54944 .67484 L F
.551 .67686 m .54934 .67539 L .54984 .67536 L F
.375 .399 .758 r
.54783 .67538 m .54787 .6755 L .54792 .6755 L F
.54787 .6755 m .54929 .67955 L .54792 .6755 L F
.55002 .67784 m .55025 .6784 L .55038 .67824 L F
.738 .611 .717 r
.54523 .67941 m .54783 .67538 L .54495 .67662 L F
.512 .129 .251 r
.5488 .67486 m .54607 .67781 L .54608 .67496 L F
.54944 .67484 m .54896 .67526 L .5488 .67486 L F
.54896 .67526 m .54607 .67781 L .5488 .67486 L F
.666 .947 .694 r
.54929 .67955 m .54673 .68168 L .55038 .67824 L F
.613 .426 .605 r
.55038 .67824 m .54746 .68099 L .55239 .68054 L F
.54746 .68099 m .54673 .68168 L .54811 .6814 L F
.54746 .68099 m .54811 .6814 L .55239 .68054 L F
.805 .582 .6 r
.54499 .68114 m .54672 .6805 L .54521 .67953 L F
.896 .759 .703 r
.54751 .61234 m .54904 .61293 L .55011 .60887 L F
.55 .804 .992 r
.42185 .59762 m .42563 .59823 L .42381 .59724 L F
.549 .792 .989 r
.42381 .59724 m .42563 .59823 L .42624 .59673 L F
.352 .568 .92 r
.42563 .59823 m .42735 .59792 L .42624 .59673 L F
.549 .524 .78 r
.42579 .60082 m .42735 .59792 L .42563 .59823 L F
.759 .585 .013 r
.20151 .56406 m .20128 .56209 L .20108 .56384 L F
.20151 .56406 m .2014 .56449 L .20128 .56209 L F
.8 .729 .786 r
.20502 .5665 m .20135 .5665 L .20151 .56406 L F
.503 .425 .701 r
.31202 .61576 m .31435 .61538 L .31337 .61209 L F
.479 .32 .587 r
.31202 .61576 m .31209 .61815 L .31435 .61538 L F
.443 .507 .83 r
.45056 .60598 m .4489 .60642 L .44757 .6024 L F
.251 .203 .607 r
.56418 .61272 m .56449 .61644 L .56484 .61491 L F
.56484 .61491 m .56449 .61644 L .56418 .61272 L F
.65 .317 .395 r
.51349 .69325 m .51427 .69542 L .51199 .69332 L F
.51577 .69313 m .51524 .69394 L .51349 .69325 L F
.51524 .69394 m .51427 .69542 L .51349 .69325 L F
.575 .478 .707 r
.51459 .69364 m .51472 .69374 L .51645 .68938 L F
.769 .466 .472 r
.51577 .69313 m .51785 .69584 L .51698 .69574 L F
.575 .478 .707 r
.51472 .69374 m .51586 .69458 L .51524 .69394 L F
.769 .466 .472 r
.51577 .69313 m .51698 .69574 L .51524 .69394 L F
.575 .478 .707 r
.51586 .69458 m .51606 .69473 L .51524 .69394 L F
0 0 .035 r
.51586 .69458 m .51529 .69396 L .51606 .69473 L F
.51459 .69364 m .51463 .69366 L .51586 .69458 L F
.769 .466 .472 r
.51524 .69394 m .51586 .69458 L .51516 .69406 L F
0 0 .035 r
.51463 .69366 m .51529 .69396 L .51586 .69458 L F
.769 .466 .472 r
.51516 .69406 m .51698 .69574 L .51427 .69542 L F
.51586 .69458 m .51698 .69574 L .51516 .69406 L F
.575 .478 .707 r
.51524 .69394 m .51606 .69473 L .51609 .69428 L F
.731 .466 .527 r
.51792 .69344 m .51785 .69584 L .51577 .69313 L F
.575 .478 .707 r
.51472 .69374 m .51609 .69428 L .51645 .68938 L F
.664 .428 .552 r
.51199 .69332 m .51459 .69364 L .51476 .6909 L F
.353 .351 .717 r
.51441 .68762 m .51476 .6909 L .51645 .68938 L F
.575 .478 .707 r
.51459 .69364 m .51645 .68938 L .51476 .6909 L F
.42 0 .113 r
.38778 .62348 m .38999 .62343 L .39154 .62138 L F
.271 0 0 r
.38999 .62343 m .39394 .62115 L .39154 .62138 L F
.857 .804 .798 r
.5893 .63488 m .58862 .63877 L .58681 .63815 L F
.885 .638 .56 r
.58862 .63877 m .58891 .64143 L .58681 .63815 L F
0 .464 .806 r
.46409 .71808 m .46503 .71809 L .46217 .71678 L F
.46409 .71808 m .46649 .71871 L .46503 .71809 L F
.723 .715 .842 r
.7537 .5174 m .75462 .52028 L .75665 .51904 L F
.922 .748 .649 r
.54742 .61526 m .54664 .61771 L .54834 .61835 L F
.826 .477 .394 r
.54676 .62012 m .54834 .61835 L .54664 .61771 L F
.54676 .62012 m .54998 .62102 L .54834 .61835 L F
.533 .895 .973 r
.81282 .51116 m .80728 .51217 L .80928 .5132 L F
.304 .043 .343 r
.5019 .64449 m .50112 .64679 L .49961 .64719 L F
.58 .308 .468 r
.50418 .64635 m .50112 .64679 L .5019 .64449 L F
0 0 .435 r
.48269 .70798 m .48399 .70912 L .48441 .70825 L F
.585 .722 .937 r
.79299 .48923 m .79467 .48735 L .79223 .48764 L F
.79299 .48923 m .79542 .4888 L .79467 .48735 L F
.159 0 0 r
.34943 .58298 m .35164 .58303 L .35321 .58274 L F
.415 0 0 r
.35321 .58274 m .35164 .58303 L .35535 .58329 L F
.705 .454 .543 r
.73845 .49491 m .7365 .49628 L .73657 .49394 L F
.73845 .49491 m .74037 .49678 L .7365 .49628 L F
.387 0 .074 r
.40804 .62687 m .4089 .62837 L .40662 .62876 L F
.40804 .62687 m .41044 .62641 L .4089 .62837 L F
.445 .497 .818 r
.2317 .55686 m .23074 .5587 L .22954 .55755 L F
.866 .897 .854 r
.53649 .68864 m .536 .68908 L .53669 .68816 L F
.855 .769 .766 r
.60006 .60628 m .60191 .6069 L .60112 .60373 L F
.937 .749 .623 r
.59982 .60858 m .60191 .6069 L .60006 .60628 L F
.59982 .60858 m .60155 .60952 L .60191 .6069 L F
.358 0 .153 r
.41044 .62641 m .4131 .62479 L .41269 .62623 L F
.524 .173 .314 r
.41623 .62379 m .41269 .62623 L .4131 .62479 L F
.735 .722 .839 r
.33012 .63315 m .33399 .63541 L .33215 .63192 L F
.33012 .63315 m .33135 .63579 L .33399 .63541 L F
.448 .644 .941 r
.33399 .63541 m .33324 .63202 L .33215 .63192 L F
.33399 .63541 m .33678 .63381 L .33324 .63202 L F
.541 .81 .996 r
.33678 .63381 m .33743 .63564 L .33787 .634 L F
0 0 0 r
.33804 .63464 m .33614 .63537 L .33781 .63405 L F
.33787 .63403 m .33781 .63405 L .33787 .634 L F
.301 .56 .927 r
.33743 .63564 m .33894 .63567 L .33787 .634 L F
0 0 0 r
.33804 .63464 m .33781 .63405 L .33787 .63403 L F
.678 .605 .767 r
.33399 .63541 m .33743 .63564 L .33696 .63433 L F
.33447 .63514 m .33696 .63433 L .33678 .63381 L F
.33399 .63541 m .33696 .63433 L .33447 .63514 L F
.513 .368 .621 r
.51637 .65604 m .51672 .65881 L .51852 .65811 L F
.464 .152 .35 r
.35401 .60125 m .35349 .60329 L .35112 .6037 L F
.221 0 .26 r
.35526 .60228 m .35401 .60125 L .35627 .60073 L F
.35526 .60228 m .35349 .60329 L .35401 .60125 L F
.873 .672 .627 r
.60155 .60952 m .60039 .61225 L .6032 .61269 L F
.842 .666 .664 r
.60039 .61225 m .60306 .6152 L .6032 .61269 L F
.527 .38 .625 r
.5328 .67603 m .53525 .67581 L .53493 .67333 L F
.733 .527 .613 r
.5318 .67828 m .53525 .67581 L .5328 .67603 L F
.386 0 .15 r
.57088 .59152 m .57336 .59114 L .57431 .58929 L F
.597 .251 .354 r
.57574 .59174 m .57431 .58929 L .57336 .59114 L F
.57574 .59174 m .57685 .58934 L .57431 .58929 L F
.917 .537 .121 r
.57046 .65033 m .56934 .64987 L .56853 .64686 L F
.978 .718 .312 r
.57046 .65033 m .56924 .64996 L .56934 .64987 L F
.57046 .65033 m .57053 .6526 L .56924 .64996 L F
.765 .31 0 r
.5675 .64518 m .56743 .64574 L .5654 .64378 L F
.5675 .64518 m .56853 .64686 L .56743 .64574 L F
.671 .268 .274 r
.56769 .60099 m .56994 .60301 L .56982 .6016 L F
.146 .687 .711 r
.38739 .59251 m .38345 .59323 L .38525 .5927 L F
.183 0 0 r
.20016 .54398 m .19994 .54356 L .19792 .5441 L F
.20016 .54398 m .20196 .54374 L .19994 .54356 L F
.492 .001 .016 r
.36049 .64224 m .35827 .64342 L .35638 .64306 L F
.259 0 0 r
.36207 .64108 m .35827 .64342 L .36049 .64224 L F
.301 0 0 r
.394 .63276 m .39251 .6344 L .39024 .63475 L F
.373 0 .04 r
.39628 .63242 m .39251 .6344 L .394 .63276 L F
.807 .757 .806 r
.80301 .49636 m .80434 .49862 L .80462 .49774 L F
.286 .206 .588 r
.20811 .61186 m .20784 .6155 L .20668 .61558 L F
.299 .134 .483 r
.20784 .6155 m .20644 .61799 L .20668 .61558 L F
.399 0 .135 r
.47791 .66308 m .47867 .66154 L .48078 .66165 L F
0 0 0 r
.3439 .63957 m .34501 .63958 L .34361 .6379 L F
.3439 .63957 m .34633 .63949 L .34501 .63958 L F
.44 .226 .491 r
.44691 .68204 m .44665 .68444 L .449 .68146 L F
.486 .385 .665 r
.31595 .59289 m .31814 .59436 L .31894 .5924 L F
.31595 .59289 m .31617 .59506 L .31814 .59436 L F
.487 .081 .196 r
.329 .58805 m .33224 .58672 L .32982 .58713 L F
.567 .925 .754 r
.783 .48183 m .78384 .48086 L .78517 .48033 L F
.606 .942 .761 r
.78517 .48033 m .78384 .48086 L .78672 .47875 L F
.696 .983 .845 r
.78384 .48086 m .78482 .47925 L .78672 .47875 L F
0 0 .113 r
.78384 .48086 m .78512 .48155 L .78487 .47968 L F
.78384 .48086 m .78487 .47968 L .78482 .47925 L F
.567 .925 .754 r
.78221 .48237 m .78384 .48086 L .783 .48183 L F
.801 .354 .18 r
.57341 .64095 m .57683 .64287 L .5745 .64165 L F
.92 .789 .701 r
.5181 .6434 m .5196 .6462 L .51819 .64623 L F
.716 .953 .668 r
.5171 .6469 m .51819 .64623 L .5196 .6462 L F
.5171 .6469 m .51591 .64815 L .51819 .64623 L F
.812 .769 .259 r
.50112 .64679 m .50078 .64885 L .49961 .64719 L F
.793 .38 0 r
.56494 .64154 m .56422 .64074 L .56315 .63848 L F
0 .011 .584 r
.5654 .64378 m .56422 .64074 L .56494 .64154 L F
.977 .738 .51 r
.59933 .60022 m .59928 .60268 L .60068 .60113 L F
.909 .589 .428 r
.59928 .60268 m .60112 .60373 L .60068 .60113 L F
0 .136 .677 r
.47498 .72505 m .47687 .72756 L .47557 .72432 L F
.71 .247 .151 r
.56304 .62416 m .56563 .62594 L .56633 .62488 L F
.688 .221 .138 r
.56563 .62594 m .56949 .62717 L .56633 .62488 L F
.966 .8 .627 r
.4901 .65259 m .49199 .65075 L .49182 .65016 L F
.4901 .65259 m .49148 .65392 L .49199 .65075 L F
.525 .583 .856 r
.4931 .6641 m .49146 .66591 L .49024 .66408 L F
.4931 .6641 m .49426 .66643 L .49146 .66591 L F
.418 .848 .947 r
.56399 .59831 m .56516 .59744 L .5627 .59749 L F
.56399 .59831 m .56633 .59773 L .56516 .59744 L F
.357 .268 .617 r
.52962 .64616 m .53139 .64644 L .53097 .64391 L F
.337 .326 .699 r
.52962 .64616 m .53237 .64877 L .53139 .64644 L F
.52962 .64616 m .53135 .65051 L .53237 .64877 L F
.537 .473 .731 r
.44645 .60109 m .44462 .60352 L .44422 .60139 L F
.574 .524 .761 r
.44645 .60109 m .44757 .6024 L .44462 .60352 L F
.435 .746 .993 r
.40249 .59023 m .40383 .58921 L .40176 .59005 L F
.40249 .59023 m .40457 .59004 L .40383 .58921 L F
.532 .129 .223 r
.53267 .63251 m .53351 .63415 L .53539 .63424 L F
.53267 .63251 m .53129 .63449 L .53351 .63415 L F
.332 .815 .859 r
.57018 .62731 m .56949 .62717 L .56856 .62731 L F
.235 .601 .951 r
.57087 .62619 m .57263 .62769 L .57018 .62731 L F
.72 .613 .737 r
.63306 .44726 m .63425 .45092 L .63057 .45065 L F
.703 .495 .603 r
.63425 .45092 m .63207 .45385 L .63057 .45065 L F
.63425 .45092 m .63422 .45334 L .63207 .45385 L F
.404 .39 .73 r
.34904 .6109 m .34738 .61288 L .34654 .60908 L F
.479 .499 .8 r
.34904 .6109 m .35023 .61446 L .34738 .61288 L F
.629 .661 .861 r
.43939 .59535 m .43717 .59601 L .43619 .5946 L F
.149 .569 .929 r
.36562 .62612 m .36184 .62448 L .36421 .6252 L F
.25 0 0 r
.36421 .6252 m .3677 .62588 L .36562 .62612 L F
.192 0 .071 r
.31814 .59436 m .32115 .592 L .31894 .5924 L F
.448 .139 .347 r
.31894 .5924 m .32115 .592 L .32154 .59076 L F
.168 .392 .837 r
.57623 .66667 m .57432 .66386 L .57613 .66468 L F
.51 0 0 r
.74157 .48799 m .74416 .48936 L .74467 .4888 L F
.43 0 0 r
.74467 .4888 m .74833 .48993 L .74678 .48865 L F
.74467 .4888 m .74416 .48936 L .74833 .48993 L F
.034 .095 .595 r
.54166 .6472 m .54252 .64659 L .54095 .64443 L F
.692 .253 .203 r
.54095 .64443 m .54252 .64659 L .53968 .64601 L F
0 0 .283 r
.61353 .64679 m .61383 .64962 L .61349 .64996 L F
0 0 0 r
.61383 .64962 m .61267 .65206 L .61349 .64996 L F
.877 .76 .73 r
.59006 .61835 m .59095 .62149 L .58935 .62056 L F
.94 .741 .607 r
.58935 .62056 m .59095 .62149 L .59056 .62393 L F
.318 .729 .978 r
.20961 .54557 m .20936 .54659 L .2075 .5456 L F
.20961 .54557 m .21134 .54654 L .20936 .54659 L F
.506 .361 .618 r
.54306 .66752 m .54517 .66413 L .54248 .66502 L F
.54306 .66752 m .54561 .66708 L .54517 .66413 L F
.413 .198 .474 r
.54314 .66987 m .54561 .66708 L .54306 .66752 L F
.413 .106 .333 r
.32154 .59076 m .32331 .59145 L .32374 .5902 L F
.32154 .59076 m .32115 .592 L .32331 .59145 L F
.694 .715 .865 r
.445 .59605 m .44352 .598 L .4418 .59508 L F
.594 .567 .793 r
.445 .59605 m .44637 .59752 L .44352 .598 L F
.53 .427 .681 r
.44637 .59752 m .44422 .60139 L .44352 .598 L F
.998 .796 .507 r
.60961 .65842 m .60923 .66124 L .61011 .66154 L F
.8 .923 .541 r
.60908 .66265 m .61011 .66154 L .60923 .66124 L F
.127 .342 .806 r
.46069 .71635 m .46217 .71678 L .46137 .71504 L F
.418 .066 .259 r
.42449 .62087 m .42334 .62342 L .42111 .6238 L F
.551 .198 .324 r
.42667 .62239 m .42449 .62087 L .42691 .62061 L F
.42667 .62239 m .42334 .62342 L .42449 .62087 L F
.997 .85 .52 r
.47605 .67221 m .4774 .67042 L .47662 .67307 L F
.755 .732 .831 r
.47606 .66821 m .4774 .67042 L .4799 .66799 L F
.997 .85 .52 r
.47662 .67307 m .4774 .67042 L .47605 .67221 L F
.519 .553 .83 r
.45742 .69548 m .4588 .69856 L .45652 .69873 L F
.689 .618 .772 r
.74037 .49678 m .73803 .4994 L .7365 .49628 L F
.621 .514 .711 r
.74037 .49678 m .73913 .49937 L .73803 .4994 L F
.661 .675 .853 r
.74173 .49993 m .73803 .4994 L .73913 .49937 L F
.434 .244 .522 r
.48702 .69472 m .48478 .69305 L .48844 .69366 L F
.537 .23 .395 r
.48844 .69366 m .48702 .69264 L .48702 .69472 L F
.581 .414 .62 r
.49077 .69052 m .49101 .69356 L .48844 .69366 L F
.537 .23 .395 r
.48844 .69366 m .49101 .69356 L .48702 .69264 L F
.48844 .69366 m .49044 .69534 L .49101 .69356 L F
.49101 .69356 m .49044 .69534 L .48844 .69366 L F
.999 .82 .486 r
.48702 .69472 m .48768 .69706 L .48844 .69366 L F
.686 .502 .633 r
.4908 .67804 m .48818 .68133 L .48847 .67948 L F
.258 .104 .473 r
.22363 .57183 m .22339 .57446 L .22195 .57486 L F
.42 .362 .687 r
.22339 .57446 m .22236 .57778 L .22195 .57486 L F
.601 .659 .879 r
.35204 .61424 m .35138 .61772 L .35023 .61446 L F
.35204 .61424 m .35351 .61694 L .35138 .61772 L F
.386 .813 .967 r
.38849 .58297 m .39073 .58259 L .39222 .58303 L F
.329 .773 .961 r
.39073 .58259 m .39444 .58289 L .39222 .58303 L F
.501 .523 .811 r
.47791 .66308 m .47898 .66552 L .47597 .6651 L F
.153 0 0 r
.39113 .59242 m .38975 .59262 L .38739 .59251 L F
.234 .751 .764 r
.39336 .59186 m .38975 .59262 L .39113 .59242 L F
.677 .504 .645 r
.4565 .61578 m .45652 .61841 L .45431 .61754 L F
.662 .634 .812 r
.4589 .61519 m .4565 .61578 L .45518 .61256 L F
.554 .405 .634 r
.45893 .61772 m .4565 .61578 L .4589 .61519 L F
.45893 .61772 m .45652 .61841 L .4565 .61578 L F
.632 .589 .788 r
.42677 .60398 m .42812 .60047 L .42579 .60082 L F
.42677 .60398 m .42917 .6032 L .42812 .60047 L F
.695 .591 .735 r
.41202 .59636 m .41389 .59874 L .41588 .5954 L F
.77 .663 .744 r
.51412 .6733 m .51163 .67577 L .51064 .67284 L F
.633 .135 .05 r
.51064 .67284 m .51254 .67373 L .51412 .6733 L F
.627 .434 .601 r
.51412 .6733 m .51417 .67588 L .51163 .67577 L F
.601 .436 .63 r
.51412 .6733 m .51658 .67304 L .51644 .67037 L F
.515 .345 .589 r
.51646 .67536 m .51412 .6733 L .51658 .67304 L F
.51646 .67536 m .51417 .67588 L .51412 .6733 L F
.621 .313 .427 r
.51236 .6758 m .51207 .67605 L .51163 .67577 L F
.51295 .67661 m .51135 .67635 L .51163 .67577 L F
.584 .506 .732 r
.51297 .67366 m .51166 .6764 L .51352 .67385 L F
.51166 .6764 m .51166 .6764 L .51352 .67385 L F
.561 .237 .377 r
.51163 .67577 m .50819 .67835 L .50827 .67607 L F
.584 .506 .732 r
.51092 .67385 m .51163 .67637 L .51297 .67366 L F
.51163 .67637 m .51164 .67643 L .51167 .67637 L F
.51163 .67637 m .51167 .67637 L .51297 .67366 L F
.561 .237 .377 r
.51163 .67577 m .51135 .67635 L .51089 .67632 L F
.51135 .67635 m .5111 .67689 L .51089 .67632 L F
.5111 .67689 m .51054 .67805 L .51071 .67723 L F
.5111 .67689 m .51071 .67723 L .51089 .67632 L F
.584 .506 .732 r
.51166 .6764 m .51164 .67643 L .51166 .6764 L F
.28 0 .044 r
.51162 .67644 m .51166 .6764 L .51164 .67643 L F
.621 .313 .427 r
.51295 .67661 m .51054 .67805 L .51135 .67635 L F
.983 .738 .339 r
.50731 .67509 m .50926 .6773 L .51164 .67643 L F
.28 0 .044 r
.5116 .67644 m .51166 .6764 L .51162 .67644 L F
.50926 .6773 m .51164 .67641 L .5116 .67644 L F
.85 .66 .644 r
.50731 .67509 m .51164 .67643 L .51064 .67284 L F
.28 0 .044 r
.51164 .67641 m .51166 .6764 L .5116 .67644 L F
.50926 .6773 m .51352 .67385 L .51168 .67637 L F
.51164 .67641 m .51168 .67637 L .51166 .6764 L F
.50926 .6773 m .51168 .67637 L .51164 .67641 L F
.561 .237 .377 r
.51089 .67632 m .51071 .67723 L .50819 .67835 L F
.51071 .67723 m .51054 .67805 L .50964 .67817 L F
.51071 .67723 m .50964 .67817 L .50819 .67835 L F
.621 .313 .427 r
.51417 .67588 m .51295 .67661 L .51207 .67605 L F
.51417 .67588 m .51207 .67605 L .51236 .6758 L F
.584 .506 .732 r
.51064 .67284 m .51092 .67385 L .51297 .67366 L F
.172 0 0 r
.51272 .67368 m .51658 .67304 L .51412 .6733 L F
.51254 .67373 m .51296 .67366 L .51272 .67368 L F
.51296 .67366 m .51658 .67304 L .51272 .67368 L F
.601 .436 .63 r
.51644 .67037 m .51658 .67304 L .51412 .6733 L F
.379 .305 .647 r
.44564 .69067 m .44735 .69034 L .44724 .68698 L F
.396 .388 .733 r
.44564 .69067 m .44818 .69259 L .44735 .69034 L F
0 .401 .832 r
.53946 .6137 m .54032 .61473 L .53686 .61323 L F
0 .394 .82 r
.53686 .61323 m .54032 .61473 L .54022 .61512 L F
.836 .607 .591 r
.60306 .6152 m .60473 .6181 L .6045 .6158 L F
.962 .765 .592 r
.59775 .59686 m .59957 .59528 L .59793 .59447 L F
.59775 .59686 m .59917 .59785 L .59957 .59528 L F
.524 .173 .314 r
.41623 .62379 m .41506 .62617 L .41269 .62623 L F
.495 .139 .292 r
.41874 .62364 m .41506 .62617 L .41623 .62379 L F
.28 .162 .535 r
.48482 .6565 m .4844 .65506 L .48511 .65287 L F
.326 0 .045 r
.39617 .6207 m .39838 .62033 L .39982 .61845 L F
.488 .135 .292 r
.39838 .62033 m .40187 .61774 L .39982 .61845 L F
.837 .688 .697 r
.58947 .6097 m .5884 .61066 L .58754 .6095 L F
.271 0 0 r
.28254 .83686 m .28157 .83608 L .28034 .83744 L F
.28254 .83686 m .28304 .83602 L .28157 .83608 L F
.102 0 .089 r
.77206 .49329 m .76943 .49599 L .76993 .49454 L F
.53 .427 .681 r
.44637 .59752 m .44645 .60109 L .44422 .60139 L F
.655 .513 .678 r
.55295 .67287 m .54958 .67039 L .55218 .66995 L F
.55295 .67287 m .54998 .67343 L .54958 .67039 L F
0 0 0 r
.49482 .70138 m .49256 .70365 L .4935 .70233 L F
.728 .59 .701 r
.5482 .65252 m .54476 .65451 L .54587 .65329 L F
.648 .274 .321 r
.43872 .61851 m .43745 .6205 L .43505 .62026 L F
.614 .235 .301 r
.44099 .62024 m .43745 .6205 L .43872 .61851 L F
.957 .634 .366 r
.61093 .63755 m .61291 .64098 L .61262 .63849 L F
.663 .556 .723 r
.73316 .4931 m .73475 .4955 L .73657 .49394 L F
.997 .779 .434 r
.61291 .64098 m .61275 .64343 L .6137 .6444 L F
.974 .784 .36 r
.61291 .64583 m .6137 .6444 L .61275 .64343 L F
.61291 .64583 m .61353 .64679 L .6137 .6444 L F
.755 .664 .762 r
.56512 .59425 m .56821 .59532 L .56633 .59773 L F
.46 .728 .984 r
.56512 .59425 m .56742 .59412 L .56821 .59532 L F
0 .02 .585 r
.56642 .59562 m .56742 .59412 L .56616 .59569 L F
.999 .801 .462 r
.56821 .59532 m .56742 .59412 L .56849 .59252 L F
.665 .153 .012 r
.56881 .59548 m .56902 .59581 L .56821 .59532 L F
.632 .365 .496 r
.56821 .59532 m .57096 .59699 L .56667 .59738 L F
.665 .153 .012 r
.572 .59631 m .57096 .59699 L .56902 .59581 L F
.572 .59631 m .56902 .59581 L .56881 .59548 L F
.282 .121 .479 r
.56975 .59705 m .57215 .59299 L .56859 .59532 L F
.991 .741 .38 r
.57096 .59699 m .56989 .59707 L .56996 .59708 L F
.56937 .59714 m .56895 .59715 L .56831 .59723 L F
.56996 .59708 m .56942 .59712 L .56937 .59714 L F
.56942 .59712 m .56895 .59715 L .56937 .59714 L F
.682 .195 0 r
.56742 .59412 m .56944 .59675 L .56859 .59532 L F
.56944 .59675 m .56966 .59704 L .56955 .59686 L F
.56944 .59675 m .56955 .59686 L .56859 .59532 L F
0 0 0 r
.56633 .59773 m .56655 .59745 L .56667 .59738 L F
.56655 .59745 m .56821 .59532 L .56667 .59738 L F
.124 .674 .78 r
.56667 .59738 m .56771 .59724 L .56681 .59731 L F
.56667 .59738 m .56681 .59731 L .56516 .59744 L F
.259 .361 .778 r
.56771 .59724 m .56835 .59563 L .56616 .59569 L F
.56835 .59563 m .56859 .59502 L .56793 .5952 L F
.56835 .59563 m .56793 .5952 L .56616 .59569 L F
.884 .799 .761 r
.56742 .59412 m .56859 .59532 L .57088 .59152 L F
0 0 0 r
.56859 .59532 m .57336 .59114 L .57088 .59152 L F
.56859 .59532 m .57215 .59299 L .57336 .59114 L F
0 .02 .585 r
.56859 .59502 m .56978 .597 L .56742 .59412 L F
.991 .741 .38 r
.56989 .59707 m .56771 .59724 L .56996 .59708 L F
.56946 .5971 m .5702 .59778 L .56911 .59713 L F
.56989 .59707 m .5702 .59778 L .56946 .5971 L F
.682 .195 0 r
.56966 .59704 m .57028 .59784 L .56975 .59705 L F
.991 .741 .38 r
.57096 .59699 m .57091 .59956 L .56987 .59812 L F
.682 .195 0 r
.57028 .59784 m .57029 .59786 L .57027 .59783 L F
.57028 .59784 m .57027 .59783 L .56975 .59705 L F
.991 .741 .38 r
.57096 .59699 m .57023 .59775 L .56989 .59707 L F
.57023 .59775 m .5702 .59778 L .56989 .59707 L F
.5702 .59778 m .5702 .59778 L .56946 .5971 L F
0 .02 .585 r
.56978 .597 m .57029 .59785 L .56966 .59704 L F
.682 .195 0 r
.57029 .59786 m .5703 .59788 L .57026 .59782 L F
0 .02 .585 r
.57029 .59785 m .5703 .59788 L .57028 .59784 L F
.57029 .59785 m .57028 .59784 L .56966 .59704 L F
.682 .195 0 r
.56966 .59704 m .56975 .59705 L .56859 .59532 L F
.57029 .59786 m .57026 .59782 L .56859 .59532 L F
0 .02 .585 r
.56978 .597 m .56966 .59704 L .56742 .59412 L F
.991 .741 .38 r
.56895 .59715 m .56771 .59724 L .56831 .59723 L F
.56911 .59713 m .56987 .59812 L .56771 .59724 L F
.5702 .59778 m .56987 .59812 L .56911 .59713 L F
.282 .121 .479 r
.57027 .59782 m .57066 .59693 L .56975 .59705 L F
.5703 .59788 m .57032 .59785 L .57027 .59782 L F
.57032 .59785 m .57066 .59693 L .57027 .59782 L F
.57066 .59693 m .57215 .59299 L .56975 .59705 L F
.991 .741 .38 r
.56831 .59723 m .56771 .59724 L .56667 .59738 L F
0 .02 .585 r
.56859 .59502 m .56742 .59412 L .56642 .59562 L F
.999 .801 .462 r
.56849 .59252 m .56742 .59412 L .56852 .5922 L F
.884 .799 .761 r
.56742 .59412 m .57088 .59152 L .56852 .5922 L F
.815 .727 .767 r
.47898 .66552 m .48186 .66683 L .48083 .66609 L F
.47898 .66552 m .4799 .66799 L .48186 .66683 L F
.456 .457 .771 r
.48186 .66683 m .48536 .66971 L .48564 .66748 L F
.48186 .66683 m .48585 .67261 L .48536 .66971 L F
.324 .204 .558 r
.21397 .59742 m .21395 .60099 L .21216 .60108 L F
.392 .198 .493 r
.21369 .60221 m .21216 .60108 L .21395 .60099 L F
.21369 .60221 m .21202 .60325 L .21216 .60108 L F
.615 .528 .733 r
.43569 .59238 m .43356 .59289 L .43253 .59153 L F
.43569 .59238 m .43619 .5946 L .43356 .59289 L F
.104 .658 .722 r
.35535 .58329 m .35755 .58302 L .35905 .58286 L F
.315 .76 .962 r
.35905 .58286 m .35977 .58216 L .36128 .58273 L F
.433 .873 .868 r
.35905 .58286 m .35755 .58302 L .35977 .58216 L F
.259 .662 .966 r
.80164 .51754 m .80052 .51667 L .80155 .51772 L F
.677 .758 .268 r
.80117 .51867 m .80164 .51754 L .80155 .51772 L F
.332 .414 .796 r
.80384 .51569 m .80473 .51918 L .80164 .51754 L F
.80384 .51569 m .80164 .51754 L .80117 .51867 L F
0 0 0 r
.57298 .61678 m .57369 .61549 L .57151 .61804 L F
.756 .702 .8 r
.57298 .61678 m .5763 .61719 L .57369 .61549 L F
.312 0 0 r
.52805 .72117 m .53033 .71949 L .52853 .71878 L F
.52805 .72117 m .53017 .72198 L .53033 .71949 L F
.658 .521 .685 r
.64106 .44466 m .64355 .44154 L .64115 .44216 L F
.664 .454 .59 r
.64115 .44216 m .6376 .44158 L .64024 .44056 L F
.64115 .44216 m .63625 .44575 L .6376 .44158 L F
.64115 .44216 m .64106 .44466 L .63625 .44575 L F
.472 .674 .952 r
.64241 .44041 m .64115 .44216 L .64024 .44056 L F
.64241 .44041 m .64115 .44216 L .64024 .44056 L F
.041 .488 .885 r
.36232 .62382 m .36184 .62448 L .36041 .62358 L F
.36232 .62382 m .36421 .6252 L .36184 .62448 L F
.702 .626 .769 r
.3167 .62691 m .31884 .63089 L .31988 .62959 L F
.512 .362 .615 r
.49322 .69308 m .49101 .69356 L .49077 .69052 L F
.557 .583 .836 r
.48935 .68974 m .49322 .69308 L .4932 .69285 L F
.779 .683 .758 r
.49094 .68671 m .49296 .69009 L .49077 .69052 L F
.512 .362 .615 r
.49322 .69308 m .49077 .69052 L .49296 .69009 L F
.557 .583 .836 r
.4917 .68997 m .4932 .69285 L .49296 .69009 L F
.779 .683 .758 r
.49036 .68742 m .49077 .69052 L .49018 .68764 L F
.49086 .68838 m .49077 .69052 L .49036 .68742 L F
.557 .583 .836 r
.48935 .68974 m .4932 .69285 L .4917 .68997 L F
.779 .683 .758 r
.49094 .68671 m .49086 .68838 L .49036 .68742 L F
.854 .956 .611 r
.55319 .68067 m .55285 .68246 L .55468 .67917 L F
.069 0 .441 r
.55319 .68067 m .5517 .68351 L .55285 .68246 L F
.68 .297 .315 r
.47662 .67307 m .4796 .67491 L .48195 .67278 L F
.72 .353 .353 r
.48195 .67278 m .48334 .67517 L .48311 .67205 L F
.48195 .67278 m .4796 .67491 L .48334 .67517 L F
.574 .427 .643 r
.51658 .67304 m .51861 .6698 L .51644 .67037 L F
.51861 .6698 m .51658 .67304 L .51644 .67037 L F
.487 .139 .302 r
.49492 .67092 m .49506 .67241 L .49243 .67286 L F
.702 .587 .723 r
.49847 .67005 m .49492 .67092 L .49517 .66803 L F
.708 .431 .502 r
.49847 .67005 m .49506 .67241 L .49492 .67092 L F
0 .535 .709 r
.39701 .59214 m .39559 .59203 L .39336 .59186 L F
0 0 0 r
.39914 .59145 m .39559 .59203 L .39701 .59214 L F
.141 .611 .924 r
.483 .6606 m .48447 .66148 L .48568 .66129 L F
.141 .547 .924 r
.48568 .66129 m .48447 .66148 L .48621 .66187 L F
.833 .725 .745 r
.59034 .62644 m .5924 .62767 L .59121 .63028 L F
0 0 .409 r
.50129 .69206 m .50083 .69538 L .49996 .69369 L F
.741 .866 .938 r
.78662 .48856 m .78972 .48845 L .78874 .48723 L F
.627 .823 .976 r
.78972 .48845 m .79129 .48642 L .78874 .48723 L F
.78972 .48845 m .79223 .48764 L .79129 .48642 L F
.484 .53 .829 r
.52825 .64109 m .52891 .63744 L .5264 .63987 L F
.52825 .64109 m .53023 .64068 L .52891 .63744 L F
.461 .456 .766 r
.52825 .64109 m .53097 .64391 L .53023 .64068 L F
.636 .568 .761 r
.41842 .59478 m .41973 .59871 L .42185 .59762 L F
.834 .508 .437 r
.55481 .62073 m .55633 .62207 L .55687 .62133 L F
.232 0 .04 r
.55633 .62207 m .55647 .62269 L .55687 .62133 L F
.763 .527 .577 r
.55647 .62269 m .55939 .62082 L .55687 .62133 L F
.753 .72 .822 r
.80462 .49774 m .80552 .49364 L .80301 .49636 L F
.119 0 .417 r
.52347 .66926 m .52191 .67178 L .52267 .67069 L F
.52361 .669 m .52327 .66957 L .52347 .66926 L F
.52327 .66957 m .52191 .67178 L .52347 .66926 L F
.66 .384 .492 r
.52293 .66968 m .52012 .67213 L .5218 .67179 L F
.119 0 .417 r
.5237 .66908 m .52267 .67069 L .52383 .66921 L F
.52361 .669 m .52347 .66926 L .5237 .66908 L F
.52347 .66926 m .52267 .67069 L .5237 .66908 L F
.52361 .669 m .52337 .67147 L .52191 .67178 L F
.66 .384 .492 r
.523 .66997 m .5218 .67179 L .52337 .67147 L F
.52293 .66968 m .5218 .67179 L .523 .66997 L F
.52254 .66814 m .52043 .67161 L .52293 .66968 L F
.52043 .67161 m .52012 .67213 L .52293 .66968 L F
.681 .71 .87 r
.19904 .56876 m .19527 .56716 L .1971 .56651 L F
.744 .776 .878 r
.20135 .5665 m .19904 .56876 L .1971 .56651 L F
0 .447 .816 r
.75117 .49271 m .75424 .49413 L .75254 .49353 L F
.741 .765 .872 r
.59088 .67056 m .59205 .67298 L .59495 .67093 L F
.769 .637 .715 r
.6305 .44813 m .63057 .45065 L .62699 .45036 L F
.77 .553 .605 r
.62699 .45036 m .63057 .45065 L .62897 .4532 L F
.758 .537 .597 r
.63057 .45065 m .63207 .45385 L .62897 .4532 L F
.72 .613 .737 r
.63306 .44726 m .63057 .45065 L .6305 .44813 L F
.683 .787 .929 r
.79311 .47872 m .79079 .47971 L .78968 .47826 L F
.325 .072 .368 r
.49062 .63562 m .49213 .63712 L .4928 .63476 L F
.49062 .63562 m .49039 .6379 L .49213 .63712 L F
.531 .337 .563 r
.72344 .48835 m .72341 .49074 L .72605 .48819 L F
.448 .244 .509 r
.31402 .59815 m .31592 .59765 L .31617 .59506 L F
.392 .189 .481 r
.31592 .59765 m .31814 .59436 L .31617 .59506 L F
.549 .524 .78 r
.42579 .60082 m .42812 .60047 L .42735 .59792 L F
.435 .385 .704 r
.31219 .60341 m .31267 .60704 L .31507 .60541 L F
.39 .325 .663 r
.31331 .60948 m .31507 .60541 L .31267 .60704 L F
.641 .305 .387 r
.45431 .61754 m .45281 .62013 L .4506 .61815 L F
.643 .307 .388 r
.45643 .61977 m .45431 .61754 L .45652 .61841 L F
.45643 .61977 m .45281 .62013 L .45431 .61754 L F
0 0 .427 r
.64831 .44769 m .64903 .44539 L .65077 .44494 L F
.649 .468 .625 r
.65077 .44494 m .65125 .44756 L .64831 .44769 L F
.679 .679 .843 r
.64739 .44518 m .64831 .44769 L .64529 .44764 L F
0 0 .427 r
.64903 .44539 m .64954 .44377 L .65073 .4449 L F
.64903 .44539 m .65073 .4449 L .65077 .44494 L F
.6487 .44644 m .64955 .44649 L .64954 .44377 L F
.64831 .44769 m .64955 .44649 L .6487 .44644 L F
.549 .807 .993 r
.64954 .44377 m .65313 .44433 L .65077 .44494 L F
.423 .315 .627 r
.65314 .44662 m .65077 .44494 L .65313 .44433 L F
.65314 .44662 m .65125 .44756 L .65077 .44494 L F
.763 .549 .608 r
.64954 .44377 m .64955 .44649 L .65314 .44662 L F
.025 .236 .74 r
.65102 .44657 m .64955 .44649 L .64894 .44624 L F
.634 .396 .539 r
.65125 .44756 m .65112 .44967 L .64831 .44769 L F
.091 0 .264 r
.65314 .44662 m .65112 .44967 L .65125 .44756 L F
.65314 .44662 m .65242 .449 L .65112 .44967 L F
.636 .096 0 r
.64955 .44649 m .65242 .449 L .65314 .44662 L F
.025 .236 .74 r
.6513 .44662 m .64955 .44649 L .65102 .44657 L F
.277 .422 .828 r
.64739 .44518 m .64955 .44649 L .64831 .44769 L F
.657 .214 .188 r
.64628 .44639 m .64955 .44649 L .64815 .44565 L F
.64654 .44611 m .64815 .44565 L .64739 .44518 L F
.64628 .44639 m .64815 .44565 L .64654 .44611 L F
.996 .816 .458 r
.41186 .59524 m .41202 .59636 L .41133 .59372 L F
.702 .744 .884 r
.41133 .59372 m .41202 .59636 L .4146 .59428 L F
.695 .591 .735 r
.41202 .59636 m .41588 .5954 L .4146 .59428 L F
.491 .024 .072 r
.44475 .61886 m .44333 .62028 L .44099 .62024 L F
.575 .12 .134 r
.4469 .62019 m .44333 .62028 L .44475 .61886 L F
.676 .153 0 r
.54223 .62106 m .54081 .6212 L .53748 .61905 L F
.776 .298 .098 r
.54409 .62343 m .54081 .6212 L .54223 .62106 L F
.761 .25 0 r
.54541 .624 m .54409 .62343 L .54223 .62106 L F
.769 .499 .527 r
.7385 .48653 m .74157 .48799 L .73974 .48614 L F
.124 0 0 r
.37045 .596 m .36626 .59743 L .36778 .59631 L F
.518 .26 .463 r
.48536 .66971 m .48772 .66934 L .48564 .66748 L F
.559 .251 .403 r
.48564 .66748 m .48772 .66934 L .48807 .66739 L F
.155 0 0 r
.37402 .63863 m .37227 .63984 L .3702 .64023 L F
.015 0 0 r
.37453 .63917 m .37402 .63863 L .37625 .63818 L F
.37453 .63917 m .37227 .63984 L .37402 .63863 L F
.855 .974 .665 r
.54753 .61398 m .54904 .61293 L .54751 .61234 L F
.54753 .61398 m .54742 .61526 L .54904 .61293 L F
.495 .333 .59 r
.31391 .60071 m .31592 .59765 L .31402 .59815 L F
.663 .139 0 r
.51106 .64802 m .51008 .64882 L .50771 .64702 L F
.464 0 0 r
.5136 .64887 m .51008 .64882 L .51106 .64802 L F
.404 .39 .73 r
.34904 .6109 m .34654 .60908 L .34858 .60895 L F
.778 .693 .77 r
.58816 .62952 m .59034 .62644 L .59121 .63028 L F
.883 .461 .188 r
.59121 .63028 m .58781 .63145 L .58816 .62952 L F
.59121 .63028 m .58969 .63022 L .58781 .63145 L F
.59121 .63028 m .59199 .63226 L .58969 .63022 L F
0 .12 .67 r
.79777 .49269 m .79764 .49386 L .79913 .49524 L F
.702 .587 .723 r
.49847 .67005 m .49517 .66803 L .49744 .66706 L F
.708 .431 .502 r
.49847 .67005 m .49725 .67278 L .49506 .67241 L F
.625 .59 .794 r
.49976 .66673 m .49847 .67005 L .49744 .66706 L F
.49976 .66673 m .50077 .66986 L .49847 .67005 L F
.566 .275 .433 r
.50048 .672 m .49847 .67005 L .50077 .66986 L F
.50048 .672 m .49725 .67278 L .49847 .67005 L F
.928 .731 .617 r
.60872 .63473 m .61081 .63284 L .60911 .63202 L F
.60872 .63473 m .61041 .63541 L .61081 .63284 L F
.06 0 0 r
.57818 .59497 m .57709 .59616 L .57453 .59695 L F
.371 0 .146 r
.57818 .59497 m .57902 .59679 L .57709 .59616 L F
.556 .557 .81 r
.58171 .59805 m .58054 .59461 L .57818 .59497 L F
.371 0 .146 r
.57818 .59497 m .58054 .59461 L .57902 .59679 L F
.596 .368 .54 r
.49535 .64695 m .49182 .65016 L .49208 .64674 L F
.49535 .64695 m .49594 .64947 L .49182 .65016 L F
.881 .476 .035 r
.59104 .61535 m .58994 .61441 L .5884 .61066 L F
.931 .92 .78 r
.5881 .61727 m .59104 .61535 L .59006 .61835 L F
.5881 .61727 m .58994 .61441 L .59104 .61535 L F
.588 .052 0 r
.54541 .624 m .54648 .62572 L .54409 .62343 L F
.54541 .624 m .54815 .62555 L .54648 .62572 L F
.557 .314 .503 r
.26611 .8542 m .26724 .85122 L .26475 .85268 L F
.521 .311 .536 r
.26611 .8542 m .26475 .85268 L .26421 .85515 L F
.483 .191 .393 r
.35915 .59805 m .35849 .60034 L .35627 .60073 L F
.402 .071 .285 r
.3615 .59775 m .35849 .60034 L .35915 .59805 L F
.441 .746 .993 r
.5794 .66951 m .58073 .66797 L .57765 .66792 L F
.5794 .66951 m .5823 .66938 L .58073 .66797 L F
.014 .587 .75 r
.39444 .58289 m .39663 .58296 L .39806 .58308 L F
.126 .673 .812 r
.39806 .58308 m .39663 .58296 L .4003 .58296 L F
.575 .239 .362 r
.58535 .58717 m .58752 .58863 L .58882 .58627 L F
.739 .427 .454 r
.58882 .58627 m .58752 .58863 L .591 .58884 L F
.141 .671 .866 r
.25533 .73599 m .25908 .73634 L .25698 .73633 L F
.25533 .73599 m .25908 .73634 L .25698 .73633 L F
.93 .836 .73 r
.49908 .68793 m .50049 .68521 L .50011 .68699 L F
.632 .588 .787 r
.49761 .68422 m .50011 .68699 L .50049 .68521 L F
.414 0 0 r
.572 .59631 m .57453 .59695 L .57096 .59699 L F
.017 .588 .767 r
.36128 .58273 m .36346 .58283 L .36484 .583 L F
.428 .855 .946 r
.36346 .58283 m .36699 .58248 L .36484 .583 L F
.435 .385 .704 r
.31219 .60341 m .31507 .60541 L .31421 .60315 L F
.532 .615 .881 r
.27976 .84003 m .28034 .83744 L .27819 .83757 L F
.27976 .84003 m .28107 .83916 L .28034 .83744 L F
.433 .032 .178 r
.40218 .6296 m .40083 .63176 L .39852 .63195 L F
.441 .054 .208 r
.40441 .62925 m .40083 .63176 L .40218 .6296 L F
.637 .112 0 r
.53748 .61905 m .53695 .62002 L .5344 .61848 L F
.679 .161 0 r
.53748 .61905 m .54081 .6212 L .53695 .62002 L F
.193 .193 .629 r
.76755 .4906 m .76686 .49154 L .76862 .48987 L F
0 0 0 r
.76686 .49154 m .76598 .49298 L .76775 .49184 L F
.83 .954 .897 r
.49816 .65206 m .49586 .65444 L .49996 .65347 L F
.708 .276 .222 r
.49586 .65444 m .4982 .65657 L .49996 .65347 L F
0 0 .555 r
.49996 .65347 m .50067 .65178 L .49816 .65206 L F
.49996 .65347 m .50129 .65372 L .50067 .65178 L F
.592 .371 .55 r
.4982 .65657 m .50129 .65372 L .49996 .65347 L F
.903 .764 .698 r
.60607 .62262 m .60862 .62149 L .60485 .62041 L F
.60607 .62262 m .60784 .62348 L .60862 .62149 L F
.379 .053 .28 r
.46152 .66693 m .46281 .66879 L .46351 .66722 L F
.46152 .66693 m .46062 .66936 L .46281 .66879 L F
.758 .704 .802 r
.63 .44655 m .6305 .44813 L .62724 .44769 L F
.769 .637 .715 r
.6305 .44813 m .62699 .45036 L .62724 .44769 L F
.72 .845 .941 r
.63224 .44565 m .6305 .44813 L .63 .44655 L F
.63224 .44565 m .63306 .44726 L .6305 .44813 L F
.57 .742 .957 r
.42645 .58977 m .42305 .58885 L .42527 .58842 L F
.455 .728 .985 r
.42747 .58837 m .42645 .58977 L .42527 .58842 L F
.42747 .58837 m .42886 .58956 L .42645 .58977 L F
.723 .715 .842 r
.7537 .5174 m .75665 .51904 L .75597 .51635 L F
.701 .719 .863 r
.75597 .51635 m .75665 .51904 L .75959 .51707 L F
.741 .77 .877 r
.76187 .51591 m .75959 .51707 L .76292 .51744 L F
.663 .741 .908 r
.76187 .51591 m .76292 .51744 L .76537 .51656 L F
.716 .687 .82 r
.49744 .66706 m .49517 .66803 L .49426 .66643 L F
.129 .257 .728 r
.73324 .5055 m .73442 .50417 L .73222 .50194 L F
.313 .543 .913 r
.73324 .5055 m .73521 .50582 L .73442 .50417 L F
.58 .657 .89 r
.77225 .5053 m .76837 .50327 L .77088 .5031 L F
.617 .681 .888 r
.77385 .50215 m .77225 .5053 L .77088 .5031 L F
.77385 .50215 m .77471 .50464 L .77225 .5053 L F
.341 0 0 r
.4588 .69856 m .46153 .69901 L .4624 .69867 L F
.421 .793 .994 r
.46281 .69783 m .46475 .69839 L .4624 .69867 L F
.671 .958 .733 r
.46153 .69901 m .46281 .69783 L .4624 .69867 L F
.388 0 0 r
.53837 .63576 m .54169 .63702 L .54169 .6365 L F
.574 .008 0 r
.54169 .63702 m .544 .63833 L .54169 .6365 L F
.685 .484 .608 r
.55939 .62082 m .56242 .62073 L .56209 .61749 L F
.555 .814 .994 r
.56242 .62073 m .55939 .62082 L .56209 .61749 L F
0 0 .319 r
.56449 .61644 m .56209 .61749 L .56484 .61491 L F
0 0 .288 r
.56484 .61491 m .56471 .61772 L .56449 .61644 L F
.518 .327 .561 r
.56209 .61749 m .56471 .61772 L .56484 .61491 L F
.404 .279 .595 r
.56209 .61749 m .56423 .62003 L .56471 .61772 L F
.56209 .61749 m .56242 .62073 L .56423 .62003 L F
.625 .146 .097 r
.58378 .58835 m .58752 .58863 L .58535 .58717 L F
.262 .109 .477 r
.20974 .60887 m .20811 .61186 L .20869 .60985 L F
.883 .915 .515 r
.52483 .66744 m .52361 .669 L .52383 .66921 L F
.559 .362 .571 r
.52109 .66722 m .51861 .6698 L .52254 .66814 L F
0 0 0 r
.51893 .67274 m .52254 .66814 L .51861 .6698 L F
.626 .074 0 r
.52254 .66814 m .52361 .669 L .52109 .66722 L F
.64 .181 .147 r
.52109 .66722 m .52361 .669 L .52483 .66744 L F
.7 .748 .889 r
.75029 .51679 m .75103 .51927 L .7537 .5174 L F
.144 0 0 r
.47039 .66967 m .47376 .66837 L .472 .66914 L F
.187 .712 .859 r
.47376 .66837 m .47455 .66797 L .472 .66914 L F
.47376 .66837 m .47606 .66821 L .47455 .66797 L F
.772 .703 .787 r
.7376 .48559 m .73561 .48747 L .73417 .48473 L F
.507 .569 .853 r
.57886 .63159 m .57919 .63315 L .57675 .63435 L F
.57919 .63315 m .57936 .63394 L .57828 .63411 L F
.57919 .63315 m .57828 .63411 L .57675 .63435 L F
.481 .361 .639 r
.5775 .63579 m .57936 .63394 L .57675 .63435 L F
.5775 .63579 m .57936 .63394 L .57675 .63435 L F
.253 0 0 r
.57936 .63394 m .57946 .63556 L .57675 .63435 L F
.739 .568 .661 r
.57983 .6325 m .58255 .63143 L .58125 .63386 L F
0 0 0 r
.57975 .63256 m .57989 .63242 L .58053 .63152 L F
.57975 .63256 m .58109 .63078 L .57976 .63256 L F
.57971 .63263 m .58118 .63056 L .57886 .63159 L F
.57976 .63256 m .58109 .63078 L .58118 .63056 L F
.739 .568 .661 r
.58054 .63152 m .58255 .63143 L .57983 .6325 L F
0 0 0 r
.57971 .63263 m .58079 .63147 L .57975 .63256 L F
.739 .568 .661 r
.57971 .63263 m .58125 .63386 L .58072 .63388 L F
.57983 .6325 m .58125 .63386 L .57971 .63263 L F
.57886 .63159 m .58072 .63388 L .57936 .63394 L F
0 0 0 r
.57821 .63473 m .58058 .63175 L .57971 .63263 L F
.58058 .63175 m .58079 .63147 L .57971 .63263 L F
.739 .568 .661 r
.57886 .63159 m .57983 .6325 L .57971 .63263 L F
0 0 0 r
.57821 .63473 m .57971 .63263 L .57886 .63159 L F
.739 .568 .661 r
.57886 .63159 m .58054 .63152 L .57983 .6325 L F
.743 .621 .723 r
.58109 .63078 m .58255 .63143 L .58054 .63152 L F
0 0 0 r
.58109 .63078 m .58182 .63007 L .58118 .63056 L F
.94 .572 .21 r
.58204 .62947 m .58251 .62987 L .58182 .63007 L F
.58182 .63007 m .58251 .62987 L .58255 .63143 L F
.473 .669 .949 r
.58185 .62998 m .58102 .62858 L .58118 .63056 L F
.94 .572 .21 r
.58102 .62858 m .58204 .62947 L .58185 .62998 L F
.58102 .62858 m .58204 .62947 L .58182 .63007 L F
.803 .713 .765 r
.58188 .62446 m .58457 .62749 L .58251 .62987 L F
.58188 .62446 m .58251 .62987 L .58102 .62858 L F
.473 .669 .949 r
.58263 .62931 m .58102 .62858 L .58185 .62998 L F
.94 .572 .21 r
.58102 .62858 m .58185 .62998 L .58182 .63007 L F
.58204 .62947 m .58251 .62987 L .58182 .63007 L F
0 0 0 r
.58156 .63077 m .58263 .62931 L .58243 .62948 L F
.58025 .63273 m .58151 .63092 L .58156 .63077 L F
.743 .621 .723 r
.58182 .63007 m .58255 .63143 L .58109 .63078 L F
0 0 0 r
.58151 .63092 m .58263 .62931 L .58156 .63077 L F
.58182 .63007 m .58243 .62948 L .58185 .62998 L F
.58182 .63007 m .58185 .62998 L .58118 .63056 L F
.94 .572 .21 r
.58182 .63007 m .58251 .62987 L .58255 .63143 L F
.743 .621 .723 r
.58174 .62991 m .58182 .63007 L .58109 .63078 L F
0 0 0 r
.58025 .63273 m .58243 .62948 L .58109 .63078 L F
.58053 .63152 m .58079 .63147 L .58109 .63078 L F
.57989 .63242 m .58079 .63147 L .58053 .63152 L F
.811 .724 .769 r
.58118 .63056 m .58102 .62858 L .57886 .63159 L F
.743 .621 .723 r
.58102 .62858 m .58174 .62991 L .57886 .63159 L F
.58174 .62991 m .58054 .63152 L .57886 .63159 L F
0 0 0 r
.57821 .63473 m .58025 .63273 L .58079 .63147 L F
.034 0 .383 r
.57675 .63435 m .57821 .63473 L .57886 .63159 L F
0 .107 .637 r
.57675 .63435 m .57946 .63556 L .57821 .63473 L F
.475 .265 .514 r
.53906 .65012 m .54118 .64968 L .54166 .6472 L F
.408 .217 .506 r
.53906 .65012 m .54096 .65183 L .54118 .64968 L F
.53906 .65012 m .539 .65256 L .54096 .65183 L F
.989 .72 .384 r
.57986 .64927 m .58005 .65186 L .58104 .65127 L F
.255 0 0 r
.58005 .65186 m .58117 .65106 L .58104 .65127 L F
.776 .898 .494 r
.53376 .64609 m .53219 .64944 L .53521 .64829 L F
.651 .774 .939 r
.53376 .64609 m .53521 .64829 L .53752 .64684 L F
.374 .282 .622 r
.76952 .49852 m .76741 .49691 L .76943 .49599 L F
.76952 .49852 m .7679 .49932 L .76741 .49691 L F
.92 .789 .701 r
.5181 .6434 m .5171 .6469 L .5196 .6462 L F
.554 .273 .444 r
.40187 .61774 m .4043 .6175 L .40471 .61498 L F
.362 .108 .389 r
.40471 .61498 m .40632 .61674 L .40753 .61484 L F
.40471 .61498 m .4043 .6175 L .40632 .61674 L F
.558 .844 .998 r
.34707 .64018 m .352 .64181 L .35237 .64108 L F
.4 .855 .873 r
.51603 .66119 m .51731 .66113 L .51672 .65881 L F
.613 .573 .785 r
.51731 .66113 m .51852 .65811 L .51672 .65881 L F
.51731 .66113 m .51978 .66086 L .51852 .65811 L F
.482 .545 .845 r
.31822 .61792 m .31861 .61432 L .31661 .61458 L F
.31822 .61792 m .32016 .61756 L .31861 .61432 L F
.475 0 0 r
.51026 .66582 m .51227 .66465 L .50854 .66473 L F
.377 .083 .333 r
.50938 .66741 m .51227 .66465 L .51178 .66715 L F
0 0 .182 r
.51334 .66138 m .51227 .66465 L .51421 .66407 L F
.41 .181 .453 r
.51178 .66715 m .51227 .66465 L .51421 .66407 L F
0 0 0 r
.51421 .66407 m .51227 .66465 L .51026 .66582 L F
.583 .677 .905 r
.35392 .64358 m .35458 .64064 L .35237 .64108 L F
.35392 .64358 m .35638 .64306 L .35458 .64064 L F
.606 .942 .761 r
.78517 .48033 m .78672 .47875 L .7873 .47897 L F
.175 0 0 r
.37457 .62558 m .37379 .62488 L .37219 .62559 L F
.37457 .62558 m .37597 .62457 L .37379 .62488 L F
.679 .679 .843 r
.64739 .44518 m .64529 .44764 L .64402 .4458 L F
.594 .328 .484 r
.64831 .44769 m .64593 .44958 L .64529 .44764 L F
.575 .621 .861 r
.46362 .70546 m .46607 .70486 L .46737 .7079 L F
.474 .448 .749 r
.46864 .70409 m .46737 .7079 L .46607 .70486 L F
.46864 .70409 m .46918 .70733 L .46737 .7079 L F
.434 .325 .63 r
.46918 .70733 m .46951 .7099 L .46737 .7079 L F
.581 .321 .488 r
.46737 .7079 m .46951 .7099 L .46704 .7102 L F
0 .182 .716 r
.58806 .60368 m .588 .60259 L .5859 .60059 L F
.249 0 .003 r
.58533 .60606 m .58773 .6052 L .58806 .60368 L F
.802 .7 .16 r
.58773 .6052 m .588 .60259 L .58806 .60368 L F
.979 .682 .359 r
.73648 .48637 m .73777 .48812 L .7376 .48559 L F
.655 .921 .624 r
.73909 .48356 m .7376 .48559 L .7385 .48653 L F
.73909 .48356 m .73648 .48637 L .7376 .48559 L F
.425 .188 .449 r
.57881 .59066 m .57685 .58934 L .57574 .59174 L F
.57881 .59066 m .57907 .58867 L .57685 .58934 L F
.498 0 0 r
.51359 .63179 m .51589 .63272 L .5171 .63266 L F
.144 0 0 r
.51589 .63272 m .51914 .63285 L .5171 .63266 L F
.46 .216 .456 r
.26611 .8542 m .2689 .85171 L .26724 .85122 L F
.521 .296 .514 r
.47126 .66106 m .47396 .65823 L .47197 .65915 L F
.648 .325 .411 r
.51441 .68762 m .51645 .68938 L .51669 .68776 L F
.433 0 0 r
.41244 .61438 m .41507 .61436 L .41661 .61311 L F
.255 0 0 r
.41661 .61311 m .41507 .61436 L .41799 .6136 L F
.24 0 0 r
.41661 .61311 m .41799 .6136 L .4188 .61255 L F
.642 .947 .953 r
.7603 .49348 m .75805 .49466 L .7569 .49425 L F
.62 .945 .751 r
.63405 .4459 m .63306 .44726 L .63224 .44565 L F
.63405 .4459 m .63543 .44545 L .63306 .44726 L F
.702 .626 .769 r
.3167 .62691 m .31988 .62959 L .31869 .62668 L F
.54 .603 .865 r
.31988 .62959 m .32109 .62618 L .31869 .62668 L F
.31988 .62959 m .32326 .62961 L .32109 .62618 L F
.86 .689 .669 r
.72822 .48498 m .72948 .48831 L .72783 .48592 L F
.662 .845 .97 r
.72948 .48831 m .72605 .48819 L .72783 .48592 L F
.688 .609 .763 r
.73162 .48544 m .72948 .48831 L .72822 .48498 L F
0 0 .364 r
.56285 .67843 m .56315 .6813 L .56298 .68158 L F
0 0 .076 r
.56315 .6813 m .56235 .68437 L .56298 .68158 L F
.779 .951 .93 r
.80719 .51034 m .80663 .51133 L .80695 .51016 L F
.80799 .5089 m .80956 .50908 L .80663 .51133 L F
.533 .895 .973 r
.81282 .51116 m .81212 .51061 L .80821 .51187 L F
.80829 .51198 m .80821 .51187 L .80728 .51217 L F
.81282 .51116 m .80821 .51187 L .80829 .51198 L F
.619 .855 .988 r
.81093 .50977 m .81212 .51061 L .81125 .50956 L F
.80728 .51217 m .81153 .5108 L .81093 .50977 L F
.81153 .5108 m .81212 .51061 L .81093 .50977 L F
.80728 .51217 m .81093 .50977 L .80838 .5121 L F
.81093 .50977 m .81125 .50956 L .80838 .5121 L F
.823 .914 .9 r
.80838 .5121 m .81026 .50863 L .80766 .51111 L F
.783 .951 .928 r
.81181 .50763 m .80956 .50908 L .80799 .5089 L F
.823 .914 .9 r
.81026 .50863 m .81031 .50852 L .81024 .5086 L F
.81026 .50863 m .81024 .5086 L .80766 .51111 L F
0 0 .421 r
.80746 .51084 m .80838 .5121 L .80766 .51111 L F
.80695 .51016 m .8078 .51131 L .80746 .51084 L F
.8078 .51131 m .80838 .5121 L .80746 .51084 L F
0 .108 .65 r
.80663 .51133 m .80838 .5121 L .80695 .51016 L F
0 0 .421 r
.80695 .51016 m .80766 .51111 L .80624 .50964 L F
.80695 .51016 m .80624 .50964 L .80581 .50919 L F
.779 .951 .93 r
.80799 .5089 m .80719 .51034 L .80695 .51016 L F
0 .108 .65 r
.80663 .51133 m .80728 .51217 L .80838 .5121 L F
0 0 0 r
.55295 .67287 m .54944 .67484 L .54998 .67343 L F
.136 0 0 r
.37338 .59552 m .37189 .596 L .37045 .596 L F
.015 0 0 r
.37581 .59528 m .37189 .596 L .37338 .59552 L F
.391 .68 .975 r
.78114 .50723 m .77798 .506 L .78076 .50562 L F
.627 .803 .967 r
.78336 .50495 m .78114 .50723 L .78076 .50562 L F
.78336 .50495 m .78476 .50639 L .78114 .50723 L F
.704 .579 .712 r
.33425 .6389 m .33602 .63963 L .33659 .63815 L F
.453 .797 .998 r
.4003 .58296 m .40254 .58263 L .40399 .58347 L F
.422 .732 .99 r
.40474 .58217 m .40399 .58347 L .40254 .58263 L F
.40474 .58217 m .40614 .58331 L .40399 .58347 L F
.7 .757 .896 r
.4146 .59428 m .41588 .5954 L .41842 .59478 L F
.872 .758 .734 r
.49557 .73183 m .49358 .73365 L .4955 .73057 L F
.341 0 0 r
.41044 .62641 m .41124 .62784 L .4089 .62837 L F
.41044 .62641 m .41269 .62623 L .41124 .62784 L F
.604 .348 .502 r
.53677 .6545 m .539 .65256 L .53652 .65325 L F
.515 .606 .882 r
.7747 .52001 m .77603 .52282 L .7779 .52099 L F
.496 .575 .865 r
.77603 .52282 m .77882 .52281 L .7779 .52099 L F
.795 .717 .779 r
.58642 .60895 m .58412 .61187 L .58425 .60956 L F
.245 0 .237 r
.48128 .64981 m .48342 .64937 L .48397 .64685 L F
.578 .594 .833 r
.48397 .64685 m .48644 .64669 L .48587 .64557 L F
.017 0 .156 r
.48397 .64685 m .48489 .64804 L .48644 .64669 L F
.48397 .64685 m .48342 .64937 L .48489 .64804 L F
.698 .386 0 r
.58171 .59805 m .58118 .59657 L .58054 .59461 L F
.662 .115 0 r
.58374 .59836 m .58118 .59657 L .58171 .59805 L F
.529 .299 .51 r
.50827 .67607 m .50819 .67835 L .50604 .67828 L F
.894 .699 .633 r
.59862 .61133 m .60155 .60952 L .59982 .60858 L F
.59862 .61133 m .60039 .61225 L .60155 .60952 L F
.59 .565 .793 r
.45267 .60563 m .45169 .60936 L .45056 .60598 L F
.45267 .60563 m .45402 .60885 L .45169 .60936 L F
.455 .504 .82 r
.45518 .61256 m .45169 .60936 L .45402 .60885 L F
0 .053 .563 r
.5859 .60059 m .58557 .6001 L .58374 .59836 L F
.713 .2 .004 r
.5859 .60059 m .58603 .60222 L .58557 .6001 L F
.5859 .60059 m .588 .60259 L .58603 .60222 L F
.646 .497 .667 r
.28609 .8243 m .28533 .82623 L .28765 .82331 L F
.594 .328 .484 r
.64831 .44769 m .64843 .44976 L .64593 .44958 L F
.66 .378 .482 r
.65112 .44967 m .64843 .44976 L .64831 .44769 L F
.33 .344 .724 r
.57323 .61883 m .57298 .61678 L .57151 .61804 L F
.929 .656 .501 r
.56235 .68437 m .56059 .68417 L .55994 .68172 L F
.918 .825 .738 r
.56235 .68437 m .55917 .68691 L .56059 .68417 L F
.93 .716 .232 r
.56176 .68544 m .56235 .68437 L .56059 .68417 L F
.56176 .68544 m .56244 .68742 L .56235 .68437 L F
0 0 0 r
.56235 .68437 m .56276 .68414 L .56176 .68544 L F
.979 .766 .547 r
.55949 .67324 m .55785 .67481 L .55551 .67526 L F
.55949 .67324 m .55932 .67559 L .55785 .67481 L F
.248 .303 .723 r
.55984 .66989 m .56052 .67347 L .55949 .67324 L F
.851 .392 .052 r
.56118 .67186 m .56052 .67347 L .56146 .67117 L F
.57 .392 .602 r
.55949 .67324 m .56203 .6754 L .55932 .67559 L F
.851 .392 .052 r
.56019 .67435 m .56052 .67347 L .56118 .67186 L F
.207 .358 .796 r
.56052 .67347 m .56203 .6754 L .56032 .67395 L F
.56052 .67347 m .56032 .67395 L .55949 .67324 L F
.491 .427 .712 r
.47572 .67654 m .47777 .67599 L .47662 .67307 L F
.286 0 .172 r
.47572 .67654 m .47483 .6781 L .47777 .67599 L F
.801 .354 .18 r
.57341 .64095 m .57529 .64339 L .57683 .64287 L F
.252 0 0 r
.57529 .64339 m .57905 .64316 L .57683 .64287 L F
.589 .523 .749 r
.31949 .63925 m .32136 .63427 L .31984 .63627 L F
0 0 .385 r
.80368 .48378 m .80354 .48557 L .80323 .48183 L F
0 .136 .682 r
.80529 .48637 m .80354 .48557 L .80368 .48378 L F
.80529 .48637 m .80513 .48757 L .80354 .48557 L F
0 0 .448 r
.80394 .48019 m .80268 .47948 L .80176 .47831 L F
.80394 .48019 m .80323 .48183 L .80268 .47948 L F
.266 0 .153 r
.5033 .65544 m .50044 .65769 L .50122 .65618 L F
.193 0 0 r
.3803 .62491 m .37971 .62438 L .37799 .62463 L F
.3803 .62491 m .38211 .62445 L .37971 .62438 L F
0 0 0 r
.49371 .65364 m .49148 .65392 L .49115 .65401 L F
.647 .949 .95 r
.58381 .66925 m .5828 .67056 L .58455 .66965 L F
.381 .572 .913 r
.5823 .66938 m .5828 .67056 L .58381 .66925 L F
.803 .356 .18 r
.591 .58884 m .59467 .59151 L .59281 .5891 L F
.617 .444 .626 r
.53493 .67333 m .53773 .67547 L .53729 .67303 L F
.53493 .67333 m .53525 .67581 L .53773 .67547 L F
.69 .953 .693 r
.78684 .50872 m .78524 .51097 L .78767 .50851 L F
.077 .637 .779 r
.78905 .50888 m .78684 .50872 L .78767 .50851 L F
.657 .578 .755 r
.79014 .50536 m .79041 .50722 L .78772 .50845 L F
.492 .458 .748 r
.79291 .50729 m .79064 .50879 L .79014 .50536 L F
.545 .568 .828 r
.79291 .50729 m .7902 .50841 L .79064 .50879 L F
.7902 .50841 m .78905 .50888 L .79064 .50879 L F
.657 .578 .755 r
.79041 .50722 m .79058 .5084 L .7902 .50841 L F
.78975 .50802 m .7902 .50841 L .78943 .50842 L F
.79041 .50722 m .7902 .50841 L .78975 .50802 L F
.79041 .50722 m .78943 .50842 L .78772 .50845 L F
.78772 .50845 m .79064 .50879 L .78767 .50851 L F
.556 .821 .46 r
.78943 .50842 m .78905 .50888 L .7902 .50841 L F
.657 .578 .755 r
.79058 .5084 m .79064 .50879 L .78772 .50845 L F
.424 .75 .994 r
.78923 .50866 m .78905 .50888 L .78767 .50851 L F
.556 .821 .46 r
.78943 .50842 m .78907 .50886 L .78905 .50888 L F
.424 .75 .994 r
.79064 .50879 m .78905 .50888 L .78923 .50866 L F
.556 .821 .46 r
.78934 .50852 m .78918 .50868 L .78907 .50886 L F
.492 .458 .748 r
.79291 .50729 m .79128 .50615 L .79285 .50484 L F
.79128 .50615 m .79014 .50536 L .79227 .50495 L F
.79128 .50615 m .79227 .50495 L .79285 .50484 L F
.556 .821 .46 r
.79137 .50602 m .79034 .50728 L .78986 .50787 L F
.79029 .50735 m .78986 .50787 L .78934 .50852 L F
.79137 .50602 m .78986 .50787 L .79029 .50735 L F
.79034 .50728 m .78918 .50868 L .78934 .50852 L F
.79137 .50602 m .78907 .50886 L .78943 .50842 L F
.79137 .50602 m .78943 .50842 L .79291 .50729 L F
.78943 .50842 m .7902 .50841 L .79291 .50729 L F
.077 .637 .779 r
.78905 .50888 m .78918 .50868 L .78684 .50872 L F
.245 0 .08 r
.47789 .65447 m .48166 .65078 L .47921 .65223 L F
.545 .639 .894 r
.7937 .52154 m .79565 .52144 L .79516 .51891 L F
.297 .716 .973 r
.54714 .59733 m .55059 .5982 L .54858 .59797 L F
.01 .573 .8 r
.54858 .59797 m .54913 .59783 L .54714 .59733 L F
.54858 .59797 m .55059 .5982 L .54913 .59783 L F
.54 .118 .188 r
.50631 .63109 m .50772 .62901 L .50402 .62967 L F
.709 .323 .315 r
.50631 .63109 m .50982 .62983 L .50772 .62901 L F
.429 .12 .338 r
.52113 .69284 m .51785 .69584 L .51792 .69344 L F
.43 .521 .85 r
.73521 .50582 m .73647 .50889 L .73822 .5068 L F
.426 .514 .846 r
.73647 .50889 m .73945 .50993 L .73822 .5068 L F
.35 .087 .367 r
.46931 .66173 m .46877 .66373 L .47126 .66106 L F
.156 .635 .925 r
.37743 .5822 m .37676 .58272 L .37532 .58176 L F
.37743 .5822 m .37894 .58298 L .37676 .58272 L F
.888 .866 .812 r
.63417 .44342 m .63543 .44545 L .6376 .44158 L F
.713 .184 0 r
.63575 .44616 m .63543 .44545 L .63405 .4459 L F
.584 .454 .669 r
.63543 .44545 m .63625 .44575 L .6376 .44158 L F
.588 .091 .039 r
.63575 .44616 m .63625 .44575 L .63543 .44545 L F
.317 .229 .595 r
.54517 .66413 m .54707 .66623 L .54697 .66372 L F
.54517 .66413 m .54561 .66708 L .54707 .66623 L F
.957 .823 .388 r
.55931 .69003 m .55917 .68691 L .56096 .68833 L F
.576 .357 .547 r
.54166 .6472 m .54387 .64922 L .54252 .64659 L F
.54166 .6472 m .54118 .64968 L .54387 .64922 L F
.636 .666 .862 r
.40457 .59004 m .40883 .59215 L .40755 .5906 L F
.331 .432 .814 r
.40883 .59215 m .40983 .59024 L .40755 .5906 L F
.40883 .59215 m .41056 .5922 L .40983 .59024 L F
.335 .418 .799 r
.40883 .59215 m .41133 .59372 L .41056 .5922 L F
.611 .346 .492 r
.50056 .63188 m .49824 .62978 L .49814 .63213 L F
.50056 .63188 m .50065 .62968 L .49824 .62978 L F
.716 .687 .82 r
.49744 .66706 m .49473 .66652 L .49612 .66643 L F
.652 .906 .981 r
.49887 .6653 m .49744 .66706 L .49976 .66673 L F
.632 .296 .383 r
.49612 .66643 m .49837 .66842 L .49776 .66632 L F
.652 .906 .981 r
.49887 .6653 m .49612 .66643 L .49744 .66706 L F
.686 .743 .895 r
.49887 .6653 m .49612 .66643 L .49713 .66413 L F
.632 .296 .383 r
.49612 .66643 m .49776 .66632 L .49713 .66413 L F
.716 .687 .82 r
.49473 .66652 m .49426 .66643 L .49612 .66643 L F
.464 .294 .565 r
.22681 .56253 m .22466 .5658 L .22485 .56326 L F
.752 .694 .797 r
.47772 .70435 m .47905 .70747 L .48168 .70484 L F
.401 .037 .228 r
.47668 .68616 m .47381 .6891 L .47505 .68773 L F
.363 .795 .967 r
.47839 .68841 m .47831 .6884 L .47617 .68871 L F
.401 .037 .228 r
.47668 .68616 m .47617 .68871 L .47387 .68903 L F
.363 .795 .967 r
.47831 .6884 m .47483 .68821 L .47617 .68871 L F
.401 .037 .228 r
.47387 .68903 m .47617 .68871 L .47381 .6891 L F
.662 .634 .812 r
.4589 .61519 m .45518 .61256 L .45755 .61189 L F
.742 .69 .801 r
.46099 .6124 m .4589 .61519 L .45755 .61189 L F
.661 .571 .743 r
.46099 .6124 m .46153 .6145 L .4589 .61519 L F
.552 .328 .529 r
.46153 .6145 m .45893 .61772 L .4589 .61519 L F
.975 .921 .614 r
.8134 .50697 m .81282 .51116 L .81181 .50763 L F
.8134 .50697 m .81212 .51061 L .81282 .51116 L F
.466 .26 .515 r
.28765 .82331 m .28533 .82623 L .28741 .82617 L F
.28765 .82331 m .28533 .82623 L .28741 .82617 L F
0 .503 .795 r
.19676 .55676 m .19485 .55609 L .19274 .55565 L F
.42 0 0 r
.19676 .55676 m .19843 .5576 L .19485 .55609 L F
.75 .436 .451 r
.49049 .67341 m .48914 .67522 L .48727 .67284 L F
.686 .44 .545 r
.49243 .67286 m .48914 .67522 L .49049 .67341 L F
.653 .245 .26 r
.45652 .61841 m .45884 .6202 L .45643 .61977 L F
.522 .32 .547 r
.45893 .61772 m .45884 .6202 L .45652 .61841 L F
.812 .769 .259 r
.50112 .64679 m .50055 .64861 L .50078 .64885 L F
.569 .106 0 r
.50055 .64861 m .50217 .65063 L .50078 .64885 L F
0 0 0 r
.37922 .59443 m .37793 .59485 L .37581 .59528 L F
.38133 .59409 m .37793 .59485 L .37922 .59443 L F
.39 .325 .663 r
.31331 .60948 m .31494 .60902 L .31507 .60541 L F
.537 .41 .654 r
.31331 .60948 m .31559 .61154 L .31494 .60902 L F
.31331 .60948 m .31337 .61209 L .31559 .61154 L F
.411 .197 .475 r
.54285 .68181 m .54261 .68412 L .54499 .68114 L F
.632 .588 .787 r
.49761 .68422 m .49908 .68793 L .50011 .68699 L F
.74 .629 .736 r
.54058 .71341 m .54318 .71071 L .54011 .7111 L F
.728 .676 .799 r
.5893 .63488 m .59199 .63226 L .59297 .6356 L F
.855 .436 .231 r
.59467 .59151 m .59793 .59447 L .59759 .59247 L F
.639 .39 .525 r
.64593 .44958 m .64253 .45255 L .64275 .45091 L F
.42 .362 .687 r
.22339 .57446 m .224 .57714 L .22236 .57778 L F
.063 0 .406 r
.22332 .57926 m .22236 .57778 L .224 .57714 L F
.22332 .57926 m .2223 .58017 L .22236 .57778 L F
.245 0 .08 r
.47789 .65447 m .48006 .65389 L .48166 .65078 L F
0 0 0 r
.48166 .65078 m .48342 .64937 L .48128 .64981 L F
.48166 .65078 m .48218 .6512 L .48342 .64937 L F
.48166 .65078 m .48006 .65389 L .48218 .6512 L F
.788 .288 0 r
.50819 .67835 m .50501 .6754 L .50604 .67828 L F
.64 .305 .389 r
.4506 .61815 m .45281 .62013 L .45096 .62014 L F
.425 .785 .996 r
.53402 .6413 m .53247 .64041 L .53023 .64068 L F
.636 .413 .563 r
.53097 .64391 m .53402 .6413 L .53023 .64068 L F
.53097 .64391 m .53373 .64374 L .53402 .6413 L F
.143 .617 .923 r
.53402 .6413 m .53426 .64074 L .53384 .64066 L F
.53306 .64075 m .53384 .64066 L .53247 .64041 L F
.53402 .6413 m .53384 .64066 L .53306 .64075 L F
.133 .12 .575 r
.53419 .63671 m .53384 .64066 L .53581 .63829 L F
.555 .342 .546 r
.53402 .6413 m .53623 .64319 L .53432 .64081 L F
.53425 .64076 m .53432 .64081 L .53426 .64074 L F
.53402 .6413 m .53432 .64081 L .53425 .64076 L F
.602 .645 .865 r
.53426 .64074 m .53623 .64319 L .53867 .64258 L F
.46 .221 .464 r
.53381 .64099 m .53482 .64227 L .53577 .64189 L F
.471 .243 .486 r
.53718 .64132 m .53426 .64074 L .53867 .64258 L F
.46 .221 .464 r
.53467 .64107 m .53577 .64189 L .53718 .64132 L F
.53381 .64099 m .53577 .64189 L .53467 .64107 L F
.53393 .64082 m .53718 .64132 L .53581 .63829 L F
.53381 .64099 m .53459 .64106 L .53393 .64082 L F
.591 .305 .452 r
.53426 .64074 m .53435 .64098 L .53432 .64097 L F
.46 .221 .464 r
.53459 .64106 m .53718 .64132 L .53435 .64098 L F
.555 .342 .546 r
.53402 .6413 m .53373 .64374 L .53623 .64319 L F
.471 .243 .486 r
.53718 .64132 m .53482 .64227 L .53435 .64098 L F
.53718 .64132 m .53435 .64098 L .53426 .64074 L F
.46 .221 .464 r
.53435 .64098 m .53718 .64132 L .53393 .64082 L F
.591 .305 .452 r
.53432 .64097 m .53482 .64227 L .53463 .64213 L F
.53435 .64098 m .53482 .64227 L .53432 .64097 L F
.133 .12 .575 r
.53384 .64066 m .53381 .64099 L .53393 .64082 L F
.53384 .64066 m .53393 .64082 L .53385 .64066 L F
.564 .503 .745 r
.53247 .64041 m .53381 .64099 L .53384 .64066 L F
.53247 .64041 m .53384 .64066 L .53419 .63671 L F
.143 .617 .923 r
.53426 .64074 m .53426 .64074 L .53247 .64041 L F
.667 .246 .235 r
.53247 .64041 m .53482 .64227 L .53381 .64099 L F
.591 .305 .452 r
.53385 .64066 m .53463 .64213 L .53247 .64041 L F
.53426 .64074 m .53463 .64213 L .53385 .64066 L F
.133 .12 .575 r
.53385 .64066 m .53393 .64082 L .53407 .64064 L F
.53384 .64066 m .53407 .64064 L .53581 .63829 L F
.954 .739 .574 r
.51707 .6376 m .51835 .64093 L .51859 .63843 L F
.51859 .63843 m .51835 .64093 L .51707 .6376 L F
.51707 .6376 m .51835 .64093 L .51859 .63843 L F
.842 .666 .664 r
.60039 .61225 m .59991 .61467 L .60306 .6152 L F
.895 .485 .217 r
.59991 .61467 m .60292 .6178 L .60306 .6152 L F
.809 .602 .622 r
.60292 .6178 m .60473 .6181 L .60306 .6152 L F
.962 .653 .39 r
.6076 .63093 m .6089 .62984 L .60667 .62869 L F
.6076 .63093 m .60911 .63202 L .6089 .62984 L F
.976 .727 .492 r
.4667 .68625 m .46807 .68471 L .46664 .68377 L F
.438 .776 .997 r
.46664 .68377 m .46807 .68471 L .46901 .68354 L F
.562 .833 .483 r
.46901 .68354 m .46807 .68471 L .4667 .68625 L F
.755 .732 .831 r
.47606 .66821 m .4799 .66799 L .47898 .66552 L F
.83 .637 .643 r
.58891 .64143 m .58499 .64115 L .58681 .63815 L F
.746 .549 .628 r
.58891 .64143 m .58485 .64328 L .58499 .64115 L F
.58891 .64143 m .58838 .64388 L .58485 .64328 L F
.191 0 .314 r
.54022 .61512 m .54046 .61752 L .54167 .61649 L F
0 0 .11 r
.54032 .61473 m .54046 .61752 L .54022 .61512 L F
.685 .825 .386 r
.54145 .61258 m .54032 .61473 L .54022 .61512 L F
.191 0 .314 r
.54022 .61512 m .54167 .61649 L .54032 .61473 L F
.683 .854 .964 r
.79565 .52144 m .80002 .52098 L .79875 .51952 L F
.72 .875 .954 r
.80002 .52098 m .80117 .51867 L .79875 .51952 L F
.80002 .52098 m .80213 .51979 L .80117 .51867 L F
.009 .433 .864 r
.7891 .51329 m .78524 .51097 L .78605 .51267 L F
0 0 .329 r
.78684 .50872 m .78605 .51267 L .78524 .51097 L F
.615 .068 0 r
.56249 .63728 m .55893 .63445 L .55992 .63541 L F
.542 .324 .533 r
.28765 .82331 m .28964 .82552 L .28741 .82617 L F
.28765 .82331 m .28964 .82552 L .28741 .82617 L F
.622 .671 .876 r
.43496 .5907 m .43253 .59153 L .43098 .58869 L F
.62 .655 .863 r
.43496 .5907 m .43569 .59238 L .43253 .59153 L F
.578 .672 .904 r
.78139 .52374 m .78557 .52559 L .78471 .52384 L F
.676 .79 .935 r
.78557 .52559 m .78737 .52312 L .78471 .52384 L F
.78557 .52559 m .78788 .52482 L .78737 .52312 L F
.815 .725 .766 r
.54096 .65183 m .54501 .65402 L .54387 .64922 L F
.848 .635 .614 r
.54096 .65183 m .54476 .65451 L .54501 .65402 L F
0 .13 .655 r
.54387 .64922 m .54501 .65402 L .54561 .65085 L F
0 0 .45 r
.54476 .65451 m .54561 .65085 L .54501 .65402 L F
.131 .299 .767 r
.57385 .65953 m .57559 .66191 L .57344 .65793 L F
.7 .757 .896 r
.4146 .59428 m .41842 .59478 L .41713 .59336 L F
.368 .659 .969 r
.41842 .59478 m .41916 .59343 L .41713 .59336 L F
.269 .535 .917 r
.41842 .59478 m .41993 .59472 L .41916 .59343 L F
.636 .568 .761 r
.41842 .59478 m .42185 .59762 L .41993 .59472 L F
.261 0 .013 r
.46575 .70191 m .46229 .70433 L .46362 .70546 L F
.56 .769 .976 r
.46362 .70546 m .46455 .70369 L .46229 .70433 L F
.46362 .70546 m .46607 .70486 L .46455 .70369 L F
.129 .408 .856 r
.48055 .68438 m .48174 .68455 L .48108 .68313 L F
.247 0 0 r
.36526 .64065 m .36447 .64101 L .36207 .64108 L F
0 0 0 r
.36654 .64038 m .36526 .64065 L .3684 .64021 L F
.36654 .64038 m .36447 .64101 L .36526 .64065 L F
.127 .669 .836 r
.47222 .71914 m .47565 .71927 L .47421 .71918 L F
.84 .683 .688 r
.47198 .72141 m .47565 .71927 L .47222 .71914 L F
.47198 .72141 m .47497 .72262 L .47565 .71927 L F
.314 .786 .929 r
.38112 .58224 m .38486 .58222 L .38246 .58247 L F
.445 .211 .464 r
.4928 .63476 m .49553 .63201 L .49306 .63265 L F
.544 0 0 r
.74097 .48883 m .74157 .48799 L .7385 .48653 L F
.74097 .48883 m .74416 .48936 L .74157 .48799 L F
.799 .555 .569 r
.60292 .6178 m .60485 .62041 L .60473 .6181 L F
.568 .497 .735 r
.43838 .59376 m .43619 .5946 L .43569 .59238 L F
.615 .671 .88 r
.43838 .59376 m .43939 .59535 L .43619 .5946 L F
.261 0 .013 r
.46575 .70191 m .46455 .70369 L .46229 .70433 L F
.267 .282 .69 r
.46662 .69846 m .46732 .70054 L .46575 .70191 L F
.686 .628 .785 r
.46732 .70054 m .46455 .70369 L .46575 .70191 L F
.466 .216 .45 r
.35349 .60329 m .3508 .60598 L .35112 .6037 L F
.901 .721 .649 r
.54511 .61435 m .54742 .61526 L .54753 .61398 L F
.54511 .61435 m .54664 .61771 L .54742 .61526 L F
0 0 0 r
.38356 .62448 m .38778 .62348 L .38551 .62357 L F
.799 .697 .752 r
.55931 .69003 m .55914 .69255 L .5571 .6931 L F
.639 .276 .34 r
.55914 .69255 m .55908 .69485 L .5571 .6931 L F
.163 0 .315 r
.56181 .68974 m .55914 .69255 L .55931 .69003 L F
.56181 .68974 m .56116 .69191 L .55914 .69255 L F
.149 0 .273 r
.56116 .69191 m .55908 .69485 L .55914 .69255 L F
.713 .43 .496 r
.51603 .66119 m .51672 .65881 L .51489 .65915 L F
.861 .48 0 r
.56422 .64074 m .56249 .63728 L .56315 .63848 L F
.794 .603 .643 r
.47378 .70819 m .47306 .71054 L .46951 .7099 L F
.614 .438 .621 r
.46704 .7102 m .46951 .7099 L .46712 .71277 L F
.401 .479 .825 r
.46948 .70405 m .46918 .70733 L .46864 .70409 L F
.46948 .70405 m .47077 .7068 L .46918 .70733 L F
.47077 .7068 m .47099 .70727 L .46994 .70731 L F
.47077 .7068 m .46994 .70731 L .46918 .70733 L F
.794 .603 .643 r
.47378 .70819 m .46951 .7099 L .47093 .70959 L F
.309 0 0 r
.47306 .71054 m .46943 .71216 L .46951 .7099 L F
.532 .455 .715 r
.47099 .70727 m .46951 .7099 L .46918 .70733 L F
.794 .603 .643 r
.47215 .70916 m .47093 .70959 L .47173 .70941 L F
.47378 .70819 m .47093 .70959 L .47215 .70916 L F
.532 .455 .715 r
.47099 .70727 m .47173 .70941 L .46951 .7099 L F
.529 .552 .823 r
.47194 .70549 m .47346 .70638 L .47134 .70671 L F
.47124 .70631 m .47134 .70671 L .47112 .70641 L F
.47107 .70675 m .47346 .70638 L .47126 .70718 L F
.284 .604 .952 r
.47263 .7084 m .47099 .70727 L .47346 .70638 L F
.47263 .7084 m .47173 .70941 L .47099 .70727 L F
.281 .139 .503 r
.47124 .70631 m .47086 .71049 L .47263 .7084 L F
.47114 .70615 m .47112 .70641 L .47124 .70631 L F
.529 .552 .823 r
.47107 .70675 m .47126 .70718 L .47099 .70727 L F
.281 .139 .503 r
.47112 .70641 m .47086 .71049 L .47124 .70631 L F
.529 .552 .823 r
.47112 .70641 m .47134 .70671 L .47077 .7068 L F
.47123 .70628 m .47124 .70631 L .47112 .70641 L F
.47194 .70549 m .47134 .70671 L .47123 .70628 L F
.281 .139 .503 r
.47114 .70615 m .47124 .70631 L .47115 .70595 L F
.192 .067 .47 r
.47099 .70655 m .47114 .70615 L .47095 .70648 L F
.47099 .70655 m .47112 .70641 L .47114 .70615 L F
.529 .552 .823 r
.46948 .70405 m .47002 .70437 L .47015 .7048 L F
0 .377 .812 r
.47141 .70492 m .47346 .70638 L .46948 .70405 L F
.192 .067 .47 r
.47095 .70648 m .47114 .70615 L .47079 .70611 L F
.529 .552 .823 r
.47079 .70611 m .47194 .70549 L .47099 .70655 L F
.173 .406 .847 r
.47079 .70552 m .47114 .70615 L .46948 .70405 L F
0 .377 .812 r
.47079 .70554 m .46948 .70405 L .47114 .70615 L F
.529 .552 .823 r
.47002 .70437 m .47079 .70554 L .47028 .70496 L F
.173 .406 .847 r
.47016 .70435 m .47079 .70552 L .46948 .70405 L F
.736 .724 .84 r
.47013 .70437 m .47022 .70453 L .47016 .70435 L F
.529 .552 .823 r
.47002 .70437 m .47079 .70482 L .47079 .70554 L F
0 .377 .812 r
.47115 .70595 m .47079 .70554 L .47114 .70615 L F
.736 .724 .84 r
.47079 .70611 m .47114 .70615 L .47079 .70552 L F
.529 .552 .823 r
.47079 .70482 m .47194 .70549 L .47079 .70611 L F
.736 .724 .84 r
.47013 .70437 m .47016 .70435 L .47009 .70431 L F
0 .377 .812 r
.47123 .70479 m .47141 .70492 L .47016 .70435 L F
.47123 .70479 m .47016 .70435 L .47009 .70431 L F
.47123 .70479 m .47009 .70431 L .47115 .70595 L F
.173 .406 .847 r
.46952 .7032 m .47016 .70435 L .46948 .70405 L F
0 .377 .812 r
.47009 .70431 m .47016 .70435 L .46948 .70405 L F
.529 .552 .823 r
.47002 .70437 m .47099 .70655 L .47077 .7068 L F
0 .377 .812 r
.47009 .70431 m .46948 .70405 L .47079 .70554 L F
.47009 .70431 m .47079 .70554 L .47115 .70595 L F
.529 .552 .823 r
.46948 .70405 m .47015 .7048 L .47077 .7068 L F
0 .223 .735 r
.46952 .7032 m .46948 .70405 L .46864 .70409 L F
.736 .724 .84 r
.46742 .70574 m .47013 .70437 L .46916 .70363 L F
.47013 .70437 m .47009 .70431 L .46916 .70363 L F
.46742 .70574 m .47079 .70611 L .47022 .70453 L F
.46742 .70574 m .47022 .70453 L .47013 .70437 L F
.529 .552 .823 r
.47028 .70496 m .47079 .70554 L .47079 .70611 L F
.736 .724 .84 r
.47079 .70611 m .47079 .70552 L .47016 .70435 L F
.46916 .70363 m .47016 .70435 L .46952 .7032 L F
.192 .067 .47 r
.4689 .7103 m .47095 .70648 L .46742 .70574 L F
.47095 .70648 m .47079 .70611 L .46742 .70574 L F
.281 .139 .503 r
.47115 .70595 m .47263 .7084 L .47123 .70479 L F
.47124 .70631 m .47263 .7084 L .47115 .70595 L F
.192 .067 .47 r
.46972 .71001 m .47099 .70655 L .4689 .7103 L F
.47099 .70655 m .47095 .70648 L .4689 .7103 L F
.529 .552 .823 r
.47077 .7068 m .47107 .70675 L .47099 .70727 L F
.192 .067 .47 r
.47093 .70669 m .47111 .70659 L .47112 .70641 L F
.47093 .70669 m .47112 .70641 L .47099 .70655 L F
.46923 .71134 m .47086 .71049 L .47111 .70659 L F
.46923 .71134 m .47111 .70659 L .47093 .70669 L F
.558 .362 .572 r
.46951 .7099 m .46943 .71216 L .46712 .71277 L F
.192 .067 .47 r
.46923 .71134 m .46972 .71001 L .4689 .7103 L F
.458 .257 .518 r
.47548 .70977 m .47306 .71054 L .47378 .70819 L F
0 .523 .709 r
.47173 .70941 m .47548 .70977 L .47378 .70819 L F
.494 .7 .961 r
.42044 .58427 m .41955 .58603 L .41902 .58518 L F
.361 .536 .893 r
.42044 .58427 m .42128 .58607 L .41955 .58603 L F
.397 .538 .88 r
.42305 .58885 m .41955 .58603 L .42128 .58607 L F
.894 .732 .673 r
.60471 .62557 m .60784 .62348 L .60607 .62262 L F
.60471 .62557 m .60665 .62651 L .60784 .62348 L F
.409 0 0 r
.33969 .58513 m .34202 .58516 L .34366 .58377 L F
.366 0 0 r
.34202 .58516 m .34589 .58341 L .34366 .58377 L F
.318 .549 .916 r
.50421 .65116 m .50362 .65269 L .50217 .65063 L F
.019 .187 .697 r
.50421 .65116 m .50553 .65491 L .50362 .65269 L F
.504 .313 .555 r
.50553 .65491 m .5033 .65544 L .50362 .65269 L F
.005 0 0 r
.51007 .66832 m .50938 .66741 L .51101 .6679 L F
.51007 .66832 m .50809 .66927 L .50938 .66741 L F
.286 0 0 r
.50938 .66741 m .51178 .66715 L .51101 .6679 L F
.94 .741 .607 r
.58935 .62056 m .59056 .62393 L .58934 .62323 L F
.985 .78 .547 r
.58934 .62323 m .59056 .62393 L .59034 .62644 L F
.342 .551 .911 r
.22271 .55058 m .22229 .5525 L .22074 .55085 L F
.22271 .55058 m .22477 .55318 L .22229 .5525 L F
.44 .645 .944 r
.72877 .49863 m .73028 .49694 L .72719 .49698 L F
.72877 .49863 m .73101 .49855 L .73028 .49694 L F
.877 .764 .26 r
.60906 .66021 m .60923 .66124 L .60961 .65842 L F
0 0 0 r
.61237 .65579 m .61135 .65785 L .60961 .65842 L F
.61135 .65785 m .60906 .66021 L .60961 .65842 L F
.515 .805 .998 r
.22787 .55659 m .22954 .55755 L .2258 .55706 L F
.222 0 0 r
.22787 .55659 m .2317 .55686 L .22954 .55755 L F
.335 0 0 r
.51914 .63285 m .52203 .63389 L .52268 .63376 L F
.434 0 0 r
.52203 .63389 m .52516 .63497 L .52268 .63376 L F
.336 .138 .457 r
.22534 .57104 m .22339 .57446 L .22363 .57183 L F
.647 .319 .402 r
.51459 .69364 m .51427 .69542 L .51199 .69332 L F
.406 .581 .911 r
.44884 .69872 m .45086 .70135 L .45272 .70137 L F
.165 .638 .93 r
.3569 .62257 m .36041 .62358 L .35839 .62338 L F
.463 .418 .722 r
.77048 .50056 m .76837 .50327 L .7679 .49932 L F
.56 .554 .804 r
.77048 .50056 m .77088 .5031 L .76837 .50327 L F
.966 .8 .627 r
.4901 .65259 m .49182 .65016 L .49253 .65251 L F
.901 .86 .791 r
.49594 .64947 m .49253 .65251 L .49182 .65016 L F
.742 .441 0 r
.56853 .64686 m .56889 .64869 L .56743 .64574 L F
.56853 .64686 m .56934 .64987 L .56889 .64869 L F
.286 .783 .755 r
.54238 .68374 m .53791 .68571 L .5378 .68294 L F
.79 .599 .642 r
.54261 .68412 m .54633 .68466 L .54567 .68414 L F
.54261 .68412 m .54333 .68671 L .54633 .68466 L F
.507 .747 .982 r
.54364 .6822 m .54468 .68092 L .54499 .68114 L F
.54324 .68294 m .54349 .68266 L .54442 .68074 L F
.54297 .68366 m .54324 .68294 L .54444 .68183 L F
.54261 .68412 m .54298 .68343 L .54297 .68366 L F
.54298 .68343 m .54324 .68294 L .54297 .68366 L F
.54309 .68327 m .54349 .68266 L .54324 .68294 L F
.54372 .68397 m .54519 .68377 L .54349 .68266 L F
.185 .475 .893 r
.54349 .68266 m .54395 .68401 L .54368 .68373 L F
.54349 .68266 m .54368 .68373 L .54315 .68317 L F
.507 .747 .982 r
.54261 .68412 m .54368 .68373 L .543 .68347 L F
.54261 .68412 m .54295 .68355 L .54324 .68294 L F
.778 .694 .771 r
.53865 .68182 m .5438 .68386 L .53781 .68293 L F
.507 .747 .982 r
.54295 .68355 m .543 .68347 L .54309 .68327 L F
.543 .68347 m .54349 .68266 L .54315 .68317 L F
.543 .68347 m .54315 .68317 L .54309 .68327 L F
.778 .694 .771 r
.5401 .67993 m .54315 .68317 L .53865 .68182 L F
.54315 .68317 m .54368 .68373 L .543 .68347 L F
.54315 .68317 m .543 .68347 L .53865 .68182 L F
.54368 .68373 m .5438 .68386 L .53865 .68182 L F
.507 .747 .982 r
.54261 .68412 m .54372 .68397 L .54368 .68373 L F
.543 .68347 m .54368 .68373 L .54349 .68266 L F
.185 .475 .893 r
.54349 .68266 m .54315 .68317 L .54299 .683 L F
.54301 .68227 m .54299 .683 L .5401 .67993 L F
.54349 .68266 m .54299 .683 L .54301 .68227 L F
.286 .783 .755 r
.54283 .68382 m .54128 .68476 L .54238 .68374 L F
.79 .599 .642 r
.54261 .68412 m .54567 .68414 L .54416 .68391 L F
.286 .783 .755 r
.54395 .68401 m .54255 .6844 L .54283 .68382 L F
.54255 .6844 m .54128 .68476 L .54283 .68382 L F
.54128 .68476 m .53791 .68571 L .54238 .68374 L F
.507 .747 .982 r
.54444 .68183 m .54364 .6822 L .54499 .68114 L F
.54324 .68294 m .54364 .6822 L .54444 .68183 L F
.54364 .6822 m .54442 .68074 L .54468 .68092 L F
.778 .694 .771 r
.53781 .68293 m .54239 .68374 L .5378 .68294 L F
.54239 .68374 m .54395 .68401 L .54238 .68374 L F
.54239 .68374 m .54238 .68374 L .5378 .68294 L F
.5438 .68386 m .54395 .68401 L .53781 .68293 L F
.79 .599 .642 r
.54416 .68391 m .54567 .68414 L .54519 .68377 L F
.375 .03 .246 r
.46351 .66722 m .46563 .66674 L .46659 .6643 L F
.345 0 .219 r
.46563 .66674 m .46877 .66373 L .46659 .6643 L F
.276 .092 .441 r
.21788 .59142 m .21602 .5945 L .21606 .59216 L F
.271 0 0 r
.38999 .62343 m .39225 .62302 L .39394 .62115 L F
.411 0 .108 r
.39225 .62302 m .39617 .6207 L .39394 .62115 L F
0 0 0 r
.78432 .48944 m .78662 .48856 L .78613 .48884 L F
.78432 .48944 m .78613 .48884 L .78366 .48848 L F
.587 .247 .359 r
.63422 .45334 m .63668 .45326 L .63669 .45495 L F
.55 .164 .262 r
.63207 .45385 m .63422 .45334 L .63246 .45465 L F
.6 .231 .314 r
.63246 .45465 m .63422 .45334 L .63669 .45495 L F
.444 0 0 r
.36911 .58167 m .37155 .58227 L .37302 .58171 L F
.037 0 0 r
.37155 .58227 m .37532 .58176 L .37302 .58171 L F
.499 .578 .866 r
.4373 .59044 m .43569 .59238 L .43496 .5907 L F
.4373 .59044 m .43759 .59202 L .43569 .59238 L F
.568 .497 .735 r
.43838 .59376 m .43569 .59238 L .43759 .59202 L F
.547 0 0 r
.73648 .48637 m .7385 .48653 L .73777 .48812 L F
.73648 .48637 m .74007 .48835 L .7385 .48653 L F
.697 .796 .926 r
.73909 .48356 m .7385 .48653 L .74086 .485 L F
.571 .024 0 r
.7385 .48653 m .74007 .48835 L .74097 .48883 L F
.584 .506 .732 r
.51064 .67284 m .51297 .67366 L .51254 .67373 L F
.51297 .67366 m .51352 .67385 L .51254 .67373 L F
.172 0 0 r
.51254 .67373 m .5157 .67363 L .51656 .67305 L F
.51254 .67373 m .51656 .67305 L .51658 .67304 L F
.574 .427 .643 r
.51658 .67304 m .51893 .67274 L .51861 .6698 L F
.507 .262 .478 r
.51893 .67274 m .51646 .67536 L .51658 .67304 L F
.397 0 0 r
.5157 .67363 m .51893 .67274 L .51658 .67304 L F
.574 .427 .643 r
.51861 .6698 m .51893 .67274 L .51658 .67304 L F
.264 .292 .704 r
.45499 .70847 m .45631 .70669 L .45417 .70462 L F
.46 .566 .876 r
.45499 .70847 m .45846 .70989 L .45631 .70669 L F
.533 .068 .095 r
.47161 .68993 m .47505 .68773 L .47381 .6891 L F
.551 .588 .844 r
.7719 .51874 m .7723 .52047 L .77419 .51815 L F
.554 .592 .846 r
.7723 .52047 m .7747 .52001 L .77419 .51815 L F
.559 .641 .888 r
.44102 .59322 m .43939 .59535 L .43838 .59376 L F
.44102 .59322 m .4418 .59508 L .43939 .59535 L F
.746 .768 .871 r
.31148 .62291 m .31348 .62422 L .31466 .62088 L F
.727 .982 .908 r
.60486 .66609 m .60391 .66585 L .60301 .66749 L F
.745 .992 .815 r
.60301 .66749 m .60391 .66585 L .60075 .66851 L F
0 0 0 r
.40753 .61484 m .40894 .61427 L .41004 .61377 L F
.40753 .61484 m .40632 .61674 L .40894 .61427 L F
.639 .801 .961 r
.40982 .58377 m .40614 .58331 L .40843 .5832 L F
.409 .804 .987 r
.40843 .5832 m .41189 .58344 L .40982 .58377 L F
.68 .768 .284 r
.55435 .66931 m .55295 .67287 L .55218 .66995 L F
.35 .167 .487 r
.21202 .60325 m .21152 .60633 L .21002 .60649 L F
.48 .264 .507 r
.21182 .60824 m .21002 .60649 L .21152 .60633 L F
.21182 .60824 m .20974 .60887 L .21002 .60649 L F
.811 .9 .905 r
.54495 .67662 m .54337 .67692 L .54266 .67816 L F
.564 .491 .731 r
.54314 .6727 m .54449 .67613 L .54608 .67496 L F
.722 .945 .954 r
.54608 .67496 m .5445 .67612 L .54495 .67662 L F
.564 .491 .731 r
.54449 .67613 m .54472 .67671 L .54608 .67496 L F
.722 .945 .954 r
.54608 .67496 m .54442 .67603 L .5445 .67612 L F
.653 .751 .922 r
.54337 .67692 m .54399 .6764 L .54373 .67629 L F
.722 .945 .954 r
.54442 .67603 m .54337 .67692 L .54495 .67662 L F
.67 .547 .706 r
.54399 .6764 m .54472 .67671 L .54449 .67613 L F
.54399 .6764 m .54449 .67613 L .54314 .6727 L F
.653 .751 .922 r
.54266 .67816 m .54373 .67629 L .54359 .67623 L F
.54165 .67669 m .54359 .67623 L .54039 .67485 L F
.54266 .67816 m .54359 .67623 L .54165 .67669 L F
.722 .945 .954 r
.54399 .6764 m .54339 .67673 L .54378 .67658 L F
.54339 .67673 m .5429 .67701 L .54378 .67658 L F
.54378 .67658 m .5429 .67701 L .54337 .67692 L F
.653 .751 .922 r
.54266 .67816 m .54472 .67671 L .54399 .6764 L F
.54266 .67816 m .54399 .6764 L .54337 .67692 L F
.811 .9 .905 r
.54337 .67692 m .5429 .67701 L .54266 .67816 L F
.653 .751 .922 r
.54266 .67816 m .5429 .67701 L .54472 .67671 L F
.722 .945 .954 r
.54442 .67603 m .54322 .6768 L .54399 .6764 L F
.54322 .6768 m .5429 .67701 L .54399 .6764 L F
.668 .64 .813 r
.54472 .67671 m .5429 .67701 L .54608 .67496 L F
.538 .379 .614 r
.54322 .6768 m .54607 .67781 L .54608 .67563 L F
.54442 .67603 m .54608 .67563 L .54608 .67496 L F
.54322 .6768 m .54608 .67563 L .54442 .67603 L F
.5429 .67701 m .54306 .67705 L .54322 .6768 L F
.54306 .67705 m .54607 .67781 L .54322 .6768 L F
.67 .547 .706 r
.54039 .67485 m .54359 .67623 L .54314 .6727 L F
.54359 .67623 m .54399 .6764 L .54385 .67582 L F
.54359 .67623 m .54385 .67582 L .54314 .6727 L F
.549 .542 .799 r
.42812 .60047 m .42917 .6032 L .43132 .60285 L F
.469 .504 .812 r
.42917 .6032 m .43237 .60623 L .43132 .60285 L F
.466 .311 .586 r
.3167 .62691 m .3189 .62331 L .31658 .62419 L F
.45 0 0 r
.35533 .6215 m .35471 .62094 L .35476 .61975 L F
.35533 .6215 m .3569 .62257 L .35471 .62094 L F
.904 .698 .614 r
.59775 .59686 m .59933 .60022 L .59917 .59785 L F
.512 .701 .955 r
.79542 .4888 m .79698 .48723 L .79467 .48735 L F
.79542 .4888 m .79723 .48881 L .79698 .48723 L F
.593 .604 .832 r
.79542 .4888 m .79863 .49047 L .79723 .48881 L F
.093 .169 .651 r
.56398 .62269 m .56304 .62416 L .56253 .62134 L F
.56338 .62194 m .56253 .62134 L .56242 .62073 L F
.56398 .62269 m .56253 .62134 L .56338 .62194 L F
.279 .131 .493 r
.56338 .62194 m .56413 .62246 L .56423 .62003 L F
.56288 .62307 m .56413 .62246 L .56338 .62194 L F
.56288 .62307 m .56338 .62194 L .56242 .62073 L F
.56338 .62194 m .56423 .62003 L .56242 .62073 L F
.093 .169 .651 r
.56413 .62246 m .56398 .62269 L .56242 .62073 L F
0 .217 .677 r
.56432 .62476 m .56304 .62416 L .56413 .62246 L F
.56432 .62476 m .56563 .62594 L .56304 .62416 L F
.563 .632 .878 r
.42527 .58842 m .42305 .58885 L .42128 .58607 L F
.686 .502 .633 r
.4908 .67804 m .48885 .68184 L .48818 .68133 L F
.233 .317 .745 r
.49053 .67682 m .49226 .67856 L .4908 .67804 L F
.605 .407 .587 r
.49416 .68025 m .4908 .67804 L .49226 .67856 L F
.49416 .68025 m .48885 .68184 L .4908 .67804 L F
.85 .467 .322 r
.42381 .59724 m .41993 .59472 L .42185 .59762 L F
.497 .577 .866 r
.77974 .50371 m .77798 .506 L .77753 .50397 L F
.543 .643 .899 r
.77974 .50371 m .78076 .50562 L .77798 .506 L F
.601 .903 .985 r
.23894 .72512 m .23939 .72377 L .2411 .72472 L F
.23894 .72512 m .23736 .72461 L .23939 .72377 L F
.23894 .72512 m .23939 .72377 L .2411 .72472 L F
.23894 .72512 m .23736 .72461 L .23939 .72377 L F
.549 .126 .191 r
.48542 .68404 m .48174 .68455 L .48394 .68545 L F
.492 .507 .801 r
.50261 .66924 m .50077 .66986 L .49976 .66673 L F
.494 .276 .512 r
.50261 .66924 m .50048 .672 L .50077 .66986 L F
.664 .595 .768 r
.52595 .65201 m .52981 .65489 L .53038 .65229 L F
.356 .257 .604 r
.53038 .65229 m .53215 .65168 L .53237 .64877 L F
.467 .273 .533 r
.52981 .65489 m .53215 .65168 L .53038 .65229 L F
.48 .825 .542 r
.3189 .62331 m .31957 .62269 L .32158 .62095 L F
.569 .572 .817 r
.32016 .61756 m .32158 .62095 L .32373 .62043 L F
0 0 0 r
.31957 .62269 m .32373 .62043 L .32158 .62095 L F
.565 .602 .849 r
.7687 .51798 m .77049 .5155 L .76791 .516 L F
.7687 .51798 m .7719 .51874 L .77049 .5155 L F
0 0 0 r
.55295 .67287 m .55135 .67411 L .54944 .67484 L F
.68 .768 .284 r
.55435 .66931 m .55338 .67164 L .55295 .67287 L F
.382 .161 .449 r
.55338 .67164 m .55135 .67411 L .55295 .67287 L F
.725 .68 .806 r
.79014 .50536 m .78767 .50851 L .78671 .50488 L F
.481 .21 .426 r
.449 .68146 m .45129 .68103 L .45181 .67893 L F
.602 .419 .607 r
.45129 .68103 m .45379 .67814 L .45181 .67893 L F
.953 .823 .386 r
.51917 .72885 m .51884 .73017 L .51956 .72786 L F
.326 .11 .424 r
.2223 .58017 m .22175 .58259 L .21961 .58307 L F
.359 .062 .319 r
.221 .58477 m .21961 .58307 L .22175 .58259 L F
.221 .58477 m .21901 .58541 L .21961 .58307 L F
0 0 0 r
.61331 .65423 m .61135 .65785 L .61237 .65579 L F
.535 .923 .828 r
.30746 .62336 m .30808 .62261 L .31017 .62196 L F
.106 .41 .86 r
.30746 .62336 m .30928 .62449 L .30808 .62261 L F
.242 0 0 r
.19792 .5441 m .19623 .54379 L .19429 .54438 L F
.608 .383 .55 r
.42182 .61146 m .42429 .61167 L .4244 .60935 L F
.621 .449 .628 r
.42429 .61167 m .42668 .60885 L .4244 .60935 L F
.512 .129 .251 r
.54944 .67484 m .54889 .67772 L .54607 .67781 L F
.289 0 .195 r
.551 .67686 m .54944 .67484 L .55135 .67411 L F
.864 .79 .777 r
.54012 .65809 m .53767 .66086 L .53754 .65848 L F
.683 .787 .929 r
.79311 .47872 m .78968 .47826 L .79212 .47727 L F
.71 .817 .931 r
.79575 .47674 m .79311 .47872 L .79212 .47727 L F
.637 .252 .298 r
.50371 .63122 m .50402 .62967 L .50065 .62968 L F
.52 .146 .271 r
.50631 .63109 m .50402 .62967 L .50371 .63122 L F
.621 .313 .427 r
.51417 .67588 m .51403 .67797 L .51054 .67805 L F
.523 .267 .468 r
.51646 .67536 m .51403 .67797 L .51417 .67588 L F
.873 .477 .28 r
.54294 .59938 m .54443 .59828 L .54354 .59821 L F
.189 0 .295 r
.4544 .67613 m .45379 .67814 L .45598 .67522 L F
.852 .725 .722 r
.47557 .72432 m .47687 .72756 L .47871 .72511 L F
.365 0 0 r
.34589 .58341 m .3477 .58395 L .34943 .58298 L F
.311 0 0 r
.3477 .58395 m .35164 .58303 L .34943 .58298 L F
.592 .326 .482 r
.49534 .65879 m .49488 .66087 L .49254 .6611 L F
.648 .441 .589 r
.4977 .65808 m .49488 .66087 L .49534 .65879 L F
.039 0 0 r
.52302 .64447 m .5205 .64487 L .52244 .6444 L F
0 0 0 r
.52489 .64305 m .52302 .64447 L .52244 .6444 L F
.664 .522 .681 r
.31337 .61209 m .31661 .61458 L .31559 .61154 L F
.31337 .61209 m .31435 .61538 L .31661 .61458 L F
.632 .764 .942 r
.79977 .4781 m .79575 .47674 L .79776 .47637 L F
.319 .591 .942 r
.80104 .47688 m .79977 .4781 L .79776 .47637 L F
.80104 .47688 m .80176 .47831 L .79977 .4781 L F
.741 .765 .872 r
.59088 .67056 m .59495 .67093 L .59342 .66995 L F
.477 .874 .962 r
.59687 .66967 m .59342 .66995 L .59495 .67093 L F
.886 .54 .386 r
.60915 .63704 m .61041 .63541 L .60872 .63473 L F
.60915 .63704 m .61093 .63755 L .61041 .63541 L F
.386 0 .18 r
.52641 .69047 m .52567 .69207 L .52333 .69225 L F
.49 .139 .298 r
.52895 .68999 m .52567 .69207 L .52641 .69047 L F
.259 0 0 r
.35997 .64237 m .36072 .64288 L .35827 .64342 L F
.521 .784 .993 r
.35827 .64342 m .36072 .64288 L .35896 .6417 L F
.467 .291 .558 r
.35896 .6417 m .36141 .64335 L .36072 .64288 L F
.663 .215 .178 r
.36307 .64448 m .35891 .64431 L .36072 .64288 L F
.467 .291 .558 r
.36141 .64335 m .36307 .64448 L .36072 .64288 L F
.259 0 0 r
.36207 .64108 m .36072 .64288 L .35997 .64237 L F
0 0 0 r
.36267 .64164 m .36207 .64108 L .36447 .64101 L F
.36267 .64164 m .36072 .64288 L .36207 .64108 L F
.558 .875 .993 r
.7873 .47897 m .78884 .47748 L .78968 .47826 L F
.59 .948 .873 r
.7873 .47897 m .78672 .47875 L .78884 .47748 L F
.539 .693 .939 r
.32246 .63895 m .32188 .63918 L .31949 .63925 L F
.168 .392 .837 r
.57623 .66667 m .57694 .66575 L .57432 .66386 L F
.061 .231 .726 r
.57623 .66667 m .57765 .66792 L .57694 .66575 L F
.544 .671 .921 r
.5884 .6708 m .59088 .67056 L .58979 .66904 L F
.678 .778 .926 r
.48168 .70484 m .47772 .70435 L .48001 .70392 L F
.752 .694 .797 r
.47772 .70435 m .48168 .70484 L .48001 .70392 L F
.769 .773 .856 r
.63 .44655 m .62547 .44672 L .62842 .44376 L F
.63 .44655 m .62724 .44769 L .62547 .44672 L F
.551 .663 .911 r
.63224 .44565 m .63 .44655 L .62842 .44376 L F
0 0 0 r
.48311 .67205 m .48536 .66971 L .48585 .67261 L F
.373 0 .04 r
.39628 .63242 m .39483 .6342 L .39251 .6344 L F
.214 0 0 r
.39702 .63359 m .39628 .63242 L .39852 .63195 L F
.39702 .63359 m .39483 .6342 L .39628 .63242 L F
.299 .134 .483 r
.20784 .6155 m .20825 .61709 L .20644 .61799 L F
.35 .13 .433 r
.20825 .61709 m .20582 .62021 L .20644 .61799 L F
0 .347 .685 r
.53954 .63615 m .53837 .63576 L .53706 .63483 L F
.53954 .63615 m .54169 .63702 L .53837 .63576 L F
.726 .335 .307 r
.62897 .4532 m .63207 .45385 L .63076 .45498 L F
.55 .164 .262 r
.63207 .45385 m .63246 .45465 L .63076 .45498 L F
.572 .6 .842 r
.57853 .61223 m .58219 .61483 L .57839 .6145 L F
.57853 .61223 m .58095 .61156 L .58219 .61483 L F
.495 .834 .998 r
.58219 .61483 m .58101 .61392 L .57839 .6145 L F
.747 .696 .803 r
.58095 .61156 m .58412 .61187 L .58219 .61483 L F
.423 .275 .575 r
.58412 .61187 m .58433 .61433 L .58219 .61483 L F
.424 .795 .994 r
.58219 .61483 m .58433 .61433 L .58101 .61392 L F
.374 0 0 r
.34501 .63958 m .34633 .63949 L .34707 .64018 L F
.108 .653 .836 r
.19052 .54354 m .19024 .54386 L .18848 .54351 L F
.19052 .54354 m .19233 .54381 L .19024 .54386 L F
.487 .081 .196 r
.329 .58805 m .3313 .58799 L .33224 .58672 L F
.374 .001 .195 r
.3313 .58799 m .33438 .58605 L .33224 .58672 L F
.254 .706 .955 r
.38486 .58222 m .38706 .58228 L .38849 .58297 L F
.462 .816 .997 r
.38706 .58228 m .39073 .58259 L .38849 .58297 L F
.871 .738 .713 r
.62724 .44769 m .62699 .45036 L .62478 .44915 L F
.847 .609 .578 r
.62699 .45036 m .62503 .45207 L .62478 .44915 L F
.62699 .45036 m .62676 .45271 L .62503 .45207 L F
.77 .553 .605 r
.62699 .45036 m .62897 .4532 L .62676 .45271 L F
.73 .754 .872 r
.48889 .68534 m .4868 .68562 L .48816 .68403 L F
.48989 .68713 m .48839 .68639 L .48889 .68534 L F
.48839 .68639 m .4868 .68562 L .48889 .68534 L F
.49018 .68764 m .48945 .6872 L .48989 .68713 L F
.48945 .6872 m .4868 .68562 L .48989 .68713 L F
.49018 .68764 m .48714 .68784 L .4868 .68562 L F
.394 .531 .875 r
.49094 .68671 m .49018 .68764 L .48986 .68708 L F
.49094 .68671 m .48986 .68708 L .48816 .68403 L F
.529 .484 .751 r
.49323 .6861 m .49094 .68671 L .49011 .68382 L F
.845 .587 .548 r
.49323 .6861 m .49233 .68623 L .49094 .68671 L F
.394 .531 .875 r
.49094 .68671 m .48816 .68403 L .49011 .68382 L F
.845 .587 .548 r
.49233 .68623 m .49022 .68656 L .49094 .68671 L F
.651 .522 .693 r
.48788 .68747 m .48935 .68974 L .49094 .68671 L F
.48742 .68759 m .48768 .68788 L .48788 .68747 L F
.48768 .68788 m .48935 .68974 L .48788 .68747 L F
.4876 .68752 m .49094 .68671 L .49022 .68656 L F
.48742 .68759 m .48788 .68747 L .4876 .68752 L F
.48788 .68747 m .49094 .68671 L .4876 .68752 L F
.466 .311 .586 r
.3167 .62691 m .31869 .62668 L .3189 .62331 L F
.975 .687 .295 r
.61284 .64872 m .61353 .64679 L .61291 .64583 L F
.61284 .64872 m .61383 .64962 L .61353 .64679 L F
.824 .47 .386 r
.47071 .71561 m .46788 .71613 L .46712 .71277 L F
.801 .748 .804 r
.46802 .71408 m .46946 .71534 L .46805 .71406 L F
0 0 .341 r
.46712 .71277 m .46787 .71608 L .46716 .71689 L F
.801 .748 .804 r
.46606 .71545 m .46792 .71539 L .46802 .71408 L F
.46792 .71539 m .46946 .71534 L .46802 .71408 L F
0 0 .341 r
.46787 .71608 m .46788 .71613 L .46786 .71615 L F
.46787 .71608 m .46786 .71615 L .46716 .71689 L F
0 .239 .756 r
.46788 .71613 m .46874 .71815 L .46716 .71689 L F
.236 0 0 r
.28503 .83672 m .28304 .83602 L .28254 .83686 L F
.28503 .83672 m .28628 .83715 L .28304 .83602 L F
.495 .139 .292 r
.41874 .62364 m .4174 .62609 L .41506 .62617 L F
.377 0 .097 r
.42111 .6238 m .4174 .62609 L .41874 .62364 L F
.737 .354 0 r
.57053 .6526 m .56998 .65191 L .56924 .64996 L F
.57053 .6526 m .57151 .65491 L .56998 .65191 L F
.77 .691 .776 r
.48702 .69264 m .49101 .69356 L .48935 .68974 L F
.557 .583 .836 r
.48935 .68974 m .49101 .69356 L .49322 .69308 L F
.487 .287 .535 r
.49322 .69308 m .49291 .69505 L .49101 .69356 L F
.419 .118 .347 r
.49101 .69356 m .49044 .69534 L .49322 .69308 L F
.49322 .69308 m .49044 .69534 L .49101 .69356 L F
.906 .928 .547 r
.5558 .69476 m .5571 .6931 L .55587 .69642 L F
.724 .578 .001 r
.55587 .69743 m .5558 .69476 L .55587 .69642 L F
.486 .36 .634 r
.55587 .69642 m .55755 .69613 L .5571 .6931 L F
.252 0 0 r
.55587 .69642 m .55755 .69613 L .55587 .69743 L F
.423 .756 .995 r
.6376 .44158 m .63385 .44079 L .63646 .43809 L F
.888 .866 .812 r
.63417 .44342 m .6376 .44158 L .63675 .44347 L F
.637 .607 .803 r
.63911 .43738 m .6376 .44158 L .63646 .43809 L F
.63911 .43738 m .64024 .44056 L .6376 .44158 L F
.093 0 0 r
.6376 .44158 m .63906 .44215 L .63675 .44347 L F
.6376 .44158 m .64024 .44056 L .63906 .44215 L F
.422 .501 .835 r
.2076 .54418 m .2059 .54538 L .20388 .54487 L F
.2076 .54418 m .2075 .5456 L .2059 .54538 L F
.465 .531 .841 r
.74378 .51484 m .74541 .51252 L .74329 .51277 L F
.74378 .51484 m .74651 .51567 L .74541 .51252 L F
.246 .12 .503 r
.72475 .4874 m .72484 .48731 L .72518 .48715 L F
.487 0 0 r
.72643 .48492 m .73105 .48426 L .72822 .48498 L F
.418 .768 .996 r
.72783 .48592 m .7271 .48539 L .72822 .48498 L F
.7271 .48539 m .72643 .48492 L .72761 .48496 L F
.7271 .48539 m .72761 .48496 L .72822 .48498 L F
.72783 .48592 m .72765 .48498 L .72643 .48492 L F
.644 .685 .874 r
.73105 .48426 m .73162 .48544 L .72822 .48498 L F
.487 0 0 r
.72771 .48474 m .73032 .48513 L .73105 .48426 L F
.72643 .48492 m .7274 .48497 L .72771 .48474 L F
.218 0 0 r
.72628 .48503 m .72658 .48506 L .72643 .48492 L F
.72662 .48509 m .7274 .48513 L .72643 .48492 L F
.487 0 0 r
.7274 .48497 m .72765 .48498 L .72771 .48474 L F
.418 .768 .996 r
.72765 .48498 m .7276 .48469 L .72643 .48492 L F
.246 .12 .503 r
.72716 .48511 m .72628 .48503 L .7276 .48469 L F
.72475 .4874 m .72628 .48503 L .72716 .48511 L F
.218 0 0 r
.72628 .48503 m .72662 .48509 L .72658 .48506 L F
.817 .919 .906 r
.72605 .48819 m .7274 .48513 L .72783 .48592 L F
.72605 .48819 m .72518 .48715 L .72709 .4852 L F
.487 0 0 r
.72643 .48492 m .7274 .48513 L .72797 .485 L F
.817 .919 .906 r
.7274 .48513 m .72709 .4852 L .7276 .48469 L F
.72605 .48819 m .72709 .4852 L .7274 .48513 L F
.487 0 0 r
.72797 .485 m .72985 .48568 L .73032 .48513 L F
.7274 .48513 m .72985 .48568 L .72797 .485 L F
.218 0 0 r
.72662 .48509 m .72985 .48568 L .7274 .48513 L F
.817 .919 .906 r
.7274 .48513 m .7276 .48469 L .72765 .48498 L F
.7274 .48513 m .72765 .48498 L .72783 .48592 L F
.487 0 0 r
.72765 .48498 m .73032 .48513 L .728 .48478 L F
.72765 .48498 m .728 .48478 L .72771 .48474 L F
.246 .12 .503 r
.72484 .48731 m .72691 .48535 L .72595 .48637 L F
.72691 .48535 m .7276 .48469 L .72709 .4852 L F
.72691 .48535 m .72709 .4852 L .72595 .48637 L F
.72484 .48731 m .72595 .48637 L .72518 .48715 L F
.429 .12 .338 r
.52113 .69284 m .52029 .69533 L .51785 .69584 L F
0 0 .136 r
.52229 .69351 m .52113 .69284 L .52333 .69225 L F
.52229 .69351 m .52029 .69533 L .52113 .69284 L F
.099 .442 .879 r
.21933 .54913 m .21865 .5499 L .21703 .54837 L F
.21933 .54913 m .22074 .55085 L .21865 .5499 L F
0 .044 .612 r
.54536 .63995 m .54558 .64148 L .544 .63833 L F
.454 0 0 r
.54558 .64148 m .54824 .64253 L .54792 .64201 L F
.884 .515 .338 r
.54536 .63995 m .54824 .64253 L .54558 .64148 L F
.916 .765 .679 r
.46367 .61847 m .46601 .62091 L .4642 .62026 L F
.91 .564 .373 r
.46601 .62091 m .46451 .62232 L .4642 .62026 L F
.628 .744 .93 r
.4681 .61979 m .46601 .62091 L .46367 .61847 L F
.46 .077 .226 r
.4681 .61979 m .46668 .62079 L .46601 .62091 L F
.4681 .61979 m .46694 .62197 L .46451 .62232 L F
.628 .744 .93 r
.4681 .61979 m .46367 .61847 L .46716 .62055 L F
.601 .613 .835 r
.46549 .61598 m .46715 .62053 L .46367 .61847 L F
.46715 .62053 m .46716 .62055 L .46714 .62054 L F
.46715 .62053 m .46714 .62054 L .46367 .61847 L F
.46 .077 .226 r
.46668 .62079 m .46451 .62232 L .46539 .6215 L F
.46668 .62079 m .46539 .6215 L .46601 .62091 L F
.255 0 0 r
.58005 .65186 m .58295 .65156 L .58117 .65106 L F
.192 0 .371 r
.58117 .65106 m .58455 .64831 L .58607 .64928 L F
.58117 .65106 m .58295 .65156 L .58455 .64831 L F
.529 .396 .644 r
.48478 .69305 m .48702 .69264 L .48686 .68965 L F
.434 .244 .522 r
.48478 .69305 m .48702 .69472 L .48702 .69264 L F
.48478 .69305 m .48464 .6956 L .48702 .69472 L F
.48702 .69472 m .48464 .6956 L .48478 .69305 L F
.323 0 .113 r
.35754 .60169 m .35627 .60073 L .35849 .60034 L F
.35754 .60169 m .35526 .60228 L .35627 .60073 L F
.382 .533 .882 r
.79723 .48881 m .79863 .49047 L .79952 .48927 L F
.124 .674 .78 r
.56667 .59738 m .56516 .59744 L .56633 .59773 L F
.658 .521 .685 r
.64106 .44466 m .64402 .4458 L .64355 .44154 L F
.371 0 0 r
.64379 .44586 m .64402 .4458 L .64106 .44466 L F
.555 .104 .137 r
.64379 .44586 m .64106 .44466 L .64032 .44635 L F
.271 .022 .341 r
.45832 .67229 m .45656 .67312 L .45598 .67522 L F
.739 .287 0 r
.55723 .63244 m .55671 .6322 L .55497 .62923 L F
0 0 .551 r
.55723 .63244 m .5583 .63337 L .55671 .6322 L F
.55723 .63244 m .55893 .63445 L .5583 .63337 L F
.268 0 0 r
.52783 .72513 m .52418 .72702 L .5254 .7247 L F
.52783 .72513 m .52652 .72664 L .52418 .72702 L F
.21 0 .076 r
.53135 .72221 m .5291 .72398 L .53017 .72198 L F
0 0 0 r
.52847 .72567 m .52925 .72312 L .5291 .72396 L F
.52847 .72567 m .5291 .72396 L .52883 .72419 L F
.21 0 .076 r
.5291 .72396 m .52883 .72419 L .52916 .72365 L F
.987 .886 .552 r
.53017 .72198 m .52916 .72365 L .52957 .72267 L F
0 0 0 r
.5291 .72396 m .52916 .72365 L .52957 .72267 L F
.52916 .72365 m .52925 .72312 L .52957 .72267 L F
.987 .886 .552 r
.52916 .72365 m .52883 .72419 L .52957 .72267 L F
0 0 0 r
.5291 .72396 m .52957 .72267 L .52883 .72419 L F
.21 0 .076 r
.5291 .72398 m .52883 .72419 L .5291 .72396 L F
.5291 .72398 m .52916 .72365 L .53017 .72198 L F
0 0 0 r
.52885 .72443 m .52783 .72513 L .52925 .72312 L F
.392 .069 .293 r
.53135 .72231 m .52883 .72419 L .53135 .72221 L F
.53132 .72379 m .52989 .72402 L .53135 .72231 L F
.52989 .72402 m .52883 .72419 L .53135 .72231 L F
.52883 .72419 m .53132 .72379 L .53084 .72311 L F
.52883 .72419 m .52847 .72567 L .53132 .72379 L F
.53132 .72379 m .52847 .72567 L .52883 .72419 L F
.033 0 .232 r
.53084 .72311 m .53003 .7253 L .52847 .72567 L F
.53084 .72311 m .5286 .72554 L .52808 .72621 L F
.5286 .72554 m .52847 .72567 L .52842 .72575 L F
.164 0 .083 r
.52847 .72567 m .52754 .72792 L .52652 .72664 L F
.907 .843 .388 r
.52808 .72621 m .52754 .72792 L .52834 .726 L F
.52808 .72621 m .52834 .726 L .52847 .72567 L F
.654 .357 .457 r
.52808 .72621 m .52754 .72792 L .52472 .72769 L F
.191 0 0 r
.52737 .72674 m .52754 .72665 L .52808 .72621 L F
0 0 .005 r
.53003 .7253 m .52754 .72792 L .52847 .72567 L F
.191 0 0 r
.52754 .72665 m .53003 .7253 L .52808 .72621 L F
.033 0 .232 r
.5286 .72554 m .52842 .72575 L .52808 .72621 L F
.161 .158 .606 r
.52805 .72117 m .52883 .72419 L .52938 .72389 L F
.53043 .72283 m .52938 .72389 L .53084 .72311 L F
.52805 .72117 m .52938 .72389 L .53043 .72283 L F
0 0 0 r
.52847 .72567 m .52801 .72528 L .52885 .72443 L F
.52801 .72528 m .52783 .72513 L .52885 .72443 L F
.52847 .72567 m .52652 .72664 L .52783 .72513 L F
.709 .323 .315 r
.50631 .63109 m .51021 .63115 L .50982 .62983 L F
.59 .033 0 r
.54824 .64253 m .54998 .64349 L .54792 .64201 L F
.827 .42 0 r
.54998 .64349 m .55121 .64625 L .55082 .6456 L F
.552 .328 .529 r
.46153 .6145 m .46156 .6173 L .45893 .61772 L F
.483 .412 .701 r
.4633 .6121 m .46153 .6145 L .46099 .6124 L F
.4633 .6121 m .4635 .61557 L .46153 .6145 L F
.637 .166 .119 r
.46153 .6145 m .46331 .61643 L .46156 .6173 L F
.46153 .6145 m .4635 .61557 L .46331 .61643 L F
.662 .177 .088 r
.31017 .62196 m .30808 .62261 L .31148 .62291 L F
.524 .318 .543 r
.31017 .62196 m .31148 .62291 L .31192 .62075 L F
.417 .474 .811 r
.49501 .66364 m .49426 .66643 L .4931 .6641 L F
.49501 .66364 m .49612 .66643 L .49426 .66643 L F
.723 .808 .338 r
.19371 .56771 m .1971 .56651 L .19527 .56716 L F
.776 .898 .494 r
.53376 .64609 m .53237 .64877 L .53219 .64944 L F
0 .033 .553 r
.53383 .651 m .53219 .64944 L .53237 .64877 L F
.728 .59 .701 r
.5482 .65252 m .55017 .65541 L .54476 .65451 L F
0 .086 .558 r
.55171 .65545 m .5513 .65508 L .5482 .65252 L F
.202 .369 .807 r
.5482 .65252 m .5513 .65508 L .55017 .65541 L F
0 0 0 r
.5513 .65508 m .54986 .65758 L .55017 .65541 L F
.487 .75 .988 r
.79129 .48642 m .79223 .48764 L .79467 .48735 L F
.461 .183 .405 r
.32331 .59145 m .32571 .58973 L .32374 .5902 L F
.495 .333 .59 r
.31391 .60071 m .31602 .60016 L .31592 .59765 L F
.485 .349 .621 r
.31421 .60315 m .31602 .60016 L .31391 .60071 L F
.168 0 0 r
.50771 .64702 m .50624 .64677 L .50418 .64635 L F
.773 .413 .374 r
.51008 .64882 m .50624 .64677 L .50771 .64702 L F
.434 .849 .963 r
.58622 .66865 m .58455 .66965 L .58792 .66873 L F
.58622 .66865 m .58381 .66925 L .58455 .66965 L F
.192 0 .071 r
.31814 .59436 m .32027 .59366 L .32115 .592 L F
.247 0 .099 r
.32115 .592 m .32237 .5929 L .32331 .59145 L F
.32115 .592 m .32027 .59366 L .32237 .5929 L F
.637 .252 .298 r
.50371 .63122 m .50065 .62968 L .50056 .63188 L F
.315 .372 .762 r
.57905 .64316 m .58013 .64681 L .57987 .64615 L F
.75 .648 .747 r
.58233 .64382 m .58013 .64681 L .57905 .64316 L F
.347 .123 .426 r
.58233 .64382 m .58244 .64596 L .58013 .64681 L F
.155 .077 .509 r
.58165 .64508 m .58013 .64681 L .58244 .64596 L F
.58165 .64508 m .57986 .64927 L .58013 .64681 L F
.793 .513 .514 r
.47198 .72141 m .47557 .72432 L .47497 .72262 L F
.639 .39 .525 r
.64593 .44958 m .64516 .45247 L .64253 .45255 L F
.645 .396 .527 r
.64878 .45211 m .64593 .44958 L .64843 .44976 L F
.64878 .45211 m .64516 .45247 L .64593 .44958 L F
0 0 0 r
.48482 .6565 m .4875 .65529 L .48619 .65619 L F
.128 0 0 r
.48512 .65693 m .48619 .65619 L .48509 .65571 L F
.842 .8 .81 r
.48466 .65784 m .48568 .66129 L .48769 .6574 L F
.48466 .65784 m .48769 .6574 L .48619 .65619 L F
.128 0 0 r
.48515 .65837 m .48466 .65784 L .48619 .65619 L F
.48515 .65837 m .48619 .65619 L .48512 .65693 L F
0 0 0 r
.4875 .65529 m .48776 .65517 L .48619 .65619 L F
.969 .704 .477 r
.57853 .61223 m .57839 .6145 L .57707 .61227 L F
.337 0 0 r
.19274 .55565 m .19485 .55609 L .19101 .55603 L F
.657 .72 .895 r
.58393 .64079 m .58233 .64382 L .58289 .64133 L F
.663 .541 .706 r
.5826 .64187 m .58374 .64089 L .58344 .64104 L F
.5826 .64187 m .58344 .64104 L .58409 .64049 L F
.58344 .64104 m .58374 .64089 L .58578 .63877 L F
.58344 .64104 m .58578 .63877 L .58409 .64049 L F
.657 .72 .895 r
.58289 .64133 m .58283 .64156 L .58113 .64255 L F
.58283 .64156 m .58233 .64382 L .58138 .64281 L F
.58283 .64156 m .58138 .64281 L .58113 .64255 L F
.58409 .64049 m .58393 .64079 L .58289 .64133 L F
.663 .541 .706 r
.5826 .64187 m .58279 .64188 L .58374 .64089 L F
.955 .855 .702 r
.58681 .63815 m .58429 .64032 L .58578 .63877 L F
.58681 .63815 m .58499 .64115 L .58422 .64058 L F
.657 .72 .895 r
.58393 .64079 m .58485 .64328 L .58233 .64382 L F
.663 .541 .706 r
.58279 .64188 m .58389 .64196 L .58418 .64076 L F
.58382 .64081 m .58418 .64076 L .58429 .64032 L F
.58279 .64188 m .58418 .64076 L .58382 .64081 L F
.657 .72 .895 r
.58409 .64049 m .58417 .64077 L .58393 .64079 L F
.58417 .64077 m .58485 .64328 L .58393 .64079 L F
.955 .855 .702 r
.58429 .64032 m .58422 .64058 L .58409 .64049 L F
.58681 .63815 m .58422 .64058 L .58429 .64032 L F
.946 .864 .727 r
.58499 .64115 m .58485 .64328 L .58417 .64077 L F
.58422 .64058 m .58417 .64077 L .58409 .64049 L F
.58499 .64115 m .58417 .64077 L .58422 .64058 L F
.663 .541 .706 r
.58431 .6403 m .58438 .64199 L .58578 .63877 L F
.58429 .64032 m .58429 .64037 L .58431 .6403 L F
.58429 .64037 m .58438 .64199 L .58431 .6403 L F
.58389 .64196 m .58438 .64199 L .58429 .64032 L F
.955 .855 .702 r
.58429 .64032 m .58409 .64049 L .58578 .63877 L F
0 0 0 r
.58681 .63815 m .58844 .63694 L .5893 .63488 L F
.44 .835 .625 r
.58578 .63877 m .58844 .63694 L .58681 .63815 L F
0 .21 .724 r
.48727 .67284 m .48779 .67193 L .4858 .67288 L F
.48727 .67284 m .48914 .67522 L .48779 .67193 L F
.663 .741 .908 r
.76187 .51591 m .76537 .51656 L .7643 .51513 L F
.612 .666 .878 r
.76537 .51656 m .7668 .51305 L .7643 .51513 L F
.76537 .51656 m .76791 .516 L .7668 .51305 L F
.634 .765 .942 r
.77882 .52281 m .78139 .52374 L .77973 .52212 L F
.555 .694 .932 r
.78139 .52374 m .78449 .52078 L .77973 .52212 L F
.78139 .52374 m .78471 .52384 L .78449 .52078 L F
.169 0 .284 r
.53283 .61557 m .53261 .61574 L .53307 .61322 L F
.302 .034 .33 r
.53307 .61322 m .53479 .61454 L .53596 .61284 L F
.534 .559 .827 r
.74021 .51187 m .74196 .5094 L .73945 .50993 L F
.74021 .51187 m .74329 .51277 L .74196 .5094 L F
.656 .277 .314 r
.58251 .62987 m .58457 .63183 L .58255 .63143 L F
.451 .303 .588 r
.58251 .62987 m .58451 .62893 L .58457 .63183 L F
.022 .592 .768 r
.35164 .58303 m .35394 .58313 L .35535 .58329 L F
.016 0 0 r
.35394 .58313 m .35755 .58302 L .35535 .58329 L F
.146 .687 .711 r
.38739 .59251 m .38595 .59275 L .38345 .59323 L F
.128 0 0 r
.38975 .59262 m .38595 .59275 L .38739 .59251 L F
.402 .071 .285 r
.3615 .59775 m .3607 .59981 L .35849 .60034 L F
.11 0 0 r
.36403 .59796 m .3607 .59981 L .3615 .59775 L F
.463 .418 .722 r
.77048 .50056 m .7679 .49932 L .76952 .49852 L F
.686 .706 .863 r
.73417 .48473 m .73162 .48544 L .73105 .48426 L F
.647 .475 .637 r
.7891 .51329 m .79192 .51435 L .79142 .51087 L F
.843 .486 .377 r
.5524 .62012 m .55633 .62207 L .55481 .62073 L F
.891 .989 .782 r
.5571 .6931 m .55883 .68951 L .55931 .69003 L F
.693 .906 .554 r
.55883 .68951 m .55661 .69247 L .55733 .69114 L F
0 0 0 r
.55733 .69114 m .55797 .69063 L .55883 .68951 L F
.957 .823 .388 r
.55931 .69003 m .55883 .68951 L .55926 .68894 L F
.891 .989 .782 r
.5571 .6931 m .55661 .69247 L .55883 .68951 L F
0 0 0 r
.55797 .69063 m .56016 .68891 L .55883 .68951 L F
.957 .823 .388 r
.55926 .68894 m .55883 .68951 L .55917 .68691 L F
.138 .303 .769 r
.45951 .71282 m .45924 .71002 L .45846 .70989 L F
.45951 .71282 m .46041 .71174 L .45924 .71002 L F
.082 .216 .705 r
.45951 .71282 m .46137 .71504 L .46041 .71174 L F
.234 .751 .764 r
.39336 .59186 m .39191 .59208 L .38975 .59262 L F
.234 .743 .879 r
.39559 .59203 m .39191 .59208 L .39336 .59186 L F
0 0 0 r
.32846 .63426 m .32746 .63417 L .33012 .63315 L F
.32846 .63426 m .32625 .63489 L .32746 .63417 L F
.653 .593 .775 r
.51852 .65811 m .52145 .65848 L .52233 .65856 L F
.363 .819 .933 r
.52233 .65856 m .5247 .65808 L .52145 .65848 L F
.023 .237 .742 r
.45272 .70137 m .45417 .70462 L .45489 .70347 L F
.019 .232 .738 r
.45417 .70462 m .45631 .70669 L .45489 .70347 L F
.272 0 0 r
.38802 .63493 m .38647 .63636 L .38427 .6367 L F
.312 0 0 r
.39024 .63475 m .38647 .63636 L .38802 .63493 L F
.625 .431 .6 r
.53978 .67276 m .54314 .6727 L .54314 .66987 L F
.413 .198 .474 r
.54314 .66987 m .54528 .66922 L .54561 .66708 L F
.727 .638 .759 r
.54314 .6727 m .54528 .66922 L .54314 .66987 L F
.422 0 0 r
.5524 .62012 m .55647 .62269 L .55633 .62207 L F
.555 0 0 r
.20016 .54398 m .20388 .54487 L .20196 .54374 L F
.412 0 0 r
.46959 .69205 m .47023 .6925 L .46909 .69177 L F
0 .028 .597 r
.52389 .7223 m .5257 .72377 L .52652 .72159 L F
.52389 .7223 m .5254 .7247 L .5257 .72377 L F
.895 .885 .815 r
.62724 .44769 m .62441 .44919 L .62547 .44672 L F
.62724 .44769 m .62478 .44915 L .62441 .44919 L F
.713 .43 .496 r
.51603 .66119 m .51489 .65915 L .51334 .66138 L F
.475 0 0 r
.51026 .66582 m .50854 .66473 L .50896 .66752 L F
.168 .669 .912 r
.35977 .58216 m .36346 .58283 L .36128 .58273 L F
.802 .836 .369 r
.55632 .65533 m .55527 .65758 L .55638 .65796 L F
.169 .401 .844 r
.3546 .61595 m .35351 .61694 L .35204 .61424 L F
0 0 .459 r
.3546 .61595 m .35476 .61975 L .35351 .61694 L F
.611 .664 .877 r
.74728 .51746 m .74887 .51508 L .74651 .51567 L F
.74728 .51746 m .75029 .51679 L .74887 .51508 L F
.816 .438 .34 r
.54676 .62012 m .54869 .62289 L .54998 .62102 L F
.377 0 .179 r
.54869 .62289 m .5524 .62012 L .54998 .62102 L F
.306 .067 .378 r
.45882 .67013 m .45832 .67229 L .46062 .66936 L F
.185 .416 .852 r
.445 .59605 m .44729 .59736 L .44637 .59752 L F
.492 .396 .674 r
.44852 .60037 m .44637 .59752 L .44729 .59736 L F
.44852 .60037 m .44645 .60109 L .44637 .59752 L F
.653 .593 .775 r
.51852 .65811 m .51978 .66086 L .52145 .65848 L F
.834 .367 .074 r
.55096 .62695 m .55018 .62785 L .54815 .62555 L F
0 .116 .587 r
.55165 .62853 m .5532 .62968 L .55018 .62785 L F
.834 .367 .074 r
.55152 .62824 m .55165 .62853 L .55018 .62785 L F
0 .298 .762 r
.55018 .62785 m .5532 .62968 L .55211 .6285 L F
.55018 .62785 m .55211 .6285 L .54872 .62743 L F
.55018 .62785 m .54872 .62743 L .54868 .62741 L F
.834 .367 .074 r
.55096 .62695 m .55152 .62824 L .55018 .62785 L F
.623 .562 .765 r
.45663 .60857 m .45518 .61256 L .45402 .60885 L F
.45663 .60857 m .45755 .61189 L .45518 .61256 L F
.374 .144 .432 r
.44665 .68444 m .44864 .6839 L .449 .68146 L F
.447 .339 .639 r
.44665 .68444 m .44891 .68646 L .44864 .6839 L F
.397 .336 .672 r
.44724 .68698 m .44891 .68646 L .44665 .68444 L F
.834 .985 .872 r
.72605 .48819 m .72341 .49074 L .72361 .48931 L F
.048 .125 .623 r
.72389 .49303 m .72361 .48931 L .72341 .49074 L F
.396 0 0 r
.75117 .49271 m .75374 .49407 L .75424 .49413 L F
.392 0 0 r
.75374 .49407 m .7569 .49425 L .75424 .49413 L F
0 0 .035 r
.51459 .69364 m .51427 .69542 L .51529 .69396 L F
.432 .505 .834 r
.35056 .61092 m .35023 .61446 L .34904 .6109 L F
.35056 .61092 m .35204 .61424 L .35023 .61446 L F
.312 0 0 r
.52805 .72117 m .53183 .72134 L .53017 .72198 L F
.21 0 .076 r
.53135 .72221 m .53017 .72198 L .53183 .72134 L F
.329 .773 .961 r
.39073 .58259 m .39295 .58237 L .39444 .58289 L F
.413 .78 .994 r
.39295 .58237 m .39663 .58296 L .39444 .58289 L F
.633 .399 .546 r
.49789 .69887 m .49447 .69922 L .49649 .69792 L F
.49789 .69887 m .49482 .70138 L .49447 .69922 L F
.49789 .69887 m .49782 .70129 L .49482 .70138 L F
.604 .364 .526 r
.50054 .69864 m .49782 .70129 L .49789 .69887 L F
.44 .665 .957 r
.40457 .59004 m .40592 .58873 L .40383 .58921 L F
.40457 .59004 m .40755 .5906 L .40592 .58873 L F
.174 .207 .656 r
.44818 .69259 m .44846 .69608 L .45004 .69475 L F
.492 .322 .579 r
.44846 .69608 m .45079 .69871 L .45004 .69475 L F
.44846 .69608 m .44884 .69872 L .45079 .69871 L F
0 .452 .722 r
.21174 .54654 m .21134 .54654 L .20961 .54557 L F
.21174 .54654 m .21374 .54709 L .21134 .54654 L F
.4 .211 .506 r
.21369 .60221 m .21152 .60633 L .21202 .60325 L F
0 0 .19 r
.57299 .63615 m .57321 .63743 L .57341 .64095 L F
.57321 .63743 m .57343 .63873 L .57342 .63915 L F
.57321 .63743 m .57342 .63915 L .57341 .64095 L F
.576 .115 0 r
.57437 .64226 m .57341 .64095 L .57355 .64014 L F
.504 .342 .595 r
.5762 .63953 m .57366 .64103 L .57351 .63984 L F
.576 .115 0 r
.57437 .64226 m .57355 .64014 L .57361 .63979 L F
.504 .342 .595 r
.57385 .64091 m .57437 .64226 L .57366 .64103 L F
.576 .115 0 r
.57437 .64226 m .57529 .64339 L .57341 .64095 L F
.504 .342 .595 r
.5762 .63953 m .57437 .64226 L .57385 .64091 L F
.57351 .63984 m .57366 .64103 L .57301 .6399 L F
.527 .558 .83 r
.57346 .63894 m .57301 .6399 L .57343 .63873 L F
.57448 .63672 m .57351 .63984 L .57346 .63894 L F
0 0 .19 r
.57346 .63894 m .57361 .63979 L .57359 .63986 L F
.527 .558 .83 r
.57448 .63672 m .57346 .63894 L .57315 .63686 L F
0 0 .19 r
.57343 .63873 m .57346 .6389 L .57346 .63894 L F
.57346 .6389 m .57361 .63979 L .57346 .63894 L F
.527 .558 .83 r
.57448 .63672 m .5762 .63953 L .57351 .63984 L F
0 0 .19 r
.57343 .63873 m .57359 .63986 L .57341 .64095 L F
.527 .558 .83 r
.57346 .63894 m .57351 .63984 L .57301 .6399 L F
0 0 .36 r
.57301 .6399 m .57361 .63979 L .57343 .63873 L F
.57301 .6399 m .57343 .63873 L .57299 .63615 L F
.527 .558 .83 r
.57343 .63873 m .57301 .6399 L .57315 .63686 L F
.57315 .63686 m .57301 .6399 L .5731 .63687 L F
.548 .332 .539 r
.53139 .64644 m .53373 .64374 L .53097 .64391 L F
.397 .218 .518 r
.21602 .5945 m .21582 .59688 L .21397 .59742 L F
.455 .308 .592 r
.21608 .59967 m .21397 .59742 L .21582 .59688 L F
.21608 .59967 m .21395 .60099 L .21397 .59742 L F
.694 .715 .865 r
.445 .59605 m .4418 .59508 L .44398 .59466 L F
.278 .421 .827 r
.44702 .59558 m .445 .59605 L .44398 .59466 L F
.44702 .59558 m .44729 .59736 L .445 .59605 L F
.461 .039 .151 r
.41799 .6136 m .42182 .61146 L .4188 .61255 L F
.41799 .6136 m .42049 .61348 L .42182 .61146 L F
.601 .211 .275 r
.42049 .61348 m .42429 .61167 L .42182 .61146 L F
.645 .934 .675 r
.58994 .6338 m .59143 .63281 L .5893 .63488 L F
0 0 .105 r
.58976 .63551 m .58994 .6338 L .5893 .63488 L F
.917 .582 .117 r
.58976 .63551 m .58922 .63428 L .58994 .6338 L F
.58922 .63428 m .58872 .63316 L .58994 .6338 L F
.645 .934 .675 r
.58994 .6338 m .59199 .63226 L .59143 .63281 L F
0 0 .105 r
.58976 .63551 m .5893 .63488 L .58844 .63694 L F
.551 .666 .913 r
.33894 .63567 m .34361 .6379 L .3411 .63525 L F
.273 .558 .93 r
.34361 .6379 m .34418 .6366 L .3411 .63525 L F
0 .001 .561 r
.34361 .6379 m .34501 .63958 L .34418 .6366 L F
.732 .297 .217 r
.78605 .51267 m .78795 .5138 L .7891 .51329 L F
.537 0 0 r
.79061 .5148 m .7891 .51329 L .78795 .5138 L F
.79061 .5148 m .79192 .51435 L .7891 .51329 L F
.411 .176 .444 r
.449 .68146 m .45079 .68321 L .45129 .68103 L F
.449 .68146 m .44864 .6839 L .45079 .68321 L F
.733 .527 .613 r
.5318 .67828 m .53544 .67844 L .53525 .67581 L F
.615 .438 .619 r
.53525 .67581 m .53544 .67844 L .53773 .67547 L F
.599 .184 .227 r
.5517 .68351 m .54974 .6854 L .54853 .68405 L F
.069 0 .441 r
.55319 .68067 m .5532 .68315 L .5517 .68351 L F
0 0 0 r
.5532 .68315 m .54974 .6854 L .5517 .68351 L F
.763 .527 .577 r
.55647 .62269 m .55919 .6229 L .55939 .62082 L F
.666 .43 .553 r
.55919 .6229 m .56242 .62073 L .55939 .62082 L F
.642 .947 .953 r
.7603 .49348 m .7569 .49425 L .75921 .49378 L F
.351 .819 .91 r
.76181 .49275 m .7603 .49348 L .75921 .49378 L F
.76181 .49275 m .76279 .49295 L .7603 .49348 L F
.034 .604 .742 r
.76279 .49295 m .76548 .49293 L .76598 .49298 L F
.447 .879 .806 r
.76598 .49298 m .76548 .49293 L .76775 .49184 L F
.613 .282 .386 r
.63668 .45326 m .63929 .45487 L .63669 .45495 L F
.63668 .45326 m .64004 .45286 L .63929 .45487 L F
.922 .862 .764 r
.59861 .60493 m .60006 .60628 L .60112 .60373 L F
.855 .73 .725 r
.59861 .60493 m .59982 .60858 L .60006 .60628 L F
.717 .727 .859 r
.46074 .61106 m .46099 .6124 L .45755 .61189 L F
.548 .509 .765 r
.46223 .60841 m .46099 .6124 L .46074 .61106 L F
.46223 .60841 m .4633 .6121 L .46099 .6124 L F
.897 .745 .685 r
.5881 .61727 m .59006 .61835 L .58935 .62056 L F
.593 .76 .958 r
.49053 .67682 m .487 .67626 L .48914 .67522 L F
0 .103 .64 r
.49141 .67724 m .49053 .67682 L .48914 .67522 L F
.49141 .67724 m .49226 .67856 L .49053 .67682 L F
.195 .277 .722 r
.72468 .49673 m .72613 .49506 L .72389 .49303 L F
.414 .611 .93 r
.72468 .49673 m .72719 .49698 L .72613 .49506 L F
.732 .721 .841 r
.6434 .43033 m .64465 .43301 L .64119 .43274 L F
.474 0 0 r
.64119 .43274 m .64465 .43301 L .64326 .43375 L F
.523 .719 .962 r
.64588 .43106 m .64465 .43301 L .6434 .43033 L F
.64588 .43106 m .64745 .43293 L .64465 .43301 L F
.64465 .43301 m .64588 .43106 L .64326 .43375 L F
.64465 .43301 m .64745 .43293 L .64588 .43106 L F
.792 .65 .704 r
.58693 .62596 m .58816 .62952 L .58451 .62893 L F
.792 .502 .498 r
.58451 .62893 m .58816 .62952 L .58781 .63145 L F
.725 .615 .735 r
.58693 .62596 m .59034 .62644 L .58816 .62952 L F
.623 .395 .551 r
.48818 .68133 m .48542 .68404 L .48509 .68152 L F
.744 .776 .878 r
.20135 .5665 m .1971 .56651 L .1994 .56625 L F
.839 .941 .891 r
.20135 .5665 m .1994 .56625 L .2014 .56449 L F
.686 .44 .545 r
.49243 .67286 m .49207 .67556 L .48914 .67522 L F
.569 .335 .522 r
.49508 .67475 m .49243 .67286 L .49506 .67241 L F
.49508 .67475 m .49207 .67556 L .49243 .67286 L F
.444 .44 .76 r
.22733 .56735 m .22564 .56915 L .22466 .5658 L F
.134 0 .419 r
.22733 .56735 m .22534 .57104 L .22564 .56915 L F
.741 .575 .669 r
.53729 .67303 m .53773 .67547 L .53978 .67276 L F
.701 .519 .639 r
.53978 .67276 m .53773 .67547 L .54039 .67485 L F
.67 .547 .706 r
.54039 .67485 m .54314 .6727 L .53978 .67276 L F
.382 .172 .465 r
.3508 .60598 m .34858 .60895 L .3486 .60664 L F
.652 .965 .914 r
.55171 .65545 m .55299 .6538 L .5513 .65508 L F
0 0 0 r
.55171 .65545 m .55047 .65704 L .55299 .6538 L F
.783 .705 .777 r
.46874 .71815 m .47222 .71914 L .4701 .71894 L F
.765 .646 .731 r
.4701 .71894 m .46996 .72251 L .46628 .72129 L F
.693 .726 .876 r
.46874 .71815 m .4701 .71894 L .46649 .71871 L F
.765 .646 .731 r
.4701 .71894 m .46628 .72129 L .46649 .71871 L F
.891 .743 .238 r
.47175 .72038 m .47222 .71914 L .46874 .71815 L F
.47175 .72038 m .47198 .72141 L .47222 .71914 L F
.215 0 0 r
.54712 .66035 m .54226 .66253 L .54212 .6602 L F
.359 .618 .95 r
.57559 .66191 m .57526 .66016 L .57344 .65793 L F
.57559 .66191 m .57666 .662 L .57526 .66016 L F
.769 .679 .764 r
.57965 .62029 m .58089 .62363 L .57732 .62322 L F
.524 0 0 r
.57732 .62322 m .58089 .62363 L .58016 .62446 L F
.374 .557 .904 r
.57965 .62029 m .58228 .62263 L .58089 .62363 L F
.625 .083 0 r
.58089 .62363 m .58188 .62446 L .58016 .62446 L F
.391 0 .143 r
.50306 .64811 m .50112 .64679 L .50418 .64635 L F
.50306 .64811 m .50055 .64861 L .50112 .64679 L F
.262 .109 .477 r
.20974 .60887 m .20948 .61131 L .20811 .61186 L F
.058 .013 .485 r
.20923 .61361 m .20811 .61186 L .20948 .61131 L F
.20923 .61361 m .20784 .6155 L .20811 .61186 L F
.441 .054 .208 r
.40441 .62925 m .40321 .6315 L .40083 .63176 L F
.41 .04 .222 r
.40662 .62876 m .40321 .6315 L .40441 .62925 L F
.506 .435 .711 r
.44852 .60037 m .44898 .60278 L .44645 .60109 L F
.325 .44 .824 r
.44645 .60109 m .44898 .60278 L .44757 .6024 L F
.64 .695 .885 r
.77753 .50397 m .77471 .50464 L .77385 .50215 L F
0 .011 .584 r
.5654 .64378 m .5656 .64285 L .56422 .64074 L F
0 .237 .753 r
.5654 .64378 m .56743 .64574 L .5656 .64285 L F
.477 .874 .962 r
.59687 .66967 m .5958 .66922 L .59342 .66995 L F
.565 .896 .984 r
.59915 .66888 m .5958 .66922 L .59687 .66967 L F
0 0 0 r
.39914 .59145 m .39855 .59162 L .39559 .59203 L F
.632 .962 .895 r
.40176 .59005 m .39999 .5902 L .39914 .59145 L F
.648 .936 .679 r
.39999 .5902 m .39855 .59162 L .39914 .59145 L F
.783 .951 .928 r
.81181 .50763 m .80799 .5089 L .81072 .50627 L F
.592 .807 .982 r
.8134 .50697 m .81181 .50763 L .81072 .50627 L F
.418 .313 .628 r
.55908 .69485 m .55755 .69613 L .5571 .6931 L F
.676 .248 .225 r
.5571 .6931 m .55908 .69485 L .5558 .69476 L F
.5571 .6931 m .5558 .69476 L .55661 .69247 L F
.5571 .6931 m .55908 .69485 L .5558 .69476 L F
.28 0 0 r
.37841 .63762 m .37453 .63917 L .37625 .63818 L F
.549 .819 .996 r
.80213 .51979 m .8038 .51818 L .80117 .51867 L F
.80213 .51979 m .80473 .51918 L .8038 .51818 L F
.064 .206 .701 r
.54212 .6602 m .54012 .65809 L .5424 .65824 L F
.895 .485 .217 r
.59991 .61467 m .60101 .6169 L .60292 .6178 L F
.862 .693 .67 r
.60101 .6169 m .60296 .62031 L .60292 .6178 L F
.799 .555 .569 r
.60292 .6178 m .60296 .62031 L .60485 .62041 L F
.855 .464 .301 r
.49256 .70365 m .49179 .70409 L .49089 .70164 L F
0 0 .458 r
.49089 .70164 m .49179 .70409 L .49113 .70038 L F
.704 .498 .607 r
.58705 .64532 m .58485 .64328 L .58838 .64388 L F
.573 .272 .419 r
.64253 .45255 m .63929 .45487 L .64004 .45286 L F
0 0 .013 r
.52732 .68151 m .52526 .68461 L .52653 .68297 L F
.323 .061 .352 r
.52353 .68657 m .52653 .68297 L .52526 .68461 L F
.69 .728 .88 r
.75597 .51635 m .75959 .51707 L .75833 .5155 L F
.735 .741 .857 r
.75833 .5155 m .75959 .51707 L .76187 .51591 L F
.922 .862 .764 r
.59861 .60493 m .60112 .60373 L .59928 .60268 L F
.734 .839 .929 r
.78671 .50488 m .78476 .50639 L .78336 .50495 L F
.25 0 0 r
.36421 .6252 m .36627 .6257 L .3677 .62588 L F
.512 .894 .96 r
.3677 .62588 m .36627 .6257 L .36867 .62484 L F
.666 .43 .553 r
.55919 .6229 m .56288 .62307 L .56242 .62073 L F
.093 .169 .651 r
.56413 .62246 m .56242 .62073 L .56423 .62003 L F
.371 .811 .956 r
.39663 .58296 m .39889 .58257 L .4003 .58296 L F
.435 .831 .982 r
.39889 .58257 m .40254 .58263 L .4003 .58296 L F
.229 .487 .894 r
.77036 .48702 m .77055 .4872 L .76974 .48868 L F
.437 .85 .682 r
.77126 .48841 m .76928 .48951 L .76974 .48868 L F
.77126 .48841 m .76774 .49049 L .76862 .48987 L F
.76774 .49049 m .76755 .4906 L .76862 .48987 L F
0 0 .032 r
.76862 .48987 m .76775 .49184 L .76928 .4894 L F
.437 .85 .682 r
.76928 .48951 m .76862 .48987 L .76974 .48868 L F
0 0 .032 r
.76862 .48987 m .76928 .4894 L .76974 .48868 L F
.453 0 0 r
.76974 .48868 m .77369 .48769 L .77126 .48841 L F
.76974 .48868 m .77136 .48915 L .77369 .48769 L F
.77136 .48915 m .77325 .48971 L .77353 .48838 L F
.77136 .48915 m .77353 .48838 L .77369 .48769 L F
.229 .487 .894 r
.77055 .4872 m .77325 .48971 L .76974 .48868 L F
0 0 0 r
.76974 .48868 m .76816 .49118 L .76921 .49004 L F
.76816 .49118 m .76775 .49184 L .76921 .49004 L F
.576 .942 .846 r
.76939 .48985 m .76921 .49004 L .76902 .48998 L F
.662 .746 .253 r
.77036 .48702 m .76974 .48868 L .76921 .49004 L F
0 0 .324 r
.77036 .48702 m .76921 .49004 L .7708 .48858 L F
.576 .942 .846 r
.76944 .48983 m .76921 .49004 L .76939 .48985 L F
.7708 .48858 m .76944 .48983 L .76868 .48989 L F
.76944 .48983 m .76902 .48998 L .76868 .48989 L F
.035 .244 .745 r
.45966 .6976 m .4588 .69856 L .45742 .69548 L F
.305 .657 .972 r
.45966 .6976 m .46153 .69901 L .4588 .69856 L F
.825 .359 0 r
.55161 .64942 m .55286 .65163 L .55409 .65247 L F
.71 .241 .135 r
.55299 .6538 m .55409 .65247 L .55286 .65163 L F
.55299 .6538 m .55639 .65451 L .55409 .65247 L F
.992 .872 .537 r
.56176 .68544 m .56181 .68974 L .56244 .68742 L F
.779 .683 .758 r
.49094 .68671 m .48935 .68974 L .49296 .69009 L F
.029 .56 .856 r
.49396 .69124 m .49721 .69218 L .49536 .69186 L F
.49721 .69218 m .49772 .69233 L .49536 .69186 L F
.495 .351 .615 r
.49536 .69186 m .49322 .69308 L .49308 .69148 L F
.49536 .69186 m .49308 .69148 L .49296 .69009 L F
.49536 .69186 m .49322 .69308 L .49296 .69009 L F
0 0 .409 r
.50129 .69206 m .50218 .69447 L .50083 .69538 L F
.234 .345 .773 r
.73222 .50194 m .73358 .50048 L .73101 .49855 L F
.188 .272 .72 r
.73222 .50194 m .73442 .50417 L .73358 .50048 L F
.566 .303 .477 r
.42917 .62041 m .42667 .62239 L .42691 .62061 L F
.06 0 0 r
.53005 .67926 m .52732 .68151 L .52958 .68024 L F
.57 .309 .481 r
.52958 .68024 m .5318 .67828 L .53005 .67926 L F
.604 .083 0 r
.20002 .55791 m .20186 .5596 L .19843 .5576 L F
.804 .787 .837 r
.2016 .55719 m .20258 .55807 L .20175 .55703 L F
.247 .139 .529 r
.20258 .55807 m .20002 .55791 L .20385 .55922 L F
.542 .554 .817 r
.20002 .55791 m .20255 .56023 L .20448 .55944 L F
.804 .787 .837 r
.20062 .55824 m .20258 .55807 L .2016 .55719 L F
.247 .139 .529 r
.20258 .55807 m .20385 .55922 L .20448 .55944 L F
.20258 .55807 m .20186 .5596 L .20002 .55791 L F
.635 .501 .681 r
.49254 .6611 m .4931 .6641 L .49024 .66408 L F
.601 .299 .429 r
.4931 .6641 m .4925 .66604 L .49024 .66408 L F
.635 .501 .681 r
.49254 .6611 m .4931 .6641 L .49024 .66408 L F
.484 .319 .581 r
.49035 .66657 m .4925 .66604 L .49024 .66408 L F
.713 .611 .742 r
.49254 .6611 m .49024 .66408 L .49007 .66172 L F
.65 .472 .63 r
.42668 .60885 m .42983 .61106 L .43009 .60903 L F
.547 .361 .58 r
.43009 .60903 m .43253 .60868 L .43237 .60623 L F
.695 .5 .62 r
.42983 .61106 m .43253 .60868 L .43009 .60903 L F
.428 .855 .946 r
.36346 .58283 m .36565 .58224 L .36699 .58248 L F
.045 0 0 r
.36565 .58224 m .36911 .58167 L .36699 .58248 L F
.703 .75 .888 r
.79516 .51891 m .79565 .52144 L .79875 .51952 L F
0 0 .48 r
.46632 .6891 m .46689 .69005 L .4667 .68625 L F
.638 .365 .488 r
.62897 .4532 m .62864 .45486 L .62676 .45271 L F
.62897 .4532 m .63076 .45498 L .62864 .45486 L F
.487 .508 .805 r
.57263 .62769 m .57528 .62882 L .57346 .62957 L F
.278 .762 .668 r
.57346 .62957 m .57528 .62882 L .57307 .62971 L F
.309 0 0 r
.47306 .71054 m .47116 .71239 L .46943 .71216 L F
.799 .719 .776 r
.47532 .71227 m .47298 .71575 L .47116 .71239 L F
.973 .712 .475 r
.47116 .71239 m .47298 .71575 L .47179 .71427 L F
.336 .234 .588 r
.47179 .71427 m .47364 .71409 L .4736 .71377 L F
.637 .179 .147 r
.47532 .71227 m .47204 .71236 L .47306 .71054 L F
.336 .234 .588 r
.4725 .71278 m .4736 .71377 L .47326 .71122 L F
.47179 .71427 m .4736 .71377 L .4725 .71278 L F
.637 .179 .147 r
.47204 .71236 m .47116 .71239 L .4716 .71196 L F
.47204 .71236 m .4716 .71196 L .47306 .71054 L F
.468 .281 .543 r
.47548 .70977 m .47532 .71227 L .47306 .71054 L F
.443 .507 .83 r
.45056 .60598 m .44757 .6024 L .44898 .60278 L F
.368 .819 .94 r
.45107 .60499 m .45056 .60598 L .44898 .60278 L F
.45107 .60499 m .45267 .60563 L .45056 .60598 L F
.877 .546 .041 r
.51707 .6376 m .51772 .64016 L .51835 .64093 L F
.986 .882 .538 r
.51835 .64093 m .51704 .6425 L .51772 .64016 L F
.877 .546 .041 r
.51707 .6376 m .51772 .64016 L .51835 .64093 L F
.986 .882 .538 r
.51835 .64093 m .51704 .6425 L .51772 .64016 L F
.58 .596 .833 r
.58662 .62365 m .59034 .62644 L .58693 .62596 L F
.58662 .62365 m .58934 .62323 L .59034 .62644 L F
.613 .516 .72 r
.48686 .68965 m .4868 .68562 L .48714 .68784 L F
.81 .996 .86 r
.47606 .66821 m .47436 .6682 L .47455 .66797 L F
.47606 .66821 m .47898 .66552 L .47496 .66782 L F
0 0 0 r
.47477 .66794 m .47436 .6682 L .47455 .66797 L F
.81 .996 .86 r
.47436 .6682 m .47477 .66794 L .47428 .6682 L F
.47606 .66821 m .47496 .66782 L .47436 .6682 L F
.5 .075 .165 r
.47453 .66813 m .47898 .66552 L .48083 .66609 L F
0 0 0 r
.47479 .66794 m .47436 .6682 L .47477 .66794 L F
.47453 .66813 m .47436 .6682 L .47479 .66794 L F
.47451 .66813 m .47446 .66816 L .47453 .66813 L F
.47446 .66816 m .47436 .6682 L .47453 .66813 L F
.405 .034 .218 r
.48126 .66432 m .48021 .66522 L .47956 .66592 L F
.5 .075 .165 r
.47501 .66789 m .47883 .66671 L .47956 .66592 L F
.47453 .66813 m .48083 .66609 L .47501 .66789 L F
0 0 0 r
.47802 .6671 m .47507 .66797 L .47956 .66592 L F
.405 .034 .218 r
.48021 .66522 m .47802 .6671 L .47956 .66592 L F
.5 .075 .165 r
.47883 .66671 m .48083 .66609 L .47956 .66592 L F
.47496 .66782 m .47898 .66552 L .47453 .66813 L F
0 0 0 r
.47503 .66791 m .47451 .66813 L .47479 .66794 L F
.5 .075 .165 r
.47428 .6682 m .47453 .66813 L .47495 .66792 L F
0 0 0 r
.47586 .66781 m .47509 .66801 L .47507 .66797 L F
.47586 .66781 m .47507 .66797 L .47503 .66791 L F
.47509 .66801 m .47436 .6682 L .47503 .66791 L F
.47507 .66797 m .47586 .66781 L .47428 .6682 L F
.47802 .6671 m .47586 .66781 L .47507 .66797 L F
.47428 .6682 m .47503 .66791 L .47495 .66792 L F
.5 .075 .165 r
.47428 .6682 m .47479 .66794 L .47453 .66813 L F
0 0 0 r
.47428 .6682 m .47495 .66792 L .47479 .66794 L F
.47428 .6682 m .47479 .66794 L .47477 .66794 L F
0 0 .023 r
.4719 .67098 m .472 .66914 L .47455 .66797 L F
.81 .996 .86 r
.47436 .6682 m .47428 .6682 L .47455 .66797 L F
0 0 0 r
.47428 .6682 m .47477 .66794 L .47455 .66797 L F
.81 .996 .86 r
.47477 .66794 m .47496 .66782 L .47428 .6682 L F
.5 .075 .165 r
.47428 .6682 m .47496 .66782 L .47479 .66794 L F
.47428 .6682 m .47495 .66792 L .47501 .66789 L F
0 0 0 r
.47503 .66791 m .47428 .6682 L .47501 .66789 L F
.47507 .66797 m .47428 .6682 L .47503 .66791 L F
.47428 .6682 m .47586 .66781 L .47503 .66791 L F
.47507 .66797 m .47501 .66789 L .47956 .66592 L F
.47586 .66781 m .47398 .66866 L .47436 .6682 L F
0 0 .023 r
.4719 .67098 m .4739 .66871 L .47387 .66871 L F
.4739 .66871 m .47455 .66797 L .47387 .66871 L F
.571 .184 .269 r
.47586 .66781 m .47383 .66871 L .47387 .66871 L F
.47383 .66871 m .47206 .66949 L .47387 .66871 L F
0 0 0 r
.47398 .66866 m .47387 .66871 L .47455 .66797 L F
.392 .189 .481 r
.31592 .59765 m .31797 .59703 L .31814 .59436 L F
.457 .315 .6 r
.31602 .60016 m .31797 .59703 L .31592 .59765 L F
.445 .395 .708 r
.20923 .61361 m .20825 .61709 L .20784 .6155 L F
.555 .44 .677 r
.51421 .66407 m .51603 .66119 L .51334 .66138 L F
.916 .725 .629 r
.56046 .67992 m .56285 .67843 L .56025 .67762 L F
.56046 .67992 m .56315 .6813 L .56285 .67843 L F
.488 .135 .292 r
.39838 .62033 m .40081 .62006 L .40187 .61774 L F
.49 .136 .293 r
.40187 .61774 m .40375 .61892 L .4043 .6175 L F
.40187 .61774 m .40081 .62006 L .40375 .61892 L F
.287 .023 .328 r
.52653 .68297 m .52958 .68024 L .52732 .68151 L F
.102 .397 .852 r
.5344 .61848 m .53531 .61805 L .53373 .61683 L F
.5344 .61848 m .53695 .62002 L .53531 .61805 L F
.763 .549 .608 r
.64954 .44377 m .65314 .44662 L .65313 .44433 L F
0 0 .538 r
.80394 .48019 m .80368 .48378 L .80323 .48183 L F
.848 .635 .614 r
.54096 .65183 m .54087 .6543 L .54476 .65451 L F
0 0 .45 r
.54476 .65451 m .54608 .6537 L .54561 .65085 L F
0 0 0 r
.54476 .65451 m .54372 .65648 L .54608 .6537 L F
.686 .205 .103 r
.54087 .6543 m .54372 .65648 L .54476 .65451 L F
.77 .821 .893 r
.31433 .61867 m .31192 .62075 L .31362 .61843 L F
.54 .482 .74 r
.31192 .62075 m .31466 .62088 L .31362 .61843 L F
.543 .336 .55 r
.31192 .62075 m .31148 .62291 L .31466 .62088 L F
.436 .535 .86 r
.55059 .5982 m .55108 .59632 L .54971 .59738 L F
.297 .716 .973 r
.54714 .59733 m .54974 .59741 L .55059 .5982 L F
.436 .535 .86 r
.55059 .5982 m .54971 .59738 L .54913 .59783 L F
.297 .716 .973 r
.54974 .59741 m .5506 .59744 L .55059 .5982 L F
.527 .631 .897 r
.55108 .59632 m .55059 .5982 L .5506 .59744 L F
.934 .674 .519 r
.56079 .68332 m .56315 .6813 L .56046 .67992 L F
.56079 .68332 m .56276 .68414 L .56315 .6813 L F
.548 .101 .141 r
.53122 .65806 m .52677 .65994 L .52677 .65736 L F
.53122 .65806 m .52949 .6602 L .52677 .65994 L F
.729 .29 .207 r
.51021 .63115 m .51212 .63228 L .51359 .63179 L F
.593 .083 .01 r
.51212 .63228 m .51589 .63272 L .51359 .63179 L F
.592 .532 .757 r
.42812 .60047 m .42981 .59741 L .42735 .59792 L F
.42812 .60047 m .43041 .60013 L .42981 .59741 L F
.549 .542 .799 r
.42812 .60047 m .43132 .60285 L .43041 .60013 L F
.957 .634 .366 r
.61093 .63755 m .61125 .64011 L .61291 .64098 L F
.94 .745 .612 r
.61125 .64011 m .61275 .64343 L .61291 .64098 L F
.015 0 0 r
.37581 .59528 m .37393 .59577 L .37189 .596 L F
0 0 0 r
.37793 .59485 m .37393 .59577 L .37581 .59528 L F
.493 .74 .982 r
.21549 .54701 m .21504 .54868 L .21374 .54709 L F
.21549 .54701 m .21703 .54837 L .21504 .54868 L F
.747 .35 .299 r
.32365 .64038 m .32473 .64214 L .32575 .64146 L F
.32365 .64038 m .32473 .64214 L .32575 .64146 L F
.442 .432 .753 r
.46567 .69497 m .46475 .69839 L .46281 .69783 L F
.46567 .69497 m .46662 .69846 L .46475 .69839 L F
.761 .667 .759 r
.23294 .55707 m .2317 .55686 L .23277 .55718 L F
.638 .515 .698 r
.23548 .55843 m .23345 .56136 L .23294 .55707 L F
.4 0 0 r
.23277 .55718 m .23548 .55843 L .23294 .55707 L F
.94 .69 .531 r
.55914 .66812 m .55984 .66989 L .55991 .66688 L F
0 0 .054 r
.56021 .66461 m .55968 .66636 L .55967 .6663 L F
.93 .922 .546 r
.55967 .6663 m .55914 .66812 L .55991 .66688 L F
0 0 .054 r
.55968 .66636 m .55914 .66812 L .55967 .6663 L F
.67 .337 0 r
.55966 .66624 m .55967 .6663 L .55991 .66688 L F
.55865 .66367 m .55967 .6663 L .55966 .66624 L F
.989 .782 .395 r
.54269 .6008 m .54192 .60264 L .542 .60049 L F
.054 0 .004 r
.54269 .6008 m .54378 .60152 L .54504 .60019 L F
.54269 .6008 m .54192 .60264 L .54378 .60152 L F
.596 .352 .517 r
.50539 .73343 m .50777 .73557 L .50789 .73322 L F
.50789 .73322 m .50777 .73557 L .50539 .73343 L F
0 0 .187 r
.48644 .64669 m .4882 .64266 L .48587 .64557 L F
.48644 .64669 m .48754 .64592 L .4882 .64266 L F
0 0 0 r
.48644 .64669 m .48489 .64804 L .48754 .64592 L F
.848 .535 .458 r
.58054 .59461 m .58118 .59657 L .57902 .59679 L F
.486 .48 .776 r
.43132 .60285 m .43237 .60623 L .43383 .6052 L F
.426 .271 .566 r
.43237 .60623 m .43453 .60598 L .43383 .6052 L F
.43237 .60623 m .43253 .60868 L .43453 .60598 L F
.85 .467 .322 r
.42381 .59724 m .42423 .59871 L .41993 .59472 L F
0 0 .442 r
.42497 .59584 m .42381 .59724 L .42624 .59673 L F
.42497 .59584 m .42423 .59871 L .42381 .59724 L F
.445 .211 .464 r
.4928 .63476 m .49476 .6344 L .49553 .63201 L F
.584 .286 .428 r
.4928 .63476 m .49533 .63643 L .49476 .6344 L F
.4928 .63476 m .49213 .63712 L .49533 .63643 L F
.564 .491 .731 r
.54314 .6727 m .54608 .67496 L .54718 .67427 L F
0 0 .026 r
.54608 .67496 m .54771 .67165 L .54718 .67427 L F
.997 .85 .52 r
.47605 .67221 m .47662 .67307 L .4738 .67262 L F
.487 .777 .996 r
.47605 .67221 m .47662 .67307 L .4738 .67262 L F
.512 .438 .71 r
.47662 .67307 m .47777 .67599 L .4796 .67491 L F
.255 .078 .438 r
.54528 .66922 m .54707 .66623 L .54561 .66708 L F
.675 .609 .774 r
.4562 .60617 m .45402 .60885 L .45267 .60563 L F
.592 .489 .706 r
.4562 .60617 m .45663 .60857 L .45402 .60885 L F
.203 0 0 r
.37799 .62463 m .37597 .62457 L .37457 .62558 L F
.59 .555 .783 r
.55038 .67824 m .55405 .67901 L .55082 .67792 L F
.635 .406 .553 r
.55319 .68067 m .55038 .67824 L .55239 .68054 L F
.55319 .68067 m .55405 .67901 L .55038 .67824 L F
.383 .802 .607 r
.78613 .48884 m .78662 .48856 L .78874 .48723 L F
.839 .804 .817 r
.4967 .69329 m .49475 .69578 L .49291 .69505 L F
.753 .236 0 r
.49475 .69578 m .49478 .69702 L .49291 .69505 L F
.49475 .69578 m .49649 .69792 L .49478 .69702 L F
.187 0 .093 r
.20255 .56023 m .20128 .56209 L .20448 .55944 L F
.257 .744 .922 r
.55791 .59347 m .56157 .59369 L .55924 .59391 L F
.557 .934 .888 r
.40228 .58898 m .40176 .59005 L .40383 .58921 L F
.40228 .58898 m .39999 .5902 L .40176 .59005 L F
.64 .345 .454 r
.4902 .65728 m .49115 .65401 L .48776 .65517 L F
.547 .287 .473 r
.4902 .65728 m .49371 .65364 L .49115 .65401 L F
.881 .493 .031 r
.55638 .65796 m .55721 .66056 L .55801 .66132 L F
.928 .579 .141 r
.55721 .66056 m .55865 .66367 L .55801 .66132 L F
.834 .985 .872 r
.72605 .48819 m .72361 .48931 L .72518 .48715 L F
.623 .395 .551 r
.48818 .68133 m .48816 .68403 L .48542 .68404 L F
.683 .444 .554 r
.49011 .68382 m .48818 .68133 L .48885 .68184 L F
.49011 .68382 m .48816 .68403 L .48818 .68133 L F
.591 .579 .808 r
.31869 .62668 m .31957 .62269 L .3189 .62331 L F
.281 .727 .961 r
.4146 .59428 m .41321 .59357 L .41133 .59372 L F
.4146 .59428 m .41321 .59357 L .41133 .59372 L F
.646 .902 .983 r
.41608 .59263 m .4146 .59428 L .41713 .59336 L F
.41608 .59263 m .41321 .59357 L .4146 .59428 L F
.44 .228 .493 r
.31814 .59436 m .32001 .59611 L .32027 .59366 L F
.31814 .59436 m .31797 .59703 L .32001 .59611 L F
.795 .542 .555 r
.54499 .68114 m .54853 .68405 L .54673 .68168 L F
.416 .441 .778 r
.54673 .68168 m .54994 .68295 L .55239 .68054 L F
.54673 .68168 m .54853 .68405 L .54994 .68295 L F
.7 .748 .889 r
.75029 .51679 m .7537 .5174 L .75236 .51566 L F
.698 .701 .849 r
.75236 .51566 m .7537 .5174 L .75597 .51635 L F
.341 .711 .984 r
.58228 .62263 m .58553 .62271 L .58662 .62365 L F
.502 .793 .998 r
.58808 .62225 m .58662 .62365 L .58553 .62271 L F
.58808 .62225 m .58934 .62323 L .58662 .62365 L F
.872 .715 .684 r
.5448 .61727 m .54664 .61771 L .54511 .61435 L F
.873 .577 .483 r
.5448 .61727 m .54492 .61978 L .54664 .61771 L F
.902 .626 .509 r
.54664 .61771 m .54492 .61978 L .54676 .62012 L F
.714 .979 .912 r
.60687 .66392 m .60486 .66609 L .60769 .6643 L F
.60687 .66392 m .60391 .66585 L .60486 .66609 L F
.788 .288 0 r
.50819 .67835 m .5076 .67859 L .50501 .6754 L F
.473 .356 .639 r
.50501 .6754 m .5076 .67859 L .50731 .67509 L F
.49 .542 .837 r
.35638 .64306 m .35689 .63985 L .35458 .64064 L F
.35638 .64306 m .35827 .64342 L .35689 .63985 L F
0 .23 .749 r
.80722 .49031 m .80513 .48757 L .80739 .48971 L F
.65 .964 .796 r
.80722 .49031 m .80436 .49205 L .80552 .49364 L F
.80722 .49031 m .80739 .48971 L .80436 .49205 L F
.242 .584 .945 r
.79723 .48881 m .80003 .48851 L .79698 .48723 L F
.79723 .48881 m .79952 .48927 L .80003 .48851 L F
.901 .86 .791 r
.49594 .64947 m .49421 .65279 L .49253 .65251 L F
0 .137 .683 r
.49421 .65279 m .49455 .65166 L .49253 .65251 L F
.49421 .65279 m .49586 .65444 L .49455 .65166 L F
.646 .224 .227 r
.49371 .65364 m .49586 .65444 L .49421 .65279 L F
.144 0 0 r
.51589 .63272 m .51865 .63302 L .51914 .63285 L F
.523 0 0 r
.51865 .63302 m .52203 .63389 L .51914 .63285 L F
.882 .469 .043 r
.55527 .65758 m .55721 .66056 L .55638 .65796 L F
.7 .203 .061 r
.55497 .62923 m .55407 .63044 L .55165 .62853 L F
.841 .395 .16 r
.55497 .62923 m .55671 .6322 L .55407 .63044 L F
.73 .41 .437 r
.52567 .69207 m .52229 .69351 L .52333 .69225 L F
.399 0 .135 r
.47855 .66277 m .48078 .66165 L .47921 .66295 L F
.867 .913 .859 r
.48009 .65926 m .47921 .66295 L .4823 .66054 L F
.48009 .65926 m .4779 .66231 L .47921 .66295 L F
0 .265 .762 r
.48023 .66325 m .47921 .66295 L .4779 .66231 L F
.48082 .66348 m .47921 .66295 L .48023 .66325 L F
.399 0 .135 r
.47791 .66308 m .47855 .66277 L .47921 .66295 L F
.855 .974 .665 r
.54753 .61398 m .54751 .61234 L .54528 .61188 L F
.686 .706 .863 r
.73417 .48473 m .73105 .48426 L .73377 .4833 L F
.88 .931 .85 r
.73709 .48131 m .73417 .48473 L .73377 .4833 L F
.177 0 0 r
.48522 .71091 m .48499 .71132 L .48221 .71175 L F
.589 .538 .766 r
.48795 .71017 m .48522 .71091 L .48441 .70825 L F
.637 .35 .465 r
.48795 .71017 m .48499 .71132 L .48522 .71091 L F
.377 0 .097 r
.42111 .6238 m .41967 .62575 L .4174 .62609 L F
.389 0 .129 r
.42334 .62342 m .41967 .62575 L .42111 .6238 L F
.815 .725 .766 r
.54096 .65183 m .54387 .64922 L .54118 .64968 L F
.662 .115 0 r
.58374 .59836 m .58345 .59887 L .58118 .59657 L F
.651 .1 0 r
.58374 .59836 m .58557 .6001 L .58345 .59887 L F
.991 .731 .391 r
.48568 .66129 m .48621 .66187 L .48526 .66286 L F
.615 .832 .983 r
.48621 .66187 m .48881 .66114 L .48568 .66129 L F
.517 .828 1 r
.48621 .66187 m .49007 .66172 L .48881 .66114 L F
.432 0 0 r
.19843 .5576 m .19668 .55704 L .19485 .55609 L F
0 .333 .807 r
.19843 .5576 m .20062 .55824 L .19668 .55704 L F
.19843 .5576 m .20186 .5596 L .20062 .55824 L F
.604 .348 .502 r
.53677 .6545 m .53865 .65477 L .539 .65256 L F
.54 .291 .486 r
.539 .65256 m .54087 .6543 L .54096 .65183 L F
.539 .65256 m .53865 .65477 L .54087 .6543 L F
.054 0 0 r
.38356 .62448 m .38211 .62445 L .3803 .62491 L F
.461 .37 .666 r
.44724 .68698 m .44973 .68876 L .44891 .68646 L F
.44724 .68698 m .44735 .69034 L .44973 .68876 L F
.554 .343 .548 r
.46156 .6173 m .45884 .6202 L .45893 .61772 L F
.956 .838 .686 r
.55279 .70165 m .55121 .70096 L .55299 .70069 L F
.429 .309 .614 r
.5547 .70098 m .55279 .70165 L .55299 .70069 L F
.261 0 0 r
.55299 .70069 m .55121 .70096 L .5547 .70098 L F
.517 .081 .15 r
.41506 .62617 m .41124 .62784 L .41269 .62623 L F
.547 .571 .83 r
.28107 .83916 m .28254 .83686 L .28034 .83744 L F
.28107 .83916 m .28282 .8384 L .28254 .83686 L F
.738 .298 .207 r
.48334 .67517 m .48552 .67735 L .487 .67626 L F
.298 0 0 r
.487 .67626 m .48799 .67706 L .48914 .67522 L F
.487 .67626 m .48552 .67735 L .48799 .67706 L F
.194 0 .316 r
.21901 .58541 m .21742 .58709 L .2173 .58606 L F
0 0 0 r
.64739 .44518 m .64402 .4458 L .64379 .44586 L F
.029 0 .478 r
.55005 .70444 m .55121 .70096 L .55279 .70165 L F
.507 .267 .486 r
.55279 .70165 m .55246 .70409 L .55005 .70444 L F
.356 .139 .441 r
.5547 .70098 m .55246 .70409 L .55279 .70165 L F
.564 .598 .846 r
.22614 .55333 m .2258 .55706 L .22477 .55318 L F
.22614 .55333 m .22787 .55659 L .2258 .55706 L F
.784 .587 .634 r
.49748 .73635 m .50027 .73663 L .49997 .73541 L F
.497 .064 .147 r
.49748 .73635 m .49844 .73664 L .49997 .73541 L F
.334 .112 .421 r
.50027 .73663 m .50242 .73512 L .49997 .73541 L F
.158 .68 .879 r
.49748 .73635 m .49803 .7364 L .49891 .73634 L F
.49803 .7364 m .50027 .73663 L .49906 .73637 L F
.49803 .7364 m .49906 .73637 L .49891 .73634 L F
.303 0 0 r
.49997 .73541 m .49876 .73638 L .50242 .73512 L F
.49876 .73638 m .49844 .73664 L .49915 .73637 L F
.49876 .73638 m .49906 .73637 L .50242 .73512 L F
.334 .112 .421 r
.49906 .73637 m .50242 .73512 L .49891 .73634 L F
.50027 .73663 m .50242 .73512 L .49906 .73637 L F
.303 0 0 r
.49906 .73637 m .49915 .73637 L .50242 .73512 L F
.479 .454 .752 r
.31661 .61458 m .31774 .61084 L .31559 .61154 L F
.31661 .61458 m .31861 .61432 L .31774 .61084 L F
.791 .556 .582 r
.54212 .61374 m .54528 .61188 L .54375 .61268 L F
.54212 .61374 m .54511 .61435 L .54528 .61188 L F
.567 .362 .563 r
.54511 .61435 m .54753 .61398 L .54528 .61188 L F
.791 .556 .582 r
.54212 .61374 m .54375 .61268 L .54145 .61258 L F
.307 .692 .978 r
.5823 .66938 m .58265 .66826 L .58073 .66797 L F
.5823 .66938 m .58381 .66925 L .58265 .66826 L F
0 .025 .586 r
.57344 .65793 m .5738 .65771 L .57151 .65491 L F
0 .097 .648 r
.57344 .65793 m .57528 .65904 L .5738 .65771 L F
.57344 .65793 m .57526 .66016 L .57528 .65904 L F
.6 .36 .525 r
.5038 .69994 m .50054 .69864 L .50373 .6987 L F
.389 0 .069 r
.50611 .6988 m .5038 .69994 L .50373 .6987 L F
.485 .349 .621 r
.31421 .60315 m .31623 .60265 L .31602 .60016 L F
.471 .355 .639 r
.31507 .60541 m .31623 .60265 L .31421 .60315 L F
.464 .294 .565 r
.22681 .56253 m .22667 .56552 L .22466 .5658 L F
.491 .429 .714 r
.22667 .56552 m .22733 .56735 L .22466 .5658 L F
.839 .804 .817 r
.4967 .69329 m .49322 .69308 L .49536 .69186 L F
.4967 .69329 m .49291 .69505 L .49322 .69308 L F
.326 .626 .959 r
.49536 .69186 m .49772 .69233 L .4967 .69329 L F
.49536 .69186 m .49772 .69233 L .4967 .69329 L F
.41 .181 .453 r
.51178 .66715 m .51421 .66407 L .514 .66646 L F
0 0 0 r
.51421 .66407 m .51026 .66582 L .514 .66646 L F
.555 .44 .677 r
.51421 .66407 m .51707 .66374 L .51603 .66119 L F
.502 .236 .442 r
.51421 .66407 m .51621 .66585 L .514 .66646 L F
.51421 .66407 m .51707 .66374 L .51621 .66585 L F
0 0 0 r
.51421 .66407 m .51603 .66119 L .51707 .66374 L F
.502 .236 .442 r
.51421 .66407 m .51621 .66585 L .514 .66646 L F
.51421 .66407 m .51707 .66374 L .51621 .66585 L F
.68 .404 .498 r
.49791 .63436 m .49553 .63201 L .49476 .6344 L F
.49791 .63436 m .49814 .63213 L .49553 .63201 L F
.009 .262 .765 r
.60471 .62557 m .60667 .62869 L .60665 .62651 L F
0 0 0 r
.77218 .49409 m .76943 .49599 L .77206 .49329 L F
.721 .957 .946 r
.77206 .49329 m .77365 .49185 L .77294 .49139 L F
0 0 .052 r
.77294 .49139 m .77218 .49409 L .77206 .49329 L F
.735 .741 .857 r
.75833 .5155 m .76187 .51591 L .76102 .51337 L F
.663 .704 .878 r
.76187 .51591 m .76325 .51227 L .76102 .51337 L F
.76187 .51591 m .7643 .51513 L .76325 .51227 L F
.651 .114 0 r
.46996 .72251 m .46926 .7237 L .46628 .72129 L F
.548 .332 .539 r
.53139 .64644 m .53376 .64609 L .53373 .64374 L F
.773 .652 .729 r
.53376 .64609 m .53623 .64319 L .53373 .64374 L F
.76 .648 .738 r
.63306 .43749 m .63385 .44079 L .63046 .44053 L F
.659 .53 .696 r
.63417 .44342 m .63046 .44053 L .63385 .44079 L F
.726 .627 .748 r
.63646 .43809 m .63385 .44079 L .63306 .43749 L F
.458 .787 .999 r
.51464 .72924 m .5159 .73 L .51367 .73047 L F
.429 .218 .489 r
.5159 .73 m .51355 .7326 L .51367 .73047 L F
.413 .341 .666 r
.49346 .68154 m .48885 .68184 L .49416 .68025 L F
.49306 .68181 m .48885 .68184 L .49346 .68154 L F
.49306 .68181 m .49011 .68382 L .48885 .68184 L F
.789 .445 .404 r
.49311 .6818 m .49499 .68293 L .4953 .68133 L F
.49306 .68181 m .49316 .68187 L .49311 .6818 L F
.49316 .68187 m .49499 .68293 L .49311 .6818 L F
.49313 .68192 m .49499 .68293 L .49306 .68181 L F
.4936 .68264 m .494 .68272 L .49313 .68192 L F
.494 .68272 m .49499 .68293 L .49313 .68192 L F
.529 .484 .751 r
.49323 .6861 m .49011 .68382 L .49287 .68209 L F
.49323 .6861 m .49287 .68209 L .49314 .68224 L F
.49323 .6861 m .49313 .68192 L .49331 .68208 L F
.67 .164 .033 r
.494 .68272 m .49471 .68312 L .49499 .68293 L F
.537 .51 .773 r
.49525 .68379 m .49314 .68852 L .49323 .6861 L F
.6 .077 0 r
.49547 .68393 m .4974 .68462 L .49448 .68328 L F
.323 .34 .724 r
.49711 .68709 m .49566 .68405 L .4974 .68462 L F
.6 .077 0 r
.49564 .68405 m .49629 .68426 L .49547 .68393 L F
.49701 .68454 m .4974 .68462 L .49547 .68393 L F
.49511 .68357 m .4974 .68462 L .49478 .68308 L F
.323 .34 .724 r
.49566 .68405 m .49544 .68358 L .4974 .68462 L F
.6 .077 0 r
.49613 .68437 m .49701 .68454 L .49629 .68426 L F
.49613 .68437 m .49629 .68426 L .49564 .68405 L F
.537 .51 .773 r
.4953 .68387 m .4958 .68795 L .49314 .68852 L F
.49544 .68358 m .49547 .68393 L .4953 .68387 L F
.49547 .68393 m .4958 .68795 L .4953 .68387 L F
.49544 .68358 m .4953 .68387 L .49525 .68379 L F
.4953 .68387 m .49314 .68852 L .49525 .68379 L F
.6 .077 0 r
.49478 .68308 m .4974 .68462 L .49499 .68293 L F
.49448 .68328 m .49511 .68357 L .49478 .68308 L F
.279 .306 .711 r
.49525 .68379 m .49519 .68386 L .49495 .68359 L F
.49519 .68386 m .49483 .68427 L .49397 .68287 L F
.323 .34 .724 r
.49711 .68709 m .4958 .68795 L .49547 .68393 L F
.49566 .68405 m .49547 .68393 L .49544 .68358 L F
.49711 .68709 m .49547 .68393 L .49566 .68405 L F
.279 .306 .711 r
.49483 .68427 m .49323 .6861 L .4933 .68233 L F
.49371 .68266 m .4933 .68233 L .49331 .68208 L F
.49483 .68427 m .4933 .68233 L .49371 .68266 L F
.67 .164 .033 r
.49371 .68266 m .49471 .68312 L .494 .68272 L F
.413 .341 .666 r
.49313 .68192 m .49011 .68382 L .49306 .68181 L F
.67 .164 .033 r
.49141 .68217 m .49404 .68293 L .49371 .68266 L F
.49404 .68293 m .49471 .68312 L .49371 .68266 L F
.279 .306 .711 r
.49483 .68427 m .49331 .68208 L .49331 .68181 L F
.6 .077 0 r
.49363 .68387 m .49613 .68437 L .49548 .68394 L F
.67 .164 .033 r
.49404 .68293 m .49448 .68328 L .49471 .68312 L F
.279 .306 .711 r
.49519 .68386 m .49397 .68287 L .49331 .68181 L F
.6 .077 0 r
.49445 .68331 m .49548 .68394 L .49448 .68328 L F
.49363 .68387 m .49548 .68394 L .49445 .68331 L F
.279 .306 .711 r
.49544 .68358 m .49525 .68379 L .49331 .68181 L F
.49525 .68379 m .49495 .68359 L .49331 .68181 L F
.67 .164 .033 r
.49141 .68217 m .49363 .68387 L .49448 .68328 L F
.49141 .68217 m .49448 .68328 L .49404 .68293 L F
.529 .484 .751 r
.49314 .68224 m .49287 .68209 L .49313 .68192 L F
.49331 .68208 m .49313 .68192 L .49331 .68181 L F
.413 .341 .666 r
.49331 .68181 m .49313 .68192 L .49306 .68181 L F
.789 .445 .404 r
.49141 .68217 m .4936 .68264 L .49306 .68181 L F
.49141 .68217 m .49306 .68181 L .49196 .67973 L F
.49306 .68181 m .4953 .68133 L .49346 .68154 L F
.83 .488 .409 r
.4953 .68133 m .49331 .68181 L .49346 .68154 L F
.4953 .68133 m .49346 .68154 L .49416 .68025 L F
.789 .445 .404 r
.49346 .68154 m .4953 .68133 L .49438 .68089 L F
.49306 .68181 m .49438 .68089 L .49196 .67973 L F
.413 .341 .666 r
.49331 .68181 m .49306 .68181 L .49346 .68154 L F
.648 .441 .589 r
.4977 .65808 m .49759 .6612 L .49488 .66087 L F
.544 .355 .575 r
.49977 .65979 m .4977 .65808 L .50044 .65769 L F
.49977 .65979 m .49759 .6612 L .4977 .65808 L F
.613 .516 .72 r
.48686 .68965 m .48742 .68759 L .4868 .68562 L F
.48686 .68965 m .48935 .68974 L .48742 .68759 L F
.614 .462 .652 r
.48686 .68965 m .48702 .69264 L .48935 .68974 L F
.673 .814 .951 r
.43098 .58869 m .42886 .58956 L .42747 .58837 L F
.552 .59 .846 r
.7719 .51874 m .77287 .51494 L .77049 .5155 L F
.7719 .51874 m .77419 .51815 L .77287 .51494 L F
.762 .524 .573 r
.60296 .62031 m .60327 .62248 L .60485 .62041 L F
.78 .524 .548 r
.60485 .62041 m .60327 .62248 L .60607 .62262 L F
.318 .59 .942 r
.49887 .6653 m .50072 .6655 L .49976 .66673 L F
.621 .458 .64 r
.50072 .6655 m .50165 .66687 L .49976 .66673 L F
.492 .507 .801 r
.50261 .66924 m .49976 .66673 L .50165 .66687 L F
.722 .779 .898 r
.48881 .66114 m .49007 .66172 L .49254 .6611 L F
0 .205 .732 r
.80529 .48637 m .80739 .48971 L .80513 .48757 L F
.823 .358 0 r
.5516 .65075 m .55161 .64942 L .5505 .64801 L F
.5516 .65075 m .55286 .65163 L .55161 .64942 L F
.604 .364 .526 r
.50054 .69864 m .50031 .70125 L .49782 .70129 L F
.6 .36 .525 r
.5038 .69994 m .50031 .70125 L .50054 .69864 L F
0 0 0 r
.48311 .67205 m .48432 .67187 L .48536 .66971 L F
.29 0 .123 r
.48536 .66971 m .48779 .67193 L .48772 .66934 L F
.48536 .66971 m .48651 .67106 L .48779 .67193 L F
.48536 .66971 m .48432 .67187 L .48651 .67106 L F
.55 .515 .77 r
.53023 .64068 m .53154 .63881 L .52891 .63744 L F
.53023 .64068 m .53247 .64041 L .53154 .63881 L F
.913 .981 .737 r
.33048 .63103 m .33012 .63315 L .33215 .63192 L F
.33048 .63103 m .32846 .63426 L .33012 .63315 L F
.382 .172 .465 r
.3508 .60598 m .35027 .60859 L .34858 .60895 L F
.421 .291 .597 r
.35027 .60859 m .35056 .61092 L .34858 .60895 L F
.313 .278 .658 r
.34858 .60895 m .35056 .61092 L .34904 .6109 L F
.445 .277 .559 r
.49488 .66087 m .4931 .6641 L .49254 .6611 L F
.469 .604 .903 r
.49133 .66129 m .49414 .66157 L .49407 .66148 L F
.18 0 0 r
.48908 .66113 m .49254 .6611 L .49133 .66129 L F
.469 .604 .903 r
.49133 .66129 m .49407 .66148 L .49226 .65897 L F
.18 0 0 r
.48881 .66114 m .48908 .66113 L .49133 .66129 L F
.899 .745 .683 r
.58751 .62011 m .5881 .61727 L .58935 .62056 L F
.877 .516 .36 r
.58751 .62011 m .58935 .62056 L .58808 .62225 L F
.984 .732 .466 r
.58808 .62225 m .58935 .62056 L .58934 .62323 L F
.659 .495 .65 r
.48311 .67205 m .4858 .67288 L .48432 .67187 L F
.48311 .67205 m .48334 .67517 L .4858 .67288 L F
.276 .092 .441 r
.21788 .59142 m .21756 .59381 L .21602 .5945 L F
.338 .182 .517 r
.21756 .59381 m .21582 .59688 L .21602 .5945 L F
.88 .931 .85 r
.73709 .48131 m .73377 .4833 L .736 .48087 L F
.713 .597 .725 r
.736 .48087 m .73909 .48356 L .73709 .48131 L F
.051 0 0 r
.51101 .6679 m .51178 .66715 L .514 .66646 L F
.375 .044 .27 r
.50276 .65706 m .50044 .65769 L .5033 .65544 L F
.384 .048 .266 r
.50553 .65491 m .50276 .65706 L .5033 .65544 L F
.697 .315 .32 r
.58758 .59022 m .591 .58884 L .58752 .58863 L F
.58758 .59022 m .59156 .59028 L .591 .58884 L F
.794 .366 .232 r
.59156 .59028 m .59329 .59171 L .591 .58884 L F
.803 .356 .18 r
.591 .58884 m .59329 .59171 L .59467 .59151 L F
.737 .526 .607 r
.58485 .64328 m .58478 .64632 L .58244 .64596 L F
.704 .498 .607 r
.58705 .64532 m .58478 .64632 L .58485 .64328 L F
.622 .671 .876 r
.43496 .5907 m .43098 .58869 L .43314 .58878 L F
.49 .664 .939 r
.43553 .5883 m .43496 .5907 L .43314 .58878 L F
.43553 .5883 m .4373 .59044 L .43496 .5907 L F
.48 .669 .946 r
.33787 .634 m .33894 .63567 L .3411 .63525 L F
.782 .541 .571 r
.58101 .61392 m .58412 .61187 L .58095 .61156 L F
.58101 .61392 m .58433 .61433 L .58412 .61187 L F
.543 .363 .587 r
.58433 .61433 m .58645 .61162 L .58412 .61187 L F
.214 0 0 r
.58412 .61187 m .58645 .61162 L .58433 .61433 L F
.543 .363 .587 r
.58433 .61433 m .58645 .61162 L .58412 .61187 L F
.256 .683 .964 r
.40474 .58217 m .40843 .5832 L .40614 .58331 L F
0 0 0 r
.32753 .64034 m .32473 .64214 L .32575 .64146 L F
.32753 .64034 m .32473 .64214 L .32575 .64146 L F
.464 .208 .441 r
.57881 .59066 m .58154 .5881 L .57907 .58867 L F
.927 .857 .753 r
.472 .66914 m .47115 .67244 L .47039 .66967 L F
.697 .615 .761 r
.53108 .66043 m .53513 .66259 L .53498 .66108 L F
.525 .344 .578 r
.53498 .66108 m .53513 .66259 L .53661 .66118 L F
.397 0 0 r
.5157 .67363 m .51743 .67402 L .51893 .67274 L F
.507 .262 .478 r
.51893 .67274 m .51878 .67493 L .51646 .67536 L F
.549 .268 .441 r
.52191 .67178 m .51878 .67493 L .51893 .67274 L F
0 0 0 r
.51893 .67274 m .51973 .67318 L .52012 .67213 L F
.51893 .67274 m .51743 .67402 L .51973 .67318 L F
.222 0 0 r
.22787 .55659 m .23034 .55694 L .2317 .55686 L F
.477 .809 1 r
.23034 .55694 m .23277 .55718 L .2317 .55686 L F
.521 .296 .514 r
.47126 .66106 m .47357 .66071 L .47396 .65823 L F
.601 .476 .682 r
.47357 .66071 m .47562 .65752 L .47396 .65823 L F
.597 .732 .939 r
.41902 .58518 m .41419 .58315 L .41647 .58273 L F
.44 .863 .728 r
.42168 .58345 m .42059 .58393 L .41647 .58273 L F
.42059 .58393 m .41862 .58479 L .41835 .58454 L F
.42059 .58393 m .41835 .58454 L .41647 .58273 L F
.438 .765 .996 r
.42059 .58393 m .4225 .58395 L .42044 .58427 L F
0 .423 .815 r
.41939 .58205 m .42168 .58345 L .41981 .58223 L F
.651 .742 .916 r
.42344 .58219 m .41939 .58205 L .4224 .58111 L F
0 .423 .815 r
.41939 .58205 m .41981 .58223 L .41922 .58184 L F
.651 .742 .916 r
.42344 .58219 m .42133 .58286 L .41939 .58205 L F
.42133 .58286 m .42101 .58296 L .41939 .58205 L F
0 .423 .815 r
.41939 .58205 m .41943 .58207 L .42168 .58345 L F
.362 .698 .983 r
.41904 .5819 m .41935 .58208 L .41647 .58273 L F
.41935 .58208 m .42168 .58345 L .41803 .58295 L F
.41935 .58208 m .41803 .58295 L .41647 .58273 L F
.414 .846 .713 r
.41939 .58205 m .41939 .58205 L .42256 .58017 L F
.549 0 0 r
.41934 .58203 m .41939 .58205 L .41939 .58205 L F
.362 .698 .983 r
.41941 .58206 m .42168 .58345 L .41904 .5819 L F
.414 .846 .713 r
.41939 .58205 m .41888 .58218 L .4208 .58113 L F
.41939 .58205 m .4208 .58113 L .42256 .58017 L F
.362 .698 .983 r
.4189 .58185 m .41647 .58273 L .41516 .58191 L F
.549 0 0 r
.41599 .58063 m .41891 .58185 L .41922 .58184 L F
.362 .698 .983 r
.41922 .58184 m .41904 .5819 L .41891 .58185 L F
.41911 .58188 m .41932 .58201 L .41904 .5819 L F
.549 0 0 r
.41934 .58203 m .41939 .58205 L .41922 .58184 L F
.362 .698 .983 r
.41932 .58201 m .41941 .58206 L .41934 .58203 L F
.41932 .58201 m .41934 .58203 L .41904 .5819 L F
.549 0 0 r
.41891 .58185 m .41934 .58203 L .41922 .58184 L F
.362 .698 .983 r
.41922 .58184 m .41891 .58185 L .4189 .58185 L F
.41904 .5819 m .41647 .58273 L .4189 .58185 L F
.549 0 0 r
.41889 .58184 m .41888 .58218 L .41939 .58205 L F
.41599 .58063 m .41938 .58205 L .41934 .58203 L F
.418 .735 .991 r
.41599 .58063 m .41922 .58184 L .4189 .58185 L F
.41599 .58063 m .4189 .58185 L .41516 .58191 L F
.549 0 0 r
.41599 .58063 m .41939 .58205 L .41938 .58205 L F
.41599 .58063 m .41671 .58101 L .41889 .58184 L F
.41671 .58101 m .41888 .58218 L .41889 .58184 L F
.414 .846 .713 r
.41939 .58205 m .42256 .58017 L .4224 .58111 L F
.362 .698 .983 r
.41922 .58184 m .42168 .58345 L .41911 .58188 L F
0 .423 .815 r
.41943 .58207 m .42101 .58296 L .42168 .58345 L F
.438 .765 .996 r
.42101 .58296 m .42059 .58393 L .42168 .58345 L F
.42101 .58296 m .42191 .58356 L .42059 .58393 L F
.42059 .58393 m .42044 .58427 L .42168 .58345 L F
.42191 .58356 m .4225 .58395 L .42059 .58393 L F
.44 .863 .728 r
.42168 .58345 m .41902 .58518 L .41862 .58479 L F
.42168 .58345 m .42044 .58427 L .41902 .58518 L F
.606 .541 .755 r
.55082 .67792 m .55552 .67774 L .55551 .67526 L F
.55082 .67792 m .55405 .67901 L .55552 .67774 L F
.466 .216 .45 r
.35349 .60329 m .35294 .60548 L .3508 .60598 L F
.339 .112 .417 r
.35526 .60228 m .35294 .60548 L .35349 .60329 L F
.572 .325 .504 r
.50042 .6341 m .49814 .63213 L .49791 .63436 L F
.50042 .6341 m .50056 .63188 L .49814 .63213 L F
.336 .138 .457 r
.22534 .57104 m .22507 .57392 L .22339 .57446 L F
.134 0 .419 r
.22733 .56735 m .22693 .57012 L .22534 .57104 L F
.217 .042 .417 r
.2269 .5723 m .22534 .57104 L .22693 .57012 L F
.2269 .5723 m .22507 .57392 L .22534 .57104 L F
.374 .557 .904 r
.57965 .62029 m .58188 .6206 L .58228 .62263 L F
.172 .68 .902 r
.58396 .62227 m .58228 .62263 L .58188 .6206 L F
.58396 .62227 m .58553 .62271 L .58228 .62263 L F
.855 .436 .231 r
.59467 .59151 m .59534 .59357 L .59793 .59447 L F
.899 .678 .595 r
.59534 .59357 m .59775 .59686 L .59793 .59447 L F
0 0 0 r
.38133 .59409 m .38037 .59435 L .37793 .59485 L F
.425 .87 .846 r
.38345 .59323 m .38238 .59331 L .38133 .59409 L F
.434 .866 .765 r
.38238 .59331 m .38037 .59435 L .38133 .59409 L F
.414 .338 .662 r
.51645 .68938 m .51606 .69473 L .51894 .69159 L F
.275 .756 .927 r
.51606 .69473 m .51901 .69424 L .51894 .69159 L F
.51606 .69473 m .51529 .69396 L .51901 .69424 L F
.11 0 .327 r
.22304 .58164 m .2223 .58017 L .22332 .57926 L F
.22304 .58164 m .22175 .58259 L .2223 .58017 L F
.936 .694 .548 r
.50819 .67835 m .50811 .68103 L .50619 .67981 L F
.983 .738 .339 r
.50731 .67509 m .50819 .67835 L .50926 .6773 L F
.50731 .67509 m .5076 .67859 L .50819 .67835 L F
.522 .872 .625 r
.50819 .67835 m .50619 .67981 L .50926 .6773 L F
.652 .46 .611 r
.51054 .67805 m .50811 .68103 L .50819 .67835 L F
.936 .694 .548 r
.50819 .67835 m .50811 .68103 L .50619 .67981 L F
.16 .515 .915 r
.57352 .62714 m .57263 .62769 L .57087 .62619 L F
.57352 .62714 m .57528 .62882 L .57263 .62769 L F
.324 .344 .728 r
.44735 .69034 m .4496 .69226 L .44973 .68876 L F
.44735 .69034 m .44818 .69259 L .4496 .69226 L F
.785 .941 .929 r
.54149 .71169 m .54234 .71149 L .53942 .71274 L F
.568 .206 .314 r
.54234 .71149 m .54212 .71312 L .53942 .71274 L F
.241 0 .241 r
.54427 .7116 m .54212 .71312 L .54234 .71149 L F
.129 0 0 r
.54149 .71169 m .54427 .7116 L .54234 .71149 L F
.916 .605 .44 r
.47288 .69555 m .47121 .69541 L .47023 .6925 L F
.638 .19 .17 r
.4757 .69566 m .47121 .69541 L .47288 .69555 L F
.887 .714 .662 r
.59862 .61133 m .59991 .61467 L .60039 .61225 L F
.252 0 0 r
.57529 .64339 m .5777 .64359 L .57905 .64316 L F
.596 .025 0 r
.47161 .68993 m .47559 .69233 L .47291 .69024 L F
.47161 .68993 m .47408 .69182 L .47559 .69233 L F
0 .258 .767 r
.47269 .68992 m .47254 .69064 L .47161 .68993 L F
.317 .051 .343 r
.47054 .69141 m .47269 .68992 L .46885 .68804 L F
.663 .643 .82 r
.46885 .68804 m .47269 .68992 L .47186 .68585 L F
.684 .657 .817 r
.47186 .68585 m .47269 .68992 L .47483 .68821 L F
.993 .879 .584 r
.47269 .68992 m .47136 .69053 L .47287 .68909 L F
.47269 .68992 m .47287 .68909 L .47412 .68791 L F
0 .258 .767 r
.47269 .68992 m .47408 .69182 L .47254 .69064 L F
.561 .675 .915 r
.43864 .59056 m .43838 .59376 L .43759 .59202 L F
.43864 .59056 m .44102 .59322 L .43838 .59376 L F
.756 .702 .8 r
.57298 .61678 m .57839 .6145 L .5763 .61719 L F
.64 .393 .529 r
.5763 .61719 m .57608 .61987 L .57323 .61883 L F
.874 .935 .858 r
.57839 .6145 m .57839 .6145 L .5763 .61719 L F
.503 .344 .598 r
.57839 .6145 m .5786 .61704 L .5763 .61719 L F
.488 .27 .509 r
.57817 .61891 m .5763 .61719 L .57608 .61987 L F
.57817 .61891 m .5786 .61704 L .5763 .61719 L F
.5763 .61719 m .5786 .61704 L .57817 .61891 L F
.771 .658 .737 r
.32136 .63427 m .32409 .6355 L .3223 .6342 L F
.552 .797 .99 r
.3223 .6342 m .32409 .6355 L .32625 .63489 L F
0 0 0 r
.64739 .44518 m .64379 .44586 L .64628 .44639 L F
.418 .352 .676 r
.22507 .57392 m .22551 .57622 L .22339 .57446 L F
.405 .352 .685 r
.22551 .57622 m .224 .57714 L .22339 .57446 L F
.528 .152 .272 r
.33349 .58756 m .33743 .5851 L .33438 .58605 L F
.33349 .58756 m .33598 .58751 L .33743 .5851 L F
.299 0 .034 r
.33598 .58751 m .33969 .58513 L .33743 .5851 L F
.334 .112 .421 r
.50027 .73663 m .50225 .73599 L .50242 .73512 L F
.50027 .73663 m .50225 .73599 L .50242 .73512 L F
0 0 0 r
.38356 .62448 m .38607 .62397 L .38778 .62348 L F
.07 0 0 r
.38836 .62372 m .38778 .62348 L .38607 .62397 L F
.38836 .62372 m .38999 .62343 L .38778 .62348 L F
.924 .719 .607 r
.60666 .63405 m .60911 .63202 L .6076 .63093 L F
.60666 .63405 m .60872 .63473 L .60911 .63202 L F
.542 .889 .982 r
.79236 .50403 m .79285 .50484 L .79014 .50536 L F
.5 .864 .986 r
.79505 .50411 m .79285 .50484 L .79236 .50403 L F
.431 .23 .505 r
.79505 .50411 m .79291 .50729 L .79285 .50484 L F
.091 .649 .746 r
.50789 .73322 m .51093 .73297 L .51113 .733 L F
.34 0 .136 r
.51113 .733 m .50777 .73557 L .50789 .73322 L F
.51113 .733 m .51003 .73512 L .50777 .73557 L F
.62 .915 .641 r
.512 .73187 m .51093 .73297 L .51113 .733 L F
0 0 0 r
.512 .73187 m .51003 .73512 L .51113 .733 L F
0 .571 .708 r
.37743 .5822 m .38112 .58224 L .37894 .58298 L F
.366 0 0 r
.34202 .58516 m .34431 .58499 L .34589 .58341 L F
.385 0 .01 r
.34589 .58341 m .34431 .58499 L .3477 .58395 L F
.753 .69 .791 r
.80017 .49521 m .80552 .49364 L .80436 .49205 L F
.702 .714 .858 r
.78922 .50412 m .79014 .50536 L .78671 .50488 L F
.542 .889 .982 r
.79236 .50403 m .79014 .50536 L .78922 .50412 L F
.326 .731 .98 r
.51352 .67385 m .5157 .67363 L .51254 .67373 L F
.223 .284 .716 r
.55984 .66989 m .56146 .67117 L .56052 .67347 L F
.851 .392 .052 r
.56019 .67435 m .56203 .6754 L .56052 .67347 L F
0 0 0 r
.32571 .58973 m .32691 .58939 L .329 .58805 L F
.402 0 0 r
.329 .58805 m .32691 .58939 L .3313 .58799 L F
.233 0 0 r
.49486 .70353 m .49256 .70365 L .49482 .70138 L F
.515 .212 .39 r
.49782 .70129 m .49486 .70353 L .49482 .70138 L F
.304 0 0 r
.38234 .6369 m .38069 .63758 L .37841 .63762 L F
.168 0 0 r
.38427 .6367 m .38069 .63758 L .38234 .6369 L F
.477 0 0 r
.59199 .63226 m .59099 .63138 L .58969 .63022 L F
.97 .882 .688 r
.58994 .6338 m .59099 .63138 L .59199 .63226 L F
.029 0 .478 r
.55005 .70444 m .55173 .70386 L .55121 .70096 L F
.881 .988 .724 r
.55246 .70409 m .55173 .70386 L .55137 .70425 L F
.55246 .70409 m .55059 .70511 L .55173 .70386 L F
0 0 0 r
.55173 .70386 m .55059 .70511 L .55182 .70377 L F
.55173 .70386 m .55182 .70377 L .55309 .70239 L F
.881 .988 .724 r
.55137 .70425 m .55173 .70386 L .55005 .70444 L F
.764 .955 .935 r
.78968 .47826 m .79112 .47584 L .79212 .47727 L F
.78968 .47826 m .78884 .47748 L .79112 .47584 L F
.981 .863 .484 r
.60906 .66021 m .60908 .66265 L .60923 .66124 L F
0 0 0 r
.73105 .48426 m .73218 .48466 L .73377 .4833 L F
.73105 .48426 m .72985 .48568 L .73218 .48466 L F
.672 .667 .837 r
.46909 .69177 m .46611 .69207 L .46689 .69005 L F
.689 .476 .593 r
.46909 .69177 m .46567 .69497 L .46611 .69207 L F
.411 0 .108 r
.39225 .62302 m .39444 .62306 L .39617 .6207 L F
.395 0 .124 r
.39444 .62306 m .39838 .62033 L .39617 .6207 L F
.312 0 0 r
.39024 .63475 m .38863 .6362 L .38647 .63636 L F
.13 0 0 r
.39251 .6344 m .38863 .6362 L .39024 .63475 L F
.549 .268 .441 r
.52191 .67178 m .52132 .6746 L .51878 .67493 L F
.465 .192 .415 r
.52369 .67402 m .52191 .67178 L .52337 .67147 L F
.52369 .67402 m .52132 .6746 L .52191 .67178 L F
.376 .842 .819 r
.32188 .63918 m .31988 .63952 L .32246 .63895 L F
.427 .433 .763 r
.57432 .66386 m .57526 .66016 L .57666 .662 L F
.57432 .66386 m .57614 .66363 L .57526 .66016 L F
.427 .426 .755 r
.57432 .66386 m .57694 .66575 L .57614 .66363 L F
.233 0 0 r
.49486 .70353 m .49179 .70409 L .49256 .70365 L F
.608 .614 .832 r
.31861 .61432 m .32016 .61756 L .32248 .61693 L F
.569 .572 .817 r
.32016 .61756 m .32373 .62043 L .32248 .61693 L F
.629 .13 .048 r
.51785 .69584 m .51469 .69659 L .51427 .69542 L F
.702 .979 .904 r
.51901 .69424 m .51785 .69584 L .52029 .69533 L F
.51901 .69424 m .51469 .69659 L .51785 .69584 L F
.72 .64 .768 r
.63547 .43472 m .63646 .43809 L .63306 .43749 L F
.617 .597 .807 r
.63765 .43408 m .63646 .43809 L .63547 .43472 L F
.63765 .43408 m .63911 .43738 L .63646 .43809 L F
0 0 0 r
.77928 .48467 m .77635 .48697 L .77831 .48563 L F
.045 0 0 r
.77928 .48467 m .78077 .48489 L .78082 .48362 L F
.77928 .48467 m .77831 .48563 L .78077 .48489 L F
.274 0 .293 r
.47126 .66106 m .46877 .66373 L .47074 .66293 L F
.416 .119 .35 r
.47126 .66106 m .47328 .66225 L .47357 .66071 L F
.47126 .66106 m .47074 .66293 L .47328 .66225 L F
.689 .357 .409 r
.43256 .62064 m .4313 .62283 L .42917 .62041 L F
.669 .333 .397 r
.43492 .62241 m .43256 .62064 L .43505 .62026 L F
.43492 .62241 m .4313 .62283 L .43256 .62064 L F
.904 .698 .614 r
.59775 .59686 m .59757 .59966 L .59933 .60022 L F
.933 .663 .504 r
.59757 .59966 m .59928 .60268 L .59933 .60022 L F
.773 .652 .729 r
.53376 .64609 m .53752 .64684 L .53623 .64319 L F
.574 .543 .782 r
.53623 .64319 m .53752 .64684 L .53968 .64601 L F
.627 .678 .879 r
.42624 .59673 m .42735 .59792 L .42981 .59741 L F
.345 0 .219 r
.46563 .66674 m .46793 .66616 L .46877 .66373 L F
.257 0 .183 r
.46877 .66373 m .46997 .66529 L .47074 .66293 L F
.46877 .66373 m .46793 .66616 L .46997 .66529 L F
.298 .238 .62 r
.4496 .69226 m .44818 .69259 L .45004 .69475 L F
.937 .966 .706 r
.32326 .62961 m .32149 .63309 L .32139 .63159 L F
.666 .139 0 r
.32149 .63309 m .3209 .63324 L .32139 .63159 L F
.467 0 0 r
.79507 .51625 m .79787 .51716 L .80052 .51667 L F
.181 .324 .774 r
.80091 .51611 m .80052 .51667 L .79787 .51716 L F
.80091 .51611 m .80155 .51772 L .80052 .51667 L F
.589 .538 .766 r
.48795 .71017 m .48441 .70825 L .48705 .70785 L F
.543 .147 .241 r
.48399 .70912 m .48705 .70785 L .48441 .70825 L F
.314 .786 .929 r
.38112 .58224 m .38338 .58192 L .38486 .58222 L F
.103 .646 .841 r
.38486 .58222 m .38338 .58192 L .38706 .58228 L F
.724 .723 .849 r
.64013 .42912 m .64119 .43274 L .63742 .43203 L F
.698 .244 .169 r
.63742 .43203 m .64119 .43274 L .64087 .43405 L F
.737 .731 .845 r
.6434 .43033 m .64119 .43274 L .64013 .42912 L F
.474 0 0 r
.64119 .43274 m .64326 .43375 L .64087 .43405 L F
.471 .252 .498 r
.35273 .6077 m .3508 .60598 L .35294 .60548 L F
.35273 .6077 m .35027 .60859 L .3508 .60598 L F
0 0 .36 r
.57301 .6399 m .57299 .63615 L .5731 .63687 L F
.592 .158 .186 r
.36654 .64038 m .36267 .64164 L .36447 .64101 L F
0 0 .449 r
.55978 .67815 m .56046 .67992 L .56025 .67762 L F
.28 0 .044 r
.50926 .6773 m .51155 .67668 L .51352 .67385 L F
.484 .107 .25 r
.51155 .67668 m .5157 .67363 L .51352 .67385 L F
.82 .993 .864 r
.60687 .66392 m .60769 .6643 L .60908 .66265 L F
.58 .455 .675 r
.53139 .64644 m .53237 .64877 L .53376 .64609 L F
.558 .844 .998 r
.34707 .64018 m .35237 .64108 L .35145 .63971 L F
.459 .665 .951 r
.35145 .63971 m .35237 .64108 L .35321 .6394 L F
.522 .741 .975 r
.35237 .64108 m .35458 .64064 L .35321 .6394 L F
.372 .542 .893 r
.73521 .50582 m .73747 .50505 L .73442 .50417 L F
.73521 .50582 m .73822 .5068 L .73747 .50505 L F
.882 .507 .327 r
.59329 .59171 m .5935 .59303 L .59467 .59151 L F
.821 .414 .278 r
.5935 .59303 m .59534 .59357 L .59467 .59151 L F
0 .312 .736 r
.47626 .67567 m .47592 .6757 L .47488 .67485 L F
.774 .707 .789 r
.47777 .67599 m .47567 .67571 L .47592 .6757 L F
.47777 .67599 m .47483 .6781 L .47326 .67539 L F
.639 .929 .972 r
.4796 .67491 m .47777 .67599 L .47592 .6757 L F
.4796 .67491 m .47592 .6757 L .47776 .67656 L F
0 .312 .736 r
.47776 .67656 m .47592 .6757 L .47626 .67567 L F
.774 .707 .789 r
.47567 .67571 m .47326 .67539 L .47592 .6757 L F
.514 .533 .814 r
.64241 .44041 m .64024 .44056 L .63911 .43738 L F
.29 0 0 r
.63906 .44215 m .64024 .44056 L .64241 .44041 L F
.789 .448 .41 r
.48768 .69706 m .48464 .6956 L .48702 .69472 L F
.48768 .69706 m .48545 .69791 L .48464 .6956 L F
.76 .395 .363 r
.48768 .69706 m .48674 .70004 L .48545 .69791 L F
0 0 .223 r
.48702 .69472 m .48789 .69763 L .48768 .69706 L F
0 0 0 r
.48789 .69763 m .48674 .70004 L .48768 .69706 L F
.68 .458 .578 r
.65112 .44967 m .64878 .45211 L .64843 .44976 L F
.021 .232 .738 r
.45846 .70989 m .45913 .70861 L .45631 .70669 L F
.45846 .70989 m .45924 .71002 L .45913 .70861 L F
.204 .405 .838 r
.44267 .59385 m .4418 .59508 L .44102 .59322 L F
.512 .826 1 r
.44267 .59385 m .44398 .59466 L .4418 .59508 L F
.716 .711 .844 r
.45847 .60796 m .45755 .61189 L .45663 .60857 L F
.45847 .60796 m .46074 .61106 L .45755 .61189 L F
.861 .48 0 r
.56422 .64074 m .56344 .64025 L .56249 .63728 L F
0 0 .455 r
.56422 .64074 m .56495 .64153 L .56344 .64025 L F
.56422 .64074 m .5656 .64285 L .56495 .64153 L F
.516 .56 .839 r
.55724 .59607 m .55791 .59347 L .55571 .59409 L F
.686 .628 .785 r
.46732 .70054 m .46607 .70486 L .46455 .70369 L F
.46732 .70054 m .46864 .70409 L .46607 .70486 L F
.481 .332 .602 r
.77291 .49693 m .76943 .49599 L .77218 .49409 L F
.77291 .49693 m .76952 .49852 L .76943 .49599 L F
.621 .449 .628 r
.42429 .61167 m .42673 .61165 L .42668 .60885 L F
.65 .472 .63 r
.42668 .60885 m .42673 .61165 L .42983 .61106 L F
.321 .488 .868 r
.32109 .62618 m .32326 .62961 L .32382 .62764 L F
.604 .485 .691 r
.32139 .63159 m .32382 .62764 L .32326 .62961 L F
.773 .78 .859 r
.30808 .62261 m .30928 .62449 L .31148 .62291 L F
.728 .305 .242 r
.56157 .59369 m .56407 .59639 L .56512 .59425 L F
.377 0 .047 r
.56616 .59569 m .56512 .59425 L .56407 .59639 L F
.56616 .59569 m .56742 .59412 L .56512 .59425 L F
.621 .598 .806 r
.77385 .50215 m .77088 .5031 L .77048 .50056 L F
.754 .517 .573 r
.62676 .45271 m .62697 .45507 L .62503 .45207 L F
.62676 .45271 m .62864 .45486 L .62697 .45507 L F
.11 0 0 r
.36403 .59796 m .36247 .59945 L .3607 .59981 L F
.205 0 0 r
.36513 .59859 m .36247 .59945 L .36403 .59796 L F
.21 0 0 r
.36626 .59743 m .36513 .59859 L .36403 .59796 L F
.675 .377 0 r
.4868 .68562 m .48742 .68759 L .48675 .68548 L F
.465 .651 .94 r
.48742 .68759 m .48906 .68501 L .48675 .68548 L F
.48742 .68759 m .49022 .68656 L .48906 .68501 L F
.44 .189 .436 r
.47604 .65523 m .47778 .65698 L .47789 .65447 L F
.47604 .65523 m .47562 .65752 L .47778 .65698 L F
.401 0 0 r
.63648 .44686 m .63575 .44616 L .63405 .4459 L F
.63648 .44686 m .63806 .44712 L .63575 .44616 L F
.77 .441 .429 r
.74416 .48936 m .74634 .49205 L .74833 .48993 L F
.791 .472 .448 r
.74634 .49205 m .74982 .49304 L .74833 .48993 L F
.857 .489 .354 r
.74833 .48993 m .74982 .49304 L .75117 .49271 L F
0 0 .389 r
.4767 .69411 m .4757 .69566 L .47559 .69233 L F
.4767 .69411 m .47559 .69233 L .47408 .69182 L F
.785 .509 .519 r
.50624 .64677 m .50306 .64811 L .50418 .64635 L F
.614 .16 .15 r
.41004 .61377 m .40894 .61427 L .41244 .61438 L F
.441 .275 .559 r
.22884 .56436 m .22681 .56253 L .22904 .56206 L F
.22884 .56436 m .22667 .56552 L .22681 .56253 L F
.426 .855 .725 r
.79381 .51329 m .79192 .51435 L .79061 .5148 L F
.325 .096 .404 r
.21182 .60824 m .20948 .61131 L .20974 .60887 L F
0 0 0 r
.31957 .62269 m .32087 .62235 L .32116 .6222 L F
.505 .638 .913 r
.32141 .62212 m .32304 .62287 L .3233 .62182 L F
.32094 .62233 m .32381 .62322 L .32141 .62212 L F
.591 .579 .808 r
.31869 .62668 m .32109 .62618 L .31957 .62269 L F
.458 .504 .818 r
.31957 .62269 m .32109 .62618 L .32229 .62408 L F
.781 .716 .792 r
.32229 .62408 m .31824 .62397 L .31976 .62289 L F
0 0 0 r
.31957 .62269 m .32116 .6222 L .32077 .62204 L F
.27 .648 .966 r
.32066 .62224 m .321 .62231 L .31957 .62269 L F
.224 .499 .902 r
.31957 .62269 m .32229 .62408 L .32066 .62224 L F
.781 .716 .792 r
.32229 .62408 m .31976 .62289 L .32079 .62239 L F
.505 .638 .913 r
.32066 .62224 m .32229 .62408 L .32381 .62322 L F
.32381 .62322 m .32229 .62408 L .32066 .62224 L F
.32304 .62287 m .32381 .62322 L .32354 .62247 L F
0 0 0 r
.32087 .62235 m .32096 .62232 L .32115 .62221 L F
.32096 .62232 m .321 .62231 L .32104 .62229 L F
.32096 .62232 m .32104 .62229 L .32115 .62221 L F
.32087 .62235 m .32115 .62221 L .32116 .6222 L F
.505 .638 .913 r
.32381 .62322 m .32066 .62224 L .32302 .62222 L F
.768 .977 .916 r
.32302 .62222 m .32047 .62402 L .32154 .62405 L F
.32265 .62317 m .32154 .62405 L .32229 .62408 L F
.32302 .62222 m .32154 .62405 L .32265 .62317 L F
.505 .638 .913 r
.32304 .62287 m .32354 .62247 L .3233 .62182 L F
.32066 .62224 m .32094 .62233 L .32141 .62212 L F
.781 .716 .792 r
.32079 .62239 m .31976 .62289 L .32066 .62224 L F
.706 .985 .84 r
.31824 .62397 m .31883 .62259 L .32066 .62224 L F
.071 0 0 r
.32066 .62224 m .31883 .62259 L .32152 .62235 L F
.32124 .62224 m .32152 .62235 L .32302 .62222 L F
.426 .014 .153 r
.321 .62231 m .3233 .62182 L .32518 .61983 L F
.607 .396 .57 r
.32066 .62224 m .3233 .62182 L .321 .62231 L F
.071 0 0 r
.32066 .62224 m .32152 .62235 L .32124 .62224 L F
0 0 0 r
.32077 .62204 m .32116 .6222 L .32373 .62043 L F
.205 .359 .798 r
.32373 .62043 m .32344 .61681 L .32248 .61693 L F
.32373 .62043 m .32518 .61983 L .32344 .61681 L F
.426 .014 .153 r
.321 .62231 m .32518 .61983 L .32373 .62043 L F
0 .37 .703 r
.5627 .59749 m .56155 .597 L .55919 .59613 L F
.372 0 .135 r
.3607 .59981 m .35754 .60169 L .35849 .60034 L F
.803 .409 .308 r
.5318 .67828 m .53543 .68088 L .53544 .67844 L F
.631 .564 .761 r
.43041 .60013 m .43132 .60285 L .43397 .60206 L F
.652 .687 .87 r
.43132 .60285 m .43329 .60297 L .43397 .60206 L F
.486 .48 .776 r
.43132 .60285 m .43383 .6052 L .43329 .60297 L F
.601 .211 .275 r
.42049 .61348 m .42311 .61368 L .42429 .61167 L F
.587 .195 .267 r
.42429 .61167 m .42311 .61368 L .42654 .61331 L F
.563 .216 .338 r
.42429 .61167 m .42654 .61331 L .42673 .61165 L F
.64 .345 .454 r
.4902 .65728 m .48776 .65517 L .48769 .6574 L F
.92 .972 .771 r
.48705 .65431 m .48776 .65517 L .48928 .65223 L F
.975 .923 .621 r
.48619 .65619 m .48776 .65517 L .48705 .65431 L F
.559 .566 .817 r
.52316 .6545 m .52677 .65736 L .52752 .65598 L F
.664 .595 .768 r
.52595 .65201 m .52752 .65598 L .52981 .65489 L F
.677 .442 .558 r
.52677 .65736 m .52981 .65489 L .52752 .65598 L F
.973 .661 .326 r
.55994 .68172 m .56059 .68417 L .55937 .68327 L F
.795 .542 .555 r
.54499 .68114 m .54519 .68377 L .54853 .68405 L F
.251 .156 .548 r
.54853 .68405 m .54974 .6854 L .54994 .68295 L F
.563 .632 .878 r
.42527 .58842 m .42128 .58607 L .4254 .58782 L F
.464 .632 .927 r
.42637 .58701 m .42527 .58842 L .4254 .58782 L F
.42637 .58701 m .42747 .58837 L .42527 .58842 L F
.611 .721 .924 r
.78471 .52384 m .78529 .52015 L .78449 .52078 L F
.78471 .52384 m .78737 .52312 L .78529 .52015 L F
.323 .061 .352 r
.52353 .68657 m .52652 .68587 L .52653 .68297 L F
.287 .023 .328 r
.52653 .68297 m .52803 .68338 L .52958 .68024 L F
.305 .048 .349 r
.52653 .68297 m .52825 .68524 L .52803 .68338 L F
.52653 .68297 m .52652 .68587 L .52825 .68524 L F
.566 .303 .477 r
.42917 .62041 m .42908 .62232 L .42667 .62239 L F
.635 .36 .485 r
.42917 .62041 m .4313 .62283 L .42908 .62232 L F
.929 .648 .488 r
.54349 .68266 m .54499 .68114 L .54442 .68074 L F
.54349 .68266 m .54519 .68377 L .54499 .68114 L F
.698 .7 .848 r
.75236 .51566 m .75597 .51635 L .75518 .5151 L F
.686 .695 .853 r
.75518 .5151 m .75597 .51635 L .75833 .5155 L F
.311 0 0 r
.3477 .58395 m .34999 .58398 L .35164 .58303 L F
.287 0 0 r
.34999 .58398 m .35394 .58313 L .35164 .58303 L F
.383 .802 .607 r
.78613 .48884 m .78874 .48723 L .78768 .48734 L F
.413 .861 .892 r
.78874 .48723 m .78983 .48614 L .78768 .48734 L F
.78874 .48723 m .79129 .48642 L .78983 .48614 L F
.669 .173 .062 r
.74982 .49304 m .75034 .49427 L .75117 .49271 L F
.517 .012 0 r
.75117 .49271 m .7525 .49423 L .75374 .49407 L F
.75117 .49271 m .75034 .49427 L .7525 .49423 L F
.712 .451 .528 r
.49506 .67241 m .49737 .67503 L .49508 .67475 L F
.71 .451 .531 r
.49725 .67278 m .49737 .67503 L .49506 .67241 L F
.719 .516 .615 r
.65112 .44967 m .65134 .45211 L .64878 .45211 L F
.533 .473 .735 r
.65242 .449 m .65134 .45211 L .65112 .44967 L F
.737 .579 .679 r
.52853 .71878 m .52668 .71924 L .52578 .71584 L F
.909 .673 .569 r
.52534 .71856 m .52668 .71924 L .52578 .71584 L F
.737 .579 .679 r
.52853 .71878 m .52578 .71584 L .52534 .71856 L F
.588 .6 .832 r
.52534 .71856 m .52805 .72117 L .52853 .71878 L F
.522 .473 .743 r
.31494 .60902 m .31559 .61154 L .31774 .61084 L F
.521 .645 .912 r
.4931 .6641 m .49414 .66157 L .49133 .66129 L F
.445 .277 .559 r
.49488 .66087 m .49501 .66364 L .4931 .6641 L F
.49488 .66087 m .49501 .66364 L .4931 .6641 L F
.521 .645 .912 r
.4931 .6641 m .49501 .66364 L .49414 .66157 L F
.363 .074 .333 r
.4931 .6641 m .4925 .66604 L .49501 .66364 L F
.599 .603 .827 r
.76791 .516 m .76924 .51215 L .7668 .51305 L F
.76791 .516 m .77049 .5155 L .76924 .51215 L F
.382 0 .024 r
.40083 .63176 m .39702 .63359 L .39852 .63195 L F
.49 .139 .298 r
.52895 .68999 m .52815 .69182 L .52567 .69207 L F
.535 .291 .492 r
.53075 .6892 m .52815 .69182 L .52895 .68999 L F
.788 .985 .726 r
.4681 .61979 m .46987 .61712 L .47062 .61736 L F
.624 .423 .589 r
.47062 .61736 m .47062 .62006 L .4681 .61979 L F
.791 .999 .833 r
.47062 .61736 m .47159 .61531 L .47307 .61658 L F
.47062 .61736 m .46987 .61712 L .47159 .61531 L F
.767 .636 .716 r
.47307 .61658 m .47062 .62006 L .47062 .61736 L F
.409 .804 .987 r
.40843 .5832 m .41073 .58287 L .41189 .58344 L F
.48 .814 .999 r
.41073 .58287 m .41419 .58315 L .41189 .58344 L F
.375 .831 .921 r
.55614 .66878 m .55615 .66841 L .55435 .66931 L F
.437 .053 .211 r
.5553 .67087 m .55435 .66931 L .55614 .66878 L F
0 0 .443 r
.55435 .66931 m .55519 .67227 L .5553 .67087 L F
.437 .053 .211 r
.5553 .67087 m .55338 .67164 L .55435 .66931 L F
0 0 .443 r
.55435 .66931 m .5553 .67087 L .55614 .66878 L F
.542 .747 .971 r
.40755 .5906 m .40823 .58852 L .40592 .58873 L F
.40755 .5906 m .40983 .59024 L .40823 .58852 L F
.594 .342 .505 r
.48743 .64053 m .48991 .64008 L .49039 .6379 L F
.543 .357 .578 r
.48991 .64008 m .49213 .63712 L .49039 .6379 L F
.597 .357 .524 r
.50048 .672 m .49737 .67503 L .49725 .67278 L F
.759 .722 .818 r
.46223 .60841 m .46074 .61106 L .45847 .60796 L F
.523 .267 .468 r
.51646 .67536 m .51623 .67777 L .51403 .67797 L F
.551 .291 .474 r
.51867 .67726 m .51623 .67777 L .51646 .67536 L F
.519 .297 .517 r
.51878 .67493 m .51867 .67726 L .51646 .67536 L F
.466 .215 .449 r
.50777 .73557 m .51093 .73297 L .50789 .73322 L F
.396 .431 .78 r
.79582 .51289 m .79507 .51625 L .79381 .51329 L F
.79582 .51289 m .79787 .51716 L .79507 .51625 L F
.816 .457 .378 r
.58125 .63386 m .57946 .63556 L .57936 .63394 L F
.154 0 .271 r
.22551 .57622 m .22332 .57926 L .224 .57714 L F
.473 .535 .84 r
.46217 .71678 m .46356 .71481 L .46137 .71504 L F
.46217 .71678 m .46503 .71809 L .46356 .71481 L F
.624 .752 .939 r
.53695 .62002 m .54081 .6212 L .53927 .61947 L F
.771 .262 0 r
.54081 .6212 m .54109 .61988 L .53927 .61947 L F
.54087 .62091 m .54124 .62074 L .54109 .61988 L F
.093 .651 .767 r
.54124 .62074 m .54029 .62072 L .54138 .62068 L F
.242 0 0 r
.54124 .62074 m .54398 .62059 L .54492 .61978 L F
.093 .651 .767 r
.54124 .62074 m .54138 .62068 L .54398 .62059 L F
.771 .262 0 r
.54081 .6212 m .54124 .62074 L .54087 .62091 L F
.54081 .6212 m .53958 .62173 L .54124 .62074 L F
.54081 .6212 m .54234 .62312 L .53958 .62173 L F
.776 .298 .098 r
.54409 .62343 m .54234 .62312 L .54081 .6212 L F
.572 .616 .858 r
.7779 .52099 m .77882 .52281 L .77973 .52212 L F
0 .472 .765 r
.35891 .62306 m .36041 .62358 L .3569 .62257 L F
.015 .562 .833 r
.36232 .62382 m .36041 .62358 L .35891 .62306 L F
.491 .849 .598 r
.55587 .69743 m .55755 .69613 L .55908 .69485 L F
.462 .816 .997 r
.38706 .58228 m .38928 .58186 L .39073 .58259 L F
.487 .802 1 r
.38928 .58186 m .39295 .58237 L .39073 .58259 L F
.414 .338 .662 r
.51645 .68938 m .51894 .69159 L .519 .68965 L F
.717 .348 .349 r
.55647 .62269 m .55831 .62504 L .55919 .6229 L F
.706 .395 .447 r
.55831 .62504 m .56288 .62307 L .55919 .6229 L F
0 0 .329 r
.78684 .50872 m .78684 .51198 L .78605 .51267 L F
0 .102 .624 r
.78708 .51082 m .78723 .51142 L .78684 .51198 L F
.807 .443 .367 r
.78684 .51198 m .79061 .5148 L .78795 .5138 L F
.78684 .51198 m .78798 .5144 L .79061 .5148 L F
0 .102 .624 r
.78723 .51142 m .78798 .5144 L .78684 .51198 L F
.137 .469 .893 r
.78684 .51198 m .78795 .5138 L .78626 .51279 L F
.78684 .51198 m .78626 .51279 L .78605 .51267 L F
.467 .426 .729 r
.43397 .60206 m .43329 .60297 L .43584 .60196 L F
.613 .557 .768 r
.43383 .6052 m .43584 .60196 L .43329 .60297 L F
.374 .001 .195 r
.3313 .58799 m .33349 .58756 L .33438 .58605 L F
.506 .61 .89 r
.7747 .52001 m .77628 .51809 L .77419 .51815 L F
.7747 .52001 m .7779 .52099 L .77628 .51809 L F
.778 .986 .898 r
.45494 .6033 m .45267 .60563 L .45107 .60499 L F
.65 .652 .839 r
.45494 .6033 m .4562 .60617 L .45267 .60563 L F
.343 .052 .319 r
.50276 .65706 m .49977 .65979 L .50044 .65769 L F
.352 .378 .748 r
.21845 .58759 m .21788 .59142 L .21742 .58709 L F
.21845 .58759 m .21938 .5911 L .21788 .59142 L F
.499 .36 .623 r
.21938 .5911 m .21756 .59381 L .21788 .59142 L F
0 .526 .805 r
.59342 .66995 m .58979 .66904 L .59088 .67056 L F
.584 .639 .872 r
.73945 .50993 m .74064 .50648 L .73822 .5068 L F
.73945 .50993 m .74196 .5094 L .74064 .50648 L F
.251 .598 .951 r
.36504 .62439 m .36421 .6252 L .36232 .62382 L F
.36504 .62439 m .36627 .6257 L .36421 .6252 L F
.66 .384 .492 r
.52254 .66814 m .52337 .67147 L .52361 .669 L F
.851 .587 .539 r
.5257 .72377 m .52805 .72117 L .52652 .72159 L F
.64 .695 .885 r
.77753 .50397 m .77385 .50215 L .77608 .50101 L F
.5 .545 .834 r
.77858 .50045 m .77753 .50397 L .77608 .50101 L F
.77858 .50045 m .77974 .50371 L .77753 .50397 L F
.561 .675 .915 r
.43864 .59056 m .43759 .59202 L .4373 .59044 L F
.697 .425 .507 r
.63246 .45465 m .63085 .4574 L .63076 .45498 L F
.63246 .45465 m .63488 .45747 L .63085 .4574 L F
.711 .512 .618 r
.63669 .45495 m .63488 .45747 L .63246 .45465 L F
.695 .218 .112 r
.33324 .63202 m .33048 .63103 L .33215 .63192 L F
.468 .542 .85 r
.20961 .54557 m .2075 .5456 L .2076 .54418 L F
.461 .083 .234 r
.32237 .5929 m .3255 .59102 L .32331 .59145 L F
.461 .183 .405 r
.32331 .59145 m .3255 .59102 L .32571 .58973 L F
.549 .126 .191 r
.48542 .68404 m .48426 .6855 L .48174 .68455 L F
.461 .01 .091 r
.48816 .68403 m .48426 .6855 L .48542 .68404 L F
.4 .211 .506 r
.21369 .60221 m .21357 .6061 L .21152 .60633 L F
.298 .106 .444 r
.21608 .59967 m .21369 .60221 L .21395 .60099 L F
.21608 .59967 m .21585 .60202 L .21369 .60221 L F
.19 .048 .446 r
.2152 .60403 m .21369 .60221 L .21585 .60202 L F
.2152 .60403 m .21357 .6061 L .21369 .60221 L F
0 0 .444 r
.48464 .6956 m .48575 .69669 L .48702 .69472 L F
.48464 .6956 m .48545 .69791 L .48575 .69669 L F
.699 .527 .652 r
.57608 .61987 m .57298 .61678 L .57323 .61883 L F
.479 .499 .801 r
.74329 .51277 m .74433 .50905 L .74196 .5094 L F
.74329 .51277 m .74541 .51252 L .74433 .50905 L F
.976 .894 .675 r
.61187 .65096 m .61383 .64962 L .61284 .64872 L F
.61187 .65096 m .61267 .65206 L .61383 .64962 L F
.46 .378 .676 r
.31494 .60902 m .31663 .60504 L .31507 .60541 L F
.31494 .60902 m .31691 .60863 L .31663 .60504 L F
.48 .478 .778 r
.31494 .60902 m .31774 .61084 L .31691 .60863 L F
.956 .69 .49 r
.5785 .65139 m .58005 .65186 L .57986 .64927 L F
.155 .077 .509 r
.58165 .64508 m .58119 .64887 L .57986 .64927 L F
.403 .095 .325 r
.58119 .64887 m .5785 .65139 L .57986 .64927 L F
.908 .567 .387 r
.54169 .63702 m .54309 .6399 L .544 .63833 L F
.674 .259 .249 r
.544 .63833 m .54309 .6399 L .54536 .63995 L F
.573 .272 .419 r
.64253 .45255 m .64299 .45439 L .63929 .45487 L F
.632 .308 .404 r
.64253 .45255 m .645 .4544 L .64299 .45439 L F
.619 .317 .437 r
.64516 .45247 m .645 .4544 L .64253 .45255 L F
.341 0 .229 r
.46351 .66722 m .46491 .66814 L .46563 .66674 L F
.46351 .66722 m .46281 .66879 L .46491 .66814 L F
.458 .171 .388 r
.40375 .61892 m .40632 .61674 L .4043 .6175 L F
.797 .73 .79 r
.63296 .43553 m .63306 .43749 L .62926 .43708 L F
.802 .717 .772 r
.63306 .43749 m .63046 .44053 L .62926 .43708 L F
.72 .64 .768 r
.63547 .43472 m .63306 .43749 L .63296 .43553 L F
.602 .368 .535 r
.53482 .65679 m .53865 .65477 L .53677 .6545 L F
.048 .125 .623 r
.72389 .49303 m .725 .49144 L .72361 .48931 L F
.149 .269 .732 r
.72389 .49303 m .72613 .49506 L .725 .49144 L F
.406 .581 .911 r
.44884 .69872 m .45272 .70137 L .45079 .69871 L F
.074 .37 .837 r
.45079 .69871 m .45272 .70137 L .45337 .70039 L F
0 .221 .738 r
.45272 .70137 m .45489 .70347 L .45337 .70039 L F
.194 0 .316 r
.21901 .58541 m .21845 .58759 L .21742 .58709 L F
.69 .395 .47 r
.5159 .73 m .51884 .73017 L .51917 .72885 L F
.536 .4 .643 r
.51884 .73016 m .51882 .73016 L .51917 .72885 L F
.51882 .73016 m .5159 .73 L .51613 .72992 L F
.51882 .73016 m .51613 .72992 L .51917 .72885 L F
.34 .07 .351 r
.51917 .72885 m .52146 .72896 L .52064 .72851 L F
.51917 .72885 m .51884 .73017 L .52052 .7294 L F
.52085 .72893 m .52102 .72902 L .52094 .72894 L F
.425 .23 .51 r
.52291 .73133 m .52104 .72901 L .52224 .72989 L F
.34 .07 .351 r
.52102 .72902 m .52116 .7291 L .52104 .72901 L F
.52102 .72902 m .52104 .72901 L .52094 .72894 L F
.425 .23 .51 r
.52291 .73133 m .5209 .73226 L .52068 .72917 L F
.52104 .72901 m .52068 .72917 L .52064 .72851 L F
.52291 .73133 m .52068 .72917 L .52104 .72901 L F
.34 .07 .351 r
.51917 .72885 m .52052 .7294 L .52085 .72893 L F
.559 .328 .522 r
.52064 .72851 m .52068 .72917 L .52051 .7294 L F
.52003 .72949 m .52051 .7294 L .51828 .7323 L F
.52064 .72851 m .52051 .7294 L .52003 .72949 L F
.52064 .72851 m .52003 .72949 L .51917 .72885 L F
.62 .728 .924 r
.51886 .73016 m .51884 .73017 L .51882 .73016 L F
.559 .328 .522 r
.52003 .72949 m .51828 .7323 L .51883 .73016 L F
.52003 .72949 m .51883 .73016 L .51917 .72885 L F
.62 .728 .924 r
.5212 .72891 m .52016 .72947 L .52011 .72945 L F
.5211 .72889 m .52011 .72945 L .51604 .72783 L F
.34 .07 .351 r
.52085 .72893 m .52052 .7294 L .52116 .7291 L F
.62 .728 .924 r
.5212 .72891 m .52011 .72945 L .5211 .72889 L F
.52016 .72947 m .51886 .73016 L .51843 .7298 L F
.52016 .72947 m .51843 .7298 L .51604 .72783 L F
.34 .07 .351 r
.52094 .72894 m .52116 .7291 L .52146 .72896 L F
.62 .728 .924 r
.52146 .72896 m .52116 .7291 L .5212 .72891 L F
.559 .328 .522 r
.52052 .7294 m .5209 .73226 L .51842 .7323 L F
.52068 .72917 m .5207 .72936 L .52052 .7294 L F
.5207 .72936 m .5209 .73226 L .52052 .7294 L F
.62 .728 .924 r
.52116 .7291 m .52052 .7294 L .5212 .72891 L F
.52052 .7294 m .51886 .73016 L .52016 .72947 L F
.52052 .7294 m .52016 .72947 L .5212 .72891 L F
.425 .23 .51 r
.52224 .72989 m .52118 .72898 L .52196 .7293 L F
.5212 .72891 m .52064 .72851 L .52121 .72885 L F
.52114 .72894 m .52064 .72851 L .5212 .72891 L F
.62 .728 .924 r
.52127 .72887 m .51627 .72788 L .51938 .72796 L F
.5212 .72891 m .51604 .72783 L .52127 .72887 L F
.425 .23 .51 r
.52104 .72901 m .52064 .72851 L .52224 .72989 L F
.559 .328 .522 r
.52068 .72917 m .51842 .7323 L .51828 .7323 L F
.398 0 0 r
.52146 .72896 m .52196 .7293 L .52126 .72888 L F
.52146 .72896 m .52126 .72888 L .52064 .72851 L F
.62 .728 .924 r
.52146 .72896 m .5212 .72891 L .52126 .72888 L F
.52146 .72896 m .52126 .72888 L .52127 .72887 L F
0 .031 .602 r
.52162 .72792 m .52146 .72896 L .51967 .7281 L F
.52162 .72792 m .51967 .7281 L .51938 .72796 L F
.425 .23 .51 r
.52118 .72898 m .52114 .72894 L .5212 .72891 L F
.52118 .72898 m .52121 .72885 L .52196 .7293 L F
0 .031 .602 r
.52162 .72792 m .52196 .7293 L .52146 .72896 L F
0 0 .438 r
.52162 .72792 m .52291 .73133 L .52196 .7293 L F
.554 .559 .813 r
.52463 .73006 m .52291 .73133 L .52162 .72792 L F
.52463 .73006 m .52162 .72792 L .52472 .72769 L F
.211 0 .036 r
.52068 .73 m .52323 .72778 L .52162 .72792 L F
.646 .824 .969 r
.52472 .72769 m .52162 .72792 L .52397 .72714 L F
.211 0 .036 r
.52323 .72778 m .52397 .72714 L .52162 .72792 L F
.333 .03 .293 r
.51938 .72796 m .52068 .73 L .52158 .72802 L F
.51938 .72796 m .52158 .72802 L .52162 .72792 L F
.62 .728 .924 r
.51627 .72788 m .51604 .72783 L .51938 .72796 L F
.51886 .73016 m .51882 .73016 L .51604 .72783 L F
.645 .734 .913 r
.51604 .72783 m .51882 .73016 L .5159 .73 L F
.51882 .73016 m .51884 .73017 L .5159 .73 L F
.536 .4 .643 r
.51828 .7323 m .5159 .73 L .51884 .73016 L F
.652 .46 .611 r
.51054 .67805 m .51053 .68087 L .50811 .68103 L F
.649 .458 .611 r
.51401 .68024 m .51054 .67805 L .51403 .67797 L F
.51401 .68024 m .51053 .68087 L .51054 .67805 L F
.551 .029 0 r
.53351 .63415 m .53706 .63483 L .53539 .63424 L F
.689 .476 .593 r
.46909 .69177 m .47009 .69595 L .46567 .69497 L F
.303 .457 .849 r
.47054 .69141 m .47023 .6925 L .46909 .69177 L F
.685 .473 .594 r
.47121 .69541 m .46909 .69177 L .47023 .6925 L F
.47121 .69541 m .47009 .69595 L .46909 .69177 L F
.326 .088 .392 r
.57965 .62029 m .57896 .6231 L .57732 .62322 L F
.368 .415 .779 r
.57732 .62322 m .58016 .62446 L .57896 .6231 L F
.609 .603 .819 r
.48221 .71175 m .48499 .71132 L .48399 .70912 L F
.571 .641 .882 r
.483 .6606 m .48466 .65784 L .4823 .66054 L F
.483 .6606 m .48568 .66129 L .48466 .65784 L F
.602 .419 .607 r
.45129 .68103 m .45398 .68093 L .45379 .67814 L F
.177 0 .284 r
.45379 .67814 m .45541 .67763 L .45598 .67522 L F
.277 .178 .559 r
.45379 .67814 m .45541 .67989 L .45541 .67763 L F
.281 .179 .557 r
.45379 .67814 m .45398 .68093 L .45541 .67989 L F
.394 .191 .482 r
.49291 .69505 m .49536 .69186 L .49322 .69308 L F
.228 .438 .858 r
.22545 .5516 m .22477 .55318 L .22271 .55058 L F
.22545 .5516 m .22614 .55333 L .22477 .55318 L F
.494 .314 .566 r
.49759 .66286 m .49488 .66087 L .49759 .6612 L F
.49759 .66286 m .49501 .66364 L .49488 .66087 L F
.34 0 0 r
.31362 .61843 m .3159 .61936 L .31433 .61867 L F
.878 .855 .815 r
.56025 .67762 m .56203 .6754 L .56019 .67435 L F
.449 .417 .731 r
.41133 .59372 m .41279 .59117 L .41056 .5922 L F
.41133 .59372 m .41321 .59357 L .41279 .59117 L F
.406 .106 .341 r
.54697 .66372 m .54918 .66326 L .54976 .66172 L F
.557 .412 .64 r
.54707 .66623 m .54918 .66326 L .54697 .66372 L F
.918 .722 .622 r
.59831 .61377 m .59991 .61467 L .59862 .61133 L F
.929 .659 .505 r
.59831 .61377 m .59847 .61629 L .59991 .61467 L F
.828 .486 .408 r
.59847 .61629 m .60101 .6169 L .59991 .61467 L F
.042 0 .378 r
.52485 .68929 m .52652 .68587 L .52353 .68657 L F
.223 .491 .897 r
.73101 .49855 m .7321 .49741 L .73028 .49694 L F
.121 .327 .795 r
.73101 .49855 m .73358 .50048 L .7321 .49741 L F
.457 .315 .6 r
.31602 .60016 m .31802 .59965 L .31797 .59703 L F
.511 .391 .653 r
.31623 .60265 m .31802 .59965 L .31602 .60016 L F
.016 0 0 r
.35394 .58313 m .35584 .58312 L .35755 .58302 L F
.448 0 0 r
.35584 .58312 m .35977 .58216 L .35755 .58302 L F
.605 .852 .991 r
.48432 .67187 m .4858 .67288 L .48779 .67193 L F
0 0 0 r
.53942 .71274 m .54115 .71192 L .54149 .71169 L F
.527 .845 .545 r
.54149 .71169 m .54255 .71054 L .54427 .7116 L F
.54149 .71169 m .54115 .71192 L .54255 .71054 L F
.568 .523 .764 r
.3255 .59102 m .32691 .58939 L .32571 .58973 L F
.647 .774 .941 r
.64588 .43106 m .64745 .43293 L .64954 .43179 L F
.64954 .43179 m .64745 .43293 L .64588 .43106 L F
.895 .882 .813 r
.56288 .62647 m .56563 .62594 L .56432 .62476 L F
.56288 .62647 m .56316 .62875 L .56563 .62594 L F
.733 .574 .675 r
.56563 .62594 m .56316 .62875 L .56632 .62852 L F
.732 .372 .367 r
.56856 .62731 m .56563 .62594 L .56632 .62852 L F
.56856 .62731 m .56949 .62717 L .56563 .62594 L F
.564 .735 .956 r
.55551 .67526 m .5553 .67087 L .55519 .67227 L F
.55551 .67526 m .55552 .67379 L .5553 .67087 L F
.55551 .67526 m .55785 .67481 L .55552 .67379 L F
.128 0 0 r
.38975 .59262 m .3881 .59283 L .38595 .59275 L F
.262 .77 .783 r
.39033 .59224 m .38975 .59262 L .39191 .59208 L F
.39033 .59224 m .3881 .59283 L .38975 .59262 L F
.688 .281 .27 r
.51311 .64886 m .51128 .64987 L .51008 .64882 L F
.745 .519 .588 r
.51008 .64882 m .51006 .6513 L .50663 .6508 L F
.524 .339 .572 r
.51008 .64882 m .51237 .65083 L .51006 .6513 L F
.86 .995 .82 r
.51166 .64808 m .5095 .65069 L .5096 .6508 L F
.51057 .65027 m .5096 .6508 L .51006 .6513 L F
.51166 .64808 m .5096 .6508 L .51057 .65027 L F
.688 .281 .27 r
.5136 .64887 m .51237 .65083 L .51128 .64987 L F
.5136 .64887 m .51128 .64987 L .51311 .64886 L F
.593 .379 .56 r
.48772 .66934 m .49023 .66907 L .49035 .66657 L F
.629 .485 .667 r
.49023 .66907 m .4925 .66604 L .49035 .66657 L F
.559 .566 .817 r
.52316 .6545 m .5247 .65808 L .52677 .65736 L F
.684 .217 .139 r
.5247 .65808 m .52677 .65994 L .52316 .65941 L F
.466 .294 .564 r
.52677 .65736 m .52677 .65994 L .5247 .65808 L F
.698 .246 .175 r
.52316 .65941 m .52521 .65972 L .52547 .66142 L F
.52521 .65972 m .52677 .65994 L .52558 .66129 L F
.52521 .65972 m .52558 .66129 L .52547 .66142 L F
.684 .217 .139 r
.52482 .65804 m .52621 .66045 L .52677 .65736 L F
.5247 .65808 m .52491 .65841 L .52482 .65804 L F
.52491 .65841 m .52621 .66045 L .52482 .65804 L F
.5247 .65808 m .52316 .65941 L .52621 .66045 L F
0 .148 .678 r
.46628 .72129 m .46503 .71809 L .46649 .71871 L F
.904 .627 .508 r
.60915 .63704 m .60934 .63931 L .61093 .63755 L F
.864 .558 .469 r
.60934 .63931 m .61125 .64011 L .61093 .63755 L F
.313 0 .17 r
.45079 .68321 m .45292 .6825 L .45129 .68103 L F
.506 .112 .228 r
.45129 .68103 m .45292 .6825 L .45398 .68093 L F
.767 .636 .716 r
.47307 .61658 m .47418 .62029 L .47062 .62006 L F
.646 .189 .153 r
.47418 .62029 m .47255 .62189 L .47062 .62006 L F
0 0 0 r
.47626 .61615 m .47418 .62029 L .47307 .61658 L F
.47626 .61615 m .47503 .61883 L .47418 .62029 L F
.675 .906 .568 r
.47503 .61883 m .47255 .62189 L .47418 .62029 L F
.731 .384 .391 r
.4796 .67491 m .48168 .67741 L .48334 .67517 L F
.69 .332 .363 r
.48168 .67741 m .48552 .67735 L .48334 .67517 L F
.229 0 .007 r
.57453 .59695 m .57091 .59956 L .57096 .59699 L F
.57453 .59695 m .57344 .59879 L .57091 .59956 L F
.276 0 .095 r
.57453 .59695 m .57572 .59834 L .57344 .59879 L F
.57453 .59695 m .57709 .59616 L .57572 .59834 L F
.838 .418 .239 r
.54409 .62343 m .54293 .62467 L .54234 .62312 L F
.745 .286 .161 r
.54409 .62343 m .54648 .62572 L .54293 .62467 L F
.952 .748 .592 r
.57965 .62029 m .5786 .61704 L .57817 .61891 L F
.56 .891 .637 r
.57896 .6231 m .58188 .6206 L .57965 .62029 L F
.582 .687 .913 r
.57839 .6145 m .57913 .61251 L .57707 .61227 L F
.57839 .6145 m .58101 .61392 L .57913 .61251 L F
.699 .527 .652 r
.57608 .61987 m .57839 .6145 L .57298 .61678 L F
.963 .766 .324 r
.57817 .61891 m .57839 .6145 L .57608 .61987 L F
.57817 .61891 m .57772 .61542 L .57839 .6145 L F
.97 .707 .285 r
.57839 .6145 m .57772 .61542 L .5786 .61704 L F
0 .023 .573 r
.4686 .70102 m .46864 .70409 L .46732 .70054 L F
.4686 .70102 m .46952 .7032 L .46864 .70409 L F
.748 .76 .863 r
.45838 .69173 m .46363 .6929 L .46075 .68866 L F
.179 .462 .885 r
.46075 .68866 m .46363 .6929 L .46374 .69106 L F
.863 .994 .753 r
.46374 .69106 m .46363 .6929 L .46092 .69456 L F
.732 .699 .819 r
.74887 .51508 m .75029 .51679 L .75236 .51566 L F
.896 .834 .778 r
.62388 .44631 m .62547 .44672 L .62349 .44594 L F
.823 .888 .89 r
.62396 .44626 m .62547 .44672 L .62388 .44631 L F
.977 .802 .602 r
.62372 .44613 m .62349 .44594 L .62396 .44613 L F
.632 .8 .963 r
.62387 .44625 m .62388 .44631 L .62349 .44594 L F
.977 .802 .602 r
.62354 .44613 m .62396 .44613 L .62396 .44626 L F
.632 .8 .963 r
.62356 .44424 m .62387 .44625 L .62349 .44594 L F
.977 .802 .602 r
.62354 .44613 m .62349 .44594 L .62372 .44613 L F
.62396 .44626 m .62396 .44613 L .62547 .44672 L F
.823 .888 .89 r
.62842 .44376 m .62396 .44626 L .62685 .44239 L F
.62396 .44626 m .62388 .44631 L .62396 .4462 L F
.62396 .44626 m .62396 .4462 L .62685 .44239 L F
.62842 .44376 m .62547 .44672 L .62396 .44626 L F
.977 .802 .602 r
.62441 .44919 m .62354 .44613 L .62547 .44672 L F
.496 .615 .899 r
.4225 .58395 m .42128 .58607 L .42044 .58427 L F
.4225 .58395 m .4254 .58782 L .42128 .58607 L F
.734 .839 .929 r
.78671 .50488 m .78336 .50495 L .78529 .50459 L F
.419 .865 .878 r
.78817 .50409 m .78671 .50488 L .78529 .50459 L F
.213 .283 .72 r
.7897 .50175 m .78921 .5035 L .78817 .50409 L F
.419 .865 .878 r
.78817 .50409 m .78922 .50412 L .78684 .50484 L F
.808 .692 .736 r
.78896 .50442 m .78922 .50412 L .78817 .50409 L F
.213 .283 .72 r
.78921 .5035 m .78896 .50442 L .78817 .50409 L F
.419 .865 .878 r
.78817 .50409 m .78684 .50484 L .78671 .50488 L F
.855 .844 .379 r
.51735 .64453 m .5181 .6434 L .51704 .6425 L F
.51735 .64453 m .5171 .6469 L .5181 .6434 L F
.855 .73 .725 r
.59861 .60493 m .59726 .60798 L .59982 .60858 L F
.863 .704 .684 r
.59726 .60798 m .59862 .61133 L .59982 .60858 L F
.921 .808 .718 r
.58705 .64532 m .58607 .64928 L .58455 .64831 L F
.723 .808 .338 r
.19371 .56771 m .19435 .56608 L .1971 .56651 L F
.138 0 0 r
.19515 .5662 m .1994 .56625 L .1971 .56651 L F
.19587 .56613 m .1994 .56625 L .19515 .5662 L F
.19435 .56608 m .19587 .56613 L .19515 .5662 L F
.19435 .56608 m .19763 .56633 L .1994 .56625 L F
.298 0 0 r
.19763 .56633 m .2014 .56449 L .1994 .56625 L F
.19763 .56633 m .19969 .5661 L .2001 .56571 L F
.19859 .56586 m .2001 .56571 L .2014 .56449 L F
.19763 .56633 m .2001 .56571 L .19859 .56586 L F
.58 .846 .995 r
.79913 .49524 m .80017 .49521 L .80015 .49397 L F
.015 0 0 r
.76427 .49299 m .76279 .49295 L .76181 .49275 L F
.76427 .49299 m .76548 .49293 L .76279 .49295 L F
.489 .416 .702 r
.46588 .61365 m .4635 .61557 L .4633 .6121 L F
0 0 0 r
.46331 .61643 m .4635 .61557 L .46588 .61365 L F
.662 .704 .878 r
.76325 .51227 m .7643 .51513 L .7668 .51305 L F
.624 .568 .772 r
.43041 .60013 m .43229 .59683 L .42981 .59741 L F
.43041 .60013 m .43349 .60022 L .43229 .59683 L F
.631 .564 .761 r
.43041 .60013 m .43397 .60206 L .43349 .60022 L F
.487 .75 .988 r
.79129 .48642 m .79467 .48735 L .79374 .48636 L F
.427 .731 .99 r
.79467 .48735 m .79672 .48599 L .79374 .48636 L F
.79467 .48735 m .79698 .48723 L .79672 .48599 L F
.992 .872 .537 r
.56176 .68544 m .56112 .68883 L .56181 .68974 L F
.815 .674 .128 r
.56112 .68883 m .56116 .69191 L .56181 .68974 L F
.705 .898 .529 r
.52471 .64166 m .52302 .64447 L .52489 .64305 L F
.602 .703 .914 r
.78219 .50324 m .78076 .50562 L .77974 .50371 L F
.78219 .50324 m .78336 .50495 L .78076 .50562 L F
.663 .627 .804 r
.45723 .60214 m .4562 .60617 L .45494 .6033 L F
.45723 .60214 m .45858 .60559 L .4562 .60617 L F
.448 .389 .699 r
.45847 .60796 m .4562 .60617 L .45858 .60559 L F
.45847 .60796 m .45663 .60857 L .4562 .60617 L F
.79 .609 .656 r
.60327 .62248 m .60471 .62557 L .60607 .62262 L F
.841 .735 .748 r
.62926 .43708 m .63046 .44053 L .62726 .44012 L F
.845 .717 .722 r
.63046 .44053 m .62842 .44376 L .62726 .44012 L F
.748 .578 .665 r
.63046 .44053 m .63166 .44401 L .62842 .44376 L F
.659 .53 .696 r
.63417 .44342 m .63166 .44401 L .63046 .44053 L F
.494 .276 .512 r
.50261 .66924 m .50235 .67148 L .50048 .672 L F
0 0 .53 r
.50165 .66687 m .50383 .67098 L .50261 .66924 L F
.435 .846 .967 r
.50383 .67098 m .50235 .67148 L .50261 .66924 L F
.592 .807 .982 r
.8134 .50697 m .81072 .50627 L .81225 .5059 L F
.978 .895 .668 r
.81125 .50956 m .8134 .50697 L .81225 .5059 L F
.81125 .50956 m .81212 .51061 L .8134 .50697 L F
.413 .78 .994 r
.39295 .58237 m .39515 .58212 L .39663 .58296 L F
.327 .763 .968 r
.39515 .58212 m .39889 .58257 L .39663 .58296 L F
.422 .368 .693 r
.51603 .66119 m .51707 .66374 L .51851 .66281 L F
.51603 .66119 m .51707 .66374 L .51851 .66281 L F
.921 .808 .718 r
.58705 .64532 m .58455 .64831 L .58478 .64632 L F
.035 .244 .745 r
.45966 .6976 m .45742 .69548 L .45996 .69545 L F
.485 .384 .664 r
.21357 .6061 m .21182 .60824 L .21152 .60633 L F
.61 .373 .533 r
.43505 .62026 m .4373 .62247 L .43492 .62241 L F
.673 .362 .439 r
.43745 .6205 m .4373 .62247 L .43505 .62026 L F
.57 .309 .481 r
.52958 .68024 m .53273 .68036 L .5318 .67828 L F
.803 .409 .308 r
.5318 .67828 m .53273 .68036 L .53543 .68088 L F
.788 .985 .726 r
.4681 .61979 m .46716 .62055 L .46987 .61712 L F
.536 .136 .229 r
.47062 .62006 m .46694 .62197 L .4681 .61979 L F
.619 .628 .837 r
.74541 .51252 m .74651 .51567 L .74887 .51508 L F
.365 .834 .813 r
.32246 .63895 m .31988 .63952 L .32173 .63881 L F
.565 .004 0 r
.50055 .64861 m .50421 .65116 L .50217 .65063 L F
.862 .693 .67 r
.60101 .6169 m .59988 .61955 L .60296 .62031 L F
.827 .617 .62 r
.59975 .62224 m .60296 .62031 L .59988 .61955 L F
.59975 .62224 m .60114 .62284 L .60296 .62031 L F
.762 .524 .573 r
.60296 .62031 m .60114 .62284 L .60327 .62248 L F
.528 .151 .27 r
.44099 .62024 m .4373 .62247 L .43745 .6205 L F
.44099 .62024 m .43934 .62271 L .4373 .62247 L F
.647 .286 .345 r
.4432 .62218 m .43934 .62271 L .44099 .62024 L F
.607 .303 .429 r
.44333 .62028 m .4432 .62218 L .44099 .62024 L F
.234 .743 .879 r
.39559 .59203 m .39421 .59178 L .39191 .59208 L F
.217 .736 .86 r
.39855 .59162 m .39421 .59178 L .39559 .59203 L F
.721 .782 .901 r
.3702 .64023 m .36654 .64038 L .3684 .64021 L F
.263 0 0 r
.3702 .64023 m .36874 .64054 L .36654 .64038 L F
.025 0 0 r
.37227 .63984 m .36874 .64054 L .3702 .64023 L F
.522 .593 .866 r
.54387 .64922 m .5449 .64683 L .54252 .64659 L F
.54387 .64922 m .54647 .64898 L .5449 .64683 L F
0 .13 .655 r
.54387 .64922 m .54561 .65085 L .54647 .64898 L F
0 .167 .693 r
.56025 .67762 m .56 .67667 L .55785 .67481 L F
.969 .649 .323 r
.55922 .67887 m .56025 .67762 L .56 .67667 L F
.55922 .67887 m .56046 .67992 L .56025 .67762 L F
.878 .855 .815 r
.56025 .67762 m .56019 .67435 L .56 .67667 L F
.969 .649 .323 r
.55922 .67887 m .56025 .67762 L .56 .67667 L F
.55922 .67887 m .56046 .67992 L .56025 .67762 L F
.893 .905 .827 r
.47254 .72446 m .47302 .72593 L .47127 .72473 L F
0 0 .538 r
.80394 .48019 m .80456 .48254 L .80368 .48378 L F
0 .049 .597 r
.80534 .48471 m .80368 .48378 L .80456 .48254 L F
.80534 .48471 m .80529 .48637 L .80368 .48378 L F
.315 .029 .31 r
.55042 .66281 m .54976 .66172 L .54918 .66326 L F
.6 .941 .766 r
.58095 .61156 m .57913 .61251 L .58101 .61392 L F
.58095 .61156 m .58197 .61034 L .57913 .61251 L F
.673 .814 .951 r
.43098 .58869 m .42747 .58837 L .42979 .58716 L F
.391 .643 .957 r
.43184 .58721 m .43098 .58869 L .42979 .58716 L F
.394 .646 .958 r
.43184 .58721 m .43314 .58878 L .43098 .58869 L F
.464 .064 .196 r
.53596 .61284 m .53479 .61454 L .53946 .6137 L F
.73 .385 0 r
.48914 .67522 m .48895 .67495 L .48779 .67193 L F
.662 .774 .933 r
.48799 .67706 m .48895 .67495 L .48914 .67522 L F
0 .103 .64 r
.49141 .67724 m .48914 .67522 L .49207 .67556 L F
.869 .906 .495 r
.48914 .67522 m .48799 .67706 L .48895 .67495 L F
.515 .212 .39 r
.49782 .70129 m .49743 .70345 L .49486 .70353 L F
.562 .254 .403 r
.49994 .7031 m .49743 .70345 L .49782 .70129 L F
.572 .25 .385 r
.50031 .70125 m .49994 .7031 L .49782 .70129 L F
.71 .817 .931 r
.79575 .47674 m .79212 .47727 L .79456 .47575 L F
.579 .841 .994 r
.7967 .47553 m .79575 .47674 L .79456 .47575 L F
.7967 .47553 m .79776 .47637 L .79575 .47674 L F
.792 .502 .498 r
.58451 .62893 m .58781 .63145 L .58457 .63183 L F
.704 .235 .134 r
.58118 .59657 m .57953 .59809 L .57902 .59679 L F
.58118 .59657 m .58129 .59865 L .57953 .59809 L F
.58118 .59657 m .58345 .59887 L .58129 .59865 L F
.94 .745 .612 r
.61125 .64011 m .61092 .64262 L .61275 .64343 L F
.985 .713 .417 r
.61143 .64367 m .61275 .64343 L .61092 .64262 L F
.61143 .64367 m .61291 .64583 L .61275 .64343 L F
.441 .776 .998 r
.19294 .56158 m .19631 .56238 L .19536 .56238 L F
.485 .009 .049 r
.19631 .56238 m .19294 .56158 L .19536 .56238 L F
.228 0 .303 r
.45832 .67229 m .45598 .67522 L .45787 .67427 L F
.469 .184 .397 r
.45598 .67522 m .45845 .67693 L .45787 .67427 L F
.45598 .67522 m .45541 .67763 L .45845 .67693 L F
0 0 0 r
.77325 .48971 m .77635 .48697 L .77369 .48769 L F
.723 .344 .331 r
.58405 .58987 m .58752 .58863 L .58378 .58835 L F
.58405 .58987 m .58758 .59022 L .58752 .58863 L F
.471 .355 .639 r
.31507 .60541 m .31663 .60504 L .31623 .60265 L F
.553 .573 .829 r
.40983 .59024 m .41056 .5922 L .41279 .59117 L F
.726 .644 .767 r
.48568 .66129 m .48881 .66114 L .48769 .6574 L F
.389 .432 .784 r
.48769 .6574 m .48881 .66114 L .49046 .6593 L F
.506 .613 .893 r
.48881 .66114 m .49133 .66129 L .49046 .6593 L F
.193 0 0 r
.35977 .58216 m .36224 .58268 L .36346 .58283 L F
.268 0 0 r
.36224 .58268 m .36565 .58224 L .36346 .58283 L F
.389 0 .069 r
.50611 .6988 m .50632 .7001 L .5038 .69994 L F
.827 .365 0 r
.50659 .70016 m .50632 .7001 L .50611 .6988 L F
.674 .228 .184 r
.50949 .70024 m .50611 .6988 L .50926 .69831 L F
.50949 .70024 m .50659 .70016 L .50611 .6988 L F
.651 .299 .363 r
.52516 .63497 m .52804 .63688 L .52904 .63491 L F
.167 .643 .929 r
.52804 .63688 m .53129 .63449 L .52904 .63491 L F
.936 .867 .745 r
.56059 .68417 m .55812 .68522 L .55937 .68327 L F
.56059 .68417 m .55917 .68691 L .55812 .68522 L F
.41 .04 .222 r
.40662 .62876 m .40549 .63113 L .40321 .6315 L F
.56 .19 .296 r
.40821 .63027 m .40662 .62876 L .4089 .62837 L F
.40821 .63027 m .40549 .63113 L .40662 .62876 L F
.695 .5 .62 r
.42983 .61106 m .4325 .61123 L .43253 .60868 L F
.693 .628 .779 r
.43453 .60598 m .43253 .60868 L .43541 .60846 L F
.693 .498 .62 r
.43253 .60868 m .43592 .61052 L .43541 .60846 L F
.43253 .60868 m .4325 .61123 L .43592 .61052 L F
.28 0 0 r
.37841 .63762 m .37674 .63896 L .37453 .63917 L F
.066 0 0 r
.37888 .63834 m .37841 .63762 L .38069 .63758 L F
.37888 .63834 m .37674 .63896 L .37841 .63762 L F
.44 .818 .991 r
.80652 .51539 m .80697 .51608 L .80384 .51569 L F
.80652 .51539 m .80697 .51608 L .80384 .51569 L F
.848 .952 .882 r
.52804 .63688 m .5264 .63987 L .52891 .63744 L F
.52804 .63688 m .52503 .63927 L .5264 .63987 L F
.517 .081 .15 r
.41506 .62617 m .41349 .62803 L .41124 .62784 L F
.444 .002 .101 r
.41698 .627 m .41506 .62617 L .4174 .62609 L F
.41698 .627 m .41349 .62803 L .41506 .62617 L F
.731 .339 .307 r
.57215 .59299 m .57574 .59344 L .57336 .59114 L F
.685 .365 .427 r
.57336 .59114 m .57574 .59344 L .57574 .59174 L F
.651 .648 .834 r
.57783 .61081 m .57972 .60842 L .57922 .60584 L F
.83 .731 .205 r
.52503 .63927 m .52408 .64157 L .52349 .63991 L F
.006 .14 .654 r
.46402 .61085 m .4633 .6121 L .46223 .60841 L F
.219 .429 .853 r
.46402 .61085 m .46588 .61365 L .4633 .6121 L F
.29 .469 .864 r
.48174 .68455 m .48284 .68286 L .48108 .68313 L F
.48174 .68455 m .48426 .6855 L .48284 .68286 L F
.997 .774 .442 r
.8038 .51818 m .80473 .51918 L .80384 .51569 L F
.957 .706 .515 r
.54867 .64544 m .5505 .64801 L .55121 .64625 L F
.045 0 0 r
.36565 .58224 m .36792 .58201 L .36911 .58167 L F
.428 0 0 r
.36911 .58167 m .36792 .58201 L .37155 .58227 L F
0 .12 .67 r
.79777 .49269 m .79913 .49524 L .79905 .49517 L F
.58 .846 .995 r
.79913 .49524 m .80015 .49397 L .79905 .49517 L F
.593 .083 .01 r
.51212 .63228 m .51445 .63367 L .51589 .63272 L F
.323 0 0 r
.51589 .63272 m .51445 .63367 L .51865 .63302 L F
.595 .451 .655 r
.54637 .59965 m .54378 .60152 L .54504 .60019 L F
.493 .1 .223 r
.42667 .62239 m .42545 .62446 L .42334 .62342 L F
.605 .26 .359 r
.42908 .62232 m .42545 .62446 L .42667 .62239 L F
.656 .339 .424 r
.45643 .61977 m .45505 .62223 L .45281 .62013 L F
.714 .423 .483 r
.45884 .6202 m .45505 .62223 L .45643 .61977 L F
.755 .52 .577 r
.62697 .45507 m .62864 .45486 L .62722 .45717 L F
.648 .425 .567 r
.62864 .45486 m .63085 .4574 L .62722 .45717 L F
.62864 .45486 m .63076 .45498 L .63085 .4574 L F
.367 0 0 r
.56316 .62875 m .56604 .62897 L .56632 .62852 L F
.732 .372 .367 r
.56856 .62731 m .56632 .62852 L .56823 .62715 L F
0 0 0 r
.56604 .62897 m .56823 .62715 L .56632 .62852 L F
.35 .13 .433 r
.20825 .61709 m .20785 .61944 L .20582 .62021 L F
.289 .124 .476 r
.20785 .61944 m .20581 .62276 L .20582 .62021 L F
.502 .14 .284 r
.54913 .59783 m .5506 .59744 L .54714 .59733 L F
.459 .587 .894 r
.48972 .65133 m .4901 .65259 L .49188 .65074 L F
.535 .713 .954 r
.4901 .65259 m .49253 .65251 L .49188 .65074 L F
.673 .729 .891 r
.48928 .65223 m .4901 .65259 L .48972 .65133 L F
.294 .205 .581 r
.53215 .65168 m .53383 .651 L .53237 .64877 L F
.247 0 .327 r
.46062 .66936 m .45832 .67229 L .46006 .67168 L F
.239 0 .307 r
.46006 .67168 m .45832 .67229 L .45787 .67427 L F
.085 .27 .756 r
.35689 .63985 m .35827 .64342 L .35896 .6417 L F
.593 .313 .462 r
.50287 .63379 m .50056 .63188 L .50042 .6341 L F
.50287 .63379 m .50371 .63122 L .50056 .63188 L F
.806 .896 .907 r
.80715 .50779 m .80695 .51016 L .80581 .50919 L F
.80715 .50779 m .80799 .5089 L .80695 .51016 L F
.435 .831 .982 r
.39889 .58257 m .40113 .58211 L .40254 .58263 L F
.44 .832 .983 r
.40113 .58211 m .40474 .58217 L .40254 .58263 L F
.121 .342 .808 r
.80104 .47688 m .80394 .48019 L .80176 .47831 L F
.745 .417 .427 r
.50631 .63109 m .50861 .63363 L .51021 .63115 L F
.508 .052 .103 r
.50861 .63363 m .51212 .63228 L .51021 .63115 L F
.574 .543 .782 r
.53623 .64319 m .53968 .64601 L .53867 .64258 L F
0 0 .352 r
.55796 .66217 m .55817 .66252 L .55865 .66367 L F
.606 .076 0 r
.55876 .66349 m .55817 .66252 L .55767 .66206 L F
.035 .228 .731 r
.55817 .66252 m .55967 .6663 L .55865 .66367 L F
.55817 .66252 m .56021 .66461 L .55967 .6663 L F
.606 .076 0 r
.55889 .66365 m .55817 .66252 L .55876 .66349 L F
0 0 .352 r
.55721 .66056 m .55817 .66252 L .55796 .66217 L F
0 0 0 r
.57922 .60584 m .58104 .60502 L .58141 .60418 L F
.083 0 .258 r
.58095 .60678 m .57922 .60584 L .57972 .60842 L F
.58095 .60678 m .58104 .60502 L .57922 .60584 L F
.71 .393 .438 r
.44708 .62203 m .44333 .62028 L .4469 .62019 L F
.674 .394 .49 r
.45096 .62014 m .44708 .62203 L .4469 .62019 L F
.824 .47 .386 r
.47071 .71561 m .46712 .71277 L .46943 .71216 L F
0 .148 .678 r
.46628 .72129 m .46729 .72056 L .46503 .71809 L F
.002 .248 .755 r
.46628 .72129 m .46926 .7237 L .46729 .72056 L F
.703 .75 .888 r
.79516 .51891 m .79875 .51952 L .79771 .51829 L F
.652 .813 .961 r
.79771 .51829 m .79875 .51952 L .80117 .51867 L F
.378 0 0 r
.52203 .63389 m .52426 .63482 L .52516 .63497 L F
.095 .375 .838 r
.52632 .63407 m .52516 .63497 L .52426 .63482 L F
.52632 .63407 m .52804 .63688 L .52516 .63497 L F
.698 .737 .881 r
.74887 .51508 m .75236 .51566 L .75152 .51291 L F
.695 .735 .881 r
.75152 .51291 m .75236 .51566 L .75518 .5151 L F
.492 .228 .441 r
.49748 .73635 m .49891 .73634 L .49844 .73664 L F
.686 .695 .853 r
.75518 .5151 m .75833 .5155 L .75739 .51261 L F
.688 .719 .873 r
.75739 .51261 m .75833 .5155 L .76102 .51337 L F
.706 .395 .447 r
.55831 .62504 m .56191 .62517 L .56288 .62307 L F
.535 .209 .363 r
.56288 .62307 m .56432 .62476 L .56413 .62246 L F
.56288 .62307 m .56191 .62517 L .56432 .62476 L F
.79 .821 .877 r
.45966 .6976 m .46281 .69783 L .46153 .69901 L F
.539 .861 .996 r
.46229 .70433 m .46455 .70369 L .4631 .70308 L F
.4631 .70308 m .46455 .70369 L .46229 .70433 L F
.46229 .70433 m .46455 .70369 L .4631 .70308 L F
.2 .654 .945 r
.41916 .59343 m .41608 .59263 L .41713 .59336 L F
.306 .487 .873 r
.41993 .59472 m .42105 .5934 L .41916 .59343 L F
.41993 .59472 m .42423 .59871 L .42105 .5934 L F
.554 .343 .548 r
.46156 .6173 m .46131 .61947 L .45884 .6202 L F
.744 .681 .79 r
.46367 .61847 m .46156 .6173 L .46331 .61643 L F
.46367 .61847 m .46131 .61947 L .46156 .6173 L F
.609 .716 .921 r
.42624 .59673 m .42715 .59353 L .42497 .59584 L F
.42624 .59673 m .42969 .59713 L .42715 .59353 L F
.685 .602 .757 r
.42624 .59673 m .42981 .59741 L .42969 .59713 L F
.522 .343 .58 r
.55709 .61431 m .55963 .61378 L .55937 .61139 L F
.55709 .61431 m .55963 .61378 L .55937 .61139 L F
.677 .442 .558 r
.52677 .65736 m .52998 .65739 L .52981 .65489 L F
.467 .273 .533 r
.52981 .65489 m .532 .65448 L .53215 .65168 L F
.505 .313 .554 r
.52981 .65489 m .5323 .65654 L .532 .65448 L F
.486 .67 .945 r
.22132 .54889 m .22074 .55085 L .21933 .54913 L F
.496 .681 .948 r
.22132 .54889 m .22271 .55058 L .22074 .55085 L F
.597 .357 .524 r
.50048 .672 m .50168 .67612 L .49737 .67503 L F
.191 .12 .542 r
.50226 .67386 m .50048 .672 L .50235 .67148 L F
.50226 .67386 m .50168 .67612 L .50048 .672 L F
.377 0 .179 r
.54869 .62289 m .55129 .62235 L .5524 .62012 L F
.629 .249 .304 r
.5524 .62012 m .55129 .62235 L .55508 .62188 L F
.422 0 0 r
.5524 .62012 m .55508 .62188 L .55647 .62269 L F
.255 .078 .438 r
.54528 .66922 m .54696 .66876 L .54707 .66623 L F
.144 .281 .746 r
.54528 .66922 m .54771 .67165 L .54696 .66876 L F
.358 .428 .797 r
.53482 .65679 m .53737 .6614 L .53916 .65915 L F
.4 .415 .76 r
.53661 .66118 m .53916 .65915 L .53737 .6614 L F
.215 0 .292 r
.55552 .67774 m .55405 .67901 L .55319 .68067 L F
.867 .943 .865 r
.46946 .71534 m .46788 .71613 L .47071 .71561 L F
.46946 .71534 m .46874 .71815 L .46788 .71613 L F
.46946 .71534 m .46731 .71755 L .46874 .71815 L F
.791 .56 .587 r
.46731 .71755 m .47175 .72038 L .46874 .71815 L F
0 .153 .625 r
.58972 .61424 m .58891 .61347 L .58645 .61162 L F
.976 .908 .675 r
.58697 .61502 m .58803 .61265 L .58891 .61347 L F
.58803 .61265 m .58812 .61244 L .58891 .61347 L F
0 .153 .625 r
.58994 .61441 m .58891 .61347 L .58972 .61424 L F
.948 .897 .742 r
.58739 .61662 m .58994 .61441 L .5881 .61727 L F
.58739 .61662 m .58891 .61347 L .58994 .61441 L F
.276 .424 .83 r
.5368 .65344 m .53561 .65542 L .53383 .651 L F
0 0 .349 r
.5368 .65344 m .53482 .65679 L .53561 .65542 L F
.674 .394 .49 r
.45096 .62014 m .44924 .62294 L .44708 .62203 L F
.637 .35 .467 r
.45262 .62179 m .45096 .62014 L .45281 .62013 L F
.45262 .62179 m .44924 .62294 L .45096 .62014 L F
.635 .607 .805 r
.80384 .51569 m .80155 .51772 L .80091 .51611 L F
.106 0 .182 r
.80117 .51867 m .80155 .51772 L .80384 .51569 L F
.245 .74 .912 r
.40894 .61427 m .411 .61419 L .41244 .61438 L F
.099 0 0 r
.41342 .61466 m .41244 .61438 L .411 .61419 L F
.41342 .61466 m .41507 .61436 L .41244 .61438 L F
.643 .338 .44 r
.64896 .45372 m .64516 .45247 L .64878 .45211 L F
.64896 .45372 m .645 .4544 L .64516 .45247 L F
.37 .673 .975 r
.53942 .71274 m .54212 .71312 L .54115 .71192 L F
.581 .564 .8 r
.43453 .60598 m .43541 .60846 L .43785 .60779 L F
.683 .607 .764 r
.43592 .61052 m .43785 .60779 L .43541 .60846 L F
.673 .939 .965 r
.28282 .8384 m .28628 .83715 L .28503 .83672 L F
.374 .089 .345 r
.46006 .67168 m .46281 .66879 L .46062 .66936 L F
.167 .643 .929 r
.52804 .63688 m .52891 .63744 L .53129 .63449 L F
.706 .562 .689 r
.52891 .63744 m .53154 .63881 L .53129 .63449 L F
.528 .425 .681 r
.53129 .63449 m .53419 .63671 L .53351 .63415 L F
.53129 .63449 m .53154 .63881 L .53419 .63671 L F
.324 0 0 r
.58781 .63145 m .58712 .63198 L .58457 .63183 L F
.57 .37 .57 r
.58969 .63022 m .59099 .63138 L .58781 .63145 L F
.109 0 0 r
.58573 .63354 m .58852 .63286 L .58568 .63494 L F
.763 .473 .493 r
.58872 .63316 m .58568 .63494 L .58848 .63295 L F
.569 .366 .566 r
.58848 .63295 m .58872 .63316 L .58848 .63298 L F
.58854 .63282 m .58872 .63316 L .58848 .63295 L F
.58781 .63145 m .58994 .6338 L .58872 .63316 L F
.763 .473 .493 r
.58872 .63316 m .58848 .63295 L .58867 .63282 L F
.109 0 0 r
.58852 .63286 m .58867 .63282 L .58848 .63295 L F
.58852 .63286 m .58848 .63295 L .58568 .63494 L F
.569 .366 .566 r
.58781 .63145 m .58854 .63282 L .58712 .63198 L F
.58854 .63282 m .58852 .63286 L .58712 .63198 L F
.442 .353 .66 r
.58712 .63198 m .58867 .63282 L .58852 .63286 L F
.58712 .63198 m .58852 .63286 L .58573 .63354 L F
.569 .366 .566 r
.58852 .63286 m .58848 .63298 L .58712 .63198 L F
.58781 .63145 m .59099 .63138 L .58994 .6338 L F
.839 .684 .69 r
.54167 .61649 m .54511 .61435 L .54212 .61374 L F
.54167 .61649 m .5448 .61727 L .54511 .61435 L F
.228 .523 .916 r
.21744 .54696 m .21703 .54837 L .21549 .54701 L F
.21744 .54696 m .21933 .54913 L .21703 .54837 L F
0 0 .182 r
.47175 .72038 m .47185 .72079 L .47198 .72141 L F
0 0 .347 r
.47287 .72271 m .47198 .72141 L .47185 .72079 L F
.598 .026 0 r
.55018 .62785 m .54648 .62572 L .54815 .62555 L F
.467 .66 .946 r
.47071 .71561 m .47298 .71575 L .47179 .71427 L F
.259 .355 .772 r
.47179 .71427 m .47071 .71561 L .46943 .71216 L F
.467 .66 .946 r
.47071 .71561 m .47298 .71575 L .47179 .71427 L F
.666 .96 .938 r
.47179 .71427 m .46946 .71534 L .47071 .71561 L F
.798 .519 .514 r
.60586 .63653 m .60872 .63473 L .60666 .63405 L F
.60586 .63653 m .60915 .63704 L .60872 .63473 L F
.408 .035 .215 r
.49508 .67475 m .49141 .67724 L .49207 .67556 L F
.959 .749 .576 r
.62478 .44915 m .6241 .45159 L .62441 .44919 L F
.62478 .44915 m .62503 .45207 L .6241 .45159 L F
.849 .402 .149 r
.54674 .62213 m .54676 .62012 L .54492 .61978 L F
.54674 .62213 m .54869 .62289 L .54676 .62012 L F
0 0 0 r
.37793 .59485 m .3761 .59535 L .37393 .59577 L F
.2 .719 .688 r
.37828 .59473 m .37793 .59485 L .38037 .59435 L F
.37828 .59473 m .3761 .59535 L .37793 .59485 L F
.808 .692 .736 r
.78896 .50442 m .79236 .50403 L .78922 .50412 L F
0 0 .44 r
.55914 .66812 m .56146 .67117 L .55984 .66989 L F
.225 .3 .731 r
.58102 .62858 m .58016 .62446 L .58188 .62446 L F
.439 .058 .218 r
.32765 .59056 m .3313 .58799 L .32691 .58939 L F
.32765 .59056 m .32959 .59057 L .3313 .58799 L F
.379 0 .188 r
.32959 .59057 m .33349 .58756 L .3313 .58799 L F
.771 .67 .752 r
.4925 .66604 m .49612 .66643 L .49501 .66364 L F
.506 .167 .326 r
.49273 .66896 m .49612 .66643 L .4925 .66604 L F
.49273 .66896 m .49523 .66858 L .49612 .66643 L F
.632 .296 .383 r
.49612 .66643 m .49523 .66858 L .49837 .66842 L F
.551 .663 .911 r
.63224 .44565 m .62842 .44376 L .63166 .44401 L F
.463 .272 .535 r
.63417 .44342 m .63224 .44565 L .63166 .44401 L F
.679 .403 .497 r
.42654 .61331 m .42983 .61106 L .42673 .61165 L F
.389 0 .129 r
.42334 .62342 m .42202 .62539 L .41967 .62575 L F
.497 .087 .192 r
.42334 .62342 m .42545 .62446 L .42202 .62539 L F
.541 .564 .827 r
.57765 .66792 m .57927 .66532 L .57694 .66575 L F
.57765 .66792 m .58073 .66797 L .57927 .66532 L F
.771 .267 0 r
.49196 .67973 m .49226 .67856 L .49141 .67724 L F
.49196 .67973 m .4953 .68133 L .49226 .67856 L F
.547 .017 0 r
.49226 .67856 m .4953 .68133 L .49416 .68025 L F
.459 .295 .571 r
.48772 .66934 m .49013 .67112 L .49023 .66907 L F
.48772 .66934 m .48779 .67193 L .49013 .67112 L F
.338 .182 .517 r
.21756 .59381 m .21743 .59627 L .21582 .59688 L F
.354 .243 .587 r
.21743 .59627 m .21608 .59967 L .21582 .59688 L F
.899 .678 .595 r
.59534 .59357 m .59526 .59618 L .59775 .59686 L F
.912 .706 .61 r
.59519 .5986 m .59775 .59686 L .59526 .59618 L F
.59519 .5986 m .59757 .59966 L .59775 .59686 L F
.009 .262 .765 r
.60471 .62557 m .60703 .62772 L .60667 .62869 L F
.883 .789 .753 r
.60703 .62772 m .6076 .63093 L .60667 .62869 L F
.588 .529 .757 r
.4501 .59925 m .44852 .60037 L .44729 .59736 L F
.091 .14 .62 r
.4502 .60149 m .44852 .60037 L .4501 .59925 L F
.4502 .60149 m .44898 .60278 L .44852 .60037 L F
.286 .783 .755 r
.54395 .68401 m .5421 .68446 L .54184 .68461 L F
.5421 .68446 m .54002 .68496 L .54184 .68461 L F
0 0 0 r
.54242 .68449 m .54002 .68496 L .54395 .68401 L F
.54242 .68449 m .54395 .68401 L .54349 .68266 L F
.54475 .68155 m .54272 .68411 L .54349 .68266 L F
.54272 .68411 m .54242 .68449 L .5426 .68418 L F
.54272 .68411 m .5426 .68418 L .54349 .68266 L F
.286 .783 .755 r
.54184 .68461 m .54002 .68496 L .53791 .68571 L F
.538 .368 .598 r
.46901 .68354 m .4667 .68625 L .46664 .68377 L F
.463 .272 .535 r
.63417 .44342 m .63405 .4459 L .63224 .44565 L F
.579 .467 .69 r
.53773 .66587 m .53612 .66506 L .53661 .66118 L F
.4 .415 .76 r
.53661 .66118 m .53838 .66293 L .53916 .65915 L F
.807 .434 .35 r
.53661 .66118 m .53805 .66323 L .53838 .66293 L F
.597 .455 .66 r
.53661 .66118 m .53773 .66587 L .53612 .66506 L F
.807 .434 .35 r
.53661 .66118 m .53525 .66489 L .53805 .66323 L F
.736 .756 .869 r
.63428 .43201 m .63547 .43472 L .63165 .43412 L F
.76 .727 .823 r
.63165 .43412 m .63547 .43472 L .63296 .43553 L F
.845 .802 .809 r
.63742 .43203 m .63547 .43472 L .63428 .43201 L F
.5 .313 .559 r
.63742 .43203 m .63765 .43408 L .63547 .43472 L F
.037 0 0 r
.37155 .58227 m .37397 .58205 L .37532 .58176 L F
.373 0 0 r
.37532 .58176 m .37397 .58205 L .37743 .5822 L F
.142 0 0 r
.53419 .63671 m .53706 .63483 L .53351 .63415 L F
.579 .467 .69 r
.53773 .66587 m .53519 .66639 L .53612 .66506 L F
.646 .282 .34 r
.53519 .66639 m .53755 .66839 L .53581 .66799 L F
.536 .321 .535 r
.53773 .66587 m .53755 .66839 L .53519 .66639 L F
.579 .467 .69 r
.53773 .66587 m .53519 .66639 L .53612 .66506 L F
.647 .341 .439 r
.45281 .62013 m .45505 .62223 L .45262 .62179 L F
.623 .14 0 r
.55723 .62392 m .55647 .62269 L .55508 .62188 L F
.653 .105 0 r
.55567 .62346 m .55748 .6244 L .55723 .62392 L F
.606 .151 .146 r
.55831 .62504 m .56165 .62661 L .56191 .62517 L F
0 .31 .694 r
.56 .6257 m .55831 .62504 L .55723 .62392 L F
.653 .105 0 r
.55748 .6244 m .56 .6257 L .55723 .62392 L F
.623 .14 0 r
.55723 .62392 m .55831 .62504 L .55681 .62312 L F
.55723 .62392 m .55681 .62312 L .55647 .62269 L F
.602 .559 .778 r
.42969 .59713 m .42981 .59741 L .43229 .59683 L F
.894 .664 .583 r
.58603 .60222 m .588 .60259 L .58773 .6052 L F
.63 .594 .795 r
.77291 .49693 m .77048 .50056 L .76952 .49852 L F
.558 .626 .875 r
.42105 .5934 m .42423 .59871 L .42497 .59584 L F
0 .526 .805 r
.59342 .66995 m .59298 .66975 L .58979 .66904 L F
.602 .774 .963 r
.59342 .66995 m .59473 .66809 L .59298 .66975 L F
.59342 .66995 m .5958 .66922 L .59473 .66809 L F
.654 .85 .975 r
.47573 .61522 m .47307 .61658 L .47159 .61531 L F
.653 .807 .957 r
.47573 .61522 m .47626 .61615 L .47307 .61658 L F
.714 .423 .483 r
.45884 .6202 m .4587 .62235 L .45505 .62223 L F
.752 .588 .673 r
.46131 .61947 m .4587 .62235 L .45884 .6202 L F
.895 .967 .825 r
.51608 .64589 m .5171 .6469 L .51735 .64453 L F
.51608 .64589 m .51591 .64815 L .5171 .6469 L F
.639 .495 .67 r
.51623 .67777 m .51401 .68024 L .51403 .67797 L F
.731 .438 .484 r
.58478 .64632 m .58455 .64831 L .58244 .64596 L F
.537 .633 .893 r
.51143 .69705 m .51141 .69825 L .50926 .69831 L F
.664 .535 .697 r
.51141 .69825 m .50949 .70024 L .50926 .69831 L F
.718 .324 .302 r
.54252 .64659 m .54208 .64812 L .53968 .64601 L F
.617 .369 .519 r
.5449 .64683 m .54208 .64812 L .54252 .64659 L F
.933 .663 .504 r
.59757 .59966 m .59757 .60198 L .59928 .60268 L F
.933 .743 .623 r
.59757 .60198 m .59861 .60493 L .59928 .60268 L F
.275 .12 .482 r
.44891 .68646 m .45079 .68321 L .44864 .6839 L F
.71 .24 .133 r
.49416 .68025 m .4953 .68133 L .49681 .68128 L F
.469 .836 .587 r
.47483 .68821 m .47381 .6891 L .47617 .68871 L F
.47483 .68821 m .47269 .68992 L .47381 .6891 L F
.236 .41 .832 r
.22855 .55477 m .22787 .55659 L .22614 .55333 L F
.425 .628 .938 r
.22855 .55477 m .23034 .55694 L .22787 .55659 L F
.514 .067 .125 r
.19485 .55609 m .19144 .55881 L .19101 .55603 L F
.648 .091 0 r
.19262 .5579 m .19268 .55797 L .19258 .55794 L F
.19262 .5579 m .19028 .55707 L .18959 .55774 L F
.19262 .5579 m .19258 .55794 L .19028 .55707 L F
.514 .067 .125 r
.19308 .5575 m .19262 .5579 L .19144 .55881 L F
.19485 .55609 m .19262 .5579 L .19308 .5575 L F
.19485 .55609 m .19268 .55797 L .19262 .5579 L F
.497 .904 .907 r
.19668 .55704 m .19268 .55797 L .19485 .55609 L F
.628 .401 .555 r
.49533 .63643 m .49791 .63436 L .49476 .6344 L F
.615 .068 0 r
.56249 .63728 m .56108 .63647 L .55893 .63445 L F
.907 .507 .229 r
.56249 .63728 m .56152 .63861 L .56108 .63647 L F
.56249 .63728 m .56344 .64025 L .56152 .63861 L F
.694 .751 .895 r
.42715 .59353 m .42969 .59713 L .4307 .59407 L F
.602 .559 .778 r
.42969 .59713 m .43229 .59683 L .4307 .59407 L F
.168 0 0 r
.38427 .6367 m .38304 .63731 L .38069 .63758 L F
.113 0 0 r
.38647 .63636 m .38304 .63731 L .38427 .6367 L F
.863 .497 .355 r
.50811 .68103 m .5046 .68209 L .50619 .67981 L F
.50811 .68103 m .50842 .68327 L .5046 .68209 L F
.691 .416 .501 r
.51053 .68087 m .50842 .68327 L .50811 .68103 L F
.538 .481 .74 r
.31362 .61843 m .31466 .62088 L .3159 .61936 L F
.112 0 0 r
.45006 .60333 m .44898 .60278 L .4502 .60149 L F
0 .048 .612 r
.45006 .60333 m .45107 .60499 L .44975 .6036 L F
.45006 .60333 m .44975 .6036 L .44898 .60278 L F
.778 .986 .898 r
.45494 .6033 m .45229 .60446 L .45382 .60432 L F
.45229 .60446 m .45107 .60499 L .45382 .60432 L F
.67 .566 .729 r
.45309 .60619 m .45436 .60428 L .45382 .60432 L F
.653 .903 .578 r
.45494 .6033 m .45382 .60432 L .45633 .6013 L F
.67 .566 .729 r
.45436 .60428 m .45633 .6013 L .45382 .60432 L F
.714 .643 .777 r
.45382 .60432 m .45006 .60333 L .4519 .6004 L F
.171 .671 .912 r
.45231 .60347 m .45029 .60313 L .45006 .60333 L F
.112 0 0 r
.45006 .60333 m .4476 .6042 L .44898 .60278 L F
0 .048 .612 r
.45006 .60333 m .44898 .60278 L .4476 .6042 L F
.638 .65 .845 r
.44604 .60111 m .4476 .6042 L .45006 .60333 L F
.243 .022 .366 r
.4519 .6004 m .4502 .60149 L .4501 .59925 L F
.627 .933 .967 r
.45076 .59986 m .4502 .60149 L .4519 .6004 L F
.867 .929 .864 r
.45006 .60333 m .45076 .59986 L .4519 .6004 L F
.713 .812 .926 r
.44604 .60111 m .4502 .60149 L .44878 .59993 L F
.638 .65 .845 r
.44604 .60111 m .45006 .60333 L .4502 .60149 L F
.316 .624 .959 r
.44878 .59993 m .4502 .60149 L .45076 .59986 L F
.867 .929 .864 r
.45006 .60333 m .44847 .60281 L .45076 .59986 L F
.171 .671 .912 r
.45029 .60313 m .44847 .60281 L .45006 .60333 L F
.674 .283 0 r
.55893 .63445 m .55854 .63392 L .5583 .63337 L F
.579 .039 0 r
.55893 .63445 m .56108 .63647 L .55981 .63561 L F
.55893 .63445 m .55981 .63561 L .55854 .63392 L F
.637 .35 .465 r
.48795 .71017 m .48718 .71218 L .48499 .71132 L F
.43 .432 .761 r
.48938 .70916 m .48795 .71017 L .48705 .70785 L F
.046 0 .175 r
.48938 .70916 m .48718 .71218 L .48795 .71017 L F
.254 0 .16 r
.56998 .62775 m .57087 .62619 L .56856 .62731 L F
.56998 .62775 m .56856 .62731 L .56823 .62715 L F
.442 .288 .576 r
.4882 .64266 m .48991 .64008 L .48743 .64053 L F
.4882 .64266 m .49011 .64255 L .48991 .64008 L F
.549 .353 .568 r
.48754 .64592 m .49011 .64255 L .4882 .64266 L F
.521 .673 .933 r
.72719 .49698 m .72853 .4946 L .72613 .49506 L F
.72719 .49698 m .73028 .49694 L .72853 .4946 L F
.299 0 .034 r
.33598 .58751 m .3382 .58704 L .33969 .58513 L F
.261 0 0 r
.3382 .58704 m .34202 .58516 L .33969 .58513 L F
.695 .735 .881 r
.75152 .51291 m .75518 .5151 L .75384 .51189 L F
.679 .72 .88 r
.75384 .51189 m .75518 .5151 L .75739 .51261 L F
.348 .816 .912 r
.40228 .58898 m .40383 .58921 L .40592 .58873 L F
.703 .833 .945 r
.79456 .47575 m .79212 .47727 L .79112 .47584 L F
.445 .395 .708 r
.20923 .61361 m .21017 .61682 L .20825 .61709 L F
.258 .052 .398 r
.20941 .61873 m .20825 .61709 L .21017 .61682 L F
.20941 .61873 m .20785 .61944 L .20825 .61709 L F
.565 .896 .984 r
.59915 .66888 m .59842 .66827 L .5958 .66922 L F
.433 .824 .985 r
.59915 .66888 m .60075 .66851 L .59842 .66827 L F
.697 .41 .485 r
.65134 .45211 m .65096 .45437 L .64878 .45211 L F
.533 .473 .735 r
.65242 .449 m .65364 .45134 L .65134 .45211 L F
.602 .409 .593 r
.65364 .45134 m .65096 .45437 L .65134 .45211 L F
.83 .588 .574 r
.62503 .45207 m .6235 .45418 L .6241 .45159 L F
.62503 .45207 m .62697 .45507 L .6235 .45418 L F
.167 .643 .929 r
.52804 .63688 m .53002 .63698 L .52891 .63744 L F
.52804 .63688 m .53002 .63698 L .52891 .63744 L F
.373 .419 .78 r
.35271 .61081 m .35204 .61424 L .35056 .61092 L F
.35271 .61081 m .35359 .61334 L .35204 .61424 L F
.375 .424 .784 r
.35359 .61334 m .3546 .61595 L .35204 .61424 L F
.692 .43 .522 r
.54109 .61988 m .5448 .61727 L .54167 .61649 L F
.54109 .61988 m .54492 .61978 L .5448 .61727 L F
.744 .681 .79 r
.46367 .61847 m .4642 .62026 L .46131 .61947 L F
.609 .347 .494 r
.4642 .62026 m .46213 .62236 L .46131 .61947 L F
.4642 .62026 m .46451 .62232 L .46213 .62236 L F
.845 .802 .809 r
.63742 .43203 m .63428 .43201 L .63657 .43073 L F
.813 .92 .909 r
.64013 .42912 m .63742 .43203 L .63657 .43073 L F
.698 .244 .169 r
.63742 .43203 m .64087 .43405 L .63765 .43408 L F
.662 .444 .578 r
.54994 .68295 m .55319 .68067 L .55239 .68054 L F
.981 .863 .484 r
.60906 .66021 m .60852 .66238 L .60908 .66265 L F
.82 .993 .864 r
.60687 .66392 m .60908 .66265 L .60852 .66238 L F
.176 .711 .755 r
.38595 .59275 m .38238 .59331 L .38345 .59323 L F
.843 .723 .732 r
.47967 .72967 m .48042 .73292 L .47853 .73184 L F
.801 .586 .61 r
.48024 .73513 m .47853 .73184 L .48042 .73292 L F
0 0 .207 r
.48015 .73157 m .48042 .73292 L .47967 .72967 L F
0 0 .107 r
.4806 .73437 m .48042 .73292 L .48015 .73157 L F
.4806 .73437 m .48024 .73513 L .48042 .73292 L F
.555 .341 .544 r
.48118 .73316 m .48294 .73496 L .48042 .73292 L F
.278 .542 .92 r
.48015 .73157 m .48118 .73316 L .48042 .73292 L F
.686 .606 .761 r
.43349 .60022 m .43397 .60206 L .43584 .59954 L F
.467 .426 .729 r
.43397 .60206 m .43584 .60196 L .43584 .59954 L F
.801 .31 .009 r
.56288 .62647 m .56604 .62897 L .56316 .62875 L F
0 .523 .709 r
.47221 .70946 m .47337 .70956 L .47548 .70977 L F
.116 0 .366 r
.47337 .70956 m .47493 .71025 L .4754 .70975 L F
0 .211 .737 r
.47607 .70904 m .47548 .70977 L .47337 .70956 L F
.116 0 .366 r
.47337 .70956 m .4754 .70975 L .47607 .70904 L F
0 .523 .709 r
.47173 .70941 m .47337 .70956 L .47221 .70946 L F
0 .211 .737 r
.47607 .70904 m .47767 .71177 L .47548 .70977 L F
.525 .328 .556 r
.47767 .71177 m .47532 .71227 L .47548 .70977 L F
.027 0 .469 r
.58645 .61162 m .58787 .61006 L .58761 .60767 L F
0 0 .172 r
.49858 .66161 m .49759 .6612 L .49977 .65979 L F
.95 .616 .208 r
.49759 .66255 m .49887 .6653 L .49759 .6612 L F
.49759 .66286 m .49786 .66339 L .49759 .66255 L F
.49786 .66339 m .49887 .6653 L .49759 .66255 L F
.68 .541 .689 r
.49713 .66413 m .49837 .66842 L .49919 .66741 L F
.791 .733 .799 r
.49713 .66413 m .49887 .6653 L .49759 .66286 L F
.266 .611 .956 r
.49887 .6653 m .50072 .6655 L .49713 .66413 L F
.68 .541 .689 r
.49825 .66456 m .49919 .66741 L .50072 .6655 L F
.49713 .66413 m .49919 .66741 L .49825 .66456 L F
0 0 .172 r
.49858 .66161 m .49759 .66286 L .49759 .6612 L F
.625 .881 .545 r
.4868 .68562 m .48675 .68548 L .48816 .68403 L F
.461 .01 .091 r
.48816 .68403 m .48675 .68548 L .48426 .6855 L F
.918 .957 .63 r
.49447 .69922 m .49478 .69702 L .49649 .69792 L F
.502 .186 .363 r
.57574 .59344 m .57881 .59066 L .57574 .59174 L F
.673 .939 .965 r
.28282 .8384 m .28503 .83672 L .28254 .83686 L F
.279 .651 .968 r
.80001 .47578 m .79776 .47637 L .7967 .47553 L F
.80001 .47578 m .80104 .47688 L .79776 .47637 L F
.236 .58 .944 r
.44479 .59366 m .44398 .59466 L .44267 .59385 L F
.44479 .59366 m .44702 .59558 L .44398 .59466 L F
.259 .471 .875 r
.20414 .56011 m .2054 .56019 L .20514 .55988 L F
.20414 .56011 m .20373 .55834 L .20448 .55944 L F
.20414 .56011 m .20514 .55988 L .20394 .55844 L F
.025 0 0 r
.20448 .55944 m .20349 .56025 L .20414 .56011 L F
.20349 .56025 m .20128 .56209 L .20414 .56011 L F
.448 .747 .992 r
.20258 .55807 m .20448 .55944 L .20373 .55834 L F
.543 .147 .241 r
.48399 .70912 m .48648 .71033 L .48705 .70785 L F
.46 .525 .838 r
.48609 .70965 m .48613 .70946 L .48418 .70631 L F
.543 .147 .241 r
.48648 .71033 m .48659 .71034 L .48705 .70785 L F
.305 0 .185 r
.48705 .70785 m .48918 .70869 L .48938 .70916 L F
.48705 .70785 m .48658 .71038 L .48918 .70869 L F
.746 .679 .787 r
.48918 .70869 m .48667 .71032 L .48629 .70971 L F
.48498 .70669 m .48629 .70971 L .48418 .70631 L F
.48918 .70869 m .48629 .70971 L .48498 .70669 L F
.48918 .70869 m .48528 .70683 L .48665 .70729 L F
.48528 .70683 m .48418 .70631 L .48665 .70729 L F
.724 .339 .321 r
.4884 .70787 m .48665 .70729 L .48817 .70729 L F
.626 .85 .47 r
.48807 .71079 m .48718 .71218 L .48938 .70916 L F
0 0 0 r
.48807 .71079 m .48918 .70869 L .48665 .70729 L F
.48807 .71079 m .48963 .70892 L .48918 .70869 L F
.724 .339 .321 r
.48909 .70967 m .48665 .70729 L .4884 .70787 L F
.46 .525 .838 r
.48629 .70971 m .48807 .71079 L .48665 .70729 L F
.543 .147 .241 r
.48648 .71033 m .48658 .71038 L .48659 .71034 L F
.46 .525 .838 r
.48614 .7107 m .48673 .71073 L .48629 .70971 L F
.48673 .71073 m .48807 .71079 L .48629 .70971 L F
.48613 .70946 m .48665 .70729 L .48418 .70631 L F
.18 .389 .831 r
.48418 .70631 m .48648 .71033 L .48399 .70912 L F
.46 .525 .838 r
.4862 .71029 m .48665 .70729 L .48594 .71026 L F
.746 .679 .787 r
.48667 .71032 m .48658 .71038 L .48418 .70631 L F
.18 .389 .831 r
.48418 .70631 m .48658 .71038 L .48648 .71033 L F
.46 .525 .838 r
.48594 .71026 m .48609 .70965 L .48418 .70631 L F
.48614 .7107 m .4862 .71029 L .48594 .71026 L F
.613 .557 .768 r
.43383 .6052 m .43699 .60531 L .43584 .60196 L F
.618 .445 .625 r
.43453 .60598 m .43699 .60531 L .43383 .6052 L F
.88 .6 .509 r
.53482 .65679 m .5323 .65654 L .532 .65448 L F
0 0 0 r
.53482 .65679 m .53389 .65879 L .53352 .65959 L F
.602 .368 .535 r
.53482 .65679 m .53881 .65694 L .53865 .65477 L F
0 0 .349 r
.5368 .65344 m .5367 .65598 L .53482 .65679 L F
.358 .428 .797 r
.53482 .65679 m .53916 .65915 L .53881 .65694 L F
.529 .291 .498 r
.5367 .65598 m .53389 .65879 L .53482 .65679 L F
.605 .643 .862 r
.53283 .61557 m .53373 .61683 L .53261 .61574 L F
.44 .591 .906 r
.53261 .61574 m .53373 .61683 L .53457 .61556 L F
.28 .375 .782 r
.53373 .61683 m .53531 .61805 L .53457 .61556 L F
.256 .683 .964 r
.40474 .58217 m .40694 .58231 L .40843 .5832 L F
.479 .798 .999 r
.40694 .58231 m .41073 .58287 L .40843 .5832 L F
.63 .594 .795 r
.77291 .49693 m .77385 .50215 L .77048 .50056 L F
0 0 .528 r
.55883 .68951 m .55812 .68522 L .55917 .68691 L F
.441 .776 .998 r
.19294 .56158 m .19535 .56141 L .19631 .56238 L F
.485 .009 .049 r
.19631 .56238 m .19346 .56381 L .19294 .56158 L F
.19464 .56321 m .19474 .56381 L .19346 .56381 L F
.928 .949 .612 r
.19435 .56608 m .19346 .56381 L .19474 .56381 L F
.748 .229 0 r
.19474 .56381 m .19763 .56633 L .19435 .56608 L F
.938 .579 .177 r
.19294 .56158 m .19346 .56381 L .19259 .5628 L F
.595 .495 .711 r
.19259 .5628 m .19487 .56465 L .19474 .56381 L F
.19487 .56465 m .19595 .56553 L .19474 .56381 L F
.485 .009 .049 r
.19631 .56238 m .19474 .56381 L .19464 .56321 L F
.993 .859 .595 r
.19535 .56141 m .19474 .56381 L .19631 .56238 L F
0 0 .054 r
.56021 .66461 m .55984 .66728 L .55914 .66812 L F
.956 .666 .23 r
.55973 .66546 m .55984 .66728 L .55985 .66426 L F
0 0 .44 r
.55914 .66812 m .56087 .67037 L .56146 .67117 L F
.956 .666 .23 r
.55938 .66897 m .55984 .66728 L .55973 .66546 L F
.55984 .66728 m .56087 .67037 L .55995 .66917 L F
.55984 .66728 m .55995 .66917 L .55914 .66812 L F
.24 .39 .813 r
.44845 .59586 m .44729 .59736 L .44702 .59558 L F
.405 .629 .945 r
.44845 .59586 m .44965 .59764 L .44729 .59736 L F
.588 .529 .757 r
.4501 .59925 m .44729 .59736 L .44965 .59764 L F
0 0 .281 r
.51427 .69542 m .51469 .69659 L .51529 .69396 L F
.22 0 0 r
.36759 .598 m .36626 .59743 L .37045 .596 L F
.304 0 0 r
.37189 .596 m .36759 .598 L .37045 .596 L F
.599 .449 .649 r
.5159 .73 m .51605 .73281 L .51355 .7326 L F
.51355 .7326 m .51605 .73281 L .5159 .73 L F
.608 .614 .832 r
.31861 .61432 m .32248 .61693 L .3213 .61535 L F
.06 .433 .872 r
.32248 .61693 m .32296 .61601 L .3213 .61535 L F
.054 .424 .868 r
.32248 .61693 m .32344 .61681 L .32296 .61601 L F
0 0 .479 r
.56743 .64574 m .56733 .64524 L .5656 .64285 L F
0 0 .495 r
.56743 .64574 m .56867 .64712 L .56733 .64524 L F
.56743 .64574 m .56889 .64869 L .56867 .64712 L F
.57 .597 .841 r
.45927 .60188 m .45858 .60559 L .45723 .60214 L F
.45927 .60188 m .4611 .60536 L .45858 .60559 L F
.566 .347 .542 r
.45858 .60559 m .4612 .60553 L .45847 .60796 L F
.589 .606 .837 r
.46283 .60427 m .4612 .60553 L .45927 .60188 L F
.659 .971 .892 r
.45922 .6058 m .46271 .60432 L .46229 .60413 L F
.46271 .60432 m .46283 .60427 L .4628 .60426 L F
.46271 .60432 m .4628 .60426 L .46229 .60413 L F
.57 .597 .841 r
.4611 .60536 m .4612 .60553 L .46082 .60554 L F
.4611 .60536 m .46082 .60554 L .45858 .60559 L F
.737 .731 .845 r
.6434 .43033 m .64013 .42912 L .64246 .42788 L F
.464 .457 .765 r
.64501 .42735 m .6434 .43033 L .64246 .42788 L F
.64501 .42735 m .64588 .43106 L .6434 .43033 L F
.384 .048 .266 r
.50553 .65491 m .50488 .65644 L .50276 .65706 L F
.56 .526 .774 r
.50663 .6508 m .50553 .65491 L .50421 .65116 L F
.50663 .6508 m .50784 .6546 L .50553 .65491 L F
.203 0 .178 r
.50779 .65472 m .50553 .65491 L .50784 .6546 L F
.50779 .65472 m .50488 .65644 L .50553 .65491 L F
.564 .503 .745 r
.53247 .64041 m .53419 .63671 L .53154 .63881 L F
.131 .302 .77 r
.64007 .43581 m .63911 .43738 L .63765 .43408 L F
0 0 .528 r
.64029 .43839 m .63911 .43738 L .64007 .43581 L F
.514 .533 .814 r
.64241 .44041 m .64178 .43983 L .64061 .43955 L F
.64178 .43983 m .63911 .43738 L .64061 .43955 L F
0 0 .528 r
.64029 .43839 m .64061 .43955 L .63911 .43738 L F
.903 .764 .697 r
.6387 .43908 m .64061 .43955 L .64029 .43839 L F
.63792 .43943 m .64061 .43955 L .6387 .43908 L F
0 0 .496 r
.47624 .6158 m .47626 .61615 L .47573 .61522 L F
.743 .821 .356 r
.47624 .6158 m .47503 .61883 L .47626 .61615 L F
0 .571 .708 r
.37743 .5822 m .37951 .58222 L .38112 .58224 L F
.204 .731 .825 r
.37951 .58222 m .38338 .58192 L .38112 .58224 L F
.464 .208 .441 r
.57881 .59066 m .58137 .59005 L .58154 .5881 L F
.576 .302 .463 r
.58137 .59005 m .58405 .58987 L .58154 .5881 L F
.628 .259 .324 r
.58154 .5881 m .58405 .58987 L .58378 .58835 L F
.22 0 0 r
.36759 .598 m .36513 .59859 L .36626 .59743 L F
.128 .456 .886 r
.58287 .60426 m .58491 .60577 L .58141 .60418 L F
0 .315 .691 r
.58141 .60418 m .5848 .60572 L .58533 .60606 L F
.5848 .60572 m .58491 .60577 L .58492 .60578 L F
.5848 .60572 m .58492 .60578 L .58533 .60606 L F
.803 .515 .502 r
.58217 .6065 m .58335 .60665 L .58299 .60484 L F
.58273 .60471 m .58299 .60484 L .58287 .60426 L F
.58217 .6065 m .58299 .60484 L .58273 .60471 L F
.128 .456 .886 r
.58287 .60426 m .58141 .60418 L .58104 .60502 L F
.825 .765 .796 r
.46341 .69569 m .46281 .69783 L .45966 .6976 L F
.746 .68 .787 r
.46341 .69569 m .46567 .69497 L .46281 .69783 L F
.688 .47 .585 r
.51894 .69159 m .5215 .68943 L .519 .68965 L F
.325 .096 .404 r
.21182 .60824 m .21142 .61096 L .20948 .61131 L F
.48 .327 .595 r
.21142 .61096 m .20923 .61361 L .20948 .61131 L F
.32 0 0 r
.19052 .54354 m .19429 .54438 L .19233 .54381 L F
.675 .491 .629 r
.53881 .65694 m .54087 .6543 L .53865 .65477 L F
.574 .29 .447 r
.50529 .63362 m .50371 .63122 L .50287 .63379 L F
.50529 .63362 m .50631 .63109 L .50371 .63122 L F
.732 .589 .697 r
.58455 .64831 m .58165 .64508 L .58244 .64596 L F
.455 .595 .902 r
.42637 .58701 m .4254 .58782 L .4225 .58395 L F
.458 .761 .995 r
.35533 .6215 m .3576 .62128 L .3569 .62257 L F
.302 .571 .933 r
.3576 .62128 m .35891 .62306 L .3569 .62257 L F
.71 .393 .438 r
.44708 .62203 m .4432 .62218 L .44333 .62028 L F
.435 .687 .97 r
.46992 .68203 m .46901 .68354 L .47108 .68346 L F
.46992 .68203 m .46901 .68354 L .47108 .68346 L F
.886 .494 .043 r
.47039 .68295 m .47108 .68346 L .46992 .68203 L F
.283 .731 .96 r
.46901 .68354 m .47183 .68401 L .47108 .68346 L F
.47108 .68346 m .4728 .68417 L .46901 .68354 L F
.886 .494 .043 r
.47186 .68585 m .47108 .68346 L .47039 .68295 L F
.283 .731 .96 r
.47183 .68401 m .4728 .68417 L .47108 .68346 L F
.586 .872 .994 r
.47108 .68346 m .4728 .68417 L .47496 .68334 L F
.543 .149 .244 r
.47186 .68585 m .4728 .68417 L .47108 .68346 L F
.47186 .68585 m .47496 .68334 L .4728 .68417 L F
.797 .73 .79 r
.63296 .43553 m .62926 .43708 L .63165 .43412 L F
.638 .19 .17 r
.4757 .69566 m .47381 .69713 L .47121 .69541 L F
.288 .467 .862 r
.4767 .69411 m .47837 .69775 L .4757 .69566 L F
.782 .389 .31 r
.47837 .69775 m .47381 .69713 L .4757 .69566 L F
.572 .616 .858 r
.7779 .52099 m .77973 .52212 L .78024 .52043 L F
.583 .74 .951 r
.77973 .52212 m .78253 .52015 L .78024 .52043 L F
.77973 .52212 m .78449 .52078 L .78253 .52015 L F
.851 .587 .539 r
.5257 .72377 m .52883 .72419 L .52805 .72117 L F
.312 0 0 r
.52805 .72117 m .53226 .72143 L .53183 .72134 L F
.41 .758 .995 r
.53077 .72041 m .53226 .72143 L .52848 .7212 L F
.393 .268 .59 r
.53183 .72134 m .53226 .72143 L .53407 .7205 L F
.586 .838 .993 r
.53407 .7205 m .53226 .72143 L .53077 .72041 L F
.53407 .7205 m .53077 .72041 L .53229 .71955 L F
.239 .081 .455 r
.53077 .72041 m .53084 .72311 L .53213 .71993 L F
.53077 .72041 m .53213 .71993 L .53229 .71955 L F
.41 .758 .995 r
.53077 .72041 m .52848 .7212 L .52805 .72117 L F
.161 .158 .606 r
.52805 .72117 m .53084 .72311 L .53077 .72041 L F
.988 .857 .618 r
.58639 .61909 m .5881 .61727 L .58751 .62011 L F
.981 .911 .639 r
.58639 .61909 m .58739 .61662 L .5881 .61727 L F
.547 .287 .473 r
.4902 .65728 m .4926 .65725 L .49371 .65364 L F
.65 .359 .464 r
.49588 .65611 m .49371 .65364 L .4926 .65725 L F
.49588 .65611 m .49586 .65444 L .49371 .65364 L F
.511 .391 .653 r
.31623 .60265 m .31829 .60213 L .31802 .59965 L F
.462 .326 .61 r
.31663 .60504 m .31829 .60213 L .31623 .60265 L F
0 0 .126 r
.22945 .56314 m .22904 .56206 L .2313 .56172 L F
.22945 .56314 m .22884 .56436 L .22904 .56206 L F
.791 .536 .552 r
.45858 .6104 m .46223 .60841 L .45847 .60796 L F
.45858 .6104 m .46318 .61067 L .46223 .60841 L F
.096 .173 .655 r
.46223 .60841 m .46402 .61085 L .46438 .60788 L F
.46223 .60841 m .46318 .61067 L .46402 .61085 L F
.006 .14 .654 r
.46402 .61085 m .46223 .60841 L .46438 .60788 L F
.824 .643 .658 r
.6235 .45418 m .62697 .45507 L .62497 .45731 L F
.755 .52 .577 r
.62697 .45507 m .62722 .45717 L .62497 .45731 L F
.575 .611 .851 r
.52418 .72702 m .5257 .72377 L .5254 .7247 L F
.13 0 0 r
.39251 .6344 m .39082 .63572 L .38863 .6362 L F
.249 0 0 r
.39483 .6342 m .39082 .63572 L .39251 .6344 L F
.689 .412 .497 r
.64878 .45211 m .65096 .45437 L .64896 .45372 L F
.392 0 0 r
.75374 .49407 m .75607 .49459 L .7569 .49425 L F
0 0 0 r
.7569 .49425 m .75843 .49372 L .75921 .49378 L F
.7569 .49425 m .75607 .49459 L .75843 .49372 L F
.39075 .62345 m .38999 .62343 L .38836 .62372 L F
.39075 .62345 m .39225 .62302 L .38999 .62343 L F
.18 0 .151 r
.78082 .48362 m .78372 .48268 L .78384 .48086 L F
.204 0 0 r
.78082 .48362 m .78307 .48403 L .78372 .48268 L F
.568 .357 .555 r
.77831 .48563 m .78082 .48749 L .78077 .48489 L F
.77831 .48563 m .77861 .48852 L .78082 .48749 L F
0 0 0 r
.78077 .48489 m .77962 .48743 L .78057 .48611 L F
.204 0 0 r
.78097 .48364 m .78077 .48489 L .78307 .48403 L F
.543 .903 .968 r
.78307 .48403 m .78077 .48489 L .78241 .48356 L F
0 0 0 r
.78077 .48489 m .78057 .48611 L .78241 .48356 L F
.204 0 0 r
.78082 .48362 m .78077 .48489 L .78097 .48364 L F
.762 .488 .519 r
.57766 .64499 m .58113 .64255 L .5777 .64359 L F
.57766 .64499 m .58165 .64508 L .58113 .64255 L F
.562 .42 .646 r
.58409 .64049 m .58113 .64255 L .5826 .64187 L F
0 0 .164 r
.58165 .64508 m .5826 .64187 L .58113 .64255 L F
.528 .489 .757 r
.46869 .69782 m .46662 .69846 L .46567 .69497 L F
.079 .402 .856 r
.46774 .69938 m .46662 .69846 L .46869 .69782 L F
.46774 .69938 m .46732 .70054 L .46662 .69846 L F
.621 .458 .64 r
.50072 .6655 m .50062 .66785 L .50165 .66687 L F
.884 .506 .317 r
.50124 .66727 m .50383 .67098 L .50165 .66687 L F
.5031 .67028 m .50383 .67098 L .50124 .66727 L F
.50062 .66785 m .5031 .67028 L .50124 .66727 L F
.674 .514 .661 r
.50062 .66785 m .50425 .67058 L .50383 .67098 L F
.435 .846 .967 r
.50383 .67098 m .50425 .67058 L .50235 .67148 L F
.668 .327 .387 r
.50497 .67381 m .50235 .67148 L .50351 .67093 L F
.5048 .67301 m .50351 .67093 L .50425 .67058 L F
.50497 .67381 m .50351 .67093 L .5048 .67301 L F
.572 .209 .313 r
.47328 .66225 m .47577 .6621 L .47357 .66071 L F
.601 .476 .682 r
.47357 .66071 m .4763 .66038 L .47562 .65752 L F
.537 .246 .42 r
.47357 .66071 m .47577 .6621 L .4763 .66038 L F
.333 .314 .688 r
.4667 .68625 m .46689 .69005 L .46885 .68804 L F
.956 .72 .54 r
.46863 .6914 m .46689 .69005 L .46678 .69016 L F
.46863 .6914 m .46885 .68804 L .46689 .69005 L F
0 .143 .688 r
.56998 .65191 m .57151 .65491 L .57139 .65377 L F
0 .091 .649 r
.57151 .65491 m .57304 .65582 L .57139 .65377 L F
.57151 .65491 m .5738 .65771 L .57304 .65582 L F
.807 .609 .636 r
.53998 .65141 m .5368 .65344 L .53613 .6505 L F
.53998 .65141 m .53613 .6505 L .53969 .6514 L F
0 0 .374 r
.54208 .64812 m .54137 .65047 L .53969 .6514 L F
.54137 .65047 m .54111 .65134 L .54012 .65138 L F
.54137 .65047 m .54012 .65138 L .53969 .6514 L F
.178 0 0 r
.54012 .65138 m .54004 .65145 L .53998 .65141 L F
.54012 .65138 m .53998 .65141 L .53969 .6514 L F
0 0 .374 r
.54111 .65134 m .54096 .65183 L .53969 .6514 L F
.54208 .64812 m .54211 .65092 L .54096 .65183 L F
.178 0 0 r
.54211 .65092 m .54007 .65147 L .54004 .65145 L F
.54211 .65092 m .54004 .65145 L .54012 .65138 L F
.54211 .65092 m .54012 .65138 L .53969 .6514 L F
.437 .844 .971 r
.53997 .65149 m .54211 .65092 L .53969 .6514 L F
.54096 .65183 m .54211 .65092 L .53997 .65149 L F
.178 0 0 r
.54211 .65092 m .54148 .65231 L .54007 .65147 L F
.447 .203 .449 r
.221 .58477 m .21845 .58759 L .21901 .58541 L F
.555 .636 .886 r
.77628 .51809 m .7779 .52099 L .78024 .52043 L F
.862 .764 .752 r
.57307 .62971 m .57528 .62882 L .57352 .62714 L F
.577 .722 .941 r
.57352 .62714 m .57528 .62882 L .57737 .62811 L F
.57352 .62714 m .57528 .62882 L .57737 .62811 L F
.413 .156 .412 r
.22305 .58413 m .22175 .58259 L .22304 .58164 L F
.22305 .58413 m .221 .58477 L .22175 .58259 L F
.478 .332 .604 r
.31797 .59703 m .32009 .59898 L .32001 .59611 L F
.31797 .59703 m .31802 .59965 L .32009 .59898 L F
.395 0 .124 r
.39444 .62306 m .39667 .62259 L .39838 .62033 L F
.512 .101 .199 r
.39838 .62033 m .39667 .62259 L .40028 .62152 L F
.486 .13 .287 r
.39838 .62033 m .40028 .62152 L .40081 .62006 L F
.907 .954 .816 r
.62685 .44239 m .62388 .44631 L .62356 .44424 L F
.905 .966 .65 r
.6226 .44842 m .62141 .44952 L .6239 .44512 L F
.62174 .45059 m .62145 .44966 L .6226 .44842 L F
.62145 .44966 m .62141 .44952 L .6226 .44842 L F
.977 .802 .602 r
.62441 .44919 m .62308 .44868 L .62322 .44775 L F
.62382 .4471 m .62322 .44775 L .62349 .44594 L F
.62441 .44919 m .62322 .44775 L .62382 .4471 L F
.834 .604 .59 r
.62441 .44919 m .62174 .45059 L .62308 .44868 L F
.62441 .44919 m .6241 .45159 L .62174 .45059 L F
.502 .186 .363 r
.57574 .59344 m .57834 .59335 L .57881 .59066 L F
.382 .035 .246 r
.58044 .5923 m .57881 .59066 L .57834 .59335 L F
.58044 .5923 m .58137 .59005 L .57881 .59066 L F
0 0 .113 r
.78384 .48086 m .78372 .48268 L .78512 .48155 L F
0 .268 .77 r
.58375 .60133 m .58449 .60352 L .58287 .60426 L F
.58573 .6021 m .58508 .60523 L .58603 .60222 L F
.58375 .60133 m .58475 .60426 L .58548 .60264 L F
.58475 .60426 m .58508 .60523 L .58573 .6021 L F
.894 .664 .583 r
.58603 .60222 m .58533 .60606 L .58498 .60582 L F
.58603 .60222 m .58498 .60582 L .58508 .60523 L F
.58603 .60222 m .58773 .6052 L .58533 .60606 L F
0 .268 .77 r
.58596 .60367 m .58606 .6032 L .58653 .60427 L F
.58375 .60133 m .58606 .6032 L .58596 .60367 L F
.051 .408 .86 r
.58606 .6032 m .5825 .60039 L .58375 .60133 L F
0 .268 .77 r
.5846 .60459 m .58287 .60426 L .58491 .60577 L F
.654 .418 .55 r
.58383 .60629 m .5846 .60459 L .58287 .60426 L F
.5846 .60459 m .58475 .60426 L .58287 .60426 L F
0 .268 .77 r
.58542 .6031 m .58523 .60427 L .58287 .60426 L F
.58375 .60133 m .58287 .60426 L .5846 .60459 L F
.58375 .60133 m .58491 .60577 L .58508 .60523 L F
.654 .418 .55 r
.58383 .60629 m .58653 .60427 L .58475 .60426 L F
0 .268 .77 r
.58542 .6031 m .58653 .60427 L .58523 .60427 L F
.051 .408 .86 r
.5825 .60039 m .58208 .60005 L .58375 .60133 L F
0 .268 .77 r
.58375 .60133 m .58548 .60264 L .58573 .6021 L F
.926 .623 .449 r
.58557 .6001 m .58375 .60133 L .58345 .59887 L F
.58557 .6001 m .58603 .60222 L .58375 .60133 L F
.925 .606 .42 r
.58345 .59887 m .58375 .60133 L .58208 .60005 L F
.051 .408 .86 r
.58453 .60199 m .58552 .60197 L .58208 .60005 L F
.58606 .6032 m .58552 .60197 L .58453 .60199 L F
.328 .633 .962 r
.58647 .6019 m .58552 .60197 L .58606 .6032 L F
0 0 0 r
.58603 .60196 m .58552 .60197 L .58647 .6019 L F
0 .268 .77 r
.58375 .60133 m .58542 .6031 L .58449 .60352 L F
0 0 0 r
.58332 .60234 m .58552 .60197 L .58603 .60196 L F
.725 .828 .374 r
.58519 .60472 m .58622 .60245 L .58606 .6032 L F
.58622 .60245 m .58647 .6019 L .58606 .6032 L F
.654 .418 .55 r
.58335 .60665 m .58383 .60629 L .58287 .60426 L F
.894 .664 .583 r
.58508 .60523 m .58498 .60582 L .58491 .60577 L F
0 0 .373 r
.56924 .64996 m .56889 .64869 L .56934 .64987 L F
.533 .453 .711 r
.49478 .69702 m .49898 .69684 L .49764 .69456 L F
.394 .191 .482 r
.49529 .69589 m .49556 .69574 L .49536 .69186 L F
.056 0 .405 r
.49536 .69186 m .49556 .69574 L .49665 .69289 L F
.533 .453 .711 r
.49556 .69574 m .49764 .69456 L .49665 .69289 L F
.49478 .69702 m .49764 .69456 L .49529 .69589 L F
.056 0 .405 r
.49556 .69574 m .49558 .696 L .49665 .69289 L F
.533 .453 .711 r
.49529 .69589 m .49556 .69574 L .49665 .69289 L F
.394 .191 .482 r
.49292 .69505 m .49529 .69589 L .49536 .69186 L F
.49529 .69589 m .49558 .696 L .49556 .69574 L F
.533 .453 .711 r
.49478 .69702 m .49529 .69589 L .49558 .696 L F
.49529 .69589 m .49665 .69289 L .49558 .696 L F
.394 .191 .482 r
.49291 .69505 m .49558 .696 L .49292 .69505 L F
.353 .252 .599 r
.49291 .69505 m .49478 .69702 L .49558 .696 L F
0 0 0 r
.55919 .59613 m .56157 .59369 L .55791 .59347 L F
.55919 .59613 m .56067 .59552 L .56157 .59369 L F
.335 .548 .91 r
.55919 .59613 m .56155 .597 L .56067 .59552 L F
.949 .932 .746 r
.54145 .61258 m .54032 .61473 L .53946 .6137 L F
.244 .277 .698 r
.54055 .61423 m .54167 .61649 L .54137 .61243 L F
.54032 .61473 m .54054 .61501 L .54055 .61423 L F
.54054 .61501 m .54167 .61649 L .54055 .61423 L F
.949 .932 .746 r
.54145 .61258 m .54056 .61308 L .54066 .611 L F
.54056 .61308 m .53946 .6137 L .54058 .61118 L F
.54056 .61308 m .54058 .61118 L .54066 .611 L F
0 0 .36 r
.54137 .61243 m .54145 .61258 L .54066 .611 L F
.54137 .61243 m .54212 .61374 L .54145 .61258 L F
.709 .555 .677 r
.58457 .63183 m .58125 .63386 L .58255 .63143 L F
.785 .959 .64 r
.55309 .70239 m .55246 .70409 L .5547 .70098 L F
.792 .987 .735 r
.55309 .70239 m .55059 .70511 L .55246 .70409 L F
.592 .158 .186 r
.36654 .64038 m .36515 .64227 L .36267 .64164 L F
0 0 0 r
.36706 .64112 m .36654 .64038 L .36874 .64054 L F
.36706 .64112 m .36515 .64227 L .36654 .64038 L F
.752 .694 .796 r
.43469 .59579 m .43229 .59683 L .43541 .59705 L F
.685 .602 .758 r
.43229 .59683 m .43584 .59954 L .43541 .59705 L F
.59 .624 .854 r
.43541 .59705 m .43807 .59551 L .43469 .59579 L F
.43541 .59705 m .43732 .59668 L .43807 .59551 L F
.497 .362 .627 r
.43584 .59954 m .43732 .59668 L .43541 .59705 L F
.14 0 .247 r
.51851 .66281 m .51707 .66374 L .51621 .66585 L F
.51851 .66281 m .51707 .66374 L .51621 .66585 L F
.825 .765 .796 r
.46341 .69569 m .45966 .6976 L .45996 .69545 L F
.176 .05 .459 r
.22884 .56436 m .22733 .56735 L .22667 .56552 L F
.866 .655 .614 r
.55509 .63175 m .55277 .62924 L .5532 .62968 L F
.55277 .62924 m .55176 .62814 L .5532 .62968 L F
0 .116 .587 r
.55165 .62853 m .5535 .63 L .5532 .62968 L F
.5535 .63 m .55407 .63044 L .5532 .62968 L F
.339 .112 .417 r
.35526 .60228 m .35454 .60497 L .35294 .60548 L F
.533 .36 .592 r
.35454 .60497 m .35273 .6077 L .35294 .60548 L F
.552 .797 .99 r
.3223 .6342 m .32625 .63489 L .32468 .63323 L F
.59 .727 .939 r
.32468 .63323 m .32625 .63489 L .32846 .63426 L F
.77 .788 .867 r
.49844 .73664 m .49891 .73634 L .50242 .73512 L F
.405 .174 .447 r
.50242 .73512 m .50225 .73599 L .50406 .73517 L F
.50406 .73517 m .50225 .73599 L .50242 .73512 L F
.547 .049 0 r
.56262 .59492 m .56157 .59369 L .56067 .59552 L F
.56262 .59492 m .56407 .59639 L .56157 .59369 L F
.477 .236 .469 r
.35754 .60169 m .35454 .60497 L .35526 .60228 L F
.73 .41 .437 r
.52567 .69207 m .52488 .69457 L .52229 .69351 L F
.556 .251 .406 r
.52815 .69182 m .52488 .69457 L .52567 .69207 L F
.516 .572 .851 r
.46137 .71504 m .462 .71169 L .46041 .71174 L F
.46137 .71504 m .46356 .71481 L .462 .71169 L F
.465 .881 .931 r
.64032 .44635 m .63806 .44712 L .63648 .44686 L F
.485 .384 .664 r
.21357 .6061 m .21366 .60767 L .21182 .60824 L F
.388 .149 .425 r
.21293 .61009 m .21182 .60824 L .21366 .60767 L F
.21293 .61009 m .21142 .61096 L .21182 .60824 L F
.293 .35 .75 r
.53867 .64258 m .53968 .64601 L .54125 .64471 L F
.303 .367 .763 r
.53968 .64601 m .54208 .64812 L .54125 .64471 L F
0 0 .291 r
.63529 .44476 m .63417 .44342 L .63675 .44347 L F
.63529 .44476 m .63405 .4459 L .63417 .44342 L F
.192 .695 .908 r
.21174 .54654 m .21549 .54701 L .21374 .54709 L F
.672 .443 .566 r
.63669 .45495 m .63938 .45755 L .63674 .45761 L F
.63669 .45495 m .63929 .45487 L .63938 .45755 L F
.711 .512 .618 r
.63669 .45495 m .63674 .45761 L .63488 .45747 L F
.154 .649 .915 r
.2021 .54419 m .20388 .54487 L .20016 .54398 L F
.222 .744 .787 r
.20445 .54452 m .20388 .54487 L .2021 .54419 L F
0 .514 .806 r
.20268 .54394 m .20441 .54443 L .20445 .54452 L F
.222 .744 .787 r
.20445 .54452 m .2076 .54418 L .20453 .54475 L F
.538 0 0 r
.20809 .54525 m .2076 .54418 L .20445 .54452 L F
0 .514 .806 r
.20441 .54443 m .20628 .54496 L .20445 .54452 L F
.222 .744 .787 r
.20445 .54452 m .20453 .54475 L .20388 .54487 L F
.942 .576 .226 r
.61207 .65333 m .61267 .65206 L .61187 .65096 L F
.61207 .65333 m .61331 .65423 L .61267 .65206 L F
.999 .835 .532 r
.57437 .64226 m .57399 .64499 L .57529 .64339 L F
.62 .18 .182 r
.57399 .64499 m .57766 .64499 L .57529 .64339 L F
.531 .279 .478 r
.57529 .64339 m .57766 .64499 L .5777 .64359 L F
.444 .504 .826 r
.77419 .51815 m .775 .51463 L .77287 .51494 L F
.77419 .51815 m .77628 .51809 L .775 .51463 L F
.848 .464 .323 r
.79582 .51289 m .80091 .51611 L .79787 .51716 L F
.79582 .51289 m .79865 .51645 L .80091 .51611 L F
.872 .957 .858 r
.80091 .51611 m .80187 .51181 L .80199 .51489 L F
.80091 .51611 m .79865 .51645 L .80187 .51181 L F
.635 .607 .805 r
.80384 .51569 m .80091 .51611 L .80199 .51489 L F
.679 .403 .497 r
.42654 .61331 m .42889 .61353 L .42983 .61106 L F
.685 .41 .5 r
.42983 .61106 m .43229 .61345 L .4325 .61123 L F
.42983 .61106 m .42889 .61353 L .43229 .61345 L F
.139 .67 .866 r
.38338 .58192 m .38563 .58194 L .38706 .58228 L F
.157 0 0 r
.38563 .58194 m .38928 .58186 L .38706 .58228 L F
.73 .664 .784 r
.44066 .60841 m .43841 .61144 L .44167 .61032 L F
.678 .406 .503 r
.43824 .6132 m .44167 .61032 L .43841 .61144 L F
.43824 .6132 m .44088 .61343 L .44167 .61032 L F
.593 .577 .805 r
.44167 .61032 m .44299 .60769 L .44066 .60841 L F
.44167 .61032 m .44424 .61079 L .44299 .60769 L F
.623 .352 .486 r
.44167 .61032 m .4443 .61281 L .44424 .61079 L F
.44167 .61032 m .44088 .61343 L .4443 .61281 L F
.578 .033 0 r
.5785 .65139 m .58074 .65193 L .58005 .65186 L F
0 0 .272 r
.58074 .65193 m .58124 .65287 L .58136 .65204 L F
.051 0 0 r
.58074 .65193 m .58295 .65156 L .58024 .65184 L F
0 0 .272 r
.58074 .65193 m .58158 .65045 L .58295 .65156 L F
.58074 .65193 m .58136 .65204 L .58158 .65045 L F
.051 0 0 r
.58074 .65193 m .58024 .65184 L .58005 .65186 L F
.683 .607 .764 r
.43592 .61052 m .43841 .61144 L .43785 .60779 L F
.669 .405 .512 r
.43592 .61052 m .43824 .6132 L .43841 .61144 L F
.7 .618 .762 r
.43785 .60779 m .43841 .61144 L .44066 .60841 L F
.339 .796 .667 r
.51007 .66832 m .51101 .6679 L .514 .66646 L F
.51007 .66832 m .514 .66646 L .51271 .66778 L F
.72 .287 .222 r
.51026 .66582 m .51271 .66778 L .514 .66646 L F
.539 .231 .394 r
.5038 .69994 m .49994 .7031 L .50031 .70125 L F
.536 .136 .229 r
.47062 .62006 m .4699 .62171 L .46694 .62197 L F
.607 .208 .26 r
.47062 .62006 m .47255 .62189 L .4699 .62171 L F
.691 .416 .501 r
.51053 .68087 m .51063 .68332 L .50842 .68327 L F
.526 .232 .411 r
.51401 .68024 m .51063 .68332 L .51053 .68087 L F
.427 .386 .711 r
.31861 .61432 m .3198 .61038 L .31774 .61084 L F
.31861 .61432 m .32046 .61408 L .3198 .61038 L F
.432 .446 .774 r
.31861 .61432 m .3213 .61535 L .32046 .61408 L F
.706 .964 .715 r
.40894 .61427 m .40632 .61674 L .40771 .61492 L F
.02 0 0 r
.4102 .6143 m .40894 .61427 L .40771 .61492 L F
.4102 .6143 m .411 .61419 L .40894 .61427 L F
.66 .395 .509 r
.43229 .61345 m .43592 .61052 L .4325 .61123 L F
.43229 .61345 m .43496 .6134 L .43592 .61052 L F
.669 .405 .512 r
.43592 .61052 m .43496 .6134 L .43824 .6132 L F
.663 .617 .793 r
.77608 .50101 m .77385 .50215 L .77291 .49693 L F
0 0 0 r
.56276 .68414 m .56183 .68536 L .56176 .68544 L F
.877 .458 .21 r
.56079 .68332 m .56183 .68536 L .56276 .68414 L F
.3 .735 .968 r
.79129 .48642 m .79251 .48536 L .78983 .48614 L F
.79129 .48642 m .79374 .48636 L .79251 .48536 L F
.186 0 0 r
.49379 .70373 m .49431 .70437 L .49179 .70409 L F
.143 .443 .877 r
.49179 .70409 m .49431 .70437 L .49233 .70287 L F
.457 0 0 r
.49476 .70481 m .4916 .70515 L .49372 .70396 L F
.509 0 0 r
.49431 .70437 m .49476 .70481 L .4945 .7046 L F
.457 0 0 r
.49476 .70481 m .49372 .70396 L .49391 .70385 L F
.509 0 0 r
.4945 .7046 m .49476 .70481 L .49451 .70462 L F
.737 .544 .631 r
.49391 .70385 m .49328 .70363 L .49233 .70287 L F
0 0 0 r
.49179 .70409 m .49318 .70058 L .49113 .70038 L F
.49272 .70175 m .49233 .70287 L .49318 .70058 L F
.49179 .70409 m .49233 .70287 L .49272 .70175 L F
.737 .544 .631 r
.49328 .70363 m .4922 .70324 L .49233 .70287 L F
.4922 .70324 m .48918 .70217 L .49233 .70287 L F
.49328 .70363 m .48928 .70495 L .48918 .70217 L F
.509 0 0 r
.49431 .70437 m .49437 .70444 L .49355 .70381 L F
.49344 .70371 m .49355 .70381 L .49233 .70287 L F
.49431 .70437 m .49355 .70381 L .49344 .70371 L F
.544 .271 .452 r
.4916 .70515 m .48928 .70495 L .49366 .70391 L F
.49372 .70396 m .49366 .70391 L .49391 .70385 L F
.4916 .70515 m .49366 .70391 L .49372 .70396 L F
.509 0 0 r
.49437 .70444 m .49328 .70363 L .49233 .70287 L F
.737 .544 .631 r
.49391 .70385 m .49366 .70391 L .49328 .70363 L F
.49366 .70391 m .48928 .70495 L .49328 .70363 L F
.509 0 0 r
.49437 .70444 m .49447 .70457 L .49328 .70363 L F
.49447 .70457 m .49451 .70462 L .49233 .70287 L F
.186 0 0 r
.49486 .70353 m .49431 .70437 L .49379 .70373 L F
.85 .562 .501 r
.49743 .70345 m .49431 .70437 L .49486 .70353 L F
.54 .82 .998 r
.58265 .66826 m .58381 .66925 L .58622 .66865 L F
.919 .719 .618 r
.59706 .61058 m .59862 .61133 L .59726 .60798 L F
.97 .721 .504 r
.59706 .61058 m .59831 .61377 L .59862 .61133 L F
.575 .611 .851 r
.52418 .72702 m .52652 .72664 L .5257 .72377 L F
.372 0 .135 r
.3607 .59981 m .35973 .60141 L .35754 .60169 L F
.338 0 .191 r
.36247 .59945 m .35973 .60141 L .3607 .59981 L F
.785 .509 .519 r
.50624 .64677 m .50411 .64986 L .50306 .64811 L F
.773 .413 .374 r
.51008 .64882 m .50588 .64953 L .50624 .64677 L F
0 0 .195 r
.50624 .64677 m .50588 .64953 L .50768 .64715 L F
.50624 .64677 m .50768 .64715 L .50411 .64986 L F
.382 0 .024 r
.40083 .63176 m .39936 .63339 L .39702 .63359 L F
.443 .005 .11 r
.40321 .6315 m .39936 .63339 L .40083 .63176 L F
.178 0 0 r
.19667 .54436 m .19792 .5441 L .19429 .54438 L F
.04 0 0 r
.19949 .54408 m .19792 .5441 L .19667 .54436 L F
.19949 .54408 m .20016 .54398 L .19792 .5441 L F
.79 .69 .754 r
.62726 .44012 m .62842 .44376 L .62685 .44239 L F
.494 .329 .586 r
.35273 .6077 m .35056 .61092 L .35027 .60859 L F
.508 .052 .103 r
.50861 .63363 m .51241 .63309 L .51212 .63228 L F
.594 .104 .061 r
.51241 .63309 m .51445 .63367 L .51212 .63228 L F
.785 .959 .64 r
.55309 .70239 m .5547 .70098 L .55121 .70096 L F
.426 .855 .725 r
.79381 .51329 m .79061 .5148 L .79274 .51426 L F
.086 0 0 r
.79582 .51289 m .79381 .51329 L .79274 .51426 L F
.559 .567 .819 r
.77049 .5155 m .7717 .51158 L .76924 .51215 L F
.77049 .5155 m .77287 .51494 L .7717 .51158 L F
.755 .866 .436 r
.79952 .48927 m .79858 .49083 L .80003 .48851 L F
0 0 .026 r
.54608 .67496 m .54714 .67371 L .54771 .67165 L F
0 0 .228 r
.54608 .67496 m .54674 .67599 L .54714 .67371 L F
.54608 .67496 m .54607 .67781 L .54674 .67599 L F
.557 .412 .64 r
.54707 .66623 m .54945 .66578 L .54918 .66326 L F
.579 .335 .511 r
.54707 .66623 m .54696 .66876 L .54944 .66827 L F
.537 .342 .565 r
.54707 .66623 m .54944 .66827 L .54945 .66578 L F
.81 .622 .648 r
.53741 .61582 m .54032 .61473 L .53946 .6137 L F
.53741 .61582 m .54046 .61752 L .54032 .61473 L F
.244 .277 .698 r
.54032 .61473 m .54137 .61243 L .53946 .6137 L F
.685 .602 .758 r
.43229 .59683 m .43349 .60022 L .43584 .59954 L F
.67 .801 .945 r
.51901 .69424 m .52029 .69533 L .52229 .69351 L F
.593 .368 .544 r
.52132 .6746 m .51867 .67726 L .51878 .67493 L F
.589 .767 .964 r
.40823 .58852 m .40983 .59024 L .41232 .58974 L F
.553 .573 .829 r
.40983 .59024 m .41279 .59117 L .41232 .58974 L F
.402 .245 .552 r
.47937 .67749 m .4792 .67888 L .47829 .67875 L F
.776 .37 .282 r
.47848 .67591 m .48168 .67741 L .4796 .67491 L F
.479 .67683 m .48168 .67741 L .47848 .67591 L F
.47776 .67656 m .479 .67683 L .47848 .67591 L F
.604 .812 .979 r
.48065 .676 m .48168 .67741 L .47776 .67656 L F
.402 .245 .552 r
.48065 .676 m .47965 .67798 L .47937 .67749 L F
.47965 .67798 m .4792 .67888 L .47937 .67749 L F
.142 0 0 r
.53419 .63671 m .53599 .63624 L .53706 .63483 L F
.594 .147 .158 r
.53706 .63483 m .53599 .63624 L .53954 .63615 L F
0 0 0 r
.45398 .68093 m .45292 .6825 L .45541 .67989 L F
.5 .782 .995 r
.46666 .60737 m .46814 .60852 L .46532 .60805 L F
.46532 .60805 m .46814 .60852 L .46666 .60737 L F
.58 .817 .989 r
.46666 .60737 m .46814 .60852 L .4703 .6078 L F
.4703 .6078 m .46814 .60852 L .46666 .60737 L F
.46666 .60737 m .46814 .60852 L .4703 .6078 L F
.109 0 .213 r
.55299 .6538 m .55047 .65704 L .5513 .65508 L F
0 0 0 r
.80436 .49205 m .80739 .48971 L .80632 .49112 L F
.374 .838 .889 r
.80363 .49183 m .80436 .49205 L .80632 .49112 L F
.837 .903 .884 r
.81072 .50627 m .80799 .5089 L .80715 .50779 L F
.809 .575 .584 r
.46805 .71406 m .46675 .71487 L .46606 .71545 L F
.483 .608 .9 r
.46446 .71681 m .46606 .71545 L .46356 .71481 L F
.794 .35 .19 r
.46606 .71545 m .46469 .71615 L .46428 .71524 L F
.809 .575 .584 r
.46675 .71487 m .46469 .71615 L .46606 .71545 L F
.483 .608 .9 r
.46503 .71809 m .46606 .71545 L .46446 .71681 L F
.46503 .71809 m .46731 .71755 L .46606 .71545 L F
0 .051 .61 r
.46503 .71809 m .46634 .71901 L .46731 .71755 L F
.46503 .71809 m .46595 .71909 L .46634 .71901 L F
.46595 .71909 m .46659 .71979 L .46634 .71901 L F
.791 .56 .587 r
.46731 .71755 m .46729 .72056 L .47175 .72038 L F
.969 .719 .503 r
.46731 .71755 m .46729 .72056 L .46634 .71901 L F
.4 .416 .761 r
.4674 .71802 m .46821 .71935 L .46634 .71901 L F
.708 .232 .118 r
.46821 .71935 m .46663 .71895 L .46634 .71901 L F
.4 .416 .761 r
.46607 .71819 m .46634 .71901 L .46445 .7184 L F
.708 .232 .118 r
.46663 .71895 m .46445 .7184 L .46634 .71901 L F
.4 .416 .761 r
.4674 .71802 m .46634 .71901 L .46607 .71819 L F
0 .051 .61 r
.46659 .71979 m .46729 .72056 L .46634 .71901 L F
.51 .814 1 r
.56516 .59744 m .56407 .59639 L .56155 .597 L F
.562 .745 .962 r
.56516 .59744 m .56616 .59569 L .56407 .59639 L F
.56516 .59744 m .56771 .59724 L .56616 .59569 L F
.999 .831 .537 r
.5786 .61704 m .57772 .61542 L .57817 .61891 L F
.473 .669 .949 r
.58263 .62931 m .58239 .62694 L .58102 .62858 L F
0 0 0 r
.58025 .63273 m .58091 .63224 L .58263 .62931 L F
.58091 .63224 m .58138 .63166 L .58263 .62931 L F
0 0 .511 r
.58263 .62931 m .58359 .62905 L .58239 .62694 L F
0 0 0 r
.58119 .63203 m .58359 .62905 L .58263 .62931 L F
0 0 .354 r
.58359 .62905 m .58242 .62601 L .58239 .62694 L F
.58261 .6265 m .58275 .62672 L .58242 .62601 L F
.58359 .62905 m .58275 .62672 L .58261 .6265 L F
.877 .818 .787 r
.57989 .63169 m .58275 .62672 L .58357 .62898 L F
.08 0 0 r
.58237 .62801 m .58324 .62751 L .58275 .62672 L F
.58324 .62751 m .58446 .6268 L .58275 .62672 L F
.877 .818 .787 r
.5834 .62919 m .58357 .62898 L .58359 .62905 L F
.57989 .63169 m .58357 .62898 L .5834 .62919 L F
0 0 0 r
.58091 .63224 m .58119 .63203 L .58138 .63166 L F
.141 .419 .862 r
.44158 .59193 m .44102 .59322 L .43864 .59056 L F
.44158 .59193 m .44267 .59385 L .44102 .59322 L F
.75 .401 .39 r
.74097 .48883 m .7428 .49135 L .74416 .48936 L F
.78 .439 .41 r
.7428 .49135 m .74634 .49205 L .74416 .48936 L F
.631 .648 .848 r
.53531 .61805 m .53695 .62002 L .53927 .61947 L F
.54 .375 .606 r
.32001 .59611 m .32237 .5929 L .32027 .59366 L F
.848 .788 .793 r
.79137 .50602 m .79291 .50729 L .79505 .50411 L F
0 0 0 r
.48342 .64937 m .48218 .6512 L .48489 .64804 L F
.628 .401 .555 r
.49533 .63643 m .49783 .63654 L .49791 .63436 L F
.601 .38 .552 r
.49783 .63654 m .50034 .63651 L .49791 .63436 L F
.603 .379 .55 r
.50034 .63651 m .50042 .6341 L .49791 .63436 L F
.745 .592 .686 r
.601 .62535 m .60327 .62248 L .60114 .62284 L F
.601 .62535 m .60471 .62557 L .60327 .62248 L F
.848 .788 .793 r
.79137 .50602 m .79505 .50411 L .79236 .50403 L F
.662 .444 .578 r
.54994 .68295 m .5532 .68315 L .55319 .68067 L F
.309 .089 .408 r
.53407 .7205 m .53135 .72221 L .53183 .72134 L F
.671 .853 .449 r
.2014 .56449 m .20414 .56011 L .20128 .56209 L F
.234 .365 .792 r
.43835 .58894 m .4373 .59044 L .43553 .5883 L F
.43835 .58894 m .43864 .59056 L .4373 .59044 L F
.252 .55 .929 r
.48499 .71132 m .48614 .7107 L .48399 .70912 L F
.48499 .71132 m .48718 .71218 L .48614 .7107 L F
.592 .363 .538 r
.64299 .45439 m .63938 .45755 L .63929 .45487 L F
.645 .734 .913 r
.51604 .72783 m .5159 .73 L .51464 .72924 L F
.536 .4 .643 r
.51828 .7323 m .51605 .73281 L .5159 .73 L F
.634 .076 0 r
.41342 .61466 m .41688 .61596 L .41507 .61436 L F
.54 .185 .314 r
.41507 .61436 m .41688 .61596 L .41799 .6136 L F
.275 .12 .482 r
.44891 .68646 m .45055 .68599 L .45079 .68321 L F
.336 .301 .671 r
.44891 .68646 m .45102 .68852 L .45055 .68599 L F
.269 .29 .698 r
.44973 .68876 m .45102 .68852 L .44891 .68646 L F
.581 .564 .8 r
.43453 .60598 m .43785 .60779 L .43699 .60531 L F
.743 .428 .45 r
.60309 .62765 m .60471 .62557 L .601 .62535 L F
.60309 .62765 m .60583 .62793 L .60471 .62557 L F
.578 .36 .548 r
.60583 .62793 m .60703 .62772 L .60471 .62557 L F
.665 .792 .943 r
.35321 .6394 m .35458 .64064 L .35689 .63985 L F
.287 0 0 r
.34999 .58398 m .35227 .584 L .35394 .58313 L F
.136 0 0 r
.35227 .584 m .35584 .58312 L .35394 .58313 L F
.176 .05 .459 r
.22884 .56436 m .22851 .56692 L .22733 .56735 L F
.445 .336 .635 r
.22851 .56692 m .22693 .57012 L .22733 .56735 L F
.617 .794 .967 r
.36867 .62484 m .36627 .6257 L .36504 .62439 L F
.36867 .62484 m .36627 .6257 L .36504 .62439 L F
.619 .628 .837 r
.74541 .51252 m .74887 .51508 L .74789 .51201 L F
.674 .684 .851 r
.74789 .51201 m .74887 .51508 L .75152 .51291 L F
.979 .748 .518 r
.4674 .70928 m .46923 .71134 L .46742 .70574 L F
.686 .147 0 r
.46646 .71126 m .46923 .71134 L .4674 .70928 L F
.46646 .71126 m .46925 .71222 L .46923 .71134 L F
0 0 0 r
.46923 .71134 m .47029 .71095 L .47086 .71049 L F
.46923 .71134 m .46925 .71222 L .47029 .71095 L F
.745 .519 .588 r
.51008 .64882 m .50663 .6508 L .50588 .64953 L F
.44 .591 .906 r
.53261 .61574 m .53457 .61556 L .53479 .61454 L F
.917 .544 .117 r
.58751 .62011 m .58808 .62225 L .58639 .61909 L F
.29 0 0 r
.63906 .44215 m .64241 .44041 L .64061 .43955 L F
.134 .675 .833 r
.64894 .44624 m .64955 .44649 L .64628 .44639 L F
.636 .096 0 r
.65053 .44734 m .65172 .44864 L .65242 .449 L F
.64955 .44649 m .65172 .44864 L .65053 .44734 L F
.659 .124 0 r
.65172 .44864 m .65262 .44968 L .65242 .449 L F
0 .094 .646 r
.6513 .44662 m .65259 .44959 L .65172 .44864 L F
.65259 .44959 m .65262 .44968 L .65172 .44864 L F
.025 .236 .74 r
.6513 .44662 m .65172 .44864 L .64955 .44649 L F
.079 .402 .856 r
.46774 .69938 m .4686 .70102 L .46732 .70054 L F
.729 .99 .845 r
.78672 .47875 m .7881 .47673 L .78884 .47748 L F
.78672 .47875 m .78482 .47925 L .7881 .47673 L F
.289 .124 .476 r
.20785 .61944 m .20756 .62202 L .20581 .62276 L F
.201 .039 .425 r
.20756 .62202 m .20567 .62524 L .20581 .62276 L F
.48 .814 .999 r
.41073 .58287 m .41295 .58242 L .41419 .58315 L F
.509 .821 1 r
.41295 .58242 m .41647 .58273 L .41419 .58315 L F
.975 .718 .481 r
.61139 .64758 m .61291 .64583 L .61143 .64367 L F
.61139 .64758 m .61284 .64872 L .61291 .64583 L F
.468 .542 .85 r
.20961 .54557 m .2076 .54418 L .20809 .54525 L F
.499 .36 .623 r
.21938 .5911 m .21959 .59328 L .21756 .59381 L F
.488 .304 .557 r
.21948 .59572 m .21756 .59381 L .21959 .59328 L F
.21948 .59572 m .21743 .59627 L .21756 .59381 L F
.528 .489 .757 r
.46869 .69782 m .46567 .69497 L .47009 .69595 L F
.294 .79 .861 r
.39421 .59178 m .39033 .59224 L .39191 .59208 L F
.461 .083 .234 r
.32237 .5929 m .32461 .59276 L .3255 .59102 L F
.347 0 .176 r
.3255 .59102 m .32692 .59187 L .32765 .59056 L F
.3255 .59102 m .32461 .59276 L .32692 .59187 L F
.568 .523 .764 r
.3255 .59102 m .32765 .59056 L .32691 .58939 L F
.487 .802 1 r
.38928 .58186 m .39142 .58146 L .39295 .58237 L F
0 .545 .78 r
.39142 .58146 m .39515 .58212 L .39295 .58237 L F
.251 .39 .808 r
.45489 .70347 m .45631 .70669 L .45759 .70538 L F
.259 .403 .817 r
.45631 .70669 m .45913 .70861 L .45759 .70538 L F
.767 .827 .899 r
.77766 .49457 m .77901 .49514 L .78068 .49523 L F
.724 .855 .943 r
.78068 .49523 m .77901 .49514 L .77919 .49497 L F
.703 .805 .928 r
.78237 .492 m .77919 .49497 L .77788 .4918 L F
.77919 .49497 m .77901 .49514 L .77892 .49486 L F
.77919 .49497 m .77892 .49486 L .77788 .4918 L F
.829 .612 .609 r
.78068 .49523 m .77983 .49508 L .77892 .49486 L F
.77878 .49481 m .77892 .49486 L .77766 .49457 L F
.78068 .49523 m .77892 .49486 L .77878 .49481 L F
.75 .83 .914 r
.77892 .49486 m .77901 .49514 L .77766 .49457 L F
.829 .612 .609 r
.77983 .49508 m .77765 .4947 L .77766 .49457 L F
.75 .83 .914 r
.77788 .4918 m .77892 .49486 L .77766 .49457 L F
.724 .855 .943 r
.78068 .49523 m .77919 .49497 L .78237 .492 L F
.829 .612 .609 r
.78068 .49523 m .77737 .49703 L .77765 .4947 L F
.78068 .49523 m .78081 .49771 L .77737 .49703 L F
.675 .492 .631 r
.78068 .49523 m .78292 .49837 L .78081 .49771 L F
.724 .855 .943 r
.78068 .49523 m .78237 .492 L .78409 .49475 L F
.648 .56 .742 r
.78409 .49475 m .78392 .49588 L .78068 .49523 L F
.759 .593 .673 r
.78392 .49588 m .78292 .49837 L .78068 .49523 L F
.143 0 0 r
.18734 .54379 m .19052 .54354 L .18848 .54351 L F
.709 .555 .677 r
.58457 .63183 m .58573 .63354 L .58125 .63386 L F
.442 .353 .66 r
.58712 .63198 m .58573 .63354 L .58457 .63183 L F
.601 .282 .402 r
.41688 .61596 m .42049 .61348 L .41799 .6136 L F
.543 .357 .578 r
.48991 .64008 m .49237 .63974 L .49213 .63712 L F
.419 .139 .379 r
.49237 .63974 m .49533 .63643 L .49213 .63712 L F
.445 .29 .576 r
.48991 .64008 m .49209 .64201 L .49237 .63974 L F
.48991 .64008 m .49011 .64255 L .49209 .64201 L F
.448 0 0 r
.35584 .58312 m .35814 .58342 L .35977 .58216 L F
.423 0 0 r
.35814 .58342 m .36224 .58268 L .35977 .58216 L F
.75 .472 .51 r
.58775 .59216 m .59156 .59028 L .58758 .59022 L F
.58775 .59216 m .59024 .59291 L .59156 .59028 L F
.693 .365 .416 r
.59024 .59291 m .59329 .59171 L .59156 .59028 L F
.14 0 0 r
.54315 .61041 m .54313 .61074 L .54066 .611 L F
.54066 .611 m .54313 .61074 L .54315 .61041 L F
0 0 0 r
.54501 .6097 m .54313 .61074 L .54315 .61041 L F
.54315 .61041 m .54313 .61074 L .54501 .6097 L F
.309 .089 .408 r
.53407 .7205 m .53357 .72294 L .53135 .72221 L F
.339 .009 .25 r
.53135 .72221 m .53357 .72294 L .53132 .72379 L F
.778 .688 .764 r
.55587 .69743 m .55908 .69485 L .5558 .69476 L F
.666 .229 .201 r
.55908 .69485 m .55761 .69648 L .5558 .69476 L F
.685 .936 .641 r
.56116 .69191 m .55955 .69326 L .55908 .69485 L F
.812 .937 .572 r
.55955 .69326 m .55761 .69648 L .55908 .69485 L F
.072 .595 .875 r
.47198 .67486 m .47198 .67507 L .47197 .67507 L F
.47198 .67486 m .47197 .67507 L .47006 .67459 L F
.327 0 0 r
.47134 .67542 m .47198 .67486 L .47006 .67459 L F
.703 .896 .526 r
.47198 .67458 m .47198 .67486 L .47134 .67542 L F
.691 .894 .528 r
.472 .67446 m .47198 .67486 L .47134 .67542 L F
0 0 .267 r
.47198 .67486 m .4719 .671 L .473 .67302 L F
.4719 .671 m .4719 .67098 L .473 .67302 L F
.703 .896 .526 r
.47217 .67434 m .47198 .67486 L .47199 .67457 L F
.47199 .67457 m .47198 .67486 L .47198 .67458 L F
.691 .894 .528 r
.473 .67302 m .47198 .67486 L .472 .67446 L F
.835 .48 .383 r
.47115 .67244 m .47198 .67486 L .47006 .67459 L F
.486 .854 .988 r
.46661 .67471 m .47006 .67459 L .47084 .67385 L F
.274 .509 .899 r
.47084 .67385 m .47006 .67459 L .47217 .67434 L F
.546 .84 .999 r
.46661 .67471 m .47084 .67385 L .46731 .67319 L F
.406 0 0 r
.47084 .67385 m .47209 .6743 L .46731 .67319 L F
.47209 .6743 m .47217 .67434 L .47208 .67431 L F
.47209 .6743 m .47208 .67431 L .46731 .67319 L F
.946 .785 .651 r
.47217 .67434 m .47004 .67376 L .46731 .67319 L F
.464 .678 .958 r
.473 .67302 m .47198 .67486 L .47134 .67542 L F
0 0 0 r
.473 .67302 m .472 .67446 L .47198 .67454 L F
.946 .785 .651 r
.47217 .67434 m .47134 .67542 L .47004 .67376 L F
0 0 0 r
.472 .67446 m .47134 .67542 L .47187 .67469 L F
.472 .67446 m .47187 .67469 L .47198 .67454 L F
.464 .678 .958 r
.473 .67302 m .47488 .67485 L .47198 .67486 L F
.473 .67302 m .47488 .67485 L .47198 .67486 L F
.647 .271 .318 r
.47198 .67454 m .47396 .6748 L .473 .67302 L F
0 .312 .736 r
.47776 .67656 m .47488 .67485 L .47636 .67435 L F
.513 .699 .954 r
.47636 .67435 m .47488 .67485 L .473 .67302 L F
.647 .271 .318 r
.47396 .6748 m .47571 .67503 L .473 .67302 L F
.072 .595 .875 r
.47198 .67486 m .47326 .67539 L .47198 .67507 L F
.257 .686 .964 r
.47488 .67485 m .47592 .6757 L .47326 .67539 L F
.369 .318 .67 r
.22699 .57491 m .22507 .57392 L .2269 .5723 L F
.22699 .57491 m .22551 .57622 L .22507 .57392 L F
.422 .826 .623 r
.53913 .60239 m .53992 .60182 L .542 .60049 L F
.609 .424 .607 r
.542 .60049 m .54192 .60264 L .53913 .60239 L F
.315 .712 .979 r
.53992 .60182 m .54192 .60264 L .53913 .60239 L F
.54 .568 .832 r
.74196 .5094 m .74317 .50575 L .74064 .50648 L F
.74196 .5094 m .74433 .50905 L .74317 .50575 L F
.259 .355 .772 r
.47179 .71427 m .46943 .71216 L .47116 .71239 L F
.389 .432 .784 r
.48769 .6574 m .49046 .6593 L .4902 .65728 L F
.702 .366 .405 r
.4973 .67698 m .49508 .67475 L .49737 .67503 L F
.675 .486 .622 r
.50168 .67612 m .4973 .67698 L .49737 .67503 L F
.448 .686 .967 r
.58979 .66904 m .59089 .66766 L .58879 .66843 L F
.58979 .66904 m .59298 .66975 L .59089 .66766 L F
.937 .667 .501 r
.59545 .60118 m .59757 .59966 L .59519 .5986 L F
.59545 .60118 m .59757 .60198 L .59757 .59966 L F
.605 .26 .359 r
.42908 .62232 m .42761 .62492 L .42545 .62446 L F
.177 0 .112 r
.42992 .62369 m .42908 .62232 L .4313 .62283 L F
.42992 .62369 m .42761 .62492 L .42908 .62232 L F
.025 0 0 r
.37227 .63984 m .37108 .64023 L .36874 .64054 L F
.032 0 0 r
.37308 .64009 m .37227 .63984 L .37453 .63917 L F
.37308 .64009 m .37108 .64023 L .37227 .63984 L F
.161 .701 .756 r
.64252 .44595 m .64379 .44586 L .64032 .44635 L F
0 .456 .708 r
.64499 .44608 m .64379 .44586 L .64252 .44595 L F
.64499 .44608 m .64628 .44639 L .64379 .44586 L F
.652 .813 .961 r
.79771 .51829 m .80117 .51867 L .80024 .51787 L F
.508 .814 1 r
.80117 .51867 m .80298 .51725 L .80024 .51787 L F
.80117 .51867 m .8038 .51818 L .80298 .51725 L F
.308 0 .138 r
.52168 .69177 m .52485 .68929 L .5215 .68943 L F
.52168 .69177 m .5239 .69126 L .52485 .68929 L F
.042 0 .378 r
.52485 .68929 m .52638 .68826 L .52652 .68587 L F
.457 .251 .51 r
.5239 .69126 m .52638 .68826 L .52485 .68929 L F
.343 .052 .319 r
.50276 .65706 m .50191 .65978 L .49977 .65979 L F
.279 0 .021 r
.49977 .65979 m .50187 .6608 L .49858 .66161 L F
.49977 .65979 m .50191 .65978 L .50187 .6608 L F
.659 .744 .913 r
.49663 .69034 m .49772 .69233 L .49396 .69124 L F
.056 0 .405 r
.49541 .69188 m .49665 .69289 L .49772 .69233 L F
.49536 .69186 m .49665 .69289 L .49541 .69188 L F
.693 .191 .046 r
.49772 .69233 m .49665 .69289 L .49396 .69124 L F
.477 .645 .931 r
.49981 .69032 m .49772 .69233 L .49663 .69034 L F
.571 .915 .703 r
.49981 .69032 m .49665 .69289 L .49772 .69233 L F
.502 0 0 r
.49665 .69289 m .50102 .6936 L .49772 .69233 L F
.63 .491 .674 r
.49665 .69289 m .50092 .69635 L .50113 .69362 L F
.49912 .69489 m .49898 .69684 L .50092 .69635 L F
.49665 .69289 m .4982 .69552 L .49912 .69489 L F
.4982 .69552 m .49898 .69684 L .49912 .69489 L F
.851 .623 .593 r
.501 .69361 m .50092 .69635 L .49844 .69535 L F
.50076 .69378 m .49844 .69535 L .50005 .69426 L F
.501 .69361 m .50034 .69406 L .50076 .69378 L F
.50034 .69406 m .49844 .69535 L .50076 .69378 L F
.502 0 0 r
.50102 .6936 m .50107 .69361 L .50104 .69358 L F
.50107 .69361 m .5011 .6936 L .50104 .69358 L F
.849 .388 .042 r
.50113 .6936 m .50169 .69314 L .50114 .69352 L F
.50114 .69352 m .50169 .69314 L .50129 .69206 L F
.785 .283 0 r
.50129 .69206 m .50194 .69297 L .50128 .69342 L F
.50194 .69297 m .50309 .69458 L .50128 .69342 L F
.851 .623 .593 r
.50128 .69342 m .50114 .6936 L .50109 .69355 L F
.50128 .69342 m .50109 .69355 L .50115 .69351 L F
.50128 .69342 m .50115 .69351 L .50156 .69323 L F
.50109 .69355 m .501 .69361 L .50103 .69359 L F
.50109 .69355 m .50103 .69359 L .50156 .69323 L F
.849 .388 .042 r
.50113 .6936 m .50218 .69447 L .50169 .69314 L F
.851 .623 .593 r
.50114 .6936 m .50092 .69635 L .501 .69361 L F
.863 .728 .208 r
.50113 .69368 m .50092 .69635 L .50115 .69725 L F
.851 .623 .593 r
.50126 .69359 m .50092 .69635 L .50114 .6936 L F
.863 .728 .208 r
.50113 .69362 m .50092 .69635 L .50113 .69368 L F
.849 .388 .042 r
.50113 .69362 m .50124 .6937 L .50113 .6936 L F
.50124 .6937 m .50218 .69447 L .50113 .6936 L F
.851 .623 .593 r
.50128 .69342 m .50126 .69359 L .50114 .6936 L F
.849 .388 .042 r
.5011 .6936 m .50129 .69206 L .49772 .69233 L F
.851 .623 .593 r
.50113 .6936 m .50114 .6936 L .5011 .6936 L F
.849 .388 .042 r
.50113 .69362 m .50113 .6936 L .5011 .6936 L F
.50113 .6936 m .50129 .69206 L .5011 .6936 L F
.851 .623 .593 r
.50109 .69355 m .50113 .6936 L .501 .69361 L F
.50113 .6936 m .5011 .6936 L .501 .69361 L F
.502 0 0 r
.50107 .69361 m .50113 .69362 L .5011 .6936 L F
.50102 .6936 m .50104 .69358 L .49772 .69233 L F
.851 .623 .593 r
.501 .69361 m .50005 .69426 L .50156 .69323 L F
.829 .612 .61 r
.49711 .68709 m .49981 .69032 L .49663 .69034 L F
0 0 .035 r
.49737 .68997 m .49665 .69289 L .49981 .69032 L F
.564 .909 .693 r
.49981 .69032 m .49718 .69204 L .49665 .69289 L F
.76 .301 .158 r
.49788 .69389 m .49665 .69289 L .49718 .69204 L F
.49844 .69535 m .49665 .69289 L .49788 .69389 L F
.724 .85 .941 r
.77861 .48852 m .77991 .49002 L .78195 .48861 L F
.77861 .48852 m .78195 .48861 L .78082 .48749 L F
.63 .818 .972 r
.78337 .48944 m .78029 .48918 L .78066 .48802 L F
.78135 .4879 m .78066 .48802 L .78082 .48749 L F
.151 .426 .865 r
.78366 .48848 m .78387 .48746 L .78195 .48861 L F
.78387 .48746 m .78304 .4876 L .78195 .48861 L F
.435 .024 .159 r
.78402 .48669 m .78082 .48749 L .78195 .48861 L F
.63 .818 .972 r
.78337 .48944 m .78066 .48802 L .78135 .4879 L F
.151 .426 .865 r
.78387 .48746 m .78402 .48669 L .78304 .4876 L F
.821 .606 .613 r
.78402 .48669 m .78765 .48734 L .78653 .48704 L F
.78765 .48734 m .78768 .48734 L .78653 .48704 L F
.774 .921 .935 r
.78867 .48406 m .78552 .48677 L .78653 .48704 L F
.821 .606 .613 r
.78402 .48669 m .78613 .48884 L .78768 .48734 L F
.151 .426 .865 r
.78366 .48848 m .78527 .48871 L .78402 .48669 L F
.78527 .48871 m .78515 .48784 L .78402 .48669 L F
.777 .675 .751 r
.78575 .48693 m .78405 .48737 L .78402 .48669 L F
.78653 .48704 m .78511 .48731 L .78575 .48693 L F
.78511 .48731 m .78176 .48796 L .78575 .48693 L F
.78653 .48704 m .78396 .48811 L .78176 .48796 L F
.705 .985 .84 r
.786 .48562 m .78412 .48791 L .78867 .48406 L F
.78412 .48791 m .78434 .48778 L .78867 .48406 L F
.774 .921 .935 r
.78552 .48677 m .78506 .48716 L .78653 .48704 L F
.78506 .48716 m .78396 .48811 L .78512 .48762 L F
.78506 .48716 m .78512 .48762 L .78653 .48704 L F
.151 .426 .865 r
.78527 .48871 m .78613 .48884 L .78515 .48784 L F
.246 .166 .563 r
.786 .48562 m .78567 .4887 L .78415 .48818 L F
.78412 .48791 m .78415 .48818 L .78396 .48811 L F
.705 .985 .84 r
.78412 .48791 m .78396 .48811 L .78434 .48778 L F
.246 .166 .563 r
.786 .48562 m .78415 .48818 L .78412 .48791 L F
.777 .675 .751 r
.78405 .48737 m .78176 .48796 L .78396 .48672 L F
.78405 .48737 m .78396 .48672 L .78402 .48669 L F
.408 .035 .215 r
.49508 .67475 m .49366 .67686 L .49141 .67724 L F
.702 .366 .405 r
.4973 .67698 m .49366 .67686 L .49508 .67475 L F
.968 .676 .418 r
.53161 .6662 m .53162 .66846 L .53006 .66739 L F
.683 .418 .515 r
.53581 .66799 m .53162 .66846 L .53162 .66693 L F
.53281 .66671 m .53162 .66693 L .53161 .6662 L F
.53581 .66799 m .53162 .66693 L .53281 .66671 L F
0 0 0 r
.53006 .66739 m .53254 .66704 L .53356 .66658 L F
.53335 .66662 m .53356 .66658 L .53361 .66655 L F
.53006 .66739 m .53356 .66658 L .53335 .66662 L F
.53006 .66739 m .53361 .66655 L .53161 .6662 L F
.225 .3 .731 r
.58102 .62858 m .58239 .62694 L .58016 .62446 L F
.549 .722 .954 r
.49188 .65074 m .49253 .65251 L .49455 .65166 L F
.462 .212 .449 r
.53336 .68651 m .533 .68866 L .53075 .6892 L F
.394 .154 .428 r
.53542 .68584 m .533 .68866 L .53336 .68651 L F
.33 0 .186 r
.46563 .66674 m .46491 .66814 L .46793 .66616 L F
.542 .272 .456 r
.50488 .65644 m .50191 .65978 L .50276 .65706 L F
.884 .515 .338 r
.54536 .63995 m .54648 .64223 L .54824 .64253 L F
.902 .488 .149 r
.54648 .64223 m .54867 .64544 L .54824 .64253 L F
.573 .277 .428 r
.55108 .59632 m .5506 .59744 L .54913 .59783 L F
.914 .687 .188 r
.55047 .65704 m .55056 .65945 L .55087 .65949 L F
.977 .702 .44 r
.55047 .65704 m .55193 .66044 L .55056 .65945 L F
.722 .68 .809 r
.46987 .61712 m .46716 .62055 L .46549 .61598 L F
.723 .808 .338 r
.19375 .5676 m .19378 .56749 L .19435 .56608 L F
0 .016 .519 r
.19378 .56749 m .19471 .56899 L .19397 .56667 L F
.928 .949 .612 r
.19435 .56608 m .19378 .56749 L .19355 .56614 L F
0 .016 .519 r
.19378 .56749 m .19397 .56667 L .19376 .56603 L F
.723 .808 .338 r
.19371 .56771 m .19378 .56749 L .19375 .5676 L F
0 0 .399 r
.19434 .5706 m .19378 .56749 L .19371 .56771 L F
.639 .302 .385 r
.53581 .66799 m .53395 .67048 L .53162 .66846 L F
.757 .497 .54 r
.53755 .66839 m .53395 .67048 L .53581 .66799 L F
.693 .258 .212 r
.53162 .66846 m .53395 .67048 L .53034 .67009 L F
.757 .497 .54 r
.53755 .66839 m .53736 .67088 L .53395 .67048 L F
.673 .231 .194 r
.53736 .67088 m .53673 .67243 L .53395 .67048 L F
.402 .093 .323 r
.53395 .67048 m .53116 .67283 L .53034 .67009 L F
.53395 .67048 m .53323 .67251 L .53116 .67283 L F
.625 .31 .417 r
.53395 .67048 m .53673 .67243 L .53323 .67251 L F
.667 .285 .312 r
.53267 .66963 m .53123 .67175 L .535 .67165 L F
.53267 .66963 m .535 .67165 L .53399 .67124 L F
.344 .231 .578 r
.53267 .66963 m .53399 .67124 L .53421 .66638 L F
.53376 .6669 m .53421 .66638 L .53424 .66571 L F
.53267 .66963 m .53421 .66638 L .53376 .6669 L F
.344 .794 .651 r
.53361 .66655 m .53454 .66598 L .53484 .66553 L F
.431 .302 .604 r
.53451 .66602 m .53658 .66841 L .53481 .66578 L F
.379 0 0 r
.53525 .66489 m .5347 .66578 L .53746 .66565 L F
.431 .302 .604 r
.5347 .66578 m .53481 .66578 L .53476 .6657 L F
.53451 .66602 m .53481 .66578 L .5347 .66578 L F
.53476 .6657 m .53658 .66841 L .53746 .66565 L F
.379 0 0 r
.5347 .66578 m .53459 .66595 L .53746 .66565 L F
.344 .794 .651 r
.53454 .66598 m .53456 .66597 L .53461 .6659 L F
.53454 .66598 m .53461 .6659 L .53484 .66553 L F
.53361 .66655 m .53484 .66553 L .53484 .66531 L F
.431 .302 .604 r
.53424 .66571 m .53451 .66602 L .53476 .6657 L F
.344 .794 .651 r
.53456 .66597 m .53459 .66595 L .53463 .66589 L F
.456 0 .059 r
.53746 .66565 m .53459 .66595 L .53424 .66571 L F
0 0 0 r
.53424 .66571 m .53484 .66561 L .53453 .66632 L F
.53484 .66561 m .53642 .66534 L .53485 .66616 L F
.53484 .66561 m .53485 .66616 L .53453 .66632 L F
.344 .794 .651 r
.53484 .66531 m .53484 .66553 L .53525 .66489 L F
.57 .575 .819 r
.5353 .66275 m .53597 .6643 L .53424 .66571 L F
.53597 .6643 m .53642 .66534 L .53484 .66561 L F
.344 .794 .651 r
.53464 .66584 m .5347 .66577 L .53525 .66489 L F
.57 .575 .819 r
.53597 .6643 m .53484 .66561 L .53424 .66571 L F
.344 .794 .651 r
.53456 .66597 m .53463 .66589 L .5347 .66577 L F
.53456 .66597 m .5347 .66577 L .53464 .66584 L F
.53361 .66655 m .53254 .66704 L .53424 .66614 L F
.431 .302 .604 r
.53424 .66571 m .53422 .66615 L .5345 .66601 L F
.344 .794 .651 r
.53455 .66598 m .53424 .66614 L .53456 .66597 L F
.53361 .66655 m .53424 .66614 L .53455 .66598 L F
.379 0 0 r
.53525 .66489 m .53746 .66565 L .53805 .66323 L F
.329 .043 .317 r
.54026 .66351 m .54005 .66529 L .53773 .66587 L F
.494 .331 .589 r
.54005 .66529 m .53755 .66839 L .53773 .66587 L F
.682 .398 .485 r
.53746 .66565 m .54016 .6639 L .53805 .66323 L F
.494 .331 .589 r
.54005 .66529 m .53983 .66784 L .53755 .66839 L F
.682 .398 .485 r
.53746 .66565 m .53996 .66614 L .54016 .6639 L F
.586 .41 .61 r
.54005 .66529 m .54227 .66757 L .53983 .66784 L F
.583 .315 .475 r
.53746 .66565 m .541 .66749 L .53996 .66614 L F
.53746 .66565 m .53658 .66841 L .541 .66749 L F
.635 .239 .277 r
.53948 .66649 m .53705 .66656 L .5375 .66476 L F
.733 .555 .651 r
.53761 .6647 m .53705 .66656 L .53948 .66649 L F
0 .156 .691 r
.5375 .66476 m .53642 .66534 L .5353 .66275 L F
.733 .555 .651 r
.53613 .66329 m .53667 .6652 L .53761 .6647 L F
.332 .782 .629 r
.53626 .66543 m .53666 .66521 L .5375 .66476 L F
.53466 .66625 m .53626 .66543 L .5375 .66476 L F
.431 .302 .604 r
.5345 .66601 m .53446 .66637 L .5347 .66624 L F
.332 .782 .629 r
.53453 .66632 m .53456 .66631 L .53466 .66625 L F
.53456 .66631 m .53626 .66543 L .53466 .66625 L F
.53626 .66543 m .53642 .66534 L .53666 .66521 L F
.431 .302 .604 r
.5347 .66624 m .53399 .67124 L .53658 .66841 L F
.53446 .66637 m .53399 .67124 L .5347 .66624 L F
.332 .782 .629 r
.53453 .66632 m .5375 .66476 L .53705 .66656 L F
.733 .555 .651 r
.53667 .6652 m .53705 .66656 L .53761 .6647 L F
.431 .302 .604 r
.53422 .66615 m .53399 .67124 L .5345 .66601 L F
.344 .231 .578 r
.53267 .66963 m .53402 .66626 L .53254 .66704 L F
.53402 .66626 m .53424 .66571 L .53254 .66704 L F
.344 .794 .651 r
.53456 .66597 m .53254 .66704 L .53459 .66595 L F
0 0 .399 r
.19434 .5706 m .19448 .56966 L .19378 .56749 L F
.814 1 .808 r
.19314 .57111 m .19448 .56966 L .19434 .5706 L F
.601 .902 .986 r
.34707 .64018 m .35145 .63971 L .3499 .63895 L F
.352 .78 .972 r
.35145 .63971 m .35321 .6394 L .3499 .63895 L F
.632 .325 .432 r
.49013 .67112 m .49248 .67117 L .49023 .66907 L F
.629 .485 .667 r
.49023 .66907 m .49273 .66896 L .4925 .66604 L F
.599 .332 .484 r
.49023 .66907 m .49248 .67117 L .49273 .66896 L F
.761 .274 .076 r
.55552 .67379 m .55785 .67481 L .55651 .67495 L F
.469 0 0 r
.55785 .67481 m .55846 .67535 L .55651 .67495 L F
.55785 .67481 m .56 .67667 L .55846 .67535 L F
.539 .231 .394 r
.5038 .69994 m .5024 .7029 L .49994 .7031 L F
.628 .41 .568 r
.50632 .7001 m .5024 .7029 L .5038 .69994 L F
.785 .283 0 r
.50129 .69206 m .50273 .69116 L .5037 .69147 L F
.691 .321 .341 r
.50449 .6938 m .50129 .69206 L .5037 .69147 L F
.50449 .6938 m .50309 .69458 L .50129 .69206 L F
.785 .283 0 r
.50129 .69206 m .50128 .69342 L .50273 .69116 L F
.48 .669 .946 r
.33787 .634 m .3411 .63525 L .34011 .63381 L F
.468 .56 .866 r
.3411 .63525 m .34118 .63281 L .34011 .63381 L F
.3411 .63525 m .34418 .6366 L .34118 .63281 L F
.358 .538 .896 r
.49414 .66157 m .49501 .66364 L .49589 .66161 L F
.576 .791 .981 r
.49589 .66161 m .49501 .66364 L .49759 .66286 L F
.465 0 0 r
.36867 .62484 m .37072 .6256 L .37219 .62559 L F
.078 .636 .791 r
.37273 .62537 m .37219 .62559 L .37072 .6256 L F
.37273 .62537 m .37457 .62558 L .37219 .62559 L F
.694 .724 .873 r
.42979 .58716 m .42747 .58837 L .42637 .58701 L F
.519 .614 .887 r
.79409 .51698 m .79516 .51891 L .79683 .51676 L F
.613 .755 .946 r
.79683 .51676 m .79516 .51891 L .79771 .51829 L F
.497 .362 .627 r
.43584 .59954 m .43796 .59904 L .43732 .59668 L F
.623 .432 .602 r
.43584 .59954 m .43833 .60158 L .43796 .59904 L F
.43584 .59954 m .43584 .60196 L .43833 .60158 L F
.934 .589 .157 r
.5516 .65075 m .55299 .6538 L .55286 .65163 L F
.998 .827 .488 r
.54137 .61243 m .54167 .61649 L .54212 .61374 L F
.039 0 0 r
.52302 .64447 m .52266 .64468 L .5205 .64487 L F
.705 .898 .529 r
.52471 .64166 m .52266 .64468 L .52302 .64447 L F
.882 .469 .043 r
.55527 .65758 m .55618 .65978 L .55721 .66056 L F
.655 .205 0 r
.55618 .65978 m .55817 .66252 L .55721 .66056 L F
.477 .809 1 r
.23034 .55694 m .23249 .55645 L .23277 .55718 L F
.046 .444 .875 r
.23424 .55704 m .23277 .55718 L .23249 .55645 L F
.23424 .55704 m .23548 .55843 L .23277 .55718 L F
0 0 .525 r
.19619 .57926 m .1962 .57909 L .19602 .57877 L F
.818 .793 .296 r
.19588 .58036 m .1962 .57909 L .19619 .57926 L F
.601 .613 .835 r
.46549 .61598 m .46367 .61847 L .46331 .61643 L F
.839 .663 .664 r
.59847 .61629 m .59988 .61955 L .60101 .6169 L F
.384 .178 .472 r
.47778 .65698 m .48006 .65389 L .47789 .65447 L F
.044 0 .206 r
.57707 .61227 m .57944 .61028 L .57972 .60842 L F
.519 .554 .831 r
.57913 .61251 m .57944 .61028 L .57707 .61227 L F
.44 .482 .806 r
.32109 .62618 m .32382 .62764 L .32229 .62408 L F
.766 .33 .215 r
.33787 .634 m .33324 .63202 L .33678 .63381 L F
.33787 .634 m .33686 .63457 L .33324 .63202 L F
.958 .7 .502 r
.33787 .634 m .33614 .63537 L .33686 .63457 L F
0 0 0 r
.33804 .63464 m .33787 .634 L .34011 .63381 L F
.516 .486 .762 r
.31774 .61084 m .31899 .60814 L .31691 .60863 L F
.31774 .61084 m .3198 .61038 L .31899 .60814 L F
.275 0 .224 r
.47074 .66293 m .47198 .66446 L .47328 .66225 L F
.47074 .66293 m .46997 .66529 L .47198 .66446 L F
.748 .939 .605 r
.72518 .48715 m .72361 .48931 L .72475 .4874 L F
.228 .195 .611 r
.72361 .48931 m .725 .49144 L .72475 .4874 L F
.423 .36 .682 r
.47562 .65752 m .47796 .65951 L .47778 .65698 L F
.47562 .65752 m .4763 .66038 L .47796 .65951 L F
.204 0 .316 r
.22551 .57622 m .22484 .57864 L .22332 .57926 L F
.454 .247 .508 r
.22504 .58107 m .22332 .57926 L .22484 .57864 L F
.22504 .58107 m .22304 .58164 L .22332 .57926 L F
.466 .215 .449 r
.50777 .73557 m .51003 .73512 L .51093 .73297 L F
0 0 .528 r
.55883 .68951 m .56016 .68891 L .55812 .68522 L F
.668 .327 .387 r
.50497 .67381 m .50226 .67386 L .50235 .67148 L F
.132 0 0 r
.58573 .63354 m .58138 .63659 L .58125 .63386 L F
.58573 .63354 m .58383 .63565 L .58138 .63659 L F
.109 0 0 r
.58573 .63354 m .58568 .63494 L .58383 .63565 L F
.354 .243 .587 r
.21743 .59627 m .21773 .59896 L .21608 .59967 L F
.057 0 .354 r
.21698 .60096 m .21608 .59967 L .21773 .59896 L F
.21698 .60096 m .21585 .60202 L .21608 .59967 L F
.541 .59 .852 r
.57694 .66575 m .57776 .66217 L .57614 .66363 L F
.57694 .66575 m .57927 .66532 L .57776 .66217 L F
.596 .283 .408 r
.46581 .68967 m .4667 .68625 L .46885 .68804 L F
.685 .936 .641 r
.56116 .69191 m .56101 .69173 L .55955 .69326 L F
.815 .674 .128 r
.56112 .68883 m .56101 .69173 L .56116 .69191 L F
.8 .626 .666 r
.55527 .65758 m .55639 .65451 L .55299 .6538 L F
.752 .588 .673 r
.46131 .61947 m .46213 .62236 L .4587 .62235 L F
0 0 0 r
.38121 .63783 m .38069 .63758 L .38304 .63731 L F
.38121 .63783 m .37888 .63834 L .38069 .63758 L F
.401 0 .115 r
.41698 .627 m .4174 .62609 L .41914 .62687 L F
.397 0 .141 r
.4174 .62609 m .41967 .62575 L .41914 .62687 L F
.75 .398 .387 r
.50949 .70024 m .5084 .7025 L .50659 .70016 L F
.664 .535 .697 r
.51141 .69825 m .51201 .70071 L .50949 .70024 L F
.714 .357 .37 r
.51162 .70241 m .50949 .70024 L .51201 .70071 L F
.51162 .70241 m .5084 .7025 L .50949 .70024 L F
0 0 .142 r
.5558 .69476 m .55733 .69114 L .55661 .69247 L F
.612 .213 .262 r
.43492 .62241 m .43356 .62441 L .4313 .62283 L F
.59 .188 .249 r
.43647 .62392 m .43492 .62241 L .4373 .62247 L F
.43647 .62392 m .43356 .62441 L .43492 .62241 L F
0 0 .164 r
.58165 .64508 m .58271 .64452 L .5826 .64187 L F
.13 0 .211 r
.5826 .64187 m .58434 .64308 L .58438 .64199 L F
.5826 .64187 m .58271 .64452 L .58434 .64308 L F
.91 .867 .785 r
.48705 .65431 m .48972 .65133 L .48734 .65026 L F
.418 .798 .992 r
.48734 .65026 m .48972 .65133 L .49188 .65074 L F
.526 .232 .411 r
.51401 .68024 m .51304 .68317 L .51063 .68332 L F
.639 .495 .67 r
.51623 .67777 m .51658 .68038 L .51401 .68024 L F
.647 .353 .459 r
.51597 .6826 m .51401 .68024 L .51658 .68038 L F
.51597 .6826 m .51304 .68317 L .51401 .68024 L F
.708 .212 0 r
.73377 .4833 m .73648 .48637 L .73561 .48361 L F
.73377 .4833 m .73561 .4858 L .73648 .48637 L F
.713 .609 .74 r
.73561 .48361 m .73648 .48637 L .73909 .48356 L F
0 .26 .674 r
.73849 .48735 m .73648 .48637 L .73561 .4858 L F
.73849 .48735 m .74007 .48835 L .73648 .48637 L F
.5 .84 .997 r
.58396 .62227 m .58808 .62225 L .58553 .62271 L F
.602 .793 .972 r
.78481 .50313 m .78336 .50495 L .78219 .50324 L F
.78481 .50313 m .78529 .50459 L .78336 .50495 L F
.472 .517 .823 r
.44965 .59764 m .45271 .59899 L .4501 .59925 L F
.243 .022 .366 r
.4519 .6004 m .4501 .59925 L .45271 .59899 L F
.886 .891 .467 r
.55087 .65949 m .55056 .65945 L .54926 .66198 L F
.268 0 0 r
.36224 .58268 m .36398 .58297 L .36565 .58224 L F
.448 0 0 r
.36398 .58297 m .36792 .58201 L .36565 .58224 L F
.647 .774 .941 r
.64588 .43106 m .64954 .43179 L .64828 .43044 L F
.64954 .43179 m .64588 .43106 L .64828 .43044 L F
.534 .765 .982 r
.64828 .43044 m .64954 .43179 L .65118 .4301 L F
.64828 .43044 m .64954 .43179 L .65118 .4301 L F
.812 .394 .251 r
.19602 .57877 m .1962 .57909 L .1956 .57893 L F
.607 .157 .157 r
.52866 .66117 m .52949 .6602 L .53352 .65959 L F
.53059 .66054 m .53352 .65959 L .5304 .6605 L F
.526 .916 .803 r
.53352 .65959 m .53389 .65879 L .5304 .6605 L F
.521 .144 .267 r
.5304 .6605 m .53389 .65879 L .53318 .66062 L F
0 0 0 r
.53361 .65893 m .53266 .65967 L .53225 .66057 L F
.521 .144 .267 r
.53207 .66057 m .53318 .66062 L .53212 .66057 L F
.5304 .6605 m .53207 .66057 L .53033 .66049 L F
.53207 .66057 m .53212 .66057 L .53033 .66049 L F
.5304 .6605 m .53033 .66049 L .53013 .66048 L F
.607 .157 .157 r
.52866 .66117 m .53059 .66054 L .5304 .6605 L F
.659 .495 .651 r
.53318 .66062 m .53021 .66372 L .53013 .66048 L F
0 0 0 r
.5325 .66056 m .53225 .66057 L .53169 .66175 L F
.53361 .65893 m .53225 .66057 L .5325 .66056 L F
.305 .348 .742 r
.57614 .66363 m .57776 .66217 L .57526 .66016 L F
.462 .326 .61 r
.31663 .60504 m .31844 .60452 L .31829 .60213 L F
.522 .436 .7 r
.31691 .60863 m .31844 .60452 L .31663 .60504 L F
.816 .457 .378 r
.58125 .63386 m .58138 .63659 L .57946 .63556 L F
.327 .763 .968 r
.39515 .58212 m .39749 .58195 L .39889 .58257 L F
.498 .841 .997 r
.39749 .58195 m .40113 .58211 L .39889 .58257 L F
0 0 .47 r
.7347 .48435 m .73561 .4858 L .73377 .4833 L F
.7347 .48435 m .73377 .4833 L .73218 .48466 L F
.657 .545 .716 r
.73377 .4833 m .73561 .48361 L .736 .48087 L F
.357 .742 .987 r
.32542 .64539 m .32559 .64426 L .32399 .6439 L F
.32542 .64539 m .32712 .64514 L .32559 .64426 L F
.32542 .64539 m .32559 .64426 L .32399 .6439 L F
.32542 .64539 m .32712 .64514 L .32559 .64426 L F
.631 .648 .848 r
.53531 .61805 m .54046 .61752 L .53741 .61582 L F
.53531 .61805 m .53927 .61947 L .54046 .61752 L F
.64 .515 .695 r
.53927 .61947 m .54167 .61649 L .54046 .61752 L F
.535 .291 .492 r
.53075 .6892 m .53046 .6915 L .52815 .69182 L F
.446 .204 .453 r
.533 .68866 m .53046 .6915 L .53075 .6892 L F
.485 .901 .847 r
.76775 .49184 m .76548 .49293 L .76427 .49299 L F
.957 .706 .515 r
.54867 .64544 m .54856 .64714 L .5505 .64801 L F
.877 .46 .031 r
.54987 .64835 m .5505 .64801 L .54856 .64714 L F
.54987 .64835 m .5516 .65075 L .5505 .64801 L F
.22 0 .135 r
.41124 .62784 m .40821 .63027 L .4089 .62837 L F
.299 .225 .603 r
.44973 .68876 m .45157 .69103 L .45102 .68852 L F
.44973 .68876 m .4496 .69226 L .45157 .69103 L F
0 0 0 r
.46455 .70369 m .46614 .7009 L .4631 .70308 L F
.46455 .70369 m .4654 .70222 L .46596 .70121 L F
.852 .518 .42 r
.4631 .70308 m .4654 .70222 L .46455 .70369 L F
.4631 .70308 m .46447 .70392 L .4654 .70222 L F
.46447 .70392 m .46742 .70574 L .4654 .70222 L F
0 0 0 r
.46596 .70121 m .4654 .70222 L .46614 .7009 L F
.458 .171 .388 r
.40375 .61892 m .40594 .61855 L .40632 .61674 L F
.486 .195 .397 r
.40632 .61674 m .40815 .61808 L .40771 .61492 L F
.40632 .61674 m .40594 .61855 L .40815 .61808 L F
.522 .631 .9 r
.73822 .5068 m .7395 .50476 L .73747 .50505 L F
.73822 .5068 m .74064 .50648 L .7395 .50476 L F
.357 0 0 r
.5276 .65842 m .52677 .65736 L .52621 .66045 L F
.5276 .65842 m .52998 .65739 L .52677 .65736 L F
.933 .743 .623 r
.59757 .60198 m .59671 .60479 L .59861 .60493 L F
.935 .846 .732 r
.5959 .60711 m .59861 .60493 L .59671 .60479 L F
.5959 .60711 m .59726 .60798 L .59861 .60493 L F
.757 .714 .812 r
.4307 .59407 m .43469 .59579 L .43277 .59381 L F
.4307 .59407 m .43229 .59683 L .43469 .59579 L F
.514 .764 .987 r
.43469 .59579 m .4351 .59374 L .43277 .59381 L F
.43469 .59579 m .43807 .59551 L .4351 .59374 L F
.837 .903 .884 r
.81072 .50627 m .80715 .50779 L .80967 .50545 L F
.542 .84 .999 r
.81072 .50627 m .80967 .50545 L .81225 .5059 L F
.039 .25 .749 r
.45924 .71002 m .46041 .71174 L .45913 .70861 L F
.791 .53 .543 r
.47706 .72961 m .47514 .73194 L .47529 .72931 L F
.47706 .72961 m .47773 .73231 L .47514 .73194 L F
.463 .811 .998 r
.47529 .72931 m .47967 .72967 L .47706 .72961 L F
.826 .551 .523 r
.47853 .73184 m .47773 .73231 L .47706 .72961 L F
.843 .723 .732 r
.47967 .72967 m .47853 .73184 L .47706 .72961 L F
.4 .275 .593 r
.54945 .66578 m .55042 .66281 L .54918 .66326 L F
0 0 0 r
.72643 .48492 m .72628 .48503 L .7276 .48469 L F
.275 .723 .96 r
.54108 .64209 m .53718 .64132 L .53867 .64258 L F
.293 .35 .75 r
.53867 .64258 m .54125 .64471 L .54108 .64209 L F
.756 .8 .316 r
.55535 .67064 m .55615 .66841 L .55614 .66878 L F
.55535 .67064 m .55615 .66841 L .55614 .66878 L F
0 0 .451 r
.73358 .50048 m .73442 .50417 L .73418 .50225 L F
.402 .586 .916 r
.73442 .50417 m .73602 .50259 L .73418 .50225 L F
.73442 .50417 m .73747 .50505 L .73602 .50259 L F
.683 .416 .512 r
.53992 .60182 m .54294 .59938 L .542 .60049 L F
.205 0 .316 r
.22692 .57733 m .22551 .57622 L .22699 .57491 L F
.22692 .57733 m .22484 .57864 L .22551 .57622 L F
0 0 0 r
.77325 .48971 m .77561 .48797 L .77635 .48697 L F
.826 .547 .516 r
.77561 .48797 m .77831 .48563 L .77635 .48697 L F
.419 .139 .379 r
.49237 .63974 m .49454 .63912 L .49533 .63643 L F
.442 .089 .269 r
.49454 .63912 m .49783 .63654 L .49533 .63643 L F
.604 .585 .805 r
.53838 .66293 m .54183 .661 L .54094 .65892 L F
.42 .459 .795 r
.79698 .48723 m .79882 .48489 L .79672 .48599 L F
.79698 .48723 m .80003 .48851 L .79882 .48489 L F
0 0 .496 r
.55587 .69743 m .55636 .6977 L .5558 .69476 L F
.675 .491 .629 r
.53881 .65694 m .54167 .6576 L .54087 .6543 L F
.462 .356 .649 r
.54087 .6543 m .54167 .6576 L .54372 .65648 L F
.605 .196 .241 r
.57902 .59679 m .57572 .59834 L .57709 .59616 L F
.688 .47 .585 r
.51894 .69159 m .52168 .69177 L .5215 .68943 L F
.772 .62 .691 r
.34418 .6366 m .34741 .63707 L .3459 .63618 L F
.34418 .6366 m .34501 .63958 L .34741 .63707 L F
.374 0 0 r
.34501 .63958 m .34707 .64018 L .34741 .63707 L F
0 .221 .734 r
.34741 .63707 m .3485 .63717 L .3459 .63618 L F
.34741 .63707 m .3499 .63895 L .3485 .63717 L F
.601 .902 .986 r
.34707 .64018 m .3499 .63895 L .34741 .63707 L F
.605 .852 .991 r
.48432 .67187 m .48779 .67193 L .48651 .67106 L F
.007 0 .4 r
.48895 .67495 m .49013 .67112 L .48779 .67193 L F
.469 .604 .903 r
.49133 .66129 m .49226 .65897 L .49046 .6593 L F
.468 0 0 r
.36792 .58201 m .36998 .58288 L .37155 .58227 L F
.342 0 0 r
.37155 .58227 m .37337 .58278 L .37397 .58205 L F
.37155 .58227 m .36998 .58288 L .37337 .58278 L F
.786 .511 .521 r
.46153 .61259 m .46318 .61067 L .45858 .6104 L F
.622 .407 .569 r
.46153 .61259 m .46402 .61085 L .46318 .61067 L F
.44 .832 .983 r
.40113 .58211 m .40335 .58165 L .40474 .58217 L F
.305 .684 .977 r
.4055 .58122 m .40474 .58217 L .40335 .58165 L F
.4055 .58122 m .40694 .58231 L .40474 .58217 L F
.149 .217 .679 r
.45004 .69475 m .45079 .69871 L .45199 .69693 L F
.283 .402 .807 r
.45079 .69871 m .45337 .70039 L .45199 .69693 L F
0 .289 .651 r
.21 .54572 m .20961 .54557 L .20809 .54525 L F
.21 .54572 m .21174 .54654 L .20961 .54557 L F
.44 0 0 r
.46579 .68992 m .46409 .6888 L .46374 .69106 L F
.46579 .68992 m .46678 .69016 L .46409 .6888 L F
0 0 0 r
.47121 .69541 m .46869 .69782 L .47009 .69595 L F
.47121 .69541 m .47028 .69725 L .46869 .69782 L F
.635 .201 .199 r
.47381 .69713 m .47028 .69725 L .47121 .69541 L F
.561 .516 .763 r
.78128 .4998 m .77974 .50371 L .77858 .50045 L F
.78128 .4998 m .78219 .50324 L .77974 .50371 L F
.717 .479 .565 r
.46213 .62236 m .45861 .62482 L .4587 .62235 L F
.46213 .62236 m .46221 .62393 L .45861 .62482 L F
.603 .374 .542 r
.46451 .62232 m .46221 .62393 L .46213 .62236 L F
.7 .425 .504 r
.50529 .63362 m .50861 .63363 L .50631 .63109 L F
.604 .041 0 r
.4776 .69953 m .47381 .69713 L .47837 .69775 L F
.825 .609 .611 r
.47874 .69763 m .4776 .69953 L .47837 .69775 L F
.764 .49 .519 r
.4767 .69411 m .47973 .69438 L .47837 .69775 L F
.672 .64 .81 r
.47874 .69763 m .47837 .69775 L .47973 .69438 L F
.653 .903 .578 r
.45494 .6033 m .45633 .6013 L .45723 .60214 L F
.087 0 .232 r
.51093 .73297 m .51003 .73512 L .512 .73187 L F
.407 .276 .588 r
.31829 .60213 m .32009 .59898 L .31802 .59965 L F
.497 .772 .993 r
.47298 .71575 m .47364 .71409 L .47179 .71427 L F
.591 .433 .636 r
.47532 .71227 m .47539 .71557 L .47298 .71575 L F
.497 .772 .993 r
.47298 .71575 m .47539 .71557 L .47364 .71409 L F
.97 .721 .504 r
.59706 .61058 m .59689 .61297 L .59831 .61377 L F
.94 .667 .495 r
.59689 .61551 m .59831 .61377 L .59689 .61297 L F
.59689 .61551 m .59847 .61629 L .59831 .61377 L F
.321 .254 .624 r
.4496 .69226 m .4515 .69433 L .45157 .69103 L F
.4496 .69226 m .45004 .69475 L .4515 .69433 L F
.354 .333 .696 r
.51345 .69983 m .51141 .69825 L .51143 .69705 L F
.51345 .69983 m .51201 .70071 L .51141 .69825 L F
.565 .004 0 r
.50055 .64861 m .50354 .65099 L .50421 .65116 L F
.964 .901 .533 r
.50421 .65116 m .5028 .65297 L .50354 .65099 L F
0 .243 .755 r
.50588 .64953 m .50663 .6508 L .50603 .64931 L F
.62 .959 .855 r
.50421 .65116 m .50603 .64931 L .50663 .6508 L F
.50421 .65116 m .50354 .65099 L .50603 .64931 L F
.964 .901 .533 r
.50421 .65116 m .5028 .65297 L .50354 .65099 L F
.403 0 .156 r
.54427 .7116 m .54056 .71426 L .54212 .71312 L F
.19 0 0 r
.41342 .61466 m .411 .61419 L .4102 .6143 L F
.463 .811 .998 r
.47529 .72931 m .47777 .72887 L .47967 .72967 L F
.883 .651 .583 r
.47777 .72887 m .48015 .73157 L .47967 .72967 L F
.727 .695 .82 r
.49455 .65166 m .49586 .65444 L .49816 .65206 L F
.614 .33 .463 r
.49588 .65611 m .4982 .65657 L .49586 .65444 L F
.6 .131 .113 r
.7466 .49406 m .74982 .49304 L .74634 .49205 L F
.7466 .49406 m .75034 .49427 L .74982 .49304 L F
.352 .288 .645 r
.51817 .67937 m .51623 .67777 L .51867 .67726 L F
.51817 .67937 m .51658 .68038 L .51623 .67777 L F
.261 0 0 r
.3382 .58704 m .3404 .58667 L .34202 .58516 L F
.416 0 .04 r
.3404 .58667 m .34431 .58499 L .34202 .58516 L F
.84 .505 .421 r
.48575 .69669 m .48789 .69763 L .48702 .69472 L F
.946 .714 .554 r
.59975 .62224 m .59931 .62465 L .601 .62535 L F
.938 .623 .417 r
.59931 .62465 m .59981 .62716 L .601 .62535 L F
.797 .67 .724 r
.59975 .62224 m .601 .62535 L .60114 .62284 L F
.767 .368 .298 r
.601 .62535 m .59981 .62716 L .60309 .62765 L F
.522 .436 .7 r
.31691 .60863 m .31899 .60814 L .31844 .60452 L F
.7 .618 .762 r
.43785 .60779 m .44066 .60841 L .43933 .60727 L F
.625 .81 .971 r
.43933 .60727 m .44066 .60841 L .44299 .60769 L F
.304 0 0 r
.37189 .596 m .37 .59761 L .36759 .598 L F
.138 0 0 r
.37393 .59577 m .37 .59761 L .37189 .596 L F
0 0 0 r
.60295 .66518 m .60155 .6673 L .60391 .66585 L F
.60155 .6673 m .60075 .66851 L .60217 .66731 L F
.60155 .6673 m .60217 .66731 L .60391 .66585 L F
.60295 .66518 m .60108 .66851 L .60075 .66851 L F
0 .543 .73 r
.60075 .66851 m .60108 .66851 L .59842 .66827 L F
.455 0 0 r
.59842 .66827 m .60108 .66851 L .5993 .66967 L F
.954 .691 .497 r
.5993 .66967 m .60108 .66851 L .59932 .66723 L F
.59927 .66723 m .59932 .66723 L .59926 .66719 L F
.5993 .66967 m .59932 .66723 L .59927 .66723 L F
.793 .963 .917 r
.60506 .66343 m .60391 .66585 L .60687 .66392 L F
.60506 .66343 m .60295 .66518 L .60391 .66585 L F
.883 .789 .753 r
.60703 .62772 m .60506 .63093 L .6076 .63093 L F
.829 .643 .652 r
.60439 .63331 m .6076 .63093 L .60506 .63093 L F
.60439 .63331 m .60666 .63405 L .6076 .63093 L F
.284 .604 .952 r
.47263 .7084 m .47337 .70956 L .47173 .70941 L F
.918 .876 .78 r
.62926 .43708 m .62614 .43901 L .62814 .43597 L F
.62926 .43708 m .62726 .44012 L .62614 .43901 L F
.882 .907 .841 r
.63165 .43412 m .62926 .43708 L .62814 .43597 L F
.719 .487 .573 r
.62722 .45717 m .62501 .45964 L .62497 .45731 L F
.62722 .45717 m .62921 .45893 L .62501 .45964 L F
.666 .461 .597 r
.63085 .4574 m .62921 .45893 L .62722 .45717 L F
.484 .107 .25 r
.51155 .67668 m .51398 .67651 L .5157 .67363 L F
.431 .048 .21 r
.51398 .67651 m .51743 .67402 L .5157 .67363 L F
.203 0 0 r
.37799 .62463 m .37457 .62558 L .37687 .62528 L F
.451 0 0 r
.37799 .62463 m .37687 .62528 L .3803 .62491 L F
.663 .617 .793 r
.77608 .50101 m .77291 .49693 L .77495 .49753 L F
.573 .536 .775 r
.77737 .49703 m .77608 .50101 L .77495 .49753 L F
.77737 .49703 m .77858 .50045 L .77608 .50101 L F
.645 .576 .762 r
.43584 .60196 m .43699 .60531 L .43938 .60494 L F
.597 .366 .536 r
.43699 .60531 m .43933 .60727 L .43938 .60494 L F
.368 .375 .735 r
.43785 .60779 m .43933 .60727 L .43699 .60531 L F
.597 .366 .536 r
.43699 .60531 m .43933 .60727 L .43938 .60494 L F
.573 .577 .819 r
.51464 .72924 m .51605 .73281 L .51828 .7323 L F
.825 .609 .611 r
.47874 .69763 m .47899 .70055 L .4776 .69953 L F
.672 .64 .81 r
.47874 .69763 m .47973 .69438 L .48126 .69738 L F
.669 .493 .638 r
.48126 .69738 m .47899 .70055 L .47874 .69763 L F
.921 .532 .231 r
.53329 .68094 m .53384 .68342 L .53273 .68036 L F
.646 .356 .465 r
.53329 .68094 m .53516 .68458 L .53384 .68342 L F
.683 .917 .591 r
.58438 .64199 m .58703 .63825 L .58578 .63877 L F
.58438 .64199 m .58534 .64006 L .58703 .63825 L F
0 0 0 r
.58438 .64199 m .58434 .64308 L .58534 .64006 L F
.713 .597 .725 r
.736 .48087 m .73561 .48361 L .73909 .48356 L F
.576 .589 .829 r
.74541 .51252 m .74671 .50867 L .74433 .50905 L F
.74541 .51252 m .74789 .51201 L .74671 .50867 L F
0 0 0 r
.5323 .65654 m .52998 .65739 L .5276 .65842 L F
.666 .512 .667 r
.54994 .68295 m .54974 .6854 L .5532 .68315 L F
.711 .534 .649 r
.54226 .66253 m .54005 .66529 L .54026 .66351 L F
.672 .611 .778 r
.44424 .61079 m .4452 .60709 L .44299 .60769 L F
.44424 .61079 m .44679 .61084 L .4452 .60709 L F
.697 .396 .462 r
.4443 .61281 m .44658 .61313 L .44424 .61079 L F
.661 .403 .519 r
.44424 .61079 m .44658 .61313 L .44679 .61084 L F
.853 .656 .636 r
.60934 .63931 m .61092 .64262 L .61125 .64011 L F
.67 .337 .402 r
.56998 .62775 m .57352 .62714 L .57087 .62619 L F
.565 .09 .086 r
.44708 .62203 m .44555 .62349 L .4432 .62218 L F
.663 .195 .131 r
.44708 .62203 m .44783 .62415 L .44555 .62349 L F
.44708 .62203 m .44924 .62294 L .44783 .62415 L F
0 .101 .63 r
.57301 .6399 m .57437 .64226 L .57361 .63979 L F
.678 .578 .736 r
.41279 .59117 m .41321 .59357 L .41608 .59263 L F
.53 .773 .987 r
.43432 .587 m .43314 .58878 L .43184 .58721 L F
.43432 .587 m .43553 .5883 L .43314 .58878 L F
.379 0 .188 r
.32959 .59057 m .33159 .59027 L .33349 .58756 L F
.432 .055 .222 r
.33349 .58756 m .33441 .58973 L .33598 .58751 L F
.33349 .58756 m .33159 .59027 L .33441 .58973 L F
.86 .667 .64 r
.1956 .57893 m .1962 .57909 L .19588 .58036 L F
.131 .302 .77 r
.64007 .43581 m .63765 .43408 L .64087 .43405 L F
.815 .558 .551 r
.60604 .63888 m .60915 .63704 L .60586 .63653 L F
.60604 .63888 m .60934 .63931 L .60915 .63704 L F
.099 0 0 r
.23345 .56136 m .22945 .56314 L .2313 .56172 L F
.374 .089 .345 r
.46006 .67168 m .46187 .67126 L .46281 .66879 L F
.356 .071 .336 r
.46281 .66879 m .46446 .67048 L .46491 .66814 L F
.46281 .66879 m .46187 .67126 L .46446 .67048 L F
.218 0 0 r
.38647 .63636 m .38516 .63708 L .38304 .63731 L F
.077 0 0 r
.38863 .6362 m .38516 .63708 L .38647 .63636 L F
.015 .562 .833 r
.36232 .62382 m .35891 .62306 L .36129 .62325 L F
.398 .608 .933 r
.36361 .62242 m .36232 .62382 L .36129 .62325 L F
.36361 .62242 m .36504 .62439 L .36232 .62382 L F
0 0 .373 r
.56924 .64996 m .56998 .65191 L .56889 .64869 L F
.693 .365 .416 r
.59024 .59291 m .5935 .59303 L .59329 .59171 L F
.58 .252 .378 r
.63674 .45761 m .63938 .45755 L .6392 .45918 L F
.672 .317 .364 r
.63488 .45747 m .63674 .45761 L .6368 .45925 L F
.583 .248 .366 r
.63674 .45761 m .6392 .45918 L .6368 .45925 L F
.609 .864 .991 r
.5958 .66922 m .59842 .66827 L .59682 .66758 L F
.505 .731 .975 r
.5958 .66922 m .59682 .66758 L .59473 .66809 L F
.622 .458 .639 r
.47711 .71282 m .47532 .71227 L .47767 .71177 L F
.47711 .71282 m .47539 .71557 L .47532 .71227 L F
0 0 0 r
.19144 .55881 m .19262 .5579 L .19056 .56002 L F
.204 .679 .936 r
.19249 .54366 m .19429 .54438 L .19052 .54354 L F
.312 .754 .964 r
.19445 .54366 m .19429 .54438 L .19249 .54366 L F
.19445 .54366 m .19667 .54436 L .19429 .54438 L F
.663 .409 .526 r
.63488 .45747 m .63085 .45984 L .63085 .4574 L F
.63488 .45747 m .63333 .46003 L .63085 .45984 L F
.672 .317 .364 r
.63488 .45747 m .6368 .45925 L .63333 .46003 L F
.759 .593 .673 r
.78392 .49588 m .78438 .49793 L .78292 .49837 L F
.491 .415 .698 r
.78409 .49475 m .78659 .49415 L .78392 .49588 L F
.342 .32 .689 r
.78678 .49641 m .78392 .49588 L .78659 .49415 L F
.78678 .49641 m .78438 .49793 L .78392 .49588 L F
.58 .361 .548 r
.50279 .63632 m .50042 .6341 L .50034 .63651 L F
.50279 .63632 m .50287 .63379 L .50042 .6341 L F
.263 .716 .956 r
.20056 .56226 m .20233 .56258 L .20217 .56299 L F
.671 .853 .449 r
.20191 .56367 m .20217 .56299 L .20414 .56011 L F
.106 0 0 r
.20217 .56299 m .20337 .56277 L .2054 .56019 L F
.263 .716 .956 r
.20233 .56258 m .20337 .56277 L .20217 .56299 L F
.671 .853 .449 r
.2014 .56449 m .20217 .56299 L .20191 .56367 L F
.746 .336 .272 r
.2014 .56449 m .20402 .56605 L .20217 .56299 L F
.2014 .56449 m .2021 .56615 L .20402 .56605 L F
.2014 .56449 m .19969 .5661 L .2021 .56615 L F
.319 .529 .901 r
.22325 .54882 m .22271 .55058 L .22132 .54889 L F
.22325 .54882 m .22545 .5516 L .22271 .55058 L F
.557 .227 .365 r
.40028 .62152 m .40375 .61892 L .40081 .62006 L F
.765 .627 .707 r
.48188 .70028 m .47899 .70055 L .48126 .69738 L F
.661 .475 .623 r
.4812 .70238 m .47899 .70055 L .48188 .70028 L F
.61 .526 .735 r
.48428 .69878 m .48188 .70028 L .48126 .69738 L F
.457 .18 .404 r
.4829 .7019 m .48188 .70028 L .48428 .69878 L F
.4829 .7019 m .4812 .70238 L .48188 .70028 L F
.707 .384 .428 r
.48545 .69791 m .48363 .69802 L .48575 .69669 L F
.48545 .69791 m .48428 .69878 L .48363 .69802 L F
.48545 .69791 m .48674 .70004 L .48428 .69878 L F
.786 .374 .27 r
.5257 .72377 m .52808 .72621 L .52883 .72419 L F
.623 .157 0 r
.5656 .64285 m .5664 .64414 L .56495 .64153 L F
.5656 .64285 m .56733 .64524 L .5664 .64414 L F
.108 .013 .454 r
.43807 .59551 m .43732 .59668 L .43906 .59517 L F
.498 .477 .765 r
.43796 .59904 m .43906 .59517 L .43732 .59668 L F
.619 .631 .841 r
.80525 .51215 m .80384 .51569 L .80199 .51489 L F
.80525 .51215 m .80652 .51539 L .80384 .51569 L F
0 .016 .519 r
.19378 .56749 m .19376 .56603 L .19355 .56614 L F
.19378 .56749 m .19448 .56966 L .19471 .56899 L F
.445 0 .071 r
.54607 .67781 m .54889 .67772 L .54829 .67875 L F
.369 .822 .934 r
.54829 .67875 m .54674 .67599 L .54607 .67781 L F
.686 .78 .922 r
.59298 .66975 m .59473 .66809 L .59089 .66766 L F
.198 .681 .93 r
.26891 .88599 m .27122 .88615 L .26946 .88542 L F
.26891 .88599 m .27122 .88615 L .26946 .88542 L F
.971 .846 .661 r
.56046 .67992 m .55827 .68211 L .55922 .67887 L F
.56046 .67992 m .55985 .68179 L .55964 .68073 L F
0 .136 .665 r
.55922 .67887 m .56079 .68332 L .56046 .67992 L F
.55933 .67919 m .56127 .68132 L .56079 .68332 L F
.55922 .67887 m .55928 .67895 L .55933 .67919 L F
.55928 .67895 m .56127 .68132 L .55933 .67919 L F
.971 .846 .661 r
.55964 .68073 m .55937 .68327 L .55827 .68211 L F
.55985 .68179 m .55937 .68327 L .55964 .68073 L F
0 0 .246 r
.5798 .63498 m .57821 .63473 L .57946 .63556 L F
.5798 .63498 m .58025 .63273 L .57821 .63473 L F
.201 0 .276 r
.4763 .66038 m .47577 .6621 L .47796 .65951 L F
.557 .227 .365 r
.40028 .62152 m .40268 .62159 L .40375 .61892 L F
.421 .091 .299 r
.40268 .62159 m .40594 .61855 L .40375 .61892 L F
.101 0 0 r
.53805 .66323 m .54016 .6639 L .54183 .661 L F
.504 .345 .599 r
.51345 .69983 m .51162 .70241 L .51201 .70071 L F
0 .234 .751 r
.80741 .48815 m .80739 .48971 L .80529 .48637 L F
.88 .914 .512 r
.80632 .49112 m .80739 .48971 L .80741 .48815 L F
.943 .845 .717 r
.62726 .44012 m .62685 .44239 L .62495 .44083 L F
.907 .954 .816 r
.62685 .44239 m .62356 .44424 L .62495 .44083 L F
.882 .907 .841 r
.63165 .43412 m .62814 .43597 L .63051 .4329 L F
.775 .879 .922 r
.63428 .43201 m .63165 .43412 L .63051 .4329 L F
.327 .51 .884 r
.46041 .71174 m .46053 .70897 L .45913 .70861 L F
.46041 .71174 m .462 .71169 L .46053 .70897 L F
.387 .401 .752 r
.65242 .449 m .65558 .45082 L .65364 .45134 L F
.544 0 0 r
.65262 .44968 m .65558 .45082 L .65242 .449 L F
0 .218 .665 r
.5583 .63337 m .55407 .63044 L .55671 .6322 L F
.664 .83 .963 r
.35896 .6417 m .36072 .64288 L .36267 .64164 L F
.775 .399 .343 r
.73944 .49068 m .74097 .48883 L .74007 .48835 L F
.73944 .49068 m .7428 .49135 L .74097 .48883 L F
.033 0 0 r
.38238 .59331 m .37828 .59473 L .38037 .59435 L F
.83 .488 .409 r
.4953 .68133 m .49499 .68293 L .49331 .68181 L F
.564 .61 .857 r
.5449 .64683 m .54647 .64898 L .54856 .64714 L F
0 0 .081 r
.54647 .64898 m .54561 .65085 L .54856 .64714 L F
.665 .792 .943 r
.35321 .6394 m .35689 .63985 L .35537 .63928 L F
0 .112 .629 r
.35689 .63985 m .35768 .64022 L .35537 .63928 L F
.35689 .63985 m .35896 .6417 L .35768 .64022 L F
.492 .472 .763 r
.22121 .58927 m .21938 .5911 L .21845 .58759 L F
.503 .363 .623 r
.2215 .59267 m .21938 .5911 L .22121 .58927 L F
.2215 .59267 m .21959 .59328 L .21938 .5911 L F
.351 .157 .471 r
.51026 .66582 m .50809 .66927 L .51007 .66832 L F
.649 .235 .245 r
.46891 .67634 m .47006 .67459 L .46661 .67471 L F
.327 0 0 r
.47134 .67542 m .47006 .67459 L .46891 .67634 L F
.731 .971 .93 r
.64151 .42747 m .64246 .42788 L .64013 .42912 L F
.507 .825 1 r
.64355 .42639 m .64246 .42788 L .64151 .42747 L F
.64355 .42639 m .64501 .42735 L .64246 .42788 L F
.849 .995 .833 r
.60898 .65884 m .61135 .65785 L .61026 .65657 L F
.60898 .65884 m .60906 .66021 L .61135 .65785 L F
.927 .92 .786 r
.61026 .65657 m .61135 .65785 L .61331 .65423 L F
.494 .329 .586 r
.35273 .6077 m .35271 .61081 L .35056 .61092 L F
.426 .253 .541 r
.55121 .70096 m .55173 .70386 L .55309 .70239 L F
.703 .833 .945 r
.79456 .47575 m .79112 .47584 L .79358 .47458 L F
.266 .689 .966 r
.79358 .47458 m .7967 .47553 L .79456 .47575 L F
.217 .736 .86 r
.39855 .59162 m .39647 .59152 L .39421 .59178 L F
.233 0 0 r
.39999 .5902 m .39647 .59152 L .39855 .59162 L F
.828 .991 .865 r
.45847 .60796 m .4612 .60553 L .45922 .6058 L F
.659 .971 .892 r
.45922 .6058 m .4612 .60553 L .46283 .60427 L F
.32 .777 .95 r
.37743 .5822 m .37397 .58205 L .37578 .58175 L F
.1 .645 .836 r
.37809 .5819 m .37743 .5822 L .37578 .58175 L F
.37809 .5819 m .37951 .58222 L .37743 .5822 L F
.593 .368 .544 r
.52132 .6746 m .52114 .67719 L .51867 .67726 L F
.571 .378 .581 r
.52369 .67402 m .52114 .67719 L .52132 .6746 L F
.823 .669 .692 r
.78081 .49771 m .77858 .50045 L .77737 .49703 L F
.598 .347 .508 r
.78128 .4998 m .78081 .49771 L .78292 .49837 L F
.78128 .4998 m .77858 .50045 L .78081 .49771 L F
.2 .654 .945 r
.41916 .59343 m .41771 .59258 L .41608 .59263 L F
.258 .69 .963 r
.41916 .59343 m .42105 .5934 L .41771 .59258 L F
.41916 .59343 m .42105 .5934 L .41771 .59258 L F
.116 .323 .794 r
.48399 .70912 m .48614 .7107 L .48418 .70631 L F
.198 .098 .507 r
.57944 .61028 m .58095 .60678 L .57972 .60842 L F
.825 .613 .615 r
.59335 .59579 m .59534 .59357 L .5935 .59303 L F
.59335 .59579 m .59526 .59618 L .59534 .59357 L F
.324 0 0 r
.22855 .55477 m .23249 .55645 L .23034 .55694 L F
.401 .381 .723 r
.79777 .49269 m .79905 .49517 L .79858 .49083 L F
.746 .371 .341 r
.54234 .62312 m .53939 .624 L .53958 .62173 L F
.54234 .62312 m .54293 .62467 L .53939 .624 L F
.688 .719 .873 r
.75739 .51261 m .76102 .51337 L .75977 .51168 L F
.718 .718 .85 r
.75977 .51168 m .76102 .51337 L .76325 .51227 L F
.712 .732 .867 r
.62174 .45059 m .6241 .45159 L .62005 .45126 L F
.899 .739 .675 r
.6241 .45159 m .62154 .45307 L .62005 .45126 L F
.6241 .45159 m .6235 .45418 L .62154 .45307 L F
.56 .891 .637 r
.57896 .6231 m .58083 .62128 L .58188 .6206 L F
.72 .218 .038 r
.58083 .62128 m .58396 .62227 L .58188 .6206 L F
.819 .34 0 r
.53954 .63615 m .54309 .6399 L .54169 .63702 L F
.969 .934 .667 r
.60898 .65884 m .60852 .66238 L .60906 .66021 L F
.928 .949 .612 r
.19435 .56608 m .19355 .56614 L .19346 .56381 L F
.998 .806 .522 r
.59588 .60943 m .59726 .60798 L .5959 .60711 L F
.59588 .60943 m .59706 .61058 L .59726 .60798 L F
.259 .756 .902 r
.45788 .60168 m .45723 .60214 L .45633 .6013 L F
.45788 .60168 m .45927 .60188 L .45723 .60214 L F
.319 .721 .98 r
.48108 .68313 m .48284 .68286 L .48165 .68221 L F
.279 .04 .362 r
.48216 .68415 m .48108 .68313 L .48165 .68221 L F
.48216 .68415 m .48053 .68536 L .48108 .68313 L F
.774 .72 .802 r
.53383 .651 m .532 .65448 L .53425 .65378 L F
0 0 0 r
.532 .65448 m .53271 .65316 L .53383 .651 L F
.844 .585 .042 r
.532 .65448 m .5316 .65503 L .53271 .65316 L F
.532 .65448 m .5323 .65654 L .5316 .65503 L F
.524 .205 .368 r
.49226 .65897 m .4902 .65728 L .49046 .6593 L F
.49226 .65897 m .4926 .65725 L .4902 .65728 L F
.64 .515 .695 r
.53927 .61947 m .54109 .61988 L .54167 .61649 L F
.556 .251 .406 r
.52815 .69182 m .52735 .69453 L .52488 .69457 L F
.567 .261 .41 r
.53001 .69373 m .52815 .69182 L .53046 .6915 L F
.53001 .69373 m .52735 .69453 L .52815 .69182 L F
0 0 0 r
.58703 .63825 m .58844 .63694 L .58578 .63877 L F
.364 .194 .513 r
.63675 .44347 m .63608 .44193 L .63529 .44476 L F
.63675 .44347 m .63906 .44215 L .63608 .44193 L F
.63675 .44347 m .63882 .44522 L .63906 .44215 L F
.63906 .44215 m .63882 .44522 L .63675 .44347 L F
.989 .864 .511 r
.63608 .44193 m .63529 .44476 L .63675 .44347 L F
.627 .286 .374 r
.78292 .49837 m .78438 .49793 L .78415 .49993 L F
.079 0 .242 r
.78415 .49993 m .78438 .49793 L .78678 .49641 L F
.479 .798 .999 r
.40694 .58231 m .40933 .58192 L .41073 .58287 L F
.51 .792 .996 r
.41154 .58134 m .41073 .58287 L .40933 .58192 L F
.41154 .58134 m .41295 .58242 L .41073 .58287 L F
.666 .461 .597 r
.63085 .4574 m .63085 .45984 L .62921 .45893 L F
.725 .614 .734 r
.66282 .44134 m .66165 .43805 L .66302 .44036 L F
.446 .666 .956 r
.66376 .43795 m .66302 .44036 L .66165 .43805 L F
.626 .618 .822 r
.66376 .43795 m .66282 .44134 L .66302 .44036 L F
0 0 .448 r
.58016 .62446 m .58083 .62128 L .57896 .6231 L F
.259 .361 .778 r
.56771 .59724 m .56987 .59812 L .56859 .59502 L F
.592 .363 .538 r
.64299 .45439 m .6429 .45672 L .63938 .45755 L F
.594 .329 .484 r
.645 .4544 m .6429 .45672 L .64299 .45439 L F
.662 .704 .878 r
.76325 .51227 m .7668 .51305 L .76569 .51154 L F
.705 .738 .877 r
.76569 .51154 m .7668 .51305 L .76924 .51215 L F
.142 .399 .848 r
.2267 .55196 m .22614 .55333 L .22545 .5516 L F
.2267 .55196 m .22855 .55477 L .22614 .55333 L F
.622 .351 .486 r
.64748 .4562 m .645 .4544 L .64896 .45372 L F
.548 .167 .272 r
.65096 .45437 m .64748 .4562 L .64896 .45372 L F
.905 .744 .672 r
.47853 .73184 m .4766 .73489 L .47773 .73231 L F
.801 .586 .61 r
.48024 .73513 m .4766 .73489 L .47853 .73184 L F
.249 0 0 r
.39483 .6342 m .3932 .63545 L .39082 .63572 L F
.443 0 .094 r
.39702 .63359 m .3932 .63545 L .39483 .6342 L F
.259 .471 .875 r
.20414 .56011 m .20258 .55807 L .20373 .55834 L F
.20414 .56011 m .20394 .55844 L .20258 .55807 L F
.106 0 0 r
.20217 .56299 m .2054 .56019 L .20414 .56011 L F
.609 .537 .748 r
.41232 .58974 m .41279 .59117 L .41416 .59052 L F
.678 .578 .736 r
.41279 .59117 m .41608 .59263 L .41416 .59052 L F
.754 .37 0 r
.48064 .69647 m .48126 .69738 L .47973 .69438 L F
.801 .379 .246 r
.48064 .69647 m .48363 .69802 L .48126 .69738 L F
.61 .526 .735 r
.48362 .69848 m .48126 .69738 L .48363 .69802 L F
.801 .379 .246 r
.48064 .69647 m .48173 .69871 L .48363 .69802 L F
.813 1 .83 r
.48363 .69802 m .48173 .69871 L .48366 .69686 L F
.48363 .69802 m .48366 .69686 L .48482 .69574 L F
.61 .526 .735 r
.48428 .69878 m .48362 .69848 L .48363 .69802 L F
.982 .698 .389 r
.45703 .60708 m .45847 .60796 L .45922 .6058 L F
.45703 .60708 m .45858 .6104 L .45847 .60796 L F
.829 .987 .872 r
.77392 .48871 m .77238 .49126 L .77561 .48797 L F
.77392 .48871 m .77238 .49126 L .77561 .48797 L F
.44 .444 .767 r
.77392 .48871 m .77403 .489 L .77238 .49126 L F
.327 .252 .618 r
.77294 .49139 m .77561 .48797 L .77238 .49126 L F
.77294 .49139 m .77588 .49255 L .77561 .48797 L F
.82 .971 .896 r
.77603 .48669 m .77561 .48797 L .77325 .48971 L F
.44 .444 .767 r
.77403 .489 m .77537 .49247 L .77321 .49159 L F
.77403 .489 m .77321 .49159 L .77238 .49126 L F
0 0 .032 r
.77303 .49215 m .77218 .49409 L .77294 .49139 L F
.77303 .49216 m .77302 .49219 L .77303 .49215 L F
.77302 .49219 m .77218 .49409 L .77303 .49215 L F
.23 .383 .811 r
.77303 .49216 m .77387 .49448 L .77218 .49409 L F
.618 .614 .825 r
.77387 .49448 m .77291 .49693 L .77218 .49409 L F
.211 .152 .569 r
.19438 .55654 m .19434 .55693 L .19268 .55797 L F
.497 .904 .907 r
.19668 .55704 m .19381 .55726 L .19268 .55797 L F
.495 .807 1 r
.20062 .55824 m .19389 .55731 L .19668 .55704 L F
.211 .152 .569 r
.19381 .55726 m .19382 .55735 L .19268 .55797 L F
.19382 .55735 m .19407 .55953 L .19272 .55802 L F
.19382 .55735 m .19272 .55802 L .19268 .55797 L F
.495 .807 1 r
.19389 .55731 m .19381 .55726 L .19668 .55704 L F
.872 .925 .536 r
.19536 .55566 m .19475 .55647 L .19438 .55654 L F
.513 .654 .922 r
.19429 .55707 m .19662 .55632 L .19536 .55566 L F
.872 .925 .536 r
.19512 .55639 m .19433 .55704 L .19438 .55654 L F
.513 .654 .922 r
.19365 .55728 m .19429 .55707 L .19536 .55566 L F
.872 .925 .536 r
.19536 .55566 m .19512 .55639 L .19475 .55647 L F
.495 .807 1 r
.20062 .55824 m .19752 .55675 L .19644 .55714 L F
.20062 .55824 m .19512 .5568 L .19513 .55722 L F
.20062 .55824 m .19429 .55707 L .19428 .55708 L F
.20062 .55824 m .19427 .55708 L .19389 .55731 L F
.697 .862 .96 r
.19901 .55596 m .19662 .55632 L .20062 .55824 L F
.035 0 0 r
.1992 .55688 m .19725 .5578 L .19866 .55633 L F
.19906 .55618 m .19866 .55633 L .19901 .55596 L F
.1992 .55688 m .19866 .55633 L .19906 .55618 L F
.495 .807 1 r
.19644 .55714 m .19662 .55632 L .19512 .5568 L F
.19752 .55675 m .19662 .55632 L .19644 .55714 L F
.19513 .55722 m .19512 .5568 L .19429 .55707 L F
.872 .925 .536 r
.19512 .55639 m .19407 .55953 L .19433 .55704 L F
.495 .807 1 r
.19428 .55708 m .19429 .55707 L .19427 .55708 L F
.872 .925 .536 r
.19512 .55639 m .19455 .55676 L .19407 .55953 L F
.211 .152 .569 r
.19434 .55693 m .19428 .55752 L .19381 .55726 L F
.872 .925 .536 r
.19455 .55676 m .19414 .5573 L .19414 .55741 L F
.211 .152 .569 r
.19428 .55752 m .19407 .55953 L .19381 .55726 L F
.872 .925 .536 r
.19427 .55839 m .19414 .55741 L .19407 .55953 L F
.19455 .55676 m .19414 .55741 L .19427 .55839 L F
.19536 .55566 m .19511 .55594 L .19512 .55639 L F
.19511 .55594 m .19415 .55701 L .19512 .55639 L F
.727 .325 .288 r
.19536 .55566 m .19725 .5578 L .19413 .55732 L F
.401 .777 .992 r
.19725 .5578 m .19535 .55697 L .1941 .55712 L F
.495 .807 1 r
.19389 .55731 m .19365 .55728 L .19381 .55726 L F
.19389 .55731 m .19427 .55708 L .19365 .55728 L F
.513 .654 .922 r
.19365 .55728 m .19536 .55566 L .19438 .55654 L F
.727 .325 .288 r
.19536 .55566 m .19413 .55732 L .19338 .55721 L F
.133 0 0 r
.19244 .55695 m .19366 .55699 L .19536 .55566 L F
.727 .325 .288 r
.19536 .55566 m .19338 .55721 L .19338 .55721 L F
.133 0 0 r
.19366 .55699 m .19415 .55701 L .19536 .55566 L F
.497 .904 .907 r
.19381 .55726 m .19365 .55728 L .19268 .55797 L F
0 0 0 r
.19268 .55797 m .19365 .55728 L .19438 .55654 L F
.49 .705 .965 r
.19249 .55575 m .19423 .55477 L .19269 .55343 L F
.516 .819 1 r
.19424 .55569 m .19423 .55477 L .19249 .55575 L F
.19536 .55566 m .19423 .55477 L .19424 .55569 L F
.133 0 0 r
.19244 .55695 m .19536 .55566 L .19249 .55575 L F
.392 .662 .967 r
.19269 .55343 m .19423 .55477 L .1943 .55321 L F
.531 .528 .797 r
.19362 .55651 m .19422 .55363 L .19423 .55477 L F
.19422 .55363 m .1943 .55321 L .19423 .55477 L F
.19338 .55721 m .19402 .55445 L .19362 .55651 L F
.19402 .55445 m .1943 .55321 L .19362 .55651 L F
.179 .244 .694 r
.19244 .55695 m .19275 .55795 L .19343 .5575 L F
.19353 .55699 m .19343 .5575 L .19415 .55701 L F
.19244 .55695 m .19343 .5575 L .19353 .55699 L F
.401 .777 .992 r
.19413 .55732 m .19411 .55718 L .19391 .55729 L F
.576 .59 .831 r
.19268 .55797 m .19535 .56141 L .19294 .56158 L F
0 0 .526 r
.19407 .55953 m .19535 .56141 L .19422 .55996 L F
.19407 .55953 m .19422 .55996 L .19268 .55797 L F
.82 .79 .291 r
.19415 .55701 m .19386 .55893 L .19407 .55953 L F
.19386 .55893 m .1936 .56066 L .19407 .55953 L F
.576 .59 .831 r
.19268 .55797 m .19294 .56158 L .19119 .56062 L F
.938 .579 .177 r
.19294 .56158 m .19259 .5628 L .19119 .56062 L F
.853 .864 .849 r
.19189 .56148 m .19259 .5628 L .19407 .55953 L F
.19189 .56148 m .19407 .55953 L .1936 .56066 L F
.179 .244 .694 r
.19275 .55795 m .1936 .56066 L .19413 .55716 L F
.19275 .55795 m .19413 .55716 L .19415 .55701 L F
.401 .777 .992 r
.19391 .55729 m .1941 .55712 L .19338 .55721 L F
.19411 .55718 m .1941 .55712 L .19391 .55729 L F
.19725 .5578 m .1941 .55712 L .19413 .55732 L F
.872 .925 .536 r
.19455 .55676 m .19415 .55701 L .19414 .5573 L F
.645 .419 .562 r
.49248 .67117 m .49523 .66858 L .49273 .66896 L F
.845 .587 .548 r
.49323 .6861 m .49154 .68819 L .49022 .68656 L F
.49323 .6861 m .49314 .68852 L .49154 .68819 L F
.733 .627 .741 r
.51006 .6513 m .50784 .6546 L .50663 .6508 L F
.722 .906 .538 r
.50898 .65265 m .50784 .6546 L .51006 .6513 L F
.299 0 0 r
.50907 .65512 m .50784 .6546 L .50898 .65265 L F
.50907 .65512 m .50779 .65472 L .50784 .6546 L F
.731 .669 .789 r
.53457 .61556 m .53531 .61805 L .53741 .61582 L F
.176 .711 .755 r
.38595 .59275 m .38445 .59292 L .38238 .59331 L F
.139 0 0 r
.3881 .59283 m .38445 .59292 L .38595 .59275 L F
.167 .678 .899 r
.47054 .69141 m .47212 .69132 L .47408 .69182 L F
.47054 .69141 m .47212 .69132 L .47408 .69182 L F
.202 .343 .783 r
.47529 .69075 m .4767 .69411 L .47408 .69182 L F
.931 .731 .611 r
.47269 .68992 m .47212 .69132 L .47408 .69182 L F
.492 .85 .992 r
.47408 .69182 m .47212 .69132 L .47529 .69075 L F
.502 .762 .989 r
.78534 .49264 m .78409 .49475 L .78329 .49347 L F
.999 .836 .525 r
.78521 .49252 m .78662 .49235 L .78499 .49159 L F
.502 .762 .989 r
.78541 .49261 m .78558 .49283 L .78534 .49264 L F
.78566 .49272 m .78558 .49283 L .78541 .49261 L F
.78558 .49283 m .78409 .49475 L .78534 .49264 L F
.7859 .49241 m .78329 .49347 L .78464 .49227 L F
.78558 .49283 m .78659 .49415 L .78409 .49475 L F
.899 .56 .395 r
.78397 .49416 m .78578 .49499 L .78524 .49266 L F
.78514 .49261 m .78524 .49266 L .78521 .49252 L F
.78397 .49416 m .78524 .49266 L .78514 .49261 L F
.502 .762 .989 r
.78566 .49272 m .78581 .49295 L .78558 .49283 L F
.78581 .49295 m .78659 .49415 L .78558 .49283 L F
.999 .836 .525 r
.78596 .49285 m .78662 .49235 L .78521 .49252 L F
.9 .956 .826 r
.78662 .49235 m .78659 .49415 L .78605 .49278 L F
.999 .836 .525 r
.7864 .49305 m .78662 .49235 L .78596 .49285 L F
.9 .956 .826 r
.78662 .49235 m .78605 .49278 L .7859 .49241 L F
.502 .762 .989 r
.7859 .49241 m .78605 .49278 L .78566 .49272 L F
.78605 .49278 m .78659 .49415 L .78566 .49272 L F
.999 .836 .525 r
.78578 .49499 m .7864 .49305 L .78566 .49272 L F
.78524 .49266 m .78566 .49272 L .78521 .49252 L F
.78578 .49499 m .78566 .49272 L .78524 .49266 L F
.502 .762 .989 r
.7859 .49241 m .78566 .49272 L .78541 .49261 L F
.899 .56 .395 r
.78478 .49212 m .78521 .49252 L .78499 .49159 L F
.457 .554 .866 r
.78524 .49164 m .7859 .49241 L .78482 .49208 L F
.9 .956 .826 r
.78662 .49235 m .7859 .49241 L .78499 .49159 L F
0 .101 .635 r
.78499 .49159 m .7859 .49241 L .78524 .49164 L F
.78499 .49159 m .78337 .48944 L .78612 .49101 L F
.78499 .49159 m .78524 .49164 L .78337 .48944 L F
.899 .56 .395 r
.78477 .49215 m .78478 .49212 L .78532 .49165 L F
.78533 .49165 m .78532 .49165 L .78595 .4911 L F
.78477 .49215 m .78532 .49165 L .78533 .49165 L F
.78478 .49212 m .78499 .49159 L .78557 .49129 L F
.78478 .49212 m .78557 .49129 L .78595 .4911 L F
.457 .554 .866 r
.78482 .49208 m .7859 .49241 L .78494 .4923 L F
.78337 .48944 m .78524 .49164 L .78482 .49208 L F
.78307 .49021 m .78494 .4923 L .78237 .492 L F
.78337 .48944 m .78494 .4923 L .78307 .49021 L F
.899 .56 .395 r
.78477 .49215 m .78494 .4923 L .78478 .49212 L F
.78494 .4923 m .78521 .49252 L .78478 .49212 L F
.78397 .49416 m .78521 .49252 L .78477 .49215 L F
.78397 .49416 m .78477 .49215 L .78612 .49101 L F
.78477 .49215 m .78595 .4911 L .78612 .49101 L F
.502 .762 .989 r
.78464 .49227 m .78329 .49347 L .78237 .492 L F
.468 .869 .962 r
.57091 .59956 m .57218 .59843 L .56987 .59812 L F
.57091 .59956 m .57344 .59879 L .57218 .59843 L F
0 .432 .701 r
.38048 .58161 m .38112 .58177 L .38161 .58193 L F
.204 .731 .825 r
.38191 .58204 m .38161 .58193 L .38338 .58192 L F
.373 0 0 r
.38161 .58193 m .38406 .58251 L .38563 .58194 L F
0 .432 .701 r
.38112 .58177 m .38406 .58251 L .38161 .58193 L F
.204 .731 .825 r
.37951 .58222 m .38161 .58193 L .38191 .58204 L F
.373 0 0 r
.38161 .58193 m .38563 .58194 L .38338 .58192 L F
.621 .584 .791 r
.4452 .60709 m .44679 .61084 L .44918 .61016 L F
.614 .362 .512 r
.44679 .61084 m .44875 .6126 L .44918 .61016 L F
.44679 .61084 m .44658 .61313 L .44875 .6126 L F
.348 .816 .912 r
.40228 .58898 m .40592 .58873 L .40437 .58869 L F
.24 .739 .904 r
.40592 .58873 m .40672 .5882 L .40437 .58869 L F
.40592 .58873 m .40823 .58852 L .40672 .5882 L F
.586 .872 .994 r
.47108 .68346 m .47496 .68334 L .47392 .68205 L F
.543 .149 .244 r
.47186 .68585 m .47425 .68526 L .47496 .68334 L F
.26 .547 .926 r
.47496 .68334 m .47614 .68271 L .47392 .68205 L F
0 0 0 r
.47558 .68424 m .47496 .68334 L .47425 .68526 L F
.47558 .68424 m .47614 .68271 L .47496 .68334 L F
.634 .114 0 r
.4313 .62283 m .43356 .62441 L .42992 .62369 L F
.684 .866 .968 r
.3209 .63324 m .3223 .6342 L .32468 .63323 L F
.617 .767 .951 r
.78718 .50215 m .78529 .50459 L .78481 .50313 L F
.78718 .50215 m .78817 .50409 L .78529 .50459 L F
.54 .375 .606 r
.32001 .59611 m .32238 .59582 L .32237 .5929 L F
.51 .346 .595 r
.32001 .59611 m .32224 .59837 L .32238 .59582 L F
.32001 .59611 m .32009 .59898 L .32224 .59837 L F
.48 .327 .595 r
.21142 .61096 m .21119 .61332 L .20923 .61361 L F
.493 .384 .659 r
.21119 .61332 m .21161 .61566 L .20923 .61361 L F
.424 .382 .707 r
.21161 .61566 m .21017 .61682 L .20923 .61361 L F
.48 .076 .195 r
.45136 .62389 m .44924 .62294 L .45262 .62179 L F
.773 .488 .504 r
.45505 .62223 m .45136 .62389 L .45262 .62179 L F
0 0 0 r
.46331 .61643 m .46588 .61365 L .46549 .61598 L F
.801 .31 .009 r
.56288 .62647 m .56441 .62879 L .56604 .62897 L F
0 0 0 r
.56663 .62926 m .56604 .62897 L .56441 .62879 L F
.56663 .62926 m .56823 .62715 L .56604 .62897 L F
.313 0 .17 r
.45079 .68321 m .45288 .68295 L .45292 .6825 L F
.208 .066 .457 r
.45079 .68321 m .45223 .68475 L .45288 .68295 L F
.45079 .68321 m .45055 .68599 L .45223 .68475 L F
.054 0 0 r
.38356 .62448 m .3803 .62491 L .3826 .62488 L F
.042 0 0 r
.38489 .62451 m .38356 .62448 L .3826 .62488 L F
.38489 .62451 m .38607 .62397 L .38356 .62448 L F
.758 .877 .932 r
.33353 .63508 m .33181 .63706 L .33082 .63571 L F
.33353 .63508 m .33181 .63706 L .33082 .63571 L F
.477 .236 .469 r
.35754 .60169 m .35665 .60617 L .35454 .60497 L F
.285 .068 .398 r
.35891 .60372 m .35754 .60169 L .35973 .60141 L F
.35891 .60372 m .35665 .60617 L .35754 .60169 L F
.211 0 0 r
.39428 .62332 m .39225 .62302 L .39075 .62345 L F
.271 0 0 r
.39428 .62332 m .39444 .62306 L .39225 .62302 L F
.239 0 .307 r
.46006 .67168 m .45787 .67427 L .45996 .67422 L F
.659 .474 .623 r
.45845 .67693 m .45996 .67422 L .45787 .67427 L F
.589 .767 .964 r
.40823 .58852 m .41232 .58974 L .41028 .58825 L F
.58 .763 .966 r
.41232 .58974 m .41275 .58764 L .41028 .58825 L F
.41232 .58974 m .41459 .58924 L .41275 .58764 L F
.609 .537 .748 r
.41232 .58974 m .41416 .59052 L .41459 .58924 L F
.027 .266 .765 r
.57526 .66016 m .57634 .65936 L .57528 .65904 L F
.044 .299 .788 r
.57526 .66016 m .57776 .66217 L .57634 .65936 L F
.125 .281 .753 r
.56889 .64869 m .56998 .65191 L .57026 .65057 L F
.605 .14 0 r
.56998 .65191 m .57049 .65271 L .57026 .65057 L F
.56998 .65191 m .57139 .65377 L .57049 .65271 L F
.205 0 .344 r
.51817 .67937 m .51597 .6826 L .51658 .68038 L F
.361 .184 .501 r
.20933 .62129 m .20785 .61944 L .20941 .61873 L F
.20933 .62129 m .20756 .62202 L .20785 .61944 L F
.695 .218 .112 r
.33324 .63202 m .3327 .63308 L .33048 .63103 L F
.76 .296 .145 r
.33324 .63202 m .33686 .63457 L .3327 .63308 L F
.308 .448 .838 r
.73028 .49694 m .73133 .49548 L .72853 .4946 L F
.73028 .49694 m .7321 .49741 L .73133 .49548 L F
.628 .335 .455 r
.53916 .65915 m .54094 .65892 L .53881 .65694 L F
.672 .32 .368 r
.53881 .65694 m .54094 .65892 L .54167 .6576 L F
.443 .005 .11 r
.40321 .6315 m .40173 .6333 L .39936 .63339 L F
.34 0 .043 r
.40518 .63182 m .40321 .6315 L .40549 .63113 L F
.40518 .63182 m .40173 .6333 L .40321 .6315 L F
.813 .92 .909 r
.64013 .42912 m .63657 .43073 L .63843 .4295 L F
.72 .988 .833 r
.64151 .42747 m .64013 .42912 L .63843 .4295 L F
.824 .738 .77 r
.32672 .63271 m .33048 .63103 L .32943 .63081 L F
.32672 .63271 m .32846 .63426 L .33048 .63103 L F
.31 .61 .953 r
.33048 .63103 m .33165 .63093 L .33081 .62999 L F
.34 .293 .66 r
.33048 .63103 m .3327 .63308 L .33165 .63093 L F
.697 .976 .915 r
.33081 .62999 m .32943 .63081 L .33048 .63103 L F
.31 .61 .953 r
.33048 .63103 m .33165 .63093 L .33081 .62999 L F
.465 .881 .931 r
.64032 .44635 m .63648 .44686 L .63882 .44522 L F
.353 .74 .986 r
.64252 .44595 m .64032 .44635 L .63882 .44522 L F
.523 0 0 r
.51865 .63302 m .52037 .63377 L .52203 .63389 L F
0 .396 .77 r
.52274 .63396 m .52203 .63389 L .52037 .63377 L F
.52274 .63396 m .52426 .63482 L .52203 .63389 L F
0 .237 .754 r
.46482 .61206 m .46615 .61292 L .46588 .61365 L F
.46473 .61193 m .46492 .61206 L .46482 .61206 L F
.46492 .61206 m .46615 .61292 L .46482 .61206 L F
.923 .825 .732 r
.46527 .61206 m .46646 .61207 L .46527 .61206 L F
0 .237 .754 r
.46498 .61199 m .46615 .61292 L .46473 .61193 L F
.46527 .61206 m .46615 .61292 L .46455 .61165 L F
.923 .825 .732 r
.46527 .61206 m .46527 .61206 L .46527 .61206 L F
.124 0 .351 r
.46527 .61206 m .46527 .61206 L .46527 .61206 L F
.622 .407 .569 r
.46527 .61206 m .46527 .61206 L .46402 .61085 L F
0 .237 .755 r
.46527 .61206 m .46646 .61207 L .46402 .61085 L F
0 .237 .754 r
.46402 .61085 m .46646 .61207 L .46615 .61292 L F
.923 .825 .732 r
.46525 .61343 m .46646 .61207 L .46527 .61206 L F
.46525 .61343 m .46527 .61206 L .46288 .61427 L F
.46527 .61206 m .46527 .61206 L .46288 .61427 L F
0 .237 .754 r
.46455 .61165 m .46498 .61199 L .46473 .61193 L F
.46402 .61085 m .46527 .61206 L .46455 .61165 L F
.124 0 .351 r
.46153 .61259 m .46288 .61427 L .46527 .61206 L F
.46153 .61259 m .46527 .61206 L .46527 .61206 L F
.622 .407 .569 r
.46153 .61259 m .46527 .61206 L .46402 .61085 L F
.301 .361 .758 r
.46706 .61425 m .46588 .61365 L .46646 .61207 L F
.46706 .61425 m .46549 .61598 L .46588 .61365 L F
.62 .379 .531 r
.51007 .66832 m .51271 .66778 L .51026 .66582 L F
.796 .634 .68 r
.6235 .45418 m .62497 .45731 L .62164 .45709 L F
.708 .599 .732 r
.62501 .45964 m .62164 .45709 L .62497 .45731 L F
.141 .679 .842 r
.64894 .44624 m .64628 .44639 L .64499 .44608 L F
0 0 0 r
.36934 .64047 m .36874 .64054 L .37108 .64023 L F
.36934 .64047 m .36706 .64112 L .36874 .64054 L F
.604 .485 .691 r
.32139 .63159 m .32378 .63269 L .32382 .62764 L F
.684 .866 .968 r
.3209 .63324 m .32378 .63269 L .32139 .63159 L F
0 .553 .764 r
.20031 .5439 m .20016 .54398 L .19949 .54408 L F
.20031 .5439 m .2021 .54419 L .20016 .54398 L F
.007 0 .4 r
.48895 .67495 m .4898 .675 L .49013 .67112 L F
0 .341 .819 r
.48895 .67495 m .49094 .67621 L .4898 .675 L F
.662 .774 .933 r
.48799 .67706 m .49094 .67621 L .48895 .67495 L F
.927 .92 .786 r
.61026 .65657 m .61331 .65423 L .61207 .65333 L F
.732 .589 .697 r
.58455 .64831 m .58119 .64887 L .58165 .64508 L F
.93 .873 .759 r
.58455 .64831 m .58158 .65045 L .58119 .64887 L F
.58455 .64831 m .58295 .65156 L .58158 .65045 L F
.694 .724 .873 r
.42979 .58716 m .42637 .58701 L .42856 .58606 L F
.449 .564 .879 r
.43139 .58571 m .42979 .58716 L .42856 .58606 L F
.43139 .58571 m .43184 .58721 L .42979 .58716 L F
.763 .68 .77 r
.46177 .68008 m .45941 .68298 L .46312 .68109 L F
.48 .263 .506 r
.45991 .68583 m .46312 .68109 L .45941 .68298 L F
.45991 .68583 m .46266 .68531 L .46312 .68109 L F
.512 .506 .787 r
.46312 .68109 m .46417 .67948 L .46177 .68008 L F
.46312 .68109 m .46536 .68294 L .46417 .67948 L F
0 0 0 r
.46266 .68531 m .46536 .68294 L .46312 .68109 L F
.316 0 0 r
.34431 .58499 m .34595 .58549 L .3477 .58395 L F
.124 0 0 r
.34595 .58549 m .34999 .58398 L .3477 .58395 L F
.407 .276 .588 r
.31829 .60213 m .32014 .60166 L .32009 .59898 L F
.435 .367 .681 r
.31829 .60213 m .3206 .60401 L .32014 .60166 L F
.51 .362 .616 r
.31844 .60452 m .3206 .60401 L .31829 .60213 L F
.204 .462 .881 r
.63529 .44476 m .63648 .44686 L .63405 .4459 L F
.445 .336 .635 r
.22851 .56692 m .22885 .56944 L .22693 .57012 L F
.361 .186 .505 r
.22885 .56944 m .2269 .5723 L .22693 .57012 L F
.379 .301 .642 r
.21486 .60674 m .21357 .6061 L .2152 .60403 L F
.21486 .60674 m .21366 .60767 L .21357 .6061 L F
.483 .54 .839 r
.58073 .66797 m .58123 .66497 L .57927 .66532 L F
.58073 .66797 m .58265 .66826 L .58123 .66497 L F
.791 .496 .489 r
.54308 .64172 m .54536 .63995 L .54309 .6399 L F
.54308 .64172 m .54648 .64223 L .54536 .63995 L F
.958 .721 .536 r
.19588 .58036 m .19419 .57927 L .1956 .57893 L F
.816 .676 .708 r
.57276 .63392 m .57307 .62971 L .57131 .6307 L F
.597 .151 .163 r
.57285 .63633 m .57355 .63632 L .57336 .63549 L F
.727 .268 0 r
.57336 .63549 m .57448 .63672 L .57316 .63457 L F
.163 .698 .839 r
.57701 .63625 m .57448 .63672 L .57336 .63549 L F
.597 .151 .163 r
.57355 .63632 m .57701 .63625 L .57336 .63549 L F
.727 .268 0 r
.57336 .63549 m .57316 .63457 L .57276 .63392 L F
.384 .533 .882 r
.45077 .59558 m .44965 .59764 L .44845 .59586 L F
.45077 .59558 m .45271 .59899 L .44965 .59764 L F
.605 .196 .241 r
.57902 .59679 m .57953 .59809 L .57572 .59834 L F
.718 .81 .922 r
.80525 .51215 m .80199 .51489 L .80187 .51181 L F
.62 .719 .917 r
.32468 .63323 m .32846 .63426 L .32672 .63271 L F
.602 .409 .593 r
.65364 .45134 m .65364 .45419 L .65096 .45437 L F
.579 .494 .723 r
.65558 .45082 m .65364 .45419 L .65364 .45134 L F
.45 .615 .92 r
.35974 .62097 m .35891 .62306 L .3576 .62128 L F
.35974 .62097 m .36129 .62325 L .35891 .62306 L F
.781 .732 .807 r
.46785 .62061 m .46969 .62043 L .47074 .61744 L F
.46969 .62043 m .47255 .62014 L .47131 .61829 L F
.46969 .62043 m .47131 .61829 L .47074 .61744 L F
.748 .628 .726 r
.4699 .62171 m .4669 .62427 L .46694 .62197 L F
.4699 .62171 m .47051 .62478 L .4669 .62427 L F
.668 .575 .741 r
.47255 .62189 m .47051 .62478 L .4699 .62171 L F
.674 .296 .323 r
.47068 .62309 m .47255 .62014 L .46785 .62061 L F
.569 .698 .929 r
.47252 .61972 m .47253 .61987 L .47124 .62125 L F
0 0 0 r
.47413 .61461 m .47404 .61471 L .4714 .61819 L F
0 .123 .642 r
.47135 .61826 m .47253 .61987 L .47191 .61754 L F
0 0 0 r
.4714 .61819 m .4714 .61819 L .47135 .61826 L F
.47413 .61461 m .4714 .61819 L .4714 .61819 L F
.654 .85 .975 r
.47359 .61527 m .47159 .61531 L .4738 .61501 L F
.352 0 .126 r
.4738 .61501 m .47159 .61531 L .47074 .61744 L F
0 .123 .642 r
.47074 .61744 m .47135 .61826 L .47135 .61821 L F
0 .349 .729 r
.47131 .61829 m .47135 .61826 L .47074 .61744 L F
.352 0 .126 r
.47137 .61823 m .47074 .61744 L .47121 .61844 L F
.4738 .61501 m .47074 .61744 L .47137 .61823 L F
0 .123 .642 r
.47074 .61744 m .47135 .61821 L .47156 .61618 L F
0 0 0 r
.47413 .61461 m .47135 .61826 L .47135 .61826 L F
.47404 .61471 m .4738 .61501 L .47239 .61687 L F
.47404 .61471 m .47239 .61687 L .47121 .61844 L F
.487 .662 .939 r
.47501 .61344 m .47602 .61499 L .4738 .61501 L F
0 0 0 r
.47501 .61344 m .4738 .61501 L .47413 .61461 L F
.913 .949 .808 r
.47501 .61344 m .47141 .61818 L .47156 .61618 L F
0 .123 .642 r
.47135 .61826 m .47141 .61818 L .47156 .61618 L F
0 0 0 r
.47135 .61826 m .47135 .61826 L .47121 .61844 L F
.913 .949 .808 r
.47141 .61818 m .47121 .61844 L .47156 .61618 L F
0 .123 .642 r
.47141 .61818 m .47191 .61754 L .47156 .61618 L F
.569 .698 .929 r
.47253 .61987 m .47381 .61818 L .47156 .61618 L F
.47381 .61818 m .47253 .61987 L .47252 .61972 L F
0 .349 .729 r
.47253 .62012 m .47253 .61987 L .47135 .61826 L F
.47255 .62014 m .47253 .61987 L .47253 .62012 L F
.47255 .62014 m .47135 .61826 L .47131 .61829 L F
.654 .85 .975 r
.47573 .61522 m .47359 .61527 L .4738 .61501 L F
.393 .726 .99 r
.4738 .61501 m .47624 .6158 L .47573 .61522 L F
.383 .633 .953 r
.48614 .7107 m .48718 .71218 L .48807 .71079 L F
.333 .368 .748 r
.41608 .59263 m .41672 .589 L .41416 .59052 L F
.41608 .59263 m .41771 .59258 L .41672 .589 L F
.555 .727 .955 r
.56155 .597 m .56262 .59492 L .56067 .59552 L F
.56155 .597 m .56407 .59639 L .56262 .59492 L F
.289 0 0 r
.43934 .62271 m .43647 .62392 L .4373 .62247 L F
.943 .845 .717 r
.62726 .44012 m .62495 .44083 L .62614 .43901 L F
.573 .394 .6 r
.50306 .64811 m .50354 .65099 L .50055 .64861 L F
.4 .275 .593 r
.54945 .66578 m .55156 .66536 L .55042 .66281 L F
.425 .376 .7 r
.54945 .66578 m .55194 .66806 L .55156 .66536 L F
.583 .379 .571 r
.54944 .66827 m .55194 .66806 L .54945 .66578 L F
.486 .669 .944 r
.21936 .54683 m .21933 .54913 L .21744 .54696 L F
.21936 .54683 m .22132 .54889 L .21933 .54913 L F
.862 .764 .752 r
.57307 .62971 m .57352 .62714 L .57131 .6307 L F
.784 .285 .003 r
.54674 .62213 m .54768 .62353 L .54869 .62289 L F
.489 .002 .026 r
.54768 .62353 m .55129 .62235 L .54869 .62289 L F
.594 .329 .484 r
.645 .4544 m .64502 .4565 L .6429 .45672 L F
.622 .351 .486 r
.64748 .4562 m .64502 .4565 L .645 .4544 L F
.447 .203 .449 r
.221 .58477 m .22055 .58703 L .21845 .58759 L F
.623 .444 .618 r
.22305 .58413 m .22055 .58703 L .221 .58477 L F
.14 0 .247 r
.51851 .66281 m .51621 .66585 L .51855 .66565 L F
.573 .304 .471 r
.51855 .66565 m .51849 .66781 L .51621 .66585 L F
.14 0 .247 r
.51851 .66281 m .51621 .66585 L .51855 .66565 L F
.573 .304 .471 r
.51855 .66565 m .51849 .66781 L .51621 .66585 L F
.958 .721 .536 r
.19588 .58036 m .19544 .58138 L .19419 .57927 L F
.683 .416 .512 r
.53992 .60182 m .54378 .60152 L .54294 .59938 L F
.595 .451 .655 r
.54378 .60152 m .54637 .59965 L .54294 .59938 L F
.601 .282 .402 r
.41688 .61596 m .41954 .61614 L .42049 .61348 L F
.528 .21 .372 r
.42049 .61348 m .42244 .61481 L .42311 .61368 L F
.42049 .61348 m .41954 .61614 L .42244 .61481 L F
.194 .341 .785 r
.52652 .72664 m .52808 .72621 L .5257 .72377 L F
.201 .039 .425 r
.20756 .62202 m .20729 .62407 L .20567 .62524 L F
.27 .169 .551 r
.20729 .62407 m .20575 .62784 L .20567 .62524 L F
.392 .767 .992 r
.78918 .50868 m .78845 .5079 L .78684 .50872 L F
0 0 .154 r
.78708 .51082 m .78684 .50872 L .78845 .5079 L F
.78708 .51082 m .78684 .51198 L .78684 .50872 L F
.73 .717 .189 r
.56183 .68536 m .56112 .68883 L .56176 .68544 L F
.73 .388 .4 r
.51006 .6513 m .50908 .65508 L .50898 .65265 L F
.968 .796 .366 r
.5095 .65069 m .50908 .65503 L .51006 .6513 L F
.696 .618 .765 r
.50908 .65503 m .50922 .65512 L .51191 .65466 L F
.50894 .65504 m .5091 .65509 L .50908 .65503 L F
.5091 .65509 m .50922 .65512 L .50908 .65503 L F
.73 .388 .4 r
.50908 .65508 m .50907 .65508 L .50898 .65265 L F
.925 .7 .579 r
.50762 .64929 m .509 .65485 L .5095 .65069 L F
.696 .618 .765 r
.50907 .65493 m .50894 .65504 L .50908 .65503 L F
.51086 .65342 m .50907 .65493 L .51191 .65466 L F
.50907 .65493 m .50908 .65503 L .51191 .65466 L F
.686 .599 .753 r
.50917 .65513 m .51052 .65508 L .50913 .65517 L F
.51052 .65508 m .5118 .65503 L .51043 .6551 L F
.51052 .65508 m .51043 .6551 L .50913 .65517 L F
.51163 .65474 m .51166 .6548 L .50917 .65513 L F
.51166 .6548 m .5118 .65503 L .51109 .65505 L F
.51166 .6548 m .51109 .65505 L .50917 .65513 L F
.646 .477 .64 r
.51474 .65036 m .51497 .65355 L .51234 .65325 L F
.541 .067 .079 r
.51497 .65355 m .51416 .65478 L .51319 .65397 L F
.51382 .65342 m .51319 .65397 L .51234 .65325 L F
.51497 .65355 m .51319 .65397 L .51382 .65342 L F
.317 .11 .432 r
.5118 .65503 m .50948 .65813 L .50876 .65519 L F
.006 .139 .653 r
.51361 .65432 m .51416 .65478 L .51385 .65422 L F
.51361 .65432 m .51385 .65422 L .51322 .65308 L F
.51234 .65325 m .51361 .65432 L .51322 .65308 L F
.509 .124 .246 r
.51189 .65474 m .51193 .65472 L .512 .65464 L F
.51187 .6547 m .512 .65464 L .51191 .65466 L F
.239 0 0 r
.51183 .65471 m .51187 .6547 L .51191 .65466 L F
.377 .511 .866 r
.51191 .65466 m .51338 .65433 L .51086 .65342 L F
.51338 .65433 m .51388 .65422 L .51311 .65401 L F
.51338 .65433 m .51311 .65401 L .51086 .65342 L F
.473 .74 .986 r
.51311 .65401 m .51166 .6548 L .51086 .65342 L F
.51388 .65422 m .51335 .65435 L .51311 .65401 L F
.51335 .65435 m .51166 .6548 L .51311 .65401 L F
.509 .124 .246 r
.50974 .65662 m .51105 .65586 L .51193 .65472 L F
.50974 .65662 m .51193 .65472 L .51189 .65474 L F
.50974 .65662 m .512 .65464 L .51187 .6547 L F
.6 .411 .598 r
.50779 .65472 m .50759 .65926 L .50438 .65938 L F
.577 .392 .594 r
.50948 .65813 m .50779 .65472 L .50876 .65519 L F
.50948 .65813 m .50759 .65926 L .50779 .65472 L F
.239 0 0 r
.50763 .65733 m .50974 .65662 L .51187 .6547 L F
.049 0 .297 r
.50856 .66021 m .50759 .65926 L .50948 .65813 L F
.726 .578 .689 r
.50725 .65746 m .50783 .65991 L .50974 .65662 L F
.239 0 0 r
.50761 .65734 m .50974 .65662 L .50763 .65733 L F
.50761 .65734 m .51187 .6547 L .51183 .65471 L F
.50762 .65734 m .51183 .65471 L .50876 .65519 L F
.50761 .65734 m .50763 .65733 L .50762 .65734 L F
.50763 .65733 m .51183 .65471 L .50762 .65734 L F
.6 .411 .598 r
.50779 .65472 m .50438 .65938 L .50488 .65644 L F
.542 .272 .456 r
.50488 .65644 m .50438 .65938 L .50191 .65978 L F
.616 .185 .2 r
.50779 .65472 m .50273 .65559 L .50474 .65748 L F
.298 0 0 r
.5076 .65734 m .50779 .65472 L .50474 .65748 L F
.50761 .65734 m .50761 .65734 L .5076 .65734 L F
.50761 .65734 m .50779 .65472 L .5076 .65734 L F
.50761 .65734 m .50876 .65519 L .50779 .65472 L F
.50761 .65734 m .50762 .65734 L .50761 .65734 L F
.50762 .65734 m .50876 .65519 L .50761 .65734 L F
.726 .578 .689 r
.50677 .65542 m .50724 .65742 L .50828 .65709 L F
.50936 .65669 m .50828 .65709 L .50942 .65672 L F
.50677 .65542 m .50828 .65709 L .50936 .65669 L F
.50973 .65662 m .50942 .65672 L .50974 .65662 L F
.50677 .65542 m .50942 .65672 L .50973 .65662 L F
.50724 .65742 m .50725 .65746 L .50763 .65733 L F
.50724 .65742 m .50763 .65733 L .50974 .65662 L F
.239 0 0 r
.51183 .65471 m .51191 .65466 L .50876 .65519 L F
.686 .599 .753 r
.51086 .65342 m .51163 .65474 L .50917 .65513 L F
.925 .7 .579 r
.50905 .65496 m .50908 .65504 L .50908 .65503 L F
.686 .599 .753 r
.51086 .65342 m .50913 .65517 L .50905 .65496 L F
.925 .7 .579 r
.509 .65485 m .50908 .65503 L .5095 .65069 L F
.968 .796 .366 r
.50908 .65503 m .50908 .65508 L .51006 .6513 L F
.86 .995 .82 r
.51166 .64808 m .51006 .6513 L .51237 .65083 L F
.707 .578 .709 r
.50513 .65243 m .50907 .65512 L .50762 .64929 L F
.86 .6 .544 r
.51054 .65108 m .51195 .65488 L .50832 .6535 L F
.51084 .65076 m .5111 .65172 L .51054 .65108 L F
.5111 .65172 m .51195 .65488 L .51054 .65108 L F
.51107 .65051 m .51123 .65132 L .51084 .65076 L F
.51123 .65132 m .51195 .65488 L .51084 .65076 L F
.473 .74 .986 r
.51335 .65435 m .5118 .65503 L .51166 .6548 L F
.51388 .65422 m .51338 .65441 L .51335 .65435 L F
.51338 .65441 m .5118 .65503 L .51335 .65435 L F
.317 .11 .432 r
.5118 .65503 m .51142 .65816 L .50948 .65813 L F
.473 .74 .986 r
.51388 .65422 m .51416 .65478 L .5118 .65503 L F
.617 .365 .512 r
.51419 .65655 m .5118 .65503 L .51416 .65478 L F
.51419 .65655 m .51142 .65816 L .5118 .65503 L F
.509 .124 .246 r
.51105 .65586 m .51388 .65422 L .51258 .65451 L F
.51105 .65586 m .51258 .65451 L .512 .65464 L F
.968 .796 .366 r
.50908 .65503 m .50908 .65504 L .50908 .65508 L F
.696 .618 .765 r
.50912 .65509 m .50876 .65519 L .50922 .65512 L F
.299 0 0 r
.50779 .65472 m .50876 .65519 L .50904 .65511 L F
.50904 .65511 m .50876 .65519 L .50779 .65472 L F
.696 .618 .765 r
.50894 .65504 m .50876 .65519 L .50912 .65509 L F
.73 .388 .4 r
.50908 .65508 m .50908 .65509 L .50907 .65508 L F
.686 .599 .753 r
.50908 .65509 m .50908 .6551 L .50902 .65507 L F
.73 .388 .4 r
.50908 .65509 m .50907 .65512 L .50907 .65508 L F
.50908 .65509 m .50907 .65508 L .50907 .65508 L F
.686 .599 .753 r
.50902 .65507 m .50908 .6551 L .50876 .65519 L F
.50908 .65504 m .50908 .65509 L .50902 .65507 L F
.50908 .6551 m .50908 .65518 L .50876 .65519 L F
.299 0 0 r
.50907 .65512 m .50876 .65519 L .50904 .65511 L F
.50904 .65511 m .50876 .65519 L .50907 .65512 L F
.968 .796 .366 r
.50908 .65504 m .50907 .65512 L .50908 .65509 L F
.50908 .65504 m .50908 .65509 L .50908 .65508 L F
.299 0 0 r
.50779 .65472 m .50904 .65511 L .50513 .65243 L F
.50904 .65511 m .50907 .65512 L .50807 .65444 L F
.50904 .65511 m .50807 .65444 L .50513 .65243 L F
.686 .599 .753 r
.50905 .65496 m .50908 .65504 L .50899 .65508 L F
.50894 .65504 m .50899 .65508 L .50876 .65519 L F
.50905 .65496 m .50899 .65508 L .50894 .65504 L F
.50908 .65504 m .50913 .65517 L .50908 .65518 L F
.925 .7 .579 r
.509 .65485 m .50907 .65512 L .50908 .65504 L F
.509 .65485 m .50908 .65504 L .50905 .65496 L F
.736 .933 .953 r
.60767 .66186 m .60687 .66392 L .60852 .66238 L F
.60767 .66186 m .60506 .66343 L .60687 .66392 L F
.729 .947 .952 r
.78884 .47748 m .79042 .47512 L .79112 .47584 L F
.78884 .47748 m .7881 .47673 L .79042 .47512 L F
.165 0 0 r
.38406 .58251 m .38625 .58252 L .38747 .58213 L F
.052 0 0 r
.38625 .58252 m .38691 .58229 L .38747 .58213 L F
.157 0 0 r
.38563 .58194 m .38747 .58213 L .38829 .58188 L F
.052 0 0 r
.38691 .58229 m .38982 .58133 L .38747 .58213 L F
.157 0 0 r
.38829 .58188 m .38747 .58213 L .38928 .58186 L F
.588 .925 .961 r
.38747 .58213 m .39142 .58146 L .38928 .58186 L F
.645 .576 .762 r
.43584 .60196 m .43938 .60494 L .43833 .60158 L F
.8 .626 .666 r
.55527 .65758 m .55333 .65437 L .55433 .65646 L F
0 0 .477 r
.55431 .65506 m .55496 .65777 L .55433 .65646 L F
.872 .479 .012 r
.55536 .6583 m .55516 .65858 L .55618 .65978 L F
.55433 .65646 m .55516 .65858 L .55536 .6583 L F
.55433 .65646 m .55618 .65978 L .55527 .65758 L F
.77 .814 .336 r
.55516 .65858 m .5553 .65763 L .5547 .6592 L F
.55516 .65858 m .5547 .6592 L .55469 .65922 L F
0 0 .477 r
.55496 .65777 m .55516 .65858 L .55433 .65646 L F
.8 .626 .666 r
.55333 .65437 m .55299 .6538 L .55433 .65646 L F
.781 .561 .603 r
.4587 .62235 m .45504 .62443 L .45505 .62223 L F
.4587 .62235 m .45861 .62482 L .45504 .62443 L F
0 0 .278 r
.55552 .67379 m .55338 .67164 L .5553 .67087 L F
.55552 .67379 m .55535 .67064 L .55338 .67164 L F
.55552 .67379 m .5558 .67321 L .55535 .67064 L F
0 .066 .628 r
.55651 .67495 m .5558 .67321 L .55552 .67379 L F
.41 0 0 r
.7525 .49423 m .75607 .49459 L .75374 .49407 L F
.988 .86 .62 r
.81031 .50852 m .81225 .5059 L .80967 .50545 L F
.81031 .50852 m .81125 .50956 L .81225 .5059 L F
.128 0 .333 r
.21948 .59572 m .21773 .59896 L .21743 .59627 L F
.442 .089 .269 r
.49454 .63912 m .49691 .63862 L .49783 .63654 L F
.545 .19 .316 r
.49691 .63862 m .50034 .63651 L .49783 .63654 L F
.603 .374 .542 r
.46451 .62232 m .46443 .62454 L .46221 .62393 L F
.657 .471 .621 r
.46694 .62197 m .46443 .62454 L .46451 .62232 L F
.742 .4 .403 r
.58624 .59243 m .58758 .59022 L .58405 .58987 L F
.863 .561 .476 r
.58624 .59243 m .58775 .59216 L .58758 .59022 L F
0 0 .142 r
.5558 .69476 m .55684 .69352 L .55733 .69114 L F
.104 .229 .71 r
.5558 .69476 m .55761 .69648 L .55684 .69352 L F
.341 .266 .625 r
.5558 .69476 m .55636 .6977 L .55761 .69648 L F
.5558 .69476 m .55636 .6977 L .55761 .69648 L F
.242 0 0 r
.54124 .62074 m .54492 .61978 L .54109 .61988 L F
.802 .32 .063 r
.54398 .62059 m .54674 .62213 L .54492 .61978 L F
.856 .445 .254 r
.53992 .60182 m .54051 .60366 L .54192 .60264 L F
.652 .815 .962 r
.54378 .60152 m .54192 .60264 L .53992 .60182 L F
.559 .76 .972 r
.54382 .67914 m .54442 .68074 L .5401 .67993 L F
.185 .475 .893 r
.54349 .68266 m .5401 .67993 L .54442 .68074 L F
.462 .694 .967 r
.54475 .67907 m .54442 .68074 L .54382 .67914 L F
0 0 .355 r
.54475 .67907 m .54349 .68266 L .54442 .68074 L F
.129 .48 .898 r
.44731 .5944 m .44702 .59558 L .44479 .59366 L F
.44731 .5944 m .44845 .59586 L .44702 .59558 L F
0 0 0 r
.47028 .69725 m .46774 .69938 L .46869 .69782 L F
.457 .196 .429 r
.48006 .65389 m .48229 .65342 L .48218 .6512 L F
.371 .14 .428 r
.48218 .6512 m .48497 .65061 L .48489 .64804 L F
.608 .461 .657 r
.48229 .65342 m .48497 .65061 L .48218 .6512 L F
.822 .673 .698 r
.57754 .64765 m .58165 .64508 L .57766 .64499 L F
.57754 .64765 m .58119 .64887 L .58165 .64508 L F
0 0 0 r
.58165 .64508 m .58156 .64596 L .58271 .64452 L F
.58165 .64508 m .58147 .64652 L .58156 .64596 L F
.678 .899 .548 r
.58156 .64596 m .58126 .64605 L .58159 .6457 L F
.58156 .64596 m .58159 .6457 L .58271 .64452 L F
0 0 0 r
.58147 .64652 m .58119 .64887 L .58156 .64596 L F
.549 .353 .568 r
.48754 .64592 m .49011 .64551 L .49011 .64255 L F
.45 .276 .552 r
.49011 .64255 m .49209 .64465 L .49209 .64201 L F
.49011 .64255 m .49011 .64551 L .49209 .64465 L F
.54 .82 .998 r
.58265 .66826 m .58622 .66865 L .58501 .6678 L F
.417 .774 .996 r
.58622 .66865 m .58879 .66843 L .58501 .6678 L F
.77 .366 .285 r
.48168 .67741 m .48543 .67973 L .48552 .67735 L F
.621 .383 .535 r
.48552 .67735 m .4879 .67945 L .48799 .67706 L F
.48552 .67735 m .48543 .67973 L .4879 .67945 L F
.487 .304 .558 r
.45541 .67989 m .45845 .67693 L .45541 .67763 L F
.9 .68 .595 r
.59833 .61864 m .59988 .61955 L .59847 .61629 L F
.878 .716 .677 r
.59676 .62126 m .59988 .61955 L .59833 .61864 L F
.59676 .62126 m .59975 .62224 L .59988 .61955 L F
.51 .359 .612 r
.45996 .67422 m .46187 .67126 L .46006 .67168 L F
.466 0 0 r
.54648 .62572 m .54552 .62593 L .54293 .62467 L F
0 .14 .621 r
.54648 .62572 m .54748 .62628 L .54552 .62593 L F
.598 .026 0 r
.55018 .62785 m .54868 .62741 L .54648 .62572 L F
0 .14 .621 r
.54648 .62572 m .54868 .62741 L .54748 .62628 L F
.483 .072 .183 r
.58278 .59181 m .58137 .59005 L .58044 .5923 L F
.58278 .59181 m .58405 .58987 L .58137 .59005 L F
.85 .562 .501 r
.49743 .70345 m .49633 .70587 L .49431 .70437 L F
.407 .077 .29 r
.49875 .70519 m .49743 .70345 L .49994 .7031 L F
.49875 .70519 m .49633 .70587 L .49743 .70345 L F
.261 .053 .396 r
.21486 .60674 m .21293 .61009 L .21366 .60767 L F
.533 .36 .592 r
.35454 .60497 m .35482 .60735 L .35273 .6077 L F
.499 .334 .587 r
.35451 .61023 m .35273 .6077 L .35482 .60735 L F
.35451 .61023 m .35271 .61081 L .35273 .6077 L F
.627 .286 .374 r
.78292 .49837 m .78415 .49993 L .78128 .4998 L F
.601 .082 0 r
.57422 .5944 m .57574 .59344 L .57215 .59299 L F
.12 0 0 r
.5768 .59383 m .57574 .59344 L .57422 .5944 L F
.5768 .59383 m .57834 .59335 L .57574 .59344 L F
.673 .588 .752 r
.43833 .60158 m .43938 .60494 L .44165 .60214 L F
.673 .589 .753 r
.43938 .60494 m .44277 .60539 L .44165 .60214 L F
.778 .631 .698 r
.43933 .60727 m .44277 .60539 L .43938 .60494 L F
.991 .851 .489 r
.45627 .68751 m .45706 .68587 L .45628 .68463 L F
.515 .532 .812 r
.45642 .68473 m .45627 .68751 L .45628 .68463 L F
.991 .851 .489 r
.45627 .68751 m .45617 .68931 L .45706 .68587 L F
.933 .714 .583 r
.45706 .68587 m .45617 .68933 L .45761 .68869 L F
.884 .924 .844 r
.45628 .68463 m .45706 .68587 L .45941 .68298 L F
.663 .528 .689 r
.45706 .68587 m .45991 .68583 L .45941 .68298 L F
0 .062 .582 r
.45706 .68587 m .45871 .68753 L .45991 .68583 L F
.45706 .68587 m .45761 .68869 L .45871 .68753 L F
.515 .532 .812 r
.45773 .68568 m .45627 .68751 L .45642 .68473 L F
.991 .851 .489 r
.45627 .68751 m .45617 .68933 L .45617 .68931 L F
.782 .479 .475 r
.48024 .73513 m .47882 .73742 L .4766 .73489 L F
.684 .844 .424 r
.4806 .73437 m .47882 .73742 L .48024 .73513 L F
.133 .12 .575 r
.53419 .63671 m .53581 .63829 L .53599 .63624 L F
.322 .258 .628 r
.45004 .69475 m .45199 .69693 L .4515 .69433 L F
.432 0 .067 r
.48952 .71026 m .48807 .71079 L .48938 .70916 L F
.48952 .71026 m .48938 .70916 L .48918 .70869 L F
.973 .709 .47 r
.45676 .69114 m .45761 .68869 L .45617 .68933 L F
.45676 .69114 m .45838 .69173 L .45761 .68869 L F
.559 .481 .723 r
.45761 .68869 m .46075 .68866 L .45871 .68753 L F
.45761 .68869 m .45838 .69173 L .46075 .68866 L F
.686 .395 .476 r
.62921 .45893 m .62733 .4619 L .62501 .45964 L F
.72 .344 .337 r
.62921 .45893 m .63125 .46159 L .62733 .4619 L F
.62921 .45893 m .63085 .45984 L .63125 .46159 L F
.956 .72 .54 r
.46863 .6914 m .47054 .69141 L .46885 .68804 L F
.317 .051 .343 r
.47054 .69141 m .47212 .69132 L .47269 .68992 L F
.248 .67 .963 r
.47136 .69053 m .47054 .69141 L .46863 .6914 L F
.47136 .69053 m .47212 .69132 L .47054 .69141 L F
.083 0 0 r
.75843 .49372 m .76181 .49275 L .75921 .49378 L F
.677 .753 .908 r
.75977 .51168 m .76325 .51227 L .7624 .51086 L F
.643 .706 .892 r
.76325 .51227 m .76482 .50874 L .7624 .51086 L F
.76325 .51227 m .76569 .51154 L .76482 .50874 L F
.499 .109 .231 r
.64326 .43375 m .64007 .43581 L .64087 .43405 L F
.155 .643 .919 r
.47577 .6621 m .4779 .66231 L .4778 .6626 L F
.47577 .6621 m .4779 .66231 L .47921 .66295 L F
.37 0 0 r
.47443 .6633 m .47652 .66345 L .4779 .66231 L F
.64 .908 .603 r
.4779 .66231 m .47652 .66345 L .47807 .66178 L F
.424 .267 .562 r
.47796 .65951 m .4779 .66231 L .48009 .65926 L F
.64 .908 .603 r
.4779 .66231 m .47807 .66178 L .47908 .6607 L F
.155 .643 .919 r
.4778 .6626 m .4779 .66231 L .47921 .66295 L F
0 .265 .762 r
.48082 .66348 m .48126 .66432 L .47921 .66295 L F
.444 .28 .563 r
.231 .56588 m .22884 .56436 L .22945 .56314 L F
.231 .56588 m .22851 .56692 L .22884 .56436 L F
.509 .821 1 r
.41295 .58242 m .41516 .58191 L .41647 .58273 L F
.555 .636 .886 r
.77628 .51809 m .78024 .52043 L .77908 .51878 L F
.501 .621 .902 r
.78024 .52043 m .78159 .51836 L .77908 .51878 L F
.78024 .52043 m .78253 .52015 L .78159 .51836 L F
.894 .988 .745 r
.58703 .63825 m .58976 .63551 L .58844 .63694 L F
.462 .313 .592 r
.32237 .5929 m .32451 .59509 L .32461 .59276 L F
.32237 .5929 m .32238 .59582 L .32451 .59509 L F
.129 0 0 r
.32692 .59187 m .32959 .59057 L .32765 .59056 L F
.554 .757 .972 r
.79771 .51829 m .7993 .51647 L .79683 .51676 L F
.79771 .51829 m .80024 .51787 L .7993 .51647 L F
.345 .467 .841 r
.45337 .70039 m .45489 .70347 L .45629 .70206 L F
.3 .395 .792 r
.45489 .70347 m .45759 .70538 L .45629 .70206 L F
.034 0 .167 r
.21161 .61566 m .20941 .61873 L .21017 .61682 L F
.416 .277 .582 r
.3566 .60628 m .35454 .60497 L .35665 .60617 L F
.3566 .60628 m .35482 .60735 L .35454 .60497 L F
.548 .167 .272 r
.65096 .45437 m .65109 .45594 L .64748 .4562 L F
.523 .149 .273 r
.65326 .45565 m .65109 .45594 L .65096 .45437 L F
.52 .155 .288 r
.65364 .45419 m .65326 .45565 L .65096 .45437 L F
.492 .472 .763 r
.22121 .58927 m .21845 .58759 L .22055 .58703 L F
.873 .447 .19 r
.56191 .62517 m .56288 .62647 L .56432 .62476 L F
.56191 .62517 m .56165 .62661 L .56288 .62647 L F
.5 .685 .95 r
.34418 .6366 m .34361 .63343 L .34118 .63281 L F
.34418 .6366 m .34436 .63412 L .34361 .63343 L F
.34418 .6366 m .3459 .63618 L .34436 .63412 L F
.562 .163 .242 r
.45861 .62482 m .46221 .62393 L .46081 .62636 L F
.603 .224 .298 r
.46221 .62393 m .4631 .6265 L .46081 .62636 L F
.46221 .62393 m .46443 .62454 L .4631 .6265 L F
.955 .627 .359 r
.45849 .69337 m .45838 .69173 L .45676 .69114 L F
.774 .364 .275 r
.46092 .69456 m .45838 .69173 L .45849 .69337 L F
.735 .663 .779 r
.52083 .66235 m .51855 .66565 L .51851 .66281 L F
0 0 .42 r
.51851 .66281 m .51943 .66409 L .52083 .66235 L F
.51851 .66281 m .51855 .66565 L .51943 .66409 L F
.794 .35 .19 r
.46446 .71504 m .46428 .71524 L .46356 .71481 L F
.46606 .71545 m .46428 .71524 L .46446 .71504 L F
.752 .337 0 r
.46428 .71524 m .46469 .71615 L .4642 .71532 L F
0 0 .527 r
.46356 .71481 m .46428 .71524 L .462 .71169 L F
.752 .337 0 r
.46428 .71524 m .4642 .71532 L .46283 .71299 L F
.678 .758 .912 r
.76569 .51154 m .76924 .51215 L .76855 .5108 L F
.585 .709 .929 r
.76855 .5108 m .76924 .51215 L .7717 .51158 L F
.88 .637 .567 r
.59672 .62386 m .59975 .62224 L .59676 .62126 L F
.59672 .62386 m .59931 .62465 L .59975 .62224 L F
.856 .723 .715 r
.6235 .45418 m .62004 .45578 L .62154 .45307 L F
.6235 .45418 m .62164 .45709 L .62004 .45578 L F
.34 0 .188 r
.52114 .67719 m .51817 .67937 L .51867 .67726 L F
.785 .641 .702 r
.57597 .64128 m .5777 .64359 L .57437 .64226 L F
.756 .675 .773 r
.5762 .63953 m .5768 .64115 L .57589 .63999 L F
.5768 .64115 m .5777 .64359 L .57651 .64122 L F
.5768 .64115 m .57651 .64122 L .57589 .63999 L F
.505 .534 .82 r
.57936 .64088 m .5777 .64359 L .5762 .63953 L F
.533 .57 .838 r
.57651 .64122 m .5777 .64359 L .57936 .64088 L F
.57597 .64128 m .5777 .64359 L .57651 .64122 L F
.045 0 0 r
.57607 .64132 m .57597 .64128 L .57651 .64122 L F
0 0 .146 r
.57587 .64143 m .57437 .64226 L .57597 .64128 L F
.756 .675 .773 r
.57589 .63999 m .57645 .64111 L .57437 .64226 L F
.57645 .64111 m .5777 .64359 L .57438 .64226 L F
.045 0 0 r
.57747 .6418 m .57489 .64299 L .57587 .64143 L F
.57607 .64132 m .57587 .64143 L .57597 .64128 L F
.57747 .6418 m .57587 .64143 L .57607 .64132 L F
.756 .675 .773 r
.57587 .64143 m .57438 .64226 L .57437 .64226 L F
.57645 .64111 m .57438 .64226 L .57587 .64143 L F
0 0 .146 r
.57489 .64299 m .57437 .64226 L .57587 .64143 L F
.045 0 0 r
.57747 .6418 m .57607 .64132 L .57936 .64088 L F
.57607 .64132 m .57651 .64122 L .57936 .64088 L F
.67 .801 .945 r
.51901 .69424 m .52168 .69177 L .51894 .69159 L F
.644 .818 .967 r
.55156 .66536 m .55139 .66183 L .55042 .66281 L F
.369 .78 .981 r
.79251 .48536 m .79374 .48636 L .79672 .48599 L F
.589 .606 .837 r
.48426 .6855 m .48544 .68225 L .48284 .68286 L F
.48426 .6855 m .48675 .68548 L .48544 .68225 L F
.083 0 0 r
.75843 .49372 m .76102 .49332 L .76181 .49275 L F
0 0 0 r
.76289 .49285 m .76344 .49264 L .76427 .49299 L F
.76344 .49264 m .7631 .49421 L .76393 .49245 L F
.621 .88 .989 r
.76581 .49173 m .76539 .4919 L .76465 .49092 L F
.76539 .4919 m .76344 .49264 L .76465 .49092 L F
0 0 0 r
.76344 .49264 m .76393 .49245 L .76465 .49092 L F
.485 .901 .847 r
.76775 .49184 m .76427 .49299 L .7668 .49237 L F
.538 .909 .955 r
.76427 .49299 m .76581 .49173 L .7668 .49237 L F
.76427 .49299 m .76344 .49264 L .76581 .49173 L F
.198 .035 .421 r
.76465 .49092 m .7631 .49421 L .76462 .49311 L F
.76465 .49092 m .76462 .49311 L .76397 .49004 L F
.76465 .49092 m .76397 .49004 L .76395 .48991 L F
0 0 0 r
.76181 .49275 m .76344 .49264 L .76289 .49285 L F
.76181 .49275 m .76102 .49332 L .76344 .49264 L F
.455 .595 .902 r
.42637 .58701 m .4225 .58395 L .42461 .58401 L F
.653 .701 .882 r
.42856 .58606 m .42637 .58701 L .42461 .58401 L F
.156 .697 .776 r
.37509 .62532 m .37457 .62558 L .37273 .62537 L F
.37509 .62532 m .37687 .62528 L .37457 .62558 L F
.541 .301 .501 r
.49237 .63974 m .49446 .6416 L .49454 .63912 L F
.49237 .63974 m .49209 .64201 L .49446 .6416 L F
.361 0 0 r
.36504 .62439 m .36692 .62488 L .36867 .62484 L F
0 .417 .777 r
.36916 .62475 m .36867 .62484 L .36692 .62488 L F
.36916 .62475 m .37072 .6256 L .36867 .62484 L F
.372 0 .09 r
.41967 .62575 m .42155 .62647 L .41914 .62687 L F
.41967 .62575 m .42202 .62539 L .42155 .62647 L F
.233 0 0 r
.39999 .5902 m .39856 .59139 L .39647 .59152 L F
.065 0 0 r
.40228 .58898 m .40107 .59054 L .39999 .5902 L F
.475 .103 .253 r
.40107 .59054 m .39856 .59139 L .39999 .5902 L F
.409 .787 .992 r
.80116 .50639 m .80049 .50563 L .79771 .50591 L F
.80116 .50639 m .80049 .50563 L .79771 .50591 L F
.863 .658 .624 r
.60904 .64184 m .61092 .64262 L .60934 .63931 L F
.828 .396 .212 r
.60904 .64184 m .60985 .64372 L .61092 .64262 L F
.843 .419 .226 r
.61092 .64262 m .60985 .64372 L .61143 .64367 L F
.345 .026 .274 r
.48489 .64804 m .48702 .6478 L .48754 .64592 L F
.449 .118 .311 r
.48754 .64592 m .48936 .64727 L .49011 .64551 L F
.48754 .64592 m .48702 .6478 L .48936 .64727 L F
.523 .337 .57 r
.47711 .71282 m .47788 .71529 L .47539 .71557 L F
.475 .403 .696 r
.47767 .71177 m .48072 .71432 L .47711 .71282 L F
.441 .149 .372 r
.48072 .71432 m .47788 .71529 L .47711 .71282 L F
.354 .357 .725 r
.35534 .61213 m .3546 .61595 L .35359 .61334 L F
.35534 .61213 m .35618 .61571 L .3546 .61595 L F
.442 .354 .661 r
.3567 .61813 m .3546 .61595 L .35618 .61571 L F
.3567 .61813 m .35476 .61975 L .3546 .61595 L F
.931 .74 .623 r
.59507 .60374 m .59757 .60198 L .59545 .60118 L F
.59507 .60374 m .59671 .60479 L .59757 .60198 L F
.544 .83 .998 r
.58197 .61034 m .57944 .61028 L .57913 .61251 L F
.987 .885 .548 r
.56146 .67117 m .56016 .67283 L .56019 .67435 L F
.56146 .67117 m .56087 .67037 L .56016 .67283 L F
0 .202 .693 r
.8028 .47778 m .80104 .47688 L .80001 .47578 L F
.8028 .47778 m .80386 .47899 L .80104 .47688 L F
.121 .342 .808 r
.80104 .47688 m .80386 .47899 L .80394 .48019 L F
.578 .329 .502 r
.63938 .45755 m .64194 .45909 L .6392 .45918 L F
.63938 .45755 m .6429 .45672 L .64194 .45909 L F
.403 .095 .325 r
.5785 .65139 m .58119 .64887 L .57754 .64765 L F
.5785 .65139 m .58158 .65045 L .58119 .64887 L F
.58119 .64887 m .58158 .65045 L .5785 .65139 L F
.887 .979 .824 r
.58119 .64887 m .5805 .64765 L .58156 .64596 L F
.784 .448 0 r
.58119 .64887 m .58158 .65045 L .5805 .64765 L F
.494 .499 .791 r
.77287 .51494 m .77422 .51115 L .7717 .51158 L F
.77287 .51494 m .775 .51463 L .77422 .51115 L F
.425 .228 .507 r
.53884 .65521 m .5368 .65344 L .53998 .65141 L F
.237 0 .194 r
.54075 .65452 m .53998 .65141 L .54148 .65231 L F
.54075 .65452 m .53884 .65521 L .53998 .65141 L F
.716 .564 .682 r
.47865 .7031 m .4776 .69953 L .47899 .70055 L F
.661 .475 .623 r
.4812 .70238 m .47865 .7031 L .47899 .70055 L F
.487 0 0 r
.44783 .62415 m .44924 .62294 L .45136 .62389 L F
0 0 0 r
.64326 .43375 m .64588 .43106 L .64481 .43224 L F
.57 .807 .989 r
.64715 .42929 m .64588 .43106 L .64501 .42735 L F
.64715 .42929 m .64828 .43044 L .64588 .43106 L F
.64588 .43106 m .64715 .42929 L .64481 .43224 L F
.64588 .43106 m .64828 .43044 L .64715 .42929 L F
.655 .205 0 r
.55618 .65978 m .55767 .66206 L .55817 .66252 L F
.606 .076 0 r
.55889 .66365 m .56021 .66461 L .55817 .66252 L F
.242 .746 .892 r
.5037 .69147 m .50273 .69116 L .50558 .6912 L F
.5037 .69147 m .50273 .69116 L .50558 .6912 L F
.708 .698 .839 r
.50558 .6912 m .50449 .6938 L .5037 .69147 L F
.782 .477 .472 r
.5205 .64487 m .51735 .64453 L .51704 .6425 L F
.735 .663 .779 r
.52083 .66235 m .5221 .66567 L .51855 .66565 L F
.633 .215 .233 r
.51855 .66565 m .5221 .66567 L .52101 .66763 L F
.305 0 0 r
.51973 .67318 m .52337 .67147 L .52012 .67213 L F
.51973 .67318 m .52207 .67294 L .52337 .67147 L F
.264 .38 .794 r
.52376 .66486 m .5221 .66567 L .52083 .66235 L F
0 0 0 r
.52101 .66763 m .5221 .66567 L .52376 .66486 L F
.53 .4 .647 r
.52337 .67147 m .52574 .67372 L .52369 .67402 L F
.553 .027 0 r
.52461 .67287 m .52337 .67147 L .52207 .67294 L F
.52461 .67287 m .52574 .67372 L .52337 .67147 L F
.711 .711 .848 r
.53457 .61556 m .53741 .61582 L .53946 .6137 L F
.791 .831 .883 r
.47159 .61531 m .46987 .61712 L .46681 .61607 L F
.47159 .61531 m .46681 .61607 L .47074 .61744 L F
.108 .172 .649 r
.46706 .61425 m .46739 .61605 L .46681 .61607 L F
.722 .68 .809 r
.46987 .61712 m .46596 .6161 L .46681 .61607 L F
.624 .424 .591 r
.46681 .61607 m .46775 .61801 L .47074 .61744 L F
.108 .172 .649 r
.46739 .61605 m .46775 .61801 L .46681 .61607 L F
.722 .68 .809 r
.46596 .6161 m .46549 .61598 L .46681 .61607 L F
.884 .924 .844 r
.45628 .68463 m .45941 .68298 L .45779 .68204 L F
.839 .812 .825 r
.45779 .68204 m .45941 .68298 L .46177 .68008 L F
.728 .946 .952 r
.34038 .63215 m .34011 .63381 L .34118 .63281 L F
.717 .68 .813 r
.33603 .63163 m .33937 .63357 L .33681 .6302 L F
.836 .999 .813 r
.34035 .63234 m .33874 .63436 L .34011 .63381 L F
.717 .68 .813 r
.33937 .63357 m .33941 .63359 L .33938 .63355 L F
.33937 .63357 m .33938 .63355 L .33681 .6302 L F
.847 .513 .423 r
.33937 .63357 m .3382 .6351 L .33941 .63359 L F
.33603 .63163 m .33773 .63434 L .33937 .63357 L F
.674 .668 .836 r
.33681 .6302 m .33938 .63355 L .34038 .63215 L F
.836 .999 .813 r
.34038 .63215 m .33938 .63355 L .34035 .63234 L F
.674 .668 .836 r
.33938 .63355 m .33941 .63359 L .34038 .63215 L F
.836 .999 .813 r
.34038 .63215 m .33874 .63436 L .33938 .63355 L F
.34038 .63215 m .33875 .63389 L .3393 .6336 L F
.854 .993 .833 r
.34038 .63215 m .33875 .63389 L .33941 .63359 L F
.836 .999 .813 r
.33875 .63389 m .33804 .63464 L .3393 .6336 L F
.854 .993 .833 r
.33875 .63389 m .33804 .63464 L .33941 .63359 L F
.847 .513 .423 r
.33773 .63434 m .33776 .6344 L .33875 .63389 L F
.33773 .63434 m .33875 .63389 L .33937 .63357 L F
.836 .999 .813 r
.3393 .6336 m .33804 .63464 L .33874 .63436 L F
.847 .513 .423 r
.33776 .6344 m .3382 .6351 L .33937 .63357 L F
.727 .695 .82 r
.49455 .65166 m .49816 .65206 L .49672 .65109 L F
.122 0 0 r
.49816 .65206 m .50067 .65178 L .49961 .6524 L F
.49816 .65206 m .49961 .6524 L .49672 .65109 L F
.374 .491 .849 r
.7321 .49741 m .73358 .50048 L .73507 .49884 L F
.374 .39 .749 r
.73418 .50225 m .73507 .49884 L .73358 .50048 L F
0 0 .448 r
.58016 .62446 m .5811 .62376 L .58083 .62128 L F
.046 .238 .737 r
.58016 .62446 m .58239 .62694 L .5811 .62376 L F
.303 .096 .424 r
.2215 .59267 m .21948 .59572 L .21959 .59328 L F
.086 0 0 r
.79582 .51289 m .79274 .51426 L .79567 .51113 L F
.35 .396 .769 r
.79809 .51113 m .79582 .51289 L .79567 .51113 L F
.79809 .51113 m .79865 .51645 L .79582 .51289 L F
0 0 .047 r
.62349 .44594 m .6239 .44512 L .62356 .44424 L F
.62349 .44594 m .62308 .44868 L .6239 .44512 L F
0 .15 .687 r
.50659 .70016 m .5084 .7025 L .50726 .70031 L F
.155 0 0 r
.50659 .70016 m .50726 .70031 L .50632 .7001 L F
.265 0 0 r
.42311 .61368 m .42548 .61366 L .42654 .61331 L F
.473 0 0 r
.42768 .6143 m .42654 .61331 L .42548 .61366 L F
.42768 .6143 m .42878 .61507 L .42654 .61331 L F
.625 .218 .252 r
.42654 .61331 m .42878 .61507 L .42889 .61353 L F
.896 .987 .739 r
.56019 .67435 m .55846 .67535 L .56 .67667 L F
.56019 .67435 m .56016 .67283 L .55846 .67535 L F
0 .545 .78 r
.39142 .58146 m .39353 .58175 L .39515 .58212 L F
.276 .751 .936 r
.39573 .58136 m .39515 .58212 L .39353 .58175 L F
.39573 .58136 m .39749 .58195 L .39515 .58212 L F
.353 0 0 r
.4432 .62218 m .44189 .6232 L .43934 .62271 L F
.562 .042 0 r
.4432 .62218 m .44555 .62349 L .44189 .6232 L F
.628 .332 .45 r
.48489 .64804 m .48734 .65026 L .48702 .6478 L F
.48489 .64804 m .48497 .65061 L .48734 .65026 L F
.99 .749 .471 r
.59564 .61187 m .59706 .61058 L .59588 .60943 L F
.59564 .61187 m .59689 .61297 L .59706 .61058 L F
.346 .768 .976 r
.21385 .54635 m .21549 .54701 L .21174 .54654 L F
.319 .702 .98 r
.21593 .54595 m .21549 .54701 L .21385 .54635 L F
.21593 .54595 m .21744 .54696 L .21549 .54701 L F
.662 .774 .933 r
.48799 .67706 m .49141 .67724 L .49094 .67621 L F
.688 .417 .507 r
.4879 .67945 m .49141 .67724 L .48799 .67706 L F
.4879 .67945 m .49196 .67973 L .49141 .67724 L F
.545 .755 .974 r
.49141 .67724 m .49291 .6758 L .49094 .67621 L F
.49141 .67724 m .49366 .67686 L .49291 .6758 L F
.523 .312 .535 r
.49141 .67724 m .49196 .67973 L .49366 .67686 L F
.771 .267 0 r
.49196 .67973 m .49141 .67724 L .49366 .67686 L F
.491 .446 .734 r
.41459 .58924 m .41416 .59052 L .41672 .589 L F
.659 .576 .751 r
.79858 .49083 m .79905 .49517 L .80015 .49397 L F
.499 .109 .231 r
.64326 .43375 m .64315 .43551 L .64007 .43581 L F
0 0 .116 r
.64421 .43446 m .64326 .43375 L .64481 .43224 L F
.64421 .43446 m .64315 .43551 L .64326 .43375 L F
.471 .217 .447 r
.54094 .65892 m .54372 .65648 L .54167 .6576 L F
.571 .001 0 r
.47788 .71529 m .47364 .71409 L .47539 .71557 L F
.544 .065 .069 r
.52547 .66142 m .52677 .65994 L .52866 .66117 L F
.538 .078 .109 r
.52677 .65994 m .52949 .6602 L .52866 .66117 L F
.804 .787 .837 r
.20062 .55824 m .20186 .5596 L .20258 .55807 L F
.846 .966 .879 r
.80652 .51539 m .80298 .51725 L .8038 .51818 L F
.596 .183 .229 r
.58712 .63198 m .58872 .63316 L .58867 .63282 L F
.262 0 .156 r
.52718 .63844 m .52503 .63927 L .52804 .63688 L F
.392 .504 .853 r
.53005 .63468 m .52804 .63688 L .52632 .63407 L F
.53005 .63468 m .53002 .63698 L .52804 .63688 L F
.244 0 .03 r
.53002 .63698 m .52718 .63844 L .52804 .63688 L F
.478 .703 .968 r
.79409 .51698 m .79554 .51537 L .79274 .51426 L F
.79409 .51698 m .79683 .51676 L .79554 .51537 L F
.632 .924 .656 r
.76921 .49004 m .76775 .49184 L .7668 .49237 L F
0 0 0 r
.38516 .63708 m .38121 .63783 L .38304 .63731 L F
.403 0 .156 r
.54427 .7116 m .54295 .71392 L .54056 .71426 L F
.424 .749 .994 r
.54632 .71132 m .54427 .7116 L .54255 .71054 L F
.228 0 .066 r
.54516 .71316 m .54427 .7116 L .54632 .71132 L F
.54516 .71316 m .54295 .71392 L .54427 .7116 L F
.711 .711 .848 r
.53457 .61556 m .53946 .6137 L .53479 .61454 L F
.789 .806 .866 r
.50926 .6773 m .50619 .67981 L .5094 .67787 L F
.477 .109 .26 r
.50549 .68181 m .5094 .67787 L .50619 .67981 L F
.50549 .68181 m .508 .68166 L .5094 .67787 L F
0 .172 .702 r
.50926 .6773 m .5094 .67787 L .51081 .67821 L F
.474 .2 .418 r
.508 .68166 m .51081 .67821 L .5094 .67787 L F
.67 .801 .945 r
.51901 .69424 m .52229 .69351 L .52168 .69177 L F
.34 .191 .529 r
.52229 .69351 m .5239 .69126 L .52168 .69177 L F
.685 .715 .871 r
.75384 .51189 m .75739 .51261 L .75629 .51119 L F
.698 .719 .866 r
.75629 .51119 m .75739 .51261 L .75977 .51168 L F
.766 .636 .717 r
.57131 .6307 m .57352 .62714 L .56998 .62775 L F
.367 .183 .495 r
.22504 .58107 m .22305 .58413 L .22304 .58164 L F
.352 0 0 r
.37674 .63896 m .37308 .64009 L .37453 .63917 L F
0 0 .454 r
.46729 .72056 m .46863 .72256 L .47175 .72038 L F
.723 .419 .464 r
.46863 .72256 m .47185 .72079 L .47175 .72038 L F
.342 0 .102 r
.33441 .58973 m .3382 .58704 L .33598 .58751 L F
.97 .886 .691 r
.61089 .65004 m .61284 .64872 L .61139 .64758 L F
.61089 .65004 m .61187 .65096 L .61284 .64872 L F
.194 0 .04 r
.5046 .68209 m .50549 .68181 L .50619 .67981 L F
.808 .692 .736 r
.78896 .50442 m .79137 .50602 L .79236 .50403 L F
.778 .631 .698 r
.43933 .60727 m .44299 .60769 L .44277 .60539 L F
.634 .524 .712 r
.44277 .60539 m .44299 .60769 L .44521 .60489 L F
.684 .596 .752 r
.44521 .60489 m .44299 .60769 L .4452 .60709 L F
.513 .563 .844 r
.25526 .85374 m .25632 .85371 L .25535 .85392 L F
.385 .102 .356 r
.25535 .85392 m .25632 .85371 L .25522 .85431 L F
.448 0 0 r
.36398 .58297 m .36628 .58324 L .36792 .58201 L F
.495 0 0 r
.36792 .58201 m .36628 .58324 L .36998 .58288 L F
.823 .914 .9 r
.80838 .5121 m .81125 .50956 L .81031 .50852 L F
.934 .589 .157 r
.5516 .65075 m .5521 .65281 L .55299 .6538 L F
.029 .245 .747 r
.5521 .65281 m .55433 .65646 L .55299 .6538 L F
.529 .554 .825 r
.72613 .49506 m .728 .49281 L .725 .49144 L F
.72613 .49506 m .72853 .4946 L .728 .49281 L F
.836 .999 .808 r
.48252 .65879 m .4823 .66054 L .48466 .65784 L F
.556 .815 .994 r
.48009 .65926 m .4823 .66054 L .48252 .65879 L F
.643 .572 .76 r
.44165 .60214 m .44277 .60539 L .44521 .60489 L F
.757 .415 .404 r
.74313 .49355 m .74634 .49205 L .7428 .49135 L F
.74313 .49355 m .7466 .49406 L .74634 .49205 L F
.748 .435 .454 r
.42878 .61507 m .43229 .61345 L .42889 .61353 L F
.42878 .61507 m .43134 .61595 L .43229 .61345 L F
.567 .243 .38 r
.43229 .61345 m .43134 .61595 L .43431 .61499 L F
.599 .221 .296 r
.43229 .61345 m .43431 .61499 L .43496 .6134 L F
.159 .686 .868 r
.19445 .54366 m .19949 .54408 L .19667 .54436 L F
.924 .95 .79 r
.487 .65466 m .48509 .65571 L .48619 .65619 L F
.91 .867 .785 r
.4871 .65284 m .48712 .65252 L .48711 .6526 L F
.48712 .65252 m .48713 .65245 L .48711 .6526 L F
.706 .636 .777 r
.48647 .65468 m .48695 .65379 L .48711 .6526 L F
.91 .867 .785 r
.48708 .65361 m .48734 .65026 L .48713 .65245 L F
.48705 .65431 m .48714 .65312 L .48708 .65361 L F
.48714 .65312 m .48734 .65026 L .48708 .65361 L F
.536 .178 .307 r
.48759 .65353 m .48757 .65591 L .48683 .65585 L F
.924 .95 .79 r
.48759 .65353 m .48619 .65619 L .48705 .65431 L F
.48703 .65401 m .48509 .65571 L .487 .65466 L F
.536 .178 .307 r
.48703 .65401 m .48683 .65585 L .48509 .65571 L F
.91 .867 .785 r
.48705 .65431 m .48713 .65245 L .4871 .65284 L F
.924 .95 .79 r
.48759 .65353 m .48705 .65431 L .4871 .65284 L F
.48759 .65353 m .4871 .65284 L .48711 .6526 L F
.48759 .65353 m .48703 .65401 L .487 .65466 L F
.536 .178 .307 r
.48759 .65353 m .48683 .65585 L .48703 .65401 L F
.273 .002 .307 r
.49105 .65082 m .48759 .65353 L .48711 .6526 L F
.671 .427 .544 r
.49105 .65082 m .48711 .6526 L .48734 .65026 L F
.706 .636 .777 r
.48695 .65379 m .48827 .65138 L .48711 .6526 L F
.994 .753 .41 r
.47514 .73194 m .47413 .72852 L .47529 .72931 L F
.46 .812 .997 r
.47413 .72852 m .47777 .72887 L .47529 .72931 L F
.636 .93 .97 r
.62174 .45059 m .62005 .45126 L .62141 .44952 L F
.84 .803 .815 r
.62154 .45307 m .62141 .44952 L .62005 .45126 L F
.773 .488 .504 r
.45505 .62223 m .45504 .62443 L .45136 .62389 L F
.531 .289 .494 r
.50279 .63632 m .50529 .63362 L .50287 .63379 L F
.796 .754 .815 r
.51529 .69396 m .51469 .69659 L .51901 .69424 L F
.466 .413 .715 r
.54696 .66876 m .54948 .67076 L .54944 .66827 L F
.54696 .66876 m .54771 .67165 L .54948 .67076 L F
0 0 .355 r
.54475 .67907 m .54475 .68155 L .54349 .68266 L F
.22 0 .135 r
.41124 .62784 m .40996 .63034 L .40821 .63027 L F
.497 .134 .28 r
.41301 .62925 m .41124 .62784 L .41349 .62803 L F
.41301 .62925 m .40996 .63034 L .41124 .62784 L F
0 0 0 r
.55812 .68522 m .55855 .68495 L .55937 .68327 L F
.989 .724 .403 r
.55937 .68327 m .55855 .68495 L .55827 .68211 L F
.818 .672 .701 r
.60439 .63331 m .60586 .63653 L .60666 .63405 L F
.674 .684 .851 r
.74789 .51201 m .75152 .51291 L .75027 .51124 L F
.701 .705 .851 r
.75027 .51124 m .75152 .51291 L .75384 .51189 L F
.73 .717 .189 r
.56183 .68536 m .56134 .68749 L .56112 .68883 L F
.997 .773 .455 r
.55989 .69098 m .56112 .68883 L .56134 .68749 L F
.55989 .69098 m .56101 .69173 L .56112 .68883 L F
.684 .866 .968 r
.3209 .63324 m .32468 .63323 L .32378 .63269 L F
.621 .7 .901 r
.32378 .63269 m .32468 .63323 L .32672 .63271 L F
.736 .413 .434 r
.53516 .68458 m .5378 .68294 L .53542 .68584 L F
.64 .472 .641 r
.5378 .68294 m .53791 .68571 L .53542 .68584 L F
.736 .413 .434 r
.53516 .68458 m .53626 .68534 L .5378 .68294 L F
0 0 .081 r
.5401 .67993 m .5378 .68294 L .53952 .6818 L F
.577 .224 .334 r
.5378 .68294 m .54002 .68496 L .53952 .6818 L F
.5378 .68294 m .53626 .68534 L .54002 .68496 L F
.423 0 0 r
.35814 .58342 m .36044 .58369 L .36224 .58268 L F
.299 0 0 r
.36224 .58268 m .36044 .58369 L .36398 .58297 L F
.279 0 0 r
.42244 .61481 m .42548 .61366 L .42311 .61368 L F
.226 0 0 r
.37578 .58175 m .37397 .58205 L .37337 .58278 L F
.618 .614 .825 r
.77387 .49448 m .77495 .49753 L .77291 .49693 L F
0 0 0 r
.25493 .85376 m .25632 .85371 L .25526 .85374 L F
.892 .602 .489 r
.59335 .59579 m .59519 .5986 L .59526 .59618 L F
.807 .704 .752 r
.58761 .60767 m .58653 .60427 L .58335 .60665 L F
.845 .539 .005 r
.58761 .60767 m .58705 .60662 L .58653 .60427 L F
.955 .7 .248 r
.58787 .61006 m .58705 .60662 L .58761 .60767 L F
.846 .966 .879 r
.80652 .51539 m .8058 .51452 L .80298 .51725 L F
.722 .317 .281 r
.80581 .50919 m .80744 .51088 L .80397 .51047 L F
.80744 .51088 m .80766 .51111 L .80719 .51103 L F
.80744 .51088 m .80719 .51103 L .80397 .51047 L F
.693 .737 .884 r
.80397 .51047 m .80766 .51111 L .80525 .51215 L F
.883 .915 .843 r
.80623 .51159 m .80666 .51005 L .80626 .51068 L F
.577 .396 .6 r
.80525 .51215 m .80766 .51111 L .8062 .51284 L F
.883 .915 .843 r
.8062 .51284 m .80642 .51148 L .80623 .51159 L F
.80642 .51148 m .80666 .51005 L .80623 .51159 L F
.262 .406 .819 r
.80525 .51215 m .8062 .51284 L .80615 .51444 L F
.883 .915 .843 r
.8062 .51284 m .80626 .51068 L .80466 .51319 L F
.262 .406 .819 r
.80615 .51444 m .8062 .51284 L .80652 .51539 L F
.991 .885 .571 r
.80652 .51539 m .8062 .51284 L .8058 .51452 L F
.80652 .51539 m .8062 .51284 L .8058 .51452 L F
.855 .769 .767 r
.46016 .67913 m .46177 .68008 L .46077 .6775 L F
.839 .812 .825 r
.45779 .68204 m .46177 .68008 L .46016 .67913 L F
.642 .641 .834 r
.46177 .68008 m .46272 .67625 L .46077 .6775 L F
.46177 .68008 m .46417 .67948 L .46272 .67625 L F
.498 .841 .997 r
.39749 .58195 m .39973 .58139 L .40113 .58211 L F
.556 .865 .996 r
.40113 .58211 m .40189 .58069 L .40335 .58165 L F
.40113 .58211 m .39973 .58139 L .40189 .58069 L F
.663 .319 .381 r
.51063 .68332 m .51019 .68489 L .50842 .68327 L F
.321 0 .108 r
.51304 .68317 m .51019 .68489 L .51063 .68332 L F
.546 .84 .999 r
.46661 .67471 m .46731 .67319 L .46506 .67353 L F
.619 .277 .37 r
.46661 .67471 m .4663 .67654 L .46891 .67634 L F
.956 .672 .232 r
.58891 .61347 m .58812 .61244 L .58787 .61006 L F
.976 .908 .675 r
.58697 .61502 m .58891 .61347 L .58739 .61662 L F
.711 .5 .601 r
.47773 .73231 m .47311 .73473 L .47514 .73194 L F
.47773 .73231 m .4766 .73489 L .47311 .73473 L F
.427 0 0 r
.51445 .63367 m .51692 .63383 L .51865 .63302 L F
.28 0 0 r
.51692 .63383 m .52037 .63377 L .51865 .63302 L F
.819 .34 0 r
.53954 .63615 m .54243 .6404 L .54309 .6399 L F
.608 .886 .99 r
.54306 .63992 m .54108 .64209 L .54309 .6399 L F
.54196 .64099 m .54173 .64128 L .54306 .63992 L F
.54173 .64128 m .54108 .64209 L .54197 .64111 L F
.54173 .64128 m .54197 .64111 L .54306 .63992 L F
.383 .126 .396 r
.54108 .64209 m .54308 .64172 L .54309 .6399 L F
.064 0 .273 r
.54125 .64471 m .54308 .64172 L .54108 .64209 L F
.54125 .64471 m .54284 .64429 L .54308 .64172 L F
.852 .417 0 r
.5415 .64144 m .54284 .64429 L .54308 .64172 L F
.716 .385 .418 r
.54308 .64172 m .54284 .64429 L .54537 .64392 L F
0 0 .235 r
.54419 .64276 m .54284 .64429 L .54308 .64172 L F
.54419 .64276 m .54308 .64172 L .5415 .64144 L F
.608 .886 .99 r
.54243 .6404 m .53948 .64132 L .54108 .64209 L F
.852 .417 0 r
.54108 .64136 m .54126 .64167 L .5415 .64144 L F
0 0 .235 r
.5414 .64151 m .5415 .64144 L .54108 .64136 L F
.54419 .64276 m .5415 .64144 L .5414 .64151 L F
.852 .417 0 r
.54126 .64167 m .54284 .64429 L .5415 .64144 L F
.608 .886 .99 r
.54243 .6404 m .54196 .64099 L .54306 .63992 L F
.553 .504 .755 r
.3567 .61813 m .35533 .6215 L .35476 .61975 L F
.266 .689 .966 r
.79358 .47458 m .79671 .47471 L .7967 .47553 L F
0 .448 .755 r
.79671 .47471 m .80001 .47578 L .7967 .47553 L F
.761 .679 .771 r
.32229 .62408 m .32592 .62454 L .32381 .62322 L F
.32229 .62408 m .3238 .6256 L .32592 .62454 L F
0 0 0 r
.32592 .62454 m .32382 .62764 L .32467 .62644 L F
.736 .608 .715 r
.3238 .6256 m .32382 .62764 L .32592 .62454 L F
.3238 .6256 m .32382 .62764 L .32592 .62454 L F
.507 .758 .986 r
.32592 .62454 m .32618 .62269 L .32381 .62322 L F
.32592 .62454 m .32807 .62417 L .32618 .62269 L F
.341 0 .14 r
.32467 .62644 m .32807 .62417 L .32592 .62454 L F
.996 .821 .464 r
.78896 .50442 m .78918 .50868 L .79137 .50602 L F
.51 .469 .747 r
.74433 .50905 m .7455 .50522 L .74317 .50575 L F
.74433 .50905 m .74671 .50867 L .7455 .50522 L F
.384 .178 .472 r
.47778 .65698 m .47989 .6563 L .48006 .65389 L F
.432 .303 .604 r
.47796 .65951 m .47989 .6563 L .47778 .65698 L F
.903 .764 .697 r
.63792 .43943 m .63906 .44215 L .64061 .43955 L F
.617 .369 .519 r
.5449 .64683 m .54472 .64794 L .54208 .64812 L F
.601 .354 .515 r
.54856 .64714 m .54472 .64794 L .5449 .64683 L F
.604 .382 .553 r
.5449 .64683 m .54856 .64714 L .54867 .64544 L F
.416 0 .04 r
.3404 .58667 m .3427 .58662 L .34431 .58499 L F
.315 0 0 r
.34431 .58499 m .3427 .58662 L .34595 .58549 L F
.913 .716 .622 r
.59689 .61551 m .59833 .61864 L .59847 .61629 L F
.798 .636 .681 r
.50842 .68327 m .50462 .68526 L .5046 .68209 L F
.50842 .68327 m .50814 .6858 L .50462 .68526 L F
.475 .346 .625 r
.51019 .68489 m .50814 .6858 L .50842 .68327 L F
.51019 .68489 m .50814 .6858 L .50842 .68327 L F
.11 .279 .755 r
.775 .51463 m .77628 .51809 L .77614 .51627 L F
.354 .615 .949 r
.77628 .51809 m .77777 .51686 L .77614 .51627 L F
.77628 .51809 m .77908 .51878 L .77777 .51686 L F
.117 0 0 r
.46793 .66616 m .46491 .66814 L .467 .66731 L F
.621 .386 .54 r
.467 .66731 m .46997 .66529 L .46793 .66616 L F
.138 0 0 r
.37393 .59577 m .37217 .59716 L .37 .59761 L F
.273 0 0 r
.3761 .59535 m .37217 .59716 L .37393 .59577 L F
.498 .477 .765 r
.43796 .59904 m .44005 .59875 L .43906 .59517 L F
.652 .629 .814 r
.43833 .60158 m .44005 .59875 L .43796 .59904 L F
.841 .772 .786 r
.45871 .68753 m .46266 .68531 L .45991 .68583 L F
0 0 0 r
.3803 .62491 m .37687 .62528 L .37835 .62514 L F
.107 0 0 r
.38089 .62527 m .3803 .62491 L .37835 .62514 L F
.38089 .62527 m .3826 .62488 L .3803 .62491 L F
.5 .84 .997 r
.58396 .62227 m .58723 .6215 L .58808 .62225 L F
.889 .506 .048 r
.58808 .62225 m .58723 .6215 L .58639 .61909 L F
.652 .629 .814 r
.43833 .60158 m .44165 .60214 L .44005 .59875 L F
.445 .218 .474 r
.53542 .68584 m .53544 .68804 L .533 .68866 L F
.673 .436 .554 r
.53791 .68571 m .53544 .68804 L .53542 .68584 L F
.971 .691 .444 r
.53162 .66846 m .53034 .67009 L .53006 .66739 L F
.715 .464 .545 r
.4654 .70222 m .4686 .70102 L .46774 .69938 L F
.4654 .70222 m .46952 .7032 L .4686 .70102 L F
.446 .204 .453 r
.533 .68866 m .53275 .69094 L .53046 .6915 L F
.504 .285 .515 r
.53544 .68804 m .53275 .69094 L .533 .68866 L F
.773 .277 0 r
.56346 .62835 m .56288 .62647 L .56165 .62661 L F
.56346 .62835 m .56441 .62879 L .56288 .62647 L F
.452 .412 .722 r
.32046 .61408 m .32151 .60993 L .3198 .61038 L F
.32046 .61408 m .32231 .61396 L .32151 .60993 L F
.381 .357 .708 r
.3213 .61535 m .32231 .61396 L .32046 .61408 L F
0 .31 .694 r
.56 .6257 m .56165 .62661 L .55831 .62504 L F
0 .218 .665 r
.5583 .63337 m .55759 .63273 L .55407 .63044 L F
.702 .176 0 r
.5583 .63337 m .55767 .63341 L .55759 .63273 L F
.5583 .63337 m .55854 .63392 L .55767 .63341 L F
.398 .258 .571 r
.21698 .60096 m .2152 .60403 L .21585 .60202 L F
.645 .419 .562 r
.49248 .67117 m .49524 .67099 L .49523 .66858 L F
.697 .462 .563 r
.49523 .66858 m .49836 .67095 L .49837 .66842 L F
.49523 .66858 m .49524 .67099 L .49836 .67095 L F
.275 .723 .96 r
.54108 .64209 m .53948 .64132 L .53718 .64132 L F
.276 .424 .83 r
.5368 .65344 m .53383 .651 L .53613 .6505 L F
.38 0 .152 r
.53383 .651 m .53506 .6527 L .53613 .6505 L F
.53383 .651 m .53271 .65316 L .53506 .6527 L F
.781 .473 .467 r
.5205 .64487 m .51878 .64897 L .51735 .64453 L F
.066 0 .126 r
.52183 .64524 m .5205 .64487 L .52266 .64468 L F
.52183 .64524 m .51878 .64897 L .5205 .64487 L F
0 0 0 r
.46266 .68531 m .46337 .68473 L .46536 .68294 L F
.575 .596 .836 r
.46536 .68294 m .46627 .6792 L .46417 .67948 L F
.46536 .68294 m .46764 .68249 L .46627 .6792 L F
.218 0 0 r
.46337 .68473 m .46764 .68249 L .46536 .68294 L F
.616 .245 .318 r
.51086 .63541 m .51241 .63309 L .50861 .63363 L F
.532 .112 .19 r
.51086 .63541 m .51445 .63367 L .51241 .63309 L F
.486 .83 .998 r
.5401 .67993 m .54115 .67869 L .54382 .67914 L F
.582 .514 .744 r
.53952 .6818 m .54115 .67869 L .5401 .67993 L F
.258 .007 .329 r
.54771 .67165 m .54714 .67371 L .54948 .67076 L F
.332 0 .167 r
.50726 .70031 m .51143 .69705 L .50713 .69712 L F
.50726 .70031 m .5094 .69988 L .51143 .69705 L F
.354 .333 .696 r
.51345 .69983 m .51143 .69705 L .51331 .699 L F
.636 .293 .373 r
.51143 .69705 m .5094 .69988 L .51331 .699 L F
.225 0 .111 r
.47328 .66225 m .47443 .6633 L .47577 .6621 L F
.47328 .66225 m .47198 .66446 L .47443 .6633 L F
.398 0 .041 r
.40821 .63027 m .40784 .63107 L .40549 .63113 L F
.198 0 0 r
.40821 .63027 m .40996 .63034 L .40784 .63107 L F
.775 .879 .922 r
.63428 .43201 m .63051 .4329 L .63314 .43178 L F
.563 .361 .565 r
.6363 .4312 m .63657 .43073 L .63428 .43201 L F
.6363 .4312 m .63428 .43201 L .63314 .43178 L F
.874 .575 .48 r
.60604 .63888 m .60904 .64184 L .60934 .63931 L F
.338 0 .191 r
.36247 .59945 m .36185 .60085 L .35973 .60141 L F
.36398 .6002 m .36247 .59945 L .36513 .59859 L F
.36398 .6002 m .36185 .60085 L .36247 .59945 L F
.599 .19 .238 r
.55129 .62235 m .55358 .6239 L .55508 .62188 L F
.426 .828 .979 r
.55358 .6239 m .55723 .62392 L .55508 .62188 L F
.687 .475 .594 r
.48674 .70004 m .4829 .7019 L .48428 .69878 L F
.852 .518 .42 r
.4631 .70308 m .46554 .70495 L .46742 .70574 L F
.979 .748 .518 r
.4674 .70928 m .46742 .70574 L .46554 .70495 L F
.669 .617 .788 r
.4654 .70222 m .46742 .70574 L .46952 .7032 L F
.639 .965 .834 r
.49823 .66177 m .49759 .66286 L .49858 .66161 L F
.359 .695 .983 r
.49589 .66161 m .49759 .66286 L .49823 .66177 L F
.49589 .66161 m .49759 .66286 L .49823 .66177 L F
.521 .435 .7 r
.31844 .60452 m .32097 .60751 L .3206 .60401 L F
.31844 .60452 m .31899 .60814 L .32097 .60751 L F
.833 .742 .763 r
.54208 .64812 m .53969 .6514 L .5386 .64887 L F
.751 .512 .57 r
.54561 .65085 m .54211 .65092 L .54208 .64812 L F
.833 .742 .763 r
.54208 .64812 m .5386 .64887 L .5422 .64957 L F
.826 .718 .745 r
.54419 .64276 m .54369 .64351 L .54284 .64429 L F
.358 .46 .828 r
.54208 .64812 m .54284 .64429 L .54146 .64555 L F
.54208 .64812 m .54375 .64687 L .54284 .64429 L F
.464 .309 .585 r
.54375 .64687 m .54537 .64392 L .54284 .64429 L F
.358 .46 .828 r
.54146 .64555 m .54284 .64429 L .54125 .64471 L F
.829 .492 .418 r
.54108 .64136 m .54278 .64461 L .53899 .64278 L F
.334 0 .119 r
.54284 .64429 m .54215 .64581 L .54292 .64486 L F
.829 .492 .418 r
.54278 .64461 m .54292 .64486 L .54271 .64475 L F
.54278 .64461 m .54271 .64475 L .53899 .64278 L F
.852 .417 0 r
.54108 .64136 m .54278 .64461 L .54284 .64429 L F
.54278 .64461 m .54292 .64486 L .54284 .64429 L F
.826 .718 .745 r
.54303 .64412 m .54279 .64458 L .54284 .64429 L F
.54279 .64458 m .54215 .64581 L .54284 .64429 L F
.828 .528 .482 r
.54271 .64475 m .5404 .64526 L .53899 .64278 L F
.54292 .64486 m .54263 .6449 L .54271 .64475 L F
.54263 .6449 m .5404 .64526 L .54271 .64475 L F
.826 .718 .745 r
.54369 .64351 m .54229 .6456 L .54271 .64475 L F
.54307 .64408 m .54271 .64475 L .54303 .64412 L F
.54369 .64351 m .54271 .64475 L .54307 .64408 L F
.828 .528 .482 r
.54263 .6449 m .54215 .64581 L .5404 .64526 L F
.54292 .64486 m .54215 .64581 L .54263 .6449 L F
.826 .718 .745 r
.54271 .64475 m .54215 .64581 L .54303 .64412 L F
.54229 .6456 m .54215 .64581 L .54271 .64475 L F
.751 .512 .57 r
.54561 .65085 m .54208 .64812 L .54472 .64794 L F
.479 0 0 r
.54561 .65085 m .54458 .65156 L .54408 .65088 L F
.661 .555 .723 r
.54856 .64714 m .54561 .65085 L .54472 .64794 L F
.13 .169 .635 r
.54375 .64687 m .54419 .65132 L .54557 .64857 L F
.54419 .65132 m .5442 .6514 L .54422 .65134 L F
.479 0 0 r
.54444 .65166 m .54419 .65133 L .54408 .65088 L F
.13 .169 .635 r
.54419 .65132 m .54422 .65134 L .54557 .64857 L F
.479 0 0 r
.54458 .65156 m .54445 .65166 L .54431 .6514 L F
.54445 .65166 m .54442 .65162 L .54431 .6514 L F
.54458 .65156 m .54431 .6514 L .54408 .65088 L F
.373 .367 .723 r
.54459 .65187 m .54557 .64857 L .54422 .65134 L F
.54459 .65187 m .54422 .65134 L .5442 .6514 L F
.479 0 0 r
.54445 .65166 m .54444 .65166 L .54442 .65162 L F
0 0 0 r
.54419 .65133 m .54459 .65187 L .5442 .6514 L F
.479 0 0 r
.54444 .65166 m .5443 .65176 L .54419 .65133 L F
0 0 0 r
.54405 .64919 m .54459 .65187 L .54419 .65133 L F
0 0 .164 r
.54405 .64919 m .54419 .65133 L .54375 .64687 L F
.54419 .65133 m .5442 .6514 L .54419 .65132 L F
.54419 .65133 m .54419 .65132 L .54375 .64687 L F
.479 0 0 r
.54561 .65085 m .54459 .65187 L .5443 .65176 L F
.54408 .65088 m .5443 .65176 L .54211 .65092 L F
0 0 .164 r
.54405 .64919 m .54208 .64812 L .5422 .64957 L F
.54405 .64919 m .54375 .64687 L .54208 .64812 L F
.128 0 0 r
.54829 .67875 m .54889 .67772 L .551 .67686 L F
.424 .371 .695 r
.3198 .61038 m .32097 .60751 L .31899 .60814 L F
.3198 .61038 m .32151 .60993 L .32097 .60751 L F
.253 0 0 r
.43431 .61499 m .43824 .6132 L .43496 .6134 L F
.265 0 .162 r
.45292 .6825 m .45426 .68232 L .45541 .67989 L F
.487 .304 .558 r
.45541 .67989 m .45828 .67991 L .45845 .67693 L F
.703 .425 .501 r
.45541 .67989 m .45779 .68204 L .45828 .67991 L F
.45541 .67989 m .45426 .68232 L .45779 .68204 L F
.769 .571 .631 r
.60117 .63025 m .60583 .62793 L .60309 .62765 L F
.60117 .63025 m .60506 .63093 L .60583 .62793 L F
.587 .388 .578 r
.60583 .62793 m .60506 .63093 L .60703 .62772 L F
.553 .504 .755 r
.3567 .61813 m .3576 .62128 L .35533 .6215 L F
.213 .283 .72 r
.7897 .50175 m .78817 .50409 L .78718 .50215 L F
.818 .675 .704 r
.3238 .6256 m .32382 .62764 L .32229 .62408 L F
.13 .185 .653 r
.32382 .62764 m .32552 .6298 L .32467 .62644 L F
.297 .234 .616 r
.32382 .62764 m .32378 .63269 L .32552 .6298 L F
.363 0 0 r
.3499 .63895 m .35321 .6394 L .35182 .63944 L F
.181 .706 .866 r
.35321 .6394 m .35399 .63904 L .35182 .63944 L F
.35321 .6394 m .35537 .63928 L .35399 .63904 L F
0 0 0 r
.5323 .65654 m .5276 .65842 L .52928 .65881 L F
.923 .975 .717 r
.5316 .65503 m .5323 .65654 L .52928 .65881 L F
0 .194 .714 r
.80534 .48471 m .80741 .48815 L .80529 .48637 L F
.576 .22 .327 r
.5024 .7029 m .49875 .70519 L .49994 .7031 L F
.154 0 0 r
.79042 .47512 m .79358 .47458 L .79112 .47584 L F
.274 .565 .934 r
.43807 .59551 m .43776 .59381 L .4351 .59374 L F
.43807 .59551 m .43906 .59517 L .43776 .59381 L F
.969 .934 .667 r
.60898 .65884 m .60767 .66186 L .60852 .66238 L F
.428 .282 .579 r
.21271 .6126 m .21142 .61096 L .21293 .61009 L F
.21271 .6126 m .21119 .61332 L .21142 .61096 L F
.604 .041 0 r
.4776 .69953 m .47602 .699 L .47587 .69843 L F
.938 .923 .769 r
.4776 .69953 m .47379 .70228 L .47602 .699 L F
.4776 .69953 m .47535 .70328 L .47379 .70228 L F
.716 .564 .682 r
.47865 .7031 m .47535 .70328 L .4776 .69953 L F
.591 .435 .638 r
.47602 .699 m .4791 .70093 L .47831 .69856 L F
.47602 .699 m .47612 .70141 L .4791 .70093 L F
0 0 0 r
.47831 .69856 m .47623 .69941 L .47602 .699 L F
.47623 .69941 m .47613 .69942 L .47602 .699 L F
.604 .041 0 r
.47587 .69843 m .47602 .699 L .47381 .69713 L F
.659 .105 0 r
.47381 .69713 m .47602 .699 L .47315 .69767 L F
.764 .49 .519 r
.4767 .69411 m .47638 .69644 L .48064 .69647 L F
.263 0 0 r
.47381 .69713 m .47338 .69748 L .47028 .69725 L F
.744 .676 .785 r
.47106 .69376 m .47297 .69749 L .47633 .69506 L F
.47297 .69749 m .47305 .69764 L .47325 .69749 L F
.47297 .69749 m .47325 .69749 L .47633 .69506 L F
.507 .562 .846 r
.47028 .69725 m .47305 .69764 L .47297 .69749 L F
.47028 .69725 m .47297 .69749 L .47106 .69376 L F
.114 0 0 r
.47315 .69767 m .47305 .69764 L .47028 .69725 L F
.263 0 0 r
.47297 .69749 m .47315 .69767 L .47204 .69751 L F
.47338 .69748 m .47333 .69752 L .47297 .69749 L F
.47333 .69752 m .47315 .69767 L .47323 .69751 L F
.693 .48 .593 r
.47315 .69767 m .47633 .69506 L .47325 .69749 L F
.47315 .69767 m .47325 .69749 L .47305 .69764 L F
.263 0 0 r
.47323 .69751 m .47315 .69767 L .47297 .69749 L F
.47338 .69748 m .47204 .69751 L .47028 .69725 L F
.824 .404 .243 r
.47602 .699 m .47466 .70005 L .47315 .69767 L F
.693 .48 .593 r
.47315 .69767 m .47556 .69956 L .47633 .69506 L F
.47563 .69961 m .47588 .69981 L .4759 .69951 L F
.432 .253 .537 r
.47623 .69941 m .47588 .69981 L .47671 .69935 L F
.47591 .69945 m .4759 .69951 L .47623 .69941 L F
.4759 .69951 m .47588 .69981 L .47623 .69941 L F
.772 .405 .361 r
.47556 .69956 m .47466 .70005 L .47588 .69981 L F
0 0 0 r
.47545 .69962 m .47466 .70005 L .47509 .69971 L F
.772 .405 .361 r
.47315 .69767 m .47466 .70005 L .47556 .69956 L F
0 0 0 r
.47613 .69945 m .47466 .70005 L .47545 .69962 L F
.47623 .69941 m .47648 .69937 L .47466 .70005 L F
.47693 .69912 m .47698 .69918 L .47623 .69941 L F
.716 .346 .347 r
.47638 .69644 m .47831 .69856 L .48064 .69647 L F
.129 .259 .73 r
.477 .69567 m .47831 .69856 L .47638 .69644 L F
.4773 .69527 m .47756 .69611 L .477 .69567 L F
.47756 .69611 m .47831 .69856 L .477 .69567 L F
0 0 .161 r
.47677 .6957 m .47638 .69644 L .47655 .69523 L F
.432 .253 .537 r
.47642 .69521 m .47621 .69933 L .47692 .69603 L F
.47633 .69506 m .47633 .69514 L .47642 .69521 L F
.47633 .69514 m .47621 .69933 L .47642 .69521 L F
0 .113 .649 r
.4773 .69527 m .47929 .69774 L .47831 .69856 L F
.432 .253 .537 r
.47591 .69945 m .47671 .69935 L .47838 .69843 L F
0 0 0 r
.47623 .69941 m .47613 .69945 L .47613 .69942 L F
.129 0 0 r
.47466 .70005 m .47838 .69843 L .47707 .69915 L F
.47466 .70005 m .47707 .69915 L .47588 .69981 L F
0 0 0 r
.47648 .69937 m .47708 .69928 L .47466 .70005 L F
.47698 .69918 m .47708 .69928 L .47623 .69941 L F
.47831 .69856 m .4781 .69868 L .47693 .69912 L F
.4781 .69868 m .47708 .69928 L .47693 .69912 L F
.693 .48 .593 r
.47556 .69956 m .47563 .69961 L .47591 .69945 L F
.47563 .69961 m .4759 .69951 L .47591 .69945 L F
0 0 0 r
.47612 .69938 m .47509 .69971 L .47602 .699 L F
.693 .48 .593 r
.47556 .69956 m .47591 .69945 L .47633 .69506 L F
0 0 0 r
.47613 .69945 m .47509 .69971 L .47612 .69938 L F
.432 .253 .537 r
.47633 .69506 m .47692 .69603 L .47565 .69442 L F
.47692 .69603 m .47621 .69933 L .47838 .69843 L F
.47692 .69603 m .47838 .69843 L .47728 .69681 L F
0 0 .161 r
.477 .69567 m .47638 .69644 L .47715 .69497 L F
.432 .253 .537 r
.47633 .69506 m .47591 .69945 L .47621 .69933 L F
.744 .676 .785 r
.47106 .69376 m .47633 .69506 L .47442 .6944 L F
.432 .253 .537 r
.47692 .69603 m .47728 .69681 L .47565 .69442 L F
0 0 .161 r
.47715 .69497 m .47677 .6957 L .4767 .69411 L F
.47677 .6957 m .47655 .69523 L .4767 .69411 L F
.4773 .69527 m .477 .69567 L .47715 .69497 L F
.099 0 0 r
.23345 .56136 m .23162 .56267 L .22945 .56314 L F
.685 .224 .151 r
.23546 .56317 m .23162 .56267 L .23345 .56136 L F
.638 .515 .698 r
.23548 .55843 m .236 .56121 L .23345 .56136 L F
.586 .283 .422 r
.236 .56121 m .23546 .56317 L .23345 .56136 L F
.898 .888 .813 r
.27342 .88274 m .27122 .88615 L .26946 .88542 L F
.487 .709 .968 r
.27122 .88615 m .27159 .88447 L .26946 .88542 L F
.53 .363 .599 r
.27342 .88274 m .27349 .88599 L .27122 .88615 L F
.487 .709 .968 r
.27122 .88615 m .27349 .88599 L .27159 .88447 L F
.621 .458 .64 r
.50072 .6655 m .49837 .66842 L .50062 .66785 L F
.695 .525 .653 r
.49836 .67095 m .50062 .66785 L .49837 .66842 L F
.932 .936 .581 r
.53946 .6137 m .5393 .61373 L .54066 .611 L F
.527 .806 .997 r
.54166 .60957 m .54313 .61074 L .54066 .611 L F
.683 .448 .56 r
.54137 .61243 m .5393 .61373 L .54066 .611 L F
.527 .806 .997 r
.54166 .60957 m .54313 .61074 L .54066 .611 L F
.268 .767 .886 r
.18666 .54372 m .19052 .54354 L .18734 .54379 L F
.18666 .54372 m .18888 .54347 L .19052 .54354 L F
.273 .749 .935 r
.18888 .54347 m .19249 .54366 L .19052 .54354 L F
.497 .497 .787 r
.35534 .61213 m .35359 .61334 L .35271 .61081 L F
.658 .303 .359 r
.63085 .45984 m .63331 .46171 L .63125 .46159 L F
.643 .316 .402 r
.63085 .45984 m .63333 .46003 L .63331 .46171 L F
.537 .864 .995 r
.31988 .63952 m .32066 .6382 L .32173 .63881 L F
.31988 .63952 m .32066 .6382 L .32173 .63881 L F
.648 .56 .741 r
.4452 .60709 m .4476 .6042 L .44521 .60489 L F
.4452 .60709 m .44859 .60775 L .4476 .6042 L F
.621 .584 .791 r
.4452 .60709 m .44918 .61016 L .44859 .60775 L F
.471 .533 .839 r
.57927 .66532 m .58002 .6621 L .57776 .66217 L F
.57927 .66532 m .58123 .66497 L .58002 .6621 L F
.53 .531 .801 r
.32344 .61681 m .32518 .61983 L .32675 .61865 L F
0 0 0 r
.32518 .61983 m .3233 .62182 L .32675 .61865 L F
.883 .651 .583 r
.47777 .72887 m .47765 .73159 L .48015 .73157 L F
.875 .598 .515 r
.47765 .73159 m .4806 .73437 L .48015 .73157 L F
.905 .966 .65 r
.62174 .45059 m .6239 .44512 L .62308 .44868 L F
.253 0 0 r
.43431 .61499 m .43675 .61454 L .43824 .6132 L F
.22 0 0 r
.43675 .61454 m .44088 .61343 L .43824 .6132 L F
.27 .169 .551 r
.20729 .62407 m .20691 .62674 L .20575 .62784 L F
.289 .066 .392 r
.20691 .62674 m .20502 .63001 L .20575 .62784 L F
.668 .657 .83 r
.25493 .85376 m .25632 .85371 L .25522 .85431 L F
.944 .582 .267 r
.56108 .63647 m .56023 .63763 L .55981 .63561 L F
.56108 .63647 m .56152 .63861 L .56023 .63763 L F
.965 .664 .405 r
.5698 .62976 m .57131 .6307 L .56998 .62775 L F
.975 .728 .499 r
.56976 .63272 m .57131 .6307 L .5698 .62976 L F
.56976 .63272 m .57121 .63351 L .57131 .6307 L F
.55 .398 .627 r
.51464 .72924 m .51753 .7304 L .51604 .72783 L F
.573 .577 .819 r
.51464 .72924 m .51828 .7323 L .51753 .7304 L F
.633 .215 .233 r
.51855 .66565 m .52101 .66763 L .51849 .66781 L F
.573 .499 .734 r
.51849 .66781 m .51943 .66409 L .51855 .66565 L F
.587 .368 .551 r
.44158 .59193 m .44479 .59366 L .44267 .59385 L F
0 .045 .613 r
.51753 .7304 m .51828 .7323 L .51804 .73114 L F
.048 0 0 r
.51828 .7323 m .51839 .73247 L .51804 .73114 L F
.51828 .7323 m .5209 .73226 L .51839 .73247 L F
.664 .602 .775 r
.44859 .60775 m .44918 .61016 L .45117 .60712 L F
.575 .483 .714 r
.44918 .61016 m .45109 .61018 L .45117 .60712 L F
.591 .413 .609 r
.44875 .6126 m .45109 .61018 L .44918 .61016 L F
.382 .161 .449 r
.55338 .67164 m .55324 .67482 L .55135 .67411 L F
.573 .512 .749 r
.55324 .67482 m .551 .67686 L .55135 .67411 L F
.654 .636 .819 r
.77737 .49703 m .77495 .49753 L .77387 .49448 L F
0 0 .032 r
.77303 .49216 m .77294 .49139 L .77238 .49126 L F
.499 .265 .491 r
.53275 .69094 m .53001 .69373 L .53046 .6915 L F
.659 .576 .751 r
.79858 .49083 m .80015 .49397 L .8013 .49379 L F
.089 .349 .819 r
.47607 .70904 m .47852 .71087 L .47767 .71177 L F
.076 .328 .806 r
.47852 .71087 m .48072 .71432 L .47767 .71177 L F
.55 .458 .704 r
.78415 .49993 m .78219 .50324 L .78128 .4998 L F
.78415 .49993 m .78481 .50313 L .78219 .50324 L F
.529 .33 .555 r
.53983 .66784 m .53736 .67088 L .53755 .66839 L F
.381 .357 .708 r
.3213 .61535 m .32296 .61601 L .32231 .61396 L F
.45 .778 .998 r
.4055 .58122 m .40933 .58192 L .40694 .58231 L F
.537 .614 .877 r
.73747 .50505 m .73858 .50185 L .73602 .50259 L F
.73747 .50505 m .7395 .50476 L .73858 .50185 L F
.294 .79 .861 r
.39421 .59178 m .39258 .59176 L .39033 .59224 L F
.15 .693 .793 r
.39647 .59152 m .39258 .59176 L .39421 .59178 L F
.325 .03 .301 r
.46446 .67048 m .467 .66731 L .46491 .66814 L F
.93 .697 .563 r
.60439 .63331 m .6041 .63584 L .60586 .63653 L F
.926 .631 .464 r
.6041 .63584 m .60604 .63888 L .60586 .63653 L F
.077 0 0 r
.38863 .6362 m .38671 .63716 L .38516 .63708 L F
.208 0 0 r
.39082 .63572 m .38671 .63716 L .38863 .6362 L F
.578 .033 0 r
.5785 .65139 m .58124 .65287 L .58074 .65193 L F
.336 .155 .481 r
.52652 .68587 m .52819 .68751 L .52825 .68524 L F
.52652 .68587 m .52638 .68826 L .52819 .68751 L F
.775 .4 .345 r
.56663 .62926 m .5698 .62976 L .56823 .62715 L F
.965 .664 .405 r
.5698 .62976 m .56998 .62775 L .56823 .62715 L F
.621 .136 0 r
.49022 .68656 m .49138 .68482 L .48906 .68501 L F
.49022 .68656 m .49021 .68676 L .49138 .68482 L F
.49022 .68656 m .49154 .68819 L .49021 .68676 L F
.568 0 0 r
.55407 .63044 m .55509 .63175 L .5532 .62968 L F
.55407 .63044 m .55759 .63273 L .55509 .63175 L F
.526 .293 .505 r
.48006 .65389 m .4833 .65469 L .48229 .65342 L F
.48006 .65389 m .47989 .6563 L .4833 .65469 L F
.954 .95 .706 r
.5854 .6182 m .58739 .61662 L .58639 .61909 L F
.5854 .6182 m .58697 .61502 L .58739 .61662 L F
.455 0 0 r
.59842 .66827 m .59685 .67009 L .59682 .66758 L F
.59842 .66827 m .5993 .66967 L .59685 .67009 L F
.437 0 .09 r
.41556 .62887 m .41349 .62803 L .41698 .627 L F
.429 0 .112 r
.41914 .62687 m .41556 .62887 L .41698 .627 L F
.372 .148 .439 r
.52718 .63844 m .52471 .64166 L .52503 .63927 L F
.805 .694 .743 r
.62164 .45709 m .6211 .45997 L .61772 .4589 L F
.509 .253 .462 r
.6211 .45997 m .61903 .46234 L .61772 .4589 L F
.6211 .45997 m .62142 .46192 L .61903 .46234 L F
.708 .599 .732 r
.62501 .45964 m .6211 .45997 L .62164 .45709 L F
.646 .34 .44 r
.62501 .45964 m .62142 .46192 L .6211 .45997 L F
.621 .7 .901 r
.32378 .63269 m .32672 .63271 L .32552 .6298 L F
.075 .181 .672 r
.57139 .65377 m .57336 .65486 L .57049 .65271 L F
.57139 .65377 m .57304 .65582 L .57336 .65486 L F
.737 .495 .563 r
.50773 .68698 m .50462 .68526 L .50814 .6858 L F
.497 .234 .446 r
.51019 .68489 m .50773 .68698 L .50814 .6858 L F
.033 0 0 r
.38238 .59331 m .3805 .59426 L .37828 .59473 L F
0 0 0 r
.38445 .59292 m .3805 .59426 L .38238 .59331 L F
.646 .34 .44 r
.62501 .45964 m .6251 .46145 L .62142 .46192 L F
.707 .389 .436 r
.62501 .45964 m .62733 .4619 L .6251 .46145 L F
.654 .635 .818 r
.74671 .50867 m .74789 .51201 L .75027 .51124 L F
.826 .547 .516 r
.77561 .48797 m .77861 .48852 L .77831 .48563 L F
.128 0 0 r
.48515 .65837 m .48252 .65879 L .48466 .65784 L F
.549 .004 0 r
.56344 .64025 m .56359 .64062 L .56152 .63861 L F
.56344 .64025 m .56495 .64153 L .56359 .64062 L F
.796 .533 .54 r
.59024 .59291 m .59335 .59579 L .5935 .59303 L F
.497 .132 .277 r
.49472 .65857 m .49588 .65611 L .4926 .65725 L F
.475 0 0 r
.49726 .65768 m .49588 .65611 L .49472 .65857 L F
.49726 .65768 m .4982 .65657 L .49588 .65611 L F
.453 .285 .562 r
.32014 .60166 m .32224 .59837 L .32009 .59898 L F
0 0 .414 r
.48292 .67833 m .48168 .67741 L .48065 .676 L F
.77 .366 .285 r
.48168 .67741 m .48237 .67949 L .48543 .67973 L F
0 0 .414 r
.48292 .67833 m .48237 .67949 L .48168 .67741 L F
.783 .332 .176 r
.55812 .68522 m .56016 .68891 L .5579 .68722 L F
.55812 .68522 m .5579 .68722 L .55855 .68495 L F
.711 .534 .649 r
.54226 .66253 m .54271 .66553 L .54005 .66529 L F
.507 .352 .605 r
.54469 .66214 m .54271 .66553 L .54226 .66253 L F
.545 .19 .316 r
.49691 .63862 m .49934 .63853 L .50034 .63651 L F
.553 .198 .32 r
.49934 .63853 m .50257 .63831 L .50034 .63651 L F
.531 .207 .364 r
.50034 .63651 m .50257 .63831 L .50279 .63632 L F
.497 .132 .277 r
.49472 .65857 m .4926 .65725 L .49226 .65897 L F
.996 .821 .464 r
.78896 .50442 m .78845 .5079 L .78916 .50831 L F
0 0 .305 r
.78896 .50442 m .78988 .50657 L .78845 .5079 L F
.569 .918 .962 r
.78845 .5079 m .78988 .50657 L .78769 .50745 L F
.78845 .5079 m .78769 .50745 L .78768 .50745 L F
.996 .821 .464 r
.78916 .50831 m .78845 .5079 L .78918 .50868 L F
.863 .928 .868 r
.80715 .50779 m .80581 .50919 L .80475 .50834 L F
.722 .317 .281 r
.80581 .50919 m .80397 .51047 L .80475 .50834 L F
.404 0 0 r
.52274 .63396 m .52632 .63407 L .52426 .63482 L F
.361 .186 .505 r
.22885 .56944 m .22864 .5719 L .2269 .5723 L F
.341 .243 .596 r
.22864 .5719 m .22699 .57491 L .2269 .5723 L F
.898 .888 .813 r
.27342 .88274 m .26946 .88542 L .27159 .88447 L F
.531 .366 .602 r
.27558 .88244 m .27349 .88599 L .27342 .88274 L F
.764 .555 .614 r
.27159 .88447 m .27558 .88244 L .27342 .88274 L F
.105 0 0 r
.38716 .62418 m .38607 .62397 L .38489 .62451 L F
.38716 .62418 m .38836 .62372 L .38607 .62397 L F
.107 .63 .882 r
.20031 .5439 m .20445 .54452 L .2021 .54419 L F
.628 .68 .88 r
.7395 .50476 m .74064 .50648 L .74317 .50575 L F
.66 .775 .934 r
.44165 .60214 m .44269 .59994 L .44005 .59875 L F
.44165 .60214 m .44399 .60139 L .44269 .59994 L F
.643 .572 .76 r
.44165 .60214 m .44521 .60489 L .44399 .60139 L F
.421 .091 .299 r
.40268 .62159 m .40495 .62111 L .40594 .61855 L F
.437 .103 .3 r
.40495 .62111 m .40815 .61808 L .40594 .61855 L F
.657 .471 .621 r
.46694 .62197 m .4669 .62427 L .46443 .62454 L F
.571 .378 .581 r
.52369 .67402 m .52387 .67706 L .52114 .67719 L F
.453 .289 .568 r
.52582 .67619 m .52369 .67402 L .52574 .67372 L F
.52582 .67619 m .52387 .67706 L .52369 .67402 L F
.34 .191 .529 r
.52229 .69351 m .52426 .69406 L .5239 .69126 L F
0 0 0 r
.52355 .69607 m .5246 .69411 L .52426 .69406 L F
.5246 .69411 m .52534 .69274 L .52426 .69406 L F
0 .444 .811 r
.52325 .6939 m .52426 .69406 L .52229 .69351 L F
.52488 .69457 m .52426 .69406 L .52325 .6939 L F
.159 .686 .868 r
.19445 .54366 m .19695 .54352 L .19949 .54408 L F
.383 0 0 r
.19695 .54352 m .20031 .5439 L .19949 .54408 L F
.101 0 .333 r
.231 .56588 m .22885 .56944 L .22851 .56692 L F
0 .172 .702 r
.50926 .6773 m .51081 .67821 L .51155 .67668 L F
.698 .719 .866 r
.75629 .51119 m .75977 .51168 L .75866 .50857 L F
.676 .702 .867 r
.75866 .50857 m .75977 .51168 L .7624 .51086 L F
.006 0 .207 r
.55574 .69971 m .55636 .6977 L .55761 .69648 L F
.55574 .69971 m .55636 .6977 L .55761 .69648 L F
.373 .475 .835 r
.44003 .58886 m .43864 .59056 L .43835 .58894 L F
.393 .504 .853 r
.44003 .58886 m .44158 .59193 L .43864 .59056 L F
.549 .722 .954 r
.49188 .65074 m .49455 .65166 L .49296 .65222 L F
.047 0 0 r
.49455 .65166 m .49568 .65202 L .49296 .65222 L F
.756 .717 .816 r
.49568 .65202 m .49891 .6525 L .49581 .65465 L F
0 0 0 r
.49625 .65223 m .49568 .65202 L .49581 .65465 L F
.54 0 0 r
.49568 .65202 m .49672 .65109 L .49961 .6524 L F
.756 .717 .816 r
.49568 .65202 m .49961 .6524 L .49891 .6525 L F
0 0 0 r
.49651 .65083 m .49568 .65202 L .49625 .65223 L F
.047 0 0 r
.49455 .65166 m .4946 .65165 L .49568 .65202 L F
.49603 .65127 m .49672 .65109 L .49568 .65202 L F
0 0 0 r
.49651 .65083 m .49541 .65259 L .49568 .65202 L F
.49541 .65259 m .49391 .65497 L .49568 .65202 L F
.047 0 0 r
.4946 .65165 m .49603 .65127 L .49568 .65202 L F
.763 .393 .354 r
.58278 .59181 m .58624 .59243 L .58405 .58987 L F
.741 .424 .445 r
.45861 .62482 m .45515 .62624 L .45504 .62443 L F
.45861 .62482 m .45826 .6264 L .45515 .62624 L F
.51 .204 .384 r
.45861 .62482 m .46081 .62636 L .45826 .6264 L F
.513 .591 .87 r
.4366 .58594 m .43553 .5883 L .43432 .587 L F
.4366 .58594 m .43835 .58894 L .43553 .5883 L F
.434 .602 .916 r
.42344 .58219 m .4225 .58395 L .42101 .58296 L F
.42344 .58219 m .42461 .58401 L .4225 .58395 L F
.817 .731 .77 r
.47029 .71095 m .46805 .71406 L .47179 .71427 L F
.771 .816 .889 r
.46805 .71406 m .46946 .71534 L .47179 .71427 L F
.336 .234 .588 r
.47179 .71427 m .47326 .71122 L .47029 .71095 L F
.532 .33 .552 r
.50768 .64715 m .50603 .64931 L .50411 .64986 L F
.449 .395 .705 r
.50306 .64811 m .50411 .64986 L .50603 .64931 L F
.501 .345 .601 r
.50603 .64931 m .50354 .65099 L .50306 .64811 L F
.22 0 0 r
.43675 .61454 m .43918 .6144 L .44088 .61343 L F
.697 .199 .055 r
.43918 .6144 m .44281 .61531 L .44088 .61343 L F
.586 .264 .391 r
.44088 .61343 m .44281 .61531 L .4443 .61281 L F
.446 .704 .976 r
.41459 .58924 m .41511 .58741 L .41275 .58764 L F
.41459 .58924 m .41672 .589 L .41511 .58741 L F
.801 .748 .804 r
.46606 .71545 m .46731 .71755 L .46946 .71534 L F
.708 .488 .587 r
.46999 .62656 m .4669 .62427 L .47051 .62478 L F
.458 .024 .125 r
.47051 .62478 m .47199 .62586 L .46999 .62656 L F
.47051 .62478 m .47316 .62477 L .47199 .62586 L F
.578 .453 .674 r
.47255 .62189 m .47316 .62477 L .47051 .62478 L F
.721 .427 .479 r
.55837 .68528 m .56079 .68332 L .56127 .68132 L F
.55837 .68528 m .56183 .68536 L .56079 .68332 L F
.443 0 .094 r
.39702 .63359 m .39554 .63544 L .3932 .63545 L F
.313 0 0 r
.39936 .63339 m .39554 .63544 L .39702 .63359 L F
.863 .928 .868 r
.80715 .50779 m .80475 .50834 L .80687 .50568 L F
.807 .849 .881 r
.80967 .50545 m .80715 .50779 L .80687 .50568 L F
.972 .707 .289 r
.57763 .65001 m .5785 .65139 L .57754 .64765 L F
.509 .322 .563 r
.58158 .65045 m .5785 .65139 L .57763 .65001 L F
.58158 .65045 m .58124 .65287 L .5785 .65139 L F
.568 .404 .619 r
.47733 .68886 m .47483 .68821 L .47839 .68841 L F
0 0 0 r
.48053 .68536 m .47906 .68808 L .47839 .68841 L F
.301 .773 .659 r
.47906 .68808 m .47733 .68886 L .47839 .68841 L F
.065 .555 .893 r
.64572 .42728 m .64501 .42735 L .64355 .42639 L F
.57 .807 .989 r
.64715 .42929 m .64501 .42735 L .64572 .42728 L F
.852 .669 .655 r
.19259 .5628 m .19535 .56141 L .19407 .55953 L F
.19259 .5628 m .19474 .56381 L .19535 .56141 L F
.86 .563 .485 r
.55026 .67218 m .55324 .67482 L .55338 .67164 L F
.699 .966 .937 r
.55397 .67001 m .5546 .67102 L .55535 .67064 L F
.543 .261 .436 r
.55194 .66806 m .55397 .67001 L .55535 .67064 L F
.817 .98 .89 r
.56087 .67037 m .55717 .67232 L .56016 .67283 L F
.55717 .67232 m .55663 .67261 L .55768 .67267 L F
.55717 .67232 m .55768 .67267 L .56016 .67283 L F
.293 .465 .86 r
.55663 .67261 m .55558 .671 L .55578 .67295 L F
.55558 .671 m .55538 .67082 L .5558 .67321 L F
.55558 .671 m .55535 .67064 L .55538 .67082 L F
.55588 .67146 m .55397 .67001 L .55535 .67064 L F
.817 .98 .89 r
.56087 .67037 m .56015 .66975 L .55663 .67261 L F
.044 .333 .814 r
.55663 .67261 m .55846 .67535 L .56016 .67283 L F
.568 .827 .464 r
.56015 .66975 m .55766 .67281 L .55663 .67261 L F
.293 .465 .86 r
.55663 .67261 m .55712 .6724 L .55397 .67001 L F
.551 0 0 r
.55417 .67024 m .55712 .6724 L .55515 .67135 L F
.55397 .67001 m .55534 .67105 L .55417 .67024 L F
.55534 .67105 m .55712 .6724 L .55417 .67024 L F
.293 .465 .86 r
.55663 .67261 m .55766 .67281 L .55712 .6724 L F
.55663 .67261 m .55578 .67295 L .5558 .67321 L F
.551 0 0 r
.55712 .6724 m .55766 .67281 L .55741 .67267 L F
.55712 .6724 m .55741 .67267 L .55515 .67135 L F
.55397 .67001 m .55515 .67135 L .55339 .6691 L F
.728 .637 .757 r
.55194 .66806 m .55615 .66841 L .55408 .66484 L F
.543 .261 .436 r
.55194 .66806 m .55535 .67064 L .55615 .66841 L F
.662 .547 .714 r
.55194 .66806 m .55408 .66484 L .55156 .66536 L F
.642 .22 0 r
.55221 .66718 m .55302 .66849 L .55315 .66878 L F
.55302 .66849 m .55397 .67001 L .55315 .66878 L F
.699 .966 .937 r
.55397 .67001 m .55026 .67218 L .55338 .67164 L F
.543 .261 .436 r
.55194 .66806 m .55167 .6708 L .55397 .67001 L F
.68 .602 .762 r
.55167 .6708 m .55026 .67218 L .55397 .67001 L F
.55042 .67122 m .55032 .67181 L .55167 .6708 L F
.55032 .67181 m .55026 .67218 L .55167 .6708 L F
.4 .142 .404 r
.54948 .67076 m .5515 .67092 L .55194 .66806 L F
.5515 .67092 m .55166 .67093 L .55167 .6708 L F
.5515 .67092 m .55167 .6708 L .55194 .66806 L F
.543 .261 .436 r
.55167 .6708 m .55166 .67093 L .55397 .67001 L F
.68 .602 .762 r
.55075 .66931 m .55148 .67086 L .55186 .67073 L F
.4 .142 .404 r
.54948 .67076 m .55194 .66806 L .54944 .66827 L F
.785 .619 .675 r
.55053 .66707 m .55144 .67019 L .55075 .66931 L F
.68 .602 .762 r
.55075 .66931 m .55186 .67073 L .55397 .67001 L F
.785 .619 .675 r
.55144 .67019 m .55166 .67093 L .55075 .66931 L F
.373 .439 .8 r
.55075 .66931 m .55166 .67093 L .5515 .67092 L F
.55075 .66931 m .5515 .67092 L .54948 .67076 L F
.68 .602 .762 r
.55075 .66931 m .55042 .67122 L .55148 .67086 L F
.688 .587 .736 r
.55075 .66931 m .55166 .67093 L .55397 .67001 L F
.551 0 0 r
.55397 .67001 m .55339 .6691 L .55315 .66878 L F
.699 .966 .937 r
.55397 .67001 m .55338 .67164 L .5546 .67102 L F
.971 .806 .621 r
.55535 .67064 m .55397 .67001 L .55455 .66735 L F
.806 .617 .647 r
.55455 .66735 m .55397 .67001 L .55221 .66718 L F
.776 .289 .065 r
.55315 .66878 m .55515 .67135 L .55354 .67076 L F
.55315 .66878 m .55354 .67076 L .55336 .66927 L F
.55315 .66878 m .55336 .66927 L .55318 .66784 L F
.401 .735 .992 r
.20402 .56605 m .20678 .5667 L .20572 .56571 L F
.337 .104 .405 r
.20402 .56605 m .20572 .56571 L .20738 .56685 L F
.701 .445 .534 r
.2021 .56615 m .20333 .56884 L .20402 .56605 L F
.438 .584 .9 r
.20402 .56605 m .20337 .56277 L .20217 .56299 L F
.20402 .56605 m .20572 .56571 L .20337 .56277 L F
.337 .104 .405 r
.20402 .56605 m .20333 .56884 L .20572 .56571 L F
.941 .882 .747 r
.20572 .56571 m .2031 .56666 L .20455 .56462 L F
.20572 .56571 m .20455 .56462 L .20463 .56451 L F
.401 .735 .992 r
.20678 .5667 m .20738 .56685 L .20572 .56571 L F
.756 .544 .609 r
.47865 .7031 m .47555 .70553 L .47535 .70328 L F
.47865 .7031 m .47826 .70596 L .47555 .70553 L F
.702 .493 .602 r
.4804 .70451 m .47865 .7031 L .4812 .70238 L F
.4804 .70451 m .47826 .70596 L .47865 .7031 L F
.978 .689 .398 r
.61083 .65243 m .61187 .65096 L .61089 .65004 L F
.61083 .65243 m .61207 .65333 L .61187 .65096 L F
0 .221 .713 r
.20258 .55807 m .20235 .5574 L .20175 .55703 L F
.035 .521 .881 r
.20258 .55807 m .20394 .55844 L .20235 .5574 L F
.925 .606 .42 r
.58345 .59887 m .58208 .60005 L .58129 .59865 L F
.112 .362 .826 r
.19544 .58138 m .19577 .58018 L .19419 .57927 L F
.034 .014 .5 r
.19506 .58371 m .19577 .58018 L .19544 .58138 L F
.659 .474 .623 r
.45845 .67693 m .46077 .6775 L .45996 .67422 L F
.562 .414 .637 r
.45996 .67422 m .46077 .6775 L .46272 .67625 L F
.45996 .67422 m .46272 .67625 L .46147 .6763 L F
.51 .359 .612 r
.45996 .67422 m .46147 .6763 L .46187 .67126 L F
.116 0 .366 r
.47337 .70956 m .47326 .71122 L .47493 .71025 L F
.403 0 .041 r
.42202 .62539 m .42545 .62446 L .42386 .62619 L F
.498 0 0 r
.42545 .62446 m .42615 .62592 L .42386 .62619 L F
.42545 .62446 m .42761 .62492 L .42615 .62592 L F
.387 .463 .817 r
.49414 .66157 m .49472 .65857 L .49226 .65897 L F
.49414 .66157 m .49589 .66161 L .49472 .65857 L F
0 0 .356 r
.80386 .47899 m .80456 .48254 L .80394 .48019 L F
.536 .094 .146 r
.33686 .63457 m .33353 .63508 L .3327 .63308 L F
.33686 .63457 m .33614 .63537 L .33353 .63508 L F
.619 .172 .166 r
.4973 .67698 m .49634 .67856 L .49366 .67686 L F
.652 .219 .208 r
.49985 .67751 m .49634 .67856 L .4973 .67698 L F
.675 .486 .622 r
.50168 .67612 m .49985 .67751 L .4973 .67698 L F
.764 .49 .519 r
.4767 .69411 m .48064 .69647 L .47973 .69438 L F
.468 .761 .994 r
.26819 .84553 m .2707 .84533 L .26864 .84408 L F
.26819 .84553 m .2707 .84533 L .26864 .84408 L F
.689 .716 .869 r
.75027 .51124 m .75384 .51189 L .75279 .51067 L F
.685 .715 .871 r
.75279 .51067 m .75384 .51189 L .75629 .51119 L F
.409 .234 .53 r
.20933 .62129 m .20729 .62407 L .20756 .62202 L F
.265 0 .162 r
.45292 .6825 m .45288 .68295 L .45426 .68232 L F
.011 0 0 r
.3881 .59283 m .38678 .59289 L .38445 .59292 L F
0 0 0 r
.39033 .59224 m .38678 .59289 L .3881 .59283 L F
.128 0 .333 r
.21948 .59572 m .21896 .59836 L .21773 .59896 L F
.263 .215 .615 r
.21896 .59836 m .21927 .6006 L .21773 .59896 L F
.519 .241 .433 r
.21773 .59896 m .21927 .6006 L .21698 .60096 L F
.21773 .59896 m .21927 .6006 L .21698 .60096 L F
.112 .43 .872 r
.36557 .62333 m .36504 .62439 L .36361 .62242 L F
.22 .566 .938 r
.36557 .62333 m .36692 .62488 L .36504 .62439 L F
.533 .354 .584 r
.47577 .6621 m .4779 .66231 L .47796 .65951 L F
.37 0 0 r
.47443 .6633 m .4779 .66231 L .47577 .6621 L F
0 0 .204 r
.49478 .69702 m .49318 .70058 L .49449 .69928 L F
.985 .801 .574 r
.49318 .70058 m .49526 .70071 L .49449 .69928 L F
.49318 .70058 m .49157 .70016 L .49526 .70071 L F
.49318 .70058 m .49233 .70287 L .49157 .70016 L F
.542 .37 .597 r
.49013 .67112 m .49302 .67373 L .49248 .67117 L F
.49013 .67112 m .4898 .675 L .49302 .67373 L F
.124 0 0 r
.34595 .58549 m .34821 .58508 L .34999 .58398 L F
.139 0 0 r
.34821 .58508 m .35227 .584 L .34999 .58398 L F
.745 .721 .829 r
.47108 .68346 m .47227 .6791 L .46992 .68203 L F
.47108 .68346 m .47392 .68205 L .47227 .6791 L F
.709 .688 .827 r
.5386 .64887 m .53969 .6514 L .53613 .6505 L F
.694 .751 .895 r
.42715 .59353 m .4307 .59407 L .4296 .59281 L F
.596 .657 .881 r
.4307 .59407 m .43198 .59169 L .4296 .59281 L F
.4307 .59407 m .43277 .59381 L .43198 .59169 L F
.852 .518 .42 r
.4631 .70308 m .4637 .70524 L .46554 .70495 L F
.904 .614 .485 r
.46378 .70789 m .46554 .70495 L .4637 .70524 L F
0 0 .359 r
.46479 .70658 m .46378 .70534 L .46376 .70427 L F
.46378 .70534 m .4637 .70524 L .4637 .70516 L F
.46378 .70534 m .4637 .70516 L .46376 .70427 L F
.904 .614 .485 r
.46443 .70681 m .4674 .70928 L .46554 .70495 L F
.46378 .70789 m .46513 .70841 L .46443 .70681 L F
.46513 .70841 m .4674 .70928 L .46443 .70681 L F
.405 .297 .618 r
.22692 .57733 m .22504 .58107 L .22484 .57864 L F
.644 .261 .304 r
.5084 .63526 m .50861 .63363 L .50529 .63362 L F
.621 .241 .301 r
.51086 .63541 m .50861 .63363 L .5084 .63526 L F
.374 .39 .749 r
.73418 .50225 m .73602 .50259 L .73507 .49884 L F
0 0 0 r
.80003 .48851 m .79858 .49083 L .79907 .49027 L F
.589 .606 .837 r
.46283 .60427 m .45927 .60188 L .46229 .60413 L F
.902 .488 .149 r
.54648 .64223 m .54701 .64469 L .54867 .64544 L F
0 .173 .706 r
.54701 .64469 m .54856 .64714 L .54867 .64544 L F
.579 .494 .723 r
.65558 .45082 m .65619 .45364 L .65364 .45419 L F
.417 .063 .255 r
.65619 .45364 m .65326 .45565 L .65364 .45419 L F
.681 .706 .867 r
.76569 .51154 m .76711 .50772 L .76482 .50874 L F
.76569 .51154 m .76855 .5108 L .76711 .50772 L F
.558 .626 .875 r
.42105 .5934 m .42497 .59584 L .42342 .59256 L F
.718 .677 .809 r
.42342 .59256 m .42497 .59584 L .42715 .59353 L F
.34 0 .188 r
.52114 .67719 m .52061 .67921 L .51817 .67937 L F
.21 0 .147 r
.52226 .67856 m .52114 .67719 L .52277 .67812 L F
.52226 .67856 m .52061 .67921 L .52114 .67719 L F
.356 0 0 r
.52387 .67706 m .52277 .67812 L .52114 .67719 L F
.679 .473 .6 r
.64502 .4565 m .64194 .45909 L .6429 .45672 L F
.826 .48 .401 r
.49314 .68852 m .49242 .69059 L .49154 .68819 L F
.957 .664 .437 r
.49396 .69124 m .49314 .68852 L .4958 .68795 L F
.49396 .69124 m .49242 .69059 L .49314 .68852 L F
.608 .349 .499 r
.63333 .46003 m .6378 .46159 L .63331 .46171 L F
.63333 .46003 m .6368 .45925 L .6378 .46159 L F
.409 .287 .601 r
.24383 .74005 m .24244 .73952 L .24539 .74082 L F
.24383 .74005 m .24244 .73952 L .24539 .74082 L F
.716 .385 .418 r
.54308 .64172 m .54537 .64392 L .54648 .64223 L F
.751 .358 .308 r
.54537 .64392 m .54701 .64469 L .54648 .64223 L F
.175 .187 .632 r
.45055 .68599 m .45256 .68722 L .45223 .68475 L F
.45055 .68599 m .45102 .68852 L .45256 .68722 L F
.289 0 0 r
.43934 .62271 m .43852 .62417 L .43647 .62392 L F
0 0 0 r
.44189 .6232 m .43852 .62417 L .43934 .62271 L F
.518 .295 .515 r
.19242 .57205 m .19448 .56966 L .19314 .57111 L F
.525 .808 .998 r
.41375 .58091 m .41295 .58242 L .41154 .58134 L F
.41375 .58091 m .41516 .58191 L .41295 .58242 L F
.75 .83 .914 r
.77788 .4918 m .77766 .49457 L .77655 .49383 L F
.982 .819 .606 r
.77766 .49457 m .77737 .49703 L .77655 .49383 L F
.087 0 .147 r
.53566 .7195 m .53407 .7205 L .53644 .7178 L F
.618 .864 .989 r
.53566 .7195 m .53407 .7205 L .53229 .71955 L F
.232 .023 .377 r
.53566 .7195 m .53357 .72294 L .53407 .7205 L F
.21 0 0 r
.40784 .63107 m .40518 .63182 L .40549 .63113 L F
.477 .313 .579 r
.32224 .59837 m .32451 .59509 L .32238 .59582 L F
.661 .586 .76 r
.44399 .60139 m .44521 .60489 L .4476 .6042 L F
.621 .366 .51 r
.7525 .49423 m .7554 .49606 L .75607 .49459 L F
.661 .413 .534 r
.7554 .49606 m .75843 .49372 L .75607 .49459 L F
.58 .598 .835 r
.58265 .66826 m .58356 .66451 L .58123 .66497 L F
.58265 .66826 m .58501 .6678 L .58356 .66451 L F
.726 .388 .406 r
.51162 .70241 m .51054 .70498 L .5084 .7025 L F
.504 .345 .599 r
.51345 .69983 m .5139 .70245 L .51162 .70241 L F
.529 .18 .319 r
.51373 .70308 m .51162 .70241 L .5139 .70245 L F
.51373 .70308 m .51054 .70498 L .51162 .70241 L F
.805 .694 .743 r
.62164 .45709 m .61772 .4589 L .62004 .45578 L F
.075 .343 .818 r
.5738 .65771 m .57528 .65904 L .57304 .65582 L F
.664 .83 .963 r
.35896 .6417 m .36267 .64164 L .36124 .64084 L F
.346 .623 .955 r
.36267 .64164 m .36361 .64053 L .36124 .64084 L F
.36267 .64164 m .36515 .64227 L .36361 .64053 L F
.281 .773 .898 r
.38048 .58161 m .37951 .58222 L .37809 .5819 L F
.38048 .58161 m .38161 .58193 L .37951 .58222 L F
.727 .934 .956 r
.47379 .70228 m .47535 .70328 L .47321 .70371 L F
.573 .556 .797 r
.47555 .70553 m .47321 .70371 L .47535 .70328 L F
.074 0 .213 r
.63843 .4295 m .63657 .43073 L .6363 .4312 L F
.733 .684 .804 r
.45477 .61009 m .45858 .6104 L .45703 .60708 L F
.818 .539 .517 r
.45477 .61009 m .45826 .6129 L .45858 .6104 L F
.786 .511 .521 r
.46153 .61259 m .45858 .6104 L .45826 .6129 L F
.485 .537 .835 r
.32344 .61681 m .32514 .61519 L .32296 .61601 L F
.32344 .61681 m .32675 .61865 L .32514 .61519 L F
0 .081 .641 r
.45759 .70538 m .45913 .70861 L .45942 .70756 L F
.03 .385 .847 r
.45942 .70756 m .45913 .70861 L .46053 .70897 L F
.165 0 0 r
.38406 .58251 m .38747 .58213 L .38563 .58194 L F
.395 .71 .986 r
.23623 .55722 m .23548 .55843 L .23424 .55704 L F
.23623 .55722 m .23723 .55808 L .23548 .55843 L F
.537 .506 .769 r
.23723 .55808 m .236 .56121 L .23548 .55843 L F
.246 .12 .503 r
.72475 .4874 m .72637 .4874 L .72628 .48503 L F
.345 .285 .646 r
.72475 .4874 m .72704 .48943 L .72637 .4874 L F
.72475 .4874 m .725 .49144 L .72704 .48943 L F
.993 .879 .584 r
.47269 .68992 m .47412 .68791 L .47483 .68821 L F
.47269 .68992 m .47212 .69132 L .47136 .69053 L F
.557 .29 .466 r
.47529 .69075 m .47269 .68992 L .47483 .68821 L F
.47529 .69075 m .47212 .69132 L .47269 .68992 L F
.346 0 .036 r
.53581 .63829 m .53954 .63615 L .53599 .63624 L F
.53581 .63829 m .53825 .63795 L .5394 .63623 L F
.532 .552 .821 r
.53718 .64132 m .53825 .63795 L .53581 .63829 L F
.488 .793 .999 r
.53704 .63697 m .53825 .63795 L .53581 .63829 L F
.532 .552 .821 r
.53718 .64132 m .53948 .64132 L .53825 .63795 L F
.598 .232 .318 r
.53799 .6401 m .53581 .63829 L .53825 .63795 L F
.226 .319 .751 r
.53704 .63697 m .53762 .6389 L .53825 .63795 L F
.53762 .6389 m .53799 .6401 L .53825 .63795 L F
.346 0 .036 r
.5394 .63623 m .53825 .63795 L .53954 .63615 L F
.807 .419 .32 r
.53825 .63795 m .54243 .6404 L .53954 .63615 L F
.803 .515 .502 r
.58217 .6065 m .58287 .60426 L .58104 .60502 L F
.749 .488 .536 r
.58775 .59216 m .58988 .59548 L .59024 .59291 L F
.796 .533 .54 r
.59024 .59291 m .58988 .59548 L .59335 .59579 L F
.673 .436 .554 r
.53791 .68571 m .53784 .68813 L .53544 .68804 L F
.477 .353 .632 r
.54002 .68496 m .53784 .68813 L .53791 .68571 L F
.803 .515 .502 r
.58217 .6065 m .58104 .60502 L .58095 .60678 L F
.539 .394 .631 r
.51604 .72783 m .51753 .7304 L .51938 .72796 L F
.583 .603 .838 r
.48544 .68225 m .48675 .68548 L .48906 .68501 L F
0 0 0 r
.4829 .7019 m .4804 .70451 L .4812 .70238 L F
.53 .153 .269 r
.56859 .59502 m .57215 .59299 L .5703 .59788 L F
.56859 .59502 m .57104 .59524 L .57215 .59299 L F
.561 .185 .285 r
.57104 .59524 m .57422 .5944 L .57215 .59299 L F
.979 .682 .352 r
.54561 .65085 m .54608 .6537 L .54459 .65187 L F
.399 .078 .301 r
.36185 .60085 m .35891 .60372 L .35973 .60141 L F
.659 .108 0 r
.45788 .60168 m .46229 .60413 L .45927 .60188 L F
.434 0 0 r
.37308 .64009 m .36934 .64047 L .37108 .64023 L F
.341 .243 .596 r
.22864 .5719 m .22892 .5747 L .22699 .57491 L F
.105 0 .239 r
.22892 .5747 m .22692 .57733 L .22699 .57491 L F
.718 .352 0 r
.57026 .65057 m .56867 .64712 L .56889 .64869 L F
.461 .469 .78 r
.47392 .68205 m .47484 .67835 L .47227 .6791 L F
.47392 .68205 m .47614 .68271 L .47484 .67835 L F
.592 .351 .52 r
.50258 .67655 m .50168 .67612 L .50226 .67386 L F
.50258 .67655 m .49985 .67751 L .50168 .67612 L F
.965 .726 .525 r
.60993 .64679 m .61143 .64367 L .60985 .64372 L F
.60993 .64679 m .61139 .64758 L .61143 .64367 L F
.653 .701 .882 r
.42856 .58606 m .42461 .58401 L .42664 .58368 L F
.536 .723 .959 r
.42895 .58331 m .42856 .58606 L .42664 .58368 L F
.42895 .58331 m .43139 .58571 L .42856 .58606 L F
.497 .497 .787 r
.35534 .61213 m .35271 .61081 L .35451 .61023 L F
.301 .361 .758 r
.46706 .61425 m .46681 .61607 L .46549 .61598 L F
.664 .973 .887 r
.46706 .61425 m .46549 .61598 L .46681 .61607 L F
.46706 .61425 m .46443 .616 L .46549 .61598 L F
.524 .38 .627 r
.46533 .61826 m .46681 .61607 L .46549 .61598 L F
.786 .582 .624 r
.50309 .69458 m .50373 .69746 L .50713 .69712 L F
.863 .631 .587 r
.5038 .69912 m .50713 .69712 L .50373 .69746 L F
.5038 .69912 m .50726 .70031 L .50713 .69712 L F
.136 0 0 r
.35227 .584 m .35451 .58374 L .35584 .58312 L F
.403 0 0 r
.35584 .58312 m .35451 .58374 L .35814 .58342 L F
.766 .7 .79 r
.47321 .70371 m .47346 .70638 L .47123 .70479 L F
.573 .556 .797 r
.47555 .70553 m .47346 .70638 L .47321 .70371 L F
.749 .612 .706 r
.47555 .70553 m .47263 .7084 L .47346 .70638 L F
.723 .287 .215 r
.63551 .43372 m .6363 .4312 L .63314 .43178 L F
.074 0 .213 r
.63843 .4295 m .6363 .4312 L .63921 .42986 L F
.74 .51 .581 r
.63551 .43372 m .63921 .42986 L .6363 .4312 L F
.541 .397 .635 r
.3566 .60628 m .35451 .61023 L .35482 .60735 L F
.247 0 0 r
.59473 .66809 m .5951 .66826 L .59089 .66766 L F
.715 .791 .912 r
.59682 .66758 m .5951 .66826 L .59473 .66809 L F
.526 .095 .165 r
.52735 .69453 m .52355 .69607 L .52488 .69457 L F
.74 .92 .952 r
.20106 .57462 m .201 .57578 L .20318 .57528 L F
.739 .574 .67 r
.2002 .57807 m .20318 .57528 L .201 .57578 L F
.2002 .57807 m .20312 .57848 L .20318 .57528 L F
.622 .899 .986 r
.20291 .57367 m .20318 .57528 L .20496 .57476 L F
.20291 .57367 m .20106 .57462 L .20318 .57528 L F
.377 .276 .612 r
.20318 .57528 m .20492 .5771 L .20496 .57476 L F
.20318 .57528 m .20312 .57848 L .20492 .5771 L F
.691 .386 .454 r
.4443 .61281 m .44643 .61515 L .44658 .61313 L F
.4443 .61281 m .44281 .61531 L .44643 .61515 L F
.324 0 0 r
.22855 .55477 m .23071 .55575 L .23249 .55645 L F
0 .429 .759 r
.23071 .55575 m .23424 .55704 L .23249 .55645 L F
.628 .41 .568 r
.50632 .7001 m .50535 .70269 L .5024 .7029 L F
.23 .013 .364 r
.50698 .70196 m .50632 .7001 L .50726 .70031 L F
.50698 .70196 m .50535 .70269 L .50632 .7001 L F
.928 .839 .736 r
.59999 .62938 m .60309 .62765 L .59981 .62716 L F
.59999 .62938 m .60117 .63025 L .60309 .62765 L F
.191 0 .016 r
.36622 .59925 m .36513 .59859 L .36759 .598 L F
.36622 .59925 m .36398 .6002 L .36513 .59859 L F
.431 .048 .21 r
.51398 .67651 m .51654 .67616 L .51743 .67402 L F
.231 0 .123 r
.51743 .67402 m .51858 .67533 L .51973 .67318 L F
.51743 .67402 m .51654 .67616 L .51858 .67533 L F
.823 .775 .808 r
.51166 .64808 m .51237 .65083 L .51608 .64589 L F
.566 .402 .618 r
.51474 .65036 m .51237 .65083 L .51608 .64589 L F
.917 .582 .117 r
.58976 .63551 m .58914 .63517 L .58872 .63316 L F
.894 .988 .745 r
.58703 .63825 m .58914 .63517 L .58976 .63551 L F
.695 .525 .653 r
.49836 .67095 m .50176 .671 L .50062 .66785 L F
.674 .514 .661 r
.50062 .66785 m .50176 .671 L .50425 .67058 L F
.623 .185 .188 r
.57399 .64499 m .57665 .64675 L .57766 .64499 L F
.997 .792 .439 r
.57766 .64499 m .57665 .64675 L .57754 .64765 L F
.349 .242 .59 r
.21271 .6126 m .21161 .61566 L .21119 .61332 L F
.766 .422 .403 r
.46443 .62454 m .46695 .62728 L .4631 .6265 L F
.649 .44 .587 r
.4669 .62427 m .46695 .62728 L .46443 .62454 L F
.588 .925 .961 r
.38747 .58213 m .38982 .58133 L .39142 .58146 L F
.03 .578 .835 r
.39205 .58119 m .39142 .58146 L .38982 .58133 L F
.39205 .58119 m .39353 .58175 L .39142 .58146 L F
.78 .682 .756 r
.53566 .7195 m .53445 .71635 L .53644 .7178 L F
.404 .548 .886 r
.53703 .71573 m .53644 .7178 L .53445 .71635 L F
.53703 .71573 m .53724 .71682 L .53644 .7178 L F
0 0 0 r
.53724 .71682 m .53566 .7195 L .53644 .7178 L F
.635 .497 .676 r
.23954 .74064 m .24212 .74131 L .24244 .73952 L F
.23954 .74064 m .24212 .74131 L .24244 .73952 L F
.351 .815 .923 r
.57344 .59879 m .57379 .59822 L .57218 .59843 L F
.57344 .59879 m .57572 .59834 L .57379 .59822 L F
.531 .289 .494 r
.50279 .63632 m .50517 .63594 L .50529 .63362 L F
.644 .261 .304 r
.5084 .63526 m .50529 .63362 L .50517 .63594 L F
0 0 .146 r
.57489 .64299 m .57399 .64499 L .57437 .64226 L F
.668 .346 .419 r
.48303 .68771 m .48053 .68536 L .48216 .68415 L F
.48303 .68771 m .47906 .68808 L .48053 .68536 L F
.418 0 0 r
.58083 .62128 m .58307 .6223 L .58396 .62227 L F
.217 .739 .757 r
.58437 .62202 m .58396 .62227 L .58307 .6223 L F
.58437 .62202 m .58723 .6215 L .58396 .62227 L F
.61 .313 .44 r
.45834 .61528 m .46153 .61259 L .45826 .6129 L F
.45834 .61528 m .4615 .61548 L .46153 .61259 L F
.124 0 .351 r
.46153 .61259 m .4615 .61548 L .46288 .61427 L F
.303 .096 .424 r
.2215 .59267 m .22095 .59511 L .21948 .59572 L F
.335 .112 .419 r
.22061 .59771 m .21948 .59572 L .22095 .59511 L F
.22061 .59771 m .21896 .59836 L .21948 .59572 L F
.195 .459 .881 r
.22566 .54995 m .22545 .5516 L .22325 .54882 L F
.084 .34 .813 r
.22566 .54995 m .2267 .55196 L .22545 .5516 L F
.489 .002 .026 r
.54768 .62353 m .54997 .62373 L .55129 .62235 L F
.616 .146 .114 r
.55129 .62235 m .54997 .62373 L .55358 .6239 L F
.18 0 0 r
.49449 .69928 m .49898 .69684 L .49478 .69702 L F
.518 .295 .515 r
.19242 .57205 m .19471 .56899 L .19448 .56966 L F
.636 .359 .482 r
.44643 .61515 m .44875 .6126 L .44658 .61313 L F
.396 .201 .494 r
.32461 .59276 m .32633 .59434 L .32692 .59187 L F
.32461 .59276 m .32451 .59509 L .32633 .59434 L F
.314 0 0 r
.55651 .67495 m .55537 .6756 L .5558 .67321 L F
.55651 .67495 m .55846 .67535 L .55537 .6756 L F
.393 .808 .976 r
.40823 .58852 m .40889 .58767 L .40672 .5882 L F
.40823 .58852 m .41028 .58825 L .40889 .58767 L F
.853 .785 .784 r
.78704 .51655 m .79061 .5148 L .78798 .5144 L F
.78704 .51655 m .78813 .51826 L .79061 .5148 L F
.623 .444 .618 r
.22305 .58413 m .22313 .58674 L .22055 .58703 L F
.367 .183 .495 r
.22504 .58107 m .2248 .58352 L .22305 .58413 L F
.416 .303 .616 r
.2248 .58352 m .22501 .58617 L .22305 .58413 L F
.448 .307 .596 r
.22305 .58413 m .22501 .58617 L .22313 .58674 L F
.88 .581 .477 r
.55056 .65945 m .55139 .66183 L .54926 .66198 L F
.866 .485 .321 r
.58696 .59395 m .58775 .59216 L .58624 .59243 L F
.58696 .59395 m .58988 .59548 L .58775 .59216 L F
.423 .293 .598 r
.46417 .67948 m .4663 .67654 L .46272 .67625 L F
.46417 .67948 m .46627 .6792 L .4663 .67654 L F
.914 .748 .662 r
.46272 .67625 m .46261 .68021 L .46417 .67948 L F
.532 .112 .19 r
.51086 .63541 m .51355 .63546 L .51445 .63367 L F
.278 0 0 r
.51355 .63546 m .51692 .63383 L .51445 .63367 L F
.892 .602 .489 r
.59335 .59579 m .59336 .59811 L .59519 .5986 L F
.954 .651 .422 r
.59397 .60013 m .59519 .5986 L .59336 .59811 L F
.59397 .60013 m .59545 .60118 L .59519 .5986 L F
.432 .303 .604 r
.47796 .65951 m .48009 .65926 L .47989 .6563 L F
.15 .144 .595 r
.45102 .68852 m .45266 .69028 L .45256 .68722 L F
.45102 .68852 m .45157 .69103 L .45266 .69028 L F
.677 .718 .88 r
.78449 .52078 m .78529 .52015 L .78253 .52015 L F
.705 .196 .022 r
.19056 .56002 m .19119 .56062 L .18942 .56018 L F
.403 0 .041 r
.42202 .62539 m .42386 .62619 L .42155 .62647 L F
.913 .716 .622 r
.59689 .61551 m .59579 .61841 L .59833 .61864 L F
.883 .724 .681 r
.59498 .62065 m .59833 .61864 L .59579 .61841 L F
.59498 .62065 m .59676 .62126 L .59833 .61864 L F
.657 .565 .74 r
.4476 .6042 m .44859 .60775 L .45117 .60712 L F
.691 .695 .849 r
.32552 .6298 m .32672 .63271 L .32943 .63081 L F
.537 .506 .769 r
.23723 .55808 m .23835 .56065 L .236 .56121 L F
.241 0 .287 r
.23735 .56208 m .236 .56121 L .23835 .56065 L F
.23735 .56208 m .23546 .56317 L .236 .56121 L F
.532 0 0 r
.54293 .62467 m .54117 .62466 L .53939 .624 L F
.474 0 0 r
.54293 .62467 m .54396 .62574 L .54117 .62466 L F
.54293 .62467 m .54552 .62593 L .54396 .62574 L F
0 .542 .769 r
.21 .54572 m .21385 .54635 L .21174 .54654 L F
.069 .632 .734 r
.37835 .62514 m .37687 .62528 L .37509 .62532 L F
.095 0 0 r
.78801 .5192 m .78529 .52015 L .78844 .51835 L F
.445 .066 .225 r
.39642 .62357 m .39444 .62306 L .39428 .62332 L F
.39642 .62357 m .39667 .62259 L .39444 .62306 L F
.654 .636 .819 r
.77737 .49703 m .77387 .49448 L .77655 .49383 L F
.312 .559 .924 r
.34118 .63281 m .3433 .63232 L .34038 .63215 L F
.34118 .63281 m .34361 .63343 L .3433 .63232 L F
.432 .023 .161 r
.41301 .62925 m .41349 .62803 L .41556 .62887 L F
.647 .461 .618 r
.51271 .66778 m .51022 .67077 L .51007 .66832 L F
0 0 .366 r
.51007 .66832 m .51108 .6692 L .51271 .66778 L F
.51007 .66832 m .51022 .67077 L .51108 .6692 L F
.555 0 0 r
.46579 .68992 m .46863 .6914 L .46678 .69016 L F
.571 .78 .978 r
.80024 .51787 m .80185 .51596 L .7993 .51647 L F
.80024 .51787 m .80298 .51725 L .80185 .51596 L F
.487 .505 .802 r
.725 .49144 m .728 .49281 L .72704 .48943 L F
.509 .509 .792 r
.54183 .661 m .54325 .6586 L .54094 .65892 L F
.54183 .661 m .54579 .66076 L .54325 .6586 L F
.507 .352 .605 r
.54469 .66214 m .54516 .66489 L .54271 .66553 L F
.249 .176 .575 r
.54644 .66362 m .54469 .66214 L .54519 .66212 L F
.54644 .66362 m .54519 .66212 L .54721 .66203 L F
.447 .092 .268 r
.54926 .66198 m .54644 .66362 L .54721 .66203 L F
.769 .655 .737 r
.54758 .66167 m .54644 .66362 L .54926 .66198 L F
.54567 .66132 m .54605 .66246 L .54758 .66167 L F
.54605 .66246 m .54644 .66362 L .54758 .66167 L F
.249 .176 .575 r
.54644 .66362 m .54516 .66489 L .54469 .66214 L F
0 0 .447 r
.54636 .66278 m .54644 .66362 L .54626 .66308 L F
.54636 .66278 m .54626 .66308 L .54567 .66132 L F
.457 .059 .197 r
.54224 .66538 m .54636 .66278 L .54548 .66276 L F
.251 .186 .585 r
.54522 .66275 m .54636 .66278 L .54567 .66132 L F
.462 .201 .431 r
.54516 .66489 m .54227 .66757 L .54271 .66553 L F
.54516 .66489 m .54458 .66705 L .54227 .66757 L F
.457 .059 .197 r
.54224 .66538 m .5445 .66626 L .54636 .66278 L F
.682 .812 .362 r
.54636 .66278 m .5445 .66626 L .54659 .66209 L F
.54636 .66278 m .54659 .66209 L .54674 .6618 L F
.457 .059 .197 r
.54483 .6631 m .54548 .66276 L .54522 .66275 L F
.54224 .66538 m .54548 .66276 L .54483 .6631 L F
0 0 .349 r
.54636 .66278 m .54711 .66442 L .54644 .66362 L F
.54711 .66442 m .54772 .66574 L .54644 .66362 L F
.567 .165 .24 r
.54183 .661 m .54522 .66275 L .54579 .66076 L F
.54183 .661 m .54016 .6639 L .54522 .66275 L F
.94 .803 .683 r
.33081 .62999 m .33165 .63093 L .33142 .62719 L F
.366 .365 .726 r
.33142 .62719 m .33165 .63093 L .33393 .6295 L F
0 .05 .601 r
.33165 .63093 m .33321 .6314 L .33393 .6295 L F
.33165 .63093 m .3327 .63308 L .33321 .6314 L F
.999 .809 .516 r
.55846 .67535 m .55922 .67887 L .56 .67667 L F
.55846 .67535 m .55922 .67887 L .56 .67667 L F
.251 .696 .958 r
.37273 .62537 m .37072 .6256 L .36916 .62475 L F
.707 .696 .838 r
.41771 .59258 m .42105 .5934 L .41954 .59117 L F
.619 .662 .871 r
.41954 .59117 m .42105 .5934 L .42342 .59256 L F
.594 .117 .093 r
.53357 .72294 m .53084 .72311 L .53132 .72379 L F
.14 .406 .853 r
.54987 .64835 m .55218 .64946 L .5516 .65075 L F
0 0 .465 r
.55218 .64946 m .5521 .65281 L .5516 .65075 L F
.546 .156 .255 r
.40028 .62152 m .39642 .62357 L .39873 .62292 L F
.40028 .62152 m .39667 .62259 L .39642 .62357 L F
.26 0 0 r
.39873 .62292 m .40268 .62159 L .40028 .62152 L F
.788 .302 .06 r
.58988 .59548 m .59336 .59811 L .59335 .59579 L F
.666 .371 .463 r
.49248 .67117 m .49487 .67339 L .49524 .67099 L F
.49248 .67117 m .49302 .67373 L .49487 .67339 L F
.994 .753 .41 r
.47514 .73194 m .47409 .73103 L .47413 .72852 L F
.751 .934 .591 r
.47514 .73194 m .4736 .73345 L .47409 .73103 L F
.47514 .73194 m .47311 .73473 L .4736 .73345 L F
.874 .575 .48 r
.60604 .63888 m .60627 .6412 L .60904 .64184 L F
.814 .388 .231 r
.60627 .6412 m .60985 .64372 L .60904 .64184 L F
.261 .053 .396 r
.21486 .60674 m .21507 .60914 L .21293 .61009 L F
.239 .108 .493 r
.21695 .6036 m .21486 .60674 L .2152 .60403 L F
.21695 .6036 m .21691 .6061 L .21486 .60674 L F
.165 0 .357 r
.21691 .6061 m .21507 .60914 L .21486 .60674 L F
.592 .371 .55 r
.4982 .65657 m .50097 .65628 L .50129 .65372 L F
.432 .463 .792 r
.50129 .65372 m .5028 .65297 L .50067 .65178 L F
.396 .201 .496 r
.50129 .65372 m .50273 .65559 L .5028 .65297 L F
.50129 .65372 m .50097 .65628 L .50273 .65559 L F
.342 0 .09 r
.40437 .58869 m .40107 .59054 L .40228 .58898 L F
.938 .962 .675 r
.48636 .69908 m .48789 .69763 L .48575 .69669 L F
.48636 .69908 m .48674 .70004 L .48789 .69763 L F
.33 .711 .983 r
.22164 .54781 m .22132 .54889 L .21936 .54683 L F
.22164 .54781 m .22325 .54882 L .22132 .54889 L F
.687 .475 .594 r
.48674 .70004 m .48682 .70252 L .4829 .7019 L F
.901 .688 .179 r
.48634 .70124 m .48674 .70004 L .48636 .69908 L F
.749 .322 .236 r
.48457 .70049 m .48603 .70141 L .48634 .70124 L F
.901 .688 .179 r
.48634 .70124 m .48682 .70252 L .48677 .701 L F
.531 .306 .519 r
.48918 .70217 m .48678 .70497 L .48682 .70252 L F
.749 .322 .236 r
.48603 .70141 m .48799 .70265 L .48634 .70124 L F
.901 .688 .179 r
.48634 .70124 m .48677 .701 L .48674 .70004 L F
.45 .164 .387 r
.48936 .64727 m .49209 .64465 L .49011 .64551 L F
.549 .621 .877 r
.45317 .5951 m .45271 .59899 L .45077 .59558 L F
.45317 .5951 m .45501 .59854 L .45271 .59899 L F
.246 0 .12 r
.45417 .59938 m .45271 .59899 L .45501 .59854 L F
.45417 .59938 m .4519 .6004 L .45271 .59899 L F
.59 .685 .908 r
.36361 .62242 m .36129 .62325 L .35974 .62097 L F
.13 .214 .684 r
.19355 .56614 m .19259 .5628 L .19346 .56381 L F
.652 .219 .208 r
.49985 .67751 m .49835 .67922 L .49634 .67856 L F
.483 .027 .091 r
.50177 .67857 m .49835 .67922 L .49985 .67751 L F
.449 .086 .256 r
.50258 .67655 m .50177 .67857 L .49985 .67751 L F
.576 .931 .764 r
.53946 .6137 m .5393 .61373 L .54137 .61243 L F
.264 .38 .794 r
.52376 .66486 m .52083 .66235 L .52315 .66188 L F
.712 .519 .626 r
.51943 .66409 m .52315 .66188 L .52083 .66235 L F
.681 .774 .921 r
.51781 .64936 m .51829 .65076 L .51474 .65036 L F
.634 .468 .64 r
.51786 .65246 m .51474 .65036 L .51829 .65076 L F
.515 .812 .999 r
.51952 .64934 m .51829 .65076 L .51781 .64936 L F
.51952 .64934 m .52061 .65028 L .51829 .65076 L F
.096 0 0 r
.52061 .65028 m .51786 .65246 L .51829 .65076 L F
.664 .86 .974 r
.54166 .60957 m .54313 .61074 L .54501 .6097 L F
.54166 .60957 m .54313 .61074 L .54501 .6097 L F
.658 .922 .625 r
.47086 .71049 m .47029 .71095 L .47263 .7084 L F
.09 .378 .841 r
.2054 .56019 m .20652 .5599 L .20394 .55844 L F
0 0 0 r
.2054 .56019 m .20337 .56277 L .20652 .5599 L F
.328 .431 .815 r
.45199 .69693 m .45337 .70039 L .45473 .69873 L F
.352 .467 .838 r
.45337 .70039 m .45629 .70206 L .45473 .69873 L F
.595 .451 .655 r
.54378 .60152 m .54629 .60161 L .54637 .59965 L F
.54637 .59965 m .54629 .60161 L .54378 .60152 L F
0 0 0 r
.47367 .62055 m .47293 .62142 L .47503 .61883 L F
.47661 .61857 m .47367 .62055 L .47503 .61883 L F
.765 .941 .939 r
.47253 .61987 m .47367 .62055 L .47661 .61857 L F
.436 .873 .803 r
.47441 .61968 m .47367 .62055 L .47253 .61987 L F
.47505 .61961 m .47367 .62055 L .47441 .61968 L F
0 0 0 r
.47367 .62055 m .47255 .62189 L .47293 .62142 L F
0 0 .293 r
.47661 .61857 m .47503 .61883 L .47624 .6158 L F
.957 .664 .437 r
.49396 .69124 m .4958 .68795 L .49663 .69034 L F
.655 .098 0 r
.49665 .69289 m .49242 .69059 L .49396 .69124 L F
.496 .074 .167 r
.51597 .6826 m .51237 .68449 L .51304 .68317 L F
.51597 .6826 m .51505 .6844 L .51237 .68449 L F
.205 0 .344 r
.51817 .67937 m .51794 .6819 L .51597 .6826 L F
.498 .224 .429 r
.51794 .6819 m .51505 .6844 L .51597 .6826 L F
.279 .306 .711 r
.49544 .68358 m .49331 .68181 L .49499 .68293 L F
.547 0 0 r
.49499 .68293 m .4974 .68462 L .49544 .68358 L F
.591 .843 .992 r
.48165 .68221 m .48543 .67973 L .48237 .67949 L F
.48165 .68221 m .48544 .68225 L .48543 .67973 L F
.648 .442 .591 r
.48544 .68225 m .4879 .67945 L .48543 .67973 L F
.599 .062 0 r
.72628 .48503 m .72906 .48678 L .72985 .48568 L F
.279 0 0 r
.72985 .48568 m .73117 .48634 L .73218 .48466 L F
.72985 .48568 m .72906 .48678 L .73117 .48634 L F
.544 .83 .998 r
.58197 .61034 m .58083 .60934 L .57944 .61028 L F
.788 .734 .802 r
.58197 .61034 m .58217 .6065 L .58083 .60934 L F
.58197 .61034 m .58335 .60665 L .58217 .6065 L F
.723 .419 .464 r
.46863 .72256 m .47287 .72271 L .47185 .72079 L F
.575 .532 .769 r
.19698 .58987 m .19887 .58887 L .19685 .58946 L F
.115 0 .299 r
.19686 .59235 m .19887 .58887 L .19698 .58987 L F
.621 .455 .636 r
.46187 .67126 m .46506 .67353 L .46446 .67048 L F
.46187 .67126 m .46147 .67625 L .46456 .67391 L F
.46147 .67625 m .46147 .6763 L .46154 .67624 L F
.46147 .67625 m .46154 .67624 L .46456 .67391 L F
.654 .513 .678 r
.46147 .6763 m .46272 .67625 L .46506 .67353 L F
.46 .786 .999 r
.46127 .67534 m .46365 .67501 L .46275 .6762 L F
.46265 .6762 m .46275 .6762 L .46272 .67625 L F
.46127 .67534 m .46275 .6762 L .46265 .6762 L F
.769 .543 .592 r
.45845 .67693 m .46016 .67913 L .46077 .6775 L F
.45845 .67693 m .45828 .67991 L .46016 .67913 L F
.828 .674 .693 r
.46265 .6762 m .4589 .6784 L .46127 .67534 L F
.46272 .67625 m .46253 .67635 L .46265 .6762 L F
.46253 .67635 m .4589 .6784 L .46265 .6762 L F
.621 .455 .636 r
.46495 .67345 m .46456 .67391 L .46506 .67353 L F
.46187 .67126 m .46456 .67391 L .46495 .67345 L F
.433 .253 .536 r
.22313 .58674 m .22121 .58927 L .22055 .58703 L F
.809 .684 .727 r
.61772 .4589 m .61903 .46234 L .61648 .46021 L F
.887 .479 .231 r
.61903 .46234 m .61792 .46343 L .61648 .46021 L F
.596 .179 .222 r
.62142 .46192 m .61792 .46343 L .61903 .46234 L F
.418 .798 .992 r
.489 .65043 m .49188 .65074 L .48977 .65011 L F
.823 .351 .077 r
.48977 .65011 m .49188 .65074 L .49105 .65082 L F
.273 .002 .307 r
.49105 .65082 m .48959 .65488 L .48759 .65353 L F
.418 .798 .992 r
.48734 .65026 m .489 .65043 L .48977 .65011 L F
.671 .427 .544 r
.49105 .65082 m .48734 .65026 L .48977 .65011 L F
.459 .176 .396 r
.49188 .65425 m .49105 .65082 L .49296 .65222 L F
.49188 .65425 m .48959 .65488 L .49105 .65082 L F
.703 .163 0 r
.48977 .65011 m .49296 .65222 L .49105 .65082 L F
.48977 .65011 m .49188 .65074 L .49296 .65222 L F
.743 .501 .564 r
.48827 .65138 m .49046 .64981 L .48977 .65011 L F
.49046 .64981 m .4915 .64907 L .48977 .65011 L F
.569 .789 .982 r
.58501 .6678 m .58879 .66843 L .58738 .66726 L F
.661 .82 .96 r
.58738 .66726 m .58879 .66843 L .59089 .66766 L F
0 .061 .601 r
.45946 .69403 m .45849 .69337 L .45676 .69114 L F
.389 0 0 r
.45946 .69403 m .46092 .69456 L .45849 .69337 L F
0 0 0 r
.57923 .59376 m .57834 .59335 L .5768 .59383 L F
.57923 .59376 m .58044 .5923 L .57834 .59335 L F
.284 .124 .48 r
.21507 .60914 m .21271 .6126 L .21293 .61009 L F
.625 .386 .536 r
.6368 .45925 m .63926 .4614 L .6378 .46159 L F
.6368 .45925 m .6392 .45918 L .63926 .4614 L F
.685 .715 .871 r
.75279 .51067 m .75629 .51119 L .75516 .50784 L F
.664 .655 .831 r
.75516 .50784 m .75629 .51119 L .75866 .50857 L F
.585 .709 .929 r
.76855 .5108 m .7717 .51158 L .77093 .51003 L F
.551 .633 .886 r
.7717 .51158 m .77348 .50963 L .77093 .51003 L F
.7717 .51158 m .77422 .51115 L .77348 .50963 L F
.129 0 0 r
.32692 .59187 m .32883 .59159 L .32959 .59057 L F
0 0 0 r
.32959 .59057 m .33067 .59081 L .33159 .59027 L F
.32959 .59057 m .32883 .59159 L .33067 .59081 L F
0 .572 .718 r
.32229 .62408 m .32047 .62402 L .31824 .62397 L F
.768 .977 .916 r
.32302 .62222 m .32229 .62408 L .32381 .62322 L F
.696 .403 .474 r
.54271 .66553 m .54227 .66757 L .54005 .66529 L F
.998 .823 .543 r
.54115 .71192 m .54044 .71294 L .54255 .71054 L F
.54115 .71192 m .54056 .71426 L .53952 .7134 L F
.54115 .71192 m .53952 .7134 L .54044 .71294 L F
.498 .601 .887 r
.43327 .58549 m .43184 .58721 L .43139 .58571 L F
.43327 .58549 m .43432 .587 L .43184 .58721 L F
.813 .33 .025 r
.55432 .66023 m .55618 .65978 L .55516 .65858 L F
.55432 .66023 m .55767 .66206 L .55618 .65978 L F
.594 .314 .462 r
.4804 .70451 m .48114 .70754 L .47826 .70596 L F
.592 .313 .462 r
.48418 .70631 m .48114 .70754 L .4804 .70451 L F
.48418 .70631 m .4804 .70451 L .48071 .70485 L F
0 0 0 r
.4829 .7019 m .48071 .70485 L .4804 .70451 L F
.509 .2 .379 r
.65067 .431 m .65118 .4301 L .64828 .43044 L F
.49 .154 .323 r
.64828 .43044 m .65118 .4301 L .65082 .43088 L F
.728 .826 .926 r
.65078 .43089 m .65067 .431 L .65062 .43095 L F
.49 .154 .323 r
.65063 .43095 m .65082 .43088 L .65077 .43098 L F
.64828 .43044 m .65082 .43088 L .65063 .43095 L F
0 0 0 r
.65079 .43087 m .65118 .4301 L .65067 .431 L F
.65161 .43007 m .65118 .4301 L .65231 .42915 L F
.65055 .43145 m .65082 .43088 L .65161 .43007 L F
.65082 .43088 m .65118 .4301 L .65161 .43007 L F
.65231 .42915 m .65118 .4301 L .65079 .43087 L F
.65231 .42915 m .65067 .431 L .65163 .43006 L F
.65231 .42915 m .65309 .42863 L .6532 .42852 L F
.436 .49 .817 r
.65447 .4274 m .65231 .42915 L .6532 .42852 L F
.546 .503 .759 r
.65447 .4274 m .65431 .42779 L .65231 .42915 L F
.65309 .42863 m .65243 .42957 L .65231 .42915 L F
0 0 0 r
.65058 .43145 m .65163 .43006 L .65289 .43124 L F
.65163 .43006 m .65231 .42915 L .65243 .42957 L F
.65163 .43006 m .65243 .42957 L .65289 .43124 L F
.65231 .42915 m .65171 .42995 L .65288 .42876 L F
.65171 .42995 m .65163 .43006 L .65288 .42876 L F
.65288 .42876 m .65163 .43006 L .65309 .42863 L F
.728 .826 .926 r
.65313 .42851 m .65157 .4301 L .64781 .42813 L F
.65157 .4301 m .65078 .43089 L .65057 .4307 L F
.65157 .4301 m .65057 .4307 L .64781 .42813 L F
.65316 .42852 m .65138 .4303 L .65313 .42851 L F
.6532 .42852 m .65309 .42863 L .65316 .42852 L F
.65309 .42863 m .65138 .4303 L .65316 .42852 L F
.546 .503 .759 r
.65431 .42779 m .65289 .43124 L .65243 .42957 L F
.65431 .42779 m .65243 .42957 L .65309 .42863 L F
0 0 0 r
.65055 .43145 m .65231 .42915 L .65058 .43145 L F
.728 .826 .926 r
.65138 .4303 m .65078 .43089 L .65313 .42851 L F
.49 .154 .323 r
.65073 .43098 m .65077 .43098 L .65076 .43099 L F
.65054 .43094 m .65073 .43097 L .65073 .43098 L F
.65073 .43097 m .65077 .43098 L .65073 .43098 L F
.728 .826 .926 r
.65078 .43089 m .65062 .43095 L .64781 .42813 L F
.242 .595 .95 r
.64781 .42813 m .65062 .43095 L .64792 .42966 L F
.728 .826 .926 r
.6532 .42852 m .64781 .42813 L .65148 .4277 L F
.598 .599 .823 r
.65032 .42565 m .65148 .4277 L .64781 .42813 L F
0 0 .469 r
.64781 .42813 m .64854 .42977 L .64778 .4277 L F
.598 .599 .823 r
.65032 .42565 m .64781 .42813 L .64729 .42636 L F
0 0 .469 r
.64781 .42813 m .64778 .4277 L .64729 .42636 L F
.242 .595 .95 r
.64781 .42813 m .64792 .42966 L .64715 .42929 L F
.65062 .43095 m .65067 .431 L .65054 .43094 L F
.65062 .43095 m .65054 .43094 L .64715 .42929 L F
.49 .154 .323 r
.64828 .43044 m .65077 .43098 L .65054 .43094 L F
.509 .2 .379 r
.65067 .431 m .64828 .43044 L .65054 .43094 L F
.49 .154 .323 r
.64828 .43044 m .65076 .43099 L .65055 .43145 L F
.509 .2 .379 r
.65054 .43094 m .64828 .43044 L .64715 .42929 L F
.49 .154 .323 r
.64828 .43044 m .64797 .42919 L .64715 .42929 L F
.64828 .43044 m .65055 .43145 L .64797 .42919 L F
.412 .679 .971 r
.49291 .6758 m .49366 .67686 L .49474 .6756 L F
.199 .356 .797 r
.49366 .67686 m .49634 .67856 L .49474 .6756 L F
.756 .477 .51 r
.50438 .65938 m .50187 .6608 L .50191 .65978 L F
.636 .359 .482 r
.44643 .61515 m .44865 .61553 L .44875 .6126 L F
.591 .413 .609 r
.44875 .6126 m .4522 .6129 L .45109 .61018 L F
.494 .186 .373 r
.44865 .61553 m .4522 .6129 L .44875 .6126 L F
.818 .539 .517 r
.45477 .61009 m .45468 .61231 L .45826 .6129 L F
.775 .5 .519 r
.45495 .61419 m .45826 .6129 L .45468 .61231 L F
.45495 .61419 m .45834 .61528 L .45826 .6129 L F
.602 .418 .606 r
.49446 .6416 m .49691 .63862 L .49454 .63912 L F
0 0 0 r
.4631 .70308 m .46595 .70104 L .4648 .70209 L F
.973 .912 .575 r
.46415 .70268 m .4648 .70209 L .46465 .70071 L F
0 0 .29 r
.46376 .70427 m .4631 .70308 L .4648 .70209 L F
.973 .912 .575 r
.46376 .70427 m .4648 .70209 L .46415 .70268 L F
0 0 0 r
.46595 .70104 m .46614 .7009 L .4648 .70209 L F
0 0 .29 r
.46376 .70427 m .4637 .70524 L .4631 .70308 L F
.352 0 0 r
.37674 .63896 m .37501 .64017 L .37308 .64009 L F
0 0 0 r
.37717 .63935 m .37674 .63896 L .37888 .63834 L F
.37717 .63935 m .37501 .64017 L .37674 .63896 L F
.793 .721 .784 r
.33353 .63508 m .33082 .63571 L .3327 .63308 L F
.598 .199 .258 r
.33353 .63508 m .33256 .6374 L .33082 .63571 L F
.688 .351 .399 r
.33614 .63537 m .33256 .6374 L .33353 .63508 L F
0 0 0 r
.38516 .63708 m .3835 .63751 L .38121 .63783 L F
.28 0 0 r
.38671 .63716 m .3835 .63751 L .38516 .63708 L F
.618 .309 .425 r
.52547 .66142 m .52621 .66045 L .52316 .65941 L F
.522 .331 .563 r
.52315 .66188 m .52547 .66142 L .52316 .65941 L F
.449 .389 .698 r
.22293 .59184 m .2215 .59267 L .22121 .58927 L F
.208 0 .358 r
.22293 .59184 m .22095 .59511 L .2215 .59267 L F
0 0 0 r
.80003 .48851 m .79907 .49027 L .79937 .48782 L F
.594 .906 .644 r
.79895 .48796 m .79937 .48782 L .79814 .48864 L F
.915 .603 .123 r
.79882 .48489 m .79976 .48768 L .79937 .48782 L F
0 0 .489 r
.79978 .4855 m .79882 .48489 L .79937 .48782 L F
.80016 .48339 m .79955 .48407 L .79978 .4855 L F
.79955 .48407 m .79882 .48489 L .79978 .4855 L F
.594 .906 .644 r
.80081 .4864 m .80004 .48704 L .80205 .48965 L F
0 0 .489 r
.80016 .48339 m .79937 .48782 L .80081 .4864 L F
.594 .906 .644 r
.80081 .4864 m .79937 .48782 L .79895 .48796 L F
.915 .603 .123 r
.79976 .48768 m .80003 .48851 L .79937 .48782 L F
.996 .779 .491 r
.79937 .48782 m .79907 .49027 L .79814 .48864 L F
.594 .906 .644 r
.80004 .48704 m .79814 .48864 L .8004 .48923 L F
.80004 .48704 m .8004 .48923 L .80205 .48965 L F
.587 .789 .976 r
.19685 .58946 m .19778 .58743 L .1953 .5868 L F
.19685 .58946 m .19887 .58887 L .19778 .58743 L F
.806 .574 .588 r
.55733 .69114 m .55955 .69326 L .56101 .69173 L F
.55733 .69114 m .55684 .69352 L .55955 .69326 L F
.55733 .69114 m .56101 .69173 L .55788 .6921 L F
.74 .942 .949 r
.55788 .6921 m .56101 .69173 L .55989 .69098 L F
.715 .78 .903 r
.56262 .59492 m .56616 .59569 L .56407 .59639 L F
.56262 .59492 m .56616 .59569 L .56407 .59639 L F
.589 .333 .496 r
.56407 .59639 m .56621 .59786 L .56616 .59569 L F
.776 .661 .736 r
.60118 .63296 m .60439 .63331 L .60506 .63093 L F
.794 .561 .584 r
.60169 .63548 m .60439 .63331 L .60118 .63296 L F
.60169 .63548 m .6041 .63584 L .60439 .63331 L F
.549 .539 .797 r
.78534 .51908 m .78813 .51826 L .78704 .51655 L F
.78534 .51908 m .78801 .5192 L .78813 .51826 L F
.904 .779 .713 r
.59507 .60374 m .5959 .60711 L .59671 .60479 L F
.863 .575 .5 r
.59657 .62613 m .59931 .62465 L .59672 .62386 L F
.59657 .62613 m .59981 .62716 L .59931 .62465 L F
.856 .795 .302 r
.50111 .68245 m .50051 .68543 L .5006 .68383 L F
.774 .593 .655 r
.50199 .68488 m .50051 .68543 L .50111 .68245 L F
.639 .622 .817 r
.50317 .68234 m .50199 .68488 L .50115 .68257 L F
.50317 .68234 m .50115 .68257 L .50111 .68245 L F
.50317 .68234 m .50462 .68526 L .50199 .68488 L F
.665 .635 .81 r
.5046 .68209 m .50462 .68526 L .50317 .68234 L F
.228 0 0 r
.50186 .68371 m .50486 .68214 L .50317 .68234 L F
.665 .635 .81 r
.5046 .68209 m .50317 .68234 L .50549 .68181 L F
.228 0 0 r
.50486 .68214 m .50549 .68181 L .50317 .68234 L F
.057 0 0 r
.5006 .68383 m .50317 .68234 L .50111 .68245 L F
.19 .704 .89 r
.47311 .73473 m .4766 .73489 L .4754 .73481 L F
.574 .086 0 r
.4766 .73489 m .47774 .73631 L .4754 .73481 L F
.4766 .73489 m .47882 .73742 L .47774 .73631 L F
.089 .148 .63 r
.51331 .699 m .5139 .70245 L .51345 .69983 L F
.615 .497 .695 r
.47003 .7248 m .46829 .72616 L .46926 .7237 L F
.101 0 .333 r
.231 .56588 m .23034 .56862 L .22885 .56944 L F
.29 .171 .54 r
.23034 .56862 m .22864 .5719 L .22885 .56944 L F
.596 .283 .408 r
.46581 .68967 m .46885 .68804 L .46757 .68786 L F
.713 .975 .921 r
.46757 .68786 m .46885 .68804 L .47186 .68585 L F
.715 .464 .545 r
.4654 .70222 m .46774 .69938 L .46614 .7009 L F
.97 .769 .577 r
.59564 .61187 m .59689 .61551 L .59689 .61297 L F
.63 .522 .713 r
.50517 .67606 m .50226 .67386 L .50497 .67381 L F
.561 .514 .76 r
.50652 .67105 m .50497 .67381 L .50425 .67058 L F
.50652 .67105 m .50759 .67343 L .50497 .67381 L F
.57 .412 .627 r
.50759 .67343 m .50517 .67606 L .50497 .67381 L F
.398 .258 .571 r
.21698 .60096 m .21695 .6036 L .2152 .60403 L F
.279 0 0 r
.42244 .61481 m .42471 .61454 L .42548 .61366 L F
.388 0 0 r
.42471 .61454 m .42768 .6143 L .42548 .61366 L F
.911 .53 .104 r
.58723 .6215 m .5854 .6182 L .58639 .61909 L F
.679 .473 .6 r
.64502 .4565 m .64521 .45886 L .64194 .45909 L F
.684 .497 .627 r
.64748 .4562 m .64521 .45886 L .64502 .4565 L F
.15 .393 .842 r
.462 .71169 m .46264 .7104 L .46053 .70897 L F
.596 .174 0 r
.462 .71169 m .46283 .71299 L .46264 .7104 L F
.462 .71169 m .46428 .71524 L .46283 .71299 L F
.839 .745 .76 r
.80967 .50545 m .80687 .50568 L .80856 .50258 L F
.595 .594 .821 r
.81105 .50173 m .80967 .50545 L .80856 .50258 L F
.81105 .50173 m .81158 .50491 L .80967 .50545 L F
.844 .996 .76 r
.81158 .50491 m .81031 .50852 L .80967 .50545 L F
.654 .635 .818 r
.74671 .50867 m .75027 .51124 L .74922 .50796 L F
.689 .662 .819 r
.74922 .50796 m .75027 .51124 L .75279 .51067 L F
.676 .702 .867 r
.75866 .50857 m .7624 .51086 L .76113 .5078 L F
.649 .681 .867 r
.76113 .5078 m .7624 .51086 L .76482 .50874 L F
.576 .22 .327 r
.5024 .7029 m .50141 .70504 L .49875 .70519 L F
.705 .36 .389 r
.50467 .70515 m .50141 .70504 L .5024 .7029 L F
.619 .378 .53 r
.50535 .70269 m .50467 .70515 L .5024 .7029 L F
.708 .488 .587 r
.46999 .62656 m .46695 .62728 L .4669 .62427 L F
.617 .464 .652 r
.75034 .49427 m .75267 .49637 L .7525 .49423 L F
.621 .366 .51 r
.7525 .49423 m .75267 .49637 L .7554 .49606 L F
.771 .456 .453 r
.73964 .49303 m .7428 .49135 L .73944 .49068 L F
.73964 .49303 m .74313 .49355 L .7428 .49135 L F
.342 0 .102 r
.33441 .58973 m .33634 .58934 L .3382 .58704 L F
.38 0 .128 r
.3382 .58704 m .33971 .58793 L .3404 .58667 L F
.3382 .58704 m .33634 .58934 L .33971 .58793 L F
.615 .781 .961 r
.80363 .49183 m .80498 .48961 L .80242 .49026 L F
.80363 .49183 m .80632 .49112 L .80498 .48961 L F
.488 .431 .719 r
.49094 .67621 m .49302 .67373 L .4898 .675 L F
.49094 .67621 m .49291 .6758 L .49302 .67373 L F
.875 .635 .572 r
.50309 .69458 m .50301 .69464 L .50128 .69342 L F
.863 .728 .208 r
.50173 .6941 m .50115 .69725 L .50218 .69447 L F
.50122 .69369 m .50122 .69389 L .50173 .6941 L F
.50122 .69389 m .50115 .69725 L .50173 .6941 L F
.50113 .69364 m .50115 .69725 L .50122 .69369 L F
.875 .635 .572 r
.50301 .69464 m .50373 .69746 L .50092 .69635 L F
.50309 .69458 m .50312 .69468 L .50301 .69464 L F
.50312 .69468 m .50373 .69746 L .50301 .69464 L F
.50301 .69464 m .50092 .69635 L .50125 .69371 L F
.50301 .69464 m .50125 .69371 L .50128 .69342 L F
.863 .728 .208 r
.50113 .69362 m .50113 .69364 L .50122 .69369 L F
.914 .899 .491 r
.50092 .69635 m .50006 .69878 L .50115 .69725 L F
.591 .257 .372 r
.50373 .69746 m .5038 .69912 L .50115 .69725 L F
.50115 .69725 m .5038 .69912 L .50373 .69746 L F
.50373 .69746 m .50115 .69725 L .50006 .69878 L F
.28 0 0 r
.51692 .63383 m .51921 .63442 L .52037 .63377 L F
.155 0 0 r
.52037 .63377 m .52145 .63425 L .52274 .63396 L F
.52037 .63377 m .51921 .63442 L .52145 .63425 L F
.954 .616 .325 r
.55408 .66484 m .55615 .66841 L .55455 .66735 L F
.971 .806 .621 r
.55535 .67064 m .55455 .66735 L .55615 .66841 L F
.161 0 .279 r
.21161 .61566 m .2108 .61813 L .20941 .61873 L F
.268 .14 .514 r
.2108 .61813 m .21072 .62059 L .20941 .61873 L F
.278 .142 .51 r
.21072 .62059 m .20933 .62129 L .20941 .61873 L F
.813 1 .83 r
.48363 .69802 m .48482 .69574 L .48575 .69669 L F
.598 .662 .883 r
.76711 .50772 m .76855 .5108 L .77093 .51003 L F
.321 0 .108 r
.51304 .68317 m .51237 .68449 L .51019 .68489 L F
.029 0 .199 r
.52471 .64166 m .52442 .64399 L .52266 .64468 L F
0 0 0 r
.52442 .64399 m .52183 .64524 L .52266 .64468 L F
.534 .528 .795 r
.578 .63651 m .5762 .63953 L .57448 .63672 L F
.578 .63651 m .57847 .63925 L .5762 .63953 L F
.505 .534 .82 r
.57936 .64088 m .5762 .63953 L .57847 .63925 L F
.661 .586 .76 r
.44399 .60139 m .4476 .6042 L .44604 .60111 L F
.657 .565 .74 r
.4476 .6042 m .45117 .60712 L .45006 .60333 L F
.382 .62 .946 r
.34436 .63412 m .3459 .63618 L .34631 .63461 L F
.252 .478 .882 r
.3459 .63618 m .3485 .63717 L .34631 .63461 L F
.433 .253 .536 r
.22313 .58674 m .22324 .58915 L .22121 .58927 L F
.449 .389 .698 r
.22293 .59184 m .22121 .58927 L .22324 .58915 L F
.879 .458 .042 r
.20186 .5672 m .2021 .56615 L .19969 .5661 L F
.20186 .5672 m .20295 .56801 L .2021 .56615 L F
.494 .821 1 r
.2031 .56666 m .20056 .56623 L .20186 .5672 L F
.20056 .56623 m .20053 .56623 L .20186 .5672 L F
.879 .458 .042 r
.20186 .5672 m .20333 .56884 L .20295 .56801 L F
.823 .775 .808 r
.51166 .64808 m .51608 .64589 L .51438 .64714 L F
0 0 0 r
.51735 .64453 m .51438 .64714 L .51608 .64589 L F
.699 .599 .74 r
.45109 .61018 m .45309 .60619 L .45117 .60712 L F
.45109 .61018 m .45477 .61009 L .45309 .60619 L F
.65 .442 .588 r
.45109 .61018 m .45468 .61231 L .45477 .61009 L F
.45109 .61018 m .4522 .6129 L .45468 .61231 L F
.537 .352 .578 r
.49209 .64201 m .49437 .64403 L .49446 .6416 L F
.49209 .64201 m .49209 .64465 L .49437 .64403 L F
.492 .791 .998 r
.47311 .73473 m .4754 .73481 L .4736 .73345 L F
.47 .692 .964 r
.44269 .59994 m .44399 .60139 L .44604 .60111 L F
.863 .994 .753 r
.46374 .69106 m .46092 .69456 L .46425 .69415 L F
.632 .24 .284 r
.46505 .6958 m .46425 .69415 L .46092 .69456 L F
.226 .251 .678 r
.46374 .69106 m .46425 .69415 L .46563 .6932 L F
.721 .615 .738 r
.46505 .6958 m .46563 .6932 L .46425 .69415 L F
0 0 .472 r
.80457 .48095 m .80456 .48254 L .80386 .47899 L F
.119 .22 .695 r
.80457 .48095 m .80534 .48471 L .80456 .48254 L F
.776 .661 .736 r
.60118 .63296 m .60506 .63093 L .60117 .63025 L F
.237 .382 .807 r
.47367 .62055 m .47508 .62378 L .47255 .62189 L F
.488 .394 .675 r
.47508 .62378 m .47316 .62477 L .47255 .62189 L F
.761 .54 .597 r
.2002 .57807 m .20335 .58082 L .20312 .57848 L F
.422 .313 .625 r
.20312 .57848 m .20497 .58 L .20492 .5771 L F
.20312 .57848 m .20335 .58082 L .20497 .58 L F
.716 .678 .812 r
.80187 .51181 m .79865 .51645 L .79809 .51113 L F
.634 .558 .752 r
.4772 .61334 m .47711 .61417 L .47602 .61499 L F
0 0 .293 r
.47661 .61857 m .47624 .6158 L .47602 .61499 L F
.634 .558 .752 r
.47711 .61417 m .47661 .61857 L .47602 .61499 L F
.393 .726 .99 r
.47533 .6155 m .47602 .61499 L .47624 .6158 L F
.4738 .61501 m .47602 .61499 L .47533 .6155 L F
.453 .285 .562 r
.32014 .60166 m .32213 .60114 L .32224 .59837 L F
.493 .407 .687 r
.3206 .60401 m .32213 .60114 L .32014 .60166 L F
.748 .229 0 r
.19474 .56381 m .19595 .56553 L .19763 .56633 L F
.467 .291 .558 r
.35896 .6417 m .36086 .64309 L .36152 .64343 L F
.414 .847 .943 r
.36452 .6424 m .36014 .64272 L .36086 .64309 L F
.467 .291 .558 r
.35896 .6417 m .35892 .64363 L .36086 .64309 L F
.35892 .64363 m .35891 .64431 L .36086 .64309 L F
.414 .847 .943 r
.36086 .64309 m .35971 .64275 L .36288 .64252 L F
.36086 .64309 m .36288 .64252 L .36452 .6424 L F
.36014 .64272 m .35971 .64275 L .36086 .64309 L F
.467 .291 .558 r
.36152 .64343 m .36086 .64309 L .36307 .64448 L F
.699 .818 .939 r
.36086 .64309 m .35891 .64431 L .36307 .64448 L F
0 0 0 r
.36397 .64376 m .36307 .64448 L .36515 .64227 L F
.537 .778 .987 r
.36086 .64309 m .36307 .64448 L .36397 .64376 L F
.36086 .64309 m .36307 .64448 L .36397 .64376 L F
.435 .847 .965 r
.39796 .58093 m .39749 .58195 L .39573 .58136 L F
.39796 .58093 m .39973 .58139 L .39749 .58195 L F
.746 .802 .898 r
.54563 .65834 m .54864 .65998 L .54805 .65632 L F
.802 .35 .168 r
.54579 .66076 m .54567 .66132 L .54325 .6586 L F
.733 .321 .269 r
.54567 .66132 m .54864 .65998 L .54563 .65834 L F
.54567 .66132 m .54926 .66198 L .54864 .65998 L F
.138 .328 .791 r
.54864 .65998 m .54967 .65742 L .54805 .65632 L F
.979 .71 .315 r
.58705 .60662 m .58606 .6032 L .58653 .60427 L F
.357 .486 .852 r
.22873 .55196 m .22855 .55477 L .2267 .55196 L F
.22873 .55196 m .23003 .55455 L .22855 .55477 L F
.351 .385 .756 r
.23003 .55455 m .23071 .55575 L .22855 .55477 L F
.769 .715 .802 r
.63792 .43943 m .63608 .44193 L .63906 .44215 L F
.513 0 0 r
.53811 .64922 m .5422 .64957 L .5386 .64887 L F
.54049 .65035 m .54106 .65024 L .5422 .64957 L F
.54153 .64951 m .5416 .64984 L .5422 .64957 L F
.94 .961 .678 r
.5422 .64957 m .54182 .64823 L .54405 .64919 L F
0 0 .121 r
.54182 .64823 m .54166 .65012 L .54405 .64919 L F
.54166 .65012 m .5436 .64975 L .54405 .64919 L F
.513 0 0 r
.53811 .64922 m .54049 .65035 L .5416 .64984 L F
.53811 .64922 m .5416 .64984 L .54153 .64951 L F
.94 .961 .678 r
.5422 .64957 m .5407 .65045 L .54182 .64823 L F
0 0 .121 r
.54182 .64823 m .54182 .6507 L .5418 .6508 L F
0 0 0 r
.54405 .64919 m .54211 .65092 L .54459 .65187 L F
.54405 .64919 m .54148 .65231 L .54211 .65092 L F
0 0 .121 r
.54166 .65012 m .54148 .65231 L .5436 .64975 L F
.54166 .65012 m .5418 .6508 L .54148 .65231 L F
.54182 .64823 m .5418 .6508 L .54166 .65012 L F
.513 0 0 r
.54049 .65035 m .5407 .65045 L .54106 .65024 L F
0 0 0 r
.53782 .64938 m .53811 .64922 L .5386 .64887 L F
.244 .352 .775 r
.53847 .64578 m .5407 .65045 L .53811 .64922 L F
0 .034 .593 r
.53811 .64922 m .5401 .6516 L .5385 .64899 L F
.53811 .64922 m .5385 .64899 L .53829 .64865 L F
0 0 0 r
.53613 .6505 m .53811 .64922 L .53782 .64938 L F
.436 .042 .191 r
.53613 .6505 m .53795 .65224 L .53811 .64922 L F
.53613 .6505 m .53506 .6527 L .53795 .65224 L F
0 0 .136 r
.78662 .49235 m .78678 .49641 L .78659 .49415 L F
.955 .7 .248 r
.58787 .61006 m .5872 .60922 L .58705 .60662 L F
.991 .86 .508 r
.58665 .61159 m .58787 .61006 L .58812 .61244 L F
.58665 .61159 m .5872 .60922 L .58787 .61006 L F
.154 0 0 r
.79042 .47512 m .79295 .47504 L .79358 .47458 L F
.456 0 0 r
.79295 .47504 m .79671 .47471 L .79358 .47458 L F
.992 .871 .538 r
.46603 .70945 m .4674 .70928 L .46378 .70789 L F
.46603 .70945 m .46646 .71126 L .4674 .70928 L F
.405 .297 .618 r
.22692 .57733 m .22675 .58041 L .22504 .58107 L F
.373 .196 .508 r
.22675 .58041 m .2248 .58352 L .22504 .58107 L F
.644 .906 .982 r
.78653 .48704 m .78768 .48734 L .78983 .48614 L F
.647 .461 .618 r
.51271 .66778 m .51297 .67089 L .51022 .67077 L F
.496 .284 .521 r
.5159 .66682 m .51297 .67089 L .51271 .66778 L F
.5159 .66682 m .51567 .67032 L .51297 .67089 L F
.727 .692 .152 r
.5163 .66683 m .51567 .67032 L .5159 .66682 L F
.067 0 0 r
.51108 .6692 m .51602 .66715 L .51271 .66778 L F
.514 .203 .377 r
.51602 .66715 m .5159 .66682 L .51271 .66778 L F
.51 .052 .101 r
.43647 .62392 m .43604 .62467 L .43356 .62441 L F
.296 0 0 r
.43852 .62417 m .43604 .62467 L .43647 .62392 L F
.589 .016 0 r
.41519 .61567 m .41688 .61596 L .41342 .61466 L F
.332 0 0 r
.41519 .61567 m .41868 .61688 L .41688 .61596 L F
.448 0 0 r
.41688 .61596 m .41868 .61688 L .41954 .61614 L F
.795 .501 .491 r
.7347 .48435 m .73849 .48735 L .73561 .4858 L F
.497 .79 .997 r
.40406 .58015 m .40335 .58165 L .40189 .58069 L F
.40406 .58015 m .4055 .58122 L .40335 .58165 L F
.504 .512 .798 r
.7321 .49741 m .73374 .49504 L .73133 .49548 L F
.7321 .49741 m .73527 .49762 L .73374 .49504 L F
.518 .449 .718 r
.7321 .49741 m .73507 .49884 L .73527 .49762 L F
.675 .371 .45 r
.50199 .68488 m .50055 .68753 L .50051 .68543 L F
.732 .438 .482 r
.50463 .6877 m .50199 .68488 L .50462 .68526 L F
.50463 .6877 m .50055 .68753 L .50199 .68488 L F
.663 .581 .753 r
.45309 .60619 m .45477 .61009 L .45703 .60708 L F
.42 .24 .529 r
.40815 .61808 m .4102 .6143 L .40771 .61492 L F
0 0 0 r
.51735 .64453 m .51566 .64701 L .51438 .64714 L F
.921 .535 .145 r
.51735 .64453 m .51666 .64619 L .51566 .64701 L F
.51735 .64453 m .51838 .64772 L .51691 .64652 L F
.51838 .64772 m .51878 .64897 L .51803 .64798 L F
.51838 .64772 m .51803 .64798 L .51691 .64652 L F
.092 .639 .835 r
.51571 .64897 m .51952 .64934 L .51781 .64936 L F
.58 .907 .979 r
.51781 .64936 m .51474 .65036 L .51571 .64897 L F
.096 0 0 r
.52061 .65028 m .51983 .65197 L .51786 .65246 L F
.542 .576 .838 r
.51571 .64897 m .51983 .65197 L .51952 .64934 L F
0 0 0 r
.51766 .64822 m .51775 .64817 L .51609 .64925 L F
.921 .535 .145 r
.5167 .6461 m .51691 .64652 L .51666 .64619 L F
.51735 .64453 m .51691 .64652 L .5167 .6461 L F
.829 .756 .782 r
.51666 .64619 m .51878 .64897 L .52183 .64524 L F
0 0 0 r
.51775 .64817 m .51927 .64741 L .51696 .64875 L F
.51775 .64817 m .51696 .64875 L .51609 .64925 L F
.639 .554 .743 r
.51667 .6408 m .51851 .64476 L .52027 .64336 L F
.477 .842 .595 r
.51851 .64476 m .51679 .64609 L .52027 .64336 L F
.5 .409 .684 r
.51439 .643 m .51666 .64619 L .51679 .64609 L F
.51459 .64308 m .51679 .64609 L .51851 .64476 L F
.51439 .643 m .51679 .64609 L .51459 .64308 L F
.114 .261 .738 r
.51734 .64684 m .51775 .64817 L .51756 .6478 L F
.477 .842 .595 r
.51679 .64609 m .51681 .64607 L .52027 .64336 L F
.829 .756 .782 r
.51681 .64607 m .52183 .64524 L .52027 .64336 L F
.477 .842 .595 r
.51679 .64609 m .51666 .64619 L .51681 .64607 L F
.829 .756 .782 r
.51666 .64619 m .51682 .64616 L .51681 .64607 L F
.51682 .64616 m .52183 .64524 L .51681 .64607 L F
.114 .261 .738 r
.51692 .64503 m .51744 .64697 L .51734 .64684 L F
.51744 .64697 m .51775 .64817 L .51734 .64684 L F
.51713 .6458 m .51927 .64741 L .51775 .64817 L F
.51692 .64503 m .51742 .64554 L .51713 .6458 L F
.51742 .64554 m .51927 .64741 L .51713 .6458 L F
.51756 .6478 m .51775 .64817 L .51766 .64822 L F
.842 .808 .817 r
.45871 .68753 m .46075 .68866 L .46239 .68623 L F
.179 .462 .885 r
.46075 .68866 m .46374 .69106 L .46239 .68623 L F
.55 .216 .356 r
.49487 .67339 m .49836 .67095 L .49524 .67099 L F
.49487 .67339 m .49778 .67327 L .49836 .67095 L F
.629 .292 .38 r
.49836 .67095 m .49778 .67327 L .50064 .67288 L F
.639 .286 .356 r
.49836 .67095 m .50064 .67288 L .50176 .671 L F
.509 0 0 r
.38089 .62527 m .38489 .62451 L .3826 .62488 L F
.501 .211 .405 r
.50486 .63794 m .50279 .63632 L .50257 .63831 L F
.50486 .63794 m .50517 .63594 L .50279 .63632 L F
.349 .242 .59 r
.21271 .6126 m .21307 .61501 L .21161 .61566 L F
.347 .087 .37 r
.21271 .61726 m .21161 .61566 L .21307 .61501 L F
.21271 .61726 m .2108 .61813 L .21161 .61566 L F
.689 .639 .795 r
.24558 .78344 m .24219 .78397 L .24457 .78318 L F
.291 0 0 r
.24458 .7836 m .24421 .78432 L .24219 .78397 L F
.24558 .78344 m .24534 .7836 L .24458 .7836 L F
.689 .161 0 r
.24518 .78371 m .24695 .78473 L .24522 .7836 L F
.498 .484 .773 r
.24522 .7836 m .24695 .78473 L .2469 .78448 L F
.763 .393 .353 r
.24553 .78416 m .24601 .78512 L .24421 .78432 L F
.24601 .78512 m .24646 .78601 L .24558 .78535 L F
.24601 .78512 m .24558 .78535 L .24421 .78432 L F
.597 .035 0 r
.24421 .78432 m .24646 .78601 L .24463 .78505 L F
.689 .161 0 r
.24463 .78505 m .24607 .78485 L .24553 .78416 L F
.24607 .78485 m .24695 .78473 L .24518 .78371 L F
.763 .393 .353 r
.24637 .78406 m .24639 .78461 L .24553 .78416 L F
.24639 .78461 m .24646 .78601 L .24553 .78416 L F
.24814 .78384 m .24736 .78485 L .2469 .78448 L F
.24656 .78404 m .2469 .78448 L .24637 .78406 L F
.24814 .78384 m .2469 .78448 L .24656 .78404 L F
.24814 .78384 m .24637 .78406 L .24558 .78344 L F
.672 .706 .873 r
.24613 .78076 m .24814 .78384 L .24558 .78344 L F
.509 .73 .973 r
.2478 .7815 m .24814 .78384 L .24613 .78076 L F
.183 .255 .704 r
.24613 .78076 m .2469 .78448 L .24778 .78206 L F
.2469 .78448 m .24695 .78473 L .24699 .7846 L F
.2469 .78448 m .24699 .7846 L .24778 .78206 L F
.795 .864 .9 r
.24668 .78476 m .24699 .7846 L .24695 .78473 L F
.763 .393 .353 r
.24736 .78485 m .24646 .78601 L .24637 .78406 L F
.498 .484 .773 r
.24641 .78409 m .2469 .78448 L .24686 .78428 L F
.24522 .7836 m .2469 .78448 L .24641 .78409 L F
.763 .393 .353 r
.24637 .78406 m .24556 .7837 L .24558 .78344 L F
.498 .484 .773 r
.24534 .7836 m .24686 .78428 L .24671 .7836 L F
.24522 .7836 m .24686 .78428 L .24534 .7836 L F
.763 .393 .353 r
.24637 .78406 m .24553 .78416 L .24556 .7837 L F
.498 .484 .773 r
.24522 .7836 m .24671 .7836 L .24613 .78076 L F
.795 .864 .9 r
.24463 .78505 m .24778 .78206 L .24699 .7846 L F
.24463 .78505 m .24699 .7846 L .24668 .78476 L F
.763 .393 .353 r
.24553 .78416 m .24421 .78432 L .24517 .7837 L F
.689 .161 0 r
.24509 .78393 m .24553 .78416 L .24518 .78371 L F
.24463 .78505 m .24553 .78416 L .24509 .78393 L F
.763 .393 .353 r
.24553 .78416 m .24517 .7837 L .24558 .78344 L F
.291 0 0 r
.24522 .7836 m .24421 .78432 L .24458 .7836 L F
.24517 .7837 m .24421 .78432 L .24522 .7836 L F
.689 .161 0 r
.24463 .78497 m .24522 .7836 L .24457 .78318 L F
.24463 .78505 m .24522 .7836 L .24463 .78497 L F
.291 0 0 r
.24534 .7836 m .24517 .7837 L .24522 .7836 L F
.672 .706 .873 r
.24613 .78076 m .24558 .78344 L .24457 .78318 L F
.498 .484 .773 r
.24457 .78318 m .24522 .7836 L .24613 .78076 L F
.324 0 .051 r
.24219 .78397 m .24421 .78432 L .24457 .78318 L F
.692 .175 0 r
.49726 .65768 m .50058 .65853 L .4982 .65657 L F
.577 .32 .491 r
.50058 .65853 m .50097 .65628 L .4982 .65657 L F
.417 0 0 r
.36998 .58288 m .3722 .5833 L .37337 .58278 L F
.226 0 0 r
.37578 .58175 m .37337 .58278 L .37575 .58203 L F
.243 0 0 r
.3722 .5833 m .37575 .58203 L .37337 .58278 L F
.999 .809 .516 r
.55846 .67535 m .55817 .67835 L .55922 .67887 L F
.995 .868 .564 r
.55827 .68211 m .55817 .67835 L .55922 .67887 L F
.999 .809 .516 r
.55846 .67535 m .55817 .67835 L .55922 .67887 L F
.645 .118 0 r
.55817 .67835 m .56127 .68132 L .55922 .67887 L F
.63 .522 .713 r
.50517 .67606 m .50258 .67655 L .50226 .67386 L F
.393 .005 .179 r
.50517 .67606 m .50177 .67857 L .50258 .67655 L F
.804 .341 0 r
.56495 .64153 m .56519 .64309 L .56359 .64062 L F
.56495 .64153 m .5664 .64414 L .56519 .64309 L F
.866 .815 .798 r
.59926 .66719 m .60108 .66851 L .60295 .66518 L F
.571 .001 0 r
.47788 .71529 m .47831 .7165 L .47364 .71409 L F
0 0 .223 r
.4781 .71561 m .47788 .71529 L .47973 .7163 L F
.4781 .71561 m .47831 .7165 L .47788 .71529 L F
.441 .149 .372 r
.48072 .71432 m .47973 .7163 L .47788 .71529 L F
.591 .843 .992 r
.48165 .68221 m .48284 .68286 L .48544 .68225 L F
.72 .432 .489 r
.45288 .68295 m .45628 .68463 L .45426 .68232 L F
.45288 .68295 m .45223 .68475 L .45628 .68463 L F
.346 .185 .514 r
.4754 .73481 m .47774 .73631 L .47779 .73603 L F
.875 .598 .515 r
.48053 .73431 m .47777 .73551 L .4806 .73437 L F
.47777 .73551 m .47777 .73551 L .4806 .73437 L F
.47765 .73159 m .47758 .73351 L .48053 .73431 L F
.346 .185 .514 r
.4754 .73481 m .47775 .73601 L .4777 .73354 L F
.95 .921 .745 r
.47774 .73631 m .4806 .73437 L .47777 .73551 L F
.346 .185 .514 r
.47775 .73601 m .47779 .73603 L .47777 .73551 L F
.47775 .73601 m .47777 .73551 L .4777 .73354 L F
.95 .921 .745 r
.47774 .73631 m .47777 .73551 L .47749 .73563 L F
.875 .598 .515 r
.47758 .73351 m .47749 .73563 L .48053 .73431 L F
.346 .185 .514 r
.4777 .73354 m .47779 .73603 L .47828 .73322 L F
.875 .598 .515 r
.47777 .73551 m .47749 .73563 L .47777 .73551 L F
.433 .224 .495 r
.47828 .73322 m .47749 .73563 L .47758 .73351 L F
.47828 .73322 m .47758 .73351 L .47765 .73159 L F
.346 .185 .514 r
.4754 .73481 m .4777 .73354 L .4775 .73354 L F
.47503 .73453 m .4775 .73354 L .4736 .73345 L F
.4754 .73481 m .4775 .73354 L .47503 .73453 L F
.4777 .73354 m .47828 .73322 L .4768 .73329 L F
.4777 .73354 m .4768 .73329 L .4736 .73345 L F
.359 .106 .387 r
.51996 .68128 m .51817 .67937 L .52061 .67921 L F
.51996 .68128 m .51794 .6819 L .51817 .67937 L F
.438 .429 .752 r
.79221 .50102 m .78896 .50442 L .7897 .50175 L F
.79221 .50102 m .79434 .50493 L .78896 .50442 L F
.722 .62 .743 r
.79434 .50493 m .78988 .50657 L .78896 .50442 L F
.707 .728 .867 r
.78159 .51836 m .78253 .52015 L .78534 .51908 L F
.696 .667 .817 r
.78253 .52015 m .78529 .52015 L .78534 .51908 L F
.958 .744 .572 r
.27613 .70299 m .27367 .70431 L .27438 .70235 L F
.27613 .70299 m .27534 .70529 L .27367 .70431 L F
.559 .849 .998 r
.27759 .70218 m .27613 .70299 L .27438 .70235 L F
.143 0 .255 r
.27759 .70218 m .27534 .70529 L .27613 .70299 L F
0 0 .454 r
.46729 .72056 m .46926 .7237 L .46863 .72256 L F
0 0 .514 r
.46926 .7237 m .47003 .7248 L .46863 .72256 L F
.549 .539 .797 r
.78534 .51908 m .78529 .52015 L .78801 .5192 L F
0 .048 .614 r
.46646 .71126 m .47029 .71095 L .46925 .71222 L F
0 .335 .814 r
.57528 .65904 m .57531 .65798 L .57304 .65582 L F
.57528 .65904 m .57634 .65936 L .57531 .65798 L F
.273 0 0 r
.3761 .59535 m .37445 .59684 L .37217 .59716 L F
.144 0 0 r
.37665 .59629 m .3761 .59535 L .37828 .59473 L F
.37665 .59629 m .37445 .59684 L .3761 .59535 L F
.327 .756 .972 r
.18494 .54277 m .18888 .54347 L .18666 .54372 L F
.288 0 .281 r
.48959 .65488 m .48757 .65591 L .48759 .65353 L F
.218 0 0 r
.46337 .68473 m .46602 .68437 L .46764 .68249 L F
.57 .536 .778 r
.46764 .68249 m .46859 .67901 L .46627 .6792 L F
.46764 .68249 m .46992 .68203 L .46859 .67901 L F
.294 0 0 r
.46764 .68249 m .46823 .68388 L .46992 .68203 L F
.46764 .68249 m .46602 .68437 L .46823 .68388 L F
.791 .569 .6 r
.47409 .73103 m .47777 .72887 L .47413 .72852 L F
.47409 .73103 m .47765 .73159 L .47777 .72887 L F
.128 0 0 r
.54829 .67875 m .551 .67686 L .55069 .679 L F
.573 .512 .749 r
.55324 .67482 m .55355 .67639 L .551 .67686 L F
.496 .238 .453 r
.551 .67686 m .55305 .6786 L .55069 .679 L F
.551 .67686 m .55355 .67639 L .55305 .6786 L F
.341 0 .14 r
.32467 .62644 m .32668 .62636 L .32807 .62417 L F
.878 .885 .835 r
.32862 .62102 m .32807 .62417 L .32991 .6229 L F
.32862 .62102 m .32618 .62269 L .32807 .62417 L F
.097 0 0 r
.32807 .62417 m .32834 .62556 L .32991 .6229 L F
.32807 .62417 m .32668 .62636 L .32834 .62556 L F
.273 .749 .935 r
.18888 .54347 m .19134 .54342 L .19249 .54366 L F
.286 .743 .954 r
.19134 .54342 m .19445 .54366 L .19249 .54366 L F
.602 .465 .667 r
.5055 .69482 m .50373 .69746 L .50309 .69458 L F
.5055 .69482 m .50373 .69746 L .50309 .69458 L F
.926 .788 .689 r
.59507 .60374 m .5945 .60643 L .5959 .60711 L F
.943 .678 .503 r
.59457 .6085 m .5959 .60711 L .5945 .60643 L F
.59457 .6085 m .59588 .60943 L .5959 .60711 L F
.198 .098 .507 r
.57944 .61028 m .58083 .60934 L .58095 .60678 L F
.948 .941 .744 r
.48809 .7122 m .48667 .71239 L .48807 .71079 L F
.924 .565 .328 r
.48809 .7122 m .48876 .71616 L .48667 .71239 L F
.379 .241 .565 r
.48952 .71026 m .48809 .7122 L .48807 .71079 L F
.48952 .71026 m .49056 .71344 L .48809 .7122 L F
.346 .166 .488 r
.4905 .71538 m .48809 .7122 L .49056 .71344 L F
.4905 .71538 m .48876 .71616 L .48809 .7122 L F
0 0 .021 r
.78512 .48155 m .78372 .48268 L .78307 .48403 L F
.697 .862 .96 r
.19901 .55596 m .20062 .55824 L .20175 .55703 L F
.417 .785 .994 r
.19595 .56553 m .19969 .5661 L .19763 .56633 L F
.437 .103 .3 r
.40495 .62111 m .40726 .6207 L .40815 .61808 L F
.42 .24 .529 r
.40815 .61808 m .4101 .61749 L .4102 .6143 L F
.461 .17 .383 r
.40726 .6207 m .4101 .61749 L .40815 .61808 L F
.718 .677 .809 r
.42342 .59256 m .42715 .59353 L .42548 .59216 L F
.618 .102 0 r
.4296 .59281 m .42548 .59216 L .42715 .59353 L F
.321 0 .254 r
.4101 .61749 m .41342 .61466 L .4102 .6143 L F
.487 .589 .882 r
.43198 .59169 m .43277 .59381 L .4351 .59374 L F
.95 .921 .745 r
.47774 .73631 m .47882 .73742 L .4806 .73437 L F
.714 .643 .777 r
.45382 .60432 m .45107 .60499 L .45006 .60333 L F
.723 .629 .753 r
.45006 .60333 m .45117 .60712 L .45382 .60432 L F
.651 .515 .685 r
.45382 .60432 m .45117 .60712 L .45309 .60619 L F
.637 .76 .937 r
.35768 .64022 m .35896 .6417 L .36124 .64084 L F
.409 .287 .601 r
.24383 .74005 m .24212 .74131 L .24244 .73952 L F
.24383 .74005 m .24212 .74131 L .24244 .73952 L F
.954 .915 .736 r
.25117 .78201 m .25014 .78103 L .25137 .78188 L F
.509 .73 .973 r
.24786 .78192 m .25023 .78353 L .24814 .78384 L F
.24831 .78193 m .25023 .78353 L .24786 .78192 L F
.771 .798 .875 r
.25014 .78103 m .25023 .78353 L .2478 .7815 L F
0 0 0 r
.24814 .78384 m .25023 .78353 L .24824 .78394 L F
.954 .915 .736 r
.24824 .78394 m .25023 .78353 L .25014 .78103 L F
.24824 .78394 m .24953 .78196 L .25117 .78201 L F
.24953 .78196 m .25014 .78103 L .25117 .78201 L F
.509 .73 .973 r
.2478 .7815 m .24831 .78193 L .24786 .78192 L F
0 0 0 r
.24814 .78384 m .24824 .78394 L .24646 .78601 L F
.553 .731 .958 r
.77908 .51878 m .78081 .51637 L .77777 .51686 L F
.77908 .51878 m .78159 .51836 L .78081 .51637 L F
.814 .762 .804 r
.50513 .65243 m .50273 .65559 L .50779 .65472 L F
.684 .497 .627 r
.64748 .4562 m .64767 .45918 L .64521 .45886 L F
.63 .456 .628 r
.65084 .45715 m .64748 .4562 L .65109 .45594 L F
.65084 .45715 m .64767 .45918 L .64748 .4562 L F
.457 .251 .51 r
.5239 .69126 m .52615 .69073 L .52638 .68826 L F
.282 .151 .519 r
.5239 .69126 m .52534 .69274 L .52615 .69073 L F
.5239 .69126 m .52426 .69406 L .52534 .69274 L F
0 0 0 r
.42615 .62592 m .42761 .62492 L .42992 .62369 L F
.621 .386 .54 r
.467 .66731 m .47197 .6696 L .46997 .66529 L F
.152 .161 .615 r
.46997 .66529 m .47044 .66544 L .47198 .66446 L F
.46997 .66529 m .47197 .6696 L .47044 .66544 L F
.646 .124 0 r
.50067 .65178 m .5028 .65297 L .49961 .6524 L F
.618 .376 .529 r
.50354 .65099 m .5028 .65297 L .50067 .65178 L F
.486 .098 .23 r
.50064 .67288 m .50425 .67058 L .50176 .671 L F
.401 0 0 r
.575 .6457 m .57399 .64499 L .57489 .64299 L F
.575 .6457 m .57665 .64675 L .57399 .64499 L F
.718 .352 0 r
.57026 .65057 m .5698 .64998 L .56867 .64712 L F
0 .003 .579 r
.57049 .65271 m .5698 .64998 L .57026 .65057 L F
0 .173 .706 r
.54701 .64469 m .5489 .64675 L .54856 .64714 L F
0 .215 .734 r
.54856 .64714 m .5489 .64675 L .54987 .64835 L F
.881 .825 .788 r
.62814 .43597 m .62465 .43779 L .62722 .43503 L F
.62814 .43597 m .62614 .43901 L .62465 .43779 L F
.918 .938 .803 r
.62814 .43597 m .62936 .43191 L .63051 .4329 L F
.62814 .43597 m .62722 .43503 L .62936 .43191 L F
.226 .251 .678 r
.46374 .69106 m .46563 .6932 L .46579 .68992 L F
.529 .462 .726 r
.35928 .61868 m .3576 .62128 L .3567 .61813 L F
.35928 .61868 m .35974 .62097 L .3576 .62128 L F
.452 .47 .787 r
.77422 .51115 m .775 .51463 L .77727 .51304 L F
.302 .369 .766 r
.775 .51463 m .77741 .51452 L .77727 .51304 L F
.775 .51463 m .77614 .51627 L .77741 .51452 L F
.689 .662 .819 r
.74922 .50796 m .75279 .51067 L .75167 .50735 L F
.699 .662 .81 r
.75167 .50735 m .75279 .51067 L .75516 .50784 L F
.648 .442 .591 r
.48544 .68225 m .48788 .68206 L .4879 .67945 L F
.723 .533 .633 r
.48788 .68206 m .49196 .67973 L .4879 .67945 L F
.841 .794 .806 r
.45828 .67991 m .45779 .68204 L .46016 .67913 L F
.628 .68 .88 r
.7395 .50476 m .74317 .50575 L .74214 .50238 L F
.685 .65 .809 r
.74214 .50238 m .74317 .50575 L .7455 .50522 L F
0 0 .467 r
.47616 .69216 m .4767 .69411 L .47529 .69075 L F
0 0 .161 r
.4773 .69527 m .4767 .69411 L .47616 .69216 L F
.112 0 0 r
.55785 .59817 m .5569 .59823 L .55437 .59807 L F
.55437 .59807 m .5569 .59823 L .55785 .59817 L F
.388 .849 .835 r
.55785 .59817 m .55967 .59723 L .5569 .59823 L F
0 0 0 r
.55785 .59817 m .55901 .59827 L .5569 .59823 L F
.55785 .59817 m .55967 .59723 L .55901 .59827 L F
.711 .579 .706 r
.7466 .49406 m .7501 .49675 L .75034 .49427 L F
.617 .464 .652 r
.75034 .49427 m .7501 .49675 L .75267 .49637 L F
.224 .74 .727 r
.52291 .73133 m .51839 .73247 L .5209 .73226 L F
.414 .714 .986 r
.21768 .54552 m .21744 .54696 L .21593 .54595 L F
.21768 .54552 m .21936 .54683 L .21744 .54696 L F
.518 .295 .515 r
.19242 .57205 m .19405 .57084 L .19471 .56899 L F
.539 .565 .83 r
.19376 .56603 m .19471 .56899 L .19682 .56753 L F
.535 .413 .659 r
.19405 .57084 m .19682 .56753 L .19471 .56899 L F
.742 .368 .343 r
.45136 .62389 m .45504 .62443 L .45338 .62635 L F
.88 .57 .459 r
.45338 .62635 m .45504 .62443 L .45515 .62624 L F
.934 .864 .747 r
.19884 .57711 m .2002 .57807 L .201 .57578 L F
.973 .765 .564 r
.19884 .57711 m .19997 .58053 L .2002 .57807 L F
.761 .54 .597 r
.2002 .57807 m .19997 .58053 L .20335 .58082 L F
.424 .749 .994 r
.54632 .71132 m .54255 .71054 L .54486 .7106 L F
.228 0 .066 r
.54516 .71316 m .54632 .71132 L .54486 .7106 L F
.493 .407 .687 r
.3206 .60401 m .32259 .60357 L .32213 .60114 L F
.461 .385 .685 r
.3206 .60401 m .32316 .60595 L .32259 .60357 L F
.3206 .60401 m .32097 .60751 L .32316 .60595 L F
.855 .997 .802 r
.47206 .66949 m .4719 .67098 L .47387 .66871 L F
0 0 .492 r
.47206 .66949 m .473 .67302 L .4719 .67098 L F
.503 .687 .95 r
.4494 .59432 m .44845 .59586 L .44731 .5944 L F
.4494 .59432 m .45077 .59558 L .44845 .59586 L F
.567 .833 .995 r
.63314 .43178 m .63051 .4329 L .62936 .43191 L F
.471 .217 .447 r
.54094 .65892 m .54325 .6586 L .54372 .65648 L F
.727 .401 .427 r
.48678 .70497 m .4829 .7019 L .48682 .70252 L F
.48678 .70497 m .48071 .70485 L .4829 .7019 L F
.122 0 .192 r
.54372 .65648 m .54519 .65598 L .54608 .6537 L F
.3 .282 .671 r
.54372 .65648 m .54563 .65834 L .54519 .65598 L F
.557 .296 .476 r
.54325 .6586 m .54563 .65834 L .54372 .65648 L F
.54325 .6586 m .54563 .65834 L .54372 .65648 L F
.763 .686 .777 r
.4792 .67888 m .47992 .6821 L .47829 .67875 L F
.425 .53 .86 r
.47992 .6821 m .4792 .67888 L .47829 .67875 L F
.763 .686 .777 r
.4792 .67888 m .47614 .68271 L .47992 .6821 L F
.608 .216 .276 r
.47992 .6821 m .47558 .68424 L .4781 .68404 L F
.47992 .6821 m .47614 .68271 L .47558 .68424 L F
.425 .53 .86 r
.47992 .6821 m .48077 .67952 L .4792 .67888 L F
.47992 .6821 m .48165 .68221 L .48077 .67952 L F
.774 .529 .565 r
.4781 .68404 m .48165 .68221 L .47992 .6821 L F
.939 .573 .268 r
.49242 .69059 m .49021 .68676 L .49154 .68819 L F
.43 .201 .463 r
.32633 .59434 m .32883 .59159 L .32692 .59187 L F
.409 .234 .53 r
.20933 .62129 m .20921 .62368 L .20729 .62407 L F
.298 .142 .495 r
.20921 .62368 m .20691 .62674 L .20729 .62407 L F
.313 0 0 r
.39936 .63339 m .39769 .63516 L .39554 .63544 L F
.505 .048 .102 r
.40096 .63452 m .39769 .63516 L .39936 .63339 L F
.475 .072 .195 r
.40173 .6333 m .40096 .63452 L .39936 .63339 L F
.696 .164 0 r
.56976 .63272 m .57083 .63401 L .57121 .63351 L F
.598 .047 0 r
.5719 .63462 m .57121 .63351 L .57083 .63401 L F
.5719 .63462 m .57336 .63549 L .57121 .63351 L F
.291 .491 .881 r
.35537 .63928 m .35611 .6376 L .35399 .63904 L F
.35537 .63928 m .35768 .64022 L .35611 .6376 L F
.079 0 .242 r
.78445 .49953 m .78678 .49641 L .78573 .49851 L F
.999 .836 .525 r
.78578 .49499 m .78678 .49641 L .78662 .49235 L F
.982 .889 .655 r
.78573 .49851 m .78678 .49641 L .78578 .49499 L F
.78573 .49851 m .78578 .49499 L .78779 .49687 L F
.78573 .49851 m .78779 .49687 L .78779 .49688 L F
.079 0 .242 r
.78415 .49993 m .78445 .49953 L .78573 .49851 L F
.585 .482 .703 r
.78718 .50215 m .78415 .49993 L .78573 .49851 L F
.78718 .50215 m .78481 .50313 L .78415 .49993 L F
.792 .708 .771 r
.50558 .6912 m .50273 .69116 L .50463 .6877 L F
.387 .229 .542 r
.50773 .68698 m .50558 .6912 L .50463 .6877 L F
.50773 .68698 m .50731 .69077 L .50558 .6912 L F
.36 .269 .615 r
.50768 .69268 m .50558 .6912 L .50731 .69077 L F
.739 .577 .673 r
.45426 .68232 m .45628 .68463 L .45779 .68204 L F
.531 .366 .602 r
.27558 .88244 m .27558 .88553 L .27349 .88599 L F
.57 .738 .955 r
.27349 .88599 m .27558 .88553 L .27159 .88447 L F
.783 .349 .219 r
.20652 .5599 m .20235 .5574 L .20394 .55844 L F
0 0 0 r
.38445 .59292 m .38266 .59373 L .3805 .59426 L F
.38678 .59289 m .38266 .59373 L .38445 .59292 L F
.678 .443 .56 r
.64194 .45909 m .63926 .4614 L .6392 .45918 L F
.684 .657 .817 r
.47186 .68585 m .47483 .68821 L .47425 .68526 L F
0 0 .152 r
.47425 .68526 m .47483 .68821 L .47461 .68698 L F
.842 .998 .822 r
.47461 .68698 m .47483 .68821 L .47412 .68791 L F
.568 .404 .619 r
.47733 .68886 m .47529 .69075 L .47483 .68821 L F
.66 .318 .382 r
.57572 .59834 m .57953 .59809 L .57801 .60036 L F
.678 .339 .393 r
.57953 .59809 m .58208 .60005 L .57801 .60036 L F
.706 .298 .272 r
.58129 .59865 m .58208 .60005 L .57953 .59809 L F
.283 .381 .786 r
.18959 .55774 m .19028 .55707 L .18909 .55646 L F
0 0 0 r
.18886 .55896 m .19028 .55707 L .18959 .55774 L F
.84 .803 .815 r
.62154 .45307 m .61909 .45251 L .62141 .44952 L F
.864 .768 .755 r
.62154 .45307 m .62004 .45578 L .61909 .45251 L F
.15 .693 .793 r
.39647 .59152 m .39483 .59151 L .39258 .59176 L F
.082 .642 .757 r
.39856 .59139 m .39483 .59151 L .39647 .59152 L F
.6 .782 .968 r
.77537 .49247 m .77387 .49448 L .77303 .49216 L F
.77537 .49247 m .77655 .49383 L .77387 .49448 L F
.977 .708 .306 r
.57665 .64675 m .57742 .6493 L .57754 .64765 L F
.57742 .6493 m .57761 .64945 L .57754 .64765 L F
.945 .77 .634 r
.57608 .64927 m .57763 .65001 L .57665 .64675 L F
.821 .876 .885 r
.5805 .64765 m .57697 .64894 L .57867 .64726 L F
.57697 .64894 m .57608 .64927 L .57673 .64876 L F
.57697 .64894 m .57673 .64876 L .57867 .64726 L F
.977 .708 .306 r
.57742 .6493 m .57763 .65001 L .57761 .64945 L F
.647 .573 .758 r
.41672 .589 m .41771 .59258 L .41954 .59117 L F
.983 .758 .518 r
.55156 .66536 m .55194 .66806 L .55053 .66707 L F
.866 .815 .798 r
.59926 .66719 m .60295 .66518 L .60154 .66393 L F
.777 .822 .888 r
.60154 .66393 m .60295 .66518 L .60506 .66343 L F
0 0 .485 r
.45157 .69103 m .4515 .69433 L .45263 .69368 L F
.201 .175 .603 r
.4515 .69433 m .45357 .6953 L .45263 .69368 L F
.4515 .69433 m .45199 .69693 L .45357 .6953 L F
.067 0 0 r
.37575 .58203 m .37809 .5819 L .37578 .58175 L F
.25 .212 .619 r
.45627 .68751 m .45676 .69114 L .45617 .68933 L F
0 0 0 r
.4775 .70749 m .47607 .70904 L .47826 .70596 L F
.185 .203 .646 r
.4775 .70749 m .47555 .70553 L .47826 .70596 L F
0 0 0 r
.47959 .70492 m .47826 .70596 L .48114 .70754 L F
.47959 .70492 m .4775 .70749 L .47826 .70596 L F
.841 .772 .786 r
.45871 .68753 m .46239 .68623 L .46266 .68531 L F
.293 .333 .732 r
.46239 .68623 m .46337 .68473 L .46266 .68531 L F
.46239 .68623 m .46451 .68675 L .46337 .68473 L F
0 .266 .771 r
.46239 .68623 m .46581 .68967 L .46579 .68992 L F
.242 .39 .812 r
.46239 .68623 m .46579 .68992 L .46451 .68675 L F
.644 .818 .967 r
.55156 .66536 m .55323 .66357 L .55139 .66183 L F
.55156 .66536 m .55408 .66484 L .55323 .66357 L F
.52 .844 .549 r
.4648 .70209 m .46614 .7009 L .46774 .69938 L F
.429 0 .112 r
.41914 .62687 m .41781 .62873 L .41556 .62887 L F
.325 0 .045 r
.42155 .62647 m .41781 .62873 L .41914 .62687 L F
.717 .725 .857 r
.73858 .50185 m .7395 .50476 L .74214 .50238 L F
0 .243 .755 r
.50588 .64953 m .50762 .64929 L .50768 .64715 L F
.50588 .64953 m .50603 .64931 L .50762 .64929 L F
.091 0 0 r
.38716 .62418 m .39075 .62345 L .38836 .62372 L F
.375 .459 .819 r
.43865 .58553 m .43835 .58894 L .4366 .58594 L F
.43865 .58553 m .44003 .58886 L .43835 .58894 L F
.723 .533 .633 r
.48788 .68206 m .49141 .68217 L .49196 .67973 L F
.372 .148 .439 r
.52718 .63844 m .52677 .64081 L .52471 .64166 L F
.135 0 .231 r
.52608 .64267 m .52471 .64166 L .52677 .64081 L F
.52608 .64267 m .52442 .64399 L .52471 .64166 L F
.091 .032 .491 r
.45266 .69028 m .45157 .69103 L .45263 .69368 L F
.208 0 0 r
.39082 .63572 m .38903 .63689 L .38671 .63716 L F
.206 0 0 r
.3932 .63545 m .38903 .63689 L .39082 .63572 L F
.824 .715 .744 r
.55684 .69352 m .55761 .69648 L .55955 .69326 L F
0 0 .471 r
.19119 .56062 m .18868 .56092 L .18942 .56018 L F
.19119 .56062 m .19189 .56148 L .18868 .56092 L F
.19119 .56062 m .19259 .5628 L .19189 .56148 L F
.477 .313 .579 r
.32224 .59837 m .32428 .59794 L .32451 .59509 L F
.518 .338 .576 r
.32224 .59837 m .32413 .60045 L .32428 .59794 L F
.32224 .59837 m .32213 .60114 L .32413 .60045 L F
.425 .228 .507 r
.53884 .65521 m .5367 .65598 L .5368 .65344 L F
.719 .76 .885 r
.63882 .44522 m .63648 .44686 L .63529 .44476 L F
.564 .577 .825 r
.728 .49281 m .72853 .4946 L .73045 .49234 L F
.57 .587 .83 r
.72853 .4946 m .73133 .49548 L .73045 .49234 L F
.724 .681 .808 r
.52864 .67306 m .52574 .67372 L .52796 .67081 L F
.469 .169 .373 r
.52864 .67306 m .52582 .67619 L .52574 .67372 L F
.52864 .67306 m .52796 .67583 L .52582 .67619 L F
.569 .541 .784 r
.53034 .67009 m .52864 .67306 L .52796 .67081 L F
.53034 .67009 m .53116 .67283 L .52864 .67306 L F
.555 .248 .402 r
.53149 .67443 m .52864 .67306 L .53116 .67283 L F
.53149 .67443 m .52796 .67583 L .52864 .67306 L F
.728 .714 .837 r
.46863 .72256 m .47003 .7248 L .47287 .72271 L F
0 0 0 r
.51081 .67821 m .51398 .67651 L .51155 .67668 L F
.785 .326 .153 r
.58138 .63659 m .58127 .63802 L .57946 .63556 L F
.773 .541 .583 r
.58383 .63565 m .58127 .63802 L .58138 .63659 L F
.45 .778 .998 r
.4055 .58122 m .40779 .5809 L .40933 .58192 L F
.532 .816 .998 r
.40933 .58192 m .4099 .5804 L .41154 .58134 L F
.40933 .58192 m .40779 .5809 L .4099 .5804 L F
.703 .219 0 r
.54659 .62255 m .54674 .62213 L .54398 .62059 L F
.54659 .62255 m .54768 .62353 L .54674 .62213 L F
.54 .655 .91 r
.79683 .51676 m .79835 .5149 L .79554 .51537 L F
.79683 .51676 m .7993 .51647 L .79835 .5149 L F
.692 .98 .823 r
.52461 .67287 m .52796 .67081 L .52574 .67372 L F
.718 .81 .922 r
.80525 .51215 m .80187 .51181 L .80397 .51047 L F
.742 .384 .374 r
.5084 .7025 m .50726 .70451 L .50698 .70196 L F
.5084 .7025 m .51054 .70498 L .50726 .70451 L F
.946 .623 .388 r
.5084 .7025 m .50698 .70196 L .50726 .70031 L F
.402 .245 .552 r
.48065 .676 m .47829 .67875 L .47776 .67656 L F
.363 .395 .761 r
.47776 .67656 m .4792 .67888 L .47829 .67875 L F
.941 .869 .738 r
.62614 .43901 m .62428 .43992 L .62465 .43779 L F
.62614 .43901 m .62495 .44083 L .62428 .43992 L F
.934 .864 .747 r
.19884 .57711 m .201 .57578 L .20106 .57462 L F
.381 .187 .489 r
.52638 .68826 m .52807 .6899 L .52819 .68751 L F
.52638 .68826 m .52615 .69073 L .52807 .6899 L F
.873 .778 .753 r
.60853 .65541 m .61207 .65333 L .61083 .65243 L F
.60853 .65541 m .61026 .65657 L .61207 .65333 L F
.424 .246 .534 r
.22501 .58617 m .22324 .58915 L .22313 .58674 L F
.764 .555 .614 r
.27159 .88447 m .27558 .88553 L .27558 .88244 L F
.492 .335 .596 r
.27558 .88244 m .27769 .88497 L .27558 .88553 L F
.763 .25 0 r
.27592 .88415 m .27558 .88244 L .27558 .88553 L F
.27592 .88415 m .27769 .88497 L .27558 .88244 L F
.737 .495 .563 r
.50773 .68698 m .50463 .6877 L .50462 .68526 L F
.926 .631 .464 r
.6041 .63584 m .60436 .63828 L .60604 .63888 L F
.92 .598 .417 r
.60436 .63828 m .60472 .64056 L .60604 .63888 L F
.935 .625 .43 r
.60604 .63888 m .60472 .64056 L .60627 .6412 L F
.419 .346 .668 r
.32151 .60993 m .32316 .60595 L .32097 .60751 L F
.486 .098 .23 r
.50064 .67288 m .50305 .67273 L .50425 .67058 L F
.368 0 .011 r
.50305 .67273 m .50652 .67105 L .50425 .67058 L F
.308 .065 .374 r
.54948 .67076 m .54714 .67371 L .54938 .67233 L F
.431 .192 .45 r
.54714 .67371 m .54966 .67505 L .54938 .67233 L F
.54714 .67371 m .54674 .67599 L .54966 .67505 L F
.608 .461 .657 r
.48229 .65342 m .48483 .65313 L .48497 .65061 L F
.658 .469 .618 r
.4833 .65469 m .48483 .65313 L .48229 .65342 L F
.531 .003 0 r
.55139 .66183 m .55198 .66257 L .54926 .66198 L F
.55139 .66183 m .55323 .66357 L .55198 .66257 L F
.492 .442 .73 r
.44005 .59875 m .44133 .59465 L .43906 .59517 L F
.44005 .59875 m .44202 .5983 L .44133 .59465 L F
.503 .498 .784 r
.44005 .59875 m .44269 .59994 L .44202 .5983 L F
0 0 .015 r
.54608 .6537 m .54675 .65439 L .54459 .65187 L F
.54608 .6537 m .54519 .65598 L .54675 .65439 L F
.289 .066 .392 r
.20691 .62674 m .2069 .62917 L .20502 .63001 L F
.298 .142 .495 r
.20921 .62368 m .20905 .62628 L .20691 .62674 L F
.314 .106 .429 r
.20905 .62628 m .2069 .62917 L .20691 .62674 L F
0 0 0 r
.54629 .60161 m .5486 .59933 L .54637 .59965 L F
.577 .527 .763 r
.54629 .60161 m .5486 .59933 L .54637 .59965 L F
.583 .329 .497 r
.51022 .67077 m .50875 .671 L .51108 .6692 L F
.51022 .67077 m .51006 .6731 L .50875 .671 L F
.51022 .67077 m .51252 .67283 L .51006 .6731 L F
.623 .319 .435 r
.51297 .67089 m .51252 .67283 L .51022 .67077 L F
.526 .095 .165 r
.52735 .69453 m .5272 .69579 L .52355 .69607 L F
.553 .118 .169 r
.52735 .69453 m .52942 .69588 L .5272 .69579 L F
.515 .164 .31 r
.53001 .69373 m .52942 .69588 L .52735 .69453 L F
.689 .161 0 r
.24463 .78505 m .24457 .78318 L .24421 .78432 L F
.72 .988 .833 r
.64151 .42747 m .63843 .4295 L .64131 .42921 L F
.626 .77 .949 r
.64355 .42639 m .64151 .42747 L .64002 .42567 L F
.64355 .42639 m .64151 .42747 L .64002 .42567 L F
.278 .006 .309 r
.64355 .42639 m .64151 .42747 L .64131 .42921 L F
.742 .661 .77 r
.47029 .71095 m .47326 .71122 L .47263 .7084 L F
.318 .221 .585 r
.47326 .71122 m .47561 .71276 L .47493 .71025 L F
.47326 .71122 m .47364 .71409 L .47561 .71276 L F
.244 0 .03 r
.53002 .63698 m .52918 .63824 L .52718 .63844 L F
.29 .051 .368 r
.52918 .63824 m .52677 .64081 L .52718 .63844 L F
.659 .771 .932 r
.36361 .64053 m .36515 .64227 L .36706 .64112 L F
.112 0 .066 r
.36706 .64112 m .36397 .64376 L .36515 .64227 L F
.36706 .64112 m .36397 .64376 L .36515 .64227 L F
.107 0 0 r
.47508 .62378 m .47199 .62586 L .47316 .62477 L F
.501 .256 .474 r
.50513 .65243 m .5028 .65297 L .50354 .65099 L F
.50513 .65243 m .5028 .65297 L .50354 .65099 L F
.274 .455 .857 r
.19577 .58018 m .19256 .5775 L .19419 .57927 L F
.321 .51 .886 r
.46634 .71901 m .46729 .72056 L .46821 .71935 L F
.941 .781 .654 r
.73849 .48735 m .73944 .49068 L .74007 .48835 L F
.985 .836 .615 r
.53958 .62173 m .53939 .624 L .53818 .62335 L F
.545 0 0 r
.54117 .62466 m .53818 .62335 L .53939 .624 L F
.247 0 .149 r
.32675 .61865 m .3233 .62182 L .32583 .62092 L F
.528 .561 .833 r
.32514 .61519 m .32675 .61865 L .32861 .61805 L F
.603 .528 .743 r
.3233 .62182 m .32381 .62322 L .32526 .6229 L F
.3254 .62245 m .32526 .6229 L .32618 .62269 L F
.3233 .62182 m .32526 .6229 L .3254 .62245 L F
.603 .767 .958 r
.32302 .62222 m .32381 .62322 L .32526 .6229 L F
.32534 .62257 m .32526 .6229 L .32618 .62269 L F
.32302 .62222 m .32526 .6229 L .32534 .62257 L F
.603 .528 .743 r
.3233 .62182 m .3254 .62245 L .32583 .62092 L F
.771 .807 .323 r
.32583 .62092 m .32559 .62177 L .32565 .62165 L F
.32583 .62092 m .32565 .62165 L .32602 .62044 L F
.603 .528 .743 r
.3254 .62245 m .326 .62176 L .32555 .62192 L F
.347 .078 .355 r
.32675 .61865 m .32626 .61998 L .32852 .61816 L F
.32626 .61998 m .32555 .62192 L .32639 .62086 L F
.32626 .61998 m .32639 .62086 L .32852 .61816 L F
.32555 .62192 m .326 .62176 L .32861 .61805 L F
.603 .528 .743 r
.3254 .62245 m .32618 .62269 L .326 .62176 L F
.894 .801 .749 r
.32618 .62269 m .32571 .62217 L .326 .62176 L F
.855 .731 .726 r
.32571 .62216 m .32601 .62236 L .32862 .62102 L F
0 0 .265 r
.32613 .62239 m .32618 .62269 L .32601 .62236 L F
.878 .885 .835 r
.32862 .62102 m .32613 .62239 L .32618 .62269 L F
0 0 .265 r
.32626 .62242 m .32618 .62269 L .32613 .62239 L F
.878 .885 .835 r
.32613 .62239 m .32606 .62243 L .32618 .62269 L F
0 .308 .801 r
.32618 .62269 m .32623 .62266 L .32606 .62243 L F
.32618 .62269 m .32606 .62243 L .32601 .62236 L F
.603 .767 .958 r
.32497 .62251 m .32618 .62269 L .32571 .62217 L F
.855 .731 .726 r
.32579 .62206 m .32571 .62216 L .32583 .62212 L F
.347 .078 .355 r
.3254 .62231 m .32571 .62216 L .32861 .61805 L F
.32675 .61865 m .32554 .62194 L .32861 .61805 L F
.32554 .62194 m .32564 .62199 L .32861 .61805 L F
.855 .731 .726 r
.32601 .62236 m .32613 .62239 L .32862 .62102 L F
.32861 .61805 m .32579 .62206 L .32862 .62102 L F
.32579 .62206 m .32583 .62212 L .32862 .62102 L F
0 0 .265 r
.32708 .61957 m .32626 .62242 L .3257 .62178 L F
0 .308 .801 r
.32587 .62209 m .32701 .62217 L .3257 .62178 L F
0 0 .265 r
.32626 .62242 m .32601 .62236 L .3257 .62178 L F
0 .308 .801 r
.32601 .62236 m .32634 .6223 L .32587 .62209 L F
0 0 .265 r
.32649 .62161 m .32661 .62242 L .32618 .62269 L F
0 .308 .801 r
.32634 .6223 m .32701 .62217 L .32587 .62209 L F
.347 .078 .355 r
.32554 .62194 m .3254 .62231 L .32564 .62199 L F
.603 .767 .958 r
.32497 .62251 m .32618 .62269 L .32587 .62209 L F
.347 .078 .355 r
.3254 .62231 m .32518 .62292 L .32571 .62216 L F
.603 .767 .958 r
.32302 .62222 m .32497 .62251 L .3257 .62178 L F
.347 .078 .355 r
.32555 .62192 m .3254 .62231 L .326 .62176 L F
.3254 .62231 m .32544 .62229 L .326 .62176 L F
.32539 .62234 m .32567 .62222 L .326 .62176 L F
.603 .528 .743 r
.32555 .62192 m .326 .62176 L .32583 .62092 L F
.894 .801 .749 r
.326 .62176 m .32571 .62217 L .32583 .62092 L F
.771 .807 .323 r
.32548 .622 m .3254 .62231 L .32565 .62165 L F
.32583 .62092 m .32547 .62203 L .32559 .62177 L F
.894 .801 .749 r
.32571 .62217 m .3255 .62193 L .32583 .62092 L F
.603 .767 .958 r
.32548 .622 m .32587 .62209 L .3257 .62178 L F
.32497 .62251 m .3254 .62231 L .32548 .622 L F
.3254 .62231 m .32587 .62209 L .32548 .622 L F
.32497 .62251 m .32571 .62217 L .32552 .62196 L F
.771 .807 .323 r
.32547 .62203 m .32539 .62234 L .3254 .62231 L F
.32547 .62203 m .3254 .62231 L .32548 .622 L F
.347 .078 .355 r
.3254 .62231 m .32539 .62234 L .32544 .62229 L F
.32539 .62234 m .32518 .62292 L .32567 .62222 L F
.771 .807 .323 r
.32547 .62203 m .32518 .62292 L .32539 .62234 L F
.894 .801 .749 r
.32571 .62217 m .32518 .62292 L .3255 .62193 L F
.603 .767 .958 r
.32552 .62196 m .32587 .62209 L .3257 .62178 L F
.32571 .62217 m .32587 .62209 L .32552 .62196 L F
.894 .801 .749 r
.32618 .62269 m .32518 .62292 L .32571 .62217 L F
.603 .767 .958 r
.32497 .62251 m .32381 .62322 L .32618 .62269 L F
.878 .885 .835 r
.32606 .62243 m .32518 .62292 L .32618 .62269 L F
.855 .731 .726 r
.32601 .62236 m .32609 .62242 L .32613 .62239 L F
0 .308 .801 r
.32623 .62266 m .32701 .62217 L .32601 .62236 L F
.603 .767 .958 r
.32571 .62217 m .32618 .62269 L .32601 .62236 L F
.32571 .62217 m .32601 .62236 L .32571 .62216 L F
.855 .731 .726 r
.32571 .62216 m .32518 .62292 L .32609 .62242 L F
.603 .767 .958 r
.32571 .62216 m .32601 .62236 L .32587 .62209 L F
0 0 .265 r
.32708 .61957 m .32701 .62217 L .32661 .62242 L F
.32708 .61957 m .32661 .62242 L .32649 .62161 L F
.603 .767 .958 r
.32302 .62222 m .32497 .62251 L .3257 .62178 L F
.32302 .62222 m .32368 .62305 L .32497 .62251 L F
.32368 .62305 m .32381 .62322 L .32497 .62251 L F
.347 .078 .355 r
.3286 .61805 m .32852 .61816 L .32861 .61805 L F
.32675 .61865 m .32852 .61816 L .3286 .61805 L F
.771 .807 .323 r
.32602 .62044 m .32565 .62165 L .32675 .61865 L F
.369 .78 .981 r
.79251 .48536 m .79672 .48599 L .79569 .48471 L F
.754 .823 .906 r
.79672 .48599 m .79882 .48489 L .79569 .48471 L F
.67 .566 .729 r
.45309 .60619 m .45703 .60708 L .45633 .6013 L F
.504 .285 .515 r
.53544 .68804 m .53515 .69027 L .53275 .69094 L F
.593 .18 .229 r
.53784 .68813 m .53757 .68949 L .53544 .68804 L F
.152 .309 .77 r
.53644 .68711 m .53757 .68949 L .53544 .68804 L F
.482 .266 .508 r
.53757 .68949 m .53544 .68804 L .53644 .68711 L F
.53757 .68949 m .53515 .69027 L .53544 .68804 L F
.661 .82 .96 r
.58738 .66726 m .59089 .66766 L .58954 .66673 L F
.586 .706 .925 r
.59089 .66766 m .59225 .66472 L .58954 .66673 L F
.59089 .66766 m .5951 .66826 L .59225 .66472 L F
.723 .629 .753 r
.45006 .60333 m .45382 .60432 L .45231 .60347 L F
.964 .673 .431 r
.45231 .60347 m .45382 .60432 L .4519 .6004 L F
.185 0 0 r
.36844 .59869 m .36759 .598 L .37 .59761 L F
.36844 .59869 m .36622 .59925 L .36759 .598 L F
.569 .47 .702 r
.475 .70384 m .4791 .70093 L .47612 .70141 L F
.766 .7 .79 r
.47321 .70371 m .47555 .70553 L .47455 .70369 L F
.47411 .70347 m .47455 .70369 L .47439 .7034 L F
.47321 .70371 m .47455 .70369 L .47411 .70347 L F
.569 .47 .702 r
.47534 .70408 m .47959 .70492 L .4791 .70093 L F
.948 .76 .615 r
.47379 .70228 m .47455 .70369 L .47461 .7047 L F
.47455 .70369 m .47555 .70553 L .47461 .7047 L F
.569 .47 .702 r
.47461 .7047 m .47677 .70479 L .47534 .70408 L F
.47677 .70479 m .47959 .70492 L .47534 .70408 L F
.47461 .7047 m .47534 .70408 L .475 .70384 L F
.47534 .70408 m .4791 .70093 L .475 .70384 L F
.766 .7 .79 r
.47358 .70281 m .47439 .7034 L .47379 .70228 L F
.47321 .70371 m .47439 .7034 L .47358 .70281 L F
.47321 .70371 m .47123 .70479 L .47555 .70553 L F
.139 0 0 r
.34821 .58508 m .35052 .58483 L .35227 .584 L F
.36 0 0 r
.35052 .58483 m .35451 .58374 L .35227 .584 L F
.511 .571 .853 r
.57776 .66217 m .57867 .65887 L .57634 .65936 L F
.57776 .66217 m .58002 .6621 L .57867 .65887 L F
.172 .221 .673 r
.79274 .51426 m .79241 .51044 L .79567 .51113 L F
.79274 .51426 m .79436 .51295 L .79241 .51044 L F
.337 .52 .889 r
.79274 .51426 m .79554 .51537 L .79436 .51295 L F
.499 .265 .491 r
.53275 .69094 m .53228 .69332 L .53001 .69373 L F
.388 .125 .389 r
.53515 .69027 m .53228 .69332 L .53275 .69094 L F
.718 .349 .349 r
.48064 .69647 m .47831 .69856 L .48173 .69871 L F
.141 .679 .842 r
.64894 .44624 m .64499 .44608 L .64741 .44626 L F
.234 0 0 r
.64741 .44626 m .6513 .44662 L .64894 .44624 L F
.135 .092 .54 r
.54948 .67076 m .55026 .67218 L .55075 .66931 L F
.535 .245 .42 r
.54938 .67233 m .55026 .67218 L .54948 .67076 L F
0 0 0 r
.39033 .59224 m .38897 .59252 L .38678 .59289 L F
.39258 .59176 m .38897 .59252 L .39033 .59224 L F
.521 .459 .728 r
.32151 .60993 m .32231 .61396 L .32415 .61151 L F
.58 .479 .704 r
.32231 .61396 m .32514 .61519 L .32415 .61151 L F
.32231 .61396 m .32296 .61601 L .32514 .61519 L F
.531 .408 .657 r
.35771 .6135 m .35618 .61571 L .35534 .61213 L F
.35771 .6135 m .35836 .61522 L .35618 .61571 L F
.573 .504 .739 r
.35836 .61522 m .3567 .61813 L .35618 .61571 L F
.6 .794 .973 r
.79305 .50956 m .79567 .51113 L .79241 .51044 L F
.544 .777 .985 r
.79305 .50956 m .79708 .5095 L .79567 .51113 L F
.44 .616 .925 r
.79708 .5095 m .79809 .51113 L .79567 .51113 L F
.573 .504 .739 r
.35836 .61522 m .35928 .61868 L .3567 .61813 L F
.497 .259 .484 r
.50535 .70269 m .50726 .70451 L .50698 .70196 L F
.50535 .70269 m .50467 .70515 L .50726 .70451 L F
.771 .583 .644 r
.5038 .69912 m .50698 .70196 L .50726 .70031 L F
.389 .076 .309 r
.50726 .70031 m .50698 .70196 L .5094 .69988 L F
.215 .613 .951 r
.3499 .63895 m .35001 .63805 L .3485 .63717 L F
.3499 .63895 m .35182 .63944 L .35001 .63805 L F
.529 .33 .555 r
.53983 .66784 m .53954 .67055 L .53736 .67088 L F
.603 .409 .591 r
.54227 .66757 m .53954 .67055 L .53983 .66784 L F
0 0 .5 r
.55733 .69114 m .5579 .68722 L .56016 .68891 L F
.91 .946 .814 r
.55989 .69098 m .55974 .68889 L .55879 .69029 L F
.55851 .69159 m .55879 .69029 L .55763 .69198 L F
.55989 .69098 m .55879 .69029 L .55851 .69159 L F
0 0 .5 r
.55733 .69114 m .55874 .69051 L .5579 .68722 L F
.55874 .69051 m .55874 .69051 L .55874 .69051 L F
.55874 .69051 m .55874 .69051 L .5579 .68722 L F
0 0 0 r
.55763 .69198 m .55733 .69114 L .55788 .6921 L F
.55763 .69198 m .55874 .69051 L .55733 .69114 L F
.601 .549 .768 r
.19997 .58053 m .2031 .58337 L .20335 .58082 L F
.1 0 .309 r
.2031 .58337 m .20497 .58 L .20335 .58082 L F
0 0 .056 r
.50051 .68543 m .50055 .68753 L .5006 .68383 L F
.644 .818 .967 r
.2724 .84437 m .2707 .84533 L .26864 .84408 L F
.2724 .84437 m .2707 .84533 L .26864 .84408 L F
.526 .865 .993 r
.41028 .58825 m .41135 .58692 L .40889 .58767 L F
.41028 .58825 m .41275 .58764 L .41135 .58692 L F
.622 .534 .734 r
.7455 .50522 m .74671 .50867 L .74922 .50796 L F
.875 .582 .488 r
.53958 .62173 m .53818 .62335 L .53735 .62048 L F
.442 .7 .975 r
.54029 .62072 m .53958 .62173 L .53735 .62048 L F
.654 .967 .909 r
.54124 .62074 m .53958 .62173 L .54029 .62072 L F
.613 .86 .505 r
.53958 .62173 m .53818 .62335 L .54029 .62072 L F
.985 .836 .615 r
.53958 .62173 m .53818 .62335 L .54029 .62072 L F
0 0 0 r
.51234 .65325 m .51322 .65308 L .51474 .65036 L F
.634 .468 .64 r
.51786 .65246 m .51497 .65355 L .51474 .65036 L F
.658 .331 .408 r
.51703 .65277 m .51416 .65478 L .51497 .65355 L F
.51786 .65246 m .51731 .6528 L .51703 .65277 L F
.51731 .6528 m .51416 .65478 L .51703 .65277 L F
.714 .402 .448 r
.51474 .65036 m .51735 .65281 L .51571 .64897 L F
.658 .331 .408 r
.51731 .6528 m .51723 .65329 L .51416 .65478 L F
.655 .321 .395 r
.51416 .65478 m .51749 .65334 L .51741 .6532 L F
.51749 .65334 m .51779 .65321 L .51756 .65321 L F
.51749 .65334 m .51756 .65321 L .51741 .6532 L F
.714 .402 .448 r
.51763 .65306 m .51779 .65321 L .51776 .65316 L F
.51756 .653 m .51762 .65306 L .51763 .65306 L F
.51762 .65306 m .51779 .65321 L .51763 .65306 L F
.655 .321 .395 r
.51416 .65478 m .51697 .65482 L .51779 .65321 L F
.508 .294 .523 r
.51769 .65306 m .51697 .65482 L .51762 .6531 L F
.51697 .65482 m .51983 .65197 L .51779 .65321 L F
.51983 .65197 m .51868 .65311 L .51769 .65306 L F
.51868 .65311 m .51697 .65482 L .51769 .65306 L F
.51798 .65243 m .51762 .6531 L .51786 .65246 L F
.51983 .65197 m .51762 .6531 L .51798 .65243 L F
.658 .331 .408 r
.51723 .65329 m .51719 .65349 L .51416 .65478 L F
.714 .402 .448 r
.51756 .653 m .51741 .6532 L .51779 .65321 L F
.658 .331 .408 r
.51763 .65306 m .51697 .65482 L .51731 .6528 L F
.655 .321 .395 r
.51416 .65478 m .51741 .6532 L .51322 .65308 L F
.714 .402 .448 r
.51474 .65036 m .51322 .65308 L .51741 .6532 L F
.51474 .65036 m .51741 .6532 L .51756 .653 L F
.658 .331 .408 r
.51719 .65349 m .51697 .65482 L .51621 .65481 L F
.51719 .65349 m .51621 .65481 L .51416 .65478 L F
.51786 .65246 m .51763 .65306 L .51731 .6528 L F
.714 .402 .448 r
.51735 .65281 m .51756 .653 L .5176 .65284 L F
.51756 .653 m .51776 .65316 L .5176 .65284 L F
.51735 .65281 m .5176 .65284 L .51571 .64897 L F
0 0 0 r
.52582 .67619 m .52277 .67812 L .52387 .67706 L F
.501 .322 .569 r
.3594 .60889 m .35781 .61078 L .35811 .61142 L F
.541 .397 .635 r
.35612 .60719 m .35781 .61078 L .35451 .61023 L F
.35781 .61078 m .35811 .61142 L .3572 .61111 L F
.35781 .61078 m .3572 .61111 L .35451 .61023 L F
.501 .322 .569 r
.35781 .61078 m .35725 .61145 L .35811 .61142 L F
.572 .416 .631 r
.3594 .60889 m .35811 .61142 L .3579 .61073 L F
.501 .322 .569 r
.3594 .60889 m .35939 .60991 L .3579 .61073 L F
.3594 .60889 m .3579 .61073 L .35781 .61078 L F
.572 .416 .631 r
.3594 .60889 m .3579 .61073 L .3566 .60628 L F
.541 .397 .635 r
.3566 .60628 m .35811 .61142 L .35612 .60719 L F
.501 .322 .569 r
.35781 .61078 m .35939 .61128 L .35725 .61145 L F
.35939 .60991 m .35939 .61128 L .35781 .61078 L F
.559 .361 .569 r
.35451 .61023 m .35811 .61142 L .35725 .61145 L F
.511 .572 .853 r
.35725 .61145 m .35534 .61213 L .35451 .61023 L F
.727 .295 .224 r
.42992 .62369 m .43356 .62441 L .43209 .62591 L F
.2 0 0 r
.43604 .62467 m .43209 .62591 L .43356 .62441 L F
.417 .063 .255 r
.65619 .45364 m .65563 .45514 L .65326 .45565 L F
.515 .369 .621 r
.65815 .44999 m .65619 .45364 L .65558 .45082 L F
.65815 .44999 m .65848 .45308 L .65619 .45364 L F
.363 .014 .232 r
.65848 .45308 m .65563 .45514 L .65619 .45364 L F
.549 .408 .641 r
.53954 .67055 m .53762 .67341 L .53736 .67088 L F
.587 .368 .551 r
.44158 .59193 m .44303 .59339 L .44479 .59366 L F
.417 .492 .829 r
.44203 .58854 m .44158 .59193 L .44003 .58886 L F
.44203 .58854 m .44322 .59161 L .44158 .59193 L F
.587 .368 .551 r
.44332 .59367 m .44133 .59465 L .44379 .59414 L F
.44158 .59193 m .44137 .59416 L .44332 .59367 L F
.44137 .59416 m .44133 .59465 L .44332 .59367 L F
.069 0 .386 r
.44155 .59392 m .44133 .59465 L .44138 .59414 L F
.44155 .59392 m .44138 .59414 L .44158 .59193 L F
.44155 .59392 m .44322 .59161 L .44344 .59227 L F
.816 .918 .906 r
.4421 .5932 m .44155 .59392 L .44232 .59325 L F
.069 0 .386 r
.44155 .59392 m .44158 .59193 L .44322 .59161 L F
.816 .918 .906 r
.44128 .59304 m .44155 .59392 L .4421 .5932 L F
.539 .403 .644 r
.43874 .59483 m .44155 .59392 L .43776 .59381 L F
.43906 .59517 m .44074 .59433 L .43874 .59483 L F
.44074 .59433 m .44155 .59392 L .43874 .59483 L F
.816 .918 .906 r
.44025 .5898 m .44128 .59304 L .44344 .59227 L F
.44128 .59304 m .44232 .59325 L .44344 .59227 L F
.587 .368 .551 r
.44303 .59339 m .44379 .59414 L .4447 .59371 L F
.44303 .59339 m .4447 .59371 L .44479 .59366 L F
.172 0 0 r
.44379 .59414 m .44731 .5944 L .44479 .59366 L F
.9 .556 .384 r
.55981 .63561 m .55767 .63341 L .55854 .63392 L F
.621 .704 .904 r
.53292 .63559 m .53002 .63698 L .53005 .63468 L F
.592 .179 .229 r
.53225 .63811 m .52918 .63824 L .53002 .63698 L F
.487 .346 .615 r
.53292 .63559 m .53283 .63591 L .53254 .63577 L F
.77 .633 .709 r
.53581 .63829 m .53292 .63559 L .5344 .63678 L F
.53581 .63829 m .53225 .63811 L .53292 .63559 L F
0 .319 .726 r
.53092 .63478 m .5344 .63678 L .53292 .63559 L F
.53092 .63478 m .53403 .63628 L .53427 .63661 L F
.53314 .63606 m .53427 .63661 L .5344 .63678 L F
.53092 .63478 m .53427 .63661 L .53314 .63606 L F
.487 .346 .615 r
.53254 .63577 m .53225 .63811 L .53002 .63698 L F
.53283 .63591 m .53225 .63811 L .53254 .63577 L F
.149 .595 .931 r
.65262 .44968 m .65543 .45052 L .65558 .45082 L F
.409 .857 .899 r
.65543 .45052 m .65815 .44999 L .65558 .45082 L F
.631 .343 .462 r
.56871 .59645 m .56859 .59502 L .56919 .59647 L F
.56871 .59645 m .57104 .59524 L .56859 .59502 L F
.439 .261 .541 r
.5668 .59691 m .56973 .59566 L .56556 .59604 L F
.144 .46 .887 r
.56795 .59642 m .56871 .59645 L .56715 .59676 L F
.56973 .59566 m .56871 .59645 L .56793 .59642 L F
.631 .343 .462 r
.56871 .59645 m .56919 .59647 L .56987 .59812 L F
.199 .639 .948 r
.56987 .59812 m .57071 .5975 L .56871 .59645 L F
.519 .916 .828 r
.56715 .59676 m .56621 .59786 L .56871 .59645 L F
.56709 .59678 m .56706 .59681 L .56715 .59676 L F
.56706 .59681 m .56621 .59786 L .56715 .59676 L F
.56709 .59678 m .56621 .59786 L .56871 .59645 L F
.631 .343 .462 r
.56871 .59645 m .57071 .5975 L .57104 .59524 L F
.89 .487 .246 r
.56871 .59645 m .56793 .59771 L .56709 .59678 L F
.144 .46 .887 r
.56973 .59566 m .57071 .5975 L .56871 .59645 L F
.638 .129 .022 r
.56871 .59645 m .56928 .59847 L .56793 .59771 L F
.56871 .59645 m .57071 .5975 L .5698 .59812 L F
.56911 .59789 m .5698 .59812 L .56928 .59847 L F
.56871 .59645 m .5698 .59812 L .56911 .59789 L F
.439 .261 .541 r
.56767 .59739 m .56973 .59566 L .56715 .59676 L F
.56793 .59771 m .56809 .59754 L .56767 .59739 L F
.56809 .59754 m .56973 .59566 L .56767 .59739 L F
.56683 .59693 m .56715 .59676 L .5668 .59691 L F
.56793 .59771 m .56715 .59676 L .56683 .59693 L F
.144 .46 .887 r
.56793 .59642 m .56795 .59642 L .56709 .59678 L F
.56795 .59642 m .56715 .59676 L .56709 .59678 L F
.199 .639 .948 r
.56987 .59812 m .57218 .59843 L .57071 .5975 L F
.325 .03 .301 r
.46446 .67048 m .46632 .66994 L .467 .66731 L F
.148 .691 .804 r
.46632 .66994 m .47197 .6696 L .467 .66731 L F
.497 .234 .446 r
.51019 .68489 m .51017 .6869 L .50773 .68698 L F
.46 .212 .45 r
.51237 .68449 m .51017 .6869 L .51019 .68489 L F
.515 .532 .812 r
.45773 .68568 m .45871 .68753 L .45627 .68751 L F
.29 .241 .629 r
.45867 .69011 m .45627 .68751 L .45871 .68753 L F
.45867 .69011 m .45676 .69114 L .45627 .68751 L F
.795 .511 .508 r
.6166 .45586 m .61775 .4564 L .61449 .45577 L F
.746 .641 .743 r
.61772 .4589 m .61449 .45577 L .61775 .4564 L F
.717 .633 .762 r
.62004 .45578 m .61775 .4564 L .6166 .45586 L F
.7 .56 .693 r
.62004 .45578 m .61772 .4589 L .61775 .4564 L F
.685 .65 .809 r
.74214 .50238 m .7455 .50522 L .74447 .50166 L F
.682 .618 .778 r
.74447 .50166 m .7455 .50522 L .74796 .50219 L F
.659 .584 .76 r
.7455 .50522 m .74905 .50552 L .74796 .50219 L F
.622 .534 .734 r
.7455 .50522 m .74922 .50796 L .74905 .50552 L F
.752 .422 .425 r
.48286 .68394 m .48375 .68431 L .48311 .68376 L F
.58 .424 .634 r
.48545 .68727 m .48216 .68415 L .48326 .68426 L F
.48401 .68475 m .48326 .68426 L .48375 .68431 L F
.48545 .68727 m .48326 .68426 L .48401 .68475 L F
.07 .241 .732 r
.48201 .6836 m .48293 .68423 L .48216 .68415 L F
.58 .424 .634 r
.48545 .68727 m .48303 .68771 L .48216 .68415 L F
.41 .298 .615 r
.4781 .68404 m .48054 .68563 L .48283 .68397 L F
.48265 .68379 m .48286 .68394 L .48311 .68376 L F
.774 .529 .565 r
.48265 .68379 m .48311 .68376 L .48165 .68221 L F
0 .041 .565 r
.48311 .68376 m .48375 .68431 L .48165 .68221 L F
.07 .241 .732 r
.48165 .68221 m .48375 .68431 L .48293 .68423 L F
.41 .298 .615 r
.48279 .68394 m .48283 .68397 L .48286 .68394 L F
.4781 .68404 m .48283 .68397 L .48279 .68394 L F
.752 .422 .425 r
.48054 .68563 m .48375 .68431 L .48286 .68394 L F
.07 .241 .732 r
.48191 .68321 m .48251 .6838 L .48201 .6836 L F
.48251 .6838 m .48293 .68423 L .48201 .6836 L F
.48165 .68221 m .48265 .68379 L .48191 .68321 L F
.48265 .68379 m .48293 .68423 L .48191 .68321 L F
.41 .298 .615 r
.4781 .68404 m .48286 .68394 L .48265 .68379 L F
.774 .529 .565 r
.4781 .68404 m .48265 .68379 L .48165 .68221 L F
0 .065 .625 r
.45629 .70206 m .45759 .70538 L .45801 .70423 L F
0 .104 .655 r
.45801 .70423 m .45759 .70538 L .45942 .70756 L F
.745 .274 0 r
.56733 .64524 m .56739 .64592 L .5664 .64414 L F
.56733 .64524 m .56867 .64712 L .56739 .64592 L F
.707 .728 .867 r
.78159 .51836 m .78534 .51908 L .78404 .51658 L F
.807 .79 .837 r
.78404 .51658 m .78534 .51908 L .78704 .51655 L F
.717 .633 .762 r
.62004 .45578 m .6166 .45586 L .61909 .45251 L F
.964 .67 .424 r
.48482 .69574 m .48636 .69908 L .48575 .69669 L F
.58 .415 .622 r
.47989 .6563 m .48252 .65879 L .4833 .65469 L F
.47989 .6563 m .48009 .65926 L .48252 .65879 L F
.799 .967 .657 r
.33082 .63571 m .33093 .63461 L .3327 .63308 L F
0 .117 .669 r
.33082 .63571 m .33256 .6374 L .33093 .63461 L F
.26 0 0 r
.39873 .62292 m .40104 .62275 L .40268 .62159 L F
.083 0 0 r
.40268 .62159 m .40323 .62223 L .40495 .62111 L F
.40268 .62159 m .40104 .62275 L .40323 .62223 L F
.678 .443 .56 r
.64194 .45909 m .64198 .46151 L .63926 .4614 L F
.62 .398 .558 r
.64525 .46058 m .64194 .45909 L .64521 .45886 L F
.64525 .46058 m .64198 .46151 L .64194 .45909 L F
.394 .712 .986 r
.36763 .62347 m .36692 .62488 L .36557 .62333 L F
.36763 .62347 m .36916 .62475 L .36692 .62488 L F
.593 .606 .834 r
.58356 .66451 m .58501 .6678 L .58738 .66726 L F
.034 .014 .5 r
.19506 .58371 m .19612 .58263 L .19577 .58018 L F
.157 .064 .49 r
.19477 .58609 m .19612 .58263 L .19506 .58371 L F
.711 .579 .706 r
.7466 .49406 m .74789 .49726 L .7501 .49675 L F
.674 .438 .556 r
.74699 .4986 m .7501 .49675 L .74789 .49726 L F
.74699 .4986 m .75027 .49927 L .7501 .49675 L F
.607 .387 .557 r
.7501 .49675 m .75277 .49858 L .75267 .49637 L F
.7501 .49675 m .75027 .49927 L .75277 .49858 L F
0 .08 .605 r
.56152 .63861 m .56262 .63939 L .56023 .63763 L F
.56152 .63861 m .56359 .64062 L .56262 .63939 L F
.149 0 .02 r
.53228 .69332 m .52942 .69588 L .53001 .69373 L F
.762 .681 .773 r
.79161 .51809 m .79467 .51983 L .79303 .51907 L F
.373 .236 .562 r
.64201 .43701 m .64007 .43581 L .64315 .43551 L F
.64201 .43701 m .64029 .43839 L .64007 .43581 L F
.513 .368 .622 r
.48734 .65026 m .48936 .64727 L .48702 .6478 L F
.583 .603 .838 r
.48544 .68225 m .48906 .68501 L .48788 .68206 L F
.72 .631 .757 r
.48788 .68206 m .48906 .68501 L .49141 .68217 L F
.525 .353 .59 r
.48906 .68501 m .49138 .68482 L .49141 .68217 L F
.653 .459 .608 r
.47263 .7084 m .47555 .70553 L .47123 .70479 L F
.514 .875 .644 r
.7881 .47673 m .78482 .47925 L .78706 .4773 L F
0 0 .34 r
.78512 .48155 m .78706 .4773 L .78482 .47925 L F
.725 .614 .734 r
.66282 .44134 m .65912 .44144 L .66165 .43805 L F
.565 .361 .564 r
.66146 .44356 m .65912 .44144 L .66282 .44134 L F
.626 .618 .822 r
.66376 .43795 m .66567 .44137 L .66282 .44134 L F
.687 .358 .413 r
.66534 .44342 m .66146 .44356 L .66282 .44134 L F
.626 .388 .538 r
.66567 .44137 m .66534 .44342 L .66282 .44134 L F
.418 .735 .991 r
.41599 .58063 m .41516 .58191 L .41375 .58091 L F
.97 .769 .577 r
.59564 .61187 m .59541 .61506 L .59689 .61551 L F
.964 .794 .623 r
.59474 .61506 m .59689 .61551 L .59541 .61506 L F
.59474 .61506 m .59579 .61841 L .59689 .61551 L F
.619 .35 .489 r
.52819 .68751 m .53086 .68535 L .52825 .68524 L F
.21 0 0 r
.40784 .63107 m .40615 .63235 L .40518 .63182 L F
.119 0 0 r
.40935 .63112 m .40784 .63107 L .40996 .63034 L F
.40935 .63112 m .40615 .63235 L .40784 .63107 L F
.64 .908 .603 r
.4779 .66231 m .47908 .6607 L .48082 .66348 L F
.353 .74 .986 r
.64252 .44595 m .63882 .44522 L .64172 .44439 L F
.558 .553 .805 r
.64412 .44335 m .64252 .44595 L .64172 .44439 L F
.64412 .44335 m .64499 .44608 L .64252 .44595 L F
.419 .346 .668 r
.32151 .60993 m .32329 .60963 L .32316 .60595 L F
.438 .473 .798 r
.32151 .60993 m .32415 .61151 L .32329 .60963 L F
.568 .57 .815 r
.19028 .55707 m .18837 .5545 L .18909 .55646 L F
.733 .59 .696 r
.74473 .49692 m .74789 .49726 L .7466 .49406 L F
.723 .513 .605 r
.74473 .49692 m .74699 .4986 L .74789 .49726 L F
.37 .131 .416 r
.5163 .66683 m .5159 .66682 L .51602 .66715 L F
.163 .698 .839 r
.57701 .63625 m .578 .63651 L .57448 .63672 L F
.762 .825 .901 r
.32967 .62808 m .33081 .62999 L .33142 .62719 L F
.429 .566 .89 r
.33347 .62668 m .33494 .62513 L .33232 .62329 L F
.133 .263 .733 r
.33356 .62581 m .33347 .62668 L .33232 .62329 L F
.44 .853 .688 r
.33356 .62581 m .33142 .62719 L .33347 .62668 L F
.33356 .62581 m .32967 .62808 L .33142 .62719 L F
.366 .365 .726 r
.33142 .62719 m .33393 .6295 L .33347 .62668 L F
.773 .646 .722 r
.74313 .49355 m .74473 .49692 L .7466 .49406 L F
.385 0 .152 r
.51973 .67318 m .51858 .67533 L .52087 .67489 L F
.51973 .67318 m .51858 .67533 L .52087 .67489 L F
.6 .579 .802 r
.52087 .67489 m .51858 .67533 L .51723 .67181 L F
.385 0 .152 r
.51973 .67318 m .52087 .67489 L .52126 .67302 L F
.6 .579 .802 r
.52087 .67489 m .51723 .67181 L .51987 .67118 L F
0 .08 .617 r
.52086 .6735 m .52064 .67599 L .52087 .67489 L F
.792 .685 .746 r
.51843 .67768 m .52226 .67856 L .52087 .67489 L F
.698 .535 .664 r
.52087 .67489 m .52052 .6773 L .51843 .67768 L F
0 .08 .617 r
.52064 .67599 m .52052 .6773 L .52087 .67489 L F
.385 0 .152 r
.52126 .67302 m .52087 .67489 L .52207 .67294 L F
.763 .473 .493 r
.58872 .63316 m .58914 .63517 L .58568 .63494 L F
.829 .612 .61 r
.49711 .68709 m .49663 .69034 L .4958 .68795 L F
0 .32 .796 r
.55837 .68528 m .56134 .68749 L .56183 .68536 L F
.756 .477 .51 r
.50438 .65938 m .50427 .66171 L .50187 .6608 L F
.557 .291 .468 r
.50759 .65926 m .50427 .66171 L .50438 .65938 L F
.661 .112 0 r
.46305 .69663 m .46092 .69456 L .45946 .69403 L F
.632 .24 .284 r
.46505 .6958 m .46201 .69489 L .46305 .69663 L F
0 0 .364 r
.46395 .69815 m .46305 .69663 L .46193 .69473 L F
.955 .878 .719 r
.46398 .69821 m .46505 .6958 L .46305 .69663 L F
0 0 .364 r
.46398 .69821 m .46305 .69663 L .46395 .69815 L F
.632 .24 .284 r
.46201 .69489 m .46092 .69456 L .46305 .69663 L F
.327 .756 .972 r
.18494 .54277 m .18676 .54267 L .18888 .54347 L F
.099 .636 .859 r
.18676 .54267 m .19134 .54342 L .18888 .54347 L F
0 0 .482 r
.58239 .62694 m .58242 .62601 L .5811 .62376 L F
.57 .395 .606 r
.21927 .6006 m .21695 .6036 L .21698 .60096 L F
.17 0 0 r
.40518 .63182 m .40096 .63452 L .40173 .6333 L F
.40518 .63182 m .40294 .634 L .40096 .63452 L F
.166 0 0 r
.40518 .63182 m .40615 .63235 L .40294 .634 L F
.749 .612 .706 r
.47555 .70553 m .47607 .70904 L .47263 .7084 L F
.706 .287 .249 r
.47607 .70904 m .47493 .71025 L .47263 .7084 L F
.185 .203 .646 r
.4775 .70749 m .47607 .70904 L .47555 .70553 L F
.695 .273 .24 r
.47493 .71025 m .47852 .71087 L .47607 .70904 L F
.523 .821 .489 r
.4775 .70749 m .47493 .71025 L .47607 .70904 L F
.746 .641 .743 r
.61772 .4589 m .61412 .45871 L .61449 .45577 L F
.806 .516 .499 r
.61648 .46021 m .61412 .45871 L .61772 .4589 L F
.287 .347 .751 r
.77614 .51627 m .77777 .51686 L .77741 .51452 L F
.861 .685 .662 r
.19984 .58341 m .20121 .5842 L .19997 .58053 L F
.683 .381 .456 r
.19984 .58341 m .20228 .58594 L .20121 .5842 L F
.601 .549 .768 r
.19997 .58053 m .20121 .5842 L .2031 .58337 L F
.528 .37 .611 r
.20121 .5842 m .2034 .58583 L .2031 .58337 L F
.692 .208 .095 r
.20121 .5842 m .20228 .58594 L .2034 .58583 L F
.566 .18 .27 r
.41868 .61688 m .42244 .61481 L .41954 .61614 L F
.41868 .61688 m .42119 .61706 L .42244 .61481 L F
.551 .21 .345 r
.42119 .61706 m .42471 .61454 L .42244 .61481 L F
.686 .141 0 r
.57572 .59834 m .57614 .59978 L .57379 .59822 L F
.57572 .59834 m .57801 .60036 L .57614 .59978 L F
.399 .078 .301 r
.36185 .60085 m .36084 .60346 L .35891 .60372 L F
.426 .112 .329 r
.36398 .6002 m .36084 .60346 L .36185 .60085 L F
.278 0 0 r
.51355 .63546 m .51584 .63508 L .51692 .63383 L F
.325 0 0 r
.51692 .63383 m .51584 .63508 L .51921 .63442 L F
.477 .353 .632 r
.54002 .68496 m .53958 .68837 L .53784 .68813 L F
.457 .06 .198 r
.53958 .68837 m .53757 .68949 L .53784 .68813 L F
.573 .499 .734 r
.51849 .66781 m .52101 .66763 L .51943 .66409 L F
.692 .289 .278 r
.45826 .6264 m .45754 .62731 L .45515 .62624 L F
.538 .17 .29 r
.46081 .62636 m .45754 .62731 L .45826 .6264 L F
.1 0 0 r
.35451 .58374 m .35676 .58368 L .35814 .58342 L F
.029 0 0 r
.35814 .58342 m .35863 .58362 L .36044 .58369 L F
.35814 .58342 m .35676 .58368 L .35863 .58362 L F
.405 .034 .218 r
.48126 .66432 m .48039 .66667 L .47802 .6671 L F
.308 0 .178 r
.48253 .66603 m .48126 .66432 L .48082 .66348 L F
.48253 .66603 m .48039 .66667 L .48126 .66432 L F
.626 .294 .389 r
.46666 .62895 m .46999 .62656 L .46918 .62898 L F
.46666 .62895 m .46695 .62728 L .46999 .62656 L F
.253 0 .183 r
.4712 .62814 m .46999 .62656 L .47199 .62586 L F
.4712 .62814 m .46918 .62898 L .46999 .62656 L F
.284 .124 .48 r
.21507 .60914 m .21477 .61164 L .21271 .6126 L F
.349 .242 .59 r
.21465 .61428 m .21271 .6126 L .21477 .61164 L F
.21465 .61428 m .21307 .61501 L .21271 .6126 L F
.591 .257 .372 r
.50373 .69746 m .50006 .69878 L .50092 .69635 L F
0 0 0 r
.5055 .69482 m .5038 .69912 L .50373 .69746 L F
.577 .527 .763 r
.54629 .60161 m .54876 .60112 L .5486 .59933 L F
0 0 0 r
.54629 .60161 m .54771 .6009 L .5486 .59933 L F
.368 .822 .934 r
.54771 .6009 m .54876 .60112 L .54629 .60161 L F
0 0 0 r
.46757 .68786 m .46581 .68967 L .46579 .68992 L F
.613 .946 .937 r
.78082 .48749 m .77962 .48743 L .77861 .48852 L F
.598 .218 .293 r
.78706 .4773 m .79042 .47512 L .7881 .47673 L F
.602 .418 .606 r
.49446 .6416 m .49716 .64112 L .49691 .63862 L F
.526 .31 .529 r
.49716 .64112 m .49934 .63853 L .49691 .63862 L F
.575 .604 .845 r
.58123 .66497 m .58215 .66145 L .58002 .6621 L F
.58123 .66497 m .58356 .66451 L .58215 .66145 L F
.661 .413 .534 r
.7554 .49606 m .75846 .49598 L .75843 .49372 L F
.496 .248 .469 r
.75846 .49598 m .76102 .49332 L .75843 .49372 L F
.532 .526 .794 r
.58059 .63797 m .57946 .63556 L .58127 .63802 L F
.58059 .63797 m .5798 .63498 L .57946 .63556 L F
.622 .865 .989 r
.6166 .45586 m .61449 .45577 L .61551 .45431 L F
.908 .949 .816 r
.6166 .45586 m .61773 .45135 L .61909 .45251 L F
.6166 .45586 m .61551 .45431 L .61773 .45135 L F
.115 0 .299 r
.19686 .59235 m .19746 .592 L .19887 .58887 L F
.149 .063 .494 r
.19692 .59493 m .19746 .592 L .19686 .59235 L F
.061 .62 .8 r
.54044 .71294 m .54486 .7106 L .54255 .71054 L F
.511 .572 .853 r
.35725 .61145 m .35771 .6135 L .35534 .61213 L F
.416 .262 .563 r
.19272 .57476 m .19405 .57084 L .19242 .57205 L F
.449 .282 .562 r
.51004 .68981 m .50773 .68698 L .51017 .6869 L F
.51004 .68981 m .50731 .69077 L .50773 .68698 L F
.688 .351 .399 r
.33614 .63537 m .33521 .63796 L .33256 .6374 L F
.269 0 .224 r
.33728 .63705 m .33614 .63537 L .33804 .63464 L F
.33728 .63705 m .33521 .63796 L .33614 .63537 L F
.744 .831 .918 r
.79569 .48471 m .79882 .48489 L .798 .48335 L F
.419 .65 .954 r
.798 .48335 m .79882 .48489 L .80016 .48339 L F
.818 .667 .696 r
.5976 .63229 m .60117 .63025 L .59999 .62938 L F
.5976 .63229 m .60118 .63296 L .60117 .63025 L F
.898 .61 .491 r
.59935 .63447 m .60118 .63296 L .5976 .63229 L F
.59935 .63447 m .60169 .63548 L .60118 .63296 L F
.691 .695 .849 r
.32552 .6298 m .32943 .63081 L .32725 .62934 L F
.773 .819 .889 r
.32725 .62934 m .32943 .63081 L .33081 .62999 L F
.976 .872 .668 r
.55323 .66357 m .55408 .66484 L .55221 .66718 L F
.79 .502 .5 r
.55408 .66484 m .55455 .66735 L .55221 .66718 L F
.211 0 0 r
.39428 .62332 m .39075 .62345 L .39294 .62397 L F
.446 0 0 r
.39294 .62397 m .39642 .62357 L .39428 .62332 L F
.639 .343 .452 r
.64521 .45886 m .64767 .46089 L .64525 .46058 L F
.664 .329 .396 r
.64767 .45918 m .64767 .46089 L .64521 .45886 L F
.509 0 0 r
.49431 .70437 m .49633 .70587 L .49476 .70481 L F
.727 .42 .459 r
.49918 .70635 m .49633 .70587 L .49875 .70519 L F
.49918 .70635 m .49476 .70481 L .49633 .70587 L F
.653 .459 .608 r
.47263 .7084 m .47577 .70877 L .47555 .70553 L F
.339 .223 .572 r
.47555 .70553 m .47577 .70877 L .4775 .70749 L F
.47555 .70553 m .4775 .70749 L .47461 .7047 L F
.404 0 0 r
.52274 .63396 m .52574 .63489 L .52632 .63407 L F
.347 0 0 r
.52632 .63407 m .52711 .6348 L .53005 .63468 L F
.52632 .63407 m .52574 .63489 L .52711 .6348 L F
.543 .66 .913 r
.42573 .58193 m .42461 .58401 L .42344 .58219 L F
.519 .63 .9 r
.42664 .58368 m .42461 .58401 L .42573 .58193 L F
.479 .307 .569 r
.45223 .68475 m .45456 .68472 L .45628 .68463 L F
.61 .948 .926 r
.45628 .68463 m .45456 .68472 L .45672 .68362 L F
.005 .279 .779 r
.45672 .68362 m .45773 .68568 L .45628 .68463 L F
0 0 .465 r
.55218 .64946 m .55278 .6519 L .5521 .65281 L F
0 .231 .743 r
.55278 .6519 m .55431 .65506 L .5521 .65281 L F
.029 .245 .747 r
.5521 .65281 m .55431 .65506 L .55433 .65646 L F
.472 .289 .551 r
.72637 .4874 m .72906 .48678 L .72628 .48503 L F
.572 .179 .259 r
.6251 .46145 m .62393 .46338 L .62142 .46192 L F
.769 .45 .448 r
.62733 .4619 m .62393 .46338 L .6251 .46145 L F
.393 .005 .179 r
.50517 .67606 m .50427 .67815 L .50177 .67857 L F
.57 .412 .627 r
.50759 .67343 m .50766 .67591 L .50517 .67606 L F
.674 .372 .455 r
.50766 .67591 m .50427 .67815 L .50517 .67606 L F
.802 .967 .658 r
.3327 .63308 m .33093 .63461 L .33321 .6314 L F
.777 .701 .78 r
.46265 .61781 m .46533 .61826 L .46443 .616 L F
.757 .368 .316 r
.46265 .61781 m .46414 .62008 L .46533 .61826 L F
.524 .38 .627 r
.46533 .61826 m .46775 .61801 L .46681 .61607 L F
.804 .639 .678 r
.46414 .62008 m .46775 .61801 L .46533 .61826 L F
.46 0 0 r
.39205 .58119 m .39573 .58136 L .39353 .58175 L F
.981 .756 .526 r
.47895 .73977 m .47774 .73631 L .47882 .73742 L F
.79 .297 .02 r
.47774 .73631 m .47895 .73977 L .47882 .73742 L F
.915 .803 .722 r
.60853 .65541 m .60898 .65884 L .61026 .65657 L F
.432 0 .067 r
.48952 .71026 m .48918 .70869 L .48963 .70892 L F
.787 .984 .723 r
.50994 .64949 m .5095 .65069 L .51166 .64808 L F
0 0 .023 r
.56003 .6625 m .55993 .66428 L .55985 .66426 L F
.85 .749 .234 r
.55985 .66426 m .56021 .66461 L .55971 .66424 L F
.55985 .66426 m .55984 .66728 L .56021 .66461 L F
0 0 .023 r
.55993 .66428 m .55989 .66507 L .55985 .66426 L F
.85 .749 .234 r
.55985 .66426 m .55971 .66424 L .55889 .66365 L F
.895 .664 .582 r
.59498 .62065 m .59672 .62386 L .59676 .62126 L F
0 .424 .759 r
.54868 .62741 m .54968 .62745 L .54748 .62628 L F
.884 .66 .594 r
.55176 .62814 m .55168 .62825 L .55225 .62767 L F
.421 .759 .995 r
.55176 .62814 m .54968 .62745 L .55211 .6285 L F
0 .424 .759 r
.55147 .6283 m .55211 .6285 L .55158 .62827 L F
.884 .66 .594 r
.55176 .62814 m .55319 .63173 L .55028 .63019 L F
.55168 .62825 m .55028 .63019 L .55183 .62822 L F
.55168 .62825 m .55183 .62822 L .55225 .62767 L F
0 .424 .759 r
.54868 .62741 m .55147 .6283 L .54968 .62745 L F
.55147 .6283 m .55158 .62827 L .54968 .62745 L F
.844 .996 .76 r
.81158 .50491 m .80896 .50711 L .81031 .50852 L F
.81158 .50491 m .81132 .5042 L .80896 .50711 L F
.803 .577 .015 r
.81105 .50173 m .81132 .5042 L .81158 .50491 L F
.536 .261 .446 r
.65326 .45565 m .65084 .45715 L .65109 .45594 L F
.769 .45 .448 r
.62733 .4619 m .62747 .46392 L .62393 .46338 L F
.718 .479 .563 r
.63125 .46159 m .62747 .46392 L .62733 .4619 L F
.225 .107 .501 r
.2069 .62917 m .20524 .63269 L .20502 .63001 L F
.619 .662 .871 r
.41954 .59117 m .42342 .59256 L .42227 .58934 L F
.536 .537 .804 r
.42342 .59256 m .42433 .58934 L .42227 .58934 L F
.42342 .59256 m .42548 .59216 L .42433 .58934 L F
.956 .666 .23 r
.55984 .66728 m .56015 .66975 L .56087 .67037 L F
.594 .117 .093 r
.53357 .72294 m .53195 .72431 L .53084 .72311 L F
.119 .278 .752 r
.53229 .71955 m .53357 .72294 L .53566 .7195 L F
.53229 .71955 m .53449 .72154 L .53357 .72294 L F
.653 .916 .612 r
.53449 .72154 m .53195 .72431 L .53357 .72294 L F
.684 .733 .888 r
.5951 .66826 m .5945 .66365 L .59225 .66472 L F
.5951 .66826 m .59655 .66674 L .5945 .66365 L F
.715 .791 .912 r
.59682 .66758 m .59655 .66674 L .5951 .66826 L F
.5 .717 .968 r
.41672 .589 m .41736 .58706 L .41511 .58741 L F
.41672 .589 m .41872 .58854 L .41736 .58706 L F
.647 .573 .758 r
.41672 .589 m .41954 .59117 L .41872 .58854 L F
.721 .612 .735 r
.46272 .67625 m .4663 .67654 L .46506 .67353 L F
.689 .509 .638 r
.4663 .67654 m .46627 .6792 L .46891 .67634 L F
.956 .783 .627 r
.60993 .64679 m .61089 .65004 L .61139 .64758 L F
0 0 0 r
.51804 .73114 m .51938 .72796 L .51753 .7304 L F
0 .448 .755 r
.79671 .47471 m .79875 .47529 L .80001 .47578 L F
.772 .469 .475 r
.79875 .47529 m .8028 .47778 L .80001 .47578 L F
.639 .448 .608 r
.49437 .64403 m .49716 .64112 L .49446 .6416 L F
.288 .749 .95 r
.54115 .67869 m .54475 .67907 L .54382 .67914 L F
.596 .179 .222 r
.62142 .46192 m .62043 .46358 L .61792 .46343 L F
.579 .161 .213 r
.62393 .46338 m .62043 .46358 L .62142 .46192 L F
.879 .727 .689 r
.6568 .44068 m .65709 .44111 L .65912 .44144 L F
.854 .798 .796 r
.65912 .44144 m .65709 .44111 L .65719 .44092 L F
.9 .974 .811 r
.65724 .44082 m .65682 .44082 L .6568 .44068 L F
.65912 .44144 m .65719 .44092 L .65724 .44082 L F
.65719 .44092 m .65682 .44082 L .65724 .44082 L F
.67 .801 .347 r
.65851 .43821 m .65719 .44092 L .65836 .43831 L F
.65719 .44092 m .65709 .44111 L .65713 .44102 L F
.65719 .44092 m .65713 .44102 L .65836 .43831 L F
.854 .798 .796 r
.65912 .44144 m .65719 .44092 L .65851 .43821 L F
.851 .676 .665 r
.65703 .44231 m .65709 .44111 L .6568 .44068 L F
.9 .974 .811 r
.6571 .4409 m .65703 .44231 L .65682 .44082 L F
.851 .676 .665 r
.65703 .44231 m .65702 .44075 L .65709 .44109 L F
.65703 .44231 m .65709 .44109 L .65709 .44111 L F
.9 .974 .811 r
.65912 .44144 m .65703 .44231 L .6571 .4409 L F
.65912 .44144 m .65683 .44427 L .65703 .44231 L F
.56 .357 .563 r
.65912 .44144 m .65925 .44417 L .65683 .44427 L F
.854 .798 .796 r
.65912 .44144 m .65851 .43821 L .66165 .43805 L F
.565 .361 .564 r
.66146 .44356 m .65925 .44417 L .65912 .44144 L F
.744 .67 .779 r
.5805 .64765 m .58158 .65045 L .57763 .65001 L F
.743 .539 .619 r
.47484 .67835 m .47776 .67656 L .47673 .67713 L F
.47484 .67835 m .4792 .67888 L .47776 .67656 L F
.394 .552 .893 r
.47915 .67519 m .47776 .67656 L .47636 .67435 L F
.563 .844 .997 r
.47915 .67519 m .48065 .676 L .47776 .67656 L F
.566 .91 .69 r
.47673 .67713 m .47776 .67656 L .47915 .67519 L F
.629 .505 .693 r
.47776 .67656 m .4792 .67888 L .48065 .676 L F
.762 .825 .901 r
.32967 .62808 m .32725 .62934 L .33081 .62999 L F
.538 0 0 r
.20809 .54525 m .20445 .54452 L .20628 .54496 L F
.245 0 0 r
.20628 .54496 m .21 .54572 L .20809 .54525 L F
.565 .425 .649 r
.48497 .65061 m .48711 .6526 L .48734 .65026 L F
.48497 .65061 m .48483 .65313 L .48711 .6526 L F
.119 .22 .695 r
.80457 .48095 m .8065 .48317 L .80534 .48471 L F
.128 .233 .705 r
.80534 .48471 m .8065 .48317 L .80729 .48663 L F
0 .194 .714 r
.80534 .48471 m .80729 .48663 L .80741 .48815 L F
.956 .942 .632 r
.19887 .58887 m .19746 .592 L .19701 .59075 L F
.711 .843 .945 r
.19778 .58743 m .19887 .58887 L .20162 .5865 L F
.779 .608 .668 r
.20201 .58648 m .20133 .58844 L .2016 .58667 L F
.711 .843 .945 r
.20038 .58657 m .20162 .5865 L .20228 .58594 L F
.19778 .58743 m .20162 .5865 L .20038 .58657 L F
.905 .834 .764 r
.20228 .58594 m .20218 .58621 L .2034 .58583 L F
.779 .608 .668 r
.2034 .58583 m .2016 .58667 L .20218 .58621 L F
.2034 .58583 m .20293 .58643 L .20201 .58648 L F
.20293 .58643 m .20133 .58844 L .20201 .58648 L F
.905 .834 .764 r
.20218 .58621 m .20133 .58844 L .2034 .58583 L F
.779 .608 .668 r
.2034 .58583 m .20218 .58621 L .20245 .58598 L F
.20245 .58598 m .19943 .58768 L .20155 .58613 L F
.382 .245 .567 r
.20162 .5865 m .2016 .58667 L .20228 .58594 L F
.2016 .58667 m .20218 .58621 L .20228 .58594 L F
.779 .608 .668 r
.2016 .58667 m .19943 .58768 L .20245 .58598 L F
.382 .245 .567 r
.2016 .58667 m .20133 .58844 L .20218 .58621 L F
.19887 .58887 m .20133 .58844 L .20162 .5865 L F
.779 .608 .668 r
.2016 .58667 m .20133 .58844 L .19943 .58768 L F
.696 .28 .253 r
.19701 .59075 m .20106 .59124 L .19887 .58887 L F
.391 .28 .606 r
.19887 .58887 m .20106 .59124 L .20133 .58844 L F
.359 .166 .478 r
.35891 .60372 m .3566 .60628 L .35665 .60617 L F
.35891 .60372 m .35893 .60582 L .3566 .60628 L F
.572 .416 .631 r
.3594 .60889 m .3566 .60628 L .35893 .60582 L F
.785 .741 .812 r
.63403 .44059 m .63608 .44193 L .63792 .43943 L F
.885 .667 .602 r
.63403 .44059 m .63529 .44476 L .63608 .44193 L F
.496 .329 .584 r
.32451 .59509 m .32644 .59723 L .32633 .59434 L F
.32451 .59509 m .32428 .59794 L .32644 .59723 L F
.192 .041 .434 r
.21072 .62059 m .20921 .62368 L .20933 .62129 L F
.361 .131 .424 r
.50273 .65559 m .50097 .65628 L .50058 .65853 L F
.712 .519 .626 r
.51943 .66409 m .52376 .66486 L .52315 .66188 L F
.546 .41 .647 r
.52315 .66188 m .52376 .66486 L .52547 .66142 L F
.431 .334 .644 r
.52546 .66389 m .52376 .66486 L .52315 .66188 L F
.52546 .66389 m .52376 .66486 L .52315 .66188 L F
.49 .799 .999 r
.51952 .64934 m .52289 .64986 L .52061 .65028 L F
.981 .689 .343 r
.51952 .64934 m .51983 .65197 L .52061 .65028 L F
.409 .857 .899 r
.65543 .45052 m .65741 .44983 L .65815 .44999 L F
.458 .884 .904 r
.65815 .44999 m .66 .44894 L .66059 .4494 L F
.65815 .44999 m .65741 .44983 L .66 .44894 L F
.597 .429 .625 r
.66164 .45079 m .65815 .44999 L .66059 .4494 L F
.66164 .45079 m .65848 .45308 L .65815 .44999 L F
.684 .576 .728 r
.45633 .6013 m .45703 .60708 L .45922 .6058 L F
.995 .868 .564 r
.55827 .68211 m .55742 .68163 L .55817 .67835 L F
.918 .67 .548 r
.55827 .68211 m .55638 .68382 L .55742 .68163 L F
.55827 .68211 m .55855 .68495 L .55638 .68382 L F
.777 .822 .888 r
.60154 .66393 m .60506 .66343 L .60404 .6626 L F
.745 .9 .947 r
.60404 .6626 m .60506 .66343 L .60767 .66186 L F
.475 .667 .947 r
.43105 .58301 m .43139 .58571 L .42895 .58331 L F
.43105 .58301 m .43327 .58549 L .43139 .58571 L F
.779 .649 .718 r
.74113 .49642 m .74473 .49692 L .74313 .49355 L F
.773 .559 .61 r
.74098 .49888 m .74473 .49692 L .74113 .49642 L F
.74098 .49888 m .74441 .49934 L .74473 .49692 L F
.723 .513 .605 r
.74473 .49692 m .74441 .49934 L .74699 .4986 L F
.741 .702 .814 r
.49157 .70016 m .49233 .70287 L .48918 .70217 L F
.696 .187 .023 r
.49233 .70287 m .49476 .70481 L .49391 .70385 L F
.539 .403 .644 r
.43906 .59517 m .44133 .59465 L .44155 .59392 L F
.29 .171 .54 r
.23034 .56862 m .23005 .57141 L .22864 .5719 L F
.306 .212 .582 r
.23005 .57141 m .23025 .57376 L .22864 .5719 L F
.297 .211 .586 r
.23025 .57376 m .22892 .5747 L .22864 .5719 L F
0 .048 .614 r
.46646 .71126 m .46805 .71406 L .47029 .71095 L F
.672 .484 .622 r
.46891 .67634 m .46627 .6792 L .46859 .67901 L F
.728 .641 .761 r
.46859 .67901 m .47134 .67542 L .46891 .67634 L F
.584 .046 0 r
.36119 .58332 m .36368 .58369 L .36277 .58347 L F
.36368 .58369 m .36463 .58383 L .36277 .58347 L F
.124 0 0 r
.3622 .58333 m .36277 .58347 L .36398 .58297 L F
.36044 .58369 m .36277 .58347 L .3622 .58333 L F
.282 0 0 r
.36398 .58297 m .36463 .58383 L .36628 .58324 L F
.36398 .58297 m .36277 .58347 L .36463 .58383 L F
0 .542 .769 r
.21 .54572 m .21203 .54594 L .21385 .54635 L F
.214 0 0 r
.21203 .54594 m .21593 .54595 L .21385 .54635 L F
.649 .63 .818 r
.23162 .56267 m .231 .56588 L .22945 .56314 L F
.23162 .56267 m .23308 .566 L .231 .56588 L F
.465 .248 .499 r
.23168 .56776 m .231 .56588 L .23308 .566 L F
.23168 .56776 m .23034 .56862 L .231 .56588 L F
0 0 .152 r
.47425 .68526 m .47461 .68698 L .47558 .68424 L F
.78 .682 .756 r
.53566 .7195 m .53229 .71955 L .53445 .71635 L F
.68 .276 .274 r
.53566 .7195 m .53449 .72154 L .53229 .71955 L F
.475 .325 .598 r
.53724 .71682 m .53782 .71867 L .53566 .7195 L F
.092 0 0 r
.53782 .71867 m .53449 .72154 L .53566 .7195 L F
.88 .914 .512 r
.80632 .49112 m .80741 .48815 L .80851 .49012 L F
.636 .79 .956 r
.80632 .49112 m .80851 .49012 L .80498 .48961 L F
.089 .148 .63 r
.51331 .699 m .51502 .70166 L .5139 .70245 L F
.482 .649 .932 r
.51502 .70166 m .51373 .70308 L .5139 .70245 L F
.566 .022 0 r
.5489 .64675 m .55218 .64946 L .54987 .64835 L F
.392 0 .147 r
.33971 .58793 m .34202 .58755 L .3404 .58667 L F
.416 0 .04 r
.3404 .58667 m .34202 .58755 L .3427 .58662 L F
.301 0 .027 r
.58162 .59353 m .58044 .5923 L .57923 .59376 L F
.58162 .59353 m .58278 .59181 L .58044 .5923 L F
.783 .531 .555 r
.60169 .63548 m .60436 .63828 L .6041 .63584 L F
.513 .368 .622 r
.48734 .65026 m .48977 .65011 L .48936 .64727 L F
.539 .86 .572 r
.48711 .6526 m .48977 .65011 L .48734 .65026 L F
0 .012 .583 r
.8028 .47778 m .80457 .48095 L .80386 .47899 L F
.78 .656 .726 r
.64131 .42921 m .64541 .43085 L .64355 .42639 L F
.817 .57 .566 r
.64481 .43224 m .64541 .43085 L .64131 .42921 L F
.618 .577 .786 r
.64355 .42639 m .64541 .43085 L .64715 .42929 L F
.127 0 .213 r
.64715 .42929 m .64541 .43085 L .64481 .43224 L F
.383 0 0 r
.19695 .54352 m .19867 .54409 L .20031 .5439 L F
.385 .823 .952 r
.19867 .54409 m .20268 .54394 L .20031 .5439 L F
.107 .63 .882 r
.20031 .5439 m .20268 .54394 L .20445 .54452 L F
.731 .636 .753 r
.47484 .67835 m .47614 .68271 L .4792 .67888 L F
.416 .262 .563 r
.19272 .57476 m .19448 .57395 L .19405 .57084 L F
.535 .413 .659 r
.19405 .57084 m .19707 .57102 L .19682 .56753 L F
.473 .302 .567 r
.19405 .57084 m .19663 .57282 L .19707 .57102 L F
.19405 .57084 m .19448 .57395 L .19663 .57282 L F
.491 .35 .617 r
.5811 .62376 m .58307 .6223 L .58083 .62128 L F
.197 0 .148 r
.40263 .59031 m .40107 .59054 L .40437 .58869 L F
0 0 0 r
.40672 .5882 m .40555 .58865 L .40437 .58869 L F
.40555 .58865 m .40263 .59031 L .40437 .58869 L F
.262 0 0 r
.33067 .59081 m .33395 .59028 L .33159 .59027 L F
.257 0 0 r
.33159 .59027 m .33395 .59028 L .33441 .58973 L F
.999 .839 .53 r
.59424 .60287 m .59545 .60118 L .59397 .60013 L F
.59424 .60287 m .59507 .60374 L .59545 .60118 L F
.84 .887 .874 r
.80298 .51725 m .80466 .51319 L .80185 .51596 L F
.80298 .51725 m .8058 .51452 L .80466 .51319 L F
.723 .701 .829 r
.41872 .58854 m .41954 .59117 L .42227 .58934 L F
.45 .164 .387 r
.48936 .64727 m .49192 .64669 L .49209 .64465 L F
.657 .337 .419 r
.49192 .64669 m .49437 .64676 L .49209 .64465 L F
.539 .357 .582 r
.49209 .64465 m .49437 .64676 L .49437 .64403 L F
.13 .214 .684 r
.19355 .56614 m .19376 .56603 L .19259 .5628 L F
.703 .805 .928 r
.78237 .492 m .77788 .4918 L .78113 .49023 L F
.457 .554 .866 r
.78337 .48944 m .78237 .492 L .78113 .49023 L F
.851 .434 .241 r
.58873 .59665 m .58988 .59548 L .58696 .59395 L F
.782 .332 .179 r
.58873 .59665 m .59196 .59797 L .58988 .59548 L F
.788 .302 .06 r
.58988 .59548 m .59196 .59797 L .59336 .59811 L F
.894 .578 .443 r
.5982 .62851 m .59981 .62716 L .59657 .62613 L F
.5982 .62851 m .59999 .62938 L .59981 .62716 L F
.591 .279 .41 r
.5306 .68756 m .53516 .68458 L .53086 .68535 L F
.5306 .68756 m .5319 .68789 L .53516 .68458 L F
.634 .338 .45 r
.53516 .68458 m .5319 .68789 L .53644 .68711 L F
.75 .381 .355 r
.53516 .68458 m .53644 .68711 L .53626 .68534 L F
0 .349 .729 r
.47255 .62014 m .47367 .62055 L .47253 .61987 L F
.47253 .61987 m .47255 .62014 L .47068 .62309 L F
.47253 .61987 m .47367 .62055 L .47255 .62014 L F
.469 .19 .406 r
.51567 .67032 m .51252 .67283 L .51297 .67089 L F
.415 .003 .146 r
.54258 .71523 m .54056 .71426 L .54295 .71392 L F
.54258 .71523 m .53933 .71591 L .54056 .71426 L F
.369 .433 .796 r
.45199 .69693 m .45473 .69873 L .45357 .6953 L F
.208 0 .358 r
.22293 .59184 m .22291 .59423 L .22095 .59511 L F
.276 .093 .443 r
.22291 .59423 m .22061 .59771 L .22095 .59511 L F
.718 .479 .563 r
.63125 .46159 m .62973 .464 L .62747 .46392 L F
.695 .446 .543 r
.63125 .46159 m .63334 .46398 L .62973 .464 L F
.63125 .46159 m .63331 .46171 L .63334 .46398 L F
.2 .32 .762 r
.6537 .44733 m .65262 .44968 L .6513 .44662 L F
.468 .645 .935 r
.6537 .44733 m .65543 .45052 L .65262 .44968 L F
.369 .822 .934 r
.54829 .67875 m .54475 .67907 L .54674 .67599 L F
.54829 .67875 m .54673 .67858 L .54537 .67901 L F
0 .518 .708 r
.55069 .679 m .54673 .67858 L .54829 .67875 L F
.29 0 0 r
.55069 .679 m .54707 .68108 L .54673 .67858 L F
.573 .503 .738 r
.54707 .68108 m .54841 .67804 L .54673 .67858 L F
.54841 .67804 m .54864 .67752 L .54673 .67858 L F
.369 .822 .934 r
.54537 .67901 m .54673 .67858 L .54475 .67907 L F
.496 .217 .42 r
.65084 .45715 m .64767 .46089 L .64767 .45918 L F
.492 .326 .584 r
.49141 .68217 m .49138 .68482 L .49363 .68387 L F
.883 .915 .843 r
.8062 .51284 m .80766 .51111 L .80666 .51005 L F
.979 .848 .642 r
.8058 .51452 m .8062 .51284 L .80466 .51319 L F
.841 .743 .755 r
.65878 .43648 m .66165 .43805 L .65851 .43821 L F
.459 .647 .939 r
.66309 .43623 m .66165 .43805 L .65878 .43648 L F
.66309 .43623 m .66376 .43795 L .66165 .43805 L F
.174 .711 .791 r
.36628 .58324 m .36849 .58293 L .36998 .58288 L F
.292 .752 .951 r
.36849 .58293 m .3722 .5833 L .36998 .58288 L F
.655 .098 0 r
.49419 .69215 m .49478 .6929 L .49394 .69208 L F
.49665 .69289 m .49478 .6929 L .49419 .69215 L F
.976 .671 .346 r
.49665 .69289 m .49533 .69475 L .49478 .6929 L F
0 0 .522 r
.49478 .6929 m .49533 .69475 L .49514 .69336 L F
.655 .098 0 r
.49665 .69289 m .49394 .69208 L .49399 .69144 L F
0 0 .522 r
.49478 .6929 m .49514 .69336 L .49468 .68989 L F
.655 .098 0 r
.49399 .69144 m .49394 .69208 L .49242 .69059 L F
0 .153 .674 r
.49242 .69059 m .49478 .6929 L .49468 .68989 L F
.687 .323 .351 r
.49388 .69293 m .49394 .69221 L .49468 .68989 L F
.49353 .69424 m .49393 .69229 L .49388 .69293 L F
.49393 .69229 m .49394 .69221 L .49388 .69293 L F
0 0 .035 r
.49737 .68997 m .49718 .69204 L .49665 .69289 L F
.76 .301 .158 r
.49844 .69535 m .49533 .69475 L .49665 .69289 L F
0 0 0 r
.5055 .69482 m .5046 .69815 L .5038 .69912 L F
.12 0 .132 r
.50626 .6972 m .5055 .69482 L .50692 .69516 L F
.50626 .6972 m .5046 .69815 L .5055 .69482 L F
.848 .713 .714 r
.46518 .69911 m .46774 .69938 L .46649 .69617 L F
.52 .844 .549 r
.4648 .70209 m .46774 .69938 L .46518 .69911 L F
.753 .671 .771 r
.46649 .69617 m .46774 .69938 L .47028 .69725 L F
.774 .763 .843 r
.47197 .6696 m .47206 .66949 L .47044 .66544 L F
.523 .351 .59 r
.47044 .66544 m .47443 .6633 L .47198 .66446 L F
.47044 .66544 m .4743 .66657 L .47443 .6633 L F
.741 .419 .438 r
.47197 .66825 m .47044 .66544 L .47206 .66949 L F
.47197 .66825 m .4743 .66657 L .47044 .66544 L F
.5 .357 .618 r
.47197 .6696 m .47206 .66949 L .47044 .66544 L F
.497 .561 .851 r
.48963 .70892 m .49296 .70982 L .48952 .71026 L F
.553 .399 .626 r
.49296 .70982 m .49056 .71344 L .48952 .71026 L F
.806 .516 .499 r
.61648 .46021 m .61411 .46087 L .61412 .45871 L F
.735 .43 .465 r
.61648 .46021 m .61434 .46311 L .61411 .46087 L F
.61648 .46021 m .61792 .46343 L .61434 .46311 L F
.705 .248 .164 r
.58278 .59181 m .58511 .59384 L .58624 .59243 L F
.801 .374 .233 r
.58511 .59384 m .58696 .59395 L .58624 .59243 L F
0 .102 .624 r
.78708 .51082 m .78882 .51298 L .78798 .5144 L F
.966 .921 .706 r
.78657 .51499 m .78798 .5144 L .78882 .51298 L F
.78657 .51499 m .78704 .51655 L .78798 .5144 L F
.165 .692 .866 r
.49217 .66139 m .49589 .66161 L .49438 .66133 L F
.966 .741 .547 r
.49472 .65857 m .49589 .66161 L .49438 .66133 L F
.388 0 0 r
.49589 .66161 m .49676 .66294 L .49438 .66133 L F
.49589 .66161 m .49823 .66177 L .49676 .66294 L F
.339 .345 .719 r
.49604 .66117 m .49438 .66133 L .49676 .66294 L F
.465 .868 .961 r
.49726 .65768 m .49472 .65857 L .49597 .65735 L F
.762 .541 .598 r
.49532 .65879 m .49798 .66096 L .49726 .65768 L F
0 0 .218 r
.49532 .65879 m .49472 .65857 L .49446 .66068 L F
.762 .541 .598 r
.49513 .6589 m .49529 .65901 L .49532 .65879 L F
.49529 .65901 m .49798 .66096 L .49532 .65879 L F
0 0 .218 r
.49597 .65735 m .49544 .65787 L .49532 .65879 L F
.49544 .65787 m .49472 .65857 L .49532 .65879 L F
.736 .557 .651 r
.49676 .66294 m .49798 .66096 L .49529 .65901 L F
0 0 .218 r
.49534 .65875 m .49446 .66068 L .49528 .65909 L F
.736 .557 .651 r
.49528 .65909 m .49529 .65901 L .49513 .6589 L F
.762 .541 .598 r
.49532 .65879 m .49726 .65768 L .49597 .65735 L F
0 0 .218 r
.49597 .65735 m .49534 .65875 L .49528 .65909 L F
.762 .541 .598 r
.49513 .6589 m .49532 .65879 L .49597 .65735 L F
0 0 .218 r
.49597 .65735 m .49528 .65909 L .49513 .6589 L F
.49528 .65909 m .49446 .66068 L .49438 .66133 L F
.49528 .65909 m .49438 .66133 L .49513 .6589 L F
.736 .557 .651 r
.49526 .65921 m .49528 .65909 L .49513 .6589 L F
.49676 .66294 m .49529 .65901 L .49526 .65921 L F
.339 .345 .719 r
.49513 .6589 m .49438 .66133 L .49604 .66117 L F
.165 .692 .866 r
.49217 .66139 m .49321 .66145 L .49438 .66133 L F
.49321 .66145 m .49589 .66161 L .49438 .66133 L F
.812 .822 .858 r
.80766 .51111 m .80896 .50711 L .80666 .51005 L F
.80766 .51111 m .81031 .50852 L .80896 .50711 L F
.067 0 0 r
.51108 .6692 m .51354 .66868 L .51602 .66715 L F
.82 .445 .345 r
.51354 .66868 m .5163 .66683 L .51602 .66715 L F
.675 .456 .581 r
.6378 .46159 m .63334 .46398 L .63331 .46171 L F
.183 0 0 r
.38121 .63783 m .37717 .63935 L .37888 .63834 L F
.584 .606 .84 r
.73133 .49548 m .73253 .49182 L .73045 .49234 L F
.73133 .49548 m .73374 .49504 L .73253 .49182 L F
.482 .665 .943 r
.18837 .5545 m .18964 .5534 L .18755 .55355 L F
.568 .57 .815 r
.19028 .55707 m .18964 .5534 L .18837 .5545 L F
.677 .415 .518 r
.73117 .48634 m .7347 .48435 L .73218 .48466 L F
.828 .674 .693 r
.46272 .67625 m .46261 .68021 L .4589 .6784 L F
0 0 .453 r
.46416 .67768 m .46272 .67625 L .46365 .67501 L F
.46416 .67768 m .46261 .68021 L .46272 .67625 L F
.618 .102 0 r
.4296 .59281 m .4269 .59322 L .42548 .59216 L F
.828 .959 .896 r
.43035 .59056 m .4296 .59281 L .43198 .59169 L F
.43035 .59056 m .4269 .59322 L .4296 .59281 L F
.809 .575 .584 r
.46805 .71406 m .4674 .71802 L .46469 .71615 L F
0 .048 .614 r
.46646 .71126 m .46829 .7134 L .46805 .71406 L F
.239 .061 .427 r
.46974 .71559 m .46805 .71406 L .46829 .7134 L F
.46974 .71559 m .4674 .71802 L .46805 .71406 L F
.697 .36 .401 r
.43069 .61684 m .43431 .61499 L .43134 .61595 L F
.43069 .61684 m .43324 .6174 L .43431 .61499 L F
.551 .204 .333 r
.43431 .61499 m .43703 .61642 L .43675 .61454 L F
.43431 .61499 m .43324 .6174 L .43703 .61642 L F
.915 .803 .722 r
.60853 .65541 m .60688 .65854 L .60898 .65884 L F
.893 .771 .721 r
.6062 .66083 m .60898 .65884 L .60688 .65854 L F
.6062 .66083 m .60767 .66186 L .60898 .65884 L F
.243 0 0 r
.3722 .5833 m .37457 .583 L .37575 .58203 L F
.067 0 0 r
.37575 .58203 m .37672 .5822 L .37809 .5819 L F
0 0 0 r
.37575 .58203 m .37457 .583 L .37672 .5822 L F
.544 .212 .355 r
.50727 .63752 m .50517 .63594 L .50486 .63794 L F
.50727 .63752 m .5084 .63526 L .50517 .63594 L F
.979 .915 .61 r
.62356 .44424 m .62428 .43992 L .62495 .44083 L F
.41 0 .055 r
.65925 .44417 m .65703 .44231 L .65683 .44427 L F
.82 .445 .345 r
.51354 .66868 m .51569 .66996 L .5163 .66683 L F
.727 .692 .152 r
.5163 .66683 m .51569 .66996 L .51567 .67032 L F
.659 .584 .76 r
.74796 .50219 m .74905 .50552 L .75158 .50499 L F
.642 .505 .68 r
.74905 .50552 m .74922 .50796 L .75158 .50499 L F
.327 .786 .945 r
.28386 .83256 m .28543 .83295 L .28169 .83286 L F
.28169 .83286 m .28543 .83295 L .28386 .83256 L F
.45 .85 .973 r
.28386 .83256 m .28607 .83202 L .28543 .83295 L F
.28543 .83295 m .28607 .83202 L .28386 .83256 L F
.565 .593 .84 r
.728 .49281 m .72897 .48904 L .72704 .48943 L F
.728 .49281 m .73045 .49234 L .72897 .48904 L F
.622 .899 .986 r
.20291 .57367 m .20496 .57476 L .20398 .57167 L F
.469 .518 .826 r
.20496 .57476 m .20527 .57079 L .20398 .57167 L F
.20496 .57476 m .2066 .57409 L .20527 .57079 L F
.497 .398 .673 r
.20492 .5771 m .2066 .57409 L .20496 .57476 L F
.75 .69 .794 r
.73586 .49025 m .73944 .49068 L .73849 .48735 L F
.728 .457 .517 r
.73597 .49247 m .73944 .49068 L .73586 .49025 L F
.73597 .49247 m .73964 .49303 L .73944 .49068 L F
.707 .716 .856 r
.46649 .69617 m .47028 .69725 L .46891 .69533 L F
.507 .562 .846 r
.47028 .69725 m .47106 .69376 L .46891 .69533 L F
.37 .679 .977 r
.31824 .62397 m .32047 .62402 L .31883 .62259 L F
.618 .577 .786 r
.64355 .42639 m .64715 .42929 L .64572 .42728 L F
.426 .828 .979 r
.55358 .6239 m .55567 .62346 L .55723 .62392 L F
.569 .632 .874 r
.45692 .59783 m .45501 .59854 L .45317 .5951 L F
.074 0 0 r
.45692 .59783 m .45417 .59938 L .45501 .59854 L F
.606 .67 .885 r
.79907 .49027 m .8013 .49379 L .80242 .49026 L F
.768 .429 .413 r
.4631 .6265 m .46695 .62728 L .46666 .62895 L F
.718 .512 .61 r
.47409 .73103 m .47828 .73322 L .47765 .73159 L F
.297 .259 .646 r
.22435 .58821 m .22293 .59184 L .22324 .58915 L F
.22435 .58821 m .22494 .59098 L .22293 .59184 L F
.337 .09 .385 r
.22476 .59353 m .22293 .59184 L .22494 .59098 L F
.22476 .59353 m .22291 .59423 L .22293 .59184 L F
.882 .477 .249 r
.59196 .59797 m .59234 .59944 L .59336 .59811 L F
.903 .512 .268 r
.59336 .59811 m .59234 .59944 L .59397 .60013 L F
.452 .459 .775 r
.23972 .55956 m .23835 .56065 L .23723 .55808 L F
0 0 0 r
.23972 .55956 m .23735 .56208 L .23835 .56065 L F
.494 .129 .275 r
.51373 .70308 m .51254 .70663 L .51054 .70498 L F
.482 .649 .932 r
.51502 .70166 m .5154 .70229 L .51373 .70308 L F
.493 .128 .275 r
.51509 .70614 m .51373 .70308 L .5154 .70229 L F
.51509 .70614 m .51254 .70663 L .51373 .70308 L F
.586 .705 .925 r
.59682 .66758 m .59702 .6662 L .59655 .66674 L F
.59682 .66758 m .59926 .66719 L .59702 .6662 L F
.56 .363 .571 r
.59685 .67009 m .59926 .66719 L .59682 .66758 L F
.626 .802 .967 r
.55433 .59676 m .55437 .59807 L .55075 .59751 L F
.516 .145 .274 r
.55437 .59807 m .55081 .60037 L .55075 .59751 L F
.55437 .59807 m .55355 .59963 L .55081 .60037 L F
.428 .681 .969 r
.55533 .59665 m .55437 .59807 L .55433 .59676 L F
.55533 .59665 m .5569 .59823 L .55437 .59807 L F
0 0 0 r
.5569 .59823 m .55355 .59963 L .55437 .59807 L F
.515 .574 .853 r
.35939 .61128 m .35771 .6135 L .35725 .61145 L F
.523 .403 .658 r
.36052 .61472 m .35771 .6135 L .35939 .61128 L F
.36052 .61472 m .35836 .61522 L .35771 .6135 L F
.561 .422 .65 r
.53954 .67055 m .54007 .67319 L .53762 .67341 L F
.541 .328 .54 r
.53762 .67341 m .53843 .67292 L .53673 .67243 L F
.53762 .67341 m .54007 .67319 L .53843 .67292 L F
.53762 .67341 m .53755 .67582 L .54007 .67319 L F
.54007 .67319 m .53755 .67582 L .53762 .67341 L F
.689 .205 .096 r
.42878 .61507 m .43069 .61684 L .43134 .61595 L F
.894 .5 .064 r
.62356 .44424 m .62261 .44366 L .6229 .44339 L F
.62356 .44424 m .6239 .44512 L .62261 .44366 L F
.979 .915 .61 r
.62356 .44424 m .6229 .44339 L .62428 .43992 L F
.59 .111 0 r
.55211 .6285 m .5532 .62968 L .55176 .62814 L F
.656 .485 .641 r
.4629 .68069 m .45879 .68122 L .4589 .6784 L F
0 0 0 r
.45879 .68122 m .45964 .67959 L .45974 .67934 L F
.45976 .67909 m .45974 .67934 L .46043 .6776 L F
.45879 .68122 m .45974 .67934 L .45976 .67909 L F
.656 .485 .641 r
.4629 .68069 m .45977 .6789 L .46261 .68021 L F
.45977 .6789 m .4589 .6784 L .45977 .67882 L F
.45977 .6789 m .45977 .67882 L .46261 .68021 L F
0 0 .208 r
.46416 .67768 m .4629 .68069 L .46261 .68021 L F
.349 .278 .634 r
.22052 .59964 m .21896 .59836 L .22061 .59771 L F
.22052 .59964 m .21927 .6006 L .21896 .59836 L F
.59 .685 .908 r
.36361 .62242 m .35974 .62097 L .3619 .62052 L F
.256 .429 .842 r
.36385 .62009 m .36361 .62242 L .3619 .62052 L F
.36385 .62009 m .36557 .62333 L .36361 .62242 L F
.619 .35 .489 r
.52819 .68751 m .5306 .68756 L .53086 .68535 L F
0 0 .37 r
.56867 .64712 m .56944 .64819 L .56739 .64592 L F
.293 .767 .933 r
.57146 .64799 m .56944 .64819 L .57143 .64555 L F
.548 .375 .599 r
.56944 .64819 m .57146 .64799 L .57143 .64555 L F
.293 .767 .933 r
.57146 .64799 m .56958 .64786 L .56944 .64819 L F
0 0 .37 r
.56867 .64712 m .56925 .6486 L .56944 .64819 L F
.624 .061 0 r
.56944 .64819 m .56797 .64774 L .56548 .64566 L F
.293 .767 .933 r
.56958 .64786 m .56797 .64774 L .56944 .64819 L F
0 0 .37 r
.56925 .6486 m .5698 .64998 L .56944 .64819 L F
.765 .794 .877 r
.57747 .6418 m .58084 .64029 L .58078 .64025 L F
.688 .955 .951 r
.58045 .64041 m .57747 .6418 L .57936 .64088 L F
.01 .226 .735 r
.57847 .63925 m .58044 .64037 L .57936 .64088 L F
.765 .794 .877 r
.58045 .64041 m .58078 .64025 L .58064 .64016 L F
.31 .109 .437 r
.58059 .63797 m .58049 .64024 L .57847 .63925 L F
.306 .105 .436 r
.58183 .63888 m .58064 .64016 L .58059 .63797 L F
.58064 .64016 m .58049 .64032 L .58049 .64024 L F
.58064 .64016 m .58049 .64024 L .58059 .63797 L F
.586 .77 .967 r
.58064 .64016 m .58064 .64016 L .58235 .63926 L F
.58064 .64016 m .58227 .63931 L .58235 .63926 L F
.306 .105 .436 r
.58235 .63926 m .58049 .64032 L .58183 .63888 L F
.586 .77 .967 r
.57888 .63899 m .58064 .64016 L .58235 .63926 L F
.58064 .64016 m .58084 .64029 L .58227 .63931 L F
.31 .109 .437 r
.58049 .64024 m .58049 .64032 L .58041 .64028 L F
.58049 .64024 m .58041 .64028 L .57847 .63925 L F
.765 .794 .877 r
.58045 .64037 m .58049 .64032 L .58044 .64037 L F
.58045 .64041 m .58064 .64016 L .58045 .64037 L F
.31 .109 .437 r
.58049 .64032 m .58049 .64039 L .58044 .64037 L F
.58049 .64032 m .58044 .64037 L .57847 .63925 L F
.765 .794 .877 r
.58044 .64037 m .58064 .64016 L .58035 .63997 L F
.58049 .64032 m .58064 .64016 L .58044 .64037 L F
.306 .105 .436 r
.58235 .63926 m .58049 .64039 L .58049 .64032 L F
.01 .226 .735 r
.58044 .64037 m .58049 .64039 L .58045 .64041 L F
.58044 .64037 m .58045 .64041 L .57936 .64088 L F
.765 .794 .877 r
.57747 .6418 m .58045 .64041 L .57888 .63899 L F
.58045 .64041 m .58035 .63997 L .57888 .63899 L F
.688 .955 .951 r
.58049 .64039 m .57747 .6418 L .58045 .64041 L F
.942 .827 .701 r
.58665 .61159 m .58812 .61244 L .58697 .61502 L F
0 .086 .63 r
.45804 .692 m .45676 .69114 L .45867 .69011 L F
0 0 .181 r
.45872 .69161 m .45804 .692 L .45976 .68909 L F
.45872 .69161 m .45804 .692 L .45976 .68909 L F
.428 .794 .995 r
.4579 .69162 m .45804 .692 L .45872 .69161 L F
0 .086 .63 r
.45804 .692 m .45836 .69284 L .45676 .69114 L F
.428 .794 .995 r
.45456 .69165 m .45804 .692 L .4579 .69162 L F
0 .086 .63 r
.45804 .692 m .45946 .69403 L .45836 .69284 L F
.595 .495 .711 r
.19259 .5628 m .19376 .56603 L .19595 .56553 L F
.645 .118 0 r
.55966 .67978 m .56054 .68095 L .56127 .68132 L F
.55817 .67835 m .56054 .68095 L .55966 .67978 L F
0 0 .501 r
.56057 .67985 m .56109 .68168 L .56054 .68095 L F
.56109 .68168 m .56148 .68307 L .56054 .68095 L F
.56051 .67964 m .56057 .67985 L .56054 .68095 L F
.233 .22 .639 r
.56054 .68095 m .55837 .68528 L .5605 .68236 L F
.56054 .68095 m .5605 .68236 L .56127 .68132 L F
.56054 .68095 m .56148 .68307 L .55837 .68528 L F
0 .32 .796 r
.55837 .68528 m .5606 .68611 L .56134 .68749 L F
0 0 .118 r
.55837 .68528 m .55875 .68703 L .5606 .68611 L F
.55837 .68528 m .56148 .68307 L .55875 .68703 L F
0 0 0 r
.1921 .57695 m .19448 .57395 L .19272 .57476 L F
.373 .196 .508 r
.22675 .58041 m .22656 .58303 L .2248 .58352 L F
.478 .349 .626 r
.22696 .58548 m .2248 .58352 L .22656 .58303 L F
.22696 .58548 m .22501 .58617 L .2248 .58352 L F
.979 .71 .315 r
.58705 .60662 m .58617 .60575 L .58606 .6032 L F
.991 .734 .383 r
.5872 .60922 m .58617 .60575 L .58705 .60662 L F
.509 0 0 r
.38089 .62527 m .38322 .62567 L .38489 .62451 L F
.228 0 0 r
.38322 .62567 m .38716 .62418 L .38489 .62451 L F
.985 .704 .366 r
.53006 .66739 m .53034 .67009 L .52924 .66904 L F
.79 .576 .611 r
.52924 .66904 m .53254 .66704 L .53006 .66739 L F
.092 .446 .881 r
.22381 .54787 m .22325 .54882 L .22164 .54781 L F
.22381 .54787 m .22566 .54995 L .22325 .54882 L F
.869 .444 .197 r
.78082 .48749 m .78029 .48918 L .77962 .48743 L F
.63 .818 .972 r
.78337 .48944 m .78082 .48749 L .78176 .48796 L F
.435 .024 .159 r
.78402 .48669 m .78176 .48796 L .78082 .48749 L F
.776 .278 .02 r
.42768 .6143 m .43069 .61684 L .42878 .61507 L F
.684 .576 .728 r
.45633 .6013 m .45922 .6058 L .45788 .60168 L F
.661 .558 .728 r
.45922 .6058 m .46229 .60413 L .45788 .60168 L F
.506 .881 .974 r
.40189 .58069 m .39973 .58139 L .39796 .58093 L F
.576 .18 .256 r
.5094 .69988 m .51161 .70135 L .51331 .699 L F
.722 .355 .353 r
.51161 .70135 m .51502 .70166 L .51331 .699 L F
0 0 .359 r
.46479 .70658 m .46378 .70789 L .4637 .70524 L F
.428 .381 .704 r
.32552 .6298 m .32668 .62636 L .32467 .62644 L F
.813 .643 .671 r
.19612 .58263 m .19997 .58053 L .19843 .57961 L F
.19612 .58263 m .19984 .58341 L .19997 .58053 L F
.973 .765 .564 r
.19884 .57711 m .19843 .57961 L .19997 .58053 L F
.424 0 0 r
.44783 .62415 m .45136 .62389 L .44973 .62501 L F
.557 .086 0 r
.45136 .62389 m .45232 .62509 L .44973 .62501 L F
.45136 .62389 m .45338 .62635 L .45232 .62509 L F
.779 .651 .721 r
.45233 .61783 m .45601 .61826 L .45495 .61419 L F
.813 .421 .31 r
.45233 .61783 m .45593 .62049 L .45601 .61826 L F
.739 .627 .735 r
.45495 .61419 m .45601 .61826 L .45834 .61528 L F
.621 .46 .642 r
.45834 .61528 m .45601 .61826 L .45885 .61787 L F
.619 .396 .557 r
.45593 .62049 m .45885 .61787 L .45601 .61826 L F
0 0 0 r
.47733 .68886 m .47606 .69052 L .47529 .69075 L F
.468 .334 .615 r
.47606 .69052 m .47616 .69216 L .47529 .69075 L F
.598 .662 .883 r
.76711 .50772 m .77093 .51003 L .76957 .50688 L F
.6 .617 .84 r
.77093 .51003 m .77226 .50628 L .76957 .50688 L F
.77093 .51003 m .77348 .50963 L .77226 .50628 L F
.597 .539 .76 r
.73507 .49884 m .73602 .50259 L .73858 .50185 L F
.9 .556 .384 r
.55981 .63561 m .55811 .63537 L .55767 .63341 L F
0 .176 .693 r
.56023 .63763 m .55811 .63537 L .55981 .63561 L F
0 0 .206 r
.54644 .66362 m .54458 .66705 L .54516 .66489 L F
.774 .319 .168 r
.46779 .69246 m .46863 .6914 L .46579 .68992 L F
.109 0 0 r
.47136 .69053 m .46863 .6914 L .46788 .69235 L F
.47136 .69053 m .46788 .69235 L .46808 .6923 L F
.793 .672 .73 r
.46984 .68701 m .47136 .69053 L .46802 .68974 L F
.109 0 0 r
.47031 .6915 m .46779 .69246 L .46986 .69191 L F
.47136 .69053 m .46943 .69157 L .47031 .6915 L F
.46943 .69157 m .46779 .69246 L .47031 .6915 L F
.772 .368 .288 r
.46802 .68974 m .469 .68997 L .46986 .69191 L F
.469 .68997 m .47136 .69053 L .47031 .6915 L F
.469 .68997 m .47031 .6915 L .46986 .69191 L F
.804 .763 .816 r
.47269 .68651 m .47136 .69053 L .46984 .68701 L F
.47269 .68651 m .47412 .68791 L .47136 .69053 L F
.504 .407 .678 r
.46975 .6881 m .47181 .69138 L .47136 .68849 L F
.47181 .69138 m .47197 .69163 L .47192 .69137 L F
.47181 .69138 m .47192 .69137 L .47136 .68849 L F
.435 .351 .663 r
.46802 .68974 m .46986 .69191 L .46975 .6881 L F
.46986 .69191 m .46986 .69191 L .46986 .69191 L F
.46986 .69191 m .46986 .69191 L .46975 .6881 L F
.109 0 0 r
.46808 .6923 m .46788 .69235 L .46779 .69246 L F
.494 .186 .373 r
.44865 .61553 m .45112 .61541 L .4522 .6129 L F
.718 .424 .478 r
.4522 .6129 m .45495 .61419 L .45468 .61231 L F
.4522 .6129 m .45112 .61541 L .45495 .61419 L F
.582 .514 .744 r
.53952 .6818 m .54237 .68216 L .54115 .67869 L F
.621 .476 .663 r
.53952 .6818 m .54242 .68449 L .54237 .68216 L F
.53952 .6818 m .54002 .68496 L .54242 .68449 L F
.286 .743 .954 r
.19134 .54342 m .1929 .54289 L .19445 .54366 L F
.209 .696 .927 r
.1929 .54289 m .19695 .54352 L .19445 .54366 L F
.536 .261 .446 r
.65326 .45565 m .65324 .45736 L .65084 .45715 L F
.394 .099 .34 r
.65563 .45514 m .65324 .45736 L .65326 .45565 L F
.658 .469 .618 r
.4833 .65469 m .48509 .65571 L .48483 .65313 L F
0 0 .058 r
.48509 .65571 m .48711 .6526 L .48483 .65313 L F
.643 .349 .457 r
.47263 .7084 m .47493 .71025 L .47577 .70877 L F
.713 .975 .921 r
.46757 .68786 m .47186 .68585 L .46984 .68701 L F
.886 .494 .043 r
.47186 .68585 m .46992 .68203 L .47217 .68407 L F
.886 .985 .811 r
.46984 .68701 m .47186 .68585 L .47217 .68407 L F
.46984 .68701 m .47217 .68407 L .47269 .68651 L F
.635 .804 .964 r
.46984 .68701 m .47269 .68651 L .47239 .68606 L F
.46984 .68701 m .47239 .68606 L .47163 .68494 L F
.713 .975 .921 r
.46757 .68786 m .46757 .68786 L .46984 .68701 L F
0 0 .201 r
.46506 .67353 m .46632 .66994 L .46446 .67048 L F
.46506 .67353 m .4661 .67251 L .46632 .66994 L F
.415 .807 .987 r
.46731 .67319 m .4661 .67251 L .46506 .67353 L F
.511 .583 .863 r
.5116 .64612 m .51166 .64808 L .51438 .64714 L F
.5116 .64612 m .50994 .64949 L .51166 .64808 L F
.377 .49 .847 r
.1953 .5868 m .1962 .58481 L .19477 .58609 L F
.1953 .5868 m .19778 .58743 L .1962 .58481 L F
.911 .53 .104 r
.58723 .6215 m .58617 .62059 L .5854 .6182 L F
.837 .932 .892 r
.58437 .62202 m .58617 .62059 L .58723 .6215 L F
.683 .703 .862 r
.77348 .50963 m .77422 .51115 L .77708 .51062 L F
.452 .47 .787 r
.77422 .51115 m .77727 .51304 L .77708 .51062 L F
0 0 0 r
.51804 .73114 m .51853 .73087 L .51938 .72796 L F
0 0 .274 r
.51804 .73114 m .51839 .73247 L .51853 .73087 L F
.706 .866 .958 r
.35738 .64327 m .35891 .64431 L .36086 .64309 L F
.35738 .64327 m .35891 .64431 L .36086 .64309 L F
.637 .76 .937 r
.35768 .64022 m .36124 .64084 L .35978 .63988 L F
.44 .791 .997 r
.36124 .64084 m .36199 .63967 L .35978 .63988 L F
.36124 .64084 m .36361 .64053 L .36199 .63967 L F
.629 .627 .829 r
.50875 .671 m .50759 .67343 L .50652 .67105 L F
.50875 .671 m .51006 .6731 L .50759 .67343 L F
.587 .413 .612 r
.51006 .6731 m .50766 .67591 L .50759 .67343 L F
.982 .731 .477 r
.56839 .63134 m .5698 .62976 L .56663 .62926 L F
.56839 .63134 m .56976 .63272 L .5698 .62976 L F
.185 0 .162 r
.45885 .61787 m .4615 .61548 L .45834 .61528 L F
0 0 0 r
.23546 .56317 m .23427 .56483 L .23308 .566 L F
.777 .691 .769 r
.23546 .56317 m .23308 .566 L .23162 .56267 L F
.177 0 .345 r
.23427 .56483 m .23168 .56776 L .23308 .566 L F
.249 0 0 r
.37217 .59716 m .36844 .59869 L .37 .59761 L F
.653 .203 .169 r
.44555 .62349 m .44389 .62487 L .44189 .6232 L F
.649 .203 .179 r
.44555 .62349 m .44618 .62494 L .44389 .62487 L F
.44555 .62349 m .44729 .62512 L .44618 .62494 L F
.44555 .62349 m .44783 .62415 L .44729 .62512 L F
0 0 0 r
.61109 .45771 m .61449 .45577 L .61412 .45871 L F
.9 .602 .472 r
.61412 .45871 m .61252 .45916 L .61109 .45771 L F
.61412 .45871 m .61411 .46087 L .61252 .45916 L F
.167 .404 .847 r
.481 .71233 m .48072 .71432 L .47852 .71087 L F
.481 .71233 m .48112 .71393 L .48072 .71432 L F
0 0 0 r
.48112 .71393 m .47973 .7163 L .48072 .71432 L F
.149 0 0 r
.19682 .56753 m .19969 .5661 L .19595 .56553 L F
.19682 .56753 m .19941 .56691 L .19969 .5661 L F
.469 .808 .999 r
.19941 .56691 m .20186 .5672 L .19969 .5661 L F
.516 .765 .987 r
.35182 .63944 m .35207 .63748 L .35001 .63805 L F
.35182 .63944 m .35399 .63904 L .35207 .63748 L F
.545 0 0 r
.54117 .62466 m .54046 .62488 L .53818 .62335 L F
0 .497 .767 r
.54396 .62574 m .54046 .62488 L .54117 .62466 L F
.74 .546 .632 r
.58095 .60678 m .58083 .60934 L .58217 .6065 L F
.931 .712 .584 r
.59443 .61097 m .59588 .60943 L .59457 .6085 L F
.59443 .61097 m .59564 .61187 L .59588 .60943 L F
.105 0 .239 r
.22892 .5747 m .22817 .57679 L .22692 .57733 L F
.11 .052 .504 r
.22811 .57917 m .22692 .57733 L .22817 .57679 L F
.22811 .57917 m .22675 .58041 L .22692 .57733 L F
.807 .79 .837 r
.78404 .51658 m .78704 .51655 L .78657 .51499 L F
.719 .76 .885 r
.63882 .44522 m .63529 .44476 L .6379 .44405 L F
.651 .215 .199 r
.6379 .44405 m .64172 .44439 L .63882 .44522 L F
.818 .701 .736 r
.66652 .44709 m .66322 .4465 L .66534 .44342 L F
.703 .429 .507 r
.66652 .44709 m .66291 .44885 L .66322 .4465 L F
.66652 .44709 m .66635 .44918 L .66291 .44885 L F
.116 .255 .731 r
.66534 .44342 m .66741 .4454 L .66652 .44709 L F
.583 .565 .8 r
.66741 .4454 m .66635 .44918 L .66652 .44709 L F
.496 .217 .42 r
.65084 .45715 m .6501 .46038 L .64767 .46089 L F
.549 .272 .447 r
.65324 .45736 m .6501 .46038 L .65084 .45715 L F
.083 .619 .861 r
.51438 .64714 m .51566 .64701 L .5116 .64612 L F
.813 .668 .703 r
.50055 .68753 m .50273 .69116 L .49981 .69032 L F
0 .436 .722 r
.50273 .69116 m .50002 .69036 L .49981 .69032 L F
.859 .797 .789 r
.50273 .69116 m .50128 .69342 L .50002 .69036 L F
.75 .651 .752 r
.50463 .6877 m .50273 .69116 L .50055 .68753 L F
.859 .797 .789 r
.50273 .69116 m .50128 .69342 L .50002 .69036 L F
0 0 0 r
.23665 .56264 m .23546 .56317 L .23735 .56208 L F
.23533 .56369 m .23545 .56319 L .23665 .56264 L F
.23545 .56319 m .23546 .56317 L .23665 .56264 L F
.23533 .56369 m .23735 .56208 L .2357 .56276 L F
.349 .823 .884 r
.23965 .5621 m .2357 .56276 L .23735 .56208 L F
.23965 .5621 m .23782 .56216 L .2375 .56225 L F
.23677 .56258 m .2375 .56225 L .2357 .56276 L F
.23965 .5621 m .2375 .56225 L .23677 .56258 L F
0 0 0 r
.23533 .56369 m .23427 .56483 L .23546 .56317 L F
.002 .256 .761 r
.66563 .43952 m .66567 .44137 L .66376 .43795 L F
0 0 .277 r
.66563 .43952 m .66534 .44342 L .66567 .44137 L F
0 0 0 r
.80856 .50258 m .80687 .50568 L .80832 .5042 L F
.80856 .50258 m .80832 .5042 L .80757 .50113 L F
.612 .876 .991 r
.81065 .50074 m .80856 .50258 L .80757 .50113 L F
.81065 .50074 m .81105 .50173 L .80856 .50258 L F
.273 .459 .861 r
.2379 .55679 m .23723 .55808 L .23623 .55722 L F
.2379 .55679 m .23972 .55956 L .23723 .55808 L F
.354 0 0 r
.52145 .63425 m .52574 .63489 L .52274 .63396 L F
.532 .526 .794 r
.58059 .63797 m .57847 .63925 L .578 .63651 L F
.731 .616 .73 r
.46992 .68203 m .47227 .6791 L .46859 .67901 L F
0 .178 .71 r
.47046 .68166 m .47217 .68407 L .46992 .68203 L F
.47046 .68166 m .46992 .68203 L .46823 .68388 L F
.448 .44 .757 r
.77238 .49126 m .77537 .49247 L .77303 .49216 L F
.179 .392 .834 r
.50128 .69342 m .50272 .692 L .50002 .69036 L F
0 0 0 r
.50272 .692 m .50156 .69323 L .50128 .69342 L F
.263 .716 .956 r
.20056 .56226 m .20337 .56277 L .20217 .56299 L F
0 .198 .727 r
.34361 .63343 m .34436 .63412 L .3433 .63232 L F
0 .429 .759 r
.23071 .55575 m .23242 .55627 L .23424 .55704 L F
.302 .644 .967 r
.23449 .55577 m .23424 .55704 L .23242 .55627 L F
.23449 .55577 m .23623 .55722 L .23424 .55704 L F
.639 .497 .673 r
.52547 .66142 m .5276 .65842 L .52621 .66045 L F
.7 .556 .688 r
.74447 .50166 m .74699 .4986 L .74441 .49934 L F
.74447 .50166 m .74796 .50219 L .74699 .4986 L F
.659 .531 .697 r
.74699 .4986 m .74796 .50219 L .75027 .49927 L F
.691 .503 .628 r
.75277 .49858 m .7554 .49606 L .75267 .49637 L F
.312 .453 .842 r
.57304 .65582 m .57432 .65425 L .57336 .65486 L F
.197 .283 .727 r
.57304 .65582 m .57531 .65798 L .57432 .65425 L F
.368 0 .011 r
.50305 .67273 m .50554 .67249 L .50652 .67105 L F
.209 0 0 r
.50554 .67249 m .50875 .671 L .50652 .67105 L F
.099 .636 .859 r
.18676 .54267 m .1888 .54268 L .19134 .54342 L F
.363 .795 .967 r
.1888 .54268 m .1929 .54289 L .19134 .54342 L F
.635 .246 .29 r
.44281 .61531 m .44515 .61714 L .44643 .61515 L F
.341 0 .117 r
.44643 .61515 m .44748 .61661 L .44865 .61553 L F
.44643 .61515 m .44515 .61714 L .44748 .61661 L F
.679 .556 .709 r
.75158 .50499 m .74922 .50796 L .75167 .50735 L F
.448 .779 .998 r
.40608 .57989 m .4055 .58122 L .40406 .58015 L F
.40608 .57989 m .40779 .5809 L .4055 .58122 L F
.728 .641 .761 r
.46859 .67901 m .47227 .6791 L .47134 .67542 L F
.682 .775 .922 r
.47227 .6791 m .4732 .67605 L .47134 .67542 L F
.47227 .6791 m .47484 .67835 L .4732 .67605 L F
.843 .448 .298 r
.56 .6257 m .56346 .62835 L .56165 .62661 L F
.372 .213 .532 r
.48065 .676 m .4792 .67888 L .48077 .67952 L F
0 0 0 r
.51081 .67821 m .51242 .67781 L .51398 .67651 L F
.469 .128 .306 r
.51398 .67651 m .51654 .67781 L .51654 .67616 L F
.722 .934 .609 r
.51398 .67651 m .51483 .67479 L .51654 .67781 L F
.51398 .67651 m .51242 .67781 L .51483 .67479 L F
.856 .992 .835 r
.78512 .48155 m .78307 .48403 L .78241 .48356 L F
.692 .98 .823 r
.52461 .67287 m .52521 .67205 L .52796 .67081 L F
.713 .986 .828 r
.52796 .67081 m .52521 .67205 L .52924 .66904 L F
.128 .285 .755 r
.52461 .67287 m .52531 .67191 L .52555 .67104 L F
.836 .954 .892 r
.52924 .66904 m .52531 .67189 L .52555 .67104 L F
.128 .285 .755 r
.52531 .67191 m .52567 .67141 L .52555 .67104 L F
.687 .858 .451 r
.52555 .67104 m .52492 .67218 L .52461 .67287 L F
.836 .954 .892 r
.52531 .67189 m .52492 .67218 L .52555 .67104 L F
.713 .986 .828 r
.52521 .67205 m .52492 .67218 L .52531 .67189 L F
.52521 .67205 m .52531 .67189 L .52924 .66904 L F
.128 .285 .755 r
.52521 .67205 m .52671 .67467 L .52567 .67141 L F
.52461 .67287 m .52464 .67289 L .52521 .67205 L F
.52464 .67289 m .52671 .67467 L .52521 .67205 L F
.692 .98 .823 r
.52461 .67287 m .52492 .67218 L .52521 .67205 L F
.713 .986 .828 r
.52796 .67081 m .52924 .66904 L .53034 .67009 L F
.333 .03 .293 r
.51938 .72796 m .51853 .73087 L .52068 .73 L F
.512 .826 1 r
.27558 .88553 m .27769 .88497 L .27592 .88415 L F
.671 .301 .336 r
.52547 .66142 m .52866 .66117 L .52778 .66345 L F
.336 .817 .808 r
.53013 .66048 m .52866 .66117 L .5304 .6605 L F
0 0 .007 r
.52778 .66345 m .52866 .66117 L .53013 .66048 L F
.225 .107 .501 r
.2069 .62917 m .20701 .63155 L .20524 .63269 L F
.523 .404 .659 r
.20701 .63155 m .2048 .63503 L .20524 .63269 L F
.916 .73 .635 r
.55166 .67616 m .55355 .67639 L .55324 .67482 L F
.85 .453 .291 r
.55166 .67616 m .55207 .67807 L .55355 .67639 L F
.48 .448 .744 r
.55324 .67482 m .55355 .67639 L .55537 .6756 L F
.709 .257 .178 r
.55355 .67639 m .55541 .67832 L .55537 .6756 L F
.596 .431 .629 r
.55305 .6786 m .55399 .67739 L .55355 .67639 L F
.709 .257 .178 r
.55355 .67639 m .55399 .67739 L .55541 .67832 L F
.596 .431 .629 r
.55305 .6786 m .55541 .67832 L .55399 .67739 L F
.709 .257 .178 r
.55399 .67739 m .55436 .67824 L .55541 .67832 L F
.596 .431 .629 r
.55399 .67739 m .55541 .67832 L .55537 .6756 L F
.55399 .67739 m .55537 .6756 L .55355 .67639 L F
.709 .257 .178 r
.55355 .67639 m .55207 .67807 L .55436 .67824 L F
.48 .448 .744 r
.55324 .67482 m .55355 .67639 L .55537 .6756 L F
.968 .739 .539 r
.54193 .68651 m .54368 .68781 L .54242 .68449 L F
.511 .159 .307 r
.54368 .68781 m .53958 .68837 L .54193 .68651 L F
.54368 .68781 m .53996 .6904 L .53958 .68837 L F
.54368 .68781 m .54302 .69018 L .53996 .6904 L F
.462 .468 .778 r
.54466 .68386 m .54368 .68781 L .54242 .68449 L F
.54466 .68386 m .54543 .68807 L .54368 .68781 L F
.319 0 .24 r
.54527 .68921 m .54368 .68781 L .54543 .68807 L F
.54527 .68921 m .54302 .69018 L .54368 .68781 L F
.321 0 .254 r
.4101 .61749 m .4122 .61721 L .41342 .61466 L F
.464 .139 .331 r
.41342 .61466 m .41477 .61649 L .41519 .61567 L F
.41342 .61466 m .4122 .61721 L .41477 .61649 L F
.684 .628 .787 r
.75516 .50784 m .75866 .50857 L .75753 .50514 L F
.675 .623 .789 r
.75753 .50514 m .75866 .50857 L .76113 .5078 L F
.571 .184 .269 r
.47586 .66781 m .47401 .66998 L .47206 .66949 L F
.384 0 .133 r
.47746 .6689 m .47586 .66781 L .47802 .6671 L F
.47746 .6689 m .47401 .66998 L .47586 .66781 L F
.718 .615 .742 r
.75167 .50735 m .75516 .50784 L .75417 .50458 L F
.65 .576 .758 r
.75417 .50458 m .75516 .50784 L .75753 .50514 L F
.809 .656 .693 r
.53644 .68711 m .54002 .68496 L .53626 .68534 L F
0 .537 .83 r
.56346 .62835 m .56663 .62926 L .56441 .62879 L F
.416 .331 .652 r
.53952 .7134 m .53724 .71682 L .53703 .71573 L F
.53952 .7134 m .53933 .71591 L .53724 .71682 L F
.489 .39 .669 r
.53933 .71591 m .53782 .71867 L .53724 .71682 L F
.785 .741 .812 r
.63403 .44059 m .63792 .43943 L .63682 .43823 L F
.73 .826 .924 r
.63682 .43823 m .63792 .43943 L .64029 .43839 L F
.412 .679 .971 r
.49291 .6758 m .49487 .67339 L .49302 .67373 L F
.49291 .6758 m .49474 .6756 L .49487 .67339 L F
.428 .381 .704 r
.32552 .6298 m .32725 .62934 L .32668 .62636 L F
.401 .27 .585 r
.32259 .60357 m .32413 .60045 L .32213 .60114 L F
.891 .937 .838 r
.80741 .48815 m .80498 .48961 L .80851 .49012 L F
.80741 .48815 m .80729 .48663 L .80498 .48961 L F
.603 .409 .591 r
.54227 .66757 m .54072 .6719 L .53954 .67055 L F
.024 0 .272 r
.54345 .66875 m .54227 .66757 L .54458 .66705 L F
.485 .39 .672 r
.54072 .6719 m .5423 .67257 L .54094 .67157 L F
.024 0 .272 r
.54287 .66816 m .54072 .6719 L .54227 .66757 L F
.54304 .66833 m .54094 .67157 L .54287 .66816 L F
.54094 .67157 m .54072 .6719 L .54287 .66816 L F
.507 .387 .65 r
.54006 .67312 m .5423 .67257 L .54007 .67319 L F
.485 .39 .672 r
.54072 .6719 m .54094 .67157 L .53954 .67055 L F
.507 .387 .65 r
.53954 .67055 m .54094 .67157 L .54006 .67312 L F
.54094 .67157 m .5423 .67257 L .54006 .67312 L F
.024 0 .272 r
.54345 .66875 m .54072 .6719 L .54304 .66833 L F
.824 .852 .869 r
.77788 .4918 m .77655 .49383 L .77537 .49247 L F
0 0 .484 r
.32862 .62102 m .33027 .62002 L .32861 .61805 L F
.484 .735 .982 r
.32991 .6229 m .33027 .62002 L .32862 .62102 L F
0 0 .353 r
.45279 .60132 m .4519 .6004 L .45417 .59938 L F
.45279 .60132 m .45231 .60347 L .4519 .6004 L F
.865 .995 .773 r
.80687 .50568 m .80475 .50834 L .80605 .50535 L F
.588 .944 .907 r
.80832 .5042 m .80687 .50568 L .80605 .50535 L F
.946 .915 .754 r
.78688 .50815 m .78708 .51082 L .78845 .5079 L F
0 .043 .609 r
.78781 .51049 m .78882 .51298 L .78708 .51082 L F
.346 0 0 r
.78684 .51056 m .78854 .51095 L .78781 .51049 L F
0 .479 .849 r
.78781 .51049 m .79094 .5115 L .79103 .51184 L F
.346 0 0 r
.78854 .51095 m .79094 .5115 L .78781 .51049 L F
0 .043 .609 r
.78781 .51049 m .78708 .51082 L .78702 .50999 L F
.78781 .51049 m .78702 .50999 L .78688 .50815 L F
.773 .541 .583 r
.58383 .63565 m .58361 .63821 L .58127 .63802 L F
.748 .656 .76 r
.58568 .63494 m .58361 .63821 L .58383 .63565 L F
.551 .821 .996 r
.58383 .63565 m .58568 .63494 L .58336 .63396 L F
.327 .76 .97 r
.41135 .58692 m .41275 .58764 L .41511 .58741 L F
.803 .843 .381 r
.80475 .50834 m .80402 .50967 L .80605 .50535 L F
.80475 .50834 m .80397 .51047 L .80402 .50967 L F
.654 .357 .457 r
.52808 .72621 m .52472 .72769 L .52397 .72714 L F
.52808 .72621 m .52397 .72714 L .52737 .72674 L F
.344 .11 .407 r
.52808 .72621 m .53003 .7253 L .53084 .72311 L F
.11 0 0 r
.3805 .59426 m .37665 .59629 L .37828 .59473 L F
.718 .828 .933 r
.78081 .51637 m .78159 .51836 L .78404 .51658 L F
.996 .771 .472 r
.5028 .65297 m .50168 .65382 L .49961 .6524 L F
.5028 .65297 m .50273 .65559 L .50168 .65382 L F
.526 .31 .529 r
.49716 .64112 m .49939 .64087 L .49934 .63853 L F
.689 .497 .623 r
.49939 .64087 m .50257 .63831 L .49934 .63853 L F
.811 .588 .6 r
.1995 .57058 m .20333 .56884 L .20186 .5672 L F
.1995 .57058 m .20398 .57167 L .20333 .56884 L F
.841 .793 .805 r
.20572 .56571 m .20333 .56884 L .20186 .5672 L F
.20572 .56571 m .20203 .56713 L .2031 .56666 L F
.20203 .56713 m .20186 .5672 L .2031 .56666 L F
.395 .532 .876 r
.2031 .56666 m .20622 .5677 L .20507 .56577 L F
.2031 .56666 m .20507 .56577 L .20494 .56556 L F
0 .169 .702 r
.20333 .56884 m .2031 .56666 L .20186 .5672 L F
.20333 .56884 m .20527 .57079 L .2031 .56666 L F
.3 .258 .643 r
.20333 .56884 m .20398 .57167 L .20527 .57079 L F
.877 .677 .152 r
.50226 .68614 m .50203 .68403 L .50186 .68371 L F
.057 0 0 r
.50162 .68324 m .50186 .68371 L .50317 .68234 L F
.555 .454 .694 r
.50395 .68093 m .50186 .68371 L .50187 .6826 L F
.877 .677 .152 r
.50203 .68403 m .50187 .6826 L .50186 .68371 L F
.057 0 0 r
.5006 .68383 m .50186 .68371 L .50162 .68324 L F
.708 .475 .569 r
.63921 .42986 m .6421 .43247 L .64175 .43183 L F
.63921 .42986 m .64179 .43186 L .64123 .43181 L F
.817 .57 .566 r
.64177 .43188 m .64177 .43186 L .64123 .43181 L F
.771 .493 .515 r
.64192 .43214 m .64177 .43188 L .64123 .43181 L F
.708 .475 .569 r
.64179 .43186 m .6424 .43234 L .64123 .43181 L F
.817 .57 .566 r
.64177 .43186 m .64131 .42921 L .64123 .43181 L F
.64481 .43224 m .64303 .4307 L .64177 .43188 L F
.64303 .4307 m .64131 .42921 L .64177 .43188 L F
.708 .475 .569 r
.63921 .42986 m .63761 .43435 L .64034 .43321 L F
.64161 .43203 m .6415 .43213 L .6421 .43247 L F
.771 .493 .515 r
.64461 .43299 m .64481 .43224 L .64228 .43251 L F
.34 .225 .574 r
.6424 .43257 m .64418 .43294 L .6424 .43234 L F
.771 .493 .515 r
.64442 .43367 m .64461 .43299 L .64228 .43251 L F
.34 .225 .574 r
.64239 .43297 m .64253 .43296 L .6424 .43257 L F
.728 .56 .663 r
.63902 .43694 m .64214 .4327 L .63761 .43435 L F
.64214 .4327 m .64228 .43251 L .64206 .4326 L F
.64214 .4327 m .64206 .4326 L .63761 .43435 L F
.771 .493 .515 r
.64421 .43446 m .64442 .43367 L .6424 .43257 L F
.708 .475 .569 r
.6415 .43213 m .64199 .43252 L .6421 .43247 L F
.771 .493 .515 r
.64253 .43296 m .6424 .43257 L .64159 .43213 L F
.64421 .43446 m .6424 .43257 L .64253 .43296 L F
.64421 .43424 m .64264 .43296 L .64418 .43294 L F
.64421 .43446 m .64253 .43296 L .64421 .43424 L F
.64253 .43296 m .64222 .43269 L .64257 .43296 L F
.64253 .43296 m .64257 .43296 L .64421 .43424 L F
.34 .225 .574 r
.64253 .43296 m .64418 .43294 L .6424 .43257 L F
.728 .56 .663 r
.63902 .43694 m .64208 .43698 L .64239 .43257 L F
.63902 .43694 m .64239 .43257 L .64228 .43251 L F
.64208 .43698 m .6423 .43671 L .6424 .43234 L F
.771 .493 .515 r
.64222 .43269 m .64193 .43244 L .64421 .43424 L F
.64193 .43244 m .64123 .43181 L .64182 .4323 L F
.728 .56 .663 r
.64228 .43251 m .64199 .43252 L .64206 .4326 L F
.771 .493 .515 r
.64193 .43244 m .64182 .4323 L .64421 .43424 L F
.728 .56 .663 r
.64228 .43251 m .6421 .43247 L .64199 .43252 L F
.64206 .4326 m .64199 .43252 L .63761 .43435 L F
.34 .225 .574 r
.6432 .43503 m .64418 .43294 L .64253 .43296 L F
.771 .493 .515 r
.64228 .43251 m .64237 .4325 L .64159 .43213 L F
.64237 .4325 m .64226 .43215 L .64159 .43213 L F
.728 .56 .663 r
.64228 .43251 m .6424 .43234 L .6421 .43247 L F
.64228 .43251 m .64239 .43257 L .6424 .43234 L F
.771 .493 .515 r
.64264 .43296 m .64182 .4323 L .64418 .43294 L F
.708 .475 .569 r
.63921 .42986 m .64034 .43321 L .64161 .43203 L F
.771 .493 .515 r
.64159 .43213 m .64192 .43214 L .64123 .43181 L F
.64182 .4323 m .64123 .43181 L .64154 .43193 L F
.64237 .4325 m .64481 .43224 L .64226 .43215 L F
.708 .475 .569 r
.6422 .43218 m .64224 .43241 L .6424 .43234 L F
.771 .493 .515 r
.64192 .43214 m .64481 .43224 L .64177 .43188 L F
.708 .475 .569 r
.64175 .43183 m .64224 .43241 L .6422 .43218 L F
.64175 .43183 m .6421 .43247 L .64224 .43241 L F
0 .421 .799 r
.6424 .43234 m .64418 .43294 L .64123 .43181 L F
.771 .493 .515 r
.64182 .4323 m .64154 .43193 L .64418 .43294 L F
0 0 0 r
.64201 .43701 m .64315 .43551 L .64401 .43465 L F
.64201 .43701 m .64401 .43465 L .64319 .43564 L F
.181 0 .26 r
.64421 .43446 m .64455 .43594 L .64201 .43701 L F
.337 .14 .458 r
.6444 .43809 m .64201 .43701 L .64455 .43594 L F
.34 .225 .574 r
.64229 .43698 m .6432 .43503 L .64253 .43296 L F
.64229 .43698 m .64253 .43296 L .64239 .43297 L F
.708 .475 .569 r
.6415 .43213 m .64034 .43321 L .64199 .43252 L F
.728 .56 .663 r
.64208 .43698 m .64229 .43698 L .6423 .43671 L F
0 0 0 r
.64319 .43564 m .64401 .43465 L .64421 .43446 L F
.398 .496 .842 r
.45473 .69873 m .45629 .70206 L .45768 .70174 L F
0 .065 .625 r
.45629 .70206 m .45801 .70423 L .45768 .70174 L F
.644 .906 .982 r
.78653 .48704 m .78983 .48614 L .78964 .48557 L F
.661 .77 .931 r
.78983 .48614 m .79186 .48453 L .78964 .48557 L F
.78983 .48614 m .79251 .48536 L .79186 .48453 L F
.2 .32 .762 r
.6537 .44733 m .6513 .44662 L .65345 .44629 L F
.16 .685 .873 r
.65021 .44625 m .6513 .44662 L .64741 .44626 L F
.461 .742 .989 r
.65345 .44629 m .6513 .44662 L .65183 .44499 L F
.723 .979 .916 r
.65183 .44499 m .6513 .44662 L .65021 .44625 L F
.537 .778 .987 r
.36086 .64309 m .36397 .64376 L .36452 .6424 L F
.36086 .64309 m .36397 .64376 L .36452 .6424 L F
0 0 .295 r
.36452 .6424 m .36397 .64376 L .36502 .64234 L F
.36452 .6424 m .36397 .64376 L .36502 .64234 L F
.774 .921 .935 r
.78867 .48406 m .78653 .48704 L .78964 .48557 L F
.47 .692 .964 r
.44269 .59994 m .44604 .60111 L .44497 .59953 L F
.71 .755 .887 r
.44497 .59953 m .44604 .60111 L .44878 .59993 L F
.592 .044 0 r
.45754 .62731 m .45338 .62635 L .45515 .62624 L F
0 0 .229 r
.4833 .65469 m .4836 .65727 L .48509 .65571 L F
.4833 .65469 m .48252 .65879 L .4836 .65727 L F
.946 .915 .754 r
.78688 .50815 m .78845 .5079 L .78768 .50745 L F
.689 .573 .72 r
.54115 .67869 m .54475 .68155 L .54475 .67907 L F
.443 .273 .554 r
.54475 .67907 m .54673 .67858 L .54674 .67599 L F
.463 .329 .613 r
.54475 .67907 m .54707 .68108 L .54673 .67858 L F
.54475 .67907 m .54707 .68108 L .54673 .67858 L F
.515 .326 .563 r
.54475 .68155 m .54707 .68108 L .54475 .67907 L F
.149 .063 .494 r
.19692 .59493 m .19781 .59429 L .19746 .592 L F
0 0 0 r
.1963 .59567 m .19781 .59429 L .19692 .59493 L F
.206 0 0 r
.3932 .63545 m .39147 .63659 L .38903 .63689 L F
.193 0 0 r
.39554 .63544 m .39147 .63659 L .3932 .63545 L F
.222 .166 .58 r
.2031 .56666 m .20427 .56433 L .20463 .56451 L F
.675 .208 0 r
.20337 .56277 m .20485 .56463 L .20463 .56451 L F
.579 .892 .619 r
.20652 .5599 m .20337 .56277 L .20486 .56121 L F
.708 .619 .052 r
.20463 .56451 m .20486 .56121 L .20337 .56277 L F
.222 .166 .58 r
.20427 .56433 m .20469 .56349 L .20463 .56451 L F
.675 .208 0 r
.20485 .56463 m .20572 .56571 L .20463 .56451 L F
.728 .626 .744 r
.74441 .49934 m .74214 .50238 L .74447 .50166 L F
.539 .565 .83 r
.19376 .56603 m .19682 .56753 L .19595 .56553 L F
.479 .307 .569 r
.45223 .68475 m .45256 .68722 L .45456 .68472 L F
.445 .457 .778 r
.47364 .71409 m .47831 .7165 L .47561 .71276 L F
.715 .689 .824 r
.4366 .58594 m .43432 .587 L .43327 .58549 L F
0 .384 .734 r
.20233 .55738 m .19901 .55596 L .20175 .55703 L F
.20229 .55737 m .19901 .55596 L .20233 .55738 L F
.20229 .55737 m .20188 .55713 L .19901 .55596 L F
.20235 .5574 m .20229 .55737 L .20233 .55738 L F
.20235 .5574 m .20188 .55713 L .20229 .55737 L F
.501 .894 .948 r
.20153 .5561 m .20062 .5564 L .20188 .55713 L F
.035 0 0 r
.1992 .55688 m .19901 .55596 L .2007 .55665 L F
.1992 .55688 m .2007 .55665 L .20188 .55713 L F
.633 .961 .819 r
.19979 .55581 m .19827 .55702 L .1992 .55688 L F
.75 .592 .68 r
.19536 .55566 m .19662 .55632 L .19901 .55596 L F
.703 .333 .344 r
.19901 .55596 m .19725 .5578 L .19536 .55566 L F
.179 0 0 r
.1992 .55688 m .19535 .55697 L .19725 .5578 L F
.1992 .55688 m .19816 .55711 L .19535 .55697 L F
.633 .961 .819 r
.19827 .55702 m .19816 .55711 L .1992 .55688 L F
.501 .894 .948 r
.20062 .5564 m .19987 .55665 L .20188 .55713 L F
.19987 .55665 m .1992 .55688 L .20129 .55707 L F
.19987 .55665 m .20129 .55707 L .20188 .55713 L F
.56 .611 .86 r
.78848 .49928 m .78718 .50215 L .78573 .49851 L F
.78848 .49928 m .7897 .50175 L .78718 .50215 L F
.906 .769 .699 r
.60993 .64679 m .60915 .64945 L .61089 .65004 L F
.939 .69 .536 r
.60918 .65144 m .61089 .65004 L .60915 .64945 L F
.60918 .65144 m .61083 .65243 L .61089 .65004 L F
.38 .156 .445 r
.21876 .60292 m .21695 .6036 L .21927 .6006 L F
.073 0 .271 r
.21876 .60292 m .21691 .6061 L .21695 .6036 L F
.532 .33 .552 r
.50768 .64715 m .50762 .64929 L .50603 .64931 L F
.2 0 0 r
.43604 .62467 m .43432 .62569 L .43209 .62591 L F
.112 0 0 r
.43811 .62455 m .43604 .62467 L .43852 .62417 L F
.43811 .62455 m .43432 .62569 L .43604 .62467 L F
.224 .74 .727 r
.52291 .73133 m .52174 .73158 L .51839 .73247 L F
.33 0 .063 r
.52463 .73006 m .52174 .73158 L .52291 .73133 L F
.537 .466 .723 r
.36122 .61712 m .35974 .62097 L .35928 .61868 L F
.36122 .61712 m .3619 .62052 L .35974 .62097 L F
.9 .607 .481 r
.55759 .63273 m .55767 .63341 L .55509 .63175 L F
.791 .509 .51 r
.1962 .58481 m .19984 .58341 L .19612 .58263 L F
.1962 .58481 m .1982 .5866 L .19984 .58341 L F
.1982 .5866 m .19823 .58662 L .19984 .58341 L F
.683 .381 .456 r
.19984 .58341 m .19823 .58662 L .19925 .58645 L F
.19823 .58662 m .19822 .58663 L .19825 .58662 L F
.19823 .58662 m .19825 .58662 L .20228 .58594 L F
.791 .509 .51 r
.1982 .5866 m .19822 .58663 L .19823 .58662 L F
.411 .508 .848 r
.1962 .58481 m .19778 .58743 L .19822 .58663 L F
.711 .843 .945 r
.19778 .58743 m .20228 .58594 L .19825 .58662 L F
.19821 .58664 m .19825 .58662 L .19822 .58663 L F
.19778 .58743 m .19825 .58662 L .19821 .58664 L F
.655 .662 .845 r
.19986 .58736 m .1992 .58706 L .1989 .58625 L F
.19916 .58611 m .1989 .58625 L .19823 .58445 L F
.19986 .58736 m .1989 .58625 L .19916 .58611 L F
.956 .786 .632 r
.19907 .58672 m .19731 .58685 L .19823 .58445 L F
.19943 .58768 m .19865 .58737 L .19907 .58672 L F
.19865 .58737 m .19731 .58685 L .19907 .58672 L F
.683 .381 .456 r
.20066 .58427 m .19925 .58645 L .20228 .58594 L F
.19984 .58341 m .19925 .58645 L .20066 .58427 L F
.655 .662 .845 r
.20155 .58613 m .20052 .58689 L .19823 .58445 L F
.20052 .58689 m .19986 .58736 L .19953 .58677 L F
.20052 .58689 m .19953 .58677 L .19823 .58445 L F
.19986 .58736 m .19943 .58768 L .1992 .58706 L F
.699 .669 .817 r
.46451 .68675 m .46579 .68992 L .46757 .68786 L F
.774 .319 .168 r
.46779 .69246 m .46579 .68992 L .46563 .6932 L F
.926 .809 .71 r
.48077 .67952 m .48237 .67949 L .48292 .67833 L F
.48077 .67952 m .48165 .68221 L .48237 .67949 L F
0 0 .336 r
.19746 .592 m .19801 .59313 L .19701 .59075 L F
.19746 .592 m .19781 .59429 L .19801 .59313 L F
.755 .948 .625 r
.48667 .71239 m .48638 .71213 L .48807 .71079 L F
0 0 0 r
.48807 .71079 m .48909 .70967 L .48963 .70892 L F
.545 .868 .585 r
.48807 .71079 m .48638 .71213 L .48909 .70967 L F
.916 .73 .635 r
.55166 .67616 m .55324 .67482 L .55026 .67218 L F
.622 .283 .375 r
.50727 .63752 m .51086 .63541 L .5084 .63526 L F
0 0 0 r
.38678 .59289 m .38506 .59331 L .38266 .59373 L F
.166 0 0 r
.38897 .59252 m .38506 .59331 L .38678 .59289 L F
.325 0 .045 r
.42155 .62647 m .42015 .62833 L .41781 .62873 L F
.58 .21 .305 r
.42386 .62619 m .42015 .62833 L .42155 .62647 L F
.659 .626 .806 r
.53825 .63795 m .53948 .64132 L .54243 .6404 L F
.778 .647 .717 r
.73964 .49303 m .74113 .49642 L .74313 .49355 L F
.752 .667 .767 r
.73858 .50185 m .74214 .50238 L .74098 .49888 L F
.757 .67 .765 r
.74098 .49888 m .74214 .50238 L .74441 .49934 L F
.728 .382 .393 r
.53581 .63829 m .53447 .6406 L .53225 .63811 L F
.488 .793 .999 r
.53704 .63697 m .53581 .63829 L .5344 .63678 L F
.598 .232 .318 r
.53799 .6401 m .53447 .6406 L .53581 .63829 L F
.568 .308 .482 r
.49474 .6756 m .49778 .67327 L .49487 .67339 L F
0 0 0 r
.42615 .62592 m .42992 .62369 L .4298 .62514 L F
.652 .328 .411 r
.42992 .62369 m .43209 .62591 L .4298 .62514 L F
.31 .704 .978 r
.57989 .63169 m .58119 .63203 L .58025 .63273 L F
0 0 .272 r
.5798 .63498 m .57989 .63169 L .58025 .63273 L F
.1 0 .309 r
.2031 .58337 m .20472 .58251 L .20497 .58 L F
0 0 0 r
.2034 .58583 m .20472 .58251 L .2031 .58337 L F
.455 .328 .618 r
.48936 .64727 m .4915 .64907 L .49192 .64669 L F
.48936 .64727 m .48977 .65011 L .4915 .64907 L F
.256 0 0 r
.38914 .62446 m .39075 .62345 L .38716 .62418 L F
.461 0 0 r
.39133 .62462 m .39075 .62345 L .38914 .62446 L F
.39133 .62462 m .39294 .62397 L .39075 .62345 L F
.093 .458 .886 r
.22025 .54618 m .21936 .54683 L .21768 .54552 L F
.22025 .54618 m .22164 .54781 L .21936 .54683 L F
.553 .49 .74 r
.36122 .61712 m .35928 .61868 L .35836 .61522 L F
.492 .815 1 r
.46888 .61171 m .47114 .61125 L .47246 .61219 L F
.46888 .61171 m .47114 .61125 L .47246 .61219 L F
.854 .908 .5 r
.79241 .51044 m .79339 .5071 L .79305 .50956 L F
.79241 .51044 m .79226 .50985 L .79339 .5071 L F
0 .064 .628 r
.79241 .51044 m .79374 .5112 L .79226 .50985 L F
.79241 .51044 m .79436 .51295 L .79374 .5112 L F
.99 .874 .618 r
.59346 .60511 m .5945 .60643 L .59507 .60374 L F
.989 .883 .623 r
.59424 .60287 m .59346 .60511 L .59507 .60374 L F
.453 .798 .998 r
.4099 .5804 m .41375 .58091 L .41154 .58134 L F
.561 .737 .958 r
.65577 .44815 m .65543 .45052 L .6537 .44733 L F
.65577 .44815 m .65741 .44983 L .65543 .45052 L F
.663 .371 .467 r
.63926 .4614 m .64182 .46359 L .63931 .46369 L F
.63926 .4614 m .64198 .46151 L .64182 .46359 L F
.693 .464 .571 r
.63926 .4614 m .63804 .46199 L .6378 .46159 L F
.63926 .4614 m .63931 .46369 L .63804 .46199 L F
.718 .615 .742 r
.75167 .50735 m .75417 .50458 L .75158 .50499 L F
.69 .577 .723 r
.75027 .49927 m .74796 .50219 L .75045 .50165 L F
.659 .584 .76 r
.74796 .50219 m .75158 .50499 L .75045 .50165 L F
.723 .701 .829 r
.41872 .58854 m .42227 .58934 L .4209 .58887 L F
.424 .793 .995 r
.42433 .58934 m .4209 .58887 L .42227 .58934 L F
.577 .643 .879 r
.57766 .65247 m .57608 .64927 L .57763 .65001 L F
.973 .711 .473 r
.57695 .65084 m .57766 .65247 L .57763 .65001 L F
.57627 .65168 m .57766 .65247 L .57695 .65084 L F
.577 .643 .879 r
.57766 .65247 m .57695 .65084 L .57608 .64927 L F
.57766 .65247 m .57942 .65288 L .57856 .6494 L F
.57766 .65247 m .57772 .65225 L .57752 .65188 L F
.634 .072 0 r
.57627 .65168 m .57942 .65288 L .57766 .65247 L F
.57627 .65168 m .57882 .6536 L .57932 .653 L F
.57864 .65258 m .57932 .653 L .57942 .65288 L F
.57627 .65168 m .57932 .653 L .57864 .65258 L F
.577 .643 .879 r
.57736 .65178 m .57752 .65188 L .57695 .65084 L F
.57766 .65247 m .57752 .65188 L .57736 .65178 L F
.973 .711 .473 r
.57695 .65084 m .57763 .65001 L .57608 .64927 L F
.821 .876 .885 r
.5805 .64765 m .57763 .65001 L .57608 .64927 L F
.577 .643 .879 r
.57772 .65225 m .57856 .6494 L .57608 .64927 L F
.973 .711 .473 r
.57627 .65168 m .57695 .65084 L .57608 .64927 L F
.496 .269 .5 r
.53434 .67298 m .53116 .67283 L .53323 .67251 L F
.53434 .67298 m .53149 .67443 L .53116 .67283 L F
.216 .07 .457 r
.22833 .58149 m .22675 .58041 L .22811 .57917 L F
.22833 .58149 m .22656 .58303 L .22675 .58041 L F
.057 0 .301 r
.22044 .60164 m .21927 .6006 L .22052 .59964 L F
.22044 .60164 m .21876 .60292 L .21927 .6006 L F
.683 .703 .862 r
.77348 .50963 m .77708 .51062 L .77675 .5092 L F
.517 .759 .984 r
.77708 .51062 m .78035 .50898 L .77675 .5092 L F
.77708 .51062 m .7795 .51008 L .78035 .50898 L F
.353 .204 .535 r
.77708 .51062 m .77914 .51221 L .7795 .51008 L F
.77708 .51062 m .77727 .51304 L .77914 .51221 L F
.692 .58 .726 r
.75045 .50165 m .75158 .50499 L .75385 .50206 L F
.684 .569 .72 r
.75385 .50206 m .75158 .50499 L .75417 .50458 L F
.421 .658 .958 r
.22732 .55037 m .2267 .55196 L .22566 .54995 L F
.22732 .55037 m .22873 .55196 L .2267 .55196 L F
.745 .9 .947 r
.60404 .6626 m .60767 .66186 L .6062 .66083 L F
.907 .82 .75 r
.61252 .45916 m .61187 .45728 L .61109 .45771 L F
0 0 0 r
.61109 .45771 m .61155 .45746 L .61449 .45577 L F
.907 .82 .75 r
.61252 .45916 m .6096 .45916 L .61016 .45795 L F
.61155 .45746 m .61127 .45557 L .61109 .45771 L F
.61164 .45728 m .61127 .45557 L .61155 .45746 L F
.817 .838 .866 r
.61551 .45431 m .61164 .45728 L .61127 .45557 L F
.907 .82 .75 r
.61178 .45703 m .61127 .45557 L .61164 .45728 L F
.765 .705 .166 r
.61127 .45557 m .61102 .45776 L .61109 .45771 L F
.817 .838 .866 r
.61164 .45728 m .61102 .45776 L .61127 .45557 L F
.907 .82 .75 r
.61178 .45703 m .61016 .45795 L .61127 .45557 L F
.709 .985 .824 r
.61449 .45577 m .61155 .45746 L .61285 .45642 L F
0 0 0 r
.61109 .45771 m .61102 .45776 L .61155 .45746 L F
.709 .985 .824 r
.61155 .45746 m .61102 .45776 L .61164 .45728 L F
.61155 .45746 m .61164 .45728 L .61551 .45431 L F
.907 .82 .75 r
.61187 .45728 m .61178 .45703 L .61155 .45746 L F
.61252 .45916 m .61016 .45795 L .61178 .45703 L F
.709 .985 .824 r
.61482 .4553 m .61285 .45642 L .61551 .45431 L F
.61449 .45577 m .61285 .45642 L .61482 .4553 L F
.858 .746 .738 r
.6239 .44512 m .6197 .44817 L .62261 .44366 L F
.6239 .44512 m .62141 .44952 L .6197 .44817 L F
.388 .125 .389 r
.53515 .69027 m .53455 .69314 L .53228 .69332 L F
.54 .259 .438 r
.53772 .69192 m .53515 .69027 L .53757 .68949 L F
.53772 .69192 m .53455 .69314 L .53515 .69027 L F
.283 0 0 r
.41172 .63073 m .40996 .63034 L .41301 .62925 L F
.338 0 0 r
.41556 .62887 m .41172 .63073 L .41301 .62925 L F
.546 .345 .559 r
.48077 .67952 m .48292 .67833 L .48065 .676 L F
.639 .448 .608 r
.49437 .64403 m .49704 .64391 L .49716 .64112 L F
.63 .485 .666 r
.49704 .64391 m .49939 .64087 L .49716 .64112 L F
.387 .461 .815 r
.43198 .59169 m .43326 .58967 L .43035 .59056 L F
.43198 .59169 m .43366 .59159 L .43326 .58967 L F
.487 .589 .882 r
.43273 .59218 m .4351 .59374 L .43366 .59159 L F
.711 .177 0 r
.43776 .59381 m .43366 .59159 L .4351 .59374 L F
.43776 .59381 m .43471 .59358 L .43366 .59159 L F
.03 0 .336 r
.43366 .59159 m .43471 .59358 L .43526 .59057 L F
.43366 .59159 m .43526 .59057 L .43543 .58965 L F
.487 .589 .882 r
.43198 .59169 m .43273 .59218 L .43366 .59159 L F
.589 .409 .606 r
.54325 .6586 m .54567 .66132 L .54563 .65834 L F
.322 .114 .435 r
.21425 .61609 m .21307 .61501 L .21465 .61428 L F
.21425 .61609 m .21271 .61726 L .21307 .61501 L F
0 0 0 r
.47788 .68951 m .47733 .68886 L .47906 .68808 L F
.47788 .68951 m .47606 .69052 L .47733 .68886 L F
.461 .17 .383 r
.40726 .6207 m .40951 .62025 L .4101 .61749 L F
.556 .335 .534 r
.40951 .62025 m .4122 .61721 L .4101 .61749 L F
.675 .456 .581 r
.6378 .46159 m .63804 .46199 L .63334 .46398 L F
.29 0 0 r
.55069 .679 m .54944 .68065 L .54707 .68108 L F
.842 .976 .876 r
.55305 .6786 m .54944 .68065 L .55069 .679 L F
.309 .051 .35 r
.52615 .69073 m .52534 .69274 L .52807 .6899 L F
.393 .123 .381 r
.52101 .66763 m .52376 .66486 L .51943 .66409 L F
.283 0 0 r
.40935 .63112 m .40996 .63034 L .41172 .63073 L F
.649 .681 .867 r
.76113 .5078 m .76482 .50874 L .76356 .50702 L F
.707 .677 .819 r
.76356 .50702 m .76482 .50874 L .76711 .50772 L F
.36 0 0 r
.35052 .58483 m .35285 .58487 L .35451 .58374 L F
.315 0 0 r
.35285 .58487 m .35676 .58368 L .35451 .58374 L F
.696 .246 .179 r
.36706 .64112 m .36502 .64234 L .36361 .64053 L F
.376 .838 .891 r
.36934 .64047 m .36785 .64046 L .36706 .64112 L F
.451 .847 .648 r
.36785 .64046 m .36502 .64234 L .36706 .64112 L F
0 0 .146 r
.22435 .58821 m .22324 .58915 L .22501 .58617 L F
.874 .853 .818 r
.27367 .70431 m .27534 .70529 L .27759 .70218 L F
.508 .803 .999 r
.27367 .70431 m .27534 .70529 L .27582 .70387 L F
.293 .159 .521 r
.21198 .61985 m .2108 .61813 L .21271 .61726 L F
.21198 .61985 m .21072 .62059 L .2108 .61813 L F
.481 .06 .164 r
.34202 .58755 m .34595 .58549 L .3427 .58662 L F
.34202 .58755 m .34444 .58754 L .34595 .58549 L F
.408 0 .147 r
.34444 .58754 m .34821 .58508 L .34595 .58549 L F
.401 .27 .585 r
.32259 .60357 m .32436 .60307 L .32413 .60045 L F
.429 .356 .673 r
.32259 .60357 m .32486 .60546 L .32436 .60307 L F
.447 .357 .66 r
.32316 .60595 m .32486 .60546 L .32259 .60357 L F
.834 .656 .661 r
.59476 .6234 m .59672 .62386 L .59498 .62065 L F
.874 .606 .531 r
.59352 .62452 m .59672 .62386 L .59476 .6234 L F
.59352 .62452 m .59657 .62613 L .59672 .62386 L F
.499 .795 .998 r
.52054 .6954 m .52122 .69643 L .51763 .69591 L F
.598 .442 .641 r
.52021 .69852 m .51763 .69591 L .52122 .69643 L F
.821 .944 .905 r
.52426 .69406 m .52122 .69643 L .52054 .6954 L F
.688 .348 .395 r
.5236 .6986 m .52021 .69852 L .52122 .69643 L F
.583 .378 .568 r
.52355 .69607 m .52122 .69643 L .52426 .69406 L F
.583 .377 .567 r
.52355 .69607 m .5236 .6986 L .52122 .69643 L F
.497 .398 .673 r
.20492 .5771 m .2071 .5767 L .2066 .57409 L F
.316 .172 .521 r
.20497 .58 m .2071 .5767 L .20492 .5771 L F
0 0 0 r
.39258 .59176 m .39079 .5925 L .38897 .59252 L F
.071 0 0 r
.39308 .5922 m .39258 .59176 L .39483 .59151 L F
.39308 .5922 m .39079 .5925 L .39258 .59176 L F
.814 .388 .231 r
.60627 .6412 m .60816 .64343 L .60985 .64372 L F
.892 .643 .555 r
.60816 .64343 m .60993 .64679 L .60985 .64372 L F
.628 .463 .64 r
.63921 .42986 m .64131 .42921 L .63843 .4295 L F
.401 .375 .715 r
.32514 .61519 m .32617 .61117 L .32415 .61151 L F
.32514 .61519 m .32695 .6148 L .32617 .61117 L F
.528 .561 .833 r
.32514 .61519 m .32861 .61805 L .32695 .6148 L F
.564 .547 .793 r
.44269 .59994 m .44412 .59676 L .44202 .5983 L F
.44269 .59994 m .44497 .59953 L .44412 .59676 L F
.967 .799 .622 r
.53674 .61761 m .53735 .62048 L .53623 .61898 L F
.914 .567 .107 r
.53735 .62048 m .53727 .62218 L .53623 .61898 L F
.937 .928 .771 r
.53727 .62218 m .53616 .62151 L .53637 .62115 L F
.439 .701 .977 r
.53925 .61934 m .53735 .62048 L .53674 .61761 L F
.53925 .61934 m .54029 .62072 L .53735 .62048 L F
.089 .615 .873 r
.53623 .61898 m .53925 .61934 L .53674 .61761 L F
.53787 .61917 m .53776 .61879 L .53925 .61934 L F
.53623 .61898 m .53776 .61879 L .53787 .61917 L F
0 .138 .625 r
.53764 .61839 m .53776 .61879 L .53667 .61757 L F
.53899 .61955 m .53776 .61879 L .53764 .61839 L F
.937 .928 .771 r
.53727 .62218 m .53776 .61879 L .53623 .61898 L F
.53727 .62218 m .53637 .62115 L .53776 .61879 L F
.914 .567 .107 r
.53735 .62048 m .53812 .62314 L .53727 .62218 L F
.53812 .62314 m .53818 .62335 L .53727 .62218 L F
.716 .678 .812 r
.80187 .51181 m .79809 .51113 L .8006 .51026 L F
.777 .783 .858 r
.8006 .51026 m .80397 .51047 L .80187 .51181 L F
.496 .248 .469 r
.75846 .49598 m .76082 .49543 L .76102 .49332 L F
.009 0 .025 r
.76082 .49543 m .76344 .49264 L .76102 .49332 L F
.548 .704 .943 r
.4494 .59432 m .45317 .5951 L .45077 .59558 L F
.424 0 0 r
.44783 .62415 m .44973 .62501 L .44729 .62512 L F
.807 .61 .635 r
.55846 .67535 m .55541 .67832 L .55537 .6756 L F
.55846 .67535 m .55817 .67835 L .55541 .67832 L F
.044 .333 .814 r
.55663 .67261 m .55933 .67447 L .55846 .67535 L F
0 0 .391 r
.55933 .67447 m .55817 .67835 L .55846 .67535 L F
.868 .84 .816 r
.46288 .61427 m .46265 .61781 L .46443 .616 L F
.46269 .6172 m .46056 .6173 L .46265 .61781 L F
.712 .362 .383 r
.46265 .61911 m .46265 .61781 L .46056 .6173 L F
.866 .598 .531 r
.46056 .6173 m .46265 .61911 L .46205 .61723 L F
.46056 .6173 m .46205 .61723 L .4615 .61548 L F
.868 .84 .816 r
.46288 .61427 m .46056 .6173 L .46269 .6172 L F
.712 .362 .383 r
.46265 .61911 m .46414 .62008 L .46265 .61781 L F
.914 .695 .592 r
.55855 .68495 m .5579 .68722 L .55638 .68382 L F
.73 .826 .924 r
.63682 .43823 m .64029 .43839 L .63902 .43694 L F
.683 .815 .946 r
.63902 .43694 m .64029 .43839 L .64201 .43701 L F
.735 .497 .568 r
.43918 .6144 m .44253 .61679 L .44281 .61531 L F
.631 .249 .301 r
.44253 .61679 m .44515 .61714 L .44281 .61531 L F
.393 .123 .381 r
.52101 .66763 m .52312 .66683 L .52376 .66486 L F
0 0 0 r
.52101 .66763 m .52376 .66486 L .52312 .66683 L F
.227 0 .303 r
.52546 .66389 m .52312 .66683 L .52376 .66486 L F
.52546 .66389 m .52312 .66683 L .52376 .66486 L F
.553 .49 .74 r
.36122 .61712 m .35836 .61522 L .36052 .61472 L F
0 0 .014 r
.55537 .6756 m .55663 .67261 L .5558 .67321 L F
.593 .606 .834 r
.58356 .66451 m .58738 .66726 L .58571 .66473 L F
.59 .681 .905 r
.58571 .66473 m .58718 .66695 L .58767 .66576 L F
.58571 .66473 m .58767 .66576 L .58729 .6666 L F
.689 .783 .922 r
.58729 .6666 m .58748 .66621 L .58748 .66617 L F
.58729 .6666 m .5909 .66317 L .58962 .66185 L F
.71 .751 .885 r
.58954 .66673 m .5909 .66317 L .58741 .66649 L F
.59 .681 .905 r
.58767 .66576 m .58752 .6665 L .58954 .66673 L F
.58752 .6665 m .58738 .66726 L .58954 .66673 L F
.71 .751 .885 r
.58954 .66673 m .58741 .66649 L .58729 .6666 L F
.59 .681 .905 r
.58767 .66576 m .58954 .66673 L .58729 .6666 L F
.689 .783 .922 r
.58729 .6666 m .58748 .66617 L .58768 .66316 L F
.58748 .66621 m .58962 .66185 L .58914 .66217 L F
.58748 .66621 m .58914 .66217 L .58768 .66316 L F
.59 .681 .905 r
.58718 .66695 m .58738 .66726 L .58767 .66576 L F
.224 .072 .454 r
.49717 .69863 m .49815 .70043 L .4978 .69935 L F
.18 0 0 r
.49669 .69808 m .49717 .69863 L .49898 .69684 L F
.963 .889 .708 r
.49898 .69684 m .49717 .69863 L .49844 .69535 L F
.89 .91 .507 r
.49844 .69535 m .49717 .69863 L .4971 .69711 L F
.224 .072 .454 r
.49717 .69863 m .4978 .69935 L .4971 .69711 L F
.18 0 0 r
.49449 .69928 m .49717 .69863 L .49669 .69808 L F
.671 .458 .588 r
.49526 .70071 m .49717 .69863 L .49449 .69928 L F
.052 0 0 r
.38625 .58252 m .38854 .5821 L .38982 .58133 L F
0 0 0 r
.38982 .58133 m .39066 .58092 L .39205 .58119 L F
.38982 .58133 m .38854 .5821 L .39066 .58092 L F
.347 0 0 r
.39486 .62453 m .39642 .62357 L .39294 .62397 L F
.201 0 0 r
.39721 .62468 m .39642 .62357 L .39486 .62453 L F
.39721 .62468 m .39873 .62292 L .39642 .62357 L F
.557 .291 .468 r
.50759 .65926 m .50732 .66106 L .50427 .66171 L F
.049 0 .297 r
.50856 .66021 m .50732 .66106 L .50759 .65926 L F
.482 .325 .591 r
.73507 .49884 m .73743 .49595 L .73527 .49762 L F
.73507 .49884 m .73737 .49833 L .73743 .49595 L F
.597 .539 .76 r
.73507 .49884 m .73858 .50185 L .73737 .49833 L F
.736 .794 .899 r
.46288 .61427 m .46443 .616 L .46706 .61425 L F
.529 .291 .498 r
.5367 .65598 m .53637 .65846 L .53389 .65879 L F
.523 .331 .562 r
.53884 .65521 m .53637 .65846 L .5367 .65598 L F
.578 .675 .906 r
.79835 .5149 m .7993 .51647 L .80185 .51596 L F
.399 .263 .578 r
.32428 .59794 m .3263 .59937 L .32644 .59723 L F
.32428 .59794 m .32413 .60045 L .3263 .59937 L F
.881 .625 .547 r
.59831 .63704 m .60169 .63548 L .59935 .63447 L F
.59831 .63704 m .60144 .63797 L .60169 .63548 L F
.783 .531 .555 r
.60169 .63548 m .60144 .63797 L .60436 .63828 L F
.7 .303 .293 r
.48299 .6897 m .47906 .68808 L .48303 .68771 L F
.671 .483 .622 r
.48545 .68727 m .48299 .6897 L .48303 .68771 L F
.874 .853 .818 r
.27367 .70431 m .27759 .70218 L .27438 .70235 L F
.41 .732 .991 r
.27815 .70093 m .28045 .7023 L .27759 .70218 L F
.421 0 0 r
.28045 .7023 m .27967 .70268 L .27759 .70218 L F
.218 .506 .907 r
.27759 .70218 m .27967 .70268 L .27815 .70093 L F
.475 .642 .93 r
.64667 .44447 m .64499 .44608 L .64412 .44335 L F
.64667 .44447 m .64741 .44626 L .64499 .44608 L F
.856 .474 .322 r
.60472 .64056 m .60816 .64343 L .60627 .6412 L F
.421 .236 .523 r
.58242 .62601 m .58307 .6223 L .5811 .62376 L F
.745 .297 .189 r
.79003 .51846 m .79161 .51809 L .79303 .51907 L F
.691 .503 .628 r
.75277 .49858 m .75601 .49918 L .7554 .49606 L F
.556 .335 .535 r
.75601 .49918 m .75846 .49598 L .7554 .49606 L F
0 .332 .812 r
.46053 .70897 m .46215 .70936 L .45942 .70756 L F
.46053 .70897 m .46264 .7104 L .46215 .70936 L F
.587 .903 .643 r
.18814 .55944 m .19028 .55707 L .18886 .55896 L F
.598 .218 .293 r
.78706 .4773 m .78969 .47738 L .79042 .47512 L F
.568 .231 .359 r
.78969 .47738 m .79295 .47504 L .79042 .47512 L F
.362 .098 .372 r
.23009 .57617 m .22892 .5747 L .23025 .57376 L F
.23009 .57617 m .22817 .57679 L .22892 .5747 L F
.593 .022 0 r
.48634 .70124 m .48799 .70265 L .48918 .70217 L F
.661 .483 .633 r
.48918 .70217 m .48928 .70495 L .48678 .70497 L F
.18 0 .165 r
.49157 .70016 m .48918 .70217 L .49091 .70146 L F
.645 .207 .195 r
.48799 .70265 m .49091 .70146 L .48918 .70217 L F
.818 .711 .747 r
.45112 .61541 m .45233 .61783 L .45495 .61419 L F
.689 .592 .743 r
.75045 .50165 m .75277 .49858 L .75027 .49927 L F
.75045 .50165 m .75385 .50206 L .75277 .49858 L F
.742 .46 .502 r
.50461 .70752 m .50141 .70504 L .50467 .70515 L F
.542 .307 .508 r
.50728 .70526 m .50467 .70515 L .50726 .70451 L F
.50728 .70526 m .50461 .70752 L .50467 .70515 L F
0 .003 .579 r
.57049 .65271 m .57059 .65163 L .5698 .64998 L F
.077 .4 .856 r
.57049 .65271 m .57336 .65486 L .57059 .65163 L F
.568 .57 .815 r
.19028 .55707 m .1911 .55686 L .18964 .5534 L F
.587 .903 .643 r
.18814 .55944 m .1911 .55686 L .19028 .55707 L F
0 0 0 r
.40495 .62111 m .40528 .62124 L .40726 .6207 L F
.40495 .62111 m .40323 .62223 L .40528 .62124 L F
.157 .064 .49 r
.19477 .58609 m .1962 .58481 L .19612 .58263 L F
.426 .112 .329 r
.36398 .6002 m .3631 .60297 L .36084 .60346 L F
.477 .16 .35 r
.3656 .60228 m .36398 .6002 L .36622 .59925 L F
.3656 .60228 m .3631 .60297 L .36398 .6002 L F
.763 .944 .939 r
.7668 .49237 m .76868 .48989 L .76921 .49004 L F
.7668 .49237 m .76581 .49173 L .76868 .48989 L F
.969 .804 .622 r
.59346 .60511 m .59457 .6085 L .5945 .60643 L F
.149 0 .02 r
.53228 .69332 m .53144 .69532 L .52942 .69588 L F
.384 0 .166 r
.53455 .69314 m .53144 .69532 L .53228 .69332 L F
.438 .045 .195 r
.52582 .67619 m .52226 .67856 L .52277 .67812 L F
.52582 .67619 m .52468 .67847 L .52226 .67856 L F
.383 0 .169 r
.52676 .6766 m .52582 .67619 L .52787 .67584 L F
.52764 .67698 m .52468 .67847 L .52499 .67785 L F
.52672 .67664 m .52524 .67735 L .52582 .67619 L F
.446 .065 .222 r
.52226 .67856 m .52632 .67683 L .52087 .67489 L F
.52632 .67683 m .52675 .67665 L .52672 .67664 L F
.52632 .67683 m .52672 .67664 L .52087 .67489 L F
.383 0 .169 r
.52676 .6766 m .52672 .67664 L .52582 .67619 L F
.52675 .67661 m .52673 .67662 L .52676 .6766 L F
.52673 .67662 m .52672 .67664 L .52673 .67662 L F
.52673 .67662 m .52673 .67662 L .52676 .6766 L F
.128 .285 .755 r
.52461 .67287 m .52673 .67662 L .52671 .67467 L F
.52673 .67662 m .52675 .67665 L .52674 .67663 L F
.52673 .67662 m .52674 .67663 L .52671 .67467 L F
.782 .591 .641 r
.52672 .67664 m .52673 .67662 L .52673 .67662 L F
.52087 .67489 m .52671 .67664 L .52461 .67287 L F
.52671 .67664 m .52673 .67662 L .52461 .67287 L F
.712 .96 .694 r
.52674 .67663 m .52583 .67662 L .52671 .67467 L F
.52675 .67665 m .52674 .67665 L .52674 .67663 L F
.782 .591 .641 r
.52671 .67664 m .52672 .67664 L .52673 .67662 L F
.52672 .67664 m .52675 .67665 L .52673 .67662 L F
.712 .96 .694 r
.52674 .67665 m .52583 .67662 L .52674 .67663 L F
.383 0 .169 r
.52676 .6766 m .52675 .67661 L .52676 .6766 L F
.446 .065 .222 r
.52632 .67683 m .52468 .67847 L .52675 .67665 L F
.383 0 .169 r
.52632 .67683 m .52499 .67785 L .52524 .67735 L F
.52603 .67712 m .52499 .67785 L .52632 .67683 L F
.446 .065 .222 r
.52226 .67856 m .52468 .67847 L .52632 .67683 L F
.383 0 .169 r
.52672 .67664 m .52603 .67712 L .52632 .67683 L F
.52764 .67698 m .52499 .67785 L .52676 .6766 L F
.52764 .67698 m .52676 .6766 L .52796 .67583 L F
.52676 .6766 m .52787 .67584 L .52796 .67583 L F
.575 .219 .328 r
.51297 .63723 m .51355 .63546 L .51086 .63541 L F
.622 .283 .375 r
.50727 .63752 m .50983 .6377 L .51086 .63541 L F
.565 .223 .348 r
.51086 .63541 m .50983 .6377 L .51297 .63723 L F
.575 .296 .455 r
.64525 .46058 m .64182 .46359 L .64198 .46151 L F
.821 .944 .905 r
.52426 .69406 m .52054 .6954 L .52355 .69607 L F
.481 .843 .992 r
.80402 .50967 m .80397 .51047 L .8006 .51026 L F
.293 .446 .843 r
.23093 .55294 m .23003 .55455 L .22873 .55196 L F
.332 .443 .824 r
.23093 .55294 m .23071 .55575 L .23003 .55455 L F
.715 .689 .824 r
.4366 .58594 m .43327 .58549 L .43598 .58469 L F
.507 .724 .97 r
.43698 .58358 m .4366 .58594 L .43598 .58469 L F
.43698 .58358 m .43865 .58553 L .4366 .58594 L F
.809 .656 .693 r
.53644 .68711 m .53958 .68837 L .54002 .68496 L F
.623 .484 .672 r
.54002 .68496 m .53958 .68837 L .54242 .68449 L F
.54002 .68496 m .53958 .68837 L .54242 .68449 L F
.692 .952 .954 r
.5805 .64765 m .58126 .64605 L .58156 .64596 L F
.5805 .64765 m .57867 .64726 L .58126 .64605 L F
.107 0 0 r
.47508 .62378 m .47387 .62563 L .47199 .62586 L F
.553 .504 .755 r
.47592 .61958 m .47508 .62378 L .47367 .62055 L F
.47592 .61958 m .47705 .6231 L .47508 .62378 L F
.141 0 0 r
.47594 .62483 m .47508 .62378 L .47705 .6231 L F
.47594 .62483 m .47387 .62563 L .47508 .62378 L F
.307 .037 .33 r
.22622 .58742 m .22501 .58617 L .22696 .58548 L F
.22622 .58742 m .22435 .58821 L .22501 .58617 L F
.187 .038 .435 r
.36025 .60504 m .35891 .60372 L .36084 .60346 L F
.36025 .60504 m .35893 .60582 L .35891 .60372 L F
.657 .558 .731 r
.75417 .50458 m .75642 .50148 L .75385 .50206 L F
.75417 .50458 m .75753 .50514 L .75642 .50148 L F
.271 0 .112 r
.58126 .64605 m .58434 .64308 L .58271 .64452 L F
.603 .314 .451 r
.63334 .46398 m .63804 .46199 L .63587 .46581 L F
.82 .461 .376 r
.63804 .46199 m .63858 .46569 L .63587 .46581 L F
.63804 .46199 m .63931 .46369 L .63858 .46569 L F
.273 0 .132 r
.65848 .45308 m .65827 .45444 L .65563 .45514 L F
.508 .087 .176 r
.66066 .45415 m .65827 .45444 L .65848 .45308 L F
.451 .198 .437 r
.66164 .45079 m .66066 .45415 L .65848 .45308 L F
0 0 0 r
.53109 .72248 m .53172 .72153 L .53229 .71955 L F
.766 .661 .747 r
.52989 .71798 m .53172 .72153 L .52733 .721 L F
.127 .657 .868 r
.52733 .721 m .53172 .72153 L .53061 .72116 L F
.962 .629 .294 r
.52989 .71798 m .53172 .72153 L .53061 .72116 L F
0 0 0 r
.53084 .72311 m .53172 .72153 L .53109 .72248 L F
.993 .848 .591 r
.53172 .72153 m .53092 .72377 L .53061 .72116 L F
.998 .834 .497 r
.53061 .72116 m .53092 .72377 L .53008 .72334 L F
.614 .863 .509 r
.53172 .72153 m .53008 .72334 L .53242 .72045 L F
.685 .271 .255 r
.53172 .72153 m .53449 .72154 L .53229 .71955 L F
.16 .288 .747 r
.53229 .71955 m .53449 .72154 L .53354 .71848 L F
.785 .691 .761 r
.53354 .71848 m .53449 .72154 L .53172 .72153 L F
0 0 0 r
.53354 .71848 m .53172 .72153 L .53245 .72041 L F
.614 .863 .509 r
.53172 .72153 m .53242 .72045 L .53245 .72041 L F
.596 .242 .339 r
.53449 .72154 m .53377 .72394 L .53284 .72389 L F
0 .072 .591 r
.53084 .72311 m .53195 .72431 L .53179 .72241 L F
.782 .706 .779 r
.53172 .72153 m .53195 .72431 L .53449 .72154 L F
.596 .242 .339 r
.53219 .72298 m .53284 .72389 L .53092 .72377 L F
.53449 .72154 m .53284 .72389 L .53219 .72298 L F
0 .072 .591 r
.53147 .72196 m .53179 .72241 L .53172 .72153 L F
.53084 .72311 m .53179 .72241 L .53147 .72196 L F
.349 .114 .41 r
.53195 .72431 m .53003 .7253 L .53084 .72311 L F
.53195 .72431 m .53003 .7253 L .53084 .72311 L F
.659 .766 .929 r
.4732 .67605 m .47484 .67835 L .47673 .67713 L F
0 0 0 r
.33955 .63434 m .33728 .63705 L .33804 .63464 L F
0 0 .023 r
.33804 .63464 m .3382 .6351 L .33955 .63434 L F
.464 .309 .585 r
.54375 .64687 m .54586 .64655 L .54537 .64392 L F
.13 .169 .635 r
.54375 .64687 m .54557 .64857 L .54586 .64655 L F
.445 0 0 r
.39856 .59139 m .39737 .59195 L .39483 .59151 L F
.13 .676 .715 r
.40078 .59141 m .39737 .59195 L .39856 .59139 L F
.475 .103 .253 r
.40107 .59054 m .40078 .59141 L .39856 .59139 L F
.169 .705 .823 r
.36119 .58332 m .36044 .58369 L .35863 .58362 L F
.36119 .58332 m .36277 .58347 L .36044 .58369 L F
.74 .51 .581 r
.63551 .43372 m .63761 .43435 L .63921 .42986 L F
.628 .463 .64 r
.63921 .42986 m .64123 .43181 L .64131 .42921 L F
.296 .158 .517 r
.54674 .67599 m .54864 .67752 L .54966 .67505 L F
.54674 .67599 m .54673 .67858 L .54864 .67752 L F
.675 .623 .789 r
.75753 .50514 m .76113 .5078 L .76001 .50437 L F
.66 .615 .794 r
.76001 .50437 m .76113 .5078 L .76356 .50702 L F
.29 .051 .368 r
.52918 .63824 m .5288 .64034 L .52677 .64081 L F
.204 0 .126 r
.52856 .6404 m .52608 .64267 L .52677 .64081 L F
.52849 .64061 m .52608 .64267 L .52856 .6404 L F
.529 .269 .466 r
.52038 .64066 m .52258 .64216 L .52307 .63986 L F
.683 .414 .51 r
.52307 .63986 m .52258 .64216 L .52769 .64122 L F
.204 0 .126 r
.5288 .64034 m .52849 .64061 L .52856 .6404 L F
.596 .945 .798 r
.5287 .6404 m .52828 .64076 L .5288 .64034 L F
.52828 .64076 m .52608 .64267 L .52849 .64061 L F
.52828 .64076 m .52849 .64061 L .5288 .64034 L F
.683 .414 .51 r
.52307 .63986 m .52769 .64122 L .52796 .641 L F
.66 .264 .283 r
.52307 .63986 m .52796 .641 L .52127 .6412 L F
.683 .414 .51 r
.52796 .641 m .52769 .64122 L .52837 .6411 L F
.66 .264 .283 r
.52796 .641 m .52834 .64109 L .52783 .6411 L F
.52796 .641 m .52783 .6411 L .52127 .6412 L F
.52834 .64109 m .52834 .6411 L .52782 .64111 L F
.52783 .6411 m .52782 .64111 L .52127 .6412 L F
.52834 .64109 m .52782 .64111 L .52783 .6411 L F
.747 .703 .81 r
.52782 .64111 m .52258 .64216 L .52127 .6412 L F
.52837 .6411 m .52769 .64122 L .52782 .64111 L F
.52769 .64122 m .52258 .64216 L .52782 .64111 L F
.596 .945 .798 r
.52726 .64123 m .52664 .64199 L .52808 .64088 L F
.52847 .64053 m .52808 .64088 L .5287 .6404 L F
.52726 .64123 m .52808 .64088 L .52847 .64053 L F
.52664 .64199 m .52642 .64226 L .52796 .641 L F
.52664 .64199 m .52796 .641 L .5287 .6404 L F
.52642 .64226 m .52608 .64267 L .5287 .6404 L F
.66 .264 .283 r
.52834 .64109 m .52837 .6411 L .52834 .6411 L F
.518 .449 .719 r
.58002 .6621 m .58165 .65773 L .57867 .65887 L F
.58002 .6621 m .58215 .66145 L .58165 .65773 L F
.214 .686 .939 r
.20826 .545 m .21 .54572 L .20628 .54496 L F
.117 .584 .917 r
.21026 .54498 m .21 .54572 L .20826 .545 L F
.21026 .54498 m .21203 .54594 L .21 .54572 L F
.227 .416 .84 r
.32861 .61805 m .32997 .61749 L .32695 .6148 L F
.55 .284 .466 r
.32708 .61957 m .32861 .61805 L .33027 .62002 L F
.32708 .61957 m .32997 .61749 L .32861 .61805 L F
.726 .309 .255 r
.49875 .70519 m .50119 .7075 L .49918 .70635 L F
.625 .357 .491 r
.50141 .70504 m .50119 .7075 L .49875 .70519 L F
.891 .55 .396 r
.55767 .63341 m .55536 .63351 L .55509 .63175 L F
.55767 .63341 m .55811 .63537 L .55536 .63351 L F
.626 .77 .949 r
.64355 .42639 m .64002 .42567 L .64245 .42507 L F
.64355 .42639 m .64002 .42567 L .64245 .42507 L F
.942 .827 .701 r
.58665 .61159 m .58697 .61502 L .58574 .61427 L F
.91 .83 .756 r
.58574 .61427 m .58697 .61502 L .5854 .6182 L F
.774 .498 .518 r
.50427 .67815 m .50412 .67943 L .50247 .67965 L F
.50427 .67815 m .50247 .67965 L .50275 .67894 L F
.50412 .67943 m .50374 .6795 L .50097 .67985 L F
.811 .781 .825 r
.50097 .67985 m .50214 .68009 L .50374 .6795 L F
.774 .498 .518 r
.50374 .6795 m .5012 .67993 L .50097 .67985 L F
.584 .327 .492 r
.50644 .68032 m .50395 .68093 L .50412 .67945 L F
.5048 .67868 m .5044 .67913 L .50427 .67815 L F
.50455 .67907 m .50412 .67945 L .5048 .67868 L F
.674 .372 .455 r
.50766 .67591 m .5061 .67858 L .50427 .67815 L F
.5061 .67858 m .50494 .679 L .50427 .67815 L F
.774 .498 .518 r
.50427 .67815 m .50366 .67847 L .50177 .67857 L F
.50366 .67847 m .50199 .67933 L .50173 .67863 L F
.50366 .67847 m .50173 .67863 L .50177 .67857 L F
.719 .486 .572 r
.49709 .67552 m .50184 .67562 L .50064 .67288 L F
.332 .295 .666 r
.50064 .67288 m .50184 .67562 L .50279 .67471 L F
.599 .202 .262 r
.49723 .67744 m .50184 .67562 L .49709 .67552 L F
.49723 .67744 m .49925 .67741 L .50184 .67562 L F
.781 .625 .686 r
.49925 .67741 m .50279 .67471 L .50184 .67562 L F
.49925 .67741 m .5033 .67879 L .50279 .67471 L F
.584 .327 .492 r
.5044 .67913 m .50417 .67904 L .50427 .67815 L F
.781 .625 .686 r
.5033 .67879 m .50447 .67919 L .50419 .67843 L F
.5033 .67879 m .50419 .67843 L .50279 .67471 L F
.774 .498 .518 r
.50199 .67933 m .50097 .67985 L .50106 .6797 L F
.50199 .67933 m .50106 .6797 L .50173 .67863 L F
.674 .372 .455 r
.5061 .67858 m .50547 .67966 L .50494 .679 L F
.581 .266 .4 r
.50976 .67805 m .50547 .67966 L .50766 .67591 L F
.418 .036 .205 r
.50976 .67805 m .50644 .68032 L .50547 .67966 L F
.378 .315 .66 r
.50547 .67966 m .50644 .68032 L .50427 .67815 L F
.483 .466 .762 r
.50279 .67471 m .50421 .67842 L .50586 .67552 L F
.50421 .67842 m .5045 .67917 L .5048 .67837 L F
.50421 .67842 m .5048 .67837 L .50586 .67552 L F
.5045 .67917 m .50452 .67921 L .50453 .67918 L F
.5045 .67917 m .50453 .67918 L .50586 .67552 L F
.584 .327 .492 r
.5044 .67913 m .50412 .67945 L .50417 .67904 L F
.50489 .67878 m .50455 .67907 L .5048 .67868 L F
.811 .781 .825 r
.50253 .67957 m .50446 .67922 L .50298 .6787 L F
.50446 .67922 m .50447 .67919 L .49925 .67741 L F
.584 .327 .492 r
.50443 .67924 m .50412 .67945 L .50489 .67878 L F
.781 .625 .686 r
.50447 .67919 m .5045 .67917 L .50279 .67471 L F
.811 .781 .825 r
.50097 .67985 m .50374 .6795 L .50442 .67924 L F
.50097 .67985 m .50442 .67924 L .50446 .67922 L F
0 0 .137 r
.50223 .67998 m .50586 .67552 L .50454 .67915 L F
.50248 .67967 m .50431 .67925 L .50586 .67552 L F
.50244 .67972 m .50245 .67972 L .50248 .67967 L F
.50245 .67972 m .50431 .67925 L .50248 .67967 L F
.774 .498 .518 r
.50275 .67894 m .50247 .67965 L .50097 .67985 L F
.383 0 0 r
.50177 .67857 m .50097 .67985 L .49835 .67922 L F
.811 .781 .825 r
.50097 .67985 m .50253 .67957 L .49925 .67741 L F
.50253 .67957 m .50298 .6787 L .49925 .67741 L F
.50446 .67922 m .50452 .67921 L .50447 .67919 L F
.781 .625 .686 r
.50447 .67919 m .50452 .67921 L .5045 .67917 L F
.584 .327 .492 r
.50498 .67886 m .50443 .67924 L .50489 .67878 L F
.811 .781 .825 r
.50446 .67922 m .50442 .67924 L .50452 .67921 L F
.584 .327 .492 r
.50644 .68032 m .50412 .67945 L .50498 .67886 L F
0 0 .137 r
.50214 .68009 m .50232 .68002 L .50244 .67972 L F
.50214 .68009 m .50223 .67998 L .50358 .67952 L F
.50214 .68009 m .50358 .67952 L .50374 .6795 L F
0 0 0 r
.50187 .6826 m .50214 .68009 L .50097 .67985 L F
.774 .498 .518 r
.50412 .67943 m .50395 .68093 L .50227 .68032 L F
.50412 .67943 m .50227 .68032 L .50229 .6802 L F
0 0 .137 r
.50374 .6795 m .50358 .67952 L .50452 .67921 L F
.228 0 0 r
.50221 .68353 m .50418 .68326 L .50549 .68181 L F
.50186 .68371 m .50218 .68365 L .50221 .68353 L F
.50218 .68365 m .50418 .68326 L .50221 .68353 L F
.15 .119 .565 r
.5006 .68383 m .50226 .68614 L .50186 .68371 L F
.877 .677 .152 r
.50226 .68614 m .50187 .68519 L .5019 .68488 L F
0 0 .556 r
.50226 .68614 m .50341 .68688 L .50187 .68519 L F
.73 .488 .561 r
.50341 .68688 m .5018 .68587 L .50187 .68519 L F
.15 .119 .565 r
.5006 .68383 m .50055 .68753 L .50226 .68614 L F
.73 .488 .561 r
.5018 .68587 m .49948 .68441 L .50187 .68519 L F
.877 .677 .152 r
.5019 .68488 m .50187 .68519 L .50187 .68476 L F
.50204 .68414 m .50187 .68476 L .50187 .6826 L F
.50226 .68614 m .50187 .68476 L .50204 .68414 L F
.555 .454 .694 r
.50395 .68093 m .50418 .68326 L .50186 .68371 L F
.50395 .68093 m .50187 .6826 L .50193 .68209 L F
0 0 0 r
.50187 .6826 m .5019 .68257 L .50203 .68117 L F
.50187 .6826 m .50203 .68117 L .50214 .68009 L F
.555 .454 .694 r
.50193 .68209 m .50187 .6826 L .50174 .6822 L F
.50395 .68093 m .50174 .6822 L .50227 .68032 L F
0 0 0 r
.5019 .68257 m .50212 .68044 L .50212 .68041 L F
.50203 .68117 m .50212 .68041 L .50214 .68009 L F
.5019 .68257 m .50212 .68041 L .50203 .68117 L F
.555 .454 .694 r
.50213 .68027 m .50174 .6822 L .50097 .67985 L F
.189 0 .097 r
.5023 .68021 m .502 .68245 L .50401 .68144 L F
.50214 .68009 m .50222 .6803 L .50229 .6802 L F
.774 .498 .518 r
.50229 .6802 m .50229 .6802 L .50213 .68027 L F
.50229 .6802 m .50227 .68032 L .50222 .6803 L F
.189 0 .097 r
.50214 .68009 m .50212 .68041 L .50222 .6803 L F
.774 .498 .518 r
.50229 .6802 m .50222 .6803 L .50213 .68027 L F
.189 0 .097 r
.50229 .6802 m .50222 .6803 L .5023 .68021 L F
.555 .454 .694 r
.50227 .68032 m .50203 .68116 L .50212 .68041 L F
.50227 .68032 m .50212 .68041 L .50222 .6803 L F
.189 0 .097 r
.50212 .68041 m .502 .68245 L .5023 .68021 L F
.555 .454 .694 r
.50222 .6803 m .50212 .68041 L .50213 .68027 L F
.50203 .68116 m .50174 .6822 L .50213 .68027 L F
.189 0 .097 r
.50236 .68001 m .50401 .68144 L .50431 .67925 L F
.50214 .68009 m .50229 .6802 L .50232 .68002 L F
.774 .498 .518 r
.50412 .67943 m .50213 .68027 L .50218 .67976 L F
.189 0 .097 r
.50232 .68002 m .50235 .68005 L .50236 .68001 L F
.50235 .68005 m .50401 .68144 L .50236 .68001 L F
.50229 .6802 m .50401 .68144 L .50232 .68002 L F
.774 .498 .518 r
.50218 .67976 m .50213 .68027 L .5012 .67993 L F
0 0 0 r
.5019 .68257 m .502 .68245 L .50212 .68044 L F
0 0 .137 r
.50223 .67998 m .50454 .67915 L .50452 .67921 L F
.50232 .68002 m .50431 .67925 L .50244 .67972 L F
.587 .413 .612 r
.51006 .6731 m .51011 .67563 L .50766 .67591 L F
.581 .266 .4 r
.50976 .67805 m .50766 .67591 L .51011 .67563 L F
.782 .591 .641 r
.52087 .67489 m .52461 .67287 L .52207 .67294 L F
.5 .611 .894 r
.35611 .6376 m .35768 .64022 L .35978 .63988 L F
0 0 .042 r
.47577 .70877 m .47493 .71025 L .4775 .70749 L F
.799 .561 .577 r
.54966 .67505 m .55026 .67218 L .54938 .67233 L F
.674 .668 .836 r
.33681 .6302 m .34038 .63215 L .33888 .62931 L F
.535 .676 .928 r
.34038 .63215 m .3401 .62904 L .33888 .62931 L F
.34038 .63215 m .3433 .63232 L .3401 .62904 L F
.457 .3 .579 r
.50986 .69017 m .50731 .69077 L .51004 .68981 L F
.50986 .69017 m .50768 .69268 L .50731 .69077 L F
.939 .573 .268 r
.49242 .69059 m .49108 .69003 L .49021 .68676 L F
0 .153 .674 r
.49242 .69059 m .49468 .68989 L .49108 .69003 L F
.316 .172 .521 r
.20497 .58 m .20707 .57931 L .2071 .5767 L F
.268 .034 .363 r
.20497 .58 m .20641 .58173 L .20707 .57931 L F
.20497 .58 m .20472 .58251 L .20641 .58173 L F
.234 0 0 r
.54029 .62072 m .54287 .62088 L .54398 .62059 L F
.608 .045 0 r
.54287 .62088 m .54659 .62255 L .54398 .62059 L F
.434 0 0 r
.37308 .64009 m .37165 .64077 L .36934 .64047 L F
.321 0 0 r
.37501 .64017 m .37165 .64077 L .37308 .64009 L F
.775 .669 .746 r
.58568 .63494 m .58914 .63517 L .58703 .63825 L F
.505 .451 .731 r
.44133 .59465 m .44202 .5983 L .44412 .59676 L F
.527 .376 .62 r
.55075 .59751 m .54876 .60112 L .5486 .59933 L F
.55075 .59751 m .55081 .60037 L .54876 .60112 L F
.514 .896 .959 r
.54771 .6009 m .55081 .60037 L .54876 .60112 L F
.505 .393 .66 r
.72637 .4874 m .72897 .48904 L .72906 .48678 L F
.453 .406 .715 r
.72704 .48943 m .72897 .48904 L .72637 .4874 L F
.948 .76 .615 r
.47379 .70228 m .47461 .7047 L .47612 .70141 L F
.571 .436 .658 r
.47461 .7047 m .4775 .70749 L .47959 .70492 L F
.977 .714 .465 r
.53334 .71068 m .5334 .71341 L .53199 .7125 L F
.53334 .71068 m .5334 .71341 L .53199 .7125 L F
.833 .76 .782 r
.73499 .48676 m .73278 .48961 L .73586 .49025 L F
.784 .551 .583 r
.73253 .49182 m .73586 .49025 L .73278 .48961 L F
.73253 .49182 m .73597 .49247 L .73586 .49025 L F
.769 .723 .811 r
.73499 .48676 m .73586 .49025 L .73849 .48735 L F
.489 .663 .939 r
.4772 .61334 m .47602 .61499 L .47501 .61344 L F
.908 .968 .804 r
.53373 .71804 m .53703 .71573 L .53445 .71635 L F
.53354 .71848 m .53449 .71774 L .53373 .71804 L F
.53449 .71774 m .53703 .71573 L .53373 .71804 L F
0 0 0 r
.53269 .71895 m .53373 .71804 L .53445 .71635 L F
.53229 .71955 m .53354 .71848 L .53373 .71804 L F
.53229 .71955 m .53373 .71804 L .53269 .71895 L F
.998 .781 .438 r
.53354 .71848 m .53245 .72041 L .53255 .71732 L F
.587 .559 .79 r
.53261 .71739 m .5327 .71791 L .53354 .71848 L F
.53255 .71732 m .53261 .71755 L .53261 .71739 L F
.53261 .71755 m .5327 .71791 L .53261 .71739 L F
.908 .968 .804 r
.53354 .71848 m .5327 .71791 L .53703 .71573 L F
.536 .924 .882 r
.5327 .71791 m .53933 .71591 L .53703 .71573 L F
.5327 .71791 m .53482 .71707 L .53449 .71737 L F
.587 .479 .698 r
.53703 .71573 m .53933 .71591 L .53952 .7134 L F
.536 .924 .882 r
.53482 .71707 m .53859 .7156 L .53449 .71737 L F
.587 .559 .79 r
.53606 .71668 m .53675 .71655 L .5327 .71791 L F
.544 .879 .989 r
.5327 .71791 m .53655 .71651 L .53669 .71645 L F
.5327 .71791 m .53606 .71668 L .53616 .71663 L F
.53494 .71703 m .53616 .71663 L .53859 .7156 L F
.5327 .71791 m .53616 .71663 L .53494 .71703 L F
.536 .924 .882 r
.53449 .71737 m .53859 .7156 L .5392 .71586 L F
.319 .777 .949 r
.53655 .71651 m .53675 .71655 L .53627 .7166 L F
.544 .879 .989 r
.53606 .71668 m .53669 .71645 L .53673 .71643 L F
.319 .777 .949 r
.53655 .71651 m .53627 .7166 L .5327 .71696 L F
0 0 .312 r
.53245 .72041 m .53267 .71733 L .53255 .71732 L F
.53267 .71733 m .5327 .71696 L .53255 .71732 L F
.587 .559 .79 r
.53255 .71732 m .53385 .71749 L .5327 .71791 L F
0 0 .312 r
.53264 .71775 m .5328 .71729 L .53274 .71709 L F
.542 .353 .574 r
.5327 .71696 m .53627 .7166 L .53268 .71729 L F
0 0 .312 r
.53267 .71733 m .53268 .71729 L .5327 .71696 L F
.542 .353 .574 r
.5327 .71696 m .53268 .71729 L .53255 .71732 L F
0 0 .312 r
.53268 .71729 m .53274 .71709 L .5327 .71696 L F
.53264 .71775 m .53274 .71709 L .53267 .71733 L F
.587 .559 .79 r
.53267 .71733 m .53606 .71668 L .53385 .71749 L F
.53255 .71732 m .53268 .71729 L .53267 .71733 L F
.53268 .71729 m .53606 .71668 L .53267 .71733 L F
.542 .353 .574 r
.53627 .7166 m .53675 .71655 L .53606 .71668 L F
.53627 .7166 m .53606 .71668 L .53255 .71732 L F
.544 .879 .989 r
.53606 .71668 m .53673 .71643 L .53859 .7156 L F
.5327 .71791 m .53675 .71655 L .53655 .71651 L F
0 0 .312 r
.53261 .71819 m .53344 .71933 L .5328 .71729 L F
.53261 .71819 m .5328 .71729 L .53264 .71775 L F
.53245 .72041 m .5326 .72024 L .53261 .71819 L F
.5326 .72024 m .53344 .71933 L .53261 .71819 L F
.536 .924 .882 r
.53827 .71623 m .5392 .71586 L .53933 .71591 L F
.53449 .71737 m .5392 .71586 L .53827 .71623 L F
.802 .878 .902 r
.49021 .68676 m .4901 .68501 L .49138 .68482 L F
.261 .769 .775 r
.49138 .68482 m .49273 .6843 L .49363 .68387 L F
.49138 .68482 m .4901 .68501 L .49273 .6843 L F
.06 0 0 r
.57087 .59566 m .57422 .5944 L .57104 .59524 L F
.57087 .59566 m .57104 .59524 L .57071 .5975 L F
.277 0 0 r
.57551 .59558 m .57422 .5944 L .57087 .59566 L F
.57551 .59558 m .5768 .59383 L .57422 .5944 L F
.603 .916 .666 r
.50698 .70196 m .50799 .70071 L .5094 .69988 L F
.599 .059 0 r
.50799 .70071 m .51161 .70135 L .5094 .69988 L F
.652 .571 .751 r
.75277 .49858 m .75385 .50206 L .75642 .50148 L F
0 0 .409 r
.55431 .65506 m .5553 .65763 L .55516 .65858 L F
.77 .814 .336 r
.55516 .65858 m .55469 .65922 L .55432 .66023 L F
.192 .041 .434 r
.21072 .62059 m .21044 .62303 L .20921 .62368 L F
.167 .038 .449 r
.21023 .62552 m .20921 .62368 L .21044 .62303 L F
.21023 .62552 m .20905 .62628 L .20921 .62368 L F
.321 .454 .839 r
.58356 .66451 m .58496 .66312 L .58215 .66145 L F
.382 .554 .899 r
.58356 .66451 m .58571 .66473 L .58496 .66312 L F
0 .227 .742 r
.46603 .70945 m .46707 .71005 L .46646 .71126 L F
0 .116 .66 r
.46707 .71005 m .46829 .7134 L .46646 .71126 L F
.171 0 0 r
.54552 .62593 m .54748 .62628 L .54396 .62574 L F
.227 .717 .923 r
.18964 .5534 m .1858 .55297 L .18755 .55355 L F
.197 0 .148 r
.40263 .59031 m .40078 .59141 L .40107 .59054 L F
.619 .396 .557 r
.45593 .62049 m .45852 .62077 L .45885 .61787 L F
.185 0 .162 r
.45885 .61787 m .46056 .6173 L .4615 .61548 L F
.656 .429 .563 r
.45885 .61787 m .46265 .61911 L .46056 .6173 L F
.45885 .61787 m .45852 .62077 L .46265 .61911 L F
.551 .21 .345 r
.42119 .61706 m .42364 .61704 L .42471 .61454 L F
.589 .25 .363 r
.42471 .61454 m .42704 .61632 L .42768 .6143 L F
.42471 .61454 m .42364 .61704 L .42704 .61632 L F
.46 .212 .45 r
.51237 .68449 m .51249 .68664 L .51017 .6869 L F
.492 .176 .358 r
.51505 .6844 m .51249 .68664 L .51237 .68449 L F
.595 .852 .993 r
.50141 .73607 m .50272 .73692 L .50508 .7363 L F
.50141 .73607 m .50272 .73692 L .50508 .7363 L F
.429 .566 .89 r
.33347 .62668 m .33477 .62607 L .33494 .62513 L F
.345 .341 .711 r
.33347 .62668 m .33606 .6285 L .33477 .62607 L F
.433 .33 .638 r
.33347 .62668 m .33393 .6295 L .33606 .6285 L F
.084 0 0 r
.50187 .6608 m .49823 .66177 L .49858 .66161 L F
.856 .992 .835 r
.78512 .48155 m .78241 .48356 L .78487 .48276 L F
0 0 .34 r
.78512 .48155 m .78659 .48011 L .78706 .4773 L F
0 0 0 r
.78512 .48155 m .78487 .48276 L .78659 .48011 L F
.745 .633 .736 r
.73743 .49595 m .74113 .49642 L .73964 .49303 L F
.762 .567 .634 r
.73737 .49833 m .74113 .49642 L .73743 .49595 L F
.73737 .49833 m .74098 .49888 L .74113 .49642 L F
.48 .026 .096 r
.57379 .59822 m .57071 .5975 L .57218 .59843 L F
.131 0 0 r
.44748 .61661 m .45112 .61541 L .44865 .61553 L F
.255 0 0 r
.78176 .48796 m .78396 .48811 L .78567 .4887 L F
.311 .784 .681 r
.40763 .58774 m .40672 .5882 L .40889 .58767 L F
.40763 .58774 m .40555 .58865 L .40672 .5882 L F
0 0 .476 r
.64781 .42813 m .64715 .42929 L .64797 .42919 L F
.394 .148 .418 r
.51252 .67283 m .51011 .67563 L .51006 .6731 L F
.748 .656 .76 r
.58568 .63494 m .58703 .63825 L .58361 .63821 L F
.824 .577 .566 r
.58703 .63825 m .58334 .63973 L .58361 .63821 L F
.58703 .63825 m .58534 .64006 L .58334 .63973 L F
.817 .666 .695 r
.34631 .63461 m .3485 .63717 L .3484 .63589 L F
.353 .312 .673 r
.3485 .63717 m .35001 .63805 L .3484 .63589 L F
.608 .394 .566 r
.49437 .64676 m .49704 .64391 L .49437 .64403 L F
0 .012 .583 r
.8028 .47778 m .80472 .4803 L .80457 .48095 L F
0 .059 .619 r
.80472 .4803 m .8065 .48317 L .80457 .48095 L F
.332 .443 .824 r
.23093 .55294 m .23242 .55627 L .23071 .55575 L F
.67 .582 .748 r
.73374 .49504 m .73527 .49762 L .73743 .49595 L F
.274 .455 .857 r
.19577 .58018 m .19434 .57741 L .19256 .5775 L F
.19577 .58018 m .19599 .58003 L .19434 .57741 L F
.059 .032 .508 r
.19577 .58018 m .19612 .58263 L .19599 .58003 L F
.482 .484 .784 r
.32415 .61151 m .32536 .60912 L .32329 .60963 L F
.32415 .61151 m .32617 .61117 L .32536 .60912 L F
0 0 .501 r
.55794 .66221 m .55767 .66206 L .55432 .66023 L F
.55794 .66221 m .55889 .66365 L .55767 .66206 L F
.403 0 .102 r
.33395 .59028 m .33634 .58934 L .33441 .58973 L F
0 0 0 r
.44189 .6232 m .44043 .62368 L .43852 .62417 L F
.568 .009 0 r
.44389 .62487 m .44043 .62368 L .44189 .6232 L F
.956 .666 .23 r
.55938 .66897 m .56015 .66975 L .55984 .66728 L F
.711 .723 .859 r
.59702 .6662 m .5945 .66365 L .59655 .66674 L F
.538 .17 .29 r
.46081 .62636 m .45939 .62857 L .45754 .62731 L F
.799 .552 .565 r
.4631 .6265 m .45939 .62857 L .46081 .62636 L F
.704 .711 .854 r
.34631 .63461 m .3484 .63589 L .35078 .63544 L F
.64 .388 .52 r
.3484 .63589 m .35001 .63805 L .35078 .63544 L F
.456 0 0 r
.79295 .47504 m .79554 .47516 L .79671 .47471 L F
.561 .061 .024 r
.79554 .47516 m .79875 .47529 L .79671 .47471 L F
.694 .692 .844 r
.76356 .50702 m .76711 .50772 L .76595 .50459 L F
.665 .676 .851 r
.76595 .50459 m .76711 .50772 L .76957 .50688 L F
.921 .97 .777 r
.66059 .4494 m .6619 .44542 L .66291 .44885 L F
.66059 .4494 m .66 .44894 L .6619 .44542 L F
.561 .425 .652 r
.66291 .44885 m .66164 .45079 L .66059 .4494 L F
.556 .335 .535 r
.75601 .49918 m .75872 .49867 L .75846 .49598 L F
.596 .365 .536 r
.75846 .49598 m .76119 .49798 L .76082 .49543 L F
.75846 .49598 m .75872 .49867 L .76119 .49798 L F
.721 .503 .595 r
.54659 .62255 m .54997 .62373 L .54768 .62353 L F
.838 .784 .801 r
.62883 .44242 m .63195 .44416 L .63103 .44038 L F
.924 .583 .374 r
.63059 .44401 m .63195 .44416 L .62951 .4428 L F
.63059 .44401 m .63196 .44586 L .63195 .44416 L F
.852 .792 .792 r
.63103 .44038 m .63195 .44416 L .63403 .44059 L F
.686 .563 .709 r
.63195 .44416 m .63529 .44476 L .63403 .44059 L F
.45 .183 .415 r
.63195 .44416 m .63494 .44389 L .63529 .44476 L F
.63195 .44416 m .63196 .44586 L .63494 .44389 L F
.697 .615 .761 r
.63494 .44389 m .63214 .44575 L .63059 .44401 L F
.63214 .44575 m .63196 .44586 L .63059 .44401 L F
.924 .583 .374 r
.63059 .44401 m .62951 .4428 L .62883 .44242 L F
.336 .435 .815 r
.45773 .68568 m .46015 .68678 L .45871 .68753 L F
.085 0 .381 r
.45976 .68909 m .45871 .68753 L .46015 .68678 L F
.45976 .68909 m .45867 .69011 L .45871 .68753 L F
.71 .755 .887 r
.44497 .59953 m .44878 .59993 L .4474 .59781 L F
.381 .444 .801 r
.44878 .59993 m .44936 .59661 L .4474 .59781 L F
.44878 .59993 m .45076 .59986 L .44936 .59661 L F
.443 0 0 r
.36463 .58383 m .36849 .58293 L .36628 .58324 L F
.165 0 .357 r
.21691 .6061 m .2164 .60845 L .21507 .60914 L F
.433 .25 .531 r
.21676 .61091 m .21507 .60914 L .2164 .60845 L F
.21676 .61091 m .21477 .61164 L .21507 .60914 L F
.653 .427 .564 r
.43703 .61642 m .43918 .6144 L .43675 .61454 L F
0 0 .058 r
.48509 .65571 m .48647 .65468 L .48711 .6526 L F
.452 .67 .956 r
.48509 .65571 m .48757 .65591 L .48647 .65468 L F
.968 .707 .486 r
.4836 .65727 m .48515 .65837 L .48509 .65571 L F
.572 .381 .584 r
.48509 .65571 m .48515 .65837 L .48757 .65591 L F
.48509 .65571 m .48515 .65837 L .48757 .65591 L F
.556 .044 0 r
.54997 .62373 m .55228 .62514 L .55358 .6239 L F
.398 0 0 r
.55358 .6239 m .55433 .62498 L .55567 .62346 L F
.55358 .6239 m .55228 .62514 L .55433 .62498 L F
.963 .94 .652 r
.56134 .68749 m .55974 .68889 L .55989 .69098 L F
.969 .933 .648 r
.56134 .68749 m .5606 .68611 L .55974 .68889 L F
.564 0 0 r
.53644 .68711 m .53866 .68855 L .53958 .68837 L F
.726 .483 .559 r
.53958 .68837 m .53996 .6904 L .53757 .68949 L F
.234 .006 .348 r
.54242 .68449 m .53958 .68837 L .54193 .68651 L F
.416 .855 .753 r
.53958 .68837 m .54165 .68717 L .54193 .68651 L F
.234 .006 .348 r
.54242 .68449 m .53958 .68837 L .54193 .68651 L F
.416 .855 .753 r
.53958 .68837 m .53866 .68855 L .54165 .68717 L F
.057 .596 .853 r
.53403 .63628 m .53704 .63697 L .5344 .63678 L F
.731 .87 .454 r
.53271 .65316 m .5316 .65503 L .53183 .6545 L F
.475 .067 .185 r
.53183 .6545 m .535 .65447 L .53271 .65316 L F
.444 .106 .297 r
.53271 .65316 m .535 .65447 L .53506 .6527 L F
.426 .054 .227 r
.53318 .66062 m .53389 .65879 L .53596 .65999 L F
.431 .049 .211 r
.53389 .65879 m .53637 .65846 L .53596 .65999 L F
.799 .552 .565 r
.4631 .6265 m .463 .62922 L .45939 .62857 L F
.768 .429 .413 r
.4631 .6265 m .46666 .62895 L .463 .62922 L F
.721 .615 .738 r
.46505 .6958 m .46649 .69617 L .46563 .6932 L F
.955 .878 .719 r
.46398 .69821 m .46649 .69617 L .46505 .6958 L F
.46398 .69821 m .46518 .69911 L .46649 .69617 L F
.703 .69 .835 r
.46649 .69617 m .46779 .69246 L .46563 .6932 L F
.46649 .69617 m .46891 .69533 L .46779 .69246 L F
.639 .497 .673 r
.52547 .66142 m .52858 .66154 L .5276 .65842 L F
.617 .327 .454 r
.52778 .66345 m .52858 .66154 L .52547 .66142 L F
.152 0 .127 r
.47199 .62586 m .47387 .62563 L .4712 .62814 L F
.54 .862 .996 r
.50842 .73613 m .50508 .7363 L .50773 .73554 L F
.50773 .73554 m .50508 .7363 L .50842 .73613 L F
.197 .65 .944 r
.50842 .73613 m .50967 .73567 L .50773 .73554 L F
.50773 .73554 m .50967 .73567 L .50842 .73613 L F
.278 0 .213 r
.52807 .6899 m .5306 .68756 L .52819 .68751 L F
.903 .898 .812 r
.59926 .66719 m .60154 .66393 L .60029 .66313 L F
.71 .899 .964 r
.60029 .66313 m .60154 .66393 L .60404 .6626 L F
.822 .57 .557 r
.1999 .57301 m .20398 .57167 L .1995 .57058 L F
.1999 .57301 m .20291 .57367 L .20398 .57167 L F
.498 0 0 r
.48963 .70892 m .48909 .70967 L .49296 .70982 L F
0 0 0 r
.54298 .71393 m .54295 .71392 L .54516 .71316 L F
.54298 .71393 m .54258 .71523 L .54295 .71392 L F
.474 .889 .921 r
.43854 .59276 m .43776 .59381 L .44155 .59392 L F
.816 .918 .906 r
.44025 .5898 m .43854 .59276 L .44155 .59392 L F
.505 .451 .731 r
.44133 .59465 m .44412 .59676 L .44379 .59414 L F
0 0 0 r
.46288 .61427 m .46056 .6173 L .4615 .61548 L F
.484 .173 .363 r
.44537 .59434 m .44825 .59537 L .44801 .59476 L F
.172 0 0 r
.44443 .59419 m .44537 .59434 L .44731 .5944 L F
.816 .892 .897 r
.44731 .5944 m .44786 .59129 L .4494 .59432 L F
.44731 .5944 m .44537 .59434 L .44786 .59129 L F
.608 .867 .523 r
.44786 .59129 m .44537 .59434 L .44699 .59218 L F
.484 .173 .363 r
.44537 .59434 m .44801 .59476 L .44699 .59218 L F
.172 0 0 r
.44379 .59414 m .44537 .59434 L .44443 .59419 L F
.675 .467 .597 r
.48678 .70497 m .48418 .70631 L .48071 .70485 L F
.48678 .70497 m .48665 .70729 L .48418 .70631 L F
.52 .337 .573 r
.48678 .70497 m .48817 .70729 L .48665 .70729 L F
.641 .377 .503 r
.48928 .70495 m .48817 .70729 L .48678 .70497 L F
.542 .072 .088 r
.57801 .60036 m .58208 .60005 L .58061 .60158 L F
.645 .165 .098 r
.58208 .60005 m .58332 .60234 L .58061 .60158 L F
.58208 .60005 m .58552 .60197 L .58332 .60234 L F
.614 .747 .941 r
.79554 .51537 m .79754 .51264 L .79436 .51295 L F
.79554 .51537 m .79835 .5149 L .79754 .51264 L F
.991 .843 .599 r
.59474 .61506 m .59498 .62065 L .59579 .61841 L F
.691 .274 .25 r
.58162 .59353 m .58511 .59384 L .58278 .59181 L F
.255 0 .026 r
.50948 .65813 m .51095 .65932 L .50856 .66021 L F
.50948 .65813 m .51142 .65816 L .51095 .65932 L F
.944 .742 .6 r
.59337 .61391 m .59564 .61187 L .59443 .61097 L F
.59337 .61391 m .59541 .61506 L .59564 .61187 L F
.677 .415 .518 r
.73117 .48634 m .73499 .48676 L .7347 .48435 L F
.795 .501 .491 r
.7347 .48435 m .73499 .48676 L .73849 .48735 L F
.794 .932 .567 r
.33681 .6302 m .33593 .63111 L .33603 .63163 L F
0 0 .476 r
.33593 .63111 m .3382 .6351 L .33603 .63163 L F
.523 .606 .878 r
.42811 .58154 m .42664 .58368 L .42573 .58193 L F
.42811 .58154 m .42895 .58331 L .42664 .58368 L F
.432 .261 .548 r
.26232 .89649 m .26251 .89906 L .26219 .89913 L F
.603 .388 .562 r
.26209 .89909 m .26251 .89906 L .26232 .89649 L F
.309 .399 .793 r
.42433 .58934 m .42548 .59216 L .42673 .59049 L F
.219 .273 .706 r
.42548 .59216 m .4269 .59322 L .42673 .59049 L F
.903 .898 .812 r
.59926 .66719 m .60029 .66313 L .59702 .6662 L F
.56 .363 .571 r
.59685 .67009 m .5993 .66967 L .59926 .66719 L F
.704 .711 .854 r
.34631 .63461 m .35078 .63544 L .3477 .63362 L F
.14 .686 .78 r
.34752 .63365 m .35138 .63337 L .34786 .63326 L F
.34752 .63365 m .3477 .63362 L .35138 .63337 L F
.685 .886 .972 r
.35138 .63337 m .3477 .63362 L .35078 .63544 L F
.405 .16 .426 r
.35078 .63544 m .35207 .63748 L .35138 .63337 L F
.35078 .63544 m .35001 .63805 L .35207 .63748 L F
.483 .606 .899 r
.44134 .58689 m .44003 .58886 L .43865 .58553 L F
.44134 .58689 m .44203 .58854 L .44003 .58886 L F
.91 .83 .756 r
.58574 .61427 m .5854 .6182 L .58462 .61671 L F
.934 .595 .157 r
.58617 .62059 m .58462 .61671 L .5854 .6182 L F
.429 .561 .886 r
.77674 .48633 m .77561 .48797 L .77603 .48669 L F
.658 .604 .783 r
.77674 .48633 m .77392 .48871 L .77561 .48797 L F
.375 .205 .519 r
.23168 .56776 m .23005 .57141 L .23034 .56862 L F
.934 .701 .562 r
.34436 .63412 m .34279 .63467 L .3433 .63232 L F
.526 .56 .833 r
.34436 .63412 m .34531 .63147 L .3433 .63232 L F
.34436 .63412 m .34631 .63461 L .34531 .63147 L F
.799 .561 .577 r
.54966 .67505 m .55166 .67616 L .55026 .67218 L F
.54 .776 .985 r
.57634 .65936 m .57763 .65791 L .57531 .65798 L F
.57634 .65936 m .57867 .65887 L .57763 .65791 L F
.739 .491 .555 r
.54586 .64655 m .54701 .64469 L .54537 .64392 L F
.552 .356 .569 r
.65597 .4443 m .65345 .44629 L .65183 .44499 L F
.41 0 .055 r
.65731 .44278 m .65637 .44435 L .65703 .44231 L F
.65837 .44458 m .65656 .44437 L .65731 .44278 L F
.65656 .44437 m .65637 .44435 L .65731 .44278 L F
.552 .356 .569 r
.65656 .44437 m .65592 .44574 L .65345 .44629 L F
.41 0 .055 r
.65837 .44458 m .65592 .44574 L .65637 .44435 L F
.552 .356 .569 r
.65694 .44414 m .65592 .44574 L .65656 .44437 L F
.707 .551 .674 r
.65703 .44231 m .65637 .44435 L .65694 .44414 L F
.552 .356 .569 r
.65694 .44414 m .65656 .44437 L .65637 .44435 L F
.707 .551 .674 r
.65637 .44435 m .65592 .44574 L .65694 .44414 L F
.552 .356 .569 r
.65694 .44414 m .65637 .44435 L .65597 .4443 L F
.65656 .44437 m .65345 .44629 L .65597 .4443 L F
.41 0 .055 r
.65925 .44417 m .65837 .44458 L .65703 .44231 L F
.65925 .44417 m .65846 .44536 L .65592 .44574 L F
.559 .108 .136 r
.65925 .44417 m .6619 .44542 L .65846 .44536 L F
.518 .25 .449 r
.66146 .44356 m .6619 .44542 L .65925 .44417 L F
.802 .878 .902 r
.49021 .68676 m .48771 .68678 L .4901 .68501 L F
.676 .42 .527 r
.49021 .68676 m .48901 .68924 L .48771 .68678 L F
.49021 .68676 m .49108 .69003 L .48901 .68924 L F
.586 .893 .989 r
.79251 .48536 m .79569 .48471 L .79451 .48418 L F
.6 .952 .86 r
.79569 .48471 m .798 .48335 L .79707 .48337 L F
.578 .889 .989 r
.79451 .48418 m .79569 .48471 L .79707 .48337 L F
.689 .497 .623 r
.49939 .64087 m .50262 .64081 L .50257 .63831 L F
.609 .434 .62 r
.50257 .63831 m .50262 .64081 L .50486 .63794 L F
.474 .889 .921 r
.43854 .59276 m .43471 .59358 L .43776 .59381 L F
0 0 0 r
.47788 .68951 m .47906 .68808 L .47875 .68641 L F
.267 .371 .785 r
.47906 .68808 m .48054 .68563 L .47875 .68641 L F
.7 .303 .293 r
.48299 .6897 m .48177 .69026 L .47906 .68808 L F
.267 .371 .785 r
.47906 .68808 m .48177 .69026 L .48054 .68563 L F
.816 .799 .836 r
.47004 .67376 m .47134 .67542 L .473 .67302 L F
.159 .399 .845 r
.47134 .67542 m .4732 .67605 L .47198 .67454 L F
.586 .893 .989 r
.79251 .48536 m .79451 .48418 L .79186 .48453 L F
.786 .501 .506 r
.60128 .64007 m .60436 .63828 L .60144 .63797 L F
.60128 .64007 m .60472 .64056 L .60436 .63828 L F
.91 .946 .814 r
.55989 .69098 m .55763 .69198 L .55788 .6921 L F
.587 .489 .711 r
.19707 .57102 m .19941 .56691 L .19682 .56753 L F
.754 .388 .362 r
.50187 .6608 m .50427 .66171 L .50057 .66133 L F
.633 .135 .05 r
.50427 .66171 m .5027 .66286 L .50057 .66133 L F
.506 .176 .342 r
.50732 .66106 m .50659 .6618 L .50427 .66171 L F
.76 .959 .654 r
.50496 .66017 m .50427 .66171 L .50659 .6618 L F
.50496 .66017 m .5027 .66286 L .50427 .66171 L F
.964 .67 .424 r
.48482 .69574 m .4849 .69841 L .48636 .69908 L F
.934 .66 .496 r
.48457 .70049 m .48636 .69908 L .4849 .69841 L F
.48457 .70049 m .48634 .70124 L .48636 .69908 L F
.484 .273 .516 r
.51259 .68885 m .51017 .6869 L .51249 .68664 L F
.51259 .68885 m .51004 .68981 L .51017 .6869 L F
.804 .639 .678 r
.46414 .62008 m .46785 .62061 L .46775 .61801 L F
.649 .517 .689 r
.46775 .61801 m .46785 .62061 L .47074 .61744 L F
.864 .851 .828 r
.62141 .44952 m .61909 .45251 L .61773 .45135 L F
.56 .094 .106 r
.57701 .63625 m .5798 .63498 L .578 .63651 L F
.532 .526 .794 r
.58059 .63797 m .578 .63651 L .5798 .63498 L F
.718 .512 .61 r
.47409 .73103 m .4736 .73345 L .47828 .73322 L F
.575 .296 .455 r
.64525 .46058 m .6447 .4632 L .64182 .46359 L F
.543 .267 .446 r
.64754 .46233 m .64525 .46058 L .64767 .46089 L F
.64754 .46233 m .6447 .4632 L .64525 .46058 L F
.976 .676 .37 r
.81007 .50284 m .81105 .50173 L .81065 .50074 L F
.81007 .50284 m .81132 .5042 L .81105 .50173 L F
.761 .563 .629 r
.54771 .6009 m .55075 .59751 L .5486 .59933 L F
.54771 .6009 m .55081 .60037 L .55075 .59751 L F
.604 .429 .618 r
.55081 .60037 m .55433 .59676 L .55075 .59751 L F
.496 .746 .984 r
.42433 .58061 m .42344 .58219 L .4224 .58111 L F
.42433 .58061 m .42573 .58193 L .42344 .58219 L F
.179 .714 .756 r
.37672 .5822 m .38048 .58161 L .37809 .5819 L F
.748 .697 .802 r
.73253 .49182 m .73374 .49504 L .73597 .49247 L F
.67 .582 .748 r
.73374 .49504 m .73743 .49595 L .73597 .49247 L F
.513 .699 .954 r
.47636 .67435 m .473 .67302 L .47571 .67503 L F
.483 0 0 r
.47571 .67503 m .47915 .67519 L .47636 .67435 L F
.917 .806 .722 r
.5939 .6198 m .59476 .6234 L .59498 .62065 L F
.991 .843 .599 r
.59474 .61506 m .5939 .6198 L .59498 .62065 L F
.442 .692 .972 r
.36988 .62306 m .36916 .62475 L .36763 .62347 L F
.36988 .62306 m .37148 .62461 L .36916 .62475 L F
.251 .696 .958 r
.37273 .62537 m .36916 .62475 L .37148 .62461 L F
.183 0 0 r
.38121 .63783 m .3797 .63897 L .37717 .63935 L F
.389 0 0 r
.3835 .63751 m .3797 .63897 L .38121 .63783 L F
.592 .044 0 r
.45754 .62731 m .45575 .62788 L .45338 .62635 L F
.583 .032 0 r
.45754 .62731 m .45939 .62857 L .45575 .62788 L F
.882 .805 .768 r
.63243 .43925 m .63403 .44059 L .63313 .43715 L F
.852 .792 .792 r
.63103 .44038 m .63403 .44059 L .63243 .43925 L F
.734 .726 .843 r
.63313 .43715 m .63403 .44059 L .63682 .43823 L F
.539 .86 .572 r
.48711 .6526 m .48827 .65138 L .48977 .65011 L F
.643 .722 .906 r
.79708 .5095 m .8006 .51026 L .79809 .51113 L F
.462 .746 .99 r
.37377 .62434 m .37273 .62537 L .37148 .62461 L F
.37377 .62434 m .37509 .62532 L .37273 .62537 L F
.725 .828 .374 r
.58519 .60472 m .58606 .6032 L .58617 .60575 L F
.706 .866 .958 r
.35738 .64327 m .36086 .64309 L .35971 .64275 L F
.35738 .64327 m .36086 .64309 L .35971 .64275 L F
.587 .903 .643 r
.18814 .55944 m .18917 .55828 L .1911 .55686 L F
.347 .438 .812 r
.1911 .55686 m .19249 .55575 L .18964 .5534 L F
.072 0 0 r
.1911 .55686 m .19244 .55695 L .19249 .55575 L F
.1911 .55686 m .18917 .55828 L .19244 .55695 L F
.708 .371 .405 r
.51054 .70498 m .50728 .70526 L .50726 .70451 L F
.51054 .70498 m .50995 .70704 L .50728 .70526 L F
.466 .137 .324 r
.51054 .70498 m .51254 .70663 L .50995 .70704 L F
.981 .756 .526 r
.47895 .73977 m .47757 .73933 L .47774 .73631 L F
.79 .297 .02 r
.47774 .73631 m .47904 .73736 L .47895 .73977 L F
.497 .21 .407 r
.47903 .73767 m .47757 .73933 L .47895 .73977 L F
.47889 .73756 m .47757 .73933 L .47903 .73767 L F
.47904 .73736 m .47889 .73756 L .47903 .73767 L F
.47904 .73736 m .48003 .73906 L .47757 .73933 L F
.663 .157 0 r
.47856 .73776 m .47774 .73631 L .47757 .73933 L F
.883 .9 .836 r
.47746 .73685 m .47856 .73776 L .47721 .737 L F
.663 .157 0 r
.47856 .73776 m .4798 .73878 L .47855 .73729 L F
.47807 .7369 m .47855 .73729 L .47774 .73631 L F
.47856 .73776 m .47855 .73729 L .47807 .7369 L F
.79 .297 .02 r
.47774 .73631 m .48003 .73906 L .47904 .73736 L F
.883 .9 .836 r
.4809 .73482 m .47856 .73776 L .47746 .73685 L F
.663 .157 0 r
.47856 .73776 m .48003 .73906 L .4798 .73878 L F
.061 .62 .8 r
.54044 .71294 m .5418 .713 L .54308 .71154 L F
.073 .627 .815 r
.54097 .71271 m .54308 .71295 L .54044 .71294 L F
.061 .62 .8 r
.5418 .713 m .54516 .71316 L .54308 .71154 L F
.5418 .713 m .54308 .71295 L .54516 .71316 L F
.54044 .71294 m .54161 .71295 L .5418 .713 L F
.54161 .71295 m .54308 .71295 L .5418 .713 L F
.832 .991 .733 r
.53933 .71591 m .54097 .71271 L .53952 .7134 L F
.443 .862 .719 r
.53859 .7156 m .53655 .71651 L .53735 .71607 L F
.832 .991 .733 r
.53971 .71516 m .53943 .71432 L .54094 .71274 L F
.53943 .71527 m .53943 .71432 L .53971 .71516 L F
.53944 .7157 m .54094 .71274 L .54095 .71275 L F
.53934 .71582 m .53943 .71432 L .53944 .7157 L F
.827 .994 .75 r
.53933 .71591 m .53859 .7156 L .53943 .71432 L F
.443 .862 .719 r
.53859 .7156 m .54029 .71444 L .53943 .71432 L F
.53863 .71557 m .53735 .71607 L .54029 .71444 L F
.53859 .7156 m .53735 .71607 L .53863 .71557 L F
.832 .991 .733 r
.53944 .7157 m .53943 .71527 L .53971 .71516 L F
.54095 .71275 m .54094 .71274 L .54097 .71271 L F
.53933 .71591 m .53934 .71582 L .53944 .7157 L F
.061 .62 .8 r
.54308 .71154 m .54516 .71316 L .54486 .7106 L F
.51 .182 .348 r
.49157 .70016 m .49091 .70146 L .49526 .70071 L F
.628 .664 .866 r
.77348 .50963 m .77465 .50586 L .77226 .50628 L F
.77348 .50963 m .77675 .5092 L .77465 .50586 L F
.43 .201 .463 r
.32633 .59434 m .32832 .5938 L .32883 .59159 L F
.503 .368 .63 r
.32644 .59723 m .32832 .5938 L .32633 .59434 L F
.427 .209 .478 r
.50273 .65559 m .50058 .65853 L .50265 .65786 L F
.855 .837 .827 r
.50168 .65382 m .50273 .65559 L .50513 .65243 L F
.436 .216 .48 r
.50273 .65559 m .50265 .65786 L .50474 .65748 L F
.824 .852 .869 r
.77788 .4918 m .77537 .49247 L .77763 .48961 L F
.51 .001 0 r
.41477 .61649 m .41769 .61666 L .41519 .61567 L F
.332 0 0 r
.41519 .61567 m .41769 .61666 L .41868 .61688 L F
.476 .397 .688 r
.32329 .60963 m .32486 .60546 L .32316 .60595 L F
.441 .824 .989 r
.49823 .66177 m .49798 .66096 L .49676 .66294 L F
.084 0 0 r
.50187 .6608 m .50057 .66133 L .49823 .66177 L F
.441 .824 .989 r
.49823 .66177 m .50057 .66133 L .49798 .66096 L F
.583 .403 .603 r
.59452 .67321 m .59696 .67261 L .59685 .67009 L F
.59685 .67009 m .59696 .67261 L .59452 .67321 L F
.568 .391 .601 r
.59696 .67261 m .5993 .66967 L .59685 .67009 L F
.59696 .67261 m .5993 .66967 L .59685 .67009 L F
.413 .362 .692 r
.5276 .65842 m .53013 .66048 L .52928 .65881 L F
.5276 .65842 m .52858 .66154 L .53013 .66048 L F
.498 .224 .429 r
.51794 .6819 m .51751 .68414 L .51505 .6844 L F
.358 .102 .384 r
.51996 .68128 m .51751 .68414 L .51794 .6819 L F
0 .244 .752 r
.45258 .61649 m .45233 .61783 L .45112 .61541 L F
.825 .939 .574 r
.45258 .61649 m .4509 .61939 L .45233 .61783 L F
.818 .425 .306 r
.4509 .61939 m .4528 .62 L .45233 .61783 L F
.813 .421 .31 r
.45233 .61783 m .4528 .62 L .45593 .62049 L F
.479 .375 .658 r
.19256 .5775 m .19438 .57426 L .1921 .57695 L F
.19256 .5775 m .19434 .57741 L .19438 .57426 L F
.677 .752 .908 r
.78964 .48557 m .79088 .48277 L .78867 .48406 L F
.78964 .48557 m .79186 .48453 L .79088 .48277 L F
.602 .818 .983 r
.43402 .58358 m .43327 .58549 L .43105 .58301 L F
.43402 .58358 m .43598 .58469 L .43327 .58549 L F
.739 .491 .555 r
.54586 .64655 m .5489 .64675 L .54701 .64469 L F
.867 .622 .567 r
.50187 .6608 m .50057 .66133 L .50058 .65853 L F
.661 .762 .925 r
.6367 .44229 m .63529 .44476 L .63494 .44389 L F
.6367 .44229 m .6379 .44405 L .63529 .44476 L F
.292 .752 .951 r
.36849 .58293 m .37061 .58276 L .3722 .5833 L F
.282 .757 .934 r
.37061 .58276 m .37457 .583 L .3722 .5833 L F
.967 .826 .651 r
.62465 .43779 m .62303 .43875 L .62367 .43672 L F
.62465 .43779 m .62428 .43992 L .62303 .43875 L F
.879 .92 .849 r
.62465 .43779 m .62608 .43386 L .62722 .43503 L F
.62465 .43779 m .62367 .43672 L .62608 .43386 L F
.87 .846 .818 r
.63173 .42912 m .62801 .4307 L .62884 .42841 L F
.63072 .42955 m .62936 .43191 L .62801 .4307 L F
.63173 .42912 m .63114 .42982 L .63072 .42955 L F
.63114 .42982 m .62936 .43191 L .63072 .42955 L F
.882 .696 .646 r
.63107 .42973 m .63173 .42912 L .62884 .42841 L F
.567 .833 .995 r
.63314 .43178 m .62936 .43191 L .63173 .42912 L F
.531 .553 .823 r
.63313 .42522 m .63173 .42912 L .63107 .42973 L F
.86 .951 .872 r
.63457 .42945 m .63314 .43178 L .63173 .42912 L F
.899 .954 .826 r
.63313 .42522 m .63107 .42973 L .62848 .42771 L F
.851 .7 .695 r
.63087 .43321 m .63265 .43411 L .63229 .43159 L F
.908 .646 .529 r
.63093 .43573 m .63265 .43411 L .63087 .43321 L F
.042 0 .003 r
.63229 .43159 m .63137 .43368 L .63087 .43321 L F
.745 .628 .729 r
.62936 .42911 m .63137 .43368 L .63275 .43017 L F
.63113 .42931 m .63275 .43017 L .63301 .42951 L F
.62936 .42911 m .63275 .43017 L .63113 .42931 L F
0 .372 .772 r
.629 .42816 m .63107 .42973 L .63028 .42926 L F
.62848 .42771 m .62918 .42826 L .629 .42816 L F
.62918 .42826 m .63107 .42973 L .629 .42816 L F
.62877 .42829 m .63028 .42926 L .62884 .42841 L F
.382 0 0 r
.63457 .42945 m .63491 .42911 L .63173 .42912 L F
.86 .951 .872 r
.63457 .42945 m .63173 .42912 L .63491 .42911 L F
.531 .553 .823 r
.63313 .42522 m .63445 .4291 L .63173 .42912 L F
.63445 .4291 m .63457 .42945 L .63355 .42933 L F
.63445 .4291 m .63355 .42933 L .63173 .42912 L F
0 0 0 r
.63707 .42744 m .63491 .42911 L .63457 .42945 L F
.63457 .42945 m .63491 .42911 L .63707 .42744 L F
.63707 .42744 m .63457 .42945 L .63476 .42644 L F
.63457 .42945 m .63707 .42744 L .63654 .42855 L F
.926 .756 .652 r
.63476 .42644 m .63457 .42945 L .63313 .42522 L F
0 0 0 r
.63654 .42855 m .63301 .42951 L .63457 .42945 L F
.63634 .42861 m .63542 .42889 L .63301 .42951 L F
.63654 .42855 m .63647 .42857 L .63634 .42861 L F
.63647 .42857 m .63542 .42889 L .63634 .42861 L F
.709 .715 .854 r
.62987 .4286 m .63301 .42951 L .63201 .42641 L F
.62936 .42911 m .63113 .42931 L .62987 .4286 L F
.63113 .42931 m .63301 .42951 L .62987 .4286 L F
0 .372 .772 r
.62855 .42786 m .63028 .42926 L .62877 .42829 L F
.62848 .42771 m .62882 .42801 L .62855 .42786 L F
.62882 .42801 m .63028 .42926 L .62855 .42786 L F
0 0 .162 r
.49981 .69032 m .50002 .69036 L .50055 .68753 L F
.141 0 .376 r
.50055 .68753 m .50228 .68844 L .50226 .68614 L F
.50055 .68753 m .50002 .69036 L .50228 .68844 L F
.372 .096 .359 r
.52203 .68055 m .52061 .67921 L .52226 .67856 L F
.52203 .68055 m .51996 .68128 L .52061 .67921 L F
.394 .099 .34 r
.65563 .45514 m .65525 .45729 L .65324 .45736 L F
.465 .158 .36 r
.65792 .4559 m .65563 .45514 L .65827 .45444 L F
.65792 .4559 m .65525 .45729 L .65563 .45514 L F
.742 .46 .502 r
.50461 .70752 m .50119 .7075 L .50141 .70504 L F
.448 0 0 r
.5423 .67257 m .53843 .67292 L .54007 .67319 L F
.671 .368 .452 r
.62973 .464 m .63334 .46398 L .63337 .46581 L F
.603 .314 .451 r
.63334 .46398 m .63587 .46581 L .63337 .46581 L F
.621 .704 .904 r
.53292 .63559 m .53005 .63468 L .53092 .63478 L F
.702 .52 .639 r
.6308 .46515 m .62747 .46392 L .62973 .464 L F
.671 .368 .452 r
.62973 .464 m .63337 .46581 L .6308 .46515 L F
.476 .397 .688 r
.32329 .60963 m .32536 .60912 L .32486 .60546 L F
0 .563 .786 r
.18319 .54211 m .18676 .54267 L .18494 .54277 L F
.474 .2 .418 r
.508 .68166 m .51033 .68117 L .51081 .67821 L F
.097 0 .289 r
.51081 .67821 m .51033 .68117 L .51242 .67781 L F
.251 .186 .585 r
.54522 .66275 m .54567 .66132 L .54579 .66076 L F
.969 .707 .479 r
.64797 .42919 m .65055 .43145 L .64966 .43196 L F
.276 0 0 r
.65055 .43145 m .65225 .43224 L .64966 .43196 L F
.65055 .43145 m .65289 .43124 L .65225 .43224 L F
.745 .656 .762 r
.73737 .49833 m .73858 .50185 L .74098 .49888 L F
.228 0 0 r
.38322 .62567 m .38549 .62541 L .38716 .62418 L F
.184 0 0 r
.38549 .62541 m .38914 .62446 L .38716 .62418 L F
.583 .479 .702 r
.54519 .65598 m .54805 .65632 L .54675 .65439 L F
.54519 .65598 m .54563 .65834 L .54805 .65632 L F
.771 .583 .644 r
.5038 .69912 m .50326 .70172 L .50698 .70196 L F
.823 .426 .298 r
.50326 .70172 m .50726 .70451 L .50698 .70196 L F
.5 .532 .821 r
.50726 .70451 m .50799 .70071 L .50698 .70196 L F
.214 0 0 r
.21203 .54594 m .214 .54615 L .21593 .54595 L F
0 .564 .726 r
.21253 .54537 m .21452 .54545 L .21626 .54556 L F
.077 0 0 r
.21626 .54556 m .21452 .54545 L .21555 .54553 L F
.284 .786 .815 r
.21593 .54595 m .21626 .54556 L .21729 .54561 L F
.21729 .54561 m .21626 .54556 L .21768 .54552 L F
.036 .592 .817 r
.21626 .54556 m .22025 .54618 L .21768 .54552 L F
.21626 .54556 m .21832 .54574 L .22025 .54618 L F
.077 0 0 r
.21626 .54556 m .21555 .54553 L .21832 .54574 L F
.284 .786 .815 r
.21593 .54595 m .214 .54615 L .21626 .54556 L F
.652 .571 .751 r
.75277 .49858 m .75642 .50148 L .75601 .49918 L F
.719 .486 .572 r
.49709 .67552 m .50064 .67288 L .49778 .67327 L F
.332 .295 .666 r
.50064 .67288 m .50279 .67471 L .50305 .67273 L F
.854 .611 .571 r
.49798 .66096 m .50058 .65853 L .49726 .65768 L F
.49798 .66096 m .50057 .66133 L .50058 .65853 L F
.463 .291 .562 r
.50058 .65853 m .50332 .66068 L .50265 .65786 L F
.50058 .65853 m .50057 .66133 L .50332 .66068 L F
.506 .881 .974 r
.40189 .58069 m .39796 .58093 L .40023 .58039 L F
0 0 0 r
.40023 .58039 m .40406 .58015 L .40189 .58069 L F
.969 .911 .7 r
.5982 .62851 m .5976 .63229 L .59999 .62938 L F
.5982 .62851 m .59666 .63145 L .5976 .63229 L F
.859 .659 .63 r
.59666 .63145 m .59935 .63447 L .5976 .63229 L F
.443 .317 .613 r
.32436 .60307 m .3263 .59937 L .32413 .60045 L F
.864 .851 .828 r
.62141 .44952 m .61773 .45135 L .6197 .44817 L F
.092 0 0 r
.53782 .71867 m .53662 .72058 L .53449 .72154 L F
.489 .39 .669 r
.53933 .71591 m .53962 .71825 L .53782 .71867 L F
.39 0 .159 r
.53962 .71825 m .53662 .72058 L .53782 .71867 L F
.86 .951 .872 r
.63457 .42945 m .63229 .43159 L .63314 .43178 L F
.648 .56 .742 r
.63229 .43159 m .63551 .43372 L .63314 .43178 L F
.906 .625 .499 r
.56739 .64592 m .56519 .64309 L .5664 .64414 L F
.457 .622 .922 r
.58571 .66473 m .58729 .6666 L .58768 .66316 L F
.573 .81 .989 r
.4836 .65727 m .48252 .65879 L .48515 .65837 L F
.534 .357 .588 r
.53755 .67582 m .54031 .67809 L .53759 .6784 L F
.53755 .67582 m .54031 .67809 L .53759 .6784 L F
.855 .72 .196 r
.46747 .62411 m .46785 .62061 L .46414 .62008 L F
.46747 .62411 m .46765 .62331 L .46785 .62061 L F
.674 .296 .323 r
.47068 .62309 m .46785 .62061 L .46765 .62331 L F
.689 .573 .72 r
.54115 .67869 m .54237 .68216 L .54475 .68155 L F
.683 .549 .696 r
.54237 .68216 m .54242 .68449 L .54475 .68155 L F
.616 .883 .558 r
.20106 .57462 m .19932 .57635 L .19884 .57711 L F
0 0 0 r
.20135 .57495 m .20106 .57462 L .20291 .57367 L F
.20135 .57495 m .19932 .57635 L .20106 .57462 L F
.183 .255 .704 r
.24613 .78076 m .24778 .78206 L .2478 .7815 L F
.657 .557 .731 r
.75642 .50148 m .75753 .50514 L .76001 .50437 L F
.423 .516 .849 r
.78779 .49688 m .78848 .49928 L .78573 .49851 L F
.895 .833 .778 r
.66534 .44342 m .6619 .44542 L .66146 .44356 L F
.66534 .44342 m .66322 .4465 L .6619 .44542 L F
0 0 .277 r
.66563 .43952 m .66588 .44229 L .66539 .44276 L F
.967 .69 .268 r
.66508 .4413 m .66588 .44229 L .66563 .43952 L F
0 .188 .705 r
.66656 .44163 m .66588 .44229 L .66508 .4413 L F
.66835 .44204 m .66588 .44229 L .66656 .44163 L F
0 0 .277 r
.66539 .44276 m .66588 .44229 L .66534 .44342 L F
0 .214 .732 r
.66588 .44229 m .66741 .4454 L .66534 .44342 L F
.991 .734 .383 r
.5872 .60922 m .58614 .60834 L .58617 .60575 L F
.985 .879 .642 r
.5854 .61066 m .5872 .60922 L .58665 .61159 L F
.5854 .61066 m .58614 .60834 L .5872 .60922 L F
.465 .096 .253 r
.48418 .70631 m .48268 .70809 L .48114 .70754 L F
.612 .211 .259 r
.48665 .70729 m .48268 .70809 L .48418 .70631 L F
.525 .479 .748 r
.46451 .68675 m .46602 .68437 L .46337 .68473 L F
.402 .666 .967 r
.41872 .58854 m .41956 .58708 L .41736 .58706 L F
.355 .606 .944 r
.41872 .58854 m .4209 .58887 L .41956 .58708 L F
.569 .242 .375 r
.55355 .59963 m .55312 .60198 L .55081 .60037 L F
.604 .429 .618 r
.55081 .60037 m .55189 .60032 L .55433 .59676 L F
0 0 0 r
.5569 .59823 m .55614 .59877 L .55355 .59963 L F
.55614 .59877 m .55427 .59945 L .55355 .59963 L F
.352 .225 .564 r
.55412 .59963 m .55533 .59665 L .55433 .59676 L F
.55407 .60022 m .5543 .59959 L .55412 .59963 L F
.5543 .59959 m .55533 .59665 L .55412 .59963 L F
.027 0 .081 r
.55312 .60198 m .55566 .59911 L .55407 .60022 L F
.232 0 .277 r
.5534 .60046 m .55517 .5994 L .55312 .60198 L F
.55517 .5994 m .55566 .59911 L .55546 .59934 L F
.55517 .5994 m .55546 .59934 L .55312 .60198 L F
.55355 .59963 m .55427 .59945 L .5534 .60046 L F
.604 .429 .618 r
.55359 .60024 m .55407 .60022 L .55412 .59963 L F
.232 0 .277 r
.55427 .59945 m .55566 .59911 L .55409 .59967 L F
0 0 0 r
.55614 .59877 m .55566 .59911 L .55427 .59945 L F
.352 .225 .564 r
.5543 .59959 m .55566 .59911 L .55533 .59665 L F
.55407 .60022 m .55566 .59911 L .5543 .59959 L F
.232 0 .277 r
.55409 .59967 m .55566 .59911 L .5534 .60046 L F
.604 .429 .618 r
.55189 .60032 m .55359 .60024 L .55413 .59951 L F
.55359 .60024 m .55412 .59963 L .55413 .59951 L F
.55189 .60032 m .55413 .59951 L .55433 .59676 L F
.635 .771 .945 r
.55533 .59665 m .55967 .59723 L .5569 .59823 L F
.724 .365 .369 r
.55901 .59827 m .55533 .59665 L .5569 .59823 L F
.665 .217 0 r
.56359 .64062 m .56339 .64073 L .56262 .63939 L F
.967 .644 .289 r
.56519 .64309 m .56342 .64077 L .56359 .64062 L F
.933 .712 .579 r
.56666 .64401 m .56548 .64074 L .56436 .64216 L F
.967 .644 .289 r
.56519 .64309 m .56411 .64249 L .56339 .64073 L F
.933 .712 .579 r
.5649 .64296 m .56436 .64216 L .56411 .64249 L F
.56666 .64401 m .56436 .64216 L .5649 .64296 L F
.967 .644 .289 r
.56342 .64077 m .56339 .64073 L .5634 .64073 L F
.56342 .64077 m .5634 .64073 L .56359 .64062 L F
.82 .971 .896 r
.77603 .48669 m .77325 .48971 L .77036 .48702 L F
.435 .156 .389 r
.49465 .67797 m .49474 .6756 L .49634 .67856 L F
.599 .392 .572 r
.49752 .67956 m .49634 .67856 L .49835 .67922 L F
0 0 0 r
.49752 .67956 m .49462 .68046 L .49835 .67922 L F
.599 .392 .572 r
.49752 .67956 m .49465 .67797 L .49634 .67856 L F
.586 .429 .635 r
.32832 .5938 m .33067 .59081 L .32883 .59159 L F
.22 0 .102 r
.52754 .72792 m .52463 .73006 L .52472 .72769 L F
.635 .871 .512 r
.50549 .68181 m .50644 .68032 L .508 .68166 L F
.50549 .68181 m .50418 .68326 L .50644 .68032 L F
.561 .425 .652 r
.66291 .44885 m .66394 .45176 L .66164 .45079 L F
.387 .035 .24 r
.66394 .45176 m .66066 .45415 L .66164 .45079 L F
.407 .412 .752 r
.45943 .68368 m .45773 .68568 L .45672 .68362 L F
.45943 .68368 m .46015 .68678 L .45773 .68568 L F
.405 .591 .919 r
.46731 .67319 m .4683 .67163 L .4661 .67251 L F
.46731 .67319 m .47004 .67376 L .4683 .67163 L F
0 .176 .693 r
.56023 .63763 m .56029 .63709 L .55811 .63537 L F
0 .237 .732 r
.56023 .63763 m .56262 .63939 L .56029 .63709 L F
.719 .873 .466 r
.65836 .43831 m .65709 .44111 L .65702 .44075 L F
.569 .632 .874 r
.45692 .59783 m .45317 .5951 L .45519 .59414 L F
.422 .844 .687 r
.45554 .59844 m .45473 .59906 L .45692 .59783 L F
.65 .22 .212 r
.45938 .59758 m .45554 .59844 L .45692 .59783 L F
.45938 .59758 m .45954 .59908 L .45554 .59844 L F
.681 .306 .33 r
.45554 .59844 m .45954 .59908 L .45731 .60016 L F
0 .215 .736 r
.45554 .59844 m .45731 .60016 L .45629 .59786 L F
.45554 .59844 m .45629 .59786 L .45615 .59754 L F
.422 .844 .687 r
.45554 .59844 m .45417 .59938 L .45473 .59906 L F
0 0 0 r
.45519 .59414 m .45734 .59258 L .45735 .59386 L F
.45519 .59414 m .45529 .59428 L .45734 .59258 L F
.886 .962 .84 r
.45529 .59428 m .45546 .59034 L .45732 .59256 L F
.45727 .59264 m .45732 .59256 L .45734 .59258 L F
.45529 .59428 m .45732 .59256 L .45727 .59264 L F
.566 .617 .863 r
.45735 .59386 m .45692 .59783 L .45562 .59506 L F
.45635 .59399 m .45562 .59506 L .45519 .59414 L F
.45735 .59386 m .45562 .59506 L .45635 .59399 L F
.45735 .59386 m .45938 .59758 L .45692 .59783 L F
.611 .33 .466 r
.53237 .63965 m .52918 .63824 L .53225 .63811 L F
.765 .367 .299 r
.53225 .63811 m .53447 .6406 L .53237 .63965 L F
.612 .64 .854 r
.46779 .69246 m .46891 .69533 L .47106 .69376 L F
.258 0 0 r
.52277 .6959 m .52288 .696 L .52355 .69607 L F
.52288 .696 m .52298 .69605 L .52355 .69607 L F
0 0 0 r
.52355 .69607 m .5245 .69462 L .52534 .69274 L F
.657 .962 .771 r
.52355 .69607 m .52298 .69605 L .5245 .69462 L F
0 0 0 r
.52288 .696 m .52301 .69603 L .5245 .69462 L F
.657 .962 .771 r
.52298 .69605 m .52293 .69605 L .5245 .69462 L F
.68 .466 .589 r
.5272 .69579 m .5236 .6986 L .52355 .69607 L F
0 0 0 r
.52301 .69603 m .52415 .69621 L .5245 .69462 L F
.52243 .69639 m .52346 .69628 L .52288 .696 L F
.52346 .69628 m .52415 .69621 L .52288 .696 L F
.258 0 0 r
.52288 .696 m .52293 .69605 L .52298 .69605 L F
0 0 0 r
.52243 .69639 m .52288 .696 L .52293 .69605 L F
.52288 .696 m .5245 .69462 L .52293 .69605 L F
.258 0 0 r
.52054 .6954 m .52293 .69605 L .52277 .6959 L F
.542 .576 .838 r
.51571 .64897 m .51779 .65321 L .51983 .65197 L F
.575 .71 .934 r
.46451 .68675 m .46757 .68786 L .46604 .68621 L F
.637 .733 .917 r
.46604 .68621 m .46757 .68786 L .46984 .68701 L F
.496 .286 .524 r
.46984 .68701 m .46757 .68786 L .46802 .68974 L F
.793 .672 .73 r
.46984 .68701 m .46802 .68974 L .46757 .68786 L F
0 0 0 r
.2034 .58583 m .204 .58456 L .20472 .58251 L F
.672 .973 .904 r
.2034 .58583 m .20155 .58613 L .204 .58456 L F
.53 .436 .693 r
.73045 .49234 m .73278 .48961 L .72897 .48904 L F
.73045 .49234 m .73253 .49182 L .73278 .48961 L F
0 0 .029 r
.51525 .69895 m .51621 .69748 L .51763 .69591 L F
.683 .531 .673 r
.51763 .69591 m .51661 .69913 L .51525 .69895 L F
.598 .442 .641 r
.52021 .69852 m .51661 .69913 L .51732 .6969 L F
.51856 .69685 m .51732 .6969 L .51763 .69591 L F
.52021 .69852 m .51732 .6969 L .51856 .69685 L F
.647 .202 .18 r
.51972 .70095 m .51661 .69913 L .52021 .69852 L F
.724 .496 .579 r
.52343 .70094 m .52021 .69852 L .5236 .6986 L F
.52343 .70094 m .51972 .70095 L .52021 .69852 L F
.508 .131 .26 r
.5183 .6992 m .52137 .69966 L .52233 .69669 L F
.52196 .69671 m .52233 .69669 L .52243 .69639 L F
.5183 .6992 m .52233 .69669 L .52196 .69671 L F
.174 0 0 r
.51621 .69748 m .52054 .6954 L .51763 .69591 L F
0 .27 .776 r
.48114 .70754 m .48165 .70662 L .47959 .70492 L F
.08 .434 .874 r
.48114 .70754 m .48268 .70809 L .48165 .70662 L F
.625 .306 .411 r
.49568 .65202 m .49188 .65425 L .49296 .65222 L F
.464 .257 .513 r
.54475 .68155 m .54242 .68449 L .54466 .68386 L F
.361 .088 .358 r
.54193 .68651 m .54466 .68386 L .54242 .68449 L F
.464 .257 .513 r
.54475 .68155 m .54242 .68449 L .54466 .68386 L F
.975 .859 .662 r
.62428 .43992 m .62183 .4422 L .62303 .43875 L F
.62428 .43992 m .6229 .44339 L .62183 .4422 L F
.859 .717 .704 r
.60508 .6575 m .60853 .65541 L .60725 .65451 L F
.60508 .6575 m .60688 .65854 L .60853 .65541 L F
.885 .887 .828 r
.60725 .65451 m .60853 .65541 L .61083 .65243 L F
.651 .215 .199 r
.6379 .44405 m .64036 .44532 L .64105 .44433 L F
.559 .413 .639 r
.64238 .4431 m .64036 .44532 L .6379 .44405 L F
.651 .215 .199 r
.64105 .44433 m .64036 .44532 L .64172 .44439 L F
.69 .942 .962 r
.64244 .44303 m .64172 .44439 L .64139 .44461 L F
.64238 .4431 m .64139 .44461 L .64036 .44532 L F
.64244 .44303 m .64139 .44461 L .64238 .4431 L F
.587 .73 .942 r
.63978 .44308 m .63966 .44267 L .6367 .44229 L F
.559 .413 .639 r
.64246 .44297 m .6409 .44334 L .63977 .44306 L F
.63965 .44264 m .63977 .44306 L .6367 .44229 L F
.564 .751 .965 r
.64256 .4427 m .63978 .44308 L .64141 .4404 L F
.903 .898 .812 r
.64129 .44059 m .63978 .44308 L .63978 .44307 L F
.64141 .4404 m .63978 .44308 L .64129 .44059 L F
.337 .14 .458 r
.64321 .43756 m .64129 .44059 L .64201 .43701 L F
.303 .109 .444 r
.64201 .43701 m .64129 .44059 L .64241 .43876 L F
.903 .898 .812 r
.64241 .43876 m .63978 .44307 L .63965 .44264 L F
.587 .73 .942 r
.63966 .44267 m .63965 .44264 L .6367 .44229 L F
.64243 .44302 m .63965 .44264 L .63966 .44267 L F
.64243 .44302 m .64246 .44297 L .63965 .44264 L F
.63978 .44308 m .64243 .44302 L .64128 .44287 L F
.564 .751 .965 r
.64144 .44285 m .63978 .44308 L .64256 .4427 L F
.587 .73 .942 r
.63978 .44308 m .64128 .44287 L .63966 .44267 L F
.564 .751 .965 r
.64002 .44305 m .63978 .44308 L .64144 .44285 L F
.559 .413 .639 r
.64144 .44285 m .63977 .44306 L .63965 .44264 L F
.69 .942 .962 r
.64259 .44275 m .64252 .44288 L .6425 .44291 L F
.559 .413 .639 r
.64246 .44297 m .6401 .44305 L .64144 .44285 L F
.69 .942 .962 r
.64252 .44288 m .64244 .44303 L .64239 .44308 L F
.64252 .44288 m .64239 .44308 L .64243 .44302 L F
.64259 .44275 m .64412 .44335 L .64172 .44439 L F
.587 .73 .942 r
.64243 .44302 m .64279 .44301 L .64246 .44297 L F
.64243 .44302 m .64279 .44301 L .64243 .44302 L F
.564 .751 .965 r
.64259 .44275 m .64279 .44301 L .64243 .44302 L F
.64259 .44275 m .64243 .44302 L .64002 .44305 L F
.69 .942 .962 r
.64243 .44302 m .64239 .44308 L .64238 .4431 L F
.559 .413 .639 r
.64238 .4431 m .6379 .44405 L .64246 .44297 L F
.69 .942 .962 r
.64259 .44275 m .6425 .44291 L .64036 .44532 L F
.564 .751 .965 r
.64002 .44305 m .64243 .44302 L .63978 .44308 L F
.64243 .44302 m .64279 .44301 L .64243 .44302 L F
.64243 .44302 m .64243 .44302 L .63978 .44308 L F
.559 .413 .639 r
.6401 .44305 m .64 .44305 L .64002 .44305 L F
.6401 .44305 m .64002 .44305 L .64144 .44285 L F
.64 .44305 m .63977 .44306 L .64144 .44285 L F
.564 .751 .965 r
.64259 .44275 m .64002 .44305 L .64256 .4427 L F
.337 .14 .458 r
.64331 .4376 m .64242 .43892 L .64321 .43756 L F
.64242 .43892 m .64141 .4404 L .64315 .43765 L F
.64242 .43892 m .64315 .43765 L .64321 .43756 L F
.564 .751 .965 r
.64259 .44275 m .64141 .4404 L .64242 .43892 L F
.64259 .44275 m .64242 .43892 L .64121 .441 L F
.337 .14 .458 r
.6444 .43809 m .64141 .4404 L .64331 .4376 L F
.564 .751 .965 r
.64242 .43892 m .64241 .43876 L .64121 .441 L F
.64242 .43892 m .64141 .4404 L .64241 .43876 L F
.337 .14 .458 r
.6444 .43809 m .64129 .44059 L .64141 .4404 L F
.6444 .43809 m .64121 .441 L .64129 .44059 L F
.903 .898 .812 r
.64241 .43876 m .64141 .4404 L .64129 .44059 L F
.303 .109 .444 r
.64129 .44059 m .64121 .441 L .64241 .43876 L F
.903 .898 .812 r
.63886 .43994 m .63965 .44264 L .63883 .43994 L F
.686 .403 .488 r
.64241 .43876 m .63989 .43978 L .6414 .43802 L F
.303 .109 .444 r
.64201 .43701 m .64241 .43876 L .6414 .43802 L F
.64171 .43701 m .6414 .43802 L .63995 .43696 L F
.64201 .43701 m .6414 .43802 L .64171 .43701 L F
.686 .403 .488 r
.64241 .43876 m .6414 .43802 L .64229 .43698 L F
.429 .086 .28 r
.64229 .43698 m .6414 .43802 L .64148 .43802 L F
.6411 .43901 m .63989 .43978 L .64099 .43937 L F
.6414 .43802 m .64068 .43886 L .6411 .43901 L F
.64068 .43886 m .63989 .43978 L .6411 .43901 L F
.903 .898 .812 r
.64241 .43876 m .63965 .44264 L .63918 .44104 L F
.64241 .43876 m .63918 .44104 L .64097 .43947 L F
.64241 .43876 m .64006 .43991 L .63989 .43978 L F
.64241 .43876 m .64097 .43947 L .64138 .4391 L F
.64241 .43876 m .64045 .44019 L .64006 .43991 L F
.452 .013 .113 r
.64045 .44019 m .6444 .43809 L .64114 .43932 L F
.64006 .43991 m .64114 .43932 L .63989 .43978 L F
.903 .898 .812 r
.64114 .43932 m .63918 .44104 L .63902 .44048 L F
.452 .013 .113 r
.64045 .44019 m .64114 .43932 L .64006 .43991 L F
.903 .898 .812 r
.64138 .4391 m .64114 .43932 L .63886 .43994 L F
.64114 .43932 m .63902 .44048 L .63886 .43994 L F
.303 .109 .444 r
.63995 .43696 m .6414 .43802 L .63902 .43694 L F
.6414 .43802 m .64241 .43876 L .64135 .43819 L F
.6414 .43802 m .64135 .43819 L .63902 .43694 L F
.429 .086 .28 r
.6414 .43802 m .64099 .43937 L .64114 .43932 L F
.903 .898 .812 r
.64241 .43876 m .64138 .4391 L .64176 .43923 L F
.429 .086 .28 r
.64257 .43805 m .64114 .43932 L .6444 .43809 L F
.6414 .43802 m .64114 .43932 L .64257 .43805 L F
.903 .898 .812 r
.63883 .43994 m .63978 .44308 L .63816 .44017 L F
.64176 .43923 m .63816 .44017 L .64045 .44019 L F
.64138 .4391 m .63816 .44017 L .64176 .43923 L F
.686 .403 .488 r
.64135 .43819 m .64229 .43698 L .63902 .43694 L F
.64241 .43876 m .64229 .43698 L .64135 .43819 L F
.429 .086 .28 r
.64229 .43698 m .64148 .43802 L .6444 .43809 L F
.69 .942 .962 r
.64252 .44288 m .64238 .4431 L .64036 .44532 L F
.523 .738 .973 r
.63816 .44017 m .63977 .44306 L .6367 .44229 L F
.63977 .44306 m .63978 .44308 L .6367 .44229 L F
.559 .413 .639 r
.6409 .44334 m .6379 .44405 L .6367 .44229 L F
.64279 .44301 m .64238 .4431 L .64246 .44297 L F
.64279 .44301 m .64036 .44532 L .64238 .4431 L F
.837 .844 .85 r
.64158 .44346 m .63922 .44696 L .64036 .44532 L F
.63922 .44696 m .63903 .44724 L .64036 .44532 L F
.338 0 0 r
.41556 .62887 m .41421 .63049 L .41172 .63073 L F
.504 .069 .147 r
.41781 .62873 m .41421 .63049 L .41556 .62887 L F
.829 .492 .418 r
.54108 .64136 m .53899 .64278 L .54013 .64055 L F
.65 .093 0 r
.54013 .64055 m .54419 .64276 L .54108 .64136 L F
.814 .613 .631 r
.62747 .46392 m .62403 .46579 L .62393 .46338 L F
.62747 .46392 m .62744 .46667 L .62403 .46579 L F
.702 .52 .639 r
.6308 .46515 m .62744 .46667 L .62747 .46392 L F
.61 .371 .53 r
.51654 .67781 m .51858 .67533 L .51654 .67616 L F
0 0 .162 r
.45092 .61941 m .4528 .62 L .4509 .61939 L F
.905 .622 .496 r
.45299 .62247 m .45543 .62083 L .4528 .62 L F
0 0 .162 r
.45313 .62083 m .45299 .62247 L .4528 .62 L F
.45313 .62083 m .4528 .62 L .45092 .61941 L F
.905 .622 .496 r
.45543 .62083 m .45593 .62049 L .4528 .62 L F
.45299 .62247 m .45465 .62275 L .45593 .62049 L F
.557 .135 .195 r
.45816 .62228 m .45593 .62049 L .45465 .62275 L F
.45816 .62228 m .45852 .62077 L .45593 .62049 L F
0 0 0 r
.53952 .7134 m .54097 .71271 L .54044 .71294 L F
.652 .636 .822 r
.45076 .59986 m .45378 .60009 L .45159 .59614 L F
.45378 .60009 m .45389 .6001 L .45385 .60003 L F
.45378 .60009 m .45385 .60003 L .45159 .59614 L F
0 0 0 r
.45534 .59858 m .45385 .60003 L .45417 .59938 L F
.45385 .60003 m .45344 .60041 L .45417 .59938 L F
.45554 .59844 m .45341 .60045 L .45534 .59858 L F
.602 .614 .836 r
.45159 .59614 m .45385 .60003 L .45554 .59844 L F
.45385 .60003 m .45389 .6001 L .45554 .59844 L F
.508 .378 .638 r
.45378 .60009 m .45279 .60132 L .45389 .6001 L F
0 0 0 r
.45379 .60008 m .45341 .60045 L .45344 .60041 L F
.45378 .60009 m .45341 .60045 L .45379 .60008 L F
.508 .378 .638 r
.45076 .59986 m .45279 .60132 L .45378 .60009 L F
0 0 0 r
.45385 .60003 m .45378 .60009 L .45379 .60008 L F
.45554 .59844 m .45389 .6001 L .45279 .60132 L F
.45554 .59844 m .45279 .60132 L .45341 .60045 L F
.444 0 0 r
.39133 .62462 m .39486 .62453 L .39294 .62397 L F
.469 .19 .406 r
.51567 .67032 m .51486 .67235 L .51252 .67283 L F
.508 .229 .425 r
.51723 .67181 m .51567 .67032 L .51569 .66996 L F
.51723 .67181 m .51486 .67235 L .51567 .67032 L F
.887 .459 .143 r
.66309 .43623 m .66563 .43952 L .66376 .43795 L F
.911 .691 .592 r
.19739 .57827 m .19884 .57711 L .19932 .57635 L F
.19739 .57827 m .19843 .57961 L .19884 .57711 L F
.544 .271 .452 r
.4916 .70515 m .48817 .70729 L .48928 .70495 L F
.885 .887 .828 r
.60725 .65451 m .61083 .65243 L .60918 .65144 L F
.66 .615 .794 r
.76001 .50437 m .76356 .50702 L .76269 .50381 L F
.633 .587 .785 r
.76269 .50381 m .76356 .50702 L .76595 .50459 L F
.568 .308 .482 r
.49474 .6756 m .49709 .67552 L .49778 .67327 L F
.672 .246 .226 r
.56923 .63453 m .56976 .63272 L .56839 .63134 L F
.56923 .63453 m .57083 .63401 L .56976 .63272 L F
.855 .837 .827 r
.50168 .65382 m .50513 .65243 L .50373 .65379 L F
0 0 0 r
.50532 .65247 m .50513 .65243 L .50762 .64929 L F
.50373 .65379 m .50513 .65243 L .50532 .65247 L F
.903 .731 .658 r
.55817 .67835 m .55539 .68058 L .55541 .67832 L F
.55817 .67835 m .55742 .68163 L .55539 .68058 L F
0 .048 .615 r
.55902 .67612 m .55981 .678 L .55935 .67784 L F
.55981 .678 m .56051 .67964 L .55935 .67784 L F
0 0 .391 r
.55842 .67751 m .55935 .67784 L .55817 .67835 L F
.55933 .67447 m .55935 .67784 L .55842 .67751 L F
0 .069 .629 r
.55935 .67784 m .56054 .68095 L .55817 .67835 L F
.535 0 0 r
.36361 .64053 m .36361 .64096 L .36199 .63967 L F
.923 .534 .172 r
.36502 .64234 m .36361 .64096 L .36361 .64053 L F
.471 .151 .341 r
.51547 .63683 m .51355 .63546 L .51297 .63723 L F
.51547 .63683 m .51584 .63508 L .51355 .63546 L F
.901 .885 .807 r
.62936 .43191 m .62608 .43386 L .62801 .4307 L F
.62936 .43191 m .62722 .43503 L .62608 .43386 L F
.6 .649 .871 r
.19599 .58003 m .19739 .57827 L .19434 .57741 L F
.19599 .58003 m .19843 .57961 L .19739 .57827 L F
.574 .427 .644 r
.19599 .58003 m .19612 .58263 L .19843 .57961 L F
.069 .079 .56 r
.45256 .68722 m .45266 .69028 L .45404 .68989 L F
.254 .161 .552 r
.45266 .69028 m .45456 .69165 L .45404 .68989 L F
.45266 .69028 m .45263 .69368 L .45456 .69165 L F
.611 .33 .466 r
.53237 .63965 m .5288 .64034 L .52918 .63824 L F
.249 0 0 r
.37217 .59716 m .37093 .59836 L .36844 .59869 L F
.449 0 .081 r
.37445 .59684 m .37093 .59836 L .37217 .59716 L F
.594 .32 .47 r
.50762 .64929 m .50985 .65172 L .50532 .65247 L F
.605 .319 .457 r
.50994 .64949 m .50985 .65172 L .50762 .64929 L F
.475 .37 .656 r
.47493 .71025 m .47741 .71217 L .47852 .71087 L F
.596 .147 .155 r
.47741 .71217 m .481 .71233 L .47852 .71087 L F
.835 .671 .679 r
.50092 .69635 m .50006 .69878 L .49844 .69535 L F
.50092 .69635 m .50006 .69878 L .49844 .69535 L F
.605 .52 .731 r
.75601 .49918 m .75642 .50148 L .75872 .49867 L F
.63 .555 .752 r
.75872 .49867 m .75642 .50148 L .75896 .50091 L F
.657 .557 .731 r
.75642 .50148 m .76001 .50437 L .75896 .50091 L F
0 .432 .701 r
.38048 .58161 m .3826 .58213 L .38406 .58251 L F
.353 .712 .986 r
.38479 .58145 m .38406 .58251 L .3826 .58213 L F
.38479 .58145 m .38625 .58252 L .38406 .58251 L F
.58 .21 .305 r
.42386 .62619 m .4227 .62851 L .42015 .62833 L F
.304 0 .095 r
.42615 .62592 m .4227 .62851 L .42386 .62619 L F
.881 .989 .808 r
.5553 .65763 m .55319 .65967 L .55469 .65922 L F
0 0 0 r
.55073 .66041 m .55319 .65967 L .55032 .65969 L F
.55319 .65967 m .55341 .65936 L .55032 .65969 L F
.55198 .66257 m .55469 .65922 L .55073 .66041 L F
0 0 .519 r
.55282 .65266 m .5553 .65763 L .55431 .65506 L F
.55282 .65266 m .55507 .6564 L .5553 .65763 L F
.717 .539 .648 r
.55032 .65969 m .55341 .65936 L .55251 .66033 L F
.881 .989 .808 r
.55319 .65967 m .5533 .65948 L .55251 .66033 L F
0 0 0 r
.55319 .65967 m .55469 .65922 L .55341 .65936 L F
.881 .989 .808 r
.55319 .65967 m .55251 .66033 L .55469 .65922 L F
.717 .539 .648 r
.55341 .65936 m .55469 .65922 L .55251 .66033 L F
.881 .989 .808 r
.5533 .65948 m .55507 .6564 L .55251 .66033 L F
.5553 .65763 m .55516 .65691 L .55319 .65967 L F
.55516 .65691 m .55507 .6564 L .55319 .65967 L F
.712 .983 .895 r
.55251 .66033 m .55105 .66078 L .55032 .65969 L F
.004 .06 .569 r
.54926 .66198 m .55032 .65969 L .54957 .65858 L F
.339 .472 .848 r
.54926 .66198 m .55198 .66257 L .55032 .65969 L F
.712 .983 .895 r
.55105 .66078 m .54906 .66141 L .55032 .65969 L F
.004 .06 .569 r
.54957 .65858 m .55032 .65969 L .54967 .65742 L F
.275 .471 .87 r
.54329 .67111 m .54072 .6719 L .54345 .66875 L F
.54329 .67111 m .5423 .67257 L .54072 .6719 L F
.533 0 0 r
.56547 .62932 m .56663 .62926 L .56346 .62835 L F
0 .187 .63 r
.56547 .62932 m .56839 .63134 L .56663 .62926 L F
0 0 0 r
.1921 .57695 m .19438 .57426 L .19448 .57395 L F
.351 .028 .269 r
.19438 .57426 m .19663 .57282 L .19448 .57395 L F
.719 .831 .934 r
.35207 .63748 m .35399 .63904 L .35611 .6376 L F
.608 .394 .566 r
.49437 .64676 m .49699 .64657 L .49704 .64391 L F
.63 .485 .666 r
.49704 .64391 m .5002 .64361 L .49939 .64087 L F
.623 .406 .567 r
.49704 .64391 m .50005 .64574 L .5002 .64361 L F
.49704 .64391 m .49699 .64657 L .50005 .64574 L F
0 .539 .716 r
.58127 .63802 m .58361 .63821 L .58059 .63797 L F
.306 .105 .436 r
.58235 .63926 m .58361 .63821 L .58334 .63973 L F
.58235 .63926 m .58059 .63797 L .58361 .63821 L F
.964 .641 .263 r
.66856 .4488 m .66903 .45116 L .67011 .45217 L F
.66856 .4488 m .66903 .45116 L .67011 .45217 L F
.723 .6 .719 r
.73597 .49247 m .73743 .49595 L .73964 .49303 L F
.193 0 0 r
.39554 .63544 m .39382 .63637 L .39147 .63659 L F
.224 0 0 r
.39769 .63516 m .39382 .63637 L .39554 .63544 L F
.249 .233 .644 r
.44438 .58806 m .44322 .59161 L .44203 .58854 L F
.44438 .58806 m .44506 .59106 L .44322 .59161 L F
.163 0 .371 r
.44506 .59106 m .44344 .59227 L .44322 .59161 L F
.981 .819 .61 r
.50249 .69943 m .5038 .69912 L .5046 .69815 L F
.50375 .69913 m .50326 .70172 L .5038 .69912 L F
.50289 .70061 m .50326 .70172 L .50375 .69913 L F
.73 .731 .851 r
.49973 .7014 m .50326 .70172 L .50249 .69943 L F
.067 0 0 r
.50668 .6999 m .50331 .70062 L .50336 .70038 L F
0 0 0 r
.50348 .69985 m .50336 .70038 L .50329 .70046 L F
.50326 .70017 m .50329 .70046 L .50229 .70164 L F
.50348 .69985 m .50329 .70046 L .50326 .70017 L F
.067 0 0 r
.50668 .6999 m .50544 .70041 L .50332 .70069 L F
.981 .819 .61 r
.50249 .69943 m .50289 .70061 L .50375 .69913 L F
.702 .372 .414 r
.4998 .70348 m .50326 .70172 L .49973 .7014 L F
0 0 0 r
.5046 .69815 m .50201 .70197 L .50249 .69943 L F
.50263 .70105 m .50229 .70164 L .50201 .70197 L F
.551 .928 .812 r
.50241 .70081 m .50201 .70197 L .50336 .70038 L F
.067 0 0 r
.50331 .70062 m .50332 .70069 L .50241 .70081 L F
.50668 .6999 m .50332 .70069 L .50331 .70062 L F
.50331 .70062 m .50241 .70081 L .50336 .70038 L F
0 0 0 r
.5046 .69815 m .50336 .70038 L .50348 .69985 L F
.5046 .69815 m .50229 .70164 L .50263 .70105 L F
.829 .612 .61 r
.49711 .68709 m .49737 .68997 L .49981 .69032 L F
.565 .371 .578 r
.54466 .68386 m .54707 .68108 L .54475 .68155 L F
.54466 .68386 m .54707 .68108 L .54475 .68155 L F
.276 .093 .443 r
.22291 .59423 m .22257 .59693 L .22061 .59771 L F
0 0 0 r
.22257 .59693 m .22052 .59964 L .22061 .59771 L F
.221 .064 .445 r
.21186 .62213 m .21072 .62059 L .21198 .61985 L F
.21186 .62213 m .21044 .62303 L .21072 .62059 L F
.566 .688 .922 r
.77777 .51686 m .77947 .51465 L .77741 .51452 L F
.77777 .51686 m .78081 .51637 L .77947 .51465 L F
.364 .801 .962 r
.64504 .44287 m .64412 .44335 L .64259 .44275 L F
.475 .642 .93 r
.64667 .44447 m .64412 .44335 L .64504 .44287 L F
.04 .325 .809 r
.20235 .5574 m .20376 .55691 L .20188 .55713 L F
.783 .349 .219 r
.20652 .5599 m .20555 .56028 L .20235 .5574 L F
.04 .325 .809 r
.20235 .5574 m .20555 .56028 L .20376 .55691 L F
.741 .322 .254 r
.52442 .64399 m .52027 .64336 L .52183 .64524 L F
.095 0 .439 r
.46434 .70129 m .46465 .70071 L .46426 .70118 L F
.52 .844 .549 r
.4648 .70209 m .46508 .69989 L .46465 .70071 L F
.095 0 .439 r
.46539 .70263 m .46376 .70427 L .46465 .70071 L F
.46539 .70263 m .46465 .70071 L .46434 .70129 L F
.52 .844 .549 r
.46508 .69989 m .46518 .69911 L .46465 .70071 L F
.985 .707 .394 r
.46465 .70071 m .46518 .69911 L .46398 .69821 L F
.073 0 .271 r
.21876 .60292 m .21823 .60566 L .21691 .6061 L F
.477 .369 .652 r
.21823 .60566 m .2164 .60845 L .21691 .6061 L F
.166 0 0 r
.38897 .59252 m .38746 .59316 L .38506 .59331 L F
.284 .784 .853 r
.39079 .5925 m .38746 .59316 L .38897 .59252 L F
.963 .685 .459 r
.47973 .7163 m .47843 .71817 L .4781 .71561 L F
.57 .567 .811 r
.481 .71233 m .47973 .7163 L .48112 .71393 L F
.481 .71233 m .48203 .71589 L .47973 .7163 L F
.407 0 .089 r
.48097 .71761 m .47973 .7163 L .48203 .71589 L F
.48097 .71761 m .47843 .71817 L .47973 .7163 L F
.923 .825 .732 r
.46525 .61343 m .46706 .61425 L .46646 .61207 L F
.736 .794 .899 r
.46288 .61427 m .46706 .61425 L .46525 .61343 L F
.937 .944 .768 r
.48126 .66021 m .48082 .66348 L .47908 .6607 L F
.48126 .66021 m .47941 .66315 L .48082 .66348 L F
.73 .34 .312 r
.47893 .66562 m .48082 .66348 L .47941 .66315 L F
.47893 .66562 m .48253 .66603 L .48082 .66348 L F
.314 .106 .429 r
.20905 .62628 m .20853 .62867 L .2069 .62917 L F
0 0 .231 r
.20853 .62867 m .20701 .63155 L .2069 .62917 L F
.79 .576 .611 r
.52924 .66904 m .53267 .66963 L .53254 .66704 L F
.255 .086 .449 r
.53459 .66595 m .53254 .66704 L .53424 .66571 L F
.452 .222 .474 r
.19525 .59656 m .19781 .59429 L .1963 .59567 L F
.255 0 0 r
.78176 .48796 m .78567 .4887 L .78337 .48944 L F
0 0 .029 r
.51525 .69895 m .51631 .69813 L .51621 .69748 L F
.63 .217 .242 r
.51661 .69913 m .51867 .70091 L .51525 .69895 L F
.647 .202 .18 r
.51846 .70021 m .51867 .70091 L .51661 .69913 L F
.51972 .70095 m .51867 .70091 L .51846 .70021 L F
.748 .571 .655 r
.51972 .70095 m .51676 .70369 L .51867 .70091 L F
.51972 .70095 m .52137 .70387 L .51676 .70369 L F
.676 .482 .615 r
.51867 .70091 m .51925 .70328 L .51882 .70145 L F
.51867 .70091 m .51882 .70145 L .5183 .6992 L F
.108 .399 .853 r
.51525 .69895 m .51867 .70091 L .51631 .69813 L F
.171 .671 .912 r
.45231 .60347 m .45117 .60295 L .44847 .60281 L F
.808 .958 .911 r
.45279 .60132 m .45117 .60295 L .45231 .60347 L F
.33 .132 .453 r
.32997 .61749 m .33307 .6195 L .33196 .61632 L F
.32997 .61749 m .33174 .61844 L .33307 .6195 L F
.32997 .61749 m .33024 .62008 L .33174 .61844 L F
.833 .848 .858 r
.33056 .61973 m .33307 .6195 L .33174 .61844 L F
.33041 .6204 m .33307 .6195 L .33038 .61975 L F
.33 .132 .453 r
.33024 .62008 m .33027 .62033 L .33174 .61844 L F
.833 .848 .858 r
.33038 .61975 m .33056 .61973 L .33174 .61844 L F
.484 .735 .982 r
.32991 .6229 m .33049 .62215 L .33027 .62002 L F
.33049 .62215 m .33073 .62184 L .33042 .62063 L F
.33049 .62215 m .33042 .62063 L .33027 .62002 L F
.851 .846 .838 r
.33027 .62002 m .33073 .62184 L .32934 .62076 L F
.833 .848 .858 r
.32934 .62076 m .33041 .6204 L .33039 .61993 L F
.545 .327 .534 r
.32997 .62026 m .32934 .62076 L .33027 .62033 L F
.851 .846 .838 r
.33027 .62002 m .32934 .62076 L .32708 .61957 L F
.545 .327 .534 r
.32708 .61957 m .32934 .62076 L .32997 .62026 L F
.55 .284 .466 r
.32708 .61957 m .32997 .62026 L .32997 .61749 L F
.32997 .62026 m .33027 .62033 L .33024 .62008 L F
.32997 .62026 m .33024 .62008 L .32997 .61749 L F
.833 .848 .858 r
.3296 .62051 m .33039 .61993 L .33038 .61975 L F
.32934 .62076 m .32997 .62026 L .3296 .62051 L F
.32997 .62026 m .33039 .61993 L .3296 .62051 L F
.484 .735 .982 r
.32991 .6229 m .33232 .62329 L .33073 .62184 L F
.767 .529 .573 r
.32991 .6229 m .33356 .62581 L .33232 .62329 L F
.32991 .6229 m .32834 .62556 L .33356 .62581 L F
.969 .804 .622 r
.59346 .60511 m .59296 .60859 L .59457 .6085 L F
.971 .656 .307 r
.59296 .60859 m .59443 .61097 L .59457 .6085 L F
.11 0 0 r
.3805 .59426 m .3788 .59573 L .37665 .59629 L F
.275 0 0 r
.38266 .59373 m .3788 .59573 L .3805 .59426 L F
.788 .828 .883 r
.31883 .62259 m .32047 .62402 L .32302 .62222 L F
.63 .956 .921 r
.32724 .63097 m .32573 .63105 L .32524 .63217 L F
.651 .738 .913 r
.47461 .68698 m .47412 .68791 L .47269 .68651 L F
.27 .325 .736 r
.54726 .68543 m .54543 .68807 L .54466 .68386 L F
.398 .292 .617 r
.5467 .68623 m .54527 .68921 L .54543 .68807 L F
.54643 .687 m .54527 .68921 L .5467 .68623 L F
.54726 .68543 m .54726 .68857 L .54527 .68921 L F
.72 .421 .472 r
.54412 .68664 m .54366 .68876 L .54585 .68865 L F
.54612 .68788 m .54585 .68865 L .54726 .68857 L F
.54412 .68664 m .54585 .68865 L .54612 .68788 L F
.398 .292 .617 r
.54726 .68543 m .54643 .687 L .5467 .68623 L F
.375 .205 .519 r
.23168 .56776 m .2321 .57091 L .23005 .57141 L F
.177 0 .345 r
.23427 .56483 m .23364 .56691 L .23168 .56776 L F
.435 .246 .525 r
.23384 .56998 m .23168 .56776 L .23364 .56691 L F
.23384 .56998 m .2321 .57091 L .23168 .56776 L F
.527 .158 .283 r
.63931 .46369 m .64193 .46509 L .63858 .46569 L F
.63931 .46369 m .64182 .46359 L .64193 .46509 L F
.592 .699 .917 r
.18868 .56092 m .18917 .55828 L .18814 .55944 L F
.18868 .56092 m .19189 .56148 L .18917 .55828 L F
.84 .374 .015 r
.5719 .63462 m .57285 .63633 L .57336 .63549 L F
.529 .384 .628 r
.54772 .66574 m .54458 .66705 L .54644 .66362 L F
.237 0 0 r
.54579 .6677 m .54458 .66705 L .54772 .66574 L F
.54579 .6677 m .54345 .66875 L .54458 .66705 L F
.549 .272 .447 r
.65324 .45736 m .65287 .46014 L .6501 .46038 L F
.407 .151 .41 r
.6552 .45926 m .65324 .45736 L .65525 .45729 L F
.6552 .45926 m .65287 .46014 L .65324 .45736 L F
0 0 0 r
.48039 .66667 m .47746 .6689 L .47802 .6671 L F
0 0 .284 r
.55221 .66718 m .55198 .66257 L .55323 .66357 L F
.55201 .66316 m .55228 .66454 L .55198 .66257 L F
.55221 .66718 m .55228 .66454 L .55205 .66394 L F
0 0 0 r
.55272 .66556 m .55387 .66364 L .55283 .66512 L F
.55253 .66635 m .55288 .66563 L .55272 .66556 L F
.55288 .66563 m .55387 .66364 L .55272 .66556 L F
0 0 .286 r
.55315 .66878 m .55318 .66784 L .55254 .66549 L F
.55249 .66547 m .55254 .66549 L .55239 .66494 L F
.55315 .66878 m .55254 .66549 L .55249 .66547 L F
.55234 .66486 m .55239 .66494 L .55228 .66454 L F
.55315 .66878 m .55239 .66494 L .55234 .66486 L F
.124 0 0 r
.55292 .66778 m .55236 .66497 L .55318 .66784 L F
.55236 .66497 m .55228 .66454 L .55239 .66494 L F
.55236 .66497 m .55239 .66494 L .55318 .66784 L F
.566 .672 .91 r
.55221 .66718 m .55228 .66454 L .55053 .66707 L F
.368 .179 .489 r
.55221 .66718 m .55075 .66931 L .55053 .66707 L F
.55221 .66718 m .55315 .66878 L .55075 .66931 L F
.336 .358 .736 r
.55315 .66878 m .55053 .66707 L .55075 .66931 L F
.55315 .66878 m .55228 .66454 L .55053 .66707 L F
.124 0 0 r
.55036 .66726 m .55228 .66454 L .55292 .66778 L F
.736 .696 .813 r
.54874 .66779 m .55115 .67199 L .54739 .67178 L F
.982 .829 .433 r
.54999 .66738 m .55115 .67199 L .54874 .66779 L F
.55036 .66726 m .55045 .66777 L .54999 .66738 L F
.55045 .66777 m .55115 .67199 L .54999 .66738 L F
.55036 .66726 m .54999 .67087 L .55115 .67199 L F
.779 .57 .616 r
.55192 .66903 m .55354 .67076 L .54999 .67087 L F
.55318 .66784 m .5535 .67038 L .55192 .66903 L F
.5535 .67038 m .55354 .67076 L .55192 .66903 L F
.55318 .66784 m .54999 .67087 L .55036 .66726 L F
.114 .539 .916 r
.55403 .6726 m .54999 .67087 L .55354 .67076 L F
.262 .522 .91 r
.54999 .67087 m .55308 .6716 L .55075 .66917 L F
0 .255 .754 r
.55075 .66917 m .55308 .6716 L .55217 .67041 L F
.765 .518 .561 r
.55075 .66917 m .55217 .67041 L .55043 .67045 L F
0 0 0 r
.54999 .67087 m .55075 .66917 L .55094 .66844 L F
.54999 .67087 m .55096 .66838 L .55103 .66772 L F
.736 .696 .813 r
.54874 .66779 m .54739 .67178 L .54579 .6677 L F
.846 .665 .657 r
.54674 .66926 m .54999 .67087 L .55036 .66726 L F
.124 0 0 r
.55114 .66671 m .55253 .66635 L .55272 .66556 L F
.55036 .66726 m .55111 .66695 L .55114 .66671 L F
.55111 .66695 m .55253 .66635 L .55114 .66671 L F
.55036 .66726 m .55272 .66556 L .55259 .66533 L F
.513 .907 .93 r
.55036 .66726 m .55155 .66613 L .55253 .66635 L F
0 0 0 r
.54999 .67087 m .55155 .66613 L .55036 .66726 L F
.771 .597 .663 r
.54579 .6677 m .54739 .67178 L .54329 .67111 L F
.903 .817 .753 r
.54692 .67153 m .54999 .67087 L .54674 .66926 L F
.765 .518 .561 r
.55075 .66917 m .55043 .67045 L .54786 .6705 L F
0 0 0 r
.55094 .66844 m .55075 .66917 L .55096 .66838 L F
.55103 .66772 m .55096 .66838 L .55155 .66613 L F
.124 0 0 r
.55259 .66533 m .55272 .66556 L .55283 .66512 L F
.55036 .66726 m .55259 .66533 L .55228 .66454 L F
.55259 .66533 m .55283 .66512 L .55228 .66454 L F
0 0 .284 r
.55205 .66394 m .55228 .66454 L .55201 .66316 L F
.917 .806 .722 r
.5939 .6198 m .5925 .62239 L .59476 .6234 L F
.825 .45 0 r
.5925 .62239 m .59352 .62452 L .59476 .6234 L F
.857 .423 .185 r
.58698 .59606 m .58696 .59395 L .58511 .59384 L F
.58698 .59606 m .58873 .59665 L .58696 .59395 L F
.977 .718 .475 r
.55474 .68688 m .55338 .68627 L .55439 .68435 L F
.718 .628 .757 r
.55638 .68382 m .55474 .68688 L .55439 .68435 L F
.29 0 .097 r
.55338 .68627 m .55638 .68382 L .55439 .68435 L F
.394 .148 .418 r
.51252 .67283 m .5123 .67512 L .51011 .67563 L F
.593 .367 .542 r
.51486 .67235 m .5123 .67512 L .51252 .67283 L F
.972 .864 .672 r
.20532 .55749 m .20652 .5599 L .20896 .55982 L F
.20532 .55749 m .20555 .56028 L .20652 .5599 L F
.442 0 0 r
.20652 .5599 m .20486 .56121 L .20864 .56082 L F
.44 0 .061 r
.20652 .5599 m .20864 .56082 L .20896 .55982 L F
.671 .483 .622 r
.48545 .68727 m .48543 .6903 L .48299 .6897 L F
.537 .779 .987 r
.48488 .68597 m .48771 .68678 L .48545 .68727 L F
.675 .486 .623 r
.48901 .68924 m .48635 .68777 L .48771 .68678 L F
.48635 .68777 m .48545 .68727 L .48771 .68678 L F
.48901 .68924 m .48543 .6903 L .48545 .68727 L F
.313 0 .058 r
.48627 .68782 m .4894 .68555 L .48771 .68678 L F
0 0 0 r
.4901 .68501 m .48771 .68678 L .48958 .68542 L F
.313 0 .058 r
.4894 .68555 m .48958 .68542 L .48771 .68678 L F
.534 .095 .151 r
.48543 .6903 m .48165 .6919 L .48299 .6897 L F
.48543 .6903 m .48405 .6921 L .48165 .6919 L F
.6 .311 .45 r
.48901 .68924 m .48755 .69223 L .48543 .6903 L F
.267 .195 .587 r
.48488 .68597 m .48544 .6906 L .48626 .68786 L F
.48488 .68597 m .48626 .68786 L .48627 .68782 L F
.537 .779 .987 r
.48488 .68597 m .48545 .68727 L .48405 .68484 L F
.48488 .68597 m .48405 .68484 L .48375 .68431 L F
.801 .607 .639 r
.47828 .73322 m .47774 .73631 L .47749 .73563 L F
.278 0 .213 r
.52807 .6899 m .53038 .68891 L .5306 .68756 L F
.486 .116 .262 r
.53038 .68891 m .53282 .68873 L .5306 .68756 L F
.514 0 0 r
.5306 .68756 m .53282 .68873 L .5319 .68789 L F
.484 .103 .241 r
.44043 .62368 m .43811 .62455 L .43852 .62417 L F
.223 0 .242 r
.33393 .6295 m .33321 .6314 L .33606 .6285 L F
.777 .514 .537 r
.61411 .46087 m .61076 .46253 L .61252 .45916 L F
.61411 .46087 m .61434 .46311 L .61076 .46253 L F
.197 0 0 r
.53005 .63468 m .52711 .6348 L .53092 .63478 L F
.692 .922 .598 r
.45256 .68722 m .4531 .68606 L .45456 .68472 L F
0 0 .532 r
.45256 .68722 m .45404 .68989 L .4531 .68606 L F
0 0 0 r
.4743 .66657 m .47652 .66345 L .47443 .6633 L F
.364 .237 .572 r
.2321 .57091 m .23025 .57376 L .23005 .57141 L F
.615 .455 .641 r
.66665 .45084 m .66291 .44885 L .66635 .44918 L F
.583 .565 .8 r
.66741 .4454 m .66856 .4488 L .66635 .44918 L F
.659 .447 .585 r
.66856 .4488 m .66665 .45084 L .66635 .44918 L F
1 .808 .495 r
.33606 .6285 m .33681 .6302 L .33888 .62931 L F
.33606 .6285 m .33593 .63111 L .33681 .6302 L F
.418 .793 .993 r
.40608 .57989 m .4099 .5804 L .40779 .5809 L F
.492 .176 .358 r
.51505 .6844 m .5135 .68736 L .51249 .68664 L F
.583 .273 .409 r
.51721 .68428 m .51505 .6844 L .51751 .68414 L F
.51721 .68428 m .5135 .68736 L .51505 .6844 L F
.72 .729 .858 r
.59702 .6662 m .60029 .66313 L .59693 .66273 L F
.711 .723 .859 r
.59702 .6662 m .59693 .66273 L .5945 .66365 L F
.984 .702 .352 r
.59314 .6018 m .59397 .60013 L .59234 .59944 L F
.59314 .6018 m .59424 .60287 L .59397 .60013 L F
.64 .331 .431 r
.42704 .61632 m .42957 .61664 L .42768 .6143 L F
.776 .278 .02 r
.42768 .6143 m .42957 .61664 L .43069 .61684 L F
.828 .579 .563 r
.48667 .71239 m .48457 .71515 L .48638 .71213 L F
.48667 .71239 m .48876 .71616 L .48457 .71515 L F
.576 .382 .582 r
.23972 .55956 m .23965 .5621 L .23735 .56208 L F
.23972 .55956 m .23965 .5621 L .23735 .56208 L F
.414 .536 .871 r
.24065 .55807 m .23972 .55956 L .2379 .55679 L F
.222 .281 .714 r
.24065 .55807 m .2418 .56176 L .23972 .55956 L F
.517 .334 .572 r
.23972 .55956 m .2418 .56176 L .23965 .5621 L F
.739 .74 .852 r
.63877 .42377 m .64002 .42567 L .63774 .42623 L F
.64 .356 .472 r
.63774 .42623 m .64002 .42567 L .63963 .42757 L F
.584 .718 .935 r
.64134 .42297 m .64002 .42567 L .63877 .42377 L F
.64134 .42297 m .64245 .42507 L .64002 .42567 L F
.159 0 0 r
.64002 .42567 m .64134 .42648 L .63963 .42757 L F
.64002 .42567 m .64245 .42507 L .64134 .42648 L F
.68 .466 .589 r
.5272 .69579 m .52808 .69905 L .5236 .6986 L F
.713 .485 .578 r
.53003 .69858 m .5272 .69579 L .52942 .69588 L F
.53003 .69858 m .52808 .69905 L .5272 .69579 L F
.354 .544 .902 r
.57336 .65486 m .57304 .65178 L .57059 .65163 L F
.57336 .65486 m .57432 .65425 L .57304 .65178 L F
.595 .852 .993 r
.50141 .73607 m .50508 .7363 L .50367 .73559 L F
.50141 .73607 m .50508 .7363 L .50367 .73559 L F
.534 .865 .994 r
.50367 .73559 m .50508 .7363 L .50773 .73554 L F
.50773 .73554 m .50508 .7363 L .50367 .73559 L F
.587 .489 .711 r
.19707 .57102 m .1995 .57058 L .19941 .56691 L F
.602 .399 .579 r
.19663 .57282 m .1995 .57058 L .19707 .57102 L F
.936 .808 .694 r
.66322 .4465 m .66291 .44885 L .6619 .44542 L F
.615 .455 .641 r
.66665 .45084 m .66394 .45176 L .66291 .44885 L F
.523 .404 .659 r
.20701 .63155 m .20616 .63392 L .2048 .63503 L F
.093 0 .314 r
.20616 .63392 m .2046 .63749 L .2048 .63503 L F
.408 0 .147 r
.34444 .58754 m .34678 .58723 L .34821 .58508 L F
.343 0 .077 r
.34678 .58723 m .35052 .58483 L .34821 .58508 L F
.035 0 0 r
.79707 .48337 m .798 .48335 L .80016 .48339 L F
.477 .358 .639 r
.2066 .57409 m .20833 .57086 L .20527 .57079 L F
.2066 .57409 m .20846 .5735 L .20833 .57086 L F
.465 .328 .609 r
.2066 .57409 m .20866 .57601 L .20846 .5735 L F
.387 .323 .663 r
.2071 .5767 m .20866 .57601 L .2066 .57409 L F
0 0 .157 r
.36025 .60504 m .3594 .60889 L .35893 .60582 L F
.36025 .60504 m .36009 .60748 L .3594 .60889 L F
.481 .5 .8 r
.36009 .60748 m .35939 .61128 L .3594 .60889 L F
.665 .676 .851 r
.76595 .50459 m .76957 .50688 L .76846 .50385 L F
.616 .623 .835 r
.76957 .50688 m .771 .50306 L .76846 .50385 L F
.76957 .50688 m .77226 .50628 L .771 .50306 L F
.48 .026 .096 r
.57379 .59822 m .57371 .59959 L .57071 .5975 L F
.57379 .59822 m .57494 .59895 L .57371 .59959 L F
0 .19 .64 r
.57379 .59822 m .57614 .59978 L .57494 .59895 L F
.209 0 0 r
.50554 .67249 m .50784 .67207 L .50875 .671 L F
.217 0 0 r
.50875 .671 m .51026 .6715 L .51108 .6692 L F
.50875 .671 m .50784 .67207 L .51026 .6715 L F
.718 .828 .933 r
.78081 .51637 m .78404 .51658 L .78293 .51507 L F
.743 .798 .896 r
.78293 .51507 m .78404 .51658 L .78657 .51499 L F
.069 .632 .734 r
.37835 .62514 m .37509 .62532 L .37729 .62525 L F
.523 .006 0 r
.37729 .62525 m .38089 .62527 L .37835 .62514 L F
.681 .505 .642 r
.5002 .64361 m .50262 .64081 L .49939 .64087 L F
.631 .451 .622 r
.5123 .67512 m .50976 .67805 L .51011 .67563 L F
.523 .152 .279 r
.64767 .46089 m .64991 .46213 L .64754 .46233 L F
.488 .198 .399 r
.6501 .46038 m .64991 .46213 L .64767 .46089 L F
.816 .799 .836 r
.47004 .67376 m .473 .67302 L .47198 .67454 L F
0 0 .357 r
.47287 .67193 m .473 .67302 L .47206 .66949 L F
.599 .447 .647 r
.47004 .67376 m .47245 .67308 L .4683 .67163 L F
.959 .92 .569 r
.47287 .67193 m .47244 .67319 L .473 .67302 L F
.599 .447 .647 r
.47245 .67308 m .4732 .67287 L .47248 .67269 L F
.47245 .67308 m .47248 .67269 L .4683 .67163 L F
.959 .92 .569 r
.47244 .67319 m .47198 .67454 L .47237 .67395 L F
.47244 .67319 m .47237 .67395 L .473 .67302 L F
.751 .479 .52 r
.4683 .67163 m .47248 .67269 L .47207 .66959 L F
.774 .763 .843 r
.47197 .6696 m .46898 .66972 L .47206 .66949 L F
.751 .479 .52 r
.47187 .6696 m .47207 .66959 L .47206 .66949 L F
.4683 .67163 m .47207 .66959 L .47187 .6696 L F
.148 .691 .804 r
.46632 .66994 m .46897 .66972 L .47197 .6696 L F
.46897 .66972 m .46898 .66972 L .46907 .66972 L F
.46897 .66972 m .46907 .66972 L .47197 .6696 L F
.751 .479 .52 r
.47248 .67269 m .47287 .67193 L .47206 .66949 L F
.47318 .67287 m .4732 .67287 L .47206 .66949 L F
0 0 .356 r
.47206 .66949 m .4732 .67287 L .47273 .67081 L F
.959 .92 .569 r
.47273 .67081 m .47227 .67311 L .47287 .67193 L F
.599 .447 .647 r
.47245 .67308 m .47198 .67454 L .4732 .67287 L F
.47004 .67376 m .47198 .67454 L .47245 .67308 L F
.959 .92 .569 r
.47273 .6722 m .47198 .67454 L .47287 .67193 L F
.47227 .67311 m .47198 .67454 L .47273 .6722 L F
.751 .479 .52 r
.47248 .67269 m .47318 .67287 L .47287 .67193 L F
0 0 .357 r
.47273 .67081 m .47287 .67193 L .47206 .66949 L F
.518 .195 .359 r
.44379 .59414 m .44573 .59622 L .44537 .59434 L F
.238 .171 .575 r
.44412 .59676 m .44573 .59622 L .44379 .59414 L F
.692 .286 .272 r
.47831 .69856 m .48062 .70083 L .48173 .69871 L F
0 0 0 r
.48482 .69574 m .48173 .69871 L .48329 .69768 L F
.629 .216 .24 r
.48173 .69871 m .48457 .70049 L .48329 .69768 L F
.48173 .69871 m .48062 .70083 L .48457 .70049 L F
0 0 .501 r
.47156 .61618 m .47121 .61844 L .47074 .61744 L F
.541 .747 .971 r
.2366 .55529 m .23623 .55722 L .23449 .55577 L F
.2366 .55529 m .2379 .55679 L .23623 .55722 L F
.468 .334 .615 r
.47606 .69052 m .47711 .6928 L .47616 .69216 L F
.636 .65 .847 r
.47788 .68951 m .47711 .6928 L .47606 .69052 L F
.081 0 .12 r
.52534 .69274 m .52715 .69236 L .52807 .6899 L F
0 0 0 r
.52534 .69274 m .52693 .69306 L .52715 .69236 L F
.52534 .69274 m .5245 .69462 L .52693 .69306 L F
.462 .725 .982 r
.33073 .62184 m .33232 .62329 L .33307 .62177 L F
.179 .373 .819 r
.33232 .62329 m .33494 .62513 L .33307 .62177 L F
.361 .433 .801 r
.45473 .69873 m .45525 .69544 L .45357 .6953 L F
.45473 .69873 m .45634 .69863 L .45525 .69544 L F
.398 .496 .842 r
.45473 .69873 m .45768 .70174 L .45634 .69863 L F
.432 .178 .427 r
.58103 .64863 m .58301 .6479 L .58352 .64527 L F
.051 .024 .503 r
.58301 .6479 m .58315 .64649 L .58352 .64527 L F
.271 0 .112 r
.58126 .64605 m .58352 .64527 L .58411 .6433 L F
.432 .178 .427 r
.58103 .64863 m .58352 .64527 L .58126 .64605 L F
.051 .024 .503 r
.58315 .64649 m .5834 .64396 L .58352 .64527 L F
.271 0 .112 r
.58411 .6433 m .58352 .64527 L .58434 .64308 L F
.211 .356 .793 r
.58434 .64308 m .58334 .63973 L .58534 .64006 L F
.58434 .64308 m .586 .64226 L .58334 .63973 L F
0 0 0 r
.58434 .64308 m .58352 .64527 L .586 .64226 L F
.81 .324 .005 r
.49363 .68387 m .49711 .68709 L .4974 .68462 L F
.878 .464 .226 r
.57801 .60036 m .57693 .60155 L .57614 .59978 L F
.479 .842 .992 r
.58061 .60158 m .57693 .60155 L .57801 .60036 L F
.967 .646 .278 r
.55282 .65266 m .55431 .65506 L .55278 .6519 L F
.604 .323 .463 r
.6308 .46515 m .62999 .46861 L .62744 .46667 L F
.597 .317 .461 r
.63385 .46757 m .6308 .46515 L .63337 .46581 L F
.63385 .46757 m .62999 .46861 L .6308 .46515 L F
.373 .367 .723 r
.54459 .65187 m .54572 .65275 L .54557 .64857 L F
.529 .356 .59 r
.54459 .65187 m .54675 .65439 L .54572 .65275 L F
.064 .593 .866 r
.47442 .6944 m .47633 .69506 L .47565 .69442 L F
.658 .322 .392 r
.49961 .6524 m .50168 .65382 L .49891 .6525 L F
.454 .367 .668 r
.22868 .58457 m .22656 .58303 L .22833 .58149 L F
.22868 .58457 m .22696 .58548 L .22656 .58303 L F
.783 .508 .52 r
.48329 .69768 m .4849 .69841 L .48482 .69574 L F
.927 .757 .651 r
.575 .6457 m .57608 .64927 L .57665 .64675 L F
.427 .246 .531 r
.57665 .64675 m .57608 .64927 L .57867 .64726 L F
0 .177 .621 r
.53818 .62335 m .53916 .62391 L .53727 .62218 L F
.53818 .62335 m .54046 .62488 L .53916 .62391 L F
.22 0 .102 r
.52754 .72792 m .52658 .73019 L .52463 .73006 L F
.523 .826 .5 r
.53003 .7253 m .52861 .72676 L .52754 .72792 L F
0 0 0 r
.52756 .72826 m .52754 .72792 L .52861 .72676 L F
.52756 .72826 m .52658 .73019 L .52754 .72792 L F
.977 .88 .668 r
.65878 .43648 m .65851 .43821 L .6579 .43643 L F
.67 .801 .347 r
.65851 .43821 m .65836 .43831 L .6579 .43643 L F
.721 .503 .595 r
.54659 .62255 m .54965 .62581 L .54997 .62373 L F
.505 .157 .311 r
.54997 .62373 m .54965 .62581 L .55228 .62514 L F
.219 .742 .78 r
.58307 .6223 m .58436 .62188 L .58437 .62202 L F
0 0 .198 r
.58301 .62502 m .58307 .6223 L .58242 .62601 L F
.58301 .62502 m .58436 .62188 L .58307 .6223 L F
.71 .751 .885 r
.58954 .66673 m .59225 .66472 L .5909 .66317 L F
0 .514 .806 r
.20268 .54394 m .20455 .54433 L .20628 .54496 L F
.411 .769 .995 r
.20455 .54433 m .20826 .545 L .20628 .54496 L F
.315 0 0 r
.35285 .58487 m .3552 .58479 L .35676 .58368 L F
.142 0 0 r
.35676 .58368 m .3552 .58479 L .35863 .58362 L F
.466 .349 .636 r
.36342 .61732 m .3619 .62052 L .36122 .61712 L F
.36342 .61732 m .36385 .62009 L .3619 .62052 L F
.842 .976 .876 r
.55305 .6786 m .55207 .67807 L .54944 .68065 L F
.65 .092 0 r
.55305 .6786 m .55373 .67999 L .55207 .67807 L F
.55305 .6786 m .55539 .68058 L .55373 .67999 L F
.566 .32 .502 r
.55541 .67832 m .55539 .68058 L .55305 .6786 L F
.453 .798 .998 r
.4099 .5804 m .41243 .58007 L .41375 .58091 L F
.45 .771 .997 r
.41467 .57962 m .41375 .58091 L .41243 .58007 L F
.41467 .57962 m .41599 .58063 L .41375 .58091 L F
.498 .12 .254 r
.33629 .59007 m .33971 .58793 L .33634 .58934 L F
.33629 .59007 m .33851 .59014 L .33971 .58793 L F
.453 .084 .247 r
.33851 .59014 m .34202 .58755 L .33971 .58793 L F
.687 .542 .683 r
.50262 .64081 m .5053 .64038 L .50486 .63794 L F
.584 .462 .679 r
.5053 .64038 m .50727 .63752 L .50486 .63794 L F
.561 .789 .985 r
.28194 .70141 m .28045 .7023 L .27815 .70093 L F
.404 .835 .686 r
.28194 .70141 m .27967 .70268 L .28045 .7023 L F
.424 .793 .995 r
.42433 .58934 m .42328 .58852 L .4209 .58887 L F
.189 .415 .85 r
.42433 .58934 m .4252 .58764 L .42328 .58852 L F
.42433 .58934 m .42673 .59049 L .4252 .58764 L F
.324 .471 .853 r
.36657 .62165 m .36557 .62333 L .36385 .62009 L F
.404 .576 .908 r
.36657 .62165 m .36763 .62347 L .36557 .62333 L F
.4 .278 .597 r
.77741 .51452 m .77914 .51221 L .77727 .51304 L F
.6 .178 .212 r
.463 .62922 m .46666 .62895 L .46532 .63081 L F
.503 .083 .176 r
.46666 .62895 m .46796 .63105 L .46532 .63081 L F
.46666 .62895 m .46918 .62898 L .46796 .63105 L F
.765 .659 .745 r
.63613 .42471 m .63774 .42623 L .63476 .42644 L F
0 0 0 r
.63707 .42744 m .63476 .42644 L .63774 .42623 L F
.739 .74 .852 r
.63877 .42377 m .63774 .42623 L .63613 .42471 L F
.64 .356 .472 r
.63774 .42623 m .63963 .42757 L .63707 .42744 L F
.423 .154 .399 r
.36793 .60089 m .36622 .59925 L .36844 .59869 L F
.36793 .60089 m .3656 .60228 L .36622 .59925 L F
.672 .541 .698 r
.52778 .66345 m .53013 .66048 L .52858 .66154 L F
.308 .329 .72 r
.19189 .56148 m .19244 .55695 L .18917 .55828 L F
.19189 .56148 m .1936 .56066 L .19244 .55695 L F
.493 .142 .299 r
.53149 .67443 m .53029 .67715 L .52796 .67583 L F
.649 .394 .519 r
.53434 .67298 m .53029 .67715 L .53149 .67443 L F
.384 .124 .391 r
.22006 .60468 m .21876 .60292 L .22044 .60164 L F
.22006 .60468 m .21823 .60566 L .21876 .60292 L F
.574 0 0 r
.53925 .61934 m .54287 .62088 L .54029 .62072 L F
.191 0 0 r
.52737 .72674 m .52861 .72676 L .53003 .7253 L F
.516 .106 .201 r
.52796 .67583 m .53029 .67715 L .52764 .67698 L F
.603 .556 .775 r
.3628 .61427 m .36122 .61712 L .36052 .61472 L F
.3628 .61427 m .36342 .61732 L .36122 .61712 L F
.439 .191 .439 r
.50986 .69017 m .50692 .69516 L .50768 .69268 L F
.18 0 0 r
.36934 .64047 m .37165 .64077 L .36785 .64046 L F
.92 .641 .496 r
.60815 .64586 m .60993 .64679 L .60816 .64343 L F
.942 .814 .69 r
.60758 .64852 m .60993 .64679 L .60815 .64586 L F
.60758 .64852 m .60915 .64945 L .60993 .64679 L F
.933 .746 .627 r
.59337 .61391 m .59474 .61506 L .59541 .61506 L F
.588 .247 .359 r
.53996 .6904 m .53772 .69192 L .53757 .68949 L F
.602 .767 .959 r
.79155 .49968 m .7897 .50175 L .78848 .49928 L F
.79155 .49968 m .79221 .50102 L .7897 .50175 L F
.56 .094 .106 r
.57701 .63625 m .57879 .63649 L .5798 .63498 L F
0 0 .272 r
.5798 .63498 m .58006 .63288 L .57989 .63169 L F
.881 .888 .462 r
.5798 .63498 m .57879 .63649 L .58006 .63288 L F
.545 .676 .924 r
.45011 .59105 m .4494 .59432 L .44786 .59129 L F
.153 0 0 r
.45273 .59501 m .45317 .5951 L .4494 .59432 L F
.545 .676 .924 r
.45011 .59105 m .45273 .59501 L .4494 .59432 L F
.395 .763 .993 r
.58568 .63494 m .58523 .63406 L .58336 .63396 L F
.915 .592 .419 r
.58336 .63396 m .58446 .63694 L .58568 .63494 L F
.963 .887 .502 r
.58446 .63694 m .58523 .63406 L .58568 .63494 L F
0 0 0 r
.39737 .59195 m .39308 .5922 L .39483 .59151 L F
.671 .583 .748 r
.75896 .50091 m .76001 .50437 L .76269 .50381 L F
.979 .763 .543 r
.3433 .63232 m .34279 .63467 L .34135 .6335 L F
.584 .694 .917 r
.3401 .62904 m .3433 .63232 L .34531 .63147 L F
.979 .763 .543 r
.3433 .63232 m .34279 .63467 L .34135 .6335 L F
.26 .046 .388 r
.21425 .61609 m .21198 .61985 L .21271 .61726 L F
.449 .037 .164 r
.49581 .65465 m .49891 .6525 L .49671 .65558 L F
.596 .044 0 r
.49891 .6525 m .4994 .65476 L .49671 .65558 L F
.49891 .6525 m .50168 .65382 L .49971 .65463 L F
.515 .358 .606 r
.49737 .6533 m .49915 .6536 L .49903 .65054 L F
.49697 .65397 m .49818 .65376 L .49737 .6533 L F
.49818 .65376 m .49915 .6536 L .49737 .6533 L F
.596 .044 0 r
.49932 .65441 m .49971 .65463 L .4994 .65476 L F
.49891 .6525 m .49971 .65463 L .49932 .65441 L F
.766 .686 .774 r
.32834 .62556 m .32967 .62808 L .33356 .62581 L F
.617 .579 .789 r
.44412 .59676 m .44497 .59953 L .4474 .59781 L F
.681 .505 .642 r
.5002 .64361 m .50255 .64346 L .50262 .64081 L F
.659 .475 .624 r
.50255 .64346 m .5053 .64038 L .50262 .64081 L F
.71 .899 .964 r
.60029 .66313 m .60404 .6626 L .60273 .66046 L F
.767 .721 .81 r
.60273 .66046 m .60404 .6626 L .6062 .66083 L F
.06 .615 .819 r
.41769 .61666 m .42119 .61706 L .41868 .61688 L F
.4 .416 .761 r
.4674 .71802 m .46445 .7184 L .46469 .71615 L F
.472 .448 .75 r
.46892 .7176 m .4674 .71802 L .46974 .71559 L F
.46892 .7176 m .46821 .71935 L .4674 .71802 L F
.442 .123 .329 r
.4915 .64907 m .49437 .64676 L .49192 .64669 L F
.317 .8 .896 r
.40794 .62006 m .40726 .6207 L .40528 .62124 L F
.40794 .62006 m .40951 .62025 L .40726 .6207 L F
.718 .628 .757 r
.55638 .68382 m .5579 .68722 L .55474 .68688 L F
.744 .473 .521 r
.5579 .68722 m .55432 .68933 L .55474 .68688 L F
.5579 .68722 m .55874 .69051 L .55432 .68933 L F
0 0 .014 r
.55537 .6756 m .55659 .67432 L .55663 .67261 L F
0 0 .034 r
.55589 .67609 m .55537 .6756 L .55541 .67832 L F
.55589 .67609 m .55659 .67432 L .55537 .6756 L F
0 .553 .818 r
.36502 .64234 m .36403 .64197 L .36452 .6424 L F
.439 .192 .441 r
.54016 .6639 m .54224 .66538 L .54522 .66275 L F
.73 .441 .489 r
.79556 .47721 m .79875 .47529 L .79554 .47516 L F
.79556 .47721 m .7991 .47737 L .79875 .47529 L F
.772 .469 .475 r
.79875 .47529 m .7991 .47737 L .8028 .47778 L F
.439 0 .1 r
.39721 .62468 m .40104 .62275 L .39873 .62292 L F
.138 .486 .901 r
.22579 .54869 m .22566 .54995 L .22381 .54787 L F
.22579 .54869 m .22732 .55037 L .22566 .54995 L F
.452 .222 .474 r
.19525 .59656 m .19801 .59313 L .19781 .59429 L F
.583 .229 .334 r
.55081 .60037 m .55312 .60198 L .55082 .60217 L F
.382 .783 .985 r
.55191 .59946 m .55081 .60037 L .54947 .59995 L F
.55191 .59946 m .55407 .60022 L .55081 .60037 L F
.867 .492 .334 r
.59352 .62452 m .59577 .6281 L .59657 .62613 L F
.867 .493 .334 r
.59657 .62613 m .59577 .6281 L .5982 .62851 L F
.217 .498 .903 r
.34631 .63461 m .34752 .63365 L .34531 .63147 L F
.34631 .63461 m .3477 .63362 L .34752 .63365 L F
.525 .479 .748 r
.46451 .68675 m .46604 .68621 L .46602 .68437 L F
.376 0 0 r
.40096 .63452 m .39981 .63566 L .39769 .63516 L F
.311 0 0 r
.40294 .634 m .39981 .63566 L .40096 .63452 L F
.392 .586 .92 r
.64881 .44459 m .64741 .44626 L .64667 .44447 L F
.473 .707 .972 r
.64881 .44459 m .65021 .44625 L .64741 .44626 L F
.435 .156 .389 r
.49465 .67797 m .49709 .67552 L .49474 .6756 L F
.08 .632 .82 r
.33629 .59007 m .33478 .58982 L .33808 .5901 L F
.33629 .59007 m .33808 .5901 L .33851 .59014 L F
.403 0 .102 r
.33458 .59004 m .33629 .59007 L .33634 .58934 L F
.33395 .59028 m .33629 .59007 L .33458 .59004 L F
.456 .886 .863 r
.40982 .5868 m .40889 .58767 L .41135 .58692 L F
.40982 .5868 m .40763 .58774 L .40889 .58767 L F
.684 .557 .704 r
.32668 .62636 m .32967 .62808 L .32834 .62556 L F
.32668 .62636 m .32725 .62934 L .32967 .62808 L F
0 0 0 r
.4589 .6784 m .46043 .6776 L .46127 .67534 L F
.45879 .68122 m .46043 .6776 L .4589 .6784 L F
.503 .368 .63 r
.32644 .59723 m .32879 .59672 L .32832 .5938 L F
.418 .187 .455 r
.3263 .59937 m .32879 .59672 L .32644 .59723 L F
.277 .407 .814 r
.49835 .67922 m .49723 .67744 L .49752 .67956 L F
.49835 .67922 m .49925 .67741 L .49723 .67744 L F
.49835 .67922 m .50097 .67985 L .49925 .67741 L F
.548 .344 .556 r
.65345 .44629 m .65592 .44574 L .65577 .44815 L F
.697 .227 .132 r
.65345 .44629 m .65577 .44815 L .6537 .44733 L F
.616 .687 .893 r
.79835 .5149 m .79977 .51145 L .79754 .51264 L F
.79835 .5149 m .8004 .51439 L .79977 .51145 L F
.578 .675 .906 r
.79835 .5149 m .80185 .51596 L .8004 .51439 L F
.612 .211 .259 r
.48665 .70729 m .48525 .7097 L .48268 .70809 L F
.724 .339 .321 r
.48909 .70967 m .48525 .7097 L .48665 .70729 L F
.404 .52 .861 r
.57942 .65288 m .58132 .65067 L .57856 .6494 L F
.765 .642 .726 r
.57882 .6536 m .58132 .65067 L .57942 .65288 L F
.522 .087 .156 r
.4298 .62514 m .42856 .62619 L .42615 .62592 L F
.519 .025 .021 r
.43209 .62591 m .42856 .62619 L .4298 .62514 L F
.643 .66 .852 r
.79584 .5064 m .79305 .50956 L .79339 .5071 L F
.79584 .5064 m .79708 .5095 L .79305 .50956 L F
.877 .818 .787 r
.57989 .63169 m .58359 .62905 L .58119 .63203 L F
.33 0 .063 r
.52463 .73006 m .52431 .73104 L .52174 .73158 L F
.212 0 .027 r
.52463 .73006 m .52658 .73019 L .52431 .73104 L F
.715 .749 .879 r
.78113 .49023 m .77763 .48961 L .78029 .48918 L F
.63 .818 .972 r
.78029 .48918 m .78337 .48944 L .78113 .49023 L F
.009 0 .025 r
.76082 .49543 m .7631 .49421 L .76344 .49264 L F
.286 .447 .846 r
.22934 .54992 m .22873 .55196 L .22732 .55037 L F
.22934 .54992 m .23093 .55294 L .22873 .55196 L F
.567 .576 .822 r
.36137 .61111 m .36052 .61472 L .35939 .61128 L F
.36137 .61111 m .3628 .61427 L .36052 .61472 L F
0 0 0 r
.50856 .66021 m .50659 .6618 L .50732 .66106 L F
.827 .389 0 r
.80832 .5042 m .80643 .50111 L .80757 .50113 L F
.564 .546 .793 r
.8092 .49708 m .80757 .50113 L .80643 .50111 L F
.8092 .49708 m .81065 .50074 L .80757 .50113 L F
.823 .426 .298 r
.50326 .70172 m .50551 .70438 L .50726 .70451 L F
.563 .337 .531 r
.50728 .70526 m .50693 .70957 L .50461 .70752 L F
.847 .484 .365 r
.50551 .70438 m .506 .70684 L .50726 .70451 L F
.5 .532 .821 r
.50726 .70451 m .50928 .70402 L .50799 .70071 L F
.103 0 0 r
.50726 .70451 m .50802 .7058 L .50928 .70402 L F
.722 .517 .612 r
.50995 .70704 m .50693 .70957 L .50728 .70526 L F
.103 0 0 r
.50726 .70451 m .506 .70684 L .50802 .7058 L F
.248 .733 .926 r
.54694 .64636 m .54782 .64668 L .54713 .64663 L F
.54694 .64636 m .54713 .64663 L .54586 .64655 L F
0 .085 .57 r
.54606 .64543 m .54668 .64597 L .54694 .64636 L F
.248 .733 .926 r
.54694 .64636 m .5489 .64675 L .54782 .64668 L F
.709 .179 0 r
.54929 .64827 m .5489 .64675 L .54694 .64636 L F
0 .085 .57 r
.54668 .64597 m .54929 .64827 L .54694 .64636 L F
.248 .733 .926 r
.54694 .64636 m .54586 .64655 L .54557 .64857 L F
.925 .935 .791 r
.54597 .646 m .54694 .64636 L .54557 .64857 L F
.54606 .64543 m .54694 .64636 L .54597 .646 L F
.709 .179 0 r
.54929 .64827 m .5511 .64875 L .5489 .64675 L F
.566 .022 0 r
.5489 .64675 m .5511 .64875 L .55218 .64946 L F
0 0 .362 r
.47795 .61891 m .47705 .6231 L .47592 .61958 L F
.47795 .61891 m .47836 .62193 L .47705 .6231 L F
0 0 0 r
.47705 .6231 m .47836 .62193 L .47594 .62483 L F
.81 .324 .005 r
.49541 .68551 m .4955 .68636 L .49711 .68709 L F
.856 .705 .693 r
.4955 .68636 m .49737 .68997 L .49711 .68709 L F
.4955 .68636 m .49398 .68926 L .49737 .68997 L F
.42 .188 .455 r
.49758 .68534 m .49566 .6877 L .4955 .68636 L F
.49566 .6877 m .49507 .68842 L .4955 .68636 L F
.81 .324 .005 r
.49363 .68387 m .4955 .68636 L .49541 .68551 L F
.475 .37 .656 r
.47493 .71025 m .47561 .71276 L .47741 .71217 L F
.234 .068 .44 r
.21676 .61091 m .21465 .61428 L .21477 .61164 L F
.72 .691 .822 r
.47661 .61857 m .47592 .61958 L .47367 .62055 L F
.436 .873 .803 r
.47505 .61961 m .47592 .61958 L .47367 .62055 L F
.74 .686 .799 r
.8004 .51439 m .80185 .51596 L .80466 .51319 L F
.709 .484 .582 r
.53673 .67243 m .53434 .67298 L .53323 .67251 L F
.662 .774 .932 r
.66 .44894 m .65741 .44983 L .65577 .44815 L F
0 0 0 r
.22257 .59693 m .22168 .59847 L .22052 .59964 L F
.216 .116 .52 r
.22168 .59847 m .22044 .60164 L .22052 .59964 L F
.588 .247 .359 r
.53996 .6904 m .53984 .69214 L .53772 .69192 L F
.541 .218 .371 r
.54302 .69018 m .53984 .69214 L .53996 .6904 L F
.28 0 0 r
.38671 .63716 m .3858 .63752 L .3835 .63751 L F
.338 0 0 r
.38903 .63689 m .3858 .63752 L .38671 .63716 L F
.958 .71 .522 r
.32725 .62934 m .32573 .63105 L .32724 .63097 L F
0 0 .324 r
.77036 .48702 m .7708 .48858 L .77017 .48699 L F
.598 .778 .966 r
.77429 .48516 m .77036 .48702 L .77017 .48699 L F
.77429 .48516 m .77603 .48669 L .77036 .48702 L F
.442 .123 .329 r
.4915 .64907 m .49454 .64862 L .49437 .64676 L F
.706 .426 .498 r
.49454 .64862 m .49699 .64657 L .49437 .64676 L F
.716 .29 .236 r
.54748 .62628 m .54618 .62794 L .54396 .62574 L F
.481 .022 .083 r
.54968 .62745 m .54618 .62794 L .54748 .62628 L F
.46 0 0 r
.39205 .58119 m .39444 .58178 L .39573 .58136 L F
.022 0 0 r
.39444 .58178 m .39796 .58093 L .39573 .58136 L F
0 .2 .723 r
.45634 .69863 m .45768 .70174 L .45793 .70093 L F
0 0 .394 r
.45768 .70174 m .45887 .70303 L .45793 .70093 L F
.45768 .70174 m .45801 .70423 L .45887 .70303 L F
.327 .76 .97 r
.41135 .58692 m .41511 .58741 L .41364 .58647 L F
.508 .759 .987 r
.41511 .58741 m .41596 .58583 L .41364 .58647 L F
.41511 .58741 m .41736 .58706 L .41596 .58583 L F
.457 0 0 r
.49476 .70481 m .49377 .706 L .4916 .70515 L F
.919 .54 .277 r
.49476 .70481 m .4954 .7073 L .49377 .706 L F
.727 .42 .459 r
.49918 .70635 m .4954 .7073 L .49476 .70481 L F
0 .067 .629 r
.45801 .70423 m .45942 .70756 L .45993 .70692 L F
0 .335 .816 r
.45942 .70756 m .46215 .70936 L .45993 .70692 L F
.199 0 0 r
.37501 .64017 m .37404 .64066 L .37165 .64077 L F
0 0 0 r
.37717 .63935 m .37622 .63997 L .37501 .64017 L F
.37501 .64017 m .37622 .63997 L .37404 .64066 L F
.659 .475 .624 r
.50255 .64346 m .50545 .64318 L .5053 .64038 L F
.584 .462 .679 r
.5053 .64038 m .50781 .63998 L .50727 .63752 L F
.623 .476 .662 r
.50545 .64318 m .50781 .63998 L .5053 .64038 L F
.328 .118 .435 r
.21022 .62793 m .20905 .62628 L .21023 .62552 L F
.21022 .62793 m .20853 .62867 L .20905 .62628 L F
.825 .852 .868 r
.80242 .49026 m .80498 .48961 L .80414 .48835 L F
.762 .99 .888 r
.80729 .48663 m .80414 .48835 L .80498 .48961 L F
.401 .49 .836 r
.46479 .70658 m .46603 .70945 L .46378 .70789 L F
.84 .61 .589 r
.59831 .63704 m .60128 .64007 L .60144 .63797 L F
.773 .709 .792 r
.60508 .6575 m .60273 .66046 L .6062 .66083 L F
.833 .739 .76 r
.60508 .6575 m .6062 .66083 L .60688 .65854 L F
.609 .446 .636 r
.52546 .66389 m .52572 .66673 L .52312 .66683 L F
.52546 .66389 m .52572 .66673 L .52312 .66683 L F
.531 .279 .478 r
.46632 .66994 m .4683 .67163 L .46898 .66972 L F
.46632 .66994 m .4661 .67251 L .4683 .67163 L F
.568 .231 .359 r
.78969 .47738 m .79226 .47709 L .79295 .47504 L F
.69 .355 .404 r
.79226 .47709 m .79556 .47721 L .79295 .47504 L F
.653 .376 .487 r
.79295 .47504 m .79556 .47721 L .79554 .47516 L F
.13 .676 .715 r
.40078 .59141 m .39852 .59174 L .39737 .59195 L F
0 0 0 r
.40263 .59031 m .39852 .59174 L .40078 .59141 L F
0 0 .37 r
.51388 .65422 m .51416 .65478 L .51322 .65308 L F
.482 .115 .266 r
.46265 .61911 m .45852 .62077 L .4604 .62193 L F
.537 .124 .206 r
.4604 .62193 m .46414 .62008 L .46265 .61911 L F
.653 .427 .564 r
.43703 .61642 m .43907 .6169 L .43918 .6144 L F
.735 .497 .568 r
.43918 .6144 m .43907 .6169 L .44253 .61679 L F
.977 .88 .668 r
.65878 .43648 m .65704 .43429 L .65939 .43365 L F
.65878 .43648 m .6579 .43643 L .65704 .43429 L F
.52 .767 .987 r
.66207 .43492 m .65878 .43648 L .65939 .43365 L F
.66207 .43492 m .66309 .43623 L .65878 .43648 L F
.73 .731 .851 r
.49973 .7014 m .50249 .69943 L .50006 .69878 L F
.683 .623 .782 r
.50249 .69943 m .50201 .70197 L .49973 .7014 L F
.609 .04 0 r
.50201 .70197 m .49815 .70043 L .49973 .7014 L F
.50093 .70154 m .50046 .70212 L .49815 .70043 L F
.50201 .70197 m .50157 .70201 L .50093 .70154 L F
.50157 .70201 m .50046 .70212 L .50093 .70154 L F
.683 .623 .782 r
.50249 .69943 m .50024 .70104 L .50006 .69878 L F
.50024 .70104 m .49973 .7014 L .49982 .70073 L F
.50024 .70104 m .49982 .70073 L .50006 .69878 L F
.435 .259 .542 r
.23009 .57617 m .22811 .57917 L .22817 .57679 L F
.661 .112 0 r
.46305 .69663 m .45946 .69403 L .46193 .69473 L F
.856 .474 .322 r
.60472 .64056 m .6057 .6429 L .60816 .64343 L F
.841 .64 .63 r
.6057 .6429 m .60815 .64586 L .60816 .64343 L F
.751 .479 .52 r
.4683 .67163 m .47206 .66949 L .46898 .66972 L F
0 0 .356 r
.47206 .66949 m .4727 .66969 L .47197 .66825 L F
0 0 .357 r
.47273 .67081 m .47206 .66949 L .47401 .66998 L F
0 0 .356 r
.47206 .66949 m .47273 .67081 L .4727 .66969 L F
.319 .582 .937 r
.55794 .66221 m .56003 .6625 L .55889 .66365 L F
0 0 .023 r
.56003 .6625 m .55985 .66426 L .55889 .66365 L F
0 .014 .573 r
.51502 .70166 m .51676 .70369 L .5154 .70229 L F
.32 .09 .4 r
.51676 .70369 m .51509 .70614 L .5154 .70229 L F
.357 .075 .342 r
.48165 .6919 m .48177 .69026 L .48299 .6897 L F
.734 .726 .843 r
.63313 .43715 m .63682 .43823 L .635 .43647 L F
.688 .685 .841 r
.635 .43647 m .63682 .43823 L .63902 .43694 L F
.686 .43 .53 r
.535 .65447 m .53795 .65224 L .53506 .6527 L F
.656 .841 .971 r
.45519 .59414 m .45317 .5951 L .45273 .59501 L F
.659 .766 .929 r
.4732 .67605 m .47673 .67713 L .47571 .67503 L F
.767 .797 .878 r
.47571 .67503 m .47673 .67713 L .47915 .67519 L F
.728 .373 .377 r
.5888 .59912 m .59196 .59797 L .58873 .59665 L F
.5888 .59912 m .59234 .59944 L .59196 .59797 L F
.766 .606 .681 r
.47558 .68424 m .47269 .68651 L .47217 .68407 L F
.47423 .6853 m .47461 .68698 L .47269 .68651 L F
.47558 .68424 m .47504 .68576 L .47423 .6853 L F
.47504 .68576 m .47461 .68698 L .47423 .6853 L F
.564 0 0 r
.47243 .68426 m .47379 .68505 L .47451 .68581 L F
.47217 .68407 m .47361 .68494 L .47243 .68426 L F
.47361 .68494 m .47379 .68505 L .47243 .68426 L F
0 0 .442 r
.47451 .68581 m .47379 .68505 L .474 .6847 L F
.65 .229 .23 r
.47505 .68502 m .47558 .68424 L .47374 .68415 L F
.47505 .68502 m .47374 .68415 L .47396 .68463 L F
.47505 .68502 m .47249 .68408 L .47367 .68457 L F
.412 .549 .883 r
.474 .6847 m .47379 .68505 L .47367 .68457 L F
.477 .597 .894 r
.47367 .68457 m .47379 .68505 L .47217 .68407 L F
.65 .229 .23 r
.47451 .68581 m .47505 .68502 L .47217 .68407 L F
0 0 .442 r
.47451 .68581 m .474 .6847 L .47546 .68229 L F
.65 .229 .23 r
.47396 .68463 m .47374 .68415 L .47249 .68408 L F
.47367 .68457 m .47249 .68408 L .47217 .68407 L F
.412 .549 .883 r
.47546 .68229 m .474 .6847 L .47295 .68146 L F
.474 .6847 m .47367 .68457 L .47295 .68146 L F
.477 .597 .894 r
.47295 .68146 m .47367 .68457 L .47217 .68407 L F
.643 .472 .636 r
.47461 .68698 m .47558 .68424 L .47451 .68581 L F
.47461 .68698 m .4781 .68404 L .47558 .68424 L F
.43 .344 .658 r
.52942 .69588 m .53179 .69793 L .53003 .69858 L F
.641 .084 0 r
.53032 .69737 m .53179 .69793 L .53118 .6974 L F
.53022 .69721 m .53118 .6974 L .52942 .69588 L F
.53032 .69737 m .53118 .6974 L .53022 .69721 L F
.53032 .69737 m .52942 .69588 L .53144 .69532 L F
.384 0 .166 r
.53455 .69314 m .53417 .6948 L .53144 .69532 L F
.153 .692 .72 r
.53417 .6948 m .53287 .69503 L .53144 .69532 L F
.118 0 .074 r
.53144 .69532 m .53287 .69503 L .53032 .69737 L F
.796 .726 .787 r
.53032 .69737 m .53287 .69503 L .53143 .69462 L F
.389 .059 .279 r
.53014 .69677 m .53013 .69679 L .53029 .69679 L F
.728 .57 .677 r
.52808 .69905 m .52343 .70094 L .5236 .6986 L F
.853 .59 .54 r
.52711 .69927 m .53032 .69737 L .53029 .69679 L F
.996 .776 .482 r
.53032 .69737 m .53014 .69677 L .53029 .69679 L F
.53014 .69677 m .52932 .69403 L .53029 .69679 L F
.389 .059 .279 r
.53016 .69674 m .53014 .69677 L .53029 .69679 L F
.796 .726 .787 r
.53014 .69677 m .53143 .69462 L .52932 .69403 L F
.53032 .69737 m .53143 .69462 L .53014 .69677 L F
.389 .059 .279 r
.52874 .69622 m .5284 .69684 L .53013 .69679 L F
.52874 .69622 m .53013 .69679 L .53016 .69674 L F
.5284 .69684 m .52711 .69927 L .52985 .69713 L F
.5284 .69684 m .52985 .69713 L .53029 .69679 L F
.787 .398 .318 r
.62403 .46579 m .62744 .46667 L .62756 .46828 L F
.652 .288 .342 r
.62744 .46667 m .62999 .46861 L .62756 .46828 L F
.741 .322 .254 r
.52442 .64399 m .52277 .64554 L .52027 .64336 L F
.589 .605 .836 r
.52436 .64312 m .52442 .64399 L .52608 .64267 L F
.52436 .64312 m .52277 .64554 L .52442 .64399 L F
.458 0 0 r
.55811 .63537 m .55702 .6347 L .55536 .63351 L F
0 .119 .602 r
.55811 .63537 m .55917 .63605 L .55702 .6347 L F
.55811 .63537 m .56029 .63709 L .55917 .63605 L F
.543 .492 .749 r
.76119 .49798 m .7631 .49421 L .76082 .49543 L F
.553 .509 .761 r
.55202 .68975 m .55338 .68627 L .55474 .68688 L F
.465 .197 .422 r
.55474 .68688 m .55432 .68933 L .55202 .68975 L F
.737 .78 .888 r
.77874 .48511 m .77962 .48743 L .77674 .48633 L F
.556 .289 .466 r
.77962 .48743 m .77763 .48961 L .77674 .48633 L F
.77962 .48743 m .78029 .48918 L .77763 .48961 L F
.85 .832 .829 r
.78241 .48356 m .77962 .48743 L .77874 .48511 L F
.495 .206 .404 r
.52715 .69236 m .53038 .68891 L .52807 .6899 L F
.708 .232 .118 r
.46821 .71935 m .4666 .72043 L .46445 .7184 L F
.658 .351 .441 r
.46892 .7176 m .4666 .72043 L .46821 .71935 L F
.59 .632 .861 r
.79186 .48453 m .79353 .48201 L .79088 .48277 L F
.79186 .48453 m .79451 .48418 L .79353 .48201 L F
.584 .269 .4 r
.46043 .6776 m .46365 .67501 L .46127 .67534 L F
.964 .635 .31 r
.5511 .64875 m .55278 .6519 L .55218 .64946 L F
.658 .162 .06 r
.5567 .67433 m .55933 .67447 L .55659 .67427 L F
.6 .468 .673 r
.55659 .67432 m .55805 .67395 L .55724 .67475 L F
.55659 .67432 m .55724 .67475 L .55589 .67609 L F
.888 .706 .192 r
.55724 .67475 m .55933 .67447 L .5567 .67433 L F
.55902 .67612 m .55906 .67593 L .55724 .67475 L F
.55906 .67593 m .55933 .67447 L .55724 .67475 L F
.55902 .67612 m .55589 .67609 L .55724 .67475 L F
.55902 .67612 m .5567 .67433 L .55659 .67432 L F
.55902 .67612 m .55724 .67475 L .55731 .67467 L F
.658 .162 .06 r
.55659 .67427 m .55933 .67447 L .55663 .67261 L F
.888 .706 .192 r
.55873 .67547 m .55731 .67467 L .55805 .67395 L F
.55902 .67612 m .55731 .67467 L .55873 .67547 L F
.658 .162 .06 r
.55659 .67432 m .5567 .67433 L .55659 .67427 L F
.203 0 0 r
.52307 .63986 m .52127 .6412 L .52038 .64066 L F
0 .169 .619 r
.52127 .6412 m .52258 .64216 L .52038 .64066 L F
.525 .369 .612 r
.52572 .66673 m .52778 .66345 L .52546 .66389 L F
.52572 .66673 m .52778 .66345 L .52546 .66389 L F
.663 .868 .977 r
.55766 .67281 m .55881 .67136 L .55515 .67135 L F
.544 .312 .514 r
.55881 .67136 m .55659 .67432 L .55515 .67135 L F
.829 .813 .327 r
.55849 .67055 m .55831 .6719 L .55881 .67136 L F
.568 .827 .464 r
.55917 .67096 m .55881 .67136 L .55766 .67281 L F
.544 .312 .514 r
.55881 .67136 m .55805 .67395 L .55659 .67432 L F
.829 .813 .327 r
.55831 .6719 m .55805 .67395 L .55881 .67136 L F
.568 .827 .464 r
.56015 .66975 m .55881 .67136 L .55917 .67096 L F
.996 .86 .537 r
.55938 .66897 m .55881 .67136 L .56015 .66975 L F
.319 .025 .299 r
.22833 .58664 m .22696 .58548 L .22868 .58457 L F
.22833 .58664 m .22622 .58742 L .22696 .58548 L F
.037 .196 .701 r
.49476 .68308 m .49363 .68387 L .49273 .6843 L F
.49476 .68308 m .4955 .68636 L .49363 .68387 L F
.316 0 .215 r
.26219 .89913 m .26251 .89906 L .26214 .89922 L F
.469 .808 .999 r
.19941 .56691 m .20053 .56623 L .20186 .5672 L F
.779 .642 .71 r
.19941 .56691 m .20186 .5672 L .20053 .56623 L F
.19941 .56691 m .1995 .57058 L .20186 .5672 L F
.494 .821 1 r
.20186 .5672 m .20053 .56623 L .2031 .56666 L F
0 0 0 r
.45456 .68472 m .45544 .68476 L .45672 .68362 L F
.45456 .68472 m .4531 .68606 L .45544 .68476 L F
.41 .735 .992 r
.3761 .62425 m .37509 .62532 L .37377 .62434 L F
.3761 .62425 m .37729 .62525 L .37509 .62532 L F
.235 .109 .497 r
.2071 .5767 m .2084 .57843 L .20866 .57601 L F
.2071 .5767 m .20707 .57931 L .2084 .57843 L F
.372 .027 .244 r
.36244 .6045 m .36084 .60346 L .3631 .60297 L F
.36244 .6045 m .36025 .60504 L .36084 .60346 L F
.515 .572 .851 r
.77675 .5092 m .77719 .50513 L .77465 .50586 L F
.77675 .5092 m .78035 .50898 L .77719 .50513 L F
0 0 .303 r
.46264 .7104 m .46351 .7117 L .46215 .70936 L F
.46264 .7104 m .46283 .71299 L .46351 .7117 L F
.669 .973 .814 r
.7795 .51008 m .78054 .50856 L .78035 .50898 L F
.541 .525 .787 r
.77914 .51221 m .78054 .50856 L .7795 .51008 L F
.084 0 0 r
.57551 .59558 m .57923 .59376 L .5768 .59383 L F
.523 .331 .562 r
.53884 .65521 m .53895 .65781 L .53637 .65846 L F
.458 .175 .395 r
.53637 .65846 m .53842 .65976 L .53596 .65999 L F
.53637 .65846 m .53895 .65781 L .53842 .65976 L F
.553 .399 .626 r
.49296 .70982 m .49298 .71334 L .49056 .71344 L F
.18 0 .078 r
.49298 .71334 m .4905 .71538 L .49056 .71344 L F
.927 .64 .479 r
.21043 .56693 m .2103 .56456 L .20893 .56713 L F
.634 .405 .553 r
.2103 .56456 m .20893 .56713 L .21043 .56693 L F
.927 .64 .479 r
.21043 .56693 m .20799 .56636 L .2103 .56456 L F
.489 .505 .8 r
.2103 .56456 m .2125 .56417 L .21158 .56236 L F
.21133 .56254 m .21158 .56236 L .2115 .56221 L F
.2103 .56456 m .21158 .56236 L .21133 .56254 L F
.7 .541 .669 r
.21128 .55868 m .21129 .56164 L .2143 .56135 L F
.21129 .56164 m .21129 .56245 L .21156 .56235 L F
.21129 .56164 m .21156 .56235 L .2143 .56135 L F
.765 .916 .539 r
.21145 .5623 m .21011 .56362 L .2103 .56456 L F
0 0 0 r
.21138 .56237 m .21011 .56362 L .21145 .56232 L F
.21129 .56245 m .21011 .56362 L .21138 .56237 L F
.768 .597 .666 r
.20864 .56082 m .21129 .56245 L .21128 .55868 L F
.951 .597 .262 r
.20913 .56088 m .21129 .56245 L .20864 .56082 L F
.20913 .56088 m .21011 .56362 L .21129 .56245 L F
.765 .916 .539 r
.2115 .56221 m .21011 .56362 L .21145 .5623 L F
.959 .625 .327 r
.2118 .563 m .21079 .56336 L .2115 .56221 L F
0 0 .371 r
.2103 .56456 m .21126 .56565 L .2125 .56417 L F
.2103 .56456 m .21043 .56693 L .21126 .56565 L F
.619 .588 .797 r
.20997 .56476 m .21108 .56515 L .21079 .56336 L F
.983 .86 .638 r
.2125 .56417 m .21126 .56565 L .21109 .56535 L F
.2125 .56417 m .21109 .56535 L .21108 .56515 L F
.21125 .56388 m .21108 .56515 L .21105 .56383 L F
.2125 .56417 m .21108 .56515 L .21125 .56388 L F
.378 .211 .524 r
.21167 .56915 m .21353 .56601 L .21108 .56515 L F
.445 .626 .93 r
.20997 .56476 m .21043 .56693 L .21126 .56565 L F
.378 .211 .524 r
.21084 .56702 m .21108 .56515 L .20997 .56476 L F
.21167 .56915 m .21108 .56515 L .21084 .56702 L F
.619 .588 .797 r
.21108 .56515 m .21192 .56544 L .21105 .56383 L F
.21108 .56515 m .21105 .56383 L .21079 .56336 L F
.20997 .56476 m .21079 .56336 L .21011 .56362 L F
.983 .86 .638 r
.21105 .56383 m .21109 .56535 L .21011 .56362 L F
.959 .625 .327 r
.21221 .5641 m .21011 .56362 L .2118 .563 L F
0 0 0 r
.21129 .56245 m .21274 .56125 L .21304 .56127 L F
.21162 .56233 m .21304 .56127 L .2143 .56135 L F
.475 .492 .796 r
.21261 .56143 m .21353 .56601 L .2149 .56509 L F
0 0 0 r
.21145 .56232 m .21088 .56287 L .21274 .56125 L F
.959 .625 .327 r
.21079 .56336 m .21064 .56308 L .2115 .56221 L F
0 0 0 r
.21088 .56287 m .21065 .56309 L .21129 .56253 L F
.21129 .56245 m .21304 .56127 L .21162 .56233 L F
.21088 .56287 m .21129 .56253 L .21274 .56125 L F
.959 .625 .327 r
.21079 .56336 m .21011 .56362 L .21064 .56308 L F
.619 .588 .797 r
.21079 .56336 m .21126 .56258 L .21011 .56362 L F
0 0 0 r
.21126 .56258 m .21011 .56362 L .2114 .56245 L F
.21065 .56309 m .21011 .56362 L .21126 .56258 L F
.959 .625 .327 r
.21152 .56225 m .21152 .56225 L .2115 .56221 L F
.821 .57 .56 r
.21257 .56124 m .21136 .56241 L .20985 .56096 L F
.619 .588 .797 r
.21126 .56258 m .2114 .56245 L .21136 .56241 L F
0 0 0 r
.21065 .56309 m .2114 .56245 L .21274 .56125 L F
.619 .588 .797 r
.21126 .56258 m .21136 .56241 L .21011 .56362 L F
.959 .625 .327 r
.21221 .5641 m .2115 .56221 L .2115 .56221 L F
.821 .57 .56 r
.21274 .56125 m .21011 .56362 L .21257 .56124 L F
.21274 .56125 m .20913 .56088 L .20985 .56016 L F
.619 .588 .797 r
.21224 .56092 m .21228 .56093 L .21226 .56087 L F
.902 .884 .806 r
.21153 .5603 m .21141 .56057 L .21226 .56087 L F
0 .418 .785 r
.21278 .56107 m .21274 .56125 L .21258 .5612 L F
.649 .733 .91 r
.20532 .55749 m .20896 .55982 L .21128 .55868 L F
.768 .597 .666 r
.20894 .55988 m .21128 .55868 L .20896 .55982 L F
.20864 .56082 m .2101 .55964 L .20894 .55988 L F
.2101 .55964 m .21128 .55868 L .20894 .55988 L F
.356 .642 .963 r
.2143 .56135 m .21529 .56034 L .21231 .55917 L F
.649 .733 .91 r
.20532 .55749 m .21128 .55868 L .20893 .55766 L F
.7 .541 .669 r
.21128 .55868 m .21145 .55883 L .21018 .55833 L F
.21193 .55925 m .2143 .56135 L .21155 .55933 L F
.356 .642 .963 r
.21155 .55933 m .21231 .55917 L .21018 .55833 L F
.2143 .56135 m .21231 .55917 L .21155 .55933 L F
.19 0 0 r
.21274 .56125 m .21529 .56034 L .2143 .56135 L F
.21274 .56125 m .2142 .5616 L .21529 .56034 L F
0 .418 .785 r
.21282 .56087 m .2142 .5616 L .21274 .56125 L F
.475 .492 .796 r
.21269 .56103 m .2149 .56509 L .2142 .5616 L F
.21226 .56087 m .21231 .56094 L .21269 .56103 L F
0 .418 .785 r
.21278 .56107 m .21258 .5612 L .21224 .56092 L F
.475 .492 .796 r
.21231 .56094 m .2149 .56509 L .21269 .56103 L F
0 .418 .785 r
.21224 .56092 m .21224 .56092 L .21074 .5605 L F
.21224 .56092 m .21258 .5612 L .21117 .56066 L F
.21224 .56092 m .21117 .56066 L .21074 .5605 L F
.821 .57 .56 r
.21136 .56241 m .21011 .56362 L .20985 .56096 L F
.619 .588 .797 r
.21136 .56241 m .21224 .56092 L .21011 .56362 L F
.21224 .56092 m .21226 .56087 L .21223 .56091 L F
.21224 .56092 m .21223 .56091 L .21011 .56362 L F
0 .418 .785 r
.21208 .56086 m .21074 .5605 L .20985 .56016 L F
.21278 .56107 m .21222 .56091 L .21208 .56086 L F
.21222 .56091 m .21074 .5605 L .21208 .56086 L F
.821 .57 .56 r
.20985 .56096 m .21011 .56362 L .20913 .56088 L F
.655 .496 .657 r
.20809 .56114 m .20841 .56481 L .21136 .56055 L F
.21097 .56044 m .21136 .56055 L .21153 .5603 L F
0 .418 .785 r
.21125 .5605 m .211 .56052 L .21097 .56043 L F
.655 .496 .657 r
.20809 .56114 m .21136 .56055 L .21097 .56044 L F
0 .418 .785 r
.2112 .5605 m .21211 .56087 L .211 .56052 L F
.21125 .5605 m .21136 .56055 L .2112 .5605 L F
.21136 .56055 m .21211 .56087 L .2112 .5605 L F
.21097 .56043 m .211 .56052 L .20985 .56016 L F
.655 .496 .657 r
.20809 .56114 m .21097 .56044 L .21011 .56042 L F
.406 0 0 r
.21128 .55868 m .21018 .55833 L .20893 .55766 L F
.281 0 0 r
.21529 .56034 m .20985 .56016 L .21018 .55833 L F
.21529 .56034 m .21397 .56072 L .20985 .56016 L F
.497 .609 .894 r
.20985 .56016 m .21397 .56072 L .21137 .55784 L F
.436 .528 .853 r
.21137 .55784 m .21237 .55994 L .20985 .56016 L F
.655 .496 .657 r
.21097 .56044 m .21153 .5603 L .21128 .56032 L F
.21097 .56044 m .21128 .56032 L .21097 .56043 L F
.902 .884 .806 r
.21153 .5603 m .21136 .56055 L .21141 .56057 L F
0 .427 .793 r
.21226 .56087 m .21282 .56087 L .21153 .5603 L F
.436 .528 .853 r
.21128 .56032 m .21282 .56087 L .21097 .56043 L F
.21237 .55994 m .21097 .56043 L .20985 .56016 L F
.655 .496 .657 r
.21097 .56043 m .21128 .56032 L .21095 .56035 L F
.21097 .56044 m .21095 .56035 L .21011 .56042 L F
.902 .884 .806 r
.21141 .56057 m .20841 .56481 L .21011 .56362 L F
.21136 .56055 m .20841 .56481 L .21141 .56057 L F
.21141 .56057 m .21223 .56091 L .21226 .56087 L F
0 .418 .785 r
.21282 .56087 m .21211 .56087 L .21125 .5605 L F
.79 .538 .556 r
.21205 .5606 m .21045 .56048 L .21128 .56032 L F
.21282 .56087 m .21222 .56078 L .21205 .5606 L F
.21222 .56078 m .21045 .56048 L .21205 .5606 L F
0 .418 .785 r
.21282 .56087 m .21278 .56107 L .21268 .56104 L F
0 .427 .793 r
.21226 .56087 m .21269 .56103 L .21282 .56087 L F
0 .418 .785 r
.21282 .56087 m .21268 .56104 L .21211 .56087 L F
0 .427 .793 r
.21269 .56103 m .2142 .5616 L .21282 .56087 L F
.577 .729 .947 r
.21469 .56051 m .2142 .5616 L .21282 .56087 L F
.672 .449 .574 r
.2142 .5616 m .21715 .55938 L .21529 .56034 L F
.2142 .5616 m .21701 .5618 L .21715 .55938 L F
.577 .729 .947 r
.21469 .56051 m .21701 .5618 L .2142 .5616 L F
.719 .279 .207 r
.21701 .5618 m .21282 .56087 L .2142 .5616 L F
.051 .171 .67 r
.2142 .5616 m .21473 .56425 L .21563 .56352 L F
.21473 .56425 m .2149 .56509 L .21563 .56352 L F
.217 .427 .852 r
.21563 .56352 m .2169 .5626 L .21669 .56265 L F
.654 .345 .437 r
.2142 .5616 m .21563 .56352 L .21701 .5618 L F
.965 .925 .706 r
.21563 .56352 m .21485 .56307 L .21701 .5618 L F
.217 .427 .852 r
.21563 .56352 m .21669 .56265 L .21485 .56307 L F
.719 .279 .207 r
.21701 .5618 m .21485 .56307 L .21282 .56087 L F
.902 .884 .806 r
.21141 .56057 m .21011 .56362 L .21223 .56091 L F
.619 .588 .797 r
.21136 .56241 m .21244 .56157 L .21228 .56093 L F
.21136 .56241 m .21228 .56093 L .21224 .56092 L F
.475 .492 .796 r
.21226 .56087 m .21244 .56157 L .21261 .56143 L F
.21244 .56157 m .21353 .56601 L .21261 .56143 L F
.959 .625 .327 r
.2125 .56417 m .21221 .5641 L .21152 .56225 L F
.2125 .56417 m .21152 .56225 L .21152 .56225 L F
.619 .588 .797 r
.21079 .56336 m .21353 .56601 L .21244 .56157 L F
.79 .538 .556 r
.21282 .56087 m .21261 .56176 L .21011 .56042 L F
.803 .991 .747 r
.21567 .55855 m .21397 .56072 L .21529 .56034 L F
.717 .674 .807 r
.21137 .55784 m .21397 .56072 L .21567 .55855 L F
.691 .665 .82 r
.21469 .56051 m .21282 .56087 L .21137 .55784 L F
.613 .091 0 r
.21282 .56087 m .21485 .56307 L .21337 .56183 L F
.691 .665 .82 r
.21469 .56051 m .21137 .55784 L .21567 .55855 L F
0 0 .51 r
.21257 .56113 m .21337 .56183 L .21241 .55853 L F
.613 .091 0 r
.21282 .56087 m .21337 .56183 L .21261 .56176 L F
0 0 .51 r
.21261 .56176 m .21326 .56182 L .21257 .56113 L F
.21326 .56182 m .21337 .56183 L .21257 .56113 L F
.79 .538 .556 r
.21282 .56087 m .21128 .56032 L .21153 .5603 L F
0 0 .51 r
.21179 .56089 m .21241 .55853 L .21015 .55915 L F
.21261 .56176 m .21257 .56113 L .21179 .56089 L F
.436 .528 .853 r
.21237 .55994 m .21282 .56087 L .21128 .56032 L F
0 0 .51 r
.21257 .56113 m .21241 .55853 L .21179 .56089 L F
.79 .538 .556 r
.21045 .56048 m .21011 .56042 L .21023 .56041 L F
.21045 .56048 m .21023 .56041 L .21128 .56032 L F
.619 .588 .797 r
.2114 .56245 m .21244 .56157 L .21136 .56241 L F
.21079 .56336 m .21244 .56157 L .21126 .56258 L F
.21192 .56544 m .21353 .56601 L .21079 .56336 L F
.71 .952 .669 r
.21011 .56362 m .20799 .56636 L .2103 .56456 L F
.072 0 .454 r
.54003 .65728 m .53884 .65521 L .54075 .65452 L F
.54003 .65728 m .53895 .65781 L .53884 .65521 L F
0 .245 .755 r
.33256 .6374 m .33309 .63652 L .33093 .63461 L F
.694 .393 .461 r
.33521 .63796 m .33449 .63988 L .33256 .6374 L F
0 .154 .689 r
.33256 .6374 m .33449 .63988 L .33309 .63652 L F
.883 .716 .67 r
.60758 .64852 m .60918 .65144 L .60915 .64945 L F
.578 .242 .364 r
.51721 .68428 m .51372 .68856 L .5135 .68736 L F
.51721 .68428 m .51621 .68871 L .51372 .68856 L F
.228 .042 .408 r
.51933 .68256 m .51917 .68428 L .51721 .68428 L F
.51933 .68256 m .51721 .68428 L .51751 .68414 L F
.514 .261 .469 r
.51917 .68428 m .51621 .68871 L .51721 .68428 L F
.638 .75 .93 r
.48647 .65468 m .48757 .65591 L .48959 .65488 L F
.451 .339 .635 r
.47711 .6928 m .4773 .69527 L .47616 .69216 L F
.702 .372 .414 r
.4998 .70348 m .5019 .70352 L .50326 .70172 L F
.767 .456 .461 r
.5019 .70352 m .50551 .70438 L .50326 .70172 L F
.894 .689 .619 r
.48876 .71616 m .48511 .71752 L .48457 .71515 L F
.48876 .71616 m .48813 .71912 L .48511 .71752 L F
.764 .552 .61 r
.48964 .71861 m .48813 .71912 L .48876 .71616 L F
.69 .629 .782 r
.4905 .71538 m .48964 .71861 L .48876 .71616 L F
.593 .045 0 r
.45338 .62635 m .45241 .62725 L .45232 .62509 L F
.45338 .62635 m .45575 .62788 L .45241 .62725 L F
.52 .731 .97 r
.4399 .58407 m .43865 .58553 L .43698 .58358 L F
.344 .461 .836 r
.4399 .58407 m .44134 .58689 L .43865 .58553 L F
.488 .22 .434 r
.50279 .67471 m .50508 .67437 L .50305 .67273 L F
.515 .212 .391 r
.50305 .67273 m .50508 .67437 L .50554 .67249 L F
.641 .205 .197 r
.50461 .70752 m .50329 .70926 L .50119 .7075 L F
.699 .274 .235 r
.50693 .70957 m .50329 .70926 L .50461 .70752 L F
.657 .251 .262 r
.55433 .62498 m .55809 .62527 L .55567 .62346 L F
.653 .105 0 r
.55567 .62346 m .55809 .62527 L .56 .6257 L F
.511 .583 .863 r
.5116 .64612 m .51242 .64964 L .50994 .64949 L F
.623 .335 .459 r
.51107 .65051 m .50994 .64949 L .51242 .64964 L F
.51107 .65051 m .50985 .65172 L .50994 .64949 L F
.187 0 0 r
.79947 .51004 m .8006 .51026 L .79708 .5095 L F
.626 .589 .792 r
.80191 .50601 m .8006 .51026 L .79947 .51004 L F
.627 .895 .987 r
.80605 .50535 m .80191 .50601 L .80527 .5047 L F
.933 .886 .763 r
.80516 .50489 m .80605 .50535 L .80527 .5047 L F
.626 .589 .792 r
.80191 .50601 m .80379 .50926 L .8006 .51026 L F
.756 .638 .73 r
.80605 .50535 m .80402 .50967 L .80191 .50601 L F
.933 .886 .763 r
.80272 .50884 m .80451 .50696 L .80516 .50489 L F
.80451 .50696 m .80605 .50535 L .80516 .50489 L F
.626 .589 .792 r
.80379 .50926 m .80402 .50967 L .80364 .50974 L F
.80379 .50926 m .80364 .50974 L .8006 .51026 L F
.528 0 0 r
.7991 .47737 m .8025 .47889 L .8028 .47778 L F
.785 .283 0 r
.8025 .47889 m .80472 .4803 L .8028 .47778 L F
.915 .764 .679 r
.61252 .45916 m .61076 .46253 L .6096 .45916 L F
.681 .334 .381 r
.54864 .67752 m .55166 .67616 L .54966 .67505 L F
.54864 .67752 m .55207 .67807 L .55166 .67616 L F
.691 .515 .643 r
.61795 .46556 m .61434 .46311 L .61792 .46343 L F
.631 .383 .523 r
.61792 .46343 m .62022 .46547 L .61795 .46556 L F
.661 .374 .473 r
.62043 .46358 m .62022 .46547 L .61792 .46343 L F
.952 .856 .709 r
.5854 .61066 m .58665 .61159 L .58574 .61427 L F
.765 .941 .939 r
.47253 .61987 m .47661 .61857 L .47505 .61961 L F
.765 .987 .753 r
.47627 .61812 m .47592 .61958 L .47505 .61961 L F
.661 .607 .784 r
.47835 .61712 m .47592 .61958 L .47661 .61857 L F
.765 .987 .753 r
.47627 .61812 m .47592 .61958 L .47505 .61961 L F
.702 .678 .824 r
.47835 .61712 m .47795 .61891 L .47592 .61958 L F
.443 0 0 r
.36463 .58383 m .36691 .58408 L .36849 .58293 L F
.059 0 0 r
.36691 .58408 m .37061 .58276 L .36849 .58293 L F
.709 .537 .654 r
.72897 .48904 m .73117 .48634 L .72906 .48678 L F
.72897 .48904 m .73278 .48961 L .73117 .48634 L F
.681 .525 .668 r
.73117 .48634 m .73278 .48961 L .73499 .48676 L F
.762 .99 .888 r
.80729 .48663 m .80708 .48587 L .80414 .48835 L F
.719 .462 0 r
.8065 .48317 m .80708 .48587 L .80729 .48663 L F
.881 .764 .729 r
.55742 .68163 m .55638 .68382 L .55539 .68058 L F
.627 .584 .786 r
.26214 .89922 m .26251 .89906 L .26209 .89909 L F
.802 .695 .748 r
.80402 .50967 m .80666 .51005 L .80605 .50535 L F
.804 .688 .737 r
.80466 .51319 m .80666 .51005 L .80402 .50967 L F
.799 .722 .779 r
.80666 .51005 m .80703 .50587 L .80605 .50535 L F
.80666 .51005 m .80896 .50711 L .80703 .50587 L F
.364 .342 .701 r
.45357 .6953 m .45456 .69165 L .45263 .69368 L F
.227 .717 .923 r
.18964 .5534 m .18598 .55296 L .1858 .55297 L F
.096 .638 .845 r
.18964 .5534 m .18783 .55303 L .18598 .55296 L F
0 .208 .708 r
.18964 .5534 m .18998 .55313 L .18783 .55303 L F
.18964 .5534 m .19249 .55575 L .18998 .55313 L F
.131 0 0 r
.44748 .61661 m .44985 .6164 L .45112 .61541 L F
0 0 0 r
.45112 .61541 m .45185 .61546 L .45258 .61649 L F
.45112 .61541 m .44985 .6164 L .45185 .61546 L F
.637 .538 .726 r
.75896 .50091 m .76119 .49798 L .75872 .49867 L F
.75896 .50091 m .76181 .50046 L .76119 .49798 L F
.671 .583 .748 r
.75896 .50091 m .76269 .50381 L .76181 .50046 L F
.321 0 0 r
.40935 .63112 m .40847 .63201 L .40615 .63235 L F
.369 0 .068 r
.41172 .63073 m .40847 .63201 L .40935 .63112 L F
.422 .379 .705 r
.58165 .65773 m .58215 .66145 L .58437 .65987 L F
.458 .445 .757 r
.58215 .66145 m .58496 .66312 L .58437 .65987 L F
.59 .552 .78 r
.76181 .50046 m .76269 .50381 L .76456 .50106 L F
.625 .598 .803 r
.76269 .50381 m .76595 .50459 L .76456 .50106 L F
.971 .656 .307 r
.59296 .60859 m .59285 .61043 L .59443 .61097 L F
.998 .85 .556 r
.59258 .61222 m .59443 .61097 L .59285 .61043 L F
.59258 .61222 m .59337 .61391 L .59443 .61097 L F
.443 .317 .613 r
.32436 .60307 m .32628 .60258 L .3263 .59937 L F
.476 .395 .685 r
.32486 .60546 m .32628 .60258 L .32436 .60307 L F
.505 .087 .182 r
.4604 .62193 m .45852 .62077 L .45816 .62228 L F
.244 .352 .775 r
.53847 .64578 m .53811 .64922 L .53585 .64793 L F
0 .034 .593 r
.53811 .64922 m .53829 .64865 L .53585 .64793 L F
.499 .342 .599 r
.53811 .64922 m .53795 .65224 L .5401 .6516 L F
0 .563 .786 r
.18319 .54211 m .18518 .54227 L .18676 .54267 L F
.438 0 0 r
.18518 .54227 m .1888 .54268 L .18676 .54267 L F
.306 .68 .976 r
.22198 .54673 m .22164 .54781 L .22025 .54618 L F
.22198 .54673 m .22381 .54787 L .22164 .54781 L F
.295 0 0 r
.63707 .42744 m .63939 .42811 L .63654 .42855 L F
.63707 .42744 m .63963 .42757 L .63939 .42811 L F
.854 .833 .825 r
.80896 .50711 m .81007 .50284 L .80703 .50587 L F
.80896 .50711 m .81132 .5042 L .81007 .50284 L F
.462 .007 .084 r
.53282 .68873 m .53644 .68711 L .5319 .68789 L F
.53289 .6887 m .53518 .68884 L .53644 .68711 L F
.634 .194 .188 r
.53644 .68711 m .53518 .68884 L .53866 .68855 L F
.565 .079 .061 r
.53518 .68884 m .53803 .69062 L .53866 .68855 L F
.548 .127 .194 r
.53706 .68895 m .53518 .68884 L .53449 .68812 L F
.53736 .68905 m .53518 .68884 L .53706 .68895 L F
.462 .007 .084 r
.53282 .68873 m .53518 .68884 L .53289 .6887 L F
.712 .96 .694 r
.52675 .67665 m .52468 .67847 L .52583 .67662 L F
.035 0 .074 r
.54258 .71523 m .53962 .71825 L .53933 .71591 L F
.95 .679 .225 r
.4677 .6254 m .46765 .62331 L .46747 .62411 L F
.503 .253 .468 r
.4677 .6254 m .47068 .62309 L .46765 .62331 L F
.673 .545 .701 r
.52928 .65881 m .53183 .6545 L .5316 .65503 L F
.234 .068 .44 r
.21676 .61091 m .21648 .61358 L .21465 .61428 L F
.037 0 .223 r
.21648 .61358 m .21425 .61609 L .21465 .61428 L F
.597 .35 .513 r
.50005 .64574 m .50255 .64346 L .5002 .64361 L F
.034 0 .386 r
.22622 .58742 m .22494 .59098 L .22435 .58821 L F
.389 0 0 r
.3835 .63751 m .38191 .63902 L .3797 .63897 L F
.473 .007 .065 r
.3858 .63752 m .38191 .63902 L .3835 .63751 L F
.942 .775 .647 r
.20133 .58844 m .19939 .59002 L .19943 .58768 L F
.20133 .58844 m .20106 .59124 L .19939 .59002 L F
.401 .059 .266 r
.49918 .70635 m .49533 .70963 L .4954 .7073 L F
.49918 .70635 m .49753 .70928 L .49533 .70963 L F
.191 0 0 r
.50119 .7075 m .49753 .70928 L .49918 .70635 L F
.763 .403 .374 r
.52924 .66904 m .53123 .67175 L .53267 .66963 L F
.72 .274 .192 r
.45939 .62857 m .463 .62922 L .46158 .6307 L F
.614 .143 .112 r
.46158 .6307 m .463 .62922 L .46532 .63081 L F
.656 .841 .971 r
.45519 .59414 m .45273 .59501 L .45529 .59428 L F
0 .272 .694 r
.45011 .59105 m .45529 .59428 L .45273 .59501 L F
.378 .178 .478 r
.22441 .59592 m .22291 .59423 L .22476 .59353 L F
.22441 .59592 m .22257 .59693 L .22291 .59423 L F
.78 .276 0 r
.33593 .63111 m .33955 .63434 L .3382 .6351 L F
.211 0 .036 r
.52068 .73 m .5227 .72971 L .52397 .72714 L F
.328 0 .088 r
.52397 .72714 m .52517 .72826 L .52737 .72674 L F
.52397 .72714 m .5227 .72971 L .52517 .72826 L F
.262 0 0 r
.33067 .59081 m .33337 .59058 L .33395 .59028 L F
.473 .871 .964 r
.33337 .59058 m .33629 .59007 L .33395 .59028 L F
.537 .399 .64 r
.44847 .60281 m .45117 .60295 L .45076 .59986 L F
.626 .22 0 r
.46469 .71615 m .4643 .71554 L .46283 .71299 L F
0 .136 .661 r
.46445 .7184 m .4643 .71554 L .46469 .71615 L F
0 .46 .777 r
.46077 .69414 m .45946 .69403 L .45804 .692 L F
.46077 .69414 m .46193 .69473 L .45946 .69403 L F
.699 .773 .909 r
.51839 .73247 m .52068 .73 L .51853 .73087 L F
.51839 .73247 m .52174 .73158 L .52068 .73 L F
.076 .628 .822 r
.51841 .73223 m .52028 .73225 L .51843 .73207 L F
0 0 0 r
.51853 .73087 m .5184 .73236 L .51841 .73223 L F
.955 .658 .431 r
.51841 .73223 m .51665 .73189 L .51853 .73087 L F
.076 .628 .822 r
.51841 .73223 m .51843 .73207 L .51665 .73189 L F
0 0 0 r
.5184 .73236 m .51839 .73247 L .51841 .73223 L F
.465 .519 .829 r
.43326 .58967 m .43366 .59159 L .43543 .58965 L F
.675 .576 .736 r
.77763 .48961 m .77537 .49247 L .77392 .48871 L F
.351 .028 .269 r
.19438 .57426 m .19604 .57435 L .19663 .57282 L F
.614 .581 .793 r
.19434 .57741 m .19604 .57435 L .19438 .57426 L F
.364 .237 .572 r
.2321 .57091 m .23195 .57324 L .23025 .57376 L F
.394 .215 .517 r
.23182 .57543 m .23025 .57376 L .23195 .57324 L F
.23182 .57543 m .23009 .57617 L .23025 .57376 L F
.504 .069 .147 r
.41781 .62873 m .41642 .6306 L .41421 .63049 L F
.256 0 0 r
.42015 .62833 m .41642 .6306 L .41781 .62873 L F
.682 .849 .963 r
.78583 .51389 m .78293 .51507 L .78657 .51499 L F
.34 .653 .969 r
.78657 .51499 m .78796 .51399 L .78583 .51389 L F
.331 .635 .963 r
.78923 .5155 m .78796 .51399 L .78657 .51499 L F
.826 .718 .745 r
.54419 .64276 m .54586 .64655 L .54215 .64581 L F
.788 .599 .645 r
.54557 .64857 m .54215 .64581 L .54586 .64655 L F
0 .032 .603 r
.54419 .64276 m .54606 .64543 L .54586 .64655 L F
.925 .935 .791 r
.54606 .64543 m .54557 .64857 L .54586 .64655 L F
.645 .207 .195 r
.48799 .70265 m .48986 .70346 L .49091 .70146 L F
.393 0 .077 r
.49091 .70146 m .49246 .7029 L .49526 .70071 L F
.49091 .70146 m .48986 .70346 L .49246 .7029 L F
.851 .806 .806 r
.63613 .42471 m .63313 .42522 L .63534 .42349 L F
.63613 .42471 m .63476 .42644 L .63313 .42522 L F
.602 .908 .982 r
.63759 .42294 m .63613 .42471 L .63534 .42349 L F
.63759 .42294 m .63877 .42377 L .63613 .42471 L F
.525 .742 .974 r
.4267 .58011 m .42573 .58193 L .42433 .58061 L F
.4267 .58011 m .42811 .58154 L .42573 .58193 L F
.744 .721 .83 r
.57939 .65668 m .57867 .65887 L .58165 .65773 L F
.427 .709 .982 r
.58165 .65773 m .58347 .65735 L .57939 .65668 L F
.422 .379 .705 r
.58165 .65773 m .58437 .65987 L .58347 .65735 L F
.5 .611 .894 r
.35611 .6376 m .35978 .63988 L .3578 .63726 L F
.482 .715 .973 r
.35978 .63988 m .36091 .63831 L .3578 .63726 L F
.35978 .63988 m .36199 .63967 L .36091 .63831 L F
.864 .857 .832 r
.57763 .65791 m .57867 .65887 L .57939 .65668 L F
.179 .714 .756 r
.37672 .5822 m .37895 .58178 L .38048 .58161 L F
.355 0 0 r
.37895 .58178 m .3826 .58213 L .38048 .58161 L F
.4 .278 .597 r
.77741 .51452 m .77947 .51465 L .77914 .51221 L F
.709 .484 .582 r
.53673 .67243 m .53627 .67498 L .53434 .67298 L F
.444 .242 .509 r
.53976 .67374 m .53673 .67243 L .53843 .67292 L F
.53976 .67374 m .53627 .67498 L .53673 .67243 L F
.745 .515 .583 r
.62393 .46338 m .62022 .46547 L .62043 .46358 L F
.62393 .46338 m .62403 .46579 L .62022 .46547 L F
.729 .476 .545 r
.6447 .4632 m .64193 .46509 L .64182 .46359 L F
.578 .717 .938 r
.79814 .48864 m .79907 .49027 L .80205 .48965 L F
.606 .67 .885 r
.79907 .49027 m .80242 .49026 L .80205 .48965 L F
0 0 0 r
.54298 .71393 m .54516 .71316 L .54308 .71295 L F
.093 0 .314 r
.20616 .63392 m .20615 .63647 L .2046 .63749 L F
0 0 .263 r
.20798 .63093 m .20616 .63392 L .20701 .63155 L F
.20798 .63093 m .20749 .63343 L .20616 .63392 L F
.271 .149 .524 r
.20749 .63343 m .20615 .63647 L .20616 .63392 L F
.771 .798 .875 r
.25014 .78103 m .2478 .7815 L .25137 .78188 L F
.375 .204 .517 r
.25137 .78188 m .25288 .78205 L .25306 .7795 L F
.25137 .78188 m .25288 .78205 L .25306 .7795 L F
.325 .419 .805 r
.25014 .78103 m .25288 .78205 L .25137 .78188 L F
.25137 .78188 m .25288 .78205 L .25014 .78103 L F
.908 .646 .529 r
.63104 .43563 m .63313 .43715 L .63265 .43411 L F
.63099 .43577 m .63313 .43715 L .63104 .43563 L F
.824 .743 .775 r
.63093 .43573 m .63243 .43925 L .63313 .43715 L F
.63093 .43573 m .62938 .43885 L .63243 .43925 L F
0 0 .063 r
.63159 .43538 m .63093 .43741 L .63028 .43801 L F
.63064 .43686 m .63028 .43801 L .62938 .43885 L F
.63159 .43538 m .63028 .43801 L .63064 .43686 L F
.908 .646 .529 r
.63093 .43573 m .63099 .43577 L .63104 .43563 L F
.648 .56 .742 r
.63229 .43159 m .63265 .43411 L .63551 .43372 L F
.714 .515 .619 r
.63265 .43411 m .635 .43647 L .63551 .43372 L F
.63265 .43411 m .63313 .43715 L .635 .43647 L F
.843 .448 .298 r
.56 .6257 m .56161 .62833 L .56346 .62835 L F
.356 0 0 r
.56161 .62833 m .56547 .62932 L .56346 .62835 L F
.529 .795 .994 r
.43698 .58358 m .43598 .58469 L .43402 .58358 L F
.754 .633 .727 r
.33728 .63705 m .33449 .63988 L .33521 .63796 L F
.75 .993 .813 r
.51376 .64275 m .51439 .643 L .51667 .6408 L F
.5 .409 .684 r
.51439 .643 m .51566 .64701 L .51666 .64619 L F
.325 .302 .679 r
.51692 .64503 m .51566 .64701 L .51439 .643 L F
.645 .214 .21 r
.51373 .64419 m .5134 .64513 L .51692 .64503 L F
.321 .793 .925 r
.51692 .64503 m .51321 .64513 L .51537 .64477 L F
.419 .097 .311 r
.51537 .64477 m .51331 .64539 L .51475 .64643 L F
.51331 .64539 m .51219 .64574 L .5131 .64599 L F
.51331 .64539 m .5131 .64599 L .51475 .64643 L F
.645 .214 .21 r
.51439 .643 m .51373 .64419 L .51692 .64503 L F
.51373 .64419 m .51321 .64513 L .5134 .64513 L F
.647 .558 .74 r
.51439 .643 m .51851 .64476 L .51667 .6408 L F
.462 .29 .561 r
.50057 .66133 m .5027 .66286 L .50332 .66068 L F
.952 .856 .709 r
.5854 .61066 m .58574 .61427 L .58306 .61362 L F
.859 .698 .681 r
.58306 .61362 m .58574 .61427 L .58462 .61671 L F
.637 .733 .917 r
.46604 .68621 m .46984 .68701 L .46823 .68388 L F
.496 .286 .524 r
.46984 .68701 m .46802 .68974 L .46975 .6881 L F
.635 .804 .964 r
.46984 .68701 m .47163 .68494 L .46823 .68388 L F
.429 0 .1 r
.47136 .68849 m .46984 .68701 L .46975 .6881 L F
.47136 .68849 m .47269 .68651 L .46984 .68701 L F
.913 .949 .808 r
.47501 .61344 m .47156 .61618 L .47361 .61393 L F
.561 .093 .1 r
.47361 .61393 m .4772 .61334 L .47501 .61344 L F
.467 .564 .87 r
.64615 .4328 m .64421 .43446 L .64418 .43294 L F
.019 0 .266 r
.64615 .4328 m .64455 .43594 L .64421 .43446 L F
.198 0 0 r
.42957 .61664 m .43324 .6174 L .43069 .61684 L F
.209 .696 .927 r
.1929 .54289 m .19507 .54292 L .19695 .54352 L F
0 .527 .839 r
.19507 .54292 m .19867 .54409 L .19695 .54352 L F
.282 .757 .934 r
.37061 .58276 m .37313 .58253 L .37457 .583 L F
.409 .848 .934 r
.37313 .58253 m .37672 .5822 L .37457 .583 L F
.569 .143 .193 r
.52746 .63654 m .53092 .63478 L .52711 .6348 L F
.52746 .63654 m .52972 .63661 L .53092 .63478 L F
.34 0 0 r
.52972 .63661 m .53403 .63628 L .53092 .63478 L F
.672 .753 .912 r
.50496 .66017 m .50659 .6618 L .50856 .66021 L F
.597 .35 .513 r
.50005 .64574 m .5025 .64566 L .50255 .64346 L F
.683 .455 .57 r
.5025 .64566 m .50545 .64318 L .50255 .64346 L F
.619 .843 .985 r
.44025 .5898 m .44344 .59227 L .44506 .59106 L F
.795 .864 .9 r
.24463 .78505 m .24646 .78601 L .24824 .78394 L F
.729 .314 .261 r
.60128 .64007 m .60341 .64203 L .60472 .64056 L F
.839 .468 .351 r
.60341 .64203 m .6057 .6429 L .60472 .64056 L F
.548 .787 .987 r
.50883 .67986 m .508 .68166 L .50644 .68032 L F
.50883 .67986 m .51033 .68117 L .508 .68166 L F
.927 .757 .651 r
.575 .6457 m .5744 .64896 L .57608 .64927 L F
.823 .384 0 r
.5744 .64896 m .57627 .65168 L .57608 .64927 L F
.47 .313 .586 r
.57608 .64927 m .57856 .6494 L .57867 .64726 L F
.611 .319 .449 r
.51547 .63683 m .51921 .63442 L .51584 .63508 L F
.178 .254 .705 r
.80016 .48339 m .80081 .4864 L .80149 .48568 L F
.174 .201 .648 r
.80205 .48965 m .80149 .48568 L .80081 .4864 L F
0 .233 .748 r
.54967 .65742 m .54675 .65439 L .54805 .65632 L F
.168 .052 .466 r
.3257 .62178 m .32701 .62217 L .32708 .61957 L F
.449 0 .081 r
.37445 .59684 m .37304 .59851 L .37093 .59836 L F
.565 .207 .319 r
.37665 .59629 m .37304 .59851 L .37445 .59684 L F
.859 .659 .63 r
.59666 .63145 m .59636 .63397 L .59935 .63447 L F
.916 .693 .585 r
.59663 .63623 m .59935 .63447 L .59636 .63397 L F
.59663 .63623 m .59831 .63704 L .59935 .63447 L F
.43 .274 .567 r
.48083 .61648 m .47795 .61891 L .47835 .61712 L F
.48083 .61648 m .48103 .61927 L .47795 .61891 L F
.431 .184 .437 r
.48103 .61927 m .47836 .62193 L .47795 .61891 L F
.497 .865 .984 r
.45709 .61408 m .45819 .61305 L .45936 .61353 L F
.724 .201 0 r
.46056 .6173 m .45709 .61408 L .45936 .61353 L F
.46056 .6173 m .45913 .61652 L .45709 .61408 L F
.102 .208 .689 r
.45709 .61408 m .45913 .61652 L .45819 .61305 L F
.851 .676 .665 r
.65703 .44231 m .65473 .4417 L .65702 .44075 L F
.65703 .44231 m .65694 .44414 L .65473 .4417 L F
.539 .39 .627 r
.48195 .69001 m .48544 .6906 L .48488 .68597 L F
.48177 .69026 m .48238 .69032 L .48195 .69001 L F
.48238 .69032 m .48544 .6906 L .48195 .69001 L F
.686 .27 .251 r
.48755 .69223 m .48497 .69214 L .48543 .6903 L F
.48497 .69214 m .48405 .6921 L .48436 .69171 L F
.48497 .69214 m .48436 .69171 L .48543 .6903 L F
.991 .736 .382 r
.58614 .60834 m .58519 .60472 L .58617 .60575 L F
.48 .471 .77 r
.3658 .61633 m .36342 .61732 L .3628 .61427 L F
.328 .252 .617 r
.3658 .61827 m .36342 .61732 L .3658 .61633 L F
.3658 .61827 m .36385 .62009 L .36342 .61732 L F
.719 .831 .934 r
.35207 .63748 m .35611 .6376 L .35503 .63745 L F
.685 .975 .909 r
.35697 .63609 m .35611 .6376 L .3578 .63726 L F
.35697 .63609 m .35503 .63745 L .35611 .6376 L F
.46 .197 .427 r
.4824 .73828 m .48003 .73906 L .47904 .73736 L F
.4824 .73828 m .48003 .73906 L .47904 .73736 L F
0 0 0 r
.40023 .58039 m .40258 .58025 L .40406 .58015 L F
.204 0 0 r
.40258 .58025 m .40608 .57989 L .40406 .58015 L F
.61 .419 .599 r
.47461 .68698 m .47875 .68641 L .4781 .68404 L F
0 0 0 r
.47788 .68951 m .47875 .68641 L .47461 .68698 L F
.645 .086 0 r
.47612 .68893 m .47788 .68951 L .47461 .68698 L F
.47612 .68893 m .47461 .68698 L .47451 .68581 L F
.67 .271 .281 r
.48946 .71176 m .49296 .70982 L .48909 .70967 L F
.48946 .71176 m .49146 .71203 L .49296 .70982 L F
.555 .463 .706 r
.4954 .7073 m .49533 .70963 L .49296 .70982 L F
.554 .4 .626 r
.49586 .71247 m .49296 .70982 L .49533 .70963 L F
.49586 .71247 m .49298 .71334 L .49296 .70982 L F
0 0 0 r
.49296 .70982 m .49339 .71087 L .49533 .70963 L F
.49296 .70982 m .49146 .71203 L .49339 .71087 L F
.555 .463 .706 r
.4954 .7073 m .49533 .70963 L .49296 .70982 L F
.866 .655 .614 r
.55509 .63175 m .55319 .63173 L .55176 .62814 L F
.734 .288 .191 r
.55509 .63175 m .55388 .63298 L .55319 .63173 L F
.935 .604 .383 r
.55509 .63175 m .55536 .63351 L .55388 .63298 L F
.477 .597 .894 r
.47295 .68146 m .47217 .68407 L .47046 .68166 L F
.586 .429 .635 r
.32832 .5938 m .33069 .59363 L .33067 .59081 L F
.442 .326 .626 r
.32832 .5938 m .33065 .59594 L .33069 .59363 L F
.32832 .5938 m .32879 .59672 L .33065 .59594 L F
.547 .546 .805 r
.23315 .55228 m .23242 .55627 L .23093 .55294 L F
.23315 .55228 m .23449 .55577 L .23242 .55627 L F
.6 .399 .581 r
.45672 .68362 m .45943 .68368 L .45879 .68122 L F
.45672 .68362 m .45943 .68368 L .45879 .68122 L F
.284 0 .195 r
.4629 .68069 m .45943 .68368 L .45879 .68122 L F
0 0 .394 r
.45879 .68122 m .45984 .68209 L .45964 .67959 L F
.45879 .68122 m .45943 .68368 L .45984 .68209 L F
.392 .237 .549 r
.52713 .6486 m .52525 .6518 L .52504 .64941 L F
.52713 .6486 m .52525 .6518 L .52504 .64941 L F
.531 .465 .726 r
.32617 .61117 m .32695 .6148 L .32894 .61418 L F
.538 .489 .748 r
.32695 .6148 m .32997 .61749 L .32894 .61418 L F
.404 .386 .726 r
.50002 .69036 m .50272 .692 L .50228 .68844 L F
.617 .579 .789 r
.44412 .59676 m .4474 .59781 L .44573 .59622 L F
.651 .658 .844 r
.46166 .59655 m .45938 .59758 L .45735 .59386 L F
.591 .174 .221 r
.45938 .59758 m .46146 .599 L .45954 .59908 L F
.483 .259 .497 r
.46166 .59655 m .46146 .599 L .45938 .59758 L F
.34 .225 .574 r
.64229 .43698 m .64455 .43594 L .64418 .43294 L F
.429 .086 .28 r
.64229 .43698 m .6444 .43809 L .64455 .43594 L F
.546 .503 .759 r
.65447 .4274 m .65531 .43091 L .65289 .43124 L F
.844 .734 .742 r
.65531 .43091 m .65225 .43224 L .65289 .43124 L F
.605 .335 .482 r
.19801 .59313 m .20106 .59124 L .19701 .59075 L F
.19801 .59313 m .20018 .59291 L .20106 .59124 L F
.975 .849 .655 r
.20106 .59124 m .19944 .59048 L .19939 .59002 L F
.20106 .59124 m .20018 .59291 L .19944 .59048 L F
.729 .643 .762 r
.20793 .56845 m .20527 .57079 L .20833 .57086 L F
.596 .55 .773 r
.20793 .56845 m .20833 .57086 L .21026 .56995 L F
0 0 .198 r
.20846 .5735 m .21026 .56995 L .20833 .57086 L F
.115 0 0 r
.44973 .62501 m .44618 .62494 L .44729 .62512 L F
.934 .595 .157 r
.58617 .62059 m .58528 .61968 L .58462 .61671 L F
.975 .901 .679 r
.58436 .62188 m .58617 .62059 L .58437 .62202 L F
.58436 .62188 m .58528 .61968 L .58617 .62059 L F
.614 .581 .793 r
.19434 .57741 m .19739 .57827 L .19604 .57435 L F
.711 .436 .507 r
.49394 .69221 m .48901 .68924 L .49108 .69003 L F
.49394 .69221 m .48755 .69223 L .48901 .68924 L F
0 0 0 r
.20135 .57495 m .20291 .57367 L .1999 .57301 L F
.41 .298 .615 r
.4781 .68404 m .47875 .68641 L .48054 .68563 L F
.758 .459 .479 r
.51838 .68035 m .52226 .67856 L .51843 .67768 L F
.51838 .68035 m .52203 .68055 L .52226 .67856 L F
.505 .236 .44 r
.52468 .67847 m .52203 .68055 L .52226 .67856 L F
.52468 .67847 m .52203 .68055 L .52226 .67856 L F
.74 .686 .799 r
.8004 .51439 m .80466 .51319 L .80327 .51194 L F
.804 .688 .737 r
.80466 .51319 m .80402 .50967 L .80327 .51194 L F
.181 .036 .436 r
.21186 .6243 m .21044 .62303 L .21186 .62213 L F
.21186 .6243 m .21023 .62552 L .21044 .62303 L F
.645 .93 .971 r
.65447 .4274 m .6532 .42852 L .65148 .4277 L F
.85 .832 .829 r
.78241 .48356 m .77874 .48511 L .78154 .48285 L F
.578 .86 .996 r
.78396 .48193 m .78487 .48276 L .78241 .48356 L F
.597 .893 .989 r
.78241 .48356 m .78154 .48285 L .78396 .48193 L F
.743 .328 .262 r
.55207 .67807 m .55373 .67999 L .55541 .67832 L F
.87 .96 .621 r
.55541 .67832 m .55373 .67999 L .55589 .67609 L F
.953 .758 .602 r
.5401 .6516 m .54075 .65452 L .54148 .65231 L F
.568 .838 .996 r
.54148 .65231 m .54182 .6507 L .5401 .6516 L F
.304 0 .095 r
.42615 .62592 m .42493 .62795 L .4227 .62851 L F
.483 .077 .193 r
.42843 .62692 m .42615 .62592 L .42856 .62619 L F
.42843 .62692 m .42493 .62795 L .42615 .62592 L F
.29 0 .097 r
.55338 .68627 m .55611 .68565 L .55638 .68382 L F
.906 .528 .299 r
.55539 .68058 m .55437 .68211 L .55373 .67999 L F
.702 .846 .419 r
.55474 .68153 m .55437 .68211 L .55539 .68058 L F
.99 .74 .372 r
.55539 .68058 m .55638 .68382 L .55474 .68153 L F
.939 .618 .174 r
.55638 .68382 m .55611 .68565 L .55474 .68153 L F
.39 0 .159 r
.53962 .71825 m .53854 .72016 L .53662 .72058 L F
.035 0 .074 r
.54258 .71523 m .54142 .71764 L .53962 .71825 L F
0 0 0 r
.54142 .71764 m .53854 .72016 L .53962 .71825 L F
.394 .348 .688 r
.32617 .61117 m .32724 .6077 L .32536 .60912 L F
.32617 .61117 m .32786 .61095 L .32724 .6077 L F
.531 .465 .726 r
.32617 .61117 m .32894 .61418 L .32786 .61095 L F
.523 .006 0 r
.37729 .62525 m .37961 .6258 L .38089 .62527 L F
.494 0 0 r
.38089 .62527 m .37961 .6258 L .38322 .62567 L F
.224 0 0 r
.39769 .63516 m .39615 .63617 L .39382 .63637 L F
.373 0 0 r
.39981 .63566 m .39615 .63617 L .39769 .63516 L F
.556 .335 .534 r
.40951 .62025 m .41187 .61996 L .4122 .61721 L F
.585 .36 .541 r
.4122 .61721 m .41478 .61863 L .41477 .61649 L F
.4122 .61721 m .41187 .61996 L .41478 .61863 L F
.925 .895 .78 r
.62261 .44366 m .62183 .4422 L .6229 .44339 L F
.906 .625 .499 r
.56739 .64592 m .56548 .64566 L .56519 .64309 L F
.624 .061 0 r
.56944 .64819 m .56548 .64566 L .56739 .64592 L F
.658 .604 .783 r
.77674 .48633 m .77763 .48961 L .77392 .48871 L F
.724 .365 .369 r
.55901 .59827 m .55967 .59723 L .55533 .59665 L F
.761 .382 .338 r
.4294 .61829 m .43324 .6174 L .42957 .61664 L F
.4294 .61829 m .43177 .61939 L .43324 .6174 L F
.645 .239 .259 r
.43324 .6174 m .43177 .61939 L .43535 .61924 L F
.584 .269 .401 r
.43324 .6174 m .43535 .61924 L .43703 .61642 L F
.453 .845 .636 r
.47886 .6981 m .47708 .69928 L .47831 .69856 L F
.129 0 0 r
.47832 .69846 m .47708 .69928 L .47838 .69843 L F
.47466 .70005 m .47708 .69928 L .47832 .69846 L F
.453 .845 .636 r
.47929 .69774 m .47708 .69928 L .47886 .6981 L F
.301 .297 .688 r
.4791 .70093 m .48062 .70083 L .47831 .69856 L F
.727 .223 .031 r
.47831 .69856 m .48062 .70083 L .47708 .69928 L F
.566 .616 .861 r
.79888 .5059 m .79708 .5095 L .79584 .5064 L F
.79888 .5059 m .79947 .51004 L .79708 .5095 L F
.457 .622 .922 r
.58571 .66473 m .58768 .66316 L .58496 .66312 L F
0 0 .474 r
.33477 .62607 m .33543 .62475 L .33494 .62513 L F
0 0 .418 r
.33606 .6285 m .33543 .62475 L .33477 .62607 L F
.387 .035 .24 r
.66394 .45176 m .66309 .45354 L .66066 .45415 L F
.365 0 .193 r
.66665 .45084 m .66309 .45354 L .66394 .45176 L F
.562 .715 .944 r
.42999 .58139 m .42895 .58331 L .42811 .58154 L F
.42999 .58139 m .43105 .58301 L .42895 .58331 L F
.634 .558 .752 r
.4772 .61334 m .47835 .61712 L .47661 .61857 L F
.82 .999 .838 r
.63301 .42951 m .63229 .43159 L .63457 .42945 L F
.476 .395 .685 r
.32486 .60546 m .3268 .60501 L .32628 .60258 L F
.513 .424 .692 r
.32486 .60546 m .32724 .6077 L .3268 .60501 L F
.32486 .60546 m .32536 .60912 L .32724 .6077 L F
.506 .301 .535 r
.50781 .63998 m .50983 .6377 L .50727 .63752 L F
.486 0 0 r
.41769 .61666 m .41967 .61723 L .42119 .61706 L F
.615 .174 .178 r
.41967 .61723 m .42364 .61704 L .42119 .61706 L F
0 0 0 r
.2418 .56176 m .23782 .56216 L .23965 .5621 L F
.695 .285 .265 r
.51161 .70135 m .51388 .70351 L .51502 .70166 L F
.698 .289 .267 r
.51502 .70166 m .51388 .70351 L .51676 .70369 L F
.76 .642 .731 r
.57351 .642 m .575 .6457 L .57489 .64299 L F
.691 .826 .948 r
.57351 .642 m .57489 .64299 L .57747 .6418 L F
.678 .426 .533 r
.50265 .65786 m .50496 .66017 L .50474 .65748 L F
.50265 .65786 m .50332 .66068 L .50496 .66017 L F
.669 .299 .334 r
.43907 .6169 m .44128 .61891 L .44253 .61679 L F
.66 .3 .351 r
.44128 .61891 m .44515 .61714 L .44253 .61679 L F
.448 0 0 r
.5423 .67257 m .54108 .67372 L .53843 .67292 L F
.631 .441 .608 r
.54329 .67111 m .54108 .67372 L .5423 .67257 L F
.602 .399 .579 r
.19663 .57282 m .1999 .57301 L .1995 .57058 L F
.202 0 0 r
.19604 .57435 m .1999 .57301 L .19663 .57282 L F
.743 .501 .564 r
.48827 .65138 m .49162 .65182 L .4915 .64907 L F
.543 .346 .564 r
.4915 .64907 m .49403 .65129 L .49454 .64862 L F
.4915 .64907 m .49162 .65182 L .49403 .65129 L F
.708 .619 .052 r
.20463 .56451 m .20469 .56349 L .20486 .56121 L F
.481 .5 .8 r
.36009 .60748 m .36137 .61111 L .35939 .61128 L F
0 0 .231 r
.20853 .62867 m .20798 .63093 L .20701 .63155 L F
.534 .548 .815 r
.57531 .65798 m .57628 .65449 L .57432 .65425 L F
.57531 .65798 m .57763 .65791 L .57628 .65449 L F
.966 .669 .412 r
.49468 .68989 m .49737 .68997 L .49398 .68926 L F
.49468 .68989 m .49718 .69204 L .49737 .68997 L F
.553 .509 .761 r
.55202 .68975 m .55432 .68933 L .55338 .68627 L F
.142 0 0 r
.46796 .63105 m .46918 .62898 L .4712 .62814 L F
.709 .79 .312 r
.63301 .42951 m .63137 .43368 L .63229 .43159 L F
.657 .352 .445 r
.43703 .61642 m .43881 .61882 L .43907 .6169 L F
.43703 .61642 m .43535 .61924 L .43881 .61882 L F
.5 .889 .719 r
.48997 .70589 m .48817 .70729 L .4916 .70515 L F
.439 0 0 r
.49377 .706 m .48997 .70589 L .4916 .70515 L F
.659 .447 .585 r
.66856 .4488 m .66903 .45116 L .66665 .45084 L F
0 0 .458 r
.66833 .4474 m .66856 .4488 L .66741 .4454 L F
.788 .547 0 r
.66833 .4474 m .66903 .45116 L .66856 .4488 L F
.796 .681 .738 r
.51723 .67181 m .51858 .67533 L .51483 .67479 L F
.61 .371 .53 r
.51858 .67533 m .51654 .67781 L .51483 .67479 L F
.51858 .67533 m .51843 .67768 L .51654 .67781 L F
.51654 .67781 m .51843 .67768 L .51858 .67533 L F
.698 .535 .664 r
.52087 .67489 m .51843 .67768 L .51858 .67533 L F
.792 .685 .746 r
.51843 .67768 m .52087 .67489 L .51858 .67533 L F
.199 .347 .789 r
.47561 .71276 m .4781 .71561 L .47741 .71217 L F
.47561 .71276 m .47831 .7165 L .4781 .71561 L F
.087 0 .265 r
.5135 .68736 m .51259 .68885 L .51249 .68664 L F
.697 .84 .951 r
.42892 .58937 m .42673 .59049 L .43035 .59056 L F
.786 .724 .795 r
.42673 .59049 m .4269 .59322 L .43035 .59056 L F
.666 .832 .963 r
.42892 .58937 m .43035 .59056 L .43326 .58967 L F
.484 .173 .363 r
.44537 .59434 m .44573 .59622 L .44825 .59537 L F
.592 .673 .896 r
.44438 .58806 m .44203 .58854 L .44134 .58689 L F
.568 .009 0 r
.44389 .62487 m .44252 .62502 L .44043 .62368 L F
0 .259 .757 r
.44043 .62368 m .44252 .62502 L .44167 .62442 L F
.484 .103 .241 r
.44043 .62368 m .44167 .62442 L .43811 .62455 L F
.773 .534 .573 r
.54664 .65117 m .54662 .65116 L .54557 .64857 L F
.175 .203 .651 r
.54572 .65275 m .54659 .65116 L .54565 .65083 L F
.346 0 0 r
.54662 .65117 m .54471 .65265 L .54182 .65318 L F
.54664 .65117 m .54663 .65118 L .54662 .65117 L F
.54663 .65118 m .54471 .65265 L .54662 .65117 L F
.175 .203 .651 r
.54572 .65275 m .54702 .65224 L .5466 .65117 L F
.54572 .65275 m .5466 .65117 L .54659 .65117 L F
.54702 .65224 m .54705 .65223 L .54662 .65116 L F
.54702 .65224 m .54662 .65116 L .54557 .64857 L F
.894 .778 .726 r
.54843 .65168 m .54663 .65118 L .54664 .65117 L F
.773 .534 .573 r
.54664 .65117 m .54662 .65117 L .54662 .65116 L F
.168 .201 .652 r
.54557 .64857 m .54843 .65168 L .54664 .65117 L F
.175 .203 .651 r
.54705 .65223 m .54843 .65168 L .54557 .64857 L F
.894 .778 .726 r
.54843 .65168 m .54471 .65265 L .54663 .65118 L F
.175 .203 .651 r
.54659 .65117 m .5466 .65117 L .54659 .65116 L F
.54565 .65083 m .54659 .65116 L .54557 .64857 L F
.773 .534 .573 r
.54662 .65116 m .54182 .6507 L .54182 .64823 L F
.54662 .65117 m .54182 .6507 L .54662 .65116 L F
.54662 .65116 m .54182 .64823 L .54557 .64857 L F
.365 .479 .843 r
.54853 .65449 m .54572 .65275 L .54675 .65439 L F
.54853 .65449 m .54845 .65237 L .54572 .65275 L F
.54845 .65237 m .54813 .6518 L .54572 .65275 L F
.443 .346 .65 r
.54675 .65439 m .5494 .65651 L .54853 .65449 L F
.365 .479 .843 r
.54853 .65449 m .54891 .65303 L .54866 .65234 L F
.54845 .65221 m .54866 .65234 L .54843 .65168 L F
.54853 .65449 m .54866 .65234 L .54845 .65221 L F
0 .142 .684 r
.5489 .65316 m .54881 .653 L .54891 .65303 L F
.954 .733 .276 r
.5494 .65651 m .54891 .65303 L .54853 .65449 L F
.5494 .65651 m .54882 .65558 L .54891 .65303 L F
.535 0 0 r
.5503 .65394 m .54868 .65235 L .54762 .65239 L F
.54868 .65235 m .54867 .65234 L .54867 .65234 L F
.365 .479 .843 r
.54845 .65237 m .54843 .65168 L .54813 .6518 L F
.894 .778 .726 r
.54843 .65168 m .54891 .65303 L .54651 .65239 L F
.535 0 0 r
.54868 .65235 m .54867 .65234 L .54762 .65239 L F
0 .142 .684 r
.54882 .65558 m .54651 .65239 L .54881 .653 L F
.54882 .65558 m .54881 .653 L .5489 .65316 L F
.697 .724 .871 r
.27815 .70093 m .27967 .70268 L .28194 .70141 L F
.549 .814 .995 r
.52174 .73158 m .5227 .72971 L .52068 .73 L F
.52174 .73158 m .52431 .73104 L .5227 .72971 L F
.843 .854 .852 r
.6197 .44817 m .61717 .44792 L .61951 .44559 L F
.879 .796 .764 r
.6197 .44817 m .61773 .45135 L .61717 .44792 L F
.905 .891 .806 r
.62261 .44366 m .6197 .44817 L .61951 .44559 L F
.57 .763 .969 r
.46175 .61289 m .46288 .61427 L .45936 .61353 L F
.748 .635 .736 r
.46288 .61427 m .46056 .6173 L .45936 .61353 L F
.631 .864 .499 r
.46158 .61574 m .46056 .6173 L .46288 .61427 L F
.627 .786 .958 r
.46387 .61246 m .46288 .61427 L .46175 .61289 L F
.46387 .61246 m .46525 .61343 L .46288 .61427 L F
.708 .894 .518 r
.46387 .61246 m .46288 .61427 L .46525 .61343 L F
.46387 .61246 m .46158 .61574 L .46288 .61427 L F
.537 .124 .206 r
.4604 .62193 m .4628 .62203 L .46414 .62008 L F
.838 .493 .401 r
.4628 .62203 m .46747 .62411 L .46414 .62008 L F
.741 .419 .438 r
.47197 .66825 m .47249 .66965 L .4743 .66657 L F
0 0 0 r
.4743 .66657 m .47526 .66539 L .47652 .66345 L F
.4743 .66657 m .47249 .66965 L .47526 .66539 L F
.706 .426 .498 r
.49454 .64862 m .49676 .64872 L .49699 .64657 L F
.531 .244 .423 r
.49676 .64872 m .50005 .64574 L .49699 .64657 L F
.923 .802 .709 r
.59513 .63044 m .5982 .62851 L .59577 .6281 L F
.59513 .63044 m .59666 .63145 L .5982 .62851 L F
.361 .088 .358 r
.54193 .68651 m .54412 .68664 L .54466 .68386 L F
.489 .204 .408 r
.54165 .68717 m .54412 .68664 L .54193 .68651 L F
.552 .356 .569 r
.65694 .44414 m .65183 .44499 L .65473 .4417 L F
.541 .731 .962 r
.37204 .6225 m .37148 .62461 L .36988 .62306 L F
.37204 .6225 m .37377 .62434 L .37148 .62461 L F
.606 .371 .535 r
.53003 .69858 m .52709 .70127 L .52808 .69905 L F
.53003 .69858 m .52978 .70096 L .52709 .70127 L F
.35 .156 .47 r
.53003 .69858 m .53179 .69793 L .52978 .70096 L F
.439 .191 .439 r
.50986 .69017 m .50907 .69465 L .50692 .69516 L F
.518 .352 .596 r
.51259 .68885 m .50986 .69017 L .51004 .68981 L F
.51259 .68885 m .51207 .69301 L .50986 .69017 L F
.5 .144 .294 r
.51207 .69301 m .50907 .69465 L .50986 .69017 L F
.364 .342 .701 r
.45357 .6953 m .45525 .69544 L .45456 .69165 L F
.385 .823 .952 r
.19867 .54409 m .20077 .54365 L .20268 .54394 L F
.186 0 0 r
.20077 .54365 m .20455 .54433 L .20268 .54394 L F
.649 .394 .519 r
.53434 .67298 m .5327 .67747 L .53029 .67715 L F
.377 .121 .394 r
.535 .67659 m .53434 .67298 L .53627 .67498 L F
.535 .67659 m .5327 .67747 L .53434 .67298 L F
.769 .261 0 r
.481 .71233 m .48457 .71515 L .48203 .71589 L F
0 0 0 r
.48304 .71491 m .48203 .71589 L .48457 .71515 L F
.48304 .71491 m .48097 .71761 L .48203 .71589 L F
.933 .746 .627 r
.59337 .61391 m .59296 .61634 L .59474 .61506 L F
.983 .83 .615 r
.59273 .61888 m .59474 .61506 L .59296 .61634 L F
.59273 .61888 m .5939 .6198 L .59474 .61506 L F
.89 .91 .507 r
.49844 .69535 m .4971 .69711 L .49533 .69475 L F
.764 .38 .327 r
.49718 .69204 m .50156 .69323 L .49844 .69535 L F
.506 .334 .581 r
.46158 .61574 m .45913 .61652 L .46056 .6173 L F
.565 .371 .578 r
.54466 .68386 m .5471 .68359 L .54707 .68108 L F
.54466 .68386 m .5471 .68359 L .54707 .68108 L F
.573 .503 .738 r
.54707 .68108 m .54944 .68065 L .54864 .67752 L F
.417 .069 .264 r
.65287 .46014 m .64991 .46213 L .6501 .46038 L F
.97 .663 .373 r
.19943 .58768 m .1978 .58833 L .19731 .58685 L F
.19943 .58768 m .19939 .59002 L .1978 .58833 L F
.673 .545 .701 r
.52928 .65881 m .53426 .65799 L .53183 .6545 L F
.794 .826 .876 r
.53013 .66048 m .53426 .65799 L .52928 .65881 L F
.53013 .66048 m .53266 .65967 L .53426 .65799 L F
.428 0 .059 r
.53169 .66175 m .53266 .65967 L .53013 .66048 L F
0 0 0 r
.53426 .65799 m .53266 .65967 L .53361 .65893 L F
0 0 .149 r
.45804 .692 m .45867 .69011 L .45976 .68909 L F
.925 .895 .78 r
.62261 .44366 m .62104 .4434 L .62183 .4422 L F
.905 .891 .806 r
.62261 .44366 m .61951 .44559 L .62104 .4434 L F
0 0 0 r
.48039 .66667 m .47901 .66815 L .47746 .6689 L F
.98 .713 .447 r
.47893 .66562 m .48039 .66667 L .48253 .66603 L F
.47893 .66562 m .47901 .66815 L .48039 .66667 L F
.519 .025 .021 r
.43209 .62591 m .4306 .62723 L .42856 .62619 L F
.488 .034 .098 r
.43432 .62569 m .4306 .62723 L .43209 .62591 L F
.514 .291 .513 r
.47652 .66345 m .47941 .66315 L .47908 .6607 L F
.474 .263 .512 r
.47908 .6607 m .47941 .66315 L .48126 .66021 L F
.418 .793 .993 r
.40608 .57989 m .40827 .57967 L .4099 .5804 L F
.243 .727 .929 r
.40827 .57967 m .41243 .58007 L .4099 .5804 L F
.645 .943 .708 r
.78628 .50819 m .78688 .50815 L .78768 .50745 L F
.502 .905 .911 r
.78768 .50745 m .78868 .50653 L .78628 .50819 L F
.78768 .50745 m .78988 .50657 L .78868 .50653 L F
.562 .582 .832 r
.77226 .50628 m .77348 .50251 L .771 .50306 L F
.77226 .50628 m .77465 .50586 L .77348 .50251 L F
.989 .827 .448 r
.59314 .6018 m .59346 .60511 L .59424 .60287 L F
.745 .491 .546 r
.53772 .69192 m .53417 .6948 L .53455 .69314 L F
.517 .223 .407 r
.54466 .68386 m .54726 .68543 L .5471 .68359 L F
.54466 .68386 m .54412 .68664 L .54726 .68543 L F
.27 .325 .736 r
.54726 .68543 m .54466 .68386 L .5471 .68359 L F
.469 .296 .563 r
.60734 .45977 m .6096 .45916 L .60749 .45734 L F
.60734 .45977 m .6096 .45916 L .60749 .45734 L F
.637 .286 .359 r
.48964 .71861 m .48799 .72062 L .48813 .71912 L F
.69 .629 .782 r
.4905 .71538 m .4921 .71889 L .48964 .71861 L F
.787 .548 .576 r
.4921 .71889 m .48799 .72062 L .48964 .71861 L F
.295 .138 .49 r
.20615 .63647 m .20418 .63984 L .2046 .63749 L F
.477 .369 .652 r
.21823 .60566 m .21828 .60791 L .2164 .60845 L F
.445 .28 .562 r
.21828 .60791 m .21824 .61038 L .2164 .60845 L F
.343 .267 .625 r
.2164 .60845 m .21824 .61038 L .21676 .61091 L F
.72 .756 .881 r
.79977 .51145 m .8004 .51439 L .80327 .51194 L F
.661 .662 .84 r
.76595 .50459 m .76707 .50067 L .76456 .50106 L F
.76595 .50459 m .76846 .50385 L .76707 .50067 L F
.861 .41 .088 r
.5599 .62742 m .56 .6257 L .55809 .62527 L F
.5599 .62742 m .56161 .62833 L .56 .6257 L F
.467 .773 .997 r
.4209 .58887 m .42189 .58733 L .41956 .58708 L F
.4209 .58887 m .42328 .58852 L .42189 .58733 L F
.96 .627 .255 r
.78628 .50819 m .78781 .51049 L .78688 .50815 L F
.593 .367 .542 r
.51486 .67235 m .51483 .67479 L .5123 .67512 L F
.796 .681 .738 r
.51723 .67181 m .51483 .67479 L .51486 .67235 L F
.453 .084 .247 r
.33851 .59014 m .34071 .59001 L .34202 .58755 L F
.434 .039 .188 r
.34071 .59001 m .34444 .58754 L .34202 .58755 L F
0 0 .022 r
.51933 .68256 m .5186 .68287 L .51996 .68128 L F
.972 .743 .532 r
.51838 .68035 m .51933 .68256 L .51996 .68128 L F
.283 .422 .826 r
.51838 .68035 m .5207 .68199 L .51933 .68256 L F
.5207 .68199 m .52084 .68209 L .51933 .68256 L F
0 0 .022 r
.51933 .68256 m .51751 .68414 L .5186 .68287 L F
.563 .84 .997 r
.51838 .68035 m .51996 .68128 L .52203 .68055 L F
.787 .548 .576 r
.4921 .71889 m .49168 .72137 L .48799 .72062 L F
0 .018 .592 r
.49196 .71735 m .4921 .71889 L .4905 .71538 L F
.967 .9 .702 r
.49196 .71735 m .49168 .72137 L .4921 .71889 L F
.435 .156 .389 r
.49465 .67797 m .49723 .67744 L .49709 .67552 L F
.598 .299 .432 r
.63337 .46581 m .63577 .4678 L .63385 .46757 L F
.63337 .46581 m .63587 .46581 L .63577 .4678 L F
.478 .729 .981 r
.77674 .48633 m .77603 .48669 L .77429 .48516 L F
.772 .639 .714 r
.61434 .46311 m .61205 .46557 L .61076 .46253 L F
.695 .518 .643 r
.61434 .46311 m .61427 .46623 L .61205 .46557 L F
.691 .515 .643 r
.61795 .46556 m .61427 .46623 L .61434 .46311 L F
.72 .597 .718 r
.635 .43647 m .63902 .43694 L .63761 .43435 L F
.453 .221 .47 r
.33069 .59363 m .33337 .59058 L .33067 .59081 L F
.65 .417 .553 r
.5255 .70726 m .52253 .70937 L .5255 .70739 L F
.776 .715 .795 r
.52564 .70554 m .5255 .70738 L .52108 .70638 L F
.5255 .70738 m .5255 .70739 L .52549 .70739 L F
.5255 .70738 m .52549 .70739 L .52108 .70638 L F
.65 .417 .553 r
.52486 .70771 m .52491 .70778 L .52253 .70937 L F
.5255 .70726 m .52554 .70737 L .52486 .70771 L F
.789 .692 .757 r
.5255 .70739 m .52253 .70937 L .52549 .70739 L F
.65 .417 .553 r
.52554 .70737 m .52615 .70941 L .52486 .70771 L F
.789 .692 .757 r
.52549 .70739 m .52253 .70937 L .52108 .70638 L F
.65 .417 .553 r
.52491 .70778 m .52615 .70941 L .52253 .70937 L F
.539 .461 .715 r
.52713 .70379 m .52765 .70743 L .5255 .70726 L F
.52713 .70379 m .5255 .70726 L .5255 .70739 L F
.734 .613 .724 r
.52765 .70743 m .52615 .70941 L .5255 .70726 L F
.074 .483 .893 r
.2389 .55644 m .2379 .55679 L .2366 .55529 L F
.2389 .55644 m .24065 .55807 L .2379 .55679 L F
.801 .483 .451 r
.45747 .68601 m .45672 .68362 L .45544 .68476 L F
.45747 .68601 m .45786 .68544 L .45672 .68362 L F
.45786 .68544 m .45907 .68367 L .45857 .68366 L F
.45786 .68544 m .45857 .68366 L .45672 .68362 L F
.066 .197 .692 r
.45786 .68544 m .4594 .68588 L .45747 .68601 L F
.45786 .68544 m .45745 .68754 L .4594 .68588 L F
.45544 .68476 m .45786 .68544 L .45747 .68601 L F
.45544 .68476 m .45717 .68716 L .45786 .68544 L F
.45717 .68716 m .45745 .68754 L .45786 .68544 L F
.801 .483 .451 r
.45747 .68601 m .45943 .68368 L .45907 .68367 L F
.625 .306 .411 r
.49568 .65202 m .49391 .65497 L .49188 .65425 L F
.343 0 .077 r
.34678 .58723 m .34905 .58681 L .35052 .58483 L F
.374 0 .038 r
.34905 .58681 m .35285 .58487 L .35052 .58483 L F
.28 0 .032 r
.40615 .63235 m .40486 .63412 L .40294 .634 L F
.317 0 .054 r
.40803 .63299 m .40615 .63235 L .40847 .63201 L F
.40803 .63299 m .40486 .63412 L .40615 .63235 L F
.683 .455 .57 r
.5025 .64566 m .50513 .64615 L .50545 .64318 L F
.623 .476 .662 r
.50545 .64318 m .50797 .64337 L .50781 .63998 L F
.707 .476 .573 r
.50545 .64318 m .50846 .64581 L .50797 .64337 L F
.50545 .64318 m .50513 .64615 L .50846 .64581 L F
.775 .645 .718 r
.65846 .44536 m .66 .44894 L .65577 .44815 L F
.688 .605 .758 r
.6619 .44542 m .66 .44894 L .65846 .44536 L F
.495 .791 .998 r
.38704 .58109 m .38625 .58252 L .38479 .58145 L F
.38704 .58109 m .38854 .5821 L .38625 .58252 L F
.774 .673 .753 r
.65531 .43091 m .65704 .43429 L .6552 .43301 L F
.857 .439 .231 r
.6552 .43301 m .65704 .43429 L .65598 .43522 L F
.666 .671 .845 r
.65753 .43069 m .65704 .43429 L .65531 .43091 L F
.65753 .43069 m .65939 .43365 L .65704 .43429 L F
.926 .562 .311 r
.65704 .43429 m .6579 .43643 L .65598 .43522 L F
.528 .188 .336 r
.51108 .6692 m .51349 .67086 L .51354 .66868 L F
.51108 .6692 m .51026 .6715 L .51349 .67086 L F
.204 0 0 r
.39066 .58092 m .39444 .58178 L .39205 .58119 L F
.909 .519 .105 r
.48788 .70874 m .48909 .70967 L .48817 .70729 L F
.48788 .70874 m .48817 .70729 L .48997 .70589 L F
.716 .619 .747 r
.2031 .56666 m .20527 .57079 L .20793 .56845 L F
.034 0 .386 r
.22622 .58742 m .22602 .59031 L .22494 .59098 L F
.139 .136 .592 r
.22602 .59031 m .22637 .59277 L .22494 .59098 L F
.334 .182 .521 r
.22637 .59277 m .22476 .59353 L .22494 .59098 L F
.752 .422 .425 r
.48054 .68563 m .48488 .68597 L .48375 .68431 L F
.26 .046 .388 r
.21425 .61609 m .21414 .61904 L .21198 .61985 L F
.037 0 .223 r
.21648 .61358 m .21578 .61579 L .21425 .61609 L F
.436 .311 .611 r
.21578 .61579 m .21414 .61904 L .21425 .61609 L F
.439 .192 .441 r
.54016 .6639 m .53996 .66614 L .54224 .66538 L F
.525 .369 .612 r
.52572 .66673 m .52806 .66672 L .52778 .66345 L F
.506 .253 .465 r
.52544 .66885 m .52806 .66672 L .52572 .66673 L F
.525 .369 .612 r
.52572 .66673 m .52806 .66672 L .52778 .66345 L F
.506 .253 .465 r
.52544 .66885 m .52806 .66672 L .52572 .66673 L F
.743 .275 .137 r
.48488 .68597 m .48627 .68782 L .48771 .68678 L F
.716 .662 .796 r
.52713 .70379 m .5255 .70739 L .52564 .70554 L F
.786 .422 .369 r
.52054 .6954 m .52243 .69639 L .52293 .69605 L F
.52054 .6954 m .5186 .69725 L .52243 .69639 L F
.508 .131 .26 r
.5183 .6992 m .52243 .69639 L .5186 .69725 L F
.368 .004 .209 r
.52243 .69639 m .52473 .69883 L .52415 .69621 L F
.52243 .69639 m .52137 .69966 L .52473 .69883 L F
.602 .069 0 r
.62855 .44237 m .63059 .44401 L .62883 .44242 L F
.62855 .44237 m .62964 .4436 L .63059 .44401 L F
.388 .844 .899 r
.63059 .44401 m .63202 .44292 L .63424 .44311 L F
.63059 .44401 m .62964 .4436 L .63202 .44292 L F
.697 .615 .761 r
.63494 .44389 m .63059 .44401 L .63424 .44311 L F
.701 .295 .274 r
.47652 .66345 m .47893 .66562 L .47941 .66315 L F
.47652 .66345 m .47526 .66539 L .47893 .66562 L F
.517 .097 .182 r
.43811 .62455 m .43701 .62586 L .43432 .62569 L F
.442 .013 .127 r
.44167 .62442 m .43701 .62586 L .43811 .62455 L F
.776 .73 .811 r
.53038 .64867 m .52713 .6486 L .53044 .64658 L F
.744 .532 .608 r
.5305 .65149 m .52713 .6486 L .53038 .64867 L F
.527 .366 .606 r
.53274 .64525 m .53038 .64867 L .53044 .64658 L F
.53274 .64525 m .53325 .64826 L .53038 .64867 L F
0 0 0 r
.53325 .64826 m .5305 .65149 L .53038 .64867 L F
.534 .865 .994 r
.50367 .73559 m .50773 .73554 L .50608 .73482 L F
.50773 .73554 m .50367 .73559 L .50608 .73482 L F
.268 .647 .966 r
.50839 .73461 m .50773 .73554 L .50608 .73482 L F
.50839 .73461 m .50967 .73567 L .50773 .73554 L F
.50773 .73554 m .50833 .73743 L .50669 .73554 L F
.50773 .73554 m .50967 .73567 L .50839 .73461 L F
.50773 .73554 m .50839 .73461 L .50833 .73743 L F
.724 .335 .313 r
.50608 .73482 m .50833 .73743 L .5047 .73708 L F
.608 .084 0 r
.50839 .73461 m .51007 .73594 L .50833 .73743 L F
.244 0 .114 r
.50839 .73461 m .50726 .73715 L .50939 .73632 L F
.50726 .73715 m .5072 .73727 L .50729 .73723 L F
.50726 .73715 m .50729 .73723 L .50939 .73632 L F
.268 .647 .966 r
.50651 .73501 m .50669 .73554 L .50608 .73482 L F
.50773 .73554 m .50669 .73554 L .50651 .73501 L F
.775 .645 .718 r
.65846 .44536 m .65577 .44815 L .65592 .44574 L F
0 0 .465 r
.47163 .68494 m .47269 .68651 L .47238 .68591 L F
.86 .905 .494 r
.47238 .68591 m .47269 .68651 L .47136 .68849 L F
.343 .172 .499 r
.21414 .61904 m .21186 .62213 L .21198 .61985 L F
.048 .212 .713 r
.46674 .70826 m .46603 .70945 L .46479 .70658 L F
.46674 .70826 m .46707 .71005 L .46603 .70945 L F
.792 .925 .924 r
.76581 .49173 m .7658 .48915 L .76868 .48989 L F
.76581 .49173 m .76465 .49092 L .7658 .48915 L F
.549 .719 .952 r
.64378 .42296 m .64245 .42507 L .64134 .42297 L F
.64378 .42296 m .64481 .42465 L .64245 .42507 L F
0 0 0 r
.64245 .42507 m .64539 .42458 L .64134 .42648 L F
.64245 .42507 m .64481 .42465 L .64539 .42458 L F
.117 0 0 r
.37165 .64077 m .37006 .64073 L .36785 .64046 L F
.506 0 0 r
.37404 .64066 m .37006 .64073 L .37165 .64077 L F
.734 .655 .771 r
.33606 .6285 m .33888 .62931 L .33787 .62845 L F
.371 .693 .982 r
.33888 .62931 m .34034 .62849 L .33787 .62845 L F
.33888 .62931 m .3401 .62904 L .34034 .62849 L F
.551 .622 .875 r
.79436 .51295 m .79623 .51069 L .79374 .5112 L F
.79436 .51295 m .79754 .51264 L .79623 .51069 L F
.174 0 0 r
.51621 .69748 m .5186 .69725 L .52054 .6954 L F
.63 .818 .972 r
.78337 .48944 m .78272 .48834 L .78029 .48918 L F
.78029 .48918 m .78272 .48834 L .78337 .48944 L F
.475 .411 .705 r
.78567 .4887 m .78612 .49101 L .78337 .48944 L F
0 0 0 r
.39737 .59195 m .3954 .59209 L .39308 .5922 L F
.133 .678 .816 r
.39737 .59195 m .3977 .59164 L .3954 .59209 L F
.39737 .59195 m .39852 .59174 L .3977 .59164 L F
.612 .64 .854 r
.46779 .69246 m .47106 .69376 L .46986 .69191 L F
.67 .351 .425 r
.24778 .78206 m .25137 .78188 L .2478 .7815 L F
.662 .591 .766 r
.46602 .68437 m .46604 .68621 L .46823 .68388 L F
.551 .928 .812 r
.50241 .70081 m .50046 .70212 L .50201 .70197 L F
.574 0 0 r
.53925 .61934 m .54179 .62107 L .54287 .62088 L F
.583 .007 0 r
.54179 .62107 m .5447 .62218 L .54287 .62088 L F
.608 .045 0 r
.54287 .62088 m .5447 .62218 L .54659 .62255 L F
.483 .325 .59 r
.51648 .65651 m .51618 .65605 L .51419 .65655 L F
.501 .249 .464 r
.51592 .65611 m .51585 .65623 L .51419 .65655 L F
.483 .325 .59 r
.51606 .65619 m .51419 .65655 L .51416 .65478 L F
.464 .247 .499 r
.51743 .65696 m .51617 .65627 L .51617 .6562 L F
.483 .325 .59 r
.51627 .65632 m .51606 .65619 L .51624 .6563 L F
.51648 .65651 m .51611 .65623 L .51627 .65632 L F
.51648 .65651 m .51552 .65653 L .51611 .65623 L F
.501 .249 .464 r
.51618 .65605 m .51617 .65627 L .51607 .6562 L F
.483 .325 .59 r
.51611 .65623 m .51606 .65619 L .51608 .65621 L F
.51617 .65627 m .51608 .65621 L .51627 .65632 L F
.51611 .65623 m .51608 .65621 L .51617 .65627 L F
.491 .894 .935 r
.51697 .65607 m .51618 .65605 L .51648 .65651 L F
.464 .247 .499 r
.51819 .6552 m .51647 .65605 L .51618 .65605 L F
.51816 .65522 m .51617 .6562 L .51819 .6552 L F
.51834 .65514 m .51617 .6562 L .51826 .65517 L F
.491 .894 .935 r
.51798 .65517 m .51834 .65514 L .51618 .65605 L F
.51798 .65517 m .51618 .65605 L .51697 .65607 L F
.464 .247 .499 r
.51647 .65605 m .51617 .6562 L .51618 .65605 L F
.51826 .65517 m .51816 .65522 L .51819 .6552 L F
.501 .249 .464 r
.51618 .65605 m .51607 .6562 L .51592 .65611 L F
.483 .325 .59 r
.51624 .6563 m .51416 .65478 L .51388 .65422 L F
.51606 .65619 m .51416 .65478 L .51624 .6563 L F
.501 .249 .464 r
.51617 .65627 m .51608 .65964 L .51607 .6562 L F
.483 .325 .59 r
.51611 .65623 m .51419 .65655 L .51606 .65619 L F
.51552 .65653 m .51419 .65655 L .51611 .65623 L F
.501 .249 .464 r
.51585 .65623 m .51356 .65992 L .51419 .65655 L F
.51607 .6562 m .51551 .65704 L .51592 .65611 L F
.51551 .65704 m .51356 .65992 L .51524 .65721 L F
.51551 .65704 m .51524 .65721 L .51592 .65611 L F
.464 .247 .499 r
.51743 .65696 m .51608 .65964 L .51616 .65665 L F
.51627 .65632 m .51616 .65665 L .51617 .65627 L F
.76 .246 0 r
.51475 .65629 m .51638 .65649 L .51388 .65422 L F
.51638 .65649 m .51648 .65651 L .51627 .65632 L F
.51638 .65649 m .51627 .65632 L .51388 .65422 L F
.464 .247 .499 r
.51647 .65643 m .51638 .65649 L .51627 .65632 L F
.51638 .65649 m .51616 .65665 L .51627 .65632 L F
.703 .971 .928 r
.51664 .65636 m .51642 .6565 L .51638 .65649 L F
.51664 .65636 m .51638 .65649 L .51641 .65647 L F
.51664 .65636 m .51648 .65651 L .51642 .6565 L F
.464 .247 .499 r
.51743 .65696 m .51616 .65665 L .51647 .65643 L F
.703 .971 .928 r
.51641 .65647 m .51638 .65649 L .51637 .65649 L F
.51657 .65636 m .51637 .65649 L .51475 .65629 L F
.51664 .65636 m .51641 .65647 L .51657 .65636 L F
.51697 .65607 m .51664 .65636 L .51657 .65636 L F
.464 .247 .499 r
.51834 .65514 m .51743 .65696 L .51651 .6564 L F
.51814 .65524 m .51651 .6564 L .51617 .6562 L F
.51834 .65514 m .51651 .6564 L .51814 .65524 L F
.703 .971 .928 r
.51641 .65647 m .51637 .65649 L .51652 .65639 L F
.51641 .65647 m .51652 .65639 L .51657 .65636 L F
.51798 .65517 m .51697 .65607 L .51475 .65629 L F
.51697 .65607 m .51657 .65636 L .51475 .65629 L F
.501 .249 .464 r
.51551 .65704 m .51608 .65964 L .51356 .65992 L F
.51607 .6562 m .51608 .6567 L .51551 .65704 L F
.51608 .6567 m .51608 .65964 L .51551 .65704 L F
.599 .104 .049 r
.54519 .60325 m .54718 .60462 L .54357 .60428 L F
.502 .223 .423 r
.54718 .60248 m .54718 .60462 L .54519 .60325 L F
.714 .987 .861 r
.54357 .60428 m .54718 .60248 L .54519 .60325 L F
.469 .475 .781 r
.53183 .6545 m .53492 .65592 L .535 .65447 L F
.53183 .6545 m .53426 .65799 L .53492 .65592 L F
.65 .101 0 r
.54506 .62708 m .5447 .62719 L .5428 .62536 L F
.54618 .62794 m .5447 .62719 L .54506 .62708 L F
0 .497 .767 r
.54396 .62574 m .5428 .62536 L .54268 .62543 L F
.65 .101 0 r
.54618 .62794 m .5428 .62536 L .54396 .62574 L F
.885 .952 .602 r
.54504 .62426 m .54462 .62586 L .54621 .6232 L F
.54504 .62426 m .54621 .6232 L .54659 .62255 L F
.721 .503 .595 r
.54659 .62255 m .54462 .62586 L .54965 .62581 L F
.59 .147 .166 r
.54462 .62586 m .54912 .62727 L .54965 .62581 L F
0 .384 .684 r
.54724 .62666 m .54462 .62586 L .54504 .62426 L F
.937 .771 .651 r
.54485 .62592 m .54504 .62426 L .54288 .62529 L F
.54485 .62592 m .54383 .62478 L .54504 .62426 L F
.5447 .62719 m .54485 .62592 L .54288 .62529 L F
.5447 .62719 m .54416 .62569 L .54485 .62592 L F
.54416 .62569 m .54383 .62478 L .54485 .62592 L F
0 .384 .684 r
.54625 .62636 m .54912 .62727 L .54587 .62625 L F
.5455 .62613 m .54587 .62625 L .54462 .62586 L F
.54625 .62636 m .54587 .62625 L .5455 .62613 L F
.54724 .62666 m .54901 .62723 L .54625 .62636 L F
.54901 .62723 m .54912 .62727 L .54625 .62636 L F
.937 .771 .651 r
.54288 .62529 m .54504 .62426 L .54149 .62385 L F
.712 .188 0 r
.54383 .62478 m .54423 .625 L .54504 .62426 L F
.54423 .625 m .54724 .62666 L .54504 .62426 L F
.696 .93 .615 r
.54525 .62614 m .54413 .62736 L .5447 .62719 L F
.663 .111 0 r
.5447 .62719 m .54385 .62767 L .54304 .62681 L F
.696 .93 .615 r
.54413 .62736 m .54385 .62767 L .5447 .62719 L F
.937 .771 .651 r
.5447 .62719 m .54289 .62531 L .5428 .62536 L F
.54289 .62531 m .54149 .62385 L .5428 .62536 L F
0 .497 .767 r
.54268 .62543 m .5428 .62536 L .54046 .62488 L F
.595 .545 .768 r
.76181 .50046 m .76353 .49746 L .76119 .49798 L F
.76181 .50046 m .76456 .50106 L .76353 .49746 L F
0 0 0 r
.40263 .59031 m .40072 .59109 L .39852 .59174 L F
.036 0 0 r
.40555 .58865 m .40414 .59024 L .40263 .59031 L F
.24 0 0 r
.40414 .59024 m .40072 .59109 L .40263 .59031 L F
.514 .651 .919 r
.47106 .69376 m .47197 .69163 L .46986 .69191 L F
.47106 .69376 m .47442 .6944 L .47197 .69163 L F
.763 .75 .841 r
.51571 .64897 m .5116 .64612 L .51566 .64701 L F
.51571 .64897 m .51242 .64964 L .5116 .64612 L F
.199 0 .097 r
.51441 .64955 m .51242 .64964 L .51571 .64897 L F
.641 .559 .747 r
.51766 .64822 m .51571 .64897 L .51566 .64701 L F
0 0 0 r
.51441 .64955 m .51571 .64897 L .51766 .64822 L F
.027 0 .081 r
.55312 .60198 m .55407 .60022 L .55191 .59946 L F
.191 0 0 r
.50119 .7075 m .49988 .70889 L .49753 .70928 L F
.658 .178 .102 r
.50119 .7075 m .50329 .70926 L .49988 .70889 L F
.493 .213 .418 r
.37093 .59836 m .36793 .60089 L .36844 .59869 L F
.439 0 .1 r
.39721 .62468 m .3996 .62458 L .40104 .62275 L F
.228 0 0 r
.40104 .62275 m .40182 .62399 L .40323 .62223 L F
.40104 .62275 m .3996 .62458 L .40182 .62399 L F
.72 .597 .718 r
.635 .43647 m .63761 .43435 L .63551 .43372 L F
.433 .241 .519 r
.33093 .63461 m .3329 .63404 L .33321 .6314 L F
.464 .322 .602 r
.33093 .63461 m .33309 .63652 L .3329 .63404 L F
.21 0 .253 r
.20472 .58251 m .204 .58456 L .20641 .58173 L F
.465 .868 .961 r
.49726 .65768 m .49597 .65735 L .49581 .65465 L F
.975 .696 .434 r
.49581 .65465 m .49726 .65768 L .49597 .65735 L F
.195 .338 .782 r
.78655 .49229 m .78578 .49499 L .78397 .49416 L F
.78655 .49229 m .78779 .49688 L .78578 .49499 L F
.36 .089 .36 r
.52505 .63723 m .52711 .6348 L .52574 .63489 L F
.52505 .63723 m .52746 .63654 L .52711 .6348 L F
.709 .751 .885 r
.59225 .66472 m .5945 .66365 L .5909 .66317 L F
0 .124 .672 r
.64797 .42919 m .64966 .43196 L .64854 .42977 L F
.318 .546 .914 r
.64854 .42977 m .64966 .43196 L .65225 .43224 L F
.338 0 0 r
.38903 .63689 m .38813 .63745 L .3858 .63752 L F
.25 0 0 r
.39147 .63659 m .38813 .63745 L .38903 .63689 L F
.277 0 0 r
.41136 .62092 m .40951 .62025 L .40794 .62006 L F
.317 0 0 r
.41136 .62092 m .41187 .61996 L .40951 .62025 L F
.457 .792 .999 r
.42256 .58017 m .42433 .58061 L .4224 .58111 L F
.543 .492 .749 r
.76119 .49798 m .76353 .49746 L .7631 .49421 L F
.741 .752 .861 r
.77947 .51465 m .78081 .51637 L .78293 .51507 L F
.275 0 0 r
.38266 .59373 m .38119 .5953 L .3788 .59573 L F
.576 .189 .273 r
.38506 .59331 m .38119 .5953 L .38266 .59373 L F
.508 .294 .523 r
.51697 .65482 m .51929 .65435 L .51983 .65197 L F
.51983 .65197 m .51929 .65435 L .51697 .65482 L F
.821 .429 0 r
.5511 .64875 m .552 .65093 L .55278 .6519 L F
.768 .413 0 r
.552 .65093 m .55282 .65266 L .55278 .6519 L F
0 0 .198 r
.20846 .5735 m .20981 .57241 L .21026 .56995 L F
0 0 .423 r
.20846 .5735 m .20957 .57466 L .20981 .57241 L F
.20846 .5735 m .20866 .57601 L .20957 .57466 L F
.655 .796 .95 r
.79155 .49968 m .79519 .50024 L .79221 .50102 L F
.79155 .49968 m .79519 .50024 L .79221 .50102 L F
.674 .534 .686 r
.79553 .50362 m .79221 .50102 L .79519 .50024 L F
.79553 .50362 m .79434 .50493 L .79221 .50102 L F
.506 .301 .535 r
.50781 .63998 m .50989 .64046 L .50983 .6377 L F
.153 .112 .555 r
.50781 .63998 m .50945 .64178 L .50989 .64046 L F
.50781 .63998 m .50797 .64337 L .50945 .64178 L F
.639 .1 0 r
.5288 .64034 m .53098 .64208 L .52726 .64123 L F
.561 .219 .346 r
.53237 .63965 m .53098 .64208 L .5288 .64034 L F
0 0 0 r
.41364 .58647 m .40982 .5868 L .41135 .58692 L F
.022 0 0 r
.39444 .58178 m .39674 .58141 L .39796 .58093 L F
.329 .796 .689 r
.39796 .58093 m .39891 .58042 L .40023 .58039 L F
.39796 .58093 m .39674 .58141 L .39891 .58042 L F
.728 .57 .677 r
.52808 .69905 m .52709 .70127 L .52343 .70094 L F
.501 .894 .948 r
.20153 .5561 m .20188 .55713 L .20376 .55691 L F
.792 .943 .924 r
.6367 .44229 m .63494 .44389 L .63424 .44311 L F
.41 0 0 r
.56973 .59566 m .57087 .59566 L .57071 .5975 L F
.722 .239 .099 r
.57071 .5975 m .57371 .59959 L .56928 .59847 L F
.917 .884 .785 r
.56973 .59566 m .57087 .59566 L .57071 .5975 L F
.671 .458 .588 r
.49526 .70071 m .49685 .70124 L .49717 .69863 L F
.224 .072 .454 r
.49717 .69863 m .49685 .70124 L .49815 .70043 L F
.598 .491 .703 r
.4791 .70093 m .48131 .70391 L .48062 .70083 L F
.4791 .70093 m .47959 .70492 L .48131 .70391 L F
.126 0 0 r
.3797 .63897 m .37622 .63997 L .37717 .63935 L F
.819 .754 .792 r
.62938 .43885 m .63103 .44038 L .63243 .43925 L F
.636 .65 .847 r
.47788 .68951 m .4796 .69267 L .47711 .6928 L F
.639 .48 .652 r
.4796 .69267 m .4773 .69527 L .47711 .6928 L F
.686 .43 .53 r
.535 .65447 m .53756 .65438 L .53795 .65224 L F
.751 .648 .747 r
.53756 .65438 m .5401 .6516 L .53795 .65224 L F
.491 .54 .835 r
.79013 .49644 m .78848 .49928 L .78779 .49688 L F
.79013 .49644 m .79155 .49968 L .78848 .49928 L F
.067 .139 .63 r
.58275 .62672 m .58301 .62502 L .58242 .62601 L F
0 .145 .667 r
.45801 .70423 m .45993 .70692 L .45887 .70303 L F
.159 .514 .915 r
.4166 .57962 m .41599 .58063 L .41467 .57962 L F
.4166 .57962 m .41888 .58218 L .41599 .58063 L F
0 0 0 r
.63939 .42811 m .63963 .42757 L .64134 .42648 L F
.112 .6 .909 r
.21026 .54498 m .214 .54615 L .21203 .54594 L F
.66 .3 .351 r
.44128 .61891 m .44477 .61894 L .44515 .61714 L F
.605 .248 .338 r
.44477 .61894 m .44723 .61891 L .44515 .61714 L F
.507 .277 .501 r
.44515 .61714 m .44723 .61891 L .44748 .61661 L F
.29 .089 .425 r
.23009 .57617 m .22965 .57868 L .22811 .57917 L F
.346 .228 .573 r
.22965 .57868 m .22978 .58104 L .22811 .57917 L F
.311 .222 .591 r
.22811 .57917 m .22978 .58104 L .22833 .58149 L F
.652 .636 .822 r
.45076 .59986 m .45159 .59614 L .44936 .59661 L F
.508 .378 .638 r
.45076 .59986 m .45117 .60295 L .45279 .60132 L F
.716 .619 .747 r
.2031 .56666 m .20793 .56845 L .20622 .5677 L F
.754 .896 .942 r
.20799 .56636 m .20793 .56845 L .21043 .56693 L F
.20799 .56636 m .20622 .5677 L .20793 .56845 L F
.596 .55 .773 r
.20793 .56845 m .21026 .56995 L .21043 .56693 L F
.611 .319 .449 r
.51547 .63683 m .51805 .63693 L .51921 .63442 L F
.507 .21 .396 r
.51921 .63442 m .51999 .63641 L .52145 .63425 L F
.51921 .63442 m .51805 .63693 L .51999 .63641 L F
.541 .218 .371 r
.54302 .69018 m .54243 .69208 L .53984 .69214 L F
.544 .221 .372 r
.54533 .6913 m .54302 .69018 L .54527 .68921 L F
.54533 .6913 m .54243 .69208 L .54302 .69018 L F
.729 .476 .545 r
.6447 .4632 m .64441 .46557 L .64193 .46509 L F
.54 .29 .485 r
.64754 .46233 m .64441 .46557 L .6447 .4632 L F
.018 .341 .821 r
.48268 .70809 m .48401 .70803 L .48165 .70662 L F
.48268 .70809 m .48525 .7097 L .48401 .70803 L F
.469 .843 .989 r
.64134 .42297 m .63877 .42377 L .63759 .42294 L F
.452 .222 .474 r
.19525 .59656 m .19749 .59607 L .19801 .59313 L F
.197 .004 .378 r
.19801 .59313 m .1991 .59514 L .20018 .59291 L F
.19801 .59313 m .19749 .59607 L .1991 .59514 L F
.102 0 0 r
.47273 .67081 m .47401 .66998 L .47746 .6689 L F
.531 .244 .423 r
.49676 .64872 m .49929 .64833 L .50005 .64574 L F
.475 .147 .329 r
.49929 .64833 m .5025 .64566 L .50005 .64574 L F
.351 .278 .633 r
.53656 .64229 m .53447 .6406 L .53799 .6401 L F
.226 .319 .751 r
.53704 .63697 m .53932 .63897 L .53799 .6401 L F
.854 .55 .473 r
.53899 .64278 m .53799 .6401 L .53932 .63897 L F
.53899 .64278 m .53656 .64229 L .53799 .6401 L F
.284 0 .195 r
.4629 .68069 m .46136 .68329 L .45943 .68368 L F
0 0 .208 r
.46416 .67768 m .46376 .68008 L .4629 .68069 L F
0 0 0 r
.46376 .68008 m .46136 .68329 L .4629 .68069 L F
.811 .755 .801 r
.61773 .45135 m .61465 .45105 L .61717 .44792 L F
.817 .74 .779 r
.61773 .45135 m .61551 .45431 L .61465 .45105 L F
.84 .785 .799 r
.20376 .55691 m .20555 .56028 L .20532 .55749 L F
.557 .295 .474 r
.50989 .64046 m .51297 .63723 L .50983 .6377 L F
.411 .769 .995 r
.20455 .54433 m .20662 .54407 L .20826 .545 L F
.318 .675 .977 r
.20856 .54376 m .20826 .545 L .20662 .54407 L F
.20856 .54376 m .21026 .54498 L .20826 .545 L F
0 .103 .653 r
.79226 .50985 m .78988 .50657 L .79339 .5071 L F
.722 .62 .743 r
.79434 .50493 m .79339 .5071 L .78988 .50657 L F
.353 .591 .935 r
.79008 .50549 m .79165 .50688 L .79042 .50524 L F
0 .103 .653 r
.79226 .50985 m .79216 .50943 L .78988 .50657 L F
.79216 .50943 m .79157 .50832 L .78988 .50657 L F
0 .189 .713 r
.78988 .50657 m .792 .50876 L .79165 .50688 L F
.78988 .50657 m .79165 .50688 L .78868 .50653 L F
.353 .591 .935 r
.78868 .50653 m .79076 .50678 L .79008 .50549 L F
.79076 .50678 m .79165 .50688 L .79008 .50549 L F
0 .103 .653 r
.79216 .50943 m .792 .50876 L .79157 .50832 L F
0 .18 .71 r
.79226 .50985 m .79374 .5112 L .792 .50876 L F
.596 .242 .339 r
.53449 .72154 m .53092 .72377 L .53172 .72153 L F
.328 .016 .275 r
.53662 .72058 m .53377 .72394 L .53449 .72154 L F
.314 .476 .861 r
.49468 .68989 m .49394 .69221 L .49108 .69003 L F
.831 .787 .81 r
.59885 .66183 m .60273 .66046 L .60139 .65943 L F
.59885 .66183 m .60029 .66313 L .60273 .66046 L F
.871 .9 .85 r
.60139 .65943 m .60273 .66046 L .60508 .6575 L F
.743 .83 .372 r
.54298 .71393 m .54282 .71429 L .54286 .71433 L F
.836 .899 .484 r
.54175 .71598 m .54142 .71764 L .54201 .71624 L F
.54175 .71598 m .54201 .71624 L .54298 .71393 L F
.753 .956 .649 r
.54302 .71446 m .5415 .71573 L .54175 .71598 L F
.5415 .71573 m .54138 .71583 L .54175 .71598 L F
.836 .899 .484 r
.54175 .71598 m .54298 .71393 L .54302 .71446 L F
.63 .066 0 r
.54097 .71271 m .54302 .71446 L .54298 .71393 L F
0 .068 .544 r
.54233 .71384 m .54267 .71415 L .54097 .71271 L F
.54267 .71415 m .54302 .71446 L .54274 .71422 L F
.54267 .71415 m .54274 .71422 L .54097 .71271 L F
.743 .83 .372 r
.54286 .71433 m .54142 .71764 L .54258 .71523 L F
.54282 .71429 m .54142 .71764 L .54286 .71433 L F
.485 .848 .991 r
.79707 .48337 m .80016 .48339 L .79919 .48279 L F
.016 .17 .682 r
.80016 .48339 m .80211 .48403 L .79919 .48279 L F
.80016 .48339 m .80149 .48568 L .80211 .48403 L F
.883 .716 .67 r
.60758 .64852 m .60655 .65127 L .60918 .65144 L F
.871 .788 .766 r
.60655 .65127 m .60725 .65451 L .60918 .65144 L F
0 .136 .661 r
.46445 .7184 m .46528 .71743 L .4643 .71554 L F
.033 .235 .737 r
.46445 .7184 m .4666 .72043 L .46528 .71743 L F
.418 .187 .455 r
.3263 .59937 m .32834 .59884 L .32879 .59672 L F
.437 .312 .612 r
.3263 .59937 m .32826 .60125 L .32834 .59884 L F
.3263 .59937 m .32628 .60258 L .32826 .60125 L F
.243 0 0 r
.48958 .68542 m .49273 .6843 L .4901 .68501 L F
.594 .82 .986 r
.34135 .6335 m .33955 .63434 L .34279 .63467 L F
.34135 .6335 m .33955 .63434 L .34279 .63467 L F
.726 .783 .898 r
.44573 .59622 m .4474 .59781 L .44936 .59661 L F
.658 .351 .441 r
.46892 .7176 m .4689 .72099 L .4666 .72043 L F
.327 .325 .705 r
.47042 .71529 m .46892 .7176 L .46974 .71559 L F
.47042 .71529 m .47174 .71744 L .46892 .7176 L F
.388 .14 .413 r
.47113 .72022 m .46892 .7176 L .47174 .71744 L F
.47113 .72022 m .4689 .72099 L .46892 .7176 L F
.701 .292 .269 r
.56923 .63453 m .5719 .63462 L .57083 .63401 L F
0 0 .536 r
.46283 .71299 m .46414 .71404 L .46351 .7117 L F
.46283 .71299 m .4643 .71554 L .46414 .71404 L F
0 0 .349 r
.54636 .66278 m .54777 .66565 L .54772 .66574 L F
.532 .45 .708 r
.54777 .66565 m .54579 .6677 L .54772 .66574 L F
.719 .426 .48 r
.51419 .65655 m .51095 .65932 L .51142 .65816 L F
.51419 .65655 m .51356 .65992 L .51095 .65932 L F
.274 0 .107 r
.66066 .45415 m .65792 .4559 L .65827 .45444 L F
.62 .585 .792 r
.19604 .57435 m .19739 .57827 L .19932 .57635 L F
.664 .677 .852 r
.3633 .61092 m .3628 .61427 L .36137 .61111 L F
.3633 .61092 m .36541 .61358 L .3628 .61427 L F
.48 .471 .77 r
.3658 .61633 m .3628 .61427 L .36541 .61358 L F
.084 0 0 r
.57551 .59558 m .57805 .59495 L .57923 .59376 L F
.563 .107 .128 r
.57805 .59495 m .58162 .59353 L .57923 .59376 L F
.75 .993 .813 r
.51376 .64275 m .51667 .6408 L .51473 .64039 L F
.522 .664 .926 r
.51667 .6408 m .5181 .63843 L .51473 .64039 L F
.51667 .6408 m .52054 .64116 L .5181 .63843 L F
.639 .554 .743 r
.51667 .6408 m .52027 .64336 L .52054 .64116 L F
.939 .67 .503 r
.58694 .59807 m .58873 .59665 L .58698 .59606 L F
.58694 .59807 m .5888 .59912 L .58873 .59665 L F
.81 .684 .725 r
.58306 .61362 m .58462 .61671 L .58108 .61649 L F
.783 .46 .441 r
.58108 .61649 m .58462 .61671 L .5832 .61884 L F
.836 .532 .476 r
.58462 .61671 m .58528 .61968 L .5832 .61884 L F
.132 0 0 r
.50064 .65448 m .50168 .65382 L .50373 .65379 L F
.4994 .65476 m .50373 .65379 L .50229 .65488 L F
0 0 .086 r
.5021 .65439 m .50381 .65266 L .50152 .65291 L F
.50229 .65488 m .50265 .65436 L .5021 .65439 L F
.50265 .65436 m .50381 .65266 L .5021 .65439 L F
.132 0 0 r
.4994 .65476 m .49998 .65452 L .50064 .65448 L F
.49998 .65452 m .50168 .65382 L .50064 .65448 L F
.527 .354 .589 r
.47959 .70492 m .48165 .70662 L .48131 .70391 L F
.672 .541 .698 r
.52778 .66345 m .53021 .66372 L .53013 .66048 L F
.659 .345 .429 r
.53027 .66589 m .52778 .66345 L .52806 .66672 L F
.53027 .66589 m .53021 .66372 L .52778 .66345 L F
0 0 .007 r
.52778 .66345 m .53013 .66048 L .53021 .66372 L F
.659 .345 .429 r
.53027 .66589 m .52778 .66345 L .52806 .66672 L F
.53027 .66589 m .53021 .66372 L .52778 .66345 L F
.821 .742 .777 r
.61551 .45431 m .61203 .45485 L .61465 .45105 L F
.817 .838 .866 r
.61551 .45431 m .61127 .45557 L .61203 .45485 L F
.304 .073 .389 r
.21022 .62793 m .20798 .63093 L .20853 .62867 L F
.745 .491 .546 r
.53772 .69192 m .53656 .69488 L .53417 .6948 L F
.667 .43 .553 r
.53984 .69214 m .53656 .69488 L .53772 .69192 L F
.845 .692 .692 r
.53313 .66311 m .53424 .66571 L .53027 .66589 L F
.088 0 0 r
.53027 .66589 m .53424 .66571 L .53272 .66592 L F
.57 .575 .819 r
.5353 .66275 m .53424 .66571 L .53313 .66311 L F
0 0 0 r
.53424 .66571 m .53453 .66632 L .53272 .66592 L F
.817 .721 .759 r
.48177 .69026 m .4796 .69267 L .47788 .68951 L F
.48177 .69026 m .47788 .68951 L .48105 .69025 L F
.357 .075 .342 r
.48165 .6919 m .4796 .69267 L .48177 .69026 L F
.539 .39 .627 r
.48177 .69026 m .48488 .68597 L .48054 .68563 L F
.232 0 0 r
.48236 .69089 m .48177 .69026 L .48105 .69025 L F
.48236 .69089 m .48544 .6906 L .48177 .69026 L F
.145 .283 .748 r
.24011 .56521 m .23924 .56682 L .23774 .56268 L F
.23799 .56271 m .23774 .56268 L .23757 .56222 L F
.24011 .56521 m .23774 .56268 L .23799 .56271 L F
.659 .972 .854 r
.23653 .56253 m .23533 .56369 L .2357 .56276 L F
.23782 .56216 m .2371 .5626 L .23653 .56253 L F
.2371 .5626 m .23533 .56369 L .23653 .56253 L F
.831 .801 .822 r
.80191 .50601 m .79947 .51004 L .79888 .5059 L F
.651 .665 .85 r
.79451 .48418 m .79707 .48337 L .79353 .48201 L F
.618 .32 .441 r
.43881 .61882 m .44128 .61891 L .43907 .6169 L F
.361 .126 .417 r
.20707 .57931 m .20828 .58096 L .2084 .57843 L F
.20707 .57931 m .20641 .58173 L .20828 .58096 L F
.311 0 0 r
.40294 .634 m .40201 .63542 L .39981 .63566 L F
.377 0 .092 r
.40486 .63412 m .40201 .63542 L .40294 .634 L F
.674 .771 .923 r
.59693 .66273 m .60029 .66313 L .59885 .66183 L F
0 0 0 r
.50373 .65379 m .50532 .65247 L .50629 .65394 L F
.451 .024 .137 r
.50532 .65247 m .50832 .6535 L .50629 .65394 L F
.50532 .65247 m .50985 .65172 L .50832 .6535 L F
.436 .633 .938 r
.41736 .58706 m .41844 .5854 L .41596 .58583 L F
.41736 .58706 m .41956 .58708 L .41844 .5854 L F
.73 .818 .919 r
.65183 .44499 m .65021 .44625 L .64881 .44459 L F
.724 .58 .694 r
.24778 .78206 m .24824 .78394 L .25137 .78188 L F
.449 .153 .368 r
.50554 .67249 m .50508 .67437 L .50784 .67207 L F
.825 .852 .868 r
.80242 .49026 m .80414 .48835 L .80205 .48965 L F
0 .203 .731 r
.80472 .4803 m .80649 .48215 L .8065 .48317 L F
0 0 .187 r
.80678 .484 m .8065 .48317 L .80649 .48215 L F
.80678 .484 m .80708 .48587 L .8065 .48317 L F
.629 .47 .648 r
.33321 .6314 m .33593 .63111 L .33606 .6285 L F
.532 .284 .484 r
.3329 .63404 m .33593 .63111 L .33321 .6314 L F
.51 .842 .998 r
.33787 .62845 m .33623 .62741 L .33606 .6285 L F
.685 .21 .116 r
.34034 .62849 m .33623 .62741 L .33787 .62845 L F
.86 .6 .544 r
.51107 .65051 m .50832 .6535 L .50985 .65172 L F
.061 .072 .556 r
.51383 .65271 m .51107 .65051 L .51441 .64955 L F
.51383 .65271 m .51195 .65488 L .51107 .65051 L F
.199 0 .097 r
.51441 .64955 m .51107 .65051 L .51242 .64964 L F
.461 .463 .774 r
.3658 .61827 m .36657 .62165 L .36385 .62009 L F
.115 0 0 r
.1858 .55297 m .18598 .55296 L .18576 .55298 L F
.705 .985 .84 r
.786 .48562 m .78867 .48406 L .78763 .48256 L F
.741 .829 .919 r
.78763 .48256 m .78867 .48406 L .79088 .48277 L F
.365 0 .193 r
.66665 .45084 m .66551 .45293 L .66309 .45354 L F
.244 0 .128 r
.66755 .45213 m .66665 .45084 L .66903 .45116 L F
.66755 .45213 m .66551 .45293 L .66665 .45084 L F
.584 .694 .917 r
.3401 .62904 m .34531 .63147 L .34449 .63051 L F
0 .087 .623 r
.34531 .63147 m .34719 .63319 L .34449 .63051 L F
.34531 .63147 m .34752 .63365 L .34719 .63319 L F
.599 .392 .572 r
.49465 .67797 m .49752 .67956 L .49723 .67744 L F
.49465 .67797 m .49462 .68046 L .49752 .67956 L F
.49752 .67956 m .49462 .68046 L .49465 .67797 L F
.815 .946 .909 r
.53274 .64525 m .53044 .64658 L .53171 .64472 L F
.573 .423 .64 r
.53514 .6447 m .53274 .64525 L .53171 .64472 L F
.53514 .6447 m .5355 .64558 L .53274 .64525 L F
.615 .453 .64 r
.5355 .64558 m .53325 .64826 L .53274 .64525 L F
.719 .615 .74 r
.61205 .46557 m .60839 .46598 L .61076 .46253 L F
.664 .351 .434 r
.61205 .46557 m .6085 .46769 L .60839 .46598 L F
.61205 .46557 m .61051 .46821 L .6085 .46769 L F
.641 .325 .42 r
.61442 .46756 m .61051 .46821 L .61205 .46557 L F
.692 .285 .271 r
.61427 .46623 m .61442 .46756 L .61205 .46557 L F
.641 .559 .747 r
.51766 .64822 m .51566 .64701 L .51692 .64503 L F
.88 .544 .409 r
.5447 .62218 m .54504 .62426 L .54659 .62255 L F
.838 .613 .597 r
.53447 .6406 m .53098 .64208 L .53237 .63965 L F
.53447 .6406 m .53514 .6447 L .53098 .64208 L F
.351 .278 .633 r
.53656 .64229 m .53514 .6447 L .53447 .6406 L F
.538 .426 .674 r
.23533 .56369 m .23364 .56691 L .23427 .56483 L F
.964 .695 .263 r
.4594 .68588 m .46015 .68678 L .45943 .68368 L F
.997 .818 .462 r
.45976 .68909 m .46015 .68678 L .4594 .68588 L F
.568 .047 0 r
.58404 .59492 m .58511 .59384 L .58162 .59353 L F
.794 .33 .135 r
.58404 .59492 m .58698 .59606 L .58511 .59384 L F
.117 0 0 r
.44618 .62494 m .44252 .62502 L .44389 .62487 L F
0 .252 .761 r
.56339 .64073 m .56029 .63709 L .56262 .63939 L F
.824 .35 0 r
.48799 .72062 m .48511 .71752 L .48813 .71912 L F
.392 .237 .549 r
.52713 .6486 m .52698 .65137 L .52525 .6518 L F
.423 .334 .65 r
.52698 .65137 m .52757 .6538 L .52525 .6518 L F
.392 .237 .549 r
.52713 .6486 m .52698 .65137 L .52525 .6518 L F
.423 .334 .65 r
.52525 .6518 m .52757 .6538 L .52698 .65137 L F
.52698 .65137 m .52757 .6538 L .52525 .6518 L F
.982 .909 .606 r
.62938 .43885 m .62883 .44242 L .63103 .44038 L F
.637 .353 .47 r
.79556 .47721 m .79852 .47908 L .7991 .47737 L F
.558 .056 .02 r
.80039 .47862 m .7991 .47737 L .79852 .47908 L F
.80039 .47862 m .8025 .47889 L .7991 .47737 L F
.933 .886 .763 r
.80272 .50884 m .80402 .50967 L .80605 .50535 L F
.977 .827 .629 r
.80327 .51194 m .80402 .50967 L .80272 .50884 L F
.836 .954 .892 r
.52924 .66904 m .52555 .67104 L .52777 .67094 L F
.772 .402 .356 r
.52777 .67094 m .53123 .67175 L .52924 .66904 L F
.192 0 0 r
.51621 .69748 m .51631 .69813 L .5186 .69725 L F
0 0 0 r
.53426 .65799 m .53361 .65893 L .53492 .65592 L F
0 0 .177 r
.78659 .48011 m .78696 .47984 L .78706 .4773 L F
.393 .136 .4 r
.78706 .4773 m .78807 .47916 L .78969 .47738 L F
.78706 .4773 m .78696 .47984 L .78807 .47916 L F
.617 .539 .744 r
.47958 .61421 m .47835 .61712 L .4772 .61334 L F
.47958 .61421 m .48083 .61648 L .47835 .61712 L F
.473 .007 .065 r
.3858 .63752 m .38443 .63913 L .38191 .63902 L F
.054 0 0 r
.38643 .63835 m .3858 .63752 L .38813 .63745 L F
.38643 .63835 m .38443 .63913 L .3858 .63752 L F
.224 .736 .698 r
.18783 .55303 m .18576 .55298 L .18598 .55296 L F
.18783 .55303 m .18388 .55419 L .18576 .55298 L F
.666 .832 .963 r
.42892 .58937 m .43326 .58967 L .4315 .58839 L F
.372 .674 .975 r
.43326 .58967 m .43374 .5882 L .4315 .58839 L F
.43326 .58967 m .43543 .58965 L .43374 .5882 L F
.565 .415 .636 r
.79553 .50362 m .79339 .5071 L .79434 .50493 L F
.79553 .50362 m .79584 .5064 L .79339 .5071 L F
.537 .883 .985 r
.45936 .61353 m .46007 .61217 L .46175 .61289 L F
.45936 .61353 m .45819 .61305 L .46007 .61217 L F
0 .383 .79 r
.80605 .50535 m .80703 .50587 L .80527 .5047 L F
.80605 .50535 m .80703 .50587 L .80527 .5047 L F
0 .514 .811 r
.37772 .62508 m .37729 .62525 L .3761 .62425 L F
.37772 .62508 m .37961 .6258 L .37729 .62525 L F
.599 .273 .389 r
.52517 .72826 m .52861 .72676 L .52737 .72674 L F
.771 .549 .597 r
.48329 .69768 m .48457 .70049 L .4849 .69841 L F
.722 .517 .612 r
.50995 .70704 m .51017 .70988 L .50693 .70957 L F
.459 .32 .604 r
.51204 .70931 m .50995 .70704 L .51254 .70663 L F
.51204 .70931 m .51017 .70988 L .50995 .70704 L F
.596 .945 .798 r
.52726 .64123 m .52436 .64312 L .52608 .64267 L F
0 .479 .849 r
.78781 .51049 m .79103 .51184 L .78882 .51298 L F
.822 .954 .902 r
.79094 .5115 m .78882 .51298 L .79103 .51184 L F
.79094 .5115 m .78923 .5155 L .78882 .51298 L F
.465 .117 .29 r
.3656 .60228 m .36244 .6045 L .3631 .60297 L F
.646 .555 .737 r
.52713 .70379 m .52343 .70094 L .52709 .70127 L F
.627 .452 .626 r
.52978 .70096 m .52713 .70379 L .52709 .70127 L F
.458 .215 .456 r
.19475 .59884 m .19749 .59607 L .19525 .59656 L F
.453 .221 .47 r
.33069 .59363 m .33281 .59324 L .33337 .59058 L F
.473 .871 .964 r
.33337 .59058 m .33478 .58982 L .33629 .59007 L F
.551 .426 .663 r
.33281 .59324 m .33478 .58982 L .33337 .59058 L F
.98 .686 .346 r
.56519 .64309 m .56548 .64566 L .56411 .64249 L F
.22 .011 .369 r
.65714 .45784 m .65525 .45729 L .65792 .4559 L F
.65714 .45784 m .6552 .45926 L .65525 .45729 L F
.535 .718 .957 r
.36846 .62153 m .36763 .62347 L .36657 .62165 L F
.36846 .62153 m .36988 .62306 L .36763 .62347 L F
.18 0 .078 r
.49298 .71334 m .49236 .71476 L .4905 .71538 L F
.783 .663 .731 r
.49586 .71247 m .49236 .71476 L .49298 .71334 L F
.236 .07 .441 r
.21787 .61271 m .21676 .61091 L .21824 .61038 L F
.21787 .61271 m .21648 .61358 L .21676 .61091 L F
.864 .857 .832 r
.57763 .65791 m .57939 .65668 L .58014 .65519 L F
.621 .605 .813 r
.57939 .65668 m .58232 .65415 L .58014 .65519 L F
.57939 .65668 m .58347 .65735 L .58232 .65415 L F
.325 0 0 r
.24026 .79408 m .24144 .79418 L .23886 .79365 L F
.24026 .79408 m .24144 .79418 L .23886 .79365 L F
.606 .949 .919 r
.24026 .79408 m .24144 .79418 L .24194 .79311 L F
.24026 .79408 m .24144 .79418 L .24194 .79311 L F
.888 .561 .424 r
.63903 .44724 m .64077 .44757 L .64036 .44532 L F
.686 .965 .741 r
.64264 .44307 m .64036 .44532 L .64279 .44301 L F
.364 .801 .962 r
.64504 .44287 m .64259 .44275 L .64527 .44184 L F
.799 .729 .786 r
.64297 .4453 m .64527 .44184 L .64321 .44254 L F
.64264 .44307 m .64321 .44254 L .64259 .44275 L F
.64297 .4453 m .64321 .44254 L .64264 .44307 L F
.69 .942 .962 r
.64264 .44307 m .64036 .44532 L .64297 .4453 L F
.64259 .44275 m .64036 .44532 L .64264 .44307 L F
.686 .965 .741 r
.64158 .44346 m .64036 .44532 L .64264 .44307 L F
.515 .309 .538 r
.64077 .44757 m .64297 .4453 L .64036 .44532 L F
.754 .633 .727 r
.33728 .63705 m .33798 .64037 L .33449 .63988 L F
.738 .361 .338 r
.33707 .64065 m .33449 .63988 L .33798 .64037 L F
.046 .139 .639 r
.33821 .6394 m .33798 .64037 L .33763 .63873 L F
.738 .361 .338 r
.33707 .64065 m .33458 .64137 L .33449 .63988 L F
.689 .43 .526 r
.33458 .64137 m .33829 .63949 L .33449 .63988 L F
.33829 .63949 m .33844 .63942 L .33825 .63944 L F
.33829 .63949 m .33825 .63944 L .33449 .63988 L F
.046 .139 .639 r
.33823 .6393 m .33821 .6394 L .33728 .63705 L F
.33821 .6394 m .33763 .63873 L .33728 .63705 L F
.3384 .6397 m .33829 .63988 L .33824 .6394 L F
.33829 .63988 m .33798 .64037 L .33823 .6393 L F
0 0 .099 r
.3384 .6397 m .33707 .64065 L .33798 .64037 L F
.689 .43 .526 r
.33829 .63949 m .33835 .6396 L .33844 .63942 L F
0 0 0 r
.33844 .63942 m .3384 .63955 L .3389 .63892 L F
.046 .139 .639 r
.3384 .6397 m .33836 .63961 L .3384 .6397 L F
0 0 0 r
.3384 .63955 m .33808 .64078 L .3389 .63892 L F
.046 .139 .639 r
.33835 .6396 m .33824 .6394 L .33835 .6396 L F
.33835 .6396 m .33835 .6396 L .3384 .6397 L F
0 0 0 r
.3384 .63955 m .33689 .64248 L .33808 .64078 L F
.33844 .63942 m .33835 .6396 L .3384 .63955 L F
.33835 .6396 m .33689 .64248 L .3384 .63955 L F
.673 .636 .804 r
.33823 .6393 m .33825 .63944 L .33844 .63942 L F
.33823 .6393 m .33844 .63942 L .33728 .63705 L F
0 0 .499 r
.33835 .63646 m .33844 .63942 L .33728 .63705 L F
.33835 .63646 m .3389 .63892 L .33844 .63942 L F
.046 .139 .639 r
.3389 .63892 m .3384 .6397 L .33728 .63705 L F
0 0 .099 r
.3389 .63892 m .33782 .63994 L .3384 .6397 L F
.33782 .63994 m .33707 .64065 L .3384 .6397 L F
.708 .308 .288 r
.33707 .64065 m .33689 .64248 L .33458 .64137 L F
0 0 .099 r
.3389 .63892 m .33808 .64078 L .3375 .64071 L F
.33782 .63994 m .3375 .64071 L .33707 .64065 L F
.689 .43 .526 r
.33781 .63996 m .33689 .64248 L .33827 .63976 L F
0 0 .099 r
.3389 .63892 m .3375 .64071 L .33782 .63994 L F
.689 .43 .526 r
.33458 .64137 m .33679 .64243 L .33781 .63996 L F
0 0 .132 r
.3375 .64071 m .33689 .64248 L .33707 .64065 L F
.689 .43 .526 r
.3375 .64071 m .33689 .64248 L .33781 .63996 L F
0 0 .132 r
.33808 .64078 m .33689 .64248 L .3375 .64071 L F
.689 .43 .526 r
.33679 .64243 m .33689 .64248 L .3375 .64071 L F
.33657 .64044 m .33827 .63976 L .33835 .6396 L F
.33458 .64137 m .33827 .63976 L .33657 .64044 L F
.33458 .64137 m .33835 .6396 L .33829 .63949 L F
.046 .139 .639 r
.3384 .6397 m .33824 .6394 L .33823 .6393 L F
.673 .636 .804 r
.33309 .63652 m .33449 .63988 L .33825 .63944 L F
.33309 .63652 m .33825 .63944 L .33823 .6393 L F
.33309 .63652 m .33823 .6393 L .33728 .63705 L F
.762 .543 .601 r
.62403 .46579 m .62039 .46777 L .62022 .46547 L F
.62403 .46579 m .62392 .46822 L .62039 .46777 L F
.787 .398 .318 r
.62403 .46579 m .62756 .46828 L .62392 .46822 L F
.274 0 .107 r
.66066 .45415 m .66037 .45578 L .65792 .4559 L F
0 0 0 r
.66309 .45354 m .66037 .45578 L .66066 .45415 L F
0 0 .177 r
.53842 .65976 m .53895 .65781 L .54003 .65728 L F
.841 .64 .63 r
.6057 .6429 m .60508 .6453 L .60815 .64586 L F
.874 .672 .626 r
.60511 .64787 m .60815 .64586 L .60508 .6453 L F
.60511 .64787 m .60758 .64852 L .60815 .64586 L F
.661 .121 0 r
.52145 .63425 m .52505 .63723 L .52574 .63489 L F
.631 .451 .622 r
.5123 .67512 m .51242 .67781 L .50976 .67805 L F
.612 .437 .621 r
.51483 .67479 m .51242 .67781 L .5123 .67512 L F
.09 .109 .585 r
.77017 .48699 m .77215 .48669 L .77429 .48516 L F
.77017 .48699 m .7708 .48858 L .77215 .48669 L F
.12 .246 .721 r
.5698 .64998 m .57059 .65163 L .56944 .64819 L F
.656 .612 .793 r
.47198 .67454 m .4732 .67605 L .47571 .67503 L F
.716 .634 .764 r
.6071 .46194 m .60839 .46598 L .60655 .46392 L F
.707 .504 .612 r
.6085 .46769 m .60655 .46392 L .60839 .46598 L F
.742 .648 .756 r
.61076 .46253 m .60839 .46598 L .6071 .46194 L F
.32 0 .007 r
.40671 .58948 m .40555 .58865 L .40763 .58774 L F
.40671 .58948 m .40414 .59024 L .40555 .58865 L F
.428 0 .059 r
.53169 .66175 m .53013 .66048 L .53021 .66372 L F
.661 .121 0 r
.52145 .63425 m .52363 .63644 L .52505 .63723 L F
.549 .057 .04 r
.52363 .63644 m .52746 .63654 L .52505 .63723 L F
.659 .495 .651 r
.53318 .66062 m .53313 .66311 L .53021 .66372 L F
.5 .313 .558 r
.53596 .65999 m .53313 .66311 L .53318 .66062 L F
.702 .924 .966 r
.7699 .4878 m .76868 .48989 L .7658 .48915 L F
.7699 .4878 m .7708 .48858 L .76868 .48989 L F
.807 .825 .865 r
.80832 .5042 m .80706 .50282 L .80703 .50587 L F
.827 .389 0 r
.80832 .5042 m .80706 .50282 L .80643 .50111 L F
.8 .819 .867 r
.81007 .50284 m .80706 .50282 L .80703 .50587 L F
.801 .821 .866 r
.80703 .50587 m .80706 .50282 L .80527 .5047 L F
.389 .162 .444 r
.32879 .59672 m .3303 .59817 L .33065 .59594 L F
.32879 .59672 m .32834 .59884 L .3303 .59817 L F
.08 .346 .819 r
.65983 .43225 m .65939 .43365 L .65753 .43069 L F
.148 .429 .868 r
.66207 .43492 m .65939 .43365 L .65983 .43225 L F
.706 .636 .777 r
.48647 .65468 m .48959 .65488 L .48827 .65138 L F
.599 .578 .801 r
.48827 .65138 m .48959 .65488 L .49188 .65425 L F
.363 .795 .967 r
.1888 .54268 m .19096 .54234 L .1929 .54289 L F
.121 .651 .87 r
.19096 .54234 m .19507 .54292 L .1929 .54289 L F
0 0 .469 r
.21043 .56693 m .21167 .56915 L .20997 .56476 L F
.84 .89 .876 r
.20997 .56476 m .20799 .56636 L .21043 .56693 L F
.142 .089 .533 r
.21026 .56995 m .21167 .56915 L .21043 .56693 L F
.662 .839 .426 r
.62801 .4307 m .62761 .43112 L .62749 .43054 L F
.62801 .4307 m .62608 .43386 L .62761 .43112 L F
.935 .559 .198 r
.62858 .42791 m .6281 .4284 L .62731 .42595 L F
.494 .708 .966 r
.62801 .4307 m .62842 .42811 L .62884 .42841 L F
.62842 .42811 m .62858 .42791 L .62884 .42841 L F
.935 .559 .198 r
.62936 .42911 m .62842 .42811 L .62858 .42791 L F
.494 .708 .966 r
.62842 .42811 m .62848 .42771 L .62858 .42791 L F
.62842 .42811 m .62936 .42911 L .62848 .42771 L F
.62801 .4307 m .62936 .42911 L .62842 .42811 L F
.935 .559 .198 r
.62936 .42911 m .62815 .42843 L .62842 .42811 L F
.62815 .42843 m .6281 .4284 L .62858 .42791 L F
.805 .653 .694 r
.62761 .43112 m .62801 .4307 L .62749 .43054 L F
.62761 .43112 m .62936 .42911 L .62801 .4307 L F
.546 .56 .82 r
.50799 .70071 m .51185 .70315 L .51161 .70135 L F
.646 .309 .387 r
.51185 .70315 m .51388 .70351 L .51161 .70135 L F
.489 .158 .332 r
.41478 .61863 m .41769 .61666 L .41477 .61649 L F
.584 .269 .4 r
.46043 .6776 m .46372 .67748 L .46365 .67501 L F
.947 .643 .199 r
.46365 .67501 m .46372 .67748 L .46416 .67768 L F
.764 .38 .327 r
.49718 .69204 m .49947 .69443 L .50156 .69323 L F
.558 .088 .096 r
.50156 .69323 m .50304 .69433 L .50272 .692 L F
.50156 .69323 m .49947 .69443 L .50304 .69433 L F
.488 .065 .163 r
.42364 .61704 m .42558 .61817 L .42704 .61632 L F
.98 .699 .317 r
.42873 .61731 m .42957 .61664 L .42877 .61667 L F
.164 0 .216 r
.42877 .61667 m .42873 .61731 L .4292 .61677 L F
.42877 .61667 m .4292 .61677 L .43039 .61538 L F
.277 0 .028 r
.4275 .61638 m .42877 .61667 L .42957 .61664 L F
.42704 .61632 m .42877 .61667 L .4275 .61638 L F
.42704 .61632 m .42558 .61817 L .42877 .61667 L F
.046 0 0 r
.37961 .6258 m .38177 .62579 L .38322 .62567 L F
.25 .761 .845 r
.38177 .62579 m .38549 .62541 L .38322 .62567 L F
.662 .338 .414 r
.51999 .63641 m .52363 .63644 L .52145 .63425 L F
.763 .716 .808 r
.78169 .51215 m .77947 .51465 L .78293 .51507 L F
.673 .672 .841 r
.78169 .51215 m .78293 .51507 L .78583 .51389 L F
.885 .72 .672 r
.52253 .70937 m .52004 .70933 L .52108 .70638 L F
.916 .706 .604 r
.52253 .70937 m .5198 .7114 L .52004 .70933 L F
.52253 .70937 m .52221 .71198 L .5198 .7114 L F
.713 .65 .094 r
.52233 .71078 m .52221 .71198 L .52253 .70937 L F
.52233 .71078 m .52253 .70937 L .52507 .71002 L F
.527 .075 .122 r
.52615 .70941 m .52507 .71002 L .52253 .70937 L F
.563 .575 .823 r
.55526 .6025 m .55684 .60496 L .55438 .60525 L F
.55526 .6025 m .55684 .60496 L .55438 .60525 L F
.887 .459 .143 r
.66309 .43623 m .66458 .43909 L .66563 .43952 L F
.829 .392 0 r
.66349 .43828 m .66309 .43623 L .66207 .43492 L F
.66349 .43828 m .66458 .43909 L .66309 .43623 L F
.544 .254 .425 r
.63577 .4678 m .63587 .46581 L .63828 .46744 L F
.563 .239 .378 r
.63587 .46581 m .63858 .46569 L .63828 .46744 L F
.404 .2 .487 r
.23182 .57543 m .22965 .57868 L .23009 .57617 L F
.369 0 .068 r
.41172 .63073 m .41023 .63276 L .40847 .63201 L F
.433 .01 .135 r
.41421 .63049 m .41023 .63276 L .41172 .63073 L F
0 0 .418 r
.33606 .6285 m .33623 .62741 L .33543 .62475 L F
.967 .69 .268 r
.66508 .4413 m .66563 .43952 L .66458 .43909 L F
.345 .152 .47 r
.33069 .59363 m .33237 .59522 L .33281 .59324 L F
.33069 .59363 m .33065 .59594 L .33237 .59522 L F
.714 .987 .861 r
.54357 .60428 m .54651 .60208 L .54718 .60248 L F
.59 .872 .552 r
.54718 .60248 m .54851 .6008 L .54947 .59995 L F
.626 .96 .895 r
.54651 .60208 m .54851 .6008 L .54718 .60248 L F
.659 .583 .759 r
.54947 .59995 m .55082 .60217 L .54718 .60248 L F
.722 .502 .592 r
.55082 .60217 m .54718 .60462 L .54718 .60248 L F
.796 .573 .6 r
.5048 .64785 m .50976 .64593 L .50846 .64581 L F
.566 .15 .213 r
.50709 .64947 m .50976 .64593 L .5048 .64785 L F
.345 0 .073 r
.51023 .64683 m .50976 .64593 L .50709 .64947 L F
.566 .03 0 r
.50846 .64581 m .50976 .64593 L .51023 .64683 L F
.335 .148 .473 r
.50519 .70729 m .50551 .70438 L .5019 .70352 L F
.50519 .70729 m .506 .70684 L .50551 .70438 L F
.795 .864 .9 r
.24463 .78505 m .24824 .78394 L .24778 .78206 L F
.66 .661 .84 r
.76707 .50067 m .76846 .50385 L .771 .50306 L F
.615 .174 .178 r
.41967 .61723 m .42201 .61871 L .42364 .61704 L F
.5 .041 .093 r
.42364 .61704 m .42201 .61871 L .42558 .61817 L F
.651 .658 .844 r
.46166 .59655 m .45735 .59386 L .45993 .59573 L F
.456 .817 .996 r
.45993 .59573 m .464 .59607 L .46166 .59655 L F
.283 .097 .442 r
.4628 .59808 m .46166 .59655 L .464 .59607 L F
.4628 .59808 m .46146 .599 L .46166 .59655 L F
.91 .781 .707 r
.80548 .4967 m .80643 .50111 L .8038 .49949 L F
.711 .289 .242 r
.80643 .50111 m .80337 .50208 L .8038 .49949 L F
.665 .758 .919 r
.80527 .5047 m .80116 .50431 L .80337 .50208 L F
.726 .675 .8 r
.80337 .50208 m .80706 .50282 L .80527 .5047 L F
.893 .956 .834 r
.80576 .503 m .80375 .5046 L .80527 .5047 L F
.711 .289 .242 r
.80643 .50111 m .80696 .50254 L .80337 .50208 L F
.80696 .50254 m .80652 .50271 L .80337 .50208 L F
.893 .956 .834 r
.80613 .50168 m .80473 .5034 L .80576 .503 L F
.80473 .5034 m .80375 .5046 L .80576 .503 L F
.711 .289 .242 r
.80696 .50254 m .80706 .50282 L .80652 .50271 L F
.756 .694 .793 r
.80548 .4967 m .8092 .49708 L .80643 .50111 L F
.995 .852 .508 r
.59218 .60675 m .59296 .60859 L .59346 .60511 L F
.989 .827 .448 r
.59314 .6018 m .5928 .60429 L .59346 .60511 L F
.991 .864 .513 r
.5928 .60429 m .59218 .60675 L .59346 .60511 L F
.828 .79 .816 r
.57304 .65178 m .57432 .65425 L .57627 .65168 L F
.482 .297 .552 r
.57432 .65425 m .57628 .65449 L .57627 .65168 L F
.636 .371 .501 r
.53976 .67374 m .535 .67659 L .53627 .67498 L F
.697 .402 .472 r
.61795 .46556 m .61442 .46756 L .61427 .46623 L F
.495 .206 .404 r
.52715 .69236 m .52965 .69189 L .53038 .68891 L F
.468 .157 .355 r
.52965 .69189 m .53282 .68873 L .53038 .68891 L F
.952 .856 .436 r
.59273 .61888 m .5925 .62239 L .5939 .6198 L F
.018 .002 .494 r
.63137 .43368 m .63093 .43573 L .63088 .43337 L F
.63137 .43368 m .63159 .43538 L .63093 .43573 L F
.325 .218 .576 r
.63313 .43419 m .63159 .43538 L .63137 .43368 L F
.283 0 0 r
.62942 .43372 m .63192 .43404 L .63137 .43368 L F
.63192 .43404 m .63313 .43419 L .63137 .43368 L F
.018 .002 .494 r
.63137 .43368 m .63088 .43337 L .63087 .43321 L F
.688 .955 .951 r
.58049 .64039 m .58084 .64029 L .57747 .6418 L F
.589 .94 .928 r
.58235 .63926 m .58084 .64029 L .58049 .64039 L F
.39 .463 .815 r
.47008 .71161 m .46829 .7134 L .46707 .71005 L F
.039 .261 .759 r
.47058 .71421 m .46829 .7134 L .47008 .71161 L F
.47058 .71421 m .47042 .71529 L .46829 .7134 L F
.051 .264 .759 r
.46829 .7134 m .47042 .71529 L .46974 .71559 L F
.845 .692 .692 r
.53313 .66311 m .53027 .66589 L .53021 .66372 L F
0 0 .283 r
.53169 .66175 m .53021 .66372 L .53027 .66589 L F
.866 .786 .769 r
.60554 .65378 m .60725 .65451 L .60655 .65127 L F
.854 .807 .803 r
.60368 .65648 m .60725 .65451 L .60554 .65378 L F
.60368 .65648 m .60508 .6575 L .60725 .65451 L F
.76 .604 .684 r
.52343 .70094 m .52564 .70554 L .52137 .70387 L F
.776 .715 .795 r
.52564 .70554 m .52108 .70638 L .52137 .70387 L F
.646 .555 .737 r
.52713 .70379 m .52564 .70554 L .52343 .70094 L F
0 .187 .63 r
.56547 .62932 m .56768 .63076 L .56839 .63134 L F
.905 .579 .095 r
.56839 .63134 m .56768 .63076 L .56923 .63453 L F
.557 .295 .474 r
.50989 .64046 m .51125 .64028 L .51297 .63723 L F
.577 .324 .496 r
.51125 .64028 m .51547 .63683 L .51297 .63723 L F
.773 .403 .355 r
.45575 .62788 m .45939 .62857 L .45821 .63076 L F
.688 .301 .31 r
.45939 .62857 m .46158 .6307 L .45821 .63076 L F
.871 .9 .85 r
.60139 .65943 m .60508 .6575 L .60368 .65648 L F
.697 .402 .472 r
.61795 .46556 m .61849 .46776 L .61442 .46756 L F
.73 .495 .572 r
.62022 .46547 m .61849 .46776 L .61795 .46556 L F
.505 .756 .986 r
.47757 .73933 m .48003 .73906 L .47856 .73776 L F
.603 .212 .275 r
.58881 .60117 m .59234 .59944 L .5888 .59912 L F
.58881 .60117 m .59094 .60132 L .59234 .59944 L F
.82 .489 .428 r
.59094 .60132 m .59314 .6018 L .59234 .59944 L F
.273 .021 .337 r
.21026 .56995 m .21151 .57167 L .21167 .56915 L F
.21026 .56995 m .20981 .57241 L .21151 .57167 L F
0 0 0 r
.51441 .64955 m .51766 .64822 L .51609 .64925 L F
.909 .568 .098 r
.80987 .49987 m .81065 .50074 L .8092 .49708 L F
.994 .874 .575 r
.81007 .50284 m .81065 .50074 L .80987 .49987 L F
.691 .826 .948 r
.57351 .642 m .57747 .6418 L .57597 .6407 L F
.765 .794 .877 r
.57747 .6418 m .57888 .63899 L .57597 .6407 L F
0 .127 .604 r
.586 .64226 m .58235 .63926 L .58334 .63973 L F
.969 .894 .696 r
.62303 .43875 m .62188 .4374 L .62367 .43672 L F
.869 .987 .833 r
.62367 .43672 m .62582 .43297 L .62608 .43386 L F
.62367 .43672 m .62312 .43597 L .62582 .43297 L F
.9 .983 .79 r
.62367 .43672 m .62188 .4374 L .62312 .43597 L F
.464 .447 .755 r
.22978 .58104 m .22868 .58457 L .22833 .58149 L F
.22978 .58104 m .23047 .5841 L .22868 .58457 L F
.473 .251 .495 r
.23047 .5841 m .22833 .58664 L .22868 .58457 L F
.999 .808 .47 r
.20018 .59291 m .1991 .59514 L .19944 .59048 L F
.954 .798 .649 r
.62303 .43875 m .62036 .441 L .62188 .4374 L F
.62303 .43875 m .62183 .4422 L .62036 .441 L F
.222 .166 .58 r
.2031 .56666 m .20494 .56556 L .20469 .56349 L F
.546 .56 .82 r
.50799 .70071 m .50928 .70402 L .51185 .70315 L F
.09 0 0 r
.50928 .70402 m .50982 .70515 L .51185 .70315 L F
.50928 .70402 m .50802 .7058 L .50982 .70515 L F
.398 .433 .781 r
.56944 .64819 m .57059 .65163 L .57223 .65018 L F
.434 .496 .823 r
.57059 .65163 m .57304 .65178 L .57223 .65018 L F
.844 .734 .742 r
.65531 .43091 m .6552 .43301 L .65225 .43224 L F
.822 .419 .285 r
.65225 .43224 m .6552 .43301 L .65598 .43522 L F
.059 0 0 r
.36691 .58408 m .36917 .58361 L .37061 .58276 L F
0 0 0 r
.37061 .58276 m .37125 .58262 L .37313 .58253 L F
.37061 .58276 m .36917 .58361 L .37125 .58262 L F
.84 .61 .589 r
.59831 .63704 m .59815 .63953 L .60128 .64007 L F
.82 .501 .449 r
.59808 .64132 m .60128 .64007 L .59815 .63953 L F
.59808 .64132 m .60013 .64189 L .60128 .64007 L F
.697 .343 .372 r
.60013 .64189 m .60341 .64203 L .60128 .64007 L F
.69 .767 .911 r
.5909 .66317 m .5945 .66365 L .59328 .66224 L F
.705 .783 .912 r
.59693 .66273 m .59328 .66224 L .5945 .66365 L F
.172 0 .218 r
.47899 .69492 m .4773 .69527 L .4796 .69267 L F
.276 .217 .608 r
.47899 .69492 m .47929 .69774 L .4773 .69527 L F
.18 .31 .76 r
.45525 .69544 m .45634 .69863 L .45754 .69725 L F
.135 .297 .764 r
.45634 .69863 m .45835 .69918 L .45754 .69725 L F
.45634 .69863 m .45793 .70093 L .45835 .69918 L F
.249 .44 .853 r
.64527 .44184 m .64667 .44447 L .64504 .44287 L F
.573 .458 .684 r
.50797 .64337 m .51088 .6436 L .50945 .64178 L F
.50797 .64337 m .50846 .64581 L .51088 .6436 L F
.256 0 0 r
.42015 .62833 m .41866 .63011 L .41642 .6306 L F
.429 0 .015 r
.4227 .62851 m .41866 .63011 L .42015 .62833 L F
.541 .525 .787 r
.77914 .51221 m .78169 .51215 L .78054 .50856 L F
.539 .376 .608 r
.77914 .51221 m .77947 .51465 L .78169 .51215 L F
.099 .206 .689 r
.46567 .70657 m .46376 .70427 L .46539 .70263 L F
.46567 .70657 m .46479 .70658 L .46376 .70427 L F
.418 .036 .205 r
.50976 .67805 m .50883 .67986 L .50644 .68032 L F
.87 .86 .828 r
.51242 .67781 m .50883 .67986 L .50976 .67805 L F
.825 .45 0 r
.5925 .62239 m .59325 .62469 L .59352 .62452 L F
.884 .47 .219 r
.59396 .62713 m .59352 .62452 L .59325 .62469 L F
.59396 .62713 m .59577 .6281 L .59352 .62452 L F
.433 .295 .593 r
.2343 .57147 m .2321 .57091 L .23384 .56998 L F
.2343 .57147 m .23195 .57324 L .2321 .57091 L F
.681 .789 .931 r
.42256 .58017 m .41888 .58218 L .4166 .57962 L F
.486 .65 .931 r
.43215 .58099 m .43105 .58301 L .42999 .58139 L F
.43215 .58099 m .43402 .58358 L .43105 .58301 L F
.415 .831 .969 r
.18135 .54244 m .18518 .54227 L .18319 .54211 L F
.489 .158 .332 r
.41478 .61863 m .41697 .61826 L .41769 .61666 L F
.062 0 0 r
.41697 .61826 m .41967 .61723 L .41769 .61666 L F
.549 .118 .175 r
.57371 .59959 m .57494 .59895 L .5728 .60076 L F
0 .516 .758 r
.57693 .60155 m .57494 .59895 L .57614 .59978 L F
.57693 .60155 m .5728 .60076 L .57494 .59895 L F
.519 .039 .055 r
.42856 .62619 m .4306 .62723 L .42843 .62692 L F
.418 0 0 r
.55536 .63351 m .55568 .63375 L .55388 .63298 L F
.55536 .63351 m .55702 .6347 L .55568 .63375 L F
.734 .566 .665 r
.52343 .70094 m .52137 .70387 L .51972 .70095 L F
0 .108 .661 r
.66715 .44397 m .66741 .4454 L .66588 .44229 L F
.218 .206 .631 r
.66818 .44483 m .66741 .4454 L .66715 .44397 L F
.66818 .44483 m .66833 .4474 L .66741 .4454 L F
0 0 .499 r
.54674 .6618 m .54777 .66565 L .54636 .66278 L F
.665 .555 .721 r
.79833 .50323 m .79553 .50362 L .79519 .50024 L F
.51 .293 .52 r
.79833 .50323 m .79584 .5064 L .79553 .50362 L F
.62 .383 .537 r
.48165 .6919 m .47899 .69492 L .4796 .69267 L F
.409 .848 .934 r
.37313 .58253 m .37551 .58194 L .37672 .5822 L F
.214 0 0 r
.37672 .5822 m .37719 .58242 L .37895 .58178 L F
.37672 .5822 m .37551 .58194 L .37719 .58242 L F
.115 0 0 r
.44973 .62501 m .44857 .62506 L .44618 .62494 L F
.083 0 0 r
.44973 .62501 m .45232 .62509 L .44857 .62506 L F
.547 .494 .748 r
.32894 .61418 m .32997 .61749 L .33196 .61632 L F
.87 .86 .828 r
.51242 .67781 m .51033 .68117 L .50883 .67986 L F
0 .539 .825 r
.46077 .69414 m .4641 .69511 L .46193 .69473 L F
0 0 .364 r
.46398 .69821 m .46193 .69473 L .4641 .69511 L F
.548 0 0 r
.56923 .63453 m .57285 .63633 L .5719 .63462 L F
.6 .338 .492 r
.66037 .45578 m .65714 .45784 L .65792 .4559 L F
.49 .705 .965 r
.19249 .55575 m .19269 .55343 L .18998 .55313 L F
.779 .643 .712 r
.60734 .45977 m .60214 .46091 L .60421 .4603 L F
.60734 .45977 m .60478 .46264 L .60214 .46091 L F
.666 .47 .611 r
.6071 .46194 m .60478 .46264 L .60734 .45977 L F
.741 .935 .951 r
.60734 .45977 m .60421 .4603 L .60762 .45804 L F
.542 .762 .979 r
.60762 .45804 m .6096 .45916 L .60734 .45977 L F
.728 .68 .804 r
.6096 .45916 m .6071 .46194 L .60734 .45977 L F
.76 .642 .731 r
.57351 .642 m .57143 .64555 L .575 .6457 L F
.795 .619 .662 r
.57146 .64799 m .575 .6457 L .57143 .64555 L F
.57146 .64799 m .5744 .64896 L .575 .6457 L F
.19 .189 .627 r
.52027 .64336 m .52205 .64205 L .52054 .64116 L F
.03 .306 .796 r
.52027 .64336 m .52162 .64349 L .52205 .64205 L F
.555 .253 .41 r
.52162 .64349 m .52436 .64312 L .52205 .64205 L F
.686 .517 .651 r
.52205 .64205 m .5227 .64236 L .52349 .64069 L F
.5227 .64236 m .52436 .64312 L .52368 .64123 L F
.5227 .64236 m .52368 .64123 L .52349 .64069 L F
0 0 0 r
.52335 .64234 m .52292 .64279 L .52179 .6434 L F
.52183 .64335 m .52179 .6434 L .52162 .64349 L F
.52335 .64234 m .52179 .6434 L .52183 .64335 L F
.03 .306 .796 r
.52089 .6439 m .52277 .64554 L .52162 .64349 L F
.583 .664 .894 r
.52277 .64554 m .52415 .64351 L .52162 .64349 L F
.555 .253 .41 r
.52162 .64349 m .52415 .64351 L .52436 .64312 L F
0 0 0 r
.52292 .64279 m .52113 .6446 L .52162 .64349 L F
.03 .306 .796 r
.52027 .64336 m .52089 .6439 L .52162 .64349 L F
.552 .248 .406 r
.52764 .67698 m .52685 .67991 L .52468 .67847 L F
.493 .162 .334 r
.53029 .67715 m .52685 .67991 L .52764 .67698 L F
.8 .973 .677 r
.5231 .67179 m .52087 .67489 L .51987 .67118 L F
.5231 .67179 m .52086 .6735 L .52087 .67489 L F
.784 .282 0 r
.51354 .66868 m .51723 .67181 L .51569 .66996 L F
.639 .251 .293 r
.51582 .67331 m .51707 .67265 L .51595 .67135 L F
.784 .282 0 r
.51405 .66911 m .51595 .67135 L .51723 .67181 L F
.521 .873 .987 r
.51723 .67181 m .51595 .67135 L .51987 .67118 L F
.639 .251 .293 r
.51707 .67265 m .51987 .67118 L .51595 .67135 L F
.784 .282 0 r
.51354 .66868 m .51595 .67135 L .51405 .66911 L F
.768 .413 0 r
.552 .65093 m .55296 .65373 L .55282 .65266 L F
0 .15 .682 r
.55296 .65373 m .55507 .6564 L .55282 .65266 L F
.356 0 0 r
.56161 .62833 m .56465 .62948 L .56547 .62932 L F
.513 0 0 r
.56465 .62948 m .56768 .63076 L .56547 .62932 L F
.822 .954 .902 r
.79094 .5115 m .78966 .51358 L .78923 .5155 L F
.892 .854 .797 r
.78966 .51358 m .78796 .51399 L .78923 .5155 L F
.906 .743 .668 r
.59513 .63044 m .59636 .63397 L .59666 .63145 L F
.982 .909 .606 r
.62938 .43885 m .62855 .44237 L .62883 .44242 L F
.565 .207 .319 r
.37665 .59629 m .37559 .59863 L .37304 .59851 L F
.473 .151 .339 r
.3788 .59573 m .37559 .59863 L .37665 .59629 L F
.54 .29 .485 r
.64754 .46233 m .64706 .46519 L .64441 .46557 L F
.522 .274 .48 r
.64988 .464 m .64754 .46233 L .64991 .46213 L F
.64988 .464 m .64706 .46519 L .64754 .46233 L F
.102 0 0 r
.47273 .67081 m .47746 .6689 L .47651 .67103 L F
0 0 .02 r
.47746 .6689 m .47901 .66815 L .47651 .67103 L F
.793 .958 .92 r
.80205 .48965 m .80414 .48835 L .80308 .48758 L F
.582 .914 .684 r
.80414 .48835 m .80413 .48813 L .80308 .48758 L F
.80414 .48835 m .80708 .48587 L .80413 .48813 L F
.608 .628 .845 r
.23315 .55228 m .23093 .55294 L .22934 .54992 L F
.55 .312 .507 r
.22441 .59592 m .22168 .59847 L .22257 .59693 L F
.413 .624 .939 r
.42878 .57982 m .42811 .58154 L .4267 .58011 L F
.42878 .57982 m .42999 .58139 L .42811 .58154 L F
.441 .257 .534 r
.22833 .58664 m .22602 .59031 L .22622 .58742 L F
.876 .439 .13 r
.65598 .43522 m .6579 .43643 L .65836 .43831 L F
.763 .48 .505 r
.49246 .7029 m .49685 .70124 L .49526 .70071 L F
0 .236 .753 r
.36199 .63967 m .36255 .6388 L .36091 .63831 L F
.36199 .63967 m .36361 .64096 L .36255 .6388 L F
.728 .68 .804 r
.6096 .45916 m .61076 .46253 L .6071 .46194 L F
.705 .351 .373 r
.78807 .47916 m .7901 .4796 L .78969 .47738 L F
.795 .558 .579 r
.7901 .4796 m .79226 .47709 L .78969 .47738 L F
.483 .466 .762 r
.50279 .67471 m .50586 .67552 L .50508 .67437 L F
.821 .771 .805 r
.4732 .67287 m .47198 .67454 L .47273 .67081 L F
.723 .588 .704 r
.55432 .68933 m .55874 .69051 L .55763 .69198 L F
.523 .738 .972 r
.22783 .54853 m .22732 .55037 L .22579 .54869 L F
.22783 .54853 m .22934 .54992 L .22732 .55037 L F
.248 .126 .51 r
.21128 .62694 m .21023 .62552 L .21186 .6243 L F
.21128 .62694 m .21022 .62793 L .21023 .62552 L F
.823 .384 0 r
.5744 .64896 m .57521 .65073 L .57627 .65168 L F
.828 .79 .816 r
.57304 .65178 m .57627 .65168 L .57521 .65073 L F
.526 .331 .559 r
.57627 .65168 m .57628 .65449 L .57882 .6536 L F
.561 .093 .1 r
.47361 .61393 m .47617 .61531 L .4772 .61334 L F
.648 .544 .723 r
.47938 .61067 m .47958 .61421 L .4772 .61334 L F
.207 0 .324 r
.47938 .61067 m .4772 .61334 L .47925 .61266 L F
.253 0 0 r
.4772 .61334 m .47805 .61482 L .47925 .61266 L F
.4772 .61334 m .47617 .61531 L .47805 .61482 L F
.956 .631 .224 r
.58006 .63288 m .57931 .63283 L .57989 .63169 L F
0 0 0 r
.5805 .63068 m .58275 .62672 L .57989 .63169 L F
.57931 .63283 m .5805 .63068 L .57989 .63169 L F
.788 .547 0 r
.66833 .4474 m .66876 .45036 L .66903 .45116 L F
.907 .972 .673 r
.66876 .45036 m .66755 .45213 L .66903 .45116 L F
.786 .977 .909 r
.62761 .43112 m .62608 .43386 L .62582 .43297 L F
.805 .317 0 r
.55469 .65922 m .55794 .66221 L .55432 .66023 L F
.55469 .65922 m .55657 .66182 L .55794 .66221 L F
0 .535 .778 r
.55657 .66182 m .56003 .6625 L .55794 .66221 L F
0 0 .47 r
.4954 .7073 m .49533 .70963 L .49649 .70803 L F
.66 .941 .682 r
.49533 .70963 m .49339 .71087 L .49649 .70803 L F
.367 .279 .623 r
.49747 .71176 m .49533 .70963 L .49753 .70928 L F
.49747 .71176 m .49586 .71247 L .49533 .70963 L F
0 .527 .839 r
.19507 .54292 m .19694 .54333 L .19867 .54409 L F
.345 .779 .968 r
.19694 .54333 m .20077 .54365 L .19867 .54409 L F
.326 0 0 r
.79341 .50013 m .79519 .50024 L .79251 .49983 L F
.665 .555 .721 r
.79833 .50323 m .7982 .5031 L .79812 .50248 L F
.7982 .5031 m .79519 .50024 L .79812 .50248 L F
.753 .275 .108 r
.79341 .50013 m .79812 .50248 L .79519 .50024 L F
.79341 .50013 m .79653 .50318 L .79812 .50248 L F
.919 .978 .726 r
.79812 .50248 m .79653 .50318 L .79659 .50305 L F
.79812 .50248 m .79659 .50305 L .79786 .50039 L F
.79812 .50248 m .79786 .50039 L .79863 .49878 L F
.243 .324 .748 r
.79524 .49795 m .796 .50101 L .79341 .50013 L F
.796 .50101 m .79653 .50318 L .79341 .50013 L F
.326 0 0 r
.79341 .50013 m .79251 .49983 L .79155 .49968 L F
0 .018 .592 r
.49196 .71735 m .4905 .71538 L .49236 .71476 L F
.908 .935 .816 r
.78659 .48011 m .78487 .48276 L .78396 .48193 L F
.985 .707 .394 r
.46465 .70071 m .46398 .69821 L .46426 .70118 L F
.478 .729 .981 r
.77674 .48633 m .77429 .48516 L .77575 .48532 L F
.75 .888 .941 r
.77874 .48511 m .77674 .48633 L .77794 .48384 L F
.753 .891 .941 r
.77794 .48384 m .77674 .48633 L .77575 .48532 L F
.417 .069 .264 r
.65287 .46014 m .65236 .46164 L .64991 .46213 L F
.382 .037 .25 r
.65473 .46097 m .65287 .46014 L .6552 .45926 L F
.65473 .46097 m .65236 .46164 L .65287 .46014 L F
.463 .312 .59 r
.64418 .43294 m .64455 .43594 L .64615 .4328 L F
.434 .039 .188 r
.34071 .59001 m .34271 .59007 L .34444 .58754 L F
.297 0 .051 r
.34271 .59007 m .34678 .58723 L .34444 .58754 L F
.801 .483 .451 r
.45747 .68601 m .4594 .68588 L .45943 .68368 L F
.363 .131 .421 r
.45943 .68368 m .46136 .68329 L .45984 .68209 L F
.45943 .68368 m .4594 .68588 L .46136 .68329 L F
.964 .695 .263 r
.4594 .68588 m .45943 .68368 L .46136 .68329 L F
.726 .783 .898 r
.44573 .59622 m .44936 .59661 L .44825 .59537 L F
.502 .816 1 r
.44936 .59661 m .45035 .59534 L .44825 .59537 L F
.44936 .59661 m .45159 .59614 L .45035 .59534 L F
0 0 0 r
.5805 .63068 m .58237 .62801 L .58275 .62672 L F
.067 .139 .63 r
.58275 .62672 m .58446 .6268 L .58301 .62502 L F
.76 .743 .837 r
.3354 .63424 m .33309 .63652 L .33728 .63705 L F
0 0 0 r
.33728 .63705 m .33772 .63368 L .3354 .63424 L F
.33728 .63705 m .33955 .63434 L .33772 .63368 L F
.33728 .63705 m .33835 .63646 L .33955 .63434 L F
.33955 .63434 m .33835 .63646 L .33728 .63705 L F
.046 .139 .639 r
.3389 .63892 m .33728 .63705 L .33835 .63646 L F
.329 .092 .394 r
.54731 .68377 m .54916 .68534 L .54768 .68541 L F
.465 .093 .248 r
.5518 .68518 m .54833 .68761 L .54936 .68479 L F
.329 .092 .394 r
.54916 .68534 m .54919 .68536 L .54915 .68536 L F
.54916 .68534 m .54915 .68536 L .54768 .68541 L F
.5471 .68359 m .54919 .68536 L .54726 .68543 L F
.353 .256 .604 r
.54726 .68543 m .54915 .68536 L .54726 .68857 L F
.54915 .68536 m .54919 .68536 L .54916 .68541 L F
.54915 .68536 m .54916 .68541 L .54726 .68857 L F
.581 .538 .772 r
.54726 .68857 m .54916 .68541 L .54827 .68462 L F
.465 .093 .248 r
.54904 .68474 m .54892 .68519 L .54827 .68462 L F
.581 .538 .772 r
.54916 .68541 m .54919 .68536 L .54827 .68462 L F
.465 .093 .248 r
.54892 .68519 m .54824 .68767 L .54827 .68462 L F
.54936 .68479 m .54915 .68534 L .54904 .68474 L F
.54915 .68534 m .54824 .68767 L .54904 .68474 L F
.54833 .68761 m .54824 .68767 L .54936 .68479 L F
.581 .538 .772 r
.5482 .6877 m .54827 .68462 L .54824 .68767 L F
.54726 .68857 m .54786 .68621 L .5482 .6877 L F
.54786 .68621 m .54827 .68462 L .5482 .6877 L F
.329 .092 .394 r
.5471 .68359 m .54731 .68377 L .54726 .68543 L F
.54731 .68377 m .54768 .68541 L .54726 .68543 L F
.751 .648 .747 r
.53756 .65438 m .54075 .65452 L .5401 .6516 L F
.74 .473 .525 r
.54003 .65728 m .54075 .65452 L .53756 .65438 L F
.398 .715 .987 r
.37455 .62305 m .37377 .62434 L .37204 .6225 L F
.37455 .62305 m .3761 .62425 L .37377 .62434 L F
.592 .673 .896 r
.44438 .58806 m .44134 .58689 L .4432 .58665 L F
.642 .766 .938 r
.44557 .58601 m .44438 .58806 L .4432 .58665 L F
.369 .412 .775 r
.44557 .58601 m .4469 .5897 L .44438 .58806 L F
.493 .395 .673 r
.4469 .5897 m .44506 .59106 L .44438 .58806 L F
.734 .613 .724 r
.52765 .70743 m .52854 .70954 L .52615 .70941 L F
.994 .749 .423 r
.52854 .70954 m .52507 .71002 L .52615 .70941 L F
.52854 .70954 m .52738 .70907 L .52507 .71002 L F
.52854 .70954 m .52838 .71214 L .52738 .70907 L F
.435 .85 .961 r
.52738 .70907 m .52854 .70954 L .52765 .70743 L F
.52738 .70907 m .53096 .70891 L .52854 .70954 L F
.479 .266 .511 r
.53096 .70891 m .52838 .71214 L .52854 .70954 L F
.428 .448 .779 r
.32786 .61095 m .32894 .61418 L .33046 .61248 L F
.547 .494 .748 r
.32894 .61418 m .33196 .61632 L .33046 .61248 L F
.799 .729 .786 r
.64297 .4453 m .64667 .44447 L .64527 .44184 L F
.401 0 0 r
.64546 .44592 m .64667 .44447 L .64297 .4453 L F
.334 0 0 r
.64881 .44459 m .64667 .44447 L .64546 .44592 L F
.488 .108 .245 r
.53843 .67292 m .54108 .67372 L .53976 .67374 L F
.106 .482 .898 r
.33494 .62513 m .33495 .6239 L .33307 .62177 L F
.33494 .62513 m .33543 .62475 L .33495 .6239 L F
.355 .157 .468 r
.22617 .59521 m .22476 .59353 L .22637 .59277 L F
.22617 .59521 m .22441 .59592 L .22476 .59353 L F
0 0 0 r
.53044 .64658 m .52713 .6486 L .52924 .64752 L F
.502 .287 .519 r
.52924 .64752 m .53171 .64472 L .53044 .64658 L F
.723 .588 .704 r
.55432 .68933 m .55763 .69198 L .55667 .68893 L F
.806 .734 .785 r
.55763 .69198 m .55974 .68889 L .55667 .68893 L F
.727 .325 .288 r
.19536 .55566 m .19338 .55721 L .19423 .55477 L F
.797 .671 .726 r
.46407 .62522 m .46747 .62411 L .4628 .62203 L F
.95 .679 .225 r
.4677 .6254 m .46747 .62411 L .46407 .62522 L F
.124 .079 .53 r
.2084 .57843 m .20957 .57466 L .20866 .57601 L F
.788 .599 .645 r
.54557 .64857 m .54182 .64823 L .54215 .64581 L F
.86 .732 .72 r
.19835 .58886 m .19293 .58901 L .19317 .58791 L F
.824 .515 .467 r
.19835 .58886 m .19347 .59319 L .19293 .58901 L F
0 .529 .758 r
.19317 .58791 m .19576 .58827 L .19835 .58886 L F
.969 .899 .697 r
.19576 .58827 m .19347 .59319 L .19835 .58886 L F
.79 .775 .839 r
.78763 .48256 m .79088 .48277 L .7901 .4796 L F
.67 .65 .821 r
.79088 .48277 m .79348 .48051 L .7901 .4796 L F
.79088 .48277 m .79353 .48201 L .79348 .48051 L F
.493 .409 .689 r
.3268 .60501 m .32826 .60125 L .32628 .60258 L F
.577 .721 .941 r
.23583 .55407 m .23449 .55577 L .23315 .55228 L F
.23583 .55407 m .2366 .55529 L .23449 .55577 L F
.584 .824 .99 r
.38107 .58106 m .3826 .58213 L .37895 .58178 L F
.579 .822 .99 r
.38479 .58145 m .3826 .58213 L .38107 .58106 L F
.421 .171 .427 r
.57856 .6494 m .58126 .64605 L .57867 .64726 L F
0 0 0 r
.47046 .68166 m .46823 .68388 L .47038 .68244 L F
.521 .535 .811 r
.46823 .68388 m .47163 .68494 L .47038 .68244 L F
.136 .198 .664 r
.45117 .58949 m .45011 .59105 L .44842 .58996 L F
0 .272 .694 r
.45011 .59105 m .45265 .59231 L .45529 .59428 L F
.462 .263 .522 r
.45136 .59339 m .45343 .59338 L .45347 .59282 L F
.886 .962 .84 r
.45529 .59428 m .45316 .59266 L .45546 .59034 L F
.45316 .59266 m .4528 .59239 L .45337 .59195 L F
.45316 .59266 m .45337 .59195 L .45546 .59034 L F
0 .272 .694 r
.45265 .59231 m .45296 .59251 L .45529 .59428 L F
.7 .434 .519 r
.45546 .59034 m .4528 .59239 L .45117 .58949 L F
.45546 .59034 m .45117 .58949 L .45361 .59062 L F
.801 .932 .919 r
.45546 .59034 m .45361 .59062 L .45602 .58848 L F
.67 .964 .762 r
.45361 .59062 m .4544 .58928 L .45602 .58848 L F
.589 .583 .813 r
.45343 .59338 m .4544 .58928 L .45391 .59011 L F
.45357 .59127 m .45391 .59011 L .45361 .59062 L F
.45343 .59338 m .45391 .59011 L .45357 .59127 L F
.462 .263 .522 r
.45261 .59185 m .45347 .59282 L .45361 .59062 L F
.136 .198 .664 r
.45263 .59208 m .4528 .59239 L .45265 .59231 L F
.45263 .59208 m .45265 .59231 L .45011 .59105 L F
0 .272 .694 r
.45265 .59231 m .4528 .59239 L .45296 .59251 L F
.462 .263 .522 r
.45136 .59339 m .45347 .59282 L .45261 .59185 L F
.136 .198 .664 r
.45089 .58991 m .45263 .59208 L .45011 .59105 L F
.45117 .58949 m .45231 .59152 L .45089 .58991 L F
.45231 .59152 m .45263 .59208 L .45089 .58991 L F
.462 .263 .522 r
.45019 .59076 m .45251 .59066 L .44994 .59022 L F
.45251 .59066 m .45361 .59062 L .4525 .5905 L F
.45251 .59066 m .4525 .5905 L .44994 .59022 L F
.45136 .59339 m .45238 .59214 L .45019 .59076 L F
.45238 .59214 m .45361 .59062 L .45019 .59076 L F
0 0 .364 r
.46398 .69821 m .4641 .69511 L .46291 .69705 L F
.982 .695 .38 r
.46291 .70024 m .46398 .69821 L .46291 .69705 L F
.46291 .70024 m .46426 .70118 L .46398 .69821 L F
.792 .943 .924 r
.6367 .44229 m .63424 .44311 L .63618 .4419 L F
.706 .984 .879 r
.6367 .44229 m .63618 .4419 L .63816 .44017 L F
.303 .517 .897 r
.36621 .61194 m .36541 .61358 L .3633 .61092 L F
0 .057 .588 r
.36621 .61194 m .36675 .6155 L .36541 .61358 L F
.159 .125 .567 r
.36675 .6155 m .3658 .61633 L .36541 .61358 L F
.606 .636 .854 r
.52431 .73104 m .52517 .72826 L .5227 .72971 L F
.52431 .73104 m .52658 .73019 L .52517 .72826 L F
.511 .491 .771 r
.76353 .49746 m .76456 .50106 L .76665 .49893 L F
.574 .592 .834 r
.76456 .50106 m .76707 .50067 L .76665 .49893 L F
.374 0 .038 r
.34905 .58681 m .35141 .58651 L .35285 .58487 L F
.362 0 0 r
.35141 .58651 m .3552 .58479 L .35285 .58487 L F
0 0 0 r
.2418 .56176 m .23918 .56206 L .23782 .56216 L F
.552 .451 .693 r
.24345 .55872 m .2418 .56176 L .24065 .55807 L F
.24345 .55872 m .24409 .5613 L .2418 .56176 L F
.42 .866 .878 r
.24253 .56102 m .2418 .56176 L .24409 .5613 L F
.24253 .56102 m .23918 .56206 L .2418 .56176 L F
.202 0 0 r
.19604 .57435 m .19719 .57468 L .1999 .57301 L F
0 0 0 r
.1999 .57301 m .19939 .57354 L .20135 .57495 L F
.1999 .57301 m .19719 .57468 L .19939 .57354 L F
.488 .034 .098 r
.43432 .62569 m .43296 .62739 L .4306 .62723 L F
.391 0 0 r
.43701 .62586 m .43296 .62739 L .43432 .62569 L F
.475 .147 .329 r
.49929 .64833 m .50172 .64786 L .5025 .64566 L F
.662 .332 .405 r
.50172 .64786 m .5048 .64785 L .5025 .64566 L F
.67 .329 .387 r
.5048 .64785 m .50513 .64615 L .5025 .64566 L F
.082 .456 .884 r
.22436 .5471 m .22381 .54787 L .22198 .54673 L F
.22436 .5471 m .22579 .54869 L .22381 .54787 L F
.466 .25 .501 r
.48131 .70391 m .48457 .70049 L .48062 .70083 L F
.48131 .70391 m .48518 .7036 L .48457 .70049 L F
.487 .329 .593 r
.48165 .70662 m .48518 .7036 L .48131 .70391 L F
.867 .851 .826 r
.65368 .44019 m .65473 .4417 L .65183 .44499 L F
.623 .771 .952 r
.65702 .44075 m .65473 .4417 L .65368 .44019 L F
.184 .488 .9 r
.55388 .63298 m .55028 .63019 L .55319 .63173 L F
.639 .557 .747 r
.6444 .43809 m .64259 .44275 L .64121 .441 L F
.854 .55 .473 r
.53899 .64278 m .53932 .63897 L .54013 .64055 L F
.65 .093 0 r
.54013 .64055 m .54258 .64243 L .54419 .64276 L F
.838 .37 .041 r
.53932 .63897 m .54258 .64243 L .54013 .64055 L F
.174 .201 .648 r
.80205 .48965 m .80308 .48758 L .80149 .48568 L F
.991 .736 .382 r
.58614 .60834 m .58527 .60746 L .58519 .60472 L F
.993 .847 .589 r
.58464 .60981 m .58614 .60834 L .5854 .61066 L F
.58464 .60981 m .58527 .60746 L .58614 .60834 L F
.687 .575 .724 r
.54944 .68065 m .55207 .67807 L .54864 .67752 L F
.833 .848 .858 r
.32934 .62076 m .33073 .62184 L .33307 .6195 L F
.462 .725 .982 r
.33073 .62184 m .33307 .62177 L .33307 .6195 L F
.567 .831 .995 r
.28079 .73418 m .27985 .73588 L .27797 .73445 L F
.28079 .73418 m .28179 .7352 L .27985 .73588 L F
.28079 .73418 m .27985 .73588 L .27797 .73445 L F
.28079 .73418 m .28179 .7352 L .27985 .73588 L F
.5 .313 .558 r
.53596 .65999 m .5353 .66275 L .53313 .66311 L F
0 .233 .748 r
.54967 .65742 m .5494 .65651 L .54675 .65439 L F
.376 0 .004 r
.40847 .63201 m .41023 .63276 L .40803 .63299 L F
.386 .143 .418 r
.4781 .71561 m .481 .71233 L .47741 .71217 L F
.4781 .71561 m .48056 .71535 L .481 .71233 L F
.645 .457 .615 r
.4781 .71561 m .48097 .71761 L .48056 .71535 L F
.4781 .71561 m .47843 .71817 L .48097 .71761 L F
.521 .272 .478 r
.79348 .48051 m .79556 .47721 L .79226 .47709 L F
.79348 .48051 m .79586 .4794 L .79556 .47721 L F
.637 .353 .47 r
.79556 .47721 m .79586 .4794 L .79852 .47908 L F
.614 .066 0 r
.53403 .63628 m .53544 .63699 L .53704 .63697 L F
0 .346 .742 r
.53544 .63699 m .53932 .63897 L .53704 .63697 L F
.184 0 0 r
.38549 .62541 m .38784 .62512 L .38914 .62446 L F
.401 0 0 r
.38914 .62446 m .38784 .62512 L .39133 .62462 L F
0 0 .47 r
.4954 .7073 m .49649 .70803 L .49377 .706 L F
.141 0 0 r
.47038 .68244 m .47295 .68146 L .47046 .68166 L F
.923 .534 .172 r
.36502 .64234 m .36403 .64197 L .36361 .64096 L F
.805 .975 .902 r
.36612 .64019 m .36502 .64234 L .36785 .64046 L F
.36612 .64019 m .36403 .64197 L .36502 .64234 L F
.393 .807 .977 r
.46407 .62522 m .46655 .62483 L .4677 .6254 L F
.821 .949 .904 r
.46891 .62246 m .4677 .6254 L .46655 .62483 L F
.46891 .62246 m .47068 .62309 L .4677 .6254 L F
.173 .475 .894 r
.47197 .69163 m .47442 .6944 L .47565 .69442 L F
.393 .243 .557 r
.22006 .60468 m .21828 .60791 L .21823 .60566 L F
.576 0 0 r
.54007 .62063 m .53925 .61934 L .53776 .61879 L F
.54007 .62063 m .54179 .62107 L .53925 .61934 L F
.528 .389 .635 r
.50846 .64581 m .5116 .64612 L .51088 .6436 L F
.518 .216 .395 r
.51023 .64683 m .5116 .64612 L .50846 .64581 L F
.796 .573 .6 r
.5048 .64785 m .50846 .64581 L .50513 .64615 L F
.655 .662 .845 r
.20155 .58613 m .19823 .58445 L .19955 .58526 L F
.818 .91 .902 r
.20155 .58613 m .20206 .58337 L .204 .58456 L F
.20155 .58613 m .19955 .58526 L .20206 .58337 L F
.204 0 0 r
.40258 .58025 m .40481 .58031 L .40608 .57989 L F
0 0 0 r
.40608 .57989 m .40707 .57961 L .40827 .57967 L F
.40608 .57989 m .40481 .58031 L .40707 .57961 L F
.532 .284 .484 r
.3329 .63404 m .3354 .63424 L .33593 .63111 L F
.514 .268 .479 r
.33593 .63111 m .3354 .63424 L .33772 .63368 L F
.78 .276 0 r
.33593 .63111 m .33772 .63368 L .33955 .63434 L F
0 .203 .664 r
.52468 .67847 m .52521 .67854 L .52583 .67662 L F
.52468 .67847 m .52685 .67991 L .52521 .67854 L F
.661 .109 0 r
.53727 .62218 m .53778 .6235 L .53616 .62151 L F
.53727 .62218 m .53916 .62391 L .53778 .6235 L F
.558 .666 .91 r
.65739 .42895 m .65531 .43091 L .65447 .4274 L F
.65739 .42895 m .65753 .43069 L .65531 .43091 L F
.21 .722 .888 r
.50856 .66021 m .50783 .65991 L .50496 .66017 L F
.93 .971 .71 r
.50974 .65662 m .50856 .66021 L .51095 .65932 L F
.50974 .65662 m .50783 .65991 L .50856 .66021 L F
.749 .622 .718 r
.60655 .46392 m .60276 .46492 L .60478 .46264 L F
.719 .518 .617 r
.60655 .46392 m .60499 .46795 L .60276 .46492 L F
.716 .634 .764 r
.6071 .46194 m .60655 .46392 L .60478 .46264 L F
.707 .504 .612 r
.6085 .46769 m .60499 .46795 L .60655 .46392 L F
.667 .43 .553 r
.53984 .69214 m .54019 .69475 L .53656 .69488 L F
.58 .37 .56 r
.54243 .69208 m .54019 .69475 L .53984 .69214 L F
.668 .729 .895 r
.59693 .66273 m .59797 .65939 L .59534 .66027 L F
.59693 .66273 m .59885 .66183 L .59797 .65939 L F
.705 .783 .912 r
.59693 .66273 m .59534 .66027 L .59328 .66224 L F
.73 .495 .572 r
.62022 .46547 m .62039 .46777 L .61849 .46776 L F
.744 .532 .608 r
.5305 .65149 m .52698 .65137 L .52713 .6486 L F
.461 .299 .574 r
.52698 .65137 m .52924 .64752 L .52713 .6486 L F
.575 .305 .47 r
.481 .71233 m .48056 .71535 L .48304 .71491 L F
.769 .261 0 r
.481 .71233 m .48304 .71491 L .48457 .71515 L F
.532 .339 .565 r
.32708 .61957 m .32701 .62217 L .32934 .62076 L F
.434 .22 .487 r
.36244 .6045 m .36009 .60748 L .36025 .60504 L F
.82 .353 .106 r
.54377 .64423 m .54419 .64276 L .54258 .64243 L F
.54377 .64423 m .54606 .64543 L .54419 .64276 L F
.576 .189 .273 r
.38506 .59331 m .38372 .59531 L .38119 .5953 L F
.538 .147 .249 r
.38684 .59476 m .38506 .59331 L .38746 .59316 L F
.38684 .59476 m .38372 .59531 L .38506 .59331 L F
.708 .784 .911 r
.49597 .65735 m .49513 .6589 L .49416 .65625 L F
.49416 .65625 m .49513 .6589 L .49597 .65735 L F
.421 .171 .427 r
.57856 .6494 m .58103 .64863 L .58126 .64605 L F
.674 .698 .864 r
.4252 .58764 m .42673 .59049 L .42892 .58937 L F
.236 0 0 r
.2389 .55644 m .24188 .55627 L .24065 .55807 L F
.562 .607 .856 r
.24188 .55627 m .24345 .55872 L .24065 .55807 L F
0 0 .043 r
.49507 .68842 m .49398 .68926 L .4955 .68636 L F
.226 .121 .519 r
.49721 .68432 m .4955 .68636 L .49476 .68308 L F
.49721 .68432 m .49758 .68534 L .4955 .68636 L F
.789 .987 .733 r
.6379 .42597 m .63654 .42855 L .63939 .42811 L F
.6379 .42597 m .63542 .42889 L .63654 .42855 L F
.63 .066 0 r
.54097 .71271 m .54298 .71393 L .54308 .71295 L F
.599 .578 .801 r
.48827 .65138 m .49188 .65425 L .49162 .65182 L F
.579 .443 .66 r
.49188 .65425 m .49403 .65129 L .49162 .65182 L F
.744 .477 .527 r
.41136 .62092 m .41478 .61863 L .41187 .61996 L F
.556 .528 .779 r
.55432 .68933 m .55611 .68565 L .55338 .68627 L F
.55432 .68933 m .55667 .68893 L .55611 .68565 L F
.259 .299 .714 r
.58437 .65987 m .58496 .66312 L .58619 .66152 L F
.452 .574 .886 r
.58496 .66312 m .58768 .66316 L .58619 .66152 L F
.98 .699 .317 r
.42873 .61731 m .4294 .61829 L .42957 .61664 L F
.376 .599 .934 r
.54046 .62488 m .54149 .62385 L .53916 .62391 L F
.54046 .62488 m .5428 .62536 L .54149 .62385 L F
.717 .861 .95 r
.55974 .68889 m .55885 .68782 L .55667 .68893 L F
.76 .661 .753 r
.55974 .68889 m .55875 .68703 L .55885 .68782 L F
.55974 .68889 m .5606 .68611 L .55875 .68703 L F
0 0 0 r
.4712 .62814 m .47387 .62563 L .47277 .6269 L F
.204 0 .061 r
.47277 .6269 m .47387 .62563 L .47594 .62483 L F
.243 .727 .929 r
.40827 .57967 m .41066 .57949 L .41243 .58007 L F
.509 .854 .994 r
.41066 .57949 m .41467 .57962 L .41243 .58007 L F
.087 0 .265 r
.5135 .68736 m .51372 .68856 L .51259 .68885 L F
.309 .17 .524 r
.51419 .69116 m .51259 .68885 L .51372 .68856 L F
.51419 .69116 m .51207 .69301 L .51259 .68885 L F
0 0 0 r
.55198 .66257 m .55328 .66153 L .55469 .65922 L F
0 0 .453 r
.55228 .66454 m .55328 .66153 L .55198 .66257 L F
.482 .5 .799 r
.44226 .58344 m .44134 .58689 L .4399 .58407 L F
.44226 .58344 m .4432 .58665 L .44134 .58689 L F
.874 .94 .858 r
.47137 .62155 m .47068 .62309 L .46891 .62246 L F
0 .349 .729 r
.47253 .61987 m .47068 .62309 L .47137 .62155 L F
.733 .656 .774 r
.57628 .65449 m .57763 .65791 L .58014 .65519 L F
.806 .688 .734 r
.48909 .70967 m .48638 .71213 L .48525 .7097 L F
.48909 .70967 m .48638 .71213 L .48525 .7097 L F
.91 .526 .275 r
.48807 .71111 m .48909 .70967 L .48788 .70874 L F
.48807 .71111 m .48946 .71176 L .48909 .70967 L F
.556 .351 .558 r
.52978 .70096 m .52972 .7036 L .52713 .70379 L F
0 0 .463 r
.53032 .69737 m .52978 .70096 L .53179 .69793 L F
.53032 .69737 m .53067 .69943 L .52978 .70096 L F
0 .029 .558 r
.52978 .70096 m .53096 .70208 L .52972 .7036 L F
.52978 .70096 m .53067 .69943 L .53096 .70208 L F
.659 .402 .52 r
.62756 .46828 m .62397 .47068 L .62392 .46822 L F
.62756 .46828 m .62703 .47046 L .62397 .47068 L F
.62 .196 .216 r
.62756 .46828 m .62995 .46977 L .62703 .47046 L F
.62756 .46828 m .62999 .46861 L .62995 .46977 L F
.421 .759 .995 r
.55176 .62814 m .55225 .62767 L .54968 .62745 L F
.509 .124 .246 r
.50974 .65662 m .51223 .65657 L .51388 .65422 L F
.76 .246 0 r
.51475 .65629 m .51388 .65422 L .51223 .65657 L F
.176 .193 .639 r
.52854 .70554 m .52765 .70743 L .52713 .70379 L F
.435 .85 .961 r
.52738 .70907 m .52765 .70743 L .52854 .70554 L F
.142 0 0 r
.46796 .63105 m .4712 .62814 L .47015 .63014 L F
0 0 0 r
.47015 .63014 m .4712 .62814 L .47277 .6269 L F
.872 .442 .035 r
.48892 .71968 m .48896 .71985 L .49058 .72076 L F
.204 .683 .933 r
.49163 .72136 m .49058 .72076 L .48799 .72062 L F
.824 .35 0 r
.48694 .7195 m .48675 .71998 L .48511 .71752 L F
.48799 .72062 m .48675 .71998 L .48694 .7195 L F
.367 0 0 r
.49058 .72076 m .48675 .71998 L .48799 .72062 L F
.49058 .72076 m .48977 .72102 L .48675 .71998 L F
.48977 .72102 m .48933 .72116 L .48836 .72071 L F
.48977 .72102 m .48836 .72071 L .48675 .71998 L F
.786 .474 .461 r
.48675 .71998 m .48532 .71675 L .48511 .71752 L F
0 0 0 r
.48511 .71752 m .48591 .71456 L .48457 .71515 L F
.786 .474 .461 r
.48675 .71998 m .48339 .71767 L .48532 .71675 L F
.48675 .71998 m .48221 .71957 L .48339 .71767 L F
.322 .009 .27 r
.4843 .71984 m .48751 .71973 L .48384 .71886 L F
.48645 .72075 m .48527 .72189 L .48675 .71998 L F
.581 .453 .672 r
.48527 .72189 m .48221 .71957 L .48675 .71998 L F
.322 .009 .27 r
.48527 .72189 m .48683 .72038 L .4843 .71984 L F
.48751 .71973 m .48645 .72075 L .48675 .71998 L F
.48683 .72038 m .48751 .71973 L .4843 .71984 L F
.872 .442 .035 r
.48896 .71985 m .48933 .72116 L .49058 .72076 L F
.204 .683 .933 r
.49168 .72137 m .49058 .72076 L .49163 .72136 L F
.967 .9 .702 r
.49196 .71735 m .49058 .72076 L .49168 .72137 L F
.96 .627 .255 r
.78628 .50819 m .78684 .51056 L .78781 .51049 L F
.36 .339 .701 r
.45456 .69165 m .45709 .69403 L .45804 .692 L F
.599 .027 0 r
.45885 .6934 m .45804 .692 L .45709 .69403 L F
.45885 .6934 m .46077 .69414 L .45804 .692 L F
.296 .732 .968 r
.20077 .54365 m .20276 .54358 L .20455 .54433 L F
.286 .74 .956 r
.20276 .54358 m .20662 .54407 L .20455 .54433 L F
.811 .929 .911 r
.33838 .63252 m .33955 .63434 L .34135 .6335 L F
.33838 .63252 m .33772 .63368 L .33955 .63434 L F
.059 0 0 r
.33772 .63368 m .34135 .6335 L .33955 .63434 L F
.908 .935 .816 r
.78659 .48011 m .78666 .48067 L .78696 .47984 L F
.78659 .48011 m .78396 .48193 L .78666 .48067 L F
.497 .265 .492 r
.49907 .66247 m .49798 .66096 L .49676 .66294 L F
.986 .739 .471 r
.51711 .67933 m .51838 .68035 L .51843 .67768 L F
.023 0 0 r
.52052 .6773 m .51711 .67933 L .51843 .67768 L F
.52052 .6773 m .51863 .67896 L .51711 .67933 L F
0 .08 .617 r
.52086 .6735 m .52166 .67647 L .52052 .6773 L F
0 0 0 r
.52166 .67647 m .51863 .67896 L .52052 .6773 L F
.935 .806 .347 r
.55891 .66736 m .55938 .66897 L .55983 .66446 L F
.55978 .66447 m .55983 .66446 L .55985 .66426 L F
.55891 .66736 m .55983 .66446 L .55978 .66447 L F
.726 .212 0 r
.55657 .66182 m .55882 .66448 L .55908 .66463 L F
.55937 .66456 m .55908 .66463 L .55989 .66507 L F
.55657 .66182 m .55908 .66463 L .55937 .66456 L F
.935 .806 .347 r
.55891 .66736 m .55985 .66426 L .55989 .66507 L F
.803 .656 .104 r
.59274 .60912 m .59296 .60859 L .59218 .60675 L F
.59274 .60912 m .59285 .61043 L .59296 .60859 L F
.313 0 .058 r
.48627 .68782 m .48833 .68736 L .48958 .68542 L F
.243 0 0 r
.48958 .68542 m .49153 .68547 L .49273 .6843 L F
.265 0 .032 r
.48958 .68542 m .48833 .68736 L .49153 .68547 L F
.292 .306 .704 r
.35138 .63337 m .35207 .63748 L .35336 .63508 L F
.584 .67 .898 r
.35207 .63748 m .35503 .63745 L .35336 .63508 L F
.665 .289 .323 r
.49394 .69221 m .48749 .69364 L .48755 .69223 L F
.49394 .69221 m .48996 .69444 L .48749 .69364 L F
.687 .323 .351 r
.49353 .69424 m .48996 .69444 L .49394 .69221 L F
.285 0 0 r
.39147 .63659 m .39049 .63725 L .38813 .63745 L F
.268 0 0 r
.39231 .63752 m .39147 .63659 L .39382 .63637 L F
.39231 .63752 m .39049 .63725 L .39147 .63659 L F
.095 .295 .774 r
.46567 .70657 m .46674 .70826 L .46479 .70658 L F
.176 .193 .639 r
.52854 .70554 m .52713 .70379 L .52972 .7036 L F
.814 .829 .861 r
.80191 .50601 m .79888 .5059 L .80116 .50431 L F
.665 .758 .919 r
.80527 .5047 m .80191 .50601 L .80116 .50431 L F
0 0 .203 r
.48457 .71515 m .48591 .71456 L .48638 .71213 L F
.331 .804 .914 r
.48457 .71515 m .48304 .71491 L .48591 .71456 L F
.48457 .71515 m .48304 .71491 L .48591 .71456 L F
.884 .517 .343 r
.54929 .64827 m .55 .65044 L .5511 .64875 L F
.888 .523 .346 r
.55 .65044 m .552 .65093 L .5511 .64875 L F
.51 .022 .033 r
.58336 .63396 m .58355 .6354 L .58446 .63694 L F
.58336 .63396 m .58523 .63406 L .58355 .6354 L F
.51 .293 .52 r
.79833 .50323 m .79888 .5059 L .79584 .5064 L F
.571 .775 .975 r
.79985 .5016 m .79833 .50323 L .79812 .50248 L F
.579 .337 .514 r
.80116 .50431 m .79833 .50323 L .79985 .5016 L F
.80116 .50431 m .79888 .5059 L .79833 .50323 L F
.795 .756 .817 r
.6509 .44357 m .65183 .44499 L .64881 .44459 L F
.867 .851 .826 r
.65368 .44019 m .65183 .44499 L .6509 .44357 L F
.682 .649 .81 r
.79353 .48201 m .79707 .48337 L .79586 .4794 L F
.558 .572 .824 r
.79586 .4794 m .79707 .48337 L .79919 .48279 L F
.596 .603 .829 r
.77348 .50251 m .77465 .50586 L .77719 .50513 L F
.119 .579 .919 r
.36785 .64046 m .36889 .63999 L .36612 .64019 L F
.36785 .64046 m .37006 .64073 L .36889 .63999 L F
.763 .48 .505 r
.49246 .7029 m .49638 .70319 L .49685 .70124 L F
.121 0 .278 r
.49685 .70124 m .49638 .70319 L .49815 .70043 L F
.568 .112 .13 r
.58064 .59528 m .58404 .59492 L .58162 .59353 L F
.563 .107 .128 r
.57805 .59495 m .58064 .59528 L .58162 .59353 L F
.114 .539 .915 r
.3578 .63726 m .35849 .6367 L .35697 .63609 L F
.3578 .63726 m .36091 .63831 L .35849 .6367 L F
.859 .47 .306 r
.45446 .62426 m .45465 .62275 L .45299 .62247 L F
.667 .378 .474 r
.45446 .62426 m .45816 .62228 L .45465 .62275 L F
.985 .724 .441 r
.33196 .61632 m .33307 .6195 L .33174 .61844 L F
.417 .518 .853 r
.33307 .62177 m .33174 .61844 L .33307 .6195 L F
.913 .641 .511 r
.49581 .65465 m .49597 .65735 L .49416 .65625 L F
0 0 0 r
.49651 .65083 m .49581 .65465 L .49697 .65397 L F
.123 .028 .464 r
.49581 .65465 m .49671 .65558 L .49697 .65397 L F
0 0 .284 r
.49647 .65578 m .49597 .65735 L .49581 .65465 L F
.49647 .65578 m .49581 .65465 L .49416 .65625 L F
0 0 .463 r
.45835 .69918 m .45793 .70093 L .45887 .70303 L F
.28 .151 .52 r
.23382 .57422 m .23195 .57324 L .2343 .57147 L F
.23382 .57422 m .23182 .57543 L .23195 .57324 L F
.226 .683 .949 r
.39066 .58092 m .39289 .58101 L .39444 .58178 L F
.261 .737 .937 r
.39289 .58101 m .39674 .58141 L .39444 .58178 L F
.722 .502 .592 r
.55082 .60217 m .55048 .60443 L .54718 .60462 L F
0 0 0 r
.55312 .60198 m .55048 .60443 L .55082 .60217 L F
.729 .558 .661 r
.50332 .66068 m .5027 .66286 L .50496 .66017 L F
.496 .462 .749 r
.50677 .65542 m .50761 .65734 L .50474 .65748 L F
.474 .416 .712 r
.50496 .66017 m .50677 .65542 L .50474 .65748 L F
.50496 .66017 m .50783 .65991 L .50677 .65542 L F
.41 0 0 r
.56973 .59566 m .57194 .59618 L .57087 .59566 L F
.421 0 0 r
.57194 .59618 m .57551 .59558 L .57087 .59566 L F
.489 .204 .408 r
.54165 .68717 m .54366 .68876 L .54412 .68664 L F
0 .124 .619 r
.54277 .688 m .54366 .68876 L .54165 .68717 L F
.411 .025 .192 r
.53866 .68855 m .54277 .688 L .54165 .68717 L F
.686 .965 .741 r
.64158 .44346 m .64279 .44301 L .64259 .44275 L F
.711 .863 .954 r
.39066 .58092 m .38854 .5821 L .38704 .58109 L F
0 .148 .665 r
.80149 .48568 m .80308 .48758 L .80211 .48403 L F
.444 0 0 r
.39133 .62462 m .39354 .62497 L .39486 .62453 L F
.337 0 0 r
.39486 .62453 m .39354 .62497 L .39721 .62468 L F
.523 .461 .728 r
.32724 .6077 m .32878 .60459 L .3268 .60501 L F
.32724 .6077 m .3301 .6071 L .32878 .60459 L F
.408 .301 .621 r
.32786 .61095 m .3301 .6071 L .32724 .6077 L F
.105 0 0 r
.40323 .62223 m .4039 .62323 L .40528 .62124 L F
.40323 .62223 m .40182 .62399 L .4039 .62323 L F
.465 .117 .29 r
.3656 .60228 m .36486 .60422 L .36244 .6045 L F
.215 0 .179 r
.3667 .60336 m .3656 .60228 L .36793 .60089 L F
.3667 .60336 m .36486 .60422 L .3656 .60228 L F
.826 .678 .699 r
.57522 .62348 m .57467 .62123 L .57589 .62226 L F
.572 .576 .819 r
.57733 .61878 m .57589 .62226 L .57467 .62123 L F
.57733 .61878 m .57835 .62142 L .57589 .62226 L F
.376 .049 .277 r
.57835 .62142 m .57522 .62348 L .57589 .62226 L F
.768 .528 .572 r
.50145 .70636 m .5019 .70352 L .4998 .70348 L F
.50145 .70636 m .50519 .70729 L .5019 .70352 L F
.493 .409 .689 r
.3268 .60501 m .32878 .60459 L .32826 .60125 L F
.112 .6 .909 r
.21026 .54498 m .21253 .54537 L .214 .54615 L F
0 .564 .726 r
.21253 .54537 m .21626 .54556 L .214 .54615 L F
.295 .138 .49 r
.20615 .63647 m .20607 .63892 L .20418 .63984 L F
.216 .018 .383 r
.20607 .63892 m .20382 .64223 L .20418 .63984 L F
.506 0 0 r
.37404 .64066 m .37218 .64134 L .37006 .64073 L F
.295 0 0 r
.37622 .63997 m .37218 .64134 L .37404 .64066 L F
.731 .313 .256 r
.47455 .67567 m .47483 .67666 L .47571 .67503 L F
.878 .876 .83 r
.57941 .61556 m .58306 .61362 L .58108 .61649 L F
.57941 .61556 m .58188 .61237 L .58306 .61362 L F
.686 .912 .577 r
.58392 .6121 m .58306 .61362 L .58188 .61237 L F
.58392 .6121 m .5854 .61066 L .58306 .61362 L F
.393 .243 .557 r
.22006 .60468 m .21983 .60733 L .21828 .60791 L F
.322 .16 .501 r
.21983 .60733 m .21824 .61038 L .21828 .60791 L F
.844 .642 .63 r
.60341 .64203 m .60508 .6453 L .6057 .6429 L F
.338 .359 .736 r
.58347 .65735 m .58429 .65371 L .58232 .65415 L F
.58347 .65735 m .58535 .65596 L .58429 .65371 L F
.316 .319 .704 r
.58584 .65935 m .58535 .65596 L .58347 .65735 L F
.321 .32 .702 r
.58437 .65987 m .58584 .65935 L .58347 .65735 L F
.363 .254 .594 r
.52084 .68209 m .51917 .68428 L .51933 .68256 L F
.293 0 0 r
.3552 .58479 m .35765 .5845 L .35863 .58362 L F
.341 0 0 r
.35765 .5845 m .36119 .58332 L .35863 .58362 L F
.693 .408 0 r
.55032 .65969 m .5494 .65651 L .54967 .65742 L F
.795 .558 .579 r
.7901 .4796 m .79348 .48051 L .79226 .47709 L F
.295 .267 .657 r
.48144 .6128 m .47958 .61421 L .47938 .61067 L F
.431 .474 .803 r
.48144 .6128 m .48083 .61648 L .47958 .61421 L F
.711 .907 .545 r
.44786 .59129 m .44842 .58996 L .45011 .59105 L F
.44786 .59129 m .44699 .59218 L .44842 .58996 L F
.869 .778 .759 r
.44985 .6164 m .45258 .61649 L .45185 .61546 L F
.44985 .6164 m .4509 .61939 L .45258 .61649 L F
.783 .663 .731 r
.49586 .71247 m .4963 .71542 L .49236 .71476 L F
.647 .142 .032 r
.4963 .71542 m .49488 .71647 L .49236 .71476 L F
0 0 .485 r
.49694 .71419 m .4963 .71542 L .49586 .71247 L F
.686 .933 .634 r
.49694 .71419 m .49488 .71647 L .4963 .71542 L F
.62 .585 .792 r
.19604 .57435 m .19932 .57635 L .19719 .57468 L F
.415 .2 .476 r
.44748 .61661 m .44723 .61891 L .44985 .6164 L F
0 .468 .861 r
.2203 .5455 m .22025 .54618 L .21832 .54574 L F
.2203 .5455 m .22198 .54673 L .22025 .54618 L F
.814 .796 .835 r
.80875 .50135 m .80706 .50282 L .81007 .50284 L F
.994 .874 .575 r
.81007 .50284 m .80987 .49987 L .80875 .50135 L F
0 0 0 r
.41364 .58647 m .41214 .58664 L .40982 .5868 L F
.41596 .58583 m .41214 .58664 L .41364 .58647 L F
.611 .344 .488 r
.48457 .70049 m .48518 .7036 L .48686 .70311 L F
.749 .322 .236 r
.48457 .70049 m .48686 .70311 L .48799 .70265 L F
.453 0 .073 r
.46701 .6941 m .46562 .6964 L .4641 .69511 L F
.384 0 0 r
.46659 .69503 m .46673 .69503 L .46701 .6941 L F
0 0 0 r
.46864 .69383 m .46673 .69503 L .46701 .6941 L F
.652 .77 .935 r
.46864 .69383 m .46673 .69503 L .46668 .69499 L F
0 0 0 r
.46864 .69383 m .46658 .69505 L .46701 .6941 L F
.46619 .69592 m .46562 .6964 L .46639 .69512 L F
.46659 .69503 m .46639 .69512 L .46701 .6941 L F
.46619 .69592 m .46639 .69512 L .46659 .69503 L F
.384 0 0 r
.4641 .69511 m .46659 .69503 L .46701 .6941 L F
.491 .722 .974 r
.46515 .69386 m .46668 .69499 L .4641 .69511 L F
.46668 .69499 m .46673 .69503 L .46659 .69503 L F
.46668 .69499 m .46659 .69503 L .4641 .69511 L F
.652 .77 .935 r
.46864 .69383 m .46668 .69499 L .46515 .69386 L F
0 0 0 r
.46864 .69383 m .46619 .69592 L .46658 .69505 L F
.66 .661 .84 r
.76707 .50067 m .771 .50306 L .76972 .50012 L F
.578 .704 .928 r
.771 .50306 m .77338 .50117 L .76972 .50012 L F
.771 .50306 m .77348 .50251 L .77338 .50117 L F
.537 .616 .879 r
.36281 .60895 m .36137 .61111 L .36009 .60748 L F
.36281 .60895 m .3633 .61092 L .36137 .61111 L F
.899 .954 .826 r
.63313 .42522 m .62848 .42771 L .63188 .42381 L F
.791 .902 .919 r
.63432 .42237 m .63313 .42522 L .63188 .42381 L F
.63432 .42237 m .63534 .42349 L .63313 .42522 L F
.431 .474 .803 r
.48144 .6128 m .4819 .6154 L .48083 .61648 L F
.092 0 .397 r
.48083 .61648 m .48241 .61802 L .48103 .61927 L F
.48083 .61648 m .4819 .6154 L .48241 .61802 L F
.455 .665 .953 r
.64487 .42306 m .64481 .42465 L .64378 .42296 L F
0 0 .402 r
.64539 .42458 m .64481 .42465 L .64487 .42306 L F
0 .216 .727 r
.45993 .70692 m .46215 .70936 L .46231 .70873 L F
0 0 .47 r
.46231 .70873 m .46215 .70936 L .46351 .7117 L F
.975 .842 .647 r
.59258 .61222 m .59296 .61634 L .59337 .61391 L F
.538 .426 .674 r
.23533 .56369 m .23568 .56648 L .23364 .56691 L F
.381 .238 .559 r
.23568 .56648 m .23384 .56998 L .23364 .56691 L F
.609 .729 .931 r
.52317 .67081 m .5231 .67179 L .51987 .67118 L F
.659 .773 .933 r
.52555 .67104 m .5231 .67179 L .52317 .67081 L F
.833 .592 .574 r
.52555 .67104 m .52086 .6735 L .5231 .67179 L F
.756 .709 .808 r
.80327 .51194 m .80272 .50884 L .79977 .51145 L F
.572 .823 .993 r
.42189 .58733 m .42328 .58852 L .4252 .58764 L F
0 .069 .629 r
.55935 .67784 m .56051 .67964 L .56054 .68095 L F
0 0 0 r
.54726 .68857 m .54533 .6913 L .54527 .68921 L F
.398 .433 .781 r
.56944 .64819 m .57223 .65018 L .57146 .64799 L F
.076 .628 .822 r
.51841 .73223 m .52028 .73225 L .51665 .73189 L F
.511 .231 .426 r
.49403 .65129 m .49676 .64872 L .49454 .64862 L F
.49403 .65129 m .49651 .65083 L .49676 .64872 L F
.591 .3 .442 r
.49676 .64872 m .49903 .65054 L .49929 .64833 L F
.49676 .64872 m .49651 .65083 L .49903 .65054 L F
.482 .065 .171 r
.63858 .46569 m .6407 .4668 L .63828 .46744 L F
.63858 .46569 m .64193 .46509 L .6407 .4668 L F
.864 .527 .412 r
.53899 .64278 m .53647 .6436 L .53656 .64229 L F
.53899 .64278 m .5404 .64526 L .53647 .6436 L F
.784 .664 .731 r
.53514 .6447 m .53171 .64472 L .53098 .64208 L F
.128 .183 .651 r
.53647 .6436 m .53514 .6447 L .53656 .64229 L F
.53647 .6436 m .5355 .64558 L .53514 .6447 L F
.591 .629 .857 r
.51631 .69813 m .51867 .70091 L .5183 .6992 L F
.676 .482 .615 r
.51867 .70091 m .51676 .70369 L .51925 .70328 L F
.17 .706 .819 r
.39891 .58042 m .40258 .58025 L .40023 .58039 L F
.952 .856 .436 r
.59273 .61888 m .59206 .62146 L .5925 .62239 L F
.792 .432 0 r
.59272 .62376 m .5925 .62239 L .59206 .62146 L F
.59272 .62376 m .59325 .62469 L .5925 .62239 L F
.818 .622 .637 r
.51017 .70988 m .50724 .71179 L .50693 .70957 L F
.51017 .70988 m .51057 .71241 L .50724 .71179 L F
.484 .391 .674 r
.5125 .71179 m .51017 .70988 L .51204 .70931 L F
.5125 .71179 m .51057 .71241 L .51017 .70988 L F
.812 .647 .678 r
.52137 .70387 m .51753 .70602 L .51676 .70369 L F
.52137 .70387 m .52108 .70638 L .51891 .70616 L F
.52137 .70387 m .51891 .70616 L .51903 .70518 L F
.389 .028 .226 r
.51928 .70327 m .52125 .7047 L .52154 .70233 L F
.51925 .70328 m .51927 .70329 L .51928 .70327 L F
.51927 .70329 m .52125 .7047 L .51928 .70327 L F
.812 .647 .678 r
.51903 .70518 m .51891 .70616 L .51753 .70602 L F
.986 .757 .505 r
.59709 .63857 m .59831 .63704 L .59663 .63623 L F
.59709 .63857 m .59815 .63953 L .59831 .63704 L F
.802 .906 .913 r
.78154 .48285 m .77874 .48511 L .77794 .48384 L F
.695 .669 .821 r
.60214 .46091 m .60478 .46264 L .60133 .46217 L F
.724 .583 .696 r
.60478 .46264 m .60276 .46492 L .60133 .46217 L F
.504 .407 .678 r
.46975 .6881 m .46986 .69191 L .47197 .69163 L F
0 0 .31 r
.535 .67165 m .53658 .66841 L .53399 .67124 L F
.845 .613 .588 r
.62392 .46822 m .62231 .47156 L .62039 .46777 L F
.62392 .46822 m .62397 .47068 L .62231 .47156 L F
.678 .488 .623 r
.54968 .62745 m .55228 .62514 L .54965 .62581 L F
.905 .597 .451 r
.52221 .71198 m .51868 .71375 L .5198 .7114 L F
.527 .559 .831 r
.51868 .71375 m .51757 .71355 L .51841 .71339 L F
.52006 .71558 m .51834 .71417 L .51868 .71375 L F
.51834 .71417 m .51757 .71355 L .51868 .71375 L F
.905 .597 .451 r
.51868 .71375 m .51865 .71372 L .5198 .7114 L F
.51862 .71379 m .51855 .71365 L .5198 .7114 L F
.747 .989 .788 r
.52232 .71087 m .51886 .71353 L .52221 .71198 L F
.52081 .71198 m .51886 .71353 L .52232 .71087 L F
.905 .597 .451 r
.51868 .71375 m .51862 .71379 L .51865 .71372 L F
.527 .559 .831 r
.52006 .71558 m .5186 .71365 L .51982 .71312 L F
.747 .989 .788 r
.51886 .71353 m .51855 .71378 L .51868 .71375 L F
.52233 .71078 m .52081 .71198 L .52232 .71087 L F
.078 0 0 r
.51982 .71312 m .51886 .71353 L .52233 .71078 L F
.19 0 .065 r
.5198 .7114 m .51857 .71361 L .51982 .71312 L F
.527 .559 .831 r
.51857 .71361 m .51841 .71339 L .51982 .71312 L F
.76 .576 .647 r
.51918 .71714 m .51516 .71399 L .51757 .71355 L F
.527 .559 .831 r
.52111 .71644 m .51918 .71714 L .51757 .71355 L F
.493 .298 .545 r
.51757 .71355 m .51779 .71452 L .51847 .71386 L F
.905 .597 .451 r
.51862 .71379 m .51847 .71386 L .51855 .71365 L F
.51847 .71386 m .51846 .71381 L .51855 .71365 L F
.493 .298 .545 r
.51841 .71339 m .51847 .71386 L .51909 .71326 L F
.51757 .71355 m .51847 .71386 L .51841 .71339 L F
.905 .597 .451 r
.51847 .71386 m .51842 .71389 L .51846 .71381 L F
.747 .989 .788 r
.51855 .71378 m .51842 .71389 L .51847 .71386 L F
.51855 .71378 m .51847 .71386 L .51868 .71375 L F
.51886 .71353 m .51868 .71375 L .52221 .71198 L F
.078 0 0 r
.51982 .71312 m .51855 .71378 L .51886 .71353 L F
.493 .298 .545 r
.51909 .71326 m .51899 .71356 L .51982 .71312 L F
.51899 .71356 m .51814 .71605 L .51982 .71312 L F
.527 .559 .831 r
.5186 .71365 m .51857 .71361 L .51982 .71312 L F
.493 .298 .545 r
.51779 .71452 m .51814 .71605 L .51899 .71354 L F
.19 0 .065 r
.51857 .71361 m .51846 .71381 L .51982 .71312 L F
.493 .298 .545 r
.51859 .71375 m .51899 .71354 L .51909 .71326 L F
.51779 .71452 m .51899 .71354 L .51859 .71375 L F
.078 0 0 r
.51982 .71312 m .51842 .71389 L .51855 .71378 L F
.19 0 .065 r
.51846 .71381 m .51842 .71389 L .51982 .71312 L F
.5198 .7114 m .51982 .71272 L .51757 .71355 L F
.51982 .71272 m .51982 .71312 L .51909 .71326 L F
.51982 .71272 m .51909 .71326 L .51757 .71355 L F
.527 .559 .831 r
.52111 .71644 m .52006 .71558 L .51982 .71312 L F
.987 .728 .44 r
.5198 .7114 m .51842 .70811 L .52004 .70933 L F
.51919 .70993 m .51859 .71138 L .51842 .70811 L F
.5198 .7114 m .51859 .71138 L .51919 .70993 L F
.19 0 .065 r
.5198 .7114 m .51757 .71355 L .51859 .71138 L F
.539 .482 .741 r
.51757 .71355 m .51839 .71189 L .51859 .71138 L F
.51839 .71189 m .51955 .70952 L .51859 .71138 L F
.51801 .71265 m .51982 .71312 L .51955 .70952 L F
.51757 .71355 m .51841 .71339 L .51801 .71265 L F
.51841 .71339 m .51982 .71312 L .51801 .71265 L F
.216 .116 .52 r
.22168 .59847 m .22169 .60104 L .22044 .60164 L F
.467 .327 .606 r
.22142 .60365 m .22044 .60164 L .22169 .60104 L F
.22142 .60365 m .22006 .60468 L .22044 .60164 L F
.673 .672 .841 r
.78169 .51215 m .78583 .51389 L .78452 .51165 L F
.464 .499 .809 r
.78583 .51389 m .78684 .51056 L .78452 .51165 L F
.78583 .51389 m .78796 .51399 L .78684 .51056 L F
.616 .193 .216 r
.62995 .46977 m .62999 .46861 L .63234 .47012 L F
.571 .26 .403 r
.63234 .47012 m .62999 .46861 L .63385 .46757 L F
.343 .172 .499 r
.21414 .61904 m .21401 .62137 L .21186 .62213 L F
.483 .321 .585 r
.21401 .62137 m .21186 .6243 L .21186 .62213 L F
.858 .727 .718 r
.53803 .69062 m .54277 .688 L .53866 .68855 L F
.764 .668 .756 r
.8082 .49359 m .8092 .49708 L .80548 .4967 L F
.127 .246 .718 r
.8082 .49359 m .80995 .49521 L .8092 .49708 L F
.949 .595 .23 r
.8086 .49868 m .8092 .49708 L .80995 .49521 L F
.8086 .49868 m .80987 .49987 L .8092 .49708 L F
.593 .256 .368 r
.51547 .63683 m .5181 .63843 L .51805 .63693 L F
.577 .324 .496 r
.51125 .64028 m .51343 .6406 L .51547 .63683 L F
.554 .298 .482 r
.51343 .6406 m .5181 .63843 L .51547 .63683 L F
.76 .995 .854 r
.46416 .67768 m .46372 .67748 L .46452 .67619 L F
.984 .812 .414 r
.46372 .67748 m .46376 .68008 L .46416 .67768 L F
.786 .489 .484 r
.58599 .60111 m .5888 .59912 L .58694 .59807 L F
.58599 .60111 m .58881 .60117 L .5888 .59912 L F
.221 .308 .742 r
.52555 .67104 m .52671 .67467 L .52822 .67372 L F
.165 0 .049 r
.52671 .67467 m .52775 .67585 L .52822 .67372 L F
.52671 .67467 m .52583 .67662 L .52775 .67585 L F
.837 .812 .826 r
.5733 .6376 m .57053 .64201 L .57351 .642 L F
.989 .814 .577 r
.57053 .64201 m .57143 .64555 L .57351 .642 L F
.635 .659 .856 r
.5733 .6376 m .57351 .642 L .57597 .6407 L F
.698 .356 .393 r
.57223 .65018 m .5744 .64896 L .57146 .64799 L F
.57223 .65018 m .57521 .65073 L .5744 .64896 L F
.429 0 .015 r
.4227 .62851 m .42087 .63018 L .41866 .63011 L F
.395 0 0 r
.42428 .62931 m .4227 .62851 L .42493 .62795 L F
.42428 .62931 m .42087 .63018 L .4227 .62851 L F
0 0 0 r
.54947 .59995 m .55064 .59997 L .55191 .59946 L F
.54947 .59995 m .54851 .6008 L .55064 .59997 L F
.744 .477 .527 r
.41136 .62092 m .41406 .62186 L .41478 .61863 L F
.484 .229 .452 r
.41478 .61863 m .41649 .62126 L .41697 .61826 L F
.41478 .61863 m .41406 .62186 L .41649 .62126 L F
.493 .213 .418 r
.37093 .59836 m .37052 .60049 L .36793 .60089 L F
.549 .275 .452 r
.37304 .59851 m .37052 .60049 L .37093 .59836 L F
.176 .69 .892 r
.38023 .62527 m .37961 .6258 L .37772 .62508 L F
.38023 .62527 m .38177 .62579 L .37961 .6258 L F
.65 .416 .551 r
.53492 .65592 m .53756 .65438 L .535 .65447 L F
.53492 .65592 m .53725 .65695 L .53756 .65438 L F
.74 .473 .525 r
.54003 .65728 m .53756 .65438 L .53725 .65695 L F
.468 .178 .388 r
.65209 .46322 m .64991 .46213 L .65236 .46164 L F
.65209 .46322 m .64988 .464 L .64991 .46213 L F
.87 .699 .667 r
.60511 .64787 m .60655 .65127 L .60758 .64852 L F
.773 .929 .566 r
.47124 .62125 m .47253 .61987 L .47137 .62155 L F
.569 .698 .929 r
.47253 .61987 m .47505 .61961 L .47381 .61818 L F
.47381 .61818 m .47505 .61961 L .47253 .61987 L F
.757 .619 .707 r
.54182 .64823 m .5407 .65045 L .53847 .64578 L F
.512 .587 .867 r
.5401 .6516 m .54033 .64819 L .53829 .64865 L F
.5401 .6516 m .54182 .6507 L .54033 .64819 L F
.408 .301 .621 r
.32786 .61095 m .3297 .61047 L .3301 .6071 L F
.448 .445 .763 r
.32786 .61095 m .33046 .61248 L .3297 .61047 L F
.479 .842 .992 r
.58061 .60158 m .57951 .60097 L .57693 .60155 L F
.282 0 0 r
.58332 .60234 m .57951 .60097 L .58061 .60158 L F
.991 .87 .61 r
.58355 .6354 m .58523 .63406 L .58446 .63694 L F
.611 .29 .402 r
.47925 .61266 m .48144 .6128 L .47938 .61067 L F
.694 .517 .644 r
.49709 .68204 m .49721 .68432 L .49673 .68408 L F
.49737 .68191 m .49721 .68428 L .49709 .68204 L F
.49721 .68428 m .49721 .68432 L .49721 .68428 L F
.49721 .68428 m .49721 .68428 L .49709 .68204 L F
.653 .428 .566 r
.49462 .68046 m .49476 .68308 L .49709 .68204 L F
.49462 .68046 m .49709 .68204 L .49752 .67956 L F
.694 .517 .644 r
.49752 .67956 m .49673 .68408 L .49476 .68308 L F
.653 .428 .566 r
.49709 .68204 m .49476 .68308 L .4973 .68288 L F
.49709 .68204 m .4973 .68288 L .49734 .6822 L F
.694 .517 .644 r
.49752 .67956 m .49737 .68191 L .49709 .68204 L F
.653 .428 .566 r
.49709 .68204 m .49734 .6822 L .49752 .67956 L F
.749 .646 .086 r
.49752 .67956 m .49734 .6822 L .49737 .68191 L F
.653 .428 .566 r
.49734 .6822 m .49827 .6828 L .49752 .67956 L F
.085 0 0 r
.49406 .6852 m .49725 .68338 L .49476 .68308 L F
.49725 .68338 m .49827 .6828 L .4973 .68288 L F
.49725 .68338 m .4973 .68288 L .49476 .68308 L F
.749 .646 .086 r
.49752 .67956 m .49728 .68307 L .49734 .6822 L F
.085 0 0 r
.49406 .6852 m .4955 .6849 L .49722 .68359 L F
.749 .646 .086 r
.49734 .68226 m .4972 .6843 L .49721 .68432 L F
.49737 .68191 m .49733 .68235 L .49734 .68226 L F
.49733 .68235 m .4972 .6843 L .49734 .68226 L F
.646 .856 .471 r
.49827 .6828 m .49716 .68424 L .49721 .68432 L F
.749 .646 .086 r
.49726 .6833 m .4972 .6843 L .49727 .68327 L F
.688 .294 .295 r
.49722 .68359 m .49716 .68424 L .49948 .68441 L F
.451 .238 .498 r
.49948 .68441 m .49721 .68432 L .49716 .68424 L F
.49948 .68441 m .49758 .68534 L .49721 .68432 L F
.688 .294 .295 r
.49716 .68424 m .49712 .6847 L .49948 .68441 L F
.085 0 0 r
.49406 .6852 m .49722 .68359 L .49725 .68338 L F
.749 .646 .086 r
.49752 .67956 m .49714 .68421 L .4972 .6843 L F
.451 .238 .498 r
.49948 .68441 m .49716 .68424 L .49714 .68421 L F
.646 .856 .471 r
.49827 .6828 m .49714 .68421 L .49716 .68424 L F
.688 .294 .295 r
.49827 .6828 m .49722 .68359 L .49756 .68372 L F
.49827 .6828 m .49756 .68372 L .49948 .68441 L F
.49722 .68359 m .4955 .6849 L .49712 .6847 L F
.085 0 0 r
.49725 .68338 m .49722 .68359 L .49827 .6828 L F
.749 .646 .086 r
.49728 .68307 m .49726 .6833 L .4973 .68288 L F
.49726 .6833 m .49727 .68327 L .4973 .68288 L F
.49728 .68307 m .4973 .68288 L .49734 .6822 L F
.653 .428 .566 r
.49734 .6822 m .4973 .68288 L .49827 .6828 L F
.688 .294 .295 r
.49827 .6828 m .49948 .68441 L .49714 .68421 L F
.803 .522 .513 r
.50188 .68259 m .49714 .68421 L .502 .68245 L F
.50187 .6826 m .50162 .68268 L .50188 .68259 L F
.50162 .68268 m .49714 .68421 L .50188 .68259 L F
.694 .517 .644 r
.49752 .67956 m .49476 .68308 L .49462 .68046 L F
.265 0 0 r
.39049 .63725 m .38643 .63835 L .38813 .63745 L F
.426 .244 .528 r
.53775 .6622 m .53596 .65999 L .53842 .65976 L F
.53775 .6622 m .5353 .66275 L .53596 .65999 L F
.757 .619 .707 r
.54182 .64823 m .5404 .64526 L .54215 .64581 L F
.619 .843 .985 r
.44025 .5898 m .44506 .59106 L .44323 .59066 L F
.675 .941 .964 r
.44543 .58946 m .44506 .59106 L .4469 .5897 L F
.44543 .58946 m .44323 .59066 L .44506 .59106 L F
.454 .354 .652 r
.52965 .65355 m .52698 .65137 L .5305 .65149 L F
0 0 0 r
.53325 .64826 m .5319 .65017 L .5305 .65149 L F
.543 .397 .633 r
.5319 .65017 m .52965 .65355 L .5305 .65149 L F
.104 0 0 r
.55258 .60249 m .552 .60382 L .55083 .60429 L F
0 0 0 r
.55268 .6024 m .55258 .60249 L .55048 .60443 L F
.217 0 0 r
.55048 .60443 m .54979 .6047 L .54718 .60462 L F
.104 0 0 r
.55258 .60249 m .54979 .6047 L .55048 .60443 L F
.55258 .60249 m .55083 .60429 L .54979 .6047 L F
0 0 0 r
.55312 .60198 m .55258 .60249 L .55268 .6024 L F
.027 0 .081 r
.55312 .60198 m .55191 .59946 L .55421 .60043 L F
0 0 .411 r
.55421 .60043 m .55258 .60249 L .55312 .60198 L F
.993 .88 .578 r
.58392 .6121 m .58464 .60981 L .5854 .61066 L F
.407 .06 .261 r
.49153 .68547 m .49476 .68308 L .49273 .6843 L F
.906 .743 .668 r
.59513 .63044 m .59488 .63346 L .59636 .63397 L F
.865 .603 .54 r
.59488 .63346 m .59663 .63623 L .59636 .63397 L F
.645 .93 .971 r
.65447 .4274 m .65148 .4277 L .65362 .42615 L F
0 .331 .769 r
.65609 .4278 m .65447 .4274 L .65362 .42615 L F
.65609 .4278 m .65739 .42895 L .65447 .4274 L F
0 0 .181 r
.45872 .69161 m .45976 .68909 L .45877 .69087 L F
.997 .818 .462 r
.45976 .68909 m .4594 .68588 L .459 .68837 L F
.996 .793 .434 r
.45877 .69087 m .45976 .68909 L .459 .68837 L F
0 0 0 r
.55115 .67199 m .54585 .67393 L .54739 .67178 L F
.54922 .6727 m .54865 .67308 L .54585 .67393 L F
.519 .137 .256 r
.54739 .67178 m .54321 .67411 L .54329 .67111 L F
.54739 .67178 m .54585 .67393 L .54321 .67411 L F
.468 .196 .418 r
.54865 .67308 m .54551 .67551 L .54585 .67393 L F
.659 .771 .298 r
.54803 .67351 m .54865 .67308 L .54692 .67153 L F
.468 .196 .418 r
.54865 .67308 m .54759 .67545 L .54551 .67551 L F
.659 .771 .298 r
.54825 .67391 m .54865 .67308 L .54803 .67351 L F
0 0 0 r
.55115 .67199 m .54865 .67308 L .54922 .6727 L F
.936 .967 .712 r
.54999 .67087 m .54865 .67308 L .55115 .67199 L F
.716 .812 .924 r
.19719 .57468 m .19932 .57635 L .20135 .57495 L F
.293 .767 .933 r
.57146 .64799 m .57143 .64555 L .5701 .64468 L F
.989 .814 .577 r
.57053 .64201 m .5701 .64468 L .57143 .64555 L F
.991 .748 .464 r
.5701 .64468 m .57146 .64799 L .57143 .64555 L F
.718 .319 .291 r
.50693 .70957 m .50576 .7117 L .50329 .70926 L F
.901 .563 .394 r
.50724 .71179 m .50576 .7117 L .50693 .70957 L F
0 .016 .582 r
.78035 .50898 m .77947 .50484 L .77719 .50513 L F
.78035 .50898 m .78054 .50856 L .77947 .50484 L F
.537 .376 .611 r
.3329 .63404 m .33309 .63652 L .3354 .63424 L F
.984 .772 .541 r
.50545 .69411 m .50626 .6972 L .50692 .69516 L F
.647 .938 .687 r
.50907 .69465 m .50626 .6972 L .50692 .69516 L F
.68 .442 .554 r
.55433 .62498 m .55847 .62694 L .55809 .62527 L F
.616 .323 .45 r
.55847 .62694 m .5599 .62742 L .55809 .62527 L F
.411 0 0 r
.56277 .62933 m .56161 .62833 L .5599 .62742 L F
.56277 .62933 m .56465 .62948 L .56161 .62833 L F
.733 .656 .774 r
.57628 .65449 m .58014 .65519 L .57882 .6536 L F
.679 .762 .914 r
.57882 .6536 m .58014 .65519 L .58232 .65415 L F
.43 .408 .734 r
.7631 .49421 m .76353 .49746 L .76573 .49545 L F
.485 .5 .798 r
.76353 .49746 m .76665 .49893 L .76573 .49545 L F
.395 0 0 r
.3797 .63897 m .378 .64048 L .37622 .63997 L F
.155 0 0 r
.38191 .63902 m .378 .64048 L .3797 .63897 L F
.695 .669 .821 r
.79353 .48201 m .79586 .4794 L .79348 .48051 L F
.546 .572 .832 r
.3401 .62904 m .34229 .62719 L .34034 .62849 L F
.3401 .62904 m .34449 .63051 L .34229 .62719 L F
.639 .251 .293 r
.51582 .67331 m .5185 .67387 L .51987 .67118 L F
.49 .095 .219 r
.51987 .67118 m .52086 .6735 L .52317 .67081 L F
.51987 .67118 m .5185 .67387 L .52086 .6735 L F
.663 .911 .978 r
.77215 .48669 m .7708 .48858 L .7699 .4878 L F
.41 .477 .819 r
.45883 .59205 m .45735 .59386 L .45734 .59258 L F
0 .295 .783 r
.45894 .59432 m .45735 .59386 L .45883 .59205 L F
.45894 .59432 m .45993 .59573 L .45735 .59386 L F
.73 .453 .508 r
.51349 .67086 m .51595 .67135 L .51354 .66868 L F
.822 .954 .902 r
.79094 .5115 m .78796 .51399 L .78966 .51358 L F
.714 .369 .392 r
.64193 .46509 m .64441 .46557 L .64422 .46723 L F
.493 .17 .346 r
.64441 .46557 m .64674 .4668 L .64422 .46723 L F
.64441 .46557 m .64706 .46519 L .64674 .4668 L F
.062 0 0 r
.41697 .61826 m .41862 .61814 L .41967 .61723 L F
.614 .089 0 r
.41862 .61814 m .42201 .61871 L .41967 .61723 L F
.78 .691 .766 r
.49815 .70043 m .49638 .70319 L .4998 .70348 L F
.671 .338 .401 r
.49635 .70594 m .4998 .70348 L .49638 .70319 L F
.49635 .70594 m .49841 .70594 L .4998 .70348 L F
.814 .515 .483 r
.4998 .70348 m .49841 .70594 L .50145 .70636 L F
.668 .795 .943 r
.59328 .66224 m .58962 .66185 L .5909 .66317 L F
.387 .16 .442 r
.49533 .69475 m .49718 .69204 L .49468 .68989 L F
.49533 .69475 m .49709 .69453 L .49718 .69204 L F
.695 .407 .483 r
.49718 .69204 m .49709 .69453 L .49947 .69443 L F
.457 .792 .999 r
.42256 .58017 m .42275 .57966 L .42433 .58061 L F
.536 .789 .991 r
.425 .57899 m .42433 .58061 L .42275 .57966 L F
.425 .57899 m .4267 .58011 L .42433 .58061 L F
.584 .046 0 r
.36119 .58332 m .36309 .5841 L .36463 .58383 L F
.2 0 0 r
.36309 .5841 m .36691 .58408 L .36463 .58383 L F
.54 .477 .734 r
.57856 .6494 m .58132 .65067 L .58103 .64863 L F
.431 .833 .978 r
.3124 .79886 m .31162 .79983 L .31386 .79937 L F
.3124 .79886 m .31162 .79983 L .31386 .79937 L F
0 0 .556 r
.50226 .68614 m .50382 .68857 L .50341 .68688 L F
.363 .223 .554 r
.50228 .68844 m .50382 .68857 L .50226 .68614 L F
.442 .013 .127 r
.44167 .62442 m .43879 .6267 L .43701 .62586 L F
.386 0 0 r
.44252 .62502 m .43879 .6267 L .44167 .62442 L F
.579 .443 .66 r
.49188 .65425 m .49391 .65497 L .49403 .65129 L F
.655 .235 .235 r
.45232 .62509 m .45062 .62699 L .44857 .62506 L F
.896 .577 .436 r
.45232 .62509 m .45241 .62725 L .45062 .62699 L F
.499 .472 .758 r
.45299 .62247 m .45232 .62509 L .45446 .62426 L F
.555 .064 .045 r
.44618 .62494 m .44482 .62622 L .44252 .62502 L F
.585 .137 .152 r
.44857 .62506 m .44482 .62622 L .44618 .62494 L F
.864 .834 .816 r
.60133 .46217 m .59773 .46261 L .60012 .46144 L F
.60133 .46217 m .59895 .46519 L .59773 .46261 L F
.709 .577 .704 r
.60276 .46492 m .59895 .46519 L .60133 .46217 L F
.593 .889 .99 r
.60133 .46217 m .60253 .46048 L .60214 .46091 L F
.60133 .46217 m .60012 .46144 L .60253 .46048 L F
.774 .633 .705 r
.58332 .60234 m .58647 .6019 L .58519 .60472 L F
.322 .08 .382 r
.19823 .58445 m .19731 .58685 L .19955 .58526 L F
.867 .43 .157 r
.80424 .48134 m .80472 .4803 L .8025 .47889 L F
.786 .314 .112 r
.80424 .48134 m .80649 .48215 L .80472 .4803 L F
.619 .246 .315 r
.50668 .6999 m .5046 .69815 L .50626 .6972 L F
.50668 .6999 m .50336 .70038 L .5046 .69815 L F
0 0 0 r
.78612 .49101 m .78547 .49248 L .78397 .49416 L F
.618 .956 .904 r
.78397 .49416 m .78547 .49248 L .78655 .49229 L F
.615 .453 .64 r
.5355 .64558 m .53585 .64793 L .53325 .64826 L F
.38 0 .046 r
.53585 .64793 m .5319 .65017 L .53325 .64826 L F
.639 .557 .747 r
.6444 .43809 m .64527 .44184 L .64259 .44275 L F
.375 0 0 r
.64527 .44184 m .64158 .44346 L .64259 .44275 L F
.468 .157 .355 r
.52965 .69189 m .53261 .69134 L .53282 .68873 L F
0 0 .174 r
.53282 .68873 m .53449 .68812 L .53518 .68884 L F
.53282 .68873 m .5334 .69024 L .53449 .68812 L F
.53282 .68873 m .53261 .69134 L .5334 .69024 L F
.96 .862 .452 r
.55847 .67032 m .55938 .66897 L .55891 .66736 L F
.55847 .67032 m .55881 .67136 L .55938 .66897 L F
.653 .442 .585 r
.60092 .46717 m .59895 .46519 L .60276 .46492 L F
.743 .521 .593 r
.60276 .46492 m .60499 .46795 L .60092 .46717 L F
.967 .905 .546 r
.62815 .44013 m .62855 .44237 L .62938 .43885 L F
.619 .105 .003 r
.62755 .44098 m .62855 .44237 L .62815 .44013 L F
.62608 .44308 m .62964 .4436 L .62855 .44237 L F
0 0 0 r
.63093 .43741 m .62815 .44013 L .62938 .43885 L F
.619 .105 .003 r
.62744 .44269 m .62855 .44237 L .62755 .44098 L F
.62608 .44308 m .62744 .44269 L .62755 .44098 L F
.802 .719 .774 r
.62807 .44283 m .62608 .44308 L .62815 .44013 L F
.62807 .44283 m .62815 .44013 L .62757 .43874 L F
0 0 .063 r
.63159 .43538 m .62938 .43885 L .63093 .43573 L F
.856 .918 .872 r
.62757 .43874 m .62815 .44013 L .63093 .43741 L F
.105 .25 .73 r
.62766 .43945 m .62989 .44121 L .62807 .44283 L F
.62757 .43874 m .6277 .43888 L .62766 .43945 L F
.6277 .43888 m .62864 .43989 L .62766 .43945 L F
.856 .918 .872 r
.62757 .43874 m .63093 .43741 L .62804 .43672 L F
.792 .63 .681 r
.62373 .43814 m .62757 .43874 L .62804 .43672 L F
.186 .274 .722 r
.63065 .43948 m .62989 .44121 L .62757 .43874 L F
.62804 .43925 m .62757 .43874 L .62635 .4391 L F
.63065 .43948 m .62899 .43908 L .62804 .43925 L F
.62899 .43908 m .62757 .43874 L .62804 .43925 L F
.73 .352 .335 r
.62373 .43814 m .62264 .44022 L .62778 .43994 L F
.73 .975 .924 r
.62778 .43994 m .6255 .43984 L .62573 .43965 L F
.218 .665 .951 r
.62738 .43829 m .63031 .43935 L .62635 .4391 L F
.563 .012 0 r
.62373 .43814 m .62635 .4391 L .62757 .43874 L F
.73 .352 .335 r
.62373 .43814 m .62778 .43994 L .62635 .4391 L F
.218 .665 .951 r
.63031 .43935 m .63008 .43943 L .62635 .4391 L F
.62738 .43829 m .62635 .4391 L .62778 .43994 L F
.73 .975 .924 r
.62763 .43932 m .62573 .43965 L .62738 .43829 L F
.62778 .43994 m .62573 .43965 L .62763 .43932 L F
.218 .665 .951 r
.63031 .43935 m .63065 .43948 L .63008 .43943 L F
.105 .25 .73 r
.62864 .43989 m .62989 .44121 L .62834 .43998 L F
.62864 .43989 m .62834 .43998 L .62766 .43945 L F
.385 .067 .299 r
.50508 .67437 m .50723 .67395 L .50784 .67207 L F
.62 .291 .39 r
.50723 .67395 m .50991 .67389 L .50784 .67207 L F
.551 .309 .502 r
.50784 .67207 m .50991 .67389 L .51026 .6715 L F
.529 .604 .872 r
.78789 .49298 m .78779 .49688 L .78655 .49229 L F
.78789 .49298 m .79013 .49644 L .78779 .49688 L F
.749 .722 .827 r
.44723 .61891 m .4509 .61939 L .44985 .6164 L F
.74 .361 .334 r
.44723 .61891 m .44933 .62136 L .4509 .61939 L F
.568 .152 .213 r
.4509 .61939 m .44933 .62136 L .45313 .62083 L F
.167 .337 .791 r
.56411 .64249 m .56548 .64566 L .56666 .64401 L F
0 .203 .723 r
.56548 .64566 m .56696 .64615 L .56666 .64401 L F
.56548 .64566 m .56797 .64774 L .56696 .64615 L F
.771 .645 .722 r
.54243 .69208 m .54338 .6952 L .54019 .69475 L F
.743 .375 .355 r
.54338 .6952 m .54235 .69675 L .54019 .69475 L F
.652 .577 .758 r
.54562 .69477 m .54338 .6952 L .54243 .69208 L F
.358 0 .076 r
.54562 .69477 m .54235 .69675 L .54338 .6952 L F
0 0 .278 r
.57879 .63649 m .57931 .63283 L .58006 .63288 L F
.346 0 .186 r
.33517 .59295 m .33851 .59014 L .33478 .58982 L F
.33517 .59295 m .33738 .59244 L .33851 .59014 L F
.307 0 .167 r
.33851 .59014 m .33956 .59171 L .34071 .59001 L F
.33851 .59014 m .33738 .59244 L .33956 .59171 L F
.224 .736 .698 r
.18783 .55303 m .18521 .55376 L .18388 .55419 L F
0 0 0 r
.18791 .55302 m .18783 .55303 L .18998 .55313 L F
.18791 .55302 m .18521 .55376 L .18783 .55303 L F
.888 .706 .192 r
.55902 .67612 m .55935 .67784 L .55933 .67447 L F
0 0 .463 r
.57014 .6299 m .56923 .63453 L .56768 .63076 L F
.57014 .6299 m .57047 .6329 L .56923 .63453 L F
.594 .051 0 r
.56787 .63534 m .56923 .63453 L .57047 .6329 L F
.56787 .63534 m .57128 .63594 L .56923 .63453 L F
.355 0 .018 r
.57008 .63716 m .57142 .63647 L .57128 .63594 L F
.548 0 0 r
.57116 .63549 m .57128 .63594 L .57285 .63633 L F
.536 .874 .99 r
.57285 .63633 m .57128 .63594 L .57401 .63514 L F
.57285 .63633 m .57128 .63594 L .57401 .63514 L F
.355 0 .018 r
.57142 .63647 m .57401 .63514 L .57128 .63594 L F
.548 0 0 r
.56923 .63453 m .57128 .63594 L .57116 .63549 L F
.703 .174 0 r
.541 .66749 m .54182 .66799 L .53996 .66614 L F
.476 .272 .523 r
.53996 .66614 m .54182 .66799 L .54224 .66538 L F
.129 0 .38 r
.51381 .70806 m .51254 .70663 L .51509 .70614 L F
.51381 .70806 m .51204 .70931 L .51254 .70663 L F
.742 .926 .952 r
.56148 .68307 m .55618 .68486 L .55875 .68703 L F
.849 .389 .025 r
.55618 .68486 m .55885 .68782 L .55875 .68703 L F
.416 0 0 r
.52054 .64116 m .51887 .64067 L .5181 .63843 L F
.52054 .64116 m .52205 .64205 L .52064 .64144 L F
.836 .671 .678 r
.5181 .63843 m .52127 .6412 L .51999 .63641 L F
0 0 0 r
.52127 .6412 m .52363 .63644 L .51999 .63641 L F
.652 .682 .865 r
.52168 .63908 m .52127 .6412 L .5181 .63843 L F
0 0 0 r
.52127 .6412 m .52278 .63882 L .52363 .63644 L F
.11 .144 .616 r
.52168 .63908 m .52278 .63882 L .52127 .6412 L F
.89 .463 .12 r
.52162 .64349 m .52022 .64206 L .52205 .64205 L F
.52022 .64206 m .51887 .64067 L .52064 .64144 L F
.52022 .64206 m .52064 .64144 L .52205 .64205 L F
.63 .476 .655 r
.52085 .6416 m .52278 .63882 L .52231 .63893 L F
.52116 .64065 m .52231 .63893 L .52168 .63908 L F
.52085 .6416 m .52231 .63893 L .52116 .64065 L F
.52059 .64238 m .521 .64171 L .52085 .6416 L F
.521 .64171 m .52278 .63882 L .52085 .6416 L F
.416 0 0 r
.52008 .64103 m .52064 .64144 L .51887 .64067 L F
.52054 .64116 m .52064 .64144 L .52008 .64103 L F
.786 .807 .869 r
.59895 .46519 m .59552 .46493 L .59773 .46261 L F
.641 .432 .584 r
.59895 .46519 m .59641 .46769 L .59552 .46493 L F
.59895 .46519 m .59898 .46756 L .59641 .46769 L F
.653 .442 .585 r
.60092 .46717 m .59898 .46756 L .59895 .46519 L F
.733 .355 .334 r
.64193 .46509 m .64422 .46723 L .6407 .4668 L F
.237 .584 .945 r
.35138 .63337 m .35228 .63246 L .34786 .63326 L F
.35138 .63337 m .3527 .63351 L .35228 .63246 L F
.292 .306 .704 r
.35138 .63337 m .35336 .63508 L .3527 .63351 L F
.518 .288 .504 r
.20486 .56121 m .20695 .56135 L .20864 .56082 L F
.20486 .56121 m .20469 .56349 L .20695 .56135 L F
.605 .727 .931 r
.43437 .58059 m .43402 .58358 L .43215 .58099 L F
.43437 .58059 m .43651 .58343 L .43402 .58358 L F
.529 .795 .994 r
.43698 .58358 m .43402 .58358 L .43651 .58343 L F
.653 .526 .697 r
.50644 .68032 m .50418 .68326 L .50395 .68093 L F
.735 .515 .593 r
.63577 .4678 m .63234 .47012 L .63385 .46757 L F
.328 .016 .275 r
.53662 .72058 m .53598 .72326 L .53377 .72394 L F
0 0 0 r
.53854 .72016 m .53598 .72326 L .53662 .72058 L F
.84 .785 .799 r
.20376 .55691 m .20532 .55749 L .20502 .55713 L F
.143 .665 .882 r
.20532 .55749 m .20893 .55766 L .20502 .55713 L F
.964 .832 .664 r
.52108 .70638 m .51842 .70811 L .51753 .70602 L F
.52108 .70638 m .52004 .70933 L .51842 .70811 L F
.608 .657 .872 r
.79374 .5112 m .79531 .50776 L .792 .50876 L F
.79374 .5112 m .79623 .51069 L .79531 .50776 L F
.247 .006 .339 r
.20952 .63007 m .20798 .63093 L .21022 .62793 L F
.249 .044 .393 r
.20952 .63007 m .20749 .63343 L .20798 .63093 L F
.771 .597 .663 r
.54579 .6677 m .54329 .67111 L .54345 .66875 L F
.438 0 0 r
.18518 .54227 m .18724 .54283 L .1888 .54268 L F
.144 .688 .747 r
.1888 .54268 m .18724 .54283 L .19096 .54234 L F
0 0 0 r
.40982 .5868 m .40671 .58948 L .40763 .58774 L F
.804 .713 .764 r
.66542 .45387 m .66206 .45709 L .66145 .45565 L F
0 0 0 r
.66309 .45354 m .66241 .45496 L .66037 .45578 L F
.66241 .45496 m .66238 .45499 L .66037 .45578 L F
.295 0 0 r
.66542 .45387 m .66241 .45496 L .66309 .45354 L F
.804 .713 .764 r
.66542 .45387 m .66145 .45565 L .66403 .4538 L F
.295 0 0 r
.66542 .45387 m .66241 .45498 L .66241 .45496 L F
.804 .713 .764 r
.66403 .4538 m .66241 .45496 L .6606 .45363 L F
.66241 .45496 m .66145 .45565 L .66133 .45536 L F
.49 .677 .948 r
.66037 .45578 m .66238 .45499 L .6606 .45363 L F
.804 .713 .764 r
.66241 .45496 m .66237 .45498 L .6606 .45363 L F
0 0 0 r
.66241 .45496 m .66241 .45498 L .66238 .45499 L F
.49 .677 .948 r
.66238 .45499 m .66241 .45498 L .6606 .45363 L F
.804 .713 .764 r
.66237 .45498 m .66133 .45536 L .6606 .45363 L F
.295 0 0 r
.66542 .45387 m .66309 .45354 L .66551 .45293 L F
.36 .339 .701 r
.45456 .69165 m .45525 .69544 L .45709 .69403 L F
.35 .323 .687 r
.45525 .69544 m .45754 .69725 L .45709 .69403 L F
.259 .299 .714 r
.58437 .65987 m .58619 .66152 L .58584 .65935 L F
.8 .426 .349 r
.56928 .59847 m .57371 .59959 L .5728 .60076 L F
0 .184 .604 r
.55702 .6347 m .55782 .63519 L .55568 .63375 L F
.55702 .6347 m .55917 .63605 L .55782 .63519 L F
.628 .884 .548 r
.20641 .58173 m .204 .58456 L .20533 .58286 L F
.306 0 .141 r
.20533 .58286 m .20828 .58096 L .20641 .58173 L F
.609 .449 .64 r
.53847 .64578 m .5355 .64558 L .53647 .6436 L F
.53847 .64578 m .53585 .64793 L .5355 .64558 L F
.694 .679 .832 r
.79623 .51069 m .79754 .51264 L .79977 .51145 L F
.331 0 0 r
.53123 .67175 m .53324 .6722 L .535 .67165 L F
0 0 .31 r
.535 .67165 m .53642 .67097 L .53658 .66841 L F
.324 .801 .73 r
.535 .67165 m .53324 .6722 L .53642 .67097 L F
.597 .151 .163 r
.57285 .63633 m .57485 .63667 L .57701 .63625 L F
.557 .089 .098 r
.57701 .63625 m .57485 .63667 L .57879 .63649 L F
.545 .419 .66 r
.32826 .60125 m .3303 .59817 L .32834 .59884 L F
.25 .761 .845 r
.38177 .62579 m .384 .62538 L .38549 .62541 L F
0 0 0 r
.384 .62538 m .38784 .62512 L .38549 .62541 L F
.765 .356 .276 r
.51057 .71241 m .50937 .71417 L .50724 .71179 L F
0 0 0 r
.5117 .71115 m .51057 .71241 L .5125 .71179 L F
.5117 .71115 m .50937 .71417 L .51057 .71241 L F
.951 .597 .262 r
.20913 .56088 m .20864 .56082 L .20695 .56135 L F
.556 .511 .76 r
.45404 .68989 m .45544 .68476 L .4531 .68606 L F
.45404 .68989 m .45741 .69032 L .45544 .68476 L F
.632 .694 .89 r
.45456 .69165 m .45741 .69032 L .45404 .68989 L F
.215 .556 .934 r
.19939 .59002 m .19943 .58871 L .1978 .58833 L F
.895 .97 .823 r
.19944 .59048 m .19943 .58871 L .19939 .59002 L F
.346 0 .14 r
.50945 .64178 m .51125 .64028 L .50989 .64046 L F
0 0 .476 r
.64781 .42813 m .64797 .42919 L .64854 .42977 L F
0 0 .411 r
.55421 .60043 m .55422 .60287 L .55258 .60249 L F
.104 0 0 r
.55422 .60287 m .552 .60382 L .55258 .60249 L F
0 0 .485 r
.49694 .71419 m .49586 .71247 L .49747 .71176 L F
.381 .238 .559 r
.23568 .56648 m .236 .56915 L .23384 .56998 L F
.265 .089 .446 r
.236 .56915 m .2343 .57147 L .23384 .56998 L F
.053 0 .42 r
.36675 .6155 m .3658 .61827 L .3658 .61633 L F
.632 .694 .89 r
.45456 .69165 m .45872 .69161 L .45741 .69032 L F
.877 .941 .855 r
.80413 .48813 m .80708 .48587 L .80678 .484 L F
.598 .194 .248 r
.20206 .58337 m .20533 .58286 L .204 .58456 L F
.136 0 .274 r
.21787 .61271 m .21578 .61579 L .21648 .61358 L F
.912 .722 .633 r
.57941 .61556 m .58108 .61649 L .58074 .61901 L F
.783 .46 .441 r
.58108 .61649 m .5832 .61884 L .58074 .61901 L F
.618 .398 .56 r
.55225 .62767 m .55433 .62498 L .55228 .62514 L F
.55225 .62767 m .55469 .6278 L .55433 .62498 L F
.68 .442 .554 r
.55433 .62498 m .55469 .6278 L .55847 .62694 L F
.517 .424 .689 r
.46946 .70923 m .46707 .71005 L .46674 .70826 L F
.46946 .70923 m .47008 .71161 L .46707 .71005 L F
0 .252 .761 r
.56339 .64073 m .56332 .63937 L .56029 .63709 L F
.534 0 0 r
.56029 .63709 m .56332 .63937 L .5622 .63885 L F
.56029 .63709 m .5622 .63885 L .55917 .63605 L F
.271 .028 .351 r
.21113 .62921 m .21022 .62793 L .21128 .62694 L F
.21113 .62921 m .20952 .63007 L .21022 .62793 L F
.846 .783 .79 r
.61465 .45105 m .61078 .45281 L .61284 .44964 L F
.61465 .45105 m .61203 .45485 L .61078 .45281 L F
.807 .749 .798 r
.61717 .44792 m .61465 .45105 L .61284 .44964 L F
.589 .051 0 r
.48749 .69364 m .48405 .6921 L .48755 .69223 L F
.534 .862 .995 r
.46007 .61217 m .46387 .61246 L .46175 .61289 L F
.561 .669 .91 r
.37078 .62085 m .36988 .62306 L .36846 .62153 L F
.37078 .62085 m .37204 .6225 L .36988 .62306 L F
.88 .822 .787 r
.49533 .69475 m .49353 .69424 L .49468 .68989 L F
.428 .325 .636 r
.49533 .69475 m .4971 .69711 L .49709 .69453 L F
.678 .488 .623 r
.54968 .62745 m .55225 .62767 L .55228 .62514 L F
.555 .569 .823 r
.56709 .59678 m .56793 .59771 L .56556 .59604 L F
.65 .523 .696 r
.56556 .59604 m .56973 .59566 L .56709 .59678 L F
.802 .312 0 r
.55451 .66003 m .55469 .65922 L .55328 .66153 L F
.55451 .66003 m .55657 .66182 L .55469 .65922 L F
.508 .582 .864 r
.245 .55693 m .24345 .55872 L .24188 .55627 L F
.399 .351 .689 r
.2451 .55898 m .24345 .55872 L .245 .55693 L F
.2451 .55898 m .24409 .5613 L .24345 .55872 L F
.645 .088 0 r
.50832 .6535 m .51195 .65488 L .51088 .6556 L F
.583 .883 .589 r
.51088 .6556 m .51195 .65488 L .51383 .65271 L F
.433 .01 .135 r
.41421 .63049 m .41259 .63251 L .41023 .63276 L F
.298 0 0 r
.41642 .6306 m .41259 .63251 L .41421 .63049 L F
.121 .651 .87 r
.19096 .54234 m .19316 .54246 L .19507 .54292 L F
0 .448 .705 r
.19316 .54246 m .19694 .54333 L .19507 .54292 L F
.771 .785 .864 r
.59797 .65939 m .59885 .66183 L .60139 .65943 L F
.618 .802 .97 r
.4824 .73828 m .48003 .73906 L .47856 .73776 L F
.433 0 0 r
.4824 .73828 m .47856 .73776 L .48003 .73906 L F
.658 .399 .517 r
.53713 .65908 m .53492 .65592 L .53361 .65893 L F
.53713 .65908 m .53725 .65695 L .53492 .65592 L F
.923 .944 .794 r
.78543 .48388 m .786 .48562 L .78763 .48256 L F
.724 .283 .204 r
.78416 .48694 m .786 .48562 L .78543 .48388 L F
.246 .166 .563 r
.786 .48562 m .78744 .48771 L .78567 .4887 L F
.724 .283 .204 r
.78416 .48694 m .78744 .48771 L .786 .48562 L F
.338 .444 .822 r
.48638 .71213 m .48807 .71111 L .48525 .7097 L F
.009 0 .219 r
.48638 .71213 m .48591 .71456 L .48807 .71111 L F
.608 .628 .845 r
.23315 .55228 m .22934 .54992 L .23119 .54943 L F
.423 .578 .902 r
.23414 .55048 m .23315 .55228 L .23119 .54943 L F
.321 .448 .833 r
.23414 .55048 m .23583 .55407 L .23315 .55228 L F
.832 .78 .802 r
.61203 .45485 m .61127 .45557 L .61078 .45281 L F
.511 .789 .996 r
.63759 .42294 m .63534 .42349 L .63432 .42237 L F
.371 .548 .898 r
.41956 .58708 m .42037 .58532 L .41844 .5854 L F
.41956 .58708 m .42189 .58733 L .42037 .58532 L F
0 .188 .705 r
.66835 .44204 m .66715 .44397 L .66588 .44229 L F
.308 .173 .528 r
.2219 .60599 m .22006 .60468 L .22142 .60365 L F
.2219 .60599 m .21983 .60733 L .22006 .60468 L F
.493 .162 .334 r
.53029 .67715 m .52935 .67965 L .52685 .67991 L F
.376 0 .103 r
.5327 .67747 m .52935 .67965 L .53029 .67715 L F
.404 .2 .487 r
.23182 .57543 m .23133 .57823 L .22965 .57868 L F
.471 .335 .613 r
.23133 .57823 m .22978 .58104 L .22965 .57868 L F
.452 .455 .771 r
.50272 .692 m .50382 .68857 L .50228 .68844 L F
.50272 .692 m .50639 .69093 L .50382 .68857 L F
.566 .526 .77 r
.50304 .69433 m .50639 .69093 L .50272 .692 L F
.745 .318 .236 r
.45241 .62725 m .45575 .62788 L .4544 .62929 L F
.853 .473 .33 r
.4544 .62929 m .45575 .62788 L .45597 .6295 L F
.773 .403 .355 r
.45575 .62788 m .45821 .63076 L .45597 .6295 L F
.284 .784 .853 r
.39079 .5925 m .38967 .5927 L .38746 .59316 L F
.462 .127 .312 r
.38967 .5927 m .38684 .59476 L .38746 .59316 L F
.321 0 0 r
.34271 .59007 m .3424 .59071 L .34478 .59029 L F
.262 0 0 r
.34478 .59029 m .34455 .59043 L .34271 .59007 L F
.297 0 .051 r
.34271 .59007 m .34455 .59043 L .34678 .58723 L F
0 0 0 r
.34678 .58723 m .3459 .58952 L .34905 .58681 L F
.34678 .58723 m .34455 .59043 L .3459 .58952 L F
0 0 .453 r
.55228 .66454 m .55283 .66512 L .55328 .66153 L F
.435 .534 .859 r
.36682 .6183 m .36657 .62165 L .3658 .61827 L F
.36682 .6183 m .36846 .62153 L .36657 .62165 L F
.659 .972 .854 r
.23782 .56216 m .23612 .56244 L .23533 .56369 L F
.266 .772 .766 r
.2382 .56183 m .23782 .56216 L .23918 .56206 L F
.2382 .56183 m .23612 .56244 L .23782 .56216 L F
0 0 .442 r
.47451 .68581 m .47546 .68229 L .47672 .68566 L F
0 0 .337 r
.47555 .68775 m .47451 .68581 L .47672 .68566 L F
.47555 .68775 m .47612 .68893 L .47451 .68581 L F
.458 .215 .456 r
.19475 .59884 m .19688 .5985 L .19749 .59607 L F
.356 .17 .486 r
.19688 .5985 m .1991 .59514 L .19749 .59607 L F
.496 .504 .795 r
.78744 .48771 m .78612 .49101 L .78567 .4887 L F
.774 .633 .705 r
.58332 .60234 m .58519 .60472 L .58542 .60354 L F
.796 .884 .459 r
.58438 .60557 m .58519 .60472 L .58527 .60746 L F
.58438 .60557 m .58542 .60354 L .58519 .60472 L F
.674 .698 .864 r
.4252 .58764 m .42892 .58937 L .42742 .58677 L F
.658 .718 .893 r
.42742 .58677 m .42892 .58937 L .4315 .58839 L F
.837 .844 .85 r
.64158 .44346 m .64077 .44757 L .63903 .44724 L F
.64158 .44346 m .64297 .4453 L .64077 .44757 L F
0 0 0 r
.37719 .58242 m .38107 .58106 L .37895 .58178 L F
.548 .723 .955 r
.43863 .58277 m .43698 .58358 L .43651 .58343 L F
.43863 .58277 m .4399 .58407 L .43698 .58358 L F
.296 .107 .446 r
.23358 .57671 m .23182 .57543 L .23382 .57422 L F
.23358 .57671 m .23133 .57823 L .23182 .57543 L F
.399 .028 .213 r
.37052 .60049 m .3667 .60336 L .36793 .60089 L F
.667 .378 .474 r
.45446 .62426 m .45673 .6247 L .45816 .62228 L F
.654 .414 .544 r
.45988 .62413 m .45816 .62228 L .45673 .6247 L F
.45988 .62413 m .4604 .62193 L .45816 .62228 L F
.642 .806 .962 r
.55781 .59842 m .56029 .59754 L .56141 .59885 L F
.716 .305 .267 r
.56141 .59885 m .56068 .60076 L .55781 .59842 L F
.451 .713 .98 r
.56029 .59754 m .56252 .59739 L .56141 .59885 L F
.583 .844 .491 r
.56141 .59885 m .56147 .59863 L .56068 .60076 L F
.56141 .59885 m .56252 .59739 L .56147 .59863 L F
.975 .669 .317 r
.66736 .44845 m .66833 .4474 L .66818 .44483 L F
.66736 .44845 m .66876 .45036 L .66833 .4474 L F
.276 .625 .961 r
.21114 .54401 m .21026 .54498 L .20856 .54376 L F
.21114 .54401 m .21253 .54537 L .21026 .54498 L F
.346 0 0 r
.54664 .65117 m .54182 .65318 L .54182 .6507 L F
0 0 0 r
.19509 .60158 m .19688 .5985 L .19475 .59884 L F
.763 .253 0 r
.54579 .6677 m .54224 .66538 L .54182 .66799 L F
.176 0 0 r
.54182 .66799 m .54467 .66807 L .54579 .6677 L F
.763 .253 0 r
.54579 .6677 m .54467 .66807 L .54224 .66538 L F
.263 .756 .683 r
.54579 .6677 m .54467 .66807 L .5469 .66725 L F
.473 .196 .411 r
.54467 .66807 m .5469 .66725 L .54579 .6677 L F
.532 .45 .708 r
.54777 .66565 m .54874 .66779 L .54579 .6677 L F
.885 .834 .791 r
.62104 .4434 m .62036 .441 L .62183 .4422 L F
.551 .426 .663 r
.33281 .59324 m .33517 .59295 L .33478 .58982 L F
.32 0 .225 r
.33237 .59522 m .33517 .59295 L .33281 .59324 L F
.848 .789 .794 r
.61127 .45557 m .60876 .45571 L .61078 .45281 L F
.856 .747 .742 r
.61127 .45557 m .60762 .45804 L .60876 .45571 L F
.61127 .45557 m .6096 .45916 L .60762 .45804 L F
.246 .047 .401 r
.49507 .68842 m .49468 .68989 L .49398 .68926 L F
.526 .085 .144 r
.43535 .61924 m .43764 .62031 L .43881 .61882 L F
.504 .052 .11 r
.43764 .62031 m .44128 .61891 L .43881 .61882 L F
.975 .842 .647 r
.59258 .61222 m .59181 .61549 L .59296 .61634 L F
.973 .757 .552 r
.59134 .61795 m .59296 .61634 L .59181 .61549 L F
.59134 .61795 m .59273 .61888 L .59296 .61634 L F
.807 .749 .798 r
.61717 .44792 m .61284 .44964 L .61584 .44691 L F
.847 .867 .856 r
.61951 .44559 m .61717 .44792 L .61584 .44691 L F
.328 .206 .557 r
.47197 .66825 m .4727 .66969 L .47249 .66965 L F
.775 .418 0 r
.7908 .49832 m .79131 .49914 L .79102 .49847 L F
.7908 .49832 m .79102 .49847 L .79013 .49644 L F
.975 .917 .599 r
.79018 .49733 m .78998 .49861 L .7908 .49832 L F
.651 .955 .746 r
.7908 .49832 m .78998 .49861 L .79053 .49813 L F
.7908 .49832 m .79053 .49813 L .79168 .49712 L F
.975 .917 .599 r
.7905 .49538 m .7908 .49832 L .79013 .49644 L F
0 .18 .714 r
.78789 .49298 m .78978 .49472 L .79013 .49644 L F
.78978 .49472 m .7905 .49538 L .79044 .49555 L F
.78978 .49472 m .79044 .49555 L .79013 .49644 L F
.639 .125 .005 r
.78547 .49248 m .78789 .49298 L .78655 .49229 L F
.779 .588 .641 r
.78874 .49044 m .78789 .49298 L .78547 .49248 L F
.632 .279 .355 r
.78801 .49485 m .7905 .49538 L .78789 .49298 L F
0 0 .117 r
.78806 .49188 m .78801 .49485 L .78789 .49298 L F
.715 .56 .678 r
.78583 .49435 m .78801 .49485 L .78805 .49254 L F
.78778 .4922 m .78805 .49254 L .78806 .49188 L F
.78583 .49435 m .78805 .49254 L .78778 .4922 L F
.445 .141 .355 r
.78801 .49485 m .79043 .49635 L .7905 .49538 L F
.79043 .49635 m .79168 .49712 L .7905 .49538 L F
.79043 .49635 m .7914 .49449 L .79168 .49712 L F
.78801 .49485 m .79046 .49459 L .79043 .49635 L F
.975 .917 .599 r
.7905 .49538 m .79044 .49578 L .79043 .49635 L F
.445 .141 .355 r
.79046 .49459 m .7914 .49449 L .79043 .49635 L F
.975 .917 .599 r
.79043 .49635 m .79018 .49733 L .79033 .49758 L F
.79044 .49578 m .79018 .49733 L .79043 .49635 L F
.7905 .49538 m .79033 .49758 L .7908 .49832 L F
.775 .418 0 r
.7908 .49832 m .79155 .49968 L .79131 .49914 L F
.185 .601 .943 r
.79302 .49916 m .79155 .49968 L .7908 .49832 L F
.79302 .49916 m .79341 .50013 L .79155 .49968 L F
.811 .65 .683 r
.5832 .61884 m .58528 .61968 L .58436 .62188 L F
.734 .649 .765 r
.23757 .56222 m .23924 .56682 L .23568 .56648 L F
.202 .113 .525 r
.23718 .56832 m .23568 .56648 L .23924 .56682 L F
.731 .964 .693 r
.24011 .56521 m .23718 .56832 L .23924 .56682 L F
.656 .329 .407 r
.52693 .69306 m .52965 .69189 L .52715 .69236 L F
.496 .504 .795 r
.78744 .48771 m .78874 .49044 L .78612 .49101 L F
.779 .588 .641 r
.78874 .49044 m .78547 .49248 L .78612 .49101 L F
.802 .906 .913 r
.78154 .48285 m .77794 .48384 L .78031 .48206 L F
.687 .287 .283 r
.78031 .48206 m .78396 .48193 L .78154 .48285 L F
.489 .023 .073 r
.50373 .65379 m .5048 .65568 L .50229 .65488 L F
.50373 .65379 m .50629 .65394 L .5048 .65568 L F
.643 .197 .177 r
.46158 .6307 m .46532 .63081 L .46391 .6324 L F
.446 0 0 r
.46532 .63081 m .46647 .63228 L .46391 .6324 L F
.46532 .63081 m .46796 .63105 L .46647 .63228 L F
.52 .047 .072 r
.38784 .62512 m .38976 .62621 L .39133 .62462 L F
.581 .134 .154 r
.38976 .62621 m .39354 .62497 L .39133 .62462 L F
.391 0 0 r
.43701 .62586 m .43535 .62731 L .43296 .62739 L F
.452 0 .02 r
.43879 .6267 m .43535 .62731 L .43701 .62586 L F
.461 .299 .574 r
.52698 .65137 m .52952 .65075 L .52924 .64752 L F
.454 .354 .652 r
.52698 .65137 m .52965 .65355 L .52952 .65075 L F
.52698 .65137 m .52757 .6538 L .52965 .65355 L F
.52965 .65355 m .52757 .6538 L .52698 .65137 L F
.492 .326 .583 r
.3303 .59817 m .33237 .59522 L .33065 .59594 L F
.789 .649 .707 r
.49988 .70889 m .50519 .70729 L .50145 .70636 L F
.49988 .70889 m .50329 .70926 L .50519 .70729 L F
0 0 0 r
.50329 .70926 m .506 .70684 L .50519 .70729 L F
.43 .408 .734 r
.7631 .49421 m .76573 .49545 L .76462 .49311 L F
.525 .739 .973 r
.46522 .62274 m .46407 .62522 L .4628 .62203 L F
.46522 .62274 m .46655 .62483 L .46407 .62522 L F
.542 .002 0 r
.45993 .59573 m .46271 .5969 L .464 .59607 L F
.935 .95 .624 r
.464 .59607 m .46271 .5969 L .4628 .59808 L F
.586 .423 .627 r
.5116 .64612 m .51321 .64513 L .51088 .6436 L F
.4 .454 .801 r
.51088 .6436 m .51188 .64118 L .50945 .64178 L F
.51088 .6436 m .51321 .64513 L .51188 .64118 L F
.681 .369 .44 r
.53842 .65976 m .54072 .66207 L .53775 .6622 L F
.647 .559 .742 r
.54003 .65728 m .5415 .65991 L .53842 .65976 L F
.638 .376 .505 r
.5415 .65991 m .54072 .66207 L .53842 .65976 L F
.455 .309 .593 r
.50586 .67552 m .50723 .67395 L .50508 .67437 L F
.362 0 0 r
.35141 .58651 m .35391 .58617 L .3552 .58479 L F
.268 0 0 r
.3552 .58479 m .35696 .58512 L .35765 .5845 L F
.3552 .58479 m .35391 .58617 L .35696 .58512 L F
.012 0 0 r
.45954 .59908 m .46146 .599 L .45963 .59914 L F
.607 .952 .903 r
.45963 .59914 m .46146 .599 L .4628 .59808 L F
.247 .524 .914 r
.23583 .55407 m .23697 .55373 L .2366 .55529 L F
.218 .491 .898 r
.23697 .55373 m .2389 .55644 L .2366 .55529 L F
0 0 0 r
.47156 .61618 m .47241 .61577 L .47361 .61393 L F
.064 .303 .788 r
.47156 .61618 m .47381 .61818 L .47241 .61577 L F
.401 0 0 r
.46131 .62317 m .4604 .62193 L .45988 .62413 L F
.46131 .62317 m .4628 .62203 L .4604 .62193 L F
.419 .836 .966 r
.40707 .57961 m .41066 .57949 L .40827 .57967 L F
.602 .614 .836 r
.45159 .59614 m .45554 .59844 L .4537 .59603 L F
.048 .36 .832 r
.4537 .59603 m .45554 .59844 L .45615 .59754 L F
.847 .867 .856 r
.61951 .44559 m .61584 .44691 L .61823 .44425 L F
.88 .864 .819 r
.62104 .4434 m .61951 .44559 L .61823 .44425 L F
.711 .863 .954 r
.39066 .58092 m .38704 .58109 L .38929 .58035 L F
.298 .688 .975 r
.39137 .57998 m .39066 .58092 L .38929 .58035 L F
.39137 .57998 m .39289 .58101 L .39066 .58092 L F
.439 .261 .541 r
.56793 .59771 m .56928 .59847 L .56973 .59566 L F
.124 .079 .53 r
.2084 .57843 m .20986 .57727 L .20957 .57466 L F
.17 .158 .601 r
.2084 .57843 m .20994 .58012 L .20986 .57727 L F
.339 .184 .52 r
.2084 .57843 m .20828 .58096 L .20994 .58012 L F
.62 .383 .537 r
.48165 .6919 m .48168 .69583 L .48094 .69271 L F
0 0 .38 r
.48197 .69707 m .48174 .69683 L .48154 .69525 L F
.62 .383 .537 r
.48168 .69583 m .48168 .69583 L .48154 .69525 L F
.48168 .69583 m .48154 .69525 L .48094 .69271 L F
.251 .253 .666 r
.48494 .69516 m .4821 .69444 L .48303 .6929 L F
0 0 .371 r
.48186 .69205 m .48167 .69513 L .48165 .6919 L F
.48303 .6929 m .4821 .69444 L .48186 .69205 L F
.4821 .69444 m .48167 .69513 L .48186 .69205 L F
.724 .657 .782 r
.48494 .69516 m .48285 .698 L .48231 .6966 L F
.48494 .69516 m .48351 .69594 L .4821 .69444 L F
.48351 .69594 m .48231 .6966 L .48214 .69484 L F
.48351 .69594 m .48214 .69484 L .4821 .69444 L F
0 0 .437 r
.48141 .69427 m .48168 .69583 L .48214 .69484 L F
0 0 .371 r
.48303 .6929 m .48168 .69583 L .48167 .69513 L F
0 0 .38 r
.48197 .69707 m .48168 .69584 L .48168 .69583 L F
.48174 .69591 m .48168 .69583 L .48141 .69427 L F
.48197 .69707 m .48168 .69583 L .48174 .69591 L F
.48168 .69584 m .48154 .69525 L .48141 .69427 L F
0 0 .437 r
.48141 .69427 m .48168 .69583 L .48168 .69583 L F
.251 .253 .666 r
.4821 .69444 m .48141 .69427 L .48303 .6929 L F
0 0 .437 r
.48141 .69427 m .48214 .69484 L .48303 .6929 L F
.724 .657 .782 r
.4821 .69444 m .48231 .6966 L .48141 .69427 L F
0 0 .38 r
.48285 .698 m .48197 .69707 L .48174 .69591 L F
.48231 .6966 m .48174 .69591 L .48141 .69427 L F
.48285 .698 m .48174 .69591 L .48231 .6966 L F
0 0 .437 r
.48141 .69427 m .48154 .69525 L .48168 .69583 L F
.48154 .69525 m .48174 .69683 L .48168 .69583 L F
.62 .383 .537 r
.48094 .69271 m .48168 .69583 L .47899 .69492 L F
0 0 .371 r
.48303 .6929 m .48165 .6919 L .48458 .6935 L F
.531 .088 .142 r
.48165 .6919 m .48405 .6921 L .48463 .69353 L F
.548 .033 0 r
.48236 .69089 m .48012 .69176 L .48303 .6929 L F
.48012 .69176 m .47921 .69212 L .48303 .6929 L F
0 0 .371 r
.48303 .6929 m .48458 .6935 L .48463 .69353 L F
.427 .475 .807 r
.33046 .61248 m .33196 .61632 L .33338 .61543 L F
.985 .724 .441 r
.33196 .61632 m .33174 .61844 L .33338 .61543 L F
.652 .577 .758 r
.54562 .69477 m .54243 .69208 L .54533 .6913 L F
.688 .712 .867 r
.35336 .63508 m .35503 .63745 L .35697 .63609 L F
.659 .773 .933 r
.52555 .67104 m .52317 .67081 L .52435 .67005 L F
.833 .592 .574 r
.52555 .67104 m .52655 .6748 L .52086 .6735 L F
.567 .618 .863 r
.52647 .67062 m .52555 .67104 L .52435 .67005 L F
.221 .308 .742 r
.52555 .67104 m .52822 .67372 L .52777 .67094 L F
.567 .618 .863 r
.52647 .67062 m .52655 .6748 L .52555 .67104 L F
.71 .422 .486 r
.54149 .62385 m .5447 .62218 L .54179 .62107 L F
.54149 .62385 m .54504 .62426 L .5447 .62218 L F
.345 .779 .968 r
.19694 .54333 m .19908 .54309 L .20077 .54365 L F
.415 .789 .993 r
.19908 .54309 m .20276 .54358 L .20077 .54365 L F
.777 .663 .738 r
.51388 .70351 m .51509 .70614 L .51676 .70369 L F
.586 .407 .606 r
.51676 .70369 m .51753 .70602 L .51509 .70614 L F
.077 0 .161 r
.51753 .70602 m .51925 .70328 L .51676 .70369 L F
.479 0 0 r
.66799 .44474 m .66818 .44483 L .66715 .44397 L F
.994 .778 .409 r
.66655 .44691 m .66818 .44483 L .66799 .44474 L F
.66655 .44691 m .66736 .44845 L .66818 .44483 L F
.573 .53 .769 r
.45819 .61305 m .45913 .61652 L .46158 .61574 L F
.506 .334 .581 r
.45913 .61652 m .46141 .61826 L .46158 .61574 L F
.46158 .61574 m .46141 .61826 L .45913 .61652 L F
.836 .671 .678 r
.5181 .63843 m .51999 .63641 L .51805 .63693 L F
.15 .495 .906 r
.64546 .44592 m .64297 .4453 L .64158 .44346 L F
.96 .649 .391 r
.49827 .6828 m .49714 .68421 L .49752 .67956 L F
.82 .647 .668 r
.62039 .46777 m .6166 .46993 L .61849 .46776 L F
.62039 .46777 m .6187 .47027 L .6166 .46993 L F
.702 .484 .59 r
.62039 .46777 m .62231 .47156 L .6187 .47027 L F
.757 .619 .707 r
.54182 .64823 m .53847 .64578 L .5404 .64526 L F
.57 .686 .919 r
.44153 .58216 m .4399 .58407 L .43863 .58277 L F
.44153 .58216 m .44226 .58344 L .4399 .58407 L F
.163 .361 .813 r
.65969 .4306 m .65753 .43069 L .65739 .42895 L F
.65969 .4306 m .65983 .43225 L .65753 .43069 L F
.579 .822 .99 r
.38479 .58145 m .38107 .58106 L .38333 .58062 L F
.292 .745 .957 r
.38333 .58062 m .38704 .58109 L .38479 .58145 L F
.473 .151 .339 r
.3788 .59573 m .37794 .59822 L .37559 .59863 L F
.441 .117 .319 r
.38119 .5953 m .37794 .59822 L .3788 .59573 L F
.646 .966 .9 r
.23533 .56369 m .23612 .56244 L .23757 .56222 L F
.734 .649 .765 r
.23757 .56222 m .23568 .56648 L .23533 .56369 L F
.012 0 0 r
.45954 .59908 m .45963 .59914 L .45731 .60016 L F
.55 .312 .507 r
.22441 .59592 m .22401 .59828 L .22168 .59847 L F
.341 .129 .439 r
.22617 .59521 m .22401 .59828 L .22441 .59592 L F
.874 .94 .858 r
.47137 .62155 m .46891 .62246 L .47124 .62125 L F
.597 .59 .815 r
.78169 .51215 m .78355 .50857 L .78054 .50856 L F
.78169 .51215 m .78452 .51165 L .78355 .50857 L F
.408 .734 .991 r
.45159 .59614 m .45258 .59502 L .45035 .59534 L F
.45159 .59614 m .4537 .59603 L .45258 .59502 L F
.247 .411 .829 r
.43543 .58965 m .4361 .58779 L .43374 .5882 L F
.43543 .58965 m .43709 .58976 L .4361 .58779 L F
.759 .539 .599 r
.43543 .58965 m .43854 .59276 L .43709 .58976 L F
.43543 .58965 m .43471 .59358 L .43854 .59276 L F
.137 .634 .91 r
.77531 .48483 m .77429 .48516 L .77215 .48669 L F
.77531 .48483 m .77575 .48532 L .77429 .48516 L F
.354 .211 .544 r
.6444 .43809 m .64629 .43759 L .64455 .43594 L F
.6444 .43809 m .64629 .43759 L .64455 .43594 L F
.286 0 0 r
.39615 .63617 m .39231 .63752 L .39382 .63637 L F
.582 .446 .66 r
.49403 .65129 m .49391 .65497 L .49651 .65083 L F
.948 .785 .646 r
.54876 .65929 m .5494 .65651 L .55032 .65969 L F
.281 0 0 r
.55032 .65969 m .54674 .6618 L .54876 .65929 L F
.55032 .65969 m .54906 .66141 L .54674 .6618 L F
.487 .329 .593 r
.48165 .70662 m .48447 .70644 L .48518 .7036 L F
.498 .422 .702 r
.48165 .70662 m .48401 .70803 L .48447 .70644 L F
.271 .149 .524 r
.20749 .63343 m .20754 .63585 L .20615 .63647 L F
.029 0 .397 r
.20697 .63813 m .20615 .63647 L .20754 .63585 L F
.20697 .63813 m .20607 .63892 L .20615 .63647 L F
.373 0 0 r
.39981 .63566 m .39852 .63629 L .39615 .63617 L F
.156 0 0 r
.40201 .63542 m .39852 .63629 L .39981 .63566 L F
.675 .226 .176 r
.5259 .7177 m .52989 .71798 L .52733 .721 L F
.5259 .7177 m .52855 .71968 L .52989 .71798 L F
.944 .622 .39 r
.52855 .71968 m .53061 .72116 L .52989 .71798 L F
.358 0 .076 r
.54562 .69477 m .54371 .69641 L .54235 .69675 L F
0 0 .517 r
.54646 .69337 m .54562 .69477 L .54533 .6913 L F
.702 .952 .678 r
.54646 .69337 m .54371 .69641 L .54562 .69477 L F
.5 .144 .294 r
.51207 .69301 m .51144 .69463 L .50907 .69465 L F
.267 0 .192 r
.5138 .69361 m .51207 .69301 L .51419 .69116 L F
.5138 .69361 m .51144 .69463 L .51207 .69301 L F
.937 .736 .606 r
.57565 .63656 m .57879 .63649 L .57485 .63667 L F
.57565 .63656 m .57888 .63899 L .57879 .63649 L F
.524 .503 .774 r
.5819 .63475 m .58148 .63147 L .57968 .63235 L F
.57958 .63324 m .57968 .63235 L .57884 .63277 L F
.5819 .63475 m .57968 .63235 L .57958 .63324 L F
0 0 .278 r
.57879 .63649 m .57926 .63599 L .57931 .63283 L F
.57926 .63599 m .57962 .63561 L .57946 .63421 L F
.57926 .63599 m .57946 .63421 L .57931 .63283 L F
.996 .795 .515 r
.58103 .63764 m .5804 .63674 L .57879 .63649 L F
.5804 .63674 m .57962 .63561 L .57904 .63622 L F
.5804 .63674 m .57904 .63622 L .57879 .63649 L F
.665 .709 .881 r
.57888 .63899 m .58103 .63764 L .57879 .63649 L F
.996 .795 .515 r
.58103 .63764 m .57983 .63803 L .57962 .63561 L F
.497 .147 .303 r
.58355 .6354 m .57983 .63803 L .58103 .63764 L F
.58122 .63704 m .58185 .63757 L .57983 .63803 L F
.817 .743 .782 r
.58103 .63764 m .58446 .63694 L .58355 .6354 L F
.497 .147 .303 r
.58355 .6354 m .58202 .63735 L .58122 .63704 L F
.58202 .63735 m .58185 .63757 L .58122 .63704 L F
.15 .165 .62 r
.58336 .63837 m .58429 .63784 L .58425 .63771 L F
0 0 0 r
.58446 .63694 m .58274 .63883 L .58336 .63837 L F
.817 .743 .782 r
.58103 .63764 m .58235 .63926 L .58446 .63694 L F
.15 .165 .62 r
.58336 .63837 m .58355 .6354 L .58446 .63694 L F
.58336 .63837 m .58425 .63771 L .58355 .6354 L F
0 0 0 r
.58274 .63883 m .58235 .63926 L .58336 .63837 L F
.291 .79 .823 r
.37344 .58212 m .37313 .58253 L .37125 .58262 L F
.37344 .58212 m .37551 .58194 L .37313 .58253 L F
.417 .518 .853 r
.33307 .62177 m .33327 .61869 L .33174 .61844 L F
.33307 .62177 m .33471 .62145 L .33327 .61869 L F
.373 .264 .599 r
.33307 .62177 m .33495 .6239 L .33471 .62145 L F
.712 .983 .895 r
.55251 .66033 m .55109 .66002 L .54906 .66141 L F
0 0 0 r
.55491 .65665 m .55449 .65735 L .55251 .66033 L F
.783 .771 .842 r
.55449 .65735 m .55109 .66002 L .55251 .66033 L F
.55449 .65735 m .55328 .66153 L .55109 .66002 L F
.939 .608 .378 r
.55334 .65651 m .55413 .65797 L .55449 .65735 L F
.783 .771 .842 r
.55449 .65735 m .55451 .66003 L .55328 .66153 L F
0 .012 .585 r
.55539 .66031 m .55451 .66003 L .55449 .65735 L F
.939 .608 .378 r
.55413 .65797 m .55539 .66031 L .55449 .65735 L F
0 0 0 r
.55507 .6564 m .55449 .65735 L .55491 .65665 L F
.63 .645 .846 r
.52517 .72826 m .52658 .73019 L .52756 .72826 L F
.519 .281 .493 r
.53656 .69488 m .53416 .69756 L .53417 .6948 L F
.53656 .69488 m .53654 .69721 L .53416 .69756 L F
.449 .226 .482 r
.53876 .69645 m .53656 .69488 L .54019 .69475 L F
.53876 .69645 m .53654 .69721 L .53656 .69488 L F
.885 .834 .791 r
.62104 .4434 m .61823 .44425 L .62036 .441 L F
.441 .257 .534 r
.22833 .58664 m .228 .58977 L .22602 .59031 L F
.481 .384 .668 r
.22825 .59208 m .22602 .59031 L .228 .58977 L F
.22825 .59208 m .22637 .59277 L .22602 .59031 L F
.811 .633 .662 r
.60341 .64203 m .60158 .64502 L .60508 .6453 L F
.75 .524 .588 r
.60141 .64756 m .60508 .6453 L .60158 .64502 L F
.60141 .64756 m .60511 .64787 L .60508 .6453 L F
.712 .679 .816 r
.59641 .46769 m .59293 .46813 L .59552 .46493 L F
.65 .354 .455 r
.59641 .46769 m .59303 .46997 L .59293 .46813 L F
.59641 .46769 m .5953 .47004 L .59303 .46997 L F
.719 .431 .489 r
.59902 .47002 m .59641 .46769 L .59898 .46756 L F
.59902 .47002 m .5953 .47004 L .59641 .46769 L F
.502 0 0 r
.43535 .61924 m .43177 .61939 L .43392 .62047 L F
.523 .014 0 r
.43392 .62047 m .43764 .62031 L .43535 .61924 L F
.858 .808 .8 r
.59147 .46543 m .59293 .46813 L .58976 .4673 L F
.735 .662 .779 r
.59303 .46997 m .58976 .4673 L .59293 .46813 L F
.774 .782 .86 r
.59552 .46493 m .59293 .46813 L .59147 .46543 L F
.28 0 0 r
.24679 .55973 m .24668 .56044 L .24463 .56028 L F
0 .472 .727 r
.24668 .56044 m .24482 .56004 L .24463 .56028 L F
.24482 .56004 m .24246 .55953 L .24463 .56028 L F
.515 .894 .962 r
.24463 .56028 m .24409 .5613 L .24441 .56057 L F
.24463 .56028 m .24441 .56057 L .2451 .55898 L F
.24463 .56028 m .24253 .56102 L .24409 .5613 L F
.922 .78 .686 r
.60459 .65054 m .60554 .65378 L .60655 .65127 L F
.60459 .65054 m .60325 .65365 L .60554 .65378 L F
.835 .84 .85 r
.60325 .65365 m .60368 .65648 L .60554 .65378 L F
.998 .803 .512 r
.60053 .6562 m .60139 .65943 L .60368 .65648 L F
.869 .718 .691 r
.60055 .65644 m .60041 .65644 L .60053 .6562 L F
.61 .599 .815 r
.59679 .65583 m .59956 .65808 L .60053 .6562 L F
.869 .718 .691 r
.60041 .65644 m .6004 .65644 L .60053 .6562 L F
.61 .599 .815 r
.60041 .65644 m .60052 .65639 L .60053 .6562 L F
.835 .84 .85 r
.6005 .65635 m .6004 .65644 L .60041 .65644 L F
.60052 .65639 m .60041 .65644 L .60055 .65644 L F
.6005 .65635 m .60041 .65644 L .60052 .65639 L F
.61 .599 .815 r
.59956 .65808 m .60036 .65873 L .60052 .65639 L F
.59956 .65808 m .60052 .65639 L .60041 .65644 L F
.998 .803 .512 r
.60053 .6562 m .60052 .65639 L .60055 .65644 L F
.60053 .6562 m .60072 .65897 L .60139 .65943 L F
.869 .718 .691 r
.60368 .65648 m .60055 .65644 L .60053 .6562 L F
.835 .84 .85 r
.60325 .65365 m .6005 .65635 L .60368 .65648 L F
.6005 .65635 m .60055 .65644 L .60368 .65648 L F
.998 .803 .512 r
.60055 .65644 m .60036 .65873 L .60072 .65897 L F
.60052 .65639 m .60036 .65873 L .60055 .65644 L F
0 0 0 r
.60214 .46091 m .60479 .45747 L .60421 .4603 L F
.60214 .46091 m .60253 .46048 L .60479 .45747 L F
.538 .685 .934 r
.47273 .67081 m .47489 .66941 L .4727 .66969 L F
.47273 .67081 m .47651 .67103 L .47489 .66941 L F
.077 0 .161 r
.51753 .70602 m .519 .70565 L .51925 .70328 L F
.184 .074 .485 r
.51925 .70328 m .52137 .69966 L .5183 .6992 L F
.51925 .70328 m .52154 .70233 L .52137 .69966 L F
.389 .028 .226 r
.51925 .70328 m .519 .70565 L .52125 .7047 L F
.599 .273 .389 r
.52517 .72826 m .52756 .72826 L .52861 .72676 L F
.881 .992 .795 r
.53092 .72377 m .52861 .72676 L .5285 .72565 L F
.539 .359 .586 r
.53092 .72377 m .531 .72644 L .52861 .72676 L F
.772 .32 .175 r
.531 .72644 m .5285 .72565 L .52861 .72676 L F
.937 .732 .601 r
.59107 .60351 m .59314 .6018 L .59094 .60132 L F
.59107 .60351 m .5928 .60429 L .59314 .6018 L F
.518 .683 .941 r
.23 .54788 m .22934 .54992 L .22783 .54853 L F
.23 .54788 m .23119 .54943 L .22934 .54992 L F
.903 .744 .674 r
.59396 .62713 m .59513 .63044 L .59577 .6281 L F
.171 .7 .689 r
.63202 .44292 m .63618 .4419 L .63424 .44311 L F
.873 .433 .125 r
.58404 .59492 m .58694 .59807 L .58698 .59606 L F
.346 0 .14 r
.50945 .64178 m .51188 .64118 L .51125 .64028 L F
.789 .822 .877 r
.51188 .64118 m .51343 .6406 L .51125 .64028 L F
.668 .795 .943 r
.59328 .66224 m .59223 .66082 L .58962 .66185 L F
.665 .875 .977 r
.59534 .66027 m .59223 .66082 L .59328 .66224 L F
.585 .645 .876 r
.76707 .50067 m .76889 .49849 L .76665 .49893 L F
.76707 .50067 m .76972 .50012 L .76889 .49849 L F
.655 .64 .823 r
.48056 .71535 m .48097 .71761 L .48304 .71491 L F
.13 .3 .769 r
.51388 .70351 m .51601 .70515 L .51509 .70614 L F
.439 .777 .998 r
.51509 .70614 m .51753 .70602 L .51601 .70515 L F
0 0 0 r
.51601 .70515 m .51381 .70806 L .51509 .70614 L F
.715 .788 .909 r
.58384 .46869 m .58492 .47051 L .58109 .47011 L F
.786 .533 .553 r
.58109 .47011 m .58492 .47051 L .58471 .47297 L F
.373 .603 .937 r
.58593 .46889 m .58492 .47051 L .58384 .46869 L F
0 0 .196 r
.58471 .47297 m .58492 .47051 L .58593 .46889 L F
.482 .283 .533 r
.49988 .70889 m .49747 .71176 L .49753 .70928 L F
.768 .683 .769 r
.5259 .7177 m .52733 .721 L .52369 .72054 L F
.367 .777 .982 r
.52369 .72054 m .52733 .721 L .52585 .7202 L F
.756 .363 .31 r
.53061 .72116 m .52585 .7202 L .52733 .721 L F
.573 .749 .961 r
.43654 .58045 m .43651 .58343 L .43437 .58059 L F
.43654 .58045 m .43863 .58277 L .43651 .58343 L F
.322 .16 .501 r
.21983 .60733 m .21976 .60974 L .21824 .61038 L F
.315 .121 .45 r
.21922 .61197 m .21824 .61038 L .21976 .60974 L F
.21922 .61197 m .21787 .61271 L .21824 .61038 L F
.434 .22 .487 r
.36244 .6045 m .36205 .60729 L .36009 .60748 L F
.473 .454 .756 r
.36205 .60729 m .36281 .60895 L .36009 .60748 L F
.713 .65 .094 r
.52233 .71078 m .52507 .71002 L .52369 .70876 L F
.602 .84 .989 r
.52507 .71002 m .52738 .70907 L .52369 .70876 L F
.919 .55 .121 r
.66508 .4413 m .66458 .43909 L .66349 .43828 L F
.585 .36 .542 r
.49903 .65054 m .50172 .64786 L .49929 .64833 L F
.481 .827 .997 r
.47526 .66539 m .47751 .66492 L .47893 .66562 L F
.99 .73 .38 r
.47804 .66776 m .47893 .66562 L .47751 .66492 L F
.47804 .66776 m .47901 .66815 L .47893 .66562 L F
.117 0 .221 r
.65714 .45784 m .65473 .46097 L .6552 .45926 L F
.791 .747 .812 r
.5404 .64526 m .53847 .64578 L .53647 .6436 L F
.5404 .64526 m .53847 .64578 L .53647 .6436 L F
.472 .86 .657 r
.47838 .69843 m .47708 .69928 L .47929 .69774 L F
.709 .675 .814 r
.47929 .69774 m .48062 .70083 L .47708 .69928 L F
.41 0 0 r
.47708 .69928 m .48062 .70083 L .47937 .70042 L F
.248 .401 .82 r
.48179 .69946 m .48062 .70083 L .47929 .69774 L F
.588 .911 .978 r
.47937 .70042 m .48062 .70083 L .48179 .69946 L F
.473 .251 .495 r
.23047 .5841 m .23007 .58645 L .22833 .58664 L F
.406 .367 .702 r
.23177 .58058 m .23047 .5841 L .22978 .58104 L F
.23177 .58058 m .23271 .58356 L .23047 .5841 L F
.179 0 .291 r
.23271 .58356 m .23007 .58645 L .23047 .5841 L F
0 .533 .732 r
.45964 .67959 m .46372 .67748 L .46043 .6776 L F
.637 .245 .285 r
.62231 .47156 m .62397 .47068 L .6228 .47266 L F
.59 .194 .259 r
.6228 .47266 m .62397 .47068 L .62647 .47229 L F
.584 .204 .288 r
.62397 .47068 m .62703 .47046 L .62647 .47229 L F
0 .175 .696 r
.46564 .70198 m .46426 .70118 L .46291 .70024 L F
.46564 .70198 m .46539 .70263 L .46426 .70118 L F
.647 .357 .465 r
.6084 .46947 m .60499 .46795 L .6085 .46769 L F
.614 .296 .408 r
.6085 .46769 m .61094 .46953 L .6084 .46947 L F
.65 .262 .295 r
.61051 .46821 m .61094 .46953 L .6085 .46769 L F
.221 0 .332 r
.41697 .61826 m .41817 .62027 L .41862 .61814 L F
.41697 .61826 m .41649 .62126 L .41817 .62027 L F
.686 .145 0 r
.51711 .67933 m .52084 .68209 L .51838 .68035 L F
.434 .863 .746 r
.65063 .44347 m .6509 .44357 L .64881 .44459 L F
.683 .921 .601 r
.65368 .44019 m .6509 .44357 L .65063 .44347 L F
.789 .822 .877 r
.51188 .64118 m .51376 .64275 L .51473 .64039 L F
.952 .747 .59 r
.51188 .64118 m .51321 .64513 L .51376 .64275 L F
.605 .249 .339 r
.54968 .62745 m .54877 .62958 L .54618 .62794 L F
.992 .843 .479 r
.54968 .62745 m .54877 .62958 L .54912 .62727 L F
.76 .727 .822 r
.49264 .66372 m .49426 .6646 L .49105 .66493 L F
.697 .593 .736 r
.49397 .6655 m .4942 .66578 L .49399 .66551 L F
.49373 .66565 m .4942 .66578 L .49397 .6655 L F
.728 .427 .469 r
.49321 .66789 m .4942 .66578 L .49105 .66493 L F
.65 .244 .262 r
.49444 .66597 m .49577 .66732 L .49321 .66789 L F
.106 0 .141 r
.49475 .66548 m .4942 .66578 L .49321 .66789 L F
.65 .244 .262 r
.49399 .66549 m .49577 .66732 L .49397 .6655 L F
.49456 .66514 m .49475 .66548 L .49399 .66549 L F
.491 .527 .821 r
.49399 .66549 m .4942 .66578 L .49475 .66548 L F
.65 .244 .262 r
.49475 .66548 m .49577 .66732 L .49399 .66549 L F
.49426 .6646 m .49456 .66514 L .49397 .6655 L F
.713 .426 .488 r
.49105 .66493 m .49426 .6646 L .49397 .6655 L F
.186 .609 .944 r
.49638 .66458 m .49426 .6646 L .49264 .66372 L F
.49638 .66458 m .49667 .66528 L .49426 .6646 L F
.65 .244 .262 r
.49483 .66502 m .49667 .66528 L .4963 .66611 L F
.49426 .6646 m .4963 .66611 L .49475 .66548 L F
.106 0 .141 r
.49638 .66458 m .49475 .66548 L .49475 .66548 L F
.49459 .66644 m .49475 .66548 L .49321 .66789 L F
.65 .244 .262 r
.49487 .66477 m .49667 .66528 L .49483 .66502 L F
.49475 .66548 m .4963 .66611 L .49577 .66732 L F
.106 0 .141 r
.49638 .66458 m .49475 .66548 L .49459 .66644 L F
.65 .244 .262 r
.49426 .6646 m .49487 .66477 L .49483 .66502 L F
.491 .527 .821 r
.49264 .66372 m .49363 .66503 L .49638 .66458 L F
.49363 .66503 m .49399 .66549 L .4944 .66534 L F
.49363 .66503 m .4944 .66534 L .49638 .66458 L F
.49399 .66549 m .49475 .66548 L .49638 .66458 L F
.65 .244 .262 r
.49397 .6655 m .49444 .66597 L .49321 .66789 L F
.697 .593 .736 r
.49105 .66493 m .49373 .66565 L .49397 .6655 L F
.49105 .66493 m .49399 .66551 L .49264 .66372 L F
.713 .426 .488 r
.49105 .66493 m .49397 .6655 L .49321 .66789 L F
.884 .981 .825 r
.586 .64226 m .58352 .64527 L .5834 .64396 L F
.788 .344 0 r
.47565 .69442 m .47838 .69843 L .47774 .69796 L F
.803 .723 .776 r
.52738 .70907 m .52838 .71214 L .53096 .70891 L F
.264 .442 .85 r
.57401 .63514 m .57565 .63656 L .57285 .63633 L F
.018 .57 .826 r
.57285 .63633 m .57565 .63656 L .57485 .63667 L F
.624 .218 .253 r
.39354 .62497 m .39579 .62668 L .39721 .62468 L F
.41 0 .094 r
.39579 .62668 m .3996 .62458 L .39721 .62468 L F
0 .156 .691 r
.5375 .66476 m .5353 .66275 L .53775 .6622 L F
.72 .421 .472 r
.54412 .68664 m .54726 .68857 L .54726 .68543 L F
.447 .735 .989 r
.64269 .42174 m .64134 .42297 L .63997 .42247 L F
.64269 .42174 m .64378 .42296 L .64134 .42297 L F
.603 .819 .983 r
.64177 .42046 m .64269 .42174 L .63997 .42247 L F
.326 .38 .765 r
.63997 .42247 m .64165 .42377 L .64173 .42163 L F
.63997 .42247 m .64173 .42163 L .64177 .42046 L F
.469 .843 .989 r
.64134 .42297 m .63896 .42295 L .63997 .42247 L F
.63896 .42295 m .63759 .42294 L .63997 .42247 L F
0 0 0 r
.47015 .63014 m .47277 .6269 L .47193 .62907 L F
.204 0 .061 r
.47277 .6269 m .47594 .62483 L .47461 .62647 L F
.029 0 .013 r
.47193 .62907 m .47277 .6269 L .47461 .62647 L F
.631 .148 .088 r
.48686 .70311 m .48986 .70346 L .48799 .70265 L F
.623 .771 .952 r
.65702 .44075 m .65368 .44019 L .65617 .4386 L F
.836 .848 .854 r
.65836 .43831 m .65702 .44075 L .65617 .4386 L F
.442 .186 .429 r
.36486 .60422 m .36205 .60729 L .36244 .6045 L F
.86 .435 .209 r
.4767 .69055 m .47788 .68951 L .47612 .68893 L F
.493 0 0 r
.4767 .69055 m .48105 .69025 L .47788 .68951 L F
.34 0 0 r
.52972 .63661 m .53181 .63671 L .53403 .63628 L F
.393 0 0 r
.53181 .63671 m .53544 .63699 L .53403 .63628 L F
.335 .168 .5 r
.22981 .58857 m .22833 .58664 L .23007 .58645 L F
.22981 .58857 m .228 .58977 L .22833 .58664 L F
.687 .686 .844 r
.79977 .51145 m .79908 .50894 L .79623 .51069 L F
.81 .837 .871 r
.79977 .51145 m .8013 .50751 L .79908 .50894 L F
.79977 .51145 m .80272 .50884 L .8013 .50751 L F
.7 .414 .488 r
.61849 .46776 m .6166 .46993 L .61442 .46756 L F
.735 .515 .593 r
.63577 .4678 m .63606 .47023 L .63234 .47012 L F
.597 .415 .607 r
.63577 .4678 m .63828 .46744 L .63606 .47023 L F
.919 .651 .515 r
.80589 .49116 m .8082 .49359 L .80563 .49271 L F
.852 .832 .827 r
.80563 .49271 m .8082 .49359 L .80548 .4967 L F
0 .092 .606 r
.80589 .49116 m .80825 .49335 L .8082 .49359 L F
.691 .193 .057 r
.80774 .49522 m .8082 .49359 L .80825 .49335 L F
.80774 .49522 m .80995 .49521 L .8082 .49359 L F
0 0 0 r
.19509 .60158 m .19614 .6005 L .19688 .5985 L F
0 0 .261 r
.19547 .60436 m .19614 .6005 L .19509 .60158 L F
.38 0 .046 r
.53585 .64793 m .53477 .6496 L .53231 .64994 L F
.428 0 .071 r
.53693 .64945 m .53585 .64793 L .53829 .64865 L F
.53693 .64945 m .53462 .64984 L .53585 .64793 L F
.663 .496 .648 r
.53423 .64731 m .53676 .64932 L .53684 .64716 L F
.53676 .64932 m .53693 .64945 L .53692 .6493 L F
.53676 .64932 m .53692 .6493 L .53684 .64716 L F
.38 0 .046 r
.53231 .64994 m .53462 .64984 L .5319 .65017 L F
.53477 .6496 m .53462 .64984 L .53231 .64994 L F
.544 .164 .272 r
.47361 .61393 m .47241 .61577 L .47617 .61531 L F
.129 0 .292 r
.53096 .70208 m .52854 .70554 L .52972 .7036 L F
.881 .992 .795 r
.53092 .72377 m .5285 .72565 L .53008 .72334 L F
.277 0 .216 r
.53377 .72394 m .531 .72644 L .53092 .72377 L F
.684 .37 .436 r
.44128 .61891 m .44342 .62128 L .44477 .61894 L F
.639 .317 .41 r
.44477 .61894 m .44683 .62073 L .44723 .61891 L F
.44477 .61894 m .44342 .62128 L .44683 .62073 L F
.837 .696 .707 r
.46007 .61217 m .46158 .61574 L .46387 .61246 L F
.262 0 0 r
.56896 .64781 m .56893 .64799 L .56797 .64774 L F
.744 .223 0 r
.56959 .64816 m .56696 .64615 L .56797 .64774 L F
.633 .114 0 r
.56696 .64615 m .56887 .64828 L .56789 .6476 L F
.56887 .64828 m .56914 .64857 L .56886 .64835 L F
.56887 .64828 m .56886 .64835 L .56789 .6476 L F
.744 .223 0 r
.56959 .64816 m .56914 .64857 L .56696 .64615 L F
.859 .876 .437 r
.56959 .64816 m .56914 .64857 L .56922 .64834 L F
.262 0 0 r
.56993 .64799 m .56959 .64816 L .56893 .64799 L F
.57146 .64799 m .56893 .64799 L .56896 .64781 L F
.859 .876 .437 r
.56959 .64816 m .56922 .64834 L .56998 .64625 L F
.262 0 0 r
.57146 .64799 m .56959 .64816 L .56993 .64799 L F
.675 .335 0 r
.5701 .64468 m .57116 .64734 L .57146 .64799 L F
.705 .985 .867 r
.57116 .64734 m .56959 .64816 L .57146 .64799 L F
.665 .709 .881 r
.57888 .63899 m .58235 .63926 L .58103 .63764 L F
.381 .351 .701 r
.58235 .63926 m .58489 .64125 L .58336 .63837 L F
0 .127 .604 r
.586 .64226 m .58489 .64125 L .58235 .63926 L F
.51 .656 .925 r
.22731 .74973 m .22872 .7496 L .22749 .74995 L F
0 0 0 r
.22729 .75005 m .22872 .7496 L .22749 .74995 L F
.80548 .4967 m .8038 .49949 L .8053 .4979 L F
.80548 .4967 m .8053 .4979 L .80438 .49517 L F
.852 .832 .827 r
.80563 .49271 m .80548 .4967 L .80438 .49517 L F
0 .148 .691 r
.51785 .64502 m .51692 .64503 L .51537 .64477 L F
.51785 .64502 m .51927 .64741 L .51692 .64503 L F
.859 .695 .678 r
.60459 .65054 m .60655 .65127 L .60511 .64787 L F
.549 .057 .04 r
.52363 .63644 m .52569 .63693 L .52746 .63654 L F
.356 0 0 r
.52569 .63693 m .52972 .63661 L .52746 .63654 L F
.866 .948 .866 r
.76465 .49092 m .76626 .48712 L .7658 .48915 L F
.76465 .49092 m .76395 .48991 L .76626 .48712 L F
.624 .951 .934 r
.5245 .69462 m .52581 .69306 L .52693 .69306 L F
0 0 0 r
.5245 .69462 m .52415 .69621 L .52581 .69306 L F
.9 .695 .617 r
.59709 .63857 m .59808 .64132 L .59815 .63953 L F
.782 .677 .748 r
.58079 .6214 m .58301 .62502 L .5809 .62348 L F
.58079 .6214 m .58436 .62188 L .58301 .62502 L F
.723 .193 0 r
.58301 .62502 m .58282 .62601 L .5809 .62348 L F
.58301 .62502 m .58446 .6268 L .58282 .62601 L F
.514 .261 .469 r
.51917 .68428 m .51854 .68841 L .51621 .68871 L F
.363 .254 .594 r
.52084 .68209 m .5213 .68474 L .51917 .68428 L F
.589 .327 .488 r
.52105 .68734 m .51917 .68428 L .5213 .68474 L F
.52105 .68734 m .51854 .68841 L .51917 .68428 L F
.209 .37 .806 r
.54618 .62794 m .54724 .62666 L .5447 .62719 L F
.54618 .62794 m .54877 .62958 L .54724 .62666 L F
.73 .393 .41 r
.54867 .65234 m .552 .65093 L .55 .65044 L F
.54867 .65234 m .55296 .65373 L .552 .65093 L F
0 0 0 r
.41596 .58583 m .41444 .58624 L .41214 .58664 L F
.082 0 0 r
.41844 .5854 m .41444 .58624 L .41596 .58583 L F
.543 .227 .382 r
.54317 .6062 m .54357 .60428 L .54121 .60448 L F
.54121 .60448 m .54357 .60428 L .54317 .6062 L F
0 0 .517 r
.54646 .69337 m .54533 .6913 L .54616 .69066 L F
0 0 0 r
.54647 .68968 m .54616 .69066 L .54533 .6913 L F
.752 .237 0 r
.54604 .69057 m .54535 .69076 L .54616 .69066 L F
.643 .35 .459 r
.54277 .688 m .54321 .68837 L .54366 .68876 L F
.752 .237 0 r
.54366 .68876 m .54581 .69064 L .54604 .69057 L F
.643 .35 .459 r
.54321 .68837 m .54518 .69002 L .54366 .68876 L F
.54277 .688 m .53974 .69047 L .54477 .69006 L F
.752 .237 0 r
.54366 .68876 m .54453 .6898 L .54581 .69064 L F
.643 .35 .459 r
.54453 .6898 m .54477 .69006 L .54518 .69002 L F
0 0 .442 r
.54579 .69179 m .54646 .69337 L .54616 .69066 L F
.54552 .69117 m .54655 .69315 L .54646 .69337 L F
.658 .425 .555 r
.54549 .69073 m .54539 .69092 L .54552 .69117 L F
0 0 .442 r
.54552 .69117 m .54579 .69179 L .54551 .69077 L F
.658 .425 .555 r
.54551 .69077 m .54552 .69117 L .54655 .69315 L F
.54549 .69073 m .54552 .69117 L .54551 .69077 L F
0 0 .442 r
.54551 .69077 m .54579 .69179 L .54611 .69079 L F
.54535 .69076 m .54552 .69117 L .54551 .69077 L F
.658 .425 .555 r
.54508 .69033 m .54378 .69404 L .54549 .69073 L F
0 0 .442 r
.54535 .69076 m .54655 .69315 L .54552 .69117 L F
.658 .425 .555 r
.54539 .69092 m .54378 .69404 L .54655 .69315 L F
.752 .237 0 r
.54472 .69 m .54549 .69073 L .54581 .69064 L F
.658 .425 .555 r
.54518 .69002 m .54508 .69033 L .54549 .69073 L F
.752 .237 0 r
.54453 .6898 m .54472 .69 L .54581 .69064 L F
.54472 .69 m .54542 .69075 L .54549 .69073 L F
.54477 .69006 m .54535 .69076 L .54542 .69075 L F
.643 .35 .459 r
.54277 .688 m .54477 .69006 L .54321 .68837 L F
.752 .237 0 r
.54453 .6898 m .54469 .68998 L .54477 .69006 L F
.656 .423 .554 r
.5399 .693 m .54378 .69404 L .54518 .69002 L F
.752 .237 0 r
.54469 .68998 m .54535 .69076 L .54477 .69006 L F
.656 .423 .554 r
.5399 .693 m .54491 .69018 L .53974 .69047 L F
.54491 .69018 m .54518 .69002 L .54477 .69006 L F
.54491 .69018 m .54477 .69006 L .53974 .69047 L F
.646 .304 .379 r
.54518 .69002 m .54535 .69076 L .54453 .6898 L F
.54518 .69002 m .54453 .6898 L .54366 .68876 L F
.643 .35 .459 r
.54321 .68837 m .54453 .6898 L .54518 .69002 L F
.658 .425 .555 r
.54518 .69002 m .54549 .69073 L .54535 .69076 L F
.54549 .69073 m .54551 .69077 L .54535 .69076 L F
.54551 .69077 m .54655 .69315 L .54535 .69076 L F
0 0 .442 r
.54535 .69076 m .54611 .69079 L .54616 .69066 L F
0 0 0 r
.54726 .68857 m .54616 .69066 L .54647 .68968 L F
.884 .981 .825 r
.586 .64226 m .5834 .64396 L .58489 .64125 L F
.375 0 0 r
.64527 .44184 m .64406 .44328 L .64158 .44346 L F
.55 .499 .751 r
.64704 .44023 m .64527 .44184 L .6444 .43809 L F
.165 0 0 r
.64647 .44257 m .64527 .44184 L .64704 .44023 L F
.64647 .44257 m .64406 .44328 L .64527 .44184 L F
.919 .978 .726 r
.79812 .50248 m .79863 .49878 L .79985 .5016 L F
.607 .365 .524 r
.50991 .67389 m .51349 .67086 L .51026 .6715 L F
.808 .811 .854 r
.57565 .63656 m .57597 .6407 L .57888 .63899 L F
.585 .137 .152 r
.44857 .62506 m .44701 .62683 L .44482 .62622 L F
.663 .23 .208 r
.45062 .62699 m .44701 .62683 L .44857 .62506 L F
.609 .95 .921 r
.55885 .68782 m .55777 .68761 L .55667 .68893 L F
.075 .166 .656 r
.55667 .68893 m .55777 .68761 L .55611 .68565 L F
0 0 0 r
.53854 .72016 m .53734 .72186 L .53598 .72326 L F
.54051 .71813 m .53854 .72016 L .54142 .71764 L F
.54051 .71813 m .53868 .72037 L .53854 .72016 L F
.53868 .72037 m .53734 .72186 L .53854 .72016 L F
.325 .078 .377 r
.47594 .62483 m .47836 .62193 L .47769 .62402 L F
.04 0 0 r
.47594 .62483 m .47671 .62563 L .47461 .62647 L F
.47594 .62483 m .47769 .62402 L .47671 .62563 L F
.556 .568 .822 r
.64729 .42636 m .64854 .42977 L .65084 .42924 L F
.318 .546 .914 r
.64854 .42977 m .65225 .43224 L .65084 .42924 L F
.386 0 0 r
.44252 .62502 m .44114 .62659 L .43879 .6267 L F
.555 .092 .109 r
.44482 .62622 m .44114 .62659 L .44252 .62502 L F
.502 .287 .519 r
.52924 .64752 m .53159 .64765 L .53171 .64472 L F
.55 .524 .78 r
.53171 .64472 m .53324 .6418 L .53098 .64208 L F
.53171 .64472 m .53435 .64419 L .53324 .6418 L F
.519 .316 .545 r
.53159 .64765 m .53435 .64419 L .53171 .64472 L F
.509 .854 .994 r
.41066 .57949 m .41301 .57893 L .41467 .57962 L F
.405 .768 .994 r
.41301 .57893 m .4166 .57962 L .41467 .57962 L F
.765 .642 .726 r
.57882 .6536 m .58232 .65415 L .58132 .65067 L F
.571 .502 .739 r
.58429 .65371 m .58132 .65067 L .58232 .65415 L F
.891 .83 .78 r
.8013 .50751 m .80527 .5047 L .80375 .5046 L F
.8013 .50751 m .80272 .50884 L .80527 .5047 L F
.893 .956 .834 r
.80613 .50168 m .80527 .5047 L .80706 .50282 L F
.526 .823 .999 r
.57693 .60155 m .57921 .60104 L .57777 .60021 L F
.57693 .60155 m .57726 .60103 L .57761 .60159 L F
.895 .865 .802 r
.57761 .60159 m .57777 .60021 L .57615 .59929 L F
0 .516 .758 r
.57693 .60155 m .57761 .60159 L .5728 .60076 L F
.487 .683 .953 r
.5728 .60076 m .57761 .60159 L .57448 .59913 L F
.922 .539 .14 r
.5781 .60255 m .57615 .59928 L .57777 .60021 L F
.895 .865 .802 r
.57615 .59929 m .57777 .60021 L .57615 .59928 L F
.922 .539 .14 r
.57615 .59928 m .57615 .59928 L .57777 .60021 L F
.526 .823 .999 r
.57921 .60104 m .57921 .60104 L .57777 .60021 L F
.57921 .60104 m .57951 .60097 L .57777 .60021 L F
.794 .679 .738 r
.57941 .61556 m .58074 .61901 L .57733 .61878 L F
.585 .366 .55 r
.58074 .61901 m .57835 .62142 L .57733 .61878 L F
.58074 .61901 m .58079 .6214 L .57835 .62142 L F
.79 .64 .696 r
.5832 .61884 m .58079 .6214 L .58074 .61901 L F
0 .282 .746 r
.58332 .60234 m .58542 .60354 L .58396 .6026 L F
.282 0 0 r
.58332 .60234 m .57957 .60307 L .57951 .60097 L F
.58332 .60234 m .58396 .6026 L .57957 .60307 L F
.334 .784 .955 r
.49377 .706 m .49234 .70552 L .48997 .70589 L F
.498 .426 .705 r
.49377 .706 m .49649 .70803 L .49635 .70594 L F
.199 .699 .911 r
.49377 .706 m .49635 .70594 L .49234 .70552 L F
.399 .278 .598 r
.52777 .67094 m .52995 .67259 L .53123 .67175 L F
.274 0 0 r
.52995 .67259 m .53324 .6722 L .53123 .67175 L F
.545 .419 .66 r
.32826 .60125 m .33049 .60081 L .3303 .59817 L F
.432 .316 .621 r
.32878 .60459 m .33049 .60081 L .32826 .60125 L F
.496 .105 .228 r
.5047 .73708 m .50839 .73461 L .50608 .73482 L F
.686 .39 .467 r
.60499 .46795 m .60297 .46974 L .60092 .46717 L F
.60499 .46795 m .6049 .46992 L .60297 .46974 L F
.647 .357 .465 r
.6084 .46947 m .6049 .46992 L .60499 .46795 L F
.591 .629 .857 r
.51631 .69813 m .5183 .6992 L .5186 .69725 L F
.384 .505 .858 r
.36452 .60887 m .3633 .61092 L .36281 .60895 L F
.378 .498 .854 r
.36452 .60887 m .36621 .61194 L .3633 .61092 L F
.531 .155 .274 r
.42843 .62692 m .42682 .62935 L .42493 .62795 L F
.392 0 .081 r
.4306 .62723 m .42682 .62935 L .42843 .62692 L F
0 .07 .624 r
.47163 .68494 m .4718 .68226 L .47038 .68244 L F
.47163 .68494 m .4725 .6846 L .4718 .68226 L F
.47163 .68494 m .47238 .68591 L .4725 .6846 L F
0 0 0 r
.40528 .62124 m .40663 .6208 L .40794 .62006 L F
0 0 .14 r
.40618 .62252 m .40528 .62124 L .4039 .62323 L F
.40618 .62252 m .40663 .6208 L .40528 .62124 L F
.295 0 0 r
.37622 .63997 m .37452 .64118 L .37218 .64134 L F
.245 0 0 r
.378 .64048 m .37452 .64118 L .37622 .63997 L F
.376 0 .103 r
.5327 .67747 m .53178 .67926 L .52935 .67965 L F
.454 .028 .139 r
.53667 .67786 m .5327 .67747 L .535 .67659 L F
.53667 .67786 m .53178 .67926 L .5327 .67747 L F
.923 .944 .794 r
.78543 .48388 m .78763 .48256 L .78666 .48067 L F
.622 .879 .543 r
.78898 .48075 m .78763 .48256 L .7901 .4796 L F
.473 .625 .918 r
.78666 .48067 m .78763 .48256 L .78898 .48075 L F
.548 .296 .486 r
.62703 .47046 m .62988 .47199 L .62647 .47229 L F
.62703 .47046 m .62995 .46977 L .62988 .47199 L F
.533 .352 .581 r
.52924 .64752 m .5319 .65017 L .53159 .64765 L F
.52924 .64752 m .52952 .65075 L .5319 .65017 L F
.054 .42 .866 r
.45741 .69032 m .45872 .69161 L .45877 .69087 L F
.447 .774 .997 r
.45739 .591 m .45734 .59258 L .45546 .59034 L F
.45739 .591 m .45883 .59205 L .45734 .59258 L F
.708 .784 .911 r
.49416 .65625 m .49597 .65735 L .49647 .65578 L F
.57 .395 .605 r
.22401 .59828 m .22169 .60104 L .22168 .59847 L F
.436 .311 .611 r
.21578 .61579 m .216 .61843 L .21414 .61904 L F
.257 .051 .398 r
.216 .61843 m .21401 .62137 L .21414 .61904 L F
0 0 0 r
.50982 .70515 m .51388 .70351 L .51185 .70315 L F
.744 .543 .622 r
.60013 .64189 m .60158 .64502 L .60341 .64203 L F
.466 .824 .996 r
.54235 .69675 m .53876 .69645 L .54019 .69475 L F
.24 .627 .958 r
.37658 .62331 m .3761 .62425 L .37455 .62305 L F
.049 .386 .848 r
.37658 .62331 m .37772 .62508 L .3761 .62425 L F
.261 .737 .937 r
.39289 .58101 m .39531 .58086 L .39674 .58141 L F
.62 .917 .978 r
.39674 .58141 m .39748 .57994 L .39891 .58042 L F
.39674 .58141 m .39531 .58086 L .39748 .57994 L F
.596 .603 .829 r
.77348 .50251 m .77719 .50513 L .77594 .50239 L F
.511 .548 .831 r
.77719 .50513 m .77836 .5015 L .77594 .50239 L F
.77719 .50513 m .77947 .50484 L .77836 .5015 L F
.273 .362 .772 r
.45887 .70303 m .45993 .70692 L .46133 .70504 L F
.239 .313 .739 r
.46133 .70504 m .45993 .70692 L .46231 .70873 L F
0 0 0 r
.48103 .61927 m .47958 .62086 L .47836 .62193 L F
.135 0 .35 r
.47836 .62193 m .47985 .6235 L .47769 .62402 L F
.47836 .62193 m .47958 .62086 L .47985 .6235 L F
.869 .64 .59 r
.46077 .69414 m .46291 .69705 L .4641 .69511 L F
.045 .054 .543 r
.4641 .69511 m .46562 .6964 L .46515 .69386 L F
.202 .113 .525 r
.23718 .56832 m .236 .56915 L .23568 .56648 L F
.829 .813 .327 r
.55849 .67055 m .55881 .67136 L .55847 .67032 L F
.172 0 .102 r
.52086 .6735 m .52435 .67005 L .52317 .67081 L F
.811 .649 .682 r
.48236 .69089 m .48627 .68782 L .48544 .6906 L F
.68 .673 .836 r
.20494 .56556 m .20622 .5677 L .20799 .56636 L F
.692 .381 .443 r
.61442 .46756 m .61094 .46953 L .61051 .46821 L F
.61442 .46756 m .61434 .46946 L .61094 .46953 L F
.726 .41 .444 r
.61442 .46756 m .6166 .46993 L .61434 .46946 L F
.681 .789 .931 r
.42256 .58017 m .4166 .57962 L .41854 .5791 L F
.249 .563 .936 r
.42134 .57781 m .42256 .58017 L .41854 .5791 L F
.42134 .57781 m .42275 .57966 L .42256 .58017 L F
.558 .572 .824 r
.79586 .4794 m .79919 .48279 L .79852 .47908 L F
.493 .395 .673 r
.79919 .48279 m .80039 .47862 L .79852 .47908 L F
.79919 .48279 m .80236 .4817 L .80039 .47862 L F
.5 .415 .692 r
.80211 .48403 m .80236 .4817 L .79919 .48279 L F
.742 .926 .952 r
.56148 .68307 m .56041 .68227 L .55618 .68486 L F
.994 .749 .429 r
.56051 .67964 m .56041 .68227 L .56148 .68307 L F
.716 .812 .924 r
.19719 .57468 m .20135 .57495 L .19939 .57354 L F
.481 .742 .985 r
.20147 .57317 m .20135 .57495 L .19939 .57354 L F
.20147 .57317 m .20324 .57454 L .20135 .57495 L F
.20147 .57317 m .20135 .57495 L .19939 .57354 L F
.20147 .57317 m .20324 .57454 L .20135 .57495 L F
.79 .64 .696 r
.5832 .61884 m .58436 .62188 L .58079 .6214 L F
.72 .749 .875 r
.47627 .61812 m .47505 .61961 L .47381 .61818 L F
.47381 .61818 m .47505 .61961 L .47627 .61812 L F
.524 .681 .937 r
.43215 .58099 m .42999 .58139 L .42878 .57982 L F
.466 0 0 r
.54357 .60428 m .54718 .60462 L .54448 .60514 L F
.527 .314 .533 r
.54357 .60428 m .54617 .60462 L .54651 .60208 L F
.391 .71 .986 r
.54718 .60462 m .54806 .60366 L .54555 .60493 L F
.527 .314 .533 r
.54617 .60462 m .54638 .60465 L .54639 .60451 L F
.54617 .60462 m .54639 .60451 L .54651 .60208 L F
.41 0 0 r
.54357 .60428 m .54617 .60462 L .54448 .60514 L F
.391 .71 .986 r
.54555 .60493 m .54603 .60466 L .54448 .60514 L F
.41 0 0 r
.54617 .60462 m .54638 .60465 L .54448 .60514 L F
.399 .187 .472 r
.54835 .60335 m .54651 .60208 L .54639 .60451 L F
.391 .71 .986 r
.54806 .60366 m .54835 .60335 L .54639 .60451 L F
.399 .187 .472 r
.54835 .60335 m .54639 .60451 L .54638 .60465 L F
.391 .71 .986 r
.54639 .60451 m .54835 .60335 L .54555 .60493 L F
.54603 .60466 m .54835 .60335 L .54448 .60514 L F
.54718 .60462 m .54979 .6047 L .54835 .60335 L F
.589 .605 .836 r
.52436 .64312 m .52519 .64521 L .52277 .64554 L F
.583 .664 .894 r
.52277 .64554 m .52519 .64521 L .52415 .64351 L F
.452 0 .017 r
.57194 .59618 m .57445 .59702 L .57551 .59558 L F
.611 .274 .375 r
.57445 .59702 m .57805 .59495 L .57551 .59558 L F
.286 .74 .956 r
.20276 .54358 m .20502 .54346 L .20662 .54407 L F
.13 .665 .856 r
.20502 .54346 m .20856 .54376 L .20662 .54407 L F
.761 .625 .709 r
.67922 .44433 m .67635 .44416 L .67842 .442 L F
.725 .53 .626 r
.67941 .4467 m .67635 .44416 L .67922 .44433 L F
.559 .498 .743 r
.68084 .44121 m .67922 .44433 L .67842 .442 L F
.68084 .44121 m .6818 .44366 L .67922 .44433 L F
.427 .228 .506 r
.6818 .44366 m .67941 .4467 L .67922 .44433 L F
.375 0 .119 r
.22723 .74984 m .22872 .7496 L .22731 .74973 L F
.233 .019 .37 r
.22825 .59208 m .22617 .59521 L .22637 .59277 L F
0 0 0 r
.48155 .61999 m .48103 .61927 L .48241 .61802 L F
.48155 .61999 m .47958 .62086 L .48103 .61927 L F
.504 .052 .11 r
.43764 .62031 m .43982 .62061 L .44128 .61891 L F
.753 .349 .287 r
.43982 .62061 m .44342 .62128 L .44128 .61891 L F
.45 0 0 r
.55064 .59997 m .55421 .60043 L .55191 .59946 L F
.726 .212 0 r
.55657 .66182 m .55989 .66507 L .56003 .6625 L F
.059 0 0 r
.33772 .63368 m .34047 .63363 L .34135 .6335 L F
.447 .794 .998 r
.34135 .6335 m .34225 .63233 L .33838 .63252 L F
.6 .95 .832 r
.34135 .6335 m .34047 .63363 L .34225 .63233 L F
.216 .018 .383 r
.20607 .63892 m .20557 .64142 L .20382 .64223 L F
.064 0 .333 r
.20557 .64142 m .20371 .64475 L .20382 .64223 L F
.64 .673 .866 r
.43709 .58976 m .43854 .59276 L .44025 .5898 L F
0 0 0 r
.49161 .7136 m .48997 .71391 L .4906 .71383 L F
.984 .701 .37 r
.49195 .71352 m .49236 .71476 L .49161 .7136 L F
.49146 .71203 m .49236 .71476 L .49161 .7136 L F
0 0 0 r
.49161 .7136 m .4906 .71383 L .49321 .71347 L F
.984 .701 .37 r
.49146 .71203 m .49195 .71352 L .49161 .7136 L F
.493 .334 .594 r
.49488 .71647 m .49196 .71735 L .49236 .71476 L F
.856 .863 .845 r
.55028 .63019 m .55054 .6279 L .55225 .62767 L F
.665 .313 .366 r
.55054 .6279 m .55459 .62951 L .55225 .62767 L F
.546 .135 .214 r
.55225 .62767 m .55459 .62951 L .55469 .6278 L F
.341 0 0 r
.35765 .5845 m .35915 .58511 L .36119 .58332 L F
.04 0 0 r
.35915 .58511 m .36309 .5841 L .36119 .58332 L F
.2 0 0 r
.36309 .5841 m .36517 .58442 L .36691 .58408 L F
.174 0 0 r
.36517 .58442 m .36917 .58361 L .36691 .58408 L F
.637 .599 .794 r
.44557 .58601 m .4432 .58665 L .44226 .58344 L F
0 .068 .544 r
.54233 .71384 m .54097 .71271 L .53943 .71432 L F
.302 .374 .771 r
.65225 .43224 m .65285 .42949 L .65084 .42924 L F
.65225 .43224 m .65256 .43243 L .65308 .42994 L F
.65256 .43243 m .65329 .43079 L .65308 .42994 L F
.65225 .43224 m .65308 .42994 L .65285 .42949 L F
.855 .737 .732 r
.65291 .42924 m .65388 .43321 L .65356 .43043 L F
0 .183 .717 r
.65291 .42924 m .65356 .43043 L .65374 .42894 L F
.945 .625 .398 r
.6536 .43008 m .65202 .43164 L .65374 .42894 L F
.65356 .43043 m .65339 .43056 L .6536 .43008 L F
.65339 .43056 m .65202 .43164 L .6536 .43008 L F
.302 .374 .771 r
.65256 .43243 m .65388 .43321 L .65329 .43079 L F
.65285 .42949 m .65308 .42994 L .65291 .42924 L F
.822 .419 .285 r
.65225 .43224 m .65598 .43522 L .6546 .43442 L F
.46 .337 .625 r
.65225 .43224 m .6546 .43442 L .65388 .43321 L F
.945 .625 .398 r
.65339 .43056 m .65359 .43353 L .65202 .43164 L F
.65349 .43048 m .6535 .4308 L .65339 .43056 L F
.6535 .4308 m .65359 .43353 L .65339 .43056 L F
.65356 .43043 m .65356 .43058 L .65349 .43048 L F
.65356 .43058 m .65359 .43353 L .65349 .43048 L F
.302 .374 .771 r
.65285 .42949 m .65291 .42924 L .6527 .42924 L F
.65285 .42949 m .6527 .42924 L .65084 .42924 L F
.861 .705 .688 r
.53417 .6948 m .53416 .69756 L .53287 .69503 L F
.179 .358 .806 r
.53287 .69503 m .53416 .69756 L .53519 .69622 L F
.486 .796 .999 r
.53416 .69756 m .53654 .69721 L .53519 .69622 L F
.488 .631 .916 r
.77338 .50117 m .77348 .50251 L .77483 .50064 L F
.459 .589 .896 r
.77348 .50251 m .77594 .50239 L .77483 .50064 L F
.17 .706 .819 r
.39891 .58042 m .40117 .58019 L .40258 .58025 L F
0 .568 .719 r
.40258 .58025 m .40117 .58019 L .40481 .58031 L F
0 0 0 r
.50329 .70926 m .50489 .70855 L .506 .70684 L F
.296 .324 .721 r
.50329 .70926 m .50576 .7117 L .50489 .70855 L F
.895 .97 .823 r
.19944 .59048 m .19726 .59164 L .19943 .58871 L F
.901 .696 .615 r
.19944 .59048 m .1991 .59514 L .19726 .59164 L F
.826 .678 .699 r
.57522 .62348 m .5729 .6246 L .57467 .62123 L F
.336 .062 .341 r
.57522 .62348 m .5728 .62718 L .5729 .6246 L F
.57522 .62348 m .57507 .62469 L .5728 .62718 L F
.699 .515 .635 r
.5729 .6246 m .57493 .62486 L .57467 .62123 L F
.57493 .62486 m .57557 .62494 L .57541 .62428 L F
.369 .088 .35 r
.57522 .62348 m .57592 .62368 L .57507 .62469 L F
.376 .049 .277 r
.57835 .62142 m .57745 .62411 L .57627 .62378 L F
.577 .62231 m .57627 .62378 L .57522 .62348 L F
.57835 .62142 m .57627 .62378 L .577 .62231 L F
.849 .934 .881 r
.57485 .62646 m .5754 .62541 L .57557 .62494 L F
.254 0 .174 r
.5728 .62718 m .57485 .62646 L .57557 .62494 L F
.369 .088 .35 r
.57567 .62454 m .5758 .62467 L .57485 .62646 L F
.5758 .62467 m .57628 .62516 L .57485 .62646 L F
.849 .934 .881 r
.57485 .62646 m .57526 .62583 L .5754 .62541 L F
.369 .088 .35 r
.57567 .62454 m .57745 .62411 L .57628 .62516 L F
.154 .199 .657 r
.57557 .62494 m .57561 .62449 L .57541 .62428 L F
.699 .515 .635 r
.57493 .62486 m .57541 .62428 L .57507 .62469 L F
.369 .088 .35 r
.57592 .62368 m .57745 .62411 L .5757 .62453 L F
.57536 .62434 m .5757 .62453 L .57507 .62469 L F
.57592 .62368 m .5757 .62453 L .57536 .62434 L F
.154 .199 .657 r
.57561 .62449 m .57705 .62303 L .576 .62015 L F
.57557 .62494 m .57583 .62461 L .57561 .62449 L F
.57583 .62461 m .57705 .62303 L .57561 .62449 L F
.849 .934 .881 r
.57526 .62583 m .57705 .62303 L .57591 .62451 L F
.57526 .62583 m .57591 .62451 L .57557 .62494 L F
.154 .199 .657 r
.57541 .62428 m .576 .62015 L .57467 .62123 L F
.57561 .62449 m .576 .62015 L .57541 .62428 L F
.254 0 .174 r
.5728 .62718 m .57557 .62494 L .57493 .62486 L F
.336 .062 .341 r
.57493 .62486 m .57485 .62646 L .57327 .62701 L F
.57507 .62469 m .57507 .62472 L .57493 .62486 L F
.57507 .62472 m .57485 .62646 L .57493 .62486 L F
.57507 .62469 m .57327 .62701 L .5728 .62718 L F
.254 0 .174 r
.5728 .62718 m .57493 .62486 L .57492 .62486 L F
.57281 .62694 m .57492 .62486 L .5729 .6246 L F
.5728 .62718 m .57492 .62486 L .57281 .62694 L F
.369 .088 .35 r
.57507 .62472 m .57567 .62454 L .57485 .62646 L F
.57507 .62469 m .57511 .62468 L .57507 .62472 L F
.57511 .62468 m .57567 .62454 L .57507 .62472 L F
.699 .515 .635 r
.57507 .62469 m .57541 .62428 L .5754 .62425 L F
.57493 .62486 m .5754 .62425 L .57467 .62123 L F
.436 .12 .33 r
.64674 .4668 m .64706 .46519 L .64988 .464 L F
.334 0 0 r
.64881 .44459 m .64546 .44592 L .64844 .44599 L F
0 0 .003 r
.65063 .44347 m .64881 .44459 L .64844 .44599 L F
.184 .488 .9 r
.55388 .63298 m .55391 .63217 L .55028 .63019 L F
0 .22 .742 r
.55388 .63298 m .55451 .63221 L .55391 .63217 L F
.088 .456 .885 r
.55388 .63298 m .55568 .63375 L .55451 .63221 L F
.456 .675 .958 r
.22637 .54688 m .22579 .54869 L .22436 .5471 L F
.22637 .54688 m .22783 .54853 L .22579 .54869 L F
.738 .819 .915 r
.60762 .45804 m .60421 .4603 L .60479 .45747 L F
.663 .468 .611 r
.60092 .46717 m .59902 .47002 L .59898 .46756 L F
.356 0 0 r
.52569 .63693 m .52848 .63748 L .52972 .63661 L F
.508 0 0 r
.52848 .63748 m .53181 .63671 L .52972 .63661 L F
0 0 .283 r
.53169 .66175 m .53027 .66589 L .53272 .66592 L F
.641 .68 .871 r
.48401 .70803 m .48525 .7097 L .48788 .70874 L F
.958 .68 .467 r
.48807 .71111 m .48788 .70874 L .48525 .7097 L F
.582 .821 .44 r
.46376 .68008 m .46229 .682 L .46136 .68329 L F
.434 .742 .992 r
.46136 .68329 m .46229 .682 L .45984 .68209 L F
.682 .37 .44 r
.44683 .62073 m .44933 .62136 L .44723 .61891 L F
.128 0 .031 r
.56928 .59847 m .57194 .59618 L .56973 .59566 L F
.746 .486 .537 r
.49234 .70552 m .49638 .70319 L .49246 .7029 L F
.49234 .70552 m .49635 .70594 L .49638 .70319 L F
.573 .53 .769 r
.45819 .61305 m .46158 .61574 L .46007 .61217 L F
.309 .045 .341 r
.65427 .46312 m .65236 .46164 L .65473 .46097 L F
.65427 .46312 m .65209 .46322 L .65236 .46164 L F
.771 .785 .864 r
.59797 .65939 m .60139 .65943 L .60036 .65873 L F
.41 .276 .586 r
.2219 .60599 m .21976 .60974 L .21983 .60733 L F
.528 .157 .279 r
.42493 .62795 m .42682 .62935 L .42428 .62931 L F
0 0 .261 r
.19547 .60436 m .19616 .60294 L .19614 .6005 L F
.151 .029 .447 r
.19535 .60685 m .19542 .6068 L .19545 .6052 L F
0 0 .469 r
.19542 .6068 m .19547 .60436 L .19545 .6052 L F
.19542 .6068 m .19616 .60294 L .19547 .60436 L F
.354 .419 .791 r
.54262 .65904 m .5415 .65991 L .54003 .65728 L F
.502 .237 .445 r
.54338 .66147 m .5415 .65991 L .54262 .65904 L F
.54338 .66147 m .54072 .66207 L .5415 .65991 L F
.887 .497 .286 r
.52581 .64042 m .52807 .64062 L .52848 .63748 L F
.52581 .64042 m .52726 .64123 L .52807 .64062 L F
.697 .165 0 r
.52581 .64042 m .52807 .64062 L .52726 .64123 L F
.471 .093 .24 r
.52971 .64179 m .52743 .6445 L .52734 .64279 L F
.52971 .64179 m .52734 .64279 L .52805 .64141 L F
0 0 .059 r
.52857 .6404 m .52843 .64291 L .53035 .63956 L F
.52807 .64062 m .52816 .64119 L .52857 .6404 L F
.52816 .64119 m .52843 .64291 L .52857 .6404 L F
.471 .093 .24 r
.52805 .64141 m .52734 .64279 L .52726 .64123 L F
.53098 .64208 m .53079 .64222 L .52971 .64179 L F
.53079 .64222 m .52743 .6445 L .52971 .64179 L F
.561 .46 .697 r
.52726 .64123 m .52519 .64521 L .52436 .64312 L F
.52726 .64123 m .52743 .6445 L .52519 .64521 L F
.66 .503 .66 r
.52349 .64069 m .52726 .64123 L .52581 .64042 L F
.52349 .64069 m .52436 .64312 L .52726 .64123 L F
.196 .051 .445 r
.52415 .64351 m .52726 .64123 L .52436 .64312 L F
.52415 .64351 m .52581 .64042 L .52726 .64123 L F
.697 .165 0 r
.52581 .64042 m .52843 .64291 L .52816 .64119 L F
.52632 .64046 m .52816 .64119 L .52807 .64062 L F
.52581 .64042 m .52816 .64119 L .52632 .64046 L F
.054 .175 .674 r
.52807 .64062 m .53035 .63956 L .52848 .63748 L F
.577 .512 .746 r
.22729 .75005 m .22872 .7496 L .22723 .74984 L F
.933 .829 .719 r
.49833 .70793 m .50145 .70636 L .49841 .70594 L F
.49833 .70793 m .49988 .70889 L .50145 .70636 L F
0 .199 .717 r
.4666 .72043 m .46737 .7196 L .46528 .71743 L F
.424 0 0 r
.4689 .72099 m .47029 .72178 L .4666 .72043 L F
.31 0 .251 r
.47113 .72022 m .47029 .72178 L .4689 .72099 L F
.146 .464 .89 r
.4666 .72043 m .47029 .72178 L .46737 .7196 L F
.549 .275 .452 r
.37304 .59851 m .3726 .60039 L .37052 .60049 L F
.392 .016 .201 r
.37559 .59863 m .3726 .60039 L .37304 .59851 L F
.067 0 .063 r
.52363 .63644 m .5248 .63733 L .52569 .63693 L F
.52363 .63644 m .52278 .63882 L .5248 .63733 L F
.683 .622 .781 r
.57223 .65018 m .57304 .65178 L .57521 .65073 L F
.867 .98 .686 r
.54175 .71598 m .54051 .71813 L .54142 .71764 L F
.053 0 .42 r
.36675 .6155 m .36682 .6183 L .3658 .61827 L F
.298 0 0 r
.41642 .6306 m .41491 .63217 L .41259 .63251 L F
.484 .072 .183 r
.41866 .63011 m .41491 .63217 L .41642 .6306 L F
.471 .335 .613 r
.23133 .57823 m .23177 .58058 L .22978 .58104 L F
.432 .316 .621 r
.32878 .60459 m .33064 .60407 L .33049 .60081 L F
.463 .417 .721 r
.32878 .60459 m .33138 .6064 L .33064 .60407 L F
.436 .419 .742 r
.32878 .60459 m .3301 .6071 L .33138 .6064 L F
.265 0 0 r
.39049 .63725 m .38864 .63828 L .38643 .63835 L F
.247 0 0 r
.39231 .63752 m .38864 .63828 L .39049 .63725 L F
.548 .127 .194 r
.53736 .68905 m .53803 .69062 L .53518 .68884 L F
.326 .285 .658 r
.22169 .60104 m .22367 .60311 L .22142 .60365 L F
.342 .185 .518 r
.22367 .60311 m .2219 .60599 L .22142 .60365 L F
.907 .745 .67 r
.59399 .62923 m .59513 .63044 L .59396 .62713 L F
.964 .798 .628 r
.59311 .63239 m .59513 .63044 L .59399 .62923 L F
.59311 .63239 m .59488 .63346 L .59513 .63044 L F
.963 .754 .574 r
.45745 .68754 m .459 .68837 L .4594 .68588 L F
.674 .653 .822 r
.79623 .51069 m .79757 .50661 L .79531 .50776 L F
.79623 .51069 m .79908 .50894 L .79757 .50661 L F
.622 .879 .543 r
.78898 .48075 m .78696 .47984 L .78666 .48067 L F
.78898 .48075 m .78807 .47916 L .78696 .47984 L F
.419 .764 .996 r
.53963 .65659 m .54003 .65728 L .53725 .65695 L F
0 .303 .785 r
.54199 .65807 m .54003 .65728 L .53963 .65659 L F
.54199 .65807 m .54262 .65904 L .54003 .65728 L F
.574 .297 .458 r
.50489 .70855 m .50802 .7058 L .506 .70684 L F
.682 .691 .852 r
.67732 .44006 m .67842 .442 L .67489 .44113 L F
.846 .785 .792 r
.67842 .442 m .67496 .44343 L .67489 .44113 L F
.67842 .442 m .67635 .44416 L .67496 .44343 L F
.611 .659 .872 r
.68084 .44121 m .67842 .442 L .67732 .44006 L F
.16 .688 .865 r
.34786 .63326 m .34719 .63319 L .34752 .63365 L F
.071 .249 .74 r
.44699 .59218 m .44825 .59537 L .449 .59394 L F
.411 .685 .974 r
.44825 .59537 m .45035 .59534 L .449 .59394 L F
.7 .431 .515 r
.58079 .6214 m .57745 .62411 L .57835 .62142 L F
.188 0 .343 r
.20957 .57466 m .21151 .57167 L .20981 .57241 L F
.635 .659 .856 r
.5733 .6376 m .57597 .6407 L .57581 .63863 L F
.5733 .6376 m .57581 .63863 L .57374 .63741 L F
.57374 .63741 m .57581 .63863 L .57565 .63656 L F
.603 .754 .95 r
.57322 .63745 m .5733 .6376 L .57374 .63741 L F
.57359 .63732 m .57374 .63741 L .57565 .63656 L F
.57322 .63745 m .57374 .63741 L .57359 .63732 L F
.699 .499 .614 r
.57565 .63656 m .57322 .63745 L .5722 .63652 L F
.603 .754 .95 r
.57294 .63693 m .57565 .63656 L .5722 .63652 L F
0 .146 .69 r
.57293 .63693 m .57308 .63701 L .5724 .63661 L F
.699 .499 .614 r
.57565 .63656 m .57623 .64021 L .57322 .63745 L F
0 .146 .69 r
.5722 .63652 m .57322 .63745 L .57308 .63701 L F
.603 .754 .95 r
.57103 .63719 m .57298 .63754 L .57359 .63732 L F
.57294 .63693 m .57359 .63732 L .57565 .63656 L F
.57103 .63719 m .57359 .63732 L .57294 .63693 L F
0 .146 .69 r
.57248 .63665 m .57363 .63731 L .57285 .63682 L F
.5724 .63661 m .57269 .63677 L .57248 .63665 L F
.57269 .63677 m .57363 .63731 L .57248 .63665 L F
.57308 .63701 m .57547 .63834 L .57269 .63677 L F
.57308 .63701 m .57269 .63677 L .5724 .63661 L F
.57308 .63701 m .57623 .64021 L .57547 .63834 L F
.57322 .63745 m .57623 .64021 L .57308 .63701 L F
.603 .754 .95 r
.57298 .63754 m .57326 .6376 L .57322 .63745 L F
.57326 .6376 m .5733 .6376 L .57322 .63745 L F
.57103 .63719 m .57294 .63693 L .5722 .63652 L F
0 .146 .69 r
.57363 .63731 m .57547 .63834 L .57464 .63786 L F
.57363 .63731 m .57464 .63786 L .57285 .63682 L F
.5722 .63652 m .57293 .63693 L .5724 .63661 L F
.237 .753 .831 r
.38235 .62534 m .38177 .62579 L .38023 .62527 L F
.38235 .62534 m .384 .62538 L .38177 .62579 L F
0 0 0 r
.48511 .71752 m .48532 .71675 L .48591 .71456 L F
.803 .522 .513 r
.50187 .6826 m .49948 .68441 L .49714 .68421 L F
.50187 .6826 m .50187 .68519 L .49948 .68441 L F
.917 .953 .801 r
.51381 .70806 m .5125 .71179 L .51204 .70931 L F
.109 .488 .9 r
.36091 .63831 m .36131 .63738 L .35849 .6367 L F
.36091 .63831 m .36255 .6388 L .36131 .63738 L F
.44 .22 .482 r
.53963 .65659 m .53725 .65695 L .53713 .65908 L F
.407 .06 .261 r
.49153 .68547 m .49406 .6852 L .49476 .68308 L F
0 .533 .732 r
.45964 .67959 m .46376 .68008 L .46372 .67748 L F
.45964 .67959 m .46198 .67984 L .46376 .68008 L F
.899 .573 .42 r
.46198 .67984 m .46229 .682 L .46376 .68008 L F
.46198 .67984 m .46229 .682 L .46376 .68008 L F
.262 .198 .595 r
.44835 .58549 m .4469 .5897 L .44557 .58601 L F
.44835 .58549 m .44842 .58996 L .4469 .5897 L F
.149 .415 .858 r
.4469 .5897 m .44823 .58908 L .44543 .58946 L F
.4469 .5897 m .44842 .58996 L .44823 .58908 L F
.864 .697 .17 r
.54705 .6876 m .54726 .68857 L .54726 .68543 L F
.54705 .6876 m .54726 .68543 L .54827 .68462 L F
.636 .768 .943 r
.51074 .73388 m .51199 .73526 L .50839 .73461 L F
.608 .084 0 r
.50839 .73461 m .51199 .73526 L .51007 .73594 L F
.631 .767 .944 r
.51485 .73451 m .51199 .73526 L .51074 .73388 L F
0 0 0 r
.51007 .73594 m .51199 .73526 L .51485 .73451 L F
.155 0 0 r
.38191 .63902 m .38019 .64012 L .378 .64048 L F
.184 0 0 r
.38191 .63902 m .3826 .63947 L .38019 .64012 L F
.38191 .63902 m .38443 .63913 L .3826 .63947 L F
.487 .319 .578 r
.1978 .58833 m .19955 .58526 L .19731 .58685 L F
.452 .013 .113 r
.64045 .44019 m .64319 .44006 L .6444 .43809 L F
.55 .499 .751 r
.64704 .44023 m .6444 .43809 L .64629 .43759 L F
.156 0 0 r
.6444 .43809 m .64563 .43904 L .64629 .43759 L F
.6444 .43809 m .64319 .44006 L .64563 .43904 L F
.752 .383 0 r
.36361 .64096 m .36403 .64197 L .36255 .6388 L F
.377 0 .092 r
.40486 .63412 m .40418 .63518 L .40201 .63542 L F
.25 0 0 r
.40803 .63299 m .40418 .63518 L .40486 .63412 L F
.663 .468 .611 r
.60092 .46717 m .60297 .46974 L .59902 .47002 L F
.333 0 0 r
.46522 .62274 m .4628 .62203 L .46131 .62317 L F
0 0 0 r
.40982 .5868 m .40847 .58859 L .40671 .58948 L F
.108 0 0 r
.41055 .58777 m .40982 .5868 L .41214 .58664 L F
.41055 .58777 m .40847 .58859 L .40982 .5868 L F
.494 .509 .801 r
.4971 .69711 m .49815 .70043 L .4997 .6983 L F
.39 .367 .713 r
.49815 .70043 m .50046 .70212 L .4997 .6983 L F
.283 0 .009 r
.49948 .69663 m .50304 .69433 L .49947 .69443 L F
.49948 .69663 m .5018 .69624 L .50304 .69433 L F
.566 .526 .77 r
.50304 .69433 m .50545 .69411 L .50639 .69093 L F
.581 .141 .169 r
.50304 .69433 m .50485 .696 L .50545 .69411 L F
.50304 .69433 m .5018 .69624 L .50485 .696 L F
.636 .371 .501 r
.53976 .67374 m .5373 .67792 L .535 .67659 L F
.521 .239 .428 r
.54029 .67451 m .53976 .67374 L .54108 .67372 L F
.54029 .67451 m .5373 .67792 L .53976 .67374 L F
.455 .309 .593 r
.50586 .67552 m .50749 .67621 L .50723 .67395 L F
.526 .244 .429 r
.50431 .67925 m .50749 .67621 L .50586 .67552 L F
.589 .051 0 r
.4866 .69324 m .4856 .69309 L .48405 .6921 L F
.611 .088 0 r
.48463 .69353 m .4856 .69314 L .4855 .69308 L F
.589 .051 0 r
.48555 .69306 m .48438 .69291 L .48406 .69213 L F
.4855 .69308 m .48438 .69291 L .48555 .69306 L F
.4856 .69309 m .48406 .69213 L .48405 .6921 L F
.611 .088 0 r
.48463 .69353 m .4855 .69308 L .48236 .69089 L F
.589 .051 0 r
.4856 .69309 m .4855 .69308 L .48555 .69306 L F
.535 .397 .639 r
.48867 .6892 m .48899 .69157 L .49111 .69061 L F
.48627 .68782 m .49111 .69061 L .48833 .68736 L F
.56 .927 .777 r
.49153 .68547 m .48833 .68736 L .48966 .68625 L F
.753 .396 .377 r
.48833 .68736 m .49111 .69061 L .48981 .69033 L F
.48841 .6873 m .48981 .69033 L .48966 .68625 L F
.48833 .68736 m .48845 .6876 L .48841 .6873 L F
.48845 .6876 m .48981 .69033 L .48841 .6873 L F
.535 .397 .639 r
.48627 .68782 m .4856 .69309 L .48899 .69157 L F
.48627 .68782 m .48899 .69157 L .48867 .6892 L F
.4856 .69309 m .4856 .69314 L .48565 .69312 L F
.4856 .69309 m .48565 .69312 L .49111 .69061 L F
.811 .649 .682 r
.48236 .69089 m .4855 .69308 L .48627 .68782 L F
.4855 .69308 m .4856 .69314 L .4856 .69309 L F
.4855 .69308 m .4856 .69309 L .48627 .68782 L F
.589 .051 0 r
.48749 .69364 m .48614 .69388 L .48463 .69353 L F
.611 .088 0 r
.48463 .69353 m .48614 .69388 L .4858 .69341 L F
.48463 .69353 m .4858 .69341 L .4856 .69314 L F
.589 .051 0 r
.4863 .69336 m .48463 .69353 L .48438 .69291 L F
.48749 .69364 m .48588 .69358 L .4863 .69336 L F
.48588 .69358 m .4858 .69341 L .4863 .69336 L F
.48749 .69364 m .48438 .69291 L .4866 .69324 L F
.538 .336 .554 r
.48614 .69388 m .49111 .69061 L .48565 .69312 L F
.4858 .69341 m .48565 .69312 L .4856 .69314 L F
.48614 .69388 m .48565 .69312 L .4858 .69341 L F
.589 .051 0 r
.48588 .69358 m .48463 .69353 L .4858 .69341 L F
.357 0 .073 r
.34071 .59001 m .3424 .59071 L .34271 .59007 L F
.34071 .59001 m .33956 .59171 L .3424 .59071 L F
0 .126 .665 r
.47058 .71421 m .47174 .71744 L .47042 .71529 L F
.514 .732 .972 r
.42807 .57852 m .4267 .58011 L .425 .57899 L F
.42807 .57852 m .42878 .57982 L .4267 .58011 L F
.141 0 0 r
.47038 .68244 m .4718 .68226 L .47295 .68146 L F
.595 .15 .163 r
.47295 .68146 m .4718 .68226 L .47546 .68229 L F
.319 .409 .797 r
.45313 .62083 m .45446 .62426 L .45299 .62247 L F
.991 .815 .568 r
.59116 .62038 m .59273 .61888 L .59134 .61795 L F
.59116 .62038 m .59206 .62146 L .59273 .61888 L F
.741 .32 .249 r
.47307 .67609 m .47483 .67666 L .47455 .67567 L F
.47455 .67567 m .47483 .67666 L .47307 .67609 L F
0 .174 .698 r
.66168 .43398 m .66207 .43492 L .65983 .43225 L F
0 0 .333 r
.6628 .43624 m .66207 .43492 L .66168 .43398 L F
.6628 .43624 m .66349 .43828 L .66207 .43492 L F
.771 .594 .659 r
.42645 .62213 m .43004 .62051 L .42833 .61841 L F
.43004 .62051 m .43076 .62019 L .42956 .61931 L F
.43004 .62051 m .42956 .61931 L .42833 .61841 L F
.635 .08 0 r
.42956 .61931 m .4294 .61829 L .42935 .61822 L F
.42964 .61975 m .42957 .61935 L .42956 .61931 L F
.42957 .61935 m .4294 .61829 L .42956 .61931 L F
.647 .098 0 r
.42833 .61841 m .42956 .61931 L .42964 .61975 L F
.462 0 0 r
.43134 .61989 m .43196 .61949 L .43034 .61967 L F
.759 .435 .437 r
.43346 .62189 m .432 .62004 L .43036 .62188 L F
.462 0 0 r
.43239 .6197 m .43196 .61949 L .43134 .61989 L F
.759 .435 .437 r
.432 .62004 m .43158 .6195 L .43138 .61988 L F
.432 .62004 m .43138 .61988 L .43036 .62188 L F
.462 0 0 r
.43392 .62047 m .43239 .6197 L .43138 .61988 L F
.432 .62004 m .43138 .61988 L .43134 .61989 L F
.43392 .62047 m .43138 .61988 L .432 .62004 L F
.994 .866 .588 r
.43036 .62188 m .43138 .61988 L .43076 .62019 L F
.43138 .61988 m .43158 .6195 L .43105 .61994 L F
.43138 .61988 m .43105 .61994 L .43076 .62019 L F
.759 .435 .437 r
.432 .62004 m .43392 .62047 L .43158 .6195 L F
.43346 .62189 m .43392 .62047 L .432 .62004 L F
.647 .098 0 r
.43009 .6197 m .43076 .62019 L .42964 .61975 L F
.779 .359 .25 r
.43076 .62019 m .43105 .61994 L .42964 .61975 L F
.462 0 0 r
.43242 .62013 m .43034 .61967 L .42964 .61975 L F
.779 .359 .25 r
.43105 .61994 m .43158 .6195 L .42964 .61975 L F
.462 0 0 r
.43392 .62047 m .43242 .62013 L .42964 .61975 L F
.43196 .61949 m .43177 .61939 L .42964 .61975 L F
.635 .08 0 r
.42964 .61975 m .43177 .61939 L .4294 .61829 L F
.647 .098 0 r
.42956 .61931 m .43009 .6197 L .42964 .61975 L F
.635 .08 0 r
.42964 .61975 m .42935 .61822 L .42873 .61731 L F
.265 .089 .446 r
.236 .56915 m .2353 .57159 L .2343 .57147 L F
.099 0 .293 r
.2353 .57159 m .23382 .57422 L .2343 .57147 L F
.043 .611 .761 r
.28248 .70004 m .28532 .70005 L .28575 .70013 L F
.28575 .70013 m .28532 .70005 L .28248 .70004 L F
0 0 .576 r
.56339 .64073 m .56411 .64249 L .56332 .63937 L F
.364 .513 .873 r
.56332 .63937 m .56411 .64249 L .56548 .64074 L F
.236 0 0 r
.2389 .55644 m .24106 .55735 L .24188 .55627 L F
.898 .667 .155 r
.24188 .55627 m .24116 .55497 L .245 .55693 L F
.24188 .55627 m .24106 .55735 L .24116 .55497 L F
.375 .432 .792 r
.77947 .50484 m .78054 .50856 L .7822 .50643 L F
.514 .632 .905 r
.78054 .50856 m .78355 .50857 L .7822 .50643 L F
.641 .535 .719 r
.33027 .62033 m .32934 .62076 L .33174 .61844 L F
.58 .394 .594 r
.49907 .66247 m .49927 .66523 L .49667 .66528 L F
.49907 .66247 m .49927 .66523 L .49667 .66528 L F
.243 .324 .748 r
.79524 .49795 m .79341 .50013 L .79302 .49916 L F
.647 .938 .687 r
.50907 .69465 m .50726 .69566 L .50626 .6972 L F
.658 .208 .172 r
.51144 .69463 m .50726 .69566 L .50907 .69465 L F
.398 .844 .925 r
.34411 .62623 m .34229 .62719 L .3446 .62673 L F
.34411 .62623 m .34175 .62683 L .34229 .62719 L F
.924 .962 .65 r
.34431 .62515 m .34411 .62623 L .3446 .62673 L F
.591 .767 .963 r
.33912 .62573 m .34175 .62683 L .34411 .62623 L F
.33912 .62573 m .34411 .62623 L .34276 .62357 L F
.195 .297 .741 r
.34276 .62357 m .34369 .62539 L .34431 .62515 L F
.34369 .62539 m .34411 .62623 L .34431 .62515 L F
.928 .948 .61 r
.3446 .62673 m .34308 .6282 L .34431 .62515 L F
0 0 0 r
.34431 .62515 m .34352 .62704 L .34581 .62454 L F
.34431 .62515 m .34581 .62454 L .34606 .62427 L F
.928 .948 .61 r
.34308 .6282 m .34295 .62832 L .34304 .62812 L F
.34308 .6282 m .34304 .62812 L .34431 .62515 L F
0 0 .265 r
.34442 .6301 m .34602 .63025 L .34396 .62959 L F
.34719 .63319 m .34602 .63025 L .34442 .6301 L F
.745 .412 .419 r
.34602 .63025 m .35025 .63164 L .34859 .63046 L F
.294 .755 .949 r
.34859 .63046 m .34762 .63041 L .34602 .63025 L F
0 0 .433 r
.34449 .63051 m .34396 .62959 L .34371 .62927 L F
.34449 .63051 m .3435 .62893 L .34387 .62958 L F
0 .112 .63 r
.34449 .63051 m .34719 .63319 L .34396 .62959 L F
0 0 .265 r
.34719 .63319 m .34694 .63256 L .34616 .63061 L F
.34625 .63083 m .34616 .63061 L .34602 .63025 L F
.34719 .63319 m .34616 .63061 L .34625 .63083 L F
.294 .755 .949 r
.34859 .63046 m .34708 .62988 L .34591 .62999 L F
.745 .412 .419 r
.34602 .63025 m .34694 .63256 L .35025 .63164 L F
.294 .755 .949 r
.34762 .63041 m .34369 .63021 L .34602 .63025 L F
.459 0 0 r
.34396 .62959 m .34602 .63025 L .34445 .63022 L F
.294 .755 .949 r
.34605 .63033 m .34591 .62999 L .34369 .63021 L F
.34859 .63046 m .34591 .62999 L .34605 .63033 L F
.459 0 0 r
.34396 .62959 m .34445 .63022 L .34369 .63021 L F
0 0 .433 r
.34371 .62927 m .34396 .62959 L .3435 .62893 L F
.34387 .62958 m .3435 .62893 L .34229 .62719 L F
.876 .45 .039 r
.65598 .43522 m .65556 .43589 L .6546 .43442 L F
.65598 .43522 m .65689 .43703 L .65556 .43589 L F
.876 .439 .13 r
.65598 .43522 m .65836 .43831 L .65689 .43703 L F
.696 .162 0 r
.62749 .43054 m .62593 .4308 L .62761 .43112 L F
.62761 .43112 m .62593 .4308 L .62749 .43054 L F
.079 0 0 r
.51225 .66044 m .51022 .65963 L .51095 .65932 L F
.634 .147 .078 r
.51356 .65992 m .51225 .66044 L .51095 .65932 L F
0 0 0 r
.50982 .70515 m .51184 .7046 L .51388 .70351 L F
.657 .163 .065 r
.51184 .7046 m .51601 .70515 L .51388 .70351 L F
.652 .41 .541 r
.51349 .67086 m .51582 .67331 L .51595 .67135 L F
.112 0 0 r
.66755 .45213 m .66542 .45387 L .66551 .45293 L F
.303 .377 .773 r
.48391 .61457 m .4819 .6154 L .48144 .6128 L F
.152 0 .404 r
.48241 .61802 m .4819 .6154 L .48391 .61457 L F
.658 .718 .893 r
.42742 .58677 m .4315 .58839 L .4299 .58611 L F
.538 .626 .887 r
.4315 .58839 m .43219 .58555 L .4299 .58611 L F
.4315 .58839 m .43374 .5882 L .43219 .58555 L F
.927 .844 .398 r
.49577 .66732 m .49667 .66528 L .49638 .66458 L F
0 0 0 r
.384 .62538 m .38633 .62527 L .38784 .62512 L F
.52 0 0 r
.38835 .62649 m .38784 .62512 L .38633 .62527 L F
.38835 .62649 m .38976 .62621 L .38784 .62512 L F
.16 .688 .865 r
.34786 .63326 m .34694 .63256 L .34719 .63319 L F
.489 .903 .875 r
.35025 .63164 m .34786 .63326 L .35228 .63246 L F
.35025 .63164 m .34694 .63256 L .34786 .63326 L F
.401 0 0 r
.45821 .63076 m .46158 .6307 L .46021 .63151 L F
.647 .119 0 r
.46021 .63151 m .46158 .6307 L .46391 .6324 L F
.958 .68 .467 r
.59309 .63486 m .59488 .63346 L .59311 .63239 L F
.59309 .63486 m .59506 .6361 L .59488 .63346 L F
.865 .603 .54 r
.59488 .63346 m .59506 .6361 L .59663 .63623 L F
.571 .501 .738 r
.58132 .65067 m .58301 .6479 L .58103 .64863 L F
.58132 .65067 m .584 .6501 L .58301 .6479 L F
.571 .502 .739 r
.58429 .65371 m .584 .6501 L .58132 .65067 L F
.318 .297 .678 r
.54338 .66147 m .54224 .66538 L .54104 .66405 L F
.54338 .66147 m .5445 .66626 L .54224 .66538 L F
.578 .076 0 r
.54224 .66538 m .54372 .6672 L .54104 .66405 L F
.54224 .66538 m .54411 .66745 L .54372 .6672 L F
.729 .399 .423 r
.54104 .66405 m .54372 .6672 L .53948 .66649 L F
.859 .935 .558 r
.54384 .66562 m .54318 .66685 L .54372 .6672 L F
.324 0 0 r
.54183 .66847 m .54467 .66807 L .54182 .66799 L F
.449 .207 .455 r
.54076 .66754 m .53845 .67027 L .541 .66749 L F
.53658 .66841 m .53793 .66975 L .54076 .66754 L F
.53793 .66975 m .53845 .67027 L .54076 .66754 L F
.53658 .66841 m .53642 .67097 L .53845 .67027 L F
.135 .332 .795 r
.53915 .6683 m .53845 .67027 L .53705 .66656 L F
0 0 .482 r
.53705 .66656 m .53845 .67027 L .53829 .66937 L F
.488 .849 .6 r
.53689 .67057 m .53492 .67205 L .53829 .66937 L F
.53642 .67097 m .53586 .67137 L .53689 .67057 L F
.045 0 0 r
.53256 .67269 m .53492 .67205 L .53642 .67097 L F
.488 .849 .6 r
.53586 .67137 m .53492 .67205 L .53689 .67057 L F
.769 .52 .559 r
.541 .66749 m .54183 .66847 L .54182 .66799 L F
.541 .66749 m .53845 .67027 L .54183 .66847 L F
.336 0 0 r
.54372 .6672 m .53961 .66819 L .53948 .66649 L F
.53961 .66819 m .53915 .6683 L .53924 .66777 L F
.53961 .66819 m .53924 .66777 L .53948 .66649 L F
.148 0 0 r
.54081 .6704 m .53838 .67095 L .53845 .67027 L F
.002 0 0 r
.53845 .67027 m .53838 .67095 L .5395 .67014 L F
.53845 .67027 m .5395 .67014 L .54183 .66847 L F
.348 0 0 r
.54183 .66847 m .5395 .67014 L .54342 .66964 L F
.5395 .67014 m .53838 .67095 L .54054 .67038 L F
.5395 .67014 m .54054 .67038 L .54342 .66964 L F
.148 0 0 r
.5405 .67001 m .5395 .67014 L .53915 .6683 L F
.5395 .67014 m .53845 .67027 L .53857 .66992 L F
.5395 .67014 m .53857 .66992 L .53915 .6683 L F
.54081 .6704 m .53845 .67027 L .5405 .67001 L F
.336 0 0 r
.54372 .6672 m .54227 .66853 L .54004 .66836 L F
.53961 .66819 m .54004 .66836 L .53915 .6683 L F
.54372 .6672 m .54004 .66836 L .53961 .66819 L F
.15 0 0 r
.54081 .6704 m .54342 .66964 L .53838 .67095 L F
.54081 .6704 m .54183 .67059 L .54342 .66964 L F
.01 .216 .726 r
.54101 .66876 m .54183 .67059 L .54165 .67056 L F
.324 0 0 r
.54183 .66847 m .54342 .66964 L .54467 .66807 L F
.859 .935 .558 r
.54318 .66685 m .54227 .66853 L .54372 .6672 L F
.747 .562 .645 r
.54065 .66498 m .54227 .66853 L .54384 .66562 L F
.578 .076 0 r
.54411 .66745 m .54467 .66807 L .54372 .6672 L F
.635 .883 .987 r
.54372 .6672 m .54467 .66807 L .5469 .66725 L F
.473 .196 .411 r
.54467 .66807 m .54674 .66926 L .5469 .66725 L F
.635 .883 .987 r
.54372 .6672 m .5469 .66725 L .54645 .66584 L F
.772 .592 .655 r
.54674 .6618 m .5445 .66626 L .54338 .66147 L F
.859 .935 .558 r
.54384 .66562 m .54372 .6672 L .54645 .66584 L F
.544 .076 .092 r
.54467 .66807 m .54342 .66964 L .54674 .66926 L F
.589 .15 .175 r
.54342 .66964 m .54545 .67098 L .54674 .66926 L F
.277 .421 .826 r
.54556 .66963 m .54684 .66715 L .54384 .66562 L F
0 .092 .649 r
.54384 .66562 m .54514 .66865 L .54531 .66812 L F
.54514 .66865 m .54556 .66963 L .54531 .66812 L F
.736 .548 .639 r
.54227 .66853 m .54531 .66812 L .54384 .66562 L F
.502 .446 .727 r
.53949 .66754 m .54227 .66853 L .54176 .66741 L F
.53949 .66754 m .54176 .66741 L .53982 .66681 L F
.54004 .66836 m .54227 .66853 L .53949 .66754 L F
.776 .687 .765 r
.54531 .66812 m .54183 .67059 L .54049 .66734 L F
.54531 .66812 m .54264 .66768 L .54383 .66805 L F
.566 .182 .273 r
.54299 .66802 m .54499 .66757 L .54531 .66812 L F
.377 .403 .76 r
.54531 .66812 m .54684 .66715 L .54384 .66562 L F
.566 .182 .273 r
.54499 .66757 m .54552 .66745 L .54531 .66812 L F
.54552 .66745 m .54684 .66715 L .54531 .66812 L F
.552 .204 .332 r
.54556 .66963 m .54545 .67098 L .54342 .66964 L F
.54556 .66963 m .54342 .66964 L .54183 .67059 L F
.54556 .66963 m .54183 .67059 L .54531 .66812 L F
.645 .668 .857 r
.54684 .66715 m .54581 .66998 L .54556 .66963 L F
.54581 .66998 m .54545 .67098 L .54554 .66982 L F
.54581 .66998 m .54554 .66982 L .54556 .66963 L F
.631 .441 .608 r
.54329 .67111 m .54321 .67411 L .54108 .67372 L F
.397 .379 .722 r
.54777 .66565 m .55036 .66726 L .54874 .66779 L F
.846 .665 .657 r
.54674 .66926 m .55036 .66726 L .5469 .66725 L F
.516 .858 .994 r
.54545 .67098 m .54692 .67153 L .54674 .66926 L F
.645 .668 .857 r
.54684 .66715 m .54786 .6705 L .54545 .67098 L F
.753 .953 .642 r
.54414 .67087 m .54245 .67324 L .54205 .67154 L F
.54414 .67087 m .54205 .67154 L .54183 .67059 L F
.516 .858 .994 r
.54545 .67098 m .54786 .6705 L .54692 .67153 L F
.577 .483 .712 r
.54431 .67242 m .5466 .67007 L .54414 .67087 L F
.746 .983 .908 r
.54617 .67021 m .54609 .67025 L .54414 .67087 L F
.508 .403 .671 r
.54245 .67324 m .54414 .67087 L .54183 .67059 L F
.753 .953 .642 r
.54414 .67087 m .54291 .67177 L .54245 .67324 L F
.508 .403 .671 r
.54245 .67324 m .54431 .67242 L .54414 .67087 L F
.746 .983 .908 r
.54609 .67025 m .54291 .67177 L .54414 .67087 L F
.5466 .67007 m .54623 .67024 L .54617 .67021 L F
.54623 .67024 m .54291 .67177 L .54617 .67021 L F
.511 .711 .962 r
.54531 .66812 m .54684 .66715 L .54556 .66963 L F
.533 .255 .44 r
.54183 .67059 m .54414 .67087 L .54531 .66812 L F
.566 .182 .273 r
.54299 .66802 m .54588 .66965 L .54613 .669 L F
.776 .687 .765 r
.54264 .66768 m .54049 .66734 L .54383 .66805 L F
.566 .182 .273 r
.54299 .66802 m .54613 .669 L .54684 .66715 L F
.776 .687 .765 r
.54383 .66805 m .54156 .66757 L .54299 .66802 L F
.54156 .66757 m .54049 .66734 L .54299 .66802 L F
.502 .446 .727 r
.53982 .66681 m .54176 .66741 L .54065 .66498 L F
.53915 .6683 m .54004 .66836 L .53949 .66754 L F
.01 .216 .726 r
.54049 .66734 m .54165 .67056 L .54095 .66974 L F
.54071 .66937 m .54095 .66974 L .54072 .66947 L F
.54049 .66734 m .54095 .66974 L .54071 .66937 L F
.54049 .66734 m .54109 .6688 L .54101 .66876 L F
.54109 .6688 m .54183 .67059 L .54101 .66876 L F
.54072 .66947 m .54165 .67056 L .54081 .6704 L F
.752 .425 .431 r
.80423 .48376 m .80649 .48215 L .80424 .48134 L F
.80423 .48376 m .80678 .484 L .80649 .48215 L F
.471 .093 .24 r
.53098 .64208 m .53045 .64456 L .52743 .6445 L F
.146 0 .148 r
.532 .64346 m .53098 .64208 L .53324 .6418 L F
.532 .64346 m .53045 .64456 L .53098 .64208 L F
.498 0 0 r
.58772 .60208 m .58881 .60117 L .58599 .60111 L F
.764 .271 .053 r
.58772 .60208 m .59107 .60351 L .58881 .60117 L F
.648 .367 .479 r
.59107 .60351 m .59094 .60132 L .58881 .60117 L F
0 .059 .618 r
.4643 .71554 m .46528 .71743 L .46414 .71404 L F
0 0 0 r
.576 .62015 m .57733 .61878 L .57467 .62123 L F
.495 .236 .45 r
.50856 .6551 m .50629 .65394 L .50832 .6535 L F
.553 .093 .114 r
.5048 .65568 m .50629 .65394 L .50856 .6551 L F
.99 .779 .524 r
.80413 .48813 m .80334 .48985 L .80308 .48758 L F
.80413 .48813 m .80327 .48968 L .80334 .48985 L F
.877 .941 .855 r
.80413 .48813 m .80678 .484 L .80652 .48729 L F
.901 .799 .738 r
.80331 .48952 m .8041 .48573 L .80308 .48758 L F
.80334 .48985 m .8034 .48955 L .80331 .48952 L F
.8034 .48955 m .8041 .48573 L .80331 .48952 L F
.186 0 .08 r
.80413 .48813 m .80652 .48729 L .80343 .48956 L F
.80335 .48954 m .8034 .48955 L .80327 .48968 L F
.901 .799 .738 r
.8034 .48955 m .80327 .48968 L .8041 .48573 L F
.80334 .48985 m .80327 .48968 L .8034 .48955 L F
.186 0 .08 r
.8034 .48955 m .80343 .48956 L .80327 .48968 L F
.80413 .48813 m .80343 .48956 L .80335 .48954 L F
.785 .558 .593 r
.60011 .64464 m .60013 .64189 L .59808 .64132 L F
.60011 .64464 m .60158 .64502 L .60013 .64189 L F
.249 .044 .393 r
.20952 .63007 m .20873 .63302 L .20749 .63343 L F
.277 .153 .526 r
.20892 .63473 m .20749 .63343 L .20873 .63302 L F
.20892 .63473 m .20754 .63585 L .20749 .63343 L F
.816 .569 .566 r
.59506 .6361 m .59709 .63857 L .59663 .63623 L F
.188 .513 .914 r
.20376 .55691 m .20393 .55566 L .20153 .5561 L F
.20376 .55691 m .20502 .55713 L .20393 .55566 L F
.125 0 0 r
.51608 .65964 m .51225 .66044 L .51356 .65992 L F
.985 .719 .343 r
.57008 .63716 m .57103 .63719 L .5722 .63652 L F
.57008 .63716 m .5722 .63652 L .57285 .63682 L F
0 .085 .57 r
.54606 .64543 m .54826 .64729 L .54929 .64827 L F
.711 .311 0 r
.54826 .64729 m .55 .65044 L .54929 .64827 L F
.842 .894 .875 r
.80613 .50168 m .80706 .50282 L .80875 .50135 L F
.80613 .50168 m .80875 .50135 L .8086 .49868 L F
.875 .871 .83 r
.80875 .50135 m .80987 .49987 L .8086 .49868 L F
.618 .802 .97 r
.4824 .73828 m .47856 .73776 L .4809 .73482 L F
.433 0 0 r
.4824 .73828 m .48065 .73858 L .47856 .73776 L F
.112 .289 .764 r
.4809 .73482 m .48335 .73716 L .4824 .73828 L F
.582 .945 .859 r
.48335 .73716 m .48065 .73858 L .4824 .73828 L F
.856 .863 .845 r
.55028 .63019 m .54877 .62958 L .55054 .6279 L F
.746 .267 .106 r
.55391 .63217 m .54877 .62958 L .55028 .63019 L F
.724 .283 .204 r
.55781 .59842 m .55976 .59939 L .56029 .59754 L F
.56061 .60071 m .56051 .60073 L .55656 .59992 L F
.791 .536 .552 r
.55656 .59992 m .56068 .60076 L .55932 .60142 L F
0 0 0 r
.5594 .60099 m .55932 .60142 L .55971 .60092 L F
.55977 .59905 m .55934 .60216 L .55933 .60197 L F
.5594 .60099 m .55933 .60197 L .55932 .60142 L F
.724 .283 .204 r
.55949 .59979 m .56061 .60071 L .55944 .60048 L F
0 0 0 r
.55977 .59905 m .5594 .60099 L .56147 .59863 L F
.55977 .59905 m .55933 .60197 L .5594 .60099 L F
.724 .283 .204 r
.55781 .59842 m .55949 .59979 L .55656 .59992 L F
.55949 .59979 m .55944 .60048 L .55656 .59992 L F
.56061 .60071 m .56068 .60076 L .56051 .60073 L F
0 0 0 r
.5594 .60099 m .55971 .60092 L .56147 .59863 L F
.724 .283 .204 r
.55781 .59842 m .55656 .59992 L .55976 .59939 L F
.283 .628 .962 r
.22224 .54545 m .22198 .54673 L .2203 .5455 L F
.22224 .54545 m .22436 .5471 L .22198 .54673 L F
.214 .627 .953 r
.35336 .63508 m .35228 .63246 L .3527 .63351 L F
.349 .823 .885 r
.39852 .59174 m .39991 .59109 L .3977 .59164 L F
.39852 .59174 m .40072 .59109 L .39991 .59109 L F
.581 .134 .154 r
.38976 .62621 m .39215 .6267 L .39354 .62497 L F
.637 .199 .191 r
.39215 .6267 m .39579 .62668 L .39354 .62497 L F
.683 .921 .601 r
.65368 .44019 m .65063 .44347 L .65273 .44235 L F
.65368 .44019 m .65273 .44235 L .6527 .43992 L F
.357 .819 .921 r
.65368 .44019 m .65493 .43938 L .65617 .4386 L F
.65368 .44019 m .6527 .43992 L .65493 .43938 L F
.723 .669 .797 r
.80337 .50208 m .80116 .50431 L .79985 .5016 L F
.898 .984 .793 r
.78729 .50533 m .78628 .50819 L .78868 .50653 L F
.353 .591 .935 r
.78868 .50653 m .79042 .50524 L .78729 .50533 L F
.415 .831 .969 r
.18135 .54244 m .18346 .54195 L .18518 .54227 L F
.268 0 0 r
.18346 .54195 m .18724 .54283 L .18518 .54227 L F
.393 0 0 r
.53181 .63671 m .53442 .63758 L .53544 .63699 L F
0 .346 .742 r
.53544 .63699 m .53802 .63813 L .53932 .63897 L F
.491 0 0 r
.53442 .63758 m .53802 .63813 L .53544 .63699 L F
.437 0 0 r
.19269 .55343 m .18791 .55302 L .18998 .55313 L F
.709 .967 .937 r
.51023 .64683 m .51321 .64513 L .5116 .64612 L F
.572 .823 .993 r
.42189 .58733 m .4252 .58764 L .42402 .58593 L F
.629 .689 .887 r
.42402 .58593 m .4252 .58764 L .42742 .58677 L F
0 0 0 r
.20695 .56135 m .20469 .56349 L .20607 .56238 L F
.20695 .56135 m .20809 .56114 L .20913 .56088 L F
.20695 .56135 m .20607 .56238 L .20809 .56114 L F
.345 0 .073 r
.51023 .64683 m .50709 .64947 L .5095 .64945 L F
.099 0 0 r
.51219 .64574 m .51321 .64513 L .51023 .64683 L F
.339 0 .224 r
.51178 .64889 m .51023 .64683 L .5095 .64945 L F
.51178 .64889 m .51219 .64574 L .51023 .64683 L F
.483 .321 .585 r
.21401 .62137 m .21399 .62417 L .21186 .6243 L F
.17 0 .29 r
.21399 .62417 m .21128 .62694 L .21186 .6243 L F
.291 .322 .721 r
.47136 .68849 m .47197 .69163 L .47348 .69119 L F
.339 .533 .898 r
.47197 .69163 m .47565 .69328 L .47348 .69119 L F
.173 .475 .894 r
.47197 .69163 m .47565 .69442 L .47565 .69328 L F
.108 .608 .901 r
.35697 .63609 m .35532 .63533 L .35336 .63508 L F
.35697 .63609 m .35532 .63533 L .35336 .63508 L F
0 .411 .844 r
.35697 .63609 m .35722 .63541 L .35532 .63533 L F
.35697 .63609 m .35849 .6367 L .35722 .63541 L F
.641 .58 .77 r
.46946 .70923 m .46674 .70826 L .4686 .70581 L F
.622 .553 .755 r
.4686 .70581 m .46674 .70826 L .46567 .70657 L F
.413 0 .034 r
.34905 .58681 m .35075 .58765 L .35141 .58651 L F
.34905 .58681 m .3459 .58952 L .35075 .58765 L F
.85 .522 0 r
.33543 .62475 m .33623 .62741 L .33495 .6239 L F
.935 .74 .615 r
.59107 .60351 m .59218 .60675 L .5928 .60429 L F
.462 .127 .312 r
.38967 .5927 m .38916 .59431 L .38684 .59476 L F
.434 .101 .301 r
.3915 .59373 m .38916 .59431 L .38967 .5927 L F
.524 .123 .223 r
.39308 .5922 m .38967 .5927 L .39079 .5925 L F
.39308 .5922 m .39204 .59278 L .38967 .5927 L F
.483 .03 .099 r
.39204 .59278 m .3915 .59373 L .38967 .5927 L F
.277 0 0 r
.41136 .62092 m .40794 .62006 L .41017 .62039 L F
.392 0 0 r
.40663 .6208 m .41017 .62039 L .40794 .62006 L F
.736 .663 .778 r
.78684 .51056 m .78796 .51399 L .79094 .5115 L F
.687 .976 .904 r
.77794 .48384 m .77575 .48532 L .77531 .48483 L F
.607 .365 .524 r
.50991 .67389 m .51249 .67394 L .51349 .67086 L F
.652 .41 .541 r
.51349 .67086 m .51249 .67394 L .51582 .67331 L F
.805 .653 .694 r
.62761 .43112 m .63137 .43368 L .62936 .42911 L F
.842 .401 .174 r
.62761 .43112 m .62942 .43372 L .63137 .43368 L F
.275 .177 .558 r
.20469 .56349 m .20619 .56533 L .20607 .56238 L F
.219 .164 .579 r
.20494 .56556 m .20619 .56533 L .20469 .56349 L F
.17 0 .29 r
.21399 .62417 m .21341 .62622 L .21128 .62694 L F
.342 .2 .539 r
.21341 .62622 m .21113 .62921 L .21128 .62694 L F
.128 0 .031 r
.56928 .59847 m .57191 .59732 L .57194 .59618 L F
.454 0 .043 r
.57191 .59732 m .57445 .59702 L .57194 .59618 L F
.63 .592 .793 r
.46734 .70244 m .46567 .70657 L .46539 .70263 L F
.46734 .70244 m .4686 .70581 L .46567 .70657 L F
.849 .389 .025 r
.55618 .68486 m .55777 .68761 L .55885 .68782 L F
.479 0 0 r
.66799 .44474 m .66715 .44397 L .66835 .44204 L F
0 .033 .596 r
.47565 .69328 m .47565 .69442 L .4762 .69327 L F
0 .119 .661 r
.47565 .69442 m .47727 .69519 L .4762 .69327 L F
.47565 .69442 m .47774 .69796 L .47727 .69519 L F
.62 .198 .219 r
.55469 .6278 m .55693 .62943 L .55847 .62694 L F
.266 0 .145 r
.55847 .62694 m .55934 .62859 L .5599 .62742 L F
.55847 .62694 m .55693 .62943 L .55934 .62859 L F
.988 .838 .462 r
.58464 .60981 m .58438 .60557 L .58527 .60746 L F
.531 .577 .846 r
.76665 .49893 m .76766 .49528 L .76573 .49545 L F
.76665 .49893 m .76889 .49849 L .76766 .49528 L F
.277 0 .216 r
.53377 .72394 m .53302 .72564 L .531 .72644 L F
.308 0 .232 r
.53377 .72394 m .53598 .72326 L .53302 .72564 L F
.614 .647 .859 r
.53916 .62391 m .54007 .62063 L .53778 .6235 L F
.53916 .62391 m .54149 .62385 L .54007 .62063 L F
.685 .21 .116 r
.34034 .62849 m .33843 .62924 L .33623 .62741 L F
.407 0 .084 r
.34229 .62719 m .33843 .62924 L .34034 .62849 L F
.758 .641 .732 r
.52303 .67486 m .52086 .6735 L .5237 .67415 L F
.52583 .67662 m .52166 .67647 L .52086 .6735 L F
.217 .354 .788 r
.52095 .67706 m .52287 .67465 L .52043 .6775 L F
.52166 .67647 m .52201 .67593 L .52095 .67706 L F
.52201 .67593 m .52287 .67465 L .52095 .67706 L F
.758 .641 .732 r
.52583 .67662 m .52303 .67486 L .52655 .6748 L F
.52303 .67486 m .5237 .67415 L .52655 .6748 L F
.567 .618 .863 r
.52647 .67062 m .52822 .67372 L .52655 .6748 L F
.293 .003 .289 r
.52775 .67585 m .52655 .6748 L .52822 .67372 L F
.52775 .67585 m .52583 .67662 L .52655 .6748 L F
.322 .109 .427 r
.21125 .63175 m .20952 .63007 L .21113 .62921 L F
.21125 .63175 m .20873 .63302 L .20952 .63007 L F
.217 .288 .723 r
.50726 .69566 m .50668 .6999 L .50626 .6972 L F
.475 .816 .999 r
.51665 .73189 m .51898 .73147 L .52028 .73225 L F
.51665 .73189 m .51898 .73147 L .52028 .73225 L F
.609 .451 .643 r
.50502 .6624 m .5078 .66256 L .50783 .65991 L F
.579 .255 .384 r
.50721 .66404 m .5078 .66256 L .50502 .6624 L F
.609 .451 .643 r
.50783 .65991 m .5078 .66256 L .50502 .6624 L F
.579 .255 .384 r
.50502 .6624 m .5078 .66256 L .50721 .66404 L F
.718 .495 .586 r
.48946 .71176 m .49161 .7136 L .49146 .71203 L F
0 0 0 r
.49161 .7136 m .49339 .71087 L .49146 .71203 L F
.656 .329 .407 r
.52693 .69306 m .52932 .69403 L .52965 .69189 L F
.808 .709 .756 r
.52932 .69403 m .53261 .69134 L .52965 .69189 L F
.118 0 0 r
.18724 .54283 m .18945 .54272 L .19096 .54234 L F
.195 .724 .825 r
.18945 .54272 m .19316 .54246 L .19096 .54234 L F
0 0 0 r
.47929 .69774 m .47708 .69928 L .4781 .69876 L F
.151 .467 .891 r
.47708 .69928 m .47937 .70042 L .4781 .69876 L F
.735 .653 .768 r
.58768 .66316 m .58962 .66185 L .58619 .66152 L F
.714 .893 .512 r
.47526 .66539 m .47249 .66965 L .47375 .66717 L F
.998 .777 .446 r
.47489 .66941 m .47249 .66965 L .4727 .66969 L F
.47489 .66941 m .47375 .66717 L .47249 .66965 L F
.306 0 .141 r
.20533 .58286 m .20711 .58296 L .20828 .58096 L F
.411 .029 .199 r
.20828 .58096 m .20915 .58252 L .20994 .58012 L F
.20828 .58096 m .20711 .58296 L .20915 .58252 L F
.789 .62 .672 r
.48686 .70311 m .48997 .70589 L .48986 .70346 L F
.48686 .70311 m .48643 .70556 L .48997 .70589 L F
.787 .644 .703 r
.48643 .70556 m .48788 .70874 L .48997 .70589 L F
.455 .272 .542 r
.48997 .70589 m .49246 .7029 L .48986 .70346 L F
.48997 .70589 m .49234 .70552 L .49246 .7029 L F
.616 .467 .657 r
.48174 .69683 m .47899 .69492 L .48168 .69583 L F
.48174 .69683 m .47929 .69774 L .47899 .69492 L F
.687 .287 .283 r
.78031 .48206 m .78273 .48335 L .78396 .48193 L F
.782 .624 .685 r
.78273 .48335 m .78666 .48067 L .78396 .48193 L F
.484 .453 .748 r
.33046 .61248 m .33175 .61012 L .3297 .61047 L F
.33046 .61248 m .33243 .61223 L .33175 .61012 L F
.427 .475 .807 r
.33046 .61248 m .33338 .61543 L .33243 .61223 L F
.963 .89 .708 r
.49196 .71735 m .48892 .71968 L .49058 .72076 L F
.344 0 0 r
.49334 .71888 m .49196 .71735 L .49488 .71647 L F
.49334 .71888 m .48892 .71968 L .49196 .71735 L F
.848 .428 .233 r
.48807 .71111 m .49161 .7136 L .48946 .71176 L F
.493 .404 .684 r
.3297 .61047 m .33138 .6064 L .3301 .6071 L F
.821 .88 .887 r
.62312 .43597 m .62391 .43275 L .62582 .43297 L F
.62312 .43597 m .62163 .43486 L .62391 .43275 L F
.902 .866 .794 r
.62312 .43597 m .62188 .4374 L .62163 .43486 L F
.814 .737 .779 r
.55589 .67609 m .55378 .67417 L .55659 .67432 L F
.55589 .67609 m .55292 .67689 L .55378 .67417 L F
.812 .713 .756 r
.55589 .67609 m .55373 .67999 L .55292 .67689 L F
.888 .706 .192 r
.55902 .67612 m .55659 .67432 L .55589 .67609 L F
0 0 0 r
.46796 .63105 m .46839 .6312 L .46647 .63228 L F
.46796 .63105 m .47015 .63014 L .46839 .6312 L F
.515 .358 .606 r
.49697 .65397 m .49903 .65054 L .49651 .65083 L F
.912 .691 .59 r
.67635 .44416 m .67629 .44667 L .67496 .44343 L F
.725 .53 .626 r
.67941 .4467 m .67629 .44667 L .67635 .44416 L F
.117 .271 .747 r
.47772 .68436 m .47672 .68566 L .47546 .68229 L F
0 0 0 r
.47555 .68775 m .47672 .68566 L .47772 .68436 L F
.641 .356 .47 r
.6187 .47027 m .61687 .47265 L .6166 .46993 L F
.6187 .47027 m .6206 .47215 L .61687 .47265 L F
.711 .333 .332 r
.6187 .47027 m .62231 .47156 L .6206 .47215 L F
.749 .686 .79 r
.43457 .59342 m .43553 .59514 L .43259 .59519 L F
.568 .09 .08 r
.43259 .59519 m .43553 .59514 L .43476 .59614 L F
.342 .483 .856 r
.43457 .59342 m .4372 .59435 L .43553 .59514 L F
0 0 0 r
.43553 .59514 m .4372 .59435 L .43476 .59614 L F
.599 .418 .608 r
.63828 .46744 m .64027 .47139 L .63606 .47023 L F
.866 .68 .649 r
.6407 .4668 m .64027 .47139 L .63828 .46744 L F
.898 .984 .793 r
.78729 .50533 m .78588 .50738 L .78628 .50819 L F
.814 .517 0 r
.78588 .50738 m .78684 .51056 L .78628 .50819 L F
.554 .334 .536 r
.50172 .64786 m .50385 .64984 L .5048 .64785 L F
.531 .182 .32 r
.50385 .64984 m .50709 .64947 L .5048 .64785 L F
.611 .474 .67 r
.5728 .62718 m .5729 .6246 L .57012 .62744 L F
.516 .281 .497 r
.5728 .62718 m .57014 .6299 L .57012 .62744 L F
0 0 .409 r
.57012 .62744 m .57159 .62804 L .5728 .62718 L F
.57012 .62744 m .57014 .6299 L .57159 .62804 L F
.611 .474 .67 r
.5728 .62718 m .5729 .6246 L .57012 .62744 L F
.503 .307 .547 r
.62391 .43275 m .62761 .43112 L .62582 .43297 L F
0 0 .039 r
.59274 .60912 m .59258 .61222 L .59285 .61043 L F
.727 .577 .686 r
.50677 .65542 m .50974 .65662 L .50761 .65734 L F
.692 .535 .669 r
.50783 .65991 m .51022 .65963 L .50974 .65662 L F
.50783 .65991 m .51022 .65963 L .50974 .65662 L F
.244 .22 .631 r
.50974 .65662 m .51181 .65874 L .51223 .65657 L F
.50974 .65662 m .51022 .65963 L .51181 .65874 L F
.582 .544 .777 r
.63301 .42951 m .63415 .42522 L .63201 .42641 L F
.63301 .42951 m .63542 .42889 L .63415 .42522 L F
.917 .953 .801 r
.51381 .70806 m .5117 .71115 L .5125 .71179 L F
.219 .682 .945 r
.19316 .54246 m .19521 .54256 L .19694 .54333 L F
.247 .72 .94 r
.19521 .54256 m .19908 .54309 L .19694 .54333 L F
.286 0 0 r
.39615 .63617 m .39461 .63739 L .39231 .63752 L F
.409 0 0 r
.39615 .63617 m .39693 .63755 L .39461 .63739 L F
.39615 .63617 m .39852 .63629 L .39693 .63755 L F
.709 .186 0 r
.50724 .71179 m .50789 .71326 L .50576 .7117 L F
.50724 .71179 m .50937 .71417 L .50789 .71326 L F
.838 .37 .041 r
.53932 .63897 m .54121 .64211 L .54258 .64243 L F
.788 .299 0 r
.54236 .64333 m .54258 .64243 L .54121 .64211 L F
.54236 .64333 m .54377 .64423 L .54258 .64243 L F
0 0 0 r
.37719 .58242 m .37951 .58184 L .38107 .58106 L F
.459 0 .023 r
.37951 .58184 m .38333 .58062 L .38107 .58106 L F
.466 0 0 r
.54357 .60428 m .54448 .60514 L .54317 .6062 L F
.928 .78 .306 r
.54297 .60521 m .54357 .60428 L .54317 .6062 L F
.41 0 0 r
.54357 .60428 m .54448 .60514 L .54317 .6062 L F
.838 .678 .684 r
.55515 .67135 m .55659 .67432 L .55378 .67417 L F
.895 .935 .561 r
.55474 .6722 m .55403 .6726 L .55515 .67135 L F
.55378 .67417 m .55403 .6726 L .55474 .6722 L F
0 0 .441 r
.55401 .67728 m .5545 .67543 L .55403 .6726 L F
.275 .269 .67 r
.55292 .67689 m .55403 .6726 L .55378 .67417 L F
.216 .316 .752 r
.55373 .67999 m .55392 .67979 L .55393 .67756 L F
.55392 .67979 m .55523 .67844 L .55419 .67774 L F
.55392 .67979 m .55419 .67774 L .55393 .67756 L F
.327 .309 .685 r
.55377 .67839 m .55523 .67844 L .55292 .67689 L F
0 0 .441 r
.554 .67857 m .5545 .67545 L .55401 .67728 L F
.554 .6788 m .55402 .67863 L .554 .67857 L F
.55402 .67863 m .5545 .67545 L .554 .67857 L F
0 0 .21 r
.55484 .68064 m .55523 .67844 L .55373 .67999 L F
.605 .586 .805 r
.55484 .68064 m .55481 .68057 L .55523 .67844 L F
.55481 .68057 m .55377 .67839 L .55393 .6784 L F
.275 .269 .67 r
.55292 .67689 m .55385 .67854 L .55403 .6726 L F
.55385 .67854 m .554 .6788 L .554 .67857 L F
.55385 .67854 m .554 .67857 L .55403 .6726 L F
.605 .586 .805 r
.55516 .67881 m .55393 .6784 L .55523 .67844 L F
.55481 .68057 m .554 .67857 L .55516 .67881 L F
.554 .67857 m .55393 .6784 L .55516 .67881 L F
.81 .775 .268 r
.55397 .6776 m .5545 .67543 L .554 .6788 L F
.5545 .67543 m .5545 .67543 L .5545 .67545 L F
.5545 .67543 m .5545 .67545 L .554 .6788 L F
.982 .691 .352 r
.5545 .67543 m .55355 .67286 L .55403 .6726 L F
.114 .539 .916 r
.55403 .6726 m .55308 .6716 L .54999 .67087 L F
.982 .691 .352 r
.55355 .67286 m .55308 .6716 L .55403 .6726 L F
0 0 .441 r
.5545 .67545 m .5545 .67543 L .55401 .67728 L F
.216 .316 .752 r
.55351 .67914 m .55393 .67756 L .55292 .67689 L F
.55373 .67999 m .55393 .67756 L .55351 .67914 L F
0 0 .21 r
.55484 .68064 m .55373 .67999 L .55437 .68211 L F
.61 .427 .609 r
.51621 .68871 m .51419 .69116 L .51372 .68856 L F
0 0 .464 r
.51753 .70602 m .51873 .70721 L .519 .70565 L F
.51829 .7078 m .51842 .70811 L .51873 .70721 L F
.054 .006 .479 r
.51842 .70811 m .51955 .70952 L .51873 .70721 L F
.51842 .70811 m .51859 .71138 L .51955 .70952 L F
.734 .632 .745 r
.51955 .70952 m .51982 .71312 L .52241 .71027 L F
.51955 .70952 m .52241 .71027 L .52128 .71039 L F
.304 .29 .679 r
.51955 .70952 m .52128 .71039 L .5204 .7093 L F
.51935 .70895 m .5204 .7093 L .51873 .70721 L F
.51955 .70952 m .5204 .7093 L .51935 .70895 L F
.786 .345 .201 r
.51873 .70721 m .5204 .7093 L .51774 .70891 L F
.5204 .7093 m .52128 .71039 L .52041 .70973 L F
.423 .042 .209 r
.52335 .70909 m .52041 .70973 L .52128 .71039 L F
.52041 .70973 m .51991 .70984 L .52128 .71039 L F
.786 .345 .201 r
.52041 .70973 m .52128 .71039 L .52041 .71003 L F
.423 .042 .209 r
.52041 .70973 m .52041 .71013 L .51991 .70984 L F
.786 .345 .201 r
.5204 .7093 m .52041 .71003 L .51774 .70891 L F
.078 0 0 r
.51982 .71312 m .52233 .71078 L .52241 .71027 L F
.604 .953 .857 r
.52335 .70909 m .52128 .71039 L .52241 .71027 L F
.423 .042 .209 r
.52118 .70956 m .52254 .71136 L .52041 .71013 L F
.52118 .70956 m .52041 .71013 L .52041 .70973 L F
.736 .907 .533 r
.52369 .70876 m .52241 .71027 L .52233 .71078 L F
.757 .763 .858 r
.52369 .70876 m .52738 .70907 L .5257 .70762 L F
0 0 0 r
.5247 .70778 m .52241 .71027 L .52369 .70876 L F
.579 .862 .537 r
.52304 .70959 m .52335 .70909 L .52241 .71027 L F
.5247 .70778 m .52335 .70909 L .52304 .70959 L F
0 0 0 r
.52854 .70554 m .5257 .70762 L .52738 .70907 L F
.52854 .70554 m .52852 .70588 L .5257 .70762 L F
.5257 .70762 m .52852 .70588 L .52696 .70701 L F
.644 .535 .715 r
.52498 .70637 m .52428 .70483 L .52342 .70586 L F
.52696 .70701 m .52546 .70579 L .52498 .70637 L F
.52546 .70579 m .52428 .70483 L .52498 .70637 L F
.897 .949 .597 r
.52485 .70653 m .52335 .70909 L .5247 .70778 L F
.52489 .70622 m .52449 .70697 L .52485 .70653 L F
.52449 .70697 m .52335 .70909 L .52485 .70653 L F
.644 .535 .715 r
.52696 .70701 m .52342 .70586 L .52489 .70622 L F
0 0 .558 r
.52329 .70814 m .52335 .70909 L .52489 .70622 L F
.52329 .70814 m .52362 .70866 L .52335 .70909 L F
.52362 .70866 m .52385 .70902 L .52335 .70909 L F
.423 .042 .209 r
.52335 .70909 m .52297 .71017 L .52118 .70956 L F
.52297 .71017 m .52254 .71136 L .52118 .70956 L F
.786 .345 .201 r
.51873 .70721 m .51774 .70891 L .51932 .70644 L F
.359 .035 .273 r
.519 .70565 m .51873 .70721 L .52115 .70544 L F
.62 .948 .764 r
.51873 .70721 m .51958 .70604 L .52115 .70544 L F
.786 .345 .201 r
.51873 .70721 m .51932 .70644 L .51958 .70604 L F
0 0 .464 r
.51753 .70602 m .51829 .7078 L .51873 .70721 L F
.622 .879 .543 r
.78898 .48075 m .7901 .4796 L .78807 .47916 L F
.685 .743 .895 r
.58619 .66152 m .58962 .66185 L .5883 .65929 L F
.652 .736 .911 r
.59223 .66082 m .5883 .65929 L .58962 .66185 L F
.364 .611 .945 r
.37265 .6211 m .37204 .6225 L .37078 .62085 L F
.37265 .6211 m .37455 .62305 L .37204 .6225 L F
.492 .326 .583 r
.3303 .59817 m .3324 .59769 L .33237 .59522 L F
.454 .323 .612 r
.33049 .60081 m .3324 .59769 L .3303 .59817 L F
.585 .36 .542 r
.49903 .65054 m .50151 .6503 L .50172 .64786 L F
.554 .334 .536 r
.50172 .64786 m .50151 .6503 L .50385 .64984 L F
.464 .247 .499 r
.51834 .65514 m .51833 .65521 L .51831 .65521 L F
.601 .361 .526 r
.52276 .65764 m .51834 .65514 L .52091 .65534 L F
.192 0 0 r
.51798 .65517 m .52091 .65534 L .51834 .65514 L F
.008 .58 .765 r
.51897 .65509 m .52087 .65533 L .51798 .65517 L F
.52087 .65533 m .52091 .65534 L .52047 .65531 L F
.52087 .65533 m .52047 .65531 L .51798 .65517 L F
.464 .247 .499 r
.51831 .65521 m .51806 .65897 L .51608 .65964 L F
.51833 .65521 m .51806 .65897 L .51831 .65521 L F
.601 .361 .526 r
.52276 .65764 m .51806 .65897 L .51834 .65514 L F
.399 .028 .213 r
.37052 .60049 m .36909 .6029 L .3667 .60336 L F
.507 .142 .281 r
.3726 .60039 m .36909 .6029 L .37052 .60049 L F
.32 0 .225 r
.33237 .59522 m .33441 .59465 L .33517 .59295 L F
.217 0 .078 r
.33441 .59465 m .33738 .59244 L .33517 .59295 L F
.732 .729 .847 r
.6379 .42597 m .63939 .42811 L .64134 .42648 L F
.534 .599 .865 r
.67177 .43033 m .67001 .43241 L .66873 .42925 L F
0 .213 .731 r
.66873 .42925 m .67001 .43241 L .66936 .43055 L F
.924 .64 .158 r
.66936 .43055 m .67001 .43241 L .67008 .43443 L F
.722 .617 .74 r
.67177 .43033 m .67008 .43443 L .67001 .43241 L F
.673 .137 0 r
.45241 .62725 m .45302 .62852 L .45062 .62699 L F
.45241 .62725 m .4544 .62929 L .45302 .62852 L F
.821 .348 0 r
.53967 .64095 m .53932 .63897 L .53802 .63813 L F
.53967 .64095 m .54121 .64211 L .53932 .63897 L F
.35 0 0 r
.45673 .6247 m .46073 .62543 L .45988 .62413 L F
0 0 .161 r
.45988 .62413 m .46073 .62543 L .46131 .62317 L F
0 .419 .83 r
.46129 .59572 m .45993 .59573 L .45894 .59432 L F
.46129 .59572 m .46271 .5969 L .45993 .59573 L F
.416 .536 .87 r
.54033 .64819 m .54182 .6507 L .54363 .64922 L F
.673 .65 .819 r
.54182 .65318 m .54363 .64922 L .54182 .6507 L F
.815 .65 .678 r
.60141 .64997 m .60511 .64787 L .60141 .64756 L F
.60141 .64997 m .60459 .65054 L .60511 .64787 L F
.797 .995 .869 r
.21011 .56362 m .20799 .56636 L .20997 .56476 L F
.858 .69 .673 r
.67369 .4377 m .67489 .44113 L .67209 .44016 L F
.881 .595 .498 r
.67496 .44343 m .67209 .44016 L .67489 .44113 L F
.652 .586 .768 r
.67732 .44006 m .67489 .44113 L .67369 .4377 L F
.357 .153 .46 r
.21787 .61271 m .21748 .61526 L .21578 .61579 L F
.401 .261 .573 r
.21748 .61526 m .21753 .61769 L .21578 .61579 L F
.36 .254 .597 r
.21753 .61769 m .216 .61843 L .21578 .61579 L F
.621 .733 .926 r
.792 .50876 m .79531 .50776 L .79165 .50688 L F
.724 .664 .79 r
.36255 .6388 m .36403 .64197 L .36612 .64019 L F
.347 0 0 r
.35696 .58512 m .35915 .58511 L .35765 .5845 L F
.874 .8 .774 r
.61284 .44964 m .60928 .45143 L .61132 .44843 L F
.61284 .44964 m .61078 .45281 L .60928 .45143 L F
.8 .842 .883 r
.61584 .44691 m .61284 .44964 L .61132 .44843 L F
0 .156 .697 r
.2382 .56183 m .23757 .56222 L .23612 .56244 L F
.2382 .56183 m .24011 .56521 L .23757 .56222 L F
.729 .569 .674 r
.49709 .69453 m .4971 .69711 L .49947 .69443 L F
.513 .268 .48 r
.49947 .69443 m .4971 .69711 L .49948 .69663 L F
.392 0 .081 r
.4306 .62723 m .42918 .62912 L .42682 .62935 L F
.391 0 .013 r
.43296 .62739 m .42918 .62912 L .4306 .62723 L F
.723 .485 .565 r
.80236 .4817 m .8025 .47889 L .80039 .47862 L F
.679 .214 .141 r
.20893 .55766 m .20713 .55892 L .20502 .55713 L F
.809 .4 .274 r
.20893 .55766 m .20985 .56016 L .20713 .55892 L F
.632 .307 .403 r
.21018 .55833 m .20985 .56016 L .20893 .55766 L F
.493 .404 .684 r
.3297 .61047 m .33175 .61012 L .33138 .6064 L F
.142 0 .011 r
.48532 .72944 m .48591 .72948 L .48789 .72851 L F
.48532 .72944 m .48591 .72948 L .48789 .72851 L F
.129 0 .292 r
.53096 .70208 m .5306 .70498 L .52854 .70554 L F
0 0 0 r
.52854 .70554 m .5306 .70498 L .52852 .70588 L F
.697 .358 .399 r
.63234 .47012 m .63606 .47023 L .6353 .47245 L F
.597 .255 .362 r
.63606 .47023 m .63844 .4717 L .6353 .47245 L F
.609 .235 .308 r
.63606 .47023 m .64027 .47139 L .63844 .4717 L F
.533 .376 .614 r
.23392 .57997 m .23133 .57823 L .23358 .57671 L F
.23392 .57997 m .23177 .58058 L .23133 .57823 L F
.25 0 0 r
.40803 .63299 m .4066 .63458 L .40418 .63518 L F
.41 0 .084 r
.41023 .63276 m .4066 .63458 L .40803 .63299 L F
.953 .635 .214 r
.55474 .68153 m .55611 .68565 L .55499 .68434 L F
.67 .145 0 r
.55611 .68565 m .55626 .68606 L .55499 .68434 L F
.55626 .68606 m .55588 .68575 L .55499 .68434 L F
.769 .297 0 r
.55499 .68434 m .5555 .68514 L .5552 .68551 L F
.5555 .68514 m .55652 .68678 L .5552 .68551 L F
.953 .635 .214 r
.55474 .68153 m .55499 .68434 L .55437 .68211 L F
.941 .867 .737 r
.55499 .68434 m .55484 .68064 L .55437 .68211 L F
.55499 .68434 m .55335 .68402 L .55484 .68064 L F
.769 .297 0 r
.55499 .68434 m .5552 .68551 L .55335 .68402 L F
.336 .375 .754 r
.5552 .68551 m .55476 .68269 L .55335 .68402 L F
.35 .346 .714 r
.55521 .68373 m .55495 .68582 L .5552 .68551 L F
.957 .918 .562 r
.55449 .68926 m .55381 .68957 L .5552 .68551 L F
.55435 .69 m .55381 .68957 L .55449 .68926 L F
.897 .614 .5 r
.55381 .68957 m .55156 .69076 L .55289 .68999 L F
.957 .918 .562 r
.55435 .69 m .5552 .68551 L .55652 .68678 L F
.35 .346 .714 r
.55455 .68911 m .55453 .68932 L .55456 .68911 L F
.812 .716 .76 r
.55784 .69033 m .55652 .68678 L .55777 .68761 L F
.904 .586 .097 r
.55652 .68678 m .55784 .69033 L .55777 .68761 L F
.812 .716 .76 r
.55784 .69033 m .55435 .69 L .55652 .68678 L F
.904 .586 .097 r
.55652 .68678 m .55687 .68874 L .55784 .69033 L F
.868 .668 .629 r
.5552 .68551 m .55687 .68874 L .55652 .68678 L F
.5552 .68551 m .55453 .68932 L .55687 .68874 L F
.745 .993 .826 r
.55841 .68346 m .55791 .68313 L .55538 .68536 L F
.55541 .68538 m .55538 .68536 L .5552 .68551 L F
.67 .145 0 r
.55611 .68565 m .55777 .68761 L .55652 .68678 L F
.382 .804 .616 r
.56041 .68227 m .55841 .68346 L .55618 .68486 L F
0 0 .154 r
.55618 .68486 m .55652 .68678 L .55777 .68761 L F
.55618 .68486 m .55841 .68346 L .55652 .68678 L F
.745 .993 .826 r
.55841 .68346 m .55538 .68536 L .55541 .68538 L F
.67 .145 0 r
.55626 .68606 m .55652 .68678 L .55588 .68575 L F
.745 .993 .826 r
.55841 .68346 m .5552 .68551 L .55652 .68678 L F
.201 0 .113 r
.55521 .68373 m .5552 .68551 L .55791 .68313 L F
.35 .346 .714 r
.55521 .68373 m .5552 .68551 L .55603 .688 L F
.184 .011 .398 r
.55397 .68911 m .55459 .68877 L .5552 .68551 L F
.35 .346 .714 r
.55459 .68877 m .55604 .68807 L .55453 .68932 L F
.55695 .68751 m .55699 .6876 L .55459 .68877 L F
.55459 .68877 m .55455 .68911 L .5552 .68551 L F
.55455 .68911 m .55456 .68911 L .5552 .68551 L F
.184 .011 .398 r
.55453 .68911 m .55607 .68813 L .5552 .68551 L F
.35 .346 .714 r
.55495 .68582 m .55459 .68877 L .5552 .68551 L F
.547 .372 .596 r
.5529 .68639 m .5552 .68551 L .55335 .68402 L F
.201 0 .113 r
.55521 .68373 m .55476 .68269 L .5552 .68551 L F
.35 .346 .714 r
.55521 .68373 m .55695 .68751 L .55459 .68877 L F
.55521 .68373 m .55603 .688 L .55607 .68813 L F
.55604 .68807 m .55699 .6876 L .55607 .68824 L F
.55604 .68807 m .55607 .68824 L .55453 .68932 L F
.184 .011 .398 r
.55381 .68957 m .55453 .68911 L .55459 .68877 L F
.55381 .68957 m .55459 .68877 L .55397 .68911 L F
.897 .614 .5 r
.55381 .68957 m .55289 .68999 L .55439 .68911 L F
.55453 .68911 m .55439 .68911 L .55607 .68813 L F
.55381 .68957 m .55439 .68911 L .55453 .68911 L F
.325 0 0 r
.37719 .58242 m .37551 .58194 L .37344 .58212 L F
.28 0 0 r
.47375 .66717 m .47751 .66492 L .47526 .66539 L F
.607 .952 .903 r
.45963 .59914 m .4628 .59808 L .46271 .5969 L F
.789 .822 .877 r
.51188 .64118 m .51473 .64039 L .51343 .6406 L F
.505 .212 .402 r
.51473 .64039 m .5181 .63843 L .51343 .6406 L F
.41 0 .094 r
.39579 .62668 m .39811 .62654 L .3996 .62458 L F
.219 0 0 r
.3996 .62458 m .40034 .62587 L .40182 .62399 L F
.3996 .62458 m .39811 .62654 L .40034 .62587 L F
.423 .213 .488 r
.52369 .72054 m .52585 .7202 L .5259 .7177 L F
0 0 .337 r
.24031 .55554 m .2389 .55644 L .23697 .55373 L F
.24031 .55554 m .24106 .55735 L .2389 .55644 L F
.378 .211 .524 r
.21167 .56915 m .21338 .56857 L .21353 .56601 L F
.41 .289 .603 r
.21167 .56915 m .21357 .57107 L .21338 .56857 L F
.475 .294 .554 r
.21167 .56915 m .21151 .57167 L .21357 .57107 L F
.571 .19 .28 r
.3954 .59209 m .39204 .59278 L .39308 .5922 L F
.476 .215 .438 r
.54674 .6618 m .54849 .66349 L .54777 .66565 L F
.742 .835 .382 r
.54849 .66349 m .5469 .66725 L .54777 .66565 L F
.635 .206 .211 r
.54777 .66565 m .5469 .66725 L .55036 .66726 L F
.752 .237 0 r
.54366 .68876 m .54616 .69066 L .54726 .68857 L F
.339 .63 .96 r
.54726 .68857 m .54824 .68767 L .54705 .6876 L F
.309 .063 .369 r
.22401 .59828 m .22343 .60054 L .22169 .60104 L F
.4 .297 .62 r
.22343 .60054 m .22367 .60311 L .22169 .60104 L F
.587 .018 0 r
.54377 .64423 m .54605 .64606 L .54606 .64543 L F
.605 .043 0 r
.54605 .64606 m .54826 .64729 L .54606 .64543 L F
0 0 .352 r
.66736 .44845 m .66755 .45213 L .66876 .45036 L F
.313 .071 .378 r
.49671 .65558 m .49915 .6536 L .49697 .65397 L F
.836 .848 .854 r
.65836 .43831 m .65617 .4386 L .65689 .43703 L F
.441 .117 .319 r
.38119 .5953 m .38035 .59789 L .37794 .59822 L F
.581 .251 .374 r
.38328 .59684 m .38119 .5953 L .38372 .59531 L F
.38328 .59684 m .38035 .59789 L .38119 .5953 L F
.68 .673 .836 r
.20494 .56556 m .20799 .56636 L .20619 .56533 L F
.784 .998 .823 r
.20841 .56481 m .20799 .56636 L .21011 .56362 L F
.537 .816 .997 r
.20619 .56533 m .20799 .56636 L .20841 .56481 L F
.62 .198 .219 r
.55469 .6278 m .55459 .62951 L .55693 .62943 L F
.317 .778 .946 r
.27797 .73445 m .28079 .73418 L .27892 .7338 L F
.27797 .73445 m .28079 .73418 L .27892 .7338 L F
.874 .798 .771 r
.53776 .61879 m .53418 .62068 L .53667 .61757 L F
.53776 .61879 m .53616 .62151 L .53418 .62068 L F
0 .138 .625 r
.53899 .61955 m .54007 .62063 L .53776 .61879 L F
.24 0 0 r
.40414 .59024 m .40403 .59077 L .40072 .59109 L F
.653 .266 .298 r
.40671 .58948 m .40403 .59077 L .40414 .59024 L F
.556 .919 .95 r
.49509 .7368 m .49299 .73771 L .49411 .73798 L F
.49509 .7368 m .49299 .73771 L .49411 .73798 L F
.419 .097 .311 r
.51537 .64477 m .51321 .64513 L .51219 .64574 L F
.295 0 .214 r
.51475 .64643 m .51219 .64574 L .51178 .64889 L F
.76 .664 .756 r
.45313 .62083 m .45171 .62431 L .45446 .62426 L F
.416 0 0 r
.45171 .62431 m .45295 .62478 L .45446 .62426 L F
.017 .564 .833 r
.45591 .62426 m .45446 .62426 L .45295 .62478 L F
.45591 .62426 m .45673 .6247 L .45446 .62426 L F
.758 .433 .435 r
.6407 .4668 m .64422 .46723 L .64404 .46904 L F
.503 .203 .39 r
.64422 .46723 m .6465 .46861 L .64404 .46904 L F
.64422 .46723 m .64674 .4668 L .6465 .46861 L F
.356 .17 .486 r
.19688 .5985 m .19869 .59777 L .1991 .59514 L F
.258 0 .283 r
.19688 .5985 m .19614 .6005 L .19869 .59777 L F
.066 .197 .692 r
.45544 .68476 m .45741 .69032 L .45745 .68754 L F
.054 .42 .866 r
.45741 .69032 m .45877 .69087 L .45745 .68754 L F
0 0 .253 r
.20697 .63813 m .20557 .64142 L .20607 .63892 L F
.695 .613 .76 r
.5264 .68167 m .52521 .67854 L .52685 .67991 L F
.485 .157 .334 r
.52935 .67965 m .5264 .68167 L .52685 .67991 L F
.659 .627 .807 r
.78355 .50857 m .78452 .51165 L .78684 .51056 L F
.659 .34 .42 r
.62995 .46977 m .63253 .4719 L .62988 .47199 L F
.62995 .46977 m .63234 .47012 L .63253 .4719 L F
.637 .599 .794 r
.44557 .58601 m .44226 .58344 L .44391 .58316 L F
.587 .706 .925 r
.44648 .5831 m .44557 .58601 L .44391 .58316 L F
.44648 .5831 m .44835 .58549 L .44557 .58601 L F
.436 .12 .33 r
.64674 .4668 m .64988 .464 L .64922 .46622 L F
.439 .123 .332 r
.64922 .46622 m .64988 .464 L .65209 .46322 L F
.88 .982 .828 r
.47651 .67103 m .47901 .66815 L .47804 .66776 L F
.448 .09 .264 r
.42877 .61667 m .42558 .61817 L .42873 .61731 L F
.323 .157 .496 r
.47175 .70579 m .46946 .70923 L .4686 .70581 L F
.47175 .70579 m .471 .70868 L .46946 .70923 L F
0 .059 .582 r
.47105 .71044 m .46946 .70923 L .471 .70868 L F
.47105 .71044 m .47008 .71161 L .46946 .70923 L F
0 .343 .694 r
.21114 .54401 m .21452 .54545 L .21253 .54537 L F
.641 .835 .429 r
.57733 .61878 m .57828 .61715 L .57941 .61556 L F
0 0 .086 r
.57941 .61556 m .58134 .61455 L .58188 .61237 L F
.084 0 .31 r
.58093 .61686 m .57941 .61556 L .57828 .61715 L F
.58093 .61686 m .58134 .61455 L .57941 .61556 L F
.723 .485 .565 r
.80236 .4817 m .80424 .48134 L .8025 .47889 L F
.392 .689 .979 r
.64494 .4217 m .64378 .42296 L .64269 .42174 L F
.64494 .4217 m .64487 .42306 L .64378 .42296 L F
.209 .355 .793 r
.23551 .55035 m .23583 .55407 L .23414 .55048 L F
.23551 .55035 m .23697 .55373 L .23583 .55407 L F
.201 .381 .818 r
.4537 .59603 m .45512 .59486 L .45258 .59502 L F
.4537 .59603 m .45615 .59754 L .45512 .59486 L F
.88 .982 .828 r
.47651 .67103 m .47804 .66776 L .47489 .66941 L F
.873 .433 .125 r
.58404 .59492 m .58561 .59755 L .58694 .59807 L F
.813 .822 .344 r
.58591 .60043 m .58694 .59807 L .58561 .59755 L F
.82 .38 0 r
.58308 .59617 m .58477 .59933 L .58591 .60043 L F
0 .077 .567 r
.58477 .59933 m .5858 .60027 L .58591 .60043 L F
.5858 .60027 m .58726 .60161 L .58591 .60043 L F
.813 .822 .344 r
.58591 .60043 m .58599 .60111 L .58611 .60071 L F
.58591 .60043 m .58611 .60071 L .58694 .59807 L F
.772 .32 .175 r
.531 .72644 m .52894 .72714 L .5285 .72565 L F
.356 .819 .731 r
.53222 .72574 m .531 .72644 L .53302 .72564 L F
.53222 .72574 m .52894 .72714 L .531 .72644 L F
.825 .631 .641 r
.56666 .64401 m .57053 .64201 L .56893 .64101 L F
.56666 .64401 m .5701 .64468 L .57053 .64201 L F
.822 .789 .821 r
.56893 .64101 m .57053 .64201 L .5733 .6376 L F
.871 .545 .033 r
.59272 .62376 m .59396 .62713 L .59325 .62469 L F
.422 .707 .982 r
.46734 .70244 m .46539 .70263 L .46564 .70198 L F
.335 .134 .452 r
.21929 .61437 m .21787 .61271 L .21922 .61197 L F
.21929 .61437 m .21748 .61526 L .21787 .61271 L F
.521 .497 .771 r
.63548 .41864 m .63655 .42243 L .63432 .42237 L F
.837 .859 .861 r
.63545 .42189 m .63655 .42243 L .63561 .42179 L F
.511 .789 .996 r
.63757 .42293 m .63432 .42237 L .63655 .42243 L F
.2 .687 .927 r
.63432 .42237 m .63655 .42243 L .63759 .42294 L F
.837 .859 .861 r
.63287 .42369 m .63655 .42243 L .63545 .42189 L F
.511 .789 .996 r
.63759 .42294 m .63757 .42293 L .63655 .42243 L F
.477 .833 .995 r
.63896 .4218 m .63759 .42294 L .63655 .42243 L F
.63896 .4218 m .63997 .42247 L .63759 .42294 L F
.292 .745 .957 r
.38333 .58062 m .38513 .58048 L .38704 .58109 L F
.227 0 0 r
.38513 .58048 m .38929 .58035 L .38704 .58109 L F
.809 .867 .891 r
.46891 .62246 m .46522 .62274 L .46731 .62063 L F
.74 .726 .838 r
.47124 .62125 m .46891 .62246 L .46731 .62063 L F
.46986 .62095 m .46731 .62063 L .46944 .62086 L F
.47124 .62125 m .46858 .62083 L .46986 .62095 L F
.46858 .62083 m .46731 .62063 L .46986 .62095 L F
.449 .24 .503 r
.47417 .6216 m .47293 .62123 L .4721 .62256 L F
.904 .89 .807 r
.47381 .61818 m .47124 .62125 L .46944 .62086 L F
.449 .24 .503 r
.47293 .62123 m .47038 .62045 L .47086 .62104 L F
.47293 .62123 m .47086 .62104 L .4721 .62256 L F
.405 .618 .937 r
.4682 .61902 m .46944 .62086 L .46731 .62063 L F
0 0 0 r
.4682 .61902 m .46799 .61939 L .4665 .62273 L F
.46799 .61939 m .46731 .62063 L .46702 .62139 L F
.46799 .61939 m .46702 .62139 L .4665 .62273 L F
.809 .867 .891 r
.46891 .62246 m .46655 .62483 L .46587 .62376 L F
.46641 .62265 m .46587 .62376 L .46522 .62274 L F
.46891 .62246 m .46587 .62376 L .46641 .62265 L F
.357 0 0 r
.40201 .63542 m .40079 .63626 L .39852 .63629 L F
.243 0 0 r
.40259 .63652 m .40201 .63542 L .40418 .63518 L F
.40259 .63652 m .40079 .63626 L .40201 .63542 L F
.415 .789 .993 r
.19908 .54309 m .20115 .54278 L .20276 .54358 L F
.349 .751 .983 r
.20115 .54278 m .20502 .54346 L .20276 .54358 L F
.508 .095 .192 r
.54321 .67411 m .54029 .67451 L .54108 .67372 L F
.568 .328 .512 r
.52585 .7202 m .52855 .71968 L .5259 .7177 L F
.399 .278 .598 r
.52777 .67094 m .52822 .67372 L .52995 .67259 L F
.74 .74 .851 r
.63072 .42198 m .63188 .42381 L .62831 .42317 L F
.795 .595 .632 r
.63188 .42381 m .62848 .42771 L .62831 .42317 L F
.685 .66 .819 r
.63293 .41956 m .63188 .42381 L .63072 .42198 L F
.63293 .41956 m .63432 .42237 L .63188 .42381 L F
.631 .28 .358 r
.42201 .61871 m .42424 .62055 L .42558 .61817 L F
.489 .126 .277 r
.42558 .61817 m .42833 .61841 L .42873 .61731 L F
.42558 .61817 m .42424 .62055 L .42833 .61841 L F
.313 .071 .378 r
.49671 .65558 m .4994 .65476 L .49915 .6536 L F
.598 .194 .248 r
.20206 .58337 m .20384 .585 L .20533 .58286 L F
.648 .375 .493 r
.20384 .585 m .20711 .58296 L .20533 .58286 L F
.442 .186 .429 r
.36486 .60422 m .36417 .60707 L .36205 .60729 L F
.329 .086 .385 r
.36618 .60583 m .36486 .60422 L .3667 .60336 L F
.36618 .60583 m .36417 .60707 L .36486 .60422 L F
.84 .736 .749 r
.53626 .68494 m .53736 .68905 L .53449 .68812 L F
.7 .424 0 r
.5369 .68741 m .53736 .68905 L .53626 .68494 L F
.059 .172 .668 r
.5369 .68741 m .53803 .69062 L .53736 .68905 L F
.839 .983 .698 r
.5807 .62899 m .58237 .62801 L .5805 .63068 L F
.506 .458 .737 r
.57884 .63277 m .5805 .63068 L .57931 .63283 L F
.57884 .63277 m .5807 .62899 L .5805 .63068 L F
.171 .7 .689 r
.63202 .44292 m .63445 .44232 L .63618 .4419 L F
0 0 0 r
.63618 .4419 m .63773 .44182 L .63816 .44017 L F
.63618 .4419 m .63445 .44232 L .63773 .44182 L F
.326 .111 .426 r
.22575 .59755 m .22401 .59828 L .22617 .59521 L F
.45 .189 .426 r
.22551 .59995 m .22401 .59828 L .22575 .59755 L F
.22551 .59995 m .22343 .60054 L .22401 .59828 L F
.774 .782 .86 r
.59552 .46493 m .59147 .46543 L .59461 .46424 L F
.829 .981 .881 r
.59773 .46261 m .59552 .46493 L .59636 .46278 L F
.787 .937 .928 r
.59636 .46278 m .59552 .46493 L .59461 .46424 L F
0 0 0 r
.58134 .61455 m .58392 .6121 L .58188 .61237 L F
.572 .399 .609 r
.58109 .47011 m .58343 .47086 L .58384 .46869 L F
.786 .533 .553 r
.58109 .47011 m .58471 .47297 L .58343 .47086 L F
.79 .873 .909 r
.65213 .4251 m .65148 .4277 L .65032 .42565 L F
.65209 .42524 m .65362 .42615 L .65148 .4277 L F
.419 .389 .72 r
.65156 .42617 m .65084 .42924 L .65332 .42691 L F
.65032 .42565 m .65063 .42779 L .65156 .42617 L F
.65063 .42779 m .65084 .42924 L .65156 .42617 L F
.79 .873 .909 r
.65213 .4251 m .65216 .42512 L .65209 .42524 L F
.65216 .42512 m .65362 .42615 L .65209 .42524 L F
.703 .971 .928 r
.51798 .65517 m .51475 .65629 L .51722 .6558 L F
.008 .58 .765 r
.51897 .65509 m .51798 .65517 L .51722 .6558 L F
0 0 0 r
.47925 .61266 m .47805 .61482 L .47983 .61332 L F
.312 0 .04 r
.47896 .61374 m .47912 .61364 L .47983 .61332 L F
0 0 0 r
.47925 .61266 m .47983 .61332 L .48104 .61278 L F
.312 0 .04 r
.47912 .61364 m .48259 .61167 L .47983 .61332 L F
0 0 0 r
.48104 .61278 m .47983 .61332 L .48144 .6128 L F
.643 .333 .431 r
.59902 .47002 m .59671 .47164 L .5953 .47004 L F
.59902 .47002 m .59908 .47202 L .59671 .47164 L F
.706 .463 .554 r
.60297 .46974 m .59908 .47202 L .59902 .47002 L F
.808 .709 .756 r
.52932 .69403 m .53287 .69503 L .53261 .69134 L F
.934 .747 .27 r
.53261 .69134 m .53287 .69503 L .53239 .69309 L F
0 .272 .677 r
.53287 .69503 m .53303 .69499 L .53239 .69309 L F
.53287 .69503 m .53519 .69622 L .53303 .69499 L F
0 0 .235 r
.54876 .65929 m .54882 .65558 L .5494 .65651 L F
.964 .829 .662 r
.8038 .49949 m .80273 .4992 L .8053 .4979 L F
.8038 .49949 m .80337 .50208 L .80273 .4992 L F
.179 0 .291 r
.23271 .58356 m .23188 .5858 L .23007 .58645 L F
.455 .295 .574 r
.23188 .5858 m .22981 .58857 L .23007 .58645 L F
0 0 0 r
.49931 .7101 m .49747 .71176 L .49988 .70889 L F
.49931 .7101 m .49694 .71419 L .49747 .71176 L F
.159 .2 .656 r
.24628 .55674 m .2451 .55898 L .245 .55693 L F
.24628 .55674 m .24679 .55973 L .2451 .55898 L F
.28 0 0 r
.24679 .55973 m .24463 .56028 L .2451 .55898 L F
.858 .727 .718 r
.53803 .69062 m .53974 .69047 L .54277 .688 L F
.491 .356 .624 r
.50783 .65991 m .50983 .66164 L .51022 .65963 L F
.50783 .65991 m .5078 .66256 L .50983 .66164 L F
.50783 .65991 m .50983 .66164 L .51022 .65963 L F
.50783 .65991 m .5078 .66256 L .50983 .66164 L F
.86 .905 .494 r
.47238 .68591 m .47136 .68849 L .47307 .68777 L F
.291 .322 .721 r
.47136 .68849 m .47348 .69119 L .47307 .68777 L F
.81 .402 .276 r
.56465 .62948 m .56776 .6334 L .56768 .63076 L F
0 0 0 r
.56776 .6334 m .57014 .6299 L .56768 .63076 L F
.685 .172 0 r
.53616 .62151 m .53652 .62256 L .53418 .62068 L F
.53616 .62151 m .53778 .6235 L .53652 .62256 L F
.542 .283 .472 r
.50749 .67621 m .50991 .67389 L .50723 .67395 L F
.295 .57 .934 r
.44153 .58216 m .44391 .58316 L .44226 .58344 L F
.392 .016 .201 r
.37559 .59863 m .37509 .59987 L .3726 .60039 L F
.461 .08 .23 r
.37559 .59863 m .37739 .59969 L .37509 .59987 L F
.447 .095 .275 r
.37794 .59822 m .37739 .59969 L .37559 .59863 L F
.064 0 .333 r
.20557 .64142 m .2051 .64391 L .20371 .64475 L F
0 0 0 r
.2051 .64391 m .20318 .64706 L .20371 .64475 L F
0 0 .445 r
.36621 .61194 m .36729 .61463 L .36675 .6155 L F
.02 0 .408 r
.36828 .61635 m .36675 .6155 L .36729 .61463 L F
.36828 .61635 m .36682 .6183 L .36675 .6155 L F
.612 .479 .675 r
.8041 .48573 m .80211 .48403 L .80308 .48758 L F
.6 .338 .492 r
.66037 .45578 m .65973 .45787 L .65714 .45784 L F
.111 .3 .775 r
.6606 .45363 m .66206 .45709 L .66037 .45578 L F
.554 .292 .474 r
.66206 .45709 m .65973 .45787 L .66037 .45578 L F
.04 0 0 r
.35915 .58511 m .36147 .58476 L .36309 .5841 L F
.214 0 0 r
.36147 .58476 m .36517 .58442 L .36309 .5841 L F
.274 0 0 r
.5248 .63733 m .52848 .63748 L .52569 .63693 L F
.033 .575 .844 r
.39137 .57998 m .39531 .58086 L .39289 .58101 L F
0 0 .453 r
.55283 .66512 m .55387 .66364 L .55328 .66153 L F
.584 .624 .858 r
.76972 .50012 m .7714 .49786 L .76889 .49849 L F
.76972 .50012 m .77338 .50117 L .7714 .49786 L F
.045 0 0 r
.54029 .71444 m .54233 .71384 L .53943 .71432 L F
.821 .816 .845 r
.62188 .4374 m .61903 .43739 L .62163 .43486 L F
.848 .715 .716 r
.62188 .4374 m .62036 .441 L .61903 .43739 L F
0 0 0 r
.18102 .5426 m .18346 .54195 L .18135 .54244 L F
.082 0 0 r
.41844 .5854 m .41692 .58597 L .41444 .58624 L F
.542 .918 .771 r
.41884 .58466 m .41844 .5854 L .42037 .58532 L F
.41884 .58466 m .41692 .58597 L .41844 .5854 L F
0 0 .196 r
.58471 .47297 m .58593 .46889 L .58343 .47086 L F
.496 .105 .228 r
.5047 .73708 m .5072 .73727 L .50839 .73461 L F
.244 0 .114 r
.50839 .73461 m .50939 .73632 L .51074 .73388 L F
.865 .82 .802 r
.61078 .45281 m .60714 .45451 L .60928 .45143 L F
.61078 .45281 m .60876 .45571 L .60714 .45451 L F
.257 .051 .398 r
.216 .61843 m .21554 .62072 L .21401 .62137 L F
.399 .276 .594 r
.21554 .62072 m .21399 .62417 L .21401 .62137 L F
.756 .363 .31 r
.53061 .72116 m .52813 .72272 L .52585 .7202 L F
.94 .724 .582 r
.52855 .71968 m .52813 .72272 L .53061 .72116 L F
.602 .766 .958 r
.43881 .57993 m .43863 .58277 L .43654 .58045 L F
.43881 .57993 m .44153 .58216 L .43863 .58277 L F
.428 .269 .562 r
.33174 .61844 m .33327 .61869 L .33338 .61543 L F
.807 .404 .288 r
.41092 .62213 m .41406 .62186 L .41136 .62092 L F
.41092 .62213 m .412 .6232 L .41406 .62186 L F
.439 0 0 r
.41406 .62186 m .412 .6232 L .41582 .62276 L F
.389 .032 .234 r
.41406 .62186 m .41582 .62276 L .41649 .62126 L F
.708 .695 .836 r
.80273 .4992 m .80337 .50208 L .79985 .5016 L F
.348 0 .059 r
.51441 .64955 m .5152 .6513 L .51383 .65271 L F
.51441 .64955 m .51609 .64925 L .5152 .6513 L F
.079 0 0 r
.51225 .66044 m .50983 .66164 L .51022 .65963 L F
.5 .368 .633 r
.50983 .66164 m .51181 .65874 L .51022 .65963 L F
.897 .806 .75 r
.60876 .45571 m .60762 .45804 L .60714 .45451 L F
.406 .727 .99 r
.28305 .69879 m .28532 .70005 L .28248 .70004 L F
.28305 .69879 m .28532 .70005 L .28248 .70004 L F
.508 0 0 r
.52848 .63748 m .53058 .63797 L .53181 .63671 L F
.442 0 0 r
.53181 .63671 m .53058 .63797 L .53442 .63758 L F
.15 0 0 r
.3942 .59213 m .39204 .59278 L .3954 .59209 L F
.351 .827 .859 r
.39624 .59152 m .3954 .59209 L .3977 .59164 L F
.39624 .59152 m .3942 .59213 L .3954 .59209 L F
.638 .643 .839 r
.37078 .62085 m .36846 .62153 L .36682 .6183 L F
.436 .836 .978 r
.39891 .58042 m .39969 .57945 L .40117 .58019 L F
.39891 .58042 m .39748 .57994 L .39969 .57945 L F
0 .15 .682 r
.55296 .65373 m .55491 .65572 L .55507 .6564 L F
.762 .248 0 r
.55284 .65402 m .55491 .65572 L .55296 .65373 L F
.963 .647 .252 r
.55384 .65484 m .55449 .65735 L .55507 .6564 L F
.762 .248 0 r
.55347 .65495 m .55384 .65484 L .55284 .65402 L F
.971 .66 .287 r
.55334 .65651 m .5536 .65492 L .55334 .65497 L F
.762 .248 0 r
.55348 .65496 m .5536 .65492 L .55347 .65495 L F
.5536 .65492 m .55384 .65484 L .55347 .65495 L F
.971 .66 .287 r
.55334 .65651 m .55449 .65735 L .5536 .65492 L F
.55346 .65495 m .5536 .65492 L .55334 .6542 L F
.963 .647 .252 r
.55334 .6542 m .5536 .65492 L .55384 .65484 L F
.762 .248 0 r
.55348 .65496 m .55491 .65572 L .55384 .65484 L F
0 .327 .801 r
.55384 .65484 m .55491 .65572 L .55334 .6542 L F
.926 .626 .456 r
.55334 .6542 m .55491 .65572 L .55346 .65495 L F
.762 .248 0 r
.55264 .65452 m .55348 .65496 L .55284 .65402 L F
.926 .626 .456 r
.55334 .6542 m .55346 .65495 L .55264 .65452 L F
.971 .66 .287 r
.55334 .65497 m .55346 .65495 L .55334 .6542 L F
.963 .647 .252 r
.5536 .65492 m .55449 .65735 L .55384 .65484 L F
0 .327 .801 r
.55507 .6564 m .55491 .65572 L .55384 .65484 L F
0 .238 .637 r
.45597 .6295 m .45669 .62987 L .4544 .62929 L F
.45597 .6295 m .45821 .63076 L .45669 .62987 L F
.465 .301 .574 r
.33237 .59522 m .33442 .59715 L .33441 .59465 L F
.461 .301 .577 r
.33237 .59522 m .3324 .59769 L .33442 .59715 L F
.559 .865 .996 r
.52519 .64521 m .52561 .64371 L .52415 .64351 L F
.52519 .64521 m .52743 .6445 L .52561 .64371 L F
.854 .406 .132 r
.41017 .62039 m .41092 .62213 L .41136 .62092 L F
.333 .415 .796 r
.46414 .71404 m .46528 .71743 L .46699 .71633 L F
.265 .276 .685 r
.46528 .71743 m .46737 .7196 L .46699 .71633 L F
.454 .323 .612 r
.33049 .60081 m .33256 .60015 L .3324 .59769 L F
.5 .383 .652 r
.33064 .60407 m .33256 .60015 L .33049 .60081 L F
.69 .537 .675 r
.67934 .44922 m .67629 .44667 L .67941 .4467 L F
.427 .228 .506 r
.6818 .44366 m .68169 .44593 L .67941 .4467 L F
.437 .28 .569 r
.68169 .44593 m .67934 .44922 L .67941 .4467 L F
0 .047 .614 r
.56035 .67782 m .56051 .67964 L .55902 .67612 L F
.994 .868 .545 r
.56035 .67782 m .56041 .68227 L .56051 .67964 L F
.806 .398 .277 r
.57011 .5999 m .56854 .6002 L .56928 .59847 L F
.8 .426 .349 r
.56928 .59847 m .5728 .60076 L .57011 .5999 L F
.425 .105 .316 r
.56854 .6002 m .57191 .59732 L .56928 .59847 L F
.724 .234 0 r
.57011 .5999 m .57033 .60056 L .56854 .6002 L F
.499 .734 .978 r
.57033 .60056 m .5697 .60022 L .56854 .6002 L F
.43 .001 .121 r
.56928 .59847 m .56854 .6002 L .56634 .60015 L F
.499 .734 .978 r
.5697 .60022 m .56959 .60016 L .56854 .6002 L F
.8 .402 .298 r
.5728 .60076 m .57212 .60263 L .57011 .5999 L F
.724 .234 0 r
.57011 .5999 m .57182 .60222 L .57033 .60056 L F
.57182 .60222 m .57212 .60263 L .57129 .60167 L F
.57182 .60222 m .57129 .60167 L .57033 .60056 L F
.425 .105 .316 r
.56854 .6002 m .56974 .60015 L .57191 .59732 L F
.334 0 .14 r
.5717 .59974 m .57369 .5992 L .57445 .59702 L F
.594 .775 .966 r
.57033 .60056 m .57229 .59971 L .57141 .59981 L F
.57033 .60056 m .57369 .5992 L .57362 .59914 L F
.334 0 .14 r
.57111 .60032 m .57369 .5992 L .5717 .59974 L F
.594 .775 .966 r
.57066 .60001 m .57141 .59981 L .57074 .59989 L F
.57033 .60056 m .57141 .59981 L .57066 .60001 L F
.57229 .59971 m .57362 .59914 L .57126 .59975 L F
.57229 .59971 m .57126 .59975 L .57074 .59989 L F
.334 0 .14 r
.57127 .59972 m .57445 .59702 L .57191 .59732 L F
.425 .105 .316 r
.56974 .60015 m .57126 .59975 L .57191 .59732 L F
.594 .775 .966 r
.57011 .59985 m .572 .59779 L .56968 .59848 L F
.57018 .60007 m .57038 .59982 L .57011 .59985 L F
.57038 .59982 m .572 .59779 L .57011 .59985 L F
.334 0 .14 r
.57126 .59975 m .57131 .59971 L .57127 .59972 L F
.57131 .59971 m .57445 .59702 L .57127 .59972 L F
.57111 .60032 m .5717 .59974 L .57126 .59975 L F
.5717 .59974 m .57445 .59702 L .57126 .59975 L F
.425 .105 .316 r
.56974 .60015 m .57117 .6001 L .57126 .59975 L F
.594 .775 .966 r
.57074 .59989 m .57362 .59914 L .572 .59779 L F
.57033 .60056 m .57074 .59989 L .57018 .60007 L F
.57074 .59989 m .572 .59779 L .57018 .60007 L F
.425 .105 .316 r
.56996 .60014 m .57111 .60032 L .57117 .6001 L F
.499 .734 .978 r
.57033 .60056 m .57018 .60007 L .56959 .60016 L F
.425 .105 .316 r
.56959 .60016 m .56983 .60018 L .56996 .60014 L F
.56983 .60018 m .57111 .60032 L .56996 .60014 L F
.56854 .6002 m .56912 .60022 L .56959 .60016 L F
.56912 .60022 m .57111 .60032 L .56959 .60016 L F
.499 .734 .978 r
.56959 .60016 m .56968 .59848 L .56921 .59995 L F
.57018 .60007 m .56968 .59848 L .56959 .60016 L F
.369 .592 .931 r
.56968 .59848 m .56994 .60026 L .56932 .59961 L F
.56968 .59848 m .56932 .59961 L .56909 .59937 L F
.56968 .59848 m .56854 .6002 L .56724 .59887 L F
.499 .734 .978 r
.56921 .59995 m .56968 .59848 L .56724 .59887 L F
.369 .592 .931 r
.56968 .59848 m .57111 .60032 L .56994 .60026 L F
.499 .734 .978 r
.56959 .60016 m .56921 .59995 L .56854 .6002 L F
.56921 .59995 m .56724 .59887 L .56854 .6002 L F
.369 .592 .931 r
.56909 .59937 m .56952 .59983 L .56854 .6002 L F
.56952 .59983 m .56994 .60026 L .56854 .6002 L F
.43 .001 .121 r
.56634 .60015 m .56854 .6002 L .56614 .60027 L F
.118 0 .127 r
.52789 .69791 m .52835 .69743 L .52874 .69622 L F
.994 .754 .41 r
.52939 .69422 m .52874 .69622 L .53029 .69679 L F
.118 0 .127 r
.52835 .69743 m .53049 .69518 L .52874 .69622 L F
.994 .754 .41 r
.52932 .69403 m .52874 .69622 L .52939 .69422 L F
.233 .746 .728 r
.18388 .55419 m .18521 .55376 L .18358 .55426 L F
.869 .64 .59 r
.46077 .69414 m .45986 .69643 L .46291 .69705 L F
.822 .585 .58 r
.46002 .69923 m .46291 .69705 L .45986 .69643 L F
.46002 .69923 m .46291 .70024 L .46291 .69705 L F
.369 .298 .645 r
.22966 .59111 m .228 .58977 L .22981 .58857 L F
.22966 .59111 m .22825 .59208 L .228 .58977 L F
.637 .245 .285 r
.62231 .47156 m .6228 .47266 L .6206 .47215 L F
.438 .15 .377 r
.33475 .62564 m .33495 .6239 L .33623 .62741 L F
.028 .271 .77 r
.33623 .62741 m .33732 .62657 L .33475 .62564 L F
.33623 .62741 m .33843 .62924 L .33732 .62657 L F
.546 .382 .61 r
.49903 .65054 m .50152 .65291 L .50151 .6503 L F
.49903 .65054 m .49915 .6536 L .50152 .65291 L F
.155 .574 .932 r
.37006 .64073 m .37081 .64021 L .36889 .63999 L F
.37006 .64073 m .37218 .64134 L .37081 .64021 L F
.838 .675 .681 r
.60039 .6468 m .60158 .64502 L .60011 .64464 L F
.60039 .6468 m .60141 .64756 L .60158 .64502 L F
.461 0 0 r
.48966 .68625 m .49305 .68654 L .49153 .68547 L F
.369 0 .152 r
.49153 .68547 m .49305 .68654 L .49406 .6852 L F
.993 .788 .526 r
.58489 .64125 m .58429 .63784 L .58336 .63837 L F
.817 .637 .66 r
.60141 .64997 m .60325 .65365 L .60459 .65054 L F
.724 .664 .79 r
.36255 .6388 m .36612 .64019 L .36496 .6379 L F
.512 .688 .947 r
.36612 .64019 m .36677 .63804 L .36496 .6379 L F
.36612 .64019 m .36889 .63999 L .36677 .63804 L F
0 0 .039 r
.59274 .60912 m .59269 .61169 L .59258 .61222 L F
.954 .951 .672 r
.59269 .61169 m .59181 .61549 L .59258 .61222 L F
.556 .568 .822 r
.64729 .42636 m .65084 .42924 L .65032 .42565 L F
.7 .794 .923 r
.64912 .43645 m .64983 .438 L .64629 .43759 L F
.575 .584 .824 r
.65024 .43909 m .64629 .43759 L .64983 .438 L F
.407 .618 .937 r
.6513 .43636 m .64983 .438 L .64912 .43645 L F
.669 .675 .847 r
.6513 .43636 m .65024 .43909 L .64983 .438 L F
.399 .187 .472 r
.54835 .60335 m .54851 .6008 L .54651 .60208 L F
.118 .669 .775 r
.49353 .69424 m .49268 .6942 L .48996 .69444 L F
.732 .75 .238 r
.49397 .69212 m .49353 .69424 L .49468 .68989 L F
.806 1 .809 r
.49397 .69212 m .49268 .6942 L .49353 .69424 L F
.923 .773 .677 r
.54149 .62385 m .54179 .62107 L .54007 .62063 L F
0 0 .432 r
.4725 .6846 m .47238 .68591 L .47307 .68777 L F
0 0 .329 r
.57832 .61964 m .57733 .61878 L .576 .62015 L F
.57832 .61964 m .57828 .61715 L .57733 .61878 L F
.233 .019 .37 r
.22825 .59208 m .22775 .59448 L .22617 .59521 L F
.377 .155 .445 r
.2276 .59688 m .22617 .59521 L .22775 .59448 L F
.2276 .59688 m .22575 .59755 L .22617 .59521 L F
.853 .59 .54 r
.52711 .69927 m .53067 .69943 L .53032 .69737 L F
0 0 .142 r
.19529 .60701 m .19542 .6068 L .19535 .60685 L F
.685 .743 .895 r
.58619 .66152 m .5883 .65929 L .58584 .65935 L F
.582 .106 .09 r
.47774 .69796 m .47929 .69774 L .4781 .69876 L F
.248 .401 .82 r
.48179 .69946 m .47929 .69774 L .48174 .69683 L F
.822 .989 .728 r
.53914 .6466 m .53829 .64865 L .54033 .64819 L F
.53914 .6466 m .53693 .64945 L .53829 .64865 L F
.606 .918 .667 r
.43457 .59342 m .43259 .59519 L .43325 .5942 L F
.121 .449 .882 r
.43259 .59519 m .43476 .59614 L .43325 .5942 L F
.266 .579 .942 r
.23245 .54862 m .23119 .54943 L .23 .54788 L F
.23245 .54862 m .23414 .55048 L .23119 .54943 L F
.7 .431 .515 r
.58079 .6214 m .5809 .62348 L .57745 .62411 L F
.653 .266 .298 r
.40671 .58948 m .40585 .5911 L .40403 .59077 L F
0 0 0 r
.40847 .58859 m .40585 .5911 L .40671 .58948 L F
.991 .747 .461 r
.55882 .66448 m .55865 .6667 L .55989 .66507 L F
.939 .909 .523 r
.55989 .66507 m .55865 .6667 L .55891 .66736 L F
.598 .56 .783 r
.53272 .66592 m .53386 .66139 L .53169 .66175 L F
.53272 .66592 m .53522 .66546 L .53386 .66139 L F
.123 0 0 r
.53453 .66632 m .53522 .66546 L .53272 .66592 L F
.693 .867 .964 r
.58282 .62601 m .58237 .62801 L .5807 .62899 L F
.58282 .62601 m .58446 .6268 L .58237 .62801 L F
.575 .584 .824 r
.65024 .43909 m .64704 .44023 L .64629 .43759 L F
.609 .362 .518 r
.65024 .43909 m .64647 .44257 L .64704 .44023 L F
.728 .663 .785 r
.48447 .70644 m .48401 .70803 L .48643 .70556 L F
.641 .68 .871 r
.48401 .70803 m .48788 .70874 L .48643 .70556 L F
.068 0 .208 r
.63313 .43419 m .63093 .43741 L .63159 .43538 L F
0 0 .462 r
.55882 .67485 m .55805 .67395 L .55849 .67055 L F
.55882 .67485 m .55902 .67612 L .55805 .67395 L F
0 0 0 r
.5728 .60076 m .57448 .59913 L .57212 .60263 L F
.848 .428 .233 r
.48807 .71111 m .48997 .71391 L .49161 .7136 L F
0 0 0 r
.49161 .7136 m .49321 .71347 L .49339 .71087 L F
.935 .559 .198 r
.62936 .42911 m .62731 .42595 L .62848 .42771 L F
.85 .944 .881 r
.63086 .42523 m .62936 .42911 L .63201 .42641 L F
.63086 .42523 m .6281 .4284 L .62936 .42911 L F
.052 0 0 r
.47671 .62563 m .47769 .62402 L .47985 .6235 L F
.697 .358 .399 r
.63234 .47012 m .6353 .47245 L .63253 .4719 L F
.091 0 0 r
.53344 .71933 m .53655 .71651 L .5327 .71696 L F
.918 .594 .413 r
.57951 .60097 m .5781 .60255 L .57777 .60021 L F
.57951 .60097 m .57957 .60307 L .5781 .60255 L F
0 0 .32 r
.47089 .71301 m .47008 .71161 L .47105 .71044 L F
.47089 .71301 m .47058 .71421 L .47008 .71161 L F
.552 .004 0 r
.49833 .70793 m .49931 .7101 L .49988 .70889 L F
.58 .225 .331 r
.38545 .5965 m .38372 .59531 L .38684 .59476 L F
.38545 .5965 m .38328 .59684 L .38372 .59531 L F
.179 0 0 r
.38643 .63835 m .3826 .63947 L .38443 .63913 L F
.236 .339 .767 r
.58728 .65758 m .58535 .65596 L .58584 .65935 L F
.488 .532 .828 r
.58584 .65935 m .5883 .65929 L .58728 .65758 L F
.964 .734 .541 r
.45745 .68754 m .45877 .69087 L .459 .68837 L F
.673 .513 .659 r
.48518 .7036 m .48643 .70556 L .48686 .70311 L F
.48518 .7036 m .48447 .70644 L .48643 .70556 L F
.687 .976 .904 r
.77794 .48384 m .77531 .48483 L .7772 .48323 L F
.679 .31 .34 r
.7772 .48323 m .78031 .48206 L .77794 .48384 L F
.577 .837 .994 r
.53519 .69622 m .53654 .69721 L .53876 .69645 L F
.985 .738 .477 r
.53519 .69622 m .53531 .6988 L .53654 .69721 L F
.494 .509 .801 r
.4971 .69711 m .4997 .6983 L .49948 .69663 L F
.958 .68 .467 r
.48807 .71111 m .48707 .71158 L .48788 .70874 L F
.48807 .71111 m .48707 .71158 L .48788 .70874 L F
.659 .144 .004 r
.55934 .62859 m .56277 .62933 L .5599 .62742 L F
.767 .492 .519 r
.51887 .64067 m .52059 .64238 L .52168 .63908 L F
.712 .396 .442 r
.5181 .63843 m .51887 .64067 L .52168 .63908 L F
.356 .213 .545 r
.21338 .56857 m .2149 .56509 L .21353 .56601 L F
.259 .14 .521 r
.44699 .59218 m .44828 .59198 L .44842 .58996 L F
.287 .281 .678 r
.44699 .59218 m .449 .59394 L .44828 .59198 L F
.407 0 .084 r
.34229 .62719 m .34065 .62935 L .33843 .62924 L F
.946 .921 .557 r
.34175 .62683 m .34065 .62935 L .34229 .62719 L F
.935 .558 .23 r
.55917 .63605 m .55837 .63721 L .55782 .63519 L F
.718 .221 .058 r
.55917 .63605 m .5622 .63885 L .55837 .63721 L F
.5 .827 .999 r
.21452 .54545 m .21669 .54495 L .21832 .54574 L F
.472 .706 .971 r
.21878 .54394 m .21832 .54574 L .21669 .54495 L F
.21878 .54394 m .2203 .5455 L .21832 .54574 L F
.286 .467 .863 r
.45761 .62268 m .45673 .6247 L .45591 .62426 L F
.45761 .62268 m .46073 .62543 L .45673 .6247 L F
0 0 .469 r
.19542 .6068 m .19649 .60575 L .19616 .60294 L F
.014 0 .175 r
.19418 .60879 m .19542 .6068 L .19529 .60701 L F
.19418 .60879 m .19649 .60575 L .19542 .6068 L F
.987 .817 .586 r
.65617 .4386 m .65556 .43589 L .65689 .43703 L F
.502 .4 .672 r
.23718 .56832 m .2353 .57159 L .236 .56915 L F
.214 .627 .953 r
.35336 .63508 m .35381 .63424 L .35228 .63246 L F
.35336 .63508 m .35532 .63533 L .35381 .63424 L F
.89 .463 .12 r
.52162 .64349 m .52113 .6446 L .51887 .64067 L F
0 0 0 r
.52335 .64234 m .52162 .64349 L .52205 .64205 L F
.288 .766 .928 r
.40117 .58019 m .40347 .57994 L .40481 .58031 L F
.493 .877 .971 r
.40481 .58031 m .40568 .57925 L .40707 .57961 L F
.40481 .58031 m .40347 .57994 L .40568 .57925 L F
.662 .649 .827 r
.79908 .50894 m .8013 .50751 L .79757 .50661 L F
.174 0 0 r
.36517 .58442 m .36739 .58434 L .36917 .58361 L F
.411 0 .026 r
.36739 .58434 m .37125 .58262 L .36917 .58361 L F
.735 .662 .779 r
.59303 .46997 m .5906 .47062 L .58976 .4673 L F
.721 .504 .596 r
.59303 .46997 m .58996 .47209 L .5906 .47062 L F
.59303 .46997 m .59307 .47236 L .58996 .47209 L F
.675 .468 .597 r
.59671 .47164 m .59303 .46997 L .5953 .47004 L F
.59671 .47164 m .59307 .47236 L .59303 .46997 L F
.631 .767 .944 r
.51485 .73451 m .51074 .73388 L .51324 .73341 L F
0 0 0 r
.51007 .73594 m .51485 .73451 L .51324 .73341 L F
.234 .645 .959 r
.51324 .73341 m .51485 .73451 L .51533 .73365 L F
.51324 .73341 m .51485 .73451 L .51533 .73365 L F
.462 .458 .768 r
.65332 .42691 m .65084 .42924 L .65291 .42924 L F
.594 .073 0 r
.48749 .69364 m .4867 .69563 L .48614 .69388 L F
.48749 .69364 m .48996 .69444 L .4867 .69563 L F
.9 .695 .617 r
.59709 .63857 m .59662 .64115 L .59808 .64132 L F
.894 .575 .437 r
.59662 .64115 m .60011 .64464 L .59808 .64132 L F
.379 .353 .704 r
.58429 .65371 m .58651 .65228 L .584 .6501 L F
.359 .314 .672 r
.58429 .65371 m .58693 .65595 L .58651 .65228 L F
.239 .303 .728 r
.58535 .65596 m .58693 .65595 L .58429 .65371 L F
.789 .291 0 r
.5568 .66348 m .55882 .66448 L .55657 .66182 L F
.5568 .66348 m .55657 .66182 L .55675 .66314 L F
.795 .302 0 r
.55451 .66003 m .55675 .66314 L .55657 .66182 L F
.445 .169 .398 r
.54001 .67662 m .5373 .67792 L .54029 .67451 L F
.508 .095 .192 r
.54321 .67411 m .54215 .67608 L .54029 .67451 L F
.43 .116 .33 r
.54029 .67451 m .54215 .67608 L .54001 .67662 L F
.904 .89 .807 r
.47381 .61818 m .46944 .62086 L .47218 .61753 L F
.711 .946 .956 r
.47381 .61818 m .47617 .61531 L .47241 .61577 L F
.47381 .61818 m .47407 .61636 L .47617 .61531 L F
.47381 .61818 m .47218 .61753 L .47407 .61636 L F
.725 .73 .854 r
.59534 .66027 m .5967 .6577 L .59505 .65955 L F
.59534 .66027 m .59797 .65939 L .5967 .6577 L F
.665 .875 .977 r
.59534 .66027 m .59505 .65955 L .59223 .66082 L F
0 .36 .736 r
.45669 .62987 m .45821 .63076 L .46021 .63151 L F
.971 .794 .368 r
.80533 .49203 m .80589 .49116 L .80563 .49271 L F
.75 .273 .112 r
.80533 .49203 m .80825 .49335 L .80589 .49116 L F
.821 .592 .592 r
.60039 .6468 m .60141 .64997 L .60141 .64756 L F
.389 .356 .701 r
.45835 .69918 m .45887 .70303 L .46087 .70269 L F
.393 .375 .72 r
.45887 .70303 m .46133 .70504 L .46087 .70269 L F
.542 .283 .472 r
.50749 .67621 m .50985 .67602 L .50991 .67389 L F
.523 .219 .393 r
.50985 .67602 m .51249 .67394 L .50991 .67389 L F
.686 .145 0 r
.51945 .68106 m .51908 .68145 L .52084 .68209 L F
0 0 0 r
.52048 .68001 m .51873 .68184 L .51908 .68145 L F
.416 .193 .464 r
.52335 .68218 m .5213 .68474 L .52084 .68209 L F
.703 .228 .121 r
.51807 .68252 m .52175 .68342 L .51985 .68202 L F
.51807 .68252 m .51985 .68202 L .51908 .68145 L F
.437 .295 .59 r
.51613 .68728 m .51807 .68252 L .51578 .68349 L F
.518 .349 .591 r
.51807 .68252 m .52049 .68511 L .52175 .68342 L F
.437 .295 .59 r
.51613 .68728 m .5189 .6867 L .51807 .68252 L F
.518 .349 .591 r
.51807 .68252 m .5189 .6867 L .52049 .68511 L F
.186 0 0 r
.52049 .6825 m .51677 .6829 L .51807 .68252 L F
.436 .876 .846 r
.51807 .68252 m .51622 .68295 L .51578 .68349 L F
.186 0 0 r
.51677 .6829 m .51622 .68295 L .51807 .68252 L F
0 0 0 r
.51873 .68184 m .51807 .68252 L .51908 .68145 L F
.686 .145 0 r
.51711 .67933 m .51908 .68145 L .51945 .68106 L F
.701 .211 .079 r
.51908 .68145 m .52335 .68218 L .52084 .68209 L F
.393 .327 .664 r
.36417 .60707 m .36281 .60895 L .36205 .60729 L F
.341 .117 .421 r
.65664 .46011 m .65473 .46097 L .65714 .45784 L F
.217 0 .191 r
.65427 .46312 m .65473 .46097 L .65664 .46011 L F
.815 .755 .797 r
.60762 .45804 m .60479 .45747 L .60714 .45451 L F
.071 0 0 r
.38792 .59531 m .38684 .59476 L .38916 .59431 L F
.38792 .59531 m .38545 .5965 L .38684 .59476 L F
.638 .371 .497 r
.48304 .71491 m .48532 .71675 L .48591 .71456 L F
.816 .717 .757 r
.67257 .43413 m .67369 .4377 L .67029 .43699 L F
.923 .804 .71 r
.67369 .4377 m .67064 .43931 L .67029 .43699 L F
.67369 .4377 m .67209 .44016 L .67064 .43931 L F
.713 .662 .798 r
.67617 .43483 m .67369 .4377 L .67257 .43413 L F
.665 .587 .758 r
.67617 .43483 m .67799 .43994 L .67369 .4377 L F
.652 .586 .768 r
.67732 .44006 m .67369 .4377 L .67799 .43994 L F
.41 .276 .586 r
.2219 .60599 m .22203 .60923 L .21976 .60974 L F
.389 .2 .499 r
.22203 .60923 m .21922 .61197 L .21976 .60974 L F
.997 .77 .451 r
.59276 .62622 m .59399 .62923 L .59396 .62713 L F
.59276 .62622 m .59261 .62863 L .59399 .62923 L F
.998 .829 .547 r
.59208 .63108 m .59399 .62923 L .59261 .62863 L F
.59208 .63108 m .59311 .63239 L .59399 .62923 L F
0 .166 .602 r
.65609 .4278 m .65362 .42615 L .65213 .4251 L F
.76 .661 .753 r
.1991 .59514 m .19494 .59521 L .19726 .59164 L F
.544 .047 .025 r
.1991 .59514 m .19662 .5963 L .19494 .59521 L F
0 0 0 r
.1991 .59514 m .19899 .59584 L .19662 .5963 L F
.1991 .59514 m .19869 .59777 L .19899 .59584 L F
.839 .67 .672 r
.67496 .44343 m .67629 .44667 L .67476 .44584 L F
.867 .682 .649 r
.67629 .44667 m .67369 .44824 L .67476 .44584 L F
.67629 .44667 m .67631 .44958 L .67369 .44824 L F
.69 .537 .675 r
.67934 .44922 m .67631 .44958 L .67629 .44667 L F
0 .201 .688 r
.65851 .42934 m .65739 .42895 L .65609 .4278 L F
.65851 .42934 m .65969 .4306 L .65739 .42895 L F
.77 .648 .727 r
.6379 .42597 m .64134 .42648 L .63997 .42247 L F
.691 .725 .876 r
.64134 .42648 m .64165 .42377 L .63997 .42247 L F
.64134 .42648 m .64539 .42458 L .64165 .42377 L F
.543 .397 .633 r
.52965 .65355 m .5319 .65017 L .52952 .65075 L F
.565 .802 .988 r
.42063 .61739 m .42201 .61871 L .41862 .61814 L F
.679 .23 .179 r
.42029 .62047 m .42201 .61871 L .42063 .61739 L F
.42029 .62047 m .42424 .62055 L .42201 .61871 L F
.645 .088 0 r
.50832 .6535 m .51088 .6556 L .50856 .6551 L F
.621 .898 .593 r
.45984 .68209 m .46198 .67984 L .45964 .67959 L F
.455 .46 .775 r
.76395 .48991 m .76462 .49311 L .76696 .4916 L F
.427 .404 .731 r
.76462 .49311 m .76766 .49528 L .76696 .4916 L F
.404 .405 .746 r
.76573 .49545 m .76766 .49528 L .76462 .49311 L F
.466 .824 .996 r
.54235 .69675 m .54081 .69609 L .53876 .69645 L F
.431 0 0 r
.54371 .69641 m .54081 .69609 L .54235 .69675 L F
.487 .319 .578 r
.1978 .58833 m .19943 .58871 L .19955 .58526 L F
.732 .697 .817 r
.42037 .58532 m .42189 .58733 L .42402 .58593 L F
.618 .723 .921 r
.54979 .6047 m .55046 .60217 L .54835 .60335 L F
.54979 .6047 m .552 .60382 L .55046 .60217 L F
.113 0 .347 r
.47985 .6235 m .47958 .62086 L .48155 .61999 L F
.977 .74 .514 r
.47058 .71421 m .47019 .71694 L .47174 .71744 L F
.576 .055 0 r
.47174 .71744 m .47474 .72029 L .47113 .72022 L F
.758 .255 .017 r
.47199 .71923 m .47174 .71744 L .47019 .71694 L F
.576 .055 0 r
.47174 .71744 m .47441 .72013 L .47474 .72029 L F
.568 .068 .028 r
.47474 .72029 m .47317 .72149 L .47113 .72022 L F
.801 .968 .66 r
.4745 .72017 m .47317 .72149 L .47474 .72029 L F
.576 .055 0 r
.47441 .72013 m .47442 .72014 L .47474 .72029 L F
.801 .968 .66 r
.47471 .71997 m .4745 .72017 L .47474 .72029 L F
.47466 .71957 m .4744 .72013 L .47471 .71997 L F
.4741 .7203 m .47317 .72149 L .47471 .71997 L F
.758 .255 .017 r
.4744 .72013 m .47442 .72014 L .47441 .72013 L F
.661 .817 .959 r
.47466 .71957 m .47442 .72014 L .4744 .72013 L F
.758 .255 .017 r
.47199 .71923 m .4744 .72013 L .47174 .71744 L F
.4744 .72013 m .47441 .72013 L .47174 .71744 L F
.661 .817 .959 r
.47466 .71957 m .4744 .72013 L .47199 .71923 L F
.801 .968 .66 r
.47466 .71957 m .4741 .7203 L .4744 .72013 L F
.761 .427 .418 r
.64165 .42377 m .64487 .42306 L .64494 .4217 L F
.64165 .42377 m .64539 .42458 L .64487 .42306 L F
.393 .327 .664 r
.36417 .60707 m .36452 .60887 L .36281 .60895 L F
.531 .014 0 r
.47921 .69212 m .48105 .69025 L .4767 .69055 L F
.548 .033 0 r
.48236 .69089 m .48105 .69025 L .47921 .69212 L F
.624 .665 .869 r
.45615 .59754 m .45731 .60016 L .45963 .59914 L F
.15 0 0 r
.3942 .59213 m .3915 .59373 L .39204 .59278 L F
.822 .713 .745 r
.58976 .4673 m .5906 .47062 L .58871 .46861 L F
.745 .487 .542 r
.5906 .47062 m .58733 .47259 L .58871 .46861 L F
.5906 .47062 m .58996 .47209 L .58733 .47259 L F
.505 .816 1 r
.49283 .65538 m .49647 .65578 L .49416 .65625 L F
.49283 .65538 m .49647 .65578 L .49416 .65625 L F
0 .403 .756 r
.43579 .59361 m .4372 .59435 L .43457 .59342 L F
.43579 .59361 m .43457 .59342 L .43325 .5942 L F
.711 .238 0 r
.44933 .62136 m .45171 .62431 L .45313 .62083 L F
.44933 .62136 m .45097 .62389 L .45171 .62431 L F
.774 .269 0 r
.45097 .62389 m .45295 .62478 L .45171 .62431 L F
.742 .814 .908 r
.76879 .48628 m .7699 .4878 L .7658 .48915 L F
.681 .792 .933 r
.77215 .48669 m .7699 .4878 L .76879 .48628 L F
.196 .671 .935 r
.18346 .54195 m .18544 .54207 L .18724 .54283 L F
.088 .625 .857 r
.18544 .54207 m .18945 .54272 L .18724 .54283 L F
.484 .072 .183 r
.41866 .63011 m .41726 .63212 L .41491 .63217 L F
.468 .055 .174 r
.42037 .63126 m .41866 .63011 L .42087 .63018 L F
.42037 .63126 m .41726 .63212 L .41866 .63011 L F
.25 .331 .752 r
.33243 .61223 m .33338 .61543 L .33467 .61422 L F
.156 .052 .475 r
.33338 .61543 m .33483 .61581 L .33467 .61422 L F
.33338 .61543 m .33327 .61869 L .33483 .61581 L F
.987 .725 .436 r
.59276 .62622 m .59396 .62713 L .59272 .62376 L F
.856 .465 .303 r
.55515 .67135 m .55403 .6726 L .55354 .67076 L F
.988 .838 .462 r
.58464 .60981 m .5838 .60624 L .58438 .60557 L F
0 0 .303 r
.58392 .6121 m .5838 .60624 L .58464 .60981 L F
.263 .052 .393 r
.20858 .63678 m .20754 .63585 L .20892 .63473 L F
.20858 .63678 m .20697 .63813 L .20754 .63585 L F
.284 0 0 r
.35075 .58765 m .35391 .58617 L .35141 .58651 L F
.483 .522 .822 r
.33471 .62145 m .33578 .61811 L .33327 .61869 L F
.33471 .62145 m .33679 .62129 L .33578 .61811 L F
.474 .338 .615 r
.33471 .62145 m .33495 .6239 L .33679 .62129 L F
.334 .81 .901 r
.58064 .59528 m .58225 .59491 L .58404 .59492 L F
.874 .449 .195 r
.58308 .59617 m .58404 .59492 L .58225 .59491 L F
.58308 .59617 m .58561 .59755 L .58404 .59492 L F
.598 .549 .771 r
.67997 .4382 m .67799 .43994 L .67617 .43483 L F
.687 .715 .87 r
.67997 .4382 m .67732 .44006 L .67799 .43994 L F
.611 .659 .872 r
.68084 .44121 m .67732 .44006 L .67997 .4382 L F
.316 .09 .404 r
.22957 .59377 m .22825 .59208 L .22966 .59111 L F
.22957 .59377 m .22775 .59448 L .22825 .59208 L F
.622 .381 .532 r
.58396 .6026 m .58438 .60557 L .58194 .60583 L F
.58396 .6026 m .58542 .60354 L .58438 .60557 L F
.746 .46 .497 r
.57957 .60307 m .58396 .6026 L .58194 .60583 L F
.624 .775 .953 r
.425 .57899 m .42275 .57966 L .42134 .57781 L F
.706 .463 .554 r
.60297 .46974 m .60344 .472 L .59908 .47202 L F
.63 .372 .508 r
.6049 .46992 m .60344 .472 L .60297 .46974 L F
.188 0 .343 r
.20957 .57466 m .21105 .57389 L .21151 .57167 L F
.18 .119 .547 r
.20957 .57466 m .21095 .57641 L .21105 .57389 L F
.20957 .57466 m .20986 .57727 L .21095 .57641 L F
.64 .627 .821 r
.68317 .44033 m .68084 .44121 L .67997 .4382 L F
.552 .375 .595 r
.68317 .44033 m .68341 .44272 L .68084 .44121 L F
.424 .421 .751 r
.68084 .44121 m .68341 .44272 L .6818 .44366 L F
.524 .681 .937 r
.43215 .58099 m .42878 .57982 L .43152 .57928 L F
.503 .587 .872 r
.43358 .5788 m .43215 .58099 L .43152 .57928 L F
.563 .668 .908 r
.43358 .5788 m .43437 .58059 L .43215 .58099 L F
.419 .836 .966 r
.40707 .57961 m .40936 .57912 L .41066 .57949 L F
.248 .757 .869 r
.40936 .57912 m .41301 .57893 L .41066 .57949 L F
.324 0 0 r
.47856 .73776 m .47928 .73826 L .47721 .737 L F
.47856 .73776 m .48065 .73858 L .47928 .73826 L F
.807 .961 .636 r
.47474 .72029 m .47442 .72014 L .47466 .71957 L F
.369 .001 .203 r
.68516 .44138 m .68509 .44144 L .68341 .44272 L F
.113 0 .411 r
.68294 .44489 m .68195 .44382 L .68341 .44272 L F
.989 .826 .445 r
.68341 .44272 m .6824 .44393 L .68294 .44489 L F
.369 .001 .203 r
.68509 .44144 m .6824 .44393 L .68341 .44272 L F
.113 0 .411 r
.68195 .44382 m .6818 .44366 L .68341 .44272 L F
.68294 .44489 m .68169 .44593 L .6818 .44366 L F
.651 .37 .479 r
.53667 .67786 m .53136 .68123 L .53178 .67926 L F
.53667 .67786 m .53395 .68137 L .53136 .68123 L F
.583 .284 .427 r
.53673 .68068 m .53667 .67786 L .53745 .67873 L F
.53673 .68068 m .53395 .68137 L .53667 .67786 L F
.715 .26 .17 r
.535 .67659 m .53745 .67873 L .53667 .67786 L F
.668 .315 .365 r
.5373 .67792 m .53745 .67873 L .535 .67659 L F
0 0 0 r
.52335 .64234 m .52205 .64205 L .52349 .64069 L F
.308 .759 .957 r
.52349 .64069 m .52581 .64042 L .52494 .63983 L F
.968 .716 .502 r
.52581 .64042 m .52349 .64069 L .52494 .63983 L F
.196 .051 .445 r
.52415 .64351 m .52561 .64371 L .52581 .64042 L F
.968 .716 .502 r
.52581 .64042 m .52561 .64371 L .5243 .64321 L F
.503 .322 .568 r
.52676 .64162 m .5243 .64321 L .52712 .64197 L F
.968 .716 .502 r
.52581 .64042 m .5235 .64223 L .52349 .64069 L F
.52581 .64042 m .5243 .64321 L .52335 .64234 L F
.503 .322 .568 r
.52494 .63983 m .52452 .64204 L .52676 .64162 L F
.52452 .64204 m .5243 .64321 L .52676 .64162 L F
.968 .716 .502 r
.5235 .64223 m .52335 .64234 L .52336 .64225 L F
.5235 .64223 m .52336 .64225 L .52349 .64069 L F
.465 .168 .376 r
.56147 .59863 m .56029 .59754 L .55976 .59939 L F
.56147 .59863 m .56252 .59739 L .56029 .59754 L F
.609 .652 .868 r
.33838 .63252 m .34047 .63363 L .33772 .63368 L F
.444 .398 .713 r
.53281 .69921 m .53096 .70208 L .53067 .69943 L F
.53281 .69921 m .53358 .70199 L .53096 .70208 L F
.588 .373 .555 r
.53358 .70199 m .5306 .70498 L .53096 .70208 L F
.574 .297 .458 r
.50489 .70855 m .50782 .70862 L .50802 .7058 L F
.638 .446 .607 r
.50782 .70862 m .50982 .70515 L .50802 .7058 L F
.519 .316 .545 r
.53159 .64765 m .53423 .64731 L .53435 .64419 L F
.646 .573 .758 r
.53324 .6418 m .53435 .64419 L .53647 .6436 L F
.59 .378 .562 r
.53423 .64731 m .53647 .6436 L .53435 .64419 L F
.8 .842 .883 r
.61584 .44691 m .61132 .44843 L .61403 .44557 L F
.808 .778 .825 r
.61823 .44425 m .61584 .44691 L .61403 .44557 L F
.904 .749 .679 r
.5967 .6577 m .59797 .65939 L .59679 .65583 L F
.61 .599 .815 r
.59679 .65583 m .59797 .65939 L .60036 .65873 L F
.742 .814 .908 r
.76879 .48628 m .7658 .48915 L .76626 .48712 L F
.894 .575 .437 r
.59662 .64115 m .597 .64385 L .60011 .64464 L F
.849 .721 .722 r
.597 .64385 m .60039 .6468 L .60011 .64464 L F
.281 0 .202 r
.19955 .58526 m .20161 .58476 L .20206 .58337 L F
.441 .291 .581 r
.19943 .58871 m .20161 .58476 L .19955 .58526 L F
.405 .768 .994 r
.41301 .57893 m .41542 .57878 L .4166 .57962 L F
.24 .73 .922 r
.41542 .57878 m .41854 .5791 L .4166 .57962 L F
.258 .052 .398 r
.21753 .61769 m .21554 .62072 L .216 .61843 L F
.338 .385 .764 r
.45754 .69725 m .45835 .69918 L .46002 .69923 L F
.389 .356 .701 r
.45835 .69918 m .46087 .70269 L .46002 .69923 L F
.121 .291 .763 r
.46231 .70873 m .46351 .7117 L .46453 .7107 L F
.199 .193 .626 r
.46351 .7117 m .46554 .71294 L .46453 .7107 L F
.46351 .7117 m .46414 .71404 L .46554 .71294 L F
.217 .288 .723 r
.50726 .69566 m .50836 .69917 L .50668 .6999 L F
.608 .936 .73 r
.50669 .69924 m .50668 .6999 L .50836 .69917 L F
.50669 .69924 m .50544 .70041 L .50668 .6999 L F
.531 .528 .797 r
.19338 .55721 m .19535 .55697 L .1943 .55321 L F
.63 .372 .508 r
.6049 .46992 m .605 .47203 L .60344 .472 L F
.683 .413 .507 r
.60712 .47173 m .6049 .46992 L .6084 .46947 L F
.60712 .47173 m .605 .47203 L .6049 .46992 L F
.696 .416 .496 r
.53775 .6622 m .54072 .66207 L .54104 .66405 L F
.318 .297 .678 r
.54338 .66147 m .54104 .66405 L .54072 .66207 L F
.516 .281 .497 r
.5728 .62718 m .5726 .62944 L .57014 .6299 L F
.394 .18 .466 r
.5728 .62718 m .57485 .62646 L .5726 .62944 L F
.375 0 .022 r
.57159 .62804 m .57485 .62646 L .5728 .62718 L F
.711 .52 .63 r
.61094 .46953 m .60712 .47173 L .6084 .46947 L F
.13 .665 .856 r
.20502 .54346 m .20701 .5434 L .20856 .54376 L F
.317 0 0 r
.20701 .5434 m .21114 .54401 L .20856 .54376 L F
.571 .807 .988 r
.42952 .57792 m .42878 .57982 L .42807 .57852 L F
.42952 .57792 m .43152 .57928 L .42878 .57982 L F
.503 .678 .944 r
.20394 .57249 m .20324 .57454 L .20147 .57317 L F
.20394 .57249 m .20461 .57382 L .20324 .57454 L F
.20324 .57454 m .20394 .57249 L .20147 .57317 L F
.20324 .57454 m .20461 .57382 L .20394 .57249 L F
.149 0 0 r
.41444 .58624 m .41055 .58777 L .41214 .58664 L F
0 0 0 r
.51566 .68999 m .51419 .69116 L .51621 .68871 L F
.167 0 0 r
.51854 .68841 m .51566 .68999 L .51621 .68871 L F
.374 .608 .94 r
.38023 .62527 m .37772 .62508 L .37658 .62331 L F
.587 .013 0 r
.55568 .63375 m .55519 .63428 L .55451 .63221 L F
.55568 .63375 m .55782 .63519 L .55519 .63428 L F
.37 .323 .675 r
.50639 .69093 m .50545 .69411 L .50707 .69339 L F
.465 .248 .499 r
.50485 .696 m .50707 .69339 L .50545 .69411 L F
0 0 .269 r
.59185 .60565 m .59218 .60675 L .59107 .60351 L F
.729 .457 0 r
.59245 .6083 m .59218 .60675 L .59185 .60565 L F
.59245 .6083 m .59274 .60912 L .59218 .60675 L F
.41 0 .084 r
.41023 .63276 m .40883 .63448 L .4066 .63458 L F
.28 0 0 r
.41259 .63251 m .40883 .63448 L .41023 .63276 L F
.006 0 0 r
.65973 .45787 m .65664 .46011 L .65714 .45784 L F
.155 .359 .813 r
.48259 .61167 m .48144 .6128 L .47983 .61332 L F
.48259 .61167 m .48391 .61457 L .48144 .6128 L F
.866 .68 .649 r
.6407 .4668 m .6416 .47002 L .64027 .47139 L F
.499 .152 .31 r
.64027 .47139 m .6416 .47002 L .64094 .4719 L F
.758 .433 .435 r
.6407 .4668 m .64404 .46904 L .6416 .47002 L F
.36 .023 .253 r
.64094 .4719 m .6416 .47002 L .64404 .46904 L F
.658 .208 .172 r
.51144 .69463 m .51041 .69614 L .50726 .69566 L F
0 0 0 r
.51171 .69494 m .51144 .69463 L .5138 .69361 L F
.51171 .69494 m .51041 .69614 L .51144 .69463 L F
.619 .742 .934 r
.469 .70275 m .4686 .70581 L .46734 .70244 L F
.793 .415 0 r
.46849 .70186 m .469 .70275 L .46822 .70128 L F
.619 .742 .934 r
.469 .70275 m .47074 .7058 L .4686 .70581 L F
.259 0 0 r
.469 .70275 m .46734 .70244 L .46562 .70442 L F
.469 .70275 m .46562 .70442 L .46998 .70504 L F
.793 .415 0 r
.46998 .70504 m .469 .70275 L .46849 .70186 L F
.619 .742 .934 r
.469 .70275 m .47175 .70579 L .47074 .7058 L F
.287 0 .249 r
.50983 .66164 m .5078 .66256 L .50721 .66404 L F
.50983 .66164 m .5078 .66256 L .50721 .66404 L F
.581 .453 .672 r
.48527 .72189 m .48322 .72317 L .48221 .71957 L F
0 0 0 r
.48221 .71957 m .48212 .7199 L .48339 .71767 L F
.17 0 .03 r
.48339 .71767 m .48384 .71886 L .48532 .71675 L F
.737 .546 .635 r
.48221 .71957 m .48322 .72317 L .47943 .72218 L F
.17 0 .03 r
.48339 .71767 m .48212 .7199 L .48384 .71886 L F
.507 .142 .281 r
.3726 .60039 m .37148 .60276 L .36909 .6029 L F
.434 .078 .26 r
.37509 .59987 m .37148 .60276 L .3726 .60039 L F
.754 .802 .892 r
.80273 .4992 m .79985 .5016 L .79863 .49878 L F
.586 .442 .652 r
.5319 .65017 m .53423 .64731 L .53159 .64765 L F
.883 .9 .836 r
.4809 .73482 m .47721 .737 L .4796 .73391 L F
0 .191 .721 r
.48127 .73408 m .4809 .73482 L .4796 .73391 L F
.48127 .73408 m .48335 .73716 L .4809 .73482 L F
.485 .48 .776 r
.77947 .50484 m .78087 .50087 L .77836 .5015 L F
.77947 .50484 m .7821 .505 L .78087 .50087 L F
.498 .406 .682 r
.77947 .50484 m .7822 .50643 L .7821 .505 L F
0 0 0 r
.48591 .71456 m .48707 .71158 L .48807 .71111 L F
.48591 .71456 m .48653 .71329 L .48707 .71158 L F
0 .235 .747 r
.48591 .71456 m .48804 .71641 L .48653 .71329 L F
.549 .284 .466 r
.48532 .71675 m .48804 .71641 L .48591 .71456 L F
.488 .128 .281 r
.18521 .55376 m .18192 .55573 L .18358 .55426 L F
.707 .271 .213 r
.62608 .44308 m .62841 .44499 L .62964 .4436 L F
.547 .081 .1 r
.62964 .4436 m .63202 .44492 L .63202 .44292 L F
.62964 .4436 m .62841 .44499 L .63202 .44492 L F
.629 .689 .887 r
.42402 .58593 m .42742 .58677 L .4263 .58538 L F
.671 .744 .906 r
.4263 .58538 m .42742 .58677 L .4299 .58611 L F
.701 .977 .914 r
.24025 .56026 m .23918 .56206 L .24253 .56102 L F
.24025 .56026 m .2382 .56183 L .23918 .56206 L F
.424 .788 .995 r
.25748 .78123 m .259 .78006 L .25564 .78024 L F
.25748 .78123 m .2595 .78086 L .259 .78006 L F
.259 .78006 m .25748 .78123 L .25564 .78024 L F
.259 .78006 m .2595 .78086 L .25748 .78123 L F
.728 .545 .644 r
.61434 .46946 m .6166 .46993 L .61455 .47216 L F
.716 .527 .633 r
.6166 .46993 m .61687 .47265 L .61455 .47216 L F
.351 .619 .952 r
.22637 .54688 m .22828 .54699 L .22783 .54853 L F
.565 .839 .996 r
.22783 .54853 m .22828 .54699 L .23 .54788 L F
.22783 .54853 m .22828 .54699 L .23 .54788 L F
.344 .797 .948 r
.38235 .62534 m .38633 .62527 L .384 .62538 L F
.902 .619 .497 r
.59411 .63804 m .59506 .6361 L .59309 .63486 L F
.59411 .63804 m .59573 .63892 L .59506 .6361 L F
.816 .569 .566 r
.59506 .6361 m .59573 .63892 L .59709 .63857 L F
.49 .186 .377 r
.51422 .65829 m .51223 .65657 L .51181 .65874 L F
.496 .185 .369 r
.51422 .65829 m .51475 .65629 L .51223 .65657 L F
.439 .123 .332 r
.64922 .46622 m .65209 .46322 L .65114 .4652 L F
.25 0 .066 r
.65114 .4652 m .65209 .46322 L .65427 .46312 L F
.567 .204 .312 r
.20161 .58476 m .20384 .585 L .20206 .58337 L F
.264 .769 .865 r
.17954 .54226 m .18346 .54195 L .18102 .5426 L F
0 .348 .772 r
.78744 .48771 m .79137 .49003 L .78874 .49044 L F
.814 .829 .355 r
.78806 .49188 m .78789 .49298 L .78874 .49044 L F
.78806 .49188 m .78874 .49044 L .79137 .49003 L F
.515 .444 .714 r
.45709 .69403 m .45754 .69725 L .45986 .69643 L F
.496 .391 .664 r
.45754 .69725 m .46002 .69923 L .45986 .69643 L F
.796 .693 .75 r
.61903 .43739 m .62036 .441 L .61875 .43914 L F
.807 .706 .754 r
.62036 .441 m .61634 .44253 L .61875 .43914 L F
.62036 .441 m .61823 .44425 L .61634 .44253 L F
0 0 0 r
.53361 .65893 m .53169 .66175 L .53386 .66139 L F
.652 .29 .345 r
.53642 .66124 m .53361 .65893 L .53386 .66139 L F
.53642 .66124 m .53713 .65908 L .53361 .65893 L F
.575 .164 .226 r
.54551 .67551 m .54215 .67608 L .54321 .67411 L F
.549 .207 .341 r
.54585 .67393 m .54551 .67551 L .54321 .67411 L F
.42 .188 .455 r
.49758 .68534 m .49711 .68781 L .49507 .68842 L F
.557 .351 .557 r
.49948 .68441 m .49711 .68781 L .49758 .68534 L F
.927 .707 .584 r
.59116 .62038 m .59272 .62376 L .59206 .62146 L F
.977 .681 .309 r
.6546 .43442 m .65356 .43043 L .65388 .43321 L F
.195 .724 .825 r
.18945 .54272 m .19155 .54244 L .19316 .54246 L F
.282 .762 .927 r
.19155 .54244 m .19521 .54256 L .19316 .54246 L F
.419 .389 .72 r
.65032 .42565 m .65332 .42691 L .65213 .4251 L F
.646 .964 .911 r
.60012 .46144 m .59636 .46278 L .59905 .45993 L F
.60012 .46144 m .59773 .46261 L .59636 .46278 L F
.628 .817 .973 r
.60253 .46048 m .60012 .46144 L .59905 .45993 L F
.659 .627 .807 r
.78355 .50857 m .78684 .51056 L .78588 .50738 L F
.611 .274 .375 r
.57445 .59702 m .57758 .59728 L .57805 .59495 L F
.434 0 0 r
.57921 .59608 m .57805 .59495 L .57758 .59728 L F
.57921 .59608 m .58064 .59528 L .57805 .59495 L F
.44 .22 .482 r
.53963 .65659 m .53713 .65908 L .53867 .65813 L F
0 0 .057 r
.53867 .65813 m .53713 .65908 L .53642 .66124 L F
0 0 .446 r
.56879 .64247 m .5694 .6444 L .56831 .64429 L F
0 .519 .759 r
.56781 .64423 m .56831 .64429 L .5701 .64468 L F
.888 .494 .048 r
.56998 .64625 m .5701 .64468 L .56831 .64429 L F
0 0 .446 r
.5694 .6444 m .56998 .64625 L .56831 .64429 L F
0 .519 .759 r
.56666 .64401 m .56831 .64429 L .56781 .64423 L F
.888 .494 .048 r
.56998 .64625 m .57116 .64734 L .5701 .64468 L F
.652 .736 .911 r
.59223 .66082 m .59078 .65859 L .5883 .65929 L F
.67 .739 .902 r
.59223 .66082 m .59313 .65787 L .59078 .65859 L F
.59223 .66082 m .59505 .65955 L .59313 .65787 L F
0 .255 .704 r
.58726 .60161 m .58599 .60111 L .58591 .60043 L F
.58726 .60161 m .58772 .60208 L .58599 .60111 L F
.356 .177 .497 r
.58542 .60354 m .58772 .60208 L .58599 .60111 L F
.681 .368 .438 r
.49635 .70594 m .49833 .70793 L .49841 .70594 L F
.459 .503 .816 r
.77338 .50117 m .77379 .49735 L .7714 .49786 L F
.77338 .50117 m .77483 .50064 L .77379 .49735 L F
.581 .653 .886 r
.43374 .5882 m .43443 .58507 L .43219 .58555 L F
.43374 .5882 m .4361 .58779 L .43443 .58507 L F
.782 .624 .685 r
.78273 .48335 m .78543 .48388 L .78666 .48067 L F
0 .066 .572 r
.66071 .43292 m .65983 .43225 L .65969 .4306 L F
.66071 .43292 m .66168 .43398 L .65983 .43225 L F
.954 .951 .672 r
.59269 .61169 m .59118 .61496 L .59181 .61549 L F
.983 .805 .586 r
.5901 .61708 m .59181 .61549 L .59118 .61496 L F
.5901 .61708 m .59134 .61795 L .59181 .61549 L F
.236 .339 .767 r
.58728 .65758 m .58693 .65595 L .58535 .65596 L F
.515 .444 .714 r
.45709 .69403 m .45986 .69643 L .45885 .6934 L F
.051 .024 .503 r
.58301 .6479 m .58432 .64646 L .5834 .64396 L F
.254 .328 .747 r
.584 .6501 m .58432 .64646 L .58301 .6479 L F
.112 0 0 r
.66755 .45213 m .66719 .45356 L .66542 .45387 L F
0 0 .352 r
.66736 .44845 m .66786 .45146 L .66755 .45213 L F
0 0 0 r
.66786 .45146 m .66719 .45356 L .66755 .45213 L F
.467 0 0 r
.54724 .62666 m .55054 .6279 L .54912 .62727 L F
.801 .401 .294 r
.4767 .69055 m .47612 .68893 L .47307 .68777 L F
.512 .319 .556 r
.23392 .57997 m .23378 .58242 L .23177 .58058 L F
.315 .31 .694 r
.23378 .58242 m .23271 .58356 L .23177 .58058 L F
.88 .447 .142 r
.49649 .70803 m .49444 .70761 L .4945 .70596 L F
.057 .071 .558 r
.49339 .71087 m .49444 .70761 L .49649 .70803 L F
.419 .364 .69 r
.49649 .70803 m .49833 .70793 L .49635 .70594 L F
.328 .214 .569 r
.4718 .68226 m .47403 .68385 L .47546 .68229 L F
.698 .253 .19 r
.47403 .68385 m .47772 .68436 L .47546 .68229 L F
.919 .55 .121 r
.66508 .4413 m .66349 .43828 L .6644 .43943 L F
.153 .409 .853 r
.66835 .44204 m .66508 .4413 L .6644 .43943 L F
.528 .898 .966 r
.20153 .5561 m .19979 .55581 L .1992 .55688 L F
.527 .707 .953 r
.45035 .59534 m .45136 .59339 L .449 .59394 L F
.45035 .59534 m .45258 .59502 L .45136 .59339 L F
.292 0 0 r
.39852 .63629 m .39924 .63731 L .39693 .63755 L F
.39852 .63629 m .40079 .63626 L .39924 .63731 L F
.501 .285 .518 r
.54876 .65929 m .54906 .66141 L .54674 .6618 L F
0 0 .235 r
.54876 .65929 m .54917 .65845 L .54882 .65558 L F
.565 .034 0 r
.55109 .66002 m .54876 .65929 L .54906 .66141 L F
.55109 .66002 m .54917 .65845 L .54876 .65929 L F
.741 .555 .642 r
.61434 .46946 m .61094 .47219 L .61094 .46953 L F
.61434 .46946 m .61455 .47216 L .61094 .47219 L F
.246 .047 .401 r
.49507 .68842 m .49479 .69071 L .49468 .68989 L F
.393 .167 .448 r
.49682 .68999 m .49507 .68842 L .49711 .68781 L F
.49682 .68999 m .49479 .69071 L .49507 .68842 L F
0 0 0 r
.51566 .68999 m .5138 .69361 L .51419 .69116 L F
.914 .65 .524 r
.59573 .63892 m .59662 .64115 L .59709 .63857 L F
.77 .264 0 r
.67631 .44958 m .67531 .45026 L .67369 .44824 L F
.582 .019 0 r
.67631 .44958 m .67886 .45113 L .67531 .45026 L F
.585 .225 .324 r
.67934 .44922 m .67886 .45113 L .67631 .44958 L F
.844 .458 .316 r
.80438 .49517 m .80337 .49703 L .80367 .4946 L F
.80438 .49517 m .8053 .4979 L .80337 .49703 L F
.744 .56 .645 r
.80367 .4946 m .80563 .49271 L .80438 .49517 L F
.996 .84 .57 r
.47416 .67925 m .47483 .67666 L .47307 .67609 L F
.763 .545 .603 r
.47483 .67666 m .47416 .67925 L .47307 .67609 L F
.996 .84 .57 r
.47416 .67925 m .47305 .67854 L .47483 .67666 L F
.529 .312 .529 r
.47483 .67666 m .47676 .67883 L .47416 .67925 L F
.717 .302 .258 r
.47305 .67854 m .47676 .67883 L .47483 .67666 L F
.803 .991 .747 r
.21567 .55855 m .21529 .56034 L .21715 .55938 L F
.521 .497 .771 r
.63548 .41864 m .63432 .42237 L .63293 .41956 L F
.513 0 0 r
.52581 .69306 m .52932 .69403 L .52693 .69306 L F
.692 .217 .118 r
.56787 .63534 m .57008 .63716 L .57128 .63594 L F
.732 .697 .817 r
.42037 .58532 m .42402 .58593 L .42255 .58456 L F
.571 .763 .969 r
.42255 .58456 m .42402 .58593 L .4263 .58538 L F
.489 .751 .988 r
.24538 .55524 m .245 .55693 L .24116 .55497 L F
.199 .446 .871 r
.24538 .55524 m .24628 .55674 L .245 .55693 L F
.945 .597 .323 r
.57931 .63283 m .57847 .63465 L .57884 .63277 L F
.131 0 0 r
.57473 .63504 m .57847 .63465 L .57631 .63553 L F
.708 .914 .966 r
.57702 .63505 m .57718 .63504 L .57847 .63465 L F
.945 .597 .323 r
.57948 .63434 m .57962 .63561 L .57847 .63465 L F
.826 .626 .632 r
.57983 .63803 m .57847 .63465 L .57962 .63561 L F
.57983 .63803 m .57631 .63553 L .57847 .63465 L F
.708 .914 .966 r
.57718 .63504 m .57968 .63491 L .57847 .63465 L F
.945 .597 .323 r
.57931 .63283 m .57948 .63434 L .57847 .63465 L F
.391 0 .013 r
.43296 .62739 m .4315 .629 L .42918 .62912 L F
.417 0 .03 r
.43542 .62831 m .4315 .629 L .43296 .62739 L F
.417 0 .036 r
.43535 .62731 m .43542 .62831 L .43296 .62739 L F
.431 0 0 r
.54371 .69641 m .54449 .6974 L .54081 .69609 L F
0 0 .066 r
.54591 .6953 m .54371 .69641 L .54646 .69337 L F
.54591 .6953 m .54449 .6974 L .54371 .69641 L F
0 0 .284 r
.45966 .59319 m .45894 .59432 L .45883 .59205 L F
.45966 .59319 m .45883 .59205 L .45739 .591 L F
.646 .573 .758 r
.53324 .6418 m .53647 .6436 L .53522 .64216 L F
0 .262 .764 r
.53647 .6436 m .53662 .64332 L .53522 .64216 L F
.631 .198 .2 r
.53662 .64332 m .53324 .6418 L .53522 .64216 L F
.53662 .64332 m .532 .64346 L .53324 .6418 L F
.369 .52 .877 r
.50341 .68688 m .50382 .68857 L .50509 .68702 L F
.351 .494 .862 r
.50382 .68857 m .50602 .6895 L .50513 .68697 L F
.511 .54 .823 r
.50602 .6895 m .50749 .68641 L .50515 .68703 L F
.50602 .6895 m .50681 .68967 L .50749 .68641 L F
.412 .065 .264 r
.50749 .68641 m .50735 .68721 L .50497 .68701 L F
.50749 .68641 m .50419 .68719 L .50513 .68697 L F
.511 .54 .823 r
.50515 .68703 m .50749 .68641 L .50513 .68697 L F
.412 .065 .264 r
.50497 .68701 m .50504 .68706 L .50419 .68719 L F
.524 .433 .694 r
.50681 .68967 m .51116 .68691 L .50749 .68641 L F
.412 .065 .264 r
.50504 .68706 m .5071 .6886 L .50431 .68725 L F
.50504 .68706 m .50431 .68725 L .50419 .68719 L F
.50735 .68721 m .5071 .6886 L .50497 .68701 L F
.369 .52 .877 r
.50356 .68689 m .50509 .68702 L .50513 .68697 L F
.50341 .68688 m .50509 .68702 L .50356 .68689 L F
.463 .457 .766 r
.50382 .68857 m .50639 .69093 L .50602 .6895 L F
.424 0 0 r
.54925 .67859 m .55212 .67905 L .55377 .67839 L F
.54925 .67859 m .55212 .67905 L .55377 .67839 L F
.701 .976 .916 r
.55212 .67905 m .554 .6788 L .55292 .67689 L F
.616 .085 0 r
.49702 .70701 m .49635 .70594 L .4945 .70596 L F
.49702 .70701 m .49833 .70793 L .49635 .70594 L F
.918 .707 .602 r
.45885 .6934 m .45986 .69643 L .46077 .69414 L F
.254 .328 .747 r
.584 .6501 m .58536 .64846 L .58432 .64646 L F
.26 .338 .754 r
.58651 .65228 m .58536 .64846 L .584 .6501 L F
0 0 0 r
.56776 .6334 m .56922 .6321 L .57014 .6299 L F
.466 .326 .606 r
.57244 .63186 m .57014 .6299 L .5726 .62944 L F
.57244 .63186 m .57047 .6329 L .57014 .6299 L F
0 0 0 r
.57014 .6299 m .56922 .6321 L .57159 .62804 L F
.696 .416 .496 r
.53775 .6622 m .54104 .66405 L .5375 .66476 L F
.491 .325 .582 r
.58384 .46869 m .58343 .47086 L .58593 .46889 L F
.647 .098 0 r
.42833 .61841 m .42964 .61975 L .42873 .61731 L F
.808 .778 .825 r
.61823 .44425 m .61403 .44557 L .61634 .44253 L F
0 0 .38 r
.48285 .698 m .48179 .69946 L .48174 .69683 L F
.822 .789 .821 r
.56893 .64101 m .5733 .6376 L .57103 .63719 L F
.846 .795 .801 r
.50381 .65266 m .507 .65337 L .50709 .64947 L F
.616 .055 0 r
.50612 .65422 m .507 .65337 L .50381 .65266 L F
0 0 .213 r
.50709 .64958 m .507 .65337 L .50737 .65214 L F
.74 .884 .479 r
.50737 .65214 m .507 .65337 L .50612 .65422 L F
.50737 .65214 m .50612 .65422 L .50763 .65446 L F
.50737 .65214 m .50763 .65446 L .50852 .6546 L F
0 0 .213 r
.50709 .64947 m .50709 .64958 L .50737 .65214 L F
.099 0 .293 r
.2353 .57159 m .23501 .57366 L .23382 .57422 L F
.406 .299 .62 r
.23501 .57366 m .23358 .57671 L .23382 .57422 L F
.529 .313 .531 r
.21105 .57389 m .21357 .57107 L .21151 .57167 L F
.696 .908 .558 r
.43267 .61233 m .43039 .61538 L .43119 .61386 L F
.546 .375 .6 r
.43267 .61233 m .43282 .61494 L .43039 .61538 L F
.519 .805 .998 r
.43119 .61386 m .43282 .61494 L .43039 .61538 L F
.448 0 .029 r
.44683 .62073 m .44342 .62128 L .44544 .62236 L F
.649 .2 .171 r
.44544 .62236 m .44933 .62136 L .44683 .62073 L F
0 0 0 r
.51422 .65829 m .51225 .66044 L .51608 .65964 L F
.684 .187 .06 r
.51806 .65897 m .51422 .65829 L .51608 .65964 L F
.5 .383 .652 r
.33064 .60407 m .33269 .60346 L .33256 .60015 L F
.434 .354 .667 r
.33138 .6064 m .33269 .60346 L .33064 .60407 L F
.187 0 .025 r
.51609 .64925 m .51927 .64741 L .51828 .64924 L F
.183 0 0 r
.5152 .6513 m .51609 .64925 L .51828 .64924 L F
.673 .65 .819 r
.54182 .65318 m .54471 .65265 L .54363 .64922 L F
.811 .743 .789 r
.54471 .65265 m .54172 .65591 L .54182 .65318 L F
.54471 .65265 m .54419 .65417 L .54172 .65591 L F
.169 0 .002 r
.54172 .65591 m .54419 .65417 L .5439 .65485 L F
.618 .39 .548 r
.54381 .65491 m .54471 .65265 L .54182 .65318 L F
.54503 .65599 m .54489 .65449 L .54381 .65491 L F
.54503 .65599 m .54381 .65491 L .54172 .65591 L F
.382 .22 .533 r
.54651 .65239 m .54471 .65265 L .54543 .65379 L F
.289 .187 .562 r
.54591 .65457 m .54419 .65417 L .5444 .65355 L F
.54573 .65428 m .5444 .65355 L .54471 .65265 L F
.54591 .65457 m .5444 .65355 L .54573 .65428 L F
.382 .22 .533 r
.54651 .65239 m .54573 .65428 L .54652 .65471 L F
.54562 .65454 m .54489 .65449 L .54503 .65599 L F
.618 .39 .548 r
.54489 .65449 m .5439 .65485 L .54381 .65491 L F
.333 0 .064 r
.5439 .65485 m .54502 .65443 L .54652 .65471 L F
.54502 .65443 m .54515 .65439 L .54652 .65471 L F
.382 .22 .533 r
.54573 .65428 m .54489 .65449 L .54562 .65454 L F
.54651 .65239 m .54543 .65379 L .54573 .65428 L F
.54543 .65379 m .54489 .65449 L .54573 .65428 L F
.289 .187 .562 r
.54652 .65471 m .54591 .65457 L .54471 .65265 L F
.382 .22 .533 r
.54573 .65428 m .54562 .65454 L .54652 .65471 L F
.54562 .65454 m .54503 .65599 L .54652 .65471 L F
.54543 .65379 m .54471 .65265 L .54489 .65449 L F
.333 0 .064 r
.54489 .65449 m .54419 .65417 L .54515 .65439 L F
.5439 .65485 m .54408 .65442 L .54489 .65449 L F
.54408 .65442 m .54419 .65417 L .54489 .65449 L F
.336 0 0 r
.5429 .65718 m .54503 .65599 L .54172 .65591 L F
.333 0 .064 r
.5429 .65718 m .5439 .65485 L .54652 .65471 L F
.618 .39 .548 r
.54489 .65449 m .54486 .65421 L .5439 .65485 L F
.54486 .65421 m .54471 .65265 L .54381 .65491 L F
.169 0 .002 r
.54381 .65491 m .5439 .65485 L .54389 .65487 L F
.54172 .65591 m .5439 .65485 L .54381 .65491 L F
.54172 .65591 m .54389 .65487 L .5429 .65718 L F
.618 .39 .548 r
.54381 .65491 m .54182 .65318 L .54172 .65591 L F
0 0 0 r
.46839 .6312 m .47015 .63014 L .47193 .62907 L F
0 .27 .777 r
.48675 .71998 m .48933 .72116 L .48751 .71973 L F
.388 0 0 r
.54417 .66264 m .54573 .66192 L .54338 .66147 L F
.539 .743 .97 r
.54465 .66211 m .54573 .66192 L .54417 .66264 L F
.259 0 0 r
.54338 .66147 m .54573 .66192 L .5465 .66178 L F
.539 .743 .97 r
.54663 .6599 m .54573 .66192 L .54465 .66211 L F
.259 0 0 r
.5465 .66178 m .54573 .66192 L .54674 .6618 L F
.161 .701 .751 r
.54758 .66157 m .54674 .6618 L .54573 .66192 L F
.54758 .66157 m .54906 .66141 L .54674 .6618 L F
.476 .215 .438 r
.54674 .6618 m .54906 .66141 L .54849 .66349 L F
.437 .28 .569 r
.68169 .44593 m .68178 .44878 L .67934 .44922 L F
.279 0 .226 r
.68097 .45019 m .67934 .44922 L .68178 .44878 L F
.68097 .45019 m .67886 .45113 L .67934 .44922 L F
.679 .31 .34 r
.7772 .48323 m .77895 .4833 L .78031 .48206 L F
.684 .317 .345 r
.78031 .48206 m .77895 .4833 L .78273 .48335 L F
.468 .188 .404 r
.64674 .4668 m .64887 .46814 L .6465 .46861 L F
.64674 .4668 m .64922 .46622 L .64887 .46814 L F
.849 .721 .722 r
.597 .64385 m .59655 .6462 L .60039 .6468 L F
.857 .65 .621 r
.59655 .6462 m .59809 .64968 L .60039 .6468 L F
.821 .592 .592 r
.60039 .6468 m .59809 .64968 L .60141 .64997 L F
.881 .595 .498 r
.67496 .44343 m .67214 .44254 L .67209 .44016 L F
.927 .676 .539 r
.67476 .44584 m .67214 .44254 L .67496 .44343 L F
.715 .619 .749 r
.63415 .42522 m .63542 .42889 L .6379 .42597 L F
.727 .279 0 r
.62688 .44298 m .62608 .44308 L .62807 .44283 L F
.508 .904 .778 r
.62989 .44121 m .62688 .44298 L .62807 .44283 L F
.367 0 0 r
.42428 .62931 m .42264 .63092 L .42087 .63018 L F
.572 .136 .174 r
.42682 .62935 m .42264 .63092 L .42428 .62931 L F
.927 .961 .776 r
.44252 .58681 m .44148 .58823 L .4419 .5892 L F
.426 .728 .989 r
.44025 .5898 m .44244 .59043 L .4419 .5892 L F
.44025 .5898 m .4419 .5892 L .4395 .58902 L F
.948 .797 .661 r
.4419 .5892 m .44041 .58703 L .4395 .58902 L F
.64 .673 .866 r
.43709 .58976 m .44025 .5898 L .4395 .58902 L F
.948 .797 .661 r
.4419 .5892 m .43986 .59045 L .44041 .58703 L F
.927 .961 .776 r
.44148 .58823 m .43986 .59045 L .4419 .5892 L F
.426 .728 .989 r
.44244 .59043 m .44323 .59066 L .4419 .5892 L F
.708 .862 .955 r
.4419 .5892 m .44323 .59066 L .44543 .58946 L F
.459 0 .023 r
.37951 .58184 m .38179 .58207 L .38333 .58062 L F
.373 0 0 r
.38333 .58062 m .38528 .58097 L .38513 .58048 L F
.38333 .58062 m .38179 .58207 L .38528 .58097 L F
.764 .652 .739 r
.80211 .48403 m .80424 .48134 L .80236 .4817 L F
.598 .416 .606 r
.80423 .48376 m .80424 .48134 L .80211 .48403 L F
.518 .343 .583 r
.47533 .70497 m .47175 .70579 L .47332 .70487 L F
.47533 .70497 m .471 .70868 L .47175 .70579 L F
.57 .722 .945 r
.47332 .70487 m .47175 .70579 L .469 .70275 L F
.651 .794 .951 r
.36131 .63738 m .36255 .6388 L .36496 .6379 L F
.777 .419 .378 r
.55328 .66153 m .54984 .66414 L .55109 .66002 L F
.55328 .66153 m .55387 .66364 L .54984 .66414 L F
.328 .559 .92 r
.54033 .64819 m .54191 .64684 L .53914 .6466 L F
.54033 .64819 m .54363 .64922 L .54191 .64684 L F
.425 .663 .96 r
.20393 .55566 m .20502 .55713 L .20569 .55548 L F
.103 .276 .756 r
.20502 .55713 m .20713 .55892 L .20569 .55548 L F
.07 .305 .789 r
.36452 .60887 m .36689 .6107 L .36621 .61194 L F
0 0 .47 r
.36689 .6107 m .36729 .61463 L .36621 .61194 L F
.526 .244 .429 r
.50431 .67925 m .50626 .67902 L .50749 .67621 L F
.524 .241 .428 r
.50749 .67621 m .51025 .67635 L .50985 .67602 L F
.50749 .67621 m .50626 .67902 L .51025 .67635 L F
.778 .995 .792 r
.79193 .48856 m .79101 .48945 L .79137 .49003 L F
.857 .9 .865 r
.79193 .48856 m .79134 .48972 L .79104 .48942 L F
.79193 .48856 m .79104 .48942 L .79007 .48845 L F
.778 .995 .792 r
.79193 .48856 m .79099 .48943 L .79101 .48945 L F
.79099 .48943 m .79043 .48995 L .79137 .49003 L F
0 .348 .772 r
.78744 .48771 m .7911 .4896 L .79137 .49003 L F
.7911 .4896 m .79134 .48972 L .79137 .49003 L F
.814 .829 .355 r
.78806 .49188 m .79137 .49003 L .79043 .48995 L F
.739 .878 .467 r
.79137 .49003 m .79134 .48972 L .79193 .48856 L F
.502 .4 .672 r
.23718 .56832 m .23778 .57102 L .2353 .57159 L F
.407 .138 .391 r
.23778 .57102 m .23501 .57366 L .2353 .57159 L F
.633 .752 .934 r
.55129 .68363 m .5518 .68518 L .54827 .68462 L F
.465 .093 .248 r
.5518 .68518 m .55112 .68741 L .54824 .68767 L F
.262 .489 .888 r
.55129 .68363 m .55335 .68402 L .5518 .68518 L F
.117 0 .122 r
.5529 .68639 m .5518 .68518 L .55335 .68402 L F
.5529 .68639 m .55112 .68741 L .5518 .68518 L F
.496 .301 .545 r
.52137 .69966 m .52367 .70176 L .52473 .69883 L F
.52137 .69966 m .52154 .70233 L .52367 .70176 L F
.247 .72 .94 r
.19521 .54256 m .19739 .5425 L .19908 .54309 L F
.25 .738 .923 r
.19739 .5425 m .20115 .54278 L .19908 .54309 L F
.638 .643 .839 r
.37078 .62085 m .36682 .6183 L .37006 .61945 L F
.42 .629 .94 r
.37173 .61928 m .37078 .62085 L .37006 .61945 L F
.329 .51 .883 r
.37173 .61928 m .37265 .6211 L .37078 .62085 L F
.342 .2 .539 r
.21341 .62622 m .21331 .62889 L .21113 .62921 L F
.376 .178 .48 r
.21331 .62889 m .21125 .63175 L .21113 .62921 L F
.485 .157 .334 r
.52935 .67965 m .52887 .68139 L .5264 .68167 L F
.55 .255 .42 r
.53178 .67926 m .52887 .68139 L .52935 .67965 L F
.539 .329 .544 r
.50152 .65291 m .50385 .64984 L .50151 .6503 L F
0 0 .329 r
.47727 .69519 m .47774 .69796 L .4781 .69876 L F
.328 .214 .569 r
.4718 .68226 m .4725 .6846 L .47403 .68385 L F
.934 .747 .27 r
.53261 .69134 m .53239 .69309 L .5334 .69024 L F
.711 .311 0 r
.54826 .64729 m .54922 .64924 L .55 .65044 L F
.98 .904 .66 r
.55 .65044 m .54762 .65239 L .54867 .65234 L F
.894 .778 .726 r
.54548 .65245 m .54651 .65239 L .54471 .65265 L F
.54843 .65168 m .54651 .65239 L .54548 .65245 L F
.98 .904 .66 r
.55 .65044 m .54922 .64924 L .54762 .65239 L F
.346 0 .028 r
.54856 .65053 m .54796 .65076 L .54762 .65239 L F
.54922 .64924 m .54825 .6504 L .54856 .65053 L F
.54825 .6504 m .54796 .65076 L .54856 .65053 L F
.824 .405 0 r
.54618 .64751 m .54813 .65035 L .54605 .64606 L F
.54813 .65035 m .54828 .65057 L .54818 .65038 L F
.54813 .65035 m .54818 .65038 L .54605 .64606 L F
.636 .44 .601 r
.54853 .65424 m .5503 .65394 L .54762 .65239 L F
.54853 .65424 m .54762 .65239 L .54796 .65076 L F
.214 .241 .673 r
.54651 .65239 m .54853 .65424 L .54821 .65229 L F
.54651 .65239 m .54821 .65229 L .54796 .65076 L F
.59 .238 .34 r
.52693 .7019 m .53067 .69943 L .52711 .69927 L F
.52693 .7019 m .53008 .70205 L .53067 .69943 L F
.345 .751 .982 r
.53146 .69935 m .53127 .69852 L .53281 .69921 L F
0 0 0 r
.53008 .70205 m .53281 .69921 L .53067 .69943 L F
.5306 .70151 m .53199 .70092 L .53281 .69921 L F
.53008 .70205 m .53199 .70092 L .5306 .70151 L F
.467 .323 .602 r
.53531 .6988 m .53358 .70199 L .53281 .69921 L F
.384 .443 .799 r
.53199 .70092 m .53366 .70114 L .53339 .70031 L F
.932 .804 .696 r
.53281 .69921 m .53303 .69499 L .53519 .69622 L F
.61 .44 .626 r
.53531 .6988 m .53281 .69921 L .53519 .69622 L F
.53531 .6988 m .53281 .69921 L .53519 .69622 L F
.932 .804 .696 r
.53281 .69921 m .53127 .69852 L .53303 .69499 L F
.936 .598 .365 r
.53281 .69921 m .53199 .70092 L .53127 .69852 L F
.384 .443 .799 r
.53199 .70092 m .53339 .70031 L .53241 .69722 L F
.53199 .70092 m .53115 .698 L .53127 .69852 L F
.734 .473 0 r
.53049 .69518 m .53127 .69852 L .5309 .69711 L F
.384 .443 .799 r
.53115 .698 m .5309 .69711 L .53127 .69852 L F
.345 .751 .982 r
.53067 .69943 m .53127 .69852 L .53146 .69935 L F
.754 .672 .77 r
.59679 .65583 m .60053 .6562 L .59912 .65295 L F
.44 .196 .446 r
.60053 .6562 m .60325 .65365 L .59912 .65295 L F
.60053 .6562 m .6004 .65644 L .60325 .65365 L F
.455 .636 .933 r
.19002 .58579 m .19079 .58578 L .19029 .58613 L F
0 0 0 r
.18994 .58664 m .19079 .58578 L .19029 .58613 L F
.388 .218 .526 r
.21055 .63368 m .20873 .63302 L .21125 .63175 L F
.21055 .63368 m .20892 .63473 L .20873 .63302 L F
.662 .647 .824 r
.4361 .58779 m .43709 .58976 L .4395 .58902 L F
.503 .307 .547 r
.62391 .43275 m .62593 .4308 L .62761 .43112 L F
.813 .544 .532 r
.62593 .4308 m .62942 .43372 L .62761 .43112 L F
.676 .708 .872 r
.7822 .50643 m .78355 .50857 L .78588 .50738 L F
.301 .511 .893 r
.79168 .49712 m .79302 .49916 L .7908 .49832 L F
.28 0 0 r
.47375 .66717 m .47639 .66656 L .47751 .66492 L F
.958 .635 .362 r
.47639 .66656 m .47804 .66776 L .47751 .66492 L F
.43 .729 .989 r
.22482 .5456 m .22436 .5471 L .22224 .54545 L F
.22482 .5456 m .22637 .54688 L .22436 .5471 L F
.543 .397 .633 r
.52965 .65355 m .5322 .6532 L .5319 .65017 L F
.5319 .65017 m .5322 .6532 L .52965 .65355 L F
.385 .257 .581 r
.51863 .67896 m .51908 .68145 L .51711 .67933 L F
.746 .267 .106 r
.55391 .63217 m .55098 .63186 L .54877 .62958 L F
0 .528 .716 r
.55391 .63217 m .55451 .63221 L .55098 .63186 L F
.655 .741 .913 r
.4781 .69876 m .47937 .70042 L .48179 .69946 L F
.227 0 0 r
.38513 .58048 m .38756 .58076 L .38929 .58035 L F
.176 0 0 r
.38756 .58076 m .39137 .57998 L .38929 .58035 L F
.123 .629 .9 r
.78675 .48726 m .78744 .48771 L .78416 .48694 L F
0 .385 .82 r
.79007 .48845 m .78744 .48771 L .78675 .48726 L F
.79007 .48845 m .79134 .48972 L .78744 .48771 L F
.434 .354 .667 r
.33138 .6064 m .33319 .60598 L .33269 .60346 L F
.499 .409 .684 r
.33138 .6064 m .33398 .60748 L .33319 .60598 L F
.33138 .6064 m .33175 .61012 L .33398 .60748 L F
.297 .619 .958 r
.37526 .62191 m .37455 .62305 L .37265 .6211 L F
.37526 .62191 m .37658 .62331 L .37455 .62305 L F
.847 .698 .698 r
.80672 .49733 m .80995 .49521 L .80774 .49522 L F
.80672 .49733 m .8086 .49868 L .80995 .49521 L F
.624 .553 .754 r
.67438 .43009 m .67257 .43413 L .67177 .43033 L F
.769 .704 .79 r
.6786 .43195 m .67617 .43483 L .67515 .43027 L F
.6786 .43195 m .67515 .43027 L .6755 .43025 L F
.768 .58 .644 r
.67727 .42821 m .67544 .43024 L .67482 .43001 L F
.67544 .43024 m .6752 .4305 L .67487 .43007 L F
.67544 .43024 m .67487 .43007 L .67482 .43001 L F
.769 .704 .79 r
.6786 .43195 m .6755 .43025 L .67699 .43068 L F
.768 .58 .644 r
.67704 .43019 m .67699 .43068 L .67542 .43026 L F
.769 .704 .79 r
.6755 .43025 m .67509 .43003 L .67699 .43068 L F
.6755 .43025 m .67515 .43027 L .67509 .43003 L F
.768 .58 .644 r
.67542 .43026 m .67699 .43068 L .6752 .4305 L F
.67727 .42821 m .67704 .43019 L .67542 .43026 L F
.624 .553 .754 r
.67498 .43021 m .67399 .43182 L .67485 .43005 L F
.768 .58 .644 r
.67482 .43001 m .6752 .4305 L .67429 .4304 L F
.624 .553 .754 r
.67485 .43005 m .67399 .43182 L .67438 .43009 L F
.67509 .43003 m .67498 .43021 L .67485 .43005 L F
.67399 .43182 m .67257 .43413 L .67438 .43009 L F
.775 .767 .258 r
.67499 .42759 m .6748 .42882 L .67437 .43016 L F
.67438 .43009 m .67437 .43016 L .67429 .4304 L F
.768 .58 .644 r
.67633 .42844 m .67429 .4304 L .6748 .42882 L F
.67727 .42821 m .67429 .4304 L .67633 .42844 L F
.624 .553 .754 r
.67509 .43003 m .67464 .43007 L .67429 .4304 L F
.67464 .43007 m .67438 .43009 L .67429 .4304 L F
.67438 .43009 m .67177 .43033 L .67429 .4304 L F
.775 .767 .258 r
.67457 .42927 m .67438 .43009 L .67429 .4304 L F
.67499 .42759 m .67437 .43016 L .67457 .42927 L F
.165 .363 .814 r
.67578 .42774 m .6748 .42882 L .67499 .42759 L F
.494 .856 .989 r
.67578 .42774 m .67727 .42821 L .6748 .42882 L F
.536 .853 .998 r
.43534 .6117 m .43267 .61233 L .4337 .61097 L F
.397 .014 .191 r
.43534 .6117 m .43358 .61351 L .43267 .61233 L F
0 0 .465 r
.43267 .61233 m .43358 .61351 L .4337 .61097 L F
.972 .71 .475 r
.43267 .61233 m .43282 .61494 L .43119 .61386 L F
0 0 .445 r
.43358 .61351 m .43282 .61494 L .43267 .61233 L F
.441 .161 .391 r
.51074 .73388 m .51007 .73594 L .51324 .73341 L F
.487 .354 .625 r
.33256 .60015 m .33442 .59715 L .3324 .59769 L F
.63 .177 .159 r
.52583 .67662 m .52471 .67848 L .52166 .67647 L F
.333 .077 .368 r
.52775 .67585 m .52521 .67854 L .52583 .67662 L F
.941 .865 .442 r
.52521 .67854 m .52471 .67848 L .52583 .67662 L F
.333 .077 .368 r
.52775 .67585 m .52521 .67854 L .52583 .67662 L F
.777 .61 .672 r
.80652 .48729 m .80678 .484 L .80423 .48376 L F
.538 .336 .554 r
.48614 .69388 m .48926 .69409 L .49111 .69061 L F
.504 .68 .945 r
.48996 .69444 m .49088 .69257 L .48821 .69508 L F
.538 .336 .554 r
.48926 .69409 m .48931 .69409 L .48936 .694 L F
.48926 .69409 m .48936 .694 L .49111 .69061 L F
.504 .68 .945 r
.48821 .69508 m .48918 .69414 L .4867 .69563 L F
.447 0 .082 r
.4867 .69563 m .48931 .69409 L .48926 .69409 L F
.4867 .69563 m .48926 .69409 L .48614 .69388 L F
.646 .488 .654 r
.48981 .69033 m .49177 .6909 L .49305 .68654 L F
.49177 .6909 m .49282 .69121 L .49292 .6893 L F
.49177 .6909 m .49292 .6893 L .49305 .68654 L F
.432 .219 .487 r
.49111 .69061 m .48936 .694 L .49006 .69331 L F
.49098 .69201 m .49006 .69331 L .49095 .69243 L F
.49111 .69061 m .49006 .69331 L .49098 .69201 L F
.504 .68 .945 r
.49088 .69257 m .49095 .69243 L .48936 .694 L F
.432 .219 .487 r
.48936 .694 m .48931 .69409 L .49095 .69243 L F
.504 .68 .945 r
.48936 .694 m .49095 .69243 L .48821 .69508 L F
.48918 .69414 m .49095 .69243 L .4867 .69563 L F
.48996 .69444 m .49268 .6942 L .49095 .69243 L F
.937 .771 .651 r
.5447 .62719 m .54304 .62681 L .54383 .62478 L F
.696 .93 .615 r
.54525 .62614 m .5447 .62719 L .54724 .62666 L F
.612 .479 .675 r
.8041 .48573 m .80423 .48376 L .80211 .48403 L F
.647 .679 .867 r
.77594 .50239 m .77836 .5015 L .77483 .50064 L F
.866 .713 .69 r
.66873 .42925 m .66936 .43055 L .66603 .43051 L F
.996 .835 .486 r
.66936 .43055 m .66787 .43244 L .66603 .43051 L F
.66936 .43055 m .66876 .43411 L .66787 .43244 L F
.924 .64 .158 r
.66936 .43055 m .67008 .43443 L .66876 .43411 L F
.217 0 .078 r
.33441 .59465 m .33646 .59403 L .33738 .59244 L F
.416 .025 .186 r
.33738 .59244 m .33882 .59356 L .33956 .59171 L F
.33738 .59244 m .33646 .59403 L .33882 .59356 L F
.399 .276 .594 r
.21554 .62072 m .2157 .62364 L .21399 .62417 L F
.133 0 .186 r
.2157 .62364 m .21341 .62622 L .21399 .62417 L F
.908 .783 .712 r
.19317 .58791 m .19293 .58901 L .19098 .58811 L F
.96 .638 .242 r
.19293 .58901 m .19172 .58796 L .19098 .58811 L F
.19291 .58898 m .19347 .59319 L .19172 .58796 L F
.19293 .58901 m .19294 .58904 L .19291 .58898 L F
.19294 .58904 m .19347 .59319 L .19291 .58898 L F
.908 .783 .712 r
.19317 .58791 m .19237 .58799 L .19153 .58629 L F
.19237 .58799 m .19098 .58811 L .1915 .58639 L F
.19237 .58799 m .1915 .58639 L .19153 .58629 L F
.256 .644 .964 r
.19419 .58708 m .19317 .58791 L .19153 .58629 L F
.19419 .58708 m .19576 .58827 L .19317 .58791 L F
.695 .344 .377 r
.5285 .72565 m .52593 .72807 L .52367 .72566 L F
.473 0 0 r
.52367 .72566 m .526 .72586 L .5285 .72565 L F
.795 .812 .866 r
.5285 .72565 m .52813 .72272 L .53008 .72334 L F
.5285 .72565 m .526 .72586 L .52813 .72272 L F
.583 .197 .276 r
.52894 .72714 m .52593 .72807 L .5285 .72565 L F
.864 .526 .014 r
.54199 .65807 m .54338 .66147 L .54262 .65904 L F
.452 .079 .24 r
.40034 .62587 m .4039 .62323 L .40182 .62399 L F
.711 .52 .63 r
.61094 .46953 m .61094 .47219 L .60712 .47173 L F
.571 .62 .862 r
.52995 .67259 m .52822 .67372 L .52647 .67062 L F
.24 .014 .356 r
.52995 .67259 m .52775 .67585 L .52822 .67372 L F
.52995 .67259 m .52775 .67585 L .52822 .67372 L F
.783 .665 .734 r
.63655 .42243 m .63997 .42247 L .63896 .4218 L F
.63655 .42243 m .6379 .42597 L .63997 .42247 L F
.603 .819 .983 r
.64177 .42046 m .63997 .42247 L .63896 .4218 L F
.326 .38 .765 r
.63997 .42247 m .64177 .42046 L .63896 .4218 L F
.329 0 .224 r
.37973 .59877 m .37794 .59822 L .38035 .59789 L F
.37973 .59877 m .37739 .59969 L .37794 .59822 L F
.568 .317 .496 r
.54199 .65807 m .53963 .65659 L .53867 .65813 L F
.54199 .65807 m .54172 .65591 L .53963 .65659 L F
0 .303 .785 r
.54199 .65807 m .53963 .65659 L .54172 .65591 L F
.59 .378 .562 r
.53423 .64731 m .53684 .64716 L .53647 .6436 L F
.628 .406 .561 r
.53647 .6436 m .53814 .64427 L .53662 .64332 L F
.53647 .6436 m .53914 .6466 L .53814 .64427 L F
.53647 .6436 m .53684 .64716 L .53914 .6466 L F
0 0 .211 r
.53647 .6436 m .53684 .64716 L .53662 .64332 L F
.15 .495 .906 r
.64381 .44487 m .64158 .44346 L .6437 .445 L F
.942 .63 .183 r
.64289 .44605 m .6437 .445 L .64216 .44356 L F
.64298 .44635 m .6437 .445 L .64289 .44605 L F
.15 .495 .906 r
.64546 .44592 m .64381 .44487 L .6437 .445 L F
.427 0 0 r
.44286 .62175 m .44342 .62128 L .43982 .62061 L F
.44 0 0 r
.44544 .62236 m .44342 .62128 L .44286 .62175 L F
.399 0 .157 r
.48186 .67245 m .48403 .67263 L .48486 .67061 L F
.269 0 0 r
.4066 .63458 m .40259 .63652 L .40418 .63518 L F
.522 .342 .578 r
.2595 .77833 m .2595 .78086 L .26175 .77782 L F
.604 .62 .841 r
.76766 .49528 m .76889 .49849 L .7714 .49786 L F
0 0 0 r
.57103 .63719 m .57021 .63977 L .56893 .64101 L F
.985 .719 .343 r
.57008 .63716 m .57021 .63977 L .57103 .63719 L F
.955 .856 .703 r
.62831 .42317 m .62631 .42437 L .62687 .42185 L F
.62831 .42317 m .62731 .42595 L .62631 .42437 L F
.633 .468 .642 r
.62831 .42317 m .62848 .42771 L .62731 .42595 L F
.748 .784 .883 r
.63072 .42198 m .62831 .42317 L .62687 .42185 L F
.274 0 0 r
.52995 .67259 m .53256 .67269 L .53324 .6722 L F
.045 0 0 r
.53256 .67269 m .53642 .67097 L .53324 .6722 L F
.751 .613 .705 r
.4994 .65476 m .50152 .65291 L .49915 .6536 L F
.259 .011 .334 r
.23363 .58487 m .23271 .58356 L .23378 .58242 L F
.23363 .58487 m .23188 .5858 L .23271 .58356 L F
.289 .582 .941 r
.35849 .6367 m .35929 .63536 L .35722 .63541 L F
.35849 .6367 m .36131 .63738 L .35929 .63536 L F
.467 0 0 r
.54724 .62666 m .55013 .62824 L .55054 .6279 L F
.57 0 0 r
.55013 .62824 m .55367 .63015 L .55054 .6279 L F
.665 .313 .366 r
.55054 .6279 m .55367 .63015 L .55459 .62951 L F
0 .18 .608 r
.19432 .59481 m .19318 .59402 L .19263 .59385 L F
.19432 .59481 m .19494 .59521 L .19318 .59402 L F
.19432 .59481 m .19318 .59402 L .19263 .59385 L F
.19432 .59481 m .19494 .59521 L .19318 .59402 L F
.189 .322 .769 r
.44844 .58217 m .44835 .58549 L .44648 .5831 L F
.44844 .58217 m .4498 .58562 L .44835 .58549 L F
0 0 .231 r
.44877 .58807 m .44835 .58549 L .4498 .58562 L F
.44877 .58807 m .44842 .58996 L .44836 .58606 L F
.44877 .58807 m .44836 .58606 L .44844 .58608 L F
.805 .627 .661 r
.44628 .58733 m .44877 .58807 L .4498 .58562 L F
.44628 .58733 m .44873 .58614 L .44873 .58631 L F
.44873 .58614 m .4498 .58562 L .44893 .58618 L F
.44873 .58614 m .44893 .58618 L .44873 .58631 L F
0 0 .231 r
.44844 .58608 m .44836 .58606 L .44835 .58549 L F
.172 0 .102 r
.52086 .6735 m .52316 .67245 L .52435 .67005 L F
.401 .032 .219 r
.52435 .67005 m .52533 .67195 L .52647 .67062 L F
.52435 .67005 m .52316 .67245 L .52533 .67195 L F
.523 .219 .393 r
.50985 .67602 m .51219 .67583 L .51249 .67394 L F
.632 .316 .417 r
.51249 .67394 m .51537 .67568 L .51582 .67331 L F
.51249 .67394 m .51219 .67583 L .51537 .67568 L F
.389 .2 .499 r
.22203 .60923 m .22261 .61158 L .21922 .61197 L F
.353 .155 .467 r
.22146 .61338 m .21922 .61197 L .22261 .61158 L F
.22146 .61338 m .21929 .61437 L .21922 .61197 L F
.821 .389 .215 r
.56399 .63187 m .56465 .62948 L .56277 .62933 L F
.56399 .63187 m .56776 .6334 L .56465 .62948 L F
.49 0 0 r
.37452 .64118 m .37081 .64021 L .37218 .64134 L F
0 0 0 r
.53302 .72564 m .53598 .72326 L .53435 .72469 L F
.606 .912 .647 r
.53598 .72326 m .53734 .72186 L .53693 .72202 L F
.596 .886 .582 r
.53598 .72326 m .53693 .72202 L .53435 .72469 L F
.651 .91 .599 r
.59123 .46543 m .59147 .46543 L .58976 .4673 L F
.46 .888 .876 r
.59162 .46493 m .59147 .46543 L .59123 .46543 L F
.59162 .46493 m .59461 .46424 L .59147 .46543 L F
.43 .361 .679 r
.33243 .61223 m .33398 .60748 L .33175 .61012 L F
.33243 .61223 m .33413 .61174 L .33398 .60748 L F
.428 .355 .672 r
.33243 .61223 m .33467 .61422 L .33413 .61174 L F
.719 .326 0 r
.55882 .67485 m .56035 .67782 L .55902 .67612 L F
.781 .66 .73 r
.52042 .72237 m .52119 .72566 L .51793 .72546 L F
.606 .108 .044 r
.52119 .72566 m .5203 .72691 L .51793 .72546 L F
.6 .633 .856 r
.52206 .72305 m .52119 .72566 L .52044 .72244 L F
.52206 .72305 m .52367 .72566 L .52119 .72566 L F
.505 .76 .987 r
.5248 .72402 m .52367 .72566 L .52206 .72305 L F
.512 .003 0 r
.52114 .72407 m .52462 .72402 L .52206 .72305 L F
.52462 .72402 m .5248 .72402 L .52206 .72305 L F
.6 .633 .856 r
.52206 .72305 m .52044 .72244 L .52042 .72237 L F
.611 .174 .186 r
.52367 .72566 m .5203 .72691 L .52119 .72566 L F
.505 .774 .992 r
.4263 .58538 m .4299 .58611 L .42848 .58498 L F
.563 .798 .987 r
.42848 .58498 m .4299 .58611 L .43219 .58555 L F
.927 .676 .539 r
.67476 .44584 m .67228 .44505 L .67214 .44254 L F
.976 .841 .644 r
.67476 .44584 m .6726 .44709 L .67228 .44505 L F
.67476 .44584 m .67369 .44824 L .6726 .44709 L F
.838 .845 .851 r
.5834 .64396 m .58371 .64058 L .58489 .64125 L F
.5834 .64396 m .58104 .64346 L .58371 .64058 L F
.786 .405 0 r
.5834 .64396 m .58286 .64351 L .58104 .64346 L F
.5834 .64396 m .58432 .64646 L .58286 .64351 L F
.443 0 0 r
.39991 .59109 m .39624 .59152 L .3977 .59164 L F
.592 .158 .185 r
.43879 .6267 m .43542 .62831 L .43535 .62731 L F
.43879 .6267 m .43736 .62849 L .43542 .62831 L F
.534 .126 .213 r
.44114 .62659 m .43736 .62849 L .43879 .6267 L F
.764 .62 .7 r
.59912 .65295 m .60325 .65365 L .60141 .64997 L F
.506 .344 .596 r
.76395 .48991 m .76633 .49022 L .76626 .48712 L F
.483 .454 .75 r
.76395 .48991 m .76696 .4916 L .76633 .49022 L F
.437 0 0 r
.19269 .55343 m .19044 .5535 L .18791 .55302 L F
.155 .697 .795 r
.1943 .55321 m .19044 .5535 L .19269 .55343 L F
.642 .215 .217 r
.43605 .62219 m .43764 .62031 L .43392 .62047 L F
.559 .134 .191 r
.43605 .62219 m .43982 .62061 L .43764 .62031 L F
.618 .526 .728 r
.33495 .6239 m .33737 .6243 L .33679 .62129 L F
.438 .15 .377 r
.33475 .62564 m .33737 .6243 L .33495 .6239 L F
.987 .817 .586 r
.65617 .4386 m .65493 .43938 L .65556 .43589 L F
.616 .892 .988 r
.24246 .55953 m .24253 .56102 L .24463 .56028 L F
.24246 .55953 m .24025 .56026 L .24253 .56102 L F
.471 .702 .969 r
.44489 .58153 m .44458 .58315 L .44412 .58282 L F
.44475 .58226 m .44648 .5831 L .44458 .58315 L F
.281 .454 .854 r
.44412 .58282 m .4454 .58279 L .44489 .58153 L F
.471 .702 .969 r
.44412 .58282 m .44458 .58315 L .44391 .58316 L F
.281 .454 .854 r
.44391 .58316 m .4454 .58279 L .44412 .58282 L F
.732 .293 .208 r
.442 .58132 m .4454 .58279 L .44369 .58251 L F
.295 .57 .934 r
.44153 .58216 m .4454 .58279 L .44391 .58316 L F
.732 .293 .208 r
.442 .58132 m .44304 .5826 L .4454 .58279 L F
.43881 .57993 m .442 .58132 L .44153 .58216 L F
.43881 .57993 m .43983 .58058 L .442 .58132 L F
.442 .58132 m .44369 .58251 L .44153 .58216 L F
.43983 .58058 m .44304 .5826 L .442 .58132 L F
.471 .702 .969 r
.44489 .58153 m .44609 .58271 L .44475 .58226 L F
.44609 .58271 m .44648 .5831 L .44475 .58226 L F
.245 0 0 r
.378 .64048 m .3768 .64106 L .37452 .64118 L F
.271 0 0 r
.38019 .64012 m .3768 .64106 L .378 .64048 L F
.46 .037 .149 r
.51785 .64502 m .51537 .64477 L .51475 .64643 L F
.621 .898 .593 r
.45984 .68209 m .46074 .68082 L .46198 .67984 L F
.402 .221 .518 r
.46407 .68063 m .46229 .682 L .46198 .67984 L F
.442 0 0 r
.46198 .67984 m .46074 .68082 L .46407 .68063 L F
.321 .412 .8 r
.46414 .71404 m .46699 .71633 L .46554 .71294 L F
.438 .15 .377 r
.33475 .62564 m .33732 .62657 L .33737 .6243 L F
.86 .766 .26 r
.55865 .6667 m .55847 .67032 L .55891 .66736 L F
.55865 .6667 m .55825 .66928 L .55847 .67032 L F
.733 .492 0 r
.55825 .66928 m .55849 .67055 L .55847 .67032 L F
.888 .867 .812 r
.19726 .59164 m .19494 .59521 L .19318 .59402 L F
.141 .25 .717 r
.19494 .59521 m .1956 .59294 L .19318 .59402 L F
.19494 .59521 m .19662 .5963 L .1956 .59294 L F
.782 .624 .685 r
.78273 .48335 m .78416 .48694 L .78543 .48388 L F
.822 .564 .549 r
.58355 .6354 m .58429 .63784 L .58185 .63757 L F
0 .142 .684 r
.54882 .65558 m .54853 .65424 L .54651 .65239 L F
0 0 .457 r
.54917 .65845 m .54853 .65424 L .54882 .65558 L F
.54917 .65845 m .54931 .65706 L .54881 .65524 L F
.54874 .65558 m .54881 .65524 L .54853 .65424 L F
.54917 .65845 m .54881 .65524 L .54874 .65558 L F
.935 .636 .451 r
.54853 .65424 m .54931 .65706 L .54736 .65565 L F
.646 .479 .642 r
.54931 .65706 m .5503 .65394 L .54853 .65424 L F
.54931 .65706 m .5503 .65394 L .54853 .65424 L F
.504 .333 .582 r
.54908 .65402 m .54736 .65565 L .54907 .65402 L F
.5503 .65394 m .54892 .65474 L .54908 .65402 L F
.54892 .65474 m .54736 .65565 L .54908 .65402 L F
.535 0 0 r
.5503 .65394 m .55145 .65387 L .54981 .65296 L F
.5503 .65394 m .54981 .65296 L .54867 .65234 L F
.5503 .65394 m .55264 .65452 L .55145 .65387 L F
.762 .248 0 r
.55264 .65452 m .55296 .65373 L .54867 .65234 L F
.361 0 .142 r
.54931 .65706 m .55264 .65452 L .5503 .65394 L F
0 0 .254 r
.55079 .65491 m .5503 .65394 L .55041 .65275 L F
.55084 .6552 m .5503 .65394 L .55079 .65491 L F
.504 .333 .582 r
.5503 .65394 m .54907 .65402 L .55041 .65275 L F
.722 .544 .648 r
.59307 .47236 m .59084 .47496 L .58996 .47209 L F
.693 .501 .623 r
.59307 .47236 m .59334 .47512 L .59084 .47496 L F
.588 .424 .626 r
.59539 .47426 m .59307 .47236 L .59671 .47164 L F
.59539 .47426 m .59334 .47512 L .59307 .47236 L F
.378 .327 .674 r
.20986 .57727 m .20994 .58012 L .21133 .57923 L F
.167 0 .272 r
.20994 .58012 m .21114 .58112 L .21133 .57923 L F
.20994 .58012 m .20915 .58252 L .21114 .58112 L F
.711 .673 .811 r
.79165 .50688 m .79531 .50776 L .79434 .50443 L F
.744 .692 .802 r
.79434 .50443 m .79531 .50776 L .79757 .50661 L F
0 0 .288 r
.20697 .63813 m .20649 .64077 L .20557 .64142 L F
.113 0 .355 r
.20622 .64279 m .20557 .64142 L .20649 .64077 L F
.20622 .64279 m .2051 .64391 L .20557 .64142 L F
.47 .835 .993 r
.50111 .7369 m .49878 .73741 L .50239 .73754 L F
.50111 .7369 m .49878 .73741 L .50239 .73754 L F
.458 .829 .992 r
.50111 .7369 m .50239 .73754 L .5047 .73708 L F
.5047 .73708 m .50239 .73754 L .50111 .7369 L F
0 .282 .775 r
.4762 .69327 m .47348 .69119 L .4767 .69055 L F
.4762 .69327 m .47565 .69328 L .47449 .69216 L F
.4762 .69327 m .47449 .69216 L .47501 .69236 L F
.4762 .69327 m .47562 .69346 L .47326 .69226 L F
.601 .031 0 r
.47326 .69226 m .4762 .69327 L .47562 .69346 L F
0 .282 .775 r
.4762 .69327 m .4767 .69055 L .47562 .69346 L F
.215 0 .202 r
.4767 .69055 m .4759 .6927 L .4777 .69234 L F
.4759 .6927 m .47562 .69346 L .47657 .69295 L F
.4759 .6927 m .47657 .69295 L .4777 .69234 L F
0 .282 .775 r
.47501 .69236 m .47449 .69216 L .47348 .69119 L F
.993 .788 .526 r
.58489 .64125 m .58371 .64058 L .58429 .63784 L F
.121 .33 .798 r
.52743 .6445 m .52843 .64291 L .52561 .64371 L F
.367 0 0 r
.53045 .64456 m .52902 .64502 L .52743 .6445 L F
.121 .33 .798 r
.52743 .6445 m .52902 .64502 L .52843 .64291 L F
.464 .324 .605 r
.55064 .59997 m .54851 .6008 L .55046 .60217 L F
.536 .299 .502 r
.55046 .60217 m .54851 .6008 L .54835 .60335 L F
.464 .324 .605 r
.55064 .59997 m .54851 .6008 L .55046 .60217 L F
.487 .65 .931 r
.33939 .6316 m .33838 .63252 L .34225 .63233 L F
.654 .742 .915 r
.34225 .63233 m .34047 .63363 L .33939 .6316 L F
.487 .65 .931 r
.33939 .6316 m .34047 .63363 L .33838 .63252 L F
.531 .373 .612 r
.20607 .56238 m .20841 .56481 L .20809 .56114 L F
.20607 .56238 m .20619 .56533 L .20841 .56481 L F
.548 .264 .437 r
.51582 .67331 m .51537 .67568 L .51795 .67529 L F
.636 .239 .276 r
.51582 .67331 m .51795 .67529 L .5185 .67387 L F
.284 0 0 r
.35075 .58765 m .35289 .58733 L .35391 .58617 L F
.242 0 0 r
.35391 .58617 m .35289 .58733 L .35541 .58672 L F
.244 0 0 r
.35391 .58617 m .35541 .58672 L .35696 .58512 L F
.649 .2 .171 r
.44544 .62236 m .44797 .62277 L .44933 .62136 L F
.751 .331 .252 r
.44797 .62277 m .45097 .62389 L .44933 .62136 L F
.067 0 0 r
.18976 .58584 m .19079 .58578 L .19002 .58579 L F
.636 .211 .218 r
.57921 .59608 m .58225 .59491 L .58064 .59528 L F
.066 0 .077 r
.41649 .62126 m .41582 .62276 L .41817 .62027 L F
.224 .319 .752 r
.53386 .66139 m .53522 .66546 L .53613 .66329 L F
.743 .561 .647 r
.53453 .66632 m .53613 .66329 L .53522 .66546 L F
.71 .629 .765 r
.63415 .42522 m .6379 .42597 L .63655 .42243 L F
.333 .792 .943 r
.40072 .59109 m .4023 .59059 L .39991 .59109 L F
.40072 .59109 m .40403 .59077 L .4023 .59059 L F
.953 .679 .479 r
.54877 .62958 m .54731 .62931 L .54724 .62666 L F
.496 0 0 r
.55098 .63186 m .54731 .62931 L .54877 .62958 L F
.8 .446 .386 r
.48653 .71329 m .48807 .71111 L .48707 .71158 L F
.48653 .71329 m .48997 .71391 L .48807 .71111 L F
.626 .281 .367 r
.61455 .47216 m .61098 .47424 L .61094 .47219 L F
.61455 .47216 m .61349 .47422 L .61098 .47424 L F
.73 .401 .422 r
.61455 .47216 m .61683 .47463 L .61349 .47422 L F
.715 .404 .451 r
.61687 .47265 m .61683 .47463 L .61455 .47216 L F
.274 .483 .88 r
.52008 .64582 m .51927 .64741 L .51785 .64502 L F
.637 .789 .341 r
.51828 .64924 m .51927 .64741 L .52008 .64582 L F
.079 0 0 r
.51225 .66044 m .51199 .66099 L .50983 .66164 L F
0 0 0 r
.51422 .65829 m .51199 .66099 L .51225 .66044 L F
.663 .424 .548 r
.59908 .47202 m .59539 .47426 L .59671 .47164 L F
.237 0 0 r
.3915 .59373 m .38792 .59531 L .38916 .59431 L F
.805 .707 .757 r
.66542 .45387 m .66241 .45498 L .6606 .45363 L F
.651 .454 .604 r
.66511 .4564 m .66206 .45709 L .66542 .45387 L F
.27 .135 .505 r
.66719 .45356 m .66511 .4564 L .66542 .45387 L F
.322 .172 .517 r
.21929 .61437 m .21753 .61769 L .21748 .61526 L F
0 0 0 r
.53008 .72334 m .53142 .72216 L .53245 .72041 L F
.53282 .72136 m .53245 .72041 L .53142 .72216 L F
.53282 .72136 m .53344 .71933 L .53245 .72041 L F
.71 .667 .806 r
.67509 .43003 m .67617 .43483 L .67257 .43413 L F
.722 .628 .752 r
.67848 .43394 m .67617 .43483 L .6786 .43195 L F
.598 .549 .771 r
.67997 .4382 m .67617 .43483 L .67848 .43394 L F
.744 .692 .802 r
.79434 .50443 m .79757 .50661 L .79666 .50324 L F
.663 .69 .865 r
.79757 .50661 m .79904 .50277 L .79666 .50324 L F
.79757 .50661 m .80061 .50494 L .79904 .50277 L F
.652 .658 .842 r
.79757 .50661 m .8013 .50751 L .80061 .50494 L F
.802 .747 .802 r
.80061 .50494 m .8013 .50751 L .80375 .5046 L F
.998 .777 .446 r
.47489 .66941 m .4738 .66937 L .47375 .66717 L F
.823 1 .817 r
.47639 .66656 m .47489 .66941 L .47804 .66776 L F
.47639 .66656 m .4738 .66937 L .47489 .66941 L F
.454 .882 .805 r
.53302 .72564 m .53435 .72469 L .53222 .72574 L F
.635 .514 .698 r
.68116 .43079 m .67848 .43394 L .6786 .43195 L F
.68116 .43079 m .68183 .43466 L .67848 .43394 L F
.615 .504 .703 r
.6822 .43694 m .67848 .43394 L .68183 .43466 L F
.6822 .43694 m .67997 .4382 L .67848 .43394 L F
.647 .371 .487 r
.61687 .47265 m .62062 .4739 L .61683 .47463 L F
.61687 .47265 m .6206 .47215 L .62062 .4739 L F
0 0 .303 r
.58392 .6121 m .58425 .61111 L .5838 .60624 L F
.737 .901 .517 r
.58276 .61342 m .58425 .61111 L .58392 .6121 L F
.144 0 .336 r
.58093 .61686 m .58276 .61342 L .58134 .61455 L F
.75 .825 .361 r
.58182 .61525 m .58235 .61402 L .58276 .61342 L F
0 0 0 r
.58134 .61455 m .58276 .61342 L .58318 .61281 L F
.75 .825 .361 r
.58235 .61402 m .58275 .6131 L .58276 .61342 L F
0 0 0 r
.58318 .61281 m .58276 .61342 L .58392 .6121 L F
.644 .089 0 r
.54402 .64549 m .54377 .64423 L .54236 .64333 L F
.54402 .64549 m .54605 .64606 L .54377 .64423 L F
.7 .398 .462 r
.6443 .4484 m .64546 .44592 L .6437 .445 L F
.6443 .4484 m .64502 .44812 L .64546 .44592 L F
.595 .3 .437 r
.64546 .44592 m .64502 .44812 L .64747 .44764 L F
.628 .286 .373 r
.64747 .44764 m .64844 .44599 L .64546 .44592 L F
.128 0 0 r
.64629 .43759 m .64771 .43817 L .64912 .43645 L F
.64629 .43759 m .64563 .43904 L .64771 .43817 L F
.425 .492 .825 r
.54363 .64922 m .54471 .65265 L .54651 .65239 L F
.289 .187 .562 r
.54652 .65471 m .54471 .65265 L .54651 .65239 L F
.659 .203 .158 r
.49234 .70552 m .49444 .70761 L .4945 .70596 L F
.44 .022 .149 r
.4945 .70596 m .49444 .70761 L .49702 .70701 L F
.732 .75 .238 r
.49397 .69212 m .49468 .68989 L .49479 .69071 L F
.76 .713 .808 r
.46737 .7196 m .47113 .72022 L .47019 .71694 L F
.789 .516 .525 r
.46737 .7196 m .47029 .72178 L .47113 .72022 L F
.758 .255 .017 r
.47199 .71923 m .47019 .71694 L .47113 .72022 L F
.101 .297 .775 r
.47113 .72022 m .47317 .72149 L .47199 .71923 L F
.058 .23 .726 r
.47113 .72022 m .47199 .71923 L .47019 .71694 L F
.41 .155 .413 r
.36871 .60492 m .3667 .60336 L .36909 .6029 L F
.36871 .60492 m .36618 .60583 L .3667 .60336 L F
.531 .434 .689 r
.49948 .69663 m .50185 .69734 L .5018 .69624 L F
.49948 .69663 m .4997 .6983 L .50185 .69734 L F
.977 .681 .309 r
.6546 .43442 m .65359 .43353 L .65356 .43043 L F
.302 .387 .784 r
.23425 .54682 m .23414 .55048 L .23245 .54862 L F
.23425 .54682 m .23551 .55035 L .23414 .55048 L F
.349 .751 .983 r
.20115 .54278 m .20306 .54257 L .20502 .54346 L F
.514 0 0 r
.20306 .54257 m .20701 .5434 L .20502 .54346 L F
.106 0 .141 r
.49638 .66458 m .49321 .66789 L .49577 .66732 L F
.563 .276 .439 r
.52813 .72272 m .53142 .72216 L .53008 .72334 L F
.64 .627 .821 r
.68317 .44033 m .67997 .4382 L .6822 .43694 L F
.684 .551 .697 r
.6822 .43694 m .68552 .43905 L .68317 .44033 L F
.269 .088 .442 r
.68552 .43905 m .68341 .44272 L .68317 .44033 L F
.748 .784 .883 r
.63072 .42198 m .62687 .42185 L .62936 .41903 L F
.754 .715 .816 r
.63293 .41956 m .63072 .42198 L .62936 .41903 L F
.006 0 0 r
.65973 .45787 m .65926 .459 L .65664 .46011 L F
.455 0 0 r
.66231 .45872 m .65926 .459 L .65973 .45787 L F
.466 .127 .306 r
.66206 .45709 m .66231 .45872 L .65973 .45787 L F
0 .012 .585 r
.55539 .66031 m .55675 .66314 L .55451 .66003 L F
.356 .213 .545 r
.21338 .56857 m .21516 .56806 L .2149 .56509 L F
.436 .334 .64 r
.21357 .57107 m .21516 .56806 L .21338 .56857 L F
.6 .414 .602 r
.49694 .71419 m .49726 .71671 L .49488 .71647 L F
.49694 .71419 m .49726 .71671 L .49488 .71647 L F
0 0 0 r
.49931 .7101 m .49828 .71296 L .49694 .71419 L F
.49828 .71296 m .49726 .71671 L .49694 .71419 L F
0 .343 .694 r
.21114 .54401 m .21283 .54468 L .21452 .54545 L F
.46 .821 .995 r
.21283 .54468 m .21669 .54495 L .21452 .54545 L F
0 0 .481 r
.56841 .63959 m .56893 .64101 L .56782 .6387 L F
.639 .425 .577 r
.56893 .64101 m .56831 .64429 L .56666 .64401 L F
0 0 0 r
.56879 .64247 m .56893 .64101 L .57021 .63977 L F
.56879 .64247 m .56831 .64429 L .56893 .64101 L F
.357 .771 .98 r
.39969 .57945 m .40347 .57994 L .40117 .58019 L F
.506 .448 .725 r
.4997 .6983 m .50046 .70212 L .50241 .70081 L F
.342 .185 .518 r
.22367 .60311 m .22356 .60548 L .2219 .60599 L F
.452 .308 .594 r
.22402 .60793 m .2219 .60599 L .22356 .60548 L F
.22402 .60793 m .22203 .60923 L .2219 .60599 L F
.695 .607 .753 r
.59084 .47496 m .58733 .47259 L .58996 .47209 L F
.565 .802 .988 r
.42063 .61739 m .41862 .61814 L .41817 .62027 L F
.888 .867 .812 r
.19726 .59164 m .19318 .59402 L .1956 .59294 L F
.391 .19 .483 r
.19943 .58871 m .19726 .59164 L .19959 .5889 L F
.176 0 0 r
.19726 .59164 m .19806 .59226 L .19959 .5889 L F
.19726 .59164 m .1956 .59294 L .19806 .59226 L F
.605 .815 .981 r
.77122 .48553 m .77215 .48669 L .76879 .48628 L F
.128 .674 .705 r
.77122 .48553 m .77531 .48483 L .77215 .48669 L F
.378 .327 .674 r
.20986 .57727 m .21133 .57923 L .21095 .57641 L F
.468 .294 .561 r
.54705 .6876 m .54824 .68767 L .54827 .68462 L F
.563 .385 .598 r
.54824 .68767 m .55129 .68363 L .54827 .68462 L F
.43 .744 .993 r
.45984 .68209 m .46229 .682 L .46074 .68082 L F
.44 .809 .994 r
.19939 .57354 m .19966 .57237 L .20147 .57317 L F
.20147 .57317 m .19966 .57237 L .19939 .57354 L F
.604 .337 .485 r
.6206 .47215 m .62295 .47417 L .62062 .4739 L F
.678 .301 .325 r
.6228 .47266 m .62295 .47417 L .6206 .47215 L F
.331 0 0 r
.44482 .62622 m .44356 .62673 L .44114 .62659 L F
.381 0 0 r
.44701 .62683 m .44356 .62673 L .44482 .62622 L F
.744 .56 .645 r
.80367 .4946 m .80533 .49203 L .80563 .49271 L F
.895 .865 .802 r
.57761 .60159 m .57615 .59928 L .57544 .59988 L F
.922 .539 .14 r
.5781 .60255 m .57694 .60162 L .57615 .59928 L F
.903 .55 .361 r
.57615 .59928 m .57694 .60162 L .57508 .6008 L F
0 0 0 r
.57508 .6008 m .57771 .59795 L .57615 .59928 L F
.57771 .59795 m .5781 .59753 L .57615 .59928 L F
.895 .865 .802 r
.57544 .59988 m .57615 .59928 L .57448 .59913 L F
.48 .031 .106 r
.35541 .58672 m .35915 .58511 L .35696 .58512 L F
.799 .405 .309 r
.46157 .70189 m .46291 .70024 L .46002 .69923 L F
.46157 .70189 m .46564 .70198 L .46291 .70024 L F
.807 .551 .552 r
.46772 .71596 m .47058 .71421 L .47089 .71301 L F
.46772 .71596 m .47019 .71694 L .47058 .71421 L F
.994 .868 .545 r
.56035 .67782 m .55965 .68161 L .56041 .68227 L F
.94 .957 .747 r
.55965 .68161 m .55841 .68346 L .56041 .68227 L F
.624 .775 .953 r
.425 .57899 m .42134 .57781 L .42347 .57688 L F
.584 .762 .963 r
.42566 .57671 m .425 .57899 L .42347 .57688 L F
.42566 .57671 m .42807 .57852 L .425 .57899 L F
.28 0 0 r
.41259 .63251 m .41111 .63412 L .40883 .63448 L F
.484 .059 .157 r
.41491 .63217 m .41111 .63412 L .41259 .63251 L F
.416 .193 .464 r
.52335 .68218 m .52324 .68444 L .5213 .68474 L F
.474 .353 .635 r
.52324 .68444 m .52105 .68734 L .5213 .68474 L F
.573 .17 .24 r
.62647 .47229 m .62988 .47199 L .62908 .47379 L F
.587 .248 .362 r
.62988 .47199 m .63142 .47418 L .62908 .47379 L F
.62988 .47199 m .63253 .4719 L .63142 .47418 L F
.229 0 .064 r
.49552 .71822 m .49488 .71647 L .49726 .71671 L F
.49552 .71822 m .49334 .71888 L .49488 .71647 L F
.727 .621 .739 r
.80327 .48968 m .80652 .48729 L .8041 .48573 L F
.392 0 0 r
.40663 .6208 m .40911 .62095 L .41017 .62039 L F
.789 .377 .27 r
.40911 .62095 m .41092 .62213 L .41017 .62039 L F
.623 .262 .337 r
.6228 .47266 m .62647 .47229 L .62558 .47447 L F
.56 .197 .31 r
.62558 .47447 m .62647 .47229 L .62908 .47379 L F
0 .56 .749 r
.5047 .73708 m .50833 .73743 L .5072 .73727 L F
.545 .888 .645 r
.50833 .73743 m .51007 .73594 L .50939 .73632 L F
.532 .916 .929 r
.5072 .73727 m .50833 .73743 L .50939 .73632 L F
.617 .894 .584 r
.19869 .59777 m .19614 .6005 L .19716 .59924 L F
.08 .015 .475 r
.19616 .60294 m .19716 .59924 L .19614 .6005 L F
.422 .707 .982 r
.46734 .70244 m .46564 .70198 L .46584 .70194 L F
.947 .664 .469 r
.46562 .70442 m .46734 .70244 L .46584 .70194 L F
.701 .211 .079 r
.51908 .68145 m .52175 .68342 L .52335 .68218 L F
.926 .971 .756 r
.52521 .67854 m .52335 .68218 L .5226 .68011 L F
.965 .92 .582 r
.52335 .68218 m .52175 .68342 L .5226 .68011 L F
.695 .613 .76 r
.5264 .68167 m .52335 .68218 L .52521 .67854 L F
.516 .206 .379 r
.5264 .68167 m .52324 .68444 L .52335 .68218 L F
.998 .819 .538 r
.3446 .62673 m .34396 .62959 L .34295 .62832 L F
.897 .966 .824 r
.53824 .7186 m .53868 .72037 L .54051 .71813 L F
.908 .957 .812 r
.53824 .7186 m .54051 .71813 L .54175 .71598 L F
.999 .791 .485 r
.6546 .43442 m .65421 .43836 L .65359 .43353 L F
.577 .377 .573 r
.65556 .43589 m .65421 .43836 L .6546 .43442 L F
.999 .791 .485 r
.6546 .43442 m .65421 .43836 L .65359 .43353 L F
.264 .769 .865 r
.17954 .54226 m .18175 .5419 L .18346 .54195 L F
.31 .773 .944 r
.18175 .5419 m .18544 .54207 L .18346 .54195 L F
.247 .086 .455 r
.58871 .46861 m .59123 .46543 L .58976 .4673 L F
.533 .48 .743 r
.50489 .70855 m .50576 .7117 L .50792 .71069 L F
.447 .289 .573 r
.50576 .7117 m .50789 .71326 L .50792 .71069 L F
.336 0 0 r
.5429 .65718 m .54172 .65591 L .54199 .65807 L F
.169 0 .002 r
.54172 .65591 m .5429 .65718 L .54199 .65807 L F
.747 .506 .566 r
.6281 .4284 m .62631 .42437 L .62731 .42595 L F
.042 .611 .75 r
.46584 .70194 m .46564 .70198 L .46157 .70189 L F
.777 .61 .672 r
.80652 .48729 m .80423 .48376 L .8041 .48573 L F
.33 .8 .923 r
.40568 .57925 m .40936 .57912 L .40707 .57961 L F
.988 .76 .504 r
.5901 .61708 m .59116 .62038 L .59134 .61795 L F
.506 .448 .725 r
.4997 .6983 m .50241 .70081 L .50185 .69734 L F
.351 0 .095 r
.42087 .63018 m .42264 .63092 L .42037 .63126 L F
0 0 0 r
.63773 .44182 m .64045 .44019 L .63816 .44017 L F
.802 .747 .802 r
.80061 .50494 m .80375 .5046 L .80267 .50347 L F
.876 .882 .835 r
.80267 .50347 m .80375 .5046 L .80613 .50168 L F
.751 .248 .022 r
.59057 .60475 m .59107 .60351 L .58772 .60208 L F
.913 .518 .127 r
.59057 .60475 m .59185 .60565 L .59107 .60351 L F
0 0 0 r
.20809 .56114 m .20985 .56016 L .20913 .56088 L F
.572 .464 .693 r
.19716 .59924 m .19899 .59584 L .19869 .59777 L F
.488 .849 .6 r
.53642 .67097 m .53829 .66937 L .53845 .67027 L F
.655 .956 .942 r
.54835 .60335 m .54638 .60465 L .54448 .60514 L F
.601 .895 .988 r
.42106 .58378 m .42037 .58532 L .42255 .58456 L F
.42106 .58378 m .41884 .58466 L .42037 .58532 L F
.605 .586 .805 r
.55484 .68064 m .55212 .67905 L .55377 .67839 L F
.057 .071 .558 r
.49339 .71087 m .49465 .71008 L .49444 .70761 L F
.585 .524 .753 r
.49321 .71347 m .49465 .71008 L .49339 .71087 L F
.818 .703 .739 r
.59809 .64968 m .59912 .65295 L .60141 .64997 L F
.248 .757 .869 r
.40936 .57912 m .41162 .57879 L .41301 .57893 L F
.5 .855 .991 r
.41162 .57879 m .41542 .57878 L .41301 .57893 L F
.762 .681 .773 r
.66731 .42625 m .66873 .42925 L .66583 .42805 L F
.866 .713 .69 r
.66873 .42925 m .66603 .43051 L .66583 .42805 L F
.597 .642 .866 r
.67087 .42692 m .66873 .42925 L .66731 .42625 L F
.67087 .42692 m .6716 .42862 L .66873 .42925 L F
.534 .599 .865 r
.67177 .43033 m .66873 .42925 L .6716 .42862 L F
.814 .855 .879 r
.63287 .42369 m .63086 .42523 L .63415 .42522 L F
.804 .866 .894 r
.63086 .42523 m .63201 .42641 L .63415 .42522 L F
.837 .859 .861 r
.63287 .42369 m .63415 .42522 L .63655 .42243 L F
.546 .926 .81 r
.5257 .70762 m .5247 .70778 L .52369 .70876 L F
.945 .654 .457 r
.67209 .44016 m .67069 .44158 L .67064 .43931 L F
.67209 .44016 m .67214 .44254 L .67069 .44158 L F
.262 .083 .439 r
.22551 .59995 m .22367 .60311 L .22343 .60054 L F
.586 .442 .652 r
.5319 .65017 m .53462 .64984 L .53423 .64731 L F
.631 .49 .672 r
.5322 .6532 m .53462 .64984 L .5319 .65017 L F
.53462 .64984 m .5322 .6532 L .5319 .65017 L F
.173 0 .316 r
.2276 .59688 m .22551 .59995 L .22575 .59755 L F
.496 .355 .619 r
.33442 .59715 m .33646 .59403 L .33441 .59465 L F
.876 .882 .835 r
.80267 .50347 m .80613 .50168 L .80505 .50049 L F
.87 .883 .842 r
.80505 .50049 m .80613 .50168 L .8086 .49868 L F
.3 .033 .331 r
.47105 .71044 m .471 .70868 L .47533 .70497 L F
.588 .384 .572 r
.52585 .7202 m .52813 .72272 L .52855 .71968 L F
.723 .936 .611 r
.53693 .72202 m .53868 .72037 L .53824 .7186 L F
.53693 .72202 m .53734 .72186 L .53868 .72037 L F
.174 0 0 r
.45062 .62699 m .44907 .62727 L .44701 .62683 L F
.558 0 0 r
.45062 .62699 m .45302 .62852 L .44907 .62727 L F
.833 .365 0 r
.5796 .62382 m .57885 .62429 L .57881 .62422 L F
.01 0 0 r
.57745 .62411 m .57994 .62365 L .5796 .62382 L F
.833 .365 0 r
.5796 .62382 m .57705 .62303 L .57745 .62411 L F
.5796 .62382 m .57881 .62422 L .57843 .62342 L F
.01 0 0 r
.57994 .62365 m .5809 .62348 L .5796 .62382 L F
.823 .347 .057 r
.5809 .62348 m .58113 .62527 L .5796 .62382 L F
.5809 .62348 m .58282 .62601 L .58113 .62527 L F
.927 .707 .584 r
.59116 .62038 m .59113 .62346 L .59272 .62376 L F
.982 .719 .45 r
.59148 .62535 m .59272 .62376 L .59113 .62346 L F
.59148 .62535 m .59276 .62622 L .59272 .62376 L F
.888 .627 .537 r
.59217 .63998 m .59573 .63892 L .59411 .63804 L F
.59217 .63998 m .59576 .64195 L .59573 .63892 L F
.914 .65 .524 r
.59573 .63892 m .59576 .64195 L .59662 .64115 L F
.36 .023 .253 r
.64094 .4719 m .64404 .46904 L .64372 .47147 L F
.416 .029 .195 r
.64404 .46904 m .64579 .47052 L .64372 .47147 L F
.64404 .46904 m .6465 .46861 L .64579 .47052 L F
.24 .73 .922 r
.41542 .57878 m .41751 .57866 L .41854 .5791 L F
.64 .943 .958 r
.41854 .5791 m .4193 .57765 L .42134 .57781 L F
.41854 .5791 m .41751 .57866 L .4193 .57765 L F
.411 0 .026 r
.36739 .58434 m .36969 .5843 L .37125 .58262 L F
.34 0 .036 r
.36969 .5843 m .37344 .58212 L .37125 .58262 L F
.706 .503 .611 r
.46515 .69386 m .46562 .6964 L .46864 .69383 L F
.487 .743 .985 r
.43215 .5775 m .43152 .57928 L .42952 .57792 L F
.43215 .5775 m .43358 .5788 L .43152 .57928 L F
.239 .313 .739 r
.46133 .70504 m .46231 .70873 L .46142 .70653 L F
.152 .298 .76 r
.46231 .70873 m .46337 .70732 L .46142 .70653 L F
.46231 .70873 m .46453 .7107 L .46337 .70732 L F
.892 .786 .737 r
.61903 .43739 m .61875 .43914 L .61579 .4395 L F
.885 .832 .789 r
.61875 .43914 m .61634 .44253 L .61579 .4395 L F
.574 .397 .603 r
.53626 .68494 m .53449 .68812 L .5369 .68741 L F
.233 0 0 r
.4544 .62929 m .45508 .62969 L .45302 .62852 L F
.4544 .62929 m .45669 .62987 L .45508 .62969 L F
.573 .915 .968 r
.20188 .55489 m .20153 .5561 L .20393 .55566 L F
.20188 .55489 m .19979 .55581 L .20153 .5561 L F
.769 .695 .781 r
.53755 .69331 m .53519 .69622 L .53876 .69645 L F
.578 .519 .752 r
.53876 .69645 m .5399 .693 L .53755 .69331 L F
.53876 .69645 m .54081 .69609 L .5399 .693 L F
.759 .518 .569 r
.54317 .6062 m .53995 .60847 L .54297 .60521 L F
.54317 .6062 m .5426 .60856 L .53995 .60847 L F
.419 .641 .949 r
.54464 .60498 m .54317 .6062 L .54297 .60521 L F
.469 .834 .581 r
.54317 .6062 m .54448 .60514 L .54464 .60498 L F
.218 .013 .373 r
.54476 .60752 m .54317 .6062 L .54464 .60498 L F
.54393 .60683 m .54339 .60753 L .54317 .6062 L F
.54339 .60753 m .5426 .60856 L .54285 .60753 L F
.54339 .60753 m .54285 .60753 L .54317 .6062 L F
.228 .234 .658 r
.54297 .60521 m .54359 .60753 L .54476 .60752 L F
.54359 .60753 m .54367 .60781 L .54476 .60752 L F
.218 .013 .373 r
.54324 .60825 m .5426 .60856 L .54352 .60736 L F
.54344 .60785 m .54352 .60736 L .54393 .60683 L F
.54324 .60825 m .54352 .60736 L .54344 .60785 L F
.766 .64 .722 r
.53995 .60847 m .5426 .60856 L .5411 .61071 L F
.715 .359 .373 r
.53995 .60847 m .5426 .60856 L .54263 .61096 L F
.194 0 .326 r
.54263 .61096 m .5426 .60856 L .54338 .60819 L F
.647 .386 .51 r
.54263 .61096 m .5432 .60922 L .54311 .6092 L F
.5432 .60922 m .54367 .60781 L .54344 .60785 L F
.5432 .60922 m .54344 .60785 L .53995 .60847 L F
.118 0 .264 r
.54476 .60752 m .54367 .60781 L .54263 .61096 L F
.194 0 .326 r
.54263 .61096 m .54338 .60819 L .54476 .60752 L F
.647 .386 .51 r
.54263 .61096 m .54311 .6092 L .53995 .60847 L F
.691 .528 .661 r
.53995 .60847 m .54344 .60785 L .54297 .60521 L F
.54344 .60785 m .54367 .60781 L .54359 .60753 L F
.54344 .60785 m .54359 .60753 L .54297 .60521 L F
.218 .013 .373 r
.54476 .60752 m .54324 .60825 L .54393 .60683 L F
0 0 0 r
.2051 .64391 m .20388 .6464 L .20318 .64706 L F
0 0 .232 r
.20388 .6464 m .20282 .64946 L .20318 .64706 L F
.874 .882 .837 r
.50789 .71326 m .50937 .71417 L .5117 .71115 L F
.615 .162 .153 r
.4955 .6849 m .49784 .68639 L .49948 .68441 L F
.557 .351 .557 r
.49948 .68441 m .49955 .6876 L .49711 .68781 L F
.759 .842 .914 r
.502 .68245 m .49714 .68421 L .49948 .68441 L F
.502 .68245 m .49948 .68441 L .50178 .68262 L F
.73 .488 .561 r
.50341 .68688 m .49955 .6876 L .49948 .68441 L F
.6 .296 .426 r
.49784 .68639 m .50178 .68262 L .49948 .68441 L F
.499 .302 .543 r
.46452 .67619 m .46686 .67599 L .46686 .67324 L F
.46452 .67619 m .46686 .67599 L .46686 .67324 L F
.651 .811 .96 r
.44823 .58908 m .44842 .58996 L .44877 .58807 L F
.053 0 .435 r
.44842 .58996 m .44994 .59022 L .45117 .58949 L F
.44842 .58996 m .44828 .59198 L .44994 .59022 L F
.53 .492 .759 r
.33327 .61869 m .33578 .61811 L .33483 .61581 L F
.75 .514 .573 r
.55046 .60217 m .55421 .60043 L .55064 .59997 L F
.55046 .60217 m .55422 .60287 L .55421 .60043 L F
0 0 .082 r
.59298 .60998 m .59274 .60912 L .59245 .6083 L F
.59298 .60998 m .59269 .61169 L .59274 .60912 L F
.76 .576 .647 r
.51918 .71714 m .51526 .7173 L .51516 .71399 L F
.263 .737 .939 r
.51876 .71939 m .51526 .7173 L .51918 .71714 L F
.364 .134 .426 r
.52111 .71644 m .51876 .71939 L .51918 .71714 L F
.882 .877 .825 r
.55932 .60142 m .56068 .60076 L .56147 .59863 L F
.533 .48 .743 r
.50489 .70855 m .50792 .71069 L .50782 .70862 L F
.727 .279 0 r
.62688 .44298 m .62841 .44499 L .62608 .44308 L F
.179 0 0 r
.38643 .63835 m .38479 .6393 L .3826 .63947 L F
.57 .108 .117 r
.38864 .63828 m .38479 .6393 L .38643 .63835 L F
.496 .592 .879 r
.36828 .61635 m .37006 .61945 L .36682 .6183 L F
.088 .625 .857 r
.18544 .54207 m .1875 .5422 L .18945 .54272 L F
.183 0 0 r
.1875 .5422 m .19155 .54244 L .18945 .54272 L F
.662 .647 .824 r
.4361 .58779 m .4395 .58902 L .43817 .58733 L F
.38 .617 .944 r
.43817 .58733 m .4395 .58902 L .44041 .58703 L F
.718 .467 .545 r
.60346 .47411 m .59908 .47202 L .60344 .472 L F
.706 .515 .628 r
.605 .47203 m .60346 .47411 L .60344 .472 L F
.352 .142 .448 r
.20809 .63937 m .20697 .63813 L .20858 .63678 L F
.20809 .63937 m .20649 .64077 L .20697 .63813 L F
.734 .741 .857 r
.68116 .43079 m .6786 .43195 L .67699 .43068 L F
0 0 0 r
.59576 .64195 m .59515 .6426 L .59662 .64115 L F
.889 .571 .442 r
.59515 .6426 m .597 .64385 L .59662 .64115 L F
.033 .575 .844 r
.39219 .58016 m .39354 .58026 L .39531 .58086 L F
.164 0 0 r
.39354 .58026 m .39222 .58087 L .39484 .58035 L F
.029 0 0 r
.39354 .58026 m .39748 .57994 L .39531 .58086 L F
.164 0 0 r
.39354 .58026 m .39484 .58035 L .39565 .58019 L F
.033 .575 .844 r
.39137 .57998 m .39354 .58026 L .39219 .58016 L F
.624 .665 .869 r
.45615 .59754 m .45963 .59914 L .45841 .59721 L F
.787 .79 .855 r
.45841 .59721 m .45963 .59914 L .46271 .5969 L F
.671 .559 .719 r
.18994 .58664 m .19079 .58578 L .18976 .58584 L F
.436 .276 .565 r
.18994 .58664 m .19153 .58629 L .19079 .58578 L F
.18994 .58664 m .19098 .58811 L .19153 .58629 L F
.646 .732 .912 r
.55046 .60217 m .552 .60382 L .55422 .60287 L F
0 0 0 r
.47407 .61636 m .47805 .61482 L .47617 .61531 L F
0 .057 .622 r
.6644 .43943 m .66349 .43828 L .6628 .43624 L F
.623 .262 .337 r
.6228 .47266 m .62558 .47447 L .62295 .47417 L F
.191 0 0 r
.37081 .64021 m .36677 .63804 L .36889 .63999 L F
0 0 .066 r
.54591 .6953 m .54646 .69337 L .54655 .69315 L F
0 0 .003 r
.65063 .44347 m .64844 .44599 L .64999 .44494 L F
0 0 0 r
.64999 .44494 m .64844 .44599 L .64747 .44764 L F
0 0 .47 r
.54251 .66105 m .54256 .65994 L .54086 .66229 L F
.82 .479 0 r
.54256 .65994 m .54338 .66147 L .54258 .65951 L F
0 0 .47 r
.54329 .66046 m .54256 .65994 L .54251 .66105 L F
.82 .479 0 r
.54256 .65994 m .54258 .65951 L .54199 .65807 L F
.388 0 0 r
.54417 .66264 m .54338 .66147 L .54256 .65994 L F
.407 .661 .963 r
.22076 .54392 m .2203 .5455 L .21878 .54394 L F
.22076 .54392 m .22224 .54545 L .2203 .5455 L F
.516 .206 .379 r
.5264 .68167 m .52575 .68412 L .52324 .68444 L F
.5 .192 .375 r
.52887 .68139 m .52575 .68412 L .5264 .68167 L F
.499 .152 .31 r
.64027 .47139 m .64094 .4719 L .63844 .4717 L F
.616 .462 .65 r
.51284 .71707 m .51526 .7173 L .51516 .71399 L F
.597 .28 .403 r
.51284 .71707 m .51517 .71899 L .51526 .7173 L F
.616 .462 .65 r
.51516 .71399 m .51526 .7173 L .51284 .71707 L F
.597 .28 .403 r
.51284 .71707 m .51517 .71899 L .51526 .7173 L F
.616 .462 .65 r
.51284 .71707 m .51526 .7173 L .51516 .71399 L F
.167 0 0 r
.51854 .68841 m .51752 .68989 L .51566 .68999 L F
.468 0 .06 r
.52048 .68939 m .51752 .68989 L .51854 .68841 L F
.438 .07 .241 r
.52105 .68734 m .52048 .68939 L .51854 .68841 L F
.437 .713 .982 r
.43516 .57921 m .43437 .58059 L .43358 .5788 L F
.43516 .57921 m .43654 .58045 L .43437 .58059 L F
.455 .295 .574 r
.23188 .5858 m .2319 .58836 L .22981 .58857 L F
0 0 .014 r
.2319 .58836 m .22966 .59111 L .22981 .58857 L F
.462 .228 .472 r
.54705 .6876 m .5482 .6898 L .54824 .68767 L F
.54705 .6876 m .5482 .6898 L .54824 .68767 L F
.754 .802 .892 r
.80273 .4992 m .79863 .49878 L .80136 .49806 L F
.833 .653 .659 r
.80312 .49902 m .80273 .4992 L .80136 .49806 L F
.80312 .49902 m .8053 .4979 L .80273 .4992 L F
0 0 0 r
.5257 .70762 m .52696 .70701 L .5247 .70778 L F
.87 .883 .842 r
.80505 .50049 m .8086 .49868 L .80672 .49733 L F
.722 .617 .74 r
.67177 .43033 m .67257 .43413 L .67008 .43443 L F
.715 .561 .678 r
.67008 .43443 m .67257 .43413 L .67029 .43699 L F
.716 .317 .291 r
.37344 .58212 m .37571 .58439 L .37719 .58242 L F
.278 0 .021 r
.37571 .58439 m .37951 .58184 L .37719 .58242 L F
.441 .291 .581 r
.19943 .58871 m .20129 .58815 L .20161 .58476 L F
.451 .292 .574 r
.19959 .5889 m .20129 .58815 L .19943 .58871 L F
.487 .354 .625 r
.33256 .60015 m .33463 .59959 L .33442 .59715 L F
.495 .379 .651 r
.33256 .60015 m .33495 .60241 L .33463 .59959 L F
.33256 .60015 m .33269 .60346 L .33495 .60241 L F
.149 0 0 r
.41444 .58624 m .41285 .58736 L .41055 .58777 L F
0 0 0 r
.41497 .58594 m .41444 .58624 L .41692 .58597 L F
.41497 .58594 m .41285 .58736 L .41444 .58624 L F
.834 .939 .895 r
.58816 .46901 m .58785 .47038 L .58692 .46955 L F
.811 .842 .378 r
.58871 .46861 m .58737 .47246 L .58785 .47038 L F
.047 0 0 r
.58871 .46861 m .58785 .47038 L .591 .46778 L F
.834 .939 .895 r
.591 .46778 m .58785 .47038 L .58816 .46901 L F
.811 .842 .378 r
.58737 .47246 m .58733 .47259 L .58785 .47038 L F
.247 .086 .455 r
.58871 .46861 m .591 .46778 L .59123 .46543 L F
.712 .581 .706 r
.53803 .69062 m .5399 .693 L .53974 .69047 L F
.234 .288 .715 r
.4725 .6846 m .47307 .68777 L .47462 .68625 L F
.479 .693 .962 r
.47307 .68777 m .47555 .68775 L .47462 .68625 L F
.801 .401 .294 r
.4767 .69055 m .47307 .68777 L .47348 .69119 L F
0 0 0 r
.51509 .70679 m .51381 .70806 L .51601 .70515 L F
.51509 .70679 m .51601 .70515 L .51184 .7046 L F
.708 .862 .955 r
.4419 .5892 m .44543 .58946 L .44394 .58803 L F
.559 .749 .966 r
.44543 .58946 m .44628 .58733 L .44394 .58803 L F
.44543 .58946 m .44823 .58908 L .44628 .58733 L F
.406 .299 .62 r
.23501 .57366 m .23534 .57601 L .23358 .57671 L F
.5 .443 .724 r
.23534 .57601 m .23392 .57997 L .23358 .57671 L F
.851 .461 0 r
.52042 .72237 m .51969 .72182 L .51876 .71939 L F
0 0 0 r
.51793 .72546 m .51969 .72182 L .52042 .72237 L F
.851 .461 0 r
.52042 .72237 m .51969 .72182 L .51876 .71939 L F
.846 .422 .225 r
.51969 .72182 m .52206 .72305 L .52042 .72237 L F
.454 .36 .659 r
.68294 .44489 m .68178 .44878 L .68169 .44593 L F
.286 .775 .904 r
.52274 .65496 m .52091 .65534 L .51897 .65509 L F
.656 .612 .793 r
.52274 .65496 m .52276 .65764 L .52091 .65534 L F
.77 .425 .401 r
.52581 .69306 m .52874 .69622 L .52932 .69403 L F
.545 .212 .354 r
.42833 .61841 m .42424 .62055 L .42645 .62213 L F
.434 .078 .26 r
.37509 .59987 m .37387 .60239 L .37148 .60276 L F
.311 0 .111 r
.37739 .59969 m .37387 .60239 L .37509 .59987 L F
.044 .508 .887 r
.2304 .54725 m .23 .54788 L .22828 .54699 L F
.2304 .54725 m .23245 .54862 L .23 .54788 L F
.722 .972 .93 r
.5437 .71285 m .54302 .71446 L .54233 .71384 L F
.765 .959 .652 r
.5437 .71285 m .54138 .71583 L .54302 .71446 L F
.72 .616 .74 r
.58733 .47259 m .58904 .47553 L .58494 .475 L F
.728 .544 .642 r
.58904 .47553 m .58479 .47755 L .58494 .475 L F
.58904 .47553 m .58698 .47742 L .58479 .47755 L F
.695 .607 .753 r
.59084 .47496 m .58904 .47553 L .58733 .47259 L F
.653 .437 .579 r
.59084 .47496 m .58698 .47742 L .58904 .47553 L F
.474 .353 .635 r
.52324 .68444 m .52304 .68777 L .52105 .68734 L F
.305 0 .196 r
.52228 .68885 m .52105 .68734 L .52304 .68777 L F
.52228 .68885 m .52048 .68939 L .52105 .68734 L F
.255 0 .249 r
.24011 .56521 m .23899 .56772 L .23718 .56832 L F
.8 .397 0 r
.23891 .56345 m .24011 .56521 L .2382 .56183 L F
.409 .381 .717 r
.24001 .56376 m .24011 .56521 L .23891 .56345 L F
.24001 .56376 m .23899 .56772 L .24011 .56521 L F
.558 .838 .997 r
.35298 .63117 m .35025 .63164 L .35228 .63246 L F
.028 .165 .672 r
.35228 .63246 m .35381 .63424 L .35298 .63117 L F
.558 .838 .997 r
.35298 .63117 m .35025 .63164 L .35228 .63246 L F
.685 .771 .916 r
.54373 .70783 m .54732 .70818 L .54637 .70665 L F
.54373 .70783 m .54732 .70818 L .54637 .70665 L F
.475 .277 .531 r
.54637 .70665 m .54854 .707 L .54732 .70818 L F
.314 .563 .926 r
.54637 .70665 m .54732 .70818 L .54854 .707 L F
.256 0 0 r
.19979 .55581 m .19619 .55504 L .19816 .55711 L F
.19935 .55572 m .19812 .55557 L .19619 .55504 L F
.19979 .55581 m .19812 .55557 L .19935 .55572 L F
.436 0 0 r
.19812 .55557 m .1972 .55528 L .19619 .55504 L F
.487 .672 .946 r
.19535 .55697 m .19816 .55711 L .19619 .55504 L F
.141 .257 .724 r
.1943 .55321 m .19471 .55469 L .19619 .55504 L F
0 .391 .699 r
.19619 .55504 m .19301 .55395 L .1943 .55321 L F
.436 0 0 r
.1972 .55528 m .19412 .55432 L .19619 .55504 L F
.141 .257 .724 r
.19471 .55469 m .19535 .55697 L .19619 .55504 L F
.436 0 0 r
.19812 .55557 m .19779 .55553 L .19412 .55432 L F
0 .391 .699 r
.19619 .55504 m .19412 .55432 L .19326 .55404 L F
.436 0 0 r
.19779 .55553 m .19596 .55534 L .19412 .55432 L F
0 .391 .699 r
.19326 .55404 m .19412 .55432 L .19301 .55395 L F
.337 0 0 r
.20013 .55508 m .19615 .55533 L .19812 .55557 L F
.19615 .55533 m .19596 .55534 L .19812 .55557 L F
.5 .443 .724 r
.23534 .57601 m .2357 .5794 L .23392 .57997 L F
.415 .24 .533 r
.23559 .58169 m .23392 .57997 L .2357 .5794 L F
.23559 .58169 m .23378 .58242 L .23392 .57997 L F
.457 .286 .56 r
.2149 .56509 m .21701 .56711 L .21563 .56352 L F
.2149 .56509 m .21516 .56806 L .21701 .56711 L F
.706 .515 .628 r
.60838 .47423 m .605 .47203 L .60712 .47173 L F
.599 .332 .484 r
.61094 .47219 m .60838 .47423 L .60712 .47173 L F
.455 .155 .366 r
.51607 .65807 m .51475 .65629 L .51422 .65829 L F
.51607 .65807 m .51722 .6558 L .51475 .65629 L F
.539 .797 .993 r
.35381 .63424 m .35532 .63533 L .35641 .63382 L F
.379 .574 .915 r
.35532 .63533 m .35722 .63541 L .35641 .63382 L F
.815 .673 .705 r
.59313 .65787 m .5967 .6577 L .59679 .65583 L F
.81 .749 .796 r
.59505 .65955 m .5967 .6577 L .59313 .65787 L F
.742 .734 .845 r
.79165 .50688 m .79296 .5029 L .79042 .50524 L F
.79165 .50688 m .79434 .50443 L .79296 .5029 L F
.861 .804 .793 r
.6109 .44511 m .61132 .44843 L .60849 .44878 L F
.861 .803 .792 r
.61132 .44843 m .60928 .45143 L .60849 .44878 L F
.796 .762 .822 r
.61403 .44557 m .61132 .44843 L .6109 .44511 L F
.599 .332 .484 r
.61094 .47219 m .61098 .47424 L .60838 .47423 L F
.853 .693 .682 r
.62942 .43372 m .62804 .43672 L .63093 .43741 L F
.754 .651 .748 r
.62942 .43372 m .63093 .43741 L .63313 .43419 L F
.389 .203 .504 r
.21753 .61769 m .21732 .62019 L .21554 .62072 L F
.424 .296 .601 r
.21732 .62019 m .21754 .62278 L .21554 .62072 L F
.426 .296 .6 r
.21754 .62278 m .2157 .62364 L .21554 .62072 L F
.815 .673 .705 r
.59313 .65787 m .59679 .65583 L .59526 .65486 L F
.823 .789 .82 r
.59526 .65486 m .59679 .65583 L .59912 .65295 L F
.972 .732 .516 r
.46085 .62579 m .46139 .6286 L .4627 .62661 L F
.799 .631 .674 r
.78085 .48615 m .78416 .48694 L .78273 .48335 L F
.784 .533 .558 r
.78089 .48846 m .78416 .48694 L .78085 .48615 L F
.78089 .48846 m .78445 .4901 L .78416 .48694 L F
.421 .267 .565 r
.78416 .48694 m .78676 .48734 L .78675 .48726 L F
.78416 .48694 m .78445 .4901 L .78676 .48734 L F
.892 .786 .737 r
.61903 .43739 m .61579 .4395 L .61807 .43658 L F
.853 .932 .878 r
.62163 .43486 m .61903 .43739 L .61807 .43658 L F
.433 0 0 r
.39061 .63898 m .38864 .63828 L .39231 .63752 L F
.171 0 0 r
.39461 .63739 m .39061 .63898 L .39231 .63752 L F
.436 .819 .989 r
.47416 .67925 m .47676 .67883 L .47305 .67854 L F
.975 .893 .679 r
.64216 .44356 m .6437 .445 L .64406 .44328 L F
.942 .63 .183 r
.64298 .44635 m .6443 .4484 L .6437 .445 L F
.715 .588 .712 r
.63202 .44492 m .63445 .44232 L .63202 .44292 L F
.445 .169 .398 r
.54001 .67662 m .53745 .67873 L .5373 .67792 L F
.508 .692 .951 r
.4361 .58779 m .43798 .5855 L .43443 .58507 L F
.4361 .58779 m .43817 .58733 L .43798 .5855 L F
.57 .225 .345 r
.66511 .4564 m .66231 .45872 L .66206 .45709 L F
.764 .705 .796 r
.50792 .71069 m .5117 .71115 L .50981 .70868 L F
.874 .882 .837 r
.50789 .71326 m .5117 .71115 L .50792 .71069 L F
.8 .711 .767 r
.50981 .70868 m .5117 .71115 L .51381 .70806 L F
.473 .349 .631 r
.51516 .71399 m .51814 .71605 L .51757 .71355 L F
.51516 .71399 m .51526 .7173 L .51814 .71605 L F
.427 .282 .581 r
.76626 .48712 m .76805 .48912 L .76879 .48628 L F
.76626 .48712 m .76633 .49022 L .76805 .48912 L F
.8 .711 .767 r
.50981 .70868 m .51381 .70806 L .5126 .70832 L F
.572 .94 .841 r
.51509 .70679 m .5126 .70832 L .51381 .70806 L F
.855 .888 .861 r
.56657 .63442 m .57047 .6329 L .56922 .6321 L F
.56657 .63442 m .56787 .63534 L .57047 .6329 L F
.791 .822 .876 r
.57244 .63186 m .56922 .6321 L .57047 .6329 L F
.953 .736 .571 r
.67008 .43443 m .66879 .43613 L .66876 .43411 L F
.67008 .43443 m .67029 .43699 L .66879 .43613 L F
.191 0 .037 r
.49406 .6852 m .49305 .68654 L .4955 .6849 L F
.5 .368 .633 r
.50983 .66164 m .51199 .66099 L .51181 .65874 L F
.539 .329 .544 r
.50152 .65291 m .50381 .65266 L .50385 .64984 L F
.846 .795 .801 r
.50381 .65266 m .50709 .64947 L .50385 .64984 L F
.663 .424 .548 r
.59908 .47202 m .59922 .47449 L .59539 .47426 L F
.718 .467 .545 r
.60346 .47411 m .59922 .47449 L .59908 .47202 L F
.559 .339 .538 r
.53449 .68812 m .5375 .68943 L .5369 .68741 L F
.53449 .68812 m .5334 .69024 L .5375 .68943 L F
.669 .675 .847 r
.6513 .43636 m .6527 .43992 L .65024 .43909 L F
.734 .497 .57 r
.65273 .44235 m .65024 .43909 L .6527 .43992 L F
.526 .592 .864 r
.65493 .43938 m .6527 .43992 L .6513 .43636 L F
.409 .212 .5 r
.65482 .44145 m .6527 .43992 L .65493 .43938 L F
.65482 .44145 m .65273 .44235 L .6527 .43992 L F
.65482 .44145 m .6527 .43992 L .65493 .43938 L F
.65482 .44145 m .65273 .44235 L .6527 .43992 L F
.461 0 0 r
.46021 .63151 m .46391 .6324 L .46238 .63232 L F
.055 0 0 r
.46391 .6324 m .46414 .63266 L .46238 .63232 L F
.46391 .6324 m .46647 .63228 L .46414 .63266 L F
0 0 0 r
.63773 .44182 m .6396 .44109 L .64045 .44019 L F
.601 .05 0 r
.6396 .44109 m .644 .44229 L .64045 .44019 L F
.568 .301 .471 r
.64045 .44019 m .644 .44229 L .64319 .44006 L F
.258 0 0 r
.5048 .65568 m .50856 .6551 L .50716 .65569 L F
.269 0 0 r
.50856 .6551 m .50911 .65558 L .50716 .65569 L F
.50856 .6551 m .51088 .6556 L .50911 .65558 L F
0 0 0 r
.52043 .6775 m .51863 .67896 L .52166 .67647 L F
.217 .354 .788 r
.52166 .67647 m .52471 .67848 L .52287 .67465 L F
.227 0 0 r
.39924 .63731 m .40079 .63626 L .40259 .63652 L F
.72 .307 0 r
.66191 .43493 m .66168 .43398 L .66071 .43292 L F
.66191 .43493 m .6628 .43624 L .66168 .43398 L F
.826 .787 .815 r
.60849 .44878 m .60928 .45143 L .6077 .45013 L F
.854 .785 .783 r
.60928 .45143 m .60647 .45146 L .6077 .45013 L F
.60928 .45143 m .60714 .45451 L .60647 .45146 L F
.489 .095 .218 r
.51795 .67529 m .52086 .6735 L .5185 .67387 L F
.787 .79 .855 r
.45841 .59721 m .46271 .5969 L .46129 .59572 L F
.313 .175 .527 r
.36618 .60583 m .36452 .60887 L .36417 .60707 L F
.701 .976 .916 r
.55212 .67905 m .55397 .6776 L .554 .6788 L F
.217 0 .191 r
.65427 .46312 m .65664 .46011 L .65636 .46225 L F
.33 .145 .473 r
.65664 .46011 m .65882 .46201 L .65636 .46225 L F
.65664 .46011 m .65926 .459 L .65882 .46201 L F
.179 0 .143 r
.65273 .44235 m .65063 .44347 L .64999 .44494 L F
.715 .675 .81 r
.7822 .50643 m .78588 .50738 L .7846 .50449 L F
.773 .701 .783 r
.7846 .50449 m .78588 .50738 L .78729 .50533 L F
.572 .136 .174 r
.42682 .62935 m .42536 .63115 L .42264 .63092 L F
.474 .053 .16 r
.42918 .62912 m .42536 .63115 L .42682 .62935 L F
.764 .457 .466 r
.57957 .60307 m .57839 .60576 L .5781 .60255 L F
.57957 .60307 m .58194 .60583 L .57839 .60576 L F
.651 .794 .951 r
.36131 .63738 m .36496 .6379 L .36337 .63707 L F
.304 .622 .959 r
.36496 .6379 m .36561 .63668 L .36337 .63707 L F
.36496 .6379 m .36677 .63804 L .36561 .63668 L F
.734 .741 .857 r
.679 .42936 m .67727 .42821 L .67914 .42904 L F
.68116 .43079 m .67699 .43068 L .67727 .42821 L F
.349 0 0 r
.67914 .42904 m .67727 .42821 L .67578 .42774 L F
.805 .786 .835 r
.67897 .42623 m .68183 .42706 L .67914 .42904 L F
.427 .349 .666 r
.68284 .42766 m .67914 .42904 L .68183 .42706 L F
.805 .786 .835 r
.67897 .42623 m .67914 .42904 L .68111 .42812 L F
.207 .7 .921 r
.67929 .42871 m .67914 .42904 L .67715 .42861 L F
.67979 .42874 m .67914 .42904 L .67929 .42871 L F
.734 .741 .857 r
.68116 .43079 m .679 .42936 L .67914 .42904 L F
.427 .349 .666 r
.68284 .42766 m .68116 .43079 L .67914 .42904 L F
.68284 .42766 m .68334 .43026 L .68116 .43079 L F
.628 .581 .782 r
.68334 .43026 m .68183 .43466 L .68116 .43079 L F
.732 .588 .695 r
.56553 .63815 m .56782 .6387 L .56787 .63534 L F
0 0 0 r
.56719 .63681 m .56553 .63815 L .56787 .63534 L F
.959 .623 .309 r
.56657 .63442 m .56719 .63681 L .56787 .63534 L F
.427 .337 .651 r
.56787 .63534 m .56782 .6387 L .57008 .63716 L F
.699 .841 .41 r
.52415 .69621 m .52441 .69547 L .52581 .69306 L F
0 .041 .61 r
.52415 .69621 m .52571 .69823 L .52441 .69547 L F
.245 .208 .617 r
.52473 .69883 m .52571 .69823 L .52415 .69621 L F
.896 .774 .718 r
.55026 .70553 m .54833 .7046 L .54874 .70706 L F
.55026 .70553 m .54833 .7046 L .54874 .70706 L F
.621 .528 .728 r
.33679 .62129 m .33737 .6243 L .33991 .62376 L F
.53 .222 .389 r
.33737 .6243 m .33912 .62573 L .33991 .62376 L F
.33737 .6243 m .33732 .62657 L .33912 .62573 L F
.791 .689 .752 r
.60125 .45699 m .60253 .46048 L .59905 .45993 L F
.775 .681 .76 r
.60479 .45747 m .60253 .46048 L .60125 .45699 L F
.653 .437 .579 r
.59084 .47496 m .59063 .47756 L .58698 .47742 L F
.602 .393 .571 r
.59309 .47703 m .59063 .47756 L .59084 .47496 L F
.674 .378 .464 r
.59334 .47512 m .59309 .47703 L .59084 .47496 L F
.635 .239 .277 r
.53948 .66649 m .5375 .66476 L .54104 .66405 L F
.547 .164 .266 r
.6353 .47245 m .63844 .4717 L .63749 .47388 L F
.565 .166 .244 r
.63844 .4717 m .64058 .47319 L .63749 .47388 L F
.63844 .4717 m .64094 .4719 L .64058 .47319 L F
.611 .174 .186 r
.52367 .72566 m .52232 .72748 L .5203 .72691 L F
.505 .76 .987 r
.5248 .72402 m .526 .72586 L .52367 .72566 L F
.737 .326 .269 r
.52367 .72566 m .52593 .72807 L .52232 .72748 L F
.859 .876 .437 r
.56959 .64816 m .56998 .64625 L .57116 .64734 L F
.684 .187 .06 r
.51806 .65897 m .51665 .66005 L .51422 .65829 L F
.347 0 .041 r
.52276 .65764 m .52017 .65933 L .51806 .65897 L F
.616 .334 .467 r
.51945 .65729 m .52164 .65655 L .51897 .65509 L F
.554 .524 .776 r
.52017 .65933 m .52164 .65655 L .51971 .6572 L F
.52017 .65933 m .51969 .65713 L .51871 .65777 L F
.616 .334 .467 r
.51956 .6578 m .52164 .65655 L .51945 .65729 L F
.554 .524 .776 r
.51971 .6572 m .52164 .65655 L .51969 .65713 L F
.498 .26 .484 r
.51945 .65729 m .51897 .65509 L .5189 .65765 L F
.554 .524 .776 r
.51871 .65777 m .51969 .65713 L .51846 .6575 L F
.498 .26 .484 r
.5189 .65765 m .51897 .65509 L .51691 .65721 L F
.51956 .6578 m .51945 .65729 L .5189 .65765 L F
.753 .948 .626 r
.51841 .65768 m .51806 .65897 L .51871 .65777 L F
.498 .26 .484 r
.51895 .65784 m .51841 .65768 L .51824 .6579 L F
.51956 .6578 m .51691 .65721 L .51895 .65784 L F
.753 .948 .626 r
.51846 .6575 m .51841 .65768 L .51871 .65777 L F
.464 .326 .608 r
.51824 .6579 m .51846 .6575 L .51956 .6578 L F
.498 .26 .484 r
.51824 .6579 m .51691 .65721 L .51607 .65807 L F
.464 .326 .608 r
.51607 .65807 m .51846 .6575 L .51824 .6579 L F
.753 .948 .626 r
.51841 .65768 m .5182 .65796 L .51806 .65897 L F
.5182 .65796 m .51665 .66005 L .51731 .65954 L F
.5182 .65796 m .51731 .65954 L .51806 .65897 L F
.51846 .6575 m .51767 .65862 L .51841 .65768 L F
.51767 .65862 m .51665 .66005 L .51841 .65768 L F
.498 .26 .484 r
.51841 .65768 m .51691 .65721 L .51824 .6579 L F
.753 .948 .626 r
.51871 .65777 m .51806 .65897 L .52017 .65933 L F
0 0 0 r
.57485 .62646 m .57379 .628 L .5726 .62944 L F
.115 .063 .515 r
.57379 .628 m .57244 .63186 L .5726 .62944 L F
.102 .353 .82 r
.46129 .59572 m .45894 .59432 L .45966 .59319 L F
.37 .323 .675 r
.50639 .69093 m .50707 .69339 L .50602 .6895 L F
.82 .38 0 r
.58308 .59617 m .58591 .60043 L .58561 .59755 L F
.322 .147 .482 r
.22957 .59377 m .2276 .59688 L .22775 .59448 L F
.355 0 .018 r
.57008 .63716 m .57285 .63682 L .57401 .63514 L F
0 .525 .8 r
.57473 .63504 m .57631 .63553 L .57401 .63514 L F
.36 .454 .821 r
.57631 .63553 m .57565 .63656 L .57401 .63514 L F
0 .525 .8 r
.57473 .63504 m .57401 .63514 L .57285 .63682 L F
.571 .763 .969 r
.42255 .58456 m .4263 .58538 L .42512 .58388 L F
.523 .747 .977 r
.4263 .58538 m .42718 .58362 L .42512 .58388 L F
.4263 .58538 m .42848 .58498 L .42718 .58362 L F
.282 .762 .927 r
.19155 .54244 m .19344 .5422 L .19521 .54256 L F
.129 .666 .853 r
.19344 .5422 m .19739 .5425 L .19521 .54256 L F
.582 .343 .519 r
.51025 .67635 m .51219 .67583 L .50985 .67602 L F
.647 .149 .053 r
.53442 .63758 m .53698 .6393 L .53802 .63813 L F
.837 .401 .196 r
.53698 .6393 m .53967 .64095 L .53802 .63813 L F
.599 .85 .491 r
.53522 .61924 m .53667 .61757 L .53418 .62068 L F
.16 .316 .773 r
.53418 .62068 m .53652 .62256 L .53522 .61924 L F
.671 .341 .405 r
.63253 .4719 m .63491 .47399 L .63142 .47418 L F
.685 .332 .371 r
.63253 .4719 m .6353 .47245 L .63491 .47399 L F
.452 0 0 r
.39413 .62757 m .39579 .62668 L .39215 .6267 L F
.308 0 0 r
.39652 .62782 m .39579 .62668 L .39413 .62757 L F
.39652 .62782 m .39811 .62654 L .39579 .62668 L F
.706 .515 .628 r
.605 .47203 m .60488 .47476 L .60346 .47411 L F
.60838 .47423 m .60488 .47476 L .605 .47203 L F
.761 .713 .807 r
.60398 .45432 m .60479 .45747 L .60125 .45699 L F
.805 .739 .79 r
.60714 .45451 m .60479 .45747 L .60398 .45432 L F
.84 .808 .819 r
.61579 .4395 m .61634 .44253 L .61331 .44243 L F
.849 .788 .792 r
.61634 .44253 m .61403 .44557 L .61331 .44243 L F
.444 .771 .997 r
.43282 .61494 m .43358 .61362 L .43119 .61386 L F
.443 .69 .97 r
.45258 .59502 m .45343 .59338 L .45136 .59339 L F
.45258 .59502 m .45512 .59486 L .45343 .59338 L F
.693 .777 .915 r
.63178 .41792 m .63293 .41956 L .62936 .41903 L F
.677 .796 .938 r
.63375 .41706 m .63293 .41956 L .63178 .41792 L F
.63375 .41706 m .63548 .41864 L .63293 .41956 L F
0 0 0 r
.51566 .68999 m .51489 .69258 L .5138 .69361 L F
.519 .881 .661 r
.51489 .69258 m .51171 .69494 L .5138 .69361 L F
.34 .362 .738 r
.54331 .70528 m .54472 .70566 L .54257 .70173 L F
.984 .704 .353 r
.54331 .70528 m .54373 .70783 L .54227 .7066 L F
.54331 .70528 m .54429 .70582 L .54472 .70566 L F
.672 .693 .861 r
.54581 .70573 m .54637 .70665 L .54429 .70582 L F
.984 .704 .353 r
.54429 .70582 m .5443 .70582 L .54432 .70582 L F
.54429 .70582 m .54432 .70582 L .54472 .70566 L F
.672 .693 .861 r
.54429 .70582 m .54637 .70665 L .54373 .70783 L F
.544 .7047 m .54429 .70582 L .54331 .70528 L F
.866 .562 .471 r
.54379 .70397 m .54472 .70566 L .54438 .70548 L F
.544 .7047 m .54438 .70548 L .5442 .70538 L F
.54379 .70397 m .54438 .70548 L .544 .7047 L F
.207 .265 .703 r
.544 .7047 m .54331 .70528 L .54257 .70173 L F
.866 .562 .471 r
.54257 .70173 m .54379 .70397 L .54152 .7039 L F
.54379 .70397 m .5442 .70538 L .54152 .7039 L F
.207 .265 .703 r
.54478 .70406 m .544 .7047 L .54257 .70173 L F
.672 .693 .861 r
.54429 .70582 m .54373 .70783 L .54331 .70528 L F
.984 .704 .353 r
.54331 .70528 m .54227 .7066 L .5443 .70582 L F
.86 .604 .55 r
.5415 .70388 m .5442 .70538 L .54227 .7066 L F
.5442 .70538 m .54472 .70566 L .54432 .70582 L F
.672 .693 .861 r
.54431 .70574 m .54441 .70581 L .54432 .70582 L F
.54429 .7058 m .54432 .70582 L .54429 .70582 L F
.86 .604 .55 r
.5442 .70538 m .54432 .70582 L .54429 .7058 L F
.672 .693 .861 r
.54431 .70574 m .54432 .70582 L .54429 .7058 L F
.86 .604 .55 r
.54429 .7058 m .54432 .70582 L .5443 .70582 L F
.672 .693 .861 r
.54431 .70574 m .54429 .70582 L .544 .7047 L F
.86 .604 .55 r
.5442 .70538 m .5443 .70582 L .54227 .7066 L F
.672 .693 .861 r
.54478 .70406 m .54431 .70574 L .5442 .70538 L F
.54405 .70466 m .5442 .70538 L .544 .7047 L F
.54478 .70406 m .5442 .70538 L .54405 .70466 L F
.866 .562 .471 r
.5415 .70388 m .54152 .7039 L .5415 .70388 L F
.54257 .70173 m .54152 .7039 L .5415 .70388 L F
.672 .693 .861 r
.54478 .70406 m .54581 .70573 L .54441 .70581 L F
.54478 .70406 m .54441 .70581 L .54431 .70574 L F
0 .183 .717 r
.65291 .42924 m .65376 .42703 L .65332 .42691 L F
.65291 .42924 m .65374 .42894 L .65376 .42703 L F
.449 .73 .987 r
.56854 .6002 m .56724 .59887 L .56614 .60027 L F
.56854 .6002 m .56724 .59887 L .56614 .60027 L F
.792 .936 .925 r
.43476 .59614 m .43579 .59361 L .43325 .5942 L F
.43476 .59614 m .4372 .59435 L .43579 .59361 L F
.747 .558 .64 r
.77895 .4833 m .78085 .48615 L .78273 .48335 L F
.682 .646 .808 r
.77483 .50064 m .77836 .5015 L .77751 .49822 L F
.596 .591 .817 r
.77751 .49822 m .77836 .5015 L .78087 .50087 L F
.853 .932 .878 r
.62163 .43486 m .61807 .43658 L .62039 .4335 L F
.815 .859 .881 r
.62391 .43275 m .62163 .43486 L .62039 .4335 L F
.506 .458 .737 r
.57884 .63277 m .58148 .63147 L .5807 .62899 L F
.524 .503 .774 r
.5819 .63475 m .57884 .63277 L .57847 .63465 L F
.128 0 0 r
.64771 .43817 m .6513 .43636 L .64912 .43645 L F
.451 .292 .574 r
.19959 .5889 m .20128 .59052 L .20129 .58815 L F
.205 0 0 r
.19806 .59226 m .20128 .59052 L .19959 .5889 L F
.374 .194 .504 r
.21055 .63368 m .20858 .63678 L .20892 .63473 L F
.638 .446 .607 r
.50782 .70862 m .50981 .70868 L .50982 .70515 L F
.359 .223 .557 r
.50982 .70515 m .51217 .70651 L .51184 .7046 L F
.50982 .70515 m .50981 .70868 L .51217 .70651 L F
.663 .496 .648 r
.53423 .64731 m .53462 .64984 L .53693 .64945 L F
.64 .601 .794 r
.5883 .65929 m .59078 .65859 L .58728 .65758 L F
.596 .068 0 r
.38835 .62649 m .3882 .62704 L .38976 .62621 L F
.607 .109 .044 r
.3882 .62704 m .39215 .6267 L .38976 .62621 L F
.655 .741 .913 r
.4781 .69876 m .48179 .69946 L .48 .70121 L F
.206 .289 .729 r
.48285 .698 m .48399 .70188 L .48179 .69946 L F
.481 .046 .135 r
.48 .70121 m .48179 .69946 L .48197 .70022 L F
.772 .273 .021 r
.48179 .69946 m .48399 .70188 L .48197 .70022 L F
.48179 .69946 m .48399 .70188 L .48197 .70022 L F
.685 .25 .209 r
.53522 .61924 m .53899 .61955 L .53667 .61757 L F
.908 .957 .812 r
.53824 .7186 m .54175 .71598 L .54138 .71583 L F
.713 .59 .717 r
.78193 .49153 m .78547 .49248 L .78445 .4901 L F
.78193 .49153 m .78285 .49333 L .78547 .49248 L F
.61 .232 .301 r
.78285 .49333 m .78583 .49435 L .78547 .49248 L F
.591 .631 .859 r
.78547 .49248 m .78729 .48962 L .78445 .4901 L F
.78547 .49248 m .78806 .49188 L .78729 .48962 L F
.715 .56 .678 r
.78583 .49435 m .78806 .49188 L .78547 .49248 L F
.55 .255 .42 r
.53178 .67926 m .53136 .68123 L .52887 .68139 L F
0 0 .014 r
.2319 .58836 m .23101 .5903 L .22966 .59111 L F
.324 .141 .471 r
.23158 .5928 m .22966 .59111 L .23101 .5903 L F
.23158 .5928 m .22957 .59377 L .22966 .59111 L F
.466 .511 .821 r
.33578 .61811 m .33679 .62129 L .33799 .61956 L F
.544 .618 .877 r
.33679 .62129 m .33915 .62074 L .33799 .61956 L F
.621 .528 .728 r
.33679 .62129 m .33991 .62376 L .33915 .62074 L F
.128 .674 .705 r
.77122 .48553 m .77429 .48499 L .77531 .48483 L F
.743 .41 .418 r
.77429 .48499 m .7772 .48323 L .77531 .48483 L F
.55 .286 .468 r
.50401 .68144 m .50626 .67902 L .50431 .67925 L F
.831 .832 .848 r
.58733 .47259 m .58494 .475 L .58356 .47429 L F
.93 .727 .607 r
.58494 .475 m .58479 .47755 L .58356 .47429 L F
.884 .893 .833 r
.53652 .62256 m .53778 .6235 L .54007 .62063 L F
.75 .441 .46 r
.48384 .71886 m .48751 .71973 L .48532 .71675 L F
.587 .416 .616 r
.48532 .71675 m .48751 .71973 L .48804 .71641 L F
.851 .585 .047 r
.66706 .45052 m .66736 .44845 L .66655 .44691 L F
.66706 .45052 m .66786 .45146 L .66736 .44845 L F
.786 .95 .927 r
.59636 .46278 m .59461 .46424 L .59162 .46493 L F
.744 .602 .699 r
.7799 .49306 m .78285 .49333 L .78193 .49153 L F
.702 .337 .352 r
.7799 .49306 m .78214 .49458 L .78285 .49333 L F
.61 .232 .301 r
.78285 .49333 m .78214 .49458 L .78583 .49435 L F
.601 .877 .992 r
.43534 .6117 m .4337 .61097 L .43613 .61023 L F
.944 .833 .704 r
.4337 .61097 m .43358 .61351 L .43534 .6117 L F
.884 .893 .833 r
.53652 .62256 m .54007 .62063 L .53859 .62232 L F
.996 .8 .523 r
.53859 .62232 m .54007 .62063 L .53899 .61955 L F
.971 .751 .547 r
.58429 .63784 m .58229 .63954 L .58185 .63757 L F
.58429 .63784 m .58371 .64058 L .58229 .63954 L F
.698 .492 .606 r
.59539 .47426 m .59309 .47703 L .59334 .47512 L F
.751 .613 .705 r
.4994 .65476 m .50229 .65488 L .50152 .65291 L F
0 0 .086 r
.50229 .65488 m .50343 .65436 L .50381 .65266 L F
.2 .583 .942 r
.50229 .65488 m .5048 .65568 L .50343 .65436 L F
.799 .754 .811 r
.60647 .45146 m .60714 .45451 L .60398 .45432 L F
.238 0 .328 r
.64887 .46814 m .64922 .46622 L .65114 .4652 L F
.317 0 0 r
.20701 .5434 m .20902 .5439 L .21114 .54401 L F
.249 .702 .954 r
.20902 .5439 m .21283 .54468 L .21114 .54401 L F
.693 .25 .194 r
.56553 .63815 m .56841 .63959 L .56782 .6387 L F
.318 .151 .49 r
.56782 .6387 m .56841 .63959 L .57008 .63716 L F
.552 .004 0 r
.49833 .70793 m .50194 .71078 L .49931 .7101 L F
.323 .02 .285 r
.50133 .71051 m .49931 .7101 L .50194 .71078 L F
.50133 .71051 m .49828 .71296 L .49931 .7101 L F
.288 .786 .786 r
.64216 .44356 m .64406 .44328 L .64647 .44257 L F
.187 0 .1 r
.4665 .62273 m .46731 .62063 L .46522 .62274 L F
.774 .681 .761 r
.5957 .65248 m .59912 .65295 L .59809 .64968 L F
.823 .789 .82 r
.59526 .65486 m .59912 .65295 L .5957 .65248 L F
.88 .522 .364 r
.54605 .64606 m .54922 .64924 L .54826 .64729 L F
.712 .188 0 r
.54383 .62478 m .54525 .62614 L .54636 .62618 L F
0 .045 .555 r
.54406 .62481 m .54525 .62614 L .54383 .62478 L F
0 0 .12 r
.54406 .62481 m .54397 .62608 L .54525 .62614 L F
.54397 .62608 m .54385 .62767 L .54525 .62614 L F
.712 .188 0 r
.54636 .62618 m .54525 .62614 L .54724 .62666 L F
.469 .285 .548 r
.54724 .62666 m .54731 .62931 L .55013 .62824 L F
.376 0 .132 r
.48739 .69945 m .48399 .70188 L .48607 .69846 L F
.48739 .69945 m .48635 .70148 L .48399 .70188 L F
.582 .42 .628 r
.48607 .69846 m .48635 .70148 L .48739 .69945 L F
.927 .556 .284 r
.66879 .43613 m .67029 .43699 L .66935 .43822 L F
.968 .649 .334 r
.67029 .43699 m .67064 .43931 L .66935 .43822 L F
.375 0 .022 r
.57159 .62804 m .57379 .628 L .57485 .62646 L F
.849 .934 .881 r
.57485 .62646 m .57745 .62411 L .57705 .62303 L F
.583 .272 .407 r
.40618 .62252 m .40911 .62095 L .40663 .6208 L F
.377 0 .085 r
.38218 .59825 m .38035 .59789 L .38328 .59684 L F
.623 .92 .655 r
.38435 .59551 m .38328 .59684 L .38545 .5965 L F
.38435 .59551 m .38294 .59692 L .38328 .59684 L F
.817 .92 .531 r
.38294 .59692 m .38218 .59825 L .38328 .59684 L F
.532 .533 .801 r
.45615 .59754 m .45729 .59396 L .45512 .59486 L F
.45615 .59754 m .45841 .59721 L .45729 .59396 L F
.399 .089 .321 r
.49955 .6876 m .49682 .68999 L .49711 .68781 L F
.774 .269 0 r
.45097 .62389 m .45123 .62497 L .45295 .62478 L F
.183 .716 .749 r
.45295 .62478 m .45397 .62446 L .45591 .62426 L F
.45295 .62478 m .45123 .62497 L .45397 .62446 L F
.181 .267 .717 r
.63781 .42063 m .63655 .42243 L .63548 .41864 L F
.654 .922 .976 r
.63561 .42179 m .63655 .42243 L .63781 .42063 L F
.944 .719 .569 r
.56332 .63937 m .56204 .6402 L .5622 .63885 L F
.742 .337 .283 r
.56332 .63937 m .56548 .64074 L .56204 .6402 L F
.218 0 .321 r
.26149 .77932 m .2595 .78086 L .26175 .77782 L F
.713 .949 .954 r
.259 .78006 m .2595 .78086 L .26149 .77932 L F
.406 .293 .611 r
.23899 .56772 m .23909 .56999 L .23718 .56832 L F
.338 .291 .658 r
.23909 .56999 m .23778 .57102 L .23718 .56832 L F
.529 .313 .531 r
.21105 .57389 m .21329 .57347 L .21357 .57107 L F
.436 .334 .64 r
.21357 .57107 m .21535 .57049 L .21516 .56806 L F
.571 .424 .642 r
.21329 .57347 m .21535 .57049 L .21357 .57107 L F
.384 .726 .99 r
.48463 .69353 m .48614 .69388 L .48303 .6929 L F
.988 .787 .543 r
.59208 .63108 m .59309 .63486 L .59311 .63239 L F
.57 .225 .345 r
.66511 .4564 m .66466 .45889 L .66231 .45872 L F
.27 .135 .505 r
.66719 .45356 m .66726 .45618 L .66511 .4564 L F
.223 0 .249 r
.66726 .45618 m .66466 .45889 L .66511 .4564 L F
.224 .319 .752 r
.53386 .66139 m .53613 .66329 L .53642 .66124 L F
.429 .213 .483 r
.48683 .65794 m .48449 .66089 L .48473 .65857 L F
.48683 .65794 m .48449 .66089 L .48473 .65857 L F
.797 .76 .819 r
.61331 .44243 m .61403 .44557 L .6109 .44511 L F
.769 .652 .733 r
.77824 .49114 m .78193 .49153 L .78089 .48846 L F
.77824 .49114 m .7799 .49306 L .78193 .49153 L F
.657 .659 .84 r
.78089 .48846 m .78193 .49153 L .78445 .4901 L F
.322 .172 .517 r
.21929 .61437 m .21915 .61727 L .21753 .61769 L F
.356 .176 .495 r
.21894 .61947 m .21753 .61769 L .21915 .61727 L F
.21894 .61947 m .21732 .62019 L .21753 .61769 L F
.412 .71 .984 r
.64177 .42046 m .64494 .4217 L .64269 .42174 L F
.679 .641 .804 r
.77379 .49735 m .77483 .50064 L .77751 .49822 L F
.806 .599 .622 r
.54383 .62478 m .53973 .62362 L .5423 .62366 L F
.54383 .62478 m .54008 .62562 L .53973 .62362 L F
.54383 .62478 m .54304 .62681 L .54008 .62562 L F
0 .045 .555 r
.54406 .62481 m .54383 .62478 L .5423 .62366 L F
0 0 0 r
.51793 .72546 m .51874 .72452 L .51969 .72182 L F
.929 .714 .591 r
.5203 .72691 m .51874 .72452 L .51793 .72546 L F
.262 .083 .439 r
.22551 .59995 m .22523 .60239 L .22367 .60311 L F
.31 .164 .516 r
.22523 .60239 m .22356 .60548 L .22367 .60311 L F
.588 .609 .841 r
.449 .59394 m .44994 .59022 L .44828 .59198 L F
.116 .293 .767 r
.23764 .55215 m .23697 .55373 L .23551 .55035 L F
.331 .556 .917 r
.23764 .55215 m .24031 .55554 L .23697 .55373 L F
.893 .778 .727 r
.38545 .5965 m .38328 .6002 L .38235 .59855 L F
.38254 .59806 m .38235 .59855 L .38218 .59825 L F
.38545 .5965 m .38235 .59855 L .38254 .59806 L F
.38545 .5965 m .38218 .59825 L .38412 .59842 L F
.354 .178 .498 r
.38435 .59551 m .38412 .59842 L .38297 .59696 L F
.38302 .59684 m .38297 .59696 L .38294 .59692 L F
.38435 .59551 m .38297 .59696 L .38302 .59684 L F
.473 .239 .479 r
.38597 .59917 m .38328 .6002 L .38545 .5965 L F
.362 .749 .987 r
.38646 .59534 m .38545 .5965 L .38792 .59531 L F
.38646 .59534 m .38435 .59551 L .38545 .5965 L F
.903 .532 .32 r
.38412 .59842 m .38597 .59917 L .38545 .5965 L F
.773 .701 .783 r
.7846 .50449 m .78729 .50533 L .78712 .50372 L F
.557 .673 .916 r
.78729 .50533 m .78993 .50286 L .78712 .50372 L F
.78729 .50533 m .79042 .50524 L .78993 .50286 L F
.648 .375 .493 r
.20384 .585 m .20617 .58511 L .20711 .58296 L F
.713 .448 .523 r
.20711 .58296 m .20981 .58516 L .20915 .58252 L F
.20711 .58296 m .20617 .58511 L .20981 .58516 L F
.849 .91 .876 r
.52813 .72272 m .526 .72586 L .5248 .72402 L F
.694 .633 .784 r
.79863 .49878 m .79653 .50318 L .79524 .49795 L F
.628 .581 .782 r
.68334 .43026 m .68459 .43433 L .68183 .43466 L F
.618 .486 .679 r
.68459 .43433 m .6822 .43694 L .68183 .43466 L F
.609 .362 .518 r
.65024 .43909 m .64889 .44265 L .64647 .44257 L F
.734 .497 .57 r
.65273 .44235 m .64889 .44265 L .65024 .43909 L F
.746 .499 .558 r
.51887 .64067 m .52113 .6446 L .52059 .64238 L F
.547 .164 .266 r
.6353 .47245 m .63749 .47388 L .63491 .47399 L F
.183 .179 .618 r
.50707 .69339 m .50681 .68967 L .50602 .6895 L F
.863 .618 .566 r
.21715 .55938 m .21469 .56051 L .21567 .55855 L F
.21715 .55938 m .21701 .5618 L .21469 .56051 L F
.104 0 0 r
.38528 .58097 m .38756 .58076 L .38513 .58048 L F
.139 0 0 r
.49682 .68999 m .49397 .69212 L .49479 .69071 L F
.113 0 0 r
.3942 .59213 m .39299 .59366 L .3915 .59373 L F
.25 0 .005 r
.39624 .59152 m .39299 .59366 L .3942 .59213 L F
.49 0 0 r
.37452 .64118 m .37301 .64134 L .37081 .64021 L F
.427 0 0 r
.3768 .64106 m .37301 .64134 L .37452 .64118 L F
.527 .427 .685 r
.33319 .60598 m .33495 .60241 L .33269 .60346 L F
.313 .175 .527 r
.36618 .60583 m .36585 .6084 L .36452 .60887 L F
.377 .342 .692 r
.36585 .6084 m .36689 .6107 L .36452 .60887 L F
.344 .575 .927 r
.20394 .57249 m .20565 .57256 L .20461 .57382 L F
.20394 .57249 m .20565 .57256 L .20461 .57382 L F
.462 0 0 r
.43392 .62047 m .42964 .61975 L .43158 .6195 L F
.586 .256 .377 r
.43346 .62189 m .43605 .62219 L .43392 .62047 L F
.831 .832 .848 r
.58733 .47259 m .58356 .47429 L .58555 .47267 L F
.856 .949 .875 r
.58785 .47038 m .58733 .47259 L .58555 .47267 L F
.361 .029 .26 r
.51712 .69194 m .51566 .68999 L .51752 .68989 L F
.51712 .69194 m .51489 .69258 L .51566 .68999 L F
.741 .653 .763 r
.58356 .47429 m .58114 .47724 L .58115 .47484 L F
0 0 .354 r
.58115 .47484 m .58237 .47554 L .58356 .47429 L F
.58115 .47484 m .58114 .47724 L .58237 .47554 L F
.294 0 .113 r
.33882 .59356 m .3424 .59071 L .33956 .59171 L F
0 0 0 r
.47193 .62907 m .47461 .62647 L .47341 .62824 L F
.121 0 0 r
.47341 .62824 m .47461 .62647 L .47671 .62563 L F
.933 .712 .579 r
.56666 .64401 m .56521 .64372 L .56548 .64074 L F
.905 .502 .106 r
.56696 .64615 m .56521 .64372 L .56666 .64401 L F
.784 .563 .601 r
.80533 .49203 m .80774 .49522 L .80825 .49335 L F
.775 .767 .258 r
.67499 .42759 m .67177 .43033 L .6716 .42862 L F
.67499 .42759 m .67429 .4304 L .67177 .43033 L F
.534 .126 .213 r
.44114 .62659 m .43983 .62866 L .43736 .62849 L F
.472 .061 .178 r
.44309 .62786 m .44114 .62659 L .44356 .62673 L F
.44309 .62786 m .43983 .62866 L .44114 .62659 L F
.604 .62 .841 r
.76766 .49528 m .7714 .49786 L .7702 .49481 L F
.596 .613 .839 r
.7714 .49786 m .77278 .49407 L .7702 .49481 L F
.7714 .49786 m .77379 .49735 L .77278 .49407 L F
.176 0 0 r
.38756 .58076 m .39001 .58063 L .39137 .57998 L F
.333 0 0 r
.39001 .58063 m .39354 .58026 L .39137 .57998 L F
.626 .326 .441 r
.26175 .77782 m .2638 .77997 L .26149 .77932 L F
.594 .035 0 r
.26003 .77723 m .2638 .77997 L .26175 .77782 L F
.426 .261 .553 r
.21105 .57389 m .21283 .57577 L .21329 .57347 L F
.21105 .57389 m .21095 .57641 L .21283 .57577 L F
.398 0 .068 r
.5306 .70498 m .52696 .70701 L .52852 .70588 L F
.527 .743 .974 r
.56719 .63681 m .56553 .63815 L .56453 .6371 L F
.426 .542 .871 r
.56719 .63681 m .56841 .63959 L .56553 .63815 L F
.527 .743 .974 r
.56719 .63681 m .56553 .63815 L .56453 .6371 L F
.636 .211 .218 r
.57921 .59608 m .58308 .59617 L .58225 .59491 L F
.291 .742 .958 r
.40585 .5911 m .4023 .59059 L .40403 .59077 L F
.926 .971 .756 r
.52521 .67854 m .5226 .68011 L .52471 .67848 L F
.359 .035 .273 r
.519 .70565 m .52115 .70544 L .52125 .7047 L F
0 0 0 r
.46839 .6312 m .47193 .62907 L .4703 .6302 L F
.47193 .62907 m .47341 .62824 L .4703 .6302 L F
.237 0 0 r
.3915 .59373 m .3902 .59502 L .38792 .59531 L F
.553 .208 .338 r
.39299 .59366 m .3902 .59502 L .3915 .59373 L F
.618 .288 .389 r
.50158 .68936 m .49955 .6876 L .50341 .68688 L F
.418 .027 .189 r
.50419 .68719 m .50341 .68688 L .50513 .68697 L F
.50419 .68719 m .50158 .68936 L .50341 .68688 L F
.25 .738 .923 r
.19739 .5425 m .19939 .54226 L .20115 .54278 L F
.124 0 0 r
.19939 .54226 m .20306 .54257 L .20115 .54278 L F
.152 0 .404 r
.48241 .61802 m .48391 .61457 L .48336 .61669 L F
0 0 0 r
.48155 .61999 m .48241 .61802 L .48336 .61669 L F
.43 .127 .348 r
.48086 .67339 m .48403 .67263 L .48186 .67245 L F
.416 .451 .789 r
.48186 .67245 m .48194 .67121 L .48086 .67339 L F
.438 .351 .66 r
.48186 .67245 m .48403 .67263 L .48569 .67171 L F
.48186 .67245 m .48403 .67263 L .48569 .67171 L F
.416 .451 .789 r
.48186 .67245 m .48403 .67263 L .48194 .67121 L F
.43 .127 .348 r
.48086 .67339 m .48403 .67263 L .48186 .67245 L F
.724 .303 .248 r
.55459 .62951 m .55647 .63095 L .55693 .62943 L F
.335 .023 .278 r
.55693 .62943 m .55647 .63095 L .55934 .62859 L F
.559 .134 .191 r
.43605 .62219 m .43846 .62248 L .43982 .62061 L F
.554 .128 .187 r
.43982 .62061 m .43846 .62248 L .44286 .62175 L F
.858 .984 .852 r
.52494 .63983 m .52581 .64042 L .52848 .63748 L F
.574 .033 0 r
.52712 .64197 m .52581 .64042 L .52494 .63983 L F
.52712 .64197 m .52843 .64291 L .52581 .64042 L F
.294 0 .113 r
.33882 .59356 m .34094 .59302 L .3424 .59071 L F
.363 0 .115 r
.34094 .59302 m .34478 .59029 L .3424 .59071 L F
.504 .045 .095 r
.5838 .60624 m .58194 .60583 L .58438 .60557 L F
.269 .088 .442 r
.68552 .43905 m .68516 .44138 L .68341 .44272 L F
.563 .798 .987 r
.42848 .58498 m .43219 .58555 L .431 .58401 L F
.543 .771 .982 r
.43219 .58555 m .43308 .58381 L .431 .58401 L F
.43219 .58555 m .43443 .58507 L .43308 .58381 L F
.489 .095 .218 r
.51795 .67529 m .52043 .67503 L .52086 .6735 L F
.434 .045 .2 r
.52086 .6735 m .52287 .67465 L .52316 .67245 L F
.52086 .6735 m .52043 .67503 L .52287 .67465 L F
.421 .274 .575 r
.20161 .58476 m .20362 .58721 L .20384 .585 L F
.20161 .58476 m .20129 .58815 L .20362 .58721 L F
.943 .68 .214 r
.66787 .43244 m .66876 .43411 L .66879 .43613 L F
.631 .49 .672 r
.5322 .6532 m .53458 .65238 L .53462 .64984 L F
.53462 .64984 m .53458 .65238 L .5322 .6532 L F
.576 .043 0 r
.45117 .58949 m .44994 .59022 L .45361 .59062 L F
0 0 0 r
.49828 .71296 m .4975 .71737 L .49726 .71671 L F
.501 .278 .507 r
.4975 .71737 m .49552 .71822 L .49726 .71671 L F
.664 .14 0 r
.53967 .64095 m .54096 .64239 L .54121 .64211 L F
.652 .12 0 r
.54096 .64239 m .54236 .64333 L .54121 .64211 L F
.188 0 .328 r
.76879 .48628 m .7702 .48671 L .77122 .48553 L F
.76879 .48628 m .76805 .48912 L .7702 .48671 L F
.215 0 .202 r
.4767 .69055 m .4777 .69234 L .47921 .69212 L F
.627 .341 .465 r
.57615 .59928 m .57758 .59728 L .57445 .59702 L F
.134 0 0 r
.57448 .59913 m .57615 .59928 L .57369 .5992 L F
.75 .347 .287 r
.57369 .5992 m .57615 .59928 L .57445 .59702 L F
.94 .651 .465 r
.5568 .66348 m .55865 .6667 L .55882 .66448 L F
.269 0 0 r
.4066 .63458 m .40489 .63618 L .40259 .63652 L F
.326 0 0 r
.4066 .63458 m .40718 .63586 L .40489 .63618 L F
.4066 .63458 m .40883 .63448 L .40718 .63586 L F
.713 .483 .575 r
.58698 .47742 m .58481 .47994 L .58479 .47755 L F
.58698 .47742 m .58899 .47919 L .58481 .47994 L F
.697 .557 .692 r
.59063 .47756 m .58899 .47919 L .58698 .47742 L F
.481 .324 .59 r
.52125 .7047 m .52367 .70176 L .52154 .70233 L F
.683 .583 .736 r
.5018 .69624 m .50517 .69663 L .50485 .696 L F
.465 .248 .499 r
.50485 .696 m .50726 .69566 L .50707 .69339 L F
.479 .26 .503 r
.50517 .69663 m .50726 .69566 L .50485 .696 L F
.246 .27 .688 r
.46087 .70269 m .46133 .70504 L .46303 .70363 L F
.446 .286 .57 r
.46133 .70504 m .46337 .70732 L .46303 .70363 L F
.46133 .70504 m .46142 .70653 L .46337 .70732 L F
.402 .685 .976 r
.20713 .55892 m .20985 .56016 L .20904 .5586 L F
0 0 0 r
.20809 .56114 m .21011 .56042 L .20985 .56016 L F
.362 .222 .553 r
.23364 .58746 m .23188 .5858 L .23363 .58487 L F
.23364 .58746 m .2319 .58836 L .23188 .5858 L F
.616 .616 .828 r
.58728 .65758 m .58946 .65527 L .58693 .65595 L F
.619 .62 .83 r
.59078 .65859 m .58946 .65527 L .58728 .65758 L F
.754 .394 .371 r
.47914 .67255 m .48104 .67513 L .48086 .67339 L F
.661 .571 .743 r
.47914 .67255 m .48086 .67339 L .48194 .67121 L F
.472 .202 .422 r
.48104 .67513 m .48403 .67263 L .48086 .67339 L F
.57 .37 .57 r
.48194 .67121 m .48104 .67513 L .47914 .67255 L F
.705 .711 .853 r
.64177 .42046 m .64165 .42377 L .64494 .4217 L F
.271 0 0 r
.38019 .64012 m .37941 .64081 L .3768 .64106 L F
0 0 0 r
.38137 .64011 m .38019 .64012 L .3826 .63947 L F
.38137 .64011 m .37941 .64081 L .38019 .64012 L F
.481 .471 .77 r
.33843 .62924 m .33912 .62573 L .33732 .62657 L F
.33843 .62924 m .34065 .62935 L .33912 .62573 L F
.792 .309 0 r
.67531 .45026 m .6726 .44709 L .67369 .44824 L F
.381 0 0 r
.44701 .62683 m .44549 .62752 L .44356 .62673 L F
.775 .979 .713 r
.44789 .62492 m .44701 .62683 L .44907 .62727 L F
.44789 .62492 m .44549 .62752 L .44701 .62683 L F
.452 .079 .24 r
.40034 .62587 m .40281 .62561 L .4039 .62323 L F
.535 .228 .393 r
.40281 .62561 m .40618 .62252 L .4039 .62323 L F
.029 0 0 r
.39354 .58026 m .39565 .58019 L .39748 .57994 L F
.518 .917 .869 r
.39748 .57994 m .39813 .57907 L .39969 .57945 L F
.39748 .57994 m .39565 .58019 L .39813 .57907 L F
.839 .57 .532 r
.55837 .63721 m .55519 .63428 L .55782 .63519 L F
.49 .308 .561 r
.50681 .68967 m .50949 .69451 L .51076 .69192 L F
.539 .363 .591 r
.50964 .69419 m .51092 .69474 L .51076 .69192 L F
.50961 .69481 m .51092 .69474 L .50929 .69404 L F
.49 .308 .561 r
.50949 .69451 m .50959 .6947 L .51076 .69192 L F
.539 .363 .591 r
.50929 .69404 m .50964 .69419 L .51076 .69192 L F
.368 .389 .75 r
.50937 .698 m .50726 .69566 L .51041 .69614 L F
.50937 .698 m .50836 .69917 L .50726 .69566 L F
.481 .82 .999 r
.50726 .69566 m .50908 .69491 L .50707 .69339 L F
.50908 .69491 m .50926 .69483 L .50915 .69476 L F
.50908 .69491 m .50915 .69476 L .50707 .69339 L F
0 0 0 r
.51171 .69494 m .50937 .698 L .51041 .69614 L F
.787 .692 .76 r
.5091 .69487 m .50937 .698 L .51171 .69494 L F
.50871 .69486 m .50883 .69544 L .5091 .69487 L F
.50883 .69544 m .50937 .698 L .5091 .69487 L F
.481 .82 .999 r
.50726 .69566 m .50871 .69486 L .50959 .6947 L F
.67 .617 .787 r
.50658 .69802 m .50703 .69802 L .50871 .69486 L F
.50703 .69802 m .50937 .698 L .50883 .69544 L F
.50703 .69802 m .50883 .69544 L .50871 .69486 L F
.481 .82 .999 r
.50926 .69483 m .50955 .69471 L .5094 .69463 L F
.50926 .69483 m .5094 .69463 L .50707 .69339 L F
.50955 .69471 m .50959 .6947 L .50956 .69468 L F
.50955 .69471 m .50956 .69468 L .50707 .69339 L F
.539 .363 .591 r
.50871 .69486 m .50952 .69482 L .50929 .69404 L F
.50952 .69482 m .50961 .69481 L .50956 .69468 L F
.183 .179 .618 r
.50707 .69339 m .50956 .69468 L .50765 .69119 L F
.50688 .69062 m .50765 .69119 L .50681 .68967 L F
.50707 .69339 m .50765 .69119 L .50688 .69062 L F
.50956 .69468 m .50949 .69451 L .50681 .68967 L F
.539 .363 .591 r
.50952 .69482 m .50956 .69468 L .50929 .69404 L F
.183 .179 .618 r
.50956 .69468 m .50959 .6947 L .50949 .69451 L F
.539 .363 .591 r
.50871 .69486 m .51076 .69192 L .50959 .6947 L F
.494 .092 .208 r
.5074 .69404 m .51076 .69192 L .51092 .69474 L F
.17 .7 .854 r
.51171 .69494 m .51092 .69474 L .50871 .69486 L F
.085 .617 .866 r
.51028 .69461 m .50937 .69424 L .5074 .69404 L F
.51092 .69474 m .50937 .69424 L .51028 .69461 L F
.494 .092 .208 r
.5074 .69404 m .50937 .69424 L .51009 .69302 L F
.67 .617 .787 r
.50658 .69802 m .50871 .69486 L .50726 .69566 L F
.494 .092 .208 r
.5074 .69404 m .5101 .69301 L .50961 .69265 L F
.524 .484 .755 r
.50681 .69098 m .50937 .69424 L .5074 .69404 L F
.343 .664 .973 r
.5074 .69404 m .50937 .69424 L .50832 .69296 L F
.5074 .69404 m .50937 .69424 L .50832 .69296 L F
.997 .797 .514 r
.50937 .69424 m .50837 .69592 L .50833 .69381 L F
.50937 .69424 m .50833 .69381 L .50832 .69296 L F
.50937 .69424 m .50837 .69612 L .50837 .69592 L F
.494 .092 .208 r
.51009 .69302 m .50937 .69424 L .5101 .69301 L F
.50961 .69265 m .5101 .69301 L .51076 .69192 L F
.37 .188 .5 r
.2237 .61084 m .22203 .60923 L .22402 .60793 L F
.2237 .61084 m .22261 .61158 L .22203 .60923 L F
.08 .015 .475 r
.19616 .60294 m .19739 .60236 L .19716 .59924 L F
0 0 .223 r
.19649 .60575 m .19676 .6053 L .19616 .60294 L F
.669 .176 .07 r
.19675 .60454 m .19677 .60567 L .19781 .6073 L F
0 0 .223 r
.19676 .6053 m .19676 .6053 L .19676 .60529 L F
.19676 .6053 m .19676 .60529 L .19616 .60294 L F
.669 .176 .07 r
.19933 .60535 m .19675 .60454 L .19781 .6073 L F
.625 .171 .153 r
.19616 .60294 m .19676 .60529 L .194 .60446 L F
.039 .537 .879 r
.19649 .60575 m .19676 .6053 L .194 .60446 L F
.669 .176 .07 r
.19676 .6053 m .1965 .60525 L .19677 .60567 L F
.19676 .60529 m .1967 .60528 L .19676 .6053 L F
.1967 .60528 m .1965 .60525 L .19676 .6053 L F
.039 .537 .879 r
.19676 .6053 m .19676 .6053 L .1967 .60528 L F
.19676 .6053 m .1967 .60528 L .194 .60446 L F
.625 .171 .153 r
.19676 .60529 m .19676 .6053 L .1967 .60528 L F
.19676 .60529 m .1967 .60528 L .194 .60446 L F
.669 .176 .07 r
.19675 .60454 m .19587 .60427 L .1965 .60525 L F
.19675 .60454 m .1965 .60525 L .19676 .60529 L F
.625 .171 .153 r
.19616 .60294 m .19587 .60427 L .19739 .60236 L F
.19616 .60294 m .194 .60446 L .19587 .60427 L F
.815 .859 .881 r
.62391 .43275 m .62039 .4335 L .62243 .43038 L F
.503 .307 .547 r
.62593 .4308 m .62391 .43275 L .62243 .43038 L F
.62593 .4308 m .62608 .43307 L .62391 .43275 L F
.62391 .43275 m .62608 .43307 L .62593 .4308 L F
.557 .197 .313 r
.34715 .58991 m .35075 .58765 L .3459 .58952 L F
.34715 .58991 m .34944 .59014 L .35075 .58765 L F
.407 .043 .232 r
.34944 .59014 m .35289 .58733 L .35075 .58765 L F
.377 0 .085 r
.38218 .59825 m .37973 .59877 L .38035 .59789 L F
.638 .592 .786 r
.7821 .505 m .78345 .50024 L .78087 .50087 L F
.7821 .505 m .7846 .50449 L .78345 .50024 L F
.622 .501 .695 r
.7821 .505 m .7822 .50643 L .7846 .50449 L F
.742 .436 .463 r
.52441 .69547 m .52874 .69622 L .52581 .69306 L F
.672 .637 .807 r
.77604 .49198 m .7799 .49306 L .77824 .49114 L F
.768 .54 .589 r
.77628 .49435 m .7799 .49306 L .77604 .49198 L F
.77628 .49435 m .77984 .49515 L .7799 .49306 L F
.623 .418 .584 r
.77984 .49515 m .78214 .49458 L .7799 .49306 L F
.443 0 0 r
.39991 .59109 m .39837 .59226 L .39624 .59152 L F
.215 0 0 r
.4023 .59059 m .39837 .59226 L .39991 .59109 L F
.703 .168 0 r
.49905 .7095 m .49833 .70793 L .49702 .70701 L F
.49905 .7095 m .50133 .71051 L .49833 .70793 L F
.552 .004 0 r
.49833 .70793 m .50133 .71051 L .50194 .71078 L F
.323 .687 .979 r
.5047 .73708 m .5072 .73727 L .5057 .73612 L F
.5047 .73708 m .5072 .73727 L .5057 .73612 L F
.641 .687 .877 r
.79524 .49795 m .79302 .49916 L .79168 .49712 L F
.374 .608 .94 r
.38023 .62527 m .37658 .62331 L .37848 .62344 L F
0 .574 .732 r
.38079 .62524 m .38023 .62527 L .37848 .62344 L F
.38079 .62524 m .38235 .62534 L .38023 .62527 L F
.698 .479 .586 r
.57731 .6397 m .57912 .63989 L .57983 .63803 L F
.668 .427 .546 r
.57983 .63803 m .58014 .64047 L .58006 .64045 L F
.36 .454 .821 r
.57896 .63963 m .57912 .63989 L .5785 .63929 L F
.668 .427 .546 r
.57823 .63909 m .5785 .63929 L .57731 .6397 L F
.699 .499 .614 r
.57565 .63656 m .5785 .63929 L .57731 .6397 L F
.5785 .63929 m .57912 .63989 L .57731 .6397 L F
.668 .427 .546 r
.5785 .63929 m .58006 .64045 L .57731 .6397 L F
.826 .626 .632 r
.57983 .63803 m .57912 .63989 L .57896 .63963 L F
.668 .427 .546 r
.57983 .63803 m .57896 .63963 L .57823 .63909 L F
.826 .626 .632 r
.57983 .63803 m .57896 .63963 L .57631 .63553 L F
.668 .427 .546 r
.57983 .63803 m .58006 .64045 L .57896 .63963 L F
.36 .454 .821 r
.57631 .63553 m .57896 .63963 L .57565 .63656 L F
.57896 .63963 m .5785 .63929 L .57565 .63656 L F
.699 .499 .614 r
.57565 .63656 m .57731 .6397 L .57623 .64021 L F
0 0 .077 r
.20419 .64613 m .20388 .6464 L .2051 .64391 L F
.172 0 .265 r
.2057 .64491 m .2051 .64391 L .20622 .64279 L F
.2057 .64491 m .20419 .64613 L .2051 .64391 L F
0 .497 .846 r
.22482 .5456 m .22828 .54699 L .22637 .54688 L F
.669 .562 .726 r
.68459 .43433 m .68735 .43946 L .6822 .43694 L F
.684 .551 .697 r
.6822 .43694 m .68735 .43946 L .68552 .43905 L F
.496 .355 .619 r
.33442 .59715 m .33653 .59659 L .33646 .59403 L F
.469 .326 .604 r
.33463 .59959 m .33653 .59659 L .33442 .59715 L F
.234 .288 .715 r
.4725 .6846 m .47462 .68625 L .47403 .68385 L F
.781 .706 .781 r
.5729 .48268 m .57432 .48685 L .57052 .4856 L F
.804 .406 .298 r
.57052 .4856 m .57432 .48685 L .57417 .4882 L F
.741 .685 .797 r
.57654 .48322 m .57432 .48685 L .5729 .48268 L F
.688 .613 .768 r
.57744 .48623 m .57432 .48685 L .57654 .48322 L F
.604 .269 .375 r
.57744 .48623 m .57417 .4882 L .57432 .48685 L F
.647 .735 .914 r
.65263 .45656 m .65614 .45721 L .6557 .45547 L F
.6557 .45547 m .65614 .45721 L .65263 .45656 L F
.983 .884 .652 r
.65511 .45526 m .65614 .45721 L .6557 .45547 L F
.65511 .45526 m .65614 .45721 L .6557 .45547 L F
.263 .737 .939 r
.51876 .71939 m .51517 .71899 L .51526 .7173 L F
.567 .388 .598 r
.51517 .71899 m .51814 .71605 L .51526 .7173 L F
.465 .168 .376 r
.56147 .59863 m .55976 .59939 L .55977 .59905 L F
.565 .034 0 r
.55109 .66002 m .54988 .65915 L .54917 .65845 L F
.407 .504 .845 r
.54758 .66157 m .54969 .66211 L .54849 .66349 L F
.235 .176 .584 r
.54985 .66267 m .54985 .66261 L .55006 .66342 L F
.54985 .66261 m .54988 .65915 L .55001 .66213 L F
.54985 .66261 m .55001 .66213 L .55006 .66342 L F
.74 .636 .744 r
.54984 .66264 m .54779 .66622 L .54849 .66349 L F
.235 .176 .584 r
.55006 .66342 m .54988 .65915 L .55109 .66002 L F
.54984 .66414 m .54985 .66267 L .55006 .66342 L F
.54984 .66414 m .5504 .66229 L .54988 .65915 L F
.74 .636 .744 r
.5504 .66229 m .54954 .66359 L .54984 .66264 L F
.54954 .66359 m .54779 .66622 L .54984 .66264 L F
.407 .504 .845 r
.54969 .66211 m .5504 .66229 L .54984 .66264 L F
.54969 .66211 m .54984 .66264 L .54849 .66349 L F
.791 .536 .552 r
.55656 .59992 m .55932 .60142 L .55934 .60216 L F
0 0 .225 r
.53239 .69309 m .53341 .69258 L .5334 .69024 L F
.545 .18 .299 r
.53405 .69427 m .53539 .69478 L .53692 .69319 L F
.53405 .69427 m .53692 .69319 L .53732 .69261 L F
.656 .292 .344 r
.5334 .69024 m .53747 .69236 L .5375 .68943 L F
.921 .941 .587 r
.53804 .69155 m .53744 .69243 L .53755 .69331 L F
.656 .292 .344 r
.53747 .69236 m .53763 .69244 L .53762 .69202 L F
.53747 .69236 m .53762 .69202 L .5375 .68943 L F
.921 .941 .587 r
.53744 .69243 m .53692 .69319 L .53697 .69351 L F
.53744 .69243 m .53697 .69351 L .53755 .69331 L F
0 0 .038 r
.53697 .69505 m .53519 .69622 L .53532 .69606 L F
.53697 .69505 m .53532 .69606 L .53755 .69331 L F
.921 .941 .587 r
.53692 .69319 m .53663 .69362 L .53697 .69351 L F
.447 .648 .944 r
.53663 .69362 m .53697 .69505 L .53755 .69331 L F
.672 .343 .408 r
.53663 .69362 m .53641 .69396 L .53655 .69399 L F
.53692 .69319 m .53539 .69478 L .53588 .69476 L F
.447 .648 .944 r
.53642 .69369 m .53655 .69399 L .53663 .69362 L F
.53655 .69399 m .53697 .69505 L .53663 .69362 L F
.672 .343 .408 r
.53692 .69319 m .53663 .69362 L .53885 .69464 L F
.53663 .69362 m .53655 .69399 L .53885 .69464 L F
.447 .648 .944 r
.53655 .69399 m .53802 .69441 L .53697 .69505 L F
.672 .343 .408 r
.53641 .69396 m .53588 .69476 L .53885 .69464 L F
.447 .648 .944 r
.53642 .69369 m .53811 .69435 L .53802 .69441 L F
.53642 .69369 m .53802 .69441 L .53655 .69399 L F
.53811 .69435 m .53885 .69464 L .53697 .69505 L F
.712 .581 .706 r
.53803 .69062 m .53755 .69331 L .5399 .693 L F
.921 .941 .587 r
.53807 .69053 m .53755 .69331 L .53803 .69062 L F
.5386 .68949 m .53807 .69145 L .53807 .69053 L F
.53807 .69145 m .53755 .69331 L .53807 .69053 L F
.672 .343 .408 r
.53763 .69244 m .53692 .69319 L .53804 .69404 L F
.53805 .6932 m .53804 .69404 L .53885 .69464 L F
.53763 .69244 m .53804 .69404 L .53805 .6932 L F
.921 .941 .587 r
.53692 .69319 m .53662 .69363 L .53663 .69362 L F
.656 .292 .344 r
.5334 .69024 m .53341 .69258 L .5374 .69245 L F
.53747 .69236 m .5374 .69245 L .53763 .69244 L F
.5334 .69024 m .5374 .69245 L .53747 .69236 L F
.973 .927 .658 r
.53762 .69202 m .5386 .68949 L .5375 .68943 L F
.921 .941 .587 r
.5386 .68949 m .53748 .69236 L .53804 .69155 L F
.973 .927 .658 r
.53763 .69244 m .5386 .68949 L .53762 .69202 L F
.836 .816 .332 r
.53303 .69499 m .53329 .69333 L .53239 .69309 L F
.53303 .69499 m .5327 .69497 L .53341 .69258 L F
.545 .18 .299 r
.5327 .69497 m .53732 .69261 L .53341 .69258 L F
.53732 .69261 m .53763 .69244 L .5374 .69245 L F
.53732 .69261 m .5374 .69245 L .53341 .69258 L F
.921 .941 .587 r
.5386 .68949 m .53662 .69363 L .53732 .69261 L F
.53756 .69218 m .53732 .69261 L .53748 .69236 L F
.5386 .68949 m .53732 .69261 L .53756 .69218 L F
.5386 .68949 m .53642 .69369 L .53655 .69365 L F
.53673 .6934 m .53655 .69365 L .53662 .69363 L F
.5386 .68949 m .53655 .69365 L .53673 .6934 L F
.545 .18 .299 r
.53732 .69261 m .53692 .69319 L .53763 .69244 L F
.5327 .69497 m .53451 .69484 L .53405 .69427 L F
.53451 .69484 m .53539 .69478 L .53405 .69427 L F
.836 .816 .332 r
.53329 .69333 m .53341 .69258 L .5329 .69284 L F
.53329 .69333 m .5329 .69284 L .53239 .69309 L F
.743 .608 .038 r
.59109 .62196 m .59113 .62346 L .59115 .62133 L F
.754 .25 0 r
.591 .62294 m .59109 .62196 L .59169 .62138 L F
0 0 .411 r
.59158 .62292 m .59148 .62535 L .59111 .62219 L F
.59117 .62213 m .59111 .62219 L .59109 .62196 L F
.59158 .62292 m .59111 .62219 L .59117 .62213 L F
0 0 0 r
.59178 .6215 m .59169 .62138 L .59215 .62082 L F
.59097 .623 m .59152 .62177 L .59178 .6215 L F
.59152 .62177 m .59169 .62138 L .59178 .6215 L F
.754 .25 0 r
.59097 .623 m .59158 .62292 L .59109 .62196 L F
.59097 .623 m .59109 .62196 L .591 .62294 L F
.743 .608 .038 r
.59109 .62196 m .59115 .62133 L .59116 .62038 L F
.752 .447 0 r
.59075 .61941 m .59116 .62038 L .5901 .61708 L F
.854 .607 .068 r
.59075 .61941 m .59109 .62196 L .59116 .62038 L F
0 0 0 r
.47407 .61636 m .47641 .61547 L .47805 .61482 L F
.59 .928 .723 r
.47805 .61482 m .47896 .61374 L .47983 .61332 L F
.592 .933 .745 r
.47805 .61482 m .47641 .61547 L .47896 .61374 L F
.091 0 0 r
.53344 .71933 m .5354 .71843 L .53655 .71651 L F
.503 .901 .774 r
.53681 .71636 m .53787 .71541 L .54029 .71444 L F
.887 .983 .817 r
.54029 .71444 m .53787 .71541 L .54013 .71256 L F
.267 0 0 r
.54138 .71583 m .53787 .71541 L .53824 .7186 L F
.54138 .71583 m .54061 .71595 L .53787 .71541 L F
.976 .774 .565 r
.54061 .71595 m .53909 .71432 L .53787 .71541 L F
.53909 .71432 m .53896 .71419 L .53787 .71541 L F
.503 .901 .774 r
.53655 .71651 m .53787 .71541 L .53681 .71636 L F
.717 .31 .276 r
.53655 .71651 m .53824 .7186 L .53787 .71541 L F
.53655 .71651 m .5354 .71843 L .53824 .7186 L F
.489 .728 .978 r
.42952 .57792 m .42807 .57852 L .42566 .57671 L F
.831 .802 .823 r
.66731 .42625 m .66583 .42805 L .66407 .42734 L F
.988 .721 .364 r
.66583 .42805 m .66505 .42909 L .66407 .42734 L F
.66583 .42805 m .66603 .43051 L .66505 .42909 L F
.484 .059 .157 r
.41491 .63217 m .41347 .63424 L .41111 .63412 L F
.472 .047 .15 r
.4169 .63322 m .41491 .63217 L .41726 .63212 L F
.4169 .63322 m .41347 .63424 L .41491 .63217 L F
.054 .036 .516 r
.52048 .68001 m .51863 .67896 L .52043 .6775 L F
.52048 .68001 m .51908 .68145 L .51863 .67896 L F
.644 .456 .614 r
.65556 .43589 m .65493 .43938 L .65421 .43836 L F
.289 .369 .772 r
.47564 .70452 m .47533 .70497 L .47332 .70487 L F
.57 .722 .945 r
.47332 .70487 m .469 .70275 L .4729 .70358 L F
.984 .848 .466 r
.47245 .70642 m .47332 .70487 L .4729 .70358 L F
.262 .767 .869 r
.47429 .7043 m .47564 .70452 L .47332 .70487 L F
0 0 0 r
.47429 .7043 m .47332 .70487 L .47245 .70642 L F
.32 .632 .963 r
.37526 .62191 m .37725 .62208 L .37658 .62331 L F
.29 .595 .948 r
.37725 .62208 m .37848 .62344 L .37658 .62331 L F
.853 .817 .813 r
.77479 .49052 m .77339 .49185 L .77604 .49198 L F
.781 .614 .673 r
.77339 .49185 m .77628 .49435 L .77604 .49198 L F
.687 .711 .867 r
.77604 .49198 m .77754 .48813 L .77479 .49052 L F
.77604 .49198 m .77824 .49114 L .77754 .48813 L F
.053 .137 .634 r
.46002 .69923 m .46087 .70269 L .46157 .70189 L F
.133 0 .186 r
.2157 .62364 m .21486 .62562 L .21341 .62622 L F
.4 .247 .555 r
.21514 .62822 m .21341 .62622 L .21486 .62562 L F
.21514 .62822 m .21331 .62889 L .21341 .62622 L F
.521 .265 .468 r
.50626 .67902 m .50902 .6806 L .51025 .67635 L F
.582 .343 .519 r
.51025 .67635 m .51385 .67681 L .51219 .67583 L F
.396 .05 .256 r
.50902 .6806 m .51385 .67681 L .51025 .67635 L F
0 0 0 r
.40612 .58948 m .40484 .59009 L .40466 .5905 L F
.291 .742 .958 r
.40448 .5909 m .40466 .5905 L .4023 .59059 L F
0 0 0 r
.4028 .59107 m .4023 .59059 L .40458 .59051 L F
.4028 .59107 m .40458 .59051 L .40466 .5905 L F
.472 .886 .769 r
.40373 .59027 m .40211 .59128 L .4028 .59107 L F
0 0 0 r
.4028 .59107 m .40046 .59197 L .4023 .59059 L F
.472 .886 .769 r
.40211 .59128 m .40208 .5913 L .4028 .59107 L F
0 0 0 r
.40484 .59009 m .4028 .59107 L .40466 .5905 L F
.291 .742 .958 r
.40585 .5911 m .40466 .5905 L .40448 .5909 L F
.694 .932 .966 r
.40612 .58948 m .40585 .5911 L .40847 .58859 L F
.40612 .58948 m .40466 .5905 L .40585 .5911 L F
.51 .191 .361 r
.37082 .60436 m .36909 .6029 L .37148 .60276 L F
.37082 .60436 m .36871 .60492 L .36909 .6029 L F
.656 .612 .793 r
.52274 .65496 m .52399 .65852 L .52276 .65764 L F
.497 .903 .913 r
.52399 .65852 m .52017 .65933 L .52276 .65764 L F
.52399 .65852 m .52315 .65802 L .52113 .65913 L F
.273 .371 .782 r
.52543 .657 m .52399 .65852 L .52274 .65496 L F
.746 .535 .609 r
.52543 .657 m .52315 .65802 L .52399 .65852 L F
.52543 .657 m .52491 .65989 L .52315 .65802 L F
.437 .487 .813 r
.52315 .65802 m .52491 .65989 L .52412 .65748 L F
.52315 .65802 m .52412 .65748 L .52368 .65614 L F
.497 .903 .913 r
.52113 .65913 m .52315 .65802 L .52017 .65933 L F
.771 .39 .333 r
.54373 .70783 m .5402 .7095 L .54227 .7066 L F
.54373 .70783 m .54321 .70999 L .5402 .7095 L F
0 0 0 r
.54637 .70665 m .54321 .70999 L .54373 .70783 L F
.246 .27 .688 r
.46087 .70269 m .46303 .70363 L .46157 .70189 L F
.7 .604 .745 r
.46699 .71633 m .46737 .7196 L .47019 .71694 L F
.014 0 .175 r
.19418 .60879 m .19556 .60795 L .19649 .60575 L F
.131 .133 .592 r
.19478 .61168 m .19556 .60795 L .19418 .60879 L F
.637 .312 .405 r
.60838 .47423 m .60513 .47641 L .60488 .47476 L F
.60838 .47423 m .60761 .47661 L .60513 .47641 L F
.546 .209 .348 r
.61098 .47424 m .60761 .47661 L .60838 .47423 L F
.511 .355 .605 r
.54081 .69609 m .54378 .69404 L .5399 .693 L F
.54081 .69609 m .54449 .6974 L .54378 .69404 L F
.48 .031 .106 r
.35541 .58672 m .35766 .58685 L .35915 .58511 L F
.459 .038 .152 r
.35766 .58685 m .36147 .58476 L .35915 .58511 L F
.685 .51 .643 r
.60295 .47644 m .59922 .47449 L .60346 .47411 L F
.594 .28 .407 r
.60488 .47476 m .60295 .47644 L .60346 .47411 L F
.395 .08 .309 r
.50178 .68262 m .50401 .68144 L .502 .68245 L F
.752 .725 .828 r
.57886 .48022 m .58015 .48336 L .57654 .48322 L F
.594 .393 .578 r
.58015 .48336 m .57744 .48623 L .57654 .48322 L F
.58015 .48336 m .57984 .48592 L .57744 .48623 L F
.642 .574 .763 r
.58103 .47947 m .58015 .48336 L .57886 .48022 L F
.58103 .47947 m .5828 .48339 L .58015 .48336 L F
.594 .253 .361 r
.58015 .48336 m .58206 .48533 L .57984 .48592 L F
.58015 .48336 m .5828 .48339 L .58206 .48533 L F
.429 .598 .915 r
.3699 .61666 m .37006 .61945 L .36828 .61635 L F
.3699 .61666 m .37173 .61928 L .37006 .61945 L F
.571 .62 .862 r
.52995 .67259 m .52647 .67062 L .53017 .67105 L F
.521 .66 .923 r
.53125 .67111 m .52995 .67259 L .53017 .67105 L F
.53125 .67111 m .53256 .67269 L .52995 .67259 L F
0 .166 .602 r
.65609 .4278 m .65213 .4251 L .65332 .42691 L F
.524 .433 .694 r
.50681 .68967 m .51113 .68941 L .51116 .68691 L F
.49 .308 .561 r
.50681 .68967 m .51076 .69192 L .51113 .68941 L F
.131 .133 .592 r
.19478 .61168 m .19592 .61094 L .19556 .60795 L F
.147 0 .317 r
.194 .61383 m .19592 .61094 L .19478 .61168 L F
0 0 0 r
.40924 .5883 m .40847 .58859 L .41055 .58777 L F
.40924 .5883 m .40612 .58948 L .40847 .58859 L F
.156 0 0 r
.55934 .62859 m .56069 .62889 L .56277 .62933 L F
.806 .34 .122 r
.56172 .63063 m .56277 .62933 L .56069 .62889 L F
.56172 .63063 m .56399 .63187 L .56277 .62933 L F
.306 .232 .607 r
.53697 .69505 m .53531 .6988 L .53519 .69622 L F
.842 .568 .523 r
.77749 .4854 m .77895 .4833 L .7772 .48323 L F
.77749 .4854 m .78085 .48615 L .77895 .4833 L F
.669 .521 .675 r
.53693 .64945 m .53458 .65238 L .53462 .64984 L F
.53693 .64945 m .53458 .65238 L .53462 .64984 L F
.488 .128 .281 r
.18521 .55376 m .18244 .55571 L .18192 .55573 L F
.18521 .55376 m .18443 .55565 L .18244 .55571 L F
.353 .771 .978 r
.19301 .55395 m .18927 .55341 L .19044 .5535 L F
.472 .885 .931 r
.19044 .5535 m .18564 .55415 L .18791 .55302 L F
0 0 0 r
.18564 .55415 m .1877 .55308 L .18776 .55309 L F
.18564 .55415 m .18521 .55376 L .1877 .55308 L F
.472 .885 .931 r
.18656 .55403 m .18665 .5537 L .18564 .55415 L F
.1878 .55318 m .18666 .55358 L .18564 .55415 L F
.332 .775 .963 r
.18668 .55357 m .18661 .55356 L .18615 .55352 L F
.18614 .55353 m .18615 .55352 L .18054 .55309 L F
.18668 .55357 m .18615 .55352 L .18614 .55353 L F
.35 .639 .962 r
.18616 .55352 m .18658 .553 L .18707 .55334 L F
.472 .885 .931 r
.19044 .5535 m .1878 .55318 L .18665 .5537 L F
.35 .639 .962 r
.18668 .55356 m .18707 .55334 L .18748 .55363 L F
.18616 .55352 m .18707 .55334 L .18668 .55356 L F
.18666 .55358 m .18616 .55352 L .18668 .55356 L F
.18616 .55352 m .18637 .55342 L .18658 .553 L F
.408 .817 .977 r
.18658 .553 m .18635 .55346 L .1867 .55351 L F
.18658 .553 m .1867 .55351 L .18707 .55334 L F
.35 .639 .962 r
.18637 .55342 m .18708 .55309 L .18658 .553 L F
.408 .817 .977 r
.18658 .553 m .18269 .55291 L .18635 .55346 L F
.18707 .55334 m .1867 .55351 L .18748 .55363 L F
.35 .639 .962 r
.18564 .55415 m .18614 .55354 L .18666 .55358 L F
0 0 0 r
.18564 .55415 m .1849 .55507 L .18521 .55376 L F
.1849 .55507 m .18443 .55565 L .18449 .5555 L F
.1849 .55507 m .18449 .5555 L .18521 .55376 L F
.332 .775 .963 r
.18526 .55469 m .18358 .55466 L .18463 .55519 L F
.472 .885 .931 r
.18666 .55358 m .18621 .55373 L .18564 .55415 L F
.35 .639 .962 r
.18564 .55415 m .18666 .55358 L .18748 .55363 L F
.332 .775 .963 r
.18668 .55357 m .18666 .55358 L .18667 .55358 L F
.568 .579 .825 r
.18463 .55519 m .18443 .55565 L .18564 .55415 L F
.18463 .55519 m .18564 .55415 L .18748 .55363 L F
.332 .775 .963 r
.18748 .55363 m .18668 .55357 L .18463 .55519 L F
.35 .639 .962 r
.18666 .55358 m .18668 .55356 L .18748 .55363 L F
.332 .775 .963 r
.18667 .55358 m .18616 .55375 L .18526 .55469 L F
.18666 .55358 m .18616 .55375 L .18667 .55358 L F
.35 .639 .962 r
.18564 .55415 m .18621 .55373 L .18614 .55354 L F
.332 .775 .963 r
.18616 .55375 m .18358 .55466 L .18526 .55469 L F
.18621 .55373 m .18071 .55318 L .18358 .55466 L F
.18666 .55358 m .18614 .55354 L .18621 .55373 L F
.18614 .55354 m .18071 .55318 L .18621 .55373 L F
.1867 .55351 m .18269 .55291 L .18668 .55357 L F
.35 .639 .962 r
.18614 .55354 m .18675 .55334 L .18616 .55352 L F
.332 .775 .963 r
.18668 .55357 m .18071 .55318 L .18666 .55358 L F
.35 .639 .962 r
.18614 .55354 m .18616 .55352 L .18666 .55358 L F
.332 .775 .963 r
.18661 .55356 m .18083 .55307 L .18054 .55309 L F
.35 .639 .962 r
.18621 .55373 m .18675 .55334 L .18614 .55354 L F
.472 .885 .931 r
.18666 .55358 m .18673 .5535 L .18621 .55373 L F
.18673 .5535 m .18708 .55309 L .18621 .55373 L F
.18673 .5535 m .18621 .55373 L .18621 .55373 L F
.1878 .55318 m .18744 .55313 L .18666 .55358 L F
.18744 .55313 m .18708 .55309 L .18666 .55358 L F
.35 .639 .962 r
.18675 .55334 m .18708 .55309 L .18616 .55352 L F
.332 .775 .963 r
.18668 .55357 m .18054 .55309 L .18071 .55318 L F
.408 .817 .977 r
.18658 .553 m .18475 .55252 L .18269 .55291 L F
0 0 0 r
.18454 .5526 m .18269 .55291 L .18475 .55252 L F
.332 .775 .963 r
.18661 .55356 m .18269 .55291 L .18142 .55312 L F
0 0 0 r
.18267 .55337 m .18269 .55291 L .18454 .5526 L F
.332 .775 .963 r
.18142 .55312 m .18269 .55291 L .18083 .55307 L F
.18748 .55363 m .1867 .55351 L .18668 .55357 L F
.472 .885 .931 r
.19044 .5535 m .18665 .5537 L .18656 .55403 L F
.353 .771 .978 r
.18927 .55341 m .18708 .55309 L .18867 .55328 L F
.18927 .55341 m .18867 .55328 L .19044 .5535 L F
0 0 0 r
.18776 .55309 m .1877 .55308 L .18791 .55302 L F
.882 .785 .75 r
.54257 .70173 m .53936 .70109 L .54124 .69904 L F
.866 .562 .471 r
.54257 .70173 m .5415 .70388 L .53936 .70109 L F
.296 .237 .62 r
.54419 .69826 m .54257 .70173 L .54124 .69904 L F
.54419 .69826 m .54402 .70163 L .54257 .70173 L F
.3 .286 .676 r
.54402 .70163 m .54478 .70406 L .54257 .70173 L F
.46 .821 .995 r
.21283 .54468 m .21504 .54424 L .21669 .54495 L F
.508 .879 .978 r
.21504 .54424 m .21878 .54394 L .21669 .54495 L F
.179 0 0 r
.6465 .46861 m .64765 .46924 L .64579 .47052 L F
.6465 .46861 m .64887 .46814 L .64765 .46924 L F
.741 .653 .763 r
.58356 .47429 m .58479 .47755 L .58114 .47724 L F
.711 .485 .579 r
.58479 .47755 m .58103 .47947 L .58114 .47724 L F
.58479 .47755 m .58481 .47994 L .58103 .47947 L F
.887 .983 .817 r
.54029 .71444 m .54013 .71256 L .54233 .71384 L F
.654 .742 .915 r
.34225 .63233 m .33939 .6316 L .34065 .62935 L F
.487 .65 .931 r
.33939 .6316 m .34225 .63233 L .34069 .632 L F
0 0 .036 r
.34295 .62832 m .34225 .63233 L .34065 .62935 L F
.34295 .62832 m .3427 .6309 L .34225 .63233 L F
.624 .926 .973 r
.3427 .6309 m .34069 .632 L .34225 .63233 L F
.568 .542 .786 r
.76766 .49528 m .76908 .49111 L .76696 .4916 L F
.76766 .49528 m .7702 .49481 L .76908 .49111 L F
.407 .138 .391 r
.23778 .57102 m .23706 .57314 L .23501 .57366 L F
.024 0 .199 r
.23909 .56999 m .23706 .57314 L .23778 .57102 L F
.491 .047 .122 r
.52647 .67062 m .52533 .67195 L .53017 .67105 L F
.173 0 .316 r
.2276 .59688 m .22702 .59924 L .22551 .59995 L F
.426 .218 .492 r
.22722 .60173 m .22551 .59995 L .22702 .59924 L F
.22722 .60173 m .22523 .60239 L .22551 .59995 L F
.655 .741 .913 r
.4781 .69876 m .48 .70121 L .48017 .69855 L F
.489 .492 .787 r
.47727 .69519 m .4781 .69876 L .48017 .69855 L F
.414 .824 .976 r
.19966 .57237 m .20394 .57249 L .20147 .57317 L F
.20394 .57249 m .19966 .57237 L .20147 .57317 L F
.989 .765 .505 r
.6258 .41848 m .62687 .42185 L .62548 .42134 L F
.988 .815 .581 r
.62548 .42134 m .62687 .42185 L .62631 .42437 L F
.758 .69 .787 r
.62936 .41903 m .62687 .42185 L .6258 .41848 L F
.791 .623 .674 r
.19172 .58796 m .19576 .58827 L .19419 .58708 L F
.19172 .58796 m .19347 .59319 L .19576 .58827 L F
.905 .502 .106 r
.56696 .64615 m .56586 .64553 L .56521 .64372 L F
.633 .114 0 r
.56696 .64615 m .56789 .6476 L .56586 .64553 L F
.831 .802 .823 r
.66731 .42625 m .66407 .42734 L .66649 .42459 L F
.497 .636 .915 r
.66872 .42404 m .66731 .42625 L .66649 .42459 L F
.66872 .42404 m .67087 .42692 L .66731 .42625 L F
.579 .627 .864 r
.48451 .61263 m .48391 .61457 L .48259 .61167 L F
.137 .032 .461 r
.48451 .61263 m .48336 .61669 L .48391 .61457 L F
.865 .529 .413 r
.50684 .71952 m .5078 .71929 L .50961 .71889 L F
.50684 .71952 m .50732 .72169 L .50542 .72068 L F
.698 .421 .501 r
.51014 .72111 m .50684 .71952 L .50961 .71889 L F
.51014 .72111 m .50732 .72169 L .50684 .71952 L F
.865 .529 .413 r
.50684 .71952 m .50542 .72068 L .5078 .71929 L F
.765 .423 .405 r
.42398 .62215 m .42424 .62055 L .42029 .62047 L F
.541 .214 .364 r
.42645 .62213 m .42424 .62055 L .42398 .62215 L F
.867 .441 .016 r
.65937 .43171 m .65969 .4306 L .65851 .42934 L F
.65937 .43171 m .66071 .43292 L .65969 .4306 L F
.635 .729 .915 r
.49095 .69243 m .49268 .6942 L .49397 .69212 L F
.737 .546 .635 r
.48221 .71957 m .47943 .72218 L .48212 .7199 L F
.63 .476 .655 r
.52059 .64238 m .52323 .64166 L .52278 .63882 L F
.396 .313 .644 r
.52278 .63882 m .52494 .63983 L .5248 .63733 L F
.52278 .63882 m .52323 .64166 L .52494 .63983 L F
.356 .683 .979 r
.54645 .66584 m .54747 .66513 L .54596 .66534 L F
.54645 .66584 m .54596 .66534 L .54384 .66562 L F
.724 .405 .44 r
.54718 .66658 m .54645 .66584 L .5469 .66725 L F
.54849 .66349 m .54645 .66584 L .54718 .66658 L F
.725 .852 .942 r
.46074 .68082 m .46229 .682 L .46407 .68063 L F
.527 .427 .685 r
.33319 .60598 m .33529 .60543 L .33495 .60241 L F
.463 .381 .679 r
.33398 .60748 m .33529 .60543 L .33319 .60598 L F
.997 .776 .427 r
.59276 .62622 m .59171 .62779 L .59261 .62863 L F
.975 .679 .385 r
.59148 .62535 m .59171 .62779 L .59276 .62622 L F
.59148 .62535 m .59171 .62779 L .59276 .62622 L F
.573 .83 .994 r
.42255 .58456 m .42366 .58276 L .42106 .58378 L F
.42255 .58456 m .42512 .58388 L .42366 .58276 L F
.214 0 0 r
.36147 .58476 m .36384 .58477 L .36517 .58442 L F
.137 0 0 r
.36517 .58442 m .36384 .58477 L .36739 .58434 L F
.563 .385 .598 r
.54824 .68767 m .55112 .68741 L .55129 .68363 L F
.473 .194 .41 r
.55112 .68741 m .5482 .6898 L .54824 .68767 L F
.5482 .6898 m .55112 .68741 L .54824 .68767 L F
.55112 .68741 m .55055 .68935 L .5482 .6898 L F
.5482 .6898 m .55055 .68935 L .55112 .68741 L F
.524 .243 .43 r
.55112 .68741 m .55055 .68935 L .54824 .68767 L F
.496 .254 .477 r
.54824 .68767 m .55055 .68935 L .5482 .6898 L F
.698 .492 .606 r
.59539 .47426 m .59717 .47733 L .59309 .47703 L F
.695 .518 .644 r
.59922 .47449 m .59717 .47733 L .59539 .47426 L F
.813 .544 .532 r
.62593 .4308 m .62608 .43307 L .62942 .43372 L F
.812 .639 .668 r
.62608 .43307 m .62804 .43672 L .62942 .43372 L F
.594 .212 .287 r
.55367 .63015 m .55499 .63157 L .55459 .62951 L F
.724 .303 .248 r
.55459 .62951 m .55499 .63157 L .55647 .63095 L F
0 0 .213 r
.50709 .64947 m .50737 .65214 L .5095 .64945 L F
.233 0 .24 r
.21754 .62278 m .21486 .62562 L .2157 .62364 L F
0 0 0 r
.53931 .67742 m .53745 .67873 L .54001 .67662 L F
.54084 .67663 m .54001 .67662 L .54215 .67608 L F
.54084 .67663 m .53931 .67742 L .54001 .67662 L F
.059 .172 .668 r
.5369 .68741 m .5386 .68949 L .53803 .69062 L F
.43 .273 .566 r
.5375 .68943 m .5386 .68949 L .5369 .68741 L F
.741 .947 .947 r
.47928 .73826 m .48065 .73858 L .48335 .73716 L F
.357 .771 .98 r
.39969 .57945 m .40187 .57926 L .40347 .57994 L F
.281 .769 .912 r
.40187 .57926 m .40568 .57925 L .40347 .57994 L F
.801 .932 .919 r
.45546 .59034 m .45602 .58848 L .45739 .591 L F
.33 .8 .923 r
.40568 .57925 m .40799 .57885 L .40936 .57912 L F
.538 .906 .96 r
.40936 .57912 m .41018 .57799 L .41162 .57879 L F
.40936 .57912 m .40799 .57885 L .41018 .57799 L F
.588 .609 .841 r
.449 .59394 m .45136 .59339 L .44994 .59022 L F
.695 .701 .851 r
.80061 .50494 m .80267 .50347 L .79904 .50277 L F
.576 .426 .64 r
.51181 .65874 m .51199 .66099 L .51422 .65829 L F
.437 .307 .605 r
.52059 .64238 m .52335 .64234 L .52323 .64166 L F
.52059 .64238 m .52113 .6446 L .52335 .64234 L F
.245 .074 .44 r
.23706 .57314 m .23534 .57601 L .23501 .57366 L F
.231 0 0 r
.17772 .54225 m .18175 .5419 L .17954 .54226 L F
.746 .735 .842 r
.79296 .5029 m .79434 .50443 L .79666 .50324 L F
.727 .647 .77 r
.52367 .70176 m .52571 .69823 L .52473 .69883 L F
.329 0 .17 r
.64058 .47319 m .64094 .4719 L .64268 .47245 L F
.339 0 .009 r
.64094 .4719 m .64372 .47147 L .64268 .47245 L F
.481 .324 .59 r
.52125 .7047 m .52428 .70483 L .52367 .70176 L F
.394 0 .094 r
.52115 .70544 m .52428 .70483 L .52125 .7047 L F
.903 .817 .753 r
.54692 .67153 m .54865 .67308 L .54999 .67087 L F
.682 .244 .204 r
.55451 .63221 m .5533 .63374 L .55098 .63186 L F
.863 .489 .339 r
.55519 .63428 m .5533 .63374 L .55451 .63221 L F
.635 .317 .415 r
.61699 .47634 m .62062 .4739 L .61946 .47623 L F
.61699 .47634 m .61683 .47463 L .62062 .4739 L F
.58 .217 .319 r
.62062 .4739 m .62201 .47616 L .61946 .47623 L F
.62062 .4739 m .62295 .47417 L .62201 .47616 L F
.786 .95 .927 r
.59636 .46278 m .59162 .46493 L .59549 .46191 L F
.854 .954 .877 r
.59905 .45993 m .59636 .46278 L .59549 .46191 L F
.634 .868 .508 r
.4796 .73391 m .47721 .737 L .4776 .73626 L F
.4796 .73391 m .4776 .73626 L .47783 .73594 L F
.4796 .73391 m .47767 .73612 L .47836 .73272 L F
.57 .625 .867 r
.48548 .73651 m .48335 .73716 L .48127 .73408 L F
.587 .644 .874 r
.47927 .73393 m .48024 .73772 L .48274 .73511 L F
.47915 .73389 m .47919 .73404 L .47927 .73393 L F
.47919 .73404 m .48024 .73772 L .47927 .73393 L F
.634 .868 .508 r
.47783 .73594 m .4776 .73626 L .47767 .73612 L F
0 .254 .712 r
.47721 .737 m .47841 .7375 L .47767 .73612 L F
.47721 .737 m .47928 .73826 L .47841 .7375 L F
.858 .984 .852 r
.52494 .63983 m .52848 .63748 L .5248 .63733 L F
.585 .266 .395 r
.52848 .63748 m .53035 .63956 L .53058 .63797 L F
.52848 .63748 m .53035 .63956 L .53058 .63797 L F
.589 .768 .964 r
.63792 .41794 m .63548 .41864 L .63375 .41706 L F
.181 .267 .717 r
.63781 .42063 m .63548 .41864 L .63792 .41794 L F
.5 .855 .991 r
.41162 .57879 m .41389 .5782 L .41542 .57878 L F
.462 .803 .999 r
.41389 .5782 m .41751 .57866 L .41542 .57878 L F
.38 .235 .555 r
.55129 .68363 m .5529 .68639 L .55335 .68402 L F
.55129 .68363 m .55112 .68741 L .5529 .68639 L F
.57 .108 .117 r
.38864 .63828 m .38709 .6398 L .38479 .6393 L F
.121 0 0 r
.39061 .63898 m .38709 .6398 L .38864 .63828 L F
.594 .28 .407 r
.60488 .47476 m .60513 .47641 L .60295 .47644 L F
.49 .333 .594 r
.53931 .67742 m .53673 .68068 L .53745 .67873 L F
.613 .545 .754 r
.33991 .62376 m .34144 .62001 L .33915 .62074 L F
.33991 .62376 m .34276 .62357 L .34144 .62001 L F
.591 .767 .963 r
.33912 .62573 m .34276 .62357 L .33991 .62376 L F
.744 .56 .645 r
.80367 .4946 m .80774 .49522 L .80533 .49203 L F
.425 .716 .985 r
.48057 .73256 m .4796 .73391 L .47836 .73272 L F
.315 .565 .927 r
.48057 .73256 m .48127 .73408 L .4796 .73391 L F
.96 .944 .694 r
.59091 .61276 m .59118 .61496 L .59269 .61169 L F
.858 .992 .737 r
.59091 .61276 m .59269 .61169 L .59298 .60998 L F
.31 .773 .944 r
.18175 .5419 m .18364 .54165 L .18544 .54207 L F
.186 .687 .912 r
.18364 .54165 m .1875 .5422 L .18544 .54207 L F
.437 0 0 r
.53662 .64332 m .53431 .64406 L .532 .64346 L F
0 .244 .717 r
.53662 .64332 m .53729 .64331 L .53431 .64406 L F
.53662 .64332 m .53814 .64427 L .53729 .64331 L F
.972 .741 .531 r
.5918 .63429 m .59411 .63804 L .59309 .63486 L F
.5918 .63429 m .59133 .63682 L .59411 .63804 L F
.919 .7 .589 r
.59046 .63902 m .59411 .63804 L .59133 .63682 L F
.59046 .63902 m .59217 .63998 L .59411 .63804 L F
.641 .505 .681 r
.50782 .70862 m .50792 .71069 L .50981 .70868 L F
.394 .333 .67 r
.33398 .60748 m .33413 .61174 L .33607 .61071 L F
.533 .484 .748 r
.33467 .61422 m .33607 .61071 L .33413 .61174 L F
.683 .583 .736 r
.5018 .69624 m .50185 .69734 L .50517 .69663 L F
.625 .48 .665 r
.50241 .70081 m .50517 .69663 L .50185 .69734 L F
.304 .743 .966 r
.20393 .55566 m .20569 .55548 L .20188 .55489 L F
.423 .497 .831 r
.37401 .61879 m .37265 .6211 L .37173 .61928 L F
.37401 .61879 m .37526 .62191 L .37265 .6211 L F
.374 .194 .504 r
.21055 .63368 m .21101 .63677 L .20858 .63678 L F
.297 .076 .4 r
.21101 .63677 m .20809 .63937 L .20858 .63678 L F
.741 .947 .947 r
.47928 .73826 m .48335 .73716 L .48043 .73797 L F
.661 .968 .911 r
.48413 .73574 m .48335 .73716 L .48548 .73651 L F
.48413 .73574 m .48043 .73797 L .48335 .73716 L F
.762 .641 .727 r
.67429 .4304 m .67699 .43068 L .67509 .43003 L F
.311 0 .111 r
.37739 .59969 m .37609 .60183 L .37387 .60239 L F
.177 0 .037 r
.37814 .60104 m .37739 .59969 L .37973 .59877 L F
.37814 .60104 m .37609 .60183 L .37739 .59969 L F
.678 .648 .813 r
.59313 .65787 m .58946 .65527 L .59078 .65859 L F
.5 .192 .375 r
.52887 .68139 m .52792 .68392 L .52575 .68412 L F
.558 .249 .401 r
.5311 .68313 m .52887 .68139 L .53136 .68123 L F
.5311 .68313 m .52792 .68392 L .52887 .68139 L F
.438 .366 .679 r
.54535 .69076 m .54655 .69315 L .5482 .69231 L F
.54535 .69076 m .54655 .69315 L .5482 .69231 L F
.743 .41 .418 r
.77429 .48499 m .77749 .4854 L .7772 .48323 L F
.588 .373 .555 r
.53358 .70199 m .53345 .70458 L .5306 .70498 L F
.467 .323 .602 r
.53531 .6988 m .53569 .70142 L .53358 .70199 L F
.477 .281 .535 r
.53572 .70394 m .53358 .70199 L .53569 .70142 L F
.53572 .70394 m .53345 .70458 L .53358 .70199 L F
.747 .506 .566 r
.6281 .4284 m .62463 .4277 L .62631 .42437 L F
.6281 .4284 m .62819 .42867 L .62463 .4277 L F
.786 .733 .803 r
.62758 .42885 m .62243 .43038 L .62788 .42859 L F
.62819 .42867 m .62593 .4308 L .62243 .43038 L F
.967 .696 .27 r
.6253 .43223 m .62573 .43127 L .62681 .42863 L F
.62573 .43127 m .62593 .4308 L .62616 .43023 L F
.62573 .43127 m .62616 .43023 L .62681 .42863 L F
.786 .733 .803 r
.62696 .42834 m .62243 .43038 L .62463 .4277 L F
.62788 .42859 m .62669 .42898 L .62696 .42834 L F
.62669 .42898 m .62243 .43038 L .62696 .42834 L F
.62819 .42867 m .62758 .42885 L .62788 .42859 L F
.81 .999 .791 r
.62681 .42863 m .62807 .42841 L .62944 .42575 L F
.62807 .42841 m .6281 .4284 L .62811 .42837 L F
.62807 .42841 m .62811 .42837 L .62944 .42575 L F
.82 .997 .85 r
.62681 .42863 m .62819 .42867 L .6281 .4284 L F
.81 .999 .8 r
.62944 .42575 m .6281 .4284 L .63086 .42523 L F
.925 .542 .159 r
.59245 .6083 m .59185 .60565 L .59057 .60475 L F
.347 .094 .38 r
.58185 .63757 m .58014 .64047 L .57983 .63803 L F
.065 .39 .85 r
.54363 .64922 m .54397 .64799 L .54191 .64684 L F
.951 .623 .208 r
.54533 .65084 m .54397 .64799 L .54363 .64922 L F
.425 .492 .825 r
.54363 .64922 m .54522 .65097 L .54533 .65084 L F
.54522 .65097 m .54635 .65221 L .54533 .65084 L F
.584 .641 .874 r
.54533 .65084 m .54796 .65076 L .54786 .65059 L F
.54574 .64924 m .54786 .65059 L .54618 .64751 L F
.54533 .65084 m .54786 .65059 L .54574 .64924 L F
.54533 .65084 m .54574 .64924 L .54572 .65042 L F
.54574 .64924 m .54618 .64751 L .54572 .65042 L F
.951 .623 .208 r
.54533 .65084 m .54427 .64942 L .54397 .64799 L F
.756 .503 .551 r
.54397 .64799 m .54294 .64861 L .54257 .64824 L F
.54294 .64861 m .5403 .65019 L .54257 .64824 L F
0 .223 .642 r
.54187 .64756 m .54257 .64824 L .54118 .64707 L F
.756 .503 .551 r
.54397 .64799 m .54469 .65142 L .5403 .65019 L F
0 .223 .642 r
.54341 .64864 m .54257 .64824 L .54187 .64756 L F
.487 .327 .59 r
.54572 .65042 m .54414 .64822 L .54257 .64824 L F
.54414 .64822 m .54397 .64799 L .54382 .64802 L F
.54414 .64822 m .54382 .64802 L .54257 .64824 L F
.504 .829 .528 r
.54533 .65084 m .54572 .65042 L .54551 .65063 L F
.951 .623 .208 r
.54533 .65084 m .54469 .65142 L .54427 .64942 L F
.504 .829 .528 r
.54533 .65084 m .54551 .65063 L .54469 .65142 L F
.425 .492 .825 r
.54635 .65221 m .54651 .65239 L .54533 .65084 L F
.604 .269 .375 r
.57744 .48623 m .57636 .48849 L .57417 .4882 L F
.759 .553 .618 r
.57984 .48592 m .57636 .48849 L .57744 .48623 L F
0 0 .092 r
.55976 .59939 m .55934 .60216 L .55977 .59905 L F
.523 .363 .606 r
.55656 .59992 m .55934 .60216 L .55976 .59939 L F
.857 .404 .087 r
.56521 .64372 m .56204 .6402 L .56548 .64074 L F
.94 .725 .585 r
.66375 .43785 m .6644 .43943 L .6628 .43624 L F
.231 .362 .79 r
.66723 .44046 m .6644 .43943 L .66375 .43785 L F
.153 .409 .853 r
.66835 .44204 m .6644 .43943 L .66723 .44046 L F
.282 .129 .488 r
.23528 .58372 m .23378 .58242 L .23559 .58169 L F
.23528 .58372 m .23363 .58487 L .23378 .58242 L F
.21 0 0 r
.1943 .55321 m .19301 .55395 L .19044 .5535 L F
.658 .558 .73 r
.68776 .43704 m .68735 .43946 L .68459 .43433 L F
.675 .574 .734 r
.68552 .43905 m .68735 .43946 L .68776 .43704 L F
.68552 .43905 m .68776 .43704 L .68786 .43866 L F
.413 .152 .405 r
.68786 .43866 m .68516 .44138 L .68552 .43905 L F
.463 .381 .679 r
.33398 .60748 m .33575 .60774 L .33529 .60543 L F
.394 .333 .67 r
.33398 .60748 m .33607 .61071 L .33575 .60774 L F
.82 .997 .85 r
.62681 .42863 m .62593 .4308 L .62819 .42867 L F
.967 .696 .27 r
.6253 .43223 m .62608 .43307 L .62593 .4308 L F
.459 0 0 r
.34396 .62959 m .34369 .63021 L .34295 .62832 L F
.55 .286 .468 r
.50401 .68144 m .50646 .68123 L .50626 .67902 L F
.521 .265 .468 r
.50626 .67902 m .50646 .68123 L .50902 .6806 L F
.417 .249 .544 r
.22072 .61622 m .21929 .61437 L .22146 .61338 L F
.22072 .61622 m .21915 .61727 L .21929 .61437 L F
.289 .369 .772 r
.47564 .70452 m .4768 .70777 L .47533 .70497 L F
.941 .596 .338 r
.47533 .70497 m .4768 .70777 L .47579 .70798 L F
.167 .287 .744 r
.47827 .70707 m .4768 .70777 L .47564 .70452 L F
.621 .664 .87 r
.47748 .70671 m .47579 .70798 L .47827 .70707 L F
.3 .033 .331 r
.47215 .70903 m .47533 .70497 L .47383 .7083 L F
.941 .596 .338 r
.47533 .70497 m .47579 .70798 L .4731 .70992 L F
.621 .664 .87 r
.47463 .70545 m .47559 .70753 L .47748 .70671 L F
.47559 .70753 m .47579 .70798 L .47748 .70671 L F
.3 .033 .331 r
.47105 .71044 m .47215 .70903 L .4731 .70992 L F
.47215 .70903 m .47383 .7083 L .4731 .70992 L F
.107 .16 .635 r
.21133 .57923 m .21257 .57826 L .21095 .57641 L F
.38 .282 .617 r
.21114 .58112 m .21257 .57826 L .21133 .57923 L F
.607 .109 .044 r
.3882 .62704 m .39055 .62786 L .39215 .6267 L F
.458 0 0 r
.39055 .62786 m .39413 .62757 L .39215 .6267 L F
.34 0 .036 r
.36969 .5843 m .37199 .58396 L .37344 .58212 L F
.718 .315 .283 r
.37344 .58212 m .37199 .58396 L .37571 .58439 L F
.51 .27 .487 r
.64319 .44006 m .64578 .44064 L .64563 .43904 L F
.64319 .44006 m .644 .44229 L .64578 .44064 L F
0 .166 .602 r
.65609 .4278 m .65332 .42691 L .65376 .42703 L F
0 .251 .715 r
.65732 .42822 m .65609 .4278 L .65376 .42703 L F
.65732 .42822 m .65851 .42934 L .65609 .4278 L F
.4 .522 .865 r
.67232 .42743 m .6716 .42862 L .67087 .42692 L F
.679 .888 .975 r
.67232 .42743 m .67499 .42759 L .6716 .42862 L F
.67232 .42743 m .67499 .42759 L .6716 .42862 L F
.676 .558 .714 r
.53684 .64716 m .53693 .64945 L .53914 .6466 L F
.846 .648 .635 r
.33912 .62573 m .34065 .62935 L .34175 .62683 L F
.613 .873 .534 r
.41817 .62027 m .41912 .61893 L .42063 .61739 L F
.986 .757 .506 r
.41912 .61893 m .42029 .62047 L .42063 .61739 L F
.864 .749 .734 r
.54984 .66414 m .55387 .66364 L .55253 .66635 L F
.719 .771 .894 r
.79555 .50117 m .79296 .5029 L .79666 .50324 L F
.581 .657 .889 r
.79666 .50324 m .79816 .50017 L .79555 .50117 L F
.79666 .50324 m .79904 .50277 L .79816 .50017 L F
.731 .628 .744 r
.80672 .49733 m .80337 .49703 L .8053 .4979 L F
.80672 .49733 m .80367 .4946 L .80337 .49703 L F
.80672 .49733 m .80774 .49522 L .80367 .4946 L F
.87 .883 .842 r
.80505 .50049 m .80672 .49733 L .8053 .4979 L F
.454 .36 .659 r
.68294 .44489 m .68376 .4479 L .68178 .44878 L F
.147 0 .075 r
.68376 .4479 m .68097 .45019 L .68178 .44878 L F
.14 .346 .806 r
.23959 .55176 m .24031 .55554 L .23764 .55215 L F
.223 0 .292 r
.24116 .55497 m .24106 .55735 L .24031 .55554 L F
.24116 .55497 m .24031 .55554 L .24127 .55499 L F
.14 .346 .806 r
.23959 .55176 m .24127 .55499 L .24031 .55554 L F
.455 .393 .698 r
.76696 .4916 m .76805 .48912 L .76633 .49022 L F
.183 0 0 r
.1875 .5422 m .18947 .5425 L .19155 .54244 L F
.09 0 0 r
.18947 .5425 m .19344 .5422 L .19155 .54244 L F
.641 .464 .628 r
.41582 .62276 m .41834 .62314 L .41817 .62027 L F
.371 .628 .953 r
.41817 .62027 m .42029 .62047 L .41912 .61893 L F
.604 .49 .696 r
.41834 .62314 m .42029 .62047 L .41817 .62027 L F
0 0 .232 r
.20388 .6464 m .20334 .64896 L .20282 .64946 L F
0 0 0 r
.20334 .64896 m .20231 .65178 L .20282 .64946 L F
.333 .812 .772 r
.47579 .70798 m .4768 .70777 L .47827 .70707 L F
.619 .77 .953 r
.44628 .58733 m .44823 .58908 L .44877 .58807 L F
.46 .037 .149 r
.51785 .64502 m .51475 .64643 L .51651 .64547 L F
.474 0 0 r
.52008 .64582 m .51785 .64502 L .51651 .64547 L F
.593 .516 .736 r
.24948 .55864 m .24679 .55973 L .24628 .55674 L F
.681 .455 .572 r
.24948 .55864 m .24668 .56044 L .24679 .55973 L F
.625 .48 .665 r
.50241 .70081 m .50544 .70041 L .50517 .69663 L F
.59 .476 .691 r
.20915 .58252 m .21212 .58469 L .21114 .58112 L F
.20915 .58252 m .20981 .58516 L .21212 .58469 L F
.396 .05 .256 r
.50902 .6806 m .51118 .68036 L .51385 .67681 L F
.824 .679 .704 r
.51118 .68036 m .51457 .67751 L .51385 .67681 L F
.619 .074 0 r
.51385 .67681 m .51457 .67751 L .51219 .67583 L F
.59 .211 .292 r
.51219 .67583 m .51457 .67751 L .51537 .67568 L F
.526 .658 .92 r
.36131 .63738 m .36133 .63517 L .35929 .63536 L F
.36131 .63738 m .36337 .63707 L .36133 .63517 L F
.338 .181 .516 r
.19098 .58811 m .19172 .58796 L .19153 .58629 L F
.537 .32 .533 r
.19153 .58629 m .19172 .58796 L .19419 .58708 L F
.985 .726 .451 r
.67214 .44254 m .67109 .44383 L .67069 .44158 L F
.67214 .44254 m .67228 .44505 L .67109 .44383 L F
.278 0 .021 r
.37592 .58425 m .37796 .58387 L .37951 .58184 L F
.25 0 0 r
.37796 .58387 m .38179 .58207 L .37951 .58184 L F
.37796 .58387 m .38027 .58348 L .38179 .58207 L F
.185 0 0 r
.37675 .58379 m .37975 .58353 L .37796 .58387 L F
.37975 .58353 m .38027 .58348 L .37796 .58387 L F
.278 0 .021 r
.37571 .58439 m .37796 .58387 L .37592 .58425 L F
.642 .923 .976 r
.42134 .57781 m .42232 .57643 L .42347 .57688 L F
.42134 .57781 m .4193 .57765 L .42232 .57643 L F
.3 .052 .36 r
.48804 .71641 m .48963 .71614 L .48997 .71391 L F
.804 .718 .771 r
.48653 .71329 m .48804 .71641 L .48997 .71391 L F
.516 .233 .424 r
.48997 .71391 m .48963 .71614 L .49228 .71556 L F
.563 .203 .315 r
.48997 .71391 m .49228 .71556 L .49321 .71347 L F
.816 .63 .651 r
.77749 .4854 m .78089 .48846 L .78085 .48615 L F
.802 .641 .683 r
.59217 .63998 m .59515 .6426 L .59576 .64195 L F
.455 .393 .698 r
.76696 .4916 m .76908 .49111 L .76805 .48912 L F
.322 .147 .482 r
.22957 .59377 m .22933 .5962 L .2276 .59688 L F
.468 .273 .532 r
.22933 .5962 m .22702 .59924 L .2276 .59688 L F
.7 .604 .745 r
.46699 .71633 m .47019 .71694 L .46772 .71596 L F
.83 .601 .051 r
.54874 .70706 m .54833 .7046 L .54854 .707 L F
.474 .053 .16 r
.42918 .62912 m .4279 .63113 L .42536 .63115 L F
.301 0 0 r
.4315 .629 m .4279 .63113 L .42918 .62912 L F
.449 .24 .503 r
.47417 .6216 m .47038 .62045 L .4721 .62256 L F
.583 .883 .589 r
.51088 .6556 m .51383 .65271 L .51294 .65455 L F
0 0 0 r
.51294 .65455 m .51383 .65271 L .5152 .6513 L F
.62 .948 .937 r
.41746 .58472 m .41692 .58597 L .41884 .58466 L F
.41746 .58472 m .41497 .58594 L .41692 .58597 L F
0 0 0 r
.47555 .68775 m .47772 .68436 L .47776 .68627 L F
.687 .803 .937 r
.47462 .68625 m .47555 .68775 L .47776 .68627 L F
.513 .527 .807 r
.46699 .71633 m .46772 .71241 L .46554 .71294 L F
.46699 .71633 m .46772 .71596 L .46772 .71241 L F
.753 .693 .794 r
.47292 .73383 m .46994 .73376 L .47107 .73052 L F
.559 .057 .017 r
.47292 .73383 m .47382 .7353 L .46994 .73376 L F
.507 .581 .864 r
.47475 .73253 m .47292 .73383 L .47128 .73091 L F
.47475 .73253 m .47128 .73091 L .47141 .73071 L F
.411 .362 .694 r
.47166 .72981 m .47107 .73052 L .47099 .72846 L F
.47165 .72978 m .47099 .72846 L .47096 .7275 L F
.47166 .72981 m .47099 .72846 L .47165 .72978 L F
.507 .581 .864 r
.47141 .73071 m .47128 .73091 L .47107 .73052 L F
0 .007 .558 r
.46994 .73376 m .47007 .73081 L .47107 .73052 L F
.277 .352 .761 r
.47096 .7275 m .47347 .72954 L .472 .72956 L F
.411 .362 .694 r
.47347 .72954 m .47169 .73027 L .47253 .72877 L F
0 0 0 r
.47179 .73009 m .47177 .73014 L .47198 .72979 L F
.484 .581 .877 r
.47186 .7302 m .47475 .73253 L .47141 .73071 L F
0 0 0 r
.47177 .73014 m .47076 .73272 L .47194 .72987 L F
.47177 .73014 m .47194 .72987 L .47198 .72979 L F
.484 .581 .877 r
.47169 .73027 m .47141 .73071 L .47107 .73052 L F
.47186 .7302 m .47141 .73071 L .47169 .73027 L F
.47347 .72954 m .47462 .73222 L .47186 .7302 L F
.47462 .73222 m .47475 .73253 L .47186 .7302 L F
.793 .526 .534 r
.47007 .73081 m .47076 .73272 L .47177 .73014 L F
.47165 .72978 m .4718 .73008 L .472 .72956 L F
0 0 0 r
.472 .72956 m .4718 .73008 L .47198 .72975 L F
.411 .362 .694 r
.47169 .73027 m .47107 .73052 L .47253 .72877 L F
.793 .526 .534 r
.47173 .7301 m .47177 .73014 L .4718 .73008 L F
.47007 .73081 m .47177 .73014 L .47173 .7301 L F
.989 .812 .574 r
.47096 .7275 m .47107 .73052 L .47007 .73081 L F
.793 .526 .534 r
.47007 .73081 m .4718 .73008 L .47165 .72978 L F
.835 .609 .596 r
.47096 .7275 m .47007 .73081 L .47165 .72978 L F
.47096 .7275 m .47165 .72978 L .472 .72956 L F
.411 .362 .694 r
.47253 .72877 m .47166 .72981 L .47096 .7275 L F
0 0 0 r
.47198 .72975 m .47179 .73009 L .47198 .72979 L F
.4718 .73008 m .47179 .73009 L .47198 .72975 L F
.47198 .72979 m .47076 .73272 L .47183 .7313 L F
.507 .272 .492 r
.47475 .73253 m .47382 .7353 L .47292 .73383 L F
.646 .592 .78 r
.6869 .43337 m .68459 .43433 L .68334 .43026 L F
.658 .558 .73 r
.68776 .43704 m .68459 .43433 L .6869 .43337 L F
.541 .927 .875 r
.46414 .63266 m .46647 .63228 L .46839 .6312 L F
.499 .808 1 r
.45993 .62226 m .46131 .62317 L .45761 .62268 L F
.778 .502 .518 r
.46131 .62317 m .46073 .62543 L .45761 .62268 L F
0 0 .448 r
.46218 .62423 m .46131 .62317 L .45993 .62226 L F
.653 .373 .482 r
.46312 .62297 m .46352 .62621 L .46522 .62274 L F
.46131 .62317 m .46209 .62425 L .46312 .62297 L F
.46209 .62425 m .46352 .62621 L .46312 .62297 L F
0 0 .448 r
.46218 .62423 m .46352 .62621 L .46131 .62317 L F
.484 .665 .942 r
.46085 .62579 m .46207 .62598 L .46134 .62558 L F
.411 .422 .761 r
.45993 .62226 m .46134 .62558 L .46085 .62579 L F
.778 .611 .673 r
.46113 .62547 m .46123 .62534 L .45993 .62226 L F
.246 .307 .729 r
.45993 .62226 m .46085 .62579 L .46113 .62547 L F
.45993 .62226 m .46113 .62547 L .46218 .62423 L F
.411 .422 .761 r
.46134 .62558 m .4615 .62596 L .46085 .62579 L F
.778 .611 .673 r
.46116 .62556 m .46155 .62609 L .46134 .62558 L F
.484 .665 .942 r
.46085 .62579 m .46087 .62579 L .46095 .62567 L F
.46087 .62579 m .4627 .625 L .46095 .62567 L F
.778 .611 .673 r
.46113 .62547 m .46134 .62558 L .46123 .62534 L F
.484 .665 .942 r
.46095 .62567 m .4627 .625 L .46218 .62423 L F
0 0 0 r
.46113 .62547 m .46095 .62567 L .46077 .62591 L F
.565 .443 .673 r
.46139 .6286 m .46352 .62621 L .46085 .62579 L F
.411 .422 .761 r
.4615 .62596 m .46155 .62609 L .46085 .62579 L F
.99 .727 .384 r
.46061 .6261 m .46139 .6286 L .46085 .62579 L F
.45976 .62721 m .46099 .62825 L .46061 .6261 L F
.46099 .62825 m .46139 .6286 L .46061 .6261 L F
.778 .611 .673 r
.4605 .62545 m .46134 .62604 L .46116 .62556 L F
.45611 .62478 m .46057 .62585 L .4605 .62545 L F
.563 .066 .033 r
.46085 .62579 m .46155 .62609 L .45976 .62721 L F
.377 0 0 r
.46085 .62579 m .46105 .62593 L .45976 .62721 L F
.723 .275 .188 r
.45976 .62721 m .46155 .62609 L .46102 .62596 L F
.377 0 0 r
.46105 .62593 m .46213 .6267 L .45976 .62721 L F
.723 .275 .188 r
.45976 .62721 m .46102 .62596 L .46078 .6259 L F
.778 .611 .673 r
.45611 .62478 m .46134 .62558 L .45781 .62366 L F
0 0 0 r
.46113 .62547 m .46078 .6259 L .45976 .62721 L F
.46078 .6259 m .46077 .62591 L .45976 .62721 L F
.46095 .62567 m .46073 .62595 L .45976 .62721 L F
.723 .275 .188 r
.45976 .62721 m .46078 .6259 L .45611 .62478 L F
0 0 0 r
.46095 .62567 m .46085 .62579 L .46073 .62595 L F
.778 .611 .673 r
.46057 .62585 m .46078 .6259 L .4605 .62545 L F
.46092 .62594 m .46134 .62604 L .46121 .62595 L F
.377 0 0 r
.46107 .62594 m .46307 .62637 L .46213 .6267 L F
.46085 .62579 m .4615 .62596 L .46107 .62594 L F
.4615 .62596 m .46307 .62637 L .46107 .62594 L F
.778 .611 .673 r
.46078 .6259 m .46092 .62594 L .46091 .62574 L F
.46092 .62594 m .46121 .62595 L .46091 .62574 L F
.46078 .6259 m .46091 .62574 L .4605 .62545 L F
.377 0 0 r
.4615 .62596 m .46352 .62621 L .46307 .62637 L F
.46085 .62579 m .46207 .62598 L .4615 .62596 L F
.46207 .62598 m .46352 .62621 L .4615 .62596 L F
.778 .611 .673 r
.46134 .62604 m .46155 .62609 L .46146 .62596 L F
.46131 .62595 m .46146 .62596 L .46116 .62556 L F
.46134 .62604 m .46146 .62596 L .46131 .62595 L F
.45781 .62366 m .46113 .62547 L .45993 .62226 L F
0 0 0 r
.46218 .62423 m .46113 .62547 L .45976 .62721 L F
.484 .665 .942 r
.46134 .62558 m .46352 .62621 L .4627 .625 L F
.46207 .62598 m .46352 .62621 L .46134 .62558 L F
.359 0 0 r
.38179 .58207 m .38429 .58199 L .38528 .58097 L F
.104 0 0 r
.38528 .58097 m .38654 .5812 L .38756 .58076 L F
.072 0 0 r
.38528 .58097 m .38429 .58199 L .38654 .5812 L F
.726 .386 .402 r
.61349 .47422 m .61683 .47463 L .61699 .47634 L F
.33 .232 .59 r
.52526 .68617 m .52324 .68444 L .52575 .68412 L F
.52526 .68617 m .52304 .68777 L .52324 .68444 L F
.431 0 0 r
.63939 .45114 m .63681 .45105 L .63681 .45091 L F
.63939 .45114 m .63681 .45105 L .63681 .45091 L F
.378 0 .027 r
.64202 .45084 m .64131 .45165 L .63939 .45114 L F
.63939 .45114 m .64131 .45165 L .64202 .45084 L F
.316 .055 .349 r
.5576 .69192 m .55551 .69313 L .55784 .69033 L F
.637 .075 0 r
.5576 .69192 m .55435 .69 L .55784 .69033 L F
.5576 .69192 m .55647 .69172 L .55435 .69 L F
.999 .831 .505 r
.55687 .68874 m .55647 .69172 L .55784 .69033 L F
.99 .806 .565 r
.5576 .69192 m .55687 .68874 L .55784 .69033 L F
.565 .324 .509 r
.63807 .43291 m .63807 .43549 L .63556 .43361 L F
.63807 .43291 m .63807 .43549 L .63556 .43361 L F
.667 .78 .933 r
.62841 .4174 m .62936 .41903 L .6258 .41848 L F
0 0 0 r
.6307 .4186 m .63178 .41792 L .62936 .41903 L F
.6307 .4186 m .62936 .41903 L .62841 .4174 L F
.556 .152 .232 r
.54304 .62681 m .54031 .62863 L .54008 .62562 L F
.54304 .62681 m .54385 .62767 L .54031 .62863 L F
.731 .627 .742 r
.53995 .60847 m .5411 .61071 L .5376 .6114 L F
.602 .252 .35 r
.5376 .6114 m .5411 .61071 L .53979 .61192 L F
.715 .359 .373 r
.53995 .60847 m .54263 .61096 L .5411 .61071 L F
.264 0 .052 r
.53979 .61192 m .5411 .61071 L .54263 .61096 L F
.758 .649 .741 r
.65359 .43353 m .65421 .43836 L .6513 .43636 L F
.526 .592 .864 r
.65493 .43938 m .6513 .43636 L .65421 .43836 L F
.713 .96 .945 r
.532 .64346 m .52902 .64502 L .53045 .64456 L F
.751 .701 .804 r
.48751 .71973 m .48963 .71614 L .48804 .71641 L F
.47 .167 .369 r
.53058 .63797 m .53327 .63882 L .53442 .63758 L F
.648 .156 .068 r
.53327 .63882 m .53698 .6393 L .53442 .63758 L F
.258 0 .25 r
.51897 .65509 m .51722 .6558 L .51607 .65807 L F
0 0 0 r
.24001 .56062 m .2382 .56183 L .24025 .56026 L F
.272 .163 .542 r
.24001 .56062 m .23891 .56345 L .2382 .56183 L F
.263 .737 .939 r
.51876 .71939 m .51803 .71891 L .51517 .71899 L F
.872 .476 .012 r
.51876 .71939 m .51969 .72182 L .51803 .71891 L F
.989 .782 .394 r
.51814 .71605 m .51876 .71939 L .52111 .71644 L F
.51814 .71605 m .51803 .71891 L .51876 .71939 L F
.872 .476 .012 r
.51876 .71939 m .51969 .72182 L .51803 .71891 L F
.939 .884 .475 r
.66707 .4514 m .66786 .45146 L .66706 .45052 L F
.66707 .4514 m .66719 .45356 L .66786 .45146 L F
.697 .557 .692 r
.59063 .47756 m .59088 .48 L .58899 .47919 L F
.637 .513 .695 r
.59309 .47703 m .59088 .48 L .59063 .47756 L F
.645 .272 .323 r
.412 .6232 m .4145 .62502 L .41582 .62276 L F
.307 0 .134 r
.41582 .62276 m .4167 .62439 L .41834 .62314 L F
.41582 .62276 m .4145 .62502 L .4167 .62439 L F
.764 .347 .258 r
.67267 .42885 m .67499 .42759 L .67232 .42743 L F
.267 0 0 r
.67578 .42774 m .67499 .42759 L .67267 .42885 L F
.318 .374 .763 r
.58651 .65228 m .58705 .64848 L .58536 .64846 L F
.58651 .65228 m .58814 .652 L .58705 .64848 L F
.613 .598 .812 r
.58693 .65595 m .58814 .652 L .58651 .65228 L F
.201 .002 .371 r
.20809 .63937 m .20622 .64279 L .20649 .64077 L F
.828 .751 .778 r
.60125 .45699 m .59723 .45877 L .59967 .45571 L F
.60125 .45699 m .59905 .45993 L .59723 .45877 L F
.808 .811 .853 r
.60398 .45432 m .60125 .45699 L .59967 .45571 L F
.511 .65 .92 r
.5048 .65568 m .50612 .65422 L .50343 .65436 L F
.5048 .65568 m .50716 .65569 L .50612 .65422 L F
.472 .202 .422 r
.48403 .67263 m .48104 .67513 L .48194 .67121 L F
.238 0 .249 r
.46522 .62274 m .46571 .62494 L .4665 .62273 L F
.46522 .62274 m .46352 .62621 L .46571 .62494 L F
.363 0 .115 r
.34094 .59302 m .34327 .59257 L .34478 .59029 L F
.461 .076 .222 r
.34327 .59257 m .34715 .58991 L .34478 .59029 L F
.424 .83 .631 r
.3459 .58952 m .34478 .59029 L .34715 .58991 L F
.3459 .58952 m .34455 .59043 L .34478 .59029 L F
.171 0 0 r
.39461 .63739 m .39304 .63856 L .39061 .63898 L F
.316 0 0 r
.39693 .63755 m .39304 .63856 L .39461 .63739 L F
.955 .866 .712 r
.58886 .61622 m .59118 .61496 L .59091 .61276 L F
.58886 .61622 m .5901 .61708 L .59118 .61496 L F
.228 .234 .658 r
.54297 .60521 m .54476 .60752 L .54464 .60498 L F
.622 .264 .341 r
.58481 .47994 m .58899 .47919 L .58728 .48177 L F
.656 .267 .296 r
.59088 .48 m .58728 .48177 L .58899 .47919 L F
.774 .831 .896 r
.4667 .6752 m .46686 .67599 L .46846 .67453 L F
.779 .769 .844 r
.77754 .48813 m .77824 .49114 L .78089 .48846 L F
.691 .437 .534 r
.53873 .66057 m .54199 .65807 L .53867 .65813 L F
.53873 .66057 m .54256 .65994 L .54199 .65807 L F
.646 .488 .654 r
.48981 .69033 m .49305 .68654 L .48966 .68625 L F
.056 0 0 r
.40034 .62587 m .39811 .62654 L .39652 .62782 L F
.88 .604 .515 r
.48176 .69512 m .48303 .6929 L .47921 .69212 L F
.661 .323 .39 r
.48494 .69516 m .48303 .6929 L .48176 .69512 L F
.376 .178 .48 r
.21331 .62889 m .21303 .63127 L .21125 .63175 L F
.329 .142 .468 r
.21303 .63127 m .21055 .63368 L .21125 .63175 L F
.698 .253 .19 r
.47403 .68385 m .47626 .6855 L .47772 .68436 L F
0 .251 .743 r
.47906 .68473 m .48023 .68615 L .47772 .68436 L F
.587 .34 .509 r
.47772 .68436 m .48023 .68615 L .47776 .68627 L F
0 .251 .743 r
.47906 .68473 m .47772 .68436 L .47626 .6855 L F
.812 .635 .662 r
.59679 .64867 m .59809 .64968 L .59655 .6462 L F
.846 .814 .818 r
.59418 .65161 m .59809 .64968 L .59679 .64867 L F
.59418 .65161 m .5957 .65248 L .59809 .64968 L F
.342 .325 .695 r
.23678 .57556 m .2357 .5794 L .23534 .57601 L F
.23678 .57556 m .23758 .57832 L .2357 .5794 L F
.241 .094 .471 r
.23727 .58077 m .2357 .5794 L .23758 .57832 L F
.23727 .58077 m .23559 .58169 L .2357 .5794 L F
.988 .787 .543 r
.59208 .63108 m .5918 .63429 L .59309 .63486 L F
.906 .769 .699 r
.59418 .65161 m .59526 .65486 L .5957 .65248 L F
.352 .774 .976 r
.25564 .78024 m .25606 .77938 L .25385 .7796 L F
.25564 .78024 m .259 .78006 L .25606 .77938 L F
.25606 .77938 m .25564 .78024 L .25385 .7796 L F
.25606 .77938 m .259 .78006 L .25564 .78024 L F
.579 .788 .979 r
.43764 .57861 m .43654 .58045 L .43516 .57921 L F
.43764 .57861 m .43881 .57993 L .43654 .58045 L F
.403 .253 .561 r
.36797 .60747 m .36618 .60583 L .36871 .60492 L F
.36797 .60747 m .36585 .6084 L .36618 .60583 L F
.833 .653 .659 r
.80312 .49902 m .80337 .49703 L .8053 .4979 L F
.841 .655 .651 r
.80337 .49703 m .80505 .50049 L .8053 .4979 L F
.583 .272 .407 r
.40618 .62252 m .40863 .62307 L .40911 .62095 L F
.404 .111 .35 r
.40911 .62095 m .412 .6232 L .41092 .62213 L F
.40911 .62095 m .41089 .62206 L .412 .6232 L F
.40911 .62095 m .40863 .62307 L .41089 .62206 L F
.316 0 0 r
.78676 .48734 m .79007 .48845 L .78675 .48726 L F
.479 .26 .503 r
.50517 .69663 m .50658 .69802 L .50726 .69566 L F
.322 .25 .618 r
.50517 .69663 m .50669 .69924 L .50658 .69802 L F
.50517 .69663 m .50544 .70041 L .50669 .69924 L F
.527 .559 .831 r
.52111 .71644 m .51982 .71312 L .51814 .71605 L F
.469 .326 .604 r
.33463 .59959 m .33665 .59907 L .33653 .59659 L F
.506 .398 .665 r
.33495 .60241 m .33665 .59907 L .33463 .59959 L F
.549 .799 .991 r
.24683 .55548 m .24628 .55674 L .24538 .55524 L F
.24683 .55548 m .24766 .55629 L .24628 .55674 L F
.593 .516 .736 r
.24948 .55864 m .24628 .55674 L .24766 .55629 L F
.807 .711 .759 r
.54759 .67545 m .54925 .67859 L .54619 .67755 L F
.58 .005 0 r
.54917 .67857 m .54835 .67872 L .54619 .67755 L F
.218 .653 .953 r
.55055 .67795 m .54925 .67859 L .54759 .67545 L F
.117 0 0 r
.54835 .67872 m .54458 .67958 L .54619 .67755 L F
.741 .986 .777 r
.54942 .67722 m .54729 .67891 L .54835 .67872 L F
.117 0 0 r
.54835 .67872 m .54657 .67949 L .54458 .67958 L F
.741 .986 .777 r
.54729 .67891 m .54657 .67949 L .54835 .67872 L F
.58 .005 0 r
.54925 .67859 m .54835 .67872 L .54917 .67857 L F
.218 .653 .953 r
.55055 .67795 m .55212 .67905 L .54925 .67859 L F
.55055 .67795 m .54925 .67859 L .54835 .67872 L F
.55055 .67795 m .55212 .67905 L .54925 .67859 L F
0 .36 .736 r
.45669 .62987 m .46021 .63151 L .45914 .63 L F
.244 .523 .914 r
.46021 .63151 m .46116 .63057 L .45914 .63 L F
.271 .567 .936 r
.46021 .63151 m .46238 .63232 L .46116 .63057 L F
.53 .727 .964 r
.54651 .65239 m .54796 .65076 L .54533 .65084 L F
.791 .822 .876 r
.57244 .63186 m .57016 .63258 L .56922 .6321 L F
.115 .063 .515 r
.57379 .628 m .57418 .63099 L .57244 .63186 L F
.363 .832 .799 r
.57244 .63186 m .57418 .63099 L .57016 .63258 L F
.31 .164 .516 r
.22523 .60239 m .22511 .60494 L .22356 .60548 L F
.342 .246 .599 r
.22511 .60494 m .22534 .60742 L .22356 .60548 L F
.283 .235 .626 r
.22356 .60548 m .22534 .60742 L .22402 .60793 L F
.783 .452 .427 r
.54551 .67551 m .54426 .67776 L .54215 .67608 L F
.54551 .67551 m .54619 .67755 L .54426 .67776 L F
.489 .292 .539 r
.54759 .67545 m .54619 .67755 L .54551 .67551 L F
.095 .196 .68 r
.45749 .58725 m .45739 .591 L .45602 .58848 L F
.45749 .58725 m .45865 .59008 L .45739 .591 L F
.139 .281 .748 r
.45865 .59008 m .45966 .59319 L .45739 .591 L F
.373 0 0 r
.22076 .54392 m .22482 .5456 L .22224 .54545 L F
0 0 0 r
.57615 .59928 m .57921 .59608 L .57758 .59728 L F
.659 .771 .298 r
.54825 .67391 m .54759 .67545 L .54865 .67308 L F
.613 .598 .812 r
.58693 .65595 m .58946 .65527 L .58814 .652 L F
.504 .502 .788 r
.58463 .48217 m .5828 .48339 L .58103 .47947 L F
.068 0 .123 r
.58206 .48533 m .5828 .48339 L .58463 .48217 L F
.651 .353 .453 r
.51457 .67751 m .51795 .67529 L .51537 .67568 L F
.654 .473 .627 r
.50737 .65214 m .51178 .64889 L .5095 .64945 L F
.142 0 .242 r
.48707 .71158 m .48653 .71329 L .4887 .71023 L F
0 0 0 r
.20128 .59052 m .20362 .58721 L .20129 .58815 L F
.265 0 0 r
.57847 .63465 m .57968 .63491 L .5819 .63475 L F
.143 .019 .44 r
.58159 .63411 m .58148 .63147 L .5819 .63475 L F
.637 .951 .942 r
.5819 .63475 m .57968 .63491 L .58159 .63411 L F
.399 .089 .321 r
.49955 .6876 m .4991 .68948 L .49682 .68999 L F
.618 .288 .389 r
.50158 .68936 m .4991 .68948 L .49955 .6876 L F
.973 .693 .44 r
.49955 .6876 m .4991 .68948 L .49784 .68639 L F
.414 .134 .376 r
.6443 .4484 m .64464 .45015 L .64502 .44812 L F
.964 .748 .306 r
.64502 .44812 m .64464 .45015 L .64433 .44868 L F
.64502 .44812 m .64433 .44868 L .64747 .44764 L F
.6 .296 .426 r
.49784 .68639 m .50068 .68643 L .50178 .68262 L F
.395 .08 .309 r
.50178 .68262 m .50388 .68276 L .50401 .68144 L F
.378 .083 .332 r
.50068 .68643 m .50388 .68276 L .50178 .68262 L F
.914 .848 .765 r
.62247 .42915 m .62343 .42917 L .62243 .43038 L F
.852 .798 .798 r
.62243 .43038 m .62039 .4335 L .61882 .43208 L F
.62243 .43038 m .61882 .43208 L .62113 .42899 L F
.914 .848 .765 r
.62256 .4262 m .62243 .43038 L .62113 .42899 L F
.673 .891 .532 r
.6202 .42983 m .62113 .42899 L .61882 .43208 L F
.54 .297 .496 r
.62418 .43094 m .62135 .42913 L .6202 .42983 L F
.62135 .42913 m .62113 .42899 L .62098 .42913 L F
.62135 .42913 m .62098 .42913 L .6202 .42983 L F
.914 .848 .765 r
.62283 .42711 m .62463 .4277 L .62343 .42917 L F
.62256 .4262 m .62343 .42917 L .62247 .42915 L F
.62256 .4262 m .62317 .42664 L .62283 .42711 L F
.62317 .42664 m .62463 .4277 L .62283 .42711 L F
.894 .858 .799 r
.62631 .42437 m .62463 .4277 L .62256 .4262 L F
.62631 .42437 m .62256 .4262 L .62577 .42312 L F
.608 .574 .79 r
.62113 .42899 m .62247 .42496 L .62256 .4262 L F
.858 .921 .87 r
.6248 .42206 m .62256 .4262 L .62247 .42496 L F
.62406 .42342 m .62577 .42312 L .62306 .42572 L F
.62406 .42342 m .62306 .42572 L .62292 .42554 L F
0 .201 .702 r
.62248 .42497 m .62585 .42803 L .62559 .42771 L F
.62248 .42497 m .62596 .42813 L .62248 .42497 L F
.858 .921 .87 r
.62292 .42554 m .62306 .42572 L .62256 .4262 L F
.608 .574 .79 r
.62113 .42899 m .62584 .42815 L .62247 .42496 L F
.62584 .42815 m .62585 .42803 L .62247 .42496 L F
.54 .297 .496 r
.62418 .43094 m .62584 .42815 L .6215 .42893 L F
.953 .873 .721 r
.62418 .43094 m .62588 .42807 L .62559 .42771 L F
.62588 .42807 m .62594 .42797 L .62559 .42771 L F
0 .201 .702 r
.62585 .42803 m .62596 .42813 L .62559 .42771 L F
.62247 .42496 m .62248 .42497 L .62248 .42497 L F
.858 .921 .87 r
.6248 .42206 m .62511 .4224 L .62406 .42342 L F
.62511 .4224 m .62577 .42312 L .62406 .42342 L F
0 .201 .702 r
.62249 .42496 m .62559 .42771 L .62622 .42547 L F
.62247 .42496 m .62248 .42497 L .62249 .42496 L F
.62248 .42497 m .62559 .42771 L .62249 .42496 L F
.953 .873 .721 r
.62584 .42815 m .62681 .42863 L .62594 .42797 L F
.608 .574 .79 r
.62584 .42815 m .62596 .42813 L .62585 .42803 L F
.953 .873 .721 r
.62418 .43094 m .6257 .4296 L .62584 .42815 L F
.6257 .4296 m .62681 .42863 L .62584 .42815 L F
.54 .297 .496 r
.62418 .43094 m .62596 .42813 L .62584 .42815 L F
.62135 .42913 m .6215 .42893 L .62113 .42899 L F
.62418 .43094 m .6215 .42893 L .62135 .42913 L F
.656 .267 .296 r
.59088 .48 m .58925 .48163 L .58728 .48177 L F
.587 .181 .238 r
.59088 .48 m .59321 .48172 L .58925 .48163 L F
.577 .431 .647 r
.59309 .47703 m .59297 .48012 L .59088 .48 L F
.545 .215 .359 r
.59297 .48012 m .59321 .48172 L .59088 .48 L F
.892 .983 .709 r
.57959 .47813 m .58114 .47724 L .57886 .48022 L F
.785 .597 .647 r
.58114 .47724 m .58103 .47947 L .57886 .48022 L F
.664 .95 .71 r
.58237 .47554 m .58114 .47724 L .57959 .47813 L F
.427 0 0 r
.3768 .64106 m .3751 .64183 L .37301 .64134 L F
.566 .109 .125 r
.37826 .64165 m .3751 .64183 L .3768 .64106 L F
.288 0 0 r
.37941 .64081 m .37826 .64165 L .3768 .64106 L F
.597 .54 .762 r
.7846 .50449 m .78601 .4994 L .78345 .50024 L F
.7846 .50449 m .78712 .50372 L .78601 .4994 L F
.511 .328 .57 r
.33653 .59659 m .33882 .59356 L .33646 .59403 L F
.596 .591 .817 r
.77751 .49822 m .78087 .50087 L .78019 .49709 L F
.59 .505 .726 r
.78019 .49709 m .78087 .50087 L .78345 .50024 L F
.839 .739 .754 r
.55435 .69 m .55551 .69313 L .5522 .69251 L F
.807 .41 .301 r
.5522 .69251 m .55551 .69313 L .55398 .69463 L F
.15 .319 .78 r
.55435 .69 m .55647 .69172 L .55551 .69313 L F
.63 .886 .553 r
.55551 .69313 m .55647 .69172 L .55398 .69463 L F
.626 .946 .946 r
.5576 .69192 m .55647 .69172 L .55551 .69313 L F
.576 .407 .616 r
.52978 .70672 m .53121 .70661 L .5312 .70659 L F
.398 0 .068 r
.5306 .70498 m .52978 .70672 L .52702 .70698 L F
.576 .407 .616 r
.52978 .70672 m .5312 .70659 L .52919 .70402 L F
.398 0 .068 r
.52702 .70698 m .52978 .70672 L .52696 .70701 L F
.698 .163 0 r
.5306 .70498 m .53139 .70375 L .52919 .70402 L F
.5306 .70498 m .53311 .70716 L .53121 .70661 L F
.578 .339 .517 r
.53345 .70458 m .53311 .70716 L .5306 .70498 L F
.698 .163 0 r
.5306 .70498 m .53121 .70661 L .53139 .70375 L F
0 .073 .583 r
.58972 .60378 m .58772 .60208 L .58726 .60161 L F
.58972 .60378 m .59057 .60475 L .58772 .60208 L F
.846 .422 .225 r
.51969 .72182 m .52114 .72407 L .52206 .72305 L F
.188 .375 .818 r
.53914 .6466 m .54064 .64567 L .53814 .64427 L F
.324 .67 .976 r
.53914 .6466 m .54191 .64684 L .54064 .64567 L F
.737 .279 .162 r
.67886 .45113 m .67758 .45263 L .67531 .45026 L F
.406 0 .129 r
.68097 .45019 m .67758 .45263 L .67886 .45113 L F
.329 .142 .468 r
.21303 .63127 m .21275 .63371 L .21055 .63368 L F
.175 0 .378 r
.21275 .63371 m .21101 .63677 L .21055 .63368 L F
.165 .295 .752 r
.38328 .6002 m .38412 .59842 L .38218 .59825 L F
.485 .264 .502 r
.38597 .59917 m .38556 .60185 L .38328 .6002 L F
.165 .295 .752 r
.38328 .6002 m .38556 .60185 L .38412 .59842 L F
.806 .727 .777 r
.59195 .65458 m .59526 .65486 L .59418 .65161 L F
.81 .716 .762 r
.59313 .65787 m .59526 .65486 L .59195 .65458 L F
.29 .165 .531 r
.57705 .62303 m .57832 .61964 L .576 .62015 L F
.695 .518 .644 r
.59922 .47449 m .59908 .47704 L .59717 .47733 L F
.685 .51 .643 r
.60295 .47644 m .59908 .47704 L .59922 .47449 L F
.678 .327 .371 r
.45397 .62446 m .45761 .62268 L .45591 .62426 L F
.591 .927 .721 r
.54652 .65471 m .54503 .65599 L .5429 .65718 L F
.533 .484 .748 r
.33467 .61422 m .33683 .61371 L .33607 .61071 L F
.593 .534 .758 r
.33483 .61581 m .33683 .61371 L .33467 .61422 L F
.719 .415 .463 r
.20362 .58721 m .20578 .58762 L .20384 .585 L F
.654 .407 .534 r
.20384 .585 m .20578 .58762 L .20617 .58511 L F
.854 .954 .877 r
.59905 .45993 m .59549 .46191 L .59723 .45877 L F
.629 .66 .861 r
.50981 .70868 m .5126 .70832 L .51217 .70651 L F
.833 .435 0 r
.78844 .49631 m .78998 .49861 L .78801 .49485 L F
.758 .789 .878 r
.79168 .49712 m .78998 .49861 L .78844 .49631 L F
.79168 .49712 m .78998 .49861 L .78844 .49631 L F
.426 .587 .908 r
.20713 .55892 m .20597 .55545 L .20569 .55548 L F
.20713 .55892 m .20904 .5586 L .20597 .55545 L F
.407 .217 .507 r
.21095 .57641 m .21257 .57826 L .21283 .57577 L F
.367 .229 .559 r
.21535 .57049 m .21701 .56711 L .21516 .56806 L F
.447 .724 .985 r
.43452 .57747 m .43358 .5788 L .43215 .5775 L F
.244 .444 .858 r
.43452 .57747 m .43516 .57921 L .43358 .5788 L F
.836 .754 .772 r
.64926 .46521 m .65 .46603 L .65255 .46373 L F
.238 0 .328 r
.64887 .46814 m .65114 .4652 L .6509 .46703 L F
.25 0 .066 r
.65114 .4652 m .65427 .46312 L .65284 .46414 L F
.65114 .4652 m .65284 .46414 L .65248 .46438 L F
.119 .108 .569 r
.65255 .46373 m .65114 .4652 L .65264 .46428 L F
0 0 .063 r
.6509 .46703 m .65114 .4652 L .65255 .46373 L F
.836 .754 .772 r
.65 .46603 m .6509 .46703 L .65209 .46464 L F
.65 .46603 m .65209 .46464 L .65255 .46373 L F
.25 0 .066 r
.65248 .46438 m .65284 .46414 L .65264 .46428 L F
0 0 0 r
.65264 .46428 m .65427 .46312 L .65636 .46225 L F
.432 .219 .487 r
.49111 .69061 m .49095 .69243 L .48981 .69033 L F
0 0 .057 r
.53867 .65813 m .53642 .66124 L .53873 .66057 L F
.347 .094 .38 r
.58185 .63757 m .58229 .63954 L .58014 .64047 L F
.191 0 0 r
.37081 .64021 m .36699 .64011 L .36677 .63804 L F
.37081 .64021 m .36944 .64032 L .36699 .64011 L F
0 .331 .784 r
.37081 .64021 m .37133 .63992 L .36944 .64032 L F
.37081 .64021 m .37301 .64134 L .37133 .63992 L F
.504 .045 .095 r
.5838 .60624 m .58201 .60687 L .58194 .60583 L F
.985 .734 .467 r
.57928 .60833 m .58056 .60671 L .58078 .61013 L F
.406 .178 .451 r
.57928 .60833 m .57997 .60756 L .58056 .60671 L F
.799 .332 .12 r
.58194 .60583 m .58056 .60671 L .58117 .60582 L F
.236 0 0 r
.58201 .60687 m .58246 .60697 L .58142 .60683 L F
.606 .121 .078 r
.58157 .60685 m .58388 .60716 L .58425 .61111 L F
.236 0 0 r
.58246 .60697 m .58395 .60731 L .5809 .60677 L F
.606 .121 .078 r
.58246 .60697 m .5838 .60624 L .58388 .60716 L F
.504 .045 .095 r
.5838 .60624 m .58246 .60697 L .58201 .60687 L F
.606 .121 .078 r
.58157 .60685 m .5838 .60624 L .58246 .60697 L F
.504 .045 .095 r
.5838 .60624 m .58395 .60731 L .58246 .60697 L F
.606 .121 .078 r
.58157 .60685 m .58395 .60731 L .5838 .60624 L F
.58079 .60707 m .58157 .60685 L .58425 .61111 L F
.58079 .60707 m .58395 .60731 L .58157 .60685 L F
.236 0 0 r
.58112 .60677 m .58142 .60683 L .58056 .60671 L F
.58201 .60687 m .58142 .60683 L .58112 .60677 L F
.58246 .60697 m .5809 .60677 L .58056 .60671 L F
.752 .535 .601 r
.58056 .60671 m .58395 .60731 L .58079 .60707 L F
.58056 .60671 m .58079 .60707 L .58078 .61013 L F
.406 .178 .451 r
.57997 .60756 m .58199 .60531 L .58056 .60671 L F
.799 .332 .12 r
.58117 .60582 m .58056 .60671 L .57839 .60576 L F
.58194 .60583 m .58201 .60687 L .58056 .60671 L F
.078 0 .355 r
.20384 .64846 m .20388 .6464 L .20419 .64613 L F
.20384 .64846 m .20334 .64896 L .20388 .6464 L F
.727 .647 .77 r
.52367 .70176 m .52693 .7019 L .52571 .69823 L F
.582 .289 .436 r
.52428 .70483 m .52693 .7019 L .52367 .70176 L F
.52428 .70483 m .52761 .70448 L .52693 .7019 L F
.829 .7 .721 r
.52571 .69823 m .52693 .7019 L .52711 .69927 L F
.625 .314 .424 r
.52761 .70448 m .52919 .70402 L .52693 .7019 L F
.613 .317 .443 r
.52919 .70402 m .53008 .70205 L .52693 .7019 L F
.664 .805 .95 r
.42718 .58362 m .42848 .58498 L .431 .58401 L F
.864 .749 .734 r
.54984 .66414 m .55253 .66635 L .55155 .66613 L F
.585 .499 .723 r
.33578 .61811 m .33778 .61708 L .33483 .61581 L F
.33578 .61811 m .33799 .61956 L .33778 .61708 L F
.719 .326 0 r
.55882 .67485 m .56006 .67756 L .56035 .67782 L F
.994 .868 .543 r
.5588 .67961 m .56035 .67782 L .56006 .67756 L F
.5588 .67961 m .55965 .68161 L .56035 .67782 L F
.938 .622 .172 r
.23458 .54856 m .23551 .55035 L .23425 .54682 L F
0 .224 .745 r
.23573 .54938 m .23551 .55035 L .23458 .54856 L F
.23573 .54938 m .23764 .55215 L .23551 .55035 L F
.592 .428 .628 r
.5376 .6114 m .53979 .61192 L .53995 .60847 L F
.568 .467 .7 r
.78445 .4901 m .78729 .48962 L .78676 .48734 L F
.907 .763 .69 r
.53303 .69499 m .53127 .69852 L .53049 .69518 L F
.306 0 0 r
.52804 .72838 m .52593 .72807 L .52894 .72714 L F
.018 0 0 r
.53222 .72574 m .53081 .72698 L .52894 .72714 L F
.03 0 0 r
.52894 .72714 m .53081 .72698 L .52804 .72838 L F
.895 .815 .761 r
.58113 .62527 m .58282 .62601 L .5807 .62899 L F
.565 .379 .589 r
.52335 .64234 m .52494 .63983 L .52323 .64166 L F
.733 .482 .548 r
.20617 .58511 m .20961 .58754 L .20981 .58516 L F
.562 .358 .562 r
.20961 .58754 m .21212 .58469 L .20981 .58516 L F
.539 .743 .97 r
.54663 .6599 m .54758 .66157 L .54573 .66192 L F
.585 .524 .753 r
.49321 .71347 m .49598 .71323 L .49465 .71008 L F
.712 .362 .384 r
.49321 .71347 m .49582 .71567 L .49598 .71323 L F
.49321 .71347 m .49228 .71556 L .49582 .71567 L F
.896 .988 .75 r
.33939 .6316 m .33898 .63027 L .34065 .62935 L F
.036 .434 .87 r
.33939 .6316 m .34069 .632 L .33898 .63027 L F
.684 .35 .403 r
.51217 .70651 m .51509 .70679 L .51184 .7046 L F
.699 .611 .755 r
.77379 .49735 m .77751 .49822 L .77628 .49435 L F
.722 .624 .748 r
.77628 .49435 m .77751 .49822 L .78019 .49709 L F
0 0 .204 r
.59109 .62196 m .59148 .62535 L .59113 .62346 L F
.702 .601 .741 r
.69011 .43639 m .68776 .43704 L .6869 .43337 L F
0 0 0 r
.69011 .43639 m .68786 .43866 L .68776 .43704 L F
.616 .055 0 r
.50612 .65422 m .50381 .65266 L .50343 .65436 L F
.525 .326 .553 r
.53613 .66329 m .53873 .66057 L .53642 .66124 L F
.376 .84 .803 r
.57448 .59913 m .57033 .60056 L .57212 .60263 L F
.158 .428 .865 r
.58479 .64379 m .58266 .6417 L .58247 .64191 L F
.984 .711 .339 r
.58229 .63954 m .58247 .64191 L .58146 .64052 L F
.158 .428 .865 r
.58266 .6417 m .58146 .64052 L .58247 .64191 L F
.524 .82 .486 r
.58371 .64058 m .58217 .64225 L .58247 .64191 L F
.58217 .64225 m .58104 .64346 L .58247 .64191 L F
.431 .636 .941 r
.58104 .64346 m .58286 .64351 L .58247 .64191 L F
.306 .086 .406 r
.21283 .57577 m .2145 .57509 L .21329 .57347 L F
.571 .424 .642 r
.21329 .57347 m .21568 .57311 L .21535 .57049 L F
.464 .119 .294 r
.21329 .57347 m .2145 .57509 L .21568 .57311 L F
.77 .588 .652 r
.64216 .44356 m .644 .44229 L .6396 .44109 L F
.856 .96 .873 r
.64578 .44064 m .644 .44229 L .64216 .44356 L F
.288 .786 .786 r
.64216 .44356 m .64647 .44257 L .64578 .44064 L F
.385 .523 .873 r
.64647 .44257 m .64769 .44041 L .64578 .44064 L F
.505 .257 .473 r
.65273 .44235 m .64999 .44494 L .64889 .44265 L F
.515 .078 .149 r
.64889 .44265 m .64958 .44334 L .64647 .44257 L F
.385 .523 .873 r
.64647 .44257 m .64958 .44334 L .64769 .44041 L F
.833 .365 0 r
.5796 .62382 m .57843 .62342 L .57705 .62303 L F
.675 .125 0 r
.5796 .62382 m .58113 .62527 L .57885 .62429 L F
0 .329 .814 r
.66191 .43493 m .66375 .43785 L .6628 .43624 L F
.66191 .43493 m .66447 .43661 L .66375 .43785 L F
.956 .95 .676 r
.66447 .43661 m .66477 .43764 L .66375 .43785 L F
.231 .362 .79 r
.66723 .44046 m .66375 .43785 L .66477 .43764 L F
.722 .624 .748 r
.77628 .49435 m .78019 .49709 L .77984 .49515 L F
.459 .407 .712 r
.78019 .49709 m .78236 .49679 L .77984 .49515 L F
.59 .505 .726 r
.78019 .49709 m .78345 .50024 L .78236 .49679 L F
.514 0 0 r
.20306 .54257 m .20521 .54353 L .20701 .5434 L F
.379 0 0 r
.20701 .5434 m .20521 .54353 L .20902 .5439 L F
.759 .727 .823 r
.57008 .63716 m .56841 .63959 L .56719 .63681 L F
.866 .71 .687 r
.59515 .6426 m .59352 .64583 L .59655 .6462 L F
.851 .686 .676 r
.59352 .64583 m .59679 .64867 L .59655 .6462 L F
.821 .693 .723 r
.59515 .6426 m .59655 .6462 L .597 .64385 L F
.978 .682 .379 r
.53973 .62362 m .53875 .62565 L .53859 .62232 L F
.53973 .62362 m .54008 .62562 L .53875 .62565 L F
.218 0 0 r
.54018 .62407 m .53973 .62362 L .53859 .62232 L F
.54044 .62435 m .5423 .62366 L .53973 .62362 L F
.444 .459 .78 r
.54018 .62407 m .54044 .62435 L .54085 .62334 L F
.834 .588 .567 r
.5413 .62647 m .54406 .62481 L .54094 .62449 L F
.444 .459 .78 r
.54044 .62435 m .54103 .62502 L .54092 .62438 L F
0 0 .551 r
.54031 .62863 m .53875 .62565 L .54008 .62562 L F
.444 .459 .78 r
.53875 .62565 m .5413 .62647 L .5411 .62509 L F
.53875 .62565 m .5411 .62509 L .54018 .62407 L F
.834 .588 .567 r
.5413 .62647 m .54094 .62449 L .54053 .62445 L F
.444 .459 .78 r
.54092 .62438 m .5411 .62509 L .541 .62438 L F
.54103 .62502 m .5411 .62509 L .54092 .62438 L F
.54044 .62435 m .541 .62438 L .54085 .62334 L F
.218 0 0 r
.54053 .62445 m .54071 .62437 L .54044 .62435 L F
.54071 .62437 m .5423 .62366 L .54044 .62435 L F
.54049 .62441 m .54044 .62435 L .54018 .62407 L F
.54044 .62435 m .53973 .62362 L .54018 .62407 L F
.312 .177 .53 r
.53859 .62232 m .53875 .62565 L .54018 .62407 L F
.53859 .62232 m .54018 .62407 L .54085 .62334 L F
.218 0 0 r
.54053 .62445 m .54049 .62441 L .53859 .62232 L F
.715 .704 .838 r
.78729 .48962 m .78806 .49188 L .79043 .48995 L F
.677 .851 .966 r
.64177 .42046 m .63896 .4218 L .63781 .42063 L F
.63781 .42063 m .63896 .4218 L .64177 .42046 L F
.639 .736 .919 r
.64083 .4317 m .64151 .43347 L .63807 .43291 L F
.313 0 .004 r
.64151 .43347 m .63807 .43549 L .63807 .43291 L F
.64151 .43347 m .64061 .435 L .63807 .43549 L F
0 .137 .684 r
.64083 .4317 m .64172 .43226 L .64151 .43347 L F
.56 .469 .709 r
.64172 .43226 m .64061 .435 L .64151 .43347 L F
.598 .355 .519 r
.77984 .49515 m .78236 .49679 L .78214 .49458 L F
.77984 .49515 m .78236 .49679 L .78214 .49458 L F
.576 .936 .926 r
.50911 .65558 m .51088 .6556 L .51294 .65455 L F
.546 .209 .348 r
.61098 .47424 m .60969 .47602 L .60761 .47661 L F
.697 .392 .455 r
.61098 .47424 m .61325 .4766 L .60969 .47602 L F
.662 .397 .509 r
.61349 .47422 m .61325 .4766 L .61098 .47424 L F
.306 .232 .607 r
.53697 .69505 m .5359 .6993 L .53531 .6988 L F
.636 .198 0 r
.5359 .6993 m .53664 .7005 L .53531 .6988 L F
.161 .11 .547 r
.53664 .7005 m .53569 .70142 L .53531 .6988 L F
.284 .697 .972 r
.45669 .62987 m .45744 .62883 L .45508 .62969 L F
.45669 .62987 m .45914 .63 L .45744 .62883 L F
.505 .257 .473 r
.65273 .44235 m .65246 .44442 L .64999 .44494 L F
.179 0 .143 r
.65273 .44235 m .64999 .44494 L .65246 .44442 L F
.376 .148 .436 r
.65482 .44145 m .65246 .44442 L .65273 .44235 L F
.65482 .44145 m .65246 .44442 L .65273 .44235 L F
.98 .705 .428 r
.66935 .43822 m .67064 .43931 L .67069 .44158 L F
.87 .732 .216 r
.55868 .67168 m .55882 .67485 L .55849 .67055 L F
.55868 .67168 m .55845 .67427 L .55882 .67485 L F
.675 .301 0 r
.55845 .67427 m .56006 .67756 L .55882 .67485 L F
.129 .666 .853 r
.19344 .5422 m .19547 .54212 L .19739 .5425 L F
.029 0 0 r
.19547 .54212 m .19939 .54226 L .19739 .5425 L F
.593 .534 .758 r
.33483 .61581 m .33778 .61708 L .33683 .61371 L F
.303 .206 .577 r
.21884 .62183 m .21732 .62019 L .21894 .61947 L F
.21884 .62183 m .21754 .62278 L .21732 .62019 L F
.425 .103 .313 r
.4955 .6849 m .49305 .68654 L .4961 .68572 L F
.618 .144 .106 r
.4961 .68572 m .49784 .68639 L .4955 .6849 L F
.646 .774 .941 r
.44844 .58217 m .44648 .5831 L .44489 .58153 L F
.762 .712 .805 r
.77278 .49407 m .77379 .49735 L .77628 .49435 L F
.354 .799 .955 r
.38309 .62462 m .3847 .62498 L .38323 .6252 L F
.38309 .62462 m .38323 .6252 L .38235 .62534 L F
.534 0 0 r
.38172 .62337 m .38298 .62418 L .38309 .62462 L F
.498 0 0 r
.38313 .62465 m .3847 .62498 L .38309 .62462 L F
.344 .797 .948 r
.38235 .62534 m .3847 .62498 L .38603 .62527 L F
.498 0 0 r
.38555 .62583 m .3847 .62498 L .38313 .62465 L F
.534 0 0 r
.38298 .62418 m .38555 .62583 L .38309 .62462 L F
.344 .797 .948 r
.38603 .62527 m .3847 .62498 L .38633 .62527 L F
.689 .154 0 r
.3847 .62498 m .38835 .62649 L .38633 .62527 L F
.452 .03 .147 r
.42037 .63126 m .41919 .63309 L .41726 .63212 L F
.38 0 .124 r
.42264 .63092 m .41919 .63309 L .42037 .63126 L F
.2 .343 .785 r
.4762 .69327 m .4777 .69234 L .47562 .69346 L F
.4762 .69327 m .47902 .69551 L .4777 .69234 L F
.287 .356 .76 r
.4762 .69327 m .47727 .69519 L .47902 .69551 L F
.678 .648 .813 r
.59313 .65787 m .59195 .65458 L .58946 .65527 L F
.158 0 .188 r
.23364 .58746 m .23101 .5903 L .2319 .58836 L F
.715 .588 .712 r
.63202 .44492 m .63481 .44495 L .63445 .44232 L F
.413 .055 .246 r
.63184 .44735 m .63481 .44495 L .63202 .44492 L F
.63184 .44735 m .63409 .44694 L .63481 .44495 L F
0 0 .054 r
.63481 .44495 m .63621 .44554 L .63737 .44429 L F
.63481 .44495 m .63409 .44694 L .63621 .44554 L F
.491 .281 .522 r
.63481 .44495 m .63773 .44182 L .63445 .44232 L F
.63481 .44495 m .63737 .44429 L .63773 .44182 L F
.052 0 0 r
.47671 .62563 m .47985 .6235 L .47852 .62488 L F
.113 0 .347 r
.47985 .6235 m .48155 .61999 L .4811 .6222 L F
0 0 0 r
.47852 .62488 m .47985 .6235 L .4811 .6222 L F
.496 0 0 r
.55098 .63186 m .54967 .63111 L .54731 .62931 L F
.479 .308 .571 r
.54731 .62931 m .54967 .63111 L .55013 .62824 L F
0 0 0 r
.52526 .68617 m .52228 .68885 L .52304 .68777 L F
0 .009 .532 r
.66603 .43051 m .66685 .43122 L .66505 .42909 L F
.66603 .43051 m .66787 .43244 L .66685 .43122 L F
.385 0 .098 r
.44356 .62673 m .44549 .62752 L .44309 .62786 L F
.569 .374 .577 r
.50453 .69151 m .50158 .68936 L .50419 .68719 L F
.471 .261 .512 r
.5071 .6886 m .50453 .69151 L .50419 .68719 L F
.245 .074 .44 r
.23706 .57314 m .23678 .57556 L .23534 .57601 L F
.25 0 .005 r
.39624 .59152 m .39525 .5931 L .39299 .59366 L F
.458 .018 .113 r
.39837 .59226 m .39525 .5931 L .39624 .59152 L F
0 0 .177 r
.57572 .60567 m .57694 .60162 L .5781 .60255 L F
.59 .423 .623 r
.5781 .60255 m .57839 .60576 L .57572 .60567 L F
0 0 .177 r
.57572 .60567 m .57688 .60509 L .57694 .60162 L F
0 0 .516 r
.57711 .60635 m .57572 .60567 L .57839 .60576 L F
.57711 .60635 m .57688 .60509 L .57572 .60567 L F
.042 .611 .75 r
.46584 .70194 m .46157 .70189 L .46488 .70066 L F
.379 .133 .41 r
.46822 .70128 m .46855 .69889 L .46584 .70194 L F
.989 .748 .369 r
.46562 .70442 m .46584 .70194 L .46488 .70066 L F
.379 .133 .41 r
.46822 .70128 m .46855 .69889 L .46584 .70194 L F
.808 .839 .874 r
.78993 .50286 m .79042 .50524 L .79296 .5029 L F
.388 .582 .918 r
.43817 .58733 m .43899 .58606 L .43798 .5855 L F
.43817 .58733 m .44041 .58703 L .43899 .58606 L F
.809 .338 .099 r
.56204 .6402 m .55837 .63721 L .5622 .63885 L F
.346 0 .028 r
.54922 .64924 m .54828 .65057 L .54796 .65076 L F
.88 .522 .364 r
.54605 .64606 m .54828 .65057 L .54922 .64924 L F
.702 .601 .741 r
.69011 .43639 m .6869 .43337 L .6893 .43275 L F
0 0 0 r
.69011 .43639 m .69037 .43733 L .68786 .43866 L F
.345 .416 .792 r
.6893 .43275 m .6923 .43495 L .69011 .43639 L F
0 0 0 r
.6923 .43495 m .69037 .43733 L .69011 .43639 L F
.533 .828 .497 r
.64747 .44764 m .64879 .44619 L .64999 .44494 L F
.618 .958 .871 r
.64747 .44764 m .64433 .44868 L .64879 .44619 L F
.498 .236 .447 r
.19649 .60575 m .19781 .6073 L .19676 .6053 L F
.19649 .60575 m .19556 .60795 L .19781 .6073 L F
0 .026 .595 r
.19649 .60575 m .19781 .6073 L .19676 .6053 L F
.4 .065 .278 r
.37337 .60354 m .37148 .60276 L .37387 .60239 L F
.37337 .60354 m .37082 .60436 L .37148 .60276 L F
.389 .059 .279 r
.52874 .69622 m .52571 .69823 L .52711 .69927 L F
.891 .708 .648 r
.63462 .45027 m .6352 .45205 L .63681 .45091 L F
.602 .032 0 r
.63681 .45091 m .63681 .45105 L .63462 .45027 L F
.033 0 0 r
.63681 .45105 m .6352 .45205 L .63681 .45091 L F
.452 .029 .144 r
.41726 .63212 m .41919 .63309 L .4169 .63322 L F
.647 .386 .51 r
.54263 .61096 m .53995 .60847 L .53979 .61192 L F
.398 .183 .467 r
.48192 .72296 m .47943 .72218 L .48322 .72317 L F
.652 .096 0 r
.48322 .72317 m .48591 .72557 L .48192 .72296 L F
.511 .327 .567 r
.48527 .72189 m .48591 .72557 L .48322 .72317 L F
.871 .994 .803 r
.47035 .6182 m .46944 .62086 L .4682 .61902 L F
.47035 .6182 m .47218 .61753 L .46944 .62086 L F
.684 .473 .594 r
.62841 .44499 m .63184 .44735 L .63202 .44492 L F
0 0 0 r
.54637 .70665 m .54491 .70924 L .54321 .70999 L F
.475 .277 .531 r
.54637 .70665 m .54833 .7046 L .54854 .707 L F
0 0 0 r
.54714 .70613 m .54833 .7046 L .54637 .70665 L F
.54714 .70613 m .54637 .70665 L .54478 .70406 L F
.54714 .70613 m .54637 .70665 L .54854 .707 L F
.54714 .70613 m .54491 .70924 L .54637 .70665 L F
.427 .663 .96 r
.35722 .63541 m .35798 .63383 L .35641 .63382 L F
.35722 .63541 m .35929 .63536 L .35798 .63383 L F
.408 .157 .419 r
.47076 .69833 m .46855 .69889 L .46822 .70128 L F
.46822 .70128 m .46855 .69889 L .47076 .69833 L F
0 .018 .571 r
.55424 .63029 m .55367 .63015 L .55013 .62824 L F
.55424 .63029 m .55499 .63157 L .55367 .63015 L F
.566 .595 .841 r
.36699 .64011 m .36561 .63668 L .36677 .63804 L F
.637 .876 .524 r
.30726 .80963 m .30554 .81154 L .30493 .81258 L F
.554 .373 .59 r
.30493 .81258 m .30738 .81257 L .30726 .80963 L F
.372 .737 .99 r
.30493 .81258 m .30738 .81257 L .30554 .81154 L F
.317 .129 .46 r
.21469 .63058 m .21331 .62889 L .21514 .62822 L F
.21469 .63058 m .21303 .63127 L .21331 .62889 L F
.845 .815 .821 r
.60849 .44878 m .6077 .45013 L .60482 .44998 L F
.857 .787 .781 r
.60482 .44998 m .6077 .45013 L .60647 .45146 L F
.755 .65 .745 r
.57522 .47967 m .57654 .48322 L .5729 .48268 L F
.675 .608 .773 r
.57886 .48022 m .57654 .48322 L .57522 .47967 L F
.121 0 0 r
.47341 .62824 m .47671 .62563 L .47517 .62713 L F
0 0 0 r
.47517 .62713 m .47671 .62563 L .47852 .62488 L F
.414 .134 .376 r
.64464 .45015 m .64202 .45084 L .6443 .4484 L F
.6443 .4484 m .64202 .45084 L .64464 .45015 L F
.64464 .45015 m .6443 .4484 L .64298 .44635 L F
0 0 0 r
.57832 .61964 m .58093 .61686 L .57828 .61715 L F
.651 .66 .846 r
.68443 .42445 m .68284 .42766 L .68183 .42706 L F
.68443 .42445 m .68531 .42756 L .68284 .42766 L F
.658 .505 .665 r
.68531 .42756 m .68334 .43026 L .68284 .42766 L F
.177 .098 .521 r
.49305 .68654 m .49485 .68905 L .4961 .68572 L F
.49305 .68654 m .49282 .69121 L .49485 .68905 L F
.056 0 0 r
.24116 .55497 m .24127 .55499 L .24538 .55524 L F
.396 .066 .285 r
.49095 .69243 m .49282 .69121 L .48981 .69033 L F
.766 .935 .94 r
.58555 .47267 m .58356 .47429 L .58301 .47322 L F
.985 .877 .521 r
.58301 .47322 m .58356 .47429 L .58237 .47554 L F
.207 0 0 r
.40883 .63448 m .4095 .63545 L .40718 .63586 L F
.40883 .63448 m .41111 .63412 L .4095 .63545 L F
.651 .459 .611 r
.7702 .48671 m .77429 .48499 L .77122 .48553 L F
.808 .811 .853 r
.60398 .45432 m .59967 .45571 L .60223 .45278 L F
.806 .767 .817 r
.60647 .45146 m .60398 .45432 L .60223 .45278 L F
.531 .916 .784 r
.47407 .61636 m .47218 .61753 L .47035 .6182 L F
.067 .626 .8 r
.58014 .64047 m .57623 .64021 L .57731 .6397 L F
.795 .664 .719 r
.47199 .71923 m .47317 .72149 L .47466 .71957 L F
.851 .686 .676 r
.59352 .64583 m .59302 .64828 L .59679 .64867 L F
.847 .721 .724 r
.59302 .64828 m .59418 .65161 L .59679 .64867 L F
.558 .568 .82 r
.18244 .55571 m .1803 .55361 L .18192 .55573 L F
.724 .405 .44 r
.54849 .66349 m .54779 .66622 L .54645 .66584 L F
.751 .701 .804 r
.48751 .71973 m .48892 .71968 L .48963 .71614 L F
.659 .269 .294 r
.48751 .71973 m .48933 .72116 L .48892 .71968 L F
.641 .593 .785 r
.48963 .71614 m .48892 .71968 L .49334 .71888 L F
.726 .386 .402 r
.61349 .47422 m .61699 .47634 L .61325 .4766 L F
.376 .84 .803 r
.57448 .59913 m .57369 .5992 L .57033 .60056 L F
.67 .614 .784 r
.45729 .59396 m .45841 .59721 L .46129 .59572 L F
.54 .572 .835 r
.45042 .58178 m .4498 .58562 L .44844 .58217 L F
.45042 .58178 m .45191 .58547 L .4498 .58562 L F
.297 .714 .974 r
.45247 .58722 m .4498 .58562 L .45191 .58547 L F
.45247 .58722 m .44873 .58631 L .4498 .58562 L F
.692 .704 .856 r
.79904 .50277 m .80267 .50347 L .80121 .50181 L F
.794 .721 .784 r
.80121 .50181 m .80267 .50347 L .80505 .50049 L F
.849 .91 .876 r
.52813 .72272 m .5248 .72402 L .52705 .72394 L F
.611 .126 .078 r
.52705 .72394 m .53072 .7242 L .52813 .72272 L F
.563 .276 .439 r
.52813 .72272 m .53072 .7242 L .53142 .72216 L F
.572 .464 .693 r
.19716 .59924 m .20017 .59911 L .19899 .59584 L F
.278 .012 .318 r
.19739 .60236 m .20017 .59911 L .19716 .59924 L F
.94 .651 .465 r
.5568 .66348 m .557 .66596 L .55865 .6667 L F
.983 .703 .4 r
.557 .66596 m .55825 .66928 L .55865 .6667 L F
.813 .699 .74 r
.26149 .77932 m .259 .78006 L .26003 .77723 L F
.442 0 .025 r
.26149 .77932 m .26 .7804 L .259 .78006 L F
.693 .885 .969 r
.2638 .77997 m .26 .7804 L .26149 .77932 L F
.951 .691 .506 r
.30726 .80963 m .30738 .81257 L .30554 .81154 L F
.694 .633 .784 r
.79863 .49878 m .79524 .49795 L .79796 .49732 L F
.711 .787 .912 r
.801 .49641 m .79863 .49878 L .79796 .49732 L F
.801 .49641 m .80136 .49806 L .79863 .49878 L F
.759 .553 .618 r
.57984 .48592 m .5802 .48848 L .57636 .48849 L F
.522 .386 .637 r
.5825 .48779 m .57984 .48592 L .58206 .48533 L F
.5825 .48779 m .5802 .48848 L .57984 .48592 L F
.971 .66 .287 r
.55334 .65651 m .55334 .6542 L .55264 .65452 L F
.594 .232 .326 r
.62201 .47616 m .62295 .47417 L .62551 .47579 L F
.607 .209 .263 r
.62295 .47417 m .62558 .47447 L .62551 .47579 L F
.649 .235 .244 r
.52164 .65655 m .52274 .65496 L .51897 .65509 L F
.559 0 0 r
.52368 .65614 m .52274 .65496 L .52164 .65655 L F
.52368 .65614 m .52543 .657 L .52274 .65496 L F
.99 .868 .522 r
.64999 .44494 m .64879 .44619 L .64958 .44334 L F
.677 .371 .448 r
.51014 .72111 m .5091 .72407 L .50732 .72169 L F
.457 .359 .656 r
.50961 .71889 m .5118 .72065 L .51014 .72111 L F
.579 .366 .556 r
.51166 .72069 m .5091 .72407 L .51014 .72111 L F
.51168 .72079 m .5091 .72407 L .51166 .72069 L F
.51168 .72079 m .51177 .72399 L .5091 .72407 L F
.5118 .72065 m .51166 .72072 L .51166 .72069 L F
.457 .359 .656 r
.50961 .71889 m .51166 .72072 L .5118 .72065 L F
.51166 .72072 m .5124 .72138 L .5118 .72065 L F
.579 .366 .556 r
.5118 .72065 m .51168 .72079 L .51166 .72072 L F
.5118 .72065 m .5118 .72089 L .51168 .72079 L F
.5118 .72089 m .51177 .72399 L .51168 .72079 L F
.727 .248 .108 r
.5099 .72095 m .5118 .72128 L .51011 .71943 L F
.50963 .71902 m .51011 .71943 L .50961 .71889 L F
.5099 .72095 m .51011 .71943 L .50963 .71902 L F
.607 .388 .559 r
.5124 .72138 m .51177 .72399 L .5118 .72089 L F
.727 .248 .108 r
.51168 .7208 m .5124 .72138 L .51166 .72072 L F
.607 .388 .559 r
.5124 .72138 m .5118 .72089 L .5118 .72065 L F
.727 .248 .108 r
.5118 .72128 m .5124 .72138 L .51168 .7208 L F
.5118 .72128 m .51166 .72072 L .50961 .71889 L F
.727 .279 0 r
.62688 .44298 m .62692 .4433 L .62841 .44499 L F
.825 .577 .564 r
.62505 .44661 m .62841 .44499 L .62692 .4433 L F
.62505 .44661 m .62868 .44779 L .62841 .44499 L F
.684 .473 .594 r
.62841 .44499 m .62868 .44779 L .63184 .44735 L F
.666 .807 .951 r
.53222 .72574 m .53072 .7242 L .53081 .72698 L F
.53222 .72574 m .53435 .72469 L .53072 .7242 L F
.486 .819 .999 r
.42232 .57643 m .42566 .57671 L .42347 .57688 L F
.557 .777 .981 r
.43308 .58381 m .43443 .58507 L .4354 .58333 L F
.41 .592 .918 r
.43443 .58507 m .43798 .5855 L .4354 .58333 L F
.988 .815 .581 r
.62548 .42134 m .62631 .42437 L .62577 .42312 L F
.107 0 .377 r
.63773 .44182 m .63768 .44356 L .6396 .44109 L F
.63773 .44182 m .63748 .44353 L .63768 .44356 L F
.812 .842 .873 r
.63813 .43998 m .63768 .44356 L .6396 .44109 L F
.63813 .43998 m .63768 .44356 L .6396 .44109 L F
.77 .588 .652 r
.64216 .44356 m .6396 .44109 L .63768 .44356 L F
.588 .015 0 r
.63768 .44356 m .64298 .44635 L .64216 .44356 L F
.095 .315 .791 r
.64039 .444 m .63768 .44356 L .63651 .44321 L F
.641 .44413 m .63768 .44356 L .64039 .444 L F
.107 0 .377 r
.63748 .44353 m .63737 .44429 L .63768 .44356 L F
.167 .287 .744 r
.47827 .70707 m .47564 .70452 L .47847 .70429 L F
.455 .8 .998 r
.47643 .7032 m .47564 .70452 L .47429 .7043 L F
.47643 .7032 m .47847 .70429 L .47564 .70452 L F
.733 .482 .548 r
.20617 .58511 m .20578 .58762 L .20961 .58754 L F
.78 .286 .037 r
.5533 .63374 m .54967 .63111 L .55098 .63186 L F
.714 .873 .956 r
.59162 .46493 m .59123 .46543 L .58965 .46428 L F
.98 .747 .511 r
.59123 .46543 m .591 .46778 L .58965 .46428 L F
.799 .406 .311 r
.48197 .70022 m .48027 .70383 L .48 .70121 L F
.48197 .70022 m .48288 .70359 L .48027 .70383 L F
.48197 .70022 m .48399 .70188 L .48288 .70359 L F
.757 .622 .71 r
.62582 .43608 m .62804 .43672 L .62608 .43307 L F
.792 .63 .681 r
.62373 .43814 m .62804 .43672 L .62582 .43608 L F
.459 .038 .152 r
.35766 .58685 m .36002 .58676 L .36147 .58476 L F
.293 0 0 r
.36002 .58676 m .36384 .58477 L .36147 .58476 L F
.689 .653 .809 r
.33799 .61956 m .33915 .62074 L .34144 .62001 L F
.461 0 0 r
.2304 .54725 m .23425 .54682 L .23245 .54862 L F
.426 .233 .514 r
.23159 .59533 m .22957 .59377 L .23158 .5928 L F
.23159 .59533 m .22933 .5962 L .22957 .59377 L F
.972 .694 .444 r
.58371 .64058 m .58247 .64191 L .58229 .63954 L F
.727 .248 .108 r
.5099 .72095 m .50961 .71889 L .5078 .71929 L F
.407 .043 .232 r
.34944 .59014 m .35168 .58979 L .35289 .58733 L F
.424 .067 .253 r
.35168 .58979 m .35541 .58672 L .35289 .58733 L F
.491 .815 1 r
.46961 .7095 m .47105 .71044 L .4731 .70992 L F
.985 .736 .47 r
.47089 .71301 m .47105 .71044 L .46961 .7095 L F
.101 .298 .776 r
.58432 .64646 m .58561 .64559 L .58286 .64351 L F
.123 .342 .808 r
.58432 .64646 m .58705 .64848 L .58561 .64559 L F
.331 .37 .751 r
.58536 .64846 m .58705 .64848 L .58432 .64646 L F
.489 .492 .787 r
.47727 .69519 m .48017 .69855 L .47902 .69551 L F
.7 .535 .661 r
.59621 .47765 m .59309 .47703 L .59717 .47733 L F
.59621 .47765 m .59297 .48012 L .59309 .47703 L F
.636 .251 .298 r
.78469 .4954 m .78801 .49485 L .78583 .49435 L F
.78469 .4954 m .78844 .49631 L .78801 .49485 L F
.445 .141 .355 r
.78801 .49485 m .78844 .49631 L .7914 .49449 L F
.038 .105 .606 r
.36689 .6107 m .36857 .61338 L .36729 .61463 L F
.317 .427 .816 r
.36857 .61338 m .36828 .61635 L .36729 .61463 L F
0 .007 .558 r
.46994 .73376 m .47076 .73272 L .47007 .73081 L F
.188 .493 .903 r
.46994 .73376 m .47382 .7353 L .47076 .73272 L F
.711 .691 .83 r
.46772 .71241 m .46772 .71596 L .47089 .71301 L F
.788 .345 .195 r
.54234 .64502 m .54236 .64333 L .54096 .64239 L F
.54234 .64502 m .54402 .64549 L .54236 .64333 L F
.833 .653 .659 r
.80312 .49902 m .80505 .50049 L .80337 .49703 L F
.794 .721 .784 r
.80121 .50181 m .80505 .50049 L .80312 .49902 L F
.656 .397 .516 r
.78214 .49458 m .78469 .4954 L .78583 .49435 L F
.927 .961 .776 r
.44252 .58681 m .4419 .5892 L .44394 .58803 L F
.379 .465 .823 r
.68485 .44331 m .68294 .44489 L .6824 .44393 L F
.68485 .44331 m .68609 .44665 L .68294 .44489 L F
.552 .421 .655 r
.68294 .44489 m .68609 .44665 L .68376 .4479 L F
.633 .62 .819 r
.56799 .62865 m .56776 .6334 L .56399 .63187 L F
.56799 .62865 m .56922 .6321 L .56776 .6334 L F
.215 0 0 r
.4023 .59059 m .40046 .59197 L .39837 .59226 L F
.548 .354 .57 r
.63807 .43549 m .64083 .4317 L .63807 .43291 L F
.634 .576 .771 r
.1956 .59294 m .19662 .5963 L .19899 .59584 L F
.68 .291 .303 r
.43036 .62188 m .43258 .62303 L .43346 .62189 L F
.283 0 .042 r
.43346 .62189 m .43506 .6232 L .43605 .62219 L F
.43346 .62189 m .43258 .62303 L .43506 .6232 L F
0 0 .144 r
.48317 .61886 m .48155 .61999 L .48336 .61669 L F
0 0 .26 r
.4811 .6222 m .48155 .61999 L .48317 .61886 L F
.504 .502 .788 r
.58463 .48217 m .58103 .47947 L .58481 .47994 L F
.367 .229 .559 r
.21535 .57049 m .21698 .56991 L .21701 .56711 L F
.382 .267 .596 r
.21535 .57049 m .21719 .5722 L .21698 .56991 L F
.351 .265 .617 r
.21535 .57049 m .21568 .57311 L .21719 .5722 L F
.8 .991 .88 r
.48212 .7199 m .47943 .72218 L .48069 .72081 L F
.398 .183 .467 r
.47943 .72218 m .48192 .72296 L .48069 .72081 L F
.47943 .72218 m .47927 .72448 L .48192 .72296 L F
.48192 .72296 m .47927 .72448 L .47943 .72218 L F
.537 .312 .521 r
.58481 .47994 m .58728 .48177 L .58463 .48217 L F
.761 .785 .873 r
.52843 .64291 m .52902 .64502 L .532 .64346 L F
.778 .522 .549 r
.49682 .68999 m .49336 .69208 L .49397 .69212 L F
.49682 .68999 m .49671 .69244 L .49571 .69233 L F
.49682 .68999 m .49571 .69233 L .49479 .69122 L F
.208 .732 .836 r
.49397 .69212 m .49336 .69208 L .49095 .69243 L F
.817 .583 .585 r
.49336 .69208 m .496 .69272 L .49586 .69251 L F
.787 .557 .587 r
.49578 .6925 m .49336 .69208 L .49571 .69233 L F
.778 .522 .549 r
.49479 .69122 m .49571 .69233 L .49336 .69208 L F
.817 .583 .585 r
.49336 .69208 m .49586 .69251 L .49458 .6907 L F
.49336 .69208 m .49319 .69466 L .496 .69272 L F
.787 .557 .587 r
.49677 .69501 m .49515 .69362 L .49543 .69336 L F
.49677 .69501 m .4954 .69332 L .49597 .693 L F
0 0 0 r
.49607 .69276 m .496 .69272 L .49585 .69297 L F
.426 .005 .134 r
.496 .69272 m .49374 .69428 L .49505 .69353 L F
.49543 .69329 m .49505 .69353 L .4954 .69332 L F
.496 .69272 m .49505 .69353 L .49543 .69329 L F
.49374 .69428 m .49319 .69466 L .4954 .69332 L F
.787 .557 .587 r
.49505 .69353 m .49319 .69466 L .49336 .69208 L F
.49677 .69501 m .49319 .69466 L .49505 .69353 L F
0 0 .528 r
.49586 .69251 m .496 .69272 L .49607 .69276 L F
.787 .557 .587 r
.49677 .69501 m .49571 .69233 L .49674 .69358 L F
.584 .402 .602 r
.49914 .69207 m .49677 .69501 L .49671 .69244 L F
.718 .557 .67 r
.49671 .69713 m .49319 .69466 L .49677 .69501 L F
.49671 .69713 m .49286 .69781 L .4931 .69551 L F
.4937 .69502 m .4931 .69551 L .49319 .69466 L F
.49671 .69713 m .4931 .69551 L .4937 .69502 L F
0 0 0 r
.49687 .69336 m .49627 .69291 L .49404 .69585 L F
.49627 .69291 m .49607 .69276 L .49562 .69345 L F
.49627 .69291 m .49562 .69345 L .49404 .69585 L F
.49607 .69276 m .49585 .69297 L .49404 .69585 L F
.787 .557 .587 r
.49543 .69336 m .49509 .69357 L .4954 .69332 L F
.49515 .69362 m .49509 .69357 L .49543 .69336 L F
.49597 .693 m .4954 .69332 L .49594 .6929 L F
.821 .651 .672 r
.49215 .69588 m .49286 .69781 L .49095 .69731 L F
.49319 .69466 m .49314 .69512 L .49215 .69588 L F
.49314 .69512 m .49286 .69781 L .49215 .69588 L F
.426 .005 .134 r
.49579 .69306 m .49266 .69608 L .49404 .69585 L F
.49585 .69297 m .49561 .6932 L .49579 .69306 L F
.49561 .6932 m .49266 .69608 L .49579 .69306 L F
.4954 .69332 m .49319 .69466 L .49266 .69608 L F
.496 .69272 m .4954 .69332 L .49585 .69297 L F
.4954 .69332 m .49266 .69608 L .49585 .69297 L F
.787 .557 .587 r
.49594 .6929 m .49336 .69208 L .49578 .6925 L F
.49509 .69357 m .49336 .69208 L .49594 .6929 L F
.49674 .69358 m .49571 .69233 L .49671 .69244 L F
0 0 .528 r
.49585 .6925 m .49586 .69251 L .49608 .69277 L F
.49586 .69251 m .49607 .69276 L .49608 .69277 L F
.49458 .6907 m .49585 .6925 L .49687 .69336 L F
.49585 .6925 m .49608 .69277 L .49687 .69336 L F
.566 .342 .535 r
.49914 .69207 m .49671 .69244 L .49682 .68999 L F
.5 .347 .605 r
.4991 .68948 m .49914 .69207 L .49682 .68999 L F
.4991 .68948 m .49914 .69207 L .49682 .68999 L F
.531 .366 .602 r
.51422 .65829 m .51665 .66005 L .51607 .65807 L F
0 0 0 r
.64765 .46924 m .64887 .46814 L .6509 .46703 L F
.249 .702 .954 r
.20902 .5439 m .21111 .54391 L .21283 .54468 L F
.338 .776 .965 r
.21111 .54391 m .21504 .54424 L .21283 .54468 L F
.506 .398 .665 r
.33495 .60241 m .33714 .60188 L .33665 .59907 L F
.448 .342 .641 r
.33529 .60543 m .33714 .60188 L .33495 .60241 L F
.596 .637 .862 r
.53367 .66915 m .53256 .67269 L .53125 .67111 L F
.53367 .66915 m .53492 .67205 L .53256 .67269 L F
.503 .294 .529 r
.53256 .67269 m .53477 .67447 L .53492 .67205 L F
.53492 .67205 m .53477 .67447 L .53256 .67269 L F
.513 .175 .331 r
.50388 .68276 m .50615 .68282 L .50401 .68144 L F
.511 .177 .337 r
.50401 .68144 m .50615 .68282 L .50646 .68123 L F
.175 .699 .87 r
.39813 .57907 m .40187 .57926 L .39969 .57945 L F
.656 .397 .516 r
.78214 .49458 m .78236 .49679 L .78469 .4954 L F
.617 .547 .753 r
.34144 .62001 m .34276 .62357 L .34512 .62242 L F
.195 .297 .741 r
.34428 .62283 m .34495 .62299 L .34512 .62242 L F
0 0 0 r
.34431 .62515 m .34756 .62236 L .34512 .62242 L F
.617 .547 .753 r
.34144 .62001 m .34512 .62242 L .34507 .62303 L F
.44 .508 .833 r
.34144 .62001 m .34506 .62302 L .34324 .61975 L F
.34506 .62302 m .34507 .62303 L .34506 .62302 L F
.34506 .62302 m .34506 .62302 L .34324 .61975 L F
.195 .297 .741 r
.34276 .62357 m .34431 .62515 L .34495 .62299 L F
.34276 .62357 m .34495 .62299 L .34428 .62283 L F
.87 .82 .797 r
.6109 .44511 m .60713 .44716 L .60973 .44399 L F
.6109 .44511 m .60849 .44878 L .60713 .44716 L F
.852 .881 .86 r
.61331 .44243 m .6109 .44511 L .60973 .44399 L F
.487 .379 .658 r
.5243 .64321 m .52113 .6446 L .52335 .64234 L F
.492 0 0 r
.41834 .62314 m .4167 .62439 L .42042 .6242 L F
.604 .49 .696 r
.41834 .62314 m .42078 .62298 L .42029 .62047 L F
.475 .068 .189 r
.41834 .62314 m .42042 .6242 L .42078 .62298 L F
.508 .879 .978 r
.21504 .54424 m .21714 .54357 L .21878 .54394 L F
.513 .825 1 r
.21714 .54357 m .22076 .54392 L .21878 .54394 L F
.67 .36 .44 r
.53136 .68123 m .53371 .68348 L .5311 .68313 L F
.65 .365 .474 r
.53395 .68137 m .53371 .68348 L .53136 .68123 L F
.685 .646 .806 r
.79399 .49448 m .79524 .49795 L .79168 .49712 L F
.593 .634 .861 r
.79591 .49411 m .79524 .49795 L .79399 .49448 L F
.79591 .49411 m .79796 .49732 L .79524 .49795 L F
0 0 0 r
.56939 .63254 m .56922 .6321 L .57016 .63258 L F
.571 .923 .736 r
.57279 .63006 m .57016 .63258 L .57418 .63099 L F
.57279 .63006 m .56939 .63254 L .57016 .63258 L F
.907 .643 .527 r
.801 .49641 m .80312 .49902 L .80136 .49806 L F
.992 .818 .443 r
.59171 .62779 m .59208 .63108 L .59261 .62863 L F
.205 0 0 r
.38479 .6393 m .38137 .64011 L .3826 .63947 L F
.68 .171 .023 r
.54215 .67608 m .54426 .67776 L .54084 .67663 L F
0 0 .488 r
.5915 .61803 m .5901 .61708 L .58886 .61622 L F
.5915 .61803 m .59075 .61941 L .5901 .61708 L F
.43 .871 .816 r
.46846 .67453 m .46765 .67452 L .4667 .6752 L F
.4667 .6752 m .46765 .67452 L .46846 .67453 L F
.252 .764 .79 r
.47005 .67397 m .46765 .67452 L .46846 .67453 L F
.47005 .67397 m .46765 .67452 L .46846 .67453 L F
.845 .815 .821 r
.60849 .44878 m .60482 .44998 L .60713 .44716 L F
.414 .824 .976 r
.19966 .57237 m .20183 .57195 L .20394 .57249 L F
.20394 .57249 m .20183 .57195 L .19966 .57237 L F
.081 .621 .852 r
.20183 .57195 m .20565 .57256 L .20394 .57249 L F
.20394 .57249 m .20565 .57256 L .20183 .57195 L F
.231 0 0 r
.17772 .54225 m .17977 .54242 L .18175 .5419 L F
.118 0 0 r
.17977 .54242 m .18364 .54165 L .18175 .5419 L F
.711 .943 .958 r
.50937 .698 m .50669 .69924 L .50836 .69917 L F
.26 .177 .569 r
.36797 .60747 m .36689 .6107 L .36585 .6084 L F
.688 .776 .918 r
.45343 .59338 m .45512 .59486 L .45729 .59396 L F
.816 .63 .651 r
.77749 .4854 m .77754 .48813 L .78089 .48846 L F
.252 .369 .788 r
.46337 .70732 m .46453 .7107 L .46579 .70912 L F
.334 .489 .865 r
.46453 .7107 m .46772 .71241 L .46579 .70912 L F
.504 .468 .751 r
.46453 .7107 m .46554 .71294 L .46772 .71241 L F
.13 0 .398 r
.22493 .60986 m .22402 .60793 L .22534 .60742 L F
.22493 .60986 m .2237 .61084 L .22402 .60793 L F
.646 .592 .78 r
.6869 .43337 m .68334 .43026 L .68597 .42988 L F
.578 .521 .755 r
.68838 .42906 m .6869 .43337 L .68597 .42988 L F
.68838 .42906 m .6893 .43275 L .6869 .43337 L F
.866 .665 .629 r
.56127 .634 m .56453 .6371 L .56505 .63585 L F
.56127 .634 m .56181 .63694 L .56453 .6371 L F
.558 .002 0 r
.56271 .63699 m .56342 .63741 L .56453 .6371 L F
.56 .398 .618 r
.56453 .6371 m .56657 .63442 L .56505 .63585 L F
.56453 .6371 m .56719 .63681 L .56657 .63442 L F
.711 .327 .321 r
.56342 .63741 m .56719 .63681 L .56453 .6371 L F
.802 .669 .717 r
.56127 .634 m .56505 .63585 L .56281 .63231 L F
.711 .327 .321 r
.56342 .63741 m .56728 .6389 L .56719 .63681 L F
.56342 .63741 m .56582 .63969 L .56728 .6389 L F
.97 .719 .499 r
.5642 .63487 m .56545 .6386 L .56342 .63741 L F
.56545 .6386 m .56582 .63969 L .56342 .63741 L F
.558 .002 0 r
.56181 .63694 m .56342 .63741 L .56271 .63699 L F
.675 .973 .801 r
.62944 .42575 m .63086 .42523 L .63287 .42369 L F
.66 .248 .253 r
.41216 .62439 m .4145 .62502 L .412 .6232 L F
.899 .509 .074 r
.412 .6232 m .41216 .62439 L .41089 .62206 L F
.635 .924 .975 r
.44783 .61289 m .44694 .61445 L .44907 .61362 L F
.44783 .61289 m .44554 .61392 L .44694 .61445 L F
.44783 .61289 m .44694 .61445 L .44907 .61362 L F
.44783 .61289 m .44554 .61392 L .44694 .61445 L F
.625 .328 .447 r
.59908 .47704 m .59621 .47765 L .59717 .47733 L F
.59908 .47704 m .59934 .47871 L .59621 .47765 L F
.62 .325 .448 r
.59908 .47704 m .60138 .47892 L .59934 .47871 L F
.624 .324 .441 r
.60295 .47644 m .60138 .47892 L .59908 .47704 L F
.963 .667 .25 r
.67228 .44505 m .67167 .446 L .67109 .44383 L F
.67228 .44505 m .6726 .44709 L .67167 .446 L F
.806 .767 .817 r
.60647 .45146 m .60223 .45278 L .60482 .44998 L F
.588 .404 .6 r
.54378 .69404 m .54591 .6953 L .54655 .69315 L F
.251 .008 .338 r
.54655 .69315 m .54591 .6953 L .5482 .69231 L F
.5482 .69231 m .54591 .6953 L .54655 .69315 L F
.201 .002 .371 r
.20809 .63937 m .20826 .64211 L .20622 .64279 L F
.303 .134 .479 r
.20826 .64211 m .2057 .64491 L .20622 .64279 L F
.721 .204 0 r
.3847 .62498 m .3882 .62704 L .38835 .62649 L F
.675 .423 .532 r
.59621 .47765 m .59321 .48172 L .59297 .48012 L F
.59621 .47765 m .59577 .48184 L .59321 .48172 L F
.606 .355 .511 r
.59934 .47871 m .59577 .48184 L .59621 .47765 L F
.322 .009 .27 r
.48527 .72189 m .48727 .72144 L .48751 .71973 L F
.48751 .71973 m .48727 .72144 L .48527 .72189 L F
.409 .381 .717 r
.24001 .56376 m .24092 .56694 L .23899 .56772 L F
.639 .822 .403 r
.24092 .56694 m .23909 .56999 L .23899 .56772 L F
.577 .421 .632 r
.2057 .64491 m .20384 .64846 L .20419 .64613 L F
.601 .452 .652 r
.47375 .66717 m .4738 .66937 L .47639 .66656 L F
.47 .167 .369 r
.53058 .63797 m .53035 .63956 L .53327 .63882 L F
.124 0 0 r
.19939 .54226 m .20142 .54249 L .20306 .54257 L F
.457 0 0 r
.20142 .54249 m .20521 .54353 L .20306 .54257 L F
.792 .707 .77 r
.65202 .43164 m .65359 .43353 L .65027 .43256 L F
.88 .875 .827 r
.65359 .43353 m .65029 .43498 L .65027 .43256 L F
.65359 .43353 m .6513 .43636 L .65029 .43498 L F
0 0 0 r
.63375 .41706 m .63178 .41792 L .6307 .4186 L F
.946 .898 .507 r
.5588 .67961 m .55841 .68346 L .55965 .68161 L F
.959 .641 .233 r
.55539 .66031 m .5568 .66348 L .55675 .66314 L F
.281 .769 .912 r
.40187 .57926 m .40413 .57893 L .40568 .57925 L F
.377 .821 .947 r
.40413 .57893 m .40799 .57885 L .40568 .57925 L F
.535 .228 .393 r
.40281 .62561 m .40554 .62523 L .40618 .62252 L F
.746 .432 .451 r
.40618 .62252 m .40845 .62537 L .40863 .62307 L F
.40618 .62252 m .40554 .62523 L .40845 .62537 L F
.413 .152 .405 r
.68786 .43866 m .68668 .44132 L .68516 .44138 L F
.451 .289 .57 r
.69037 .43733 m .68668 .44132 L .68786 .43866 L F
.198 .671 .937 r
.42718 .58362 m .42366 .58276 L .42512 .58388 L F
.966 .656 .382 r
.54854 .707 m .54833 .7046 L .54714 .70613 L F
.297 .076 .4 r
.21101 .63677 m .21044 .6394 L .20809 .63937 L F
0 0 .053 r
.21044 .6394 m .20826 .64211 L .20809 .63937 L F
.511 .328 .57 r
.33653 .59659 m .33874 .59607 L .33882 .59356 L F
.513 .334 .575 r
.33653 .59659 m .33871 .59856 L .33874 .59607 L F
.48 .335 .606 r
.33665 .59907 m .33871 .59856 L .33653 .59659 L F
.839 .57 .532 r
.55837 .63721 m .5555 .63673 L .55519 .63428 L F
.736 .273 .15 r
.55837 .63721 m .55735 .63849 L .5555 .63673 L F
.802 .361 .198 r
.55837 .63721 m .56058 .64004 L .55735 .63849 L F
.809 .338 .099 r
.56204 .6402 m .56058 .64004 L .55837 .63721 L F
.753 .371 .33 r
.45302 .62852 m .44896 .62924 L .44907 .62727 L F
.45302 .62852 m .45165 .63052 L .44896 .62924 L F
.322 0 0 r
.45508 .62969 m .45165 .63052 L .45302 .62852 L F
.428 .146 .381 r
.55647 .63095 m .55908 .63081 L .55934 .62859 L F
.558 .254 .408 r
.55908 .63081 m .56069 .62889 L .55934 .62859 L F
.675 .973 .801 r
.62944 .42575 m .63287 .42369 L .63182 .42512 L F
.502 .882 .687 r
.6343 .42244 m .63287 .42369 L .63561 .42179 L F
0 0 0 r
.63182 .42512 m .63287 .42369 L .6343 .42244 L F
.756 .767 .862 r
.79399 .49448 m .79168 .49712 L .7914 .49449 L F
.648 .835 .972 r
.5057 .73612 m .5072 .73727 L .50939 .73632 L F
.50939 .73632 m .5072 .73727 L .5057 .73612 L F
0 0 0 r
.55505 .63155 m .55539 .63142 L .55647 .63095 L F
.076 .536 .901 r
.55419 .63018 m .55627 .63109 L .55539 .63142 L F
.56 .151 .224 r
.55539 .63142 m .55908 .63081 L .55647 .63095 L F
.55539 .63142 m .55863 .63213 L .55908 .63081 L F
.076 .536 .901 r
.55627 .63109 m .55863 .63213 L .55539 .63142 L F
0 0 0 r
.55499 .63157 m .55539 .63142 L .55505 .63155 L F
.81 .707 .751 r
.52843 .64291 m .532 .64346 L .53035 .63956 L F
.39 .23 .542 r
.53171 .64256 m .53551 .6413 L .53208 .64125 L F
0 0 .362 r
.53035 .63956 m .53127 .64173 L .53136 .64179 L F
.53127 .64173 m .53191 .64323 L .53159 .64238 L F
.53127 .64173 m .53159 .64238 L .53136 .64179 L F
.351 0 0 r
.53729 .64331 m .53164 .6428 L .53431 .64406 L F
.53729 .64331 m .53543 .64382 L .53164 .6428 L F
.39 .23 .542 r
.53177 .64275 m .53543 .64382 L .53551 .6413 L F
0 0 .362 r
.53191 .64323 m .532 .64346 L .53188 .64313 L F
.53191 .64323 m .53188 .64313 L .53136 .64179 L F
.151 .541 .924 r
.532 .64346 m .53164 .6428 L .53136 .64179 L F
.39 .23 .542 r
.53164 .6428 m .53181 .64285 L .53177 .64275 L F
.53181 .64285 m .53543 .64382 L .53177 .64275 L F
.53164 .6428 m .53177 .64275 L .53171 .64256 L F
.53177 .64275 m .53551 .6413 L .53171 .64256 L F
.151 .541 .924 r
.532 .64346 m .53431 .64406 L .53164 .6428 L F
0 0 0 r
.64268 .47245 m .64372 .47147 L .64579 .47052 L F
.824 .405 0 r
.54618 .64751 m .54605 .64606 L .54402 .64549 L F
.847 .729 .734 r
.57159 .62804 m .56922 .6321 L .56799 .62865 L F
.786 .485 .478 r
.56799 .62865 m .57077 .6289 L .57159 .62804 L F
.706 .702 .843 r
.57077 .6289 m .57379 .628 L .57159 .62804 L F
.964 .719 .28 r
.66651 .45508 m .66719 .45356 L .66707 .4514 L F
.66651 .45508 m .66726 .45618 L .66719 .45356 L F
.558 .568 .82 r
.18244 .55571 m .18463 .55519 L .1803 .55361 L F
.18244 .55571 m .18443 .55565 L .18463 .55519 L F
.137 .032 .461 r
.48451 .61263 m .48515 .61597 L .48336 .61669 L F
.031 0 .176 r
.48515 .61597 m .48317 .61886 L .48336 .61669 L F
0 .458 .825 r
.67122 .4266 m .67087 .42692 L .66872 .42404 L F
.67122 .4266 m .67232 .42743 L .67087 .42692 L F
.128 0 0 r
.64771 .43817 m .65019 .43754 L .6513 .43636 L F
.996 .767 .452 r
.6513 .43636 m .65019 .43754 L .65029 .43498 L F
0 .412 .743 r
.56104 .64023 m .55938 .63971 L .56058 .64004 L F
.857 .404 .087 r
.56521 .64372 m .56403 .64348 L .56228 .64058 L F
.56521 .64372 m .56228 .64058 L .56243 .64063 L F
.56243 .64063 m .56228 .64058 L .56204 .6402 L F
0 .016 .589 r
.56204 .6402 m .5632 .64211 L .56339 .64118 L F
.5632 .64211 m .56403 .64348 L .56339 .64118 L F
.501 .848 .995 r
.56411 .63992 m .56364 .64003 L .56339 .64118 L F
0 .016 .589 r
.56204 .6402 m .56339 .64118 L .56058 .64004 L F
.501 .848 .995 r
.56364 .64003 m .56174 .64046 L .56339 .64118 L F
0 .412 .743 r
.56339 .64118 m .5599 .6399 L .56104 .64023 L F
.5599 .6399 m .55938 .63971 L .56104 .64023 L F
.891 .491 .057 r
.56521 .64372 m .5648 .64458 L .56403 .64348 L F
.56521 .64372 m .56586 .64553 L .5648 .64458 L F
.588 .404 .6 r
.54378 .69404 m .54449 .6974 L .54591 .6953 L F
.602 .627 .849 r
.35381 .63424 m .35459 .63064 L .35298 .63117 L F
.35381 .63424 m .35641 .63382 L .35459 .63064 L F
0 0 0 r
.41285 .58736 m .40924 .5883 L .41055 .58777 L F
.683 .54 .684 r
.68597 .42988 m .68334 .43026 L .68531 .42756 L F
.491 .493 .786 r
.68678 .42359 m .68531 .42756 L .68443 .42445 L F
.68678 .42359 m .68771 .42741 L .68531 .42756 L F
.491 .496 .79 r
.68771 .42741 m .68838 .42906 L .68531 .42756 L F
.561 .466 .704 r
.68838 .42906 m .68597 .42988 L .68531 .42756 L F
.793 .799 .857 r
.79161 .50133 m .79296 .5029 L .7923 .50038 L F
.808 .839 .874 r
.78993 .50286 m .79296 .5029 L .79161 .50133 L F
.713 .752 .883 r
.7923 .50038 m .79296 .5029 L .79555 .50117 L F
.32 0 0 r
.36384 .58477 m .36634 .58475 L .36739 .58434 L F
.267 0 0 r
.36634 .58475 m .36969 .5843 L .36739 .58434 L F
.071 0 .445 r
.2345 .58641 m .23363 .58487 L .23528 .58372 L F
.2345 .58641 m .23364 .58746 L .23363 .58487 L F
.585 .776 .97 r
.43325 .5942 m .43579 .59361 L .43426 .59236 L F
.43325 .5942 m .43579 .59361 L .43426 .59236 L F
.739 .653 .764 r
.56281 .63231 m .56505 .63585 L .56657 .63442 L F
.645 .367 .483 r
.60513 .47641 m .60138 .47892 L .60295 .47644 L F
.613 .302 .419 r
.48069 .72081 m .48389 .72208 L .48212 .7199 L F
.759 .277 .095 r
.48212 .7199 m .48527 .72189 L .48384 .71886 L F
.48212 .7199 m .48389 .72208 L .48527 .72189 L F
.765 .654 .739 r
.47317 .72149 m .46978 .72189 L .47199 .71923 L F
.174 0 0 r
.47317 .72149 m .47238 .72187 L .46978 .72189 L F
.087 .288 .771 r
.47199 .71923 m .47429 .72081 L .47317 .72149 L F
.374 .812 .658 r
.47429 .72081 m .47238 .72187 L .47317 .72149 L F
.399 .846 .922 r
.38309 .62462 m .38235 .62534 L .38079 .62524 L F
.248 0 .043 r
.37985 .59985 m .37973 .59877 L .38218 .59825 L F
.37985 .59985 m .37814 .60104 L .37973 .59877 L F
.369 .001 .203 r
.68516 .44138 m .68485 .44331 L .6824 .44393 L F
.683 .388 .469 r
.68668 .44132 m .68485 .44331 L .68516 .44138 L F
.448 .342 .641 r
.33529 .60543 m .3371 .60502 L .33714 .60188 L F
.465 .408 .709 r
.33529 .60543 m .33785 .60727 L .3371 .60502 L F
.497 .405 .681 r
.33575 .60774 m .33785 .60727 L .33529 .60543 L F
.359 .169 .482 r
.22722 .60173 m .22511 .60494 L .22523 .60239 L F
.181 .679 .915 r
.35298 .63117 m .34859 .63046 L .35025 .63164 L F
.549 .087 .109 r
.63142 .47418 m .63491 .47399 L .63399 .47556 L F
.049 0 0 r
.63491 .47399 m .63604 .47415 L .63399 .47556 L F
.63491 .47399 m .63749 .47388 L .63604 .47415 L F
.771 .594 .659 r
.42645 .62213 m .43036 .62188 L .43076 .62019 L F
.809 .999 .837 r
.49095 .69243 m .48931 .69409 L .4867 .69563 L F
.419 .815 .985 r
.41018 .57799 m .41389 .5782 L .41162 .57879 L F
.23 0 .306 r
.5529 .68639 m .55055 .68935 L .55112 .68741 L F
.55112 .68741 m .55055 .68935 L .5529 .68639 L F
.781 .614 .673 r
.77339 .49185 m .77278 .49407 L .77628 .49435 L F
.51 .857 .993 r
.5243 .64321 m .52561 .64371 L .52843 .64291 L F
.218 0 .091 r
.52792 .68392 m .52526 .68617 L .52575 .68412 L F
.651 .353 .453 r
.51457 .67751 m .517 .67807 L .51795 .67529 L F
.655 .357 .455 r
.51795 .67529 m .52043 .6775 L .52043 .67503 L F
.51795 .67529 m .517 .67807 L .52043 .6775 L F
.86 .82 .807 r
.61654 .43511 m .61807 .43658 L .61579 .4395 L F
.849 .821 .82 r
.62039 .4335 m .61807 .43658 L .61654 .43511 L F
.617 .561 .769 r
.7702 .49481 m .77132 .49041 L .76908 .49111 L F
.7702 .49481 m .77278 .49407 L .77132 .49041 L F
.857 .9 .865 r
.79193 .48856 m .79007 .48845 L .79043 .48741 L F
.866 .892 .852 r
.79007 .48845 m .79193 .48856 L .79043 .48741 L F
.79007 .48845 m .79043 .48995 L .79193 .48856 L F
.548 .919 .943 r
.62722 .41718 m .62841 .4174 L .6258 .41848 L F
0 0 .302 r
.62722 .41718 m .6258 .41848 L .62548 .42134 L F
.356 .255 .6 r
.42103 .6133 m .42119 .61608 L .41928 .61402 L F
.42103 .6133 m .42119 .61608 L .41928 .61402 L F
.943 .68 .214 r
.66787 .43244 m .66879 .43613 L .66808 .43477 L F
.822 .491 0 r
.66808 .43477 m .66879 .43613 L .66935 .43822 L F
.693 .644 .797 r
.33799 .61956 m .34144 .62001 L .34006 .61664 L F
.438 .457 .782 r
.34144 .62001 m .34222 .61622 L .34006 .61664 L F
.34144 .62001 m .34324 .61975 L .34222 .61622 L F
.662 .472 .616 r
.44789 .62492 m .45097 .62389 L .44797 .62277 L F
.44789 .62492 m .45123 .62497 L .45097 .62389 L F
.819 .773 .81 r
.68095 .42366 m .68183 .42706 L .67897 .42623 L F
.688 .696 .853 r
.68443 .42445 m .68183 .42706 L .68095 .42366 L F
.191 0 0 r
.64202 .45084 m .64131 .45165 L .64464 .45015 L F
.64202 .45084 m .64131 .45165 L .64464 .45015 L F
.307 .157 .508 r
.22087 .61848 m .21915 .61727 L .22072 .61622 L F
.22087 .61848 m .21894 .61947 L .21915 .61727 L F
.589 .768 .964 r
.63792 .41794 m .63375 .41706 L .63628 .41583 L F
.539 .709 .95 r
.64025 .41746 m .63792 .41794 L .63628 .41583 L F
.677 .851 .966 r
.64177 .42046 m .63792 .41794 L .64025 .41746 L F
.64177 .42046 m .63781 .42063 L .63792 .41794 L F
.864 .925 .866 r
.66649 .42459 m .66407 .42734 L .66365 .42578 L F
0 0 .414 r
.66407 .42734 m .66474 .42809 L .66365 .42578 L F
.66407 .42734 m .66505 .42909 L .66474 .42809 L F
.301 0 0 r
.4315 .629 m .43011 .63074 L .4279 .63113 L F
.349 0 0 r
.43421 .62934 m .43011 .63074 L .4315 .629 L F
.348 0 0 r
.43542 .62831 m .43421 .62934 L .4315 .629 L F
.29 .165 .531 r
.57705 .62303 m .57843 .62342 L .57832 .61964 L F
0 .497 .846 r
.22482 .5456 m .22658 .54605 L .22828 .54699 L F
.139 .614 .922 r
.22872 .5464 m .22828 .54699 L .22658 .54605 L F
.22872 .5464 m .2304 .54725 L .22828 .54699 L F
.205 0 0 r
.19806 .59226 m .19979 .59214 L .20128 .59052 L F
0 0 0 r
.20128 .59052 m .20203 .58973 L .20362 .58721 L F
.304 .022 .31 r
.19979 .59214 m .20203 .58973 L .20128 .59052 L F
.272 .163 .542 r
.24001 .56062 m .24001 .56376 L .23891 .56345 L F
.961 .718 .524 r
.34065 .62935 m .33898 .63027 L .33911 .62784 L F
.757 .526 .583 r
.33898 .63027 m .34295 .62832 L .34065 .62935 L F
.739 .653 .764 r
.56281 .63231 m .56657 .63442 L .56613 .63323 L F
0 0 0 r
.56922 .6321 m .56773 .63366 L .56657 .63442 L F
.299 .609 .954 r
.56657 .63442 m .56773 .63366 L .56613 .63323 L F
.852 .881 .86 r
.61331 .44243 m .60973 .44399 L .61203 .44119 L F
.86 .849 .832 r
.61579 .4395 m .61331 .44243 L .61203 .44119 L F
.671 .688 .857 r
.51217 .70651 m .5126 .70832 L .51509 .70679 L F
.333 0 0 r
.39001 .58063 m .39222 .58087 L .39354 .58026 L F
.874 .728 .697 r
.62265 .43509 m .62582 .43608 L .62608 .43307 L F
.867 .745 .726 r
.62265 .43509 m .62373 .43814 L .62582 .43608 L F
.874 .728 .697 r
.62265 .43509 m .62608 .43307 L .6253 .43223 L F
.895 .815 .761 r
.58113 .62527 m .5807 .62899 L .58106 .62795 L F
0 0 .396 r
.58241 .63069 m .58106 .62795 L .5807 .62899 L F
.353 .362 .73 r
.58148 .63147 m .58241 .63069 L .5807 .62899 L F
.497 .317 .567 r
.33882 .59356 m .34092 .59551 L .34094 .59302 L F
.33882 .59356 m .33874 .59607 L .34092 .59551 L F
.59 .502 .723 r
.33778 .61708 m .33799 .61956 L .34006 .61664 L F
.626 .458 .635 r
.52919 .70402 m .53199 .70092 L .53008 .70205 L F
.143 .019 .44 r
.58159 .63411 m .58241 .63069 L .58148 .63147 L F
.678 .327 .371 r
.45397 .62446 m .45611 .62478 L .45761 .62268 L F
.778 .611 .673 r
.45611 .62478 m .45993 .62226 L .45761 .62268 L F
.52 .314 .54 r
.53572 .70394 m .53311 .70716 L .53345 .70458 L F
.361 .177 .491 r
.64578 .44064 m .64771 .43817 L .64563 .43904 L F
.296 .094 .426 r
.23909 .56999 m .23853 .57271 L .23706 .57314 L F
.467 .259 .512 r
.23886 .575 m .23706 .57314 L .23853 .57271 L F
.23886 .575 m .23678 .57556 L .23706 .57314 L F
.778 .608 .669 r
.57052 .4856 m .57075 .48854 L .56927 .48657 L F
0 0 0 r
.56927 .48681 m .57052 .4856 L .56927 .48657 L F
.57194 .48358 m .57172 .48396 L .57129 .48596 L F
.8 .996 .863 r
.57277 .4823 m .57172 .48396 L .57223 .48251 L F
0 0 0 r
.57223 .48251 m .57172 .48396 L .57194 .48358 L F
.605 .858 .505 r
.57172 .48396 m .5729 .48268 L .57137 .48455 L F
.57172 .48396 m .57137 .48455 L .57052 .4856 L F
.88 .597 .504 r
.56927 .48657 m .57075 .48854 L .57035 .49058 L F
.863 .587 .52 r
.56927 .48657 m .57035 .49058 L .56704 .48983 L F
.619 .879 .544 r
.57172 .48396 m .57052 .4856 L .56927 .48681 L F
.804 .406 .298 r
.57052 .4856 m .57417 .4882 L .57075 .48854 L F
.697 .727 .873 r
.79816 .50017 m .79904 .50277 L .80121 .50181 L F
.635 .425 .58 r
.52287 .67465 m .52533 .67195 L .52316 .67245 L F
.245 0 0 r
.46238 .63232 m .46414 .63266 L .46336 .63299 L F
.46238 .63232 m .46336 .63299 L .46116 .63057 L F
.623 .331 .454 r
.62558 .47447 m .62905 .47535 L .62551 .47579 L F
.62558 .47447 m .62908 .47379 L .62905 .47535 L F
0 0 .127 r
.66838 .44307 m .66799 .44474 L .66835 .44204 L F
.88 .983 .7 r
.66655 .44691 m .66799 .44474 L .66838 .44307 L F
.723 .431 .483 r
.53762 .68332 m .53395 .68137 L .53673 .68068 L F
.53762 .68332 m .53371 .68348 L .53395 .68137 L F
.64 .786 .952 r
.63462 .45027 m .63681 .45105 L .63464 .44942 L F
.867 .791 .773 r
.63681 .45105 m .6352 .45205 L .63464 .44942 L F
.615 .743 .937 r
.44252 .58681 m .44394 .58803 L .44628 .58733 L F
.827 .574 .558 r
.56728 .6389 m .57008 .63716 L .56719 .63681 L F
.56728 .6389 m .57021 .63977 L .57008 .63716 L F
.462 .803 .999 r
.41389 .5782 m .41613 .57783 L .41751 .57866 L F
.691 .89 .97 r
.41751 .57866 m .41811 .5768 L .4193 .57765 L F
.41751 .57866 m .41613 .57783 L .41811 .5768 L F
.86 .849 .832 r
.61579 .4395 m .61203 .44119 L .61419 .43806 L F
.86 .82 .807 r
.61654 .43511 m .61579 .4395 L .61419 .43806 L F
.538 .316 .526 r
.25836 .82399 m .26033 .82627 L .2607 .82339 L F
.25836 .82399 m .26033 .82627 L .2607 .82339 L F
.064 .371 .838 r
.18554 .57543 m .18597 .57566 L .18597 .57603 L F
.157 .044 .463 r
.18597 .57566 m .18556 .57836 L .18597 .57603 L F
.521 .671 .931 r
.37237 .61664 m .37173 .61928 L .3699 .61666 L F
.37237 .61664 m .37401 .61879 L .37173 .61928 L F
0 .334 .814 r
.24917 .55654 m .24766 .55629 L .24683 .55548 L F
.24917 .55654 m .25025 .55792 L .24766 .55629 L F
.191 .381 .821 r
.24766 .55629 m .25025 .55792 L .24948 .55864 L F
.57 .625 .867 r
.48548 .73651 m .48127 .73408 L .48413 .73574 L F
.221 0 0 r
.38027 .58348 m .38429 .58199 L .38179 .58207 L F
.734 .629 .742 r
.48607 .69846 m .48399 .70188 L .48285 .698 L F
.335 0 .044 r
.48399 .70188 m .48544 .70307 L .48288 .70359 L F
.48399 .70188 m .48635 .70148 L .48551 .70295 L F
.48399 .70188 m .48551 .70295 L .48535 .70299 L F
.598 .514 .73 r
.48288 .70359 m .48594 .69979 L .48176 .70005 L F
.48288 .70359 m .48289 .70358 L .48288 .70359 L F
.48289 .70358 m .48594 .69979 L .48288 .70359 L F
.335 0 .044 r
.48535 .70299 m .48551 .70295 L .48544 .70307 L F
.681 .455 .572 r
.24948 .55864 m .24888 .56106 L .24668 .56044 L F
.43 .215 .484 r
.25119 .56012 m .24948 .55864 L .25025 .55792 L F
.25119 .56012 m .24888 .56106 L .24948 .55864 L F
.295 0 .214 r
.51475 .64643 m .51178 .64889 L .51407 .64823 L F
.214 0 .233 r
.51651 .64547 m .51475 .64643 L .51407 .64823 L F
.349 0 0 r
.67914 .42904 m .67578 .42774 L .67715 .42861 L F
0 0 0 r
.68111 .42812 m .67914 .42904 L .67979 .42874 L F
.607 .461 .657 r
.76805 .48912 m .77132 .49041 L .7702 .48671 L F
.76805 .48912 m .76908 .49111 L .77132 .49041 L F
.71 .482 .577 r
.65882 .46201 m .66231 .45872 L .66154 .46114 L F
.65882 .46201 m .65926 .459 L .66231 .45872 L F
.4 0 0 r
.66231 .45872 m .66319 .45989 L .66154 .46114 L F
.66231 .45872 m .66466 .45889 L .66319 .45989 L F
.361 .503 .866 r
.43989 .57789 m .43881 .57993 L .43764 .57861 L F
.43989 .57789 m .44304 .5826 L .43881 .57993 L F
.716 .73 .861 r
.50542 .72068 m .50732 .72169 L .50328 .72139 L F
.656 .219 .2 r
.50732 .72169 m .50561 .72337 L .50328 .72139 L F
.769 .369 .296 r
.50732 .72169 m .5091 .72407 L .50561 .72337 L F
.02 0 0 r
.42106 .58378 m .41746 .58472 L .41884 .58466 L F
.652 .355 .456 r
.62908 .47379 m .6314 .47585 L .62905 .47535 L F
.684 .341 .388 r
.62908 .47379 m .63142 .47418 L .6314 .47585 L F
.316 0 0 r
.39693 .63755 m .39527 .6386 L .39304 .63856 L F
.262 0 0 r
.39924 .63731 m .39527 .6386 L .39693 .63755 L F
.636 .198 0 r
.5359 .6993 m .53611 .69982 L .53664 .7005 L F
.201 .13 .548 r
.5386 .69702 m .5359 .6993 L .53697 .69505 L F
0 0 0 r
.5386 .69702 m .53611 .69982 L .5359 .6993 L F
.849 .821 .82 r
.62039 .4335 m .61654 .43511 L .61882 .43208 L F
.715 .704 .838 r
.78729 .48962 m .79043 .48995 L .79007 .48845 L F
.115 0 .336 r
.20338 .65071 m .20334 .64896 L .20384 .64846 L F
.20338 .65071 m .20245 .65159 L .20334 .64896 L F
0 0 0 r
.20334 .64896 m .20245 .65159 L .20231 .65178 L F
.367 0 0 r
.52232 .72748 m .52593 .72807 L .52448 .72816 L F
.164 0 0 r
.52448 .72816 m .52593 .72807 L .52804 .72838 L F
.567 .388 .598 r
.51517 .71899 m .51803 .71891 L .51814 .71605 L F
.664 .805 .95 r
.42718 .58362 m .431 .58401 L .42943 .58328 L F
0 .503 .715 r
.43308 .58381 m .42943 .58328 L .431 .58401 L F
.439 .195 .445 r
.38294 .59692 m .38412 .59842 L .38218 .59825 L F
.388 .125 .389 r
.21675 .62502 m .21486 .62562 L .21754 .62278 L F
.302 .044 .347 r
.21841 .62417 m .21754 .62278 L .21884 .62183 L F
.21841 .62417 m .21675 .62502 L .21754 .62278 L F
.489 .728 .978 r
.42952 .57792 m .42566 .57671 L .42993 .57703 L F
.512 .808 .999 r
.43045 .57637 m .42952 .57792 L .42993 .57703 L F
.43045 .57637 m .43215 .5775 L .42952 .57792 L F
.186 .687 .912 r
.18364 .54165 m .18581 .54157 L .1875 .5422 L F
.125 .627 .904 r
.18581 .54157 m .18947 .5425 L .1875 .5422 L F
.289 0 0 r
.52115 .70544 m .51958 .70604 L .52342 .70586 L F
.394 0 .094 r
.52115 .70544 m .52342 .70586 L .52428 .70483 L F
.714 .873 .956 r
.59162 .46493 m .58965 .46428 L .59207 .46152 L F
.756 .768 .863 r
.59549 .46191 m .59162 .46493 L .59207 .46152 L F
.223 0 .04 r
.53871 .66282 m .54256 .65994 L .53873 .66057 L F
.53871 .66282 m .54086 .66229 L .54256 .65994 L F
.812 .78 .823 r
.54498 .65858 m .54417 .66264 L .54329 .66046 L F
.54498 .65858 m .54663 .6599 L .54417 .66264 L F
.555 .31 .498 r
.54346 .66078 m .54514 .6614 L .54498 .65858 L F
0 0 .47 r
.54326 .66044 m .54417 .66264 L .54256 .65994 L F
.54333 .66057 m .54417 .66264 L .54326 .66044 L F
.555 .31 .498 r
.54268 .66192 m .54399 .66164 L .54346 .66078 L F
.54399 .66164 m .54514 .6614 L .54346 .66078 L F
0 0 .47 r
.54329 .66046 m .54333 .66057 L .54326 .66044 L F
.067 .626 .8 r
.58014 .64047 m .5789 .64026 L .57623 .64021 L F
.399 .853 .806 r
.58014 .64047 m .58023 .64015 L .5789 .64026 L F
.58014 .64047 m .58229 .63954 L .58023 .64015 L F
.461 0 0 r
.2304 .54725 m .23263 .54787 L .23425 .54682 L F
.943 .628 .412 r
.23425 .54682 m .23263 .54787 L .23458 .54856 L F
.414 .252 .551 r
.23727 .58077 m .23528 .58372 L .23559 .58169 L F
.331 0 0 r
.43736 .62849 m .43421 .62934 L .43542 .62831 L F
.436 .856 .953 r
.20013 .55508 m .19979 .55581 L .20188 .55489 L F
.20013 .55508 m .19812 .55557 L .19979 .55581 L F
.596 .536 .758 r
.33683 .61371 m .33778 .61708 L .34006 .61664 L F
.562 .358 .562 r
.20961 .58754 m .21195 .58724 L .21212 .58469 L F
.563 .567 .815 r
.21212 .58469 m .21289 .58071 L .21114 .58112 L F
.21212 .58469 m .21426 .58417 L .21289 .58071 L F
.448 .263 .536 r
.21212 .58469 m .21393 .5866 L .21426 .58417 L F
.21212 .58469 m .21195 .58724 L .21393 .5866 L F
.521 .39 .642 r
.47403 .68385 m .47462 .68625 L .47626 .6855 L F
.7 .518 .639 r
.46998 .70504 m .4729 .70358 L .469 .70275 L F
.685 .323 .356 r
.57921 .59608 m .58155 .59827 L .58308 .59617 L F
.794 .465 .433 r
.58155 .59827 m .58477 .59933 L .58308 .59617 L F
.662 .607 .782 r
.48017 .69855 m .48176 .69512 L .47902 .69551 L F
.48017 .69855 m .48285 .698 L .48176 .69512 L F
.457 .061 .2 r
.48176 .70005 m .48017 .69855 L .48 .70121 L F
.48176 .70005 m .48285 .698 L .48017 .69855 L F
.937 .637 .447 r
.48384 .71886 m .48389 .72208 L .48527 .72189 L F
.768 .422 .401 r
.48389 .72208 m .48727 .72144 L .48527 .72189 L F
.516 .33 .567 r
.48755 .72399 m .48527 .72189 L .48727 .72144 L F
.48755 .72399 m .48591 .72557 L .48527 .72189 L F
.389 .059 .279 r
.52571 .69823 m .52874 .69622 L .52441 .69547 L F
.52571 .69823 m .52789 .69791 L .52874 .69622 L F
.52874 .69622 m .52789 .69791 L .52571 .69823 L F
.118 0 .127 r
.52789 .69791 m .53049 .69518 L .52874 .69622 L F
.623 .635 .842 r
.59195 .65458 m .58814 .652 L .58946 .65527 L F
.959 .641 .233 r
.55539 .66031 m .55583 .66273 L .5568 .66348 L F
.978 .696 .309 r
.55583 .66273 m .557 .66596 L .5568 .66348 L F
.107 .661 .745 r
.3902 .59502 m .38646 .59534 L .38792 .59531 L F
.584 .315 .475 r
.33732 .62657 m .33911 .62784 L .33912 .62573 L F
.531 .916 .784 r
.47407 .61636 m .47035 .6182 L .47326 .61725 L F
.642 .317 .405 r
.47326 .61725 m .47641 .61547 L .47407 .61636 L F
.88 .983 .7 r
.66655 .44691 m .66838 .44307 L .66519 .44622 L F
.907 .497 .171 r
.66706 .45052 m .66655 .44691 L .66519 .44622 L F
0 0 0 r
.57522 .47967 m .5729 .48268 L .57461 .48152 L F
.57461 .48152 m .5729 .48268 L .57172 .48396 L F
.536 .74 .969 r
.36337 .63707 m .36416 .63531 L .36133 .63517 L F
.36337 .63707 m .36561 .63668 L .36416 .63531 L F
.78 .559 .601 r
.53859 .62232 m .53522 .61924 L .53652 .62256 L F
.373 .576 .919 r
.50612 .65422 m .50716 .65569 L .50911 .65558 L F
.472 .202 .422 r
.48104 .67513 m .48335 .67467 L .48403 .67263 L F
.48403 .67263 m .48335 .67467 L .48104 .67513 L F
.234 0 .31 r
.48403 .67263 m .48335 .67467 L .48569 .67171 L F
.48403 .67263 m .48335 .67467 L .48569 .67171 L F
.16 0 0 r
.38756 .58076 m .38654 .5812 L .39001 .58063 L F
.111 0 0 r
.57565 .48005 m .57522 .47967 L .57461 .48152 L F
.675 .608 .773 r
.57886 .48022 m .57813 .48011 L .57792 .47959 L F
.57813 .48011 m .57522 .47967 L .57792 .47959 L F
.111 0 0 r
.57565 .48005 m .57792 .47959 L .57522 .47967 L F
.795 .983 .897 r
.5777 .47905 m .57792 .47959 L .57565 .48005 L F
.57959 .47813 m .57792 .47959 L .5777 .47905 L F
.09 0 0 r
.18947 .5425 m .19163 .54249 L .19344 .5422 L F
.42 .85 .945 r
.19163 .54249 m .19547 .54212 L .19344 .5422 L F
.726 .412 .448 r
.57636 .48849 m .5802 .48848 L .57968 .4903 L F
.395 .095 .333 r
.57968 .4903 m .5802 .48848 L .5825 .48779 L F
.267 0 0 r
.67578 .42774 m .67267 .42885 L .67517 .42769 L F
.468 0 0 r
.67715 .42861 m .67578 .42774 L .67517 .42769 L F
.183 0 0 r
.5152 .6513 m .51828 .64924 L .51726 .65088 L F
.637 .789 .341 r
.51828 .64924 m .52008 .64582 L .52007 .6483 L F
.096 0 .067 r
.51726 .65088 m .51828 .64924 L .52007 .6483 L F
.841 .73 .741 r
.58079 .60707 m .58425 .61111 L .58276 .61342 L F
.683 .25 .216 r
.24127 .55499 m .24323 .55687 L .24538 .55524 L F
0 0 0 r
.24323 .55687 m .24683 .55548 L .24538 .55524 L F
.494 .379 .652 r
.33575 .60774 m .33838 .60989 L .33785 .60727 L F
.33575 .60774 m .33607 .61071 L .33838 .60989 L F
.004 0 0 r
.24246 .55953 m .24001 .56062 L .24025 .56026 L F
.79 .68 .743 r
.77132 .49041 m .77479 .49052 L .77405 .48772 L F
.77132 .49041 m .77339 .49185 L .77479 .49052 L F
.744 .748 .855 r
.77405 .48772 m .77479 .49052 L .77754 .48813 L F
.312 0 .04 r
.47896 .61374 m .48163 .61323 L .48259 .61167 L F
0 0 0 r
.48259 .61167 m .48306 .61049 L .48491 .61068 L F
.48259 .61167 m .48362 .61132 L .48306 .61049 L F
.579 .627 .864 r
.48451 .61263 m .48259 .61167 L .48491 .61068 L F
0 0 0 r
.48259 .61167 m .48163 .61323 L .48362 .61132 L F
0 .564 .788 r
.20569 .55548 m .20384 .5551 L .20188 .55489 L F
.299 .716 .973 r
.20597 .55545 m .20384 .5551 L .20569 .55548 L F
.658 .603 .782 r
.78236 .49679 m .78345 .50024 L .78601 .4994 L F
.417 0 0 r
.48274 .73511 m .48127 .73408 L .48057 .73256 L F
.48274 .73511 m .48413 .73574 L .48127 .73408 L F
0 0 .174 r
.48489 .6108 m .48535 .61159 L .48451 .61263 L F
.48535 .61159 m .48538 .61163 L .48537 .61163 L F
.48535 .61159 m .48537 .61163 L .48451 .61263 L F
.22 0 .012 r
.48362 .61132 m .48448 .61274 L .48555 .61207 L F
0 .133 .666 r
.48579 .61192 m .48668 .6148 L .48538 .61163 L F
.22 0 .012 r
.48545 .61183 m .48555 .61207 L .48579 .61192 L F
.48362 .61132 m .48555 .61207 L .48545 .61183 L F
.496 0 0 r
.48306 .61049 m .48544 .61174 L .48538 .61163 L F
.48544 .61174 m .48579 .61192 L .48538 .61163 L F
0 0 .174 r
.48491 .61068 m .48538 .61163 L .48489 .6108 L F
.296 .13 .48 r
.48668 .6148 m .48451 .61263 L .48538 .61163 L F
.48668 .6148 m .48515 .61597 L .48451 .61263 L F
.634 .576 .771 r
.1956 .59294 m .19899 .59584 L .19806 .59226 L F
.396 .066 .285 r
.49095 .69243 m .49336 .69208 L .49282 .69121 L F
0 0 .44 r
.49282 .69121 m .49458 .6907 L .49356 .69042 L F
0 0 .528 r
.49458 .6907 m .49601 .69236 L .4964 .69101 L F
.49601 .69236 m .49687 .69336 L .4964 .69101 L F
.496 .096 .211 r
.4964 .69101 m .49824 .6878 L .49485 .68905 L F
.67 .4 .503 r
.49485 .68905 m .49784 .68639 L .4961 .68572 L F
.49485 .68905 m .49824 .6878 L .49784 .68639 L F
.727 .781 .895 r
.49736 .68863 m .4964 .69101 L .49563 .68787 L F
.4964 .69101 m .49736 .68863 L .49699 .68898 L F
.257 .314 .731 r
.49458 .6907 m .49687 .69336 L .4964 .69101 L F
.166 0 0 r
.49537 .69092 m .49458 .6907 L .49279 .69072 L F
.4964 .69101 m .49458 .6907 L .49537 .69092 L F
.496 .096 .211 r
.4964 .69101 m .49485 .68905 L .49458 .6907 L F
0 0 .44 r
.49282 .69121 m .49336 .69208 L .49458 .6907 L F
.166 0 0 r
.49279 .69072 m .49458 .6907 L .4964 .69101 L F
0 0 .44 r
.49356 .69042 m .49458 .6907 L .49485 .68905 L F
.166 0 0 r
.4964 .69101 m .49279 .69072 L .49563 .68787 L F
.49279 .69072 m .4936 .69078 L .4943 .69148 L F
.4936 .69078 m .4964 .69101 L .4943 .69148 L F
.727 .781 .895 r
.4964 .69101 m .49699 .68898 L .4943 .69148 L F
0 0 0 r
.49563 .68787 m .49279 .69072 L .49286 .69069 L F
.49349 .69007 m .49286 .69069 L .4929 .69067 L F
.49563 .68787 m .49286 .69069 L .49349 .69007 L F
.49563 .68787 m .4929 .69067 L .49391 .68845 L F
.839 .753 .768 r
.4943 .69148 m .49736 .68863 L .49391 .68845 L F
.4943 .69148 m .49406 .68958 L .49617 .68932 L F
.626 .418 .58 r
.50158 .68936 m .49914 .69207 L .4991 .68948 L F
.50158 .68936 m .50169 .69197 L .49914 .69207 L F
.648 .49 .655 r
.49914 .69207 m .49953 .69507 L .49677 .69501 L F
.532 .407 .655 r
.50154 .69448 m .49914 .69207 L .50169 .69197 L F
.50154 .69448 m .49953 .69507 L .49914 .69207 L F
.728 .671 .794 r
.49687 .69336 m .50061 .69287 L .49878 .68994 L F
.49687 .69336 m .49878 .68994 L .4964 .69101 L F
.532 .425 .678 r
.49907 .69077 m .49562 .69192 L .49815 .69031 L F
.49562 .69192 m .49447 .6923 L .49517 .69192 L F
.49562 .69192 m .49517 .69192 L .49815 .69031 L F
.242 0 .062 r
.49618 .69244 m .49447 .6923 L .49907 .69077 L F
.257 0 .229 r
.49517 .69192 m .49447 .6923 L .49618 .69244 L F
.538 .053 .052 r
.49878 .68994 m .49824 .6878 L .49642 .69098 L F
.49878 .68994 m .49642 .69098 L .4964 .69101 L F
0 0 .169 r
.4991 .68948 m .50034 .68853 L .50068 .68643 L F
.853 .502 0 r
.49824 .6878 m .4991 .68948 L .49784 .68639 L F
0 0 .169 r
.4991 .68948 m .50068 .68643 L .49784 .68639 L F
.272 .505 .896 r
.49824 .6878 m .50034 .68853 L .4991 .68948 L F
.31 .053 .352 r
.50068 .68643 m .50034 .68853 L .50252 .68749 L F
.538 .053 .052 r
.49878 .68994 m .50034 .68853 L .49824 .6878 L F
.594 .881 .992 r
.50252 .68749 m .50034 .68853 L .50114 .68697 L F
.71 .929 .602 r
.50004 .68836 m .50034 .68853 L .49878 .68994 L F
.50114 .68697 m .50105 .68714 L .50004 .68836 L F
.50105 .68714 m .50034 .68853 L .50004 .68836 L F
.838 .728 .742 r
.49736 .68863 m .49911 .68947 L .4983 .68695 L F
.71 .929 .602 r
.50114 .68697 m .50004 .68836 L .50145 .68903 L F
.50004 .68836 m .49878 .68994 L .49955 .68968 L F
.50004 .68836 m .49955 .68968 L .50145 .68903 L F
.838 .728 .742 r
.49911 .68947 m .49955 .68968 L .49933 .68921 L F
.49911 .68947 m .49933 .68921 L .4983 .68695 L F
.49955 .68968 m .49971 .68976 L .4996 .68953 L F
.49955 .68968 m .4996 .68953 L .4983 .68695 L F
.71 .929 .602 r
.50145 .68903 m .49955 .68968 L .50148 .68918 L F
.723 .78 .897 r
.49878 .68994 m .49971 .68976 L .49955 .68968 L F
.71 .929 .602 r
.49955 .68968 m .49878 .68994 L .49953 .68973 L F
.49955 .68968 m .49953 .68973 L .50148 .68918 L F
.723 .78 .897 r
.49878 .68994 m .49955 .68968 L .49946 .68964 L F
.49878 .68994 m .49946 .68964 L .49736 .68863 L F
.727 .781 .895 r
.49736 .68863 m .49878 .68994 L .4964 .69101 L F
.4964 .69101 m .49878 .68994 L .49736 .68863 L F
.532 .425 .678 r
.49815 .69031 m .49517 .69192 L .49617 .68932 L F
.257 0 .229 r
.4943 .69148 m .49447 .6923 L .49517 .69192 L F
.532 .425 .678 r
.49517 .69192 m .49447 .6923 L .49468 .69192 L F
.49517 .69192 m .49468 .69192 L .49617 .68932 L F
.257 0 .229 r
.49402 .69193 m .49517 .69249 L .49362 .69257 L F
.839 .753 .768 r
.4943 .69148 m .49468 .69192 L .49447 .6923 L F
.257 0 .229 r
.4943 .69148 m .49468 .69192 L .49402 .69193 L F
.49468 .69192 m .49517 .69249 L .49402 .69193 L F
.49468 .69192 m .49618 .69244 L .49517 .69249 L F
.4943 .69148 m .49517 .69192 L .49468 .69192 L F
.49517 .69192 m .49618 .69244 L .49468 .69192 L F
.839 .753 .768 r
.4943 .69148 m .49471 .69188 L .49468 .69192 L F
.4943 .69148 m .49617 .68932 L .49471 .69188 L F
.532 .425 .678 r
.49907 .69077 m .49617 .68932 L .49835 .68898 L F
.028 0 0 r
.49468 .69051 m .4981 .68908 L .49617 .68932 L F
.4981 .68908 m .49835 .68898 L .49617 .68932 L F
.839 .753 .768 r
.49406 .68958 m .49405 .68952 L .49617 .68932 L F
.49405 .68952 m .49391 .68845 L .49479 .68879 L F
.49405 .68952 m .49479 .68879 L .49617 .68932 L F
.934 .64 .46 r
.55519 .63428 m .55386 .63592 L .5533 .63374 L F
.55519 .63428 m .5555 .63673 L .55386 .63592 L F
.549 .087 .109 r
.63142 .47418 m .63399 .47556 L .6314 .47585 L F
.769 .265 0 r
.53698 .6393 m .54096 .64239 L .53967 .64095 L F
.541 .927 .875 r
.46414 .63266 m .46839 .6312 L .46729 .63144 L F
0 0 0 r
.46961 .63074 m .46839 .6312 L .4703 .6302 L F
.254 .761 .739 r
.46729 .63144 m .46839 .6312 L .46961 .63074 L F
.946 .898 .507 r
.5588 .67961 m .55791 .68313 L .55841 .68346 L F
.581 .045 0 r
.64032 .46378 m .64218 .46528 L .64127 .46471 L F
.64032 .46378 m .64218 .46528 L .64127 .46471 L F
0 0 0 r
.64332 .46205 m .64292 .46317 L .64314 .46316 L F
.64292 .46317 m .64218 .46528 L .64314 .46316 L F
.067 .23 .723 r
.64032 .46378 m .64127 .46471 L .64092 .46368 L F
.64031 .46375 m .64092 .46368 L .63997 .46085 L F
.64032 .46378 m .64092 .46368 L .64031 .46375 L F
.635 .087 0 r
.63994 .46405 m .64127 .46471 L .64032 .46378 L F
.848 .722 .724 r
.64127 .46471 m .64332 .46205 L .63997 .46085 L F
.772 .935 .936 r
.64314 .46316 m .64127 .46471 L .63994 .46405 L F
.64226 .46353 m .63994 .46405 L .64206 .46361 L F
.64314 .46316 m .64148 .46362 L .64226 .46353 L F
.64148 .46362 m .63994 .46405 L .64226 .46353 L F
0 0 0 r
.64339 .46314 m .64314 .46316 L .64206 .46361 L F
.64549 .46239 m .64314 .46316 L .64339 .46314 L F
.763 .97 .925 r
.64314 .46316 m .64218 .46528 L .64127 .46471 L F
.64314 .46316 m .64218 .46528 L .64127 .46471 L F
.49 .333 .594 r
.53931 .67742 m .53972 .68042 L .53673 .68068 L F
.467 .365 .656 r
.53972 .68042 m .53762 .68332 L .53673 .68068 L F
.317 .427 .816 r
.36857 .61338 m .3699 .61666 L .36828 .61635 L F
.587 .078 .008 r
.44409 .62252 m .44797 .62277 L .44544 .62236 L F
.818 .52 .486 r
.44461 .62415 m .44797 .62277 L .44409 .62252 L F
.44461 .62415 m .44789 .62492 L .44797 .62277 L F
.288 0 0 r
.57765 .63844 m .57616 .6381 L .57589 .63816 L F
0 0 .158 r
.57549 .63824 m .57589 .63816 L .57588 .6354 L F
.131 0 0 r
.57542 .63497 m .57702 .63505 L .57847 .63465 L F
.5755 .63505 m .57702 .63505 L .57542 .63497 L F
.57473 .63504 m .5755 .63505 L .57542 .63497 L F
0 0 0 r
.57473 .63504 m .57588 .63474 L .57702 .63505 L F
0 0 .158 r
.57547 .63834 m .57588 .63474 L .5745 .6362 L F
.57581 .63534 m .57588 .6354 L .57588 .63474 L F
.57547 .63834 m .57588 .6354 L .57581 .63534 L F
0 0 0 r
.57285 .63682 m .5745 .6362 L .57473 .63504 L F
.262 .422 .833 r
.57285 .63682 m .57547 .63834 L .5745 .6362 L F
0 0 0 r
.57473 .63504 m .5745 .6362 L .57588 .63474 L F
.797 .561 .581 r
.57588 .63474 m .57589 .63816 L .57249 .63701 L F
.288 0 0 r
.57616 .6381 m .57487 .63781 L .57589 .63816 L F
0 0 .158 r
.57547 .63834 m .57589 .63816 L .57549 .63824 L F
.461 .076 .222 r
.34327 .59257 m .34576 .59221 L .34715 .58991 L F
.097 0 .016 r
.34715 .58991 m .34755 .5914 L .34944 .59014 L F
.34715 .58991 m .34576 .59221 L .34755 .5914 L F
.576 .527 .763 r
.78601 .4994 m .78712 .50372 L .78993 .50286 L F
.331 .242 .602 r
.21649 .6274 m .21486 .62562 L .21675 .62502 L F
.21649 .6274 m .21514 .62822 L .21486 .62562 L F
.511 .366 .621 r
.54988 .65915 m .54758 .66157 L .54663 .6599 L F
.54988 .65915 m .5504 .66229 L .54758 .66157 L F
.583 .12 .119 r
.42848 .62361 m .43036 .62188 L .42645 .62213 L F
.332 0 0 r
.42848 .62361 m .43258 .62303 L .43036 .62188 L F
.056 0 0 r
.40034 .62587 m .39652 .62782 L .39876 .62728 L F
.372 0 0 r
.39876 .62728 m .40281 .62561 L .40034 .62587 L F
.67 .614 .784 r
.45729 .59396 m .46129 .59572 L .45966 .59319 L F
.639 .822 .403 r
.24092 .56694 m .23983 .56865 L .23909 .56999 L F
.242 .047 .404 r
.24058 .57134 m .23909 .56999 L .23983 .56865 L F
.24058 .57134 m .23853 .57271 L .23909 .56999 L F
0 0 .007 r
.21568 .57311 m .2145 .57509 L .21719 .5722 L F
0 0 .216 r
.53664 .7005 m .53572 .70394 L .53569 .70142 L F
.045 0 .194 r
.53072 .7242 m .53282 .72136 L .53142 .72216 L F
.773 .303 0 r
.66073 .4339 m .66071 .43292 L .65937 .43171 L F
.66073 .4339 m .66191 .43493 L .66071 .43292 L F
.495 .256 .482 r
.51449 .66326 m .51197 .66599 L .51197 .66348 L F
.51449 .66326 m .51197 .66599 L .51197 .66348 L F
.802 .641 .683 r
.59217 .63998 m .59176 .64246 L .59515 .6426 L F
.802 .624 .66 r
.59176 .64246 m .59352 .64583 L .59515 .6426 L F
.471 .47 .776 r
.21563 .56352 m .21701 .56711 L .21911 .56614 L F
.345 .213 .553 r
.21701 .56711 m .21906 .56872 L .21911 .56614 L F
.21701 .56711 m .21698 .56991 L .21906 .56872 L F
.765 .423 .405 r
.42398 .62215 m .42029 .62047 L .42078 .62298 L F
.743 .561 .647 r
.53453 .66632 m .53705 .66656 L .53613 .66329 L F
.525 .326 .553 r
.53613 .66329 m .53871 .66282 L .53873 .66057 L F
.733 .555 .651 r
.53613 .66329 m .53948 .66649 L .53871 .66282 L F
.556 .169 .263 r
.42042 .6242 m .42398 .62215 L .42078 .62298 L F
.42042 .6242 m .4227 .62438 L .42398 .62215 L F
.516 .13 .249 r
.4227 .62438 m .42645 .62213 L .42398 .62215 L F
.644 .828 .971 r
.47462 .68625 m .47776 .68627 L .47626 .6855 L F
.588 .132 0 r
.47776 .68627 m .47886 .68781 L .47626 .6855 L F
.47776 .68627 m .47991 .68915 L .47886 .68781 L F
.602 .405 .588 r
.48023 .68615 m .47991 .68915 L .47776 .68627 L F
.78 .559 .601 r
.53859 .62232 m .53899 .61955 L .53522 .61924 L F
.427 0 0 r
.20578 .58762 m .20778 .58843 L .20961 .58754 L F
.488 0 .023 r
.20778 .58843 m .21195 .58724 L .20961 .58754 L F
.54 .509 .771 r
.19806 .59226 m .19899 .59584 L .20092 .59407 L F
.64 .686 .877 r
.19899 .59584 m .2026 .59642 L .20092 .59407 L F
.713 .546 .661 r
.20017 .59911 m .2026 .59642 L .19899 .59584 L F
.727 .899 .957 r
.55271 .67675 m .55212 .67905 L .55055 .67795 L F
.55271 .67675 m .55397 .6776 L .55212 .67905 L F
.55271 .67675 m .55212 .67905 L .55055 .67795 L F
.55271 .67675 m .55397 .6776 L .55212 .67905 L F
.605 .586 .805 r
.55484 .68064 m .55397 .6776 L .55212 .67905 L F
.935 .874 .753 r
.46749 .70706 m .46953 .70681 L .46998 .70504 L F
.911 .606 .456 r
.46961 .7095 m .46953 .70681 L .46749 .70706 L F
.767 .69 .778 r
.46953 .70681 m .4729 .70358 L .46998 .70504 L F
.984 .848 .466 r
.47245 .70642 m .4729 .70358 L .46953 .70681 L F
.491 .815 1 r
.46961 .7095 m .47245 .70642 L .46953 .70681 L F
.654 .366 .471 r
.57075 .48854 m .57294 .49072 L .57035 .49058 L F
.57075 .48854 m .57417 .4882 L .57294 .49072 L F
.093 .345 .816 r
.37919 .62259 m .37848 .62344 L .37725 .62208 L F
.37919 .62259 m .38079 .62524 L .37848 .62344 L F
.724 .657 .782 r
.48494 .69516 m .48607 .69846 L .48285 .698 L F
0 0 .369 r
.48597 .69734 m .48607 .69846 L .48494 .69516 L F
.582 .42 .628 r
.48607 .69846 m .48912 .70092 L .48635 .70148 L F
.573 .016 0 r
.48707 .69973 m .48912 .70092 L .48607 .69846 L F
.48707 .69973 m .48607 .69846 L .48597 .69734 L F
.576 .936 .926 r
.50911 .65558 m .51294 .65455 L .51186 .65447 L F
0 0 0 r
.51488 .65209 m .51294 .65455 L .5152 .6513 L F
.641 .466 .631 r
.51178 .64889 m .51503 .6519 L .51407 .64823 L F
.38 .264 .594 r
.515 .65155 m .51675 .64817 L .51407 .64823 L F
.101 0 0 r
.5152 .6513 m .51545 .65146 L .51488 .65209 L F
.51545 .65146 m .51546 .65147 L .51509 .65187 L F
.51545 .65146 m .51509 .65187 L .51488 .65209 L F
.38 .264 .594 r
.51509 .65187 m .51534 .65148 L .515 .65155 L F
.51512 .65199 m .51525 .65168 L .51509 .65187 L F
.51525 .65168 m .51534 .65148 L .51509 .65187 L F
.101 0 0 r
.5152 .6513 m .51726 .65088 L .51688 .65115 L F
.38 .264 .594 r
.51534 .65148 m .51675 .64817 L .515 .65155 L F
.101 0 0 r
.51608 .65133 m .51688 .65115 L .51662 .65135 L F
.097 .025 .477 r
.51675 .64817 m .51646 .65136 L .51818 .64973 L F
.51646 .65136 m .51642 .65188 L .51682 .65139 L F
.51646 .65136 m .51682 .65139 L .51818 .64973 L F
.101 0 0 r
.51605 .65133 m .51606 .65133 L .51608 .65133 L F
.51606 .65133 m .51688 .65115 L .51608 .65133 L F
.5152 .6513 m .51688 .65115 L .51605 .65133 L F
.38 .264 .594 r
.51512 .65199 m .51642 .65188 L .51646 .65136 L F
.51512 .65199 m .51646 .65136 L .5156 .65146 L F
.101 0 0 r
.51547 .65147 m .51662 .65135 L .516 .6518 L F
.5152 .6513 m .51662 .65135 L .51547 .65147 L F
.38 .264 .594 r
.5156 .65146 m .51646 .65136 L .51655 .6504 L F
.101 0 0 r
.51546 .65147 m .51547 .65147 L .51536 .65158 L F
.38 .264 .594 r
.51525 .65168 m .51655 .6504 L .51675 .64817 L F
.51512 .65199 m .51655 .6504 L .51525 .65168 L F
.641 .466 .631 r
.51504 .65191 m .51512 .65199 L .51509 .65187 L F
.101 0 0 r
.51536 .65158 m .516 .6518 L .51488 .65209 L F
.51547 .65147 m .516 .6518 L .51536 .65158 L F
.115 .665 .8 r
.516 .6518 m .51642 .65188 L .51512 .65199 L F
.516 .6518 m .51512 .65199 L .51425 .65364 L F
.101 0 0 r
.51488 .65209 m .516 .6518 L .51425 .65364 L F
.641 .466 .631 r
.51503 .6519 m .51504 .65191 L .51508 .65183 L F
.51504 .65191 m .51509 .65187 L .51508 .65183 L F
.51503 .6519 m .51508 .65183 L .51407 .64823 L F
0 0 0 r
.51425 .65364 m .51304 .65448 L .51488 .65209 L F
.51304 .65448 m .51294 .65455 L .51488 .65209 L F
.437 .873 .896 r
.51186 .65447 m .51294 .65455 L .51425 .65364 L F
.566 .595 .841 r
.36699 .64011 m .36772 .63655 L .36561 .63668 L F
.36699 .64011 m .36944 .64032 L .36772 .63655 L F
.581 .187 .259 r
.57417 .4882 m .57694 .4896 L .57294 .49072 L F
.57417 .4882 m .57636 .48849 L .57694 .4896 L F
.236 0 0 r
.38137 .64011 m .37826 .64165 L .37941 .64081 L F
.688 .776 .918 r
.45343 .59338 m .45729 .59396 L .45609 .59293 L F
.609 .847 .989 r
.45609 .59293 m .45729 .59396 L .45966 .59319 L F
.44 0 0 r
.44544 .62236 m .44286 .62175 L .44409 .62252 L F
.596 .374 .549 r
.53282 .72136 m .5354 .71843 L .53344 .71933 L F
.708 .631 .769 r
.20503 .59456 m .2026 .59642 L .20583 .59635 L F
.622 .405 .566 r
.20258 .59914 m .20583 .59635 L .2026 .59642 L F
.20258 .59914 m .20555 .59919 L .20583 .59635 L F
.476 .51 .813 r
.20503 .59456 m .20583 .59635 L .20726 .59543 L F
.334 .161 .491 r
.20583 .59635 m .20711 .5982 L .20726 .59543 L F
.20583 .59635 m .20555 .59919 L .20711 .5982 L F
.721 .778 .898 r
.5437 .71285 m .54233 .71384 L .54013 .71256 L F
0 0 0 r
.20231 .65178 m .20245 .65159 L .20203 .65231 L F
.57 .468 .699 r
.78729 .48962 m .79007 .48845 L .78676 .48734 L F
.763 .765 .855 r
.66616 .42293 m .66649 .42459 L .66372 .4234 L F
.864 .925 .866 r
.66649 .42459 m .66365 .42578 L .66372 .4234 L F
.463 .556 .865 r
.66821 .42241 m .66649 .42459 L .66616 .42293 L F
.535 .662 .918 r
.66872 .42404 m .66649 .42459 L .66821 .42241 L F
.234 0 .319 r
.2237 .61084 m .22146 .61338 L .22261 .61158 L F
.022 .22 .726 r
.54917 .65845 m .54988 .65915 L .54931 .65706 L F
.331 0 0 r
.43736 .62849 m .4359 .62952 L .43421 .62934 L F
.235 0 0 r
.43983 .62866 m .4359 .62952 L .43736 .62849 L F
.654 .473 .627 r
.50737 .65214 m .51346 .65373 L .51178 .64889 L F
.641 .466 .631 r
.51178 .64889 m .51346 .65373 L .51512 .65199 L F
.713 .546 .661 r
.20017 .59911 m .20258 .59914 L .2026 .59642 L F
.75 .723 .827 r
.20092 .59407 m .2026 .59642 L .20503 .59456 L F
.147 0 .317 r
.194 .61383 m .19565 .61272 L .19592 .61094 L F
.434 .329 .636 r
.19398 .61639 m .19565 .61272 L .194 .61383 L F
.645 .367 .483 r
.60513 .47641 m .60579 .47888 L .60138 .47892 L F
.635 .361 .486 r
.60751 .47859 m .60579 .47888 L .60513 .47641 L F
.648 .358 .466 r
.60761 .47661 m .60751 .47859 L .60513 .47641 L F
.766 .935 .94 r
.58555 .47267 m .58301 .47322 L .58387 .47239 L F
.85 .897 .87 r
.58785 .47038 m .58555 .47267 L .58387 .47239 L F
.93 .689 .553 r
.38412 .59842 m .38556 .60185 L .38597 .59917 L F
.99 .806 .565 r
.5576 .69192 m .55647 .69172 L .55687 .68874 L F
.55687 .68874 m .55647 .69172 L .5576 .69192 L F
.716 .987 .868 r
.63781 .42063 m .6343 .42244 L .63561 .42179 L F
.577 .867 .995 r
.4454 .58279 m .44541 .5823 L .44489 .58153 L F
.4454 .58279 m .44304 .5826 L .44541 .5823 L F
.646 .774 .941 r
.44844 .58217 m .44489 .58153 L .44727 .5811 L F
.468 .598 .899 r
.44965 .58029 m .44844 .58217 L .44727 .5811 L F
.44965 .58029 m .45042 .58178 L .44844 .58217 L F
.501 .219 .418 r
.4337 .61097 m .43553 .61235 L .43613 .61023 L F
.422 .242 .53 r
.4337 .61097 m .43358 .61362 L .43553 .61235 L F
.501 .219 .418 r
.4337 .61097 m .43553 .61235 L .43613 .61023 L F
.897 .949 .597 r
.52489 .70622 m .5247 .70778 L .52696 .70701 L F
.842 .904 .88 r
.67722 .41856 m .67486 .4212 L .67367 .42024 L F
.615 .495 .693 r
.67722 .41856 m .67743 .42098 L .67486 .4212 L F
.575 .314 .483 r
.67486 .4212 m .67743 .42098 L .67794 .42324 L F
0 .274 .755 r
.67486 .4212 m .67692 .42198 L .67367 .42024 L F
.67486 .4212 m .67794 .42324 L .67692 .42198 L F
.982 .691 .352 r
.5545 .67543 m .55328 .67463 L .55308 .6716 L F
.991 .845 .6 r
.55271 .67675 m .5545 .67543 L .55397 .6776 L F
.55271 .67675 m .55328 .67463 L .5545 .67543 L F
.381 .321 .664 r
.49444 .70761 m .49469 .70834 L .49702 .70701 L F
.49444 .70761 m .49465 .71008 L .49469 .70834 L F
.683 .574 .727 r
.49465 .71008 m .49598 .71323 L .49828 .71296 L F
.523 .293 .507 r
.49582 .71567 m .49828 .71296 L .49598 .71323 L F
.82 .693 .724 r
.58056 .60671 m .57711 .60635 L .57839 .60576 L F
.907 .643 .527 r
.801 .49641 m .8007 .49904 L .80312 .49902 L F
.896 .865 .8 r
.8007 .49904 m .80121 .50181 L .80312 .49902 L F
.406 0 .129 r
.68097 .45019 m .68057 .4524 L .67758 .45263 L F
.017 0 0 r
.68376 .4479 m .68326 .44882 L .68097 .45019 L F
.161 0 .078 r
.68268 .45107 m .68097 .45019 L .68326 .44882 L F
.68268 .45107 m .68057 .4524 L .68097 .45019 L F
.883 .88 .826 r
.47199 .71923 m .46994 .7202 L .47081 .71773 L F
.46994 .7202 m .47026 .71841 L .47081 .71773 L F
.718 .863 .95 r
.46978 .71827 m .47081 .71773 L .47017 .71771 L F
.758 .858 .924 r
.46964 .71552 m .46978 .71827 L .46759 .71763 L F
.775 .87 .918 r
.47134 .71486 m .4701 .71757 L .46964 .71552 L F
.4701 .71757 m .46978 .71827 L .46974 .7176 L F
.4701 .71757 m .46974 .7176 L .46964 .71552 L F
.718 .863 .95 r
.46978 .71827 m .47017 .71771 L .46759 .71763 L F
.503 .276 .503 r
.47027 .71833 m .46978 .71827 L .4701 .71757 L F
.885 .91 .839 r
.47017 .71771 m .46756 .71777 L .46884 .71767 L F
.47081 .71773 m .47019 .71774 L .47017 .71771 L F
.47019 .71774 m .46756 .71777 L .47017 .71771 L F
.503 .276 .503 r
.47036 .71806 m .47061 .71645 L .47134 .71486 L F
0 .197 .677 r
.47222 .7189 m .47199 .71923 L .47081 .71773 L F
.4735 .71995 m .47324 .71983 L .47222 .7189 L F
.47324 .71983 m .47199 .71923 L .47222 .7189 L F
.503 .276 .503 r
.47206 .71854 m .4718 .71851 L .47068 .71699 L F
.47128 .71803 m .47081 .71773 L .47039 .71795 L F
.885 .91 .839 r
.47081 .71773 m .46809 .72108 L .46793 .72095 L F
.503 .276 .503 r
.47042 .71817 m .47039 .71795 L .46978 .71827 L F
.4706 .71797 m .47039 .71795 L .47042 .71817 L F
.196 .335 .779 r
.47206 .71854 m .4735 .71995 L .47081 .71773 L F
.503 .276 .503 r
.47206 .71854 m .47128 .71803 L .46978 .71827 L F
.47027 .71833 m .47033 .71801 L .47034 .71802 L F
.885 .91 .839 r
.47081 .71773 m .47027 .71833 L .47034 .71802 L F
.503 .276 .503 r
.47028 .71831 m .47034 .71802 L .47036 .71806 L F
.47027 .71833 m .47034 .71802 L .47028 .71831 L F
.885 .91 .839 r
.47019 .71774 m .46693 .72013 L .46756 .71777 L F
.46884 .71767 m .46756 .71777 L .46759 .71763 L F
.486 .306 .561 r
.46759 .71763 m .46813 .71852 L .46964 .71552 L F
.885 .91 .839 r
.47034 .71802 m .46793 .72095 L .46712 .72028 L F
.47034 .71802 m .46712 .72028 L .46736 .71987 L F
.47027 .71833 m .46793 .72095 L .47034 .71802 L F
.503 .276 .503 r
.47027 .71833 m .4701 .71757 L .47033 .71801 L F
.885 .91 .839 r
.47034 .71802 m .46693 .72013 L .47019 .71774 L F
.883 .88 .826 r
.46994 .7202 m .46809 .72108 L .47026 .71841 L F
.486 .306 .561 r
.46813 .71852 m .46919 .72026 L .4696 .71596 L F
.46813 .71852 m .4696 .71596 L .46964 .71552 L F
.885 .91 .839 r
.46736 .71987 m .46712 .72028 L .46693 .72013 L F
.503 .276 .503 r
.47128 .71803 m .4706 .71797 L .47042 .71817 L F
.885 .91 .839 r
.47081 .71773 m .47034 .71802 L .47019 .71774 L F
.503 .276 .503 r
.4718 .71851 m .47027 .71833 L .47056 .71738 L F
.4718 .71851 m .47056 .71738 L .47068 .71699 L F
.47033 .71801 m .47061 .71645 L .47036 .71806 L F
.47033 .71801 m .4701 .71757 L .47061 .71645 L F
.47152 .7158 m .47068 .71699 L .47134 .71486 L F
.47206 .71854 m .47068 .71699 L .47152 .7158 L F
.883 .88 .826 r
.47199 .71923 m .46978 .72189 L .46809 .72108 L F
0 0 .092 r
.47382 .71993 m .4735 .71995 L .47405 .71892 L F
0 .197 .677 r
.4735 .71995 m .47429 .72081 L .47308 .71998 L F
0 0 0 r
.47082 .72339 m .47238 .72187 L .47429 .72081 L F
.47082 .72339 m .47429 .72081 L .47321 .72266 L F
.998 .797 .449 r
.47321 .72266 m .47429 .72081 L .4735 .71995 L F
0 0 .092 r
.47321 .72266 m .4735 .71995 L .47382 .71993 L F
0 .197 .677 r
.4735 .71995 m .47308 .71998 L .47199 .71923 L F
.61 .313 .441 r
.48192 .72296 m .48389 .72208 L .48069 .72081 L F
.677 .851 .966 r
.63781 .42063 m .64177 .42046 L .64033 .4202 L F
.97 .671 .395 r
.64033 .4202 m .64177 .42046 L .64025 .41746 L F
.803 .883 .904 r
.57959 .47813 m .57886 .48022 L .57792 .47959 L F
.26 .177 .569 r
.36797 .60747 m .36794 .61065 L .36689 .6107 L F
.262 .192 .587 r
.36794 .61065 m .36857 .61338 L .36689 .6107 L F
.488 .188 .383 r
.68609 .44665 m .68326 .44882 L .68376 .4479 L F
.98 .705 .428 r
.66935 .43822 m .67069 .44158 L .66952 .44052 L F
.953 .631 .216 r
.67069 .44158 m .67008 .44263 L .66952 .44052 L F
.67069 .44158 m .67109 .44383 L .67008 .44263 L F
0 .272 .706 r
.53814 .64427 m .5391 .64174 L .53729 .64331 L F
.53814 .64427 m .53883 .64445 L .5391 .64174 L F
.53814 .64427 m .54064 .64567 L .53883 .64445 L F
.594 .035 0 r
.26003 .77723 m .2622 .77912 L .2638 .77997 L F
.693 .885 .969 r
.2638 .77997 m .2622 .77912 L .26 .7804 L F
.265 .579 .943 r
.57997 .61818 m .58177 .61812 L .58109 .61733 L F
.57997 .61818 m .58109 .61733 L .58062 .6168 L F
0 0 0 r
.579 .61891 m .57997 .61818 L .58093 .61686 L F
.57832 .61964 m .57997 .61818 L .579 .61891 L F
.299 .334 .731 r
.58072 .6216 m .57832 .61964 L .57843 .62342 L F
.58072 .6216 m .57997 .61818 L .57832 .61964 L F
.658 .603 .782 r
.78236 .49679 m .78601 .4994 L .78469 .4954 L F
.625 .507 .699 r
.78469 .4954 m .78601 .4994 L .78844 .49631 L F
0 0 0 r
.57615 .59928 m .5781 .59753 L .57921 .59608 L F
.407 .252 .557 r
.48027 .70383 m .47847 .70429 L .48 .70121 L F
.355 .155 .464 r
.48006 .70609 m .47847 .70429 L .48027 .70383 L F
.48006 .70609 m .47827 .70707 L .47847 .70429 L F
.903 .867 .794 r
.48 .70121 m .47847 .70429 L .47643 .7032 L F
.317 .633 .963 r
.37602 .62073 m .37526 .62191 L .37401 .61879 L F
.37602 .62073 m .37725 .62208 L .37526 .62191 L F
0 0 0 r
.26003 .77723 m .259 .78006 L .25931 .77936 L F
.341 .768 .973 r
.25931 .77936 m .259 .78006 L .25606 .77938 L F
.044 .43 .87 r
.25931 .77936 m .26 .7804 L .259 .78006 L F
.341 .768 .973 r
.25931 .77936 m .259 .78006 L .25606 .77938 L F
.103 .328 .801 r
.58561 .64559 m .58247 .64191 L .58286 .64351 L F
.765 .574 .64 r
.53936 .70109 m .54189 .70301 L .54124 .69904 L F
.524 .408 .663 r
.54124 .69904 m .54384 .70145 L .54419 .69826 L F
.54124 .69904 m .54189 .70301 L .54384 .70145 L F
.051 .369 .838 r
.18597 .57434 m .18554 .57543 L .18385 .57415 L F
.18597 .57434 m .18597 .57566 L .18554 .57543 L F
.863 .587 .52 r
.56927 .48657 m .56704 .48983 L .56927 .48681 L F
.617 .057 0 r
.26046 .77831 m .26003 .77723 L .25931 .77936 L F
.26046 .77831 m .2622 .77912 L .26003 .77723 L F
.824 .661 .68 r
.77132 .49041 m .77278 .49407 L .77339 .49185 L F
.545 .298 .491 r
.34435 .63432 m .34637 .63619 L .34669 .63363 L F
.34435 .63432 m .344 .63657 L .34637 .63619 L F
0 0 0 r
.34448 .63497 m .34435 .63432 L .34669 .63363 L F
.34448 .63497 m .344 .63657 L .34435 .63432 L F
.664 .341 .417 r
.51186 .65447 m .50737 .65214 L .50852 .6546 L F
.51186 .65447 m .51346 .65373 L .50737 .65214 L F
.361 .782 .976 r
.20521 .54353 m .20732 .54327 L .20902 .5439 L F
.263 .703 .962 r
.2093 .54308 m .20902 .5439 L .20732 .54327 L F
.2093 .54308 m .21111 .54391 L .20902 .5439 L F
.365 .098 .371 r
.51921 .69105 m .51752 .68989 L .52048 .68939 L F
0 0 0 r
.52228 .68885 m .51921 .69105 L .52048 .68939 L F
.641 .406 .548 r
.51969 .72182 m .51874 .72452 L .52114 .72407 L F
.51969 .72182 m .51874 .72452 L .52114 .72407 L F
.792 .309 0 r
.67531 .45026 m .67408 .44937 L .6726 .44709 L F
.726 .291 .216 r
.67531 .45026 m .67422 .45171 L .67408 .44937 L F
.67531 .45026 m .67758 .45263 L .67422 .45171 L F
.468 .273 .532 r
.22933 .5962 m .22913 .59874 L .22702 .59924 L F
.439 .31 .607 r
.22889 .60091 m .22702 .59924 L .22913 .59874 L F
.22889 .60091 m .22722 .60173 L .22702 .59924 L F
.929 .714 .591 r
.5203 .72691 m .51872 .72697 L .51874 .72452 L F
.558 .536 .787 r
.5203 .72691 m .52114 .72407 L .51872 .72697 L F
.5203 .72691 m .52232 .72748 L .52114 .72407 L F
.947 .676 .49 r
.53705 .66656 m .53829 .66937 L .53584 .66769 L F
.8 .739 .796 r
.53829 .66937 m .53367 .66915 L .53584 .66769 L F
.53829 .66937 m .53492 .67205 L .53367 .66915 L F
.831 .369 .112 r
.6726 .44709 m .6725 .44853 L .67167 .446 L F
.6726 .44709 m .67408 .44937 L .6725 .44853 L F
.793 .994 .874 r
.65264 .46428 m .65636 .46225 L .65553 .46185 L F
.409 .788 .992 r
.65636 .46225 m .6579 .46107 L .65658 .4615 L F
.65636 .46225 m .65882 .46201 L .6579 .46107 L F
.074 0 0 r
.65882 .46201 m .66154 .46114 L .65986 .46248 L F
.65882 .46201 m .65986 .46248 L .6579 .46107 L F
.559 .815 .993 r
.65448 .46048 m .65553 .46185 L .65658 .4615 L F
.65644 .46116 m .65658 .4615 L .6579 .46107 L F
.641 .358 .475 r
.6579 .46107 m .65986 .46248 L .65644 .46116 L F
.6579 .46107 m .65644 .46116 L .6562 .46106 L F
.6579 .46107 m .6562 .46106 L .65633 .45911 L F
.559 .815 .993 r
.6563 .46079 m .65641 .46107 L .6579 .46107 L F
0 .01 .552 r
.65633 .45911 m .6562 .46106 L .65642 .46096 L F
.559 .815 .993 r
.6564 .46062 m .6579 .46107 L .65633 .45911 L F
.656 .46074 m .6579 .46107 L .65489 .46017 L F
0 .01 .552 r
.65633 .45911 m .65642 .46096 L .65818 .46008 L F
.559 .815 .993 r
.65489 .46017 m .6564 .46062 L .65633 .45911 L F
.65448 .46048 m .656 .46074 L .65489 .46017 L F
.158 .589 .934 r
.65642 .46096 m .65952 .46113 L .65818 .46008 L F
.65632 .461 m .65652 .46101 L .65642 .46096 L F
.65652 .46101 m .65952 .46113 L .65642 .46096 L F
.6562 .46106 m .65641 .46107 L .65632 .461 L F
.65641 .46107 m .65952 .46113 L .65632 .461 L F
.559 .815 .993 r
.65641 .46107 m .65644 .46116 L .65651 .46115 L F
.65641 .46107 m .65651 .46115 L .6579 .46107 L F
.201 .548 .93 r
.6562 .46106 m .65644 .46116 L .65641 .46107 L F
.559 .815 .993 r
.65448 .46048 m .65658 .4615 L .6563 .46079 L F
.201 .548 .93 r
.65641 .46107 m .65677 .46128 L .65694 .46108 L F
.65644 .46116 m .65677 .46128 L .65641 .46107 L F
.65694 .46108 m .65986 .46248 L .65952 .46113 L F
.65677 .46128 m .65986 .46248 L .65694 .46108 L F
.409 .788 .992 r
.65606 .46211 m .65658 .4615 L .65553 .46185 L F
.65636 .46225 m .65658 .4615 L .65606 .46211 L F
.554 .524 .776 r
.52017 .65933 m .52315 .65802 L .52164 .65655 L F
.267 0 0 r
.54385 .62767 m .54271 .62844 L .54031 .62863 L F
0 0 .12 r
.54406 .62481 m .54409 .62782 L .54385 .62767 L F
0 0 0 r
.54385 .62767 m .54409 .62782 L .54271 .62844 L F
.293 0 0 r
.36002 .58676 m .36237 .5864 L .36384 .58477 L F
.126 0 0 r
.36237 .5864 m .36634 .58475 L .36384 .58477 L F
.4 .047 .245 r
.37609 .60183 m .37337 .60354 L .37387 .60239 L F
0 0 .191 r
.55335 .68402 m .55476 .68269 L .55484 .68064 L F
.731 .445 0 r
.55484 .68064 m .55461 .67999 L .55397 .6776 L F
.201 .124 .539 r
.55476 .68269 m .55461 .67999 L .55484 .68064 L F
.612 .053 0 r
.54942 .67722 m .55055 .67795 L .55015 .67761 L F
.54942 .67722 m .55015 .67761 L .54759 .67545 L F
.54942 .67722 m .54759 .67545 L .54825 .67391 L F
.938 .694 .543 r
.54825 .67391 m .54819 .67656 L .54942 .67722 L F
.54819 .67656 m .54818 .67675 L .54942 .67722 L F
0 0 0 r
.58093 .61686 m .58182 .61525 L .58276 .61342 L F
.653 .845 .442 r
.57997 .61818 m .58182 .61525 L .58093 .61686 L F
.239 .189 .597 r
.54586 .70029 m .54402 .70163 L .54419 .69826 L F
.536 .924 .838 r
.54586 .70029 m .54384 .70145 L .54402 .70163 L F
.469 .372 .662 r
.33665 .59907 m .33906 .60114 L .33871 .59856 L F
.33665 .59907 m .33714 .60188 L .33906 .60114 L F
0 0 0 r
.56939 .63254 m .56773 .63366 L .56922 .6321 L F
.587 .493 .714 r
.49465 .71008 m .4974 .71159 L .49469 .70834 L F
.683 .574 .727 r
.49465 .71008 m .49828 .71296 L .4974 .71159 L F
.439 .382 .697 r
.33683 .61371 m .33838 .60989 L .33607 .61071 L F
.33683 .61371 m .33869 .61324 L .33838 .60989 L F
.596 .536 .758 r
.33683 .61371 m .34006 .61664 L .33869 .61324 L F
.845 .821 .825 r
.59691 .45569 m .59723 .45877 L .59452 .45857 L F
.87 .759 .738 r
.59723 .45877 m .59549 .46191 L .59452 .45857 L F
.842 .819 .826 r
.59967 .45571 m .59723 .45877 L .59691 .45569 L F
.983 .703 .4 r
.557 .66596 m .5571 .66852 L .55825 .66928 L F
.968 .646 .315 r
.5571 .66852 m .55868 .67168 L .55825 .66928 L F
.733 .492 0 r
.55825 .66928 m .55868 .67168 L .55849 .67055 L F
0 0 0 r
.37082 .60436 m .36797 .60747 L .36871 .60492 L F
.38 0 .124 r
.42264 .63092 m .4215 .63277 L .41919 .63309 L F
.353 0 0 r
.42536 .63115 m .4215 .63277 L .42264 .63092 L F
0 0 0 r
.38412 .59842 m .37985 .59985 L .38218 .59825 L F
.633 .62 .819 r
.46321 .69749 m .46157 .70189 L .46143 .70002 L F
.46321 .69749 m .46488 .70066 L .46157 .70189 L F
.085 .277 .761 r
.46157 .70189 m .46303 .70363 L .46143 .70002 L F
.992 .818 .443 r
.59171 .62779 m .59138 .63021 L .59208 .63108 L F
.999 .804 .505 r
.59074 .63296 m .59208 .63108 L .59138 .63021 L F
.59074 .63296 m .5918 .63429 L .59208 .63108 L F
.85 .897 .87 r
.58785 .47038 m .58387 .47239 L .58692 .46955 L F
.434 0 .023 r
.40259 .63652 m .40112 .63801 L .39924 .63731 L F
.27 0 0 r
.40489 .63618 m .40112 .63801 L .40259 .63652 L F
.379 0 .007 r
.46978 .72189 m .47082 .72339 L .46809 .72108 L F
.46978 .72189 m .47238 .72187 L .47082 .72339 L F
.513 .326 .565 r
.35275 .62965 m .3501 .63023 L .35252 .6305 L F
.181 .679 .915 r
.35298 .63117 m .35252 .6305 L .35037 .63048 L F
.899 .88 .449 r
.35275 .62965 m .35252 .6305 L .35298 .63117 L F
.405 .638 .951 r
.34859 .63046 m .35252 .6305 L .3501 .63023 L F
.899 .88 .449 r
.35275 .62965 m .35298 .63117 L .35459 .63064 L F
.947 .659 .459 r
.35459 .63064 m .35359 .63177 L .35275 .62965 L F
.35359 .63177 m .35313 .63229 L .35297 .63117 L F
.35359 .63177 m .35297 .63117 L .35275 .62965 L F
.513 .326 .565 r
.35275 .62965 m .35288 .63108 L .3501 .63023 L F
.964 .671 .425 r
.35275 .62965 m .35297 .63117 L .35288 .63108 L F
.186 .527 .921 r
.35287 .63107 m .35288 .63108 L .35211 .63035 L F
.35287 .63107 m .35211 .63035 L .35211 .63035 L F
.35288 .63108 m .35214 .63031 L .35193 .63017 L F
.181 .679 .915 r
.35298 .63117 m .35037 .63048 L .34961 .63062 L F
.964 .671 .425 r
.35219 .63036 m .35298 .63219 L .35149 .63124 L F
.35275 .62965 m .35288 .63108 L .35219 .63036 L F
.35288 .63108 m .35298 .63219 L .35219 .63036 L F
.513 .326 .565 r
.35275 .62965 m .35369 .63122 L .35288 .63108 L F
.876 .86 .821 r
.35298 .63219 m .35313 .63229 L .35371 .63141 L F
.35219 .63036 m .35363 .62982 L .35275 .62965 L F
.35363 .62982 m .35535 .62917 L .35275 .62965 L F
.246 .222 .634 r
.35382 .62985 m .35378 .63084 L .35275 .62965 L F
.35378 .63084 m .35369 .63122 L .35275 .62965 L F
.876 .86 .821 r
.35298 .63044 m .35535 .62917 L .35438 .62954 L F
.35279 .63042 m .35438 .62954 L .35219 .63036 L F
.87 .751 .729 r
.35279 .63042 m .35339 .63099 L .35382 .62985 L F
.513 .326 .565 r
.35369 .63122 m .35363 .6313 L .35288 .63108 L F
.186 .527 .921 r
.35288 .63108 m .35363 .6313 L .35214 .63031 L F
.35363 .6313 m .35356 .63122 L .35214 .63031 L F
.964 .671 .425 r
.35288 .63108 m .35313 .63229 L .35298 .63219 L F
.35297 .63117 m .35313 .63229 L .35288 .63108 L F
.876 .86 .821 r
.35197 .63154 m .35298 .63219 L .35363 .6313 L F
.35339 .63099 m .35363 .6313 L .35405 .63073 L F
.35197 .63154 m .35363 .6313 L .35339 .63099 L F
.186 .527 .921 r
.352 .63016 m .35355 .6312 L .35243 .63008 L F
.876 .86 .821 r
.35363 .6313 m .35366 .63135 L .35369 .63122 L F
.35366 .63135 m .35371 .63141 L .35369 .63122 L F
.513 .326 .565 r
.35369 .63122 m .35377 .63135 L .35363 .6313 L F
.186 .527 .921 r
.35355 .6312 m .35377 .63135 L .35339 .63099 L F
.35355 .6312 m .35339 .63099 L .35243 .63008 L F
.246 .222 .634 r
.35378 .63084 m .35377 .63135 L .35369 .63122 L F
.87 .751 .729 r
.35339 .63099 m .35377 .63135 L .35378 .63084 L F
.35339 .63099 m .35378 .63084 L .35382 .62985 L F
.186 .527 .921 r
.35214 .63031 m .35356 .63122 L .352 .63016 L F
.35356 .63122 m .35377 .63135 L .35355 .6312 L F
.35356 .63122 m .35355 .6312 L .352 .63016 L F
.876 .86 .821 r
.35149 .63124 m .35197 .63154 L .35316 .63069 L F
.35298 .63044 m .35316 .63069 L .35509 .62932 L F
.186 .527 .921 r
.35069 .63041 m .35287 .63107 L .35193 .63017 L F
.876 .86 .821 r
.35149 .63124 m .35316 .63069 L .35298 .63044 L F
.35197 .63154 m .35405 .63073 L .35509 .62932 L F
.35298 .63044 m .35438 .62954 L .35279 .63042 L F
.246 .222 .634 r
.35396 .62579 m .35275 .62965 L .35535 .62917 L F
.35396 .62579 m .35382 .62985 L .35275 .62965 L F
.87 .751 .729 r
.35046 .6282 m .35279 .63042 L .35396 .62579 L F
.35279 .63042 m .35382 .62985 L .35396 .62579 L F
.876 .86 .821 r
.35369 .63122 m .35371 .63141 L .35509 .62932 L F
.35298 .63219 m .35371 .63141 L .35363 .6313 L F
.186 .527 .921 r
.35363 .6313 m .35377 .63135 L .35356 .63122 L F
.876 .86 .821 r
.35509 .62932 m .35313 .63229 L .35535 .62917 L F
.186 .527 .921 r
.35193 .63017 m .35214 .63031 L .352 .63016 L F
.876 .86 .821 r
.35149 .63124 m .35298 .63044 L .35219 .63036 L F
.186 .527 .921 r
.35211 .63035 m .35211 .63035 L .35193 .63017 L F
.3501 .63023 m .35069 .63041 L .35046 .6282 L F
.35069 .63041 m .35243 .63008 L .35046 .6282 L F
.181 .679 .915 r
.34961 .63062 m .35037 .63048 L .34859 .63046 L F
.673 .329 .384 r
.53948 .66649 m .53915 .6683 L .53705 .66656 L F
.53948 .66649 m .53915 .6683 L .53705 .66656 L F
.101 .203 .685 r
.53871 .66282 m .53948 .66649 L .54065 .66498 L F
.502 .446 .727 r
.53915 .6683 m .54065 .66498 L .53948 .66649 L F
.091 0 0 r
.63749 .47388 m .64058 .47319 L .63917 .47389 L F
.329 0 .17 r
.64058 .47319 m .64268 .47245 L .64221 .47233 L F
.335 .787 .641 r
.63917 .47389 m .64058 .47319 L .64221 .47233 L F
.813 .985 .712 r
.55435 .69 m .5522 .69251 L .55172 .69249 L F
.55435 .69 m .55172 .69249 L .55312 .6921 L F
.55435 .69 m .55312 .6921 L .55358 .6918 L F
.634 .071 0 r
.55468 .69097 m .55435 .69 L .55358 .6918 L F
.174 0 0 r
.55468 .69097 m .55358 .6918 L .55452 .69118 L F
.55452 .69118 m .55252 .6925 L .55291 .6932 L F
.634 .071 0 r
.55468 .69097 m .55358 .6918 L .5535 .692 L F
.897 .614 .5 r
.55381 .68957 m .55355 .69159 L .55156 .69076 L F
.493 .713 .969 r
.55156 .69076 m .55312 .6921 L .55172 .69249 L F
.174 0 0 r
.5531 .69209 m .55156 .69076 L .55252 .6925 L F
.55468 .69097 m .55156 .69076 L .5531 .69209 L F
.55375 .69167 m .55252 .6925 L .55358 .6918 L F
.55371 .69166 m .55252 .6925 L .55375 .69167 L F
.813 .985 .712 r
.55358 .6918 m .55312 .6921 L .5535 .692 L F
.493 .713 .969 r
.55156 .69076 m .5535 .692 L .55312 .6921 L F
.897 .614 .5 r
.55355 .69159 m .5535 .692 L .55156 .69076 L F
.174 0 0 r
.55468 .69097 m .55371 .69166 L .55375 .69167 L F
.634 .071 0 r
.55468 .69097 m .55435 .69 L .55381 .68957 L F
.55468 .69097 m .55647 .69172 L .55435 .69 L F
.55468 .69097 m .55647 .69172 L .55435 .69 L F
.558 .254 .408 r
.55908 .63081 m .56172 .63063 L .56069 .62889 L F
.757 .74 .837 r
.53072 .7242 m .53435 .72469 L .53203 .7237 L F
.853 .885 .861 r
.53435 .72469 m .53546 .721 L .53203 .7237 L F
.53435 .72469 m .53693 .72202 L .53546 .721 L F
.697 .727 .873 r
.79816 .50017 m .80121 .50181 L .8007 .49904 L F
.587 .388 .579 r
.52533 .67195 m .52824 .67402 L .53017 .67105 L F
.377 .013 .214 r
.52824 .67402 m .53125 .67111 L .53017 .67105 L F
.747 .335 .269 r
.43506 .6232 m .43846 .62248 L .43605 .62219 L F
.636 .386 .523 r
.50615 .68282 m .50902 .6806 L .50646 .68123 L F
0 0 0 r
.47517 .62713 m .47852 .62488 L .47715 .62659 L F
.4811 .6222 m .48025 .62412 L .47852 .62488 L F
.47852 .62488 m .48025 .62412 L .47715 .62659 L F
.557 .339 .539 r
.52043 .67503 m .52043 .6775 L .52287 .67465 L F
0 0 .446 r
.56879 .64247 m .56988 .64473 L .56998 .64625 L F
.959 .846 .688 r
.56789 .6476 m .56998 .64625 L .56988 .64473 L F
.56789 .6476 m .56914 .64857 L .56998 .64625 L F
0 0 .307 r
.34597 .62135 m .34512 .62242 L .34756 .62236 L F
.34597 .62135 m .34507 .62303 L .34512 .62242 L F
.234 0 .319 r
.2237 .61084 m .22297 .61284 L .22146 .61338 L F
.416 .289 .598 r
.22297 .61284 m .22072 .61622 L .22146 .61338 L F
.524 .375 .621 r
.54464 .60498 m .54476 .60752 L .54735 .60664 L F
.54464 .60498 m .54476 .60752 L .54735 .60664 L F
.54735 .60664 m .54476 .60752 L .54464 .60498 L F
.54 .297 .496 r
.58182 .61525 m .58344 .61502 L .58275 .6131 L F
.58344 .61502 m .58445 .61487 L .58275 .6131 L F
.841 .73 .741 r
.58079 .60707 m .5821 .61128 L .58275 .6131 L F
.5821 .61128 m .58276 .61342 L .58275 .6131 L F
.99 .728 .385 r
.45976 .62721 m .46116 .63057 L .46139 .6286 L F
.565 .443 .673 r
.46139 .6286 m .46327 .62853 L .46352 .62621 L F
.224 0 .344 r
.46139 .6286 m .46257 .62975 L .46327 .62853 L F
.46139 .6286 m .46116 .63057 L .46257 .62975 L F
.792 .475 .452 r
.54426 .67776 m .54619 .67755 L .54458 .67958 L F
.609 .486 .686 r
.19556 .60795 m .1985 .60966 L .19781 .6073 L F
.19556 .60795 m .19592 .61094 L .1985 .60966 L F
.611 .113 .046 r
.62546 .44838 m .62868 .44779 L .62505 .44661 L F
.62546 .44838 m .62902 .44901 L .62868 .44779 L F
.546 .068 .07 r
.62868 .44779 m .62902 .44901 L .631 .449 L F
.537 .124 .205 r
.62868 .44779 m .631 .449 L .63184 .44735 L F
.373 0 0 r
.22076 .54392 m .22293 .54495 L .22482 .5456 L F
.016 .508 .872 r
.22494 .545 m .22482 .5456 L .22293 .54495 L F
.22494 .545 m .22658 .54605 L .22482 .5456 L F
.717 .32 .294 r
.63184 .44735 m .63464 .44942 L .63409 .44694 L F
.63184 .44735 m .631 .449 L .63464 .44942 L F
.259 .084 .444 r
.21423 .63291 m .21303 .63127 L .21469 .63058 L F
.21423 .63291 m .21275 .63371 L .21303 .63127 L F
0 .501 .862 r
.45914 .63 m .45978 .62966 L .45744 .62883 L F
.45914 .63 m .46116 .63057 L .45978 .62966 L F
.818 .708 .744 r
.59081 .65142 m .59418 .65161 L .59302 .64828 L F
.812 .736 .781 r
.59195 .65458 m .59418 .65161 L .59081 .65142 L F
.464 .326 .608 r
.51607 .65807 m .51665 .66005 L .51846 .6575 L F
.657 .315 .382 r
.61699 .47634 m .61346 .47829 L .61325 .4766 L F
.61699 .47634 m .61589 .47871 L .61346 .47829 L F
.561 .257 .41 r
.61699 .47634 m .61946 .47801 L .61589 .47871 L F
.61699 .47634 m .61946 .47623 L .61946 .47801 L F
.523 .293 .507 r
.49582 .71567 m .4975 .71737 L .49828 .71296 L F
.771 .737 .821 r
.4974 .71159 m .49828 .71296 L .50133 .71051 L F
.315 .14 .478 r
.21283 .57577 m .21425 .5774 L .2145 .57509 L F
.21283 .57577 m .21257 .57826 L .21425 .5774 L F
.613 .069 0 r
.54053 .62445 m .54406 .62481 L .5423 .62366 L F
.361 0 .142 r
.54931 .65706 m .55079 .65685 L .55264 .65452 L F
.819 .515 .475 r
.55264 .65452 m .55079 .65685 L .55334 .65651 L F
.623 .635 .842 r
.59195 .65458 m .59081 .65142 L .58814 .652 L F
.002 .2 .714 r
.21289 .58071 m .21426 .58417 L .21478 .58262 L F
.198 .25 .691 r
.21289 .58071 m .21373 .58236 L .21349 .58215 L F
.38 .282 .617 r
.21114 .58112 m .21289 .58071 L .21219 .57903 L F
.198 .25 .691 r
.21289 .58071 m .21349 .58215 L .21118 .58014 L F
.38 .282 .617 r
.21219 .57903 m .21289 .58071 L .21257 .57826 L F
.651 .783 .944 r
.47581 .73037 m .47836 .73272 L .47475 .73253 L F
.597 .243 .34 r
.47347 .72954 m .47595 .73009 L .47475 .73253 L F
.654 .217 .199 r
.47424 .73025 m .47183 .7313 L .47547 .73139 L F
.47347 .72954 m .47291 .73014 L .47424 .73025 L F
.47291 .73014 m .47183 .7313 L .47424 .73025 L F
.651 .783 .944 r
.47595 .73009 m .47625 .73041 L .47581 .73037 L F
.47625 .73041 m .47836 .73272 L .47581 .73037 L F
.746 .485 .536 r
.47836 .73272 m .47464 .73568 L .47475 .73253 L F
.47836 .73272 m .47767 .73612 L .47464 .73568 L F
.712 .177 0 r
.47595 .73009 m .48057 .73256 L .47836 .73272 L F
.876 .74 .708 r
.58965 .46428 m .591 .46778 L .5888 .46668 L F
.834 .939 .895 r
.591 .46778 m .58692 .46955 L .5888 .46668 L F
.536 .349 .575 r
.65482 .44145 m .65491 .44382 L .65246 .44442 L F
.65482 .44145 m .65491 .44382 L .65246 .44442 L F
.638 .444 .605 r
.49469 .70834 m .49905 .7095 L .49702 .70701 L F
.618 .499 .695 r
.49469 .70834 m .4974 .71159 L .49905 .7095 L F
.347 0 0 r
.41111 .63412 m .41185 .63523 L .4095 .63545 L F
.41111 .63412 m .41347 .63424 L .41185 .63523 L F
.152 .676 .878 r
.51924 .64547 m .52008 .64582 L .51684 .6455 L F
.778 .574 .623 r
.51875 .64773 m .52026 .64545 L .51924 .64547 L F
.766 .944 .938 r
.52099 .64435 m .52199 .64472 L .51924 .64547 L F
.778 .574 .623 r
.52026 .64545 m .52099 .64435 L .51924 .64547 L F
.152 .676 .878 r
.51924 .64547 m .51684 .6455 L .51651 .64547 L F
.621 .949 .935 r
.52199 .64472 m .52008 .64582 L .51924 .64547 L F
.16 .049 .468 r
.52153 .64757 m .52008 .64582 L .52199 .64472 L F
.52153 .64757 m .52007 .6483 L .52008 .64582 L F
.563 .585 .834 r
.45351 .58297 m .45191 .58547 L .45042 .58178 L F
0 0 .029 r
.45351 .58297 m .45247 .58722 L .45191 .58547 L F
.424 .067 .253 r
.35168 .58979 m .35392 .58944 L .35541 .58672 L F
.428 .037 .194 r
.35392 .58944 m .35766 .58685 L .35541 .58672 L F
.729 .277 .177 r
.5781 .59753 m .58155 .59827 L .57921 .59608 L F
.85 .475 0 r
.67163 .42707 m .67232 .42743 L .67122 .4266 L F
.67163 .42707 m .67267 .42885 L .67232 .42743 L F
.373 .206 .522 r
.54419 .69826 m .54585 .69777 L .54591 .6953 L F
.433 .229 .502 r
.54419 .69826 m .54586 .70029 L .54585 .69777 L F
.54419 .69826 m .54384 .70145 L .54586 .70029 L F
.373 .206 .522 r
.54419 .69826 m .54585 .69777 L .54591 .6953 L F
.239 .189 .597 r
.54586 .70029 m .54419 .69826 L .54585 .69777 L F
.494 .295 .538 r
.2313 .59801 m .22933 .5962 L .23159 .59533 L F
.2313 .59801 m .22913 .59874 L .22933 .5962 L F
.641 .593 .785 r
.48963 .71614 m .49334 .71888 L .49228 .71556 L F
.533 .538 .806 r
.49228 .71556 m .49334 .71888 L .49552 .71822 L F
.676 .543 .696 r
.49552 .71822 m .49349 .72121 L .49334 .71888 L F
.52 .108 .2 r
.49195 .72023 m .49552 .71822 L .49334 .71888 L F
.47 0 .039 r
.43846 .62248 m .44031 .62357 L .44286 .62175 L F
.134 0 0 r
.44031 .62357 m .44409 .62252 L .44286 .62175 L F
.945 .89 .49 r
.63737 .44429 m .63651 .44321 L .63768 .44356 L F
.63737 .44429 m .63621 .44554 L .63651 .44321 L F
.004 0 0 r
.24246 .55953 m .24182 .56012 L .24001 .56062 L F
.5 .383 .652 r
.24182 .56012 m .24001 .56376 L .24001 .56062 L F
.217 .427 .852 r
.21563 .56352 m .21911 .56614 L .2169 .5626 L F
.932 .853 .741 r
.53546 .721 m .53824 .7186 L .5354 .71843 L F
.53546 .721 m .53693 .72202 L .53824 .7186 L F
0 0 .498 r
.48176 .69512 m .48285 .698 L .48317 .69726 L F
.653 .795 .344 r
.48317 .69726 m .48285 .698 L .48176 .70005 L F
.935 .874 .753 r
.46749 .70706 m .46998 .70504 L .46562 .70442 L F
.919 .672 .55 r
.46757 .70281 m .46941 .70382 L .46822 .70128 L F
0 0 0 r
.4673 .70344 m .46822 .70128 L .46759 .70321 L F
.989 .748 .369 r
.46562 .70442 m .46488 .70066 L .46759 .70321 L F
.683 .139 0 r
.46542 .70208 m .46759 .70321 L .46659 .70227 L F
.4652 .70151 m .46659 .70227 L .46488 .70066 L F
.46542 .70208 m .46659 .70227 L .4652 .70151 L F
.919 .672 .55 r
.4673 .70344 m .46998 .70504 L .46941 .70382 L F
.4673 .70344 m .46941 .70382 L .46757 .70281 L F
.789 .583 .621 r
.77429 .48499 m .77754 .48813 L .77749 .4854 L F
.325 .181 .526 r
.22087 .61848 m .21884 .62183 L .21894 .61947 L F
.557 .83 .997 r
.47928 .73826 m .48024 .73772 L .47841 .7375 L F
.47928 .73826 m .48043 .73797 L .48024 .73772 L F
.516 .652 .919 r
.21011 .56042 m .21261 .56176 L .21015 .55915 L F
.763 .331 .226 r
.24888 .56106 m .2464 .56041 L .24668 .56044 L F
0 .472 .727 r
.24668 .56044 m .24509 .56006 L .24317 .55968 L F
0 0 0 r
.2458 .56048 m .24499 .56118 L .2438 .56175 L F
.63 .872 .518 r
.24592 .56031 m .24499 .56118 L .2458 .56048 L F
.763 .331 .226 r
.24888 .56106 m .2458 .56048 L .24484 .56 L F
.63 .872 .518 r
.24735 .55821 m .24562 .56038 L .24592 .56031 L F
0 0 0 r
.2458 .56048 m .2438 .56175 L .24484 .56 L F
.63 .872 .518 r
.24562 .56038 m .24499 .56118 L .24592 .56031 L F
.763 .331 .226 r
.2464 .56041 m .24597 .5603 L .24635 .56036 L F
.24597 .5603 m .24484 .56 L .24603 .56028 L F
.24597 .5603 m .24603 .56028 L .24635 .56036 L F
.2464 .56041 m .24635 .56036 L .24668 .56044 L F
.047 0 0 r
.25119 .56012 m .2458 .56048 L .24888 .56106 L F
.25119 .56012 m .24882 .56045 L .24646 .56047 L F
.24642 .56044 m .24646 .56047 L .2458 .56048 L F
.25119 .56012 m .24646 .56047 L .24642 .56044 L F
.63 .872 .518 r
.24735 .55821 m .24597 .56024 L .24882 .56045 L F
.24597 .56024 m .2458 .56048 L .24714 .56047 L F
.24597 .56024 m .24714 .56047 L .24882 .56045 L F
0 .472 .727 r
.24317 .55968 m .24484 .56 L .24246 .55953 L F
.24509 .56006 m .24484 .56 L .24317 .55968 L F
.365 .098 .371 r
.51921 .69105 m .51712 .69194 L .51752 .68989 L F
.836 .563 .527 r
.65279 .42574 m .65376 .42703 L .65155 .42627 L F
.099 0 0 r
.65279 .42574 m .65155 .42627 L .65084 .42685 L F
.888 .654 .579 r
.65376 .42703 m .6508 .42808 L .65155 .42627 L F
.099 0 0 r
.65279 .42574 m .65084 .42685 L .65444 .42451 L F
.239 .51 .907 r
.6544 .42386 m .65446 .42557 L .65279 .42574 L F
.6544 .42386 m .65279 .42574 L .65444 .42451 L F
.246 .39 .81 r
.65446 .42557 m .65376 .42703 L .65279 .42574 L F
.632 .854 .984 r
.5226 .68011 m .52244 .67902 L .52471 .67848 L F
.084 .268 .754 r
.52287 .67465 m .52471 .67848 L .52515 .67666 L F
.817 .995 .861 r
.52471 .67848 m .52244 .67902 L .52515 .67666 L F
.903 .867 .794 r
.48 .70121 m .47643 .7032 L .48027 .70383 L F
.592 .54 .765 r
.48027 .70383 m .48176 .70005 L .48 .70121 L F
.588 .015 0 r
.64044 .44502 m .64077 .44569 L .64298 .44635 L F
.63768 .44356 m .64077 .44569 L .64044 .44502 L F
.916 .517 .153 r
.64077 .44569 m .64202 .4476 L .64298 .44635 L F
0 0 .094 r
.641 .44413 m .64113 .44644 L .64077 .44569 L F
.916 .517 .153 r
.64077 .44569 m .64121 .44791 L .64202 .4476 L F
0 0 .094 r
.64113 .44644 m .64121 .44791 L .64077 .44569 L F
.095 .315 .791 r
.641 .44413 m .64077 .44569 L .63768 .44356 L F
.376 .473 .832 r
.34324 .61975 m .34507 .62303 L .34597 .62135 L F
.324 0 .03 r
.50328 .72139 m .5046 .7219 L .50542 .72068 L F
.278 0 0 r
.50196 .72104 m .5046 .7219 L .50328 .72139 L F
.024 .249 .752 r
.50328 .72139 m .50561 .72337 L .5046 .7219 L F
.841 .822 .83 r
.59935 .45283 m .59967 .45571 L .59691 .45569 L F
.833 .817 .834 r
.60223 .45278 m .59967 .45571 L .59935 .45283 L F
.361 .177 .491 r
.64578 .44064 m .64769 .44041 L .64771 .43817 L F
.75 .723 .827 r
.20092 .59407 m .20503 .59456 L .20319 .59379 L F
.177 .53 .922 r
.20503 .59456 m .20574 .59373 L .20319 .59379 L F
.20503 .59456 m .20726 .59543 L .20574 .59373 L F
.824 .679 .704 r
.51118 .68036 m .51579 .68212 L .51457 .67751 L F
.015 .586 .764 r
.51082 .68167 m .51404 .68196 L .5114 .68049 L F
.51082 .68167 m .5114 .68049 L .51118 .68036 L F
.006 0 .212 r
.50944 .68296 m .5089 .68601 L .51082 .68167 L F
.84 .892 .467 r
.51082 .68167 m .5089 .68601 L .50951 .68386 L F
.68 .36 .427 r
.50951 .68386 m .50983 .68368 L .51082 .68167 L F
.015 .586 .764 r
.51082 .68167 m .51318 .68178 L .51579 .68212 L F
.68 .36 .427 r
.50983 .68368 m .51318 .68178 L .51082 .68167 L F
.915 .954 .62 r
.51318 .68178 m .51064 .68534 L .51077 .68536 L F
.51271 .68334 m .51077 .68536 L .51205 .68555 L F
.51318 .68178 m .51077 .68536 L .51271 .68334 L F
.015 .586 .764 r
.51404 .68196 m .51579 .68212 L .51439 .68159 L F
.51404 .68196 m .51439 .68159 L .51118 .68036 L F
.031 .153 .659 r
.51579 .68212 m .51727 .68096 L .51457 .67751 L F
.752 .749 .849 r
.51318 .68178 m .51727 .68096 L .51579 .68212 L F
.887 .662 .592 r
.42238 .61366 m .42103 .6133 L .42397 .61253 L F
.42238 .61366 m .42119 .61608 L .42103 .6133 L F
.47 .174 .38 r
.42238 .61366 m .42411 .6157 L .42119 .61608 L F
.39 .164 .446 r
.42593 .61241 m .42238 .61366 L .42397 .61253 L F
.42593 .61241 m .42411 .6157 L .42238 .61366 L F
.247 .14 .53 r
.42397 .61253 m .42411 .6157 L .42238 .61366 L F
.577 .421 .632 r
.2057 .64491 m .20654 .64823 L .20384 .64846 L F
.303 .134 .479 r
.20826 .64211 m .20809 .64473 L .2057 .64491 L F
0 0 .043 r
.20809 .64473 m .20654 .64823 L .2057 .64491 L F
.966 .682 .262 r
.59087 .6268 m .59148 .62535 L .59158 .62292 L F
.59087 .6268 m .59171 .62779 L .59148 .62535 L F
.672 .412 .52 r
.60969 .47602 m .60751 .47859 L .60761 .47661 L F
.057 0 0 r
.20654 .64823 m .20338 .65071 L .20384 .64846 L F
.522 .335 .568 r
.54191 .64684 m .54234 .64502 L .54064 .64567 L F
.54191 .64684 m .54402 .64549 L .54234 .64502 L F
.54191 .64684 m .54397 .64799 L .54402 .64549 L F
.426 0 0 r
.24484 .56 m .24182 .56012 L .24246 .55953 L F
0 0 .26 r
.4811 .6222 m .48317 .61886 L .48241 .621 L F
0 0 0 r
.48241 .621 m .48025 .62412 L .4811 .6222 L F
.553 .208 .338 r
.39299 .59366 m .39238 .5953 L .3902 .59502 L F
.308 0 .232 r
.39462 .59445 m .39299 .59366 L .39525 .5931 L F
.39462 .59445 m .39238 .5953 L .39299 .59366 L F
.44 .051 .204 r
.64412 .46112 m .64332 .46205 L .64314 .46316 L F
0 0 0 r
.64616 .45948 m .64412 .46112 L .64634 .46058 L F
.251 0 .114 r
.64412 .46112 m .64449 .46146 L .64634 .46058 L F
.64449 .46146 m .64549 .46239 L .64626 .46075 L F
.64449 .46146 m .64626 .46075 L .64634 .46058 L F
.743 .75 .858 r
.64119 .46008 m .64323 .46197 L .64616 .45948 L F
.64323 .46197 m .64332 .46205 L .64355 .46184 L F
.251 0 .114 r
.64412 .46112 m .64314 .46316 L .64549 .46239 L F
0 0 0 r
.64616 .45948 m .64332 .46205 L .64412 .46112 L F
.743 .75 .858 r
.64323 .46197 m .64355 .46184 L .64616 .45948 L F
0 0 .15 r
.20017 .59911 m .20057 .60047 L .20258 .59914 L F
.717 .274 .196 r
.20057 .60047 m .20456 .60122 L .20258 .59914 L F
.601 .307 .442 r
.20258 .59914 m .20456 .60122 L .20555 .59919 L F
.486 .819 .999 r
.42232 .57643 m .42472 .5759 L .42566 .57671 L F
.484 .719 .975 r
.42659 .57495 m .42566 .57671 L .42472 .5759 L F
.42659 .57495 m .42993 .57703 L .42566 .57671 L F
.523 .311 .533 r
.53477 .67447 m .53712 .67403 L .53492 .67205 L F
.53477 .67447 m .53712 .67403 L .53492 .67205 L F
.65 .838 .973 r
.56847 .6268 m .57077 .6289 L .56799 .62865 L F
.784 .801 .867 r
.57115 .62369 m .57077 .6289 L .56847 .6268 L F
.57115 .62369 m .57275 .62495 L .57077 .6289 L F
.706 .702 .843 r
.57077 .6289 m .57275 .62495 L .57379 .628 L F
.038 0 0 r
.63604 .47415 m .63749 .47388 L .63917 .47389 L F
.774 .653 .728 r
.65202 .43164 m .64919 .43097 L .6508 .42808 L F
.65202 .43164 m .65027 .43256 L .64919 .43097 L F
.822 .805 .835 r
.65374 .42894 m .65202 .43164 L .6508 .42808 L F
0 0 0 r
.63375 .41706 m .6307 .4186 L .63398 .41732 L F
.63628 .41583 m .63375 .41706 L .63398 .41732 L F
.336 .125 .438 r
.20338 .65071 m .20203 .65231 L .20245 .65159 L F
.068 0 .123 r
.58206 .48533 m .58463 .48217 L .58479 .48458 L F
.669 .494 .639 r
.58728 .48177 m .58479 .48458 L .58463 .48217 L F
.532 .799 .995 r
.35929 .63536 m .36035 .63397 L .35798 .63383 L F
.35929 .63536 m .36133 .63517 L .36035 .63397 L F
.459 0 0 r
.53821 .66754 m .53705 .66656 L .53584 .66769 L F
0 0 0 r
.53821 .66754 m .53661 .66917 L .53846 .66776 L F
.459 0 0 r
.53821 .66754 m .53915 .6683 L .53805 .66739 L F
.413 .763 .995 r
.53821 .66754 m .54049 .66734 L .53915 .6683 L F
0 0 0 r
.53821 .66754 m .53846 .66776 L .5389 .66743 L F
.459 0 0 r
.53821 .66754 m .53805 .66739 L .53705 .66656 L F
.713 .752 .883 r
.7923 .50038 m .79555 .50117 L .79458 .49913 L F
.645 .727 .909 r
.79458 .49913 m .79555 .50117 L .79816 .50017 L F
0 .067 .618 r
.63464 .44942 m .6352 .45205 L .63462 .45027 L F
.628 .653 .856 r
.50749 .68641 m .51116 .68691 L .51004 .68559 L F
0 0 0 r
.51004 .68559 m .50987 .68565 L .50749 .68641 L F
.50987 .68565 m .5089 .68601 L .50816 .68622 L F
.50987 .68565 m .50816 .68622 L .50749 .68641 L F
.317 .259 .634 r
.50816 .68622 m .5071 .6886 L .50749 .68641 L F
.62 .235 .292 r
.50872 .68604 m .50814 .68633 L .50863 .68793 L F
.317 .259 .634 r
.5089 .68601 m .50798 .68733 L .50816 .68622 L F
.50798 .68733 m .5071 .6886 L .50816 .68622 L F
.50798 .68733 m .50863 .68793 L .5071 .6886 L F
.62 .235 .292 r
.50814 .68633 m .50788 .68795 L .50863 .68793 L F
.50872 .68604 m .50863 .68793 L .5089 .68601 L F
.317 .259 .634 r
.5089 .68601 m .50863 .68793 L .50798 .68733 L F
.62 .235 .292 r
.50798 .68733 m .50476 .68805 L .50788 .68795 L F
.50814 .68633 m .50734 .68674 L .50798 .68733 L F
.50734 .68674 m .50476 .68805 L .50798 .68733 L F
0 0 0 r
.50861 .68605 m .5089 .68601 L .50749 .68641 L F
.62 .235 .292 r
.50874 .68558 m .50718 .68655 L .50872 .68604 L F
.50718 .68655 m .50476 .68805 L .50872 .68604 L F
.50874 .68558 m .50872 .68604 L .5089 .68601 L F
0 0 0 r
.51004 .68559 m .5089 .68601 L .50861 .68605 L F
.496 .223 .43 r
.53609 .68488 m .53371 .68348 L .53762 .68332 L F
.467 .365 .656 r
.53972 .68042 m .54048 .68315 L .53762 .68332 L F
.611 .272 .373 r
.54048 .68315 m .53609 .68488 L .53762 .68332 L F
.359 .169 .482 r
.22722 .60173 m .22687 .60433 L .22511 .60494 L F
.33 .205 .555 r
.22687 .60433 m .22534 .60742 L .22511 .60494 L F
.973 .927 .658 r
.53763 .69244 m .53642 .69369 L .5386 .68949 L F
.672 .343 .408 r
.53763 .69244 m .53885 .69464 L .53642 .69369 L F
.648 .835 .972 r
.5057 .73612 m .50939 .73632 L .50803 .73548 L F
.50939 .73632 m .5057 .73612 L .50803 .73548 L F
0 0 0 r
.5437 .71285 m .5425 .71461 L .54138 .71583 L F
.575 .936 .791 r
.54138 .71583 m .5425 .71461 L .54061 .71595 L F
.888 .654 .579 r
.65376 .42703 m .65374 .42894 L .6508 .42808 L F
.016 .494 .873 r
.6561 .42725 m .65376 .42703 L .65446 .42557 L F
.846 .401 0 r
.65503 .42632 m .6561 .42725 L .65497 .42615 L F
.016 .494 .873 r
.6561 .42725 m .65714 .42816 L .65376 .42703 L F
.846 .401 0 r
.65564 .42798 m .6561 .42725 L .65503 .42632 L F
.016 .494 .873 r
.6561 .42725 m .65732 .42822 L .65714 .42816 L F
.377 .013 .214 r
.52824 .67402 m .53085 .67396 L .53125 .67111 L F
.01 0 .047 r
.53125 .67111 m .53274 .67076 L .53367 .66915 L F
0 0 .106 r
.53125 .67111 m .53212 .67272 L .53274 .67076 L F
.53125 .67111 m .53085 .67396 L .53212 .67272 L F
.672 .412 .52 r
.60969 .47602 m .61096 .47838 L .60751 .47859 L F
.687 .344 .389 r
.60969 .47602 m .61346 .47829 L .61096 .47838 L F
.60969 .47602 m .61325 .4766 L .61346 .47829 L F
.267 0 0 r
.36634 .58475 m .36797 .58524 L .36969 .5843 L F
.28 0 0 r
.36797 .58524 m .37199 .58396 L .36969 .5843 L F
.565 .379 .589 r
.52335 .64234 m .5243 .64321 L .52494 .63983 L F
.278 .012 .318 r
.19739 .60236 m .19925 .60186 L .20017 .59911 L F
0 0 .15 r
.20017 .59911 m .19925 .60186 L .20057 .60047 L F
.515 .459 .731 r
.69073 .42847 m .6893 .43275 L .68838 .42906 L F
.69073 .42847 m .69177 .43224 L .6893 .43275 L F
.506 .415 .687 r
.69177 .43224 m .6923 .43495 L .6893 .43275 L F
.711 .691 .83 r
.46772 .71241 m .47089 .71301 L .46972 .71232 L F
.985 .736 .47 r
.47089 .71301 m .46961 .7095 L .46972 .71232 L F
.637 .524 .708 r
.78601 .4994 m .78833 .49872 L .78844 .49631 L F
.576 .527 .763 r
.78601 .4994 m .78993 .50286 L .78833 .49872 L F
.338 .776 .965 r
.21111 .54391 m .21316 .54368 L .21504 .54424 L F
.037 .607 .723 r
.21316 .54368 m .21714 .54357 L .21504 .54424 L F
0 0 0 r
.472 .72956 m .47183 .7313 L .47347 .72954 L F
.975 .687 .414 r
.18458 .57699 m .18597 .57566 L .18597 .57434 L F
.157 .044 .463 r
.18597 .57566 m .18606 .57802 L .18556 .57836 L F
.975 .687 .414 r
.18458 .57699 m .18606 .57802 L .18597 .57566 L F
.012 .071 .579 r
.5915 .61803 m .59109 .62196 L .59075 .61941 L F
.264 0 .242 r
.19565 .61272 m .1985 .60966 L .19592 .61094 L F
.348 .477 .848 r
.35641 .63382 m .35636 .63045 L .35459 .63064 L F
.35641 .63382 m .35798 .63383 L .35636 .63045 L F
.513 .825 1 r
.21714 .54357 m .21926 .54302 L .22076 .54392 L F
.223 .407 .834 r
.22135 .542 m .22076 .54392 L .21926 .54302 L F
.22135 .542 m .22293 .54495 L .22076 .54392 L F
.637 .755 .934 r
.33898 .63027 m .34069 .632 L .3427 .6309 L F
.347 .087 .371 r
.23364 .58746 m .23264 .59029 L .23101 .5903 L F
.371 .288 .632 r
.23264 .59029 m .23299 .5922 L .23101 .5903 L F
.331 .284 .654 r
.23101 .5903 m .23299 .5922 L .23158 .5928 L F
.175 .699 .87 r
.39913 .57912 m .40028 .57891 L .40187 .57926 L F
.033 0 0 r
.39902 .57945 m .40107 .57876 L .40028 .57891 L F
.492 .856 .989 r
.40028 .57891 m .40215 .57841 L .40413 .57893 L F
.033 0 0 r
.40107 .57876 m .40215 .57841 L .40028 .57891 L F
.175 .699 .87 r
.39813 .57907 m .40028 .57891 L .39913 .57912 L F
.492 .856 .989 r
.40028 .57891 m .40413 .57893 L .40187 .57926 L F
.771 .737 .821 r
.4974 .71159 m .50133 .71051 L .49905 .7095 L F
.582 .675 .904 r
.43452 .57747 m .43563 .57788 L .43507 .57897 L F
.43563 .57788 m .43764 .57861 L .43507 .57897 L F
.647 .652 .841 r
.43485 .5786 m .43764 .57861 L .43452 .57747 L F
0 .563 .796 r
.43758 .57424 m .43674 .57409 L .43556 .57312 L F
.43674 .57409 m .43347 .57353 L .43542 .57315 L F
.43674 .57409 m .43542 .57315 L .43556 .57312 L F
.43758 .57424 m .436 .57394 L .43347 .57353 L F
.755 .892 .94 r
.43702 .5743 m .43485 .5786 L .436 .57394 L F
.4374 .57443 m .43734 .57452 L .43702 .5743 L F
.43734 .57452 m .43485 .5786 L .43702 .5743 L F
.43858 .57484 m .4357 .57775 L .4374 .57443 L F
.4357 .57775 m .43485 .5786 L .4374 .57443 L F
.582 .675 .904 r
.43507 .57897 m .43764 .57861 L .43516 .57921 L F
.496 0 0 r
.48306 .61049 m .48538 .61163 L .48491 .61068 L F
.982 .82 .605 r
.45602 .58848 m .45495 .58675 L .45749 .58725 L F
.45602 .58848 m .4544 .58928 L .45495 .58675 L F
.218 0 .091 r
.52792 .68392 m .52746 .68528 L .52526 .68617 L F
.396 0 .118 r
.5311 .68313 m .52746 .68528 L .52792 .68392 L F
.336 .125 .438 r
.20338 .65071 m .20153 .65397 L .20203 .65231 L F
.785 .743 .815 r
.4731 .70992 m .47579 .70798 L .47463 .70545 L F
.54 .509 .771 r
.19806 .59226 m .20092 .59407 L .19979 .59214 L F
.525 .243 .43 r
.19587 .60427 m .19925 .60186 L .19739 .60236 L F
.676 .157 0 r
.58661 .60149 m .58726 .60161 L .58477 .59933 L F
.651 .095 0 r
.58773 .60287 m .58726 .60161 L .58661 .60149 L F
.58773 .60287 m .58972 .60378 L .58726 .60161 L F
.007 .065 .574 r
.46303 .70363 m .46337 .70732 L .46443 .7059 L F
.211 .363 .799 r
.46337 .70732 m .46579 .70912 L .46443 .7059 L F
0 .152 .638 r
.23447 .54816 m .23458 .54856 L .23263 .54787 L F
.23447 .54816 m .23573 .54938 L .23458 .54856 L F
.681 .268 0 r
.65732 .42822 m .65937 .43171 L .65851 .42934 L F
.69 .931 .624 r
.56281 .63231 m .5612 .63366 L .56127 .634 L F
.987 .769 .524 r
.56172 .63063 m .56281 .63231 L .56613 .63323 L F
.56172 .63063 m .5612 .63366 L .56281 .63231 L F
.838 .997 .833 r
.66534 .45673 m .66466 .45889 L .66726 .45618 L F
.844 .976 .671 r
.66319 .45989 m .66466 .45889 L .66534 .45673 L F
.635 .425 .58 r
.52287 .67465 m .52548 .6747 L .52533 .67195 L F
.587 .388 .579 r
.52533 .67195 m .52548 .6747 L .52824 .67402 L F
.533 .538 .806 r
.49228 .71556 m .49552 .71822 L .49582 .71567 L F
.501 .278 .507 r
.49552 .71822 m .4975 .71737 L .49582 .71567 L F
0 0 0 r
.38646 .59534 m .38412 .59842 L .38435 .59551 L F
.493 0 0 r
.62722 .41718 m .6307 .4186 L .62841 .4174 L F
.48 .266 .511 r
.2607 .82339 m .26285 .82317 L .26033 .82627 L F
.2607 .82339 m .26285 .82317 L .26033 .82627 L F
0 0 0 r
.34482 .6247 m .34606 .62427 L .34756 .62236 L F
.509 .8 .998 r
.34597 .62135 m .34756 .62236 L .34838 .62097 L F
.498 .315 .563 r
.34606 .62427 m .34838 .62097 L .34756 .62236 L F
.34606 .62427 m .34816 .62404 L .34838 .62097 L F
.845 .954 .607 r
.34606 .62427 m .34563 .62382 L .34701 .62394 L F
.34606 .62427 m .34701 .62394 L .34816 .62404 L F
0 0 0 r
.34431 .62515 m .34606 .62427 L .34482 .6247 L F
.335 0 .038 r
.20203 .58973 m .20578 .58762 L .20362 .58721 L F
.20203 .58973 m .20413 .58957 L .20578 .58762 L F
.434 0 .102 r
.20578 .58762 m .20413 .58957 L .20778 .58843 L F
.774 .68 .759 r
.5437 .71285 m .5402 .7095 L .54321 .70999 L F
.5437 .71285 m .54013 .71256 L .5402 .7095 L F
.905 .962 .815 r
.54491 .70924 m .5437 .71285 L .54321 .70999 L F
.54491 .70924 m .54271 .71196 L .5437 .71285 L F
.999 .818 .476 r
.54271 .71196 m .5425 .71461 L .5437 .71285 L F
.415 .231 .521 r
.2345 .58641 m .23264 .59029 L .23364 .58746 L F
.644 .535 .715 r
.52696 .70701 m .52761 .70448 L .52428 .70483 L F
.416 .289 .598 r
.22297 .61284 m .22326 .61561 L .22072 .61622 L F
.437 .242 .516 r
.22326 .61561 m .22087 .61848 L .22072 .61622 L F
.756 .767 .862 r
.79399 .49448 m .7914 .49449 L .79345 .49278 L F
.481 .522 .822 r
.79593 .49239 m .79399 .49448 L .79345 .49278 L F
.79593 .49239 m .79591 .49411 L .79399 .49448 L F
.672 .511 .659 r
.50658 .69802 m .50669 .69924 L .50937 .698 L F
.686 .881 .971 r
.42232 .57643 m .4193 .57765 L .41811 .5768 L F
.491 .815 1 r
.46961 .7095 m .4731 .70992 L .47245 .70642 L F
.785 .743 .815 r
.4731 .70992 m .47463 .70545 L .47245 .70642 L F
.418 .222 .506 r
.33871 .59856 m .34092 .59551 L .33874 .59607 L F
0 .415 .783 r
.79591 .49411 m .801 .49641 L .79796 .49732 L F
.297 .714 .974 r
.45247 .58722 m .45087 .58629 L .44873 .58631 L F
0 0 .029 r
.45351 .58297 m .45311 .58581 L .45247 .58722 L F
.499 .818 1 r
.45247 .58722 m .45311 .58581 L .45087 .58629 L F
.118 0 0 r
.17977 .54242 m .18186 .54229 L .18364 .54165 L F
0 0 0 r
.18364 .54165 m .18395 .54157 L .18581 .54157 L F
.18364 .54165 m .18186 .54229 L .18395 .54157 L F
.145 .671 .876 r
.37248 .58402 m .37416 .58403 L .37571 .58439 L F
.149 0 0 r
.37265 .5851 m .376 .58403 L .37416 .58403 L F
.214 .734 .856 r
.37416 .58403 m .37675 .58379 L .37796 .58387 L F
.149 0 0 r
.376 .58403 m .37675 .58379 L .37416 .58403 L F
.145 .671 .876 r
.37199 .58396 m .37416 .58403 L .37248 .58402 L F
.214 .734 .856 r
.37416 .58403 m .37796 .58387 L .37571 .58439 L F
.239 .04 .396 r
.21608 .62992 m .21514 .62822 L .21649 .6274 L F
.21608 .62992 m .21469 .63058 L .21514 .62822 L F
0 0 0 r
.50542 .72068 m .50648 .72058 L .5078 .71929 L F
.50542 .72068 m .5046 .7219 L .50648 .72058 L F
.483 .192 .394 r
.41182 .58777 m .41025 .5887 L .4079 .58899 L F
0 0 0 r
.41285 .58736 m .41095 .58794 L .41077 .5879 L F
.41182 .58777 m .4079 .58899 L .40924 .5883 L F
.743 .971 .929 r
.41229 .58681 m .41025 .5887 L .41182 .58777 L F
0 0 0 r
.41059 .58873 m .41025 .5887 L .41105 .58797 L F
.41123 .58801 m .41105 .58797 L .41229 .58681 L F
.41059 .58873 m .41105 .58797 L .41123 .58801 L F
.41285 .58736 m .41182 .58777 L .41095 .58794 L F
.41077 .5879 m .41095 .58794 L .40924 .5883 L F
.723 .951 .951 r
.41359 .58553 m .41285 .58736 L .41497 .58594 L F
.772 .933 .577 r
.41359 .58553 m .41182 .58777 L .41285 .58736 L F
.56 .381 .596 r
.54967 .63111 m .55424 .63029 L .55013 .62824 L F
.936 .607 .163 r
.56728 .6389 m .56879 .64247 L .57021 .63977 L F
.56728 .6389 m .56777 .64187 L .56879 .64247 L F
.819 .364 0 r
.56872 .64373 m .56879 .64247 L .56777 .64187 L F
.56872 .64373 m .56988 .64473 L .56879 .64247 L F
.677 .599 .761 r
.53936 .70109 m .5415 .70388 L .54189 .70301 L F
.551 .454 .697 r
.54189 .70301 m .5415 .70388 L .54384 .70145 L F
.685 .667 .826 r
.5415 .70388 m .54478 .70406 L .54384 .70145 L F
.646 .431 .577 r
.54227 .7066 m .54478 .70406 L .5415 .70388 L F
.205 .172 .597 r
.19581 .61873 m .19398 .61639 L .19436 .61749 L F
.407 .298 .618 r
.19448 .61924 m .19581 .61873 L .19436 .61749 L F
0 0 0 r
.37082 .60436 m .36971 .60652 L .36797 .60747 L F
.147 0 .052 r
.37196 .60536 m .37082 .60436 L .37337 .60354 L F
.37196 .60536 m .36971 .60652 L .37082 .60436 L F
.377 .821 .947 r
.40413 .57893 m .40651 .57849 L .40799 .57885 L F
.371 .834 .896 r
.40651 .57849 m .41018 .57799 L .40799 .57885 L F
.394 0 0 r
.38479 .6393 m .38053 .64118 L .38137 .64011 L F
.38479 .6393 m .38233 .64182 L .38053 .64118 L F
.243 0 0 r
.38461 .64113 m .38479 .6393 L .38709 .6398 L F
.38415 .64127 m .38233 .64182 L .38375 .64036 L F
.202 .292 .734 r
.38053 .64118 m .38233 .64182 L .38209 .6411 L F
.675 .59 .752 r
.38209 .6411 m .38233 .64182 L .38461 .64113 L F
.167 0 0 r
.38434 .6417 m .3802 .64191 L .38209 .6411 L F
.38451 .64174 m .38437 .64175 L .38434 .6417 L F
.38437 .64175 m .3802 .64191 L .38434 .6417 L F
.243 0 0 r
.38461 .64113 m .38415 .64127 L .38479 .6393 L F
.38415 .64127 m .38375 .64036 L .38479 .6393 L F
.69 .518 .649 r
.40863 .62307 m .41216 .62439 L .41089 .62206 L F
.40863 .62307 m .40845 .62537 L .41216 .62439 L F
.833 .817 .834 r
.60223 .45278 m .59935 .45283 L .6007 .45144 L F
.811 .803 .843 r
.60482 .44998 m .60223 .45278 L .6007 .45144 L F
0 0 0 r
.47429 .7043 m .47245 .70642 L .47463 .70545 L F
.159 .32 .778 r
.20904 .5586 m .21011 .56042 L .21015 .55915 L F
.419 .815 .985 r
.41018 .57799 m .41245 .5776 L .41389 .5782 L F
.413 .812 .984 r
.41389 .5782 m .41245 .5776 L .41613 .57783 L F
.646 .431 .577 r
.54227 .7066 m .54478 .70657 L .54478 .70406 L F
.524 .333 .564 r
.54478 .70657 m .54714 .70613 L .54478 .70406 L F
.726 .412 .448 r
.57636 .48849 m .57968 .4903 L .57694 .4896 L F
.548 .354 .57 r
.63807 .43549 m .64061 .435 L .64083 .4317 L F
.56 .469 .709 r
.64172 .43226 m .64061 .435 L .64083 .4317 L F
.353 0 0 r
.42536 .63115 m .42388 .63263 L .4215 .63277 L F
.462 0 .049 r
.4279 .63113 m .42388 .63263 L .42536 .63115 L F
0 0 0 r
.4682 .61902 m .4665 .62273 L .46811 .62164 L F
.109 0 .203 r
.4665 .62273 m .46571 .62494 L .46811 .62164 L F
.72 .591 .71 r
.54084 .67663 m .53972 .68042 L .53931 .67742 L F
.416 .315 .633 r
.33714 .60188 m .33916 .60371 L .33906 .60114 L F
.33714 .60188 m .3371 .60502 L .33916 .60371 L F
.702 .647 .791 r
.67592 .41485 m .67722 .41856 L .67366 .41764 L F
.842 .904 .88 r
.67722 .41856 m .67367 .42024 L .67366 .41764 L F
.697 .667 .817 r
.67841 .41414 m .67722 .41856 L .67592 .41485 L F
.67841 .41414 m .67965 .41751 L .67722 .41856 L F
.609 .47 .667 r
.67965 .41751 m .67743 .42098 L .67722 .41856 L F
.101 .51 .906 r
.4741 .69195 m .47326 .69226 L .47234 .69181 L F
.4741 .69195 m .47562 .69346 L .47326 .69226 L F
.47326 .69226 m .4741 .69195 L .47234 .69181 L F
.47326 .69226 m .47562 .69346 L .4741 .69195 L F
0 .198 .723 r
.56586 .64553 m .5671 .6452 L .5648 .64458 L F
.56586 .64553 m .56789 .6476 L .5671 .6452 L F
.593 .908 .981 r
.34295 .62832 m .34352 .62704 L .34431 .62515 L F
.339 .549 .91 r
.20597 .55545 m .20904 .5586 L .20962 .55716 L F
.159 .32 .778 r
.20904 .5586 m .21015 .55915 L .20962 .55716 L F
.929 .681 .543 r
.58113 .62527 m .57917 .6267 L .57885 .62429 L F
.58113 .62527 m .58106 .62795 L .57917 .6267 L F
.989 .748 .369 r
.46562 .70442 m .46759 .70321 L .4673 .70344 L F
.813 .411 .29 r
.46443 .7059 m .46749 .70706 L .46562 .70442 L F
.46443 .7059 m .46562 .70442 L .4673 .70344 L F
.507 .272 .492 r
.47475 .73253 m .47464 .73568 L .47382 .7353 L F
.495 .256 .482 r
.51449 .66326 m .51429 .66552 L .51197 .66599 L F
.51449 .66326 m .51429 .66552 L .51197 .66599 L F
.58 .444 .659 r
.51665 .66005 m .51449 .66326 L .51708 .66267 L F
.593 .375 .555 r
.51708 .66267 m .51429 .66552 L .51449 .66326 L F
.51708 .66267 m .51694 .66553 L .51429 .66552 L F
.041 0 .338 r
.51449 .66326 m .51563 .66474 L .51708 .66267 L F
.51449 .66326 m .51429 .66552 L .51563 .66474 L F
.58 .444 .659 r
.51665 .66005 m .51449 .66326 L .51708 .66267 L F
.543 .552 .813 r
.34006 .61664 m .34089 .61278 L .33869 .61324 L F
.34006 .61664 m .34222 .61622 L .34089 .61278 L F
.786 .718 .788 r
.59452 .45857 m .59549 .46191 L .59207 .46152 L F
.596 .132 0 r
.4798 .68574 m .48023 .68615 L .47906 .68473 L F
0 .269 .678 r
.48153 .68681 m .48023 .68615 L .4798 .68574 L F
.619 .53 .732 r
.48153 .68681 m .47991 .68915 L .48023 .68615 L F
.943 .943 .756 r
.66534 .45673 m .66726 .45618 L .66651 .45508 L F
.252 0 0 r
.42243 .58356 m .42214 .58426 L .41987 .58429 L F
.419 0 0 r
.42214 .58426 m .42121 .58425 L .41987 .58429 L F
.02 0 0 r
.42106 .58378 m .41987 .58429 L .41904 .58431 L F
.419 0 0 r
.42121 .58425 m .41833 .58422 L .41987 .58429 L F
.02 0 0 r
.41904 .58431 m .41987 .58429 L .41746 .58472 L F
0 0 0 r
.42366 .58276 m .42243 .58356 L .42106 .58378 L F
.252 0 0 r
.42243 .58356 m .41987 .58429 L .42106 .58378 L F
.887 .752 .708 r
.62265 .43509 m .62234 .43822 L .62373 .43814 L F
.818 .46 .38 r
.62234 .43822 m .62264 .44022 L .62373 .43814 L F
.736 .751 .864 r
.51809 .72911 m .51766 .73323 L .51402 .73288 L F
.143 0 0 r
.51766 .73323 m .51626 .73316 L .51402 .73288 L F
0 0 .472 r
.51872 .72951 m .51766 .73323 L .51809 .72911 L F
.51872 .72951 m .519 .73272 L .51766 .73323 L F
.26 .766 .862 r
.51766 .73323 m .519 .73272 L .51626 .73316 L F
.077 .623 .838 r
.33911 .62784 m .3415 .62799 L .34295 .62832 L F
.33911 .62784 m .3415 .62799 L .34295 .62832 L F
.757 .526 .583 r
.33898 .63027 m .3427 .6309 L .34295 .62832 L F
.593 .908 .981 r
.34295 .62832 m .3415 .62799 L .34352 .62704 L F
0 0 .56 r
.34295 .62832 m .34352 .62704 L .3415 .62799 L F
.34295 .62832 m .34369 .63021 L .34352 .62704 L F
.615 .743 .937 r
.44252 .58681 m .44628 .58733 L .44575 .58485 L F
.668 .705 .875 r
.44575 .58485 m .44628 .58733 L .44873 .58631 L F
.428 .265 .556 r
.22493 .60986 m .22297 .61284 L .2237 .61084 L F
.121 0 0 r
.39061 .63898 m .38942 .63952 L .38709 .6398 L F
.065 0 0 r
.39304 .63856 m .38942 .63952 L .39061 .63898 L F
.009 .518 .863 r
.1803 .55361 m .18463 .55519 L .18054 .55309 L F
.897 .729 .666 r
.54205 .68025 m .5433 .68358 L .54171 .68278 L F
.914 .603 .442 r
.5433 .68358 m .54197 .68557 L .54171 .68278 L F
.906 .941 .579 r
.54458 .67958 m .5433 .68358 L .54205 .68025 L F
.54458 .67958 m .54278 .68412 L .5433 .68358 L F
.356 0 .175 r
.54278 .68412 m .54197 .68557 L .5433 .68358 L F
.789 .583 .621 r
.77429 .48499 m .77405 .48772 L .77754 .48813 L F
.309 .794 .895 r
.51348 .69428 m .51171 .69494 L .51489 .69258 L F
.24 0 0 r
.51712 .69194 m .51348 .69428 L .51489 .69258 L F
.925 .542 .159 r
.59245 .6083 m .59057 .60475 L .59052 .60706 L F
.938 .573 .185 r
.59196 .60926 m .59245 .6083 L .59052 .60706 L F
.59196 .60926 m .59298 .60998 L .59245 .6083 L F
.534 0 0 r
.38172 .62337 m .38395 .62505 L .38555 .62583 L F
0 .325 .791 r
.38474 .62512 m .38555 .62583 L .38395 .62505 L F
.498 0 0 r
.38555 .62583 m .38626 .62646 L .3847 .62498 L F
.721 .204 0 r
.3847 .62498 m .38681 .62697 L .3882 .62704 L F
0 .325 .791 r
.38577 .62522 m .38555 .62583 L .38474 .62512 L F
.498 0 0 r
.38555 .62583 m .38681 .62697 L .38626 .62646 L F
.201 .13 .548 r
.5386 .69702 m .53697 .69505 L .53885 .69464 L F
.379 .106 .369 r
.43812 .60988 m .43553 .61235 L .43613 .61023 L F
.43812 .60988 m .43553 .61235 L .43613 .61023 L F
.8 .571 .591 r
.57275 .62495 m .5758 .62735 L .57379 .628 L F
.45 .297 .581 r
.57379 .628 m .5758 .62735 L .57418 .63099 L F
.744 .681 .79 r
.51004 .68559 m .51332 .68625 L .51205 .68555 L F
.51004 .68559 m .51116 .68691 L .51332 .68625 L F
.726 .601 .716 r
.51116 .68691 m .51113 .68941 L .51332 .68625 L F
0 0 .012 r
.51113 .68941 m .51224 .68892 L .51332 .68625 L F
.617 .462 .649 r
.51332 .68625 m .51613 .68728 L .51578 .68349 L F
.788 .929 .927 r
.51619 .68326 m .51332 .68625 L .51578 .68349 L F
.51619 .68326 m .51205 .68555 L .51332 .68625 L F
.661 .324 .391 r
.51332 .68625 m .51224 .68892 L .51584 .68866 L F
.657 .325 .399 r
.51332 .68625 m .51584 .68866 L .51613 .68728 L F
.009 .518 .863 r
.1803 .55361 m .18054 .55309 L .17849 .55345 L F
0 0 .516 r
.5522 .69251 m .55291 .6932 L .55172 .69249 L F
.5522 .69251 m .55398 .69463 L .55291 .6932 L F
.198 .671 .937 r
.42718 .58362 m .42567 .58286 L .42366 .58276 L F
.417 .796 .992 r
.42943 .58328 m .42567 .58286 L .42718 .58362 L F
.519 .42 .682 r
.58489 .48702 m .58206 .48533 L .58479 .48458 L F
.58489 .48702 m .5825 .48779 L .58206 .48533 L F
.643 .206 .197 r
.48635 .70148 m .48841 .70322 L .48544 .70307 L F
.527 .262 .457 r
.48912 .70092 m .48841 .70322 L .48635 .70148 L F
.683 .388 .469 r
.68668 .44132 m .68751 .44342 L .68485 .44331 L F
.451 .289 .57 r
.69037 .43733 m .68981 .43988 L .68668 .44132 L F
.664 .547 .712 r
.68981 .43988 m .68751 .44342 L .68668 .44132 L F
.703 .535 .658 r
.49116 .72432 m .49224 .72754 L .489 .72711 L F
.027 0 .093 r
.489 .72711 m .48979 .72724 L .49116 .72432 L F
.517 .194 .358 r
.49116 .72432 m .49362 .7261 L .49331 .72411 L F
.237 .259 .681 r
.49362 .7261 m .49224 .72754 L .49116 .72432 L F
.517 .194 .358 r
.49116 .72432 m .48979 .72724 L .49362 .7261 L F
.237 .259 .681 r
.49362 .7261 m .49116 .72432 L .49331 .72411 L F
.651 .459 .611 r
.7702 .48671 m .77405 .48772 L .77429 .48499 L F
.628 .519 .711 r
.7702 .48671 m .77132 .49041 L .77405 .48772 L F
.029 0 0 r
.19547 .54212 m .19757 .5422 L .19939 .54226 L F
.143 0 0 r
.19939 .54226 m .19757 .5422 L .20142 .54249 L F
.829 .783 .809 r
.54931 .65706 m .54988 .65915 L .54663 .6599 L F
.899 .657 .564 r
.65027 .43256 m .64832 .43206 L .64919 .43097 L F
0 .257 .767 r
.65029 .43498 m .64832 .43206 L .65027 .43256 L F
.378 .083 .332 r
.50068 .68643 m .50278 .68587 L .50388 .68276 L F
.726 .43 .478 r
.50388 .68276 m .50874 .68558 L .50615 .68282 L F
.50388 .68276 m .50278 .68587 L .50874 .68558 L F
.606 .355 .511 r
.59934 .47871 m .60011 .48146 L .59577 .48184 L F
.68 .428 .534 r
.60138 .47892 m .60011 .48146 L .59934 .47871 L F
0 0 .162 r
.51113 .68941 m .5118 .69026 L .51224 .68892 L F
.51113 .68941 m .51076 .69192 L .5118 .69026 L F
.873 .898 .847 r
.62743 .44299 m .62692 .4433 L .62688 .44298 L F
0 0 0 r
.62989 .44121 m .62928 .44227 L .62688 .44298 L F
.62688 .44298 m .62928 .44227 L .62743 .44299 L F
.391 .357 .7 r
.23902 .57743 m .23678 .57556 L .23886 .575 L F
.23902 .57743 m .23758 .57832 L .23678 .57556 L F
.609 .47 .667 r
.67965 .41751 m .67983 .42051 L .67743 .42098 L F
.796 .615 .657 r
.67983 .42051 m .67794 .42324 L .67743 .42098 L F
.453 .72 .982 r
.43359 .57611 m .43215 .5775 L .43045 .57637 L F
.43359 .57611 m .43452 .57747 L .43215 .5775 L F
.981 .69 .353 r
.66787 .43244 m .6669 .43361 L .66685 .43122 L F
.66787 .43244 m .66808 .43477 L .6669 .43361 L F
.309 .794 .895 r
.51348 .69428 m .51092 .69474 L .51171 .69494 L F
.434 .329 .636 r
.19398 .61639 m .19598 .61605 L .19565 .61272 L F
.205 .172 .597 r
.19581 .61873 m .19598 .61605 L .19398 .61639 L F
.195 .06 .459 r
.21719 .5722 m .21906 .56872 L .21698 .56991 L F
.614 .557 .767 r
.58814 .652 m .58942 .64784 L .58705 .64848 L F
.58814 .652 m .59081 .65142 L .58942 .64784 L F
.538 .35 .574 r
.46811 .62164 m .47035 .6182 L .4682 .61902 L F
0 0 .127 r
.66838 .44307 m .66835 .44204 L .66723 .44046 L F
.209 0 0 r
.34755 .5914 m .35168 .58979 L .34944 .59014 L F
.344 .156 .476 r
.22901 .60332 m .22722 .60173 L .22889 .60091 L F
.22901 .60332 m .22687 .60433 L .22722 .60173 L F
.902 .741 .673 r
.59046 .63902 m .59176 .64246 L .59217 .63998 L F
.488 0 .023 r
.20778 .58843 m .20994 .58874 L .21195 .58724 L F
.144 0 0 r
.21195 .58724 m .21214 .58824 L .21393 .5866 L F
.21195 .58724 m .20994 .58874 L .21214 .58824 L F
.958 .642 .23 r
.62548 .42134 m .62577 .42312 L .6248 .42206 L F
0 0 .302 r
.62722 .41718 m .62548 .42134 L .62728 .4191 L F
.571 .837 .484 r
.62728 .4191 m .62548 .42134 L .6248 .42206 L F
.447 .534 .853 r
.36944 .64032 m .3696 .6364 L .36772 .63655 L F
.36944 .64032 m .37133 .63992 L .3696 .6364 L F
.262 0 0 r
.39924 .63731 m .39759 .63845 L .39527 .6386 L F
.426 0 0 r
.40112 .63801 m .39759 .63845 L .39924 .63731 L F
.741 .913 .952 r
.48024 .73772 m .48043 .73797 L .48413 .73574 L F
.126 0 0 r
.36237 .5864 m .36453 .58598 L .36634 .58475 L F
.268 0 0 r
.36634 .58475 m .36453 .58598 L .36797 .58524 L F
0 0 .351 r
.44727 .5811 m .4483 .57729 L .44965 .58029 L F
.44727 .5811 m .44752 .58094 L .4483 .57729 L F
.491 .411 .694 r
.44489 .58153 m .44752 .58094 L .44727 .5811 L F
.44489 .58153 m .44541 .5823 L .44752 .58094 L F
.569 .374 .577 r
.50453 .69151 m .50169 .69197 L .50158 .68936 L F
0 0 0 r
.52232 .72748 m .5248 .72402 L .52114 .72407 L F
.52232 .72748 m .52383 .72629 L .5248 .72402 L F
.334 .499 .873 r
.52232 .72748 m .52448 .72816 L .52383 .72629 L F
.516 .13 .249 r
.4227 .62438 m .42526 .62436 L .42645 .62213 L F
.545 .161 .264 r
.42645 .62213 m .42526 .62436 L .42848 .62361 L F
.113 .663 .807 r
.20384 .5551 m .20013 .55508 L .20188 .55489 L F
.545 .363 .585 r
.34094 .59302 m .34092 .59551 L .34327 .59257 L F
.979 .724 .32 r
.58993 .60626 m .59057 .60475 L .58972 .60378 L F
.58993 .60626 m .59052 .60706 L .59057 .60475 L F
.235 0 0 r
.43983 .62866 m .43817 .62948 L .4359 .62952 L F
.617 .09 0 r
.43983 .62866 m .44192 .6302 L .43817 .62948 L F
.553 .204 .33 r
.44309 .62786 m .44192 .6302 L .43983 .62866 L F
.118 0 .264 r
.54476 .60752 m .54263 .61096 L .54485 .60996 L F
.194 0 .326 r
.54263 .61096 m .54476 .60752 L .54485 .60996 L F
.452 .27 .542 r
.547 .60938 m .54476 .60752 L .54735 .60664 L F
.547 .60938 m .54485 .60996 L .54476 .60752 L F
.547 .60938 m .54476 .60752 L .54735 .60664 L F
.547 .60938 m .54485 .60996 L .54476 .60752 L F
0 .013 .572 r
.66474 .42809 m .66505 .42909 L .66685 .43122 L F
.306 0 0 r
.4169 .63322 m .4158 .634 L .41347 .63424 L F
.4169 .63322 m .4181 .63377 L .4158 .634 L F
.4169 .63322 m .41919 .63309 L .4181 .63377 L F
.806 .852 .884 r
.64268 .47245 m .64579 .47052 L .64458 .46904 L F
.65 .958 .934 r
.64764 .46867 m .64579 .47052 L .64765 .46924 L F
.559 .762 .973 r
.64458 .46904 m .64579 .47052 L .64764 .46867 L F
.575 .556 .795 r
.68973 .42486 m .68838 .42906 L .68771 .42741 L F
.68973 .42486 m .69073 .42847 L .68838 .42906 L F
.737 .342 .303 r
.53327 .63882 m .53551 .6413 L .53698 .6393 L F
.732 .336 .299 r
.53551 .6413 m .5391 .64174 L .53698 .6393 L F
.769 .265 0 r
.53698 .6393 m .5391 .64174 L .54096 .64239 L F
.332 0 0 r
.42848 .62361 m .43092 .62375 L .43258 .62303 L F
.275 .777 .858 r
.43092 .62375 m .43506 .6232 L .43258 .62303 L F
.483 .802 1 r
.17592 .5419 m .17977 .54242 L .17772 .54225 L F
.221 0 0 r
.38027 .58348 m .38269 .58315 L .38429 .58199 L F
0 0 0 r
.38429 .58199 m .38479 .58248 L .38654 .5812 L F
.38429 .58199 m .38269 .58315 L .38479 .58248 L F
.516 .866 .99 r
.53327 .63882 m .53035 .63956 L .53183 .63838 L F
.929 .545 .201 r
.53035 .63956 m .53136 .64179 L .52974 .64052 L F
.53035 .63956 m .52974 .64052 L .53183 .63838 L F
.757 .578 .654 r
.43899 .58606 m .44252 .58681 L .44311 .58489 L F
.43899 .58606 m .44041 .58703 L .44252 .58681 L F
.99 .85 .606 r
.43897 .58895 m .43986 .59045 L .44041 .58703 L F
.917 .885 .786 r
.43897 .58895 m .44252 .58681 L .44041 .58703 L F
.43897 .58895 m .43986 .59045 L .44252 .58681 L F
.669 .709 .878 r
.44311 .58489 m .44252 .58681 L .44575 .58485 L F
0 .001 .575 r
.53136 .64179 m .53164 .6428 L .53208 .64125 L F
.907 .834 .374 r
.55164 .69427 m .55183 .69519 L .55096 .69707 L F
.55164 .69427 m .55183 .69519 L .55096 .69707 L F
.396 0 .118 r
.5311 .68313 m .52995 .68488 L .52746 .68528 L F
.768 .467 .477 r
.53371 .68348 m .52995 .68488 L .5311 .68313 L F
.792 .698 .762 r
.45609 .59293 m .45966 .59319 L .45865 .59008 L F
.641 .813 .966 r
.4777 .69234 m .47562 .69346 L .4741 .69195 L F
.4777 .69234 m .47562 .69346 L .4741 .69195 L F
.134 0 0 r
.44031 .62357 m .44461 .62415 L .44409 .62252 L F
0 0 .551 r
.54031 .62863 m .53923 .62645 L .53875 .62565 L F
.412 .564 .896 r
.5413 .62647 m .54031 .62863 L .54271 .62844 L F
.5413 .62647 m .53923 .62645 L .54031 .62863 L F
.175 0 .378 r
.21275 .63371 m .21237 .63607 L .21101 .63677 L F
.039 0 .284 r
.21161 .63831 m .21101 .63677 L .21237 .63607 L F
.21161 .63831 m .21044 .6394 L .21101 .63677 L F
.984 .722 .448 r
.66808 .43477 m .66935 .43822 L .66808 .43711 L F
0 0 .208 r
.66935 .43822 m .66985 .43902 L .66808 .43711 L F
.66935 .43822 m .66952 .44052 L .66985 .43902 L F
.155 .695 .731 r
.38654 .5812 m .38848 .58085 L .39001 .58063 L F
.127 .673 .817 r
.38848 .58085 m .39222 .58087 L .39001 .58063 L F
.726 .81 .917 r
.572 .59779 m .57111 .60032 L .56968 .59848 L F
.572 .59779 m .57369 .5992 L .57111 .60032 L F
.729 .71 .833 r
.53139 .70375 m .53572 .70394 L .53366 .70114 L F
.73 .496 .573 r
.53121 .70661 m .53572 .70394 L .53139 .70375 L F
.52 .314 .54 r
.53572 .70394 m .53547 .70681 L .53311 .70716 L F
.73 .496 .573 r
.53121 .70661 m .53547 .70681 L .53572 .70394 L F
0 0 .216 r
.53572 .70394 m .53611 .69982 L .53366 .70114 L F
.53572 .70394 m .53664 .7005 L .53611 .69982 L F
.53572 .70394 m .53602 .70415 L .53664 .7005 L F
.376 .193 .502 r
.53572 .70394 m .53716 .7056 L .53602 .70415 L F
.53572 .70394 m .53547 .70681 L .53716 .7056 L F
0 0 .216 r
.53664 .7005 m .53602 .70415 L .53572 .70394 L F
.376 .193 .502 r
.53716 .7056 m .53572 .70394 L .53602 .70415 L F
.53716 .7056 m .53547 .70681 L .53572 .70394 L F
0 0 .396 r
.58241 .63069 m .58215 .62993 L .58106 .62795 L F
.896 .969 .655 r
.58079 .6322 m .58241 .63069 L .58159 .63411 L F
.58079 .6322 m .58215 .62993 L .58241 .63069 L F
.831 .632 .633 r
.59163 .64479 m .59352 .64583 L .59176 .64246 L F
.775 .608 .672 r
.58942 .64784 m .59352 .64583 L .59163 .64479 L F
.58942 .64784 m .59302 .64828 L .59352 .64583 L F
0 .045 .55 r
.5555 .63673 m .55617 .63724 L .55386 .63592 L F
.5555 .63673 m .55735 .63849 L .55617 .63724 L F
.515 .668 .932 r
.23842 .54997 m .23764 .55215 L .23573 .54938 L F
.23842 .54997 m .23959 .55176 L .23764 .55215 L F
.373 .576 .919 r
.50612 .65422 m .50911 .65558 L .50852 .6546 L F
.567 .218 .337 r
.44552 .62907 m .44309 .62786 L .44549 .62752 L F
.44552 .62907 m .44192 .6302 L .44309 .62786 L F
0 0 .498 r
.48176 .69512 m .48317 .69726 L .48494 .69516 L F
.658 .252 .265 r
.48597 .69734 m .48494 .69516 L .48317 .69726 L F
.747 .335 .269 r
.43506 .6232 m .437 .6241 L .43846 .62248 L F
.465 0 .065 r
.43846 .62248 m .437 .6241 L .44031 .62357 L F
0 .415 .783 r
.79591 .49411 m .79961 .49557 L .801 .49641 L F
.989 .746 .47 r
.79961 .49557 m .8007 .49904 L .801 .49641 L F
0 0 .371 r
.21393 .5866 m .21478 .58262 L .21426 .58417 L F
.776 .67 .747 r
.6725 .41435 m .67366 .41764 L .67011 .41712 L F
.787 .54 .563 r
.67011 .41712 m .67366 .41764 L .67367 .42024 L F
.687 .623 .779 r
.67592 .41485 m .67366 .41764 L .6725 .41435 L F
.397 .526 .869 r
.46579 .70912 m .46772 .71241 L .46972 .71232 L F
.456 0 0 r
.38681 .62697 m .39055 .62786 L .3882 .62704 L F
.888 .586 .078 r
.55328 .67463 m .55217 .67041 L .55308 .6716 L F
.06 .477 .889 r
.51578 .68349 m .51622 .68295 L .51619 .68326 L F
.214 0 .233 r
.51651 .64547 m .51407 .64823 L .51675 .64817 L F
.152 .676 .878 r
.51924 .64547 m .51651 .64547 L .51675 .64817 L F
0 0 0 r
.18556 .57836 m .18606 .57802 L .18524 .57871 L F
.324 .257 .626 r
.33785 .60727 m .33916 .60371 L .3371 .60502 L F
.539 .709 .95 r
.64025 .41746 m .63628 .41583 L .63933 .41589 L F
0 0 .558 r
.64146 .41879 m .64025 .41746 L .63933 .41589 L F
.97 .671 .395 r
.64033 .4202 m .64025 .41746 L .64146 .41879 L F
.452 .759 .995 r
.34448 .63497 m .34637 .63619 L .34669 .63363 L F
0 0 .347 r
.55672 .66488 m .557 .66596 L .55583 .66273 L F
0 0 .032 r
.55706 .6673 m .557 .66596 L .55672 .66488 L F
.55706 .6673 m .5571 .66852 L .557 .66596 L F
.491 .31 .562 r
.54485 .60996 m .54263 .61096 L .54475 .61269 L F
.54475 .61269 m .54263 .61096 L .54485 .60996 L F
.372 0 0 r
.39876 .62728 m .40114 .62718 L .40281 .62561 L F
.594 .136 .135 r
.40281 .62561 m .40114 .62718 L .40469 .62701 L F
.522 .197 .357 r
.40281 .62561 m .40469 .62701 L .40554 .62523 L F
.88 .604 .515 r
.48176 .69512 m .47921 .69212 L .47902 .69551 L F
0 0 .534 r
.56216 .63532 m .56127 .634 L .5612 .63366 L F
.56216 .63532 m .56181 .63694 L .56127 .634 L F
.387 .665 .969 r
.36133 .63517 m .36265 .63354 L .36035 .63397 L F
.36133 .63517 m .36416 .63531 L .36265 .63354 L F
.312 .177 .53 r
.53859 .62232 m .54085 .62334 L .54053 .62445 L F
.008 .073 .582 r
.54786 .6705 m .54825 .67391 L .54692 .67153 L F
.545 .096 .136 r
.62551 .47579 m .62905 .47535 L .62782 .47689 L F
.516 0 0 r
.62905 .47535 m .6302 .47675 L .62782 .47689 L F
.62905 .47535 m .6314 .47585 L .6302 .47675 L F
.337 .18 .515 r
.19431 .62173 m .19581 .61873 L .19448 .61924 L F
.478 .636 .924 r
.36561 .63668 m .36653 .63464 L .36416 .63531 L F
.36561 .63668 m .36772 .63655 L .36653 .63464 L F
0 0 0 r
.4703 .6302 m .47198 .62987 L .46961 .63074 L F
.4703 .6302 m .47341 .62824 L .47198 .62987 L F
.103 0 0 r
.52383 .72629 m .52705 .72394 L .5248 .72402 L F
.259 .422 .835 r
.24189 .5531 m .24127 .55499 L .23959 .55176 L F
.103 .241 .722 r
.24189 .5531 m .24323 .55687 L .24127 .55499 L F
.509 .293 .522 r
.24127 .55499 m .24323 .55687 L .24101 .55739 L F
.24127 .55499 m .24323 .55687 L .24101 .55739 L F
.589 .583 .813 r
.45343 .59338 m .45609 .59293 L .4544 .58928 L F
.377 .273 .608 r
.23299 .5922 m .23159 .59533 L .23158 .5928 L F
.662 .337 .413 r
.61946 .47623 m .62197 .47856 L .61946 .47801 L F
.628 .347 .473 r
.62201 .47616 m .62197 .47856 L .61946 .47623 L F
.644 .744 .922 r
.46571 .62494 m .46352 .62621 L .46218 .62423 L F
.448 .868 .739 r
.46213 .6267 m .46352 .62621 L .46571 .62494 L F
.656 .525 .692 r
.46352 .62621 m .46572 .62779 L .46571 .62494 L F
.46352 .62621 m .46327 .62853 L .46572 .62779 L F
.133 .681 .771 r
.39055 .62786 m .39274 .62761 L .39413 .62757 L F
.415 0 0 r
.39274 .62761 m .39652 .62782 L .39413 .62757 L F
.322 .227 .589 r
.37005 .6089 m .36797 .60747 L .36971 .60652 L F
.37005 .6089 m .36794 .61065 L .36797 .60747 L F
.51 .857 .993 r
.5243 .64321 m .52843 .64291 L .52712 .64197 L F
.399 .706 .984 r
.57623 .64021 m .57726 .63893 L .57547 .63834 L F
.57623 .64021 m .5789 .64026 L .57726 .63893 L F
.806 .852 .884 r
.64268 .47245 m .64458 .46904 L .64221 .47233 L F
.939 .571 .206 r
.64769 .44041 m .64958 .44334 L .64819 .44247 L F
.989 .824 .586 r
.64958 .44334 m .64879 .44619 L .64819 .44247 L F
.287 .411 .814 r
.46143 .70002 m .46303 .70363 L .46408 .70213 L F
.05 .082 .573 r
.46408 .70213 m .46303 .70363 L .46443 .7059 L F
.581 .41 .615 r
.52696 .70701 m .52919 .70402 L .52761 .70448 L F
.52696 .70701 m .52978 .70672 L .52919 .70402 L F
.548 .288 .474 r
.52978 .70672 m .52919 .70886 L .52696 .70701 L F
.52978 .70672 m .52919 .70886 L .52696 .70701 L F
.984 .816 .42 r
.59082 .63547 m .5918 .63429 L .59074 .63296 L F
.59082 .63547 m .59133 .63682 L .5918 .63429 L F
.618 .59 .8 r
.78833 .49872 m .7907 .49631 L .78844 .49631 L F
.78833 .49872 m .7923 .50038 L .7907 .49631 L F
.71 .565 .689 r
.78833 .49872 m .79161 .50133 L .7923 .50038 L F
.78833 .49872 m .78993 .50286 L .79161 .50133 L F
.436 .805 .994 r
.53311 .70716 m .53547 .70681 L .53121 .70661 L F
.716 .987 .868 r
.63781 .42063 m .63721 .42032 L .6343 .42244 L F
.738 .992 .857 r
.639 .41873 m .63781 .42063 L .64033 .4202 L F
.639 .41873 m .63721 .42032 L .63781 .42063 L F
.601 .654 .874 r
.19676 .6053 m .19587 .60427 L .194 .60446 L F
.19676 .6053 m .19781 .6073 L .19587 .60427 L F
.588 .606 .838 r
.19781 .6073 m .20029 .60799 L .19933 .60535 L F
.602 .444 .639 r
.1985 .60966 m .20029 .60799 L .19781 .6073 L F
.478 .268 .515 r
.64771 .43817 m .64769 .44041 L .65019 .43754 L F
.585 .264 .392 r
.40845 .62537 m .41072 .62719 L .41216 .62439 L F
.384 0 .083 r
.41072 .62719 m .4145 .62502 L .41216 .62439 L F
.488 .188 .383 r
.68609 .44665 m .68637 .44857 L .68326 .44882 L F
.565 .506 .748 r
.68751 .44342 m .68609 .44665 L .68485 .44331 L F
.68751 .44342 m .68847 .44616 L .68609 .44665 L F
.496 .263 .491 r
.68609 .44665 m .68833 .44851 L .68637 .44857 L F
.68609 .44665 m .68847 .44616 L .68833 .44851 L F
.55 .122 .181 r
.40469 .62701 m .40845 .62537 L .40554 .62523 L F
.40469 .62701 m .40704 .62726 L .40845 .62537 L F
.64 .225 .24 r
.40845 .62537 m .40704 .62726 L .41072 .62719 L F
.236 0 0 r
.38137 .64011 m .38053 .64118 L .37826 .64165 L F
.811 .803 .843 r
.60482 .44998 m .6007 .45144 L .60332 .44859 L F
.838 .807 .821 r
.60713 .44716 m .60482 .44998 L .60332 .44859 L F
.477 .298 .559 r
.54397 .64799 m .54618 .64751 L .54402 .64549 L F
.395 .095 .333 r
.57968 .4903 m .5825 .48779 L .58227 .48993 L F
.428 .196 .457 r
.58227 .48993 m .5825 .48779 L .58489 .48702 L F
0 0 0 r
.47198 .62987 m .47341 .62824 L .47517 .62713 L F
.565 .133 .179 r
.46327 .62853 m .46422 .62962 L .46572 .62779 L F
.46327 .62853 m .46257 .62975 L .46422 .62962 L F
.741 .986 .777 r
.54942 .67722 m .54835 .67872 L .55055 .67795 L F
.646 .306 .381 r
.51457 .67751 m .51727 .68096 L .517 .67807 L F
.107 .661 .745 r
.3902 .59502 m .38872 .59511 L .38646 .59534 L F
.234 0 0 r
.3902 .59502 m .39238 .5953 L .38872 .59511 L F
.285 .698 .972 r
.20349 .54256 m .20521 .54353 L .20142 .54249 L F
.327 .741 .978 r
.20349 .54256 m .20732 .54327 L .20521 .54353 L F
.962 .63 .319 r
.55397 .6776 m .55301 .67887 L .55271 .67675 L F
.55397 .6776 m .55461 .67999 L .55301 .67887 L F
.626 .458 .635 r
.52919 .70402 m .53139 .70375 L .53199 .70092 L F
.576 .407 .616 r
.52978 .70672 m .53121 .70661 L .52919 .70402 L F
.3 .105 .44 r
.21841 .62417 m .21649 .6274 L .21675 .62502 L F
0 .255 .632 r
.3751 .64183 m .37133 .63992 L .37301 .64134 L F
.256 .379 .797 r
.64433 .44868 m .64464 .45015 L .64298 .44635 L F
.599 .553 .774 r
.54984 .66414 m .55155 .66613 L .5504 .66229 L F
.636 .386 .523 r
.50615 .68282 m .50944 .68296 L .50902 .6806 L F
.237 .124 .515 r
.50902 .6806 m .51082 .68167 L .51118 .68036 L F
.50902 .6806 m .50944 .68296 L .51082 .68167 L F
.384 .443 .799 r
.53199 .70092 m .53241 .69722 L .5309 .69711 L F
.729 .71 .833 r
.53139 .70375 m .53366 .70114 L .53199 .70092 L F
.47 .179 .389 r
.78844 .49631 m .7907 .49631 L .7914 .49449 L F
.64 .641 .835 r
.68092 .41344 m .67965 .41751 L .67841 .41414 L F
.68092 .41344 m .68229 .41664 L .67965 .41751 L F
.654 .538 .71 r
.68229 .41664 m .67983 .42051 L .67965 .41751 L F
.89 .54 .378 r
.54409 .62782 m .54474 .62987 L .54596 .62795 L F
.54409 .62782 m .54474 .62987 L .54596 .62795 L F
0 0 .473 r
.55419 .63018 m .55499 .63157 L .55424 .63029 L F
.366 .681 .978 r
.55419 .63018 m .55539 .63142 L .55499 .63157 L F
.468 0 0 r
.67715 .42861 m .67897 .42623 L .67786 .42791 L F
.67715 .42861 m .67709 .42553 L .67897 .42623 L F
.67715 .42861 m .67517 .42769 L .67709 .42553 L F
.303 .733 .97 r
.67786 .42791 m .67979 .42874 L .67715 .42861 L F
.414 .252 .551 r
.23727 .58077 m .23701 .58357 L .23528 .58372 L F
.251 .011 .343 r
.23701 .58357 m .2345 .58641 L .23528 .58372 L F
.084 .268 .754 r
.52287 .67465 m .52515 .67666 L .52548 .6747 L F
.563 .385 .598 r
.48335 .67467 m .48574 .67467 L .48569 .67171 L F
.48335 .67467 m .48574 .67467 L .48569 .67171 L F
.45 .287 .568 r
.23954 .58 m .23758 .57832 L .23902 .57743 L F
.23954 .58 m .23727 .58077 L .23758 .57832 L F
0 .503 .715 r
.43308 .58381 m .43197 .58363 L .42943 .58328 L F
.778 .991 .885 r
.43371 .58212 m .43308 .58381 L .4354 .58333 L F
.43371 .58212 m .43197 .58363 L .43308 .58381 L F
.056 0 0 r
.39222 .58087 m .39451 .58061 L .39565 .58019 L F
0 0 0 r
.39565 .58019 m .39687 .58014 L .39813 .57907 L F
.39451 .58061 m .39687 .58014 L .39565 .58019 L F
.763 .76 .85 r
.66431 .42008 m .66616 .42293 L .66372 .4234 L F
.468 .628 .922 r
.66821 .42241 m .66616 .42293 L .66431 .42008 L F
.663 .436 .566 r
.58925 .48163 m .58722 .48428 L .58728 .48177 L F
.676 .618 .783 r
.58967 .48441 m .58848 .48769 L .58722 .48428 L F
.615 .353 .496 r
.58967 .48441 m .58907 .48548 L .58848 .48769 L F
.792 .677 .738 r
.58722 .48428 m .58848 .48769 L .58489 .48702 L F
.657 .148 .021 r
.58489 .48702 m .58848 .48769 L .58727 .48871 L F
.615 .353 .496 r
.58907 .48548 m .58727 .48871 L .58746 .48856 L F
.58907 .48548 m .58746 .48856 L .58848 .48769 L F
.663 .436 .566 r
.58925 .48163 m .59048 .48279 L .58722 .48428 L F
.615 .353 .496 r
.58907 .48548 m .5896 .48884 L .58727 .48871 L F
.58967 .48441 m .58966 .48514 L .58907 .48548 L F
.58966 .48514 m .5896 .48884 L .58907 .48548 L F
.663 .436 .566 r
.59048 .48279 m .5917 .48394 L .58957 .48453 L F
.635 .31 .403 r
.59323 .48422 m .58967 .48441 L .59268 .48487 L F
.719 .421 .472 r
.59323 .48422 m .59268 .48487 L .59267 .48486 L F
.635 .31 .403 r
.59323 .48422 m .59272 .4848 L .58967 .48441 L F
.5925 .48485 m .59042 .48475 L .58967 .48441 L F
.678 .455 .577 r
.59374 .48624 m .5896 .48884 L .58967 .48441 L F
.676 .618 .783 r
.58967 .48441 m .58722 .48428 L .5925 .48485 L F
.58967 .48441 m .5925 .48485 L .59268 .48487 L F
.635 .31 .403 r
.5934 .48489 m .5925 .48485 L .58967 .48441 L F
.719 .421 .472 r
.59323 .48422 m .59267 .48486 L .58925 .48163 L F
.635 .31 .403 r
.59323 .48422 m .5934 .48489 L .59272 .4848 L F
.663 .436 .566 r
.59267 .48486 m .59268 .48487 L .5925 .48485 L F
.635 .31 .403 r
.5934 .48489 m .59374 .48624 L .59042 .48475 L F
.663 .436 .566 r
.5917 .48394 m .59267 .48486 L .59052 .48463 L F
.59267 .48486 m .5925 .48485 L .59052 .48463 L F
.5917 .48394 m .59052 .48463 L .58957 .48453 L F
.59048 .48279 m .58957 .48453 L .58722 .48428 L F
.719 .421 .472 r
.59323 .48422 m .58925 .48163 L .59321 .48172 L F
.688 .696 .853 r
.68443 .42445 m .68095 .42366 L .6834 .42263 L F
.63 .646 .847 r
.68569 .42174 m .68443 .42445 L .6834 .42263 L F
.68569 .42174 m .68678 .42359 L .68443 .42445 L F
.903 .742 .672 r
.59006 .64139 m .59176 .64246 L .59046 .63902 L F
.883 .678 .621 r
.58864 .64469 m .59176 .64246 L .59006 .64139 L F
.58864 .64469 m .59163 .64479 L .59176 .64246 L F
.33 .205 .555 r
.22687 .60433 m .22692 .60685 L .22534 .60742 L F
.453 .232 .487 r
.22698 .60931 m .22534 .60742 L .22692 .60685 L F
.22698 .60931 m .22493 .60986 L .22534 .60742 L F
.405 .638 .951 r
.34859 .63046 m .3501 .63023 L .34708 .62988 L F
.74 .636 .744 r
.5504 .66229 m .55155 .66613 L .54779 .66622 L F
.845 .639 .623 r
.55155 .66613 m .54814 .66806 L .54779 .66622 L F
.55155 .66613 m .55075 .66917 L .54814 .66806 L F
.101 .203 .685 r
.53871 .66282 m .54065 .66498 L .54086 .66229 L F
.988 .727 .432 r
.52175 .68342 m .52048 .68001 L .5226 .68011 L F
.52175 .68342 m .52049 .6825 L .52048 .68001 L F
.99 .744 .46 r
.52175 .68342 m .52049 .68511 L .52049 .6825 L F
.466 .365 .655 r
.51708 .66267 m .51904 .66213 L .51665 .66005 L F
.51708 .66267 m .51904 .66213 L .51665 .66005 L F
.556 .537 .789 r
.68973 .42486 m .68771 .42741 L .68678 .42359 L F
.539 .662 .916 r
.56216 .63532 m .56342 .63741 L .56181 .63694 L F
.719 .66 .79 r
.44541 .5823 m .43989 .57789 L .44232 .57726 L F
.44541 .5823 m .44304 .5826 L .43989 .57789 L F
.61 .666 .879 r
.44752 .58094 m .44541 .5823 L .44232 .57726 L F
.347 0 .154 r
.47896 .61374 m .47641 .61547 L .47836 .61479 L F
0 0 0 r
.47836 .61479 m .48163 .61323 L .47896 .61374 L F
.548 .356 .573 r
.53049 .69518 m .5309 .69711 L .5327 .69497 L F
.067 .23 .723 r
.64032 .46378 m .63997 .46085 L .6389 .46207 L F
.635 .087 0 r
.63994 .46405 m .64032 .46378 L .6389 .46207 L F
.939 .608 .378 r
.55334 .65651 m .55408 .65989 L .55539 .66031 L F
.921 .531 .151 r
.55408 .65989 m .55583 .66273 L .55539 .66031 L F
.984 .711 .339 r
.58229 .63954 m .58146 .64052 L .58023 .64015 L F
0 0 0 r
.24348 .55677 m .24483 .55632 L .24683 .55548 L F
.557 .504 .752 r
.24636 .55432 m .24593 .55595 L .24483 .55632 L F
.539 0 0 r
.24683 .55548 m .24483 .55632 L .24917 .55654 L F
.154 0 0 r
.24519 .55875 m .24917 .55654 L .24483 .55632 L F
.557 .504 .752 r
.24593 .55595 m .24519 .55875 L .24483 .55632 L F
0 0 0 r
.24323 .55687 m .24483 .55632 L .24348 .55677 L F
.392 .089 .327 r
.20555 .59919 m .20675 .60051 L .20711 .5982 L F
.20555 .59919 m .20456 .60122 L .20675 .60051 L F
.425 .322 .633 r
.24058 .57134 m .23886 .575 L .23853 .57271 L F
.979 .855 .648 r
.64919 .43097 m .64832 .43206 L .64749 .43017 L F
.898 .936 .83 r
.64919 .43097 m .64976 .42733 L .6508 .42808 L F
.64919 .43097 m .64749 .43017 L .64976 .42733 L F
.97 .712 .487 r
.4705 .62119 m .47057 .62399 L .4721 .62256 L F
.647 .806 .959 r
.4705 .62119 m .4721 .62256 L .47417 .6216 L F
.4705 .62119 m .4721 .62256 L .47417 .6216 L F
.449 .464 .783 r
.34222 .61622 m .34324 .61975 L .34485 .61779 L F
.376 .473 .832 r
.34324 .61975 m .34597 .62135 L .34485 .61779 L F
.838 .807 .821 r
.60713 .44716 m .60332 .44859 L .60589 .44583 L F
.863 .856 .833 r
.60973 .44399 m .60713 .44716 L .60589 .44583 L F
.768 .467 .477 r
.53371 .68348 m .53345 .68548 L .52995 .68488 L F
.496 .223 .43 r
.53609 .68488 m .53345 .68548 L .53371 .68348 L F
.767 .548 .601 r
.48934 .67462 m .48574 .67467 L .48569 .67171 L F
.535 .42 .669 r
.48574 .67467 m .48659 .67248 L .48569 .67171 L F
.767 .548 .601 r
.48934 .67462 m .48569 .67171 L .48659 .67248 L F
.012 .071 .579 r
.5915 .61803 m .59169 .62138 L .59109 .62196 L F
0 0 0 r
.26 .7804 m .25963 .78044 L .25931 .77936 L F
.26 .7804 m .26003 .78154 L .25963 .78044 L F
.26 .7804 m .2622 .77912 L .26003 .78154 L F
.5 .383 .652 r
.24182 .56012 m .24199 .56324 L .24001 .56376 L F
.52 .455 .723 r
.24199 .56324 m .24289 .56584 L .24001 .56376 L F
.524 .455 .72 r
.24289 .56584 m .24092 .56694 L .24001 .56376 L F
0 0 .449 r
.67109 .44383 m .67214 .44462 L .67008 .44263 L F
.67109 .44383 m .67167 .446 L .67214 .44462 L F
.685 .349 .4 r
.49224 .72754 m .4894 .72908 L .489 .72711 L F
0 0 .109 r
.4894 .72908 m .48979 .72724 L .489 .72711 L F
.325 .181 .526 r
.22087 .61848 m .22091 .62104 L .21884 .62183 L F
.326 .146 .478 r
.22091 .62104 m .21841 .62417 L .21884 .62183 L F
.686 .881 .971 r
.42232 .57643 m .41811 .5768 L .42106 .57568 L F
.572 .872 .995 r
.42232 .57643 m .42317 .57489 L .42472 .5759 L F
.42232 .57643 m .42106 .57568 L .42317 .57489 L F
.828 .948 .595 r
.57968 .63491 m .58079 .6322 L .58159 .63411 L F
.708 .914 .966 r
.57702 .63505 m .5801 .63341 L .57968 .63491 L F
.828 .948 .595 r
.57968 .63491 m .5801 .63341 L .58079 .6322 L F
.428 .037 .194 r
.35392 .58944 m .35618 .58933 L .35766 .58685 L F
.367 0 .101 r
.35618 .58933 m .36002 .58676 L .35766 .58685 L F
.953 .616 .337 r
.55223 .65857 m .55334 .65651 L .55079 .65685 L F
.55223 .65857 m .55408 .65989 L .55334 .65651 L F
.035 .381 .845 r
.37237 .61664 m .37432 .61772 L .37401 .61879 L F
0 .179 .714 r
.37432 .61772 m .37602 .62073 L .37401 .61879 L F
.081 .521 .903 r
.23095 .54663 m .2304 .54725 L .22872 .5464 L F
.23095 .54663 m .23263 .54787 L .2304 .54725 L F
0 0 0 r
.52228 .68885 m .52176 .6897 L .51921 .69105 L F
.206 0 .18 r
.52526 .68617 m .52465 .68847 L .52228 .68885 L F
.386 0 .164 r
.52465 .68847 m .52176 .6897 L .52228 .68885 L F
.845 .802 .808 r
.48591 .72557 m .48441 .72401 L .48192 .72296 L F
.48591 .72557 m .4862 .726 L .48441 .72401 L F
.79 .79 .852 r
.48755 .72399 m .4862 .726 L .48591 .72557 L F
.795 .798 .854 r
.48441 .72401 m .4862 .726 L .48755 .72399 L F
.324 .257 .626 r
.33785 .60727 m .33932 .60693 L .33916 .60371 L F
.342 .328 .699 r
.33785 .60727 m .34002 .60914 L .33932 .60693 L F
.42 .332 .651 r
.33785 .60727 m .33838 .60989 L .34002 .60914 L F
.21 .734 .836 r
.62264 .44022 m .6255 .43984 L .62778 .43994 L F
.402 .317 .645 r
.19734 .61229 m .19773 .61464 L .19929 .61393 L F
.863 .988 .721 r
.19823 .61325 m .19734 .61229 L .19929 .61393 L F
.418 .318 .633 r
.19565 .61272 m .19773 .61464 L .19734 .61229 L F
.264 0 .242 r
.19565 .61272 m .19734 .61229 L .19669 .6116 L F
.418 .318 .633 r
.19565 .61272 m .19598 .61605 L .19773 .61464 L F
.611 .147 .127 r
.19734 .61229 m .19542 .61366 L .19355 .61238 L F
.19542 .61366 m .19524 .61379 L .1951 .61367 L F
.19542 .61366 m .1951 .61367 L .19355 .61238 L F
0 0 0 r
.1961 .61241 m .19524 .61379 L .19615 .61247 L F
.08 0 0 r
.19603 .61232 m .1961 .61241 L .19734 .61229 L F
.264 0 .242 r
.19669 .6116 m .19734 .61229 L .1985 .60966 L F
0 0 0 r
.19734 .61229 m .2009 .60968 L .1985 .60966 L F
.45 .881 .897 r
.1961 .61241 m .19643 .61208 L .19836 .61158 L F
0 0 0 r
.1961 .61241 m .19615 .61247 L .19643 .61208 L F
.08 0 0 r
.19355 .61238 m .1961 .61241 L .19603 .61232 L F
0 0 0 r
.19907 .61102 m .19836 .61158 L .2009 .60968 L F
.19734 .61229 m .1982 .6117 L .19907 .61102 L F
.1982 .6117 m .19836 .61158 L .19907 .61102 L F
.45 .881 .897 r
.1961 .61241 m .19836 .61158 L .19734 .61229 L F
.768 .719 .807 r
.19643 .61208 m .19701 .61245 L .20142 .61124 L F
.19701 .61245 m .20017 .61238 L .20142 .61124 L F
.19777 .61202 m .20142 .61124 L .19971 .61194 L F
.19643 .61208 m .19805 .61181 L .19777 .61202 L F
.19805 .61181 m .20142 .61124 L .19777 .61202 L F
.863 .988 .721 r
.19643 .61208 m .19524 .61379 L .19734 .61229 L F
.19643 .61208 m .19734 .61229 L .19823 .61325 L F
.768 .719 .807 r
.19701 .61245 m .19882 .61363 L .20017 .61238 L F
.19882 .61363 m .19929 .61393 L .19953 .61362 L F
.19882 .61363 m .19953 .61362 L .20142 .61124 L F
.602 .444 .639 r
.1985 .60966 m .2009 .60968 L .20029 .60799 L F
.596 .374 .549 r
.53282 .72136 m .53546 .721 L .5354 .71843 L F
.605 .681 .895 r
.52354 .64234 m .52199 .64472 L .52099 .64435 L F
.52354 .64234 m .52408 .64446 L .52199 .64472 L F
.492 .138 .293 r
.52199 .64472 m .52415 .6472 L .52153 .64757 L F
.52199 .64472 m .52408 .64446 L .52415 .6472 L F
.468 .275 .536 r
.5273 .65904 m .52491 .65989 L .52543 .657 L F
.576 .575 .815 r
.52368 .65614 m .5273 .65904 L .52543 .657 L F
0 0 0 r
.5402 .7095 m .54115 .70872 L .54227 .7066 L F
.759 .501 .544 r
.54115 .70872 m .54478 .70657 L .54227 .7066 L F
.682 .303 0 r
.5571 .66852 m .55819 .67083 L .55868 .67168 L F
.986 .787 .389 r
.55778 .67338 m .55868 .67168 L .55819 .67083 L F
.55778 .67338 m .55845 .67427 L .55868 .67168 L F
.481 .19 .394 r
.7914 .49449 m .79344 .49567 L .79345 .49278 L F
.7914 .49449 m .7907 .49631 L .79344 .49567 L F
.807 .544 .541 r
.53883 .64445 m .54096 .64239 L .5391 .64174 L F
.53883 .64445 m .54234 .64502 L .54096 .64239 L F
.854 .509 .4 r
.57694 .60162 m .57529 .60345 L .57508 .6008 L F
.57694 .60162 m .57688 .60509 L .57529 .60345 L F
.171 .371 .819 r
.64634 .46058 m .64744 .4599 L .64616 .45948 L F
0 0 0 r
.64549 .46239 m .64744 .4599 L .64634 .46058 L F
.987 .769 .524 r
.56172 .63063 m .56613 .63323 L .56399 .63187 L F
.464 .828 .571 r
.56399 .63187 m .56659 .62973 L .56799 .62865 L F
0 0 0 r
.56613 .63323 m .56659 .62973 L .56399 .63187 L F
.373 .814 .954 r
.48934 .67462 m .48854 .67416 L .48574 .67467 L F
.543 0 0 r
.48659 .67248 m .48854 .67416 L .48934 .67462 L F
.8 .571 .591 r
.57275 .62495 m .57581 .62496 L .5758 .62735 L F
.518 0 0 r
.57602 .62522 m .57642 .62525 L .57581 .62496 L F
.929 .647 .484 r
.57885 .62429 m .57917 .6267 L .57719 .62583 L F
.781 .282 0 r
.57917 .6267 m .57924 .62799 L .57719 .62583 L F
.928 .722 .237 r
.57748 .62614 m .57901 .62528 L .57719 .62583 L F
.57924 .62799 m .57901 .62539 L .57768 .62634 L F
.57923 .62787 m .57875 .62708 L .57901 .62528 L F
.57924 .62799 m .57875 .62708 L .57923 .62787 L F
.94 .604 .365 r
.57875 .62708 m .57717 .62653 L .57908 .62544 L F
0 .193 .708 r
.57875 .62708 m .57947 .62584 L .57822 .62621 L F
.57875 .62708 m .57822 .62621 L .57717 .62653 L F
0 0 .146 r
.57899 .62539 m .57976 .62485 L .57901 .62528 L F
.733 .253 0 r
.57907 .62542 m .57966 .62509 L .57908 .62544 L F
.57966 .62509 m .57977 .62504 L .57908 .62544 L F
.94 .604 .365 r
.57875 .62708 m .57908 .62544 L .58065 .62453 L F
0 0 .146 r
.57875 .62708 m .57966 .62509 L .57899 .62539 L F
.57966 .62509 m .57976 .62485 L .57899 .62539 L F
.733 .253 0 r
.57966 .62509 m .58065 .62453 L .57977 .62504 L F
0 0 .146 r
.58033 .62471 m .58065 .62453 L .58066 .62421 L F
.57976 .62485 m .58066 .62421 L .5807 .62279 L F
.57875 .62708 m .58066 .62421 L .57976 .62485 L F
.807 .741 .79 r
.5807 .62279 m .57908 .62544 L .57901 .62528 L F
0 0 .146 r
.57976 .62485 m .5807 .62279 L .57901 .62528 L F
.61 .618 .834 r
.5774 .62261 m .57885 .62429 L .57581 .62496 L F
.247 0 0 r
.57673 .62481 m .57885 .62429 L .57862 .6245 L F
.57581 .62496 m .57683 .62474 L .57673 .62481 L F
.57683 .62474 m .57885 .62429 L .57673 .62481 L F
.57581 .62496 m .57862 .6245 L .57682 .62495 L F
.61 .618 .834 r
.5774 .62261 m .57581 .62496 L .57653 .62495 L F
.934 .956 .765 r
.57562 .62252 m .5774 .62261 L .57653 .62495 L F
.61 .618 .834 r
.57653 .62495 m .57581 .62496 L .57642 .62525 L F
.934 .956 .765 r
.57637 .62507 m .57653 .62495 L .57642 .62525 L F
.57562 .62252 m .57653 .62495 L .57637 .62507 L F
.247 0 0 r
.57581 .62555 m .57686 .62619 L .5758 .62735 L F
.57581 .62496 m .57602 .62522 L .57581 .62555 L F
.57602 .62522 m .57686 .62619 L .57581 .62555 L F
.622 .795 .965 r
.57342 .62289 m .57614 .62503 L .57275 .62495 L F
.934 .956 .765 r
.57637 .62507 m .57642 .62525 L .57623 .6251 L F
.247 0 0 r
.57607 .62512 m .57816 .62493 L .57719 .62583 L F
.57581 .62496 m .57706 .62495 L .57607 .62512 L F
.57706 .62495 m .57816 .62493 L .57607 .62512 L F
.934 .956 .765 r
.57562 .62252 m .57637 .62507 L .57342 .62289 L F
.57637 .62507 m .57623 .6251 L .57342 .62289 L F
.622 .795 .965 r
.57614 .62503 m .57623 .6251 L .57611 .62509 L F
.518 0 0 r
.57275 .62495 m .57602 .62522 L .57581 .62496 L F
.622 .795 .965 r
.57614 .62503 m .57611 .62509 L .57275 .62495 L F
.247 0 0 r
.57602 .62522 m .57719 .62583 L .5767 .626 L F
.57581 .62496 m .57608 .62513 L .57602 .62522 L F
.57608 .62513 m .57719 .62583 L .57602 .62522 L F
.622 .795 .965 r
.57623 .6251 m .57642 .62525 L .57602 .62522 L F
.57608 .62513 m .57602 .62522 L .57581 .6252 L F
.57623 .6251 m .57602 .62522 L .57608 .62513 L F
.57623 .6251 m .57581 .6252 L .57275 .62495 L F
.247 0 0 r
.57682 .62495 m .57862 .6245 L .57816 .62493 L F
.698 .983 .846 r
.57976 .62173 m .57843 .62342 L .5774 .62261 L F
.57976 .62173 m .58072 .6216 L .57843 .62342 L F
.188 0 0 r
.57562 .62252 m .57976 .62173 L .5774 .62261 L F
.57562 .62252 m .57899 .62245 L .57976 .62173 L F
.172 .139 .577 r
.57562 .62252 m .57715 .62002 L .57899 .62245 L F
.807 .741 .79 r
.5807 .62279 m .57899 .62245 L .57908 .62544 L F
.733 .253 0 r
.57794 .62119 m .57908 .62544 L .57899 .62245 L F
.57794 .62119 m .58065 .62453 L .57907 .62542 L F
0 0 .146 r
.57875 .62708 m .58065 .62453 L .58033 .62471 L F
.928 .722 .237 r
.57768 .62634 m .57901 .62528 L .57748 .62614 L F
.57901 .62539 m .57901 .62528 L .57768 .62634 L F
.27 .127 .495 r
.57901 .62528 m .57908 .62544 L .57719 .62583 L F
.232 .744 .87 r
.57719 .62583 m .57908 .62544 L .57819 .62547 L F
.57719 .62583 m .57819 .62547 L .57601 .62556 L F
.247 0 0 r
.5767 .626 m .57719 .62583 L .57686 .62619 L F
.201 0 .176 r
.51726 .65088 m .52007 .6483 L .51884 .65025 L F
.71 .984 .814 r
.51818 .64973 m .51691 .65128 L .516 .6518 L F
.51691 .65128 m .51642 .65188 L .516 .6518 L F
0 0 0 r
.516 .6518 m .51726 .65088 L .51843 .65041 L F
.516 .6518 m .51843 .65041 L .51884 .65025 L F
.863 .856 .833 r
.60973 .44399 m .60589 .44583 L .60843 .44289 L F
.867 .879 .843 r
.61203 .44119 m .60973 .44399 L .60843 .44289 L F
.4 .047 .245 r
.37609 .60183 m .37539 .60358 L .37337 .60354 L F
.384 .031 .238 r
.37762 .60279 m .37609 .60183 L .37814 .60104 L F
.37762 .60279 m .37539 .60358 L .37609 .60183 L F
.745 .677 .785 r
.53203 .7237 m .53282 .72136 L .53072 .7242 L F
.53203 .7237 m .53282 .72136 L .53072 .7242 L F
.634 .556 .749 r
.53203 .7237 m .53546 .721 L .53282 .72136 L F
.78 .286 .037 r
.5533 .63374 m .55187 .63357 L .54967 .63111 L F
.797 .315 .067 r
.5533 .63374 m .55259 .63475 L .55187 .63357 L F
.941 .577 .207 r
.5533 .63374 m .55386 .63592 L .55259 .63475 L F
.914 .976 .777 r
.63464 .44942 m .63621 .44554 L .63409 .44694 L F
.969 .931 .68 r
.56006 .67756 m .55819 .67896 L .5588 .67961 L F
.889 .523 .05 r
.55845 .67427 m .55927 .67681 L .56006 .67756 L F
.972 .924 .675 r
.55927 .67681 m .55819 .67896 L .56006 .67756 L F
.668 .495 .642 r
.51874 .72452 m .51872 .72697 L .52114 .72407 L F
.685 .349 .4 r
.49224 .72754 m .49324 .72985 L .4894 .72908 L F
.412 .223 .512 r
.49368 .72918 m .49224 .72754 L .49362 .7261 L F
.49368 .72918 m .49324 .72985 L .49224 .72754 L F
.751 .607 .698 r
.54426 .67776 m .54205 .68025 L .54084 .67663 L F
.792 .475 .452 r
.54426 .67776 m .54458 .67958 L .54205 .68025 L F
.909 .713 .626 r
.55468 .69097 m .55687 .68874 L .55453 .68932 L F
.55468 .69097 m .55647 .69172 L .55687 .68874 L F
.68 .428 .534 r
.60138 .47892 m .60152 .48119 L .60011 .48146 L F
.666 .417 .535 r
.60527 .48058 m .60138 .47892 L .60579 .47888 L F
.60527 .48058 m .60152 .48119 L .60138 .47892 L F
.831 .7 .719 r
.4777 .69234 m .47902 .69551 L .47921 .69212 L F
.97 .719 .499 r
.5642 .63487 m .56342 .63741 L .56216 .63532 L F
.27 0 0 r
.40489 .63618 m .4034 .63767 L .40112 .63801 L F
.219 0 0 r
.40718 .63586 m .4034 .63767 L .40489 .63618 L F
0 0 .009 r
.51884 .65025 m .52007 .6483 L .52153 .64757 L F
.772 .638 .713 r
.59081 .65142 m .59302 .64828 L .58942 .64784 L F
.488 .082 .196 r
.39837 .59226 m .39462 .59445 L .39525 .5931 L F
.39837 .59226 m .39701 .59447 L .39462 .59445 L F
.063 0 0 r
.39903 .59338 m .39837 .59226 L .40046 .59197 L F
.39903 .59338 m .39701 .59447 L .39837 .59226 L F
.244 0 0 r
.41347 .63424 m .41433 .63514 L .41185 .63523 L F
.41347 .63424 m .4158 .634 L .41433 .63514 L F
0 0 .494 r
.54967 .63111 m .55056 .63202 L .55424 .63029 L F
.54967 .63111 m .55187 .63357 L .55056 .63202 L F
.649 .916 .979 r
.21289 .58071 m .21425 .5774 L .21257 .57826 L F
.393 .678 .974 r
.33911 .62784 m .3415 .62799 L .33979 .62644 L F
.33911 .62784 m .3415 .62799 L .33979 .62644 L F
.058 0 .017 r
.52746 .68528 m .52465 .68847 L .52526 .68617 L F
.266 .392 .805 r
.436 .57394 m .43485 .5786 L .43452 .57747 L F
.596 .615 .841 r
.43858 .57484 m .43764 .57861 L .43485 .5786 L F
.937 .677 .518 r
.52916 .72595 m .53072 .7242 L .52705 .72394 L F
.52916 .72595 m .53081 .72698 L .53072 .7242 L F
0 .072 .615 r
.44461 .62415 m .44549 .62752 L .44789 .62492 L F
.662 .472 .616 r
.44789 .62492 m .45065 .62534 L .45123 .62497 L F
.501 .305 .545 r
.44789 .62492 m .45016 .62671 L .45065 .62534 L F
.44789 .62492 m .44789 .62735 L .45016 .62671 L F
.366 .833 .889 r
.47906 .68473 m .47626 .6855 L .47722 .68475 L F
0 .241 .753 r
.47626 .6855 m .47886 .68781 L .47722 .68475 L F
.885 .846 .801 r
.61419 .43806 m .61068 .43992 L .61276 .43676 L F
.61419 .43806 m .61203 .44119 L .61068 .43992 L F
.853 .829 .823 r
.61654 .43511 m .61419 .43806 L .61276 .43676 L F
.507 .155 .304 r
.24275 .56737 m .24092 .56694 L .24289 .56584 L F
.24275 .56737 m .23983 .56865 L .24092 .56694 L F
0 0 0 r
.53787 .71541 m .53896 .71419 L .54013 .71256 L F
.479 .814 .999 r
.62031 .45258 m .61968 .45174 L .61793 .45237 L F
.62031 .45258 m .61968 .45174 L .61682 .45226 L F
.372 .13 .411 r
.61886 .45336 m .62149 .45109 L .61968 .45174 L F
.62149 .45109 m .62251 .45021 L .61968 .45174 L F
.479 .814 .999 r
.61793 .45237 m .61968 .45174 L .61682 .45226 L F
.707 .719 .859 r
.47841 .7375 m .48024 .73772 L .47915 .73389 L F
.741 .913 .952 r
.48024 .73772 m .48413 .73574 L .48274 .73511 L F
.999 .81 .469 r
.56058 .63291 m .55908 .63081 L .55863 .63213 L F
.56058 .63291 m .56172 .63063 L .55908 .63081 L F
0 0 0 r
.42103 .6133 m .4228 .6129 L .42397 .61253 L F
0 0 .455 r
.42103 .6133 m .42231 .61455 L .4228 .6129 L F
.42103 .6133 m .42119 .61608 L .42231 .61455 L F
.786 .894 .921 r
.58387 .47239 m .58301 .47322 L .58175 .47219 L F
.98 .819 .61 r
.58175 .47219 m .58301 .47322 L .58237 .47554 L F
.583 .342 .517 r
.49677 .69501 m .49911 .69723 L .49671 .69713 L F
.623 .336 .462 r
.49953 .69507 m .49911 .69723 L .49677 .69501 L F
.75 .554 .63 r
.48727 .72144 m .49055 .72364 L .48964 .72108 L F
.48727 .72144 m .48755 .72399 L .49055 .72364 L F
.48727 .72144 m .49055 .72364 L .48964 .72108 L F
.48727 .72144 m .48755 .72399 L .49055 .72364 L F
.583 .393 .59 r
.49349 .72121 m .49055 .72364 L .48964 .72108 L F
.562 .841 .997 r
.49349 .72121 m .48964 .72108 L .49195 .72023 L F
0 0 .412 r
.49055 .72364 m .49195 .72023 L .48964 .72108 L F
.583 .393 .59 r
.49349 .72121 m .49331 .72411 L .49055 .72364 L F
0 0 .412 r
.49055 .72364 m .49185 .72338 L .49195 .72023 L F
.11 .608 .903 r
.49331 .72411 m .49185 .72338 L .49055 .72364 L F
.943 .673 .495 r
.65155 .42627 m .6508 .42808 L .64976 .42733 L F
.65155 .42627 m .64976 .42733 L .65084 .42685 L F
.879 .753 .719 r
.54796 .65076 m .54828 .65057 L .54618 .64751 L F
.768 .422 .401 r
.48389 .72208 m .48755 .72399 L .48727 .72144 L F
.885 .75 .708 r
.67794 .42324 m .67897 .42623 L .67709 .42553 L F
.776 .702 .781 r
.68095 .42366 m .67897 .42623 L .67794 .42324 L F
.69 .277 .258 r
.67897 .42623 m .68111 .42812 L .67786 .42791 L F
.176 0 .269 r
.2313 .59801 m .22889 .60091 L .22913 .59874 L F
.644 .355 .466 r
.62201 .47616 m .62499 .47737 L .62197 .47856 L F
.62201 .47616 m .62551 .47579 L .62499 .47737 L F
.236 .043 .403 r
.21423 .63291 m .21237 .63607 L .21275 .63371 L F
.827 .75 .779 r
.63997 .46085 m .64332 .46205 L .64119 .46008 L F
.601 .054 0 r
.34708 .62988 m .34352 .62704 L .34369 .63021 L F
.802 .5 .477 r
.57694 .4896 m .57968 .4903 L .57913 .49252 L F
.498 .183 .362 r
.57968 .4903 m .58157 .49189 L .57913 .49252 L F
.57968 .4903 m .58227 .48993 L .58157 .49189 L F
.599 .918 .975 r
.41607 .5845 m .41497 .58594 L .41746 .58472 L F
.41607 .5845 m .41359 .58553 L .41497 .58594 L F
0 0 0 r
.40612 .58948 m .40358 .59081 L .4028 .59107 L F
.40924 .5883 m .4079 .58899 L .40612 .58948 L F
.4079 .58899 m .40358 .59081 L .40612 .58948 L F
.829 .769 .795 r
.56704 .48983 m .57035 .49058 L .56816 .49324 L F
.702 .563 .694 r
.57035 .49058 m .57088 .49379 L .56816 .49324 L F
.595 .442 .644 r
.57294 .49072 m .57088 .49379 L .57035 .49058 L F
.568 .428 .65 r
.56659 .62973 m .56847 .6268 L .56799 .62865 L F
.55 .799 .991 r
.34448 .63497 m .344 .63657 L .34637 .63619 L F
0 0 0 r
.38764 .64005 m .38709 .6398 L .38942 .63952 L F
.38764 .64005 m .38461 .64113 L .38709 .6398 L F
.803 .879 .902 r
.58877 .61256 m .59091 .61276 L .58956 .61149 L F
0 0 0 r
.59009 .61499 m .58886 .61622 L .59091 .61276 L F
.59009 .61499 m .59091 .61276 L .58877 .61256 L F
.902 .931 .824 r
.59091 .61276 m .59196 .60926 L .58956 .61149 L F
.59091 .61276 m .59298 .60998 L .59196 .60926 L F
.336 .125 .438 r
.20338 .65071 m .2029 .6528 L .20153 .65397 L F
.057 0 0 r
.20654 .64823 m .20552 .65007 L .20338 .65071 L F
.222 .03 .396 r
.20552 .65007 m .2029 .6528 L .20338 .65071 L F
.587 .618 .85 r
.43798 .5855 m .43899 .58606 L .43837 .58458 L F
.673 .665 .835 r
.43837 .58458 m .43899 .58606 L .44311 .58489 L F
.587 .618 .85 r
.43798 .5855 m .43837 .58458 L .4354 .58333 L F
.891 .891 .823 r
.61882 .43208 m .61537 .434 L .61777 .43121 L F
.61882 .43208 m .61654 .43511 L .61537 .434 L F
.673 .891 .532 r
.6202 .42983 m .61882 .43208 L .61777 .43121 L F
.636 .251 0 r
.46442 .69983 m .46488 .70066 L .46321 .69749 L F
.683 .139 0 r
.46542 .70208 m .46488 .70066 L .46442 .69983 L F
.701 .282 .247 r
.50648 .72058 m .5099 .72095 L .5078 .71929 L F
.154 .357 .812 r
.59009 .61499 m .5915 .61803 L .58886 .61622 L F
.636 .655 .852 r
.58942 .64784 m .58561 .64559 L .58705 .64848 L F
.853 .829 .823 r
.61654 .43511 m .61276 .43676 L .61537 .434 L F
.85 .833 .829 r
.51512 .65199 m .51346 .65373 L .51186 .65447 L F
.51512 .65199 m .51186 .65447 L .51425 .65364 L F
.395 .393 .738 r
.46572 .62779 m .46815 .62667 L .46571 .62494 L F
.004 0 0 r
.46572 .62779 m .46422 .62962 L .46815 .62667 L F
.09 0 0 r
.51205 .68555 m .5089 .68601 L .51004 .68559 L F
0 .145 .68 r
.66848 .42309 m .66872 .42404 L .66821 .42241 L F
.66848 .42309 m .67122 .4266 L .66872 .42404 L F
0 .487 .822 r
.20909 .59496 m .20574 .59373 L .20726 .59543 L F
.474 .323 .595 r
.20711 .5982 m .20909 .59496 L .20726 .59543 L F
.384 0 .083 r
.41072 .62719 m .41316 .62695 L .4145 .62502 L F
.206 0 0 r
.4145 .62502 m .41536 .62624 L .4167 .62439 L F
.4145 .62502 m .41316 .62695 L .41536 .62624 L F
0 .257 .767 r
.65029 .43498 m .65022 .43381 L .64832 .43206 L F
0 0 .053 r
.65029 .43498 m .65047 .43497 L .65022 .43381 L F
.65029 .43498 m .65019 .43754 L .65047 .43497 L F
0 0 .043 r
.20809 .64473 m .20743 .6472 L .20654 .64823 L F
0 0 0 r
.20636 .64917 m .20654 .64823 L .20743 .6472 L F
.20636 .64917 m .20552 .65007 L .20654 .64823 L F
.867 .879 .843 r
.61203 .44119 m .60843 .44289 L .61068 .43992 L F
.953 .873 .721 r
.62418 .43094 m .6253 .43223 L .62681 .42863 L F
.86 .915 .867 r
.62559 .42771 m .62681 .42863 L .62944 .42575 L F
.6 .709 .92 r
.20092 .59407 m .20151 .59173 L .19979 .59214 L F
.20092 .59407 m .20319 .59379 L .20151 .59173 L F
.485 .189 .388 r
.517 .67807 m .51982 .67883 L .52043 .6775 L F
.981 .747 .339 r
.51982 .67883 m .52048 .68001 L .52043 .6775 L F
.846 .683 .679 r
.46094 .69279 m .46111 .695 L .46358 .69502 L F
.834 .371 0 r
.46186 .69666 m .46321 .69749 L .46111 .695 L F
.986 .776 .538 r
.46358 .69502 m .46186 .69666 L .46111 .695 L F
.46358 .69502 m .46321 .69749 L .46186 .69666 L F
.286 .57 .936 r
.46419 .69371 m .46358 .69502 L .46094 .69279 L F
.986 .776 .538 r
.46186 .69666 m .46358 .69502 L .46419 .69371 L F
.46186 .69666 m .46321 .69749 L .46358 .69502 L F
0 .001 .575 r
.53136 .64179 m .53208 .64125 L .52974 .64052 L F
.418 .222 .506 r
.33871 .59856 m .34068 .598 L .34092 .59551 L F
.466 .353 .642 r
.33906 .60114 m .34068 .598 L .33871 .59856 L F
.765 .746 .836 r
.45703 .58563 m .45749 .58725 L .45495 .58675 L F
.593 .64 .867 r
.45948 .58533 m .45749 .58725 L .45703 .58563 L F
0 0 0 r
.45948 .58533 m .45874 .5884 L .45749 .58725 L F
.338 .342 .717 r
.45874 .5884 m .45865 .59008 L .45749 .58725 L F
.867 .747 .729 r
.67554 .45523 m .67279 .4544 L .67422 .45171 L F
0 .311 .803 r
.67503 .45678 m .67279 .4544 L .67554 .45523 L F
.712 .676 .813 r
.67758 .45263 m .67554 .45523 L .67422 .45171 L F
.571 .471 .703 r
.67758 .45263 m .67831 .45546 L .67554 .45523 L F
.569 .381 .587 r
.67747 .45835 m .67468 .45909 L .67498 .45768 L F
.67572 .45681 m .67498 .45768 L .67525 .45639 L F
.67747 .45835 m .67498 .45768 L .67572 .45681 L F
.117 0 0 r
.67554 .45523 m .67686 .45548 L .67503 .45678 L F
.67686 .45548 m .67699 .4555 L .67666 .45572 L F
.67686 .45548 m .67666 .45572 L .67503 .45678 L F
.67554 .45523 m .67831 .45546 L .67699 .4555 L F
.657 .612 .792 r
.7907 .49631 m .7923 .50038 L .79458 .49913 L F
.016 0 0 r
.39813 .57907 m .39902 .57945 L .40028 .57891 L F
.39813 .57907 m .39687 .58014 L .39902 .57945 L F
.213 0 .219 r
.2145 .57509 m .21668 .57425 L .21719 .5722 L F
.195 .06 .459 r
.21719 .5722 m .21888 .57162 L .21906 .56872 L F
.015 0 .144 r
.21719 .5722 m .21796 .57344 L .21888 .57162 L F
.21719 .5722 m .21668 .57425 L .21796 .57344 L F
.72 .533 .636 r
.56816 .49324 m .56478 .49639 L .5665 .49198 L F
.56816 .49324 m .56593 .49603 L .56478 .49639 L F
.56816 .49324 m .56817 .49613 L .56593 .49603 L F
.829 .769 .795 r
.56704 .48983 m .56816 .49324 L .5665 .49198 L F
.725 .551 .654 r
.57088 .49379 m .56817 .49613 L .56816 .49324 L F
.697 .831 .947 r
.53547 .70681 m .5388 .70664 L .53716 .7056 L F
.801 .889 .908 r
.18524 .57871 m .18458 .57699 L .18347 .57828 L F
.18524 .57871 m .18606 .57802 L .18458 .57699 L F
.796 .615 .657 r
.67983 .42051 m .68095 .42366 L .67794 .42324 L F
.654 .538 .71 r
.68229 .41664 m .68307 .42055 L .67983 .42051 L F
.637 .52 .703 r
.68307 .42055 m .68095 .42366 L .67983 .42051 L F
.128 .651 .881 r
.2093 .54308 m .21316 .54368 L .21111 .54391 L F
.405 .491 .834 r
.19933 .60535 m .20029 .60799 L .20168 .60635 L F
.469 .37 .66 r
.20029 .60799 m .20288 .6079 L .20168 .60635 L F
.20029 .60799 m .2009 .60968 L .20288 .6079 L F
.516 .515 .793 r
.54013 .71256 m .54115 .70872 L .5402 .7095 L F
.54013 .71256 m .54271 .71196 L .54115 .70872 L F
.811 .624 .649 r
.53896 .71419 m .54271 .71196 L .54013 .71256 L F
.175 .562 .934 r
.3777 .62112 m .37725 .62208 L .37602 .62073 L F
.3777 .62112 m .37919 .62259 L .37725 .62208 L F
.508 .22 .412 r
.62499 .47737 m .62551 .47579 L .62782 .47689 L F
.037 .607 .723 r
.21316 .54368 m .21525 .5436 L .21714 .54357 L F
.246 0 0 r
.21811 .54339 m .21946 .54342 L .22069 .5425 L F
.229 0 0 r
.21563 .54359 m .21926 .54302 L .21714 .54357 L F
.21525 .5436 m .21633 .54344 L .21563 .54359 L F
.21633 .54344 m .21926 .54302 L .21563 .54359 L F
.21525 .5436 m .21731 .54366 L .21926 .54302 L F
.246 0 0 r
.21731 .54366 m .22135 .542 L .21926 .54302 L F
.21731 .54366 m .22069 .5425 L .21953 .54275 L F
.897 .572 .424 r
.22135 .542 m .21946 .54342 L .22158 .54308 L F
.228 .685 .949 r
.21774 .54273 m .22089 .54346 L .21946 .54342 L F
.103 .624 .883 r
.21946 .54342 m .22114 .54378 L .22158 .54308 L F
.414 .63 .943 r
.22158 .54308 m .22293 .54495 L .22177 .54278 L F
.22158 .54308 m .22494 .545 L .22293 .54495 L F
.103 .624 .883 r
.22114 .54378 m .2232 .54421 L .22158 .54308 L F
.414 .63 .943 r
.22158 .54308 m .22177 .54278 L .22135 .542 L F
.228 .685 .949 r
.22089 .54346 m .22158 .54362 L .21946 .54342 L F
.246 0 0 r
.21731 .54366 m .21946 .54342 L .21811 .54339 L F
.21953 .54275 m .22069 .5425 L .22135 .542 L F
.845 .693 .693 r
.53308 .65416 m .53367 .65684 L .53215 .65632 L F
.848 .488 .371 r
.53367 .65684 m .53372 .65913 L .53215 .65632 L F
.37 .379 .739 r
.53564 .656 m .53367 .65684 L .53308 .65416 L F
.197 0 .35 r
.53564 .656 m .53372 .65913 L .53367 .65684 L F
.668 .705 .875 r
.44575 .58485 m .44873 .58631 L .44712 .58491 L F
.545 .593 .853 r
.45185 .58007 m .45351 .58297 L .45042 .58178 L F
.505 .397 .665 r
.44873 .58631 m .45152 .58108 L .44712 .58491 L F
.44873 .58631 m .45087 .58629 L .45152 .58108 L F
.486 .336 .602 r
.37098 .61252 m .36794 .61065 L .37005 .6089 L F
.37098 .61252 m .36857 .61338 L .36794 .61065 L F
.308 .479 .866 r
.38172 .62337 m .38079 .62524 L .37919 .62259 L F
.569 .795 .985 r
.38172 .62337 m .38309 .62462 L .38079 .62524 L F
.645 .727 .909 r
.79458 .49913 m .79816 .50017 L .79678 .49796 L F
.652 .644 .829 r
.79816 .50017 m .8007 .49904 L .79678 .49796 L F
.591 .34 .505 r
.59577 .48184 m .59323 .48422 L .59321 .48172 L F
.731 .495 .57 r
.68637 .44857 m .68268 .45107 L .68326 .44882 L F
.356 .683 .979 r
.54645 .66584 m .54779 .66622 L .54747 .66513 L F
.715 .347 .351 r
.54779 .66622 m .54814 .66806 L .54645 .66584 L F
.54779 .66622 m .54814 .66806 L .54645 .66584 L F
.965 .759 .319 r
.59087 .6268 m .59138 .63021 L .59171 .62779 L F
.401 .482 .827 r
.37095 .61439 m .3699 .61666 L .36857 .61338 L F
.489 .587 .879 r
.37095 .61439 m .37237 .61664 L .3699 .61666 L F
0 0 0 r
.47983 .68985 m .47921 .69212 L .47991 .68915 L F
.817 .83 .86 r
.47983 .68985 m .47921 .69212 L .4777 .69234 L F
.831 .7 .719 r
.4777 .69234 m .47921 .69212 L .47983 .68985 L F
.512 0 0 r
.56058 .64004 m .55938 .63971 L .55735 .63849 L F
.554 .29 .47 r
.79345 .49278 m .79572 .49433 L .79593 .49239 L F
.79345 .49278 m .79344 .49567 L .79572 .49433 L F
.669 .494 .639 r
.58728 .48177 m .58722 .48428 L .58479 .48458 L F
.28 0 0 r
.36797 .58524 m .37031 .58511 L .37199 .58396 L F
.32 0 0 r
.37031 .58511 m .37416 .58403 L .37199 .58396 L F
.763 .76 .85 r
.66431 .42008 m .66372 .4234 L .66252 .42214 L F
.996 .812 .455 r
.66372 .4234 m .66287 .42451 L .66252 .42214 L F
.66372 .4234 m .66365 .42578 L .66287 .42451 L F
.057 0 0 r
.6314 .47585 m .63237 .47611 L .6302 .47675 L F
.6314 .47585 m .63399 .47556 L .63237 .47611 L F
.632 .854 .984 r
.5226 .68011 m .52048 .68001 L .52244 .67902 L F
.77 .392 .34 r
.58204 .60046 m .58477 .59933 L .58155 .59827 L F
.58204 .60046 m .58381 .60098 L .58477 .59933 L F
.713 .323 .307 r
.58381 .60098 m .58661 .60149 L .58477 .59933 L F
.3 .555 .924 r
.42881 .57436 m .42993 .57703 L .42659 .57495 L F
.42881 .57436 m .43045 .57637 L .42993 .57703 L F
.865 .653 .614 r
.50956 .72311 m .5124 .72138 L .5099 .72095 L F
.50956 .72311 m .51177 .72399 L .5124 .72138 L F
.778 .959 .927 r
.54779 .66622 m .54829 .66382 L .54747 .66513 L F
.918 .521 .161 r
.54779 .66622 m .54684 .66715 L .54829 .66382 L F
.54779 .66622 m .54814 .66806 L .54684 .66715 L F
.725 .551 .654 r
.57088 .49379 m .57142 .49558 L .56817 .49613 L F
.595 .442 .644 r
.57294 .49072 m .57438 .49281 L .57088 .49379 L F
.449 .386 .695 r
.57397 .4958 m .57088 .49379 L .57438 .49281 L F
.57397 .4958 m .57142 .49558 L .57088 .49379 L F
.535 .252 .433 r
.48027 .70383 m .48237 .70565 L .48006 .70609 L F
.48027 .70383 m .48288 .70359 L .48237 .70565 L F
.797 .524 .525 r
.48006 .70609 m .48027 .70383 L .47643 .7032 L F
.592 .54 .765 r
.48027 .70383 m .48288 .70359 L .48176 .70005 L F
.535 .252 .433 r
.48027 .70383 m .48237 .70565 L .48006 .70609 L F
.48027 .70383 m .48288 .70359 L .48237 .70565 L F
.873 .898 .847 r
.62743 .44299 m .62505 .44661 L .62692 .4433 L F
.62743 .44299 m .62391 .44552 L .62505 .44661 L F
.85 .68 .672 r
.62391 .44552 m .62546 .44838 L .62505 .44661 L F
.824 .605 .607 r
.62862 .42006 m .6307 .4186 L .62722 .41718 L F
.779 .52 .545 r
.62862 .42006 m .63098 .41987 L .6307 .4186 L F
.644 .518 .695 r
.63098 .41987 m .63398 .41732 L .6307 .4186 L F
.637 .52 .703 r
.68307 .42055 m .6834 .42263 L .68095 .42366 L F
.662 .349 .433 r
.37539 .60358 m .37196 .60536 L .37337 .60354 L F
.504 .333 .582 r
.5503 .65394 m .54931 .65706 L .54736 .65565 L F
.5503 .65394 m .55079 .65685 L .54931 .65706 L F
0 0 .254 r
.55084 .6552 m .55079 .65685 L .5503 .65394 L F
.839 .694 .703 r
.58965 .46428 m .58584 .46609 L .58777 .46301 L F
.58965 .46428 m .5888 .46668 L .58584 .46609 L F
.804 .768 .82 r
.59207 .46152 m .58965 .46428 L .58777 .46301 L F
.911 .606 .456 r
.46961 .7095 m .46749 .70706 L .46826 .70899 L F
.976 .704 .447 r
.46826 .70899 m .46972 .71232 L .46961 .7095 L F
.774 .382 .312 r
.5091 .72407 m .50791 .72602 L .50561 .72337 L F
.667 .826 .395 r
.50956 .72311 m .50791 .72602 L .5091 .72407 L F
.125 .627 .904 r
.18581 .54157 m .18783 .5418 L .18947 .5425 L F
.278 .724 .961 r
.18783 .5418 m .19163 .54249 L .18947 .5425 L F
0 .003 .579 r
.56403 .64348 m .5648 .64458 L .56339 .64118 L F
.543 .36 .583 r
.49571 .72333 m .49331 .72411 L .49349 .72121 L F
.676 .543 .696 r
.49552 .71822 m .49627 .72125 L .49349 .72121 L F
.646 .349 .454 r
.49627 .72125 m .49571 .72333 L .49349 .72121 L F
.77 .83 .898 r
.51809 .72911 m .51402 .73288 L .51293 .73157 L F
.422 .641 .947 r
.51402 .73288 m .51504 .73114 L .51293 .73157 L F
.51402 .73288 m .51626 .73316 L .51504 .73114 L F
.371 .834 .896 r
.40651 .57849 m .40889 .57789 L .41018 .57799 L F
.401 .841 .939 r
.40889 .57789 m .41245 .5776 L .41018 .57799 L F
.707 .719 .859 r
.47841 .7375 m .47915 .73389 L .47767 .73612 L F
.621 .664 .87 r
.47463 .70545 m .47827 .70707 L .47641 .70578 L F
.629 .827 .976 r
.47641 .70578 m .47827 .70707 L .48006 .70609 L F
.48 .283 .534 r
.51923 .66489 m .51708 .66267 L .51904 .66213 L F
.51923 .66489 m .51694 .66553 L .51708 .66267 L F
.719 .491 .579 r
.51563 .66474 m .51904 .66213 L .51708 .66267 L F
.873 .795 .77 r
.58942 .64784 m .59163 .64479 L .58864 .64469 L F
.462 0 .049 r
.4279 .63113 m .42624 .63272 L .42388 .63263 L F
.314 0 0 r
.42964 .63158 m .4279 .63113 L .43011 .63074 L F
.42964 .63158 m .42624 .63272 L .4279 .63113 L F
.582 .006 0 r
.66173 .4356 m .66191 .43493 L .66073 .4339 L F
.66173 .4356 m .66447 .43661 L .66191 .43493 L F
.637 .386 .522 r
.52515 .67666 m .52824 .67402 L .52548 .6747 L F
.712 .177 0 r
.47595 .73009 m .47897 .73212 L .48057 .73256 L F
.717 .327 .309 r
.47915 .73389 m .48057 .73256 L .47897 .73212 L F
.47915 .73389 m .48274 .73511 L .48057 .73256 L F
.759 .501 .544 r
.54115 .70872 m .54491 .70924 L .54478 .70657 L F
.518 .316 .546 r
.54478 .70657 m .54491 .70924 L .54714 .70613 L F
.545 .593 .853 r
.45185 .58007 m .45042 .58178 L .44965 .58029 L F
.661 .41 .53 r
.51846 .6575 m .52164 .65655 L .51956 .6578 L F
.437 .487 .813 r
.52315 .65802 m .52368 .65614 L .52164 .65655 L F
0 0 .084 r
.47983 .68985 m .47991 .68915 L .4777 .69234 L F
.943 .615 .185 r
.47886 .68781 m .47991 .68915 L .47983 .68985 L F
.619 .53 .732 r
.48153 .68681 m .48243 .68914 L .47991 .68915 L F
.574 .254 .389 r
.47991 .68915 m .48217 .69099 L .47983 .68985 L F
.47991 .68915 m .48243 .68914 L .48217 .69099 L F
.485 .189 .388 r
.517 .67807 m .51727 .68096 L .51982 .67883 L F
.163 0 .287 r
.2029 .6528 m .201 .65629 L .20153 .65397 L F
.699 .684 .832 r
.50911 .65558 m .51186 .65447 L .50852 .6546 L F
.922 .55 .133 r
.66721 .44106 m .66723 .44046 L .66477 .43764 L F
.66721 .44106 m .66838 .44307 L .66723 .44046 L F
.184 .615 .943 r
.22694 .54524 m .22658 .54605 L .22494 .545 L F
.22694 .54524 m .22872 .5464 L .22658 .54605 L F
.72 .591 .71 r
.54084 .67663 m .54205 .68025 L .53972 .68042 L F
.79 .557 .584 r
.54171 .68278 m .53972 .68042 L .54205 .68025 L F
.403 .199 .487 r
.2145 .57509 m .21573 .57686 L .21668 .57425 L F
.2145 .57509 m .21425 .5774 L .21573 .57686 L F
.629 .64 .843 r
.62577 .42312 m .62728 .4191 L .6248 .42206 L F
.62577 .42312 m .62825 .4227 L .62728 .4191 L F
.648 .357 .463 r
.62622 .42547 m .62577 .42312 L .6248 .42206 L F
.62622 .42547 m .62769 .42433 L .62577 .42312 L F
.855 .695 .684 r
.62769 .42433 m .62825 .4227 L .62577 .42312 L F
.591 .34 .505 r
.59577 .48184 m .59563 .48401 L .59323 .48422 L F
.647 .427 .57 r
.60011 .48146 m .59563 .48401 L .59577 .48184 L F
.557 .823 .995 r
.49074 .7001 m .48912 .70092 L .48707 .69973 L F
.215 0 .316 r
.49074 .7001 m .48841 .70322 L .48912 .70092 L F
.689 .665 .822 r
.63867 .46829 m .63862 .46896 L .63611 .46992 L F
.507 .909 .907 r
.63611 .46992 m .63862 .46896 L .63846 .46891 L F
.611 .606 .822 r
.63867 .46829 m .64209 .46958 L .64139 .46816 L F
.63867 .46829 m .64139 .46816 L .63963 .46867 L F
.63867 .46829 m .63963 .46867 L .63862 .46896 L F
.997 .778 .434 r
.639 .46871 m .63963 .46867 L .63867 .46829 L F
.64208 .46963 m .64209 .46958 L .63927 .46852 L F
.63926 .46852 m .63927 .46852 L .63867 .46829 L F
.64208 .46963 m .63927 .46852 L .63926 .46852 L F
.6417 .47204 m .639 .46871 L .63888 .47185 L F
.639 .46871 m .63867 .46829 L .63869 .46873 L F
.557 .865 .996 r
.63862 .46896 m .639 .46871 L .6388 .46872 L F
.997 .778 .434 r
.639 .46871 m .63869 .46873 L .63888 .47185 L F
.557 .865 .996 r
.63862 .46896 m .63963 .46867 L .639 .46871 L F
.6388 .46872 m .639 .46871 L .6388 .46872 L F
.6384 .4689 m .63989 .46722 L .63774 .4687 L F
.63862 .46896 m .6387 .46877 L .63846 .46891 L F
.483 .267 .51 r
.6387 .46881 m .63846 .46891 L .63888 .47185 L F
.63846 .46891 m .63611 .46992 L .63646 .47016 L F
.63846 .46891 m .63646 .47016 L .63888 .47185 L F
.557 .865 .996 r
.63862 .46896 m .6388 .46872 L .6387 .46877 L F
.483 .267 .51 r
.63867 .46829 m .63611 .46992 L .6387 .46881 L F
.557 .865 .996 r
.63846 .46891 m .6387 .46877 L .6384 .4689 L F
.6388 .46872 m .63989 .46722 L .6384 .4689 L F
.814 .48 0 r
.63932 .4663 m .63989 .46722 L .63891 .46443 L F
.507 .909 .907 r
.63611 .46992 m .63846 .46891 L .63774 .4687 L F
.227 .308 .739 r
.63888 .47185 m .63611 .46992 L .63774 .4687 L F
.673 .578 .74 r
.63544 .4722 m .63774 .4687 L .63495 .46951 L F
.038 0 0 r
.63604 .47415 m .63917 .47389 L .63883 .47176 L F
.675 .602 .766 r
.63544 .4722 m .63604 .47415 L .63883 .47176 L F
.63544 .4722 m .63883 .47176 L .63888 .47185 L F
.673 .578 .74 r
.63544 .4722 m .63888 .47185 L .63774 .4687 L F
0 0 0 r
.63669 .47003 m .63774 .4687 L .63989 .46722 L F
.557 .865 .996 r
.6388 .46872 m .64059 .46833 L .63989 .46722 L F
0 0 0 r
.6382 .46903 m .63989 .46722 L .6397 .46802 L F
.63669 .47003 m .63834 .46858 L .6382 .46903 L F
.63834 .46858 m .63989 .46722 L .6382 .46903 L F
.872 .439 .166 r
.63746 .46517 m .63932 .46753 L .63891 .46443 L F
.63932 .46753 m .6397 .46802 L .63951 .46715 L F
.63932 .46753 m .63951 .46715 L .63891 .46443 L F
0 0 0 r
.63669 .47003 m .6397 .46802 L .63856 .46851 L F
.63922 .46771 m .638 .46962 L .63856 .46851 L F
.814 .48 0 r
.6397 .46802 m .63989 .46722 L .63932 .4663 L F
.557 .865 .996 r
.64059 .46833 m .64139 .46816 L .63989 .46722 L F
.384 .778 .988 r
.63989 .46722 m .64139 .46816 L .64351 .46777 L F
.557 .865 .996 r
.63963 .46867 m .64139 .46816 L .6388 .46872 L F
.7 .245 .166 r
.63989 .46722 m .64351 .46777 L .64172 .46881 L F
.494 0 0 r
.63989 .46722 m .64172 .46881 L .64063 .46795 L F
.375 .096 .357 r
.63891 .46443 m .6397 .46802 L .64121 .46487 L F
.773 .532 .57 r
.64121 .46487 m .6397 .46802 L .63746 .46517 L F
.745 .945 .947 r
.6397 .46802 m .6398 .46703 L .63856 .46851 L F
0 0 0 r
.6398 .46703 m .63894 .46826 L .63922 .46771 L F
.63894 .46826 m .638 .46962 L .63922 .46771 L F
.638 .46962 m .63762 .47016 L .6381 .46932 L F
.638 .46962 m .6381 .46932 L .63856 .46851 L F
.997 .778 .434 r
.6417 .47204 m .64208 .46963 L .63963 .46867 L F
.6417 .47204 m .63963 .46867 L .639 .46871 L F
.832 .367 0 r
.58106 .62795 m .5808 .62901 L .57917 .6267 L F
.58106 .62795 m .58215 .62993 L .5808 .62901 L F
.64 .456 .619 r
.57694 .4896 m .57438 .49281 L .57294 .49072 L F
.18 0 0 r
.41919 .63309 m .42016 .63375 L .4181 .63377 L F
.41919 .63309 m .4215 .63277 L .42016 .63375 L F
0 0 0 r
.56613 .63323 m .56635 .63204 L .56638 .63135 L F
.365 0 0 r
.56773 .63366 m .56635 .63204 L .56613 .63323 L F
.56773 .63366 m .5642 .63487 L .56635 .63204 L F
.685 .325 .358 r
.56567 .63316 m .56631 .63291 L .56635 .63204 L F
.789 .716 .783 r
.56635 .63204 m .56855 .6324 L .56918 .62929 L F
.56855 .6324 m .56939 .63254 L .56931 .6314 L F
.56855 .6324 m .56931 .6314 L .56918 .62929 L F
.365 0 0 r
.5648 .63466 m .56681 .63461 L .5642 .63487 L F
.56773 .63366 m .56681 .63461 L .5648 .63466 L F
.574 .536 .774 r
.5687 .63196 m .56939 .63254 L .56635 .63204 L F
.5687 .63196 m .56681 .63461 L .56708 .63433 L F
.56816 .63292 m .56708 .63433 L .56773 .63366 L F
.5687 .63196 m .56708 .63433 L .56816 .63292 L F
.5687 .63196 m .56773 .63366 L .56939 .63254 L F
.5687 .63196 m .56814 .63457 L .56681 .63461 L F
.56814 .63457 m .56812 .63468 L .56681 .63461 L F
.685 .325 .358 r
.56631 .63291 m .5687 .63196 L .56635 .63204 L F
0 0 0 r
.56638 .63135 m .56635 .63204 L .56659 .62973 L F
.52 .108 .2 r
.49195 .72023 m .49461 .72007 L .49552 .71822 L F
.501 .278 .507 r
.49552 .71822 m .49785 .71804 L .4975 .71737 L F
.481 .419 .71 r
.4982 .72054 m .49552 .71822 L .49785 .71804 L F
.4982 .72054 m .49627 .72125 L .49552 .71822 L F
.792 .606 .649 r
.49461 .72007 m .49785 .71804 L .49552 .71822 L F
.501 .278 .507 r
.4975 .71737 m .49785 .71804 L .49552 .71822 L F
.136 0 .235 r
.51613 .68728 m .51769 .6873 L .5189 .6867 L F
.51613 .68728 m .51584 .68866 L .51769 .6873 L F
.632 .801 .964 r
.63226 .44028 m .62989 .44121 L .63065 .43948 L F
0 0 0 r
.63094 .44139 m .62989 .44121 L .63226 .44028 L F
.63094 .44139 m .62928 .44227 L .62989 .44121 L F
.49 .335 .596 r
.23954 .58 m .23701 .58357 L .23727 .58077 L F
.992 .855 .602 r
.62114 .43603 m .62234 .43822 L .62265 .43509 L F
.932 .56 .266 r
.62023 .43811 m .62234 .43822 L .62114 .43603 L F
.62023 .43811 m .62264 .44022 L .62234 .43822 L F
.555 .502 .752 r
.33869 .61324 m .34002 .60914 L .33838 .60989 L F
.33869 .61324 m .34089 .61278 L .34002 .60914 L F
.357 .085 .357 r
.34068 .598 m .3433 .59514 L .34092 .59551 L F
.57 .396 .606 r
.34092 .59551 m .3433 .59514 L .34327 .59257 L F
.596 .615 .841 r
.43858 .57484 m .43989 .57789 L .43764 .57861 L F
.42 .85 .945 r
.19163 .54249 m .19374 .54192 L .19547 .54212 L F
.489 .882 .96 r
.19547 .54212 m .1959 .5412 L .19757 .5422 L F
.19547 .54212 m .19374 .54192 L .1959 .5412 L F
.377 .273 .608 r
.23299 .5922 m .23325 .59469 L .23159 .59533 L F
.386 .249 .57 r
.23325 .59469 m .2313 .59801 L .23159 .59533 L F
.861 .777 .767 r
.67139 .41084 m .6725 .41435 L .66987 .41352 L F
.845 .795 .803 r
.66987 .41352 m .6725 .41435 L .67011 .41712 L F
.62 .598 .806 r
.67391 .40998 m .6725 .41435 L .67139 .41084 L F
.148 0 0 r
.6725 .41435 m .67566 .41483 L .67592 .41485 L F
.62 .598 .806 r
.67391 .40998 m .67566 .41483 L .6725 .41435 L F
.783 .346 0 r
.66365 .42578 m .66381 .42703 L .66287 .42451 L F
.66365 .42578 m .66474 .42809 L .66381 .42703 L F
.47 .086 .23 r
.48192 .72296 m .48279 .72313 L .48389 .72208 L F
.698 .38 .435 r
.48279 .72313 m .48441 .72401 L .48389 .72208 L F
.768 .422 .401 r
.48389 .72208 m .48441 .72401 L .48755 .72399 L F
.333 0 0 r
.42567 .58286 m .42243 .58356 L .42366 .58276 L F
.781 .646 .713 r
.53712 .67403 m .53801 .6771 L .54081 .6704 L F
.758 .633 .722 r
.54084 .67663 m .53801 .6771 L .53889 .67527 L F
.438 .265 .547 r
.53891 .67496 m .53801 .6771 L .53889 .67527 L F
.758 .633 .722 r
.53889 .67527 m .53801 .6771 L .53712 .67403 L F
.547 .564 .824 r
.54084 .67663 m .53883 .6764 L .53801 .6771 L F
.758 .633 .722 r
.54084 .67663 m .53889 .67527 L .5388 .67675 L F
.547 .564 .824 r
.54084 .67663 m .54245 .67324 L .53883 .6764 L F
.438 .265 .547 r
.53826 .6766 m .53851 .67667 L .53883 .6764 L F
.758 .633 .722 r
.5388 .67675 m .53857 .67637 L .53704 .67685 L F
.53857 .67637 m .53712 .67403 L .53706 .6762 L F
.53857 .67637 m .53706 .6762 L .53704 .67685 L F
.384 0 0 r
.53704 .67685 m .53993 .67763 L .54035 .67717 L F
.5388 .67675 m .54035 .67717 L .54084 .67663 L F
.438 .265 .547 r
.53826 .6766 m .53801 .6771 L .53851 .67667 L F
.384 0 0 r
.53704 .67685 m .54035 .67717 L .5388 .67675 L F
.438 .265 .547 r
.53889 .67527 m .53826 .6766 L .53883 .6764 L F
.758 .633 .722 r
.53889 .67527 m .53712 .67403 L .5388 .67675 L F
.438 .265 .547 r
.53949 .67358 m .53891 .67496 L .54027 .67364 L F
.996 .763 .456 r
.53595 .67488 m .53704 .67685 L .5371 .67479 L F
.53595 .67488 m .5371 .67479 L .53712 .67403 L F
.44 .841 .976 r
.53812 .67482 m .53498 .67496 L .53595 .67488 L F
0 0 .282 r
.53478 .67497 m .53355 .67842 L .53595 .67488 L F
.44 .841 .976 r
.53498 .67496 m .53478 .67497 L .53595 .67488 L F
.17 0 0 r
.54027 .67364 m .53595 .67488 L .53712 .67403 L F
.54032 .67364 m .54029 .67364 L .54027 .67364 L F
.687 .492 .618 r
.54081 .6704 m .54032 .67364 L .54027 .67364 L F
.467 .39 .686 r
.54036 .67356 m .54032 .67364 L .54081 .6704 L F
.17 0 0 r
.54029 .67364 m .53812 .67482 L .53595 .67488 L F
.54032 .67364 m .54031 .67364 L .54029 .67364 L F
.54031 .67364 m .53812 .67482 L .54029 .67364 L F
.438 .265 .547 r
.54034 .67364 m .53998 .67539 L .54011 .67528 L F
.54081 .6704 m .54027 .67364 L .54034 .67364 L F
.54031 .67364 m .53998 .67539 L .54034 .67364 L F
.54027 .67365 m .53998 .67539 L .54031 .67364 L F
.425 0 0 r
.54245 .67324 m .54031 .67364 L .54032 .67364 L F
.438 .265 .547 r
.54081 .6704 m .54036 .67356 L .54245 .67324 L F
.467 .39 .686 r
.54036 .67356 m .54245 .67324 L .54032 .67364 L F
.438 .265 .547 r
.54036 .67356 m .54011 .67528 L .54245 .67324 L F
.54081 .6704 m .54245 .67324 L .54183 .67059 L F
.467 .39 .686 r
.54183 .67059 m .54245 .67324 L .54036 .67356 L F
.438 .265 .547 r
.54027 .67364 m .53891 .67496 L .53998 .67539 L F
.425 0 0 r
.54245 .67324 m .53812 .67482 L .54031 .67364 L F
.438 .265 .547 r
.54027 .67364 m .54027 .67365 L .54031 .67364 L F
.467 .39 .686 r
.54183 .67059 m .54036 .67356 L .54081 .6704 L F
.17 0 0 r
.54029 .67364 m .53595 .67488 L .54027 .67364 L F
.438 .265 .547 r
.54081 .6704 m .53949 .67358 L .54027 .67364 L F
.53891 .67496 m .53883 .6764 L .53998 .67539 L F
.687 .492 .618 r
.54081 .6704 m .54027 .67364 L .53712 .67403 L F
.01 .216 .726 r
.54049 .66734 m .54081 .6704 L .53915 .6683 L F
.369 .796 .97 r
.41245 .5776 m .41483 .57727 L .41613 .57783 L F
.763 .948 .939 r
.41613 .57783 m .4167 .57587 L .41811 .5768 L F
.41613 .57783 m .41483 .57727 L .4167 .57587 L F
.014 .552 .844 r
.38704 .62665 m .38895 .62737 L .38681 .62697 L F
.171 0 0 r
.38762 .62692 m .38895 .62737 L .38704 .62665 L F
0 .515 .782 r
.38681 .62697 m .38895 .62737 L .3901 .62775 L F
.171 0 0 r
.38976 .62796 m .38895 .62737 L .38762 .62692 L F
0 .515 .782 r
.3901 .62775 m .38895 .62737 L .39055 .62786 L F
.29 .767 .929 r
.39133 .62721 m .39055 .62786 L .38895 .62737 L F
.39133 .62721 m .39274 .62761 L .39055 .62786 L F
.326 .116 .434 r
.21579 .63205 m .21469 .63058 L .21608 .62992 L F
.21579 .63205 m .21423 .63291 L .21469 .63058 L F
.533 .605 .871 r
.46257 .62975 m .46116 .63057 L .45976 .62721 L F
.977 .779 .57 r
.45976 .62721 m .46116 .63057 L .45978 .62966 L F
0 .121 .671 r
.46116 .63057 m .46257 .62975 L .45978 .62966 L F
.46116 .63057 m .46251 .6311 L .46257 .62975 L F
.46116 .63057 m .46336 .63299 L .46251 .6311 L F
.855 .695 .684 r
.62769 .42433 m .62944 .42575 L .62825 .4227 L F
.86 .915 .867 r
.62559 .42771 m .62944 .42575 L .62769 .42433 L F
.57 .554 .797 r
.62825 .4227 m .62944 .42575 L .63182 .42512 L F
.474 .432 .731 r
.2544 .55836 m .25025 .55792 L .25009 .55771 L F
.2506 .55728 m .25009 .55771 L .24951 .55697 L F
.2544 .55836 m .25009 .55771 L .2506 .55728 L F
0 0 .085 r
.25367 .55327 m .25314 .55532 L .252 .5563 L F
.25367 .55327 m .25314 .55532 L .252 .5563 L F
.063 0 0 r
.25132 .55667 m .25314 .55532 L .252 .5563 L F
.474 .432 .731 r
.2544 .55836 m .24917 .55654 L .252 .5563 L F
.01 0 0 r
.25093 .55674 m .25132 .55667 L .252 .5563 L F
.474 .432 .731 r
.2544 .55836 m .24951 .55697 L .25013 .55687 L F
.96 .696 .49 r
.24735 .55821 m .24882 .56045 L .24917 .55654 L F
.01 0 0 r
.24735 .55821 m .25132 .55667 L .25093 .55674 L F
.474 .432 .731 r
.25013 .55687 m .24951 .55697 L .24917 .55654 L F
.01 0 0 r
.24735 .55821 m .252 .5563 L .24917 .55654 L F
.063 0 0 r
.24951 .55767 m .25218 .55594 L .25132 .55667 L F
.25218 .55594 m .25314 .55532 L .25132 .55667 L F
.01 0 0 r
.24735 .55821 m .24951 .55767 L .25132 .55667 L F
.474 .432 .731 r
.25393 .55862 m .25119 .56012 L .25324 .55824 L F
.25324 .55824 m .25119 .56012 L .25025 .55792 L F
.441 .878 .86 r
.2507 .55962 m .25119 .56012 L .2544 .55836 L F
.424 .867 .808 r
.2528 .55858 m .2507 .55962 L .2544 .55836 L F
.59 .016 0 r
.25513 .5594 m .2528 .55858 L .2548 .55908 L F
.255 .55919 m .2548 .55908 L .25495 .55912 L F
.25513 .5594 m .2548 .55908 L .255 .55919 L F
.474 .432 .731 r
.2544 .55836 m .25393 .55862 L .25324 .55824 L F
.428 .265 .556 r
.22493 .60986 m .22487 .61239 L .22297 .61284 L F
.257 .174 .566 r
.22455 .61481 m .22297 .61284 L .22487 .61239 L F
.22455 .61481 m .22326 .61561 L .22297 .61284 L F
.786 .894 .921 r
.58387 .47239 m .58175 .47219 L .58346 .46907 L F
.763 .727 .819 r
.58692 .46955 m .58387 .47239 L .58346 .46907 L F
0 0 0 r
.51076 .69192 m .50937 .69424 L .5118 .69026 L F
.547 .564 .824 r
.54084 .67663 m .54218 .67716 L .54245 .67324 L F
.347 0 0 r
.53993 .67763 m .54218 .67716 L .54084 .67663 L F
0 0 0 r
.63359 .45065 m .63303 .45201 L .63303 .452 L F
.627 .133 .059 r
.63412 .44936 m .63359 .45065 L .63464 .44942 L F
0 0 0 r
.63359 .45065 m .63303 .452 L .63466 .44882 L F
.627 .133 .059 r
.631 .449 m .63359 .45065 L .63412 .44936 L F
.914 .976 .777 r
.63464 .44942 m .63422 .44842 L .63621 .44554 L F
.966 .874 .481 r
.63464 .44942 m .63359 .45065 L .63422 .44842 L F
.686 .516 .651 r
.45123 .62497 m .45065 .62534 L .45397 .62446 L F
0 0 0 r
.38412 .59842 m .38235 .59935 L .37985 .59985 L F
.38646 .59534 m .38524 .59739 L .38412 .59842 L F
.506 .884 .688 r
.38524 .59739 m .38235 .59935 L .38412 .59842 L F
0 0 0 r
.63628 .41583 m .63398 .41732 L .63534 .41568 L F
.292 .73 .966 r
.63789 .41515 m .63628 .41583 L .63534 .41568 L F
.63789 .41515 m .63933 .41589 L .63628 .41583 L F
.606 .351 .505 r
.60751 .47859 m .60527 .48058 L .60579 .47888 L F
.79 .557 .584 r
.54171 .68278 m .54048 .68315 L .53972 .68042 L F
.408 .473 .815 r
.21911 .56614 m .2191 .56202 L .2169 .5626 L F
.21911 .56614 m .22051 .56549 L .2191 .56202 L F
.323 .2 .553 r
.21906 .56872 m .22051 .56549 L .21911 .56614 L F
.279 .78 .773 r
.67795 .41424 m .67592 .41485 L .67566 .41483 L F
.67795 .41424 m .67841 .41414 L .67592 .41485 L F
.795 .983 .897 r
.57959 .47813 m .57565 .48005 L .57881 .47737 L F
.828 .981 .882 r
.58237 .47554 m .57959 .47813 L .57881 .47737 L F
.339 0 .06 r
.45016 .62671 m .45397 .62446 L .45065 .62534 L F
.59 .208 .285 r
.56817 .49613 m .57142 .49558 L .57065 .49772 L F
.737 .564 .658 r
.57397 .4958 m .57065 .49772 L .57142 .49558 L F
.692 .896 .531 r
.35535 .62917 m .35459 .63064 L .35636 .63045 L F
.35535 .62917 m .35313 .63229 L .35459 .63064 L F
.504 .829 .999 r
.68111 .42812 m .67979 .42874 L .67786 .42791 L F
.77 .845 .392 r
.53217 .65573 m .53308 .65416 L .53215 .65632 L F
.679 .219 .152 r
.53217 .65573 m .53564 .656 L .53308 .65416 L F
.667 .487 .632 r
.58479 .48458 m .58722 .48428 L .58489 .48702 L F
.566 .109 .125 r
.37826 .64165 m .37764 .64234 L .3751 .64183 L F
.197 0 0 r
.37995 .64178 m .37826 .64165 L .38053 .64118 L F
.37995 .64178 m .37764 .64234 L .37826 .64165 L F
.319 0 0 r
.39304 .63856 m .39187 .63936 L .38942 .63952 L F
.164 0 0 r
.39375 .63943 m .39304 .63856 L .39527 .6386 L F
.39375 .63943 m .39187 .63936 L .39304 .63856 L F
.772 .692 .775 r
.66519 .44622 m .66721 .44106 L .66397 .44501 L F
.66519 .44622 m .66838 .44307 L .66721 .44106 L F
.962 .629 .267 r
.66559 .44883 m .66519 .44622 L .66397 .44501 L F
.907 .497 .171 r
.66706 .45052 m .66519 .44622 L .66559 .44883 L F
.56 .469 .709 r
.64172 .43226 m .64298 .43429 L .64061 .435 L F
.64172 .43226 m .64298 .43429 L .64061 .435 L F
.725 .394 .418 r
.50252 .68749 m .50874 .68558 L .50278 .68587 L F
.50252 .68749 m .50476 .68805 L .50874 .68558 L F
.599 .097 0 r
.50874 .68558 m .5089 .68601 L .50615 .68282 L F
.614 .294 .404 r
.50615 .68282 m .5089 .68601 L .50944 .68296 L F
.504 .344 .597 r
.34327 .59257 m .34547 .59457 L .34576 .59221 L F
.34327 .59257 m .3433 .59514 L .34547 .59457 L F
.887 .692 .175 r
.66808 .43477 m .66773 .43567 L .6669 .43361 L F
.66808 .43477 m .66808 .43711 L .66773 .43567 L F
0 0 0 r
.38696 .59628 m .38646 .59534 L .38872 .59511 L F
.38696 .59628 m .38524 .59739 L .38646 .59534 L F
.415 0 0 r
.39274 .62761 m .39501 .62845 L .39652 .62782 L F
.573 .116 .129 r
.39501 .62845 m .39876 .62728 L .39652 .62782 L F
.606 .351 .505 r
.60751 .47859 m .6076 .4806 L .60527 .48058 L F
.617 .359 .505 r
.60751 .47859 m .60989 .4807 L .6076 .4806 L F
.652 .349 .445 r
.61096 .47838 m .60989 .4807 L .60751 .47859 L F
.31 .053 .352 r
.50068 .68643 m .50252 .68749 L .50278 .68587 L F
.881 .446 .09 r
.55461 .67999 m .55436 .68196 L .55301 .67887 L F
.201 .124 .539 r
.55476 .68269 m .55573 .68277 L .55461 .67999 L F
.881 .446 .09 r
.55461 .67999 m .55573 .68277 L .55436 .68196 L F
.225 .409 .835 r
.47382 .7353 m .47321 .73277 L .47076 .73272 L F
.47382 .7353 m .47464 .73568 L .47321 .73277 L F
.872 .908 .852 r
.62265 .43509 m .6253 .43223 L .62283 .43212 L F
.889 .891 .825 r
.62283 .43212 m .6253 .43223 L .62418 .43094 L F
0 .072 .615 r
.44461 .62415 m .44612 .62687 L .44549 .62752 L F
.689 .481 .601 r
.44789 .62735 m .44552 .62907 L .44549 .62752 L F
.339 0 .06 r
.45016 .62671 m .45247 .62636 L .45397 .62446 L F
.791 .426 .367 r
.45247 .62636 m .45588 .62711 L .45397 .62446 L F
.697 .424 .506 r
.45397 .62446 m .45588 .62711 L .45611 .62478 L F
.266 .392 .805 r
.436 .57394 m .43452 .57747 L .43359 .57611 L F
.576 .133 .161 r
.56582 .63969 m .56564 .64089 L .56728 .6389 L F
.892 .554 .4 r
.56564 .64089 m .56777 .64187 L .56728 .6389 L F
.871 .599 .523 r
.67408 .44937 m .67265 .45122 L .6725 .44853 L F
.67408 .44937 m .67422 .45171 L .67265 .45122 L F
.804 .768 .82 r
.59207 .46152 m .58777 .46301 L .59051 .46016 L F
.837 .81 .824 r
.59452 .45857 m .59207 .46152 L .59051 .46016 L F
.958 .948 .678 r
.62114 .43603 m .62265 .43509 L .62283 .43212 L F
.642 .317 .405 r
.47326 .61725 m .47535 .61807 L .47641 .61547 L F
.322 .001 .257 r
.47641 .61547 m .47751 .6173 L .47836 .61479 L F
.47641 .61547 m .47535 .61807 L .47751 .6173 L F
.834 .588 .567 r
.5413 .62647 m .54409 .62782 L .54406 .62481 L F
.631 .492 .674 r
.51162 .66769 m .50831 .66557 L .51085 .6661 L F
.51162 .66769 m .50854 .66834 L .50831 .66557 L F
0 0 .406 r
.50831 .66557 m .50946 .66721 L .51085 .6661 L F
.50831 .66557 m .50854 .66834 L .50946 .66721 L F
.719 .491 .579 r
.50507 .69449 m .50169 .69197 L .50453 .69151 L F
.50507 .69449 m .50154 .69448 L .50169 .69197 L F
.529 .287 .491 r
.50154 .69448 m .49911 .69723 L .49953 .69507 L F
.837 .813 .826 r
.55398 .69463 m .55468 .69097 L .55291 .6932 L F
.55398 .69463 m .55647 .69172 L .55468 .69097 L F
.256 .379 .797 r
.64433 .44868 m .64298 .44635 L .64567 .44636 L F
.172 0 .103 r
.64394 .4474 m .64409 .44844 L .64541 .44725 L F
.64202 .4476 m .64263 .44785 L .64394 .4474 L F
.64263 .44785 m .64409 .44844 L .64394 .4474 L F
.765 .921 .94 r
.64879 .44619 m .64433 .44868 L .64535 .44692 L F
.64726 .44627 m .64535 .44692 L .64567 .44636 L F
.64879 .44619 m .64535 .44692 L .64726 .44627 L F
.315 .044 .333 r
.4982 .72054 m .49571 .72333 L .49627 .72125 L F
.775 .67 .747 r
.4544 .58928 m .45865 .59008 L .45696 .58912 L F
.4544 .58928 m .45609 .59293 L .45865 .59008 L F
.739 .899 .95 r
.45897 .58783 m .45865 .59008 L .45874 .5884 L F
.45897 .58783 m .45696 .58912 L .45865 .59008 L F
.268 .378 .791 r
.34089 .61278 m .34222 .61622 L .34329 .61463 L F
.333 .467 .846 r
.34222 .61622 m .34485 .61779 L .34329 .61463 L F
.193 0 0 r
.46414 .63266 m .46729 .63144 L .46623 .63279 L F
0 0 0 r
.46802 .63157 m .47198 .62987 L .47017 .63071 L F
.322 .801 .736 r
.46897 .63112 m .46802 .63157 L .47017 .63071 L F
0 0 0 r
.46729 .63144 m .46802 .63157 L .46671 .63218 L F
.322 .801 .736 r
.46624 .63206 m .46802 .63157 L .46897 .63112 L F
0 0 0 r
.46671 .63218 m .46802 .63157 L .46623 .63279 L F
.46729 .63144 m .46961 .63074 L .46802 .63157 L F
.198 .708 .895 r
.19757 .5422 m .19963 .54211 L .20142 .54249 L F
.177 .689 .897 r
.19963 .54211 m .20349 .54256 L .20142 .54249 L F
.24 0 0 r
.51712 .69194 m .51579 .69373 L .51348 .69428 L F
.121 0 0 r
.51794 .69291 m .51712 .69194 L .51921 .69105 L F
.51794 .69291 m .51579 .69373 L .51712 .69194 L F
.235 .408 .831 r
.52595 .64359 m .52408 .64446 L .52354 .64234 L F
.616 .499 .698 r
.52099 .64435 m .52486 .64455 L .52354 .64234 L F
.52486 .64455 m .52505 .64456 L .52494 .6444 L F
.52486 .64455 m .52494 .6444 L .52354 .64234 L F
0 0 .101 r
.52595 .64359 m .52505 .64456 L .52415 .6472 L F
0 0 .229 r
.52415 .6472 m .52412 .64592 L .52595 .64359 L F
.607 .354 .508 r
.52415 .6472 m .52505 .64456 L .52486 .64455 L F
0 0 .229 r
.52476 .64455 m .52408 .64446 L .525 .64403 L F
.52412 .64592 m .5241 .64509 L .52476 .64455 L F
.5241 .64509 m .52408 .64446 L .52476 .64455 L F
.52486 .64455 m .525 .64403 L .52519 .64394 L F
.344 .394 .769 r
.52354 .64234 m .52494 .6444 L .52595 .64359 L F
.52494 .6444 m .52505 .64456 L .52595 .64359 L F
0 0 .229 r
.52412 .64592 m .525 .64403 L .52486 .64455 L F
.607 .354 .508 r
.52415 .6472 m .52486 .64455 L .52099 .64435 L F
0 0 .229 r
.52412 .64592 m .52519 .64394 L .52595 .64359 L F
.63 .341 .46 r
.61096 .47838 m .61332 .48032 L .60989 .4807 L F
.61096 .47838 m .61346 .47829 L .61332 .48032 L F
.149 .687 .838 r
.40215 .57841 m .40651 .57849 L .40413 .57893 L F
.83 .723 .747 r
.58584 .46609 m .5888 .46668 L .58692 .46955 L F
.337 .18 .515 r
.19431 .62173 m .1962 .61878 L .19581 .61873 L F
.19431 .62173 m .19696 .62198 L .1962 .61878 L F
.349 .24 .586 r
.19435 .62434 m .19696 .62198 L .19431 .62173 L F
.434 .86 .943 r
.67227 .41484 m .67144 .41535 L .67388 .41467 L F
.845 .795 .803 r
.66987 .41352 m .67005 .4162 L .67144 .41535 L F
.759 .346 .266 r
.66987 .41352 m .67144 .41535 L .66874 .41433 L F
.434 .86 .943 r
.67028 .41504 m .67144 .41535 L .67227 .41484 L F
.845 .795 .803 r
.67005 .4162 m .67011 .41712 L .67144 .41535 L F
.378 .547 .895 r
.67011 .41712 m .6734 .41814 L .67144 .41535 L F
.787 .54 .563 r
.67011 .41712 m .67367 .42024 L .6734 .41814 L F
.356 0 .175 r
.54278 .68412 m .54456 .68495 L .54197 .68557 L F
.558 .483 .726 r
.54657 .67949 m .54278 .68412 L .54458 .67958 L F
.54657 .67949 m .5474 .68172 L .54278 .68412 L F
.736 .956 .661 r
.5474 .68172 m .54456 .68495 L .54278 .68412 L F
.538 .35 .574 r
.46811 .62164 m .4705 .62119 L .47035 .6182 L F
.421 .864 .904 r
.47218 .61745 m .47326 .61725 L .47035 .6182 L F
.546 .426 .667 r
.4705 .62119 m .47218 .61745 L .47035 .6182 L F
.415 .231 .521 r
.2345 .58641 m .2346 .58986 L .23264 .59029 L F
.251 .011 .343 r
.23701 .58357 m .23673 .58553 L .2345 .58641 L F
.359 .189 .51 r
.2367 .5879 m .2345 .58641 L .23673 .58553 L F
.2367 .5879 m .2346 .58986 L .2345 .58641 L F
.118 0 0 r
.46414 .63266 m .46623 .63279 L .46336 .63299 L F
.878 .684 .637 r
.51991 .70984 m .51774 .70891 L .52128 .71039 L F
.51991 .70984 m .51724 .71135 L .51774 .70891 L F
.162 0 0 r
.51991 .70984 m .51918 .71145 L .51724 .71135 L F
.421 0 0 r
.52254 .71136 m .51918 .71145 L .51991 .70984 L F
.209 0 0 r
.34755 .5914 m .35001 .59103 L .35168 .58979 L F
.542 .11 .17 r
.35001 .59103 m .35392 .58944 L .35168 .58979 L F
.649 .916 .979 r
.21289 .58071 m .21347 .57875 L .21425 .5774 L F
.21289 .58071 m .21118 .58014 L .21347 .57875 L F
.198 .25 .691 r
.21289 .58071 m .21478 .58262 L .21373 .58236 L F
.407 .271 .581 r
.22901 .60332 m .22692 .60685 L .22687 .60433 L F
.79 .704 .769 r
.53883 .64445 m .54064 .64567 L .54234 .64502 L F
.425 .322 .633 r
.24058 .57134 m .24056 .57436 L .23886 .575 L F
.357 .226 .561 r
.24056 .57436 m .23902 .57743 L .23886 .575 L F
.956 .95 .676 r
.66447 .43661 m .66379 .43839 L .66477 .43764 L F
.816 .534 .513 r
.66293 .4419 m .66477 .43764 L .66379 .43839 L F
.66293 .4419 m .66721 .44106 L .66477 .43764 L F
.353 0 0 r
.4167 .62439 m .41886 .62465 L .42042 .6242 L F
.395 0 0 r
.42042 .6242 m .42142 .62532 L .4227 .62438 L F
.42042 .6242 m .41886 .62465 L .42142 .62532 L F
.255 0 .205 r
.53274 .67076 m .53584 .66769 L .53367 .66915 L F
.73 .345 .321 r
.53208 .64125 m .53327 .63882 L .53183 .63838 L F
.53208 .64125 m .53551 .6413 L .53327 .63882 L F
.357 .273 .623 r
.2438 .56175 m .24182 .56012 L .24484 .56 L F
.2438 .56175 m .24199 .56324 L .24182 .56012 L F
.948 .957 .685 r
.57418 .63099 m .57431 .62847 L .57279 .63006 L F
.57418 .63099 m .5758 .62735 L .57431 .62847 L F
0 0 .386 r
.66985 .43902 m .66952 .44052 L .67008 .44263 L F
.723 .275 .188 r
.45976 .62721 m .45611 .62478 L .45588 .62711 L F
.536 .582 .848 r
.6846 .41626 m .68229 .41664 L .68092 .41344 L F
.604 .537 .752 r
.6846 .41626 m .68307 .42055 L .68229 .41664 L F
.508 .747 .982 r
.42119 .61608 m .42411 .6157 L .42231 .61455 L F
.414 .434 .771 r
.21015 .55915 m .2119 .55661 L .20962 .55716 L F
.21015 .55915 m .21241 .55853 L .2119 .55661 L F
.148 0 0 r
.38654 .5812 m .38708 .58198 L .38848 .58085 L F
.38654 .5812 m .38479 .58248 L .38708 .58198 L F
.669 .744 .907 r
.67517 .42769 m .67267 .42885 L .67163 .42707 L F
.772 .483 .497 r
.54197 .68557 m .54048 .68315 L .54171 .68278 L F
.321 .376 .763 r
.47429 .7043 m .47463 .70545 L .47641 .70578 L F
.113 .663 .807 r
.20384 .5551 m .20169 .5549 L .20013 .55508 L F
.283 .766 .921 r
.20608 .55513 m .20169 .5549 L .20384 .5551 L F
.299 .716 .973 r
.20597 .55545 m .20608 .55513 L .20384 .5551 L F
.176 0 .269 r
.2313 .59801 m .23079 .60021 L .22889 .60091 L F
.326 .131 .455 r
.23061 .60263 m .22889 .60091 L .23079 .60021 L F
.23061 .60263 m .22901 .60332 L .22889 .60091 L F
.491 .31 .562 r
.54485 .60996 m .54475 .61269 L .54392 .61115 L F
.574 .428 .645 r
.547 .60938 m .54475 .61269 L .54485 .60996 L F
.288 0 .153 r
.547 .60938 m .54485 .60996 L .54392 .61115 L F
.383 .551 .896 r
.20597 .55545 m .2096 .55583 L .20608 .55513 L F
.20597 .55545 m .20962 .55716 L .2096 .55583 L F
.487 .327 .59 r
.54572 .65042 m .54618 .64751 L .54397 .64799 L F
0 0 .053 r
.21044 .6394 m .20943 .64139 L .20826 .64211 L F
0 0 .334 r
.20887 .64385 m .20826 .64211 L .20943 .64139 L F
.20887 .64385 m .20809 .64473 L .20826 .64211 L F
.57 .722 .945 r
.54271 .62844 m .54409 .62782 L .5413 .62647 L F
.414 .279 .587 r
.54409 .62782 m .54474 .62987 L .54271 .62844 L F
.3 .105 .44 r
.21841 .62417 m .21861 .62653 L .21649 .6274 L F
.332 .131 .451 r
.21752 .62892 m .21649 .6274 L .21861 .62653 L F
.21752 .62892 m .21608 .62992 L .21649 .6274 L F
.441 .878 .86 r
.2507 .55962 m .24882 .56045 L .25119 .56012 L F
.073 .61 .857 r
.18273 .57366 m .18385 .57415 L .18213 .57304 L F
.18273 .57366 m .18597 .57434 L .18385 .57415 L F
.186 0 0 r
.52049 .6825 m .51807 .68252 L .52048 .68001 L F
.466 .353 .642 r
.33906 .60114 m .341 .60057 L .34068 .598 L F
.389 .246 .562 r
.33916 .60371 m .341 .60057 L .33906 .60114 L F
.624 .587 .792 r
.69332 .4277 m .69073 .42847 L .68973 .42486 L F
.601 .513 .727 r
.69422 .43139 m .69073 .42847 L .69332 .4277 L F
.69422 .43139 m .69177 .43224 L .69073 .42847 L F
.515 .422 .687 r
.6944 .43379 m .69177 .43224 L .69422 .43139 L F
.6944 .43379 m .6923 .43495 L .69177 .43224 L F
.491 0 .011 r
.2009 .60968 m .20142 .61124 L .20288 .6079 L F
.2009 .60968 m .19836 .61158 L .20142 .61124 L F
.497 .78 .995 r
.46274 .59099 m .46423 .5923 L .46182 .59246 L F
.572 .308 .478 r
.46423 .5923 m .46407 .59439 L .46182 .59246 L F
.127 .288 .759 r
.46182 .59246 m .46407 .59439 L .46274 .59099 L F
.828 .78 .807 r
.54736 .65565 m .54931 .65706 L .54663 .6599 L F
.652 .236 .242 r
.51958 .70604 m .52329 .70814 L .52342 .70586 L F
0 0 .558 r
.52329 .70814 m .52489 .70622 L .52342 .70586 L F
.546 .286 .473 r
.52978 .70672 m .52919 .70886 L .53121 .70661 L F
.52978 .70672 m .52919 .70886 L .53121 .70661 L F
.483 0 0 r
.79572 .49433 m .79961 .49557 L .79591 .49411 L F
.429 .755 .995 r
.51429 .66552 m .51694 .66553 L .51563 .66474 L F
.054 0 0 r
.38002 .60026 m .37814 .60104 L .37985 .59985 L F
.068 0 0 r
.38235 .59935 m .38002 .60026 L .37985 .59985 L F
.166 .704 .805 r
.41987 .58429 m .41607 .5845 L .41746 .58472 L F
.466 .012 .089 r
.52347 .70001 m .52816 .69901 L .52463 .70085 L F
.246 0 0 r
.52816 .69901 m .52721 .70031 L .52463 .70085 L F
.466 .012 .089 r
.52347 .70001 m .52721 .70031 L .52816 .69901 L F
0 0 0 r
.52816 .69901 m .52897 .69923 L .52721 .70031 L F
.52721 .70031 m .52897 .69923 L .52816 .69901 L F
.837 .81 .824 r
.59452 .45857 m .59051 .46016 L .59297 .45724 L F
.812 .758 .802 r
.59508 .45421 m .59452 .45857 L .59297 .45724 L F
.59508 .45421 m .59691 .45569 L .59452 .45857 L F
.604 .537 .752 r
.6846 .41626 m .68555 .42005 L .68307 .42055 L F
.612 .515 .72 r
.68555 .42005 m .6834 .42263 L .68307 .42055 L F
.473 .199 .416 r
.64202 .4476 m .64567 .44636 L .64298 .44635 L F
.556 .537 .789 r
.68973 .42486 m .68678 .42359 L .68911 .42269 L F
.632 .647 .847 r
.68911 .42269 m .68678 .42359 L .68569 .42174 L F
.103 0 0 r
.52383 .72629 m .52581 .72575 L .52705 .72394 L F
.453 .778 .998 r
.52682 .71687 m .52864 .7179 L .52577 .7181 L F
.559 .329 .523 r
.52864 .7179 m .52811 .7202 L .52577 .7181 L F
.124 .286 .758 r
.52577 .7181 m .52811 .7202 L .52682 .71687 L F
.726 .289 .211 r
.52581 .72575 m .52916 .72595 L .52705 .72394 L F
.332 .522 .892 r
.48192 .72296 m .48441 .72401 L .48279 .72313 L F
0 0 .371 r
.21393 .5866 m .21479 .58564 L .21478 .58262 L F
.017 0 0 r
.21393 .5866 m .21412 .5875 L .21479 .58564 L F
.21393 .5866 m .21214 .58824 L .21412 .5875 L F
.887 .746 .7 r
.64777 .46652 m .6509 .46703 L .64926 .46521 L F
.814 .858 .881 r
.64765 .46924 m .6509 .46703 L .64777 .46652 L F
.528 0 0 r
.39238 .5953 m .39054 .59616 L .38872 .59511 L F
.224 0 0 r
.39462 .59445 m .39054 .59616 L .39238 .5953 L F
.681 .268 0 r
.65732 .42822 m .65898 .43148 L .65937 .43171 L F
.802 .326 0 r
.65939 .43288 m .65937 .43171 L .65898 .43148 L F
.65939 .43288 m .66073 .4339 L .65937 .43171 L F
.349 0 0 r
.43421 .62934 m .43243 .6305 L .43011 .63074 L F
.413 0 .058 r
.4359 .62952 m .43243 .6305 L .43421 .62934 L F
.103 .328 .801 r
.58561 .64559 m .58479 .64379 L .58247 .64191 L F
.217 .362 .796 r
.6734 .41814 m .67367 .42024 L .67489 .41839 L F
0 .357 .814 r
.67367 .42024 m .6756 .42059 L .67489 .41839 L F
.67367 .42024 m .67692 .42198 L .6756 .42059 L F
.882 .651 .584 r
.44896 .62924 m .44789 .62735 L .44907 .62727 L F
.584 .256 .379 r
.25963 .78044 m .25931 .77936 L .25606 .77938 L F
.362 .12 .407 r
.5309 .69711 m .53241 .69722 L .5327 .69497 L F
.628 .639 .842 r
.4354 .58333 m .43837 .58458 L .43803 .58259 L F
.368 .447 .81 r
.43803 .58259 m .43837 .58458 L .43984 .5827 L F
.673 .665 .835 r
.43837 .58458 m .44311 .58489 L .43984 .5827 L F
.577 .896 .63 r
.5758 .62735 m .57719 .62583 L .57431 .62847 L F
.118 .327 .796 r
.35636 .63045 m .35798 .63383 L .35871 .63249 L F
.4 .69 .978 r
.35798 .63383 m .36035 .63397 L .35871 .63249 L F
.683 .512 .649 r
.62825 .4227 m .63098 .41987 L .62862 .42006 L F
.62825 .4227 m .63184 .42304 L .63098 .41987 L F
.644 .518 .695 r
.63098 .41987 m .6338 .42001 L .63398 .41732 L F
.671 .523 .675 r
.63184 .42304 m .6338 .42001 L .63098 .41987 L F
.344 .106 .402 r
.46811 .62164 m .46571 .62494 L .46776 .62424 L F
.496 .233 .445 r
.46811 .62164 m .46776 .62424 L .4705 .62119 L F
.417 .796 .992 r
.42943 .58328 m .42792 .58256 L .42567 .58286 L F
.37 .635 .957 r
.42943 .58328 m .43014 .58194 L .42792 .58256 L F
.42943 .58328 m .43197 .58363 L .43014 .58194 L F
.367 0 .101 r
.35618 .58933 m .35835 .58915 L .36002 .58676 L F
.44 .038 .179 r
.35835 .58915 m .36237 .5864 L .36002 .58676 L F
.205 .172 .597 r
.19581 .61873 m .1962 .61878 L .19598 .61605 L F
.793 .456 .417 r
.61364 .45366 m .61682 .45226 L .61549 .45088 L F
.61364 .45366 m .6165 .45382 L .61682 .45226 L F
.571 .615 .858 r
.61682 .45226 m .61824 .44968 L .61549 .45088 L F
.61682 .45226 m .61968 .45174 L .61824 .44968 L F
.497 .207 .404 r
.6165 .45382 m .61968 .45174 L .61682 .45226 L F
.596 .319 .466 r
.5327 .69497 m .53241 .69722 L .535 .69669 L F
.597 .318 .464 r
.5327 .69497 m .535 .69669 L .53539 .69478 L F
.612 .515 .72 r
.68555 .42005 m .68569 .42174 L .6834 .42263 L F
.535 .73 .964 r
.21485 .56307 m .21558 .5612 L .21337 .56183 L F
.21485 .56307 m .2169 .5626 L .21558 .5612 L F
.999 .81 .469 r
.56058 .63291 m .5612 .63366 L .56172 .63063 L F
.785 .774 .843 r
.6874 .45492 m .68425 .45431 L .68659 .45215 L F
.861 .593 .531 r
.6874 .45492 m .68406 .4568 L .68425 .45431 L F
.6874 .45492 m .6875 .45753 L .68406 .4568 L F
.659 .7 .877 r
.68998 .45412 m .6874 .45492 L .68659 .45215 L F
.47 .243 .486 r
.68998 .45412 m .6875 .45753 L .6874 .45492 L F
.703 .419 .492 r
.56593 .49603 m .56817 .49613 L .56827 .49805 L F
.59 .208 .285 r
.56817 .49613 m .57065 .49772 L .56827 .49805 L F
.347 0 0 r
.53993 .67763 m .54178 .67798 L .54218 .67716 L F
.354 .332 .696 r
.54218 .67716 m .54431 .67242 L .54245 .67324 L F
.54218 .67716 m .54683 .67776 L .54431 .67242 L F
.101 0 0 r
.54178 .67798 m .54683 .67776 L .54218 .67716 L F
.535 .42 .669 r
.48574 .67467 m .48854 .67416 L .48659 .67248 L F
.636 .655 .852 r
.58942 .64784 m .58864 .64469 L .58561 .64559 L F
.127 .673 .817 r
.38848 .58085 m .39089 .58073 L .39222 .58087 L F
0 0 0 r
.39089 .58073 m .39451 .58061 L .39222 .58087 L F
.164 0 0 r
.52448 .72816 m .52804 .72838 L .52729 .72787 L F
.758 .819 .9 r
.52804 .72838 m .52916 .72595 L .52729 .72787 L F
.52804 .72838 m .53081 .72698 L .52916 .72595 L F
.619 .799 .969 r
.43371 .58212 m .4354 .58333 L .43803 .58259 L F
.477 .675 .952 r
.20319 .59379 m .20394 .59159 L .20151 .59173 L F
.20319 .59379 m .20574 .59373 L .20394 .59159 L F
.828 .78 .807 r
.54736 .65565 m .54663 .6599 L .54498 .65858 L F
.82 .78 .815 r
.59762 .45127 m .59691 .45569 L .59508 .45421 L F
.59762 .45127 m .59935 .45283 L .59691 .45569 L F
.633 .62 .819 r
.46321 .69749 m .46143 .70002 L .46363 .70066 L F
.287 .411 .814 r
.46143 .70002 m .46408 .70213 L .46363 .70066 L F
.828 .981 .882 r
.58237 .47554 m .57881 .47737 L .58081 .47431 L F
.98 .819 .61 r
.58175 .47219 m .58237 .47554 L .58081 .47431 L F
.814 .858 .881 r
.64765 .46924 m .64777 .46652 L .64764 .46867 L F
.453 .347 .644 r
.2346 .58986 m .23299 .5922 L .23264 .59029 L F
0 0 .346 r
.55728 .66866 m .5571 .66852 L .55706 .6673 L F
.55728 .66866 m .55819 .67083 L .5571 .66852 L F
.326 .146 .478 r
.22091 .62104 m .22065 .62369 L .21841 .62417 L F
.337 .141 .461 r
.22065 .62369 m .21861 .62653 L .21841 .62417 L F
.664 .562 .73 r
.68751 .44342 m .69098 .44344 L .68847 .44616 L F
.524 .286 .496 r
.68847 .44616 m .69123 .44851 L .68833 .44851 L F
.608 .478 .678 r
.69098 .44344 m .69105 .44646 L .68847 .44616 L F
.594 .266 .384 r
.69105 .44646 m .69123 .44851 L .68847 .44616 L F
.976 .822 .627 r
.64879 .44619 m .64736 .44505 L .64819 .44247 L F
.765 .921 .94 r
.64879 .44619 m .64567 .44636 L .64736 .44505 L F
.703 .701 .845 r
.47464 .73568 m .47767 .73612 L .47733 .73463 L F
.636 .657 .854 r
.47733 .73463 m .47767 .73612 L .47915 .73389 L F
.836 .754 .772 r
.64926 .46521 m .65255 .46373 L .65152 .46243 L F
.777 .909 .931 r
.65255 .46373 m .65448 .46048 L .65152 .46243 L F
.65255 .46373 m .65553 .46185 L .65448 .46048 L F
.793 .994 .874 r
.65264 .46428 m .65553 .46185 L .65255 .46373 L F
.657 .612 .792 r
.7907 .49631 m .79458 .49913 L .79344 .49567 L F
.733 .684 .803 r
.79344 .49567 m .79458 .49913 L .79678 .49796 L F
.882 .651 .584 r
.44896 .62924 m .44776 .63016 L .44789 .62735 L F
.694 .183 .014 r
.44896 .62924 m .44987 .63107 L .44776 .63016 L F
.44896 .62924 m .45165 .63052 L .44987 .63107 L F
.304 .022 .31 r
.19979 .59214 m .20151 .59173 L .20203 .58973 L F
.442 .144 .362 r
.20203 .58973 m .20151 .59173 L .20413 .58957 L F
.921 .531 .151 r
.55408 .65989 m .55467 .66198 L .55583 .66273 L F
.606 .163 0 r
.55467 .66198 m .55672 .66488 L .55583 .66273 L F
.819 .8 .834 r
.60012 .44844 m .6007 .45144 L .59762 .45127 L F
.829 .779 .805 r
.59762 .45127 m .6007 .45144 L .59935 .45283 L F
.804 .792 .841 r
.60332 .44859 m .6007 .45144 L .60012 .44844 L F
.542 .342 .559 r
.47641 .70578 m .47643 .7032 L .47429 .7043 L F
.963 .745 .562 r
.26003 .78154 m .2622 .77912 L .26046 .77831 L F
.641 .813 .966 r
.4777 .69234 m .4741 .69195 L .47618 .69093 L F
.4777 .69234 m .4741 .69195 L .47618 .69093 L F
.307 .46 .85 r
.5831 .6211 m .57997 .61818 L .58072 .6216 L F
.155 0 0 r
.58141 .62257 m .58072 .6216 L .57976 .62173 L F
.58141 .62257 m .5831 .6211 L .58072 .6216 L F
.592 .366 .543 r
.50829 .67103 m .50854 .66834 L .51162 .66769 L F
.96 .714 .52 r
.50626 .66982 m .50854 .66834 L .50829 .67103 L F
.571 .906 .67 r
.50946 .66721 m .50854 .66834 L .50626 .66982 L F
.229 .497 .9 r
.23842 .54997 m .24015 .55039 L .23959 .55176 L F
.16 .413 .854 r
.24015 .55039 m .24189 .5531 L .23959 .55176 L F
.437 .242 .516 r
.22326 .61561 m .22299 .61806 L .22087 .61848 L F
.352 .159 .473 r
.22299 .61806 m .22091 .62104 L .22087 .61848 L F
.452 .759 .995 r
.34448 .63497 m .34692 .63469 L .34637 .63619 L F
.34637 .63619 m .34692 .63469 L .34448 .63497 L F
.576 .575 .815 r
.52368 .65614 m .52491 .65989 L .5273 .65904 L F
.387 .162 .446 r
.6923 .43495 m .69236 .43733 L .69037 .43733 L F
.626 .584 .787 r
.69236 .43733 m .68981 .43988 L .69037 .43733 L F
.812 .994 .759 r
.65019 .43754 m .64769 .44041 L .64841 .43841 L F
.978 .892 .539 r
.64819 .44247 m .64841 .43841 L .64769 .44041 L F
.765 .518 .561 r
.55075 .66917 m .54786 .6705 L .54814 .66806 L F
.57 .29 .452 r
.61346 .47829 m .61586 .48008 L .61332 .48032 L F
.637 .239 .274 r
.61346 .47829 m .61589 .47871 L .61586 .48008 L F
.322 0 0 r
.45508 .62969 m .4541 .63036 L .45165 .63052 L F
.022 0 0 r
.45744 .62883 m .4541 .63036 L .45508 .62969 L F
.64 .456 .619 r
.57694 .4896 m .57657 .49259 L .57438 .49281 L F
.802 .5 .477 r
.57694 .4896 m .57913 .49252 L .57657 .49259 L F
.601 .183 .222 r
.56478 .49639 m .56593 .49603 L .56463 .4976 L F
.703 .419 .492 r
.56593 .49603 m .56827 .49805 L .56463 .4976 L F
.276 .018 .33 r
.51675 .64817 m .51875 .64773 L .51924 .64547 L F
.097 .025 .477 r
.51675 .64817 m .51818 .64973 L .51875 .64773 L F
.226 .551 .931 r
.51982 .67883 m .52155 .67922 L .52048 .68001 L F
.43 .867 .782 r
.52048 .68001 m .52155 .67922 L .52244 .67902 L F
.611 .913 .98 r
.43513 .59088 m .43426 .59236 L .43305 .59183 L F
.43513 .59088 m .43426 .59236 L .43305 .59183 L F
.273 .519 .906 r
.44311 .58489 m .44226 .58202 L .43984 .5827 L F
.44311 .58489 m .44341 .58395 L .44226 .58202 L F
.669 .709 .878 r
.44311 .58489 m .44575 .58485 L .44341 .58395 L F
.778 .696 .774 r
.58584 .46609 m .58692 .46955 L .58346 .46907 L F
.749 .282 0 r
.59099 .60841 m .59052 .60706 L .58993 .60626 L F
.59099 .60841 m .59196 .60926 L .59052 .60706 L F
.664 .547 .712 r
.68981 .43988 m .69098 .44344 L .68751 .44342 L F
.773 .385 .32 r
.5781 .59753 m .58016 .60006 L .58155 .59827 L F
.812 .439 .35 r
.58016 .60006 m .58204 .60046 L .58155 .59827 L F
.905 .744 .672 r
.58725 .64113 m .59046 .63902 L .58912 .63794 L F
.58725 .64113 m .59006 .64139 L .59046 .63902 L F
.918 .85 .76 r
.58912 .63794 m .59046 .63902 L .59133 .63682 L F
.876 .832 .8 r
.55819 .67896 m .55791 .68313 L .5588 .67961 L F
.55819 .67896 m .55573 .68277 L .55791 .68313 L F
.901 .616 .493 r
.55791 .68313 m .55573 .68277 L .55521 .68373 L F
.539 .534 .797 r
.45502 .58064 m .45351 .58297 L .45185 .58007 L F
.45502 .58064 m .45597 .58257 L .45351 .58297 L F
.779 .821 .885 r
.45703 .58563 m .45351 .58297 L .45597 .58257 L F
.45703 .58563 m .45311 .58581 L .45351 .58297 L F
.327 .741 .978 r
.20349 .54256 m .20557 .54246 L .20732 .54327 L F
.118 .642 .879 r
.20557 .54246 m .2093 .54308 L .20732 .54327 L F
0 .255 .632 r
.37371 .64113 m .3736 .64107 L .37133 .63992 L F
.37505 .64181 m .3736 .64107 L .37371 .64113 L F
.658 .887 .535 r
.37426 .63985 m .37341 .64097 L .3736 .64107 L F
.973 .72 .492 r
.3736 .64107 m .37201 .64279 L .37185 .64018 L F
.658 .887 .535 r
.37341 .64097 m .37201 .64279 L .3736 .64107 L F
.306 .412 .806 r
.37133 .63992 m .3736 .64107 L .37223 .63772 L F
.973 .72 .492 r
.3736 .64107 m .37185 .64018 L .37184 .64015 L F
0 .255 .632 r
.3751 .64183 m .3736 .64107 L .37505 .64181 L F
0 .46 .764 r
.37764 .64234 m .3736 .64107 L .3751 .64183 L F
.592 .868 .994 r
.66541 .45064 m .66707 .4514 L .66706 .45052 L F
.998 .84 .547 r
.66558 .45409 m .66707 .4514 L .66541 .45064 L F
.66558 .45409 m .66651 .45508 L .66707 .4514 L F
.511 .654 .923 r
.36653 .63464 m .36772 .63655 L .36873 .63444 L F
.416 .539 .872 r
.36772 .63655 m .3696 .6364 L .36873 .63444 L F
.321 .18 .528 r
.22641 .61157 m .22493 .60986 L .22698 .60931 L F
.22641 .61157 m .22487 .61239 L .22493 .60986 L F
.669 .176 .07 r
.19933 .60535 m .19801 .6059 L .19587 .60427 L F
.435 .482 .809 r
.19933 .60535 m .20006 .60362 L .19801 .6059 L F
.243 .03 .378 r
.19925 .60186 m .19919 .60452 L .20035 .60295 L F
.435 .482 .809 r
.20006 .60362 m .20035 .60295 L .19919 .60452 L F
.243 .03 .378 r
.19919 .60452 m .19919 .60461 L .20035 .60295 L F
.435 .482 .809 r
.20006 .60362 m .19871 .60503 L .19801 .6059 L F
.532 .315 .53 r
.19912 .6046 m .19801 .6059 L .19919 .60461 L F
.19587 .60427 m .19801 .6059 L .19912 .6046 L F
.435 .482 .809 r
.19912 .6046 m .20035 .60295 L .19871 .60503 L F
.525 .243 .43 r
.19912 .6046 m .19919 .60452 L .19925 .60186 L F
.435 .482 .809 r
.19919 .60452 m .19926 .60444 L .19912 .6046 L F
.19926 .60444 m .20035 .60295 L .19912 .6046 L F
.525 .243 .43 r
.19587 .60427 m .19912 .6046 L .19925 .60186 L F
.19912 .6046 m .19919 .60461 L .19919 .60452 L F
.243 .03 .378 r
.19925 .60186 m .20035 .60295 L .20057 .60047 L F
.712 .59 .717 r
.6491 .43325 m .64749 .43017 L .64832 .43206 L F
.737 .221 0 r
.64832 .43206 m .65022 .43381 L .6491 .43325 L F
.337 0 0 r
.42397 .61253 m .4228 .6129 L .42593 .61241 L F
0 0 .476 r
.53215 .65632 m .53372 .65913 L .53217 .65573 L F
.483 .802 1 r
.17592 .5419 m .17808 .54147 L .17977 .54242 L F
.396 0 0 r
.17808 .54147 m .18186 .54229 L .17977 .54242 L F
.116 0 0 r
.4158 .634 m .41648 .63449 L .41433 .63514 L F
.4158 .634 m .4181 .63377 L .41648 .63449 L F
.448 .868 .739 r
.46213 .6267 m .46571 .62494 L .46218 .62423 L F
.461 .388 .687 r
.46571 .62494 m .46815 .62667 L .46776 .62424 L F
.991 .884 .57 r
.55778 .67338 m .55711 .67604 L .55845 .67427 L F
.876 .548 .426 r
.55711 .67604 m .55927 .67681 L .55845 .67427 L F
.497 .243 .46 r
.69448 .43606 m .69236 .43733 L .6923 .43495 L F
.448 .289 .572 r
.6944 .43379 m .69448 .43606 L .6923 .43495 L F
.641 .849 .458 r
.48417 .61731 m .48317 .61886 L .48515 .61597 L F
.028 0 .208 r
.48413 .62023 m .48317 .61886 L .48417 .61731 L F
.48413 .62023 m .48241 .621 L .48317 .61886 L F
.786 .696 .764 r
.46443 .7059 m .46579 .70912 L .46749 .70706 L F
.512 .305 .535 r
.46579 .70912 m .46826 .70899 L .46749 .70706 L F
0 0 0 r
.21161 .63831 m .20943 .64139 L .21044 .6394 L F
.846 .505 0 r
.67167 .446 m .67151 .44694 L .67214 .44462 L F
.67167 .446 m .6725 .44853 L .67151 .44694 L F
.952 .708 .533 r
.53551 .6413 m .53729 .64331 L .5391 .64174 L F
.53551 .6413 m .53543 .64382 L .53729 .64331 L F
0 0 0 r
.65986 .46248 m .66154 .46114 L .66319 .45989 L F
.743 .75 .858 r
.64119 .46008 m .64616 .45948 L .64442 .45748 L F
.207 .349 .788 r
.64616 .45948 m .64667 .457 L .64442 .45748 L F
.64616 .45948 m .64744 .4599 L .64667 .457 L F
.733 .684 .803 r
.79344 .49567 m .79678 .49796 L .79572 .49433 L F
.681 .639 .801 r
.79572 .49433 m .79678 .49796 L .79961 .49557 L F
.673 .624 .792 r
.79678 .49796 m .8007 .49904 L .79961 .49557 L F
.945 .96 .71 r
.65019 .43754 m .64841 .43841 L .65047 .43497 L F
.163 0 .287 r
.2029 .6528 m .20269 .65572 L .201 .65629 L F
.222 .03 .396 r
.20552 .65007 m .20503 .65271 L .2029 .6528 L F
0 0 .239 r
.20382 .65452 m .2029 .6528 L .20503 .65271 L F
.20382 .65452 m .20269 .65572 L .2029 .6528 L F
.219 0 0 r
.40718 .63586 m .40581 .63722 L .4034 .63767 L F
.482 .051 .143 r
.4095 .63545 m .40581 .63722 L .40718 .63586 L F
.098 .139 .616 r
.58056 .60671 m .58199 .60531 L .58048 .6058 L F
.82 .693 .724 r
.58056 .60671 m .58048 .6058 L .57711 .60635 L F
.428 .196 .457 r
.58227 .48993 m .58489 .48702 L .58469 .48931 L F
.408 .097 .323 r
.58157 .49189 m .58227 .48993 L .58469 .48931 L F
.661 .621 .799 r
.67795 .41424 m .67566 .41483 L .67391 .40998 L F
.593 .284 .414 r
.59323 .48422 m .59563 .48598 L .59374 .48624 L F
.576 .294 .451 r
.59563 .48401 m .59563 .48598 L .59323 .48422 L F
.539 .682 .931 r
.52448 .72816 m .52581 .72575 L .52383 .72629 L F
.52448 .72816 m .52729 .72787 L .52581 .72575 L F
.918 .85 .76 r
.58912 .63794 m .59133 .63682 L .59082 .63547 L F
.444 .459 .78 r
.53875 .62565 m .53923 .62645 L .5413 .62647 L F
0 .324 .661 r
.48313 .68744 m .48153 .68681 L .4798 .68574 L F
.48313 .68744 m .48493 .68818 L .48153 .68681 L F
.562 .499 .742 r
.48493 .68818 m .48243 .68914 L .48153 .68681 L F
.395 .658 .964 r
.44575 .58485 m .44413 .58264 L .44341 .58395 L F
.44575 .58485 m .44712 .58491 L .44413 .58264 L F
.336 .713 .984 r
.58023 .64015 m .57726 .63893 L .5789 .64026 L F
.336 .763 .973 r
.45165 .63052 m .45295 .62957 L .44987 .63107 L F
.45165 .63052 m .4541 .63036 L .45295 .62957 L F
.334 .604 .946 r
.23651 .54804 m .23573 .54938 L .23447 .54816 L F
.23651 .54804 m .23842 .54997 L .23573 .54938 L F
.637 .386 .522 r
.52515 .67666 m .52763 .67658 L .52824 .67402 L F
.227 0 .215 r
.52763 .67658 m .53085 .67396 L .52824 .67402 L F
.474 .323 .595 r
.20711 .5982 m .20917 .59765 L .20909 .59496 L F
.338 .124 .435 r
.20711 .5982 m .20851 .59981 L .20917 .59765 L F
.20711 .5982 m .20675 .60051 L .20851 .59981 L F
.628 .424 .587 r
.48493 .68818 m .48217 .69099 L .48243 .68914 L F
.397 .526 .869 r
.46579 .70912 m .46972 .71232 L .46826 .70899 L F
.283 .772 .7 r
.4028 .59107 m .40208 .5913 L .40046 .59197 L F
.086 0 0 r
.40126 .59269 m .40046 .59197 L .40208 .5913 L F
.40126 .59269 m .39903 .59338 L .40046 .59197 L F
.058 .313 .798 r
.46809 .72108 m .46919 .72026 L .46693 .72013 L F
.46809 .72108 m .47082 .72339 L .46919 .72026 L F
.332 .302 .675 r
.2438 .56175 m .24289 .56584 L .24199 .56324 L F
.386 .249 .57 r
.23325 .59469 m .23337 .59768 L .2313 .59801 L F
.108 0 .108 r
.23337 .59768 m .23079 .60021 L .2313 .59801 L F
.992 .864 .52 r
.59009 .63185 m .59074 .63296 L .59138 .63021 L F
.965 .759 .319 r
.59087 .6268 m .59078 .62942 L .59138 .63021 L F
.983 .881 .526 r
.59078 .62942 m .59009 .63185 L .59138 .63021 L F
.575 .185 .266 r
.48362 .61132 m .48579 .61192 L .48306 .61049 L F
.58 .921 .71 r
.62531 .44405 m .62391 .44552 L .62743 .44299 L F
.375 .841 .857 r
.62743 .44299 m .62745 .44229 L .62531 .44405 L F
.62743 .44299 m .62928 .44227 L .62745 .44229 L F
.528 .67 .927 r
.67758 .45263 m .68057 .4524 L .67893 .45051 L F
.67758 .45263 m .68057 .4524 L .67893 .45051 L F
.648 .52 .693 r
.68098 .45452 m .67758 .45263 L .68057 .4524 L F
.68098 .45452 m .67831 .45546 L .67758 .45263 L F
0 0 0 r
.49266 .69608 m .49319 .69466 L .49095 .69731 L F
.622 .795 .965 r
.57342 .62289 m .57275 .62495 L .57115 .62369 L F
.751 .706 .809 r
.50073 .71744 m .50196 .72104 L .4982 .72054 L F
.439 .274 .559 r
.50035 .72265 m .4982 .72054 L .50196 .72104 L F
.98 .782 .566 r
.50048 .72001 m .50196 .72104 L .50073 .71744 L F
.141 0 .004 r
.50561 .72337 m .50413 .72553 L .5059 .72386 L F
0 0 0 r
.50554 .72354 m .50523 .72398 L .50558 .72342 L F
.50523 .72398 m .50413 .72553 L .50503 .72421 L F
.50523 .72398 m .50503 .72421 L .50558 .72342 L F
.722 .281 .203 r
.50196 .72104 m .50553 .72359 L .50035 .72265 L F
.50553 .72359 m .50542 .72375 L .50035 .72265 L F
.87 .727 .701 r
.50542 .72375 m .50286 .72224 L .50035 .72265 L F
.722 .281 .203 r
.50553 .72359 m .5059 .72386 L .50542 .72375 L F
.87 .727 .701 r
.5059 .72386 m .50551 .72365 L .50542 .72375 L F
.50551 .72365 m .50286 .72224 L .50542 .72375 L F
.568 0 0 r
.50286 .72224 m .50551 .72365 L .50196 .72104 L F
.50551 .72365 m .5059 .72386 L .50553 .72359 L F
.50551 .72365 m .50553 .72359 L .50196 .72104 L F
.724 .208 0 r
.50601 .72417 m .50791 .72602 L .50646 .72511 L F
.50561 .72337 m .50704 .72501 L .50601 .72417 L F
.50704 .72501 m .50791 .72602 L .50601 .72417 L F
.50561 .72337 m .50595 .72406 L .50588 .72315 L F
.50595 .72406 m .50646 .72511 L .50588 .72315 L F
0 0 .297 r
.50561 .72337 m .5059 .72386 L .50588 .72315 L F
.821 .767 .802 r
.50588 .72315 m .5059 .72386 L .50551 .72365 L F
0 0 0 r
.50573 .72328 m .50554 .72354 L .50561 .72337 L F
.50554 .72354 m .50558 .72342 L .50561 .72337 L F
.50588 .72315 m .50527 .72399 L .50573 .72328 L F
.50561 .72337 m .50648 .72058 L .5046 .7219 L F
.50561 .72337 m .50588 .72315 L .50648 .72058 L F
.821 .767 .802 r
.50588 .72315 m .50551 .72365 L .50286 .72224 L F
0 0 0 r
.50533 .72389 m .50413 .72553 L .50484 .72453 L F
.50537 .72383 m .50484 .72453 L .50573 .72328 L F
.50533 .72389 m .50484 .72453 L .50537 .72383 L F
.87 .727 .701 r
.5059 .72386 m .50413 .72553 L .50551 .72365 L F
0 0 0 r
.50527 .72399 m .50413 .72553 L .50533 .72389 L F
.87 .727 .701 r
.50551 .72365 m .50413 .72553 L .50286 .72224 L F
.852 .72 .717 r
.50286 .72224 m .50413 .72553 L .50546 .72373 L F
.50409 .72262 m .50546 .72373 L .50588 .72315 L F
.50286 .72224 m .50546 .72373 L .50409 .72262 L F
.568 0 0 r
.50286 .72224 m .50196 .72104 L .50048 .72001 L F
.534 .292 .494 r
.4975 .71737 m .50073 .71744 L .50042 .71513 L F
.4975 .71737 m .49785 .71804 L .50073 .71744 L F
.4975 .71737 m .50073 .71744 L .50042 .71513 L F
.4975 .71737 m .49785 .71804 L .50073 .71744 L F
.779 .821 .885 r
.45703 .58563 m .45495 .58675 L .45311 .58581 L F
.91 .726 .642 r
.45495 .58675 m .4544 .58928 L .45311 .58581 L F
0 .027 .588 r
.58275 .6131 m .58078 .61013 L .58079 .60707 L F
.58275 .6131 m .5824 .61186 L .58078 .61013 L F
0 .081 .631 r
.58275 .6131 m .58445 .61487 L .5824 .61186 L F
.597 .243 .34 r
.47347 .72954 m .47547 .73139 L .47595 .73009 L F
.736 .486 .551 r
.535 .69669 m .53885 .69464 L .53539 .69478 L F
.535 .69669 m .5386 .69702 L .53885 .69464 L F
.584 .682 .908 r
.45657 .58278 m .45703 .58563 L .45597 .58257 L F
.45657 .58278 m .45948 .58533 L .45703 .58563 L F
0 0 0 r
.47836 .61479 m .48003 .6145 L .48163 .61323 L F
.046 0 .084 r
.47836 .61479 m .47751 .6173 L .48003 .6145 L F
.594 .466 .676 r
.19598 .61605 m .19846 .6181 L .19773 .61464 L F
.19598 .61605 m .1962 .61878 L .19846 .6181 L F
.203 0 .121 r
.55217 .67041 m .54825 .67391 L .54786 .6705 L F
.55217 .67041 m .55063 .67314 L .54825 .67391 L F
.693 .355 .4 r
.55217 .67041 m .5525 .67334 L .55063 .67314 L F
.888 .586 .078 r
.55328 .67463 m .5525 .67334 L .55217 .67041 L F
.872 .78 .757 r
.62728 .4191 m .62825 .4227 L .62862 .42006 L F
.57 .554 .797 r
.62825 .4227 m .63182 .42512 L .63184 .42304 L F
.545 .319 .522 r
.58489 .48702 m .58727 .48871 L .58469 .48931 L F
.689 .481 .601 r
.44789 .62735 m .44776 .63016 L .44552 .62907 L F
.615 .177 .186 r
.44612 .62687 m .45016 .62671 L .44789 .62735 L F
.972 .663 .36 r
.46186 .69666 m .46363 .70066 L .46321 .69749 L F
.267 .158 .539 r
.46442 .69983 m .46363 .70066 L .46321 .69749 L F
.972 .663 .36 r
.46186 .69666 m .46363 .70066 L .46321 .69749 L F
0 0 0 r
.48417 .61731 m .48515 .61597 L .48668 .6148 L F
.48163 .61323 m .48199 .61358 L .48362 .61132 L F
.48163 .61323 m .48003 .6145 L .48199 .61358 L F
.32 0 0 r
.37031 .58511 m .37265 .5851 L .37416 .58403 L F
.161 0 0 r
.18581 .54157 m .18395 .54157 L .18783 .5418 L F
0 0 0 r
.47198 .62987 m .47517 .62713 L .47391 .62858 L F
.207 0 0 r
.47715 .62659 m .47391 .62858 L .47517 .62713 L F
.635 .701 .894 r
.68019 .4126 m .67841 .41414 L .67795 .41424 L F
.68019 .4126 m .68092 .41344 L .67841 .41414 L F
.813 .411 .29 r
.46443 .7059 m .4673 .70344 L .46643 .70431 L F
0 0 0 r
.46643 .70431 m .4673 .70344 L .46759 .70321 L F
.817 .656 .107 r
.55271 .67675 m .5525 .67334 L .55328 .67463 L F
.658 .874 .98 r
.41811 .5768 m .41939 .57456 L .42106 .57568 L F
.41811 .5768 m .4167 .57587 L .41939 .57456 L F
.235 .646 .959 r
.58048 .6058 m .58016 .60423 L .57814 .60451 L F
.58048 .6058 m .58199 .60531 L .58016 .60423 L F
.724 .915 .959 r
.57711 .60635 m .58048 .6058 L .57814 .60451 L F
.97 .879 .687 r
.67794 .42324 m .67709 .42553 L .67606 .42413 L F
.97 .875 .683 r
.67692 .42198 m .67794 .42324 L .67606 .42413 L F
.193 .72 .846 r
.6956 .442 m .69348 .44223 L .69234 .43919 L F
.6956 .442 m .69576 .44197 L .69348 .44223 L F
.757 .666 .761 r
.69676 .44286 m .69348 .44223 L .69576 .44197 L F
.69676 .44286 m .69456 .44448 L .69348 .44223 L F
.676 .508 .651 r
.69676 .44286 m .6945 .44579 L .69456 .44448 L F
.652 .475 .632 r
.69676 .44286 m .69647 .44633 L .6945 .44579 L F
.601 .868 .993 r
.69676 .44286 m .69576 .44197 L .69911 .44185 L F
.714 .53 .639 r
.70008 .44534 m .69676 .44286 L .69911 .44185 L F
.70008 .44534 m .69647 .44633 L .69676 .44286 L F
.76 .288 .123 r
.52347 .70001 m .5212 .7003 L .52405 .69901 L F
.52347 .70001 m .52463 .70085 L .52168 .70037 L F
.364 .686 .98 r
.52535 .69884 m .52347 .70001 L .52405 .69901 L F
.52535 .69884 m .52721 .70031 L .52347 .70001 L F
.105 0 0 r
.52348 .70156 m .52093 .70312 L .52105 .70185 L F
.52463 .70085 m .52328 .7024 L .52093 .70312 L F
.747 .814 .905 r
.51941 .70131 m .51708 .70232 L .52026 .70168 L F
.827 .529 .485 r
.51941 .70158 m .51708 .70232 L .51941 .70131 L F
.669 .898 .978 r
.51708 .70232 m .51833 .70193 L .52026 .70168 L F
.51687 .70211 m .51907 .70168 L .52026 .70168 L F
.51645 .7017 m .51953 .70158 L .52026 .70168 L F
.827 .529 .485 r
.519 .70205 m .51708 .70232 L .51895 .70173 L F
.51938 .70489 m .51713 .70237 L .519 .70205 L F
.51713 .70237 m .51708 .70232 L .519 .70205 L F
.51938 .70489 m .51895 .70173 L .51941 .7018 L F
.51938 .70489 m .51941 .70158 L .51953 .7017 L F
.51951 .70474 m .51953 .7017 L .52093 .70312 L F
.51938 .70489 m .51953 .7017 L .51951 .70474 L F
.669 .898 .978 r
.51708 .70232 m .51687 .70211 L .51833 .70193 L F
.51687 .70211 m .51645 .7017 L .51907 .70168 L F
.51645 .7017 m .51581 .70108 L .51953 .70158 L F
.987 .712 .378 r
.51708 .70232 m .51609 .70323 L .51581 .70108 L F
.51708 .70232 m .51696 .70473 L .51609 .70323 L F
.827 .529 .485 r
.51938 .70489 m .51696 .70473 L .51708 .70232 L F
.222 0 0 r
.51609 .70323 m .51953 .70195 L .51581 .70108 L F
.51953 .70195 m .52026 .70168 L .51953 .70158 L F
.827 .529 .485 r
.51941 .7018 m .51895 .70173 L .51941 .70158 L F
.222 0 0 r
.51953 .70195 m .51953 .70158 L .51581 .70108 L F
.827 .529 .485 r
.51941 .70158 m .51963 .70157 L .52093 .70312 L F
.222 0 0 r
.51609 .70323 m .51809 .70316 L .51994 .70189 L F
.261 0 .251 r
.52026 .70168 m .52049 .70171 L .52115 .70105 L F
.761 .663 .754 r
.52111 .70129 m .52108 .70158 L .52062 .70158 L F
.52111 .70129 m .52062 .70158 L .52087 .70133 L F
.261 0 .251 r
.52049 .70171 m .52062 .70173 L .52113 .70108 L F
.52049 .70171 m .52113 .70108 L .52115 .70105 L F
.747 .814 .905 r
.51941 .70131 m .52026 .70168 L .5212 .7003 L F
.761 .663 .754 r
.52087 .70133 m .52062 .70158 L .51963 .70157 L F
.52105 .70185 m .52093 .70312 L .52008 .7018 L F
.261 0 .218 r
.52045 .70193 m .52037 .70182 L .51977 .70201 L F
.52037 .70182 m .52026 .70168 L .52008 .7018 L F
.761 .663 .754 r
.52008 .7018 m .52093 .70312 L .51986 .70185 L F
.261 0 .218 r
.52037 .70182 m .52008 .7018 L .51977 .70201 L F
0 0 0 r
.52093 .70312 m .52328 .7024 L .52168 .70358 L F
.638 .878 .986 r
.52328 .7024 m .52381 .70109 L .52168 .70358 L F
.261 0 .218 r
.52168 .70358 m .52298 .70206 L .52049 .70171 L F
.105 0 0 r
.52463 .70085 m .52348 .70156 L .52113 .70108 L F
.52348 .70156 m .52105 .70185 L .52113 .70108 L F
.52463 .70085 m .52115 .70107 L .52168 .70037 L F
.52115 .70107 m .52113 .70108 L .52115 .70105 L F
.52115 .70107 m .52115 .70105 L .52168 .70037 L F
.261 0 .251 r
.52026 .70168 m .52115 .70105 L .5212 .7003 L F
.105 0 0 r
.52168 .70037 m .52113 .70108 L .5212 .7003 L F
.76 .288 .123 r
.52165 .70024 m .52168 .70037 L .5212 .7003 L F
.52347 .70001 m .52168 .70037 L .52165 .70024 L F
.261 0 .251 r
.52115 .70105 m .52405 .69901 L .5212 .7003 L F
.52174 .70064 m .523 .70203 L .52405 .69901 L F
.523 .70203 m .52303 .70206 L .52307 .70195 L F
.523 .70203 m .52307 .70195 L .52405 .69901 L F
.52202 .70192 m .52303 .70206 L .52174 .70064 L F
.638 .878 .986 r
.52298 .70206 m .52402 .70056 L .52168 .70358 L F
.52381 .70109 m .52383 .70103 L .52298 .70206 L F
.52383 .70103 m .52402 .70056 L .52298 .70206 L F
.261 0 .218 r
.52168 .70358 m .52303 .70206 L .52298 .70206 L F
.52037 .70182 m .52049 .70171 L .52026 .70168 L F
.52168 .70358 m .52049 .70171 L .52037 .70182 L F
.761 .663 .754 r
.52108 .70158 m .52105 .70185 L .52038 .70182 L F
.52108 .70158 m .52037 .70182 L .52049 .70171 L F
.261 0 .251 r
.52062 .70173 m .52202 .70192 L .52115 .70105 L F
.52113 .70108 m .52115 .70105 L .52115 .70105 L F
.761 .663 .754 r
.5212 .7003 m .52111 .70129 L .51941 .70131 L F
.261 0 .251 r
.52062 .70173 m .52115 .70105 L .52113 .70108 L F
.761 .663 .754 r
.52038 .70181 m .52038 .70182 L .52037 .70182 L F
.52108 .70158 m .52038 .70182 L .52038 .70181 L F
.52049 .70171 m .52037 .70182 L .52008 .7018 L F
.222 0 0 r
.51969 .70189 m .52008 .7018 L .52026 .70168 L F
.761 .663 .754 r
.52108 .70158 m .51986 .70185 L .51963 .70157 L F
.222 0 0 r
.51945 .70198 m .51994 .70189 L .52008 .7018 L F
.51945 .70198 m .52008 .7018 L .51969 .70189 L F
.51609 .70323 m .51994 .70189 L .51945 .70198 L F
0 0 0 r
.52093 .70312 m .52168 .70358 L .51938 .70489 L F
.261 0 .218 r
.52168 .70358 m .52049 .70198 L .51809 .70316 L F
.52049 .70198 m .52045 .70193 L .52038 .70196 L F
.52049 .70198 m .52038 .70196 L .51809 .70316 L F
.761 .663 .754 r
.52111 .70129 m .51963 .70157 L .51941 .70131 L F
.827 .529 .485 r
.51941 .70158 m .51941 .70131 L .51963 .70157 L F
.261 0 .218 r
.52045 .70193 m .51977 .70201 L .51809 .70316 L F
.261 0 .251 r
.52115 .70105 m .52202 .70192 L .52174 .70064 L F
.624 .346 .475 r
.60527 .48058 m .60162 .48331 L .60152 .48119 L F
.60527 .48058 m .60401 .48352 L .60162 .48331 L F
.594 .314 .461 r
.60806 .48159 m .60527 .48058 L .6076 .4806 L F
.60806 .48159 m .60401 .48352 L .60527 .48058 L F
.633 .847 .982 r
.42659 .57495 m .42472 .5759 L .42317 .57489 L F
0 .096 .598 r
.55735 .63849 m .55767 .63854 L .55617 .63724 L F
0 .307 .723 r
.55938 .63971 m .55767 .63854 L .55735 .63849 L F
0 0 0 r
.45948 .58533 m .45897 .58783 L .45874 .5884 L F
.681 .896 .975 r
.34794 .62777 m .34708 .62988 L .3501 .63023 L F
.186 .527 .921 r
.3501 .63023 m .35046 .6282 L .34794 .62777 L F
.373 .49 .849 r
.3696 .6364 m .37133 .63992 L .37223 .63772 L F
.628 .377 .519 r
.60152 .48119 m .59978 .483 L .60011 .48146 L F
.60152 .48119 m .60162 .48331 L .59978 .483 L F
0 .272 .714 r
.55386 .63592 m .55489 .63621 L .55259 .63475 L F
.55386 .63592 m .55617 .63724 L .55489 .63621 L F
.035 0 0 r
.39004 .63978 m .38942 .63952 L .39187 .63936 L F
.39004 .63978 m .38764 .64005 L .38942 .63952 L F
.506 .227 .425 r
.48288 .70359 m .48475 .70538 L .48237 .70565 L F
.48288 .70359 m .48544 .70307 L .48475 .70538 L F
.598 .514 .73 r
.48288 .70359 m .48544 .70307 L .48594 .69979 L F
.506 .227 .425 r
.48475 .70538 m .48288 .70359 L .48237 .70565 L F
.48475 .70538 m .48544 .70307 L .48288 .70359 L F
.651 .613 .799 r
.53241 .69722 m .53366 .70114 L .53611 .69982 L F
.758 .69 .786 r
.21373 .58236 m .20819 .58142 L .21118 .58014 L F
.21373 .58236 m .20904 .58281 L .20819 .58142 L F
.148 0 .147 r
.20991 .58369 m .20904 .58281 L .21373 .58236 L F
.105 0 0 r
.21219 .58327 m .21373 .58236 L .21478 .58262 L F
.21219 .58327 m .20991 .58369 L .21373 .58236 L F
.611 .272 .373 r
.54048 .68315 m .53869 .68538 L .53609 .68488 L F
.772 .483 .497 r
.54197 .68557 m .53869 .68538 L .54048 .68315 L F
.586 .582 .815 r
.34597 .62135 m .34693 .61744 L .34485 .61779 L F
.34597 .62135 m .34838 .62097 L .34693 .61744 L F
.915 .954 .62 r
.51318 .68178 m .51205 .68555 L .51619 .68326 L F
.242 .665 .961 r
.51619 .68326 m .51622 .68295 L .51318 .68178 L F
.569 .193 .289 r
.49671 .69713 m .49299 .69951 L .49286 .69781 L F
.49671 .69713 m .49542 .69945 L .49299 .69951 L F
.559 .192 .3 r
.49911 .69723 m .49542 .69945 L .49671 .69713 L F
.781 .548 .583 r
.49571 .72333 m .49185 .72338 L .49331 .72411 L F
.49 .335 .596 r
.23954 .58 m .23918 .583 L .23701 .58357 L F
.36 .077 .342 r
.23918 .583 m .23673 .58553 L .23701 .58357 L F
.635 .256 .308 r
.20035 .60295 m .20456 .60122 L .20057 .60047 L F
.20035 .60295 m .20299 .60303 L .20456 .60122 L F
.608 .223 .287 r
.20456 .60122 m .20299 .60303 L .20639 .60291 L F
.471 .249 .495 r
.20456 .60122 m .20639 .60291 L .20675 .60051 L F
.627 .778 .954 r
.33979 .62644 m .3415 .62799 L .34352 .62704 L F
.34352 .62704 m .3415 .62799 L .33979 .62644 L F
.33979 .62644 m .3415 .62799 L .34352 .62704 L F
.543 .919 .774 r
.63237 .47611 m .63399 .47556 L .63604 .47415 L F
.058 0 .017 r
.52746 .68528 m .52665 .68743 L .52465 .68847 L F
.818 .586 .587 r
.52995 .68488 m .52665 .68743 L .52746 .68528 L F
.7 .685 .832 r
.47321 .73277 m .47464 .73568 L .47733 .73463 L F
.098 0 0 r
.4167 .62439 m .41743 .62538 L .41886 .62465 L F
.4167 .62439 m .41536 .62624 L .41743 .62538 L F
.838 .646 .642 r
.58676 .64345 m .59006 .64139 L .58725 .64113 L F
.58676 .64345 m .58864 .64469 L .59006 .64139 L F
.255 0 .205 r
.53274 .67076 m .53518 .67035 L .53584 .66769 L F
.011 0 .119 r
.53584 .66769 m .53661 .66917 L .53821 .66754 L F
.53584 .66769 m .53518 .67035 L .53661 .66917 L F
.535 .272 .463 r
.52919 .70886 m .53185 .70842 L .53121 .70661 L F
.336 .713 .984 r
.58023 .64015 m .57985 .6391 L .57726 .63893 L F
.307 .604 .951 r
.58146 .64052 m .57985 .6391 L .58023 .64015 L F
.789 .29 0 r
.65715 .4295 m .65732 .42822 L .6561 .42725 L F
.65715 .4295 m .65898 .43148 L .65732 .42822 L F
.332 .302 .675 r
.2438 .56175 m .24424 .56513 L .24289 .56584 L F
.489 .457 .749 r
.24424 .56513 m .24275 .56737 L .24289 .56584 L F
.69 .637 .791 r
.69348 .44223 m .69456 .44448 L .69098 .44344 L F
.718 .566 .682 r
.6945 .44579 m .69098 .44344 L .69456 .44448 L F
.777 .789 .863 r
.639 .41873 m .64033 .4202 L .64146 .41879 L F
.435 .482 .809 r
.19933 .60535 m .20168 .60635 L .20035 .60295 L F
.054 0 .255 r
.21359 .63498 m .21237 .63607 L .21423 .63291 L F
.149 0 .284 r
.21296 .63717 m .21237 .63607 L .21359 .63498 L F
.21296 .63717 m .21161 .63831 L .21237 .63607 L F
.613 .357 .505 r
.57438 .49281 m .57685 .49501 L .57397 .4958 L F
.57438 .49281 m .57657 .49259 L .57685 .49501 L F
.532 .138 .239 r
.61589 .47871 m .61946 .47801 L .61837 .47992 L F
.596 .119 .093 r
.61946 .47801 m .62153 .47946 L .61837 .47992 L F
.61946 .47801 m .62197 .47856 L .62153 .47946 L F
.292 0 0 r
.62441 .47879 m .62197 .47856 L .62499 .47737 L F
.314 0 0 r
.62499 .47737 m .62664 .47847 L .62441 .47879 L F
.62499 .47737 m .62782 .47689 L .62664 .47847 L F
.394 .112 .363 r
.38006 .60203 m .37814 .60104 L .38002 .60026 L F
.38006 .60203 m .37762 .60279 L .37814 .60104 L F
0 0 0 r
.516 .6518 m .51884 .65025 L .51895 .65069 L F
0 0 .009 r
.51884 .65025 m .52153 .64757 L .52153 .64973 L F
.014 0 0 r
.51895 .65069 m .51884 .65025 L .52153 .64973 L F
.134 0 0 r
.44031 .62357 m .44412 .62412 L .44461 .62415 L F
.84 .447 .304 r
.44273 .62536 m .44461 .62415 L .44412 .62412 L F
.44273 .62536 m .44612 .62687 L .44461 .62415 L F
.532 .138 .239 r
.61589 .47871 m .61837 .47992 L .61586 .48008 L F
.61 .666 .879 r
.44752 .58094 m .44232 .57726 L .44446 .5766 L F
.764 .678 .768 r
.4483 .57729 m .44752 .58094 L .44446 .5766 L F
.425 .674 .966 r
.47076 .73272 m .47321 .73277 L .47183 .7313 L F
.335 .139 .458 r
.34576 .59221 m .34547 .59457 L .34755 .5914 L F
.357 .085 .357 r
.34068 .598 m .34272 .59742 L .3433 .59514 L F
.382 .107 .367 r
.3433 .59514 m .34488 .59674 L .34547 .59457 L F
.3433 .59514 m .34272 .59742 L .34488 .59674 L F
.174 .431 .865 r
.55172 .69249 m .55291 .6932 L .55156 .69076 L F
.647 .427 .57 r
.60011 .48146 m .59978 .483 L .59563 .48401 L F
.173 .116 .547 r
.63398 .41732 m .6355 .41857 L .63534 .41568 L F
.63398 .41732 m .6338 .42001 L .6355 .41857 L F
.357 .226 .561 r
.24056 .57436 m .2407 .5769 L .23902 .57743 L F
.366 .25 .586 r
.2407 .5769 m .24081 .57936 L .23902 .57743 L F
.277 .235 .629 r
.23902 .57743 m .24081 .57936 L .23954 .58 L F
.669 .347 .42 r
.62748 .45081 m .631 .449 L .62902 .44901 L F
.62748 .45081 m .63161 .45137 L .631 .449 L F
.56 .281 .45 r
.631 .449 m .63161 .45137 L .63359 .45065 L F
.128 .651 .881 r
.2093 .54308 m .21153 .54313 L .21316 .54368 L F
0 .54 .745 r
.21153 .54313 m .21525 .5436 L .21316 .54368 L F
.349 .24 .586 r
.19435 .62434 m .19625 .62413 L .19696 .62198 L F
.01 0 0 r
.1936 .62615 m .19625 .62413 L .19435 .62434 L F
.519 .421 .683 r
.37098 .61252 m .37095 .61439 L .36857 .61338 L F
.581 .766 .967 r
.36265 .63354 m .36416 .63531 L .36653 .63464 L F
.402 0 .061 r
.43011 .63074 m .43213 .63153 L .42964 .63158 L F
.398 0 .108 r
.43243 .6305 m .43213 .63153 L .43011 .63074 L F
.389 .246 .562 r
.33916 .60371 m .34097 .60302 L .341 .60057 L F
.459 .372 .671 r
.33932 .60693 m .34097 .60302 L .33916 .60371 L F
.447 .056 .203 r
.50507 .69449 m .50149 .6969 L .50154 .69448 L F
.50507 .69449 m .50389 .69669 L .50149 .6969 L F
.566 .514 .756 r
.50681 .69098 m .50507 .69449 L .50453 .69151 L F
.50681 .69098 m .5074 .69404 L .50507 .69449 L F
.49 .134 .289 r
.5074 .69404 m .50389 .69669 L .50507 .69449 L F
.201 0 .113 r
.55521 .68373 m .55573 .68277 L .55476 .68269 L F
.453 .347 .644 r
.2346 .58986 m .23497 .59155 L .23299 .5922 L F
.415 .249 .546 r
.23497 .59155 m .2348 .59407 L .23299 .5922 L F
.332 .24 .599 r
.23299 .5922 m .2348 .59407 L .23325 .59469 L F
0 .425 .789 r
.57547 .63834 m .57726 .63893 L .57589 .63816 L F
.413 .863 .847 r
.67699 .4555 m .67831 .45546 L .68098 .45452 L F
.599 .473 .681 r
.45175 .57739 m .44965 .58029 L .4483 .57729 L F
.45175 .57739 m .45185 .58007 L .44965 .58029 L F
.713 .286 .233 r
.53345 .68548 m .53232 .68721 L .52995 .68488 L F
.441 .029 .159 r
.53609 .68488 m .53232 .68721 L .53345 .68548 L F
.86 .825 .812 r
.5671 .6452 m .56789 .6476 L .56988 .64473 L F
.234 .073 .447 r
.22441 .61729 m .22326 .61561 L .22455 .61481 L F
.22441 .61729 m .22299 .61806 L .22326 .61561 L F
.866 .766 .749 r
.66397 .44501 m .66721 .44106 L .66293 .4419 L F
.439 .241 .514 r
.24275 .56737 m .24058 .57134 L .23983 .56865 L F
.24275 .56737 m .2426 .57087 L .24058 .57134 L F
.489 .457 .749 r
.24424 .56513 m .24472 .56751 L .24275 .56737 L F
.387 .161 .444 r
.24472 .56751 m .2426 .57087 L .24275 .56737 L F
.626 .584 .787 r
.69236 .43733 m .69234 .43919 L .68981 .43988 L F
.654 .542 .714 r
.69348 .44223 m .68981 .43988 L .69234 .43919 L F
.69348 .44223 m .69098 .44344 L .68981 .43988 L F
.813 .773 .816 r
.60258 .44557 m .60332 .44859 L .60012 .44844 L F
.792 .762 .825 r
.60589 .44583 m .60332 .44859 L .60258 .44557 L F
.637 .644 .841 r
.20904 .58281 m .20661 .58327 L .20819 .58142 L F
0 0 .011 r
.20661 .58327 m .20772 .58307 L .20819 .58142 L F
.495 .157 .323 r
.20904 .58281 m .20815 .58478 L .20661 .58327 L F
0 .114 .654 r
.20661 .58327 m .20815 .58478 L .20772 .58307 L F
.671 .523 .675 r
.63184 .42304 m .6343 .42244 L .6338 .42001 L F
.784 .808 .872 r
.6343 .42244 m .6355 .41857 L .6338 .42001 L F
.313 .477 .863 r
.38019 .62051 m .37919 .62259 L .3777 .62112 L F
.38019 .62051 m .38172 .62337 L .37919 .62259 L F
.419 .821 .981 r
.51626 .73316 m .51747 .7321 L .51504 .73114 L F
.51626 .73316 m .519 .73272 L .51747 .7321 L F
.185 0 0 r
.37675 .58379 m .37828 .58414 L .38027 .58348 L F
0 0 0 r
.37828 .58414 m .38269 .58315 L .38027 .58348 L F
.679 .263 .25 r
.42142 .62532 m .42526 .62436 L .4227 .62438 L F
.323 .2 .553 r
.21906 .56872 m .22055 .56799 L .22051 .56549 L F
.322 .161 .502 r
.21906 .56872 m .2204 .5707 L .22055 .56799 L F
.21906 .56872 m .21888 .57162 L .2204 .5707 L F
.014 .552 .844 r
.38704 .62665 m .38681 .62697 L .38555 .62583 L F
.353 .771 .978 r
.19301 .55395 m .19085 .55343 L .18708 .55309 L F
.503 0 0 r
.19301 .55395 m .19412 .55432 L .19085 .55343 L F
.705 .19 0 r
.19412 .55432 m .19243 .55496 L .19085 .55343 L F
.47 0 0 r
.19596 .55534 m .19243 .55496 L .19412 .55432 L F
.976 .774 .565 r
.54061 .71595 m .5388 .71674 L .53896 .71419 L F
.53896 .71419 m .54061 .71595 L .5425 .71461 L F
.53896 .71419 m .5388 .71674 L .54061 .71595 L F
.593 .425 .623 r
.56393 .60379 m .56377 .60084 L .56135 .60389 L F
.565 .294 .463 r
.56393 .60379 m .56369 .60574 L .56135 .60389 L F
.593 .425 .623 r
.56135 .60389 m .56377 .60084 L .56393 .60379 L F
.565 .294 .463 r
.56393 .60379 m .56369 .60574 L .56135 .60389 L F
.593 .425 .623 r
.56393 .60379 m .56377 .60084 L .56135 .60389 L F
.719 .823 .93 r
.57868 .6321 m .57702 .63505 L .57588 .63474 L F
.57868 .6321 m .5801 .63341 L .57702 .63505 L F
.644 .419 .562 r
.19696 .62198 m .19846 .6181 L .1962 .61878 L F
.337 0 0 r
.20013 .55508 m .19823 .55559 L .19596 .55534 L F
.261 .762 .717 r
.20032 .55489 m .20013 .55508 L .20169 .5549 L F
.20032 .55489 m .19823 .55559 L .20013 .55508 L F
.284 .059 .386 r
.54086 .66229 m .54268 .66192 L .54329 .66046 L F
.366 .353 .712 r
.54086 .66229 m .54224 .66489 L .54268 .66192 L F
.691 .688 .842 r
.54065 .66498 m .54224 .66489 L .54086 .66229 L F
.698 .178 0 r
.4798 .68574 m .47906 .68473 L .47722 .68475 L F
.571 .774 .974 r
.51756 .72818 m .51872 .72951 L .51809 .72911 L F
.528 .879 .986 r
.51976 .72824 m .51872 .72951 L .51756 .72818 L F
.51976 .72824 m .52161 .72882 L .51872 .72951 L F
.445 .223 .481 r
.52161 .72882 m .519 .73272 L .51872 .72951 L F
0 0 0 r
.56892 .48889 m .56927 .48681 L .56704 .48983 L F
.56904 .48872 m .56927 .48681 L .56892 .48889 L F
.357 .113 .401 r
.57129 .48596 m .57172 .48396 L .56927 .48681 L F
.136 0 .001 r
.57129 .48596 m .56927 .48681 L .56903 .48883 L F
0 0 .38 r
.56704 .48983 m .56846 .49083 L .56902 .48884 L F
.855 .694 .681 r
.56808 .48974 m .56902 .48883 L .56846 .49083 L F
.56902 .48883 m .57022 .48769 L .56846 .49083 L F
0 0 .38 r
.56902 .48884 m .56846 .49083 L .56903 .48884 L F
.136 0 .001 r
.56904 .48882 m .56903 .48883 L .56903 .48884 L F
.57129 .48596 m .56903 .48883 L .56904 .48882 L F
.57129 .48596 m .56904 .48882 L .57024 .48767 L F
.855 .694 .681 r
.56719 .48718 m .56984 .48763 L .56808 .48974 L F
.56984 .48763 m .57022 .48769 L .56903 .48883 L F
0 0 0 r
.56902 .48884 m .56904 .48872 L .56892 .48889 L F
.56903 .48883 m .56904 .48872 L .56902 .48884 L F
.855 .694 .681 r
.56984 .48763 m .56903 .48883 L .56808 .48974 L F
0 0 0 r
.56903 .48884 m .56903 .48883 L .56902 .48884 L F
.136 0 .001 r
.56904 .48882 m .56903 .48884 L .57024 .48767 L F
.855 .694 .681 r
.57021 .48769 m .57024 .48767 L .57022 .48769 L F
.56719 .48718 m .57024 .48767 L .57021 .48769 L F
.847 .73 .734 r
.56896 .4841 m .5701 .48728 L .56719 .48718 L F
.5701 .48728 m .57024 .48767 L .56986 .48761 L F
.5701 .48728 m .56986 .48761 L .56719 .48718 L F
.681 .867 .474 r
.58062 .6168 m .58182 .61525 L .57997 .61818 L F
.307 .46 .85 r
.5831 .6211 m .58177 .61812 L .57997 .61818 L F
.159 .664 .906 r
.18783 .5418 m .18992 .54189 L .19163 .54249 L F
.451 .839 .984 r
.18992 .54189 m .19374 .54192 L .19163 .54249 L F
.407 .271 .581 r
.22901 .60332 m .22858 .60637 L .22692 .60685 L F
.409 .272 .582 r
.22868 .60852 m .22692 .60685 L .22858 .60637 L F
.22868 .60852 m .22698 .60931 L .22692 .60685 L F
.67 .52 .673 r
.63182 .42512 m .6343 .42244 L .63184 .42304 L F
.718 .566 .682 r
.6945 .44579 m .69105 .44646 L .69098 .44344 L F
.724 .428 .478 r
.62546 .44838 m .62748 .45081 L .62902 .44901 L F
.343 0 0 r
.4215 .63277 m .42239 .63406 L .42016 .63375 L F
.4215 .63277 m .42388 .63263 L .42239 .63406 L F
.874 .755 .728 r
.42231 .61455 m .42593 .61241 L .4228 .6129 L F
.42231 .61455 m .42411 .6157 L .42593 .61241 L F
.851 .721 .719 r
.62559 .42771 m .62769 .42433 L .62622 .42547 L F
.965 .647 .355 r
.62592 .41786 m .62722 .41718 L .62728 .4191 L F
.62592 .41786 m .62722 .41718 L .62728 .4191 L F
.824 .605 .607 r
.62862 .42006 m .62722 .41718 L .62728 .4191 L F
.401 .841 .939 r
.40889 .57789 m .41112 .57734 L .41245 .5776 L F
.433 .858 .946 r
.41245 .5776 m .41339 .57668 L .41483 .57727 L F
.41245 .5776 m .41112 .57734 L .41339 .57668 L F
.058 .224 .721 r
.56339 .64118 m .5648 .64458 L .56545 .64325 L F
.286 .517 .902 r
.5648 .64458 m .5671 .6452 L .56545 .64325 L F
.462 .064 .198 r
.46274 .59099 m .46534 .58995 L .46423 .5923 L F
.551 .603 .859 r
.46534 .58995 m .46678 .59191 L .46423 .5923 L F
.48 .232 .46 r
.46678 .59191 m .46407 .59439 L .46423 .5923 L F
.922 .711 .219 r
.46094 .69279 m .46111 .695 L .46049 .69339 L F
0 0 .308 r
.46111 .695 m .46186 .69666 L .46049 .69339 L F
.86 .825 .812 r
.5671 .6452 m .56988 .64473 L .56872 .64373 L F
.868 .878 .841 r
.56362 .49425 m .56478 .49639 L .56237 .49836 L F
.601 .183 .222 r
.56478 .49639 m .56463 .4976 L .56237 .49836 L F
.937 .882 .755 r
.5665 .49198 m .56478 .49639 L .56362 .49425 L F
.797 .524 .525 r
.48006 .70609 m .47643 .7032 L .47641 .70578 L F
.984 .702 .388 r
.5886 .6049 m .58972 .60378 L .58773 .60287 L F
.5886 .6049 m .58993 .60626 L .58972 .60378 L F
.64 .197 .181 r
.51348 .69428 m .50937 .69424 L .51092 .69474 L F
.64 .702 .891 r
.58561 .64559 m .58676 .64345 L .58479 .64379 L F
.58561 .64559 m .58864 .64469 L .58676 .64345 L F
0 0 0 r
.57461 .48152 m .57172 .48396 L .57277 .4823 L F
.79 .384 .283 r
.49286 .69781 m .49299 .69951 L .49095 .69731 L F
.729 .723 .845 r
.62067 .45814 m .61802 .46069 L .62085 .46045 L F
.725 .53 .627 r
.61802 .46069 m .62157 .46384 L .62085 .46045 L F
.188 0 .362 r
.62085 .46045 m .62375 .45759 L .62067 .45814 L F
.62085 .46045 m .62308 .45948 L .62375 .45759 L F
.31 .257 .634 r
.62085 .46045 m .62157 .46384 L .62308 .45948 L F
0 0 .461 r
.59215 .62082 m .59169 .62138 L .5915 .61803 L F
.335 .489 .864 r
.47983 .68985 m .48054 .6881 L .47886 .68781 L F
.47983 .68985 m .48217 .69099 L .48054 .6881 L F
.438 0 0 r
.46094 .69279 m .46049 .69339 L .46419 .69371 L F
.98 .686 .373 r
.6294 .41377 m .62956 .41605 L .62828 .41488 L F
.576 .651 .887 r
.63171 .41194 m .63218 .41374 L .6294 .41377 L F
.832 .808 .827 r
.62956 .41605 m .6294 .41377 L .62828 .41488 L F
.59 .372 .552 r
.6294 .41377 m .63218 .41374 L .62956 .41605 L F
.832 .808 .827 r
.62956 .41605 m .63171 .41194 L .6294 .41377 L F
.607 .062 0 r
.56377 .60084 m .5673 .60372 L .56393 .60379 L F
.487 .344 .612 r
.56393 .60379 m .56643 .60332 L .56377 .60084 L F
.607 .062 0 r
.56377 .60084 m .56643 .60332 L .5673 .60372 L F
.964 .85 .438 r
.59061 .62474 m .59158 .62292 L .59097 .623 L F
.59061 .62474 m .59087 .6268 L .59158 .62292 L F
.997 .778 .434 r
.6417 .47204 m .64221 .47233 L .64209 .46958 L F
.677 .843 .962 r
.64209 .46958 m .64351 .46777 L .64139 .46816 L F
.64209 .46958 m .64458 .46904 L .64351 .46777 L F
.692 .539 .675 r
.64209 .46958 m .64221 .47233 L .64458 .46904 L F
.949 .605 .211 r
.6544 .42386 m .6561 .42725 L .65446 .42557 L F
.566 .579 .825 r
.44088 .57411 m .43989 .57789 L .43858 .57484 L F
.44088 .57411 m .44232 .57726 L .43989 .57789 L F
.42 .143 .384 r
.69352 .44732 m .69105 .44646 L .6945 .44579 L F
.65 .111 0 r
.6945 .44579 m .696 .44765 L .69352 .44732 L F
.6945 .44579 m .69725 .44802 L .696 .44765 L F
.633 .194 .189 r
.69647 .44633 m .69725 .44802 L .6945 .44579 L F
.778 .574 .623 r
.51875 .64773 m .52153 .64757 L .52099 .64435 L F
.607 .354 .508 r
.52415 .6472 m .52099 .64435 L .52153 .64757 L F
.922 .532 .161 r
.5534 .66107 m .55408 .65989 L .55223 .65857 L F
.5534 .66107 m .55467 .66198 L .55408 .65989 L F
.43 .014 .146 r
.21347 .57875 m .21573 .57686 L .21425 .5774 L F
.632 .801 .964 r
.63226 .44028 m .63065 .43948 L .63083 .44018 L F
.871 .496 .333 r
.63083 .44018 m .63094 .44139 L .63226 .44028 L F
.506 .81 1 r
.45185 .58233 m .45424 .58152 L .45243 .58145 L F
.563 .56 .808 r
.45126 .58324 m .45185 .58233 L .45152 .58108 L F
.803 .74 .794 r
.44413 .58264 m .44712 .58491 L .45152 .58108 L F
.44413 .58264 m .44562 .58233 L .44666 .58286 L F
.44562 .58233 m .45152 .58108 L .44827 .58227 L F
.44562 .58233 m .44827 .58227 L .44666 .58286 L F
.283 .77 .693 r
.45048 .58139 m .44666 .58286 L .45152 .58108 L F
.45048 .58139 m .45152 .58108 L .45185 .58233 L F
.506 .81 1 r
.45165 .58219 m .45243 .58145 L .45048 .58139 L F
.45185 .58233 m .45195 .58219 L .45165 .58219 L F
.45195 .58219 m .45243 .58145 L .45165 .58219 L F
.563 .56 .808 r
.45087 .58629 m .45185 .58233 L .45126 .58324 L F
.45087 .58629 m .45311 .58581 L .45185 .58233 L F
.827 .991 .866 r
.57565 .48005 m .57461 .48152 L .57277 .4823 L F
.118 0 .428 r
.26046 .77831 m .25931 .77936 L .25963 .78044 L F
.929 .663 .182 r
.57529 .60345 m .5744 .59973 L .57508 .6008 L F
0 0 0 r
.57684 .59917 m .5781 .59753 L .57508 .6008 L F
.57684 .59917 m .57508 .6008 L .5744 .59973 L F
.053 0 0 r
.52463 .70085 m .52532 .70138 L .52328 .7024 L F
.52463 .70085 m .52721 .70031 L .52532 .70138 L F
.464 .347 .636 r
.34068 .598 m .34294 .59998 L .34272 .59742 L F
.458 .347 .641 r
.341 .60057 m .34294 .59998 L .34068 .598 L F
.599 .519 .736 r
.51075 .68643 m .5089 .68601 L .51205 .68555 L F
.896 .967 .65 r
.51064 .68534 m .51075 .68643 L .51205 .68555 L F
0 .013 .572 r
.66474 .42809 m .66685 .43122 L .66587 .43002 L F
.964 .722 .282 r
.66685 .43122 m .6662 .43227 L .66587 .43002 L F
.66685 .43122 m .6669 .43361 L .6662 .43227 L F
.881 .902 .839 r
.67606 .42413 m .67709 .42553 L .67517 .42769 L F
0 .127 .676 r
.66773 .43567 m .66808 .43711 L .66985 .43902 L F
.661 .621 .799 r
.67795 .41424 m .67391 .40998 L .67643 .40932 L F
.657 .649 .831 r
.68019 .4126 m .67795 .41424 L .67643 .40932 L F
0 0 .48 r
.55151 .6576 m .55079 .65685 L .55084 .6552 L F
.55151 .6576 m .55223 .65857 L .55079 .65685 L F
.419 .354 .678 r
.34089 .61278 m .34222 .60831 L .34002 .60914 L F
.34089 .61278 m .34258 .6123 L .34222 .60831 L F
.43 .391 .715 r
.34089 .61278 m .34329 .61463 L .34258 .6123 L F
.583 .493 .719 r
.68798 .41954 m .68569 .42174 L .68555 .42005 L F
.661 .622 .8 r
.68798 .41954 m .68911 .42269 L .68569 .42174 L F
.659 .7 .877 r
.68998 .45412 m .68659 .45215 L .68865 .45086 L F
.47 .243 .486 r
.68998 .45412 m .69 .45531 L .68884 .45569 L F
.523 .425 .685 r
.69206 .4515 m .69276 .45448 L .68998 .45412 L F
.533 .29 .493 r
.69276 .45448 m .69002 .45689 L .68998 .45412 L F
.807 .753 .802 r
.689 .45535 m .69214 .45462 L .69273 .45413 L F
.69214 .45462 m .69276 .45448 L .69276 .45442 L F
.69214 .45462 m .69276 .45442 L .69273 .45413 L F
.47 .243 .486 r
.68884 .45569 m .69002 .45689 L .6875 .45753 L F
.69 .45531 m .69002 .45689 L .68884 .45569 L F
.694 .671 .824 r
.69206 .4515 m .68998 .45412 L .68865 .45086 L F
.632 .416 .572 r
.46218 .62423 m .45976 .62721 L .46213 .6267 L F
.471 .261 .512 r
.5071 .6886 m .50681 .69098 L .50453 .69151 L F
0 .487 .822 r
.20909 .59496 m .20739 .59413 L .20574 .59373 L F
.622 .867 .989 r
.20953 .59332 m .20739 .59413 L .20909 .59496 L F
0 .054 .603 r
.20909 .59496 m .21044 .59658 L .20953 .59332 L F
.217 .125 .531 r
.20909 .59496 m .20917 .59765 L .21044 .59658 L F
.553 .299 .485 r
.64458 .46904 m .64764 .46867 L .64703 .4712 L F
0 .23 .747 r
.64458 .46904 m .646 .46921 L .64351 .46777 L F
.64458 .46904 m .64703 .4712 L .646 .46921 L F
.073 .598 .873 r
.1959 .5412 m .19963 .54211 L .19757 .5422 L F
.404 .707 .984 r
.23095 .54663 m .233 .54654 L .23263 .54787 L F
.3 .597 .948 r
.233 .54654 m .23447 .54816 L .23263 .54787 L F
.31 .075 .386 r
.21535 .63338 m .21423 .63291 L .21579 .63205 L F
.21535 .63338 m .21359 .63498 L .21423 .63291 L F
.592 .366 .543 r
.50829 .67103 m .51162 .66769 L .5115 .67069 L F
.561 .536 .784 r
.51337 .66608 m .51162 .66769 L .51085 .6661 L F
.51337 .66608 m .51344 .66729 L .51162 .66769 L F
.229 .02 .374 r
.51344 .66729 m .5115 .67069 L .51162 .66769 L F
.468 .628 .922 r
.66821 .42241 m .66431 .42008 L .66643 .41906 L F
0 .035 .604 r
.6679 .42115 m .66821 .42241 L .66643 .41906 L F
0 0 .283 r
.66848 .42309 m .66821 .42241 L .6679 .42115 L F
.553 .806 .992 r
.51563 .66474 m .51694 .66553 L .51923 .66489 L F
.85 .68 .672 r
.62391 .44552 m .62348 .44836 L .62546 .44838 L F
.78 .449 .427 r
.62348 .44836 m .62748 .45081 L .62546 .44838 L F
0 0 .183 r
.54818 .67675 m .54657 .67949 L .54942 .67722 L F
.529 .287 .491 r
.50154 .69448 m .50149 .6969 L .49911 .69723 L F
.624 .587 .792 r
.69332 .4277 m .68973 .42486 L .692 .42427 L F
.597 .578 .803 r
.69465 .42348 m .69332 .4277 L .692 .42427 L F
.69465 .42348 m .69545 .42553 L .69332 .4277 L F
.612 .603 .818 r
.69545 .42553 m .69584 .42706 L .69332 .4277 L F
.593 .505 .724 r
.69667 .43076 m .69332 .4277 L .69584 .42706 L F
.69667 .43076 m .69422 .43139 L .69332 .4277 L F
.563 .608 .856 r
.5612 .63366 m .5642 .63487 L .56216 .63532 L F
0 .35 .684 r
.3936 .62788 m .39274 .62761 L .39133 .62721 L F
.3936 .62788 m .39501 .62845 L .39274 .62761 L F
.565 .405 .623 r
.69688 .43321 m .69422 .43139 L .69667 .43076 L F
.69688 .43321 m .6944 .43379 L .69422 .43139 L F
.491 .09 .207 r
.44552 .62907 m .44432 .63021 L .44192 .6302 L F
.59 .112 .088 r
.44776 .63016 m .44432 .63021 L .44552 .62907 L F
.495 .854 .991 r
.46257 .62975 m .46424 .62857 L .46422 .62962 L F
.742 .993 .847 r
.46422 .62962 m .46717 .62632 L .46815 .62667 L F
.46422 .62962 m .46424 .62857 L .46717 .62632 L F
.921 .834 .743 r
.67422 .45171 m .6716 .45286 L .67265 .45122 L F
.67422 .45171 m .67279 .4544 L .6716 .45286 L F
.238 0 0 r
.39759 .63845 m .39375 .63943 L .39527 .6386 L F
.774 .55 .595 r
.50648 .72058 m .50956 .72311 L .5099 .72095 L F
.459 .372 .671 r
.33932 .60693 m .34141 .60644 L .34097 .60302 L F
.557 .46 .7 r
.33932 .60693 m .34222 .60831 L .34141 .60644 L F
.33932 .60693 m .34002 .60914 L .34222 .60831 L F
.498 .131 .272 r
.6995 .44721 m .69647 .44633 L .70008 .44534 L F
.554 .543 .797 r
.70221 .44433 m .70008 .44534 L .69911 .44185 L F
.348 0 .137 r
.70195 .4467 m .70008 .44534 L .70221 .44433 L F
.70195 .4467 m .6995 .44721 L .70008 .44534 L F
.593 .543 .768 r
.68701 .41567 m .68555 .42005 L .6846 .41626 L F
.68701 .41567 m .68798 .41954 L .68555 .42005 L F
.544 .483 .738 r
.692 .42427 m .68973 .42486 L .68911 .42269 L F
.709 .959 .946 r
.63917 .47389 m .6417 .47204 L .63883 .47176 L F
.63917 .47389 m .64221 .47233 L .6417 .47204 L F
.98 .715 .452 r
.6725 .44853 m .67069 .44962 L .67151 .44694 L F
.6725 .44853 m .67265 .45122 L .67069 .44962 L F
0 0 .499 r
.67163 .42707 m .67122 .4266 L .66848 .42309 L F
.659 .877 .51 r
.55699 .6876 m .55468 .69097 L .55453 .68932 L F
.149 .687 .838 r
.40323 .57843 m .40483 .57827 L .40651 .57849 L F
0 0 0 r
.40365 .57872 m .40615 .57813 L .40483 .57827 L F
.329 .813 .858 r
.40711 .57791 m .40651 .57849 L .40483 .57827 L F
0 0 0 r
.40615 .57813 m .40711 .57791 L .40483 .57827 L F
.149 .687 .838 r
.40215 .57841 m .40483 .57827 L .40323 .57843 L F
.329 .813 .858 r
.40711 .57791 m .40889 .57789 L .40651 .57849 L F
0 0 0 r
.46802 .63157 m .46961 .63074 L .47198 .62987 L F
.669 .744 .907 r
.67517 .42769 m .67163 .42707 L .67403 .42655 L F
.881 .902 .839 r
.67606 .42413 m .67517 .42769 L .67403 .42655 L F
.755 .628 .719 r
.54115 .70872 m .54271 .71196 L .54491 .70924 L F
.922 .529 .197 r
.63789 .41515 m .64037 .41845 L .63933 .41589 L F
0 0 .558 r
.64146 .41879 m .63933 .41589 L .64037 .41845 L F
.166 .704 .805 r
.41987 .58429 m .41833 .58422 L .41607 .5845 L F
.653 .795 .344 r
.48317 .69726 m .48176 .70005 L .48594 .69979 L F
.815 .988 .878 r
.56369 .60574 m .5673 .60372 L .56393 .60379 L F
.56369 .60574 m .56643 .60332 L .5673 .60372 L F
.615 .939 .953 r
.5673 .60372 m .56842 .60227 L .56643 .60332 L F
.5673 .60372 m .56842 .60227 L .56643 .60332 L F
.181 0 0 r
.39054 .59616 m .38696 .59628 L .38872 .59511 L F
.842 .731 .741 r
.58777 .46301 m .58405 .46475 L .58631 .46157 L F
.58777 .46301 m .58584 .46609 L .58405 .46475 L F
.814 .833 .864 r
.59051 .46016 m .58777 .46301 L .58631 .46157 L F
.396 .378 .722 r
.3733 .61356 m .37237 .61664 L .37095 .61439 L F
.3733 .61356 m .37432 .61772 L .37237 .61664 L F
.658 .389 .501 r
.57657 .49259 m .57906 .49493 L .57685 .49501 L F
.57657 .49259 m .57913 .49252 L .57906 .49493 L F
.634 .365 .493 r
.59978 .483 m .59563 .48598 L .59563 .48401 L F
.542 .11 .17 r
.35001 .59103 m .35269 .59115 L .35392 .58944 L F
.199 0 0 r
.35269 .59115 m .35578 .58992 L .35392 .58944 L F
.364 0 .019 r
.35392 .58944 m .35578 .58992 L .35618 .58933 L F
.784 .808 .872 r
.6343 .42244 m .63721 .42032 L .6355 .41857 L F
.574 .567 .807 r
.69086 .41903 m .68911 .42269 L .68798 .41954 L F
.69086 .41903 m .69163 .42205 L .68911 .42269 L F
.556 .479 .723 r
.69163 .42205 m .692 .42427 L .68911 .42269 L F
0 0 0 r
.51774 .70891 m .51875 .70823 L .51958 .70604 L F
.127 .673 .812 r
.51875 .70823 m .52329 .70814 L .51958 .70604 L F
.573 .116 .129 r
.39501 .62845 m .39722 .62889 L .39876 .62728 L F
.253 0 0 r
.39722 .62889 m .40114 .62718 L .39876 .62728 L F
.288 0 .153 r
.547 .60938 m .54392 .61115 L .54553 .61168 L F
.574 .428 .645 r
.547 .60938 m .54745 .6125 L .54475 .61269 L F
.237 0 0 r
.54475 .61269 m .54745 .6125 L .54545 .61359 L F
0 0 .406 r
.54392 .61115 m .54545 .61359 L .54553 .61168 L F
.54392 .61115 m .54475 .61269 L .54545 .61359 L F
.7 .685 .832 r
.47321 .73277 m .47733 .73463 L .47547 .73139 L F
.772 .725 .809 r
.47547 .73139 m .47733 .73463 L .47897 .73212 L F
.636 .657 .854 r
.47733 .73463 m .47915 .73389 L .47897 .73212 L F
.792 .606 .649 r
.49461 .72007 m .4982 .72054 L .49785 .71804 L F
.751 .706 .809 r
.50073 .71744 m .4982 .72054 L .49785 .71804 L F
.512 .409 .674 r
.49785 .71804 m .50048 .72001 L .50073 .71744 L F
.49785 .71804 m .4982 .72054 L .50048 .72001 L F
0 0 .109 r
.4894 .72908 m .4898 .72863 L .48979 .72724 L F
.695 .455 .556 r
.49324 .72985 m .49114 .73175 L .4894 .72908 L F
0 .098 .651 r
.4894 .72908 m .49114 .73175 L .4898 .72863 L F
.785 .583 .627 r
.4482 .57611 m .44446 .5766 L .4472 .57476 L F
.4482 .57611 m .4483 .57729 L .44446 .5766 L F
.688 .838 .955 r
.45058 .57476 m .4482 .57611 L .4472 .57476 L F
.703 .657 .802 r
.45058 .57476 m .4483 .57729 L .4482 .57611 L F
.37 .828 .739 r
.5118 .69026 m .51584 .68866 L .51224 .68892 L F
.5118 .69026 m .51402 .68923 L .51584 .68866 L F
.421 .809 .57 r
.51584 .68866 m .51686 .68791 L .51769 .6873 L F
.433 .865 .76 r
.51584 .68866 m .51402 .68923 L .51686 .68791 L F
.42 .143 .384 r
.69352 .44732 m .69123 .44851 L .69105 .44646 L F
.35 .261 .612 r
.24248 .57296 m .24058 .57134 L .2426 .57087 L F
.24248 .57296 m .24056 .57436 L .24058 .57134 L F
.092 .576 .904 r
.22694 .54524 m .23095 .54663 L .22872 .5464 L F
0 0 0 r
.38708 .58198 m .39089 .58073 L .38848 .58085 L F
.038 0 .058 r
.52424 .71021 m .52335 .70909 L .52385 .70902 L F
.52424 .71021 m .52254 .71136 L .52335 .70909 L F
.154 0 0 r
.24519 .55875 m .24735 .55821 L .24917 .55654 L F
.264 .559 .933 r
.23085 .79349 m .23121 .79358 L .23107 .79375 L F
.571 .886 .61 r
.23107 .79375 m .23121 .79358 L .23081 .79395 L F
.125 0 0 r
.45744 .62883 m .45667 .62964 L .4541 .63036 L F
.611 .48 .678 r
.45744 .62883 m .45976 .62721 L .45588 .62711 L F
.45744 .62883 m .45978 .62966 L .45976 .62721 L F
.627 .153 .108 r
.45744 .62883 m .45978 .62966 L .45667 .62964 L F
.942 .923 .761 r
.66534 .45673 m .66651 .45508 L .66558 .45409 L F
.533 .605 .871 r
.46257 .62975 m .45976 .62721 L .46213 .6267 L F
.778 .694 .771 r
.46213 .6267 m .45978 .62966 L .46257 .62975 L F
0 0 .037 r
.46257 .62975 m .46251 .6311 L .46424 .62857 L F
.656 .261 .285 r
.42567 .58286 m .42214 .58426 L .42243 .58356 L F
.42567 .58286 m .42457 .58498 L .42214 .58426 L F
.722 .905 .535 r
.42655 .58112 m .42567 .58286 L .42792 .58256 L F
.42655 .58112 m .42525 .5831 L .42567 .58286 L F
0 0 0 r
.42547 .58345 m .42567 .58286 L .42525 .5831 L F
.42547 .58345 m .42457 .58498 L .42567 .58286 L F
.731 .495 .57 r
.68637 .44857 m .68516 .45018 L .68268 .45107 L F
.683 .484 .61 r
.68833 .44851 m .68516 .45018 L .68637 .44857 L F
.719 .491 .579 r
.51563 .66474 m .51923 .66489 L .51904 .66213 L F
.585 .492 .715 r
.51904 .66213 m .52206 .66208 L .52121 .6604 L F
.46 .296 .571 r
.5213 .6641 m .51904 .66213 L .52206 .66208 L F
.5213 .6641 m .51923 .66489 L .51904 .66213 L F
.585 .492 .715 r
.51904 .66213 m .52206 .66208 L .52121 .6604 L F
.46 .296 .571 r
.5213 .6641 m .51904 .66213 L .52206 .66208 L F
.5213 .6641 m .51923 .66489 L .51904 .66213 L F
0 0 0 r
.58877 .61256 m .58956 .61149 L .58976 .61149 L F
.141 .143 .598 r
.58976 .61149 m .59009 .61499 L .58877 .61256 L F
.722 .989 .86 r
.64118 .45911 m .63997 .46085 L .64119 .46008 L F
.823 .948 .596 r
.64299 .45602 m .64119 .46008 L .64442 .45748 L F
.64299 .45602 m .64118 .45911 L .64119 .46008 L F
.667 .26 .264 r
.48544 .70307 m .48841 .70322 L .48721 .70519 L F
.696 .268 .226 r
.48944 .70176 m .49074 .7001 L .48707 .69973 L F
.406 .76 .994 r
.48992 .70107 m .48944 .70176 L .48874 .70083 L F
.591 .828 .448 r
.48944 .70176 m .48868 .70285 L .49074 .7001 L F
.638 .961 .805 r
.49289 .69993 m .49219 .70098 L .49175 .70115 L F
.406 .76 .994 r
.4916 .70141 m .48944 .70176 L .48992 .70107 L F
.591 .828 .448 r
.48944 .70176 m .48841 .70322 L .48868 .70285 L F
0 0 0 r
.48721 .70519 m .48841 .70322 L .48944 .70176 L F
.48721 .70519 m .48944 .70176 L .48983 .7047 L F
.551 .413 .647 r
.49153 .70418 m .48944 .70176 L .49198 .70148 L F
.49153 .70418 m .48983 .7047 L .48944 .70176 L F
.736 .694 .811 r
.49219 .70098 m .49198 .70148 L .48874 .70083 L F
.682 .286 .29 r
.48607 .70165 m .48944 .70176 L .48707 .69973 L F
.634 .184 .167 r
.48855 .70336 m .48944 .70176 L .48607 .70165 L F
.494 0 0 r
.48896 .70225 m .49219 .70098 L .48874 .70083 L F
.638 .961 .805 r
.49226 .7003 m .49175 .70115 L .48896 .70225 L F
.49289 .69993 m .49175 .70115 L .49226 .7003 L F
.406 .76 .994 r
.49198 .70148 m .49153 .70153 L .4916 .70141 L F
.49153 .70153 m .48944 .70176 L .4916 .70141 L F
.095 0 .321 r
.50863 .68793 m .50681 .69098 L .5071 .6886 L F
.96 .63 .251 r
.64121 .44791 m .64163 .44958 L .64202 .4476 L F
.473 .199 .416 r
.64202 .4476 m .64541 .44725 L .64567 .44636 L F
.172 0 .103 r
.64202 .4476 m .64163 .44958 L .64409 .44844 L F
.802 .739 .793 r
.60428 .44431 m .60589 .44583 L .60258 .44557 L F
.794 .739 .801 r
.60843 .44289 m .60589 .44583 L .60428 .44431 L F
.89 .518 .05 r
.54374 .62875 m .54474 .62987 L .54409 .62782 L F
.54409 .62782 m .54474 .62987 L .54374 .62875 L F
.202 .292 .734 r
.38053 .64118 m .38209 .6411 L .37995 .64178 L F
.858 .921 .87 r
.6248 .42206 m .62247 .42496 L .62622 .42547 L F
.984 .71 .34 r
.61687 .45915 m .61703 .46162 L .61802 .46069 L F
.14 0 0 r
.62067 .45814 m .61687 .45915 L .61802 .46069 L F
.171 .423 .86 r
.61932 .45907 m .61802 .46069 L .61703 .46162 L F
.61932 .45907 m .62157 .46384 L .61802 .46069 L F
.538 .159 .27 r
.20413 .58957 m .20609 .5908 L .20778 .58843 L F
.348 0 .146 r
.20778 .58843 m .20812 .59032 L .20994 .58874 L F
.20778 .58843 m .20609 .5908 L .20812 .59032 L F
.816 .792 .829 r
.66304 .41835 m .66252 .42214 L .66079 .42136 L F
.66304 .41835 m .66431 .42008 L .66252 .42214 L F
.978 .679 .35 r
.66252 .42214 m .66149 .42312 L .66079 .42136 L F
.66252 .42214 m .66287 .42451 L .66149 .42312 L F
.404 0 0 r
.40112 .63801 m .39994 .63867 L .39759 .63845 L F
.216 0 0 r
.4034 .63767 m .39994 .63867 L .40112 .63801 L F
.929 .949 .781 r
.61187 .43589 m .61276 .43676 L .61068 .43992 L F
.856 .96 .873 r
.61537 .434 m .61276 .43676 L .61187 .43589 L F
.937 .882 .755 r
.5665 .49198 m .56362 .49425 L .56431 .49359 L F
0 0 .38 r
.56704 .48983 m .5665 .49198 L .56846 .49083 L F
0 0 0 r
.56846 .49083 m .5665 .49198 L .56431 .49359 L F
.921 .823 .732 r
.62559 .42771 m .62596 .42813 L .62418 .43094 L F
.547 .577 .836 r
.4544 .58928 m .45511 .58541 L .45311 .58581 L F
.4544 .58928 m .45696 .58912 L .45511 .58541 L F
.619 .799 .969 r
.43371 .58212 m .43803 .58259 L .43605 .57995 L F
.339 .512 .881 r
.43803 .58259 m .43821 .57965 L .43605 .57995 L F
.43803 .58259 m .43984 .5827 L .43821 .57965 L F
.295 0 0 r
.62153 .47946 m .62197 .47856 L .62441 .47879 L F
.041 0 0 r
.55056 .63202 m .55419 .63018 L .55424 .63029 L F
.387 .828 .693 r
.52176 .6897 m .51993 .69051 L .51921 .69105 L F
0 0 0 r
.51993 .69051 m .51794 .69291 L .51921 .69105 L F
.20155 .65746 m .201 .65629 L .20269 .65572 L F
.20155 .65746 m .20029 .65853 L .201 .65629 L F
.777 .789 .863 r
.639 .41873 m .64146 .41879 L .64037 .41845 L F
.817 .656 .107 r
.55271 .67675 m .55248 .67545 L .5525 .67334 L F
.935 .734 .257 r
.55301 .67887 m .55248 .67545 L .55271 .67675 L F
.397 .375 .718 r
.24433 .55272 m .24323 .55687 L .24189 .5531 L F
.24433 .55272 m .24483 .55632 L .24323 .55687 L F
.366 .287 .634 r
.24483 .55632 m .24519 .55875 L .24323 .55687 L F
.24483 .55632 m .24519 .55875 L .24323 .55687 L F
.149 0 0 r
.37265 .5851 m .37493 .58483 L .37675 .58379 L F
.187 0 0 r
.37675 .58379 m .37493 .58483 L .37828 .58414 L F
.595 .271 .39 r
.6076 .4806 m .61006 .48225 L .60806 .48159 L F
.6076 .4806 m .60989 .4807 L .61006 .48225 L F
.325 0 0 r
.51156 .66702 m .51085 .6661 L .50946 .66721 L F
.51156 .66702 m .51337 .66608 L .51085 .6661 L F
.413 .863 .847 r
.67699 .4555 m .68098 .45452 L .68149 .45571 L F
.659 .621 .8 r
.68268 .45107 m .68098 .45452 L .68057 .4524 L F
.68268 .45107 m .68425 .45431 L .68098 .45452 L F
.692 .167 0 r
.68406 .4568 m .68098 .45452 L .68425 .45431 L F
.68406 .4568 m .68149 .45571 L .68098 .45452 L F
.177 .689 .897 r
.19963 .54211 m .2018 .54211 L .20349 .54256 L F
.225 .72 .916 r
.2018 .54211 m .20557 .54246 L .20349 .54256 L F
.691 .688 .842 r
.54065 .66498 m .54384 .66562 L .54224 .66489 L F
.655 .652 .836 r
.54384 .66562 m .54514 .6614 L .54224 .66489 L F
.54384 .66562 m .54747 .66513 L .54514 .6614 L F
.661 .454 .593 r
.46776 .62424 m .47057 .62399 L .4705 .62119 L F
.546 .426 .667 r
.4705 .62119 m .47281 .62069 L .47218 .61745 L F
.501 .329 .579 r
.4705 .62119 m .47282 .62323 L .47281 .62069 L F
.4705 .62119 m .47057 .62399 L .47282 .62323 L F
0 .46 .764 r
.37764 .64234 m .37542 .64153 L .3736 .64107 L F
0 .574 .737 r
.37995 .64178 m .37542 .64153 L .37764 .64234 L F
.016 0 0 r
.17849 .55345 m .18054 .55309 L .17808 .55363 L F
.951 .74 .583 r
.52682 .71687 m .52811 .7202 L .52864 .7179 L F
.577 .348 .532 r
.58157 .49189 m .57906 .49493 L .57913 .49252 L F
.737 .689 .804 r
.55063 .67314 m .54818 .67675 L .54825 .67391 L F
.44 .038 .179 r
.35835 .58915 m .36057 .5896 L .36237 .5864 L F
.342 0 .127 r
.36237 .5864 m .36406 .58703 L .36453 .58598 L F
.36237 .5864 m .36057 .5896 L .36406 .58703 L F
.662 .349 .433 r
.37539 .60358 m .37393 .60624 L .37196 .60536 L F
.47 .139 .323 r
.37656 .60567 m .37539 .60358 L .37762 .60279 L F
.37656 .60567 m .37393 .60624 L .37539 .60358 L F
.691 .236 0 r
.55187 .63357 m .55259 .63475 L .55056 .63202 L F
.283 .766 .921 r
.20608 .55513 m .20376 .55468 L .20169 .5549 L F
.251 .634 .961 r
.20608 .55513 m .2069 .55419 L .20376 .55468 L F
.20608 .55513 m .2096 .55583 L .2069 .55419 L F
.703 .657 .802 r
.45058 .57476 m .45175 .57739 L .4483 .57729 L F
.558 .589 .84 r
.45306 .57433 m .45175 .57739 L .45058 .57476 L F
.45306 .57433 m .45405 .57703 L .45175 .57739 L F
.54 .427 .674 r
.45405 .57703 m .45185 .58007 L .45175 .57739 L F
.587 .745 .952 r
.43095 .57403 m .43045 .57637 L .42881 .57436 L F
.43095 .57403 m .43359 .57611 L .43045 .57637 L F
.811 .624 .649 r
.53896 .71419 m .5425 .71461 L .54271 .71196 L F
.317 .141 .477 r
.22641 .61157 m .22455 .61481 L .22487 .61239 L F
.567 .244 .38 r
.4898 .72863 m .49362 .7261 L .48979 .72724 L F
.306 .118 .454 r
.21752 .62892 m .21579 .63205 L .21608 .62992 L F
0 0 .137 r
.20887 .64385 m .20743 .6472 L .20809 .64473 L F
.417 .271 .573 r
.24124 .58183 m .23954 .58 L .24081 .57936 L F
.24124 .58183 m .23918 .583 L .23954 .58 L F
.481 .347 .621 r
.57928 .60833 m .5819 .61038 L .58139 .60758 L F
0 0 0 r
.58102 .60981 m .58139 .60758 L .5819 .61038 L F
0 .055 .621 r
.58078 .61013 m .5819 .61038 L .58022 .60906 L F
0 0 0 r
.58081 .60967 m .58084 .60954 L .58102 .60981 L F
.58084 .60954 m .58139 .60758 L .58102 .60981 L F
.406 .178 .451 r
.57928 .60833 m .58139 .60758 L .58199 .60531 L F
0 0 .322 r
.58139 .60758 m .58295 .6049 L .58199 .60531 L F
.58139 .60758 m .58309 .60635 L .58295 .6049 L F
0 0 0 r
.58094 .6092 m .58309 .60635 L .58139 .60758 L F
.48 .394 .681 r
.57711 .60635 m .57928 .60833 L .57732 .60846 L F
.623 .462 .643 r
.58016 .60423 m .58188 .60753 L .57809 .60754 L F
.332 0 0 r
.57809 .60754 m .58188 .60753 L .57926 .60856 L F
.955 .794 .643 r
.57961 .60771 m .58188 .60753 L .58017 .60636 L F
.57926 .60856 m .57999 .60827 L .57961 .60771 L F
.57999 .60827 m .58188 .60753 L .57961 .60771 L F
0 0 0 r
.58081 .60967 m .58111 .60924 L .58094 .6092 L F
.58111 .60924 m .58309 .60635 L .58094 .6092 L F
0 .055 .621 r
.57983 .60899 m .58022 .60906 L .57928 .60833 L F
.58078 .61013 m .58022 .60906 L .57983 .60899 L F
.58078 .61013 m .5824 .61186 L .5819 .61038 L F
.365 .049 .291 r
.53212 .67272 m .53518 .67035 L .53274 .67076 L F
0 0 0 r
.17561 .54198 m .17808 .54147 L .17592 .5419 L F
.634 .365 .493 r
.59978 .483 m .59813 .48617 L .59563 .48598 L F
.577 .301 .461 r
.60209 .48476 m .59978 .483 L .60162 .48331 L F
.60209 .48476 m .59813 .48617 L .59978 .483 L F
.737 .689 .804 r
.55063 .67314 m .552 .67798 L .54818 .67675 L F
.213 0 .209 r
.55019 .67756 m .54818 .67675 L .552 .67798 L F
0 0 .143 r
.5525 .67334 m .552 .67798 L .55063 .67314 L F
.5525 .67334 m .55248 .67545 L .552 .67798 L F
.845 .596 .562 r
.55248 .67545 m .55019 .67756 L .552 .67798 L F
.478 .407 .699 r
.49095 .69731 m .49299 .69951 L .49074 .7001 L F
.401 .786 .99 r
.36035 .63397 m .36116 .63282 L .35871 .63249 L F
.36035 .63397 m .36265 .63354 L .36116 .63282 L F
0 .109 .648 r
.2096 .55583 m .20962 .55716 L .21008 .5555 L F
.518 .784 .993 r
.20962 .55716 m .2119 .55661 L .21008 .5555 L F
.404 0 0 r
.40114 .62718 m .40319 .62793 L .40469 .62701 L F
.606 .119 .072 r
.40319 .62793 m .40673 .62802 L .40469 .62701 L F
.507 .026 .047 r
.40673 .62802 m .40704 .62726 L .40469 .62701 L F
.97 .719 .499 r
.5642 .63487 m .56463 .63887 L .56582 .63969 L F
.501 .848 .995 r
.56411 .63992 m .56582 .63969 L .56463 .63887 L F
.56411 .63992 m .56339 .64118 L .56582 .63969 L F
.272 0 .108 r
.56339 .64118 m .56564 .64089 L .56582 .63969 L F
.924 .771 .672 r
.64831 .45355 m .65032 .45445 L .64908 .45279 L F
.64831 .45355 m .65032 .45445 L .64908 .45279 L F
.492 .653 .931 r
.64908 .45279 m .65032 .45445 L .65161 .45393 L F
.678 .149 0 r
.64908 .45279 m .65161 .45393 L .65032 .45445 L F
.402 .492 .837 r
.51504 .73114 m .51747 .7321 L .51675 .73093 L F
.77 .83 .898 r
.51809 .72911 m .5134 .73135 L .51504 .73114 L F
.571 .774 .974 r
.51756 .72818 m .51809 .72911 L .51504 .73114 L F
.402 .492 .837 r
.51504 .73114 m .51675 .73093 L .51608 .72985 L F
.77 .83 .898 r
.5134 .73135 m .51293 .73157 L .51504 .73114 L F
.748 .355 .308 r
.44192 .6302 m .44053 .6319 L .43817 .62948 L F
.462 .02 .11 r
.44437 .63096 m .44192 .6302 L .44432 .63021 L F
.44437 .63096 m .44053 .6319 L .44192 .6302 L F
.226 0 0 r
.23033 .79344 m .23121 .79358 L .23085 .79349 L F
.515 .583 .861 r
.34485 .61779 m .34527 .61422 L .34329 .61463 L F
.34485 .61779 m .34693 .61744 L .34527 .61422 L F
0 0 .386 r
.66985 .43902 m .67008 .44263 L .67076 .44119 L F
.127 .297 .767 r
.67008 .44263 m .67214 .44462 L .67076 .44119 L F
.076 .536 .901 r
.55419 .63018 m .55909 .63176 L .55863 .63213 L F
.175 .405 .846 r
.56007 .63075 m .56058 .63291 L .55863 .63213 L F
.56007 .63075 m .55863 .63213 L .55909 .63176 L F
.255 .757 .89 r
.50911 .73161 m .51293 .73157 L .5114 .73132 L F
.50911 .73161 m .51293 .73157 L .5114 .73132 L F
.303 .787 .906 r
.5114 .73132 m .51293 .73157 L .51504 .73114 L F
.51504 .73114 m .51293 .73157 L .5114 .73132 L F
.984 .731 .342 r
.58992 .63434 m .59074 .63296 L .59009 .63185 L F
.58992 .63434 m .59082 .63547 L .59074 .63296 L F
.419 0 .082 r
.4359 .62952 m .43213 .63153 L .43243 .6305 L F
.4359 .62952 m .43441 .63137 L .43213 .63153 L F
.549 .145 .228 r
.43817 .62948 m .43441 .63137 L .4359 .62952 L F
.352 .159 .473 r
.22299 .61806 m .22269 .62046 L .22091 .62104 L F
.327 .147 .478 r
.22231 .62299 m .22091 .62104 L .22269 .62046 L F
.22231 .62299 m .22065 .62369 L .22091 .62104 L F
.498 .131 .272 r
.6995 .44721 m .69725 .44802 L .69647 .44633 L F
.647 .819 .966 r
.67786 .42791 m .68111 .42812 L .68002 .42683 L F
.794 .739 .801 r
.60843 .44289 m .60428 .44431 L .60678 .44152 L F
.835 .783 .802 r
.61068 .43992 m .60843 .44289 L .60678 .44152 L F
.926 .864 .76 r
.5808 .62901 m .58215 .62993 L .58079 .6322 L F
0 0 0 r
.39089 .58073 m .3924 .58068 L .39451 .58061 L F
.099 0 0 r
.3924 .58068 m .39687 .58014 L .39451 .58061 L F
.224 0 0 r
.39462 .59445 m .39279 .59589 L .39054 .59616 L F
.361 0 0 r
.39701 .59447 m .39279 .59589 L .39462 .59445 L F
.864 .988 .836 r
.63997 .46085 m .63786 .4616 L .6389 .46207 L F
.869 .471 .278 r
.63891 .46443 m .6389 .46207 L .63786 .4616 L F
.63891 .46443 m .63994 .46405 L .6389 .46207 L F
.303 .186 .55 r
.2348 .59659 m .23325 .59469 L .2348 .59407 L F
.2348 .59659 m .23337 .59768 L .23325 .59469 L F
.687 .754 .903 r
.66643 .41906 m .66431 .42008 L .66304 .41835 L F
0 .412 .743 r
.56339 .64118 m .56174 .64046 L .55938 .63971 L F
.058 .224 .721 r
.56339 .64118 m .56545 .64325 L .56564 .64089 L F
.752 .803 .893 r
.6355 .41857 m .63721 .42032 L .639 .41873 L F
.587 .391 .583 r
.4982 .72054 m .4982 .72135 L .49571 .72333 L F
.4982 .72135 m .49821 .72311 L .49738 .72318 L F
.4982 .72135 m .49738 .72318 L .49571 .72333 L F
.37 .11 .383 r
.49709 .72275 m .49571 .72333 L .4982 .72054 L F
.781 .548 .583 r
.49571 .72333 m .49603 .72659 L .49185 .72338 L F
.599 .66 .881 r
.49571 .72333 m .49821 .72311 L .49709 .72275 L F
.479 .326 .595 r
.49709 .72275 m .49603 .72659 L .49571 .72333 L F
.88 .744 .708 r
.49455 .72295 m .49552 .72534 L .49709 .72275 L F
.49552 .72534 m .49595 .72638 L .49709 .72275 L F
.49595 .72638 m .49603 .72659 L .49632 .72553 L F
.49595 .72638 m .49632 .72553 L .49709 .72275 L F
.37 .11 .383 r
.49709 .72275 m .4982 .72054 L .49461 .72007 L F
.439 .274 .559 r
.4982 .72054 m .50035 .72265 L .50048 .72001 L F
.4982 .72054 m .49821 .72311 L .50035 .72265 L F
.50035 .72265 m .49821 .72311 L .4982 .72054 L F
.781 .282 0 r
.57917 .6267 m .5808 .62901 L .57924 .62799 L F
.776 .732 .813 r
.58295 .46545 m .58346 .46907 L .58031 .46867 L F
.825 .723 .753 r
.58346 .46907 m .57952 .47088 L .58031 .46867 L F
.58346 .46907 m .58175 .47219 L .57952 .47088 L F
.814 .758 .8 r
.58584 .46609 m .58346 .46907 L .58295 .46545 L F
.51 .829 1 r
.68406 .4568 m .6875 .45753 L .68673 .45663 L F
.517 .832 1 r
.6875 .45753 m .69002 .45689 L .68673 .45663 L F
.606 .163 0 r
.55467 .66198 m .55616 .66414 L .55672 .66488 L F
.93 .65 .174 r
.5561 .66597 m .55672 .66488 L .55616 .66414 L F
.5561 .66597 m .55706 .6673 L .55672 .66488 L F
.835 .783 .802 r
.61068 .43992 m .60678 .44152 L .6093 .43861 L F
.929 .949 .781 r
.61187 .43589 m .61068 .43992 L .6093 .43861 L F
.047 .298 .788 r
.37432 .61772 m .37664 .61953 L .37602 .62073 L F
.202 .503 .908 r
.37664 .61953 m .3777 .62112 L .37602 .62073 L F
.662 .208 .164 r
.58062 .6168 m .58354 .61699 L .58182 .61525 L F
.518 .238 .428 r
.58354 .61699 m .58445 .61487 L .58182 .61525 L F
.19 .381 .822 r
.5831 .6211 m .58402 .61938 L .58177 .61812 L F
.704 .928 .604 r
.58141 .62257 m .58402 .61938 L .5831 .6211 L F
.536 .582 .848 r
.6846 .41626 m .68092 .41344 L .68336 .41281 L F
.574 .58 .821 r
.68701 .41567 m .6846 .41626 L .68336 .41281 L F
.644 .255 .293 r
.47218 .61745 m .47535 .61807 L .47326 .61725 L F
.517 .057 .099 r
.52049 .6825 m .51924 .68407 L .51622 .68295 L F
.986 .74 .472 r
.52049 .6825 m .52049 .68511 L .51924 .68407 L F
.166 .057 .474 r
.51724 .71135 m .51875 .70823 L .51774 .70891 L F
.469 .31 .582 r
.2427 .57626 m .24056 .57436 L .24248 .57296 L F
.2427 .57626 m .2407 .5769 L .24056 .57436 L F
.594 .687 .906 r
.68336 .41281 m .68092 .41344 L .68019 .4126 L F
.445 .223 .481 r
.52161 .72882 m .52124 .73194 L .519 .73272 L F
.224 .716 .921 r
.52339 .72865 m .52161 .72882 L .51976 .72824 L F
.361 .152 .456 r
.52339 .72865 m .52124 .73194 L .52161 .72882 L F
.43 .608 .922 r
.46062 .58337 m .45948 .58533 L .45657 .58278 L F
.46062 .58337 m .46106 .58465 L .45948 .58533 L F
.169 0 .318 r
.46106 .58465 m .45897 .58783 L .45948 .58533 L F
.483 .224 .445 r
.52244 .67902 m .52531 .67843 L .52515 .67666 L F
.701 .383 .435 r
.52531 .67843 m .52737 .67921 L .52515 .67666 L F
.637 .385 .52 r
.52515 .67666 m .52737 .67921 L .52763 .67658 L F
.549 .828 .998 r
.2191 .56202 m .21735 .56107 L .2169 .5626 L F
.374 .65 .964 r
.2169 .5626 m .21735 .56107 L .21558 .5612 L F
.54 .048 .036 r
.40673 .62802 m .41072 .62719 L .40704 .62726 L F
.40673 .62802 m .40914 .62854 L .41072 .62719 L F
.294 0 0 r
.40914 .62854 m .41316 .62695 L .41072 .62719 L F
.674 .451 .575 r
.49368 .72918 m .49114 .73175 L .49324 .72985 L F
.148 0 .147 r
.20991 .58369 m .20815 .58478 L .20904 .58281 L F
.561 .604 .853 r
.20288 .6079 m .20366 .6058 L .20168 .60635 L F
.20288 .6079 m .20557 .60913 L .20366 .6058 L F
.724 .442 .499 r
.20288 .6079 m .20471 .61077 L .20557 .60913 L F
.20288 .6079 m .20142 .61124 L .20471 .61077 L F
.962 .629 .267 r
.66559 .44883 m .66397 .44501 L .66423 .44926 L F
.951 .685 .497 r
.66297 .4516 m .66451 .44986 L .66325 .44875 L F
.995 .761 .407 r
.66453 .44961 m .66448 .44918 L .6645 .44957 L F
.66541 .45064 m .66456 .44931 L .66453 .44961 L F
.951 .685 .497 r
.66451 .44986 m .66448 .44934 L .66325 .44875 L F
.561 0 0 r
.66325 .44875 m .66448 .44934 L .66423 .44926 L F
.995 .761 .407 r
.66456 .44936 m .6645 .44934 L .66453 .44961 L F
.951 .685 .497 r
.6645 .44957 m .66483 .4495 L .66448 .44934 L F
.995 .761 .407 r
.66541 .45064 m .6645 .44957 L .66483 .4495 L F
.951 .685 .497 r
.66451 .44986 m .66483 .4495 L .6645 .44957 L F
.995 .761 .407 r
.6645 .44957 m .66448 .44918 L .66423 .44926 L F
.6645 .44957 m .66423 .44926 L .66483 .4495 L F
.561 0 0 r
.66448 .44934 m .66483 .4495 L .66423 .44926 L F
.995 .761 .407 r
.66456 .44931 m .66448 .44918 L .6645 .44934 L F
.66456 .44931 m .6645 .44934 L .66456 .44936 L F
.951 .685 .497 r
.66451 .44986 m .66501 .45208 L .66483 .4495 L F
.66297 .4516 m .66433 .45192 L .66451 .44986 L F
.66433 .45192 m .66501 .45208 L .66451 .44986 L F
.995 .761 .407 r
.66541 .45064 m .66559 .44883 L .66448 .44918 L F
.592 .868 .994 r
.66541 .45064 m .66706 .45052 L .66559 .44883 L F
.5 .352 .611 r
.56463 .4976 m .56439 .50014 L .56237 .49836 L F
.936 .667 .504 r
.56316 .49878 m .56338 .49653 L .56339 .49896 L F
.868 .878 .841 r
.56359 .49434 m .56237 .49836 L .56338 .49653 L F
.726 .956 .67 r
.56338 .49653 m .56237 .49836 L .56097 .49925 L F
.936 .667 .504 r
.56171 .49759 m .56338 .49653 L .56316 .49878 L F
.868 .878 .841 r
.56362 .49425 m .56359 .49434 L .56338 .49653 L F
.718 .222 .058 r
.56237 .49836 m .56439 .50014 L .56097 .49925 L F
0 0 0 r
.47715 .62659 m .48025 .62412 L .47896 .62575 L F
.4817 .62325 m .48025 .62412 L .48241 .621 L F
.47896 .62575 m .48025 .62412 L .4817 .62325 L F
.502 .377 .642 r
.54973 .61184 m .547 .60938 L .54936 .60887 L F
.54973 .61184 m .54745 .6125 L .547 .60938 L F
.698 .493 .606 r
.54553 .61168 m .54936 .60887 L .547 .60938 L F
.521 .407 .665 r
.37196 .60536 m .37201 .60795 L .36971 .60652 L F
.573 .554 .795 r
.37201 .60795 m .37005 .6089 L .36971 .60652 L F
.59 .112 .088 r
.44776 .63016 m .44636 .63158 L .44432 .63021 L F
.2 0 0 r
.44871 .63112 m .44776 .63016 L .44987 .63107 L F
.44871 .63112 m .44636 .63158 L .44776 .63016 L F
.525 .393 .643 r
.34097 .60302 m .34294 .59998 L .341 .60057 L F
.269 0 .036 r
.42526 .62436 m .42372 .62697 L .4269 .62498 L F
.293 0 0 r
.42848 .62361 m .42526 .62436 L .42663 .62488 L F
0 .553 .716 r
.4298 .62367 m .43092 .62375 L .42848 .62361 L F
.786 .689 .757 r
.43142 .62499 m .42937 .62779 L .43142 .62499 L F
.568 .241 .375 r
.42358 .62723 m .42529 .628 L .42817 .62434 L F
.42529 .628 m .42593 .62769 L .42817 .62434 L F
.42358 .62723 m .42817 .62434 L .4276 .62458 L F
0 .553 .716 r
.42839 .62421 m .42848 .62361 L .42663 .62488 L F
.42844 .6242 m .42663 .62488 L .42704 .62475 L F
.4298 .62367 m .42855 .62415 L .42844 .6242 L F
.42855 .62415 m .42663 .62488 L .42844 .6242 L F
.771 .491 .511 r
.42838 .62423 m .42562 .62815 L .42937 .62779 L F
0 .553 .716 r
.4298 .62367 m .4298 .62367 L .42977 .62368 L F
.269 0 .036 r
.42663 .62488 m .4269 .62498 L .42751 .62461 L F
0 .553 .716 r
.42704 .62475 m .42663 .62488 L .42652 .62496 L F
0 0 0 r
.42834 .62409 m .4298 .62367 L .42704 .62475 L F
.269 0 .036 r
.42663 .62488 m .42704 .62475 L .42834 .62409 L F
0 0 0 r
.42834 .62409 m .42704 .62475 L .42652 .62496 L F
.269 0 .036 r
.42704 .62475 m .42751 .62461 L .42834 .62409 L F
.771 .491 .511 r
.42834 .62409 m .42817 .62434 L .42838 .62423 L F
.42817 .62434 m .42562 .62815 L .42838 .62423 L F
.568 .241 .375 r
.4276 .62458 m .42817 .62434 L .42834 .62409 L F
.771 .491 .511 r
.42834 .62409 m .42838 .62423 L .42837 .62424 L F
.42834 .62409 m .42837 .62424 L .428 .62436 L F
.42838 .62423 m .42937 .62779 L .42819 .62484 L F
.42838 .62423 m .42819 .62484 L .428 .62436 L F
0 .553 .716 r
.42977 .62368 m .42858 .62362 L .42839 .62421 L F
.42858 .62362 m .42848 .62361 L .42839 .62421 L F
.786 .689 .757 r
.428 .62436 m .42877 .62629 L .43142 .62499 L F
.42877 .62629 m .42937 .62779 L .43142 .62499 L F
.568 .241 .375 r
.42529 .628 m .42562 .62815 L .42593 .62769 L F
0 .553 .716 r
.4298 .62367 m .42848 .62361 L .42977 .62368 L F
.269 0 .036 r
.42526 .62436 m .42663 .62488 L .42834 .62409 L F
.293 0 0 r
.42663 .62488 m .42526 .62436 L .42652 .62496 L F
.722 .989 .851 r
.64118 .45911 m .63786 .4616 L .63997 .46085 L F
.651 .613 .799 r
.53241 .69722 m .53611 .69982 L .535 .69669 L F
.732 .637 .752 r
.535 .69669 m .53611 .69982 L .5386 .69702 L F
.734 .57 .67 r
.18299 .57692 m .18597 .57434 L .18273 .57366 L F
.18299 .57692 m .18458 .57699 L .18597 .57434 L F
.641 .563 .752 r
.45405 .57703 m .45502 .58064 L .45185 .58007 L F
.674 .451 .575 r
.49368 .72918 m .49401 .73192 L .49114 .73175 L F
.588 .509 .733 r
.49629 .72834 m .49368 .72918 L .49362 .7261 L F
.473 .28 .538 r
.49629 .72834 m .49401 .73192 L .49368 .72918 L F
.776 .561 .608 r
.56827 .49805 m .56439 .50014 L .56463 .4976 L F
.56827 .49805 m .56823 .50084 L .56439 .50014 L F
.502 .336 .588 r
.57037 .50005 m .56827 .49805 L .57065 .49772 L F
.57037 .50005 m .56823 .50084 L .56827 .49805 L F
.596 .037 0 r
.67279 .4544 m .67328 .4553 L .6716 .45286 L F
0 .311 .803 r
.67503 .45678 m .67525 .45639 L .67279 .4544 L F
.596 .037 0 r
.67279 .4544 m .67525 .45639 L .67328 .4553 L F
.69 .76 .905 r
.65444 .42451 m .65084 .42685 L .64898 .42403 L F
.891 .812 .765 r
.65084 .42685 m .64976 .42733 L .64898 .42403 L F
.845 .386 0 r
.62137 .43999 m .62264 .44022 L .62023 .43811 L F
.144 .689 .764 r
.62366 .43993 m .62264 .44022 L .62137 .43999 L F
.62366 .43993 m .6255 .43984 L .62264 .44022 L F
.591 .844 .993 r
.42317 .57489 m .42106 .57568 L .41939 .57456 L F
.818 .586 .587 r
.52995 .68488 m .53005 .68793 L .52665 .68743 L F
.491 .328 .588 r
.52995 .68488 m .53232 .68721 L .53005 .68793 L F
.52995 .68488 m .53232 .68721 L .53005 .68793 L F
.789 .376 .267 r
.57684 .59917 m .58016 .60006 L .5781 .59753 L F
.797 .459 .416 r
.47547 .73139 m .47897 .73212 L .47595 .73009 L F
.971 .817 .632 r
.54814 .66806 m .54786 .6705 L .54684 .66715 L F
.633 .9 .586 r
.34606 .62427 m .3441 .62641 L .34476 .62537 L F
.845 .954 .607 r
.34606 .62427 m .34476 .62537 L .34563 .62382 L F
.371 .709 .986 r
.34476 .62537 m .34747 .62496 L .34549 .62424 L F
.515 .358 .605 r
.34436 .62298 m .34444 .62347 L .34563 .62382 L F
.34444 .62347 m .34476 .62537 L .34563 .62382 L F
.821 .94 .576 r
.34476 .62537 m .34493 .62404 L .34563 .62382 L F
.327 0 0 r
.34493 .62404 m .34862 .6247 L .34563 .62382 L F
.34862 .6247 m .34899 .62476 L .34563 .62382 L F
.371 .709 .986 r
.34476 .62537 m .34549 .62424 L .34493 .62404 L F
.633 .9 .586 r
.3441 .62641 m .34352 .62704 L .34476 .62537 L F
.854 .52 .421 r
.45427 .62875 m .45588 .62711 L .45247 .62636 L F
.45427 .62875 m .45667 .62964 L .45588 .62711 L F
.559 .192 .3 r
.49911 .69723 m .49798 .69949 L .49542 .69945 L F
.439 .07 .24 r
.50083 .69844 m .49911 .69723 L .50149 .6969 L F
.50083 .69844 m .49798 .69949 L .49911 .69723 L F
.356 .44 .81 r
.2191 .56202 m .22051 .56549 L .22196 .56434 L F
.252 .254 .668 r
.22051 .56549 m .2224 .56737 L .22196 .56434 L F
.422 .277 .578 r
.22055 .56799 m .2224 .56737 L .22051 .56549 L F
.467 .252 .503 r
.67699 .4555 m .67525 .45639 L .67503 .45678 L F
.814 .758 .8 r
.58584 .46609 m .58295 .46545 L .58405 .46475 L F
.785 .78 .848 r
.23081 .79395 m .23121 .79358 L .23033 .79344 L F
.865 .944 .867 r
.58956 .61149 m .59196 .60926 L .59099 .60841 L F
.852 .7 .693 r
.58175 .47219 m .58081 .47431 L .57952 .47088 L F
.482 .051 .143 r
.4095 .63545 m .40806 .63737 L .40581 .63722 L F
.499 .096 .207 r
.41185 .63523 m .40806 .63737 L .4095 .63545 L F
.265 0 0 r
.42016 .63375 m .41648 .63449 L .4181 .63377 L F
1 .808 .486 r
.55728 .66866 m .55778 .67338 L .55819 .67083 L F
.154 0 0 r
.52155 .67922 m .52531 .67843 L .52244 .67902 L F
.759 .766 .859 r
.43014 .58194 m .43197 .58363 L .43371 .58212 L F
.556 .191 .304 r
.50829 .67103 m .51064 .67265 L .5081 .67243 L F
.50829 .67103 m .5115 .67069 L .51064 .67265 L F
.936 .576 .301 r
.50626 .66982 m .50829 .67103 L .5081 .67243 L F
.644 .419 .562 r
.19696 .62198 m .19789 .62254 L .19846 .6181 L F
.599 .53 .748 r
.19773 .61464 m .19846 .6181 L .20075 .61742 L F
.564 .347 .544 r
.19846 .6181 m .2004 .62078 L .20075 .61742 L F
.19846 .6181 m .19789 .62254 L .2004 .62078 L F
.269 .034 .36 r
.22868 .60852 m .22641 .61157 L .22698 .60931 L F
.856 .96 .873 r
.61537 .434 m .61187 .43589 L .6142 .43293 L F
.852 .847 .838 r
.61647 .42977 m .61537 .434 L .6142 .43293 L F
.61647 .42977 m .61777 .43121 L .61537 .434 L F
.918 .837 .749 r
.64777 .46652 m .64926 .46521 L .64815 .46247 L F
.813 .804 .842 r
.64815 .46247 m .64926 .46521 L .65152 .46243 L F
.667 .26 .264 r
.48544 .70307 m .48721 .70519 L .48475 .70538 L F
0 0 .12 r
.48594 .69979 m .48544 .70307 L .48607 .70165 L F
0 0 0 r
.48607 .70165 m .48544 .70307 L .48475 .70538 L F
.626 .097 0 r
.5403 .65019 m .54469 .65142 L .54295 .65201 L F
.923 .931 .794 r
.54572 .65042 m .54457 .65109 L .54469 .65142 L F
.484 .329 .595 r
.54572 .65042 m .54621 .65238 L .54469 .65142 L F
.487 .327 .59 r
.54572 .65042 m .54257 .64824 L .54473 .64951 L F
.923 .931 .794 r
.54572 .65042 m .54473 .64951 L .54295 .65201 L F
.713 .196 0 r
.54517 .65035 m .54884 .65179 L .54621 .65238 L F
.54473 .64951 m .54551 .64994 L .54517 .65035 L F
.54551 .64994 m .54884 .65179 L .54517 .65035 L F
.923 .931 .794 r
.54457 .65109 m .54295 .65201 L .54414 .6516 L F
.54457 .65109 m .54414 .6516 L .54469 .65142 L F
.061 .515 .895 r
.20574 .59373 m .20578 .59291 L .20394 .59159 L F
.20574 .59373 m .20739 .59413 L .20578 .59291 L F
.6 .504 .717 r
.69448 .43606 m .69234 .43919 L .69236 .43733 L F
.69448 .43606 m .6956 .442 L .69234 .43919 L F
.497 .207 .404 r
.6165 .45382 m .61886 .45336 L .61968 .45174 L F
.578 .618 .856 r
.61824 .44968 m .61968 .45174 L .62251 .45021 L F
.74 .432 .46 r
.52153 .64973 m .52153 .64757 L .51875 .64773 L F
.421 .179 .44 r
.52153 .64973 m .52153 .64757 L .52415 .6472 L F
.52153 .64973 m .52153 .64757 L .52415 .6472 L F
0 0 .03 r
.48322 .62189 m .48241 .621 L .48413 .62023 L F
.48322 .62189 m .4817 .62325 L .48241 .621 L F
.677 .679 .845 r
.46443 .7059 m .46542 .70208 L .46408 .70213 L F
.46443 .7059 m .46643 .70431 L .46542 .70208 L F
.419 .113 .337 r
.20151 .59173 m .20394 .59159 L .20413 .58957 L F
.512 .188 .355 r
.20413 .58957 m .20394 .59159 L .20609 .5908 L F
.635 .605 .803 r
.54224 .66489 m .54514 .6614 L .54268 .66192 L F
.207 0 0 r
.47715 .62659 m .47604 .62806 L .47391 .62858 L F
0 0 0 r
.47896 .62575 m .47604 .62806 L .47715 .62659 L F
.869 .711 .684 r
.55711 .67604 m .55819 .67896 L .55927 .67681 L F
.174 0 0 r
.55468 .69097 m .55409 .69106 L .55156 .69076 L F
.659 .877 .51 r
.55699 .6876 m .55571 .68925 L .55468 .69097 L F
.702 .962 .709 r
.55468 .69097 m .55571 .68925 L .55409 .69106 L F
.615 .177 .186 r
.44612 .62687 m .44875 .62846 L .45016 .62671 L F
.608 .252 .341 r
.44875 .62846 m .45247 .62636 L .45016 .62671 L F
.715 .353 .361 r
.58402 .60268 m .58661 .60149 L .58381 .60098 L F
.58402 .60268 m .58773 .60287 L .58661 .60149 L F
.972 .709 .476 r
.62748 .45081 m .62758 .45433 L .62882 .45418 L F
.826 .995 .853 r
.62758 .45433 m .62721 .45422 L .62882 .45418 L F
.481 .33 .599 r
.62882 .45418 m .63161 .45137 L .62748 .45081 L F
.62882 .45418 m .631 .45351 L .63161 .45137 L F
.881 .628 .552 r
.62462 .45221 m .62748 .45425 L .62748 .45081 L F
.62748 .45425 m .62758 .45433 L .62758 .45424 L F
.62748 .45425 m .62758 .45424 L .62748 .45081 L F
0 .285 .752 r
.62462 .45221 m .62721 .45422 L .62758 .45433 L F
.423 0 0 r
.62721 .45422 m .631 .45351 L .62952 .45397 L F
.62784 .4542 m .62952 .45397 L .62882 .45418 L F
.62721 .45422 m .62952 .45397 L .62784 .4542 L F
.912 .91 .805 r
.66319 .45989 m .66534 .45673 L .6644 .4558 L F
.942 .923 .761 r
.66534 .45673 m .66558 .45409 L .6644 .4558 L F
.772 .484 .498 r
.35915 .62964 m .35535 .62917 L .35636 .63045 L F
.606 .38 .548 r
.35636 .63045 m .35871 .63249 L .35915 .62964 L F
.118 .642 .879 r
.20557 .54246 m .20762 .54249 L .2093 .54308 L F
.24 .712 .942 r
.20762 .54249 m .21153 .54313 L .2093 .54308 L F
.577 .785 .978 r
.4541 .63036 m .45427 .62875 L .45295 .62957 L F
.4541 .63036 m .45667 .62964 L .45427 .62875 L F
.852 .764 .765 r
.59429 .45085 m .59508 .45421 L .59326 .4526 L F
.833 .745 .767 r
.59508 .45421 m .59111 .45559 L .59326 .4526 L F
.59508 .45421 m .59297 .45724 L .59111 .45559 L F
.778 .722 .8 r
.59762 .45127 m .59508 .45421 L .59429 .45085 L F
0 0 .572 r
.59141 .6169 m .5915 .61803 L .59009 .61499 L F
.919 .608 .44 r
.59033 .61991 m .5915 .61803 L .59141 .6169 L F
.59033 .61991 m .59215 .62082 L .5915 .61803 L F
0 0 .499 r
.67163 .42707 m .66848 .42309 L .67041 .4249 L F
.55 .686 .929 r
.67403 .42655 m .67163 .42707 L .67041 .4249 L F
.683 .484 .61 r
.68833 .44851 m .68865 .45086 L .68516 .45018 L F
.538 .381 .616 r
.68833 .44851 m .69123 .44851 L .68865 .45086 L F
.814 .833 .864 r
.59051 .46016 m .58631 .46157 L .58891 .45877 L F
.822 .789 .821 r
.59297 .45724 m .59051 .46016 L .58891 .45877 L F
.318 0 0 r
.39375 .63943 m .39004 .63978 L .39187 .63936 L F
.346 .477 .849 r
.25314 .55532 m .2544 .55836 L .252 .5563 L F
.396 0 0 r
.17808 .54147 m .17974 .54221 L .18186 .54229 L F
.268 0 0 r
.17974 .54221 m .18395 .54157 L .18186 .54229 L F
.978 .892 .539 r
.64819 .44247 m .64757 .44124 L .64841 .43841 L F
.201 .241 .679 r
.64736 .44505 m .64757 .44124 L .64819 .44247 L F
.482 .552 .851 r
.34838 .62097 m .34851 .61728 L .34693 .61744 L F
.34838 .62097 m .3501 .62043 L .34851 .61728 L F
.53 .342 .57 r
.34838 .62097 m .35097 .6233 L .3501 .62043 L F
.34838 .62097 m .34816 .62404 L .35097 .6233 L F
.679 .263 .25 r
.42142 .62532 m .42372 .62697 L .42526 .62436 L F
.269 0 .036 r
.42526 .62436 m .42834 .62409 L .42652 .62496 L F
.601 .054 0 r
.34708 .62988 m .34568 .62905 L .34352 .62704 L F
.681 .896 .975 r
.34794 .62777 m .34568 .62905 L .34708 .62988 L F
.985 .903 .617 r
.54498 .65858 m .54408 .65726 L .54533 .65642 L F
.555 .31 .498 r
.54268 .66192 m .54498 .65858 L .54329 .66046 L F
.774 .689 .77 r
.54533 .65642 m .54736 .65565 L .54498 .65858 L F
.985 .903 .617 r
.54498 .65858 m .54408 .65726 L .54533 .65642 L F
.013 .443 .867 r
.54498 .65858 m .54607 .65833 L .54408 .65726 L F
.552 .541 .796 r
.54514 .6614 m .54607 .65833 L .54498 .65858 L F
.866 .793 .777 r
.66174 .43607 m .66379 .43839 L .66447 .43661 L F
.995 .81 .544 r
.66192 .4409 m .66379 .43839 L .66174 .43607 L F
.66192 .4409 m .66293 .4419 L .66379 .43839 L F
.815 .71 .749 r
.67139 .41084 m .66737 .41277 L .66985 .40921 L F
.67139 .41084 m .66987 .41352 L .66737 .41277 L F
.721 .751 .875 r
.67241 .40718 m .67139 .41084 L .66985 .40921 L F
.67241 .40718 m .67391 .40998 L .67139 .41084 L F
.63 .475 .654 r
.69688 .43321 m .69448 .43606 L .6944 .43379 L F
.673 .774 .926 r
.49266 .69608 m .49095 .69731 L .48943 .69677 L F
.502 .412 .686 r
.49095 .69731 m .49299 .69951 L .49266 .69608 L F
.905 .767 .698 r
.46643 .70431 m .46759 .70321 L .46542 .70208 L F
.874 .834 .803 r
.58079 .6322 m .5801 .63341 L .57868 .6321 L F
.408 .097 .323 r
.58157 .49189 m .58469 .48931 L .5847 .49131 L F
.557 .349 .555 r
.58469 .48931 m .58731 .49115 L .5847 .49131 L F
.58469 .48931 m .58727 .48871 L .58731 .49115 L F
.725 .341 .322 r
.54197 .68557 m .54059 .6875 L .53869 .68538 L F
.153 0 0 r
.54314 .68617 m .54197 .68557 L .54059 .6875 L F
.54314 .68617 m .54456 .68495 L .54197 .68557 L F
.648 .194 0 r
.55056 .63202 m .55259 .63475 L .55149 .6334 L F
0 .28 .764 r
.55259 .63475 m .5527 .63405 L .55149 .6334 L F
.036 .339 .819 r
.55149 .6334 m .5527 .63405 L .5518 .63241 L F
.761 .253 0 r
.5518 .63241 m .55285 .63492 L .55146 .63387 L F
0 0 0 r
.55149 .6334 m .5518 .63241 L .55184 .63224 L F
.55149 .6334 m .55185 .63221 L .55191 .63187 L F
.041 0 0 r
.55056 .63202 m .55194 .6317 L .55203 .63128 L F
.55194 .6317 m .55345 .63137 L .55203 .63128 L F
.378 .791 .979 r
.55203 .63143 m .55345 .63137 L .55284 .6315 L F
.55196 .63146 m .55284 .6315 L .55056 .63202 L F
.55203 .63143 m .55284 .6315 L .55196 .63146 L F
.051 .358 .831 r
.55149 .6334 m .5518 .63241 L .55075 .63245 L F
.378 .791 .979 r
.55203 .63143 m .55056 .63202 L .54983 .63127 L F
.051 .358 .831 r
.55 .63149 m .5518 .63241 L .54983 .63127 L F
.55149 .6334 m .54983 .63127 L .55056 .63202 L F
.599 .131 .114 r
.54974 .63135 m .5518 .63241 L .54827 .63256 L F
.54983 .63127 m .54999 .63136 L .54974 .63135 L F
.54999 .63136 m .5518 .63241 L .54974 .63135 L F
.761 .253 0 r
.5518 .63241 m .55146 .63387 L .55105 .63356 L F
0 0 0 r
.55184 .63224 m .5518 .63241 L .55185 .63221 L F
.55191 .63187 m .55185 .63221 L .55203 .63143 L F
.041 0 0 r
.55203 .63128 m .55345 .63137 L .55419 .63018 L F
.186 0 0 r
.55419 .63018 m .55557 .6308 L .55909 .63176 L F
.55419 .63018 m .55345 .63137 L .55557 .6308 L F
.695 .313 .321 r
.53355 .67842 m .53704 .67685 L .53595 .67488 L F
.53355 .67842 m .53634 .67884 L .53704 .67685 L F
.47 .091 .238 r
.53704 .67685 m .53634 .67884 L .53993 .67763 L F
.433 .181 .431 r
.56393 .60379 m .56643 .60332 L .56369 .60574 L F
.038 0 0 r
.6262 .457 m .62308 .45948 L .62528 .45845 L F
.967 .839 .425 r
.6262 .457 m .62528 .45845 L .62574 .45619 L F
.6262 .457 m .62528 .45845 L .62574 .45619 L F
.683 .139 0 r
.46542 .70208 m .46363 .70066 L .46408 .70213 L F
.517 .62 .893 r
.56271 .63191 m .5612 .63366 L .56058 .63291 L F
.56271 .63191 m .5642 .63487 L .5612 .63366 L F
.22 0 .012 r
.48362 .61132 m .48199 .61358 L .48448 .61274 L F
.67 .806 .948 r
.6202 .42983 m .61777 .43121 L .61647 .42977 L F
.875 .706 .669 r
.62065 .44765 m .62391 .44552 L .62195 .44669 L F
.62065 .44765 m .62348 .44836 L .62391 .44552 L F
.584 .925 .724 r
.62531 .44405 m .62195 .44669 L .62391 .44552 L F
.643 .317 .404 r
.61345 .45629 m .6165 .45382 L .61364 .45366 L F
.61345 .45629 m .61626 .45589 L .6165 .45382 L F
.38 .05 .274 r
.61626 .45589 m .61886 .45336 L .6165 .45382 L F
.665 .523 .682 r
.46213 .6267 m .45978 .62966 L .45976 .62721 L F
.45976 .62721 m .45978 .62966 L .46213 .6267 L F
.818 .809 .842 r
.62308 .45948 m .62157 .46384 L .61932 .45907 L F
.865 .944 .867 r
.58956 .61149 m .59141 .6108 L .58976 .61149 L F
.58956 .61149 m .59099 .60841 L .59141 .6108 L F
.224 .726 .905 r
.18395 .54157 m .18603 .54144 L .18783 .5418 L F
.241 0 0 r
.18603 .54144 m .18992 .54189 L .18783 .5418 L F
0 0 0 r
.65986 .46248 m .66319 .45989 L .66223 .46107 L F
.912 .91 .805 r
.66319 .45989 m .6644 .4558 L .66326 .45924 L F
.789 .898 .491 r
.66223 .46107 m .66319 .45989 L .66326 .45924 L F
0 0 .03 r
.21573 .57686 m .21796 .57344 L .21668 .57425 L F
.348 .144 .455 r
.20675 .60051 m .20639 .60291 L .20851 .59981 L F
.724 .651 .776 r
.68659 .45215 m .68425 .45431 L .68268 .45107 L F
0 0 0 r
.53183 .63838 m .52974 .64052 L .53051 .64003 L F
.082 .515 .902 r
.52974 .64052 m .53208 .64125 L .53051 .64003 L F
.728 .913 .55 r
.41229 .58681 m .41182 .58777 L .41359 .58553 L F
.014 0 0 r
.41607 .5845 m .41525 .58529 L .41359 .58553 L F
.406 0 .149 r
.41525 .58529 m .41229 .58681 L .41359 .58553 L F
.795 .708 .769 r
.53217 .65573 m .53372 .65913 L .53564 .656 L F
.28 0 0 r
.17401 .54264 m .17808 .54147 L .17561 .54198 L F
.772 .641 .081 r
.59069 .62765 m .59087 .6268 L .59061 .62474 L F
.59069 .62765 m .59078 .62942 L .59087 .6268 L F
.321 0 0 r
.62782 .47689 m .62883 .47798 L .62664 .47847 L F
.62782 .47689 m .6302 .47675 L .62883 .47798 L F
.665 .358 .443 r
.47378 .61969 m .47218 .61745 L .47281 .62069 L F
.47378 .61969 m .47535 .61807 L .47218 .61745 L F
.752 .749 .849 r
.51318 .68178 m .51622 .68295 L .51727 .68096 L F
.082 0 .395 r
.51727 .68096 m .51622 .68295 L .51824 .68126 L F
.355 .408 .778 r
.51622 .68295 m .51924 .68407 L .51824 .68126 L F
.168 .425 .862 r
.67144 .41535 m .6734 .41814 L .67489 .41839 L F
.335 .207 .554 r
.23056 .60515 m .22901 .60332 L .23061 .60263 L F
.23056 .60515 m .22858 .60637 L .22901 .60332 L F
.56 .417 .644 r
.23704 .59106 m .2346 .58986 L .2367 .5879 L F
.23704 .59106 m .23497 .59155 L .2346 .58986 L F
.628 .424 .587 r
.48493 .68818 m .48466 .69101 L .48217 .69099 L F
.506 .838 .998 r
.48553 .68673 m .48493 .68818 L .48313 .68744 L F
.48553 .68673 m .48703 .68752 L .48493 .68818 L F
.568 .423 .645 r
.48703 .68752 m .48466 .69101 L .48493 .68818 L F
.633 .847 .982 r
.42659 .57495 m .42317 .57489 L .42543 .5741 L F
.562 .798 .987 r
.42756 .5733 m .42659 .57495 L .42543 .5741 L F
.42756 .5733 m .42881 .57436 L .42659 .57495 L F
0 .197 .716 r
.45609 .58083 m .45597 .58257 L .45502 .58064 L F
.43 .196 .455 r
.45511 .58541 m .45597 .58257 L .45609 .58083 L F
.45511 .58541 m .45657 .58278 L .45597 .58257 L F
.775 .693 .773 r
.54621 .65238 m .54736 .65565 L .54533 .65642 L F
.728 .669 .792 r
.54621 .65238 m .55041 .65275 L .54736 .65565 L F
.441 .029 .159 r
.53609 .68488 m .53476 .68703 L .53232 .68721 L F
.607 .203 .252 r
.53858 .68665 m .53609 .68488 L .53869 .68538 L F
.53858 .68665 m .53476 .68703 L .53609 .68488 L F
.955 .645 .404 r
.65047 .43497 m .6491 .43325 L .65022 .43381 L F
.748 .937 .947 r
.20366 .6058 m .20454 .60487 L .20299 .60303 L F
.20454 .60487 m .20639 .60291 L .20364 .603 L F
.20454 .60487 m .20364 .603 L .20299 .60303 L F
.198 .295 .739 r
.2049 .60418 m .20501 .60398 L .2048 .60342 L F
.748 .937 .947 r
.20454 .60487 m .2049 .60418 L .20639 .60291 L F
.198 .295 .739 r
.20557 .60913 m .2049 .60418 L .20366 .6058 L F
.2049 .60418 m .2048 .60342 L .20366 .6058 L F
.748 .937 .947 r
.20542 .60374 m .20566 .60319 L .20639 .60291 L F
.2049 .60418 m .20532 .60364 L .20542 .60374 L F
.20532 .60364 m .20566 .60319 L .20542 .60374 L F
.323 .432 .818 r
.2048 .60342 m .20526 .60358 L .20509 .60341 L F
.748 .937 .947 r
.20501 .60398 m .20536 .60331 L .20552 .60324 L F
.478 .472 .772 r
.2048 .60342 m .20501 .60398 L .20516 .60377 L F
.323 .432 .818 r
.20526 .60358 m .20851 .60701 L .20732 .60429 L F
.2048 .60342 m .20516 .60377 L .20526 .60358 L F
.748 .937 .947 r
.205 .60404 m .2051 .60386 L .20566 .60319 L F
.323 .432 .818 r
.20516 .60377 m .20851 .60701 L .20526 .60358 L F
.748 .937 .947 r
.2049 .60418 m .20501 .60398 L .2051 .60386 L F
.2049 .60418 m .2051 .60386 L .205 .60404 L F
.20366 .6058 m .20509 .60341 L .20536 .60331 L F
.20366 .6058 m .20536 .60331 L .20454 .60487 L F
.323 .432 .818 r
.20526 .60358 m .20732 .60429 L .20509 .60341 L F
.478 .472 .772 r
.20516 .60377 m .20666 .60844 L .20851 .60701 L F
.20501 .60398 m .20666 .60844 L .20516 .60377 L F
.748 .937 .947 r
.20501 .60398 m .20552 .60324 L .20566 .60319 L F
.198 .295 .739 r
.20517 .60617 m .20666 .60844 L .20501 .60398 L F
.20517 .60617 m .20501 .60398 L .2049 .60418 L F
.20557 .60913 m .20636 .60863 L .20517 .60617 L F
.20636 .60863 m .20666 .60844 L .20517 .60617 L F
0 0 .108 r
.20471 .61077 m .20666 .60844 L .20557 .60913 L F
.926 .864 .76 r
.5808 .62901 m .58079 .6322 L .57868 .6321 L F
.825 .356 0 r
.66019 .43445 m .66073 .4339 L .65939 .43288 L F
.66019 .43445 m .66173 .4356 L .66073 .4339 L F
0 .118 .643 r
.47274 .71672 m .47206 .71854 L .47134 .71486 L F
0 .26 .767 r
.47405 .71892 m .47206 .71854 L .47274 .71672 L F
.47405 .71892 m .4735 .71995 L .47206 .71854 L F
0 0 .19 r
.20917 .59765 m .20851 .59981 L .21044 .59658 L F
.573 .554 .795 r
.37201 .60795 m .37233 .60981 L .37005 .6089 L F
.65 .519 .691 r
.37329 .6118 m .37005 .6089 L .37233 .60981 L F
.37329 .6118 m .37098 .61252 L .37005 .6089 L F
.807 .786 .833 r
.52581 .72575 m .52729 .72787 L .52916 .72595 L F
.184 0 .298 r
.21085 .64031 m .20943 .64139 L .21161 .63831 L F
.565 .401 .618 r
.21085 .64031 m .20887 .64385 L .20943 .64139 L F
.551 .545 .801 r
.21337 .56183 m .21437 .55837 L .21241 .55853 L F
.21337 .56183 m .21558 .5612 L .21437 .55837 L F
.21 .042 .422 r
.22407 .61971 m .22299 .61806 L .22441 .61729 L F
.22407 .61971 m .22269 .62046 L .22299 .61806 L F
.599 .274 .389 r
.60989 .4807 m .61239 .48248 L .61006 .48225 L F
.611 .264 .358 r
.61332 .48032 m .61239 .48248 L .60989 .4807 L F
.386 0 0 r
.42142 .62532 m .41886 .62465 L .41743 .62538 L F
.568 .428 .65 r
.56659 .62973 m .56918 .62929 L .56847 .6268 L F
.789 .716 .783 r
.56635 .63204 m .56918 .62929 L .56659 .62973 L F
.759 .346 .266 r
.66987 .41352 m .66874 .41433 L .66737 .41277 L F
0 .307 .723 r
.55938 .63971 m .55885 .63913 L .55767 .63854 L F
.576 .078 .035 r
.56116 .64001 m .5631 .64128 L .56042 .64003 L F
.485 0 0 r
.56174 .64046 m .5595 .63943 L .55938 .63971 L F
.5595 .63943 m .55885 .63913 L .55894 .63923 L F
.56174 .64046 m .56042 .64003 L .55885 .63913 L F
.576 .078 .035 r
.56411 .63992 m .56042 .64003 L .56174 .64046 L F
.56411 .63992 m .56344 .64081 L .56116 .64001 L F
.56344 .64081 m .5631 .64128 L .56116 .64001 L F
.485 0 0 r
.5595 .63943 m .55894 .63923 L .55938 .63971 L F
.658 .252 .265 r
.48597 .69734 m .48317 .69726 L .48601 .69682 L F
.496 .859 .988 r
.48601 .69682 m .48943 .69677 L .48597 .69734 L F
0 0 0 r
.48417 .61731 m .48668 .6148 L .48651 .61726 L F
.287 .389 .792 r
.48579 .61192 m .48843 .61375 L .48668 .6148 L F
.208 0 .282 r
.48826 .61628 m .48668 .6148 L .48843 .61375 L F
.48826 .61628 m .48651 .61726 L .48668 .6148 L F
.674 .21 .144 r
.57279 .63006 m .56918 .62929 L .56939 .63254 L F
0 0 0 r
.53821 .66754 m .5389 .66743 L .54049 .66734 L F
.832 .808 .827 r
.62956 .41605 m .63218 .41374 L .63171 .41194 L F
.628 .686 .885 r
.63461 .41266 m .63218 .41374 L .63171 .41194 L F
.427 .192 .453 r
.63428 .41478 m .63218 .41374 L .63461 .41266 L F
.148 .332 .792 r
.63171 .41194 m .63218 .41374 L .63428 .41478 L F
0 .311 .747 r
.63218 .41374 m .63534 .41568 L .63428 .41478 L F
.249 .696 .957 r
.22158 .54362 m .22194 .5437 L .2232 .54421 L F
.508 0 0 r
.22158 .54308 m .2232 .54421 L .22443 .54471 L F
.249 .696 .957 r
.22194 .5437 m .22533 .54446 L .2232 .54421 L F
.508 0 0 r
.22443 .54471 m .2232 .54421 L .22494 .545 L F
.13 .622 .911 r
.2232 .54421 m .22694 .54524 L .22494 .545 L F
.227 0 .215 r
.52763 .67658 m .52984 .67574 L .53085 .67396 L F
.338 .133 .448 r
.52763 .67658 m .52737 .67921 L .52984 .67574 L F
.56 .261 .418 r
.61332 .48032 m .61579 .48194 L .61239 .48248 L F
.61332 .48032 m .61586 .48008 L .61579 .48194 L F
.774 .55 .595 r
.50648 .72058 m .50588 .72315 L .50956 .72311 L F
.223 .299 .732 r
.34352 .62704 m .34568 .62905 L .34476 .62537 L F
.718 .425 .48 r
.43709 .62568 m .44031 .62357 L .437 .6241 L F
.43709 .62568 m .43953 .62655 L .44031 .62357 L F
.589 .297 .441 r
.44031 .62357 m .44273 .62536 L .44412 .62412 L F
.44031 .62357 m .43953 .62655 L .44273 .62536 L F
0 0 0 r
.37828 .58414 m .38058 .58371 L .38269 .58315 L F
.085 0 0 r
.38058 .58371 m .38479 .58248 L .38269 .58315 L F
.567 .244 .38 r
.4898 .72863 m .49228 .72859 L .49362 .7261 L F
.588 .509 .733 r
.49629 .72834 m .49362 .7261 L .49535 .72722 L F
.526 .227 .403 r
.49228 .72859 m .49535 .72722 L .49362 .7261 L F
.73 .633 .75 r
.18347 .57828 m .18458 .57699 L .18299 .57692 L F
.49 .134 .289 r
.5074 .69404 m .50632 .69653 L .50389 .69669 L F
0 .01 .546 r
.50746 .69095 m .5074 .69404 L .50681 .69098 L F
.50746 .69095 m .50832 .69296 L .5074 .69404 L F
.604 .48 .685 r
.50832 .69296 m .50632 .69653 L .5074 .69404 L F
.102 0 0 r
.18054 .55309 m .17653 .55477 L .17808 .55363 L F
.857 .404 .097 r
.5895 .60775 m .58993 .60626 L .5886 .6049 L F
.5895 .60775 m .59099 .60841 L .58993 .60626 L F
.567 .25 .392 r
.60162 .48331 m .60404 .48493 L .60209 .48476 L F
.593 .223 .31 r
.60401 .48352 m .60404 .48493 L .60162 .48331 L F
.094 .518 .906 r
.23861 .54908 m .23842 .54997 L .23651 .54804 L F
.23861 .54908 m .24015 .55039 L .23842 .54997 L F
.477 .02 .088 r
.42388 .63263 m .42608 .63346 L .42239 .63406 L F
.42388 .63263 m .42624 .63272 L .42608 .63346 L F
.866 .793 .777 r
.66174 .43607 m .66447 .43661 L .66173 .4356 L F
.631 .461 .634 r
.38235 .59935 m .38006 .60203 L .38002 .60026 L F
.461 .002 .074 r
.36453 .58598 m .36636 .58695 L .36797 .58524 L F
.324 0 0 r
.36636 .58695 m .37031 .58511 L .36797 .58524 L F
.822 .789 .821 r
.59297 .45724 m .58891 .45877 L .59111 .45559 L F
.588 .682 .906 r
.6748 .40653 m .67391 .40998 L .67241 .40718 L F
.6748 .40653 m .67643 .40932 L .67391 .40998 L F
.275 .777 .858 r
.43092 .62375 m .43321 .62332 L .43506 .6232 L F
.749 .342 .281 r
.43321 .62332 m .437 .6241 L .43506 .6232 L F
.937 .849 .73 r
.50646 .72511 m .50956 .72311 L .50588 .72315 L F
.50646 .72511 m .50791 .72602 L .50956 .72311 L F
.953 .652 .426 r
.53051 .64003 m .53208 .64125 L .53183 .63838 L F
.586 .424 .629 r
.21296 .63717 m .21085 .64031 L .21161 .63831 L F
.084 0 .249 r
.34547 .59457 m .34686 .5938 L .34755 .5914 L F
.471 .167 .368 r
.34547 .59457 m .34721 .5962 L .34686 .5938 L F
.34547 .59457 m .34488 .59674 L .34721 .5962 L F
.472 .886 .769 r
.40373 .59027 m .4028 .59107 L .40358 .59081 L F
.542 .678 .927 r
.24222 .55038 m .24189 .5531 L .24015 .55039 L F
.24222 .55038 m .24433 .55272 L .24189 .5531 L F
.775 .485 .494 r
.56545 .64325 m .56777 .64187 L .56564 .64089 L F
.56545 .64325 m .56872 .64373 L .56777 .64187 L F
.979 .693 .316 r
.63522 .47379 m .63604 .47415 L .63544 .4722 L F
.543 .919 .774 r
.63237 .47611 m .63604 .47415 L .63522 .47379 L F
.737 .564 .658 r
.57397 .4958 m .5741 .49775 L .57065 .49772 L F
.608 .46 .655 r
.57685 .49501 m .5741 .49775 L .57397 .4958 L F
.599 .53 .748 r
.19773 .61464 m .20075 .61742 L .19929 .61393 L F
.158 .428 .865 r
.58479 .64379 m .5833 .64128 L .58146 .64052 L F
.634 .693 .887 r
.58676 .64345 m .5833 .64128 L .58479 .64379 L F
.544 .876 .991 r
.519 .73272 m .52005 .73129 L .51747 .7321 L F
.519 .73272 m .52124 .73194 L .52005 .73129 L F
.319 .806 .863 r
.40934 .57731 m .40889 .57789 L .40711 .57791 L F
.40934 .57731 m .41112 .57734 L .40889 .57789 L F
.581 .766 .967 r
.36265 .63354 m .36653 .63464 L .36448 .63279 L F
.481 .711 .971 r
.36653 .63464 m .36746 .63301 L .36448 .63279 L F
.36653 .63464 m .36873 .63444 L .36746 .63301 L F
.36 .077 .342 r
.23918 .583 m .23862 .58499 L .23673 .58553 L F
.51 .3 .53 r
.24124 .58183 m .23862 .58499 L .23918 .583 L F
.833 .965 .89 r
.52049 .68511 m .5189 .6867 L .51769 .6873 L F
.554 .594 .848 r
.54829 .66382 m .54514 .6614 L .54747 .66513 L F
.866 .766 .749 r
.66397 .44501 m .66293 .4419 L .66299 .44402 L F
.962 .647 .245 r
.66423 .44926 m .66397 .44501 L .66299 .44402 L F
.744 .681 .79 r
.47722 .68475 m .47886 .68781 L .4798 .68574 L F
.413 .299 .614 r
.4798 .68574 m .47886 .68781 L .48054 .6881 L F
.43 .014 .146 r
.21347 .57875 m .21508 .57852 L .21573 .57686 L F
0 0 .03 r
.21573 .57686 m .21722 .57552 L .21796 .57344 L F
0 0 0 r
.21573 .57686 m .21508 .57852 L .21722 .57552 L F
.925 .586 .376 r
.54476 .70233 m .54599 .70302 L .54482 .70476 L F
0 0 0 r
.54476 .70233 m .54711 .70167 L .54599 .70302 L F
.54711 .70167 m .54482 .70476 L .54599 .70302 L F
.229 .02 .374 r
.51344 .66729 m .51338 .67015 L .5115 .67069 L F
.317 .34 .726 r
.51529 .66667 m .51344 .66729 L .51337 .66608 L F
.225 .017 .373 r
.515 .66882 m .51344 .66729 L .51529 .66667 L F
.515 .66882 m .51338 .67015 L .51344 .66729 L F
0 0 0 r
.69576 .44197 m .69891 .44187 L .69911 .44185 L F
.576 .893 .987 r
.70163 .44101 m .69911 .44185 L .70029 .4405 L F
.586 .899 .63 r
.69911 .44185 m .69891 .44187 L .70029 .4405 L F
.554 .543 .797 r
.70221 .44433 m .69911 .44185 L .70163 .44101 L F
.705 .732 .872 r
.67893 .45051 m .68057 .4524 L .68268 .45107 L F
.612 .102 .014 r
.67893 .45051 m .68268 .45107 L .68057 .4524 L F
.775 .411 .368 r
.58204 .60046 m .58402 .60268 L .58381 .60098 L F
.451 .839 .984 r
.18992 .54189 m .1921 .54139 L .19075 .5419 L F
.241 0 0 r
.18603 .54144 m .18794 .54188 L .18992 .54189 L F
.334 0 0 r
.18794 .54188 m .1921 .54139 L .18992 .54189 L F
.18794 .54188 m .19008 .54212 L .1921 .54139 L F
.185 0 0 r
.19008 .54212 m .1934 .5409 L .1921 .54139 L F
.1934 .5409 m .19408 .54065 L .1921 .54139 L F
.451 .839 .984 r
.19075 .5419 m .1921 .54139 L .19374 .54192 L F
.564 .886 .989 r
.19374 .54192 m .19408 .54065 L .1959 .5412 L F
.19374 .54192 m .1921 .54139 L .19408 .54065 L F
.035 0 .075 r
.21796 .57344 m .2204 .5707 L .21888 .57162 L F
.861 .824 .81 r
.57549 .47706 m .57565 .48005 L .57336 .48008 L F
.854 .839 .829 r
.57336 .48008 m .57565 .48005 L .57277 .4823 L F
.778 .765 .841 r
.57881 .47737 m .57565 .48005 L .57549 .47706 L F
.551 .435 .675 r
.69907 .42811 m .69667 .43076 L .69584 .42706 L F
.69907 .42811 m .69913 .43016 L .69667 .43076 L F
.535 .384 .622 r
.69913 .43016 m .69688 .43321 L .69667 .43076 L F
.526 .537 .81 r
.57529 .60345 m .57688 .60509 L .57711 .60635 L F
.724 .915 .959 r
.57711 .60635 m .57814 .60451 L .57529 .60345 L F
.724 .651 .776 r
.68659 .45215 m .68268 .45107 L .68516 .45018 L F
.669 .551 .712 r
.68865 .45086 m .68659 .45215 L .68516 .45018 L F
.869 .985 .708 r
.63589 .446 m .63422 .44842 L .63456 .44655 L F
0 0 0 r
.63422 .44842 m .63466 .44882 L .63456 .44655 L F
.982 .701 .4 r
.63456 .44655 m .63466 .44882 L .63384 .44685 L F
.63456 .44655 m .63384 .44685 L .63334 .44566 L F
.869 .985 .708 r
.63621 .44554 m .63589 .446 L .63456 .44655 L F
.935 .654 .183 r
.63621 .44554 m .63491 .44131 L .63651 .44321 L F
.63621 .44554 m .63542 .44428 L .63491 .44131 L F
.986 .898 .627 r
.63621 .44554 m .63456 .44655 L .63542 .44428 L F
0 0 0 r
.54822 .69984 m .54732 .70187 L .54711 .70167 L F
.575 .54 .778 r
.69788 .42464 m .69584 .42706 L .69545 .42553 L F
.69788 .42464 m .69907 .42811 L .69584 .42706 L F
.966 .805 .631 r
.67069 .44962 m .67265 .45122 L .6716 .45286 L F
.584 .27 .403 r
.37844 .60339 m .37762 .60279 L .38006 .60203 L F
.37844 .60339 m .37656 .60567 L .37762 .60279 L F
.64 .197 .181 r
.51348 .69428 m .51223 .69583 L .50937 .69424 L F
.252 0 0 r
.51579 .69373 m .51223 .69583 L .51348 .69428 L F
.677 .538 .689 r
.46776 .62424 m .46815 .62667 L .47057 .62399 L F
.727 .471 .54 r
.43321 .62332 m .43709 .62568 L .437 .6241 L F
.936 .605 .38 r
.53866 .64946 m .5403 .65019 L .5391 .65182 L F
.826 .876 .881 r
.54257 .64824 m .5403 .65019 L .53866 .64946 L F
.624 .17 .154 r
.5403 .65019 m .54295 .65201 L .5391 .65182 L F
0 0 .334 r
.6669 .43361 m .66752 .43465 L .6662 .43227 L F
.6669 .43361 m .66773 .43567 L .66752 .43465 L F
.337 .778 .963 r
.46336 .63299 m .46379 .63201 L .46251 .6311 L F
.46336 .63299 m .46623 .63279 L .46379 .63201 L F
.773 .731 .814 r
.59667 .44809 m .59762 .45127 L .59429 .45085 L F
.786 .738 .808 r
.60012 .44844 m .59762 .45127 L .59667 .44809 L F
.683 .139 0 r
.46542 .70208 m .46442 .69983 L .46363 .70066 L F
.548 .315 .514 r
.64815 .46247 m .64744 .4599 L .64549 .46239 L F
.385 .481 .835 r
.64667 .457 m .64744 .4599 L .64952 .4582 L F
.661 .611 .788 r
.64815 .46247 m .64952 .4582 L .64744 .4599 L F
.558 .555 .807 r
.20035 .60295 m .20168 .60635 L .20366 .6058 L F
.133 0 .105 r
.5115 .67069 m .51338 .67015 L .51064 .67265 L F
.492 .265 .497 r
.49185 .72338 m .49461 .72007 L .49195 .72023 L F
.004 .062 .571 r
.63669 .47003 m .63495 .46951 L .63774 .4687 L F
.63669 .47003 m .63544 .4722 L .63495 .46951 L F
.657 .649 .831 r
.68019 .4126 m .67643 .40932 L .67853 .40881 L F
.57 .672 .908 r
.68085 .40829 m .68019 .4126 L .67853 .40881 L F
.68085 .40829 m .68386 .41234 L .68019 .4126 L F
.594 .687 .906 r
.68336 .41281 m .68019 .4126 L .68386 .41234 L F
0 0 .384 r
.6485 .46669 m .64764 .46867 L .64777 .46652 L F
.078 .202 .692 r
.64944 .47039 m .64764 .46867 L .6485 .46669 L F
.49 .241 .463 r
.64703 .4712 m .64764 .46867 L .64944 .47039 L F
.577 .525 .76 r
.68951 .415 m .68798 .41954 L .68701 .41567 L F
.68951 .415 m .69086 .41903 L .68798 .41954 L F
.759 .766 .859 r
.43014 .58194 m .43371 .58212 L .43268 .57989 L F
.759 .811 .894 r
.43268 .57989 m .43371 .58212 L .43605 .57995 L F
.985 .716 .423 r
.62833 .41722 m .62956 .41605 L .62828 .41488 L F
.62833 .41722 m .62956 .41605 L .62828 .41488 L F
.713 .917 .569 r
.62728 .4191 m .62956 .41605 L .62833 .41722 L F
.314 .09 .406 r
.21535 .63338 m .21296 .63717 L .21359 .63498 L F
0 0 0 r
.20819 .58142 m .20915 .58094 L .21118 .58014 L F
.20819 .58142 m .20772 .58307 L .20915 .58094 L F
.798 .419 0 r
.66287 .42451 m .66298 .42575 L .66149 .42312 L F
.66287 .42451 m .66381 .42703 L .66298 .42575 L F
.772 .484 .498 r
.35915 .62964 m .35835 .63194 L .35535 .62917 L F
.239 0 .274 r
.57049 .6261 m .57115 .62369 L .56847 .6268 L F
.481 .213 .43 r
.57049 .6261 m .57342 .62289 L .57115 .62369 L F
.387 .161 .444 r
.24472 .56751 m .24463 .57023 L .2426 .57087 L F
.365 .369 .731 r
.24424 .56513 m .2468 .56739 L .24472 .56751 L F
.178 .002 .39 r
.24599 .56939 m .24472 .56751 L .2468 .56739 L F
.24599 .56939 m .24463 .57023 L .24472 .56751 L F
.317 .492 .873 r
.3696 .6364 m .37042 .63492 L .36873 .63444 L F
.3696 .6364 m .37223 .63772 L .37042 .63492 L F
.486 .306 .561 r
.46759 .71763 m .46693 .72013 L .46919 .72026 L F
.818 .686 .718 r
.57952 .47088 m .58081 .47431 L .57759 .47394 L F
.815 .702 .741 r
.57759 .47394 m .58081 .47431 L .57881 .47737 L F
0 0 0 r
.63422 .44842 m .63359 .45065 L .63466 .44882 L F
.238 0 0 r
.39759 .63845 m .39595 .63936 L .39375 .63943 L F
.148 0 0 r
.39994 .63867 m .39595 .63936 L .39759 .63845 L F
.56 .512 .759 r
.45713 .57953 m .45502 .58064 L .45405 .57703 L F
0 .197 .716 r
.45609 .58083 m .45502 .58064 L .45713 .57953 L F
.76 .36 0 r
.52199 .66226 m .52206 .66208 L .52121 .6604 L F
.52121 .6604 m .52206 .66208 L .52199 .66226 L F
.22 .018 .378 r
.48574 .61911 m .48417 .61731 L .48651 .61726 L F
.48574 .61911 m .48413 .62023 L .48417 .61731 L F
.185 0 0 r
.52176 .6897 m .52397 .68965 L .51993 .69051 L F
.386 0 .164 r
.52465 .68847 m .52397 .68965 L .52176 .6897 L F
.713 .792 .913 r
.47183 .7313 m .47321 .73277 L .47547 .73139 L F
.468 .492 .8 r
.45311 .58581 m .45424 .58152 L .45185 .58233 L F
.45311 .58581 m .45511 .58541 L .45424 .58152 L F
.171 0 0 r
.38976 .62796 m .39133 .62721 L .38895 .62737 L F
.6 .748 .948 r
.436 .57394 m .43359 .57611 L .43095 .57403 L F
.118 0 .428 r
.26046 .77831 m .25963 .78044 L .26003 .78154 L F
.659 .642 .822 r
.48594 .69979 m .48601 .69682 L .48317 .69726 L F
.48594 .69979 m .48707 .69973 L .48601 .69682 L F
0 0 .12 r
.48594 .69979 m .48607 .70165 L .48707 .69973 L F
.337 .141 .461 r
.22065 .62369 m .22039 .62604 L .21861 .62653 L F
.274 .067 .406 r
.22039 .62604 m .21752 .62892 L .21861 .62653 L F
.689 .981 .867 r
.4167 .57587 m .41483 .57727 L .41559 .57586 L F
.581 .888 .99 r
.41483 .57727 m .41339 .57668 L .41559 .57586 L F
.734 .57 .67 r
.18299 .57692 m .18273 .57366 L .18199 .57456 L F
.777 .611 .674 r
.62283 .43212 m .62418 .43094 L .6202 .42983 L F
.765 .743 .833 r
.56635 .63204 m .5642 .63487 L .56271 .63191 L F
.532 .402 .649 r
.56648 .63765 m .5642 .63487 L .56681 .63461 L F
.56648 .63765 m .56463 .63887 L .5642 .63487 L F
.768 .32 .186 r
.54533 .65642 m .54408 .65726 L .54319 .65628 L F
.775 .693 .773 r
.54621 .65238 m .54533 .65642 L .54319 .65628 L F
.414 0 .037 r
.20994 .58874 m .21103 .59 L .21214 .58824 L F
.20994 .58874 m .20812 .59032 L .21103 .59 L F
.681 .272 .264 r
.18161 .57357 m .18273 .57366 L .18213 .57304 L F
.69 .391 .463 r
.62251 .45021 m .62348 .44836 L .62065 .44765 L F
.62251 .45021 m .62393 .45037 L .62348 .44836 L F
.78 .449 .427 r
.62348 .44836 m .62393 .45037 L .62748 .45081 L F
.577 .348 .532 r
.58157 .49189 m .58161 .49463 L .57906 .49493 L F
.564 .337 .53 r
.58157 .49189 m .58452 .4938 L .58161 .49463 L F
.58157 .49189 m .5847 .49131 L .58452 .4938 L F
.693 .751 .896 r
.66609 .41662 m .66643 .41906 L .66304 .41835 L F
.254 .406 .822 r
.66772 .41728 m .66643 .41906 L .66609 .41662 L F
.161 .259 .717 r
.66886 .42003 m .66643 .41906 L .66772 .41728 L F
.66886 .42003 m .6679 .42115 L .66643 .41906 L F
.813 .804 .842 r
.64815 .46247 m .65152 .46243 L .6505 .46149 L F
.732 .917 .956 r
.6505 .46149 m .65152 .46243 L .65448 .46048 L F
.583 .267 .399 r
.60806 .48159 m .60404 .48493 L .60401 .48352 L F
.60806 .48159 m .60652 .48496 L .60404 .48493 L F
.573 .24 .366 r
.60806 .48159 m .60927 .48473 L .60652 .48496 L F
.60806 .48159 m .61006 .48225 L .60927 .48473 L F
.644 .085 0 r
.43142 .62499 m .43092 .62375 L .4298 .62367 L F
.43142 .62499 m .43313 .62568 L .43092 .62375 L F
.532 .309 .522 r
.43092 .62375 m .43313 .62568 L .43321 .62332 L F
.253 0 0 r
.39722 .62889 m .3996 .62854 L .40114 .62718 L F
.418 0 0 r
.40114 .62718 m .3996 .62854 L .40319 .62793 L F
.83 .663 .675 r
.54085 .62334 m .5413 .62647 L .54053 .62445 L F
.654 .532 .703 r
.37329 .6118 m .37095 .61439 L .37098 .61252 L F
.831 .515 0 r
.62981 .43778 m .63065 .43948 L .62738 .43829 L F
.62981 .43778 m .63083 .44018 L .63065 .43948 L F
.082 0 .395 r
.51727 .68096 m .51824 .68126 L .51982 .67883 L F
.174 0 0 r
.51824 .68126 m .52155 .67922 L .51982 .67883 L F
.306 .118 .454 r
.21752 .62892 m .21801 .63176 L .21579 .63205 L F
.259 .015 .341 r
.21801 .63176 m .21535 .63338 L .21579 .63205 L F
.704 .656 .799 r
.69123 .44851 m .69206 .4515 L .68865 .45086 L F
.556 .514 .764 r
.69352 .44732 m .69206 .4515 L .69123 .44851 L F
.69352 .44732 m .69491 .45068 L .69206 .4515 L F
.534 .434 .688 r
.69491 .45068 m .69485 .45317 L .69206 .4515 L F
.536 .434 .685 r
.69485 .45317 m .69276 .45448 L .69206 .4515 L F
.166 .057 .474 r
.51724 .71135 m .51883 .7104 L .51875 .70823 L F
.216 .152 .566 r
.51724 .71135 m .51918 .71145 L .51883 .7104 L F
.62 .481 .671 r
.3733 .61356 m .37095 .61439 L .37329 .6118 L F
.646 .805 .959 r
.67886 .42544 m .67786 .42791 L .68002 .42683 L F
.68002 .42683 m .67786 .42791 L .67886 .42544 L F
0 0 0 r
.57223 .48251 m .57129 .48596 L .57084 .48519 L F
.944 .902 .512 r
.57084 .48519 m .57129 .48596 L .57024 .48767 L F
.035 0 0 r
.52465 .68847 m .52665 .68743 L .52397 .68965 L F
.752 .803 .893 r
.6355 .41857 m .639 .41873 L .63819 .41779 L F
.702 .651 .796 r
.639 .41873 m .63789 .41515 L .63819 .41779 L F
.639 .41873 m .64037 .41845 L .63789 .41515 L F
.844 .394 0 r
.66474 .42809 m .66454 .42896 L .66381 .42703 L F
.66474 .42809 m .66587 .43002 L .66454 .42896 L F
.826 .876 .881 r
.54257 .64824 m .53866 .64946 L .54118 .64707 L F
0 .223 .642 r
.54341 .64864 m .54473 .64951 L .54257 .64824 L F
.712 .59 .717 r
.6491 .43325 m .64539 .43391 L .64749 .43017 L F
.589 .438 .644 r
.64539 .43391 m .64799 .4338 L .64798 .43371 L F
.278 0 0 r
.6491 .43325 m .64889 .43363 L .64798 .43371 L F
.64778 .43348 m .64798 .43371 L .64539 .43391 L F
.6491 .43325 m .64798 .43371 L .64778 .43348 L F
0 0 .356 r
.64749 .43017 m .64798 .43371 L .64834 .43066 L F
.64798 .43371 m .64799 .4338 L .648 .43373 L F
.64798 .43371 m .648 .43373 L .64834 .43066 L F
.589 .438 .644 r
.64539 .43391 m .64798 .43371 L .64749 .43017 L F
.245 0 0 r
.64539 .43391 m .64859 .43418 L .64799 .4338 L F
.995 .822 .558 r
.649 .43473 m .64876 .43406 L .64799 .4338 L F
.955 .645 .404 r
.64884 .43429 m .649 .43473 L .64859 .43418 L F
.65047 .43497 m .649 .43473 L .64884 .43429 L F
.65047 .43497 m .64884 .43429 L .6491 .43325 L F
.64884 .43429 m .64859 .43418 L .64868 .43401 L F
.64884 .43429 m .64868 .43401 L .6491 .43325 L F
.995 .822 .558 r
.64884 .43429 m .6489 .43411 L .64876 .43406 L F
.649 .43473 m .64896 .43448 L .64884 .43429 L F
.64896 .43448 m .6489 .43411 L .64884 .43429 L F
.278 0 0 r
.64889 .43363 m .64868 .43401 L .64795 .43371 L F
.995 .822 .558 r
.6489 .43411 m .64834 .43066 L .648 .43373 L F
.6489 .43411 m .648 .43373 L .64799 .4338 L F
.278 0 0 r
.64795 .43371 m .64859 .43418 L .64539 .43391 L F
.64868 .43401 m .64859 .43418 L .64795 .43371 L F
.916 .951 .803 r
.46815 .62667 m .4684 .62409 L .47057 .62399 L F
.46815 .62667 m .46717 .62632 L .4684 .62409 L F
.603 .328 .472 r
.34755 .5914 m .34983 .59346 L .35001 .59103 L F
.34755 .5914 m .34686 .5938 L .34983 .59346 L F
.367 .29 .637 r
.56918 .62929 m .57049 .6261 L .56847 .6268 L F
.14 0 0 r
.62067 .45814 m .61932 .45907 L .61687 .45915 L F
0 0 0 r
.62169 .45793 m .62067 .45814 L .62375 .45759 L F
.62169 .45793 m .61932 .45907 L .62067 .45814 L F
.073 .598 .873 r
.1959 .5412 m .19783 .54144 L .19963 .54211 L F
.061 .606 .842 r
.19783 .54144 m .2018 .54211 L .19963 .54211 L F
.442 .55 .871 r
.48054 .6881 m .48217 .69099 L .48368 .68934 L F
.347 0 0 r
.48217 .69099 m .48466 .69101 L .48381 .6914 L F
.297 .327 .724 r
.48368 .68934 m .48217 .69099 L .48381 .6914 L F
.307 .604 .951 r
.58146 .64052 m .58224 .63952 L .57985 .6391 L F
.183 .425 .859 r
.58146 .64052 m .5833 .64128 L .58224 .63952 L F
.505 0 0 r
.21478 .58262 m .21428 .58224 L .21219 .58327 L F
.468 .331 .611 r
.21478 .58262 m .21479 .58564 L .21685 .58457 L F
.505 0 0 r
.21478 .58262 m .21685 .58457 L .21428 .58224 L F
.423 .253 .544 r
.23862 .58499 m .2367 .5879 L .23673 .58553 L F
.755 .892 .94 r
.43858 .57484 m .436 .57394 L .43758 .57424 L F
.619 .897 .987 r
.43858 .57484 m .43969 .57328 L .44088 .57411 L F
.43858 .57484 m .43758 .57424 L .43969 .57328 L F
.679 .749 .904 r
.44226 .58202 m .44341 .58395 L .44413 .58264 L F
0 0 0 r
.54545 .61359 m .54745 .6125 L .54973 .61184 L F
.604 .296 .42 r
.5741 .49775 m .57037 .50005 L .57065 .49772 L F
.5741 .49775 m .57522 .49862 L .57037 .50005 L F
.608 .46 .655 r
.57685 .49501 m .57674 .4975 L .5741 .49775 L F
.574 .319 .492 r
.5741 .49775 m .57646 .49954 L .57522 .49862 L F
.5741 .49775 m .57674 .4975 L .57646 .49954 L F
.034 0 .314 r
.23056 .60515 m .22868 .60852 L .22858 .60637 L F
.487 .309 .565 r
.23683 .59351 m .23497 .59155 L .23704 .59106 L F
.23683 .59351 m .2348 .59407 L .23497 .59155 L F
.688 .838 .955 r
.45058 .57476 m .4472 .57476 L .44942 .57371 L F
.533 .702 .947 r
.45153 .5726 m .45058 .57476 L .44942 .57371 L F
.45153 .5726 m .45306 .57433 L .45058 .57476 L F
.713 .653 .788 r
.44446 .5766 m .44232 .57726 L .44088 .57411 L F
0 0 .238 r
.20636 .64917 m .20503 .65271 L .20552 .65007 L F
.437 .006 .119 r
.4283 .63353 m .42624 .63272 L .42964 .63158 L F
.423 0 .121 r
.42964 .63158 m .43064 .63345 L .4283 .63353 L F
.42964 .63158 m .43213 .63153 L .43064 .63345 L F
.764 .676 .766 r
.46274 .59099 m .46678 .59191 L .46494 .59112 L F
.46274 .59099 m .46407 .59439 L .46678 .59191 L F
.586 .617 .85 r
.46872 .59091 m .46678 .59191 L .46534 .58995 L F
.802 .841 .881 r
.46795 .59131 m .46494 .59112 L .46678 .59191 L F
.46583 .59107 m .46494 .59112 L .46795 .59131 L F
.878 .676 .626 r
.46494 .59112 m .46771 .59158 L .46675 .59117 L F
.462 .064 .198 r
.46274 .59099 m .46556 .59115 L .46534 .58995 L F
.878 .676 .626 r
.46557 .59114 m .46675 .59117 L .46616 .59092 L F
.805 .863 .891 r
.46572 .59101 m .46769 .59062 L .46534 .58995 L F
.878 .676 .626 r
.46572 .59101 m .46616 .59092 L .46593 .59082 L F
.46557 .59114 m .46616 .59092 L .46572 .59101 L F
.805 .863 .891 r
.46578 .59116 m .46872 .59091 L .46769 .59062 L F
.46578 .59116 m .46769 .59062 L .46572 .59101 L F
.802 .841 .881 r
.46813 .59121 m .46675 .59117 L .46795 .59131 L F
.46872 .59091 m .46675 .59117 L .46813 .59121 L F
.46613 .59115 m .46771 .59158 L .46549 .59121 L F
.879 .534 .392 r
.46583 .59107 m .46771 .59158 L .46562 .59105 L F
.46675 .59117 m .46771 .59158 L .46583 .59107 L F
.802 .841 .881 r
.46872 .59091 m .46771 .59158 L .46613 .59115 L F
.462 .064 .198 r
.46556 .59115 m .46563 .59115 L .46572 .59101 L F
.46563 .59115 m .46575 .5911 L .46572 .59101 L F
.42 .644 .95 r
.46431 .59013 m .46537 .59099 L .46274 .59099 L F
.878 .676 .626 r
.46494 .59112 m .46555 .59114 L .46431 .59013 L F
.46555 .59114 m .46557 .59114 L .46431 .59013 L F
.462 .064 .198 r
.46556 .59115 m .46572 .59101 L .46534 .58995 L F
.878 .676 .626 r
.46557 .59114 m .46593 .59082 L .46431 .59013 L F
.42 .644 .95 r
.46431 .59013 m .46554 .59099 L .46537 .59099 L F
.802 .841 .881 r
.46581 .59107 m .46563 .59115 L .46559 .59108 L F
.46872 .59091 m .46583 .59107 L .46675 .59117 L F
.46872 .59091 m .46549 .59121 L .46581 .59107 L F
.462 .064 .198 r
.46563 .59115 m .46578 .59116 L .46575 .5911 L F
.42 .644 .95 r
.46554 .59099 m .46578 .59116 L .46563 .59115 L F
.46554 .59099 m .46563 .59115 L .46274 .59099 L F
.802 .841 .881 r
.46559 .59108 m .46549 .59121 L .46494 .59112 L F
.46563 .59115 m .46549 .59121 L .46559 .59108 L F
.879 .534 .392 r
.46562 .59105 m .46771 .59158 L .46578 .59116 L F
.46431 .59013 m .46675 .59117 L .46562 .59105 L F
.868 .802 .783 r
.64898 .42403 m .64976 .42733 L .64818 .42599 L F
.246 .232 .645 r
.64749 .43017 m .64818 .42599 L .64976 .42733 L F
.434 .686 .97 r
.23488 .54646 m .23447 .54816 L .233 .54654 L F
.23488 .54646 m .23651 .54804 L .23447 .54816 L F
.429 .867 .908 r
.47282 .62323 m .47057 .62399 L .4684 .62409 L F
0 0 .283 r
.66848 .42309 m .6679 .42115 L .66924 .42301 L F
0 .205 .73 r
.66924 .42301 m .67041 .4249 L .66848 .42309 L F
.274 .067 .406 r
.22039 .62604 m .21986 .62842 L .21752 .62892 L F
.248 .081 .449 r
.21947 .63085 m .21752 .62892 L .21986 .62842 L F
.21947 .63085 m .21801 .63176 L .21752 .62892 L F
.525 .393 .643 r
.34097 .60302 m .34324 .60249 L .34294 .59998 L F
.523 .415 .672 r
.34141 .60644 m .34324 .60249 L .34097 .60302 L F
.033 0 0 r
.39902 .57945 m .40126 .57898 L .40215 .57841 L F
.185 0 0 r
.40215 .57841 m .40126 .57898 L .40483 .57827 L F
0 0 .037 r
.63522 .47379 m .63544 .4722 L .63669 .47003 L F
.771 .648 .727 r
.49401 .73192 m .49474 .73484 L .49111 .73465 L F
.039 .606 .772 r
.49111 .73465 m .49474 .73484 L .49371 .7347 L F
.01 .131 .643 r
.49573 .73364 m .49474 .73484 L .49401 .73192 L F
.574 .937 .918 r
.49371 .7347 m .49474 .73484 L .49573 .73364 L F
.584 .778 .972 r
.62592 .41786 m .62728 .4191 L .62833 .41722 L F
.506 .911 .884 r
.62745 .44229 m .62928 .44227 L .63094 .44139 L F
.095 0 .321 r
.50863 .68793 m .50746 .69095 L .50681 .69098 L F
.449 .029 .149 r
.36406 .58703 m .36636 .58695 L .36453 .58598 L F
.987 .717 .399 r
.63534 .41568 m .63434 .41712 L .63428 .41478 L F
.63534 .41568 m .6355 .41857 L .63434 .41712 L F
.534 .821 .998 r
.63428 .41478 m .63789 .41515 L .63534 .41568 L F
.494 .886 .72 r
.47017 .63071 m .47198 .62987 L .47391 .62858 L F
.63 .554 .75 r
.69418 .42151 m .69465 .42348 L .692 .42427 L F
.597 .508 .724 r
.69418 .42151 m .692 .42427 L .69163 .42205 L F
.912 .556 .349 r
.54431 .67242 m .54818 .67675 L .54734 .67222 L F
.54431 .67242 m .54683 .67776 L .54818 .67675 L F
.812 .889 .899 r
.54683 .67776 m .54699 .67687 L .54818 .67675 L F
0 0 .183 r
.54818 .67675 m .54823 .67873 L .54657 .67949 L F
0 0 .269 r
.54818 .67675 m .54848 .67165 L .54734 .67222 L F
.54818 .67675 m .54877 .67423 L .54848 .67165 L F
.626 .612 .816 r
.54699 .67687 m .54877 .67423 L .54818 .67675 L F
.213 0 .209 r
.55019 .67756 m .54823 .67873 L .54818 .67675 L F
.216 0 0 r
.4034 .63767 m .40213 .63894 L .39994 .63867 L F
.514 .057 .104 r
.40581 .63722 m .40213 .63894 L .4034 .63767 L F
.407 0 0 r
.57899 .62245 m .58141 .62257 L .57976 .62173 L F
.905 .891 .806 r
.58828 .63733 m .58725 .64113 L .58912 .63794 L F
.943 .958 .736 r
.58992 .63434 m .58912 .63794 L .59082 .63547 L F
.58992 .63434 m .58828 .63733 L .58912 .63794 L F
.978 .755 .534 r
.55436 .68196 m .55573 .68277 L .55521 .68373 L F
.902 .884 .805 r
.55436 .68196 m .55573 .68277 L .55819 .67896 L F
0 0 .573 r
.55436 .68196 m .55521 .68373 L .55573 .68277 L F
.619 .76 .946 r
.42655 .58112 m .42792 .58256 L .43014 .58194 L F
.493 .496 .788 r
.24499 .56118 m .24424 .56513 L .2438 .56175 L F
.246 .232 .645 r
.64749 .43017 m .64942 .42962 L .64818 .42599 L F
0 0 .356 r
.64749 .43017 m .64834 .43066 L .64942 .42962 L F
.01 0 0 r
.1936 .62615 m .1952 .62557 L .19625 .62413 L F
.244 .743 .674 r
.19317 .62629 m .1952 .62557 L .1936 .62615 L F
.665 .747 .254 r
.52199 .66226 m .5213 .6641 L .52206 .66208 L F
.52199 .66226 m .5213 .6641 L .52206 .66208 L F
.415 0 0 r
.51529 .66667 m .51337 .66608 L .51156 .66702 L F
.587 .122 .118 r
.44432 .63021 m .44636 .63158 L .44437 .63096 L F
.216 0 .06 r
.47751 .6173 m .47535 .61807 L .47378 .61969 L F
.249 .371 .792 r
.54823 .67873 m .5491 .68138 L .54657 .67949 L F
.384 .381 .733 r
.54657 .67949 m .5491 .68138 L .5474 .68172 L F
.373 0 .071 r
.35578 .58992 m .35835 .58915 L .35618 .58933 L F
.786 .738 .808 r
.60012 .44844 m .59667 .44809 L .59837 .44685 L F
.796 .742 .803 r
.60258 .44557 m .60012 .44844 L .59837 .44685 L F
.785 .405 .337 r
.58096 .60215 m .58204 .60046 L .58016 .60006 L F
.58096 .60215 m .58402 .60268 L .58204 .60046 L F
.549 .145 .228 r
.43817 .62948 m .43682 .63142 L .43441 .63137 L F
.735 .364 .348 r
.43817 .62948 m .44053 .6319 L .43682 .63142 L F
.983 .717 .44 r
.55711 .67604 m .55702 .67836 L .55819 .67896 L F
.902 .884 .805 r
.55436 .68196 m .55819 .67896 L .55702 .67836 L F
.108 0 .108 r
.23337 .59768 m .23238 .59954 L .23079 .60021 L F
.454 .334 .627 r
.23238 .59954 m .23061 .60263 L .23079 .60021 L F
.469 .292 .558 r
.22055 .56799 m .22253 .57001 L .2224 .56737 L F
.22055 .56799 m .2204 .5707 L .22253 .57001 L F
.493 .496 .788 r
.24499 .56118 m .24621 .56456 L .24424 .56513 L F
.46 .378 .677 r
.24621 .56456 m .2468 .56739 L .24424 .56513 L F
.71 .984 .814 r
.51818 .64973 m .516 .6518 L .51895 .65069 L F
.829 .818 .839 r
.60367 .44137 m .60428 .44431 L .60258 .44557 L F
.807 .806 .85 r
.60678 .44152 m .60428 .44431 L .60367 .44137 L F
.482 .363 .641 r
.21241 .55853 m .21436 .55571 L .2119 .55661 L F
.21241 .55853 m .21437 .55837 L .21436 .55571 L F
.59 .27 .396 r
.51686 .68791 m .52049 .68511 L .51769 .6873 L F
.51686 .68791 m .52006 .68748 L .52049 .68511 L F
.638 .669 .864 r
.52006 .68748 m .51924 .68407 L .52049 .68511 L F
.713 .653 .788 r
.44446 .5766 m .44088 .57411 L .4432 .57337 L F
.706 .702 .844 r
.4472 .57476 m .44446 .5766 L .4432 .57337 L F
.425 0 0 r
.54245 .67324 m .54077 .67487 L .53812 .67482 L F
.753 .931 .582 r
.54291 .67177 m .54077 .67487 L .54245 .67324 L F
.987 .729 .352 r
.5561 .66597 m .55728 .66866 L .55706 .6673 L F
.395 .236 .545 r
.2427 .57626 m .24081 .57936 L .2407 .5769 L F
.818 .706 .741 r
.68151 .45986 m .68262 .4616 L .68012 .46067 L F
.853 .61 .57 r
.68262 .4616 m .68169 .46472 L .68012 .46067 L F
.76 .692 .786 r
.68335 .46043 m .68262 .4616 L .68151 .45986 L F
.609 .386 .553 r
.68335 .46043 m .68169 .46472 L .68262 .4616 L F
.605 .547 .763 r
.69314 .41783 m .69163 .42205 L .69086 .41903 L F
.69314 .41783 m .69418 .42151 L .69163 .42205 L F
.271 .345 .756 r
.57529 .60345 m .57685 .60178 L .5744 .59973 L F
.35 .468 .839 r
.57529 .60345 m .57814 .60451 L .57685 .60178 L F
0 0 .343 r
.47281 .62069 m .47397 .62215 L .47378 .61969 L F
.47281 .62069 m .47282 .62323 L .47397 .62215 L F
.935 .734 .257 r
.55301 .67887 m .55241 .6782 L .55248 .67545 L F
.877 .454 .038 r
.55301 .67887 m .55311 .68076 L .55241 .6782 L F
.55301 .67887 m .55436 .68196 L .55311 .68076 L F
.767 .459 .464 r
.56439 .50014 m .56823 .50084 L .56828 .50288 L F
.617 .424 .598 r
.57037 .50005 m .56828 .50288 L .56823 .50084 L F
.848 .562 .504 r
.49461 .72007 m .49455 .72295 L .49709 .72275 L F
.501 .468 .753 r
.34222 .60831 m .3435 .60591 L .34141 .60644 L F
.34222 .60831 m .34432 .60818 L .3435 .60591 L F
.447 .376 .683 r
.34222 .60831 m .3449 .61062 L .34432 .60818 L F
.34222 .60831 m .34258 .6123 L .3449 .61062 L F
.792 .586 .623 r
.49114 .73175 m .49111 .73465 L .48736 .73417 L F
.49114 .73175 m .48736 .73417 L .48941 .73392 L F
0 .189 .709 r
.49114 .73175 m .49191 .73074 L .4898 .72863 L F
.566 .819 .448 r
.49114 .73175 m .48941 .73392 L .49191 .73074 L F
.771 .648 .727 r
.49401 .73192 m .49111 .73465 L .49114 .73175 L F
.361 0 0 r
.39701 .59447 m .39476 .5961 L .39279 .59589 L F
0 0 0 r
.39772 .59483 m .39701 .59447 L .39903 .59338 L F
.39772 .59483 m .39476 .5961 L .39701 .59447 L F
.626 .591 .795 r
.37457 .60785 m .37233 .60981 L .37201 .60795 L F
.418 .336 .657 r
.37457 .60785 m .37329 .6118 L .37233 .60981 L F
.881 .628 .552 r
.62462 .45221 m .62748 .45081 L .62393 .45037 L F
.678 .455 .577 r
.59374 .48624 m .59317 .48865 L .5896 .48884 L F
.579 .359 .546 r
.59557 .48805 m .59374 .48624 L .59563 .48598 L F
.59557 .48805 m .59317 .48865 L .59374 .48624 L F
.923 .975 .72 r
.61479 .45193 m .61549 .45088 L .61437 .451 L F
.538 .925 .832 r
.61437 .451 m .61549 .45088 L .61701 .44959 L F
.543 .928 .878 r
.61549 .45088 m .61824 .44968 L .61701 .44959 L F
.369 .039 .27 r
.61437 .451 m .61701 .44959 L .61605 .45253 L F
.61437 .451 m .61605 .45253 L .61396 .45009 L F
.61437 .451 m .61396 .45009 L .61303 .449 L F
.923 .975 .72 r
.61364 .45366 m .61479 .45193 L .61437 .451 L F
.805 .698 .747 r
.57759 .47394 m .57881 .47737 L .57549 .47706 L F
.893 .6 .094 r
.62981 .43778 m .63094 .44139 L .63083 .44018 L F
.448 .314 .606 r
.34294 .59998 m .34488 .59674 L .34272 .59742 L F
.491 .802 1 r
.54884 .65179 m .55041 .65275 L .54621 .65238 L F
.808 .4 0 r
.54884 .65179 m .55084 .6552 L .55041 .65275 L F
.686 .98 .865 r
.61701 .44959 m .61824 .44968 L .62065 .44765 L F
.578 .618 .856 r
.61824 .44968 m .62251 .45021 L .62065 .44765 L F
.51 .176 .337 r
.2349 .59916 m .23337 .59768 L .2348 .59659 L F
.2349 .59916 m .23238 .59954 L .23337 .59768 L F
.74 .432 .46 r
.52153 .64973 m .51875 .64773 L .51818 .64973 L F
.065 0 .409 r
.70371 .43996 m .70221 .44433 L .70163 .44101 L F
.70371 .43996 m .70369 .44586 L .70221 .44433 L F
.604 .806 .978 r
.70369 .44586 m .70195 .4467 L .70221 .44433 L F
.317 .141 .477 r
.22641 .61157 m .22625 .61411 L .22455 .61481 L F
.32 .161 .503 r
.22607 .61651 m .22455 .61481 L .22625 .61411 L F
.22607 .61651 m .22441 .61729 L .22455 .61481 L F
.569 .634 .876 r
.46919 .72026 m .47082 .72339 L .47321 .72266 L F
0 .494 .844 r
.44273 .62536 m .44498 .6261 L .44612 .62687 L F
0 .233 .672 r
.44738 .62743 m .44612 .62687 L .44498 .6261 L F
.44738 .62743 m .44875 .62846 L .44612 .62687 L F
.164 .67 .905 r
.57726 .63893 m .57765 .63844 L .57589 .63816 L F
.57726 .63893 m .57985 .6391 L .57765 .63844 L F
.663 .807 .952 r
.52535 .69884 m .52897 .69923 L .52721 .70031 L F
.52721 .70031 m .52535 .69884 L .52532 .70138 L F
.52721 .70031 m .52897 .69923 L .52535 .69884 L F
.973 .725 .501 r
.3736 .64107 m .37184 .64015 L .37223 .63772 L F
.658 .887 .535 r
.37426 .63985 m .3736 .64107 L .37542 .64153 L F
0 .069 .621 r
.5824 .61186 m .58445 .61487 L .58395 .61371 L F
.976 .9 .552 r
.58395 .61371 m .58445 .61487 L .58354 .61699 L F
.531 .368 .605 r
.48054 .6881 m .48313 .68744 L .4798 .68574 L F
0 0 0 r
.38708 .58198 m .38936 .58148 L .39089 .58073 L F
.38936 .58148 m .3924 .58068 L .39089 .58073 L F
.75 .272 0 r
.55458 .66286 m .55467 .66198 L .5534 .66107 L F
.55458 .66286 m .55616 .66414 L .55467 .66198 L F
.632 .424 .582 r
.64541 .44725 m .64736 .44505 L .64567 .44636 L F
0 .54 .745 r
.21153 .54313 m .21352 .54334 L .21525 .5436 L F
.061 .619 .807 r
.21525 .5436 m .21352 .54334 L .21731 .54366 L F
.736 .956 .661 r
.5474 .68172 m .54621 .68262 L .54456 .68495 L F
.035 0 0 r
.5491 .68138 m .54621 .68262 L .5474 .68172 L F
.673 .639 .808 r
.45511 .58541 m .45696 .58912 L .45897 .58783 L F
0 .574 .737 r
.37995 .64178 m .37808 .64162 L .37542 .64153 L F
.376 0 0 r
.38209 .6411 m .37808 .64162 L .37995 .64178 L F
.731 .593 .702 r
.63883 .47176 m .6417 .47204 L .63888 .47185 L F
.534 .193 .336 r
.19355 .61238 m .19524 .61379 L .1961 .61241 L F
.833 .791 .812 r
.20915 .58094 m .21347 .57875 L .21118 .58014 L F
.576 .581 .821 r
.45517 .57328 m .45405 .57703 L .45306 .57433 L F
.45517 .57328 m .45635 .57651 L .45405 .57703 L F
.56 .512 .759 r
.45713 .57953 m .45405 .57703 L .45635 .57651 L F
.545 .558 .819 r
.20075 .61742 m .20158 .61369 L .19929 .61393 L F
.20075 .61742 m .20292 .61685 L .20158 .61369 L F
.465 .28 .544 r
.2004 .62078 m .20292 .61685 L .20075 .61742 L F
.225 .72 .916 r
.2018 .54211 m .20385 .54187 L .20557 .54246 L F
0 .511 .736 r
.20385 .54187 m .20762 .54249 L .20557 .54246 L F
.099 0 0 r
.3924 .58068 m .39497 .58057 L .39687 .58014 L F
.28 0 0 r
.39497 .58057 m .39902 .57945 L .39687 .58014 L F
.473 .42 .717 r
.34329 .61463 m .3449 .61062 L .34258 .6123 L F
.492 .265 .497 r
.49185 .72338 m .49455 .72295 L .49461 .72007 L F
.368 .172 .478 r
.24463 .57023 m .24248 .57296 L .2426 .57087 L F
.674 .21 .144 r
.57279 .63006 m .5712 .63115 L .56918 .62929 L F
.856 .969 .869 r
.57431 .62847 m .57308 .62795 L .57279 .63006 L F
.909 .978 .702 r
.57308 .62795 m .5712 .63115 L .57279 .63006 L F
.833 .791 .812 r
.20915 .58094 m .21305 .58242 L .21347 .57875 L F
.685 .646 .805 r
.20915 .58094 m .21219 .58327 L .21305 .58242 L F
0 0 0 r
.21305 .58242 m .21508 .57852 L .21347 .57875 L F
.21305 .58242 m .21414 .58139 L .21508 .57852 L F
.21305 .58242 m .21428 .58224 L .21414 .58139 L F
.21305 .58242 m .21219 .58327 L .21428 .58224 L F
.236 .671 .958 r
.2191 .56202 m .2189 .56102 L .21735 .56107 L F
.2191 .56202 m .2207 .56194 L .2189 .56102 L F
.356 .44 .81 r
.2191 .56202 m .22196 .56434 L .2207 .56194 L F
.858 .899 .862 r
.58295 .46545 m .58031 .46867 L .57899 .46769 L F
.958 .851 .694 r
.58031 .46867 m .57952 .47088 L .57899 .46769 L F
.63 .475 .654 r
.69688 .43321 m .697 .4361 L .69448 .43606 L F
.478 .419 .713 r
.69694 .43819 m .69448 .43606 L .697 .4361 L F
.69694 .43819 m .6956 .442 L .69448 .43606 L F
0 0 0 r
.53085 .67396 m .52984 .67574 L .53212 .67272 L F
.074 0 0 r
.19085 .55343 m .18658 .553 L .18708 .55309 L F
.6 .056 0 r
.19085 .55343 m .19104 .55402 L .18854 .5532 L F
.081 .559 .902 r
.19104 .55402 m .18889 .55324 L .18854 .5532 L F
.18889 .55324 m .18674 .55246 L .18854 .5532 L F
.074 0 0 r
.18838 .55318 m .18854 .5532 L .18658 .553 L F
.19085 .55343 m .18854 .5532 L .18838 .55318 L F
.6 .056 0 r
.19085 .55343 m .19231 .55484 L .19104 .55402 L F
.084 .594 .888 r
.19265 .55398 m .18957 .55307 L .19104 .55402 L F
.18957 .55307 m .18953 .55306 L .19104 .55402 L F
.6 .056 0 r
.19231 .55484 m .19243 .55496 L .19104 .55402 L F
.208 0 0 r
.50389 .69669 m .50083 .69844 L .50149 .6969 L F
.28 0 0 r
.17401 .54264 m .17597 .54269 L .17808 .54147 L F
0 0 0 r
.17808 .54147 m .17825 .54187 L .17974 .54221 L F
.17808 .54147 m .17597 .54269 L .17825 .54187 L F
.418 .336 .657 r
.37457 .60785 m .37501 .61166 L .37329 .6118 L F
.556 .522 .772 r
.37501 .61166 m .3733 .61356 L .37329 .6118 L F
0 0 0 r
.64206 .46361 m .63994 .46405 L .63891 .46443 L F
.58 .283 .428 r
.61586 .48008 m .61822 .48179 L .61579 .48194 L F
.61586 .48008 m .61837 .47992 L .61822 .48179 L F
.501 .304 .544 r
.26003 .78154 m .26218 .78103 L .26046 .77831 L F
.963 .745 .562 r
.26003 .78154 m .26046 .77831 L .26218 .78103 L F
.796 .742 .803 r
.60258 .44557 m .59837 .44685 L .60111 .44417 L F
.829 .818 .839 r
.60367 .44137 m .60258 .44557 L .60111 .44417 L F
.228 0 0 r
.4079 .58899 m .40373 .59027 L .40358 .59081 L F
.4079 .58899 m .40614 .59006 L .40373 .59027 L F
.059 0 0 r
.41025 .5887 m .40614 .59006 L .4079 .58899 L F
.76 .692 .786 r
.68335 .46043 m .68151 .45986 L .68454 .45914 L F
.609 .386 .553 r
.68335 .46043 m .68405 .46446 L .68169 .46472 L F
.435 .301 .6 r
.68454 .45914 m .68659 .46084 L .68335 .46043 L F
.69 .601 .751 r
.68659 .46084 m .68405 .46446 L .68335 .46043 L F
.157 .007 .413 r
.2086 .6461 m .20743 .6472 L .20887 .64385 L F
.167 0 .182 r
.20796 .64814 m .20743 .6472 L .2086 .6461 L F
.20796 .64814 m .20636 .64917 L .20743 .6472 L F
.616 .589 .8 r
.69788 .42464 m .69545 .42553 L .69465 .42348 L F
1 .808 .486 r
.55728 .66866 m .55685 .67256 L .55778 .67338 L F
.996 .862 .539 r
.55685 .67256 m .55711 .67604 L .55778 .67338 L F
0 0 0 r
.64549 .46239 m .64206 .46361 L .6448 .4632 L F
.338 0 0 r
.6448 .4632 m .64815 .46247 L .64549 .46239 L F
.514 .117 .225 r
.53005 .68793 m .52641 .69007 L .52665 .68743 L F
.53005 .68793 m .52888 .69007 L .52641 .69007 L F
.382 0 .157 r
.53157 .68955 m .53005 .68793 L .53232 .68721 L F
.53157 .68955 m .52888 .69007 L .53005 .68793 L F
.614 .556 .766 r
.69694 .43819 m .69576 .44197 L .6956 .442 L F
.499 .096 .207 r
.41185 .63523 m .4105 .63738 L .40806 .63737 L F
.403 0 .114 r
.41433 .63514 m .4105 .63738 L .41185 .63523 L F
.294 0 0 r
.40914 .62854 m .41154 .62832 L .41316 .62695 L F
.122 0 0 r
.41154 .62832 m .41536 .62624 L .41316 .62695 L F
.953 .726 .268 r
.66501 .45208 m .66541 .45064 L .66483 .4495 L F
.66501 .45208 m .66558 .45409 L .66541 .45064 L F
0 .484 .765 r
.64667 .457 m .64299 .45602 L .64442 .45748 L F
0 .28 .764 r
.55287 .63493 m .55489 .63621 L .5527 .63405 L F
.433 0 0 r
.55332 .63466 m .55439 .63646 L .5527 .63405 L F
.55489 .63621 m .55439 .63646 L .55332 .63466 L F
.837 .397 .183 r
.55689 .63823 m .55565 .63862 L .55439 .63646 L F
0 0 .507 r
.55439 .63646 m .55565 .63862 L .55561 .63852 L F
0 .329 .801 r
.55767 .63854 m .55489 .63621 L .55617 .63724 L F
.55495 .63626 m .55786 .63767 L .55489 .63621 L F
.55767 .63854 m .5578 .63797 L .55495 .63626 L F
.5578 .63797 m .55786 .63767 L .55495 .63626 L F
.563 .321 .507 r
.55753 .63781 m .5578 .63797 L .55689 .63823 L F
.338 0 0 r
.5578 .63797 m .55689 .63823 L .55786 .63767 L F
.55767 .63854 m .55689 .63823 L .5578 .63797 L F
.563 .321 .507 r
.5578 .63797 m .55919 .63881 L .55689 .63823 L F
.55954 .63646 m .55919 .63881 L .55753 .63781 L F
.55919 .63881 m .55919 .63881 L .55753 .63781 L F
.433 0 0 r
.55489 .63621 m .55786 .63767 L .55439 .63646 L F
.837 .397 .183 r
.55689 .63823 m .55439 .63646 L .55786 .63767 L F
0 0 .507 r
.55439 .63646 m .55561 .63852 L .55423 .63516 L F
0 .103 .657 r
.55439 .63646 m .55264 .63372 L .5527 .63405 L F
.55264 .63372 m .5518 .63241 L .5527 .63405 L F
0 .28 .764 r
.55259 .63475 m .55287 .63493 L .5527 .63405 L F
.777 .611 .674 r
.62283 .43212 m .6202 .42983 L .62043 .4325 L F
.956 .95 .671 r
.62076 .43495 m .62283 .43212 L .62043 .4325 L F
.62076 .43495 m .62114 .43603 L .62283 .43212 L F
.807 .753 .802 r
.689 .45535 m .69002 .45689 L .69276 .45448 L F
.277 0 0 r
.69485 .45317 m .69273 .45413 L .69295 .45436 L F
.69485 .45317 m .69386 .45429 L .69273 .45413 L F
0 .517 .782 r
.69273 .45413 m .69386 .45429 L .69262 .45401 L F
.69273 .45413 m .69262 .45401 L .69031 .45347 L F
.277 0 0 r
.69295 .45436 m .69273 .45413 L .69276 .45448 L F
.142 0 .39 r
.22165 .6252 m .22065 .62369 L .22231 .62299 L F
.22165 .6252 m .22039 .62604 L .22065 .62369 L F
.676 .479 .612 r
.5896 .48884 m .58731 .49115 L .58727 .48871 L F
.918 .837 .749 r
.64777 .46652 m .64815 .46247 L .64704 .4647 L F
0 0 .384 r
.6485 .46669 m .64777 .46652 L .64704 .4647 L F
.473 .28 .538 r
.49629 .72834 m .49624 .7315 L .49401 .73192 L F
.429 .692 .974 r
.49827 .72757 m .49629 .72834 L .49535 .72722 L F
.333 .17 .505 r
.49821 .73056 m .49629 .72834 L .49827 .72757 L F
.49821 .73056 m .49624 .7315 L .49629 .72834 L F
.436 .508 .834 r
.68559 .41296 m .68336 .41281 L .68529 .4109 L F
0 0 0 r
.68529 .4109 m .68336 .41281 L .68386 .41234 L F
.574 .58 .821 r
.68701 .41567 m .68336 .41281 L .68559 .41296 L F
.698 .493 .606 r
.54553 .61168 m .54973 .61184 L .54936 .60887 L F
.473 .333 .609 r
.54936 .60887 m .54973 .61184 L .55173 .61083 L F
.55173 .61083 m .54973 .61184 L .54936 .60887 L F
.346 .477 .849 r
.25314 .55532 m .25495 .55912 L .2544 .55836 L F
.424 .867 .808 r
.2528 .55858 m .2544 .55836 L .25495 .55912 L F
.612 .304 .423 r
.25314 .55532 m .25592 .55514 L .25367 .55327 L F
.25314 .55532 m .25592 .55514 L .25367 .55327 L F
0 0 .106 r
.25592 .55514 m .25495 .55912 L .25314 .55532 L F
.25592 .55514 m .25513 .5594 L .25495 .55912 L F
.632 .424 .582 r
.64541 .44725 m .64782 .4473 L .64736 .44505 L F
.201 .241 .679 r
.64736 .44505 m .6492 .44465 L .64757 .44124 L F
.612 .653 .866 r
.64782 .4473 m .6492 .44465 L .64736 .44505 L F
.529 .282 .485 r
.59563 .48598 m .59808 .48761 L .59557 .48805 L F
.597 .224 .306 r
.59563 .48598 m .59813 .48617 L .59808 .48761 L F
.38 .05 .274 r
.61626 .45589 m .61859 .45523 L .61886 .45336 L F
.372 .13 .411 r
.61886 .45336 m .62139 .45256 L .62251 .45021 L F
.356 .054 .308 r
.61859 .45523 m .62139 .45256 L .61886 .45336 L F
.492 .653 .931 r
.64908 .45279 m .65161 .45393 L .6516 .45047 L F
.678 .149 0 r
.64908 .45279 m .65168 .45508 L .65161 .45393 L F
.346 .357 .729 r
.6516 .45054 m .65161 .45393 L .65373 .45196 L F
.596 .262 .374 r
.65373 .45196 m .65118 .45271 L .65282 .45135 L F
.65373 .45196 m .65282 .45135 L .65404 .45034 L F
.346 .357 .729 r
.6516 .45047 m .6516 .45054 L .65373 .45196 L F
0 0 .006 r
.65161 .45393 m .65168 .45508 L .65373 .45196 L F
.523 .415 .672 r
.34141 .60644 m .3435 .60591 L .34324 .60249 L F
.854 .839 .829 r
.57336 .48008 m .57277 .4823 L .57223 .48251 L F
.759 .699 .795 r
.56545 .64325 m .5671 .6452 L .56872 .64373 L F
.621 .498 .691 r
.69945 .43272 m .69688 .43321 L .69913 .43016 L F
.72 .546 .653 r
.70049 .43602 m .69688 .43321 L .69945 .43272 L F
.70049 .43602 m .697 .4361 L .69688 .43321 L F
0 0 0 r
.54711 .70167 m .54732 .70187 L .54482 .70476 L F
.54476 .70233 m .54732 .70187 L .54711 .70167 L F
.54711 .70167 m .54732 .70187 L .54476 .70233 L F
.613 .684 .893 r
.68857 .41307 m .68701 .41567 L .68559 .41296 L F
.68857 .41307 m .68951 .415 L .68701 .41567 L F
.102 0 0 r
.18054 .55309 m .1784 .55449 L .17653 .55477 L F
.18 0 0 r
.18269 .55291 m .1784 .55449 L .18054 .55309 L F
.433 .313 .616 r
.57895 .49661 m .57674 .4975 L .57685 .49501 L F
.611 .251 .336 r
.57685 .49501 m .57906 .49493 L .57895 .49661 L F
.433 .313 .616 r
.57895 .49661 m .57674 .4975 L .57685 .49501 L F
.867 .865 .835 r
.19919 .60461 m .19801 .6059 L .20035 .60295 L F
.404 .384 .723 r
.37611 .61592 m .37432 .61772 L .3733 .61356 L F
.377 .342 .692 r
.37611 .61592 m .37664 .61953 L .37432 .61772 L F
.473 .42 .717 r
.34329 .61463 m .34527 .61422 L .3449 .61062 L F
.591 .844 .993 r
.42317 .57489 m .41939 .57456 L .42157 .5738 L F
.613 .844 .987 r
.42389 .57306 m .42317 .57489 L .42157 .5738 L F
.42389 .57306 m .42543 .5741 L .42317 .57489 L F
.705 .732 .872 r
.67893 .45051 m .68268 .45107 L .68263 .45086 L F
.612 .102 .014 r
.67893 .45051 m .68159 .45206 L .68268 .45107 L F
.634 .928 .667 r
.68416 .44932 m .68263 .45086 L .68268 .45107 L F
.555 .341 .544 r
.68159 .45206 m .68416 .44932 L .68268 .45107 L F
.24 0 0 r
.41833 .58422 m .41525 .58529 L .41607 .5845 L F
.735 .337 .296 r
.53869 .68538 m .54059 .6875 L .53858 .68665 L F
.01 .131 .643 r
.49573 .73364 m .49401 .73192 L .49624 .7315 L F
.74 .989 .889 r
.57719 .62583 m .57308 .62795 L .57431 .62847 L F
.69 .513 .643 r
.56812 .63468 m .56648 .63765 L .56681 .63461 L F
.782 .686 .758 r
.46049 .69339 m .46186 .69666 L .46419 .69371 L F
0 0 0 r
.62023 .43811 m .62114 .43603 L .62061 .43763 L F
.925 .752 .268 r
.62061 .43763 m .62114 .43603 L .62076 .43495 L F
.188 0 .267 r
.6516 .45047 m .65118 .45271 L .64908 .45279 L F
.22 .271 .703 r
.65118 .45271 m .65168 .45508 L .64908 .45279 L F
.594 .466 .676 r
.37393 .60624 m .37201 .60795 L .37196 .60536 L F
.942 .859 .73 r
.58725 .64113 m .58606 .64055 L .58676 .64345 L F
.634 .693 .887 r
.58676 .64345 m .58606 .64055 L .5833 .64128 L F
.667 .864 .974 r
.21224 .55475 m .2119 .55661 L .21436 .55571 L F
.613 .816 .978 r
.21008 .5555 m .2119 .55661 L .21224 .55475 L F
.314 .09 .406 r
.21535 .63338 m .2153 .63698 L .21296 .63717 L F
.259 .015 .341 r
.21801 .63176 m .21732 .63402 L .21535 .63338 L F
.281 .066 .399 r
.21693 .63629 m .21535 .63338 L .21732 .63402 L F
.21693 .63629 m .2153 .63698 L .21535 .63338 L F
.554 .587 .841 r
.49185 .72338 m .49603 .72659 L .49455 .72295 L F
.148 .128 .577 r
.51504 .73114 m .51615 .72781 L .51756 .72818 L F
.099 .64 .848 r
.51615 .72781 m .51976 .72824 L .51756 .72818 L F
.376 .423 .782 r
.34693 .61744 m .34741 .61365 L .34527 .61422 L F
.34693 .61744 m .34851 .61728 L .34741 .61365 L F
.556 .522 .772 r
.37501 .61166 m .37568 .61366 L .3733 .61356 L F
.404 .384 .723 r
.37611 .61592 m .3733 .61356 L .37568 .61366 L F
.268 0 0 r
.17974 .54221 m .18189 .54232 L .18395 .54157 L F
.347 0 0 r
.18189 .54232 m .18603 .54144 L .18395 .54157 L F
.965 .936 .64 r
.63122 .45824 m .63056 .4624 L .63188 .45898 L F
.63122 .45824 m .6301 .46125 L .63056 .4624 L F
.494 .359 .626 r
.63056 .4624 m .63301 .46263 L .63188 .45898 L F
.766 .292 .115 r
.6301 .46125 m .63301 .46263 L .63056 .4624 L F
.092 .576 .904 r
.22694 .54524 m .22933 .54565 L .23095 .54663 L F
.335 .731 .983 r
.22933 .54565 m .233 .54654 L .23095 .54663 L F
.439 0 .08 r
.42608 .63346 m .42624 .63272 L .4283 .63353 L F
.387 .845 .891 r
.6302 .47675 m .632 .47583 L .62883 .47798 L F
.798 .933 .566 r
.63177 .47541 m .632 .47583 L .63279 .4737 L F
.387 .845 .891 r
.6302 .47675 m .63219 .47617 L .632 .47583 L F
0 0 0 r
.62883 .47798 m .632 .47583 L .63072 .47716 L F
.798 .933 .566 r
.63072 .47716 m .632 .47583 L .63177 .47541 L F
.387 .845 .891 r
.63219 .47617 m .63237 .47611 L .632 .47583 L F
.064 .607 .846 r
.18658 .553 m .18854 .5532 L .18475 .55252 L F
.349 .826 .844 r
.4167 .57587 m .41788 .57516 L .41939 .57456 L F
.4167 .57587 m .41559 .57586 L .41788 .57516 L F
.945 .826 .697 r
.6756 .42059 m .67692 .42198 L .67606 .42413 L F
.759 .74 .836 r
.68673 .45663 m .69002 .45689 L .689 .45535 L F
.839 .833 .841 r
.58363 .46183 m .58405 .46475 L .58128 .46446 L F
.849 .818 .819 r
.58128 .46446 m .58405 .46475 L .58295 .46545 L F
.866 .849 .824 r
.58631 .46157 m .58405 .46475 L .58363 .46183 L F
.949 .605 .211 r
.6544 .42386 m .65497 .42615 L .6561 .42725 L F
.846 .401 0 r
.65564 .42798 m .65715 .4295 L .6561 .42725 L F
0 .325 .791 r
.38577 .62522 m .38704 .62665 L .38555 .62583 L F
.748 .652 .755 r
.18199 .57456 m .18273 .57366 L .18161 .57357 L F
.687 .51 .641 r
.55468 .68642 m .55096 .68533 L .55247 .68394 L F
.55468 .68642 m .55272 .68885 L .55096 .68533 L F
.55468 .68642 m .55607 .68813 L .55272 .68885 L F
.978 .755 .534 r
.55436 .68196 m .55468 .68642 L .55247 .68394 L F
.55436 .68196 m .55521 .68373 L .55468 .68642 L F
.556 .483 .728 r
.55468 .68642 m .55521 .68373 L .55607 .68813 L F
.942 .891 .49 r
.64841 .43841 m .649 .43473 L .65047 .43497 L F
.449 0 0 r
.34899 .62476 m .34816 .62404 L .34563 .62382 L F
.34899 .62476 m .35084 .62596 L .34816 .62404 L F
.435 .125 .339 r
.34816 .62404 m .3507 .62586 L .35097 .6233 L F
.3507 .62586 m .35085 .62577 L .35097 .6233 L F
.095 .195 .678 r
.35097 .6233 m .35082 .61916 L .3501 .62043 L F
.35097 .6233 m .35195 .62216 L .35082 .61916 L F
.435 .125 .339 r
.3507 .62586 m .35084 .62596 L .35085 .62577 L F
.714 .589 .714 r
.34899 .62476 m .35097 .6233 L .35084 .62596 L F
.34899 .62476 m .35195 .62216 L .35097 .6233 L F
.34899 .62476 m .35147 .62535 L .35195 .62216 L F
.35147 .62535 m .35287 .62568 L .35259 .62461 L F
.35147 .62535 m .35259 .62461 L .35195 .62216 L F
.526 .421 .678 r
.19696 .62198 m .19625 .62413 L .19798 .62301 L F
0 0 0 r
.19625 .62413 m .1952 .62557 L .19798 .62301 L F
.537 .286 .482 r
.37909 .60669 m .37656 .60567 L .37844 .60339 L F
.393 .002 .174 r
.38244 .60238 m .37844 .60339 L .38006 .60203 L F
.38244 .60238 m .38136 .60442 L .37844 .60339 L F
.368 .117 .397 r
.38106 .60604 m .37844 .60339 L .38136 .60442 L F
.38106 .60604 m .37909 .60669 L .37844 .60339 L F
.92 .879 .455 r
.59069 .62765 m .59009 .63185 L .59078 .62942 L F
.614 .556 .766 r
.69694 .43819 m .69891 .44187 L .69576 .44197 L F
.568 .423 .645 r
.48703 .68752 m .48733 .69093 L .48466 .69101 L F
.332 0 0 r
.48466 .69101 m .48682 .69174 L .48381 .6914 L F
.48466 .69101 m .48733 .69093 L .48682 .69174 L F
.608 .252 .341 r
.44875 .62846 m .45145 .62867 L .45247 .62636 L F
.764 .425 .412 r
.45247 .62636 m .45145 .62867 L .45427 .62875 L F
.575 .361 .553 r
.50035 .72265 m .50286 .72224 L .50048 .72001 L F
.896 .751 .693 r
.59033 .61991 m .59097 .623 L .59215 .62082 L F
.355 .503 .868 r
.38297 .62179 m .38172 .62337 L .38019 .62051 L F
.234 .327 .755 r
.38297 .62179 m .38395 .62505 L .38172 .62337 L F
.821 .844 .866 r
.6693 .40655 m .66985 .40921 L .667 .40901 L F
.856 .788 .784 r
.667 .40901 m .66985 .40921 L .66737 .41277 L F
.713 .779 .904 r
.67241 .40718 m .66985 .40921 L .6693 .40655 L F
.269 .034 .36 r
.22868 .60852 m .22807 .61095 L .22641 .61157 L F
.423 .26 .553 r
.22807 .61095 m .22625 .61411 L .22641 .61157 L F
.647 .642 .832 r
.49299 .69951 m .49404 .69585 L .49266 .69608 L F
.559 .043 0 r
.58657 .60403 m .58773 .60287 L .58402 .60268 L F
.893 .494 .255 r
.58657 .60403 m .5886 .6049 L .58773 .60287 L F
.527 .207 .369 r
.57906 .49493 m .58138 .49633 L .57895 .49661 L F
.57906 .49493 m .58161 .49463 L .58138 .49633 L F
.712 .983 .898 r
.62738 .43829 m .6255 .43984 L .62366 .43993 L F
.202 0 .236 r
.631 .45351 m .63359 .45065 L .63161 .45137 L F
.822 .94 .904 r
.70163 .44101 m .70325 .43795 L .70452 .43923 L F
.70163 .44101 m .70029 .4405 L .70325 .43795 L F
.669 .587 .755 r
.70371 .43996 m .70163 .44101 L .70452 .43923 L F
0 0 0 r
.20155 .65746 m .20098 .65798 L .20029 .65853 L F
0 0 .019 r
.20029 .65853 m .20098 .65798 L .19956 .66041 L F
0 .264 .768 r
.2096 .55583 m .20974 .5542 L .2069 .55419 L F
.2096 .55583 m .21008 .5555 L .20974 .5542 L F
0 .432 .703 r
.48448 .61274 m .48843 .61375 L .48579 .61192 L F
.81 .774 .819 r
.57899 .46769 m .57952 .47088 L .57639 .47047 L F
.836 .712 .728 r
.57639 .47047 m .57952 .47088 L .57759 .47394 L F
.381 .363 .714 r
.24636 .55432 m .24483 .55632 L .24433 .55272 L F
.324 0 0 r
.36636 .58695 m .36872 .58668 L .37031 .58511 L F
.445 0 .047 r
.36872 .58668 m .37265 .5851 L .37031 .58511 L F
.527 .296 .508 r
.21412 .5875 m .21685 .58457 L .21479 .58564 L F
.367 .29 .637 r
.56918 .62929 m .57112 .62871 L .57049 .6261 L F
.36 .272 .619 r
.56918 .62929 m .5712 .63115 L .57112 .62871 L F
.558 .555 .807 r
.20035 .60295 m .20366 .6058 L .20299 .60303 L F
.565 .401 .618 r
.21085 .64031 m .21143 .64342 L .20887 .64385 L F
.586 .424 .629 r
.21296 .63717 m .21377 .64046 L .21085 .64031 L F
0 0 0 r
.21377 .64046 m .21143 .64342 L .21085 .64031 L F
.47 .738 .986 r
.42981 .57295 m .42881 .57436 L .42756 .5733 L F
.42981 .57295 m .43095 .57403 L .42881 .57436 L F
.35 .004 .23 r
.56648 .63765 m .56411 .63992 L .56463 .63887 L F
.81 .802 .845 r
.60624 .43868 m .60678 .44152 L .60367 .44137 L F
.824 .811 .838 r
.6093 .43861 m .60678 .44152 L .60624 .43868 L F
.034 0 .314 r
.23056 .60515 m .23021 .60749 L .22868 .60852 L F
.239 .007 .346 r
.23011 .60997 m .22868 .60852 L .23021 .60749 L F
.23011 .60997 m .22807 .61095 L .22868 .60852 L F
.555 .348 .554 r
.21143 .64342 m .2086 .6461 L .20887 .64385 L F
.83 .73 .754 r
.54473 .64951 m .54621 .65238 L .54295 .65201 L F
.834 .718 .737 r
.54295 .65201 m .54621 .65238 L .54319 .65628 L F
.448 .314 .606 r
.34294 .59998 m .34493 .5994 L .34488 .59674 L F
.458 .344 .636 r
.34294 .59998 m .34518 .60193 L .34493 .5994 L F
.34324 .60249 m .34518 .60193 L .34294 .59998 L F
.154 0 0 r
.52155 .67922 m .52375 .67898 L .52531 .67843 L F
.704 .339 .355 r
.52375 .67898 m .52737 .67921 L .52531 .67843 L F
.421 .169 .423 r
.19246 .62851 m .1952 .62557 L .19317 .62629 L F
.277 .092 .44 r
.22389 .62216 m .22269 .62046 L .22407 .61971 L F
.22389 .62216 m .22231 .62299 L .22269 .62046 L F
.615 .669 .879 r
.43821 .57965 m .43984 .5827 L .44226 .58202 L F
.903 .889 .807 r
.5118 .69026 m .50937 .69424 L .50832 .69296 L F
.631 .258 .318 r
.51223 .69583 m .50837 .69612 L .50937 .69424 L F
.626 .591 .795 r
.37457 .60785 m .37201 .60795 L .37393 .60624 L F
.893 .904 .827 r
.66304 .41835 m .66079 .42136 L .65978 .42016 L F
.832 .425 0 r
.65978 .42016 m .66079 .42136 L .66149 .42312 L F
.72 .759 .883 r
.54075 .68441 m .54456 .68495 L .54346 .68321 L F
.699 .256 .193 r
.54314 .68617 m .54456 .68495 L .54075 .68441 L F
.602 .623 .844 r
.54456 .68495 m .54558 .68095 L .54346 .68321 L F
.54456 .68495 m .54621 .68262 L .54558 .68095 L F
.734 .525 .608 r
.59333 .48941 m .5896 .48884 L .59317 .48865 L F
.59333 .48941 m .58973 .49146 L .5896 .48884 L F
.574 .242 .369 r
.59333 .48941 m .58973 .49305 L .58973 .49146 L F
.59333 .48941 m .59211 .49296 L .58973 .49305 L F
.47 .287 .549 r
.59557 .48805 m .59333 .48941 L .59317 .48865 L F
.59557 .48805 m .59692 .49023 L .59333 .48941 L F
.559 .227 .363 r
.59622 .49201 m .59333 .48941 L .59692 .49023 L F
.59622 .49201 m .59211 .49296 L .59333 .48941 L F
0 0 0 r
.20639 .60291 m .20748 .60201 L .20851 .59981 L F
.682 .415 .512 r
.20509 .60341 m .20748 .60201 L .20639 .60291 L F
.976 .919 .66 r
.63182 .45688 m .63188 .45898 L .63471 .45698 L F
.63182 .45688 m .63122 .45824 L .63188 .45898 L F
.769 .725 .811 r
.63704 .45839 m .64118 .45911 L .63957 .4576 L F
.63776 .4575 m .63957 .4576 L .6385 .45659 L F
.63704 .45839 m .63957 .4576 L .63776 .4575 L F
.515 .265 .474 r
.63188 .45898 m .6358 .45992 L .63471 .45698 L F
.6358 .45992 m .63588 .45982 L .63471 .45698 L F
.832 .982 .697 r
.63948 .45515 m .63742 .45789 L .6385 .45659 L F
.63742 .45789 m .63704 .45839 L .63743 .45791 L F
.63742 .45789 m .63743 .45791 L .6385 .45659 L F
.261 .309 .724 r
.63471 .45698 m .63739 .45771 L .63745 .4576 L F
.63678 .45745 m .63745 .4576 L .63559 .45738 L F
.778 .957 .639 r
.63739 .45771 m .63742 .45789 L .6377 .45751 L F
.261 .309 .724 r
.63745 .4576 m .63739 .45771 L .63781 .45768 L F
.63745 .4576 m .63781 .45768 L .63753 .45764 L F
.778 .957 .639 r
.6375 .45758 m .6377 .45751 L .63948 .45515 L F
.638 .45653 m .63754 .45742 L .63948 .45515 L F
.63754 .45742 m .63739 .45771 L .63811 .45682 L F
.63754 .45742 m .63811 .45682 L .63948 .45515 L F
0 0 .052 r
.63646 .45908 m .63743 .45807 L .63704 .45839 L F
.63743 .45807 m .63781 .45768 L .63704 .45839 L F
.769 .725 .811 r
.63704 .45839 m .63786 .4616 L .64118 .45911 L F
.102 .186 .666 r
.63788 .45665 m .64005 .45915 L .63839 .45657 L F
.601 .58 .802 r
.63948 .45515 m .64278 .45444 L .64087 .45116 L F
.63948 .45515 m .64087 .45116 L .64146 .4531 L F
.53 .844 .538 r
.64146 .4531 m .63788 .45665 L .63948 .45515 L F
.707 .968 .731 r
.63919 .45453 m .63788 .45665 L .64146 .4531 L F
.082 .18 .668 r
.63919 .45453 m .63947 .45604 L .63788 .45665 L F
.755 .655 .751 r
.6385 .45659 m .64118 .45911 L .64299 .45602 L F
.6385 .45659 m .64299 .45602 L .63948 .45515 L F
.082 .18 .668 r
.63837 .45669 m .63832 .45716 L .63807 .45687 L F
.02 .044 .544 r
.63826 .45675 m .63824 .4574 L .63704 .45839 L F
.63837 .45669 m .63824 .4574 L .63826 .45675 L F
.63753 .45798 m .63759 .46097 L .63704 .45839 L F
0 0 .052 r
.63753 .45798 m .63772 .45793 L .63781 .45768 L F
.02 .044 .544 r
.63824 .4574 m .63817 .45779 L .63753 .45798 L F
.63817 .45779 m .63759 .46097 L .63753 .45798 L F
.01 0 .117 r
.63593 .45996 m .6348 .46104 L .63704 .45839 L F
.521 .375 .623 r
.6358 .45992 m .6348 .46104 L .63593 .45996 L F
0 0 .052 r
.6348 .46104 m .63577 .45996 L .63646 .45908 L F
.63577 .45996 m .6358 .45992 L .63588 .45982 L F
.63577 .45996 m .63588 .45982 L .63646 .45908 L F
.462 .24 .49 r
.63471 .45698 m .63588 .45982 L .63704 .45839 L F
.63588 .45982 m .63593 .45996 L .63704 .45839 L F
.521 .375 .623 r
.63188 .45898 m .6348 .46104 L .6358 .45992 L F
0 0 .052 r
.6348 .46104 m .6358 .45993 L .6358 .45992 L F
.6348 .46104 m .63719 .45953 L .63772 .45793 L F
.515 .265 .474 r
.6358 .45992 m .63593 .45996 L .63588 .45982 L F
0 0 .052 r
.6348 .46104 m .63772 .45793 L .63753 .45798 L F
.951 .938 .607 r
.63837 .45669 m .63637 .46191 L .63759 .46097 L F
.02 .044 .544 r
.63839 .45657 m .63837 .45669 L .63826 .45675 L F
.951 .938 .607 r
.63839 .45657 m .63838 .45661 L .63837 .45669 L F
.63838 .45661 m .63637 .46191 L .63837 .45669 L F
.082 .18 .668 r
.63858 .45691 m .64005 .45915 L .63832 .45716 L F
.607 .948 .788 r
.64005 .45915 m .63838 .45661 L .63839 .45657 L F
.082 .18 .668 r
.63947 .45604 m .63832 .45716 L .63837 .45669 L F
.607 .948 .788 r
.64005 .45915 m .63637 .46191 L .63838 .45661 L F
.082 .18 .668 r
.63947 .45604 m .64005 .45915 L .63858 .45691 L F
.63947 .45604 m .63807 .45687 L .63788 .45665 L F
0 0 .052 r
.6358 .45993 m .63781 .45768 L .63646 .45908 L F
.516 .464 .737 r
.63719 .45953 m .6361 .45892 L .63781 .45768 L F
.261 .309 .724 r
.63745 .4576 m .63738 .45762 L .63559 .45738 L F
.175 .65 .931 r
.6373 .45761 m .63738 .45762 L .63729 .45757 L F
.63738 .45762 m .63738 .45759 L .63729 .45757 L F
.261 .309 .724 r
.63471 .45698 m .63607 .4578 L .63739 .45771 L F
.778 .957 .639 r
.63739 .45771 m .63704 .45839 L .63742 .45789 L F
.261 .309 .724 r
.63607 .4578 m .63704 .45839 L .63781 .45768 L F
.63471 .45698 m .63678 .45745 L .63182 .45688 L F
.63678 .45745 m .63559 .45738 L .63182 .45688 L F
.175 .65 .931 r
.63182 .45688 m .6373 .45761 L .63178 .45649 L F
.6373 .45761 m .63729 .45757 L .63178 .45649 L F
.423 0 0 r
.62721 .45422 m .63267 .45427 L .631 .45351 L F
.532 0 0 r
.6273 .45387 m .63189 .45421 L .62721 .45422 L F
.63189 .45421 m .63267 .45427 L .63187 .45426 L F
.63189 .45421 m .63187 .45426 L .62721 .45422 L F
.857 .574 .507 r
.63199 .45422 m .63178 .45649 L .63249 .45424 L F
.532 0 0 r
.6273 .45387 m .62868 .45412 L .6319 .45424 L F
.63189 .45421 m .6319 .45424 L .63267 .45427 L F
.6273 .45387 m .6319 .45424 L .63189 .45421 L F
0 0 .057 r
.63178 .45649 m .63206 .45604 L .63209 .45579 L F
.006 .581 .734 r
.6319 .45424 m .63249 .45424 L .63267 .45427 L F
.647 .158 0 r
.63267 .45427 m .63192 .45324 L .631 .45351 L F
.63267 .45427 m .63249 .45424 L .63192 .45324 L F
0 0 .193 r
.63192 .45324 m .63249 .45424 L .63303 .45201 L F
.891 .938 .569 r
.63249 .45424 m .6338 .45021 L .63303 .45201 L F
.63249 .45424 m .63235 .45297 L .6338 .45021 L F
.848 .88 .444 r
.63249 .45424 m .63237 .45279 L .63235 .45297 L F
.63249 .45424 m .63178 .45649 L .63237 .45279 L F
0 0 .057 r
.63202 .45527 m .63209 .45579 L .63224 .45417 L F
.63178 .45649 m .63209 .45579 L .63202 .45527 L F
.006 .581 .734 r
.62868 .45412 m .63199 .45422 L .6319 .45424 L F
.63199 .45422 m .63249 .45424 L .6319 .45424 L F
0 0 .057 r
.63218 .45418 m .63224 .45417 L .63231 .45345 L F
.63178 .45649 m .63224 .45417 L .63218 .45418 L F
.857 .574 .507 r
.62868 .45412 m .63178 .45649 L .63199 .45422 L F
0 0 .057 r
.63225 .45356 m .63231 .45345 L .63237 .45279 L F
.63178 .45649 m .63231 .45345 L .63225 .45356 L F
.857 .574 .507 r
.62868 .45412 m .62876 .4565 L .63178 .45649 L F
.853 .974 .868 r
.63012 .45956 m .63178 .45649 L .62876 .4565 L F
.755 .536 .598 r
.63178 .45649 m .63012 .45956 L .63122 .45824 L F
.521 .375 .623 r
.63188 .45898 m .63301 .46263 L .6348 .46104 L F
.803 .869 .429 r
.63178 .45649 m .63122 .45824 L .63182 .45688 L F
.907 .918 .528 r
.63012 .45956 m .6301 .46125 L .63122 .45824 L F
.755 .536 .598 r
.63178 .45649 m .63475 .46095 L .63012 .45956 L F
.516 .464 .737 r
.63719 .45953 m .63475 .46095 L .63178 .45649 L F
.853 .974 .868 r
.63012 .45956 m .63206 .45604 L .63178 .45649 L F
0 0 .057 r
.63178 .45649 m .63206 .45604 L .63237 .45279 L F
.793 .673 .731 r
.62876 .4565 m .62678 .45954 L .63012 .45956 L F
.853 .974 .868 r
.63072 .45847 m .62927 .45875 L .63206 .45604 L F
.63012 .45956 m .6296 .45906 L .63072 .45847 L F
.6296 .45906 m .62927 .45875 L .63072 .45847 L F
.516 .464 .737 r
.6361 .45892 m .63307 .45722 L .63738 .45759 L F
.63307 .45722 m .63178 .45649 L .63373 .45688 L F
.63307 .45722 m .63373 .45688 L .63738 .45759 L F
.02 .044 .544 r
.63759 .45766 m .63704 .45839 L .63742 .45761 L F
.261 .309 .724 r
.63742 .45761 m .63753 .45764 L .63738 .45762 L F
.63745 .4576 m .63753 .45764 L .63742 .45761 L F
.778 .957 .639 r
.63788 .45665 m .63704 .45839 L .638 .45653 L F
.175 .65 .931 r
.63738 .45762 m .63753 .45764 L .63738 .45759 L F
.63753 .45764 m .63781 .45768 L .63757 .45763 L F
.778 .957 .639 r
.63739 .45771 m .6377 .45751 L .6375 .45758 L F
.02 .044 .544 r
.63753 .45764 m .63742 .45761 L .63756 .45762 L F
.63757 .45763 m .63756 .45762 L .6376 .45762 L F
.63753 .45764 m .63756 .45762 L .63757 .45763 L F
.175 .65 .931 r
.63753 .45764 m .63757 .45763 L .63738 .45759 L F
.516 .464 .737 r
.6361 .45892 m .63738 .45759 L .63757 .45763 L F
.63767 .45777 m .63757 .45763 L .63781 .45768 L F
.02 .044 .544 r
.63759 .45766 m .63753 .45764 L .6376 .45762 L F
.516 .464 .737 r
.6361 .45892 m .63757 .45763 L .63767 .45777 L F
.02 .044 .544 r
.6376 .45762 m .63742 .45761 L .63788 .45665 L F
.63839 .45657 m .63759 .45766 L .63788 .45665 L F
.634 .353 .474 r
.70049 .43602 m .69694 .43819 L .697 .4361 L F
.70049 .43602 m .70132 .4386 L .69694 .43819 L F
.613 .443 .629 r
.70416 .4337 m .70049 .43602 L .69945 .43272 L F
.70416 .4337 m .70287 .43815 L .70049 .43602 L F
.351 .186 .512 r
.70607 .43561 m .70287 .43815 L .70416 .4337 L F
0 0 0 r
.70532 .43666 m .70287 .43815 L .70607 .43561 L F
.553 .308 .498 r
.70325 .43795 m .70049 .43602 L .70287 .43815 L F
.70325 .43795 m .70132 .4386 L .70049 .43602 L F
0 0 .252 r
.2153 .63698 m .21377 .64046 L .21296 .63717 L F
.765 .743 .833 r
.56635 .63204 m .56271 .63191 L .56567 .63316 L F
.202 0 .236 r
.631 .45351 m .63192 .45324 L .63359 .45065 L F
.647 .642 .832 r
.49299 .69951 m .49542 .69945 L .49404 .69585 L F
.148 .128 .577 r
.51504 .73114 m .51608 .72985 L .51615 .72781 L F
.851 .661 .645 r
.67525 .45639 m .67138 .45796 L .67328 .4553 L F
.67525 .45639 m .67468 .45909 L .67138 .45796 L F
.467 .252 .503 r
.67699 .4555 m .67703 .45728 L .67644 .45698 L F
.67562 .4562 m .67644 .45698 L .67525 .45639 L F
.67699 .4555 m .67644 .45698 L .67562 .4562 L F
.344 .16 .481 r
.6792 .45313 m .67699 .4555 L .68149 .45571 L F
.6792 .45313 m .67703 .45728 L .67699 .4555 L F
.849 .765 .77 r
.67565 .4548 m .67703 .45728 L .6792 .45313 L F
.506 .843 .997 r
.67764 .4571 m .67751 .45801 L .67565 .4548 L F
.67751 .45801 m .67747 .45835 L .67708 .4576 L F
.122 .378 .835 r
.67525 .45639 m .67703 .45728 L .67565 .4548 L F
.506 .843 .997 r
.67751 .45801 m .67708 .4576 L .67565 .4548 L F
.27 .358 .77 r
.67703 .45728 m .67747 .45835 L .67525 .45639 L F
.057 .301 .788 r
.67565 .4548 m .67747 .45835 L .67525 .45639 L F
.657 .321 0 r
.67076 .44119 m .67214 .44462 L .67176 .44367 L F
.944 .857 .431 r
.67176 .44367 m .67214 .44462 L .67151 .44694 L F
.893 .904 .827 r
.66304 .41835 m .65978 .42016 L .66221 .41766 L F
.686 .939 .964 r
.66609 .41662 m .66304 .41835 L .66221 .41766 L F
.607 .558 .774 r
.70137 .42731 m .69907 .42811 L .69788 .42464 L F
.591 .478 .693 r
.70137 .42731 m .69913 .43016 L .69907 .42811 L F
0 .127 .676 r
.66773 .43567 m .66985 .43902 L .66992 .43764 L F
0 0 .342 r
.66985 .43902 m .67039 .43992 L .66992 .43764 L F
.66985 .43902 m .67076 .44119 L .67039 .43992 L F
.487 .31 .567 r
.58177 .61812 m .58354 .61699 L .58062 .6168 L F
.58177 .61812 m .58402 .61938 L .58354 .61699 L F
.869 .841 .814 r
.58592 .45865 m .58631 .46157 L .58363 .46183 L F
.829 .816 .838 r
.58891 .45877 m .58631 .46157 L .58592 .45865 L F
0 .049 .536 r
.66773 .43567 m .66861 .43643 L .66752 .43465 L F
.66773 .43567 m .66939 .43717 L .66861 .43643 L F
.899 .548 .369 r
.66861 .43643 m .66723 .43777 L .66794 .43579 L F
.66861 .43643 m .66794 .43579 L .66803 .43555 L F
0 .049 .536 r
.66939 .43717 m .66992 .43764 L .66861 .43643 L F
0 0 0 r
.63359 .45065 m .63192 .45324 L .63303 .45201 L F
.998 .846 .516 r
.667 .40901 m .66737 .41277 L .66649 .41219 L F
.67 .164 0 r
.66737 .41277 m .66874 .41433 L .66649 .41219 L F
.343 .121 .426 r
.57646 .49954 m .57674 .4975 L .57895 .49661 L F
.813 .659 .692 r
.50463 .69003 m .50863 .68793 L .50476 .68805 L F
.50463 .69003 m .50746 .69095 L .50863 .68793 L F
.599 .519 .736 r
.5089 .68601 m .50863 .68793 L .51075 .68643 L F
.51075 .68643 m .50863 .68793 L .5089 .68601 L F
.43 .196 .455 r
.45511 .58541 m .45728 .58479 L .45657 .58278 L F
.582 .275 .415 r
.45657 .58278 m .45728 .58479 L .46062 .58337 L F
.67 .806 .948 r
.62007 .4299 m .61977 .43007 L .62043 .4325 L F
.61977 .43007 m .61706 .43159 L .62026 .43246 L F
.61977 .43007 m .62026 .43246 L .62043 .4325 L F
.61977 .43007 m .61647 .42977 L .61706 .43159 L F
.6202 .42983 m .6199 .42982 L .61977 .43007 L F
.6199 .42982 m .61647 .42977 L .61977 .43007 L F
.952 .66 .447 r
.61913 .43631 m .62076 .43495 L .61839 .43259 L F
.951 .669 .468 r
.6172 .43141 m .62043 .4325 L .61706 .43159 L F
.952 .66 .447 r
.61796 .43335 m .61839 .43259 L .6172 .43141 L F
.61913 .43631 m .61839 .43259 L .61796 .43335 L F
.62076 .43495 m .62076 .43495 L .62076 .43494 L F
.62076 .43495 m .62076 .43494 L .6172 .43141 L F
.951 .669 .468 r
.6172 .43141 m .62076 .43494 L .62043 .4325 L F
.62076 .43494 m .62076 .43495 L .62043 .4325 L F
.67 .806 .948 r
.6202 .42983 m .62007 .4299 L .62043 .4325 L F
.584 .725 .94 r
.37883 .61894 m .3777 .62112 L .37664 .61953 L F
.37883 .61894 m .38019 .62051 L .3777 .62112 L F
.395 .236 .545 r
.2427 .57626 m .2426 .57891 L .24081 .57936 L F
.444 .367 .676 r
.2426 .57891 m .24124 .58183 L .24081 .57936 L F
0 0 .416 r
.35535 .62917 m .3555 .62917 L .35396 .62579 L F
.523 .744 .975 r
.35715 .62888 m .35879 .63052 L .35952 .63043 L F
.35724 .62918 m .35965 .63138 L .35715 .62888 L F
.35715 .62888 m .35941 .63035 L .35819 .62976 L F
.912 .823 .745 r
.35819 .62976 m .3578 .62912 L .35724 .62918 L F
.3578 .62912 m .35669 .62729 L .35719 .629 L F
.3578 .62912 m .35719 .629 L .35724 .62918 L F
.523 .744 .975 r
.35628 .62831 m .35715 .62888 L .35819 .62976 L F
0 .263 .767 r
.35535 .62917 m .35835 .63194 L .35771 .63083 L F
.912 .823 .745 r
.35724 .62918 m .35709 .62883 L .35534 .62802 L F
.35724 .62918 m .35534 .62802 L .35536 .62803 L F
.35536 .62803 m .35534 .62802 L .35529 .62799 L F
.35724 .62918 m .35529 .62799 L .35628 .62831 L F
.523 .744 .975 r
.35628 .62831 m .35835 .63194 L .35965 .63138 L F
.912 .823 .745 r
.35819 .62976 m .35641 .6291 L .35636 .62872 L F
.197 0 0 r
.35694 .62915 m .35641 .6291 L .35753 .62951 L F
.35752 .62943 m .35753 .62951 L .35819 .62976 L F
.35694 .62915 m .35753 .62951 L .35752 .62943 L F
0 .263 .767 r
.35589 .62867 m .35758 .63067 L .35628 .62831 L F
.35758 .63067 m .35771 .63083 L .35758 .63059 L F
.35758 .63067 m .35758 .63059 L .35628 .62831 L F
.35535 .62917 m .35771 .63083 L .35589 .62867 L F
.912 .823 .745 r
.35709 .62883 m .35601 .62617 L .35549 .62747 L F
.35709 .62883 m .35549 .62747 L .35529 .62799 L F
.523 .744 .975 r
.35628 .62831 m .35724 .62918 L .35715 .62888 L F
.912 .823 .745 r
.35669 .62729 m .35601 .62617 L .35724 .62918 L F
.35819 .62976 m .35724 .62918 L .35628 .62831 L F
.35819 .62976 m .35636 .62872 L .35601 .62617 L F
.197 0 0 r
.36046 .62942 m .35694 .62915 L .35819 .62976 L F
.35851 .62927 m .35944 .6295 L .35641 .6291 L F
.36046 .62942 m .35961 .62949 L .35851 .62927 L F
.35961 .62949 m .35944 .6295 L .35851 .62927 L F
.523 .744 .975 r
.35941 .63035 m .36039 .631 L .35819 .62976 L F
.35952 .63043 m .35965 .63138 L .36044 .63103 L F
.36039 .631 m .36044 .63103 L .35819 .62976 L F
.427 .799 .994 r
.36171 .63014 m .36046 .62942 L .35819 .62976 L F
.36205 .63018 m .36192 .63012 L .36171 .63014 L F
.36192 .63012 m .36046 .62942 L .36171 .63014 L F
.523 .744 .975 r
.35879 .63052 m .35965 .63138 L .35952 .63043 L F
0 .263 .767 r
.35535 .62917 m .35628 .62831 L .3555 .62917 L F
.55 .686 .929 r
.67403 .42655 m .67041 .4249 L .67351 .42465 L F
.864 .881 .848 r
.67606 .42413 m .67403 .42655 L .67351 .42465 L F
.807 .778 .826 r
.55135 .68785 m .54962 .68408 L .55096 .68533 L F
.55135 .68785 m .54677 .68698 L .54962 .68408 L F
.85 .662 .647 r
.55135 .68785 m .54835 .69025 L .54677 .68698 L F
.589 .563 .793 r
.55096 .68533 m .55272 .68885 L .55135 .68785 L F
.835 .735 .754 r
.55272 .68885 m .54835 .69025 L .55135 .68785 L F
.628 .686 .885 r
.63461 .41266 m .63171 .41194 L .63306 .41125 L F
.982 .742 .495 r
.63428 .41478 m .63461 .41266 L .63306 .41125 L F
.759 .811 .894 r
.43268 .57989 m .43605 .57995 L .43464 .57952 L F
.098 0 0 r
.43821 .57965 m .43464 .57952 L .43605 .57995 L F
.423 .253 .544 r
.23862 .58499 m .23863 .58742 L .2367 .5879 L F
.347 .262 .616 r
.23863 .58742 m .23704 .59106 L .2367 .5879 L F
.123 0 0 r
.64409 .44844 m .64782 .4473 L .64541 .44725 L F
.017 .569 .826 r
.19408 .54065 m .19783 .54144 L .1959 .5412 L F
.586 .866 .995 r
.36116 .63282 m .36265 .63354 L .36448 .63279 L F
.36 .831 .876 r
.41339 .57668 m .41112 .57734 L .40934 .57731 L F
.684 .916 .973 r
.46379 .63201 m .46623 .63279 L .46802 .63157 L F
.493 .005 .026 r
.20142 .61124 m .20393 .61159 L .20471 .61077 L F
0 0 .108 r
.20471 .61077 m .20603 .61056 L .20666 .60844 L F
0 0 0 r
.20471 .61077 m .20393 .61159 L .20603 .61056 L F
.136 .439 .876 r
.64351 .46777 m .646 .46921 L .64506 .46726 L F
.64351 .46777 m .64506 .46726 L .64172 .46881 L F
.339 0 0 r
.5389 .66743 m .54299 .66802 L .54049 .66734 L F
.978 .744 .329 r
.55628 .67493 m .55702 .67836 L .55711 .67604 L F
.996 .862 .539 r
.55685 .67256 m .55628 .67493 L .55711 .67604 L F
.785 .669 .736 r
.63713 .44076 m .63651 .44321 L .63491 .44131 L F
.677 .558 .713 r
.64039 .4416 m .63651 .44321 L .63713 .44076 L F
.095 .315 .791 r
.641 .44413 m .63651 .44321 L .64039 .4416 L F
.727 .471 .54 r
.43321 .62332 m .43313 .62568 L .43709 .62568 L F
.653 .157 0 r
.66019 .43445 m .66174 .43607 L .66173 .4356 L F
.923 .975 .72 r
.61364 .45366 m .61437 .451 L .612 .45253 L F
.89 .673 .603 r
.612 .45253 m .61345 .45629 L .61364 .45366 L F
.578 .327 .499 r
.38524 .59739 m .38243 .6013 L .38235 .59935 L F
.35 .061 .325 r
.3857 .59976 m .38524 .59739 L .38696 .59628 L F
.3857 .59976 m .38243 .6013 L .38524 .59739 L F
.958 .654 .232 r
.66587 .43002 m .66523 .43101 L .66454 .42896 L F
.66587 .43002 m .6662 .43227 L .66523 .43101 L F
.626 .581 .783 r
.69667 .42087 m .69465 .42348 L .69418 .42151 L F
.69667 .42087 m .69788 .42464 L .69465 .42348 L F
.003 .036 .542 r
.59092 .61294 m .58976 .61149 L .59141 .6108 L F
.59092 .61294 m .59009 .61499 L .58976 .61149 L F
.441 .233 .5 r
.62375 .45759 m .62308 .45948 L .62528 .45845 L F
.534 0 0 r
.62375 .45759 m .62528 .45845 L .62169 .45793 L F
.44 .233 .502 r
.62574 .45619 m .62528 .45845 L .62375 .45759 L F
.62375 .45759 m .62528 .45845 L .62574 .45619 L F
.525 .1 .176 r
.61837 .47992 m .62153 .47946 L .62068 .48118 L F
.369 0 .105 r
.62068 .48118 m .62153 .47946 L .62441 .47879 L F
.514 .24 .437 r
.54223 .70495 m .54482 .70476 L .54476 .70233 L F
.925 .586 .376 r
.54476 .70233 m .54482 .70476 L .54223 .70495 L F
.369 .133 .419 r
.54482 .70476 m .54732 .70187 L .54476 .70233 L F
.797 .561 .581 r
.57588 .63474 m .57249 .63701 L .57538 .63458 L F
.756 .983 .742 r
.57588 .63474 m .57692 .63283 L .57868 .6321 L F
.57588 .63474 m .57538 .63458 L .57692 .63283 L F
.526 .421 .678 r
.19696 .62198 m .19798 .62301 L .19789 .62254 L F
.858 .899 .862 r
.58295 .46545 m .57899 .46769 L .58128 .46446 L F
.418 .272 .574 r
.23663 .59585 m .2348 .59407 L .23683 .59351 L F
.23663 .59585 m .2348 .59659 L .2348 .59407 L F
.426 .397 .723 r
.21558 .5612 m .21663 .55732 L .21437 .55837 L F
.21558 .5612 m .21735 .56107 L .21663 .55732 L F
.905 .891 .806 r
.58828 .63733 m .58606 .64055 L .58725 .64113 L F
.347 .262 .616 r
.23863 .58742 m .23861 .59041 L .23704 .59106 L F
.364 .205 .528 r
.23861 .59041 m .23683 .59351 L .23704 .59106 L F
.148 0 0 r
.39994 .63867 m .39825 .63927 L .39595 .63936 L F
.356 0 0 r
.40213 .63894 m .39825 .63927 L .39994 .63867 L F
.728 .421 .46 r
.50252 .68749 m .50463 .69003 L .50476 .68805 L F
.767 .931 .939 r
.68012 .46067 m .68064 .45991 L .68151 .45986 L F
.702 .6 .739 r
.68454 .45914 m .68151 .45986 L .68406 .4568 L F
.68454 .45914 m .68151 .45986 L .68406 .4568 L F
.415 0 0 r
.68064 .45991 m .68454 .45914 L .68151 .45986 L F
.605 .347 .5 r
.5847 .49131 m .58716 .49336 L .58452 .4938 L F
.5847 .49131 m .58731 .49115 L .58716 .49336 L F
.148 .332 .792 r
.63171 .41194 m .63428 .41478 L .63306 .41125 L F
.326 .763 .967 r
.48736 .73417 m .49111 .73465 L .48941 .73392 L F
.463 .665 .95 r
.49111 .73465 m .49241 .73334 L .48941 .73392 L F
.49111 .73465 m .49371 .7347 L .49241 .73334 L F
.898 .839 .779 r
.59429 .45085 m .59081 .45284 L .59298 .44964 L F
.59429 .45085 m .59326 .4526 L .59081 .45284 L F
.841 .866 .862 r
.59667 .44809 m .59429 .45085 L .59298 .44964 L F
.673 .639 .808 r
.45511 .58541 m .45897 .58783 L .458 .58636 L F
.877 .861 .821 r
.458 .58636 m .45897 .58783 L .46106 .58465 L F
.773 .716 .799 r
.64694 .42693 m .6475 .43016 L .64298 .42873 L F
.48 .262 .504 r
.6453 .43065 m .64298 .42873 L .6475 .43016 L F
.366 .303 .654 r
.64818 .42599 m .6475 .43016 L .64694 .42693 L F
.64818 .42599 m .64942 .42962 L .6475 .43016 L F
.25 0 0 r
.64834 .43066 m .6475 .43016 L .64942 .42962 L F
.64834 .43066 m .6453 .43065 L .6475 .43016 L F
.748 .937 .947 r
.20509 .60341 m .20366 .6058 L .2048 .60342 L F
.20366 .6058 m .20319 .60492 L .20509 .60341 L F
.20509 .60341 m .20319 .60492 L .20366 .6058 L F
.64 .822 .97 r
.20578 .59291 m .20739 .59413 L .20953 .59332 L F
.754 .418 .415 r
.50148 .68918 m .50252 .68749 L .50114 .68697 L F
.50148 .68918 m .50463 .69003 L .50252 .68749 L F
.505 .639 .914 r
.67853 .40881 m .67643 .40932 L .6748 .40653 L F
.903 .889 .807 r
.5118 .69026 m .50832 .69296 L .5107 .69218 L F
.185 0 .095 r
.5118 .69026 m .51384 .69008 L .51402 .68923 L F
.281 0 .043 r
.5118 .69026 m .51301 .69162 L .51384 .69008 L F
.5118 .69026 m .5107 .69218 L .51301 .69162 L F
.075 .632 .803 r
.53107 .65556 m .53217 .65573 L .52841 .65554 L F
.53107 .65556 m .53217 .65573 L .52841 .65554 L F
.667 .963 .933 r
.53107 .65556 m .53217 .65573 L .53312 .65429 L F
.53107 .65556 m .53217 .65573 L .53312 .65429 L F
.591 .478 .693 r
.70137 .42731 m .70167 .42954 L .69913 .43016 L F
.684 .603 .759 r
.70167 .42954 m .69945 .43272 L .69913 .43016 L F
.085 0 0 r
.38058 .58371 m .38294 .58334 L .38479 .58248 L F
.432 0 0 r
.38294 .58334 m .38708 .58198 L .38479 .58248 L F
.918 .932 .802 r
.52005 .73129 m .52124 .73194 L .52339 .72865 L F
0 0 0 r
.48607 .70165 m .48475 .70538 L .48603 .70369 L F
.546 .713 .95 r
.48475 .70538 m .48721 .70519 L .48603 .70369 L F
.466 .189 .408 r
.61822 .48179 m .61837 .47992 L .62068 .48118 L F
.642 .361 .478 r
.60209 .48476 m .59808 .48761 L .59813 .48617 L F
.454 .334 .627 r
.23238 .59954 m .23254 .6021 L .23061 .60263 L F
.414 .245 .542 r
.23254 .6021 m .23056 .60515 L .23061 .60263 L F
.619 .76 .946 r
.42655 .58112 m .43014 .58194 L .42892 .58039 L F
.734 .801 .905 r
.42892 .58039 m .43014 .58194 L .43268 .57989 L F
.087 .306 .786 r
.3501 .62043 m .35082 .61916 L .34851 .61728 L F
.995 .822 .558 r
.649 .43473 m .64799 .4338 L .64859 .43418 L F
.918 .932 .802 r
.52005 .73129 m .52339 .72865 L .51976 .72824 L F
0 0 .185 r
.20851 .59981 m .20982 .59901 L .21044 .59658 L F
.18 0 .157 r
.20851 .59981 m .2092 .60131 L .20982 .59901 L F
.20851 .59981 m .20748 .60201 L .2092 .60131 L F
.097 .477 .895 r
.36873 .63444 m .36929 .63358 L .36746 .63301 L F
.114 .5 .905 r
.36873 .63444 m .37042 .63492 L .36929 .63358 L F
.13 .622 .911 r
.2232 .54421 m .22533 .54446 L .22694 .54524 L F
.138 .584 .926 r
.2276 .54453 m .22694 .54524 L .22533 .54446 L F
.2276 .54453 m .22933 .54565 L .22694 .54524 L F
.835 .735 .754 r
.55272 .68885 m .55156 .69076 L .54835 .69025 L F
.697 .544 .676 r
.55607 .68813 m .55156 .69076 L .55272 .68885 L F
.252 0 0 r
.51579 .69373 m .51448 .69538 L .51223 .69583 L F
.509 .145 .284 r
.51794 .69291 m .51448 .69538 L .51579 .69373 L F
0 0 0 r
.40373 .59027 m .40126 .59269 L .40208 .5913 L F
.809 .376 .214 r
.58922 .61642 m .59009 .61499 L .59092 .61294 L F
.58922 .61642 m .59141 .6169 L .59009 .61499 L F
.68 .36 .427 r
.50951 .68386 m .51064 .68534 L .51318 .68178 L F
.706 .702 .844 r
.4472 .57476 m .4432 .57337 L .44554 .57261 L F
.632 .726 .915 r
.44942 .57371 m .4472 .57476 L .44554 .57261 L F
.281 0 .135 r
.21103 .59 m .21412 .5875 L .21214 .58824 L F
.782 .653 .721 r
.63713 .44076 m .63334 .43932 L .6362 .43892 L F
.63713 .44076 m .63491 .44131 L .63334 .43932 L F
.083 .642 .71 r
.6362 .43892 m .63944 .43857 L .63713 .44076 L F
.677 .558 .713 r
.64039 .4416 m .63713 .44076 L .63944 .43857 L F
.676 .479 .612 r
.5896 .48884 m .58973 .49146 L .58731 .49115 L F
.955 .662 .441 r
.55151 .6576 m .5534 .66107 L .55223 .65857 L F
.69 .513 .643 r
.56812 .63468 m .57042 .63741 L .56648 .63765 L F
.405 .37 .706 r
.5687 .63196 m .57122 .63363 L .56812 .63468 L F
.631 .141 0 r
.56932 .63636 m .57042 .63741 L .56812 .63468 L F
.56932 .63636 m .56812 .63468 L .57122 .63363 L F
.873 .827 .8 r
.57179 .4789 m .57223 .48251 L .56974 .48182 L F
.917 .726 .63 r
.56974 .48182 m .57223 .48251 L .57084 .48519 L F
.867 .824 .804 r
.57336 .48008 m .57223 .48251 L .57179 .4789 L F
.828 .817 .838 r
.58837 .45597 m .58891 .45877 L .58592 .45865 L F
.87 .84 .812 r
.59111 .45559 m .58891 .45877 L .58837 .45597 L F
.826 .682 .704 r
.56097 .49925 m .56439 .50014 L .56232 .50307 L F
.724 .534 .634 r
.56439 .50014 m .56607 .50293 L .56232 .50307 L F
.767 .459 .464 r
.56439 .50014 m .56828 .50288 L .56607 .50293 L F
.775 .87 .918 r
.47134 .71486 m .46964 .71552 L .47049 .71335 L F
0 .007 .582 r
.47244 .71553 m .47134 .71486 L .47049 .71335 L F
.47244 .71553 m .47274 .71672 L .47134 .71486 L F
.254 .535 .92 r
.24222 .55038 m .24456 .55112 L .24433 .55272 L F
.185 .463 .885 r
.24456 .55112 m .24553 .55265 L .24433 .55272 L F
.381 .363 .714 r
.24636 .55432 m .24433 .55272 L .24553 .55265 L F
.393 .37 .714 r
.55521 .68373 m .55699 .6876 L .55607 .68813 L F
0 .35 .718 r
.48829 .68797 m .48703 .68752 L .48553 .68673 L F
.598 .446 .646 r
.49183 .68906 m .48733 .69093 L .48703 .68752 L F
.49183 .68906 m .48703 .68752 L .48829 .68797 L F
.559 .754 .969 r
.70948 .43738 m .71014 .4388 L .70667 .43778 L F
.597 .322 .47 r
.71014 .4388 m .70765 .44109 L .70667 .43778 L F
.71014 .4388 m .70986 .44086 L .70765 .44109 L F
.318 .085 .395 r
.71156 .44002 m .71014 .4388 L .70948 .43738 L F
.71156 .44002 m .70986 .44086 L .71014 .4388 L F
.412 .229 .52 r
.35001 .59103 m .34983 .59346 L .35184 .59268 L F
.58 .201 .289 r
.35001 .59103 m .35184 .59268 L .35269 .59115 L F
.586 .259 .383 r
.57037 .50005 m .57522 .49862 L .57309 .50185 L F
.644 .281 .339 r
.57522 .49862 m .57553 .50151 L .57309 .50185 L F
.57522 .49862 m .57646 .49954 L .57553 .50151 L F
.675 .881 .975 r
.44088 .57411 m .44187 .57221 L .4432 .57337 L F
.44088 .57411 m .43969 .57328 L .44187 .57221 L F
.578 .276 .42 r
.4898 .72863 m .49191 .73074 L .49228 .72859 L F
.888 .866 .812 r
.59326 .4526 m .59111 .45559 L .59081 .45284 L F
.69 .76 .905 r
.65444 .42451 m .64898 .42403 L .6523 .42257 L F
.664 .761 .922 r
.6544 .42386 m .65444 .42451 L .6523 .42257 L F
.864 .881 .848 r
.67606 .42413 m .67351 .42465 L .67468 .42318 L F
.945 .826 .697 r
.6756 .42059 m .67606 .42413 L .67468 .42318 L F
.916 .729 .635 r
.68406 .4568 m .68454 .45914 L .68312 .45668 L F
.415 0 0 r
.68064 .45991 m .68303 .46046 L .68454 .45914 L F
.669 .198 .124 r
.68454 .45914 m .68303 .46046 L .68659 .46084 L F
.014 0 0 r
.51895 .65069 m .52153 .64973 L .52108 .652 L F
.72 .452 .52 r
.52108 .652 m .52153 .64973 L .51818 .64973 L F
.421 .179 .44 r
.52153 .64973 m .52415 .6472 L .52172 .64992 L F
.772 .504 .529 r
.52153 .64973 m .52472 .65237 L .52108 .652 L F
.024 .591 .784 r
.52351 .65215 m .52108 .652 L .52153 .64973 L F
0 0 0 r
.52172 .64992 m .52153 .64973 L .52108 .652 L F
.421 .179 .44 r
.52153 .64973 m .52415 .6472 L .52172 .64992 L F
.024 .591 .784 r
.52351 .65215 m .52153 .64973 L .52172 .64992 L F
.629 .522 .713 r
.70667 .43778 m .70371 .43996 L .70452 .43923 L F
.70667 .43778 m .70765 .44109 L .70371 .43996 L F
.691 .44 .54 r
.70795 .44382 m .70371 .43996 L .70765 .44109 L F
.70795 .44382 m .70369 .44586 L .70371 .43996 L F
.082 .138 .623 r
.66886 .42003 m .66924 .42301 L .6679 .42115 L F
.824 .811 .838 r
.6093 .43861 m .60624 .43868 L .60789 .43727 L F
.834 .844 .854 r
.61053 .43451 m .6093 .43861 L .60789 .43727 L F
.61053 .43451 m .61187 .43589 L .6093 .43861 L F
.779 .427 .39 r
.57853 .60193 m .58016 .60006 L .57684 .59917 L F
.57853 .60193 m .58096 .60215 L .58016 .60006 L F
.341 0 0 r
.66874 .41433 m .67144 .41535 L .67028 .41504 L F
.168 .425 .862 r
.67144 .41535 m .67489 .41839 L .67388 .41467 L F
.732 .917 .956 r
.6505 .46149 m .65448 .46048 L .65302 .46007 L F
.811 .948 .912 r
.65302 .46007 m .65448 .46048 L .65633 .45911 L F
.594 .555 .78 r
.69557 .41728 m .69418 .42151 L .69314 .41783 L F
.69557 .41728 m .69667 .42087 L .69418 .42151 L F
.631 .461 .634 r
.38235 .59935 m .38244 .60238 L .38006 .60203 L F
.414 .451 .79 r
.38243 .6013 m .38244 .60238 L .38235 .59935 L F
.402 .404 .747 r
.45635 .57651 m .45899 .57904 L .45713 .57953 L F
.155 0 .039 r
.45899 .57904 m .45609 .58083 L .45713 .57953 L F
.878 .86 .819 r
.59081 .45284 m .59111 .45559 L .58979 .45436 L F
.87 .84 .812 r
.59111 .45559 m .58837 .45597 L .58979 .45436 L F
.035 0 .075 r
.21796 .57344 m .21948 .57262 L .2204 .5707 L F
.318 0 .226 r
.2204 .5707 m .21948 .57262 L .22253 .57001 L F
.737 .722 .838 r
.44226 .58202 m .44413 .58264 L .44496 .58084 L F
.535 .482 .743 r
.44496 .58084 m .44413 .58264 L .44714 .58083 L F
.584 .591 .825 r
.44413 .58264 m .44666 .58286 L .44714 .58083 L F
.359 .484 .85 r
.46274 .59099 m .46494 .59112 L .46431 .59013 L F
.74 .989 .889 r
.57719 .62583 m .57601 .62556 L .57308 .62795 L F
.61 .635 .851 r
.20772 .58307 m .20815 .58478 L .20991 .58369 L F
.704 .339 .355 r
.52375 .67898 m .52748 .68051 L .52737 .67921 L F
.156 0 .291 r
.52984 .67574 m .52737 .67921 L .52944 .67785 L F
.45 .252 .518 r
.52748 .68051 m .52944 .67785 L .52737 .67921 L F
.694 .653 .805 r
.69189 .41444 m .69086 .41903 L .68951 .415 L F
.69189 .41444 m .69314 .41783 L .69086 .41903 L F
.481 .213 .43 r
.57049 .6261 m .5734 .6258 L .57342 .62289 L F
.611 .367 .522 r
.5734 .6258 m .57562 .62252 L .57342 .62289 L F
0 .484 .862 r
.21436 .55571 m .21398 .5549 L .21224 .55475 L F
.21436 .55571 m .21547 .5559 L .21398 .5549 L F
.522 .395 .649 r
.21436 .55571 m .21663 .55732 L .21547 .5559 L F
.21436 .55571 m .21437 .55837 L .21663 .55732 L F
.511 .663 .93 r
.35835 .63194 m .35871 .63249 L .36044 .63103 L F
.425 .504 .836 r
.35871 .63249 m .36116 .63282 L .36044 .63103 L F
.669 .905 .978 r
.65952 .46113 m .65986 .46248 L .66223 .46107 L F
.987 .861 .497 r
.56007 .63075 m .5597 .63383 L .56058 .63291 L F
.56058 .63291 m .56007 .63075 L .56271 .63191 L F
.56058 .63291 m .5597 .63383 L .56007 .63075 L F
.973 .814 .626 r
.67109 .45118 m .66916 .45346 L .67102 .45109 L F
0 0 .192 r
.67109 .45118 m .67123 .45082 L .67088 .4483 L F
.973 .814 .626 r
.67109 .45118 m .67102 .45109 L .67123 .45082 L F
.966 .805 .631 r
.67069 .44962 m .67114 .45124 L .67109 .45118 L F
.67114 .45124 m .6716 .45286 L .67109 .45118 L F
.789 .386 .289 r
.6716 .45286 m .67033 .4548 L .67109 .45118 L F
.6716 .45286 m .67328 .4553 L .67033 .4548 L F
.564 .634 .879 r
.24735 .55821 m .24882 .56045 L .2507 .55962 L F
.768 .334 .22 r
.55156 .69076 m .55 .69204 L .54835 .69025 L F
.852 .86 .846 r
.55409 .69106 m .55 .69204 L .55156 .69076 L F
.684 .603 .759 r
.70167 .42954 m .70416 .4337 L .69945 .43272 L F
.502 .339 .592 r
.19929 .61393 m .20158 .61369 L .20142 .61124 L F
.773 .52 .553 r
.63434 .41712 m .63789 .41515 L .63428 .41478 L F
.63434 .41712 m .63819 .41779 L .63789 .41515 L F
.902 .857 .788 r
.6644 .4558 m .66558 .45409 L .66501 .45208 L F
.599 .519 .736 r
.5089 .68601 m .51075 .68643 L .50951 .68386 L F
0 0 .573 r
.55436 .68196 m .55556 .68368 L .55521 .68373 L F
.423 .331 .647 r
.55556 .68368 m .55599 .68455 L .55521 .68373 L F
.696 .603 .748 r
.55386 .68502 m .55555 .68369 L .55432 .68311 L F
.55555 .68369 m .55556 .68368 L .55555 .68368 L F
.55555 .68369 m .55555 .68368 L .55432 .68311 L F
0 0 .502 r
.55599 .68455 m .55699 .6876 L .55611 .68569 L F
.55571 .68426 m .55611 .68569 L .55521 .68373 L F
.55599 .68455 m .55611 .68569 L .55571 .68426 L F
.811 .948 .912 r
.65302 .46007 m .65633 .45911 L .65532 .45796 L F
0 .01 .552 r
.65633 .45911 m .65818 .46008 L .65532 .45796 L F
.552 .128 .19 r
.61006 .48225 m .61288 .48373 L .60927 .48473 L F
.61006 .48225 m .61239 .48248 L .61288 .48373 L F
.646 .805 .959 r
.68002 .42683 m .67667 .42872 L .67934 .4281 L F
.68002 .42683 m .67886 .42544 L .67667 .42872 L F
.592 .734 .942 r
.68002 .42683 m .68154 .42318 L .67886 .42544 L F
.68002 .42683 m .6825 .42624 L .68154 .42318 L F
.193 0 0 r
.68168 .42742 m .68002 .42683 L .67934 .4281 L F
.68168 .42742 m .6825 .42624 L .68002 .42683 L F
.181 0 0 r
.39054 .59616 m .38933 .59638 L .38696 .59628 L F
0 0 0 r
.39279 .59589 m .38933 .59638 L .39054 .59616 L F
.24 .712 .942 r
.20762 .54249 m .20972 .54247 L .21153 .54313 L F
.075 .604 .868 r
.20972 .54247 m .21352 .54334 L .21153 .54313 L F
.108 .662 .762 r
.20376 .55468 m .20032 .55489 L .20169 .5549 L F
.258 0 0 r
.39201 .6276 m .39133 .62721 L .38976 .62796 L F
.39201 .6276 m .3936 .62788 L .39133 .62721 L F
.808 .4 0 r
.54884 .65179 m .55066 .65555 L .55084 .6552 L F
.755 .405 0 r
.55066 .65555 m .55151 .6576 L .55084 .6552 L F
.554 .594 .848 r
.54829 .66382 m .54751 .66101 L .54514 .6614 L F
0 0 .157 r
.54684 .66715 m .54819 .66601 L .54829 .66382 L F
0 0 .538 r
.54829 .66382 m .54869 .66392 L .54751 .66101 L F
0 0 .136 r
.54829 .66382 m .54819 .66601 L .54869 .66392 L F
.557 .504 .752 r
.24636 .55432 m .24735 .55821 L .24519 .55875 L F
.926 .62 .444 r
.67761 .45179 m .67893 .45051 L .67796 .44925 L F
.67761 .45179 m .6792 .45313 L .67893 .45051 L F
.517 .667 .93 r
.67893 .45051 m .68161 .44817 L .67796 .44925 L F
.67893 .45051 m .68263 .45086 L .68161 .44817 L F
.523 .319 .545 r
.67893 .45051 m .6792 .45313 L .68159 .45206 L F
.368 .172 .478 r
.24463 .57023 m .24425 .57245 L .24248 .57296 L F
.455 .368 .668 r
.24437 .57559 m .24248 .57296 L .24425 .57245 L F
.24437 .57559 m .2427 .57626 L .24248 .57296 L F
.626 .146 .094 r
.49407 .70011 m .49542 .69945 L .49505 .70081 L F
.356 .463 .832 r
.49404 .69585 m .49542 .69945 L .49733 .69848 L F
.583 .262 .391 r
.49798 .69949 m .49768 .70129 L .49542 .69945 L F
.287 .298 .697 r
.49542 .69945 m .49768 .70129 L .49733 .69848 L F
.51 .3 .53 r
.24124 .58183 m .24104 .58463 L .23862 .58499 L F
.444 .367 .676 r
.2426 .57891 m .24312 .58129 L .24124 .58183 L F
.29 .12 .47 r
.24264 .58377 m .24124 .58183 L .24312 .58129 L F
.24264 .58377 m .24104 .58463 L .24124 .58183 L F
.936 .576 .301 r
.50626 .66982 m .5081 .67243 L .50459 .67268 L F
.212 0 0 r
.50459 .67268 m .5081 .67243 L .50704 .67275 L F
.247 .698 .955 r
.5081 .67243 m .5095 .67193 L .50704 .67275 L F
.5081 .67243 m .51064 .67265 L .5095 .67193 L F
0 0 0 r
.20382 .65452 m .20155 .65746 L .20269 .65572 L F
.484 .288 .538 r
.21722 .57552 m .21948 .57262 L .21796 .57344 L F
.877 .861 .821 r
.458 .58636 m .46106 .58465 L .46062 .58337 L F
.446 .619 .924 r
.46106 .58465 m .46295 .58342 L .46062 .58337 L F
.46106 .58465 m .46295 .58342 L .46062 .58337 L F
.061 .606 .842 r
.19793 .54146 m .19987 .54153 L .2018 .54211 L F
.196 .723 .837 r
.19818 .54172 m .20106 .54158 L .19987 .54153 L F
.163 .685 .878 r
.19987 .54153 m .20209 .54153 L .20385 .54187 L F
.196 .723 .837 r
.20106 .54158 m .20209 .54153 L .19987 .54153 L F
.061 .606 .842 r
.19783 .54144 m .19987 .54153 L .19793 .54146 L F
.163 .685 .878 r
.19987 .54153 m .20385 .54187 L .2018 .54211 L F
.862 .806 .318 r
.57868 .6321 m .57924 .62799 L .5808 .62901 L F
.516 .356 .602 r
.57685 .60178 m .57684 .59917 L .5744 .59973 L F
.429 .867 .908 r
.47282 .62323 m .46984 .62381 L .47059 .62359 L F
.285 .763 .657 r
.47153 .62331 m .47059 .62359 L .47028 .62419 L F
.511 .914 .869 r
.47397 .62215 m .47282 .62323 L .47059 .62359 L F
.285 .763 .657 r
.47203 .62296 m .47059 .62359 L .47153 .62331 L F
.429 .867 .908 r
.46984 .62381 m .4684 .62409 L .47059 .62359 L F
.199 0 0 r
.35269 .59115 m .35465 .59074 L .35578 .58992 L F
.324 0 0 r
.35578 .58992 m .35465 .59074 L .35799 .5898 L F
.373 0 .071 r
.35578 .58992 m .35799 .5898 L .35835 .58915 L F
.642 .361 .478 r
.60209 .48476 m .60067 .48773 L .59808 .48761 L F
.567 .253 .396 r
.60209 .48476 m .60418 .48616 L .60067 .48773 L F
.60209 .48476 m .60404 .48493 L .60418 .48616 L F
.911 .74 .657 r
.56564 .64089 m .56545 .64325 L .56411 .63992 L F
.56564 .64089 m .56545 .64325 L .56411 .63992 L F
.992 .75 .387 r
.66205 .44276 m .66293 .4419 L .66192 .4409 L F
.66205 .44276 m .66299 .44402 L .66293 .4419 L F
.313 .129 .463 r
.22607 .61651 m .22407 .61971 L .22441 .61729 L F
0 0 .162 r
.47049 .71335 m .46964 .71552 L .47015 .71591 L F
.59 .569 .799 r
.46919 .72026 m .47015 .71591 L .46964 .71552 L F
.538 .658 .913 r
.68529 .4109 m .68386 .41234 L .68085 .40829 L F
.419 0 0 r
.42214 .58426 m .42031 .58457 L .41833 .58422 L F
.6 .098 .031 r
.42214 .58426 m .42457 .58498 L .42031 .58457 L F
.127 .673 .812 r
.51875 .70823 m .52069 .70813 L .52329 .70814 L F
.749 .41 .409 r
.52069 .70813 m .52385 .70902 L .52329 .70814 L F
.364 .488 .851 r
.37223 .63772 m .37311 .63546 L .37042 .63492 L F
.37223 .63772 m .37377 .63724 L .37311 .63546 L F
.553 .416 .648 r
.37184 .64015 m .37377 .63724 L .37223 .63772 L F
.826 .708 .735 r
.57639 .47047 m .57759 .47394 L .57572 .47259 L F
.815 .713 .752 r
.57572 .47259 m .57759 .47394 L .57549 .47706 L F
.616 .778 .959 r
.6355 .41857 m .63819 .41779 L .63434 .41712 L F
.494 .886 .72 r
.47017 .63071 m .47391 .62858 L .47237 .63024 L F
0 0 0 r
.47604 .62806 m .47237 .63024 L .47391 .62858 L F
.465 .234 .478 r
.51883 .7104 m .52069 .70813 L .51875 .70823 L F
.274 .334 .744 r
.20953 .59332 m .21044 .59658 L .2118 .59541 L F
.391 .109 .36 r
.21044 .59658 m .21187 .59826 L .2118 .59541 L F
.21044 .59658 m .20982 .59901 L .21187 .59826 L F
.332 .682 .979 r
.24077 .54926 m .24015 .55039 L .23861 .54908 L F
.24077 .54926 m .24222 .55038 L .24015 .55039 L F
.577 .483 .712 r
.54431 .67242 m .54734 .67222 L .5466 .67007 L F
.617 .424 .598 r
.57037 .50005 m .57107 .5027 L .56828 .50288 L F
.586 .259 .383 r
.57037 .50005 m .57309 .50185 L .57107 .5027 L F
.514 .057 .104 r
.40581 .63722 m .40422 .63901 L .40213 .63894 L F
.499 .05 .116 r
.40806 .63737 m .40422 .63901 L .40581 .63722 L F
.078 .202 .692 r
.64944 .47039 m .646 .46921 L .64703 .4712 L F
.479 .381 .666 r
.34324 .60249 m .3456 .6044 L .34518 .60193 L F
.34324 .60249 m .3435 .60591 L .3456 .6044 L F
0 .234 .745 r
.19587 .60989 m .19643 .61208 L .1961 .61241 L F
0 0 0 r
.1961 .61241 m .19643 .61208 L .19587 .60989 L F
.367 .133 .421 r
.24104 .58463 m .23863 .58742 L .23862 .58499 L F
.754 .843 .918 r
.70667 .43778 m .70452 .43923 L .70325 .43795 L F
.418 .551 .882 r
.57985 .6391 m .58089 .63662 L .57765 .63844 L F
.57985 .6391 m .58224 .63952 L .58089 .63662 L F
.737 .608 .715 r
.6132 .4586 m .61687 .45915 L .61626 .45589 L F
.693 .465 .573 r
.61494 .45942 m .61687 .45915 L .6132 .4586 L F
.61494 .45942 m .61703 .46162 L .61687 .45915 L F
.386 .294 .628 r
.61687 .45915 m .61859 .45523 L .61626 .45589 L F
.61687 .45915 m .61932 .45907 L .61859 .45523 L F
.805 .863 .891 r
.46578 .59116 m .46771 .59158 L .46872 .59091 L F
.641 .586 .778 r
.70672 .43152 m .70416 .4337 L .70167 .42954 L F
.351 .186 .512 r
.70607 .43561 m .70416 .4337 L .70672 .43152 L F
.056 .582 .869 r
.3936 .62788 m .39722 .62889 L .39501 .62845 L F
.65 .294 .354 r
.54545 .61359 m .54973 .61184 L .54553 .61168 L F
.692 .167 0 r
.68406 .4568 m .68312 .45668 L .68149 .45571 L F
.657 .915 .978 r
.68543 .45534 m .68406 .4568 L .68673 .45663 L F
.68543 .45534 m .68312 .45668 L .68406 .4568 L F
.317 .112 .436 r
.37656 .60567 m .37457 .60785 L .37393 .60624 L F
.52 .514 .789 r
.64145 .43789 m .64039 .4416 L .63944 .43857 L F
.64145 .43789 m .64277 .44072 L .64039 .4416 L F
0 0 0 r
.64277 .44072 m .641 .44413 L .64039 .4416 L F
0 0 .101 r
.52595 .64359 m .52415 .6472 L .52579 .64597 L F
0 0 0 r
.52172 .64992 m .52415 .6472 L .52579 .64597 L F
0 0 .229 r
.52415 .6472 m .52595 .64359 L .52579 .64597 L F
0 0 0 r
.52172 .64992 m .52415 .6472 L .52579 .64597 L F
.174 0 0 r
.51824 .68126 m .52038 .68071 L .52155 .67922 L F
.363 0 .017 r
.52038 .68071 m .52375 .67898 L .52155 .67922 L F
.442 .55 .871 r
.48054 .6881 m .48368 .68934 L .48313 .68744 L F
.477 .23 .461 r
.19798 .62301 m .2004 .62078 L .19789 .62254 L F
.552 .541 .796 r
.54514 .6614 m .54751 .66101 L .54607 .65833 L F
.545 .158 .258 r
.43441 .63137 m .43064 .63345 L .43213 .63153 L F
.598 .519 .736 r
.52199 .66226 m .52373 .66394 L .5213 .6641 L F
.52199 .66226 m .52373 .66394 L .5213 .6641 L F
.862 .806 .318 r
.57868 .6321 m .5788 .62879 L .57924 .62799 L F
.92 .973 .771 r
.57692 .63283 m .5788 .62879 L .57868 .6321 L F
.761 .423 .413 r
.50477 .69257 m .50746 .69095 L .50463 .69003 L F
.50477 .69257 m .50832 .69296 L .50746 .69095 L F
.89 .92 .837 r
.42517 .58027 m .42525 .5831 L .42655 .58112 L F
.861 .893 .857 r
.42367 .58468 m .42493 .58411 L .42509 .58285 L F
.599 .178 0 r
.42509 .58285 m .42547 .58345 L .42525 .5831 L F
0 0 0 r
.42547 .58345 m .42396 .58644 L .42457 .58498 L F
0 0 .059 r
.42547 .58345 m .42498 .58575 L .42396 .58644 L F
.195 .716 .869 r
.42892 .58039 m .42517 .58027 L .42655 .58112 L F
.42892 .58039 m .42738 .5801 L .42517 .58027 L F
.351 .229 .57 r
.42738 .5801 m .42547 .58345 L .42509 .58285 L F
.42738 .5801 m .42771 .58285 L .42547 .58345 L F
.247 0 .274 r
.42771 .58285 m .42498 .58575 L .42547 .58345 L F
.861 .893 .857 r
.42493 .58411 m .42771 .58285 L .42509 .58285 L F
.599 .178 0 r
.42509 .58285 m .42525 .5831 L .42521 .58179 L F
.42509 .58285 m .42521 .58179 L .42517 .58027 L F
.872 .606 .534 r
.55247 .68394 m .54962 .68408 L .54957 .68078 L F
.864 .861 .835 r
.55247 .68394 m .55096 .68533 L .54962 .68408 L F
.79 .844 .892 r
.55311 .68076 m .55247 .68394 L .54957 .68078 L F
.55311 .68076 m .55436 .68196 L .55247 .68394 L F
.701 .284 .253 r
.19596 .55534 m .19464 .5559 L .19243 .55496 L F
.604 .878 .992 r
.19823 .55559 m .19464 .5559 L .19596 .55534 L F
0 .484 .765 r
.64667 .457 m .64559 .45658 L .64505 .45657 L F
.661 .611 .788 r
.64815 .46247 m .65005 .45997 L .64918 .45928 L F
.603 .256 .355 r
.64602 .45675 m .64949 .45989 L .64559 .45658 L F
.64949 .45989 m .64948 .45988 L .64559 .45658 L F
.64787 .45823 m .64952 .45991 L .64602 .45675 L F
.907 .895 .805 r
.64982 .46008 m .6498 .46011 L .64893 .45957 L F
.1 .25 .731 r
.6498 .46011 m .64983 .46009 L .64893 .45957 L F
.603 .256 .355 r
.64952 .45991 m .64953 .45993 L .64951 .45991 L F
.64952 .45991 m .64951 .45991 L .64602 .45675 L F
.661 .611 .788 r
.64918 .45928 m .65005 .45997 L .64952 .4582 L F
.603 .256 .355 r
.64667 .457 m .64787 .45823 L .64602 .45675 L F
.64667 .457 m .64952 .4582 L .64953 .45991 L F
.632 .594 .792 r
.64952 .4582 m .6505 .46149 L .65302 .46007 L F
.661 .611 .788 r
.64815 .46247 m .6505 .46149 L .65005 .45997 L F
.632 .594 .792 r
.64952 .4582 m .65235 .46064 L .6498 .46011 L F
.907 .895 .805 r
.64987 .45927 m .64982 .46008 L .64947 .45987 L F
.632 .594 .792 r
.64952 .4582 m .65145 .45923 L .65074 .45925 L F
.64952 .4582 m .6498 .46011 L .65143 .45692 L F
.907 .895 .805 r
.65143 .45692 m .65023 .45926 L .64987 .45927 L F
.65023 .45926 m .64982 .46008 L .64987 .45927 L F
.632 .594 .792 r
.65074 .45925 m .65302 .46007 L .65235 .46064 L F
.65145 .45923 m .65302 .46007 L .65074 .45925 L F
.1 .25 .731 r
.64983 .46009 m .65006 .45995 L .64952 .45991 L F
.603 .256 .355 r
.64952 .45991 m .64953 .45991 L .64953 .45993 L F
.64667 .457 m .64953 .45991 L .64952 .45991 L F
.059 .379 .843 r
.64742 .4569 m .64826 .45884 L .64757 .45693 L F
.64559 .45658 m .64748 .45819 L .64742 .4569 L F
.64748 .45819 m .64826 .45884 L .64742 .4569 L F
.492 .782 .997 r
.64739 .45644 m .64804 .45689 L .64742 .45688 L F
.937 .819 .702 r
.64804 .45689 m .64952 .4599 L .64983 .45814 L F
.1 .25 .731 r
.65006 .45995 m .65123 .45923 L .64952 .45991 L F
.937 .819 .702 r
.64952 .4599 m .64953 .45993 L .64954 .45991 L F
.164 0 .302 r
.64953 .45993 m .64952 .4582 L .65143 .45692 L F
.937 .819 .702 r
.64955 .45972 m .64957 .45972 L .64983 .45814 L F
.164 0 .302 r
.64957 .45972 m .65143 .45692 L .65053 .4539 L F
.907 .895 .805 r
.65143 .45692 m .64958 .45972 L .64957 .45971 L F
.164 0 .302 r
.64953 .45993 m .65143 .45692 L .64957 .45972 L F
.907 .895 .805 r
.65143 .45692 m .64957 .45971 L .64896 .45876 L F
.64958 .45972 m .64947 .45987 L .6494 .45972 L F
.64958 .45972 m .6494 .45972 L .64896 .45876 L F
.937 .819 .702 r
.64952 .4599 m .64954 .45991 L .64957 .45972 L F
.64952 .4599 m .64957 .45972 L .64955 .45972 L F
.64773 .45698 m .64953 .45993 L .64804 .45689 L F
.059 .379 .843 r
.64948 .45988 m .6494 .45972 L .64756 .45671 L F
.64755 .4567 m .64756 .45671 L .64739 .45644 L F
.64948 .45988 m .64756 .45671 L .64755 .4567 L F
.64826 .45884 m .64881 .45878 L .64739 .45644 L F
.384 0 0 r
.64889 .45691 m .64781 .45701 L .64773 .45698 L F
.64804 .45689 m .64773 .45698 L .64742 .45688 L F
.937 .819 .702 r
.64739 .45644 m .64983 .45814 L .65053 .4539 L F
.384 0 0 r
.64889 .45691 m .64773 .45698 L .64804 .45689 L F
.937 .819 .702 r
.64739 .45644 m .64773 .45698 L .64804 .45689 L F
.492 .782 .997 r
.64739 .45644 m .64889 .45691 L .64804 .45689 L F
.79 .746 .812 r
.64739 .45644 m .64761 .45708 L .64889 .45691 L F
.64761 .45708 m .64835 .45922 L .64889 .45691 L F
.907 .895 .805 r
.65143 .45692 m .64896 .45876 L .65143 .45731 L F
.531 .369 .606 r
.64835 .45922 m .64838 .45722 L .64889 .45691 L F
.059 .379 .843 r
.64826 .45884 m .64948 .45988 L .64881 .45878 L F
.907 .895 .805 r
.64896 .45876 m .64947 .45987 L .64835 .45922 L F
.64896 .45876 m .64835 .45922 L .64912 .45874 L F
.64896 .45876 m .64912 .45874 L .65143 .45731 L F
.771 .736 .821 r
.65085 .45766 m .64835 .45922 L .64761 .45708 L F
.531 .369 .606 r
.64835 .45922 m .64507 .4592 L .64838 .45722 L F
.771 .736 .821 r
.65143 .45731 m .65085 .45766 L .64838 .45679 L F
.64838 .45665 m .64838 .45679 L .64739 .45644 L F
.65143 .45731 m .64838 .45679 L .64838 .45665 L F
.793 .697 .76 r
.64781 .45701 m .64776 .45706 L .64759 .45707 L F
.64781 .45701 m .64759 .45707 L .64747 .45705 L F
.64889 .45691 m .64811 .45737 L .64781 .45701 L F
.64811 .45737 m .64507 .4592 L .64781 .45701 L F
.771 .736 .821 r
.65085 .45766 m .64761 .45708 L .64739 .45644 L F
.793 .697 .76 r
.64747 .45705 m .64759 .45707 L .64352 .45745 L F
.64776 .45706 m .64507 .4592 L .64366 .45761 L F
.64776 .45706 m .64366 .45761 L .64352 .45745 L F
.907 .895 .805 r
.64982 .46008 m .64893 .45957 L .64835 .45922 L F
.1 .25 .731 r
.64931 .45979 m .65123 .45923 L .64893 .45957 L F
.603 .256 .355 r
.64949 .45989 m .64953 .45993 L .64948 .45988 L F
.1 .25 .731 r
.64952 .45991 m .64953 .45991 L .64931 .45979 L F
.059 .379 .843 r
.64948 .45988 m .64951 .45991 L .6494 .45972 L F
.64951 .45991 m .64953 .45993 L .64951 .4599 L F
.64951 .45991 m .64951 .4599 L .6494 .45972 L F
.1 .25 .731 r
.64953 .45991 m .65123 .45923 L .64966 .45969 L F
.64951 .4599 m .64966 .45969 L .64931 .45979 L F
.64953 .45991 m .64966 .45969 L .64951 .4599 L F
.059 .379 .843 r
.64638 .45652 m .64757 .45693 L .64739 .45644 L F
.64559 .45658 m .64757 .45693 L .64638 .45652 L F
.492 .782 .997 r
.64739 .45644 m .64742 .45688 L .64495 .45683 L F
.384 0 0 r
.64742 .45688 m .64352 .45745 L .64495 .45683 L F
.64781 .45701 m .64352 .45745 L .64742 .45688 L F
.1 .25 .731 r
.64893 .45957 m .65123 .45923 L .64835 .45922 L F
.059 .379 .843 r
.64559 .45658 m .64739 .45644 L .64638 .4566 L F
.64559 .45658 m .64638 .4566 L .64495 .45683 L F
0 .484 .765 r
.64505 .45657 m .64559 .45658 L .64299 .45602 L F
.208 0 0 r
.50389 .69669 m .50266 .69845 L .50083 .69844 L F
.3 0 0 r
.50543 .69784 m .50266 .69845 L .50389 .69669 L F
.353 0 0 r
.50632 .69653 m .50543 .69784 L .50389 .69669 L F
0 0 .203 r
.20588 .65134 m .20503 .65271 L .20636 .64917 L F
0 0 .156 r
.20588 .65134 m .20382 .65452 L .20503 .65271 L F
.668 .606 .776 r
.70039 .42368 m .69788 .42464 L .69667 .42087 L F
.607 .558 .774 r
.70137 .42731 m .69788 .42464 L .70039 .42368 L F
.987 .729 .352 r
.5561 .66597 m .55629 .66869 L .55728 .66866 L F
.956 .801 .357 r
.5562 .67115 m .55728 .66866 L .55629 .66869 L F
.5562 .67115 m .55685 .67256 L .55728 .66866 L F
.403 0 .114 r
.41433 .63514 m .41287 .63716 L .4105 .63738 L F
.39 0 .106 r
.41589 .63629 m .41433 .63514 L .41648 .63449 L F
.41589 .63629 m .41287 .63716 L .41433 .63514 L F
.878 .957 .615 r
.64711 .4633 m .64704 .4647 L .64815 .46247 L F
0 .065 .627 r
.64711 .4633 m .6485 .46669 L .64704 .4647 L F
.234 .319 .746 r
.54894 .66926 m .54819 .66601 L .54684 .66715 L F
.608 .078 0 r
.54723 .66797 m .54684 .66715 L .54588 .66965 L F
.54723 .66797 m .54894 .66926 L .54684 .66715 L F
.566 .182 .273 r
.54299 .66802 m .54588 .66965 L .54684 .66715 L F
.989 .752 .37 r
.59012 .62227 m .59097 .623 L .59033 .61991 L F
.854 .634 .095 r
.59012 .62227 m .59061 .62474 L .59097 .623 L F
.969 .875 .687 r
.66206 .45814 m .6644 .4558 L .66344 .45442 L F
.66206 .45814 m .66326 .45924 L .6644 .4558 L F
.902 .857 .788 r
.6644 .4558 m .66501 .45208 L .66344 .45442 L F
.859 .844 .829 r
.6142 .43293 m .61187 .43589 L .61053 .43451 L F
0 0 .446 r
.63094 .44139 m .63181 .44174 L .63016 .4418 L F
.237 .656 .96 r
.63148 .44164 m .63016 .4418 L .63181 .44174 L F
.62856 .44079 m .63016 .4418 L .63148 .44164 L F
.506 .911 .884 r
.62745 .44229 m .62869 .44197 L .63016 .4418 L F
.62869 .44197 m .63094 .44139 L .63016 .4418 L F
.709 .673 .813 r
.63334 .43932 m .63094 .44139 L .62981 .43778 L F
.861 .627 .582 r
.63491 .44131 m .63186 .44286 L .63094 .44139 L F
0 0 .446 r
.63094 .44139 m .63186 .44286 L .63181 .44174 L F
.69 .636 .791 r
.63334 .43932 m .63491 .44131 L .63094 .44139 L F
.751 .623 .718 r
.61088 .4619 m .61494 .45942 L .6132 .4586 L F
.471 .139 .321 r
.61312 .46275 m .61494 .45942 L .61088 .4619 L F
.603 .946 .926 r
.61312 .46275 m .61703 .46162 L .61494 .45942 L F
0 0 0 r
.48003 .6145 m .47751 .6173 L .47941 .61564 L F
.382 .093 .344 r
.47941 .61564 m .48199 .61358 L .48003 .6145 L F
.58 .305 .464 r
.62139 .45256 m .62393 .45037 L .62251 .45021 L F
.216 0 .06 r
.47751 .6173 m .47378 .61969 L .47598 .61863 L F
.386 .01 .197 r
.47598 .61863 m .47941 .61564 L .47751 .6173 L F
.767 .931 .939 r
.68012 .46067 m .6781 .46164 L .68064 .45991 L F
.733 .558 .655 r
.68012 .46067 m .67827 .4643 L .6781 .46164 L F
.68012 .46067 m .68169 .46472 L .67827 .4643 L F
.871 .837 .81 r
.69787 .45004 m .69663 .45067 L .6995 .44721 L F
.71 .393 .439 r
.69787 .45004 m .69744 .45235 L .69663 .45067 L F
.69787 .45004 m .69976 .45263 L .69744 .45235 L F
.657 .602 .781 r
.70195 .4467 m .69787 .45004 L .6995 .44721 L F
.70195 .4467 m .70321 .44956 L .69787 .45004 L F
.61 .378 .541 r
.70292 .45129 m .69787 .45004 L .70321 .44956 L F
.70292 .45129 m .69976 .45263 L .69787 .45004 L F
0 0 0 r
.58295 .6049 m .58402 .60268 L .58199 .60531 L F
.804 .713 .764 r
.58199 .60531 m .58402 .60268 L .58096 .60215 L F
.548 .162 .261 r
.58295 .6049 m .58657 .60403 L .58402 .60268 L F
.814 .688 .146 r
.59009 .63185 m .5898 .63346 L .58992 .63434 L F
.92 .879 .455 r
.59069 .62765 m .58988 .63096 L .59009 .63185 L F
.847 .686 .151 r
.58988 .63096 m .5898 .63346 L .59009 .63185 L F
.317 .112 .436 r
.37656 .60567 m .37649 .60727 L .37457 .60785 L F
.467 .372 .665 r
.37698 .61096 m .37457 .60785 L .37649 .60727 L F
.37698 .61096 m .37501 .61166 L .37457 .60785 L F
.123 0 0 r
.64409 .44844 m .64673 .44798 L .64782 .4473 L F
.612 .653 .866 r
.64782 .4473 m .65026 .44701 L .6492 .44465 L F
.353 0 0 r
.65389 .44737 m .65263 .44752 L .65026 .44701 L F
.65389 .44737 m .65263 .44752 L .65026 .44701 L F
.368 .603 .938 r
.65026 .44701 m .65152 .44513 L .6492 .44465 L F
.65026 .44701 m .65263 .44752 L .65152 .44513 L F
.65152 .44513 m .65263 .44752 L .65026 .44701 L F
.65152 .44513 m .65026 .44701 L .65038 .44867 L F
.576 .639 .877 r
.65152 .44513 m .65082 .44729 L .64811 .44468 L F
.793 .504 .498 r
.64673 .44798 m .65038 .44867 L .65026 .44701 L F
.576 .639 .877 r
.65082 .44729 m .65038 .44867 L .64966 .44741 L F
.793 .504 .498 r
.64726 .44765 m .65026 .44701 L .64782 .4473 L F
.64834 .44754 m .65026 .44701 L .64726 .44765 L F
.576 .639 .877 r
.65082 .44729 m .64966 .44741 L .64811 .44468 L F
.793 .504 .498 r
.64673 .44798 m .64834 .44754 L .64726 .44765 L F
.28 0 0 r
.39497 .58057 m .3973 .58049 L .39902 .57945 L F
0 0 0 r
.39902 .57945 m .39909 .57953 L .40126 .57898 L F
.39902 .57945 m .3973 .58049 L .39909 .57953 L F
.549 .304 .496 r
.58161 .49463 m .58394 .49639 L .58138 .49633 L F
.58161 .49463 m .58452 .4938 L .58394 .49639 L F
.369 .585 .926 r
.56431 .49359 m .56362 .49425 L .56442 .49242 L F
0 0 .106 r
.56442 .49242 m .56362 .49425 L .56338 .49653 L F
.149 .409 .854 r
.23752 .54708 m .23651 .54804 L .23488 .54646 L F
.23752 .54708 m .23861 .54908 L .23651 .54804 L F
.409 0 0 r
.36037 .58966 m .35835 .58915 L .35799 .5898 L F
.36037 .58966 m .36057 .5896 L .35835 .58915 L F
.785 .804 .867 r
.5978 .44424 m .59837 .44685 L .59516 .44664 L F
.799 .785 .84 r
.59837 .44685 m .59667 .44809 L .59516 .44664 L F
.798 .811 .862 r
.60111 .44417 m .59837 .44685 L .5978 .44424 L F
.373 .218 .539 r
.24411 .57826 m .2427 .57626 L .24437 .57559 L F
.24411 .57826 m .2426 .57891 L .2427 .57626 L F
.333 .428 .809 r
.45756 .57476 m .45635 .57651 L .45517 .57328 L F
.299 .381 .779 r
.45756 .57476 m .45899 .57904 L .45635 .57651 L F
.457 .248 .507 r
.52815 .643 m .52579 .64597 L .52595 .64359 L F
.52815 .643 m .52579 .64597 L .52595 .64359 L F
.701 .743 .883 r
.44987 .63107 m .45145 .62867 L .44875 .62846 L F
.45008 .63074 m .45295 .62957 L .45145 .62867 L F
.45016 .63093 m .45295 .62957 L .45008 .63074 L F
0 .217 .74 r
.4499 .62831 m .45101 .63052 L .4493 .62896 L F
.44906 .62842 m .4493 .62896 L .44875 .62846 L F
.4499 .62831 m .4493 .62896 L .44906 .62842 L F
.701 .743 .883 r
.44987 .63107 m .45016 .63093 L .45008 .63074 L F
.862 .825 .81 r
.57549 .47706 m .57336 .48008 L .57179 .4789 L F
.735 .24 0 r
.66649 .41219 m .66874 .41433 L .66787 .41409 L F
.323 0 0 r
.66787 .41409 m .66874 .41433 L .67028 .41504 L F
.648 .747 .922 r
.45517 .57328 m .45306 .57433 L .45153 .5726 L F
.58 .305 .464 r
.62139 .45256 m .62462 .45221 L .62393 .45037 L F
.087 0 .266 r
.47378 .61969 m .47397 .62215 L .47598 .61863 L F
.945 .787 .653 r
.64841 .43841 m .6457 .44091 L .64772 .43895 L F
.64841 .43841 m .64757 .44124 L .6457 .44091 L F
.942 .891 .49 r
.64841 .43841 m .64798 .43668 L .649 .43473 L F
.932 .85 .411 r
.64841 .43841 m .64772 .43895 L .64798 .43668 L F
.534 0 0 r
.66924 .42301 m .67351 .42465 L .67041 .4249 L F
.841 .866 .862 r
.59667 .44809 m .59298 .44964 L .59516 .44664 L F
.818 .809 .842 r
.62308 .45948 m .61932 .45907 L .62169 .45793 L F
.644 .798 .957 r
.62528 .45845 m .62308 .45948 L .62169 .45793 L F
.737 .608 .715 r
.6132 .4586 m .61626 .45589 L .61345 .45629 L F
.72 .452 .52 r
.52108 .652 m .51818 .64973 L .51895 .65069 L F
.607 .842 .988 r
.42756 .5733 m .42543 .5741 L .42389 .57306 L F
.447 .013 .121 r
.40126 .59269 m .39772 .59483 L .39903 .59338 L F
.89 .873 .814 r
.61647 .42977 m .61294 .43171 L .61525 .42832 L F
.61647 .42977 m .6142 .43293 L .61294 .43171 L F
.688 .801 .935 r
.61729 .42864 m .61647 .42977 L .61525 .42832 L F
.064 0 .403 r
.61706 .43159 m .61647 .42977 L .61729 .42864 L F
.598 .18 .221 r
.52397 .68965 m .5233 .69127 L .51993 .69051 L F
.356 0 0 r
.52641 .69007 m .5233 .69127 L .52397 .68965 L F
.604 .432 .622 r
.52665 .68743 m .52641 .69007 L .52397 .68965 L F
.18 0 0 r
.18269 .55291 m .18065 .55413 L .1784 .55449 L F
0 0 0 r
.18267 .55337 m .18065 .55413 L .18269 .55291 L F
.524 .346 .581 r
.55857 .49985 m .56087 .50169 L .56097 .49925 L F
.55857 .49985 m .56087 .50169 L .56097 .49925 L F
.206 .711 .903 r
.21352 .54334 m .21565 .54326 L .21731 .54366 L F
.497 .838 .997 r
.21565 .54326 m .21946 .54342 L .21731 .54366 L F
.615 .503 .702 r
.69663 .45067 m .69485 .45317 L .69491 .45068 L F
.427 .261 .551 r
.69663 .45067 m .69744 .45235 L .69485 .45317 L F
.794 .6 .638 r
.69744 .45235 m .69386 .45429 L .69485 .45317 L F
.376 0 0 r
.38209 .6411 m .3802 .64191 L .37808 .64162 L F
.475 0 0 r
.38461 .64113 m .38451 .64174 L .38209 .6411 L F
.623 .276 .361 r
.49933 .69548 m .50061 .69287 L .49687 .69336 L F
.549 .598 .855 r
.49878 .68994 m .50061 .69287 L .50221 .69183 L F
.028 0 .051 r
.50221 .69183 m .50061 .69287 L .49933 .69548 L F
.059 0 0 r
.41025 .5887 m .40841 .58965 L .40614 .59006 L F
0 0 0 r
.41059 .58873 m .40841 .58965 L .41025 .5887 L F
.736 .578 .678 r
.65389 .44737 m .65754 .45025 L .65498 .44745 L F
.65389 .44737 m .65404 .45034 L .65754 .45025 L F
.341 .042 .304 r
.65404 .45034 m .65575 .45059 L .65754 .45025 L F
0 .136 .658 r
.65754 .45025 m .65706 .44939 L .65498 .44745 L F
.856 .983 .855 r
.65754 .45025 m .65575 .45059 L .65706 .44939 L F
.586 .327 .491 r
.20394 .59159 m .20578 .59291 L .20609 .5908 L F
.336 .387 .766 r
.69637 .44932 m .69491 .45068 L .69352 .44732 L F
.862 .825 .81 r
.57549 .47706 m .57179 .4789 L .57384 .47577 L F
.815 .713 .752 r
.57572 .47259 m .57549 .47706 L .57384 .47577 L F
.597 .251 .354 r
.52728 .65306 m .52757 .65261 L .52472 .65237 L F
.024 .591 .784 r
.52351 .65215 m .52472 .65237 L .52108 .652 L F
.52108 .652 m .52472 .65237 L .52351 .65215 L F
.318 .723 .979 r
.52472 .65237 m .5259 .6515 L .52351 .65215 L F
.52472 .65237 m .52757 .65261 L .5259 .6515 L F
.243 .595 .95 r
.52472 .65237 m .5259 .6515 L .52351 .65215 L F
.52472 .65237 m .52728 .65306 L .5259 .6515 L F
.564 .657 .899 r
.69189 .41444 m .68951 .415 L .68857 .41307 L F
.074 0 0 r
.40126 .57898 m .40365 .57872 L .40483 .57827 L F
.392 .181 .469 r
.53212 .67272 m .52984 .67574 L .53214 .67496 L F
.413 .138 .383 r
.52984 .67574 m .53204 .67708 L .53214 .67496 L F
.52984 .67574 m .52944 .67785 L .53204 .67708 L F
.477 .23 .461 r
.19798 .62301 m .20014 .62254 L .2004 .62078 L F
.465 .28 .544 r
.2004 .62078 m .20289 .62017 L .20292 .61685 L F
.431 .191 .448 r
.2004 .62078 m .20014 .62254 L .20289 .62017 L F
.276 .727 .958 r
.18854 .5532 m .18674 .55246 L .18475 .55252 L F
.584 .33 .497 r
.58731 .49115 m .58973 .49305 L .58716 .49336 L F
.648 .293 .355 r
.58731 .49115 m .58973 .49146 L .58973 .49305 L F
.995 .757 .408 r
.67468 .45909 m .67345 .46004 L .67138 .45796 L F
.67468 .45909 m .67455 .46136 L .67345 .46004 L F
.783 .53 .554 r
.6781 .46164 m .67468 .45909 L .67747 .45835 L F
.6781 .46164 m .67455 .46136 L .67468 .45909 L F
.859 .844 .829 r
.6142 .43293 m .61053 .43451 L .61294 .43171 L F
.778 .859 .91 r
.68543 .45534 m .68673 .45663 L .689 .45535 L F
.606 .119 .072 r
.40319 .62793 m .40532 .62859 L .40673 .62802 L F
.522 .01 0 r
.40673 .62802 m .40532 .62859 L .40914 .62854 L F
.122 0 0 r
.41154 .62832 m .41374 .62772 L .41536 .62624 L F
.421 .009 .149 r
.41374 .62772 m .41743 .62538 L .41536 .62624 L F
.59 .339 .505 r
.19798 .62301 m .1952 .62557 L .19647 .62482 L F
0 0 .504 r
.19683 .62465 m .1982 .6268 L .19715 .62457 L F
0 0 0 r
.19683 .62465 m .20014 .62254 L .19798 .62301 L F
.19683 .62465 m .19751 .62461 L .20014 .62254 L F
.19683 .62465 m .19798 .62301 L .19655 .62473 L F
0 .276 .779 r
.19649 .62318 m .19751 .62461 L .19683 .62465 L F
0 0 .504 r
.19683 .62465 m .19715 .62457 L .19649 .62318 L F
0 0 0 r
.19683 .62465 m .19655 .62473 L .19647 .62482 L F
.43 .196 .455 r
.45511 .58541 m .45609 .58083 L .45424 .58152 L F
.539 .506 .768 r
.45511 .58541 m .458 .58636 L .45728 .58479 L F
.538 .521 .784 r
.70029 .4405 m .69891 .44187 L .69694 .43819 L F
.461 .275 .541 r
.34493 .5994 m .34721 .5962 L .34488 .59674 L F
.804 .713 .764 r
.58199 .60531 m .58096 .60215 L .58016 .60423 L F
.521 .527 .803 r
.52841 .65554 m .53107 .65556 L .52983 .65281 L F
.52841 .65554 m .53107 .65556 L .52983 .65281 L F
.966 .653 .265 r
.55528 .66477 m .55616 .66414 L .55458 .66286 L F
.55528 .66477 m .5561 .66597 L .55616 .66414 L F
.976 .9 .552 r
.58395 .61371 m .58354 .61699 L .58541 .61576 L F
.597 .57 .795 r
.58402 .61938 m .58541 .61576 L .58354 .61699 L F
.375 .316 .663 r
.34432 .60818 m .3456 .6044 L .3435 .60591 L F
.34432 .60818 m .3459 .60779 L .3456 .6044 L F
.373 .308 .654 r
.34432 .60818 m .3464 .61019 L .3459 .60779 L F
.393 .31 .643 r
.3449 .61062 m .3464 .61019 L .34432 .60818 L F
.35 .004 .23 r
.56648 .63765 m .56612 .6398 L .56411 .63992 L F
.42 0 .085 r
.57042 .63741 m .56612 .6398 L .56648 .63765 L F
.471 .325 .601 r
.34686 .5938 m .34926 .59556 L .34983 .59346 L F
.34686 .5938 m .34721 .5962 L .34926 .59556 L F
.493 .426 .709 r
.56239 .50806 m .5602 .50597 L .56192 .50361 L F
0 0 0 r
.56232 .50307 m .56192 .50361 L .5602 .50597 L F
.681 .471 .595 r
.56607 .50293 m .56192 .50361 L .56232 .50307 L F
.56607 .50293 m .56568 .50497 L .56192 .50361 L F
.562 .291 .462 r
.56568 .50497 m .56239 .50806 L .56192 .50361 L F
.815 .962 .905 r
.63237 .47611 m .63438 .473 L .632 .47583 L F
.63237 .47611 m .63522 .47379 L .63438 .473 L F
.469 .067 .193 r
.44437 .63096 m .44015 .63347 L .44053 .6319 L F
.44437 .63096 m .44257 .63333 L .44015 .63347 L F
.241 0 0 r
.44636 .63158 m .44257 .63333 L .44437 .63096 L F
.223 .152 .561 r
.2224 .56737 m .22391 .56353 L .22196 .56434 L F
.2224 .56737 m .22381 .56644 L .22391 .56353 L F
0 0 .41 r
.2224 .56737 m .22338 .56857 L .22381 .56644 L F
.2224 .56737 m .22253 .57001 L .22338 .56857 L F
.861 .627 .582 r
.63491 .44131 m .63542 .44428 L .63186 .44286 L F
.616 .561 .769 r
.67388 .41467 m .67489 .41839 L .67668 .41657 L F
.941 .579 .284 r
.67489 .41839 m .67524 .41855 L .67668 .41657 L F
.616 .561 .769 r
.67388 .41467 m .67668 .41657 L .67652 .4138 L F
.548 .479 .73 r
.67387 .41723 m .67018 .4165 L .67279 .41542 L F
.67203 .41687 m .67115 .41913 L .67018 .4165 L F
.67387 .41723 m .67314 .41774 L .67203 .41687 L F
.67314 .41774 m .67115 .41913 L .67203 .41687 L F
.315 .089 .403 r
.67314 .41774 m .67057 .4212 L .67115 .41913 L F
.67387 .41723 m .67333 .41789 L .67314 .41774 L F
.67333 .41789 m .67057 .4212 L .67314 .41774 L F
.486 .462 .756 r
.66772 .41728 m .67115 .41913 L .66886 .42003 L F
.116 .164 .637 r
.67057 .4212 m .66886 .42003 L .67115 .41913 L F
.507 .456 .734 r
.67018 .4165 m .67115 .41913 L .66772 .41728 L F
.847 .861 .852 r
.66936 .41995 m .67057 .4212 L .67387 .41723 L F
.66936 .41995 m .67306 .41772 L .67205 .41692 L F
.67306 .41772 m .67387 .41723 L .67205 .41692 L F
.438 .108 .307 r
.67018 .4165 m .67028 .41504 L .67279 .41542 L F
.436 .228 .498 r
.67071 .41586 m .67205 .41692 L .67071 .41585 L F
.67206 .41864 m .66936 .41995 L .67205 .41692 L F
.67206 .41864 m .67205 .41692 L .67071 .41586 L F
.608 .125 0 r
.67353 .41805 m .67437 .41875 L .67205 .41692 L F
.67394 .41836 m .6741 .4185 L .67353 .41805 L F
.6741 .4185 m .67437 .41875 L .67353 .41805 L F
.548 .479 .73 r
.67387 .41723 m .67279 .41542 L .67205 .41692 L F
.892 .776 .727 r
.67542 .41534 m .67504 .41874 L .67205 .41692 L F
.67504 .41874 m .67503 .41879 L .675 .41877 L F
.941 .579 .284 r
.67489 .41839 m .67552 .42034 L .67406 .41939 L F
.67552 .42034 m .6756 .42059 L .67546 .42048 L F
.67552 .42034 m .67546 .42048 L .67406 .41939 L F
.813 .815 .331 r
.67468 .42318 m .67416 .424 L .67452 .42253 L F
.847 .864 .416 r
.6756 .42059 m .67525 .41956 L .67406 .41939 L F
.813 .815 .331 r
.67492 .42166 m .67452 .42253 L .67525 .41956 L F
.67468 .42318 m .67452 .42253 L .67492 .42166 L F
.941 .579 .284 r
.67489 .41839 m .67456 .41879 L .67508 .4187 L F
.892 .776 .727 r
.67504 .41874 m .675 .41877 L .67205 .41692 L F
.941 .579 .284 r
.67524 .41855 m .67508 .4187 L .67544 .41864 L F
.67489 .41839 m .67508 .4187 L .67524 .41855 L F
.67456 .41879 m .67406 .41939 L .67478 .419 L F
.892 .776 .727 r
.67503 .41879 m .67483 .41904 L .67476 .41899 L F
.941 .579 .284 r
.67456 .41879 m .67476 .41899 L .67508 .4187 L F
.892 .776 .727 r
.675 .41877 m .67476 .41899 L .67205 .41692 L F
.67503 .41879 m .67476 .41899 L .675 .41877 L F
.278 .71 .967 r
.67544 .41864 m .67499 .41916 L .67504 .41874 L F
.941 .579 .284 r
.67508 .4187 m .67504 .41874 L .67544 .41864 L F
.67524 .41855 m .67607 .41759 L .67668 .41657 L F
.278 .71 .967 r
.67544 .41864 m .67504 .41874 L .67542 .41534 L F
.941 .579 .284 r
.67504 .41874 m .67478 .419 L .67544 .41864 L F
.67476 .41899 m .67478 .419 L .67508 .4187 L F
.608 .125 0 r
.67476 .41899 m .67482 .41905 L .67394 .41836 L F
.67499 .41916 m .67478 .419 L .67476 .41899 L F
.892 .776 .727 r
.67503 .41879 m .67499 .41916 L .67483 .41904 L F
.278 .71 .967 r
.67544 .41864 m .67478 .419 L .67499 .41916 L F
.67478 .419 m .67406 .41939 L .67499 .41916 L F
.608 .125 0 r
.67499 .41916 m .67483 .41905 L .67478 .419 L F
.67483 .41905 m .67482 .41905 L .67476 .41899 L F
.67482 .41905 m .67437 .41875 L .67394 .41836 L F
.941 .579 .284 r
.67524 .41855 m .67544 .41864 L .67607 .41759 L F
.265 0 0 r
.42016 .63375 m .41892 .63437 L .41648 .63449 L F
.399 0 0 r
.42239 .63406 m .41892 .63437 L .42016 .63375 L F
.652 .349 .446 r
.56607 .50293 m .56836 .50411 L .56568 .50497 L F
.56607 .50293 m .56828 .50288 L .56836 .50411 L F
.789 .628 .682 r
.6781 .46164 m .67582 .46461 L .67455 .46136 L F
.727 .537 .634 r
.67827 .4643 m .67582 .46461 L .6781 .46164 L F
.689 .626 .781 r
.68064 .45991 m .6781 .46164 L .67747 .45835 L F
.935 .558 .21 r
.5895 .60775 m .59141 .6108 L .59099 .60841 L F
.81 .864 .887 r
.65818 .43166 m .65939 .43288 L .65898 .43148 L F
.955 .612 .245 r
.65818 .43166 m .65859 .43386 L .65939 .43288 L F
.855 .405 .124 r
.65939 .43288 m .65859 .43386 L .66019 .43445 L F
.257 .052 .398 r
.22143 .62767 m .22039 .62604 L .22165 .6252 L F
.22143 .62767 m .21986 .62842 L .22039 .62604 L F
.676 .531 .681 r
.6516 .45047 m .65404 .45034 L .65389 .44737 L F
.6516 .45047 m .65404 .45034 L .65389 .44737 L F
.826 .987 .874 r
.65454 .4455 m .65263 .44752 L .65389 .44737 L F
.65454 .4455 m .65263 .44752 L .65389 .44737 L F
.508 .41 .679 r
.65404 .45034 m .65498 .44745 L .65389 .44737 L F
.414 .556 .888 r
.65389 .44737 m .65498 .44745 L .65454 .4455 L F
.674 .363 .44 r
.54319 .65628 m .54042 .65757 L .5427 .65457 L F
.54319 .65628 m .54408 .65726 L .54042 .65757 L F
.834 .718 .737 r
.54295 .65201 m .54319 .65628 L .5427 .65457 L F
.571 .583 .826 r
.69557 .41728 m .69314 .41783 L .69189 .41444 L F
.675 .24 .208 r
.43553 .62714 m .43927 .62757 L .43709 .62568 L F
.668 .224 .188 r
.43553 .62714 m .43795 .629 L .43927 .62757 L F
0 .18 .678 r
.43567 .62678 m .43756 .62862 L .43553 .62714 L F
.43756 .62862 m .43795 .629 L .43553 .62714 L F
.597 .143 .144 r
.43355 .62568 m .43553 .62714 L .43709 .62568 L F
.43313 .62568 m .43553 .62714 L .43355 .62568 L F
.685 .224 .153 r
.43709 .62568 m .43927 .62757 L .43953 .62655 L F
.389 .417 .769 r
.37501 .61166 m .37763 .61328 L .37568 .61366 L F
.233 .104 .491 r
.37763 .61328 m .37611 .61592 L .37568 .61366 L F
.833 .48 0 r
.20292 .61685 m .20219 .61609 L .20158 .61369 L F
.324 .169 .511 r
.20292 .61685 m .20289 .62017 L .20374 .61866 L F
.929 .568 .149 r
.20374 .61866 m .20219 .61609 L .20292 .61685 L F
.778 .859 .91 r
.68543 .45534 m .689 .45535 L .68816 .45368 L F
.585 .806 .984 r
.68816 .45368 m .689 .45535 L .69273 .45413 L F
.445 0 .047 r
.36872 .58668 m .37112 .58672 L .37265 .5851 L F
.424 0 .084 r
.37112 .58672 m .37493 .58483 L .37265 .5851 L F
.425 .062 .243 r
.35184 .59268 m .35465 .59074 L .35269 .59115 L F
0 0 .329 r
.64202 .44467 m .64119 .4468 L .641 .44413 L F
.814 .981 .697 r
.64202 .44467 m .64123 .44571 L .64119 .4468 L F
0 0 .094 r
.641 .44413 m .64119 .4468 L .64118 .44731 L F
.814 .981 .697 r
.64123 .44571 m .63972 .44768 L .64119 .4468 L F
0 0 .094 r
.64118 .44731 m .64119 .4468 L .64121 .44791 L F
0 0 .362 r
.64119 .4468 m .64163 .44958 L .64121 .44791 L F
.61 .275 .377 r
.6516 .45047 m .65373 .45196 L .65404 .45034 L F
.605 .279 .391 r
.65373 .45196 m .65118 .45271 L .6516 .45047 L F
.61 .275 .377 r
.6516 .45047 m .65373 .45196 L .65404 .45034 L F
.338 0 0 r
.6448 .4632 m .64711 .4633 L .64814 .46247 L F
.396 .68 .975 r
.64593 .4619 m .64711 .4633 L .6448 .4632 L F
.489 .733 .98 r
.6485 .46165 m .64711 .4633 L .64593 .4619 L F
.956 .677 .468 r
.6459 .46429 m .64711 .4633 L .6485 .46165 L F
.64558 .46461 m .64711 .4633 L .6459 .46429 L F
.338 0 0 r
.64814 .46247 m .64711 .4633 L .64815 .46247 L F
.569 .634 .876 r
.46919 .72026 m .47321 .72266 L .47111 .72115 L F
0 0 .092 r
.47321 .72266 m .47405 .71892 L .47213 .72037 L F
.409 .236 .534 r
.47234 .72051 m .47111 .72115 L .47405 .71892 L F
.084 .269 .755 r
.47095 .7167 m .47234 .72051 L .47269 .71844 L F
.47015 .71591 m .47184 .71945 L .47095 .7167 L F
.47184 .71945 m .47234 .72051 L .47095 .7167 L F
0 0 .092 r
.47277 .72235 m .47213 .72037 L .47111 .72115 L F
.47321 .72266 m .47213 .72037 L .47277 .72235 L F
.365 .049 .291 r
.53212 .67272 m .53417 .67235 L .53518 .67035 L F
0 0 .058 r
.53518 .67035 m .53417 .67235 L .53661 .66917 L F
.549 .368 .589 r
.55536 .61126 m .55791 .61086 L .55556 .61402 L F
.945 .673 .49 r
.55536 .61126 m .55556 .61402 L .55389 .61263 L F
.55389 .61263 m .55556 .61402 L .55536 .61126 L F
.549 .368 .589 r
.55556 .61402 m .55791 .61086 L .55536 .61126 L F
.193 0 .169 r
.53346 .68868 m .53232 .68721 L .53476 .68703 L F
.53346 .68868 m .53157 .68955 L .53232 .68721 L F
.565 .824 .994 r
.56007 .63075 m .55909 .63176 L .55557 .6308 L F
.114 .66 .824 r
.51938 .70489 m .5178 .70462 L .51696 .70473 L F
.45 .873 .931 r
.52168 .70358 m .5178 .70462 L .51938 .70489 L F
0 .077 .632 r
.62061 .43763 m .62137 .43999 L .62023 .43811 L F
.577 .546 .783 r
.24846 .5638 m .24621 .56456 L .24499 .56118 L F
.294 .265 .655 r
.24819 .56611 m .24621 .56456 L .24846 .5638 L F
.24819 .56611 m .2468 .56739 L .24621 .56456 L F
.836 .654 .657 r
.61206 .45477 m .61345 .45629 L .612 .45253 L F
.803 .661 .707 r
.60964 .45813 m .61345 .45629 L .61206 .45477 L F
.60964 .45813 m .6132 .4586 L .61345 .45629 L F
.771 .682 .765 r
.19836 .61158 m .19992 .60785 L .20142 .61124 L F
.918 .574 .117 r
.19992 .60785 m .20074 .61096 L .20142 .61124 L F
.824 1 .801 r
.20074 .61096 m .19971 .61194 L .20142 .61124 L F
.591 .406 .599 r
.20142 .61124 m .20158 .61369 L .20393 .61159 L F
0 0 0 r
.46424 .62857 m .46251 .6311 L .46353 .63068 L F
0 .14 .672 r
.46353 .63068 m .46251 .6311 L .46379 .63201 L F
.593 .305 .448 r
.56828 .50288 m .57068 .50477 L .56836 .50411 L F
.587 .308 .46 r
.56828 .50288 m .57107 .5027 L .57068 .50477 L F
.497 .515 .806 r
.2207 .56194 m .22196 .56434 L .22391 .56353 L F
.64 .822 .97 r
.20578 .59291 m .20812 .59032 L .20609 .5908 L F
.854 .634 .095 r
.59012 .62227 m .59058 .62539 L .59061 .62474 L F
0 0 .18 r
.59058 .62539 m .59069 .62765 L .59061 .62474 L F
.442 .517 .84 r
.37542 .64153 m .37692 .63939 L .37426 .63985 L F
.37542 .64153 m .37808 .64162 L .37692 .63939 L F
.981 .857 .644 r
.53858 .64593 m .53866 .64946 L .53729 .64906 L F
.954 .622 .221 r
.53866 .64946 m .53827 .6504 L .53729 .64906 L F
.53866 .64946 m .5391 .65182 L .53827 .6504 L F
.728 .673 .795 r
.54118 .64707 m .53866 .64946 L .53858 .64593 L F
.796 .69 .748 r
.61088 .4619 m .6132 .4586 L .60964 .45813 L F
.163 0 .302 r
.20796 .64814 m .20588 .65134 L .20636 .64917 L F
.656 .504 .666 r
.53214 .67496 m .53417 .67235 L .53212 .67272 L F
.664 .761 .922 r
.6544 .42386 m .6523 .42257 L .65365 .42268 L F
.891 .561 .066 r
.65365 .42268 m .65497 .42615 L .6544 .42386 L F
.555 .348 .554 r
.21143 .64342 m .21122 .64591 L .2086 .6461 L F
.276 0 .165 r
.21122 .64591 m .20796 .64814 L .2086 .6461 L F
.544 .354 .574 r
.54482 .70476 m .54234 .70767 L .54223 .70495 L F
.54223 .70495 m .54234 .70767 L .54482 .70476 L F
.42 0 .085 r
.57042 .63741 m .56948 .63931 L .56612 .6398 L F
.991 .739 .383 r
.56932 .63636 m .56948 .63931 L .57042 .63741 L F
0 0 0 r
.49687 .69336 m .49404 .69585 L .49672 .69565 L F
.623 .276 .361 r
.49933 .69548 m .49687 .69336 L .49672 .69565 L F
.238 .133 .527 r
.23611 .59832 m .2348 .59659 L .23663 .59585 L F
.23611 .59832 m .2349 .59916 L .2348 .59659 L F
.347 0 0 r
.18189 .54232 m .18412 .54244 L .18603 .54144 L F
.357 0 0 r
.18603 .54144 m .18412 .54244 L .18794 .54188 L F
.86 .463 0 r
.66381 .42703 m .66351 .42776 L .66298 .42575 L F
.66381 .42703 m .66454 .42896 L .66351 .42776 L F
.634 .679 .875 r
.5833 .64128 m .58606 .64055 L .58224 .63952 L F
.751 .721 .824 r
.696 .44765 m .69725 .44802 L .6995 .44721 L F
.75 .622 .717 r
.6995 .44721 m .69663 .45067 L .696 .44765 L F
.628 .95 .76 r
.62065 .44765 m .62195 .44669 L .62214 .44603 L F
.623 .95 .768 r
.62214 .44603 m .62195 .44669 L .62531 .44405 L F
.603 .562 .781 r
.34476 .62537 m .34568 .62905 L .34794 .62777 L F
.966 .877 .694 r
.66223 .46107 m .66326 .45924 L .66206 .45814 L F
.712 .983 .898 r
.62738 .43829 m .62366 .43993 L .62646 .4376 L F
.571 .738 .955 r
.62892 .4363 m .62738 .43829 L .62646 .4376 L F
.62892 .4363 m .62981 .43778 L .62738 .43829 L F
.202 .495 .903 r
.68149 .45571 m .68159 .45206 L .6792 .45313 L F
.68149 .45571 m .68175 .45459 L .68159 .45206 L F
.68149 .45571 m .68312 .45668 L .68175 .45459 L F
.356 0 .113 r
.38764 .64005 m .38451 .64174 L .38461 .64113 L F
.598 .521 .738 r
.70396 .42621 m .70137 .42731 L .70039 .42368 L F
.626 .503 .693 r
.70419 .42889 m .70137 .42731 L .70396 .42621 L F
.70419 .42889 m .70167 .42954 L .70137 .42731 L F
.344 .193 .528 r
.24599 .56939 m .24425 .57245 L .24463 .57023 L F
0 .049 .616 r
.50951 .68386 m .51075 .68643 L .51064 .68534 L F
.783 .599 .651 r
.64818 .42599 m .6478 .42323 L .64898 .42403 L F
.64818 .42599 m .64526 .42534 L .6478 .42323 L F
.64818 .42599 m .64694 .42693 L .64526 .42534 L F
.443 .348 .653 r
.65145 .42789 m .64942 .42962 L .64818 .42599 L F
.64818 .42599 m .64942 .42962 L .65145 .42789 L F
.402 .012 .18 r
.36037 .58966 m .36406 .58703 L .36057 .5896 L F
.36037 .58966 m .36268 .58931 L .36406 .58703 L F
.418 .012 .159 r
.36268 .58931 m .36636 .58695 L .36406 .58703 L F
.448 .162 .385 r
.49228 .72859 m .49191 .73074 L .49444 .73001 L F
.526 .227 .403 r
.49228 .72859 m .49349 .72864 L .49535 .72722 L F
.497 .126 .266 r
.49228 .72859 m .49444 .73001 L .49349 .72864 L F
.478 .379 .665 r
.49391 .68845 m .49303 .69039 L .49104 .6882 L F
.49303 .69039 m .4929 .69067 L .49269 .6904 L F
.652 .39 .51 r
.49183 .68906 m .4886 .69079 L .48733 .69093 L F
.49183 .68906 m .489 .69233 L .48682 .69174 L F
.478 .379 .665 r
.49303 .69039 m .49269 .6904 L .49104 .6882 L F
.969 .674 .411 r
.49063 .69045 m .49132 .69152 L .489 .69233 L F
.49183 .68906 m .49154 .69043 L .49063 .69045 L F
.49154 .69043 m .49132 .69152 L .49063 .69045 L F
.49132 .69152 m .49124 .69187 L .49077 .69197 L F
.49132 .69152 m .49077 .69197 L .489 .69233 L F
0 0 .43 r
.4929 .69067 m .49279 .69072 L .49183 .68906 L F
.969 .674 .411 r
.49183 .68906 m .49279 .69072 L .49134 .6918 L F
.49132 .69152 m .49134 .6918 L .49124 .69187 L F
.49183 .68906 m .49134 .6918 L .49132 .69152 L F
0 0 .43 r
.49093 .68919 m .49183 .68906 L .49075 .68873 L F
.4929 .69067 m .49199 .68931 L .49082 .6892 L F
.49199 .68931 m .49183 .68906 L .49082 .6892 L F
.4929 .69067 m .48971 .68841 L .49094 .68953 L F
.645 .419 .562 r
.49104 .6882 m .49269 .6904 L .49114 .68954 L F
.49104 .6882 m .49114 .68954 L .49103 .68826 L F
.504 .301 .537 r
.489 .69233 m .49055 .68918 L .4903 .68915 L F
.645 .419 .562 r
.49269 .6904 m .49258 .69049 L .4903 .68915 L F
0 0 .43 r
.49094 .68953 m .48971 .68841 L .48829 .68797 L F
.645 .419 .562 r
.49034 .6891 m .4903 .68915 L .48829 .68797 L F
.49269 .6904 m .4903 .68915 L .49034 .6891 L F
.504 .301 .537 r
.48865 .69131 m .4903 .68915 L .48782 .68893 L F
.489 .69233 m .4903 .68915 L .48865 .69131 L F
0 0 .352 r
.49104 .6882 m .49112 .68969 L .49229 .69053 L F
.49112 .68969 m .49124 .69187 L .49173 .69125 L F
.49112 .68969 m .49173 .69125 L .49229 .69053 L F
0 0 .43 r
.49082 .6892 m .49093 .68919 L .48971 .68841 L F
.49093 .68919 m .49075 .68873 L .48971 .68841 L F
.504 .301 .537 r
.49055 .68918 m .49104 .6882 L .4903 .68915 L F
.49055 .68918 m .49094 .68953 L .49104 .6882 L F
.645 .419 .562 r
.49104 .6882 m .49095 .68944 L .49034 .6891 L F
.49104 .6882 m .49034 .6891 L .48829 .68797 L F
.504 .301 .537 r
.4903 .68915 m .49104 .6882 L .48782 .68893 L F
.48782 .68893 m .49104 .6882 L .48778 .6888 L F
.645 .419 .562 r
.49103 .68826 m .49114 .68954 L .49095 .68944 L F
.504 .301 .537 r
.49002 .69025 m .49092 .68991 L .49094 .68953 L F
.49002 .69025 m .49094 .68953 L .49055 .68918 L F
.49092 .68991 m .49113 .68983 L .49104 .6882 L F
.645 .419 .562 r
.49269 .6904 m .4929 .69067 L .49258 .69049 L F
.504 .301 .537 r
.489 .69233 m .49124 .69187 L .49113 .68983 L F
.489 .69233 m .49113 .68983 L .49002 .69025 L F
.652 .39 .51 r
.4886 .69079 m .48682 .69174 L .48705 .69137 L F
.4886 .69079 m .48705 .69137 L .48733 .69093 L F
0 0 0 r
.21377 .64046 m .2129 .64252 L .21143 .64342 L F
0 0 .162 r
.2129 .64252 m .21122 .64591 L .21143 .64342 L F
.614 .045 0 r
.52665 .68743 m .52547 .68729 L .52312 .686 L F
.989 .795 .553 r
.52547 .68729 m .52665 .68743 L .52312 .686 L F
.52547 .68729 m .52641 .69007 L .52665 .68743 L F
.751 .981 .913 r
.52711 .68598 m .52547 .68729 L .52665 .68743 L F
.989 .795 .553 r
.52665 .68743 m .52547 .68729 L .52711 .68598 L F
.52665 .68743 m .52641 .69007 L .52547 .68729 L F
.615 .669 .879 r
.43821 .57965 m .44226 .58202 L .44089 .57868 L F
.724 .669 .795 r
.44089 .57868 m .44226 .58202 L .44496 .58084 L F
.103 .624 .883 r
.21946 .54342 m .22158 .54362 L .2232 .54421 L F
.63 .408 .563 r
.59808 .48761 m .59692 .49023 L .59557 .48805 L F
.369 0 .105 r
.62068 .48118 m .62441 .47879 L .62313 .48073 L F
.288 0 0 r
.62441 .47879 m .6252 .47994 L .62313 .48073 L F
.62441 .47879 m .62664 .47847 L .6252 .47994 L F
.606 .436 .626 r
.54052 .6698 m .54391 .6704 L .54349 .66888 L F
.339 0 0 r
.5389 .66743 m .54019 .66805 L .54299 .66802 L F
.54019 .66805 m .54078 .6682 L .54299 .66802 L F
.145 .362 .818 r
.54423 .66646 m .54299 .66802 L .54054 .66822 L F
.54423 .66646 m .54588 .66965 L .54299 .66802 L F
.821 .734 .769 r
.54423 .66646 m .54054 .66822 L .54038 .66766 L F
.606 .436 .626 r
.5417 .66843 m .54349 .66888 L .54296 .66696 L F
.54052 .6698 m .54349 .66888 L .5417 .66843 L F
.339 0 0 r
.54019 .66805 m .54054 .66822 L .54078 .6682 L F
.706 .9 .966 r
.54346 .68321 m .54216 .6821 L .54075 .68441 L F
0 0 0 r
.54075 .68441 m .54116 .68421 L .54314 .68617 L F
.54075 .68441 m .54216 .6821 L .54116 .68421 L F
.024 0 .135 r
.20666 .60844 m .20603 .61056 L .20851 .60701 L F
.82 .342 .041 r
.5824 .61186 m .58194 .61283 L .5819 .61038 L F
.5824 .61186 m .58395 .61371 L .58194 .61283 L F
.675 .357 .429 r
.43927 .62757 m .44273 .62536 L .43953 .62655 L F
.43927 .62757 m .44134 .62808 L .44273 .62536 L F
.532 .152 .266 r
.44134 .62808 m .44498 .6261 L .44273 .62536 L F
.538 .521 .784 r
.70029 .4405 m .69694 .43819 L .70132 .4386 L F
.653 .157 0 r
.66019 .43445 m .66164 .43628 L .66174 .43607 L F
.99 .747 .373 r
.66103 .43977 m .66174 .43607 L .66164 .43628 L F
.66103 .43977 m .66192 .4409 L .66174 .43607 L F
.274 .759 .664 r
.41939 .57456 m .42004 .57428 L .42157 .5738 L F
.41939 .57456 m .41788 .57516 L .42004 .57428 L F
.587 .219 .311 r
.41833 .58422 m .41446 .58656 L .41525 .58529 L F
.41833 .58422 m .41705 .58688 L .41446 .58656 L F
.634 .269 .334 r
.42083 .58594 m .41833 .58422 L .42031 .58457 L F
.42083 .58594 m .41705 .58688 L .41833 .58422 L F
.64 .822 .97 r
.20578 .59291 m .20953 .59332 L .20812 .59032 L F
.597 .586 .811 r
.20812 .59032 m .20953 .59332 L .212 .59284 L F
.274 .334 .744 r
.20953 .59332 m .2118 .59541 L .212 .59284 L F
.757 .672 .769 r
.62469 .41434 m .62592 .41786 L .6222 .41675 L F
.181 .301 .751 r
.62447 .41886 m .6222 .41675 L .62592 .41786 L F
0 0 0 r
.62553 .41702 m .62551 .4169 L .62649 .41535 L F
.934 .959 .652 r
.62447 .41886 m .62592 .41786 L .62551 .4169 L F
0 0 0 r
.62447 .41886 m .62551 .4169 L .62553 .41702 L F
.716 .4 0 r
.62469 .41434 m .62547 .41658 L .62551 .4169 L F
.62547 .41658 m .62592 .41786 L .62551 .4169 L F
.524 .85 .997 r
.62592 .41786 m .62833 .41722 L .62551 .4169 L F
.414 .451 .79 r
.38243 .6013 m .38457 .60229 L .38244 .60238 L F
.292 0 .105 r
.38457 .60229 m .38136 .60442 L .38244 .60238 L F
.747 .79 .888 r
.56209 .63065 m .56271 .63191 L .56007 .63075 L F
.507 .661 .93 r
.56428 .63033 m .56271 .63191 L .56209 .63065 L F
.388 .466 .819 r
.56428 .63033 m .56567 .63316 L .56271 .63191 L F
.555 .389 .611 r
.50459 .67268 m .50704 .67275 L .50626 .66982 L F
.423 .26 .553 r
.22807 .61095 m .2281 .61352 L .22625 .61411 L F
.384 .209 .516 r
.22782 .61584 m .22625 .61411 L .2281 .61352 L F
.22782 .61584 m .22607 .61651 L .22625 .61411 L F
0 0 .252 r
.2153 .63698 m .21494 .63953 L .21377 .64046 L F
0 0 0 r
.21414 .64162 m .21377 .64046 L .21494 .63953 L F
.21414 .64162 m .2129 .64252 L .21377 .64046 L F
.47 .209 .436 r
.50986 .66978 m .50946 .66721 L .50626 .66982 L F
.515 .365 .615 r
.50626 .66982 m .5095 .67193 L .50986 .66978 L F
.50626 .66982 m .50704 .67275 L .5095 .67193 L F
.791 .801 .311 r
.67088 .4483 m .67151 .44694 L .67069 .44962 L F
.944 .857 .431 r
.67176 .44367 m .67151 .44694 L .67123 .44596 L F
.91 .789 .308 r
.67123 .44596 m .67151 .44694 L .67088 .4483 L F
0 0 .037 r
.63522 .47379 m .63636 .47088 L .63601 .4713 L F
0 0 0 r
.63551 .4719 m .63601 .4713 L .63762 .47016 L F
.715 .98 .776 r
.63279 .4737 m .63438 .473 L .63601 .4713 L F
0 0 0 r
.63479 .47249 m .63601 .4713 L .63551 .4719 L F
0 0 .037 r
.63636 .47088 m .63669 .47003 L .63601 .4713 L F
.785 .957 .924 r
.63438 .473 m .63522 .47379 L .63601 .4713 L F
0 .473 .738 r
.22933 .54565 m .23111 .54602 L .233 .54654 L F
.406 .793 .99 r
.23111 .54602 m .23488 .54646 L .233 .54654 L F
.48 .091 .223 r
.61288 .48373 m .61239 .48248 L .6148 .48348 L F
.486 .05 .137 r
.6148 .48348 m .61239 .48248 L .61579 .48194 L F
.375 .117 .39 r
.4979 .73305 m .49624 .7315 L .49821 .73056 L F
.4979 .73305 m .49573 .73364 L .49624 .7315 L F
.761 .644 .732 r
.42457 .58498 m .42187 .58783 L .42031 .58457 L F
.247 0 .243 r
.42396 .58644 m .42187 .58783 L .42457 .58498 L F
.64 .271 .329 r
.52034 .71013 m .52385 .70902 L .52069 .70813 L F
.52034 .71013 m .52424 .71021 L .52385 .70902 L F
.854 .523 .426 r
.58658 .60668 m .5886 .6049 L .58657 .60403 L F
.58658 .60668 m .5895 .60775 L .5886 .6049 L F
.566 .317 .498 r
.2349 .59916 m .23431 .60145 L .23238 .59954 L F
.427 .313 .622 r
.23238 .59954 m .23431 .60145 L .23254 .6021 L F
.566 .317 .498 r
.2349 .59916 m .23431 .60145 L .23238 .59954 L F
.859 .798 .789 r
.56087 .50169 m .56232 .50307 L .5602 .50597 L F
.826 .682 .704 r
.56097 .49925 m .56232 .50307 L .56087 .50169 L F
.508 .41 .679 r
.65404 .45034 m .65706 .44939 L .65498 .44745 L F
.341 .042 .304 r
.65575 .45059 m .65404 .45034 L .65706 .44939 L F
.65575 .45059 m .65373 .45196 L .65404 .45034 L F
.65404 .45034 m .65373 .45196 L .65575 .45059 L F
.209 0 .204 r
.61803 .44878 m .61906 .44835 L .61846 .44796 L F
.686 .98 .865 r
.61701 .44959 m .62026 .44785 L .61906 .44835 L F
.209 0 .204 r
.61605 .45253 m .61701 .44959 L .61906 .44835 L F
.61605 .45253 m .61906 .44835 L .61803 .44878 L F
.686 .98 .865 r
.62026 .44785 m .62065 .44765 L .61906 .44835 L F
.629 .952 .766 r
.61906 .44835 m .62065 .44765 L .62214 .44603 L F
.852 .86 .846 r
.55409 .69106 m .55275 .6893 L .55 .69204 L F
.765 .841 .909 r
.55409 .69106 m .55571 .68925 L .55275 .6893 L F
.87 .751 .729 r
.35046 .6282 m .35396 .62579 L .35287 .62568 L F
0 0 .477 r
.35396 .62579 m .35472 .62524 L .35287 .62568 L F
.35396 .62579 m .35529 .62799 L .35472 .62524 L F
.35396 .62579 m .3555 .62917 L .35529 .62799 L F
.478 .402 .693 r
.37698 .61096 m .37763 .61328 L .37501 .61166 L F
.754 .843 .918 r
.70667 .43778 m .70325 .43795 L .70532 .43666 L F
.594 .645 .87 r
.70786 .43429 m .70667 .43778 L .70532 .43666 L F
.70786 .43429 m .70948 .43738 L .70667 .43778 L F
.924 .588 .132 r
.66224 .44382 m .66299 .44402 L .66205 .44276 L F
.66224 .44382 m .66342 .44653 L .66299 .44402 L F
.962 .647 .245 r
.66423 .44926 m .66299 .44402 L .66342 .44653 L F
.668 .606 .776 r
.70039 .42368 m .69667 .42087 L .69923 .42014 L F
.67 .621 .791 r
.70308 .42306 m .70039 .42368 L .69923 .42014 L F
.598 .521 .738 r
.70396 .42621 m .70039 .42368 L .70308 .42306 L F
.641 .586 .778 r
.70672 .43152 m .70167 .42954 L .70419 .42889 L F
.459 .459 .771 r
.48368 .68934 m .48381 .6914 L .48682 .69174 L F
.207 0 .313 r
.22389 .62216 m .22165 .6252 L .22231 .62299 L F
.532 .216 .379 r
.50052 .70089 m .49798 .69949 L .50083 .69844 L F
.50052 .70089 m .49768 .70129 L .49798 .69949 L F
.421 0 0 r
.52254 .71136 m .52149 .7119 L .51918 .71145 L F
.457 .858 .675 r
.52424 .71021 m .52149 .7119 L .52254 .71136 L F
.809 .696 .741 r
.60751 .461 m .61088 .4619 L .60964 .45813 L F
.806 .424 .333 r
.61055 .46319 m .61088 .4619 L .60751 .461 L F
.479 .101 .245 r
.61312 .46275 m .61088 .4619 L .61055 .46319 L F
.606 .345 .495 r
.49535 .72722 m .49827 .72757 L .49782 .72664 L F
.49535 .72722 m .49349 .72864 L .49827 .72757 L F
.429 .692 .974 r
.49827 .72757 m .49535 .72722 L .49782 .72664 L F
.53 .249 .434 r
.51173 .66889 m .50946 .66721 L .50986 .66978 L F
.547 .241 .4 r
.51173 .66889 m .51156 .66702 L .50946 .66721 L F
.713 .779 .904 r
.67241 .40718 m .6693 .40655 L .67142 .40529 L F
.595 .658 .881 r
.67389 .40458 m .67241 .40718 L .67142 .40529 L F
.67389 .40458 m .6748 .40653 L .67241 .40718 L F
.375 .096 .357 r
.63891 .46443 m .64121 .46487 L .64206 .46361 L F
.108 .659 .701 r
.64368 .46336 m .6437 .46336 L .64206 .46361 L F
0 0 0 r
.64121 .46487 m .64368 .46336 L .64206 .46361 L F
.754 .881 .937 r
.6414 .46189 m .64368 .46336 L .64121 .46487 L F
.395 0 0 r
.64366 .46336 m .64368 .46336 L .6414 .46189 L F
.64558 .46461 m .64368 .46336 L .64366 .46336 L F
.108 .659 .701 r
.64368 .46336 m .6448 .4632 L .6437 .46336 L F
.414 .245 .542 r
.23254 .6021 m .2325 .60457 L .23056 .60515 L F
.217 0 .305 r
.2325 .60457 m .23021 .60749 L .23056 .60515 L F
.58 .066 0 r
.43556 .57312 m .43969 .57328 L .43758 .57424 L F
.724 .669 .795 r
.44089 .57868 m .44496 .58084 L .44363 .57802 L F
.588 .615 .846 r
.44363 .57802 m .44496 .58084 L .44636 .57953 L F
.535 .482 .743 r
.44496 .58084 m .44714 .58083 L .44636 .57953 L F
.024 0 0 r
.46424 .62857 m .46593 .62784 L .46717 .62632 L F
0 0 0 r
.4684 .62409 m .46717 .62632 L .46844 .6245 L F
.46593 .62784 m .46844 .6245 L .46717 .62632 L F
.898 .644 .546 r
.63581 .46306 m .63786 .4616 L .63759 .46097 L F
.63581 .46306 m .63891 .46443 L .63786 .4616 L F
.672 .679 .849 r
.44714 .58083 m .44666 .58286 L .45048 .58139 L F
.539 .475 .732 r
.57308 .62795 m .57049 .6261 L .57112 .62871 L F
.57308 .62795 m .5734 .6258 L .57049 .6261 L F
.687 .328 .361 r
.44053 .6319 m .43661 .63355 L .43682 .63142 L F
.44053 .6319 m .44015 .63347 L .43661 .63355 L F
.538 .282 .475 r
.48721 .70519 m .48983 .7047 L .48938 .70706 L F
0 .141 .664 r
.48603 .70369 m .48721 .70519 L .48938 .70706 L F
.604 .878 .992 r
.19823 .55559 m .19492 .55479 L .19464 .5559 L F
.46 .832 .991 r
.19844 .55455 m .19823 .55559 L .20032 .55489 L F
.19844 .55455 m .19492 .55479 L .19823 .55559 L F
.701 .469 .57 r
.51608 .72985 m .51976 .72824 L .51615 .72781 L F
.51608 .72985 m .52005 .73129 L .51976 .72824 L F
.766 .764 .851 r
.6084 .45226 m .612 .45253 L .61062 .44972 L F
.811 .634 .663 r
.60823 .45498 m .612 .45253 L .6084 .45226 L F
.60823 .45498 m .61206 .45477 L .612 .45253 L F
.695 .733 .88 r
.61062 .44972 m .612 .45253 L .61437 .451 L F
.578 .143 .18 r
.68169 .46472 m .67831 .46618 L .67827 .4643 L F
.68169 .46472 m .68085 .46652 L .67831 .46618 L F
.46 .027 .129 r
.68409 .46569 m .68085 .46652 L .68169 .46472 L F
.46 .031 .137 r
.68405 .46446 m .68409 .46569 L .68169 .46472 L F
.432 0 0 r
.38294 .58334 m .38539 .58345 L .38708 .58198 L F
.29 0 0 r
.38539 .58345 m .38936 .58148 L .38708 .58198 L F
.648 .24 0 r
.6662 .43227 m .66674 .43338 L .66523 .43101 L F
.6662 .43227 m .66752 .43465 L .66674 .43338 L F
.386 0 0 r
.42142 .62532 m .41743 .62538 L .41941 .62508 L F
.097 0 0 r
.4196 .62766 m .42142 .62532 L .41941 .62508 L F
.4196 .62766 m .42358 .62723 L .42142 .62532 L F
.675 .272 .273 r
.42358 .62723 m .42372 .62697 L .42142 .62532 L F
.686 .939 .964 r
.66609 .41662 m .66221 .41766 L .6642 .41595 L F
.286 .395 .799 r
.66704 .41534 m .66609 .41662 L .6642 .41595 L F
.66704 .41534 m .66772 .41728 L .66609 .41662 L F
.459 .161 .372 r
.38933 .59638 m .3857 .59976 L .38696 .59628 L F
.289 0 0 r
.17323 .54314 m .17597 .54269 L .17401 .54264 L F
.176 0 .093 r
.51402 .68923 m .51548 .68926 L .51686 .68791 L F
.771 .364 .28 r
.51548 .68926 m .51891 .69014 L .51686 .68791 L F
.884 .693 .64 r
.51891 .69014 m .52006 .68748 L .51686 .68791 L F
.586 .866 .995 r
.36116 .63282 m .36448 .63279 L .36263 .6323 L F
.172 0 0 r
.36746 .63301 m .36263 .6323 L .36448 .63279 L F
.494 0 0 r
.63989 .46722 m .64063 .46795 L .6397 .46802 L F
.626 .817 .974 r
.44554 .57261 m .4432 .57337 L .44187 .57221 L F
.904 .5 .103 r
.67076 .44119 m .67025 .44227 L .67039 .43992 L F
.67076 .44119 m .67176 .44367 L .67025 .44227 L F
.428 0 .016 r
.61579 .48194 m .61722 .48318 L .6148 .48348 L F
.61579 .48194 m .61822 .48179 L .61722 .48318 L F
.527 .296 .508 r
.21412 .5875 m .2164 .58714 L .21685 .58457 L F
.34 .448 .825 r
.21685 .58457 m .21654 .58012 L .21428 .58224 L F
.21685 .58457 m .21811 .58387 L .21654 .58012 L F
.138 0 .362 r
.21685 .58457 m .21785 .58599 L .21811 .58387 L F
.21685 .58457 m .2164 .58714 L .21785 .58599 L F
0 0 0 r
.20155 .65746 m .19956 .66041 L .20098 .65798 L F
.202 .329 .77 r
.64145 .43789 m .64427 .44014 L .64277 .44072 L F
.672 .269 .273 r
.64485 .44101 m .64277 .44072 L .64427 .44014 L F
.64579 .44241 m .64372 .44125 L .64485 .44101 L F
.64372 .44125 m .64277 .44072 L .64485 .44101 L F
.861 .536 .436 r
.64757 .44124 m .64579 .44241 L .6457 .44091 L F
.672 .269 .273 r
.64579 .44241 m .64284 .44233 L .64277 .44072 L F
.64284 .44233 m .64195 .4423 L .64219 .44186 L F
.64284 .44233 m .64219 .44186 L .64277 .44072 L F
.55 .184 .3 r
.64579 .44241 m .64202 .44467 L .64195 .4423 L F
.64579 .44241 m .64428 .4447 L .64202 .44467 L F
.597 .344 .505 r
.64202 .44467 m .64428 .4447 L .64406 .4432 L F
.6434 .44273 m .64406 .4432 L .64389 .44204 L F
.64202 .44467 m .64406 .4432 L .6434 .44273 L F
.928 .722 .604 r
.6457 .44091 m .64579 .44241 L .64485 .44101 L F
.64508 .44058 m .64485 .44101 L .64427 .44014 L F
.6457 .44091 m .64485 .44101 L .64508 .44058 L F
.023 0 .439 r
.64444 .44178 m .64607 .44249 L .64698 .44057 L F
.64389 .44204 m .64426 .44212 L .64444 .44178 L F
.64426 .44212 m .64607 .44249 L .64444 .44178 L F
.64536 .44091 m .64698 .44057 L .64768 .43912 L F
.64389 .44204 m .64698 .44057 L .64536 .44091 L F
.718 .653 .783 r
.64327 .43976 m .64389 .44204 L .64427 .44014 L F
.64074 .43879 m .64272 .44083 L .64327 .43976 L F
.64272 .44083 m .64389 .44204 L .64327 .43976 L F
0 0 0 r
.64277 .44072 m .64197 .44228 L .641 .44413 L F
.64197 .44228 m .64195 .4423 L .64194 .44233 L F
.64197 .44228 m .64194 .44233 L .641 .44413 L F
0 0 .329 r
.64202 .44467 m .641 .44413 L .64195 .4423 L F
.834 .677 .688 r
.5602 .50597 m .5605 .50886 L .55669 .50831 L F
.812 .751 .795 r
.55669 .50831 m .5605 .50886 L .5576 .51131 L F
.471 .189 .403 r
.5576 .51131 m .5605 .50886 L .56003 .51081 L F
.493 .426 .709 r
.56239 .50806 m .5605 .50886 L .5602 .50597 L F
.314 .051 .345 r
.56003 .51081 m .5605 .50886 L .56239 .50806 L F
.677 .87 .972 r
.6523 .42257 m .64898 .42403 L .6478 .42323 L F
.559 .485 .728 r
.3449 .61062 m .34527 .61422 L .34741 .61365 L F
.683 .173 .021 r
.3936 .62788 m .39561 .62969 L .39722 .62889 L F
.601 .158 .171 r
.39561 .62969 m .3996 .62854 L .39722 .62889 L F
0 0 0 r
.70532 .43666 m .70325 .43795 L .70287 .43815 L F
.661 .792 .944 r
.67783 .43471 m .68147 .43543 L .6807 .43361 L F
.799 .505 .49 r
.68146 .43752 m .68147 .43543 L .67783 .43471 L F
.564 .753 .966 r
.68147 .43543 m .68281 .4331 L .6807 .43361 L F
.68147 .43543 m .68443 .4349 L .68281 .4331 L F
.485 .194 .396 r
.68379 .4368 m .68147 .43543 L .68146 .43752 L F
.68379 .4368 m .68443 .4349 L .68147 .43543 L F
.845 .596 .562 r
.55248 .67545 m .55241 .6782 L .55019 .67756 L F
.552 .103 .14 r
.42608 .63346 m .42471 .63501 L .42239 .63406 L F
.411 0 .001 r
.42608 .63346 m .42709 .63497 L .42471 .63501 L F
.42608 .63346 m .4283 .63353 L .42709 .63497 L F
.748 .64 .74 r
.6222 .41675 m .62391 .42125 L .61996 .4203 L F
.634 .112 0 r
.61996 .4203 m .62378 .42122 L .62271 .42125 L F
.61996 .4203 m .62271 .42125 L .62008 .42239 L F
.843 .9 .878 r
.62102 .42129 m .62271 .42125 L .62237 .41972 L F
.62008 .42239 m .62271 .42125 L .62102 .42129 L F
.634 .112 0 r
.62378 .42122 m .62391 .42125 L .62271 .42125 L F
.181 .301 .751 r
.62447 .41886 m .62391 .42125 L .6222 .41675 L F
.782 .913 .929 r
.62271 .42125 m .62391 .42125 L .62447 .41886 L F
.59 .569 .799 r
.46919 .72026 m .47234 .72051 L .47015 .71591 L F
.574 .606 .847 r
.46919 .72026 m .47111 .72115 L .47234 .72051 L F
0 .4 .84 r
.38839 .62657 m .38704 .62665 L .38577 .62522 L F
.38839 .62657 m .38976 .62796 L .38704 .62665 L F
.8 .721 .777 r
.45427 .62875 m .45295 .62957 L .45145 .62867 L F
.338 0 0 r
.55767 .63854 m .55885 .63913 L .55689 .63823 L F
.798 .811 .862 r
.60111 .44417 m .5978 .44424 L .59974 .44297 L F
.841 .86 .858 r
.60367 .44137 m .60111 .44417 L .59974 .44297 L F
.516 .16 .302 r
.60652 .48496 m .60418 .48616 L .60404 .48493 L F
0 0 0 r
.46424 .62857 m .46455 .62945 L .46593 .62784 L F
.46424 .62857 m .46353 .63068 L .46455 .62945 L F
0 0 .167 r
.696 .44765 m .69663 .45067 L .69637 .44932 L F
0 0 .444 r
.69663 .45067 m .69744 .45235 L .69637 .44932 L F
.695 .475 .584 r
.71035 .44355 m .70765 .44109 L .70986 .44086 L F
.71035 .44355 m .70795 .44382 L .70765 .44109 L F
.837 .865 .865 r
.51064 .67265 m .51173 .66889 L .5095 .67193 L F
.51064 .67265 m .51338 .67015 L .51173 .66889 L F
.923 .805 .713 r
.55599 .68455 m .55571 .68925 L .55699 .6876 L F
0 .361 .767 r
.2207 .56194 m .22154 .56198 L .2189 .56102 L F
.2207 .56194 m .22391 .56353 L .22154 .56198 L F
.685 .325 .358 r
.56567 .63316 m .56725 .63428 L .5687 .63196 L F
.627 .257 .323 r
.56725 .63428 m .57122 .63363 L .5687 .63196 L F
.61 .635 .851 r
.20772 .58307 m .20991 .58369 L .20915 .58094 L F
.564 .717 .944 r
.38236 .61984 m .38019 .62051 L .37883 .61894 L F
.355 .503 .868 r
.38297 .62179 m .38019 .62051 L .38236 .61984 L F
.514 .222 .409 r
.53347 .68114 m .53634 .67884 L .53355 .67842 L F
.53347 .68114 m .53595 .68082 L .53634 .67884 L F
.373 .009 .212 r
.53595 .68082 m .53993 .67763 L .53634 .67884 L F
.364 .205 .528 r
.23861 .59041 m .23835 .59293 L .23683 .59351 L F
.319 .146 .484 r
.23808 .59481 m .23683 .59351 L .23835 .59293 L F
.23808 .59481 m .23663 .59585 L .23683 .59351 L F
.789 .711 .777 r
.54823 .67873 m .54558 .68095 L .5491 .68138 L F
.786 .721 .792 r
.54558 .68095 m .54621 .68262 L .5491 .68138 L F
.552 .692 .932 r
.68708 .41068 m .68559 .41296 L .68529 .4109 L F
.68708 .41068 m .68857 .41307 L .68559 .41296 L F
.343 .121 .426 r
.57646 .49954 m .57895 .49661 L .57877 .49885 L F
.296 0 .17 r
.57553 .50151 m .57646 .49954 L .57877 .49885 L F
.543 .321 .529 r
.34926 .59556 m .35184 .59268 L .34983 .59346 L F
.834 .677 .688 r
.5602 .50597 m .55669 .50831 L .55831 .50481 L F
.859 .798 .789 r
.56087 .50169 m .5602 .50597 L .55831 .50481 L F
.59 .016 0 r
.25513 .5594 m .25529 .56002 L .2528 .55858 L F
.274 .191 .577 r
.25637 .55746 m .25513 .5594 L .25592 .55514 L F
0 0 0 r
.25637 .55746 m .25529 .56002 L .25513 .5594 L F
0 0 .235 r
.54962 .68408 m .5502 .68259 L .54957 .68078 L F
.913 .945 .809 r
.5502 .68259 m .55311 .68076 L .54957 .68078 L F
.684 .916 .973 r
.46379 .63201 m .46802 .63157 L .46624 .63206 L F
0 0 .078 r
.24819 .56611 m .24599 .56939 L .2468 .56739 L F
.832 .425 0 r
.65978 .42016 m .66149 .42312 L .66004 .42225 L F
.854 .4 .032 r
.66149 .42312 m .66156 .42486 L .66004 .42225 L F
.66149 .42312 m .66298 .42575 L .66156 .42486 L F
.656 .101 0 r
.54542 .6509 m .54473 .64951 L .54341 .64864 L F
.54542 .6509 m .54711 .65158 L .54473 .64951 L F
.713 .196 0 r
.54473 .64951 m .54711 .65158 L .54884 .65179 L F
.573 .786 .979 r
.43347 .57353 m .43095 .57403 L .42981 .57295 L F
.6 .748 .948 r
.436 .57394 m .43095 .57403 L .43347 .57353 L F
.373 .009 .212 r
.53595 .68082 m .53834 .68032 L .53993 .67763 L F
0 0 0 r
.53993 .67763 m .54065 .67804 L .54178 .67798 L F
.53986 .67774 m .53834 .68032 L .54065 .67804 L F
.798 .999 .819 r
.53834 .68032 m .53869 .67843 L .54065 .67804 L F
.212 0 0 r
.53869 .67843 m .54276 .67841 L .54065 .67804 L F
.269 0 0 r
.53869 .67843 m .54117 .67823 L .54065 .67804 L F
.54117 .67823 m .54272 .67811 L .54065 .67804 L F
0 0 0 r
.53993 .67763 m .53986 .67774 L .54065 .67804 L F
.698 .85 .955 r
.51173 .66889 m .51338 .67015 L .515 .66882 L F
.872 .439 .166 r
.63746 .46517 m .63891 .46443 L .63581 .46306 L F
.779 .399 0 r
.42077 .58554 m .42187 .58783 L .42083 .58594 L F
.7 .763 .901 r
.42083 .58594 m .42187 .58783 L .42396 .58644 L F
.165 .696 .855 r
.42275 .58655 m .42091 .58652 L .42083 .58594 L F
.42091 .58652 m .41874 .58647 L .42083 .58594 L F
.779 .399 0 r
.42031 .58457 m .42077 .58554 L .42083 .58594 L F
.063 0 0 r
.25159 .55633 m .25226 .55629 L .25314 .55532 L F
.341 0 0 r
.25314 .55532 m .25149 .55712 L .25383 .55658 L F
.25149 .55712 m .25125 .55738 L .25158 .55728 L F
.25149 .55712 m .25158 .55728 L .25383 .55658 L F
.529 .609 .877 r
.24951 .55767 m .2507 .55962 L .2528 .55858 L F
.24951 .55767 m .2528 .55858 L .25125 .55738 L F
.909 .768 .694 r
.25125 .55738 m .25103 .55935 L .2528 .55858 L F
0 0 .241 r
.2517 .5575 m .25216 .55914 L .25103 .55935 L F
.721 .587 .704 r
.25353 .55621 m .25118 .55466 L .2526 .55505 L F
.25118 .55466 m .24988 .55379 L .2526 .55505 L F
.341 0 0 r
.25314 .55532 m .25383 .55658 L .25592 .55514 L F
.429 .656 .955 r
.25462 .55495 m .25383 .55658 L .2526 .55505 L F
.25462 .55495 m .25383 .55658 L .2526 .55505 L F
.329 .127 .448 r
.25445 .55556 m .2526 .55505 L .25462 .55495 L F
.721 .587 .704 r
.25383 .55658 m .25332 .55622 L .25353 .55621 L F
.25332 .55622 m .24988 .55379 L .25353 .55621 L F
.913 .613 .462 r
.25592 .55514 m .25383 .55658 L .25637 .55746 L F
.914 .725 .634 r
.25383 .55658 m .25529 .56002 L .25637 .55746 L F
.25383 .55658 m .25529 .56002 L .25637 .55746 L F
.563 .572 .82 r
.2528 .55858 m .25383 .55658 L .25125 .55738 L F
.2528 .55858 m .25529 .56002 L .25383 .55658 L F
.015 .22 .729 r
.25529 .56002 m .25582 .55848 L .25383 .55658 L F
.063 0 0 r
.24951 .55767 m .25125 .55738 L .25226 .55629 L F
.24951 .55767 m .25226 .55629 L .25159 .55633 L F
.721 .587 .704 r
.25148 .55492 m .25125 .55738 L .24988 .55379 L F
.25383 .55658 m .25125 .55738 L .25148 .55492 L F
0 0 .241 r
.2526 .55505 m .25125 .55738 L .25383 .55658 L F
.2526 .55505 m .25109 .55919 L .25125 .55738 L F
.25109 .55919 m .25103 .55935 L .25125 .55738 L F
.329 .127 .448 r
.2537 .55821 m .2526 .55505 L .25445 .55556 L F
0 0 .241 r
.2526 .55505 m .25223 .55846 L .2517 .5575 L F
.25223 .55846 m .25216 .55914 L .2517 .5575 L F
.36 .831 .876 r
.41339 .57668 m .40934 .57731 L .41158 .57658 L F
.463 .885 .915 r
.41158 .57658 m .41559 .57586 L .41339 .57668 L F
.709 .673 .813 r
.63334 .43932 m .62981 .43778 L .63219 .43734 L F
.159 .7 .775 r
.63466 .43898 m .63334 .43932 L .63219 .43734 L F
0 .258 .737 r
.63355 .43774 m .63466 .43898 L .63219 .43734 L F
.874 .479 .017 r
.6342 .43894 m .63466 .43898 L .63355 .43774 L F
.159 .7 .775 r
.63466 .43898 m .63533 .43904 L .63334 .43932 L F
.874 .479 .017 r
.63499 .44042 m .63466 .43898 L .6342 .43894 L F
.159 .7 .775 r
.63466 .43898 m .6362 .43892 L .63533 .43904 L F
.758 .946 .617 r
.55702 .67836 m .55558 .67967 L .55436 .68196 L F
0 0 .162 r
.55628 .67493 m .5569 .67773 L .55702 .67836 L F
.827 .961 .629 r
.5569 .67773 m .55558 .67967 L .55702 .67836 L F
.734 .801 .905 r
.42892 .58039 m .43268 .57989 L .43147 .57868 L F
.607 .804 .976 r
.43147 .57868 m .43268 .57989 L .43464 .57952 L F
.465 .234 .478 r
.51883 .7104 m .52034 .71013 L .52069 .70813 L F
0 0 0 r
.17653 .55477 m .1784 .55449 L .17589 .55493 L F
.51 0 0 r
.43155 .62609 m .43313 .62568 L .43142 .62499 L F
.43155 .62609 m .43553 .62714 L .43313 .62568 L F
.598 .186 .232 r
.53858 .68665 m .53705 .68857 L .53476 .68703 L F
.238 0 0 r
.54091 .68923 m .53858 .68665 L .54059 .6875 L F
.54091 .68923 m .53705 .68857 L .53858 .68665 L F
.993 .793 .416 r
.64119 .4468 m .64117 .44997 L .64163 .44958 L F
.98 .687 .335 r
.64117 .44997 m .64087 .45116 L .64163 .44958 L F
0 0 0 r
.64163 .44958 m .64229 .44984 L .64409 .44844 L F
.64163 .44958 m .64087 .45116 L .64229 .44984 L F
.972 .876 .68 r
.55558 .67967 m .55556 .68368 L .55436 .68196 L F
.017 .569 .826 r
.19408 .54065 m .19546 .54079 L .19783 .54144 L F
.457 0 0 r
.19546 .54079 m .19987 .54153 L .19783 .54144 L F
.797 .749 .809 r
.58685 .61893 m .59033 .61991 L .58922 .61642 L F
.982 .714 .439 r
.58895 .622 m .59033 .61991 L .58685 .61893 L F
.58895 .622 m .59012 .62227 L .59033 .61991 L F
.86 .779 .77 r
.58922 .61642 m .59033 .61991 L .59141 .6169 L F
.318 0 0 r
.39375 .63943 m .39231 .63989 L .39004 .63978 L F
.194 0 0 r
.39595 .63936 m .39231 .63989 L .39375 .63943 L F
.339 .699 .983 r
.19243 .55496 m .19265 .55398 L .19104 .55402 L F
.209 .562 .936 r
.19243 .55496 m .19464 .5559 L .19265 .55398 L F
.988 .803 .413 r
.48874 .70083 m .48944 .70176 L .48855 .70336 L F
.689 .626 .781 r
.68064 .45991 m .67747 .45835 L .67973 .45758 L F
0 .443 .709 r
.67994 .45969 m .68064 .45991 L .67973 .45758 L F
.67994 .45969 m .68303 .46046 L .68064 .45991 L F
.651 .631 .817 r
.69799 .4167 m .69667 .42087 L .69557 .41728 L F
.69799 .4167 m .69923 .42014 L .69667 .42087 L F
.509 .145 .284 r
.51794 .69291 m .51705 .69525 L .51448 .69538 L F
0 0 .008 r
.51891 .69014 m .51794 .69291 L .51993 .69051 L F
.51891 .69014 m .5185 .69271 L .51794 .69291 L F
.581 .548 .783 r
.5185 .69271 m .51705 .69525 L .51794 .69291 L F
0 0 .132 r
.51924 .68407 m .52038 .68071 L .51824 .68126 L F
.51924 .68407 m .52012 .68288 L .52038 .68071 L F
.977 .716 .467 r
.52186 .68582 m .52012 .68288 L .51924 .68407 L F
.638 .669 .864 r
.52006 .68748 m .52186 .68582 L .51924 .68407 L F
.238 .01 .353 r
.1952 .62557 m .19621 .62725 L .19647 .62482 L F
.445 .264 .54 r
.19621 .62725 m .19683 .62465 L .19647 .62482 L F
.271 .012 .325 r
.50266 .69845 m .50052 .70089 L .50083 .69844 L F
0 .511 .736 r
.20385 .54187 m .2059 .54217 L .20762 .54249 L F
.14 .672 .86 r
.20762 .54249 m .2059 .54217 L .20972 .54247 L F
.814 .678 .713 r
.60964 .45813 m .61206 .45477 L .60823 .45498 L F
.434 0 .012 r
.37493 .58483 m .37681 .58562 L .37828 .58414 L F
.442 .005 .111 r
.37681 .58562 m .38058 .58371 L .37828 .58414 L F
.108 .662 .762 r
.20376 .55468 m .20247 .5547 L .20032 .55489 L F
.336 .817 .861 r
.20465 .5541 m .20376 .55468 L .2069 .55419 L F
.20465 .5541 m .20247 .5547 L .20376 .55468 L F
.447 0 .072 r
.52402 .70056 m .52405 .69901 L .52303 .70206 L F
.52402 .70056 m .52535 .69884 L .52405 .69901 L F
.638 .878 .986 r
.52328 .7024 m .52532 .70138 L .52402 .70056 L F
.566 .305 .48 r
.58452 .4938 m .58693 .49559 L .58394 .49639 L F
.58452 .4938 m .58716 .49336 L .58693 .49559 L F
.461 .275 .541 r
.34493 .5994 m .34701 .59886 L .34721 .5962 L F
.503 .382 .647 r
.34518 .60193 m .34701 .59886 L .34493 .5994 L F
.078 .202 .692 r
.64944 .47039 m .6485 .46669 L .646 .46921 L F
.651 .756 .926 r
.68175 .45459 m .68312 .45668 L .68543 .45534 L F
.632 .726 .915 r
.44942 .57371 m .44554 .57261 L .44778 .57218 L F
.681 .792 .933 r
.45153 .5726 m .44942 .57371 L .44778 .57218 L F
.632 .272 .341 r
.67827 .4643 m .67831 .46618 L .67582 .46461 L F
.434 .86 .943 r
.67028 .41504 m .67388 .41467 L .67279 .41542 L F
.611 .863 .991 r
.67521 .41283 m .67388 .41467 L .67652 .4138 L F
.651 .916 .613 r
.67279 .41542 m .67388 .41467 L .67521 .41283 L F
.404 .271 .584 r
.23011 .60997 m .2281 .61352 L .22807 .61095 L F
.545 .158 .258 r
.43441 .63137 m .43288 .63368 L .43064 .63345 L F
.683 .316 .344 r
.43441 .63137 m .43661 .63355 L .43288 .63368 L F
.612 .333 .469 r
.43682 .63142 m .43661 .63355 L .43441 .63137 L F
.349 .541 .901 r
.19389 .63444 m .1949 .63347 L .19298 .6331 L F
0 0 0 r
.19271 .63613 m .1949 .63347 L .19389 .63444 L F
.703 .449 .537 r
.515 .66882 m .51529 .66667 L .51156 .66702 L F
.548 .563 .822 r
.57814 .60451 m .57853 .60193 L .57685 .60178 L F
.57814 .60451 m .58016 .60423 L .57853 .60193 L F
.537 .286 .482 r
.37909 .60669 m .37649 .60727 L .37656 .60567 L F
.797 .856 .894 r
.64506 .46726 m .646 .46921 L .6485 .46669 L F
.197 .299 .743 r
.34741 .61365 m .34851 .61728 L .34962 .61563 L F
.222 .334 .767 r
.34851 .61728 m .35082 .61916 L .34962 .61563 L F
.611 .367 .522 r
.5734 .6258 m .57601 .62556 L .57562 .62252 L F
.172 .139 .577 r
.57562 .62252 m .57794 .62119 L .57715 .62002 L F
0 0 .214 r
.57659 .6248 m .57562 .62252 L .57601 .62556 L F
.57659 .6248 m .57794 .62119 L .57562 .62252 L F
0 0 0 r
.20155 .65746 m .19943 .6607 L .19956 .66041 L F
.766 .292 .115 r
.6301 .46125 m .6314 .46309 L .63301 .46263 L F
.582 .211 .303 r
.6314 .46309 m .6348 .46104 L .63301 .46263 L F
0 0 .282 r
.53478 .67497 m .53462 .6774 L .53355 .67842 L F
0 0 .227 r
.53401 .67823 m .53355 .67842 L .53462 .6774 L F
.53401 .67823 m .53347 .68114 L .53355 .67842 L F
0 0 0 r
.57441 .63746 m .57427 .63761 L .57653 .63603 L F
0 .365 .672 r
.57589 .63816 m .57426 .6376 L .57412 .63756 L F
.489 0 0 r
.57487 .63781 m .57357 .63832 L .57441 .63746 L F
0 0 0 r
.57427 .63761 m .57357 .63832 L .57442 .63766 L F
.57427 .63761 m .57442 .63766 L .57653 .63603 L F
0 .365 .672 r
.57589 .63816 m .57487 .63781 L .57426 .6376 L F
.57412 .63756 m .57426 .6376 L .57249 .63701 L F
.612 .591 .805 r
.51747 .7321 m .52005 .73129 L .51608 .72985 L F
.861 .536 .436 r
.64757 .44124 m .6492 .44465 L .64579 .44241 L F
.728 .673 .795 r
.54118 .64707 m .53858 .64593 L .53988 .64653 L F
.635 .084 0 r
.5407 .64805 m .54118 .64707 L .53988 .64653 L F
.5407 .64805 m .54341 .64864 L .54118 .64707 L F
.888 .468 .073 r
.63456 .44655 m .63186 .44286 L .63542 .44428 L F
.421 .169 .423 r
.19246 .62851 m .1946 .62836 L .1952 .62557 L F
.238 .01 .353 r
.1952 .62557 m .1946 .62836 L .19621 .62725 L F
.356 .054 .308 r
.61859 .45523 m .62099 .45483 L .62139 .45256 L F
.182 0 .254 r
.62139 .45256 m .62318 .45304 L .62462 .45221 L F
.62139 .45256 m .62099 .45483 L .62318 .45304 L F
.912 .522 .112 r
.696 .44765 m .69637 .44932 L .6951 .4481 L F
.696 .44765 m .69637 .44932 L .6951 .4481 L F
.685 .646 .805 r
.20915 .58094 m .20991 .58369 L .21219 .58327 L F
.568 .241 .375 r
.42358 .62723 m .42834 .62409 L .42372 .62697 L F
0 0 0 r
.42834 .62409 m .428 .62436 L .4298 .62367 L F
.921 .915 .794 r
.54444 .67955 m .54346 .68321 L .54558 .68095 L F
.018 .556 .846 r
.53982 .68121 m .54076 .68148 L .54216 .6821 L F
.921 .915 .794 r
.54444 .67955 m .54216 .6821 L .54359 .68273 L F
.569 .304 .475 r
.54444 .67955 m .54441 .68253 L .54216 .6821 L F
.018 .556 .846 r
.54076 .68148 m .54441 .68253 L .54216 .6821 L F
.921 .915 .794 r
.54359 .68273 m .54216 .6821 L .54346 .68321 L F
.559 .485 .728 r
.3449 .61062 m .34741 .61365 L .3464 .61019 L F
.581 .778 .973 r
.63948 .45515 m .64299 .45602 L .64278 .45444 L F
.713 .179 0 r
.64559 .45658 m .64278 .45444 L .64299 .45602 L F
.385 .158 .443 r
.24735 .55821 m .24691 .56063 L .24499 .56118 L F
.577 .546 .783 r
.24846 .5638 m .24499 .56118 L .24691 .56063 L F
.363 0 .017 r
.52038 .68071 m .52262 .68043 L .52375 .67898 L F
.732 .313 .251 r
.52262 .68043 m .52569 .6808 L .52375 .67898 L F
.704 .339 .355 r
.52375 .67898 m .52569 .6808 L .52748 .68051 L F
.656 .146 .021 r
.428 .62436 m .43142 .62499 L .4298 .62367 L F
.773 .716 .799 r
.64694 .42693 m .64298 .42873 L .6438 .4255 L F
.513 .906 .932 r
.64526 .42534 m .6438 .4255 L .64431 .42492 L F
.857 .983 .699 r
.64298 .42873 m .64431 .42492 L .6438 .4255 L F
.64375 .42652 m .64294 .42689 L .64431 .42492 L F
.64298 .42873 m .64295 .42757 L .64375 .42652 L F
.64295 .42757 m .64294 .42689 L .64375 .42652 L F
.854 .557 .486 r
.64526 .42534 m .64694 .42693 L .64434 .42575 L F
.64459 .42541 m .64434 .42575 L .6438 .4255 L F
.64526 .42534 m .64434 .42575 L .64459 .42541 L F
.771 .682 .765 r
.19836 .61158 m .19643 .61208 L .19992 .60785 L F
.887 .577 .456 r
.45145 .62867 m .45101 .63052 L .45295 .62957 L F
.281 0 .135 r
.21103 .59 m .21317 .58945 L .21412 .5875 L F
.01 0 .004 r
.21412 .5875 m .21467 .58856 L .2164 .58714 L F
.21412 .5875 m .21317 .58945 L .21467 .58856 L F
.284 0 .158 r
.52757 .65261 m .52993 .65183 L .52728 .65306 L F
.573 .798 .984 r
.52757 .65261 m .52813 .65047 L .5259 .6515 L F
.52757 .65261 m .52993 .65183 L .52813 .65047 L F
.583 .57 .804 r
.6825 .42624 m .68364 .42225 L .68154 .42318 L F
.6825 .42624 m .68499 .42562 L .68364 .42225 L F
.174 .702 .691 r
.68354 .42597 m .6825 .42624 L .68168 .42742 L F
.68354 .42597 m .68499 .42562 L .6825 .42624 L F
.655 .739 .912 r
.49371 .7347 m .49573 .73364 L .49241 .73334 L F
.41 0 0 r
.49124 .69187 m .49279 .69072 L .4943 .69148 L F
.562 .291 .462 r
.56568 .50497 m .56519 .50783 L .56239 .50806 L F
.325 .007 .263 r
.56836 .50411 m .56519 .50783 L .56568 .50497 L F
0 0 .041 r
.48574 .61911 m .48322 .62189 L .48413 .62023 L F
.158 0 .199 r
.48574 .61911 m .48651 .61726 L .48826 .61628 L F
.083 .642 .71 r
.6362 .43892 m .63839 .43867 L .63944 .43857 L F
.348 0 0 r
.63839 .43867 m .64145 .43789 L .63944 .43857 L F
.766 .619 .697 r
.54314 .68617 m .54091 .68923 L .54059 .6875 L F
.523 .552 .826 r
.4714 .7096 m .47289 .7131 L .47049 .71335 L F
.4714 .7096 m .47049 .71335 L .47123 .71212 L F
.965 .745 .554 r
.47244 .71553 m .47049 .71335 L .47015 .71591 L F
0 .007 .582 r
.47244 .71553 m .47049 .71335 L .47289 .7131 L F
.965 .745 .554 r
.47244 .71553 m .47123 .71212 L .47049 .71335 L F
.176 0 .093 r
.51402 .68923 m .51384 .69008 L .51548 .68926 L F
.56 .404 .627 r
.51918 .71145 m .52034 .71013 L .51883 .7104 L F
.797 .692 .749 r
.45291 .58034 m .45609 .58083 L .4551 .57954 L F
.45291 .58034 m .45424 .58152 L .45609 .58083 L F
.195 .726 .783 r
.45899 .57904 m .4551 .57954 L .45609 .58083 L F
.406 0 .149 r
.41525 .58529 m .41446 .58656 L .41229 .58681 L F
.904 .801 .735 r
.57639 .47047 m .57312 .47268 L .57525 .46942 L F
.57639 .47047 m .57572 .47259 L .57312 .47268 L F
.857 .889 .859 r
.57773 .46656 m .57639 .47047 L .57525 .46942 L F
.57773 .46656 m .57899 .46769 L .57639 .47047 L F
.486 .224 .442 r
.5576 .51131 m .55991 .51298 L .55732 .51352 L F
.5576 .51131 m .56003 .51081 L .55991 .51298 L F
.74 .712 .825 r
.55368 .51057 m .55669 .50831 L .5576 .51131 L F
.776 .467 .463 r
.55368 .51057 m .5576 .51131 L .55732 .51352 L F
.884 .693 .64 r
.51891 .69014 m .51993 .69051 L .52006 .68748 L F
.638 .669 .864 r
.52006 .68748 m .52312 .686 L .52186 .68582 L F
.528 .386 .632 r
.52235 .68969 m .52006 .68748 L .51993 .69051 L F
.52235 .68969 m .52312 .686 L .52006 .68748 L F
.903 .807 .743 r
.57312 .47268 m .57572 .47259 L .57384 .47577 L F
.367 .133 .421 r
.24104 .58463 m .24048 .58684 L .23863 .58742 L F
.397 .302 .63 r
.2406 .58935 m .23863 .58742 L .24048 .58684 L F
.2406 .58935 m .23861 .59041 L .23863 .58742 L F
.915 .535 .279 r
.54786 .65324 m .54884 .65179 L .54711 .65158 L F
.54786 .65324 m .55066 .65555 L .54884 .65179 L F
.562 .529 .776 r
.24851 .55398 m .24735 .55821 L .24636 .55432 L F
.24851 .55398 m .24951 .55767 L .24735 .55821 L F
.564 .634 .879 r
.24735 .55821 m .2507 .55962 L .24951 .55767 L F
.388 .131 .399 r
.24951 .55767 m .24691 .56063 L .24735 .55821 L F
.499 .05 .116 r
.40806 .63737 m .40655 .63917 L .40422 .63901 L F
.446 0 .076 r
.4105 .63738 m .40655 .63917 L .40806 .63737 L F
.984 .733 .473 r
.52532 .70138 m .52535 .69884 L .52402 .70056 L F
.604 .48 .685 r
.50832 .69296 m .50837 .69612 L .50632 .69653 L F
.564 .075 .052 r
.50823 .69781 m .50632 .69653 L .50837 .69612 L F
.50823 .69781 m .50543 .69784 L .50632 .69653 L F
.624 .597 .802 r
.70444 .44597 m .70321 .44956 L .70195 .4467 L F
.70444 .44597 m .70587 .44984 L .70321 .44956 L F
.213 0 0 r
.70587 .44984 m .70292 .45129 L .70321 .44956 L F
.337 .14 .458 r
.21508 .57852 m .21689 .5779 L .21722 .57552 L F
.386 .108 .364 r
.21508 .57852 m .21654 .58012 L .21689 .5779 L F
.21508 .57852 m .21414 .58139 L .21654 .58012 L F
.858 .698 .683 r
.56846 .49083 m .57024 .48767 L .56903 .48884 L F
.818 .717 .754 r
.57084 .48519 m .57024 .48767 L .56896 .4841 L F
.784 .581 .627 r
.49444 .73001 m .49827 .72757 L .49349 .72864 L F
.603 .946 .926 r
.61505 .46219 m .61626 .4613 L .61703 .46162 L F
0 0 0 r
.61728 .46055 m .61626 .4613 L .61492 .46263 L F
.72 .985 .894 r
.61703 .46162 m .61626 .4613 L .61815 .45979 L F
0 0 0 r
.61815 .45979 m .61626 .4613 L .61728 .46055 L F
.603 .946 .926 r
.61312 .46275 m .61626 .4613 L .61505 .46219 L F
.721 .973 .734 r
.61932 .45907 m .61703 .46162 L .61815 .45979 L F
.841 .86 .858 r
.60367 .44137 m .59974 .44297 L .60239 .4401 L F
.835 .863 .865 r
.60624 .43868 m .60367 .44137 L .60239 .4401 L F
.746 .983 .908 r
.5466 .67007 m .54588 .66965 L .54291 .67177 L F
.651 .833 .97 r
.5466 .67007 m .54723 .66797 L .54588 .66965 L F
.5466 .67007 m .54894 .66926 L .54723 .66797 L F
.243 .281 .702 r
.54734 .67222 m .54848 .67165 L .5466 .67007 L F
.516 .272 .484 r
.5466 .67007 m .54848 .67165 L .54894 .66926 L F
.955 .662 .441 r
.55151 .6576 m .55192 .66043 L .5534 .66107 L F
0 0 .547 r
.55473 .66192 m .5534 .66107 L .55192 .66043 L F
.55473 .66192 m .55458 .66286 L .5534 .66107 L F
.727 .855 .942 r
.64393 .41755 m .64621 .41649 L .64659 .41598 L F
.489 .277 .517 r
.64658 .41627 m .64393 .41755 L .64659 .41598 L F
.416 .857 .763 r
.64637 .41637 m .64621 .41649 L .64393 .41755 L F
.489 .277 .517 r
.6465 .41825 m .64393 .41755 L .64658 .41627 L F
.137 .001 .419 r
.6465 .41825 m .64657 .41654 L .64703 .41668 L F
.108 0 .428 r
.64659 .41598 m .64621 .41649 L .64703 .41668 L F
.137 .001 .419 r
.64657 .41654 m .64659 .41598 L .64703 .41668 L F
.008 .226 .735 r
.64703 .41668 m .64621 .41649 L .64625 .41646 L F
.64703 .41668 m .64625 .41646 L .64675 .41609 L F
.416 .857 .763 r
.64675 .41609 m .64637 .41637 L .64393 .41755 L F
.452 .367 .67 r
.64675 .41609 m .64393 .41755 L .6465 .41825 L F
.414 .309 .626 r
.24411 .57826 m .24463 .58072 L .2426 .57891 L F
.353 .306 .666 r
.2426 .57891 m .24463 .58072 L .24312 .58129 L F
0 0 0 r
.47604 .62806 m .47465 .6292 L .47237 .63024 L F
.47896 .62575 m .47765 .62771 L .47604 .62806 L F
.47604 .62806 m .47765 .62771 L .47465 .6292 L F
.356 0 0 r
.52641 .69007 m .52413 .69167 L .5233 .69127 L F
.531 .062 .087 r
.52864 .69149 m .52641 .69007 L .52888 .69007 L F
.52864 .69149 m .52413 .69167 L .52641 .69007 L F
.94 .705 .555 r
.67455 .46136 m .67553 .46443 L .67184 .46281 L F
.844 .38 .034 r
.67553 .46443 m .67368 .46443 L .67184 .46281 L F
.67553 .46443 m .67494 .46526 L .67368 .46443 L F
.545 .502 .759 r
.67455 .46136 m .67582 .46461 L .67553 .46443 L F
.676 .136 0 r
.67582 .46461 m .67494 .46526 L .67553 .46443 L F
.67 .621 .791 r
.70308 .42306 m .69923 .42014 L .70175 .41946 L F
.602 .615 .837 r
.70422 .41885 m .70308 .42306 L .70175 .41946 L F
.70422 .41885 m .70554 .42231 L .70308 .42306 L F
.624 .526 .723 r
.70554 .42231 m .70396 .42621 L .70308 .42306 L F
.347 .097 .386 r
.57068 .50477 m .57107 .5027 L .57309 .50185 L F
.287 .787 .801 r
.19151 .6306 m .1946 .62836 L .19246 .62851 L F
.526 .391 .64 r
.3857 .59976 m .38457 .60229 L .38243 .6013 L F
.415 .451 .789 r
.38624 .6013 m .38243 .6013 L .3857 .59976 L F
.38624 .6013 m .38457 .60229 L .38243 .6013 L F
.978 .748 .524 r
.52921 .7216 m .52984 .71937 L .53069 .72266 L F
.088 0 .237 r
.52984 .71937 m .52921 .7216 L .53069 .72266 L F
.88 .919 .847 r
.5898 .63346 m .58828 .63733 L .58992 .63434 L F
.313 .129 .463 r
.22607 .61651 m .22578 .61914 L .22407 .61971 L F
.425 .238 .522 r
.22579 .62148 m .22407 .61971 L .22578 .61914 L F
.22579 .62148 m .22389 .62216 L .22407 .61971 L F
0 0 .013 r
.48011 .62468 m .48025 .62493 L .47896 .62575 L F
.06 0 0 r
.4797 .6267 m .47896 .62575 L .48025 .62493 L F
.4797 .6267 m .47765 .62771 L .47896 .62575 L F
0 0 0 r
.47896 .62575 m .4817 .62325 L .48011 .62468 L F
.208 0 .113 r
.22253 .57001 m .21948 .57262 L .22158 .5718 L F
.526 .157 .283 r
.22253 .57001 m .22401 .57153 L .22338 .56857 L F
.22253 .57001 m .22158 .5718 L .22401 .57153 L F
.023 0 0 r
.46844 .6245 m .47059 .62359 L .4684 .62409 L F
.391 .227 .536 r
.23431 .60145 m .2325 .60457 L .23254 .6021 L F
.126 .326 .793 r
.65498 .44745 m .65706 .44939 L .65454 .4455 L F
0 0 0 r
.48011 .62468 m .4817 .62325 L .48322 .62189 L F
.77 .334 .215 r
.54607 .65833 m .5434 .65918 L .54282 .65794 L F
0 0 .181 r
.5434 .65918 m .54338 .659 L .54282 .65794 L F
.477 0 .003 r
.54408 .65726 m .54282 .65794 L .54252 .6574 L F
.77 .334 .215 r
.54607 .65833 m .54282 .65794 L .54408 .65726 L F
.833 .832 .359 r
.54282 .65794 m .54388 .65324 L .5427 .65457 L F
.54361 .65446 m .54304 .65581 L .54388 .65324 L F
.54282 .65794 m .54304 .65581 L .54361 .65446 L F
0 0 .181 r
.54338 .659 m .54304 .65581 L .54282 .65794 L F
.5434 .65918 m .54339 .65813 L .54304 .65581 L F
.937 .627 .426 r
.54304 .65581 m .54339 .65813 L .54228 .65762 L F
.477 0 .003 r
.54252 .6574 m .54282 .65794 L .54042 .65757 L F
.562 .408 .629 r
.54042 .65757 m .54282 .65794 L .5427 .65457 L F
.937 .627 .426 r
.54304 .65581 m .54228 .65762 L .54193 .65747 L F
.561 .512 .758 r
.70674 .42829 m .70672 .43152 L .70419 .42889 L F
.70674 .42829 m .70791 .43214 L .70672 .43152 L F
.49 .275 .514 r
.70786 .43429 m .70672 .43152 L .70791 .43214 L F
.70786 .43429 m .70607 .43561 L .70672 .43152 L F
.752 .806 .895 r
.68166 .4481 m .68416 .44932 L .68292 .44632 L F
.68161 .44817 m .68172 .44822 L .68166 .4481 L F
.68172 .44822 m .68416 .44932 L .68166 .4481 L F
.68226 .44846 m .68263 .45086 L .68416 .44932 L F
.873 .627 .563 r
.68278 .44899 m .68292 .44632 L .67968 .44483 L F
.68278 .44899 m .68091 .44647 L .68299 .4469 L F
.68091 .44647 m .67968 .44483 L .68033 .44523 L F
.68091 .44647 m .68033 .44523 L .68299 .4469 L F
.581 .378 .571 r
.68282 .44815 m .68572 .44609 L .68292 .44632 L F
.68278 .44899 m .68474 .44705 L .68282 .44815 L F
.68474 .44705 m .68572 .44609 L .68282 .44815 L F
.752 .806 .895 r
.68161 .44817 m .68182 .44872 L .68226 .44846 L F
.68182 .44872 m .68263 .45086 L .68226 .44846 L F
.413 .804 .988 r
.54055 .65189 m .54295 .65201 L .54135 .65148 L F
.94 .734 .596 r
.54135 .65148 m .54295 .65201 L .5427 .65457 L F
.261 .359 .775 r
.54135 .65148 m .54388 .65324 L .54289 .65068 L F
.54135 .65148 m .54289 .65068 L .5428 .65044 L F
.413 .804 .988 r
.5391 .65182 m .54055 .65189 L .54135 .65148 L F
0 0 0 r
.20155 .65746 m .20058 .65994 L .19943 .6607 L F
0 0 .097 r
.20382 .65452 m .20307 .65702 L .20155 .65746 L F
0 0 0 r
.20178 .65879 m .20155 .65746 L .20307 .65702 L F
.20178 .65879 m .20058 .65994 L .20155 .65746 L F
.784 .334 0 r
.6767 .45632 m .67764 .4571 L .67644 .45595 L F
.506 .843 .997 r
.67764 .4571 m .67864 .45795 L .67747 .45835 L F
.784 .334 0 r
.67845 .45871 m .67764 .4571 L .6767 .45632 L F
.506 .843 .997 r
.67764 .4571 m .67973 .45758 L .67864 .45795 L F
.222 .457 .874 r
.20974 .5542 m .21008 .5555 L .21047 .55385 L F
.6 .846 .991 r
.21047 .55385 m .21008 .5555 L .21224 .55475 L F
.464 .284 .552 r
.34701 .59886 m .34926 .59556 L .34721 .5962 L F
.075 .604 .868 r
.20972 .54247 m .21182 .54274 L .21352 .54334 L F
.358 .768 .981 r
.21182 .54274 m .21565 .54326 L .21352 .54334 L F
0 0 0 r
.52172 .64992 m .52108 .652 L .52214 .65061 L F
.397 .675 .972 r
.52108 .652 m .52351 .65215 L .52214 .65061 L F
.458 0 0 r
.40532 .62859 m .4074 .62955 L .40914 .62854 L F
.372 0 0 r
.4074 .62955 m .41154 .62832 L .40914 .62854 L F
.801 .357 0 r
.65564 .42798 m .65818 .43166 L .65715 .4295 L F
.81 .864 .887 r
.65818 .43166 m .65898 .43148 L .65715 .4295 L F
.459 .36 .655 r
.71156 .44002 m .71035 .44355 L .70986 .44086 L F
.725 .986 .889 r
.6478 .42323 m .64526 .42534 L .64431 .42492 L F
.745 .594 .689 r
.50221 .69183 m .50463 .69003 L .50148 .68918 L F
.626 .389 .538 r
.50221 .69183 m .50477 .69257 L .50463 .69003 L F
.695 .982 .861 r
.19912 .66148 m .19943 .6607 L .20058 .65994 L F
.19912 .66148 m .19819 .66268 L .19943 .6607 L F
.62 .066 0 r
.67582 .46461 m .67831 .46618 L .67494 .46526 L F
.241 0 0 r
.44636 .63158 m .44491 .63296 L .44257 .63333 L F
.201 0 0 r
.44871 .63112 m .44491 .63296 L .44636 .63158 L F
.392 .367 .711 r
.21735 .56107 m .21832 .55688 L .21663 .55732 L F
.21735 .56107 m .2189 .56102 L .21832 .55688 L F
.126 0 .275 r
.21874 .63305 m .21801 .63176 L .21947 .63085 L F
.21874 .63305 m .21732 .63402 L .21801 .63176 L F
.89 .885 .821 r
.58128 .46446 m .57899 .46769 L .57773 .46656 L F
.69 .601 .751 r
.68659 .46084 m .68755 .46437 L .68405 .46446 L F
.276 0 0 r
.68755 .46437 m .68409 .46569 L .68405 .46446 L F
.34 0 0 r
.62527 .45372 m .62759 .45399 L .6273 .45387 L F
.62759 .45399 m .62868 .45412 L .6273 .45387 L F
0 .285 .752 r
.62604 .45331 m .6273 .45387 L .62721 .45422 L F
.62462 .45221 m .6273 .45387 L .62604 .45331 L F
.484 .004 .04 r
.39279 .59589 m .39185 .59746 L .38933 .59638 L F
.379 0 0 r
.39476 .5961 m .39185 .59746 L .39279 .59589 L F
.735 .6 .706 r
.45728 .58479 m .458 .58636 L .46062 .58337 L F
.779 .427 .39 r
.57853 .60193 m .57684 .59917 L .57685 .60178 L F
.563 .204 .317 r
.35422 .59227 m .35799 .5898 L .35465 .59074 L F
.35422 .59227 m .35672 .59225 L .35799 .5898 L F
.327 0 .104 r
.35672 .59225 m .36037 .58966 L .35799 .5898 L F
.603 .562 .781 r
.34476 .62537 m .34794 .62777 L .34747 .62496 L F
.607 .842 .988 r
.42756 .5733 m .42389 .57306 L .42617 .57241 L F
.489 .768 .993 r
.42844 .57181 m .42756 .5733 L .42617 .57241 L F
.42844 .57181 m .42981 .57295 L .42756 .5733 L F
.846 .775 .782 r
.58495 .63898 m .58828 .63733 L .58713 .63638 L F
.58495 .63898 m .58606 .64055 L .58828 .63733 L F
.88 .919 .847 r
.5898 .63346 m .58713 .63638 L .58828 .63733 L F
0 .217 .74 r
.4499 .62831 m .44875 .62846 L .44738 .62743 L F
.512 .316 .552 r
.44875 .62846 m .45101 .63052 L .44871 .63112 L F
.237 0 0 r
.61822 .48179 m .61962 .48266 L .61722 .48318 L F
.61822 .48179 m .62068 .48118 L .61962 .48266 L F
.441 .26 .539 r
.24264 .58377 m .24048 .58684 L .24104 .58463 L F
.648 .747 .922 r
.45517 .57328 m .45153 .5726 L .45384 .57173 L F
.31 .427 .819 r
.45618 .57144 m .45517 .57328 L .45384 .57173 L F
.45618 .57144 m .45756 .57476 L .45517 .57328 L F
.847 .864 .416 r
.6756 .42059 m .67468 .42318 L .67525 .41956 L F
.591 .323 .479 r
.57895 .49661 m .58146 .49838 L .57877 .49885 L F
.57895 .49661 m .58138 .49633 L .58146 .49838 L F
.596 .208 .277 r
.3996 .62854 m .40161 .63018 L .40319 .62793 L F
.583 .193 .269 r
.40319 .62793 m .40496 .62953 L .40532 .62859 L F
.40319 .62793 m .40161 .63018 L .40496 .62953 L F
.396 .558 .897 r
.37042 .63492 m .37152 .63303 L .36929 .63358 L F
.37042 .63492 m .37311 .63546 L .37152 .63303 L F
.826 .805 .832 r
.65952 .46113 m .66223 .46107 L .66079 .46001 L F
.966 .877 .694 r
.66223 .46107 m .66206 .45814 L .66079 .46001 L F
.79 .605 .65 r
.667 .40901 m .66311 .41074 L .66578 .40778 L F
.667 .40901 m .66649 .41219 L .66311 .41074 L F
.825 .855 .87 r
.6693 .40655 m .667 .40901 L .66578 .40778 L F
.68 .963 .74 r
.20158 .61369 m .20211 .61256 L .20393 .61159 L F
.995 .841 .49 r
.20219 .61609 m .20211 .61256 L .20158 .61369 L F
0 0 .156 r
.20588 .65134 m .20535 .65396 L .20382 .65452 L F
0 0 .044 r
.20427 .65584 m .20382 .65452 L .20535 .65396 L F
.20427 .65584 m .20307 .65702 L .20382 .65452 L F
.433 .414 .738 r
.67652 .4138 m .67668 .41657 L .67884 .41562 L F
.745 .427 .444 r
.67544 .41864 m .67897 .41811 L .67884 .41562 L F
.305 .099 .426 r
.67884 .41562 m .67897 .41811 L .68294 .4166 L F
.451 .458 .775 r
.68294 .4166 m .67897 .41811 L .6786 .41632 L F
.745 .427 .444 r
.67619 .4174 m .67884 .41562 L .67668 .41657 L F
.67749 .41682 m .67884 .41562 L .67619 .4174 L F
.228 .387 .815 r
.67652 .4138 m .67884 .41562 L .67736 .41166 L F
.69 .681 .837 r
.67736 .41166 m .67884 .41562 L .681 .41297 L F
.604 .552 .769 r
.67884 .41562 m .682 .41557 L .681 .41297 L F
.305 .099 .426 r
.67884 .41562 m .68294 .4166 L .682 .41557 L F
.451 .458 .775 r
.68054 .41546 m .6786 .41632 L .6782 .41435 L F
.68294 .4166 m .6786 .41632 L .68054 .41546 L F
.745 .427 .444 r
.67544 .41864 m .67749 .41682 L .67619 .4174 L F
.484 .122 .274 r
.41836 .63588 m .41648 .63449 L .41892 .63437 L F
.41836 .63588 m .41589 .63629 L .41648 .63449 L F
.505 .639 .914 r
.67853 .40881 m .6748 .40653 L .67719 .40475 L F
.528 .616 .883 r
.68085 .40829 m .67853 .40881 L .67719 .40475 L F
.625 .538 .736 r
.70644 .42584 m .70419 .42889 L .70396 .42621 L F
.644 .564 .75 r
.70674 .42829 m .70419 .42889 L .70644 .42584 L F
0 .514 .715 r
.17825 .54187 m .18189 .54232 L .17974 .54221 L F
.53 .921 .828 r
.40126 .57898 m .40188 .5781 L .40365 .57872 L F
.40126 .57898 m .39909 .57953 L .40188 .5781 L F
.557 .359 .568 r
.48313 .68744 m .48545 .68925 L .48553 .68673 L F
.385 .375 .725 r
.48368 .68934 m .48545 .68925 L .48313 .68744 L F
.703 .449 .537 r
.515 .66882 m .51156 .66702 L .51173 .66889 L F
.564 .478 .716 r
.37883 .61894 m .37664 .61953 L .37611 .61592 L F
.459 .459 .771 r
.48368 .68934 m .48682 .69174 L .48545 .68925 L F
.688 .801 .935 r
.61729 .42864 m .61525 .42832 L .61777 .42461 L F
.064 0 .403 r
.61706 .43159 m .61729 .42864 L .618 .43049 L F
.308 .259 .639 r
.61972 .42713 m .61729 .42864 L .61777 .42461 L F
.053 0 .196 r
.618 .43049 m .61729 .42864 L .61972 .42713 L F
.386 .01 .197 r
.47598 .61863 m .47836 .61815 L .47941 .61564 L F
.382 .093 .344 r
.47941 .61564 m .48134 .61529 L .48199 .61358 L F
.514 .185 .346 r
.47836 .61815 m .48134 .61529 L .47941 .61564 L F
.838 .728 .742 r
.49736 .68863 m .49971 .68976 L .4983 .68695 L F
.233 .104 .491 r
.37763 .61328 m .37762 .61551 L .37611 .61592 L F
.564 .478 .716 r
.37883 .61894 m .37611 .61592 L .37762 .61551 L F
.89 .885 .821 r
.58128 .46446 m .57773 .46656 L .58018 .46339 L F
.843 .843 .844 r
.58225 .46048 m .58128 .46446 L .58018 .46339 L F
.58225 .46048 m .58363 .46183 L .58128 .46446 L F
.849 .765 .77 r
.67565 .4548 m .6792 .45313 L .67761 .45179 L F
0 .227 .748 r
.3555 .62917 m .35628 .62831 L .35529 .62799 L F
.308 .158 .509 r
.24045 .59186 m .23861 .59041 L .2406 .58935 L F
.24045 .59186 m .23835 .59293 L .23861 .59041 L F
.356 0 .113 r
.38764 .64005 m .38616 .64189 L .38451 .64174 L F
.366 0 .056 r
.39004 .63978 m .38616 .64189 L .38764 .64005 L F
.862 .465 0 r
.54751 .66101 m .54637 .65962 L .54607 .65833 L F
0 .072 .634 r
.54869 .66392 m .54637 .65962 L .54751 .66101 L F
0 0 .095 r
.5562 .67115 m .55628 .67493 L .55685 .67256 L F
.997 .773 .451 r
.56097 .49925 m .55983 .50088 L .56171 .49759 L F
.56097 .49925 m .56087 .50169 L .55983 .50088 L F
.917 .726 .63 r
.56974 .48182 m .57084 .48519 L .56896 .4841 L F
.236 .016 .363 r
.23577 .6007 m .2349 .59916 L .23611 .59832 L F
.23577 .6007 m .23431 .60145 L .2349 .59916 L F
.163 0 .302 r
.20796 .64814 m .20777 .65107 L .20588 .65134 L F
0 0 .149 r
.20661 .65285 m .20588 .65134 L .20777 .65107 L F
.20661 .65285 m .20535 .65396 L .20588 .65134 L F
.81 .6 .618 r
.56612 .6398 m .5631 .64128 L .56411 .63992 L F
.549 .598 .855 r
.49878 .68994 m .50221 .69183 L .50148 .68918 L F
.869 .868 .835 r
.19992 .60785 m .19643 .61208 L .19587 .60989 L F
.498 .216 .416 r
.19643 .61208 m .20074 .61096 L .19587 .60989 L F
.19643 .61208 m .19971 .61194 L .20074 .61096 L F
.532 .152 .266 r
.44134 .62808 m .44404 .62803 L .44498 .6261 L F
.587 .209 .293 r
.44498 .6261 m .44404 .62803 L .44738 .62743 L F
.586 .911 .668 r
.20014 .62254 m .20089 .62157 L .20289 .62017 L F
.585 .896 .622 r
.20014 .62254 m .19751 .62461 L .20089 .62157 L F
.607 .804 .976 r
.43147 .57868 m .43464 .57952 L .43353 .57755 L F
.098 0 0 r
.43821 .57965 m .43687 .57969 L .43464 .57952 L F
.698 .159 0 r
.43687 .57969 m .43353 .57755 L .43464 .57952 L F
.683 .494 .624 r
.61859 .45523 m .61932 .45907 L .62169 .45793 L F
.61859 .45523 m .62169 .45793 L .61978 .45687 L F
.61859 .45523 m .61978 .45687 L .62099 .45483 L F
.597 .586 .811 r
.20812 .59032 m .212 .59284 L .21103 .59 L F
0 0 .106 r
.56442 .49242 m .56338 .49653 L .56286 .49571 L F
.927 .973 .732 r
.56286 .49571 m .56338 .49653 L .56171 .49759 L F
.425 .062 .243 r
.35184 .59268 m .35422 .59227 L .35465 .59074 L F
.94 .705 .555 r
.67455 .46136 m .67184 .46281 L .67345 .46004 L F
.61 .157 .151 r
.53705 .68857 m .53346 .68868 L .53476 .68703 L F
.73 .983 .906 r
.43784 .5787 m .43821 .57965 L .44089 .57868 L F
.43784 .5787 m .43687 .57969 L .43821 .57965 L F
0 .432 .703 r
.48448 .61274 m .48667 .61328 L .48843 .61375 L F
.14 .008 .426 r
.48965 .6152 m .48826 .61628 L .48843 .61375 L F
.48965 .6152 m .48843 .61375 L .48667 .61328 L F
.983 .752 .508 r
.61913 .43631 m .62061 .43763 L .62076 .43495 L F
.125 0 0 r
.18674 .55246 m .18267 .55337 L .18475 .55252 L F
.723 .229 0 r
.58395 .61371 m .58365 .61419 L .58194 .61283 L F
.58395 .61371 m .58541 .61576 L .58365 .61419 L F
.56 .139 .201 r
.53301 .68246 m .53347 .68114 L .53401 .67823 L F
.53301 .68246 m .53595 .68082 L .53347 .68114 L F
0 .104 .649 r
.19464 .5559 m .19478 .55355 L .19265 .55398 L F
.19464 .5559 m .19492 .55479 L .19478 .55355 L F
0 0 .18 r
.59058 .62539 m .59093 .62733 L .59069 .62765 L F
.067 .169 .662 r
.59166 .62356 m .59058 .62539 L .59012 .62227 L F
.684 .144 0 r
.58895 .622 m .59166 .62356 L .59012 .62227 L F
0 0 0 r
.59136 .6254 m .59093 .62733 L .59157 .62401 L F
.5916 .62394 m .59157 .62401 L .59166 .62356 L F
.59136 .6254 m .59157 .62401 L .5916 .62394 L F
.42 .018 .169 r
.59201 .62417 m .59136 .6254 L .59166 .62356 L F
.684 .144 0 r
.58895 .622 m .59201 .62417 L .59166 .62356 L F
0 .252 .729 r
.59097 .62316 m .59165 .62381 L .58895 .622 L F
.58928 .62152 m .59097 .62316 L .58895 .622 L F
.59165 .62381 m .59188 .62404 L .59163 .62386 L F
.59165 .62381 m .59163 .62386 L .58895 .622 L F
.59188 .62404 m .59201 .62417 L .59183 .62404 L F
.59188 .62404 m .59183 .62404 L .58895 .622 L F
0 0 .214 r
.5914 .624 m .59093 .62733 L .59058 .62539 L F
.59166 .62356 m .59157 .62401 L .5914 .624 L F
.59157 .62401 m .59093 .62733 L .5914 .624 L F
.497 .838 .997 r
.21565 .54326 m .21774 .54273 L .21946 .54342 L F
.597 .696 .912 r
.58224 .63952 m .58606 .64055 L .58495 .63898 L F
0 0 0 r
.62664 .47847 m .62834 .47825 L .6252 .47994 L F
.62664 .47847 m .62883 .47798 L .62834 .47825 L F
0 0 .192 r
.67109 .45118 m .67088 .4483 L .67069 .44962 L F
.852 .998 .805 r
.44773 .62052 m .44893 .61953 L .4498 .61959 L F
.625 .961 .88 r
.45077 .61826 m .44893 .61953 L .4498 .61959 L F
.852 .998 .805 r
.4498 .61959 m .44893 .61953 L .44773 .62052 L F
.636 .958 .787 r
.44773 .62052 m .4498 .61959 L .45077 .61826 L F
.789 .714 .781 r
.61787 .44037 m .62137 .43999 L .62061 .43763 L F
.731 .424 .46 r
.62109 .4429 m .62137 .43999 L .61787 .44037 L F
.494 .141 .296 r
.62336 .44165 m .62137 .43999 L .62109 .4429 L F
.62336 .44165 m .62366 .43993 L .62137 .43999 L F
.325 .007 .263 r
.56836 .50411 m .56744 .50692 L .56519 .50783 L F
.589 .204 .281 r
.56836 .50411 m .57074 .50627 L .56744 .50692 L F
.56836 .50411 m .57068 .50477 L .57074 .50627 L F
.447 .013 .121 r
.40126 .59269 m .39985 .59461 L .39772 .59483 L F
0 0 0 r
.40373 .59027 m .40242 .59183 L .40126 .59269 L F
.535 .331 .549 r
.40242 .59183 m .39985 .59461 L .40126 .59269 L F
.424 0 .084 r
.37112 .58672 m .37354 .58658 L .37493 .58483 L F
.43 0 .088 r
.37493 .58483 m .37354 .58658 L .37681 .58562 L F
.444 .528 .849 r
.21663 .55732 m .21832 .55688 L .21547 .5559 L F
0 0 0 r
.20211 .61256 m .20603 .61056 L .20393 .61159 L F
.276 0 0 r
.68755 .46437 m .68664 .46537 L .68409 .46569 L F
.57 .526 .766 r
.68995 .46354 m .68755 .46437 L .68659 .46084 L F
0 0 0 r
.68916 .46438 m .68755 .46437 L .68995 .46354 L F
.68916 .46438 m .68664 .46537 L .68755 .46437 L F
.573 .272 .42 r
.64177 .42936 m .6413 .43035 L .63679 .43382 L F
.6413 .43035 m .63988 .43332 L .63688 .43381 L F
.6413 .43035 m .63688 .43381 L .63679 .43382 L F
.72 .445 .509 r
.6411 .4305 m .64025 .43117 L .64039 .43117 L F
.225 0 .228 r
.64189 .43229 m .63988 .43332 L .6413 .43035 L F
.72 .445 .509 r
.64198 .42967 m .64122 .43033 L .64127 .43034 L F
.64199 .42961 m .64026 .43116 L .64198 .42967 L F
.225 0 .228 r
.64189 .43229 m .6413 .43035 L .64182 .43044 L F
.64183 .43087 m .64182 .43044 L .642 .43058 L F
.64182 .43044 m .64198 .42967 L .6431 .43142 L F
.72 .445 .509 r
.64298 .42873 m .6431 .43142 L .64198 .42967 L F
.64298 .42873 m .64039 .43117 L .64222 .43118 L F
.64298 .42873 m .64177 .42936 L .64025 .43117 L F
.225 0 .228 r
.64182 .43044 m .6413 .43035 L .64177 .42936 L F
.72 .445 .509 r
.64127 .43034 m .64026 .43116 L .6411 .4305 L F
.64122 .43033 m .64026 .43116 L .64127 .43034 L F
.192 0 0 r
.64143 .43158 m .64025 .43117 L .6385 .43308 L F
.64222 .43118 m .64166 .43117 L .64143 .43158 L F
.64166 .43117 m .64025 .43117 L .64143 .43158 L F
.225 0 .228 r
.64189 .43229 m .64183 .43087 L .6431 .43142 L F
.64183 .43087 m .642 .43058 L .6431 .43142 L F
.64182 .43044 m .64177 .42936 L .64198 .42967 L F
.72 .445 .509 r
.64298 .42873 m .64199 .42961 L .64198 .42967 L F
.64026 .43116 m .64025 .43117 L .6411 .4305 L F
.64298 .42873 m .64198 .42967 L .64177 .42936 L F
.64298 .42873 m .64222 .43118 L .64258 .4282 L F
.857 .983 .699 r
.64298 .42873 m .64258 .4282 L .64294 .42689 L F
.48 .262 .504 r
.6453 .43065 m .6431 .43142 L .64298 .42873 L F
0 0 0 r
.40365 .57872 m .40595 .57822 L .40711 .57791 L F
.03 0 0 r
.40595 .57822 m .40934 .57731 L .40711 .57791 L F
0 0 0 r
.40442 .59086 m .40373 .59027 L .40614 .59006 L F
.40442 .59086 m .40242 .59183 L .40373 .59027 L F
.438 .866 .933 r
.2067 .55346 m .2069 .55419 L .20974 .5542 L F
.2067 .55346 m .20465 .5541 L .2069 .55419 L F
.276 0 .165 r
.21122 .64591 m .21024 .64824 L .20796 .64814 L F
.034 0 .265 r
.20898 .64994 m .20796 .64814 L .21024 .64824 L F
.20898 .64994 m .20777 .65107 L .20796 .64814 L F
.682 .353 0 r
.65442 .42476 m .65497 .42615 L .65365 .42268 L F
.851 .447 0 r
.65456 .4266 m .65497 .42615 L .65442 .42476 L F
.65456 .4266 m .65564 .42798 L .65497 .42615 L F
.761 .649 .737 r
.55368 .51057 m .55483 .51397 L .5519 .51375 L F
.677 .251 .229 r
.55483 .51397 m .55411 .51562 L .5519 .51375 L F
.776 .467 .463 r
.55368 .51057 m .55732 .51352 L .55483 .51397 L F
.741 .513 .584 r
.55732 .51352 m .55411 .51562 L .55483 .51397 L F
.509 .524 .808 r
.24553 .55265 m .24851 .55398 L .24636 .55432 L F
.818 .638 .659 r
.57853 .60193 m .58016 .60423 L .58096 .60215 L F
.372 .174 .477 r
.6222 .41675 m .61996 .4203 L .62237 .41972 L F
.843 .9 .878 r
.62008 .42239 m .62237 .41972 L .61996 .4203 L F
.758 .493 .532 r
.51223 .69583 m .50823 .69781 L .50837 .69612 L F
.51223 .69583 m .51203 .69818 L .50823 .69781 L F
.477 .251 .491 r
.51448 .69538 m .51203 .69818 L .51223 .69583 L F
.64 .491 .664 r
.57112 .62871 m .5712 .63115 L .57308 .62795 L F
.572 .937 .807 r
.42157 .5738 m .42193 .573 L .42389 .57306 L F
.42157 .5738 m .42004 .57428 L .42193 .573 L F
.344 .193 .528 r
.24599 .56939 m .24591 .57192 L .24425 .57245 L F
.292 .247 .635 r
.24608 .57445 m .24425 .57245 L .24591 .57192 L F
.24608 .57445 m .24437 .57559 L .24425 .57245 L F
.935 .558 .21 r
.5895 .60775 m .59007 .60986 L .59141 .6108 L F
.984 .863 .492 r
.59092 .61294 m .59141 .6108 L .59022 .61236 L F
.978 .694 .412 r
.59141 .6108 m .59007 .60986 L .59022 .61236 L F
.59141 .6108 m .59007 .60986 L .59022 .61236 L F
.369 .513 .871 r
.38529 .62357 m .38395 .62505 L .38297 .62179 L F
.38529 .62357 m .38577 .62522 L .38395 .62505 L F
.869 .868 .835 r
.19992 .60785 m .19587 .60989 L .20074 .61096 L F
.516 .16 .302 r
.60652 .48496 m .60656 .48621 L .60418 .48616 L F
.531 .172 .303 r
.60652 .48496 m .60885 .48628 L .60656 .48621 L F
.525 .181 .327 r
.60927 .48473 m .60885 .48628 L .60652 .48496 L F
.684 .832 .954 r
.52728 .65306 m .52813 .65047 L .5259 .6515 L F
.52728 .65306 m .52993 .65183 L .52813 .65047 L F
.503 .382 .647 r
.34518 .60193 m .3473 .60141 L .34701 .59886 L F
.499 .395 .668 r
.3456 .6044 m .3473 .60141 L .34518 .60193 L F
.837 .992 .737 r
.43155 .5841 m .43021 .58585 L .43239 .58377 L F
.85 .991 .733 r
.43239 .58377 m .431 .5851 L .43155 .5841 L F
.546 .857 .555 r
.43239 .58377 m .43021 .58585 L .431 .5851 L F
.22 .081 .469 r
.24602 .57674 m .24437 .57559 L .24608 .57445 L F
.24602 .57674 m .24411 .57826 L .24437 .57559 L F
.52 .094 .172 r
.43147 .57868 m .42738 .5801 L .42892 .58039 L F
.418 .012 .159 r
.36268 .58931 m .36495 .58914 L .36636 .58695 L F
.413 .006 .154 r
.36495 .58914 m .36872 .58668 L .36636 .58695 L F
.553 .416 .648 r
.37184 .64015 m .37426 .63985 L .37377 .63724 L F
.548 .391 .62 r
.37184 .64015 m .37201 .64279 L .37426 .63985 L F
.625 .479 .664 r
.70325 .43795 m .70029 .4405 L .70132 .4386 L F
.623 .95 .768 r
.62214 .44603 m .62531 .44405 L .62433 .4436 L F
.674 .975 .82 r
.62664 .44235 m .62531 .44405 L .62745 .44229 L F
.661 .953 .949 r
.62433 .4436 m .62531 .44405 L .62664 .44235 L F
.421 .009 .149 r
.41374 .62772 m .41609 .62751 L .41743 .62538 L F
.714 .33 .319 r
.41609 .62751 m .4196 .62766 L .41743 .62538 L F
.623 .349 .482 r
.41743 .62538 m .4196 .62766 L .41941 .62508 L F
.238 .033 .387 r
.24463 .58072 m .24264 .58377 L .24312 .58129 L F
.307 0 .247 r
.48134 .61529 m .48448 .61274 L .48199 .61358 L F
.268 .072 .419 r
.22143 .62767 m .21947 .63085 L .21986 .62842 L F
.63 .408 .563 r
.59808 .48761 m .59812 .49 L .59692 .49023 L F
.642 .41 .552 r
.60067 .48773 m .59812 .49 L .59808 .48761 L F
.356 .463 .832 r
.49404 .69585 m .49733 .69848 L .49672 .69565 L F
.835 .863 .865 r
.60624 .43868 m .60239 .4401 L .60485 .43733 L F
.82 .834 .859 r
.60485 .43733 m .60789 .43727 L .60624 .43868 L F
.832 .724 .746 r
.67377 .42732 m .67667 .42872 L .67544 .42523 L F
.819 .542 .519 r
.67576 .42982 m .67667 .42872 L .67377 .42732 L F
.67576 .42982 m .67659 .43112 L .67667 .42872 L F
.772 .696 .78 r
.67544 .42523 m .67667 .42872 L .67886 .42544 L F
.663 .48 .627 r
.67659 .43112 m .67934 .4281 L .67667 .42872 L F
.172 0 0 r
.36746 .63301 m .36557 .63282 L .36263 .6323 L F
.083 .477 .893 r
.36746 .63301 m .36777 .63213 L .36557 .63282 L F
.36746 .63301 m .36929 .63358 L .36777 .63213 L F
.87 .841 .815 r
.58592 .45865 m .58363 .46183 L .58225 .46048 L F
.574 .537 .776 r
.51993 .69051 m .5233 .69127 L .52235 .68969 L F
.6 .61 .833 r
.58224 .63952 m .58351 .63576 L .58089 .63662 L F
.58224 .63952 m .58495 .63898 L .58351 .63576 L F
.842 .988 .859 r
.62547 .41236 m .62469 .41434 L .6222 .41675 L F
.62547 .41236 m .6222 .41675 L .62269 .4163 L F
.102 0 .418 r
.6222 .41675 m .62397 .41837 L .62269 .4163 L F
.6222 .41675 m .62237 .41972 L .62397 .41837 L F
.624 .526 .723 r
.70554 .42231 m .70644 .42584 L .70396 .42621 L F
.634 .184 .167 r
.48855 .70336 m .48607 .70165 L .48603 .70369 L F
0 0 .162 r
.2129 .64252 m .21237 .6449 L .21122 .64591 L F
0 0 0 r
.21155 .64713 m .21122 .64591 L .21237 .6449 L F
.21155 .64713 m .21024 .64824 L .21122 .64591 L F
.323 .064 .357 r
.58141 .62257 m .58392 .62191 L .58402 .61938 L F
.597 .57 .795 r
.58402 .61938 m .58685 .61893 L .58541 .61576 L F
.361 0 .065 r
.58545 .62074 m .58402 .61938 L .58392 .62191 L F
.58545 .62074 m .58685 .61893 L .58402 .61938 L F
0 .236 .707 r
.24691 .56063 m .25126 .56404 L .24846 .5638 L F
.585 .274 .408 r
.25126 .56404 m .24819 .56611 L .24846 .5638 L F
.849 .688 .683 r
.61233 .44293 m .61604 .44391 L .61532 .44135 L F
.826 .741 .77 r
.61306 .44615 m .61604 .44391 L .61233 .44293 L F
.614 .349 .492 r
.61579 .44613 m .61604 .44391 L .61306 .44615 L F
.558 .518 .767 r
.61532 .44135 m .61604 .44391 L .61816 .44316 L F
.429 .192 .451 r
.61816 .44316 m .61604 .44391 L .61579 .44613 L F
.593 .488 .704 r
.71027 .42881 m .70791 .43214 L .70674 .42829 L F
.71027 .42881 m .71063 .43163 L .70791 .43214 L F
.511 .223 .413 r
.71037 .43351 m .70791 .43214 L .71063 .43163 L F
.71037 .43351 m .70786 .43429 L .70791 .43214 L F
.748 .694 .8 r
.54091 .68923 m .54409 .69095 L .54357 .69255 L F
.54091 .68923 m .54462 .68958 L .54409 .69095 L F
.346 0 .047 r
.54409 .69095 m .5446 .69412 L .54357 .69255 L F
.246 0 0 r
.54732 .69068 m .54409 .69095 L .54462 .68958 L F
.54732 .69068 m .54631 .69158 L .54409 .69095 L F
.984 .786 .556 r
.54607 .69151 m .5446 .69412 L .54409 .69095 L F
.933 .68 .531 r
.5446 .69412 m .54495 .69347 L .54429 .69041 L F
.995 .765 .466 r
.54495 .69347 m .54497 .69357 L .54444 .69298 L F
.54497 .69357 m .54555 .69638 L .54476 .69397 L F
.54497 .69357 m .54476 .69397 L .54444 .69298 L F
.984 .786 .556 r
.54631 .69158 m .54498 .69355 L .54607 .69151 L F
.54498 .69355 m .5446 .69412 L .54607 .69151 L F
.484 .288 .538 r
.21722 .57552 m .21924 .575 L .21948 .57262 L F
.437 .212 .473 r
.21689 .5779 m .21924 .575 L .21722 .57552 L F
.825 .826 .849 r
.6073 .43445 m .60789 .43727 L .60485 .43733 L F
.813 .819 .855 r
.61053 .43451 m .60789 .43727 L .6073 .43445 L F
.557 .313 .501 r
.53845 .66328 m .53798 .66551 L .53565 .66358 L F
.53845 .66328 m .53798 .66551 L .53565 .66358 L F
.523 0 0 r
.50477 .69257 m .50783 .69398 L .50832 .69296 L F
.626 .233 .278 r
.50783 .69398 m .5107 .69218 L .50832 .69296 L F
.698 .694 .842 r
.45048 .58139 m .45424 .58152 L .45291 .58034 L F
.474 .224 .455 r
.48938 .70706 m .48983 .7047 L .49153 .70418 L F
.995 .822 .558 r
.649 .43473 m .64804 .43374 L .64834 .43066 L F
.917 .624 .473 r
.649 .43473 m .647 .43613 L .64804 .43374 L F
.649 .43473 m .64798 .43668 L .647 .43613 L F
.564 .657 .899 r
.69189 .41444 m .68857 .41307 L .69114 .4125 L F
.532 .62 .885 r
.69416 .41396 m .69189 .41444 L .69114 .4125 L F
.571 .583 .826 r
.69557 .41728 m .69189 .41444 L .69416 .41396 L F
.185 .535 .925 r
.24308 .54954 m .24222 .55038 L .24077 .54926 L F
.24308 .54954 m .24456 .55112 L .24222 .55038 L F
.086 .043 .507 r
.212 .59284 m .21317 .58945 L .21103 .59 L F
.212 .59284 m .21302 .59237 L .21317 .58945 L F
.451 .381 .687 r
.2118 .59541 m .21302 .59237 L .212 .59284 L F
0 0 0 r
.34794 .62777 m .34899 .62476 L .34747 .62496 L F
.34794 .62777 m .34835 .62703 L .34899 .62476 L F
.251 .654 .964 r
.34794 .62777 m .35046 .6282 L .34835 .62703 L F
.361 .166 .476 r
.22782 .61584 m .22578 .61914 L .22607 .61651 L F
.243 .65 .961 r
.2276 .54453 m .22951 .54469 L .22933 .54565 L F
.159 .562 .931 r
.22951 .54469 m .23111 .54602 L .22933 .54565 L F
.569 .601 .845 r
.69799 .4167 m .69557 .41728 L .69416 .41396 L F
.716 .774 .899 r
.4441 .57014 m .44554 .57261 L .44187 .57221 L F
.556 .612 .864 r
.44617 .56915 m .44554 .57261 L .4441 .57014 L F
.44617 .56915 m .44778 .57218 L .44554 .57261 L F
.87 .841 .815 r
.58592 .45865 m .58225 .46048 L .58459 .4575 L F
.846 .859 .852 r
.58837 .45597 m .58592 .45865 L .58459 .4575 L F
.917 .871 .777 r
.66297 .4516 m .66344 .45442 L .66501 .45208 L F
.608 .88 .991 r
.53774 .64484 m .53858 .64593 L .5351 .64577 L F
.788 .578 .616 r
.53858 .64593 m .53416 .64795 L .5351 .64577 L F
0 .048 .603 r
.53729 .64906 m .53827 .6504 L .53817 .65022 L F
.788 .578 .616 r
.53858 .64593 m .53729 .64906 L .53587 .64717 L F
0 .048 .603 r
.53729 .64906 m .53817 .65022 L .53697 .64814 L F
.788 .578 .616 r
.53587 .64717 m .53729 .64906 L .53416 .64795 L F
.467 0 0 r
.53743 .64646 m .53858 .64593 L .5367 .64614 L F
.53841 .64689 m .5367 .64614 L .53816 .64682 L F
.897 .964 .825 r
.5367 .64614 m .53858 .64593 L .53774 .64484 L F
.534 .336 .559 r
.53697 .64814 m .53774 .64484 L .53604 .64696 L F
.5367 .64614 m .53774 .64484 L .53556 .64561 L F
.897 .964 .825 r
.53596 .64622 m .5367 .64614 L .53774 .64484 L F
.821 .623 .634 r
.53596 .64622 m .53774 .64484 L .53737 .64645 L F
.53596 .64622 m .53737 .64645 L .53697 .64814 L F
.467 0 0 r
.53841 .64689 m .53846 .64663 L .53743 .64646 L F
.53846 .64663 m .53858 .64593 L .53743 .64646 L F
.53816 .64682 m .5367 .64614 L .53596 .64622 L F
.534 .336 .559 r
.53604 .64696 m .5367 .64614 L .5351 .64577 L F
.5367 .64614 m .53556 .64561 L .5351 .64577 L F
.467 0 0 r
.53841 .64689 m .53988 .64653 L .53858 .64593 L F
.643 .259 .302 r
.42239 .63406 m .42092 .63619 L .41892 .63437 L F
.346 0 0 r
.42471 .63501 m .42092 .63619 L .42239 .63406 L F
0 .031 .598 r
.63012 .45956 m .6314 .46309 L .6301 .46125 L F
.548 .725 .956 r
.63219 .43734 m .62981 .43778 L .62892 .4363 L F
.242 .17 .572 r
.62649 .41535 m .62647 .41221 L .62584 .41395 L F
.62649 .41535 m .62469 .41434 L .62489 .41384 L F
.62584 .41395 m .62489 .41384 L .6253 .41278 L F
.62649 .41535 m .62489 .41384 L .62584 .41395 L F
.62649 .41535 m .62602 .41397 L .62647 .41221 L F
.555 .572 .826 r
.62602 .41397 m .62584 .41395 L .62647 .41221 L F
.242 .17 .572 r
.62602 .41397 m .62547 .41236 L .62647 .41221 L F
.555 .572 .826 r
.62618 .41399 m .62602 .41397 L .62647 .41221 L F
.6278 .41185 m .62618 .41399 L .62647 .41221 L F
.242 .17 .572 r
.62649 .41535 m .62584 .41395 L .62551 .41487 L F
.555 .572 .826 r
.62618 .41399 m .62551 .41487 L .62584 .41395 L F
.242 .17 .572 r
.62649 .41535 m .6253 .41278 L .62547 .41236 L F
.62649 .41535 m .62551 .4169 L .62469 .41434 L F
.615 .616 .828 r
.7005 .41605 m .69923 .42014 L .69799 .4167 L F
.7005 .41605 m .70175 .41946 L .69923 .42014 L F
.534 0 0 r
.66924 .42301 m .67171 .42454 L .67351 .42465 L F
.334 0 0 r
.67351 .42465 m .67171 .42454 L .67544 .42523 L F
0 0 0 r
.67468 .42318 m .67351 .42465 L .67416 .424 L F
.163 .544 .926 r
.21547 .5559 m .21651 .55528 L .21398 .5549 L F
.21547 .5559 m .21832 .55688 L .21651 .55528 L F
.695 .733 .88 r
.61062 .44972 m .61437 .451 L .61303 .449 L F
.86 .95 .872 r
.66221 .41766 m .65978 .42016 L .65911 .41906 L F
.98 .774 .555 r
.66004 .42225 m .65911 .41906 L .65978 .42016 L F
.959 .644 .386 r
.51353 .71621 m .51223 .71788 L .51212 .71562 L F
.51353 .71621 m .51223 .71788 L .51212 .71562 L F
.57 .291 .453 r
.58716 .49336 m .58964 .49512 L .58693 .49559 L F
.58716 .49336 m .58973 .49305 L .58964 .49512 L F
0 .269 .744 r
.65859 .43386 m .66164 .43628 L .66019 .43445 L F
.028 0 .051 r
.50221 .69183 m .49933 .69548 L .50125 .69465 L F
.624 .233 .282 r
.50369 .6945 m .50221 .69183 L .50125 .69465 L F
.50369 .6945 m .50477 .69257 L .50221 .69183 L F
.784 .581 .627 r
.49444 .73001 m .49821 .73056 L .49827 .72757 L F
.396 .68 .975 r
.64593 .4619 m .6448 .4632 L .64368 .46336 L F
.583 .708 .929 r
.68963 .41014 m .68857 .41307 L .68708 .41068 L F
.68963 .41014 m .69114 .4125 L .68857 .41307 L F
.582 .211 .303 r
.6314 .46309 m .6337 .46361 L .6348 .46104 L F
0 0 0 r
.6348 .46104 m .6337 .46361 L .63719 .45953 L F
.396 .741 .992 r
.51486 .72684 m .51712 .72672 L .51615 .72781 L F
.51615 .72781 m .51712 .72672 L .51486 .72684 L F
.213 0 0 r
.70587 .44984 m .70512 .45115 L .70292 .45129 L F
.593 .579 .807 r
.70765 .44797 m .70587 .44984 L .70444 .44597 L F
0 0 0 r
.70713 .45008 m .70587 .44984 L .70765 .44797 L F
.70713 .45008 m .70512 .45115 L .70587 .44984 L F
0 .072 .634 r
.54869 .66392 m .54799 .66208 L .54637 .65962 L F
.974 .826 .633 r
.54819 .66601 m .54799 .66208 L .54869 .66392 L F
.723 .617 .739 r
.54677 .68698 m .54835 .69025 L .54462 .68958 L F
.69 .276 .255 r
.54462 .68958 m .54732 .69068 L .54835 .69025 L F
.914 .752 .666 r
.54835 .69025 m .54828 .69294 L .54732 .69068 L F
.66 .137 0 r
.54835 .69025 m .54832 .69053 L .54732 .69068 L F
.54835 .69025 m .55 .69204 L .54832 .69053 L F
.586 .657 .887 r
.36116 .63282 m .36205 .63018 L .36044 .63103 L F
.36116 .63282 m .36263 .6323 L .36205 .63018 L F
.99 .773 .517 r
.52826 .71962 m .52984 .71937 L .52953 .72046 L F
.52826 .71962 m .52953 .72046 L .52866 .72046 L F
.488 .559 .854 r
.53033 .71601 m .52984 .71937 L .52826 .71962 L F
.212 .051 .434 r
.53152 .71601 m .53115 .71848 L .52984 .71937 L F
.488 .559 .854 r
.53033 .71601 m .53115 .71848 L .52984 .71937 L F
.99 .773 .517 r
.52826 .71962 m .52921 .7216 L .52782 .72069 L F
.848 .991 .847 r
.53115 .71848 m .53041 .71796 L .52804 .72046 L F
.52818 .72046 m .52804 .72046 L .52782 .72069 L F
.53115 .71848 m .52804 .72046 L .52818 .72046 L F
.99 .773 .517 r
.52866 .72046 m .52953 .72046 L .52921 .7216 L F
.088 0 .237 r
.52984 .71937 m .53115 .71848 L .52921 .7216 L F
.904 .516 .086 r
.66454 .42896 m .66413 .42987 L .66351 .42776 L F
.66454 .42896 m .66523 .43101 L .66413 .42987 L F
0 0 0 r
.38936 .58148 m .39147 .58095 L .3924 .58068 L F
.164 0 0 r
.3924 .58068 m .39147 .58095 L .39497 .58057 L F
.391 .152 .427 r
.53417 .67235 m .53633 .67188 L .53661 .66917 L F
.475 .848 .617 r
.53661 .66917 m .53784 .66812 L .5389 .66743 L F
.324 .098 .408 r
.53661 .66917 m .53845 .67064 L .53784 .66812 L F
.53661 .66917 m .53633 .67188 L .53845 .67064 L F
.888 .468 .073 r
.63456 .44655 m .63334 .44566 L .63186 .44286 L F
.89 .841 .79 r
.59153 .44844 m .59298 .44964 L .59081 .45284 L F
.873 .846 .814 r
.59516 .44664 m .59298 .44964 L .59153 .44844 L F
.746 .848 .926 r
.62237 .41972 m .62271 .42125 L .62447 .41886 L F
0 .236 .707 r
.24691 .56063 m .25066 .56339 L .25126 .56404 L F
.585 .274 .408 r
.25126 .56404 m .25067 .56603 L .24819 .56611 L F
.767 .937 .939 r
.25126 .56404 m .25091 .56176 L .25318 .56319 L F
.25126 .56404 m .25066 .56339 L .25091 .56176 L F
.242 0 .273 r
.25318 .56319 m .25067 .56603 L .25126 .56404 L F
.168 0 0 r
.54065 .67804 m .54438 .67799 L .54178 .67798 L F
.101 0 0 r
.54178 .67798 m .54438 .67799 L .54683 .67776 L F
.873 .846 .814 r
.59516 .44664 m .59153 .44844 L .59397 .44552 L F
.813 .888 .898 r
.5978 .44424 m .59516 .44664 L .59397 .44552 L F
.604 .806 .978 r
.70369 .44586 m .70444 .44597 L .70195 .4467 L F
.703 .878 .963 r
.55275 .6893 m .55571 .68925 L .55499 .68809 L F
.996 .867 .567 r
.55499 .68809 m .55571 .68925 L .55599 .68455 L F
0 0 0 r
.21924 .575 m .22158 .5718 L .21948 .57262 L F
.812 .889 .899 r
.54683 .67776 m .54438 .67799 L .54699 .67687 L F
.666 .858 .973 r
.44146 .57675 m .44089 .57868 L .44363 .57802 L F
.756 .942 .943 r
.44146 .57675 m .43784 .5787 L .44089 .57868 L F
.56 .404 .627 r
.51918 .71145 m .52149 .7119 L .52034 .71013 L F
.926 .706 .585 r
.60776 .45652 m .60964 .45813 L .60823 .45498 L F
.862 .788 .776 r
.60578 .46007 m .60964 .45813 L .60776 .45652 L F
.60578 .46007 m .60751 .461 L .60964 .45813 L F
.77 .334 .215 r
.54607 .65833 m .54637 .65962 L .5434 .65918 L F
.661 .691 .867 r
.44714 .58083 m .45048 .58139 L .44881 .57974 L F
.699 .698 .846 r
.44881 .57974 m .45048 .58139 L .45291 .58034 L F
.884 .452 .122 r
.47269 .71844 m .47274 .71672 L .47244 .71553 L F
.47269 .71844 m .47405 .71892 L .47274 .71672 L F
.533 .715 .956 r
.5391 .65182 m .54033 .65048 L .53827 .6504 L F
.5391 .65182 m .54135 .65148 L .54033 .65048 L F
.118 .152 .622 r
.51696 .70473 m .51809 .70316 L .51609 .70323 L F
.51696 .70473 m .5178 .70462 L .51809 .70316 L F
.432 .555 .879 r
.71043 .43549 m .70938 .43719 L .70786 .43429 L F
.781 .278 0 r
.70908 .43536 m .70973 .43654 L .71043 .43549 L F
.615 .128 .075 r
.70973 .43654 m .71074 .435 L .71043 .43549 L F
.747 .664 .769 r
.7129 .43341 m .71043 .43549 L .71037 .43351 L F
.665 .489 .636 r
.7128 .43072 m .71037 .43351 L .71063 .43163 L F
.907 .976 .795 r
.71043 .43549 m .7109 .43476 L .71091 .43473 L F
.665 .489 .636 r
.7128 .43072 m .71286 .43225 L .71037 .43351 L F
.71286 .43225 m .71192 .43345 L .71037 .43351 L F
.907 .976 .795 r
.71053 .43521 m .71091 .43473 L .71173 .43164 L F
.71043 .43549 m .71091 .43473 L .71053 .43521 L F
.665 .489 .636 r
.71286 .43225 m .7129 .43341 L .71192 .43345 L F
.615 .128 .075 r
.71074 .435 m .7109 .43476 L .71043 .43549 L F
.432 .555 .879 r
.71043 .43549 m .70948 .43738 L .70938 .43719 L F
.411 .529 .866 r
.71043 .43549 m .7119 .4373 L .70948 .43738 L F
.318 .085 .395 r
.71156 .44002 m .70948 .43738 L .7119 .4373 L F
.765 .773 .859 r
.56679 .4895 m .56431 .49359 L .56442 .49242 L F
.56679 .4895 m .56846 .49083 L .56431 .49359 L F
.391 .288 .617 r
.49672 .69565 m .4988 .69753 L .49933 .69548 L F
.49672 .69565 m .49733 .69848 L .4988 .69753 L F
0 0 0 r
.65145 .42789 m .64834 .43066 L .64942 .42962 L F
.65145 .42789 m .64834 .43066 L .64942 .42962 L F
.58 .066 0 r
.43556 .57312 m .43808 .57416 L .43969 .57328 L F
.585 .922 .71 r
.43969 .57328 m .44095 .57191 L .44187 .57221 L F
.43969 .57328 m .43808 .57416 L .44095 .57191 L F
.257 .539 .922 r
.2466 .55178 m .24553 .55265 L .24456 .55112 L F
.2466 .55178 m .24851 .55398 L .24553 .55265 L F
.826 .731 .759 r
.67033 .4548 m .67328 .4553 L .67138 .45796 L F
.361 .046 .289 r
.5807 .62279 m .58392 .62191 L .58141 .62257 L F
.807 .741 .79 r
.5807 .62279 m .58141 .62257 L .57899 .62245 L F
.601 .158 .171 r
.39561 .62969 m .39808 .6303 L .3996 .62854 L F
.623 .185 .187 r
.3996 .62854 m .39808 .6303 L .40161 .63018 L F
.697 .657 .806 r
.68161 .44817 m .67761 .45179 L .67796 .44925 L F
.837 .774 .792 r
.57312 .47268 m .57384 .47577 L .57092 .47535 L F
.844 .76 .77 r
.57092 .47535 m .57384 .47577 L .57179 .4789 L F
.648 .577 .761 r
.57308 .62795 m .57601 .62556 L .5734 .6258 L F
.563 .367 .574 r
.24562 .80458 m .24796 .80389 L .24809 .80116 L F
.24562 .80458 m .24796 .80389 L .24809 .80116 L F
.185 0 0 r
.1901 .54211 m .19217 .54187 L .19408 .54065 L F
.162 0 0 r
.19217 .54187 m .19546 .54079 L .19408 .54065 L F
.19259 .54173 m .19428 .54164 L .19546 .54079 L F
.19217 .54187 m .19428 .54164 L .19259 .54173 L F
.502 0 0 r
.19546 .54079 m .19428 .54164 L .19818 .54172 L F
.165 .694 .863 r
.19214 .54126 m .19603 .54154 L .19428 .54164 L F
.19603 .54154 m .19624 .54156 L .19428 .54164 L F
0 .568 .772 r
.19035 .54117 m .19421 .54163 L .19217 .54187 L F
.19421 .54163 m .19428 .54164 L .19217 .54187 L F
.185 0 0 r
.19008 .54212 m .19217 .54187 L .1901 .54211 L F
.673 .462 .591 r
.71035 .44355 m .70807 .44609 L .70795 .44382 L F
.71035 .44355 m .71047 .44611 L .70807 .44609 L F
.659 .572 .746 r
.71156 .44002 m .71317 .44328 L .71035 .44355 L F
.651 .445 .592 r
.7135 .44506 m .71035 .44355 L .71317 .44328 L F
.7135 .44506 m .71047 .44611 L .71035 .44355 L F
.409 .236 .534 r
.47234 .72051 m .47405 .71892 L .47269 .71844 L F
.195 .726 .783 r
.45899 .57904 m .45752 .57909 L .4551 .57954 L F
.762 .665 .755 r
.4611 .57526 m .45899 .57904 L .45756 .57476 L F
.357 0 0 r
.46097 .57917 m .45752 .57909 L .45899 .57904 L F
.687 .567 .715 r
.46098 .57852 m .45899 .57904 L .4611 .57526 L F
.223 0 0 r
.46098 .57852 m .46097 .57917 L .45899 .57904 L F
.633 .587 .784 r
.53312 .65429 m .53107 .65556 L .52983 .65281 L F
.52983 .65281 m .53107 .65556 L .53312 .65429 L F
.52983 .65281 m .53107 .65556 L .53312 .65429 L F
.46 .854 .976 r
.56007 .63075 m .55937 .63022 L .56209 .63065 L F
.76 .919 .942 r
.56209 .63065 m .56253 .62861 L .56428 .63033 L F
.56209 .63065 m .55937 .63022 L .56253 .62861 L F
.459 .161 .372 r
.38933 .59638 m .38932 .59899 L .3857 .59976 L F
.452 .156 .371 r
.39185 .59746 m .38932 .59899 L .38933 .59638 L F
.562 .237 .376 r
.49198 .70148 m .49407 .70011 L .49505 .70081 L F
.652 .456 .606 r
.49768 .70129 m .49655 .70258 L .49505 .70081 L F
.49655 .70258 m .49515 .70417 L .49505 .70081 L F
.49768 .70129 m .49517 .70083 L .4963 .70157 L F
0 .27 .776 r
.4963 .70157 m .49495 .70069 L .49505 .70081 L F
.49495 .70069 m .49407 .70011 L .49505 .70081 L F
.718 .988 .836 r
.49289 .69993 m .49407 .70011 L .49198 .70148 L F
.664 .541 .704 r
.49505 .70081 m .49153 .70418 L .49198 .70148 L F
.49505 .70081 m .49515 .70417 L .49153 .70418 L F
.486 0 0 r
.4963 .70157 m .49407 .70011 L .49289 .69993 L F
.62 .076 0 r
.62527 .45372 m .62462 .45221 L .62318 .45304 L F
.62527 .45372 m .6273 .45387 L .62462 .45221 L F
.367 0 0 r
.42396 .58644 m .42275 .58655 L .42083 .58594 L F
.38 .844 .832 r
.42498 .58575 m .42275 .58655 L .42396 .58644 L F
.509 .291 .518 r
.57249 .63701 m .57441 .63746 L .57538 .63458 L F
.465 0 0 r
.57249 .63701 m .57487 .63781 L .57441 .63746 L F
.423 0 0 r
.19298 .6331 m .1949 .63347 L .19223 .63358 L F
.958 .721 .536 r
.19151 .6306 m .19223 .63358 L .19298 .6331 L F
.825 .855 .87 r
.6693 .40655 m .66578 .40778 L .66792 .40487 L F
.76 .762 .854 r
.66792 .40487 m .67142 .40529 L .6693 .40655 L F
.677 .87 .972 r
.6523 .42257 m .6478 .42323 L .65016 .42142 L F
.375 .688 .98 r
.6526 .42142 m .6523 .42257 L .65016 .42142 L F
.6526 .42142 m .65365 .42268 L .6523 .42257 L F
0 0 .097 r
.5788 .62879 m .57875 .62708 L .57924 .62799 L F
.499 .395 .668 r
.3456 .6044 m .34768 .60391 L .3473 .60141 L F
.378 .273 .607 r
.3459 .60779 m .34768 .60391 L .3456 .6044 L F
.682 .18 .043 r
.39391 .62985 m .3936 .62788 L .39201 .6276 L F
.39391 .62985 m .39561 .62969 L .3936 .62788 L F
.63 .202 .211 r
.52569 .6808 m .52637 .68167 L .52748 .68051 L F
.45 .252 .518 r
.52748 .68051 m .52931 .68031 L .52944 .67785 L F
.488 .105 .239 r
.52637 .68167 m .52931 .68031 L .52748 .68051 L F
.419 .41 .742 r
.34741 .61365 m .34841 .60977 L .3464 .61019 L F
.34741 .61365 m .34912 .61317 L .34841 .60977 L F
.396 .327 .662 r
.34741 .61365 m .34962 .61563 L .34912 .61317 L F
.44 .841 .976 r
.53812 .67482 m .53679 .67439 L .53478 .67497 L F
.212 .709 .916 r
.53812 .67482 m .54077 .67487 L .53679 .67439 L F
.412 0 0 r
.1784 .55449 m .17462 .55558 L .17589 .55493 L F
.556 .893 .984 r
.20024 .55354 m .20032 .55489 L .20247 .5547 L F
.20024 .55354 m .19844 .55455 L .20032 .55489 L F
.584 .318 .479 r
.58138 .49633 m .58382 .49822 L .58146 .49838 L F
.614 .303 .42 r
.58138 .49633 m .58394 .49639 L .58382 .49822 L F
.574 .646 .884 r
.67719 .40475 m .6748 .40653 L .67389 .40458 L F
.397 0 .093 r
.41446 .58656 m .41059 .58873 L .41229 .58681 L F
.463 .841 .609 r
.20289 .62017 m .20315 .61868 L .20374 .61866 L F
.20289 .62017 m .20258 .62027 L .20315 .61868 L F
.20289 .62017 m .20089 .62157 L .20258 .62027 L F
.682 .415 .512 r
.20509 .60341 m .20732 .60429 L .20748 .60201 L F
.217 .036 .408 r
.20748 .60201 m .20876 .60347 L .2092 .60131 L F
.20748 .60201 m .20732 .60429 L .20876 .60347 L F
.846 .859 .852 r
.58837 .45597 m .58459 .4575 L .58709 .45473 L F
.861 .86 .838 r
.58709 .45473 m .58979 .45436 L .58837 .45597 L F
.366 0 .056 r
.39004 .63978 m .38848 .64165 L .38616 .64189 L F
.058 0 0 r
.39061 .64074 m .39004 .63978 L .39231 .63989 L F
.39061 .64074 m .38848 .64165 L .39004 .63978 L F
.573 .786 .979 r
.43347 .57353 m .42981 .57295 L .43212 .57193 L F
.541 .642 .899 r
.43448 .57123 m .43347 .57353 L .43212 .57193 L F
.43448 .57123 m .43556 .57312 L .43347 .57353 L F
.951 .62 .21 r
.66992 .43764 m .66921 .43855 L .66861 .43643 L F
.66992 .43764 m .67039 .43992 L .66921 .43855 L F
.565 .151 .215 r
.43064 .63345 m .42709 .63497 L .4283 .63353 L F
.247 .058 .416 r
.23816 .59727 m .23663 .59585 L .23808 .59481 L F
.23816 .59727 m .23611 .59832 L .23663 .59585 L F
.29 0 0 r
.38539 .58345 m .38774 .58313 L .38936 .58148 L F
.296 0 0 r
.38774 .58313 m .39147 .58095 L .38936 .58148 L F
.788 .709 .776 r
.54438 .67799 m .54823 .67873 L .54699 .67687 L F
.54472 .67805 m .54519 .68 L .54823 .67873 L F
.54438 .67799 m .54463 .6786 L .54472 .67805 L F
.54463 .6786 m .54519 .68 L .54472 .67805 L F
.712 .672 .809 r
.54444 .67955 m .54558 .68095 L .54438 .67799 L F
.458 .461 .774 r
.54529 .67871 m .54441 .68253 L .54444 .67971 L F
.54447 .67952 m .54444 .67971 L .54444 .67955 L F
.54529 .67871 m .54444 .67971 L .54447 .67952 L F
.112 .524 .912 r
.54272 .67811 m .54529 .67871 L .54447 .67952 L F
.54415 .67931 m .54447 .67952 L .54444 .67955 L F
.54272 .67811 m .54447 .67952 L .54415 .67931 L F
.788 .709 .776 r
.54519 .68 m .54558 .68095 L .54605 .68056 L F
.54519 .68 m .54605 .68056 L .54823 .67873 L F
.612 .627 .842 r
.54699 .67687 m .54823 .67873 L .55019 .67756 L F
.116 .164 .637 r
.67057 .4212 m .66924 .42301 L .66886 .42003 L F
.218 .31 .745 r
.67057 .4212 m .67171 .42454 L .66924 .42301 L F
.86 .95 .872 r
.66221 .41766 m .65911 .41906 L .6612 .41688 L F
.768 .989 .894 r
.6642 .41595 m .66221 .41766 L .66333 .41556 L F
.714 .927 .962 r
.66333 .41556 m .66221 .41766 L .6612 .41688 L F
.661 .691 .867 r
.44714 .58083 m .44881 .57974 L .44636 .57953 L F
.868 .841 .817 r
.59081 .45284 m .58979 .45436 L .58709 .45473 L F
.96 .783 .618 r
.54723 .66797 m .54819 .66601 L .54894 .66926 L F
0 .151 .676 r
.54848 .67165 m .54723 .66797 L .54894 .66926 L F
.197 .354 .796 r
.5427 .65457 m .54388 .65324 L .54135 .65148 L F
.681 .792 .933 r
.45153 .5726 m .44778 .57218 L .45024 .57202 L F
.613 .906 .984 r
.45384 .57173 m .45153 .5726 L .45246 .57108 L F
.692 .609 .759 r
.44796 .56911 m .45246 .57108 L .45024 .57202 L F
.609 .902 .986 r
.45153 .5726 m .45025 .57202 L .45246 .57108 L F
.45025 .57202 m .45028 .572 L .45246 .57108 L F
.692 .609 .759 r
.44796 .56911 m .45137 .572 L .45246 .57108 L F
.457 .576 .885 r
.4497 .56676 m .45114 .57127 L .44796 .56911 L F
.45114 .57127 m .45137 .572 L .45083 .57154 L F
.45114 .57127 m .45083 .57154 L .44796 .56911 L F
.609 .902 .986 r
.45025 .57202 m .45024 .57202 L .45028 .572 L F
.723 .521 .618 r
.70795 .44382 m .70444 .44597 L .70369 .44586 L F
.70795 .44382 m .70807 .44609 L .70444 .44597 L F
.561 0 0 r
.66325 .44875 m .66423 .44926 L .66342 .44653 L F
.463 .885 .915 r
.41158 .57658 m .41348 .57586 L .41559 .57586 L F
.491 .898 .921 r
.41559 .57586 m .41654 .57488 L .41788 .57516 L F
.41559 .57586 m .41348 .57586 L .41654 .57488 L F
.574 .779 .976 r
.44363 .57802 m .44389 .57591 L .44146 .57675 L F
.44363 .57802 m .44586 .57723 L .44389 .57591 L F
.563 .617 .864 r
.44363 .57802 m .44636 .57953 L .44586 .57723 L F
.53 .837 .999 r
.67544 .42523 m .67886 .42544 L .67776 .42454 L F
.689 .903 .972 r
.67776 .42454 m .67886 .42544 L .68154 .42318 L F
.665 .882 .979 r
.67521 .41283 m .67652 .4138 L .67736 .41166 L F
.44 .528 .851 r
.44586 .57723 m .44636 .57953 L .44769 .57701 L F
.541 .654 .909 r
.44636 .57953 m .44881 .57974 L .44769 .57701 L F
.797 .856 .894 r
.64506 .46726 m .6485 .46669 L .64716 .46588 L F
.982 .707 .421 r
.64716 .46588 m .6485 .46669 L .64711 .4633 L F
.849 .688 .683 r
.61233 .44293 m .61532 .44135 L .61468 .44026 L F
.691 .845 .957 r
.61468 .44026 m .61532 .44135 L .61787 .44037 L F
.558 .518 .767 r
.61532 .44135 m .61816 .44316 L .61787 .44037 L F
0 .362 .809 r
.55885 .63913 m .55919 .63881 L .55689 .63823 L F
.55885 .63913 m .56042 .64003 L .55919 .63881 L F
.646 .58 .766 r
.70898 .42529 m .70674 .42829 L .70644 .42584 L F
.70898 .42529 m .71027 .42881 L .70674 .42829 L F
.996 .79 .51 r
.63972 .44768 m .64117 .44997 L .64119 .4468 L F
.53 .044 0 r
.55311 .68076 m .55019 .67756 L .55241 .6782 L F
.642 .41 .552 r
.60067 .48773 m .60077 .49005 L .59812 .49 L F
.563 .349 .548 r
.60291 .48956 m .60067 .48773 L .60418 .48616 L F
.60291 .48956 m .60077 .49005 L .60067 .48773 L F
.656 .504 .666 r
.53214 .67496 m .53478 .67497 L .53417 .67235 L F
.474 .391 .682 r
.53478 .67497 m .53633 .67188 L .53417 .67235 L F
.758 .719 .816 r
.64811 .44468 m .65038 .44867 L .64673 .44798 L F
.269 .215 .61 r
.46306 .57705 m .46098 .57852 L .4611 .57526 L F
0 0 0 r
.46306 .57705 m .46097 .57917 L .46098 .57852 L F
.67 .418 .531 r
.53204 .67708 m .53478 .67497 L .53214 .67496 L F
.334 .773 .965 r
.68303 .46046 m .68556 .46024 L .68659 .46084 L F
.509 .893 .959 r
.68659 .46084 m .68813 .45957 L .68892 .4601 L F
.495 .865 .984 r
.68659 .46084 m .68556 .46024 L .68813 .45957 L F
.653 .748 .919 r
.68892 .4601 m .69049 .46075 L .68659 .46084 L F
.57 .526 .766 r
.68995 .46354 m .68659 .46084 L .69049 .46075 L F
.155 0 .228 r
.52931 .68031 m .53204 .67708 L .52944 .67785 L F
.532 .306 .517 r
.2092 .60131 m .21187 .59826 L .20982 .59901 L F
.216 0 0 r
.39595 .63936 m .3946 .63985 L .39231 .63989 L F
.24 0 0 r
.39825 .63927 m .3946 .63985 L .39595 .63936 L F
.969 .769 .58 r
.60645 .45375 m .60823 .45498 L .6084 .45226 L F
.835 .992 .856 r
.60895 .44997 m .6084 .45226 L .61062 .44972 L F
.862 .987 .712 r
.60645 .45375 m .6084 .45226 L .60895 .44997 L F
.755 .405 0 r
.55066 .65555 m .55097 .65661 L .55151 .6576 L F
.888 .619 .103 r
.55128 .659 m .55151 .6576 L .55097 .65661 L F
.55128 .659 m .55192 .66043 L .55151 .6576 L F
.034 0 0 r
.17212 .54315 m .17597 .54269 L .17323 .54314 L F
.457 .008 .095 r
.40496 .62953 m .4074 .62955 L .40532 .62859 L F
.766 .619 .697 r
.54314 .68617 m .54462 .68958 L .54091 .68923 L F
.707 .593 .726 r
.54677 .68698 m .54462 .68958 L .54314 .68617 L F
.469 .069 .197 r
.52888 .69007 m .53097 .69119 L .52864 .69149 L F
.444 .107 .298 r
.53157 .68955 m .53097 .69119 L .52888 .69007 L F
.966 .741 .547 r
.67722 .43508 m .67783 .43471 L .67659 .43112 L F
.866 .508 .37 r
.67803 .4361 m .67783 .43471 L .67722 .43508 L F
.634 .598 .796 r
.67659 .43112 m .67783 .43471 L .6807 .43361 L F
.799 .505 .49 r
.68146 .43752 m .67783 .43471 L .67803 .4361 L F
.691 .441 .541 r
.52034 .71013 m .52149 .7119 L .52424 .71021 L F
.868 .841 .817 r
.59081 .45284 m .58709 .45473 L .58953 .45168 L F
.89 .841 .79 r
.59153 .44844 m .59081 .45284 L .58953 .45168 L F
.249 .696 .957 r
.22158 .54362 m .22368 .54353 L .22533 .54446 L F
.316 .718 .979 r
.22368 .54353 m .2276 .54453 L .22533 .54446 L F
.378 .273 .607 r
.3459 .60779 m .34763 .60744 L .34768 .60391 L F
.49 .432 .719 r
.3464 .61019 m .34763 .60744 L .3459 .60779 L F
.498 .576 .865 r
.37311 .63546 m .37377 .63724 L .37537 .63548 L F
.636 .471 .642 r
.37377 .63724 m .37692 .63939 L .37537 .63548 L F
.37377 .63724 m .37426 .63985 L .37692 .63939 L F
.404 .271 .584 r
.23011 .60997 m .23018 .6128 L .2281 .61352 L F
.347 .156 .474 r
.23018 .6128 m .22782 .61584 L .2281 .61352 L F
.79 .296 .017 r
.68278 .44899 m .68416 .44932 L .6833 .45002 L F
.555 .341 .544 r
.68159 .45206 m .68413 .45162 L .68416 .44932 L F
.577 .359 .547 r
.68416 .44932 m .68413 .45162 L .68683 .45095 L F
.102 0 0 r
.68416 .44932 m .6855 .44999 L .6833 .45002 L F
.577 .359 .547 r
.68416 .44932 m .68683 .45095 L .68635 .44861 L F
.492 .334 .594 r
.68683 .45095 m .68895 .44804 L .68635 .44861 L F
.235 0 0 r
.68605 .4491 m .68794 .44924 L .6855 .44999 L F
.68635 .44861 m .68701 .44887 L .68605 .4491 L F
.68701 .44887 m .68794 .44924 L .68605 .4491 L F
.68635 .44861 m .68895 .44804 L .68873 .4483 L F
.68635 .44861 m .68873 .4483 L .68769 .44866 L F
.68701 .44887 m .68841 .44869 L .68701 .44887 L F
.68635 .44861 m .68803 .44867 L .68712 .44885 L F
.318 .261 .635 r
.68572 .44609 m .68712 .44885 L .68811 .44685 L F
.68712 .44885 m .68714 .44887 L .68715 .44885 L F
.68712 .44885 m .68715 .44885 L .68811 .44685 L F
.235 0 0 r
.68691 .44883 m .68712 .44885 L .68701 .44887 L F
.68635 .44861 m .68712 .44885 L .68691 .44883 L F
.68803 .44867 m .68841 .44869 L .68701 .44887 L F
.581 .378 .571 r
.68668 .44889 m .68696 .44888 L .68704 .44869 L F
.68696 .44888 m .68714 .44887 L .68712 .44885 L F
.68696 .44888 m .68712 .44885 L .68704 .44869 L F
.68668 .44889 m .68704 .44869 L .68572 .44609 L F
.797 .837 .881 r
.68811 .44685 m .68715 .44885 L .68587 .44672 L F
.68715 .44885 m .68714 .44887 L .68713 .44886 L F
.68715 .44885 m .68713 .44886 L .68581 .44662 L F
.529 .711 .955 r
.68701 .44887 m .68714 .44887 L .68699 .44888 L F
.68713 .44886 m .68714 .44887 L .68701 .44887 L F
.235 0 0 r
.68701 .44887 m .68841 .44869 L .68794 .44924 L F
.529 .711 .955 r
.68712 .44885 m .68713 .44886 L .68701 .44887 L F
.581 .378 .571 r
.68456 .44894 m .68668 .44889 L .68601 .44693 L F
.68456 .44894 m .68601 .44693 L .68572 .44609 L F
.68278 .44899 m .68456 .44894 L .68572 .44609 L F
.529 .711 .955 r
.68574 .44667 m .68712 .44885 L .68278 .44899 L F
.68712 .44885 m .68699 .44888 L .68668 .44889 L F
.68676 .44886 m .68668 .44889 L .68278 .44899 L F
.68712 .44885 m .68668 .44889 L .68676 .44886 L F
.102 0 0 r
.68416 .44932 m .68635 .44861 L .68605 .4491 L F
.68544 .44931 m .68605 .4491 L .68592 .4493 L F
.68416 .44932 m .68605 .4491 L .68544 .44931 L F
.589 .46 .672 r
.68292 .44632 m .68572 .44609 L .68521 .44277 L F
.734 .651 .767 r
.68145 .44214 m .68292 .44632 L .68521 .44277 L F
.529 .711 .955 r
.68581 .44662 m .68278 .44899 L .68299 .4469 L F
.533 0 0 r
.68123 .44634 m .68299 .4469 L .67968 .44483 L F
.169 .693 .873 r
.68547 .4466 m .68299 .4469 L .68123 .44634 L F
.866 .707 .683 r
.68569 .44664 m .68591 .44621 L .68427 .4456 L F
.169 .693 .873 r
.68581 .44662 m .68573 .44663 L .68547 .4466 L F
.68573 .44663 m .68299 .4469 L .68547 .4466 L F
.866 .707 .683 r
.68453 .44899 m .68569 .44664 L .68566 .44662 L F
.68547 .4466 m .68566 .44662 L .68318 .4452 L F
.68569 .44664 m .68427 .4456 L .68318 .4452 L F
.169 .693 .873 r
.68581 .44662 m .68547 .4466 L .68318 .4452 L F
.842 .704 .71 r
.67968 .44483 m .68292 .44632 L .68145 .44214 L F
.169 .693 .873 r
.68547 .4466 m .68123 .44634 L .68318 .4452 L F
.866 .707 .683 r
.68361 .44639 m .68547 .4466 L .68318 .4452 L F
.68453 .44899 m .68566 .44662 L .68361 .44639 L F
.529 .711 .955 r
.68575 .44667 m .68577 .4467 L .68574 .44667 L F
.68577 .4467 m .68712 .44885 L .68574 .44667 L F
.858 .619 .577 r
.6862 .44666 m .68591 .44621 L .68563 .44677 L F
.797 .837 .881 r
.68811 .44685 m .6862 .44666 L .68591 .44621 L F
.858 .619 .577 r
.68621 .44666 m .68591 .44621 L .6862 .44666 L F
.797 .837 .881 r
.6862 .44666 m .68581 .44662 L .68591 .44621 L F
.529 .711 .955 r
.68581 .44662 m .68587 .44672 L .68575 .44667 L F
.68587 .44672 m .68712 .44885 L .68575 .44667 L F
.858 .619 .577 r
.68794 .44924 m .68641 .44697 L .68453 .44899 L F
.68641 .44697 m .68621 .44666 L .68609 .44682 L F
.68641 .44697 m .68609 .44682 L .68453 .44899 L F
.68621 .44666 m .68563 .44677 L .68453 .44899 L F
.797 .837 .881 r
.6862 .44666 m .68587 .44672 L .68581 .44662 L F
.68811 .44685 m .68587 .44672 L .6862 .44666 L F
.235 0 0 r
.68769 .44866 m .68873 .4483 L .68841 .44869 L F
.102 0 0 r
.68507 .44977 m .68592 .4493 L .6855 .44999 L F
.68416 .44932 m .68592 .4493 L .68507 .44977 L F
.163 .42 .859 r
.23752 .54708 m .23907 .54757 L .23861 .54908 L F
.355 .637 .96 r
.23907 .54757 m .24077 .54926 L .23861 .54908 L F
.573 .272 .42 r
.64177 .42936 m .63679 .43382 L .63703 .43132 L F
.633 .347 .468 r
.63703 .43132 m .64025 .43117 L .64177 .42936 L F
.361 .046 .289 r
.5807 .62279 m .58304 .62384 L .58392 .62191 L F
.383 .009 .198 r
.58065 .62453 m .58304 .62384 L .5807 .62279 L F
.736 .788 .894 r
.67038 .40356 m .67142 .40529 L .66792 .40487 L F
.61 .743 .94 r
.67298 .40286 m .67142 .40529 L .67038 .40356 L F
.67298 .40286 m .67389 .40458 L .67142 .40529 L F
.862 .807 .795 r
.57019 .47759 m .57179 .4789 L .56974 .48182 L F
.844 .76 .77 r
.57092 .47535 m .57179 .4789 L .57019 .47759 L F
.476 .703 .968 r
.66311 .41074 m .66649 .41219 L .66541 .41057 L F
.11 .193 .67 r
.66649 .41219 m .66834 .41153 L .66574 .41067 L F
.29 0 0 r
.66638 .41103 m .66834 .41153 L .66655 .41111 L F
.66541 .41057 m .66748 .41125 L .66638 .41103 L F
.66748 .41125 m .66834 .41153 L .66638 .41103 L F
0 .004 .574 r
.66595 .40976 m .66632 .41078 L .66596 .40977 L F
.66506 .40895 m .66616 .41056 L .66595 .40976 L F
.66616 .41056 m .66632 .41078 L .66595 .40976 L F
.66524 .40941 m .66655 .41111 L .66506 .40895 L F
.591 .869 .543 r
.66538 .40816 m .66311 .41074 L .66474 .40876 L F
.66578 .40778 m .66539 .40822 L .66538 .40816 L F
.66539 .40822 m .66311 .41074 L .66538 .40816 L F
.869 .849 .821 r
.66792 .40487 m .66578 .40778 L .66441 .40655 L F
.972 .669 .379 r
.66441 .40655 m .66578 .40778 L .66474 .40876 L F
.385 .261 .586 r
.66441 .40655 m .66474 .40876 L .66744 .4081 L F
.66578 .40868 m .66744 .4081 L .66605 .40909 L F
0 .004 .574 r
.66474 .40876 m .66503 .40894 L .66578 .40868 L F
.66567 .40853 m .66578 .40868 L .66725 .40816 L F
.66567 .40853 m .66725 .40816 L .66734 .40812 L F
.66734 .40812 m .66725 .40816 L .66744 .4081 L F
.385 .261 .586 r
.66441 .40655 m .66744 .4081 L .66578 .40868 L F
.75 .775 .873 r
.66589 .40882 m .66605 .40909 L .66632 .40861 L F
.385 .261 .586 r
.66578 .40868 m .66605 .40909 L .66584 .40876 L F
0 .004 .574 r
.66503 .40894 m .66584 .40942 L .66615 .40917 L F
.66578 .40868 m .66588 .40881 L .66744 .4081 L F
.722 .737 .863 r
.66744 .4081 m .66837 .40499 L .66632 .40861 L F
.66744 .4081 m .66632 .40861 L .66605 .40909 L F
0 .004 .574 r
.66588 .40881 m .66615 .40917 L .66744 .4081 L F
0 0 .406 r
.66584 .40876 m .66605 .40909 L .66589 .40882 L F
0 .004 .574 r
.66503 .40894 m .66615 .40917 L .66578 .40868 L F
.869 .849 .821 r
.66792 .40487 m .66441 .40655 L .66684 .40372 L F
.878 .968 .846 r
.66591 .40314 m .66441 .40655 L .66362 .40518 L F
.66591 .40314 m .66684 .40372 L .66441 .40655 L F
.66441 .40654 m .66441 .40655 L .66441 .40655 L F
.66591 .40314 m .66441 .40655 L .66441 .40654 L F
0 0 .406 r
.6637 .40528 m .66584 .40876 L .66405 .40572 L F
.66362 .40518 m .66385 .40554 L .6637 .40528 L F
.66385 .40554 m .66584 .40876 L .6637 .40528 L F
.66584 .40876 m .66589 .40882 L .66405 .40572 L F
.75 .775 .873 r
.66405 .40572 m .66589 .40882 L .66837 .40499 L F
.66589 .40882 m .66632 .40861 L .66837 .40499 L F
0 .004 .574 r
.66474 .40876 m .66578 .40868 L .66567 .40853 L F
.385 .261 .586 r
.66536 .40802 m .66578 .40868 L .66536 .40797 L F
.66578 .40868 m .66584 .40876 L .66536 .40797 L F
.66441 .40655 m .66536 .40802 L .66362 .40518 L F
.66536 .40802 m .66536 .40797 L .66362 .40518 L F
.504 .657 .929 r
.66474 .40876 m .66311 .41074 L .66541 .41057 L F
.29 0 0 r
.66541 .41057 m .66655 .41111 L .66474 .40876 L F
.761 .972 .924 r
.66167 .41173 m .66592 .40967 L .66101 .41306 L F
.66514 .40991 m .66592 .40967 L .66167 .41173 L F
.66592 .40967 m .66593 .40971 L .66101 .41306 L F
.794 .83 .879 r
.66425 .4129 m .66101 .41306 L .66593 .40971 L F
.66425 .4129 m .66593 .40971 L .66596 .40977 L F
0 .004 .574 r
.66578 .40939 m .66594 .40972 L .66584 .40942 L F
.802 .959 .914 r
.66584 .40942 m .66604 .40963 L .66592 .40967 L F
0 .004 .574 r
.66594 .40972 m .66596 .40977 L .66584 .40942 L F
.802 .959 .914 r
.66584 .40942 m .66592 .40967 L .66211 .41086 L F
.815 .904 .903 r
.66584 .40942 m .66521 .4108 L .66596 .40975 L F
.66521 .4108 m .66425 .4129 L .66538 .41084 L F
.66521 .4108 m .66538 .41084 L .66604 .40963 L F
.11 .193 .67 r
.6661 .41159 m .66574 .41067 L .66541 .41057 L F
.66649 .41219 m .66574 .41067 L .6661 .41159 L F
.815 .904 .903 r
.66576 .40959 m .66655 .41111 L .66425 .4129 L F
0 .004 .574 r
.66506 .40895 m .66596 .40977 L .66578 .40939 L F
.815 .904 .903 r
.66584 .40942 m .66588 .40952 L .66576 .40959 L F
0 .004 .574 r
.66632 .41078 m .66655 .41111 L .66584 .40942 L F
.815 .904 .903 r
.66588 .40952 m .66655 .41111 L .66576 .40959 L F
.761 .972 .924 r
.66211 .41086 m .66514 .40991 L .66167 .41173 L F
.66592 .40967 m .66604 .40963 L .66593 .40971 L F
.794 .83 .879 r
.66596 .40977 m .66593 .40971 L .66604 .40963 L F
.815 .904 .903 r
.66584 .40942 m .66596 .40975 L .66604 .40963 L F
0 .004 .574 r
.66474 .40876 m .66524 .40941 L .66506 .40895 L F
.11 .193 .67 r
.66649 .41219 m .66787 .41409 L .66834 .41153 L F
.217 0 .305 r
.2325 .60457 m .23176 .60685 L .23021 .60749 L F
.329 .185 .528 r
.23176 .60685 m .23011 .60997 L .23021 .60749 L F
.561 .341 .538 r
.60418 .48616 m .60637 .48894 L .60291 .48956 L F
.60418 .48616 m .60656 .48621 L .60637 .48894 L F
.984 .702 .386 r
.66068 .44132 m .66192 .4409 L .66103 .43977 L F
.66068 .44132 m .66205 .44276 L .66192 .4409 L F
.446 0 .076 r
.4105 .63738 m .40894 .63919 L .40655 .63917 L F
.337 0 .006 r
.41279 .63785 m .4105 .63738 L .41287 .63716 L F
.41279 .63785 m .40894 .63919 L .4105 .63738 L F
.352 .136 .439 r
.22346 .62454 m .22165 .6252 L .22389 .62216 L F
.345 .17 .495 r
.22316 .62695 m .22165 .6252 L .22346 .62454 L F
.22316 .62695 m .22143 .62767 L .22165 .6252 L F
.705 .372 .411 r
.69976 .45263 m .6999 .45436 L .69744 .45235 L F
.322 .096 .408 r
.7018 .45377 m .69976 .45263 L .70292 .45129 L F
.7018 .45377 m .6999 .45436 L .69976 .45263 L F
.272 0 .112 r
.21467 .58856 m .21785 .58599 L .2164 .58714 L F
.442 .005 .111 r
.37681 .58562 m .37918 .58555 L .38058 .58371 L F
.238 0 0 r
.37918 .58555 m .38294 .58334 L .38058 .58371 L F
.55 .509 .762 r
.68085 .40829 m .68362 .40665 L .68338 .40772 L F
.538 .658 .913 r
.68529 .4109 m .68085 .40829 L .6826 .40789 L F
.55 .509 .762 r
.68085 .40829 m .68129 .40858 L .68362 .40665 L F
.625 .648 .852 r
.68362 .40665 m .68227 .40777 L .67873 .40343 L F
.68227 .40777 m .68129 .40858 L .68057 .40713 L F
.68227 .40777 m .68057 .40713 L .67873 .40343 L F
.538 .658 .913 r
.68375 .40833 m .6826 .40789 L .68338 .40772 L F
.68529 .4109 m .6826 .40789 L .68375 .40833 L F
.382 .55 .896 r
.68708 .41068 m .68529 .4109 L .68338 .40772 L F
.561 .282 .45 r
.57641 .60423 m .57929 .60359 L .57685 .60178 L F
.526 .875 .988 r
.57641 .60423 m .57929 .60359 L .57685 .60178 L F
.477 .35 .628 r
.37909 .60669 m .37698 .61096 L .37649 .60727 L F
.978 .762 .543 r
.68281 .4331 m .68443 .4349 L .68379 .4368 L F
.406 .793 .99 r
.23111 .54602 m .2332 .5457 L .23488 .54646 L F
.195 .639 .945 r
.2332 .5457 m .23752 .54708 L .23488 .54646 L F
.902 .864 .793 r
.66212 .45315 m .66344 .45442 L .66297 .4516 L F
.95 .827 .688 r
.66066 .45683 m .66344 .45442 L .66212 .45315 L F
.66066 .45683 m .66206 .45814 L .66344 .45442 L F
.955 .621 .341 r
.52813 .65047 m .52993 .65183 L .52951 .65047 L F
.52813 .65047 m .52993 .65183 L .52951 .65047 L F
.826 .731 .759 r
.67033 .4548 m .67138 .45796 L .66967 .45723 L F
.735 .311 .242 r
.67138 .45796 m .67002 .45948 L .66967 .45723 L F
.67138 .45796 m .67345 .46004 L .67002 .45948 L F
.424 .787 .996 r
.45756 .57476 m .45981 .57443 L .4611 .57526 L F
.45756 .57476 m .45981 .57443 L .4611 .57526 L F
.489 .582 .874 r
.46285 .57312 m .4611 .57526 L .45981 .57443 L F
.46285 .57312 m .46395 .57553 L .4611 .57526 L F
.269 .215 .61 r
.46306 .57705 m .4611 .57526 L .46395 .57553 L F
.848 .853 .846 r
.43021 .58585 m .43034 .58736 L .42866 .58607 L F
.42866 .58607 m .43034 .58736 L .43021 .58585 L F
.927 .897 .779 r
.43021 .58585 m .43034 .58736 L .431 .5851 L F
.476 .812 .999 r
.50039 .7328 m .50179 .73369 L .4979 .73305 L F
.723 .442 .501 r
.50179 .73369 m .49819 .73627 L .4979 .73305 L F
.50179 .73369 m .5015 .73561 L .49819 .73627 L F
.872 .91 .853 r
.50352 .73137 m .50179 .73369 L .50039 .7328 L F
.573 .437 .657 r
.50352 .73137 m .50474 .73364 L .50179 .73369 L F
.421 .836 .658 r
.50474 .73364 m .5015 .73561 L .50179 .73369 L F
0 0 0 r
.65302 .46007 m .65445 .45965 L .65235 .46064 L F
.65302 .46007 m .65532 .45796 L .65445 .45965 L F
.167 0 0 r
.38451 .64174 m .38251 .64201 L .3802 .64191 L F
.156 0 0 r
.38616 .64189 m .38251 .64201 L .38451 .64174 L F
.993 .822 .569 r
.67176 .44367 m .67014 .44468 L .67025 .44227 L F
.67176 .44367 m .67123 .44596 L .67014 .44468 L F
.888 .838 .79 r
.614 .42684 m .61525 .42832 L .61294 .43171 L F
.875 .839 .806 r
.61777 .42461 m .61525 .42832 L .614 .42684 L F
.646 .93 .66 r
.55134 .51254 m .55368 .51057 L .5519 .51375 L F
.678 .18 0 r
.55411 .51562 m .55134 .51254 L .5519 .51375 L F
0 .351 .759 r
.22391 .56353 m .22416 .56346 L .22154 .56198 L F
.13 .075 .522 r
.22391 .56353 m .2251 .56531 L .22416 .56346 L F
.22391 .56353 m .22381 .56644 L .2251 .56531 L F
.526 .875 .988 r
.57641 .60423 m .58016 .60423 L .57929 .60359 L F
.623 .462 .643 r
.58016 .60423 m .57809 .60754 L .57641 .60423 L F
.797 .348 0 r
.57929 .60359 m .58016 .60423 L .57853 .60193 L F
.906 .494 .152 r
.58017 .60636 m .58016 .60423 L .57929 .60359 L F
.58017 .60636 m .58188 .60753 L .58016 .60423 L F
.786 .767 .837 r
.6096 .43139 m .61053 .43451 L .60918 .43272 L F
.813 .819 .855 r
.61053 .43451 m .6073 .43445 L .60918 .43272 L F
.813 .782 .823 r
.61294 .43171 m .61053 .43451 L .6096 .43139 L F
.707 .662 .803 r
.49241 .73334 m .49573 .73364 L .49444 .73001 L F
.517 .55 .829 r
.49444 .73001 m .49573 .73364 L .4979 .73305 L F
.753 .331 .248 r
.49573 .73364 m .49819 .73627 L .49417 .73551 L F
.467 .354 .642 r
.4979 .73305 m .49819 .73627 L .49573 .73364 L F
.753 .331 .248 r
.49573 .73364 m .49677 .73503 L .4979 .73305 L F
.49573 .73364 m .49417 .73551 L .49677 .73503 L F
.646 .93 .66 r
.55134 .51254 m .55362 .51034 L .55368 .51057 L F
.795 .919 .922 r
.55336 .50858 m .55669 .50831 L .55368 .51057 L F
.722 .508 0 r
.55368 .51057 m .55362 .51034 L .55336 .50858 L F
.615 .649 .86 r
.69201 .45828 m .69049 .46075 L .68892 .4601 L F
.69201 .45828 m .69274 .46129 L .69049 .46075 L F
.539 .366 .595 r
.69254 .46275 m .69049 .46075 L .69274 .46129 L F
.69254 .46275 m .68995 .46354 L .69049 .46075 L F
0 .35 .718 r
.48829 .68797 m .48553 .68673 L .48778 .6888 L F
.645 .419 .562 r
.49104 .6882 m .48829 .68797 L .48778 .6888 L F
.875 .839 .806 r
.61777 .42461 m .614 .42684 L .61642 .42389 L F
.815 .923 .908 r
.62008 .42239 m .61777 .42461 L .61642 .42389 L F
.534 .386 .626 r
.62008 .42239 m .62061 .42485 L .61777 .42461 L F
.308 .259 .639 r
.61972 .42713 m .61777 .42461 L .62061 .42485 L F
.293 .025 .325 r
.56003 .51081 m .56239 .50806 L .56218 .50983 L F
.532 .219 .383 r
.56218 .50983 m .56239 .50806 L .56469 .50956 L F
.536 .215 .372 r
.56239 .50806 m .56519 .50783 L .56469 .50956 L F
.322 .801 .736 r
.46624 .63206 m .47017 .63071 L .46865 .63222 L F
.182 0 0 r
.47017 .63071 m .471 .6316 L .46865 .63222 L F
.47017 .63071 m .47237 .63024 L .471 .6316 L F
.862 .807 .795 r
.57019 .47759 m .56974 .48182 L .56789 .48063 L F
.892 .756 .706 r
.56974 .48182 m .56896 .4841 L .56789 .48063 L F
.477 .35 .628 r
.37909 .60669 m .37966 .61061 L .37698 .61096 L F
.455 .388 .693 r
.37936 .6124 m .37698 .61096 L .37966 .61061 L F
.37936 .6124 m .37763 .61328 L .37698 .61096 L F
.519 .328 .561 r
.48545 .68925 m .48778 .6888 L .48553 .68673 L F
.972 .876 .68 r
.55558 .67967 m .55432 .68311 L .55556 .68368 L F
.423 .331 .647 r
.55556 .68368 m .5579 .68602 L .55599 .68455 L F
.996 .867 .567 r
.55499 .68809 m .55599 .68455 L .5579 .68602 L F
.696 .603 .748 r
.55386 .68502 m .5579 .68602 L .55556 .68368 L F
.348 0 0 r
.63839 .43867 m .64074 .43879 L .64145 .43789 L F
.684 .165 0 r
.64074 .43879 m .64427 .44014 L .64145 .43789 L F
.437 .864 .937 r
.68135 .43806 m .68025 .43734 L .68105 .43822 L F
.554 0 0 r
.68025 .43734 m .68146 .43752 L .67898 .43649 L F
.437 .864 .937 r
.68379 .4368 m .68146 .43752 L .68025 .43734 L F
.68379 .4368 m .68025 .43734 L .68135 .43806 L F
.554 0 0 r
.68025 .43734 m .67898 .43649 L .67803 .4361 L F
.902 .676 .587 r
.60426 .46394 m .60751 .461 L .60578 .46007 L F
.60426 .46394 m .60736 .46348 L .60751 .461 L F
.806 .424 .333 r
.61055 .46319 m .60751 .461 L .60736 .46348 L F
.659 .664 .843 r
.54487 .68482 m .54677 .68698 L .54314 .68617 L F
0 0 0 r
.54677 .68698 m .54841 .68628 L .54962 .68408 L F
.321 .529 .901 r
.54487 .68482 m .54841 .68628 L .54677 .68698 L F
.197 .019 .4 r
.21635 .63859 m .2153 .63698 L .21693 .63629 L F
.21635 .63859 m .21494 .63953 L .2153 .63698 L F
0 0 .095 r
.5562 .67115 m .55634 .67368 L .55628 .67493 L F
.774 .495 0 r
.55623 .67569 m .55628 .67493 L .55634 .67368 L F
.55623 .67569 m .5569 .67773 L .55628 .67493 L F
.794 .6 .638 r
.69744 .45235 m .69733 .45502 L .69386 .45429 L F
.583 .42 .627 r
.69744 .45235 m .6999 .45436 L .69733 .45502 L F
.421 .257 .552 r
.24819 .56611 m .24793 .56882 L .24599 .56939 L F
.49 .339 .602 r
.24793 .56882 m .24591 .57192 L .24599 .56939 L F
0 .516 .744 r
.20209 .54153 m .2059 .54217 L .20385 .54187 L F
.524 .89 .973 r
.57361 .63314 m .57692 .63283 L .57538 .63458 L F
.282 .227 .616 r
.57441 .63746 m .57361 .63314 L .57538 .63458 L F
.538 .413 .658 r
.23436 .81645 m .23256 .81835 L .23261 .8157 L F
.527 .042 .047 r
.23314 .81791 m .23261 .8157 L .23075 .81749 L F
.23314 .81791 m .23436 .81645 L .23261 .8157 L F
.619 .409 .575 r
.20258 .62027 m .2031 .61975 L .20315 .61868 L F
.2031 .61975 m .20516 .6177 L .20315 .61868 L F
.929 .568 .149 r
.2032 .61776 m .20315 .61868 L .20219 .61609 L F
.20374 .61866 m .20315 .61868 L .2032 .61776 L F
.806 .853 .885 r
.65454 .4455 m .65263 .44752 L .65152 .44513 L F
.65152 .44513 m .65263 .44752 L .65454 .4455 L F
.755 .651 .746 r
.68175 .45459 m .68413 .45162 L .68159 .45206 L F
.354 .195 .522 r
.24045 .59186 m .23808 .59481 L .23835 .59293 L F
.823 .995 .856 r
.59092 .61294 m .58767 .61498 L .58922 .61642 L F
.59092 .61294 m .59022 .61236 L .58767 .61498 L F
.627 .695 .893 r
.38112 .61824 m .38236 .61984 L .37883 .61894 L F
.71 .723 .861 r
.38436 .61858 m .38236 .61984 L .38112 .61824 L F
.164 .022 .429 r
.38436 .61858 m .38297 .62179 L .38236 .61984 L F
.332 0 0 r
.57809 .60754 m .57926 .60856 L .57694 .60876 L F
.866 .742 .725 r
.57641 .60423 m .57809 .60754 L .57585 .60742 L F
.621 .091 0 r
.57809 .60754 m .57694 .60876 L .57585 .60742 L F
.191 .004 .382 r
.23388 .60379 m .2325 .60457 L .23431 .60145 L F
.39 .189 .482 r
.23388 .60379 m .23176 .60685 L .2325 .60457 L F
.905 .877 .797 r
.55669 .50831 m .55764 .5039 L .55831 .50481 L F
.892 .943 .837 r
.55983 .50088 m .55831 .50481 L .55764 .5039 L F
.55983 .50088 m .56087 .50169 L .55831 .50481 L F
.746 .635 .737 r
.65373 .45196 m .65168 .45508 L .65118 .45271 L F
.687 .726 .88 r
.54441 .68253 m .54314 .68617 L .54116 .68421 L F
.54441 .68253 m .54487 .68482 L .54314 .68617 L F
.121 0 0 r
.2059 .54217 m .20794 .54239 L .20972 .54247 L F
.094 .641 .832 r
.20794 .54239 m .21182 .54274 L .20972 .54247 L F
.418 .728 .989 r
.53152 .71601 m .53258 .71477 L .5339 .716 L F
.53152 .71601 m .53258 .71477 L .5339 .716 L F
.466 .084 .23 r
.70473 .45301 m .70292 .45129 L .70512 .45115 L F
.70473 .45301 m .7018 .45377 L .70292 .45129 L F
0 .408 .701 r
.21398 .5549 m .21047 .55385 L .21224 .55475 L F
.472 .38 .671 r
.56218 .50983 m .56251 .5126 L .56003 .51081 L F
.618 .332 .462 r
.56003 .51081 m .56251 .5126 L .55991 .51298 L F
.924 .552 .291 r
.58859 .60913 m .5895 .60775 L .58658 .60668 L F
.58859 .60913 m .59007 .60986 L .5895 .60775 L F
.322 .11 .428 r
.22523 .62383 m .22389 .62216 L .22579 .62148 L F
.22523 .62383 m .22346 .62454 L .22389 .62216 L F
.034 0 0 r
.17212 .54315 m .1745 .54296 L .17597 .54269 L F
.267 0 0 r
.1745 .54296 m .17825 .54187 L .17597 .54269 L F
.521 .266 .47 r
.25779 .55917 m .25529 .56002 L .25637 .55746 L F
.25779 .55917 m .25529 .56002 L .25637 .55746 L F
.929 .677 .536 r
.55436 .66743 m .5561 .66597 L .55528 .66477 L F
.55436 .66743 m .55629 .66869 L .5561 .66597 L F
.354 .432 .803 r
.68364 .42225 m .68499 .42562 L .68634 .42323 L F
.791 .998 .799 r
.68634 .42323 m .68499 .42562 L .68354 .42597 L F
.323 0 0 r
.66787 .41409 m .67028 .41504 L .67018 .4165 L F
.785 .691 .761 r
.5481 .61287 m .54556 .6158 L .54573 .61338 L F
.5481 .61287 m .54948 .61624 L .54556 .6158 L F
.49 .248 .475 r
.5483 .61507 m .54573 .61338 L .54556 .6158 L F
.5483 .61507 m .5481 .61287 L .54573 .61338 L F
.638 .261 .313 r
.41892 .63437 m .42092 .63619 L .41836 .63588 L F
.296 0 .17 r
.57553 .50151 m .57877 .49885 L .57886 .50132 L F
.58 .345 .524 r
.58146 .49838 m .57886 .50132 L .57877 .49885 L F
.818 .582 .582 r
.54948 .61624 m .54593 .61802 L .54556 .6158 L F
.54948 .61624 m .54939 .61888 L .54593 .61802 L F
.957 .64 .227 r
.5483 .61507 m .54948 .61624 L .5481 .61287 L F
0 0 .098 r
.5498 .61776 m .54939 .61888 L .54948 .61624 L F
.5498 .61776 m .54948 .61624 L .5483 .61507 L F
.388 .131 .399 r
.24951 .55767 m .24904 .56013 L .24691 .56063 L F
.286 .338 .741 r
.24988 .55379 m .24951 .55767 L .24851 .55398 L F
.24988 .55379 m .25125 .55738 L .24951 .55767 L F
.475 .207 .427 r
.25103 .55935 m .24951 .55767 L .25125 .55738 L F
.25103 .55935 m .24904 .56013 L .24951 .55767 L F
.327 0 .104 r
.35672 .59225 m .35908 .59172 L .36037 .58966 L F
.208 0 .039 r
.36037 .58966 m .36112 .59102 L .36268 .58931 L F
.36037 .58966 m .35908 .59172 L .36112 .59102 L F
.855 .694 .681 r
.56719 .48718 m .56846 .49083 L .56679 .4895 L F
.543 .321 .529 r
.34926 .59556 m .35161 .5952 L .35184 .59268 L F
.453 .212 .458 r
.35161 .5952 m .35422 .59227 L .35184 .59268 L F
.699 .698 .846 r
.44881 .57974 m .45291 .58034 L .45125 .57824 L F
.603 .751 .948 r
.45125 .57824 m .45291 .58034 L .4551 .57954 L F
.323 0 0 r
.66787 .41409 m .66772 .41728 L .66704 .41534 L F
.66787 .41409 m .67018 .4165 L .66772 .41728 L F
.799 .763 .821 r
.69532 .458 m .69274 .46129 L .69201 .45828 L F
.512 .183 .346 r
.69274 .46129 m .69504 .46249 L .69254 .46275 L F
.551 .399 .628 r
.69514 .46053 m .69274 .46129 L .69532 .458 L F
.478 .226 .454 r
.69514 .46053 m .69504 .46249 L .69274 .46129 L F
.623 .54 .74 r
.70796 .42169 m .70644 .42584 L .70554 .42231 L F
.70796 .42169 m .70898 .42529 L .70644 .42584 L F
.972 .688 .431 r
.57908 .62544 m .57717 .62653 L .57659 .6248 L F
0 .141 .664 r
.48603 .70369 m .48938 .70706 L .48855 .70336 L F
.464 .284 .552 r
.34701 .59886 m .34922 .59824 L .34926 .59556 L F
.446 .316 .609 r
.3473 .60141 m .34922 .59824 L .34701 .59886 L F
.164 .022 .429 r
.38436 .61858 m .38416 .62177 L .38297 .62179 L F
.165 .332 .787 r
.38416 .62177 m .38529 .62357 L .38297 .62179 L F
.807 .329 .073 r
.6492 .44465 m .64811 .44468 L .64579 .44241 L F
.21 0 0 r
.6492 .44465 m .65152 .44513 L .64811 .44468 L F
.591 .541 .766 r
.71559 .44204 m .71317 .44328 L .71156 .44002 L F
.579 .452 .672 r
.71559 .44204 m .7135 .44506 L .71317 .44328 L F
.714 .584 .709 r
.49191 .73074 m .48941 .73392 L .49241 .73334 L F
.578 .493 .722 r
.49191 .73074 m .49241 .73334 L .49444 .73001 L F
.612 .614 .829 r
.70673 .41819 m .70554 .42231 L .70422 .41885 L F
.70673 .41819 m .70796 .42169 L .70554 .42231 L F
.662 .214 .176 r
.65532 .45796 m .65818 .46008 L .65445 .45965 L F
.801 .357 0 r
.65564 .42798 m .65712 .43067 L .65818 .43166 L F
.879 .573 .06 r
.65789 .43256 m .65818 .43166 L .65712 .43067 L F
.65789 .43256 m .65859 .43386 L .65818 .43166 L F
.756 .402 .383 r
.51547 .69147 m .51891 .69014 L .51548 .68926 L F
.51547 .69147 m .5185 .69271 L .51891 .69014 L F
.372 0 0 r
.4074 .62955 m .40987 .62955 L .41154 .62832 L F
.351 0 0 r
.40987 .62955 m .41374 .62772 L .41154 .62832 L F
.658 .158 .05 r
.49391 .68845 m .49736 .68863 L .49563 .68787 L F
.647 .478 .641 r
.49563 .68787 m .49736 .68863 L .4983 .68695 L F
.932 .773 .299 r
.5597 .63383 m .55951 .63169 L .56007 .63075 L F
.938 .829 .382 r
.55902 .63249 m .55951 .63169 L .55557 .6308 L F
.55951 .63169 m .56007 .63075 L .55977 .63076 L F
.55951 .63169 m .55977 .63076 L .55557 .6308 L F
.932 .773 .299 r
.55951 .63169 m .55909 .63242 L .55937 .63022 L F
.5597 .63383 m .55922 .63272 L .55951 .63169 L F
.938 .829 .382 r
.55932 .63263 m .56007 .63075 L .55902 .63249 L F
.932 .773 .299 r
.55922 .63272 m .55909 .63242 L .55951 .63169 L F
.55951 .63169 m .55937 .63022 L .56007 .63075 L F
.612 .128 .081 r
.55448 .63212 m .55911 .63261 L .55557 .6308 L F
.55911 .63261 m .55932 .63263 L .55895 .63245 L F
.55911 .63261 m .55895 .63245 L .55557 .6308 L F
.938 .829 .382 r
.55932 .63263 m .5597 .63383 L .5598 .63298 L F
.537 .545 .81 r
.56161 .63578 m .55956 .63319 L .5597 .63383 L F
.903 .74 .24 r
.55932 .63263 m .55933 .63291 L .5597 .63383 L F
.537 .545 .81 r
.55951 .63299 m .55927 .63276 L .5597 .63383 L F
.55927 .63276 m .55921 .6327 L .5597 .63383 L F
.903 .74 .24 r
.55933 .63291 m .55954 .63646 L .5597 .63383 L F
.442 .265 .545 r
.5597 .63383 m .55954 .63646 L .56161 .63578 L F
.537 .545 .81 r
.56161 .63578 m .55954 .63646 L .55933 .63291 L F
.56161 .63578 m .55933 .63291 L .55932 .63263 L F
.56161 .63578 m .55951 .63299 L .55956 .63319 L F
.55951 .63299 m .55909 .63242 L .55921 .6327 L F
.663 .231 .211 r
.55448 .63212 m .55589 .6336 L .55932 .63263 L F
.57 .247 .382 r
.55752 .63273 m .55589 .6336 L .55448 .63212 L F
.49 .055 .139 r
.55557 .6308 m .55345 .63137 L .55203 .63143 L F
.288 0 0 r
.5518 .63241 m .55557 .6308 L .55203 .63143 L F
.55229 .6322 m .55448 .63212 L .55557 .6308 L F
.594 .707 .922 r
.55448 .63212 m .55564 .62939 L .55735 .632 L F
.55448 .63212 m .55735 .632 L .55767 .63249 L F
.288 0 0 r
.5518 .63241 m .55448 .63212 L .55229 .6322 L F
.594 .707 .922 r
.55448 .63212 m .55767 .63249 L .55752 .63273 L F
.702 .662 .807 r
.55905 .63139 m .55767 .63249 L .55564 .62939 L F
.776 .972 .919 r
.55767 .63249 m .55589 .6336 L .5578 .63226 L F
.55723 .63322 m .55648 .63344 L .55767 .63249 L F
.55648 .63344 m .55589 .6336 L .55767 .63249 L F
.55723 .63322 m .5578 .63226 L .55905 .63139 L F
.702 .662 .807 r
.55905 .63139 m .55788 .63281 L .55767 .63249 L F
.57 .247 .382 r
.55788 .63281 m .55589 .6336 L .55752 .63273 L F
.776 .972 .919 r
.55932 .63263 m .55723 .63322 L .55793 .63252 L F
.55915 .63186 m .55793 .63252 L .55905 .63139 L F
.55932 .63263 m .55793 .63252 L .55915 .63186 L F
.594 .707 .922 r
.55752 .63273 m .55767 .63249 L .55788 .63281 L F
.537 .545 .81 r
.55916 .63252 m .55932 .63263 L .55909 .63242 L F
.56161 .63578 m .55932 .63263 L .55916 .63252 L F
.938 .829 .382 r
.55932 .63263 m .5598 .63298 L .56007 .63075 L F
.986 .71 .376 r
.5819 .61038 m .58194 .61283 L .58081 .60967 L F
.486 .132 .291 r
.61288 .48373 m .60885 .48628 L .60927 .48473 L F
.813 .888 .898 r
.5978 .44424 m .59397 .44552 L .59652 .4428 L F
.758 .828 .906 r
.59652 .4428 m .59974 .44297 L .5978 .44424 L F
.602 .317 .457 r
.58973 .49305 m .59216 .49497 L .58964 .49512 L F
.599 .319 .463 r
.58973 .49305 m .59211 .49296 L .59216 .49497 L F
.755 .651 .746 r
.68175 .45459 m .68543 .45534 L .68413 .45162 L F
.655 .597 .778 r
.68413 .45162 m .68543 .45534 L .68816 .45368 L F
0 0 0 r
.62169 .45793 m .61932 .45907 L .61815 .45979 L F
.62169 .45793 m .61815 .45979 L .61978 .45687 L F
.522 .427 .688 r
.22338 .56857 m .2251 .56531 L .22381 .56644 L F
.652 .456 .606 r
.49768 .70129 m .49772 .70385 L .49515 .70417 L F
.625 .552 .752 r
.49733 .69848 m .49768 .70129 L .50052 .70089 L F
.833 .591 .573 r
.4972 .70262 m .49768 .70129 L .4963 .70157 L F
.6 .414 .602 r
.50052 .70089 m .49772 .70385 L .49768 .70129 L F
.833 .591 .573 r
.4972 .70262 m .50052 .70089 L .49768 .70129 L F
.571 .299 .466 r
.58693 .49559 m .58382 .49822 L .58394 .49639 L F
.474 .224 .455 r
.48938 .70706 m .49153 .70418 L .49159 .70696 L F
.782 .612 .67 r
.49515 .70417 m .49159 .70696 L .49153 .70418 L F
.813 .782 .823 r
.61294 .43171 m .6096 .43139 L .6116 .43013 L F
.888 .838 .79 r
.614 .42684 m .61294 .43171 L .6116 .43013 L F
.495 0 .006 r
.60736 .46348 m .61008 .46367 L .61055 .46319 L F
.386 0 .053 r
.61226 .46452 m .61055 .46319 L .61008 .46367 L F
.61226 .46452 m .61312 .46275 L .61055 .46319 L F
.112 .665 .751 r
.63466 .43898 m .63839 .43867 L .6362 .43892 L F
.318 0 0 r
.43937 .63349 m .43513 .63503 L .43661 .63355 L F
.43937 .63349 m .43749 .63501 L .43513 .63503 L F
.082 .642 .765 r
.43661 .63355 m .44015 .63347 L .43937 .63349 L F
.344 0 0 r
.44116 .63451 m .43749 .63501 L .43937 .63349 L F
.335 0 0 r
.44257 .63333 m .43937 .63349 L .44015 .63347 L F
.44257 .63333 m .44116 .63451 L .43937 .63349 L F
.023 0 .004 r
.54962 .68408 m .55013 .68521 L .5502 .68259 L F
.54962 .68408 m .54841 .68628 L .55013 .68521 L F
0 0 0 r
.62834 .47825 m .62883 .47798 L .63072 .47716 L F
.891 .987 .729 r
.20851 .60701 m .20603 .61056 L .20609 .60874 L F
.229 .304 .734 r
.20851 .60701 m .20876 .60347 L .20732 .60429 L F
.20851 .60701 m .20936 .60652 L .20876 .60347 L F
.473 .073 .2 r
.20609 .60874 m .20936 .60652 L .20851 .60701 L F
.863 .761 .748 r
.61153 .44563 m .61306 .44615 L .61233 .44293 L F
.819 .574 .568 r
.61011 .44843 m .61306 .44615 L .61153 .44563 L F
.61011 .44843 m .61303 .449 L .61306 .44615 L F
.619 .373 .522 r
.61601 .44916 m .61306 .44615 L .61303 .449 L F
.61601 .44916 m .61579 .44613 L .61306 .44615 L F
.614 .594 .808 r
.38112 .61824 m .37883 .61894 L .37762 .61551 L F
.67 .418 .531 r
.53204 .67708 m .53462 .6774 L .53478 .67497 L F
.474 .391 .682 r
.53478 .67497 m .53679 .67439 L .53633 .67188 L F
.168 0 0 r
.62068 .48118 m .62188 .48179 L .61962 .48266 L F
.62068 .48118 m .62313 .48073 L .62188 .48179 L F
.55 .818 .996 r
.35819 .62976 m .36044 .63103 L .36205 .63018 L F
.585 .806 .984 r
.68816 .45368 m .69273 .45413 L .69031 .45347 L F
.856 .868 .849 r
.61787 .44037 m .62061 .43763 L .61913 .43631 L F
.495 .896 .935 r
.42389 .57306 m .42494 .57198 L .42617 .57241 L F
.42389 .57306 m .42193 .573 L .42494 .57198 L F
.56 .139 .201 r
.53301 .68246 m .53495 .68331 L .53595 .68082 L F
.071 0 .01 r
.53595 .68082 m .5369 .68189 L .53834 .68032 L F
.53595 .68082 m .53495 .68331 L .5369 .68189 L F
.975 .883 .675 r
.58894 .62892 m .58988 .63096 L .59069 .62765 L F
.58894 .62892 m .59069 .62765 L .59093 .62733 L F
.58894 .62892 m .59093 .62733 L .58889 .62913 L F
.58894 .62892 m .58889 .62913 L .58867 .62933 L F
.85 .985 .859 r
.58879 .62915 m .58867 .62933 L .58884 .62918 L F
.925 .904 .504 r
.58867 .62933 m .58855 .62832 L .58894 .62892 L F
.85 .985 .859 r
.58885 .62907 m .58855 .62832 L .58867 .62933 L F
.93 .801 .696 r
.58855 .62832 m .58889 .62915 L .58894 .62892 L F
.85 .985 .859 r
.59136 .6254 m .58855 .62832 L .58885 .62907 L F
.93 .801 .696 r
.58855 .62832 m .58876 .62974 L .58889 .62915 L F
.85 .985 .859 r
.58879 .62915 m .58884 .62918 L .58889 .62913 L F
.93 .801 .696 r
.58889 .62913 m .58895 .62925 L .58894 .62892 L F
.85 .985 .859 r
.58887 .62909 m .58889 .62913 L .59093 .62733 L F
.58879 .62915 m .58889 .62913 L .58887 .62909 L F
.93 .801 .696 r
.58876 .62974 m .58907 .63191 L .58895 .62925 L F
.58876 .62974 m .58895 .62925 L .58889 .62913 L F
.85 .985 .859 r
.59136 .6254 m .58879 .62915 L .59093 .62733 L F
.956 .75 .296 r
.58907 .63191 m .58988 .63096 L .58914 .62936 L F
.58895 .62925 m .58914 .62936 L .58894 .62892 L F
.58907 .63191 m .58914 .62936 L .58895 .62925 L F
.58907 .63191 m .5898 .63346 L .58988 .63096 L F
.982 .705 .331 r
.63972 .44768 m .64087 .45116 L .64117 .44997 L F
0 0 0 r
.40665 .59023 m .40614 .59006 L .40841 .58965 L F
.40665 .59023 m .40442 .59086 L .40614 .59006 L F
.265 0 .259 r
.71537 .43623 m .7119 .4373 L .71303 .43677 L F
.71537 .43623 m .71156 .44002 L .7119 .4373 L F
.71537 .43623 m .71426 .43908 L .71156 .44002 L F
.513 .545 .826 r
.7164 .43352 m .71537 .43623 L .71303 .43677 L F
.7164 .43352 m .71775 .43746 L .71537 .43623 L F
0 0 0 r
.71775 .43746 m .71426 .43908 L .71537 .43623 L F
.884 .542 .395 r
.54786 .65324 m .55097 .65661 L .55066 .65555 L F
.395 .324 .658 r
.24602 .57674 m .24463 .58072 L .24411 .57826 L F
.701 .81 .933 r
.64172 .46881 m .64362 .46569 L .64063 .46795 L F
.64172 .46881 m .64506 .46726 L .64362 .46569 L F
.828 .728 .755 r
.56789 .48063 m .56896 .4841 L .56581 .48377 L F
.832 .708 .727 r
.56581 .48377 m .56896 .4841 L .56719 .48718 L F
0 0 0 r
.46593 .62784 m .46732 .6266 L .46844 .6245 L F
.023 0 0 r
.46844 .6245 m .47028 .62419 L .47059 .62359 L F
.101 0 .016 r
.46844 .6245 m .46732 .6266 L .47028 .62419 L F
.517 .55 .829 r
.49444 .73001 m .4979 .73305 L .49821 .73056 L F
.587 .359 .537 r
.4979 .73305 m .50039 .7328 L .49821 .73056 L F
.476 .812 .999 r
.50039 .7328 m .4979 .73305 L .49821 .73056 L F
.288 0 0 r
.57765 .63844 m .57728 .63852 L .57487 .63781 L F
.42 .845 .696 r
.58089 .63662 m .57728 .63852 L .57765 .63844 L F
.127 .664 .853 r
.23326 .79477 m .23606 .79481 L .23708 .79509 L F
.069 0 0 r
.23708 .79509 m .23448 .79488 L .23326 .79477 L F
.349 .813 .925 r
.23606 .79481 m .23448 .79488 L .23708 .79509 L F
.977 .716 .467 r
.52186 .68582 m .5202 .68563 L .52012 .68288 L F
.348 .806 .937 r
.52186 .68582 m .52251 .68501 L .5202 .68563 L F
.52186 .68582 m .5239 .68534 L .52251 .68501 L F
.381 .592 .928 r
.52312 .686 m .5239 .68534 L .52186 .68582 L F
.445 .296 .584 r
.37936 .6124 m .37762 .61551 L .37763 .61328 L F
.401 .643 .955 r
.37808 .64162 m .37877 .64028 L .37692 .63939 L F
.37808 .64162 m .3802 .64191 L .37877 .64028 L F
.201 0 0 r
.44871 .63112 m .44723 .6325 L .44491 .63296 L F
.407 0 .076 r
.45101 .63052 m .44723 .6325 L .44871 .63112 L F
.508 .526 .81 r
.24904 .56013 m .25066 .56339 L .24691 .56063 L F
.613 .363 .515 r
.59692 .49023 m .59817 .49206 L .59622 .49201 L F
.59692 .49023 m .59812 .49 L .59817 .49206 L F
.796 .398 0 r
.6526 .42142 m .65442 .42476 L .65365 .42268 L F
.49 .432 .719 r
.3464 .61019 m .34841 .60977 L .34763 .60744 L F
0 0 0 r
.67761 .45179 m .68162 .45007 L .67922 .45164 L F
.67761 .45179 m .67922 .45164 L .67909 .45131 L F
.67565 .4548 m .67761 .45179 L .67773 .45175 L F
.67565 .4548 m .67773 .45175 L .67702 .45342 L F
.67702 .45342 m .67773 .45175 L .67909 .45131 L F
.67565 .4548 m .67909 .45131 L .67695 .45241 L F
.6 .104 0 r
.67644 .45595 m .67764 .4571 L .67565 .4548 L F
.67644 .45595 m .67565 .4548 L .67695 .45241 L F
.98 .722 .465 r
.6762 .45532 m .67695 .45241 L .67505 .45231 L F
.67644 .45595 m .6767 .45416 L .6762 .45532 L F
.6767 .45416 m .67695 .45241 L .6762 .45532 L F
.697 .657 .806 r
.68161 .44817 m .68162 .45007 L .67761 .45179 L F
0 0 0 r
.46593 .62784 m .46455 .62945 L .46732 .6266 L F
.14 .686 .76 r
.39147 .58095 m .3938 .58064 L .39497 .58057 L F
.355 .812 .936 r
.3938 .58064 m .3973 .58049 L .39497 .58057 L F
.238 0 .15 r
.48322 .62189 m .48025 .62493 L .48011 .62468 L F
.48322 .62189 m .48223 .62423 L .48025 .62493 L F
.236 0 .272 r
.48525 .62096 m .48322 .62189 L .48574 .61911 L F
.485 .204 .412 r
.48525 .62096 m .48223 .62423 L .48322 .62189 L F
.358 .768 .981 r
.21182 .54274 m .21401 .54256 L .21565 .54326 L F
.385 .804 .974 r
.21401 .54256 m .21774 .54273 L .21565 .54326 L F
.524 .802 .996 r
.62745 .44229 m .62856 .44079 L .62664 .44235 L F
.62745 .44229 m .63016 .4418 L .62856 .44079 L F
.544 .28 .467 r
.51301 .69162 m .51548 .68926 L .51384 .69008 L F
0 .127 .662 r
.54038 .66766 m .5389 .66743 L .53784 .66812 L F
.54038 .66766 m .54054 .66822 L .5389 .66743 L F
.992 .743 .431 r
.5389 .66743 m .53784 .66812 L .53798 .66551 L F
.691 .845 .957 r
.61468 .44026 m .61787 .44037 L .61647 .43884 L F
.856 .868 .849 r
.61787 .44037 m .61913 .43631 L .61647 .43884 L F
.731 .424 .46 r
.62109 .4429 m .61787 .44037 L .61816 .44316 L F
.441 .26 .539 r
.24264 .58377 m .24248 .58624 L .24048 .58684 L F
.476 .337 .613 r
.24248 .58624 m .2406 .58935 L .24048 .58684 L F
.681 .729 .887 r
.21414 .58139 m .21428 .58224 L .21654 .58012 L F
0 .514 .715 r
.17825 .54187 m .18023 .5421 L .18031 .54212 L F
.088 0 0 r
.17825 .54187 m .17798 .54286 L .18023 .5421 L F
.302 .785 .708 r
.18023 .5421 m .17798 .54286 L .18004 .54205 L F
.18023 .5421 m .18004 .54205 L .1803 .54195 L F
0 .514 .715 r
.18031 .54212 m .18023 .5421 L .18189 .54232 L F
.016 .585 .772 r
.18189 .54232 m .18023 .5421 L .18412 .54244 L F
.148 0 0 r
.40188 .5781 m .40595 .57822 L .40365 .57872 L F
.872 .91 .853 r
.50352 .73137 m .50039 .7328 L .50276 .73239 L F
0 .104 .645 r
.5045 .73206 m .50474 .73364 L .50352 .73137 L F
.357 0 .165 r
.50276 .73239 m .5045 .73206 L .50352 .73137 L F
0 0 0 r
.62552 .43902 m .62646 .4376 L .62366 .43993 L F
.69 .58 .727 r
.62336 .44165 m .62552 .43902 L .62366 .43993 L F
.969 .769 .58 r
.60776 .45652 m .60823 .45498 L .60645 .45375 L F
.503 .564 .85 r
.71426 .43908 m .71559 .44204 L .71156 .44002 L F
.064 0 .403 r
.61706 .43159 m .618 .43049 L .61682 .43078 L F
0 0 .372 r
.6172 .43141 m .61706 .43159 L .61682 .43078 L F
.451 .381 .687 r
.2118 .59541 m .21365 .59493 L .21302 .59237 L F
.514 .412 .677 r
.21187 .59826 m .21365 .59493 L .2118 .59541 L F
.69 .604 .755 r
.71269 .42797 m .71027 .42881 L .70898 .42529 L F
.672 .545 .702 r
.71269 .42797 m .71063 .43163 L .71027 .42881 L F
.413 .006 .154 r
.36495 .58914 m .36719 .58898 L .36872 .58668 L F
.34 0 .027 r
.36719 .58898 m .37112 .58672 L .36872 .58668 L F
.347 .097 .386 r
.57068 .50477 m .57309 .50185 L .57306 .50412 L F
.611 .379 .541 r
.57553 .50151 m .57306 .50412 L .57309 .50185 L F
.725 .986 .889 r
.6478 .42323 m .64431 .42492 L .64632 .42353 L F
.749 .973 .925 r
.65016 .42142 m .6478 .42323 L .64884 .42119 L F
.778 .998 .819 r
.64884 .42119 m .6478 .42323 L .64632 .42353 L F
.036 .356 .83 r
.55059 .63058 m .54983 .63127 L .54827 .63256 L F
.597 .15 .16 r
.54983 .63127 m .5518 .63241 L .55203 .63143 L F
.036 .356 .83 r
.55059 .63058 m .5518 .63241 L .54983 .63127 L F
.663 .48 .627 r
.67659 .43112 m .67945 .43095 L .67934 .4281 L F
.627 .523 .717 r
.67945 .43095 m .68168 .42742 L .67934 .4281 L F
.965 .745 .554 r
.47244 .71553 m .47289 .7131 L .47123 .71212 L F
.967 .725 .52 r
.4714 .7096 m .47289 .7131 L .47123 .71212 L F
0 0 0 r
.52172 .64992 m .52214 .65061 L .52351 .65215 L F
.565 .761 .97 r
.52214 .65061 m .52351 .65215 L .5259 .6515 L F
.52214 .65061 m .52351 .65215 L .5259 .6515 L F
.381 .592 .928 r
.52312 .686 m .52547 .68729 L .5239 .68534 L F
.432 .134 .358 r
.52235 .68969 m .52547 .68729 L .52312 .686 L F
.973 .814 .626 r
.67109 .45118 m .67033 .4548 L .66916 .45346 L F
.067 0 0 r
.18412 .54244 m .1863 .54229 L .18794 .54188 L F
.467 .856 .977 r
.1863 .54229 m .19008 .54212 L .18794 .54188 L F
.029 0 .075 r
.48574 .61911 m .48826 .61628 L .48727 .61817 L F
.116 0 .223 r
.48525 .62096 m .48574 .61911 L .48727 .61817 L F
.718 .988 .836 r
.49289 .69993 m .49198 .70148 L .49219 .70098 L F
.292 0 .105 r
.38457 .60229 m .38371 .60383 L .38136 .60442 L F
0 0 0 r
.38525 .60275 m .38457 .60229 L .38624 .6013 L F
.38525 .60275 m .38371 .60383 L .38457 .60229 L F
.657 .836 .969 r
.43212 .57193 m .42981 .57295 L .42844 .57181 L F
.587 .872 .994 r
.66564 .41426 m .6642 .41595 L .66333 .41556 L F
.66564 .41426 m .66704 .41534 L .6642 .41595 L F
.311 0 0 r
.36557 .63282 m .36182 .63265 L .36263 .6323 L F
.593 .579 .807 r
.70765 .44797 m .70444 .44597 L .70807 .44609 L F
.422 .085 .287 r
.71047 .44611 m .70765 .44797 L .70807 .44609 L F
0 0 0 r
.48727 .61817 m .48826 .61628 L .48965 .6152 L F
.945 .744 .602 r
.66224 .44382 m .66325 .44875 L .66342 .44653 L F
.412 0 0 r
.1784 .55449 m .17661 .55592 L .17462 .55558 L F
.273 0 0 r
.18065 .55413 m .17661 .55592 L .1784 .55449 L F
.552 .354 .567 r
.34926 .59556 m .35153 .59759 L .35161 .5952 L F
.34926 .59556 m .34922 .59824 L .35153 .59759 L F
.084 .594 .888 r
.19265 .55398 m .19085 .55319 L .18953 .55306 L F
.247 0 0 r
.19085 .55319 m .19068 .55321 L .18953 .55306 L F
.081 .559 .902 r
.19104 .55402 m .18953 .55306 L .18777 .55283 L F
.247 0 0 r
.19068 .55321 m .18751 .55357 L .18953 .55306 L F
.081 .559 .902 r
.18777 .55283 m .18953 .55306 L .18674 .55246 L F
.758 .651 .744 r
.56462 .63159 m .56567 .63316 L .56428 .63033 L F
.533 0 0 r
.56636 .63409 m .56567 .63316 L .56462 .63159 L F
.56636 .63409 m .56809 .63492 L .56567 .63316 L F
.468 0 0 r
.56567 .63316 m .56809 .63492 L .56725 .63428 L F
.688 .203 .093 r
.52494 .68226 m .52569 .6808 L .52262 .68043 L F
.52494 .68226 m .52637 .68167 L .52569 .6808 L F
.626 .612 .816 r
.54699 .67687 m .55019 .67756 L .54877 .67423 L F
.746 .751 .856 r
.70786 .43429 m .70532 .43666 L .70607 .43561 L F
.919 .555 .119 r
.66298 .42575 m .66243 .42654 L .66156 .42486 L F
.66298 .42575 m .66351 .42776 L .66243 .42654 L F
.276 .081 .425 r
.21852 .6355 m .21732 .63402 L .21874 .63305 L F
.21852 .6355 m .21693 .63629 L .21732 .63402 L F
.643 .194 .17 r
.43927 .62757 m .44124 .62894 L .44134 .62808 L F
.43927 .62757 m .43795 .629 L .44124 .62894 L F
.343 .776 .969 r
.45384 .57173 m .45246 .57108 L .45618 .57144 L F
.487 .323 .583 r
.7128 .43072 m .71063 .43163 L .71269 .42797 L F
.999 .817 .483 r
.53798 .66551 m .53712 .66497 L .53845 .66328 L F
.526 .859 .995 r
.64553 .44735 m .64673 .44798 L .64409 .44844 L F
0 0 0 r
.64409 .44844 m .64229 .44984 L .64553 .44735 L F
.389 .057 .278 r
.57074 .50627 m .57068 .50477 L .57306 .50412 L F
0 0 0 r
.63601 .4713 m .63669 .47003 L .63856 .46851 L F
.03 0 0 r
.40595 .57822 m .40832 .5778 L .40934 .57731 L F
0 0 0 r
.40934 .57731 m .41051 .57696 L .41158 .57658 L F
.40934 .57731 m .40832 .5778 L .41051 .57696 L F
.57 .33 .512 r
.59812 .49 m .60055 .4919 L .59817 .49206 L F
.618 .308 .423 r
.59812 .49 m .60077 .49005 L .60055 .4919 L F
.553 .157 .244 r
.50369 .6945 m .50783 .69398 L .50477 .69257 L F
.125 0 0 r
.18674 .55246 m .18495 .55315 L .18267 .55337 L F
.388 0 0 r
.18953 .55306 m .18495 .55315 L .18674 .55246 L F
.303 .099 .428 r
.23544 .60289 m .23431 .60145 L .23577 .6007 L F
.23544 .60289 m .23388 .60379 L .23431 .60145 L F
.905 .877 .797 r
.55669 .50831 m .55562 .50692 L .55764 .5039 L F
.846 .875 .862 r
.55336 .50858 m .55562 .50692 L .55669 .50831 L F
.858 .567 .036 r
.67445 .42666 m .67576 .42982 L .67377 .42732 L F
.67445 .42666 m .6751 .42938 L .67553 .42924 L F
.332 .315 .69 r
.67628 .42702 m .6751 .42938 L .67445 .42666 L F
.739 .886 .485 r
.67628 .42702 m .67492 .42944 L .6751 .42938 L F
.67492 .42944 m .67409 .43089 L .6751 .42938 L F
.858 .567 .036 r
.67553 .42924 m .6751 .42938 L .67576 .42982 L F
.865 .936 .561 r
.67409 .43089 m .67576 .42982 L .6751 .42938 L F
.67409 .43089 m .67391 .43252 L .67576 .42982 L F
.903 .705 .626 r
.67391 .43252 m .67659 .43112 L .67576 .42982 L F
.802 .806 .855 r
.34835 .62703 m .35046 .6282 L .35287 .62568 L F
.155 .395 .842 r
.41874 .58647 m .42045 .58613 L .42041 .58607 L F
0 0 0 r
.42083 .58594 m .41874 .58647 L .41804 .58664 L F
.155 .395 .842 r
.41874 .58647 m .42041 .58607 L .41905 .58429 L F
0 0 0 r
.41804 .58664 m .41874 .58647 L .41705 .58688 L F
.767 .974 .92 r
.4441 .57014 m .44187 .57221 L .44235 .57044 L F
.797 .992 .878 r
.44187 .57221 m .44095 .57191 L .44235 .57044 L F
0 0 0 r
.54677 .69127 m .54732 .69068 L .54832 .69053 L F
.54677 .69127 m .54631 .69158 L .54732 .69068 L F
.594 .589 .817 r
.70298 .4153 m .70175 .41946 L .7005 .41605 L F
.70298 .4153 m .70422 .41885 L .70175 .41946 L F
.594 .91 .98 r
.47269 .71844 m .47405 .71892 L .47483 .71756 L F
.47269 .71844 m .47405 .71892 L .47483 .71756 L F
0 0 .352 r
.49104 .6882 m .49229 .69053 L .49391 .68845 L F
.432 .134 .358 r
.52235 .68969 m .52467 .68913 L .52547 .68729 L F
.722 .737 .863 r
.5239 .68534 m .52547 .68729 L .52711 .68598 L F
.5239 .68534 m .52711 .68598 L .52625 .68516 L F
.371 .075 .326 r
.52547 .68729 m .52625 .68516 L .52711 .68598 L F
.52547 .68729 m .52694 .68822 L .52625 .68516 L F
.52547 .68729 m .52467 .68913 L .52694 .68822 L F
.966 .701 .481 r
.58713 .63638 m .58351 .63576 L .58495 .63898 L F
.772 .539 .582 r
.58309 .60635 m .58657 .60403 L .58295 .6049 L F
.58309 .60635 m .58658 .60668 L .58657 .60403 L F
.53 .044 0 r
.55311 .68076 m .55219 .67977 L .55019 .67756 L F
.913 .945 .809 r
.5502 .68259 m .55219 .67977 L .55311 .68076 L F
0 .155 .691 r
.21811 .58387 m .21849 .5828 L .21654 .58012 L F
.188 .197 .636 r
.21785 .58599 m .21849 .5828 L .21811 .58387 L F
.803 .76 .814 r
.58685 .61893 m .58767 .61498 L .58541 .61576 L F
.58685 .61893 m .58922 .61642 L .58767 .61498 L F
.797 .426 .354 r
.58545 .62074 m .58895 .622 L .58685 .61893 L F
.437 .212 .473 r
.21689 .5779 m .21894 .57735 L .21924 .575 L F
0 0 0 r
.21924 .575 m .22057 .57399 L .22158 .5718 L F
0 0 .02 r
.21894 .57735 m .22057 .57399 L .21924 .575 L F
.653 .096 0 r
.5631 .64128 m .55919 .63881 L .56042 .64003 L F
.539 .127 .208 r
.69254 .46275 m .68916 .46438 L .68995 .46354 L F
.83 .997 .772 r
.63279 .4737 m .632 .47583 L .63438 .473 L F
.628 .948 .943 r
.68892 .4601 m .6903 .45832 L .69201 .45828 L F
.68892 .4601 m .68813 .45957 L .6903 .45832 L F
.221 0 0 r
.54077 .67487 m .54079 .67513 L .53679 .67439 L F
.655 .861 .476 r
.54291 .67177 m .5416 .67341 L .54077 .67487 L F
.514 .33 .568 r
.5416 .67341 m .54079 .67513 L .54077 .67487 L F
.164 0 0 r
.3946 .63985 m .39061 .64074 L .39231 .63989 L F
.268 0 .299 r
.51407 .69751 m .51203 .69818 L .51448 .69538 L F
.495 .185 .37 r
.51448 .69538 m .51651 .69696 L .51407 .69751 L F
.521 .175 .321 r
.51705 .69525 m .51651 .69696 L .51448 .69538 L F
.336 .769 .969 r
.20974 .5542 m .21047 .55385 L .2067 .55346 L F
.598 .689 .906 r
.44769 .57701 m .44881 .57974 L .45125 .57824 L F
.719 .688 .819 r
.68364 .42225 m .68712 .42246 L .68614 .41965 L F
.354 .432 .803 r
.68364 .42225 m .68634 .42323 L .68712 .42246 L F
.606 .623 .842 r
.68614 .41965 m .68712 .42246 L .68964 .42172 L F
.043 0 0 r
.68964 .42172 m .68712 .42246 L .68634 .42323 L F
.848 .879 .863 r
.65818 .46008 m .66079 .46001 L .66066 .45683 L F
.65818 .46008 m .65952 .46113 L .66079 .46001 L F
.875 .859 .822 r
.66066 .45683 m .66079 .46001 L .66206 .45814 L F
.606 .192 0 r
.66752 .43465 m .66861 .43643 L .66674 .43338 L F
.186 .059 .464 r
.5233 .69127 m .52467 .68913 L .52235 .68969 L F
.5233 .69127 m .52413 .69167 L .52467 .68913 L F
.096 .126 .603 r
.52413 .69167 m .52503 .69456 L .5233 .69127 L F
.687 .375 .443 r
.5233 .69127 m .52424 .69179 L .52413 .69167 L F
.5233 .69127 m .52204 .69452 L .52147 .69228 L F
.5233 .69127 m .52503 .69456 L .52204 .69452 L F
.5233 .69127 m .52147 .69228 L .52424 .69179 L F
.483 .014 .064 r
.6385 .43308 m .63703 .43132 L .63679 .43382 L F
.6385 .43308 m .64025 .43117 L .63703 .43132 L F
.228 .685 .949 r
.21774 .54273 m .21983 .54276 L .22158 .54362 L F
.282 .69 .972 r
.22157 .54247 m .22158 .54362 L .21983 .54276 L F
.22157 .54247 m .22368 .54353 L .22158 .54362 L F
.514 .185 .346 r
.47836 .61815 m .48083 .61805 L .48134 .61529 L F
.307 0 .247 r
.48134 .61529 m .48356 .61536 L .48448 .61274 L F
.375 .066 .308 r
.48134 .61529 m .48305 .61732 L .48356 .61536 L F
.48134 .61529 m .48083 .61805 L .48305 .61732 L F
.524 .89 .973 r
.57361 .63314 m .576 .63229 L .57692 .63283 L F
.554 .297 .48 r
.576 .63229 m .5788 .62879 L .57692 .63283 L F
0 0 0 r
.20211 .61256 m .20237 .61261 L .20603 .61056 L F
.86 .993 .827 r
.20603 .61056 m .20237 .61261 L .20609 .60874 L F
.414 .083 .293 r
.48448 .61274 m .48599 .6147 L .48667 .61328 L F
.48448 .61274 m .48356 .61536 L .48599 .6147 L F
.806 .762 .813 r
.59794 .44165 m .59974 .44297 L .59652 .4428 L F
.796 .764 .824 r
.60239 .4401 m .59974 .44297 L .59794 .44165 L F
.465 0 0 r
.54357 .69255 m .53937 .68907 L .54091 .68923 L F
.54357 .69255 m .54201 .69128 L .53937 .68907 L F
.238 0 0 r
.54091 .68923 m .53937 .68907 L .53933 .68896 L F
.086 .266 .752 r
.53937 .68907 m .54201 .69128 L .54089 .68834 L F
.53937 .68907 m .54089 .68834 L .53946 .68932 L F
.53937 .68907 m .53946 .68932 L .53569 .69193 L F
.238 0 0 r
.53933 .68896 m .53937 .68907 L .53705 .68857 L F
.859 .801 .792 r
.69733 .45502 m .6938 .45671 L .69386 .45429 L F
.69733 .45502 m .69532 .458 L .6938 .45671 L F
.633 .474 .649 r
.69733 .45502 m .69834 .45739 L .69532 .458 L F
.535 .293 .496 r
.6999 .45436 m .69987 .45665 L .69733 .45502 L F
.388 .347 .691 r
.69987 .45665 m .69834 .45739 L .69733 .45502 L F
.535 .293 .496 r
.6999 .45436 m .69987 .45665 L .69733 .45502 L F
.486 .132 .291 r
.61288 .48373 m .61134 .48603 L .60885 .48628 L F
.452 .037 .159 r
.61288 .48373 m .61378 .48543 L .61134 .48603 L F
.61288 .48373 m .6148 .48348 L .61378 .48543 L F
.625 .552 .752 r
.49733 .69848 m .50052 .70089 L .4988 .69753 L F
.423 .187 .449 r
.21654 .58012 m .21894 .57735 L .21689 .5779 L F
.554 .362 .575 r
.47015 .71591 m .47269 .71844 L .47244 .71553 L F
.422 .085 .287 r
.71047 .44611 m .71071 .44779 L .70765 .44797 L F
.619 .22 .265 r
.71047 .44611 m .71307 .4477 L .71071 .44779 L F
.576 .285 .438 r
.7135 .44506 m .71307 .4477 L .71047 .44611 L F
.497 .201 .394 r
.38842 .59965 m .3857 .59976 L .38932 .59899 L F
.38842 .59965 m .38624 .6013 L .3857 .59976 L F
.862 .996 .771 r
.431 .5851 m .43021 .58585 L .43155 .5841 L F
.429 .192 .451 r
.61816 .44316 m .61579 .44613 L .61817 .44547 L F
.574 .342 .526 r
.62029 .44514 m .61816 .44316 L .61817 .44547 L F
.62029 .44514 m .62109 .4429 L .61816 .44316 L F
.715 .907 .963 r
.21765 .56219 m .21858 .55992 L .21867 .55994 L F
.773 .553 0 r
.21832 .55688 m .21875 .55996 L .21867 .55994 L F
.21832 .55688 m .21867 .55994 L .21989 .55676 L F
.715 .907 .963 r
.21858 .55992 m .21908 .5587 L .21867 .55994 L F
.773 .553 0 r
.21875 .55996 m .2189 .56102 L .21867 .55994 L F
.964 .925 .595 r
.2189 .56102 m .21765 .56219 L .21867 .55994 L F
.539 .05 .043 r
.22154 .56198 m .21765 .56219 L .2189 .56102 L F
.492 .565 .858 r
.53827 .6504 m .53841 .64689 L .53697 .64814 L F
.53827 .6504 m .54033 .65048 L .53841 .64689 L F
.697 .831 .392 r
.63466 .44882 m .63303 .45201 L .6338 .45021 L F
.69 .604 .755 r
.71269 .42797 m .70898 .42529 L .7116 .42474 L F
.625 .573 .777 r
.71484 .42532 m .71269 .42797 L .7116 .42474 L F
.71484 .42532 m .71523 .42745 L .71269 .42797 L F
.603 .422 .61 r
.71523 .42745 m .7128 .43072 L .71269 .42797 L F
.258 0 .123 r
.62821 .43815 m .62646 .4376 L .62552 .43902 L F
.62821 .43815 m .62892 .4363 L .62646 .4376 L F
.446 .316 .609 r
.3473 .60141 m .34923 .60085 L .34922 .59824 L F
.456 .344 .638 r
.3473 .60141 m .34955 .6034 L .34923 .60085 L F
.426 .343 .66 r
.34768 .60391 m .34955 .6034 L .3473 .60141 L F
.216 .015 .378 r
.22098 .62997 m .21947 .63085 L .22143 .62767 L F
.214 0 .308 r
.22043 .63221 m .21947 .63085 L .22098 .62997 L F
.22043 .63221 m .21874 .63305 L .21947 .63085 L F
.436 0 0 r
.38839 .62657 m .39201 .6276 L .38976 .62796 L F
.71 .723 .861 r
.38436 .61858 m .38112 .61824 L .38452 .6177 L F
0 0 .505 r
.38452 .6177 m .38491 .61785 L .38436 .61858 L F
0 0 .329 r
.38548 .62009 m .38436 .61858 L .38491 .61785 L F
.38548 .62009 m .38416 .62177 L .38436 .61858 L F
.334 .435 .816 r
.63334 .44566 m .63466 .44882 L .63666 .44647 L F
0 0 0 r
.63466 .44882 m .6338 .45021 L .63666 .44647 L F
.438 .272 .557 r
.24962 .56816 m .24819 .56611 L .24894 .56498 L F
.24962 .56816 m .24793 .56882 L .24819 .56611 L F
.097 0 0 r
.4196 .62766 m .42193 .62754 L .42358 .62723 L F
.377 0 0 r
.42172 .62877 m .42358 .62723 L .42193 .62754 L F
.42172 .62877 m .42562 .62815 L .42358 .62723 L F
.287 .787 .801 r
.19151 .6306 m .19352 .63001 L .1946 .62836 L F
.562 .336 .529 r
.19352 .63001 m .19621 .62725 L .1946 .62836 L F
.379 0 0 r
.39476 .5961 m .39382 .59728 L .39185 .59746 L F
.437 .055 .216 r
.39772 .59483 m .39382 .59728 L .39476 .5961 L F
.472 .319 .592 r
.51069 .69988 m .50823 .69781 L .51203 .69818 L F
.327 0 .12 r
.51407 .69751 m .51069 .69988 L .51203 .69818 L F
.799 .763 .821 r
.69532 .458 m .69201 .45828 L .6938 .45671 L F
.534 .325 .543 r
.69834 .45739 m .69514 .46053 L .69532 .458 L F
.52 .094 .172 r
.43147 .57868 m .42981 .58011 L .42738 .5801 L F
.593 .893 .606 r
.43231 .57764 m .43147 .57868 L .43353 .57755 L F
.43231 .57764 m .42981 .58011 L .43147 .57868 L F
.98 .774 .555 r
.66004 .42225 m .65873 .42125 L .65911 .41906 L F
.804 .345 0 r
.66004 .42225 m .66028 .42376 L .65873 .42125 L F
.66004 .42225 m .66156 .42486 L .66028 .42376 L F
.582 .56 .795 r
.48682 .69174 m .48778 .6888 L .48545 .68925 L F
.48682 .69174 m .489 .69233 L .48778 .6888 L F
.975 .696 .436 r
.66068 .44132 m .66224 .44382 L .66205 .44276 L F
.642 .183 0 r
.57715 .62002 m .57794 .62119 L .57899 .62245 L F
.626 .233 .278 r
.50783 .69398 m .50959 .69426 L .5107 .69218 L F
.397 0 .16 r
.5107 .69218 m .51187 .69377 L .51301 .69162 L F
.5107 .69218 m .50959 .69426 L .51187 .69377 L F
.835 .992 .856 r
.60895 .44997 m .61062 .44972 L .61011 .44843 L F
.639 .814 .967 r
.61062 .44972 m .61303 .449 L .61011 .44843 L F
.405 0 .047 r
.46379 .63201 m .46566 .63247 L .46313 .63263 L F
.46379 .63201 m .46624 .63206 L .46566 .63247 L F
.207 0 .134 r
.54291 .67177 m .54588 .66965 L .54496 .6709 L F
.314 0 .091 r
.54496 .6709 m .5416 .67341 L .54291 .67177 L F
.397 0 .093 r
.41446 .58656 m .41299 .58852 L .41059 .58873 L F
.602 .337 .487 r
.41728 .58655 m .41525 .58845 L .41519 .58779 L F
.41525 .58845 m .41374 .58987 L .41519 .58779 L F
.19 0 0 r
.41519 .58779 m .41446 .58656 L .41508 .58664 L F
.41519 .58779 m .41508 .58664 L .41705 .58688 L F
.41519 .58779 m .41299 .58852 L .41446 .58656 L F
0 .279 .782 r
.67171 .42454 m .67377 .42732 L .67544 .42523 L F
.592 .198 .264 r
.67776 .42454 m .67416 .424 L .67544 .42523 L F
.592 .422 .62 r
.55991 .51298 m .5574 .51547 L .55732 .51352 L F
.741 .513 .584 r
.55732 .51352 m .5574 .51547 L .55411 .51562 L F
.806 .853 .885 r
.65454 .4455 m .65152 .44513 L .65379 .44427 L F
.65152 .44513 m .65454 .4455 L .65379 .44427 L F
0 0 .372 r
.6172 .43141 m .61682 .43078 L .618 .43049 L F
.361 .166 .476 r
.22782 .61584 m .22766 .61846 L .22578 .61914 L F
.369 .242 .574 r
.2275 .62069 m .22578 .61914 L .22766 .61846 L F
.2275 .62069 m .22579 .62148 L .22578 .61914 L F
.192 0 .349 r
.24463 .58072 m .24413 .58315 L .24264 .58377 L F
.356 .224 .561 r
.24413 .58315 m .24248 .58624 L .24264 .58377 L F
.505 .182 .354 r
.52251 .6822 m .52038 .68071 L .52012 .68288 L F
.52251 .6822 m .52262 .68043 L .52038 .68071 L F
.974 .826 .633 r
.54819 .66601 m .54656 .66516 L .54799 .66208 L F
.977 .819 .62 r
.54723 .66797 m .54656 .66516 L .54819 .66601 L F
.815 .923 .908 r
.61957 .4226 m .61642 .42389 L .61952 .42299 L F
.614 .796 .969 r
.61819 .4216 m .61952 .42299 L .61642 .42389 L F
.731 .262 0 r
.6195 .42327 m .61952 .42299 L .61819 .4216 L F
.61985 .42372 m .61952 .42299 L .6195 .42327 L F
.815 .923 .908 r
.62008 .42239 m .61957 .4226 L .61952 .42299 L F
.869 .569 .047 r
.61985 .42372 m .62008 .42239 L .61952 .42299 L F
.61985 .42372 m .62061 .42485 L .62008 .42239 L F
.631 .856 .481 r
.43142 .62499 m .42937 .62779 L .43018 .62643 L F
.18 0 0 r
.43142 .62499 m .43231 .62572 L .43155 .62609 L F
.43142 .62499 m .43018 .62643 L .43231 .62572 L F
.543 .611 .871 r
.44796 .56911 m .44778 .57218 L .44617 .56915 L F
.44796 .56911 m .45024 .57202 L .44778 .57218 L F
.528 .616 .883 r
.68085 .40829 m .67719 .40475 L .68129 .40858 L F
.579 .452 .672 r
.71559 .44204 m .71636 .44494 L .7135 .44506 L F
.586 .295 .44 r
.7157 .44725 m .7135 .44506 L .71636 .44494 L F
.7157 .44725 m .71307 .4477 L .7135 .44506 L F
.518 .675 .935 r
.45807 .57289 m .45706 .57357 L .45618 .57144 L F
.403 .798 .987 r
.4542 .57125 m .45461 .57078 L .45618 .57144 L F
.45246 .57108 m .45461 .57078 L .4542 .57125 L F
.148 .439 .874 r
.45527 .56939 m .45547 .5698 L .45461 .57078 L F
.841 .461 .331 r
.45461 .57078 m .45807 .57289 L .45618 .57144 L F
.45461 .57078 m .45691 .57274 L .45807 .57289 L F
.148 .439 .874 r
.45547 .5698 m .45665 .57222 L .45461 .57078 L F
.45665 .57222 m .45691 .57274 L .45461 .57078 L F
.513 .85 .996 r
.45691 .57274 m .45866 .5725 L .45807 .57289 L F
.45866 .5725 m .46176 .57207 L .45807 .57289 L F
.518 .675 .935 r
.45807 .57289 m .45756 .57476 L .45706 .57357 L F
.45807 .57289 m .45981 .57443 L .45756 .57476 L F
.02 .418 .861 r
.56809 .63492 m .57122 .63363 L .56725 .63428 L F
.56809 .63492 m .56932 .63636 L .57122 .63363 L F
.782 .612 .67 r
.49515 .70417 m .49534 .70694 L .49159 .70696 L F
.667 .525 .682 r
.49772 .70385 m .49534 .70694 L .49515 .70417 L F
.544 .644 .899 r
.69207 .40932 m .69114 .4125 L .68963 .41014 L F
.69207 .40932 m .69352 .41207 L .69114 .4125 L F
.532 .62 .885 r
.69416 .41396 m .69114 .4125 L .69352 .41207 L F
.356 0 0 r
.40213 .63894 m .40054 .63936 L .39825 .63927 L F
.422 0 0 r
.40422 .63901 m .40054 .63936 L .40213 .63894 L F
.562 .26 .414 r
.59622 .49201 m .59216 .49497 L .59211 .49296 L F
.583 .424 .632 r
.38133 .60954 m .37909 .60669 L .38106 .60604 L F
.38133 .60954 m .37966 .61061 L .37909 .60669 L F
.81 .366 .184 r
.67845 .45871 m .67973 .45758 L .67764 .4571 L F
.946 .606 .341 r
.67845 .45871 m .67994 .45969 L .67973 .45758 L F
.837 .371 .074 r
.54542 .6509 m .54641 .65262 L .54711 .65158 L F
.859 .408 .093 r
.54711 .65158 m .54641 .65262 L .54786 .65324 L F
.548 .725 .956 r
.63219 .43734 m .62892 .4363 L .6312 .43584 L F
0 .258 .737 r
.63355 .43774 m .63219 .43734 L .6312 .43584 L F
.811 .389 0 r
.63186 .44286 m .63224 .4444 L .63181 .44174 L F
.63194 .44301 m .63334 .44566 L .63224 .4444 L F
0 .436 .712 r
.63334 .44566 m .6349 .44599 L .63224 .4444 L F
.623 .117 .027 r
.63224 .4444 m .6349 .44599 L .63252 .44567 L F
.63224 .4444 m .63252 .44567 L .63129 .4455 L F
.811 .389 0 r
.63186 .44286 m .63194 .44301 L .63224 .4444 L F
.64 .204 0 r
.66523 .43101 m .66573 .43199 L .66413 .42987 L F
.694 .36 0 r
.66573 .43199 m .66659 .43429 L .66605 .43302 L F
.66573 .43199 m .66605 .43302 L .66592 .43245 L F
.66573 .43199 m .66592 .43245 L .6655 .43061 L F
.64 .204 0 r
.66523 .43101 m .66552 .43146 L .66573 .43199 L F
.66552 .43146 m .66674 .43338 L .66573 .43199 L F
.345 .18 .509 r
.23816 .59727 m .23577 .6007 L .23611 .59832 L F
.313 .502 .883 r
.24889 .55192 m .24851 .55398 L .2466 .55178 L F
.24889 .55192 m .24988 .55379 L .24851 .55398 L F
.494 0 0 r
.42562 .62815 m .42788 .62889 L .42937 .62779 L F
.651 .924 .638 r
.42937 .62779 m .42788 .62889 L .43018 .62643 L F
.329 .185 .528 r
.23176 .60685 m .2317 .60941 L .23011 .60997 L F
.466 .358 .647 r
.2317 .60941 m .23018 .6128 L .23011 .60997 L F
.565 .151 .215 r
.43064 .63345 m .42913 .63546 L .42709 .63497 L F
.537 .12 .197 r
.433 .63485 m .43064 .63345 L .43288 .63368 L F
.433 .63485 m .42913 .63546 L .43064 .63345 L F
.569 .601 .845 r
.69799 .4167 m .69416 .41396 L .69635 .41326 L F
.61 .661 .875 r
.69887 .41252 m .69799 .4167 L .69635 .41326 L F
.69887 .41252 m .7005 .41605 L .69799 .4167 L F
.867 .87 .838 r
.54116 .68421 m .54216 .6821 L .53982 .68121 L F
.644 .77 .94 r
.53982 .68121 m .54441 .68253 L .54116 .68421 L F
.982 .819 .42 r
.67123 .44596 m .67028 .44717 L .67014 .44468 L F
.67123 .44596 m .67088 .4483 L .67028 .44717 L F
.903 .705 .626 r
.67391 .43252 m .67722 .43508 L .67659 .43112 L F
.634 .598 .796 r
.67659 .43112 m .6807 .43361 L .67945 .43095 L F
0 .048 .603 r
.53729 .64906 m .5346 .65064 L .53416 .64795 L F
.53729 .64906 m .53697 .64814 L .5346 .65064 L F
.773 .682 .764 r
.56581 .48377 m .56719 .48718 L .56321 .48666 L F
.743 .542 .622 r
.56719 .48718 m .5631 .48884 L .56321 .48666 L F
.56719 .48718 m .56679 .4895 L .5631 .48884 L F
.699 .229 .133 r
.60623 .46476 m .60736 .46348 L .60426 .46394 L F
.264 0 0 r
.60623 .46476 m .61008 .46367 L .60736 .46348 L F
.905 .524 .292 r
.67433 .43487 m .67722 .43508 L .67391 .43252 L F
.67433 .43487 m .67669 .43629 L .67722 .43508 L F
.866 .508 .37 r
.67803 .4361 m .67722 .43508 L .67669 .43629 L F
.694 .278 0 r
.65617 .42927 m .65564 .42798 L .65456 .4266 L F
.65617 .42927 m .65712 .43067 L .65564 .42798 L F
.956 .677 .468 r
.64558 .46461 m .64716 .46588 L .64711 .4633 L F
0 0 0 r
.54135 .65148 m .5407 .64805 L .54033 .65048 L F
.54135 .65148 m .54341 .64864 L .5407 .64805 L F
.54135 .65148 m .5428 .65044 L .54341 .64864 L F
.74 .33 .273 r
.5428 .65044 m .54542 .6509 L .54341 .64864 L F
.975 .736 .512 r
.42362 .58183 m .42509 .58285 L .42517 .58027 L F
.199 0 0 r
.42663 .58087 m .42517 .58027 L .42738 .5801 L F
.42663 .58087 m .42362 .58183 L .42517 .58027 L F
.748 .651 .752 r
.4988 .69753 m .50125 .69465 L .49933 .69548 L F
.849 .94 .882 r
.66787 .41409 m .66704 .41534 L .66564 .41426 L F
.573 .563 .805 r
.34962 .61563 m .35082 .61916 L .35316 .61839 L F
.482 .296 .552 r
.35082 .61916 m .35318 .62083 L .35316 .61839 L F
.303 .325 .718 r
.35082 .61916 m .35195 .62216 L .35318 .62083 L F
.989 .731 .43 r
.67039 .43992 m .66907 .44101 L .66921 .43855 L F
.67039 .43992 m .67025 .44227 L .66907 .44101 L F
.541 .117 .187 r
.44124 .62894 m .44355 .62938 L .44134 .62808 L F
.528 .141 .252 r
.44134 .62808 m .44355 .62938 L .44404 .62803 L F
.519 .898 .959 r
.41788 .57516 m .41892 .574 L .42004 .57428 L F
.41788 .57516 m .41654 .57488 L .41892 .574 L F
0 .046 .597 r
.56319 .62927 m .56462 .63159 L .56428 .63033 L F
.56304 .62934 m .56462 .63159 L .56319 .62927 L F
.56253 .62861 m .56304 .62934 L .56319 .62927 L F
.56253 .62861 m .56514 .63138 L .56462 .63159 L F
.81 .712 .177 r
.55937 .63022 m .55909 .63242 L .55905 .63139 L F
.012 0 0 r
.55905 .63139 m .56406 .63031 L .56121 .63025 L F
.55907 .63131 m .56121 .63025 L .55937 .63022 L F
.55905 .63139 m .56121 .63025 L .55907 .63131 L F
0 0 .494 r
.56514 .63138 m .56636 .63409 L .56462 .63159 L F
.449 .656 .949 r
.37311 .63546 m .37313 .63322 L .37152 .63303 L F
.37311 .63546 m .37537 .63548 L .37313 .63322 L F
.02 .418 .861 r
.56809 .63492 m .56961 .63537 L .56932 .63636 L F
0 0 .348 r
.57023 .63775 m .56932 .63636 L .56961 .63537 L F
.969 .687 .443 r
.57082 .63797 m .57023 .63775 L .57259 .63696 L F
0 0 .348 r
.57023 .63775 m .56948 .63931 L .56938 .63742 L F
.594 .345 .51 r
.56948 .63931 m .5686 .64102 L .56612 .6398 L F
0 0 .341 r
.57023 .63775 m .5686 .64102 L .56948 .63931 L F
.57023 .63775 m .57016 .64047 L .5686 .64102 L F
.969 .687 .443 r
.56875 .63916 m .57016 .64047 L .57023 .63775 L F
.56875 .63916 m .57023 .63775 L .57082 .63797 L F
0 0 .348 r
.57023 .63775 m .56938 .63742 L .56932 .63636 L F
.503 .405 .677 r
.6807 .43361 m .68251 .43089 L .67945 .43095 L F
.6807 .43361 m .68281 .4331 L .68251 .43089 L F
.713 .179 0 r
.64559 .45658 m .64495 .45683 L .64278 .45444 L F
.958 .721 .536 r
.19151 .6306 m .19139 .63073 L .19223 .63358 L F
.679 .548 .699 r
.19223 .63358 m .1949 .63347 L .19271 .63613 L F
.958 .721 .536 r
.19271 .63613 m .19099 .63517 L .19223 .63358 L F
.137 0 0 r
.61492 .46263 m .61626 .4613 L .61312 .46275 L F
.156 0 0 r
.61492 .46263 m .61312 .46275 L .61226 .46452 L F
.347 .156 .474 r
.23018 .6128 m .22995 .61518 L .22782 .61584 L F
.383 .184 .482 r
.22966 .61763 m .22782 .61584 L .22995 .61518 L F
.22966 .61763 m .22766 .61846 L .22782 .61584 L F
.569 .619 .862 r
.67873 .40343 m .68129 .40858 L .67719 .40475 L F
.945 .744 .602 r
.66224 .44382 m .66159 .4478 L .66325 .44875 L F
.954 .718 .544 r
.66145 .45033 m .66325 .44875 L .66159 .4478 L F
.66145 .45033 m .66297 .4516 L .66325 .44875 L F
.435 .208 .469 r
.56519 .50783 m .56718 .50915 L .56469 .50956 L F
.56519 .50783 m .56744 .50692 L .56718 .50915 L F
.504 .288 .519 r
.61846 .44796 m .61579 .44613 L .61601 .44916 L F
.503 .288 .52 r
.61846 .44796 m .61817 .44547 L .61579 .44613 L F
.677 .542 .693 r
.50986 .66978 m .5095 .67193 L .51173 .66889 L F
.415 0 0 r
.20364 .55397 m .20024 .55354 L .2017 .5543 L F
.20465 .5541 m .20232 .55423 L .20024 .55354 L F
0 0 0 r
.2067 .55346 m .20232 .55423 L .20465 .5541 L F
.2065 .5535 m .20447 .55388 L .20232 .55423 L F
.2067 .55346 m .2066 .55348 L .2065 .5535 L F
.2066 .55348 m .20447 .55388 L .2065 .5535 L F
.415 0 0 r
.20465 .5541 m .20364 .55397 L .20247 .5547 L F
.20364 .55397 m .2017 .5543 L .20247 .5547 L F
.954 .732 .563 r
.55019 .67756 m .54914 .67734 L .54877 .67423 L F
.752 .29 .152 r
.55019 .67756 m .54876 .67901 L .54914 .67734 L F
.55019 .67756 m .55219 .67977 L .54876 .67901 L F
.828 .752 .779 r
.54972 .68927 m .55275 .6893 L .5513 .68718 L F
.82 .779 .813 r
.55 .69204 m .55275 .6893 L .54972 .68927 L F
.654 .588 .769 r
.55499 .68809 m .5513 .68718 L .55275 .6893 L F
.354 .195 .522 r
.24045 .59186 m .2403 .59457 L .23808 .59481 L F
.317 .089 .402 r
.2403 .59457 m .23816 .59727 L .23808 .59481 L F
.532 .306 .517 r
.2092 .60131 m .21157 .60097 L .21187 .59826 L F
.514 .412 .677 r
.21187 .59826 m .2142 .59769 L .21365 .59493 L F
.417 .193 .464 r
.21157 .60097 m .2142 .59769 L .21187 .59826 L F
.24 0 0 r
.39825 .63927 m .39736 .64028 L .3946 .63985 L F
.326 0 0 r
.39902 .64026 m .39825 .63927 L .40054 .63936 L F
.39902 .64026 m .39736 .64028 L .39825 .63927 L F
.238 0 0 r
.37918 .58555 m .38145 .58504 L .38294 .58334 L F
.267 0 0 r
.38145 .58504 m .38539 .58345 L .38294 .58334 L F
.534 .596 .862 r
.48938 .70706 m .49015 .70419 L .48855 .70336 L F
.48938 .70706 m .49159 .70696 L .49015 .70419 L F
.991 .861 .508 r
.55128 .659 m .55068 .66175 L .55192 .66043 L F
.592 .102 .059 r
.55192 .66043 m .55068 .66175 L .55473 .66192 L F
.991 .861 .508 r
.55128 .659 m .55068 .66175 L .55192 .66043 L F
.673 .57 .732 r
.71118 .42243 m .70898 .42529 L .70796 .42169 L F
.652 .54 .715 r
.7116 .42474 m .70898 .42529 L .71118 .42243 L F
.982 .73 .332 r
.55544 .66996 m .55629 .66869 L .55436 .66743 L F
.55544 .66996 m .5562 .67115 L .55629 .66869 L F
.538 .413 .658 r
.23436 .81645 m .23488 .81853 L .23256 .81835 L F
.369 0 0 r
.23256 .81835 m .23488 .81853 L .23241 .81844 L F
.485 .746 .986 r
.23163 .54438 m .23111 .54602 L .22951 .54469 L F
.23163 .54438 m .2332 .5457 L .23111 .54602 L F
.642 .241 .268 r
.71076 .4501 m .70765 .44797 L .71071 .44779 L F
.71076 .4501 m .70713 .45008 L .70765 .44797 L F
.549 .62 .876 r
.69592 .41168 m .69416 .41396 L .69352 .41207 L F
.522 .581 .855 r
.69635 .41326 m .69416 .41396 L .69592 .41168 L F
.573 .33 .511 r
.60656 .48621 m .60858 .48856 L .60637 .48894 L F
.60656 .48621 m .60885 .48628 L .60858 .48856 L F
.029 .248 .75 r
.38529 .62357 m .38635 .62394 L .38577 .62522 L F
.185 .45 .876 r
.38635 .62394 m .38839 .62657 L .38577 .62522 L F
.981 .691 .377 r
.63548 .41061 m .63579 .413 L .63438 .41172 L F
.63548 .41061 m .63579 .413 L .63438 .41172 L F
.457 0 0 r
.19546 .54079 m .19818 .54172 L .19987 .54153 L F
.57 .095 .087 r
.43661 .63355 m .43513 .63503 L .43288 .63368 L F
.363 .527 .885 r
.21832 .55688 m .21904 .55483 L .21651 .55528 L F
.21832 .55688 m .21989 .55676 L .21904 .55483 L F
.758 .719 .816 r
.64811 .44468 m .64673 .44798 L .64553 .44735 L F
.587 .731 .943 r
.67634 .40397 m .67389 .40458 L .67298 .40286 L F
.574 .646 .884 r
.67719 .40475 m .67389 .40458 L .67634 .40397 L F
.373 .149 .44 r
.22286 .62932 m .22143 .62767 L .22316 .62695 L F
.22286 .62932 m .22098 .62997 L .22143 .62767 L F
.82 .779 .813 r
.55 .69204 m .54972 .68927 L .54832 .69053 L F
0 0 0 r
.68154 .42318 m .68364 .42225 L .6836 .42237 L F
.8 .999 .846 r
.68341 .42138 m .68364 .42225 L .68614 .41965 L F
.721 .469 0 r
.6836 .42237 m .68364 .42225 L .68341 .42138 L F
.608 .125 0 r
.67499 .41916 m .67549 .41993 L .67523 .41957 L F
.925 .886 .776 r
.67525 .41956 m .67523 .41958 L .67549 .41993 L F
.67525 .41956 m .67416 .424 L .67295 .4225 L F
.67523 .41958 m .67295 .4225 L .67549 .41993 L F
.608 .125 0 r
.67523 .41957 m .67549 .41993 L .67536 .41979 L F
0 0 0 r
.67499 .41916 m .67406 .41939 L .67522 .41956 L F
.608 .125 0 r
.67499 .41916 m .67536 .41979 L .67437 .41875 L F
0 0 0 r
.67499 .41916 m .67522 .41956 L .67525 .41956 L F
.434 0 0 r
.67994 .45969 m .68103 .46031 L .68303 .46046 L F
.279 .758 .929 r
.68454 .45965 m .68303 .46046 L .68103 .46031 L F
.68454 .45965 m .68556 .46024 L .68303 .46046 L F
.611 .379 .541 r
.57553 .50151 m .57537 .50383 L .57306 .50412 L F
.668 .485 .628 r
.57886 .50132 m .57537 .50383 L .57553 .50151 L F
.186 .536 .925 r
.24308 .54954 m .24488 .54993 L .24456 .55112 L F
.154 .5 .908 r
.24488 .54993 m .2466 .55178 L .24456 .55112 L F
.345 0 0 r
.41287 .63716 m .4149 .63766 L .41279 .63785 L F
.352 0 .044 r
.41589 .63629 m .4149 .63766 L .41287 .63716 L F
.296 0 0 r
.38774 .58313 m .39004 .58272 L .39147 .58095 L F
.256 0 0 r
.39147 .58095 m .39236 .58217 L .3938 .58064 L F
.39147 .58095 m .39004 .58272 L .39236 .58217 L F
0 0 0 r
.71775 .43746 m .71662 .43813 L .71426 .43908 L F
.598 .547 .768 r
.71936 .43256 m .71775 .43746 L .7164 .43352 L F
.576 .303 .466 r
.72071 .43627 m .72093 .43746 L .71775 .43746 L F
.501 .169 .337 r
.72071 .43627 m .72053 .43714 L .71775 .43746 L F
.598 .547 .768 r
.72053 .43714 m .72093 .43746 L .71775 .43746 L F
.687 .318 .342 r
.72189 .43779 m .72099 .43736 L .72071 .43627 L F
.221 .077 .464 r
.72071 .43627 m .72093 .43746 L .72099 .43737 L F
.687 .318 .342 r
.72099 .43736 m .72053 .43714 L .72071 .43627 L F
.72364 .43701 m .72189 .43779 L .72071 .43627 L F
.221 .077 .464 r
.72071 .43627 m .7224 .43543 L .72364 .43701 L F
.72071 .43627 m .72099 .43737 L .7224 .43543 L F
.598 .547 .768 r
.72082 .43711 m .72088 .43731 L .72053 .43714 L F
.72088 .43731 m .72093 .43746 L .72053 .43714 L F
.687 .318 .342 r
.72189 .43779 m .72026 .43852 L .72053 .43714 L F
.501 .169 .337 r
.72053 .43714 m .72026 .43852 L .71775 .43746 L F
.598 .547 .768 r
.71936 .43256 m .72082 .43711 L .71775 .43746 L F
.475 0 0 r
.72026 .43852 m .71662 .43813 L .71775 .43746 L F
.628 .376 .518 r
.60291 .48956 m .60055 .4919 L .60077 .49005 L F
.287 .787 .801 r
.19151 .6306 m .19282 .63021 L .19352 .63001 L F
.156 0 0 r
.19139 .63073 m .19282 .63021 L .19151 .6306 L F
.709 .939 .63 r
.63759 .46097 m .63637 .46191 L .63581 .46306 L F
.958 .721 .536 r
.19271 .63613 m .19211 .63611 L .19099 .63517 L F
.655 .597 .778 r
.68413 .45162 m .68816 .45368 L .68683 .45095 L F
.49 .339 .602 r
.24793 .56882 m .24798 .57136 L .24591 .57192 L F
.434 .282 .575 r
.24798 .57136 m .24608 .57445 L .24591 .57192 L F
.446 .472 .793 r
.43687 .57075 m .43556 .57312 L .43448 .57123 L F
.43687 .57075 m .43808 .57416 L .43556 .57312 L F
.473 0 0 r
.68085 .46652 m .67724 .46602 L .67831 .46618 L F
.68085 .46652 m .67973 .46708 L .67724 .46602 L F
.328 .401 .786 r
.67724 .46602 m .67973 .46708 L .6797 .46699 L F
.67724 .46602 m .6797 .46699 L .67858 .46355 L F
.35 0 0 r
.67494 .46526 m .67612 .46558 L .67724 .46602 L F
.67612 .46558 m .67831 .46618 L .67724 .46602 L F
.206 0 .193 r
.53346 .68868 m .53097 .69119 L .53157 .68955 L F
.129 .508 .91 r
.54746 .68467 m .54487 .68482 L .54441 .68253 L F
.425 .302 .608 r
.54694 .68205 m .54746 .68467 L .54441 .68253 L F
.864 .967 .862 r
.54738 .68341 m .54706 .68379 L .54746 .68467 L F
.129 .508 .91 r
.54746 .68467 m .54814 .68617 L .54487 .68482 L F
.864 .967 .862 r
.54706 .68379 m .5452 .68602 L .54746 .68467 L F
.129 .508 .91 r
.54746 .68467 m .54841 .68628 L .54814 .68617 L F
0 0 0 r
.64189 .43229 m .6431 .43142 L .6453 .43065 L F
.831 .362 0 r
.64804 .43374 m .6453 .43065 L .64834 .43066 L F
.56 0 0 r
.67934 .43757 m .67803 .4361 L .67669 .43629 L F
.67934 .43757 m .68025 .43734 L .67803 .4361 L F
.178 0 0 r
.20209 .54153 m .20412 .54193 L .2059 .54217 L F
.253 .728 .938 r
.20412 .54193 m .20794 .54239 L .2059 .54217 L F
.571 .299 .466 r
.58693 .49559 m .58625 .49785 L .58382 .49822 L F
.555 .291 .471 r
.58693 .49559 m .58873 .49747 L .58625 .49785 L F
.58693 .49559 m .58964 .49512 L .58873 .49747 L F
.796 .764 .824 r
.60239 .4401 m .59794 .44165 L .60103 .43886 L F
.85 .861 .85 r
.60353 .43609 m .60239 .4401 L .60103 .43886 L F
.60353 .43609 m .60485 .43733 L .60239 .4401 L F
.81 .6 .618 r
.56612 .6398 m .56642 .64232 L .5631 .64128 L F
.537 .403 .646 r
.5686 .64102 m .56642 .64232 L .56612 .6398 L F
.5686 .64102 m .56642 .64232 L .56612 .6398 L F
.674 .258 .249 r
.49159 .70696 m .49534 .70694 L .49369 .70876 L F
.644 .221 .226 r
.49534 .70694 m .49749 .70884 L .49369 .70876 L F
.574 .399 .607 r
.49772 .70385 m .49787 .70661 L .49534 .70694 L F
.533 .264 .454 r
.49787 .70661 m .49749 .70884 L .49534 .70694 L F
.3 .324 .719 r
.6833 .45002 m .68162 .45007 L .68161 .44817 L F
.133 0 0 r
.67922 .45164 m .68162 .45007 L .6833 .45002 L F
0 .181 .698 r
.63637 .46191 m .63746 .46517 L .63581 .46306 L F
.488 .105 .239 r
.52637 .68167 m .52846 .68214 L .52931 .68031 L F
.155 0 .228 r
.52931 .68031 m .53084 .67992 L .53204 .67708 L F
.098 0 .053 r
.52931 .68031 m .52846 .68214 L .53084 .67992 L F
.285 .763 .657 r
.47203 .62296 m .47397 .62215 L .47059 .62359 L F
.286 .465 .861 r
.37692 .63939 m .37662 .63576 L .37537 .63548 L F
.37692 .63939 m .37783 .63769 L .37662 .63576 L F
.37692 .63939 m .37809 .63909 L .37783 .63769 L F
.26 .334 .75 r
.37692 .63939 m .37877 .64028 L .37809 .63909 L F
0 0 0 r
.47465 .6292 m .47395 .62993 L .47237 .63024 L F
.47237 .63024 m .47395 .62993 L .471 .6316 L F
.848 .991 .847 r
.53115 .71848 m .52782 .72069 L .52921 .7216 L F
.968 .7 .276 r
.53033 .71601 m .53041 .71796 L .53115 .71848 L F
.796 .341 .162 r
.5407 .64805 m .53988 .64653 L .53841 .64689 L F
.421 .308 .619 r
.34768 .60391 m .34979 .60592 L .34955 .6034 L F
.34768 .60391 m .34763 .60744 L .34979 .60592 L F
.882 .82 .783 r
.57525 .46942 m .57161 .4713 L .57403 .46842 L F
.57525 .46942 m .57312 .47268 L .57161 .4713 L F
.868 .905 .855 r
.57773 .46656 m .57525 .46942 L .57403 .46842 L F
.802 .806 .855 r
.34835 .62703 m .35287 .62568 L .34899 .62476 L F
0 0 .503 r
.35195 .62216 m .35287 .62568 L .35305 .62369 L F
.505 .711 .964 r
.35305 .62369 m .35287 .62568 L .35472 .62524 L F
.6 .414 .602 r
.50052 .70089 m .50072 .70357 L .49772 .70385 L F
.833 .591 .573 r
.4972 .70262 m .50072 .70357 L .50052 .70089 L F
.747 .654 .758 r
.4988 .69753 m .50052 .70089 L .50266 .69845 L F
.351 .23 .571 r
.50052 .70089 m .50232 .70293 L .50072 .70357 L F
.50052 .70089 m .50232 .70293 L .50072 .70357 L F
.476 .337 .613 r
.24248 .58624 m .24271 .58884 L .2406 .58935 L F
.413 .23 .52 r
.2423 .59124 m .2406 .58935 L .24271 .58884 L F
.2423 .59124 m .24045 .59186 L .2406 .58935 L F
0 0 0 r
.22158 .5718 m .22168 .57255 L .22401 .57153 L F
.22158 .5718 m .2212 .57263 L .22168 .57255 L F
.372 .8 .969 r
.22044 .57245 m .22187 .57252 L .22168 .57255 L F
.373 .344 .697 r
.22338 .56857 m .22401 .57153 L .2255 .57006 L F
.611 .286 .394 r
.22168 .57255 m .2255 .57006 L .22401 .57153 L F
.22533 .57018 m .22445 .57266 L .2255 .57006 L F
.22168 .57255 m .22445 .57266 L .22533 .57018 L F
.372 .8 .969 r
.22187 .57252 m .22445 .57266 L .22168 .57255 L F
.22044 .57245 m .22292 .57207 L .22445 .57266 L F
.983 .747 .503 r
.22292 .57207 m .22388 .57425 L .22445 .57266 L F
.22388 .57425 m .22427 .57511 L .22445 .57266 L F
0 0 0 r
.2212 .57263 m .22057 .57399 L .22168 .57255 L F
.043 0 .286 r
.21356 .64393 m .2129 .64252 L .21414 .64162 L F
.21356 .64393 m .21237 .6449 L .2129 .64252 L F
.516 .302 .527 r
.50072 .70357 m .49787 .70661 L .49772 .70385 L F
.562 .26 .414 r
.59622 .49201 m .59464 .49477 L .59216 .49497 L F
.58 .301 .457 r
.59622 .49201 m .59911 .49425 L .59464 .49477 L F
.59622 .49201 m .59817 .49206 L .59911 .49425 L F
.772 .657 .735 r
.64675 .41609 m .6465 .41825 L .64703 .41668 L F
.282 .227 .616 r
.57441 .63746 m .576 .63229 L .57361 .63314 L F
.57455 .63701 m .57653 .63603 L .576 .63229 L F
.535 .389 .629 r
.57653 .63603 m .57839 .63223 L .576 .63229 L F
.57653 .63603 m .57851 .63564 L .57839 .63223 L F
.676 .182 .066 r
.57411 .63502 m .57758 .63551 L .57653 .63603 L F
.57758 .63551 m .57851 .63564 L .57653 .63603 L F
.282 .227 .616 r
.57441 .63746 m .57653 .63603 L .57455 .63701 L F
.785 .996 .795 r
.64772 .43895 m .6457 .44091 L .6471 .43897 L F
.425 .869 .827 r
.64772 .43895 m .647 .43613 L .64798 .43668 L F
.64772 .43895 m .64922 .438 L .647 .43613 L F
.64772 .43895 m .6471 .43897 L .64922 .438 L F
.519 .536 .813 r
.68683 .45095 m .68816 .45368 L .69031 .45347 L F
.632 .313 .412 r
.65235 .46064 m .65189 .46219 L .6498 .46011 L F
.1 .25 .731 r
.6498 .46011 m .65189 .46219 L .65123 .45923 L F
0 .151 .676 r
.54848 .67165 m .54937 .67058 L .54723 .66797 L F
.217 .269 .702 r
.54877 .67423 m .54937 .67058 L .54848 .67165 L F
.395 .324 .658 r
.24602 .57674 m .24627 .58044 L .24463 .58072 L F
.388 .15 .428 r
.24641 .58227 m .24463 .58072 L .24627 .58044 L F
.24641 .58227 m .24413 .58315 L .24463 .58072 L F
.391 .124 .384 r
.38371 .60383 m .38106 .60604 L .38136 .60442 L F
.61 .461 .654 r
.68521 .44277 m .68792 .4423 L .68754 .43973 L F
.6 .459 .662 r
.68572 .44609 m .68792 .4423 L .68521 .44277 L F
.726 .669 .794 r
.68145 .44214 m .68521 .44277 L .68411 .43915 L F
.771 .694 .778 r
.68411 .43915 m .68521 .44277 L .68754 .43973 L F
.51 0 0 r
.43155 .62609 m .434 .6271 L .43553 .62714 L F
0 .18 .678 r
.43567 .62678 m .43553 .62714 L .434 .6271 L F
.494 0 0 r
.48896 .70225 m .48874 .70083 L .48855 .70336 L F
.687 .318 .342 r
.72364 .43701 m .72379 .43862 L .72026 .43852 L F
.787 .845 .895 r
.72622 .4341 m .72364 .43701 L .7224 .43543 L F
.641 .591 .782 r
.72622 .4341 m .72611 .43653 L .72364 .43701 L F
.697 .447 .541 r
.72611 .43653 m .72379 .43862 L .72364 .43701 L F
.577 .42 .633 r
.58194 .61283 m .57937 .6158 L .57907 .61516 L F
.58194 .61283 m .58197 .61538 L .57937 .6158 L F
.919 .902 .498 r
.57818 .61751 m .57907 .61516 L .57937 .6158 L F
.455 .031 .143 r
.58197 .61538 m .57818 .61751 L .57937 .6158 L F
.618 .618 .828 r
.7102 .41941 m .70796 .42169 L .70673 .41819 L F
.628 .634 .838 r
.7102 .41941 m .71118 .42243 L .70796 .42169 L F
.928 .722 .604 r
.6457 .44091 m .64427 .44014 L .6471 .43897 L F
.741 .856 .933 r
.66919 .40216 m .66792 .40487 L .66684 .40372 L F
.66919 .40216 m .67038 .40356 L .66792 .40487 L F
.319 0 0 r
.6148 .48348 m .61611 .4846 L .61378 .48543 L F
.6148 .48348 m .61722 .48318 L .61611 .4846 L F
0 .279 .782 r
.67171 .42454 m .67445 .42666 L .67377 .42732 L F
0 .436 .702 r
.54593 .61802 m .54939 .61888 L .54922 .6188 L F
.699 .85 .427 r
.54922 .6188 m .54939 .61888 L .5498 .61776 L F
.062 .236 .731 r
.43353 .57755 m .4349 .57674 L .43231 .57764 L F
.698 .159 0 r
.43687 .57969 m .43566 .57959 L .43353 .57755 L F
.062 .236 .731 r
.43353 .57755 m .43566 .57959 L .4349 .57674 L F
.627 .523 .717 r
.67945 .43095 m .68251 .43089 L .68168 .42742 L F
0 0 .503 r
.35195 .62216 m .35305 .62369 L .35318 .62083 L F
.534 .325 .543 r
.69834 .45739 m .69767 .46005 L .69514 .46053 L F
.451 .205 .449 r
.69741 .46176 m .69514 .46053 L .69767 .46005 L F
.69741 .46176 m .69504 .46249 L .69514 .46053 L F
.805 .612 .641 r
.34493 .62404 m .34747 .62496 L .34899 .62476 L F
.187 .689 .91 r
.23241 .81844 m .23314 .81791 L .23074 .81769 L F
.23241 .81844 m .23488 .81853 L .23314 .81791 L F
.578 .741 .953 r
.36777 .63213 m .36929 .63358 L .37152 .63303 L F
.614 .594 .808 r
.38112 .61824 m .37762 .61551 L .37956 .61582 L F
.613 .692 .899 r
.38452 .6177 m .38112 .61824 L .37956 .61582 L F
.267 0 0 r
.1745 .54296 m .17583 .5434 L .17825 .54187 L F
.088 0 0 r
.17825 .54187 m .17583 .5434 L .17798 .54286 L F
.086 .275 .759 r
.25091 .56176 m .25066 .56339 L .24904 .56013 L F
.86 .845 .828 r
.24894 .56498 m .25318 .56319 L .25091 .56176 L F
.24894 .56498 m .25067 .56603 L .25318 .56319 L F
.08 0 .126 r
.62318 .45304 m .62099 .45483 L .61978 .45687 L F
.168 0 0 r
.54065 .67804 m .54272 .67811 L .54438 .67799 L F
.584 .332 .501 r
.19052 .63268 m .19282 .63021 L .19139 .63073 L F
0 .269 .744 r
.65859 .43386 m .66117 .43551 L .66164 .43628 L F
.965 .787 .612 r
.65956 .43855 m .66164 .43628 L .66117 .43551 L F
.65956 .43855 m .66103 .43977 L .66164 .43628 L F
.453 .212 .458 r
.35161 .5952 m .35375 .59467 L .35422 .59227 L F
.412 .176 .443 r
.35422 .59227 m .35647 .59349 L .35672 .59225 L F
.35422 .59227 m .35375 .59467 L .35647 .59349 L F
.989 .893 .592 r
.67033 .4548 m .66899 .45605 L .66916 .45346 L F
.67033 .4548 m .66967 .45723 L .66899 .45605 L F
.459 .027 .129 r
.36112 .59102 m .36495 .58914 L .36268 .58931 L F
.58 .345 .524 r
.58146 .49838 m .58123 .50092 L .57886 .50132 L F
.584 .315 .475 r
.58146 .49838 m .58382 .50036 L .58123 .50092 L F
.58146 .49838 m .58382 .49822 L .58382 .50036 L F
.421 .836 .658 r
.50474 .73364 m .50335 .73446 L .5015 .73561 L F
.873 .851 .818 r
.5045 .73206 m .50335 .73446 L .50474 .73364 L F
.748 .651 .752 r
.4988 .69753 m .50266 .69845 L .50125 .69465 L F
.044 .21 .712 r
.50125 .69465 m .50266 .69845 L .50337 .6966 L F
.3 0 0 r
.50543 .69784 m .50502 .69809 L .50266 .69845 L F
.516 .767 .988 r
.50266 .69845 m .50502 .69809 L .50337 .6966 L F
.547 .792 .989 r
.5339 .716 m .53631 .71545 L .53258 .71477 L F
.5339 .716 m .53631 .71545 L .53258 .71477 L F
0 0 0 r
.5579 .638 m .55689 .63823 L .55919 .63881 L F
.5579 .638 m .55565 .63862 L .55689 .63823 L F
.395 0 0 r
.40422 .63901 m .40242 .64023 L .40054 .63936 L F
.266 0 0 r
.40655 .63917 m .40242 .64023 L .40422 .63901 L F
.406 .185 .462 r
.55954 .63646 m .55919 .63881 L .56161 .63578 L F
.55954 .63646 m .55919 .63881 L .56161 .63578 L F
.42 .863 .901 r
.49819 .73627 m .5015 .73561 L .50037 .73548 L F
.585 .459 .674 r
.5015 .73561 m .50039 .7328 L .50037 .73548 L F
.5015 .73561 m .50276 .73239 L .50039 .7328 L F
.5015 .73561 m .50335 .73446 L .50276 .73239 L F
.697 .68 .829 r
.54423 .66646 m .54723 .66797 L .54588 .66965 L F
0 0 0 r
.54723 .66797 m .54496 .6709 L .54588 .66965 L F
.705 .778 .909 r
.58767 .61498 m .58365 .61419 L .58541 .61576 L F
.466 .715 .977 r
.44769 .57701 m .44389 .57591 L .44586 .57723 L F
.65 .271 .313 r
.44491 .63296 m .44116 .63451 L .44257 .63333 L F
.969 .769 .58 r
.60776 .45652 m .60645 .45375 L .60661 .45591 L F
.944 .959 .728 r
.60521 .45868 m .60776 .45652 L .60661 .45591 L F
.60521 .45868 m .60578 .46007 L .60776 .45652 L F
0 0 0 r
.62188 .48179 m .62313 .48073 L .6252 .47994 L F
.787 .769 .837 r
.61906 .44835 m .62029 .44514 L .61817 .44547 L F
.61906 .44835 m .62214 .44603 L .62029 .44514 L F
.622 .953 .926 r
.61846 .44796 m .61906 .44835 L .62042 .44681 L F
.61846 .44796 m .61906 .44835 L .62042 .44681 L F
.841 .861 .858 r
.6073 .43445 m .60485 .43733 L .60353 .43609 L F
.094 .641 .832 r
.20794 .54239 m .21012 .54244 L .21182 .54274 L F
.216 .727 .889 r
.21012 .54244 m .21401 .54256 L .21182 .54274 L F
.76 .678 .771 r
.57851 .63564 m .57931 .63733 L .58204 .6354 L F
.225 .381 .81 r
.57851 .63564 m .58036 .63662 L .57931 .63733 L F
.42 .845 .696 r
.58089 .63662 m .57931 .63733 L .57846 .6379 L F
.225 .381 .81 r
.58036 .63662 m .58131 .63713 L .57931 .63733 L F
.42 .845 .696 r
.57846 .6379 m .57931 .63733 L .57728 .63852 L F
.563 .91 .969 r
.58089 .63662 m .58351 .63576 L .58204 .6354 L F
.58 .928 .741 r
.58204 .6354 m .57931 .63733 L .58089 .63662 L F
.106 .653 .826 r
.64884 .42119 m .6526 .42142 L .65016 .42142 L F
.921 .535 .141 r
.64146 .4531 m .64278 .45444 L .64087 .45116 L F
.638 .113 0 r
.64278 .45444 m .64346 .45558 L .64146 .4531 L F
.968 .703 .277 r
.64346 .45558 m .64352 .45745 L .64265 .456 L F
.272 0 0 r
.64265 .456 m .64325 .45581 L .64346 .45558 L F
.638 .113 0 r
.64363 .45538 m .64495 .45683 L .64346 .45558 L F
.931 .637 .462 r
.64495 .45683 m .64352 .45745 L .64346 .45558 L F
.535 .726 .962 r
.64495 .45683 m .64636 .45484 L .64346 .45558 L F
.64495 .45683 m .64636 .45484 L .64346 .45558 L F
.272 0 0 r
.64325 .45581 m .64636 .45484 L .64346 .45558 L F
.638 .113 0 r
.64278 .45444 m .64363 .45538 L .64346 .45558 L F
.466 .181 .397 r
.20876 .60347 m .21157 .60097 L .2092 .60131 L F
.445 .264 .54 r
.19621 .62725 m .1982 .6268 L .19683 .62465 L F
.868 .905 .855 r
.57773 .46656 m .57403 .46842 L .57662 .46559 L F
.894 .915 .83 r
.58018 .46339 m .57773 .46656 L .57662 .46559 L F
.737 .469 .524 r
.53204 .67708 m .53401 .67823 L .53462 .6774 L F
.53204 .67708 m .53084 .67992 L .53401 .67823 L F
.724 .817 .923 r
.64362 .46569 m .64506 .46726 L .64716 .46588 L F
.534 .336 .559 r
.53697 .64814 m .5351 .64577 L .53416 .64795 L F
.671 .7 .868 r
.51809 .70316 m .5178 .70462 L .52168 .70358 L F
.808 .777 .272 r
.55623 .67569 m .55558 .67967 L .5569 .67773 L F
.782 .463 .448 r
.64811 .44468 m .64428 .4447 L .64579 .44241 L F
.324 0 .15 r
.6312 .43584 m .62892 .4363 L .62821 .43815 L F
.116 0 0 r
.23326 .79477 m .23448 .79488 L .23606 .79481 L F
.601 .929 .963 r
.42617 .57241 m .42721 .571 L .42844 .57181 L F
.42617 .57241 m .42494 .57198 L .42721 .571 L F
.544 .28 .467 r
.51301 .69162 m .51547 .69147 L .51548 .68926 L F
.445 .296 .584 r
.37936 .6124 m .37956 .61582 L .37762 .61551 L F
.865 .863 .836 r
.58566 .63547 m .5898 .63346 L .58738 .63425 L F
.58566 .63547 m .58713 .63638 L .5898 .63346 L F
.888 .953 .842 r
.58907 .63191 m .58738 .63425 L .5898 .63346 L F
.409 0 .09 r
.41836 .63588 m .4149 .63766 L .41589 .63629 L F
0 0 0 r
.47598 .61863 m .47397 .62215 L .47484 .62111 L F
.457 .11 .288 r
.47484 .62111 m .47836 .61815 L .47598 .61863 L F
.355 .812 .936 r
.3938 .58064 m .39594 .58025 L .3973 .58049 L F
.433 .853 .955 r
.3973 .58049 m .3988 .57977 L .39909 .57953 L F
.3973 .58049 m .39594 .58025 L .3988 .57977 L F
.563 .437 .666 r
.69987 .45665 m .69767 .46005 L .69834 .45739 L F
.437 .864 .937 r
.68379 .4368 m .68105 .43822 L .68411 .43915 L F
.978 .762 .543 r
.68281 .4331 m .68379 .4368 L .68664 .43656 L F
.553 .361 .575 r
.68411 .43915 m .68664 .43656 L .68379 .4368 L F
.34 0 .027 r
.36719 .58898 m .36919 .58899 L .37112 .58672 L F
.414 0 .075 r
.37112 .58672 m .36919 .58899 L .37292 .58751 L F
.416 0 .063 r
.37112 .58672 m .37292 .58751 L .37354 .58658 L F
.325 .624 .958 r
.24125 .54788 m .24077 .54926 L .23907 .54757 L F
.24125 .54788 m .24308 .54954 L .24077 .54926 L F
.894 .915 .83 r
.58018 .46339 m .57662 .46559 L .57923 .46227 L F
.903 .921 .82 r
.58018 .46339 m .58123 .45951 L .58225 .46048 L F
.58018 .46339 m .57923 .46227 L .58123 .45951 L F
.866 .833 .812 r
.57312 .47268 m .5694 .47434 L .57161 .4713 L F
.57312 .47268 m .57092 .47535 L .5694 .47434 L F
0 0 .539 r
.35529 .62799 m .35601 .62617 L .35472 .62524 L F
.069 0 .193 r
.21635 .63859 m .21414 .64162 L .21494 .63953 L F
0 .408 .701 r
.21398 .5549 m .21261 .55446 L .21047 .55385 L F
.093 .621 .872 r
.21651 .55528 m .21261 .55446 L .21398 .5549 L F
0 0 .48 r
.73932 .42663 m .73989 .42802 L .7388 .42544 L F
.887 .564 .063 r
.73989 .42802 m .73992 .42985 L .7388 .42544 L F
.559 .611 .861 r
.74186 .42605 m .73989 .42802 L .73932 .42663 L F
.74186 .42605 m .74212 .42733 L .73989 .42802 L F
.429 .021 .162 r
.74252 .42918 m .73989 .42802 L .74212 .42733 L F
.74252 .42918 m .73992 .42985 L .73989 .42802 L F
.414 0 .073 r
.44355 .62938 m .44738 .62743 L .44404 .62803 L F
.44355 .62938 m .44586 .6293 L .44738 .62743 L F
.532 .07 .104 r
.44586 .6293 m .4499 .62831 L .44738 .62743 L F
.273 0 0 r
.18065 .55413 m .17875 .55569 L .17661 .55592 L F
.048 0 0 r
.18083 .55499 m .18065 .55413 L .18267 .55337 L F
.18083 .55499 m .17875 .55569 L .18065 .55413 L F
.948 .854 .716 r
.55473 .66192 m .55528 .66477 L .55458 .66286 L F
.351 0 0 r
.40987 .62955 m .41231 .6293 L .41374 .62772 L F
.157 0 0 r
.41231 .6293 m .41609 .62751 L .41374 .62772 L F
.853 .591 .54 r
.5434 .65918 m .54637 .65962 L .54505 .66211 L F
.837 .569 .532 r
.54637 .65962 m .54799 .66208 L .54505 .66211 L F
.432 .555 .879 r
.71043 .43549 m .70786 .43429 L .71037 .43351 L F
.597 .942 .779 r
.47484 .62111 m .47397 .62215 L .47203 .62296 L F
.608 .65 .867 r
.71662 .43813 m .71559 .44204 L .71426 .43908 L F
.71662 .43813 m .71807 .44141 L .71559 .44204 L F
.662 .557 .725 r
.71807 .44141 m .71636 .44494 L .71559 .44204 L F
.603 .751 .948 r
.45125 .57824 m .4551 .57954 L .45344 .57767 L F
.511 .697 .953 r
.4551 .57954 m .45555 .57717 L .45344 .57767 L F
.4551 .57954 m .45752 .57909 L .45555 .57717 L F
.906 .921 .816 r
.58225 .46048 m .58344 .45641 L .58459 .4575 L F
.58225 .46048 m .58123 .45951 L .58344 .45641 L F
.614 .892 .989 r
.25779 .55917 m .25582 .55848 L .25529 .56002 L F
.25779 .55917 m .25582 .55848 L .25529 .56002 L F
.619 .503 .699 r
.68754 .43973 m .6902 .43922 L .68947 .43676 L F
.534 .407 .653 r
.68754 .43973 m .69023 .44158 L .6902 .43922 L F
.68754 .43973 m .68792 .4423 L .69023 .44158 L F
.769 .7 .786 r
.68411 .43915 m .68754 .43973 L .68664 .43656 L F
.761 .695 .789 r
.68664 .43656 m .68754 .43973 L .68947 .43676 L F
.395 .195 .487 r
.22504 .62627 m .22346 .62454 L .22523 .62383 L F
.22504 .62627 m .22316 .62695 L .22346 .62454 L F
.555 .572 .826 r
.6278 .41185 m .62649 .41535 L .62551 .41487 L F
.79 .768 .833 r
.62029 .44514 m .62214 .44603 L .62433 .4436 L F
.335 .35 .727 r
.34841 .60977 m .34912 .61317 L .35069 .61173 L F
.536 .514 .779 r
.34962 .61563 m .35069 .61173 L .34912 .61317 L F
.055 0 0 r
.17037 .54405 m .1745 .54296 L .17212 .54315 L F
.493 .306 .555 r
.35161 .5952 m .35364 .59703 L .35375 .59467 L F
.35161 .5952 m .35153 .59759 L .35364 .59703 L F
.339 .092 .386 r
.22746 .62299 m .22579 .62148 L .2275 .62069 L F
.22746 .62299 m .22523 .62383 L .22579 .62148 L F
.354 .617 .95 r
.37877 .64028 m .3802 .64191 L .38109 .6406 L F
.409 .691 .977 r
.3802 .64191 m .38251 .64201 L .38109 .6406 L F
.204 .098 .504 r
.21302 .59237 m .21467 .58856 L .21317 .58945 L F
0 0 .433 r
.54556 .6158 m .54683 .61689 L .5483 .61507 L F
.54556 .6158 m .54593 .61802 L .54683 .61689 L F
.264 0 0 r
.60623 .46476 m .60882 .46442 L .61008 .46367 L F
.417 0 0 r
.60882 .46442 m .61226 .46452 L .61008 .46367 L F
.86 .901 .862 r
.58709 .45473 m .58459 .4575 L .58344 .45641 L F
.346 0 0 r
.42471 .63501 m .42336 .63595 L .42092 .63619 L F
.35 0 0 r
.42709 .63497 m .42336 .63595 L .42471 .63501 L F
.963 .887 .709 r
.61027 .44396 m .61153 .44563 L .61233 .44293 L F
.974 .878 .675 r
.61011 .44843 m .61153 .44563 L .61027 .44396 L F
.773 .532 .57 r
.64121 .46487 m .63746 .46517 L .64012 .46434 L F
.754 .881 .937 r
.6414 .46189 m .64121 .46487 L .64012 .46434 L F
.007 0 0 r
.68409 .46569 m .68289 .46654 L .68085 .46652 L F
.089 0 0 r
.68664 .46537 m .68289 .46654 L .68409 .46569 L F
.777 .663 .738 r
.55857 .49498 m .56094 .49884 L .55659 .49805 L F
.791 .575 .608 r
.55659 .49805 m .56094 .49884 L .55983 .50088 L F
.69 .635 .79 r
.56171 .49759 m .56094 .49884 L .55857 .49498 L F
0 0 0 r
.55983 .50088 m .56094 .49884 L .56171 .49759 L F
.618 .136 .087 r
.41609 .62751 m .41813 .62902 L .4196 .62766 L F
.521 .024 .016 r
.4196 .62766 m .41813 .62902 L .42172 .62877 L F
.492 .13 .281 r
.4196 .62766 m .42172 .62877 L .42193 .62754 L F
.966 .701 .481 r
.58713 .63638 m .58566 .63547 L .58351 .63576 L F
.58713 .63638 m .58568 .63795 L .58566 .63547 L F
.58566 .63547 m .58568 .63795 L .58713 .63638 L F
.657 .836 .969 r
.43212 .57193 m .42844 .57181 L .43072 .57064 L F
.629 .794 .962 r
.43448 .57123 m .43212 .57193 L .43072 .57064 L F
.643 .584 .773 r
.71378 .42188 m .7116 .42474 L .71118 .42243 L F
.71378 .42188 m .71484 .42532 L .7116 .42474 L F
.842 .979 .874 r
.43806 .57711 m .43687 .57969 L .43784 .5787 L F
.43806 .57711 m .43566 .57959 L .43687 .57969 L F
.59 .589 .819 r
.71266 .41851 m .71118 .42243 L .7102 .41941 L F
.71266 .41851 m .71378 .42188 L .71118 .42243 L F
.695 .982 .861 r
.19912 .66148 m .19841 .6622 L .19819 .66268 L F
.718 .942 .631 r
.19819 .66268 m .19841 .6622 L .19752 .66328 L F
.407 0 .076 r
.45101 .63052 m .44966 .63225 L .44723 .6325 L F
0 .194 .724 r
.4499 .62831 m .45141 .62967 L .45101 .63052 L F
.664 .246 .243 r
.45101 .63052 m .45321 .63239 L .44966 .63225 L F
0 .232 .751 r
.45141 .62967 m .45321 .63239 L .45101 .63052 L F
.674 .683 .851 r
.46577 .57427 m .46395 .57553 L .46285 .57312 L F
.153 0 .132 r
.46577 .57427 m .46306 .57705 L .46395 .57553 L F
.615 .946 .939 r
.62397 .41837 m .62237 .41972 L .62447 .41886 L F
.764 .634 .717 r
.5631 .48884 m .56442 .49242 L .56072 .49195 L F
.764 .632 .714 r
.56442 .49242 m .56286 .49571 L .56072 .49195 L F
.729 .617 .732 r
.5631 .48884 m .56679 .4895 L .56442 .49242 L F
.195 .639 .945 r
.2332 .5457 m .23588 .5461 L .23752 .54708 L F
0 .415 .79 r
.23588 .5461 m .23907 .54757 L .23752 .54708 L F
.831 .362 0 r
.64804 .43374 m .64618 .4325 L .6453 .43065 L F
0 0 .523 r
.647 .43613 m .64618 .4325 L .64804 .43374 L F
.863 .854 .832 r
.6096 .43139 m .60918 .43272 L .60616 .43318 L F
.862 .855 .833 r
.60616 .43318 m .60918 .43272 L .6073 .43445 L F
.532 .427 .68 r
.50276 .73239 m .50335 .73446 L .5045 .73206 L F
.72 .398 .432 r
.50823 .69781 m .50502 .69809 L .50543 .69784 L F
.49 0 0 r
.50813 .70068 m .50502 .69809 L .50823 .69781 L F
.327 0 .12 r
.51407 .69751 m .51306 .69931 L .51069 .69988 L F
.255 .742 .924 r
.51306 .69931 m .51266 .69928 L .51069 .69988 L F
.472 .319 .592 r
.51069 .69988 m .50813 .70066 L .50823 .69781 L F
.255 .742 .924 r
.51266 .69928 m .50937 .69906 L .51069 .69988 L F
.472 .319 .592 r
.51069 .69988 m .50813 .70068 L .50813 .70066 L F
.953 .669 .462 r
.59022 .61236 m .59007 .60986 L .58859 .60913 L F
.522 .427 .688 r
.22338 .56857 m .22534 .56832 L .2251 .56531 L F
.373 .344 .697 r
.22338 .56857 m .2255 .57006 L .22534 .56832 L F
.58 .447 .664 r
.61303 .449 m .61605 .45253 L .61601 .44916 L F
.603 .422 .61 r
.71523 .42745 m .71521 .43035 L .7128 .43072 L F
.612 .565 .777 r
.71752 .42464 m .71523 .42745 L .71484 .42532 L F
.611 .564 .777 r
.71752 .42464 m .71763 .42724 L .71523 .42745 L F
.709 .574 .701 r
.71763 .42724 m .71521 .43035 L .71523 .42745 L F
.948 .854 .716 r
.55473 .66192 m .55321 .66511 L .55528 .66477 L F
.892 .773 .724 r
.55321 .66511 m .55436 .66743 L .55528 .66477 L F
.831 .872 .875 r
.46353 .63068 m .4607 .63319 L .45904 .63214 L F
.612 .438 .623 r
.46353 .63068 m .46313 .63263 L .4607 .63319 L F
.688 .216 .124 r
.46313 .63263 m .45904 .63214 L .4607 .63319 L F
.465 .372 .666 r
.53679 .67439 m .53845 .67064 L .53633 .67188 L F
.769 .261 0 r
.57715 .62002 m .57794 .62119 L .57626 .62024 L F
.57626 .62024 m .57794 .62119 L .57715 .62002 L F
.123 .661 .852 r
.18023 .5421 m .18244 .54211 L .18412 .54244 L F
.441 .824 .988 r
.18244 .54211 m .1863 .54229 L .18412 .54244 L F
.975 .696 .436 r
.66068 .44132 m .66091 .44462 L .66224 .44382 L F
.923 .72 .61 r
.65984 .4469 m .66224 .44382 L .66091 .44462 L F
.65984 .4469 m .66159 .4478 L .66224 .44382 L F
.14 .008 .426 r
.48965 .6152 m .48806 .61418 L .48946 .61417 L F
.48806 .61418 m .48667 .61328 L .48946 .61417 L F
.001 .578 .707 r
.48946 .61417 m .48782 .61418 L .49115 .61417 L F
.48946 .61417 m .49115 .61417 L .49143 .61417 L F
.317 .805 .862 r
.48599 .6147 m .48946 .61417 L .48667 .61328 L F
0 0 0 r
.40424 .57836 m .40225 .57966 L .40476 .57856 L F
.148 0 0 r
.40371 .57815 m .40424 .57836 L .40595 .57822 L F
.468 .885 .927 r
.40424 .57836 m .40832 .5778 L .40595 .57822 L F
0 0 0 r
.40424 .57836 m .40476 .57856 L .4063 .57788 L F
.148 0 0 r
.40188 .5781 m .40424 .57836 L .40371 .57815 L F
.462 0 .059 r
.41059 .58873 m .40665 .59023 L .40841 .58965 L F
.849 .94 .882 r
.66787 .41409 m .66564 .41426 L .66834 .41153 L F
.434 .389 .709 r
.7018 .45377 m .70245 .45618 L .6999 .45436 L F
.6 .345 .503 r
.70245 .45618 m .69987 .45665 L .6999 .45436 L F
0 0 0 r
.44773 .62052 m .44893 .61953 L .45077 .61826 L F
.268 .751 .926 r
.65117 .42105 m .6526 .42142 L .65135 .42134 L F
.65117 .42105 m .65135 .42134 L .64884 .42119 L F
0 .092 .595 r
.6509 .42064 m .65117 .42105 L .64995 .41974 L F
0 0 .248 r
.65317 .42278 m .6526 .42142 L .65117 .42105 L F
0 .092 .595 r
.65229 .42195 m .65117 .42105 L .6509 .42064 L F
.65317 .42278 m .65253 .42222 L .65229 .42195 L F
.65253 .42222 m .65117 .42105 L .65229 .42195 L F
.796 .398 0 r
.65393 .42386 m .65336 .42392 L .65442 .42476 L F
.6526 .42142 m .65301 .42279 L .65393 .42386 L F
.65301 .42279 m .65336 .42392 L .65393 .42386 L F
.956 .665 .23 r
.65367 .42531 m .65442 .42476 L .65336 .42392 L F
.65367 .42531 m .65456 .4266 L .65442 .42476 L F
.915 .803 .722 r
.57092 .47535 m .57019 .47759 L .5694 .47434 L F
.592 .422 .62 r
.55991 .51298 m .55981 .51543 L .5574 .51547 L F
.559 .266 .427 r
.5574 .51547 m .55967 .51721 L .55637 .51778 L F
.5574 .51547 m .55981 .51543 L .55967 .51721 L F
.689 .346 .389 r
.55411 .51562 m .5574 .51547 L .55637 .51778 L F
.747 .664 .769 r
.7129 .43341 m .71303 .43677 L .71043 .43549 L F
.777 .64 .711 r
.71303 .43677 m .7119 .4373 L .71043 .43549 L F
.69 .62 .772 r
.7164 .43352 m .71303 .43677 L .7129 .43341 L F
.39 .189 .482 r
.23388 .60379 m .23369 .6063 L .23176 .60685 L F
.373 .203 .517 r
.23369 .6063 m .2317 .60941 L .23176 .60685 L F
.385 .804 .974 r
.21401 .54256 m .21605 .54221 L .21774 .54273 L F
.191 .687 .918 r
.21605 .54221 m .21983 .54276 L .21774 .54273 L F
.731 .958 .67 r
.61233 .44293 m .61468 .44026 L .6133 .44123 L F
.68 .975 .807 r
.61468 .44026 m .61612 .43849 L .6133 .44123 L F
.61468 .44026 m .61647 .43884 L .61612 .43849 L F
.619 .074 0 r
.65778 .43473 m .65859 .43386 L .65789 .43256 L F
.65778 .43473 m .66117 .43551 L .65859 .43386 L F
.581 .548 .783 r
.5185 .69271 m .51946 .69486 L .51705 .69525 L F
.489 .163 .34 r
.51946 .69486 m .51651 .69696 L .51705 .69525 L F
.316 .718 .979 r
.22368 .54353 m .22589 .54358 L .2276 .54453 L F
.21 .654 .95 r
.22589 .54358 m .22951 .54469 L .2276 .54453 L F
.378 .019 .224 r
.62649 .41535 m .6285 .41672 L .626 .41698 L F
.354 .791 .964 r
.626 .41698 m .6285 .41672 L .62652 .41654 L F
0 0 0 r
.62511 .41774 m .62649 .41535 L .626 .41698 L F
.354 .791 .964 r
.626 .41698 m .62652 .41654 L .62562 .41646 L F
0 0 0 r
.62447 .41886 m .62511 .41774 L .626 .41698 L F
.663 .965 .924 r
.626 .41698 m .62397 .41837 L .62447 .41886 L F
.957 .635 .373 r
.533 .64985 m .53416 .64795 L .5346 .65064 L F
.418 0 .057 r
.53697 .64814 m .53416 .64795 L .533 .64985 L F
.413 .279 .587 r
.24977 .57056 m .24793 .56882 L .24962 .56816 L F
.24977 .57056 m .24798 .57136 L .24793 .56882 L F
.918 .883 .784 r
.59033 .44731 m .59153 .44844 L .58953 .45168 L F
.872 .892 .845 r
.59397 .44552 m .59153 .44844 L .59033 .44731 L F
.492 0 0 r
.49362 .69257 m .49124 .69187 L .4943 .69148 L F
.777 .522 .55 r
.49677 .73503 m .50039 .7328 L .4979 .73305 L F
.204 .098 .504 r
.21302 .59237 m .21481 .59128 L .21467 .58856 L F
.232 .527 .918 r
.21365 .59493 m .21481 .59128 L .21302 .59237 L F
.253 .734 .932 r
.51346 .72636 m .51712 .72672 L .51486 .72684 L F
.51346 .72636 m .51712 .72672 L .51486 .72684 L F
.363 .157 .462 r
.34923 .60085 m .35153 .59759 L .34922 .59824 L F
.879 .991 .745 r
.41734 .58462 m .41705 .58688 L .41874 .58647 L F
.41734 .58462 m .41519 .58779 L .41705 .58688 L F
.75 .992 .8 r
.61027 .44396 m .61233 .44293 L .6133 .44123 L F
.793 .689 .749 r
.58081 .60967 m .58194 .61283 L .5804 .6116 L F
.577 .42 .633 r
.58194 .61283 m .57907 .61516 L .5804 .6116 L F
.41 .288 .603 r
.58365 .61419 m .58197 .61538 L .58194 .61283 L F
.976 .896 .542 r
.60426 .46394 m .60578 .46007 L .60521 .45868 L F
.424 0 .01 r
.53834 .68032 m .53982 .68121 L .53869 .67843 L F
.53834 .68032 m .5369 .68189 L .53982 .68121 L F
.99 .749 .377 r
.63048 .4637 m .63147 .46581 L .6314 .46309 L F
.587 .381 .569 r
.63475 .46095 m .6314 .46309 L .63012 .45956 L F
.63475 .46095 m .6337 .46361 L .6314 .46309 L F
.592 .31 .457 r
.6314 .46309 m .63399 .46487 L .6337 .46361 L F
0 .201 .666 r
.6314 .46309 m .63399 .46487 L .63272 .46374 L F
.513 .348 .595 r
.6314 .46309 m .63147 .46581 L .63399 .46487 L F
0 .201 .666 r
.6314 .46309 m .63272 .46374 L .63048 .4637 L F
.914 .841 .388 r
.57585 .60742 m .57576 .60517 L .57641 .60423 L F
.649 .098 0 r
.57585 .60742 m .57334 .60908 L .57576 .60517 L F
.57585 .60742 m .57449 .60958 L .57334 .60908 L F
.57585 .60742 m .57588 .60822 L .57449 .60958 L F
.57585 .60742 m .57694 .60876 L .57588 .60822 L F
.688 .203 .093 r
.52494 .68226 m .52262 .68043 L .52251 .6822 L F
.574 .761 .967 r
.56728 .64176 m .57016 .64047 L .56875 .63916 L F
0 0 0 r
.56753 .64184 m .56727 .64181 L .56756 .64182 L F
.433 .745 .993 r
.56753 .64184 m .56823 .6419 L .56758 .64182 L F
.56642 .64232 m .56667 .64226 L .56753 .64184 L F
.56667 .64226 m .56823 .6419 L .56753 .64184 L F
0 0 0 r
.5686 .64102 m .57016 .64047 L .56897 .64114 L F
.56753 .64184 m .56792 .64166 L .567 .64225 L F
.567 .64225 m .56675 .64218 L .56753 .64184 L F
.567 .64225 m .56823 .6419 L .56642 .64232 L F
.567 .64225 m .56642 .64232 L .56675 .64218 L F
0 .533 .739 r
.5631 .64128 m .56758 .64182 L .56627 .64164 L F
.56338 .64128 m .56627 .64164 L .56371 .64128 L F
.5631 .64128 m .56627 .64164 L .56338 .64128 L F
.56758 .64182 m .56768 .64183 L .56371 .64128 L F
.56768 .64183 m .56769 .64183 L .56762 .64182 L F
.56768 .64183 m .56762 .64182 L .56371 .64128 L F
.574 .761 .967 r
.56691 .64171 m .56875 .63916 L .56671 .64049 L F
0 0 0 r
.56753 .64184 m .56642 .64232 L .56727 .64181 L F
.433 .745 .993 r
.56642 .64232 m .56758 .64182 L .5631 .64128 L F
.542 .839 .999 r
.567 .64225 m .56371 .64128 L .56766 .64182 L F
.574 .761 .967 r
.567 .64225 m .56728 .64176 L .56691 .64171 L F
.56728 .64176 m .56875 .63916 L .56691 .64171 L F
0 .533 .739 r
.56758 .64182 m .56823 .6419 L .56769 .64183 L F
.542 .839 .999 r
.567 .64225 m .56766 .64182 L .56823 .6419 L F
0 0 0 r
.56792 .64166 m .56897 .64114 L .567 .64225 L F
.5686 .64102 m .56897 .64114 L .56753 .64184 L F
.574 .761 .967 r
.567 .64225 m .56777 .64182 L .56728 .64176 L F
0 0 0 r
.56756 .64182 m .56727 .64181 L .5686 .64102 L F
.574 .761 .967 r
.56777 .64182 m .57016 .64047 L .56728 .64176 L F
.445 .226 .486 r
.51212 .71562 m .51223 .71788 L .50986 .71838 L F
.48 .331 .601 r
.51223 .71788 m .51218 .72049 L .50986 .71838 L F
.445 .226 .486 r
.50986 .71838 m .51223 .71788 L .51212 .71562 L F
.48 .331 .601 r
.50986 .71838 m .51218 .72049 L .51223 .71788 L F
0 0 0 r
.54677 .69127 m .54832 .69053 L .54829 .68828 L F
.746 .869 .937 r
.54829 .68828 m .54832 .69053 L .54972 .68927 L F
.925 .597 .399 r
.66833 .45862 m .66967 .45723 L .67002 .45948 L F
.992 .88 .561 r
.66899 .45605 m .66967 .45723 L .66833 .45862 L F
.925 .597 .399 r
.66833 .45862 m .66967 .45723 L .67002 .45948 L F
.968 .919 .584 r
.61972 .42713 m .62061 .42485 L .62024 .4243 L F
.61972 .42713 m .62024 .4243 L .61979 .42516 L F
.968 .657 .371 r
.61889 .43225 m .61942 .43212 L .61883 .43129 L F
.457 .218 .462 r
.618 .43049 m .6188 .42891 L .61883 .43098 L F
.618 .43049 m .61972 .42713 L .61906 .43104 L F
.762 .732 .825 r
.61883 .43129 m .61942 .43212 L .61933 .43088 L F
.457 .218 .462 r
.6188 .4312 m .61906 .43104 L .619 .43137 L F
.618 .43049 m .61906 .43104 L .6188 .4312 L F
.489 .246 .472 r
.61906 .43104 m .61972 .42713 L .62222 .42935 L F
.694 .682 .833 r
.61933 .43088 m .61942 .43212 L .62195 .42928 L F
.489 .246 .472 r
.619 .43137 m .61906 .43104 L .62222 .42935 L F
.694 .682 .833 r
.62195 .42928 m .62158 .42969 L .62222 .42935 L F
.62158 .42969 m .61942 .43212 L .62222 .42935 L F
.457 .218 .462 r
.61883 .43098 m .61972 .42713 L .61905 .43111 L F
.6188 .42891 m .61972 .42713 L .61883 .43098 L F
.694 .682 .833 r
.61915 .42853 m .61933 .43088 L .62195 .42928 L F
0 0 .372 r
.6172 .43141 m .618 .43049 L .61899 .43173 L F
.268 .326 .738 r
.61894 .43172 m .61913 .43631 L .6172 .43141 L F
.61899 .43173 m .61899 .43185 L .61894 .43172 L F
.61899 .43185 m .61913 .43631 L .61894 .43172 L F
.644 .145 0 r
.61893 .43165 m .61942 .43212 L .61899 .43173 L F
.618 .43049 m .61942 .43212 L .61893 .43165 L F
.968 .657 .371 r
.61824 .43099 m .61883 .43143 L .61725 .42905 L F
.61884 .43217 m .61883 .43156 L .61824 .43099 L F
.61883 .43156 m .61883 .43143 L .61824 .43099 L F
0 .138 .68 r
.619 .43137 m .61942 .43212 L .618 .43049 L F
.968 .657 .371 r
.61883 .43143 m .61883 .43129 L .61872 .43112 L F
.61883 .43143 m .61872 .43112 L .61725 .42905 L F
.61889 .43225 m .61883 .43129 L .61884 .43217 L F
.457 .218 .462 r
.61887 .43125 m .61905 .43111 L .619 .43137 L F
.618 .43049 m .61905 .43111 L .61887 .43125 L F
.762 .732 .825 r
.61725 .42905 m .61883 .43129 L .61915 .42853 L F
.61883 .43129 m .61933 .43088 L .61915 .42853 L F
.968 .919 .584 r
.61972 .42713 m .61985 .42372 L .61893 .42618 L F
0 .083 .592 r
.62222 .42935 m .61972 .42713 L .61893 .42618 L F
.62222 .42935 m .61916 .4264 L .61915 .42853 L F
.61916 .4264 m .61893 .42618 L .61898 .42674 L F
.61916 .4264 m .61898 .42674 L .61915 .42853 L F
.968 .919 .584 r
.61979 .42516 m .62024 .4243 L .61985 .42372 L F
.341 .804 .932 r
.38616 .64189 m .38475 .6416 L .38251 .64201 L F
.421 .828 .976 r
.38848 .64165 m .38475 .6416 L .38616 .64189 L F
.435 .373 .689 r
.34841 .60977 m .34979 .60592 L .34763 .60744 L F
.898 .483 .18 r
.53084 .67992 m .53301 .68246 L .53401 .67823 L F
.239 .014 .357 r
.21852 .6355 m .21635 .63859 L .21693 .63629 L F
.579 .793 .981 r
.67185 .40148 m .67038 .40356 L .66919 .40216 L F
.67185 .40148 m .67298 .40286 L .67038 .40356 L F
.661 .204 .156 r
.58309 .60635 m .58548 .60824 L .58658 .60668 L F
.801 .379 .246 r
.58548 .60824 m .58859 .60913 L .58658 .60668 L F
.543 .122 .192 r
.40161 .63018 m .40408 .63049 L .40496 .62953 L F
.134 0 0 r
.40408 .63049 m .4074 .62955 L .40496 .62953 L F
.272 0 .112 r
.21467 .58856 m .21663 .58811 L .21785 .58599 L F
.188 .197 .636 r
.21785 .58599 m .21937 .58531 L .21849 .5828 L F
.271 0 .112 r
.21785 .58599 m .21869 .58749 L .21937 .58531 L F
.21785 .58599 m .21663 .58811 L .21869 .58749 L F
.6 .459 .662 r
.68572 .44609 m .6882 .44583 L .68792 .4423 L F
.318 .261 .635 r
.68572 .44609 m .68811 .44685 L .6882 .44583 L F
.858 .994 .751 r
.52168 .70358 m .52402 .70056 L .52303 .70206 L F
.467 .856 .977 r
.1863 .54229 m .18839 .54169 L .19008 .54212 L F
.499 .838 .998 r
.18839 .54169 m .19217 .54187 L .19008 .54212 L F
.002 .128 .644 r
.68085 .46652 m .68289 .46654 L .68365 .46542 L F
.68085 .46652 m .68365 .46542 L .67973 .46708 L F
.833 .736 .757 r
.56789 .48063 m .56401 .48231 L .5662 .47922 L F
.56789 .48063 m .56581 .48377 L .56401 .48231 L F
.832 .773 .796 r
.57019 .47759 m .56789 .48063 L .5662 .47922 L F
0 0 .127 r
.65143 .45692 m .65311 .45448 L .65053 .4539 L F
.65143 .45692 m .65268 .45626 L .65311 .45448 L F
0 0 0 r
.65143 .45692 m .65143 .45731 L .65268 .45626 L F
.56 .032 0 r
.19478 .55355 m .19085 .55319 L .19265 .55398 L F
.79 .768 .833 r
.62029 .44514 m .62336 .44165 L .62109 .4429 L F
.836 .765 .784 r
.5694 .47434 m .57019 .47759 L .56848 .47616 L F
.832 .773 .796 r
.57019 .47759 m .5662 .47922 L .56848 .47616 L F
.621 .595 .802 r
.70557 .41445 m .70422 .41885 L .70298 .4153 L F
.70557 .41445 m .70673 .41819 L .70422 .41885 L F
.466 .358 .647 r
.2317 .60941 m .23229 .61223 L .23018 .6128 L F
.316 .131 .464 r
.23154 .61442 m .23018 .6128 L .23229 .61223 L F
.23154 .61442 m .22995 .61518 L .23018 .6128 L F
.434 .282 .575 r
.24798 .57136 m .24803 .57387 L .24608 .57445 L F
.456 .299 .579 r
.24803 .57387 m .24602 .57674 L .24608 .57445 L F
.626 .185 .184 r
.53705 .68857 m .53535 .69042 L .53346 .68868 L F
.823 .59 .585 r
.53937 .68907 m .53535 .69042 L .53705 .68857 L F
.941 .762 .631 r
.54799 .66208 m .54503 .66427 L .54505 .66211 L F
.54799 .66208 m .54656 .66516 L .54503 .66427 L F
.831 .872 .875 r
.46353 .63068 m .45904 .63214 L .46182 .63021 L F
.739 .992 .835 r
.46455 .62945 m .46353 .63068 L .46403 .62921 L F
.623 .922 .976 r
.46403 .62921 m .46353 .63068 L .46182 .63021 L F
.696 .564 .702 r
.71521 .43035 m .7129 .43341 L .7128 .43072 L F
.995 .841 .49 r
.20219 .61609 m .20142 .61525 L .20211 .61256 L F
.871 .509 .015 r
.20219 .61609 m .20315 .61868 L .20142 .61525 L F
.869 .789 .77 r
.67889 .4418 m .68145 .44214 L .68105 .43822 L F
.878 .763 .731 r
.67968 .44483 m .68145 .44214 L .67889 .4418 L F
.748 .706 .812 r
.68105 .43822 m .68145 .44214 L .68411 .43915 L F
.605 .477 .68 r
.56469 .50956 m .56251 .5126 L .56218 .50983 L F
.62 .613 .821 r
.69031 .45347 m .69266 .45454 L .69263 .45445 L F
.984 .759 .518 r
.69386 .45429 m .69338 .45477 L .6927 .45448 L F
.69386 .45429 m .6927 .45448 L .69271 .45444 L F
0 0 .056 r
.69266 .45454 m .69251 .45565 L .6927 .45453 L F
.282 .375 .781 r
.69263 .45445 m .69266 .45454 L .69268 .45449 L F
.74 .303 .213 r
.69031 .45347 m .69251 .45565 L .69266 .45454 L F
.984 .759 .518 r
.69267 .45447 m .69251 .45565 L .69031 .45347 L F
.69338 .45477 m .69299 .45517 L .69267 .45447 L F
0 0 .056 r
.69266 .45454 m .6927 .45453 L .69268 .45449 L F
.984 .759 .518 r
.69299 .45517 m .69251 .45565 L .69267 .45447 L F
.69386 .45429 m .69263 .45445 L .69193 .45385 L F
0 0 .056 r
.69268 .45449 m .6941 .45403 L .69415 .45148 L F
.6927 .45453 m .6941 .45403 L .69268 .45449 L F
.6927 .45453 m .69251 .45565 L .6941 .45403 L F
.984 .759 .518 r
.69271 .45444 m .6927 .45448 L .69263 .45445 L F
.69193 .45385 m .69263 .45445 L .69031 .45347 L F
.282 .375 .781 r
.69115 .44838 m .69263 .45445 L .69415 .45148 L F
.69263 .45445 m .69268 .45449 L .69415 .45148 L F
.62 .613 .821 r
.69031 .45347 m .69263 .45445 L .69115 .44838 L F
.984 .759 .518 r
.69386 .45429 m .6938 .45671 L .69251 .45565 L F
.76 .63 .717 r
.56072 .49195 m .56286 .49571 L .55857 .49498 L F
.69 .635 .79 r
.56171 .49759 m .55857 .49498 L .56286 .49571 L F
.389 .057 .278 r
.57074 .50627 m .57306 .50412 L .57307 .50646 L F
.646 .418 .558 r
.57537 .50383 m .57307 .50646 L .57306 .50412 L F
.656 .759 .926 r
.19478 .55355 m .19492 .55479 L .19844 .55455 L F
.508 .901 .759 r
.41158 .57658 m .41251 .57569 L .41348 .57586 L F
.41158 .57658 m .41051 .57696 L .41251 .57569 L F
.446 .234 .497 r
.23582 .6055 m .23388 .60379 L .23544 .60289 L F
.23582 .6055 m .23369 .6063 L .23388 .60379 L F
.968 .924 .596 r
.55375 .68159 m .55558 .67967 L .55544 .67934 L F
.55375 .68159 m .55432 .68311 L .55558 .67967 L F
.808 .777 .272 r
.55623 .67569 m .55544 .67934 L .55558 .67967 L F
.872 .892 .845 r
.59397 .44552 m .59033 .44731 L .59298 .44459 L F
.855 .937 .876 r
.59652 .4428 m .59397 .44552 L .59298 .44459 L F
.129 0 .187 r
.48145 .6256 m .48025 .62493 L .48223 .62423 L F
.48145 .6256 m .4797 .6267 L .48025 .62493 L F
.628 .376 .518 r
.60291 .48956 m .60309 .49198 L .60055 .4919 L F
.594 .351 .518 r
.60627 .49106 m .60291 .48956 L .60637 .48894 L F
.60627 .49106 m .60309 .49198 L .60291 .48956 L F
.539 .127 .208 r
.69254 .46275 m .69175 .46457 L .68916 .46438 L F
.212 0 .071 r
.69413 .46359 m .69254 .46275 L .69504 .46249 L F
.69413 .46359 m .69175 .46457 L .69254 .46275 L F
.414 0 0 r
.17462 .55558 m .17661 .55592 L .17378 .55628 L F
.503 .391 .659 r
.23683 .81767 m .23488 .81853 L .23436 .81645 L F
.481 0 0 r
.23436 .81645 m .23577 .81757 L .23314 .81791 L F
.23436 .81645 m .23683 .81767 L .23577 .81757 L F
.967 .883 .5 r
.63424 .44578 m .6349 .44599 L .63448 .44501 L F
0 .436 .712 r
.63334 .44566 m .6355 .44619 L .6349 .44599 L F
.643 .152 .071 r
.63129 .4455 m .6349 .44599 L .63379 .44722 L F
.967 .883 .5 r
.63379 .44722 m .6349 .44599 L .63424 .44578 L F
0 .436 .712 r
.6355 .44619 m .63666 .44647 L .6349 .44599 L F
.86 .901 .862 r
.58709 .45473 m .58344 .45641 L .5856 .45328 L F
.847 .815 .819 r
.58953 .45168 m .58709 .45473 L .5856 .45328 L F
.286 .745 .953 r
.53429 .66505 m .53712 .66497 L .53798 .66551 L F
.53429 .66505 m .53712 .66497 L .53798 .66551 L F
.992 .755 .39 r
.53798 .66551 m .53784 .66812 L .53712 .66497 L F
.79 .528 .542 r
.57576 .60517 m .57929 .60359 L .57641 .60423 L F
.492 .334 .594 r
.68683 .45095 m .68927 .4503 L .68895 .44804 L F
.519 .536 .813 r
.68683 .45095 m .69031 .45347 L .68927 .4503 L F
.3 .324 .719 r
.6833 .45002 m .68161 .44817 L .68278 .44899 L F
.401 0 0 r
.52494 .68226 m .52846 .68214 L .52637 .68167 L F
.556 .141 .21 r
.43288 .63368 m .43513 .63503 L .433 .63485 L F
0 .119 .67 r
.66413 .42987 m .66243 .42654 L .66351 .42776 L F
.356 .224 .561 r
.24413 .58315 m .24413 .58562 L .24248 .58624 L F
.364 .243 .58 r
.24413 .58562 m .24427 .58812 L .24248 .58624 L F
.345 .241 .591 r
.24248 .58624 m .24427 .58812 L .24271 .58884 L F
.654 .588 .769 r
.55499 .68809 m .55386 .68502 L .5513 .68718 L F
.55499 .68809 m .55546 .68755 L .55386 .68502 L F
.754 .754 .852 r
.5579 .68602 m .55546 .68755 L .55499 .68809 L F
.164 0 0 r
.3946 .63985 m .39296 .64058 L .39061 .64074 L F
.209 0 0 r
.39736 .64028 m .39296 .64058 L .3946 .63985 L F
.606 .623 .842 r
.68614 .41965 m .68964 .42172 L .68849 .41864 L F
.043 0 0 r
.68964 .42172 m .68634 .42323 L .68859 .42275 L F
.609 .623 .84 r
.68964 .42172 m .6908 .418 L .68849 .41864 L F
.68964 .42172 m .69237 .42169 L .6908 .418 L F
.032 0 0 r
.69114 .42179 m .68964 .42172 L .68859 .42275 L F
.69114 .42179 m .69237 .42169 L .68964 .42172 L F
.598 .282 .406 r
.55991 .51298 m .56228 .51477 L .55981 .51543 L F
.55991 .51298 m .56251 .5126 L .56228 .51477 L F
.565 .761 .97 r
.52214 .65061 m .5259 .6515 L .52444 .64994 L F
.52214 .65061 m .5259 .6515 L .52444 .64994 L F
.675 .749 .906 r
.52444 .64994 m .5259 .6515 L .52813 .65047 L F
.52813 .65047 m .5259 .6515 L .52444 .64994 L F
.653 .852 .976 r
.42362 .58183 m .42131 .58274 L .42509 .58285 L F
.671 .227 .187 r
.42131 .58274 m .42367 .58468 L .42509 .58285 L F
.524 .351 .589 r
.42738 .5801 m .42771 .58285 L .42509 .58285 L F
.565 .311 .49 r
.59817 .49206 m .60047 .49394 L .59911 .49425 L F
.59817 .49206 m .60055 .4919 L .60047 .49394 L F
.465 .372 .666 r
.53679 .67439 m .53911 .67398 L .53845 .67064 L F
.486 .496 .793 r
.53679 .67439 m .54079 .67513 L .53911 .67398 L F
.841 .861 .858 r
.6073 .43445 m .60353 .43609 L .60616 .43318 L F
.487 .385 .664 r
.38132 .61151 m .37936 .6124 L .37966 .61061 L F
.556 .414 .644 r
.38132 .61151 m .37956 .61582 L .37936 .6124 L F
.974 .666 .337 r
.67088 .4483 m .66992 .44956 L .67028 .44717 L F
.67088 .4483 m .67123 .45082 L .66992 .44956 L F
.8 .602 .634 r
.67002 .45948 m .67345 .46004 L .67184 .46281 L F
.697 .447 .541 r
.72611 .43653 m .72632 .43882 L .72379 .43862 L F
.702 .643 .787 r
.72946 .43574 m .72611 .43653 L .72622 .4341 L F
.541 .27 .453 r
.72946 .43574 m .72632 .43882 L .72611 .43653 L F
.847 .815 .819 r
.58953 .45168 m .5856 .45328 L .58829 .45055 L F
.918 .883 .784 r
.59033 .44731 m .58953 .45168 L .58829 .45055 L F
.382 .55 .896 r
.68708 .41068 m .68338 .40772 L .68583 .40715 L F
.585 .588 .822 r
.68811 .40656 m .68708 .41068 L .68583 .40715 L F
.68811 .40656 m .68963 .41014 L .68708 .41068 L F
.968 .676 .422 r
.62698 .45492 m .62868 .45412 L .62527 .45372 L F
.62698 .45492 m .62876 .4565 L .62868 .45412 L F
.435 .373 .689 r
.34841 .60977 m .35016 .60925 L .34979 .60592 L F
.43 .357 .673 r
.34841 .60977 m .35069 .61173 L .35016 .60925 L F
.437 .055 .216 r
.39772 .59483 m .39627 .59705 L .39382 .59728 L F
0 0 0 r
.39985 .59461 m .39627 .59705 L .39772 .59483 L F
.277 .762 .918 r
.58351 .63576 m .58566 .63547 L .58204 .6354 L F
.603 .318 .458 r
.58964 .49512 m .59204 .49708 L .58873 .49747 L F
.58964 .49512 m .59216 .49497 L .59204 .49708 L F
.04 .371 .839 r
.48896 .70225 m .48855 .70336 L .49015 .70419 L F
.856 .914 .871 r
.6612 .41688 m .65911 .41906 L .65811 .41786 L F
.997 .805 .523 r
.65911 .41906 m .6577 .42004 L .65811 .41786 L F
.65911 .41906 m .65873 .42125 L .6577 .42004 L F
.849 .754 .758 r
.62234 .41197 m .62547 .41236 L .62269 .4163 L F
.326 .78 .951 r
.62647 .41221 m .62547 .41236 L .62234 .41197 L F
.474 .107 .261 r
.35647 .59349 m .35908 .59172 L .35672 .59225 L F
.942 .888 .748 r
.19091 .63609 m .19126 .63544 L .19211 .63611 L F
.54 .363 .59 r
.19012 .63767 m .19162 .63596 L .19126 .63544 L F
.591 .068 0 r
.19211 .63611 m .19126 .63544 L .19116 .63531 L F
.54 .363 .59 r
.19162 .63596 m .19249 .63497 L .19126 .63544 L F
.591 .068 0 r
.19116 .63531 m .19126 .63544 L .19099 .63517 L F
.787 .853 .901 r
.61382 .4243 m .614 .42684 L .61058 .42702 L F
.829 .763 .789 r
.614 .42684 m .6116 .43013 L .61058 .42702 L F
.871 .906 .853 r
.61642 .42389 m .614 .42684 L .61382 .4243 L F
.536 .514 .779 r
.34962 .61563 m .35176 .61526 L .35069 .61173 L F
.573 .563 .805 r
.34962 .61563 m .35316 .61839 L .35176 .61526 L F
.473 .073 .2 r
.20609 .60874 m .2085 .60871 L .20936 .60652 L F
0 0 0 r
.20936 .60652 m .21103 .60302 L .20876 .60347 L F
.20936 .60652 m .21043 .60515 L .21103 .60302 L F
.143 0 .067 r
.20936 .60652 m .21037 .60777 L .21043 .60515 L F
.20936 .60652 m .2085 .60871 L .21037 .60777 L F
.827 .762 .791 r
.61058 .42702 m .6116 .43013 L .60836 .43008 L F
.809 .804 .847 r
.60836 .43008 m .6116 .43013 L .6096 .43139 L F
.721 .982 .776 r
.61612 .43849 m .61647 .43884 L .61913 .43631 L F
.724 .728 .853 r
.7032 .43292 m .70917 .43405 L .70573 .42982 L F
.648 .391 .516 r
.7032 .43292 m .70858 .43352 L .70917 .43405 L F
.059 .233 .729 r
.70917 .43405 m .70813 .42886 L .70573 .42982 L F
.70917 .43405 m .70967 .43277 L .70813 .42886 L F
.68 .503 .64 r
.70858 .43352 m .70967 .43277 L .70917 .43405 L F
.43 .243 .525 r
.55448 .63212 m .55423 .63516 L .55589 .6336 L F
.55589 .6336 m .55423 .63516 L .55448 .63212 L F
.773 .995 .87 r
.5542 .63439 m .55423 .63516 L .55589 .6336 L F
0 .103 .657 r
.55427 .63628 m .55423 .63516 L .5518 .63241 L F
.761 .253 0 r
.5518 .63241 m .55423 .63516 L .55285 .63492 L F
.773 .995 .87 r
.55305 .63492 m .55423 .63516 L .5542 .63439 L F
0 .103 .657 r
.55439 .63646 m .55423 .63516 L .55427 .63628 L F
.533 .035 .019 r
.40242 .64023 m .39902 .64026 L .40054 .63936 L F
.599 .426 .619 r
.58304 .62384 m .58545 .62074 L .58392 .62191 L F
.33 .118 .433 r
.63719 .45953 m .6337 .46361 L .63475 .46095 L F
.79 .768 .833 r
.62029 .44514 m .62433 .4436 L .62336 .44165 L F
.666 .625 .799 r
.62433 .4436 m .62664 .44235 L .62336 .44165 L F
.66 .426 .555 r
.58625 .49785 m .58382 .50036 L .58382 .49822 L F
.729 .679 .802 r
.53841 .64689 m .54033 .65048 L .5407 .64805 L F
.263 0 .271 r
.65445 .45965 m .65189 .46219 L .65235 .46064 L F
.714 .733 .866 r
.19478 .55355 m .19844 .55455 L .19732 .55263 L F
.508 .618 .896 r
.19844 .55455 m .19988 .55225 L .19732 .55263 L F
.509 .617 .895 r
.20024 .55354 m .20037 .55459 L .19844 .55455 L F
.508 .618 .896 r
.19844 .55455 m .20037 .55459 L .19988 .55225 L F
.267 0 0 r
.38145 .58504 m .3838 .58479 L .38539 .58345 L F
.234 0 0 r
.3838 .58479 m .38774 .58313 L .38539 .58345 L F
.512 .193 .364 r
.60885 .48628 m .61079 .48774 L .60858 .48856 L F
.60885 .48628 m .61134 .48603 L .61079 .48774 L F
.487 .385 .664 r
.38132 .61151 m .37966 .61061 L .38133 .60954 L F
0 0 .111 r
.52413 .69167 m .52694 .68822 L .52467 .68913 L F
.086 .275 .759 r
.25091 .56176 m .24904 .56013 L .25103 .55935 L F
.803 .693 .743 r
.5631 .48884 m .56173 .4852 L .56321 .48666 L F
.5631 .48884 m .55943 .48851 L .56173 .4852 L F
.803 .695 .746 r
.5631 .48884 m .56072 .49195 L .55943 .48851 L F
.63 .678 .877 r
.70154 .41229 m .7005 .41605 L .69887 .41252 L F
.70154 .41229 m .70298 .4153 L .7005 .41605 L F
.37 0 .011 r
.37292 .58751 m .37681 .58562 L .37354 .58658 L F
.37292 .58751 m .37525 .58733 L .37681 .58562 L F
.23 0 0 r
.37525 .58733 m .37918 .58555 L .37681 .58562 L F
.584 .332 .501 r
.19052 .63268 m .19352 .63001 L .19282 .63021 L F
.525 .446 .709 r
.68947 .43676 m .6902 .43922 L .6925 .43854 L F
.758 .702 .798 r
.68664 .43656 m .68947 .43676 L .68848 .43537 L F
.577 .639 .876 r
.68848 .43537 m .68947 .43676 L .69211 .43612 L F
.542 .44 .687 r
.68947 .43676 m .6925 .43854 L .69211 .43612 L F
.436 0 0 r
.38863 .62664 m .39078 .6277 L .39201 .6276 L F
.765 .252 0 r
.39078 .6277 m .39391 .62985 L .39201 .6276 L F
.195 .33 .774 r
.39179 .62683 m .39219 .62839 L .39078 .6277 L F
.39219 .62839 m .39228 .62877 L .39078 .6277 L F
.436 0 0 r
.38839 .62657 m .39078 .6277 L .38863 .62664 L F
.736 .974 .925 r
.4441 .57014 m .44509 .56868 L .44617 .56915 L F
.4441 .57014 m .44235 .57044 L .44509 .56868 L F
.621 .509 .706 r
.6882 .44583 m .69023 .44158 L .68792 .4423 L F
.232 .527 .918 r
.21365 .59493 m .21393 .59343 L .21469 .59168 L F
.421 .463 .799 r
.2142 .59769 m .2144 .59414 L .21365 .59493 L F
.96 .736 .555 r
.21393 .59343 m .21424 .59732 L .21277 .5961 L F
.21393 .59343 m .21277 .5961 L .2117 .59521 L F
.232 .527 .918 r
.21469 .59168 m .21393 .59343 L .21481 .59128 L F
.21365 .59493 m .2144 .59414 L .21393 .59343 L F
.8 .999 .846 r
.68341 .42138 m .68614 .41965 L .68509 .41826 L F
.68 .809 .945 r
.68614 .41965 m .68849 .41864 L .68509 .41826 L F
.423 .187 .449 r
.21654 .58012 m .21675 .58012 L .21894 .57735 L F
0 0 .02 r
.21894 .57735 m .21991 .57617 L .22057 .57399 L F
.182 .011 .4 r
.21675 .58012 m .21991 .57617 L .21894 .57735 L F
0 0 .528 r
.63972 .44768 m .64105 .45052 L .64087 .45116 L F
.837 .369 .057 r
.63666 .44647 m .64097 .4506 L .63972 .44768 L F
.911 .528 .105 r
.64127 .45039 m .64115 .45018 L .64191 .44917 L F
.64087 .45116 m .64104 .45055 L .64127 .45039 L F
.64104 .45055 m .64115 .45018 L .64127 .45039 L F
.64087 .45116 m .6403 .45132 L .64105 .45052 L F
0 0 .505 r
.63957 .45039 m .64009 .45158 L .64081 .45072 L F
.911 .528 .105 r
.6403 .45132 m .64027 .45133 L .64043 .45117 L F
.6403 .45132 m .64043 .45117 L .64105 .45052 L F
0 0 .528 r
.64105 .45052 m .64119 .45082 L .64087 .45116 L F
0 0 .505 r
.64081 .45072 m .64009 .45158 L .64119 .45082 L F
.837 .369 .057 r
.64097 .4506 m .64081 .45072 L .64119 .45082 L F
.63666 .44647 m .64081 .45072 L .64097 .4506 L F
.64097 .4506 m .64119 .45082 L .64105 .45052 L F
.911 .528 .105 r
.64105 .45052 m .64027 .45133 L .64115 .45018 L F
0 .09 .62 r
.64066 .45082 m .64111 .45103 L .64191 .44917 L F
.911 .528 .105 r
.64087 .45116 m .64009 .45158 L .64027 .45133 L F
0 .09 .62 r
.64009 .45158 m .64051 .45135 L .64066 .45082 L F
.911 .528 .105 r
.64009 .45158 m .64087 .45116 L .64119 .45082 L F
0 .09 .62 r
.64051 .45135 m .64111 .45103 L .64066 .45082 L F
.837 .369 .057 r
.63666 .44647 m .63957 .45039 L .6407 .45069 L F
.64072 .45063 m .6407 .45069 L .64081 .45072 L F
.63666 .44647 m .6407 .45069 L .64072 .45063 L F
.64097 .4506 m .64105 .45052 L .63972 .44768 L F
.911 .528 .105 r
.64009 .45158 m .64146 .4531 L .64087 .45116 L F
.754 .981 .912 r
.64229 .44984 m .64087 .45116 L .64191 .44917 L F
.911 .528 .105 r
.64087 .45116 m .64146 .4531 L .64009 .45158 L F
0 0 0 r
.63601 .4713 m .63856 .46851 L .63762 .47016 L F
.694 .957 .949 r
.42193 .573 m .42004 .57428 L .42082 .57263 L F
.711 .972 .928 r
.42004 .57428 m .41892 .574 L .42082 .57263 L F
.668 .485 .628 r
.57886 .50132 m .57908 .50392 L .57537 .50383 L F
.626 .462 .641 r
.58123 .50092 m .57908 .50392 L .57886 .50132 L F
.897 .957 .828 r
.69201 .45828 m .69251 .45565 L .6938 .45671 L F
.69201 .45828 m .6903 .45832 L .69251 .45565 L F
.637 .219 0 r
.66861 .43643 m .66803 .43555 L .66674 .43338 L F
.899 .548 .369 r
.66861 .43643 m .66921 .43855 L .66723 .43777 L F
.798 .727 .786 r
.56581 .48377 m .56173 .4852 L .56401 .48231 L F
.56581 .48377 m .56321 .48666 L .56173 .4852 L F
.594 .231 .323 r
.51301 .69162 m .51586 .69317 L .51547 .69147 L F
.51301 .69162 m .51187 .69377 L .51586 .69317 L F
.706 .846 .949 r
.68026 .42617 m .68168 .42742 L .68354 .42597 L F
.68026 .42617 m .68168 .42742 L .68354 .42597 L F
.649 .538 .714 r
.68168 .42742 m .6851 .43026 L .68354 .42597 L F
.68168 .42742 m .68251 .43089 L .6851 .43026 L F
.662 .557 .725 r
.71807 .44141 m .7189 .44504 L .71636 .44494 L F
.609 .329 .467 r
.7189 .44504 m .7157 .44725 L .71636 .44494 L F
.345 .18 .509 r
.23816 .59727 m .23807 .59984 L .23577 .6007 L F
.434 .276 .567 r
.23807 .59984 m .23544 .60289 L .23577 .6007 L F
.696 .603 .748 r
.55386 .68502 m .55546 .68755 L .5579 .68602 L F
.585 .811 .986 r
.52008 .67088 m .51787 .67165 L .51629 .67035 L F
.52008 .67088 m .51787 .67165 L .51629 .67035 L F
.582 .624 .859 r
.22336 .5628 m .22338 .56281 L .22516 .56329 L F
.22338 .56281 m .22731 .56477 L .22516 .56329 L F
.468 .726 .982 r
.22731 .56477 m .2277 .56286 L .22516 .56329 L F
.593 .224 .311 r
.2277 .56286 m .22625 .56358 L .22516 .56329 L F
.875 .459 .025 r
.22416 .56346 m .2251 .56531 L .22336 .5628 L F
.582 .624 .859 r
.22336 .5628 m .2251 .56531 L .22731 .56477 L F
.593 .224 .311 r
.22625 .56358 m .22367 .56486 L .22516 .56329 L F
.272 0 0 r
.22516 .56329 m .22506 .56328 L .22336 .5628 L F
.875 .459 .025 r
.22416 .56346 m .22336 .5628 L .22261 .56258 L F
.272 0 0 r
.22506 .56328 m .2217 .56322 L .22336 .5628 L F
.875 .459 .025 r
.22261 .56258 m .22336 .5628 L .22154 .56198 L F
.611 .561 .773 r
.71632 .42107 m .71484 .42532 L .71378 .42188 L F
.71632 .42107 m .71752 .42464 L .71484 .42532 L F
.69 .343 .383 r
.63466 .43898 m .63708 .44101 L .63839 .43867 L F
.758 .425 .422 r
.63839 .43867 m .64061 .44069 L .64074 .43879 L F
.63839 .43867 m .63708 .44101 L .64061 .44069 L F
.562 .336 .529 r
.19352 .63001 m .19617 .6298 L .19621 .62725 L F
.435 .235 .508 r
.19621 .62725 m .19617 .6298 L .1982 .6268 L F
0 .132 .677 r
.21654 .58012 m .21805 .58143 L .21675 .58012 L F
.21654 .58012 m .21849 .5828 L .21805 .58143 L F
.594 .65 .875 r
.68512 .40534 m .68338 .40772 L .68362 .40665 L F
.68512 .40534 m .68583 .40715 L .68338 .40772 L F
.725 .845 .938 r
.64593 .4619 m .64368 .46336 L .6425 .46175 L F
0 .274 .766 r
.6425 .46175 m .64368 .46336 L .64558 .46461 L F
.569 .619 .862 r
.67873 .40343 m .67719 .40475 L .67634 .40397 L F
.488 .827 .998 r
.36205 .63018 m .36282 .62909 L .36046 .62942 L F
.631 .311 .411 r
.56251 .5126 m .56471 .51473 L .56228 .51477 L F
.568 .429 .652 r
.56469 .50956 m .56471 .5123 L .56251 .5126 L F
.541 .322 .532 r
.56251 .5126 m .56471 .5123 L .56471 .51473 L F
.488 .298 .55 r
.68281 .4331 m .6851 .43026 L .68251 .43089 L F
.718 .653 .783 r
.64074 .43879 m .64195 .4423 L .64389 .44204 L F
.597 .344 .505 r
.64202 .44467 m .64389 .44204 L .64195 .4423 L F
.558 .502 .748 r
.64427 .44014 m .64389 .44204 L .64768 .43912 L F
.023 0 .439 r
.64389 .44204 m .64428 .4447 L .64607 .44249 L F
.516 .302 .527 r
.50072 .70357 m .50024 .70628 L .49787 .70661 L F
.095 0 .3 r
.49975 .70729 m .4993 .70641 L .50024 .70628 L F
.003 0 .447 r
.49898 .71058 m .49943 .70716 L .50009 .70743 L F
.798 .551 .564 r
.49998 .7078 m .50231 .70813 L .50009 .70744 L F
.003 0 .447 r
.49898 .71058 m .50009 .70743 L .49981 .70836 L F
.798 .551 .564 r
.50302 .70582 m .50231 .70813 L .49978 .70778 L F
.003 0 .447 r
.49898 .71058 m .49749 .70884 L .49943 .70716 L F
0 0 .012 r
.49943 .70716 m .49749 .70884 L .49948 .70777 L F
.71 .482 .577 r
.49981 .70836 m .49977 .70761 L .49865 .70806 L F
0 0 .012 r
.49953 .70771 m .49948 .70777 L .49953 .70774 L F
.49943 .70716 m .49948 .70777 L .49953 .70771 L F
.095 0 .3 r
.49953 .70771 m .49943 .70716 L .49956 .70769 L F
.49943 .70716 m .4993 .70641 L .49975 .70729 L F
.49953 .70774 m .49787 .70661 L .4993 .70641 L F
.4995 .70772 m .49749 .70884 L .49787 .70661 L F
.49953 .70774 m .49948 .70777 L .4995 .70772 L F
.49948 .70777 m .49749 .70884 L .4995 .70772 L F
.71 .482 .577 r
.4995 .70772 m .49969 .70628 L .49865 .70806 L F
.095 0 .3 r
.49956 .70769 m .49943 .70716 L .49975 .70729 L F
.49953 .70774 m .49953 .70771 L .49956 .70769 L F
.798 .551 .564 r
.50302 .70582 m .50009 .70744 L .50024 .70628 L F
.50009 .70744 m .49975 .70729 L .50024 .70628 L F
.003 0 .447 r
.49975 .70729 m .49943 .70716 L .49944 .70716 L F
.49975 .70729 m .49944 .70716 L .50065 .70611 L F
.798 .551 .564 r
.50009 .70744 m .49977 .70761 L .49975 .70729 L F
.49977 .70761 m .49953 .70774 L .49956 .70769 L F
.49977 .70761 m .49956 .70769 L .49975 .70729 L F
.546 .329 .536 r
.50302 .70582 m .50024 .70628 L .50072 .70357 L F
.743 .614 .715 r
.49496 .70713 m .50005 .70622 L .49876 .70509 L F
.798 .551 .564 r
.5004 .70652 m .50076 .70544 L .50016 .70632 L F
0 0 .012 r
.49984 .70726 m .49943 .70716 L .49953 .70771 L F
.003 0 .447 r
.50009 .70743 m .49975 .70729 L .50044 .70639 L F
.798 .551 .564 r
.50009 .70744 m .5004 .70652 L .50016 .70632 L F
0 0 .012 r
.50065 .70611 m .50049 .70625 L .49984 .70726 L F
.50049 .70625 m .49943 .70716 L .49984 .70726 L F
.71 .482 .577 r
.49977 .70761 m .49984 .70726 L .49976 .70738 L F
.49977 .70761 m .49976 .70738 L .49953 .70771 L F
.798 .551 .564 r
.49953 .70774 m .50009 .70744 L .49992 .70714 L F
.71 .482 .577 r
.49953 .70771 m .49954 .70757 L .4995 .70772 L F
.49954 .70757 m .49969 .70628 L .4995 .70772 L F
.49976 .70738 m .49969 .70628 L .49953 .70771 L F
.49865 .70806 m .49969 .70628 L .49496 .70713 L F
.798 .551 .564 r
.49953 .70774 m .49992 .70714 L .49876 .70509 L F
.49988 .70707 m .50023 .70535 L .49876 .70509 L F
.50009 .70744 m .50023 .70535 L .49988 .70707 L F
.743 .614 .715 r
.50005 .70622 m .50065 .70611 L .49876 .70509 L F
.798 .551 .564 r
.50016 .70632 m .50076 .70544 L .50023 .70535 L F
.71 .482 .577 r
.49977 .70761 m .50065 .70611 L .49984 .70726 L F
.003 0 .447 r
.49981 .70836 m .50009 .70743 L .50015 .70746 L F
.798 .551 .564 r
.49953 .70774 m .49998 .7078 L .50009 .70744 L F
.71 .482 .577 r
.49981 .70836 m .50015 .70746 L .49977 .70761 L F
.798 .551 .564 r
.50009 .70744 m .50302 .70582 L .50076 .70544 L F
.003 0 .447 r
.50015 .70746 m .50009 .70743 L .50065 .70611 L F
.50009 .70743 m .50044 .70639 L .50065 .70611 L F
.71 .482 .577 r
.50015 .70746 m .50065 .70611 L .49977 .70761 L F
0 0 .012 r
.50065 .70611 m .49953 .70771 L .49953 .70774 L F
.71 .482 .577 r
.49976 .70738 m .50065 .70611 L .49969 .70628 L F
.798 .551 .564 r
.49977 .70761 m .49978 .70778 L .49953 .70774 L F
.50302 .70582 m .49978 .70778 L .49977 .70761 L F
.868 .621 .562 r
.49749 .70884 m .49458 .71103 L .49369 .70876 L F
.49749 .70884 m .4976 .71144 L .49458 .71103 L F
.003 0 .447 r
.49898 .71058 m .4976 .71144 L .49749 .70884 L F
.71 .482 .577 r
.49898 .71058 m .49981 .70836 L .49496 .70713 L F
.798 .551 .564 r
.50009 .70744 m .50231 .70813 L .50302 .70582 L F
.37 .183 .492 r
.22031 .6348 m .21874 .63305 L .22043 .63221 L F
.22031 .6348 m .21852 .6355 L .21874 .63305 L F
.715 .98 .776 r
.63279 .4737 m .63601 .4713 L .63479 .47249 L F
.778 .346 .224 r
.49876 .70509 m .50072 .70357 L .4972 .70262 L F
.546 .329 .536 r
.50302 .70582 m .50072 .70357 L .50232 .70293 L F
.816 .589 .594 r
.49876 .70509 m .50232 .70293 L .50072 .70357 L F
.702 .643 .787 r
.72946 .43574 m .72622 .4341 L .72853 .43312 L F
.541 .27 .453 r
.72946 .43574 m .72903 .4384 L .72632 .43882 L F
.63 .574 .773 r
.7314 .43227 m .72946 .43574 L .72853 .43312 L F
.7314 .43227 m .73216 .43622 L .72946 .43574 L F
.636 .256 .306 r
.72946 .43574 m .73234 .43767 L .72903 .4384 L F
.72946 .43574 m .73216 .43622 L .73234 .43767 L F
.409 0 .09 r
.41836 .63588 m .41707 .63761 L .4149 .63766 L F
.464 0 .023 r
.42092 .63619 m .41707 .63761 L .41836 .63588 L F
.884 .542 .395 r
.54786 .65324 m .54958 .65678 L .55097 .65661 L F
.84 .443 .295 r
.54958 .65678 m .54969 .65818 L .55097 .65661 L F
.946 .626 .394 r
.54969 .65818 m .55128 .659 L .55097 .65661 L F
.839 .713 .724 r
.64061 .44069 m .64195 .4423 L .64074 .43879 L F
.812 .62 .642 r
.64061 .44069 m .64202 .44467 L .64195 .4423 L F
.116 0 .223 r
.48525 .62096 m .48727 .61817 L .48748 .62022 L F
0 0 0 r
.48727 .61817 m .48965 .6152 L .49016 .61723 L F
.399 .157 .427 r
.49016 .61723 m .48748 .62022 L .48727 .61817 L F
.217 .269 .702 r
.54877 .67423 m .55048 .67303 L .54937 .67058 L F
.884 .94 .571 r
.54914 .67734 m .55048 .67303 L .54877 .67423 L F
.841 .882 .871 r
.59794 .44165 m .59533 .44162 L .59652 .44035 L F
.59794 .44165 m .59652 .4428 L .59533 .44162 L F
.798 .869 .901 r
.60103 .43886 m .59794 .44165 L .59652 .44035 L F
.677 .128 0 r
.68105 .43822 m .68025 .43734 L .67934 .43757 L F
.863 .854 .832 r
.6096 .43139 m .60616 .43318 L .60836 .43008 L F
.362 0 .049 r
.43024 .62923 m .434 .6271 L .43155 .62609 L F
.43024 .62923 m .43155 .62609 L .43231 .62572 L F
.392 .05 .261 r
.52864 .69149 m .52503 .69456 L .52413 .69167 L F
.52864 .69149 m .52654 .69529 L .52503 .69456 L F
.404 .062 .268 r
.52988 .69341 m .52864 .69149 L .53097 .69119 L F
.52988 .69341 m .52654 .69529 L .52864 .69149 L F
.196 .723 .837 r
.19818 .54172 m .20035 .54146 L .20209 .54153 L F
.48 .807 1 r
.20035 .54146 m .20412 .54193 L .20209 .54153 L F
0 0 .015 r
.64294 .42689 m .64258 .4282 L .64222 .43118 L F
.907 .823 .753 r
.66145 .45033 m .66212 .45315 L .66297 .4516 L F
.66145 .45033 m .65975 .45328 L .66212 .45315 L F
.904 .765 .697 r
.65901 .45557 m .66212 .45315 L .65975 .45328 L F
.65901 .45557 m .66066 .45683 L .66212 .45315 L F
.538 .007 0 r
.57487 .63781 m .57728 .63852 L .57357 .63832 L F
.555 .559 .813 r
.5239 .68534 m .52251 .6822 L .52251 .68501 L F
.5239 .68534 m .52494 .68226 L .52251 .6822 L F
.5239 .68534 m .52625 .68516 L .52494 .68226 L F
.782 .338 0 r
.6453 .43065 m .64618 .4325 L .64488 .43093 L F
.252 .419 .834 r
.64536 .43073 m .64488 .43093 L .64584 .43093 L F
.64289 .42966 m .64488 .43093 L .64536 .43073 L F
0 0 0 r
.64189 .43229 m .64347 .43153 L .64488 .43093 L F
.64347 .43153 m .6453 .43065 L .64488 .43093 L F
.937 .819 .702 r
.64739 .45644 m .65053 .4539 L .64984 .45415 L F
.435 .657 .954 r
.65053 .4539 m .65311 .45448 L .65205 .45238 L F
.584 .547 .78 r
.65205 .45238 m .64984 .45415 L .65053 .4539 L F
.856 .914 .871 r
.6612 .41688 m .65811 .41786 L .65966 .41541 L F
.718 .829 .933 r
.66333 .41556 m .6612 .41688 L .65966 .41541 L F
.705 .778 .909 r
.58767 .61498 m .58702 .61272 L .58365 .61419 L F
.804 .817 .861 r
.58767 .61498 m .58869 .61114 L .58702 .61272 L F
.58767 .61498 m .59022 .61236 L .58869 .61114 L F
.697 .68 .829 r
.54423 .66646 m .54656 .66516 L .54723 .66797 L F
0 0 0 r
.54723 .66797 m .54636 .67011 L .54496 .6709 L F
.698 .314 .317 r
.54723 .66797 m .54937 .67058 L .54636 .67011 L F
0 0 0 r
.54723 .66797 m .54636 .67011 L .54496 .6709 L F
.688 .216 .124 r
.46313 .63263 m .46149 .63423 L .45904 .63214 L F
.46 0 0 r
.46519 .63372 m .46149 .63423 L .46313 .63263 L F
.447 0 .085 r
.46313 .63263 m .46566 .63247 L .46519 .63372 L F
.543 .024 0 r
.39636 .63139 m .39561 .62969 L .39391 .62985 L F
.39636 .63139 m .39808 .6303 L .39561 .62969 L F
.485 .204 .412 r
.48525 .62096 m .48483 .62388 L .48223 .62423 L F
.355 .096 .376 r
.48692 .62296 m .48525 .62096 L .48748 .62022 L F
.48692 .62296 m .48483 .62388 L .48525 .62096 L F
.813 .758 .802 r
.55119 .50866 m .55362 .51034 L .55134 .51254 L F
.805 .76 .812 r
.55336 .50858 m .55362 .51034 L .55119 .50866 L F
0 0 0 r
.20427 .65584 m .20178 .65879 L .20307 .65702 L F
.044 .21 .712 r
.50125 .69465 m .50337 .6966 L .50369 .6945 L F
.458 .553 .865 r
.49015 .70419 m .49159 .70696 L .49345 .70528 L F
.319 .32 .703 r
.49345 .70528 m .49159 .70696 L .49369 .70876 L F
.165 .696 .855 r
.42275 .58655 m .42045 .58613 L .41874 .58647 L F
.728 .971 .93 r
.42367 .58468 m .42275 .58655 L .42498 .58575 L F
.42367 .58468 m .42045 .58613 L .42275 .58655 L F
.534 .214 .371 r
.38842 .59965 m .38525 .60275 L .38624 .6013 L F
.38842 .59965 m .38774 .60262 L .38525 .60275 L F
.348 .023 .265 r
.39185 .59746 m .38842 .59965 L .38932 .59899 L F
.39185 .59746 m .39048 .59977 L .38842 .59965 L F
.535 .215 .372 r
.39024 .60219 m .38842 .59965 L .39048 .59977 L F
.39024 .60219 m .38774 .60262 L .38842 .59965 L F
.678 .18 0 r
.55411 .51562 m .55332 .5151 L .55134 .51254 L F
.642 .361 .476 r
.55411 .51562 m .55394 .5178 L .55332 .5151 L F
.55411 .51562 m .55637 .51778 L .55394 .5178 L F
.988 .725 .42 r
.65956 .43855 m .66068 .44132 L .66103 .43977 L F
.429 0 0 r
.40161 .63018 m .39808 .6303 L .39975 .63118 L F
.263 0 0 r
.39975 .63118 m .40408 .63049 L .40161 .63018 L F
.378 .794 .977 r
.25977 .5588 m .25582 .55848 L .25779 .55917 L F
.25977 .5588 m .25582 .55848 L .25779 .55917 L F
.821 .685 .713 r
.64811 .44468 m .64553 .44735 L .64428 .4447 L F
.573 .532 .771 r
.7224 .43543 m .72093 .43746 L .71936 .43256 L F
.266 0 0 r
.40655 .63917 m .40492 .64009 L .40242 .64023 L F
.203 0 0 r
.40894 .63919 m .40492 .64009 L .40655 .63917 L F
.541 .887 .983 r
.57449 .60958 m .57588 .60822 L .57334 .60908 L F
.489 .801 1 r
.57449 .60958 m .57694 .60876 L .57588 .60822 L F
.682 .469 .591 r
.57074 .50627 m .56718 .50915 L .56744 .50692 L F
0 0 0 r
.20178 .65879 m .19912 .66148 L .20058 .65994 L F
.255 0 0 r
.61722 .48318 m .61861 .4842 L .61611 .4846 L F
.61722 .48318 m .61962 .48266 L .61861 .4842 L F
.592 .198 .264 r
.67776 .42454 m .67445 .42666 L .67416 .424 L F
.67776 .42454 m .6767 .42658 L .67445 .42666 L F
.689 .903 .972 r
.67776 .42454 m .68154 .42318 L .68016 .42334 L F
.642 .251 .289 r
.68026 .42617 m .67776 .42454 L .68016 .42334 L F
.68026 .42617 m .6767 .42658 L .67776 .42454 L F
.724 .817 .923 r
.64362 .46569 m .64716 .46588 L .64558 .46461 L F
0 0 .097 r
.5788 .62879 m .57887 .63002 L .57875 .62708 L F
0 .193 .708 r
.57875 .62708 m .58073 .6292 L .57947 .62584 L F
.406 .291 .609 r
.57887 .63002 m .58073 .6292 L .57875 .62708 L F
.855 .937 .876 r
.59652 .4428 m .59298 .44459 L .59533 .44162 L F
.363 .157 .462 r
.34923 .60085 m .35117 .60039 L .35153 .59759 L F
.497 .411 .689 r
.34955 .6034 m .35117 .60039 L .34923 .60085 L F
.7 .72 .865 r
.46285 .57312 m .45981 .57443 L .45807 .57289 L F
.455 .031 .143 r
.58197 .61538 m .58073 .61735 L .57818 .61751 L F
.726 .49 .57 r
.58365 .61419 m .58073 .61735 L .58197 .61538 L F
.305 .501 .884 r
.35515 .61812 m .35176 .61526 L .35316 .61839 L F
.501 .311 .555 r
.35316 .61839 m .35318 .62083 L .35515 .61812 L F
.566 .417 .638 r
.69023 .44158 m .6925 .43854 L .6902 .43922 L F
.563 .814 .992 r
.49417 .73551 m .49819 .73627 L .49677 .73503 L F
.561 .813 .992 r
.49819 .73627 m .50037 .73548 L .49677 .73503 L F
.554 .297 .48 r
.576 .63229 m .57887 .63002 L .5788 .62879 L F
.631 .445 .612 r
.67521 .41283 m .67542 .41534 L .67279 .41542 L F
.67521 .41283 m .67542 .41534 L .67279 .41542 L F
.511 .384 .643 r
.67736 .41166 m .6782 .41435 L .67521 .41283 L F
.53 .37 .608 r
.67521 .41283 m .6782 .41435 L .67542 .41534 L F
.182 .011 .4 r
.21675 .58012 m .21968 .57849 L .21991 .57617 L F
.261 .147 .529 r
.21805 .58143 m .21968 .57849 L .21675 .58012 L F
0 0 0 r
.20661 .65285 m .20427 .65584 L .20535 .65396 L F
.522 .353 .593 r
.5202 .68563 m .52251 .6822 L .52012 .68288 L F
.064 0 0 r
.47465 .6292 m .4762 .62921 L .47395 .62993 L F
.47465 .6292 m .47765 .62771 L .4762 .62921 L F
.548 .63 .885 r
.69456 .40876 m .69352 .41207 L .69207 .40932 L F
.69456 .40876 m .69592 .41168 L .69352 .41207 L F
.314 0 .091 r
.54496 .6709 m .54391 .67293 L .5416 .67341 L F
.516 .284 .502 r
.54636 .67011 m .54391 .67293 L .54496 .6709 L F
.624 .423 .589 r
.42981 .58011 m .42771 .58285 L .42738 .5801 L F
.174 .699 .868 r
.36543 .63282 m .36406 .63256 L .36182 .63265 L F
.961 .68 .457 r
.36406 .63256 m .36235 .63125 L .36182 .63265 L F
.36406 .63256 m .36244 .63374 L .36239 .63226 L F
.36406 .63256 m .36239 .63226 L .36235 .63125 L F
.174 .699 .868 r
.36557 .63282 m .36406 .63256 L .36543 .63282 L F
.903 .913 .818 r
.36642 .62918 m .36557 .63282 L .36777 .63213 L F
.36642 .62918 m .36406 .63256 L .36557 .63282 L F
.494 .054 .132 r
.46624 .63206 m .46865 .63222 L .46566 .63247 L F
.178 0 0 r
.39236 .58217 m .39594 .58025 L .3938 .58064 L F
.57 .631 .872 r
.20142 .61525 m .20315 .61868 L .20516 .6177 L F
.587 .731 .943 r
.67634 .40397 m .67298 .40286 L .67521 .40269 L F
.537 .78 .988 r
.67873 .40343 m .67634 .40397 L .67521 .40269 L F
.646 .418 .558 r
.57537 .50383 m .57544 .50599 L .57307 .50646 L F
.706 .514 .628 r
.57908 .50392 m .57544 .50599 L .57537 .50383 L F
.391 .124 .384 r
.38371 .60383 m .38306 .60584 L .38106 .60604 L F
.482 .398 .684 r
.3838 .60869 m .38106 .60604 L .38306 .60584 L F
.3838 .60869 m .38133 .60954 L .38106 .60604 L F
.871 .906 .853 r
.61642 .42389 m .61382 .4243 L .61517 .4229 L F
.614 .796 .969 r
.61819 .4216 m .61642 .42389 L .61517 .4229 L F
.981 .909 .649 r
.64274 .42562 m .64431 .42492 L .64294 .42689 L F
.51 .895 .727 r
.64632 .42353 m .64431 .42492 L .64274 .42562 L F
0 0 0 r
.4762 .62921 m .47765 .62771 L .4797 .6267 L F
.453 .276 .549 r
.24243 .59391 m .24045 .59186 L .2423 .59124 L F
.24243 .59391 m .2403 .59457 L .24045 .59186 L F
.174 .421 .858 r
.37537 .63548 m .37613 .63422 L .37313 .63322 L F
.37537 .63548 m .37662 .63576 L .37613 .63422 L F
.813 .758 .802 r
.55119 .50866 m .55134 .51254 L .54938 .51179 L F
.496 .313 .562 r
.55134 .51254 m .55052 .51655 L .54938 .51179 L F
.55134 .51254 m .55332 .5151 L .55052 .51655 L F
.987 .779 .383 r
.67025 .44227 m .66941 .44339 L .66907 .44101 L F
.67025 .44227 m .67014 .44468 L .66941 .44339 L F
0 0 .111 r
.52413 .69167 m .52625 .69049 L .52694 .68822 L F
.432 .235 .512 r
.52424 .69179 m .52625 .69049 L .52413 .69167 L F
.089 0 0 r
.68664 .46537 m .68599 .46604 L .68289 .46654 L F
.35 .822 .774 r
.68916 .46438 m .68795 .46471 L .68664 .46537 L F
0 0 0 r
.68795 .46471 m .68599 .46604 L .68664 .46537 L F
.64 .378 .506 r
.70858 .43352 m .7061 .4374 L .70804 .43694 L F
.991 .853 .606 r
.70971 .43293 m .70908 .43536 L .71043 .43549 L F
.70954 .43336 m .70908 .43536 L .70971 .43293 L F
.68 .503 .64 r
.70858 .43352 m .70908 .43536 L .70967 .43277 L F
.64 .378 .506 r
.70858 .43352 m .70973 .43654 L .70908 .43536 L F
.709 .43463 m .70804 .43694 L .70973 .43654 L F
.70858 .43352 m .70804 .43694 L .709 .43463 L F
.991 .853 .606 r
.70967 .43277 m .70954 .43336 L .70971 .43293 L F
.907 .976 .795 r
.71043 .43549 m .71173 .43164 L .70967 .43277 L F
0 .278 .78 r
.38572 .62226 m .38529 .62357 L .38416 .62177 L F
.38572 .62226 m .38635 .62394 L .38529 .62357 L F
.309 0 0 r
.21047 .55385 m .20887 .55391 L .2067 .55346 L F
0 .453 .797 r
.21047 .55385 m .21091 .55364 L .20887 .55391 L F
.21047 .55385 m .21261 .55446 L .21091 .55364 L F
.055 0 0 r
.17037 .54405 m .17225 .54384 L .1745 .54296 L F
.269 0 0 r
.1745 .54296 m .17225 .54384 L .17583 .5434 L F
.577 .899 .984 r
.23683 .81767 m .23488 .81853 L .23314 .81791 L F
.411 .626 .941 r
.23364 .5438 m .2332 .5457 L .23163 .54438 L F
.23364 .5438 m .23588 .5461 L .2332 .5457 L F
0 0 0 r
.20898 .64994 m .20661 .65285 L .20777 .65107 L F
.491 0 0 r
.54827 .63256 m .5518 .63241 L .55105 .63356 L F
.511 .672 .937 r
.55059 .63058 m .55448 .63212 L .5518 .63241 L F
.357 0 0 r
.46097 .57917 m .4598 .5795 L .45752 .57909 L F
.563 .007 0 r
.46221 .57832 m .46294 .57934 L .46225 .57879 L F
.431 .867 .781 r
.46221 .57832 m .46097 .57917 L .46217 .57795 L F
.46221 .57832 m .4598 .5795 L .46097 .57917 L F
.658 .726 .9 r
.45869 .5776 m .4598 .5795 L .46221 .57832 L F
.563 .007 0 r
.46221 .57832 m .46225 .57879 L .46071 .57756 L F
.431 .867 .781 r
.46221 .57832 m .46217 .57795 L .46306 .57705 L F
.391 .734 .991 r
.44787 .56821 m .44617 .56915 L .44509 .56868 L F
.44787 .56821 m .44796 .56911 L .44617 .56915 L F
0 .278 .78 r
.38572 .62226 m .38416 .62177 L .38548 .62009 L F
.488 .298 .55 r
.68281 .4331 m .68521 .43302 L .6851 .43026 L F
.978 .762 .543 r
.68281 .4331 m .68664 .43656 L .68521 .43302 L F
.806 .696 .744 r
.56072 .49195 m .55732 .49155 L .55943 .48851 L F
.805 .699 .747 r
.56072 .49195 m .55857 .49498 L .55732 .49155 L F
.253 .728 .938 r
.20412 .54193 m .20613 .54183 L .20794 .54239 L F
.2 .694 .92 r
.20613 .54183 m .21012 .54244 L .20794 .54239 L F
.49 0 0 r
.50813 .70068 m .50705 .69986 L .50502 .69809 L F
.955 .637 .22 r
.50813 .70068 m .50838 .7029 L .50705 .69986 L F
.433 .225 .495 r
.51069 .69988 m .50838 .7029 L .50813 .70068 L F
.884 .94 .571 r
.54914 .67734 m .54936 .67508 L .55048 .67303 L F
.882 .99 .741 r
.54766 .67782 m .54914 .67734 L .54876 .67901 L F
.54766 .67782 m .54936 .67508 L .54914 .67734 L F
.367 .12 .401 r
.22246 .63154 m .22098 .62997 L .22286 .62932 L F
.22246 .63154 m .22043 .63221 L .22098 .62997 L F
0 0 0 r
.21155 .64713 m .20898 .64994 L .21024 .64824 L F
.385 0 0 r
.68454 .45965 m .68813 .45957 L .68556 .46024 L F
.828 .773 .8 r
.72853 .43312 m .72522 .43273 L .72748 .4298 L F
.782 .829 .889 r
.72853 .43312 m .72622 .4341 L .72522 .43273 L F
.627 .661 .863 r
.7314 .43227 m .72853 .43312 L .72748 .4298 L F
.269 .109 .471 r
.24977 .57056 m .24803 .57387 L .24798 .57136 L F
0 0 0 r
.61815 .45979 m .61492 .46263 L .6182 .46155 L F
.389 .21 .514 r
.61978 .45687 m .61815 .45979 L .61993 .45945 L F
.686 .53 .67 r
.6182 .46155 m .61993 .45945 L .61815 .45979 L F
.709 .574 .701 r
.71763 .42724 m .71877 .43041 L .71521 .43035 L F
.657 .595 .774 r
.71998 .42392 m .71763 .42724 L .71752 .42464 L F
.71998 .42392 m .7211 .42739 L .71763 .42724 L F
.663 .55 .716 r
.7211 .42739 m .71877 .43041 L .71763 .42724 L F
.377 0 0 r
.42172 .62877 m .42415 .62896 L .42562 .62815 L F
.485 0 0 r
.42562 .62815 m .42415 .62896 L .42788 .62889 L F
.604 .518 .731 r
.68895 .44804 m .69143 .44533 L .6882 .44583 L F
.68895 .44804 m .69161 .44825 L .69143 .44533 L F
.319 .213 .573 r
.68895 .44804 m .69115 .44838 L .69161 .44825 L F
.727 .892 .955 r
.69115 .44838 m .68895 .44804 L .68811 .44685 L F
.319 .213 .573 r
.68895 .44804 m .68927 .4503 L .69115 .44838 L F
.727 .892 .955 r
.69115 .44838 m .68794 .44924 L .68895 .44804 L F
.784 .862 .907 r
.55013 .68521 m .55386 .68502 L .55296 .68374 L F
.821 .807 .837 r
.5513 .68718 m .55386 .68502 L .55013 .68521 L F
.964 .864 .692 r
.55296 .68374 m .55386 .68502 L .55432 .68311 L F
.587 .305 .457 r
.63679 .43382 m .63988 .43332 L .6388 .43421 L F
.396 .625 .945 r
.63679 .43382 m .6388 .43421 L .6385 .43308 L F
.822 .815 .844 r
.33151 .80543 m .32922 .80628 L .3312 .80355 L F
.53 .122 .213 r
.33151 .80543 m .33206 .80665 L .32922 .80628 L F
.283 .419 .823 r
.3312 .80355 m .33397 .80547 L .33151 .80543 L F
.286 .016 .317 r
.33151 .80543 m .33397 .80547 L .33206 .80665 L F
.777 .522 .55 r
.49677 .73503 m .50037 .73548 L .50039 .7328 L F
.674 .683 .851 r
.46577 .57427 m .46285 .57312 L .46476 .57287 L F
.513 .266 .477 r
.4654 .57651 m .46306 .57705 L .46577 .57427 L F
.497 .514 .805 r
.46648 .57346 m .46577 .57427 L .46476 .57287 L F
.46648 .57346 m .4654 .57651 L .46577 .57427 L F
.563 .437 .666 r
.69987 .45665 m .70021 .45952 L .69767 .46005 L F
.467 .17 .378 r
.70021 .45952 m .69741 .46176 L .69767 .46005 L F
.717 .346 .346 r
.43795 .629 m .43973 .63005 L .44124 .62894 L F
.534 .099 .161 r
.44124 .62894 m .44208 .63127 L .44355 .62938 L F
.44124 .62894 m .43973 .63005 L .44208 .63127 L F
.522 .261 .461 r
.60637 .48894 m .60801 .49037 L .60627 .49106 L F
.60637 .48894 m .60858 .48856 L .60801 .49037 L F
.916 .817 .734 r
.57926 .60856 m .5804 .6116 L .57733 .61107 L F
.57926 .60856 m .58081 .60967 L .5804 .6116 L F
.9 .73 .662 r
.57733 .61107 m .5804 .6116 L .57907 .61516 L F
.443 .813 .994 r
.21765 .56219 m .21598 .56141 L .21547 .56256 L F
.21765 .56219 m .21598 .56141 L .21547 .56256 L F
.629 .794 .962 r
.43448 .57123 m .43072 .57064 L .43293 .56978 L F
.711 .27 .201 r
.43293 .56978 m .43687 .57075 L .43448 .57123 L F
.578 .741 .953 r
.36777 .63213 m .37152 .63303 L .36961 .63047 L F
.429 .619 .931 r
.36961 .63047 m .37152 .63303 L .37264 .63138 L F
.288 .425 .826 r
.37152 .63303 m .37313 .63322 L .37264 .63138 L F
.696 .564 .702 r
.71521 .43035 m .7164 .43352 L .7129 .43341 L F
.436 .268 .554 r
.38536 .60954 m .38133 .60954 L .3838 .60869 L F
.38536 .60954 m .38132 .61151 L .38133 .60954 L F
.79 .528 .542 r
.57576 .60517 m .58017 .60636 L .57929 .60359 L F
.613 .692 .899 r
.38452 .6177 m .37956 .61582 L .38186 .61586 L F
0 .021 .595 r
.38448 .61627 m .38452 .6177 L .38186 .61586 L F
.38448 .61627 m .38491 .61785 L .38452 .6177 L F
.466 .181 .397 r
.20876 .60347 m .21103 .60302 L .21157 .60097 L F
.417 .193 .464 r
.21157 .60097 m .21393 .60034 L .2142 .59769 L F
.233 0 .304 r
.21157 .60097 m .21273 .60215 L .21393 .60034 L F
.21157 .60097 m .21103 .60302 L .21273 .60215 L F
.518 .859 .994 r
.62868 .45955 m .62678 .45954 L .62927 .45875 L F
0 0 0 r
.62927 .45875 m .62536 .46025 L .62799 .45973 L F
.613 .9 .606 r
.62975 .4581 m .62927 .45875 L .62799 .45973 L F
.63087 .45706 m .62927 .45875 L .62975 .4581 L F
.518 .859 .994 r
.63012 .45956 m .62868 .45955 L .62927 .45875 L F
.609 .329 .467 r
.7189 .44504 m .71864 .44682 L .7157 .44725 L F
.563 .382 .594 r
.72128 .44211 m .7189 .44504 L .71807 .44141 L F
.72128 .44211 m .72146 .44457 L .7189 .44504 L F
.48 .164 .352 r
.7189 .44504 m .72114 .44617 L .71864 .44682 L F
.7189 .44504 m .72146 .44457 L .72114 .44617 L F
.584 .332 .501 r
.19052 .63268 m .19285 .63286 L .19352 .63001 L F
.667 .412 .526 r
.19352 .63001 m .19285 .63286 L .19479 .63163 L F
.577 .398 .603 r
.19352 .63001 m .19479 .63163 L .19617 .6298 L F
.709 .571 .697 r
.71877 .43041 m .7164 .43352 L .71521 .43035 L F
.654 .494 .654 r
.71936 .43256 m .7164 .43352 L .71877 .43041 L F
.626 .498 .687 r
.7211 .42739 m .72176 .43077 L .71877 .43041 L F
.628 .373 .512 r
.72176 .43077 m .72371 .43234 L .71877 .43041 L F
.585 .452 .666 r
.71877 .43041 m .72371 .43234 L .71936 .43256 L F
.464 0 .023 r
.42092 .63619 m .41934 .63777 L .41707 .63761 L F
.487 .006 .039 r
.42305 .6373 m .41934 .63777 L .42092 .63619 L F
.464 .07 .207 r
.42336 .63595 m .42305 .6373 L .42092 .63619 L F
.555 .572 .826 r
.6278 .41185 m .62955 .41474 L .62649 .41535 L F
.378 .019 .224 r
.62649 .41535 m .62955 .41474 L .6285 .41672 L F
.336 .161 .49 r
.22966 .61763 m .2275 .62069 L .22766 .61846 L F
.964 .864 .692 r
.55296 .68374 m .55432 .68311 L .55375 .68159 L F
.615 .128 .075 r
.70973 .43654 m .71203 .43715 L .7109 .43476 L F
.479 .433 .728 r
.7109 .43476 m .7145 .43128 L .71173 .43164 L F
.7109 .43476 m .71709 .43491 L .7145 .43128 L F
.693 .522 .652 r
.71203 .43715 m .71709 .43491 L .7109 .43476 L F
.65 .271 .313 r
.44491 .63296 m .44382 .63521 L .44116 .63451 L F
.382 0 .183 r
.4459 .63477 m .44491 .63296 L .44723 .6325 L F
.4459 .63477 m .44382 .63521 L .44491 .63296 L F
.722 .705 .833 r
.61605 .45253 m .61689 .45393 L .61338 .45393 L F
.522 .019 .002 r
.61338 .45393 m .61689 .45393 L .61572 .45516 L F
.297 .486 .875 r
.61759 .45175 m .61689 .45393 L .61605 .45253 L F
.801 .925 .547 r
.61572 .45516 m .61689 .45393 L .61759 .45175 L F
.572 .292 .453 r
.59204 .49708 m .59216 .49497 L .59462 .49675 L F
.572 .292 .452 r
.59216 .49497 m .59464 .49477 L .59462 .49675 L F
.421 .463 .799 r
.2142 .59769 m .21581 .59709 L .2144 .59414 L F
0 0 0 r
.2142 .59769 m .21426 .59855 L .21581 .59709 L F
.2142 .59769 m .21393 .60034 L .21426 .59855 L F
.546 .519 .777 r
.681 .41297 m .682 .41557 L .68414 .4142 L F
.856 .434 0 r
.68327 .41758 m .68376 .41709 L .68306 .41637 L F
.991 .753 .474 r
.68294 .4166 m .68306 .41636 L .682 .41557 L F
.68294 .4166 m .68376 .41709 L .68414 .4142 L F
.991 .759 .484 r
.6824 .4157 m .68376 .41709 L .68294 .4166 L F
.856 .434 0 r
.68307 .41714 m .68306 .41637 L .6824 .4157 L F
.68327 .41758 m .68306 .41637 L .68307 .41714 L F
.991 .753 .474 r
.68306 .41636 m .68414 .4142 L .68303 .41491 L F
.68306 .41636 m .68303 .41491 L .682 .41557 L F
.459 .027 .129 r
.36112 .59102 m .36372 .59086 L .36495 .58914 L F
.268 0 0 r
.36372 .59086 m .36719 .58898 L .36495 .58914 L F
.448 .252 .52 r
.52826 .71962 m .53041 .71796 L .53033 .71601 L F
0 .222 .74 r
.68079 .45903 m .67994 .45969 L .67845 .45871 L F
.68079 .45903 m .68103 .46031 L .67994 .45969 L F
.885 .861 .812 r
.54829 .68828 m .5513 .68718 L .55013 .68521 L F
.54829 .68828 m .54972 .68927 L .5513 .68718 L F
.892 .776 .727 r
.67542 .41534 m .67205 .41692 L .67279 .41542 L F
0 0 0 r
.39985 .59461 m .39698 .59676 L .39627 .59705 L F
.535 .331 .549 r
.40242 .59183 m .40223 .59436 L .39985 .59461 L F
0 0 .161 r
.40298 .59274 m .40223 .59436 L .40242 .59183 L F
.563 .343 .539 r
.40298 .59274 m .40112 .59412 L .40116 .59419 L F
0 0 0 r
.40116 .59419 m .39985 .59461 L .40132 .59445 L F
.40116 .59419 m .39698 .59676 L .39985 .59461 L F
.563 .343 .539 r
.40112 .59412 m .40012 .59485 L .40116 .59419 L F
0 0 0 r
.40116 .59419 m .40132 .59445 L .40223 .59436 L F
.057 .207 .704 r
.50502 .69809 m .50546 .69663 L .50337 .6966 L F
.50502 .69809 m .50705 .69986 L .50546 .69663 L F
.401 .138 .396 r
.55967 .51721 m .55981 .51543 L .56228 .51477 L F
.828 .452 .341 r
.49475 .7027 m .4963 .70157 L .49289 .69993 L F
.709 .273 .213 r
.4972 .70262 m .4963 .70157 L .49475 .7027 L F
.461 .24 .492 r
.35153 .59759 m .35335 .5998 L .35364 .59703 L F
.35153 .59759 m .35117 .60039 L .35335 .5998 L F
.412 .554 .887 r
.48946 .61417 m .49143 .61417 L .48965 .6152 L F
.606 .586 .804 r
.49143 .61417 m .49016 .61723 L .48965 .6152 L F
0 0 .143 r
.21356 .64393 m .21155 .64713 L .21237 .6449 L F
.782 .687 .76 r
.19617 .6298 m .19719 .63292 L .19479 .63163 L F
.19617 .6298 m .19719 .63292 L .19479 .63163 L F
.9 .541 .353 r
.54662 .65509 m .54786 .65324 L .54641 .65262 L F
.54662 .65509 m .54958 .65678 L .54786 .65324 L F
0 0 0 r
.68154 .42318 m .6836 .42237 L .68016 .42334 L F
.685 .634 .792 r
.72026 .43852 m .72128 .44211 L .71807 .44141 L F
.569 .428 .65 r
.72379 .43862 m .72128 .44211 L .72026 .43852 L F
.72379 .43862 m .72382 .44155 L .72128 .44211 L F
.553 .375 .594 r
.72382 .44155 m .72146 .44457 L .72128 .44211 L F
0 0 .161 r
.40298 .59274 m .40242 .59183 L .40442 .59086 L F
.111 .642 .869 r
.62057 .45393 m .62137 .45405 L .62144 .45419 L F
.08 0 .126 r
.62318 .45304 m .62171 .45469 L .62144 .45419 L F
.509 0 0 r
.62418 .45449 m .62318 .45304 L .62144 .45419 L F
.111 .642 .869 r
.62137 .45405 m .62418 .45449 L .62144 .45419 L F
.08 0 .126 r
.62171 .45469 m .61978 .45687 L .62144 .45419 L F
0 0 .209 r
.61978 .45687 m .62018 .45774 L .62144 .45419 L F
.61978 .45687 m .61993 .45945 L .62018 .45774 L F
.792 .64 .693 r
.55592 .5003 m .55764 .5039 L .55398 .50339 L F
.785 .672 .739 r
.55764 .5039 m .55562 .50692 L .55398 .50339 L F
.733 .617 .728 r
.55983 .50088 m .55764 .5039 L .55592 .5003 L F
.802 .737 .792 r
.55052 .51655 m .55125 .51828 L .54936 .51745 L F
.856 .48 .334 r
.54936 .51745 m .55125 .51828 L .55034 .51999 L F
.628 .601 .804 r
.55052 .51655 m .55394 .5178 L .55125 .51828 L F
.518 .295 .515 r
.55125 .51828 m .55375 .52022 L .55034 .51999 L F
.55125 .51828 m .55394 .5178 L .55375 .52022 L F
.849 .754 .758 r
.62234 .41197 m .62269 .4163 L .61992 .41502 L F
.848 .391 .101 r
.62269 .4163 m .62204 .41707 L .61992 .41502 L F
.62269 .4163 m .62397 .41837 L .62204 .41707 L F
.704 .782 .299 r
.21989 .55676 m .21867 .55994 L .21908 .5587 L F
.969 .671 .271 r
.73794 .42366 m .7388 .42544 L .73559 .42638 L F
.73794 .42366 m .73932 .42663 L .7388 .42544 L F
.6 .666 .886 r
.74045 .42287 m .73932 .42663 L .73794 .42366 L F
.74045 .42287 m .74186 .42605 L .73932 .42663 L F
.437 .743 .992 r
.67368 .46443 m .67494 .46526 L .67607 .46425 L F
.371 .628 .953 r
.67494 .46526 m .67724 .46602 L .67607 .46425 L F
.157 0 0 r
.41231 .6293 m .41458 .62883 L .41609 .62751 L F
.618 .137 .09 r
.41609 .62751 m .41458 .62883 L .41813 .62902 L F
.509 0 0 r
.62418 .45449 m .62527 .45372 L .62318 .45304 L F
.791 .575 .608 r
.55659 .49805 m .55983 .50088 L .55592 .5003 L F
.878 .763 .731 r
.67968 .44483 m .67889 .4418 L .67813 .44414 L F
.533 0 0 r
.68123 .44634 m .67968 .44483 L .67813 .44414 L F
.69 .58 .727 r
.62336 .44165 m .62664 .44235 L .62552 .43902 L F
.216 .727 .889 r
.21012 .54244 m .21215 .54217 L .21401 .54256 L F
.22 .735 .871 r
.21215 .54217 m .21605 .54221 L .21401 .54256 L F
.741 .719 .831 r
.72026 .43852 m .71807 .44141 L .71662 .43813 L F
.457 .11 .288 r
.47484 .62111 m .4775 .62065 L .47836 .61815 L F
.342 .005 .241 r
.47836 .61815 m .4798 .61985 L .48083 .61805 L F
.47836 .61815 m .4775 .62065 L .4798 .61985 L F
.411 0 0 r
.35472 .62524 m .35504 .62589 L .35305 .62369 L F
.35472 .62524 m .35601 .62617 L .35504 .62589 L F
.695 .423 .508 r
.7079 .45288 m .70512 .45115 L .70713 .45008 L F
.7079 .45288 m .70473 .45301 L .70512 .45115 L F
.62 .613 .821 r
.69031 .45347 m .69115 .44838 L .68927 .4503 L F
.688 .9 .972 r
.43072 .57064 m .42844 .57181 L .42721 .571 L F
.675 .483 .618 r
.68709 .42943 m .68882 .43102 L .6851 .43026 L F
.518 .481 .754 r
.69006 .42896 m .68882 .43102 L .68709 .42943 L F
.695 .612 .76 r
.68715 .4304 m .69006 .42896 L .68709 .42943 L F
.607 .631 .848 r
.68715 .4304 m .68882 .43102 L .68852 .4305 L F
.6867 .43059 m .68882 .43102 L .68715 .4304 L F
.695 .612 .76 r
.68821 .42998 m .69006 .42896 L .68715 .4304 L F
.648 .649 .837 r
.68821 .42998 m .68882 .43102 L .69006 .42896 L F
.695 .612 .76 r
.68959 .42942 m .69006 .42896 L .68821 .42998 L F
.648 .649 .837 r
.68634 .4268 m .68821 .42998 L .69006 .42896 L F
.635 .395 .538 r
.6851 .43026 m .68715 .4304 L .68709 .42943 L F
.607 .631 .848 r
.6851 .43026 m .68852 .4305 L .68634 .4268 L F
.695 .612 .76 r
.68721 .43173 m .68959 .42942 L .68715 .4304 L F
.607 .631 .848 r
.6851 .43026 m .6867 .43059 L .68715 .4304 L F
.635 .395 .538 r
.6851 .43026 m .68721 .43173 L .68715 .4304 L F
.703 .895 .523 r
.58153 .60824 m .58309 .60635 L .58081 .60967 L F
.644 .232 .248 r
.58153 .60824 m .58548 .60824 L .58309 .60635 L F
.624 .733 .925 r
.63399 .46487 m .63147 .46581 L .63048 .4637 L F
.745 .945 .947 r
.6397 .46802 m .64063 .46795 L .6398 .46703 L F
.77 .953 .933 r
.6398 .46703 m .64063 .46795 L .64362 .46569 L F
.849 .768 .773 r
.20089 .62157 m .19649 .62318 L .19867 .62082 L F
.20089 .62157 m .19751 .62461 L .19649 .62318 L F
.138 0 0 r
.19867 .62082 m .20258 .62027 L .20089 .62157 L F
.791 .4 0 r
.65617 .42927 m .65789 .43256 L .65712 .43067 L F
.277 .542 .92 r
.54593 .61802 m .54922 .6188 L .54683 .61689 L F
.621 .509 .706 r
.6882 .44583 m .69143 .44533 L .69023 .44158 L F
.66 .426 .555 r
.58625 .49785 m .58626 .5002 L .58382 .50036 L F
.639 .439 .596 r
.58873 .49747 m .58626 .5002 L .58625 .49785 L F
.373 .203 .517 r
.23369 .6063 m .23344 .60881 L .2317 .60941 L F
.387 .236 .551 r
.23344 .60881 m .23336 .61141 L .2317 .60941 L F
.233 .201 .616 r
.23336 .61141 m .23229 .61223 L .2317 .60941 L F
0 0 0 r
.67499 .41916 m .67525 .41956 L .67549 .41993 L F
.779 .854 .907 r
.43806 .57711 m .43784 .5787 L .44146 .57675 L F
0 0 .248 r
.65317 .42278 m .65336 .42392 L .6526 .42142 L F
.728 .305 0 r
.66156 .42486 m .66146 .42523 L .66028 .42376 L F
.66156 .42486 m .66243 .42654 L .66146 .42523 L F
.586 .749 .955 r
.47549 .72235 m .47696 .72394 L .47373 .72423 L F
.995 .792 .521 r
.47696 .72394 m .47629 .72614 L .47373 .72423 L F
.324 .331 .713 r
.47549 .72235 m .47373 .72423 L .47629 .72614 L F
.302 .785 .708 r
.18023 .5421 m .1803 .54195 L .18244 .54211 L F
.269 0 0 r
.53869 .67843 m .54276 .67841 L .54272 .67811 L F
.305 0 0 r
.54276 .67841 m .54529 .67871 L .54272 .67811 L F
.453 .115 .301 r
.55937 .63022 m .56406 .63031 L .56253 .62861 L F
.562 .346 .544 r
.53346 .68868 m .53336 .69076 L .53097 .69119 L F
.417 .227 .513 r
.53346 .68868 m .53535 .69042 L .53336 .69076 L F
.516 .78 .992 r
.58153 .60824 m .58081 .60967 L .57926 .60856 L F
.633 .508 .693 r
.56718 .50915 m .56471 .5123 L .56469 .50956 L F
.619 .533 .735 r
.22534 .56832 m .22731 .56477 L .2251 .56531 L F
.656 .586 .764 r
.67416 .424 m .67171 .42454 L .67057 .4212 L F
.482 .336 .605 r
.24427 .58812 m .2423 .59124 L .24271 .58884 L F
.297 .514 .896 r
.49229 .69053 m .49124 .69187 L .49362 .69257 L F
.456 .299 .579 r
.24803 .57387 m .24804 .5763 L .24602 .57674 L F
.439 .357 .667 r
.2484 .5788 m .24602 .57674 L .24804 .5763 L F
.2484 .5788 m .24627 .58044 L .24602 .57674 L F
.787 .845 .895 r
.72622 .4341 m .7224 .43543 L .72522 .43273 L F
.427 .867 .901 r
.67505 .45231 m .67695 .45241 L .67909 .45131 L F
.607 .631 .848 r
.6851 .43026 m .68634 .4268 L .68354 .42597 L F
.623 .402 .561 r
.6851 .43026 m .68521 .43302 L .68721 .43173 L F
0 0 0 r
.58533 .62373 m .58895 .622 L .58545 .62074 L F
.059 .319 .802 r
.58975 .62657 m .58989 .62562 L .58898 .62472 L F
.58906 .62557 m .58898 .62472 L .58735 .6231 L F
.58975 .62657 m .58898 .62472 L .58906 .62557 L F
0 0 0 r
.58714 .62286 m .58735 .6231 L .58895 .622 L F
0 .434 .836 r
.58672 .62024 m .58928 .62152 L .58735 .6231 L F
.58672 .62024 m .58912 .62119 L .58928 .62152 L F
.993 .753 .451 r
.58883 .62316 m .58928 .62152 L .58912 .62119 L F
.58864 .62447 m .58886 .62345 L .58883 .62316 L F
.58886 .62345 m .58928 .62152 L .58883 .62316 L F
.534 .024 0 r
.58735 .6231 m .58864 .62447 L .58753 .62331 L F
0 0 0 r
.58533 .62373 m .58735 .6231 L .58714 .62286 L F
.394 .427 .776 r
.58672 .62024 m .58735 .6231 L .58533 .62373 L F
0 0 0 r
.58667 .6224 m .58533 .62373 L .58735 .6231 L F
.534 .024 0 r
.58735 .6231 m .58753 .62331 L .58667 .6224 L F
0 .252 .729 r
.58928 .62152 m .58895 .622 L .58735 .6231 L F
.569 .6 .845 r
.6908 .418 m .69237 .42169 L .69438 .42051 L F
.52 .917 .841 r
.69438 .42051 m .69237 .42169 L .69114 .42179 L F
.713 .629 .761 r
.44095 .57191 m .43808 .57416 L .43687 .57075 L F
.991 .736 .42 r
.55539 .67286 m .5562 .67115 L .55544 .66996 L F
.55539 .67286 m .55634 .67368 L .5562 .67115 L F
.767 .681 .767 r
.55732 .49155 m .55857 .49498 L .55493 .49447 L F
.774 .659 .736 r
.55857 .49498 m .55659 .49805 L .55493 .49447 L F
.544 .04 0 r
.56373 .63 m .56253 .62861 L .56406 .63031 L F
.56373 .63 m .56514 .63138 L .56253 .62861 L F
.249 .685 .961 r
.22157 .54247 m .22589 .54358 L .22368 .54353 L F
.137 0 .263 r
.38525 .60275 m .38306 .60584 L .38371 .60383 L F
.682 .469 .591 r
.57074 .50627 m .57119 .50884 L .56718 .50915 L F
.716 .545 .656 r
.57307 .50646 m .57119 .50884 L .57074 .50627 L F
.497 0 0 r
.18953 .55306 m .18751 .55357 L .18495 .55315 L F
.34 .131 .443 r
.22504 .62627 m .22286 .62932 L .22316 .62695 L F
0 0 0 r
.62188 .48179 m .6252 .47994 L .62367 .48098 L F
.57 .939 .841 r
.6252 .47994 m .62834 .47825 L .62682 .4785 L F
.505 .865 .626 r
.62367 .48098 m .6252 .47994 L .62682 .4785 L F
.778 .705 .782 r
.62536 .40915 m .62647 .41221 L .62234 .41197 L F
.988 .752 .487 r
.62498 .41127 m .62647 .41221 L .62536 .40915 L F
.279 .708 .968 r
.6278 .41185 m .62647 .41221 L .62498 .41127 L F
.019 .273 .772 r
.55919 .63881 m .56129 .63954 L .5579 .638 L F
.653 .096 0 r
.5631 .64128 m .5616 .64085 L .55919 .63881 L F
.019 .273 .772 r
.55919 .63881 m .5616 .64085 L .56129 .63954 L F
.598 .689 .906 r
.44769 .57701 m .45125 .57824 L .44998 .57651 L F
.553 .688 .929 r
.44998 .57651 m .45125 .57824 L .45344 .57767 L F
.062 0 .393 r
.25255 .56003 m .25103 .55935 L .25216 .55914 L F
.25255 .56003 m .25091 .56176 L .25103 .55935 L F
.779 .854 .907 r
.43806 .57711 m .44146 .57675 L .44036 .57618 L F
.692 .937 .964 r
.44218 .575 m .44146 .57675 L .44389 .57591 L F
.44218 .575 m .44036 .57618 L .44146 .57675 L F
.558 .502 .748 r
.64427 .44014 m .64768 .43912 L .6471 .43897 L F
.359 .034 .272 r
.39273 .59912 m .39185 .59746 L .39382 .59728 L F
.39273 .59912 m .39048 .59977 L .39185 .59746 L F
.623 .662 .867 r
.73342 .43273 m .73216 .43622 L .7314 .43227 L F
.73342 .43273 m .7346 .43566 L .73216 .43622 L F
.65 .266 .304 r
.73216 .43622 m .73485 .43799 L .73234 .43767 L F
.557 .355 .562 r
.7346 .43566 m .73485 .43799 L .73216 .43622 L F
.618 .618 .828 r
.7102 .41941 m .70673 .41819 L .70935 .41762 L F
.626 .614 .819 r
.70814 .4138 m .70673 .41819 L .70557 .41445 L F
.70814 .4138 m .70935 .41762 L .70673 .41819 L F
.506 .778 .993 r
.38251 .64201 m .38321 .6404 L .38109 .6406 L F
.38251 .64201 m .38475 .6416 L .38321 .6404 L F
.625 .648 .852 r
.68362 .40665 m .67873 .40343 L .68108 .40308 L F
.57 .66 .898 r
.68512 .40534 m .68362 .40665 L .68108 .40308 L F
.438 .875 .817 r
.62682 .4785 m .62834 .47825 L .63072 .47716 L F
.941 .715 .569 r
.20211 .61256 m .20142 .61525 L .19962 .61329 L F
0 0 .291 r
.20264 .61074 m .20237 .61261 L .20211 .61256 L F
.732 .99 .871 r
.20211 .61256 m .19962 .61329 L .20264 .61074 L F
.867 .807 .789 r
.61994 .41258 m .61744 .41234 L .61904 .41018 L F
.902 .641 .534 r
.61994 .41258 m .61749 .41396 L .61744 .41234 L F
.61994 .41258 m .61992 .41502 L .61749 .41396 L F
.582 .621 .856 r
.62162 .40931 m .61994 .41258 L .61904 .41018 L F
.62162 .40931 m .62234 .41197 L .61994 .41258 L F
.849 .754 .758 r
.62234 .41197 m .61992 .41502 L .61994 .41258 L F
.364 0 .1 r
.19912 .66148 m .19752 .66328 L .19841 .6622 L F
.19912 .66148 m .19569 .66367 L .19752 .66328 L F
.626 .462 .641 r
.58123 .50092 m .58141 .50341 L .57908 .50392 L F
.559 .392 .611 r
.58382 .50036 m .58141 .50341 L .58123 .50092 L F
.721 .982 .776 r
.61612 .43849 m .61913 .43631 L .61845 .43568 L F
.968 .657 .371 r
.61889 .43225 m .61725 .42905 L .61855 .43203 L F
.991 .877 .546 r
.6174 .43662 m .61845 .43568 L .61889 .43225 L F
.922 .781 .303 r
.61889 .43225 m .61913 .43631 L .61901 .43233 L F
.986 .874 .519 r
.61845 .43568 m .61913 .43631 L .61889 .43225 L F
.991 .877 .546 r
.6174 .43662 m .61889 .43225 L .61908 .43326 L F
.968 .657 .371 r
.61889 .43225 m .61855 .43203 L .61908 .43326 L F
.922 .781 .303 r
.61889 .43225 m .61901 .43233 L .61899 .43173 L F
.59 .523 .748 r
.62552 .43902 m .62664 .44235 L .62856 .44079 L F
.745 .667 .774 r
.68664 .43656 m .68721 .43173 L .68521 .43302 L F
.68664 .43656 m .68848 .43537 L .68721 .43173 L F
.56 .214 .338 r
.51651 .69696 m .51306 .69931 L .51407 .69751 L F
.394 .224 .53 r
.24641 .58227 m .24413 .58562 L .24413 .58315 L F
.898 .483 .18 r
.53084 .67992 m .53167 .68221 L .53301 .68246 L F
.749 .428 .441 r
.53076 .68486 m .53301 .68246 L .53167 .68221 L F
.53076 .68486 m .53433 .68537 L .53301 .68246 L F
.492 .314 .568 r
.53301 .68246 m .53433 .68537 L .53495 .68331 L F
.401 0 .078 r
.69741 .46176 m .69413 .46359 L .69504 .46249 L F
.867 .552 .452 r
.60935 .46791 m .61136 .46842 L .60958 .46804 L F
.806 .648 .687 r
.60623 .46715 m .60958 .46804 L .60882 .46442 L F
.778 .704 .782 r
.60935 .46791 m .60958 .46804 L .60623 .46715 L F
.682 .57 .722 r
.60882 .46442 m .60958 .46804 L .61226 .46452 L F
.676 .647 .813 r
.61136 .46842 m .6118 .4665 L .60958 .46804 L F
.6118 .4665 m .60994 .46757 L .60958 .46804 L F
.61136 .46842 m .61396 .46859 L .61226 .46452 L F
0 .035 .543 r
.61208 .46905 m .61136 .46842 L .60935 .46791 L F
.674 .376 .461 r
.61352 .47054 m .61396 .46859 L .61136 .46842 L F
.298 .523 .902 r
.61147 .46676 m .61208 .46905 L .60935 .46791 L F
.61147 .46676 m .60939 .46788 L .6083 .46856 L F
.60939 .46788 m .60935 .46791 L .60931 .46793 L F
.60939 .46788 m .60931 .46793 L .6083 .46856 L F
.676 .647 .813 r
.6118 .4665 m .61226 .46452 L .60994 .46757 L F
0 .035 .543 r
.61208 .46905 m .61352 .47054 L .61136 .46842 L F
.04 .609 .707 r
.22154 .56198 m .21957 .56208 L .21901 .56211 L F
.506 0 0 r
.22336 .5628 m .21957 .56208 L .22154 .56198 L F
.22336 .5628 m .2217 .56322 L .21957 .56208 L F
.848 .496 .387 r
.2217 .56322 m .22056 .56203 L .21957 .56208 L F
.22056 .56203 m .21864 .56001 L .21957 .56208 L F
.04 .609 .707 r
.21901 .56211 m .21957 .56208 L .21765 .56219 L F
.134 0 0 r
.40408 .63049 m .40597 .6305 L .4074 .62955 L F
.344 0 0 r
.40597 .6305 m .40987 .62955 L .4074 .62955 L F
.489 .163 .34 r
.51946 .69486 m .51901 .69662 L .51651 .69696 L F
.614 .516 .72 r
.51946 .69486 m .52147 .69228 L .5185 .69271 L F
.51946 .69486 m .52204 .69452 L .52147 .69228 L F
.545 .258 .431 r
.51946 .69486 m .52154 .69683 L .51901 .69662 L F
.51946 .69486 m .52204 .69452 L .52154 .69683 L F
.786 .672 .738 r
.55398 .50339 m .55562 .50692 L .55201 .50647 L F
.784 .68 .75 r
.55201 .50647 m .55562 .50692 L .55336 .50858 L F
0 0 0 r
.6951 .4481 m .69734 .44493 L .69382 .44441 L F
.57 .024 0 r
.69382 .44441 m .69734 .44493 L .69646 .44502 L F
0 0 0 r
.6951 .4481 m .69654 .44694 L .69734 .44493 L F
.594 .623 .85 r
.69734 .44493 m .6988 .44109 L .69646 .44502 L F
.69734 .44493 m .69981 .44431 L .6988 .44109 L F
.331 0 .137 r
.69654 .44694 m .69981 .44431 L .69734 .44493 L F
.539 .638 .897 r
.25094 .55165 m .24988 .55379 L .24889 .55192 L F
.417 .49 .827 r
.25094 .55165 m .2526 .55505 L .24988 .55379 L F
.339 .126 .436 r
.35364 .59703 m .35647 .59349 L .35375 .59467 L F
.681 .632 .794 r
.68721 .43173 m .68848 .43537 L .69125 .43274 L F
.577 .639 .876 r
.68848 .43537 m .69211 .43612 L .69125 .43274 L F
.569 .613 .856 r
.69887 .41252 m .69635 .41326 L .69592 .41168 L F
.321 .065 .361 r
.52782 .72069 m .53041 .71796 L .52826 .71962 L F
.543 .293 .487 r
.60055 .4919 m .60296 .4936 L .60047 .49394 L F
.597 .258 .366 r
.60055 .4919 m .60309 .49198 L .60296 .4936 L F
0 0 .523 r
.647 .43613 m .6474 .435 L .64618 .4325 L F
0 .282 .782 r
.647 .43613 m .64922 .438 L .6474 .435 L F
.637 .125 0 r
.54357 .69255 m .5446 .69412 L .54201 .69128 L F
.629 .613 .815 r
.71632 .42107 m .71378 .42188 L .71266 .41851 L F
.823 .59 .585 r
.53937 .68907 m .53569 .69193 L .53535 .69042 L F
.619 .533 .735 r
.22534 .56832 m .22795 .56786 L .22731 .56477 L F
.492 .251 .476 r
.2255 .57006 m .22795 .56786 L .22534 .56832 L F
.628 .749 .934 r
.63912 .46267 m .63746 .46517 L .63637 .46191 L F
.63912 .46267 m .64012 .46434 L .63746 .46517 L F
.733 .253 0 r
.58022 .62463 m .58023 .62464 L .58023 .62464 L F
.809 .804 .847 r
.58104 .62254 m .58023 .62464 L .5801 .62451 L F
0 0 .228 r
.5801 .62451 m .58013 .62446 L .58104 .62254 L F
.733 .253 0 r
.57954 .62317 m .58022 .62463 L .58065 .62453 L F
.57794 .62119 m .58004 .62436 L .57954 .62317 L F
.58004 .62436 m .58022 .62463 L .57954 .62317 L F
.736 .255 0 r
.57844 .62234 m .58023 .62464 L .57794 .62119 L F
.5788 .62315 m .58004 .62444 L .57854 .62247 L F
.58004 .62444 m .58023 .62464 L .57844 .62234 L F
0 0 .228 r
.5801 .62451 m .58094 .62275 L .57881 .62315 L F
.58094 .62275 m .58104 .62254 L .57946 .62297 L F
.58094 .62275 m .57946 .62297 L .57881 .62315 L F
.5801 .62451 m .57881 .62315 L .5788 .62315 L F
.809 .804 .847 r
.58104 .62254 m .5801 .62451 L .5788 .62315 L F
0 0 .228 r
.57947 .62584 m .5801 .62451 L .57949 .62387 L F
.57899 .6239 m .57949 .62387 L .5788 .62315 L F
.941 .775 .648 r
.57626 .62024 m .57794 .62119 L .57659 .6248 L F
.57626 .62024 m .57659 .6248 L .57554 .62252 L F
.871 .667 .624 r
.57659 .6248 m .57427 .62512 L .57554 .62252 L F
.55 .65 .901 r
.57907 .62388 m .57554 .62252 L .57473 .62421 L F
.57907 .62388 m .57473 .62421 L .57873 .62392 L F
.871 .667 .624 r
.57659 .6248 m .57717 .62653 L .57427 .62512 L F
.801 .781 .834 r
.57947 .62584 m .57907 .62388 L .57647 .62598 L F
.806 .794 .841 r
.57647 .62598 m .57907 .62388 L .57462 .62444 L F
.879 .824 .789 r
.57947 .62584 m .5788 .62315 L .57907 .62388 L F
0 0 .228 r
.57947 .62584 m .57949 .62387 L .57899 .6239 L F
.55 .65 .901 r
.57873 .62392 m .57473 .62421 L .57462 .62444 L F
.415 0 0 r
.58099 .62283 m .5794 .62417 L .57906 .62414 L F
.55 .65 .901 r
.57907 .62388 m .57789 .62209 L .57554 .62252 L F
.415 0 0 r
.57884 .62343 m .57906 .62414 L .57701 .62394 L F
.58099 .62283 m .57906 .62414 L .57884 .62343 L F
.736 .255 0 r
.57864 .62279 m .57854 .62247 L .57844 .62234 L F
.5788 .62315 m .57854 .62247 L .57864 .62279 L F
.733 .253 0 r
.58022 .62463 m .58023 .62464 L .58065 .62453 L F
.605 .845 .99 r
.58156 .62225 m .58065 .62453 L .58023 .62464 L F
.58156 .62225 m .58304 .62384 L .58065 .62453 L F
.809 .804 .847 r
.58104 .62254 m .58156 .62225 L .58023 .62464 L F
.503 .454 .735 r
.58012 .62455 m .58184 .62577 L .58099 .62283 L F
.57947 .62584 m .58106 .62579 L .58012 .62455 L F
.58106 .62579 m .58184 .62577 L .58012 .62455 L F
.599 .426 .619 r
.58545 .62074 m .58304 .62384 L .58249 .62325 L F
.58281 .62176 m .58249 .62325 L .58156 .62225 L F
.58545 .62074 m .58249 .62325 L .58281 .62176 L F
.854 .7 .691 r
.58545 .62074 m .58285 .62094 L .58235 .6181 L F
.599 .426 .619 r
.58545 .62074 m .58156 .62225 L .58285 .62094 L F
.099 .476 .895 r
.58235 .6181 m .58672 .62024 L .58545 .62074 L F
0 0 .507 r
.58235 .6181 m .58285 .62094 L .58332 .61968 L F
.58316 .619 m .58332 .61968 L .58345 .61932 L F
.58235 .6181 m .58332 .61968 L .58316 .619 L F
.238 .509 .906 r
.58363 .61748 m .58672 .62024 L .58235 .6181 L F
.599 .426 .619 r
.58545 .62074 m .58533 .62373 L .58304 .62384 L F
.58304 .62384 m .58533 .62373 L .58545 .62074 L F
.394 .427 .776 r
.58672 .62024 m .58533 .62373 L .58545 .62074 L F
0 0 .507 r
.58235 .6181 m .58323 .61907 L .58073 .61735 L F
.58323 .61907 m .58345 .61932 L .58296 .61897 L F
.58323 .61907 m .58296 .61897 L .58073 .61735 L F
.512 .201 .376 r
.58337 .61913 m .58672 .62024 L .58363 .61748 L F
.58323 .62008 m .5861 .62021 L .58337 .61913 L F
.5861 .62021 m .58672 .62024 L .58337 .61913 L F
.58294 .62195 m .5836 .62165 L .58323 .62008 L F
.5836 .62165 m .58672 .62024 L .58323 .62008 L F
.726 .49 .57 r
.58365 .61419 m .58235 .6181 L .58073 .61735 L F
.699 .864 .96 r
.58365 .61419 m .58702 .61272 L .58588 .6116 L F
.266 .129 .5 r
.58379 .61399 m .58235 .6181 L .58365 .61419 L F
.58379 .61399 m .58516 .61588 L .58235 .6181 L F
.238 .509 .906 r
.58363 .61748 m .58235 .6181 L .58468 .61626 L F
.58363 .61748 m .58468 .61626 L .58516 .61588 L F
.713 .598 .727 r
.58363 .61748 m .58186 .61544 L .583 .61821 L F
.512 .201 .376 r
.58332 .61968 m .58363 .61748 L .58363 .61783 L F
.5833 .6196 m .58363 .61748 L .58332 .61968 L F
.713 .598 .727 r
.58363 .61748 m .583 .61821 L .58345 .61932 L F
.181 .273 .724 r
.58073 .61735 m .58296 .61897 L .58186 .61544 L F
.58296 .61897 m .58345 .61932 L .58247 .61692 L F
.58296 .61897 m .58247 .61692 L .58186 .61544 L F
.396 .391 .736 r
.58294 .62195 m .58332 .61968 L .58317 .62007 L F
.512 .201 .376 r
.58294 .62195 m .5833 .6196 L .58332 .61968 L F
.58294 .62195 m .58367 .62201 L .58382 .62155 L F
.58294 .62195 m .58363 .61783 L .58362 .62199 L F
.58294 .62195 m .58362 .62199 L .58362 .62248 L F
.998 .832 .492 r
.58345 .61932 m .58359 .62198 L .58363 .61748 L F
.58359 .62198 m .5836 .62219 L .5836 .62199 L F
.58359 .62198 m .5836 .62199 L .58363 .61748 L F
.512 .201 .376 r
.58367 .62201 m .5851 .62211 L .58382 .62155 L F
.674 .603 .767 r
.58422 .62199 m .58501 .62206 L .58362 .62199 L F
.58359 .62198 m .58362 .62199 L .58294 .62195 L F
.396 .391 .736 r
.58294 .62195 m .58362 .62248 L .58359 .62198 L F
.58294 .62195 m .58359 .62198 L .58345 .61932 L F
.674 .603 .767 r
.58356 .62197 m .58359 .62198 L .58294 .62195 L F
.58422 .62199 m .58362 .62199 L .58356 .62197 L F
.998 .832 .492 r
.5836 .62219 m .58362 .62214 L .58362 .62199 L F
.5836 .62199 m .58362 .62199 L .58363 .61748 L F
.5836 .62219 m .58362 .62199 L .5836 .62199 L F
.512 .201 .376 r
.5851 .62211 m .58671 .62183 L .58672 .62024 L F
.674 .603 .767 r
.58501 .62206 m .58671 .62222 L .58367 .62201 L F
.58362 .62199 m .58367 .62201 L .58294 .62195 L F
.58501 .62206 m .58367 .62201 L .58362 .62199 L F
.998 .832 .492 r
.5836 .62219 m .58362 .62248 L .58362 .62214 L F
.512 .201 .376 r
.58382 .62155 m .5851 .62211 L .58672 .62024 L F
.5851 .62211 m .58671 .62222 L .58671 .62183 L F
.396 .391 .736 r
.58294 .62195 m .58345 .61932 L .58332 .61968 L F
.58294 .62195 m .58317 .62007 L .58289 .62139 L F
.58294 .62195 m .58285 .62094 L .58156 .62225 L F
.58294 .62195 m .58156 .62225 L .58104 .62254 L F
.282 0 .047 r
.58099 .62283 m .58294 .62195 L .58104 .62254 L F
.58099 .62283 m .58422 .62199 L .58294 .62195 L F
.568 .803 .988 r
.58196 .62053 m .58422 .62199 L .58117 .62278 L F
.581 .62281 m .58117 .62278 L .58099 .62283 L F
.58196 .62053 m .58117 .62278 L .581 .62281 L F
.396 .391 .736 r
.58289 .62139 m .58317 .62007 L .58285 .62094 L F
.832 .443 .314 r
.58304 .62384 m .58726 .62698 L .58533 .62373 L F
.828 .755 .782 r
.58374 .62637 m .58519 .63023 L .58726 .62698 L F
.58155 .62599 m .58369 .62849 L .58374 .62637 L F
.58369 .62849 m .58519 .63023 L .58374 .62637 L F
.58155 .62599 m .58726 .62698 L .58397 .62668 L F
.832 .443 .314 r
.58304 .62384 m .58397 .62668 L .58726 .62698 L F
0 0 .453 r
.58442 .62494 m .58397 .62668 L .58375 .626 L F
.58378 .62444 m .58375 .626 L .58304 .62384 L F
.58442 .62494 m .58375 .626 L .58378 .62444 L F
.58442 .62494 m .58304 .62384 L .58533 .62373 L F
.605 .518 .729 r
.58099 .62283 m .58442 .62494 L .58422 .62199 L F
.559 .164 .249 r
.58422 .62199 m .58174 .62311 L .58099 .62283 L F
0 0 .228 r
.58013 .62446 m .58099 .62283 L .58091 .6228 L F
.58012 .62455 m .58099 .62283 L .5801 .62451 L F
.605 .518 .729 r
.58099 .62283 m .58184 .62577 L .58442 .62494 L F
.559 .164 .249 r
.58174 .62311 m .5794 .62417 L .58099 .62283 L F
0 0 .228 r
.58091 .6228 m .58099 .62283 L .58104 .62254 L F
.57947 .62584 m .58012 .62455 L .5801 .62451 L F
.953 .669 .462 r
.59022 .61236 m .58859 .60913 L .58869 .61114 L F
.706 .514 .628 r
.57908 .50392 m .57904 .50614 L .57544 .50599 L F
.605 .423 .609 r
.58141 .50341 m .57904 .50614 L .57908 .50392 L F
.467 .625 .921 r
.247 .54943 m .2466 .55178 L .24488 .54993 L F
.247 .54943 m .24889 .55192 L .2466 .55178 L F
.906 .98 .71 r
.60895 .44997 m .61011 .44843 L .60851 .44945 L F
.974 .878 .675 r
.61011 .44843 m .61027 .44396 L .60936 .44703 L F
.985 .895 .64 r
.60851 .44945 m .61011 .44843 L .60936 .44703 L F
.362 .526 .885 r
.21904 .55483 m .21989 .55676 L .22072 .55485 L F
.053 0 .051 r
.21989 .55676 m .22071 .55781 L .22072 .55485 L F
.21989 .55676 m .21908 .5587 L .22071 .55781 L F
.297 0 0 r
.49229 .69053 m .49617 .68932 L .49391 .68845 L F
.892 .773 .724 r
.55321 .66511 m .55237 .6674 L .55436 .66743 L F
.809 .332 .078 r
.55237 .6674 m .55544 .66996 L .55436 .66743 L F
.805 .671 .716 r
.55659 .49805 m .55311 .49764 L .55493 .49447 L F
.791 .648 .704 r
.55659 .49805 m .55232 .4998 L .55311 .49764 L F
.55659 .49805 m .55592 .5003 L .55232 .4998 L F
.468 .885 .927 r
.40424 .57836 m .40623 .57763 L .40832 .5778 L F
.443 .872 .922 r
.40832 .5778 m .40818 .57689 L .41051 .57696 L F
.40832 .5778 m .40623 .57763 L .40818 .57689 L F
0 0 0 r
.53196 .69077 m .53097 .69119 L .53336 .69076 L F
.53196 .69077 m .52988 .69341 L .53097 .69119 L F
.651 .699 .881 r
.67736 .41166 m .681 .41297 L .68019 .41056 L F
.548 .634 .889 r
.68019 .41056 m .681 .41297 L .6828 .41052 L F
.486 .547 .844 r
.681 .41297 m .68414 .4142 L .6828 .41052 L F
0 .533 .739 r
.5631 .64128 m .56371 .64128 L .5616 .64085 L F
0 .273 .777 r
.38635 .62394 m .38874 .62569 L .38839 .62657 L F
0 .38 .841 r
.38874 .62569 m .39078 .6277 L .38839 .62657 L F
.075 0 0 r
.39909 .57953 m .40108 .57907 L .40188 .5781 L F
.147 0 0 r
.3988 .57977 m .40108 .57907 L .39909 .57953 L F
.744 .659 .766 r
.69382 .44441 m .69161 .44825 L .6951 .4481 L F
0 0 0 r
.69115 .44838 m .6951 .4481 L .69161 .44825 L F
.69115 .44838 m .69363 .44823 L .6951 .4481 L F
.537 .925 .854 r
.6951 .4481 m .69363 .44823 L .69654 .44694 L F
.462 0 .059 r
.41059 .58873 m .40908 .59039 L .40665 .59023 L F
.045 0 0 r
.4114 .58943 m .41059 .58873 L .41299 .58852 L F
.4114 .58943 m .40908 .59039 L .41059 .58873 L F
.383 .402 .757 r
.25143 .56697 m .24962 .56816 L .24894 .56498 L F
.392 .301 .632 r
.25143 .56697 m .24977 .57056 L .24962 .56816 L F
.916 .517 .172 r
.65367 .42531 m .65617 .42927 L .65456 .4266 L F
.672 .351 .422 r
.4654 .57651 m .46221 .57832 L .46306 .57705 L F
.441 .824 .988 r
.18244 .54211 m .18439 .54164 L .1863 .54229 L F
.417 .827 .975 r
.18439 .54164 m .18839 .54169 L .1863 .54229 L F
.995 .792 .521 r
.47696 .72394 m .47743 .72677 L .47629 .72614 L F
.47629 .72614 m .47743 .72677 L .47696 .72394 L F
.973 .767 .341 r
.61267 .45244 m .61338 .45393 L .61303 .45518 L F
.744 .885 .944 r
.61605 .45253 m .61338 .45393 L .61267 .45244 L F
.522 .019 .002 r
.61338 .45393 m .61572 .45516 L .61303 .45518 L F
.105 0 0 r
.18296 .55433 m .18267 .55337 L .18495 .55315 L F
.18296 .55433 m .18083 .55499 L .18267 .55337 L F
.497 .411 .689 r
.34955 .6034 m .3516 .60285 L .35117 .60039 L F
.475 .349 .629 r
.34979 .60592 m .3516 .60285 L .34955 .6034 L F
.458 .461 .774 r
.54529 .67871 m .54694 .68205 L .54441 .68253 L F
.724 .782 .898 r
.68509 .41826 m .68849 .41864 L .68768 .41782 L F
.56 .728 .953 r
.68768 .41782 m .68849 .41864 L .6908 .418 L F
.538 .571 .836 r
.61226 .46452 m .61396 .46859 L .61598 .46759 L F
.272 .015 .328 r
.61598 .46759 m .61396 .46859 L .61352 .47054 L F
.421 .828 .976 r
.38848 .64165 m .38695 .64116 L .38475 .6416 L F
.236 0 0 r
.39061 .64074 m .38695 .64116 L .38848 .64165 L F
.586 .452 .665 r
.61601 .44916 m .61605 .45253 L .61846 .44796 L F
.324 0 .15 r
.6312 .43584 m .62821 .43815 L .63038 .43753 L F
.649 .251 .277 r
.63355 .43774 m .6312 .43584 L .63038 .43753 L F
.743 .665 .774 r
.65445 .45965 m .65818 .46008 L .65642 .45858 L F
.757 .664 .758 r
.65642 .45858 m .65818 .46008 L .66066 .45683 L F
.476 .243 .481 r
.24817 .58152 m .24627 .58044 L .2484 .5788 L F
.24817 .58152 m .24641 .58227 L .24627 .58044 L F
.155 .395 .842 r
.41874 .58647 m .41905 .58429 L .41734 .58462 L F
.13 .371 .829 r
.56884 .63389 m .56809 .63492 L .56636 .63409 L F
.56884 .63389 m .56961 .63537 L .56809 .63492 L F
.604 .189 0 r
.65873 .42125 m .6594 .42235 L .6577 .42004 L F
.65873 .42125 m .66028 .42376 L .6594 .42235 L F
.59 .523 .748 r
.62552 .43902 m .62856 .44079 L .62821 .43815 L F
.595 .637 .862 r
.74446 .42563 m .74212 .42733 L .74186 .42605 L F
.004 0 .361 r
.7436 .42764 m .74212 .42733 L .74446 .42563 L F
.7436 .42764 m .74252 .42918 L .74212 .42733 L F
.607 .24 .32 r
.42709 .63497 m .42305 .6373 L .42336 .63595 L F
.42709 .63497 m .42539 .63767 L .42305 .6373 L F
.606 .239 .32 r
.42889 .63712 m .42709 .63497 L .42913 .63546 L F
.42889 .63712 m .42539 .63767 L .42709 .63497 L F
.753 .713 .814 r
.53429 .66505 m .53069 .66472 L .53258 .66265 L F
.688 .258 .222 r
.53429 .66505 m .53304 .66676 L .53069 .66472 L F
.279 .498 .889 r
.53258 .66265 m .53541 .66378 L .53429 .66505 L F
.444 .746 .992 r
.53541 .66378 m .53712 .66497 L .53429 .66505 L F
.53541 .66378 m .53712 .66497 L .53429 .66505 L F
.609 .482 .682 r
.53069 .66472 m .53408 .66541 L .53258 .66265 L F
.53408 .66541 m .53452 .6655 L .53428 .66515 L F
.53408 .66541 m .53428 .66515 L .53258 .66265 L F
.621 .305 .414 r
.53408 .66541 m .53304 .66676 L .53452 .6655 L F
0 0 0 r
.53393 .66559 m .53304 .66676 L .53353 .66609 L F
.621 .305 .414 r
.53069 .66472 m .53304 .66676 L .53408 .66541 L F
0 0 0 r
.53508 .66415 m .53428 .66515 L .53429 .66505 L F
.53541 .66378 m .53353 .66609 L .53508 .66415 L F
.472 .434 .734 r
.53258 .66265 m .53428 .66515 L .53541 .66378 L F
.53428 .66515 m .53452 .6655 L .53541 .66378 L F
0 0 0 r
.53428 .66515 m .53353 .66609 L .53369 .66587 L F
.53428 .66515 m .53369 .66587 L .53429 .66505 L F
.53541 .66378 m .53304 .66676 L .53393 .66559 L F
.497 .9 .925 r
.41654 .57488 m .41348 .57586 L .41251 .57569 L F
.544 .117 .18 r
.46865 .63222 m .46519 .63372 L .46566 .63247 L F
.995 .778 .415 r
.65311 .45448 m .65268 .45626 L .65205 .45238 L F
.569 .65 .891 r
.45404 .56917 m .45137 .572 L .4497 .56676 L F
.672 .967 .772 r
.45246 .57108 m .45137 .572 L .45404 .56917 L F
.672 .603 .771 r
.72364 .42677 m .7211 .42739 L .71998 .42392 L F
.711 .824 .373 r
.72364 .42677 m .72176 .43077 L .7211 .42739 L F
.945 .704 .543 r
.6599 .44878 m .66159 .4478 L .65984 .4469 L F
.6599 .44878 m .66145 .45033 L .66159 .4478 L F
.82 .976 .68 r
.42816 .58115 m .4279 .5826 L .42981 .58011 L F
0 0 0 r
.42996 .58018 m .42816 .58115 L .42981 .58011 L F
.42996 .58018 m .42829 .58047 L .42816 .58115 L F
.404 0 0 r
.42816 .58115 m .42608 .5803 L .42663 .58087 L F
.42816 .58115 m .42661 .58077 L .42608 .5803 L F
0 0 0 r
.42829 .58047 m .42661 .58077 L .42816 .58115 L F
.82 .976 .68 r
.42816 .58115 m .42771 .58285 L .4279 .5826 L F
.751 .99 .787 r
.43231 .57764 m .4303 .57821 L .42981 .58011 L F
0 0 0 r
.42996 .58018 m .42981 .58011 L .4303 .57821 L F
.118 0 .236 r
.21561 .6408 m .21414 .64162 L .21635 .63859 L F
.277 .08 .423 r
.21561 .6408 m .21356 .64393 L .21414 .64162 L F
.554 .297 .48 r
.576 .63229 m .57839 .63223 L .57887 .63002 L F
.738 .645 .756 r
.57839 .63223 m .58073 .6292 L .57887 .63002 L F
.741 .631 .737 r
.35318 .62083 m .35638 .62116 L .35515 .61812 L F
.645 .47 .632 r
.35451 .62251 m .35853 .62337 L .35831 .62321 L F
.35662 .62265 m .35831 .62321 L .35766 .62271 L F
.35451 .62251 m .35831 .62321 L .35662 .62265 L F
.605 .115 .063 r
.35318 .62083 m .35707 .6228 L .35638 .62116 L F
.35707 .6228 m .35717 .62285 L .35716 .62283 L F
.35707 .6228 m .35716 .62283 L .35638 .62116 L F
.629 .574 .774 r
.35515 .61812 m .35638 .62116 L .35843 .62073 L F
.5 .06 .135 r
.35638 .62116 m .35766 .62271 L .35843 .62073 L F
.35638 .62116 m .35717 .62285 L .35766 .62271 L F
.573 .532 .771 r
.7224 .43543 m .71999 .43315 L .72336 .43317 L F
.72336 .43317 m .71936 .43256 L .72371 .43234 L F
.71999 .43315 m .71936 .43256 L .72336 .43317 L F
.7224 .43543 m .72371 .43234 L .72148 .43451 L F
.503 .105 .219 r
.72148 .43451 m .72396 .43333 L .7224 .43543 L F
.72396 .43333 m .72522 .43273 L .72406 .43383 L F
.72396 .43333 m .72406 .43383 L .7224 .43543 L F
.711 .824 .373 r
.72364 .42677 m .72207 .42974 L .72176 .43077 L F
.651 .737 .912 r
.72207 .42974 m .72522 .43273 L .72371 .43234 L F
.82 .758 .794 r
.72748 .4298 m .72522 .43273 L .72341 .43101 L F
.72312 .42975 m .72341 .43101 L .72207 .42974 L F
.72748 .4298 m .72341 .43101 L .72312 .42975 L F
0 0 .205 r
.72355 .43159 m .72389 .43303 L .7232 .42997 L F
.72371 .43234 m .72381 .43273 L .72355 .43159 L F
.503 .105 .219 r
.72148 .43451 m .72425 .43439 L .72496 .43317 L F
.72429 .43317 m .72496 .43317 L .72522 .43273 L F
.72148 .43451 m .72496 .43317 L .72429 .43317 L F
.765 .4 .365 r
.72522 .43273 m .72425 .43439 L .72371 .43234 L F
0 0 .205 r
.72381 .43273 m .72389 .43303 L .72355 .43159 L F
.72389 .43303 m .72425 .43439 L .72366 .43192 L F
.72389 .43303 m .72366 .43192 L .7232 .42997 L F
.718 .31 .273 r
.63499 .44042 m .63708 .44101 L .63466 .43898 L F
.599 .635 .858 r
.36642 .62918 m .36777 .63213 L .36961 .63047 L F
.7 .72 .865 r
.46285 .57312 m .45807 .57289 L .46176 .57207 L F
.385 .748 .992 r
.46313 .5719 m .46285 .57312 L .46176 .57207 L F
.46313 .5719 m .46476 .57287 L .46285 .57312 L F
.962 .925 .714 r
.54746 .68467 m .54646 .68731 L .54841 .68628 L F
.899 .58 .434 r
.54646 .68731 m .54829 .68828 L .54841 .68628 L F
.756 .712 .811 r
.62836 .42677 m .62978 .43013 L .62614 .42998 L F
.359 0 0 r
.62614 .42998 m .62978 .43013 L .6269 .43091 L F
.289 .438 .838 r
.63143 .42886 m .62978 .43013 L .62836 .42677 L F
.502 .905 .799 r
.6269 .43091 m .6285 .43048 L .62839 .43048 L F
.342 0 0 r
.62859 .43052 m .62839 .43048 L .6269 .43091 L F
.62839 .43048 m .62614 .42998 L .6269 .43091 L F
.203 0 0 r
.62222 .42935 m .62614 .42998 L .62839 .43048 L F
.62222 .42935 m .62839 .43048 L .62835 .43048 L F
.62835 .43048 m .62839 .43048 L .62859 .43052 L F
.8 .748 .805 r
.62607 .42765 m .62614 .42998 L .62222 .42935 L F
.76 .718 .813 r
.62836 .42677 m .62614 .42998 L .62607 .42765 L F
.605 .691 .903 r
.62835 .43048 m .62842 .43044 L .62456 .42856 L F
.62805 .43042 m .62815 .43038 L .62456 .42856 L F
.62222 .42935 m .62805 .43042 L .62456 .42856 L F
.62805 .43042 m .62835 .43048 L .62815 .43038 L F
.342 0 0 r
.62829 .43042 m .6269 .43091 L .62749 .43016 L F
.324 .789 .67 r
.6269 .43091 m .62794 .43042 L .62749 .43016 L F
.44 0 0 r
.62822 .43034 m .62813 .43037 L .62749 .43016 L F
.324 .789 .67 r
.62794 .43042 m .62989 .42951 L .62749 .43016 L F
.44 0 0 r
.62456 .42856 m .6256 .42907 L .62749 .43016 L F
.6256 .42907 m .62822 .43034 L .62749 .43016 L F
.502 .905 .799 r
.6285 .43048 m .62858 .43046 L .62786 .43048 L F
.44 0 0 r
.62842 .43044 m .62829 .43042 L .62813 .43037 L F
.502 .905 .799 r
.62858 .43046 m .62978 .43013 L .6282 .43042 L F
.62858 .43046 m .6282 .43042 L .62786 .43048 L F
.44 0 0 r
.62822 .43034 m .62842 .43044 L .62813 .43037 L F
.605 .691 .903 r
.62835 .43048 m .62859 .43052 L .62842 .43044 L F
.44 0 0 r
.62842 .43044 m .62859 .43052 L .62829 .43042 L F
.324 .789 .67 r
.62794 .43042 m .62981 .42959 L .62989 .42951 L F
.6269 .43091 m .62804 .4304 L .62794 .43042 L F
.62804 .4304 m .62981 .42959 L .62794 .43042 L F
.62981 .42959 m .63143 .42886 L .63079 .42913 L F
.62981 .42959 m .63079 .42913 L .62989 .42951 L F
.502 .905 .799 r
.62981 .42959 m .62978 .43013 L .63143 .42886 L F
.62786 .43048 m .62856 .43035 L .62981 .42959 L F
.62856 .43035 m .62978 .43013 L .62981 .42959 L F
.6269 .43091 m .62839 .43048 L .62814 .43048 L F
.342 0 0 r
.62859 .43052 m .6269 .43091 L .62829 .43042 L F
.502 .905 .799 r
.6269 .43091 m .62814 .43048 L .62786 .43048 L F
.821 .734 .769 r
.54423 .66646 m .54038 .66766 L .54296 .66696 L F
.595 .309 .452 r
.54296 .66696 m .54656 .66516 L .54423 .66646 L F
.396 0 .092 r
.41279 .63785 m .41088 .63987 L .40894 .63919 L F
.397 0 .085 r
.4149 .63766 m .41088 .63987 L .41279 .63785 L F
.001 0 0 r
.6388 .43421 m .63988 .43332 L .64189 .43229 L F
0 .119 .67 r
.66413 .42987 m .66422 .42848 L .66243 .42654 L F
0 .048 .615 r
.66413 .42987 m .66573 .43199 L .66422 .42848 L F
.576 .845 .996 r
.19861 .57108 m .19467 .57086 L .19687 .57015 L F
.19861 .57108 m .19467 .57086 L .19687 .57015 L F
.812 .349 0 r
.66674 .43338 m .66659 .43429 L .66573 .43199 L F
.66674 .43338 m .66803 .43555 L .66659 .43429 L F
.532 .07 .104 r
.44586 .6293 m .44966 .62928 L .4499 .62831 L F
.673 .207 .138 r
.44966 .62928 m .45141 .62967 L .4499 .62831 L F
.781 .66 .73 r
.54388 .65324 m .54542 .6509 L .5428 .65044 L F
.394 .063 .28 r
.61134 .48603 m .61383 .48673 L .61079 .48774 L F
.61134 .48603 m .61378 .48543 L .61383 .48673 L F
.683 .472 .595 r
.71307 .4477 m .71076 .4501 L .71071 .44779 L F
.71307 .4477 m .71316 .4504 L .71076 .4501 L F
.606 .395 .569 r
.7157 .44725 m .71316 .4504 L .71307 .4477 L F
.628 .613 .817 r
.70935 .41762 m .71266 .41851 L .7102 .41941 L F
.792 .64 .693 r
.55232 .4998 m .55592 .5003 L .55398 .50339 L F
.495 .564 .855 r
.44995 .57516 m .44769 .57701 L .44998 .57651 L F
.44995 .57516 m .44845 .57688 L .44769 .57701 L F
.466 .715 .977 r
.44769 .57701 m .44845 .57688 L .44389 .57591 L F
.433 .278 .57 r
.23154 .61442 m .22966 .61763 L .22995 .61518 L F
.658 .716 .891 r
.70407 .41161 m .70298 .4153 L .70154 .41229 L F
.70407 .41161 m .70557 .41445 L .70298 .4153 L F
.441 .274 .557 r
.21467 .58856 m .21481 .59128 L .21663 .58811 L F
.174 .515 .916 r
.20024 .55354 m .20232 .55423 L .20019 .55239 L F
.20024 .55354 m .20019 .55239 L .20037 .55459 L F
0 0 .45 r
.19988 .55225 m .20037 .55459 L .20019 .55239 L F
.736 .255 0 r
.5788 .62315 m .57794 .62119 L .57626 .62024 L F
.418 0 .057 r
.53697 .64814 m .533 .64985 L .5346 .65064 L F
.431 .713 .983 r
.67521 .40269 m .67298 .40286 L .67185 .40148 L F
.38 .061 .294 r
.64768 .43912 m .64922 .438 L .6471 .43897 L F
.427 0 0 r
.39975 .63118 m .39808 .6303 L .39636 .63139 L F
.255 .439 .85 r
.37783 .63769 m .37809 .63909 L .37911 .63777 L F
.435 .565 .886 r
.37877 .64028 m .37911 .63777 L .37809 .63909 L F
.901 .634 .526 r
.60407 .45528 m .60645 .45375 L .60604 .45236 L F
.60407 .45528 m .60661 .45591 L .60645 .45375 L F
.908 .955 .814 r
.60604 .45236 m .60645 .45375 L .60895 .44997 L F
.365 0 0 r
.40188 .5781 m .40108 .57907 L .40424 .57836 L F
.23 0 0 r
.37525 .58733 m .37755 .58697 L .37918 .58555 L F
.37755 .58697 m .38145 .58504 L .37918 .58555 L F
.713 .629 .761 r
.43963 .57154 m .43687 .57075 L .43954 .57105 L F
.296 0 0 r
.43545 .57102 m .43954 .57105 L .43687 .57075 L F
.43545 .57102 m .43844 .57128 L .43954 .57105 L F
.914 .958 .802 r
.43954 .57105 m .43844 .57128 L .43922 .56923 L F
.43954 .57105 m .43922 .56923 L .44003 .56709 L F
.713 .629 .761 r
.44095 .57191 m .43963 .57154 L .43954 .57105 L F
.727 .747 .868 r
.44235 .57044 m .44095 .57191 L .43954 .57105 L F
.218 .528 .92 r
.2435 .54822 m .24308 .54954 L .24125 .54788 L F
.2435 .54822 m .24488 .54993 L .24308 .54954 L F
.499 .838 .998 r
.18839 .54169 m .19035 .54117 L .19217 .54187 L F
.718 .829 .933 r
.66333 .41556 m .65966 .41541 L .66232 .4146 L F
.699 .9 .969 r
.66564 .41426 m .66333 .41556 L .66232 .4146 L F
.771 .986 .901 r
.64229 .44984 m .64496 .44681 L .64553 .44735 L F
.64229 .44984 m .64191 .44917 L .64496 .44681 L F
.21 .654 .95 r
.22589 .54358 m .22783 .54373 L .22951 .54469 L F
.445 .77 .997 r
.22993 .54335 m .22951 .54469 L .22783 .54373 L F
.22993 .54335 m .23163 .54438 L .22951 .54469 L F
.725 .845 .938 r
.64593 .4619 m .6425 .46175 L .64507 .4592 L F
.531 .369 .606 r
.64835 .45922 m .64593 .4619 L .64507 .4592 L F
.64835 .45922 m .6485 .46165 L .64593 .4619 L F
.757 .664 .758 r
.65642 .45858 m .66066 .45683 L .65901 .45557 L F
.093 .621 .872 r
.21651 .55528 m .21459 .55464 L .21261 .55446 L F
.424 .824 .981 r
.21904 .55483 m .21459 .55464 L .21651 .55528 L F
.995 .789 .514 r
.67002 .45948 m .66867 .46094 L .66833 .45862 L F
.67002 .45948 m .66984 .46195 L .66867 .46094 L F
.8 .602 .634 r
.67002 .45948 m .67184 .46281 L .66984 .46195 L F
.776 .972 .919 r
.55932 .63263 m .55905 .63139 L .55909 .63242 L F
.258 .035 .373 r
.218 .63779 m .21635 .63859 L .21852 .6355 L F
.355 .119 .411 r
.218 .63779 m .21561 .6408 L .21635 .63859 L F
.633 .508 .693 r
.56718 .50915 m .56796 .51233 L .56471 .5123 L F
.674 .475 .608 r
.56796 .51233 m .56471 .51473 L .56471 .5123 L F
.571 .523 .763 r
.54052 .6698 m .53784 .66812 L .53845 .67064 L F
.656 .537 .707 r
.53911 .67398 m .54052 .6698 L .53845 .67064 L F
.743 .324 .254 r
.51547 .69147 m .51777 .69395 L .5185 .69271 L F
.813 .637 .663 r
.51777 .69395 m .52147 .69228 L .5185 .69271 L F
.375 .191 .499 r
.22746 .62299 m .22504 .62627 L .22523 .62383 L F
.817 .627 .645 r
.63708 .44101 m .6387 .4442 L .64061 .44069 L F
.812 .62 .642 r
.64061 .44069 m .6387 .4442 L .64202 .44467 L F
.766 .404 .368 r
.54683 .61689 m .5498 .61776 L .5483 .61507 L F
.675 .952 .953 r
.42193 .573 m .42278 .57142 L .42494 .57198 L F
.42193 .573 m .42082 .57263 L .42278 .57142 L F
.633 .353 .476 r
.51586 .69317 m .51777 .69395 L .51547 .69147 L F
.886 .869 .816 r
.67123 .45082 m .66801 .45212 L .66992 .44956 L F
.67123 .45082 m .66916 .45346 L .66801 .45212 L F
.565 .339 .531 r
.72632 .43882 m .72382 .44155 L .72379 .43862 L F
.328 .401 .786 r
.67724 .46602 m .67858 .46355 L .67607 .46425 L F
.818 .704 .739 r
.6782 .41435 m .67544 .41864 L .67542 .41534 L F
.662 .59 .764 r
.71998 .42392 m .71752 .42464 L .71632 .42107 L F
.533 .415 .665 r
.70263 .45889 m .69987 .45665 L .70245 .45618 L F
.70263 .45889 m .70021 .45952 L .69987 .45665 L F
.798 .869 .901 r
.60103 .43886 m .59652 .44035 L .59985 .43774 L F
.857 .895 .862 r
.60353 .43609 m .60103 .43886 L .59985 .43774 L F
.56 .032 0 r
.19478 .55355 m .19241 .55428 L .19085 .55319 L F
.279 .772 .716 r
.19456 .55351 m .19478 .55355 L .19732 .55263 L F
.472 .889 .789 r
.19731 .55217 m .19535 .55273 L .19456 .55351 L F
0 0 0 r
.19535 .55273 m .19478 .55333 L .19456 .55351 L F
.093 .193 .677 r
.19433 .55678 m .19313 .55801 L .19265 .55551 L F
.19305 .55511 m .19265 .55551 L .19241 .55428 L F
.19433 .55678 m .19265 .55551 L .19305 .55511 L F
.279 .772 .716 r
.19456 .55351 m .19432 .5537 L .19478 .55355 L F
0 0 0 r
.19478 .55333 m .19431 .55383 L .19456 .55351 L F
.711 .206 0 r
.1928 .55543 m .19433 .55678 L .19241 .55428 L F
0 0 0 r
.19431 .55383 m .1928 .55543 L .19366 .55449 L F
.19431 .55383 m .19366 .55449 L .19456 .55351 L F
.279 .772 .716 r
.19456 .55351 m .19241 .55428 L .19432 .5537 L F
.406 .591 .918 r
.45752 .57909 m .45869 .5776 L .45555 .57717 L F
.45752 .57909 m .4598 .5795 L .45869 .5776 L F
.434 .276 .567 r
.23807 .59984 m .23754 .60323 L .23544 .60289 L F
.472 .3 .566 r
.23769 .60462 m .23544 .60289 L .23754 .60323 L F
.23769 .60462 m .23582 .6055 L .23544 .60289 L F
.784 .68 .75 r
.55201 .50647 m .55336 .50858 L .55119 .50866 L F
.317 .089 .402 r
.2403 .59457 m .23983 .59677 L .23816 .59727 L F
.282 .105 .455 r
.23983 .59677 m .23807 .59984 L .23816 .59727 L F
.894 .851 .793 r
.56173 .4852 m .558 .48724 L .56063 .48436 L F
.56173 .4852 m .55943 .48851 L .558 .48724 L F
.89 .961 .836 r
.56401 .48231 m .56173 .4852 L .56063 .48436 L F
.607 .6 .819 r
.69207 .40932 m .68963 .41014 L .68811 .40656 L F
0 .184 .693 r
.67184 .46281 m .67246 .46299 L .66984 .46195 L F
.67184 .46281 m .67368 .46443 L .67246 .46299 L F
.556 .414 .644 r
.38132 .61151 m .38186 .61586 L .37956 .61582 L F
.988 .725 .42 r
.65956 .43855 m .65956 .44043 L .66068 .44132 L F
.985 .707 .397 r
.65957 .44328 m .66068 .44132 L .65956 .44043 L F
.65957 .44328 m .66091 .44462 L .66068 .44132 L F
.672 .967 .772 r
.45246 .57108 m .45404 .56917 L .45461 .57078 L F
.336 .161 .49 r
.22966 .61763 m .22954 .62015 L .2275 .62069 L F
.286 .075 .407 r
.22954 .62015 m .22746 .62299 L .2275 .62069 L F
.565 .339 .531 r
.72632 .43882 m .72642 .44111 L .72382 .44155 L F
.554 .323 .519 r
.72903 .4384 m .72642 .44111 L .72632 .43882 L F
.474 .107 .261 r
.35647 .59349 m .35826 .59343 L .35908 .59172 L F
.486 .187 .383 r
.35826 .59343 m .36112 .59102 L .35908 .59172 L F
.245 .132 .521 r
.52694 .68822 m .52856 .68489 L .52625 .68516 L F
.52694 .68822 m .52872 .68756 L .52856 .68489 L F
.543 .345 .562 r
.52625 .69049 m .52872 .68756 L .52694 .68822 L F
.096 0 .3 r
.19126 .63544 m .19052 .63268 L .19099 .63517 L F
.19126 .63544 m .19285 .63286 L .19052 .63268 L F
.104 .656 .806 r
.19428 .54164 m .19624 .54156 L .19818 .54172 L F
.078 .639 .759 r
.19624 .54156 m .20035 .54146 L .19818 .54172 L F
.828 .732 .759 r
.63666 .44647 m .63972 .44768 L .6387 .4442 L F
.793 .715 .777 r
.6387 .4442 m .63972 .44768 L .64202 .44467 L F
.817 .737 .777 r
.54876 .67901 m .55219 .67977 L .5502 .68259 L F
.434 .871 .905 r
.46455 .62945 m .46632 .62844 L .46732 .6266 L F
.46455 .62945 m .46403 .62921 L .46632 .62844 L F
.656 .586 .764 r
.67416 .424 m .67205 .42235 L .67295 .4225 L F
.963 .632 .319 r
.67313 .42503 m .67445 .42666 L .67416 .424 L F
0 0 .389 r
.67416 .424 m .67445 .42666 L .67542 .42446 L F
.67416 .424 m .67542 .42446 L .67313 .42503 L F
.3 0 0 r
.6767 .42658 m .67628 .42702 L .67559 .42689 L F
.67638 .42659 m .67559 .42689 L .67445 .42666 L F
.6767 .42658 m .67559 .42689 L .67638 .42659 L F
.97 .898 .695 r
.67486 .42716 m .67329 .42996 L .67409 .43089 L F
.67506 .42622 m .67456 .42727 L .67486 .42716 L F
.67456 .42727 m .67329 .42996 L .67486 .42716 L F
.317 .345 .733 r
.67445 .42666 m .67628 .42702 L .67542 .42446 L F
0 0 .255 r
.67295 .4225 m .67417 .41929 L .67549 .41993 L F
.67417 .41929 m .67437 .41875 L .67459 .41898 L F
.67417 .41929 m .67459 .41898 L .67549 .41993 L F
.656 .586 .764 r
.67205 .42235 m .67057 .4212 L .67295 .4225 L F
.561 .106 .13 r
.67057 .4212 m .66946 .42257 L .67295 .4225 L F
.564 .112 .136 r
.66987 .42256 m .67208 .4241 L .67295 .4225 L F
.66946 .42257 m .67208 .4241 L .66987 .42256 L F
.644 .638 .829 r
.6731 .42456 m .6737 .42262 L .67295 .4225 L F
0 0 .255 r
.67315 .42198 m .67409 .42101 L .67437 .41875 L F
.67295 .4225 m .67409 .42101 L .67315 .42198 L F
.567 .935 .812 r
.67589 .41936 m .67532 .41974 L .67409 .42101 L F
.632 .362 .491 r
.67409 .42101 m .67206 .41864 L .67437 .41875 L F
.567 .935 .812 r
.67532 .41974 m .67368 .42081 L .67409 .42101 L F
.838 .757 .774 r
.67409 .42101 m .67208 .4241 L .67143 .42292 L F
.925 .939 .791 r
.67143 .42282 m .67208 .4241 L .67409 .42101 L F
.901 .653 .553 r
.67143 .42282 m .67318 .42487 L .67208 .4241 L F
.589 .035 0 r
.67322 .42491 m .67506 .42622 L .67353 .42528 L F
.67208 .4241 m .67327 .42511 L .67313 .42503 L F
.67208 .4241 m .67372 .4255 L .67412 .42572 L F
.644 .638 .829 r
.67321 .42469 m .67542 .42446 L .67409 .42101 L F
.67313 .42503 m .67353 .42493 L .67321 .42469 L F
.67353 .42493 m .67542 .42446 L .67321 .42469 L F
.589 .035 0 r
.67208 .4241 m .67412 .42572 L .67373 .42528 L F
.901 .653 .553 r
.67318 .42487 m .67372 .4255 L .67208 .4241 L F
.632 .362 .491 r
.67409 .42101 m .67143 .42292 L .6717 .42106 L F
.6732 .41998 m .6717 .42106 L .67206 .41864 L F
.67409 .42101 m .6717 .42106 L .6732 .41998 L F
.589 .035 0 r
.67373 .42528 m .67412 .42572 L .67506 .42622 L F
.644 .638 .829 r
.67313 .42503 m .67321 .42469 L .6731 .42456 L F
.67321 .42469 m .6737 .42262 L .6731 .42456 L F
.6737 .42262 m .67409 .42101 L .67295 .4225 L F
.861 .892 .857 r
.3312 .80355 m .32922 .80628 L .32763 .80546 L F
.1 .618 .884 r
.32922 .80628 m .33013 .80591 L .32763 .80546 L F
.32922 .80628 m .33206 .80665 L .33013 .80591 L F
.234 0 0 r
.3838 .58479 m .38612 .58446 L .38774 .58313 L F
.301 0 0 r
.38612 .58446 m .39004 .58272 L .38774 .58313 L F
.987 .745 .479 r
.66936 .41995 m .66946 .42257 L .67057 .4212 L F
.655 .847 .974 r
.41981 .58162 m .42362 .58183 L .42199 .58082 L F
.043 0 .25 r
.42191 .58096 m .41981 .58162 L .42199 .58082 L F
.551 .809 .994 r
.41782 .58225 m .42131 .58274 L .41981 .58162 L F
.08 0 0 r
.41734 .58462 m .42131 .58274 L .41757 .58222 L F
.41734 .58462 m .41905 .58429 L .42131 .58274 L F
.655 .847 .974 r
.41981 .58162 m .42131 .58274 L .42362 .58183 L F
.043 0 .25 r
.42069 .58312 m .41981 .58162 L .42191 .58096 L F
.551 .809 .994 r
.41757 .58222 m .41782 .58225 L .41981 .58162 L F
.674 .222 .171 r
.42131 .58274 m .41905 .58429 L .42367 .58468 L F
.964 .732 .538 r
.54304 .65581 m .54208 .65228 L .54388 .65324 L F
.672 .44 .562 r
.59911 .49425 m .59462 .49675 L .59464 .49477 L F
.944 .687 .222 r
.67028 .44717 m .66941 .44339 L .67014 .44468 L F
.263 0 0 r
.39975 .63118 m .40232 .6312 L .40408 .63049 L F
.067 0 0 r
.40232 .6312 m .40597 .6305 L .40408 .63049 L F
.83 .743 .768 r
.54876 .67901 m .5502 .68259 L .54694 .68205 L F
.859 .586 .523 r
.55013 .68521 m .54694 .68205 L .5502 .68259 L F
.36 .192 .513 r
.23516 .60791 m .23369 .6063 L .23582 .6055 L F
.23516 .60791 m .23344 .60881 L .23369 .6063 L F
.716 .545 .656 r
.57307 .50646 m .57305 .509 L .57119 .50884 L F
.674 .51 .655 r
.57544 .50599 m .57305 .509 L .57307 .50646 L F
0 0 0 r
.6836 .42237 m .68163 .423 L .68016 .42334 L F
.509 .339 .586 r
.68306 .42447 m .68016 .42334 L .68163 .423 L F
.68306 .42447 m .68026 .42617 L .68016 .42334 L F
.015 .225 .733 r
.36046 .62942 m .36182 .63265 L .36235 .63125 L F
.191 .687 .918 r
.21605 .54221 m .21819 .5421 L .21983 .54276 L F
.233 0 0 r
.21819 .5421 m .22157 .54247 L .21983 .54276 L F
.757 .687 .784 r
.73224 .42355 m .72835 .4213 L .73076 .42058 L F
.73224 .42355 m .72973 .42439 L .72835 .4213 L F
.659 .505 .664 r
.73224 .42355 m .72959 .42666 L .72973 .42439 L F
.324 .084 .386 r
.73559 .42638 m .73332 .4296 L .73494 .42785 L F
.739 .528 .607 r
.73559 .42638 m .73494 .42785 L .73482 .42766 L F
0 0 .022 r
.73559 .42638 m .73494 .42745 L .73332 .4296 L F
.739 .528 .607 r
.73559 .42638 m .73482 .42766 L .73224 .42355 L F
0 0 .022 r
.73559 .42638 m .73553 .42667 L .73494 .42745 L F
.659 .505 .664 r
.73482 .42766 m .73494 .42785 L .73471 .4278 L F
.691 .521 .652 r
.73332 .4296 m .72959 .42666 L .73471 .4278 L F
.73332 .4296 m .73471 .4278 L .73494 .42785 L F
0 0 .022 r
.73471 .4278 m .73518 .42844 L .73349 .42949 L F
.73553 .42667 m .73551 .42677 L .73471 .4278 L F
.73551 .42677 m .73518 .42844 L .73471 .4278 L F
.73553 .42667 m .73349 .42949 L .73332 .4296 L F
.659 .505 .664 r
.73224 .42355 m .73482 .42766 L .72959 .42666 L F
.73482 .42766 m .73471 .4278 L .72959 .42666 L F
.765 .771 .858 r
.73448 .42074 m .73224 .42355 L .73076 .42058 L F
.619 .545 .75 r
.73448 .42074 m .73479 .4231 L .73224 .42355 L F
.739 .528 .607 r
.73559 .42638 m .73224 .42355 L .73479 .4231 L F
.571 .523 .763 r
.54052 .6698 m .54038 .66766 L .53784 .66812 L F
.825 .454 0 r
.64553 .44735 m .64496 .44681 L .64428 .4447 L F
.839 .374 .073 r
.67576 .43693 m .67669 .43629 L .67433 .43487 L F
.529 0 0 r
.67934 .43757 m .67669 .43629 L .67576 .43693 L F
.612 .059 0 r
.73992 .42985 m .73559 .42638 L .7388 .42544 L F
.086 0 0 r
.17661 .55592 m .17254 .55808 L .17378 .55628 L F
.249 0 0 r
.57728 .63852 m .57646 .63871 L .57357 .63832 L F
.092 0 0 r
.57931 .63733 m .57646 .63871 L .57728 .63852 L F
.755 .623 .714 r
.72959 .42666 m .72603 .42382 L .72973 .42439 L F
.72959 .42666 m .72532 .42778 L .72603 .42382 L F
.725 .519 .612 r
.72959 .42666 m .72748 .4298 L .72532 .42778 L F
.748 .55 .628 r
.72959 .42666 m .73095 .43042 L .72748 .4298 L F
.691 .521 .652 r
.73332 .4296 m .73095 .43042 L .72959 .42666 L F
.55 .623 .878 r
.68745 .40473 m .68583 .40715 L .68512 .40534 L F
.597 .688 .906 r
.68745 .40473 m .68811 .40656 L .68583 .40715 L F
.435 .565 .886 r
.37877 .64028 m .38109 .6406 L .37911 .63777 L F
0 0 0 r
.46732 .6266 m .46906 .626 L .47028 .62419 L F
.054 0 0 r
.47028 .62419 m .47104 .62507 L .47203 .62296 L F
.47028 .62419 m .46906 .626 L .47104 .62507 L F
.384 .291 .625 r
.38272 .61252 m .38132 .61151 L .38536 .60954 L F
.38272 .61252 m .38186 .61586 L .38132 .61151 L F
.909 .867 .786 r
.62548 .45795 m .62876 .4565 L .62698 .45492 L F
.62548 .45795 m .62678 .45954 L .62876 .4565 L F
.566 .417 .638 r
.69023 .44158 m .69278 .4409 L .6925 .43854 L F
.669 .537 .695 r
.69023 .44158 m .69382 .44441 L .69278 .4409 L F
.69023 .44158 m .69143 .44533 L .69382 .44441 L F
.203 0 0 r
.40894 .63919 m .40726 .63999 L .40492 .64009 L F
.377 0 0 r
.41088 .63987 m .40726 .63999 L .40894 .63919 L F
.907 .873 .792 r
.5694 .47434 m .56848 .47616 L .56709 .47485 L F
.897 .902 .821 r
.56848 .47616 m .56492 .47809 L .56709 .47485 L F
.56848 .47616 m .5662 .47922 L .56492 .47809 L F
.457 .416 .724 r
.35176 .61526 m .35307 .61116 L .35069 .61173 L F
.35176 .61526 m .35351 .61484 L .35307 .61116 L F
.38 .529 .88 r
.35515 .61812 m .35708 .61818 L .35705 .6181 L F
.35571 .61742 m .35705 .6181 L .35641 .61653 L F
.35515 .61812 m .35705 .6181 L .35571 .61742 L F
.478 .521 .823 r
.35176 .61526 m .35292 .61602 L .35351 .61484 L F
.315 .434 .823 r
.35571 .61742 m .35608 .61807 L .35515 .61812 L F
.35641 .61653 m .35608 .61807 L .35571 .61742 L F
.478 .521 .823 r
.35292 .61602 m .35608 .61807 L .35547 .6173 L F
.35292 .61602 m .35547 .6173 L .35351 .61484 L F
.305 .501 .884 r
.35515 .61812 m .35608 .61807 L .35176 .61526 L F
.651 .382 .499 r
.50546 .69663 m .50369 .6945 L .50337 .6966 L F
.50546 .69663 m .50783 .69398 L .50369 .6945 L F
.262 .769 .768 r
.20718 .55313 m .2067 .55346 L .20887 .55391 L F
.20718 .55313 m .20447 .55388 L .2067 .55346 L F
.998 .794 .444 r
.66916 .45346 m .66811 .45494 L .66801 .45212 L F
.66916 .45346 m .66899 .45605 L .66811 .45494 L F
.117 0 0 r
.48483 .62388 m .48145 .6256 L .48223 .62423 L F
.744 .885 .944 r
.61605 .45253 m .61267 .45244 L .61466 .45187 L F
.399 .834 .949 r
.61759 .45175 m .61605 .45253 L .61466 .45187 L F
.269 .109 .471 r
.24977 .57056 m .2497 .5732 L .24803 .57387 L F
.329 .247 .61 r
.2497 .5732 m .24985 .57575 L .24803 .57387 L F
.401 .256 .567 r
.24803 .57387 m .24985 .57575 L .24804 .5763 L F
.497 .9 .925 r
.41654 .57488 m .41251 .57569 L .41475 .57461 L F
.507 .897 .95 r
.41892 .574 m .41654 .57488 L .41475 .57461 L F
.545 .703 .943 r
.44389 .57591 m .44465 .57318 L .44218 .575 L F
.44389 .57591 m .44845 .57688 L .44465 .57318 L F
.605 .423 .609 r
.58141 .50341 m .58151 .50607 L .57904 .50614 L F
.559 .392 .611 r
.58382 .50036 m .58385 .50288 L .58141 .50341 L F
.557 .385 .605 r
.58385 .50288 m .58151 .50607 L .58141 .50341 L F
.651 .737 .912 r
.72207 .42974 m .72371 .43234 L .72176 .43077 L F
.915 .948 .806 r
.5662 .47922 m .563 .48138 L .56492 .47809 L F
.5662 .47922 m .56401 .48231 L .563 .48138 L F
.683 .579 .732 r
.69143 .44533 m .69161 .44825 L .69382 .44441 L F
.341 .111 .413 r
.22031 .6348 m .218 .63779 L .21852 .6355 L F
.858 .743 .227 r
.54314 .66082 m .54339 .65813 L .5434 .65918 L F
.853 .591 .54 r
.5434 .65918 m .54505 .66211 L .54314 .66082 L F
.639 .439 .596 r
.58873 .49747 m .58936 .49984 L .58626 .5002 L F
.539 .316 .525 r
.59204 .49708 m .58936 .49984 L .58873 .49747 L F
.544 .117 .18 r
.46865 .63222 m .46746 .63417 L .46519 .63372 L F
.248 0 .024 r
.46971 .63351 m .46865 .63222 L .471 .6316 L F
.46971 .63351 m .46746 .63417 L .46865 .63222 L F
.537 .298 .501 r
.52846 .68214 m .53167 .68221 L .53084 .67992 L F
.713 .736 .869 r
.58073 .6292 m .58519 .63023 L .58155 .62599 L F
.707 .626 .765 r
.58073 .6292 m .5841 .63113 L .58519 .63023 L F
.335 .129 .445 r
.58726 .62698 m .58662 .62799 L .58785 .62819 L F
0 .511 .808 r
.58596 .62763 m .58846 .62829 L .58785 .62819 L F
.38 .175 .471 r
.58785 .62819 m .58855 .62832 L .58975 .62657 L F
0 .511 .808 r
.58846 .62829 m .58855 .62832 L .58785 .62819 L F
.335 .129 .445 r
.58662 .62799 m .58519 .63023 L .58785 .62819 L F
0 0 0 r
.58519 .63023 m .5841 .63113 L .58785 .62819 L F
.457 .576 .885 r
.4497 .56676 m .44796 .56911 L .44787 .56821 L F
.861 .893 .857 r
.42367 .58468 m .42498 .58575 L .42771 .58285 L F
.683 .976 .9 r
.66819 .40199 m .66919 .40216 L .66684 .40372 L F
.655 .932 .97 r
.66819 .40199 m .66684 .40372 L .66591 .40314 L F
.727 .892 .955 r
.69115 .44838 m .68927 .4503 L .68794 .44924 L F
.68794 .44924 m .68927 .4503 L .69115 .44838 L F
.41 .154 .412 r
.60801 .49037 m .60858 .48856 L .61079 .48774 L F
.532 .879 .634 r
.55005 .69687 m .55133 .69564 L .5495 .69718 L F
.55005 .69687 m .55133 .69564 L .5495 .69718 L F
.362 0 .049 r
.43024 .62923 m .43291 .62897 L .434 .6271 L F
0 0 0 r
.434 .6271 m .43474 .62783 L .43567 .62678 L F
.434 .6271 m .43291 .62897 L .43474 .62783 L F
.518 .192 .355 r
.60296 .4936 m .60309 .49198 L .60627 .49106 L F
.321 0 .061 r
.39627 .59705 m .39273 .59912 L .39382 .59728 L F
0 0 .067 r
.22057 .57399 m .21991 .57617 L .22168 .57255 L F
.133 0 0 r
.67922 .45164 m .6833 .45002 L .68251 .45036 L F
.368 .728 .989 r
.6833 .45002 m .68453 .44899 L .68251 .45036 L F
.6833 .45002 m .6855 .44999 L .68453 .44899 L F
0 0 0 r
.46732 .6266 m .46797 .62718 L .46906 .626 L F
.46732 .6266 m .46632 .62844 L .46797 .62718 L F
.843 .616 .071 r
.6385 .43308 m .6388 .43421 L .63866 .43517 L F
.183 0 .022 r
.63843 .43627 m .6388 .43421 L .64108 .43422 L F
0 0 0 r
.63866 .43517 m .6388 .43421 L .63843 .43627 L F
.733 .859 .94 r
.6385 .43308 m .6388 .43421 L .64189 .43229 L F
.199 .465 .884 r
.64108 .43422 m .6388 .43421 L .6385 .43308 L F
.976 .735 .507 r
.66921 .43855 m .66767 .44001 L .66723 .43777 L F
.66921 .43855 m .66907 .44101 L .66767 .44001 L F
.198 .588 .943 r
.23122 .81659 m .23075 .81749 L .23061 .81757 L F
.23122 .81659 m .23314 .81791 L .23075 .81749 L F
.672 .603 .771 r
.72364 .42677 m .71998 .42392 L .72354 .42454 L F
.688 .597 .748 r
.72603 .42382 m .72364 .42677 L .72354 .42454 L F
.611 .485 .684 r
.72603 .42382 m .72532 .42778 L .72364 .42677 L F
.777 .425 .389 r
.72748 .4298 m .72364 .42677 L .72532 .42778 L F
.72748 .4298 m .72207 .42974 L .72364 .42677 L F
.487 .346 .615 r
.23336 .61141 m .23154 .61442 L .23229 .61223 L F
0 .415 .79 r
.23588 .5461 m .23739 .5466 L .23907 .54757 L F
.232 .628 .957 r
.23948 .54655 m .23907 .54757 L .23739 .5466 L F
.23948 .54655 m .24125 .54788 L .23907 .54757 L F
.706 .846 .949 r
.68026 .42617 m .68354 .42597 L .68306 .42447 L F
.68026 .42617 m .68354 .42597 L .68306 .42447 L F
.86 .91 .865 r
.68634 .42323 m .68354 .42597 L .68306 .42447 L F
.274 .554 .928 r
.68354 .42597 m .68531 .42516 L .68306 .42447 L F
.68354 .42597 m .68634 .4268 L .68531 .42516 L F
.875 .842 .809 r
.57161 .4713 m .56797 .47311 L .57056 .47043 L F
.57161 .4713 m .5694 .47434 L .56797 .47311 L F
.884 .928 .845 r
.57161 .4713 m .57298 .46749 L .57403 .46842 L F
.57161 .4713 m .57056 .47043 L .57298 .46749 L F
.707 .968 .731 r
.63973 .45276 m .64146 .4531 L .64009 .45158 L F
0 .131 .679 r
.64146 .4531 m .64202 .45224 L .64009 .45158 L F
0 0 .505 r
.63957 .45039 m .64027 .45168 L .64009 .45158 L F
0 0 0 r
.64111 .45103 m .64009 .45158 L .64202 .45224 L F
0 .09 .62 r
.64009 .45158 m .64074 .45255 L .64111 .45103 L F
0 0 .505 r
.64027 .45168 m .64074 .45255 L .64009 .45158 L F
.56 .745 .963 r
.64111 .45103 m .64074 .45255 L .64013 .45207 L F
0 0 0 r
.64111 .45103 m .64042 .45176 L .64009 .45158 L F
.707 .968 .731 r
.64046 .45373 m .64146 .4531 L .63973 .45276 L F
.687 .728 .215 r
.63973 .45276 m .63937 .45388 L .63919 .45453 L F
.64009 .45158 m .63984 .45238 L .63973 .45276 L F
.63984 .45238 m .63937 .45388 L .63973 .45276 L F
0 0 0 r
.64027 .45168 m .63937 .45388 L .64009 .45158 L F
.938 .656 .481 r
.64013 .45207 m .64074 .45255 L .64027 .45168 L F
0 0 0 r
.6406 .45186 m .6396 .4535 L .64027 .45168 L F
.707 .968 .731 r
.63919 .45453 m .64046 .45373 L .63973 .45276 L F
0 0 0 r
.6396 .4535 m .63937 .45388 L .64027 .45168 L F
.938 .656 .481 r
.6374 .44999 m .64013 .45207 L .63957 .45039 L F
.64013 .45207 m .64027 .45168 L .63957 .45039 L F
.56 .745 .963 r
.64111 .45103 m .64013 .45207 L .63996 .45195 L F
.64028 .45087 m .63996 .45195 L .63797 .45042 L F
.64111 .45103 m .63996 .45195 L .64028 .45087 L F
0 0 0 r
.64111 .45103 m .6406 .45186 L .64042 .45176 L F
.56 .745 .963 r
.63771 .45007 m .63797 .45042 L .6374 .44999 L F
.64111 .45103 m .63797 .45042 L .63771 .45007 L F
0 .131 .679 r
.64146 .4531 m .64346 .45558 L .64202 .45224 L F
.522 .353 .593 r
.5202 .68563 m .52251 .68501 L .52251 .6822 L F
.674 .51 .655 r
.57544 .50599 m .57645 .50966 L .57305 .509 L F
.499 .262 .486 r
.57904 .50614 m .57645 .50966 L .57544 .50599 L F
.701 .8 .927 r
.68516 .42178 m .68634 .42323 L .6836 .42237 L F
.86 .91 .865 r
.68634 .42323 m .68306 .42447 L .6836 .42237 L F
.535 .73 .964 r
.68859 .42275 m .68634 .42323 L .68516 .42178 L F
.554 .383 .604 r
.52625 .68516 m .52846 .68214 L .52494 .68226 L F
.52625 .68516 m .52856 .68489 L .52846 .68214 L F
.89 .961 .836 r
.56401 .48231 m .56063 .48436 L .563 .48138 L F
.499 .262 .486 r
.57904 .50614 m .57871 .50836 L .57645 .50966 L F
.558 .234 .376 r
.57904 .50614 m .5815 .50761 L .57871 .50836 L F
.57904 .50614 m .58151 .50607 L .5815 .50761 L F
.609 .201 .244 r
.35451 .62251 m .35318 .62083 L .35305 .62369 L F
.35451 .62251 m .35717 .62285 L .35318 .62083 L F
.711 .27 .201 r
.43293 .56978 m .43545 .57102 L .43687 .57075 L F
.428 .523 .853 r
.58726 .62698 m .58735 .6231 L .58533 .62373 L F
.58726 .62698 m .58975 .62657 L .58735 .6231 L F
.354 .137 .44 r
.58726 .62698 m .58785 .62819 L .58975 .62657 L F
.663 .533 .696 r
.70473 .45301 m .70245 .45618 L .7018 .45377 L F
.178 0 0 r
.39236 .58217 m .39452 .58168 L .39594 .58025 L F
.279 0 0 r
.39452 .58168 m .3988 .57977 L .39594 .58025 L F
.805 .872 .896 r
.55059 .63058 m .54827 .63256 L .54699 .63138 L F
0 .453 .864 r
.54699 .63138 m .54827 .63256 L .55105 .63356 L F
.409 .171 .439 r
.24243 .59391 m .23983 .59677 L .2403 .59457 L F
.606 .395 .569 r
.7157 .44725 m .71596 .45031 L .71316 .4504 L F
.713 .475 .563 r
.71873 .44829 m .7157 .44725 L .71864 .44682 L F
.71873 .44829 m .71596 .45031 L .7157 .44725 L F
.637 .355 .474 r
.50546 .69663 m .50959 .69426 L .50783 .69398 L F
.48 .807 1 r
.20035 .54146 m .20223 .541 L .20412 .54193 L F
.014 .566 .824 r
.20223 .541 m .20613 .54183 L .20412 .54193 L F
.053 0 0 r
.61962 .48266 m .62074 .48318 L .61861 .4842 L F
.61962 .48266 m .62188 .48179 L .62074 .48318 L F
.518 .261 .464 r
.48305 .61732 m .48599 .6147 L .48356 .61536 L F
.914 .625 .482 r
.58683 .61027 m .58859 .60913 L .58548 .60824 L F
.58683 .61027 m .58869 .61114 L .58859 .60913 L F
.882 .93 .848 r
.57403 .46842 m .57543 .46447 L .57662 .46559 L F
.57403 .46842 m .57298 .46749 L .57543 .46447 L F
.469 .074 .207 r
.52503 .69456 m .52154 .69683 L .52204 .69452 L F
.52503 .69456 m .52382 .69665 L .52154 .69683 L F
.475 .079 .21 r
.52696 .69595 m .52503 .69456 L .52654 .69529 L F
.52696 .69595 m .52382 .69665 L .52503 .69456 L F
.857 .895 .862 r
.60353 .43609 m .59985 .43774 L .60242 .435 L F
.859 .905 .864 r
.60616 .43318 m .60353 .43609 L .60242 .435 L F
.907 .873 .792 r
.5694 .47434 m .56709 .47485 L .56797 .47311 L F
.206 .436 .862 r
.42663 .58087 m .42771 .58285 L .42816 .58115 L F
.797 .749 .809 r
.65123 .45923 m .65189 .46219 L .65445 .45965 L F
.688 .9 .972 r
.43072 .57064 m .42721 .571 L .4294 .57001 L F
.776 .943 .933 r
.43072 .57064 m .43103 .56847 L .43293 .56978 L F
.43072 .57064 m .4294 .57001 L .43103 .56847 L F
.529 .626 .892 r
.43302 .5859 m .43512 .58904 L .43139 .58618 L F
.775 .268 0 r
.43139 .58618 m .43512 .58904 L .43318 .58835 L F
.553 .638 .889 r
.43644 .58725 m .43512 .58904 L .43302 .5859 L F
.324 0 0 r
.43644 .58725 m .43318 .58835 L .43512 .58904 L F
.289 .637 .965 r
.23122 .81659 m .23074 .81769 L .23061 .81757 L F
.23122 .81659 m .23314 .81791 L .23074 .81769 L F
.629 .574 .774 r
.35515 .61812 m .35843 .62073 L .35708 .61818 L F
.252 .758 .878 r
.19988 .55225 m .19731 .55217 L .19732 .55263 L F
.482 .895 .798 r
.19731 .55217 m .19456 .55351 L .19732 .55263 L F
.986 .74 .472 r
.55526 .67446 m .55634 .67368 L .55539 .67286 L F
.55526 .67446 m .55623 .67569 L .55634 .67368 L F
.475 .349 .629 r
.34979 .60592 m .35182 .60539 L .3516 .60285 L F
.438 .354 .664 r
.35016 .60925 m .35182 .60539 L .34979 .60592 L F
.616 .524 .728 r
.69211 .43612 m .69365 .43177 L .69125 .43274 L F
.69211 .43612 m .69499 .43577 L .69365 .43177 L F
.611 .488 .688 r
.69211 .43612 m .6925 .43854 L .69499 .43577 L F
.885 .831 .788 r
.55943 .48851 m .55587 .49032 L .558 .48724 L F
.55943 .48851 m .55732 .49155 L .55587 .49032 L F
.399 .157 .427 r
.49016 .61723 m .48983 .62031 L .48748 .62022 L F
.349 .067 .336 r
.48899 .62216 m .48748 .62022 L .48983 .62031 L F
.48899 .62216 m .48692 .62296 L .48748 .62022 L F
.818 .704 .739 r
.6782 .41435 m .67897 .41811 L .67544 .41864 L F
.908 .955 .814 r
.60604 .45236 m .60895 .44997 L .60851 .44945 L F
.317 .805 .862 r
.48599 .6147 m .48782 .61418 L .48946 .61417 L F
.461 .112 .287 r
.72146 .44457 m .72369 .44546 L .72114 .44617 L F
.72146 .44457 m .72406 .44415 L .72369 .44546 L F
.567 .393 .605 r
.72382 .44155 m .72406 .44415 L .72146 .44457 L F
.772 .669 .749 r
.5471 .51463 m .54938 .51179 L .55052 .51655 L F
.5471 .51463 m .55052 .51655 L .54936 .51745 L F
.628 .601 .804 r
.55052 .51655 m .55332 .5151 L .55394 .5178 L F
.598 .906 .983 r
.67736 .41166 m .68019 .41056 L .67893 .41007 L F
.05 .102 .597 r
.67934 .41273 m .67736 .41166 L .67893 .41007 L F
.663 .631 .807 r
.6748 .40768 m .67821 .41268 L .67851 .41162 L F
.67853 .40984 m .67851 .41162 L .67893 .41007 L F
.6748 .40768 m .67851 .41162 L .67853 .40984 L F
.05 .102 .597 r
.6785 .41227 m .6782 .41435 L .67736 .41166 L F
.67934 .41273 m .67847 .41396 L .6785 .41227 L F
.67847 .41396 m .6782 .41435 L .6785 .41227 L F
.72 .67 .8 r
.72835 .4213 m .72973 .42439 L .72603 .42382 L F
.895 .766 .712 r
.55196 .66363 m .55473 .66192 L .55068 .66175 L F
.55196 .66363 m .55321 .66511 L .55473 .66192 L F
.166 .687 .881 r
.28622 .75263 m .29002 .75298 L .28854 .75261 L F
.28622 .75263 m .29002 .75298 L .28854 .75261 L F
.55 .9 .976 r
.28854 .75261 m .29002 .75298 L .29061 .75181 L F
.29061 .75181 m .29002 .75298 L .28854 .75261 L F
.086 0 0 r
.17661 .55592 m .17465 .55747 L .17254 .55808 L F
.52 .096 .175 r
.17875 .55569 m .17465 .55747 L .17661 .55592 L F
.821 .623 .634 r
.53596 .64622 m .53697 .64814 L .53841 .64689 L F
.563 .739 .959 r
.47843 .72301 m .47696 .72394 L .47549 .72235 L F
.995 .792 .521 r
.47629 .72614 m .47696 .72394 L .47843 .72301 L F
.438 .354 .664 r
.35016 .60925 m .35219 .60897 L .35182 .60539 L F
.547 .435 .678 r
.35016 .60925 m .35307 .61116 L .35219 .60897 L F
.35016 .60925 m .35069 .61173 L .35307 .61116 L F
.397 .225 .528 r
.25091 .56176 m .25082 .56439 L .24894 .56498 L F
.462 .406 .709 r
.25082 .56439 m .25143 .56697 L .24894 .56498 L F
.891 .988 .74 r
.1982 .6268 m .19617 .6298 L .19606 .62815 L F
.348 .403 .777 r
.19479 .63163 m .19606 .62815 L .19617 .6298 L F
0 0 0 r
.68612 .46066 m .68658 .46005 L .68554 .46128 L F
.385 0 0 r
.68693 .4596 m .68658 .46005 L .68813 .45957 L F
.607 .945 .932 r
.68897 .45881 m .68658 .46005 L .68813 .4585 L F
0 0 0 r
.68813 .4585 m .68658 .46005 L .68612 .46066 L F
.385 0 0 r
.68454 .45965 m .68658 .46005 L .68693 .4596 L F
.436 .866 .758 r
.68813 .45957 m .68897 .45881 L .6903 .45832 L F
.68813 .45957 m .68658 .46005 L .68897 .45881 L F
.606 .586 .804 r
.49143 .61417 m .4924 .6165 L .49016 .61723 L F
.091 0 .158 r
.4924 .6165 m .48983 .62031 L .49016 .61723 L F
.481 .217 .436 r
.19285 .63286 m .19463 .63437 L .19479 .63163 L F
.348 .403 .777 r
.19479 .63163 m .19714 .63097 L .19606 .62815 L F
.294 .018 .313 r
.19479 .63163 m .19666 .63338 L .19714 .63097 L F
.19479 .63163 m .19463 .63437 L .19666 .63338 L F
.605 .095 0 r
.43705 .62827 m .43795 .629 L .43567 .62678 L F
.713 .246 .141 r
.4382 .63106 m .43795 .629 L .43705 .62827 L F
.4382 .63106 m .43973 .63005 L .43795 .629 L F
.772 .622 .694 r
.69961 .42955 m .7032 .43292 L .70214 .42888 L F
.69961 .42955 m .70157 .4329 L .7032 .43292 L F
.663 .403 .516 r
.70112 .43521 m .7032 .43292 L .70157 .4329 L F
.70112 .43521 m .70324 .43507 L .7032 .43292 L F
.648 .609 .796 r
.70214 .42888 m .7032 .43292 L .70573 .42982 L F
.648 .391 .516 r
.7032 .43292 m .70324 .43507 L .70858 .43352 L F
.983 .738 .34 r
.58566 .63547 m .58485 .63478 L .58204 .6354 L F
.58566 .63547 m .58568 .63795 L .58485 .63478 L F
.896 .973 .82 r
.58748 .63118 m .58566 .63547 L .58738 .63425 L F
.58748 .63118 m .58485 .63478 L .58566 .63547 L F
.983 .738 .34 r
.58485 .63478 m .58568 .63795 L .58566 .63547 L F
.394 .224 .53 r
.24641 .58227 m .24603 .58507 L .24413 .58562 L F
.411 .279 .589 r
.24597 .58744 m .24413 .58562 L .24603 .58507 L F
.24597 .58744 m .24427 .58812 L .24413 .58562 L F
.55 .575 .833 r
.19649 .62318 m .1982 .6268 L .20017 .6261 L F
.71 .411 .468 r
.19606 .62815 m .20017 .6261 L .1982 .6268 L F
.741 .661 .771 r
.65268 .45626 m .65642 .45858 L .65589 .45554 L F
.65268 .45626 m .65445 .45965 L .65642 .45858 L F
.794 .827 .877 r
.65589 .45554 m .65642 .45858 L .65901 .45557 L F
.848 .756 .761 r
.67692 .44053 m .68105 .43822 L .67934 .43757 L F
.67692 .44053 m .67889 .4418 L .68105 .43822 L F
.56 .397 .617 r
.52856 .68489 m .53167 .68221 L .52846 .68214 L F
.56 .214 .338 r
.51651 .69696 m .51562 .69957 L .51306 .69931 L F
.42 .081 .282 r
.51799 .69892 m .51651 .69696 L .51901 .69662 L F
.519 .068 .121 r
.51859 .69757 m .52028 .6985 L .51799 .69892 L F
.51901 .69662 m .51942 .69721 L .51859 .69757 L F
.51942 .69721 m .51912 .69744 L .51859 .69757 L F
.764 .566 .63 r
.5144 .69638 m .51913 .69744 L .51777 .69395 L F
.51913 .69744 m .51914 .69744 L .51913 .69743 L F
.51913 .69744 m .51913 .69743 L .51777 .69395 L F
.519 .068 .121 r
.51901 .69662 m .52154 .69683 L .52107 .69745 L F
.51901 .69662 m .52107 .69745 L .52056 .69744 L F
.51901 .69662 m .52093 .69764 L .51952 .69737 L F
.41 0 .057 r
.52154 .69683 m .52377 .69768 L .52028 .6985 L F
.54 .452 .705 r
.51954 .69738 m .52321 .69735 L .52251 .69692 L F
.5198 .69743 m .52321 .69735 L .51954 .69738 L F
.519 .068 .121 r
.51942 .69721 m .51951 .69735 L .5192 .69742 L F
.51942 .69721 m .5192 .69742 L .51913 .69743 L F
.41 0 .061 r
.52382 .69665 m .52377 .69768 L .52154 .69683 L F
.54 .452 .705 r
.51913 .69743 m .52251 .69692 L .51777 .69395 L F
.51914 .69744 m .52251 .69692 L .51913 .69743 L F
.699 .233 .14 r
.51777 .69395 m .52321 .69735 L .52204 .69452 L F
.657 .315 0 r
.52204 .69452 m .52321 .69735 L .52217 .69486 L F
.862 .713 .695 r
.52217 .69486 m .52321 .69735 L .51896 .69684 L F
.539 .242 .411 r
.52143 .69687 m .52391 .69456 L .52217 .69486 L F
.52129 .69722 m .52167 .69684 L .52143 .69687 L F
.52167 .69684 m .52391 .69456 L .52143 .69687 L F
.17 .692 .877 r
.5193 .69708 m .52321 .69735 L .5198 .69743 L F
.51896 .69684 m .52019 .69699 L .5193 .69708 L F
.52019 .69699 m .52321 .69735 L .5193 .69708 L F
.54 .452 .705 r
.51914 .69744 m .5198 .69743 L .51954 .69738 L F
.519 .068 .121 r
.51913 .69743 m .5192 .69742 L .51914 .69744 L F
.327 .131 .455 r
.5144 .69638 m .51633 .69749 L .51913 .69744 L F
.51913 .69744 m .51913 .69744 L .51914 .69744 L F
.5144 .69638 m .51913 .69744 L .51913 .69744 L F
.519 .068 .121 r
.51913 .69744 m .51913 .69744 L .51912 .69744 L F
.51913 .69744 m .51914 .69744 L .51913 .69744 L F
.51913 .69744 m .51913 .69744 L .51912 .69744 L F
.51913 .69743 m .51914 .69744 L .51913 .69744 L F
.17 .692 .877 r
.51914 .69744 m .5198 .69743 L .51914 .69744 L F
.51956 .69742 m .5198 .69743 L .51914 .69744 L F
.51914 .69744 m .51914 .69744 L .51913 .69744 L F
.519 .068 .121 r
.51951 .69735 m .52028 .6985 L .51859 .69757 L F
.17 .692 .877 r
.51913 .69741 m .51956 .69742 L .51914 .69744 L F
.51896 .69684 m .5198 .69743 L .51913 .69741 L F
.519 .068 .121 r
.52056 .69744 m .52107 .69745 L .52093 .69764 L F
.51952 .69737 m .52093 .69764 L .52028 .6985 L F
.17 .692 .877 r
.51913 .69741 m .51914 .69744 L .519 .69744 L F
.51914 .69744 m .51913 .69744 L .519 .69744 L F
.51896 .69684 m .51913 .69741 L .51633 .69749 L F
.51913 .69741 m .519 .69744 L .51633 .69749 L F
.42 .081 .282 r
.51799 .69892 m .51562 .69957 L .51611 .69815 L F
.5172 .69788 m .51611 .69815 L .51651 .69696 L F
.51799 .69892 m .51611 .69815 L .5172 .69788 L F
.948 .767 .624 r
.54969 .65818 m .55068 .66175 L .55128 .659 L F
.766 .671 .758 r
.65245 .4579 m .65445 .45965 L .65268 .45626 L F
.797 .749 .809 r
.65123 .45923 m .65445 .45965 L .65245 .4579 L F
.451 .556 .871 r
.49015 .70419 m .49149 .70159 L .48896 .70225 L F
.49015 .70419 m .49345 .70528 L .49149 .70159 L F
.542 .839 .999 r
.567 .64225 m .56671 .64049 L .56371 .64128 L F
.77 .953 .933 r
.6398 .46703 m .64362 .46569 L .6414 .46189 L F
.703 .681 .826 r
.6414 .46189 m .64362 .46569 L .64558 .46461 L F
.627 .661 .863 r
.7314 .43227 m .72748 .4298 L .73095 .43042 L F
.73 .648 .768 r
.73332 .4296 m .7314 .43227 L .73095 .43042 L F
.823 .949 .903 r
.73267 .42946 m .73038 .43124 L .7314 .43227 L F
.73178 .43143 m .7314 .43227 L .73205 .43137 L F
.701 .167 0 r
.73038 .43124 m .73342 .43273 L .7314 .43227 L F
.73111 .4316 m .73263 .43325 L .73342 .43273 L F
.73038 .43124 m .73085 .43166 L .73111 .4316 L F
.73085 .43166 m .73263 .43325 L .73111 .4316 L F
.823 .949 .903 r
.73267 .42946 m .73178 .43143 L .73332 .4296 L F
.73178 .43143 m .73205 .43137 L .73332 .4296 L F
.94 .771 .303 r
.67409 .43089 m .67433 .43487 L .67391 .43252 L F
.415 .82 .98 r
.50994 .72579 m .50885 .7253 L .5075 .72615 L F
.50994 .72579 m .50885 .7253 L .5075 .72615 L F
.813 .637 .663 r
.51777 .69395 m .52204 .69452 L .52147 .69228 L F
.852 .972 .871 r
.52204 .69452 m .52424 .69179 L .52147 .69228 L F
.788 .568 .602 r
.57926 .60856 m .58017 .60636 L .57576 .60517 L F
.878 .844 .807 r
.21937 .58531 m .21805 .58143 L .21849 .5828 L F
.303 0 .199 r
.69962 .46095 m .69741 .46176 L .70021 .45952 L F
.11 0 0 r
.70263 .45889 m .69962 .46095 L .70021 .45952 L F
0 0 0 r
.43285 .57765 m .43231 .57764 L .4349 .57674 L F
.43285 .57765 m .4303 .57821 L .43231 .57764 L F
.595 .721 .932 r
.44465 .57318 m .44845 .57688 L .44995 .57516 L F
.577 .899 .984 r
.23683 .81767 m .23314 .81791 L .23577 .81757 L F
.682 .559 .71 r
.70461 .455 m .70245 .45618 L .70473 .45301 L F
.488 .302 .555 r
.70506 .45795 m .70245 .45618 L .70461 .455 L F
.70506 .45795 m .70263 .45889 L .70245 .45618 L F
.378 .535 .885 r
.35843 .62073 m .36005 .61949 L .35708 .61818 L F
.741 .362 .334 r
.35843 .62073 m .36134 .62312 L .36005 .61949 L F
.35843 .62073 m .35766 .62271 L .36134 .62312 L F
.715 .907 .963 r
.21765 .56219 m .21864 .56001 L .21908 .5587 L F
.21765 .56219 m .21598 .56141 L .21864 .56001 L F
.507 .666 .934 r
.21765 .56219 m .21864 .56001 L .21598 .56141 L F
.21765 .56219 m .21957 .56208 L .21864 .56001 L F
.096 0 .3 r
.19126 .63544 m .19249 .63497 L .19285 .63286 L F
.54 .363 .59 r
.19012 .63767 m .19126 .63544 L .19091 .63609 L F
.627 .419 .58 r
.58626 .5002 m .58385 .50288 L .58382 .50036 L F
.595 .309 .452 r
.54296 .66696 m .54628 .6674 L .54656 .66516 L F
.951 .663 .454 r
.54656 .66516 m .54628 .6674 L .54503 .66427 L F
.237 .656 .96 r
.62856 .44079 m .63181 .44174 L .63129 .44025 L F
.626 .58 .782 r
.63181 .44174 m .63355 .43774 L .63129 .44025 L F
.63181 .44174 m .63499 .44042 L .63355 .43774 L F
.911 .642 .145 r
.63181 .44174 m .63386 .44101 L .6339 .44087 L F
.63181 .44174 m .63224 .4444 L .63161 .44311 L F
.63181 .44174 m .63161 .44311 L .63386 .44101 L F
.849 .984 .861 r
.6323 .44067 m .63386 .44101 L .63161 .44311 L F
.402 0 0 r
.63379 .44125 m .63386 .44101 L .6323 .44067 L F
.741 .419 .437 r
.63656 .44249 m .63499 .44042 L .63386 .44101 L F
.63656 .44249 m .63641 .44241 L .6364 .44226 L F
.63641 .44241 m .63386 .44101 L .6364 .44226 L F
.63656 .44249 m .63708 .44101 L .63499 .44042 L F
.402 0 0 r
.6364 .44226 m .63386 .44101 L .63379 .44125 L F
.911 .642 .145 r
.6339 .44087 m .63386 .44101 L .63499 .44042 L F
.402 0 0 r
.6364 .44226 m .6323 .44067 L .63696 .441 L F
0 0 .299 r
.63738 .44007 m .6364 .44226 L .63703 .441 L F
.402 0 0 r
.6364 .44226 m .63696 .441 L .63703 .441 L F
.661 .792 .944 r
.63738 .44007 m .63703 .441 L .63697 .44097 L F
.63738 .44007 m .63697 .44097 L .63372 .43946 L F
.682 .81 .358 r
.63724 .44035 m .63699 .44093 L .63738 .44007 L F
.63699 .44093 m .6364 .44226 L .63738 .44007 L F
.6364 .44209 m .6364 .44226 L .63724 .44035 L F
.948 .957 .681 r
.63448 .44501 m .63656 .44249 L .6364 .44226 L F
0 0 0 r
.63575 .44342 m .63448 .44501 L .63485 .44448 L F
.63575 .44342 m .63485 .44448 L .6364 .44226 L F
.682 .81 .358 r
.63575 .44342 m .6364 .44226 L .6364 .44209 L F
.409 .732 .991 r
.63372 .43946 m .63703 .441 L .6323 .44067 L F
.938 .928 .77 r
.63532 .4405 m .63575 .44342 L .63738 .44007 L F
.159 .365 .817 r
.63532 .4405 m .63643 .44261 L .63575 .44342 L F
.852 .779 .78 r
.6349 .44599 m .6387 .4442 L .63656 .44249 L F
.948 .957 .681 r
.63448 .44501 m .6349 .44599 L .63656 .44249 L F
.159 .365 .817 r
.63643 .44261 m .63741 .44444 L .63575 .44342 L F
.993 .745 .435 r
.62536 .46025 m .62678 .45954 L .62548 .45795 L F
0 0 0 r
.62927 .45875 m .62878 .45891 L .62875 .45895 L F
.613 .9 .606 r
.63087 .45706 m .62862 .45915 L .62986 .45808 L F
.62862 .45915 m .62799 .45973 L .62857 .45921 L F
.62862 .45915 m .62857 .45921 L .62986 .45808 L F
0 0 0 r
.62875 .45895 m .62678 .45954 L .62536 .46025 L F
.62878 .45891 m .62678 .45954 L .62875 .45895 L F
.492 .251 .476 r
.2255 .57006 m .22641 .57034 L .22795 .56786 L F
.51 .184 .35 r
.22445 .57266 m .22641 .57034 L .2255 .57006 L F
.64 .463 .628 r
.57119 .50884 m .56796 .51233 L .56718 .50915 L F
.852 .972 .871 r
.52204 .69452 m .52218 .69309 L .52424 .69179 L F
.657 .315 0 r
.52204 .69452 m .52217 .69486 L .52218 .69309 L F
.51 .895 .727 r
.64632 .42353 m .64274 .42562 L .6457 .42297 L F
.787 .741 .811 r
.64733 .41932 m .64632 .42353 L .6457 .42297 L F
.64733 .41932 m .64884 .42119 L .64632 .42353 L F
.615 .625 .838 r
.71181 .41707 m .71266 .41851 L .70935 .41762 L F
.616 .641 .852 r
.71044 .41335 m .70935 .41762 L .70814 .4138 L F
.71044 .41335 m .71181 .41707 L .70935 .41762 L F
0 0 0 r
.4762 .62921 m .4797 .6267 L .47839 .62842 L F
.48034 .62753 m .4797 .6267 L .48145 .6256 L F
.48034 .62753 m .47839 .62842 L .4797 .6267 L F
.787 .747 .816 r
.73698 .43256 m .7346 .43566 L .73342 .43273 L F
.627 .508 .698 r
.73698 .43256 m .73764 .43554 L .7346 .43566 L F
.487 .217 .429 r
.73764 .43554 m .73485 .43799 L .7346 .43566 L F
.501 .297 .535 r
.72642 .44111 m .72406 .44415 L .72382 .44155 L F
.156 0 0 r
.61492 .46263 m .61226 .46452 L .61537 .46518 L F
.471 .249 .494 r
.61537 .46518 m .6182 .46155 L .61492 .46263 L F
.562 .527 .773 r
.22795 .56786 m .22921 .56442 L .22731 .56477 L F
.22795 .56786 m .23006 .56744 L .22921 .56442 L F
.547 .315 .514 r
.22795 .56786 m .22989 .56949 L .23006 .56744 L F
.22795 .56786 m .22641 .57034 L .22989 .56949 L F
.514 .227 .417 r
.7079 .45288 m .70461 .455 L .70473 .45301 L F
.7079 .45288 m .70761 .45569 L .70461 .455 L F
.51 .293 .52 r
.71076 .4501 m .7079 .45288 L .70713 .45008 L F
.71076 .4501 m .71046 .45235 L .7079 .45288 L F
.458 .176 .397 r
.71046 .45235 m .70761 .45569 L .7079 .45288 L F
.605 .235 .314 r
.44208 .63127 m .44586 .6293 L .44355 .62938 L F
.95 .628 .384 r
.54505 .66211 m .54503 .66427 L .54314 .66082 L F
.699 .864 .96 r
.58365 .61419 m .58588 .6116 L .58379 .61399 L F
.772 .669 .749 r
.5471 .51463 m .54936 .51745 L .54677 .51708 L F
.727 .421 .461 r
.54936 .51745 m .54639 .51959 L .54677 .51708 L F
.54936 .51745 m .55034 .51999 L .54639 .51959 L F
.344 0 0 r
.40597 .6305 m .40832 .63058 L .40987 .62955 L F
.399 0 0 r
.40832 .63058 m .41231 .6293 L .40987 .62955 L F
0 0 0 r
.20178 .65879 m .20038 .66064 L .19912 .66148 L F
.20427 .65584 m .20319 .65814 L .20178 .65879 L F
.20163 .65976 m .20178 .65879 L .20319 .65814 L F
.20163 .65976 m .20038 .66064 L .20178 .65879 L F
.533 .157 .273 r
.44945 .6339 m .44723 .6325 L .44966 .63225 L F
.44945 .6339 m .4459 .63477 L .44723 .6325 L F
.638 .961 .805 r
.49289 .69993 m .48896 .70225 L .49149 .70159 L F
.834 .45 .326 r
.49149 .70159 m .49475 .7027 L .49289 .69993 L F
.662 .59 .764 r
.71998 .42392 m .71632 .42107 L .7189 .42038 L F
.693 .605 .754 r
.7225 .42303 m .71998 .42392 L .7189 .42038 L F
.693 .604 .753 r
.7225 .42303 m .72354 .42454 L .71998 .42392 L F
.537 .78 .988 r
.67873 .40343 m .67521 .40269 L .67765 .40235 L F
.464 .766 .996 r
.68108 .40308 m .67873 .40343 L .67765 .40235 L F
.771 .736 .821 r
.65143 .45731 m .64739 .45644 L .64984 .45415 L F
.565 .548 .794 r
.65268 .45626 m .65143 .45731 L .64984 .45415 L F
.484 .409 .696 r
.65143 .45731 m .65245 .4579 L .65268 .45626 L F
.2 .694 .92 r
.20613 .54183 m .20831 .54173 L .21012 .54244 L F
.169 .684 .891 r
.20831 .54173 m .21215 .54217 L .21012 .54244 L F
.153 0 0 r
.48083 .61805 m .48183 .61902 L .48305 .61732 L F
.48083 .61805 m .4798 .61985 L .48183 .61902 L F
.716 .53 .636 r
.57119 .50884 m .57305 .509 L .57097 .51184 L F
.706 .516 .629 r
.57305 .509 m .57314 .51207 L .57097 .51184 L F
.675 .491 .629 r
.57592 .51066 m .57305 .509 L .57645 .50966 L F
.57592 .51066 m .57314 .51207 L .57305 .509 L F
.557 .635 .884 r
.69829 .41119 m .69592 .41168 L .69456 .40876 L F
.569 .613 .856 r
.69887 .41252 m .69592 .41168 L .69829 .41119 L F
.719 .983 .902 r
.40298 .59274 m .40116 .59419 L .40223 .59436 L F
.875 .774 .747 r
.55493 .49447 m .55138 .49643 L .55334 .49325 L F
.55493 .49447 m .55311 .49764 L .55138 .49643 L F
.843 .816 .823 r
.55732 .49155 m .55493 .49447 L .55334 .49325 L F
.768 .734 .822 r
.4349 .57674 m .43566 .57959 L .43806 .57711 L F
.622 .173 .164 r
.53535 .69042 m .53196 .69077 L .53336 .69076 L F
.881 .843 .803 r
.5856 .45328 m .58201 .45513 L .58459 .4523 L F
.5856 .45328 m .58344 .45641 L .58201 .45513 L F
.85 .93 .88 r
.58829 .45055 m .5856 .45328 L .58459 .4523 L F
.279 0 0 r
.39452 .58168 m .397 .58141 L .3988 .57977 L F
.177 0 0 r
.3988 .57977 m .397 .58141 L .40003 .58031 L F
.147 0 0 r
.3988 .57977 m .40003 .58031 L .40108 .57907 L F
.364 0 .1 r
.19912 .66148 m .19773 .66359 L .19569 .66367 L F
.349 0 .091 r
.20008 .66309 m .19912 .66148 L .20038 .66064 L F
.20008 .66309 m .19773 .66359 L .19912 .66148 L F
.887 .903 .833 r
.57923 .46227 m .57662 .46559 L .57543 .46447 L F
.9 .73 .662 r
.57733 .61107 m .57907 .61516 L .57798 .61392 L F
.558 .717 .947 r
.57818 .61751 m .57798 .61392 L .57907 .61516 L F
.268 0 0 r
.36372 .59086 m .36598 .59044 L .36719 .58898 L F
.211 0 0 r
.36719 .58898 m .36823 .58979 L .36919 .58899 L F
.36719 .58898 m .36598 .59044 L .36823 .58979 L F
.657 .571 .747 r
.73794 .42366 m .73559 .42638 L .73479 .4231 L F
.615 .475 .668 r
.73963 .43185 m .73698 .43256 L .73992 .42985 L F
.771 .656 .735 r
.73848 .43035 m .73915 .42963 L .73992 .42985 L F
.612 .059 0 r
.73992 .42985 m .73952 .42973 L .73559 .42638 L F
.771 .656 .735 r
.73952 .42973 m .74091 .42771 L .73992 .42985 L F
.73937 .42939 m .74091 .42771 L .73952 .42973 L F
.434 .187 .439 r
.74252 .42918 m .73963 .43185 L .73992 .42985 L F
0 0 .382 r
.74091 .42771 m .74045 .43053 L .73992 .42985 L F
.434 .187 .439 r
.74252 .42918 m .74203 .43123 L .73963 .43185 L F
.771 .656 .735 r
.73937 .42939 m .73966 .4296 L .74091 .42771 L F
.802 .701 .754 r
.73722 .4271 m .73962 .42966 L .74091 .42771 L F
.73962 .42966 m .74045 .43053 L .74091 .42771 L F
.771 .656 .735 r
.73966 .4296 m .74203 .43123 L .74091 .42771 L F
0 .188 .697 r
.73559 .42638 m .73952 .42973 L .738 .428 L F
.612 .059 0 r
.73992 .42985 m .74045 .43053 L .73952 .42973 L F
0 .188 .697 r
.73952 .42973 m .73956 .42977 L .7395 .42971 L F
.771 .656 .735 r
.73915 .42963 m .73937 .42939 L .73952 .42973 L F
0 .188 .697 r
.73956 .42977 m .74045 .43053 L .73949 .42951 L F
.746 .992 .809 r
.73961 .42996 m .73891 .43065 L .73848 .43035 L F
.73891 .43065 m .73698 .43256 L .73848 .43035 L F
.541 0 0 r
.73736 .42998 m .73809 .43008 L .73848 .43035 L F
.746 .992 .809 r
.73992 .42985 m .73965 .4301 L .73961 .42996 L F
.73965 .4301 m .73698 .43256 L .73961 .42996 L F
.771 .656 .735 r
.73848 .43035 m .74089 .43095 L .73937 .42939 L F
.541 0 0 r
.73809 .43008 m .74077 .43046 L .73848 .43035 L F
.771 .656 .735 r
.74089 .43095 m .74203 .43123 L .73937 .42939 L F
0 .188 .697 r
.73705 .42703 m .738 .428 L .73722 .4271 L F
.73559 .42638 m .738 .428 L .73705 .42703 L F
.73952 .42973 m .7395 .42971 L .73722 .4271 L F
.73956 .42977 m .73949 .42951 L .73722 .4271 L F
.73559 .42638 m .73722 .4271 L .73518 .42844 L F
.867 .821 .801 r
.60836 .43008 m .60466 .4318 L .60713 .42914 L F
.60836 .43008 m .60616 .43318 L .60466 .4318 L F
.906 .973 .802 r
.61058 .42702 m .60836 .43008 L .60891 .42694 L F
.817 .906 .902 r
.60891 .42694 m .60836 .43008 L .60713 .42914 L F
.69 .604 .754 r
.72603 .42382 m .72354 .42454 L .7225 .42303 L F
.386 .012 .201 r
.71873 .44829 m .71571 .45162 L .71596 .45031 L F
.71873 .44829 m .71824 .45109 L .71571 .45162 L F
.31 .103 .428 r
.72114 .44617 m .71873 .44829 L .71864 .44682 L F
.72114 .44617 m .72121 .44872 L .71873 .44829 L F
.623 .374 .519 r
.72121 .44872 m .71824 .45109 L .71873 .44829 L F
.339 .126 .436 r
.35364 .59703 m .35548 .59634 L .35647 .59349 L F
.458 .233 .484 r
.35364 .59703 m .35553 .59914 L .35548 .59634 L F
.35364 .59703 m .35335 .5998 L .35553 .59914 L F
.695 .616 .764 r
.6925 .43854 m .69517 .4378 L .69499 .43577 L F
.627 .399 .553 r
.69518 .44034 m .6925 .43854 L .69278 .4409 L F
.69518 .44034 m .69517 .4378 L .6925 .43854 L F
.64 .463 .628 r
.57119 .50884 m .57097 .51184 L .56796 .51233 L F
.593 .655 .88 r
.74306 .42247 m .74186 .42605 L .74045 .42287 L F
.74306 .42247 m .74446 .42563 L .74186 .42605 L F
.622 .085 0 r
.62698 .45492 m .62527 .45372 L .62418 .45449 L F
.656 .537 .707 r
.53911 .67398 m .5416 .67341 L .54052 .6698 L F
.514 .33 .568 r
.54079 .67513 m .5416 .67341 L .53911 .67398 L F
.511 .672 .937 r
.55059 .63058 m .55319 .63062 L .55448 .63212 L F
.594 .707 .922 r
.55448 .63212 m .55319 .63062 L .55564 .62939 L F
.629 .613 .815 r
.71632 .42107 m .71266 .41851 L .71513 .41766 L F
.674 .63 .798 r
.7189 .42038 m .71632 .42107 L .71513 .41766 L F
.082 0 .176 r
.20579 .65505 m .20427 .65584 L .20661 .65285 L F
0 0 0 r
.20456 .65706 m .20427 .65584 L .20579 .65505 L F
.20456 .65706 m .20319 .65814 L .20427 .65584 L F
.693 .641 .793 r
.69382 .44441 m .69646 .44502 L .69518 .44034 L F
.645 .611 .801 r
.69518 .44034 m .69646 .44502 L .6988 .44109 L F
.78 .635 .701 r
.55232 .4998 m .55398 .50339 L .55032 .50286 L F
.775 .657 .732 r
.55032 .50286 m .55398 .50339 L .55201 .50647 L F
.35 0 0 r
.69175 .46457 m .68795 .46471 L .68916 .46438 L F
.799 .945 .92 r
.61382 .4243 m .61058 .42702 L .6117 .42428 L F
.842 .991 .854 r
.61058 .42702 m .60891 .42694 L .6117 .42428 L F
.482 .336 .605 r
.24427 .58812 m .24449 .59075 L .2423 .59124 L F
.294 .171 .536 r
.24391 .59304 m .2423 .59124 L .24449 .59075 L F
.24391 .59304 m .24243 .59391 L .2423 .59124 L F
.744 .343 .29 r
.49876 .70509 m .4972 .70262 L .49475 .7027 L F
.223 0 0 r
.40665 .59023 m .40729 .59039 L .40442 .59086 L F
.604 .318 .457 r
.40729 .59039 m .40298 .59274 L .40442 .59086 L F
.875 .745 .716 r
.64733 .41932 m .64884 .42119 L .6482 .41748 L F
.6482 .41748 m .64884 .42119 L .64733 .41932 L F
.474 .757 .992 r
.64995 .41974 m .64884 .42119 L .64733 .41932 L F
.64995 .41974 m .65117 .42105 L .64884 .42119 L F
.887 .903 .833 r
.57923 .46227 m .57543 .46447 L .57811 .46105 L F
.9 .909 .821 r
.58123 .45951 m .57923 .46227 L .57873 .45993 L F
.899 .909 .822 r
.57873 .45993 m .57923 .46227 L .57811 .46105 L F
.637 .355 .474 r
.50546 .69663 m .50939 .69647 L .50959 .69426 L F
.677 .466 .592 r
.50939 .69647 m .51187 .69377 L .50959 .69426 L F
.588 .596 .828 r
.55423 .63516 m .55565 .63862 L .5579 .638 L F
.897 .894 .817 r
.58344 .45641 m .58002 .45833 L .58201 .45513 L F
.58344 .45641 m .58123 .45951 L .58002 .45833 L F
.075 .427 .87 r
.23603 .54486 m .23588 .5461 L .23364 .5438 L F
.23603 .54486 m .23739 .5466 L .23588 .5461 L F
.644 .612 .803 r
.62856 .44079 m .63038 .43753 L .62821 .43815 L F
.62856 .44079 m .63129 .44025 L .63038 .43753 L F
.9 .909 .821 r
.58123 .45951 m .57873 .45993 L .58002 .45833 L F
.254 0 0 r
.18751 .55357 m .18296 .55433 L .18495 .55315 L F
.432 .079 .265 r
.71316 .4504 m .71046 .45235 L .71076 .4501 L F
.859 .905 .864 r
.60616 .43318 m .60242 .435 L .60466 .4318 L F
.737 .684 .8 r
.68509 .41826 m .68768 .41782 L .68622 .41359 L F
.466 .434 .738 r
.68768 .41782 m .68923 .41459 L .68622 .41359 L F
.68768 .41782 m .6901 .41712 L .68923 .41459 L F
.56 .728 .953 r
.68768 .41782 m .6908 .418 L .6901 .41712 L F
.366 .166 .471 r
.70723 .45688 m .70461 .455 L .70761 .45569 L F
.70723 .45688 m .70506 .45795 L .70461 .455 L F
.106 .477 .896 r
.66984 .46195 m .67078 .46126 L .66867 .46094 L F
.66984 .46195 m .67246 .46299 L .67078 .46126 L F
.707 .626 .765 r
.58073 .6292 m .58179 .63286 L .5841 .63113 L F
.514 .339 .581 r
.58204 .6354 m .5841 .63113 L .58179 .63286 L F
.738 .645 .756 r
.57839 .63223 m .58179 .63286 L .58073 .6292 L F
.75 .55 .625 r
.57851 .63564 m .58179 .63286 L .57839 .63223 L F
.57851 .63564 m .58204 .6354 L .58179 .63286 L F
.585 .21 .297 r
.433 .63485 m .43134 .63711 L .42913 .63546 L F
.377 0 .056 r
.43513 .63503 m .43134 .63711 L .433 .63485 L F
.843 .816 .823 r
.55732 .49155 m .55334 .49325 L .55587 .49032 L F
.816 .589 .594 r
.49876 .70509 m .50302 .70582 L .50232 .70293 L F
0 .034 .557 r
.50232 .70293 m .5038 .70579 L .50302 .70582 L F
.50302 .70582 m .5038 .70579 L .50232 .70293 L F
.192 0 0 r
.64222 .43118 m .6385 .43308 L .64189 .43229 L F
.139 .07 .51 r
.64294 .42689 m .64222 .43118 L .64289 .42966 L F
0 0 0 r
.64289 .42966 m .64222 .43118 L .64189 .43229 L F
.468 .726 .982 r
.22731 .56477 m .22921 .56442 L .2277 .56286 L F
.627 .419 .58 r
.58626 .5002 m .58644 .50269 L .58385 .50288 L F
.62 .373 .522 r
.58626 .5002 m .58898 .50235 L .58644 .50269 L F
.58626 .5002 m .58936 .49984 L .58898 .50235 L F
.672 .351 .422 r
.4654 .57651 m .4639 .57907 L .46221 .57832 L F
.497 .514 .805 r
.46648 .57346 m .46765 .57623 L .4654 .57651 L F
.69 .372 .432 r
.46832 .5785 m .4654 .57651 L .46765 .57623 L F
.46832 .5785 m .4639 .57907 L .4654 .57651 L F
.57 .631 .872 r
.20142 .61525 m .20516 .6177 L .20353 .61424 L F
.619 .409 .575 r
.20258 .62027 m .20502 .62025 L .20516 .6177 L F
.565 .684 .92 r
.20516 .6177 m .20513 .6145 L .20353 .61424 L F
.20516 .6177 m .20737 .61722 L .20513 .6145 L F
.449 .267 .542 r
.20516 .6177 m .20702 .61964 L .20737 .61722 L F
.20516 .6177 m .20502 .62025 L .20702 .61964 L F
.706 .849 .423 r
.68424 .41961 m .68341 .42138 L .68509 .41826 L F
.383 .482 .837 r
.68424 .41961 m .68516 .42178 L .68341 .42138 L F
.497 .2 .391 r
.68341 .42138 m .68516 .42178 L .6836 .42237 L F
.885 .727 .681 r
.67692 .44053 m .67813 .44414 L .67889 .4418 L F
.711 .813 .928 r
.44235 .57044 m .43954 .57105 L .44226 .56765 L F
.778 .862 .912 r
.44509 .56868 m .44235 .57044 L .44226 .56765 L F
.389 .212 .517 r
.22246 .63154 m .22031 .6348 L .22043 .63221 L F
.34 .131 .443 r
.22504 .62627 m .22474 .62873 L .22286 .62932 L F
.344 .115 .416 r
.22474 .62873 m .22246 .63154 L .22286 .62932 L F
.569 .289 .452 r
.55637 .51778 m .55375 .52022 L .55394 .5178 L F
.203 0 .273 r
.20827 .65213 m .20661 .65285 L .20898 .64994 L F
.068 0 .122 r
.20827 .65213 m .20579 .65505 L .20661 .65285 L F
.518 .192 .355 r
.60296 .4936 m .60627 .49106 L .60549 .49327 L F
.341 0 .195 r
.60627 .49106 m .6077 .4924 L .60549 .49327 L F
.60627 .49106 m .60801 .49037 L .6077 .4924 L F
.397 0 .085 r
.4149 .63766 m .41328 .63971 L .41088 .63987 L F
.613 .253 .335 r
.41707 .63761 m .41328 .63971 L .4149 .63766 L F
.313 .606 .951 r
.61749 .41396 m .62062 .41475 L .61751 .41234 L F
.62062 .41475 m .62054 .41464 L .61751 .41234 L F
.345 .746 .983 r
.61933 .41373 m .62002 .41194 L .61751 .41234 L F
.62055 .41472 m .62002 .41194 L .61915 .41421 L F
.62054 .41464 m .62015 .41412 L .62002 .41194 L F
.62015 .41412 m .61922 .41289 L .61959 .41246 L F
.62015 .41412 m .61959 .41246 L .62002 .41194 L F
.313 .606 .951 r
.62071 .41477 m .62136 .41494 L .61751 .41234 L F
.345 .746 .983 r
.61915 .41421 m .61933 .41373 L .61751 .41234 L F
.029 .542 .869 r
.61992 .41502 m .62102 .41496 L .61749 .41396 L F
.62102 .41496 m .62119 .41495 L .6208 .41484 L F
.62102 .41496 m .6208 .41484 L .61749 .41396 L F
.62119 .41495 m .62071 .41477 L .62062 .41475 L F
.6208 .41484 m .62062 .41475 L .61749 .41396 L F
.62119 .41495 m .62062 .41475 L .6208 .41484 L F
.345 .746 .983 r
.62055 .41472 m .61922 .41289 L .62054 .41464 L F
.62082 .41611 m .62004 .41453 L .61915 .41421 L F
.62082 .41611 m .61751 .41234 L .62015 .41412 L F
.614 .079 0 r
.61992 .41502 m .62082 .41611 L .62136 .41494 L F
.345 .746 .983 r
.62082 .41611 m .61998 .41443 L .62055 .41472 L F
.61998 .41443 m .61922 .41289 L .62055 .41472 L F
.62082 .41611 m .61775 .41462 L .61854 .41369 L F
.61998 .41443 m .61854 .41369 L .61922 .41289 L F
.62082 .41611 m .61854 .41369 L .61998 .41443 L F
.313 .606 .951 r
.62062 .41475 m .62071 .41477 L .62054 .41464 L F
.029 .542 .869 r
.62119 .41495 m .62136 .41494 L .62071 .41477 L F
.345 .746 .983 r
.62082 .41611 m .62015 .41412 L .62136 .41494 L F
.614 .079 0 r
.61992 .41502 m .62204 .41707 L .62082 .41611 L F
.695 .612 .76 r
.68721 .43173 m .69125 .43274 L .69006 .42896 L F
.681 .635 .797 r
.69125 .43274 m .69224 .42829 L .69006 .42896 L F
.69125 .43274 m .69365 .43177 L .69224 .42829 L F
.806 .413 .308 r
.54637 .65722 m .54958 .65678 L .54662 .65509 L F
.54637 .65722 m .54969 .65818 L .54958 .65678 L F
.693 .641 .793 r
.69382 .44441 m .69518 .44034 L .69278 .4409 L F
.598 .682 .9 r
.70691 .41077 m .70557 .41445 L .70407 .41161 L F
.70691 .41077 m .70814 .4138 L .70557 .41445 L F
.735 .378 .374 r
.45302 .63411 m .44966 .63225 L .45321 .63239 L F
.516 .839 .999 r
.45408 .63107 m .45321 .63239 L .45141 .62967 L F
.45408 .63107 m .45553 .63187 L .45321 .63239 L F
.646 .339 .438 r
.45321 .63239 m .45553 .63463 L .45302 .63411 L F
.538 .35 .575 r
.45553 .63187 m .45553 .63463 L .45321 .63239 L F
.901 .856 .789 r
.59033 .44731 m .58693 .44931 L .58948 .44652 L F
.59033 .44731 m .58829 .45055 L .58693 .44931 L F
.857 .965 .87 r
.59033 .44731 m .59209 .44384 L .59298 .44459 L F
.59033 .44731 m .58948 .44652 L .59209 .44384 L F
.861 .892 .857 r
.3312 .80355 m .32763 .80546 L .33003 .80335 L F
.581 .007 0 r
.33242 .805 m .3312 .80355 L .33003 .80335 L F
.33242 .805 m .33397 .80547 L .3312 .80355 L F
.249 .685 .961 r
.22157 .54247 m .22433 .54267 L .22589 .54358 L F
.197 .652 .944 r
.22433 .54267 m .22783 .54373 L .22589 .54358 L F
.705 .797 .922 r
.45743 .63086 m .45904 .63214 L .45553 .63187 L F
.48 .095 .231 r
.45904 .63214 m .45553 .63463 L .45553 .63187 L F
.45904 .63214 m .45814 .63457 L .45553 .63463 L F
.773 .863 .916 r
.45982 .62936 m .45904 .63214 L .45743 .63086 L F
.45982 .62936 m .46182 .63021 L .45904 .63214 L F
.653 .265 .298 r
.46149 .63423 m .45814 .63457 L .45904 .63214 L F
.624 .733 .925 r
.63399 .46487 m .63048 .4637 L .63272 .46374 L F
.392 .301 .632 r
.25143 .56697 m .25158 .5702 L .24977 .57056 L F
.516 .303 .529 r
.25188 .57255 m .24977 .57056 L .25158 .5702 L F
.25188 .57255 m .2497 .5732 L .24977 .57056 L F
.798 .933 .566 r
.63072 .47716 m .63279 .4737 L .63214 .4755 L F
.932 .896 .492 r
.63214 .4755 m .63279 .4737 L .63172 .47502 L F
.558 .934 .846 r
.63438 .47228 m .63279 .4737 L .63479 .47249 L F
0 0 0 r
.63172 .47502 m .63279 .4737 L .63438 .47228 L F
.805 .872 .896 r
.55059 .63058 m .54699 .63138 L .54959 .63023 L F
.211 .705 .919 r
.55088 .62999 m .55059 .63058 L .54959 .63023 L F
.55088 .62999 m .55319 .63062 L .55059 .63058 L F
.914 .958 .802 r
.43954 .57105 m .44003 .56709 L .44226 .56765 L F
.438 .875 .817 r
.62682 .4785 m .63072 .47716 L .62893 .477 L F
.833 .985 .872 r
.62893 .477 m .63072 .47716 L .63214 .4755 L F
.22 .735 .871 r
.21215 .54217 m .21411 .54193 L .21605 .54221 L F
.075 .633 .794 r
.21411 .54193 m .21819 .5421 L .21605 .54221 L F
.872 .737 .709 r
.60341 .4577 m .60661 .45591 L .60407 .45528 L F
.60341 .4577 m .60521 .45868 L .60661 .45591 L F
.015 0 .056 r
.21155 .64713 m .21054 .64915 L .20898 .64994 L F
.213 0 .327 r
.21054 .64915 m .20827 .65213 L .20898 .64994 L F
.772 .811 .883 r
.6414 .46189 m .64012 .46434 L .63912 .46267 L F
.674 .475 .608 r
.56796 .51233 m .56833 .5139 L .56471 .51473 L F
.652 .478 .636 r
.57097 .51184 m .56833 .5139 L .56796 .51233 L F
.693 .605 .754 r
.7225 .42303 m .7189 .42038 L .72152 .41966 L F
.66 .628 .807 r
.72489 .4205 m .7225 .42303 L .72152 .41966 L F
.69 .604 .754 r
.72603 .42382 m .7225 .42303 L .72489 .4205 L F
.927 .857 .752 r
.65851 .43692 m .66117 .43551 L .65778 .43473 L F
.65851 .43692 m .65956 .43855 L .66117 .43551 L F
.236 .396 .819 r
.65617 .42927 m .65883 .43083 L .65789 .43256 L F
.836 .828 .84 r
.65883 .43083 m .65778 .43473 L .65789 .43256 L F
.778 .658 .73 r
.55032 .50286 m .55201 .50647 L .54818 .50576 L F
.781 .648 .714 r
.54818 .50576 m .55201 .50647 L .55119 .50866 L F
.728 .609 .724 r
.69717 .43247 m .70157 .4329 L .69961 .42955 L F
.695 .482 .596 r
.6973 .43487 m .70157 .4329 L .69717 .43247 L F
.6973 .43487 m .70112 .43521 L .70157 .4329 L F
.481 .399 .687 r
.25255 .56003 m .25082 .56439 L .25091 .56176 L F
.984 .786 .556 r
.54631 .69158 m .54495 .69347 L .54493 .69363 L F
0 0 0 r
.54677 .69127 m .54495 .69347 L .54631 .69158 L F
.831 .623 .621 r
.54528 .69076 m .54495 .69347 L .54677 .69127 L F
.54429 .69041 m .54495 .69347 L .54528 .69076 L F
.984 .786 .556 r
.54493 .69363 m .54495 .69347 L .5446 .69412 L F
.976 .896 .542 r
.60426 .46394 m .60521 .45868 L .60493 .46112 L F
.593 .029 0 r
.60268 .4638 m .60426 .46394 L .60493 .46112 L F
.60268 .4638 m .60623 .46476 L .60426 .46394 L F
.482 .886 .944 r
.18244 .54211 m .18273 .5411 L .18439 .54164 L F
.18244 .54211 m .1803 .54195 L .18273 .5411 L F
.331 0 .137 r
.69654 .44694 m .69901 .44635 L .69981 .44431 L F
.614 .636 .849 r
.6988 .44109 m .69981 .44431 L .70159 .44313 L F
.507 .102 .207 r
.69981 .44431 m .70217 .4454 L .70159 .44313 L F
.69981 .44431 m .69901 .44635 L .70217 .4454 L F
.535 .726 .962 r
.64495 .45683 m .64739 .45644 L .64636 .45484 L F
.64495 .45683 m .64739 .45644 L .64636 .45484 L F
.804 .757 .81 r
.62536 .40915 m .62162 .40931 L .62378 .40754 L F
.62536 .40915 m .62234 .41197 L .62162 .40931 L F
0 .15 .675 r
.62378 .40754 m .62498 .41127 L .62536 .40915 L F
.595 .194 .252 r
.41519 .58779 m .4114 .58943 L .41299 .58852 L F
.61 .492 .695 r
.69517 .4378 m .6973 .43487 L .69499 .43577 L F
.69517 .4378 m .69923 .43851 L .6973 .43487 L F
.683 .525 .666 r
.69518 .44034 m .69923 .43851 L .69517 .4378 L F
.954 .831 .684 r
.6599 .44878 m .65975 .45328 L .66145 .45033 L F
.79 .713 .779 r
.50705 .69986 m .50838 .7029 L .51069 .69988 L F
.297 0 0 r
.49229 .69053 m .49468 .69051 L .49617 .68932 L F
.719 .668 .799 r
.72835 .4213 m .72603 .42382 L .72489 .4205 L F
.672 .44 .562 r
.59911 .49425 m .59739 .49713 L .59462 .49675 L F
.572 .272 .421 r
.59911 .49425 m .60029 .49585 L .59739 .49713 L F
.59911 .49425 m .60047 .49394 L .60029 .49585 L F
0 .062 .627 r
.37662 .63576 m .37783 .63769 L .37613 .63422 L F
.565 .224 .349 r
.42913 .63546 m .43134 .63711 L .42889 .63712 L F
.325 .547 .913 r
.38448 .61627 m .38612 .6163 L .38491 .61785 L F
.151 .113 .557 r
.38699 .61833 m .38491 .61785 L .38612 .6163 L F
.38699 .61833 m .38548 .62009 L .38491 .61785 L F
.973 .708 .467 r
.68376 .41709 m .68424 .41961 L .68509 .41826 L F
.737 .684 .8 r
.68509 .41826 m .68414 .4142 L .68376 .41709 L F
.68509 .41826 m .68622 .41359 L .68414 .4142 L F
.179 0 .336 r
.21306 .64623 m .21155 .64713 L .21356 .64393 L F
.292 .014 .309 r
.21306 .64623 m .21054 .64915 L .21155 .64713 L F
0 0 .488 r
.64428 .4447 m .64607 .44486 L .64607 .44249 L F
.64428 .4447 m .64496 .44681 L .64607 .44486 L F
.537 .767 .983 r
.38475 .6416 m .3855 .63981 L .38321 .6404 L F
.38475 .6416 m .38695 .64116 L .3855 .63981 L F
.485 .699 .964 r
.67246 .46299 m .67368 .46443 L .67607 .46425 L F
.855 .865 .847 r
.58748 .63118 m .58738 .63425 L .58907 .63191 L F
.46 .888 .869 r
.73518 .42844 m .73267 .42946 L .73332 .4296 L F
.351 .75 .984 r
.50994 .72579 m .51346 .72636 L .51214 .72558 L F
.50994 .72579 m .51346 .72636 L .51214 .72558 L F
.606 .436 .626 r
.54052 .6698 m .54296 .66696 L .54038 .66766 L F
.528 .413 .666 r
.5416 .67341 m .54391 .6704 L .54052 .6698 L F
.647 .639 .828 r
.71513 .41766 m .71266 .41851 L .71181 .41707 L F
.433 .278 .57 r
.23154 .61442 m .23161 .61713 L .22966 .61763 L F
.273 .111 .471 r
.23106 .61936 m .22966 .61763 L .23161 .61713 L F
.23106 .61936 m .22954 .62015 L .22966 .61763 L F
0 .274 .766 r
.6425 .46175 m .64558 .46461 L .64407 .46281 L F
.809 .804 .847 r
.64407 .46281 m .64558 .46461 L .6485 .46165 L F
.401 0 .078 r
.69741 .46176 m .69669 .46336 L .69413 .46359 L F
.244 0 .017 r
.69911 .46264 m .69741 .46176 L .69962 .46095 L F
.69911 .46264 m .69669 .46336 L .69741 .46176 L F
.46 .569 .878 r
.43406 .56721 m .43293 .56978 L .43103 .56847 L F
.43406 .56721 m .43545 .57102 L .43293 .56978 L F
.423 .224 .504 r
.38525 .60275 m .385 .60551 L .38306 .60584 L F
.485 .423 .712 r
.385 .60551 m .3838 .60869 L .38306 .60584 L F
.247 0 0 r
.19085 .55319 m .18907 .55399 L .18751 .55357 L F
.561 .023 0 r
.19241 .55428 m .18907 .55399 L .19085 .55319 L F
.488 .857 .987 r
.6705 .4009 m .66919 .40216 L .66819 .40199 L F
.6705 .4009 m .67185 .40148 L .66919 .40216 L F
.432 .079 .265 r
.71316 .4504 m .71314 .4518 L .71046 .45235 L F
.524 .149 .272 r
.71316 .4504 m .71571 .45162 L .71314 .4518 L F
.526 .144 .26 r
.71596 .45031 m .71571 .45162 L .71316 .4504 L F
.686 .53 .67 r
.6182 .46155 m .62095 .46156 L .61993 .45945 L F
.255 .314 .731 r
.61993 .45945 m .6223 .45692 L .62018 .45774 L F
.61993 .45945 m .62095 .46156 L .6223 .45692 L F
.699 .9 .969 r
.66564 .41426 m .66232 .4146 L .66425 .4129 L F
.855 .882 .857 r
.66655 .41111 m .66564 .41426 L .66425 .4129 L F
.66655 .41111 m .66834 .41153 L .66564 .41426 L F
.607 .948 .788 r
.64005 .45915 m .6382 .45987 L .63637 .46191 L F
.346 .553 .911 r
.6382 .45987 m .63912 .46267 L .63637 .46191 L F
.636 .87 .986 r
.42199 .58082 m .42362 .58183 L .42663 .58087 L F
.659 .895 .981 r
.42721 .571 m .42494 .57198 L .42278 .57142 L F
.475 .367 .652 r
.3516 .60285 m .35335 .5998 L .35117 .60039 L F
.545 .708 .947 r
.68414 .4142 m .68488 .41128 L .6828 .41052 L F
.68414 .4142 m .68622 .41359 L .68488 .41128 L F
.649 .366 .477 r
.55637 .51778 m .55967 .51721 L .55823 .51924 L F
.401 .138 .396 r
.55967 .51721 m .56228 .51477 L .5622 .5171 L F
.563 .328 .517 r
.55967 .51721 m .56214 .51933 L .55823 .51924 L F
.55967 .51721 m .5622 .5171 L .56214 .51933 L F
.706 .495 .601 r
.54296 .66696 m .54636 .67011 L .54628 .6674 L F
.54296 .66696 m .54391 .6704 L .54636 .67011 L F
.669 .531 .686 r
.73776 .42112 m .73479 .4231 L .73448 .42074 L F
.73776 .42112 m .73794 .42366 L .73479 .4231 L F
.85 .93 .88 r
.58829 .45055 m .58459 .4523 L .58693 .44931 L F
.781 .648 .714 r
.54818 .50576 m .55119 .50866 L .54777 .50823 L F
.808 .673 .715 r
.54777 .50823 m .55119 .50866 L .54938 .51179 L F
.925 .793 .696 r
.6338 .45021 m .63104 .45144 L .63256 .44933 L F
.6338 .45021 m .63235 .45297 L .63104 .45144 L F
0 .335 .804 r
.63501 .44815 m .63485 .44857 L .63379 .44722 L F
.652 .885 .533 r
.63666 .44647 m .63465 .4491 L .63485 .44857 L F
.63666 .44647 m .63485 .44857 L .6349 .44599 L F
.762 .451 .459 r
.63485 .44857 m .63666 .44647 L .6349 .44599 L F
.63485 .44857 m .63957 .45039 L .63666 .44647 L F
.938 .656 .481 r
.6374 .44999 m .63957 .45039 L .63485 .44857 L F
0 .335 .804 r
.6374 .44999 m .63485 .44857 L .63501 .44815 L F
.652 .885 .533 r
.63465 .4491 m .6338 .45021 L .63485 .44857 L F
.599 .868 .993 r
.63485 .44857 m .6338 .45021 L .63256 .44933 L F
.888 .483 .242 r
.62204 .41707 m .62397 .41837 L .62288 .41944 L F
0 0 0 r
.62288 .41944 m .62397 .41837 L .626 .41698 L F
.566 .059 0 r
.66243 .42654 m .66312 .42747 L .66146 .42523 L F
.66243 .42654 m .66422 .42848 L .66312 .42747 L F
.426 0 0 r
.39228 .62877 m .39391 .62985 L .39078 .6277 L F
0 .185 .603 r
.39482 .63041 m .39391 .62985 L .39228 .62877 L F
.39482 .63041 m .39636 .63139 L .39391 .62985 L F
.246 0 .326 r
.21103 .60302 m .21043 .60515 L .21273 .60215 L F
.586 .938 .932 r
.41051 .57696 m .41136 .57578 L .41251 .57569 L F
.41051 .57696 m .40818 .57689 L .41136 .57578 L F
.79 .713 .779 r
.50705 .69986 m .51069 .69988 L .50937 .69906 L F
.465 .77 .996 r
.24914 .55036 m .24889 .55192 L .247 .54943 L F
.24914 .55036 m .25094 .55165 L .24889 .55192 L F
.988 .817 .429 r
.63161 .44311 m .63224 .4444 L .63129 .4455 L F
.554 .323 .519 r
.72903 .4384 m .72918 .4407 L .72642 .44111 L F
.459 .253 .512 r
.73151 .43984 m .72903 .4384 L .73234 .43767 L F
.73151 .43984 m .72918 .4407 L .72903 .4384 L F
.868 .987 .835 r
.20609 .60874 m .20547 .60939 L .20264 .61074 L F
.20547 .60939 m .20237 .61261 L .20264 .61074 L F
.632 .92 .977 r
.19962 .61329 m .20063 .61168 L .20264 .61074 L F
.796 .517 .516 r
.20063 .61168 m .20074 .61164 L .20264 .61074 L F
.20074 .61164 m .20428 .61059 L .20264 .61074 L F
.868 .987 .835 r
.20609 .60874 m .20264 .61074 L .20428 .61059 L F
.528 .121 .212 r
.20428 .61059 m .2085 .60871 L .20609 .60874 L F
.553 .688 .929 r
.44998 .57651 m .45344 .57767 L .45234 .57589 L F
.589 .767 .964 r
.45344 .57767 m .45445 .57587 L .45234 .57589 L F
.45344 .57767 m .45555 .57717 L .45445 .57587 L F
.375 .191 .499 r
.22746 .62299 m .2272 .62592 L .22504 .62627 L F
.248 .008 .339 r
.2272 .62592 m .22474 .62873 L .22504 .62627 L F
.833 .911 .89 r
.57653 .63603 m .57259 .63696 L .57411 .63502 L F
.57653 .63603 m .57357 .63832 L .57259 .63696 L F
.481 .217 .436 r
.19285 .63286 m .19249 .63497 L .19463 .63437 L F
.417 .827 .975 r
.18439 .54164 m .18654 .54121 L .18839 .54169 L F
.07 .633 .761 r
.18654 .54121 m .19035 .54117 L .18839 .54169 L F
.879 .947 .588 r
.21393 .60034 m .21273 .60215 L .21426 .59855 L F
.422 .32 .633 r
.24985 .57575 m .2484 .5788 L .24804 .5763 L F
.649 .366 .477 r
.55637 .51778 m .55823 .51924 L .55638 .51979 L F
.569 .289 .452 r
.55637 .51778 m .55638 .51979 L .55375 .52022 L F
.778 .704 .782 r
.60935 .46791 m .60623 .46715 L .6083 .46856 L F
.989 .854 .614 r
.66899 .45605 m .66725 .45737 L .66811 .45494 L F
.66899 .45605 m .66833 .45862 L .66725 .45737 L F
.342 0 0 r
.41813 .62902 m .42054 .62926 L .42172 .62877 L F
.267 0 0 r
.42172 .62877 m .42258 .62962 L .42415 .62896 L F
.42172 .62877 m .42054 .62926 L .42258 .62962 L F
.539 .316 .525 r
.59204 .49708 m .59191 .49932 L .58936 .49984 L F
.583 .323 .489 r
.59204 .49708 m .5945 .49893 L .59191 .49932 L F
.59204 .49708 m .59462 .49675 L .5945 .49893 L F
.506 .193 .371 r
.60047 .49394 m .60274 .49538 L .60029 .49585 L F
.60047 .49394 m .60296 .4936 L .60274 .49538 L F
.514 .339 .581 r
.58204 .6354 m .58485 .63478 L .5841 .63113 L F
.506 .425 .699 r
.5841 .63113 m .58596 .62763 L .58785 .62819 L F
.5841 .63113 m .58748 .63118 L .58596 .62763 L F
.503 .332 .582 r
.5841 .63113 m .58485 .63478 L .58748 .63118 L F
.645 .358 .468 r
.56228 .51477 m .56472 .51677 L .5622 .5171 L F
.56228 .51477 m .56471 .51473 L .56472 .51677 L F
.513 .291 .514 r
.57871 .50836 m .57592 .51066 L .57645 .50966 L F
.514 .33 .568 r
.54079 .67513 m .54163 .67594 L .5416 .67341 L F
.5416 .67341 m .54163 .67594 L .54079 .67513 L F
.528 .413 .666 r
.5416 .67341 m .54391 .67293 L .54391 .6704 L F
.501 .319 .566 r
.5416 .67341 m .54163 .67594 L .54391 .67293 L F
.5416 .67341 m .54163 .67594 L .54391 .67293 L F
.898 .86 .795 r
.64636 .45484 m .64739 .45644 L .64984 .45415 L F
.64636 .45484 m .64739 .45644 L .64984 .45415 L F
.584 .547 .78 r
.65205 .45238 m .65268 .45626 L .64984 .45415 L F
.139 .07 .51 r
.64294 .42689 m .64289 .42966 L .64274 .42562 L F
.806 .648 .687 r
.60623 .46715 m .60882 .46442 L .60623 .46476 L F
.874 .775 .749 r
.55138 .49643 m .55311 .49764 L .55232 .4998 L F
.829 .753 .779 r
.54922 .49946 m .55138 .49643 L .55232 .4998 L F
.839 .722 .735 r
.54922 .49946 m .55232 .4998 L .55032 .50286 L F
.887 .978 .825 r
.59533 .44162 m .59298 .44459 L .59343 .44216 L F
.863 .963 .866 r
.59298 .44459 m .59209 .44384 L .59343 .44216 L F
.162 0 0 r
.36919 .58899 m .37142 .58878 L .37292 .58751 L F
.433 0 .01 r
.37142 .58878 m .37525 .58733 L .37292 .58751 L F
.471 .249 .494 r
.61537 .46518 m .61795 .46372 L .6182 .46155 L F
.452 0 0 r
.6195 .46283 m .6182 .46155 L .61795 .46372 L F
.6195 .46283 m .62095 .46156 L .6182 .46155 L F
.792 .631 .072 r
.60609 .4665 m .60623 .46476 L .60268 .4638 L F
.60609 .4665 m .60623 .46715 L .60623 .46476 L F
.354 .201 .531 r
.23516 .60791 m .23336 .61141 L .23344 .60881 L F
.783 .701 .774 r
.4349 .57674 m .43806 .57711 L .43715 .57599 L F
.659 .673 .852 r
.43715 .57599 m .43806 .57711 L .44036 .57618 L F
.615 .387 .547 r
.38761 .60496 m .38525 .60275 L .38774 .60262 L F
.38761 .60496 m .385 .60551 L .38525 .60275 L F
.537 .024 0 r
.44208 .63127 m .43973 .63005 L .4382 .63106 L F
.557 .233 .376 r
.5815 .50761 m .58151 .50607 L .58387 .50761 L F
.606 .45 .643 r
.58385 .50288 m .58413 .50578 L .58151 .50607 L F
.545 .244 .407 r
.58151 .50607 m .58413 .50578 L .58387 .50761 L F
.15 .635 .92 r
.57357 .63832 m .57497 .63789 L .57259 .63696 L F
.57357 .63832 m .57646 .63871 L .57497 .63789 L F
.787 .747 .816 r
.73698 .43256 m .73342 .43273 L .73612 .4318 L F
.715 .931 .961 r
.73698 .43256 m .73612 .4318 L .73848 .43035 L F
.538 .449 .703 r
.74003 .43476 m .73698 .43256 L .73963 .43185 L F
.74003 .43476 m .73764 .43554 L .73698 .43256 L F
.778 .862 .912 r
.44509 .56868 m .44226 .56765 L .4439 .56747 L F
.546 .719 .953 r
.44597 .56625 m .44509 .56868 L .4439 .56747 L F
.44597 .56625 m .44787 .56821 L .44509 .56868 L F
.369 .125 .408 r
.41981 .58162 m .41734 .58462 L .41757 .58222 L F
.674 .63 .798 r
.7189 .42038 m .71513 .41766 L .71763 .41688 L F
.636 .639 .836 r
.72013 .41608 m .7189 .42038 L .71763 .41688 L F
.72013 .41608 m .72152 .41966 L .7189 .42038 L F
.23 0 0 r
.37755 .58697 m .37985 .58656 L .38145 .58504 L F
.387 0 .006 r
.37985 .58656 m .3838 .58479 L .38145 .58504 L F
.503 0 0 r
.42415 .62896 m .42611 .63013 L .42788 .62889 L F
.632 .181 .161 r
.42611 .63013 m .43024 .62923 L .42788 .62889 L F
.56 .417 .643 r
.42788 .62889 m .43024 .62923 L .43018 .62643 L F
.569 .6 .845 r
.6908 .418 m .69438 .42051 L .69319 .41755 L F
.52 .917 .841 r
.69438 .42051 m .69114 .42179 L .69367 .42118 L F
.61 .672 .885 r
.69438 .42051 m .69522 .41706 L .69319 .41755 L F
.69438 .42051 m .69715 .42016 L .69522 .41706 L F
.732 .648 .766 r
.69489 .42563 m .69842 .42624 L .69702 .42152 L F
.183 0 .198 r
.6982 .42037 m .69715 .42016 L .69575 .42243 L F
.69687 .42163 m .69575 .42243 L .69536 .42305 L F
.6982 .42037 m .69575 .42243 L .69687 .42163 L F
.69945 .41919 m .69704 .42151 L .69984 .42174 L F
.68 .647 .81 r
.69842 .42624 m .69984 .42174 L .6972 .42152 L F
.69842 .42624 m .69717 .42141 L .69702 .42152 L F
.732 .648 .766 r
.69489 .42563 m .69702 .42152 L .69683 .4217 L F
.549 .272 .447 r
.69522 .4231 m .69438 .42051 L .69367 .42118 L F
.69522 .4231 m .69715 .42016 L .69438 .42051 L F
.68 .584 .741 r
.69522 .4231 m .69579 .4238 L .69634 .42269 L F
.549 .272 .447 r
.69526 .42321 m .69536 .42305 L .69522 .4231 L F
.69536 .42305 m .69715 .42016 L .69522 .4231 L F
.68 .584 .741 r
.69503 .42286 m .69522 .4231 L .69683 .4217 L F
.69522 .4231 m .69634 .42269 L .69683 .4217 L F
.69367 .42118 m .69503 .42286 L .69698 .42139 L F
.69503 .42286 m .69683 .4217 L .69698 .42139 L F
.183 0 .198 r
.69712 .42152 m .69526 .42321 L .69984 .42174 L F
.69704 .42151 m .69684 .4217 L .69712 .42152 L F
.69684 .4217 m .69526 .42321 L .69712 .42152 L F
.68 .647 .81 r
.6972 .42152 m .69984 .42174 L .69717 .42141 L F
.69702 .42152 m .69717 .42141 L .69698 .42139 L F
.732 .648 .766 r
.69683 .4217 m .69702 .42152 L .69698 .42139 L F
.183 0 .198 r
.69945 .41919 m .69938 .41922 L .6982 .42037 L F
.69938 .41922 m .69715 .42016 L .6982 .42037 L F
.69684 .4217 m .69536 .42305 L .69526 .42321 L F
.69945 .41919 m .69536 .42305 L .69684 .4217 L F
.68 .584 .741 r
.69526 .42314 m .69489 .42563 L .69579 .4238 L F
.69367 .42118 m .69442 .42391 L .69526 .42314 L F
.69442 .42391 m .69489 .42563 L .69526 .42314 L F
.549 .272 .447 r
.69526 .42321 m .69522 .4231 L .69367 .42118 L F
.138 0 0 r
.19867 .62082 m .20137 .62064 L .20258 .62027 L F
0 0 .535 r
.20269 .62009 m .20258 .62027 L .20137 .62064 L F
.611 .365 .52 r
.20258 .62027 m .20461 .6226 L .20502 .62025 L F
0 0 .535 r
.20269 .62009 m .20461 .6226 L .20258 .62027 L F
.617 .779 .959 r
.63145 .41318 m .62955 .41474 L .6278 .41185 L F
.63145 .41318 m .63201 .41476 L .62955 .41474 L F
.505 .008 .01 r
.62955 .41474 m .63098 .4161 L .6285 .41672 L F
.62955 .41474 m .63201 .41476 L .63098 .4161 L F
.424 .824 .981 r
.21799 .55479 m .2168 .5542 L .21459 .55464 L F
.21904 .55483 m .2168 .5542 L .21799 .55479 L F
.652 .155 .056 r
.22072 .55485 m .2168 .5542 L .21904 .55483 L F
.22072 .55485 m .21876 .55546 L .2168 .5542 L F
0 0 .48 r
.22072 .55485 m .21827 .55515 L .21876 .55546 L F
.21827 .55515 m .21779 .5552 L .21876 .55546 L F
.419 .264 .563 r
.22072 .55485 m .22071 .55781 L .22254 .5569 L F
0 0 .48 r
.22072 .55485 m .22119 .55533 L .21833 .55522 L F
.21827 .55515 m .2183 .55518 L .21779 .5552 L F
.356 .745 .987 r
.2168 .5542 m .21298 .55341 L .21459 .55464 L F
.2168 .5542 m .21509 .55329 L .21298 .55341 L F
.55 0 0 r
.21779 .5552 m .21509 .55329 L .2183 .55518 L F
.21779 .5552 m .2183 .55518 L .21876 .55546 L F
0 0 .48 r
.2183 .55518 m .21833 .55522 L .21779 .5552 L F
.22072 .55485 m .21833 .55522 L .21827 .55515 L F
.443 0 0 r
.21653 .55406 m .21827 .55515 L .21576 .55368 L F
.21827 .55515 m .21876 .55546 L .2183 .55518 L F
.21827 .55515 m .2183 .55518 L .21576 .55368 L F
.2168 .5542 m .21876 .55546 L .21653 .55406 L F
.2168 .5542 m .21576 .55368 L .21509 .55329 L F
.923 .975 .749 r
.21663 .58811 m .21481 .59128 L .21445 .58942 L F
.811 .799 .841 r
.21393 .59343 m .21445 .58942 L .21481 .59128 L F
.277 .08 .423 r
.21561 .6408 m .21528 .6432 L .21356 .64393 L F
.265 .044 .38 r
.21528 .6432 m .21306 .64623 L .21356 .64393 L F
.458 .28 .551 r
.24817 .58418 m .24641 .58227 L .24817 .58152 L F
.24817 .58418 m .24603 .58507 L .24641 .58227 L F
.132 .313 .78 r
.44995 .57516 m .44998 .57651 L .45084 .57513 L F
.543 .85 .998 r
.45084 .57513 m .44998 .57651 L .45234 .57589 L F
.45084 .57513 m .44998 .57651 L .45234 .57589 L F
.988 .828 .447 r
.63098 .4161 m .63201 .41476 L .63145 .41318 L F
.675 .734 .895 r
.19962 .61329 m .20142 .61525 L .20353 .61424 L F
.817 .616 .061 r
.55196 .66363 m .55237 .6674 L .55321 .66511 L F
.615 .676 .885 r
.70074 .41055 m .69887 .41252 L .69829 .41119 L F
.70074 .41055 m .70154 .41229 L .69887 .41252 L F
.586 .842 .483 r
.67833 .42447 m .6767 .42658 L .68026 .42617 L F
.201 0 0 r
.68306 .42447 m .67833 .42447 L .68026 .42617 L F
.923 .709 .595 r
.21581 .59709 m .21393 .59343 L .2144 .59414 L F
.21581 .59709 m .21424 .59732 L .21393 .59343 L F
.78 .349 .228 r
.21581 .59709 m .21442 .59831 L .21424 .59732 L F
.636 .903 .591 r
.21426 .59855 m .21442 .59831 L .21581 .59709 L F
.21426 .59855 m .21442 .59831 L .21581 .59709 L F
.607 .6 .819 r
.69207 .40932 m .68811 .40656 L .69064 .40628 L F
.576 .598 .838 r
.69317 .4057 m .69207 .40932 L .69064 .40628 L F
.69317 .4057 m .69456 .40876 L .69207 .40932 L F
.082 0 0 r
.43139 .58618 m .43163 .58673 L .43302 .5859 L F
.61 .119 0 r
.43139 .58618 m .43318 .58835 L .43163 .58673 L F
.485 .423 .712 r
.385 .60551 m .38585 .60827 L .3838 .60869 L F
.035 0 .305 r
.38585 .60827 m .38536 .60954 L .3838 .60869 L F
.482 .435 .728 r
.25379 .55264 m .2526 .55505 L .25094 .55165 L F
.25379 .55264 m .25462 .55495 L .2526 .55505 L F
.329 .127 .448 r
.2537 .55821 m .25216 .55914 L .2526 .55505 L F
.8 .371 0 r
.64618 .4325 m .64642 .43385 L .64488 .43093 L F
.64618 .4325 m .6474 .435 L .64642 .43385 L F
.357 .036 .278 r
.61383 .48673 m .61378 .48543 L .61611 .4846 L F
.944 .687 .222 r
.67028 .44717 m .66963 .44638 L .66941 .44339 L F
.969 .756 .561 r
.67028 .44717 m .66861 .44808 L .66963 .44638 L F
.67028 .44717 m .66992 .44956 L .66861 .44808 L F
.71 .683 .823 r
.696 .42914 m .69961 .42955 L .69842 .42624 L F
.733 .616 .728 r
.69717 .43247 m .69961 .42955 L .696 .42914 L F
.679 .664 .828 r
.69961 .42955 m .70092 .42541 L .69842 .42624 L F
.69961 .42955 m .70214 .42888 L .70092 .42541 L F
.519 .296 .515 r
.35548 .59634 m .35826 .59343 L .35647 .59349 L F
.475 .367 .652 r
.3516 .60285 m .35361 .6023 L .35335 .5998 L F
.519 .406 .665 r
.35182 .60539 m .35361 .6023 L .3516 .60285 L F
0 .568 .772 r
.19035 .54117 m .19214 .54126 L .19428 .54164 L F
.705 .601 .738 r
.69365 .43177 m .69717 .43247 L .696 .42914 L F
.668 .518 .673 r
.69499 .43577 m .69717 .43247 L .69365 .43177 L F
.69499 .43577 m .6973 .43487 L .69717 .43247 L F
.937 .728 .594 r
.58928 .62152 m .59136 .6254 L .59201 .62417 L F
0 0 0 r
.17018 .54409 m .17225 .54384 L .17037 .54405 L F
.516 .421 .685 r
.38272 .61252 m .38448 .61627 L .38186 .61586 L F
.908 .904 .808 r
.65966 .41541 m .65811 .41786 L .65717 .41659 L F
.995 .843 .491 r
.65811 .41786 m .65706 .41866 L .65717 .41659 L F
.65811 .41786 m .6577 .42004 L .65706 .41866 L F
.701 .632 .776 r
.7367 .41794 m .73776 .42112 L .73448 .42074 L F
.645 .6 .789 r
.74003 .4204 m .73776 .42112 L .7367 .41794 L F
.532 .425 .679 r
.74045 .42287 m .73776 .42112 L .74003 .4204 L F
.74045 .42287 m .73794 .42366 L .73776 .42112 L F
.282 .105 .455 r
.23983 .59677 m .23956 .59918 L .23807 .59984 L F
.329 .183 .527 r
.23955 .60169 m .23807 .59984 L .23956 .59918 L F
.23955 .60169 m .23754 .60323 L .23807 .59984 L F
.739 .238 .038 r
.3889 .64113 m .38752 .64202 L .38741 .6419 L F
.236 0 0 r
.38939 .64088 m .3889 .64113 L .38695 .64116 L F
.739 .238 .038 r
.3889 .64113 m .3855 .63981 L .38695 .64116 L F
.3889 .64113 m .38741 .6419 L .3855 .63981 L F
.236 0 0 r
.39061 .64074 m .3889 .64113 L .38939 .64088 L F
.465 0 .012 r
.39296 .64058 m .3889 .64113 L .39061 .64074 L F
.922 .781 .303 r
.61889 .43225 m .61899 .43173 L .61942 .43212 L F
.752 .795 .887 r
.62222 .42935 m .61942 .43212 L .619 .43137 L F
.972 .822 .635 r
.619 .43137 m .61942 .43212 L .61899 .43173 L F
.042 0 0 r
.47484 .62111 m .47203 .62296 L .47435 .62196 L F
.391 0 0 r
.47435 .62196 m .47675 .62185 L .47484 .62111 L F
.383 0 .12 r
.47484 .62111 m .47675 .62185 L .4775 .62065 L F
.265 .276 .685 r
.49345 .70528 m .49369 .70876 L .49496 .70713 L F
.083 .025 .486 r
.49496 .70713 m .49369 .70876 L .49458 .71103 L F
.136 0 0 r
.471 .6316 m .47395 .62993 L .47314 .63088 L F
.221 0 .005 r
.47395 .62993 m .47497 .63111 L .47314 .63088 L F
.47395 .62993 m .4762 .62921 L .47497 .63111 L F
.689 .849 .959 r
.6901 .41712 m .6908 .418 L .69256 .41594 L F
.552 .623 .876 r
.6908 .418 m .69319 .41755 L .69256 .41594 L F
.258 .171 .562 r
.24578 .58979 m .24427 .58812 L .24597 .58744 L F
.24578 .58979 m .24449 .59075 L .24427 .58812 L F
.531 .296 .503 r
.58936 .49984 m .59184 .50186 L .58898 .50235 L F
.58936 .49984 m .59191 .49932 L .59184 .50186 L F
.301 0 0 r
.38612 .58446 m .38847 .5842 L .39004 .58272 L F
.241 0 0 r
.38847 .5842 m .39236 .58217 L .39004 .58272 L F
.344 .261 .617 r
.35305 .62369 m .35504 .62589 L .35451 .62251 L F
.495 .288 .528 r
.58644 .50269 m .58413 .50578 L .58385 .50288 L F
.775 .915 .934 r
.55013 .68521 m .55296 .68374 L .55034 .68302 L F
.854 .896 .866 r
.55034 .68302 m .55296 .68374 L .55375 .68159 L F
.148 .439 .874 r
.45527 .56939 m .45461 .57078 L .45404 .56917 L F
.161 .331 .787 r
.38843 .62412 m .38635 .62394 L .38572 .62226 L F
.38843 .62412 m .38874 .62569 L .38635 .62394 L F
.964 .765 .586 r
.65851 .43692 m .65956 .44043 L .65956 .43855 L F
.393 .548 .89 r
.68079 .45903 m .67845 .45871 L .68002 .4571 L F
0 0 .108 r
.68002 .4571 m .67845 .45871 L .67882 .45897 L F
.784 .334 0 r
.67845 .45871 m .67644 .45595 L .67882 .45897 L F
.964 .732 .538 r
.54304 .65581 m .54179 .65519 L .54208 .65228 L F
.937 .627 .426 r
.54304 .65581 m .54193 .65747 L .54179 .65519 L F
.745 .667 .774 r
.69224 .42829 m .69365 .43177 L .696 .42914 L F
.985 .885 .643 r
.65151 .45625 m .65245 .4579 L .65268 .45626 L F
.923 .882 .776 r
.64981 .45801 m .65245 .4579 L .65151 .45625 L F
.64981 .45801 m .65123 .45923 L .65245 .4579 L F
.539 .479 .737 r
.19719 .66705 m .19945 .66696 L .19729 .66745 L F
.386 .185 .481 r
.19945 .66696 m .19719 .67002 L .19729 .66745 L F
.541 .696 .94 r
.68973 .40458 m .68811 .40656 L .68745 .40473 L F
.68973 .40458 m .69064 .40628 L .68811 .40656 L F
.34 .577 .929 r
.37313 .63322 m .37365 .63165 L .37264 .63138 L F
.37313 .63322 m .37613 .63422 L .37365 .63165 L F
.88 .952 .6 r
.6223 .45692 m .62095 .46156 L .6195 .46283 L F
.898 .731 .667 r
.67653 .44325 m .67813 .44414 L .67692 .44053 L F
.906 .541 .333 r
.67773 .44528 m .67813 .44414 L .67653 .44325 L F
.635 .22 .238 r
.67773 .44528 m .68123 .44634 L .67813 .44414 L F
.529 .574 .844 r
.19773 .66359 m .19719 .66705 L .19556 .66514 L F
.19773 .66359 m .19945 .66696 L .19719 .66705 L F
.51 .184 .35 r
.22445 .57266 m .22686 .57236 L .22641 .57034 L F
.371 .029 .249 r
.22686 .57236 m .22989 .56949 L .22641 .57034 L F
.649 .158 .071 r
.45527 .56939 m .46052 .57094 L .45691 .57274 L F
.513 .85 .996 r
.45691 .57274 m .46052 .57094 L .46176 .57207 L F
.563 .779 .979 r
.6826 .45863 m .68103 .46031 L .68079 .45903 L F
.6826 .45863 m .68454 .45965 L .68103 .46031 L F
.804 .998 .787 r
.59652 .44035 m .59533 .44162 L .59627 .43957 L F
.798 .997 .859 r
.59533 .44162 m .59343 .44216 L .59627 .43957 L F
.765 .771 .858 r
.73448 .42074 m .73076 .42058 L .73387 .42038 L F
.582 .835 .471 r
.7367 .41794 m .73448 .42074 L .73587 .41891 L F
.703 .984 .868 r
.73448 .42074 m .73387 .42038 L .73587 .41891 L F
.314 .803 .864 r
.36282 .62909 m .35944 .6295 L .36046 .62942 L F
.562 .304 .483 r
.36046 .62942 m .36235 .63125 L .36282 .62909 L F
.691 .222 .133 r
.54874 .66218 m .54897 .66221 L .54977 .66068 L F
0 .24 .756 r
.54977 .66068 m .55196 .66363 L .55068 .66175 L F
.54977 .66068 m .5522 .66269 L .55196 .66363 L F
.691 .222 .133 r
.54897 .66221 m .5522 .66269 L .54977 .66068 L F
.984 .723 .336 r
.54977 .66068 m .55068 .66175 L .55018 .65992 L F
.54977 .66068 m .55018 .65992 L .54969 .65818 L F
.479 .145 .322 r
.57309 .51359 m .57592 .51066 L .57556 .51333 L F
.57309 .51359 m .57314 .51207 L .57592 .51066 L F
.513 .291 .514 r
.57871 .50836 m .57904 .51086 L .57592 .51066 L F
.617 .355 .497 r
.57904 .51086 m .57556 .51333 L .57592 .51066 L F
.561 .212 .333 r
.56471 .51473 m .56718 .51627 L .56472 .51677 L F
.56471 .51473 m .56833 .5139 L .56718 .51627 L F
.97 .666 .383 r
.66907 .44101 m .66791 .44222 L .66767 .44001 L F
.66907 .44101 m .66941 .44339 L .66791 .44222 L F
.222 .712 .924 r
.22993 .54335 m .23364 .5438 L .23163 .54438 L F
.527 .35 .584 r
.53433 .68537 m .5369 .68189 L .53495 .68331 L F
.859 .586 .523 r
.55013 .68521 m .54746 .68467 L .54694 .68205 L F
.498 0 0 r
.55013 .68521 m .54865 .68512 L .54746 .68467 L F
.775 .915 .934 r
.55013 .68521 m .55034 .68302 L .54865 .68512 L F
.953 .824 .679 r
.55392 .67837 m .55623 .67569 L .55526 .67446 L F
.55392 .67837 m .55544 .67934 L .55623 .67569 L F
.078 .639 .759 r
.19624 .54156 m .19811 .54144 L .20035 .54146 L F
.344 .818 .89 r
.19811 .54144 m .20223 .541 L .20035 .54146 L F
.41 .154 .412 r
.60801 .49037 m .61079 .48774 L .61053 .48996 L F
.227 0 .17 r
.60801 .49037 m .61053 .48996 L .6077 .4924 L F
0 0 0 r
.58667 .6224 m .58442 .62494 L .58533 .62373 L F
.908 .904 .808 r
.65966 .41541 m .65717 .41659 L .65865 .41411 L F
.636 .781 .951 r
.66101 .41306 m .65966 .41541 L .65865 .41411 L F
.66101 .41306 m .66232 .4146 L .65966 .41541 L F
.377 0 .056 r
.43513 .63503 m .43369 .63685 L .43134 .63711 L F
.578 .183 .258 r
.43749 .63501 m .43369 .63685 L .43513 .63503 L F
.57 .66 .898 r
.68512 .40534 m .68108 .40308 L .68324 .40283 L F
.551 .677 .921 r
.68745 .40473 m .68512 .40534 L .68324 .40283 L F
.238 .475 .883 r
.37783 .63769 m .3775 .63409 L .37613 .63422 L F
.37783 .63769 m .37845 .63608 L .3775 .63409 L F
.37783 .63769 m .37911 .63777 L .37845 .63608 L F
.451 .458 .775 r
.68294 .4166 m .6782 .41435 L .68183 .41792 L F
.21 .328 .766 r
.67934 .41273 m .68183 .41792 L .6782 .41435 L F
0 .434 .798 r
.57717 .62653 m .57647 .62598 L .57427 .62512 L F
.801 .781 .834 r
.57947 .62584 m .57647 .62598 L .57717 .62653 L F
.863 .824 .808 r
.36235 .63125 m .36406 .63256 L .36642 .62918 L F
.961 .68 .457 r
.36406 .63256 m .36244 .63374 L .36235 .63125 L F
.487 .217 .429 r
.73764 .43554 m .73744 .43747 L .73485 .43799 L F
.415 .156 .409 r
.74003 .43476 m .73744 .43747 L .73764 .43554 L F
.875 .99 .814 r
.61528 .46704 m .61352 .47054 L .61208 .46905 L F
.61528 .46704 m .61598 .46759 L .61352 .47054 L F
.488 .193 .392 r
.51214 .69676 m .51586 .69317 L .51187 .69377 L F
.51214 .69676 m .5144 .69638 L .51586 .69317 L F
.764 .566 .63 r
.5144 .69638 m .51777 .69395 L .51586 .69317 L F
.538 .571 .836 r
.61226 .46452 m .61598 .46759 L .61537 .46518 L F
0 .056 .589 r
.61537 .46518 m .61648 .46519 L .61795 .46372 L F
.61537 .46518 m .61598 .46759 L .61648 .46519 L F
.948 .803 .667 r
.66803 .43555 m .66568 .43646 L .66659 .43429 L F
.66803 .43555 m .66723 .43777 L .66568 .43646 L F
.39 .157 .436 r
.23769 .60462 m .23516 .60791 L .23582 .6055 L F
.809 .804 .847 r
.64407 .46281 m .6485 .46165 L .64751 .46052 L F
.819 .925 .905 r
.64751 .46052 m .6485 .46165 L .65123 .45923 L F
.819 .807 .839 r
.58702 .61272 m .58683 .61027 L .58588 .6116 L F
.58702 .61272 m .58869 .61114 L .58683 .61027 L F
0 0 0 r
.64289 .42966 m .64189 .43229 L .64488 .43093 L F
.652 .478 .636 r
.57097 .51184 m .57075 .51432 L .56833 .5139 L F
.506 .351 .605 r
.57309 .51359 m .57075 .51432 L .57097 .51184 L F
.666 .296 .335 r
.57097 .51184 m .57314 .51207 L .57309 .51359 L F
.506 .351 .605 r
.57309 .51359 m .57075 .51432 L .57097 .51184 L F
.79 .542 .562 r
.52485 .68708 m .52856 .68489 L .52505 .68416 L F
.52485 .68708 m .52872 .68756 L .52856 .68489 L F
.773 .374 .296 r
.52505 .68416 m .52863 .686 L .52856 .68489 L F
.56 .397 .617 r
.52856 .68489 m .53076 .68486 L .53167 .68221 L F
.401 .172 .448 r
.52872 .68756 m .53076 .68486 L .52856 .68489 L F
.52872 .68756 m .53076 .68486 L .52856 .68489 L F
.537 .921 .799 r
.52863 .686 m .53076 .68486 L .52856 .68489 L F
.93 .801 .696 r
.58855 .62832 m .58748 .63118 L .58907 .63191 L F
.583 .315 .477 r
.51372 .6586 m .51605 .66063 L .51669 .65856 L F
.51669 .65856 m .51605 .66063 L .51372 .6586 L F
.641 .294 .367 r
.56833 .5139 m .56936 .516 L .56718 .51627 L F
.56833 .5139 m .57075 .51432 L .56936 .516 L F
.486 .187 .383 r
.35826 .59343 m .36063 .59305 L .36112 .59102 L F
.574 .268 .411 r
.36063 .59305 m .3632 .59287 L .36112 .59102 L F
.563 .27 .428 r
.36112 .59102 m .3632 .59287 L .36372 .59086 L F
.533 .683 .935 r
.49362 .69257 m .49468 .69051 L .49229 .69053 L F
.49362 .69257 m .49618 .69244 L .49468 .69051 L F
.347 .765 .978 r
.21091 .55364 m .20718 .55313 L .20887 .55391 L F
.558 .717 .947 r
.57818 .61751 m .58032 .61591 L .57798 .61392 L F
.57818 .61751 m .58073 .61735 L .58032 .61591 L F
.573 .831 .994 r
.57694 .60876 m .57926 .60856 L .57588 .60822 L F
.501 .297 .535 r
.72642 .44111 m .72652 .44348 L .72406 .44415 L F
.483 .238 .467 r
.72918 .4407 m .72652 .44348 L .72642 .44111 L F
.511 .255 .464 r
.50649 .70615 m .50231 .70813 L .50302 .70582 L F
0 0 .178 r
.50302 .70582 m .50378 .70709 L .5038 .70579 L F
.50302 .70582 m .50231 .70813 L .50378 .70709 L F
.511 .255 .464 r
.50649 .70615 m .50302 .70582 L .5038 .70579 L F
.507 .897 .95 r
.41892 .574 m .41475 .57461 L .41679 .57403 L F
.367 .831 .767 r
.41679 .57403 m .42082 .57263 L .41892 .574 L F
.954 .831 .684 r
.6599 .44878 m .6585 .45235 L .65975 .45328 L F
.894 .767 .715 r
.65766 .45402 m .65975 .45328 L .6585 .45235 L F
.65766 .45402 m .65901 .45557 L .65975 .45328 L F
.667 .859 .973 r
.46403 .62921 m .46182 .63021 L .45982 .62936 L F
.52 .273 .48 r
.53738 .68682 m .53982 .68121 L .5369 .68189 L F
.53738 .68682 m .53977 .68553 L .53982 .68121 L F
0 0 0 r
.53982 .68121 m .54276 .67841 L .53869 .67843 L F
.53982 .68121 m .5416 .68 L .54276 .67841 L F
.637 .521 .705 r
.53977 .68553 m .5416 .68 L .53982 .68121 L F
.557 .377 .593 r
.39273 .59912 m .39024 .60219 L .39048 .59977 L F
.988 .895 .588 r
.60899 .44459 m .61027 .44396 L .60999 .44299 L F
.60899 .44459 m .60936 .44703 L .61027 .44396 L F
.777 .967 .923 r
.61318 .44061 m .61027 .44396 L .6133 .44123 L F
.61318 .44061 m .60999 .44299 L .61027 .44396 L F
.82 .995 .762 r
.59652 .44035 m .59875 .43667 L .59985 .43774 L F
.59652 .44035 m .59627 .43957 L .59875 .43667 L F
.704 .647 .789 r
.63038 .43753 m .63129 .44025 L .63355 .43774 L F
.817 .616 .061 r
.55196 .66363 m .5521 .66668 L .55237 .6674 L F
.81 .345 .124 r
.55232 .66895 m .55237 .6674 L .5521 .66668 L F
.55232 .66895 m .55424 .66977 L .55237 .6674 L F
.809 .332 .078 r
.55237 .6674 m .55424 .66977 L .55544 .66996 L F
.962 .943 .679 r
.21663 .58811 m .21715 .58417 L .21869 .58749 L F
.21663 .58811 m .21585 .58751 L .21715 .58417 L F
.934 .966 .742 r
.21663 .58811 m .21445 .58942 L .21585 .58751 L F
.526 .359 .597 r
.57588 .60822 m .57576 .60517 L .57334 .60908 L F
.487 .346 .615 r
.23336 .61141 m .23363 .61386 L .23154 .61442 L F
.379 .236 .558 r
.23334 .61639 m .23154 .61442 L .23363 .61386 L F
.23334 .61639 m .23161 .61713 L .23154 .61442 L F
.39 .751 .992 r
.46313 .5719 m .46535 .57174 L .46476 .57287 L F
.164 .476 .895 r
.46535 .57174 m .46648 .57346 L .46476 .57287 L F
.293 .664 .972 r
.21261 .55446 m .21298 .55341 L .21091 .55364 L F
.21261 .55446 m .21459 .55464 L .21298 .55341 L F
.611 .826 .983 r
.36538 .62812 m .36282 .62909 L .36642 .62918 L F
.863 .824 .808 r
.36235 .63125 m .36642 .62918 L .36282 .62909 L F
.453 .749 .992 r
.36538 .62812 m .36642 .62918 L .36716 .62778 L F
.4 .685 .976 r
.36642 .62918 m .36818 .62897 L .36716 .62778 L F
.599 .635 .858 r
.36642 .62918 m .36961 .63047 L .36818 .62897 L F
.914 .922 .807 r
.61904 .41018 m .61744 .41234 L .61723 .41 L F
.762 .966 .929 r
.61904 .41018 m .62044 .40779 L .62162 .40931 L F
.61904 .41018 m .61723 .41 L .62044 .40779 L F
.518 .261 .464 r
.48305 .61732 m .48544 .61705 L .48599 .6147 L F
.34 .1 .397 r
.48599 .6147 m .48544 .61705 L .48782 .61418 L F
.883 .989 .805 r
.61648 .46519 m .61598 .46759 L .61528 .46704 L F
.735 .378 .374 r
.45302 .63411 m .44945 .6339 L .44966 .63225 L F
.254 0 0 r
.18751 .55357 m .18513 .5544 L .18296 .55433 L F
.246 0 0 r
.18907 .55399 m .18513 .5544 L .18751 .55357 L F
.431 .713 .983 r
.67521 .40269 m .67185 .40148 L .6741 .40149 L F
.493 .765 .992 r
.6741 .40149 m .67765 .40235 L .67521 .40269 L F
.091 0 .158 r
.49215 .61687 m .49145 .61925 L .48983 .62031 L F
.083 0 .145 r
.49145 .61925 m .48899 .62216 L .48983 .62031 L F
.257 0 .308 r
.49103 .62127 m .48899 .62216 L .49145 .61925 L F
.136 .234 .702 r
.4902 .61766 m .49096 .62094 L .49145 .61925 L F
.49096 .62094 m .49103 .62127 L .49145 .61925 L F
.091 0 .158 r
.4924 .6165 m .49145 .61925 L .49215 .61687 L F
.94 .935 .585 r
.49485 .61577 m .49469 .61616 L .49512 .61716 L F
0 .533 .834 r
.49464 .61669 m .4924 .6165 L .49143 .61417 L F
.49463 .61679 m .4924 .6165 L .49464 .61669 L F
.49463 .61679 m .49512 .61716 L .4924 .6165 L F
.14 0 0 r
.49512 .61716 m .49145 .61925 L .4924 .6165 L F
.49512 .61716 m .49368 .61866 L .49145 .61925 L F
.94 .935 .585 r
.49469 .61616 m .49454 .61776 L .49512 .61716 L F
0 .533 .834 r
.49479 .61681 m .49512 .61716 L .49463 .61679 L F
.94 .935 .585 r
.49463 .61679 m .49368 .61866 L .49454 .61776 L F
.49467 .61634 m .49455 .61673 L .49463 .61679 L F
.828 .76 .788 r
.49485 .61577 m .49479 .61681 L .49457 .61667 L F
.533 0 0 r
.49236 .61525 m .49479 .61681 L .49143 .61417 L F
.828 .76 .788 r
.49485 .61577 m .49457 .61667 L .49236 .61525 L F
.94 .935 .585 r
.49469 .61616 m .49448 .61667 L .49455 .61673 L F
.49469 .61616 m .49455 .61673 L .49467 .61634 L F
.49448 .61667 m .49368 .61866 L .49463 .61679 L F
0 .533 .834 r
.49479 .61681 m .49463 .61679 L .49464 .61669 L F
.878 .844 .807 r
.21937 .58531 m .2196 .58111 L .21805 .58143 L F
.21937 .58531 m .21715 .58417 L .2196 .58111 L F
.948 .741 .591 r
.21937 .58531 m .21869 .58749 L .21715 .58417 L F
.387 .05 .268 r
.72406 .44415 m .72631 .44483 L .72369 .44546 L F
.72406 .44415 m .72652 .44348 L .72631 .44483 L F
.092 0 0 r
.57931 .63733 m .57874 .63802 L .57646 .63871 L F
.049 0 0 r
.57931 .63733 m .58131 .63713 L .57874 .63802 L F
.321 0 .061 r
.39627 .59705 m .3951 .59865 L .39273 .59912 L F
.387 0 .1 r
.39778 .59816 m .39627 .59705 L .39698 .59676 L F
.39778 .59816 m .3951 .59865 L .39627 .59705 L F
.676 .935 .967 r
.33206 .80665 m .33242 .805 L .33013 .80591 L F
.33206 .80665 m .33397 .80547 L .33242 .805 L F
.648 .649 .837 r
.68634 .4268 m .69006 .42896 L .6891 .42621 L F
.619 .629 .838 r
.69006 .42896 m .69128 .42498 L .6891 .42621 L F
.69006 .42896 m .69224 .42829 L .69128 .42498 L F
.185 0 0 r
.47194 .63273 m .471 .6316 L .47314 .63088 L F
.47194 .63273 m .46971 .63351 L .471 .6316 L F
.677 .466 .592 r
.50939 .69647 m .51214 .69676 L .51187 .69377 L F
.941 .891 .752 r
.65883 .44558 m .66091 .44462 L .65957 .44328 L F
.65883 .44558 m .65984 .4469 L .66091 .44462 L F
.683 .424 .524 r
.54179 .65519 m .54641 .65262 L .54208 .65228 L F
.54179 .65519 m .54662 .65509 L .54641 .65262 L F
.651 .606 .791 r
.70813 .42886 m .70967 .43277 L .71173 .43164 L F
.567 .597 .843 r
.61303 .45518 m .61466 .45187 L .61267 .45244 L F
.61303 .45518 m .61572 .45516 L .61466 .45187 L F
.38 .061 .294 r
.64768 .43912 m .64939 .43886 L .64922 .438 L F
.021 .303 .795 r
.64922 .438 m .6499 .43695 L .6474 .435 L F
.398 .536 .878 r
.64939 .43886 m .6499 .43695 L .64922 .438 L F
.647 .639 .828 r
.71513 .41766 m .71181 .41707 L .71415 .41493 L F
.626 .647 .851 r
.71415 .41493 m .71181 .41707 L .71044 .41335 L F
.423 .187 .449 r
.69251 .45565 m .6903 .45832 L .6924 .4573 L F
.258 .056 .404 r
.69251 .45565 m .6939 .45607 L .6941 .45403 L F
.69251 .45565 m .6924 .4573 L .6939 .45607 L F
.823 .745 .777 r
.64121 .45869 m .6425 .46175 L .64071 .46062 L F
.772 .811 .883 r
.6414 .46189 m .64071 .46062 L .6425 .46175 L F
.742 .709 .82 r
.64507 .4592 m .6425 .46175 L .64121 .45869 L F
0 .498 .846 r
.64407 .46281 m .6414 .46189 L .6425 .46175 L F
.222 0 .239 r
.61253 .48884 m .61079 .48774 L .61383 .48673 L F
.61253 .48884 m .61053 .48996 L .61079 .48774 L F
.922 .64 .49 r
.63656 .44249 m .6387 .4442 L .63708 .44101 L F
.852 .779 .78 r
.6349 .44599 m .63666 .44647 L .6387 .4442 L F
.12 0 0 r
.73485 .43799 m .73151 .43984 L .73234 .43767 L F
.721 .818 .358 r
.64768 .43912 m .64607 .44249 L .64668 .44078 L F
.64768 .43912 m .64668 .44078 L .64939 .43886 L F
.571 .774 .975 r
.52839 .53976 m .53016 .54046 L .52779 .54105 L F
.652 .294 .353 r
.53016 .54046 m .52868 .53915 L .52779 .54105 L F
.776 .675 .753 r
.52362 .53848 m .52863 .54018 L .52294 .53928 L F
.52525 .53656 m .52819 .53971 L .52362 .53848 L F
.52819 .53971 m .52863 .54018 L .52362 .53848 L F
.571 .774 .975 r
.52868 .53915 m .52981 .54014 L .52839 .53976 L F
.52981 .54014 m .53016 .54046 L .52839 .53976 L F
.743 .647 .754 r
.54777 .50823 m .54938 .51179 L .54535 .5112 L F
.748 .631 .73 r
.54535 .5112 m .54938 .51179 L .5471 .51463 L F
.534 .913 .941 r
.16827 .54466 m .17225 .54384 L .17018 .54409 L F
.623 .438 .611 r
.69923 .43851 m .70112 .43521 L .6973 .43487 L F
.998 .778 .466 r
.55431 .67191 m .55544 .66996 L .55424 .66977 L F
.55431 .67191 m .55539 .67286 L .55544 .66996 L F
.979 .691 .398 r
.5082 .72265 m .50885 .7253 L .50994 .72579 L F
.296 .751 .955 r
.50885 .7253 m .51214 .72558 L .50994 .72579 L F
.50994 .72579 m .51214 .72558 L .50885 .7253 L F
.618 .743 .936 r
.58155 .62599 m .58397 .62668 L .58442 .62494 L F
.58155 .62599 m .58442 .62494 L .58184 .62577 L F
.219 .229 .657 r
.58073 .6292 m .58155 .62599 L .58184 .62577 L F
.58073 .6292 m .58184 .62577 L .57947 .62584 L F
.481 .72 .976 r
.68019 .41056 m .68165 .40909 L .67893 .41007 L F
.68019 .41056 m .6828 .41052 L .68165 .40909 L F
.325 0 0 r
.6117 .42428 m .61517 .4229 L .61382 .4243 L F
.6117 .42428 m .61423 .42422 L .61517 .4229 L F
.457 .887 .846 r
.61517 .4229 m .61681 .42185 L .61819 .4216 L F
.816 .721 .76 r
.61423 .42422 m .61681 .42185 L .61517 .4229 L F
.577 .845 .995 r
.68453 .44899 m .6855 .44999 L .68794 .44924 L F
.283 .618 .958 r
.36961 .63047 m .37092 .6298 L .36818 .62897 L F
.36961 .63047 m .37264 .63138 L .37092 .6298 L F
.638 .925 .655 r
.61456 .43957 m .6133 .44123 L .61612 .43849 L F
.666 .974 .851 r
.61318 .44061 m .6133 .44123 L .61456 .43957 L F
.755 .534 .596 r
.60131 .46068 m .60521 .45868 L .60341 .4577 L F
.60131 .46068 m .60493 .46112 L .60521 .45868 L F
.117 0 0 r
.48483 .62388 m .4837 .62503 L .48145 .6256 L F
0 0 0 r
.48692 .62296 m .4837 .62503 L .48483 .62388 L F
.788 .568 .602 r
.57926 .60856 m .57576 .60517 L .57588 .60822 L F
0 0 0 r
.57733 .61107 m .57811 .61019 L .57926 .60856 L F
.472 .024 .103 r
.57926 .60856 m .57974 .60981 L .58153 .60824 L F
.57926 .60856 m .57811 .61019 L .57974 .60981 L F
0 0 0 r
.57733 .61107 m .57811 .61019 L .57926 .60856 L F
.346 .466 .839 r
.35351 .61484 m .35608 .61807 L .35641 .61653 L F
.213 0 .078 r
.47203 .62296 m .47317 .62428 L .47435 .62196 L F
.47203 .62296 m .47104 .62507 L .47317 .62428 L F
.985 .885 .643 r
.65151 .45625 m .65268 .45626 L .65228 .45549 L F
.564 .729 .952 r
.65268 .45626 m .65439 .45399 L .65228 .45549 L F
.65268 .45626 m .65589 .45554 L .65439 .45399 L F
.321 0 0 r
.69175 .46457 m .69036 .46528 L .68795 .46471 L F
.005 0 0 r
.69413 .46359 m .69036 .46528 L .69175 .46457 L F
.833 .985 .872 r
.62893 .477 m .63214 .4755 L .63172 .47502 L F
.983 .716 .436 r
.65853 .44689 m .65984 .4469 L .65883 .44558 L F
.65853 .44689 m .6599 .44878 L .65984 .4469 L F
.652 .392 .514 r
.70348 .43718 m .70858 .43352 L .70324 .43507 L F
.70348 .43718 m .7061 .4374 L .70858 .43352 L F
.925 .974 .724 r
.55544 .67934 m .55342 .6808 L .55375 .68159 L F
.97 .786 .6 r
.55392 .67837 m .55342 .6808 L .55544 .67934 L F
.81 .679 .719 r
.54429 .69041 m .54829 .68828 L .54646 .68731 L F
.54429 .69041 m .54677 .69127 L .54829 .68828 L F
.573 .64 .879 r
.43621 .56658 m .43545 .57102 L .43406 .56721 L F
.43621 .56658 m .43844 .57128 L .43545 .57102 L F
.518 .143 .269 r
.52218 .69309 m .52615 .69284 L .52424 .69179 L F
.432 .235 .512 r
.52424 .69179 m .52615 .69284 L .52625 .69049 L F
.399 0 0 r
.40832 .63058 m .41062 .6307 L .41231 .6293 L F
.504 .076 .16 r
.41062 .6307 m .41458 .62883 L .41231 .6293 L F
0 0 0 r
.62188 .48179 m .62367 .48098 L .62379 .48094 L F
.62074 .48318 m .62188 .48179 L .62379 .48094 L F
.726 .694 .82 r
.69224 .42829 m .696 .42914 L .69489 .42563 L F
.711 .686 .824 r
.69489 .42563 m .696 .42914 L .69842 .42624 L F
.663 .907 .58 r
.6174 .43662 m .61612 .43849 L .61845 .43568 L F
.692 .946 .666 r
.6174 .43662 m .61456 .43957 L .61612 .43849 L F
.355 .119 .411 r
.218 .63779 m .21757 .64021 L .21561 .6408 L F
.294 .065 .386 r
.21757 .64021 m .21528 .6432 L .21561 .6408 L F
.753 .633 .727 r
.54535 .5112 m .5471 .51463 L .5432 .51413 L F
.784 .582 .628 r
.5471 .51463 m .54312 .51665 L .5432 .51413 L F
.5471 .51463 m .54677 .51708 L .54312 .51665 L F
.667 .527 .684 r
.5416 .68 m .54529 .67871 L .54276 .67841 L F
.647 .859 .98 r
.54107 .67716 m .54276 .67841 L .53869 .67843 L F
.249 .686 .96 r
.2622 .79009 m .26378 .79094 L .26613 .79098 L F
.2622 .79009 m .26378 .79094 L .26613 .79098 L F
.582 .373 .562 r
.5815 .50761 m .57904 .51086 L .57871 .50836 L F
.046 .553 .878 r
.2435 .54822 m .247 .54943 L .24488 .54993 L F
.341 .111 .413 r
.22031 .6348 m .21991 .63721 L .218 .63779 L F
.318 .081 .388 r
.21991 .63721 m .21757 .64021 L .218 .63779 L F
.814 .421 .309 r
.49458 .71103 m .4976 .71144 L .4962 .71314 L F
0 0 0 r
.4962 .71314 m .4976 .71144 L .49898 .71058 L F
.142 0 0 r
.68897 .45881 m .6924 .4573 L .6903 .45832 L F
.014 .566 .824 r
.20223 .541 m .20431 .54119 L .20613 .54183 L F
.284 0 0 r
.20431 .54119 m .20831 .54173 L .20613 .54183 L F
.605 .235 .314 r
.44208 .63127 m .44466 .63133 L .44586 .6293 L F
.495 .082 .186 r
.44466 .63133 m .44836 .62963 L .44586 .6293 L F
.518 .046 .073 r
.44586 .6293 m .44836 .62963 L .44966 .62928 L F
.653 .615 .799 r
.7145 .43128 m .71933 .43251 L .7168 .42817 L F
.709 .497 .6 r
.7145 .43128 m .71786 .43402 L .71933 .43251 L F
.71 .638 .774 r
.7168 .42817 m .71933 .43251 L .72039 .43063 L F
.907 .938 .818 r
.71933 .43251 m .71786 .43402 L .72039 .43063 L F
.776 .583 .638 r
.71786 .43402 m .72371 .43234 L .72039 .43063 L F
.71786 .43402 m .72148 .43451 L .72371 .43234 L F
.602 .757 .953 r
.72039 .43063 m .72371 .43234 L .7232 .42997 L F
.571 .282 .437 r
.72148 .43451 m .72425 .43439 L .72371 .43234 L F
.76 .718 .813 r
.62836 .42677 m .62607 .42765 L .62736 .42539 L F
.583 .737 .949 r
.63027 .42619 m .62836 .42677 L .62736 .42539 L F
.289 .438 .838 r
.63143 .42886 m .62836 .42677 L .63027 .42619 L F
.719 .668 .799 r
.72835 .4213 m .72489 .4205 L .72737 .41948 L F
.628 .669 .87 r
.73076 .42058 m .72835 .4213 L .72737 .41948 L F
0 0 .137 r
.61749 .41396 m .61723 .41 L .61744 .41234 L F
.794 .827 .877 r
.65589 .45554 m .65901 .45557 L .65766 .45402 L F
.52 .096 .175 r
.17875 .55569 m .17704 .55773 L .17465 .55747 L F
.162 0 0 r
.1791 .55701 m .17875 .55569 L .18083 .55499 L F
.1791 .55701 m .17704 .55773 L .17875 .55569 L F
.252 .419 .834 r
.64289 .42966 m .64591 .4305 L .64378 .42789 L F
.759 .324 .218 r
.64378 .42789 m .64591 .4305 L .64567 .43042 L F
.204 .213 .646 r
.64277 .42654 m .64289 .42966 L .64378 .42789 L F
.759 .324 .218 r
.64378 .42789 m .64567 .43042 L .64206 .4293 L F
.204 .213 .646 r
.64274 .42562 m .64277 .42654 L .64378 .42789 L F
.252 .419 .834 r
.64289 .42966 m .64584 .43093 L .64591 .4305 L F
.261 .147 .529 r
.21805 .58143 m .2196 .58111 L .21968 .57849 L F
.233 0 0 r
.21819 .5421 m .22018 .54247 L .22157 .54247 L F
.196 .711 .884 r
.22018 .54247 m .22433 .54267 L .22157 .54247 L F
.422 .32 .633 r
.24985 .57575 m .25011 .57827 L .2484 .5788 L F
.428 .318 .627 r
.25011 .57827 m .24817 .58152 L .2484 .5788 L F
.473 .544 .849 r
.23006 .56744 m .23023 .56427 L .22921 .56442 L F
.23006 .56744 m .23213 .56649 L .23023 .56427 L F
.184 .001 .384 r
.22989 .56949 m .23213 .56649 L .23006 .56744 L F
.468 .679 .957 r
.38109 .6406 m .38273 .63948 L .37911 .63777 L F
.38109 .6406 m .38321 .6404 L .38273 .63948 L F
.409 .171 .439 r
.24243 .59391 m .24187 .59616 L .23983 .59677 L F
.456 .257 .521 r
.24187 .59616 m .23956 .59918 L .23983 .59677 L F
.563 .128 .173 r
.44116 .63451 m .43968 .63641 L .43749 .63501 L F
.628 .202 .216 r
.44325 .63621 m .43968 .63641 L .44116 .63451 L F
.631 .199 .202 r
.44382 .63521 m .44325 .63621 L .44116 .63451 L F
.961 .891 .714 r
.64731 .41896 m .6482 .41748 L .64715 .41615 L F
.64745 .41907 m .6482 .41748 L .64731 .41896 L F
.64733 .41932 m .6482 .41748 L .64715 .41615 L F
.64733 .41932 m .64715 .41615 L .64604 .41809 L F
.64733 .41932 m .64715 .41615 L .64604 .41809 L F
.204 .598 .946 r
.64995 .41974 m .64634 .41821 L .64866 .41883 L F
.64634 .41821 m .64604 .41809 L .64625 .41815 L F
.64634 .41821 m .64625 .41815 L .64866 .41883 L F
.961 .891 .714 r
.64733 .41932 m .64745 .41907 L .64731 .41896 L F
.813 .71 .751 r
.54829 .50164 m .54922 .49946 L .55032 .50286 L F
.812 .71 .753 r
.54829 .50164 m .55032 .50286 L .54818 .50576 L F
.396 .433 .781 r
.21991 .57617 m .22044 .57245 L .22168 .57255 L F
.21991 .57617 m .22185 .57575 L .22044 .57245 L F
.588 .346 .516 r
.21991 .57617 m .22207 .57812 L .22185 .57575 L F
.21991 .57617 m .21968 .57849 L .22207 .57812 L F
.671 .578 .742 r
.70214 .42888 m .70573 .42982 L .70448 .42594 L F
.753 .704 .805 r
.70092 .42541 m .70214 .42888 L .70448 .42594 L F
.535 .73 .964 r
.68859 .42275 m .68516 .42178 L .68749 .41986 L F
.644 .671 .861 r
.69114 .42179 m .68859 .42275 L .68749 .41986 L F
.727 .892 .955 r
.69115 .44838 m .68811 .44685 L .69049 .44818 L F
.858 .619 .577 r
.68794 .44924 m .68811 .44685 L .68591 .44621 L F
.492 .3 .548 r
.69049 .44818 m .68811 .44685 L .68794 .44924 L F
.956 .638 .226 r
.66833 .45862 m .66762 .45969 L .66725 .45737 L F
.66833 .45862 m .66867 .46094 L .66762 .45969 L F
.786 .841 .893 r
.4336 .57525 m .43715 .57599 L .43511 .57348 L F
.4336 .57525 m .4349 .57674 L .43715 .57599 L F
.68 .767 .917 r
.43511 .57348 m .43715 .57599 L .43885 .57317 L F
.659 .673 .852 r
.43715 .57599 m .44036 .57618 L .43885 .57317 L F
.12 0 0 r
.73485 .43799 m .73388 .4392 L .73151 .43984 L F
.489 .052 .135 r
.73744 .43747 m .73388 .4392 L .73485 .43799 L F
.412 .382 .716 r
.35307 .61116 m .35351 .61484 L .35558 .61329 L F
.346 .466 .839 r
.35351 .61484 m .35641 .61653 L .35558 .61329 L F
.623 .438 .611 r
.69923 .43851 m .70094 .43769 L .70112 .43521 L F
.555 .313 .504 r
.70094 .43769 m .70324 .43507 L .70112 .43521 L F
.671 .202 .131 r
.45177 .63068 m .45141 .62967 L .44966 .62928 L F
.58 .146 .183 r
.45177 .63068 m .45408 .63107 L .45141 .62967 L F
.783 .751 .823 r
.74665 .42277 m .74446 .42563 L .74306 .42247 L F
.585 .46 .676 r
.74665 .42277 m .74701 .42567 L .74446 .42563 L F
.649 .374 .49 r
.74701 .42567 m .7436 .42764 L .74446 .42563 L F
.493 .306 .555 r
.19649 .62318 m .19873 .62376 L .19867 .62082 L F
.55 .575 .833 r
.19649 .62318 m .20017 .6261 L .19873 .62376 L F
.389 .212 .517 r
.22246 .63154 m .22226 .63424 L .22031 .6348 L F
.351 .12 .417 r
.22226 .63424 m .21991 .63721 L .22031 .6348 L F
.686 .318 .344 r
.531 .68706 m .53433 .68537 L .53076 .68486 L F
.531 .68706 m .53448 .68723 L .53433 .68537 L F
.642 .284 .349 r
.53448 .68723 m .53687 .68697 L .53433 .68537 L F
.527 .35 .584 r
.53433 .68537 m .53738 .68682 L .5369 .68189 L F
.459 .4 .705 r
.53687 .68697 m .53738 .68682 L .53433 .68537 L F
.578 .319 .488 r
.59462 .49675 m .59705 .49864 L .5945 .49893 L F
.644 .28 .34 r
.59462 .49675 m .59739 .49713 L .59705 .49864 L F
.286 .075 .407 r
.22954 .62015 m .22904 .62246 L .22746 .62299 L F
.333 .157 .486 r
.2289 .62509 m .22746 .62299 L .22904 .62246 L F
.2289 .62509 m .2272 .62592 L .22746 .62299 L F
.629 .656 .857 r
.71763 .41688 m .71513 .41766 L .71415 .41493 L F
.636 .87 .986 r
.42199 .58082 m .42663 .58087 L .42608 .5803 L F
.547 .526 .784 r
.38579 .60995 m .38272 .61252 L .38536 .60954 L F
.38579 .60995 m .3868 .61359 L .38272 .61252 L F
.371 .163 .463 r
.3868 .61359 m .38448 .61627 L .38272 .61252 L F
.343 .111 .411 r
.24371 .59551 m .24243 .59391 L .24391 .59304 L F
.24371 .59551 m .24187 .59616 L .24243 .59391 L F
.659 .895 .981 r
.42721 .571 m .42278 .57142 L .42572 .57046 L F
.624 .906 .984 r
.4294 .57001 m .42721 .571 L .42572 .57046 L F
.558 .654 .899 r
.56655 .63084 m .56636 .63409 L .56514 .63138 L F
.56655 .63084 m .56884 .63389 L .56636 .63409 L F
.293 .598 .949 r
.24146 .54634 m .24125 .54788 L .23948 .54655 L F
.24146 .54634 m .2435 .54822 L .24125 .54788 L F
.458 .176 .397 r
.71046 .45235 m .71002 .45539 L .70761 .45569 L F
.526 .248 .436 r
.71314 .4518 m .71002 .45539 L .71046 .45235 L F
.362 0 .049 r
.43024 .62923 m .43231 .62572 L .43018 .62643 L F
.555 .313 .504 r
.70094 .43769 m .70348 .43718 L .70324 .43507 L F
.532 .338 .563 r
.20461 .6226 m .20702 .61964 L .20502 .62025 L F
.71 .411 .468 r
.19606 .62815 m .19934 .62815 L .20017 .6261 L F
.446 .599 .909 r
.19873 .62376 m .20017 .6261 L .20163 .62468 L F
.378 .072 .314 r
.20017 .6261 m .20114 .62759 L .20163 .62468 L F
.20017 .6261 m .19934 .62815 L .20114 .62759 L F
.391 0 .08 r
.48183 .61902 m .48544 .61705 L .48305 .61732 L F
0 0 0 r
.62456 .42856 m .62607 .42765 L .62222 .42935 L F
.862 .996 .775 r
.62736 .42539 m .62607 .42765 L .62456 .42856 L F
.965 .661 .396 r
.61915 .42853 m .61893 .42618 L .61746 .42483 L F
.88 .814 .779 r
.61746 .42483 m .61893 .42618 L .61985 .42372 L F
.588 .596 .828 r
.55423 .63516 m .5579 .638 L .55589 .6336 L F
.024 .219 .726 r
.55589 .6336 m .5579 .638 L .5589 .63697 L F
.204 .513 .913 r
.5579 .638 m .56129 .63954 L .5589 .63697 L F
.495 .288 .528 r
.58644 .50269 m .58645 .50505 L .58413 .50578 L F
.555 .325 .522 r
.58898 .50235 m .58645 .50505 L .58644 .50269 L F
.098 .629 .869 r
.5493 .67057 m .54837 .67013 L .54636 .67011 L F
.339 .147 .467 r
.54632 .67246 m .54837 .67013 L .54636 .67011 L F
.948 .615 .36 r
.54837 .67013 m .54753 .67134 L .54769 .66981 L F
.305 .506 .888 r
.54636 .67011 m .54837 .67013 L .5478 .66864 L F
.948 .615 .36 r
.54837 .67013 m .54769 .66981 L .5478 .66864 L F
.098 .629 .869 r
.54937 .67058 m .54837 .67013 L .5493 .67057 L F
.955 .609 .277 r
.55048 .67303 m .54837 .67013 L .54937 .67058 L F
.701 .903 .968 r
.45743 .63086 m .45553 .63187 L .45408 .63107 L F
.819 .635 .653 r
.6836 .42237 m .68306 .42447 L .68163 .423 L F
.519 .406 .665 r
.35182 .60539 m .35405 .60488 L .35361 .6023 L F
.455 .367 .667 r
.35182 .60539 m .35425 .60741 L .35405 .60488 L F
.35182 .60539 m .35219 .60897 L .35425 .60741 L F
.11 0 0 r
.70263 .45889 m .70204 .46038 L .69962 .46095 L F
.299 0 .085 r
.70506 .45795 m .70204 .46038 L .70263 .45889 L F
.878 .809 .777 r
.51949 .54926 m .52041 .55273 L .51844 .55183 L F
.77 .453 .45 r
.52041 .55273 m .51709 .55447 L .51844 .55183 L F
.52041 .55273 m .52065 .55479 L .51709 .55447 L F
.803 .771 .823 r
.52303 .54937 m .52041 .55273 L .51949 .54926 L F
.42 .231 .516 r
.52303 .54937 m .52291 .55178 L .52041 .55273 L F
.402 .191 .476 r
.52291 .55178 m .52065 .55479 L .52041 .55273 L F
.804 .835 .875 r
.53866 .70237 m .53573 .70226 L .53788 .70078 L F
.426 .005 .134 r
.53866 .70237 m .53473 .70467 L .53573 .70226 L F
.53866 .70237 m .53733 .7045 L .53473 .70467 L F
0 .181 .714 r
.53788 .70078 m .53853 .70113 L .53866 .70237 L F
.888 .903 .491 r
.53853 .70113 m .53733 .7045 L .53866 .70237 L F
0 0 .52 r
.66028 .42376 m .66146 .42523 L .6594 .42235 L F
.593 .498 .716 r
.50546 .69663 m .50937 .69906 L .50939 .69647 L F
.50546 .69663 m .50705 .69986 L .50937 .69906 L F
.527 .382 .627 r
.74223 .43382 m .73963 .43185 L .74203 .43123 L F
.74223 .43382 m .74003 .43476 L .73963 .43185 L F
.428 .318 .627 r
.25011 .57827 m .25025 .58079 L .24817 .58152 L F
.496 .332 .588 r
.25025 .58079 m .24817 .58418 L .24817 .58152 L F
.789 .993 .878 r
.63479 .47249 m .63705 .46957 L .63438 .47228 L F
.63479 .47249 m .63762 .47016 L .63705 .46957 L F
.671 .202 .131 r
.45177 .63068 m .44966 .62928 L .44836 .62963 L F
.916 .517 .172 r
.65367 .42531 m .65497 .42854 L .65617 .42927 L F
.954 .609 .299 r
.65497 .42854 m .65523 .43027 L .65617 .42927 L F
.616 .1 0 r
.65523 .43027 m .65883 .43083 L .65617 .42927 L F
.404 .592 .92 r
.56129 .63954 m .5616 .64085 L .56285 .63922 L F
.382 .56 .904 r
.5616 .64085 m .56371 .64128 L .56285 .63922 L F
.807 .365 .192 r
.43474 .62783 m .43705 .62827 L .43567 .62678 L F
.279 .708 .968 r
.6278 .41185 m .62498 .41127 L .62727 .41278 L F
.599 .088 .007 r
.62727 .41278 m .63145 .41318 L .6278 .41185 L F
.219 0 0 r
.40665 .59023 m .40908 .59039 L .40729 .59039 L F
.149 .462 .888 r
.64016 .4323 m .64108 .43422 L .6385 .43308 L F
.64016 .4323 m .6385 .43308 L .63866 .43517 L F
.666 .723 .892 r
.43885 .57317 m .44036 .57618 L .44218 .575 L F
.645 .6 .789 r
.74003 .4204 m .7367 .41794 L .73925 .41717 L F
.552 .512 .765 r
.74312 .41895 m .74003 .4204 L .73925 .41717 L F
.599 .491 .703 r
.74312 .41895 m .74045 .42287 L .74003 .4204 L F
.491 .419 .703 r
.5717 .63465 m .57023 .63775 L .56961 .63537 L F
.5717 .63465 m .57259 .63696 L .57023 .63775 L F
.795 .747 .808 r
.54081 .51966 m .54208 .5217 L .53828 .52261 L F
.711 .472 .562 r
.54208 .5217 m .53825 .52482 L .53828 .52261 L F
.54208 .5217 m .54292 .52644 L .53825 .52482 L F
.524 .346 .581 r
.54463 .5198 m .54208 .5217 L .54081 .51966 L F
.54463 .5198 m .54467 .52249 L .54208 .5217 L F
.532 .352 .583 r
.54434 .52492 m .54208 .5217 L .54467 .52249 L F
.54434 .52492 m .54292 .52644 L .54208 .5217 L F
.269 0 .093 r
.56936 .516 m .57075 .51432 L .57309 .51359 L F
.683 .689 .849 r
.54766 .67782 m .54876 .67901 L .54529 .67871 L F
.716 .584 .707 r
.54529 .67871 m .54876 .67901 L .54694 .68205 L F
.468 .227 .465 r
.58413 .50578 m .58637 .50718 L .58387 .50761 L F
.58413 .50578 m .58645 .50505 L .58637 .50718 L F
.537 .006 0 r
.41458 .62883 m .41646 .63011 L .41813 .62902 L F
.477 0 0 r
.41646 .63011 m .42054 .62926 L .41813 .62902 L F
.613 .253 .335 r
.41707 .63761 m .41558 .64006 L .41328 .63971 L F
.504 .134 .271 r
.41916 .63902 m .41707 .63761 L .41934 .63777 L F
.41916 .63902 m .41558 .64006 L .41707 .63761 L F
.6 .887 .991 r
.55564 .62939 m .55319 .63062 L .55088 .62999 L F
.1 .513 .907 r
.67506 .42622 m .67445 .42666 L .67313 .42503 L F
.67506 .42622 m .67628 .42702 L .67445 .42666 L F
.819 .925 .905 r
.64751 .46052 m .65123 .45923 L .64981 .45801 L F
.613 .661 .872 r
.70326 .40982 m .70154 .41229 L .70074 .41055 L F
.70326 .40982 m .70407 .41161 L .70154 .41229 L F
.167 0 0 r
.19988 .55225 m .20019 .55239 L .19731 .55217 L F
.424 .689 .974 r
.45555 .57717 m .45661 .57578 L .45445 .57587 L F
.45555 .57717 m .45869 .5776 L .45661 .57578 L F
.562 .662 .904 r
.56884 .63389 m .5717 .63465 L .56961 .63537 L F
.427 .62 .932 r
.20513 .6145 m .20737 .61722 L .20801 .61581 L F
.129 .073 .52 r
.20702 .61964 m .20801 .61581 L .20737 .61722 L F
.812 .71 .753 r
.54829 .50164 m .54818 .50576 L .54628 .50468 L F
.865 .694 .669 r
.54628 .50468 m .54818 .50576 L .54777 .50823 L F
.309 .798 .875 r
.17225 .54384 m .17435 .54337 L .17583 .5434 L F
.139 .684 .736 r
.17435 .54337 m .17798 .54286 L .17583 .5434 L F
.815 .725 .766 r
.49149 .70159 m .49345 .70528 L .49475 .7027 L F
.283 .106 .455 r
.49475 .7027 m .49345 .70528 L .49495 .70471 L F
.265 .276 .685 r
.49345 .70528 m .49496 .70713 L .49495 .70471 L F
.557 .635 .884 r
.69829 .41119 m .69456 .40876 L .69699 .40798 L F
.593 .621 .849 r
.69944 .40729 m .69829 .41119 L .69699 .40798 L F
.69944 .40729 m .70074 .41055 L .69829 .41119 L F
0 .518 .738 r
.55285 .63492 m .55423 .63516 L .55305 .63492 L F
0 0 .482 r
.57789 .62209 m .5788 .62315 L .57626 .62024 L F
.57789 .62209 m .57626 .62024 L .57554 .62252 L F
.939 .614 .393 r
.54057 .53688 m .54216 .53781 L .54104 .53932 L F
.599 .601 .825 r
.54323 .53381 m .54216 .53781 L .54057 .53688 L F
.54323 .53381 m .54417 .5369 L .54216 .53781 L F
.28 0 .216 r
.54216 .53781 m .54353 .53907 L .54104 .53932 L F
.54216 .53781 m .54417 .5369 L .54353 .53907 L F
.535 .643 .903 r
.71044 .41335 m .70814 .4138 L .70691 .41077 L F
.662 .573 .744 r
.70448 .42594 m .70573 .42982 L .70813 .42886 L F
.563 .333 .525 r
.5622 .5171 m .5647 .51906 L .56214 .51933 L F
.5622 .5171 m .56472 .51677 L .5647 .51906 L F
.711 .402 .452 r
.58381 .61019 m .58548 .60824 L .58153 .60824 L F
.755 .463 .489 r
.58381 .61019 m .58683 .61027 L .58548 .60824 L F
.443 .346 .651 r
.23955 .60169 m .23769 .60462 L .23754 .60323 L F
.481 .399 .687 r
.25255 .56003 m .25277 .56376 L .25082 .56439 L F
.289 .204 .584 r
.25277 .56376 m .25143 .56697 L .25082 .56439 L F
.362 .08 .343 r
.72369 .44546 m .72121 .44872 L .72114 .44617 L F
.354 .201 .531 r
.23516 .60791 m .23499 .61138 L .23336 .61141 L F
.422 .328 .643 r
.23499 .61138 m .23363 .61386 L .23336 .61141 L F
.172 0 0 r
.40108 .57907 m .40225 .57966 L .40424 .57836 L F
.40108 .57907 m .40003 .58031 L .40225 .57966 L F
.675 .734 .895 r
.19962 .61329 m .20353 .61424 L .2018 .61378 L F
.088 .51 .903 r
.20353 .61424 m .2036 .61323 L .2018 .61378 L F
.20353 .61424 m .20513 .6145 L .2036 .61323 L F
0 0 .57 r
.6577 .42004 m .65881 .42074 L .65706 .41866 L F
.6577 .42004 m .6594 .42235 L .65881 .42074 L F
.186 .657 .935 r
.46052 .57094 m .46313 .5719 L .46176 .57207 L F
.464 .766 .996 r
.68108 .40308 m .67765 .40235 L .68008 .40179 L F
.484 .704 .966 r
.68241 .40141 m .68108 .40308 L .68008 .40179 L F
.68241 .40141 m .68324 .40283 L .68108 .40308 L F
.613 .417 .592 r
.39024 .60219 m .38761 .60496 L .38774 .60262 L F
.586 .842 .483 r
.67833 .42447 m .67628 .42702 L .6767 .42658 L F
.386 .836 .736 r
.41251 .57569 m .41361 .57498 L .41475 .57461 L F
.377 .842 .839 r
.41251 .57569 m .41136 .57578 L .41361 .57498 L F
.623 .63 .837 r
.72273 .41553 m .72152 .41966 L .72013 .41608 L F
.72273 .41553 m .72417 .41886 L .72152 .41966 L F
.627 .659 .862 r
.72417 .41886 m .72489 .4205 L .72152 .41966 L F
.482 .151 .327 r
.60296 .4936 m .60492 .4949 L .60274 .49538 L F
.60296 .4936 m .60549 .49327 L .60492 .4949 L F
.516 .284 .502 r
.54391 .67293 m .54636 .67011 L .54391 .6704 L F
.54391 .67293 m .54632 .67246 L .54636 .67011 L F
.54636 .67011 m .54632 .67246 L .54391 .67293 L F
.027 .056 .554 r
.54636 .67011 m .54714 .66616 L .54628 .6674 L F
.54636 .67011 m .5478 .66864 L .54714 .66616 L F
.667 .527 .684 r
.5416 .68 m .544 .6778 L .54529 .67871 L F
.687 .717 .872 r
.54605 .6749 m .54529 .67871 L .54523 .67772 L F
.54605 .6749 m .54766 .67782 L .54529 .67871 L F
.653 .916 .978 r
.544 .6778 m .54523 .67772 L .54529 .67871 L F
.942 .853 .724 r
.64733 .41932 m .64437 .42163 L .64604 .41809 L F
.64733 .41932 m .6457 .42297 L .64437 .42163 L F
.204 .598 .946 r
.64995 .41974 m .64733 .41932 L .64604 .41809 L F
.71 .756 .254 r
.63235 .45297 m .63187 .45421 L .63104 .45144 L F
.63235 .45297 m .63237 .45279 L .63187 .45421 L F
.708 .967 .724 r
.63206 .45604 m .62927 .45875 L .63087 .45706 L F
.513 .566 .846 r
.64346 .45558 m .64493 .45141 L .64202 .45224 L F
.64346 .45558 m .64636 .45484 L .64493 .45141 L F
.614 .636 .849 r
.6988 .44109 m .70159 .44313 L .70086 .44004 L F
.544 .394 .629 r
.70159 .44313 m .70473 .44061 L .70086 .44004 L F
.70159 .44313 m .70475 .44288 L .70473 .44061 L F
.554 .359 .571 r
.70217 .4454 m .70475 .44288 L .70159 .44313 L F
0 0 .442 r
.57797 .61369 m .57733 .61107 L .57798 .61392 L F
.57797 .61369 m .57811 .61019 L .57733 .61107 L F
.907 .713 .211 r
.6532 .42483 m .65367 .42531 L .65336 .42392 L F
.785 .407 0 r
.6539 .42673 m .65367 .42531 L .6532 .42483 L F
.6539 .42673 m .65497 .42854 L .65367 .42531 L F
.585 .628 .861 r
.68634 .4268 m .68748 .42423 L .68531 .42516 L F
.68634 .4268 m .6891 .42621 L .68748 .42423 L F
.676 .182 .066 r
.57411 .63502 m .57714 .63708 L .57851 .63564 L F
.333 0 0 r
.57971 .63629 m .57851 .63564 L .57714 .63708 L F
.57971 .63629 m .58131 .63713 L .57851 .63564 L F
.314 .803 .864 r
.36282 .62909 m .36205 .6289 L .35944 .6295 L F
.06 0 0 r
.36538 .62812 m .36205 .6289 L .36282 .62909 L F
.582 .835 .471 r
.7367 .41794 m .73587 .41891 L .7356 .41725 L F
.701 .757 .896 r
.73925 .41717 m .7367 .41794 L .7356 .41725 L F
0 0 .35 r
.66767 .44001 m .66568 .43646 L .66723 .43777 L F
.502 .62 .901 r
.69522 .41706 m .69826 .4186 L .69743 .41522 L F
.5 .618 .9 r
.69522 .41706 m .69945 .41919 L .69826 .4186 L F
.69522 .41706 m .69715 .42016 L .69945 .41919 L F
.563 .739 .959 r
.47843 .72301 m .47549 .72235 L .47721 .72242 L F
.73 .608 .721 r
.47549 .72235 m .47843 .72301 L .47721 .72242 L F
.47549 .72235 m .47629 .72614 L .47843 .72301 L F
0 0 0 r
.4837 .62503 m .48248 .62537 L .48145 .6256 L F
.463 .275 .539 r
.48248 .62537 m .48034 .62753 L .48145 .6256 L F
.337 .296 .664 r
.35307 .61116 m .35425 .60741 L .35219 .60897 L F
.35307 .61116 m .35459 .61083 L .35425 .60741 L F
.412 .382 .716 r
.35307 .61116 m .35558 .61329 L .35459 .61083 L F
.752 .533 .598 r
.55375 .52022 m .55035 .52246 L .55034 .51999 L F
.55375 .52022 m .55422 .52282 L .55035 .52246 L F
.621 .445 .622 r
.55375 .52022 m .55638 .51979 L .55422 .52282 L F
.744 .343 .29 r
.49876 .70509 m .49475 .7027 L .49495 .70471 L F
.13 0 0 r
.68801 .46574 m .68599 .46604 L .68795 .46471 L F
.391 0 .159 r
.68795 .46471 m .69036 .46528 L .68801 .46574 L F
.884 .988 .807 r
.53452 .6655 m .53304 .66676 L .53541 .66378 L F
.152 .691 .83 r
.48782 .61418 m .49025 .61406 L .49143 .61417 L F
.533 0 0 r
.49236 .61525 m .49143 .61417 L .49025 .61406 L F
.98 .722 .465 r
.67644 .45595 m .67541 .45326 L .67584 .45426 L F
.62 .183 .19 r
.67495 .45581 m .67655 .45588 L .67584 .45426 L F
0 .135 .682 r
.67584 .45426 m .67882 .45897 L .67644 .45595 L F
.593 .594 .823 r
.68002 .4571 m .67882 .45897 L .67584 .45426 L F
.68002 .4571 m .67584 .45426 L .67889 .45599 L F
.62 .183 .19 r
.67655 .45588 m .67889 .45599 L .67584 .45426 L F
.98 .722 .465 r
.67541 .45326 m .67505 .45231 L .67584 .45426 L F
.983 .703 .406 r
.36001 .62381 m .36134 .62312 L .35766 .62271 L F
.36001 .62381 m .36127 .62537 L .36134 .62312 L F
.156 .308 .768 r
.36134 .62312 m .36269 .62189 L .36005 .61949 L F
.983 .703 .406 r
.36134 .62312 m .36001 .62381 L .36269 .62189 L F
.36134 .62312 m .36127 .62537 L .36001 .62381 L F
0 0 .156 r
.7436 .42764 m .74203 .43123 L .74252 .42918 L F
.327 .276 .648 r
.38699 .61833 m .38572 .62226 L .38548 .62009 L F
.18 0 .354 r
.67206 .41864 m .66946 .42257 L .66936 .41995 L F
0 0 0 r
.40424 .57836 m .4063 .57788 L .40623 .57763 L F
.386 .217 .526 r
.24817 .58418 m .24597 .58744 L .24603 .58507 L F
.896 .988 .763 r
.63705 .46957 m .63762 .47016 L .6398 .46703 L F
.94 .806 .684 r
.60773 .44632 m .60936 .44703 L .60899 .44459 L F
.60773 .44632 m .60851 .44945 L .60936 .44703 L F
.745 .64 .744 r
.54683 .61689 m .54922 .6188 L .5498 .61776 L F
.328 0 0 r
.42258 .62962 m .42611 .63013 L .42415 .62896 L F
.519 .296 .515 r
.35548 .59634 m .35807 .59586 L .35826 .59343 L F
.475 .259 .505 r
.35826 .59343 m .36021 .59512 L .36063 .59305 L F
.35826 .59343 m .35807 .59586 L .36021 .59512 L F
.528 .121 .212 r
.20428 .61059 m .20674 .61079 L .2085 .60871 L F
.269 0 .033 r
.2085 .60871 m .20918 .60965 L .21037 .60777 L F
.2085 .60871 m .20674 .61079 L .20918 .60965 L F
.595 .194 .252 r
.41519 .58779 m .41374 .58987 L .4114 .58943 L F
.322 .118 .44 r
.41728 .58655 m .41519 .58779 L .41734 .58462 L F
.285 .104 .45 r
.24578 .58979 m .24391 .59304 L .24449 .59075 L F
.707 .69 .831 r
.35601 .62617 m .35641 .6291 L .35504 .62589 L F
0 .079 .64 r
.35504 .62589 m .35641 .6291 L .35615 .62769 L F
.316 .664 .974 r
.35641 .6291 m .35724 .6279 L .35615 .62769 L F
.35641 .6291 m .35944 .6295 L .35724 .6279 L F
0 0 0 r
.63206 .45604 m .63187 .45421 L .63237 .45279 L F
.63206 .45604 m .63284 .45632 L .63187 .45421 L F
.63206 .45604 m .63087 .45706 L .63284 .45632 L F
0 .007 .583 r
.66422 .42848 m .66573 .43199 L .6655 .43061 L F
.731 .262 0 r
.61985 .42372 m .61819 .4216 L .62012 .42202 L F
.88 .814 .779 r
.61746 .42483 m .61985 .42372 L .62012 .42202 L F
.651 .64 .825 r
.68749 .41986 m .68516 .42178 L .68424 .41961 L F
.5 .226 .43 r
.59739 .49713 m .5998 .4985 L .59705 .49864 L F
.59739 .49713 m .60029 .49585 L .5998 .4985 L F
.669 .733 .228 r
.53167 .68221 m .53092 .68441 L .53076 .68486 L F
.151 0 .04 r
.70132 .46155 m .69962 .46095 L .70204 .46038 L F
.70132 .46155 m .69911 .46264 L .69962 .46095 L F
.457 .278 .549 r
.19867 .62082 m .20056 .62294 L .20137 .62064 L F
.19867 .62082 m .19873 .62376 L .20056 .62294 L F
.289 .204 .584 r
.25277 .56376 m .25296 .56629 L .25143 .56697 L F
.291 .222 .605 r
.2532 .56885 m .25143 .56697 L .25296 .56629 L F
.2532 .56885 m .25158 .5702 L .25143 .56697 L F
.433 0 .01 r
.37142 .58878 m .37381 .58885 L .37525 .58733 L F
.506 .087 .178 r
.37381 .58885 m .37755 .58697 L .37525 .58733 L F
.646 .769 .938 r
.23122 .81659 m .23577 .81757 L .23314 .81791 L F
.686 .293 .297 r
.23314 .81791 m .23486 .8195 L .23137 .8192 L F
.915 .689 .582 r
.23314 .81791 m .23137 .8192 L .23122 .81659 L F
.46 .522 .835 r
.35708 .61818 m .35854 .61611 L .35641 .61653 L F
.35708 .61818 m .36005 .61949 L .35854 .61611 L F
.727 .892 .955 r
.68794 .44924 m .69115 .44838 L .69049 .44818 L F
.026 0 0 r
.69049 .44818 m .69363 .44823 L .69115 .44838 L F
.492 .427 .712 r
.69115 .44838 m .69335 .44823 L .69049 .44818 L F
.69115 .44838 m .69415 .45148 L .69335 .44823 L F
.533 .035 .019 r
.40242 .64023 m .40128 .64055 L .39902 .64026 L F
.274 0 0 r
.40492 .64009 m .40128 .64055 L .40242 .64023 L F
.683 .525 .666 r
.69518 .44034 m .6988 .44109 L .69923 .43851 L F
.69 .692 .847 r
.72737 .41948 m .72489 .4205 L .72417 .41886 L F
.876 .519 .368 r
.65609 .43428 m .65649 .43623 L .65778 .43473 L F
.836 .828 .84 r
.65883 .43083 m .65609 .43428 L .65778 .43473 L F
.894 .548 .385 r
.65778 .43473 m .65649 .43623 L .65851 .43692 L F
.241 .697 .952 r
.24914 .55036 m .25335 .55124 L .25094 .55165 L F
.516 .641 .911 r
.25335 .55124 m .25379 .55264 L .25094 .55165 L F
.828 .731 .757 r
.54535 .5112 m .54228 .51105 L .54432 .50763 L F
.825 .745 .775 r
.54535 .5112 m .5432 .51413 L .54228 .51105 L F
.779 .705 .782 r
.54432 .50763 m .54777 .50823 L .54535 .5112 L F
.896 .988 .763 r
.63705 .46957 m .6398 .46703 L .63944 .46659 L F
0 .498 .846 r
.64407 .46281 m .64339 .46221 L .6414 .46189 L F
.261 0 .3 r
.64339 .46221 m .64155 .46358 L .6414 .46189 L F
.745 .907 .949 r
.64237 .4623 m .64155 .46358 L .64339 .46221 L F
.85 .983 .697 r
.64155 .46358 m .64022 .46567 L .6414 .46189 L F
.745 .907 .949 r
.64056 .46245 m .64155 .46358 L .64237 .4623 L F
.85 .983 .697 r
.64155 .46358 m .6398 .46703 L .64022 .46567 L F
.64155 .46358 m .63944 .46659 L .6398 .46703 L F
.901 .792 .308 r
.49485 .61577 m .49512 .61716 L .49479 .61681 L F
.445 0 0 r
.23023 .56427 m .2277 .56286 L .22921 .56442 L F
.359 .176 .491 r
.23106 .61936 m .22904 .62246 L .22954 .62015 L F
.966 .814 .641 r
.4336 .57525 m .43285 .57765 L .4349 .57674 L F
0 0 0 r
.62288 .41944 m .626 .41698 L .62344 .4168 L F
.541 .569 .832 r
.62204 .41707 m .62562 .41646 L .62382 .41274 L F
.216 .132 .54 r
.62204 .41707 m .62344 .4168 L .62562 .41646 L F
.467 .865 .967 r
.62562 .41646 m .62344 .4168 L .626 .41698 L F
.354 .791 .964 r
.626 .41698 m .6285 .41672 L .62562 .41646 L F
0 .422 .718 r
.22433 .54267 m .2261 .54316 L .22783 .54373 L F
.03 .6 .763 r
.2261 .54316 m .22993 .54335 L .22783 .54373 L F
.028 0 0 r
.49468 .69051 m .49752 .68978 L .49835 .68898 L F
.261 .281 .693 r
.4998 .68931 m .49907 .69077 L .49835 .68898 L F
.292 0 0 r
.49835 .68898 m .49752 .68978 L .4998 .68931 L F
.404 .234 .534 r
.25188 .57255 m .24985 .57575 L .2497 .5732 L F
.878 .847 .81 r
.66992 .44956 m .66635 .45139 L .66861 .44808 L F
.66992 .44956 m .66801 .45212 L .66635 .45139 L F
.754 .979 .915 r
.64191 .44917 m .64353 .44669 L .64496 .44681 L F
.64191 .44917 m .64148 .4484 L .64353 .44669 L F
.942 .796 .337 r
.64191 .44917 m .64111 .45103 L .64148 .4484 L F
.964 .765 .586 r
.65851 .43692 m .65807 .43965 L .65956 .44043 L F
.919 .637 .491 r
.65782 .44208 m .65956 .44043 L .65807 .43965 L F
.65782 .44208 m .65957 .44328 L .65956 .44043 L F
.69 .979 .89 r
.60746 .46539 m .60623 .46715 L .60609 .4665 L F
.591 .819 .429 r
.60514 .46861 m .60623 .46715 L .60746 .46539 L F
.638 .166 .118 r
.6083 .46856 m .60623 .46715 L .60514 .46861 L F
.413 .757 .995 r
.45445 .57587 m .45084 .57513 L .45234 .57589 L F
.98 .702 .422 r
.51214 .69676 m .51182 .69891 L .51306 .69931 L F
.255 .742 .924 r
.51306 .69931 m .51182 .69891 L .50937 .69906 L F
.06 0 .413 r
.51306 .69931 m .5144 .69638 L .51214 .69676 L F
.51306 .69931 m .51465 .69814 L .5144 .69638 L F
.44 .677 .964 r
.51306 .69931 m .51562 .69957 L .51465 .69814 L F
.525 .89 .974 r
.51465 .69814 m .51182 .69891 L .51306 .69931 L F
.07 .633 .761 r
.18654 .54121 m .18837 .5411 L .19035 .54117 L F
.201 .715 .885 r
.18837 .5411 m .19214 .54126 L .19035 .54117 L F
.771 .681 .764 r
.19241 .55428 m .19313 .55801 L .1905 .55781 L F
.773 .536 .576 r
.19449 .56017 m .1905 .55781 L .19313 .55801 L F
0 0 .081 r
.19433 .55678 m .19449 .56017 L .19313 .55801 L F
.756 .458 0 r
.67909 .45131 m .67922 .45164 L .67834 .44881 L F
.71 .695 .834 r
.67922 .45164 m .68089 .44835 L .67834 .44881 L F
.67922 .45164 m .68251 .45036 L .68089 .44835 L F
.742 .709 .82 r
.64507 .4592 m .64121 .45869 L .64352 .45745 L F
.651 .606 .791 r
.70813 .42886 m .71173 .43164 L .71069 .42813 L F
.66 .649 .828 r
.71173 .43164 m .71489 .43022 L .71069 .42813 L F
.71173 .43164 m .7145 .43128 L .71489 .43022 L F
.441 .268 .549 r
.35548 .59634 m .35777 .59805 L .35807 .59586 L F
.35548 .59634 m .35553 .59914 L .35777 .59805 L F
.339 .067 .346 r
.36372 .59086 m .36522 .59216 L .36598 .59044 L F
.36372 .59086 m .3632 .59287 L .36522 .59216 L F
.386 .185 .481 r
.19945 .66696 m .19907 .66943 L .19719 .67002 L F
.314 .029 .311 r
.19719 .67002 m .19907 .66943 L .19684 .67107 L F
.94 .771 .303 r
.67409 .43089 m .67384 .43416 L .67433 .43487 L F
0 0 .501 r
.67503 .43551 m .67433 .43487 L .67384 .43416 L F
.67503 .43551 m .67576 .43693 L .67433 .43487 L F
.465 0 .012 r
.39296 .64058 m .39142 .64207 L .3889 .64113 L F
.547 .068 .07 r
.39474 .642 m .39296 .64058 L .39522 .64052 L F
.39474 .642 m .39142 .64207 L .39296 .64058 L F
.209 0 0 r
.39736 .64028 m .39522 .64052 L .39296 .64058 L F
.622 .173 .164 r
.53535 .69042 m .53456 .69146 L .53196 .69077 L F
.402 .32 .649 r
.53535 .69042 m .53687 .68697 L .5346 .68985 L F
.53535 .69042 m .53569 .69193 L .53687 .68697 L F
.995 .852 .511 r
.5346 .68985 m .53456 .69146 L .53535 .69042 L F
.54 .363 .59 r
.19012 .63767 m .19236 .63722 L .19249 .63497 L F
.773 .914 .532 r
.19052 .64049 m .19236 .63722 L .19012 .63767 L F
.704 .546 .67 r
.69923 .43851 m .70086 .44004 L .70094 .43769 L F
.69923 .43851 m .6988 .44109 L .70086 .44004 L F
.788 .496 .494 r
.46832 .5785 m .46445 .58027 L .4639 .57907 L F
.46832 .5785 m .46777 .58081 L .46445 .58027 L F
.484 .48 .777 r
.46927 .57437 m .46832 .5785 L .46765 .57623 L F
.46927 .57437 m .47036 .57811 L .46832 .5785 L F
.377 .106 .37 r
.47036 .57811 m .46777 .58081 L .46832 .5785 L F
.211 .697 .927 r
.6741 .40149 m .67185 .40148 L .6705 .4009 L F
.427 .285 .585 r
.35361 .6023 m .35553 .59914 L .35335 .5998 L F
.278 0 0 r
.36823 .58979 m .37142 .58878 L .36919 .58899 L F
.122 0 0 r
.18273 .5411 m .18654 .54121 L .18439 .54164 L F
.107 0 .145 r
.21908 .5587 m .21864 .56001 L .22071 .55781 L F
.553 .638 .889 r
.43644 .58725 m .43302 .5859 L .43508 .58544 L F
.331 0 0 r
.43163 .58673 m .43508 .58544 L .43302 .5859 L F
.344 .115 .416 r
.22474 .62873 m .22443 .63131 L .22246 .63154 L F
.385 .218 .528 r
.22443 .63131 m .22226 .63424 L .22246 .63154 L F
.387 0 .006 r
.37985 .58656 m .38227 .58643 L .3838 .58479 L F
.284 0 0 r
.38227 .58643 m .38612 .58446 L .3838 .58479 L F
.673 .232 .196 r
.45302 .63411 m .45186 .63486 L .44945 .6339 L F
.484 0 0 r
.45553 .63463 m .45186 .63486 L .45302 .63411 L F
.856 .911 .87 r
.60242 .435 m .59985 .43774 L .59875 .43667 L F
.164 .266 .724 r
.54628 .6674 m .54714 .66616 L .54503 .66427 L F
.043 .138 .639 r
.62605 .40843 m .62548 .40948 L .62417 .40779 L F
.645 .82 .396 r
.62605 .40843 m .62591 .40866 L .62548 .40948 L F
0 .15 .675 r
.62378 .40754 m .62548 .40948 L .62481 .41074 L F
.645 .82 .396 r
.62591 .40866 m .62478 .41052 L .62548 .40948 L F
0 .15 .675 r
.62481 .41074 m .62548 .40948 L .62498 .41127 L F
.801 .689 .741 r
.62548 .40948 m .62727 .41278 L .62498 .41127 L F
.564 .328 .517 r
.5945 .49893 m .59184 .50186 L .59191 .49932 L F
.195 .33 .774 r
.39179 .62683 m .39078 .6277 L .38874 .62569 L F
.578 .183 .258 r
.43749 .63501 m .43634 .63711 L .43369 .63685 L F
.549 .152 .242 r
.43968 .63641 m .43634 .63711 L .43749 .63501 L F
.835 .775 .794 r
.60297 .45197 m .60604 .45236 L .60501 .4492 L F
.851 .73 .729 r
.60407 .45528 m .60604 .45236 L .60297 .45197 L F
.796 .756 .816 r
.60501 .4492 m .60604 .45236 L .60851 .44945 L F
.485 .699 .964 r
.67246 .46299 m .67607 .46425 L .67578 .46159 L F
.622 .635 .842 r
.67607 .46425 m .67718 .46019 L .67578 .46159 L F
.67607 .46425 m .67858 .46355 L .67718 .46019 L F
.994 .807 .547 r
.55431 .67191 m .55526 .67446 L .55539 .67286 L F
.99 .733 .376 r
.66801 .45212 m .66711 .45389 L .66635 .45139 L F
.66801 .45212 m .66811 .45494 L .66711 .45389 L F
0 0 0 r
.6195 .46283 m .61795 .46372 L .61648 .46519 L F
.367 .831 .767 r
.41679 .57403 m .41999 .57278 L .42082 .57263 L F
.531 .918 .799 r
.42082 .57263 m .4219 .57156 L .42278 .57142 L F
.531 .916 .79 r
.42082 .57263 m .41999 .57278 L .4219 .57156 L F
.774 .718 .8 r
.54228 .51105 m .5432 .51413 L .53988 .51314 L F
.813 .576 .58 r
.5432 .51413 m .53991 .51632 L .53988 .51314 L F
.5432 .51413 m .54312 .51665 L .53991 .51632 L F
.446 .102 .288 r
.47675 .62185 m .4798 .61985 L .4775 .62065 L F
.471 0 0 r
.46519 .63372 m .46378 .63454 L .46149 .63423 L F
0 0 0 r
.46746 .63417 m .46378 .63454 L .46519 .63372 L F
.431 .47 .799 r
.67858 .46355 m .67973 .46708 L .68365 .46542 L F
.998 .853 .539 r
.67561 .4414 m .67653 .44325 L .67692 .44053 L F
.885 .975 .832 r
.6769 .43839 m .67692 .44053 L .67934 .43757 L F
.934 .953 .63 r
.6769 .43839 m .67561 .4414 L .67692 .44053 L F
.477 .659 .941 r
.58032 .61591 m .58073 .61735 L .58186 .61544 L F
.848 .44 0 r
.54503 .66427 m .54306 .66102 L .54314 .66082 L F
.54503 .66427 m .54404 .6632 L .54306 .66102 L F
.67 .12 0 r
.54503 .66427 m .54409 .66481 L .54404 .6632 L F
.54503 .66427 m .54714 .66616 L .54409 .66481 L F
.534 .36 .591 r
.50937 .69906 m .51182 .69891 L .50939 .69647 L F
.661 .352 .438 r
.50939 .69647 m .51182 .69891 L .51214 .69676 L F
.47 .816 .529 r
.66432 .40455 m .66591 .40314 L .66362 .40518 L F
0 0 .406 r
.66362 .40518 m .66405 .40572 L .66432 .40455 L F
.794 .83 .879 r
.66425 .4129 m .66232 .4146 L .66101 .41306 L F
.507 .038 .075 r
.42305 .6373 m .42188 .63891 L .41934 .63777 L F
.683 .282 .281 r
.42539 .63767 m .42188 .63891 L .42305 .6373 L F
.667 .859 .973 r
.46403 .62921 m .45982 .62936 L .4625 .63017 L F
0 0 0 r
.46632 .62844 m .46403 .62921 L .4625 .63017 L F
.254 .733 .934 r
.5502 .69303 m .5515 .69351 L .54785 .69313 L F
.5502 .69303 m .5515 .69351 L .54785 .69313 L F
.423 .239 .524 r
.5515 .69351 m .55133 .69564 L .5495 .69718 L F
.474 .857 .98 r
.5502 .69303 m .55282 .69238 L .5515 .69351 L F
.5502 .69303 m .55282 .69238 L .5515 .69351 L F
.672 .497 .64 r
.54677 .51708 m .54463 .5198 L .54312 .51665 L F
.54677 .51708 m .54639 .51959 L .54463 .5198 L F
.557 .88 .607 r
.73342 .43273 m .73517 .43092 L .73612 .4318 L F
.73342 .43273 m .73263 .43325 L .73517 .43092 L F
.96 .938 .713 r
.56709 .47485 m .56622 .47405 L .56797 .47311 L F
.85 .988 .853 r
.57056 .47043 m .56797 .47311 L .56827 .47117 L F
.881 .992 .762 r
.56797 .47311 m .56622 .47405 L .56827 .47117 L F
.637 .445 .606 r
.55823 .51924 m .5559 .52267 L .55638 .51979 L F
.55823 .51924 m .55937 .52228 L .5559 .52267 L F
.618 .359 .503 r
.55823 .51924 m .56212 .52168 L .55937 .52228 L F
.55823 .51924 m .56214 .51933 L .56212 .52168 L F
.541 .569 .832 r
.62204 .41707 m .62382 .41274 L .62082 .41611 L F
.216 .132 .54 r
.62204 .41707 m .62288 .41944 L .62344 .4168 L F
.632 .181 .161 r
.42611 .63013 m .42863 .63066 L .43024 .62923 L F
.581 .118 .119 r
.42863 .63066 m .43237 .63061 L .43024 .62923 L F
.496 .221 .426 r
.43024 .62923 m .43237 .63061 L .43291 .62897 L F
.472 .499 .805 r
.46927 .57437 m .46765 .57623 L .46648 .57346 L F
.369 .125 .408 r
.41981 .58162 m .41905 .58429 L .41734 .58462 L F
.043 0 .25 r
.42069 .58312 m .41905 .58429 L .41981 .58162 L F
.443 .051 .199 r
.4459 .63477 m .44325 .63621 L .44382 .63521 L F
.772 .811 .883 r
.6414 .46189 m .63912 .46267 L .64071 .46062 L F
.697 .632 .78 r
.70448 .42594 m .70721 .42568 L .70686 .42299 L F
.662 .573 .744 r
.70448 .42594 m .70813 .42886 L .70721 .42568 L F
.768 .67 .755 r
.70092 .42541 m .70448 .42594 L .70328 .42241 L F
.698 .633 .78 r
.70328 .42241 m .70448 .42594 L .70686 .42299 L F
.793 .668 .726 r
.54628 .50468 m .54777 .50823 L .54432 .50763 L F
.542 .337 .552 r
.55034 .51999 m .54854 .52372 L .54639 .51959 L F
.55034 .51999 m .55035 .52246 L .54854 .52372 L F
.19 0 .303 r
.51814 .6573 m .51605 .66063 L .51669 .65856 L F
.51669 .65856 m .51605 .66063 L .51814 .6573 L F
.51669 .65856 m .51605 .66063 L .51814 .6573 L F
.827 .872 .878 r
.64437 .42163 m .64274 .42562 L .64241 .42457 L F
.64437 .42163 m .6457 .42297 L .64274 .42562 L F
.857 .441 0 r
.64274 .42562 m .64265 .42696 L .64241 .42457 L F
.64274 .42562 m .64378 .42789 L .64265 .42696 L F
.241 0 0 r
.38847 .5842 m .39084 .58376 L .39236 .58217 L F
.105 0 0 r
.39236 .58217 m .39301 .58307 L .39452 .58168 L F
.39236 .58217 m .39084 .58376 L .39301 .58307 L F
.975 .691 .421 r
.66941 .44339 m .66813 .44525 L .66791 .44222 L F
.66941 .44339 m .66963 .44638 L .66813 .44525 L F
.915 .771 .688 r
.65685 .45101 m .6599 .44878 L .65853 .44689 L F
.65685 .45101 m .6585 .45235 L .6599 .44878 L F
.201 0 0 r
.68306 .42447 m .68168 .42466 L .67833 .42447 L F
.37 .837 .806 r
.68401 .42383 m .68306 .42447 L .68531 .42516 L F
.68401 .42383 m .68168 .42466 L .68306 .42447 L F
.87 .98 .844 r
.55003 .49532 m .55334 .49325 L .55138 .49643 L F
.55003 .49532 m .55255 .49249 L .55334 .49325 L F
.91 .974 .793 r
.55334 .49325 m .55477 .48936 L .55587 .49032 L F
.55334 .49325 m .55255 .49249 L .55477 .48936 L F
.783 .751 .823 r
.74665 .42277 m .74306 .42247 L .74597 .42135 L F
.584 .684 .91 r
.74597 .42135 m .74905 .42286 L .74665 .42277 L F
.626 .489 .676 r
.74926 .42513 m .74665 .42277 L .74905 .42286 L F
.74926 .42513 m .74701 .42567 L .74665 .42277 L F
.726 .694 .819 r
.69128 .42498 m .69224 .42829 L .69489 .42563 L F
.088 .646 .785 r
.19569 .66367 m .19773 .66359 L .19489 .66363 L F
.73 .64 .759 r
.54785 .69313 m .5495 .69718 L .54555 .69638 L F
.43 .752 .995 r
.54555 .69638 m .5495 .69718 L .54823 .69598 L F
.769 .894 .932 r
.54823 .69598 m .5495 .69718 L .54785 .69313 L F
.54823 .69598 m .55133 .69564 L .5495 .69718 L F
.5495 .69718 m .55133 .69564 L .54823 .69598 L F
.423 0 0 r
.20447 .55388 m .20019 .55239 L .20232 .55423 L F
.523 .306 .526 r
.54605 .6749 m .54632 .67246 L .54391 .67293 L F
.54605 .6749 m .54632 .67246 L .54391 .67293 L F
.608 .922 .677 r
.32836 .8044 m .33003 .80335 L .32763 .80546 L F
.257 .6 .952 r
.32763 .80546 m .33013 .80591 L .32836 .8044 L F
.576 .916 .699 r
.62367 .48098 m .62682 .4785 L .62524 .47933 L F
.62367 .48098 m .62524 .47933 L .62379 .48094 L F
.955 .609 .277 r
.55048 .67303 m .54909 .67242 L .54837 .67013 L F
.969 .888 .694 r
.55048 .67303 m .54936 .67508 L .54909 .67242 L F
.536 .508 .773 r
.74046 .4128 m .74165 .41664 L .73925 .41717 L F
.74046 .4128 m .73925 .41717 L .73956 .4168 L F
.142 .684 .819 r
.73925 .41717 m .7356 .41725 L .73956 .4168 L F
.552 .512 .765 r
.74312 .41895 m .73925 .41717 L .74165 .41664 L F
.39 .157 .436 r
.23769 .60462 m .23735 .60733 L .23516 .60791 L F
.443 .346 .651 r
.23955 .60169 m .23949 .60448 L .23769 .60462 L F
.486 .237 .463 r
.23944 .60642 m .23769 .60462 L .23949 .60448 L F
.23944 .60642 m .23735 .60733 L .23769 .60462 L F
.779 .79 .862 r
.55905 .63139 m .55589 .6336 L .55788 .63281 L F
.06 0 .163 r
.41905 .58429 m .41728 .58655 L .41734 .58462 L F
.801 .775 .829 r
.52303 .54937 m .51949 .54926 L .52147 .54805 L F
.576 .532 .768 r
.52409 .54521 m .52303 .54937 L .52147 .54805 L F
.52409 .54521 m .52544 .54893 L .52303 .54937 L F
.339 .166 .494 r
.52545 .5502 m .52303 .54937 L .52544 .54893 L F
.52545 .5502 m .52291 .55178 L .52303 .54937 L F
.759 .847 .917 r
.62378 .40754 m .62162 .40931 L .62044 .40779 L F
0 .436 .837 r
.52619 .68436 m .52863 .686 L .52505 .68416 L F
.687 .42 .514 r
.52759 .68602 m .52619 .68436 L .5259 .68584 L F
.5296 .68623 m .52852 .68563 L .52759 .68602 L F
.52852 .68563 m .52619 .68436 L .52759 .68602 L F
.537 .921 .799 r
.52863 .686 m .53011 .68497 L .53076 .68486 L F
0 0 0 r
.53129 .68403 m .53092 .68441 L .5296 .68623 L F
.639 .909 .607 r
.53076 .68486 m .53092 .68441 L .53194 .68318 L F
0 0 0 r
.53194 .68318 m .53092 .68441 L .53129 .68403 L F
.537 .921 .799 r
.53054 .68479 m .53092 .68441 L .53083 .68467 L F
.53011 .68497 m .53092 .68441 L .53054 .68479 L F
.53011 .68497 m .53083 .68467 L .53076 .68486 L F
.401 .172 .448 r
.52872 .68756 m .531 .68706 L .53076 .68486 L F
.52872 .68756 m .531 .68706 L .53076 .68486 L F
.943 .588 .302 r
.53076 .68486 m .5296 .68623 L .53194 .68318 L F
.53076 .68486 m .531 .68706 L .5296 .68623 L F
.857 .636 .602 r
.54339 .65813 m .54031 .66048 L .54193 .65747 L F
.54339 .65813 m .54306 .66102 L .54031 .66048 L F
.858 .743 .227 r
.54314 .66082 m .54306 .66102 L .54339 .65813 L F
.96 .736 .555 r
.21393 .59343 m .2117 .59521 L .21163 .59273 L F
.811 .799 .841 r
.21393 .59343 m .21163 .59273 L .21445 .58942 L F
.988 .721 .37 r
.54874 .65974 m .54969 .65818 L .54637 .65722 L F
.54874 .65974 m .54977 .66068 L .54969 .65818 L F
.454 .246 .507 r
.21043 .60515 m .21243 .60471 L .21273 .60215 L F
.511 .35 .599 r
.21037 .60777 m .21243 .60471 L .21043 .60515 L F
.56 .827 .996 r
.54572 .63038 m .54699 .63138 L .54343 .63104 L F
.54572 .63038 m .54699 .63138 L .54343 .63104 L F
.654 .863 .979 r
.54959 .63023 m .54699 .63138 L .54572 .63038 L F
.54572 .63038 m .54699 .63138 L .54959 .63023 L F
0 .453 .864 r
.54699 .63138 m .55105 .63356 L .54959 .63023 L F
.713 .712 .847 r
.44003 .56709 m .43844 .57128 L .43621 .56658 L F
.357 .036 .278 r
.61383 .48673 m .61611 .4846 L .61552 .48622 L F
.278 0 0 r
.61611 .4846 m .61765 .4856 L .61552 .48622 L F
.61611 .4846 m .61861 .4842 L .61765 .4856 L F
.287 .051 .371 r
.23334 .61639 m .23106 .61936 L .23161 .61713 L F
.649 .552 .732 r
.70086 .44004 m .70348 .43718 L .70094 .43769 L F
.483 .238 .467 r
.72918 .4407 m .72899 .44284 L .72652 .44348 L F
.564 .367 .572 r
.73151 .43984 m .72899 .44284 L .72918 .4407 L F
.641 .759 .934 r
.68488 .41128 m .68622 .41359 L .68887 .41273 L F
.628 .616 .819 r
.68622 .41359 m .68923 .41459 L .68887 .41273 L F
.649 .552 .732 r
.70086 .44004 m .70473 .44061 L .70348 .43718 L F
0 0 0 r
.62623 .45658 m .62548 .45795 L .62698 .45492 L F
.52 .076 .135 r
.6223 .45692 m .62387 .4581 L .62529 .45614 L F
.829 .91 .506 r
.62529 .45614 m .62387 .4581 L .62454 .45667 L F
.7 .768 .277 r
.62144 .45419 m .62105 .4553 L .62062 .45631 L F
.62105 .4553 m .62018 .45774 L .62062 .45631 L F
.744 .453 .489 r
.62062 .45631 m .62529 .45614 L .62418 .45449 L F
.392 .699 .982 r
.62018 .45774 m .6223 .45692 L .62062 .45631 L F
.7 .768 .277 r
.62144 .45419 m .62062 .45631 L .62057 .45393 L F
.744 .453 .489 r
.62062 .45631 m .62418 .45449 L .62057 .45393 L F
.52 .076 .135 r
.6223 .45692 m .62529 .45614 L .62062 .45631 L F
.924 .907 .787 r
.62048 .45921 m .6195 .46283 L .61836 .46188 L F
.62091 .45986 m .6195 .46283 L .62048 .45921 L F
.6223 .45692 m .61847 .46175 L .61989 .46035 L F
.61847 .46175 m .61836 .46188 L .61989 .46035 L F
.6223 .45692 m .62091 .45986 L .62048 .45921 L F
.433 .121 .334 r
.61989 .46035 m .62387 .4581 L .6223 .45692 L F
.769 .846 .91 r
.62182 .45698 m .6228 .45751 L .61989 .46035 L F
.6228 .45751 m .62387 .4581 L .61989 .46035 L F
.7 .941 .961 r
.61815 .4577 m .61944 .45862 L .61768 .45779 L F
1 .817 .498 r
.62062 .45631 m .62018 .45875 L .61973 .45805 L F
.62018 .45875 m .61989 .46035 L .61973 .45805 L F
0 0 0 r
.62186 .45455 m .62014 .45744 L .62062 .45631 L F
.62014 .45744 m .61944 .45862 L .62062 .45631 L F
.727 .36 .355 r
.62062 .45631 m .61944 .45862 L .61693 .45605 L F
.771 .525 .562 r
.62057 .45393 m .62062 .45631 L .61693 .45605 L F
.464 .373 .668 r
.61693 .45605 m .61944 .45862 L .61933 .4551 L F
0 0 .362 r
.62167 .45446 m .62062 .45631 L .62057 .45393 L F
.62186 .45455 m .62166 .45484 L .62167 .45446 L F
.62166 .45484 m .62062 .45631 L .62167 .45446 L F
.97 .661 .283 r
.61925 .4513 m .62057 .45393 L .61912 .45246 L F
.771 .525 .562 r
.62057 .45393 m .61693 .45605 L .61912 .45246 L F
.401 .538 .878 r
.62262 .45258 m .62057 .45393 L .61925 .4513 L F
.561 .286 .455 r
.61933 .4551 m .62169 .4533 L .61912 .45246 L F
.62169 .4533 m .62262 .45258 L .6217 .45255 L F
.62169 .4533 m .6217 .45255 L .61912 .45246 L F
.638 .511 .692 r
.61933 .4551 m .61944 .45862 L .62186 .45455 L F
.425 .254 .545 r
.62186 .45455 m .61944 .45862 L .62182 .45698 L F
.7 .941 .961 r
.62182 .45698 m .61944 .45862 L .61815 .4577 L F
1 .817 .498 r
.61973 .45805 m .61979 .45887 L .61944 .45862 L F
.61979 .45887 m .61989 .46035 L .61944 .45862 L F
.014 .184 .695 r
.62529 .45614 m .62623 .45658 L .62418 .45449 L F
.829 .91 .506 r
.6253 .45582 m .62454 .45667 L .62532 .45502 L F
.62529 .45614 m .62454 .45667 L .6253 .45582 L F
0 0 0 r
.62623 .45658 m .62698 .45492 L .62621 .4548 L F
.62539 .45572 m .62621 .4548 L .62418 .45449 L F
.62623 .45658 m .62621 .4548 L .62539 .45572 L F
.212 0 .045 r
.4762 .62921 m .47707 .63051 L .47497 .63111 L F
.4762 .62921 m .47839 .62842 L .47707 .63051 L F
.371 .029 .249 r
.22686 .57236 m .229 .57187 L .22989 .56949 L F
.184 .001 .384 r
.22989 .56949 m .2317 .56887 L .23213 .56649 L F
.336 0 .234 r
.22989 .56949 m .2311 .57127 L .2317 .56887 L F
.22989 .56949 m .229 .57187 L .2311 .57127 L F
.726 .608 .726 r
.59795 .47259 m .60125 .47298 L .60047 .46953 L F
.723 .535 .636 r
.59809 .47541 m .60125 .47298 L .59795 .47259 L F
.59809 .47541 m .60173 .47564 L .60125 .47298 L F
.34 .349 .724 r
.60047 .46953 m .60125 .47298 L .60318 .47123 L F
.209 .183 .608 r
.60125 .47298 m .60354 .47368 L .60318 .47123 L F
.60125 .47298 m .60173 .47564 L .60354 .47368 L F
.488 .327 .588 r
.38761 .60496 m .38585 .60827 L .385 .60551 L F
0 0 0 r
.57427 .62512 m .57462 .62444 L .57554 .62252 L F
.701 .903 .968 r
.45743 .63086 m .45408 .63107 L .45633 .6323 L F
.04 0 0 r
.45982 .62936 m .45743 .63086 L .45888 .63088 L F
.035 0 0 r
.45888 .63088 m .45743 .63086 L .45633 .6323 L F
.403 .683 .975 r
.37092 .6298 m .37264 .63138 L .37324 .62994 L F
.05 .256 .752 r
.37264 .63138 m .37365 .63165 L .37324 .62994 L F
.324 0 0 r
.43644 .58725 m .43572 .58816 L .43318 .58835 L F
.117 .656 .85 r
.43821 .58712 m .43644 .58725 L .43508 .58544 L F
.43821 .58712 m .43917 .5874 L .43644 .58725 L F
.111 0 0 r
.43821 .58712 m .43644 .58725 L .43917 .5874 L F
.43821 .58712 m .43572 .58816 L .43644 .58725 L F
.616 .56 .769 r
.70721 .42568 m .70929 .42238 L .70686 .42299 L F
.70721 .42568 m .71056 .42615 L .70929 .42238 L F
.664 .551 .716 r
.70721 .42568 m .71069 .42813 L .71056 .42615 L F
.70721 .42568 m .70813 .42886 L .71069 .42813 L F
.068 0 .122 r
.20827 .65213 m .20743 .65444 L .20579 .65505 L F
.213 0 .327 r
.21054 .64915 m .21011 .65176 L .20827 .65213 L F
.027 0 .103 r
.20894 .65335 m .20827 .65213 L .21011 .65176 L F
.20894 .65335 m .20743 .65444 L .20827 .65213 L F
.248 .008 .339 r
.2272 .62592 m .22657 .62809 L .22474 .62873 L F
.225 .019 .377 r
.22598 .63037 m .22474 .62873 L .22657 .62809 L F
.22598 .63037 m .22443 .63131 L .22474 .62873 L F
.748 .633 .733 r
.60131 .46068 m .60268 .4638 L .60493 .46112 L F
.701 .522 .643 r
.58596 .62763 m .58748 .63118 L .58855 .62832 L F
.658 .726 .9 r
.45957 .57778 m .46221 .57832 L .46071 .57756 L F
.563 .007 0 r
.46221 .57832 m .46445 .58027 L .46294 .57934 L F
.664 .207 .157 r
.4639 .57907 m .46445 .58027 L .46221 .57832 L F
.24 .318 .743 r
.46071 .57756 m .46294 .57934 L .46225 .57725 L F
.46071 .57756 m .46225 .57725 L .46189 .57613 L F
.658 .726 .9 r
.45869 .5776 m .45957 .57778 L .46071 .57756 L F
.115 0 .431 r
.21426 .59855 m .21273 .60215 L .21426 .601 L F
.348 .232 .577 r
.21243 .60471 m .21426 .601 L .21273 .60215 L F
.612 .618 .832 r
.69699 .40798 m .69456 .40876 L .69317 .4057 L F
.885 .975 .832 r
.6769 .43839 m .67934 .43757 L .67576 .43693 L F
.244 .659 .962 r
.67759 .41934 m .67549 .41993 L .67437 .41875 L F
.236 .657 .959 r
.67549 .41993 m .67757 .41942 L .67437 .41875 L F
.244 .659 .962 r
.67759 .41934 m .6779 .42028 L .67549 .41993 L F
.236 .657 .959 r
.67549 .41993 m .6774 .42021 L .67753 .41943 L F
.567 .935 .812 r
.67589 .41936 m .67409 .42101 L .67754 .41937 L F
.306 .613 .955 r
.67757 .41942 m .67759 .41934 L .67437 .41875 L F
.567 .935 .812 r
.67755 .41934 m .67754 .41937 L .67759 .41934 L F
.67589 .41936 m .67754 .41937 L .67755 .41934 L F
.236 .657 .959 r
.67753 .41943 m .6779 .42028 L .67757 .41942 L F
.6774 .42021 m .6779 .42028 L .67753 .41943 L F
.98 .686 .354 r
.55089 .66536 m .55196 .66363 L .5522 .66269 L F
.55089 .66536 m .5521 .66668 L .55196 .66363 L F
.37 .684 .979 r
.23784 .54521 m .23739 .5466 L .23603 .54486 L F
.23784 .54521 m .23948 .54655 L .23739 .5466 L F
.57 .862 .996 r
.57646 .63871 m .57714 .63708 L .57497 .63789 L F
.57646 .63871 m .57874 .63802 L .57714 .63708 L F
.181 0 0 r
.17254 .55808 m .17465 .55747 L .1725 .55812 L F
.955 .769 .613 r
.23331 .81842 m .23577 .81757 L .23122 .81659 L F
.23331 .81842 m .23486 .8195 L .23577 .81757 L F
.784 .649 .714 r
.41905 .58429 m .42045 .58613 L .42367 .58468 L F
.546 0 0 r
.42429 .58555 m .42367 .58468 L .42206 .58549 L F
.992 .739 .403 r
.42429 .58555 m .42328 .58527 L .42331 .58508 L F
.42429 .58555 m .42331 .58508 L .42357 .58339 L F
.546 0 0 r
.42429 .58555 m .42614 .58665 L .42551 .58615 L F
.42429 .58555 m .42551 .58615 L .42367 .58468 L F
.222 .712 .924 r
.22993 .54335 m .23216 .54332 L .23364 .5438 L F
.507 0 0 r
.23216 .54332 m .23603 .54486 L .23364 .5438 L F
0 0 .17 r
.25507 .55207 m .25379 .55264 L .25335 .55124 L F
.25507 .55207 m .25462 .55495 L .25379 .55264 L F
.906 .922 .817 r
.55587 .49032 m .55697 .4863 L .558 .48724 L F
.885 .939 .846 r
.558 .48724 m .55944 .48333 L .56063 .48436 L F
.558 .48724 m .55697 .4863 L .55944 .48333 L F
.554 .32 .515 r
.67205 .41692 m .67206 .41864 L .67071 .41585 L F
.67205 .41692 m .67437 .41875 L .67206 .41864 L F
.887 .949 .842 r
.57298 .46749 m .57056 .47043 L .57074 .46799 L F
.904 .958 .819 r
.57056 .47043 m .56827 .47117 L .57074 .46799 L F
.587 .728 .941 r
.69224 .40399 m .69064 .40628 L .68973 .40458 L F
.69224 .40399 m .69317 .4057 L .69064 .40628 L F
.708 .796 .919 r
.61354 .46541 m .61208 .46905 L .61147 .46676 L F
.61354 .46541 m .61528 .46704 L .61208 .46905 L F
.773 .914 .532 r
.19052 .64049 m .19092 .6391 L .19236 .63722 L F
.791 .672 .733 r
.18916 .64195 m .19052 .64049 L .18863 .64135 L F
.18916 .64195 m .19092 .6391 L .19052 .64049 L F
.495 .082 .186 r
.44466 .63133 m .44907 .63014 L .44836 .62963 L F
.671 .202 .131 r
.45177 .63068 m .44836 .62963 L .45012 .63108 L F
0 .182 .708 r
.44907 .63014 m .45012 .63108 L .44836 .62963 L F
.169 .684 .892 r
.52485 .68708 m .52872 .68756 L .52736 .68711 L F
.543 .345 .562 r
.52625 .69049 m .52851 .69026 L .52872 .68756 L F
.45 .784 .998 r
.52872 .68756 m .5296 .68623 L .52736 .68711 L F
.52872 .68756 m .531 .68706 L .5296 .68623 L F
.702 .618 .761 r
.52851 .69026 m .531 .68706 L .52872 .68756 L F
.376 .219 .537 r
.23713 .60969 m .23516 .60791 L .23735 .60733 L F
.23713 .60969 m .23499 .61138 L .23516 .60791 L F
.17 .359 .809 r
.20036 .66571 m .19945 .66696 L .19773 .66359 L F
0 0 .297 r
.20036 .66571 m .19907 .66943 L .19945 .66696 L F
.493 .588 .878 r
.49618 .69244 m .49752 .68978 L .49468 .69051 L F
.242 0 .062 r
.49618 .69244 m .49907 .69077 L .49795 .69224 L F
.493 .588 .878 r
.49618 .69244 m .49795 .69224 L .49752 .68978 L F
.485 .291 .541 r
.19236 .63722 m .19463 .63437 L .19249 .63497 L F
.788 .65 .71 r
.59912 .46367 m .60268 .4638 L .60131 .46068 L F
.655 .387 .503 r
.59906 .46603 m .60268 .4638 L .59912 .46367 L F
.59906 .46603 m .60249 .4666 L .60268 .4638 L F
.658 .39 .503 r
.60249 .4666 m .60609 .4665 L .60268 .4638 L F
0 0 0 r
.66819 .40199 m .66591 .40314 L .66432 .40455 L F
.536 .319 .532 r
.52625 .69049 m .52615 .69284 L .52851 .69026 L F
.699 .373 .422 r
.57974 .60981 m .58239 .61054 L .58153 .60824 L F
.711 .402 .452 r
.58381 .61019 m .58153 .60824 L .58239 .61054 L F
0 0 0 r
.17465 .55747 m .17062 .5588 L .1725 .55812 L F
.66 .63 .808 r
.67329 .41053 m .67821 .41268 L .6748 .40768 L F
.625 .644 .849 r
.67566 .40971 m .67821 .41268 L .67329 .41053 L F
.901 .628 .123 r
.67861 .41074 m .67821 .41268 L .67566 .40971 L F
.67861 .41074 m .67893 .41007 L .67821 .41268 L F
.856 .911 .87 r
.60242 .435 m .59875 .43667 L .60134 .43397 L F
.906 .915 .816 r
.60466 .4318 m .60242 .435 L .60134 .43397 L F
.164 0 .119 r
.20743 .65444 m .20456 .65706 L .20579 .65505 L F
.292 .014 .309 r
.21306 .64623 m .2125 .64882 L .21054 .64915 L F
.265 .044 .38 r
.21528 .6432 m .215 .64586 L .21306 .64623 L F
.138 0 .251 r
.21404 .64783 m .21306 .64623 L .215 .64586 L F
.21404 .64783 m .2125 .64882 L .21306 .64623 L F
.906 .915 .816 r
.60466 .4318 m .60134 .43397 L .60363 .43068 L F
.862 .909 .863 r
.60713 .42914 m .60466 .4318 L .60363 .43068 L F
.488 .369 .644 r
.25369 .57164 m .25158 .5702 L .2532 .56885 L F
.25369 .57164 m .25188 .57255 L .25158 .5702 L F
.891 .921 .836 r
.56492 .47809 m .56622 .47405 L .56709 .47485 L F
.737 .665 .78 r
.55035 .52246 m .55147 .52535 L .54783 .52573 L F
.658 .329 .404 r
.54783 .52573 m .55147 .52535 L .55068 .52784 L F
.754 .569 .646 r
.55035 .52246 m .55402 .52539 L .55147 .52535 L F
.577 .254 .386 r
.55402 .52539 m .55068 .52784 L .55147 .52535 L F
.628 .669 .87 r
.73076 .42058 m .72737 .41948 L .73027 .4187 L F
.501 .741 .98 r
.73224 .4191 m .73076 .42058 L .73027 .4187 L F
.73224 .4191 m .73387 .42038 L .73076 .42058 L F
.667 .959 .94 r
.26244 .80208 m .2602 .80269 L .26144 .80154 L F
.832 .639 .641 r
.2583 .80465 m .26244 .80208 L .26069 .80425 L F
.2583 .80465 m .2602 .80269 L .26244 .80208 L F
.595 .389 .572 r
.26144 .80154 m .26069 .80425 L .26244 .80208 L F
.688 .769 .913 r
.4497 .56676 m .44787 .56821 L .44597 .56625 L F
.367 0 0 r
.52391 .69456 m .52218 .69309 L .52217 .69486 L F
.52391 .69456 m .52615 .69284 L .52218 .69309 L F
.796 .76 .82 r
.54605 .6749 m .54936 .67508 L .54766 .67782 L F
.698 .687 .836 r
.54201 .69128 m .54324 .68729 L .54089 .68834 L F
.54201 .69128 m .54429 .69041 L .54324 .68729 L F
.933 .68 .531 r
.5446 .69412 m .54429 .69041 L .54201 .69128 L F
.579 .354 .538 r
.54201 .69128 m .54444 .69298 L .54429 .69041 L F
.771 .931 .572 r
.49795 .69224 m .49907 .69077 L .4998 .68931 L F
.797 .729 .789 r
.61466 .45187 m .61572 .45516 L .61759 .45175 L F
.757 .791 .881 r
.53569 .69193 m .53917 .68655 L .53687 .68697 L F
.53569 .69193 m .54089 .68834 L .53917 .68655 L F
.412 0 0 r
.33062 .80381 m .33003 .80335 L .32836 .8044 L F
.33062 .80381 m .33242 .805 L .33003 .80335 L F
.79 .346 .191 r
.63688 .45918 m .64005 .45915 L .63657 .45671 L F
.63688 .45918 m .6382 .45987 L .64005 .45915 L F
.859 .733 .723 r
.63657 .45671 m .64005 .45915 L .63919 .45453 L F
.545 .085 .112 r
.39902 .64026 m .39522 .64052 L .39736 .64028 L F
.521 .659 .922 r
.69319 .41755 m .69477 .41565 L .69256 .41594 L F
.69319 .41755 m .69522 .41706 L .69477 .41565 L F
.655 .759 .926 r
.67078 .46126 m .67246 .46299 L .67578 .46159 L F
.293 .791 .825 r
.69363 .44823 m .69592 .44751 L .69654 .44694 L F
0 0 0 r
.69779 .4467 m .69654 .44694 L .69592 .44751 L F
.69779 .4467 m .69901 .44635 L .69654 .44694 L F
.906 .922 .817 r
.55587 .49032 m .55477 .48936 L .55697 .4863 L F
.404 .234 .534 r
.25188 .57255 m .25169 .57519 L .24985 .57575 L F
.448 .354 .657 r
.25169 .57519 m .25205 .57769 L .24985 .57575 L F
.47 .355 .64 r
.24985 .57575 m .25205 .57769 L .25011 .57827 L F
.613 .417 .592 r
.39024 .60219 m .39089 .60511 L .38761 .60496 L F
.557 .377 .593 r
.39273 .59912 m .39314 .60232 L .39024 .60219 L F
.192 0 .272 r
.39314 .60232 m .39089 .60511 L .39024 .60219 L F
.343 0 0 r
.62012 .42202 m .61681 .42185 L .61819 .4216 L F
.773 .995 .87 r
.55305 .63492 m .55589 .6336 L .5554 .63582 L F
0 .148 .692 r
.55589 .6336 m .5589 .63697 L .5589 .63696 L F
.55792 .63502 m .5589 .63696 L .55808 .63513 L F
.55589 .6336 m .5589 .63696 L .55792 .63502 L F
.55589 .6336 m .55808 .63513 L .5554 .63582 L F
.649 .641 .829 r
.5554 .63582 m .55649 .6322 L .55428 .63303 L F
.55649 .6322 m .55656 .63197 L .55641 .63204 L F
.55649 .6322 m .55641 .63204 L .55428 .63303 L F
.854 .896 .866 r
.55034 .68302 m .55375 .68159 L .55342 .6808 L F
.508 .024 .042 r
.39902 .64026 m .39759 .64169 L .39522 .64052 L F
.401 0 0 r
.4008 .64194 m .39902 .64026 L .40128 .64055 L F
.4008 .64194 m .39759 .64169 L .39902 .64026 L F
.356 .51 .873 r
.37613 .63422 m .37729 .63255 L .37365 .63165 L F
.37613 .63422 m .3775 .63409 L .37729 .63255 L F
.142 0 0 r
.68897 .45881 m .69188 .45816 L .6924 .4573 L F
.253 0 .067 r
.69188 .45816 m .6939 .45607 L .6924 .4573 L F
.344 .818 .89 r
.19811 .54144 m .2004 .54086 L .20223 .541 L F
.244 .73 .926 r
.2004 .54086 m .20431 .54119 L .20223 .541 L F
.169 .684 .891 r
.20831 .54173 m .21031 .54173 L .21215 .54217 L F
.343 .784 .962 r
.21031 .54173 m .21411 .54193 L .21215 .54217 L F
0 0 0 r
.40012 .59485 m .39698 .59676 L .40116 .59419 L F
.491 .153 .321 r
.40049 .59764 m .39698 .59676 L .40012 .59485 L F
.40049 .59764 m .39778 .59816 L .39698 .59676 L F
.876 .878 .833 r
.64071 .46062 m .63912 .46267 L .6382 .45987 L F
.165 .694 .863 r
.19214 .54126 m .19447 .54119 L .19624 .54156 L F
.292 0 0 r
.19447 .54119 m .19811 .54144 L .19624 .54156 L F
.885 .826 .784 r
.62002 .41194 m .61766 .41315 L .61751 .41234 L F
0 0 .137 r
.61749 .41396 m .61751 .41234 L .61731 .4113 L F
.885 .826 .784 r
.61766 .41315 m .61657 .4137 L .61751 .41234 L F
0 0 .137 r
.61731 .4113 m .61751 .41234 L .61723 .41 L F
.644 .676 .865 r
.68089 .44835 m .68251 .45036 L .68453 .44899 L F
.555 .325 .522 r
.58898 .50235 m .58883 .50479 L .58645 .50505 L F
.627 .439 .608 r
.59184 .50186 m .58883 .50479 L .58898 .50235 L F
.839 .557 .511 r
.67353 .44476 m .67653 .44325 L .67561 .4414 L F
.67353 .44476 m .67773 .44528 L .67653 .44325 L F
.772 .723 .807 r
.60724 .44757 m .60851 .44945 L .60773 .44632 L F
.796 .756 .816 r
.60501 .4492 m .60851 .44945 L .60724 .44757 L F
.446 .701 .975 r
.68165 .40909 m .6828 .41052 L .68397 .40901 L F
.225 .382 .811 r
.68397 .40901 m .6828 .41052 L .68488 .41128 L F
.64 .496 .671 r
.59136 .6254 m .58855 .62832 L .58975 .62657 L F
.427 .285 .585 r
.35361 .6023 m .35553 .60167 L .35553 .59914 L F
.44 .319 .619 r
.35361 .6023 m .35575 .60429 L .35553 .60167 L F
.389 .316 .652 r
.35405 .60488 m .35575 .60429 L .35361 .6023 L F
.687 .631 .787 r
.58379 .61399 m .58239 .61054 L .58191 .61297 L F
.58379 .61399 m .58381 .61019 L .58239 .61054 L F
.58379 .61399 m .58588 .6116 L .58381 .61019 L F
.648 .213 .201 r
.58186 .61544 m .58379 .61399 L .58191 .61297 L F
.58186 .61544 m .58516 .61588 L .58379 .61399 L F
.644 .671 .861 r
.69114 .42179 m .68749 .41986 L .69002 .41908 L F
.437 .853 .959 r
.69034 .42128 m .69114 .42179 L .69002 .41908 L F
.69034 .42128 m .69367 .42118 L .69114 .42179 L F
.862 .996 .797 r
.57543 .46447 m .57298 .46749 L .57361 .46531 L F
.83 .979 .883 r
.57298 .46749 m .57074 .46799 L .57361 .46531 L F
.396 .072 .294 r
.52988 .69341 m .52696 .69595 L .52654 .69529 L F
.386 .217 .526 r
.24817 .58418 m .24828 .5867 L .24597 .58744 L F
.395 .216 .517 r
.24828 .5867 m .24578 .58979 L .24597 .58744 L F
.576 .579 .819 r
.68887 .41273 m .68923 .41459 L .69133 .41219 L F
.612 .519 .726 r
.68923 .41459 m .69256 .41594 L .69133 .41219 L F
.68923 .41459 m .6901 .41712 L .69256 .41594 L F
.697 .546 .679 r
.55422 .52282 m .55638 .51979 L .5559 .52267 L F
.411 .085 .3 r
.72652 .44348 m .72903 .4444 L .72631 .44483 L F
.72652 .44348 m .72899 .44284 L .72903 .4444 L F
.511 .249 .454 r
.25651 .55632 m .2537 .55821 L .25462 .55495 L F
.25651 .55632 m .25462 .55495 L .2547 .55569 L F
0 0 .17 r
.25507 .55207 m .2547 .55569 L .25462 .55495 L F
.762 .99 .891 r
.64496 .44681 m .64353 .44669 L .64607 .44486 L F
.878 .973 .664 r
.58201 .45513 m .58002 .45833 L .58054 .4562 L F
.874 .984 .833 r
.58201 .45513 m .58239 .45284 L .58459 .4523 L F
.58201 .45513 m .58148 .45429 L .58239 .45284 L F
.964 .936 .631 r
.58054 .4562 m .58148 .45429 L .58201 .45513 L F
.749 .641 .74 r
.54312 .51665 m .54463 .5198 L .54081 .51966 L F
.661 .454 .593 r
.54463 .5198 m .54639 .51959 L .54467 .52249 L F
.655 .631 .814 r
.68666 .41759 m .68424 .41961 L .68376 .41709 L F
.324 0 0 r
.68523 .41794 m .68376 .41709 L .68327 .41758 L F
.68523 .41794 m .68666 .41759 L .68376 .41709 L F
.929 .897 .775 r
.56492 .47809 m .56184 .48036 L .56381 .47711 L F
.56492 .47809 m .563 .48138 L .56184 .48036 L F
.891 .921 .836 r
.56492 .47809 m .56381 .47711 L .56622 .47405 L F
.778 .534 .567 r
.52863 .54018 m .52284 .54193 L .52294 .53928 L F
.52863 .54018 m .52664 .54252 L .52284 .54193 L F
.458 .594 .9 r
.52868 .53915 m .52863 .54018 L .52525 .53656 L F
.941 .962 .732 r
.52868 .53915 m .52664 .54252 L .52863 .54018 L F
.652 .294 .353 r
.53016 .54046 m .52664 .54252 L .52868 .53915 L F
.53016 .54046 m .52895 .54244 L .52664 .54252 L F
.668 .807 .95 r
.53094 .5387 m .53016 .54046 L .52868 .53915 L F
.699 .558 .691 r
.53094 .5387 m .52895 .54244 L .53016 .54046 L F
.774 .681 .76 r
.5942 .47187 m .59795 .47259 L .59647 .46895 L F
.783 .591 .64 r
.59382 .47414 m .59795 .47259 L .5942 .47187 L F
.59382 .47414 m .59809 .47541 L .59795 .47259 L F
.771 .679 .762 r
.59795 .47259 m .60047 .46953 L .59647 .46895 L F
.568 .241 .375 r
.71807 .43652 m .72148 .43451 L .71786 .43402 L F
.71807 .43652 m .72114 .43677 L .72148 .43451 L F
.464 .151 .35 r
.72148 .43451 m .72403 .43554 L .72425 .43439 L F
.72148 .43451 m .72114 .43677 L .72403 .43554 L F
.724 .722 .847 r
.71489 .43022 m .7145 .43128 L .7168 .42817 L F
.709 .497 .6 r
.7145 .43128 m .71709 .43491 L .71786 .43402 L F
.541 .117 .186 r
.42889 .63712 m .4275 .639 L .42539 .63767 L F
.51 .085 .169 r
.43134 .63711 m .4275 .639 L .42889 .63712 L F
.415 .156 .409 r
.74003 .43476 m .73976 .43671 L .73744 .43747 L F
.569 .287 .449 r
.74238 .43625 m .74003 .43476 L .74223 .43382 L F
.74238 .43625 m .73976 .43671 L .74003 .43476 L F
.595 .721 .932 r
.44628 .57379 m .44995 .57516 L .4472 .57288 L F
.74 .22 0 r
.45084 .57513 m .4472 .57288 L .44995 .57516 L F
.45084 .57513 m .44913 .57467 L .4472 .57288 L F
.326 .382 .767 r
.4472 .57288 m .44913 .57467 L .44844 .57164 L F
.4472 .57288 m .44844 .57164 L .44818 .57051 L F
.595 .721 .932 r
.44465 .57318 m .44628 .57379 L .4472 .57288 L F
.89 .866 .809 r
.55003 .49532 m .55138 .49643 L .54922 .49946 L F
.583 .737 .949 r
.63027 .42619 m .62736 .42539 L .62981 .42472 L F
0 .159 .688 r
.63192 .42701 m .63027 .42619 L .62981 .42472 L F
.63192 .42701 m .63214 .42862 L .63027 .42619 L F
.226 .269 .698 r
.63214 .42862 m .63143 .42886 L .63027 .42619 L F
.035 0 .305 r
.38585 .60827 m .38579 .60995 L .38536 .60954 L F
.488 .327 .588 r
.38761 .60496 m .38799 .60826 L .38585 .60827 L F
.464 .187 .408 r
.38799 .60826 m .38579 .60995 L .38585 .60827 L F
.582 .373 .562 r
.5815 .50761 m .58108 .51047 L .57904 .51086 L F
.574 .291 .449 r
.5815 .50761 m .58373 .50975 L .58108 .51047 L F
.5815 .50761 m .58387 .50761 L .58373 .50975 L F
0 0 0 r
.63284 .45632 m .63087 .45706 L .62986 .45808 L F
.768 .488 .509 r
.43425 .63013 m .43705 .62827 L .43474 .62783 L F
.43425 .63013 m .4382 .63106 L .43705 .62827 L F
.541 .311 .515 r
.50649 .70615 m .50461 .71018 L .50231 .70813 L F
.237 .298 .724 r
.50231 .70813 m .50461 .71018 L .50378 .70709 L F
.69 .692 .847 r
.72737 .41948 m .72417 .41886 L .72642 .41777 L F
.626 .651 .855 r
.72874 .41548 m .72737 .41948 L .72642 .41777 L F
.72874 .41548 m .73027 .4187 L .72737 .41948 L F
.072 0 0 r
.40492 .64009 m .4008 .64194 L .40128 .64055 L F
.40492 .64009 m .40316 .64137 L .4008 .64194 L F
.279 0 0 r
.40726 .63999 m .40316 .64137 L .40492 .64009 L F
.94 .714 .567 r
.52505 .68416 m .5259 .68584 L .52619 .68436 L F
.588 .066 0 r
.52119 .68669 m .52485 .68708 L .52229 .68778 L F
.53 0 0 r
.52331 .68738 m .52485 .68708 L .52437 .68703 L F
.52331 .68738 m .52437 .68703 L .52119 .68669 L F
.575 .07 .018 r
.52229 .68778 m .52331 .68738 L .52119 .68669 L F
.492 .897 .777 r
.52255 .68764 m .52331 .68738 L .52229 .68778 L F
.94 .714 .567 r
.52505 .68416 m .52487 .68679 L .52331 .68738 L F
.52487 .68679 m .52485 .68708 L .52331 .68738 L F
.52505 .68416 m .52331 .68738 L .5259 .68584 L F
.492 .897 .777 r
.5259 .68584 m .52331 .68738 L .52255 .68764 L F
.629 .656 .857 r
.71763 .41688 m .71415 .41493 L .71662 .41396 L F
.636 .642 .839 r
.71889 .41285 m .71763 .41688 L .71662 .41396 L F
.71889 .41285 m .72013 .41608 L .71763 .41688 L F
.764 .981 .911 r
.59136 .6254 m .58989 .62562 L .58975 .62657 L F
.59136 .6254 m .58989 .62562 L .58975 .62657 L F
.968 .914 .702 r
.64121 .45869 m .64071 .46062 L .63972 .45939 L F
.876 .878 .833 r
.64071 .46062 m .6382 .45987 L .63972 .45939 L F
.774 .668 .746 r
.59647 .46895 m .60047 .46953 L .59906 .46603 L F
.56 .511 .757 r
.60047 .46953 m .60249 .4666 L .59906 .46603 L F
.60047 .46953 m .60287 .46911 L .60249 .4666 L F
.34 .349 .724 r
.60047 .46953 m .60318 .47123 L .60287 .46911 L F
.398 .536 .878 r
.64939 .43886 m .65171 .43981 L .6499 .43695 L F
.376 0 0 r
.64939 .43886 m .65006 .44011 L .65171 .43981 L F
.64939 .43886 m .64668 .44078 L .65006 .44011 L F
.456 .76 .995 r
.67646 .40124 m .67765 .40235 L .6741 .40149 L F
.541 .802 .994 r
.68008 .40179 m .67765 .40235 L .67646 .40124 L F
.773 .536 .576 r
.19449 .56017 m .19005 .56046 L .1905 .55781 L F
.65 .226 .225 r
.19449 .56017 m .19325 .56126 L .19005 .56046 L F
.19011 .56048 m .19144 .56163 L .19005 .56046 L F
.19325 .56126 m .19145 .56163 L .19011 .56048 L F
.19145 .56163 m .19144 .56163 L .19011 .56048 L F
.19325 .56126 m .19215 .56222 L .19144 .56163 L F
0 0 .081 r
.19433 .55678 m .19451 .55923 L .19449 .56017 L F
.486 .286 .533 r
.19153 .56169 m .19215 .56222 L .19451 .55923 L F
.19096 .56216 m .19215 .56222 L .19153 .56169 L F
.486 .291 .541 r
.19005 .56046 m .19151 .56169 L .19096 .56216 L F
.19151 .56169 m .19215 .56222 L .19096 .56216 L F
.486 .286 .533 r
.19096 .56216 m .19451 .55923 L .19446 .5592 L F
.19096 .56216 m .19446 .5592 L .19245 .55791 L F
.833 .846 .856 r
.19048 .55882 m .1909 .56174 L .19245 .55791 L F
.1909 .56174 m .19096 .56216 L .19112 .56169 L F
.1909 .56174 m .19112 .56169 L .19245 .55791 L F
.766 .962 .659 r
.19451 .55923 m .19215 .56222 L .19449 .56017 L F
.476 .17 .367 r
.60029 .49585 m .6021 .49775 L .5998 .4985 L F
.60029 .49585 m .60274 .49538 L .6021 .49775 L F
.526 .353 .589 r
.3951 .59865 m .39314 .60232 L .39273 .59912 L F
.649 .374 .49 r
.74701 .42567 m .7468 .4281 L .7436 .42764 L F
.657 .381 .491 r
.74989 .4271 m .74701 .42567 L .74926 .42513 L F
.74989 .4271 m .7468 .4281 L .74701 .42567 L F
.613 .782 .962 r
.52619 .68436 m .53092 .68441 L .52863 .686 L F
.422 .328 .643 r
.23499 .61138 m .23531 .61324 L .23363 .61386 L F
.353 .164 .479 r
.23505 .6156 m .23363 .61386 L .23531 .61324 L F
.23505 .6156 m .23334 .61639 L .23363 .61386 L F
.434 0 0 r
.39142 .64207 m .38752 .64202 L .3889 .64113 L F
.764 .738 .829 r
.73463 .41328 m .7356 .41725 L .73224 .41595 L F
0 .096 .565 r
.73587 .41891 m .73224 .41595 L .7356 .41725 L F
.347 .454 .828 r
.73956 .4168 m .7356 .41725 L .73463 .41328 L F
.18 0 .354 r
.67206 .41864 m .67143 .42292 L .66946 .42257 L F
.06 .328 .809 r
.67143 .42292 m .67208 .4241 L .66946 .42257 L F
.925 .863 .76 r
.54788 .49851 m .54829 .50164 L .54565 .50135 L F
.54788 .49851 m .54922 .49946 L .54829 .50164 L F
.875 .799 .771 r
.54565 .50135 m .54829 .50164 L .54628 .50468 L F
.624 .906 .984 r
.4294 .57001 m .42572 .57046 L .42811 .56946 L F
.767 .984 .905 r
.43103 .56847 m .4294 .57001 L .43009 .56817 L F
.714 .94 .959 r
.4294 .57001 m .42811 .56946 L .43009 .56817 L F
.012 0 0 r
.55905 .63139 m .56146 .63099 L .56406 .63031 L F
.544 .04 0 r
.56373 .63 m .56406 .63031 L .56146 .63099 L F
.987 .714 .37 r
.67188 .40932 m .67329 .41053 L .67274 .40817 L F
.997 .781 .481 r
.67258 .41227 m .67329 .41053 L .67188 .40932 L F
.66 .63 .808 r
.67329 .41053 m .6748 .40768 L .67274 .40817 L F
.625 .644 .849 r
.67566 .40971 m .67329 .41053 L .67258 .41227 L F
.067 0 0 r
.40232 .6312 m .40463 .63093 L .40597 .6305 L F
.269 0 0 r
.40597 .6305 m .40463 .63093 L .40832 .63058 L F
.68 .647 .81 r
.69842 .42624 m .70092 .42541 L .69984 .42174 L F
.396 .072 .294 r
.52988 .69341 m .52898 .69563 L .52696 .69595 L F
.595 .845 .482 r
.53086 .69206 m .52988 .69341 L .53196 .69077 L F
.039 0 .116 r
.53085 .69459 m .52988 .69341 L .53086 .69206 L F
.53085 .69459 m .52898 .69563 L .52988 .69341 L F
.52 .899 .723 r
.62682 .4785 m .62893 .477 L .6284 .47714 L F
.51 .884 .684 r
.62524 .47933 m .62682 .4785 L .6284 .47714 L F
.091 .594 .895 r
.68401 .45917 m .68454 .45965 L .6826 .45863 L F
.68401 .45917 m .68658 .46005 L .68454 .45965 L F
0 .247 .737 r
.55105 .63356 m .55167 .63347 L .54959 .63023 L F
.55105 .63356 m .55285 .63492 L .55167 .63347 L F
.504 .076 .16 r
.41062 .6307 m .41309 .63072 L .41458 .62883 L F
.498 .069 .156 r
.41458 .62883 m .41309 .63072 L .41646 .63011 L F
.862 .909 .863 r
.60713 .42914 m .60363 .43068 L .60605 .42803 L F
.815 .902 .902 r
.60891 .42694 m .60713 .42914 L .60605 .42803 L F
.994 .807 .547 r
.55431 .67191 m .5538 .67461 L .55526 .67446 L F
0 0 0 r
.55478 .67699 m .55392 .67837 L .55526 .67446 L F
.55478 .67699 m .55526 .67446 L .5538 .67461 L F
0 0 .48 r
.22072 .55485 m .22254 .5569 L .22119 .55533 L F
.534 .913 .941 r
.16827 .54466 m .1699 .54376 L .17225 .54384 L F
.535 .913 .941 r
.17225 .54384 m .1719 .54281 L .17435 .54337 L F
.17225 .54384 m .1699 .54376 L .1719 .54281 L F
.456 .257 .521 r
.24187 .59616 m .24163 .59863 L .23956 .59918 L F
.435 .256 .538 r
.24163 .59863 m .23955 .60169 L .23956 .59918 L F
.145 0 0 r
.18126 .55626 m .18083 .55499 L .18296 .55433 L F
.18126 .55626 m .1791 .55701 L .18083 .55499 L F
.046 .553 .878 r
.2435 .54822 m .24538 .54858 L .247 .54943 L F
.064 .433 .873 r
.24762 .54869 m .247 .54943 L .24538 .54858 L F
.24762 .54869 m .24914 .55036 L .247 .54943 L F
.89 .866 .809 r
.55003 .49532 m .54922 .49946 L .54788 .49851 L F
.639 .294 .372 r
.35766 .62271 m .35717 .62285 L .35451 .62251 L F
.645 .47 .632 r
.35451 .62251 m .35504 .62589 L .35853 .62337 L F
0 0 .012 r
.50065 .70611 m .49953 .70774 L .49876 .70509 L F
.599 .491 .703 r
.74312 .41895 m .74306 .42247 L .74045 .42287 L F
.875 .724 .691 r
.53799 .67624 m .53869 .67843 L .53685 .67808 L F
.869 .563 .467 r
.53869 .67843 m .53814 .68116 L .53685 .67808 L F
.86 .7 .683 r
.53685 .67808 m .5385 .67752 L .53799 .67624 L F
.5385 .67752 m .53882 .67742 L .53799 .67624 L F
.568 .542 .785 r
.5388 .67826 m .53869 .67843 L .53846 .67769 L F
.53855 .67764 m .53846 .67769 L .53799 .67624 L F
.5388 .67826 m .53846 .67769 L .53855 .67764 L F
.53918 .67762 m .5388 .67826 L .5385 .67752 L F
.53998 .67627 m .54107 .67716 L .53921 .67815 L F
.53906 .67781 m .53921 .67815 L .53869 .67843 L F
.53998 .67627 m .53921 .67815 L .53906 .67781 L F
.576 .561 .801 r
.53846 .67769 m .53896 .67759 L .53869 .67843 L F
.53896 .67759 m .54107 .67716 L .53921 .67815 L F
.53896 .67759 m .53921 .67815 L .53869 .67843 L F
.568 .542 .785 r
.53998 .67627 m .53918 .67762 L .53897 .67738 L F
0 0 .01 r
.53882 .67742 m .5389 .67746 L .53998 .67627 L F
.53882 .67742 m .53998 .67627 L .53799 .67624 L F
.568 .542 .785 r
.53998 .67627 m .53897 .67738 L .53799 .67624 L F
0 0 .01 r
.5389 .67746 m .53891 .67746 L .53998 .67627 L F
.576 .561 .801 r
.53996 .67683 m .54107 .67716 L .53896 .67759 L F
.53893 .67751 m .53896 .67759 L .53875 .67763 L F
.53996 .67683 m .53896 .67759 L .53893 .67751 L F
.568 .542 .785 r
.53876 .67713 m .5385 .67752 L .53799 .67624 L F
.53918 .67762 m .53896 .67759 L .53876 .67713 L F
0 0 .525 r
.53889 .67744 m .5389 .67745 L .53889 .67744 L F
.5389 .67745 m .5389 .67745 L .53889 .67744 L F
.53889 .67744 m .5389 .67745 L .53882 .67742 L F
.53889 .67744 m .53882 .67742 L .5387 .67755 L F
.547 .087 .113 r
.5387 .67755 m .53882 .67742 L .5385 .67752 L F
.568 .542 .785 r
.53896 .67759 m .5385 .67752 L .53876 .67713 L F
0 0 .525 r
.5389 .67744 m .5389 .67745 L .53889 .67744 L F
.576 .561 .801 r
.53996 .67683 m .53875 .67763 L .53896 .67741 L F
0 0 .01 r
.53891 .67746 m .53981 .67793 L .53997 .67631 L F
0 0 .525 r
.53961 .67766 m .53891 .67746 L .5389 .67744 L F
.53891 .67746 m .5389 .67745 L .5389 .67744 L F
0 0 .01 r
.53891 .67746 m .53997 .67631 L .53998 .67627 L F
0 0 .525 r
.53891 .67746 m .53891 .67746 L .5389 .67745 L F
.576 .561 .801 r
.53896 .67741 m .53875 .67763 L .53846 .67769 L F
0 0 .525 r
.53961 .67766 m .53981 .67793 L .53891 .67746 L F
.53961 .67766 m .53891 .67746 L .53891 .67746 L F
.5389 .67744 m .53889 .67744 L .53888 .67745 L F
.576 .561 .801 r
.53799 .67624 m .53996 .67683 L .53846 .67769 L F
.547 .087 .113 r
.53668 .67974 m .53685 .67808 L .53814 .68116 L F
0 0 .525 r
.53961 .67766 m .5389 .67744 L .53668 .67974 L F
.5389 .67744 m .53888 .67745 L .53668 .67974 L F
.53889 .67744 m .5387 .67755 L .53668 .67974 L F
.547 .087 .113 r
.53668 .67974 m .5387 .67755 L .53685 .67808 L F
.5387 .67755 m .5385 .67752 L .53685 .67808 L F
.714 .538 .65 r
.54107 .67716 m .53814 .68116 L .53869 .67843 L F
.207 0 0 r
.47419 .632 m .47314 .63088 L .47497 .63111 L F
.47419 .632 m .47194 .63273 L .47314 .63088 L F
.005 0 0 r
.69413 .46359 m .69355 .46443 L .69036 .46528 L F
.487 0 0 r
.69669 .46336 m .69355 .46443 L .69413 .46359 L F
.987 .714 .37 r
.67188 .40932 m .67274 .40817 L .66921 .40799 L F
.178 0 0 r
.66921 .40799 m .67274 .40817 L .67289 .40825 L F
.027 0 0 r
.67289 .40825 m .67274 .40817 L .6748 .40768 L F
.756 .575 .651 r
.54639 .51959 m .54854 .52372 L .54467 .52249 L F
.551 .677 .921 r
.68745 .40473 m .68324 .40283 L .68646 .40324 L F
.52 .721 .965 r
.68882 .40288 m .68745 .40473 L .68646 .40324 L F
.474 .657 .94 r
.68973 .40458 m .68745 .40473 L .68882 .40288 L F
.502 .097 .205 r
.41934 .63777 m .42188 .63891 L .41916 .63902 L F
.624 .245 .304 r
.48692 .62296 m .48248 .62537 L .4837 .62503 L F
.48692 .62296 m .48601 .62468 L .48248 .62537 L F
.363 0 .169 r
.48863 .62386 m .48692 .62296 L .48899 .62216 L F
.48863 .62386 m .48601 .62468 L .48692 .62296 L F
.616 .816 .977 r
.444 .58116 m .44026 .58082 L .44248 .57994 L F
.975 .72 .484 r
.444 .58116 m .44248 .57994 L .44026 .58082 L F
.444 .58116 m .44378 .5839 L .44248 .57994 L F
.502 .669 .938 r
.44493 .57925 m .444 .58116 L .44248 .57994 L F
.44493 .57925 m .4462 .5809 L .444 .58116 L F
.477 .259 .504 r
.4462 .5809 m .44378 .5839 L .444 .58116 L F
.371 .163 .463 r
.3868 .61359 m .38612 .6163 L .38448 .61627 L F
.819 .806 .839 r
.5452 .68602 m .54646 .68731 L .54746 .68467 L F
.5452 .68602 m .54324 .68729 L .54646 .68731 L F
.836 .758 .777 r
.54324 .68729 m .54429 .69041 L .54646 .68731 L F
.749 .597 .688 r
.42267 .58034 m .42199 .58082 L .42608 .5803 L F
.295 0 0 r
.42608 .5803 m .42661 .58077 L .42267 .58034 L F
0 0 .284 r
.42674 .57764 m .42661 .58077 L .42608 .5803 L F
.036 0 .26 r
.21137 .65059 m .21054 .64915 L .2125 .64882 L F
.21137 .65059 m .21011 .65176 L .21054 .64915 L F
.658 .96 .934 r
.44006 .58591 m .43917 .5874 L .43821 .58712 L F
.44006 .58591 m .43917 .5874 L .43821 .58712 L F
.632 .92 .977 r
.19962 .61329 m .19797 .61289 L .20063 .61168 L F
.35 .563 .916 r
.19962 .61329 m .20063 .61168 L .19797 .61289 L F
.19962 .61329 m .2018 .61378 L .20063 .61168 L F
.651 .444 .59 r
.39046 .60703 m .38761 .60496 L .39089 .60511 L F
.39046 .60703 m .38799 .60826 L .38761 .60496 L F
.532 .027 .002 r
.41088 .63987 m .4095 .6405 L .40726 .63999 L F
.396 0 0 r
.41328 .63971 m .4095 .6405 L .41088 .63987 L F
.427 0 0 r
.39975 .63118 m .39636 .63139 L .3986 .63072 L F
.287 .743 .955 r
.3986 .63072 m .40232 .6312 L .39975 .63118 L F
.561 .668 .91 r
.57076 .62982 m .56884 .63389 L .56655 .63084 L F
.57076 .62982 m .57124 .63344 L .56884 .63389 L F
.562 .662 .904 r
.56884 .63389 m .57124 .63344 L .5717 .63465 L F
.881 .901 .84 r
.56063 .48436 m .56184 .48036 L .563 .48138 L F
.56063 .48436 m .55944 .48333 L .56184 .48036 L F
.837 .994 .85 r
.6461 .45942 m .64407 .46281 L .64751 .46052 L F
.6461 .45942 m .64339 .46221 L .64407 .46281 L F
.489 .052 .135 r
.73744 .43747 m .7364 .43917 L .73388 .4392 L F
.638 .212 .217 r
.73744 .43747 m .73997 .4393 L .7364 .43917 L F
.487 .314 .572 r
.73976 .43671 m .73997 .4393 L .73744 .43747 L F
.537 .312 .522 r
.56472 .51677 m .56718 .51627 L .5647 .51906 L F
.455 .277 .55 r
.54555 .69638 m .54823 .69598 L .54785 .69313 L F
.438 .22 .484 r
.54549 .69864 m .54823 .69598 L .54555 .69638 L F
.43 .752 .995 r
.54555 .69638 m .54823 .69598 L .54549 .69864 L F
.649 .585 .769 r
.71056 .42615 m .71069 .42813 L .71293 .42533 L F
.645 .579 .766 r
.71069 .42813 m .71489 .43022 L .71293 .42533 L F
.391 0 .08 r
.48183 .61902 m .48429 .6187 L .48544 .61705 L F
0 0 0 r
.48782 .61418 m .48544 .61705 L .4868 .61574 L F
.347 0 .056 r
.48544 .61705 m .48741 .61785 L .4868 .61574 L F
.48544 .61705 m .48429 .6187 L .48741 .61785 L F
.526 .248 .436 r
.71314 .4518 m .71295 .45519 L .71002 .45539 L F
.179 0 .355 r
.7148 .45298 m .71314 .4518 L .71571 .45162 L F
.7148 .45298 m .71295 .45519 L .71314 .4518 L F
.983 .77 .539 r
.1905 .55781 m .18876 .55931 L .18828 .55625 L F
.1905 .55781 m .19005 .56046 L .18876 .55931 L F
.876 .832 .8 r
.19241 .55428 m .1905 .55781 L .18828 .55625 L F
.754 .569 .646 r
.55035 .52246 m .55422 .52282 L .55402 .52539 L F
.589 .382 .569 r
.5559 .52267 m .55402 .52539 L .55422 .52282 L F
.574 .6 .842 r
.62623 .45658 m .62536 .46025 L .62548 .45795 L F
.893 .472 .108 r
.21424 .59732 m .21442 .59831 L .2117 .59521 L F
.824 .709 .739 r
.60015 .45728 m .60341 .4577 L .60407 .45528 L F
.818 .728 .766 r
.60015 .45728 m .60131 .46068 L .60341 .4577 L F
.666 .723 .892 r
.43885 .57317 m .44218 .575 L .44139 .57212 L F
.667 .638 .812 r
.44139 .57212 m .44218 .575 L .44465 .57318 L F
.484 0 0 r
.45553 .63463 m .45403 .63577 L .45186 .63486 L F
.468 0 .008 r
.45814 .63457 m .45403 .63577 L .45553 .63463 L F
.97 .726 .513 r
.41612 .60348 m .41771 .6046 L .41797 .60165 L F
.41612 .60348 m .41771 .6046 L .41797 .60165 L F
.894 .952 .834 r
.58693 .44931 m .58459 .4523 L .58375 .45134 L F
.911 .95 .812 r
.58459 .4523 m .58239 .45284 L .58375 .45134 L F
.324 0 .031 r
.70761 .45569 m .70988 .45613 L .70723 .45688 L F
.70761 .45569 m .71002 .45539 L .70988 .45613 L F
.944 .689 .222 r
.54122 .65647 m .54193 .65747 L .54179 .65519 L F
.54122 .65647 m .54193 .65747 L .54179 .65519 L F
.695 .465 .57 r
.54193 .65747 m .54662 .65509 L .54179 .65519 L F
.881 .647 .58 r
.68318 .4452 m .68591 .44621 L .68581 .44662 L F
.294 .065 .386 r
.21757 .64021 m .21731 .6427 L .21528 .6432 L F
.192 0 .356 r
.21648 .64493 m .21528 .6432 L .21731 .6427 L F
.21648 .64493 m .215 .64586 L .21528 .6432 L F
.427 .867 .901 r
.67505 .45231 m .67909 .45131 L .67591 .44969 L F
.756 .458 0 r
.67909 .45131 m .67834 .44881 L .67591 .44969 L F
.892 .976 .82 r
.57811 .46105 m .57543 .46447 L .57571 .46228 L F
.907 .981 .78 r
.57543 .46447 m .57361 .46531 L .57571 .46228 L F
.55 .289 .473 r
.22445 .57266 m .2264 .57458 L .22686 .57236 L F
.485 .291 .541 r
.22427 .57511 m .2264 .57458 L .22445 .57266 L F
.702 .662 .807 r
.55905 .63139 m .55564 .62939 L .55776 .62819 L F
.568 .554 .798 r
.56017 .62742 m .55905 .63139 L .55776 .62819 L F
.56017 .62742 m .56146 .63099 L .55905 .63139 L F
.608 .345 .493 r
.5559 .52267 m .55912 .52479 L .55651 .52508 L F
.5559 .52267 m .55937 .52228 L .55912 .52479 L F
.589 .382 .569 r
.5559 .52267 m .55651 .52508 L .55402 .52539 L F
.256 .555 .931 r
.46989 .57339 m .46648 .57346 L .46535 .57174 L F
.46989 .57339 m .46927 .57437 L .46648 .57346 L F
.794 .704 .766 r
.54854 .52372 m .54783 .52573 L .54434 .52492 L F
.795 .702 .762 r
.54434 .52492 m .54783 .52573 L .54575 .52832 L F
.447 .218 .473 r
.54783 .52573 m .54801 .52779 L .54575 .52832 L F
.671 .567 .73 r
.54854 .52372 m .55035 .52246 L .54783 .52573 L F
.658 .329 .404 r
.54783 .52573 m .55068 .52784 L .54801 .52779 L F
.139 .684 .736 r
.17435 .54337 m .1766 .54301 L .17798 .54286 L F
.366 .832 .78 r
.17798 .54286 m .1787 .54233 L .1803 .54195 L F
.343 .822 .825 r
.17798 .54286 m .1766 .54301 L .1787 .54233 L F
.695 .465 .57 r
.54193 .65747 m .54637 .65722 L .54662 .65509 L F
.362 .08 .343 r
.72369 .44546 m .7233 .44795 L .72121 .44872 L F
.551 .29 .474 r
.72631 .44483 m .7233 .44795 L .72369 .44546 L F
.937 .728 .594 r
.58928 .62152 m .58989 .62562 L .59136 .6254 L F
.354 .655 .969 r
.45869 .5776 m .45916 .57616 L .45661 .57578 L F
.45869 .5776 m .46071 .57756 L .45916 .57616 L F
.913 .97 .793 r
.57873 .45993 m .578 .45924 L .58002 .45833 L F
.869 .993 .814 r
.58002 .45833 m .578 .45924 L .58054 .4562 L F
.291 0 .03 r
.61383 .48673 m .61483 .48793 L .61253 .48884 L F
.61383 .48673 m .61552 .48622 L .61483 .48793 L F
.683 .416 .513 r
.64488 .43093 m .64591 .4305 L .64584 .43093 L F
.527 .234 .412 r
.64365 .43413 m .64439 .43313 L .64108 .43422 L F
.683 .416 .513 r
.64387 .43355 m .64439 .43313 L .64365 .43413 L F
.48 .145 .321 r
.64108 .43422 m .64395 .43327 L .64314 .43405 L F
.564 .588 .836 r
.64361 .43401 m .64365 .43413 L .64108 .43422 L F
.48 .145 .321 r
.64395 .43327 m .64387 .43355 L .64296 .43431 L F
.64277 .4344 m .64296 .43431 L .64223 .43491 L F
.64395 .43327 m .64296 .43431 L .64277 .4344 L F
.64395 .43327 m .64439 .43313 L .64387 .43355 L F
.683 .416 .513 r
.64488 .43093 m .64439 .43313 L .64387 .43355 L F
.64488 .43093 m .64642 .43385 L .64439 .43313 L F
.64488 .43093 m .64387 .43355 L .64591 .4305 L F
.64387 .43355 m .64365 .43413 L .64377 .43393 L F
.64387 .43355 m .64377 .43393 L .64591 .4305 L F
.743 .694 .804 r
.64377 .43393 m .64365 .43413 L .64361 .43401 L F
.48 .145 .321 r
.64223 .43491 m .6433 .43403 L .64328 .43554 L F
.6433 .43403 m .64439 .43313 L .64328 .43554 L F
.48 .257 .497 r
.64336 .4376 m .64104 .43608 L .64328 .43554 L F
.64336 .4376 m .64104 .43608 L .64328 .43554 L F
.848 .634 .093 r
.64326 .43682 m .64328 .43554 L .64336 .4376 L F
.564 .588 .836 r
.64206 .4293 m .64361 .43401 L .64108 .43422 L F
.48 .145 .321 r
.64108 .43422 m .64314 .43405 L .64223 .43491 L F
.64108 .43422 m .64328 .43554 L .64104 .43608 L F
.183 0 .022 r
.63843 .43627 m .64108 .43422 L .64104 .43608 L F
.564 .588 .836 r
.64206 .4293 m .64108 .43422 L .64016 .4323 L F
.565 .544 .79 r
.64016 .4323 m .64104 .43608 L .64328 .43554 L F
.64016 .4323 m .64328 .43554 L .64116 .43227 L F
.169 .41 .851 r
.64116 .43227 m .64328 .43554 L .64287 .43369 L F
.848 .634 .093 r
.64287 .43369 m .64328 .43554 L .64326 .43682 L F
.743 .694 .804 r
.64591 .4305 m .64377 .43393 L .64206 .4293 L F
.64377 .43393 m .64361 .43401 L .64206 .4293 L F
.119 .546 .918 r
.36818 .62897 m .36917 .62847 L .36716 .62778 L F
.36818 .62897 m .37092 .6298 L .36917 .62847 L F
.284 0 .202 r
.40766 .59183 m .40729 .59039 L .40908 .59039 L F
.465 .086 .234 r
.4114 .58943 m .40766 .59183 L .40908 .59039 L F
.94 .842 .719 r
.67386 .45104 m .67591 .44969 L .67461 .44809 L F
.67386 .45104 m .67505 .45231 L .67591 .44969 L F
.7 .712 .858 r
.67461 .44809 m .67591 .44969 L .67834 .44881 L F
.362 .598 .937 r
.54746 .68467 m .54865 .68512 L .54738 .68341 L F
.824 .709 .739 r
.60015 .45728 m .60407 .45528 L .60206 .45452 L F
.851 .73 .729 r
.60407 .45528 m .60297 .45197 L .60206 .45452 L F
.723 .692 .82 r
.53702 .51951 m .53828 .52261 L .53451 .52209 L F
.711 .574 .699 r
.53825 .52482 m .53451 .52209 L .53828 .52261 L F
.779 .719 .796 r
.54081 .51966 m .53828 .52261 L .53702 .51951 L F
.519 .307 .532 r
.2196 .58111 m .22207 .57812 L .21968 .57849 L F
.523 .633 .901 r
.6826 .45863 m .68079 .45903 L .68002 .4571 L F
.075 .633 .794 r
.21411 .54193 m .21633 .54193 L .21819 .5421 L F
.206 0 0 r
.21633 .54193 m .22018 .54247 L .21819 .5421 L F
.495 .095 .211 r
.39759 .64169 m .39474 .642 L .39522 .64052 L F
.981 .69 .339 r
.54429 .69041 m .54495 .69347 L .54444 .69298 L F
.54429 .69041 m .54495 .69347 L .54444 .69298 L F
.441 .266 .546 r
.24371 .59551 m .24163 .59863 L .24187 .59616 L F
.778 .595 .652 r
.58381 .61019 m .58588 .6116 L .58683 .61027 L F
.462 .055 .181 r
.4868 .61574 m .49025 .61406 L .48782 .61418 L F
.669 .631 .802 r
.19489 .66363 m .19773 .66359 L .19556 .66514 L F
.256 .619 .958 r
.66762 .45969 m .66867 .46094 L .67078 .46126 L F
.683 .282 .281 r
.42539 .63767 m .42391 .63959 L .42188 .63891 L F
.541 .117 .186 r
.4275 .639 m .42391 .63959 L .42539 .63767 L F
.655 .631 .814 r
.68666 .41759 m .68749 .41986 L .68424 .41961 L F
.477 .719 .976 r
.43318 .58835 m .43436 .5866 L .43163 .58673 L F
.43318 .58835 m .43572 .58816 L .43436 .5866 L F
.32 .549 .916 r
.37911 .63777 m .38011 .63628 L .37845 .63608 L F
.37911 .63777 m .38273 .63948 L .38011 .63628 L F
.6 .633 .855 r
.70567 .40916 m .70407 .41161 L .70326 .40982 L F
.70567 .40916 m .70691 .41077 L .70407 .41161 L F
.327 .276 .648 r
.38699 .61833 m .38706 .6229 L .38572 .62226 L F
.004 .355 .829 r
.38706 .6229 m .38843 .62412 L .38572 .62226 L F
.647 .702 .886 r
.64578 .41241 m .645 .41452 L .6429 .41337 L F
.721 .203 0 r
.645 .41452 m .6444 .41508 L .6429 .41337 L F
.645 .41452 m .64715 .41615 L .6444 .41508 L F
.6444 .41508 m .645 .41452 L .64578 .41241 L F
.6444 .41508 m .64715 .41615 L .645 .41452 L F
0 0 0 r
.19907 .66943 m .19639 .67224 L .19684 .67107 L F
.026 0 0 r
.69049 .44818 m .69335 .44823 L .69363 .44823 L F
.293 .791 .825 r
.69363 .44823 m .69335 .44823 L .69592 .44751 L F
.832 .794 .816 r
.65685 .45101 m .65439 .45399 L .65766 .45402 L F
.831 .795 .817 r
.65439 .45399 m .65589 .45554 L .65766 .45402 L F
.847 .802 .807 r
.65685 .45101 m .65766 .45402 L .6585 .45235 L F
.637 .51 .692 r
.20056 .62294 m .20269 .62009 L .20137 .62064 L F
.965 .661 .396 r
.61915 .42853 m .61746 .42483 L .61603 .42847 L F
.755 .821 .904 r
.61725 .42905 m .61915 .42853 L .61603 .42847 L F
.659 .269 .295 r
.60063 .477 m .60173 .47564 L .59809 .47541 L F
0 0 0 r
.60354 .47368 m .60173 .47564 L .60063 .477 L F
.832 .735 .757 r
.59795 .46047 m .60131 .46068 L .60015 .45728 L F
.834 .723 .742 r
.59912 .46367 m .60131 .46068 L .59795 .46047 L F
.522 .226 .406 r
.58645 .50505 m .58872 .50665 L .58637 .50718 L F
.58645 .50505 m .58883 .50479 L .58872 .50665 L F
0 0 0 r
.64016 .4323 m .63866 .43517 L .63843 .43627 L F
.202 0 .318 r
.22814 .62725 m .2272 .62592 L .2289 .62509 L F
.22814 .62725 m .22657 .62809 L .2272 .62592 L F
.317 0 .256 r
.60492 .4949 m .60549 .49327 L .6077 .4924 L F
.589 .021 0 r
.6474 .435 m .64691 .43521 L .64642 .43385 L F
.6474 .435 m .6499 .43695 L .64691 .43521 L F
.836 .738 .756 r
.67353 .44476 m .67461 .44809 L .67773 .44528 L F
.7 .712 .858 r
.67461 .44809 m .67834 .44881 L .67773 .44528 L F
.613 .491 .69 r
.67773 .44528 m .67834 .44881 L .68123 .44634 L F
.276 .384 .793 r
.54569 .53557 m .54417 .5369 L .54323 .53381 L F
0 0 .014 r
.54353 .53907 m .54417 .5369 L .54569 .53557 L F
.591 .753 .955 r
.38273 .63948 m .38321 .6404 L .3855 .63981 L F
.752 .682 .784 r
.54434 .52492 m .54575 .52832 L .54185 .52781 L F
.765 .639 .722 r
.54185 .52781 m .54575 .52832 L .54327 .5314 L F
.679 .512 .653 r
.54575 .52832 m .54647 .53076 L .54327 .5314 L F
.265 .131 .505 r
.54801 .52779 m .54647 .53076 L .54575 .52832 L F
.299 0 .085 r
.70506 .45795 m .70435 .45978 L .70204 .46038 L F
.202 0 .049 r
.70676 .45882 m .70506 .45795 L .70723 .45688 L F
.70676 .45882 m .70435 .45978 L .70506 .45795 L F
.894 .952 .834 r
.58693 .44931 m .58375 .45134 L .58604 .44843 L F
.867 .949 .865 r
.58693 .44931 m .58727 .44686 L .58948 .44652 L F
.58693 .44931 m .58604 .44843 L .58727 .44686 L F
.584 .591 .825 r
.7255 .41557 m .72417 .41886 L .72273 .41553 L F
.7255 .41557 m .72642 .41777 L .72417 .41886 L F
.188 .469 .889 r
.20425 .62089 m .20461 .6226 L .20269 .62009 L F
.532 .338 .563 r
.20461 .6226 m .20687 .62218 L .20702 .61964 L F
.768 .607 .679 r
.20425 .62089 m .20687 .62218 L .20461 .6226 L F
.904 .966 .813 r
.57811 .46105 m .578 .45924 L .57873 .45993 L F
.57811 .46105 m .57571 .46228 L .578 .45924 L F
.896 .487 .217 r
.67428 .45348 m .67505 .45231 L .67386 .45104 L F
.67428 .45348 m .67584 .45426 L .67505 .45231 L F
.405 .226 .523 r
.25369 .57164 m .25169 .57519 L .25188 .57255 L F
.849 .998 .786 r
.64121 .45869 m .64265 .456 L .64352 .45745 L F
.64121 .45869 m .63972 .45939 L .64265 .456 L F
.743 .614 .715 r
.49496 .70713 m .49876 .70509 L .49495 .70471 L F
.392 .452 .803 r
.56613 .62829 m .56514 .63138 L .56373 .63 L F
.56613 .62829 m .56655 .63084 L .56514 .63138 L F
.129 .073 .52 r
.20702 .61964 m .20818 .61894 L .20801 .61581 L F
.163 .141 .584 r
.20702 .61964 m .2085 .62137 L .20818 .61894 L F
.328 .171 .511 r
.20702 .61964 m .20687 .62218 L .2085 .62137 L F
.169 .553 .93 r
.57427 .62512 m .57647 .62598 L .57462 .62444 L F
.282 0 .133 r
.36021 .59512 m .3632 .59287 L .36063 .59305 L F
.477 0 0 r
.41646 .63011 m .41918 .63026 L .42054 .62926 L F
.349 0 0 r
.41918 .63026 m .42258 .62962 L .42054 .62926 L F
.604 .318 .457 r
.40729 .59039 m .40543 .59266 L .40298 .59274 L F
.284 0 .202 r
.40766 .59183 m .40543 .59266 L .40729 .59039 L F
.452 .355 .655 r
.35425 .60741 m .35575 .60429 L .35405 .60488 L F
.196 .711 .884 r
.22018 .54247 m .2223 .54236 L .22433 .54267 L F
.33 .735 .981 r
.2223 .54236 m .2261 .54316 L .22433 .54267 L F
.623 .538 .738 r
.70348 .43718 m .70473 .44061 L .70728 .43997 L F
.589 .428 .631 r
.70475 .44288 m .70728 .43997 L .70473 .44061 L F
.627 .652 .855 r
.70201 .40665 m .70074 .41055 L .69944 .40729 L F
.70201 .40665 m .70326 .40982 L .70074 .41055 L F
.439 .046 .196 r
.47317 .62428 m .47675 .62185 L .47435 .62196 L F
.594 .217 .297 r
.52696 .69595 m .52377 .69768 L .52382 .69665 L F
0 .253 .755 r
.57798 .61392 m .58032 .61591 L .57797 .61369 L F
.552 .451 .693 r
.25205 .57769 m .25025 .58079 L .25011 .57827 L F
.88 .806 .773 r
.54468 .50329 m .54628 .50468 L .54432 .50763 L F
.875 .799 .771 r
.54565 .50135 m .54628 .50468 L .54468 .50329 L F
.914 .6 .437 r
.55259 .67082 m .55424 .66977 L .55232 .66895 L F
.55259 .67082 m .55431 .67191 L .55424 .66977 L F
0 .08 .63 r
.66146 .42523 m .66145 .42436 L .6594 .42235 L F
0 .029 .601 r
.66146 .42523 m .66281 .42604 L .66145 .42436 L F
.66146 .42523 m .66312 .42747 L .66281 .42604 L F
.535 .645 .905 r
.57124 .63344 m .5736 .63315 L .5717 .63465 L F
.609 .483 .684 r
.57411 .63502 m .5717 .63465 L .5736 .63315 L F
.57411 .63502 m .57259 .63696 L .5717 .63465 L F
.338 .384 .762 r
.35853 .62337 m .36001 .62381 L .35766 .62271 L F
.345 .746 .983 r
.62082 .41611 m .62049 .41483 L .61775 .41462 L F
.758 .993 .872 r
.62215 .41317 m .62082 .41611 L .62382 .41274 L F
.62215 .41317 m .62049 .41483 L .62082 .41611 L F
.851 .983 .861 r
.59209 .44384 m .58948 .44652 L .59008 .44421 L F
.836 .972 .884 r
.58948 .44652 m .58727 .44686 L .59008 .44421 L F
0 0 0 r
.40623 .57763 m .40742 .57726 L .40818 .57689 L F
.4063 .57788 m .40742 .57726 L .40623 .57763 L F
.423 0 0 r
.20447 .55388 m .20305 .55367 L .20019 .55239 L F
.545 .916 .946 r
.20521 .55271 m .20447 .55388 L .20718 .55313 L F
.20521 .55271 m .20305 .55367 L .20447 .55388 L F
.696 .636 .784 r
.70328 .42241 m .70686 .42299 L .70569 .41994 L F
.642 .614 .806 r
.70686 .42299 m .70811 .41903 L .70569 .41994 L F
.70686 .42299 m .70929 .42238 L .70811 .41903 L F
.862 .996 .775 r
.62736 .42539 m .62456 .42856 L .62671 .42703 L F
.452 .177 .405 r
.62998 .42701 m .62736 .42539 L .62671 .42703 L F
.62998 .42701 m .62981 .42472 L .62736 .42539 L F
.564 .328 .517 r
.5945 .49893 m .5944 .5013 L .59184 .50186 L F
.575 .312 .48 r
.5945 .49893 m .59691 .50079 L .5944 .5013 L F
.5945 .49893 m .59705 .49864 L .59691 .50079 L F
.318 .081 .388 r
.21991 .63721 m .21959 .63981 L .21757 .64021 L F
.033 0 .297 r
.21847 .64167 m .21757 .64021 L .21959 .63981 L F
.21847 .64167 m .21731 .6427 L .21757 .64021 L F
.794 .704 .766 r
.54854 .52372 m .54434 .52492 L .54467 .52249 L F
.74 .871 .941 r
.73303 .42842 m .73038 .43124 L .73267 .42946 L F
.73303 .42842 m .72892 .43029 L .73038 .43124 L F
.629 .322 .431 r
.72999 .43282 m .73038 .43124 L .72892 .43029 L F
.72999 .43282 m .73263 .43325 L .73038 .43124 L F
.269 0 .093 r
.56936 .516 m .57309 .51359 L .57348 .5163 L F
.547 .282 .465 r
.57309 .51359 m .57557 .51562 L .57348 .5163 L F
.57309 .51359 m .57556 .51333 L .57557 .51562 L F
.283 .779 .743 r
.41361 .57498 m .41679 .57403 L .41475 .57461 L F
.876 .832 .8 r
.19241 .55428 m .18828 .55625 L .18907 .55399 L F
.711 .206 0 r
.1928 .55543 m .19241 .55428 L .19456 .55351 L F
.001 0 0 r
.46906 .626 m .46797 .62718 L .47104 .62507 L F
.623 .538 .738 r
.70348 .43718 m .70728 .43997 L .7061 .4374 L F
.571 .935 .8 r
.42278 .57142 m .42351 .57038 L .42572 .57046 L F
.42278 .57142 m .4219 .57156 L .42351 .57038 L F
.758 .914 .537 r
.73368 .42701 m .73267 .42946 L .73518 .42844 L F
.73368 .42701 m .73303 .42842 L .73267 .42946 L F
.347 .765 .978 r
.21091 .55364 m .20925 .5529 L .20718 .55313 L F
.261 .727 .947 r
.21298 .55341 m .20925 .5529 L .21091 .55364 L F
.569 .65 .891 r
.45404 .56917 m .4497 .56676 L .45151 .56639 L F
.17 .298 .753 r
.45512 .56789 m .45404 .56917 L .45151 .56639 L F
.45512 .56789 m .45527 .56939 L .45404 .56917 L F
.498 .097 .212 r
.44945 .6339 m .4455 .63611 L .4459 .63477 L F
.44945 .6339 m .44799 .63605 L .4455 .63611 L F
.442 0 0 r
.45186 .63486 m .44799 .63605 L .44945 .6339 L F
.485 .291 .541 r
.19236 .63722 m .19421 .63682 L .19463 .63437 L F
.749 .52 .584 r
.19092 .6391 m .19421 .63682 L .19236 .63722 L F
.774 .621 .69 r
.59556 .47797 m .59809 .47541 L .59382 .47414 L F
.644 .42 .564 r
.59556 .47797 m .59841 .47777 L .59809 .47541 L F
.659 .269 .295 r
.60063 .477 m .59809 .47541 L .59841 .47777 L F
.81 .701 .745 r
.62562 .41646 m .6285 .41672 L .62727 .41278 L F
.78 .558 .599 r
.63098 .4161 m .62727 .41278 L .6285 .41672 L F
.784 .783 .852 r
.54909 .67242 m .54936 .67508 L .54605 .6749 L F
.431 .47 .799 r
.67858 .46355 m .68365 .46542 L .68104 .46294 L F
.584 .613 .848 r
.67718 .46019 m .67858 .46355 L .68104 .46294 L F
.487 0 0 r
.51562 .69957 m .5142 .70025 L .51465 .69814 L F
.51562 .69957 m .51742 .7006 L .5142 .70025 L F
.422 .085 .286 r
.51799 .69892 m .51742 .7006 L .51562 .69957 L F
.617 .355 .497 r
.57904 .51086 m .57778 .51334 L .57556 .51333 L F
.608 .345 .492 r
.58105 .51198 m .57904 .51086 L .58108 .51047 L F
.58105 .51198 m .57778 .51334 L .57904 .51086 L F
.578 .793 .981 r
.56371 .64128 m .56519 .63927 L .56285 .63922 L F
.56371 .64128 m .56671 .64049 L .56519 .63927 L F
.635 .574 .768 r
.71293 .42533 m .71489 .43022 L .7168 .42817 L F
.756 .629 .72 r
.69128 .42498 m .69489 .42563 L .69367 .42118 L F
.351 .12 .417 r
.22226 .63424 m .22189 .63694 L .21991 .63721 L F
.074 0 .304 r
.22086 .6387 m .21991 .63721 L .22189 .63694 L F
.22086 .6387 m .21959 .63981 L .21991 .63721 L F
.443 .051 .199 r
.4459 .63477 m .4455 .63611 L .44325 .63621 L F
.794 .712 .774 r
.70092 .42541 m .70328 .42241 L .69984 .42174 L F
.637 .235 .264 r
.46149 .63423 m .46013 .6363 L .45814 .63457 L F
.349 0 0 r
.46378 .63454 m .46013 .6363 L .46149 .63423 L F
.849 .984 .861 r
.6323 .44067 m .63161 .44311 L .63057 .44231 L F
.999 .805 .501 r
.63161 .44311 m .63129 .4455 L .63057 .44231 L F
.506 .087 .178 r
.37381 .58885 m .3761 .58905 L .37755 .58697 L F
.413 .009 .159 r
.3761 .58905 m .37985 .58656 L .37755 .58697 L F
.626 .647 .851 r
.71415 .41493 m .71044 .41335 L .71292 .41259 L F
.641 .651 .845 r
.71292 .41259 m .71662 .41396 L .71415 .41493 L F
.793 .714 .776 r
.69984 .42174 m .70328 .42241 L .70212 .41889 L F
.718 .674 .805 r
.70212 .41889 m .70328 .42241 L .70569 .41994 L F
.825 .801 .828 r
.6136 .431 m .61725 .42905 L .61603 .42847 L F
.67 .447 .574 r
.61305 .4334 m .61725 .42905 L .6136 .431 L F
.61305 .4334 m .61565 .4336 L .61725 .42905 L F
.692 .472 .583 r
.61565 .4336 m .61908 .43326 L .61725 .42905 L F
.915 .557 .107 r
.65649 .43623 m .65807 .43965 L .65851 .43692 L F
.792 .868 .905 r
.65096 .4546 m .65151 .45625 L .65228 .45549 L F
.68 .914 .974 r
.65096 .4546 m .65228 .45549 L .65439 .45399 L F
.571 .344 .532 r
.56214 .51933 m .5647 .52129 L .56212 .52168 L F
.56214 .51933 m .5647 .51906 L .5647 .52129 L F
.78 .715 .791 r
.53868 .51838 m .54081 .51966 L .53702 .51951 L F
.793 .71 .772 r
.54312 .51665 m .54081 .51966 L .53868 .51838 L F
.528 .328 .553 r
.54785 .69313 m .54823 .69598 L .5502 .69303 L F
.259 .697 .962 r
.73848 .43035 m .74077 .43046 L .74203 .43123 L F
.732 .634 .751 r
.74091 .42771 m .74203 .43123 L .7436 .42764 L F
.157 .608 .933 r
.7437 .43078 m .74203 .43123 L .74077 .43046 L F
.7437 .43078 m .74359 .43107 L .74203 .43123 L F
.63 .683 .881 r
.74359 .43107 m .74223 .43382 L .74203 .43123 L F
.531 .518 .787 r
.35641 .61653 m .35736 .61244 L .35558 .61329 L F
.35641 .61653 m .35854 .61611 L .35736 .61244 L F
.547 .738 .964 r
.74989 .42263 m .75078 .42117 L .75084 .42237 L F
.432 .685 .97 r
.7498 .42263 m .74949 .42263 L .74597 .42135 L F
.547 .738 .964 r
.74954 .42238 m .75 .42282 L .75078 .42117 L F
.432 .685 .97 r
.74982 .42263 m .74981 .42263 L .7498 .42263 L F
.74981 .42263 m .74949 .42263 L .7498 .42263 L F
.74982 .42263 m .75 .42282 L .74949 .42263 L F
.584 .684 .91 r
.74597 .42135 m .75 .42282 L .74905 .42286 L F
.547 .738 .964 r
.74905 .42286 m .75 .42282 L .74954 .42238 L F
.74905 .42286 m .74954 .42238 L .74989 .42263 L F
.549 .74 .965 r
.75078 .42117 m .75 .42282 L .74961 .42243 L F
.547 .738 .964 r
.74954 .42238 m .75078 .42117 L .74961 .42243 L F
.549 .74 .965 r
.75078 .42117 m .74961 .42243 L .74707 .41989 L F
.547 .738 .964 r
.74961 .42243 m .75078 .42117 L .74989 .42263 L F
.432 .685 .97 r
.74674 .42033 m .74982 .42263 L .74597 .42135 L F
.74707 .41989 m .74961 .42243 L .74674 .42033 L F
.74961 .42243 m .74982 .42263 L .74674 .42033 L F
.486 .469 .764 r
.74989 .42263 m .74926 .42513 L .74905 .42286 L F
.75084 .42237 m .75069 .42263 L .74989 .42263 L F
.75069 .42263 m .74926 .42513 L .74989 .42263 L F
.75084 .42237 m .75228 .42414 L .74926 .42513 L F
.215 .046 .424 r
.75228 .42414 m .74989 .4271 L .74926 .42513 L F
.78 .558 .599 r
.63098 .4161 m .63145 .41318 L .62727 .41278 L F
.868 .444 .014 r
.66422 .42848 m .66394 .42937 L .66312 .42747 L F
.848 .397 0 r
.66422 .42848 m .6655 .43061 L .66394 .42937 L F
.901 .85 .784 r
.63129 .44759 m .63256 .44933 L .63104 .45144 L F
.627 .823 .976 r
.63379 .44722 m .63256 .44933 L .63129 .44759 L F
.63379 .44722 m .63485 .44857 L .63256 .44933 L F
.793 .71 .772 r
.54312 .51665 m .53868 .51838 L .53991 .51632 L F
.723 .722 .849 r
.62269 .40477 m .62378 .40754 L .62229 .40586 L F
.759 .847 .917 r
.62378 .40754 m .62044 .40779 L .62229 .40586 L F
.4 .366 .706 r
.62492 .40348 m .62378 .40754 L .62269 .40477 L F
.62492 .40348 m .62417 .40779 L .62378 .40754 L F
.586 .275 .409 r
.62417 .40779 m .62548 .40948 L .62378 .40754 L F
.778 .822 .887 r
.54865 .68512 m .54904 .68234 L .54738 .68341 L F
.54865 .68512 m .55034 .68302 L .54904 .68234 L F
.249 .686 .96 r
.2622 .79009 m .26613 .79098 L .26437 .78979 L F
.2622 .79009 m .26613 .79098 L .26437 .78979 L F
.796 .806 .86 r
.26613 .79098 m .26922 .7883 L .26437 .78979 L F
.26437 .78979 m .26922 .7883 L .26613 .79098 L F
.647 .578 .763 r
.70929 .42238 m .71056 .42615 L .71293 .42533 L F
0 0 0 r
.62989 .42951 m .63143 .42886 L .63214 .42862 L F
.496 .332 .588 r
.25025 .58079 m .25029 .58394 L .24817 .58418 L F
.538 .331 .547 r
.25024 .58626 m .24817 .58418 L .25029 .58394 L F
.25024 .58626 m .24828 .5867 L .24817 .58418 L F
.643 .894 .985 r
.73612 .4318 m .73736 .42998 L .73848 .43035 L F
.73612 .4318 m .73517 .43092 L .73736 .42998 L F
.284 0 0 r
.38227 .58643 m .38455 .58607 L .38612 .58446 L F
.426 0 .076 r
.38455 .58607 m .38847 .5842 L .38612 .58446 L F
.511 .35 .599 r
.21037 .60777 m .21251 .60726 L .21243 .60471 L F
.17 0 .014 r
.20918 .60965 m .21251 .60726 L .21037 .60777 L F
0 0 .35 r
.66767 .44001 m .66707 .43893 L .66568 .43646 L F
.975 .668 .333 r
.66767 .44001 m .66669 .4412 L .66707 .43893 L F
.66767 .44001 m .66791 .44222 L .66669 .4412 L F
.439 .659 .953 r
.68469 .40121 m .68324 .40283 L .68241 .40141 L F
.68469 .40121 m .68646 .40324 L .68324 .40283 L F
.69 .66 .815 r
.68748 .42423 m .6891 .42621 L .69128 .42498 L F
.423 .248 .537 r
.36235 .63125 m .36244 .63374 L .36422 .63058 L F
.359 .176 .491 r
.23106 .61936 m .2308 .62184 L .22904 .62246 L F
.24 .09 .467 r
.23033 .62418 m .22904 .62246 L .2308 .62184 L F
.23033 .62418 m .2289 .62509 L .22904 .62246 L F
.722 .737 .863 r
.66744 .4081 m .66921 .40799 L .66837 .40499 L F
.266 .766 .887 r
.66845 .40771 m .66921 .40799 L .66744 .4081 L F
.63 .704 .899 r
.66921 .40799 m .66992 .40392 L .66837 .40499 L F
.66944 .40801 m .67238 .4075 L .66992 .40392 L F
.592 .687 .908 r
.66992 .40392 m .67238 .4075 L .67392 .4071 L F
.63 .704 .899 r
.66944 .40801 m .67289 .40825 L .67238 .4075 L F
.54 .835 .999 r
.67122 .4062 m .67392 .4071 L .67188 .40932 L F
.027 0 0 r
.67289 .40825 m .6748 .40768 L .6748 .40767 L F
.54 .835 .999 r
.67392 .4071 m .67482 .4074 L .67452 .4076 L F
.6742 .40719 m .67517 .40703 L .67482 .4074 L F
.027 0 0 r
.67414 .4075 m .6748 .40767 L .67549 .40668 L F
.67289 .40825 m .6748 .40767 L .67414 .4075 L F
.54 .835 .999 r
.67414 .4075 m .67452 .4076 L .67429 .40775 L F
.67392 .4071 m .67452 .4076 L .67414 .4075 L F
.67463 .40691 m .67549 .40668 L .67517 .40703 L F
.592 .687 .908 r
.67298 .40544 m .67392 .4071 L .67549 .40668 L F
.66992 .40392 m .67392 .4071 L .67298 .40544 L F
.54 .835 .999 r
.67122 .4062 m .67517 .40703 L .6742 .40719 L F
.592 .687 .908 r
.67238 .4075 m .67289 .40825 L .67549 .40668 L F
.54 .835 .999 r
.67392 .4071 m .67429 .40775 L .67188 .40932 L F
.67122 .4062 m .67549 .40668 L .67463 .40691 L F
.63 .704 .899 r
.66921 .40799 m .66944 .40801 L .66992 .40392 L F
.347 0 0 r
.67188 .40932 m .66921 .40799 L .66845 .40771 L F
0 0 0 r
.18069 .54171 m .18297 .54151 L .18462 .54126 L F
.263 .771 .78 r
.18462 .54126 m .18297 .54151 L .1836 .54134 L F
.122 0 0 r
.18273 .5411 m .18462 .54126 L .18559 .54118 L F
.263 .771 .78 r
.18462 .54126 m .1836 .54134 L .18509 .54094 L F
.122 0 0 r
.18559 .54118 m .18462 .54126 L .18654 .54121 L F
.125 0 0 r
.18462 .54126 m .18837 .5411 L .18654 .54121 L F
.959 .823 .666 r
.66811 .45494 m .66609 .45623 L .66711 .45389 L F
.66811 .45494 m .66725 .45737 L .66609 .45623 L F
.933 .959 .765 r
.65865 .41411 m .65638 .41536 L .65728 .41318 L F
.65865 .41411 m .65717 .41659 L .65638 .41536 L F
.641 .91 .982 r
.66009 .4123 m .65865 .41411 L .65728 .41318 L F
.66009 .4123 m .66101 .41306 L .65865 .41411 L F
.503 .143 .289 r
.42267 .58034 m .42069 .58312 L .42199 .58082 L F
.42267 .58034 m .42344 .58308 L .42069 .58312 L F
.496 .14 .291 r
.42655 .58257 m .42267 .58034 L .42661 .58077 L F
.42655 .58257 m .42344 .58308 L .42267 .58034 L F
.06 0 0 r
.36538 .62812 m .36368 .62875 L .36205 .6289 L F
0 0 0 r
.36716 .62778 m .36368 .62875 L .36538 .62812 L F
.602 .887 .991 r
.68959 .41816 m .68749 .41986 L .68666 .41759 L F
.68959 .41816 m .69002 .41908 L .68749 .41986 L F
.385 .218 .528 r
.22443 .63131 m .22427 .63371 L .22226 .63424 L F
.311 .087 .404 r
.22371 .63613 m .22226 .63424 L .22427 .63371 L F
.22371 .63613 m .22189 .63694 L .22226 .63424 L F
.179 .075 .49 r
.2537 .55821 m .25255 .56003 L .25216 .55914 L F
.2537 .55821 m .25359 .56022 L .25255 .56003 L F
.281 .244 .638 r
.25424 .56199 m .25255 .56003 L .25359 .56022 L F
.25424 .56199 m .25277 .56376 L .25255 .56003 L F
.847 .709 .71 r
.52065 .55479 m .51694 .55682 L .51709 .55447 L F
.52065 .55479 m .5191 .55772 L .51694 .55682 L F
.735 .561 .657 r
.52346 .55731 m .5191 .55772 L .52065 .55479 L F
.506 .321 .563 r
.52291 .55178 m .52302 .55422 L .52065 .55479 L F
.646 .617 .806 r
.52302 .55422 m .52346 .55731 L .52065 .55479 L F
.334 .064 .348 r
.35777 .59805 m .36021 .59512 L .35807 .59586 L F
0 0 0 r
.46632 .62844 m .4625 .63017 L .46501 .63066 L F
.284 0 .125 r
.46632 .62844 m .46753 .62967 L .46797 .62718 L F
.46632 .62844 m .46501 .63066 L .46753 .62967 L F
.588 .312 .465 r
.36522 .59216 m .36823 .58979 L .36598 .59044 L F
.285 .104 .45 r
.24578 .58979 m .24568 .59226 L .24391 .59304 L F
.346 .186 .517 r
.24568 .59226 m .24371 .59551 L .24391 .59304 L F
.404 .588 .917 r
.56129 .63954 m .56243 .63778 L .5589 .63697 L F
.56129 .63954 m .56285 .63922 L .56243 .63778 L F
.675 .599 .763 r
.67834 .44881 m .68089 .44835 L .68123 .44634 L F
.764 .639 .722 r
.54185 .52781 m .54327 .5314 L .53961 .53089 L F
.583 .391 .587 r
.54327 .5314 m .5417 .53452 L .53961 .53089 L F
.54327 .5314 m .54323 .53381 L .5417 .53452 L F
.553 .367 .583 r
.54327 .5314 m .54569 .53328 L .54323 .53381 L F
.621 .343 .474 r
.54327 .5314 m .54647 .53076 L .54569 .53328 L F
.298 .601 .95 r
.24146 .54634 m .24398 .54684 L .2435 .54822 L F
.262 .56 .933 r
.24398 .54684 m .24538 .54858 L .2435 .54822 L F
.818 .683 .14 r
.65717 .41659 m .65686 .4175 L .65638 .41536 L F
.65717 .41659 m .65706 .41866 L .65686 .4175 L F
.51 .085 .169 r
.43134 .63711 m .42986 .63911 L .4275 .639 L F
.541 .118 .189 r
.43335 .63856 m .43134 .63711 L .43369 .63685 L F
.43335 .63856 m .42986 .63911 L .43134 .63711 L F
0 0 0 r
.46746 .63417 m .46632 .63431 L .46378 .63454 L F
.215 .738 .761 r
.46829 .63386 m .46746 .63417 L .46971 .63351 L F
.46829 .63386 m .46632 .63431 L .46746 .63417 L F
.209 .714 .903 r
.39482 .63041 m .3986 .63072 L .39636 .63139 L F
.84 .986 .866 r
.59209 .44384 m .5928 .44151 L .59343 .44216 L F
.59209 .44384 m .59008 .44421 L .5928 .44151 L F
.641 .759 .934 r
.68488 .41128 m .68887 .41273 L .68715 .41085 L F
.503 .736 .978 r
.69133 .41219 m .69258 .41014 L .68987 .41062 L F
.538 .924 .82 r
.69258 .41014 m .69232 .41026 L .68987 .41062 L F
.546 .788 .988 r
.68887 .41273 m .68987 .41062 L .68728 .411 L F
.68887 .41273 m .69133 .41219 L .68987 .41062 L F
.538 .924 .82 r
.69232 .41026 m .68801 .41232 L .68987 .41062 L F
.546 .788 .988 r
.68728 .411 m .68987 .41062 L .68715 .41085 L F
.03 .6 .763 r
.2261 .54316 m .22863 .54323 L .22993 .54335 L F
.02 0 0 r
.22863 .54323 m .23216 .54332 L .22993 .54335 L F
0 0 .4 r
.38579 .60995 m .38738 .61419 L .3868 .61359 L F
0 0 .108 r
.3874 .61424 m .3868 .61359 L .38738 .61419 L F
.3874 .61424 m .38612 .6163 L .3868 .61359 L F
0 0 0 r
.66819 .40199 m .66432 .40455 L .66719 .40106 L F
.634 .891 .986 r
.6705 .4009 m .66819 .40199 L .66719 .40106 L F
.548 .398 .63 r
.2552 .56576 m .25277 .56376 L .25424 .56199 L F
.2552 .56576 m .25296 .56629 L .25277 .56376 L F
.457 .309 .592 r
.35553 .59914 m .35744 .60104 L .35777 .59805 L F
.35553 .59914 m .35553 .60167 L .35744 .60104 L F
.535 .643 .903 r
.71044 .41335 m .70691 .41077 L .70905 .40949 L F
.63 .651 .852 r
.71157 .40918 m .71044 .41335 L .70905 .40949 L F
.71157 .40918 m .71292 .41259 L .71044 .41335 L F
.721 .611 .733 r
.5267 .5548 m .52669 .55747 L .52434 .55765 L F
.731 .501 .579 r
.52669 .55747 m .52439 .56003 L .52434 .55765 L F
.52669 .55747 m .52761 .56056 L .52439 .56003 L F
.641 .459 .621 r
.53018 .55539 m .52669 .55747 L .5267 .5548 L F
.53018 .55539 m .53007 .55737 L .52669 .55747 L F
.58 .371 .562 r
.53007 .55737 m .52761 .56056 L .52669 .55747 L F
.034 0 .351 r
.19463 .63437 m .19562 .63573 L .19666 .63338 L F
.19463 .63437 m .19421 .63682 L .19562 .63573 L F
.466 0 0 r
.45012 .63108 m .45408 .63107 L .45177 .63068 L F
.577 .254 .386 r
.55402 .52539 m .55404 .52726 L .55068 .52784 L F
.636 .301 .387 r
.55402 .52539 m .55651 .5273 L .55404 .52726 L F
.575 .334 .514 r
.55651 .52508 m .55651 .5273 L .55402 .52539 L F
.899 .528 .322 r
.54306 .66102 m .54181 .66132 L .54031 .66048 L F
.54306 .66102 m .54404 .6632 L .54181 .66132 L F
.156 .224 .683 r
.36005 .61949 m .36038 .61567 L .35854 .61611 L F
.36005 .61949 m .36138 .61876 L .36038 .61567 L F
.197 .318 .762 r
.36005 .61949 m .36269 .62189 L .36138 .61876 L F
0 0 .051 r
.66568 .43646 m .66605 .43302 L .66659 .43429 L F
.634 .197 .193 r
.22516 .56329 m .22367 .56486 L .2217 .56322 L F
.516 .098 .186 r
.45982 .62936 m .45888 .63088 L .4625 .63017 L F
.53 .139 .245 r
.69901 .44635 m .70125 .44717 L .70217 .4454 L F
.554 .359 .571 r
.70217 .4454 m .70492 .44527 L .70475 .44288 L F
.722 .497 .584 r
.70125 .44717 m .70492 .44527 L .70217 .4454 L F
.535 .342 .567 r
.19714 .63097 m .19934 .62815 L .19606 .62815 L F
.19714 .63097 m .19902 .63074 L .19934 .62815 L F
.216 0 .338 r
.19902 .63074 m .20114 .62759 L .19934 .62815 L F
.262 .414 .826 r
.38981 .62408 m .38874 .62569 L .38843 .62412 L F
.376 .569 .913 r
.38981 .62408 m .39179 .62683 L .38874 .62569 L F
.446 .599 .909 r
.19873 .62376 m .20163 .62468 L .20056 .62294 L F
.304 .013 .295 r
.19666 .63338 m .19902 .63074 L .19714 .63097 L F
.446 .102 .288 r
.47675 .62185 m .47916 .62151 L .4798 .61985 L F
.584 .345 .52 r
.47916 .62151 m .48183 .61902 L .4798 .61985 L F
.389 .719 .988 r
.54753 .67134 m .54909 .67242 L .54901 .67242 L F
.54753 .67134 m .54901 .67242 L .54632 .67246 L F
.784 .783 .852 r
.54909 .67242 m .54605 .6749 L .54632 .67246 L F
.389 .719 .988 r
.54753 .67134 m .54632 .67246 L .54605 .6749 L F
.881 .838 .8 r
.5461 .67029 m .54753 .67134 L .54562 .67461 L F
.54612 .67015 m .54753 .67134 L .5461 .67029 L F
.518 .4 .658 r
.49458 .71103 m .4938 .71379 L .4962 .71314 L F
.49458 .71103 m .4938 .71379 L .4962 .71314 L F
.567 .88 .992 r
.57971 .63629 m .57874 .63802 L .57714 .63708 L F
.57971 .63629 m .58131 .63713 L .57874 .63802 L F
.71 .638 .774 r
.7168 .42817 m .72039 .43063 L .7191 .42756 L F
.593 .508 .728 r
.72039 .43063 m .7233 .42872 L .7191 .42756 L F
.72039 .43063 m .7232 .42997 L .7233 .42872 L F
.759 .324 .218 r
.64378 .42789 m .64206 .4293 L .64265 .42696 L F
0 0 .496 r
.67617 .43717 m .67576 .43693 L .67503 .43551 L F
.67617 .43717 m .6769 .43839 L .67576 .43693 L F
.094 0 0 r
.39452 .58168 m .39522 .58245 L .397 .58141 L F
.39452 .58168 m .39301 .58307 L .39522 .58245 L F
.019 0 0 r
.61483 .48793 m .61552 .48622 L .61765 .4856 L F
.766 .634 .715 r
.53232 .5251 m .53393 .52879 L .53012 .52802 L F
.777 .624 .691 r
.53393 .52879 m .52971 .53058 L .53012 .52802 L F
.53393 .52879 m .53355 .53102 L .52971 .53058 L F
.711 .61 .742 r
.53579 .52795 m .53393 .52879 L .53232 .5251 L F
.682 .533 .677 r
.53579 .52795 m .53355 .53102 L .53393 .52879 L F
.753 .554 .627 r
.52162 .56039 m .5191 .55772 L .52346 .55731 L F
.646 .617 .806 r
.52302 .55422 m .52434 .55765 L .52346 .55731 L F
.632 .427 .587 r
.52439 .56003 m .52346 .55731 L .52434 .55765 L F
.52439 .56003 m .52162 .56039 L .52346 .55731 L F
.601 .412 .597 r
.50781 .70715 m .50461 .71018 L .50649 .70615 L F
.633 .217 .237 r
.50378 .70709 m .50781 .70715 L .5038 .70579 L F
.626 .184 .182 r
.5038 .70579 m .50781 .70715 L .50649 .70615 L F
.594 .217 .297 r
.52696 .69595 m .52611 .69792 L .52377 .69768 L F
.059 0 0 r
.52898 .69563 m .52611 .69792 L .52696 .69595 L F
.862 .782 .771 r
.54432 .50763 m .54049 .50967 L .54223 .50662 L F
.54432 .50763 m .54228 .51105 L .54049 .50967 L F
.88 .806 .773 r
.54468 .50329 m .54432 .50763 L .54223 .50662 L F
.083 .025 .486 r
.49496 .70713 m .49458 .71103 L .49534 .70987 L F
.71 .482 .577 r
.49898 .71058 m .49496 .70713 L .49534 .70987 L F
.505 .217 .41 r
.58387 .50761 m .58615 .50911 L .58373 .50975 L F
.58387 .50761 m .58637 .50718 L .58615 .50911 L F
.578 .533 .768 r
.52768 .54831 m .52544 .54893 L .52409 .54521 L F
.676 .234 .195 r
.52544 .54893 m .52752 .55059 L .52545 .5502 L F
.515 .328 .566 r
.52768 .54831 m .52752 .55059 L .52544 .54893 L F
.654 .863 .979 r
.54959 .63023 m .54572 .63038 L .54822 .62785 L F
.54572 .63038 m .54959 .63023 L .54807 .63004 L F
.483 .566 .864 r
.55088 .62999 m .54959 .63023 L .54822 .62785 L F
.437 .297 .592 r
.54959 .63023 m .55088 .62999 L .54807 .63004 L F
.54959 .63023 m .55167 .63347 L .55088 .62999 L F
.763 .677 .767 r
.5267 .5548 m .52434 .55765 L .52302 .55422 L F
.702 .618 .761 r
.52851 .69026 m .53196 .69077 L .531 .68706 L F
.655 .485 .642 r
.52851 .69026 m .52615 .69284 L .53018 .69153 L F
.438 0 0 r
.53018 .69153 m .53086 .69206 L .52851 .69026 L F
.595 .845 .482 r
.53086 .69206 m .53196 .69077 L .52851 .69026 L F
.623 .569 .773 r
.531 .68706 m .53196 .69077 L .5346 .68985 L F
.615 .541 .748 r
.53196 .69077 m .53456 .69146 L .5346 .68985 L F
.335 .756 .976 r
.46197 .57113 m .46535 .57174 L .46313 .5719 L F
.186 .657 .935 r
.4617 .57137 m .46197 .57113 L .46313 .5719 L F
.719 .262 .165 r
.46197 .57113 m .46245 .57216 L .46535 .57174 L F
.46245 .57216 m .4633 .57404 L .46431 .57291 L F
.46245 .57216 m .46431 .57291 L .46535 .57174 L F
0 0 0 r
.46197 .57113 m .46155 .57259 L .46233 .57081 L F
0 0 .438 r
.46273 .5699 m .4633 .57404 L .46197 .57113 L F
0 0 0 r
.46197 .57113 m .46233 .57081 L .46273 .5699 L F
.186 .657 .935 r
.46052 .57094 m .46197 .57113 L .4617 .57137 L F
.736 .429 .462 r
.45791 .57087 m .46197 .57113 L .46052 .57094 L F
.45791 .57087 m .46155 .57259 L .46197 .57113 L F
.661 .614 .791 r
.46273 .5699 m .46184 .57192 L .45903 .56671 L F
.46184 .57192 m .46155 .57259 L .46114 .57165 L F
.46184 .57192 m .46114 .57165 L .45903 .56671 L F
0 0 0 r
.20456 .65706 m .20163 .65976 L .20319 .65814 L F
.612 .618 .832 r
.69699 .40798 m .69317 .4057 L .69699 .4074 L F
.597 .614 .839 r
.6989 .40592 m .69699 .40798 L .69699 .4074 L F
.6989 .40592 m .69944 .40729 L .69699 .40798 L F
.596 .389 .571 r
.52506 .55322 m .52291 .55178 L .52545 .5502 L F
.52506 .55322 m .52302 .55422 L .52291 .55178 L F
.266 .766 .887 r
.66845 .40771 m .66744 .4081 L .66584 .40942 L F
.729 .536 .63 r
.53448 .68723 m .5346 .68985 L .53687 .68697 L F
.252 0 .095 r
.53917 .68655 m .53738 .68682 L .53687 .68697 L F
.587 .555 .786 r
.7232 .42997 m .72425 .43439 L .7264 .43352 L F
.534 .107 .177 r
.72403 .43554 m .72659 .43562 L .72425 .43439 L F
.452 .234 .491 r
.72425 .43439 m .72659 .43562 L .7264 .43352 L F
.962 .796 .631 r
.65523 .43027 m .65452 .43318 L .65609 .43428 L F
.944 .625 .401 r
.65452 .43318 m .65649 .43623 L .65609 .43428 L F
.755 .687 .786 r
.65523 .43027 m .65609 .43428 L .65883 .43083 L F
.778 .527 .556 r
.71824 .45109 m .7148 .45298 L .71571 .45162 L F
.768 .68 .765 r
.42867 .59834 m .42966 .6018 L .42594 .60136 L F
.544 .817 .997 r
.42594 .60136 m .42966 .6018 L .42883 .60077 L F
.973 .701 .291 r
.42883 .60077 m .42966 .6018 L .42867 .59834 L F
0 0 0 r
.61861 .4842 m .61957 .48427 L .61765 .4856 L F
.61861 .4842 m .62074 .48318 L .61957 .48427 L F
.478 0 0 r
.67759 .41934 m .67771 .41937 L .6779 .42028 L F
.065 0 0 r
.68083 .41951 m .6779 .42028 L .68022 .41999 L F
0 0 0 r
.68122 .41941 m .68083 .41951 L .68083 .41951 L F
.68083 .41951 m .67989 .41976 L .68083 .41951 L F
.67989 .41976 m .6779 .42028 L .68037 .41963 L F
.67989 .41976 m .68037 .41963 L .68083 .41951 L F
.68063 .41956 m .67986 .41976 L .68083 .41951 L F
.67986 .41976 m .6779 .42028 L .67989 .41976 L F
.67986 .41976 m .67989 .41976 L .68083 .41951 L F
.68083 .41951 m .68063 .41956 L .68083 .41951 L F
.68083 .41951 m .68083 .41951 L .68022 .41999 L F
.1 .656 .741 r
.68022 .41999 m .68042 .41962 L .68083 .41951 L F
0 0 0 r
.68083 .41951 m .68071 .41954 L .68083 .41951 L F
.68071 .41954 m .68063 .41956 L .68083 .41951 L F
.68122 .41941 m .68083 .41951 L .68327 .41758 L F
.68327 .41758 m .68083 .41951 L .68083 .41951 L F
.562 .526 .772 r
.6824 .4157 m .68183 .41792 L .67934 .41273 L F
.991 .759 .484 r
.6824 .4157 m .68294 .4166 L .68183 .41792 L F
.838 .794 .809 r
.68327 .41758 m .67949 .41673 L .68186 .41688 L F
.1 .656 .741 r
.68083 .41951 m .68127 .41838 L .68327 .41758 L F
.838 .794 .809 r
.68117 .4171 m .68071 .41861 L .67949 .41673 L F
.68327 .41758 m .68101 .41848 L .68117 .4171 L F
.68101 .41848 m .68071 .41861 L .68117 .4171 L F
.427 .808 .991 r
.67791 .41942 m .67959 .41984 L .68071 .41954 L F
.1 .656 .741 r
.68071 .41954 m .68186 .41688 L .68083 .41951 L F
.427 .808 .991 r
.68066 .41941 m .68071 .41954 L .68122 .41941 L F
.1 .656 .741 r
.68022 .41999 m .68085 .41992 L .68092 .41934 L F
.68051 .41945 m .68186 .41688 L .68071 .41954 L F
.427 .808 .991 r
.67757 .41942 m .68066 .41941 L .67949 .41673 L F
.68066 .41941 m .68122 .41941 L .68096 .419 L F
.1 .656 .741 r
.68051 .41945 m .68066 .41941 L .68101 .41848 L F
.68066 .41941 m .68096 .419 L .68101 .41848 L F
.427 .808 .991 r
.68066 .41941 m .68096 .419 L .67949 .41673 L F
.1 .656 .741 r
.68066 .41941 m .68092 .41934 L .68096 .419 L F
.427 .808 .991 r
.68051 .41945 m .68071 .41954 L .68066 .41941 L F
.1 .656 .741 r
.68042 .41962 m .68051 .41945 L .68071 .41954 L F
.68022 .41999 m .68092 .41934 L .68051 .41945 L F
.427 .808 .991 r
.68041 .41941 m .68051 .41945 L .68066 .41941 L F
.67791 .41942 m .68071 .41954 L .68041 .41941 L F
.838 .794 .809 r
.68327 .41758 m .68122 .41941 L .68071 .41861 L F
.1 .656 .741 r
.68127 .41838 m .68186 .41688 L .68327 .41758 L F
.869 .906 .855 r
.68186 .41688 m .68122 .41941 L .68327 .41758 L F
.725 .761 .881 r
.68186 .41688 m .68122 .41941 L .68096 .419 L F
.1 .656 .741 r
.68101 .41848 m .68113 .41859 L .68186 .41688 L F
.725 .761 .881 r
.68186 .41688 m .68096 .419 L .67949 .41673 L F
.1 .656 .741 r
.68096 .419 m .68113 .41859 L .68101 .41848 L F
.725 .761 .881 r
.67949 .41673 m .68096 .419 L .68186 .41688 L F
.68096 .419 m .68122 .41941 L .68186 .41688 L F
.67949 .41673 m .68122 .41941 L .68186 .41688 L F
.1 .656 .741 r
.68085 .41992 m .68237 .41976 L .68113 .41859 L F
.68085 .41992 m .68113 .41859 L .68096 .419 L F
.68113 .41859 m .68237 .41976 L .68186 .41688 L F
.478 0 0 r
.67771 .41937 m .68022 .41999 L .6779 .42028 L F
.751 .681 .784 r
.67773 .42033 m .67822 .42369 L .67959 .41984 L F
.67904 .41998 m .68022 .41999 L .67918 .42004 L F
.427 .808 .991 r
.67757 .41942 m .6779 .42028 L .67772 .41942 L F
.751 .681 .784 r
.67759 .41934 m .67773 .42033 L .67959 .41984 L F
.67759 .41934 m .67959 .41984 L .67904 .41998 L F
.67959 .41984 m .67822 .42369 L .68022 .41999 L F
.67959 .41984 m .68022 .41999 L .67904 .41998 L F
.478 0 0 r
.67959 .41984 m .67918 .42004 L .68022 .41999 L F
.67759 .41934 m .67904 .41998 L .67959 .41984 L F
.67904 .41998 m .67918 .42004 L .67959 .41984 L F
.811 .627 .653 r
.71709 .43491 m .71807 .43652 L .71786 .43402 L F
.498 .248 .466 r
.55937 .52228 m .56111 .52418 L .55912 .52479 L F
.55937 .52228 m .56212 .52168 L .56111 .52418 L F
.691 .222 .133 r
.54874 .66218 m .54977 .66068 L .54874 .65974 L F
.519 .307 .532 r
.2196 .58111 m .22186 .5807 L .22207 .57812 L F
.685 .578 .729 r
.22185 .57575 m .22207 .57812 L .22427 .57511 L F
.564 .414 .636 r
.22427 .57511 m .22207 .57812 L .22458 .57761 L F
.471 .267 .52 r
.22207 .57812 m .22395 .58014 L .22458 .57761 L F
.22207 .57812 m .22186 .5807 L .22395 .58014 L F
.115 0 .431 r
.21426 .59855 m .21426 .601 L .21442 .59831 L F
.265 .131 .505 r
.54801 .52779 m .54799 .53024 L .54647 .53076 L F
.484 .294 .547 r
.54799 .53024 m .54569 .53328 L .54647 .53076 L F
.783 .76 .832 r
.53788 .70078 m .53573 .70226 L .53341 .7013 L F
.942 .849 .722 r
.53573 .70226 m .5333 .70409 L .53341 .7013 L F
.53573 .70226 m .53473 .70467 L .5333 .70409 L F
.695 .637 .787 r
.52903 .55227 m .53018 .55539 L .5267 .5548 L F
.692 .644 .798 r
.53145 .55127 m .53018 .55539 L .52903 .55227 L F
.53145 .55127 m .53263 .55466 L .53018 .55539 L F
.518 .289 .506 r
.53263 .55466 m .53007 .55737 L .53018 .55539 L F
.912 .89 .797 r
.53451 .52209 m .53108 .52411 L .53337 .52107 L F
.53451 .52209 m .53232 .5251 L .53108 .52411 L F
.733 .583 .687 r
.53451 .52209 m .53648 .52602 L .53232 .5251 L F
.898 .937 .83 r
.53451 .52209 m .5357 .51806 L .53702 .51951 L F
.53451 .52209 m .53337 .52107 L .5357 .51806 L F
.711 .574 .699 r
.53825 .52482 m .53648 .52602 L .53451 .52209 L F
.816 .721 .76 r
.61423 .42422 m .61746 .42483 L .61681 .42185 L F
.852 .704 .698 r
.61409 .42678 m .61746 .42483 L .61423 .42422 L F
.61409 .42678 m .61603 .42847 L .61746 .42483 L F
.743 .677 .787 r
.61681 .42185 m .61746 .42483 L .62012 .42202 L F
.711 .61 .742 r
.53579 .52795 m .53232 .5251 L .53648 .52602 L F
.692 .548 .685 r
.53579 .52795 m .53758 .53113 L .53355 .53102 L F
.728 .611 .726 r
.53825 .52482 m .53579 .52795 L .53648 .52602 L F
.698 .566 .702 r
.53825 .52482 m .53965 .52866 L .53579 .52795 L F
.654 .482 .639 r
.53965 .52866 m .53758 .53113 L .53579 .52795 L F
.769 .687 .773 r
.53763 .53439 m .53886 .53765 L .53558 .5372 L F
.747 .587 .677 r
.53886 .53765 m .53442 .53937 L .53558 .5372 L F
.53886 .53765 m .53863 .54003 L .53442 .53937 L F
.707 .606 .742 r
.5417 .53452 m .53886 .53765 L .53763 .53439 L F
.5417 .53452 m .54057 .53688 L .53886 .53765 L F
.674 .521 .67 r
.54057 .53688 m .53863 .54003 L .53886 .53765 L F
.969 .687 .443 r
.57108 .63782 m .5712 .63776 L .57118 .63757 L F
.5712 .63776 m .57259 .63696 L .57118 .63757 L F
0 .102 .633 r
.57062 .63634 m .57118 .63757 L .57148 .63674 L F
.57062 .63634 m .57112 .63688 L .57118 .63757 L F
.372 0 0 r
.57259 .63696 m .57323 .63757 L .57118 .63757 L F
0 .102 .633 r
.57148 .63674 m .57118 .63757 L .57323 .63757 L F
.57112 .63688 m .57293 .63889 L .57118 .63757 L F
.969 .687 .443 r
.56875 .63916 m .57108 .63782 L .57118 .63757 L F
.372 0 0 r
.57259 .63696 m .57497 .63789 L .57323 .63757 L F
.837 .377 0 r
.1903 .64298 m .19001 .6442 L .18849 .64287 L F
.186 .162 .596 r
.19062 .64576 m .19145 .64517 L .19065 .64365 L F
.1904 .64388 m .19065 .64365 L .1903 .64298 L F
.19062 .64576 m .19065 .64365 L .1904 .64388 L F
.837 .377 0 r
.1903 .64298 m .19145 .64517 L .19001 .6442 L F
.738 .34 .296 r
.18916 .64195 m .1903 .64372 L .19224 .64231 L F
.523 .873 .626 r
.19205 .64237 m .1903 .64372 L .19175 .64247 L F
.19224 .64231 m .19165 .64274 L .19205 .64237 L F
.19165 .64274 m .1903 .64372 L .19205 .64237 L F
.783 .76 .832 r
.53788 .70078 m .53341 .7013 L .53612 .6996 L F
0 .395 .819 r
.53612 .6996 m .53807 .70045 L .53853 .70113 L F
.53729 .70039 m .53853 .70113 L .53788 .70078 L F
.53754 .7005 m .53853 .70113 L .53729 .70039 L F
0 0 .357 r
.53807 .70045 m .53733 .7045 L .53853 .70113 L F
.53802 .70071 m .53837 .70314 L .53733 .7045 L F
.53807 .70045 m .5381 .70075 L .53802 .70071 L F
.5381 .70075 m .53837 .70314 L .53802 .70071 L F
0 .395 .819 r
.53612 .6996 m .53754 .7005 L .53729 .70039 L F
.211 .697 .927 r
.6741 .40149 m .6705 .4009 L .6729 .40064 L F
.393 .78 .99 r
.6753 .4005 m .6741 .40149 L .6729 .40064 L F
.6753 .4005 m .67646 .40124 L .6741 .40149 L F
.327 .131 .455 r
.5144 .69638 m .51465 .69814 L .51633 .69749 L F
.807 .794 .841 r
.54049 .50967 m .53988 .51314 L .53784 .51268 L F
.54049 .50967 m .54228 .51105 L .53988 .51314 L F
.844 .615 .592 r
.53988 .51314 m .53784 .51489 L .53784 .51268 L F
.53988 .51314 m .53991 .51632 L .53784 .51489 L F
.46 .492 .804 r
.69133 .41219 m .69256 .41594 L .69477 .41565 L F
.534 .024 0 r
.58735 .6231 m .58963 .62537 L .58864 .62447 L F
.566 .243 .381 r
.58672 .62024 m .58671 .62222 L .58912 .62119 L F
0 0 0 r
.58671 .62222 m .58805 .62097 L .58912 .62119 L F
1 .818 .498 r
.58805 .62097 m .5877 .62362 L .58864 .62447 L F
.674 .603 .767 r
.58422 .62199 m .58442 .62494 L .58667 .6224 L F
.775 .399 .343 r
.58667 .6224 m .58864 .62447 L .58541 .62362 L F
1 .818 .498 r
.5877 .62362 m .58766 .62386 L .58864 .62447 L F
.534 .024 0 r
.58963 .62537 m .58989 .62562 L .58864 .62447 L F
.554 .808 .992 r
.35944 .6295 m .35961 .62778 L .35724 .6279 L F
.35944 .6295 m .36205 .6289 L .35961 .62778 L F
.674 .557 .715 r
.53825 .52482 m .54185 .52781 L .53965 .52866 L F
.53825 .52482 m .54292 .52644 L .54185 .52781 L F
.997 .779 .48 r
.67276 .43372 m .67409 .43089 L .67329 .42996 L F
.67276 .43372 m .67384 .43416 L .67409 .43089 L F
.97 .898 .695 r
.67506 .42622 m .67409 .43089 L .67628 .42702 L F
.552 .451 .693 r
.25205 .57769 m .25302 .58037 L .25025 .58079 L F
.489 .326 .587 r
.2524 .58334 m .25025 .58079 L .25302 .58037 L F
.2524 .58334 m .25029 .58394 L .25025 .58079 L F
.327 0 0 r
.4008 .63122 m .40097 .63103 L .3986 .63072 L F
.096 .581 .905 r
.39907 .6302 m .4008 .63122 L .3986 .63072 L F
0 .25 .714 r
.39907 .6302 m .40062 .63142 L .4008 .63122 L F
.40062 .63142 m .40105 .63177 L .4008 .63122 L F
.327 0 0 r
.4008 .63122 m .40232 .6312 L .40097 .63103 L F
.718 .194 0 r
.40105 .63177 m .40232 .6312 L .4008 .63122 L F
.40105 .63177 m .40457 .63334 L .40232 .6312 L F
.54 .326 .538 r
.40232 .6312 m .40457 .63334 L .40463 .63093 L F
.841 .929 .546 r
.20163 .65976 m .20008 .66309 L .20038 .66064 L F
.833 .683 .697 r
.59554 .46559 m .59906 .46603 L .59912 .46367 L F
.817 .744 .782 r
.59647 .46895 m .59906 .46603 L .59554 .46559 L F
.676 .573 .731 r
.69415 .45148 m .6941 .45403 L .69728 .45295 L F
.347 .073 .348 r
.6939 .45607 m .69728 .45295 L .6941 .45403 L F
.812 .714 .756 r
.59761 .46269 m .59912 .46367 L .59795 .46047 L F
.833 .683 .697 r
.59554 .46559 m .59912 .46367 L .59761 .46269 L F
.626 .656 .859 r
.72145 .41218 m .72013 .41608 L .71889 .41285 L F
.72145 .41218 m .72273 .41553 L .72013 .41608 L F
.779 .323 .162 r
.68554 .46128 m .68658 .46005 L .68401 .45917 L F
.249 .223 .632 r
.6269 .40507 m .62417 .40779 L .62492 .40348 L F
.043 .138 .639 r
.62605 .40843 m .62417 .40779 L .6269 .40507 L F
.589 .428 .631 r
.70475 .44288 m .70722 .44242 L .70728 .43997 L F
.662 .493 .646 r
.70492 .44527 m .70722 .44242 L .70475 .44288 L F
.635 .306 .397 r
.44439 .63299 m .44907 .63014 L .44466 .63133 L F
.44439 .63299 m .44684 .63341 L .44907 .63014 L F
.735 .453 .502 r
.44684 .63341 m .45012 .63108 L .44907 .63014 L F
.284 0 0 r
.20431 .54119 m .20648 .54165 L .20831 .54173 L F
.032 .602 .746 r
.20831 .54173 m .20648 .54165 L .21031 .54173 L F
.728 .758 .876 r
.4439 .56747 m .44003 .56709 L .44241 .56629 L F
.4439 .56747 m .44226 .56765 L .44003 .56709 L F
.695 .837 .951 r
.44597 .56625 m .4439 .56747 L .44241 .56629 L F
.421 .371 .697 r
.49458 .71103 m .4962 .71314 L .49534 .70987 L F
.455 .467 .782 r
.25742 .5528 m .2547 .55569 L .25507 .55207 L F
.461 .474 .785 r
.25742 .5528 m .25651 .55632 L .2547 .55569 L F
.729 .969 .711 r
.21864 .56001 m .21924 .55883 L .22071 .55781 L F
.848 .496 .387 r
.21887 .56025 m .21942 .56274 L .21864 .56001 L F
.2217 .56322 m .21942 .56274 L .21887 .56025 L F
.859 .541 .448 r
.2217 .56322 m .21979 .56478 L .21942 .56274 L F
0 0 .048 r
.21979 .56478 m .21983 .56456 L .21942 .56274 L F
.21983 .56456 m .22045 .56081 L .21942 .56274 L F
0 0 .457 r
.21864 .56001 m .21942 .56274 L .21924 .55883 L F
.914 .856 .77 r
.66963 .44638 m .66861 .44808 L .66813 .44525 L F
.663 .631 .807 r
.6748 .40768 m .67893 .41007 L .67787 .40851 L F
.901 .628 .123 r
.67861 .41074 m .67934 .41273 L .67893 .41007 L F
.652 .803 .955 r
.67893 .41007 m .68056 .40772 L .67787 .40851 L F
.67893 .41007 m .68165 .40909 L .68056 .40772 L F
.907 .713 .211 r
.6532 .42483 m .65336 .42392 L .65317 .42278 L F
.675 .54 .693 r
.7061 .4374 m .70976 .43942 L .70973 .43654 L F
.7061 .4374 m .70728 .43997 L .70976 .43942 L F
.073 0 0 r
.20019 .55239 m .19974 .55238 L .19731 .55217 L F
.032 .534 .875 r
.20305 .55367 m .19974 .55238 L .20019 .55239 L F
.901 .85 .784 r
.63129 .44759 m .63104 .45144 L .62934 .45075 L F
.833 .508 .439 r
.63104 .45144 m .62912 .45316 L .62934 .45075 L F
.63104 .45144 m .63187 .45421 L .62912 .45316 L F
.939 .614 .393 r
.54057 .53688 m .54104 .53932 L .53863 .54003 L F
.647 .534 .712 r
.54323 .53381 m .54057 .53688 L .5417 .53452 L F
.413 .757 .995 r
.45445 .57587 m .45331 .57489 L .45084 .57513 L F
.461 .618 .917 r
.45445 .57587 m .45555 .57386 L .45331 .57489 L F
.45445 .57587 m .45661 .57578 L .45555 .57386 L F
.731 .732 .852 r
.52506 .55322 m .5267 .5548 L .52302 .55422 L F
.752 .735 .836 r
.52903 .55227 m .5267 .5548 L .52506 .55322 L F
.479 .238 .471 r
.70976 .43942 m .71203 .43715 L .70973 .43654 L F
.516 .46 .732 r
.69415 .45148 m .69592 .44751 L .69335 .44823 L F
.648 .435 .581 r
.56936 .516 m .56721 .51895 L .56718 .51627 L F
.56936 .516 m .57073 .51874 L .56721 .51895 L F
.6 .42 .61 r
.57348 .5163 m .57073 .51874 L .56936 .516 L F
.514 .64 .911 r
.69471 .40341 m .69317 .4057 L .69224 .40399 L F
.69471 .40341 m .69699 .4074 L .69317 .4057 L F
.704 .561 .69 r
.43237 .63061 m .43474 .62783 L .43291 .62897 L F
0 0 0 r
.19907 .66943 m .19753 .67161 L .19639 .67224 L F
0 0 .297 r
.20036 .66571 m .20017 .66824 L .19907 .66943 L F
.209 0 .073 r
.20007 .67068 m .19907 .66943 L .20017 .66824 L F
.20007 .67068 m .19753 .67161 L .19907 .66943 L F
.739 .553 .641 r
.23034 .81931 m .23137 .8192 L .23122 .81659 L F
.23034 .81931 m .23137 .8192 L .23122 .81659 L F
.442 .325 .625 r
.23137 .8192 m .23331 .81842 L .23122 .81659 L F
.519 0 0 r
.4382 .63106 m .44064 .63239 L .44208 .63127 L F
.65 .15 .049 r
.44064 .63239 m .44439 .63299 L .44208 .63127 L F
.606 .239 .319 r
.44208 .63127 m .44439 .63299 L .44466 .63133 L F
.965 .899 .709 r
.60899 .44459 m .60999 .44299 L .60892 .44192 L F
.791 .921 .925 r
.60892 .44192 m .60999 .44299 L .61318 .44061 L F
.602 .337 .487 r
.41728 .58655 m .41687 .58964 L .41374 .58987 L F
.06 0 .163 r
.41905 .58429 m .41866 .58659 L .41728 .58655 L F
.374 .141 .428 r
.41831 .58849 m .41728 .58655 L .41866 .58659 L F
.41831 .58849 m .41687 .58964 L .41728 .58655 L F
0 0 0 r
.17465 .55747 m .17257 .5583 L .17062 .5588 L F
.289 .788 .846 r
.17704 .55773 m .17257 .5583 L .17465 .55747 L F
.713 .575 .698 r
.53353 .53343 m .52971 .53058 L .53355 .53102 L F
.716 .527 .632 r
.53758 .53113 m .53353 .53343 L .53355 .53102 L F
.827 .732 .76 r
.69034 .42128 m .69128 .42498 L .69367 .42118 L F
.68 .584 .741 r
.69367 .42118 m .69698 .42139 L .69526 .42321 L F
.564 .367 .572 r
.73151 .43984 m .73173 .44243 L .72899 .44284 L F
.443 .278 .561 r
.73393 .44142 m .73151 .43984 L .73388 .4392 L F
.73393 .44142 m .73173 .44243 L .73151 .43984 L F
.082 0 0 r
.47707 .63051 m .47839 .62842 L .48034 .62753 L F
.593 .884 .992 r
.64373 .41192 m .64578 .41241 L .6429 .41337 L F
.758 .291 .139 r
.6429 .41337 m .64181 .41454 L .64373 .41192 L F
.6429 .41337 m .6444 .41508 L .64181 .41454 L F
.638 .504 .683 r
.69698 .42139 m .69984 .42174 L .69526 .42321 L F
.348 .232 .577 r
.21243 .60471 m .21403 .60401 L .21426 .601 L F
.273 .167 .547 r
.21243 .60471 m .21394 .60613 L .21403 .60401 L F
.21243 .60471 m .21251 .60726 L .21394 .60613 L F
.672 .77 .924 r
.53917 .68655 m .54089 .68834 L .54324 .68729 L F
.279 0 0 r
.40726 .63999 m .40563 .64119 L .40316 .64137 L F
.037 0 0 r
.4095 .6405 m .40563 .64119 L .40726 .63999 L F
.414 .492 .831 r
.39386 .62692 m .39228 .62877 L .39179 .62683 L F
.351 .399 .771 r
.39386 .62692 m .39482 .63041 L .39228 .62877 L F
.595 .833 .99 r
.7433 .42674 m .74091 .42771 L .7436 .42764 L F
.245 .651 .962 r
.7468 .4281 m .7433 .42674 L .7436 .42764 L F
.654 .482 .639 r
.53965 .52866 m .53961 .53089 L .53758 .53113 L F
.65 .479 .639 r
.53965 .52866 m .54185 .52781 L .53961 .53089 L F
.402 .715 .987 r
.52485 .68708 m .5259 .68584 L .52229 .68778 L F
.52485 .68708 m .52736 .68711 L .5259 .68584 L F
.859 .742 .733 r
.65782 .44208 m .65883 .44558 L .65957 .44328 L F
.822 .734 .768 r
.2196 .58111 m .21587 .58149 L .2178 .58027 L F
.2196 .58111 m .21715 .58417 L .21587 .58149 L F
.554 .852 .998 r
.2196 .58111 m .21999 .57963 L .22186 .5807 L F
.2196 .58111 m .2178 .58027 L .21999 .57963 L F
.831 .724 .747 r
.43883 .57755 m .44026 .58082 L .43754 .57953 L F
.743 .225 0 r
.44026 .58082 m .43884 .58078 L .43754 .57953 L F
.596 .613 .839 r
.44248 .57994 m .44026 .58082 L .43883 .57755 L F
0 0 0 r
.44248 .57994 m .43884 .58078 L .44026 .58082 L F
.282 .768 .686 r
.44248 .57994 m .44146 .58029 L .44026 .58082 L F
.6 .887 .991 r
.55564 .62939 m .55088 .62999 L .5542 .62776 L F
.713 .75 .881 r
.55776 .62819 m .55564 .62939 L .5542 .62776 L F
.689 .592 .743 r
.22044 .57245 m .22185 .57575 L .22427 .57511 L F
.435 .256 .538 r
.24163 .59863 m .24152 .60112 L .23955 .60169 L F
.432 .32 .625 r
.24152 .60112 m .23949 .60448 L .23955 .60169 L F
.811 .627 .653 r
.71709 .43491 m .71689 .43754 L .71807 .43652 L F
.734 .494 .565 r
.71689 .43754 m .71621 .43888 L .71807 .43652 L F
.796 .584 .615 r
.71807 .43652 m .71621 .43888 L .71917 .43921 L F
.653 .579 .759 r
.71917 .43921 m .72114 .43677 L .71807 .43652 L F
.673 .903 .977 r
.68478 .46624 m .68365 .46542 L .68289 .46654 L F
.68499 .4662 m .68439 .46585 L .68478 .46624 L F
.68439 .46585 m .68365 .46542 L .68478 .46624 L F
.876 .943 .855 r
.68365 .46542 m .68462 .46629 L .68439 .46585 L F
.991 .885 .573 r
.68462 .46629 m .68401 .46684 L .68391 .46537 L F
.876 .943 .855 r
.68365 .46542 m .68439 .46585 L .68387 .46488 L F
.991 .885 .573 r
.68439 .46585 m .68391 .46537 L .68387 .46488 L F
.673 .903 .977 r
.68407 .46553 m .68462 .46629 L .68365 .46542 L F
.991 .885 .573 r
.68462 .46629 m .68407 .46553 L .68439 .46585 L F
.673 .903 .977 r
.68599 .46604 m .68365 .46542 L .68499 .4662 L F
.68599 .46604 m .68462 .46629 L .68407 .46553 L F
.991 .885 .573 r
.68462 .46629 m .68391 .46537 L .68407 .46553 L F
.256 .043 .386 r
.35615 .62769 m .35853 .62337 L .35504 .62589 L F
.241 .697 .952 r
.24914 .55036 m .25125 .55038 L .25335 .55124 L F
0 .357 .81 r
.25324 .55039 m .25335 .55124 L .25125 .55038 L F
.25324 .55039 m .25507 .55207 L .25335 .55124 L F
.449 .124 .321 r
.60274 .49538 m .60462 .49724 L .6021 .49775 L F
.60274 .49538 m .60492 .4949 L .60462 .49724 L F
.14 0 0 r
.53018 .69153 m .52615 .69284 L .52391 .69456 L F
.684 .619 .777 r
.68089 .44835 m .68318 .4452 L .68123 .44634 L F
.68089 .44835 m .68453 .44899 L .68318 .4452 L F
.723 .976 .923 r
.43103 .56847 m .43172 .56686 L .43406 .56721 L F
.43103 .56847 m .43009 .56817 L .43172 .56686 L F
.395 .216 .517 r
.24828 .5867 m .24808 .58948 L .24578 .58979 L F
.399 .192 .48 r
.24743 .59138 m .24578 .58979 L .24808 .58948 L F
.24743 .59138 m .24568 .59226 L .24578 .58979 L F
.683 .873 .97 r
.42359 .58635 m .41962 .58686 L .42206 .58549 L F
.772 .51 .538 r
.42359 .58635 m .41991 .5893 L .41962 .58686 L F
.42359 .58635 m .42121 .58913 L .41991 .5893 L F
.733 .454 .505 r
.42359 .58635 m .42571 .58952 L .42121 .58913 L F
.634 .432 .591 r
.42614 .58665 m .42571 .58952 L .42359 .58635 L F
.904 .837 .769 r
.60034 .45339 m .60206 .45452 L .60168 .45081 L F
.909 .834 .76 r
.60015 .45728 m .60206 .45452 L .60034 .45339 L F
.89 .829 .78 r
.60168 .45081 m .60206 .45452 L .60297 .45197 L F
.723 .739 .864 r
.44827 .56522 m .4497 .56676 L .44597 .56625 L F
.268 .548 .926 r
.44827 .56522 m .45035 .56563 L .4497 .56676 L F
.482 .811 1 r
.45035 .56563 m .45151 .56639 L .4497 .56676 L F
.575 .407 .616 r
.74528 .41928 m .74306 .42247 L .74312 .41895 L F
.74528 .41928 m .74597 .42135 L .74306 .42247 L F
.448 .197 .44 r
.22686 .57236 m .2264 .57458 L .229 .57187 L F
.563 .343 .539 r
.40298 .59274 m .40382 .59623 L .40012 .59485 L F
.677 .586 .746 r
.40382 .59623 m .40049 .59764 L .40012 .59485 L F
.955 .61 .295 r
.65388 .42907 m .65497 .42854 L .6539 .42673 L F
.65388 .42907 m .65523 .43027 L .65497 .42854 L F
.864 .839 .82 r
.49752 .68978 m .49795 .69224 L .4998 .68931 L F
.253 0 .067 r
.69188 .45816 m .694 .45757 L .6939 .45607 L F
.347 .073 .348 r
.6939 .45607 m .697 .4561 L .69728 .45295 L F
.293 0 .066 r
.694 .45757 m .697 .4561 L .6939 .45607 L F
.451 .128 .325 r
.67258 .41227 m .67588 .41077 L .67566 .40971 L F
.494 .154 .32 r
.67588 .41077 m .67861 .41074 L .67566 .40971 L F
.854 .823 .817 r
.60386 .44806 m .60724 .44757 L .60773 .44632 L F
.843 .855 .853 r
.60501 .4492 m .60724 .44757 L .60386 .44806 L F
.282 0 .133 r
.36021 .59512 m .36214 .59465 L .3632 .59287 L F
.41 .032 .207 r
.3632 .59287 m .36472 .59414 L .36522 .59216 L F
.3632 .59287 m .36214 .59465 L .36472 .59414 L F
.929 .881 .767 r
.51949 .54926 m .51844 .55183 L .51719 .55002 L F
.909 .785 .712 r
.51844 .55183 m .5155 .55315 L .51719 .55002 L F
.51844 .55183 m .51709 .55447 L .5155 .55315 L F
0 .18 .684 r
.55167 .63347 m .55285 .63492 L .55305 .63492 L F
.63 .683 .881 r
.74359 .43107 m .74482 .43327 L .74223 .43382 L F
.59 .394 .585 r
.74791 .43521 m .74223 .43382 L .74482 .43327 L F
.74791 .43521 m .74238 .43625 L .74223 .43382 L F
0 .25 .762 r
.23023 .56427 m .23213 .56649 L .23172 .56513 L F
.262 .067 .416 r
.23213 .56649 m .23326 .56806 L .23172 .56513 L F
.23213 .56649 m .2317 .56887 L .23326 .56806 L F
.39 .305 .639 r
.23693 .61255 m .23499 .61138 L .23713 .60969 L F
.23693 .61255 m .23531 .61324 L .23499 .61138 L F
.56 .803 .99 r
.23137 .8192 m .23486 .8195 L .23331 .81842 L F
.863 .848 .827 r
.23721 .81653 m .23486 .8195 L .23331 .81842 L F
.448 .826 .99 r
.23486 .8195 m .23534 .81846 L .23331 .81842 L F
.57 .394 .604 r
.23721 .81653 m .2374 .8191 L .23486 .8195 L F
.448 .826 .99 r
.23486 .8195 m .2374 .8191 L .23534 .81846 L F
.983 .805 .587 r
.55221 .6799 m .55392 .67837 L .55478 .67699 L F
.55221 .6799 m .55342 .6808 L .55392 .67837 L F
.967 .778 .598 r
.65751 .44446 m .65883 .44558 L .65782 .44208 L F
.945 .79 .657 r
.65751 .44446 m .65853 .44689 L .65883 .44558 L F
.631 .701 .896 r
.6989 .40592 m .69699 .4074 L .69471 .40341 L F
.824 .862 .875 r
.6461 .45942 m .64751 .46052 L .64981 .45801 L F
.178 .29 .742 r
.19662 .67359 m .19788 .67463 L .19721 .67528 L F
.501 .83 .534 r
.19721 .67528 m .19788 .67463 L .19641 .67601 L F
.789 .734 .801 r
.52147 .54805 m .51775 .54811 L .52064 .54514 L F
.52147 .54805 m .51949 .54926 L .51775 .54811 L F
.826 .804 .83 r
.52409 .54521 m .52147 .54805 L .52064 .54514 L F
.859 .733 .723 r
.63657 .45671 m .63919 .45453 L .63937 .45388 L F
.27 .031 .355 r
.23334 .61639 m .23273 .61872 L .23106 .61936 L F
.382 .195 .498 r
.23252 .62117 m .23106 .61936 L .23273 .61872 L F
.23252 .62117 m .2308 .62184 L .23106 .61936 L F
.52 .291 .507 r
.47036 .57811 m .47008 .5804 L .46777 .58081 L F
.443 .424 .743 r
.47146 .57404 m .47036 .57811 L .46927 .57437 L F
.47146 .57404 m .47235 .57761 L .47036 .57811 L F
.364 .161 .466 r
.47235 .57761 m .47008 .5804 L .47036 .57811 L F
.452 .355 .655 r
.35425 .60741 m .35616 .60678 L .35575 .60429 L F
.448 .375 .681 r
.35459 .61083 m .35616 .60678 L .35425 .60741 L F
.514 .596 .874 r
.6499 .43695 m .65171 .43981 L .65358 .43448 L F
.877 .989 .815 r
.65358 .43448 m .65171 .43981 L .65006 .44011 L F
.17 .359 .809 r
.20036 .66571 m .19773 .66359 L .20008 .66309 L F
.627 .439 .608 r
.59184 .50186 m .59184 .50401 L .58883 .50479 L F
.574 .356 .546 r
.59184 .50186 m .59426 .50346 L .59184 .50401 L F
.59184 .50186 m .5944 .5013 L .59426 .50346 L F
.263 .512 .903 r
.73096 .41709 m .73027 .4187 L .72874 .41548 L F
.73096 .41709 m .73224 .4191 L .73027 .4187 L F
.685 .638 .797 r
.74429 .41582 m .74312 .41895 L .74165 .41664 L F
.74429 .41582 m .74528 .41928 L .74312 .41895 L F
.916 .818 .735 r
.59221 .47518 m .5942 .47187 L .59289 .47041 L F
.768 .593 .661 r
.59221 .47518 m .59382 .47414 L .5942 .47187 L F
.859 .829 .817 r
.5942 .47187 m .59496 .46774 L .59289 .47041 L F
.5942 .47187 m .59647 .46895 L .59496 .46774 L F
.462 .055 .181 r
.4868 .61574 m .48985 .61559 L .49025 .61406 L F
.505 .093 .193 r
.49025 .61406 m .48985 .61559 L .49236 .61525 L F
.527 .443 .705 r
.74705 .4154 m .74528 .41928 L .74429 .41582 L F
.74705 .4154 m .7477 .41844 L .74528 .41928 L F
.009 .074 .583 r
.74707 .41989 m .74528 .41928 L .7477 .41844 L F
.74707 .41989 m .74597 .42135 L .74528 .41928 L F
.622 .817 .975 r
.26144 .80154 m .2602 .80269 L .25932 .80085 L F
.937 .928 .771 r
.25932 .80085 m .2602 .80269 L .2583 .80465 L F
.256 .043 .386 r
.35615 .62769 m .35724 .6279 L .35853 .62337 L F
.127 0 .32 r
.35853 .62337 m .35956 .6256 L .36001 .62381 L F
.35853 .62337 m .35724 .6279 L .35956 .6256 L F
.259 .763 .734 r
.1803 .54195 m .18069 .54171 L .18273 .5411 L F
.1803 .54195 m .1787 .54233 L .18069 .54171 L F
.44 0 0 r
.62456 .42856 m .62749 .43016 L .62671 .42703 L F
.849 .861 .851 r
.6117 .42428 m .60798 .4262 L .61039 .4236 L F
.6117 .42428 m .60891 .42694 L .60798 .4262 L F
.501 .66 .932 r
.61193 .42187 m .6117 .42428 L .61039 .4236 L F
.61193 .42187 m .61423 .42422 L .6117 .42428 L F
.331 0 0 r
.43163 .58673 m .43436 .5866 L .43508 .58544 L F
0 .413 .846 r
.43634 .58546 m .43821 .58712 L .43508 .58544 L F
.43634 .58546 m .43508 .58544 L .43436 .5866 L F
.623 .569 .773 r
.531 .68706 m .5346 .68985 L .53448 .68723 L F
.436 .243 .519 r
.40463 .63093 m .40685 .63242 L .40832 .63058 L F
.574 .124 .145 r
.40832 .63058 m .4106 .63191 L .41062 .6307 L F
.40832 .63058 m .40685 .63242 L .4106 .63191 L F
.473 .126 .297 r
.72899 .44284 m .7314 .4438 L .72903 .4444 L F
.72899 .44284 m .73173 .44243 L .7314 .4438 L F
.929 .794 .689 r
.59496 .46774 m .59647 .46895 L .59554 .46559 L F
.184 0 .199 r
.42055 .58529 m .41905 .58429 L .42069 .58312 L F
.42055 .58529 m .41866 .58659 L .41905 .58429 L F
.135 0 0 r
.21924 .55883 m .22254 .5569 L .22071 .55781 L F
.505 .313 .553 r
.58373 .50975 m .58105 .51198 L .58108 .51047 L F
.338 .38 .759 r
.7432 .41429 m .74165 .41664 L .74046 .4128 L F
.625 .769 .949 r
.7432 .41429 m .74429 .41582 L .74165 .41664 L F
.659 .481 .632 r
.56718 .51627 m .56721 .51895 L .5647 .51906 L F
.472 .216 .444 r
.53863 .54003 m .53665 .54351 L .53442 .53937 L F
.53863 .54003 m .53853 .54221 L .53665 .54351 L F
.588 .31 .462 r
.54094 .54158 m .53853 .54221 L .53863 .54003 L F
.53 .342 .571 r
.54104 .53932 m .54094 .54158 L .53863 .54003 L F
.55 .65 .901 r
.57907 .62388 m .5788 .62315 L .57789 .62209 L F
.516 .46 .732 r
.69415 .45148 m .69671 .4512 L .69592 .44751 L F
.676 .573 .731 r
.69415 .45148 m .69728 .45295 L .69671 .4512 L F
.448 .375 .681 r
.35459 .61083 m .35652 .61042 L .35616 .60678 L F
.466 .462 .769 r
.35459 .61083 m .35736 .61244 L .35652 .61042 L F
.492 .456 .745 r
.35459 .61083 m .35558 .61329 L .35736 .61244 L F
.192 0 .272 r
.39314 .60232 m .39248 .60437 L .39089 .60511 L F
.687 .917 .588 r
.39248 .60437 m .39046 .60703 L .39089 .60511 L F
.863 .848 .827 r
.23721 .81653 m .23331 .81842 L .23534 .81846 L F
.94 .677 .51 r
.23534 .81846 m .2374 .8191 L .23721 .81653 L F
.811 .81 .85 r
.61648 .46519 m .61528 .46704 L .61354 .46541 L F
.526 .353 .589 r
.3951 .59865 m .39485 .60216 L .39314 .60232 L F
.512 .34 .585 r
.39714 .60081 m .3951 .59865 L .39778 .59816 L F
.39714 .60081 m .39485 .60216 L .3951 .59865 L F
.487 0 0 r
.69669 .46336 m .69566 .46455 L .69355 .46443 L F
.249 0 0 r
.69911 .46264 m .69566 .46455 L .69669 .46336 L F
.417 0 0 r
.69779 .4467 m .70125 .44717 L .69901 .44635 L F
.84 .817 .827 r
.66861 .44808 m .66588 .4478 L .66813 .44525 L F
.921 .919 .796 r
.66861 .44808 m .66547 .45018 L .66588 .4478 L F
.66861 .44808 m .66635 .45139 L .66547 .45018 L F
.647 .578 .763 r
.70929 .42238 m .71293 .42533 L .71181 .42167 L F
.642 .626 .818 r
.70929 .42238 m .71057 .41825 L .70811 .41903 L F
.70929 .42238 m .71181 .42167 L .71057 .41825 L F
.533 .277 .473 r
.59691 .50079 m .59705 .49864 L .59945 .50026 L F
.565 .255 .402 r
.59705 .49864 m .5998 .4985 L .59945 .50026 L F
.432 .32 .625 r
.24152 .60112 m .24178 .60382 L .23949 .60448 L F
.377 .19 .496 r
.24178 .60382 m .23944 .60642 L .23949 .60448 L F
.204 0 0 r
.54193 .65747 m .54468 .65754 L .54637 .65722 L F
.515 0 0 r
.54468 .65754 m .54874 .65974 L .54637 .65722 L F
.712 .73 .865 r
.5553 .62004 m .55677 .62238 L .55276 .62186 L F
.76 .496 .535 r
.55276 .62186 m .55677 .62238 L .55628 .62502 L F
.514 .639 .91 r
.55789 .62117 m .55677 .62238 L .5553 .62004 L F
0 0 .242 r
.55628 .62502 m .55677 .62238 L .55789 .62117 L F
.792 .868 .905 r
.65096 .4546 m .64836 .4564 L .65151 .45625 L F
.845 .749 .757 r
.64836 .4564 m .64981 .45801 L .65151 .45625 L F
.667 .638 .812 r
.44139 .57212 m .44465 .57318 L .4434 .57222 L F
.498 .762 .99 r
.44465 .57318 m .44591 .57174 L .4434 .57222 L F
.44465 .57318 m .4472 .57288 L .44591 .57174 L F
.693 .522 .652 r
.71203 .43715 m .71689 .43754 L .71709 .43491 L F
.088 .647 .755 r
.53473 .70467 m .53541 .7045 L .5333 .70409 L F
.53473 .70467 m .53733 .7045 L .53541 .7045 L F
.442 0 0 r
.45186 .63486 m .45049 .636 L .44799 .63605 L F
.491 0 .016 r
.45403 .63577 m .45049 .636 L .45186 .63486 L F
.518 .289 .506 r
.53263 .55466 m .53249 .55697 L .53007 .55737 L F
.576 .488 .718 r
.53402 .55054 m .53263 .55466 L .53145 .55127 L F
.53402 .55054 m .53503 .55408 L .53263 .55466 L F
.513 .287 .509 r
.53503 .55408 m .53249 .55697 L .53263 .55466 L F
.577 .351 .537 r
.40506 .59481 m .40382 .59623 L .40298 .59274 L F
.612 .349 .495 r
.40543 .59266 m .40506 .59481 L .40298 .59274 L F
.815 .902 .902 r
.60891 .42694 m .60605 .42803 L .60798 .4262 L F
.77 .812 .886 r
.73587 .41891 m .73387 .42038 L .73224 .4191 L F
.716 .527 .632 r
.53758 .53113 m .53763 .53439 L .53353 .53343 L F
.69 .506 .632 r
.53928 .53301 m .53758 .53113 L .53961 .53089 L F
.53928 .53301 m .53763 .53439 L .53758 .53113 L F
.863 .993 .821 r
.59343 .44216 m .59527 .43866 L .59627 .43957 L F
.59343 .44216 m .5928 .44151 L .59527 .43866 L F
.863 .772 .759 r
.21715 .58417 m .21585 .58751 L .21358 .58605 L F
.995 .784 .508 r
.21445 .58942 m .21358 .58605 L .21585 .58751 L F
.565 .408 .627 r
.70728 .43997 m .70974 .44181 L .70976 .43942 L F
.70728 .43997 m .70722 .44242 L .70974 .44181 L F
.13 0 0 r
.68801 .46574 m .68462 .46629 L .68599 .46604 L F
.694 .654 .806 r
.68748 .42423 m .69128 .42498 L .69034 .42128 L F
.646 .518 .693 r
.54185 .52781 m .54292 .52644 L .54434 .52492 L F
.346 0 0 r
.68801 .46574 m .68401 .46684 L .68462 .46629 L F
.68801 .46574 m .68657 .46674 L .68401 .46684 L F
.075 0 0 r
.68996 .46564 m .68801 .46574 L .69036 .46528 L F
.68996 .46564 m .68657 .46674 L .68801 .46574 L F
.366 .116 .397 r
.23484 .61764 m .23334 .61639 L .23505 .6156 L F
.23484 .61764 m .23273 .61872 L .23334 .61639 L F
.672 .449 .574 r
.60514 .46861 m .60249 .4666 L .60287 .46911 L F
.457 .263 .528 r
.60514 .46861 m .60287 .46911 L .60318 .47123 L F
.739 .827 .919 r
.68401 .42383 m .68531 .42516 L .68748 .42423 L F
.802 .701 .754 r
.73722 .4271 m .74091 .42771 L .74022 .42625 L F
.597 .824 .986 r
.74022 .42625 m .74091 .42771 L .7433 .42674 L F
.796 .517 .516 r
.20063 .61168 m .2036 .61323 L .20428 .61059 L F
.371 .108 .379 r
.20428 .61059 m .2036 .61323 L .2059 .61153 L F
.472 0 .036 r
.20428 .61059 m .2059 .61153 L .20674 .61079 L F
.838 .776 .793 r
.52409 .54521 m .52064 .54514 L .52284 .54193 L F
.731 .726 .846 r
.52664 .54252 m .52409 .54521 L .52284 .54193 L F
.641 .575 .765 r
.52664 .54252 m .52854 .54621 L .52409 .54521 L F
.578 .533 .768 r
.52768 .54831 m .52409 .54521 L .52854 .54621 L F
.622 .572 .776 r
.71181 .42167 m .71293 .42533 L .71547 .4246 L F
.635 .574 .768 r
.71293 .42533 m .7168 .42817 L .71547 .4246 L F
.252 0 .095 r
.53917 .68655 m .53977 .68553 L .53738 .68682 L F
.775 .615 .681 r
.53961 .53089 m .5417 .53452 L .53928 .53301 L F
.707 .606 .742 r
.5417 .53452 m .53763 .53439 L .53928 .53301 L F
.541 .802 .994 r
.68008 .40179 m .67646 .40124 L .67897 .4011 L F
.428 .806 .992 r
.68241 .40141 m .68008 .40179 L .67897 .4011 L F
.689 .592 .743 r
.22044 .57245 m .22427 .57511 L .22292 .57207 L F
.151 0 .35 r
.22458 .57761 m .2264 .57458 L .22427 .57511 L F
.542 .168 .281 r
.74989 .4271 m .74952 .42932 L .7468 .4281 L F
.215 .046 .424 r
.75228 .42414 m .75209 .4263 L .74989 .4271 L F
.626 .459 .637 r
.75209 .4263 m .74952 .42932 L .74989 .4271 L F
.862 .988 .838 r
.53801 .66692 m .53545 .66909 L .53849 .66574 L F
.531 .254 .44 r
.53801 .66692 m .5354 .67132 L .53545 .66909 L F
.53801 .66692 m .53789 .67112 L .5354 .67132 L F
.149 .17 .627 r
.53849 .66574 m .54014 .66786 L .53801 .66692 L F
.524 .354 .592 r
.53854 .66715 m .53795 .66915 L .53801 .66692 L F
.53902 .66737 m .53814 .66882 L .53854 .66715 L F
.53814 .66882 m .53795 .66915 L .53854 .66715 L F
.534 .264 .452 r
.5354 .67132 m .53802 .66934 L .53545 .66909 L F
.53802 .66934 m .53879 .66876 L .53814 .66882 L F
.53802 .66934 m .53814 .66882 L .53545 .66909 L F
.609 .443 .632 r
.53545 .66909 m .53814 .66882 L .53849 .66574 L F
.53814 .66882 m .53879 .66876 L .5387 .6679 L F
.53814 .66882 m .5387 .6679 L .53849 .66574 L F
.534 .264 .452 r
.53802 .66934 m .53789 .67112 L .53879 .66876 L F
.524 .354 .592 r
.53804 .66909 m .53789 .67112 L .53795 .66915 L F
.534 .264 .452 r
.5354 .67132 m .53789 .67112 L .53802 .66934 L F
.524 .354 .592 r
.53789 .67112 m .54014 .66786 L .53879 .66876 L F
.54014 .66786 m .53789 .67112 L .53804 .66909 L F
.54014 .66786 m .5387 .6679 L .53902 .66737 L F
.293 .211 .589 r
.53849 .66574 m .5387 .6679 L .54014 .66786 L F
.5387 .6679 m .53879 .66876 L .54014 .66786 L F
.524 .354 .592 r
.54014 .66786 m .53795 .66915 L .5387 .6679 L F
.568 .293 .459 r
.58883 .50479 m .59122 .50655 L .58872 .50665 L F
.58883 .50479 m .59184 .50401 L .59122 .50655 L F
.31 .402 .795 r
.57549 .63302 m .57411 .63502 L .5736 .63315 L F
.57549 .63302 m .57714 .63708 L .57411 .63502 L F
.779 .715 .792 r
.57789 .62209 m .58104 .62254 L .5788 .62315 L F
.57789 .62209 m .58104 .62254 L .5788 .62315 L F
.623 .374 .519 r
.72121 .44872 m .72112 .45102 L .71824 .45109 L F
.511 .315 .551 r
.7233 .44795 m .72112 .45102 L .72121 .44872 L F
.83 .825 .844 r
.52884 .67004 m .53042 .67049 L .52707 .67227 L F
.245 0 0 r
.52707 .67227 m .53036 .67052 L .52975 .67226 L F
.53036 .67052 m .53038 .67059 L .52975 .67226 L F
.412 0 .014 r
.52975 .67226 m .53042 .67049 L .5308 .67175 L F
.694 .923 .597 r
.52884 .67004 m .52707 .67227 L .52806 .67053 L F
.684 .141 0 r
.52806 .67053 m .53058 .67165 L .52884 .67004 L F
.53058 .67165 m .5308 .67175 L .53056 .67154 L F
.53058 .67165 m .53056 .67154 L .52884 .67004 L F
.245 0 0 r
.53036 .67052 m .53042 .67049 L .53038 .67059 L F
.689 .151 0 r
.5308 .67175 m .53042 .67049 L .52884 .67004 L F
.762 .911 .94 r
.43801 .57289 m .44139 .57212 L .43998 .57209 L F
.43801 .57289 m .43885 .57317 L .44139 .57212 L F
.12 .634 .892 r
.44139 .57212 m .44169 .57168 L .43998 .57209 L F
.44139 .57212 m .4434 .57222 L .44169 .57168 L F
.637 .949 .946 r
.42572 .57046 m .42686 .56884 L .42811 .56946 L F
.42572 .57046 m .42351 .57038 L .42686 .56884 L F
0 0 0 r
.18313 .55477 m .18296 .55433 L .18513 .5544 L F
.18313 .55477 m .18126 .55626 L .18296 .55433 L F
.751 .611 .704 r
.59176 .47741 m .59556 .47797 L .59382 .47414 L F
.694 .504 .626 r
.59318 .48064 m .59556 .47797 L .59176 .47741 L F
.59318 .48064 m .59575 .48061 L .59556 .47797 L F
.6 .395 .575 r
.59575 .48061 m .59841 .47777 L .59556 .47797 L F
.362 .806 .954 r
.1719 .54281 m .1766 .54301 L .17435 .54337 L F
.548 0 0 r
.46777 .58081 m .46673 .58198 L .46587 .58134 L F
.46777 .58081 m .46587 .58134 L .46571 .58048 L F
.52 0 0 r
.4688 .58219 m .46777 .58081 L .47008 .5804 L F
.4688 .58219 m .46673 .58198 L .46777 .58081 L F
.549 0 0 r
.46445 .58027 m .46587 .58134 L .46513 .58163 L F
.46587 .58134 m .46673 .58198 L .46596 .58181 L F
.46587 .58134 m .46596 .58181 L .46513 .58163 L F
.442 .025 .151 r
.4688 .58219 m .46515 .58406 L .46513 .58163 L F
.65 .155 .062 r
.46513 .58163 m .46673 .58198 L .4688 .58219 L F
.651 .588 .772 r
.46612 .58266 m .46893 .57964 L .46606 .58163 L F
.46613 .58272 m .46613 .58271 L .46612 .58266 L F
.46613 .58271 m .46893 .57964 L .46612 .58266 L F
.46613 .58272 m .46613 .58272 L .46613 .58272 L F
.46613 .58272 m .46893 .57964 L .46613 .58272 L F
.548 0 0 r
.46571 .58048 m .46587 .58134 L .46445 .58027 L F
0 0 .046 r
.18989 .64759 m .19145 .64517 L .19062 .64576 L F
.886 .841 .795 r
.53232 .5251 m .52875 .52708 L .53108 .52411 L F
.53232 .5251 m .53012 .52802 L .52875 .52708 L F
.177 .299 .751 r
.54031 .66048 m .54122 .65647 L .54193 .65747 L F
.276 0 0 r
.54384 .65841 m .54468 .65754 L .54193 .65747 L F
.54384 .65841 m .54193 .65747 L .54122 .65647 L F
.693 .934 .629 r
.21163 .59273 m .2126 .59099 L .21445 .58942 L F
0 0 .238 r
.21163 .59273 m .21258 .59346 L .2126 .59099 L F
.21163 .59273 m .2117 .59521 L .21258 .59346 L F
.343 .784 .962 r
.21031 .54173 m .21249 .54147 L .21411 .54193 L F
.403 .787 .991 r
.21249 .54147 m .21633 .54193 L .21411 .54193 L F
.929 .881 .767 r
.51949 .54926 m .51719 .55002 L .51775 .54811 L F
.46 .72 .981 r
.23988 .54494 m .23948 .54655 L .23784 .54521 L F
.23988 .54494 m .24146 .54634 L .23948 .54655 L F
.462 .542 .852 r
.57797 .61369 m .58032 .61591 L .58186 .61544 L F
0 .115 .607 r
.19692 .67361 m .19639 .67224 L .19753 .67161 L F
.19692 .67361 m .19662 .67359 L .19639 .67224 L F
.655 .759 .926 r
.67078 .46126 m .67578 .46159 L .67383 .45924 L F
.672 .657 .828 r
.67383 .45924 m .67578 .46159 L .67718 .46019 L F
.945 .616 .377 r
.68879 .42028 m .69002 .41908 L .68959 .41816 L F
.68879 .42028 m .69034 .42128 L .69002 .41908 L F
.593 .515 .736 r
.67542 .42446 m .67628 .42702 L .67833 .42447 L F
.749 .623 .72 r
.53006 .54519 m .53145 .54857 L .52768 .54831 L F
.745 .522 .592 r
.53145 .54857 m .52752 .55059 L .52768 .54831 L F
.53145 .54857 m .53145 .55127 L .52752 .55059 L F
.678 .589 .749 r
.53381 .54808 m .53145 .54857 L .53006 .54519 L F
.693 .479 .593 r
.53402 .55054 m .53145 .54857 L .53381 .54808 L F
.53402 .55054 m .53145 .55127 L .53145 .54857 L F
.244 0 .296 r
.39433 .6033 m .39314 .60232 L .39485 .60216 L F
.39433 .6033 m .39248 .60437 L .39314 .60232 L F
.396 0 0 r
.41328 .63971 m .41186 .64117 L .4095 .6405 L F
.598 .137 .13 r
.41558 .64006 m .41186 .64117 L .41328 .63971 L F
.8 .726 .783 r
.21587 .58149 m .21715 .58417 L .21408 .58357 L F
.863 .772 .759 r
.21715 .58417 m .21358 .58605 L .21408 .58357 L F
.625 .492 .68 r
.57797 .61369 m .57974 .60981 L .57811 .61019 L F
.57797 .61369 m .58191 .61297 L .57974 .60981 L F
.462 .542 .852 r
.57797 .61369 m .58186 .61544 L .58191 .61297 L F
.788 .455 .425 r
.61723 .41 m .61464 .4116 L .61616 .40888 L F
.61723 .41 m .61751 .41234 L .61464 .4116 L F
.782 .876 .916 r
.62044 .40779 m .61723 .41 L .61616 .40888 L F
.599 .317 .46 r
.61723 .41 m .61751 .41234 L .62002 .41194 L F
.61723 .41 m .61751 .41234 L .62002 .41194 L F
.718 .674 .805 r
.70212 .41889 m .70569 .41994 L .70459 .41809 L F
.647 .688 .874 r
.70569 .41994 m .70811 .41903 L .70459 .41809 L F
.064 .408 .86 r
.65174 .41954 m .64995 .41974 L .64866 .41883 L F
.65174 .41954 m .65257 .42105 L .64995 .41974 L F
0 .092 .595 r
.65317 .42278 m .64995 .41974 L .65257 .42105 L F
.891 .761 .713 r
.67353 .44476 m .67207 .44734 L .67461 .44809 L F
.989 .833 .598 r
.67271 .44969 m .67461 .44809 L .67207 .44734 L F
.67271 .44969 m .67386 .45104 L .67461 .44809 L F
.911 .717 .627 r
.5191 .55772 m .51682 .55921 L .51694 .55682 L F
.5191 .55772 m .51863 .56026 L .51682 .55921 L F
.753 .554 .627 r
.52162 .56039 m .51863 .56026 L .5191 .55772 L F
.614 .584 .797 r
.67542 .42446 m .67759 .41934 L .67409 .42101 L F
.67542 .42446 m .67822 .42369 L .67759 .41934 L F
.593 .515 .736 r
.67542 .42446 m .67833 .42447 L .67822 .42369 L F
.439 .046 .196 r
.47317 .62428 m .47559 .624 L .47675 .62185 L F
.558 .217 .347 r
.47559 .624 m .47916 .62151 L .47675 .62185 L F
.629 .202 .213 r
.22367 .56486 m .21979 .56478 L .2217 .56322 L F
.612 .174 .183 r
.44325 .63621 m .44211 .63806 L .43968 .63641 L F
.681 .348 .405 r
.4455 .63611 m .44211 .63806 L .44325 .63621 L F
.818 .864 .882 r
.62893 .477 m .63172 .47502 L .63038 .47385 L F
.858 .909 .867 r
.63172 .47502 m .63314 .4712 L .63038 .47385 L F
.63172 .47502 m .63438 .47228 L .63314 .4712 L F
.502 .62 .901 r
.69522 .41706 m .69743 .41522 L .69477 .41565 L F
.51 .468 .745 r
.69728 .45295 m .69897 .4501 L .69671 .4512 L F
.69728 .45295 m .69971 .45261 L .69897 .4501 L F
.367 .089 .353 r
.69728 .45295 m .6993 .45518 L .69971 .45261 L F
.69728 .45295 m .697 .4561 L .6993 .45518 L F
.468 0 .008 r
.45814 .63457 m .45624 .63602 L .45403 .63577 L F
.662 .213 .175 r
.46013 .6363 m .45624 .63602 L .45814 .63457 L F
.574 .6 .842 r
.62623 .45658 m .62799 .45973 L .62536 .46025 L F
.302 .114 .451 r
.2552 .56576 m .2532 .56885 L .25296 .56629 L F
.933 .615 .414 r
.66725 .45737 m .66621 .45876 L .66609 .45623 L F
.66725 .45737 m .66762 .45969 L .66621 .45876 L F
.94 .919 .766 r
.64715 .41615 m .64482 .41756 L .6444 .41508 L F
.64715 .41615 m .64609 .418 L .64593 .41689 L F
0 0 .025 r
.64783 .41683 m .64604 .41809 L .64715 .41615 L F
.64783 .41683 m .64715 .41615 L .6444 .41508 L F
.223 .41 .836 r
.64727 .41485 m .64783 .41683 L .64576 .41578 L F
.64565 .41498 m .64576 .41578 L .6444 .41508 L F
.64727 .41485 m .64576 .41578 L .64565 .41498 L F
.94 .919 .766 r
.64593 .41689 m .64604 .41809 L .64482 .41756 L F
.64609 .418 m .64604 .41809 L .64593 .41689 L F
.562 .613 .861 r
.20513 .6145 m .2059 .61153 L .2036 .61323 L F
.20513 .6145 m .20801 .61581 L .2059 .61153 L F
.607 .116 .061 r
.43475 .63186 m .4382 .63106 L .43425 .63013 L F
.43475 .63186 m .4368 .63259 L .4382 .63106 L F
.52 .018 .004 r
.4382 .63106 m .4368 .63259 L .44064 .63239 L F
.492 .761 .991 r
.22044 .57245 m .22292 .57207 L .22122 .57084 L F
.22044 .57245 m .22292 .57207 L .22122 .57084 L F
.363 .494 .857 r
.67503 .40734 m .6748 .40768 L .67633 .40598 L F
.024 .538 .867 r
.6748 .40768 m .67636 .40762 L .67633 .40598 L F
.539 .834 .999 r
.67496 .40742 m .67633 .40598 L .67636 .40762 L F
.67482 .4074 m .67633 .40598 L .67496 .40742 L F
.67482 .4074 m .67549 .40668 L .67633 .40598 L F
.363 .494 .857 r
.67549 .40668 m .67503 .40734 L .67633 .40598 L F
.599 .927 .964 r
.67808 .40595 m .67636 .40762 L .67944 .40632 L F
0 0 0 r
.67686 .40729 m .67636 .40762 L .67808 .40595 L F
.024 .538 .867 r
.67584 .40796 m .67787 .40851 L .67636 .40762 L F
0 0 0 r
.6758 .40845 m .67636 .40762 L .67686 .40729 L F
.024 .538 .867 r
.6748 .40768 m .67584 .40796 L .67636 .40762 L F
.445 0 0 r
.23023 .56427 m .22977 .56419 L .2277 .56286 L F
.402 0 0 r
.23023 .56427 m .22964 .56418 L .22977 .56419 L F
.23023 .56427 m .23172 .56513 L .22964 .56418 L F
.458 .862 .965 r
.43621 .56658 m .43406 .56721 L .43172 .56686 L F
.405 .226 .523 r
.25369 .57164 m .25381 .57479 L .25169 .57519 L F
.535 .416 .664 r
.25422 .57707 m .25169 .57519 L .25381 .57479 L F
.25422 .57707 m .25205 .57769 L .25169 .57519 L F
.479 .238 .471 r
.70976 .43942 m .71201 .43888 L .71203 .43715 L F
.694 .41 .489 r
.71203 .43715 m .71621 .43888 L .71689 .43754 L F
.71203 .43715 m .71201 .43888 L .71621 .43888 L F
.19 .691 .911 r
.21633 .54193 m .21844 .54195 L .22018 .54247 L F
.264 .738 .939 r
.21844 .54195 m .2223 .54236 L .22018 .54247 L F
.623 .65 .856 r
.70567 .40916 m .70326 .40982 L .70201 .40665 L F
.557 .29 .466 r
.57557 .51562 m .57556 .51333 L .57796 .51502 L F
.592 .266 .386 r
.57556 .51333 m .57778 .51334 L .57796 .51502 L F
0 .115 .607 r
.19692 .67361 m .19788 .67463 L .19662 .67359 L F
.441 .266 .546 r
.24371 .59551 m .24361 .59802 L .24163 .59863 L F
.375 .208 .523 r
.2433 .60042 m .24163 .59863 L .24361 .59802 L F
.2433 .60042 m .24152 .60112 L .24163 .59863 L F
0 .095 .648 r
.6594 .42235 m .66079 .42299 L .65881 .42074 L F
.6594 .42235 m .66145 .42436 L .66079 .42299 L F
.656 .809 .957 r
.33013 .80591 m .33062 .80381 L .32836 .8044 L F
.33013 .80591 m .33242 .805 L .33062 .80381 L F
.58 .371 .562 r
.53007 .55737 m .53017 .55997 L .52761 .56056 L F
.615 .398 .564 r
.53269 .5595 m .53007 .55737 L .53249 .55697 L F
.53269 .5595 m .53017 .55997 L .53007 .55737 L F
0 0 0 r
.39008 .60727 m .38799 .60826 L .39046 .60703 L F
.687 .917 .588 r
.39248 .60437 m .39008 .60727 L .39046 .60703 L F
.466 0 0 r
.45012 .63108 m .45285 .63212 L .45408 .63107 L F
.59 .075 0 r
.45408 .63107 m .45285 .63212 L .45633 .6323 L F
0 0 .007 r
.53998 .67627 m .5414 .67598 L .54288 .67659 L F
.467 .666 .949 r
.54288 .67659 m .54107 .67716 L .53998 .67627 L F
0 0 .007 r
.53998 .67627 m .53981 .67793 L .5414 .67598 L F
.714 .538 .65 r
.54107 .67716 m .5416 .68 L .53814 .68116 L F
.467 .666 .949 r
.54288 .67659 m .544 .6778 L .54107 .67716 L F
.667 .527 .684 r
.544 .6778 m .5416 .68 L .54107 .67716 L F
.21 0 0 r
.53825 .68112 m .54042 .68082 L .53814 .68116 L F
.5416 .68 m .54042 .68082 L .53825 .68112 L F
.637 .521 .705 r
.53977 .68553 m .54237 .68471 L .5416 .68 L F
.667 .527 .684 r
.544 .6778 m .54397 .68148 L .5416 .68 L F
.681 .551 .701 r
.5416 .68 m .5453 .68403 L .54397 .68148 L F
.5416 .68 m .54237 .68471 L .5453 .68403 L F
.37 .767 .986 r
.54397 .68148 m .54042 .68082 L .5416 .68 L F
.667 .527 .684 r
.5416 .68 m .54397 .68148 L .544 .6778 L F
.766 .377 .317 r
.5416 .68 m .54397 .68148 L .54042 .68082 L F
.507 .686 .948 r
.54042 .68082 m .54294 .68063 L .54282 .68049 L F
.54042 .68082 m .54282 .68049 L .54148 .67882 L F
.928 .674 .533 r
.5416 .68 m .54042 .68082 L .54107 .67716 L F
.346 .209 .548 r
.53961 .67766 m .54148 .67882 L .5414 .67598 L F
.53961 .67766 m .5414 .67598 L .53981 .67793 L F
.98 .721 .464 r
.5414 .67598 m .54148 .67882 L .54024 .67549 L F
.5414 .67598 m .54024 .67549 L .54006 .67503 L F
0 0 .007 r
.54288 .67659 m .5414 .67598 L .54288 .67659 L F
.768 .607 .679 r
.20425 .62089 m .20602 .624 L .20687 .62218 L F
0 0 0 r
.20602 .624 m .2085 .62137 L .20687 .62218 L F
.75 .374 .341 r
.71621 .43888 m .71827 .44122 L .71917 .43921 L F
.653 .579 .759 r
.71917 .43921 m .72178 .43917 L .72114 .43677 L F
.462 .036 .143 r
.71827 .44122 m .72178 .43917 L .71917 .43921 L F
.644 .598 .788 r
.56373 .63 m .56146 .63099 L .56017 .62742 L F
.818 .864 .882 r
.62893 .477 m .63038 .47385 L .6284 .47714 L F
.638 .166 .118 r
.6083 .46856 m .60514 .46861 L .60781 .46792 L F
.655 .957 .941 r
.61147 .46676 m .6083 .46856 L .60781 .46792 L F
.486 .291 .541 r
.19005 .56046 m .19096 .56216 L .18876 .55931 L F
.528 .32 .541 r
.49103 .62127 m .48863 .62386 L .48899 .62216 L F
.854 .823 .817 r
.60386 .44806 m .60773 .44632 L .60683 .44558 L F
.887 .941 .844 r
.60683 .44558 m .60773 .44632 L .60899 .44459 L F
.591 .753 .955 r
.38273 .63948 m .3855 .63981 L .38419 .63879 L F
0 .084 .64 r
.3855 .63981 m .38701 .64081 L .38419 .63879 L F
.3855 .63981 m .38752 .64202 L .38701 .64081 L F
.539 .619 .88 r
.57181 .63001 m .57124 .63344 L .57076 .62982 L F
.57181 .63001 m .5736 .63315 L .57124 .63344 L F
.561 .568 .818 r
.49145 .61925 m .49236 .61525 L .4902 .61766 L F
.49145 .61925 m .49368 .61866 L .49236 .61525 L F
.863 .888 .853 r
.57924 .62119 m .58099 .62283 L .57701 .62394 L F
.568 .803 .988 r
.58196 .62053 m .58099 .62283 L .57924 .62119 L F
.867 .834 .812 r
.60168 .45081 m .60297 .45197 L .60501 .4492 L F
.60168 .45081 m .60501 .4492 L .60386 .44806 L F
.739 .827 .919 r
.68401 .42383 m .68748 .42423 L .68589 .42263 L F
.784 .827 .885 r
.68589 .42263 m .68748 .42423 L .69034 .42128 L F
.18 .36 .807 r
.37729 .63255 m .3775 .63409 L .37851 .63255 L F
.351 .451 .823 r
.37845 .63608 m .37851 .63255 L .3775 .63409 L F
.14 0 0 r
.53018 .69153 m .52391 .69456 L .52718 .69427 L F
.768 .529 .574 r
.52718 .69427 m .53086 .69206 L .53018 .69153 L F
0 0 .047 r
.66605 .43302 m .66636 .43366 L .66715 .43146 L F
.793 .608 .652 r
.66636 .43366 m .66625 .43356 L .66715 .43146 L F
0 0 .051 r
.66568 .43646 m .66613 .43491 L .66605 .43302 L F
.086 .299 .781 r
.66605 .43302 m .66394 .42937 L .6655 .43061 L F
.66605 .43302 m .66715 .43146 L .66394 .42937 L F
.793 .608 .652 r
.66625 .43356 m .66336 .43071 L .66645 .43132 L F
.66625 .43356 m .66645 .43132 L .66715 .43146 L F
0 0 .051 r
.66613 .43491 m .66618 .43473 L .66616 .43453 L F
.66613 .43491 m .66616 .43453 L .66605 .43302 L F
.928 .907 .781 r
.66707 .43893 m .66618 .43473 L .66568 .43646 L F
.44 .307 .603 r
.35575 .60429 m .35744 .60104 L .35553 .60167 L F
.638 .398 .537 r
.5647 .51906 m .56712 .52152 L .5647 .52129 L F
.642 .397 .533 r
.5647 .51906 m .56721 .51895 L .56712 .52152 L F
.312 0 0 r
.73722 .4271 m .73368 .42701 L .73518 .42844 L F
.47 .245 .489 r
.23944 .60642 m .23713 .60969 L .23735 .60733 L F
.849 .766 .77 r
.63057 .44231 m .63129 .4455 L .6287 .44473 L F
.88 .583 .479 r
.6287 .44473 m .63129 .4455 L .63129 .44759 L F
.643 .152 .071 r
.63129 .4455 m .63379 .44722 L .63129 .44759 L F
.496 .185 .369 r
.52028 .6985 m .51742 .7006 L .51799 .69892 L F
.604 .369 .534 r
.70976 .43942 m .71227 .44136 L .71201 .43888 L F
.70976 .43942 m .70974 .44181 L .71227 .44136 L F
.935 .558 .222 r
.66635 .45139 m .66557 .45259 L .66547 .45018 L F
.66635 .45139 m .66711 .45389 L .66557 .45259 L F
0 0 0 r
.67188 .40932 m .67482 .4074 L .67318 .40933 L F
.085 0 0 r
.67318 .40933 m .67482 .4074 L .67636 .40762 L F
.272 0 0 r
.64265 .456 m .64478 .45592 L .64636 .45484 L F
.161 .337 .793 r
.64493 .45141 m .64636 .45484 L .64688 .45254 L F
.704 .261 .197 r
.64636 .45484 m .64478 .45592 L .64836 .4564 L F
.994 .75 .435 r
.64836 .4564 m .64688 .45254 L .64636 .45484 L F
.719 .626 .754 r
.71547 .4246 m .7191 .42756 L .71802 .42381 L F
.71547 .4246 m .7168 .42817 L .7191 .42756 L F
.676 .646 .812 r
.71802 .42381 m .7191 .42756 L .72156 .42478 L F
.637 .585 .779 r
.7191 .42756 m .7233 .42872 L .72156 .42478 L F
.484 .244 .473 r
.74238 .43625 m .73997 .4393 L .73976 .43671 L F
0 .04 .604 r
.65686 .4175 m .65706 .41866 L .65881 .42074 L F
.945 .79 .657 r
.65751 .44446 m .65618 .44713 L .65853 .44689 L F
.998 .835 .546 r
.65618 .44713 m .65685 .45101 L .65853 .44689 L F
.669 .969 .789 r
.38669 .60902 m .38579 .60995 L .38799 .60826 L F
.148 0 0 r
.39008 .60727 m .38669 .60902 L .38799 .60826 L F
.632 .682 .879 r
.69826 .4186 m .69983 .4142 L .69743 .41522 L F
.69826 .4186 m .70106 .41834 L .69983 .4142 L F
.666 .648 .823 r
.69945 .41919 m .70106 .41834 L .69826 .4186 L F
.288 .223 .608 r
.38669 .60902 m .38738 .61419 L .38579 .60995 L F
.256 .747 .915 r
.20925 .5529 m .20521 .55271 L .20718 .55313 L F
.537 .267 .453 r
.55651 .52508 m .55884 .52677 L .55651 .5273 L F
.55651 .52508 m .55912 .52479 L .55884 .52677 L F
.274 0 0 r
.19974 .55238 m .19535 .55273 L .19731 .55217 L F
.31 0 0 r
.68523 .41794 m .68959 .41816 L .68666 .41759 L F
.753 .639 .734 r
.44248 .57994 m .44378 .5839 L .4462 .5809 L F
.44248 .57994 m .4462 .5809 L .44491 .5817 L F
.375 .436 .796 r
.44762 .57885 m .4462 .5809 L .44493 .57925 L F
.44762 .57885 m .44776 .58023 L .4462 .5809 L F
.328 0 .14 r
.44935 .58133 m .44776 .58023 L .44957 .57872 L F
.44935 .58133 m .44704 .58193 L .44776 .58023 L F
.478 .241 .476 r
.44842 .58 m .44704 .58193 L .44935 .58133 L F
.442 .489 .813 r
.44957 .57872 m .44776 .58023 L .44762 .57885 L F
.478 .241 .476 r
.44762 .57885 m .44731 .58054 L .44842 .58 L F
.44731 .58054 m .44704 .58193 L .44842 .58 L F
.47 .07 .2 r
.44776 .58023 m .44521 .58154 L .4462 .5809 L F
.44521 .58154 m .44491 .5817 L .44499 .58165 L F
.44521 .58154 m .44499 .58165 L .4462 .5809 L F
.221 0 .163 r
.6077 .4924 m .61053 .48996 L .60968 .49153 L F
.146 0 .12 r
.60968 .49153 m .61053 .48996 L .61253 .48884 L F
.915 .557 .107 r
.65649 .43623 m .65711 .43858 L .65807 .43965 L F
.98 .765 .543 r
.65649 .44082 m .65807 .43965 L .65711 .43858 L F
.65649 .44082 m .65782 .44208 L .65807 .43965 L F
.688 .508 .639 r
.57974 .60981 m .58191 .61297 L .58239 .61054 L F
.953 .727 .269 r
.65258 .42337 m .65317 .42278 L .65257 .42105 L F
.65258 .42337 m .6532 .42483 L .65317 .42278 L F
.443 .658 .952 r
.38273 .63948 m .38382 .63799 L .38011 .63628 L F
.38273 .63948 m .38419 .63879 L .38382 .63799 L F
.376 .205 .517 r
.23693 .61255 m .23505 .6156 L .23531 .61324 L F
.591 .77 .965 r
.64111 .45103 m .64202 .45224 L .64493 .45141 L F
.367 .222 .549 r
.22598 .63037 m .22427 .63371 L .22443 .63131 L F
.786 .721 .791 r
.6136 .431 m .61409 .42678 L .61168 .42981 L F
.6136 .431 m .61603 .42847 L .61409 .42678 L F
.89 .716 .66 r
.61168 .42981 m .61305 .4334 L .6136 .431 L F
.883 .957 .846 r
.43313 .57323 m .4336 .57525 L .43511 .57348 L F
.932 .764 .65 r
.43108 .57582 m .4336 .57525 L .43313 .57323 L F
.43108 .57582 m .43285 .57765 L .4336 .57525 L F
.328 .613 .953 r
.21442 .59831 m .21482 .59673 L .2117 .59521 L F
.21442 .59831 m .21607 .59803 L .21482 .59673 L F
.378 .245 .571 r
.21442 .59831 m .21559 .60036 L .21607 .59803 L F
.21442 .59831 m .21426 .601 L .21559 .60036 L F
.851 .91 .874 r
.63314 .4712 m .63438 .47228 L .63705 .46957 L F
.751 .611 .704 r
.59176 .47741 m .59382 .47414 L .59221 .47518 L F
.523 .633 .901 r
.6826 .45863 m .68002 .4571 L .6824 .45865 L F
.296 0 0 r
.6824 .45865 m .68401 .45917 L .6826 .45863 L F
.635 .654 .851 r
.71532 .4118 m .71662 .41396 L .71292 .41259 L F
.654 .662 .845 r
.71889 .41285 m .71662 .41396 L .71532 .4118 L F
.445 .437 .756 r
.25489 .56828 m .25369 .57164 L .2532 .56885 L F
.25489 .56828 m .25583 .57148 L .25369 .57164 L F
.545 .332 .542 r
.25593 .57421 m .25369 .57164 L .25583 .57148 L F
.25593 .57421 m .25381 .57479 L .25369 .57164 L F
.961 .897 .718 r
.64482 .41756 m .64604 .41809 L .64437 .42163 L F
.293 .522 .903 r
.64783 .41683 m .64866 .41883 L .64604 .41809 L F
.961 .897 .718 r
.64482 .41756 m .64604 .41809 L .64437 .42163 L F
.113 0 0 r
.40742 .57726 m .41136 .57578 L .40818 .57689 L F
.40742 .57726 m .40982 .57681 L .41136 .57578 L F
0 0 0 r
.41136 .57578 m .41195 .57608 L .41361 .57498 L F
.41136 .57578 m .40982 .57681 L .41195 .57608 L F
.501 .655 .928 r
.2018 .61378 m .2036 .61323 L .20063 .61168 L F
.465 .086 .234 r
.4114 .58943 m .41006 .59157 L .40766 .59183 L F
.621 .261 .339 r
.41374 .58987 m .41006 .59157 L .4114 .58943 L F
.735 .942 .951 r
.66211 .41086 m .66101 .41306 L .66009 .4123 L F
0 0 0 r
.40225 .57966 m .40373 .57952 L .4063 .57788 L F
.4063 .57788 m .40586 .57868 L .40742 .57726 L F
.4063 .57788 m .40373 .57952 L .40586 .57868 L F
.991 .73 .392 r
.55089 .66536 m .55232 .66895 L .5521 .66668 L F
.666 .648 .823 r
.69945 .41919 m .70212 .41889 L .70106 .41834 L F
.656 .507 .669 r
.69984 .42174 m .70212 .41889 L .69945 .41919 L F
.671 .447 .572 r
.52162 .56039 m .51827 .56267 L .51863 .56026 L F
.52162 .56039 m .52205 .56333 L .51827 .56267 L F
.624 .414 .577 r
.52441 .56263 m .52162 .56039 L .52439 .56003 L F
.52441 .56263 m .52205 .56333 L .52162 .56039 L F
.58 .718 .937 r
.69224 .40399 m .68973 .40458 L .68882 .40288 L F
.507 0 0 r
.23216 .54332 m .23411 .54448 L .23603 .54486 L F
.089 .552 .907 r
.23622 .54411 m .23603 .54486 L .23411 .54448 L F
.23622 .54411 m .23784 .54521 L .23603 .54486 L F
.349 0 0 r
.46378 .63454 m .46259 .63601 L .46013 .6363 L F
.203 0 0 r
.46496 .63544 m .46378 .63454 L .46632 .63431 L F
.46496 .63544 m .46259 .63601 L .46378 .63454 L F
.68 .767 .917 r
.43511 .57348 m .43885 .57317 L .43801 .57289 L F
.276 .384 .793 r
.54569 .53557 m .54323 .53381 L .54569 .53328 L F
.124 0 0 r
.397 .58141 m .39935 .58091 L .40003 .58031 L F
0 0 0 r
.40003 .58031 m .4015 .58014 L .40225 .57966 L F
.40003 .58031 m .39935 .58091 L .4015 .58014 L F
.882 .939 .849 r
.59627 .43957 m .59805 .43558 L .59875 .43667 L F
.59627 .43957 m .59527 .43866 L .59805 .43558 L F
.555 .833 .997 r
.67877 .46869 m .67636 .4694 L .67544 .46823 L F
.67877 .46869 m .67636 .4694 L .67544 .46823 L F
.3 .788 .896 r
.4374 .57282 m .43511 .57348 L .43801 .57289 L F
.4374 .57282 m .43313 .57323 L .43511 .57348 L F
.749 .52 .584 r
.19092 .6391 m .19402 .63949 L .19421 .63682 L F
.105 0 .42 r
.19421 .63682 m .19554 .63809 L .19562 .63573 L F
.19421 .63682 m .19402 .63949 L .19554 .63809 L F
.551 .29 .474 r
.72631 .44483 m .72606 .44761 L .7233 .44795 L F
.529 .272 .47 r
.72852 .44691 m .72631 .44483 L .72903 .4444 L F
.72852 .44691 m .72606 .44761 L .72631 .44483 L F
.703 .254 .181 r
.72874 .41548 m .73191 .41679 L .73224 .41595 L F
.671 .19 .102 r
.73224 .41595 m .73157 .41654 L .72874 .41548 L F
.634 .57 .765 r
.73178 .4164 m .73186 .41665 L .73157 .41654 L F
.73186 .41665 m .73191 .41679 L .72874 .41548 L F
.728 .776 .281 r
.73224 .41595 m .73191 .41679 L .7321 .41619 L F
.73224 .41595 m .7321 .41619 L .73355 .41179 L F
.726 .623 .742 r
.73355 .41179 m .7321 .41619 L .73009 .41102 L F
.7321 .41619 m .73191 .41679 L .73178 .4164 L F
.7321 .41619 m .73178 .4164 L .73009 .41102 L F
.237 .376 .802 r
.73154 .41657 m .73207 .41624 L .73096 .41709 L F
.73157 .41654 m .73166 .41649 L .73154 .41657 L F
.73166 .41649 m .73207 .41624 L .73154 .41657 L F
.73224 .41595 m .73574 .41878 L .73432 .41489 L F
.561 .906 .685 r
.73587 .41891 m .73566 .41886 L .73575 .41878 L F
.73587 .41891 m .73575 .41878 L .73748 .41727 L F
0 .096 .565 r
.73587 .41891 m .73586 .41888 L .73574 .41878 L F
.73587 .41891 m .73574 .41878 L .73224 .41595 L F
.237 .376 .802 r
.73574 .41878 m .73586 .41888 L .7358 .41871 L F
.73574 .41878 m .7358 .41871 L .73432 .41489 L F
.561 .906 .685 r
.73566 .41886 m .73558 .41884 L .73608 .41843 L F
.577 .593 .833 r
.73432 .41489 m .7358 .41871 L .73748 .41727 L F
.561 .906 .685 r
.73566 .41886 m .7358 .41871 L .73748 .41727 L F
.577 .593 .833 r
.7358 .41871 m .73586 .41888 L .73748 .41727 L F
.561 .906 .685 r
.7358 .41871 m .73608 .41843 L .73748 .41727 L F
.237 .376 .802 r
.73207 .41624 m .73432 .41489 L .73197 .41642 L F
.73207 .41624 m .73197 .41642 L .73096 .41709 L F
.73224 .41595 m .73342 .41535 L .73157 .41654 L F
.73342 .41535 m .73432 .41489 L .73157 .41654 L F
.634 .57 .765 r
.73009 .41102 m .73178 .4164 L .72874 .41548 L F
.73178 .4164 m .73157 .41654 L .72874 .41548 L F
.671 .19 .102 r
.73157 .41654 m .73096 .41709 L .72874 .41548 L F
.728 .776 .281 r
.73224 .41595 m .73355 .41179 L .73463 .41328 L F
.588 .312 .465 r
.36522 .59216 m .36785 .592 L .36823 .58979 L F
.278 0 0 r
.36823 .58979 m .37059 .58936 L .37142 .58878 L F
.497 .223 .429 r
.36785 .592 m .37059 .58936 L .36823 .58979 L F
.317 0 .256 r
.60492 .4949 m .6077 .4924 L .60739 .49404 L F
.282 0 .273 r
.60739 .49404 m .6077 .4924 L .60968 .49153 L F
.678 .589 .749 r
.53381 .54808 m .53006 .54519 L .53369 .54597 L F
.617 .523 .725 r
.53616 .54525 m .53381 .54808 L .53369 .54597 L F
.595 .491 .706 r
.53616 .54525 m .53612 .54772 L .53381 .54808 L F
.646 .521 .697 r
.53612 .54772 m .53402 .55054 L .53381 .54808 L F
.458 .002 .079 r
.37142 .58878 m .37059 .58936 L .37381 .58885 L F
.685 .98 .862 r
.54288 .67659 m .54523 .67772 L .544 .6778 L F
.54288 .67659 m .54605 .6749 L .54523 .67772 L F
.948 .615 .36 r
.54837 .67013 m .54909 .67242 L .54753 .67134 L F
.584 .245 .361 r
.71295 .45519 m .70988 .45613 L .71002 .45539 L F
.791 .921 .925 r
.60892 .44192 m .61318 .44061 L .61063 .44053 L F
.755 .882 .937 r
.61063 .44053 m .61318 .44061 L .61456 .43957 L F
.77 .812 .886 r
.73587 .41891 m .73224 .4191 L .73558 .41884 L F
.516 .834 .528 r
.73748 .41727 m .73586 .41888 L .73587 .41891 L F
.927 .711 .591 r
.54167 .68642 m .54324 .68729 L .54237 .68471 L F
.821 .818 .846 r
.54167 .68642 m .5452 .68602 L .5453 .68403 L F
.54167 .68642 m .54324 .68729 L .5452 .68602 L F
.77 .736 .822 r
.5453 .68403 m .5452 .68602 L .54738 .68341 L F
.685 .31 .331 r
.64439 .43313 m .64691 .43521 L .64328 .43554 L F
.64439 .43313 m .64642 .43385 L .64691 .43521 L F
.757 .679 .776 r
.55628 .62502 m .55776 .62819 L .5542 .62776 L F
.669 .705 .875 r
.55861 .62475 m .55776 .62819 L .55628 .62502 L F
.55861 .62475 m .56017 .62742 L .55776 .62819 L F
.477 .609 .903 r
.37365 .63165 m .37523 .62979 L .37324 .62994 L F
.37365 .63165 m .37729 .63255 L .37523 .62979 L F
.523 .584 .858 r
.20801 .61581 m .20824 .61104 L .2059 .61153 L F
.20801 .61581 m .21071 .6154 L .20824 .61104 L F
.421 .294 .602 r
.20801 .61581 m .21028 .61814 L .21071 .6154 L F
.20801 .61581 m .20818 .61894 L .21028 .61814 L F
.387 0 0 r
.18907 .55399 m .18734 .55463 L .18513 .5544 L F
.924 .717 .606 r
.18907 .55399 m .18828 .55625 L .18734 .55463 L F
.718 .374 .396 r
.62998 .42701 m .63192 .42701 L .62981 .42472 L F
.672 .449 .574 r
.60514 .46861 m .60609 .4665 L .60249 .4666 L F
.814 .821 .855 r
.53868 .51838 m .5357 .51806 L .53784 .51489 L F
.53868 .51838 m .53702 .51951 L .5357 .51806 L F
.755 .673 .771 r
.53991 .51632 m .53868 .51838 L .53784 .51489 L F
0 0 0 r
.16781 .54513 m .1699 .54376 L .16827 .54466 L F
.946 .788 .655 r
.53012 .52802 m .52971 .53058 L .52875 .52708 L F
.807 .903 .908 r
.55034 .68302 m .55221 .6799 L .54904 .68234 L F
.55034 .68302 m .55342 .6808 L .55221 .6799 L F
.304 .013 .295 r
.19666 .63338 m .19816 .63296 L .19902 .63074 L F
.216 0 .338 r
.19902 .63074 m .20097 .62997 L .20114 .62759 L F
.438 .229 .497 r
.19816 .63296 m .20097 .62997 L .19902 .63074 L F
.617 .339 .473 r
.53917 .68655 m .54237 .68471 L .53977 .68553 L F
.628 .643 .845 r
.70905 .40949 m .70691 .41077 L .70567 .40916 L F
.33 .735 .981 r
.2223 .54236 m .22439 .54229 L .2261 .54316 L F
.186 .667 .93 r
.22439 .54229 m .22863 .54323 L .2261 .54316 L F
.639 .677 .871 r
.71409 .4085 m .71292 .41259 L .71157 .40918 L F
.71409 .4085 m .71532 .4118 L .71292 .41259 L F
0 0 .214 r
.64607 .44249 m .64607 .44486 L .64668 .44078 L F
.6 .395 .575 r
.59575 .48061 m .59816 .48051 L .59841 .47777 L F
.669 .495 .64 r
.59816 .48051 m .60063 .477 L .59841 .47777 L F
.691 .814 .941 r
.43436 .5866 m .43572 .58816 L .43821 .58712 L F
.214 0 .34 r
.22814 .62725 m .22598 .63037 L .22657 .62809 L F
.246 .744 .906 r
.45084 .57513 m .45176 .57461 L .44913 .57467 L F
.45084 .57513 m .45331 .57489 L .45176 .57461 L F
.245 .651 .962 r
.7468 .4281 m .74569 .42703 L .7433 .42674 L F
.241 .413 .833 r
.7468 .4281 m .74868 .42689 L .74569 .42703 L F
.7468 .4281 m .74952 .42932 L .74868 .42689 L F
.554 .216 .35 r
.43369 .63685 m .43587 .63846 L .43335 .63856 L F
.582 .194 .272 r
.43634 .63711 m .43587 .63846 L .43369 .63685 L F
.413 .009 .159 r
.3761 .58905 m .37832 .58893 L .37985 .58656 L F
.379 0 .099 r
.37832 .58893 m .38227 .58643 L .37985 .58656 L F
.991 .73 .392 r
.55089 .66536 m .55115 .66841 L .55232 .66895 L F
.966 .703 .483 r
.55115 .66841 m .55259 .67082 L .55232 .66895 L F
.759 .623 .709 r
.53006 .54519 m .52664 .54252 L .52895 .54244 L F
.53006 .54519 m .52854 .54621 L .52664 .54252 L F
.781 .672 .743 r
.53006 .54519 m .52768 .54831 L .52854 .54621 L F
.699 .617 .762 r
.53251 .54232 m .53006 .54519 L .52895 .54244 L F
.691 .604 .754 r
.53251 .54232 m .53369 .54597 L .53006 .54519 L F
.732 .618 .732 r
.53558 .5372 m .53442 .53937 L .53094 .5387 L F
.742 .577 .67 r
.53442 .53937 m .53251 .54232 L .53094 .5387 L F
.706 .529 .646 r
.53442 .53937 m .53665 .54351 L .53251 .54232 L F
.781 .489 .494 r
.74046 .4128 m .73956 .4168 L .73717 .41229 L F
.347 .454 .828 r
.73956 .4168 m .73463 .41328 L .73688 .4124 L F
.73746 .41283 m .73688 .4124 L .73717 .41229 L F
.73956 .4168 m .73688 .4124 L .73746 .41283 L F
.729 .349 .33 r
.73897 .41396 m .74085 .41507 L .74046 .4128 L F
.73809 .41464 m .74036 .41499 L .73897 .41396 L F
.74036 .41499 m .74085 .41507 L .73897 .41396 L F
.73809 .41464 m .74046 .4128 L .73717 .41229 L F
.57 .238 .368 r
.74085 .41507 m .7432 .41429 L .74046 .4128 L F
.801 .689 .741 r
.62548 .40948 m .62382 .41274 L .62727 .41278 L F
.801 .689 .742 r
.62382 .41274 m .62562 .41646 L .62727 .41278 L F
.824 .862 .875 r
.6461 .45942 m .64981 .45801 L .64836 .4564 L F
0 0 .348 r
.5111 .67728 m .51022 .67797 L .51005 .6806 L F
.673 .594 .759 r
.5111 .67728 m .51005 .6806 L .51022 .67797 L F
.55 .821 .996 r
.42661 .58498 m .42614 .58665 L .42429 .58555 L F
.216 .466 .881 r
.42661 .58498 m .42764 .58711 L .42614 .58665 L F
.64 .524 .705 r
.42764 .58711 m .42571 .58952 L .42614 .58665 L F
.256 .619 .958 r
.66762 .45969 m .67078 .46126 L .6703 .46152 L F
.774 .918 .935 r
.67078 .46126 m .67253 .45812 L .6703 .46152 L F
.67078 .46126 m .67383 .45924 L .67253 .45812 L F
.933 .598 .375 r
.67495 .45581 m .67584 .45426 L .67428 .45348 L F
.252 .383 .801 r
.20163 .62468 m .20271 .62418 L .20056 .62294 L F
.168 .094 .522 r
.20114 .62759 m .20271 .62418 L .20163 .62468 L F
.426 0 .076 r
.38455 .58607 m .38694 .586 L .38847 .5842 L F
.255 0 0 r
.38847 .5842 m .38996 .58459 L .39084 .58376 L F
.38847 .5842 m .38694 .586 L .38996 .58459 L F
.283 .779 .743 r
.41361 .57498 m .41582 .57423 L .41679 .57403 L F
.451 .879 .79 r
.41679 .57403 m .41789 .57317 L .41999 .57278 L F
0 0 0 r
.41616 .57421 m .41943 .57232 L .41789 .57317 L F
.599 .951 .874 r
.4219 .57156 m .41789 .57317 L .4198 .5721 L F
0 0 0 r
.41943 .57232 m .4198 .5721 L .41789 .57317 L F
.451 .879 .79 r
.41679 .57403 m .41606 .57418 L .41789 .57317 L F
.41606 .57418 m .41582 .57423 L .41789 .57317 L F
.663 .689 .864 r
.54181 .66132 m .54404 .6632 L .54141 .66185 L F
.937 .626 .172 r
.54404 .6632 m .54297 .66387 L .54141 .66185 L F
.54404 .6632 m .54409 .66481 L .54297 .66387 L F
.965 .899 .709 r
.60899 .44459 m .60892 .44192 L .6078 .44357 L F
.887 .941 .844 r
.60683 .44558 m .60899 .44459 L .6078 .44357 L F
.593 .224 .311 r
.2277 .56286 m .22619 .565 L .22367 .56486 L F
.453 .069 .22 r
.22908 .56443 m .2277 .56286 L .22977 .56419 L F
.22908 .56443 m .22619 .565 L .2277 .56286 L F
.678 .641 .806 r
.72874 .41548 m .72642 .41777 L .7255 .41557 L F
.334 .064 .348 r
.35777 .59805 m .35954 .59751 L .36021 .59512 L F
.533 .3 .508 r
.35954 .59751 m .36214 .59465 L .36021 .59512 L F
.681 .54 .687 r
.40766 .59183 m .40506 .59481 L .40543 .59266 L F
.168 .094 .522 r
.20114 .62759 m .20274 .62679 L .20271 .62418 L F
.261 .022 .35 r
.20114 .62759 m .2026 .62928 L .20274 .62679 L F
.20114 .62759 m .20097 .62997 L .2026 .62928 L F
.629 .568 .767 r
.53616 .54525 m .53369 .54597 L .53251 .54232 L F
.662 .493 .646 r
.70492 .44527 m .70738 .44509 L .70722 .44242 L F
.742 .661 .77 r
.70738 .44509 m .70974 .44181 L .70722 .44242 L F
.62 .316 .432 r
.54801 .52779 m .55038 .52976 L .54799 .53024 L F
.54801 .52779 m .55068 .52784 L .55038 .52976 L F
.29 .711 .971 r
.46989 .57339 m .47146 .57404 L .46927 .57437 L F
.855 .934 .876 r
.60134 .43397 m .59875 .43667 L .59805 .43558 L F
.876 .943 .855 r
.68365 .46542 m .68387 .46488 L .68104 .46294 L F
.584 .613 .848 r
.67718 .46019 m .68104 .46294 L .67945 .45898 L F
.519 .579 .855 r
.67945 .45898 m .68104 .46294 L .68324 .46229 L F
.46 .355 .648 r
.68104 .46294 m .68387 .46488 L .68324 .46229 L F
.933 .832 .722 r
.59598 .46119 m .59761 .46269 L .59795 .46047 L F
.916 .841 .756 r
.59554 .46559 m .59761 .46269 L .59598 .46119 L F
.816 .857 .879 r
.62229 .40586 m .62165 .40373 L .62269 .40477 L F
.62229 .40586 m .61885 .40616 L .62165 .40373 L F
.84 .805 .817 r
.62229 .40586 m .62044 .40779 L .61885 .40616 L F
.346 .186 .517 r
.24568 .59226 m .24533 .59512 L .24371 .59551 L F
.425 .253 .543 r
.24554 .59736 m .24371 .59551 L .24533 .59512 L F
.24554 .59736 m .24361 .59802 L .24371 .59551 L F
0 .227 .696 r
.6824 .45865 m .68002 .4571 L .67889 .45599 L F
.919 .908 .794 r
.59795 .46047 m .60015 .45728 L .59912 .45626 L F
.909 .834 .76 r
.60015 .45728 m .60034 .45339 L .59912 .45626 L F
.776 .862 .913 r
.6152 .46423 m .61648 .46519 L .61354 .46541 L F
.805 .864 .892 r
.6195 .46283 m .61648 .46519 L .6152 .46423 L F
.742 .661 .77 r
.70738 .44509 m .71091 .44533 L .70974 .44181 L F
.25 0 0 r
.70758 .44742 m .71091 .44533 L .70738 .44509 L F
.70758 .44742 m .71029 .44679 L .71091 .44533 L F
.293 .381 .783 r
.70974 .44181 m .71091 .44533 L .71276 .44451 L F
0 0 0 r
.71091 .44533 m .71235 .44503 L .71276 .44451 L F
.71091 .44533 m .71029 .44679 L .71235 .44503 L F
.587 .355 .53 r
.59426 .50346 m .59122 .50655 L .59184 .50401 L F
.752 .735 .836 r
.52903 .55227 m .52506 .55322 L .52752 .55059 L F
.691 .693 .847 r
.53145 .55127 m .52903 .55227 L .52752 .55059 L F
.687 .539 .679 r
.4962 .71314 m .49898 .71058 L .49534 .70987 L F
.292 0 0 r
.19447 .54119 m .19664 .54156 L .19811 .54144 L F
.26 .769 .804 r
.19664 .54156 m .2004 .54086 L .19811 .54144 L F
.486 .649 .93 r
.6815 .41219 m .67934 .41273 L .67861 .41074 L F
.562 .526 .772 r
.6824 .4157 m .67934 .41273 L .6815 .41219 L F
.735 .453 .502 r
.44684 .63341 m .45299 .63509 L .45012 .63108 L F
.335 .341 .718 r
.45012 .63108 m .45299 .63509 L .45285 .63212 L F
.749 .603 .695 r
.53353 .53343 m .53558 .5372 L .53128 .53642 L F
.732 .618 .732 r
.53558 .5372 m .53094 .5387 L .53128 .53642 L F
.699 .585 .724 r
.53763 .53439 m .53558 .5372 L .53353 .53343 L F
.385 .689 .98 r
.37092 .6298 m .37181 .62849 L .36917 .62847 L F
.37092 .6298 m .37324 .62994 L .37181 .62849 L F
.968 .682 .434 r
.66791 .44222 m .66659 .44383 L .66669 .4412 L F
.66791 .44222 m .66813 .44525 L .66659 .44383 L F
.615 .623 .836 r
.7239 .41137 m .72273 .41553 L .72145 .41218 L F
.7239 .41137 m .7255 .41557 L .72273 .41553 L F
.476 .214 .437 r
.58637 .50718 m .58846 .5087 L .58615 .50911 L F
.58637 .50718 m .58872 .50665 L .58846 .5087 L F
.99 .767 .505 r
.51709 .55447 m .51567 .55561 L .5155 .55315 L F
.51709 .55447 m .51694 .55682 L .51567 .55561 L F
.577 .464 .689 r
.25434 .57957 m .25205 .57769 L .25422 .57707 L F
.25434 .57957 m .25302 .58037 L .25205 .57769 L F
.739 .564 .657 r
.57073 .51874 m .56712 .52152 L .56721 .51895 L F
.727 .647 .769 r
.72892 .43029 m .7264 .43352 L .72999 .43282 L F
.449 .231 .49 r
.7264 .43352 m .72892 .43461 L .72999 .43282 L F
0 0 0 r
.72892 .43461 m .73263 .43325 L .72999 .43282 L F
.17 0 .014 r
.20918 .60965 m .21123 .60925 L .21251 .60726 L F
.016 0 0 r
.21251 .60726 m .21298 .60835 L .21394 .60613 L F
.21251 .60726 m .21123 .60925 L .21298 .60835 L F
.851 .91 .874 r
.63314 .4712 m .63705 .46957 L .63586 .46819 L F
.869 .86 .829 r
.63705 .46957 m .63793 .46518 L .63586 .46819 L F
.63705 .46957 m .63944 .46659 L .63793 .46518 L F
.637 .51 .692 r
.20056 .62294 m .20453 .62252 L .20269 .62009 L F
.567 .258 .404 r
.20056 .62294 m .20271 .62418 L .20453 .62252 L F
.582 .279 .42 r
.58105 .51198 m .57796 .51502 L .57778 .51334 L F
.58105 .51198 m .5807 .51481 L .57796 .51502 L F
.505 .313 .553 r
.58373 .50975 m .58349 .51153 L .58105 .51198 L F
.498 .225 .43 r
.58349 .51153 m .5807 .51481 L .58105 .51198 L F
0 0 0 r
.62989 .42951 m .63214 .42862 L .63192 .42701 L F
.885 .857 .809 r
.63793 .46518 m .64155 .46358 L .64056 .46245 L F
.63793 .46518 m .63944 .46659 L .64155 .46358 L F
.33 .399 .782 r
.3874 .61424 m .38872 .61811 L .38612 .6163 L F
.406 .399 .739 r
.38612 .6163 m .38872 .61811 L .38699 .61833 L F
.556 .326 .522 r
.5944 .5013 m .59665 .50303 L .59426 .50346 L F
.5944 .5013 m .59691 .50079 L .59665 .50303 L F
.773 .645 .721 r
.66701 .41551 m .67071 .41585 L .66934 .41219 L F
0 .554 .74 r
.66701 .41551 m .67011 .41576 L .67071 .41585 L F
0 0 .105 r
.67071 .41585 m .67258 .41227 L .66934 .41219 L F
.67107 .41516 m .67228 .41457 L .67258 .41227 L F
.578 .094 .069 r
.67113 .41473 m .67315 .41415 L .67228 .41457 L F
.357 .015 .24 r
.67258 .41227 m .67228 .41457 L .67466 .41372 L F
.578 .094 .069 r
.67315 .41415 m .67466 .41372 L .67228 .41457 L F
0 0 .105 r
.67071 .41585 m .67228 .41457 L .67107 .41516 L F
.532 .923 .847 r
.67071 .41585 m .67011 .41576 L .67228 .41457 L F
.543 .343 .559 r
.42594 .60136 m .42883 .60077 L .42867 .59834 L F
.281 0 .123 r
.46797 .62718 m .47042 .62684 L .47104 .62507 L F
.055 0 .04 r
.47104 .62507 m .47195 .62605 L .47317 .62428 L F
.47104 .62507 m .47042 .62684 L .47195 .62605 L F
.417 .16 .414 r
.54572 .63038 m .54807 .63004 L .54822 .62785 L F
.639 .894 .567 r
.55039 .62505 m .54822 .62785 L .54923 .62633 L F
.553 .604 .858 r
.55039 .62505 m .55062 .62705 L .54822 .62785 L F
.55062 .62705 m .55075 .62827 L .55062 .62825 L F
.55062 .62705 m .55062 .62825 L .54822 .62785 L F
.727 .614 .731 r
.55286 .62431 m .55075 .62827 L .55039 .62505 L F
.528 .339 .567 r
.54923 .62633 m .55286 .62431 L .55039 .62505 L F
.55061 .62556 m .55074 .62405 L .55286 .62431 L F
.54923 .62633 m .55061 .62425 L .55061 .62556 L F
.55061 .62425 m .55074 .62405 L .55061 .62556 L F
.483 .566 .864 r
.55088 .62999 m .54822 .62785 L .55075 .62827 L F
.557 .274 .441 r
.54822 .62785 m .55109 .62928 L .54923 .62633 L F
.73 .702 .824 r
.55075 .62827 m .5542 .62776 L .55088 .62999 L F
.557 .274 .441 r
.54822 .62785 m .54807 .63004 L .55109 .62928 L F
.518 .887 .974 r
.55109 .62928 m .54807 .63004 L .55088 .62999 L F
.565 .568 .816 r
.55167 .63347 m .55109 .62928 L .55088 .62999 L F
.458 .594 .9 r
.52868 .53915 m .52525 .53656 L .52766 .53621 L F
.677 .579 .738 r
.53128 .53642 m .52868 .53915 L .52766 .53621 L F
.668 .807 .95 r
.53094 .5387 m .52868 .53915 L .53128 .53642 L F
.964 .882 .702 r
.67225 .42883 m .67506 .42622 L .67372 .4255 L F
.67225 .42883 m .67329 .42996 L .67506 .42622 L F
.524 .84 .999 r
.69069 .45739 m .68897 .45881 L .68813 .4585 L F
.69069 .45739 m .69188 .45816 L .68897 .45881 L F
.441 .268 .549 r
.36244 .63374 m .36466 .6334 L .36422 .63058 L F
.36422 .63058 m .36466 .6334 L .36244 .63374 L F
.36244 .63374 m .36466 .6334 L .36422 .63058 L F
.099 0 .23 r
.23033 .62418 m .22814 .62725 L .2289 .62509 L F
.801 .696 .749 r
.58829 .47696 m .59176 .47741 L .59065 .47392 L F
.808 .669 .71 r
.58973 .48035 m .59176 .47741 L .58829 .47696 L F
.757 .596 .677 r
.58973 .48035 m .59318 .48064 L .59176 .47741 L F
.814 .702 .742 r
.59065 .47392 m .59176 .47741 L .59221 .47518 L F
.006 0 0 r
.47194 .63273 m .46829 .63386 L .46971 .63351 L F
.654 .938 .966 r
.42206 .58549 m .41962 .58686 L .42055 .58529 L F
.742 .427 .449 r
.41962 .58686 m .41991 .5893 L .41831 .58849 L F
.681 .966 .932 r
.41962 .58686 m .41866 .58659 L .42055 .58529 L F
.978 .909 .668 r
.41962 .58686 m .41831 .58849 L .41866 .58659 L F
.782 .876 .916 r
.62044 .40779 m .61616 .40888 L .61885 .40616 L F
.462 .036 .143 r
.71827 .44122 m .72112 .44117 L .72178 .43917 L F
.572 .461 .688 r
.72178 .43917 m .72403 .43554 L .72114 .43677 L F
.72178 .43917 m .72452 .43847 L .72403 .43554 L F
.182 0 .051 r
.72178 .43917 m .72336 .4402 L .72452 .43847 L F
.72178 .43917 m .72112 .44117 L .72336 .4402 L F
.209 .714 .903 r
.39482 .63041 m .39716 .63034 L .3986 .63072 L F
.096 .581 .905 r
.39907 .6302 m .3986 .63072 L .39716 .63034 L F
.361 .304 .658 r
.38942 .62061 m .38706 .6229 L .38699 .61833 L F
.271 .293 .7 r
.38942 .62061 m .38843 .62412 L .38706 .6229 L F
.935 .697 .555 r
.55259 .67082 m .5538 .67461 L .55431 .67191 L F
.797 .551 .565 r
.52793 .56301 m .52439 .56003 L .52761 .56056 L F
.602 .48 .686 r
.53017 .55997 m .52793 .56301 L .52761 .56056 L F
.037 0 0 r
.4095 .6405 m .40804 .64096 L .40563 .64119 L F
.325 0 0 r
.41186 .64117 m .40804 .64096 L .4095 .6405 L F
.435 .252 .532 r
.7232 .42997 m .72519 .42736 L .7233 .42872 L F
.7232 .42997 m .72543 .43013 L .72519 .42736 L F
.587 .555 .786 r
.7232 .42997 m .7264 .43352 L .72543 .43013 L F
.302 .114 .451 r
.2552 .56576 m .25489 .56828 L .2532 .56885 L F
.672 .77 .924 r
.53917 .68655 m .54324 .68729 L .54167 .68642 L F
.634 .891 .986 r
.6705 .4009 m .66719 .40106 L .66944 .39967 L F
.487 .755 .989 r
.66944 .39967 m .6729 .40064 L .6705 .4009 L F
.995 .784 .508 r
.21445 .58942 m .21326 .58858 L .21358 .58605 L F
.991 .824 .577 r
.21445 .58942 m .2126 .59099 L .21326 .58858 L F
0 0 0 r
.64016 .4323 m .63843 .43627 L .64104 .43608 L F
.599 .951 .874 r
.4219 .57156 m .41999 .57278 L .41789 .57317 L F
.548 .641 .895 r
.74733 .43245 m .74482 .43327 L .74359 .43107 L F
0 0 .393 r
.74733 .43245 m .74791 .43521 L .74482 .43327 L F
.512 .312 .546 r
.24979 .58841 m .24828 .5867 L .25024 .58626 L F
.24979 .58841 m .24808 .58948 L .24828 .5867 L F
.205 0 .311 r
.60746 .46539 m .60609 .4665 L .60514 .46861 L F
.151 0 .35 r
.22458 .57761 m .22588 .57694 L .2264 .57458 L F
.542 .395 .631 r
.22395 .58014 m .22588 .57694 L .22458 .57761 L F
.761 .972 .924 r
.64353 .44669 m .64148 .4484 L .64226 .44642 L F
.97 .742 .538 r
.64148 .4484 m .63968 .44964 L .64226 .44642 L F
.64148 .4484 m .64111 .45103 L .63968 .44964 L F
.015 0 0 r
.397 .58141 m .39747 .5819 L .39935 .58091 L F
.397 .58141 m .39522 .58245 L .39747 .5819 L F
.401 0 0 r
.4008 .64194 m .39967 .6422 L .39759 .64169 L F
.361 0 0 r
.40316 .64137 m .39967 .6422 L .4008 .64194 L F
.499 .53 .82 r
.35854 .61611 m .35916 .61223 L .35736 .61244 L F
.35854 .61611 m .36038 .61567 L .35916 .61223 L F
.427 .634 .942 r
.2501 .5487 m .24914 .55036 L .24762 .54869 L F
.2501 .5487 m .25125 .55038 L .24914 .55036 L F
.751 .497 .548 r
.59319 .483 m .59318 .48064 L .58973 .48035 L F
.684 .446 .556 r
.5958 .483 m .59318 .48064 L .59319 .483 L F
.5958 .483 m .59575 .48061 L .59318 .48064 L F
.704 .561 .69 r
.43237 .63061 m .43425 .63013 L .43474 .62783 L F
.803 .343 .142 r
.54714 .66616 m .54689 .66794 L .54409 .66481 L F
.932 .754 .638 r
.54489 .66692 m .54612 .67015 L .54454 .66888 L F
.645 .35 .457 r
.54454 .66888 m .54612 .67015 L .54489 .66692 L F
.54454 .66888 m .54689 .66794 L .54612 .67015 L F
.54454 .66888 m .54648 .66812 L .54689 .66794 L F
.932 .586 .152 r
.5478 .66864 m .54689 .66794 L .54754 .66766 L F
.645 .35 .457 r
.54648 .66812 m .54901 .66712 L .54689 .66794 L F
.932 .586 .152 r
.54754 .66766 m .54689 .66794 L .54714 .66616 L F
.436 .243 .519 r
.40463 .63093 m .40457 .63334 L .40685 .63242 L F
.463 .685 .962 r
.68165 .40909 m .68287 .40744 L .68056 .40772 L F
.68165 .40909 m .68397 .40901 L .68287 .40744 L F
.685 .98 .862 r
.54288 .67659 m .54562 .67461 L .54605 .6749 L F
.389 .719 .988 r
.54753 .67134 m .54605 .6749 L .54562 .67461 L F
.515 0 0 r
.54605 .6749 m .54562 .67461 L .54562 .67461 L F
.791 .75 .815 r
.72543 .43013 m .7264 .43352 L .72892 .43029 L F
.449 .231 .49 r
.7264 .43352 m .72659 .43562 L .72892 .43461 L F
.02 0 0 r
.22863 .54323 m .23024 .54327 L .23216 .54332 L F
0 .271 .739 r
.23253 .54301 m .23216 .54332 L .23024 .54327 L F
.23253 .54301 m .23411 .54448 L .23216 .54332 L F
.695 .837 .951 r
.44597 .56625 m .44241 .56629 L .44458 .5652 L F
.664 .942 .963 r
.44827 .56522 m .44597 .56625 L .44682 .5647 L F
.525 .784 .992 r
.44682 .5647 m .44597 .56625 L .44458 .5652 L F
.125 0 .115 r
.70894 .45739 m .70723 .45688 L .70988 .45613 L F
.70894 .45739 m .70676 .45882 L .70723 .45688 L F
.296 0 .182 r
.60492 .4949 m .60662 .49614 L .60462 .49724 L F
.60492 .4949 m .60739 .49404 L .60662 .49614 L F
.598 .137 .13 r
.41558 .64006 m .41393 .64162 L .41186 .64117 L F
.572 .106 .11 r
.41775 .64149 m .41393 .64162 L .41558 .64006 L F
.526 .172 .311 r
.41916 .63902 m .41775 .64149 L .41558 .64006 L F
.503 .736 .978 r
.69133 .41219 m .69381 .41179 L .69258 .41014 L F
.46 .492 .804 r
.69133 .41219 m .69378 .41426 L .69381 .41179 L F
.69133 .41219 m .69477 .41565 L .69378 .41426 L F
.993 .753 .451 r
.58864 .62447 m .58989 .62562 L .58928 .62152 L F
.519 .733 .971 r
.45916 .57616 m .46071 .57756 L .46189 .57613 L F
.938 .681 .521 r
.55286 .62431 m .55074 .62405 L .55276 .62186 L F
.634 .963 .831 r
.55397 .6203 m .5553 .62004 L .55276 .62186 L F
.583 .853 .51 r
.55276 .62186 m .55074 .62405 L .55397 .6203 L F
.76 .496 .535 r
.55276 .62186 m .55628 .62502 L .55286 .62431 L F
.622 .572 .776 r
.71181 .42167 m .71547 .4246 L .71431 .42101 L F
.603 .614 .836 r
.71181 .42167 m .71302 .41763 L .71057 .41825 L F
.71181 .42167 m .71431 .42101 L .71302 .41763 L F
.781 .989 .752 r
.61563 .43746 m .61456 .43957 L .6174 .43662 L F
.991 .877 .546 r
.6174 .43662 m .61908 .43326 L .61913 .43563 L F
.617 .848 .987 r
.6153 .43588 m .6174 .43662 L .61913 .43563 L F
.871 .471 .271 r
.61563 .43746 m .6174 .43662 L .6153 .43588 L F
.85 .75 .752 r
.52875 .52708 m .52971 .53058 L .5279 .52933 L F
.804 .666 .711 r
.52971 .53058 m .52588 .53216 L .5279 .52933 L F
.52971 .53058 m .52769 .53355 L .52588 .53216 L F
.749 .587 .675 r
.52971 .53058 m .53169 .53406 L .52769 .53355 L F
.713 .575 .698 r
.53353 .53343 m .53169 .53406 L .52971 .53058 L F
.568 .365 .566 r
.25651 .55632 m .25359 .56022 L .2537 .55821 L F
.271 .293 .7 r
.38942 .62061 m .38981 .62408 L .38843 .62412 L F
.484 .32 .583 r
.25194 .58546 m .25029 .58394 L .2524 .58334 L F
.25194 .58546 m .25024 .58626 L .25029 .58394 L F
.698 .53 .656 r
.53353 .53343 m .53128 .53642 L .53169 .53406 L F
.713 .712 .847 r
.44003 .56709 m .43832 .56686 L .43871 .56622 L F
.61 .85 .989 r
.44241 .56629 m .44003 .56709 L .43871 .56622 L F
.44241 .56629 m .43871 .56622 L .44112 .56547 L F
0 0 0 r
.43916 .56608 m .43955 .5648 L .44112 .56547 L F
.43871 .56622 m .43955 .5648 L .43916 .56608 L F
0 .124 .669 r
.43973 .56313 m .43994 .56354 L .43955 .5648 L F
.481 0 0 r
.43955 .5648 m .4432 .56423 L .44112 .56547 L F
.677 .902 .976 r
.44458 .5652 m .44241 .56629 L .44112 .56547 L F
.44458 .5652 m .44112 .56547 L .4432 .56423 L F
.481 0 0 r
.43955 .5648 m .44116 .56599 L .4432 .56423 L F
0 .124 .669 r
.43994 .56354 m .44116 .56599 L .43955 .5648 L F
.713 .712 .847 r
.43832 .56686 m .43621 .56658 L .43871 .56622 L F
.458 .862 .965 r
.43621 .56658 m .43594 .5666 L .43476 .5658 L F
.43594 .5666 m .43172 .56686 L .43476 .5658 L F
.676 .921 .973 r
.43172 .56686 m .4334 .56489 L .43476 .5658 L F
.556 0 0 r
.43342 .5649 m .43476 .5658 L .4334 .56489 L F
.986 .815 .59 r
.43542 .56717 m .43416 .56716 L .43563 .56816 L F
.556 0 0 r
.43526 .56706 m .43476 .5658 L .43342 .5649 L F
.43532 .5671 m .43476 .5658 L .43526 .56706 L F
.596 .085 .007 r
.43476 .5658 m .43871 .56622 L .43621 .56658 L F
.43476 .5658 m .43832 .56834 L .43871 .56622 L F
.43832 .56834 m .43836 .56837 L .43837 .56835 L F
.43832 .56834 m .43837 .56835 L .43871 .56622 L F
.43836 .56837 m .43837 .56837 L .43871 .56622 L F
0 0 0 r
.43871 .56622 m .43837 .56835 L .43953 .56485 L F
.43837 .56835 m .43837 .56837 L .43839 .56831 L F
.43837 .56835 m .43839 .56831 L .43953 .56485 L F
.667 .7 .871 r
.43885 .56726 m .43921 .56849 L .44182 .56798 L F
0 0 0 r
.43837 .56837 m .43837 .56837 L .43953 .56485 L F
.43871 .56622 m .43953 .56485 L .43955 .5648 L F
.701 .711 .856 r
.43592 .56803 m .43829 .56836 L .43829 .56834 L F
.986 .815 .59 r
.43541 .56711 m .43532 .5671 L .43542 .56717 L F
.556 0 0 r
.43532 .5671 m .43688 .56731 L .43476 .5658 L F
.43545 .56713 m .43836 .56837 L .43688 .56731 L F
.827 .597 .59 r
.43955 .5648 m .43837 .56837 L .43681 .56763 L F
.43955 .5648 m .43681 .56763 L .43578 .56691 L F
.556 0 0 r
.43532 .56711 m .43688 .56731 L .43532 .5671 L F
.689 .66 .817 r
.43541 .56711 m .43669 .56768 L .43681 .56763 L F
.43605 .5671 m .43681 .56763 L .43807 .56707 L F
.43541 .56711 m .43681 .56763 L .43605 .5671 L F
.43541 .56711 m .43563 .56816 L .43669 .56768 L F
.556 0 0 r
.43532 .56711 m .43669 .56768 L .43545 .56713 L F
.827 .597 .59 r
.43556 .56704 m .43683 .56764 L .43534 .56716 L F
.556 0 0 r
.43669 .56768 m .43836 .56837 L .43545 .56713 L F
.701 .711 .856 r
.43669 .56768 m .43829 .56834 L .43807 .56707 L F
.43592 .56803 m .43829 .56834 L .43669 .56768 L F
.556 0 0 r
.43534 .56716 m .43837 .56838 L .43836 .56837 L F
.827 .597 .59 r
.43683 .56764 m .43837 .56838 L .43723 .56792 L F
.556 0 0 r
.43534 .56716 m .43836 .56837 L .43532 .56711 L F
.827 .597 .59 r
.43683 .56764 m .43723 .56792 L .43534 .56716 L F
.43578 .56691 m .43681 .56763 L .43556 .56704 L F
.43955 .5648 m .43578 .56691 L .43803 .56357 L F
.689 .66 .817 r
.4353 .56658 m .43541 .56711 L .43605 .5671 L F
.827 .597 .59 r
.43578 .56691 m .43534 .56716 L .43583 .56651 L F
.43578 .56691 m .43583 .56651 L .43629 .56589 L F
.43578 .56691 m .43629 .56589 L .43642 .56597 L F
.261 0 0 r
.43498 .56505 m .43803 .56357 L .43583 .56651 L F
.689 .66 .817 r
.43593 .56567 m .43583 .56651 L .43807 .56707 L F
.43583 .56651 m .43581 .56667 L .43594 .56669 L F
.43583 .56651 m .43594 .56669 L .43807 .56707 L F
.43498 .56505 m .4353 .56658 L .43581 .56667 L F
.986 .815 .59 r
.43498 .56505 m .43532 .5671 L .43541 .56711 L F
.261 0 0 r
.43498 .56505 m .43583 .56651 L .43534 .56716 L F
.689 .66 .817 r
.43593 .56567 m .43807 .56707 L .43531 .56528 L F
.43498 .56505 m .43581 .56667 L .43593 .56567 L F
.43531 .56528 m .43607 .56577 L .43584 .56566 L F
.43498 .56505 m .43593 .56567 L .43531 .56528 L F
0 .145 .684 r
.436 .56551 m .43631 .566 L .43614 .56557 L F
.43498 .56505 m .43613 .56587 L .436 .56551 L F
.43613 .56587 m .43631 .566 L .436 .56551 L F
.261 0 0 r
.43498 .56505 m .43589 .56545 L .43803 .56357 L F
.86 .779 .77 r
.43898 .56139 m .43593 .56529 L .43517 .56313 L F
0 .145 .684 r
.43498 .56505 m .43589 .56545 L .43517 .56313 L F
.43589 .56545 m .43614 .56557 L .43596 .56513 L F
.43589 .56545 m .43596 .56513 L .43517 .56313 L F
.805 .972 .671 r
.43803 .56357 m .43589 .56545 L .43898 .56139 L F
.261 0 0 r
.43498 .56505 m .43559 .56572 L .43589 .56545 L F
.805 .972 .671 r
.43589 .56545 m .43572 .5656 L .43591 .56536 L F
.43589 .56545 m .43591 .56536 L .43898 .56139 L F
.86 .779 .77 r
.43593 .56529 m .43559 .56572 L .43517 .56313 L F
.805 .972 .671 r
.43572 .5656 m .43559 .56572 L .43569 .56559 L F
.43572 .5656 m .43569 .56559 L .43898 .56139 L F
.181 .716 .776 r
.43873 .56558 m .43613 .56593 L .43631 .566 L F
.43613 .56593 m .43495 .56609 L .43631 .566 L F
.689 .66 .817 r
.43584 .56566 m .43646 .56605 L .43631 .566 L F
.43646 .56605 m .43807 .56707 L .43631 .566 L F
.43607 .56577 m .43807 .56707 L .43584 .56566 L F
.827 .597 .59 r
.43642 .56597 m .43629 .56589 L .43803 .56357 L F
.689 .66 .817 r
.4353 .56658 m .43605 .5671 L .43807 .56707 L F
.986 .815 .59 r
.43498 .56505 m .43526 .56706 L .43532 .5671 L F
.43442 .56649 m .43416 .56716 L .43542 .56717 L F
.556 0 0 r
.43534 .56716 m .43532 .5671 L .43526 .56706 L F
.011 .113 .625 r
.43498 .56505 m .43534 .56716 L .43526 .56706 L F
.43498 .56505 m .43526 .56706 L .4334 .56489 L F
.986 .815 .59 r
.43498 .56505 m .43442 .56649 L .43526 .56706 L F
.701 .711 .856 r
.43832 .56849 m .43837 .56837 L .43829 .56833 L F
.596 .085 .007 r
.43836 .56837 m .43837 .56838 L .43837 .56837 L F
.827 .597 .59 r
.43837 .56837 m .43837 .56838 L .43556 .56704 L F
.701 .711 .856 r
.43829 .56833 m .43863 .56777 L .43807 .56707 L F
.43837 .56837 m .43863 .56777 L .43829 .56833 L F
.667 .7 .871 r
.43807 .56707 m .43863 .56777 L .43885 .56726 L F
.43863 .56777 m .43921 .56849 L .43885 .56726 L F
.43921 .56849 m .4393 .56861 L .43955 .56855 L F
.43921 .56849 m .43955 .56855 L .44182 .56798 L F
.701 .711 .856 r
.43563 .56816 m .43832 .56849 L .43829 .56836 L F
.43563 .56816 m .43829 .56836 L .43592 .56803 L F
.43832 .56849 m .4393 .56861 L .43863 .56777 L F
0 0 0 r
.43837 .56837 m .43837 .56838 L .43837 .56837 L F
.201 .715 .885 r
.18837 .5411 m .19064 .54101 L .19214 .54126 L F
.177 .7 .874 r
.19064 .54101 m .19447 .54119 L .19214 .54126 L F
.467 .89 .819 r
.58233 .63543 m .57971 .63629 L .58131 .63713 L F
.57971 .63629 m .58233 .63543 L .58131 .63713 L F
.41 .119 .357 r
.59945 .50026 m .5998 .4985 L .6021 .49775 L F
.75 .926 .948 r
.56671 .64049 m .56753 .63839 L .56519 .63927 L F
.56671 .64049 m .56875 .63916 L .56753 .63839 L F
.584 .345 .52 r
.47916 .62151 m .48167 .62137 L .48183 .61902 L F
.517 .27 .479 r
.48167 .62137 m .48429 .6187 L .48183 .61902 L F
.682 .718 .876 r
.70212 .41889 m .70338 .41509 L .70106 .41834 L F
.70212 .41889 m .70459 .41809 L .70338 .41509 L F
.413 .495 .834 r
.3922 .62341 m .39179 .62683 L .38981 .62408 L F
.3922 .62341 m .39386 .62692 L .39179 .62683 L F
.797 .551 .565 r
.52793 .56301 m .52441 .56263 L .52439 .56003 L F
.632 .421 .579 r
.52793 .56301 m .52539 .56557 L .52441 .56263 L F
.52793 .56301 m .52794 .56548 L .52539 .56557 L F
.602 .48 .686 r
.53017 .55997 m .53019 .56273 L .52793 .56301 L F
.535 .344 .569 r
.53017 .56497 m .52793 .56301 L .53019 .56273 L F
.53017 .56497 m .52794 .56548 L .52793 .56301 L F
.572 .287 .444 r
.59821 .48246 m .59575 .48061 L .5958 .483 L F
.59821 .48246 m .59816 .48051 L .59575 .48061 L F
.722 .497 .584 r
.70125 .44717 m .70494 .44751 L .70492 .44527 L F
.61 .381 .544 r
.70494 .44751 m .70738 .44509 L .70492 .44527 L F
.997 .781 .481 r
.67258 .41227 m .67188 .40932 L .66934 .41219 L F
.357 .015 .24 r
.67258 .41227 m .67466 .41372 L .67588 .41077 L F
.606 .638 .856 r
.70102 .405 m .69944 .40729 L .6989 .40592 L F
.70102 .405 m .70201 .40665 L .69944 .40729 L F
.361 .304 .658 r
.38942 .62061 m .38699 .61833 L .38872 .61811 L F
.778 .527 .556 r
.71824 .45109 m .71832 .45345 L .7148 .45298 L F
.539 .34 .559 r
.71824 .45109 m .72087 .45292 L .71832 .45345 L F
.604 .305 .435 r
.72112 .45102 m .72087 .45292 L .71824 .45109 L F
.261 .727 .947 r
.21298 .55341 m .21125 .5528 L .20925 .5529 L F
0 .542 .749 r
.21509 .55329 m .21125 .5528 L .21298 .55341 L F
.681 .513 .653 r
.53169 .53406 m .52766 .53621 L .52769 .53355 L F
.53169 .53406 m .53128 .53642 L .52766 .53621 L F
.599 .916 .976 r
.42902 .57662 m .42767 .57621 L .42674 .57764 L F
.42902 .57662 m .42767 .57621 L .42674 .57764 L F
.629 .663 .864 r
.42674 .57764 m .4303 .57821 L .42902 .57662 L F
.42674 .57764 m .4303 .57821 L .42902 .57662 L F
.534 .685 .936 r
.68789 .40141 m .68646 .40324 L .68469 .40121 L F
.68789 .40141 m .68882 .40288 L .68646 .40324 L F
.911 .802 .726 r
.6444 .41508 m .64578 .41241 L .64373 .41192 L F
.289 .788 .846 r
.17704 .55773 m .17508 .55773 L .17257 .5583 L F
.066 0 0 r
.1791 .55701 m .17508 .55773 L .17704 .55773 L F
.549 .327 .531 r
.40082 .59942 m .39778 .59816 L .40049 .59764 L F
.40082 .59942 m .39714 .60081 L .39778 .59816 L F
.841 .929 .546 r
.20163 .65976 m .20014 .66174 L .20008 .66309 L F
.973 .741 .526 r
.19866 .66314 m .20008 .66309 L .20014 .66174 L F
.19866 .66314 m .20036 .66571 L .20008 .66309 L F
0 0 0 r
.36716 .62778 m .36545 .62833 L .36368 .62875 L F
.633 .959 .805 r
.36668 .62724 m .36716 .62778 L .36917 .62847 L F
.36668 .62724 m .36545 .62833 L .36716 .62778 L F
.91 .947 .813 r
.55003 .49532 m .5513 .49134 L .55255 .49249 L F
.55003 .49532 m .54996 .49272 L .5513 .49134 L F
.914 .948 .808 r
.54787 .49601 m .54996 .49272 L .55003 .49532 L F
.921 .939 .798 r
.54787 .49601 m .55003 .49532 L .54788 .49851 L F
.608 .857 .501 r
.62184 .48265 m .62246 .48205 L .62378 .48023 L F
0 0 0 r
.61957 .48427 m .62246 .48205 L .6213 .48332 L F
.608 .857 .501 r
.6213 .48332 m .62246 .48205 L .62184 .48265 L F
0 0 0 r
.62074 .48318 m .62308 .48146 L .62246 .48205 L F
.62308 .48146 m .62379 .48094 L .62246 .48205 L F
.61957 .48427 m .62074 .48318 L .62246 .48205 L F
.484 .244 .473 r
.74238 .43625 m .74255 .43857 L .73997 .4393 L F
.376 .166 .462 r
.74466 .43735 m .74238 .43625 L .74791 .43521 L F
.74466 .43735 m .74255 .43857 L .74238 .43625 L F
.865 .816 .799 r
.60363 .43068 m .59983 .43244 L .6022 .42942 L F
.60363 .43068 m .60134 .43397 L .59983 .43244 L F
.845 .852 .849 r
.60605 .42803 m .60363 .43068 L .6022 .42942 L F
.916 .818 .735 r
.59221 .47518 m .59289 .47041 L .59065 .47392 L F
.351 .451 .823 r
.37845 .63608 m .38011 .63628 L .37851 .63255 L F
.542 .179 .301 r
.43475 .63186 m .43425 .63013 L .43237 .63061 L F
.657 .27 .299 r
.42863 .63066 m .43102 .63273 L .43237 .63061 L F
.129 0 0 r
.43102 .63273 m .43475 .63186 L .43237 .63061 L F
.916 .723 .628 r
.61031 .43249 m .61305 .4334 L .61168 .42981 L F
.793 .546 .565 r
.60948 .4352 m .61305 .4334 L .61031 .43249 L F
.60948 .4352 m .61315 .43579 L .61305 .4334 L F
.594 .335 .495 r
.61315 .43579 m .61565 .4336 L .61305 .4334 L F
.349 0 .209 r
.42005 .64088 m .41916 .63902 L .42188 .63891 L F
.42005 .64088 m .41775 .64149 L .41916 .63902 L F
.699 .558 .691 r
.53094 .5387 m .53251 .54232 L .52895 .54244 L F
.736 .646 .76 r
.52766 .53621 m .52525 .53656 L .52769 .53355 L F
.891 .988 .739 r
.64437 .42163 m .64241 .42457 L .6424 .4228 L F
0 0 .123 r
.6424 .4228 m .64241 .42457 L .64265 .42696 L F
0 .246 .759 r
.62532 .45502 m .62623 .45658 L .62529 .45614 L F
.704 .617 .757 r
.72156 .42478 m .7233 .42872 L .72519 .42736 L F
.448 .171 .399 r
.19562 .63573 m .19816 .63296 L .19666 .63338 L F
.568 .365 .566 r
.25651 .55632 m .25637 .56137 L .25359 .56022 L F
.461 .474 .785 r
.25742 .5528 m .25852 .55638 L .25651 .55632 L F
.081 0 .43 r
.25771 .5567 m .25651 .55632 L .25852 .55638 L F
.25771 .5567 m .25637 .56137 L .25651 .55632 L F
.332 0 0 r
.45035 .56563 m .45512 .56789 L .45151 .56639 L F
.574 .294 .453 r
.56212 .52168 m .56433 .52367 L .56111 .52418 L F
.56212 .52168 m .5647 .52129 L .56433 .52367 L F
.661 .665 .843 r
.67383 .45924 m .67718 .46019 L .67668 .45766 L F
.572 .604 .846 r
.67668 .45766 m .67718 .46019 L .67945 .45898 L F
.898 .743 .681 r
.51863 .56026 m .51827 .56267 L .51682 .55921 L F
.357 .425 .795 r
.56613 .62829 m .5687 .62936 L .56655 .63084 L F
.516 .779 .992 r
.5687 .62936 m .57076 .62982 L .56655 .63084 L F
.691 .238 .172 r
.21999 .57963 m .22395 .58014 L .22186 .5807 L F
.332 .716 .983 r
.36205 .6289 m .36152 .6278 L .35961 .62778 L F
.36205 .6289 m .36368 .62875 L .36152 .6278 L F
.059 0 0 r
.52898 .69563 m .52706 .69734 L .52611 .69792 L F
0 0 0 r
.53085 .69459 m .52706 .69734 L .52898 .69563 L F
.44 .307 .603 r
.35575 .60429 m .35776 .6039 L .35744 .60104 L F
.462 .4 .702 r
.35575 .60429 m .3583 .60628 L .35776 .6039 L F
.512 .397 .659 r
.35616 .60678 m .3583 .60628 L .35575 .60429 L F
.423 .276 .575 r
.35777 .59805 m .35973 .60002 L .35954 .59751 L F
.35777 .59805 m .35744 .60104 L .35973 .60002 L F
.646 .521 .697 r
.53612 .54772 m .53723 .55096 L .53402 .55054 L F
.562 .48 .72 r
.53741 .55351 m .53402 .55054 L .53723 .55096 L F
.53741 .55351 m .53503 .55408 L .53402 .55054 L F
.933 .832 .722 r
.59598 .46119 m .59795 .46047 L .59682 .45949 L F
.919 .908 .794 r
.59795 .46047 m .59912 .45626 L .59682 .45949 L F
.652 .695 .877 r
.69983 .4142 m .70106 .41834 L .70338 .41509 L F
.791 .294 0 r
.68554 .46128 m .68401 .45917 L .6824 .45865 L F
.855 .934 .876 r
.60134 .43397 m .59805 .43558 L .59983 .43244 L F
.889 .787 .742 r
.54223 .50662 m .5388 .50846 L .54114 .50552 L F
.54223 .50662 m .54049 .50967 L .5388 .50846 L F
.9 .93 .827 r
.54468 .50329 m .54223 .50662 L .54114 .50552 L F
.616 .587 .798 r
.46671 .57487 m .46982 .57543 L .46949 .57438 L F
.446 0 0 r
.46535 .57174 m .46599 .57353 L .46989 .57339 L F
.46599 .57353 m .46683 .57373 L .46989 .57339 L F
.684 .951 .955 r
.46989 .57339 m .46609 .57382 L .46888 .57241 L F
.616 .587 .798 r
.46756 .57391 m .46949 .57438 L .46888 .57241 L F
.46671 .57487 m .46949 .57438 L .46756 .57391 L F
.446 0 0 r
.46599 .57353 m .46609 .57382 L .46683 .57373 L F
.46535 .57174 m .4633 .57404 L .46609 .57382 L F
.635 .13 0 r
.67364 .43429 m .67384 .43416 L .67276 .43372 L F
.67364 .43429 m .67503 .43551 L .67384 .43416 L F
.567 .182 .272 r
.43968 .63641 m .43587 .63846 L .43634 .63711 L F
.43968 .63641 m .43826 .63867 L .43587 .63846 L F
.591 .209 .287 r
.44211 .63806 m .43826 .63867 L .43968 .63641 L F
.47 .245 .489 r
.23944 .60642 m .23937 .60938 L .23713 .60969 L F
.377 .19 .496 r
.24178 .60382 m .24155 .6062 L .23944 .60642 L F
.357 .157 .466 r
.24132 .60864 m .23944 .60642 L .24155 .6062 L F
.24132 .60864 m .23937 .60938 L .23944 .60642 L F
.647 .628 .817 r
.71547 .4246 m .71681 .42035 L .71431 .42101 L F
.71547 .4246 m .71802 .42381 L .71681 .42035 L F
.805 .864 .892 r
.6195 .46283 m .6152 .46423 L .61836 .46188 L F
.121 0 0 r
.20648 .54165 m .20864 .54179 L .21031 .54173 L F
0 0 0 r
.20864 .54179 m .21249 .54147 L .21031 .54173 L F
.888 .895 .829 r
.54438 .5004 m .54788 .49851 L .54565 .50135 L F
.54438 .5004 m .5466 .4975 L .54788 .49851 L F
.921 .939 .798 r
.54787 .49601 m .54788 .49851 L .5466 .4975 L F
.319 .208 .566 r
.21426 .601 m .21579 .60302 L .21559 .60036 L F
.21426 .601 m .21403 .60401 L .21579 .60302 L F
.309 .506 .886 r
.52806 .67053 m .52707 .67227 L .52975 .67226 L F
0 0 0 r
.69355 .46443 m .69217 .46499 L .69036 .46528 L F
.69036 .46528 m .69217 .46499 L .68996 .46564 L F
.417 .755 .995 r
.67784 .40008 m .67646 .40124 L .6753 .4005 L F
.67784 .40008 m .67897 .4011 L .67646 .40124 L F
.891 .988 .739 r
.64437 .42163 m .6424 .4228 L .64389 .42059 L F
.961 .897 .718 r
.64482 .41756 m .64437 .42163 L .64389 .42059 L F
.258 0 .227 r
.7314 .4438 m .73173 .44243 L .73393 .44142 L F
.644 .598 .788 r
.56373 .63 m .56017 .62742 L .56228 .62758 L F
.547 .789 .988 r
.56228 .62758 m .56613 .62829 L .56373 .63 L F
.712 .638 .773 r
.52752 .55059 m .52506 .55322 L .52545 .5502 L F
.045 0 .112 r
.21648 .64493 m .21404 .64783 L .215 .64586 L F
.662 .941 .68 r
.62379 .48094 m .62524 .47933 L .62512 .47914 L F
.636 .903 .593 r
.62246 .48205 m .62379 .48094 L .62512 .47914 L F
0 0 0 r
.21404 .64783 m .21137 .65059 L .2125 .64882 L F
.755 .882 .937 r
.61063 .44053 m .61456 .43957 L .61364 .43905 L F
.766 .984 .906 r
.61364 .43905 m .61456 .43957 L .61563 .43746 L F
.929 .877 .763 r
.54438 .5004 m .54565 .50135 L .54468 .50329 L F
.587 .389 .581 r
.5435 .54106 m .54104 .53932 L .54353 .53907 L F
.5435 .54106 m .54094 .54158 L .54104 .53932 L F
.382 .155 .441 r
.23217 .62353 m .2308 .62184 L .23252 .62117 L F
.23217 .62353 m .23033 .62418 L .2308 .62184 L F
.9 .901 .818 r
.55697 .4863 m .55358 .48832 L .55598 .4854 L F
.55697 .4863 m .55477 .48936 L .55358 .48832 L F
.909 .939 .816 r
.55697 .4863 m .5591 .48182 L .55944 .48333 L F
.55697 .4863 m .55598 .4854 L .5591 .48182 L F
.164 0 .119 r
.20743 .65444 m .20621 .65647 L .20456 .65706 L F
0 0 0 r
.20894 .65335 m .20621 .65647 L .20743 .65444 L F
.198 0 0 r
.52977 .70347 m .53341 .7013 L .5333 .70409 L F
.36 0 0 r
.53341 .7013 m .53239 .70299 L .53473 .70243 L F
.735 .311 .243 r
.5333 .70409 m .53222 .70521 L .52977 .70347 L F
.746 .688 .796 r
.53147 .70338 m .53222 .70521 L .53401 .70232 L F
.36 0 0 r
.53239 .70299 m .53231 .70314 L .53473 .70243 L F
.746 .688 .796 r
.53401 .70232 m .53381 .70265 L .53473 .70243 L F
.53381 .70265 m .53222 .70521 L .53473 .70243 L F
.198 0 0 r
.52977 .70347 m .53193 .70319 L .53341 .7013 L F
.53193 .70319 m .53239 .70299 L .53341 .7013 L F
.746 .688 .796 r
.53083 .70183 m .53147 .70338 L .53401 .70232 L F
.198 0 0 r
.53193 .70319 m .53231 .70314 L .53239 .70299 L F
.058 0 0 r
.53341 .7013 m .53516 .7012 L .53612 .6996 L F
.36 0 0 r
.53341 .7013 m .53473 .70243 L .53516 .7012 L F
.472 .461 .764 r
.20269 .62009 m .20453 .62252 L .20425 .62089 L F
0 0 0 r
.21137 .65059 m .20894 .65335 L .21011 .65176 L F
.68 .914 .974 r
.65096 .4546 m .65439 .45399 L .65317 .45278 L F
.869 .876 .839 r
.65317 .45278 m .65439 .45399 L .65685 .45101 L F
.897 .891 .816 r
.55477 .48936 m .55255 .49249 L .5513 .49134 L F
.55477 .48936 m .5513 .49134 L .55358 .48832 L F
.224 0 0 r
.2059 .61153 m .20918 .60965 L .20674 .61079 L F
.596 .613 .839 r
.44248 .57994 m .43883 .57755 L .4414 .57699 L F
0 0 0 r
.44248 .57994 m .44146 .58029 L .43884 .58078 L F
.704 .165 0 r
.4414 .57699 m .44493 .57925 L .44248 .57994 L F
.078 .314 .794 r
.44248 .57994 m .44319 .57882 L .44146 .58029 L F
.44248 .57994 m .44491 .5817 L .44319 .57882 L F
.341 .692 .981 r
.24575 .54733 m .24538 .54858 L .24398 .54684 L F
.24575 .54733 m .24762 .54869 L .24538 .54858 L F
0 0 .362 r
.62186 .45455 m .62057 .45393 L .62262 .45258 L F
.463 .032 .134 r
.39743 .60248 m .39485 .60216 L .39714 .60081 L F
.39743 .60248 m .39433 .6033 L .39485 .60216 L F
.627 .844 .983 r
.74579 .41392 m .74429 .41582 L .7432 .41429 L F
.74579 .41392 m .74705 .4154 L .74429 .41582 L F
.742 .592 .689 r
.54397 .68148 m .54738 .68341 L .54617 .681 L F
.54397 .68148 m .5453 .68403 L .54738 .68341 L F
.561 .751 .966 r
.54904 .68234 m .54617 .681 L .54738 .68341 L F
.973 .812 .623 r
.65322 .43205 m .65523 .43027 L .65388 .42907 L F
.65322 .43205 m .65452 .43318 L .65523 .43027 L F
.416 .178 .443 r
.2317 .56887 m .23317 .57059 L .23326 .56806 L F
.2317 .56887 m .2311 .57127 L .23317 .57059 L F
.332 0 .152 r
.70435 .45978 m .70132 .46155 L .70204 .46038 L F
.987 .713 .372 r
.68397 .40901 m .68488 .41128 L .68406 .41147 L F
.553 .592 .847 r
.68397 .40901 m .68488 .41128 L .68715 .41085 L F
.677 .33 .38 r
.4106 .63191 m .41286 .63295 L .41062 .6307 L F
.598 .344 .504 r
.41062 .6307 m .41286 .63295 L .41309 .63072 L F
.605 .32 .458 r
.55068 .52784 m .55212 .52978 L .55038 .52976 L F
.55068 .52784 m .55404 .52726 L .55212 .52978 L F
.649 .688 .873 r
.70459 .41809 m .70811 .41903 L .7072 .41736 L F
.631 .685 .882 r
.70811 .41903 m .7101 .4168 L .7072 .41736 L F
.70811 .41903 m .71057 .41825 L .7101 .4168 L F
.669 .495 .64 r
.59816 .48051 m .60105 .47945 L .60063 .477 L F
0 0 0 r
.60354 .47368 m .60063 .477 L .60264 .47696 L F
.512 .365 .618 r
.60105 .47945 m .60264 .47696 L .60063 .477 L F
.88 .85 .81 r
.54339 .50194 m .54438 .5004 L .54468 .50329 L F
.9 .93 .827 r
.54468 .50329 m .54114 .50552 L .54339 .50194 L F
.406 .734 .991 r
.43154 .58503 m .43436 .5866 L .43163 .58673 L F
.43154 .58503 m .43436 .5866 L .43163 .58673 L F
.687 .42 .514 r
.5296 .68623 m .53092 .68441 L .52619 .68436 L F
.513 .287 .509 r
.53503 .55408 m .53495 .55655 L .53249 .55697 L F
.564 .329 .517 r
.53744 .55592 m .53503 .55408 L .53741 .55351 L F
.53744 .55592 m .53495 .55655 L .53503 .55408 L F
.845 .852 .849 r
.60605 .42803 m .6022 .42942 L .60467 .42656 L F
.82 .841 .864 r
.60798 .4262 m .60605 .42803 L .60467 .42656 L F
.697 .898 .969 r
.67253 .45812 m .67383 .45924 L .67668 .45766 L F
.78 .682 .756 r
.52525 .53656 m .52115 .53866 L .52359 .5351 L F
.52525 .53656 m .52294 .53928 L .52115 .53866 L F
.794 .74 .803 r
.52769 .53355 m .52525 .53656 L .52359 .5351 L F
.899 .847 .784 r
.56381 .47711 m .56043 .47915 L .56307 .47639 L F
.56381 .47711 m .56184 .48036 L .56043 .47915 L F
.846 .985 .863 r
.56381 .47711 m .56584 .47366 L .56622 .47405 L F
.56381 .47711 m .56307 .47639 L .56584 .47366 L F
.284 .493 .885 r
.56132 .626 m .56017 .62742 L .55861 .62475 L F
.328 .559 .92 r
.56132 .626 m .56228 .62758 L .56017 .62742 L F
.624 .816 .974 r
.5259 .68584 m .52736 .68711 L .5296 .68623 L F
.641 .47 .637 r
.48741 .61785 m .48985 .61559 L .4868 .61574 L F
.441 .14 .358 r
.7364 .43917 m .73393 .44142 L .73388 .4392 L F
.617 .339 .473 r
.53917 .68655 m .54167 .68642 L .54237 .68471 L F
.821 .818 .846 r
.54167 .68642 m .5453 .68403 L .54237 .68471 L F
.444 .54 .86 r
.55305 .63492 m .55428 .63303 L .55167 .63347 L F
.55305 .63492 m .5554 .63582 L .55428 .63303 L F
.88 .738 .701 r
.51682 .55921 m .51827 .56267 L .51537 .56173 L F
.967 .754 .563 r
.51659 .56501 m .51537 .56173 L .51827 .56267 L F
.698 .469 .573 r
.51827 .56267 m .52079 .56364 L .51659 .56501 L F
.653 .519 .688 r
.52205 .56333 m .52079 .56364 L .51827 .56267 L F
0 .497 .777 r
.44682 .5647 m .45035 .56563 L .44827 .56522 L F
0 0 0 r
.42996 .58018 m .42955 .5803 L .42661 .58077 L F
0 .121 .646 r
.4305 .57727 m .42996 .58018 L .42902 .57662 L F
.71 .584 .712 r
.43285 .57765 m .42996 .58018 L .4303 .57821 L F
.853 .901 .485 r
.4305 .57727 m .42955 .5803 L .42996 .58018 L F
.71 .584 .712 r
.43285 .57765 m .42996 .58018 L .4303 .57821 L F
.244 .73 .926 r
.2004 .54086 m .20276 .54078 L .20431 .54119 L F
0 .482 .745 r
.20276 .54078 m .20648 .54165 L .20431 .54119 L F
.454 .168 .388 r
.46797 .62718 m .46995 .62924 L .47042 .62684 L F
.46797 .62718 m .46753 .62967 L .46995 .62924 L F
.967 .646 .332 r
.67287 .45247 m .67386 .45104 L .67271 .44969 L F
.67287 .45247 m .67428 .45348 L .67386 .45104 L F
0 0 0 r
.229 .57187 m .2264 .57458 L .22783 .57346 L F
.207 0 .034 r
.22783 .57346 m .2311 .57127 L .229 .57187 L F
.328 0 0 r
.42258 .62962 m .42488 .63012 L .42611 .63013 L F
.372 0 0 r
.42488 .63012 m .42863 .63066 L .42611 .63013 L F
.495 .305 .553 r
.25459 .58198 m .25302 .58037 L .25434 .57957 L F
.25459 .58198 m .2524 .58334 L .25302 .58037 L F
.721 .771 .893 r
.73355 .41179 m .73717 .41229 L .73463 .41328 L F
.848 .714 .714 r
.49236 .61525 m .49368 .61866 L .49485 .61577 L F
.724 .69 .817 r
.42902 .57662 m .43285 .57765 L .43108 .57582 L F
.42902 .57662 m .4303 .57821 L .43285 .57765 L F
.598 .197 .254 r
.48248 .62537 m .48601 .62468 L .48521 .62651 L F
.35 0 .146 r
.48521 .62651 m .48601 .62468 L .48863 .62386 L F
.375 .731 .99 r
.46294 .57934 m .46445 .58027 L .46468 .57917 L F
.549 0 0 r
.46445 .58027 m .46513 .58163 L .46468 .57917 L F
.944 .625 .401 r
.65452 .43318 m .65484 .43535 L .65649 .43623 L F
.951 .676 .48 r
.65484 .43535 m .65507 .43734 L .65649 .43623 L F
.889 .546 .392 r
.65507 .43734 m .65711 .43858 L .65649 .43623 L F
.629 .568 .767 r
.53616 .54525 m .53251 .54232 L .53665 .54351 L F
.646 .464 .622 r
.61522 .41559 m .61373 .4192 L .61584 .41877 L F
.676 .749 .906 r
.61584 .41877 m .61373 .4192 L .6155 .41835 L F
.973 .669 .374 r
.6155 .41835 m .61584 .41877 L .61551 .41839 L F
.61522 .41559 m .61584 .41877 L .6155 .41835 L F
.676 .749 .906 r
.61584 .41877 m .6155 .41835 L .61769 .4173 L F
.512 .319 .555 r
.61769 .4173 m .6155 .41835 L .61522 .41559 L F
.6155 .41835 m .61373 .4192 L .61522 .41559 L F
.973 .669 .374 r
.61522 .41559 m .61551 .41839 L .61408 .41676 L F
.648 .154 .062 r
.61408 .41676 m .61769 .4173 L .61522 .41559 L F
.689 .458 .567 r
.61913 .43563 m .61908 .43326 L .61565 .4336 L F
.61 .381 .544 r
.70494 .44751 m .70758 .44742 L .70738 .44509 L F
.364 .161 .466 r
.47235 .57761 m .47225 .57974 L .47008 .5804 L F
.544 .106 .158 r
.47193 .58182 m .47008 .5804 L .47225 .57974 L F
.47193 .58182 m .4688 .58219 L .47008 .5804 L F
.621 .261 .339 r
.41374 .58987 m .41398 .59248 L .41006 .59157 L F
.567 .222 .343 r
.41701 .59171 m .41398 .59248 L .41374 .58987 L F
.564 .227 .357 r
.41687 .58964 m .41701 .59171 L .41374 .58987 L F
.242 .182 .587 r
.68406 .41147 m .6824 .4157 L .6815 .41219 L F
.51 .378 .637 r
.6871 .41368 m .6844 .41463 L .68406 .41147 L F
.408 .859 .878 r
.68567 .41402 m .6844 .41463 L .6871 .41368 L F
.242 .182 .587 r
.68406 .41147 m .6844 .41463 L .68245 .41557 L F
.408 .859 .878 r
.6821 .41487 m .6844 .41463 L .68567 .41402 L F
.242 .182 .587 r
.68245 .41557 m .6844 .41463 L .6824 .4157 L F
.613 .557 .768 r
.68419 .41761 m .68546 .4188 L .68523 .41794 L F
.863 .908 .861 r
.6844 .41463 m .68352 .41693 L .6824 .4157 L F
.68352 .41693 m .68327 .41758 L .68249 .41589 L F
.68352 .41693 m .68249 .41589 L .6824 .4157 L F
.6844 .41463 m .68186 .41688 L .68327 .41758 L F
.613 .557 .768 r
.68186 .41688 m .68523 .41794 L .68327 .41758 L F
.68186 .41688 m .68524 .41869 L .68419 .41761 L F
.68524 .41869 m .68546 .4188 L .68419 .41761 L F
.623 .65 .856 r
.70567 .40916 m .70201 .40665 L .7045 .40579 L F
.669 .666 .838 r
.70819 .40719 m .70567 .40916 L .7045 .40579 L F
.643 .613 .805 r
.70819 .40719 m .70905 .40949 L .70567 .40916 L F
.801 .968 .66 r
.58239 .45284 m .58148 .45429 L .58218 .45241 L F
.897 .987 .754 r
.58054 .4562 m .58218 .45241 L .58148 .45429 L F
.704 .617 .757 r
.72156 .42478 m .72519 .42736 L .72402 .42383 L F
.577 .57 .809 r
.72402 .42383 m .72519 .42736 L .72765 .42669 L F
.536 .325 .54 r
.72519 .42736 m .7276 .42892 L .72765 .42669 L F
.72519 .42736 m .72543 .43013 L .7276 .42892 L F
.739 .564 .657 r
.57073 .51874 m .56967 .52006 L .56712 .52152 L F
.6 .42 .61 r
.57348 .5163 m .57328 .51803 L .57073 .51874 L F
.552 .3 .487 r
.57073 .51874 m .57284 .5199 L .56967 .52006 L F
.57073 .51874 m .57328 .51803 L .57284 .5199 L F
.224 0 0 r
.2059 .61153 m .20824 .61104 L .20918 .60965 L F
.611 .337 .477 r
.20824 .61104 m .21123 .60925 L .20918 .60965 L F
0 0 .123 r
.21847 .64167 m .21648 .64493 L .21731 .6427 L F
.869 .876 .839 r
.65317 .45278 m .65685 .45101 L .6559 .44994 L F
.998 .835 .546 r
.65618 .44713 m .6559 .44994 L .65685 .45101 L F
.885 .69 .634 r
.53784 .51268 m .53453 .51463 L .5364 .51147 L F
.53784 .51268 m .53784 .51489 L .53453 .51463 L F
.823 .811 .839 r
.5388 .50846 m .53784 .51268 L .5364 .51147 L F
.5388 .50846 m .54049 .50967 L .53784 .51268 L F
.284 0 0 r
.18273 .5411 m .18069 .54171 L .18462 .54126 L F
.782 .866 .911 r
.62492 .40348 m .62269 .40477 L .62165 .40373 L F
.791 .672 .733 r
.18916 .64195 m .19224 .64231 L .19092 .6391 L F
.601 .469 .673 r
.19224 .64231 m .19402 .63949 L .19092 .6391 L F
.19224 .64231 m .19464 .64209 L .19402 .63949 L F
.523 .873 .626 r
.19224 .64231 m .19175 .64247 L .19464 .64209 L F
.601 .412 .597 r
.50461 .71018 m .50781 .70715 L .50378 .70709 L F
.50461 .71018 m .50737 .71037 L .50781 .70715 L F
.451 0 0 r
.50461 .71018 m .50737 .71037 L .50588 .7111 L F
.601 .412 .597 r
.50781 .70715 m .50737 .71037 L .50461 .71018 L F
.451 0 0 r
.50461 .71018 m .50737 .71037 L .50588 .7111 L F
.868 .868 .835 r
.56184 .48036 m .55944 .48333 L .5591 .48182 L F
.761 .376 .325 r
.53885 .66196 m .54031 .66048 L .54071 .66326 L F
.53885 .66196 m .54122 .66148 L .54031 .66048 L F
.177 .299 .751 r
.54031 .66048 m .54123 .65907 L .54122 .65647 L F
.54031 .66048 m .54122 .66148 L .54123 .65907 L F
.697 .362 0 r
.65258 .42337 m .6539 .42673 L .6532 .42483 L F
.959 .77 .605 r
.65631 .44358 m .65782 .44208 L .65649 .44082 L F
.65631 .44358 m .65751 .44446 L .65782 .44208 L F
.718 .898 .96 r
.57714 .63708 m .57323 .63757 L .57497 .63789 L F
0 0 .092 r
.51719 .55002 m .51696 .54684 L .51775 .54811 L F
.833 .943 .896 r
.52064 .54514 m .51775 .54811 L .51696 .54684 L F
.006 0 .211 r
.51465 .69814 m .51588 .69933 L .51633 .69749 L F
.51465 .69814 m .5142 .70025 L .51588 .69933 L F
.813 .328 0 r
.50781 .70715 m .51061 .71002 L .50737 .71037 L F
.434 .264 .549 r
.50737 .71037 m .50947 .70979 L .50781 .70715 L F
.813 .328 0 r
.50781 .70715 m .50947 .70979 L .51061 .71002 L F
.577 .939 .916 r
.53733 .7045 m .53837 .70314 L .53541 .7045 L F
.458 .578 .887 r
.56285 .63922 m .56446 .63778 L .56243 .63778 L F
.56285 .63922 m .56519 .63927 L .56446 .63778 L F
.011 .072 .58 r
.58442 .62494 m .58541 .62362 L .58422 .62199 L F
.425 .798 .994 r
.74785 .41408 m .74705 .4154 L .74579 .41392 L F
.492 .648 .927 r
.75163 .41395 m .75004 .41533 L .75082 .41512 L F
.375 .292 .633 r
.75009 .41529 m .75011 .41785 L .75004 .41533 L F
.649 .869 .981 r
.75163 .41395 m .75082 .41512 L .75058 .41504 L F
.375 .292 .633 r
.75163 .41395 m .75058 .41504 L .75009 .41529 L F
.649 .869 .981 r
.75163 .41395 m .75058 .41504 L .74785 .41408 L F
.375 .292 .633 r
.75163 .41395 m .75137 .41462 L .75058 .41504 L F
.425 .798 .994 r
.75058 .41504 m .75082 .41512 L .75035 .41516 L F
.375 .292 .633 r
.75137 .41462 m .75011 .41785 L .75009 .41529 L F
.425 .798 .994 r
.74785 .41408 m .75058 .41504 L .74705 .4154 L F
.75058 .41504 m .75035 .41516 L .74705 .4154 L F
.454 .796 .998 r
.75082 .41512 m .75004 .41533 L .74705 .4154 L F
.472 .289 .551 r
.75004 .41533 m .7477 .41844 L .74705 .4154 L F
.856 .968 .647 r
.56622 .47405 m .56788 .47034 L .56827 .47117 L F
.56622 .47405 m .56584 .47366 L .56788 .47034 L F
.725 .943 .954 r
.42811 .56946 m .42886 .56754 L .43009 .56817 L F
.42811 .56946 m .42686 .56884 L .42886 .56754 L F
.691 .814 .941 r
.43436 .5866 m .43821 .58712 L .43634 .58546 L F
.713 .871 .956 r
.64629 .4495 m .64493 .45141 L .64671 .45124 L F
.568 .095 .093 r
.64493 .45141 m .64688 .45254 L .64671 .45124 L F
.865 .945 .867 r
.64629 .4495 m .64671 .45124 L .64956 .4477 L F
.627 .521 .714 r
.64671 .45124 m .65007 .4516 L .64956 .4477 L F
.486 .035 .105 r
.64671 .45124 m .64961 .4523 L .65007 .4516 L F
.64671 .45124 m .64688 .45254 L .64961 .4523 L F
0 0 0 r
.20456 .65706 m .20278 .65885 L .20163 .65976 L F
.347 0 .126 r
.20621 .65647 m .20278 .65885 L .20456 .65706 L F
.434 .428 .753 r
.25685 .56483 m .2552 .56576 L .25424 .56199 L F
.432 .275 .566 r
.25685 .56483 m .25489 .56828 L .2552 .56576 L F
.81 .627 .655 r
.52294 .53928 m .51974 .53931 L .52115 .53866 L F
.711 .5 .601 r
.52294 .53928 m .51907 .54125 L .51974 .53931 L F
.52294 .53928 m .52284 .54193 L .51907 .54125 L F
.614 .341 .48 r
.71227 .44136 m .71621 .43888 L .71201 .43888 L F
.71227 .44136 m .71689 .44097 L .71621 .43888 L F
.696 .386 .447 r
.71689 .44097 m .71827 .44122 L .71621 .43888 L F
.91 .885 .796 r
.66576 .41445 m .66934 .41219 L .66884 .41174 L F
.66576 .41445 m .66701 .41551 L .66934 .41219 L F
.728 .963 .692 r
.67074 .40984 m .66934 .41219 L .67188 .40932 L F
.745 .993 .826 r
.67074 .40984 m .66884 .41174 L .66934 .41219 L F
.497 .875 .975 r
.43754 .57953 m .43743 .5787 L .43883 .57755 L F
.686 .331 .368 r
.43743 .5787 m .4414 .57699 L .43883 .57755 L F
.249 0 0 r
.69911 .46264 m .69825 .46404 L .69566 .46455 L F
0 0 0 r
.70094 .46178 m .69911 .46264 L .70132 .46155 L F
.70094 .46178 m .69825 .46404 L .69911 .46264 L F
.594 .335 .495 r
.61315 .43579 m .6153 .43588 L .61565 .4336 L F
.689 .458 .567 r
.61913 .43563 m .61565 .4336 L .6153 .43588 L F
.403 .787 .991 r
.21249 .54147 m .21463 .54119 L .21633 .54193 L F
.378 .755 .99 r
.21463 .54119 m .21844 .54195 L .21633 .54193 L F
.699 .574 .71 r
.67833 .42447 m .68168 .42466 L .67822 .42369 L F
.24 .752 .863 r
.18734 .55463 m .18313 .55477 L .18513 .5544 L F
.937 .928 .771 r
.25932 .80085 m .2583 .80465 L .26069 .80425 L F
.532 .387 .63 r
.26069 .80425 m .2606 .80674 L .2583 .80465 L F
.26069 .80425 m .2606 .80674 L .2583 .80465 L F
.686 .598 .752 r
.67822 .42369 m .68168 .42466 L .68022 .41999 L F
.659 .591 .768 r
.19692 .67361 m .19641 .67601 L .19788 .67463 L F
.19692 .67361 m .1953 .67696 L .19641 .67601 L F
0 0 .101 r
.54181 .66132 m .54141 .66185 L .54336 .66095 L F
.739 .45 .49 r
.54334 .66328 m .54752 .66405 L .54687 .66162 L F
.54263 .66361 m .54339 .66368 L .54334 .66328 L F
.54339 .66368 m .54752 .66405 L .54334 .66328 L F
0 0 .422 r
.54319 .66219 m .54141 .66185 L .54297 .66387 L F
.54336 .66095 m .54305 .66109 L .54319 .66219 L F
.54305 .66109 m .54141 .66185 L .54319 .66219 L F
.656 .896 .982 r
.19833 .61117 m .19797 .61289 L .20063 .61168 L F
.20063 .61168 m .19797 .61289 L .19833 .61117 L F
.326 .382 .767 r
.4472 .57288 m .44818 .57051 L .44591 .57174 L F
.439 .274 .56 r
.63929 .45595 m .6388 .4584 L .63657 .45671 L F
.859 .733 .723 r
.63657 .45671 m .63937 .45388 L .63929 .45595 L F
.528 .817 .999 r
.6388 .4584 m .63688 .45918 L .63657 .45671 L F
.654 .662 .845 r
.71889 .41285 m .71532 .4118 L .71807 .4108 L F
.589 .62 .851 r
.72145 .41218 m .71889 .41285 L .71807 .4108 L F
.606 .914 .979 r
.64951 .43641 m .6499 .43695 L .65358 .43448 L F
.79 .805 .864 r
.65143 .43676 m .65006 .44011 L .64843 .43993 L F
.65358 .43448 m .65212 .43682 L .65143 .43676 L F
.65212 .43682 m .65006 .44011 L .65143 .43676 L F
.65358 .43448 m .64843 .43993 L .65186 .43687 L F
.204 0 0 r
.65095 .43673 m .6508 .4367 L .65186 .43687 L F
.6508 .4367 m .64951 .43641 L .65117 .43673 L F
.6508 .4367 m .65117 .43673 L .65186 .43687 L F
.64854 .43637 m .64951 .43641 L .65095 .43673 L F
0 .463 .86 r
.64691 .43521 m .64863 .43621 L .64951 .43641 L F
.64863 .43621 m .6499 .43695 L .64951 .43641 L F
.603 .17 .192 r
.39474 .642 m .39396 .64267 L .39142 .64207 L F
.071 0 0 r
.39759 .64169 m .39396 .64267 L .39474 .642 L F
.367 .222 .549 r
.22598 .63037 m .22601 .63303 L .22427 .63371 L F
.125 0 .299 r
.22508 .63505 m .22427 .63371 L .22601 .63303 L F
.22508 .63505 m .22371 .63613 L .22427 .63371 L F
.428 .317 .625 r
.24362 .60312 m .24152 .60112 L .2433 .60042 L F
.24362 .60312 m .24178 .60382 L .24152 .60112 L F
.979 .789 .579 r
.61262 .42542 m .61409 .42678 L .61423 .42422 L F
.556 .056 0 r
.61193 .42187 m .6137 .42375 L .61423 .42422 L F
.917 .976 .703 r
.6137 .42375 m .61262 .42542 L .61423 .42422 L F
0 0 0 r
.16781 .54513 m .16918 .54437 L .1699 .54376 L F
.26 0 .102 r
.16627 .54611 m .16918 .54437 L .16781 .54513 L F
.727 .614 .731 r
.55286 .62431 m .5542 .62776 L .55075 .62827 L F
.706 .604 .739 r
.55628 .62502 m .5542 .62776 L .55286 .62431 L F
.369 0 .144 r
.67466 .41372 m .67861 .41074 L .67588 .41077 L F
.782 .866 .911 r
.62492 .40348 m .62165 .40373 L .62341 .40216 L F
.514 .568 .847 r
.62737 .40184 m .62492 .40348 L .62341 .40216 L F
.62737 .40184 m .62688 .40282 L .62492 .40348 L F
.249 .223 .632 r
.6269 .40507 m .62492 .40348 L .62688 .40282 L F
0 0 .379 r
.66312 .42747 m .66394 .42937 L .66281 .42604 L F
.33 .656 .971 r
.45661 .57578 m .45733 .57424 L .45555 .57386 L F
.45661 .57578 m .45916 .57616 L .45733 .57424 L F
.349 .449 .822 r
.19418 .6659 m .19499 .66538 L .19377 .66497 L F
.744 .688 .797 r
.19374 .6683 m .19499 .66538 L .19418 .6659 L F
.158 0 .115 r
.22371 .63613 m .22086 .6387 L .22189 .63694 L F
.538 .515 .778 r
.53814 .68116 m .53961 .67766 L .53668 .67974 L F
.53814 .68116 m .54042 .68082 L .53961 .67766 L F
.289 .398 .801 r
.45653 .56762 m .45527 .56939 L .45512 .56789 L F
.649 .158 .071 r
.45527 .56939 m .45791 .57087 L .46052 .57094 L F
.327 .451 .834 r
.45653 .56762 m .45791 .57087 L .45527 .56939 L F
.135 0 0 r
.21924 .55883 m .22097 .55857 L .22254 .5569 L F
.407 .65 .957 r
.22119 .55533 m .22254 .5569 L .22314 .55526 L F
.018 0 0 r
.22254 .5569 m .22294 .55774 L .22314 .55526 L F
.22254 .5569 m .22097 .55857 L .22294 .55774 L F
.161 0 .357 r
.22588 .57694 m .22783 .57346 L .2264 .57458 L F
.872 .993 .804 r
.56827 .47117 m .57028 .46741 L .57074 .46799 L F
.835 .999 .793 r
.57074 .46799 m .57276 .46458 L .57361 .46531 L F
.57074 .46799 m .57028 .46741 L .57276 .46458 L F
.868 .868 .835 r
.56184 .48036 m .5591 .48182 L .56043 .47915 L F
.635 .509 .693 r
.53835 .54458 m .53612 .54772 L .53616 .54525 L F
.53835 .54458 m .5394 .54801 L .53612 .54772 L F
.606 .477 .679 r
.5394 .54801 m .53723 .55096 L .53612 .54772 L F
.745 .654 .76 r
.52441 .56263 m .52539 .56557 L .52195 .56541 L F
.766 .509 .546 r
.52539 .56557 m .52208 .56797 L .52195 .56541 L F
.52539 .56557 m .52552 .56846 L .52208 .56797 L F
.664 .43 .555 r
.52798 .56788 m .52539 .56557 L .52794 .56548 L F
.52798 .56788 m .52552 .56846 L .52539 .56557 L F
.791 .75 .815 r
.72543 .43013 m .72892 .43029 L .7276 .42892 L F
.745 .826 .915 r
.7276 .42892 m .72892 .43029 L .73303 .42842 L F
.558 .217 .347 r
.47559 .624 m .47824 .62399 L .47916 .62151 L F
.609 .269 .368 r
.47916 .62151 m .48128 .62329 L .48167 .62137 L F
.47916 .62151 m .47824 .62399 L .48128 .62329 L F
.072 0 .354 r
.2085 .62137 m .21028 .61814 L .20818 .61894 L F
.519 .305 .528 r
.55912 .52479 m .56112 .52668 L .55884 .52677 L F
.55912 .52479 m .56111 .52418 L .56112 .52668 L F
.551 .246 .405 r
.36472 .59414 m .36731 .59383 L .36522 .59216 L F
.564 .241 .379 r
.36522 .59216 m .36731 .59383 L .36785 .592 L F
.397 .219 .52 r
.24743 .59138 m .24533 .59512 L .24568 .59226 L F
.5 .284 .517 r
.58615 .50911 m .58349 .51153 L .58373 .50975 L F
0 0 0 r
.22086 .6387 m .21847 .64167 L .21959 .63981 L F
.649 .576 .76 r
.68022 .41999 m .68168 .42466 L .68401 .42383 L F
.681 .66 .823 r
.72773 .4121 m .7255 .41557 L .7239 .41137 L F
.676 .654 .82 r
.72773 .4121 m .72874 .41548 L .7255 .41557 L F
.681 .348 .405 r
.4455 .63611 m .44433 .63883 L .44211 .63806 L F
.568 .228 .354 r
.44804 .63775 m .4455 .63611 L .44799 .63605 L F
.44804 .63775 m .44433 .63883 L .4455 .63611 L F
.808 .861 .888 r
.60798 .4262 m .60467 .42656 L .60741 .42426 L F
.831 .871 .874 r
.61039 .4236 m .60798 .4262 L .60741 .42426 L F
.548 .406 .639 r
.53495 .55655 m .53269 .5595 L .53249 .55697 L F
.647 .497 .665 r
.57557 .51562 m .57328 .51803 L .57348 .5163 L F
.506 .83 .999 r
.27093 .78855 m .27048 .78979 L .26874 .78905 L F
.27093 .78855 m .27048 .78979 L .26874 .78905 L F
.318 0 .221 r
.25637 .56137 m .25424 .56199 L .25359 .56022 L F
.649 .7 .883 r
.70338 .41509 m .70459 .41809 L .7072 .41736 L F
.834 .679 .691 r
.5883 .47974 m .58973 .48035 L .58829 .47696 L F
.763 .566 .631 r
.58599 .48227 m .58973 .48035 L .5883 .47974 L F
.58599 .48227 m .58957 .48287 L .58973 .48035 L F
.751 .497 .548 r
.59319 .483 m .58973 .48035 L .58957 .48287 L F
.082 0 0 r
.47707 .63051 m .48034 .62753 L .48025 .62986 L F
.503 .303 .542 r
.48268 .62702 m .48025 .62986 L .48034 .62753 L F
.463 .275 .539 r
.48248 .62537 m .48268 .62702 L .48034 .62753 L F
.511 .315 .551 r
.7233 .44795 m .72345 .45049 L .72112 .45102 L F
.472 .228 .463 r
.72606 .44761 m .72345 .45049 L .7233 .44795 L F
.655 .523 .69 r
.53835 .54458 m .53665 .54351 L .53853 .54221 L F
.53835 .54458 m .53616 .54525 L .53665 .54351 L F
.37 .767 .986 r
.54397 .68148 m .54294 .68063 L .54042 .68082 L F
.549 .004 0 r
.54617 .681 m .54294 .68063 L .54397 .68148 L F
.655 .957 .941 r
.61147 .46676 m .60801 .46786 L .60941 .46729 L F
.74 .809 .907 r
.61151 .46372 m .61147 .46676 L .60941 .46729 L F
.61151 .46372 m .61354 .46541 L .61147 .46676 L F
.536 .405 .649 r
.60941 .46729 m .61247 .46892 L .6121 .4662 L F
.60941 .46729 m .6121 .4662 L .61204 .46569 L F
.655 .957 .941 r
.60801 .46786 m .60781 .46792 L .60941 .46729 L F
.55 .562 .819 r
.73152 .43374 m .73419 .43369 L .73385 .43296 L F
0 0 0 r
.72923 .4345 m .73152 .43374 L .73263 .43325 L F
.731 .987 .792 r
.73263 .43325 m .73304 .43192 L .73517 .43092 L F
.751 .968 .687 r
.73263 .43325 m .73152 .43374 L .73304 .43192 L F
.932 .965 .756 r
.73517 .43092 m .73304 .43192 L .73575 .42743 L F
.55 .562 .819 r
.73152 .43374 m .73266 .43045 L .73304 .43192 L F
.931 .93 .781 r
.73575 .42743 m .73304 .43192 L .73266 .43045 L F
.55 .562 .819 r
.73152 .43374 m .73385 .43296 L .73266 .43045 L F
0 0 0 r
.72892 .43461 m .73152 .43374 L .72923 .4345 L F
.428 .806 .992 r
.68241 .40141 m .67897 .4011 L .68148 .40075 L F
.334 .753 .977 r
.68469 .40121 m .68241 .40141 L .68148 .40075 L F
.872 .993 .804 r
.56827 .47117 m .56788 .47034 L .57028 .46741 L F
.445 0 0 r
.57118 .63757 m .56753 .63839 L .56875 .63916 L F
.587 .803 .982 r
.67787 .40851 m .67944 .40632 L .67636 .40762 L F
.67787 .40851 m .68056 .40772 L .67944 .40632 L F
.278 .603 .953 r
.24291 .54544 m .24146 .54634 L .23988 .54494 L F
.24291 .54544 m .24398 .54684 L .24146 .54634 L F
.497 .223 .429 r
.36785 .592 m .37024 .59157 L .37059 .58936 L F
.439 .173 .412 r
.37059 .58936 m .37239 .591 L .37381 .58885 L F
.37059 .58936 m .37024 .59157 L .37239 .591 L F
.004 0 .128 r
.60514 .46861 m .60318 .47123 L .60441 .47054 L F
.126 .094 .548 r
.60318 .47123 m .60457 .47331 L .60441 .47054 L F
.60318 .47123 m .60354 .47368 L .60457 .47331 L F
.862 .996 .771 r
.58604 .44843 m .58375 .45134 L .58431 .44925 L F
.812 .962 .636 r
.58239 .45284 m .58431 .44925 L .58375 .45134 L F
.472 .289 .551 r
.75004 .41533 m .75011 .41785 L .7477 .41844 L F
.051 0 0 r
.75011 .41785 m .74707 .41989 L .7477 .41844 L F
.986 .723 .349 r
.74617 .41775 m .74707 .41989 L .7477 .41844 L F
.484 .294 .547 r
.54799 .53024 m .54799 .53267 L .54569 .53328 L F
.589 .445 .653 r
.54799 .53267 m .54569 .53557 L .54569 .53328 L F
.362 .806 .954 r
.1719 .54281 m .17422 .54248 L .1766 .54301 L F
.537 .887 .982 r
.1766 .54301 m .17664 .54173 L .1787 .54233 L F
.1766 .54301 m .17422 .54248 L .17664 .54173 L F
.847 .689 .686 r
.19004 .56514 m .1915 .56868 L .1881 .56824 L F
.759 .515 .564 r
.1915 .56868 m .1872 .57078 L .1881 .56824 L F
.1915 .56868 m .1908 .57014 L .1872 .57078 L F
0 0 .55 r
.19144 .56714 m .1915 .56868 L .19004 .56514 L F
0 0 0 r
.19155 .56967 m .1915 .56868 L .19144 .56714 L F
.19155 .56967 m .1908 .57014 L .1915 .56868 L F
.918 .547 .301 r
.66621 .45876 m .66762 .45969 L .66666 .46108 L F
.659 .188 .122 r
.66762 .45969 m .6703 .46152 L .66666 .46108 L F
.198 .357 .798 r
.75315 .42211 m .75084 .42237 L .75078 .42117 L F
.75315 .42211 m .75228 .42414 L .75084 .42237 L F
.264 .738 .939 r
.21844 .54195 m .22058 .54184 L .2223 .54236 L F
.173 .686 .895 r
.22058 .54184 m .22439 .54229 L .2223 .54236 L F
.4 .274 .592 r
.23917 .61153 m .23713 .60969 L .23937 .60938 L F
.23917 .61153 m .23693 .61255 L .23713 .60969 L F
.683 .213 .129 r
.42488 .63012 m .42715 .63203 L .42863 .63066 L F
.692 .224 .136 r
.42715 .63203 m .43102 .63273 L .42863 .63066 L F
.668 .721 .889 r
.71669 .40793 m .71532 .4118 L .71409 .4085 L F
.71669 .40793 m .71807 .4108 L .71532 .4118 L F
.796 .669 .724 r
.52769 .53355 m .52436 .53328 L .52588 .53216 L F
.794 .74 .803 r
.52769 .53355 m .52359 .5351 L .52436 .53328 L F
.631 .701 .896 r
.6989 .40592 m .69471 .40341 L .6972 .40276 L F
.606 .702 .912 r
.70102 .405 m .6989 .40592 L .6972 .40276 L F
0 .143 .688 r
.36173 .62271 m .36261 .62262 L .36251 .62251 L F
0 0 0 r
.36143 .62279 m .36173 .62271 L .36269 .62189 L F
.932 .746 .628 r
.36269 .62189 m .36173 .62271 L .3606 .62054 L F
0 .143 .688 r
.36173 .62271 m .36251 .62251 L .3606 .62054 L F
0 0 0 r
.36001 .62381 m .36173 .62271 L .36143 .62279 L F
.328 .029 .296 r
.35956 .6256 m .36173 .62271 L .36001 .62381 L F
.487 .029 .091 r
.73997 .4393 m .73644 .44079 L .7364 .43917 L F
.73997 .4393 m .7392 .44084 L .73644 .44079 L F
.271 0 .015 r
.74255 .43857 m .7392 .44084 L .73997 .4393 L F
.563 .492 .734 r
.62671 .42703 m .62749 .43016 L .62989 .42951 L F
.713 .598 .727 r
.58363 .61748 m .58516 .61588 L .58186 .61544 L F
.798 .495 .477 r
.63187 .45421 m .62912 .45554 L .62912 .45316 L F
.63187 .45421 m .63284 .45632 L .62912 .45554 L F
.499 .413 .689 r
.35616 .60678 m .35865 .60904 L .3583 .60628 L F
.35616 .60678 m .35652 .61042 L .35865 .60904 L F
.784 .827 .885 r
.68589 .42263 m .69034 .42128 L .68879 .42028 L F
.601 .939 .945 r
.51061 .71002 m .50588 .7111 L .50737 .71037 L F
.51061 .71002 m .50947 .70979 L .50588 .7111 L F
.512 .902 .944 r
.51175 .70889 m .51061 .71002 L .513 .70966 L F
.51175 .70889 m .50947 .70979 L .51061 .71002 L F
.51175 .70889 m .51061 .71002 L .513 .70966 L F
.51175 .70889 m .50947 .70979 L .51061 .71002 L F
.496 .185 .369 r
.52028 .6985 m .51989 .70037 L .51742 .7006 L F
.502 .103 .217 r
.52028 .6985 m .52204 .69977 L .51989 .70037 L F
.52028 .6985 m .52377 .69768 L .52204 .69977 L F
.648 .518 .69 r
.53269 .5595 m .53019 .56273 L .53017 .55997 L F
.668 .415 .53 r
.55404 .52726 m .5564 .52959 L .55212 .52978 L F
.55404 .52726 m .55651 .5273 L .5564 .52959 L F
.148 0 0 r
.39008 .60727 m .38913 .60835 L .38669 .60902 L F
.39 .296 .627 r
.38946 .61202 m .38669 .60902 L .38913 .60835 L F
.38946 .61202 m .38738 .61419 L .38669 .60902 L F
.404 .135 .388 r
.72319 .45199 m .72112 .45102 L .72345 .45049 L F
.72319 .45199 m .72087 .45292 L .72112 .45102 L F
.422 0 .114 r
.37239 .591 m .3761 .58905 L .37381 .58885 L F
.376 .205 .517 r
.23693 .61255 m .23712 .61508 L .23505 .6156 L F
.429 .201 .465 r
.23685 .61706 m .23505 .6156 L .23712 .61508 L F
.23685 .61706 m .23484 .61764 L .23505 .6156 L F
.432 .874 .856 r
.4374 .57282 m .43801 .57289 L .43998 .57209 L F
.872 .734 .707 r
.51682 .55921 m .51567 .55561 L .51694 .55682 L F
.445 0 0 r
.57118 .63757 m .57293 .63889 L .56753 .63839 L F
.185 .028 .421 r
.21394 .60613 m .21579 .60302 L .21403 .60401 L F
.497 .875 .975 r
.43754 .57953 m .4351 .57949 L .43743 .5787 L F
0 .154 .686 r
.43754 .57953 m .43743 .5787 L .4351 .57949 L F
.43754 .57953 m .43884 .58078 L .43743 .5787 L F
.545 .817 .996 r
.73605 .41119 m .73717 .41229 L .73355 .41179 L F
.77 .394 .344 r
.73612 .41413 m .73717 .41229 L .73605 .41119 L F
.73612 .41413 m .73809 .41464 L .73717 .41229 L F
.922 .613 .443 r
.6444 .41508 m .64219 .41654 L .64181 .41454 L F
.6444 .41508 m .64482 .41756 L .64219 .41654 L F
.911 .802 .726 r
.6444 .41508 m .64373 .41192 L .6461 .41391 L F
.223 .41 .836 r
.64727 .41485 m .6444 .41508 L .6461 .41391 L F
.846 .999 .803 r
.58727 .44686 m .58604 .44843 L .58673 .44629 L F
.85 .997 .773 r
.58604 .44843 m .58431 .44925 L .58673 .44629 L F
.392 .338 .677 r
.35736 .61244 m .35865 .60904 L .35652 .61042 L F
.35736 .61244 m .35916 .61223 L .35865 .60904 L F
.246 0 0 r
.52377 .69768 m .52507 .6981 L .52204 .69977 L F
.52377 .69768 m .52611 .69792 L .52507 .6981 L F
.043 0 0 r
.41361 .57498 m .41428 .57548 L .41582 .57423 L F
.41361 .57498 m .41195 .57608 L .41428 .57548 L F
.876 .833 .8 r
.53885 .66196 m .54071 .66326 L .54181 .66132 L F
.489 .175 .361 r
.59691 .50079 m .59916 .50236 L .59665 .50303 L F
.59691 .50079 m .59945 .50026 L .59916 .50236 L F
.908 .823 .751 r
.53784 .51489 m .53413 .517 L .53453 .51463 L F
.53784 .51489 m .5357 .51806 L .53413 .517 L F
.887 .932 .842 r
.64118 .45598 m .6388 .4584 L .63929 .45595 L F
.64265 .456 m .64158 .45667 L .64118 .45598 L F
.64158 .45667 m .6388 .4584 L .64118 .45598 L F
.831 .96 .627 r
.63996 .45188 m .63937 .45388 L .64111 .45103 L F
.872 .7 .665 r
.64142 .45441 m .64176 .45507 L .64234 .45463 L F
.182 .356 .803 r
.64103 .45363 m .64213 .45579 L .64035 .45456 L F
.046 0 0 r
.63929 .45595 m .64196 .45603 L .64265 .456 L F
.872 .7 .665 r
.64052 .45601 m .64184 .45603 L .64234 .45463 L F
.876 .615 .54 r
.64142 .45441 m .6425 .45604 L .64234 .45463 L F
.182 .356 .803 r
.64001 .45226 m .64097 .45371 L .64035 .45456 L F
.79 .57 .004 r
.64265 .456 m .64234 .45463 L .64478 .45592 L F
.853 .724 .72 r
.64201 .45555 m .64246 .45561 L .64234 .45463 L F
.79 .57 .004 r
.64265 .456 m .64252 .45604 L .64234 .45463 L F
.853 .724 .72 r
.64246 .45561 m .64478 .45592 L .64234 .45463 L F
.79 .57 .004 r
.64252 .45604 m .6425 .45604 L .64234 .45463 L F
.853 .724 .72 r
.64228 .45601 m .64478 .45592 L .64201 .45555 L F
.182 .356 .803 r
.64103 .45363 m .6425 .45604 L .64217 .45581 L F
.64201 .45555 m .64217 .45581 L .64213 .45579 L F
.64103 .45363 m .64217 .45581 L .64201 .45555 L F
.853 .724 .72 r
.64184 .45603 m .64228 .45601 L .64201 .45555 L F
.182 .356 .803 r
.63996 .45188 m .64035 .45456 L .63957 .4532 L F
.872 .7 .665 r
.63975 .45401 m .64052 .45601 L .64176 .45507 L F
.63975 .45401 m .64176 .45507 L .64142 .45441 L F
.876 .615 .54 r
.63975 .45401 m .6425 .45604 L .64142 .45441 L F
.182 .356 .803 r
.63996 .45188 m .64103 .45363 L .64097 .45371 L F
.63996 .45188 m .64097 .45371 L .64001 .45226 L F
.887 .932 .842 r
.64004 .45763 m .63972 .45939 L .6388 .4584 L F
.64265 .456 m .63991 .45917 L .64004 .45763 L F
.63991 .45917 m .63972 .45939 L .64004 .45763 L F
.197 .318 .762 r
.63929 .45595 m .64011 .45673 L .63975 .45401 L F
.64011 .45673 m .64121 .45779 L .64023 .45525 L F
.64011 .45673 m .64023 .45525 L .63975 .45401 L F
.872 .7 .665 r
.64052 .45601 m .64121 .45779 L .64184 .45603 L F
.046 0 0 r
.64196 .45603 m .642 .45603 L .64201 .45603 L F
.64196 .45603 m .64201 .45603 L .64265 .456 L F
.853 .724 .72 r
.64121 .45779 m .6445 .45607 L .64184 .45603 L F
.046 0 0 r
.642 .45603 m .6425 .45604 L .64252 .45604 L F
.642 .45603 m .64252 .45604 L .64265 .456 L F
.853 .724 .72 r
.6445 .45607 m .64478 .45592 L .64184 .45603 L F
.182 .356 .803 r
.63957 .4532 m .64035 .45456 L .63937 .45388 L F
.864 .855 .831 r
.21587 .58149 m .21301 .58145 L .21441 .58024 L F
.21587 .58149 m .21408 .58357 L .21301 .58145 L F
.726 .854 .942 r
.2178 .58027 m .21587 .58149 L .21441 .58024 L F
.606 .245 .331 r
.5647 .52129 m .56685 .52328 L .56433 .52367 L F
.5647 .52129 m .56712 .52152 L .56685 .52328 L F
.527 .195 .348 r
.56712 .52152 m .56967 .52006 L .56957 .52287 L F
.584 .281 .421 r
.57284 .5199 m .56957 .52287 L .56967 .52006 L F
.563 .492 .734 r
.62671 .42703 m .62989 .42951 L .62998 .42701 L F
.673 .646 .815 r
.62986 .45808 m .62799 .45973 L .62623 .45658 L F
0 0 .142 r
.21358 .58605 m .21301 .58145 L .21408 .58357 L F
.745 .907 .949 r
.64056 .46245 m .64339 .46221 L .64189 .46089 L F
.809 .797 .84 r
.64189 .46089 m .64339 .46221 L .6461 .45942 L F
.908 .768 .694 r
.59236 .46778 m .59554 .46559 L .59408 .46445 L F
.59236 .46778 m .59496 .46774 L .59554 .46559 L F
.916 .841 .756 r
.59554 .46559 m .59598 .46119 L .59408 .46445 L F
.226 .737 .7 r
.17257 .5583 m .16977 .55914 L .17062 .5588 L F
.317 .117 .443 r
.23484 .61764 m .23252 .62117 L .23273 .61872 L F
.467 .89 .819 r
.58233 .63543 m .58199 .63524 L .57971 .63629 L F
.57971 .63629 m .58199 .63524 L .58233 .63543 L F
.63 .324 .434 r
.52079 .56364 m .51843 .56721 L .51659 .56501 L F
.653 .519 .688 r
.52205 .56333 m .52195 .56541 L .52079 .56364 L F
.809 .553 .552 r
.52195 .56541 m .51843 .56721 L .52079 .56364 L F
.755 .48 .516 r
.52024 .56694 m .52079 .56364 L .52195 .56541 L F
.52024 .56694 m .51843 .56721 L .52079 .56364 L F
.379 0 .099 r
.37832 .58893 m .38057 .5888 L .38227 .58643 L F
.394 0 .124 r
.38057 .5888 m .38455 .58607 L .38227 .58643 L F
.675 .407 .508 r
.42559 .59086 m .42121 .58913 L .42571 .58952 L F
.613 .222 .278 r
.42571 .58952 m .42789 .5913 L .42559 .59086 L F
.64 .524 .705 r
.42764 .58711 m .42826 .58931 L .42571 .58952 L F
.569 .246 .382 r
.42826 .58931 m .42789 .5913 L .42571 .58952 L F
.873 .819 .792 r
.67196 .44378 m .67561 .4414 L .67469 .44047 L F
.67196 .44378 m .67353 .44476 L .67561 .4414 L F
.966 .907 .707 r
.67617 .43717 m .67561 .4414 L .6769 .43839 L F
.67617 .43717 m .67469 .44047 L .67561 .4414 L F
.259 .245 .653 r
.19402 .63949 m .19564 .64051 L .19554 .63809 L F
.19402 .63949 m .19464 .64209 L .19564 .64051 L F
.412 .063 .261 r
.42955 .5803 m .42655 .58257 L .42661 .58077 L F
.497 .731 .977 r
.69378 .41426 m .69477 .41565 L .69743 .41522 L F
.432 .223 .494 r
.25223 .58692 m .25024 .58626 L .25194 .58546 L F
.25223 .58692 m .24979 .58841 L .25024 .58626 L F
.528 .817 .999 r
.6388 .4584 m .63972 .45939 L .63688 .45918 L F
.755 .62 .71 r
.63972 .45939 m .6382 .45987 L .63688 .45918 L F
.912 .885 .793 r
.19001 .6442 m .19145 .64517 L .18989 .64759 L F
.915 .753 .263 r
.67196 .44378 m .67207 .44734 L .67353 .44476 L F
.733 .277 .169 r
.18784 .64171 m .18916 .64195 L .18863 .64135 L F
.536 .454 .71 r
.41831 .58849 m .41728 .59213 L .41701 .59171 L F
.41831 .58849 m .41957 .59243 L .41728 .59213 L F
.409 .208 .494 r
.41805 .59318 m .41728 .59213 L .41957 .59243 L F
.41805 .59318 m .41701 .59171 L .41728 .59213 L F
.621 .871 .525 r
.74367 .42445 m .74208 .42643 L .7422 .42653 L F
0 .515 .736 r
.74227 .42658 m .7422 .42653 L .74022 .42625 L F
.485 .876 .966 r
.74022 .42625 m .73908 .42585 L .73722 .4271 L F
.691 .193 .058 r
.7422 .42653 m .73908 .42585 L .74022 .42625 L F
.7422 .42653 m .74115 .42757 L .73908 .42585 L F
.621 .871 .525 r
.74208 .42643 m .74115 .42757 L .7422 .42653 L F
0 .515 .736 r
.7433 .42674 m .7422 .42653 L .74227 .42658 L F
.319 .752 .97 r
.74569 .42703 m .7422 .42653 L .7433 .42674 L F
.75 .775 .873 r
.66405 .40572 m .66837 .40499 L .66734 .40387 L F
.62 .809 .973 r
.66734 .40387 m .66837 .40499 L .66992 .40392 L F
.518 .605 .88 r
.5589 .63697 m .5604 .63478 L .55808 .63513 L F
.5589 .63697 m .56243 .63778 L .5604 .63478 L F
.858 .723 .713 r
.20453 .62252 m .20271 .62418 L .20425 .62089 L F
.485 .13 .288 r
.60063 .48177 m .59816 .48051 L .59821 .48246 L F
.60063 .48177 m .60105 .47945 L .59816 .48051 L F
0 0 0 r
.20278 .65885 m .20014 .66174 L .20163 .65976 L F
.481 .233 .461 r
.60745 .46995 m .60514 .46861 L .60441 .47054 L F
.60745 .46995 m .60781 .46792 L .60514 .46861 L F
.932 .965 .756 r
.73517 .43092 m .73575 .42743 L .73736 .42998 L F
0 0 0 r
.73575 .42743 m .73571 .42788 L .73583 .42778 L F
.312 0 0 r
.73722 .4271 m .73575 .42743 L .73567 .42706 L F
.288 0 .074 r
.73908 .42585 m .73575 .42743 L .73722 .4271 L F
.362 .404 .771 r
.7394 .42653 m .73736 .42998 L .73575 .42743 L F
.443 .872 .775 r
.73575 .42743 m .73908 .42585 L .73522 .42476 L F
.73702 .42683 m .73792 .42609 L .73908 .42585 L F
.73575 .42743 m .73792 .42609 L .73702 .42683 L F
.747 .527 .597 r
.73522 .42476 m .73908 .42585 L .73843 .42291 L F
.73522 .42476 m .73843 .42291 L .73541 .42231 L F
.439 .329 .632 r
.73843 .42291 m .73908 .42585 L .74088 .42475 L F
.753 .734 .835 r
.74039 .42522 m .73705 .42602 L .73664 .42361 L F
.107 .236 .716 r
.7401 .42509 m .73705 .42602 L .74039 .42522 L F
.7387 .42446 m .73761 .42549 L .7401 .42509 L F
.73761 .42549 m .73705 .42602 L .7401 .42509 L F
.312 0 0 r
.73567 .42706 m .73575 .42743 L .73368 .42701 L F
.477 .464 .764 r
.73368 .42701 m .73575 .42743 L .73522 .42476 L F
.795 .566 .59 r
.73792 .42609 m .73462 .42644 L .73466 .42597 L F
.477 .464 .764 r
.73368 .42701 m .73522 .42476 L .73315 .42538 L F
.558 .585 .836 r
.73315 .42538 m .73522 .42476 L .73375 .42154 L F
.87 .724 .698 r
.73375 .42154 m .73522 .42476 L .73541 .42231 L F
.689 .691 .847 r
.73664 .42361 m .73705 .42602 L .73492 .42308 L F
.107 .236 .716 r
.7387 .42446 m .73792 .42609 L .73705 .42602 L F
.795 .566 .59 r
.73792 .42609 m .73492 .42308 L .73705 .42602 L F
.73736 .42553 m .73466 .42597 L .73492 .42308 L F
.73792 .42609 m .73466 .42597 L .73736 .42553 L F
.775 .33 .195 r
.73876 .4254 m .73792 .42609 L .7387 .42446 L F
.362 .404 .771 r
.73964 .42665 m .73736 .42998 L .7394 .42653 L F
.541 0 0 r
.73736 .42998 m .74004 .43126 L .74077 .43046 L F
.362 .404 .771 r
.73964 .42665 m .74004 .43126 L .73736 .42998 L F
.7398 .42678 m .74004 .43126 L .73964 .42665 L F
.563 .565 .814 r
.74115 .42757 m .74004 .43126 L .7398 .42678 L F
.665 .114 0 r
.74004 .42692 m .74115 .42757 L .74065 .42715 L F
.288 0 .074 r
.73908 .42585 m .7394 .42653 L .73575 .42743 L F
.665 .114 0 r
.73964 .42665 m .74065 .42715 L .73868 .42593 L F
.563 .565 .814 r
.74115 .42757 m .7398 .42678 L .73978 .42644 L F
.665 .114 0 r
.73947 .4267 m .74115 .42757 L .74004 .42692 L F
.73792 .42609 m .73953 .42683 L .73947 .4267 L F
.73953 .42683 m .74115 .42757 L .73947 .4267 L F
.73868 .42593 m .74065 .42715 L .73908 .42585 L F
.288 0 .074 r
.73908 .42585 m .73978 .42644 L .7394 .42653 L F
.665 .114 0 r
.73792 .42609 m .74065 .42715 L .73833 .42601 L F
0 .453 .816 r
.7401 .42687 m .74115 .42757 L .73792 .42609 L F
.775 .33 .195 r
.73892 .42763 m .7401 .42687 L .73792 .42609 L F
.73892 .42763 m .73792 .42609 L .73876 .4254 L F
.665 .114 0 r
.73833 .42601 m .73964 .42665 L .73868 .42593 L F
.362 .404 .771 r
.73978 .42644 m .7398 .42678 L .73964 .42665 L F
.73978 .42644 m .73964 .42665 L .7394 .42653 L F
0 0 0 r
.73575 .42743 m .73583 .42778 L .73792 .42609 L F
.399 .55 .89 r
.19499 .66538 m .19202 .66433 L .19377 .66497 L F
.428 .491 .823 r
.57466 .62884 m .5736 .63315 L .57181 .63001 L F
.57466 .62884 m .57549 .63302 L .5736 .63315 L F
.165 0 0 r
.47497 .63111 m .47669 .63116 L .47419 .632 L F
.47497 .63111 m .47707 .63051 L .47669 .63116 L F
.677 .567 .724 r
.69592 .44751 m .69671 .4512 L .69897 .4501 L F
.61 .06 0 r
.54384 .65841 m .54694 .65902 L .54468 .65754 L F
.515 0 0 r
.54468 .65754 m .54694 .65902 L .54874 .65974 L F
0 0 .242 r
.55628 .62502 m .55789 .62117 L .55894 .62234 L F
.532 .47 .732 r
.55894 .62234 m .55861 .62475 L .55628 .62502 L F
.686 .571 .72 r
.53269 .5595 m .53281 .56218 L .53019 .56273 L F
.688 .469 .585 r
.53281 .56218 m .53017 .56497 L .53019 .56273 L F
.236 .689 .952 r
.66793 .41431 m .67011 .41576 L .66701 .41551 L F
.557 .169 .261 r
.66778 .41311 m .66875 .41398 L .66769 .41427 L F
.674 .927 .972 r
.66982 .41436 m .66815 .41431 L .66829 .41423 L F
.67228 .41457 m .66981 .41441 L .66982 .41436 L F
.66981 .41441 m .66815 .41431 L .66982 .41436 L F
.347 0 0 r
.67188 .40932 m .66845 .40771 L .67122 .4062 L F
0 0 0 r
.67188 .40932 m .67318 .40933 L .67074 .40984 L F
.526 .821 .999 r
.67074 .40984 m .67318 .40933 L .67198 .40843 L F
.592 .687 .908 r
.66992 .40392 m .67549 .40668 L .67122 .4062 L F
.628 .678 .878 r
.67318 .40933 m .67435 .40569 L .67198 .40843 L F
0 0 .232 r
.6704 .41292 m .67198 .40843 L .67222 .40831 L F
.734 .821 .358 r
.67027 .41293 m .6704 .41292 L .67222 .40831 L F
.674 .927 .972 r
.67228 .41457 m .67011 .41576 L .66815 .41431 L F
.67228 .41457 m .66829 .41423 L .6704 .41292 L F
.557 .169 .261 r
.66829 .41423 m .6681 .41434 L .66843 .41407 L F
.674 .927 .972 r
.66829 .41423 m .66801 .4142 L .66859 .41389 L F
.66829 .41423 m .66859 .41389 L .6704 .41292 L F
.557 .169 .261 r
.66843 .41407 m .6681 .41434 L .66769 .41427 L F
.549 .16 .257 r
.66953 .41469 m .6704 .41292 L .66859 .41389 L F
.557 .169 .261 r
.66871 .41399 m .66829 .41423 L .66843 .41407 L F
.66872 .414 m .66829 .41423 L .66871 .41399 L F
.66875 .41398 m .66936 .41453 L .6681 .41434 L F
.674 .927 .972 r
.66829 .41423 m .66815 .41431 L .66801 .4142 L F
.549 .16 .257 r
.66953 .41469 m .66859 .41389 L .66801 .4142 L F
.557 .169 .261 r
.66875 .41398 m .66872 .414 L .66871 .41399 L F
.66778 .41311 m .6704 .41292 L .66953 .41469 L F
.734 .821 .358 r
.66953 .41469 m .67006 .41362 L .67027 .41293 L F
.67006 .41362 m .6704 .41292 L .67027 .41293 L F
.236 .689 .952 r
.66801 .4142 m .66815 .41431 L .66793 .41431 L F
.66815 .41431 m .67011 .41576 L .66793 .41431 L F
.557 .169 .261 r
.66769 .41431 m .66953 .41469 L .66763 .41511 L F
.236 .689 .952 r
.66793 .41431 m .66701 .41551 L .66756 .41425 L F
.557 .169 .261 r
.66769 .41427 m .66785 .41431 L .66769 .41431 L F
.66785 .41431 m .66953 .41469 L .66769 .41431 L F
.66936 .41453 m .66953 .41469 L .66769 .41427 L F
.236 .689 .952 r
.66756 .41425 m .66701 .41551 L .66576 .41445 L F
.66801 .4142 m .66793 .41431 L .66756 .41425 L F
.898 .629 .523 r
.19245 .55791 m .19433 .55678 L .1928 .55543 L F
.19245 .55791 m .19451 .55923 L .19433 .55678 L F
.395 .192 .483 r
.2452 .59977 m .24361 .59802 L .24554 .59736 L F
.2452 .59977 m .2433 .60042 L .24361 .59802 L F
.293 .381 .783 r
.70974 .44181 m .71276 .44451 L .71227 .44136 L F
.917 .911 .798 r
.63129 .44759 m .62934 .45075 L .6282 .44989 L F
.994 .778 .5 r
.62934 .45075 m .62912 .45316 L .6282 .44989 L F
.431 .362 .679 r
.72403 .43554 m .72663 .43675 L .72659 .43562 L F
.72403 .43554 m .72452 .43847 L .72663 .43675 L F
.563 .376 .585 r
.55038 .52976 m .54799 .53267 L .54799 .53024 L F
.634 .57 .765 r
.73009 .41102 m .72874 .41548 L .72773 .4121 L F
.488 .364 .637 r
.35776 .6039 m .35973 .60002 L .35744 .60104 L F
.322 .807 .872 r
.74004 .43126 m .7437 .43078 L .74077 .43046 L F
.595 .389 .572 r
.26069 .80425 m .26144 .80154 L .25932 .80085 L F
.26069 .80425 m .26296 .80377 L .26144 .80154 L F
.26144 .80154 m .26296 .80377 L .26069 .80425 L F
.606 .477 .679 r
.5394 .54801 m .53972 .55051 L .53723 .55096 L F
.595 .433 .632 r
.53972 .55051 m .53741 .55351 L .53723 .55096 L F
.88 .583 .479 r
.6287 .44473 m .63129 .44759 L .62896 .44617 L F
.917 .911 .798 r
.63129 .44759 m .6282 .44989 L .62896 .44617 L F
0 0 0 r
.3916 .60623 m .39008 .60727 L .39248 .60437 L F
.274 0 .137 r
.39468 .60461 m .39248 .60437 L .39433 .6033 L F
.39468 .60461 m .3916 .60623 L .39248 .60437 L F
.676 .646 .812 r
.71802 .42381 m .72156 .42478 L .72055 .42295 L F
.682 .694 .855 r
.72055 .42295 m .72156 .42478 L .72402 .42383 L F
.223 0 0 r
.39142 .64207 m .3898 .64238 L .38752 .64202 L F
.108 .656 .821 r
.39396 .64267 m .3898 .64238 L .39142 .64207 L F
.907 .894 .478 r
.61262 .42542 m .61168 .42981 L .61409 .42678 L F
.87 .887 .844 r
.54123 .65907 m .54122 .66148 L .53885 .66196 L F
.876 .833 .8 r
.53885 .66196 m .54181 .66132 L .54123 .65907 L F
0 0 .101 r
.54181 .66132 m .54336 .66095 L .54123 .65907 L F
.674 .539 .693 r
.54094 .54158 m .53835 .54458 L .53853 .54221 L F
.925 .939 .791 r
.67143 .42282 m .67409 .42101 L .67368 .42081 L F
.933 .917 .536 r
.65641 .41368 m .65728 .41318 L .65651 .41503 L F
.983 .715 .331 r
.65631 .41126 m .65728 .41318 L .65641 .41368 L F
.628 .795 .963 r
.65869 .41084 m .65728 .41318 L .65641 .41368 L F
.887 .968 .835 r
.65869 .41084 m .65717 .41273 L .65629 .41221 L F
.65717 .41273 m .65641 .41368 L .65629 .41221 L F
0 0 .262 r
.65641 .41368 m .65699 .41477 L .65632 .41229 L F
.65641 .41368 m .65632 .41229 L .65629 .41221 L F
.886 .475 .051 r
.65523 .41158 m .65629 .41221 L .65699 .41477 L F
.65486 .41091 m .65629 .41221 L .65523 .41158 L F
.933 .917 .536 r
.65641 .41368 m .65651 .41503 L .65638 .41536 L F
.628 .795 .963 r
.65869 .41084 m .66009 .4123 L .65728 .41318 L F
.062 0 0 r
.51422 .54467 m .51154 .54627 L .5139 .54504 L F
.51154 .54627 m .51142 .54634 L .51158 .54626 L F
.51154 .54627 m .51158 .54626 L .5139 .54504 L F
.943 .646 .193 r
.51422 .54467 m .5139 .54504 L .51388 .54497 L F
.833 .663 .671 r
.51262 .54567 m .51154 .54627 L .51422 .54467 L F
.977 .837 .639 r
.5139 .54504 m .51142 .54634 L .51386 .54498 L F
.833 .663 .671 r
.51197 .54608 m .51158 .54625 L .51262 .54567 L F
.51158 .54625 m .51154 .54627 L .51262 .54567 L F
.51388 .54497 m .51197 .54608 L .51422 .54467 L F
.869 .658 .615 r
.51149 .54602 m .50886 .54443 L .51125 .54552 L F
.977 .837 .639 r
.51386 .54498 m .51145 .54632 L .51179 .54552 L F
.51278 .5434 m .51179 .54552 L .51271 .5433 L F
.51386 .54498 m .51179 .54552 L .51278 .5434 L F
.869 .658 .615 r
.51147 .54619 m .5083 .54756 L .50886 .54443 L F
.977 .837 .639 r
.51145 .54632 m .51142 .54634 L .51147 .54624 L F
.878 .472 .029 r
.5116 .54661 m .51371 .54976 L .5137 .54986 L F
.729 .857 .942 r
.5136 .55013 m .50921 .55077 L .51153 .54649 L F
.878 .472 .029 r
.51142 .54634 m .51157 .54656 L .5116 .54661 L F
.51157 .54656 m .51371 .54976 L .5116 .54661 L F
.863 .704 .683 r
.51142 .54634 m .51148 .54642 L .51163 .5463 L F
.655 .666 .848 r
.51159 .54657 m .51393 .54965 L .51157 .54656 L F
.51148 .54642 m .51393 .54965 L .51149 .54644 L F
.5131 .54884 m .51393 .54965 L .51371 .54976 L F
.51157 .54656 m .51247 .54773 L .5131 .54884 L F
.51247 .54773 m .51393 .54965 L .5131 .54884 L F
.128 0 .004 r
.5137 .54986 m .51371 .54976 L .51395 .55008 L F
.729 .857 .942 r
.51395 .55008 m .51191 .54675 L .5137 .54986 L F
.51191 .54675 m .51163 .5463 L .51243 .54767 L F
.51191 .54675 m .51243 .54767 L .5137 .54986 L F
.863 .704 .683 r
.51253 .54805 m .5137 .54986 L .51226 .54737 L F
.51253 .54805 m .51226 .54737 L .51163 .5463 L F
.5116 .54661 m .51253 .54805 L .51163 .5463 L F
.729 .857 .942 r
.51395 .55008 m .5136 .55013 L .51185 .54671 L F
.833 .663 .671 r
.51609 .54415 m .51494 .549 L .51177 .5466 L F
.729 .857 .942 r
.51176 .54655 m .51153 .54649 L .51163 .5463 L F
.51185 .54671 m .51177 .54666 L .51176 .54655 L F
.51177 .54666 m .51153 .54649 L .51176 .54655 L F
.869 .658 .615 r
.51163 .5463 m .51152 .54634 L .5115 .54631 L F
.863 .704 .683 r
.51142 .54634 m .51163 .5463 L .5114 .54624 L F
.869 .658 .615 r
.51163 .5463 m .51148 .54631 L .51155 .54628 L F
.51163 .5463 m .51155 .54628 L .51158 .54626 L F
.51148 .54623 m .51143 .54629 L .51147 .54619 L F
.51149 .54635 m .51144 .54631 L .51148 .54623 L F
.51144 .54631 m .51142 .54629 L .51148 .54623 L F
.977 .688 .305 r
.51318 .54234 m .51388 .54497 L .51271 .5433 L F
.51388 .54497 m .51386 .54498 L .51271 .5433 L F
.788 .684 .749 r
.51145 .54629 m .51355 .54348 L .51317 .5434 L F
.51144 .54631 m .51355 .54348 L .51145 .54629 L F
.977 .837 .639 r
.51145 .54632 m .51147 .54624 L .51271 .5433 L F
.788 .684 .749 r
.51147 .54624 m .51317 .5434 L .51271 .5433 L F
.51142 .54634 m .51317 .5434 L .51147 .54624 L F
.869 .658 .615 r
.51154 .54611 m .51147 .54619 L .51149 .54602 L F
.51161 .54625 m .51149 .5462 L .51154 .54611 L F
.51149 .5462 m .51147 .54619 L .51154 .54611 L F
.51163 .5463 m .51158 .54626 L .51161 .54625 L F
.833 .663 .671 r
.51178 .54617 m .51142 .54634 L .51154 .54627 L F
.869 .658 .615 r
.51158 .54626 m .51147 .54619 L .51161 .54625 L F
.833 .663 .671 r
.51155 .54628 m .51142 .54634 L .51154 .54628 L F
.51158 .54626 m .51154 .54628 L .51178 .54617 L F
.51155 .54628 m .51154 .54628 L .51158 .54626 L F
.5115 .5463 m .51142 .54634 L .51155 .54628 L F
.869 .658 .615 r
.51158 .54626 m .51155 .54628 L .51147 .54619 L F
.51155 .54628 m .51148 .54631 L .51148 .54626 L F
.51155 .54628 m .51148 .54626 L .51147 .54619 L F
.51147 .54619 m .50886 .54443 L .51149 .54602 L F
.863 .704 .683 r
.5114 .54624 m .51155 .54628 L .51125 .54552 L F
.51155 .54628 m .51163 .5463 L .51161 .54625 L F
.51155 .54628 m .51161 .54625 L .51125 .54552 L F
.833 .663 .671 r
.51172 .5462 m .51168 .54653 L .5115 .5463 L F
.51609 .54415 m .51175 .54649 L .51172 .5462 L F
.729 .857 .942 r
.51175 .5465 m .51176 .54655 L .51163 .5463 L F
.833 .663 .671 r
.51175 .54649 m .51168 .54653 L .51172 .5462 L F
.51609 .54415 m .51177 .5466 L .51175 .54649 L F
.9 .802 .743 r
.51146 .54636 m .50862 .54872 L .5083 .54756 L F
.655 .666 .848 r
.51142 .54634 m .51148 .54642 L .51149 .54644 L F
.833 .663 .671 r
.5115 .5463 m .51152 .54634 L .51142 .54634 L F
.9 .802 .743 r
.51148 .5464 m .51144 .54645 L .51145 .54641 L F
.833 .663 .671 r
.51197 .54608 m .5115 .5463 L .51178 .54617 L F
.977 .688 .305 r
.51388 .54497 m .5139 .54504 L .51386 .54498 L F
.833 .663 .671 r
.51337 .54543 m .51309 .54556 L .51388 .54497 L F
.51309 .54556 m .51197 .54608 L .51388 .54497 L F
.51609 .54415 m .51337 .54543 L .51422 .54467 L F
.788 .684 .749 r
.51152 .54621 m .51494 .549 L .51355 .54348 L F
.869 .658 .615 r
.5115 .54631 m .51149 .54635 L .51148 .54631 L F
.788 .684 .749 r
.51144 .54631 m .51149 .54635 L .51152 .54621 L F
.9 .802 .743 r
.51148 .54639 m .51148 .54642 L .51148 .5464 L F
.51163 .5463 m .51149 .54641 L .51148 .54639 L F
.51149 .54641 m .51148 .54642 L .51148 .54639 L F
.51163 .5463 m .51145 .54641 L .51152 .54634 L F
.869 .658 .615 r
.51152 .54634 m .51149 .54635 L .5115 .54631 L F
.788 .684 .749 r
.51149 .54635 m .51494 .549 L .51152 .54621 L F
0 .21 .658 r
.51883 .54356 m .51574 .54134 L .51677 .542 L F
.613 .414 .589 r
.51907 .54125 m .51883 .54356 L .51677 .542 L F
0 .21 .658 r
.51776 .54279 m .51808 .54286 L .51574 .54134 L F
.51883 .54356 m .51808 .54286 L .51776 .54279 L F
0 0 0 r
.51883 .54356 m .51794 .54537 L .51808 .54286 L F
.781 .658 .104 r
.51808 .54286 m .51788 .54345 L .51849 .54294 L F
.773 .675 .755 r
.52284 .54193 m .51883 .54356 L .51907 .54125 L F
.781 .658 .104 r
.51808 .54286 m .51821 .54289 L .52008 .5416 L F
.604 .91 .981 r
.51907 .54125 m .51677 .542 L .51574 .54134 L F
.51907 .54125 m .51574 .54134 L .5175 .53986 L F
.542 .109 .167 r
.52008 .5416 m .51626 .54172 L .51808 .54286 L F
.781 .658 .104 r
.51821 .54289 m .51924 .54231 L .52008 .5416 L F
.542 .109 .167 r
.52008 .5416 m .51962 .54222 L .5194 .54219 L F
.52008 .5416 m .5194 .54219 L .51626 .54172 L F
.471 .768 .995 r
.52008 .5416 m .5228 .54189 L .5212 .54071 L F
.52008 .5416 m .5228 .54189 L .5212 .54071 L F
0 0 0 r
.5212 .54071 m .51962 .54222 L .52008 .5416 L F
.695 .78 .916 r
.5212 .54071 m .51962 .54222 L .5195 .54211 L F
0 0 0 r
.52008 .5416 m .51878 .54271 L .5212 .54071 L F
.912 .873 .786 r
.51974 .53931 m .51907 .54125 L .5175 .53986 L F
.695 .78 .916 r
.5212 .54071 m .5195 .54211 L .51751 .54024 L F
0 0 0 r
.51932 .54225 m .51788 .54345 L .51878 .54271 L F
.397 .664 .967 r
.51945 .5422 m .51954 .54215 L .5195 .54211 L F
.51942 .54217 m .5195 .54211 L .51751 .54024 L F
.51945 .5422 m .5195 .54211 L .51942 .54217 L F
0 0 0 r
.5194 .54219 m .51897 .54254 L .51932 .54225 L F
.52008 .5416 m .51924 .54231 L .5194 .54219 L F
.51924 .54231 m .51897 .54254 L .5194 .54219 L F
.51897 .54254 m .51788 .54345 L .51932 .54225 L F
.397 .664 .967 r
.51626 .54172 m .51945 .5422 L .51751 .54024 L F
.51945 .5422 m .51962 .54222 L .51954 .54215 L F
.781 .658 .104 r
.51821 .54289 m .51849 .54294 L .51924 .54231 L F
.39 .226 .535 r
.51808 .54286 m .51494 .549 L .51609 .54415 L F
.769 .673 .757 r
.51405 .54547 m .51494 .549 L .51726 .54445 L F
.602 .68 .896 r
.51461 .54713 m .51636 .54842 L .51147 .54636 L F
.833 .663 .671 r
.51152 .54634 m .51148 .54638 L .51142 .54634 L F
.9 .802 .743 r
.51163 .5463 m .51151 .54652 L .51148 .54642 L F
.863 .704 .683 r
.51148 .54642 m .5116 .54658 L .51163 .5463 L F
.833 .663 .671 r
.51152 .54634 m .51168 .54653 L .51148 .54638 L F
.788 .684 .749 r
.51142 .54634 m .51148 .54638 L .51144 .54631 L F
.51148 .54638 m .51168 .54653 L .51149 .54635 L F
.51148 .54638 m .51149 .54635 L .51144 .54631 L F
.729 .857 .942 r
.51191 .54675 m .51185 .54671 L .51176 .54655 L F
.51157 .54656 m .51153 .54649 L .51185 .54671 L F
.655 .666 .848 r
.51148 .54642 m .51556 .54883 L .5116 .54658 L F
.51142 .54634 m .51147 .54637 L .51148 .54642 L F
.833 .663 .671 r
.51175 .54649 m .51177 .5466 L .51168 .54653 L F
.729 .857 .942 r
.51181 .54658 m .51176 .54655 L .51175 .5465 L F
.788 .684 .749 r
.51177 .5466 m .51494 .549 L .5118 .54659 L F
.729 .857 .942 r
.51191 .54675 m .51179 .54659 L .51181 .54658 L F
.51179 .54659 m .51176 .54655 L .51181 .54658 L F
.788 .684 .749 r
.51168 .54653 m .51177 .5466 L .51144 .54631 L F
.9 .802 .743 r
.51152 .54634 m .51148 .54638 L .51149 .54635 L F
.788 .684 .749 r
.51177 .5466 m .5118 .54659 L .51144 .54631 L F
.655 .666 .848 r
.51147 .54637 m .51556 .54883 L .51148 .54642 L F
.9 .802 .743 r
.51147 .54636 m .51145 .54641 L .51146 .54636 L F
.51149 .54635 m .51147 .54638 L .51147 .54636 L F
.51147 .54638 m .51145 .54641 L .51147 .54636 L F
.51148 .54638 m .51145 .54641 L .51149 .54635 L F
.788 .684 .749 r
.51142 .54634 m .51144 .54631 L .51145 .54629 L F
.869 .658 .615 r
.51149 .54635 m .51147 .54636 L .51142 .54629 L F
.602 .68 .896 r
.51145 .54635 m .51146 .54636 L .51142 .54634 L F
.655 .666 .848 r
.51142 .54634 m .51146 .54636 L .51147 .54637 L F
.602 .68 .896 r
.51145 .54635 m .51142 .54634 L .5114 .54624 L F
.869 .658 .615 r
.51147 .54636 m .51141 .54631 L .51142 .54629 L F
.655 .666 .848 r
.51146 .54636 m .51147 .54636 L .51147 .54636 L F
.51146 .54636 m .51147 .54636 L .51147 .54637 L F
.869 .658 .615 r
.51146 .54636 m .51138 .5464 L .51141 .54631 L F
.51147 .54636 m .51147 .54636 L .51146 .54636 L F
.51147 .54636 m .51138 .5464 L .51146 .54636 L F
.602 .68 .896 r
.51146 .54635 m .51147 .54636 L .51146 .54636 L F
.51146 .54635 m .51146 .54636 L .51145 .54635 L F
.51461 .54713 m .51147 .54636 L .51146 .54635 L F
.9 .802 .743 r
.51148 .54642 m .51144 .54645 L .51148 .5464 L F
.655 .666 .848 r
.51147 .54637 m .51636 .54842 L .51556 .54883 L F
.51147 .54636 m .51636 .54842 L .51147 .54637 L F
.9 .802 .743 r
.51144 .54645 m .50862 .54872 L .51146 .54636 L F
.602 .68 .896 r
.51159 .54568 m .51145 .54635 L .51125 .54552 L F
.51461 .54713 m .51146 .54635 L .51159 .54568 L F
.51146 .54635 m .51145 .54635 L .51159 .54568 L F
.51145 .54635 m .5114 .54624 L .51125 .54552 L F
.655 .666 .848 r
.5116 .54658 m .51556 .54883 L .51393 .54965 L F
.729 .857 .942 r
.51395 .55008 m .51185 .54671 L .51191 .54675 L F
.655 .666 .848 r
.51149 .54644 m .51159 .54657 L .51157 .54656 L F
.9 .802 .743 r
.51148 .54642 m .50921 .55077 L .50862 .54872 L F
.51151 .54652 m .50921 .55077 L .51148 .54642 L F
.729 .857 .942 r
.5136 .55013 m .51157 .54656 L .51185 .54671 L F
.863 .704 .683 r
.51142 .54634 m .5116 .54661 L .5116 .54658 L F
.869 .658 .615 r
.51138 .5464 m .5083 .54756 L .51147 .54619 L F
.943 .646 .193 r
.51422 .54467 m .51388 .54497 L .51318 .54234 L F
.214 .181 .603 r
.51574 .54134 m .51422 .54467 L .51318 .54234 L F
.51574 .54134 m .51609 .54415 L .51422 .54467 L F
.471 .368 .657 r
.51808 .54286 m .51609 .54415 L .51574 .54134 L F
.769 .673 .757 r
.51355 .54348 m .51399 .54521 L .51808 .54286 L F
.51399 .54521 m .51405 .54547 L .51543 .54458 L F
.51399 .54521 m .51543 .54458 L .51808 .54286 L F
.51405 .54547 m .51726 .54445 L .51808 .54286 L F
.125 0 0 r
.18462 .54126 m .18681 .5413 L .18837 .5411 L F
.441 .854 .961 r
.18681 .5413 m .19064 .54101 L .18837 .5411 L F
0 0 0 r
.40225 .57966 m .4015 .58014 L .40373 .57952 L F
.26 .539 .921 r
.25543 .55056 m .25507 .55207 L .25324 .55039 L F
.25543 .55056 m .25742 .5528 L .25507 .55207 L F
.802 .959 .914 r
.66584 .40942 m .66211 .41086 L .66474 .40936 L F
.652 .97 .859 r
.66727 .40774 m .66845 .40771 L .66584 .40942 L F
.652 .97 .86 r
.66727 .40774 m .66584 .40942 L .66474 .40936 L F
0 0 .067 r
.63379 .44722 m .63448 .44501 L .63575 .44342 L F
.58 .718 .937 r
.69224 .40399 m .68882 .40288 L .69123 .40221 L F
.574 .699 .926 r
.69471 .40341 m .69224 .40399 L .69123 .40221 L F
.561 .751 .966 r
.54904 .68234 m .5487 .68037 L .54617 .681 L F
.536 .906 .958 r
.55221 .6799 m .5487 .68037 L .54904 .68234 L F
.516 .306 .533 r
.55651 .5273 m .55886 .52911 L .5564 .52959 L F
.55651 .5273 m .55884 .52677 L .55886 .52911 L F
.318 0 .221 r
.25637 .56137 m .25605 .5618 L .25424 .56199 L F
.434 .428 .753 r
.25685 .56483 m .25424 .56199 L .25605 .5618 L F
0 0 .014 r
.54353 .53907 m .54569 .53557 L .54616 .53855 L F
.608 .428 .612 r
.54616 .53855 m .5435 .54106 L .54353 .53907 L F
.413 .278 .586 r
.25666 .57651 m .25434 .57957 L .25422 .57707 L F
.25666 .57651 m .25688 .57919 L .25434 .57957 L F
.395 .231 .538 r
.25688 .57919 m .25459 .58198 L .25434 .57957 L F
.35 .491 .859 r
.18876 .55931 m .19096 .56216 L .19048 .55882 L F
.64 .62 .814 r
.71061 .40615 m .70905 .40949 L .70819 .40719 L F
.71061 .40615 m .71157 .40918 L .70905 .40949 L F
.664 .198 0 r
.67521 .43614 m .67503 .43551 L .67364 .43429 L F
.67521 .43614 m .67617 .43717 L .67503 .43551 L F
.508 .606 .885 r
.18828 .55625 m .18908 .55413 L .18734 .55463 L F
.18828 .55625 m .1907 .55591 L .18908 .55413 L F
.233 .083 .462 r
.18876 .55931 m .1907 .55591 L .18828 .55625 L F
.397 0 0 r
.45917 .63133 m .4625 .63017 L .45888 .63088 L F
.45917 .63133 m .46102 .6317 L .4625 .63017 L F
.621 .165 .149 r
.4625 .63017 m .46102 .6317 L .46457 .63164 L F
.614 .18 .195 r
.46457 .63164 m .46501 .63066 L .4625 .63017 L F
.677 .586 .746 r
.40382 .59623 m .4029 .5984 L .40049 .59764 L F
.616 .241 .309 r
.4029 .5984 m .40082 .59942 L .40049 .59764 L F
.794 .974 .909 r
.64607 .44486 m .64353 .44669 L .64226 .44642 L F
.512 .365 .618 r
.60105 .47945 m .60291 .47846 L .60264 .47696 L F
.251 0 .199 r
.60269 .48075 m .60105 .47945 L .60063 .48177 L F
.60269 .48075 m .60291 .47846 L .60105 .47945 L F
.878 .646 .584 r
.67028 .43149 m .67329 .42996 L .67225 .42883 L F
.67028 .43149 m .67276 .43372 L .67329 .42996 L F
.587 .355 .53 r
.59426 .50346 m .59412 .5058 L .59122 .50655 L F
.463 .252 .507 r
.59666 .50562 m .59426 .50346 L .59665 .50303 L F
.59666 .50562 m .59412 .5058 L .59426 .50346 L F
0 0 .481 r
.21924 .55883 m .21942 .56274 L .22045 .56081 L F
.745 .826 .915 r
.7276 .42892 m .73303 .42842 L .73019 .42609 L F
.562 .699 .933 r
.73019 .42609 m .73303 .42842 L .73368 .42701 L F
.709 .838 .401 r
.62478 .41052 m .62382 .41274 L .62548 .40948 L F
.884 .97 .838 r
.57361 .46531 m .57531 .46158 L .57571 .46228 L F
.57361 .46531 m .57276 .46458 L .57531 .46158 L F
.555 .833 .997 r
.67877 .46869 m .67544 .46823 L .6776 .46723 L F
.67877 .46869 m .67544 .46823 L .6776 .46723 L F
.559 .765 .974 r
.67877 .46869 m .68122 .46822 L .6776 .46723 L F
.67877 .46869 m .68122 .46822 L .6776 .46723 L F
.626 .221 .255 r
.42377 .6407 m .42005 .64088 L .42188 .63891 L F
.66 .201 .151 r
.42391 .63959 m .42377 .6407 L .42188 .63891 L F
.849 .828 .826 r
.68387 .46488 m .68401 .46684 L .68122 .46822 L F
.316 0 0 r
.68122 .46822 m .68401 .46684 L .68396 .4678 L F
.099 .654 .785 r
.68401 .46684 m .68657 .46674 L .68616 .46662 L F
.106 0 0 r
.68396 .4678 m .68401 .46684 L .68616 .46662 L F
.912 .885 .793 r
.19001 .6442 m .18989 .64759 L .18823 .64584 L F
.258 .297 .712 r
.47385 .57602 m .47235 .57761 L .47146 .57404 L F
.527 .291 .501 r
.47469 .57913 m .47235 .57761 L .47385 .57602 L F
.47469 .57913 m .47225 .57974 L .47235 .57761 L F
.146 0 .12 r
.60968 .49153 m .61253 .48884 L .61221 .49092 L F
.327 0 .248 r
.61221 .49092 m .61253 .48884 L .61483 .48793 L F
.889 .988 .738 r
.57571 .46228 m .57752 .45835 L .578 .45924 L F
.57571 .46228 m .57531 .46158 L .57752 .45835 L F
.864 .988 .839 r
.578 .45924 m .58 .45557 L .58054 .4562 L F
.578 .45924 m .57752 .45835 L .58 .45557 L F
.185 0 0 r
.55641 .62036 m .5553 .62004 L .55397 .6203 L F
.514 .639 .91 r
.55789 .62117 m .5553 .62004 L .55901 .62086 L F
.185 0 0 r
.55641 .62036 m .55901 .62086 L .5553 .62004 L F
.554 .272 .442 r
.70153 .44921 m .70494 .44751 L .70125 .44717 L F
.70153 .44921 m .70499 .4496 L .70494 .44751 L F
.603 .31 .444 r
.70494 .44751 m .70743 .44931 L .70758 .44742 L F
.70494 .44751 m .70499 .4496 L .70743 .44931 L F
.256 .747 .915 r
.20925 .5529 m .20735 .55252 L .20521 .55271 L F
.187 .703 .886 r
.21125 .5528 m .20735 .55252 L .20925 .5529 L F
.677 .543 .695 r
.54094 .54158 m .54178 .54478 L .53835 .54458 L F
.555 .372 .588 r
.54178 .54478 m .5394 .54801 L .53835 .54458 L F
.517 .27 .479 r
.48167 .62137 m .48407 .62098 L .48429 .6187 L F
.19 0 .115 r
.48407 .62098 m .48741 .61785 L .48429 .6187 L F
.677 .567 .724 r
.69592 .44751 m .69897 .4501 L .69779 .4467 L F
.584 .245 .361 r
.71295 .45519 m .71238 .45613 L .70988 .45613 L F
.588 .25 .363 r
.71568 .45528 m .71295 .45519 L .7148 .45298 L F
.71568 .45528 m .71238 .45613 L .71295 .45519 L F
.73 .612 .726 r
.70125 .44717 m .69897 .4501 L .70153 .44921 L F
.508 .337 .584 r
.69971 .45261 m .70153 .44921 L .69897 .4501 L F
.69971 .45261 m .70242 .45214 L .70153 .44921 L F
.229 0 .239 r
.70242 .45214 m .70499 .4496 L .70153 .44921 L F
.794 .974 .909 r
.64607 .44486 m .64279 .4462 L .64463 .44603 L F
.873 .468 .257 r
.64463 .44603 m .64646 .44681 L .64607 .44486 L F
.289 .078 .41 r
.64607 .44486 m .64646 .44681 L .64766 .44456 L F
.64607 .44486 m .64646 .44681 L .64766 .44456 L F
.384 .668 .971 r
.64517 .44439 m .64662 .44583 L .64463 .44603 L F
.64662 .44583 m .6469 .44612 L .64463 .44603 L F
.794 .974 .909 r
.64279 .4462 m .64226 .44642 L .64463 .44603 L F
.102 .097 .565 r
.64668 .44078 m .64607 .44486 L .64634 .44452 L F
.64668 .44078 m .64634 .44452 L .6469 .4413 L F
.6469 .4413 m .64634 .44452 L .64759 .44295 L F
.64668 .44078 m .64759 .44295 L .64642 .4412 L F
.535 .109 .179 r
.65006 .44011 m .64668 .44078 L .64642 .4412 L F
.65006 .44011 m .64694 .44105 L .64843 .43993 L F
.64694 .44105 m .64642 .4412 L .64697 .44085 L F
.64694 .44105 m .64697 .44085 L .64843 .43993 L F
.38 .496 .851 r
.64607 .44486 m .64766 .44456 L .64759 .44295 L F
.665 .53 .689 r
.52441 .56263 m .52195 .56541 L .52205 .56333 L F
.673 .594 .759 r
.5111 .67728 m .51282 .68111 L .51005 .6806 L F
0 0 .348 r
.5111 .67728 m .51005 .6806 L .51091 .68032 L F
.673 .297 .325 r
.51282 .68111 m .51271 .68277 L .51005 .6806 L F
0 .151 .651 r
.51005 .6806 m .51236 .68218 L .51091 .68032 L F
.51005 .6806 m .51271 .68277 L .51236 .68218 L F
.55 0 0 r
.21779 .5552 m .21698 .5548 L .21509 .55329 L F
.341 .734 .984 r
.21779 .5552 m .21892 .55431 L .21698 .5548 L F
.21779 .5552 m .22119 .55533 L .21892 .55431 L F
.883 .841 .799 r
.58998 .47097 m .59289 .47041 L .59146 .46914 L F
.58998 .47097 m .59065 .47392 L .59289 .47041 L F
.878 .873 .828 r
.59146 .46914 m .59289 .47041 L .59496 .46774 L F
.95 .798 .658 r
.65493 .44653 m .65751 .44446 L .65631 .44358 L F
.65493 .44653 m .65618 .44713 L .65751 .44446 L F
.841 .82 .829 r
.58907 .47275 m .59065 .47392 L .58998 .47097 L F
.867 .813 .794 r
.58829 .47696 m .59065 .47392 L .58907 .47275 L F
0 0 0 r
.19892 .66543 m .19744 .66676 L .19827 .66608 L F
.973 .741 .526 r
.19968 .66468 m .19892 .66543 L .20036 .66571 L F
.151 .432 .869 r
.20057 .66417 m .20036 .66571 L .19866 .66314 L F
0 0 .108 r
.20057 .66417 m .20055 .66734 L .20036 .66571 L F
0 0 0 r
.19959 .66492 m .19977 .66483 L .20057 .66417 L F
.973 .741 .526 r
.19866 .66314 m .19892 .66543 L .19968 .66468 L F
.656 .517 .682 r
.19573 .66521 m .19892 .66543 L .19866 .66314 L F
.817 .508 0 r
.19839 .66354 m .19866 .66314 L .19956 .66363 L F
.19996 .66399 m .19956 .66363 L .20057 .66417 L F
.19839 .66354 m .19956 .66363 L .19996 .66399 L F
0 0 .489 r
.20101 .6669 m .20123 .66638 L .20049 .66449 L F
.514 .391 .65 r
.20014 .66174 m .20057 .66417 L .19866 .66314 L F
0 0 0 r
.19892 .66543 m .19827 .66608 L .19977 .66483 L F
.19892 .66543 m .19977 .66483 L .19959 .66492 L F
.301 0 .098 r
.19866 .66314 m .19507 .66479 L .19573 .66521 L F
.19866 .66314 m .19879 .66445 L .19507 .66479 L F
.61 .666 .879 r
.19813 .6644 m .19839 .66354 L .19922 .66529 L F
.301 0 .098 r
.19879 .66445 m .19881 .66465 L .19845 .66466 L F
.19879 .66445 m .19845 .66466 L .19507 .66479 L F
.622 .279 .369 r
.19573 .66521 m .19744 .66676 L .19892 .66543 L F
.61 .666 .879 r
.19744 .66676 m .19796 .66498 L .19922 .66529 L F
.19796 .66498 m .19813 .6644 L .19845 .66466 L F
.19796 .66498 m .19845 .66466 L .19922 .66529 L F
.817 .508 0 r
.19839 .66354 m .19881 .66465 L .19866 .66314 L F
.61 .666 .879 r
.19922 .66529 m .19839 .66354 L .20057 .66417 L F
0 .035 .59 r
.20009 .66346 m .20048 .66677 L .20056 .66613 L F
.20048 .66677 m .20055 .66734 L .20056 .66669 L F
.20048 .66677 m .20056 .66669 L .20056 .66613 L F
0 0 0 r
.19744 .66676 m .19748 .66749 L .20024 .66703 L F
.2007 .66689 m .20079 .66694 L .20101 .6669 L F
0 .035 .59 r
.20023 .66462 m .20035 .66483 L .20053 .66582 L F
.20023 .66462 m .20061 .66614 L .20048 .66677 L F
.61 .666 .879 r
.2007 .66689 m .20101 .6669 L .20065 .66643 L F
.355 0 0 r
.20079 .66694 m .20123 .66638 L .20101 .6669 L F
0 .035 .59 r
.20061 .66614 m .20081 .66691 L .2007 .66689 L F
.20081 .66691 m .20079 .66694 L .2007 .66689 L F
.20061 .66614 m .2007 .66689 L .20048 .66677 L F
0 0 .126 r
.20055 .66734 m .20017 .66824 L .20036 .66571 L F
.61 .666 .879 r
.19744 .66676 m .2007 .66689 L .19927 .66467 L F
.2007 .66689 m .20065 .66643 L .19927 .66467 L F
0 0 .489 r
.20101 .6669 m .20009 .66346 L .20065 .66643 L F
0 .035 .59 r
.20053 .66582 m .20123 .66638 L .20082 .66696 L F
0 0 0 r
.20038 .66688 m .20024 .66703 L .20079 .66694 L F
0 .035 .59 r
.20048 .66677 m .20082 .66696 L .20055 .66734 L F
0 0 0 r
.20038 .66688 m .20079 .66694 L .2007 .66689 L F
.19744 .66676 m .20024 .66703 L .20038 .66688 L F
0 .035 .59 r
.20009 .66346 m .20056 .66613 L .20057 .66417 L F
0 0 .489 r
.20101 .6669 m .20049 .66449 L .20032 .66433 L F
.355 0 0 r
.19748 .66749 m .20123 .66638 L .20079 .66694 L F
0 .035 .59 r
.20081 .66691 m .20082 .66696 L .20079 .66694 L F
0 0 .489 r
.20065 .66643 m .20009 .66346 L .19839 .66354 L F
0 .035 .59 r
.20035 .66483 m .20123 .66638 L .20053 .66582 L F
.61 .666 .879 r
.19813 .6644 m .19848 .66448 L .19839 .66354 L F
.803 .808 .854 r
.19772 .6641 m .19848 .66448 L .19839 .66354 L F
.19848 .66448 m .19881 .66465 L .19839 .66354 L F
.61 .666 .879 r
.19848 .66448 m .19927 .66467 L .19839 .66354 L F
.272 .677 .969 r
.19507 .66479 m .19845 .66466 L .1981 .6644 L F
.19845 .66466 m .19881 .66465 L .19783 .66416 L F
.61 .666 .879 r
.19744 .66676 m .19927 .66467 L .19813 .6644 L F
.272 .677 .969 r
.19731 .66421 m .1981 .6644 L .19772 .6641 L F
.19507 .66479 m .1981 .6644 L .19731 .66421 L F
.19845 .66466 m .19783 .66416 L .19772 .6641 L F
0 0 .489 r
.20032 .66433 m .20049 .66449 L .20009 .66346 L F
0 .035 .59 r
.20009 .66346 m .20049 .6645 L .20023 .66462 L F
.20049 .6645 m .20123 .66638 L .20023 .66462 L F
.63 .619 .82 r
.71681 .42035 m .71802 .42381 L .72055 .42295 L F
.51 .065 .129 r
.4275 .639 m .42377 .6407 L .42391 .63959 L F
.4275 .639 m .42605 .6408 L .42377 .6407 L F
.468 .013 .087 r
.42986 .63911 m .42605 .6408 L .4275 .639 L F
.349 0 0 r
.41918 .63026 m .4214 .63029 L .42258 .62962 L F
.557 .08 .079 r
.4214 .63029 m .42488 .63012 L .42258 .62962 L F
.014 .156 .668 r
.39565 .62896 m .39482 .63041 L .39386 .62692 L F
.444 .724 .985 r
.39565 .62896 m .39716 .63034 L .39482 .63041 L F
.144 0 0 r
.38996 .58459 m .39301 .58307 L .39084 .58376 L F
.95 .877 .728 r
.66711 .45389 m .66491 .45487 L .66557 .45259 L F
.66711 .45389 m .66609 .45623 L .66491 .45487 L F
.186 .667 .93 r
.22439 .54229 m .22676 .54231 L .22863 .54323 L F
.28 0 0 r
.22676 .54231 m .23024 .54327 L .22863 .54323 L F
.121 .548 .919 r
.37729 .63255 m .3775 .63162 L .37523 .62979 L F
.37729 .63255 m .37851 .63255 L .3775 .63162 L F
.851 .988 .719 r
.62911 .44316 m .63057 .44231 L .6287 .44473 L F
.798 .981 .9 r
.6323 .44067 m .63057 .44231 L .63135 .44024 L F
.829 .988 .721 r
.63135 .44024 m .63057 .44231 L .62911 .44316 L F
.591 .77 .965 r
.64111 .45103 m .64493 .45141 L .6435 .45002 L F
.319 .315 .697 r
.64629 .4495 m .64688 .45254 L .64493 .45141 L F
0 .267 .72 r
.64493 .45141 m .64604 .45181 L .6435 .45002 L F
.64493 .45141 m .64688 .45254 L .64604 .45181 L F
.985 .708 .402 r
.73096 .41709 m .73151 .41976 L .73224 .4191 L F
.257 0 0 r
.73224 .4191 m .73151 .41976 L .73558 .41884 L F
.547 .348 .563 r
.49816 .58318 m .49814 .58591 L .49563 .58613 L F
.49563 .58613 m .49814 .58591 L .49816 .58318 L F
.474 .291 .551 r
.50032 .58507 m .49814 .58591 L .49816 .58318 L F
.49816 .58318 m .49814 .58591 L .50032 .58507 L F
.547 .348 .563 r
.49816 .58318 m .49814 .58591 L .49563 .58613 L F
.469 .208 .436 r
.58846 .5087 m .58872 .50665 L .59119 .50778 L F
.513 .096 .188 r
.58872 .50665 m .59122 .50655 L .59119 .50778 L F
.123 0 0 r
.46829 .63386 m .46496 .63544 L .46632 .63431 L F
.768 .607 .679 r
.20425 .62089 m .20271 .62418 L .20602 .624 L F
.468 .329 .608 r
.20271 .62418 m .20474 .62622 L .20602 .624 L F
0 0 0 r
.20602 .624 m .20731 .62369 L .2085 .62137 L F
.047 0 0 r
.20602 .624 m .20634 .62553 L .20731 .62369 L F
.20602 .624 m .20474 .62622 L .20634 .62553 L F
.126 0 .233 r
.69971 .45261 m .70107 .45371 L .70242 .45214 L F
.69971 .45261 m .6993 .45518 L .70107 .45371 L F
.282 0 .273 r
.60739 .49404 m .60968 .49153 L .60959 .49381 L F
.271 0 .277 r
.60959 .49381 m .60968 .49153 L .61221 .49092 L F
.935 .697 .555 r
.55259 .67082 m .55212 .67419 L .5538 .67461 L F
.832 .616 .611 r
.55212 .67419 m .55478 .67699 L .5538 .67461 L F
.57 .505 .743 r
.25666 .57651 m .25422 .57707 L .25381 .57479 L F
.878 .873 .828 r
.59146 .46914 m .59496 .46774 L .59236 .46778 L F
.481 .145 .319 r
.41286 .63295 m .41646 .63011 L .41309 .63072 L F
.41286 .63295 m .41546 .6327 L .41646 .63011 L F
.313 0 .243 r
.41646 .63011 m .41734 .63195 L .41918 .63026 L F
.41646 .63011 m .41546 .6327 L .41734 .63195 L F
.072 0 .354 r
.2085 .62137 m .20993 .62051 L .21028 .61814 L F
.29 0 .164 r
.2085 .62137 m .20938 .62304 L .20993 .62051 L F
.2085 .62137 m .20731 .62369 L .20938 .62304 L F
.994 .75 .435 r
.64836 .4564 m .64723 .4553 L .64688 .45254 L F
.779 .678 .753 r
.64478 .45592 m .6461 .45942 L .64836 .4564 L F
.886 .906 .837 r
.64961 .4523 m .64836 .4564 L .65096 .4546 L F
.64961 .4523 m .64723 .4553 L .64836 .4564 L F
.37 .834 .896 r
.20197 .55209 m .20142 .55224 L .20135 .5527 L F
.20142 .55224 m .1999 .55266 L .20135 .5527 L F
.032 .534 .875 r
.20131 .55299 m .20135 .5527 L .19974 .55238 L F
.20305 .55367 m .20135 .5527 L .20131 .55299 L F
.297 .776 .923 r
.20521 .55271 m .20135 .5527 L .20305 .55367 L F
.688 .469 .585 r
.53281 .56218 m .53386 .56513 L .53017 .56497 L F
.59 .464 .677 r
.53446 .55844 m .53281 .56218 L .53269 .5595 L F
.53446 .55844 m .53579 .56241 L .53281 .56218 L F
.667 .458 .593 r
.53634 .56486 m .53281 .56218 L .53579 .56241 L F
.53634 .56486 m .53386 .56513 L .53281 .56218 L F
.823 .999 .828 r
.62478 .41052 m .62215 .41317 L .62382 .41274 L F
.647 .497 .665 r
.57557 .51562 m .57561 .51803 L .57328 .51803 L F
.584 .228 .332 r
.57328 .51803 m .57621 .51976 L .57284 .5199 L F
.57328 .51803 m .57561 .51803 L .57621 .51976 L F
.616 .241 .309 r
.4029 .5984 m .40314 .5997 L .40082 .59942 L F
.879 .835 .799 r
.40506 .59481 m .4029 .5984 L .40382 .59623 L F
.686 .558 .704 r
.40627 .59828 m .4029 .5984 L .40506 .59481 L F
.813 .645 .673 r
.40627 .59828 m .40314 .5997 L .4029 .5984 L F
.422 .656 .957 r
.37324 .62994 m .37416 .62826 L .37181 .62849 L F
.37324 .62994 m .37523 .62979 L .37416 .62826 L F
.535 0 0 r
.51237 .66274 m .51499 .66509 L .51381 .66417 L F
.59 .379 .563 r
.51559 .66246 m .51499 .66509 L .51237 .66274 L F
.535 0 0 r
.51237 .66274 m .51381 .66417 L .51559 .66246 L F
.816 .889 .465 r
.6103 .43178 m .61031 .43249 L .61168 .42981 L F
.907 .894 .478 r
.61262 .42542 m .61141 .42909 L .61168 .42981 L F
.907 .892 .474 r
.61168 .42981 m .61141 .42909 L .6103 .43178 L F
.562 .132 .183 r
.53612 .6996 m .53516 .7012 L .53807 .70045 L F
.971 .738 .529 r
.5478 .66864 m .54612 .67015 L .54689 .66794 L F
.5478 .66864 m .54753 .67134 L .54612 .67015 L F
.704 .165 0 r
.4414 .57699 m .44319 .57882 L .44493 .57925 L F
.364 .806 .956 r
.44493 .57925 m .44319 .57882 L .44762 .57885 L F
.345 .809 .927 r
.5597 .6205 m .55789 .62117 L .55901 .62086 L F
.326 .29 .665 r
.5597 .6205 m .55894 .62234 L .55789 .62117 L F
0 0 .144 r
.75305 .42418 m .75228 .42414 L .75315 .42211 L F
.75305 .42418 m .75209 .4263 L .75228 .42414 L F
.945 .692 .523 r
.36138 .61876 m .36269 .62189 L .3606 .62054 L F
.027 .205 .712 r
.36138 .61876 m .36269 .62189 L .36326 .62033 L F
.812 .962 .636 r
.58239 .45284 m .58218 .45241 L .58431 .44925 L F
.642 .963 .909 r
.4219 .57156 m .42283 .57014 L .42351 .57038 L F
.658 .972 .854 r
.4219 .57156 m .4198 .5721 L .42283 .57014 L F
.559 .164 .249 r
.58422 .62199 m .58226 .62483 L .5794 .62417 L F
.58226 .62483 m .58225 .62483 L .58225 .62483 L F
.58226 .62483 m .58225 .62483 L .5794 .62417 L F
.586 .217 .309 r
.58671 .62222 m .58422 .62199 L .58196 .62053 L F
.674 .603 .767 r
.58422 .62199 m .58667 .6224 L .58671 .62222 L F
.586 .217 .309 r
.58671 .62222 m .58541 .62362 L .58422 .62199 L F
.893 .929 .548 r
.58222 .62501 m .58422 .62199 L .58541 .62362 L F
.888 .508 .311 r
.58194 .62495 m .58184 .62543 L .58222 .62501 L F
.559 .164 .249 r
.58194 .62495 m .58184 .62543 L .58133 .62517 L F
.58225 .62483 m .58133 .62517 L .5794 .62417 L F
0 0 0 r
.57979 .62446 m .5794 .62417 L .58184 .62543 L F
.888 .508 .311 r
.57979 .62446 m .58184 .62543 L .58194 .62495 L F
.58194 .62495 m .58222 .62501 L .58227 .62483 L F
.559 .164 .249 r
.58225 .62483 m .58184 .62543 L .58194 .62495 L F
.893 .929 .548 r
.58222 .62501 m .58184 .62543 L .58422 .62199 L F
.743 .731 .841 r
.58476 .61969 m .58671 .62222 L .58196 .62053 L F
.489 .633 .917 r
.58805 .62097 m .58671 .62222 L .58476 .61969 L F
.707 .812 .93 r
.58312 .62165 m .58227 .62483 L .58664 .62196 L F
.58227 .62483 m .58222 .62501 L .58256 .62478 L F
.58227 .62483 m .58256 .62478 L .58664 .62196 L F
.88 .96 .848 r
.57948 .62071 m .57701 .62394 L .57573 .62344 L F
.57948 .62071 m .57924 .62119 L .57701 .62394 L F
.608 .744 .941 r
.58051 .61915 m .57924 .62119 L .57948 .62071 L F
.58051 .61915 m .58196 .62053 L .57924 .62119 L F
.882 .824 .786 r
.57441 .62206 m .57948 .62071 L .57573 .62344 L F
.57441 .62206 m .57676 .61917 L .57948 .62071 L F
.314 .704 .979 r
.57948 .62071 m .57992 .61912 L .58051 .61915 L F
.57948 .62071 m .57676 .61917 L .57992 .61912 L F
.751 .656 .755 r
.57745 .62201 m .58123 .62348 L .57992 .61912 L F
.484 .59 .884 r
.57745 .62201 m .57979 .62446 L .58123 .62348 L F
.634 .587 .784 r
.57992 .61912 m .58123 .62348 L .58312 .62165 L F
.787 .982 .903 r
.58123 .62348 m .57979 .62446 L .58312 .62165 L F
.888 .508 .311 r
.57979 .62446 m .58194 .62495 L .58312 .62165 L F
.58194 .62495 m .58227 .62483 L .58312 .62165 L F
.848 .916 .879 r
.52115 .53866 m .51877 .5384 L .52084 .53553 L F
.52115 .53866 m .51974 .53931 L .51877 .5384 L F
.878 .883 .834 r
.52359 .5351 m .52115 .53866 L .52084 .53553 L F
.928 .907 .781 r
.66707 .43893 m .66596 .43796 L .66618 .43473 L F
.954 .736 .57 r
.66707 .43893 m .66513 .44021 L .66596 .43796 L F
.66707 .43893 m .66669 .4412 L .66513 .44021 L F
.802 .51 .494 r
.52195 .56541 m .52208 .56797 L .52024 .56694 L F
.615 .42 .594 r
.52815 .56619 m .52794 .56548 L .53017 .56497 L F
.52815 .56619 m .52798 .56788 L .52794 .56548 L F
.536 .454 .71 r
.41831 .58849 m .41701 .59171 L .41687 .58964 L F
.441 .14 .358 r
.7364 .43917 m .73644 .44079 L .73393 .44142 L F
.035 0 0 r
.45888 .63088 m .45633 .6323 L .45917 .63133 L F
.331 .123 .439 r
.2277 .62962 m .22598 .63037 L .22814 .62725 L F
.362 .183 .499 r
.2277 .62962 m .22749 .63199 L .22598 .63037 L F
.309 .177 .534 r
.22749 .63199 m .22601 .63303 L .22598 .63037 L F
.789 .765 .831 r
.73953 .40947 m .7361 .40924 L .73824 .40776 L F
.464 0 0 r
.73953 .40947 m .73809 .40968 L .7361 .40924 L F
.185 .477 .894 r
.73824 .40776 m .73913 .40799 L .73928 .40914 L F
.204 .469 .886 r
.73902 .40663 m .73982 .40817 L .73824 .40776 L F
.9 .981 .795 r
.73897 .40681 m .73735 .40866 L .73809 .40968 L F
.73902 .40663 m .73895 .40672 L .73897 .40681 L F
.77 .713 .798 r
.73824 .40776 m .73489 .40716 L .73822 .40541 L F
.73824 .40776 m .7361 .40924 L .73489 .40716 L F
.204 .469 .886 r
.73902 .40663 m .73824 .40776 L .73822 .40541 L F
.9 .981 .795 r
.73895 .40672 m .73735 .40866 L .73897 .40681 L F
.185 .477 .894 r
.73928 .40914 m .73982 .40817 L .73953 .40947 L F
.73913 .40799 m .73982 .40817 L .73928 .40914 L F
.73 .983 .906 r
.73982 .40817 m .73809 .40968 L .73953 .40947 L F
.537 .414 .659 r
.5435 .54106 m .54178 .54478 L .54094 .54158 L F
0 0 0 r
.4434 .57222 m .4444 .57206 L .44169 .57168 L F
.4434 .57222 m .44591 .57174 L .4444 .57206 L F
.832 .702 .721 r
.64428 .45833 m .6461 .45942 L .64478 .45592 L F
.809 .797 .84 r
.64189 .46089 m .6461 .45942 L .64428 .45833 L F
.897 .987 .754 r
.58054 .4562 m .58 .45557 L .58218 .45241 L F
.808 .736 .784 r
.69779 .4467 m .69897 .4501 L .70125 .44717 L F
.177 .7 .874 r
.19064 .54101 m .19279 .54093 L .19447 .54119 L F
.13 0 0 r
.19279 .54093 m .19664 .54156 L .19447 .54119 L F
.514 .827 1 r
.69323 .45682 m .69188 .45816 L .69069 .45739 L F
.69323 .45682 m .694 .45757 L .69188 .45816 L F
.26 .769 .804 r
.19664 .54156 m .19878 .54104 L .2004 .54086 L F
.375 .824 .939 r
.19878 .54104 m .20276 .54078 L .2004 .54086 L F
.968 .647 .315 r
.65355 .43427 m .65452 .43318 L .65322 .43205 L F
.65355 .43427 m .65484 .43535 L .65452 .43318 L F
0 0 .047 r
.66605 .43302 m .66618 .43473 L .66636 .43366 L F
.8 .998 .85 r
.58727 .44686 m .58952 .44372 L .59008 .44421 L F
.58727 .44686 m .58673 .44629 L .58952 .44372 L F
.186 0 0 r
.72452 .43847 m .72584 .43942 L .72663 .43675 L F
.72452 .43847 m .72336 .4402 L .72584 .43942 L F
.599 .623 .847 r
.71431 .42101 m .71554 .41702 L .71302 .41763 L F
.71431 .42101 m .71681 .42035 L .71554 .41702 L F
.544 .366 .589 r
.3916 .60623 m .38913 .60835 L .39008 .60727 L F
.331 .138 .461 r
.24362 .60312 m .24155 .6062 L .24178 .60382 L F
.862 .713 .695 r
.52217 .69486 m .51896 .69684 L .52129 .69722 L F
.071 0 0 r
.39759 .64169 m .39619 .64229 L .39396 .64267 L F
.056 0 0 r
.39967 .6422 m .39619 .64229 L .39759 .64169 L F
.006 0 0 r
.47194 .63273 m .47032 .63359 L .46829 .63386 L F
.053 0 0 r
.47358 .63275 m .47194 .63273 L .47419 .632 L F
.47358 .63275 m .47032 .63359 L .47194 .63273 L F
.473 .275 .53 r
.23874 .61445 m .23693 .61255 L .23917 .61153 L F
.23874 .61445 m .23712 .61508 L .23693 .61255 L F
.76 .488 .522 r
.60951 .43761 m .61315 .43579 L .60948 .4352 L F
.60951 .43761 m .61364 .43905 L .61315 .43579 L F
.503 .31 .552 r
.61315 .43579 m .61364 .43905 L .61563 .43746 L F
.578 .267 .405 r
.61315 .43579 m .61563 .43746 L .6153 .43588 L F
.915 .662 .542 r
.54694 .65902 m .54874 .66218 L .54874 .65974 L F
.831 .871 .874 r
.61039 .4236 m .60741 .42426 L .60926 .42264 L F
.876 .914 .85 r
.61039 .4236 m .6117 .41976 L .61193 .42187 L F
.61039 .4236 m .60926 .42264 L .6117 .41976 L F
.699 .614 .759 r
.53446 .55844 m .53269 .5595 L .53495 .55655 L F
.123 .619 .908 r
.67161 .39997 m .6729 .40064 L .66944 .39967 L F
.354 .761 .982 r
.67415 .39978 m .6729 .40064 L .67161 .39997 L F
.67415 .39978 m .6753 .4005 L .6729 .40064 L F
.064 .623 .801 r
.42206 .58549 m .42055 .58529 L .42429 .58555 L F
.681 .54 .687 r
.40766 .59183 m .40767 .59551 L .40506 .59481 L F
.628 .526 .719 r
.40827 .5973 m .40506 .59481 L .40767 .59551 L F
.40827 .5973 m .40627 .59828 L .40506 .59481 L F
.647 .683 .87 r
.70367 .40421 m .70201 .40665 L .70102 .405 L F
.70367 .40421 m .7045 .40579 L .70201 .40665 L F
.905 .8 .733 r
.54892 .66452 m .5522 .66269 L .54874 .66218 L F
.54892 .66452 m .55089 .66536 L .5522 .66269 L F
.874 .906 .85 r
.66813 .44525 m .66588 .4478 L .66481 .44674 L F
.983 .811 .593 r
.66588 .4478 m .66426 .44906 L .66481 .44674 L F
.66588 .4478 m .66547 .45018 L .66426 .44906 L F
.533 .3 .508 r
.35954 .59751 m .36203 .59724 L .36214 .59465 L F
.492 .267 .5 r
.36214 .59465 m .36431 .59664 L .36472 .59414 L F
.36214 .59465 m .36203 .59724 L .36431 .59664 L F
.318 .076 .38 r
.24979 .58841 m .24743 .59138 L .24808 .58948 L F
.649 .576 .76 r
.68022 .41999 m .68401 .42383 L .68204 .42271 L F
.7 .664 .811 r
.68204 .42271 m .68401 .42383 L .68589 .42263 L F
.827 .457 0 r
.51143 .67864 m .51282 .68111 L .5111 .67728 L F
.961 .655 .24 r
.51143 .67864 m .51271 .68277 L .51282 .68111 L F
.629 .482 .664 r
.57796 .51502 m .57561 .51803 L .57557 .51562 L F
.164 0 .156 r
.7314 .4438 m .72852 .44691 L .72903 .4444 L F
.615 .361 .51 r
.71832 .45345 m .71568 .45528 L .7148 .45298 L F
.71832 .45345 m .71792 .45512 L .71568 .45528 L F
0 0 0 r
.72087 .45292 m .71792 .45512 L .71832 .45345 L F
.41 .119 .357 r
.59945 .50026 m .6021 .49775 L .60201 .49996 L F
.472 .235 .473 r
.6021 .49775 m .60462 .49724 L .60201 .49996 L F
.703 .515 .631 r
.58954 .48515 m .59319 .483 L .58957 .48287 L F
.58954 .48515 m .5933 .48562 L .59319 .483 L F
.699 .512 .632 r
.5933 .48562 m .5958 .483 L .59319 .483 L F
.505 .397 .665 r
.41019 .59415 m .40766 .59183 L .41006 .59157 L F
.41019 .59415 m .40767 .59551 L .40766 .59183 L F
.598 .197 .254 r
.48248 .62537 m .48521 .62651 L .48268 .62702 L F
.543 .06 .058 r
.43108 .57582 m .42767 .57621 L .42902 .57662 L F
0 0 .026 r
.43053 .57676 m .42902 .57662 L .42767 .57621 L F
.43053 .57676 m .4305 .57727 L .42902 .57662 L F
.744 .688 .797 r
.19374 .6683 m .19735 .66857 L .19573 .66521 L F
.653 .217 .2 r
.19345 .66863 m .19735 .66857 L .19374 .6683 L F
.19345 .66863 m .19541 .67022 L .19735 .66857 L F
0 .227 .741 r
.19573 .66521 m .19735 .66857 L .19744 .66676 L F
.895 .977 .683 r
.19735 .66857 m .19541 .67022 L .19744 .66676 L F
.685 .824 .383 r
.60081 .45226 m .60034 .45339 L .60168 .45081 L F
0 0 0 r
.60288 .44945 m .60168 .45081 L .60386 .44806 L F
.602 .45082 m .60168 .45081 L .60288 .44945 L F
.602 .45082 m .60081 .45226 L .60168 .45081 L F
.498 .225 .43 r
.58349 .51153 m .58312 .51443 L .5807 .51481 L F
.5 .284 .517 r
.58615 .50911 m .58616 .51097 L .58349 .51153 L F
.512 .256 .463 r
.58616 .51097 m .58312 .51443 L .58349 .51153 L F
.56 .745 .963 r
.64111 .45103 m .6374 .44999 L .63968 .44964 L F
0 0 0 r
.63996 .45188 m .64111 .45103 L .6435 .45002 L F
.607 .037 0 r
.40105 .63177 m .40311 .63308 L .40457 .63334 L F
.083 0 0 r
.40311 .63308 m .40685 .63242 L .40457 .63334 L F
.807 .609 .635 r
.43154 .58503 m .43248 .58744 L .42933 .58662 L F
.154 .637 .922 r
.43018 .58639 m .42933 .58662 L .43091 .58654 L F
.106 .46 .888 r
.42933 .58662 m .42763 .58707 L .42661 .58498 L F
.42933 .58662 m .42661 .58498 L .4289 .58494 L F
.807 .609 .635 r
.43154 .58503 m .42933 .58662 L .4289 .58494 L F
.154 .637 .922 r
.42726 .58579 m .42933 .58662 L .43018 .58639 L F
.106 .46 .888 r
.42933 .58662 m .42764 .58711 L .42763 .58707 L F
.42933 .58662 m .43017 .58805 L .42764 .58711 L F
.399 .372 .713 r
.43017 .58805 m .42826 .58931 L .42764 .58711 L F
.627 .67 .872 r
.48521 .62776 m .48762 .62859 L .48502 .62902 L F
.35 0 .146 r
.48521 .62651 m .48863 .62386 L .48803 .62712 L F
.48521 .62651 m .48803 .62712 L .48745 .62725 L F
.48745 .62725 m .48803 .62712 L .48797 .62742 L F
.294 .288 .681 r
.48521 .62651 m .48797 .62742 L .4861 .62278 L F
.627 .67 .872 r
.48549 .62581 m .48672 .62742 L .48521 .62776 L F
.48672 .62742 m .48762 .62859 L .48521 .62776 L F
.528 .32 .541 r
.49103 .62127 m .49087 .62342 L .48863 .62386 L F
.226 0 .163 r
.4902 .62519 m .48863 .62386 L .49087 .62342 L F
.4902 .62519 m .48797 .62742 L .48863 .62386 L F
.29 .711 .971 r
.46989 .57339 m .47077 .57314 L .47146 .57404 L F
.427 .806 .992 r
.47146 .57404 m .47077 .57314 L .47362 .57361 L F
.258 .297 .712 r
.47385 .57602 m .47146 .57404 L .47362 .57361 L F
.1 .656 .741 r
.68022 .41999 m .67918 .42004 L .68237 .41976 L F
.451 .452 .769 r
.68022 .41999 m .68237 .41976 L .67918 .42004 L F
.68022 .41999 m .68204 .42271 L .68237 .41976 L F
.636 .478 .651 r
.40082 .59942 m .39743 .60248 L .39714 .60081 L F
.68 .484 .614 r
.5933 .48562 m .59599 .48546 L .5958 .483 L F
.509 .344 .592 r
.59599 .48546 m .59821 .48246 L .5958 .483 L F
.791 .969 .915 r
.19564 .64051 m .19464 .64209 L .19175 .64247 L F
.878 .802 .771 r
.61235 .46194 m .61354 .46541 L .61151 .46372 L F
.709 .661 .8 r
.61404 .46137 m .61354 .46541 L .61235 .46194 L F
.809 .692 .736 r
.61268 .45918 m .61235 .46194 L .61398 .46055 L F
.61406 .46056 m .61466 .46116 L .61235 .46194 L F
0 0 0 r
.61305 .46215 m .61388 .46071 L .61235 .46194 L F
.61388 .46071 m .61398 .46055 L .61235 .46194 L F
.809 .692 .736 r
.61379 .46029 m .61388 .46071 L .61235 .46194 L F
.975 .718 .305 r
.61362 .46021 m .61381 .46039 L .61383 .46079 L F
.61381 .46039 m .61398 .46055 L .61388 .46071 L F
.61381 .46039 m .61388 .46071 L .61383 .46079 L F
.567 .074 0 r
.61268 .45918 m .61398 .46055 L .61381 .46039 L F
.809 .692 .736 r
.61268 .45918 m .61375 .46033 L .61235 .46194 L F
.567 .074 0 r
.61268 .45918 m .61381 .46039 L .61228 .45891 L F
.809 .692 .736 r
.61268 .45918 m .61379 .46029 L .61375 .46033 L F
.61379 .46029 m .61406 .46056 L .61388 .46071 L F
.975 .718 .305 r
.61228 .45891 m .61362 .46021 L .61305 .46215 L F
.61362 .46021 m .61383 .46079 L .61305 .46215 L F
.709 .661 .8 r
.61466 .46116 m .61436 .46228 L .61404 .46137 L F
.61436 .46228 m .61354 .46541 L .61404 .46137 L F
.61466 .46116 m .6152 .46423 L .61354 .46541 L F
.628 .474 .655 r
.21559 .60036 m .21725 .59743 L .21607 .59803 L F
.21559 .60036 m .21803 .60018 L .21734 .59772 L F
.21702 .59784 m .21734 .59772 L .21725 .59743 L F
.21559 .60036 m .21734 .59772 L .21702 .59784 L F
.712 .476 .566 r
.21726 .59742 m .21607 .59803 L .21725 .59743 L F
.341 .166 .493 r
.21803 .60018 m .21854 .59953 L .21725 .59743 L F
.712 .476 .566 r
.21862 .59738 m .21741 .59769 L .21726 .59742 L F
.21741 .59769 m .21726 .59743 L .21726 .59742 L F
.572 .922 .957 r
.21862 .59738 m .21841 .59733 L .21748 .59767 L F
.528 .385 .63 r
.21725 .59743 m .22022 .59436 L .21862 .59738 L F
.21725 .59743 m .21826 .59729 L .22022 .59436 L F
0 0 0 r
.22022 .59436 m .21958 .59532 L .21862 .59738 L F
.21992 .5946 m .21826 .5973 L .21862 .59738 L F
.528 .385 .63 r
.21826 .59729 m .22052 .597 L .22022 .59436 L F
0 0 0 r
.22022 .59436 m .21992 .5946 L .21958 .59532 L F
.21992 .5946 m .21688 .59699 L .21826 .5973 L F
.341 .166 .493 r
.21854 .59953 m .22052 .597 L .21826 .59729 L F
.21772 .59818 m .21826 .59729 L .21725 .59743 L F
.21854 .59953 m .21826 .59729 L .21772 .59818 L F
.712 .476 .566 r
.21741 .59769 m .21607 .59803 L .21726 .59743 L F
.572 .922 .957 r
.21748 .59767 m .21688 .59699 L .21607 .59803 L F
.21841 .59733 m .21688 .59699 L .21748 .59767 L F
.989 .74 .459 r
.66609 .45623 m .66472 .45697 L .66491 .45487 L F
.66609 .45623 m .66621 .45876 L .66472 .45697 L F
.966 .703 .483 r
.55115 .66841 m .55095 .67032 L .55259 .67082 L F
.963 .731 .54 r
.55058 .67337 m .55259 .67082 L .55095 .67032 L F
.55058 .67337 m .55212 .67419 L .55259 .67082 L F
.874 .906 .85 r
.66813 .44525 m .66481 .44674 L .66659 .44383 L F
.57 .505 .743 r
.25666 .57651 m .25381 .57479 L .25593 .57421 L F
.575 .304 .468 r
.36731 .59383 m .37024 .59157 L .36785 .592 L F
.136 .234 .702 r
.4902 .61766 m .49222 .62049 L .49103 .62127 L F
.511 .488 .767 r
.49222 .62049 m .49087 .62342 L .49103 .62127 L F
.137 .678 .694 r
.45555 .57386 m .45176 .57461 L .45331 .57489 L F
.555 .893 .649 r
.60386 .44806 m .60683 .44558 L .60532 .44665 L F
0 0 0 r
.60487 .44834 m .60386 .44806 L .60532 .44665 L F
.60487 .44834 m .60288 .44945 L .60386 .44806 L F
.568 .574 .819 r
.35724 .6279 m .35961 .62778 L .35956 .6256 L F
0 0 .142 r
.21358 .58605 m .21348 .58462 L .21301 .58145 L F
0 0 .204 r
.21358 .58605 m .21414 .58723 L .21348 .58462 L F
.21358 .58605 m .21326 .58858 L .21414 .58723 L F
.802 .979 .696 r
.6658 .40182 m .66719 .40106 L .66432 .40455 L F
.189 .638 .943 r
.67034 .39908 m .67161 .39997 L .66944 .39967 L F
.324 .042 .322 r
.67034 .39908 m .67013 .39916 L .66804 .40136 L F
.407 .824 .642 r
.66944 .39967 m .6658 .40182 L .66728 .40016 L F
.189 .638 .943 r
.67034 .39908 m .66944 .39967 L .66728 .40016 L F
.324 .042 .322 r
.67013 .39916 m .66728 .40016 L .66763 .40071 L F
.67013 .39916 m .66763 .40071 L .66804 .40136 L F
.407 .824 .642 r
.66944 .39967 m .66719 .40106 L .66614 .40164 L F
.66667 .40131 m .66614 .40164 L .6658 .40182 L F
.66944 .39967 m .66614 .40164 L .66667 .40131 L F
.76 .597 .675 r
.58739 .48582 m .58957 .48287 L .58599 .48227 L F
.72 .539 .645 r
.58739 .48582 m .58954 .48515 L .58957 .48287 L F
.412 0 .104 r
.47317 .62428 m .47387 .6257 L .47559 .624 L F
.47317 .62428 m .47195 .62605 L .47387 .6257 L F
.066 0 0 r
.1791 .55701 m .17663 .55762 L .17508 .55773 L F
.397 .851 .8 r
.17996 .55624 m .1791 .55701 L .18126 .55626 L F
.17996 .55624 m .17663 .55762 L .1791 .55701 L F
.408 .209 .496 r
.25459 .58198 m .25194 .58546 L .2524 .58334 L F
0 .471 .733 r
.20276 .54078 m .20471 .54119 L .20648 .54165 L F
.467 .8 .999 r
.20471 .54119 m .20864 .54179 L .20648 .54165 L F
.82 .775 .811 r
.60892 .44192 m .61063 .44053 L .60951 .43761 L F
.625 .674 .877 r
.60951 .43761 m .61063 .44053 L .61364 .43905 L F
.309 0 0 r
.71238 .45613 m .70894 .45739 L .70988 .45613 L F
.74 .366 .344 r
.51742 .7006 m .51639 .7028 L .5142 .70025 L F
.779 .388 .315 r
.52204 .69977 m .51929 .7005 L .51989 .70037 L F
0 0 0 r
.51862 .70069 m .51742 .7006 L .51989 .70037 L F
.779 .388 .315 r
.51929 .7005 m .51918 .70054 L .51989 .70037 L F
.52204 .69977 m .51933 .70078 L .51929 .7005 L F
.715 .683 .818 r
.52015 .69776 m .51934 .70082 L .52074 .69789 L F
.51934 .70082 m .51913 .70158 L .51945 .70086 L F
.779 .388 .315 r
.52204 .69977 m .52141 .70154 L .51933 .70078 L F
.715 .683 .818 r
.51934 .70082 m .51945 .70086 L .52074 .69789 L F
.779 .388 .315 r
.52141 .70154 m .52123 .70204 L .51945 .70086 L F
.52141 .70154 m .51945 .70086 L .51933 .70078 L F
.51929 .7005 m .51903 .70057 L .51918 .70054 L F
.51903 .70057 m .51862 .70069 L .51989 .70037 L F
.51929 .7005 m .51933 .70078 L .51903 .70057 L F
.602 .551 .77 r
.51988 .70114 m .51913 .70158 L .52123 .70204 L F
0 0 .288 r
.51927 .70232 m .51913 .70158 L .51934 .70082 L F
.51937 .7011 m .51934 .70082 L .51943 .70046 L F
.602 .551 .77 r
.51956 .7006 m .51913 .70158 L .52104 .70045 L F
0 0 .288 r
.51934 .70145 m .51937 .70104 L .51937 .7011 L F
.51927 .70232 m .51937 .70104 L .51934 .70145 L F
.51927 .70232 m .51934 .70082 L .51937 .70104 L F
.51964 .7004 m .51943 .70046 L .52015 .69776 L F
.779 .388 .315 r
.51903 .70057 m .51836 .70075 L .51862 .70069 L F
0 0 0 r
.51833 .70076 m .51817 .70073 L .51834 .70076 L F
.51817 .70073 m .51742 .7006 L .51862 .70069 L F
.389 .401 .752 r
.51793 .70114 m .51833 .70076 L .51927 .70232 L F
0 0 0 r
.51833 .70076 m .51827 .70082 L .51742 .7006 L F
.51834 .70076 m .51817 .70073 L .51862 .70069 L F
.779 .388 .315 r
.51836 .70075 m .51834 .70076 L .51862 .70069 L F
.628 .246 .3 r
.52123 .70204 m .51913 .70158 L .51927 .70232 L F
0 0 .288 r
.51927 .70232 m .51937 .7011 L .51939 .70123 L F
.628 .246 .3 r
.52123 .70204 m .51927 .70232 L .51939 .70123 L F
0 0 .288 r
.51927 .70232 m .51939 .70123 L .51943 .70149 L F
.628 .246 .3 r
.51939 .70123 m .51927 .70232 L .51842 .7008 L F
0 0 .288 r
.51927 .70232 m .51943 .70149 L .51853 .701 L F
.51927 .70232 m .51853 .701 L .51818 .7008 L F
.628 .246 .3 r
.51842 .7008 m .51927 .70232 L .51833 .70076 L F
.779 .388 .315 r
.51903 .70057 m .51933 .70078 L .51837 .70076 L F
.51903 .70057 m .51837 .70076 L .51836 .70075 L F
.51933 .70078 m .51939 .70123 L .51833 .70076 L F
0 0 .288 r
.51943 .70149 m .51943 .70046 L .51964 .7004 L F
.779 .388 .315 r
.51933 .70078 m .52123 .70204 L .51939 .70123 L F
0 0 .288 r
.51937 .7011 m .51943 .70046 L .51943 .70149 L F
.51943 .70149 m .51964 .7004 L .51836 .70075 L F
.51943 .70149 m .51836 .70075 L .51818 .7008 L F
.779 .388 .315 r
.51836 .70075 m .51837 .70076 L .51833 .70076 L F
0 0 0 r
.51833 .70076 m .51831 .70079 L .51833 .70076 L F
.389 .401 .752 r
.51588 .69933 m .51828 .70073 L .51793 .70114 L F
0 0 0 r
.51827 .70082 m .51793 .70114 L .51742 .7006 L F
.51793 .70114 m .51653 .70249 L .51663 .70227 L F
.51793 .70114 m .51663 .70227 L .51742 .7006 L F
.273 .392 .802 r
.51588 .69933 m .51793 .70114 L .51766 .70063 L F
.389 .401 .752 r
.5181 .70095 m .51812 .70097 L .51793 .70114 L F
.51828 .70073 m .51812 .70097 L .5181 .70095 L F
.51828 .70073 m .51831 .70078 L .51812 .70097 L F
.51588 .69933 m .51813 .70097 L .51831 .70079 L F
.51588 .69933 m .51831 .70079 L .51828 .70073 L F
0 0 0 r
.51746 .69752 m .51633 .69749 L .51588 .69933 L F
.683 .928 .621 r
.51648 .69842 m .51746 .69752 L .51588 .69933 L F
.273 .392 .802 r
.51793 .70114 m .51824 .70088 L .51648 .69842 L F
0 0 0 r
.51827 .70082 m .51639 .7028 L .51653 .70249 L F
.51831 .70079 m .51639 .7028 L .51833 .70076 L F
.389 .401 .752 r
.51588 .69933 m .51639 .7028 L .51813 .70097 L F
.273 .392 .802 r
.51588 .69933 m .51766 .70063 L .51648 .69842 L F
.51793 .70114 m .51927 .70232 L .51824 .70088 L F
0 0 .288 r
.51831 .70077 m .5182 .70077 L .51818 .7008 L F
.51833 .70076 m .5183 .70076 L .51831 .70077 L F
.5183 .70076 m .5182 .70077 L .51831 .70077 L F
.51834 .70076 m .51833 .70076 L .51833 .70076 L F
.51964 .7004 m .5182 .70077 L .51834 .70076 L F
.389 .401 .752 r
.51828 .70073 m .51833 .70076 L .51831 .70078 L F
0 0 .288 r
.51833 .70076 m .5182 .70077 L .51833 .70076 L F
.389 .401 .752 r
.51828 .70073 m .51831 .70079 L .51833 .70076 L F
0 0 .288 r
.51964 .7004 m .52015 .69776 L .51826 .70067 L F
.51829 .70075 m .51826 .70067 L .5182 .70077 L F
.51964 .7004 m .51826 .70067 L .51829 .70075 L F
0 0 0 r
.51833 .70076 m .51833 .70076 L .51834 .70076 L F
.779 .388 .315 r
.51836 .70075 m .51833 .70076 L .51834 .70076 L F
0 0 .288 r
.51818 .7008 m .52015 .69776 L .51648 .69842 L F
.602 .551 .77 r
.52099 .70003 m .51956 .7006 L .52104 .70045 L F
.52074 .69789 m .51965 .7004 L .52099 .70003 L F
.51965 .7004 m .51956 .7006 L .52099 .70003 L F
.52104 .70045 m .51988 .70114 L .52123 .70204 L F
.813 .645 .673 r
.40627 .59828 m .40646 .60067 L .40314 .5997 L F
.39 .323 .662 r
.40806 .59968 m .40627 .59828 L .40827 .5973 L F
.40806 .59968 m .40646 .60067 L .40627 .59828 L F
.309 .379 .773 r
.5333 .70409 m .53473 .70243 L .53222 .70521 L F
.5333 .70409 m .53541 .7045 L .53473 .70243 L F
.756 .341 .263 r
.61751 .41234 m .61657 .4137 L .61464 .4116 L F
.535 .183 .317 r
.56685 .52328 m .56712 .52152 L .56957 .52287 L F
.814 .663 .695 r
.58474 .47898 m .58829 .47696 L .5869 .47587 L F
.58474 .47898 m .5883 .47974 L .58829 .47696 L F
.867 .813 .794 r
.58829 .47696 m .58907 .47275 L .5869 .47587 L F
.314 .486 .869 r
.2117 .59521 m .21482 .59673 L .21258 .59346 L F
.209 0 0 r
.39747 .5819 m .4015 .58014 L .39935 .58091 L F
.444 .762 .996 r
.23838 .54387 m .23784 .54521 L .23622 .54411 L F
.23838 .54387 m .23988 .54494 L .23784 .54521 L F
.583 .655 .886 r
.7101 .4168 m .71057 .41825 L .71302 .41763 L F
.761 .943 .941 r
.43009 .56817 m .43009 .56634 L .43172 .56686 L F
.43009 .56817 m .42886 .56754 L .43009 .56634 L F
.807 .688 .733 r
.58599 .48227 m .5883 .47974 L .58474 .47898 L F
.788 .855 .405 r
.59967 .45419 m .60034 .45339 L .60081 .45226 L F
.59967 .45419 m .59912 .45626 L .60034 .45339 L F
.555 .372 .588 r
.54178 .54478 m .54185 .54729 L .5394 .54801 L F
.537 .414 .659 r
.5435 .54106 m .54422 .54433 L .54178 .54478 L F
.582 .428 .638 r
.54422 .54433 m .54185 .54729 L .54178 .54478 L F
.414 .291 .602 r
.60264 .47696 m .60557 .47579 L .60354 .47368 L F
.339 .128 .439 r
.60533 .47802 m .60264 .47696 L .60291 .47846 L F
.60533 .47802 m .60557 .47579 L .60264 .47696 L F
.743 .745 .854 r
.52611 .69792 m .52706 .69734 L .52718 .69427 L F
.52611 .69792 m .52718 .69427 L .52718 .69675 L F
.576 .941 .835 r
.52507 .6981 m .52611 .69792 L .52718 .69675 L F
.984 .724 .449 r
.53106 .70683 m .52972 .70614 L .52977 .70347 L F
.392 .465 .816 r
.53222 .70521 m .53106 .70683 L .52977 .70347 L F
.71 .923 .964 r
.53222 .70521 m .52972 .70614 L .53106 .70683 L F
.833 .943 .896 r
.52064 .54514 m .51696 .54684 L .51883 .54356 L F
.773 .675 .755 r
.52284 .54193 m .52064 .54514 L .51883 .54356 L F
.415 .366 .695 r
.64956 .4477 m .65007 .4516 L .65199 .44932 L F
.775 .681 .76 r
.64961 .4523 m .65199 .44932 L .65007 .4516 L F
.609 .159 .159 r
.41918 .63026 m .41734 .63195 L .42114 .63196 L F
.508 .2 .38 r
.41918 .63026 m .42114 .63196 L .4214 .63029 L F
.535 .924 .86 r
.67122 .4062 m .66845 .40771 L .66727 .40774 L F
.447 .15 .367 r
.71276 .44451 m .71689 .44097 L .71227 .44136 L F
.385 .181 .476 r
.22998 .62654 m .22814 .62725 L .23033 .62418 L F
.378 .163 .456 r
.22933 .6289 m .22814 .62725 L .22998 .62654 L F
.22933 .6289 m .2277 .62962 L .22814 .62725 L F
.605 .797 .973 r
.68397 .40901 m .68535 .40688 L .68287 .40744 L F
.68397 .40901 m .68652 .40826 L .68535 .40688 L F
.553 .592 .847 r
.68397 .40901 m .68715 .41085 L .68652 .40826 L F
.547 .789 .988 r
.56228 .62758 m .56515 .62721 L .56613 .62829 L F
.719 .861 .949 r
.56613 .62829 m .56745 .62594 L .5687 .62936 L F
.56613 .62829 m .56515 .62721 L .56745 .62594 L F
.897 .798 .743 r
.61464 .4116 m .61477 .40755 L .61616 .40888 L F
.817 .834 .862 r
.61885 .40616 m .61616 .40888 L .61477 .40755 L F
.723 .763 .885 r
.64961 .4523 m .65096 .4546 L .65317 .45278 L F
.508 .301 .534 r
.42121 .58913 m .41957 .59243 L .41991 .5893 L F
.42121 .58913 m .42182 .59188 L .41957 .59243 L F
.675 .407 .508 r
.42559 .59086 m .42182 .59188 L .42121 .58913 L F
.641 .313 .4 r
.43096 .59086 m .42826 .58931 L .43017 .58805 L F
.43096 .59086 m .42789 .5913 L .42826 .58931 L F
.48 .386 .671 r
.54183 .54991 m .5394 .54801 L .54185 .54729 L F
.54183 .54991 m .53972 .55051 L .5394 .54801 L F
.802 .708 .761 r
.64766 .44456 m .64956 .4477 L .6475 .44748 L F
.865 .945 .867 r
.64629 .4495 m .64728 .44896 L .64646 .44681 L F
.939 .816 .363 r
.64748 .4471 m .6475 .44748 L .64746 .44739 L F
.865 .945 .867 r
.64728 .44896 m .64956 .4477 L .64744 .44747 L F
0 .259 .74 r
.64956 .4477 m .65048 .44781 L .64769 .4475 L F
.64956 .4477 m .64769 .4475 L .6475 .44748 L F
.865 .945 .867 r
.64745 .44739 m .64956 .4477 L .64748 .4471 L F
.64769 .4475 m .64956 .4477 L .64745 .44739 L F
.939 .816 .363 r
.64766 .44456 m .64756 .44635 L .64748 .4471 L F
.64756 .44635 m .6475 .44748 L .64748 .4471 L F
.83 .714 .737 r
.64748 .4471 m .64956 .4477 L .64766 .44456 L F
.131 .592 .923 r
.64759 .44746 m .65048 .44781 L .64959 .44693 L F
.6475 .44748 m .64769 .4475 L .64759 .44746 L F
.64769 .4475 m .65048 .44781 L .64759 .44746 L F
.83 .714 .737 r
.64646 .44681 m .64748 .4471 L .64766 .44456 L F
.939 .816 .363 r
.64766 .44456 m .64746 .44739 L .6469 .44612 L F
.131 .592 .923 r
.64745 .44737 m .64959 .44693 L .6469 .44612 L F
.6475 .44748 m .64759 .44746 L .64745 .44737 L F
.64759 .44746 m .64959 .44693 L .64745 .44737 L F
.865 .945 .867 r
.64744 .44747 m .64766 .4475 L .64745 .44739 L F
.64766 .4475 m .64769 .4475 L .64759 .44746 L F
.64766 .4475 m .64759 .44746 L .64745 .44739 L F
.64728 .44896 m .64748 .4471 L .64646 .44681 L F
0 .259 .74 r
.64956 .4477 m .65199 .44932 L .65048 .44781 L F
.686 .331 .368 r
.43743 .5787 m .43978 .57918 L .4414 .57699 L F
.639 .274 .335 r
.4414 .57699 m .43978 .57918 L .44319 .57882 L F
.613 .413 .588 r
.56433 .52367 m .56112 .52668 L .56111 .52418 L F
.41 .145 .399 r
.48128 .62329 m .48344 .62289 L .48167 .62137 L F
.463 .135 .324 r
.48167 .62137 m .48344 .62289 L .48407 .62098 L F
0 0 .467 r
.6287 .44473 m .62896 .44617 L .62911 .44316 L F
.691 .238 .172 r
.21999 .57963 m .22195 .58151 L .22395 .58014 L F
.518 .021 .015 r
.22395 .58014 m .22551 .58145 L .22628 .57969 L F
.22395 .58014 m .22195 .58151 L .22551 .58145 L F
.542 .395 .631 r
.22395 .58014 m .22628 .57969 L .22588 .57694 L F
0 0 0 r
.20864 .54179 m .2109 .54163 L .21249 .54147 L F
.25 .762 .837 r
.2109 .54163 m .21463 .54119 L .21249 .54147 L F
0 0 0 r
.62989 .42951 m .63192 .42701 L .63376 .42929 L F
.626 .224 .262 r
.62989 .42951 m .63376 .42929 L .63125 .43147 L F
.143 .369 .824 r
.63479 .42877 m .63376 .42929 L .63192 .42701 L F
.26 .649 .965 r
.63479 .42877 m .63609 .43003 L .63376 .42929 L F
.752 .397 .382 r
.63376 .42929 m .63604 .43189 L .63125 .43147 L F
.734 .402 .419 r
.63376 .42929 m .63609 .43003 L .63604 .43189 L F
.847 .803 .808 r
.52588 .53216 m .52258 .52954 L .52457 .52915 L F
.52588 .53216 m .52272 .53204 L .52258 .52954 L F
.52588 .53216 m .52436 .53328 L .52272 .53204 L F
.794 .709 .77 r
.5279 .52933 m .52588 .53216 L .52457 .52915 L F
0 .542 .749 r
.21474 .55324 m .21332 .55301 L .21125 .5528 L F
.255 0 0 r
.21549 .55368 m .21192 .55278 L .21332 .55301 L F
.123 .66 .854 r
.21332 .55301 m .20947 .55265 L .21125 .5528 L F
.21332 .55301 m .21145 .55266 L .20947 .55265 L F
.255 0 0 r
.21192 .55278 m .21145 .55266 L .21332 .55301 L F
0 .542 .749 r
.21509 .55329 m .21332 .55301 L .21474 .55324 L F
.002 .489 .866 r
.21698 .5548 m .21332 .55301 L .21509 .55329 L F
.348 .433 .807 r
.35916 .61223 m .36038 .61567 L .36183 .61411 L F
.351 .437 .81 r
.36038 .61567 m .36333 .61775 L .36183 .61411 L F
.491 .438 .725 r
.36038 .61567 m .36138 .61876 L .36333 .61775 L F
.967 .754 .563 r
.51659 .56501 m .51528 .56462 L .51537 .56173 L F
.714 .319 .299 r
.51659 .56501 m .51489 .56677 L .51528 .56462 L F
.51659 .56501 m .51843 .56721 L .51489 .56677 L F
.687 .778 .92 r
.61408 .41676 m .61584 .41877 L .61769 .4173 L F
0 0 0 r
.1699 .54376 m .17082 .54335 L .1719 .54281 L F
.1699 .54376 m .16918 .54437 L .17082 .54335 L F
.50588 .7111 m .50947 .70979 L .50737 .71037 L F
.50737 .71037 m .50947 .70979 L .50588 .7111 L F
.647 .505 .676 r
.52815 .56619 m .52898 .5707 L .52798 .56788 L F
.52815 .56619 m .5314 .57062 L .52898 .5707 L F
.647 .475 .637 r
.53386 .56513 m .52815 .56619 L .53017 .56497 L F
.53386 .56513 m .5339 .56767 L .52815 .56619 L F
.488 .298 .548 r
.5339 .56767 m .5314 .57062 L .52815 .56619 L F
.617 .34 .474 r
.63609 .43003 m .63886 .43018 L .63959 .42961 L F
.795 .64 .69 r
.63886 .43018 m .64016 .4323 L .6366 .43195 L F
.63959 .42961 m .63976 .43044 L .63886 .43018 L F
.63976 .43044 m .64016 .4323 L .63886 .43018 L F
.65 .548 .726 r
.64206 .4293 m .64016 .4323 L .63959 .42961 L F
.617 .34 .474 r
.63886 .43018 m .64089 .4303 L .63959 .42961 L F
.795 .64 .69 r
.63959 .42961 m .63875 .43015 L .63609 .43003 L F
.418 .747 .994 r
.63514 .4291 m .63875 .43015 L .63609 .43003 L F
.63875 .43015 m .63886 .43018 L .63609 .43003 L F
.795 .64 .69 r
.63875 .43015 m .63604 .43189 L .63609 .43003 L F
.63959 .42961 m .6366 .43195 L .63604 .43189 L F
.418 .747 .994 r
.63479 .42877 m .64089 .4303 L .63886 .43018 L F
.63479 .42877 m .63886 .43018 L .63514 .4291 L F
.7 .247 .172 r
.44064 .63239 m .44325 .63469 L .44439 .63299 L F
.568 .096 .096 r
.44439 .63299 m .44325 .63469 L .44771 .63373 L F
.57 .102 .104 r
.44439 .63299 m .44771 .63373 L .44684 .63341 L F
.649 .641 .829 r
.5554 .63582 m .55808 .63513 L .55656 .63197 L F
.575 .447 .668 r
.53744 .55592 m .53446 .55844 L .53495 .55655 L F
.53744 .55592 m .53906 .55947 L .53446 .55844 L F
.726 .539 .639 r
.53596 .56131 m .53446 .55844 L .53906 .55947 L F
.53596 .56131 m .53579 .56241 L .53446 .55844 L F
.649 .7 .883 r
.70338 .41509 m .7072 .41736 L .70591 .41418 L F
.627 .645 .848 r
.7072 .41736 m .70842 .41337 L .70591 .41418 L F
.7072 .41736 m .7101 .4168 L .70842 .41337 L F
.361 .091 .362 r
.21579 .60302 m .21803 .60018 L .21559 .60036 L F
.462 .449 .758 r
.25764 .5703 m .25583 .57148 L .25489 .56828 L F
.403 .291 .611 r
.25757 .57347 m .25583 .57148 L .25764 .5703 L F
.25757 .57347 m .25593 .57421 L .25583 .57148 L F
.604 .714 .922 r
.69054 .40103 m .68882 .40288 L .68789 .40141 L F
.69054 .40103 m .69123 .40221 L .68882 .40288 L F
.837 .722 .737 r
.44264 .58527 m .44387 .58878 L .44041 .58799 L F
.946 .834 .702 r
.44023 .59087 m .43845 .59235 L .43865 .59211 L F
.871 .612 .544 r
.44311 .58861 m .44023 .59087 L .44041 .58799 L F
0 0 .172 r
.44041 .58799 m .44023 .59087 L .44073 .5897 L F
.812 .999 .799 r
.44073 .5897 m .44023 .59087 L .43986 .59054 L F
.946 .834 .702 r
.44023 .59087 m .43865 .59211 L .44073 .5897 L F
.871 .612 .544 r
.44387 .58878 m .44023 .59087 L .44311 .58861 L F
.44387 .58878 m .44365 .59128 L .44023 .59087 L F
.459 .743 .99 r
.44464 .58722 m .44387 .58878 L .44264 .58527 L F
.44464 .58722 m .44601 .5884 L .44387 .58878 L F
.656 .526 .693 r
.44601 .5884 m .44365 .59128 L .44387 .58878 L F
.779 .508 .525 r
.40646 .60195 m .40314 .5997 L .40646 .60067 L F
.494 .321 .575 r
.40806 .59968 m .40646 .60195 L .40646 .60067 L F
.262 0 .168 r
.60662 .49614 m .60739 .49404 L .60959 .49381 L F
.929 .969 .755 r
.6283 .47526 m .63038 .47385 L .62916 .47269 L F
.6283 .47526 m .6284 .47714 L .63038 .47385 L F
.82 .864 .879 r
.63038 .47385 m .63186 .46993 L .62916 .47269 L F
.63038 .47385 m .63314 .4712 L .63186 .46993 L F
.284 .548 .923 r
.2501 .5487 m .25181 .54888 L .25125 .55038 L F
.383 .662 .968 r
.25181 .54888 m .25324 .55039 L .25125 .55038 L F
.768 .529 .574 r
.52718 .69427 m .53085 .69459 L .53086 .69206 L F
.887 .7 .644 r
.21744 .56787 m .21892 .57122 L .21697 .57058 L F
.888 .581 .461 r
.21892 .57122 m .21734 .57253 L .21697 .57058 L F
.47 .257 .507 r
.22178 .56905 m .21892 .57122 L .21744 .56787 L F
.22178 .56905 m .22122 .57084 L .21892 .57122 L F
.382 0 .073 r
.22122 .57084 m .21734 .57253 L .21892 .57122 L F
.799 .687 .742 r
.52875 .52708 m .5279 .52933 L .52457 .52915 L F
.448 .171 .399 r
.19562 .63573 m .19782 .63528 L .19816 .63296 L F
.438 .229 .497 r
.19816 .63296 m .20066 .63257 L .20097 .62997 L F
.417 .15 .398 r
.19782 .63528 m .20066 .63257 L .19816 .63296 L F
.609 .804 .385 r
.19004 .56514 m .1881 .56824 L .18876 .56716 L F
.634 .255 .308 r
.19004 .56514 m .18876 .56716 L .19144 .56714 L F
.095 .202 .686 r
.21071 .6154 m .21054 .61131 L .20824 .61104 L F
.21071 .6154 m .21144 .61484 L .21054 .61131 L F
.395 .224 .529 r
.21071 .6154 m .21218 .61739 L .21144 .61484 L F
.21071 .6154 m .21028 .61814 L .21218 .61739 L F
.361 0 0 r
.40316 .64137 m .40189 .64211 L .39967 .6422 L F
.288 0 0 r
.40563 .64119 m .40189 .64211 L .40316 .64137 L F
.177 .246 .697 r
.60354 .47368 m .60557 .47579 L .60457 .47331 L F
.806 .334 .098 r
.18844 .64281 m .18916 .64195 L .18784 .64171 L F
.18844 .64281 m .1903 .64372 L .18916 .64195 L F
.274 .624 .96 r
.74607 .43098 m .74359 .43107 L .7437 .43078 L F
.74607 .43098 m .74733 .43245 L .74411 .43126 L F
.562 .738 .958 r
.74846 .43012 m .74733 .43245 L .74607 .43098 L F
.278 0 0 r
.74514 .43213 m .74734 .4308 L .74607 .43098 L F
.74734 .4308 m .74846 .43012 L .74607 .43098 L F
.274 .624 .96 r
.74607 .43098 m .74411 .43126 L .74359 .43107 L F
.558 .228 .367 r
.20012 .67326 m .19753 .67161 L .20007 .67068 L F
.20012 .67326 m .19692 .67361 L .19753 .67161 L F
.674 .336 .395 r
.44799 .63605 m .45022 .63832 L .44804 .63775 L F
.623 .345 .476 r
.45049 .636 m .45022 .63832 L .44799 .63605 L F
.677 .215 .149 r
.18849 .64287 m .19001 .6442 L .18687 .64383 L F
.515 .413 .677 r
.41126 .59643 m .40767 .59551 L .41019 .59415 L F
.41126 .59643 m .40827 .5973 L .40767 .59551 L F
.79 .979 .906 r
.62524 .47933 m .6284 .47714 L .62771 .47637 L F
.936 .967 .732 r
.62771 .47637 m .6284 .47714 L .6283 .47526 L F
.718 .308 .269 r
.45285 .63212 m .45574 .6356 L .45633 .6323 L F
0 0 .091 r
.45633 .6323 m .45705 .63389 L .45917 .63133 L F
.45633 .6323 m .45574 .6356 L .45705 .63389 L F
.69 .305 .314 r
.63228 .42865 m .63192 .42701 L .62998 .42701 L F
.594 .242 .343 r
.63479 .42877 m .63192 .42701 L .63228 .42865 L F
.229 0 .035 r
.46753 .62967 m .46501 .63066 L .46457 .63164 L F
.735 .798 .903 r
.52701 .52579 m .52875 .52708 L .52501 .52663 L F
.799 .687 .742 r
.52875 .52708 m .52457 .52915 L .52501 .52663 L F
.838 .792 .808 r
.53108 .52411 m .52875 .52708 L .52701 .52579 L F
.925 .944 .598 r
.54061 .68864 m .54022 .68761 L .54167 .68642 L F
.75 .575 .658 r
.54167 .68642 m .54233 .6893 L .54061 .68864 L F
.379 .334 .682 r
.54167 .68642 m .54492 .68834 L .54233 .6893 L F
.436 0 0 r
.5433 .68766 m .54167 .68642 L .54022 .68761 L F
.5433 .68766 m .54492 .68834 L .54167 .68642 L F
.773 .855 .911 r
.54402 .67332 m .54288 .67659 L .5414 .67598 L F
.54402 .67332 m .54562 .67461 L .54288 .67659 L F
.645 .716 .9 r
.72055 .42295 m .72402 .42383 L .72312 .42199 L F
.598 .689 .906 r
.72402 .42383 m .7261 .42127 L .72312 .42199 L F
.72402 .42383 m .72652 .42319 L .7261 .42127 L F
.577 .57 .809 r
.72402 .42383 m .72765 .42669 L .72652 .42319 L F
.633 .421 .577 r
.72663 .43675 m .72892 .43461 L .72659 .43562 L F
.493 .414 .695 r
.66432 .40455 m .66405 .40572 L .66433 .4022 L F
.802 .979 .696 r
.6658 .40182 m .66432 .40455 L .66433 .4022 L F
.704 .761 .896 r
.66405 .40572 m .6658 .40182 L .66433 .4022 L F
.66405 .40572 m .66734 .40387 L .6658 .40182 L F
.625 .961 .845 r
.70435 .45978 m .70287 .45995 L .70132 .46155 L F
.483 .899 .833 r
.70539 .45871 m .70435 .45978 L .70676 .45882 L F
.70539 .45871 m .70287 .45995 L .70435 .45978 L F
0 0 0 r
.1908 .57014 m .18912 .57046 L .1872 .57078 L F
.317 .804 .777 r
.19155 .56967 m .18912 .57046 L .1908 .57014 L F
.515 .229 .418 r
.42344 .58308 m .42055 .58529 L .42069 .58312 L F
.601 .638 .86 r
.21999 .57963 m .2178 .58027 L .21631 .57723 L F
.479 .57 .87 r
.21631 .57723 m .2178 .58027 L .21692 .57816 L F
.726 .854 .942 r
.2178 .58027 m .21441 .58024 L .21692 .57816 L F
.733 .737 .854 r
.52718 .69427 m .52706 .69734 L .53085 .69459 L F
.481 .782 .997 r
.6804 .39966 m .67897 .4011 L .67784 .40008 L F
.6804 .39966 m .68148 .40075 L .67897 .4011 L F
.397 .219 .52 r
.24743 .59138 m .24748 .59492 L .24533 .59512 L F
.446 .306 .597 r
.2474 .59664 m .24533 .59512 L .24748 .59492 L F
.2474 .59664 m .24554 .59736 L .24533 .59512 L F
0 0 .481 r
.21924 .55883 m .22045 .56081 L .22097 .55857 L F
.415 .686 .974 r
.69258 .41014 m .69381 .41179 L .69566 .4113 L F
.615 .381 .539 r
.69381 .41179 m .69603 .4135 L .69566 .4113 L F
.69381 .41179 m .69378 .41426 L .69603 .4135 L F
.996 .781 .493 r
.60701 .44059 m .6078 .44357 L .60892 .44192 L F
.82 .775 .811 r
.60892 .44192 m .60951 .43761 L .60701 .44059 L F
.639 .706 .895 r
.72121 .40858 m .71807 .4108 L .71669 .40793 L F
.589 .62 .851 r
.72145 .41218 m .71807 .4108 L .72121 .40858 L F
.519 .579 .855 r
.67945 .45898 m .68324 .46229 L .6824 .45865 L F
.791 .294 0 r
.68554 .46128 m .6824 .45865 L .68324 .46229 L F
0 0 .317 r
.68324 .46229 m .68387 .46314 L .68554 .46128 L F
.68324 .46229 m .68387 .46488 L .68387 .46314 L F
.167 0 0 r
.40586 .57868 m .40982 .57681 L .40742 .57726 L F
.985 .775 .373 r
.65304 .42798 m .65388 .42907 L .6539 .42673 L F
0 0 .453 r
.65377 .42579 m .6539 .42673 L .65258 .42337 L F
.892 .866 .423 r
.65304 .42798 m .6539 .42673 L .65377 .42579 L F
.697 .898 .969 r
.67253 .45812 m .67668 .45766 L .67495 .45581 L F
.705 .691 .834 r
.67889 .45599 m .67668 .45766 L .67495 .45581 L F
.572 .604 .846 r
.67668 .45766 m .67945 .45898 L .67889 .45599 L F
1 .818 .498 r
.58805 .62097 m .58864 .62447 L .58912 .62119 L F
.86 .997 .785 r
.59008 .44421 m .59195 .44066 L .5928 .44151 L F
.59008 .44421 m .58952 .44372 L .59195 .44066 L F
.602 .442 .637 r
.53972 .55051 m .54003 .55304 L .53741 .55351 L F
.595 .403 .592 r
.54003 .55304 m .53744 .55592 L .53741 .55351 L F
.233 .083 .462 r
.18876 .55931 m .19048 .55882 L .1907 .55591 L F
.586 .229 .331 r
.57621 .51976 m .57561 .51803 L .57796 .5198 L F
.608 .453 .647 r
.57796 .51502 m .57836 .51802 L .57561 .51803 L F
.564 .243 .383 r
.57561 .51803 m .57836 .51802 L .57796 .5198 L F
.589 .712 .929 r
.57832 .63478 m .57714 .63708 L .57549 .63302 L F
0 .239 .68 r
.57635 .63337 m .57832 .63478 L .57549 .63302 L F
.741 .78 .885 r
.57626 .63594 m .57635 .63337 L .57571 .63477 L F
.718 .898 .96 r
.57682 .63712 m .57626 .63594 L .57323 .63757 L F
0 0 0 r
.57323 .63757 m .57626 .63594 L .57473 .63692 L F
.741 .78 .885 r
.57626 .63594 m .57571 .63477 L .57473 .63692 L F
.718 .898 .96 r
.57714 .63708 m .57626 .63594 L .57682 .63712 L F
.589 .712 .929 r
.57832 .63478 m .57971 .63629 L .57714 .63708 L F
.57714 .63708 m .57832 .63478 L .57626 .63594 L F
.57714 .63708 m .57971 .63629 L .57832 .63478 L F
.327 .486 .865 r
.38419 .63879 m .38557 .63735 L .38382 .63799 L F
.38419 .63879 m .38555 .63866 L .38557 .63735 L F
.33 .394 .777 r
.38419 .63879 m .38701 .64081 L .38555 .63866 L F
.532 .309 .522 r
.58846 .5087 m .58616 .51097 L .58615 .50911 L F
.589 .445 .653 r
.54799 .53267 m .54826 .53506 L .54569 .53557 L F
.621 .498 .692 r
.54826 .53506 m .54616 .53855 L .54569 .53557 L F
.443 .838 .98 r
.20177 .61116 m .19833 .61117 L .20063 .61168 L F
.19833 .61117 m .20177 .61116 L .20063 .61168 L F
.951 .599 .263 r
.67321 .45413 m .67428 .45348 L .67287 .45247 L F
.67321 .45413 m .67495 .45581 L .67428 .45348 L F
0 0 0 r
.62887 .44776 m .62896 .44617 L .62834 .44921 L F
.761 .945 .615 r
.62926 .44668 m .62887 .44776 L .6276 .44893 L F
0 0 .028 r
.62945 .44561 m .62887 .44776 L .62988 .44585 L F
.761 .945 .615 r
.62988 .44585 m .62887 .44776 L .62926 .44668 L F
0 0 0 r
.62887 .44776 m .62834 .44921 L .6282 .44989 L F
0 0 .287 r
.62911 .44316 m .62896 .44617 L .62945 .44561 L F
0 0 0 r
.62945 .44561 m .62896 .44617 L .62887 .44776 L F
.838 .792 .808 r
.53108 .52411 m .52701 .52579 L .52962 .52297 L F
.873 .855 .821 r
.53337 .52107 m .53108 .52411 L .52962 .52297 L F
.716 .777 .9 r
.60765 .44475 m .60683 .44558 L .6078 .44357 L F
.60765 .44475 m .60532 .44665 L .60683 .44558 L F
.185 .028 .421 r
.21394 .60613 m .21569 .60582 L .21579 .60302 L F
0 0 0 r
.21394 .60613 m .21374 .6072 L .21569 .60582 L F
.21394 .60613 m .21298 .60835 L .21374 .6072 L F
.565 .568 .816 r
.55167 .63347 m .55269 .62912 L .55109 .62928 L F
.55167 .63347 m .55428 .63303 L .55269 .62912 L F
.584 .565 .798 r
.71299 .40522 m .71157 .40918 L .71061 .40615 L F
.71299 .40522 m .71409 .4085 L .71157 .40918 L F
.837 .722 .737 r
.44264 .58527 m .44041 .58799 L .44006 .58591 L F
0 0 .294 r
.44006 .58591 m .44086 .58666 L .44264 .58527 L F
.44006 .58591 m .44041 .58799 L .44086 .58666 L F
.367 .536 .891 r
.64998 .41686 m .64866 .41883 L .64783 .41683 L F
.64998 .41686 m .65174 .41954 L .64866 .41883 L F
.882 .809 .773 r
.52272 .53204 m .52359 .5351 L .52194 .53418 L F
.878 .883 .834 r
.52359 .5351 m .52084 .53553 L .52194 .53418 L F
.861 .799 .789 r
.52436 .53328 m .52359 .5351 L .52272 .53204 L F
.784 .283 0 r
.54409 .66481 m .54489 .66692 L .54297 .66387 L F
.54409 .66481 m .54689 .66794 L .54489 .66692 L F
.401 .195 .481 r
.23168 .62557 m .23033 .62418 L .23217 .62353 L F
.23168 .62557 m .22998 .62654 L .23033 .62418 L F
.332 0 0 r
.45035 .56563 m .45484 .56784 L .45512 .56789 L F
.808 .653 .102 r
.45512 .56789 m .45485 .56618 L .45653 .56762 L F
.45512 .56789 m .45484 .56784 L .45485 .56618 L F
.027 .205 .712 r
.36138 .61876 m .36326 .62033 L .36333 .61775 L F
.873 .855 .821 r
.53337 .52107 m .52962 .52297 L .53185 .51986 L F
.862 .836 .82 r
.5357 .51806 m .53337 .52107 L .53185 .51986 L F
0 0 .129 r
.65282 .42218 m .65257 .42105 L .65174 .41954 L F
.65282 .42218 m .65258 .42337 L .65257 .42105 L F
.472 .228 .463 r
.72606 .44761 m .72619 .45002 L .72345 .45049 L F
.373 .157 .451 r
.72837 .44878 m .72606 .44761 L .72852 .44691 L F
.72837 .44878 m .72619 .45002 L .72606 .44761 L F
.535 .108 .178 r
.43335 .63856 m .43199 .64045 L .42986 .63911 L F
.494 .069 .16 r
.43587 .63846 m .43199 .64045 L .43335 .63856 L F
.621 .205 .233 r
.40685 .63242 m .40913 .63304 L .4106 .63191 L F
.506 0 0 r
.40913 .63304 m .41286 .63295 L .4106 .63191 L F
.915 .753 .263 r
.67196 .44378 m .6717 .44623 L .67207 .44734 L F
.817 .496 0 r
.6721 .44851 m .67207 .44734 L .6717 .44623 L F
.6721 .44851 m .67271 .44969 L .67207 .44734 L F
.47 .07 .2 r
.44776 .58023 m .44704 .58193 L .44491 .5817 L F
.499 .163 .329 r
.59122 .50655 m .59357 .50793 L .59119 .50778 L F
.59122 .50655 m .59412 .5058 L .59357 .50793 L F
.19 0 .115 r
.48407 .62098 m .48603 .62022 L .48741 .61785 L F
.641 .47 .637 r
.48741 .61785 m .4902 .61766 L .48985 .61559 L F
.37 .012 .22 r
.48741 .61785 m .48849 .61856 L .4902 .61766 L F
.48741 .61785 m .48603 .62022 L .48849 .61856 L F
.472 .267 .52 r
.35973 .60002 m .36203 .59724 L .35954 .59751 L F
0 0 .123 r
.6424 .4228 m .64265 .42696 L .64185 .42598 L F
.996 .864 .559 r
.64185 .42598 m .64265 .42696 L .64206 .4293 L F
.328 .713 .982 r
.24825 .54757 m .24762 .54869 L .24575 .54733 L F
.24825 .54757 m .2501 .5487 L .24762 .54869 L F
.663 .486 .634 r
.48985 .61559 m .4902 .61766 L .49236 .61525 L F
.459 .639 .934 r
.36368 .62875 m .36413 .62652 L .36152 .6278 L F
.36368 .62875 m .36545 .62833 L .36413 .62652 L F
.673 .646 .815 r
.62986 .45808 m .62623 .45658 L .62915 .45798 L F
.758 .723 .82 r
.62912 .45554 m .62986 .45808 L .62915 .45798 L F
.62912 .45554 m .63284 .45632 L .62986 .45808 L F
.472 .778 .997 r
.68715 .41085 m .68987 .41062 L .68653 .41055 L F
.5 .186 .366 r
.59945 .50026 m .60155 .50186 L .59916 .50236 L F
.59945 .50026 m .60201 .49996 L .60155 .50186 L F
.699 .654 .802 r
.61466 .46116 m .61836 .46188 L .6152 .46423 L F
.862 .836 .82 r
.5357 .51806 m .53185 .51986 L .53413 .517 L F
.24 .752 .863 r
.18734 .55463 m .18531 .55445 L .18313 .55477 L F
.227 0 0 r
.18908 .55413 m .18531 .55445 L .18734 .55463 L F
.79 .979 .906 r
.62524 .47933 m .62771 .47637 L .62512 .47914 L F
.317 .117 .443 r
.23484 .61764 m .23461 .62117 L .23252 .62117 L F
.338 .132 .446 r
.23391 .62231 m .23252 .62117 L .23461 .62117 L F
.23391 .62231 m .23217 .62353 L .23252 .62117 L F
.677 .536 .686 r
.41991 .5893 m .41957 .59243 L .41831 .58849 L F
.207 0 .034 r
.22783 .57346 m .23008 .57278 L .2311 .57127 L F
.212 0 .037 r
.2311 .57127 m .23185 .57214 L .23317 .57059 L F
.2311 .57127 m .23008 .57278 L .23185 .57214 L F
.669 .666 .838 r
.70819 .40719 m .7045 .40579 L .70698 .40502 L F
.651 .697 .88 r
.71061 .40615 m .70819 .40719 L .70698 .40502 L F
.777 .513 .537 r
.5155 .55315 m .51197 .55531 L .51507 .55288 L F
.5155 .55315 m .51567 .55561 L .51197 .55531 L F
0 0 0 r
.51719 .55002 m .5155 .55315 L .51678 .55182 L F
.567 .937 .9 r
.51678 .55182 m .5155 .55315 L .51507 .55288 L F
.95 .697 .52 r
.54901 .66712 m .55089 .66536 L .54892 .66452 L F
.54901 .66712 m .55115 .66841 L .55089 .66536 L F
0 0 .556 r
.25827 .55295 m .25852 .55638 L .25742 .5528 L F
.25827 .55295 m .25906 .55497 L .25852 .55638 L F
.287 .286 .683 r
.25906 .55497 m .25771 .5567 L .25852 .55638 L F
.625 .612 .817 r
.68237 .41976 m .68204 .42271 L .68546 .4188 L F
.7 .664 .811 r
.68204 .42271 m .68589 .42263 L .68546 .4188 L F
.47 .355 .64 r
.54183 .54991 m .5422 .55243 L .53972 .55051 L F
.479 .354 .632 r
.5422 .55243 m .54003 .55304 L .53972 .55051 L F
.171 0 .353 r
.45256 .63648 m .45049 .636 L .45403 .63577 L F
.479 0 0 r
.45855 .63696 m .45499 .63736 L .45624 .63602 L F
.624 .511 .704 r
.45499 .63736 m .45835 .63705 L .45826 .63682 L F
.705 .241 .146 r
.45624 .63602 m .45314 .63641 L .45403 .63577 L F
.446 0 0 r
.46013 .6363 m .45855 .63696 L .45624 .63602 L F
.705 .241 .146 r
.45624 .63602 m .45499 .63736 L .45256 .63648 L F
.624 .511 .704 r
.45545 .63659 m .45826 .63682 L .45705 .63389 L F
.45499 .63736 m .45826 .63682 L .45545 .63659 L F
.705 .241 .146 r
.45314 .63641 m .45256 .63648 L .45278 .63638 L F
.45314 .63641 m .45278 .63638 L .45403 .63577 L F
.468 .212 .442 r
.70758 .44742 m .70743 .44931 L .71029 .44679 L F
.752 .758 .857 r
.68546 .4188 m .68589 .42263 L .68879 .42028 L F
.885 .826 .784 r
.62002 .41194 m .61775 .41462 L .61657 .4137 L F
.318 .076 .38 r
.24979 .58841 m .24936 .5907 L .24743 .59138 L F
.451 .26 .53 r
.24896 .59413 m .24743 .59138 L .24936 .5907 L F
.24896 .59413 m .24748 .59492 L .24743 .59138 L F
.258 0 .227 r
.7314 .4438 m .73393 .44142 L .73384 .44309 L F
.474 .212 .436 r
.73393 .44142 m .73624 .44265 L .73384 .44309 L F
.73393 .44142 m .73644 .44079 L .73624 .44265 L F
.378 .755 .99 r
.21463 .54119 m .21668 .54102 L .21844 .54195 L F
.195 .676 .931 r
.21668 .54102 m .22058 .54184 L .21844 .54195 L F
.274 0 0 r
.19974 .55238 m .19759 .55289 L .19535 .55273 L F
.322 0 0 r
.20135 .5527 m .19759 .55289 L .19974 .55238 L F
.234 0 0 r
.46214 .63664 m .45855 .63696 L .46013 .6363 L F
.26 0 0 r
.46259 .63601 m .46214 .63664 L .46013 .6363 L F
.607 .652 .868 r
.72765 .42669 m .72851 .42319 L .72652 .42319 L F
.72765 .42669 m .73019 .42609 L .72851 .42319 L F
.547 .367 .589 r
.72765 .42669 m .7276 .42892 L .73019 .42609 L F
.432 .874 .856 r
.4374 .57282 m .43998 .57209 L .43845 .57208 L F
.268 .775 .821 r
.43998 .57209 m .44097 .57157 L .43845 .57208 L F
.43998 .57209 m .44169 .57168 L .44097 .57157 L F
.461 .03 .133 r
.71568 .45528 m .71443 .45682 L .71238 .45613 L F
.052 0 0 r
.71792 .45512 m .71443 .45682 L .71568 .45528 L F
.486 .649 .93 r
.6815 .41219 m .67861 .41074 L .68046 .41112 L F
.565 .876 .993 r
.68305 .41073 m .6815 .41219 L .68046 .41112 L F
.68305 .41073 m .68406 .41147 L .6815 .41219 L F
0 .04 .604 r
.65686 .4175 m .65881 .42074 L .65803 .41933 L F
0 .024 .58 r
.65803 .41933 m .65881 .42074 L .66079 .42299 L F
.108 .656 .821 r
.39396 .64267 m .3921 .64236 L .3898 .64238 L F
.229 0 0 r
.39619 .64229 m .3921 .64236 L .39396 .64267 L F
.637 .282 .353 r
.64328 .43554 m .64691 .43521 L .64594 .43723 L F
.601 .039 0 r
.64691 .43521 m .64854 .43637 L .64594 .43723 L F
.64691 .43521 m .64951 .43641 L .64854 .43637 L F
.342 .621 .955 r
.21607 .59803 m .21688 .59699 L .21482 .59673 L F
.21607 .59803 m .21688 .59699 L .21482 .59673 L F
.409 .732 .991 r
.63372 .43946 m .6323 .44067 L .63135 .44024 L F
.799 .734 .792 r
.67834 .41677 m .67757 .41942 L .67949 .41673 L F
.67834 .41677 m .67759 .41934 L .67757 .41942 L F
.412 .17 .435 r
.25223 .58692 m .24936 .5907 L .24979 .58841 L F
.557 .709 .942 r
.43884 .58078 m .43978 .57918 L .43743 .5787 L F
.43884 .58078 m .44146 .58029 L .43978 .57918 L F
.408 .209 .496 r
.25459 .58198 m .25446 .58491 L .25194 .58546 L F
.444 .228 .489 r
.25349 .58642 m .25194 .58546 L .25446 .58491 L F
.25349 .58642 m .25223 .58692 L .25194 .58546 L F
.052 0 .08 r
.20894 .65335 m .20794 .65585 L .20621 .65647 L F
.248 0 .295 r
.21047 .65265 m .20894 .65335 L .21137 .65059 L F
0 0 .012 r
.20929 .65475 m .20894 .65335 L .21047 .65265 L F
.20929 .65475 m .20794 .65585 L .20894 .65335 L F
0 0 .35 r
.65638 .41536 m .65699 .41601 L .65641 .41368 L F
.65638 .41536 m .65686 .4175 L .65699 .41601 L F
.55 .872 .592 r
.70287 .45995 m .70094 .46178 L .70132 .46155 L F
.161 0 .357 r
.22588 .57694 m .2273 .57685 L .22783 .57346 L F
.187 .203 .644 r
.22588 .57694 m .22774 .57886 L .2273 .57685 L F
.292 .219 .6 r
.22628 .57969 m .22774 .57886 L .22588 .57694 L F
.508 .31 .547 r
.5807 .51481 m .57836 .51802 L .57796 .51502 L F
.474 .477 .781 r
.19613 .67923 m .19828 .67949 L .19644 .68015 L F
.302 .055 .363 r
.19644 .68015 m .19828 .67949 L .19585 .68249 L F
.432 .275 .566 r
.25685 .56483 m .25681 .56778 L .25489 .56828 L F
.485 .448 .742 r
.25681 .56778 m .25764 .5703 L .25489 .56828 L F
.213 .732 .859 r
.17664 .54173 m .18069 .54171 L .1787 .54233 L F
.653 .55 .725 r
.22371 .56688 m .21979 .56478 L .22367 .56486 L F
.606 .358 .515 r
.22619 .565 m .22371 .56688 L .22367 .56486 L F
.872 .734 .707 r
.51682 .55921 m .51385 .55825 L .51567 .55561 L F
.97 .733 .521 r
.51537 .56173 m .51385 .55825 L .51682 .55921 L F
.609 .421 .602 r
.58721 .48844 m .58954 .48515 L .58739 .48582 L F
.58721 .48844 m .58978 .48915 L .58954 .48515 L F
.735 .542 .632 r
.58978 .48915 m .5933 .48562 L .58954 .48515 L F
0 0 .331 r
.51091 .68032 m .51143 .67864 L .5111 .67728 L F
0 0 .393 r
.74733 .43245 m .74797 .43482 L .74791 .43521 L F
.781 .997 .857 r
.74791 .43521 m .74797 .43482 L .74466 .43735 L F
.422 0 .114 r
.37239 .591 m .37488 .59075 L .3761 .58905 L F
.419 0 .13 r
.37488 .59075 m .37832 .58893 L .3761 .58905 L F
.912 .873 .786 r
.51974 .53931 m .5175 .53986 L .51877 .5384 L F
.826 .733 .761 r
.6282 .44989 m .62912 .45316 L .6263 .45295 L F
.756 .504 .552 r
.62912 .45316 m .62532 .45502 L .6263 .45295 L F
.62912 .45316 m .62912 .45554 L .62532 .45502 L F
.394 .763 .993 r
.38296 .63429 m .38194 .63411 L .38113 .6346 L F
.38194 .63411 m .37964 .6337 L .38113 .6346 L F
.23 .373 .801 r
.37851 .63255 m .37976 .63546 L .38113 .6346 L F
.37976 .63546 m .38011 .63628 L .38113 .6346 L F
.392 .589 .922 r
.38011 .63628 m .38382 .63799 L .38113 .6346 L F
.562 .738 .958 r
.74846 .43012 m .74978 .43187 L .74733 .43245 L F
.347 .27 .626 r
.74968 .43394 m .74733 .43245 L .74978 .43187 L F
.74968 .43394 m .74797 .43482 L .74733 .43245 L F
.441 .813 .993 r
.63604 .43189 m .64016 .4323 L .6385 .43148 L F
.078 .589 .886 r
.6385 .43148 m .64016 .4323 L .64116 .43227 L F
.617 .458 .644 r
.26296 .80377 m .2606 .80674 L .26069 .80425 L F
.26069 .80425 m .2606 .80674 L .26296 .80377 L F
.82 .604 .61 r
.23172 .56513 m .22956 .56725 L .22964 .56418 L F
.23172 .56513 m .23326 .56806 L .22956 .56725 L F
.741 .847 .929 r
.45733 .57424 m .45916 .57616 L .46086 .57416 L F
.519 .733 .971 r
.45916 .57616 m .46189 .57613 L .46086 .57416 L F
.263 .771 .78 r
.18462 .54126 m .18509 .54094 L .18681 .5413 L F
0 .42 .856 r
.68523 .41794 m .68879 .42028 L .68959 .41816 L F
.669 .675 .847 r
.7229 .40801 m .72145 .41218 L .72121 .40858 L F
.7229 .40801 m .7239 .41137 L .72145 .41218 L F
.985 .708 .362 r
.66547 .45018 m .66442 .45144 L .66426 .44906 L F
.66547 .45018 m .66557 .45259 L .66442 .45144 L F
0 .227 .696 r
.6824 .45865 m .67889 .45599 L .67945 .45898 L F
.468 .329 .608 r
.20271 .62418 m .20274 .62679 L .20474 .62622 L F
.201 0 .211 r
.21306 .6497 m .21137 .65059 L .21404 .64783 L F
.026 0 .095 r
.21541 .64687 m .21404 .64783 L .21648 .64493 L F
.184 0 .246 r
.21541 .64687 m .21306 .6497 L .21404 .64783 L F
.421 .593 .915 r
.67201 .46902 m .67275 .47083 L .67418 .46905 L F
.67201 .46902 m .67275 .47083 L .67418 .46905 L F
.488 .364 .637 r
.35776 .6039 m .35983 .60342 L .35973 .60002 L F
.504 .427 .703 r
.3583 .60628 m .35983 .60342 L .35776 .6039 L F
.122 0 0 r
.45262 .5716 m .45195 .57158 L .4507 .57206 L F
.377 .419 .777 r
.44818 .57051 m .44871 .57283 L .4507 .57206 L F
.659 .176 .092 r
.44818 .57051 m .4507 .57206 L .44672 .57165 L F
.122 0 0 r
.45195 .57158 m .44884 .57153 L .4507 .57206 L F
.377 .419 .777 r
.44871 .57283 m .44913 .57467 L .4507 .57206 L F
.516 .598 .875 r
.44913 .57467 m .45176 .57461 L .4507 .57206 L F
.071 .221 .714 r
.38965 .61665 m .38872 .61811 L .3874 .61424 L F
0 .023 .592 r
.38993 .61875 m .38872 .61811 L .38965 .61665 L F
.38993 .61875 m .39074 .62104 L .38872 .61811 L F
.176 .17 .612 r
.38872 .61811 m .39074 .62104 L .38942 .62061 L F
.86 .68 .657 r
.65507 .43734 m .65649 .44082 L .65711 .43858 L F
0 0 .092 r
.51719 .55002 m .51722 .54994 L .51696 .54684 L F
0 0 0 r
.51719 .55002 m .51678 .55182 L .51722 .54994 L F
.58805 .62097 m .58541 .62362 L .58671 .62222 L F
.58671 .62222 m .58541 .62362 L .58805 .62097 L F
.217 .374 .806 r
.39496 .62529 m .39386 .62692 L .3922 .62341 L F
.075 .174 .664 r
.39496 .62529 m .39565 .62896 L .39386 .62692 L F
.857 .962 .871 r
.5928 .44151 m .59315 .43908 L .59527 .43866 L F
.5928 .44151 m .59195 .44066 L .59315 .43908 L F
0 0 .023 r
.21306 .6497 m .21047 .65265 L .21137 .65059 L F
.164 0 .156 r
.7314 .4438 m .73088 .44602 L .72852 .44691 L F
.181 0 .161 r
.733 .44475 m .7314 .4438 L .73384 .44309 L F
.733 .44475 m .73088 .44602 L .7314 .4438 L F
.399 .55 .89 r
.19499 .66538 m .19507 .66479 L .19202 .66433 L F
.19499 .66538 m .19573 .66521 L .19507 .66479 L F
.744 .688 .797 r
.19374 .6683 m .19573 .66521 L .19499 .66538 L F
.144 0 0 r
.2059 .61153 m .20608 .61169 L .20824 .61104 L F
.20824 .61104 m .20608 .61169 L .2059 .61153 L F
.686 .682 .84 r
.73258 .40857 m .73355 .41179 L .73009 .41102 L F
.583 .741 .952 r
.73493 .40962 m .73355 .41179 L .73258 .40857 L F
.73493 .40962 m .73605 .41119 L .73355 .41179 L F
.817 .834 .862 r
.61885 .40616 m .61477 .40755 L .61747 .40475 L F
.808 .83 .868 r
.62165 .40373 m .61885 .40616 L .61747 .40475 L F
.202 0 .362 r
.218 .64379 m .21648 .64493 L .21847 .64167 L F
.189 0 .2 r
.21682 .64628 m .21648 .64493 L .218 .64379 L F
.21682 .64628 m .21541 .64687 L .21648 .64493 L F
.774 .447 .434 r
.54233 .6893 m .54192 .69176 L .54061 .68864 L F
.268 .068 .413 r
.54233 .6893 m .54405 .69065 L .54192 .69176 L F
.54233 .6893 m .54492 .68834 L .54405 .69065 L F
.354 .828 .811 r
.68616 .46662 m .68657 .46674 L .68996 .46564 L F
.375 .713 .987 r
.36917 .62847 m .36988 .62739 L .36668 .62724 L F
.36917 .62847 m .37181 .62849 L .36988 .62739 L F
.629 .258 .32 r
.61912 .45246 m .62262 .45258 L .61925 .4513 L F
.468 .013 .087 r
.42986 .63911 m .42843 .64077 L .42605 .6408 L F
.542 .095 .137 r
.43199 .64045 m .42843 .64077 L .42986 .63911 L F
0 0 .067 r
.63379 .44722 m .63575 .44342 L .63505 .44519 L F
.353 .387 .757 r
.63505 .44519 m .63617 .44863 L .63379 .44722 L F
0 .335 .804 r
.6374 .44999 m .63379 .44722 L .63617 .44863 L F
.65 .548 .726 r
.64206 .4293 m .63959 .42961 L .64099 .42821 L F
.361 .467 .833 r
.63959 .42961 m .64089 .4303 L .64099 .42821 L F
.441 .854 .961 r
.18681 .5413 m .18892 .54072 L .19064 .54101 L F
.174 .698 .871 r
.19064 .54101 m .18892 .54072 L .19279 .54093 L F
.394 0 .124 r
.38057 .5888 m .38314 .58853 L .38455 .58607 L F
.32 0 .086 r
.38455 .58607 m .38451 .5879 L .38694 .586 L F
.38455 .58607 m .38314 .58853 L .38451 .5879 L F
.174 0 .184 r
.60533 .47802 m .60291 .47846 L .60269 .48075 L F
.755 .426 .428 r
.4214 .63029 m .42477 .63226 L .42488 .63012 L F
.537 .307 .514 r
.42477 .63226 m .42715 .63203 L .42488 .63012 L F
.506 .806 .999 r
.4432 .56423 m .44682 .5647 L .44458 .5652 L F
.271 0 .015 r
.74255 .43857 m .742 .44014 L .7392 .44084 L F
0 0 0 r
.74376 .43869 m .74255 .43857 L .74466 .43735 L F
.74376 .43869 m .742 .44014 L .74255 .43857 L F
.735 .542 .632 r
.58978 .48915 m .59329 .48816 L .5933 .48562 L F
.582 .353 .533 r
.59329 .48816 m .59599 .48546 L .5933 .48562 L F
.819 .989 .728 r
.5591 .48182 m .55598 .4854 L .5567 .48339 L F
.906 .978 .698 r
.5591 .48182 m .55867 .48033 L .56043 .47915 L F
.898 .984 .724 r
.5591 .48182 m .5567 .48339 L .55867 .48033 L F
.507 .686 .948 r
.54042 .68082 m .54148 .67882 L .53961 .67766 L F
.423 .106 .321 r
.72619 .45002 m .72319 .45199 L .72345 .45049 L F
.608 .428 .612 r
.54616 .53855 m .54614 .54131 L .5435 .54106 L F
.578 .423 .635 r
.54614 .54131 m .54422 .54433 L .5435 .54106 L F
.309 0 0 r
.71238 .45613 m .71146 .45727 L .70894 .45739 L F
.285 .786 .835 r
.71443 .45682 m .71146 .45727 L .71238 .45613 L F
.498 .394 .667 r
.19776 .67661 m .19613 .67923 L .1953 .67696 L F
.19776 .67661 m .19828 .67949 L .19613 .67923 L F
.972 .753 .548 r
.66394 .42937 m .66251 .42847 L .66281 .42604 L F
.66394 .42937 m .66251 .42847 L .66281 .42604 L F
.588 .069 0 r
.66394 .42937 m .66336 .43071 L .66251 .42847 L F
.66394 .42937 m .66715 .43146 L .66336 .43071 L F
0 0 0 r
.41126 .59643 m .40806 .59968 L .40827 .5973 L F
.966 .644 .27 r
.62881 .43064 m .6267 .43377 L .62652 .43189 L F
.11 0 0 r
.62767 .43173 m .62881 .43064 L .62762 .43176 L F
.988 .719 .397 r
.62989 .42959 m .62998 .4319 L .62881 .43064 L F
.626 .224 .262 r
.62989 .42951 m .63125 .43147 L .62998 .4319 L F
.966 .644 .27 r
.62881 .43064 m .62998 .4319 L .63002 .43372 L F
.62881 .43064 m .63002 .43372 L .6267 .43377 L F
.11 0 0 r
.63125 .43005 m .62881 .43064 L .62767 .43173 L F
.988 .719 .397 r
.62989 .42951 m .62989 .42959 L .62881 .43064 L F
.69 .305 .314 r
.63228 .42865 m .62998 .42701 L .62989 .42951 L F
0 0 0 r
.63228 .42865 m .62989 .42951 L .62881 .43064 L F
.977 .732 .5 r
.23326 .56806 m .23175 .56933 L .22956 .56725 L F
.23326 .56806 m .23317 .57059 L .23175 .56933 L F
.171 0 .353 r
.45256 .63648 m .45022 .63832 L .45049 .636 L F
.173 .686 .895 r
.22058 .54184 m .22264 .5417 L .22439 .54229 L F
.223 .707 .93 r
.22264 .5417 m .22676 .54231 L .22439 .54229 L F
.799 .734 .792 r
.67834 .41677 m .67918 .42004 L .67759 .41934 L F
.477 0 0 r
.67918 .42004 m .67589 .41936 L .67759 .41934 L F
.396 .157 .431 r
.59666 .50562 m .59665 .50303 L .59916 .50236 L F
.796 .683 .74 r
.58232 .4818 m .58599 .48227 L .58474 .47898 L F
.804 .631 .667 r
.58383 .48535 m .58599 .48227 L .58232 .4818 L F
.79 .61 .658 r
.58383 .48535 m .58739 .48582 L .58599 .48227 L F
.96 .82 .662 r
.64482 .41756 m .64226 .41899 L .64219 .41654 L F
.64482 .41756 m .64389 .42059 L .64226 .41899 L F
.369 0 .144 r
.67466 .41372 m .67766 .41308 L .67861 .41074 L F
0 0 0 r
.67861 .41074 m .67982 .41054 L .68046 .41112 L F
.67861 .41074 m .67766 .41308 L .67982 .41054 L F
.723 .819 .924 r
.43634 .58546 m .43436 .5866 L .43154 .58503 L F
.43634 .58546 m .43436 .5866 L .43154 .58503 L F
.336 0 0 r
.47707 .63051 m .47919 .63099 L .47669 .63116 L F
.47707 .63051 m .48025 .62986 L .47919 .63099 L F
.996 .781 .493 r
.60701 .44059 m .60677 .44425 L .6078 .44357 L F
.716 .777 .9 r
.60765 .44475 m .6078 .44357 L .60677 .44425 L F
.22 .538 .925 r
.38752 .64202 m .38792 .64064 L .38701 .64081 L F
.38752 .64202 m .3898 .64238 L .38792 .64064 L F
.505 0 0 r
.44771 .63373 m .45299 .63509 L .44684 .63341 L F
.768 .512 .548 r
.44749 .63654 m .44979 .63523 L .4489 .63456 L F
.505 0 0 r
.44782 .63376 m .4489 .63456 L .45299 .63509 L F
.449 .044 .178 r
.4489 .63456 m .45285 .63212 L .45299 .63509 L F
.768 .512 .548 r
.44979 .63523 m .45128 .63438 L .4489 .63456 L F
.505 0 0 r
.44771 .63373 m .4489 .63456 L .44782 .63376 L F
.43 .283 .579 r
.38946 .61202 m .3874 .61424 L .38738 .61419 L F
.555 .372 .588 r
.62912 .45554 m .62623 .45658 L .62532 .45502 L F
.62912 .45554 m .62915 .45798 L .62623 .45658 L F
.807 .517 0 r
.66621 .45876 m .66603 .45911 L .66472 .45697 L F
.66621 .45876 m .66666 .46108 L .66603 .45911 L F
.571 .605 .847 r
.63919 .44646 m .6374 .44999 L .63617 .44863 L F
.63919 .44646 m .63968 .44964 L .6374 .44999 L F
.239 .064 .431 r
.20097 .62997 m .20211 .63173 L .2026 .62928 L F
.20097 .62997 m .20066 .63257 L .20211 .63173 L F
.475 .744 .987 r
.67944 .40632 m .68056 .40772 L .68287 .40744 L F
.548 .428 .668 r
.53596 .56131 m .53634 .56486 L .53579 .56241 L F
.53596 .56131 m .53871 .56432 L .53634 .56486 L F
.501 .4 .671 r
.54232 .55835 m .53596 .56131 L .53906 .55947 L F
.54232 .55835 m .54045 .56123 L .53596 .56131 L F
.462 .372 .668 r
.54045 .56123 m .53871 .56432 L .53596 .56131 L F
.563 .376 .585 r
.55038 .52976 m .55033 .53217 L .54799 .53267 L F
.674 .475 .608 r
.55212 .52978 m .55033 .53217 L .55038 .52976 L F
.411 .192 .468 r
.23606 .61961 m .23484 .61764 L .23685 .61706 L F
.23606 .61961 m .23461 .62117 L .23484 .61764 L F
.553 .401 .629 r
.55033 .53217 m .54826 .53506 L .54799 .53267 L F
.621 .498 .692 r
.54826 .53506 m .5486 .53785 L .54616 .53855 L F
.398 .176 .457 r
.5486 .53785 m .54614 .54131 L .54616 .53855 L F
.845 .865 .857 r
.63186 .46993 m .63314 .4712 L .63586 .46819 L F
.63 .619 .82 r
.71681 .42035 m .72055 .42295 L .7193 .41971 L F
.632 .639 .839 r
.7193 .41971 m .72055 .42295 L .72312 .42199 L F
.857 .996 .816 r
.59805 .43558 m .59527 .43866 L .59593 .43635 L F
.926 .974 .737 r
.59983 .43244 m .59805 .43558 L .59812 .43325 L F
.91 .975 .788 r
.59805 .43558 m .59593 .43635 L .59812 .43325 L F
.781 .642 .707 r
.52552 .56846 m .5255 .57096 L .52187 .57047 L F
.719 .594 .715 r
.52546 .57344 m .52187 .57047 L .5255 .57096 L F
.711 .584 .711 r
.52798 .56788 m .5255 .57096 L .52552 .56846 L F
.701 .569 .703 r
.52898 .5707 m .5255 .57096 L .52798 .56788 L F
.643 .414 .557 r
.52898 .5707 m .52546 .57344 L .5255 .57096 L F
.606 .702 .912 r
.70102 .405 m .6972 .40276 L .69972 .40214 L F
.623 .724 .919 r
.70221 .40144 m .70102 .405 L .69972 .40214 L F
.70221 .40144 m .70367 .40421 L .70102 .405 L F
.123 0 0 r
.46829 .63386 m .46728 .63492 L .46496 .63544 L F
.008 0 0 r
.46942 .6342 m .46829 .63386 L .47032 .63359 L F
.46942 .6342 m .46728 .63492 L .46829 .63386 L F
.596 .541 .763 r
.3922 .62341 m .38981 .62408 L .38942 .62061 L F
0 0 0 r
.51746 .69752 m .51896 .69684 L .51633 .69749 L F
.504 .427 .703 r
.3583 .60628 m .36039 .60575 L .35983 .60342 L F
.54 .451 .703 r
.35865 .60904 m .36039 .60575 L .3583 .60628 L F
.637 .282 .353 r
.64328 .43554 m .64594 .43723 L .64336 .4376 L F
.537 .595 .859 r
.56243 .63778 m .56293 .63444 L .5604 .63478 L F
.56243 .63778 m .56446 .63778 L .56293 .63444 L F
.728 .828 .927 r
.66211 .41086 m .66009 .4123 L .65869 .41084 L F
.503 .303 .542 r
.48268 .62702 m .48253 .62958 L .48025 .62986 L F
.522 .109 .199 r
.48253 .62958 m .47919 .63099 L .48025 .62986 L F
.276 0 0 r
.54384 .65841 m .54122 .65647 L .54123 .65907 L F
.671 .226 .186 r
.53759 .65621 m .54122 .65647 L .53993 .6581 L F
.348 0 0 r
.54018 .65661 m .54122 .65647 L .53759 .65621 L F
.918 .577 .376 r
.53993 .6581 m .54122 .65647 L .54018 .65661 L F
.583 .33 .499 r
.55884 .52677 m .56126 .52878 L .55886 .52911 L F
.55884 .52677 m .56112 .52668 L .56126 .52878 L F
.548 .174 .283 r
.39743 .60248 m .39638 .60472 L .39433 .6033 L F
.636 .478 .651 r
.40082 .59942 m .40011 .603 L .39743 .60248 L F
.517 .093 .175 r
.40011 .603 m .39638 .60472 L .39743 .60248 L F
.781 .642 .707 r
.52552 .56846 m .52187 .57047 L .52208 .56797 L F
.767 .619 .695 r
.58345 .48794 m .58739 .48582 L .58383 .48535 L F
.58345 .48794 m .58721 .48844 L .58739 .48582 L F
.842 .981 .691 r
.59762 .45725 m .59682 .45949 L .59912 .45626 L F
.859 .981 .69 r
.59967 .45419 m .59762 .45725 L .59912 .45626 L F
.273 .221 .615 r
.25757 .57347 m .25666 .57651 L .25593 .57421 L F
.827 .421 0 r
.54061 .68864 m .54192 .69176 L .54103 .69085 L F
.871 .795 .773 r
.54045 .68893 m .54214 .68954 L .54073 .68851 L F
.733 .486 .555 r
.54022 .68761 m .541 .69075 L .53655 .6901 L F
.541 .69075 m .54103 .69085 L .5409 .69083 L F
.541 .69075 m .5409 .69083 L .53655 .6901 L F
.733 .5 .575 r
.53655 .6901 m .54103 .69085 L .53829 .69291 L F
.749 .67 .774 r
.53697 .69298 m .53755 .69408 L .53619 .69301 L F
.53755 .69408 m .53859 .69608 L .53732 .69446 L F
.53755 .69408 m .53732 .69446 L .53619 .69301 L F
.733 .5 .575 r
.53701 .69297 m .53829 .69291 L .53743 .69355 L F
.53701 .69303 m .53743 .69355 L .53713 .69378 L F
.53701 .69297 m .53743 .69355 L .53701 .69303 L F
.029 .264 .763 r
.53883 .69527 m .53859 .69608 L .53789 .69472 L F
.53743 .69355 m .53789 .69472 L .53697 .69298 L F
.53883 .69527 m .53789 .69472 L .53743 .69355 L F
.733 .5 .575 r
.53655 .6901 m .53829 .69291 L .53701 .69297 L F
.827 .421 0 r
.54061 .68864 m .54102 .6908 L .54022 .68761 L F
.54102 .6908 m .54103 .69085 L .541 .69075 L F
.54102 .6908 m .541 .69075 L .54022 .68761 L F
.871 .795 .773 r
.53743 .69353 m .54103 .69085 L .54214 .68954 L F
.53713 .69378 m .53743 .69355 L .53743 .69353 L F
.53743 .69355 m .54103 .69085 L .53743 .69353 L F
.53713 .69378 m .53743 .69353 L .53737 .69343 L F
.53743 .69353 m .53832 .69278 L .5374 .69341 L F
.029 .264 .763 r
.53739 .69336 m .53697 .69298 L .53667 .6924 L F
.9 .907 .82 r
.54073 .68851 m .53827 .68903 L .53732 .693 L F
.029 .264 .763 r
.53739 .69336 m .5374 .69339 L .53739 .69336 L F
.53743 .69354 m .53697 .69298 L .53739 .69336 L F
.9 .907 .82 r
.5374 .69339 m .53732 .693 L .53713 .69378 L F
.54073 .68851 m .53732 .693 L .5374 .69339 L F
.029 .264 .763 r
.53883 .69527 m .53743 .69354 L .5374 .69339 L F
.53883 .69527 m .5374 .69339 L .53739 .69336 L F
.871 .795 .773 r
.5374 .69339 m .54094 .69055 L .54045 .68893 L F
.53737 .69343 m .5374 .6934 L .5374 .69339 L F
.5374 .6934 m .54094 .69055 L .5374 .69339 L F
.53743 .69353 m .5374 .69341 L .53737 .69343 L F
.029 .264 .763 r
.53905 .69449 m .53883 .69527 L .53739 .69336 L F
.733 .486 .555 r
.54022 .68761 m .53655 .6901 L .5397 .68667 L F
.276 0 0 r
.53593 .68905 m .5397 .68667 L .53655 .6901 L F
.475 .476 .779 r
.53713 .69378 m .53655 .6901 L .53667 .6924 L F
.733 .5 .575 r
.53655 .6901 m .53713 .69378 L .53667 .6924 L F
.475 .476 .779 r
.53713 .69378 m .5369 .69285 L .53655 .6901 L F
.5369 .69285 m .53593 .68905 L .5365 .69001 L F
.5369 .69285 m .5365 .69001 L .53655 .6901 L F
.749 .67 .774 r
.53619 .69301 m .53859 .69608 L .53435 .69536 L F
.523 .328 .558 r
.53682 .69537 m .53723 .69521 L .53667 .6924 L F
.475 .476 .779 r
.53713 .69378 m .53732 .693 L .53726 .69292 L F
.029 .264 .763 r
.53726 .69292 m .53739 .69336 L .53667 .6924 L F
.523 .328 .558 r
.5369 .69285 m .53726 .69292 L .53686 .69257 L F
.475 .476 .779 r
.5369 .69285 m .53726 .69292 L .53673 .69219 L F
.53713 .69378 m .53726 .69292 L .5369 .69285 L F
.53732 .693 m .53827 .68903 L .53673 .69219 L F
.029 .264 .763 r
.5373 .69295 m .53731 .69298 L .53726 .69292 L F
.53731 .69298 m .53739 .69336 L .53726 .69292 L F
.871 .795 .773 r
.53872 .69243 m .54094 .69055 L .53737 .69343 L F
.029 .264 .763 r
.53905 .69449 m .53739 .69336 L .5373 .69295 L F
.523 .328 .558 r
.53723 .69521 m .53905 .69449 L .53726 .69292 L F
.53723 .69521 m .53726 .69292 L .5369 .69285 L F
.53723 .69521 m .53686 .69257 L .53667 .6924 L F
.475 .476 .779 r
.53673 .69219 m .53827 .68903 L .53593 .68905 L F
.871 .795 .773 r
.53832 .69278 m .53872 .69243 L .53836 .6927 L F
.53832 .69278 m .53836 .6927 L .53737 .69343 L F
.749 .67 .774 r
.53667 .6924 m .53697 .69298 L .53619 .69301 L F
.871 .795 .773 r
.54094 .69055 m .54214 .68954 L .54045 .68893 L F
.84 .986 .865 r
.59593 .43635 m .59527 .43866 L .59315 .43908 L F
.361 .091 .362 r
.21579 .60302 m .21797 .60257 L .21803 .60018 L F
.341 .166 .493 r
.21803 .60018 m .22029 .59948 L .22052 .597 L F
.283 .033 .347 r
.21803 .60018 m .21797 .60257 L .22029 .59948 L F
.582 .353 .533 r
.59329 .48816 m .59601 .48795 L .59599 .48546 L F
.509 .344 .592 r
.59599 .48546 m .59853 .48486 L .59821 .48246 L F
.469 .233 .474 r
.59825 .48708 m .59599 .48546 L .59601 .48795 L F
.59825 .48708 m .59853 .48486 L .59599 .48546 L F
.806 .334 .098 r
.18844 .64281 m .18784 .64171 L .18665 .64313 L F
.654 .766 .932 r
.56519 .63927 m .5661 .63702 L .56446 .63778 L F
.56519 .63927 m .56753 .63839 L .5661 .63702 L F
0 0 0 r
.41582 .57423 m .41616 .57421 L .41789 .57317 L F
.41582 .57423 m .41428 .57548 L .41616 .57421 L F
.536 .906 .958 r
.55221 .6799 m .55137 .6794 L .5487 .68037 L F
.992 .803 .423 r
.55159 .67677 m .55221 .6799 L .55478 .67699 L F
.55159 .67677 m .55137 .6794 L .55221 .6799 L F
.643 .414 .557 r
.52898 .5707 m .52879 .5737 L .52546 .57344 L F
.427 .145 .381 r
.5314 .57062 m .52879 .5737 L .52898 .5707 L F
.703 .837 .947 r
.4495 .58831 m .44601 .5884 L .44837 .5874 L F
.307 0 .263 r
.4495 .58831 m .44678 .59158 L .44601 .5884 L F
.4495 .58831 m .44888 .59089 L .44678 .59158 L F
.479 .602 .897 r
.45078 .58672 m .4495 .58831 L .44837 .5874 L F
.45078 .58672 m .45133 .58754 L .4495 .58831 L F
.089 0 .184 r
.45057 .58968 m .4495 .58831 L .45133 .58754 L F
.45057 .58968 m .44888 .59089 L .4495 .58831 L F
.442 .303 .596 r
.2452 .59977 m .24533 .60241 L .2433 .60042 L F
.398 .299 .626 r
.24533 .60241 m .24362 .60312 L .2433 .60042 L F
0 0 .139 r
.20055 .66734 m .20007 .67068 L .20017 .66824 L F
.042 0 0 r
.42182 .59188 m .41805 .59318 L .41957 .59243 L F
.957 .711 .524 r
.66669 .4412 m .66659 .44383 L .66513 .44021 L F
.37 .182 .491 r
.24132 .60864 m .23917 .61153 L .23937 .60938 L F
.14 0 .097 r
.22267 .63779 m .22086 .6387 L .22371 .63613 L F
.272 0 .18 r
.22438 .63708 m .22371 .63613 L .22508 .63505 L F
.22438 .63708 m .22267 .63779 L .22371 .63613 L F
.891 .949 .837 r
.68113 .46668 m .68122 .46822 L .68387 .46488 L F
.506 .79 .997 r
.68258 .46659 m .68122 .46822 L .68113 .46668 L F
.68258 .46659 m .68396 .4678 L .68122 .46822 L F
.881 .838 .8 r
.54612 .67015 m .54562 .67461 L .54402 .67332 L F
.513 0 0 r
.54562 .67461 m .54562 .67461 L .54402 .67332 L F
.226 .737 .7 r
.17257 .5583 m .17114 .5587 L .16977 .55914 L F
0 0 0 r
.16977 .55914 m .17114 .5587 L .16869 .55951 L F
.347 0 .126 r
.20621 .65647 m .20503 .65844 L .20278 .65885 L F
0 0 0 r
.20794 .65585 m .20503 .65844 L .20621 .65647 L F
.254 .718 .948 r
.19279 .54093 m .19488 .54089 L .19664 .54156 L F
.25 .745 .91 r
.19488 .54089 m .19878 .54104 L .19664 .54156 L F
.404 .434 .778 r
.62879 .40122 m .62688 .40282 L .62737 .40184 L F
.365 .261 .601 r
.62879 .40122 m .6269 .40507 L .62688 .40282 L F
.122 .624 .903 r
.44682 .5647 m .44935 .56503 L .45035 .56563 L F
0 .304 .706 r
.45146 .56598 m .45035 .56563 L .44935 .56503 L F
.45146 .56598 m .45484 .56784 L .45035 .56563 L F
.424 .335 .651 r
.60941 .46729 m .60781 .46792 L .61002 .46958 L F
.56 .303 .484 r
.61002 .46958 m .60781 .46792 L .60745 .46995 L F
.452 .25 .514 r
.51559 .66246 m .51721 .66443 L .51499 .66509 L F
.663 .271 .293 r
.51381 .66417 m .51721 .66443 L .51559 .66246 L F
.294 .047 .358 r
.2201 .64098 m .21847 .64167 L .22086 .6387 L F
.374 .146 .435 r
.21967 .64301 m .21847 .64167 L .2201 .64098 L F
.21967 .64301 m .218 .64379 L .21847 .64167 L F
.623 .685 .887 r
.70594 .40351 m .7045 .40579 L .70367 .40421 L F
.70594 .40351 m .70698 .40502 L .7045 .40579 L F
.326 .107 .419 r
.22783 .57346 m .22912 .57606 L .23008 .57278 L F
.22783 .57346 m .2273 .57685 L .22912 .57606 L F
.87 .995 .777 r
.6022 .42942 m .59983 .43244 L .60048 .43011 L F
.871 .994 .762 r
.60048 .43011 m .59983 .43244 L .59812 .43325 L F
.897 .798 .743 r
.61464 .4116 m .613 .4108 L .61477 .40755 L F
.742 .351 .31 r
.61464 .4116 m .61292 .41313 L .613 .4108 L F
.61464 .4116 m .61657 .4137 L .61292 .41313 L F
0 0 0 r
.51883 .54356 m .51696 .54684 L .51794 .54537 L F
.942 .959 .674 r
.59682 .45949 m .59538 .46038 L .59598 .46119 L F
.844 .985 .704 r
.59762 .45725 m .59538 .46038 L .59682 .45949 L F
.137 .678 .694 r
.45555 .57386 m .45451 .57407 L .45176 .57461 L F
.462 0 0 r
.45733 .57424 m .45451 .57407 L .45555 .57386 L F
.995 .851 .507 r
.65322 .43205 m .65388 .42907 L .65304 .42798 L F
.471 .784 .998 r
.23451 .54308 m .23411 .54448 L .23253 .54301 L F
.23451 .54308 m .23622 .54411 L .23411 .54448 L F
.654 .503 .667 r
.41398 .59248 m .41019 .59415 L .41006 .59157 L F
.055 0 .15 r
.22749 .63199 m .22508 .63505 L .22601 .63303 L F
.395 .231 .538 r
.25688 .57919 m .2567 .58178 L .25459 .58198 L F
.334 .13 .447 r
.2567 .58178 m .25446 .58491 L .25459 .58198 L F
.756 .447 .461 r
.58722 .49043 m .58721 .48844 L .58345 .48794 L F
.623 .309 .418 r
.58975 .49037 m .58721 .48844 L .58722 .49043 L F
.58975 .49037 m .58978 .48915 L .58721 .48844 L F
.447 .15 .367 r
.71276 .44451 m .71528 .44384 L .71689 .44097 L F
.69 .354 .401 r
.71719 .44286 m .71689 .44097 L .71528 .44384 L F
.71719 .44286 m .71827 .44122 L .71689 .44097 L F
0 0 0 r
.63996 .45188 m .6435 .45002 L .64211 .45064 L F
0 .261 .759 r
.6435 .45002 m .64529 .45129 L .64433 .45006 L F
.64529 .45129 m .64604 .45181 L .64433 .45006 L F
.693 .791 .926 r
.64319 .44861 m .64433 .45006 L .64383 .44742 L F
0 .261 .759 r
.6435 .45002 m .64433 .45006 L .64211 .45064 L F
.693 .791 .926 r
.64211 .45064 m .64433 .45006 L .64319 .44861 L F
.853 .724 .72 r
.64121 .45779 m .64428 .45833 L .64478 .45592 L F
.44 .237 .506 r
.19554 .63809 m .19782 .63528 L .19562 .63573 L F
.584 .281 .421 r
.57284 .5199 m .57202 .52267 L .56957 .52287 L F
.615 .367 .519 r
.57621 .51976 m .57202 .52267 L .57284 .5199 L F
.277 0 .217 r
.61483 .48793 m .61765 .4856 L .61706 .4871 L F
.154 0 .158 r
.61706 .4871 m .61765 .4856 L .61957 .48427 L F
.831 .777 .801 r
.64121 .45779 m .64189 .46089 L .64428 .45833 L F
.574 .367 .562 r
.48521 .62651 m .48253 .62958 L .48268 .62702 L F
.876 .988 .822 r
.6022 .42942 m .60263 .42702 L .60467 .42656 L F
.6022 .42942 m .60164 .42865 L .60263 .42702 L F
.921 .977 .75 r
.6022 .42942 m .60048 .43011 L .60164 .42865 L F
.052 0 0 r
.71792 .45512 m .71792 .45558 L .71443 .45682 L F
0 0 0 r
.72087 .45292 m .71992 .45415 L .71792 .45512 L F
.71992 .45415 m .71792 .45558 L .71792 .45512 L F
.835 .372 .097 r
.49085 .62032 m .4902 .61766 L .48849 .61856 L F
.49085 .62032 m .49222 .62049 L .4902 .61766 L F
.334 .753 .977 r
.68469 .40121 m .68148 .40075 L .68361 .40012 L F
.476 .746 .988 r
.68629 .39973 m .68469 .40121 L .68361 .40012 L F
.68629 .39973 m .68789 .40141 L .68469 .40121 L F
.327 0 .248 r
.61221 .49092 m .61483 .48793 L .61418 .48996 L F
.163 0 .004 r
.61483 .48793 m .6161 .48891 L .61418 .48996 L F
.61483 .48793 m .61706 .4871 L .6161 .48891 L F
.051 0 0 r
.75011 .41785 m .74945 .41911 L .74707 .41989 L F
.375 .292 .633 r
.75163 .41395 m .75254 .41636 L .75011 .41785 L F
.332 0 0 r
.75211 .4186 m .75011 .41785 L .75254 .41636 L F
.75211 .4186 m .74945 .41911 L .75011 .41785 L F
.141 .675 .857 r
.42055 .58529 m .42328 .58527 L .42429 .58555 L F
.569 .492 .729 r
.42655 .58257 m .42429 .58555 L .42344 .58308 L F
.42655 .58257 m .42661 .58498 L .42429 .58555 L F
.992 .739 .403 r
.42429 .58555 m .42328 .58527 L .42357 .58339 L F
.346 .096 .384 r
.22181 .64007 m .22086 .6387 L .22267 .63779 L F
.22181 .64007 m .2201 .64098 L .22086 .6387 L F
.52 .364 .61 r
.56021 .63257 m .55808 .63513 L .5604 .63478 L F
.74 .683 .796 r
.55656 .63197 m .55808 .63513 L .56021 .63257 L F
.056 0 0 r
.39967 .6422 m .39834 .64241 L .39619 .64229 L F
.052 0 0 r
.40057 .64236 m .39967 .6422 L .40189 .64211 L F
.40057 .64236 m .39834 .64241 L .39967 .6422 L F
.897 .956 .829 r
.21744 .56787 m .21839 .5645 L .21979 .56478 L F
.708 .574 .703 r
.21979 .56478 m .22178 .56905 L .21744 .56787 L F
0 0 .048 r
.21979 .56478 m .22024 .56332 L .22024 .56204 L F
.658 .957 .941 r
.21979 .56478 m .21839 .5645 L .22024 .56332 L F
.653 .55 .725 r
.22371 .56688 m .22178 .56905 L .21979 .56478 L F
.864 .443 .218 r
.21906 .56475 m .22023 .56526 L .22024 .56332 L F
.22023 .56526 m .22256 .56628 L .22024 .56332 L F
0 0 .048 r
.22024 .56204 m .22024 .56332 L .22045 .56081 L F
.808 .83 .868 r
.62165 .40373 m .61747 .40475 L .61967 .40336 L F
.7 .916 .968 r
.62165 .40373 m .62259 .4018 L .62341 .40216 L F
.62165 .40373 m .61967 .40336 L .62259 .4018 L F
.901 .653 .553 r
.67143 .42282 m .67119 .42534 L .67372 .4255 L F
.905 .762 .692 r
.67119 .42534 m .67225 .42883 L .67372 .4255 L F
.768 .752 .838 r
.72894 .40796 m .73009 .41102 L .72773 .4121 L F
.706 .72 .86 r
.73258 .40857 m .73009 .41102 L .72894 .40796 L F
.297 .776 .923 r
.20521 .55271 m .20346 .55241 L .20135 .5527 L F
.24 .741 .901 r
.20735 .55252 m .20346 .55241 L .20521 .55271 L F
.512 .914 .877 r
.68576 .41019 m .68653 .41055 L .68406 .41147 L F
.51 .378 .637 r
.6871 .41368 m .68406 .41147 L .68653 .41055 L F
.437 .386 .702 r
.68652 .40826 m .68653 .41055 L .68865 .40835 L F
.707 .984 .817 r
.68865 .40835 m .68653 .41055 L .68576 .41019 L F
.267 .1 .46 r
.68801 .41232 m .68653 .41055 L .68987 .41062 L F
.68801 .41232 m .6871 .41368 L .68653 .41055 L F
.33 0 .041 r
.73985 .41645 m .7432 .41429 L .74085 .41507 L F
.73985 .41645 m .74228 .41646 L .7432 .41429 L F
.27 0 .019 r
.7432 .41429 m .74492 .41552 L .74579 .41392 L F
.7432 .41429 m .74228 .41646 L .74492 .41552 L F
.414 .088 .301 r
.59357 .50793 m .59412 .5058 L .59666 .50562 L F
.206 .275 .715 r
.25605 .5618 m .2581 .56366 L .25685 .56483 L F
.194 .087 .497 r
.25843 .56561 m .25685 .56483 L .2581 .56366 L F
.25843 .56561 m .25681 .56778 L .25685 .56483 L F
.328 .029 .296 r
.35956 .6256 m .36083 .62556 L .36173 .62271 L F
.313 .016 .29 r
.36173 .62271 m .36294 .62423 L .36261 .62262 L F
.36173 .62271 m .36083 .62556 L .36294 .62423 L F
.463 .463 .773 r
.56025 .62248 m .55861 .62475 L .55894 .62234 L F
.56025 .62248 m .56132 .626 L .55861 .62475 L F
.421 .715 .985 r
.39782 .62882 m .39716 .63034 L .39565 .62896 L F
.39782 .62882 m .39907 .6302 L .39716 .63034 L F
.603 .583 .804 r
.45903 .56671 m .45791 .57087 L .45653 .56762 L F
.45903 .56671 m .46155 .57259 L .45791 .57087 L F
0 .307 .788 r
.24291 .54544 m .24419 .54611 L .24398 .54684 L F
.035 .494 .883 r
.24419 .54611 m .24575 .54733 L .24398 .54684 L F
.307 0 0 r
.72038 .44211 m .71827 .44122 L .71719 .44286 L F
.72038 .44211 m .72112 .44117 L .71827 .44122 L F
.474 .437 .736 r
.46294 .57934 m .46412 .5756 L .46189 .57613 L F
.46294 .57934 m .46468 .57917 L .46412 .5756 L F
.981 .699 .323 r
.52156 .52861 m .52258 .52954 L .52272 .53204 L F
.86 .94 .872 r
.52501 .52663 m .52258 .52954 L .52156 .52861 L F
.981 .699 .323 r
.52156 .52861 m .52258 .52954 L .52272 .53204 L F
.646 .546 .727 r
.52501 .52663 m .52457 .52915 L .52258 .52954 L F
.574 .699 .926 r
.69471 .40341 m .69123 .40221 L .69378 .40148 L F
.601 .689 .904 r
.69625 .40084 m .69471 .40341 L .69378 .40148 L F
.69625 .40084 m .6972 .40276 L .69471 .40341 L F
.511 .25 .455 r
.5564 .52959 m .55869 .53125 L .55616 .53161 L F
.5564 .52959 m .55886 .52911 L .55869 .53125 L F
.525 .221 .394 r
.5564 .52959 m .5533 .53192 L .55212 .52978 L F
.5564 .52959 m .55616 .53161 L .5533 .53192 L F
.629 .35 .476 r
.57927 .62524 m .57701 .62394 L .5794 .62417 L F
.57927 .62524 m .57573 .62344 L .57701 .62394 L F
.674 .475 .608 r
.55212 .52978 m .5533 .53192 L .55033 .53217 L F
.88 .991 .75 r
.64326 .41128 m .64373 .41192 L .64181 .41454 L F
0 .104 .606 r
.6461 .41391 m .64373 .41192 L .64326 .41128 L F
.251 .296 .714 r
.5142 .70025 m .51639 .7028 L .51588 .69933 L F
.273 .221 .615 r
.25757 .57347 m .25806 .57595 L .25666 .57651 L F
.23 .115 .509 r
.25806 .57595 m .25803 .57848 L .25666 .57651 L F
.168 .098 .527 r
.25666 .57651 m .25803 .57848 L .25688 .57919 L F
.535 .186 .322 r
.39433 .6033 m .39638 .60472 L .39468 .60461 L F
.891 .704 .643 r
.21744 .56787 m .21399 .56898 L .2163 .56711 L F
.21744 .56787 m .21697 .57058 L .21399 .56898 L F
.897 .956 .829 r
.21744 .56787 m .2163 .56711 L .21839 .5645 L F
.521 .362 .606 r
.4988 .71794 m .49643 .71872 L .49852 .71525 L F
.405 .109 .346 r
.49839 .7199 m .49643 .71872 L .4988 .71794 L F
.369 0 0 r
.49524 .71843 m .49643 .71872 L .49362 .71769 L F
.49524 .71843 m .49643 .71872 L .49362 .71769 L F
.92 .975 .762 r
.49852 .71525 m .49643 .71872 L .49524 .71843 L F
.433 0 0 r
.49524 .71843 m .49643 .71872 L .49839 .7199 L F
.468 .239 .483 r
.40314 .5997 m .40011 .603 L .40082 .59942 L F
.626 .459 .637 r
.75209 .4263 m .75226 .42906 L .74952 .42932 L F
0 .235 .65 r
.75226 .42906 m .74868 .42689 L .74952 .42932 L F
.986 .708 .387 r
.74952 .42932 m .75145 .42851 L .75226 .42906 L F
.74952 .42932 m .74978 .43187 L .74846 .43012 L F
.487 .256 .489 r
.75226 .42906 m .74978 .43187 L .74952 .42932 L F
0 .235 .65 r
.75222 .42904 m .75145 .42851 L .74868 .42689 L F
.75226 .42906 m .75145 .42851 L .75222 .42904 L F
.936 .967 .728 r
.75145 .42851 m .74987 .42874 L .75055 .42788 L F
.959 .946 .685 r
.75226 .42906 m .75209 .4263 L .75503 .42841 L F
.602 .442 .637 r
.75503 .42841 m .75226 .42906 L .75209 .4263 L F
.959 .946 .685 r
.75226 .42906 m .75305 .42418 L .75209 .4263 L F
.432 .457 .786 r
.74771 .42579 m .75096 .42684 L .74903 .42305 L F
.942 .948 .624 r
.75158 .42634 m .75145 .42851 L .75297 .4244 L F
.7526 .42484 m .75297 .4244 L .75305 .42418 L F
.75158 .42634 m .75297 .4244 L .7526 .42484 L F
.959 .946 .685 r
.75226 .42906 m .75145 .42851 L .75305 .42418 L F
.942 .948 .624 r
.75191 .42586 m .75305 .42418 L .75324 .42509 L F
.859 .618 .573 r
.74903 .42305 m .75094 .42646 L .75261 .42527 L F
.937 .842 .725 r
.75261 .42527 m .75235 .42561 L .75208 .42565 L F
.75235 .42561 m .75098 .42733 L .75093 .42642 L F
.859 .618 .573 r
.75094 .42646 m .75119 .42691 L .75261 .42527 L F
.937 .842 .725 r
.75261 .42527 m .75208 .42565 L .7509 .42581 L F
.75235 .42561 m .75093 .42642 L .7509 .42581 L F
.119 .43 .872 r
.74868 .42689 m .75145 .42851 L .75116 .42712 L F
.75103 .42691 m .75116 .42712 L .75111 .42691 L F
.74868 .42689 m .75116 .42712 L .75103 .42691 L F
.74868 .42689 m .75103 .42691 L .74771 .42579 L F
.75103 .42691 m .75119 .42691 L .75096 .42684 L F
.75103 .42691 m .75096 .42684 L .74771 .42579 L F
.937 .842 .725 r
.75098 .42733 m .74987 .42874 L .75065 .42654 L F
.7508 .42669 m .75065 .42654 L .75071 .42636 L F
.75098 .42733 m .75065 .42654 L .7508 .42669 L F
.432 .457 .786 r
.75096 .42684 m .75094 .42646 L .74903 .42305 L F
.937 .842 .725 r
.75095 .42677 m .75071 .42636 L .7509 .42581 L F
.75098 .42733 m .75071 .42636 L .75095 .42677 L F
.936 .967 .728 r
.75145 .42851 m .75055 .42788 L .75116 .42712 L F
.75145 .42851 m .75116 .42712 L .75156 .4266 L F
.119 .43 .872 r
.75111 .42691 m .75145 .42851 L .75119 .42691 L F
.942 .948 .624 r
.75119 .42691 m .75145 .42851 L .75158 .42634 L F
.936 .967 .728 r
.75145 .42851 m .75156 .4266 L .75235 .42561 L F
.75257 .4254 m .75235 .42561 L .75261 .42527 L F
.75145 .42851 m .75235 .42561 L .75257 .4254 L F
.75145 .42851 m .75257 .4254 L .75373 .42749 L F
.942 .948 .624 r
.7526 .42546 m .75324 .42509 L .75373 .42749 L F
.936 .967 .728 r
.75257 .4254 m .75261 .42527 L .75373 .42749 L F
.942 .948 .624 r
.75191 .42586 m .7526 .42546 L .75373 .42749 L F
.75119 .42691 m .75158 .42634 L .75373 .42749 L F
.75158 .42634 m .75191 .42586 L .752 .42594 L F
.75158 .42634 m .752 .42594 L .75373 .42749 L F
.432 .457 .786 r
.75096 .42684 m .75119 .42691 L .75094 .42646 L F
.937 .842 .725 r
.7509 .42581 m .74987 .42874 L .74997 .42611 L F
.859 .618 .573 r
.74903 .42305 m .75237 .42512 L .74997 .42611 L F
.75237 .42512 m .75261 .42527 L .75211 .42543 L F
.75237 .42512 m .75211 .42543 L .74997 .42611 L F
.986 .708 .387 r
.74952 .42932 m .74846 .43012 L .75145 .42851 L F
.898 .927 .829 r
.59538 .46038 m .59408 .46445 L .59598 .46119 L F
.854 .843 .377 r
.22131 .56912 m .22178 .56905 L .22371 .56688 L F
.22131 .56912 m .22122 .57084 L .22178 .56905 L F
.336 .786 .954 r
.5597 .6205 m .55901 .62086 L .55641 .62036 L F
.359 .398 .766 r
.55109 .62928 m .55165 .62573 L .54923 .62633 L F
.55109 .62928 m .55269 .62912 L .55165 .62573 L F
.511 .488 .767 r
.49222 .62049 m .49281 .62303 L .49087 .62342 L F
.498 .109 .234 r
.49281 .62303 m .4902 .62519 L .49087 .62342 L F
.144 0 0 r
.38996 .58459 m .39154 .58469 L .39301 .58307 L F
.243 0 0 r
.39301 .58307 m .39377 .58418 L .39522 .58245 L F
.39301 .58307 m .39154 .58469 L .39377 .58418 L F
.319 .752 .97 r
.74569 .42703 m .74493 .42642 L .7422 .42653 L F
.523 .796 .995 r
.74868 .42689 m .74493 .42642 L .74569 .42703 L F
.906 .898 .808 r
.63574 .46507 m .63793 .46518 L .63685 .464 L F
.63574 .46507 m .63586 .46819 L .63793 .46518 L F
.858 .893 .86 r
.63685 .464 m .63793 .46518 L .64056 .46245 L F
.331 .138 .461 r
.24362 .60312 m .24336 .60565 L .24155 .6062 L F
.03 0 .19 r
.24336 .60565 m .24132 .60864 L .24155 .6062 L F
0 .101 .632 r
.61227 .42118 m .61193 .42187 L .6117 .41976 L F
0 .013 .551 r
.61325 .42029 m .61274 .42232 L .6117 .41976 L F
0 0 .041 r
.6117 .41976 m .60926 .42264 L .61267 .42015 L F
0 .013 .551 r
.61325 .42029 m .61288 .42017 L .61269 .42016 L F
.61288 .42017 m .6117 .41976 L .61267 .42015 L F
.61288 .42017 m .61267 .42015 L .61269 .42016 L F
0 0 .041 r
.6117 .41976 m .61267 .42015 L .6128 .42006 L F
.304 .269 .654 r
.61243 .4179 m .61302 .41962 L .61154 .41988 L F
0 .013 .551 r
.61268 .42016 m .6117 .41976 L .61154 .41988 L F
.61269 .42016 m .61269 .42016 L .61268 .42016 L F
.61269 .42016 m .6117 .41976 L .61268 .42016 L F
0 .512 .753 r
.61154 .41988 m .60886 .41929 L .60941 .41741 L F
.304 .269 .654 r
.61243 .4179 m .61154 .41988 L .60941 .41741 L F
0 .512 .753 r
.61154 .41988 m .6128 .42006 L .60886 .41929 L F
.893 .952 .835 r
.61256 .42014 m .60886 .41929 L .61275 .42005 L F
.60843 .42209 m .6088 .41964 L .61256 .42014 L F
.6088 .41964 m .60886 .41929 L .61256 .42014 L F
.61272 .4201 m .61275 .42005 L .6128 .42006 L F
.60843 .42209 m .61275 .42005 L .61272 .4201 L F
.304 .269 .654 r
.61302 .41962 m .61308 .4198 L .6129 .41981 L F
.61302 .41962 m .6129 .41981 L .61154 .41988 L F
.627 .937 .961 r
.61267 .42015 m .61266 .42015 L .6128 .42006 L F
.61266 .42015 m .61272 .4201 L .6128 .42006 L F
.304 .269 .654 r
.61308 .4198 m .61325 .42029 L .61265 .42015 L F
0 0 .041 r
.6117 .41976 m .6128 .42006 L .61154 .41988 L F
.304 .269 .654 r
.61308 .4198 m .61265 .42015 L .61154 .41988 L F
.627 .937 .961 r
.61266 .42015 m .61264 .42013 L .61272 .4201 L F
.61262 .42019 m .61263 .42015 L .61267 .42015 L F
.61263 .42015 m .61264 .42013 L .61267 .42015 L F
.60926 .42264 m .60843 .42209 L .61264 .42013 L F
.60926 .42264 m .61264 .42013 L .61262 .42019 L F
0 .101 .632 r
.61274 .42232 m .61202 .42192 L .61227 .42118 L F
.61202 .42192 m .61193 .42187 L .61227 .42118 L F
0 0 .244 r
.61325 .42029 m .61265 .42196 L .61274 .42232 L F
0 .101 .632 r
.61274 .42232 m .61286 .42286 L .61193 .42187 L F
0 0 .244 r
.61265 .42196 m .61176 .42444 L .61274 .42232 L F
0 .101 .632 r
.61274 .42232 m .6137 .42375 L .61286 .42286 L F
.432 .178 .426 r
.47469 .57913 m .47193 .58182 L .47225 .57974 L F
.402 .165 .437 r
.36472 .59414 m .36642 .59596 L .36731 .59383 L F
.36472 .59414 m .36431 .59664 L .36642 .59596 L F
.891 .949 .837 r
.68113 .46668 m .68387 .46488 L .68258 .46659 L F
.888 .911 .508 r
.68387 .46314 m .68387 .46488 L .68258 .46659 L F
.926 .69 .563 r
.22964 .56418 m .22956 .56725 L .22908 .56443 L F
.866 .544 .44 r
.22964 .56418 m .22908 .56443 L .22977 .56419 L F
.569 .168 .242 r
.47559 .624 m .47387 .6257 L .47769 .62549 L F
.547 .188 .31 r
.47559 .624 m .47769 .62549 L .47824 .62399 L F
.428 .218 .49 r
.24741 .59902 m .24554 .59736 L .2474 .59664 L F
.24741 .59902 m .2452 .59977 L .24554 .59736 L F
.438 .596 .91 r
.22119 .55533 m .22162 .55317 L .21892 .55431 L F
.22119 .55533 m .22314 .55526 L .22162 .55317 L F
.285 0 0 r
.45705 .63389 m .46102 .6317 L .45917 .63133 L F
.872 .917 .855 r
.68703 .45759 m .68813 .4585 L .68554 .46128 L F
.68703 .45759 m .68554 .46128 L .68744 .46 L F
0 0 0 r
.68744 .46 m .68554 .46128 L .68387 .46314 L F
.582 .428 .638 r
.54422 .54433 m .54431 .54678 L .54185 .54729 L F
.501 .298 .536 r
.54431 .54678 m .54183 .54991 L .54185 .54729 L F
.832 .616 .611 r
.55212 .67419 m .55159 .67677 L .55478 .67699 L F
.676 .499 .639 r
.53634 .56486 m .5339 .56767 L .53386 .56513 L F
.679 .662 .826 r
.72697 .40845 m .72773 .4121 L .7239 .41137 L F
.768 .752 .838 r
.72894 .40796 m .72773 .4121 L .72697 .40845 L F
.595 .678 .899 r
.61078 .43291 m .60948 .4352 L .61031 .43249 L F
.61078 .43291 m .6119 .43456 L .60948 .4352 L F
.952 .918 .74 r
.61078 .43291 m .60948 .4352 L .6119 .43456 L F
.61078 .43291 m .60951 .43761 L .60948 .4352 L F
0 0 0 r
.72193 .45278 m .72087 .45292 L .72319 .45199 L F
.72193 .45278 m .71992 .45415 L .72087 .45292 L F
.606 .358 .515 r
.22619 .565 m .22567 .56766 L .22371 .56688 L F
.701 .448 .538 r
.22956 .56725 m .22619 .565 L .22908 .56443 L F
.22956 .56725 m .22567 .56766 L .22619 .565 L F
0 0 0 r
.17508 .55773 m .17114 .5587 L .17257 .5583 L F
.6 .708 .92 r
.56357 .6254 m .56228 .62758 L .56132 .626 L F
.56357 .6254 m .56515 .62721 L .56228 .62758 L F
.405 .2 .486 r
.21028 .61814 m .21185 .61989 L .21218 .61739 L F
.21028 .61814 m .20993 .62051 L .21185 .61989 L F
.676 .921 .973 r
.43172 .56686 m .43009 .56634 L .4334 .56489 L F
.67 .797 .943 r
.68949 .45606 m .68813 .4585 L .68703 .45759 L F
.68949 .45606 m .69069 .45739 L .68813 .4585 L F
.606 .914 .979 r
.64951 .43641 m .65358 .43448 L .65186 .43687 L F
.54 .451 .703 r
.35865 .60904 m .36113 .6085 L .36039 .60575 L F
.472 .364 .65 r
.35916 .61223 m .36113 .6085 L .35865 .60904 L F
.508 .268 .485 r
.44491 .5817 m .44762 .57885 L .44319 .57882 L F
.44491 .5817 m .44704 .58193 L .44762 .57885 L F
.478 .241 .476 r
.44762 .57885 m .44935 .58133 L .44957 .57872 L F
.41 .28 .592 r
.25771 .5567 m .25605 .5618 L .25637 .56137 L F
.494 .069 .16 r
.43587 .63846 m .43441 .64043 L .43199 .64045 L F
.546 .124 .193 r
.43793 .63996 m .43587 .63846 L .43826 .63867 L F
.43793 .63996 m .43441 .64043 L .43587 .63846 L F
.671 .746 .906 r
.62398 .4331 m .62442 .43427 L .62156 .43504 L F
0 0 0 r
.62398 .4331 m .62156 .43504 L .62325 .43411 L F
.403 .854 .895 r
.62325 .43411 m .62442 .43427 L .62156 .43504 L F
.93 .666 .185 r
.65432 .43624 m .65484 .43535 L .65355 .43427 L F
.65432 .43624 m .65507 .43734 L .65484 .43535 L F
.595 .602 .829 r
.71681 .42035 m .71812 .41626 L .71554 .41702 L F
.71681 .42035 m .7193 .41971 L .71812 .41626 L F
.595 .403 .592 r
.54003 .55304 m .54003 .55538 L .53744 .55592 L F
.553 .416 .649 r
.5422 .55243 m .54003 .55538 L .54003 .55304 L F
.575 .304 .468 r
.36731 .59383 m .36981 .59373 L .37024 .59157 L F
.513 .275 .492 r
.36981 .59373 m .37239 .591 L .37024 .59157 L F
.549 .004 0 r
.54617 .681 m .5451 .68173 L .54294 .68063 L F
.552 .776 .982 r
.54617 .681 m .5475 .67911 L .5451 .68173 L F
.54617 .681 m .5487 .68037 L .5475 .67911 L F
.88 .991 .75 r
.64326 .41128 m .64181 .41454 L .64206 .41274 L F
0 0 .244 r
.64206 .41274 m .64181 .41454 L .64219 .41654 L F
.905 .903 .812 r
.54204 .50101 m .54438 .5004 L .54339 .50194 L F
.918 .876 .779 r
.54339 .50194 m .53986 .50444 L .54204 .50101 L F
.54339 .50194 m .54114 .50552 L .53986 .50444 L F
.043 0 .281 r
.21326 .58858 m .21411 .5895 L .21414 .58723 L F
.21326 .58858 m .2126 .59099 L .21411 .5895 L F
.528 .605 .874 r
.35961 .62778 m .36083 .62556 L .35956 .6256 L F
.35961 .62778 m .36152 .6278 L .36083 .62556 L F
.197 0 .227 r
.73088 .44602 m .72837 .44878 L .72852 .44691 L F
.549 .74 .965 r
.75078 .42117 m .74707 .41989 L .74945 .41911 L F
.062 .433 .873 r
.75315 .42211 m .75078 .42117 L .74945 .41911 L F
.798 .758 .816 r
.63872 .46069 m .64189 .46089 L .64121 .45779 L F
.807 .736 .785 r
.63872 .46069 m .64056 .46245 L .64189 .46089 L F
.735 .368 .356 r
.73809 .41464 m .73985 .41645 L .74085 .41507 L F
.43 .292 .591 r
.61912 .45246 m .61693 .45605 L .61933 .4551 L F
.599 .186 .23 r
.69566 .46455 m .69217 .46499 L .69355 .46443 L F
.375 .824 .939 r
.19878 .54104 m .20093 .54057 L .20276 .54078 L F
.094 .571 .906 r
.20298 .54016 m .20276 .54078 L .20093 .54057 L F
.20298 .54016 m .20471 .54119 L .20276 .54078 L F
.845 .865 .857 r
.63186 .46993 m .63586 .46819 L .63393 .46848 L F
.916 .903 .797 r
.63574 .46507 m .63393 .46848 L .63586 .46819 L F
.543 .06 .058 r
.43108 .57582 m .43053 .57676 L .42767 .57621 L F
0 0 0 r
.43227 .57514 m .43108 .57582 L .43313 .57323 L F
.43227 .57514 m .43053 .57676 L .43108 .57582 L F
.491 0 0 r
.62049 .41483 m .61657 .4137 L .61775 .41462 L F
.665 .515 .671 r
.62049 .41483 m .61769 .4173 L .61775 .41462 L F
.62 .809 .973 r
.66734 .40387 m .66992 .40392 L .66937 .40311 L F
0 .175 .699 r
.66992 .40392 m .6712 .4038 L .66937 .40311 L F
.66992 .40392 m .67122 .4062 L .6712 .4038 L F
.508 .31 .547 r
.5807 .51481 m .58082 .51743 L .57836 .51802 L F
.523 .294 .51 r
.5807 .51481 m .58317 .5166 L .58082 .51743 L F
.5807 .51481 m .58312 .51443 L .58317 .5166 L F
.858 .893 .86 r
.63685 .464 m .64056 .46245 L .63872 .46069 L F
.996 .864 .559 r
.64185 .42598 m .64206 .4293 L .64099 .42821 L F
.574 .618 .858 r
.70842 .41337 m .7101 .4168 L .71231 .41615 L F
.583 .655 .886 r
.7101 .4168 m .71302 .41763 L .71231 .41615 L F
.659 .591 .768 r
.19692 .67361 m .19776 .67661 L .1953 .67696 L F
0 .55 .721 r
.21125 .5528 m .20947 .55265 L .20735 .55252 L F
0 .175 .7 r
.19585 .68249 m .19777 .68456 L .19723 .6858 L F
.092 0 .404 r
.19777 .68456 m .19622 .68795 L .19723 .6858 L F
.775 .681 .76 r
.64961 .4523 m .65317 .45278 L .65199 .44932 L F
.742 .665 .774 r
.65199 .44932 m .65317 .45278 L .6559 .44994 L F
.354 .828 .811 r
.68616 .46662 m .68996 .46564 L .68855 .46522 L F
0 0 0 r
.68996 .46564 m .69116 .4654 L .68855 .46522 L F
.68996 .46564 m .69217 .46499 L .69116 .4654 L F
.81 .97 .904 r
.60741 .42426 m .60467 .42656 L .60544 .42427 L F
.838 .993 .851 r
.60467 .42656 m .60263 .42702 L .60544 .42427 L F
.955 .784 .631 r
.65493 .44653 m .6559 .44994 L .65618 .44713 L F
.89 .9 .829 r
.54532 .49656 m .54438 .5004 L .5433 .49949 L F
.54532 .49656 m .5466 .4975 L .54438 .5004 L F
.894 .923 .833 r
.54204 .50101 m .5433 .49949 L .54438 .5004 L F
.915 .662 .542 r
.54694 .65902 m .54687 .66162 L .54874 .66218 L F
.926 .559 .303 r
.54687 .66162 m .54892 .66452 L .54874 .66218 L F
.741 .666 .776 r
.18908 .55413 m .1928 .55543 L .19141 .55405 L F
.18908 .55413 m .1907 .55591 L .1928 .55543 L F
.735 .503 .577 r
.1907 .55591 m .19245 .55791 L .1928 .55543 L F
.826 .868 .877 r
.19141 .55405 m .1928 .55543 L .19535 .55273 L F
.726 .987 .884 r
.42351 .57038 m .42478 .56846 L .42686 .56884 L F
.42351 .57038 m .42283 .57014 L .42478 .56846 L F
.324 .767 .963 r
.19163 .66988 m .19411 .6701 L .19345 .66863 L F
.19213 .66992 m .19396 .66972 L .19541 .67022 L F
.19163 .66988 m .19396 .66972 L .19213 .66992 L F
.19411 .6701 m .19541 .67022 L .19467 .66963 L F
.581 .884 .992 r
.19541 .67022 m .19396 .66972 L .19595 .66884 L F
.815 .528 .504 r
.19396 .66972 m .19512 .67188 L .19576 .66952 L F
.19396 .66972 m .19576 .66952 L .19595 .66884 L F
.546 0 0 r
.19316 .67192 m .19396 .66972 L .19163 .66988 L F
.19316 .67192 m .19223 .67215 L .19306 .67098 L F
.19369 .67045 m .19306 .67098 L .19396 .66972 L F
.19316 .67192 m .19306 .67098 L .19369 .67045 L F
.324 .767 .963 r
.19411 .6701 m .19467 .66963 L .19345 .66863 L F
0 .42 .856 r
.68523 .41794 m .68792 .41908 L .68879 .42028 L F
.539 .064 .078 r
.68546 .4188 m .68792 .41908 L .68523 .41794 L F
.54 .926 .838 r
.4444 .57206 m .44591 .57174 L .44818 .57051 L F
0 .37 .821 r
.25721 .55185 m .25742 .5528 L .25543 .55056 L F
.25721 .55185 m .25827 .55295 L .25742 .5528 L F
.52 .515 .79 r
.65597 .4393 m .65649 .44082 L .65507 .43734 L F
.959 .79 .63 r
.65459 .44137 m .65649 .44082 L .65597 .4393 L F
.65459 .44137 m .65631 .44358 L .65649 .44082 L F
.694 .69 .842 r
.72697 .40845 m .7239 .41137 L .7229 .40801 L F
0 0 0 r
.47669 .63116 m .4756 .63182 L .47419 .632 L F
.4756 .63182 m .47358 .63275 L .47419 .632 L F
.752 .758 .857 r
.68546 .4188 m .68879 .42028 L .68792 .41908 L F
.432 .812 .991 r
.67579 .39905 m .6753 .4005 L .67415 .39978 L F
.67579 .39905 m .67784 .40008 L .6753 .4005 L F
.428 .123 .343 r
.57836 .51802 m .58038 .51923 L .57796 .5198 L F
.57836 .51802 m .58082 .51743 L .58038 .51923 L F
.467 .8 .999 r
.20471 .54119 m .20681 .54079 L .20864 .54179 L F
.4 .767 .993 r
.20681 .54079 m .2109 .54163 L .20864 .54179 L F
.44 .581 .897 r
.53083 .70183 m .53231 .70314 L .52977 .70347 L F
.351 .461 .832 r
.52977 .70347 m .53222 .70521 L .53083 .70183 L F
.658 .428 .559 r
.52977 .70347 m .52972 .70614 L .53222 .70521 L F
0 0 0 r
.22022 .59436 m .21769 .59667 L .21688 .59699 L F
.865 .977 .674 r
.22013 .59261 m .22022 .59436 L .22154 .59605 L F
.22013 .59261 m .21769 .59667 L .22022 .59436 L F
.051 .039 .521 r
.22052 .597 m .22154 .59605 L .22022 .59436 L F
.505 .341 .593 r
.60441 .47054 m .60756 .4724 L .60745 .46995 L F
.60441 .47054 m .60457 .47331 L .60756 .4724 L F
0 .13 .676 r
.66145 .42436 m .66281 .42604 L .66079 .42299 L F
.252 0 .236 r
.48407 .62098 m .48344 .62289 L .48603 .62022 L F
.553 .401 .629 r
.55033 .53217 m .55048 .53469 L .54826 .53506 L F
.484 .358 .633 r
.55048 .53469 m .5486 .53785 L .54826 .53506 L F
.86 .929 .87 r
.5466 .4975 m .54692 .49493 L .54787 .49601 L F
.831 .907 .89 r
.54532 .49656 m .54692 .49493 L .5466 .4975 L F
.356 .155 .464 r
.2026 .62928 m .20474 .62622 L .20274 .62679 L F
.469 .394 .69 r
.54232 .55835 m .53744 .55592 L .54003 .55538 L F
.54232 .55835 m .53906 .55947 L .53744 .55592 L F
.675 .965 .932 r
.69575 .45568 m .697 .4561 L .694 .45757 L F
.509 .899 .947 r
.6993 .45518 m .697 .4561 L .69575 .45568 L F
.374 .249 .579 r
.59821 .48246 m .60034 .48389 L .60063 .48177 L F
.59821 .48246 m .59853 .48486 L .60034 .48389 L F
.506 0 0 r
.40913 .63304 m .41127 .63408 L .41286 .63295 L F
.433 0 0 r
.41127 .63408 m .41546 .6327 L .41286 .63295 L F
.676 .499 .639 r
.53634 .56486 m .5367 .56774 L .5339 .56767 L F
.519 .387 .64 r
.53885 .56703 m .53634 .56486 L .53871 .56432 L F
.53885 .56703 m .5367 .56774 L .53634 .56486 L F
.497 .731 .977 r
.69378 .41426 m .69743 .41522 L .69603 .4135 L F
.671 .639 .809 r
.69743 .41522 m .69983 .4142 L .69603 .4135 L F
.122 .624 .903 r
.58864 .62447 m .58766 .62386 L .58541 .62362 L F
.288 0 0 r
.40563 .64119 m .40404 .64255 L .40189 .64211 L F
.442 0 .02 r
.40804 .64096 m .40404 .64255 L .40563 .64119 L F
.939 .964 .692 r
.5358 .51068 m .5364 .51147 L .53453 .51463 L F
.881 .99 .803 r
.5388 .50846 m .5364 .51147 L .5358 .51068 L F
.675 .965 .932 r
.69575 .45568 m .694 .45757 L .69323 .45682 L F
.304 .631 .963 r
.68535 .40688 m .68652 .40826 L .68865 .40835 L F
.229 0 .035 r
.46753 .62967 m .46457 .63164 L .46677 .63132 L F
.41 .067 .27 r
.46995 .62924 m .46753 .62967 L .46677 .63132 L F
0 .1 .654 r
.54901 .66712 m .55095 .67032 L .55115 .66841 L F
.694 .661 .813 r
.61691 .45992 m .61836 .46188 L .61466 .46116 L F
.687 .659 .817 r
.61989 .46035 m .61836 .46188 L .61691 .45992 L F
.542 .377 .607 r
.50095 .71486 m .4988 .71794 L .49852 .71525 L F
.92 .975 .762 r
.49852 .71525 m .49524 .71843 L .49714 .71699 L F
.968 .691 .452 r
.49714 .71699 m .4988 .71794 L .49852 .71525 L F
.571 .359 .554 r
.5284 .6881 m .5281 .68591 L .5259 .68584 L F
.927 .858 .421 r
.67521 .43614 m .67469 .44047 L .67617 .43717 L F
.978 .819 .617 r
.63823 .45572 m .6388 .4584 L .63929 .45595 L F
.838 .962 .888 r
.63975 .45401 m .63823 .45572 L .63929 .45595 L F
.545 .373 .599 r
.6388 .4584 m .64121 .45779 L .63929 .45595 L F
.24 0 0 r
.38694 .586 m .38859 .58632 L .38996 .58459 L F
.147 0 0 r
.38996 .58459 m .38859 .58632 L .39154 .58469 L F
.678 .397 .49 r
.59297 .48989 m .59329 .48816 L .58978 .48915 L F
.417 .162 .418 r
.59538 .48936 m .59329 .48816 L .59297 .48989 L F
.485 .092 .22 r
.59538 .48936 m .59601 .48795 L .59329 .48816 L F
.07 0 0 r
.4368 .63259 m .43933 .63256 L .44064 .63239 L F
.449 0 0 r
.43933 .63256 m .44325 .63469 L .44064 .63239 L F
.118 .252 .728 r
.57466 .62884 m .57638 .63155 L .57549 .63302 L F
0 .239 .68 r
.57635 .63337 m .57549 .63302 L .57638 .63155 L F
.427 .145 .381 r
.5314 .57062 m .53134 .57296 L .52879 .5737 L F
.488 .298 .548 r
.5339 .56767 m .53376 .57013 L .5314 .57062 L F
.578 .263 .399 r
.53435 .57254 m .5314 .57062 L .53376 .57013 L F
.53435 .57254 m .53134 .57296 L .5314 .57062 L F
.662 .756 .92 r
.75559 .40577 m .75431 .40812 L .75435 .40743 L F
.882 .788 .752 r
.75445 .40313 m .75559 .40577 L .75435 .40743 L F
0 .299 .793 r
.75435 .40743 m .75502 .40711 L .75439 .40678 L F
.882 .788 .752 r
.75445 .40313 m .75435 .40743 L .75297 .40605 L F
0 .299 .793 r
.75435 .40743 m .75439 .40678 L .75297 .40605 L F
.662 .756 .92 r
.75431 .40812 m .75409 .40853 L .75435 .40743 L F
.75559 .40577 m .7568 .40761 L .75409 .40853 L F
.445 .129 .335 r
.7568 .40761 m .75692 .40929 L .75409 .40853 L F
0 .478 .844 r
.75409 .40853 m .75601 .40871 L .75435 .40743 L F
.75409 .40853 m .75692 .40929 L .75601 .40871 L F
.89 .742 .236 r
.6714 .44479 m .67196 .44378 L .67142 .44228 L F
.6714 .44479 m .6717 .44623 L .67196 .44378 L F
.555 .823 .996 r
.67379 .44185 m .67196 .44378 L .67469 .44047 L F
.67379 .44185 m .67142 .44228 L .67196 .44378 L F
.613 .413 .588 r
.56433 .52367 m .5645 .52582 L .56112 .52668 L F
.608 .43 .615 r
.56685 .52328 m .5645 .52582 L .56433 .52367 L F
.621 .445 .623 r
.22551 .58145 m .22774 .57886 L .22628 .57969 L F
.532 .309 .522 r
.58846 .5087 m .58874 .51079 L .58616 .51097 L F
.58 .385 .582 r
.59119 .50778 m .58874 .51079 L .58846 .5087 L F
.129 0 0 r
.43102 .63273 m .43331 .63242 L .43475 .63186 L F
.616 .141 .104 r
.43475 .63186 m .43331 .63242 L .4368 .63259 L F
.417 .587 .912 r
.38382 .63799 m .38296 .63429 L .38113 .6346 L F
.38382 .63799 m .38557 .63735 L .38296 .63429 L F
.881 .99 .803 r
.5388 .50846 m .5358 .51068 L .538 .50758 L F
.939 .958 .751 r
.5388 .50846 m .53986 .50444 L .54114 .50552 L F
.5388 .50846 m .538 .50758 L .53986 .50444 L F
.866 .833 .812 r
.67253 .45812 m .67495 .45581 L .67321 .45413 L F
.755 .426 .428 r
.4214 .63029 m .42114 .63196 L .42477 .63226 L F
.879 .861 .818 r
.55358 .48832 m .5499 .49011 L .55224 .48714 L F
.55358 .48832 m .5513 .49134 L .5499 .49011 L F
.869 .873 .837 r
.55598 .4854 m .55358 .48832 L .55224 .48714 L F
.496 .842 .996 r
.68576 .41019 m .68406 .41147 L .68305 .41073 L F
.084 0 0 r
.69566 .46455 m .69368 .46493 L .69217 .46499 L F
.464 .89 .877 r
.69747 .46335 m .69566 .46455 L .69825 .46404 L F
.69747 .46335 m .69368 .46493 L .69566 .46455 L F
.587 .785 .974 r
.19202 .66433 m .19507 .66479 L .19197 .66309 L F
.272 .677 .969 r
.19507 .66479 m .19772 .6641 L .19197 .66309 L F
.601 .638 .86 r
.21999 .57963 m .21631 .57723 L .21877 .57588 L F
.28 .353 .76 r
.21972 .57641 m .21999 .57963 L .21877 .57588 L F
0 .113 .653 r
.22015 .57914 m .21999 .57963 L .21972 .57641 L F
.22015 .57914 m .22195 .58151 L .21999 .57963 L F
.472 .364 .65 r
.35916 .61223 m .36118 .61167 L .36113 .6085 L F
.493 .433 .718 r
.35916 .61223 m .36183 .61411 L .36118 .61167 L F
.837 .554 .51 r
.67028 .43149 m .67364 .43429 L .67276 .43372 L F
0 .25 .714 r
.39907 .6302 m .40144 .63167 L .40105 .63177 L F
0 .269 .722 r
.40144 .63167 m .40311 .63308 L .40105 .63177 L F
.769 .462 .466 r
.5308 .67175 m .53183 .67386 L .52975 .67226 L F
.84 .608 .588 r
.52975 .67226 m .5308 .67175 L .52806 .67053 L F
.621 .735 .928 r
.6932 .4001 m .69123 .40221 L .69054 .40103 L F
.6932 .4001 m .69378 .40148 L .69123 .40221 L F
.886 .891 .829 r
.44365 .59128 m .44135 .59443 L .43982 .59354 L F
.562 .395 .612 r
.44365 .59128 m .4438 .59396 L .44135 .59443 L F
.077 .27 .757 r
.44135 .59443 m .44242 .59326 L .43982 .59354 L F
.525 .284 .492 r
.4438 .59396 m .44353 .59622 L .44135 .59443 L F
.077 .27 .757 r
.44135 .59443 m .44353 .59622 L .44242 .59326 L F
.987 .885 .549 r
.54996 .49272 m .5499 .49011 L .5513 .49134 L F
.229 0 .239 r
.70242 .45214 m .70441 .45192 L .70499 .4496 L F
.143 0 0 r
.70242 .45214 m .70107 .45371 L .70441 .45192 L F
.234 0 0 r
.18313 .55477 m .17996 .55624 L .18126 .55626 L F
.752 .706 .809 r
.73489 .40716 m .7361 .40924 L .73258 .40857 L F
.57 .017 0 r
.7361 .40924 m .73493 .40962 L .73258 .40857 L F
.588 .893 .989 r
.73809 .40968 m .73493 .40962 L .7361 .40924 L F
.735 .503 .577 r
.1907 .55591 m .19048 .55882 L .19245 .55791 L F
.376 .195 .504 r
.22902 .63104 m .2277 .62962 L .22933 .6289 L F
.22902 .63104 m .22749 .63199 L .2277 .62962 L F
.642 .918 .628 r
.56307 .47639 m .56043 .47915 L .56164 .47749 L F
.654 .938 .679 r
.56043 .47915 m .55867 .48033 L .56164 .47749 L F
.957 .809 .655 r
.65356 .44528 m .65631 .44358 L .65459 .44137 L F
.65356 .44528 m .65493 .44653 L .65631 .44358 L F
.472 .267 .52 r
.35973 .60002 m .36178 .59968 L .36203 .59724 L F
.459 .341 .631 r
.35973 .60002 m .3621 .60185 L .36178 .59968 L F
.35973 .60002 m .35983 .60342 L .3621 .60185 L F
.286 .631 .963 r
.2401 .54363 m .23988 .54494 L .23838 .54387 L F
.2401 .54363 m .24291 .54544 L .23988 .54494 L F
.756 .719 .817 r
.49978 .7237 m .50346 .72406 L .50249 .72092 L F
.633 .816 .971 r
.49978 .7237 m .50346 .72406 L .50302 .72281 L F
.749 .453 0 r
.50249 .72092 m .50346 .72406 L .50302 .72281 L F
.467 .299 .569 r
.46995 .62924 m .47195 .62605 L .47042 .62684 L F
.752 .701 .804 r
.57077 .62691 m .57181 .63001 L .5687 .62936 L F
.748 .342 .283 r
.5687 .62936 m .57181 .63001 L .57076 .62982 L F
.628 .58 .781 r
.57077 .62691 m .57383 .62834 L .57181 .63001 L F
.529 .513 .782 r
.57383 .62834 m .57466 .62884 L .57181 .63001 L F
.512 .256 .463 r
.58616 .51097 m .58554 .5141 L .58312 .51443 L F
.534 .282 .48 r
.58874 .51079 m .58554 .5141 L .58616 .51097 L F
.377 .292 .632 r
.1872 .57078 m .18876 .56716 L .1881 .56824 L F
.209 0 0 r
.39747 .5819 m .39981 .58148 L .4015 .58014 L F
.337 0 0 r
.39981 .58148 m .40373 .57952 L .4015 .58014 L F
.579 .657 .89 r
.71231 .41615 m .71302 .41763 L .71554 .41702 L F
.459 .28 .55 r
.23835 .61608 m .23712 .61508 L .23874 .61445 L F
.23835 .61608 m .23685 .61706 L .23712 .61508 L F
.41 .28 .592 r
.25771 .5567 m .25759 .56253 L .25605 .5618 L F
.388 .296 .629 r
.25759 .56253 m .2581 .56366 L .25605 .5618 L F
.58 .224 .33 r
.4428 .63723 m .44771 .63373 L .44325 .63469 L F
.4428 .63723 m .44565 .63754 L .44771 .63373 L F
.133 0 .084 r
.44771 .63373 m .44749 .63654 L .4489 .63456 L F
.44771 .63373 m .44565 .63754 L .44749 .63654 L F
.934 .837 .725 r
.59113 .46665 m .59408 .46445 L .59305 .46342 L F
.59113 .46665 m .59236 .46778 L .59408 .46445 L F
.898 .927 .829 r
.59538 .46038 m .59305 .46342 L .59408 .46445 L F
.97 .733 .521 r
.51537 .56173 m .51408 .56115 L .51385 .55825 L F
.963 .749 .568 r
.51537 .56173 m .51364 .56351 L .51408 .56115 L F
.51537 .56173 m .51528 .56462 L .51364 .56351 L F
.25 .762 .837 r
.2109 .54163 m .21312 .5412 L .21463 .54119 L F
.329 .801 .918 r
.21312 .5412 m .21668 .54102 L .21463 .54119 L F
.177 0 0 r
.42389 .59173 m .42182 .59188 L .42559 .59086 L F
.198 .728 .799 r
.42789 .5913 m .42389 .59173 L .42559 .59086 L F
.197 0 .207 r
.60201 .49996 m .60462 .49724 L .60396 .49901 L F
.203 0 .209 r
.60396 .49901 m .60462 .49724 L .60662 .49614 L F
.636 .735 .92 r
.6658 .40182 m .66734 .40387 L .66937 .40311 L F
.833 .409 0 r
.65244 .42429 m .65258 .42337 L .65282 .42218 L F
.65244 .42429 m .65377 .42579 L .65258 .42337 L F
.125 0 0 r
.46496 .63544 m .46214 .63664 L .46259 .63601 L F
.578 .423 .635 r
.54614 .54131 m .54656 .54372 L .54422 .54433 L F
.496 .318 .57 r
.54656 .54372 m .54431 .54678 L .54422 .54433 L F
.825 .424 0 r
.37523 .62979 m .37574 .63139 L .37416 .62826 L F
.383 .633 .953 r
.37416 .62826 m .37523 .62979 L .37608 .62828 L F
.37416 .62826 m .37523 .62979 L .37608 .62828 L F
.646 .264 .307 r
.37523 .62979 m .3775 .63162 L .37574 .63139 L F
0 0 .266 r
.21579 .60302 m .2163 .60416 L .21797 .60257 L F
.21579 .60302 m .21569 .60582 L .2163 .60416 L F
.398 .176 .457 r
.5486 .53785 m .54835 .54015 L .54614 .54131 L F
.484 .358 .633 r
.55048 .53469 m .55094 .53721 L .5486 .53785 L F
.607 .444 .635 r
.55094 .53721 m .54835 .54015 L .5486 .53785 L F
.423 0 0 r
.63738 .42992 m .64089 .4303 L .63479 .42877 L F
.876 .905 .847 r
.64099 .42821 m .64089 .4303 L .63738 .42992 L F
.869 .873 .837 r
.55598 .4854 m .55224 .48714 L .55494 .48483 L F
.753 .959 .937 r
.55598 .4854 m .55494 .48483 L .5567 .48339 L F
0 0 0 r
.74797 .43482 m .7465 .43643 L .74466 .43735 L F
.456 .098 .268 r
.74968 .43394 m .7465 .43643 L .74797 .43482 L F
.684 .951 .955 r
.46989 .57339 m .46888 .57241 L .47077 .57314 L F
.178 0 0 r
.40395 .63272 m .40605 .63305 L .40538 .63284 L F
.40605 .63305 m .40764 .63331 L .40538 .63284 L F
.083 0 0 r
.40506 .63274 m .40538 .63284 L .40685 .63242 L F
.40311 .63308 m .40538 .63284 L .40506 .63274 L F
.247 0 0 r
.40538 .63284 m .40913 .63304 L .40685 .63242 L F
.931 .843 .736 r
.64226 .41899 m .64389 .42059 L .6424 .4228 L F
.377 .292 .632 r
.1872 .57078 m .18912 .57046 L .18876 .56716 L F
.513 .834 .999 r
.62341 .40216 m .62482 .40068 L .62737 .40184 L F
.58 .936 .931 r
.62341 .40216 m .62259 .4018 L .62482 .40068 L F
.57 .195 .291 r
.73151 .41976 m .73375 .42154 L .73558 .41884 L F
.507 .384 .648 r
.73558 .41884 m .73724 .41947 L .73748 .41727 L F
.864 .734 .718 r
.73375 .42154 m .73724 .41947 L .73558 .41884 L F
.507 .384 .648 r
.73558 .41884 m .73724 .41947 L .73748 .41727 L F
.611 .337 .477 r
.20824 .61104 m .21054 .61131 L .21123 .60925 L F
.447 .237 .501 r
.21054 .61131 m .21298 .60835 L .21123 .60925 L F
.65 .697 .88 r
.70947 .40415 m .71061 .40615 L .70698 .40502 L F
.646 .699 .885 r
.71207 .40331 m .71061 .40615 L .70947 .40415 L F
.71207 .40331 m .71299 .40522 L .71061 .40615 L F
.562 .59 .84 r
.46189 .57613 m .46412 .5756 L .46086 .57416 L F
.596 .541 .763 r
.3922 .62341 m .38942 .62061 L .39074 .62104 L F
.586 .072 0 r
.4374 .57282 m .43234 .57268 L .43313 .57323 L F
.4374 .57282 m .43576 .57413 L .43234 .57268 L F
.782 .953 .624 r
.43645 .57295 m .4374 .57282 L .43845 .57208 L F
.43645 .57295 m .43576 .57413 L .4374 .57282 L F
.313 .476 .861 r
.72652 .42319 m .72791 .42157 L .7261 .42127 L F
.388 .59 .924 r
.72652 .42319 m .72851 .42319 L .72791 .42157 L F
.811 .58 .589 r
.47077 .57314 m .47385 .57602 L .47362 .57361 L F
.412 .063 .261 r
.42955 .5803 m .42835 .58232 L .42655 .58257 L F
.506 .479 .761 r
.43203 .57736 m .43038 .57877 L .43053 .57676 L F
0 0 .026 r
.43053 .57676 m .43051 .57694 L .4305 .57727 L F
.43051 .57694 m .43038 .57877 L .4305 .57727 L F
.232 0 .332 r
.43203 .57736 m .43058 .58026 L .43038 .57877 L F
0 0 0 r
.43058 .58026 m .4305 .57727 L .43038 .57877 L F
.43058 .58026 m .43035 .58027 L .4305 .57727 L F
.43035 .58027 m .42955 .5803 L .4305 .57727 L F
.43058 .58026 m .42835 .58232 L .42955 .5803 L F
.575 .144 .186 r
.41775 .64149 m .41394 .64301 L .41393 .64162 L F
.41775 .64149 m .41627 .64337 L .41394 .64301 L F
.512 .141 .273 r
.42005 .64088 m .41627 .64337 L .41775 .64149 L F
.32 .129 .458 r
.24533 .60241 m .24336 .60565 L .24362 .60312 L F
.623 .365 .507 r
.23617 .85091 m .23539 .85328 L .23429 .85085 L F
.23429 .85085 m .23539 .85328 L .23617 .85091 L F
.233 0 .27 r
.60155 .50186 m .60201 .49996 L .60396 .49901 L F
.697 .246 .177 r
.44086 .58666 m .44464 .58722 L .44264 .58527 L F
.633 .421 .577 r
.72663 .43675 m .72933 .43712 L .72892 .43461 L F
.51 .338 .583 r
.72892 .43461 m .72933 .43712 L .73152 .43374 L F
.837 .764 .782 r
.21692 .57816 m .21478 .57577 L .21631 .57723 L F
.21692 .57816 m .21267 .57821 L .21478 .57577 L F
0 .097 .637 r
.21328 .58037 m .21692 .57816 L .21441 .58024 L F
.21328 .58037 m .21267 .57821 L .21692 .57816 L F
.43 .283 .579 r
.38946 .61202 m .38923 .61433 L .3874 .61424 L F
.071 .221 .714 r
.38965 .61665 m .3874 .61424 L .38923 .61433 L F
.708 .443 .522 r
.53473 .70243 m .53807 .70045 L .53516 .7012 L F
.53473 .70243 m .53837 .70314 L .53807 .70045 L F
.914 .681 .182 r
.67228 .45093 m .67271 .44969 L .6721 .44851 L F
.67228 .45093 m .67287 .45247 L .67271 .44969 L F
.735 .681 .798 r
.65199 .44932 m .6559 .44994 L .65493 .44653 L F
.515 .229 .418 r
.42344 .58308 m .42328 .58527 L .42055 .58529 L F
.595 .678 .899 r
.61078 .43291 m .61031 .43249 L .6103 .43178 L F
.507 .296 .528 r
.36203 .59724 m .36407 .59911 L .36431 .59664 L F
.36203 .59724 m .36178 .59968 L .36407 .59911 L F
.154 0 .211 r
.70499 .4496 m .7064 .45032 L .70743 .44931 L F
.70499 .4496 m .70441 .45192 L .7064 .45032 L F
.752 .593 .679 r
.52208 .56797 m .52187 .57047 L .52024 .56694 L F
.572 .173 .247 r
.44211 .63806 m .44043 .6402 L .43826 .63867 L F
.494 .021 .062 r
.44433 .63883 m .44043 .6402 L .44211 .63806 L F
.517 .093 .175 r
.40011 .603 m .39891 .60492 L .39638 .60472 L F
.468 .239 .483 r
.40314 .5997 m .4029 .60261 L .40011 .603 L F
.08 0 0 r
.40195 .60281 m .40011 .603 L .4029 .60261 L F
.40195 .60281 m .39891 .60492 L .40011 .603 L F
.565 .342 .536 r
.23238 .62732 m .22998 .62654 L .23168 .62557 L F
.23238 .62732 m .22933 .6289 L .22998 .62654 L F
.544 .366 .589 r
.3916 .60623 m .39042 .60972 L .38913 .60835 L F
.566 .405 .622 r
.39135 .61113 m .38913 .60835 L .39042 .60972 L F
.39135 .61113 m .38946 .61202 L .38913 .60835 L F
.859 .846 .829 r
.58633 .4728 m .58399 .47552 L .5869 .47587 L F
.878 .838 .802 r
.58302 .47739 m .5869 .47587 L .58399 .47552 L F
.58302 .47739 m .58474 .47898 L .5869 .47587 L F
.883 .858 .812 r
.58633 .4728 m .5869 .47587 L .58907 .47275 L F
.881 .509 .032 r
.65398 .43619 m .65597 .4393 L .65507 .43734 L F
.965 .764 .582 r
.65281 .44175 m .65597 .4393 L .65398 .43619 L F
.65281 .44175 m .65459 .44137 L .65597 .4393 L F
.575 .319 .49 r
.56112 .52668 m .56349 .52862 L .56126 .52878 L F
.56112 .52668 m .5645 .52582 L .56349 .52862 L F
.779 .508 .525 r
.40646 .60195 m .4029 .60261 L .40314 .5997 L F
.886 .891 .829 r
.44365 .59128 m .43982 .59354 L .44023 .59087 L F
.656 .526 .693 r
.44601 .5884 m .44678 .59158 L .44365 .59128 L F
.41 .279 .59 r
.44597 .59325 m .44365 .59128 L .44678 .59158 L F
.44597 .59325 m .4438 .59396 L .44365 .59128 L F
.539 .693 .939 r
.65869 .41084 m .65631 .41126 L .65807 .40913 L F
.7 .95 .955 r
.61565 .4591 m .61466 .46116 L .61268 .45918 L F
.61565 .4591 m .61691 .45992 L .61466 .46116 L F
.17 .678 .902 r
.4444 .57206 m .44097 .57157 L .44169 .57168 L F
.535 .924 .86 r
.67122 .4062 m .66727 .40774 L .66954 .40626 L F
.894 .963 .83 r
.6712 .4038 m .67122 .4062 L .66954 .40626 L F
.554 .389 .612 r
.5604 .63478 m .56293 .63444 L .56021 .63257 L F
.647 .768 .937 r
.55656 .63197 m .56021 .63257 L .55892 .63111 L F
.344 .622 .955 r
.55892 .63111 m .56021 .63257 L .56122 .63125 L F
.186 .393 .833 r
.56021 .63257 m .56293 .63444 L .56122 .63125 L F
.449 .044 .178 r
.4489 .63456 m .45128 .63438 L .45285 .63212 L F
.688 .312 .33 r
.45128 .63438 m .45574 .6356 L .45285 .63212 L F
.719 .594 .715 r
.52546 .57344 m .52297 .57371 L .52187 .57047 L F
.702 .495 .606 r
.52546 .57344 m .52332 .5763 L .52297 .57371 L F
.749 .562 .642 r
.52546 .57344 m .52574 .57602 L .52332 .5763 L F
.659 .51 .67 r
.52879 .5737 m .52574 .57602 L .52546 .57344 L F
.867 .989 .833 r
.54692 .49493 m .54996 .49272 L .54787 .49601 L F
.543 .854 .551 r
.224 .56645 m .22371 .56688 L .22567 .56766 L F
.224 .56645 m .22131 .56912 L .22371 .56688 L F
.87 .877 .839 r
.58787 .47103 m .58907 .47275 L .58998 .47097 L F
.58787 .47103 m .58633 .4728 L .58907 .47275 L F
.846 .738 .744 r
.72979 .41647 m .72811 .41639 L .73096 .41709 L F
.853 .66 .64 r
.72811 .41639 m .73151 .41976 L .73096 .41709 L F
.734 .781 .891 r
.72979 .41647 m .73096 .41709 L .73432 .41489 L F
.562 .699 .933 r
.73019 .42609 m .73368 .42701 L .73315 .42538 L F
.755 .728 .827 r
.18687 .64383 m .19001 .6442 L .18823 .64584 L F
.491 0 0 r
.62049 .41483 m .61887 .41487 L .61657 .4137 L F
.893 .982 .808 r
.62051 .41292 m .62049 .41483 L .62215 .41317 L F
.62051 .41292 m .61887 .41487 L .62049 .41483 L F
.616 .455 .642 r
.20608 .61169 m .21054 .61131 L .20824 .61104 L F
.20608 .61169 m .21054 .61131 L .20824 .61104 L F
.167 0 0 r
.40586 .57868 m .40813 .57821 L .40982 .57681 L F
.334 0 .016 r
.40813 .57821 m .41195 .57608 L .40982 .57681 L F
.524 .354 .592 r
.53789 .67112 m .54043 .67079 L .54014 .66786 L F
.54014 .66786 m .54043 .67079 L .53789 .67112 L F
.672 .681 .85 r
.72851 .42319 m .73019 .42609 L .73315 .42538 L F
.774 .682 .761 r
.72933 .43712 m .73277 .43789 L .73152 .43374 L F
.474 0 0 r
.72933 .43712 m .73156 .43805 L .73277 .43789 L F
.64 .604 .798 r
.73152 .43374 m .73277 .43789 L .73538 .43701 L F
.011 0 0 r
.73156 .43805 m .73538 .43701 L .73277 .43789 L F
.326 .29 .665 r
.5597 .6205 m .56025 .62248 L .55894 .62234 L F
.687 .282 .274 r
.41186 .64117 m .41022 .64303 L .40804 .64096 L F
.652 .239 .248 r
.41394 .64301 m .41186 .64117 L .41393 .64162 L F
.41394 .64301 m .41022 .64303 L .41186 .64117 L F
.59 .927 .96 r
.17082 .54335 m .17422 .54248 L .1719 .54281 L F
.484 .784 .997 r
.68361 .40012 m .68148 .40075 L .6804 .39966 L F
.213 .732 .859 r
.17664 .54173 m .17879 .54149 L .18069 .54171 L F
.217 0 0 r
.17879 .54149 m .18297 .54151 L .18069 .54171 L F
.652 .695 .877 r
.69983 .4142 m .70338 .41509 L .7023 .41342 L F
.67 .713 .88 r
.70338 .41509 m .70591 .41418 L .7023 .41342 L F
.938 .803 .344 r
.51318 .54234 m .51297 .53947 L .51574 .54134 L F
.51318 .54234 m .51271 .5433 L .51297 .53947 L F
.614 .605 .819 r
.71551 .40468 m .71409 .4085 L .71299 .40522 L F
.71551 .40468 m .71669 .40793 L .71409 .4085 L F
.516 .381 .635 r
.54898 .543 m .54614 .54131 L .54835 .54015 L F
.54898 .543 m .54656 .54372 L .54614 .54131 L F
.973 .92 .681 r
.61274 .42232 m .61262 .42542 L .6137 .42375 L F
.353 0 .061 r
.47769 .62549 m .48128 .62329 L .47824 .62399 L F
.47769 .62549 m .48026 .6252 L .48128 .62329 L F
.727 .304 .241 r
.48128 .62329 m .48026 .6252 L .48542 .62577 L F
.48543 .62573 m .48542 .62577 L .48553 .62579 L F
.48128 .62329 m .48542 .62577 L .48543 .62573 L F
.294 .288 .681 r
.48546 .62553 m .4861 .62278 L .48563 .62484 L F
.48548 .62539 m .4861 .62278 L .48546 .62553 L F
.48521 .62651 m .48543 .62564 L .48527 .62636 L F
.723 .701 .165 r
.48553 .62579 m .4861 .62278 L .48544 .62566 L F
.294 .288 .681 r
.48543 .62564 m .48593 .62366 L .48542 .62575 L F
.48543 .62564 m .48542 .62575 L .48527 .62636 L F
.54 0 0 r
.48026 .6252 m .48241 .62582 L .48542 .62579 L F
.48542 .62577 m .48542 .62579 L .48553 .62579 L F
.48026 .6252 m .48542 .62579 L .48542 .62577 L F
.723 .701 .165 r
.48544 .62566 m .4861 .62278 L .48344 .62289 L F
.294 .288 .681 r
.48563 .62484 m .4861 .62278 L .48593 .62366 L F
.48521 .62651 m .48548 .62539 L .48546 .62553 L F
.727 .304 .241 r
.48543 .62573 m .48553 .62579 L .48544 .62566 L F
.548 .824 .473 r
.48527 .62604 m .48545 .62586 L .48241 .62582 L F
.48545 .62586 m .48553 .62579 L .48542 .62579 L F
.48545 .62586 m .48542 .62579 L .48241 .62582 L F
.294 .288 .681 r
.48546 .62588 m .48593 .62366 L .48549 .62581 L F
.548 .824 .473 r
.48545 .62586 m .48549 .62581 L .48553 .62579 L F
.294 .288 .681 r
.48536 .62599 m .48541 .62578 L .48545 .62586 L F
.548 .824 .473 r
.48527 .62604 m .48549 .62581 L .48545 .62586 L F
.294 .288 .681 r
.48527 .62636 m .48536 .62599 L .48546 .62588 L F
.48536 .62599 m .48545 .62586 L .48546 .62588 L F
.48541 .62578 m .48593 .62366 L .48546 .62588 L F
.727 .304 .241 r
.48128 .62329 m .48543 .62573 L .48344 .62289 L F
.48543 .62573 m .48544 .62566 L .48344 .62289 L F
.777 .973 .918 r
.60741 .42426 m .60843 .42209 L .60926 .42264 L F
.60741 .42426 m .60544 .42427 L .60843 .42209 L F
.939 .816 .363 r
.64766 .44456 m .6469 .44612 L .64759 .44295 L F
.876 .839 .805 r
.58232 .4818 m .58474 .47898 L .58302 .47739 L F
.326 0 .014 r
.71235 .44503 m .71528 .44384 L .71276 .44451 L F
.406 .269 .58 r
.20012 .67326 m .19776 .67661 L .19692 .67361 L F
.20012 .67326 m .19963 .67616 L .19776 .67661 L F
.366 .302 .653 r
.19979 .67866 m .19776 .67661 L .19963 .67616 L F
.19979 .67866 m .19828 .67949 L .19776 .67661 L F
.481 .872 .969 r
.2158 .55263 m .21504 .55286 L .21549 .55368 L F
.21504 .55286 m .21357 .55331 L .21549 .55368 L F
.002 .489 .866 r
.21578 .55422 m .21549 .55368 L .21332 .55301 L F
.21698 .5548 m .21549 .55368 L .21578 .55422 L F
.355 .754 .984 r
.21892 .55431 m .21549 .55368 L .21698 .5548 L F
.664 .432 .559 r
.55033 .53217 m .5532 .53458 L .55048 .53469 L F
.55033 .53217 m .5533 .53192 L .5532 .53458 L F
.664 .781 .936 r
.22666 .55819 m .23066 .55877 L .22944 .55706 L F
.773 .631 .703 r
.22666 .55819 m .2284 .56128 L .23066 .55877 L F
.663 .464 .605 r
.2284 .56128 m .23053 .56145 L .23066 .55877 L F
.258 .555 .931 r
.23066 .55877 m .23095 .55722 L .22944 .55706 L F
.341 .643 .965 r
.23066 .55877 m .23187 .55828 L .23095 .55722 L F
.56 .377 .591 r
.23066 .55877 m .23307 .56098 L .23187 .55828 L F
.23066 .55877 m .23053 .56145 L .23307 .56098 L F
.322 .807 .872 r
.74004 .43126 m .74242 .43068 L .7437 .43078 L F
.065 0 0 r
.7437 .43078 m .74242 .43068 L .74607 .43098 L F
.506 .172 .335 r
.40646 .60195 m .40254 .60518 L .4029 .60261 L F
.40646 .60195 m .40497 .60494 L .40254 .60518 L F
.494 .321 .575 r
.40806 .59968 m .40819 .6026 L .40646 .60195 L F
.748 .44 .461 r
.40848 .60525 m .40646 .60195 L .40819 .6026 L F
.40848 .60525 m .40497 .60494 L .40646 .60195 L F
.783 .627 .688 r
.52187 .57047 m .52297 .57371 L .52019 .57331 L F
.855 .467 .31 r
.52332 .5763 m .52019 .57331 L .52297 .57371 L F
.443 .838 .98 r
.20177 .61116 m .20062 .61059 L .19833 .61117 L F
.19833 .61117 m .20062 .61059 L .20177 .61116 L F
.427 .867 .793 r
.70894 .45739 m .70539 .45871 L .70676 .45882 L F
.561 .798 .988 r
.68867 .39924 m .68789 .40141 L .68629 .39973 L F
.68867 .39924 m .69054 .40103 L .68789 .40141 L F
.466 .206 .434 r
.73624 .44265 m .73644 .44079 L .73876 .44196 L F
.521 .101 .185 r
.73644 .44079 m .7392 .44084 L .73876 .44196 L F
.269 .67 .969 r
.2539 .54949 m .25324 .55039 L .25181 .54888 L F
.2539 .54949 m .25543 .55056 L .25324 .55039 L F
.412 .17 .435 r
.25223 .58692 m .25148 .59032 L .24936 .5907 L F
.483 .246 .478 r
.25349 .58642 m .25148 .59032 L .25223 .58692 L F
.441 .119 .323 r
.5367 .56774 m .53376 .57013 L .5339 .56767 L F
.382 0 .073 r
.22051 .57115 m .22027 .57234 L .22005 .57235 L F
.21986 .57143 m .22005 .57235 L .21734 .57253 L F
.22051 .57115 m .22005 .57235 L .21986 .57143 L F
.487 .47 .764 r
.22027 .57234 m .22074 .57556 L .21877 .57588 L F
.699 .451 0 r
.22016 .57289 m .22046 .57434 L .22074 .57556 L F
.487 .47 .764 r
.22027 .57234 m .21877 .57588 L .21734 .57253 L F
.699 .451 0 r
.21989 .57163 m .22026 .57339 L .22016 .57289 L F
.22026 .57339 m .22046 .57434 L .22016 .57289 L F
.21989 .57163 m .22016 .57289 L .22027 .57234 L F
.22016 .57289 m .22074 .57556 L .22027 .57234 L F
.382 0 .073 r
.22122 .57084 m .22027 .57234 L .22051 .57115 L F
.955 .941 .626 r
.22131 .56912 m .22027 .57234 L .22122 .57084 L F
.287 .286 .683 r
.25906 .55497 m .25967 .55723 L .25771 .5567 L F
.318 .206 .565 r
.25959 .55864 m .25771 .5567 L .25967 .55723 L F
.25959 .55864 m .25759 .56253 L .25771 .5567 L F
.272 .323 .733 r
.73612 .41413 m .73985 .41645 L .73809 .41464 L F
.646 .929 .656 r
.56307 .47639 m .5643 .47474 L .56584 .47366 L F
.639 .917 .627 r
.56307 .47639 m .56164 .47749 L .5643 .47474 L F
.905 .696 .609 r
.54976 .67571 m .55212 .67419 L .55058 .67337 L F
.54976 .67571 m .55159 .67677 L .55212 .67419 L F
.78 .683 .757 r
.64854 .43637 m .64843 .43993 L .64642 .4412 L F
.596 .528 .749 r
.65186 .43687 m .64843 .43993 L .64854 .43637 L F
0 0 0 r
.43227 .57514 m .43313 .57323 L .43234 .57268 L F
.229 0 0 r
.39619 .64229 m .39432 .64262 L .3921 .64236 L F
.024 0 0 r
.39834 .64241 m .39432 .64262 L .39619 .64229 L F
.239 0 0 r
.38694 .586 m .38451 .5879 L .38859 .58632 L F
.353 .151 .462 r
.23326 .62467 m .23217 .62353 L .23391 .62231 L F
.23326 .62467 m .23168 .62557 L .23217 .62353 L F
.436 .851 .961 r
.18509 .54094 m .18892 .54072 L .18681 .5413 L F
.673 .627 .796 r
.55269 .62912 m .55428 .63303 L .55656 .63197 L F
.902 .497 .221 r
.21734 .57253 m .21399 .56898 L .21697 .57058 L F
0 0 .25 r
.627 .40676 m .62605 .40843 L .6269 .40507 L F
.84 .995 .842 r
.62627 .40769 m .62605 .40843 L .627 .40676 L F
.62627 .40769 m .62478 .41052 L .62605 .40843 L F
.232 .717 .929 r
.66666 .46108 m .6703 .46152 L .66963 .46104 L F
.799 .952 .613 r
.67131 .4592 m .6703 .46152 L .67253 .45812 L F
.827 .997 .845 r
.66963 .46104 m .6703 .46152 L .67131 .4592 L F
.728 .828 .927 r
.66211 .41086 m .65869 .41084 L .66146 .41043 L F
.643 .957 .933 r
.66474 .40936 m .66211 .41086 L .66146 .41043 L F
.487 .256 .489 r
.75226 .42906 m .75222 .43125 L .74978 .43187 L F
.959 .946 .685 r
.75226 .42906 m .75503 .42841 L .75373 .42749 L F
.574 .915 .968 r
.75226 .42906 m .75145 .42851 L .75373 .42749 L F
.554 .309 .498 r
.75503 .42841 m .75222 .43125 L .75226 .42906 L F
.943 .881 .744 r
.51567 .55561 m .51304 .55757 L .51197 .55531 L F
.51567 .55561 m .51385 .55825 L .51304 .55757 L F
.851 .928 .879 r
.42686 .56884 m .42755 .56646 L .42886 .56754 L F
.42686 .56884 m .42478 .56846 L .42755 .56646 L F
0 .154 .678 r
.65686 .4175 m .65803 .41933 L .65699 .41601 L F
.195 .676 .931 r
.21668 .54102 m .21878 .54109 L .22058 .54184 L F
.072 .611 .852 r
.21878 .54109 m .22264 .5417 L .22058 .54184 L F
.344 0 0 r
.56753 .63839 m .57293 .63889 L .56939 .63942 L F
.56753 .63839 m .56939 .63942 L .5661 .63702 L F
.419 .405 .737 r
.23185 .57214 m .23175 .56933 L .23317 .57059 L F
.909 .7 .608 r
.52024 .56694 m .51701 .56898 L .51843 .56721 L F
.52024 .56694 m .51888 .57 L .51701 .56898 L F
.858 .629 .591 r
.52187 .57047 m .51888 .57 L .52024 .56694 L F
.098 0 0 r
.62325 .43411 m .62442 .43427 L .62622 .43452 L F
.578 .526 .761 r
.62652 .43189 m .62442 .43427 L .62398 .4331 L F
.62652 .43189 m .6267 .43377 L .62442 .43427 L F
.169 0 0 r
.62442 .43427 m .6267 .43377 L .62622 .43452 L F
.629 .312 .415 r
.62998 .4319 m .63256 .4338 L .63002 .43372 L F
.336 .374 .753 r
.63125 .43147 m .63256 .4338 L .62998 .4319 L F
.146 0 0 r
.73533 .44363 m .73384 .44309 L .73624 .44265 L F
.73533 .44363 m .733 .44475 L .73384 .44309 L F
.86 .94 .872 r
.52501 .52663 m .52156 .52861 L .52354 .52544 L F
.732 .762 .877 r
.5265 .52303 m .52501 .52663 L .52354 .52544 L F
.5265 .52303 m .52701 .52579 L .52501 .52663 L F
.855 .966 .871 r
.21441 .58024 m .21301 .58145 L .21328 .58037 L F
.791 .969 .915 r
.19564 .64051 m .19175 .64247 L .19533 .64124 L F
.039 .057 .549 r
.19554 .63809 m .19564 .64051 L .19683 .63962 L F
0 0 0 r
.19564 .64051 m .19533 .64124 L .19683 .63962 L F
.787 .664 .727 r
.57996 .48728 m .58345 .48794 L .58383 .48535 L F
.79 .653 .711 r
.58116 .49067 m .58345 .48794 L .57996 .48728 L F
.634 .423 .578 r
.58116 .49067 m .5836 .49042 L .58345 .48794 L F
.756 .447 .461 r
.58722 .49043 m .58345 .48794 L .5836 .49042 L F
0 .224 .746 r
.66079 .42299 m .66281 .42604 L .6626 .42483 L F
.874 .756 .249 r
.66281 .42604 m .66233 .42722 L .6626 .42483 L F
.66281 .42604 m .66251 .42847 L .66233 .42722 L F
.716 .752 .88 r
.57971 .63629 m .58199 .63524 L .57832 .63478 L F
.57971 .63629 m .58199 .63524 L .57832 .63478 L F
.558 .396 .618 r
.61364 .43905 m .61589 .44002 L .61563 .43746 L F
.766 .984 .906 r
.61364 .43905 m .61563 .43746 L .61589 .44002 L F
.515 .589 .867 r
.56446 .63778 m .56503 .63408 L .56293 .63444 L F
.56446 .63778 m .5661 .63702 L .56503 .63408 L F
.28 0 0 r
.22676 .54231 m .22858 .5429 L .23024 .54327 L F
.305 .776 .935 r
.23024 .54327 m .22858 .5429 L .23253 .54301 L F
.261 0 .019 r
.36642 .59596 m .36981 .59373 L .36731 .59383 L F
.629 .273 .348 r
.53993 .6581 m .54018 .65661 L .53759 .65621 L F
.889 .785 .74 r
.52187 .57047 m .51842 .57232 L .51888 .57 L F
.52187 .57047 m .52019 .57331 L .51842 .57232 L F
.881 .509 .032 r
.65398 .43619 m .65507 .43734 L .65432 .43624 L F
.547 .023 0 r
.40404 .64255 m .40057 .64236 L .40189 .64211 L F
.429 .601 .918 r
.39299 .62163 m .3922 .62341 L .39074 .62104 L F
.329 .482 .86 r
.39299 .62163 m .39392 .62358 L .3922 .62341 L F
.217 .374 .806 r
.39496 .62529 m .3922 .62341 L .39392 .62358 L F
0 0 0 r
.16555 .54639 m .16809 .5458 L .16627 .54611 L F
.26 0 .102 r
.16627 .54611 m .16809 .5458 L .16918 .54437 L F
.807 .565 .572 r
.54336 .66095 m .54694 .65902 L .54384 .65841 L F
.54336 .66095 m .54687 .66162 L .54694 .65902 L F
.419 0 .13 r
.37488 .59075 m .37728 .5905 L .37832 .58893 L F
.328 0 .078 r
.37832 .58893 m .37728 .5905 L .38027 .58932 L F
.316 0 0 r
.37832 .58893 m .38027 .58932 L .38057 .5888 L F
.651 .665 .85 r
.69603 .4135 m .69839 .41095 L .69566 .4113 L F
.69603 .4135 m .69983 .4142 L .69839 .41095 L F
.574 .367 .562 r
.48521 .62651 m .48502 .62902 L .48253 .62958 L F
.627 .67 .872 r
.48549 .62581 m .48502 .62902 L .48521 .62651 L F
.654 .503 .667 r
.41398 .59248 m .41335 .59411 L .41019 .59415 L F
.69 .536 .673 r
.41335 .59411 m .41126 .59643 L .41019 .59415 L F
.632 .639 .839 r
.7193 .41971 m .72312 .42199 L .72198 .41894 L F
.592 .576 .805 r
.72312 .42199 m .72473 .41839 L .72198 .41894 L F
.72312 .42199 m .7261 .42127 L .72473 .41839 L F
.933 .88 .463 r
.66557 .45259 m .66496 .45374 L .66442 .45144 L F
.66519 .45392 m .66491 .45487 L .66496 .45374 L F
.875 .741 .229 r
.66491 .45487 m .66431 .4544 L .66496 .45374 L F
.718 .47 .551 r
.66431 .4544 m .66561 .45487 L .66496 .45374 L F
.626 .146 0 r
.66496 .45374 m .66561 .45487 L .66437 .45328 L F
.66496 .45374 m .66437 .45328 L .66243 .4508 L F
.933 .88 .463 r
.66557 .45259 m .66519 .45392 L .66496 .45374 L F
.588 .893 .989 r
.73809 .40968 m .73735 .40866 L .73493 .40962 L F
.9 .981 .795 r
.73902 .40663 m .73809 .40968 L .73982 .40817 L F
.485 .514 .812 r
.44672 .57165 m .44884 .57153 L .4488 .57141 L F
.54 .926 .838 r
.44482 .57188 m .44818 .57051 L .44672 .57165 L F
.485 .514 .812 r
.44672 .57165 m .4488 .57141 L .44763 .56809 L F
.54 .926 .838 r
.4444 .57206 m .44482 .57188 L .44672 .57165 L F
.853 .66 .64 r
.72811 .41639 m .72791 .41896 L .73151 .41976 L F
.458 0 0 r
.73094 .41977 m .73087 .41979 L .73101 .41981 L F
.244 0 0 r
.72791 .41896 m .73087 .41979 L .7312 .41969 L F
.458 0 0 r
.7293 .41897 m .73087 .41979 L .73094 .41977 L F
.244 0 0 r
.7312 .41969 m .73087 .41979 L .73151 .41976 L F
.535 0 0 r
.73101 .41981 m .73151 .41976 L .73087 .41979 L F
.73101 .41981 m .73375 .42154 L .73151 .41976 L F
0 0 0 r
.66576 .41445 m .66884 .41174 L .66778 .41311 L F
.091 0 .311 r
.66801 .4142 m .66576 .41445 L .66778 .41311 L F
.635 .931 .969 r
.44837 .5874 m .44601 .5884 L .44737 .58717 L F
.583 .798 .981 r
.44737 .58717 m .44601 .5884 L .44464 .58722 L F
.46 .816 .997 r
.62482 .40068 m .62879 .40122 L .62737 .40184 L F
0 0 .023 r
.21306 .6497 m .21207 .65206 L .21047 .65265 L F
.19 0 .029 r
.21121 .65411 m .21047 .65265 L .21207 .65206 L F
.21121 .65411 m .20929 .65475 L .21047 .65265 L F
.927 .858 .421 r
.67521 .43614 m .67426 .43971 L .67469 .44047 L F
.927 .853 .413 r
.67426 .43971 m .67379 .44185 L .67469 .44047 L F
.53 .299 .51 r
.55616 .53161 m .5532 .53458 L .5533 .53192 L F
.522 0 0 r
.37851 .63255 m .37964 .6337 L .3775 .63162 L F
.37851 .63255 m .38113 .6346 L .37964 .6337 L F
.829 .754 .78 r
.63708 .45705 m .6388 .4584 L .63823 .45572 L F
.864 .645 .604 r
.6359 .46047 m .6388 .4584 L .63708 .45705 L F
.6359 .46047 m .63872 .46069 L .6388 .4584 L F
.798 .758 .816 r
.63872 .46069 m .64121 .45779 L .6388 .4584 L F
.395 0 0 r
.43096 .59086 m .43038 .59171 L .42789 .5913 L F
.847 .55 .014 r
.43017 .58805 m .43066 .59108 L .43096 .59086 L F
.709 .847 .418 r
.43066 .59108 m .43038 .59171 L .43096 .59086 L F
.872 .683 .644 r
.73289 .41317 m .73605 .41119 L .73493 .40962 L F
.73289 .41317 m .73612 .41413 L .73605 .41119 L F
0 0 .414 r
.64712 .44693 m .64646 .44681 L .64463 .44603 L F
.64712 .44693 m .64629 .4495 L .64646 .44681 L F
.539 .242 .411 r
.52129 .69722 m .52415 .69631 L .52391 .69456 L F
.728 .481 .554 r
.52415 .69631 m .52718 .69427 L .52391 .69456 L F
.92 .977 .738 r
.6282 .44989 m .6263 .45295 L .62653 .45074 L F
.852 .996 .761 r
.6282 .44989 m .62653 .45074 L .62887 .44776 L F
.826 .868 .877 r
.19141 .55405 m .19535 .55273 L .19333 .5534 L F
.146 .69 .751 r
.19759 .55289 m .19333 .5534 L .19535 .55273 L F
.184 0 .14 r
.71029 .44679 m .70743 .44931 L .70947 .44806 L F
0 0 0 r
.71029 .44679 m .71175 .44561 L .71235 .44503 L F
0 0 .076 r
.70947 .44806 m .71175 .44561 L .71029 .44679 L F
.692 .223 .135 r
.42715 .63203 m .42938 .63398 L .43102 .63273 L F
.068 0 0 r
.42938 .63398 m .43331 .63242 L .43102 .63273 L F
.462 .827 .994 r
.18892 .54072 m .19097 .54027 L .19279 .54093 L F
.159 .669 .9 r
.19097 .54027 m .19488 .54089 L .19279 .54093 L F
.613 .557 .768 r
.68186 .41688 m .68237 .41976 L .68546 .4188 L F
.966 .661 .396 r
.51499 .66509 m .51389 .66533 L .51381 .66417 L F
.234 .747 .726 r
.51499 .66509 m .51721 .66443 L .51389 .66533 L F
.923 .975 .752 r
.56788 .47034 m .56584 .47366 L .56603 .47116 L F
.933 .962 .663 r
.56584 .47366 m .5643 .47474 L .56603 .47116 L F
0 0 0 r
.70743 .44931 m .70958 .44905 L .70947 .44806 L F
.70743 .44931 m .7064 .45032 L .70958 .44905 L F
.823 .638 .653 r
.58199 .48444 m .58383 .48535 L .58232 .4818 L F
.787 .664 .727 r
.57996 .48728 m .58383 .48535 L .58199 .48444 L F
.825 .78 .81 r
.64226 .44642 m .63968 .44964 L .63919 .44646 L F
0 0 0 r
.57323 .63757 m .57473 .63692 L .57062 .63634 L F
.523 0 0 r
.42114 .63196 m .42286 .63302 L .42477 .63226 L F
0 0 0 r
.42286 .63302 m .42715 .63203 L .42477 .63226 L F
.903 .969 .812 r
.56788 .47034 m .56805 .46788 L .57028 .46741 L F
.56788 .47034 m .56718 .46943 L .56805 .46788 L F
.949 .952 .728 r
.56788 .47034 m .56603 .47116 L .56718 .46943 L F
.44 .237 .506 r
.19554 .63809 m .19752 .63781 L .19782 .63528 L F
.039 .057 .549 r
.19554 .63809 m .19683 .63962 L .19752 .63781 L F
0 0 0 r
.41126 .59643 m .40951 .59862 L .40806 .59968 L F
.912 .686 .185 r
.40779 .6016 m .40819 .6026 L .40812 .60106 L F
.40779 .6016 m .40812 .60106 L .40806 .59968 L F
.661 .598 .775 r
.40628 .60107 m .40748 .60211 L .40779 .6016 L F
.775 .575 .629 r
.41231 .60553 m .40819 .6026 L .4092 .6028 L F
.4111 .60429 m .4092 .6028 L .40975 .60291 L F
.41231 .60553 m .4092 .6028 L .4111 .60429 L F
.41231 .60553 m .40848 .60525 L .40819 .6026 L F
.661 .598 .775 r
.40748 .60211 m .40959 .60396 L .40798 .60184 L F
.744 .337 .279 r
.40779 .6016 m .40975 .60291 L .40819 .6026 L F
.661 .598 .775 r
.40775 .60166 m .40798 .60184 L .40779 .6016 L F
.40748 .60211 m .40798 .60184 L .40775 .60166 L F
.912 .686 .185 r
.40779 .6016 m .40806 .59968 L .40951 .59862 L F
.583 .159 .203 r
.43826 .63867 m .44043 .6402 L .43793 .63996 L F
.174 0 0 r
.72584 .43942 m .72933 .43712 L .72663 .43675 L F
.741 .722 .833 r
.43978 .57918 m .44146 .58029 L .44319 .57882 L F
.764 .794 .877 r
.21877 .57588 m .21631 .57723 L .21478 .57577 L F
.61 .718 .922 r
.70473 .40071 m .70367 .40421 L .70221 .40144 L F
.70473 .40071 m .70594 .40351 L .70367 .40421 L F
.184 0 .246 r
.21541 .64687 m .21491 .64953 L .21306 .6497 L F
.104 0 .087 r
.21376 .65118 m .21306 .6497 L .21491 .64953 L F
.21376 .65118 m .21207 .65206 L .21306 .6497 L F
.441 .493 .817 r
.36183 .61411 m .36333 .61775 L .36478 .61703 L F
.373 .208 .524 r
.36333 .61775 m .36512 .61946 L .36478 .61703 L F
.36333 .61775 m .36326 .62033 L .36512 .61946 L F
.866 .833 .812 r
.67253 .45812 m .67321 .45413 L .67298 .45672 L F
.832 .956 .616 r
.67131 .4592 m .67253 .45812 L .67298 .45672 L F
.826 .608 .608 r
.60355 .44243 m .60701 .44059 L .60573 .4393 L F
.60355 .44243 m .60677 .44425 L .60701 .44059 L F
.865 .873 .842 r
.60573 .4393 m .60701 .44059 L .60951 .43761 L F
.37 .182 .491 r
.24132 .60864 m .2409 .61109 L .23917 .61153 L F
.283 .13 .489 r
.2409 .61109 m .23874 .61445 L .23917 .61153 L F
.987 .885 .549 r
.54996 .49272 m .54932 .49218 L .5499 .49011 L F
.867 .989 .833 r
.54692 .49493 m .54932 .49218 L .54996 .49272 L F
.639 .667 .861 r
.69983 .4142 m .70113 .41028 L .69839 .41095 L F
.69983 .4142 m .7023 .41342 L .70113 .41028 L F
.587 .785 .974 r
.19202 .66433 m .19197 .66309 L .19032 .66314 L F
.984 .743 .345 r
.51696 .54684 m .51756 .54644 L .51794 .54537 L F
.51696 .54684 m .51722 .54994 L .51636 .54842 L F
.51696 .54684 m .51636 .54842 L .51756 .54644 L F
.799 .734 .792 r
.67834 .41677 m .67589 .41936 L .67918 .42004 L F
.478 .234 .465 r
.74978 .43187 m .75222 .43125 L .74968 .43394 L F
0 0 0 r
.16918 .54437 m .16809 .5458 L .17082 .54335 L F
0 .019 .576 r
.21482 .59673 m .21434 .59546 L .21258 .59346 L F
0 .264 .759 r
.21482 .59673 m .21606 .59722 L .21434 .59546 L F
.29 0 0 r
.21688 .59699 m .21606 .59722 L .21482 .59673 L F
.073 .563 .895 r
.24825 .54757 m .25181 .54888 L .2501 .5487 L F
.984 .747 .496 r
.64604 .45181 m .64723 .4553 L .64688 .45254 L F
.677 .563 .719 r
.64961 .4523 m .64688 .45254 L .64629 .4495 L F
0 0 .139 r
.20055 .66734 m .20039 .67015 L .20007 .67068 L F
0 0 .253 r
.20049 .6723 m .20007 .67068 L .20039 .67015 L F
0 0 0 r
.20166 .67152 m .20104 .67195 L .20049 .6723 L F
0 0 .253 r
.20049 .6723 m .20012 .67326 L .2001 .67254 L F
.705 .672 .126 r
.1999 .6745 m .20012 .67326 L .20049 .6723 L F
.981 .867 .65 r
.20049 .6723 m .19868 .67355 L .1999 .6745 L F
0 0 0 r
.20104 .67195 m .19868 .67355 L .20049 .6723 L F
0 0 .253 r
.20049 .6723 m .2001 .67254 L .20007 .67068 L F
.643 .158 .088 r
.63125 .43147 m .63604 .43189 L .63526 .43329 L F
.161 .7 .754 r
.63604 .43189 m .63672 .43164 L .63526 .43329 L F
.63604 .43189 m .6385 .43148 L .63672 .43164 L F
.122 0 .225 r
.21645 .64849 m .21541 .64687 L .21682 .64628 L F
.21645 .64849 m .21491 .64953 L .21541 .64687 L F
.186 0 .307 r
.23759 .85016 m .23539 .85328 L .23617 .85091 L F
.23617 .85091 m .23539 .85328 L .23759 .85016 L F
.621 .871 .525 r
.74367 .42445 m .7422 .42653 L .74493 .42642 L F
.578 .094 .069 r
.67113 .41473 m .67228 .41457 L .6704 .41292 L F
.838 .652 .651 r
.52574 .57602 m .52684 .57928 L .5235 .57783 L F
.846 .48 .36 r
.52684 .57928 m .52531 .5809 L .5235 .57783 L F
.652 .555 .733 r
.52893 .57639 m .52684 .57928 L .52574 .57602 L F
.748 .338 .274 r
.52684 .57928 m .52931 .5816 L .52531 .5809 L F
.674 .587 .749 r
.52997 .5778 m .52684 .57928 L .52893 .57639 L F
.593 .399 .589 r
.52997 .5778 m .52931 .5816 L .52684 .57928 L F
.921 .71 .6 r
.66513 .44021 m .66659 .44383 L .66506 .44246 L F
.922 .894 .784 r
.66659 .44383 m .66381 .44541 L .66506 .44246 L F
.66659 .44383 m .66481 .44674 L .66381 .44541 L F
0 0 .39 r
.21301 .58145 m .21348 .58462 L .21328 .58037 L F
.503 .114 .236 r
.44804 .63775 m .44644 .64002 L .44433 .63883 L F
.515 .075 .141 r
.45022 .63832 m .44644 .64002 L .44804 .63775 L F
.697 .319 .329 r
.46102 .6317 m .46116 .63235 L .46457 .63164 L F
.495 .043 .106 r
.46116 .63235 m .46279 .63205 L .46457 .63164 L F
.46116 .63235 m .4656 .63321 L .46677 .63132 L F
.494 .04 .102 r
.46116 .63235 m .46232 .63349 L .4656 .63321 L F
.577 .119 .13 r
.46102 .6317 m .46232 .63349 L .46116 .63235 L F
.46148 .63233 m .45937 .63357 L .46232 .63349 L F
.46102 .6317 m .46024 .63259 L .46148 .63233 L F
.46024 .63259 m .45937 .63357 L .46148 .63233 L F
.495 .043 .106 r
.46279 .63205 m .46677 .63132 L .46526 .63154 L F
.46279 .63205 m .46526 .63154 L .46457 .63164 L F
.042 0 0 r
.42182 .59188 m .42036 .59271 L .41805 .59318 L F
.309 0 0 r
.42389 .59173 m .42036 .59271 L .42182 .59188 L F
.891 .936 .564 r
.22029 .59948 m .22154 .59605 L .22052 .597 L F
.653 .729 .905 r
.70835 .40178 m .70698 .40502 L .70594 .40351 L F
.70835 .40178 m .70947 .40415 L .70698 .40502 L F
.819 .816 .847 r
.52962 .52297 m .52701 .52579 L .5265 .52303 L F
.338 0 0 r
.52015 .69776 m .51896 .69684 L .51746 .69752 L F
.52015 .69776 m .52129 .69722 L .51896 .69684 L F
.441 .119 .323 r
.5367 .56774 m .53614 .56973 L .53376 .57013 L F
.492 .166 .341 r
.53845 .56913 m .5367 .56774 L .53885 .56703 L F
.53845 .56913 m .53614 .56973 L .5367 .56774 L F
.678 .397 .49 r
.59297 .48989 m .58978 .48915 L .58975 .49037 L F
.674 .781 .93 r
.44524 .56306 m .44682 .5647 L .4432 .56423 L F
.24 .656 .961 r
.44798 .56404 m .44682 .5647 L .44524 .56306 L F
.44798 .56404 m .44935 .56503 L .44682 .5647 L F
.84 .734 .747 r
.67119 .42534 m .66932 .42831 L .67225 .42883 L F
.832 .714 .735 r
.66839 .43094 m .67225 .42883 L .66932 .42831 L F
.66839 .43094 m .67028 .43149 L .67225 .42883 L F
.258 .153 .538 r
.25803 .57848 m .2567 .58178 L .25688 .57919 L F
.553 .416 .649 r
.5422 .55243 m .54249 .55532 L .54003 .55538 L F
0 0 .351 r
.54249 .55532 m .54232 .55835 L .54003 .55538 L F
.815 .996 .769 r
.57276 .46458 m .57028 .46741 L .57104 .46539 L F
.792 .991 .884 r
.57104 .46539 m .57028 .46741 L .56805 .46788 L F
.404 .338 .669 r
.42217 .58657 m .42424 .58652 L .42394 .58455 L F
.42334 .58461 m .42394 .58455 L .42383 .5838 L F
0 0 0 r
.42197 .58475 m .42055 .58529 L .42328 .58527 L F
.532 .12 .206 r
.41925 .58653 m .42328 .58527 L .42055 .58529 L F
.41925 .58653 m .42217 .58657 L .42328 .58527 L F
.404 .338 .669 r
.42217 .58657 m .42394 .58455 L .42334 .58461 L F
0 0 0 r
.42181 .58469 m .42159 .58479 L .42197 .58475 L F
.42159 .58479 m .42055 .58529 L .42197 .58475 L F
.42181 .58469 m .41925 .58653 L .42055 .58529 L F
.432 .178 .426 r
.47469 .57913 m .47416 .5812 L .47193 .58182 L F
.443 .453 .775 r
.47669 .57708 m .47469 .57913 L .47385 .57602 L F
.47669 .57708 m .47385 .57602 L .47616 .57743 L F
.585 .686 .911 r
.47678 .5741 m .47776 .57599 L .47616 .57743 L F
.581 .705 .928 r
.47644 .57734 m .47669 .57708 L .47616 .57743 L F
.47817 .5768 m .47933 .57821 L .47669 .57708 L F
.47817 .5768 m .47669 .57708 L .47644 .57734 L F
.272 .113 .474 r
.47668 .57709 m .47416 .5812 L .47468 .57916 L F
.47644 .57734 m .47468 .57916 L .47469 .57913 L F
.47668 .57709 m .47468 .57916 L .47644 .57734 L F
.585 .686 .911 r
.47776 .57599 m .47817 .5768 L .47644 .57734 L F
.47776 .57599 m .47644 .57734 L .47616 .57743 L F
.272 .113 .474 r
.47669 .57708 m .47668 .57709 L .47469 .57913 L F
.47668 .57709 m .47469 .57913 L .47469 .57913 L F
.501 .298 .536 r
.54431 .54678 m .54423 .5494 L .54183 .54991 L F
.496 .318 .57 r
.54656 .54372 m .54659 .54614 L .54431 .54678 L F
.466 .263 .52 r
.54659 .54614 m .54423 .5494 L .54431 .54678 L F
.499 .313 .559 r
.54384 .65841 m .54123 .65907 L .54336 .66095 L F
.154 0 .158 r
.61706 .4871 m .61957 .48427 L .61881 .48616 L F
0 0 0 r
.61881 .48616 m .61957 .48427 L .6213 .48332 L F
.42 .331 .649 r
.36039 .60575 m .3621 .60185 L .35983 .60342 L F
0 0 0 r
.74466 .43735 m .74604 .43734 L .74376 .43869 L F
.74466 .43735 m .7465 .43643 L .74604 .43734 L F
.597 .481 .692 r
.54423 .5494 m .5422 .55243 L .54183 .54991 L F
.283 .713 .968 r
.69217 .46499 m .69304 .46397 L .69116 .4654 L F
.69217 .46499 m .69368 .46493 L .69304 .46397 L F
.546 .109 .162 r
.47193 .58182 m .47157 .58263 L .4688 .58219 L F
.125 0 0 r
.47416 .5812 m .47157 .58263 L .47193 .58182 L F
.894 .635 .538 r
.64433 .45006 m .64629 .4495 L .64712 .44693 L F
.64433 .45006 m .64604 .45181 L .64629 .4495 L F
.677 .563 .719 r
.64961 .4523 m .64629 .4495 L .64604 .45181 L F
.682 .773 .92 r
.19175 .64247 m .1903 .64372 L .18844 .64281 L F
.687 .659 .817 r
.61989 .46035 m .61691 .45992 L .61944 .45862 L F
.769 .846 .91 r
.62182 .45698 m .61989 .46035 L .61944 .45862 L F
.933 .84 .728 r
.6263 .45295 m .62467 .4522 L .62653 .45074 L F
.6263 .45295 m .62532 .45502 L .62467 .4522 L F
.786 .677 .744 r
.64594 .43723 m .64642 .4412 L .64344 .44038 L F
.778 .303 0 r
.64642 .4412 m .6463 .44208 L .64344 .44038 L F
.64642 .4412 m .64759 .44295 L .6463 .44208 L F
.78 .683 .757 r
.64854 .43637 m .64642 .4412 L .64594 .43723 L F
.223 .388 .818 r
.38557 .63735 m .38555 .63866 L .38671 .63731 L F
.107 .258 .737 r
.38701 .64081 m .38671 .63731 L .38555 .63866 L F
.29 .274 .668 r
.25843 .56561 m .25764 .5703 L .25681 .56778 L F
.25843 .56561 m .25905 .56961 L .25764 .5703 L F
.346 .26 .614 r
.25955 .57212 m .25764 .5703 L .25905 .56961 L F
.25955 .57212 m .25757 .57347 L .25764 .5703 L F
.963 .918 .572 r
.61098 .42606 m .61262 .42542 L .61176 .42444 L F
.61098 .42606 m .61141 .42909 L .61262 .42542 L F
.973 .92 .681 r
.61274 .42232 m .61176 .42444 L .61262 .42542 L F
.812 .916 .524 r
.61477 .40755 m .613 .4108 L .61365 .4087 L F
0 0 0 r
.61477 .40755 m .61648 .40607 L .61747 .40475 L F
.61477 .40755 m .61365 .4087 L .61648 .40607 L F
.825 .78 .81 r
.64226 .44642 m .63919 .44646 L .64111 .4449 L F
.526 .718 .961 r
.64463 .44603 m .64226 .44642 L .64111 .4449 L F
.967 .926 .603 r
.51119 .68424 m .51271 .68277 L .51182 .68187 L F
.901 .955 .616 r
.51236 .68218 m .51271 .68277 L .51119 .68424 L F
.901 .587 .093 r
.51182 .68187 m .51271 .68277 L .51143 .67864 L F
.696 .174 0 r
.51182 .68187 m .51091 .68032 L .51236 .68218 L F
.901 .587 .093 r
.51182 .68187 m .51143 .67864 L .51091 .68032 L F
.309 .372 .765 r
.54294 .68063 m .54395 .67824 L .54148 .67882 L F
.54294 .68063 m .5451 .68173 L .54395 .67824 L F
.558 .289 .463 r
.55869 .53125 m .55886 .52911 L .56122 .53095 L F
.542 .295 .49 r
.55886 .52911 m .56126 .52878 L .56122 .53095 L F
.421 .199 .469 r
.23835 .61608 m .23606 .61961 L .23685 .61706 L F
.156 .696 .807 r
.20135 .5527 m .1999 .55266 L .19759 .55289 L F
.37 .834 .896 r
.20197 .55209 m .20135 .5527 L .20346 .55241 L F
.875 .762 .734 r
.58097 .48056 m .58199 .48444 L .58232 .4818 L F
.876 .839 .805 r
.58232 .4818 m .58302 .47739 L .58097 .48056 L F
.289 .018 .317 r
.21967 .64301 m .21682 .64628 L .218 .64379 L F
.865 .873 .842 r
.60573 .4393 m .60951 .43761 L .60847 .43669 L F
.952 .918 .74 r
.61078 .43291 m .60847 .43669 L .60951 .43761 L F
.995 .851 .507 r
.65322 .43205 m .65304 .42798 L .65263 .43041 L F
.91 .617 .124 r
.65277 .4328 m .65322 .43205 L .65263 .43041 L F
.65277 .4328 m .65355 .43427 L .65322 .43205 L F
.876 .883 .836 r
.58787 .47103 m .58998 .47097 L .59146 .46914 L F
.764 .794 .877 r
.21877 .57588 m .21478 .57577 L .21734 .57253 L F
.28 .353 .76 r
.21972 .57641 m .21877 .57588 L .22074 .57556 L F
.281 .104 .454 r
.39327 .60734 m .3916 .60623 L .39468 .60461 L F
.39327 .60734 m .39042 .60972 L .3916 .60623 L F
.701 .742 .883 r
.56745 .62594 m .56515 .62721 L .56357 .6254 L F
.602 .708 .919 r
.36413 .62652 m .36545 .62833 L .36668 .62724 L F
.25 .745 .91 r
.19488 .54089 m .19714 .5407 L .19878 .54104 L F
.362 .814 .94 r
.19714 .5407 m .20093 .54057 L .19878 .54104 L F
.838 .652 .651 r
.52574 .57602 m .5235 .57783 L .52332 .5763 L F
.659 .51 .67 r
.52879 .5737 m .52893 .57639 L .52574 .57602 L F
.603 .677 .893 r
.45176 .57461 m .45262 .5716 L .4507 .57206 L F
.45176 .57461 m .45451 .57407 L .45262 .5716 L F
.417 .15 .398 r
.19782 .63528 m .19995 .63473 L .20066 .63257 L F
.144 0 .266 r
.20066 .63257 m .19995 .63473 L .20211 .63173 L F
.61 .659 .873 r
.36083 .62556 m .36152 .6278 L .36413 .62652 L F
.227 0 0 r
.18908 .55413 m .18762 .55455 L .18531 .55445 L F
.288 .778 .721 r
.18954 .55384 m .18908 .55413 L .19141 .55405 L F
.18954 .55384 m .18762 .55455 L .18908 .55413 L F
.986 .723 .433 r
.51489 .56677 m .51364 .56351 L .51528 .56462 L F
.585 .53 .759 r
.42835 .58232 m .42661 .58498 L .42655 .58257 L F
.42835 .58232 m .4289 .58494 L .42661 .58498 L F
.654 .928 .973 r
.61768 .45779 m .61691 .45992 L .61565 .4591 L F
.61768 .45779 m .61944 .45862 L .61691 .45992 L F
.837 .554 .51 r
.67028 .43149 m .67047 .4338 L .67364 .43429 L F
.625 .088 0 r
.67047 .4338 m .6728 .43513 L .67364 .43429 L F
.671 .16 0 r
.67388 .43507 m .67364 .43429 L .6728 .43513 L F
.67388 .43507 m .67521 .43614 L .67364 .43429 L F
.716 .777 .9 r
.60765 .44475 m .60843 .44647 L .60532 .44665 L F
.171 0 .227 r
.60765 .44475 m .60532 .44665 L .60843 .44647 L F
.403 .592 .92 r
.60765 .44475 m .60843 .44647 L .60965 .44469 L F
.60765 .44475 m .60843 .44647 L .60965 .44469 L F
.198 .728 .799 r
.42789 .5913 m .42588 .59133 L .42389 .59173 L F
.002 .547 .833 r
.42789 .5913 m .42865 .59104 L .42588 .59133 L F
.42789 .5913 m .43038 .59171 L .42865 .59104 L F
.365 .261 .601 r
.62879 .40122 m .62939 .40415 L .6269 .40507 L F
.26 .023 .352 r
.62939 .40415 m .627 .40676 L .6269 .40507 L F
.561 .297 .473 r
.3606 .62054 m .36261 .62262 L .36326 .62033 L F
.494 .021 .062 r
.44433 .63883 m .44298 .64019 L .44043 .6402 L F
.526 .057 .085 r
.44644 .64002 m .44298 .64019 L .44433 .63883 L F
.884 .812 .772 r
.52272 .53204 m .52194 .53418 L .51901 .53408 L F
.893 .779 .728 r
.51901 .53408 m .52194 .53418 L .52084 .53553 L F
.475 .744 .987 r
.67944 .40632 m .68287 .40744 L .68185 .4062 L F
0 0 0 r
.68287 .40744 m .68535 .40688 L .6844 .40739 L F
.68287 .40744 m .6844 .40739 L .68185 .4062 L F
.939 .964 .692 r
.5358 .51068 m .53453 .51463 L .53329 .51467 L F
.971 .82 .636 r
.53453 .51463 m .53413 .517 L .53329 .51467 L F
.596 .731 .939 r
.6921 .45464 m .69069 .45739 L .68949 .45606 L F
.6921 .45464 m .69323 .45682 L .69069 .45739 L F
.403 .022 .198 r
.44821 .59271 m .44678 .59158 L .44888 .59089 L F
.44821 .59271 m .44597 .59325 L .44678 .59158 L F
.886 .866 .814 r
.5905 .46817 m .59146 .46914 L .59113 .46665 L F
.876 .883 .836 r
.58787 .47103 m .59146 .46914 L .5905 .46817 L F
.872 .858 .825 r
.59113 .46665 m .59146 .46914 L .59236 .46778 L F
.808 .821 .861 r
.66968 .42164 m .67143 .42282 L .67368 .42081 L F
.945 .7 .535 r
.66968 .42164 m .67119 .42534 L .67143 .42282 L F
.522 .109 .199 r
.48253 .62958 m .48147 .63132 L .47919 .63099 L F
0 0 0 r
.48309 .62977 m .48253 .62958 L .48502 .62902 L F
.48309 .62977 m .48147 .63132 L .48253 .62958 L F
.204 .352 .791 r
.19392 .67364 m .19467 .67286 L .19316 .67192 L F
0 0 0 r
.19345 .67604 m .19467 .67286 L .19392 .67364 L F
.763 .963 .665 r
.19828 .67949 m .19626 .68119 L .19585 .68249 L F
0 .161 .696 r
.19626 .68119 m .19777 .68456 L .19585 .68249 L F
.86 .887 .855 r
.6807 .41568 m .6844 .41463 L .6821 .41487 L F
.6807 .41568 m .68186 .41688 L .6844 .41463 L F
0 0 0 r
.66778 .41311 m .66884 .41174 L .67074 .40984 L F
.773 .685 .766 r
.64604 .45181 m .64723 .4553 L .64961 .4523 L F
.848 .634 .093 r
.64319 .43621 m .64336 .4376 L .64275 .4361 L F
.433 .477 .806 r
.64344 .44038 m .64275 .4361 L .64336 .4376 L F
.786 .677 .744 r
.64594 .43723 m .64344 .44038 L .64336 .4376 L F
.433 .477 .806 r
.64344 .44038 m .64416 .43693 L .64275 .4361 L F
.427 0 0 r
.64231 .43598 m .64275 .4361 L .64416 .43693 L F
.64116 .43539 m .64275 .4361 L .64231 .43598 L F
.848 .634 .093 r
.64287 .43369 m .64319 .43621 L .64275 .4361 L F
.524 .718 .961 r
.37181 .62849 m .37244 .62653 L .36988 .62739 L F
.37181 .62849 m .37416 .62826 L .37244 .62653 L F
.735 .741 .856 r
.74353 .41935 m .74707 .41989 L .74617 .41775 L F
.577 .036 0 r
.74353 .41935 m .74607 .42077 L .74707 .41989 L F
.472 .511 .817 r
.74707 .41989 m .74868 .4163 L .74617 .41775 L F
.74707 .41989 m .74902 .41925 L .74868 .4163 L F
.74902 .41925 m .74936 .4188 L .74868 .4163 L F
0 0 0 r
.74835 .41998 m .74945 .41911 L .74707 .41989 L F
.696 .656 .806 r
.75042 .41747 m .74945 .41911 L .75211 .4186 L F
.923 .535 .158 r
.75101 .41508 m .75169 .41565 L .75163 .41395 L F
.75169 .41565 m .75254 .41636 L .75204 .41503 L F
.75169 .41565 m .75204 .41503 L .75163 .41395 L F
.983 .774 .545 r
.75181 .41575 m .75211 .4186 L .75254 .41636 L F
.75101 .41508 m .75138 .41626 L .75181 .41575 L F
.696 .656 .806 r
.74936 .4188 m .74945 .41911 L .75042 .41747 L F
.472 .511 .817 r
.74902 .41925 m .74945 .41911 L .74936 .4188 L F
.062 .433 .873 r
.75315 .42211 m .74945 .41911 L .75211 .4186 L F
.293 0 0 r
.75211 .4186 m .74945 .41911 L .74835 .41998 L F
.75211 .4186 m .75126 .41641 L .75145 .41618 L F
.681 .938 .965 r
.75125 .41641 m .75117 .41645 L .75183 .41569 L F
.75177 .41576 m .75183 .41569 L .75185 .41567 L F
.75125 .41641 m .75183 .41569 L .75177 .41576 L F
.696 .656 .806 r
.75079 .4152 m .75126 .41641 L .75101 .41508 L F
.75126 .41641 m .75211 .4186 L .75138 .41626 L F
.75126 .41641 m .75138 .41626 L .75101 .41508 L F
.983 .774 .545 r
.75145 .41618 m .75211 .4186 L .75181 .41575 L F
.293 0 0 r
.75211 .4186 m .75145 .41618 L .75212 .41535 L F
.351 .405 .777 r
.7548 .4164 m .75211 .4186 L .75212 .41535 L F
0 .347 .719 r
.75309 .41553 m .7548 .4164 L .75212 .41535 L F
.75309 .41553 m .75225 .41538 L .75121 .4165 L F
.75225 .41538 m .75225 .41538 L .75222 .4154 L F
.75225 .41538 m .75222 .4154 L .75121 .4165 L F
.696 .656 .806 r
.74868 .4163 m .74989 .41711 L .75079 .4152 L F
.681 .938 .965 r
.75126 .41641 m .75185 .41567 L .75129 .41637 L F
.696 .656 .806 r
.75042 .41747 m .75126 .41641 L .75117 .41617 L F
.681 .938 .965 r
.75027 .41763 m .75177 .41576 L .75126 .41641 L F
.75177 .41576 m .75185 .41567 L .75126 .41641 L F
.696 .656 .806 r
.74989 .41711 m .75042 .41747 L .75117 .41617 L F
.75042 .41747 m .75211 .4186 L .75126 .41641 L F
.74989 .41711 m .75117 .41617 L .75079 .4152 L F
.293 0 0 r
.75211 .4186 m .74835 .41998 L .75126 .41641 L F
.983 .774 .545 r
.75138 .41626 m .75211 .4186 L .75145 .41618 L F
.681 .938 .965 r
.75027 .41763 m .7508 .41693 L .75125 .41641 L F
.7508 .41693 m .75117 .41645 L .75125 .41641 L F
0 .347 .719 r
.75078 .41727 m .75121 .4165 L .74988 .41794 L F
.75309 .41553 m .75121 .4165 L .75078 .41727 L F
.75225 .41538 m .75212 .41535 L .75185 .41567 L F
.681 .938 .965 r
.75129 .41637 m .75185 .41567 L .75212 .41535 L F
0 .347 .719 r
.75225 .41538 m .75185 .41567 L .74988 .41794 L F
.696 .656 .806 r
.74989 .41711 m .74936 .4188 L .75042 .41747 L F
.74868 .4163 m .74906 .41771 L .74989 .41711 L F
.74906 .41771 m .74936 .4188 L .74989 .41711 L F
.681 .938 .965 r
.74835 .41998 m .74988 .41794 L .75117 .41645 L F
.74835 .41998 m .75117 .41645 L .75027 .41763 L F
0 0 0 r
.74835 .41998 m .74707 .41989 L .74607 .42077 L F
.999 .834 .506 r
.66426 .44906 m .66381 .44541 L .66481 .44674 L F
.052 .17 .669 r
.21054 .61131 m .21144 .61484 L .21232 .61326 L F
.182 .344 .792 r
.21144 .61484 m .21386 .61668 L .21232 .61326 L F
.42 .361 .685 r
.21144 .61484 m .21218 .61739 L .21386 .61668 L F
.085 0 0 r
.67318 .40933 m .67636 .40762 L .6758 .40845 L F
.423 .265 .56 r
.25157 .59253 m .24936 .5907 L .25148 .59032 L F
.25157 .59253 m .24896 .59413 L .24936 .5907 L F
.154 0 0 r
.74579 .41392 m .74743 .41454 L .74785 .41408 L F
.74579 .41392 m .74492 .41552 L .74743 .41454 L F
.394 .768 .992 r
.6719 .39922 m .67161 .39997 L .67034 .39908 L F
.6719 .39922 m .67415 .39978 L .67161 .39997 L F
0 0 0 r
.57979 .62446 m .57927 .62524 L .5794 .62417 L F
.436 .224 .491 r
.19752 .63781 m .19995 .63473 L .19782 .63528 L F
.394 0 0 r
.1992 .68073 m .19828 .67949 L .19979 .67866 L F
.1992 .68073 m .19626 .68119 L .19828 .67949 L F
.674 .86 .97 r
.68258 .46659 m .68396 .4678 L .68616 .46662 L F
.419 .071 .266 r
.66804 .40136 m .66728 .40016 L .6658 .40182 L F
.669 .455 .585 r
.60756 .4724 m .61002 .46958 L .60745 .46995 L F
.551 .032 0 r
.43331 .63242 m .43539 .63368 L .4368 .63259 L F
0 0 0 r
.4368 .63259 m .43759 .63298 L .43933 .63256 L F
.4368 .63259 m .43539 .63368 L .43759 .63298 L F
.672 .681 .85 r
.72851 .42319 m .73315 .42538 L .73319 .42295 L F
.558 .585 .836 r
.73315 .42538 m .73375 .42154 L .73319 .42295 L F
.654 .969 .895 r
.58664 .62196 m .58541 .62362 L .58766 .62386 L F
.58664 .62196 m .58222 .62501 L .58541 .62362 L F
.309 .761 .957 r
.5241 .54944 m .52565 .54918 L .52275 .54929 L F
.52643 .54969 m .52565 .54918 L .5241 .54944 L F
.634 .936 .964 r
.52749 .54812 m .52565 .54918 L .52643 .54969 L F
.346 .113 .411 r
.52749 .54812 m .52681 .54899 L .52565 .54918 L F
.997 .848 .518 r
.52643 .54969 m .52511 .55112 L .52565 .54918 L F
.346 .113 .411 r
.52681 .54899 m .52511 .55112 L .52565 .54918 L F
.627 .869 .514 r
.52643 .54969 m .52511 .55112 L .52749 .54812 L F
0 0 0 r
.72336 .4402 m .72112 .44117 L .72038 .44211 L F
.594 .734 .942 r
.69865 .40047 m .6972 .40276 L .69625 .40084 L F
.69865 .40047 m .69972 .40214 L .6972 .40276 L F
.9 .888 .81 r
.66618 .43473 m .66596 .43796 L .6646 .43691 L F
.926 .786 .686 r
.66596 .43796 m .66382 .4391 L .6646 .43691 L F
.66596 .43796 m .66513 .44021 L .66382 .4391 L F
.756 .742 .841 r
.52204 .69977 m .52415 .69631 L .52129 .69722 L F
0 .124 .66 r
.52261 .69855 m .52204 .69977 L .52129 .69722 L F
.756 .742 .841 r
.52204 .69977 m .52507 .6981 L .52415 .69631 L F
0 0 0 r
.52261 .69855 m .52123 .70204 L .52204 .69977 L F
.728 .481 .554 r
.52415 .69631 m .52718 .69675 L .52718 .69427 L F
.806 .99 .74 r
.57531 .46158 m .57276 .46458 L .57361 .46254 L F
.807 .996 .77 r
.57276 .46458 m .57104 .46539 L .57361 .46254 L F
.42 .331 .649 r
.36039 .60575 m .36221 .6053 L .3621 .60185 L F
.434 .381 .7 r
.36039 .60575 m .36293 .60774 L .36221 .6053 L F
.431 .381 .702 r
.36039 .60575 m .36113 .6085 L .36293 .60774 L F
.446 .563 .879 r
.7587 .40554 m .7568 .40761 L .75559 .40577 L F
.7587 .40554 m .75889 .40749 L .7568 .40761 L F
.399 .097 .333 r
.7568 .40761 m .75889 .40749 L .75692 .40929 L F
.802 .797 .848 r
.73289 .41317 m .73432 .41489 L .73612 .41413 L F
.577 .593 .833 r
.73432 .41489 m .73748 .41727 L .73612 .41413 L F
.272 .323 .733 r
.73612 .41413 m .7388 .41538 L .73985 .41645 L F
.73612 .41413 m .73748 .41727 L .7388 .41538 L F
.608 .43 .615 r
.56685 .52328 m .56704 .5256 L .5645 .52582 L F
.615 .383 .542 r
.56685 .52328 m .56952 .52521 L .56704 .5256 L F
.56685 .52328 m .56957 .52287 L .56952 .52521 L F
.741 .847 .929 r
.45733 .57424 m .46086 .57416 L .45999 .57321 L F
.266 .582 .944 r
.46086 .57416 m .46293 .57383 L .45999 .57321 L F
.46086 .57416 m .46412 .5756 L .46293 .57383 L F
.798 .638 .683 r
.22666 .55819 m .22664 .56158 L .2284 .56128 L F
.739 .441 .478 r
.22664 .56158 m .22604 .5634 L .2284 .56128 L F
.677 .351 .416 r
.2284 .56128 m .22604 .5634 L .23017 .5634 L F
.648 .351 .455 r
.2284 .56128 m .23017 .5634 L .23053 .56145 L F
.147 .65 .906 r
.23451 .54308 m .23838 .54387 L .23622 .54411 L F
.584 .334 .503 r
.5645 .52582 m .56695 .52783 L .56349 .52862 L F
.5645 .52582 m .56704 .5256 L .56695 .52783 L F
.284 0 0 r
.22956 .56725 m .22808 .56772 L .22567 .56766 L F
0 .246 .76 r
.22956 .56725 m .2302 .56657 L .22808 .56772 L F
.22956 .56725 m .23175 .56933 L .2302 .56657 L F
.226 0 .103 r
.59825 .48708 m .59601 .48795 L .59538 .48936 L F
0 0 .172 r
.44041 .58799 m .44073 .5897 L .44086 .58666 L F
.814 .658 .689 r
.73541 .42231 m .73843 .42291 L .73724 .41947 L F
.451 .248 .513 r
.73843 .42291 m .74085 .41968 L .73724 .41947 L F
.73843 .42291 m .74078 .42213 L .74085 .41968 L F
.439 .329 .632 r
.73843 .42291 m .74088 .42475 L .74078 .42213 L F
.115 0 0 r
.20735 .55252 m .20558 .55256 L .20346 .55241 L F
.126 .67 .825 r
.20947 .55265 m .20558 .55256 L .20735 .55252 L F
.794 .805 .86 r
.65048 .44781 m .65199 .44932 L .65493 .44653 L F
.771 .842 .386 r
.21258 .59346 m .21411 .5895 L .2126 .59099 L F
.247 0 0 r
.40538 .63284 m .40764 .63331 L .40913 .63304 L F
.459 0 0 r
.40764 .63331 m .41127 .63408 L .40913 .63304 L F
.771 .729 .814 r
.51405 .53947 m .51574 .54134 L .51297 .53947 L F
.735 .724 .84 r
.5175 .53986 m .51574 .54134 L .51405 .53947 L F
0 0 .179 r
.49839 .7199 m .4988 .71794 L .50011 .71794 L F
.968 .688 .447 r
.49839 .7199 m .4988 .71794 L .49714 .71699 L F
.493 .431 .715 r
.60457 .47331 m .60761 .47492 L .60756 .4724 L F
.60457 .47331 m .60557 .47579 L .60761 .47492 L F
.283 .079 .416 r
.60034 .48389 m .59853 .48486 L .59825 .48708 L F
.675 .527 .676 r
.41602 .59395 m .41398 .59248 L .41701 .59171 L F
.409 .208 .494 r
.41805 .59318 m .41602 .59395 L .41701 .59171 L F
.43 .202 .466 r
.20938 .62304 m .21185 .61989 L .20993 .62051 L F
.664 .303 .351 r
.42377 .6407 m .42226 .64299 L .42005 .64088 L F
.58 .214 .311 r
.42605 .6408 m .42226 .64299 L .42377 .6407 L F
.479 .295 .552 r
.5284 .6881 m .53063 .6874 L .5281 .68591 L F
.5281 .68591 m .53063 .6874 L .5284 .6881 L F
0 0 0 r
.63228 .42865 m .62881 .43064 L .63125 .43005 L F
.475 0 0 r
.6337 .43009 m .63228 .42865 L .63125 .43005 L F
.6337 .43009 m .63479 .42877 L .63228 .42865 L F
.283 .13 .489 r
.2409 .61109 m .24075 .61368 L .23874 .61445 L F
.212 .016 .383 r
.24075 .61368 m .23835 .61608 L .23874 .61445 L F
.49 .878 .692 r
.72619 .45002 m .72491 .45061 L .72319 .45199 L F
.663 .95 .71 r
.72626 .44926 m .72619 .45002 L .72837 .44878 L F
.72626 .44926 m .72491 .45061 L .72619 .45002 L F
.79 .951 .616 r
.57752 .45835 m .57531 .46158 L .57608 .45963 L F
.758 .977 .715 r
.58 .45557 m .57752 .45835 L .57841 .45654 L F
.738 .938 .607 r
.57752 .45835 m .57608 .45963 L .57841 .45654 L F
.339 .683 .979 r
.56745 .62594 m .57077 .62691 L .5687 .62936 L F
.528 .339 .567 r
.54923 .62633 m .55165 .62573 L .55074 .62405 L F
.441 .227 .492 r
.55074 .62405 m .55469 .62372 L .55397 .6203 L F
.507 .396 .662 r
.55165 .62573 m .55469 .62372 L .55074 .62405 L F
.467 .847 .623 r
.72319 .45199 m .72491 .45061 L .72193 .45278 L F
.442 .025 .151 r
.4688 .58219 m .46839 .58376 L .46515 .58406 L F
.015 0 .031 r
.4698 .58308 m .4688 .58219 L .47157 .58263 L F
.4698 .58308 m .46839 .58376 L .4688 .58219 L F
.38 .175 .472 r
.22133 .64219 m .2201 .64098 L .22181 .64007 L F
.22133 .64219 m .21967 .64301 L .2201 .64098 L F
.412 .28 .59 r
.24711 .60164 m .2452 .59977 L .24741 .59902 L F
.24711 .60164 m .24533 .60241 L .2452 .59977 L F
.406 0 .145 r
.39377 .58418 m .39747 .5819 L .39522 .58245 L F
.808 .99 .74 r
.57531 .46158 m .57361 .46254 L .57608 .45963 L F
.643 .909 .601 r
.62246 .48205 m .62512 .47914 L .62378 .48023 L F
.047 .037 .521 r
.53028 .57425 m .52879 .5737 L .53134 .57296 L F
.53028 .57425 m .52893 .57639 L .52879 .5737 L F
.606 .423 .608 r
.55048 .53469 m .5532 .53738 L .55094 .53721 L F
.55048 .53469 m .5532 .53458 L .5532 .53738 L F
.509 .247 .453 r
.58312 .51443 m .58529 .51601 L .58317 .5166 L F
.58312 .51443 m .58554 .5141 L .58529 .51601 L F
.479 .411 .702 r
.25955 .57212 m .25806 .57595 L .25757 .57347 L F
.675 .527 .676 r
.41602 .59395 m .41335 .59411 L .41398 .59248 L F
.542 .653 .908 r
.61373 .43242 m .6119 .43456 L .61078 .43291 L F
.61373 .43242 m .6119 .43456 L .61078 .43291 L F
.074 .338 .814 r
.39937 .62864 m .39907 .6302 L .39782 .62882 L F
.39937 .62864 m .40144 .63167 L .39907 .6302 L F
.654 .619 .802 r
.7193 .41971 m .72079 .41544 L .71812 .41626 L F
.7193 .41971 m .72198 .41894 L .72079 .41544 L F
.673 .627 .796 r
.55269 .62912 m .55656 .63197 L .55512 .62875 L F
.634 .649 .847 r
.55512 .62875 m .55656 .63197 L .55892 .63111 L F
.467 .333 .615 r
.24896 .59413 m .2474 .59664 L .24748 .59492 L F
.495 .32 .572 r
.54898 .543 m .54659 .54614 L .54656 .54372 L F
.592 .888 .99 r
.66804 .4692 m .67201 .46902 L .67048 .46827 L F
.66804 .4692 m .67201 .46902 L .67048 .46827 L F
.2 .679 .933 r
.67418 .46905 m .67201 .46902 L .67048 .46827 L F
.67048 .46827 m .67201 .46902 L .67418 .46905 L F
.67048 .46827 m .67201 .46902 L .67418 .46905 L F
.513 .275 .492 r
.36981 .59373 m .37215 .59333 L .37239 .591 L F
.493 .225 .436 r
.37215 .59333 m .37488 .59075 L .37239 .591 L F
.688 .549 .69 r
.22045 .56081 m .22294 .55774 L .22097 .55857 L F
0 0 .223 r
.43068 .58858 m .43017 .58805 L .42933 .58662 L F
.43068 .58858 m .43066 .59108 L .43017 .58805 L F
.561 .286 .455 r
.61933 .4551 m .62186 .45455 L .62262 .45258 L F
.326 .055 .341 r
.62262 .45258 m .62186 .45455 L .62467 .4522 L F
.151 0 .314 r
.61204 .46569 m .61151 .46372 L .60941 .46729 L F
.536 .405 .649 r
.60941 .46729 m .61002 .46958 L .61247 .46892 L F
.467 .329 .61 r
.61563 .43746 m .61589 .44002 L .61809 .43925 L F
.61563 .43746 m .61589 .44002 L .61809 .43925 L F
.483 0 0 r
.74785 .41408 m .75101 .41508 L .75163 .41395 L F
0 0 0 r
.6424 .4228 m .64185 .42598 L .64242 .42357 L F
.931 .843 .736 r
.64226 .41899 m .6424 .4228 L .643 .42149 L F
0 0 0 r
.643 .42149 m .6424 .4228 L .64242 .42357 L F
.857 .809 .802 r
.53116 .51684 m .53185 .51986 L .53015 .51868 L F
.847 .786 .792 r
.53185 .51986 m .52787 .52176 L .53015 .51868 L F
.53185 .51986 m .52962 .52297 L .52787 .52176 L F
.828 .778 .805 r
.53276 .51511 m .53185 .51986 L .53116 .51684 L F
.53276 .51511 m .53413 .517 L .53185 .51986 L F
0 0 0 r
.47778 .63113 m .47777 .63109 L .47919 .63099 L F
.47879 .63071 m .47778 .63113 L .48032 .63085 L F
.47841 .63067 m .47823 .6308 L .47879 .63071 L F
.47823 .6308 m .47778 .63113 L .47879 .63071 L F
.744 .964 .937 r
.48217 .62945 m .48032 .63085 L .48147 .63132 L F
.011 0 0 r
.48259 .6297 m .48106 .63034 L .48217 .62945 L F
.142 0 0 r
.48217 .62945 m .47841 .63067 L .48032 .63085 L F
.011 0 0 r
.48106 .63034 m .47916 .63113 L .48038 .63045 L F
.48106 .63034 m .48038 .63045 L .48217 .62945 L F
0 0 0 r
.47841 .63067 m .4778 .63119 L .47778 .63113 L F
.4778 .63119 m .47633 .63244 L .47778 .63113 L F
.47778 .63113 m .47669 .63116 L .47777 .63109 L F
.47778 .63113 m .4756 .63182 L .47669 .63116 L F
.288 .045 .361 r
.22668 .63404 m .22508 .63505 L .22749 .63199 L F
.585 .417 .62 r
.22668 .63404 m .22438 .63708 L .22508 .63505 L F
0 0 0 r
.61305 .46215 m .61235 .46194 L .61151 .46372 L F
0 0 .315 r
.61305 .46215 m .61151 .46372 L .61204 .46569 L F
.724 .637 .761 r
.73724 .41947 m .74085 .41968 L .73985 .41645 L F
.618 .678 .885 r
.74085 .41968 m .74228 .41646 L .73985 .41645 L F
.74085 .41968 m .74353 .41935 L .74228 .41646 L F
.57 .344 .533 r
.74085 .41968 m .74353 .42148 L .74353 .41935 L F
.74085 .41968 m .74078 .42213 L .74353 .42148 L F
.356 .155 .464 r
.2026 .62928 m .20439 .62865 L .20474 .62622 L F
.511 .331 .573 r
.20211 .63173 m .20439 .62865 L .2026 .62928 L F
.802 .698 .75 r
.52156 .52861 m .52272 .53204 L .52083 .53111 L F
.884 .812 .772 r
.52272 .53204 m .51901 .53408 L .52083 .53111 L F
.668 .714 .883 r
.7023 .41342 m .70591 .41418 L .70471 .41268 L F
.689 .736 .887 r
.70591 .41418 m .70705 .41234 L .70471 .41268 L F
.70591 .41418 m .70842 .41337 L .70705 .41234 L F
.636 .735 .92 r
.6658 .40182 m .66937 .40311 L .66804 .40136 L F
.005 .384 .844 r
.66804 .40136 m .66937 .40311 L .6712 .4038 L F
.667 .702 .874 r
.52415 .69631 m .52507 .6981 L .52718 .69675 L F
.344 .341 .713 r
.46412 .5756 m .46468 .57917 L .46672 .57747 L F
.773 .532 .571 r
.46468 .57917 m .46606 .58163 L .46672 .57747 L F
.46468 .57917 m .46513 .58163 L .46606 .58163 L F
.6 .424 .616 r
.22438 .63708 m .22181 .64007 L .22267 .63779 L F
.287 0 0 r
.17508 .55773 m .17229 .55922 L .17114 .5587 L F
0 0 0 r
.17663 .55762 m .17229 .55922 L .17508 .55773 L F
.706 .72 .86 r
.73258 .40857 m .72894 .40796 L .73127 .40686 L F
.766 .749 .838 r
.73489 .40716 m .73258 .40857 L .73127 .40686 L F
.63 .89 .987 r
.72717 .41572 m .72979 .41647 L .72882 .41506 L F
.72717 .41572 m .72811 .41639 L .72979 .41647 L F
.8 .964 .913 r
.72882 .41506 m .72979 .41647 L .73289 .41317 L F
.734 .781 .891 r
.72979 .41647 m .73432 .41489 L .73289 .41317 L F
.808 .821 .861 r
.66968 .42164 m .67368 .42081 L .67258 .41958 L F
.718 .878 .956 r
.67258 .41958 m .67368 .42081 L .67589 .41936 L F
.982 .878 .652 r
.62717 .47423 m .62916 .47269 L .62838 .47181 L F
.62717 .47423 m .6283 .47526 L .62916 .47269 L F
.848 .966 .878 r
.62838 .47181 m .62916 .47269 L .63186 .46993 L F
.715 .321 .301 r
.51843 .56721 m .51701 .56898 L .51489 .56677 L F
.351 .137 .443 r
.44597 .59325 m .44353 .59622 L .4438 .59396 L F
.381 0 0 r
.40144 .63167 m .40538 .63284 L .40311 .63308 L F
.483 .246 .478 r
.25349 .58642 m .25375 .59004 L .25148 .59032 L F
.343 .151 .47 r
.25623 .58428 m .25349 .58642 L .25446 .58491 L F
.25623 .58428 m .25608 .58657 L .25349 .58642 L F
.427 .205 .473 r
.25575 .58943 m .25349 .58642 L .25608 .58657 L F
.25575 .58943 m .25375 .59004 L .25349 .58642 L F
.515 .075 .141 r
.45022 .63832 m .44918 .6402 L .44644 .64002 L F
0 0 0 r
.45256 .63648 m .45199 .63708 L .45022 .63832 L F
.45083 .63911 m .45022 .63832 L .45199 .63708 L F
.45083 .63911 m .44918 .6402 L .45022 .63832 L F
.494 .878 .969 r
.45078 .58672 m .44837 .5874 L .44737 .58717 L F
.595 .809 .982 r
.54489 .66692 m .54689 .66794 L .54901 .66712 L F
.69 .536 .673 r
.41335 .59411 m .41358 .59685 L .41126 .59643 L F
.675 .525 .673 r
.41602 .59395 m .41358 .59685 L .41335 .59411 L F
.415 .686 .974 r
.69258 .41014 m .69566 .4113 L .69507 .41007 L F
.559 .692 .929 r
.69566 .4113 m .69756 .40942 L .69507 .41007 L F
.69566 .4113 m .69839 .41095 L .69756 .40942 L F
.817 .996 .768 r
.20278 .65885 m .20016 .66067 L .20014 .66174 L F
0 0 0 r
.20362 .65855 m .20278 .65885 L .20503 .65844 L F
.20362 .65855 m .20016 .66067 L .20278 .65885 L F
.498 .109 .234 r
.49281 .62303 m .49214 .62565 L .4902 .62519 L F
.054 .162 .66 r
.49222 .62049 m .49385 .62263 L .49281 .62303 L F
.298 .787 .893 r
.49037 .62535 m .49248 .62505 L .49053 .62524 L F
.592 .358 .531 r
.49385 .62263 m .49457 .62476 L .49214 .62565 L F
.298 .787 .893 r
.49248 .62505 m .49457 .62476 L .49262 .62499 L F
.49248 .62505 m .49262 .62499 L .49053 .62524 L F
.592 .358 .531 r
.49385 .62263 m .49247 .62505 L .49281 .62303 L F
.49247 .62505 m .49214 .62565 L .49227 .62514 L F
.49247 .62505 m .49227 .62514 L .49281 .62303 L F
.827 .993 .86 r
.50249 .72092 m .49978 .7237 L .50039 .72203 L F
.638 .804 .963 r
.50039 .72203 m .49978 .7237 L .50302 .72281 L F
.803 .773 .826 r
.53329 .51467 m .53413 .517 L .53276 .51511 L F
.819 .816 .847 r
.52962 .52297 m .5265 .52303 L .52787 .52176 L F
.271 0 .277 r
.60959 .49381 m .61221 .49092 L .61175 .49301 L F
.271 .015 .329 r
.61221 .49092 m .61418 .48996 L .61175 .49301 L F
.756 .749 .846 r
.62532 .45502 m .62186 .45455 L .62467 .4522 L F
.886 .809 .767 r
.62532 .45502 m .62182 .45698 L .62186 .45455 L F
.62532 .45502 m .62387 .4581 L .62182 .45698 L F
.442 0 .02 r
.40804 .64096 m .40649 .64255 L .40404 .64255 L F
.703 .267 .212 r
.40804 .64096 m .41022 .64303 L .40649 .64255 L F
.739 .627 .735 r
.57758 .49019 m .58116 .49067 L .57996 .48728 L F
.74 .623 .73 r
.57758 .49019 m .5788 .49351 L .58116 .49067 L F
.669 .519 .671 r
.5788 .49351 m .58155 .49325 L .58116 .49067 L F
.501 .4 .672 r
.58116 .49067 m .58369 .49253 L .5836 .49042 L F
.58116 .49067 m .58155 .49325 L .58369 .49253 L F
.996 .789 .432 r
.51636 .54842 m .51722 .54994 L .51678 .55182 L F
.717 .972 .929 r
.68046 .41112 m .68184 .40908 L .68305 .41073 L F
.68046 .41112 m .67982 .41054 L .68184 .40908 L F
.292 .751 .951 r
.58051 .61915 m .58476 .61969 L .58196 .62053 L F
.58051 .61915 m .58337 .61888 L .58476 .61969 L F
.846 .64 .624 r
.58337 .61888 m .58664 .61703 L .58476 .61969 L F
.489 .633 .917 r
.58805 .62097 m .58476 .61969 L .58664 .61703 L F
.107 .258 .737 r
.38701 .64081 m .38792 .64064 L .38671 .63731 L F
.4 .767 .993 r
.20681 .54079 m .20864 .54053 L .2109 .54163 L F
.233 .713 .934 r
.20864 .54053 m .21312 .5412 L .2109 .54163 L F
.589 .421 .621 r
.22902 .63104 m .22668 .63404 L .22749 .63199 L F
.467 .333 .615 r
.24896 .59413 m .24927 .59647 L .2474 .59664 L F
.529 .351 .584 r
.24927 .59647 m .24741 .59902 L .2474 .59664 L F
.768 .939 .594 r
.58218 .45241 m .58 .45557 L .58086 .45361 L F
.903 .985 .758 r
.58431 .44925 m .58218 .45241 L .58241 .45006 L F
.908 .947 .595 r
.58218 .45241 m .58086 .45361 L .58241 .45006 L F
.469 .799 .999 r
.20507 .53983 m .20471 .54119 L .20298 .54016 L F
.20507 .53983 m .20681 .54079 L .20471 .54119 L F
.64 .604 .798 r
.73152 .43374 m .73538 .43701 L .73419 .43369 L F
.011 0 0 r
.73156 .43805 m .73447 .43746 L .73538 .43701 L F
.728 .699 .823 r
.73419 .43369 m .73538 .43701 L .73734 .43464 L F
.513 .385 .643 r
.73538 .43701 m .73783 .4368 L .73734 .43464 L F
.398 .824 .657 r
.73538 .43701 m .73666 .43614 L .73783 .4368 L F
.73538 .43701 m .73447 .43746 L .73666 .43614 L F
.78 .334 0 r
.52045 .57553 m .51842 .57232 L .52019 .57331 L F
.855 .467 .31 r
.52332 .5763 m .52045 .57553 L .52019 .57331 L F
.574 .618 .858 r
.70842 .41337 m .71231 .41615 L .7112 .41295 L F
.6 .601 .824 r
.71231 .41615 m .71447 .41349 L .7112 .41295 L F
.71231 .41615 m .7146 .41553 L .71447 .41349 L F
.579 .657 .89 r
.71231 .41615 m .71554 .41702 L .7146 .41553 L F
.433 0 0 r
.41127 .63408 m .4137 .6342 L .41546 .6327 L F
.26 0 0 r
.41546 .6327 m .41697 .63312 L .41734 .63195 L F
.41546 .6327 m .4137 .6342 L .41697 .63312 L F
.856 .944 .876 r
.62512 .47914 m .62771 .47637 L .62555 .47618 L F
.919 .95 .608 r
.62378 .48023 m .62512 .47914 L .62555 .47618 L F
.619 .825 .98 r
.67949 .41673 m .68186 .41688 L .6807 .41568 L F
.903 .985 .758 r
.58431 .44925 m .58241 .45006 L .58365 .44853 L F
.817 .982 .887 r
.58431 .44925 m .58486 .447 L .58673 .44629 L F
.58431 .44925 m .58365 .44853 L .58486 .447 L F
.583 .712 .932 r
.69625 .40084 m .69378 .40148 L .6932 .4001 L F
.726 .616 .735 r
.57518 .49314 m .5788 .49351 L .57758 .49019 L F
.613 .409 .581 r
.57617 .49651 m .5788 .49351 L .57518 .49314 L F
.57617 .49651 m .57887 .49612 L .5788 .49351 L F
.704 .515 .63 r
.57887 .49612 m .58155 .49325 L .5788 .49351 L F
.957 .649 .408 r
.45485 .56618 m .45536 .56879 L .45653 .56762 L F
.611 .914 .979 r
.45653 .56762 m .45752 .5662 L .45903 .56671 L F
.454 .709 .977 r
.45485 .56618 m .45752 .5662 L .45653 .56762 L F
.575 .661 .896 r
.71551 .40468 m .71299 .40522 L .71207 .40331 L F
.857 .644 .612 r
.63975 .45401 m .6425 .45604 L .63996 .45188 L F
.875 .741 .229 r
.66491 .45487 m .66472 .45697 L .66431 .4544 L F
.792 .983 .717 r
.58 .45557 m .57841 .45654 L .58086 .45361 L F
0 0 0 r
.48849 .61856 m .48603 .62022 L .4876 .61927 L F
.638 .149 .075 r
.4876 .61927 m .49085 .62032 L .48849 .61856 L F
.462 .372 .668 r
.54045 .56123 m .54111 .56406 L .53871 .56432 L F
.63 .561 .759 r
.54111 .56406 m .53885 .56703 L .53871 .56432 L F
.441 .575 .892 r
.64915 .41471 m .64783 .41683 L .64727 .41485 L F
.444 .579 .894 r
.64915 .41471 m .64998 .41686 L .64783 .41683 L F
.323 .794 .924 r
.42755 .56646 m .43009 .56634 L .42886 .56754 L F
.234 0 0 r
.18313 .55477 m .18146 .55615 L .17996 .55624 L F
.481 .033 .107 r
.18531 .55445 m .18146 .55615 L .18313 .55477 L F
.766 .749 .838 r
.73489 .40716 m .73127 .40686 L .73416 .40453 L F
.622 .719 .916 r
.73822 .40541 m .73489 .40716 L .73416 .40453 L F
.232 0 0 r
.7392 .44084 m .74088 .44111 L .73876 .44196 L F
.7392 .44084 m .742 .44014 L .74088 .44111 L F
.603 .813 .981 r
.69133 .39854 m .69054 .40103 L .68867 .39924 L F
.69133 .39854 m .6932 .4001 L .69054 .40103 L F
.58 .385 .582 r
.59119 .50778 m .59103 .51048 L .58874 .51079 L F
.6 .332 .483 r
.59119 .50778 m .59336 .50999 L .59103 .51048 L F
.59119 .50778 m .59357 .50793 L .59336 .50999 L F
.494 .294 .538 r
.58082 .51743 m .58311 .5189 L .58038 .51923 L F
.58082 .51743 m .58317 .5166 L .58311 .5189 L F
.479 .394 .682 r
.36118 .61167 m .36293 .60774 L .36113 .6085 L F
.677 .611 .774 r
.53541 .7045 m .53837 .70314 L .53473 .70243 L F
0 .1 .654 r
.54901 .66712 m .55094 .66937 L .55095 .67032 L F
.934 .708 .571 r
.54874 .67234 m .55095 .67032 L .55094 .66937 L F
.54874 .67234 m .55058 .67337 L .55095 .67032 L F
0 0 0 r
.6161 .48891 m .61706 .4871 L .61881 .48616 L F
.628 .492 .677 r
.73748 .41727 m .73985 .41645 L .7388 .41538 L F
.73748 .41727 m .73724 .41947 L .73985 .41645 L F
0 .246 .761 r
.65211 .41841 m .65174 .41954 L .64998 .41686 L F
0 0 .45 r
.65254 .41993 m .65174 .41954 L .65211 .41841 L F
.012 .264 .766 r
.65211 .41841 m .64915 .41471 L .65219 .41443 L F
.766 .463 0 r
.65148 .41657 m .65254 .41993 L .65211 .41841 L F
0 0 .465 r
.6526 .41905 m .65254 .41993 L .65148 .41657 L F
.755 .71 .175 r
.65259 .41905 m .65254 .41993 L .6526 .41905 L F
0 0 .45 r
.65254 .41993 m .65244 .42127 L .65174 .41954 L F
.755 .71 .175 r
.65217 .42145 m .65254 .41993 L .65259 .41905 L F
0 0 .45 r
.65254 .41993 m .65282 .42218 L .65244 .42127 L F
.689 .363 .418 r
.58655 .49168 m .58722 .49043 L .5836 .49042 L F
.631 .296 .386 r
.58655 .49168 m .58978 .49233 L .58722 .49043 L F
.601 .317 .457 r
.58978 .49233 m .58975 .49037 L .58722 .49043 L F
.078 .589 .886 r
.6385 .43148 m .64116 .43227 L .64058 .43056 L F
.63 .081 0 r
.64116 .43227 m .64123 .43312 L .64058 .43056 L F
.64116 .43227 m .64287 .43369 L .64123 .43312 L F
.961 .902 .531 r
.6103 .43178 m .61097 .43016 L .61049 .43016 L F
.6103 .43178 m .61049 .43016 L .61045 .43023 L F
.61049 .43016 m .61098 .42606 L .61045 .43023 L F
.616 .702 .906 r
.6102 .43016 m .61039 .43032 L .61045 .43023 L F
.592 .027 0 r
.61045 .43023 m .61373 .43242 L .61078 .43291 L F
.616 .702 .906 r
.61047 .43039 m .61192 .4316 L .61045 .43023 L F
.61039 .43032 m .61047 .43039 L .61045 .43023 L F
.44 0 0 r
.6076 .432 m .60942 .4336 L .60949 .43229 L F
.60589 .43173 m .60717 .43241 L .6076 .432 L F
.60717 .43241 m .60942 .4336 L .6076 .432 L F
.514 .595 .873 r
.61045 .43023 m .61078 .43291 L .6103 .43178 L F
.616 .702 .906 r
.60965 .43017 m .61192 .4316 L .6102 .43016 L F
.126 0 .159 r
.60967 .43045 m .6096 .4301 L .60964 .43015 L F
.616 .702 .906 r
.6098 .43038 m .60949 .43229 L .61192 .4316 L F
.60949 .42997 m .60968 .43017 L .6102 .43016 L F
.126 0 .159 r
.6098 .43038 m .60972 .42986 L .61024 .43016 L F
.60975 .4304 m .60974 .4303 L .6098 .43038 L F
.60974 .4303 m .60972 .42986 L .6098 .43038 L F
.616 .702 .906 r
.60944 .42996 m .60957 .43007 L .60949 .42997 L F
.60957 .43007 m .60968 .43017 L .60949 .42997 L F
.6098 .43037 m .6098 .43038 L .6098 .43038 L F
.6098 .43038 m .60949 .43229 L .6098 .43038 L F
.60974 .4303 m .61192 .4316 L .60965 .43017 L F
.6098 .43037 m .6098 .43038 L .60974 .4303 L F
.6098 .43038 m .61192 .4316 L .60974 .4303 L F
.126 0 .159 r
.60984 .43191 m .60975 .4304 L .60983 .4304 L F
.61034 .43107 m .60983 .4304 L .61072 .43043 L F
.60984 .43191 m .60983 .4304 L .61034 .43107 L F
.60975 .4304 m .61024 .43016 L .61072 .43043 L F
.60984 .43191 m .60965 .43047 L .60967 .43045 L F
.60965 .43047 m .6096 .4301 L .60967 .43045 L F
.44 0 0 r
.60589 .43173 m .60808 .43311 L .60942 .4336 L F
.707 .759 .893 r
.6076 .432 m .60949 .43229 L .60907 .43084 L F
.616 .702 .906 r
.60907 .43084 m .60949 .43229 L .6098 .43037 L F
.126 0 .159 r
.60984 .43191 m .60808 .43311 L .60932 .43064 L F
.60964 .43039 m .60932 .43064 L .6096 .4301 L F
.60984 .43191 m .60932 .43064 L .60964 .43039 L F
.707 .759 .893 r
.60589 .43173 m .6076 .432 L .60904 .43073 L F
.6076 .432 m .60907 .43084 L .60904 .43073 L F
.534 .227 .393 r
.6075 .43095 m .60757 .4312 L .60589 .43173 L F
.60947 .42998 m .60914 .43072 L .6075 .43095 L F
.60914 .43072 m .60808 .43311 L .6075 .43095 L F
.616 .702 .906 r
.60876 .42977 m .60947 .42998 L .60944 .42996 L F
.60876 .42977 m .61045 .43023 L .61062 .42799 L F
.712 .962 .943 r
.60972 .42986 m .60947 .42998 L .60876 .42977 L F
.60947 .42998 m .60589 .43173 L .60876 .42977 L F
.616 .702 .906 r
.60876 .42977 m .60968 .43017 L .60947 .42998 L F
.707 .759 .893 r
.60589 .43173 m .60904 .43073 L .60876 .42977 L F
.534 .227 .393 r
.60757 .4312 m .60808 .43311 L .60589 .43173 L F
.616 .702 .906 r
.60876 .42977 m .60904 .43073 L .6098 .43037 L F
.60904 .43073 m .60907 .43084 L .6093 .43069 L F
.60904 .43073 m .6093 .43069 L .6098 .43037 L F
.60945 .43017 m .6098 .43037 L .60965 .43017 L F
.126 0 .159 r
.60964 .43015 m .6096 .4301 L .60963 .43004 L F
.60972 .42995 m .60963 .43004 L .60972 .42986 L F
.60984 .43191 m .60963 .43004 L .60972 .42995 L F
.534 .227 .393 r
.60972 .42986 m .6096 .4301 L .60947 .42998 L F
.6096 .4301 m .60808 .43311 L .60947 .42998 L F
.616 .702 .906 r
.60876 .42977 m .60945 .43017 L .60968 .43017 L F
.961 .902 .531 r
.61049 .43016 m .61141 .42909 L .61098 .42606 L F
.61097 .43016 m .61141 .42909 L .61049 .43016 L F
.304 0 .192 r
.20731 .62369 m .20634 .62553 L .20938 .62304 L F
.03 0 .19 r
.24336 .60565 m .24257 .60791 L .24132 .60864 L F
.421 .227 .51 r
.24293 .61032 m .24132 .60864 L .24257 .60791 L F
.24293 .61032 m .2409 .61109 L .24132 .60864 L F
.842 .943 .888 r
.51507 .55288 m .5128 .55263 L .51395 .55008 L F
.51507 .55288 m .51197 .55531 L .5128 .55263 L F
.323 .155 .492 r
.51678 .55182 m .51507 .55288 L .51395 .55008 L F
.51678 .55182 m .51669 .55421 L .51507 .55288 L F
.567 .937 .9 r
.51678 .55182 m .51507 .55288 L .51669 .55421 L F
.354 .105 .392 r
.23008 .57278 m .23009 .57538 L .23185 .57214 L F
.23008 .57278 m .22912 .57606 L .23009 .57538 L F
.314 .027 .307 r
.23238 .62732 m .22902 .63104 L .22933 .6289 L F
.337 0 0 r
.39981 .58148 m .40216 .58122 L .40373 .57952 L F
.352 0 .105 r
.40216 .58122 m .40586 .57868 L .40373 .57952 L F
.525 .451 .716 r
.53202 .5778 m .52997 .5778 L .52893 .57639 L F
.713 .513 .617 r
.53242 .58119 m .52997 .5778 L .53055 .57989 L F
.53242 .58119 m .53095 .57933 L .53084 .579 L F
.465 .374 .668 r
.53104 .5796 m .53055 .57989 L .53095 .57933 L F
.525 .451 .716 r
.53095 .57933 m .53055 .57989 L .52997 .5778 L F
0 0 0 r
.53104 .5796 m .53242 .58119 L .53055 .57989 L F
.713 .513 .617 r
.53216 .58122 m .52931 .5816 L .52989 .57827 L F
.53135 .57996 m .52989 .57827 L .52997 .5778 L F
.53216 .58122 m .52989 .57827 L .53135 .57996 L F
0 0 0 r
.53418 .57769 m .53242 .58119 L .53104 .5796 L F
.465 .374 .668 r
.53418 .57769 m .53104 .5796 L .53202 .5778 L F
.53104 .5796 m .53095 .57933 L .53202 .5778 L F
.713 .513 .617 r
.53242 .58119 m .53216 .58122 L .53095 .57933 L F
.53084 .579 m .53095 .57933 L .52997 .5778 L F
.525 .451 .716 r
.53202 .5778 m .53095 .57933 L .52997 .5778 L F
.554 .309 .498 r
.75503 .42841 m .75514 .43111 L .75222 .43125 L F
.508 .83 1 r
.75373 .42749 m .75773 .42787 L .75503 .42841 L F
.396 .191 .48 r
.75733 .42994 m .75503 .42841 L .75773 .42787 L F
.75733 .42994 m .75514 .43111 L .75503 .42841 L F
.615 .367 .519 r
.57621 .51976 m .576 .52268 L .57202 .52267 L F
.621 .35 .485 r
.57621 .51976 m .57794 .52195 L .576 .52268 L F
.57621 .51976 m .57796 .5198 L .57794 .52195 L F
.003 0 0 r
.17114 .5587 m .16707 .56019 L .16869 .55951 L F
.866 .499 .353 r
.52332 .5763 m .522 .57762 L .52045 .57553 L F
.918 .591 .408 r
.5235 .57783 m .522 .57762 L .52332 .5763 L F
.661 .614 .791 r
.46273 .5699 m .45903 .56671 L .46103 .56644 L F
.61 .666 .879 r
.46524 .56921 m .46273 .5699 L .46103 .56644 L F
.596 .565 .79 r
.46524 .56921 m .46572 .57162 L .46273 .5699 L F
.678 .449 .566 r
.46609 .57382 m .46273 .5699 L .46572 .57162 L F
.46609 .57382 m .4633 .57404 L .46273 .5699 L F
.048 0 .416 r
.23326 .62467 m .23238 .62732 L .23168 .62557 L F
.396 .157 .431 r
.59666 .50562 m .59916 .50236 L .59896 .50501 L F
.504 .191 .37 r
.59916 .50236 m .60127 .50427 L .59896 .50501 L F
.59916 .50236 m .60155 .50186 L .60127 .50427 L F
.171 0 .227 r
.60765 .44475 m .60487 .44834 L .60532 .44665 L F
.859 .739 .729 r
.63504 .46267 m .63872 .46069 L .6359 .46047 L F
.63504 .46267 m .63685 .464 L .63872 .46069 L F
.646 .288 .351 r
.59285 .4926 m .59297 .48989 L .58975 .49037 L F
.381 .078 .321 r
.59538 .48936 m .59297 .48989 L .59285 .4926 L F
.334 .13 .447 r
.2567 .58178 m .25623 .58428 L .25446 .58491 L F
.654 .778 .94 r
.5487 .68037 m .54971 .67812 L .5475 .67911 L F
.5487 .68037 m .55137 .6794 L .54971 .67812 L F
.798 .707 .764 r
.5708 .499 m .57383 .49963 L .5731 .4964 L F
.795 .626 .672 r
.57048 .50165 m .57383 .49963 L .5708 .499 L F
.57048 .50165 m .57428 .50232 L .57383 .49963 L F
.629 .494 .679 r
.57383 .49963 m .57617 .49651 L .5731 .4964 L F
.57383 .49963 m .57647 .49907 L .57617 .49651 L F
.635 .518 .703 r
.57383 .49963 m .57428 .50232 L .57647 .49907 L F
.603 .364 .527 r
.23017 .5634 m .23307 .56098 L .23053 .56145 L F
.392 .808 .61 r
.61747 .40475 m .61913 .40367 L .61967 .40336 L F
0 0 0 r
.61747 .40475 m .61648 .40607 L .61913 .40367 L F
.087 0 0 r
.41224 .59694 m .41126 .59643 L .41358 .59685 L F
.41224 .59694 m .40951 .59862 L .41126 .59643 L F
.841 .638 .628 r
.4411 .60029 m .44251 .60264 L .43916 .60211 L F
.73 .264 .143 r
.44251 .60264 m .44036 .60371 L .43916 .60211 L F
.345 .441 .816 r
.44436 .60084 m .44251 .60264 L .4411 .60029 L F
.583 .928 .735 r
.44436 .60084 m .44036 .60371 L .44251 .60264 L F
.926 .559 .303 r
.54687 .66162 m .54752 .66405 L .54892 .66452 L F
.96 .687 .474 r
.54752 .66405 m .54901 .66712 L .54892 .66452 L F
.639 .706 .895 r
.72121 .40858 m .71669 .40793 L .71923 .40712 L F
.653 .653 .837 r
.71923 .40712 m .7229 .40801 L .72121 .40858 L F
.73 .984 .779 r
.58952 .44372 m .58673 .44629 L .58782 .44444 L F
.731 .987 .797 r
.58673 .44629 m .58486 .447 L .58782 .44444 L F
.744 .583 .676 r
.20016 .66067 m .20009 .66346 L .20014 .66174 L F
.872 .6 .075 r
.20014 .66174 m .20009 .66346 L .20057 .66417 L F
.764 .498 .531 r
.6682 .43354 m .67028 .43149 L .66839 .43094 L F
.6682 .43354 m .67047 .4338 L .67028 .43149 L F
.59 .927 .96 r
.17082 .54335 m .17233 .54247 L .17422 .54248 L F
.116 0 .07 r
.17082 .54335 m .17191 .54362 L .17263 .54229 L F
.713 .952 .952 r
.17422 .54248 m .17242 .54247 L .17446 .54107 L F
.158 0 .148 r
.1741 .54117 m .17371 .54271 L .17435 .5411 L F
.042 0 0 r
.17446 .54107 m .17309 .54145 L .17435 .5411 L F
.17446 .54107 m .17381 .54139 L .17309 .54145 L F
.158 0 .148 r
.17309 .54145 m .17327 .54181 L .17381 .54139 L F
.116 0 .07 r
.17082 .54335 m .17233 .54247 L .17309 .54145 L F
.042 0 0 r
.17381 .54139 m .17165 .54247 L .17309 .54145 L F
.158 0 .148 r
.17309 .54145 m .17381 .54139 L .1741 .54117 L F
.713 .952 .952 r
.17233 .54247 m .17267 .54222 L .17446 .54107 L F
.17267 .54222 m .17385 .54137 L .17405 .54127 L F
.17267 .54222 m .17405 .54127 L .17446 .54107 L F
.17242 .54247 m .17292 .54208 L .17446 .54107 L F
.158 0 .148 r
.17327 .54181 m .17191 .54362 L .17371 .54271 L F
.17309 .54145 m .17267 .54222 L .17327 .54181 L F
.17267 .54222 m .17191 .54362 L .17327 .54181 L F
.17327 .54181 m .17371 .54271 L .1741 .54117 L F
.713 .952 .952 r
.17242 .54247 m .17233 .54247 L .17292 .54208 L F
.116 0 .07 r
.17233 .54247 m .17267 .54222 L .17309 .54145 L F
.577 .913 .688 r
.17309 .54145 m .17165 .54247 L .17082 .54335 L F
.713 .952 .952 r
.17233 .54247 m .17165 .54247 L .17385 .54137 L F
.116 0 .07 r
.17233 .54247 m .17263 .54229 L .17267 .54222 L F
.59 .927 .96 r
.17082 .54335 m .17165 .54247 L .17233 .54247 L F
.713 .952 .952 r
.17422 .54248 m .17446 .54107 L .17664 .54173 L F
.847 .808 .812 r
.52084 .53553 m .51877 .5384 L .51675 .53714 L F
.856 .804 .799 r
.51675 .53714 m .51877 .5384 L .5175 .53986 L F
.828 .969 .892 r
.6988 .46179 m .69825 .46404 L .70094 .46178 L F
.843 .98 .871 r
.6988 .46179 m .69747 .46335 L .69825 .46404 L F
.548 .295 .484 r
.55397 .6203 m .5587 .62155 L .55641 .62036 L F
.598 .105 .056 r
.55641 .62036 m .55749 .62104 L .5597 .6205 L F
.548 .295 .484 r
.55397 .6203 m .55859 .62161 L .55822 .62142 L F
.488 .264 .5 r
.55393 .62556 m .55862 .62162 L .55469 .62372 L F
.598 .105 .056 r
.55749 .62104 m .55883 .62174 L .5597 .6205 L F
.488 .264 .5 r
.55862 .62162 m .5587 .62155 L .55859 .62161 L F
.55862 .62162 m .55859 .62161 L .55469 .62372 L F
.53 .327 .55 r
.55865 .62163 m .55876 .62183 L .5587 .62155 L F
.55627 .62519 m .55876 .62183 L .55865 .62163 L F
.598 .105 .056 r
.55866 .62165 m .55876 .62183 L .55883 .62174 L F
.55859 .62161 m .55876 .62183 L .55866 .62165 L F
.55749 .62104 m .55836 .62158 L .55859 .62161 L F
.488 .264 .5 r
.55393 .62556 m .55627 .62519 L .5587 .62155 L F
.598 .105 .056 r
.55836 .62158 m .55876 .62183 L .55859 .62161 L F
.548 .295 .484 r
.55397 .6203 m .55469 .62372 L .55859 .62161 L F
.55822 .62142 m .55859 .62161 L .5587 .62155 L F
.461 .807 .998 r
.6794 .39859 m .67784 .40008 L .67579 .39905 L F
.6794 .39859 m .6804 .39966 L .67784 .40008 L F
.688 .691 .847 r
.71806 .40395 m .71669 .40793 L .71551 .40468 L F
.71806 .40395 m .71923 .40712 L .71669 .40793 L F
.514 .613 .889 r
.22567 .56766 m .22632 .56565 L .224 .56645 L F
.22567 .56766 m .22808 .56772 L .22632 .56565 L F
.509 .899 .947 r
.6993 .45518 m .69575 .45568 L .69859 .45451 L F
.719 .966 .938 r
.70107 .45371 m .6993 .45518 L .70047 .45317 L F
.721 .968 .936 r
.70047 .45317 m .6993 .45518 L .69859 .45451 L F
.363 .495 .858 r
.22314 .55526 m .22395 .55281 L .22162 .55317 L F
.22314 .55526 m .22443 .55465 L .22395 .55281 L F
.398 .283 .605 r
.22294 .55774 m .22443 .55465 L .22314 .55526 L F
.875 .762 .734 r
.58097 .48056 m .57905 .48397 L .58199 .48444 L F
.862 .792 .78 r
.57905 .48397 m .57996 .48728 L .58199 .48444 L F
.363 .142 .438 r
.60269 .48075 m .60063 .48177 L .60034 .48389 L F
.999 .839 .53 r
.53088 .67256 m .53183 .67386 L .53044 .67514 L F
.514 .786 .994 r
.53088 .67256 m .53454 .67352 L .53183 .67386 L F
.135 0 0 r
.53316 .67428 m .53183 .67386 L .53044 .67514 L F
.53316 .67428 m .53454 .67352 L .53183 .67386 L F
.41 .067 .27 r
.46995 .62924 m .46677 .63132 L .46919 .63063 L F
.467 .299 .569 r
.46995 .62924 m .47196 .62859 L .47195 .62605 L F
.253 0 .109 r
.46919 .63063 m .47196 .62859 L .46995 .62924 L F
.596 .561 .786 r
.56251 .62197 m .56132 .626 L .56025 .62248 L F
.56251 .62197 m .56357 .6254 L .56132 .626 L F
.597 .481 .692 r
.54423 .5494 m .54476 .55187 L .5422 .55243 L F
.514 .387 .645 r
.54477 .55451 m .5422 .55243 L .54476 .55187 L F
.54477 .55451 m .54249 .55532 L .5422 .55243 L F
.929 .894 .773 r
.61292 .41313 m .61365 .4087 L .613 .4108 L F
.261 0 .019 r
.36642 .59596 m .3686 .59547 L .36981 .59373 L F
.183 0 0 r
.3686 .59547 m .37215 .59333 L .36981 .59373 L F
.091 .643 .811 r
.61565 .4591 m .61268 .45918 L .61228 .45891 L F
.811 .58 .589 r
.47077 .57314 m .46982 .57543 L .47385 .57602 L F
.375 .782 .982 r
.46982 .57543 m .47196 .57557 L .47385 .57602 L F
.136 .417 .862 r
.47437 .57436 m .47385 .57602 L .47196 .57557 L F
.47437 .57436 m .47616 .57743 L .47385 .57602 L F
.463 .31 .588 r
.21185 .61989 m .21386 .61668 L .21218 .61739 L F
.364 .148 .447 r
.60761 .47492 m .60557 .47579 L .60533 .47802 L F
.583 .044 0 r
.61657 .4137 m .61562 .41455 L .61292 .41313 L F
.555 .012 0 r
.61887 .41487 m .61562 .41455 L .61657 .4137 L F
.435 .566 .887 r
.66603 .45911 m .66666 .46108 L .66788 .4591 L F
.501 .652 .926 r
.66666 .46108 m .66963 .46104 L .66788 .4591 L F
.489 .334 .596 r
.39092 .61336 m .38946 .61202 L .39135 .61113 L F
.39092 .61336 m .38923 .61433 L .38946 .61202 L F
.864 .734 .718 r
.73375 .42154 m .73541 .42231 L .73724 .41947 L F
.188 .695 .903 r
.22666 .55819 m .22464 .55764 L .22294 .55774 L F
.798 .638 .683 r
.22355 .56074 m .22666 .55819 L .22294 .55774 L F
.22355 .56074 m .22664 .56158 L .22666 .55819 L F
.155 0 0 r
.22944 .55706 m .22464 .55764 L .22666 .55819 L F
.436 .549 .872 r
.53028 .57425 m .53202 .5778 L .52893 .57639 L F
.546 0 0 r
.19316 .67192 m .19467 .67286 L .19223 .67215 L F
.784 .974 .914 r
.6988 .46179 m .70094 .46178 L .70287 .45995 L F
.482 .278 .526 r
.36431 .59664 m .36644 .59847 L .36642 .59596 L F
.36431 .59664 m .36407 .59911 L .36644 .59847 L F
.34 .247 .603 r
.20474 .62622 m .20655 .62816 L .20634 .62553 L F
.483 .264 .505 r
.20474 .62622 m .20439 .62865 L .20655 .62816 L F
.20474 .62622 m .20439 .62865 L .20655 .62816 L F
.644 .567 .753 r
.63919 .44646 m .63617 .44863 L .63505 .44519 L F
.174 0 0 r
.72584 .43942 m .72831 .43865 L .72933 .43712 L F
0 0 0 r
.72933 .43712 m .73027 .43718 L .73156 .43805 L F
.72933 .43712 m .72831 .43865 L .73027 .43718 L F
.589 .246 .355 r
.57094 .50408 m .57428 .50232 L .57048 .50165 L F
.57094 .50408 m .57377 .50408 L .57428 .50232 L F
.521 .372 .619 r
.57647 .49907 m .57428 .50232 L .57663 .50168 L F
.384 .056 .282 r
.57428 .50232 m .57377 .50408 L .57663 .50168 L F
.796 .984 .717 r
.41413 .59514 m .41358 .59685 L .41602 .59395 L F
0 0 0 r
.41805 .59318 m .41413 .59514 L .41602 .59395 L F
.805 .517 0 r
.67321 .45413 m .67287 .45247 L .67228 .45093 L F
.262 0 .168 r
.60662 .49614 m .60959 .49381 L .60882 .49521 L F
.268 0 .179 r
.60882 .49521 m .60959 .49381 L .61175 .49301 L F
.534 .282 .48 r
.58874 .51079 m .58842 .51343 L .58554 .5141 L F
.544 .273 .455 r
.58874 .51079 m .59115 .51258 L .58842 .51343 L F
.58874 .51079 m .59103 .51048 L .59115 .51258 L F
.523 .796 .995 r
.74868 .42689 m .74771 .42579 L .74493 .42642 L F
0 0 .262 r
.65641 .41368 m .65699 .41601 L .65699 .41477 L F
.412 .28 .59 r
.36178 .59968 m .36396 .60123 L .36407 .59911 L F
.36178 .59968 m .3621 .60185 L .36396 .60123 L F
.381 .37 .722 r
.39326 .60959 m .39042 .60972 L .39327 .60734 L F
.39326 .60959 m .39135 .61113 L .39042 .60972 L F
.932 .713 .584 r
.54971 .67812 m .55159 .67677 L .54976 .67571 L F
.54971 .67812 m .55137 .6794 L .55159 .67677 L F
.352 .645 .965 r
.24591 .54573 m .24575 .54733 L .24419 .54611 L F
.24591 .54573 m .24825 .54757 L .24575 .54733 L F
.977 .819 .621 r
.65304 .42798 m .65377 .42579 L .65244 .42429 L F
.491 .783 .997 r
.41314 .60407 m .41231 .60553 L .41216 .60538 L F
.41314 .60407 m .41216 .60538 L .40975 .60291 L F
.486 .682 .953 r
.41436 .60255 m .41314 .60407 L .41262 .60312 L F
.397 .366 .708 r
.41436 .60255 m .41378 .60322 L .41314 .60407 L F
.494 .109 .238 r
.40975 .60291 m .41262 .60312 L .41268 .60322 L F
.4115 .60351 m .41268 .60322 L .41314 .60407 L F
.40975 .60291 m .41268 .60322 L .4115 .60351 L F
.397 .366 .708 r
.41378 .60322 m .41239 .60484 L .41314 .60407 L F
.491 .783 .997 r
.41314 .60407 m .41473 .60512 L .41231 .60553 L F
.679 .977 .883 r
.41314 .60407 m .41231 .60553 L .41473 .60512 L F
.397 .366 .708 r
.41407 .60288 m .41322 .60666 L .41239 .60484 L F
.41436 .60255 m .41428 .60283 L .41407 .60288 L F
.41428 .60283 m .41322 .60666 L .41407 .60288 L F
.679 .977 .883 r
.41314 .60407 m .41136 .60544 L .41231 .60553 L F
0 0 0 r
.41239 .60484 m .41142 .60544 L .41136 .60544 L F
.41142 .60544 m .41063 .60592 L .41136 .60544 L F
0 .547 .72 r
.41128 .60546 m .41136 .60544 L .40848 .60525 L F
.41231 .60553 m .41136 .60544 L .41128 .60546 L F
.056 0 0 r
.60487 .44834 m .602 .45082 L .60288 .44945 L F
.806 .918 .914 r
.62422 .40988 m .62215 .41317 L .62478 .41052 L F
.62422 .40988 m .62051 .41292 L .62215 .41317 L F
.626 .398 .552 r
.57202 .52267 m .56952 .52521 L .56957 .52287 L F
.808 .971 .668 r
.21734 .57253 m .21529 .57417 L .2149 .57169 L F
.519 .542 .82 r
.21529 .57417 m .21514 .5728 L .2149 .57169 L F
.902 .497 .221 r
.21734 .57253 m .2149 .57169 L .21441 .56943 L F
.519 .542 .82 r
.21514 .5728 m .21475 .56904 L .2149 .57169 L F
.902 .497 .221 r
.21441 .56943 m .2149 .57169 L .21399 .56898 L F
.808 .971 .668 r
.21734 .57253 m .21478 .57577 L .21529 .57417 L F
.521 .332 .566 r
.53614 .56973 m .53435 .57254 L .53376 .57013 L F
.54 .425 .671 r
.5597 .6205 m .56251 .62197 L .56025 .62248 L F
.357 0 0 r
.5612 .62137 m .5597 .6205 L .55876 .62183 L F
.5612 .62137 m .56251 .62197 L .5597 .6205 L F
0 .123 .659 r
.65699 .41601 m .65803 .41933 L .6587 .41799 L F
.049 .282 .774 r
.6587 .41799 m .65803 .41933 L .66032 .4212 L F
0 .024 .58 r
.65803 .41933 m .66079 .42299 L .66032 .4212 L F
.123 0 .221 r
.63135 .44024 m .62911 .44316 L .63125 .44188 L F
0 0 .356 r
.62911 .44316 m .63025 .44404 L .63125 .44188 L F
.62911 .44316 m .62945 .44561 L .63025 .44404 L F
.781 .998 .828 r
.41413 .59514 m .41224 .59694 L .41358 .59685 L F
.847 .808 .812 r
.52084 .53553 m .51675 .53714 L .51901 .53408 L F
.741 .78 .885 r
.57626 .63594 m .57832 .63478 L .57635 .63337 L F
.329 .801 .918 r
.21312 .5412 m .21505 .54082 L .21668 .54102 L F
.054 0 0 r
.21505 .54082 m .21878 .54109 L .21668 .54102 L F
.799 .844 .384 r
.64242 .42357 m .64185 .42598 L .64099 .42821 L F
.999 .834 .506 r
.66426 .44906 m .6634 .44811 L .66381 .44541 L F
.964 .68 .254 r
.66426 .44906 m .66442 .45144 L .6634 .44811 L F
.855 .782 .779 r
.57393 .49207 m .57518 .49314 L .57416 .48985 L F
.858 .733 .724 r
.57145 .4952 m .57518 .49314 L .57393 .49207 L F
.57145 .4952 m .5731 .4964 L .57518 .49314 L F
.769 .602 .671 r
.57518 .49314 m .5731 .4964 L .57617 .49651 L F
.816 .763 .804 r
.57416 .48985 m .57518 .49314 L .57758 .49019 L F
.592 .613 .842 r
.63741 .44444 m .63505 .44519 L .63575 .44342 L F
.953 .739 .577 r
.66513 .44021 m .66384 .44069 L .66382 .4391 L F
.66513 .44021 m .66506 .44246 L .66384 .44069 L F
.626 .598 .802 r
.71554 .41702 m .71695 .4127 L .7146 .41553 L F
.71554 .41702 m .71812 .41626 L .71695 .4127 L F
.513 0 0 r
.46609 .57382 m .46293 .57383 L .46412 .5756 L F
.655 .749 .919 r
.46609 .57382 m .46412 .5756 L .46671 .57487 L F
.344 .341 .713 r
.46412 .5756 m .46672 .57747 L .46671 .57487 L F
.643 .957 .933 r
.66474 .40936 m .66146 .41043 L .6636 .40879 L F
.455 .856 .672 r
.66603 .40835 m .66474 .40936 L .6636 .40879 L F
.66603 .40835 m .66727 .40774 L .66474 .40936 L F
.897 .479 .108 r
.66251 .42847 m .66198 .42963 L .66233 .42722 L F
.66251 .42847 m .66336 .43071 L .66198 .42963 L F
.512 .141 .273 r
.42005 .64088 m .41871 .64329 L .41627 .64337 L F
.662 .304 .356 r
.42226 .64299 m .41871 .64329 L .42005 .64088 L F
.735 .724 .84 r
.5175 .53986 m .51405 .53947 L .51675 .53714 L F
.171 0 0 r
.46496 .63544 m .46091 .637 L .46214 .63664 L F
.46496 .63544 m .463 .63678 L .46091 .637 L F
.478 .023 .093 r
.46728 .63492 m .463 .63678 L .46496 .63544 L F
.618 .266 .351 r
.71511 .44465 m .71719 .44286 L .71528 .44384 L F
.71511 .44465 m .71804 .44515 L .71719 .44286 L F
.158 .036 .452 r
.71719 .44286 m .7191 .44354 L .72038 .44211 L F
.71719 .44286 m .71804 .44515 L .71912 .44355 L F
.598 .193 .245 r
.71577 .44542 m .71804 .44515 L .71511 .44465 L F
.551 .93 .83 r
.71577 .44542 m .71596 .44499 L .71907 .44316 L F
.158 .036 .452 r
.7191 .44354 m .71912 .44355 L .71914 .44352 L F
.7191 .44354 m .71914 .44352 L .72038 .44211 L F
.994 .75 .416 r
.51385 .55825 m .51283 .55894 L .51304 .55757 L F
.51385 .55825 m .51408 .56115 L .51283 .55894 L F
.704 .515 .63 r
.57887 .49612 m .58151 .49586 L .58155 .49325 L F
.656 .559 .733 r
.58151 .49586 m .58369 .49253 L .58155 .49325 L F
.538 .924 .82 r
.69258 .41014 m .69182 .4102 L .68801 .41232 L F
.423 .746 .993 r
.69258 .41014 m .69401 .40897 L .69182 .4102 L F
.69258 .41014 m .69507 .41007 L .69401 .40897 L F
.326 0 .014 r
.71235 .44503 m .71511 .44465 L .71528 .44384 L F
0 0 .036 r
.39479 .60553 m .39468 .60461 L .39638 .60472 L F
.39479 .60553 m .39327 .60734 L .39468 .60461 L F
.548 .333 .54 r
.44957 .57872 m .44935 .58133 L .45195 .57801 L F
.44957 .57872 m .44935 .58133 L .45195 .57801 L F
.84 .89 .876 r
.54402 .67332 m .5414 .67598 L .54006 .67503 L F
0 .269 .775 r
.45078 .58672 m .45143 .58652 L .45133 .58754 L F
.784 .794 .3 r
.45143 .58652 m .45057 .58968 L .45133 .58754 L F
.64 .485 .657 r
.18876 .56716 m .19155 .56967 L .19144 .56714 L F
.694 .69 .842 r
.72697 .40845 m .7229 .40801 L .72527 .4072 L F
.693 .724 .874 r
.72527 .4072 m .72894 .40796 L .72697 .40845 L F
.339 .683 .979 r
.56745 .62594 m .56984 .62603 L .57077 .62691 L F
.672 .797 .941 r
.56984 .62603 m .57321 .6263 L .57077 .62691 L F
.628 .58 .781 r
.57077 .62691 m .57321 .6263 L .57383 .62834 L F
.414 .088 .301 r
.59357 .50793 m .59666 .50562 L .59627 .50811 L F
.756 .639 .731 r
.59896 .50501 m .59627 .50811 L .59666 .50562 L F
.421 .199 .469 r
.23835 .61608 m .23862 .61944 L .23606 .61961 L F
.212 .016 .383 r
.24075 .61368 m .24035 .61588 L .23835 .61608 L F
.368 .162 .463 r
.2405 .61865 m .23835 .61608 L .24035 .61588 L F
.2405 .61865 m .23862 .61944 L .23835 .61608 L F
.984 .704 .395 r
.58664 .61703 m .58752 .62112 L .58805 .62097 L F
.996 .805 .531 r
.58664 .62196 m .58805 .62097 L .58752 .62112 L F
.58664 .62196 m .58766 .62386 L .58805 .62097 L F
.88 .449 .064 r
.51197 .55531 m .51163 .55658 L .5128 .55263 L F
.51197 .55531 m .51304 .55757 L .51163 .55658 L F
.665 .683 .857 r
.7023 .41342 m .7036 .40939 L .70113 .41028 L F
.7023 .41342 m .70471 .41268 L .7036 .40939 L F
.84 .995 .842 r
.62627 .40769 m .62422 .40988 L .62478 .41052 L F
.834 .993 .746 r
.4411 .60029 m .43916 .60211 L .43965 .60051 L F
.989 .74 .367 r
.44036 .60371 m .43965 .60051 L .43916 .60211 L F
.317 .194 .55 r
.44036 .60371 m .43875 .60474 L .43916 .60211 L F
.989 .74 .367 r
.44036 .60371 m .43969 .60328 L .43965 .60051 L F
.902 .972 .81 r
.44173 .60077 m .43969 .60328 L .44036 .60371 L F
.39 .794 .983 r
.43965 .60051 m .44258 .60072 L .4411 .60029 L F
.44258 .60072 m .44436 .60084 L .44335 .60067 L F
.44258 .60072 m .44335 .60067 L .4411 .60029 L F
.43965 .60051 m .44199 .60022 L .44436 .60084 L F
.902 .972 .81 r
.44199 .60022 m .44157 .60078 L .44173 .60077 L F
.44157 .60078 m .43969 .60328 L .44173 .60077 L F
.735 .698 .816 r
.56588 .6234 m .56745 .62594 L .56357 .6254 L F
.475 .563 .865 r
.56875 .62348 m .56745 .62594 L .56588 .6234 L F
.56875 .62348 m .56984 .62603 L .56745 .62594 L F
.756 .96 .659 r
.59195 .44066 m .58952 .44372 L .59054 .44171 L F
.774 .993 .779 r
.58952 .44372 m .58782 .44444 L .59054 .44171 L F
.334 0 .016 r
.40813 .57821 m .41062 .57785 L .41195 .57608 L F
.033 0 0 r
.41195 .57608 m .41266 .57691 L .41428 .57548 L F
.41195 .57608 m .41062 .57785 L .41266 .57691 L F
0 0 .441 r
.49255 .62088 m .49222 .62049 L .49085 .62032 L F
.49255 .62088 m .49385 .62263 L .49222 .62049 L F
.341 0 0 r
.6267 .43377 m .6284 .43454 L .62622 .43452 L F
.6267 .43377 m .63002 .43372 L .6284 .43454 L F
.447 .237 .501 r
.21054 .61131 m .21264 .61079 L .21298 .60835 L F
.052 .17 .669 r
.21054 .61131 m .21232 .61326 L .21264 .61079 L F
.43 .103 .308 r
.62638 .43418 m .62398 .4331 L .62325 .43411 L F
.62638 .43418 m .62652 .43189 L .62398 .4331 L F
.479 .394 .682 r
.36118 .61167 m .36317 .61124 L .36293 .60774 L F
.485 .426 .716 r
.36183 .61411 m .36317 .61124 L .36118 .61167 L F
.689 .363 .418 r
.58655 .49168 m .5836 .49042 L .58369 .49253 L F
.127 0 .303 r
.24479 .60472 m .24336 .60565 L .24533 .60241 L F
.448 .259 .53 r
.24479 .60472 m .24257 .60791 L .24336 .60565 L F
.754 .535 .598 r
.22355 .56074 m .22604 .5634 L .22664 .56158 L F
.513 .019 .02 r
.63738 .42992 m .63479 .42877 L .6337 .43009 L F
.621 .376 .525 r
.63125 .44188 m .63372 .43946 L .63135 .44024 L F
.359 .147 .45 r
.23606 .61961 m .23391 .62231 L .23461 .62117 L F
.23606 .61961 m .23613 .62219 L .23391 .62231 L F
.379 .186 .489 r
.23613 .62219 m .23326 .62467 L .23391 .62231 L F
.848 .966 .878 r
.62838 .47181 m .63186 .46993 L .63081 .46892 L F
.771 .91 .935 r
.63081 .46892 m .63186 .46993 L .63393 .46848 L F
.612 .41 .585 r
.48344 .62289 m .4861 .62278 L .48603 .62022 L F
.37 .223 .548 r
.48603 .62022 m .48842 .62271 L .4876 .61927 L F
.48603 .62022 m .4861 .62278 L .48842 .62271 L F
.98 .729 .483 r
.22107 .59035 m .22013 .59261 L .22201 .59364 L F
.865 .977 .674 r
.22013 .59261 m .22154 .59605 L .22201 .59364 L F
.425 .429 .76 r
.22107 .59035 m .22201 .59364 L .22362 .59283 L F
.449 .277 .554 r
.22154 .59605 m .22362 .59283 L .22201 .59364 L F
.631 .709 .903 r
.70842 .41337 m .70983 .40994 L .70705 .41234 L F
.70842 .41337 m .7112 .41295 L .70983 .40994 L F
.64 .485 .657 r
.18876 .56716 m .18912 .57046 L .19155 .56967 L F
.794 .805 .86 r
.65048 .44781 m .65493 .44653 L .65356 .44528 L F
0 0 0 r
.44524 .56306 m .4432 .56423 L .44463 .56351 L F
.543 .195 .329 r
.44116 .56599 m .44463 .56351 L .4432 .56423 L F
.292 .6 .95 r
.68258 .46659 m .68113 .46668 L .68134 .46508 L F
.68258 .46659 m .68113 .46668 L .68134 .46508 L F
.963 .645 .254 r
.67128 .4475 m .6717 .44623 L .6714 .44479 L F
.67128 .4475 m .6721 .44851 L .6717 .44623 L F
.607 .444 .635 r
.55094 .53721 m .55142 .54018 L .54835 .54015 L F
.557 .379 .596 r
.55142 .54018 m .54898 .543 L .54835 .54015 L F
.203 0 .209 r
.60396 .49901 m .60662 .49614 L .60637 .4984 L F
.333 .025 .283 r
.60637 .4984 m .60662 .49614 L .60882 .49521 L F
0 0 .076 r
.70947 .44806 m .71126 .44733 L .71175 .44561 L F
0 0 0 r
.70947 .44806 m .70958 .44905 L .71126 .44733 L F
.642 .736 .917 r
.71075 .40099 m .70947 .40415 L .70835 .40178 L F
.71075 .40099 m .71207 .40331 L .70947 .40415 L F
.816 .763 .803 r
.57658 .48695 m .57416 .48985 L .57758 .49019 L F
.822 .766 .799 r
.57658 .48695 m .57758 .49019 L .57996 .48728 L F
.921 .895 .787 r
.62555 .47618 m .62771 .47637 L .6283 .47526 L F
.643 .243 .271 r
.48762 .62859 m .48309 .62977 L .48502 .62902 L F
.59 .069 0 r
.66079 .42299 m .66088 .42339 L .66032 .4212 L F
.66079 .42299 m .6626 .42483 L .66088 .42339 L F
.593 .587 .815 r
.55269 .62912 m .55393 .62556 L .55165 .62573 L F
.55269 .62912 m .55512 .62875 L .55393 .62556 L F
.172 0 0 r
.50445 .72117 m .50719 .72038 L .50795 .71926 L F
0 0 0 r
.50445 .72117 m .50719 .72038 L .50795 .71926 L F
.621 .819 .409 r
.50836 .71856 m .50719 .72038 L .50795 .71926 L F
.50795 .71926 m .50719 .72038 L .50836 .71856 L F
.634 .498 .679 r
.57617 .49651 m .57647 .49907 L .57887 .49612 L F
.82 .771 .807 r
.57905 .48397 m .57658 .48695 L .57996 .48728 L F
.223 .707 .93 r
.22264 .5417 m .22485 .54174 L .22676 .54231 L F
.14 .619 .921 r
.22485 .54174 m .22858 .5429 L .22676 .54231 L F
.285 0 0 r
.45705 .63389 m .45937 .63357 L .46102 .6317 L F
.577 .33 .505 r
.55616 .53161 m .55857 .53363 L .556 .53392 L F
.55616 .53161 m .55869 .53125 L .55857 .53363 L F
.53 .299 .51 r
.55616 .53161 m .556 .53392 L .5532 .53458 L F
.285 .786 .835 r
.71443 .45682 m .714 .45668 L .71146 .45727 L F
.557 .931 .815 r
.71623 .45529 m .71443 .45682 L .71792 .45558 L F
.71623 .45529 m .714 .45668 L .71443 .45682 L F
0 0 0 r
.59967 .45419 m .60081 .45226 L .602 .45082 L F
.52 .008 0 r
.41734 .63195 m .41955 .63315 L .42114 .63196 L F
0 0 0 r
.41955 .63315 m .42286 .63302 L .42114 .63196 L F
.887 .968 .835 r
.65869 .41084 m .65629 .41221 L .65807 .40913 L F
.509 .798 .998 r
.6602 .4093 m .65869 .41084 L .65807 .40913 L F
.6602 .4093 m .66146 .41043 L .65869 .41084 L F
.436 .851 .961 r
.18509 .54094 m .18708 .5404 L .18892 .54072 L F
.489 0 0 r
.18708 .5404 m .19097 .54027 L .18892 .54072 L F
.919 .523 .195 r
.19922 .67614 m .19957 .67638 L .1999 .6745 L F
.705 .672 .126 r
.1999 .6745 m .19963 .67616 L .2001 .67336 L F
.151 .106 .549 r
.20123 .67748 m .19963 .67616 L .1999 .6745 L F
.919 .523 .195 r
.19957 .67638 m .20123 .67748 L .1999 .6745 L F
.705 .672 .126 r
.1999 .6745 m .2001 .67336 L .20012 .67326 L F
.559 .35 .553 r
.47196 .62859 m .47387 .6257 L .47195 .62605 L F
.48 .239 .47 r
.57794 .52195 m .57796 .5198 L .58038 .51923 L F
.31 .778 .937 r
.22858 .5429 m .23073 .54261 L .23253 .54301 L F
.34 .766 .974 r
.23073 .54261 m .23451 .54308 L .23253 .54301 L F
.004 0 0 r
.16427 .54743 m .16809 .5458 L .16555 .54639 L F
.936 .75 .625 r
.46888 .57241 m .46982 .57543 L .47077 .57314 L F
.258 .153 .538 r
.25803 .57848 m .25807 .58103 L .2567 .58178 L F
.37 .21 .531 r
.25807 .58103 m .25623 .58428 L .2567 .58178 L F
.068 0 0 r
.42938 .63398 m .431 .63363 L .43269 .63267 L F
.465 .313 .59 r
.43099 .63352 m .42938 .63398 L .42715 .63203 L F
.28 .766 .916 r
.43099 .63352 m .43168 .63348 L .42938 .63398 L F
.127 0 0 r
.42406 .63495 m .43029 .63367 L .42448 .63347 L F
.43029 .63367 m .43099 .63352 L .43043 .63352 L F
.43029 .63367 m .43043 .63352 L .42448 .63347 L F
.713 .923 .585 r
.42939 .63462 m .42864 .63544 L .42907 .63508 L F
.465 .313 .59 r
.43099 .63352 m .42715 .63203 L .42556 .63246 L F
.706 .347 .366 r
.42556 .63246 m .42448 .63347 L .43099 .63352 L F
.127 0 0 r
.42406 .63495 m .42644 .63476 L .43017 .63374 L F
.43029 .63367 m .43017 .63374 L .43099 .63352 L F
.42406 .63495 m .43017 .63374 L .43029 .63367 L F
.713 .923 .585 r
.42943 .63456 m .42907 .63497 L .42939 .63462 L F
.897 .668 .584 r
.43099 .63352 m .43017 .63374 L .42943 .63456 L F
.43099 .63352 m .42943 .63456 L .42989 .63442 L F
.654 .968 .899 r
.43099 .63352 m .42644 .63476 L .43042 .63316 L F
.897 .668 .584 r
.43099 .63352 m .43053 .6339 L .43042 .63316 L F
.43053 .6339 m .42998 .63421 L .43042 .63316 L F
.713 .923 .585 r
.43042 .63316 m .42943 .63456 L .42993 .63433 L F
.897 .668 .584 r
.43017 .63374 m .42644 .63476 L .42864 .63544 L F
.713 .923 .585 r
.42986 .63395 m .42907 .63497 L .42943 .63456 L F
.43042 .63316 m .42974 .63404 L .42986 .63395 L F
.42974 .63404 m .42872 .63534 L .42986 .63395 L F
.897 .668 .584 r
.42998 .63421 m .4293 .6346 L .43042 .63316 L F
.28 .766 .916 r
.43099 .63352 m .43042 .63316 L .43168 .63348 L F
.713 .923 .585 r
.43042 .63316 m .42993 .63433 L .43168 .63348 L F
.42943 .63456 m .42907 .63508 L .4298 .63463 L F
.42943 .63456 m .4298 .63463 L .42989 .63442 L F
.897 .668 .584 r
.42989 .63442 m .42943 .63456 L .42864 .63544 L F
.713 .923 .585 r
.42986 .63395 m .42872 .63534 L .42907 .63497 L F
.42872 .63534 m .42864 .63544 L .42939 .63462 L F
.897 .668 .584 r
.42998 .63421 m .42864 .63544 L .4293 .6346 L F
.43053 .6339 m .42989 .63442 L .42998 .63421 L F
.42989 .63442 m .42864 .63544 L .42998 .63421 L F
.713 .923 .585 r
.42989 .63442 m .4298 .63463 L .4304 .63427 L F
.42943 .63456 m .4304 .63427 L .43168 .63348 L F
.068 0 0 r
.43269 .63267 m .43168 .63348 L .43331 .63242 L F
.431 .63363 m .43168 .63348 L .43269 .63267 L F
.55 .027 0 r
.43331 .63242 m .43168 .63348 L .43539 .63368 L F
.931 .93 .781 r
.73575 .42743 m .73266 .43045 L .73571 .42788 L F
.653 .744 .916 r
.54192 .69176 m .54214 .68954 L .54103 .69085 L F
.54192 .69176 m .54405 .69065 L .54214 .68954 L F
.921 .895 .787 r
.62555 .47618 m .6283 .47526 L .62717 .47423 L F
0 0 .422 r
.54336 .66095 m .54297 .66387 L .54263 .66361 L F
.739 .45 .49 r
.54263 .66361 m .54687 .66162 L .54336 .66095 L F
.58 .214 .311 r
.42605 .6408 m .42461 .64301 L .42226 .64299 L F
.581 .215 .312 r
.42846 .6424 m .42461 .64301 L .42605 .6408 L F
.563 .234 .369 r
.42843 .64077 m .42846 .6424 L .42605 .6408 L F
.868 .799 .78 r
.54454 .66888 m .54612 .67015 L .54402 .67332 L F
.485 .426 .716 r
.36183 .61411 m .36384 .61362 L .36317 .61124 L F
.441 .493 .817 r
.36183 .61411 m .36478 .61703 L .36384 .61362 L F
.767 .625 .703 r
.53083 .70183 m .53231 .70314 L .53473 .70243 L F
.537 .293 .494 r
.56704 .5256 m .56945 .52742 L .56695 .52783 L F
.56704 .5256 m .56952 .52521 L .56945 .52742 L F
.003 0 0 r
.17114 .5587 m .16908 .55976 L .16707 .56019 L F
.33 .813 .864 r
.17229 .55922 m .16908 .55976 L .17114 .5587 L F
.407 .006 .163 r
.4656 .63321 m .46919 .63063 L .46677 .63132 L F
.563 .565 .814 r
.74115 .42757 m .74242 .43068 L .74004 .43126 L F
.47 .867 .968 r
.18701 .64215 m .18665 .64313 L .18647 .64362 L F
.18701 .64215 m .18844 .64281 L .18665 .64313 L F
.427 .867 .793 r
.70894 .45739 m .7081 .45754 L .70539 .45871 L F
.551 .883 .989 r
.71146 .45727 m .7081 .45754 L .70894 .45739 L F
0 0 0 r
.42286 .63302 m .42556 .63246 L .42715 .63203 L F
.434 .361 .675 r
.22774 .57886 m .22912 .57606 L .2273 .57685 L F
.565 .303 .478 r
.56126 .52878 m .56367 .53067 L .56122 .53095 L F
.56126 .52878 m .56349 .52862 L .56367 .53067 L F
.479 .411 .702 r
.25955 .57212 m .26001 .57559 L .25806 .57595 L F
.476 .322 .592 r
.26001 .57559 m .25803 .57848 L .25806 .57595 L F
.669 .455 .585 r
.60756 .4724 m .61022 .47208 L .61002 .46958 L F
.513 .339 .582 r
.61002 .46958 m .61022 .47208 L .61247 .46892 L F
.543 .511 .77 r
.46805 .56855 m .46572 .57162 L .46524 .56921 L F
.46805 .56855 m .46777 .57097 L .46572 .57162 L F
.543 .305 .504 r
.46888 .57241 m .46572 .57162 L .46777 .57097 L F
.46888 .57241 m .46609 .57382 L .46572 .57162 L F
.327 0 0 r
.67715 .41546 m .67401 .41572 L .6751 .41555 L F
.67585 .41556 m .67631 .41573 L .67401 .41572 L F
.67715 .41546 m .67637 .41571 L .67585 .41556 L F
.67637 .41571 m .67631 .41573 L .67585 .41556 L F
.652 .843 .973 r
.67715 .41546 m .67834 .41677 L .6807 .41568 L F
0 0 .214 r
.67766 .41308 m .67715 .41546 L .67918 .41347 L F
.633 .902 .985 r
.67918 .41347 m .67715 .41546 L .67955 .41445 L F
.258 .269 .681 r
.67852 .41562 m .67781 .41611 L .67706 .41493 L F
.871 .972 .851 r
.67616 .41726 m .67834 .41677 L .67715 .41546 L F
.258 .269 .681 r
.67781 .41611 m .67616 .41726 L .67672 .41581 L F
.67781 .41611 m .67672 .41581 L .67706 .41493 L F
.663 .406 .521 r
.67401 .41572 m .67631 .41573 L .67526 .41552 L F
.67401 .41572 m .67526 .41552 L .67113 .41473 L F
.327 0 0 r
.6751 .41555 m .67401 .41572 L .67457 .41557 L F
.578 .094 .069 r
.67526 .41552 m .6761 .41547 L .67466 .41372 L F
.613 .099 .001 r
.67466 .41372 m .6761 .41547 L .67715 .41546 L F
.327 0 0 r
.67715 .41546 m .67457 .41557 L .67714 .41539 L F
.613 .099 .001 r
.6761 .41547 m .67631 .41573 L .67715 .41546 L F
.327 0 0 r
.67714 .41539 m .6761 .41547 L .67706 .41493 L F
.578 .094 .069 r
.67113 .41473 m .67526 .41552 L .67466 .41372 L F
.327 0 0 r
.6761 .41547 m .67457 .41557 L .67494 .41548 L F
.502 .243 .454 r
.67466 .41372 m .67715 .41546 L .67766 .41308 L F
.327 0 0 r
.6761 .41547 m .67494 .41548 L .67706 .41493 L F
.578 .094 .069 r
.67526 .41552 m .67631 .41573 L .6761 .41547 L F
.314 .027 .307 r
.23238 .62732 m .23138 .63089 L .22902 .63104 L F
.048 0 .416 r
.23326 .62467 m .23372 .62776 L .23238 .62732 L F
.357 .137 .437 r
.23372 .62776 m .23138 .63089 L .23238 .62732 L F
.621 .553 .756 r
.72198 .41894 m .72473 .41839 L .72409 .41633 L F
.673 .63 .798 r
.72079 .41544 m .72198 .41894 L .72409 .41633 L F
.631 .731 .919 r
.70835 .40178 m .70594 .40351 L .70473 .40071 L F
.191 .066 .47 r
.20228 .66896 m .20055 .66734 L .20123 .66638 L F
.20228 .66896 m .20039 .67015 L .20055 .66734 L F
.619 .825 .98 r
.67949 .41673 m .6807 .41568 L .67834 .41677 L F
.644 .604 .795 r
.43058 .58026 m .4289 .58494 L .42835 .58232 L F
.43058 .58026 m .43229 .58449 L .42904 .58455 L F
.43229 .58449 m .43247 .58493 L .43188 .58487 L F
.43229 .58449 m .43188 .58487 L .42904 .58455 L F
.438 .486 .812 r
.43416 .58375 m .43247 .58493 L .43058 .58026 L F
.543 .715 .952 r
.43188 .58487 m .43247 .58493 L .43416 .58375 L F
.43154 .58503 m .43247 .58493 L .43188 .58487 L F
.644 .604 .795 r
.42904 .58455 m .43247 .58493 L .4289 .58494 L F
.47 .783 .998 r
.4289 .58494 m .43181 .58493 L .43154 .58503 L F
.43181 .58493 m .43247 .58493 L .43154 .58503 L F
0 .144 .66 r
.43326 .58594 m .43164 .58509 L .43222 .58478 L F
.43401 .58411 m .43222 .58478 L .43416 .58375 L F
.43326 .58594 m .43222 .58478 L .43401 .58411 L F
.43164 .58509 m .43154 .58503 L .43188 .58487 L F
.43164 .58509 m .43188 .58487 L .43416 .58375 L F
.217 0 0 r
.17879 .54149 m .18093 .54174 L .18297 .54151 L F
.394 0 0 r
.18093 .54174 m .18509 .54094 L .18297 .54151 L F
.723 .701 .165 r
.48553 .62579 m .48549 .62581 L .4861 .62278 L F
.671 .745 .906 r
.50011 .71794 m .50249 .72092 L .49839 .7199 L F
.785 .486 .481 r
.49839 .7199 m .50249 .72092 L .50039 .72203 L F
.66 .642 .821 r
.50315 .71696 m .50249 .72092 L .50011 .71794 L F
.50315 .71696 m .50445 .72117 L .50249 .72092 L F
.848 .615 .586 r
.50249 .72092 m .50302 .72281 L .50039 .72203 L F
0 .2 .727 r
.50249 .72092 m .50317 .72032 L .50039 .72203 L F
.50249 .72092 m .50336 .72164 L .50317 .72032 L F
.611 .163 .163 r
.50445 .72117 m .50336 .72164 L .50249 .72092 L F
.23 .238 .661 r
.50336 .72164 m .50302 .72281 L .50249 .72092 L F
.146 .69 .751 r
.19759 .55289 m .19557 .55306 L .19333 .5534 L F
.156 .698 .775 r
.1999 .55266 m .19557 .55306 L .19759 .55289 L F
.415 .238 .53 r
.22074 .57556 m .22015 .57914 L .21972 .57641 L F
.999 .805 .503 r
.6463 .44208 m .64759 .44295 L .6469 .44612 L F
.736 .977 .738 r
.21374 .6072 m .21298 .60835 L .21405 .60661 L F
.902 .965 .816 r
.21569 .60582 m .21374 .6072 L .2163 .60416 L F
.133 .135 .593 r
.21405 .60661 m .2163 .60416 L .21374 .6072 L F
0 0 .259 r
.21298 .60835 m .21386 .60948 L .21405 .60661 L F
.21298 .60835 m .21264 .61079 L .21386 .60948 L F
.286 .042 .358 r
.36326 .62033 m .36261 .62262 L .36512 .61946 L F
.623 .48 .666 r
.5532 .53738 m .55142 .54018 L .55094 .53721 L F
.592 .613 .842 r
.63741 .44444 m .63919 .44646 L .63505 .44519 L F
.464 0 .011 r
.46513 .58163 m .46613 .58272 L .46606 .58163 L F
.318 .353 .74 r
.46606 .58163 m .46764 .5759 L .46672 .57747 L F
.46606 .58163 m .46893 .57964 L .46764 .5759 L F
0 .23 .734 r
.25602 .55027 m .25543 .55056 L .2539 .54949 L F
.25602 .55027 m .25721 .55185 L .25543 .55056 L F
.789 .58 .618 r
.63623 .45369 m .63996 .45188 L .6393 .45146 L F
.63623 .45369 m .63975 .45401 L .63996 .45188 L F
.717 .893 .96 r
.63996 .45188 m .64211 .45064 L .64093 .4497 L F
.817 .999 .838 r
.6393 .45146 m .63996 .45188 L .64093 .4497 L F
0 0 0 r
.63629 .43891 m .63554 .44042 L .63711 .43702 L F
.63629 .43891 m .63711 .43702 L .63728 .43665 L F
.661 .792 .944 r
.63738 .44007 m .63589 .43982 L .63629 .43891 L F
.63589 .43982 m .63372 .43946 L .63629 .43891 L F
.959 .878 .712 r
.63629 .43891 m .63738 .44007 L .63532 .4405 L F
.523 .791 .994 r
.63952 .43946 m .63738 .44007 L .63629 .43891 L F
.576 .764 .968 r
.45195 .57801 m .45555 .57869 L .45419 .57724 L F
.45195 .57801 m .45555 .57869 L .45419 .57724 L F
0 0 .288 r
.4565 .57484 m .45555 .57869 L .45419 .57724 L F
.4565 .57484 m .45649 .57736 L .45555 .57869 L F
.367 .659 .969 r
.45555 .57869 m .45649 .57736 L .45419 .57724 L F
.708 .711 .85 r
.72777 .40607 m .72894 .40796 L .72527 .4072 L F
.7 .744 .886 r
.73057 .40399 m .72894 .40796 L .72777 .40607 L F
.73057 .40399 m .73127 .40686 L .72894 .40796 L F
.783 .678 .748 r
.22029 .59948 m .21797 .60257 L .21606 .59722 L F
.22029 .59948 m .21606 .59722 L .21801 .59832 L F
.82 .999 .839 r
.22041 .59772 m .22029 .59948 L .21801 .59832 L F
.891 .936 .564 r
.22029 .59948 m .22015 .59799 L .22154 .59605 L F
.82 .999 .839 r
.22041 .59772 m .22015 .59799 L .22029 .59948 L F
.322 .646 .968 r
.73985 .41645 m .74138 .41539 L .7388 .41538 L F
.73985 .41645 m .74228 .41646 L .74138 .41539 L F
.73985 .41645 m .74138 .41539 L .7388 .41538 L F
.73985 .41645 m .74228 .41646 L .74138 .41539 L F
.966 .64 .301 r
.64236 .43995 m .64344 .44038 L .64372 .44321 L F
.433 .477 .806 r
.64344 .44038 m .64548 .44098 L .64416 .43693 L F
.551 .211 .345 r
.6463 .44208 m .64548 .44098 L .64344 .44038 L F
.282 .753 .94 r
.45903 .56671 m .45752 .5662 L .46103 .56644 L F
.419 .319 .635 r
.25959 .55864 m .2581 .56366 L .25759 .56253 L F
.492 .698 .96 r
.3898 .64238 m .39018 .64063 L .38792 .64064 L F
.3898 .64238 m .3921 .64236 L .39018 .64063 L F
.667 .685 .857 r
.72054 .40298 m .71923 .40712 L .71806 .40395 L F
.72054 .40298 m .72162 .40626 L .71923 .40712 L F
.66 .647 .826 r
.72162 .40626 m .7229 .40801 L .71923 .40712 L F
.446 .851 .67 r
.66954 .40626 m .66727 .40774 L .66603 .40835 L F
.041 0 0 r
.73801 .4426 m .73624 .44265 L .73876 .44196 L F
.73801 .4426 m .73533 .44363 L .73624 .44265 L F
.879 .863 .819 r
.63521 .45622 m .63823 .45572 L .63623 .45369 L F
.63521 .45622 m .63708 .45705 L .63823 .45572 L F
.753 .749 .848 r
.63623 .45369 m .63823 .45572 L .63975 .45401 L F
.634 .917 .635 r
.59195 .44066 m .59323 .43902 L .59315 .43908 L F
.59195 .44066 m .59054 .44171 L .59323 .43902 L F
.596 .079 0 r
.74242 .43068 m .74514 .43213 L .74607 .43098 L F
.456 .325 .613 r
.25157 .59253 m .24927 .59647 L .24896 .59413 L F
.993 .748 .394 r
.64123 .43312 m .64287 .43369 L .64275 .4361 L F
.664 .676 .851 r
.72408 .40435 m .7229 .40801 L .72162 .40626 L F
.72408 .40435 m .72527 .4072 L .7229 .40801 L F
.432 .218 .487 r
.24711 .60164 m .24479 .60472 L .24533 .60241 L F
.646 .288 .351 r
.59285 .4926 m .58975 .49037 L .58978 .49233 L F
.804 .488 .456 r
.60355 .44243 m .60765 .44475 L .60677 .44425 L F
.532 .34 .565 r
.48676 .56698 m .48669 .56946 L .48431 .57006 L F
.48676 .56698 m .48669 .56946 L .48431 .57006 L F
.557 .338 .538 r
.61589 .44002 m .61588 .44247 L .61323 .44284 L F
.61589 .44002 m .61588 .44247 L .61323 .44284 L F
.44 .246 .519 r
.61809 .44159 m .61589 .44002 L .61809 .43925 L F
.61809 .44159 m .61588 .44247 L .61589 .44002 L F
.61589 .44002 m .61809 .44159 L .61809 .43925 L F
.61589 .44002 m .61588 .44247 L .61809 .44159 L F
.233 0 .27 r
.60155 .50186 m .60396 .49901 L .60384 .50118 L F
.201 .004 .374 r
.60585 .50019 m .60396 .49901 L .60637 .4984 L F
.60585 .50019 m .60384 .50118 L .60396 .49901 L F
0 0 0 r
.61967 .40336 m .62131 .40268 L .62259 .4018 L F
.61967 .40336 m .61913 .40367 L .62131 .40268 L F
.579 .918 .967 r
.19022 .64155 m .18844 .64281 L .18701 .64215 L F
.682 .773 .92 r
.19175 .64247 m .18844 .64281 L .19022 .64155 L F
.304 .631 .963 r
.68535 .40688 m .68865 .40835 L .68784 .40635 L F
0 .1 .656 r
.68784 .40635 m .68865 .40835 L .68954 .40803 L F
.241 .74 .666 r
.68954 .40803 m .68865 .40835 L .68771 .40869 L F
.68954 .40803 m .68865 .40835 L .68771 .40869 L F
.655 .106 0 r
.68685 .40666 m .68784 .40635 L .68821 .40671 L F
.68771 .4071 m .68821 .40671 L .68954 .40803 L F
.68685 .40666 m .68821 .40671 L .68771 .4071 L F
.531 .619 .885 r
.68954 .40803 m .68771 .40869 L .68685 .40666 L F
.532 .741 .972 r
.68771 .40869 m .68915 .40694 L .68655 .40736 L F
.028 0 0 r
.68536 .40818 m .68655 .40736 L .68759 .40719 L F
.68701 .40764 m .68759 .40719 L .68915 .40694 L F
.68536 .40818 m .68759 .40719 L .68701 .40764 L F
.532 .741 .972 r
.68771 .40869 m .6904 .40837 L .68939 .40721 L F
.68771 .40869 m .68939 .40721 L .68915 .40694 L F
.707 .984 .817 r
.68865 .40835 m .68668 .4096 L .68771 .40869 L F
.68668 .4096 m .68576 .41019 L .68771 .40869 L F
.986 .723 .433 r
.51489 .56677 m .51372 .56605 L .51364 .56351 L F
0 .079 .567 r
.51701 .56898 m .51372 .56605 L .51489 .56677 L F
.581 .923 .962 r
.19261 .64109 m .19175 .64247 L .19022 .64155 L F
.19261 .64109 m .19533 .64124 L .19175 .64247 L F
0 0 0 r
.41616 .57421 m .41817 .57341 L .4198 .5721 L F
.4198 .5721 m .42122 .57143 L .42283 .57014 L F
.4198 .5721 m .41817 .57341 L .42122 .57143 L F
0 .285 .729 r
.24254 .5448 m .24291 .54544 L .2401 .54363 L F
.24254 .5448 m .24419 .54611 L .24291 .54544 L F
.533 .308 .518 r
.5532 .53458 m .555 .53596 L .5532 .53738 L F
.5532 .53458 m .556 .53392 L .555 .53596 L F
.629 .35 .476 r
.57927 .62524 m .57583 .62573 L .57573 .62344 L F
.741 .438 .468 r
.57573 .62344 m .57213 .62503 L .57441 .62206 L F
.57573 .62344 m .57583 .62573 L .57213 .62503 L F
.081 0 .087 r
.74968 .43394 m .75222 .43125 L .75176 .43272 L F
.193 0 .128 r
.75176 .43272 m .75222 .43125 L .75374 .43158 L F
.199 0 0 r
.75222 .43125 m .75514 .43111 L .75374 .43158 L F
.003 .117 .632 r
.3965 .62737 m .39565 .62896 L .39496 .62529 L F
.442 .686 .968 r
.3965 .62737 m .39782 .62882 L .39565 .62896 L F
.407 .737 .992 r
.67944 .40632 m .68082 .4051 L .67808 .40595 L F
.67944 .40632 m .68185 .4062 L .68082 .4051 L F
.599 .58 .803 r
.57583 .62573 m .57383 .62834 L .57321 .6263 L F
.57583 .62573 m .5772 .62895 L .57383 .62834 L F
.985 .899 .638 r
.5772 .62895 m .57466 .62884 L .57383 .62834 L F
.734 .739 .855 r
.74228 .41646 m .74353 .41935 L .74617 .41775 L F
.511 .285 .509 r
.74353 .42148 m .74607 .42077 L .74353 .41935 L F
.489 .341 .606 r
.39092 .61336 m .38965 .61665 L .38923 .61433 L F
.55 .629 .883 r
.50526 .71837 m .50445 .72117 L .50315 .71696 L F
.50526 .71837 m .50719 .72038 L .50445 .72117 L F
0 0 0 r
.50445 .72117 m .50336 .72164 L .50719 .72038 L F
.289 .018 .317 r
.21967 .64301 m .21923 .64599 L .21682 .64628 L F
.305 .031 .322 r
.22111 .64521 m .21967 .64301 L .22133 .64219 L F
.22111 .64521 m .21923 .64599 L .21967 .64301 L F
.63 .561 .759 r
.54111 .56406 m .54138 .56652 L .53885 .56703 L F
.656 .443 .585 r
.54138 .56652 m .53845 .56913 L .53885 .56703 L F
.581 .909 .978 r
.69304 .46397 m .69368 .46493 L .69747 .46335 L F
.213 0 0 r
.71235 .44503 m .71175 .44561 L .71511 .44465 L F
0 .009 .585 r
.66472 .45697 m .66603 .45911 L .66431 .4544 L F
.439 .329 .632 r
.73908 .42585 m .73951 .42621 L .74088 .42475 L F
.515 .306 .534 r
.74088 .42475 m .74353 .42148 L .74078 .42213 L F
.74088 .42475 m .74101 .42474 L .74353 .42148 L F
.74101 .42474 m .74367 .42445 L .74362 .42335 L F
.74101 .42474 m .74103 .42473 L .74353 .42148 L F
.74103 .42473 m .7436 .42296 L .74353 .42148 L F
.706 .763 .897 r
.74306 .42263 m .74073 .42489 L .73962 .42062 L F
.74073 .42489 m .74036 .42508 L .73962 .42062 L F
.74346 .42287 m .74083 .42488 L .74306 .42263 L F
.74083 .42488 m .74039 .42522 L .74306 .42263 L F
.662 .963 .929 r
.74211 .42271 m .74045 .42513 L .74346 .42287 L F
.74045 .42513 m .74039 .42522 L .74103 .42473 L F
.74045 .42513 m .74103 .42473 L .74346 .42287 L F
.515 .306 .534 r
.74103 .42473 m .74362 .42335 L .7436 .42296 L F
.706 .763 .897 r
.74073 .42489 m .74039 .42522 L .74036 .42508 L F
.439 .329 .632 r
.73951 .42621 m .74115 .42757 L .74089 .42482 L F
.73951 .42621 m .74089 .42482 L .74088 .42475 L F
.457 0 0 r
.73908 .42585 m .74115 .42757 L .73978 .42644 L F
.159 .669 .9 r
.19097 .54027 m .19298 .54032 L .19488 .54089 L F
.182 0 0 r
.19298 .54032 m .19714 .5407 L .19488 .54089 L F
.666 .118 0 r
.52074 .69789 m .52129 .69722 L .52015 .69776 L F
.52074 .69789 m .52261 .69855 L .52129 .69722 L F
.415 .251 .549 r
.7261 .42127 m .72791 .41896 L .72473 .41839 L F
.7261 .42127 m .72791 .42157 L .72791 .41896 L F
.493 .103 .229 r
.38027 .58932 m .38314 .58853 L .38057 .5888 L F
.661 .537 .702 r
.57647 .49907 m .57919 .499 L .57887 .49612 L F
.629 .349 .475 r
.579 .50109 m .57647 .49907 L .57663 .50168 L F
.579 .50109 m .57919 .499 L .57647 .49907 L F
.916 .922 .804 r
.63444 .46523 m .63685 .464 L .63504 .46267 L F
.63444 .46523 m .63574 .46507 L .63685 .464 L F
.597 .641 .865 r
.72851 .42319 m .73087 .41979 L .72791 .42157 L F
.72851 .42319 m .73319 .42295 L .73087 .41979 L F
.84 .89 .876 r
.54402 .67332 m .54006 .67503 L .54271 .67255 L F
.868 .799 .78 r
.54454 .66888 m .54402 .67332 L .54271 .67255 L F
.443 .176 .413 r
.45451 .57407 m .45769 .57313 L .45262 .5716 L F
.462 0 0 r
.45733 .57424 m .4565 .57484 L .45451 .57407 L F
.443 .176 .413 r
.45451 .57407 m .4565 .57484 L .45769 .57313 L F
.434 .874 .852 r
.63672 .43164 m .6385 .43148 L .64058 .43056 L F
.621 .445 .623 r
.22551 .58145 m .22786 .58134 L .22774 .57886 L F
.434 .361 .675 r
.22774 .57886 m .22979 .57827 L .22912 .57606 L F
.436 .303 .601 r
.22774 .57886 m .22972 .58047 L .22979 .57827 L F
.22774 .57886 m .22786 .58134 L .22972 .58047 L F
.658 .764 .928 r
.69575 .45568 m .69323 .45682 L .6921 .45464 L F
0 .097 .637 r
.21328 .58037 m .2142 .58062 L .21267 .57821 L F
.196 .166 .595 r
.21328 .58037 m .21502 .58301 L .2142 .58062 L F
.21328 .58037 m .21348 .58462 L .21502 .58301 L F
.92 .536 .134 r
.25721 .55185 m .25906 .55497 L .25827 .55295 L F
0 0 0 r
.66778 .41311 m .67074 .40984 L .6704 .41292 L F
0 0 .232 r
.6704 .41292 m .67074 .40984 L .67198 .40843 L F
0 0 .351 r
.54249 .55532 m .54253 .55735 L .54232 .55835 L F
.54 .335 .551 r
.54477 .55451 m .54253 .55735 L .54249 .55532 L F
0 0 0 r
.62762 .43176 m .62652 .43189 L .62638 .43418 L F
.62762 .43176 m .62881 .43064 L .62652 .43189 L F
.943 .784 .654 r
.6359 .46047 m .63708 .45705 L .63521 .45622 L F
.819 .695 .727 r
.21606 .59722 m .21797 .60257 L .21433 .60158 L F
.897 .639 .539 r
.2163 .60416 m .21433 .60158 L .21797 .60257 L F
.493 .225 .436 r
.37215 .59333 m .37449 .59291 L .37488 .59075 L F
.462 .164 .373 r
.37449 .59291 m .37728 .5905 L .37488 .59075 L F
.928 .918 .785 r
.52354 .52544 m .52033 .52762 L .52251 .52455 L F
.52354 .52544 m .52156 .52861 L .52033 .52762 L F
.79 .938 .926 r
.5265 .52303 m .52354 .52544 L .52251 .52455 L F
.894 .867 .804 r
.52083 .53111 m .52033 .52762 L .52156 .52861 L F
.52083 .53111 m .51815 .53045 L .52033 .52762 L F
.938 .82 .703 r
.52033 .5314 m .51763 .53298 L .51815 .53045 L F
0 0 .152 r
.51815 .53045 m .51763 .53298 L .5186 .5313 L F
.51815 .53045 m .5186 .5313 L .51677 .52985 L F
.51815 .53045 m .51677 .52985 L .5162 .52939 L F
.938 .82 .703 r
.52083 .53111 m .52033 .5314 L .51815 .53045 L F
.52083 .53111 m .51901 .53408 L .51763 .53298 L F
.38 .141 .422 r
.23862 .61944 m .23613 .62219 L .23606 .61961 L F
.771 .842 .386 r
.21258 .59346 m .21289 .59202 L .21411 .5895 L F
0 .121 .667 r
.21258 .59346 m .21434 .59546 L .21289 .59202 L F
.626 .398 .552 r
.57202 .52267 m .57204 .52511 L .56952 .52521 L F
.622 .405 .566 r
.57202 .52267 m .57525 .52424 L .57204 .52511 L F
.57202 .52267 m .576 .52268 L .57525 .52424 L F
.634 .649 .847 r
.55512 .62875 m .55892 .63111 L .55737 .62825 L F
.431 .517 .846 r
.55892 .63111 m .55967 .62765 L .55737 .62825 L F
.55892 .63111 m .56122 .63125 L .55967 .62765 L F
.922 .618 .142 r
.68703 .45759 m .68744 .46 L .68624 .45642 L F
.753 .856 .926 r
.68763 .45478 m .68703 .45759 L .68624 .45642 L F
.68763 .45478 m .68949 .45606 L .68703 .45759 L F
.561 .36 .566 r
.39645 .61242 m .39135 .61113 L .39326 .60959 L F
.39645 .61242 m .39092 .61336 L .39135 .61113 L F
.43 .189 .445 r
.59336 .50999 m .59357 .50793 L .59559 .50954 L F
.54 .151 .252 r
.59357 .50793 m .59627 .50811 L .59559 .50954 L F
.466 .263 .52 r
.54659 .54614 m .54669 .54875 L .54423 .5494 L F
.495 .32 .572 r
.54898 .543 m .54894 .5457 L .54659 .54614 L F
.602 .428 .619 r
.54894 .5457 m .54669 .54875 L .54659 .54614 L F
.716 .454 .529 r
.51389 .66533 m .51721 .66443 L .51381 .66417 L F
.494 .878 .969 r
.45078 .58672 m .44737 .58717 L .44923 .58627 L F
.128 .659 .866 r
.44923 .58627 m .45143 .58652 L .45078 .58672 L F
.917 .849 .761 r
.37298 .62681 m .37301 .62674 L .37416 .62826 L F
.357 .655 .969 r
.37466 .62691 m .37416 .62826 L .37315 .62692 L F
.37466 .62691 m .37315 .62692 L .37301 .62674 L F
.347 0 0 r
.37297 .62677 m .37466 .62691 L .37301 .62674 L F
.357 .655 .969 r
.37295 .62677 m .37466 .62691 L .37281 .62659 L F
.37416 .62826 m .37466 .62691 L .37295 .62677 L F
.953 .952 .672 r
.37297 .62677 m .37141 .63054 L .37081 .62862 L F
.37301 .62674 m .37298 .62681 L .37297 .62677 L F
.357 .655 .969 r
.37298 .62682 m .37281 .62659 L .37307 .62717 L F
.953 .952 .672 r
.37298 .62681 m .37141 .63054 L .37297 .62677 L F
.357 .655 .969 r
.37307 .62717 m .37281 .62659 L .37244 .62653 L F
.37394 .62804 m .37298 .62682 L .37307 .62717 L F
.37416 .62826 m .37298 .62681 L .37394 .62804 L F
.37298 .62681 m .37281 .62659 L .37394 .62804 L F
.917 .849 .761 r
.37164 .63043 m .37141 .63054 L .37298 .62681 L F
.37298 .62681 m .37298 .62681 L .37301 .62674 L F
.37164 .63043 m .37298 .62681 L .37298 .62681 L F
.37164 .63043 m .37298 .62681 L .37416 .62826 L F
.347 0 0 r
.37081 .62862 m .37466 .62691 L .37297 .62677 L F
.357 .655 .969 r
.37416 .62826 m .37608 .62828 L .37466 .62691 L F
.37466 .62691 m .37608 .62828 L .37416 .62826 L F
.547 .775 .983 r
.37608 .62828 m .37706 .62653 L .37466 .62691 L F
.37706 .62653 m .37608 .62828 L .37466 .62691 L F
.793 .55 .57 r
.37318 .62859 m .37637 .6269 L .37466 .62691 L F
.37637 .6269 m .37706 .62653 L .37466 .62691 L F
.807 .598 .62 r
.37416 .62826 m .37574 .63139 L .37164 .63043 L F
.084 0 0 r
.47358 .63275 m .46942 .6342 L .47032 .63359 L F
.47322 .63288 m .47184 .63374 L .46942 .6342 L F
.094 0 0 r
.47028 .63504 m .46942 .6342 L .47184 .63374 L F
.858 .445 .245 r
.47014 .6334 m .47025 .63472 L .47184 .63374 L F
.47025 .63472 m .47028 .63504 L .47184 .63374 L F
.084 0 0 r
.47358 .63275 m .47184 .63374 L .47322 .63288 L F
0 0 0 r
.47399 .63294 m .47358 .63275 L .4756 .63182 L F
.47399 .63294 m .47184 .63374 L .47358 .63275 L F
.476 .401 .692 r
.54688 .5513 m .54423 .5494 L .54669 .54875 L F
.54688 .5513 m .54476 .55187 L .54423 .5494 L F
.295 0 .18 r
.60155 .50186 m .60319 .50302 L .60127 .50427 L F
.60155 .50186 m .60384 .50118 L .60319 .50302 L F
.994 .82 .564 r
.66381 .44541 m .66384 .44069 L .66506 .44246 L F
.092 0 .404 r
.19777 .68456 m .19755 .6871 L .19622 .68795 L F
.865 .963 .63 r
.19755 .6871 m .19587 .69042 L .19622 .68795 L F
.187 0 .191 r
.21818 .64766 m .21682 .64628 L .21923 .64599 L F
.21818 .64766 m .21645 .64849 L .21682 .64628 L F
.674 .86 .97 r
.68258 .46659 m .68616 .46662 L .68514 .46575 L F
.672 .875 .975 r
.68756 .46439 m .68616 .46662 L .68855 .46522 L F
.701 .913 .968 r
.68514 .46575 m .68616 .46662 L .68756 .46439 L F
.641 .25 .288 r
.22195 .58151 m .22381 .5835 L .22551 .58145 L F
.587 .185 .248 r
.22551 .58145 m .22679 .58271 L .22786 .58134 L F
.22551 .58145 m .22381 .5835 L .22679 .58271 L F
.997 .801 .516 r
.51364 .56351 m .51283 .55894 L .51408 .56115 L F
.425 .429 .76 r
.22107 .59035 m .22362 .59283 L .22274 .58991 L F
.332 0 .213 r
.22107 .59035 m .22236 .5917 L .22274 .58991 L F
.22107 .59035 m .22013 .59261 L .22236 .5917 L F
.268 .027 .351 r
.22107 .59035 m .22274 .58991 L .22337 .58743 L F
.381 0 0 r
.40144 .63167 m .40395 .63272 L .40538 .63284 L F
.899 .483 .114 r
.65277 .43476 m .65355 .43427 L .65277 .4328 L F
.65277 .43476 m .65432 .43624 L .65355 .43427 L F
.6 .424 .616 r
.22438 .63708 m .22499 .64023 L .22181 .64007 L F
.231 0 .026 r
.22499 .64023 m .22133 .64219 L .22181 .64007 L F
.355 .754 .984 r
.21892 .55431 m .21743 .55345 L .21549 .55368 L F
.565 .856 .997 r
.21952 .55271 m .21892 .55431 L .22162 .55317 L F
.21952 .55271 m .21743 .55345 L .21892 .55431 L F
.286 .338 .741 r
.56665 .63551 m .56624 .63384 L .56503 .63408 L F
.353 .029 .269 r
.56503 .63408 m .56732 .63363 L .56552 .63413 L F
.638 .674 .868 r
.56468 .62921 m .56552 .63413 L .56612 .63336 L F
.56512 .62929 m .56612 .63336 L .56868 .63 L F
.56468 .62921 m .56612 .63336 L .56512 .62929 L F
.286 .338 .741 r
.5661 .63702 m .56665 .63551 L .56503 .63408 L F
.56665 .63551 m .56732 .63363 L .56624 .63384 L F
.5661 .63702 m .56939 .63942 L .56732 .63363 L F
.047 .603 .817 r
.20558 .55256 m .20197 .55209 L .20346 .55241 L F
.362 .814 .94 r
.19714 .5407 m .19912 .5403 L .20093 .54057 L F
.197 0 0 r
.19912 .5403 m .20298 .54016 L .20093 .54057 L F
.267 .765 .715 r
.21769 .59667 m .21606 .59722 L .21688 .59699 L F
0 .144 .66 r
.43326 .58594 m .43248 .58744 L .43154 .58503 L F
.506 .479 .761 r
.43203 .57736 m .43053 .57676 L .43227 .57514 L F
.125 0 0 r
.47338 .58282 m .47307 .58305 L .47157 .58263 L F
0 .387 .719 r
.47157 .58263 m .47307 .58305 L .4723 .58275 L F
.827 .653 .667 r
.47338 .58282 m .47305 .58304 L .4723 .58275 L F
0 .387 .719 r
.47307 .58305 m .47354 .58318 L .4723 .58275 L F
.827 .653 .667 r
.47305 .58304 m .47202 .58375 L .4723 .58275 L F
.816 .602 .612 r
.4759 .58053 m .47568 .58077 L .47416 .5812 L F
.827 .653 .667 r
.47543 .58294 m .47259 .58361 L .47345 .58282 L F
.455 0 0 r
.47354 .58318 m .47543 .58294 L .47338 .58282 L F
.038 .605 .771 r
.47543 .58294 m .47388 .5828 L .47345 .58282 L F
.816 .602 .612 r
.47388 .5828 m .47543 .58294 L .47354 .58318 L F
.4759 .58053 m .47543 .58294 L .47388 .5828 L F
.038 .605 .771 r
.47543 .58294 m .47397 .58279 L .47388 .5828 L F
.47543 .58294 m .47467 .58281 L .47397 .58279 L F
.125 0 0 r
.47298 .58185 m .47338 .58282 L .47157 .58263 L F
.038 .605 .771 r
.47345 .58282 m .47397 .58279 L .4723 .58275 L F
.816 .602 .612 r
.47568 .58077 m .47388 .5828 L .47373 .58256 L F
.47388 .5828 m .47354 .58318 L .47365 .58281 L F
.47388 .5828 m .47365 .58281 L .47373 .58256 L F
.47568 .58077 m .47373 .58256 L .47416 .5812 L F
.827 .653 .667 r
.47345 .58282 m .47215 .58371 L .47338 .58282 L F
.47259 .58361 m .47215 .58371 L .47345 .58282 L F
.47215 .58371 m .47202 .58375 L .47338 .58282 L F
.125 0 0 r
.47338 .58282 m .47354 .58318 L .47307 .58305 L F
.455 0 0 r
.47354 .58318 m .47338 .58282 L .4723 .58275 L F
.125 0 0 r
.47416 .5812 m .47361 .58294 L .47298 .58185 L F
.47361 .58294 m .47346 .58298 L .47298 .58185 L F
.485 .693 .96 r
.4723 .58275 m .47415 .5828 L .47307 .58046 L F
.47415 .5828 m .47467 .58281 L .47459 .58268 L F
.47415 .5828 m .47459 .58268 L .47307 .58046 L F
.125 0 0 r
.47361 .58294 m .47354 .58318 L .47346 .58298 L F
.272 .113 .474 r
.47669 .57708 m .4759 .58053 L .47416 .5812 L F
.151 .106 .549 r
.20123 .67748 m .19979 .67866 L .19963 .67616 L F
.824 .994 .858 r
.40335 .60121 m .40195 .60281 L .4029 .60261 L F
.976 .854 .461 r
.4029 .60261 m .40199 .60261 L .40335 .60121 L F
.4029 .60261 m .40254 .60518 L .40199 .60261 L F
.712 .711 .847 r
.73419 .43369 m .73734 .43464 L .73675 .43214 L F
.556 .607 .859 r
.73675 .43214 m .73734 .43464 L .73934 .43201 L F
.468 .481 .789 r
.73734 .43464 m .74037 .43601 L .73934 .43201 L F
.568 .42 .641 r
.73734 .43464 m .73783 .4368 L .74037 .43601 L F
.581 .884 .992 r
.19556 .66997 m .19595 .66884 L .19744 .66676 L F
0 0 0 r
.19744 .66676 m .19695 .66743 L .19748 .66749 L F
.19695 .66743 m .19595 .66884 L .19748 .66749 L F
.799 .992 .877 r
.19748 .66749 m .19595 .66884 L .19609 .66744 L F
.056 0 0 r
.19609 .66744 m .19801 .66754 L .19748 .66749 L F
.19801 .66754 m .20039 .66767 L .19748 .66749 L F
0 .085 .64 r
.19595 .66884 m .19767 .67098 L .19628 .66787 L F
.19595 .66884 m .19628 .66787 L .19609 .66744 L F
.581 .884 .992 r
.19541 .67022 m .19595 .66884 L .19556 .66997 L F
.557 .722 .95 r
.74493 .42642 m .74646 .42369 L .74367 .42445 L F
.74493 .42642 m .74771 .42579 L .74646 .42369 L F
.955 .948 .654 r
.46311 .58237 m .46384 .5832 L .46359 .58202 L F
.46311 .58237 m .46384 .5832 L .46359 .58202 L F
.111 0 .067 r
.46359 .58202 m .45994 .58524 L .46189 .58451 L F
.46189 .58451 m .45994 .58524 L .46359 .58202 L F
.278 0 0 r
.46311 .58238 m .46324 .58253 L .46311 .58237 L F
.46324 .58253 m .46384 .5832 L .46324 .58252 L F
.46324 .58253 m .46324 .58252 L .46311 .58237 L F
.111 0 .067 r
.46324 .58253 m .46359 .58202 L .46384 .5832 L F
.599 .838 .464 r
.46513 .58163 m .46383 .58332 L .46384 .5832 L F
.727 .551 .652 r
.46515 .58406 m .46267 .58484 L .46513 .58163 L F
.464 0 .011 r
.46513 .58163 m .46384 .5832 L .46613 .58272 L F
.561 .503 .747 r
.46545 .58712 m .46366 .58565 L .46515 .58406 L F
.46366 .58565 m .46267 .58484 L .46397 .58443 L F
.46366 .58565 m .46397 .58443 L .46515 .58406 L F
.66 .323 .392 r
.46157 .58768 m .46313 .58786 L .46269 .58958 L F
.46157 .58768 m .46313 .58786 L .46269 .58958 L F
.704 .712 .185 r
.46291 .58869 m .46313 .58786 L .46269 .58958 L F
.561 .503 .747 r
.46545 .58712 m .46313 .58786 L .46267 .58484 L F
.054 .123 .618 r
.46267 .58484 m .46313 .58786 L .46374 .58528 L F
.704 .712 .185 r
.46374 .58528 m .46339 .58674 L .46291 .58869 L F
.46339 .58674 m .46313 .58786 L .46291 .58869 L F
.704 .564 .694 r
.46374 .58528 m .46613 .58272 L .46384 .5832 L F
.638 .324 .422 r
.46359 .58202 m .46324 .58253 L .46491 .58403 L F
.958 .943 .642 r
.46311 .58237 m .46189 .58451 L .46384 .5832 L F
.111 0 .067 r
.46189 .58451 m .46324 .58253 L .46384 .5832 L F
.278 0 0 r
.46386 .58306 m .46384 .5832 L .46311 .58238 L F
.46491 .58403 m .46384 .5832 L .46386 .58306 L F
.599 .838 .464 r
.46383 .58332 m .46267 .58484 L .46384 .5832 L F
.054 .123 .618 r
.46267 .58484 m .46374 .58528 L .46384 .5832 L F
.278 0 0 r
.46491 .58403 m .46189 .58451 L .46384 .5832 L F
.638 .324 .422 r
.46324 .58253 m .46189 .58451 L .46491 .58403 L F
.882 .689 .637 r
.66948 .42419 m .67119 .42534 L .66968 .42164 L F
.918 .871 .776 r
.66826 .4269 m .67119 .42534 L .66948 .42419 L F
.66826 .4269 m .66932 .42831 L .67119 .42534 L F
.585 .417 .62 r
.22668 .63404 m .22735 .63724 L .22438 .63708 L F
0 0 0 r
.22735 .63724 m .22499 .64023 L .22438 .63708 L F
0 0 .244 r
.64206 .41274 m .64219 .41654 L .64054 .41581 L F
.816 .599 .608 r
.64219 .41654 m .64226 .41899 L .64054 .41581 L F
.199 .411 .844 r
.45006 .56351 m .44935 .56503 L .44798 .56404 L F
.45006 .56351 m .45146 .56598 L .44935 .56503 L F
.876 .905 .847 r
.64099 .42821 m .63738 .42992 L .64058 .43056 L F
.799 .844 .384 r
.64242 .42357 m .64099 .42821 L .64247 .42703 L F
.157 0 .351 r
.64247 .42703 m .64099 .42821 L .64058 .43056 L F
0 0 0 r
.42283 .57014 m .4231 .57014 L .42478 .56846 L F
.42283 .57014 m .42122 .57143 L .4231 .57014 L F
.12 0 .072 r
.17082 .54335 m .16809 .5458 L .17007 .54469 L F
.116 0 .07 r
.17082 .54335 m .17007 .54469 L .17191 .54362 L F
.606 .732 .934 r
.70114 .39971 m .69972 .40214 L .69865 .40047 L F
.70114 .39971 m .70221 .40144 L .69972 .40214 L F
.995 .803 .534 r
.72717 .41572 m .72791 .41896 L .72811 .41639 L F
.436 .224 .491 r
.19752 .63781 m .19957 .63724 L .19995 .63473 L F
.379 .094 .35 r
.19752 .63781 m .19683 .63962 L .19957 .63724 L F
.586 .317 .476 r
.52275 .54929 m .52511 .55112 L .52261 .55124 L F
.571 .323 .502 r
.52565 .54918 m .52511 .55112 L .52275 .54929 L F
.586 .317 .476 r
.52261 .55124 m .52511 .55112 L .52275 .54929 L F
.571 .323 .502 r
.52565 .54918 m .52511 .55112 L .52275 .54929 L F
.456 .098 .268 r
.74968 .43394 m .74933 .4361 L .7465 .43643 L F
.428 .166 .412 r
.75176 .43272 m .74933 .4361 L .74968 .43394 L F
.559 .35 .553 r
.47196 .62859 m .47443 .62815 L .47387 .6257 L F
.499 .18 .356 r
.47443 .62815 m .47769 .62549 L .47387 .6257 L F
.47 .867 .968 r
.18701 .64215 m .18647 .64362 L .18676 .64236 L F
.714 .978 .914 r
.18477 .64375 m .18676 .64236 L .18647 .64362 L F
.771 .91 .935 r
.63081 .46892 m .63393 .46848 L .63274 .46731 L F
.911 .894 .799 r
.63274 .46731 m .63393 .46848 L .63574 .46507 L F
0 0 0 r
.60263 .42702 m .60164 .42865 L .60281 .42683 L F
.614 .855 .491 r
.60164 .42865 m .60175 .42828 L .60281 .42683 L F
.60164 .42865 m .60048 .43011 L .60175 .42828 L F
.629 .273 .349 r
.43199 .64045 m .42846 .6424 L .42843 .64077 L F
.43199 .64045 m .43061 .64286 L .42846 .6424 L F
.559 .196 .31 r
.43411 .64229 m .43199 .64045 L .43441 .64043 L F
.43411 .64229 m .43061 .64286 L .43199 .64045 L F
0 0 0 r
.17773 .55738 m .17589 .55839 L .17432 .55855 L F
.13 .639 .899 r
.17432 .55855 m .17546 .55834 L .17514 .55833 L F
.17432 .55855 m .17514 .55833 L .17315 .55828 L F
0 0 0 r
.17364 .55872 m .17432 .55855 L .17229 .55922 L F
.17663 .55762 m .17432 .55855 L .17364 .55872 L F
.17996 .55624 m .17773 .55738 L .17663 .55762 L F
.17773 .55738 m .17432 .55855 L .17663 .55762 L F
.526 .718 .961 r
.64463 .44603 m .64111 .4449 L .64372 .44321 L F
0 .202 .719 r
.64517 .44439 m .64463 .44603 L .64372 .44321 L F
0 0 .414 r
.64712 .44693 m .64463 .44603 L .6469 .44612 L F
.562 .315 .498 r
.58842 .51343 m .58529 .51601 L .58554 .5141 L F
0 .387 .719 r
.47157 .58263 m .4723 .58275 L .4698 .58308 L F
.589 .421 .621 r
.22902 .63104 m .22971 .63425 L .22668 .63404 L F
0 0 0 r
.22971 .63425 m .22735 .63724 L .22668 .63404 L F
.234 0 0 r
.46214 .63664 m .46091 .637 L .45855 .63696 L F
.539 .818 .997 r
.40211 .61894 m .40275 .61998 L .399 .61956 L F
.736 .361 .342 r
.40275 .61998 m .40143 .62204 L .399 .61956 L F
.344 0 .111 r
.40432 .62126 m .40275 .61998 L .40221 .6191 L F
.40432 .62126 m .40221 .6191 L .40245 .6193 L F
.40432 .62126 m .40143 .62204 L .40275 .61998 L F
.40432 .62126 m .40245 .6193 L .40281 .61965 L F
.40245 .6193 m .40211 .61894 L .40281 .61965 L F
.464 0 0 r
.40281 .61965 m .40191 .62035 L .4036 .62043 L F
.419 .483 .82 r
.40432 .62126 m .40577 .62054 L .40281 .61965 L F
.464 0 0 r
.40281 .61965 m .4036 .62043 L .40387 .62045 L F
.40294 .61969 m .40387 .62045 L .40577 .62054 L F
.40281 .61965 m .40387 .62045 L .40294 .61969 L F
.344 0 .111 r
.40245 .6193 m .40221 .6191 L .40211 .61894 L F
.791 .968 .665 r
.45885 .57173 m .45733 .57424 L .45999 .57321 L F
.095 .572 .907 r
.45999 .57321 m .46161 .57288 L .45885 .57173 L F
.45999 .57321 m .46293 .57383 L .46161 .57288 L F
.318 .35 .738 r
.21348 .58462 m .21581 .58644 L .21502 .58301 L F
.4 .353 .689 r
.21414 .58723 m .21581 .58644 L .21348 .58462 L F
.484 .784 .997 r
.68361 .40012 m .6804 .39966 L .68054 .39911 L F
.514 .804 .998 r
.68544 .39862 m .68361 .40012 L .68054 .39911 L F
.68544 .39862 m .68629 .39973 L .68361 .40012 L F
.871 .972 .851 r
.67616 .41726 m .67589 .41936 L .67834 .41677 L F
.488 .663 .939 r
.56293 .63444 m .56398 .63328 L .56122 .63125 L F
.56293 .63444 m .56503 .63408 L .56398 .63328 L F
.985 .899 .638 r
.5772 .62895 m .57638 .63155 L .57466 .62884 L F
.602 .708 .919 r
.36413 .62652 m .36668 .62724 L .36625 .62587 L F
.53 .762 .982 r
.36668 .62724 m .36835 .62587 L .36625 .62587 L F
.36668 .62724 m .36988 .62739 L .36835 .62587 L F
.323 .794 .924 r
.42755 .56646 m .43091 .56566 L .43009 .56634 L F
.092 .316 .793 r
.43263 .56386 m .43271 .56403 L .43188 .56485 L F
0 0 0 r
.43061 .56611 m .43188 .56485 L .4334 .56489 L F
.011 .113 .625 r
.43498 .56505 m .4334 .56489 L .43188 .56485 L F
.708 .443 .521 r
.43188 .56485 m .43416 .56716 L .43498 .56505 L F
.092 .316 .793 r
.43271 .56403 m .43416 .56716 L .43188 .56485 L F
0 0 0 r
.43009 .56634 m .43188 .56485 L .43061 .56611 L F
.43009 .56634 m .43091 .56566 L .43188 .56485 L F
.68535 .40688 m .68685 .40666 L .6844 .40739 L F
.68535 .40688 m .68784 .40635 L .68685 .40666 L F
.718 .878 .956 r
.67258 .41958 m .67589 .41936 L .67539 .41829 L F
.85 .96 .878 r
.67539 .41829 m .67589 .41936 L .67616 .41726 L F
.406 0 .145 r
.39377 .58418 m .39636 .58389 L .39747 .5819 L F
.287 0 .085 r
.39747 .5819 m .39862 .58328 L .39981 .58148 L F
.39747 .5819 m .39636 .58389 L .39862 .58328 L F
.449 0 0 r
.44295 .63453 m .4418 .63408 L .44325 .63469 L F
.43933 .63256 m .4418 .63408 L .44295 .63453 L F
0 .256 .724 r
.44064 .63292 m .44056 .63332 L .43933 .63256 L F
.988 .834 .601 r
.44064 .63292 m .4405 .63359 L .4418 .63408 L F
.4405 .63359 m .44011 .63545 L .4418 .63408 L F
0 .256 .724 r
.44064 .63292 m .43933 .63256 L .43759 .63298 L F
.718 .963 .942 r
.71623 .45529 m .71792 .45558 L .71992 .45415 L F
.736 .276 .158 r
.43248 .58744 m .43068 .58858 L .42933 .58662 L F
.145 .64 .913 r
.42933 .58662 m .42939 .58663 L .43091 .58654 L F
.42939 .58663 m .43248 .58744 L .4313 .58676 L F
.42939 .58663 m .4313 .58676 L .43091 .58654 L F
.718 .963 .7 r
.43326 .58594 m .43068 .58858 L .43248 .58744 L F
.461 .211 .448 r
.43238 .58684 m .43291 .58836 L .43068 .58858 L F
.43326 .58594 m .43313 .58688 L .43238 .58684 L F
.43313 .58688 m .43291 .58836 L .43238 .58684 L F
.58 .395 .595 r
.57919 .499 m .58151 .49586 L .57887 .49612 L F
.57919 .499 m .5815 .49876 L .58151 .49586 L F
.656 .559 .733 r
.58151 .49586 m .58442 .49546 L .58369 .49253 L F
.604 .398 .575 r
.5815 .49876 m .58442 .49546 L .58151 .49586 L F
.643 .158 .088 r
.63125 .43147 m .63526 .43329 L .63256 .4338 L F
.004 0 0 r
.16427 .54743 m .16611 .54701 L .16809 .5458 L F
.212 0 0 r
.16611 .54701 m .17007 .54469 L .16809 .5458 L F
.307 .143 .487 r
.53128 .58324 m .52931 .5816 L .53242 .58119 L F
0 0 0 r
.53321 .57961 m .53314 .5804 L .53242 .58119 L F
.53314 .5804 m .53128 .58324 L .53242 .58119 L F
.615 .786 .963 r
.53323 .58212 m .53128 .58324 L .53314 .5804 L F
.53306 .58134 m .53314 .5804 L .5326 .57918 L F
.53323 .58212 m .53314 .5804 L .53306 .58134 L F
0 0 0 r
.53418 .57769 m .53314 .5804 L .53321 .57961 L F
.674 .721 .884 r
.70471 .41268 m .70611 .4087 L .7036 .40939 L F
.70471 .41268 m .70705 .41234 L .70611 .4087 L F
.846 .98 .687 r
.54385 .49755 m .54532 .49656 L .5433 .49949 L F
.835 .998 .828 r
.54123 .50033 m .5433 .49949 L .54204 .50101 L F
.54123 .50033 m .54385 .49755 L .5433 .49949 L F
.131 0 .255 r
.20211 .63173 m .19995 .63473 L .20142 .63395 L F
0 0 0 r
.19995 .63473 m .19987 .63574 L .20142 .63395 L F
.19995 .63473 m .19957 .63724 L .19987 .63574 L F
.055 .618 .785 r
.63002 .43372 m .63121 .43358 L .6284 .43454 L F
.63002 .43372 m .63256 .4338 L .63121 .43358 L F
.416 .776 .995 r
.67579 .39905 m .67415 .39978 L .6719 .39922 L F
.952 .749 .592 r
.22155 .58362 m .22115 .58638 L .22337 .58743 L F
.966 .734 .538 r
.22134 .58892 m .22337 .58743 L .22115 .58638 L F
.22134 .58892 m .22274 .58991 L .22337 .58743 L F
.526 .566 .839 r
.22337 .58743 m .22381 .5835 L .22155 .58362 L F
.22337 .58743 m .22532 .58683 L .22381 .5835 L F
.367 .114 .392 r
.22337 .58743 m .22274 .58991 L .22532 .58683 L F
.392 0 0 r
.74743 .41454 m .75101 .41508 L .74785 .41408 L F
.803 .499 .475 r
.37574 .63139 m .37345 .63286 L .37164 .63043 L F
0 0 0 r
.37537 .63217 m .37574 .63139 L .3775 .63162 L F
.37537 .63217 m .37345 .63286 L .37574 .63139 L F
.336 .406 .786 r
.75482 .4202 m .75315 .42211 L .75211 .4186 L F
.106 .008 .449 r
.75482 .4202 m .75305 .42418 L .75315 .42211 L F
.933 .967 .693 r
.60942 .4336 m .61078 .43291 L .60949 .43229 L F
.60942 .4336 m .60847 .43669 L .61078 .43291 L F
.476 .871 .966 r
.61192 .4316 m .61078 .43291 L .61373 .43242 L F
.61192 .4316 m .60949 .43229 L .61078 .43291 L F
.487 .251 .482 r
.59103 .51048 m .59346 .51221 L .59115 .51258 L F
.59103 .51048 m .59336 .50999 L .59346 .51221 L F
.943 .811 .685 r
.54405 .69065 m .54492 .68834 L .5433 .68766 L F
.422 .242 .53 r
.2427 .61302 m .2409 .61109 L .24293 .61032 L F
.2427 .61302 m .24075 .61368 L .2409 .61109 L F
0 0 0 r
.20794 .65585 m .20577 .65781 L .20503 .65844 L F
.20929 .65475 m .20577 .65781 L .20794 .65585 L F
.702 .68 .826 r
.71447 .41349 m .7146 .41553 L .71695 .4127 L F
.507 .396 .662 r
.55165 .62573 m .55393 .62556 L .55469 .62372 L F
.46 .816 .997 r
.62482 .40068 m .62725 .40027 L .62879 .40122 L F
.468 .819 .997 r
.62879 .40122 m .62742 .40037 L .63135 .40063 L F
.62742 .40037 m .62781 .40032 L .63135 .40063 L F
.294 0 0 r
.62375 .40222 m .62628 .40191 L .62837 .40037 L F
.62827 .40036 m .62837 .40037 L .62854 .40025 L F
.62375 .40222 m .62837 .40037 L .62827 .40036 L F
.083 0 0 r
.6279 .40032 m .63035 .40056 L .63135 .40063 L F
.62781 .40032 m .62799 .40033 L .6279 .40032 L F
.62799 .40033 m .63035 .40056 L .6279 .40032 L F
.468 .819 .997 r
.62742 .40037 m .62725 .40027 L .62781 .40032 L F
.366 0 .002 r
.62482 .40068 m .62789 .40033 L .62725 .40027 L F
.083 0 0 r
.62725 .40027 m .62789 .40033 L .62781 .40032 L F
.366 0 .002 r
.62789 .40033 m .62854 .40025 L .62725 .40027 L F
.083 0 0 r
.62725 .40027 m .62843 .40038 L .62789 .40033 L F
.62843 .40038 m .63035 .40056 L .62781 .40032 L F
.366 0 .002 r
.62612 .40053 m .62375 .40222 L .62827 .40036 L F
.62789 .40033 m .62827 .40036 L .62854 .40025 L F
.62612 .40053 m .62827 .40036 L .62789 .40033 L F
.62482 .40068 m .62481 .4007 L .62612 .40053 L F
.62481 .4007 m .62375 .40222 L .62612 .40053 L F
.352 .252 .6 r
.63109 .40289 m .62879 .40122 L .63135 .40063 L F
.63109 .40289 m .62939 .40415 L .62879 .40122 L F
.922 .964 .783 r
.54385 .49755 m .54692 .49493 L .54532 .49656 L F
.866 .995 .77 r
.55224 .48714 m .5499 .49011 L .5504 .48808 L F
.803 .988 .885 r
.55494 .48483 m .55224 .48714 L .55286 .48514 L F
.835 .998 .774 r
.55224 .48714 m .5504 .48808 L .55286 .48514 L F
.13 0 0 r
.17446 .54107 m .17879 .54149 L .17664 .54173 L F
.154 .677 .88 r
.19216 .63431 m .19367 .63472 L .1898 .6343 L F
.1898 .6343 m .19367 .63472 L .19216 .63431 L F
.634 .927 .973 r
.19408 .63331 m .19367 .63472 L .19216 .63431 L F
.19216 .63431 m .19367 .63472 L .19408 .63331 L F
.5 .095 .205 r
.41697 .63312 m .41955 .63315 L .41734 .63195 L F
.616 .587 .798 r
.46671 .57487 m .46888 .57241 L .46609 .57382 L F
0 0 .294 r
.46671 .57487 m .46764 .5759 L .46982 .57543 L F
.46671 .57487 m .46672 .57747 L .46764 .5759 L F
0 0 .242 r
.23138 .63089 m .22971 .63425 L .22902 .63104 L F
.435 0 0 r
.19333 .5534 m .18954 .55384 L .19141 .55405 L F
.626 .146 0 r
.66496 .45374 m .66243 .4508 L .66442 .45144 L F
0 0 0 r
.72336 .4402 m .72038 .44211 L .72196 .43935 L F
.566 .862 .996 r
.72584 .43942 m .72336 .4402 L .72196 .43935 L F
.941 .959 .668 r
.54932 .49218 m .5504 .48808 L .5499 .49011 L F
.253 0 0 r
.48147 .63132 m .47778 .63113 L .47919 .63099 L F
.564 .726 .95 r
.40254 .60518 m .40497 .60494 L .40228 .60284 L F
.40254 .60518 m .40228 .60284 L .40206 .60295 L F
.071 0 0 r
.40848 .60525 m .40798 .60522 L .40497 .60494 L F
.733 .423 .455 r
.40335 .60121 m .39958 .60326 L .40195 .60281 L F
.326 .63 .961 r
.40497 .60494 m .40798 .60522 L .40199 .60261 L F
.683 .61 .768 r
.40317 .60219 m .40798 .60522 L .40628 .60107 L F
.741 .988 .892 r
.39958 .60326 m .39891 .60492 L .40195 .60281 L F
.547 .3 .493 r
.40028 .60547 m .39958 .60326 L .40097 .60453 L F
.893 .624 .523 r
.40115 .60428 m .4031 .60682 L .4005 .60558 L F
.40134 .60369 m .4005 .60558 L .40028 .60547 L F
.547 .3 .493 r
.40028 .60547 m .40097 .60453 L .40139 .60492 L F
.893 .624 .523 r
.40199 .60261 m .40209 .60301 L .40115 .60428 L F
.40209 .60301 m .4031 .60682 L .40115 .60428 L F
.40199 .60261 m .4005 .60558 L .40134 .60369 L F
.733 .423 .455 r
.40134 .60231 m .40136 .60364 L .39958 .60326 L F
.40134 .60369 m .40139 .60492 L .40097 .60453 L F
.40137 .60366 m .40139 .60492 L .40134 .60369 L F
.259 0 .145 r
.40199 .60261 m .40134 .60369 L .40207 .6026 L F
.683 .61 .768 r
.40199 .60261 m .40243 .6028 L .40258 .60268 L F
.40199 .60261 m .40258 .60268 L .40216 .60255 L F
.40243 .6028 m .40798 .60522 L .40317 .60219 L F
.564 .726 .95 r
.40206 .60295 m .40228 .60284 L .40199 .60261 L F
.888 .622 .529 r
.40406 .60622 m .4031 .60682 L .40199 .60261 L F
.733 .423 .455 r
.40193 .60249 m .40139 .60492 L .40134 .60231 L F
.259 0 .145 r
.40242 .60298 m .40413 .60235 L .4055 .60561 L F
.231 .357 .786 r
.40199 .60261 m .40238 .60295 L .40406 .60622 L F
.40241 .60298 m .40332 .60375 L .40328 .60387 L F
.40242 .60298 m .4055 .60561 L .40241 .60298 L F
.129 0 .117 r
.40242 .60298 m .40139 .60492 L .40241 .60299 L F
.231 .357 .786 r
.40238 .60295 m .40513 .60577 L .40406 .60622 L F
.129 0 .117 r
.40361 .60284 m .40139 .60492 L .40242 .60298 L F
.259 0 .145 r
.40199 .60261 m .40207 .6026 L .40238 .60295 L F
.733 .423 .455 r
.40241 .60298 m .40139 .60492 L .40193 .60249 L F
.831 .989 .867 r
.40361 .60284 m .40028 .60547 L .40139 .60492 L F
.129 0 .117 r
.40413 .60235 m .40361 .60284 L .40242 .60298 L F
.831 .989 .867 r
.40413 .60235 m .40364 .60275 L .40361 .60284 L F
.40364 .60275 m .40028 .60547 L .40361 .60284 L F
.231 .357 .786 r
.40328 .60387 m .4055 .60561 L .40513 .60577 L F
.40332 .60375 m .4055 .60561 L .40328 .60387 L F
.733 .423 .455 r
.40258 .60268 m .40241 .60298 L .40238 .60295 L F
.231 .357 .786 r
.40238 .60295 m .40242 .60298 L .40241 .60298 L F
.129 0 .117 r
.40413 .60235 m .40241 .60299 L .40257 .60269 L F
.259 0 .145 r
.40238 .60295 m .40413 .60235 L .40242 .60298 L F
.733 .423 .455 r
.40258 .60268 m .40238 .60295 L .40198 .6025 L F
.259 0 .145 r
.40207 .6026 m .40413 .60235 L .40238 .60295 L F
.733 .423 .455 r
.40198 .6025 m .40238 .60295 L .40193 .60249 L F
.259 0 .145 r
.40207 .6026 m .40028 .60547 L .40413 .60235 L F
.733 .423 .455 r
.40136 .60364 m .40097 .60453 L .39958 .60326 L F
.259 0 .145 r
.40134 .60369 m .40028 .60547 L .40207 .6026 L F
.733 .423 .455 r
.40136 .60364 m .40137 .60366 L .40134 .60369 L F
.683 .61 .768 r
.40199 .60261 m .40216 .60255 L .40335 .60121 L F
.733 .423 .455 r
.40335 .60121 m .40258 .60268 L .40216 .60255 L F
.683 .61 .768 r
.40317 .60219 m .40628 .60107 L .40335 .60121 L F
.129 0 .117 r
.40371 .60174 m .40317 .60219 L .40335 .60121 L F
.40317 .60219 m .40258 .60268 L .40335 .60121 L F
.683 .61 .768 r
.40216 .60255 m .40317 .60219 L .40335 .60121 L F
.733 .423 .455 r
.40335 .60121 m .40216 .60255 L .40134 .60231 L F
.683 .61 .768 r
.40216 .60255 m .40258 .60268 L .40317 .60219 L F
.129 0 .117 r
.40391 .60203 m .40257 .60269 L .40258 .60268 L F
.40391 .60203 m .40258 .60268 L .40371 .60174 L F
.40413 .60235 m .40257 .60269 L .40391 .60203 L F
.909 .949 .815 r
.53986 .50444 m .54123 .50033 L .54204 .50101 L F
.126 .67 .825 r
.20947 .55265 m .20797 .55243 L .20558 .55256 L F
.266 0 0 r
.21145 .55266 m .20797 .55243 L .20947 .55265 L F
.419 .405 .737 r
.23185 .57214 m .23323 .56906 L .23175 .56933 L F
.23185 .57214 m .23377 .57123 L .23323 .56906 L F
.542 .291 .486 r
.23185 .57214 m .23392 .57448 L .23377 .57123 L F
.23185 .57214 m .23009 .57538 L .23392 .57448 L F
0 0 0 r
.19345 .67604 m .1938 .67553 L .19467 .67286 L F
.641 .924 .648 r
.19276 .67658 m .1938 .67553 L .19345 .67604 L F
.217 .426 .851 r
.38557 .63735 m .38635 .63606 L .38296 .63429 L F
.38557 .63735 m .38671 .63731 L .38635 .63606 L F
.147 .65 .906 r
.23451 .54308 m .23683 .54325 L .23838 .54387 L F
.435 .798 .996 r
.23683 .54325 m .2401 .54363 L .23838 .54387 L F
.571 .443 .667 r
.54688 .5513 m .54477 .55451 L .54476 .55187 L F
.372 .42 .781 r
.36384 .61362 m .36478 .61703 L .3665 .61561 L F
.629 .585 .786 r
.36512 .61946 m .3665 .61561 L .36478 .61703 L F
.873 .499 .333 r
.52531 .5809 m .522 .57762 L .5235 .57783 L F
.61 .659 .873 r
.36083 .62556 m .36413 .62652 L .36294 .62423 L F
.848 .916 .879 r
.51297 .53947 m .51226 .53826 L .51405 .53947 L F
.784 .89 .921 r
.51552 .53612 m .51405 .53947 L .51226 .53826 L F
.51552 .53612 m .51675 .53714 L .51405 .53947 L F
0 0 0 r
.39775 .60466 m .39638 .60472 L .39891 .60492 L F
.39775 .60466 m .39479 .60553 L .39638 .60472 L F
.22075 .57656 m .22074 .57556 L .22046 .57434 L F
.22075 .57656 m .22015 .57914 L .22074 .57556 L F
.853 .566 .502 r
.56939 .63942 m .57293 .63889 L .57062 .63634 L F
.78 .538 .57 r
.42853 .57469 m .43234 .57268 L .43103 .57175 L F
.42853 .57469 m .43227 .57514 L .43234 .57268 L F
.401 .491 .836 r
.43234 .57268 m .43323 .56902 L .43103 .57175 L F
.59 .567 .797 r
.4356 .57365 m .43761 .57381 L .43645 .57295 L F
.597 .598 .823 r
.43323 .56902 m .43576 .57413 L .43645 .57295 L F
.59 .567 .797 r
.4348 .57431 m .43593 .57411 L .4356 .57365 L F
.43593 .57411 m .43761 .57381 L .4356 .57365 L F
.401 .491 .836 r
.43234 .57268 m .43576 .57413 L .43536 .57333 L F
.43297 .57007 m .43536 .57333 L .43323 .56902 L F
.43234 .57268 m .43536 .57333 L .43297 .57007 L F
.58 .371 .562 r
.4348 .57431 m .43227 .57514 L .43234 .57268 L F
.892 .747 .694 r
.51636 .54842 m .51395 .55008 L .51371 .54976 L F
.671 .58 .745 r
.46157 .58768 m .46313 .58786 L .46267 .58484 L F
.46157 .58768 m .46313 .58786 L .46267 .58484 L F
.418 .324 .642 r
.36221 .6053 m .36396 .60123 L .3621 .60185 L F
.181 .286 .736 r
.39581 .62404 m .39392 .62358 L .39299 .62163 L F
.39581 .62404 m .39496 .62529 L .39392 .62358 L F
.927 .739 .628 r
.67265 .4384 m .67521 .43614 L .67388 .43507 L F
.67265 .4384 m .67426 .43971 L .67521 .43614 L F
.603 .364 .527 r
.23017 .5634 m .2325 .56327 L .23307 .56098 L F
.504 .489 .774 r
.23187 .55828 m .23307 .56098 L .23491 .56006 L F
.54 .303 .506 r
.23307 .56098 m .23491 .56247 L .23491 .56006 L F
.23307 .56098 m .2325 .56327 L .23491 .56247 L F
.595 .922 .696 r
.62467 .4522 m .62186 .45455 L .62336 .45291 L F
0 0 .11 r
.62186 .45455 m .62221 .45476 L .62336 .45291 L F
.62186 .45455 m .62182 .45698 L .62221 .45476 L F
.61 .683 .894 r
.7112 .41295 m .71216 .40898 L .70983 .40994 L F
.7112 .41295 m .71371 .41243 L .71216 .40898 L F
.606 .571 .789 r
.7112 .41295 m .71447 .41349 L .71371 .41243 L F
.577 .181 .256 r
.5587 .62155 m .55876 .62183 L .55641 .62036 L F
0 0 .024 r
.21478 .57577 m .21267 .57821 L .21415 .57679 L F
.107 .083 .545 r
.21415 .57679 m .21529 .57417 L .21478 .57577 L F
.794 .951 .921 r
.19683 .63962 m .19533 .64124 L .19261 .64109 L F
.672 .797 .941 r
.56984 .62603 m .57213 .62503 L .57321 .6263 L F
.569 .754 .965 r
.57213 .62503 m .57583 .62573 L .57321 .6263 L F
.771 .982 .726 r
.72949 .44665 m .72837 .44878 L .73088 .44602 L F
.49 .88 .701 r
.73249 .4447 m .73088 .44602 L .733 .44475 L F
.73249 .4447 m .72949 .44665 L .73088 .44602 L F
.513 .224 .413 r
.59765 .48868 m .59825 .48708 L .59538 .48936 L F
.337 .141 .461 r
.60034 .48389 m .59825 .48708 L .60001 .48602 L F
.215 0 .269 r
.60001 .48602 m .59825 .48708 L .59765 .48868 L F
.821 .75 .784 r
.5708 .499 m .5731 .4964 L .57145 .4952 L F
.751 .637 .734 r
.58039 .62784 m .5772 .62895 L .5797 .62919 L F
.101 0 .313 r
.58039 .62784 m .5797 .62919 L .58129 .62797 L F
.371 .352 .709 r
.58129 .62797 m .5797 .62919 L .57961 .62809 L F
.58001 .62775 m .57958 .62767 L .5795 .62666 L F
0 .484 .731 r
.58039 .62784 m .58129 .62797 L .58001 .62775 L F
.578 .859 .531 r
.58035 .62783 m .57961 .62809 L .58039 .62784 L F
.57961 .62809 m .57958 .62812 L .58039 .62784 L F
.371 .352 .709 r
.58129 .62797 m .57961 .62809 L .58046 .62737 L F
.749 .644 .744 r
.57961 .62809 m .5772 .62895 L .5795 .62666 L F
.758 .659 .752 r
.5795 .62666 m .5772 .62895 L .57583 .62573 L F
0 .484 .731 r
.58001 .62775 m .58129 .62797 L .57849 .62738 L F
.371 .352 .709 r
.58046 .62737 m .58001 .62775 L .5795 .62666 L F
.58001 .62775 m .57961 .62809 L .57958 .62767 L F
.578 .859 .531 r
.57961 .62809 m .5772 .62895 L .57958 .62812 L F
.57849 .62738 m .5772 .62895 L .58035 .62783 L F
.749 .644 .744 r
.5797 .62919 m .5772 .62895 L .57961 .62809 L F
.795 .567 .591 r
.53435 .57254 m .53028 .57425 L .53134 .57296 L F
.645 .461 .62 r
.66839 .43094 m .6682 .43354 L .66636 .43366 L F
.66839 .43094 m .6682 .43354 L .66636 .43366 L F
.954 .939 .617 r
.6681 .42939 m .66839 .43094 L .66932 .42831 L F
.073 .152 .642 r
.6681 .42939 m .6682 .43354 L .66839 .43094 L F
.772 .993 .88 r
.72626 .44926 m .72837 .44878 L .72949 .44665 L F
.695 .62 .769 r
.56588 .6234 m .56357 .6254 L .56251 .62197 L F
.073 .563 .895 r
.24825 .54757 m .25011 .54792 L .25181 .54888 L F
.103 .52 .909 r
.25205 .54798 m .25181 .54888 L .25011 .54792 L F
.25205 .54798 m .2539 .54949 L .25181 .54888 L F
.218 .717 .91 r
.4507 .57206 m .44884 .57153 L .44672 .57165 L F
.791 .968 .665 r
.45885 .57173 m .4565 .57484 L .45733 .57424 L F
.571 .326 .506 r
.55869 .53125 m .5611 .53328 L .55857 .53363 L F
.55869 .53125 m .56122 .53095 L .5611 .53328 L F
.535 .245 .421 r
.58152 .5006 m .57919 .499 L .579 .50109 L F
.58152 .5006 m .5815 .49876 L .57919 .499 L F
.48 .893 .918 r
.20577 .65781 m .20562 .65758 L .20503 .65844 L F
.514 .915 .878 r
.20562 .65758 m .20362 .65855 L .20503 .65844 L F
.057 .357 .829 r
.22093 .57919 m .22195 .58151 L .22015 .57914 L F
.95 .791 .338 r
.22128 .58264 m .22195 .58151 L .22093 .57919 L F
.22128 .58264 m .22155 .58362 L .22195 .58151 L F
.545 .258 .429 r
.22155 .58362 m .22381 .5835 L .22195 .58151 L F
.489 .29 .537 r
.58311 .5189 m .58317 .5166 L .58529 .51601 L F
.977 .819 .621 r
.65304 .42798 m .65244 .42429 L .65264 .42658 L F
.735 .691 .148 r
.65279 .42916 m .65304 .42798 L .65264 .42658 L F
.65279 .42916 m .65263 .43041 L .65304 .42798 L F
.497 .305 .55 r
.44821 .59271 m .45057 .58968 L .44888 .59089 L F
.899 .781 .291 r
.65244 .42429 m .65282 .42218 L .65254 .41993 L F
.965 .799 .625 r
.51888 .57 m .51701 .57145 L .51701 .56898 L F
.51888 .57 m .51842 .57232 L .51701 .57145 L F
.499 .18 .356 r
.47443 .62815 m .47699 .62803 L .47769 .62549 L F
.722 .524 .622 r
.47699 .62803 m .48026 .6252 L .47769 .62549 L F
.591 .052 0 r
.3775 .63162 m .3781 .6326 L .37537 .63217 L F
.3775 .63162 m .37964 .6337 L .3781 .6326 L F
.309 0 0 r
.42389 .59173 m .42298 .59258 L .42036 .59271 L F
0 0 0 r
.42504 .5918 m .42389 .59173 L .42588 .59133 L F
.42504 .5918 m .42298 .59258 L .42389 .59173 L F
.583 .586 .82 r
.36294 .62423 m .36413 .62652 L .36625 .62587 L F
.631 .872 .519 r
.6426 .41186 m .64326 .41128 L .64206 .41274 L F
0 .104 .606 r
.6461 .41391 m .64326 .41128 L .64555 .41205 L F
.424 0 0 r
.64555 .41205 m .64326 .41128 L .6426 .41186 L F
.61 .666 .879 r
.46524 .56921 m .46103 .56644 L .4634 .56611 L F
.576 .622 .861 r
.46596 .56516 m .46524 .56921 L .4634 .56611 L F
.46596 .56516 m .46805 .56855 L .46524 .56921 L F
.621 .725 .921 r
.69839 .41095 m .70113 .41028 L .69756 .40942 L F
.688 .549 .69 r
.22045 .56081 m .22355 .56074 L .22294 .55774 L F
.398 .283 .605 r
.22294 .55774 m .22464 .55764 L .22443 .55465 L F
.43 .202 .466 r
.20938 .62304 m .21148 .62243 L .21185 .61989 L F
.463 .31 .588 r
.21185 .61989 m .21392 .61938 L .21386 .61668 L F
.012 0 .305 r
.21185 .61989 m .2127 .62105 L .21392 .61938 L F
.21185 .61989 m .21148 .62243 L .2127 .62105 L F
.244 0 .309 r
.20211 .63173 m .203 .63317 L .20431 .63127 L F
.20211 .63173 m .20142 .63395 L .203 .63317 L F
.511 .331 .573 r
.20211 .63173 m .20431 .63127 L .20439 .62865 L F
.734 .739 .855 r
.74228 .41646 m .74617 .41775 L .74492 .41552 L F
.618 .694 .898 r
.74617 .41775 m .74743 .41454 L .74492 .41552 L F
.74617 .41775 m .74868 .4163 L .74743 .41454 L F
.557 .379 .596 r
.55142 .54018 m .55099 .54248 L .54898 .543 L F
.472 .27 .524 r
.55099 .54248 m .54894 .5457 L .54898 .543 L F
.846 .64 .624 r
.58337 .61888 m .58752 .62112 L .58664 .61703 L F
.591 .932 .739 r
.40959 .60396 m .40848 .60525 L .41136 .60544 L F
.40959 .60396 m .40798 .60522 L .40848 .60525 L F
.929 .894 .773 r
.61292 .41313 m .61179 .41208 L .61365 .4087 L F
.636 .599 .796 r
.61562 .41455 m .61179 .41208 L .61292 .41313 L F
.758 .712 .809 r
.63989 .44185 m .63919 .44646 L .63741 .44444 L F
.63989 .44185 m .64111 .4449 L .63919 .44646 L F
.408 .859 .878 r
.6821 .41487 m .6871 .41368 L .68585 .41234 L F
.855 .898 .866 r
.68585 .41234 m .6871 .41368 L .68801 .41232 L F
.853 .566 .502 r
.56939 .63942 m .57062 .63634 L .57131 .63429 L F
.785 .575 .617 r
.57473 .63692 m .57131 .63429 L .57062 .63634 L F
.677 .452 .573 r
.22045 .56081 m .22285 .56316 L .22355 .56074 L F
.22045 .56081 m .22024 .56332 L .22285 .56316 L F
.379 .186 .489 r
.23613 .62219 m .23586 .62482 L .23326 .62467 L F
.322 .102 .417 r
.23586 .62482 m .23372 .62776 L .23326 .62467 L F
.928 .958 .778 r
.4393 .56861 m .43845 .57208 L .44097 .57157 L F
.4393 .56861 m .43645 .57295 L .43845 .57208 L F
.233 .713 .934 r
.20864 .54053 m .211 .54044 L .21312 .5412 L F
.258 .744 .923 r
.211 .54044 m .21505 .54082 L .21312 .5412 L F
.686 .642 .801 r
.71812 .41626 m .71955 .41205 L .71695 .4127 L F
.71812 .41626 m .72079 .41544 L .71955 .41205 L F
.643 .243 .271 r
.48762 .62859 m .48611 .63072 L .48309 .62977 L F
.721 .216 .029 r
.4902 .62519 m .4861 .62278 L .48797 .62742 L F
.153 .43 .868 r
.48853 .62763 m .48762 .62859 L .48549 .62581 L F
.148 0 0 r
.48847 .62978 m .48762 .62859 L .48853 .62763 L F
.48847 .62978 m .48611 .63072 L .48762 .62859 L F
.419 .319 .635 r
.25959 .55864 m .2601 .56371 L .2581 .56366 L F
.419 .336 .656 r
.2601 .56371 m .26028 .56558 L .2581 .56366 L F
.4 .335 .669 r
.2581 .56366 m .26028 .56558 L .25843 .56561 L F
.586 .771 .968 r
.68455 .40864 m .68305 .41073 L .68184 .40908 L F
.68455 .40864 m .68576 .41019 L .68305 .41073 L F
.722 .758 .881 r
.73416 .40453 m .73127 .40686 L .73057 .40399 L F
.784 .974 .914 r
.6988 .46179 m .70287 .45995 L .70197 .45937 L F
.566 .9 .981 r
.70437 .45844 m .70287 .45995 L .70539 .45871 L F
.70437 .45844 m .70197 .45937 L .70287 .45995 L F
.155 0 0 r
.22944 .55706 m .22745 .55752 L .22464 .55764 L F
.372 .838 .802 r
.22926 .55678 m .22944 .55706 L .23095 .55722 L F
.22926 .55678 m .22745 .55752 L .22944 .55706 L F
.183 0 0 r
.3686 .59547 m .37069 .59497 L .37215 .59333 L F
.324 0 0 r
.37069 .59497 m .37449 .59291 L .37215 .59333 L F
.595 .809 .982 r
.54489 .66692 m .54901 .66712 L .54752 .66405 L F
.645 .35 .457 r
.54454 .66888 m .54731 .66934 L .54901 .66712 L F
.666 .378 .474 r
.54731 .66934 m .55094 .66937 L .54901 .66712 L F
.892 .795 .745 r
.7315 .41176 m .73493 .40962 L .73425 .4092 L F
.7315 .41176 m .73289 .41317 L .73493 .40962 L F
.605 .877 .992 r
.73493 .40962 m .73631 .40779 L .73425 .4092 L F
.73493 .40962 m .73735 .40866 L .73631 .40779 L F
.932 .766 .652 r
.67058 .4561 m .67321 .45413 L .6729 .45318 L F
.67058 .4561 m .67298 .45672 L .67321 .45413 L F
.702 .415 0 r
.67228 .45093 m .6729 .45318 L .67321 .45413 L F
.252 .71 .952 r
.20507 .53983 m .20864 .54053 L .20681 .54079 L F
.352 0 .105 r
.40216 .58122 m .4047 .58075 L .40586 .57868 L F
.141 0 .001 r
.40586 .57868 m .40674 .57986 L .40813 .57821 L F
.40586 .57868 m .4047 .58075 L .40674 .57986 L F
.784 .494 .496 r
.52931 .5816 m .5255 .5833 L .52531 .5809 L F
.52931 .5816 m .52947 .58375 L .5255 .5833 L F
.307 .143 .487 r
.53128 .58324 m .52947 .58375 L .52931 .5816 L F
.919 .915 .798 r
.59113 .46665 m .58931 .46667 L .5905 .46817 L F
.905 .936 .821 r
.58931 .46667 m .58787 .47103 L .5905 .46817 L F
.496 .57 .86 r
.39153 .61847 m .39074 .62104 L .38993 .61875 L F
.39153 .61847 m .39299 .62163 L .39074 .62104 L F
.529 .351 .584 r
.24927 .59647 m .24947 .59885 L .24741 .59902 L F
.441 .269 .551 r
.24916 .60058 m .24741 .59902 L .24947 .59885 L F
.24916 .60058 m .24711 .60164 L .24741 .59902 L F
.547 .366 .587 r
.58442 .49546 m .58655 .49168 L .58369 .49253 L F
.58442 .49546 m .5871 .49467 L .58655 .49168 L F
.637 .405 .549 r
.5897 .4946 m .58655 .49168 L .5871 .49467 L F
.5897 .4946 m .58978 .49233 L .58655 .49168 L F
.469 .342 .624 r
.53696 .675 m .53454 .67352 L .53647 .67251 L F
.7 .198 .046 r
.53316 .67428 m .53454 .67352 L .53088 .67256 L F
.954 .939 .617 r
.6681 .42939 m .66932 .42831 L .66826 .4269 L F
.376 .062 .301 r
.46269 .58958 m .46313 .58786 L .46545 .58712 L F
.57 .802 .987 r
.43617 .59298 m .43982 .59354 L .43845 .59235 L F
.43617 .59298 m .43982 .59354 L .43845 .59235 L F
.946 .834 .702 r
.44023 .59087 m .43982 .59354 L .43845 .59235 L F
.422 .779 .996 r
.43982 .59354 m .4406 .59238 L .43845 .59235 L F
.43982 .59354 m .44242 .59326 L .4406 .59238 L F
.639 .926 .655 r
.59315 .43908 m .59445 .43735 L .59593 .43635 L F
0 0 0 r
.59315 .43908 m .59323 .43902 L .59445 .43735 L F
.943 .819 .692 r
.54823 .67489 m .55058 .67337 L .54874 .67234 L F
.54823 .67489 m .54976 .67571 L .55058 .67337 L F
.691 .973 .775 r
.2163 .56711 m .21497 .56819 L .21489 .56778 L F
0 .043 .589 r
.21489 .56778 m .21577 .56844 L .21475 .56706 L F
.848 .66 .121 r
.21489 .56778 m .21445 .56665 L .2144 .56425 L F
0 .043 .589 r
.21489 .56778 m .21475 .56706 L .21445 .56665 L F
.691 .973 .775 r
.21497 .56819 m .21399 .56898 L .21489 .56778 L F
.727 .639 .761 r
.21614 .56249 m .2144 .56425 L .21601 .56239 L F
.897 .959 .828 r
.21839 .5645 m .2163 .56711 L .21461 .56529 L F
.21839 .5645 m .21461 .56529 L .21468 .56517 L F
.044 0 0 r
.21839 .5645 m .21906 .56475 L .22024 .56332 L F
.21839 .5645 m .21452 .5652 L .21906 .56475 L F
.727 .639 .761 r
.21906 .56475 m .21514 .56433 L .21614 .56249 L F
.21514 .56433 m .2144 .56425 L .21614 .56249 L F
.897 .959 .828 r
.21468 .56517 m .21461 .56529 L .21452 .5652 L F
.848 .66 .121 r
.21489 .56778 m .2144 .56425 L .21452 .5652 L F
.964 .93 .705 r
.2163 .56711 m .21489 .56778 L .21452 .5652 L F
.206 0 .27 r
.25375 .59004 m .25157 .59253 L .25148 .59032 L F
.583 .712 .932 r
.69625 .40084 m .6932 .4001 L .69537 .39922 L F
.521 .688 .943 r
.69865 .40047 m .69625 .40084 L .69537 .39922 L F
.765 .71 .8 r
.44242 .59326 m .44353 .59622 L .44597 .59325 L F
.315 .339 .727 r
.23175 .56933 m .2321 .56563 L .2302 .56657 L F
.23175 .56933 m .23323 .56906 L .2321 .56563 L F
.481 .033 .107 r
.18531 .55445 m .1833 .5564 L .18146 .55615 L F
.575 .142 .18 r
.18702 .55574 m .18531 .55445 L .18762 .55455 L F
.18702 .55574 m .1833 .5564 L .18531 .55445 L F
.632 .693 .889 r
.70611 .4087 m .70705 .41234 L .70983 .40994 L F
.255 .483 .885 r
.23187 .55828 m .23257 .55694 L .23095 .55722 L F
.23187 .55828 m .23491 .56006 L .23257 .55694 L F
.467 .408 .707 r
.5336 .57509 m .53202 .5778 L .53028 .57425 L F
.5336 .57509 m .53418 .57769 L .53202 .5778 L F
.915 .914 .802 r
.538 .50758 m .53897 .50345 L .53986 .50444 L F
.909 .949 .815 r
.53986 .50444 m .53897 .50345 L .54123 .50033 L F
.576 .302 .463 r
.56349 .52862 m .56609 .53065 L .56367 .53067 L F
.56349 .52862 m .56695 .52783 L .56609 .53065 L F
.911 .894 .799 r
.63274 .46731 m .63574 .46507 L .63444 .46523 L F
.575 .661 .896 r
.71551 .40468 m .71207 .40331 L .71457 .4027 L F
.613 .65 .863 r
.71698 .40201 m .71551 .40468 L .71457 .4027 L F
.71698 .40201 m .71806 .40395 L .71551 .40468 L F
.501 .287 .52 r
.46839 .58376 m .46545 .58712 L .46515 .58406 L F
.446 .33 .628 r
.54284 .5601 m .54045 .56123 L .54232 .55835 L F
.651 .494 .657 r
.54351 .56322 m .54045 .56123 L .54284 .5601 L F
.54351 .56322 m .54111 .56406 L .54045 .56123 L F
.04 0 .341 r
.21411 .5895 m .21581 .58644 L .21414 .58723 L F
.643 .67 .861 r
.72408 .40435 m .72162 .40626 L .72054 .40298 L F
.804 .488 .456 r
.60355 .44243 m .60367 .44462 L .60765 .44475 L F
.902 .89 .81 r
.60367 .44713 m .60765 .44475 L .60367 .44462 L F
.60367 .44713 m .60487 .44834 L .60765 .44475 L F
.719 .772 .894 r
.72675 .40357 m .72527 .4072 L .72408 .40435 L F
.72675 .40357 m .72777 .40607 L .72527 .4072 L F
0 0 0 r
.20938 .62304 m .20634 .62553 L .20845 .62413 L F
.20845 .62413 m .21148 .62243 L .20938 .62304 L F
.534 .167 .29 r
.44073 .5897 m .44464 .58722 L .44086 .58666 L F
.44073 .5897 m .44347 .58982 L .44464 .58722 L F
.694 .336 .364 r
.44464 .58722 m .44347 .58982 L .44658 .58904 L F
.654 .352 .449 r
.44658 .58904 m .44737 .58717 L .44464 .58722 L F
0 0 .297 r
.51271 .5433 m .51117 .53918 L .51297 .53947 L F
.737 .882 .947 r
.51253 .54263 m .51355 .54348 L .51626 .54172 L F
.51253 .54263 m .51626 .54172 L .51585 .54184 L F
.636 .21 .217 r
.51585 .54184 m .51255 .54249 L .51253 .54263 L F
0 0 .297 r
.5125 .54275 m .51253 .54263 L .51117 .53918 L F
.636 .21 .217 r
.51255 .54249 m .51104 .54279 L .51253 .54263 L F
0 0 .297 r
.51271 .5433 m .51253 .54263 L .5125 .54275 L F
0 .455 .854 r
.51271 .5433 m .51355 .54348 L .51253 .54263 L F
.94 .96 .743 r
.59087 .46432 m .59113 .46665 L .59305 .46342 L F
.869 .995 .789 r
.59485 .45994 m .59305 .46342 L .59538 .46038 L F
.59485 .45994 m .59257 .46277 L .59305 .46342 L F
.872 .995 .785 r
.59257 .46277 m .59087 .46432 L .59305 .46342 L F
.445 .21 .462 r
.36396 .60123 m .36644 .59847 L .36407 .59911 L F
.913 .74 .654 r
.65182 .44394 m .65459 .44137 L .65281 .44175 L F
.65182 .44394 m .65356 .44528 L .65459 .44137 L F
.821 .75 .784 r
.5708 .499 m .57145 .4952 L .56956 .49852 L F
.944 .795 .666 r
.56956 .49852 m .57048 .50165 L .5708 .499 L F
.459 .857 .972 r
.6689 .43541 m .67047 .4338 L .6682 .43354 L F
.6689 .43541 m .6728 .43513 L .67047 .4338 L F
.693 .791 .926 r
.64211 .45064 m .64383 .44742 L .64093 .4497 L F
.56 .816 .446 r
.53023 .65526 m .53129 .6539 L .5326 .65227 L F
.567 .39 .601 r
.5326 .65227 m .53306 .65508 L .53023 .65526 L F
.463 .764 .995 r
.53129 .6539 m .53306 .65508 L .53023 .65526 L F
.546 .625 .882 r
.22632 .56565 m .22808 .56772 L .2302 .56657 L F
0 .049 .615 r
.65699 .41477 m .65699 .41601 L .6587 .41799 L F
.725 .984 .901 r
.5567 .48339 m .55494 .48483 L .55286 .48514 L F
.837 .982 .695 r
.59619 .45811 m .59538 .46038 L .59762 .45725 L F
.84 .998 .786 r
.59619 .45811 m .59485 .45994 L .59538 .46038 L F
.321 .143 .477 r
.20123 .67748 m .1992 .68073 L .19979 .67866 L F
.456 .325 .613 r
.25157 .59253 m .25098 .59624 L .24927 .59647 L F
.425 .265 .559 r
.25098 .59624 m .24947 .59885 L .24927 .59647 L F
.894 .635 .538 r
.64433 .45006 m .64712 .44693 L .64725 .44792 L F
.307 .533 .907 r
.64959 .44693 m .64712 .44693 L .6469 .44612 L F
.29 0 .128 r
.64725 .44792 m .64712 .44693 L .64959 .44693 L F
.672 .814 .951 r
.41929 .60073 m .41692 .60179 L .41527 .60059 L F
.481 0 0 r
.41929 .60073 m .41527 .60059 L .41692 .60179 L F
.596 .791 .974 r
.36835 .62587 m .36988 .62739 L .37244 .62653 L F
0 0 0 r
.42478 .56846 m .42615 .56823 L .42755 .56646 L F
.432 .733 .99 r
.42814 .56468 m .43091 .56566 L .42755 .56646 L F
0 0 0 r
.42755 .56646 m .42748 .56668 L .42814 .56468 L F
.42755 .56646 m .42615 .56823 L .42748 .56668 L F
.418 .324 .642 r
.36221 .6053 m .36395 .60479 L .36396 .60123 L F
.285 .223 .61 r
.36293 .60774 m .36395 .60479 L .36221 .6053 L F
.607 .726 .929 r
.71335 .40037 m .71207 .40331 L .71075 .40099 L F
.71335 .40037 m .71457 .4027 L .71207 .40331 L F
.97 .789 .604 r
.44244 .63609 m .4428 .63723 L .44308 .63568 L F
.943 .787 .658 r
.4418 .63408 m .44088 .63673 L .4428 .63723 L F
.723 .297 .235 r
.44088 .63673 m .44565 .63754 L .4428 .63723 L F
.44132 .63681 m .44357 .63931 L .44565 .63754 L F
.44088 .63673 m .4411 .63694 L .44132 .63681 L F
.4411 .63694 m .44357 .63931 L .44132 .63681 L F
.97 .789 .604 r
.4418 .63408 m .44244 .63609 L .44325 .63469 L F
.44244 .63609 m .44308 .63568 L .44325 .63469 L F
.984 .74 .486 r
.46769 .67883 m .46619 .68052 L .46632 .67767 L F
.421 .737 .992 r
.46857 .67752 m .46769 .67883 L .46632 .67767 L F
.615 .86 .502 r
.46857 .67752 m .46619 .68052 L .46769 .67883 L F
.522 .841 .999 r
.19032 .66314 m .19197 .66309 L .19017 .66177 L F
.486 .633 .919 r
.19197 .66309 m .19456 .66186 L .19017 .66177 L F
.19197 .66309 m .19772 .6641 L .19456 .66186 L F
.35 .811 .93 r
.63256 .4338 m .63387 .43283 L .63121 .43358 L F
.63256 .4338 m .63526 .43329 L .63387 .43283 L F
.848 .916 .879 r
.51297 .53947 m .51117 .53918 L .51226 .53826 L F
.17 .678 .902 r
.4444 .57206 m .44295 .57155 L .44097 .57157 L F
.634 .919 .978 r
.44551 .57072 m .4444 .57206 L .44672 .57165 L F
.44551 .57072 m .44295 .57155 L .4444 .57206 L F
.572 .801 .986 r
.69537 .39922 m .6932 .4001 L .69133 .39854 L F
1 .812 .483 r
.64054 .41581 m .64027 .41832 L .63917 .41665 L F
.803 .595 .622 r
.64054 .41581 m .64226 .41899 L .64027 .41832 L F
.745 .864 .436 r
.64206 .41274 m .64054 .41581 L .64138 .41356 L F
.807 .968 .659 r
.64138 .41356 m .64054 .41581 L .63917 .41665 L F
.807 .677 .72 r
.56686 .50115 m .5646 .50428 L .5681 .50466 L F
.668 .583 .751 r
.5646 .50428 m .56824 .50717 L .5681 .50466 L F
.755 .651 .746 r
.56686 .50115 m .5681 .50466 L .57048 .50165 L F
.7 .568 .703 r
.57048 .50165 m .5681 .50466 L .57094 .50408 L F
.697 .444 .536 r
.5681 .50466 m .57054 .50666 L .57094 .50408 L F
.5681 .50466 m .56824 .50717 L .57054 .50666 L F
.616 .552 .76 r
.54148 .67882 m .54218 .6738 L .54006 .67503 L F
.54148 .67882 m .54395 .67824 L .54218 .6738 L F
.623 .48 .666 r
.5532 .53738 m .5537 .5395 L .55142 .54018 L F
.534 .262 .448 r
.55142 .54018 m .55267 .54132 L .55099 .54248 L F
.55142 .54018 m .5537 .5395 L .55267 .54132 L F
.646 .835 .973 r
.6921 .45464 m .68949 .45606 L .68763 .45478 L F
0 0 0 r
.74088 .44111 m .742 .44014 L .74376 .43869 L F
.475 .242 .482 r
.20439 .62865 m .20609 .63046 L .20655 .62816 L F
.393 .236 .546 r
.20439 .62865 m .20431 .63127 L .20609 .63046 L F
.475 .242 .482 r
.20439 .62865 m .20609 .63046 L .20655 .62816 L F
.754 .535 .598 r
.22355 .56074 m .22285 .56316 L .22604 .5634 L F
.476 .322 .592 r
.26001 .57559 m .26007 .5779 L .25803 .57848 L F
.467 .31 .585 r
.26007 .5779 m .25807 .58103 L .25803 .57848 L F
.655 .406 .531 r
.61005 .47435 m .60756 .4724 L .60761 .47492 L F
.61005 .47435 m .61022 .47208 L .60756 .4724 L F
.721 .216 .029 r
.4902 .62519 m .48947 .62542 L .4861 .62278 L F
.375 .416 .775 r
.4861 .62278 m .48947 .62542 L .48842 .62271 L F
.736 .698 .815 r
.56686 .50115 m .57048 .50165 L .56956 .49852 L F
.666 .665 .839 r
.64372 .44321 m .64111 .4449 L .63989 .44185 L F
.476 .816 .999 r
.68054 .39911 m .6804 .39966 L .6794 .39859 L F
.693 .513 .64 r
.75889 .40749 m .75956 .41005 L .75692 .40929 L F
.255 .484 .886 r
.76122 .40692 m .75889 .40749 L .7587 .40554 L F
.76122 .40692 m .76193 .40883 L .75889 .40749 L F
.516 .404 .665 r
.75889 .40749 m .76193 .40883 L .75956 .41005 L F
.637 .84 .443 r
.59872 .45543 m .59762 .45725 L .59967 .45419 L F
0 0 0 r
.602 .45082 m .60116 .45255 L .59967 .45419 L F
.60116 .45255 m .59872 .45543 L .59967 .45419 L F
.672 .649 .819 r
.72473 .41839 m .72717 .41572 L .72409 .41633 L F
.72473 .41839 m .72791 .41896 L .72717 .41572 L F
.476 .164 .358 r
.46919 .63063 m .47221 .63109 L .47196 .62859 L F
.522 .197 .357 r
.47196 .62859 m .47221 .63109 L .47398 .63027 L F
.503 .203 .389 r
.47196 .62859 m .47398 .63027 L .47443 .62815 L F
.508 .341 .589 r
.21267 .57821 m .2142 .58062 L .21415 .57679 L F
.913 .823 .744 r
.67058 .4561 m .67131 .4592 L .67298 .45672 L F
.713 .961 .695 r
.59872 .45543 m .59619 .45811 L .59762 .45725 L F
.729 .857 .942 r
.51395 .55008 m .51067 .55185 L .50921 .55077 L F
.802 .457 .404 r
.5128 .55263 m .51067 .55185 L .51395 .55008 L F
.5128 .55263 m .50921 .55077 L .51067 .55185 L F
.958 .658 .419 r
.53129 .6539 m .53306 .65508 L .5326 .65227 L F
.363 .142 .438 r
.60269 .48075 m .60034 .48389 L .60285 .4824 L F
.22 .043 .415 r
.60285 .4824 m .60034 .48389 L .60001 .48602 L F
.351 .034 .281 r
.22679 .58271 m .22972 .58047 L .22786 .58134 L F
.827 .997 .843 r
.54599 .49431 m .54932 .49218 L .54692 .49493 L F
.922 .964 .783 r
.54385 .49755 m .54599 .49431 L .54692 .49493 L F
.541 .552 .815 r
.55512 .62875 m .55627 .62519 L .55393 .62556 L F
.55512 .62875 m .55737 .62825 L .55627 .62519 L F
0 0 .402 r
.72791 .41896 m .7293 .41897 L .73087 .41979 L F
.72791 .41896 m .72791 .42157 L .7293 .41897 L F
.656 .443 .585 r
.54138 .56652 m .54153 .56904 L .53845 .56913 L F
.563 .441 .672 r
.54351 .56322 m .54138 .56652 L .54111 .56406 L F
.54351 .56322 m .54384 .56611 L .54138 .56652 L F
.532 .329 .55 r
.54138 .56652 m .54389 .56823 L .54153 .56904 L F
.54138 .56652 m .54384 .56611 L .54389 .56823 L F
.72 .966 .938 r
.70441 .45192 m .70107 .45371 L .70047 .45317 L F
.392 .068 .291 r
.57663 .50168 m .57377 .50408 L .57613 .50342 L F
.415 .088 .3 r
.57663 .50168 m .57883 .50275 L .579 .50109 L F
.57663 .50168 m .57613 .50342 L .57883 .50275 L F
.706 .644 .786 r
.44658 .58904 m .44923 .58627 L .44737 .58717 L F
.561 .82 .994 r
.69507 .41007 m .69756 .40942 L .69401 .40897 L F
.65 .448 .596 r
.57054 .50666 m .57377 .50408 L .57094 .50408 L F
.635 .85 .465 r
.59593 .43635 m .59704 .43457 L .59812 .43325 L F
.723 .927 .588 r
.60048 .43011 m .59812 .43325 L .59924 .43116 L F
.683 .868 .473 r
.59812 .43325 m .59704 .43457 L .59924 .43116 L F
.835 .559 .522 r
.66952 .45054 m .6721 .44851 L .67128 .4475 L F
.66952 .45054 m .67228 .45093 L .6721 .44851 L F
.421 .369 .695 r
.26072 .56886 m .25843 .56561 L .26028 .56558 L F
.26072 .56886 m .25905 .56961 L .25843 .56561 L F
.601 .14 .131 r
.41394 .64301 m .41241 .64368 L .41022 .64303 L F
.354 0 0 r
.41497 .64427 m .41394 .64301 L .41627 .64337 L F
.41497 .64427 m .41241 .64368 L .41394 .64301 L F
.379 0 0 r
.44385 .56562 m .44524 .56306 L .44463 .56351 L F
.44385 .56562 m .44798 .56404 L .44524 .56306 L F
.591 .337 .501 r
.56952 .52521 m .57201 .52719 L .56945 .52742 L F
.608 .33 .469 r
.56952 .52521 m .57204 .52511 L .57201 .52719 L F
.608 .603 .821 r
.26129 .55417 m .25906 .55497 L .25721 .55185 L F
.282 .138 .502 r
.26129 .55417 m .25967 .55723 L .25906 .55497 L F
.409 .845 .943 r
.73666 .43614 m .74037 .43601 L .73783 .4368 L F
.2 .679 .933 r
.67418 .46905 m .67048 .46827 L .67305 .46778 L F
.67048 .46827 m .67418 .46905 L .67305 .46778 L F
.523 .575 .849 r
.54129 .68423 m .54022 .68761 L .5397 .68667 L F
.54129 .68423 m .5433 .68766 L .54022 .68761 L F
.535 .193 .336 r
.47933 .57821 m .4759 .58053 L .47669 .57708 L F
.47933 .57821 m .47847 .58035 L .4759 .58053 L F
.359 .097 .374 r
.48194 .57545 m .47933 .57821 L .47817 .5768 L F
.48194 .57545 m .48153 .57763 L .47933 .57821 L F
.667 .474 .615 r
.48153 .57763 m .47847 .58035 L .47933 .57821 L F
.458 .858 .969 r
.22195 .55209 m .22162 .55317 L .22395 .55281 L F
.22195 .55209 m .21952 .55271 L .22162 .55317 L F
.26 .023 .352 r
.62939 .40415 m .62911 .40621 L .627 .40676 L F
.073 0 0 r
.62911 .40621 m .62627 .40769 L .627 .40676 L F
.706 .566 .693 r
.53614 .56973 m .53669 .5727 L .53435 .57254 L F
.59 .869 .994 r
.53715 .56812 m .53614 .56973 L .53845 .56913 L F
.532 .399 .645 r
.53845 .56913 m .53669 .5727 L .53614 .56973 L F
.549 .913 .732 r
.67258 .41958 m .67137 .42011 L .66968 .42164 L F
0 0 .375 r
.67119 .42225 m .66968 .42164 L .67137 .42011 L F
.67119 .42225 m .66948 .42419 L .66968 .42164 L F
.359 .097 .374 r
.48194 .57545 m .47817 .5768 L .48049 .57436 L F
.632 .833 .978 r
.48424 .57471 m .48194 .57545 L .48049 .57436 L F
.446 .159 .383 r
.48424 .57471 m .48153 .57763 L .48194 .57545 L F
.693 .946 .664 r
.59593 .43635 m .59445 .43735 L .59704 .43457 L F
.522 .841 .999 r
.19032 .66314 m .19017 .66177 L .18854 .66267 L F
.72 .966 .938 r
.70441 .45192 m .70047 .45317 L .70345 .45087 L F
.748 .93 .949 r
.7064 .45032 m .70441 .45192 L .70345 .45087 L F
.613 .788 .965 r
.47064 .57388 m .47196 .57557 L .46982 .57543 L F
.511 .737 .976 r
.47437 .57436 m .47196 .57557 L .47064 .57388 L F
.914 .902 .799 r
.53458 .50966 m .5358 .51068 L .53329 .51467 L F
.899 .919 .826 r
.53458 .50966 m .538 .50758 L .5358 .51068 L F
.94 .857 .731 r
.57202 .49059 m .57393 .49207 L .57416 .48985 L F
.924 .884 .775 r
.57202 .49059 m .57145 .4952 L .57393 .49207 L F
0 0 .028 r
.62945 .44561 m .62988 .44585 L .63025 .44404 L F
.096 .653 .746 r
.57992 .61912 m .58337 .61888 L .58051 .61915 L F
.186 0 .195 r
.60519 .48041 m .60533 .47802 L .60269 .48075 L F
.116 0 .232 r
.60761 .47492 m .60533 .47802 L .60695 .47679 L F
.076 0 .175 r
.60695 .47679 m .60533 .47802 L .60519 .48041 L F
.185 0 .252 r
.61175 .49301 m .61418 .48996 L .61364 .49177 L F
.232 0 .273 r
.61364 .49177 m .61418 .48996 L .6161 .48891 L F
.793 .608 .652 r
.66636 .43366 m .66283 .43313 L .66336 .43071 L F
.872 .764 .741 r
.66636 .43366 m .66284 .43551 L .66283 .43313 L F
.66636 .43366 m .6646 .43691 L .66284 .43551 L F
.9 .888 .81 r
.66618 .43473 m .6646 .43691 L .66636 .43366 L F
.594 .279 .406 r
.6682 .43354 m .6689 .43541 L .66636 .43366 L F
.6682 .43354 m .6689 .43541 L .66636 .43366 L F
.516 .324 .558 r
.66636 .43366 m .6689 .43541 L .66618 .43473 L F
.04 .031 .518 r
.21399 .56898 m .2149 .57169 L .21489 .56778 L F
.758 .659 .752 r
.5795 .62666 m .57583 .62573 L .57927 .62524 L F
.663 .14 0 r
.57849 .62738 m .5795 .62666 L .57927 .62524 L F
.57849 .62738 m .58129 .62797 L .5795 .62666 L F
.604 .398 .575 r
.5815 .49876 m .58418 .49762 L .58442 .49546 L F
.487 .227 .445 r
.58656 .49759 m .58442 .49546 L .58418 .49762 L F
.58656 .49759 m .5871 .49467 L .58442 .49546 L F
.598 .225 .306 r
.43793 .63996 m .43663 .64222 L .43441 .64043 L F
.658 .312 .374 r
.44043 .6402 m .43663 .64222 L .43793 .63996 L F
.899 .919 .826 r
.53458 .50966 m .53685 .50658 L .538 .50758 L F
.915 .914 .802 r
.538 .50758 m .53685 .50658 L .53897 .50345 L F
.191 0 .214 r
.60519 .48041 m .60269 .48075 L .60285 .4824 L F
.072 .611 .852 r
.21878 .54109 m .221 .54123 L .22264 .5417 L F
.219 0 0 r
.221 .54123 m .22485 .54174 L .22264 .5417 L F
.837 .887 .877 r
.53144 .51363 m .53329 .51467 L .53276 .51511 L F
.914 .902 .799 r
.53458 .50966 m .53329 .51467 L .53144 .51363 L F
.837 .887 .877 r
.53144 .51363 m .53276 .51511 L .52964 .51552 L F
.866 .82 .802 r
.53276 .51511 m .53116 .51684 L .52964 .51552 L F
.643 .901 .579 r
.60048 .43011 m .59924 .43116 L .60175 .42828 L F
0 0 0 r
.41428 .57548 m .41543 .57465 L .41616 .57421 L F
.41428 .57548 m .41266 .57691 L .41543 .57465 L F
.816 .814 .849 r
.52787 .52176 m .52488 .52162 L .52738 .51899 L F
.829 .79 .815 r
.52787 .52176 m .5265 .52303 L .52488 .52162 L F
.866 .843 .82 r
.53015 .51868 m .52787 .52176 L .52738 .51899 L F
.215 0 .333 r
.61247 .46892 m .61022 .47208 L .61171 .47096 L F
.302 .116 .453 r
.61171 .47096 m .61022 .47208 L .61005 .47435 L F
.908 .879 .795 r
.57971 .47942 m .58302 .47739 L .58176 .47627 L F
.57971 .47942 m .58097 .48056 L .58302 .47739 L F
.92 .888 .783 r
.58176 .47627 m .58302 .47739 L .58399 .47552 L F
.489 .341 .606 r
.39092 .61336 m .39095 .61852 L .38965 .61665 L F
.257 .159 .547 r
.39263 .61447 m .39095 .61852 L .39092 .61336 L F
.141 0 0 r
.39403 .61765 m .39095 .61852 L .39263 .61447 L F
.39403 .61765 m .39153 .61847 L .39095 .61852 L F
.308 .28 .665 r
.39095 .61852 m .39153 .61847 L .38965 .61665 L F
.349 .286 .644 r
.38965 .61665 m .39153 .61847 L .38993 .61875 L F
.323 .155 .492 r
.51678 .55182 m .51395 .55008 L .51486 .55095 L F
.892 .747 .694 r
.51636 .54842 m .51678 .55182 L .51486 .55095 L F
.468 .348 .633 r
.555 .53596 m .5537 .5395 L .5532 .53738 L F
.012 .264 .766 r
.65211 .41841 m .64998 .41686 L .64915 .41471 L F
.792 .959 .92 r
.64959 .44693 m .65048 .44781 L .65356 .44528 L F
.357 0 .015 r
.52015 .69776 m .51746 .69752 L .51648 .69842 L F
.478 .023 .093 r
.46728 .63492 m .46597 .63666 L .463 .63678 L F
0 0 0 r
.46942 .6342 m .46597 .63666 L .46728 .63492 L F
.286 .211 .595 r
.26072 .56886 m .25955 .57212 L .25905 .56961 L F
.578 .859 .531 r
.57849 .62738 m .57573 .63044 L .5772 .62895 L F
.985 .899 .638 r
.5772 .62895 m .57573 .63044 L .57638 .63155 L F
.736 .258 .11 r
.64027 .41832 m .64226 .41899 L .64123 .41982 L F
.941 .594 .336 r
.64226 .41899 m .643 .42149 L .64123 .41982 L F
.756 .639 .731 r
.59896 .50501 m .59852 .50617 L .59627 .50811 L F
.407 .109 .343 r
.59627 .50811 m .59852 .50617 L .59904 .50741 L F
.244 .095 .47 r
.60062 .50591 m .59852 .50617 L .59896 .50501 L F
.229 .03 .389 r
.59904 .50741 m .59852 .50617 L .60062 .50591 L F
.433 0 0 r
.49524 .71843 m .49839 .7199 L .49714 .71699 L F
0 0 0 r
.50011 .71794 m .49839 .7199 L .49947 .71911 L F
.176 .37 .816 r
.49839 .7199 m .50039 .72203 L .49947 .71911 L F
.13 .281 .751 r
.49714 .71699 m .49839 .7199 L .49947 .71911 L F
.257 .159 .547 r
.39263 .61447 m .39092 .61336 L .39645 .61242 L F
.278 0 0 r
.74514 .43213 m .74771 .43165 L .74846 .43012 L F
.559 .934 .837 r
.74846 .43012 m .74987 .42874 L .75145 .42851 L F
0 0 0 r
.74846 .43012 m .74771 .43165 L .74987 .42874 L F
.645 .264 .309 r
.45855 .63696 m .45725 .63927 L .45499 .63736 L F
.163 .682 .885 r
.46091 .637 m .45912 .63661 L .45855 .63696 L F
.523 .341 .576 r
.45912 .63661 m .45725 .63927 L .45855 .63696 L F
.135 0 .029 r
.60882 .49521 m .61175 .49301 L .61095 .49447 L F
0 0 0 r
.61095 .49447 m .61175 .49301 L .61364 .49177 L F
.585 .686 .911 r
.47678 .5741 m .47616 .57743 L .47437 .57436 L F
.69 .789 .926 r
.64383 .44742 m .64433 .45006 L .64725 .44792 L F
.333 .025 .283 r
.60637 .4984 m .60882 .49521 L .60829 .49741 L F
.188 0 .142 r
.60829 .49741 m .60882 .49521 L .61095 .49447 L F
.078 .143 .63 r
.39581 .62404 m .3965 .62737 L .39496 .62529 L F
.279 0 0 r
.62131 .40268 m .62482 .40068 L .62259 .4018 L F
0 0 .185 r
.20228 .66896 m .20049 .6723 L .20039 .67015 L F
.244 .095 .47 r
.60062 .50591 m .59896 .50501 L .60127 .50427 L F
.408 .212 .501 r
.36644 .59847 m .3686 .59547 L .36642 .59596 L F
.775 .73 .811 r
.54214 .68954 m .54405 .69065 L .5433 .68766 L F
.886 .941 .845 r
.58662 .47022 m .58633 .4728 L .58787 .47103 L F
.905 .936 .821 r
.58931 .46667 m .58662 .47022 L .58787 .47103 L F
.361 .527 .885 r
.64555 .41205 m .64727 .41485 L .6461 .41391 L F
.04 0 .341 r
.21411 .5895 m .21544 .58903 L .21581 .58644 L F
0 0 .01 r
.21411 .5895 m .21289 .59202 L .21544 .58903 L F
.877 .895 .841 r
.58286 .4745 m .58633 .4728 L .58301 .47359 L F
.58286 .4745 m .58399 .47552 L .58633 .4728 L F
.86 .922 .869 r
.58662 .47022 m .58301 .47359 L .58633 .4728 L F
.797 .573 .597 r
.58337 .61888 m .58664 .62196 L .58752 .62112 L F
.745 .864 .436 r
.64206 .41274 m .64138 .41356 L .6426 .41186 L F
.795 .567 .591 r
.53435 .57254 m .53279 .57477 L .53028 .57425 L F
.53435 .57254 m .5336 .57509 L .53279 .57477 L F
.56 .324 .515 r
.53612 .57425 m .5336 .57509 L .53435 .57254 L F
.663 .304 .355 r
.53669 .5727 m .53612 .57425 L .53435 .57254 L F
.92 .888 .783 r
.58176 .47627 m .58399 .47552 L .58286 .4745 L F
.895 .874 .808 r
.60227 .44124 m .60573 .4393 L .60492 .43844 L F
.60227 .44124 m .60355 .44243 L .60573 .4393 L F
.83 .967 .892 r
.60782 .43583 m .60573 .4393 L .60847 .43669 L F
.60782 .43583 m .60492 .43844 L .60573 .4393 L F
.745 .914 .95 r
.6636 .40879 m .66146 .41043 L .66231 .40804 L F
.713 .881 .959 r
.66231 .40804 m .66146 .41043 L .6602 .4093 L F
.975 .747 .53 r
.66088 .42339 m .6626 .42483 L .66233 .42722 L F
.232 0 .332 r
.43203 .57736 m .43202 .58049 L .43058 .58026 L F
.526 .396 .646 r
.4348 .57431 m .43203 .57736 L .43227 .57514 L F
.4348 .57431 m .4348 .57798 L .43203 .57736 L F
.464 .163 .368 r
.43428 .57981 m .43203 .57736 L .4348 .57798 L F
.43428 .57981 m .43202 .58049 L .43203 .57736 L F
.556 .598 .851 r
.75707 .40239 m .75559 .40577 L .75445 .40313 L F
.75707 .40239 m .7587 .40554 L .75559 .40577 L F
0 0 0 r
.41805 .59318 m .41615 .59419 L .41413 .59514 L F
.619 .51 .708 r
.4164 .59391 m .41616 .59418 L .41413 .59514 L F
.41616 .59418 m .41341 .59735 L .41413 .59514 L F
0 0 0 r
.41615 .59419 m .41607 .59423 L .41413 .59514 L F
.41743 .59359 m .41805 .59318 L .42036 .59271 L F
.619 .51 .708 r
.41616 .59418 m .41732 .5977 L .41341 .59735 L F
.4164 .59391 m .41643 .59405 L .41616 .59418 L F
.41643 .59405 m .41732 .5977 L .41616 .59418 L F
0 0 0 r
.41753 .59353 m .41643 .59405 L .41805 .59318 L F
.41643 .59405 m .41615 .59419 L .41638 .59407 L F
.41643 .59405 m .41638 .59407 L .41805 .59318 L F
.672 .814 .951 r
.41929 .60073 m .41527 .60059 L .41781 .59843 L F
.564 .598 .845 r
.42026 .59745 m .41929 .60073 L .41781 .59843 L F
.68 .909 .975 r
.42026 .59745 m .41781 .59843 L .41892 .59685 L F
.699 .936 .964 r
.41781 .59843 m .41732 .5977 L .41892 .59685 L F
.862 .613 .561 r
.41744 .59754 m .41798 .59937 L .41892 .59685 L F
.718 .953 .667 r
.41527 .60059 m .41732 .5977 L .41781 .59843 L F
.41527 .60059 m .41484 .60052 L .41732 .5977 L F
.789 .741 .809 r
.41732 .5977 m .41484 .60052 L .4123 .59907 L F
0 0 .312 r
.41671 .59472 m .41732 .5977 L .41643 .59405 L F
.4172 .59661 m .41732 .5977 L .41671 .59472 L F
.789 .741 .809 r
.41732 .5977 m .4123 .59907 L .41341 .59735 L F
.862 .613 .561 r
.41554 .59844 m .41732 .5977 L .41709 .59564 L F
.41554 .59844 m .41892 .59685 L .41732 .5977 L F
.41554 .59844 m .41791 .59934 L .41744 .59754 L F
.41791 .59934 m .41798 .59937 L .41744 .59754 L F
0 0 .312 r
.41709 .59564 m .4172 .59661 L .41671 .59472 L F
.41645 .59405 m .41643 .59405 L .4164 .59391 L F
.41709 .59564 m .41643 .59405 L .41645 .59405 L F
.098 0 .025 r
.4164 .59391 m .41743 .59359 L .41736 .59315 L F
0 0 .312 r
.4173 .59367 m .4164 .59391 L .41736 .59315 L F
.41709 .59564 m .41645 .59405 L .4173 .59367 L F
0 0 0 r
.41743 .59359 m .41657 .59399 L .41645 .59405 L F
.41743 .59359 m .41615 .59419 L .41753 .59353 L F
0 0 .312 r
.41645 .59405 m .4164 .59391 L .41657 .59399 L F
0 0 0 r
.41645 .59405 m .41607 .59423 L .41615 .59419 L F
.41657 .59399 m .41607 .59423 L .41645 .59405 L F
.098 0 .025 r
.4164 .59391 m .41607 .59423 L .41657 .59399 L F
.4164 .59391 m .41657 .59399 L .41743 .59359 L F
0 0 .312 r
.41657 .59399 m .4164 .59391 L .4173 .59367 L F
.659 .423 .551 r
.22632 .56565 m .23017 .5634 L .22604 .5634 L F
.22632 .56565 m .2302 .56657 L .23017 .5634 L F
.628 .398 .55 r
.23017 .5634 m .2302 .56657 L .2321 .56563 L F
.611 .397 .566 r
.23017 .5634 m .2321 .56563 L .2325 .56327 L F
.829 .845 .859 r
.5451 .68173 m .54619 .67789 L .54395 .67824 L F
.5451 .68173 m .5475 .67911 L .54619 .67789 L F
.532 .399 .645 r
.53845 .56913 m .53887 .57213 L .53669 .5727 L F
.474 .159 .352 r
.53887 .57213 m .53612 .57425 L .53669 .5727 L F
.14 .619 .921 r
.22485 .54174 m .22687 .54201 L .22858 .5429 L F
.261 .723 .95 r
.22687 .54201 m .23073 .54261 L .22858 .5429 L F
.827 .997 .843 r
.54599 .49431 m .5487 .49159 L .54932 .49218 L F
.724 .973 .731 r
.5487 .49159 m .547 .49256 L .54731 .49225 L F
.941 .959 .668 r
.54959 .49118 m .5487 .49159 L .5504 .48808 L F
0 0 0 r
.5504 .48808 m .54933 .4903 L .5497 .48986 L F
.54933 .4903 m .5487 .49159 L .5497 .48986 L F
.519 .841 .542 r
.5497 .48986 m .54834 .49108 L .55006 .48943 L F
.719 .969 .934 r
.5504 .48808 m .55112 .48624 L .55286 .48514 L F
0 0 .121 r
.5497 .48986 m .55102 .48851 L .55112 .48624 L F
.519 .841 .542 r
.5497 .48986 m .55006 .48943 L .55102 .48851 L F
.724 .973 .731 r
.5487 .49159 m .54731 .49225 L .5497 .48986 L F
.941 .959 .668 r
.54932 .49218 m .5487 .49159 L .54959 .49118 L F
.91 .669 .561 r
.54489 .66692 m .54263 .66361 L .54297 .66387 L F
.553 0 0 r
.39432 .64262 m .39018 .64063 L .3921 .64236 L F
0 0 0 r
.49081 .58008 m .48942 .5815 L .49179 .5782 L F
.894 .877 .812 r
.48942 .5815 m .4903 .57705 L .49179 .5782 L F
.465 .77 .996 r
.4903 .57705 m .49264 .57676 L .49179 .5782 L F
.831 .885 .456 r
.49174 .57675 m .49179 .5782 L .49264 .57676 L F
.551 .563 .82 r
.49156 .57295 m .49231 .57562 L .4903 .57705 L F
.49231 .57562 m .49264 .57676 L .49192 .57685 L F
.49231 .57562 m .49192 .57685 L .4903 .57705 L F
.115 0 .403 r
.4903 .57705 m .49264 .57676 L .49111 .57638 L F
.4903 .57705 m .49174 .57675 L .49264 .57676 L F
.831 .885 .456 r
.49174 .57675 m .49081 .58008 L .49104 .57965 L F
.49176 .57737 m .49104 .57965 L .49179 .5782 L F
.49174 .57675 m .49104 .57965 L .49176 .57737 L F
.894 .877 .812 r
.48942 .5815 m .48767 .58076 L .4903 .57705 L F
.328 .813 .838 r
.49081 .58008 m .48767 .58076 L .48942 .5815 L F
.489 0 0 r
.18708 .5404 m .18905 .54119 L .19097 .54027 L F
.053 0 0 r
.18905 .54119 m .19298 .54032 L .19097 .54027 L F
.551 .883 .989 r
.71146 .45727 m .71066 .45662 L .7081 .45754 L F
.599 .905 .984 r
.71296 .45561 m .71146 .45727 L .714 .45668 L F
.71296 .45561 m .71066 .45662 L .71146 .45727 L F
.625 .587 .79 r
.72079 .41544 m .72325 .41266 L .71955 .41205 L F
.72079 .41544 m .72309 .41461 L .72325 .41266 L F
.642 .659 .851 r
.72079 .41544 m .72409 .41633 L .72309 .41461 L F
0 0 .181 r
.19467 .67286 m .19349 .67195 L .19223 .67215 L F
.19467 .67286 m .1938 .67553 L .19438 .67504 L F
.19467 .67286 m .19438 .67504 L .19349 .67195 L F
.605 .54 .754 r
.72409 .41633 m .72565 .41202 L .72309 .41461 L F
.72409 .41633 m .72717 .41572 L .72565 .41202 L F
.864 .82 .804 r
.52964 .51552 m .53015 .51868 L .52882 .51722 L F
.52964 .51552 m .53116 .51684 L .53015 .51868 L F
.866 .843 .82 r
.53015 .51868 m .52738 .51899 L .52882 .51722 L F
.442 .572 .889 r
.64915 .41471 m .64727 .41485 L .64555 .41205 L F
.681 .628 .789 r
.73266 .43045 m .73419 .43369 L .73675 .43214 L F
.482 .763 .993 r
.26822 .56229 m .27 .56356 L .27056 .56201 L F
.26822 .56229 m .27 .56356 L .27056 .56201 L F
.167 0 0 r
.60885 .47563 m .60761 .47492 L .60695 .47679 L F
.60885 .47563 m .61005 .47435 L .60761 .47492 L F
.769 .673 .757 r
.51355 .54348 m .51808 .54286 L .51626 .54172 L F
.781 .658 .104 r
.51808 .54286 m .51794 .54537 L .51788 .54345 L F
.816 .704 .741 r
.6634 .44811 m .66442 .45144 L .66243 .4508 L F
.878 .949 .853 r
.59087 .46432 m .58931 .46667 L .59113 .46665 L F
.562 .667 .908 r
.56541 .62138 m .56588 .6234 L .56251 .62197 L F
.193 0 0 r
.56757 .62398 m .56875 .62348 L .56588 .6234 L F
.56757 .62398 m .56588 .6234 L .56541 .62138 L F
.054 0 0 r
.21505 .54082 m .21706 .54097 L .21878 .54109 L F
.285 0 0 r
.21706 .54097 m .221 .54123 L .21878 .54109 L F
.79 .938 .926 r
.5265 .52303 m .52251 .52455 L .52488 .52162 L F
.742 .918 .951 r
.42865 .59104 m .43038 .59171 L .43066 .59108 L F
.855 .898 .866 r
.68585 .41234 m .68801 .41232 L .68771 .40869 L F
.741 .811 .908 r
.68801 .41232 m .6904 .40837 L .68771 .40869 L F
.68801 .41232 m .69182 .4102 L .6904 .40837 L F
.621 .376 .525 r
.63125 .44188 m .63366 .44161 L .63372 .43946 L F
.462 .248 .502 r
.63372 .43946 m .63532 .4405 L .63629 .43891 L F
.63372 .43946 m .63366 .44161 L .63532 .4405 L F
.37 .21 .531 r
.25807 .58103 m .25797 .58363 L .25623 .58428 L F
.343 .151 .47 r
.25797 .58363 m .25608 .58657 L .25623 .58428 L F
.449 .522 .84 r
.66603 .45911 m .66717 .45533 L .66431 .4544 L F
.66603 .45911 m .66788 .4591 L .66717 .45533 L F
.171 0 0 r
.39154 .58469 m .38859 .58632 L .39091 .58564 L F
.409 0 .044 r
.39091 .58564 m .39313 .58561 L .39154 .58469 L F
.372 0 .174 r
.39154 .58469 m .39313 .58561 L .39377 .58418 L F
.381 .078 .321 r
.59538 .48936 m .59285 .4926 L .59489 .4917 L F
.368 0 .135 r
.59708 .49077 m .59538 .48936 L .59489 .4917 L F
.59708 .49077 m .59765 .48868 L .59538 .48936 L F
.48 .239 .47 r
.57794 .52195 m .58038 .51923 L .58042 .52158 L F
.632 .416 .571 r
.58311 .5189 m .58042 .52158 L .58038 .51923 L F
.874 .548 .43 r
.60213 .44389 m .60355 .44243 L .60227 .44124 L F
.60213 .44389 m .60367 .44462 L .60355 .44243 L F
.285 .223 .61 r
.36293 .60774 m .36433 .60735 L .36395 .60479 L F
.45 .371 .677 r
.36293 .60774 m .36526 .60974 L .36433 .60735 L F
.36293 .60774 m .36317 .61124 L .36526 .60974 L F
.829 .792 .294 r
.67722 .45772 m .67758 .4572 L .6769 .45899 L F
.671 .847 .967 r
.50317 .72032 m .50336 .72164 L .50719 .72038 L F
.855 .401 .099 r
.51842 .57232 m .5175 .5733 L .51701 .57145 L F
.51842 .57232 m .51993 .57517 L .5175 .5733 L F
.78 .334 0 r
.52045 .57553 m .51993 .57517 L .51842 .57232 L F
.795 .692 .752 r
.54823 .67489 m .54971 .67812 L .54976 .67571 L F
.758 .733 .83 r
.66788 .4591 m .66963 .46104 L .67131 .4592 L F
.785 .997 .86 r
.46982 .57543 m .46764 .5759 L .47064 .57388 L F
.874 .76 .733 r
.57743 .48256 m .58097 .48056 L .57971 .47942 L F
.57743 .48256 m .57905 .48397 L .58097 .48056 L F
.446 .851 .67 r
.66954 .40626 m .66603 .40835 L .6688 .40701 L F
.139 0 .318 r
.6712 .4038 m .66954 .40626 L .67184 .40512 L F
.783 .694 .766 r
.6688 .40701 m .67184 .40512 L .66954 .40626 L F
.586 .232 .336 r
.43441 .64043 m .43663 .64222 L .43411 .64229 L F
.359 .831 .866 r
.19989 .5521 m .19762 .55277 L .1999 .55266 L F
.214 0 0 r
.19947 .55248 m .19762 .55277 L .19989 .5521 L F
.156 .698 .775 r
.1999 .55266 m .19762 .55277 L .19613 .55301 L F
.214 0 0 r
.19783 .554 m .19762 .55277 L .19947 .55248 L F
.156 .698 .775 r
.19613 .55301 m .19762 .55277 L .19557 .55306 L F
.359 .831 .866 r
.19989 .5521 m .1999 .55266 L .20197 .55209 L F
.255 0 0 r
.21549 .55368 m .21357 .55331 L .21318 .5531 L F
.242 0 0 r
.2158 .55263 m .21394 .55351 L .21357 .55331 L F
.21394 .55351 m .21141 .55471 L .21357 .55331 L F
.255 0 0 r
.21318 .5531 m .21357 .55331 L .21145 .55266 L F
.481 .872 .969 r
.2158 .55263 m .21549 .55368 L .21743 .55345 L F
0 0 0 r
.60487 .44834 m .60375 .44943 L .602 .45082 L F
.983 .696 .353 r
.60367 .44713 m .60375 .44943 L .60487 .44834 L F
.91 .669 .561 r
.54489 .66692 m .5431 .66647 L .54263 .66361 L F
.903 .608 .476 r
.54489 .66692 m .54292 .66799 L .54454 .66888 L F
.54489 .66692 m .5431 .66647 L .54292 .66799 L F
.91 .669 .561 r
.54263 .66361 m .54489 .66692 L .54752 .66405 L F
.54263 .66361 m .5431 .66647 L .54489 .66692 L F
.903 .608 .476 r
.54489 .66692 m .54292 .66799 L .54454 .66888 L F
.54489 .66692 m .5431 .66647 L .54292 .66799 L F
.538 .352 .577 r
.28493 .77324 m .28498 .7762 L .28257 .77622 L F
.28493 .77324 m .28498 .7762 L .28257 .77622 L F
.621 .794 .965 r
.73349 .4356 m .73156 .43805 L .73027 .43718 L F
.73349 .4356 m .73447 .43746 L .73156 .43805 L F
.282 .138 .502 r
.26129 .55417 m .2611 .55673 L .25967 .55723 L F
.415 .334 .656 r
.2611 .55673 m .25959 .55864 L .25967 .55723 L F
.508 .83 1 r
.75373 .42749 m .75643 .42701 L .75773 .42787 L F
.615 .875 .99 r
.75773 .42787 m .75643 .42701 L .75961 .42678 L F
.241 .006 .342 r
.75961 .42678 m .75733 .42994 L .75773 .42787 L F
.462 .164 .373 r
.37449 .59291 m .37681 .59247 L .37728 .5905 L F
.425 .131 .36 r
.37728 .5905 m .37907 .59194 L .38027 .58932 L F
.37728 .5905 m .37681 .59247 L .37907 .59194 L F
.938 .863 .436 r
.54263 .66361 m .54336 .66095 L .54236 .66265 L F
.54236 .66265 m .54336 .66095 L .54263 .66361 L F
0 0 0 r
.60263 .42702 m .60522 .42394 L .60544 .42427 L F
.60263 .42702 m .60281 .42683 L .60522 .42394 L F
.029 0 .404 r
.21232 .61326 m .21386 .60948 L .21264 .61079 L F
.394 0 0 r
.18093 .54174 m .18332 .54193 L .18509 .54094 L F
0 0 0 r
.18509 .54094 m .1852 .5409 L .18708 .5404 L F
.18509 .54094 m .18332 .54193 L .1852 .5409 L F
.997 .801 .516 r
.51364 .56351 m .51259 .56277 L .51283 .55894 L F
.933 .671 .516 r
.51364 .56351 m .51185 .56525 L .51259 .56277 L F
.51364 .56351 m .51372 .56605 L .51185 .56525 L F
0 .244 .759 r
.75692 .40929 m .75781 .40894 L .75601 .40871 L F
.697 .325 .339 r
.75692 .40929 m .75956 .41005 L .76006 .41214 L F
0 .244 .759 r
.75692 .40929 m .76006 .41214 L .75781 .40894 L F
.976 .706 .453 r
.21232 .61326 m .21386 .61668 L .21229 .61489 L F
0 0 .478 r
.2137 .6165 m .21393 .61527 L .21229 .61489 L F
.398 .353 .692 r
.21229 .61489 m .21393 .61527 L .21323 .61302 L F
0 0 .517 r
.21323 .61302 m .21393 .61527 L .21435 .61373 L F
.923 .609 .429 r
.21393 .61527 m .21235 .6168 L .21416 .61402 L F
.21393 .61527 m .21416 .61402 L .21435 .61373 L F
0 0 .478 r
.21386 .61668 m .21393 .61527 L .2137 .6165 L F
.21386 .61668 m .21481 .61804 L .21393 .61527 L F
0 0 .441 r
.21386 .61668 m .21392 .61938 L .21481 .61804 L F
.616 .424 .599 r
.55857 .53363 m .555 .53596 L .556 .53392 L F
.552 .903 .687 r
.62653 .45074 m .62467 .4522 L .62336 .45291 L F
.765 .71 .8 r
.44242 .59326 m .44597 .59325 L .44417 .59183 L F
.631 .705 .899 r
.44417 .59183 m .44597 .59325 L .44821 .59271 L F
.592 .352 .521 r
.576 .52268 m .5778 .52402 L .57525 .52424 L F
.576 .52268 m .57794 .52195 L .5778 .52402 L F
.677 .749 .906 r
.73057 .40399 m .72777 .40607 L .72675 .40357 L F
0 0 0 r
.22154 .59605 m .22015 .59799 L .22041 .59772 L F
.449 .277 .554 r
.22154 .59605 m .2235 .59549 L .22362 .59283 L F
.762 .562 .627 r
.22041 .59772 m .2235 .59549 L .22154 .59605 L F
.857 .645 .108 r
.61204 .46569 m .61247 .46892 L .61198 .46673 L F
.987 .894 .575 r
.61198 .46673 m .61247 .46892 L .61171 .47096 L F
.897 .639 .539 r
.2163 .60416 m .21408 .60402 L .21433 .60158 L F
.133 .135 .593 r
.21405 .60661 m .21408 .60402 L .2163 .60416 L F
.695 .667 .819 r
.63989 .44185 m .63741 .44444 L .63532 .4405 L F
.296 .284 .676 r
.46944 .56828 m .46777 .57097 L .46805 .56855 L F
.474 .47 .774 r
.46944 .56828 m .46888 .57241 L .46777 .57097 L F
.94 .622 .406 r
.51304 .55757 m .5115 .55886 L .51163 .55658 L F
.51304 .55757 m .51283 .55894 L .5115 .55886 L F
.911 .769 .692 r
.67667 .44493 m .67867 .44828 L .67719 .44477 L F
.834 .618 .61 r
.67688 .44522 m .67784 .4479 L .67652 .44578 L F
.67719 .44477 m .67735 .44556 L .67688 .44522 L F
.67735 .44556 m .67784 .4479 L .67688 .44522 L F
0 .403 .821 r
.67667 .44493 m .67721 .44527 L .67735 .44556 L F
.6768 .44516 m .67735 .44556 L .67867 .44828 L F
.67667 .44493 m .67735 .44556 L .6768 .44516 L F
.971 .676 .28 r
.67867 .44828 m .67735 .44556 L .67731 .44536 L F
.67753 .44557 m .67731 .44536 L .67719 .44477 L F
.67867 .44828 m .67731 .44536 L .67753 .44557 L F
0 .403 .821 r
.67721 .44527 m .6802 .44673 L .68114 .44766 L F
.67667 .44493 m .67709 .44515 L .67721 .44527 L F
.67709 .44515 m .6802 .44673 L .67721 .44527 L F
.67721 .44527 m .68114 .44766 L .67867 .44828 L F
.971 .676 .28 r
.67867 .44828 m .67784 .4479 L .67735 .44556 L F
.592 .934 .949 r
.6802 .44673 m .67867 .44828 L .68114 .44766 L F
.6802 .44673 m .67784 .4479 L .67867 .44828 L F
.407 .109 .343 r
.59627 .50811 m .59904 .50741 L .59559 .50954 L F
.842 .879 .868 r
.67982 .41054 m .67766 .41308 L .67634 .4112 L F
0 0 .214 r
.67766 .41308 m .67918 .41347 L .67634 .4112 L F
.195 .574 .939 r
.24856 .5465 m .24825 .54757 L .24591 .54573 L F
.24856 .5465 m .25011 .54792 L .24825 .54757 L F
0 0 0 r
.74094 .4413 m .73876 .44196 L .74088 .44111 L F
.74094 .4413 m .73801 .4426 L .73876 .44196 L F
.955 .941 .626 r
.22131 .56912 m .21989 .57163 L .22027 .57234 L F
.755 .968 .685 r
.60544 .42427 m .60752 .42117 L .60843 .42209 L F
.60544 .42427 m .60522 .42394 L .60752 .42117 L F
.931 .599 .15 r
.74115 .42757 m .74167 .43096 L .74242 .43068 L F
0 .473 .786 r
.74167 .43096 m .74514 .43213 L .74242 .43068 L F
.389 .732 .991 r
.45601 .56508 m .45752 .5662 L .45485 .56618 L F
.148 .335 .795 r
.45485 .56618 m .4559 .56598 L .45601 .56508 L F
.785 .58 .622 r
.45485 .56618 m .45146 .56598 L .4559 .56598 L F
.45485 .56618 m .45484 .56784 L .45146 .56598 L F
.866 .775 .758 r
.66284 .43551 m .66382 .4391 L .66145 .43677 L F
.96 .622 .27 r
.66384 .44069 m .66145 .43677 L .66382 .4391 L F
.857 .77 .765 r
.6646 .43691 m .66382 .4391 L .66284 .43551 L F
.466 .409 .71 r
.36384 .61362 m .36526 .60974 L .36317 .61124 L F
.231 0 .026 r
.22499 .64023 m .22369 .64219 L .22133 .64219 L F
.278 .015 .323 r
.22292 .64438 m .22133 .64219 L .22369 .64219 L F
.22292 .64438 m .22111 .64521 L .22133 .64219 L F
.073 .152 .642 r
.6681 .42939 m .66985 .43143 L .6682 .43354 L F
.764 .385 0 r
.66831 .4346 m .6689 .43541 L .6682 .43354 L F
.66831 .4346 m .6682 .43354 L .66985 .43143 L F
.561 .591 .841 r
.36294 .62423 m .36464 .62223 L .36261 .62262 L F
.36294 .62423 m .36625 .62587 L .36464 .62223 L F
.756 .584 .663 r
.22285 .56316 m .224 .56645 L .22604 .5634 L F
.729 .547 .645 r
.22604 .5634 m .224 .56645 L .22632 .56565 L F
.753 .734 .835 r
.74039 .42522 m .73664 .42361 L .73962 .42062 L F
.662 .963 .929 r
.74211 .42271 m .7387 .42446 L .74039 .42522 L F
.628 .678 .878 r
.67318 .40933 m .6758 .40845 L .67435 .40569 L F
.456 .881 .787 r
.75374 .43158 m .75514 .43111 L .75733 .42994 L F
.107 .083 .545 r
.21415 .57679 m .2158 .5769 L .21529 .57417 L F
0 0 .308 r
.21415 .57679 m .21505 .57906 L .2158 .5769 L F
.21415 .57679 m .2142 .58062 L .21505 .57906 L F
.303 0 .009 r
.60371 .45191 m .602 .45082 L .60375 .44943 L F
.60371 .45191 m .60116 .45255 L .602 .45082 L F
.658 .764 .928 r
.69575 .45568 m .6921 .45464 L .69468 .4539 L F
.686 .778 .921 r
.69708 .4528 m .69575 .45568 L .69468 .4539 L F
.69708 .4528 m .69859 .45451 L .69575 .45568 L F
0 0 0 r
.56718 .46943 m .56818 .46773 L .56805 .46788 L F
.56603 .47116 m .5674 .46898 L .56718 .46943 L F
.56603 .47116 m .56527 .47288 L .56717 .46942 L F
.56717 .46942 m .56636 .47112 L .56657 .47008 L F
.56712 .46935 m .56657 .47008 L .5668 .46899 L F
.5674 .46898 m .56818 .46773 L .56762 .46868 L F
.5674 .46898 m .56762 .46868 L .56718 .46943 L F
.56672 .47006 m .56717 .46942 L .56818 .46773 L F
.56603 .47116 m .56717 .46942 L .56672 .47006 L F
.526 .907 .946 r
.56717 .46942 m .5668 .46899 L .56781 .46851 L F
.56717 .46942 m .56873 .46807 L .56941 .46653 L F
.56717 .46942 m .56781 .46851 L .56873 .46807 L F
0 0 0 r
.56717 .46942 m .56657 .47008 L .56712 .46935 L F
.448 .259 .53 r
.24479 .60472 m .24462 .6074 L .24257 .60791 L F
.384 .253 .576 r
.24462 .6074 m .24293 .61032 L .24257 .60791 L F
.526 .267 .466 r
.56695 .52783 m .56912 .52943 L .56609 .53065 L F
.56695 .52783 m .56945 .52742 L .56912 .52943 L F
.652 .891 .983 r
.57134 .62404 m .56984 .62603 L .56875 .62348 L F
.57134 .62404 m .57213 .62503 L .56984 .62603 L F
.448 .825 .991 r
.5634 .62078 m .56251 .62197 L .5612 .62137 L F
.5634 .62078 m .56541 .62138 L .56251 .62197 L F
.34 .766 .974 r
.23073 .54261 m .23284 .54241 L .23451 .54308 L F
.346 .738 .985 r
.23284 .54241 m .23683 .54325 L .23451 .54308 L F
.994 .82 .564 r
.66381 .44541 m .66275 .44484 L .66384 .44069 L F
.918 .721 .621 r
.66381 .44541 m .66159 .44681 L .66275 .44484 L F
.66381 .44541 m .6634 .44811 L .66159 .44681 L F
.8 .964 .913 r
.72882 .41506 m .73289 .41317 L .7315 .41176 L F
.562 .315 .498 r
.58842 .51343 m .58778 .51589 L .58529 .51601 L F
.538 .293 .492 r
.59115 .51258 m .58778 .51589 L .58842 .51343 L F
.748 .708 .814 r
.57409 .63329 m .57638 .63155 L .57573 .63044 L F
.57409 .63329 m .57635 .63337 L .57638 .63155 L F
.993 .748 .394 r
.64123 .43312 m .64275 .4361 L .64116 .43539 L F
.407 .006 .163 r
.4656 .63321 m .46796 .63293 L .46919 .63063 L F
.633 .34 .456 r
.46796 .63293 m .47221 .63109 L .46919 .63063 L F
.718 .963 .942 r
.71623 .45529 m .71992 .45415 L .71937 .45383 L F
.674 .968 .924 r
.72133 .45234 m .71992 .45415 L .72193 .45278 L F
.681 .978 .873 r
.72133 .45234 m .71937 .45383 L .71992 .45415 L F
.547 .485 .738 r
.1992 .68073 m .19777 .68456 L .19626 .68119 L F
.1992 .68073 m .19991 .68411 L .19777 .68456 L F
.494 .296 .54 r
.19991 .68411 m .19755 .6871 L .19777 .68456 L F
.364 .431 .797 r
.38671 .63731 m .38792 .64064 L .3895 .63889 L F
.472 .598 .897 r
.38792 .64064 m .39018 .64063 L .3895 .63889 L F
.324 .042 .322 r
.67034 .39908 m .66804 .40136 L .66802 .39986 L F
.67034 .39908 m .66802 .39986 L .66814 .39991 L F
.368 .756 .988 r
.67066 .39815 m .67034 .39908 L .66814 .39991 L F
.67066 .39815 m .6719 .39922 L .67034 .39908 L F
.943 .784 .654 r
.6359 .46047 m .63521 .45622 L .63465 .45925 L F
.945 .861 .726 r
.63375 .46131 m .6359 .46047 L .63465 .45925 L F
.63375 .46131 m .63504 .46267 L .6359 .46047 L F
.542 0 0 r
.66804 .40136 m .6673 .40217 L .66802 .39986 L F
.005 .384 .844 r
.66804 .40136 m .6712 .4038 L .67124 .40269 L F
.542 0 0 r
.66804 .40136 m .67124 .40269 L .6673 .40217 L F
.522 .286 .498 r
.5611 .53328 m .56122 .53095 L .56357 .53274 L F
.546 .277 .458 r
.56122 .53095 m .56367 .53067 L .56357 .53274 L F
.182 0 0 r
.19298 .54032 m .19516 .54068 L .19714 .5407 L F
.462 0 0 r
.19516 .54068 m .19912 .5403 L .19714 .5407 L F
.76 .418 .405 r
.3961 .61764 m .39875 .61874 L .39925 .61897 L F
.385 .829 .941 r
.40006 .61935 m .39925 .61897 L .40211 .61894 L F
.533 0 0 r
.39925 .61897 m .40083 .61979 L .40281 .61965 L F
.40083 .61979 m .40191 .62035 L .4024 .61997 L F
.40083 .61979 m .4024 .61997 L .40281 .61965 L F
.76 .418 .405 r
.39875 .61874 m .40043 .61943 L .39925 .61897 L F
.385 .829 .941 r
.399 .61956 m .39925 .61897 L .40006 .61935 L F
.742 .357 .323 r
.399 .61956 m .39764 .61931 L .39925 .61897 L F
.76 .418 .405 r
.3961 .61764 m .39925 .61897 L .39764 .61931 L F
.3961 .61764 m .39737 .61938 L .40043 .61943 L F
.742 .357 .323 r
.399 .61956 m .39832 .62117 L .39764 .61931 L F
.399 .61956 m .40143 .62204 L .39832 .62117 L F
.595 .54 .764 r
.39764 .61931 m .39564 .62161 L .39508 .61945 L F
.39764 .61931 m .39832 .62117 L .39564 .62161 L F
.76 .418 .405 r
.39737 .61938 m .39846 .62087 L .40006 .6197 L F
.39737 .61938 m .40006 .6197 L .40043 .61943 L F
.286 .211 .595 r
.26072 .56886 m .26105 .57155 L .25955 .57212 L F
.428 .373 .695 r
.26188 .574 m .25955 .57212 L .26105 .57155 L F
.26188 .574 m .26001 .57559 L .25955 .57212 L F
.199 .142 .564 r
.20634 .62553 m .20769 .62733 L .20845 .62413 L F
.20634 .62553 m .20655 .62816 L .20769 .62733 L F
.468 .348 .633 r
.555 .53596 m .55603 .53892 L .5537 .5395 L F
.539 .344 .565 r
.55603 .53892 m .55267 .54132 L .5537 .5395 L F
.517 .307 .534 r
.74353 .42148 m .74646 .42369 L .74607 .42077 L F
.74353 .42148 m .74367 .42445 L .74646 .42369 L F
.939 .757 .63 r
.68624 .45642 m .68744 .46 L .6859 .45862 L F
.827 .806 .832 r
.6859 .45862 m .68744 .46 L .68387 .46314 L F
.161 0 0 r
.47778 .63113 m .47454 .63267 L .4756 .63182 L F
.47778 .63113 m .47633 .63244 L .47399 .63294 L F
.421 .248 .54 r
.47614 .62954 m .47631 .63216 L .47841 .63067 L F
.47631 .63216 m .47633 .63244 L .47683 .63201 L F
.47631 .63216 m .47683 .63201 L .47841 .63067 L F
.161 0 0 r
.47454 .63267 m .47399 .63294 L .47425 .63276 L F
.47454 .63267 m .47425 .63276 L .4756 .63182 L F
.142 .277 .743 r
.64416 .43693 m .64548 .44098 L .64594 .43777 L F
.655 .781 .941 r
.645 .43951 m .64548 .44098 L .64594 .43777 L F
0 0 .546 r
.645 .43951 m .64548 .44098 L .6463 .44208 L F
0 0 0 r
.22735 .63724 m .22603 .63929 L .22499 .64023 L F
.22516 .64127 m .22499 .64023 L .22603 .63929 L F
.22516 .64127 m .22369 .64219 L .22499 .64023 L F
0 .124 .669 r
.43973 .56313 m .43955 .5648 L .43803 .56357 L F
.472 .27 .524 r
.55099 .54248 m .55127 .5451 L .54894 .5457 L F
.542 .361 .586 r
.55267 .54132 m .55127 .5451 L .55099 .54248 L F
.561 .263 .42 r
.48842 .62271 m .49085 .62032 L .4876 .61927 L F
.323 0 .108 r
.37907 .59194 m .38279 .58923 L .38027 .58932 L F
.493 .103 .229 r
.38027 .58932 m .38279 .58923 L .38314 .58853 L F
.707 .726 .865 r
.71447 .41349 m .71634 .41151 L .71371 .41243 L F
.71447 .41349 m .71695 .4127 L .71634 .41151 L F
.464 .361 .653 r
.26188 .574 m .26007 .5779 L .26001 .57559 L F
0 0 0 r
.42478 .56846 m .4231 .57014 L .42615 .56823 L F
.582 .256 .382 r
.38279 .58923 m .38451 .5879 L .38314 .58853 L F
.367 .139 .43 r
.36261 .62262 m .36464 .62223 L .36512 .61946 L F
.466 .409 .71 r
.36384 .61362 m .36578 .61313 L .36526 .60974 L F
.372 .42 .781 r
.36384 .61362 m .3665 .61561 L .36578 .61313 L F
.553 .306 .495 r
.57794 .52195 m .58032 .52366 L .5778 .52402 L F
.57794 .52195 m .58042 .52158 L .58032 .52366 L F
0 0 .005 r
.66948 .42419 m .66953 .42571 L .66826 .4269 L F
.737 .558 0 r
.66934 .4236 m .66948 .42419 L .67119 .42225 L F
.66934 .4236 m .66953 .42571 L .66948 .42419 L F
.471 .15 .34 r
.58394 .50002 m .5815 .49876 L .58152 .5006 L F
.58394 .50002 m .58418 .49762 L .5815 .49876 L F
.507 .817 1 r
.68775 .39825 m .68629 .39973 L .68544 .39862 L F
.68775 .39825 m .68867 .39924 L .68629 .39973 L F
.603 .342 .494 r
.57204 .52511 m .57463 .52713 L .57201 .52719 L F
.57204 .52511 m .57525 .52424 L .57463 .52713 L F
.582 .256 .382 r
.38279 .58923 m .38502 .58977 L .38451 .5879 L F
.455 .119 .307 r
.38502 .58977 m .38859 .58632 L .38451 .5879 L F
.883 .788 .751 r
.4145 .58861 m .41704 .59036 L .41925 .58653 L F
.394 .174 .458 r
.41925 .58653 m .41704 .59036 L .41898 .58935 L F
.822 .395 .226 r
.41341 .58866 m .41514 .59119 L .41704 .59036 L F
.128 0 0 r
.41514 .59119 m .41803 .58981 L .41704 .59036 L F
.41803 .58981 m .41898 .58935 L .41779 .58997 L F
.41803 .58981 m .41779 .58997 L .41704 .59036 L F
.515 .889 .693 r
.42027 .58549 m .41925 .58653 L .42181 .58469 L F
.55 .269 .443 r
.41898 .58935 m .42217 .58657 L .41925 .58653 L F
0 0 0 r
.42027 .58549 m .41835 .5896 L .41925 .58653 L F
.128 0 0 r
.41514 .59119 m .41744 .59067 L .41842 .58983 L F
.41786 .58989 m .41842 .58983 L .41898 .58935 L F
.41514 .59119 m .41842 .58983 L .41786 .58989 L F
.336 .679 .978 r
.41341 .58866 m .41639 .59005 L .4145 .58861 L F
.41639 .59005 m .41704 .59036 L .41657 .59003 L F
.41639 .59005 m .41657 .59003 L .4145 .58861 L F
0 0 0 r
.41835 .5896 m .41821 .58991 L .41829 .58964 L F
.41835 .5896 m .41829 .58964 L .41925 .58653 L F
.883 .788 .751 r
.4145 .58861 m .41925 .58653 L .41821 .58991 L F
.642 .364 .481 r
.43668 .6432 m .43887 .64462 L .43671 .64392 L F
.43663 .64222 m .43769 .64335 L .43668 .6432 L F
.43769 .64335 m .43887 .64462 L .43668 .6432 L F
.681 .451 .566 r
.44251 .64394 m .44119 .64388 L .44267 .64259 L F
.766 .263 .008 r
.43788 .64374 m .43887 .64462 L .43663 .64222 L F
.681 .451 .566 r
.44119 .64388 m .43788 .64374 L .43879 .64352 L F
.44119 .64388 m .43879 .64352 L .44267 .64259 L F
.658 .312 .374 r
.44043 .6402 m .43788 .64374 L .43663 .64222 L F
.697 .359 .4 r
.44267 .64259 m .43788 .64374 L .44043 .6402 L F
.637 .367 .493 r
.44298 .64019 m .44267 .64259 L .44043 .6402 L F
.925 .752 .649 r
.66336 .43071 m .6612 .43193 L .66198 .42963 L F
.66336 .43071 m .66283 .43313 L .6612 .43193 L F
.796 .715 .775 r
.66957 .44166 m .67142 .44228 L .6702 .43948 L F
.765 .538 .589 r
.66781 .44433 m .67142 .44228 L .66957 .44166 L F
.66781 .44433 m .6714 .44479 L .67142 .44228 L F
.625 .632 .837 r
.6702 .43948 m .67142 .44228 L .67379 .44185 L F
.774 .598 .661 r
.76193 .40883 m .76006 .41214 L .75956 .41005 L F
.598 .46 .664 r
.22912 .57606 m .2319 .57757 L .23009 .57538 L F
.22912 .57606 m .22979 .57827 L .2319 .57757 L F
.328 .058 .343 r
.62051 .41292 m .62087 .41414 L .61887 .41487 L F
.562 .903 .672 r
.62266 .41085 m .62051 .41292 L .62422 .40988 L F
.755 .909 .529 r
.62266 .41085 m .62087 .41414 L .62051 .41292 L F
.607 .702 .911 r
.70362 .39885 m .70221 .40144 L .70114 .39971 L F
.70362 .39885 m .70473 .40071 L .70221 .40144 L F
.54 .335 .551 r
.54477 .55451 m .54471 .55691 L .54253 .55735 L F
.571 .443 .667 r
.54688 .5513 m .54748 .55391 L .54477 .55451 L F
.543 .337 .551 r
.54742 .55616 m .54477 .55451 L .54748 .55391 L F
.54742 .55616 m .54471 .55691 L .54477 .55451 L F
.314 .459 .846 r
.22395 .55281 m .22443 .55465 L .22555 .55325 L F
0 0 .474 r
.22443 .55465 m .22578 .55548 L .22555 .55325 L F
.22443 .55465 m .22464 .55764 L .22578 .55548 L F
.65 .448 .596 r
.57054 .50666 m .57399 .50683 L .57377 .50408 L F
.619 .474 .663 r
.57399 .50683 m .57613 .50342 L .57377 .50408 L F
.935 .964 .75 r
.60942 .4336 m .60782 .43583 L .60847 .43669 L F
.047 .603 .817 r
.20558 .55256 m .20374 .5521 L .20197 .55209 L F
.268 0 0 r
.20797 .55243 m .20374 .5521 L .20558 .55256 L F
.351 .405 .777 r
.7548 .4164 m .75482 .4202 L .75211 .4186 L F
0 .426 .849 r
.68185 .4062 m .6844 .40739 L .68082 .4051 L F
.251 .159 .552 r
.42933 .58662 m .43068 .58858 L .43091 .58654 L F
.615 .068 0 r
.42726 .58579 m .43068 .58858 L .42933 .58662 L F
.203 0 0 r
.53503 .57124 m .53845 .56913 L .53715 .56812 L F
.474 .159 .352 r
.53887 .57213 m .53883 .57387 L .53612 .57425 L F
.722 .493 .578 r
.54123 .57156 m .53883 .57387 L .53887 .57213 L F
.54123 .57156 m .54244 .57516 L .53883 .57387 L F
.069 .236 .729 r
.53883 .57387 m .54011 .5735 L .53755 .57058 L F
.78 .283 .021 r
.53755 .57058 m .53958 .57397 L .53787 .57148 L F
.203 0 0 r
.53503 .57124 m .53755 .57058 L .53728 .56985 L F
.577 .562 .801 r
.53612 .57425 m .53755 .57058 L .53503 .57124 L F
.53612 .57425 m .53883 .57387 L .53755 .57058 L F
.78 .283 .021 r
.53755 .57058 m .53787 .57148 L .53653 .56951 L F
.203 0 0 r
.53728 .56985 m .53755 .57058 L .53845 .56913 L F
0 0 0 r
.53771 .56755 m .53783 .56749 L .53715 .56812 L F
0 0 .372 r
.53845 .56913 m .53948 .56679 L .53715 .56812 L F
.53948 .56679 m .54008 .56541 L .53865 .56673 L F
.53948 .56679 m .53865 .56673 L .53798 .56743 L F
.53845 .56913 m .54004 .56801 L .54021 .5651 L F
0 0 .225 r
.54021 .5651 m .54004 .56801 L .54088 .56615 L F
.54021 .5651 m .54088 .56615 L .53798 .56743 L F
.54021 .5651 m .53798 .56743 L .53771 .56755 L F
0 0 .372 r
.53798 .56743 m .53865 .56673 L .53783 .56749 L F
.29 .767 .66 r
.53798 .56743 m .53783 .56749 L .53771 .56755 L F
0 0 .372 r
.53948 .56679 m .53783 .56749 L .53715 .56812 L F
.29 .767 .66 r
.54088 .56615 m .5386 .56714 L .53783 .56749 L F
.54088 .56615 m .53783 .56749 L .53798 .56743 L F
0 0 0 r
.53783 .56749 m .5386 .56714 L .53715 .56812 L F
0 0 .372 r
.54008 .56541 m .54021 .5651 L .53715 .56812 L F
.604 .45 .646 r
.54123 .57156 m .53845 .56913 L .54153 .56904 L F
.54123 .57156 m .53887 .57213 L .53845 .56913 L F
0 0 0 r
.53845 .56913 m .53755 .57058 L .54004 .56801 L F
.22971 .63425 m .22849 .63622 L .22735 .63724 L F
.025 0 0 r
.22775 .63845 m .22735 .63724 L .22849 .63622 L F
.22775 .63845 m .22603 .63929 L .22735 .63724 L F
.415 .334 .656 r
.2611 .55673 m .26137 .5587 L .25959 .55864 L F
.535 .404 .65 r
.26192 .56276 m .25959 .55864 L .26137 .5587 L F
.26192 .56276 m .2601 .56371 L .25959 .55864 L F
.737 .705 .821 r
.6391 .43689 m .63952 .43946 L .63629 .43891 L F
.762 .531 .583 r
.63952 .43946 m .63532 .4405 L .63629 .43891 L F
.63952 .43946 m .63989 .44185 L .63532 .4405 L F
.593 .574 .801 r
.64116 .43539 m .63952 .43946 L .6391 .43689 L F
.64116 .43539 m .64236 .43995 L .63952 .43946 L F
.634 .442 .606 r
.63952 .43946 m .64236 .43995 L .63989 .44185 L F
.96 .622 .27 r
.66384 .44069 m .66238 .44064 L .66145 .43677 L F
.688 .708 .182 r
.66384 .44069 m .66341 .44232 L .66238 .44064 L F
.66384 .44069 m .66275 .44484 L .66341 .44232 L F
.455 .119 .307 r
.38502 .58977 m .38746 .58947 L .38859 .58632 L F
.432 .122 .338 r
.38746 .58947 m .39091 .58564 L .38859 .58632 L F
.704 .825 .94 r
.54619 .67789 m .5475 .67911 L .54971 .67812 L F
.387 .767 .991 r
.6757 .3985 m .6719 .39922 L .67066 .39815 L F
.416 .776 .995 r
.67579 .39905 m .6719 .39922 L .6757 .3985 L F
.162 0 0 r
.39862 .58328 m .40216 .58122 L .39981 .58148 L F
.098 0 0 r
.62325 .43411 m .62622 .43452 L .62638 .43418 L F
.108 0 0 r
.19755 .6871 m .19548 .68882 L .19585 .68995 L F
0 0 .423 r
.19557 .68894 m .19559 .68899 L .19585 .68995 L F
.865 .963 .63 r
.19755 .6871 m .19585 .68995 L .19594 .69027 L F
0 0 .423 r
.19559 .68899 m .19714 .6922 L .19585 .68995 L F
.865 .963 .63 r
.19594 .69027 m .19585 .68995 L .19587 .69042 L F
.342 .241 .593 r
.19585 .68995 m .19547 .69287 L .19587 .69042 L F
.513 0 0 r
.46609 .57382 m .4648 .57448 L .46293 .57383 L F
.574 .209 .311 r
.46888 .57241 m .4648 .57448 L .46609 .57382 L F
.432 .218 .487 r
.24711 .60164 m .24662 .60423 L .24479 .60472 L F
.45 .26 .53 r
.2465 .60678 m .24479 .60472 L .24662 .60423 L F
.2465 .60678 m .24462 .6074 L .24479 .60472 L F
.803 .538 .538 r
.56172 .50981 m .56386 .51206 L .56368 .51019 L F
.7 .591 .731 r
.56368 .51019 m .56424 .50665 L .56172 .50981 L F
.56368 .51019 m .56563 .50791 L .56424 .50665 L F
.56368 .51019 m .56577 .51018 L .56563 .50791 L F
.68 .421 .524 r
.56573 .51244 m .56368 .51019 L .56386 .51206 L F
.56573 .51244 m .56577 .51018 L .56368 .51019 L F
0 .299 .793 r
.75435 .40743 m .75601 .40871 L .75502 .40711 L F
0 0 0 r
.61176 .42444 m .61104 .42618 L .61098 .42606 L F
0 0 .244 r
.61325 .42029 m .61266 .42469 L .61176 .42444 L F
.159 0 .028 r
.6132 .42524 m .61176 .42444 L .61266 .42469 L F
.6132 .42524 m .61104 .42618 L .61176 .42444 L F
.36 .144 .444 r
.24916 .60058 m .24662 .60423 L .24711 .60164 L F
.642 .7 .888 r
.71216 .40898 m .71371 .41243 L .71634 .41151 L F
.958 .89 .72 r
.51236 .68218 m .51119 .68424 L .51182 .68187 L F
0 0 .498 r
.73818 .40503 m .73902 .40663 L .73822 .40541 L F
.622 .719 .916 r
.73822 .40541 m .73416 .40453 L .73597 .40353 L F
0 0 .498 r
.73818 .40503 m .73822 .40541 L .73597 .40353 L F
.911 .934 .813 r
.73631 .40779 m .73902 .40663 L .73818 .40503 L F
.73631 .40779 m .73735 .40866 L .73902 .40663 L F
.537 .401 .643 r
.74088 .42475 m .74115 .42757 L .74367 .42445 L F
.723 .976 .922 r
.39958 .60326 m .39775 .60466 L .39891 .60492 L F
.982 .817 .602 r
.63444 .46523 m .63504 .46267 L .63375 .46131 L F
.629 .585 .786 r
.36512 .61946 m .36756 .61956 L .3665 .61561 L F
.549 .298 .488 r
.36464 .62223 m .3671 .62194 L .36512 .61946 L F
.612 .306 .427 r
.36512 .61946 m .3671 .62194 L .36756 .61956 L F
.14 0 .167 r
.71175 .44561 m .71492 .44478 L .71511 .44465 L F
.374 .817 .95 r
.71492 .44478 m .71577 .44542 L .71511 .44465 L F
.7 .941 .961 r
.62182 .45698 m .61768 .45779 L .62155 .45593 L F
.878 .993 .78 r
.62221 .45476 m .62182 .45698 L .62155 .45593 L F
.412 .195 .472 r
.2427 .61302 m .24035 .61588 L .24075 .61368 L F
.92 .839 .748 r
.68387 .46314 m .68258 .46659 L .68134 .46508 L F
.591 .871 .994 r
.68258 .46659 m .68413 .46488 L .68134 .46508 L F
.68258 .46659 m .68514 .46575 L .68413 .46488 L F
.354 0 0 r
.49214 .62565 m .49037 .62535 L .4902 .62519 L F
0 0 .32 r
.4902 .62519 m .49037 .62535 L .49053 .62524 L F
.008 0 0 r
.4902 .62519 m .49053 .62524 L .48947 .62542 L F
.4902 .62519 m .49053 .62524 L .48947 .62542 L F
.891 .889 .823 r
.51901 .53408 m .51675 .53714 L .51552 .53612 L F
.652 .843 .973 r
.67715 .41546 m .6807 .41568 L .67955 .41445 L F
.774 .874 .921 r
.67955 .41445 m .6807 .41568 L .6821 .41487 L F
.462 .465 .776 r
.22274 .58991 m .22362 .59283 L .22515 .59162 L F
.474 .297 .56 r
.22362 .59283 m .22587 .59484 L .22515 .59162 L F
.22362 .59283 m .2235 .59549 L .22587 .59484 L F
.474 .637 .926 r
.39882 .62688 m .39782 .62882 L .3965 .62737 L F
.39882 .62688 m .39937 .62864 L .39782 .62882 L F
.773 .717 .8 r
.57131 .63429 m .57475 .63447 L .57409 .63329 L F
.785 .575 .617 r
.57473 .63692 m .57475 .63447 L .57131 .63429 L F
.748 .708 .814 r
.57409 .63329 m .57475 .63447 L .57635 .63337 L F
.611 .431 .615 r
.57635 .63337 m .57475 .63447 L .57473 .63692 L F
.768 .512 .548 r
.44749 .63654 m .45199 .63708 L .45128 .63438 L F
.893 .583 .454 r
.45128 .63438 m .45199 .63708 L .45256 .63648 L F
.685 .604 .76 r
.45256 .63648 m .45574 .6356 L .45128 .63438 L F
.663 .563 .732 r
.56563 .50791 m .56577 .51018 L .56824 .50717 L F
.633 .519 .706 r
.56577 .51018 m .56838 .51006 L .56824 .50717 L F
.599 .332 .484 r
.56809 .51218 m .56577 .51018 L .56573 .51244 L F
.56809 .51218 m .56838 .51006 L .56577 .51018 L F
.891 .889 .823 r
.51901 .53408 m .51552 .53612 L .51763 .53298 L F
.843 .799 .809 r
.56584 .49792 m .56365 .50078 L .56686 .50115 L F
.852 .75 .75 r
.56305 .50289 m .56686 .50115 L .56365 .50078 L F
.56305 .50289 m .5646 .50428 L .56686 .50115 L F
.768 .762 .847 r
.56584 .49792 m .56686 .50115 L .56956 .49852 L F
0 0 .108 r
.65283 .43149 m .65263 .43041 L .65279 .42916 L F
.65283 .43149 m .65277 .4328 L .65263 .43041 L F
.605 .181 0 r
.63917 .41665 m .64027 .41832 L .64123 .41982 L F
0 0 .242 r
.23138 .63089 m .23098 .63341 L .22971 .63425 L F
0 0 0 r
.22994 .63531 m .22971 .63425 L .23098 .63341 L F
.22994 .63531 m .22849 .63622 L .22971 .63425 L F
.92 .839 .748 r
.68387 .46314 m .68134 .46508 L .6839 .46191 L F
.827 .806 .832 r
.6859 .45862 m .68387 .46314 L .6839 .46191 L F
.892 .747 .694 r
.51636 .54842 m .51486 .55095 L .51395 .55008 L F
.643 .684 .874 r
.51756 .54644 m .51636 .54842 L .51461 .54713 L F
.794 .951 .921 r
.19683 .63962 m .19261 .64109 L .19555 .64022 L F
0 0 0 r
.19957 .63724 m .19683 .63962 L .19797 .63944 L F
.19797 .63944 m .19683 .63962 L .19555 .64022 L F
.448 0 0 r
.41627 .64337 m .4184 .64434 L .41497 .64427 L F
.454 .015 .112 r
.41627 .64337 m .41871 .64329 L .4184 .64434 L F
.197 0 0 r
.19912 .5403 m .20109 .54054 L .20298 .54016 L F
.356 0 0 r
.20109 .54054 m .20507 .53983 L .20298 .54016 L F
.934 .845 .732 r
.54271 .67255 m .54454 .66888 L .54292 .66799 L F
.791 .327 .136 r
.54428 .67114 m .54454 .66888 L .54292 .66799 L F
.54428 .67114 m .54681 .67157 L .54454 .66888 L F
.877 .613 .535 r
.54681 .67157 m .54731 .66934 L .54454 .66888 L F
.68 .669 .833 r
.39508 .61945 m .39299 .62163 L .39153 .61847 L F
.597 .533 .754 r
.39508 .61945 m .39564 .62161 L .39299 .62163 L F
.181 .286 .736 r
.39581 .62404 m .39299 .62163 L .39564 .62161 L F
0 .218 .741 r
.40079 .63019 m .40144 .63167 L .39937 .62864 L F
.787 .299 .054 r
.40079 .63019 m .40395 .63272 L .40144 .63167 L F
.779 .63 .695 r
.43121 .57326 m .43227 .57514 L .42853 .57469 L F
.553 0 0 r
.43121 .57326 m .4348 .57431 L .43227 .57514 L F
.156 0 .316 r
.63109 .40289 m .62911 .40621 L .62939 .40415 L F
.561 .018 0 r
.41022 .64303 m .40952 .64432 L .40649 .64255 L F
.531 0 0 r
.41241 .64368 m .40952 .64432 L .41022 .64303 L F
.453 .451 .765 r
.44097 .57157 m .44182 .56798 L .4393 .56861 L F
.44097 .57157 m .44295 .57155 L .44182 .56798 L F
.52 .477 .75 r
.54455 .55943 m .54351 .56322 L .54284 .5601 L F
.54455 .55943 m .54575 .56273 L .54351 .56322 L F
.513 .405 .669 r
.54655 .56546 m .54351 .56322 L .54575 .56273 L F
.54655 .56546 m .54384 .56611 L .54351 .56322 L F
.94 .857 .731 r
.57202 .49059 m .57416 .48985 L .57283 .48866 L F
.851 .833 .828 r
.57283 .48866 m .57416 .48985 L .57658 .48695 L F
.566 .862 .996 r
.72584 .43942 m .72196 .43935 L .72477 .43843 L F
.578 .838 .994 r
.72731 .43761 m .72584 .43942 L .72477 .43843 L F
.72731 .43761 m .72831 .43865 L .72584 .43942 L F
.612 .351 .497 r
.59234 .49451 m .58978 .49233 L .5897 .4946 L F
.59234 .49451 m .59285 .4926 L .58978 .49233 L F
.602 .428 .619 r
.54894 .5457 m .54913 .54823 L .54669 .54875 L F
.508 .369 .627 r
.54894 .5457 m .55145 .5477 L .54913 .54823 L F
.54894 .5457 m .55127 .5451 L .55145 .5477 L F
.441 .217 .477 r
.59346 .51221 m .59336 .50999 L .59559 .50954 L F
.063 0 .155 r
.19206 .678 m .1938 .67553 L .19276 .67658 L F
.891 .984 .713 r
.55867 .48033 m .55733 .48099 L .55836 .47963 L F
.55867 .48033 m .5567 .48339 L .55733 .48099 L F
.813 .999 .839 r
.55867 .48033 m .56097 .47694 L .56164 .47749 L F
.55867 .48033 m .55836 .47963 L .56097 .47694 L F
.954 .942 .624 r
.21606 .59722 m .21433 .60158 L .21389 .60032 L F
.784 .561 .597 r
.21769 .59667 m .21434 .59546 L .21606 .59722 L F
.985 .895 .636 r
.21606 .59722 m .21389 .60032 L .21508 .59773 L F
.21606 .59722 m .21508 .59773 L .21801 .59832 L F
.562 .415 .639 r
.21769 .59667 m .21801 .59832 L .21606 .59722 L F
.824 .703 .731 r
.73087 .41979 m .73375 .42154 L .73101 .41981 L F
.73087 .41979 m .73319 .42295 L .73375 .42154 L F
.652 .711 .891 r
.69756 .40942 m .70113 .41028 L .7 .40845 L F
.671 .755 .913 r
.70113 .41028 m .70252 .40761 L .7 .40845 L F
.70113 .41028 m .7036 .40939 L .70252 .40761 L F
.467 .31 .585 r
.26007 .5779 m .26012 .58044 L .25807 .58103 L F
.467 .311 .586 r
.26012 .58044 m .26017 .58312 L .25807 .58103 L F
.496 .313 .562 r
.25807 .58103 m .26017 .58312 L .25797 .58363 L F
.307 .771 .944 r
.48147 .63132 m .48032 .63085 L .47778 .63113 L F
.763 .979 .914 r
.48217 .62945 m .48147 .63132 L .48309 .62977 L F
.653 .704 .884 r
.49947 .71911 m .50039 .72203 L .50317 .72032 L F
.13 0 0 r
.17446 .54107 m .17707 .54139 L .17879 .54149 L F
.117 0 0 r
.17879 .54149 m .17707 .54139 L .18093 .54174 L F
.755 .739 .838 r
.66788 .4591 m .67131 .4592 L .67058 .4561 L F
.893 .952 .835 r
.60843 .42209 m .60752 .42117 L .60886 .41929 L F
.363 .721 .988 r
.68855 .46522 m .69004 .46435 L .68756 .46439 L F
.68855 .46522 m .69116 .4654 L .69004 .46435 L F
.693 .78 .918 r
.65398 .43619 m .65432 .43624 L .65277 .43476 L F
.666 .499 .648 r
.2321 .56563 m .23491 .56247 L .2325 .56327 L F
.807 .914 .521 r
.19987 .63574 m .19957 .63724 L .19797 .63944 L F
.755 .588 .016 r
.22075 .57656 m .22093 .57919 L .22015 .57914 L F
.774 .874 .921 r
.67955 .41445 m .6821 .41487 L .6821 .41187 L F
.728 .806 .913 r
.6821 .41187 m .6821 .41487 L .68585 .41234 L F
.446 .33 .628 r
.54284 .5601 m .54232 .55835 L .54253 .55735 L F
.565 .402 .619 r
.54455 .55943 m .54253 .55735 L .54471 .55691 L F
.54455 .55943 m .54284 .5601 L .54253 .55735 L F
.725 .984 .901 r
.5567 .48339 m .55286 .48514 L .55547 .4834 L F
.882 .988 .81 r
.5567 .48339 m .55547 .4834 L .55733 .48099 L F
.777 .699 .777 r
.53435 .69536 m .53605 .69829 L .53193 .69813 L F
.075 0 0 r
.53193 .69813 m .53605 .69829 L .53388 .69825 L F
.741 .687 .799 r
.53435 .69536 m .53859 .69608 L .53605 .69829 L F
.766 .955 .934 r
.5351 .69921 m .53616 .69744 L .53605 .69829 L F
.075 0 0 r
.53388 .69825 m .53605 .69829 L .5346 .6983 L F
.766 .955 .934 r
.5351 .69921 m .53566 .69828 L .53605 .69829 L F
.53566 .69828 m .53616 .69744 L .53605 .69829 L F
.203 0 0 r
.61887 .41487 m .61773 .41489 L .61562 .41455 L F
.253 .763 .765 r
.62087 .41414 m .61773 .41489 L .61887 .41487 L F
.49 .634 .917 r
.54395 .67824 m .54451 .67622 L .54218 .6738 L F
.54395 .67824 m .54619 .67789 L .54451 .67622 L F
.632 .416 .571 r
.58311 .5189 m .58313 .52165 L .58042 .52158 L F
.489 .29 .537 r
.58311 .5189 m .58529 .51601 L .58549 .51827 L F
.521 .339 .574 r
.58549 .51827 m .58313 .52165 L .58311 .5189 L F
.139 0 .318 r
.6712 .4038 m .67184 .40512 L .67124 .40269 L F
0 0 0 r
.21645 .64849 m .21376 .65118 L .21491 .64953 L F
.434 .874 .852 r
.63672 .43164 m .64058 .43056 L .63738 .42992 L F
.157 0 .351 r
.64247 .42703 m .64058 .43056 L .64287 .42943 L F
.181 .034 .432 r
.64287 .42943 m .64058 .43056 L .64123 .43312 L F
.215 0 .269 r
.60001 .48602 m .59765 .48868 L .59982 .48826 L F
.035 0 .036 r
.59982 .48826 m .59765 .48868 L .59708 .49077 L F
.916 .953 .802 r
.57566 .61817 m .57676 .61917 L .57441 .62206 L F
.287 .707 .971 r
.57992 .61912 m .57676 .61917 L .57566 .61817 L F
.61 .415 .594 r
.52261 .55124 m .5223 .55314 L .52511 .55112 L F
.52511 .55112 m .5223 .55314 L .52261 .55124 L F
.545 .381 .61 r
.54913 .54823 m .54688 .5513 L .54669 .54875 L F
.851 .833 .828 r
.57283 .48866 m .57658 .48695 L .57533 .48605 L F
.872 .882 .84 r
.57533 .48605 m .57658 .48695 L .57905 .48397 L F
.95 .639 .41 r
.68427 .41047 m .68585 .41234 L .68576 .41019 L F
.542 .245 .412 r
.58529 .51601 m .58769 .51773 L .58549 .51827 L F
.58529 .51601 m .58778 .51589 L .58769 .51773 L F
.663 .792 .943 r
.71695 .4127 m .7197 .41025 L .71634 .41151 L F
.71695 .4127 m .71955 .41205 L .7197 .41025 L F
.552 .903 .687 r
.62653 .45074 m .62336 .45291 L .62454 .45136 L F
.715 .93 .603 r
.62887 .44776 m .62653 .45074 L .6276 .44893 L F
.764 .996 .841 r
.6276 .44893 m .62653 .45074 L .62454 .45136 L F
.492 0 0 r
.40764 .63331 m .4096 .63405 L .41127 .63408 L F
.623 .156 .124 r
.4096 .63405 m .4137 .6342 L .41127 .63408 L F
.493 .506 .799 r
.36625 .62587 m .3671 .62194 L .36464 .62223 L F
.36625 .62587 m .36835 .62587 L .3671 .62194 L F
.685 .604 .76 r
.45256 .63648 m .45499 .63736 L .45574 .6356 L F
.624 .511 .704 r
.45499 .63736 m .45705 .63389 L .45574 .6356 L F
.591 .838 .991 r
.45725 .63927 m .45835 .63705 L .45499 .63736 L F
.666 .394 .498 r
.44604 .64198 m .44298 .64019 L .44644 .64002 L F
.456 .181 .406 r
.44901 .64112 m .44644 .64002 L .44918 .6402 L F
.44901 .64112 m .44604 .64198 L .44644 .64002 L F
0 0 0 r
.67356 .41917 m .67258 .41958 L .67539 .41829 L F
.67356 .41917 m .67137 .42011 L .67258 .41958 L F
.547 .775 .983 r
.37608 .62828 m .37835 .62778 L .37706 .62653 L F
.37706 .62653 m .37835 .62778 L .37608 .62828 L F
0 0 .498 r
.73818 .40503 m .73597 .40353 L .73904 .40288 L F
.687 .779 .921 r
.73543 .40061 m .73597 .40353 L .7327 .40309 L F
.767 .677 .763 r
.7327 .40309 m .73597 .40353 L .73416 .40453 L F
.559 .688 .926 r
.73904 .40288 m .73597 .40353 L .73543 .40061 L F
.795 .503 .494 r
.22024 .56332 m .224 .56645 L .22285 .56316 L F
.22024 .56332 m .22256 .56628 L .224 .56645 L F
.562 .298 .473 r
.57525 .52424 m .57707 .5269 L .57463 .52713 L F
.57525 .52424 m .5778 .52402 L .57707 .5269 L F
.343 0 .215 r
.18917 .55513 m .18762 .55455 L .18954 .55384 L F
.18917 .55513 m .18702 .55574 L .18762 .55455 L F
.053 0 .081 r
.60319 .50302 m .60384 .50118 L .60585 .50019 L F
.632 .833 .978 r
.48424 .57471 m .48049 .57436 L .48276 .57194 L F
.446 .159 .383 r
.48424 .57471 m .48389 .5771 L .48153 .57763 L F
.682 .73 .887 r
.48655 .57345 m .48424 .57471 L .48276 .57194 L F
.485 .192 .393 r
.48638 .57635 m .48389 .5771 L .48424 .57471 L F
.59 .486 .704 r
.48655 .57345 m .48752 .57576 L .48424 .57471 L F
.598 .11 .067 r
.48752 .57576 m .48638 .57635 L .48424 .57471 L F
.481 0 0 r
.41926 .60073 m .41787 .60148 L .41527 .60059 L F
.126 0 0 r
.41787 .60148 m .41436 .60255 L .41527 .60059 L F
.41731 .60165 m .41646 .60234 L .41436 .60255 L F
.41787 .60148 m .41646 .60234 L .41731 .60165 L F
0 0 .137 r
.41646 .60234 m .41322 .60666 L .41436 .60255 L F
.512 .845 .561 r
.41726 .6015 m .4153 .60329 L .41646 .60234 L F
.4153 .60329 m .41481 .60373 L .41646 .60234 L F
.916 .974 .689 r
.41798 .59937 m .41654 .6022 L .41787 .60148 L F
.41654 .6022 m .41646 .60234 L .41787 .60148 L F
.481 0 0 r
.41929 .60073 m .41787 .60148 L .41926 .60073 L F
.564 .598 .845 r
.42026 .59745 m .42171 .60018 L .41929 .60073 L F
0 0 0 r
.42008 .60065 m .41929 .60073 L .42171 .60018 L F
.42008 .60065 m .41787 .60148 L .41929 .60073 L F
.551 .922 .937 r
.70651 .45749 m .70539 .45871 L .7081 .45754 L F
.70651 .45749 m .70437 .45844 L .70539 .45871 L F
.212 0 0 r
.16611 .54701 m .16816 .54652 L .17007 .54469 L F
.016 0 0 r
.17007 .54469 m .17101 .54489 L .17191 .54362 L F
.17007 .54469 m .16816 .54652 L .17101 .54489 L F
.48 .82 .999 r
.45752 .5662 m .4597 .56574 L .46103 .56644 L F
.192 .694 .91 r
.4597 .56574 m .4634 .56611 L .46103 .56644 L F
.324 0 0 r
.37069 .59497 m .37298 .59465 L .37449 .59291 L F
.384 0 .083 r
.37298 .59465 m .37681 .59247 L .37449 .59291 L F
.681 .628 .789 r
.73266 .43045 m .73675 .43214 L .7355 .43116 L F
.503 .713 .965 r
.73675 .43214 m .73849 .43046 L .7355 .43116 L F
.73675 .43214 m .73934 .43201 L .73849 .43046 L F
.743 .627 .731 r
.56424 .50665 m .56563 .50791 L .5646 .50428 L F
.668 .583 .751 r
.5646 .50428 m .56563 .50791 L .56824 .50717 L F
.966 .854 .678 r
.63396 .45546 m .63623 .45369 L .63502 .45245 L F
.63396 .45546 m .63521 .45622 L .63623 .45369 L F
.769 .824 .895 r
.63623 .45369 m .6378 .44977 L .63502 .45245 L F
.63623 .45369 m .6393 .45146 L .6378 .44977 L F
.938 .781 .659 r
.21881 .5709 m .21989 .57163 L .22131 .56912 L F
.931 .969 .746 r
.22256 .56628 m .22131 .56912 L .224 .56645 L F
.22256 .56628 m .22051 .56865 L .22131 .56912 L F
.911 .979 .777 r
.22051 .56865 m .21881 .5709 L .22131 .56912 L F
.693 .78 .918 r
.65398 .43619 m .65277 .43476 L .65186 .43776 L F
.971 .798 .611 r
.65146 .4408 m .65398 .43619 L .65186 .43776 L F
.65146 .4408 m .65281 .44175 L .65398 .43619 L F
.939 .619 .402 r
.522 .57762 m .51993 .57517 L .52045 .57553 L F
.527 .227 .402 r
.2034 .67081 m .2042 .67163 L .20166 .67152 L F
.28 .705 .969 r
.20166 .67152 m .2042 .67163 L .20269 .67096 L F
.138 .186 .65 r
.20228 .66896 m .2034 .67081 L .20166 .67152 L F
.28 .705 .969 r
.20166 .67152 m .20269 .67096 L .20169 .67051 L F
0 0 .185 r
.20058 .67212 m .20166 .67152 L .20049 .6723 L F
.20228 .66896 m .20166 .67152 L .20058 .67212 L F
.266 0 0 r
.21145 .55266 m .20978 .5528 L .20797 .55243 L F
.338 0 0 r
.21145 .55266 m .21357 .55331 L .20978 .5528 L F
.44 .147 .369 r
.47443 .62815 m .47614 .62954 L .47699 .62803 L F
.47443 .62815 m .47398 .63027 L .47614 .62954 L F
.918 .882 .783 r
.65807 .40913 m .65486 .41091 L .65649 .40846 L F
.65807 .40913 m .65629 .41221 L .65486 .41091 L F
.587 .885 .991 r
.65892 .40757 m .65807 .40913 L .65649 .40846 L F
.349 .602 .943 r
.65892 .40757 m .6602 .4093 L .65807 .40913 L F
.587 .885 .991 r
.65892 .40757 m .65807 .40913 L .65649 .40846 L F
.425 .265 .559 r
.25098 .59624 m .25116 .5986 L .24947 .59885 L F
.395 .165 .443 r
.25098 .59992 m .24947 .59885 L .25116 .5986 L F
.25098 .59992 m .24916 .60058 L .24947 .59885 L F
.183 0 .222 r
.21376 .65118 m .21121 .65411 L .21207 .65206 L F
.206 0 .27 r
.25375 .59004 m .25312 .59197 L .25157 .59253 L F
.384 .26 .585 r
.2534 .59465 m .25157 .59253 L .25312 .59197 L F
.2534 .59465 m .25098 .59624 L .25157 .59253 L F
.854 .74 .737 r
.56827 .49479 m .56956 .49852 L .57145 .4952 L F
.863 .678 .651 r
.57145 .4952 m .57078 .49572 L .56827 .49479 L F
.924 .884 .775 r
.57202 .49059 m .57078 .49572 L .57145 .4952 L F
.696 .598 .742 r
.45262 .5716 m .45769 .57313 L .45536 .56879 L F
.628 .569 .769 r
.45536 .56879 m .45769 .57313 L .45885 .57173 L F
0 0 0 r
.45769 .57313 m .4565 .57484 L .45885 .57173 L F
.106 .008 .449 r
.75482 .4202 m .75491 .42269 L .75305 .42418 L F
.609 .594 .811 r
.75491 .42269 m .75373 .42749 L .75305 .42418 L F
.374 .073 .32 r
.58656 .49759 m .58418 .49762 L .58394 .50002 L F
.474 .752 .991 r
.24457 .54458 m .24419 .54611 L .24254 .5448 L F
.24457 .54458 m .24591 .54573 L .24419 .54611 L F
.999 .805 .503 r
.6463 .44208 m .6469 .44612 L .64835 .44342 L F
.437 .475 .801 r
.6469 .44612 m .64959 .44693 L .64835 .44342 L F
.537 .333 .552 r
.6469 .44612 m .64725 .44792 L .64959 .44693 L F
.122 0 0 r
.45262 .5716 m .4519 .57172 L .44884 .57153 L F
.829 .996 .848 r
.45291 .56929 m .45262 .5716 L .45514 .56901 L F
.4522 .56937 m .45232 .57002 L .45291 .56929 L F
.45232 .57002 m .45262 .5716 L .45291 .56929 L F
.576 .05 0 r
.45291 .56929 m .45305 .56721 L .45071 .5689 L F
.45305 .56721 m .45279 .56732 L .45071 .5689 L F
.45291 .56929 m .45071 .5689 L .4522 .56937 L F
.54 .422 .668 r
.45015 .56762 m .45071 .5689 L .45306 .56711 L F
.512 .298 .526 r
.45015 .56762 m .4522 .56937 L .45071 .5689 L F
.45074 .56812 m .45006 .57006 L .4522 .56937 L F
.45015 .56762 m .45012 .56836 L .45074 .56812 L F
.45012 .56836 m .45006 .57006 L .45074 .56812 L F
.576 .05 0 r
.45305 .56721 m .45306 .56711 L .45279 .56732 L F
.829 .996 .848 r
.45317 .56919 m .45514 .56901 L .45536 .56879 L F
.4522 .56937 m .45314 .56926 L .45317 .56919 L F
.45314 .56926 m .45514 .56901 L .45317 .56919 L F
.375 .771 .987 r
.45267 .56474 m .45415 .56531 L .45146 .56598 L F
.45415 .56531 m .4559 .56598 L .45408 .56598 L F
.45415 .56531 m .45408 .56598 L .45146 .56598 L F
.711 .875 .958 r
.45601 .56508 m .4559 .56598 L .45267 .56474 L F
.45601 .56508 m .45267 .56474 L .4543 .56461 L F
.375 .771 .987 r
.45267 .56474 m .45146 .56598 L .45006 .56351 L F
0 .332 .779 r
.45096 .56344 m .45267 .56474 L .45006 .56351 L F
.658 .727 .9 r
.45096 .56344 m .4543 .56461 L .45267 .56474 L F
.76 .662 .754 r
.45096 .56344 m .45306 .56711 L .4543 .56461 L F
.789 .895 .485 r
.45421 .56471 m .45306 .56711 L .45385 .56511 L F
.4543 .56461 m .4542 .56481 L .45421 .56471 L F
.4542 .56481 m .45306 .56711 L .45421 .56471 L F
.373 .411 .772 r
.45306 .56711 m .45386 .56789 L .45385 .56511 L F
.576 .05 0 r
.45458 .56966 m .45291 .56929 L .4522 .56937 L F
.45599 .56982 m .45379 .56944 L .45458 .56966 L F
.45379 .56944 m .45291 .56929 L .45458 .56966 L F
.45599 .56982 m .45461 .56954 L .45291 .56929 L F
.45589 .56973 m .45296 .56923 L .45291 .56929 L F
.451 0 0 r
.45393 .5694 m .45599 .56982 L .4522 .56937 L F
.628 .569 .769 r
.45536 .56879 m .45885 .57173 L .45712 .56944 L F
.451 0 0 r
.45712 .56944 m .45599 .56982 L .45393 .5694 L F
.576 .05 0 r
.45599 .56982 m .45589 .56973 L .45461 .56954 L F
.451 0 0 r
.45712 .56944 m .45393 .5694 L .45536 .56879 L F
.45393 .5694 m .45388 .56939 L .45536 .56879 L F
.45386 .5694 m .45317 .56919 L .45536 .56879 L F
.576 .05 0 r
.45589 .56973 m .45398 .56797 L .45296 .56923 L F
.451 0 0 r
.45393 .5694 m .45386 .5694 L .45388 .56939 L F
.45386 .5694 m .4522 .56937 L .45317 .56919 L F
.576 .05 0 r
.45599 .56982 m .45628 .57023 L .45306 .56711 L F
.373 .411 .772 r
.45386 .56789 m .45611 .57006 L .45455 .56658 L F
.45611 .57006 m .45613 .57008 L .45612 .57006 L F
.45611 .57006 m .45612 .57006 L .45455 .56658 L F
.45613 .57008 m .45628 .57023 L .45623 .57011 L F
.37 .4 .761 r
.45885 .57173 m .46082 .57065 L .45712 .56944 L F
.452 .8 .998 r
.46082 .57065 m .45599 .56982 L .45712 .56944 L F
.4597 .57046 m .4584 .5695 L .45599 .56982 L F
.46082 .57065 m .4584 .5695 L .4597 .57046 L F
0 0 .184 r
.45723 .56839 m .45599 .56982 L .4584 .5695 L F
.992 .74 .436 r
.4584 .5695 m .45696 .57054 L .4572 .56862 L F
.4584 .5695 m .4572 .56862 L .45723 .56839 L F
0 0 .184 r
.45723 .56839 m .45628 .57023 L .45599 .56982 L F
.373 .411 .772 r
.45613 .57008 m .45623 .57011 L .45455 .56658 L F
.45386 .56789 m .45455 .56658 L .45385 .56511 L F
.576 .05 0 r
.45398 .56797 m .45306 .56711 L .45291 .56929 L F
.914 .937 .574 r
.4522 .56937 m .4519 .57172 L .45262 .5716 L F
.256 0 0 r
.18146 .55615 m .17773 .55738 L .17996 .55624 L F
0 0 0 r
.203 .63317 m .20609 .63046 L .20431 .63127 L F
.968 .908 .701 r
.62717 .47423 m .62838 .47181 L .62626 .4731 L F
.867 .992 .822 r
.62838 .47181 m .63081 .46892 L .62895 .46949 L F
.879 .993 .763 r
.62626 .4731 m .62838 .47181 L .62895 .46949 L F
.063 0 .155 r
.19206 .678 m .19438 .67504 L .1938 .67553 L F
.842 .879 .868 r
.67982 .41054 m .67634 .4112 L .67843 .40863 L F
.723 .796 .909 r
.68184 .40908 m .67982 .41054 L .67843 .40863 L F
.506 .911 .857 r
.73533 .44363 m .73474 .44346 L .733 .44475 L F
.494 .901 .801 r
.73474 .44346 m .73249 .4447 L .733 .44475 L F
.783 .728 .801 r
.57745 .62201 m .57542 .62456 L .57927 .62524 L F
.484 .59 .884 r
.57745 .62201 m .57927 .62524 L .57979 .62446 L F
.646 .815 .965 r
.57979 .62446 m .57804 .62503 L .57927 .62524 L F
.57804 .62503 m .57583 .62573 L .57927 .62524 L F
.783 .728 .801 r
.57542 .62456 m .57533 .62468 L .57927 .62524 L F
.635 .825 .973 r
.57583 .62573 m .57533 .62468 L .57927 .62524 L F
.673 .483 .62 r
.44086 .58666 m .43715 .58643 L .43953 .58579 L F
.44086 .58666 m .43986 .59054 L .43715 .58643 L F
.44086 .58666 m .44073 .5897 L .43986 .59054 L F
0 0 .347 r
.44202 .58795 m .44073 .5897 L .44086 .58666 L F
.44202 .58795 m .44086 .58666 L .43953 .58579 L F
.384 .253 .576 r
.24462 .6074 m .24466 .60983 L .24293 .61032 L F
.404 .223 .519 r
.2446 .61236 m .24293 .61032 L .24466 .60983 L F
.2446 .61236 m .2427 .61302 L .24293 .61032 L F
.14 0 .167 r
.71175 .44561 m .71126 .44733 L .71492 .44478 L F
.299 .609 .954 r
.25683 .55025 m .25721 .55185 L .25602 .55027 L F
.25683 .55025 m .26005 .55243 L .25721 .55185 L F
.608 .603 .821 r
.26129 .55417 m .25721 .55185 L .26005 .55243 L F
.872 .882 .84 r
.57533 .48605 m .57905 .48397 L .57743 .48256 L F
.432 .457 .786 r
.74771 .42579 m .74903 .42305 L .74646 .42369 L F
.856 .981 .858 r
.5643 .47474 m .56164 .47749 L .56212 .47517 L F
.887 .99 .758 r
.56164 .47749 m .56097 .47694 L .56212 .47517 L F
.662 .703 .877 r
.71945 .40046 m .71806 .40395 L .71698 .40201 L F
.71945 .40046 m .72054 .40298 L .71806 .40395 L F
.666 .394 .498 r
.44604 .64198 m .44267 .64259 L .44298 .64019 L F
0 .196 .722 r
.37164 .63043 m .37345 .63286 L .37357 .63206 L F
.37164 .63043 m .37357 .63206 L .37141 .63054 L F
.502 .324 .571 r
.54375 .67364 m .54428 .67114 L .54322 .67134 L F
.934 .845 .732 r
.54271 .67255 m .54292 .66799 L .54152 .67167 L F
.502 .324 .571 r
.54223 .6723 m .54322 .67134 L .54152 .67167 L F
.54375 .67364 m .54322 .67134 L .54223 .6723 L F
.715 .978 .765 r
.54271 .67255 m .54006 .67503 L .5405 .67395 L F
.54065 .67381 m .5405 .67395 L .54053 .67388 L F
.54271 .67255 m .5405 .67395 L .54065 .67381 L F
.662 .97 .902 r
.54006 .67503 m .54218 .6738 L .54053 .67388 L F
.616 .424 .599 r
.55857 .53363 m .55875 .53605 L .555 .53596 L F
.609 .376 .538 r
.555 .53596 m .55852 .53848 L .55603 .53892 L F
.555 .53596 m .55875 .53605 L .55852 .53848 L F
.153 0 0 r
.7465 .43643 m .74868 .43657 L .74604 .43734 L F
.7465 .43643 m .74933 .4361 L .74868 .43657 L F
.915 .754 .668 r
.67265 .4384 m .67379 .44185 L .67426 .43971 L F
.917 .976 .767 r
.42966 .57118 m .42853 .57469 L .43103 .57175 L F
.42966 .57118 m .42788 .57394 L .42853 .57469 L F
.647 .406 .539 r
.42788 .57394 m .43121 .57326 L .42853 .57469 L F
.42788 .57394 m .42953 .57598 L .43121 .57326 L F
.383 0 .079 r
.43121 .57326 m .43239 .57546 L .43364 .57444 L F
.43121 .57326 m .42953 .57598 L .43239 .57546 L F
.553 0 0 r
.43121 .57326 m .43364 .57444 L .4348 .57431 L F
.792 .959 .92 r
.64959 .44693 m .65356 .44528 L .65182 .44394 L F
.642 .874 .514 r
.58241 .45006 m .58246 .44987 L .58365 .44853 L F
0 0 0 r
.58365 .44853 m .58435 .44877 L .58486 .447 L F
.58365 .44853 m .58246 .44987 L .58435 .44877 L F
.885 .932 .845 r
.41014 .5981 m .40779 .6016 L .40951 .59862 L F
.413 .83 .652 r
.41224 .59694 m .41095 .59767 L .40951 .59862 L F
0 0 0 r
.40951 .59862 m .41095 .59767 L .41014 .5981 L F
.065 0 0 r
.40813 .57821 m .40887 .57904 L .41062 .57785 L F
.40813 .57821 m .40674 .57986 L .40887 .57904 L F
.871 .848 .818 r
.22532 .58683 m .22274 .58991 L .22134 .58892 L F
.22532 .58683 m .22134 .58892 L .22173 .58872 L F
.521 .397 .652 r
.22532 .58683 m .22679 .58271 L .22381 .5835 L F
.22532 .58683 m .2275 .58642 L .22679 .58271 L F
.737 .609 .715 r
.22173 .58872 m .2275 .58642 L .22532 .58683 L F
.619 .732 .927 r
.71698 .40201 m .71457 .4027 L .71335 .40037 L F
.499 .822 .516 r
.56805 .46788 m .56941 .46653 L .57104 .46539 L F
.56805 .46788 m .56818 .46773 L .56941 .46653 L F
.643 .306 .386 r
.502 .71777 m .50315 .71696 L .50011 .71794 L F
.699 .392 .453 r
.502 .71777 m .50526 .71837 L .50315 .71696 L F
.841 .722 .733 r
.61261 .41533 m .61015 .41509 L .61179 .41208 L F
.8 .572 .593 r
.61261 .41533 m .60941 .41741 L .61015 .41509 L F
.61261 .41533 m .61243 .4179 L .60941 .41741 L F
.636 .599 .796 r
.61562 .41455 m .61261 .41533 L .61179 .41208 L F
.471 .289 .552 r
.61502 .4167 m .61261 .41533 L .61562 .41455 L F
.61502 .4167 m .61243 .4179 L .61261 .41533 L F
.556 .466 .708 r
.23009 .57538 m .23354 .57675 L .23392 .57448 L F
.23009 .57538 m .2319 .57757 L .23354 .57675 L F
.661 .541 .707 r
.56824 .50717 m .57161 .50959 L .57054 .50666 L F
.664 .496 .648 r
.57161 .50959 m .57399 .50683 L .57054 .50666 L F
.258 .744 .923 r
.211 .54044 m .21332 .54026 L .21505 .54082 L F
0 .465 .7 r
.21332 .54026 m .21706 .54097 L .21505 .54082 L F
.885 .932 .845 r
.41014 .5981 m .40628 .60107 L .40779 .6016 L F
.744 .337 .279 r
.40779 .6016 m .40959 .60396 L .40975 .60291 L F
.26 .277 .689 r
.64242 .42357 m .64247 .42703 L .64335 .42583 L F
0 0 .308 r
.64335 .42583 m .64247 .42703 L .64287 .42943 L F
.276 0 0 r
.53593 .68905 m .53943 .68768 L .5397 .68667 L F
.741 .713 .18 r
.5397 .68667 m .54035 .68284 L .54129 .68423 L F
.5397 .68667 m .53943 .68768 L .54035 .68284 L F
.22 .043 .415 r
.60285 .4824 m .60001 .48602 L .60232 .48536 L F
.062 0 .113 r
.60232 .48536 m .60001 .48602 L .59982 .48826 L F
.547 .023 0 r
.40404 .64255 m .40254 .64284 L .40057 .64236 L F
.226 0 0 r
.40649 .64255 m .40254 .64284 L .40404 .64255 L F
.596 .78 .968 r
.73666 .43614 m .73447 .43746 L .73349 .4356 L F
.409 .845 .943 r
.73666 .43614 m .73902 .43555 L .74037 .43601 L F
.597 .567 .792 r
.73934 .43201 m .74037 .43601 L .74291 .43536 L F
.418 0 0 r
.73902 .43555 m .74291 .43536 L .74037 .43601 L F
.664 .784 .938 r
.6904 .40837 m .69182 .4102 L .69401 .40897 L F
.501 .287 .52 r
.46839 .58376 m .46817 .58659 L .46545 .58712 L F
.238 .073 .445 r
.46839 .58376 m .46969 .58549 L .4698 .58308 L F
.46839 .58376 m .46817 .58659 L .46969 .58549 L F
.786 .686 .14 r
.21433 .60158 m .21407 .60264 L .21389 .60032 L F
.21433 .60158 m .21408 .60402 L .21407 .60264 L F
.612 .453 .643 r
.54389 .56823 m .54123 .57156 L .54153 .56904 L F
.631 .731 .919 r
.70835 .40178 m .70473 .40071 L .70722 .39987 L F
.619 .689 .893 r
.70971 .39892 m .70835 .40178 L .70722 .39987 L F
.70971 .39892 m .71075 .40099 L .70835 .40178 L F
.438 .486 .812 r
.43416 .58375 m .43058 .58026 L .43202 .58049 L F
.714 .333 0 r
.6587 .41799 m .66032 .4212 L .65953 .4198 L F
.851 .514 0 r
.65953 .4198 m .66032 .4212 L .66088 .42339 L F
.435 .798 .996 r
.23683 .54325 m .23908 .54287 L .2401 .54363 L F
.145 .437 .874 r
.24134 .54291 m .2401 .54363 L .23908 .54287 L F
.24134 .54291 m .24254 .5448 L .2401 .54363 L F
.376 .062 .301 r
.46269 .58958 m .46545 .58712 L .46505 .58909 L F
.438 .13 .344 r
.46545 .58712 m .46732 .58849 L .46505 .58909 L F
.46545 .58712 m .46817 .58659 L .46732 .58849 L F
0 0 0 r
.56603 .47116 m .5643 .47474 L .56527 .47288 L F
.492 .013 .047 r
.42226 .64299 m .4184 .64434 L .41871 .64329 L F
.42226 .64299 m .42075 .64455 L .4184 .64434 L F
.714 .277 .21 r
.42226 .64299 m .42448 .64511 L .42075 .64455 L F
.616 .323 .449 r
.42461 .64301 m .42448 .64511 L .42226 .64299 L F
.722 .758 .881 r
.73416 .40453 m .73057 .40399 L .7327 .40309 L F
.853 .511 .406 r
.66953 .41469 m .67113 .41473 L .6704 .41292 L F
.706 .819 .935 r
.7293 .41897 m .72791 .42157 L .73087 .41979 L F
.671 .847 .967 r
.50317 .72032 m .50719 .72038 L .50526 .71837 L F
.771 .673 .754 r
.50526 .71837 m .50719 .72038 L .50836 .71856 L F
.50526 .71837 m .50719 .72038 L .50836 .71856 L F
.337 .498 .871 r
.26206 .55224 m .26129 .55417 L .26005 .55243 L F
.26206 .55224 m .26302 .5544 L .26129 .55417 L F
.357 .439 .808 r
.26409 .55201 m .26528 .55467 L .26302 .5544 L F
.658 .453 .595 r
.26533 .55562 m .26143 .55422 L .26302 .5544 L F
.26533 .55562 m .2611 .55673 L .26129 .55417 L F
.544 .302 .499 r
.26533 .55562 m .26137 .5587 L .2611 .55673 L F
.26532 .55562 m .2644 .55893 L .26137 .5587 L F
.26533 .55562 m .26532 .55562 L .26532 .55562 L F
.26532 .55562 m .2644 .55893 L .26532 .55562 L F
.571 .891 .624 r
.26707 .55664 m .26548 .55801 L .26533 .55562 L F
.26548 .55801 m .2644 .55893 L .26522 .55599 L F
.26548 .55801 m .26522 .55599 L .26533 .55562 L F
.758 .6 .682 r
.26699 .56268 m .26137 .5587 L .2644 .55893 L F
.26699 .56268 m .26192 .56276 L .26137 .5587 L F
.571 .891 .624 r
.26707 .55664 m .26494 .55829 L .2644 .55893 L F
.951 .663 .217 r
.26494 .55829 m .26699 .56268 L .2644 .55893 L F
.26579 .5601 m .26597 .56199 L .26699 .56268 L F
.26572 .55995 m .26589 .56129 L .26579 .5601 L F
.26589 .56129 m .26597 .56199 L .26579 .5601 L F
.053 0 0 r
.26699 .56268 m .26192 .565 L .26192 .56276 L F
.26493 .56362 m .26373 .56459 L .26192 .565 L F
.26699 .56268 m .26524 .56371 L .26493 .56362 L F
.26524 .56371 m .26373 .56459 L .26493 .56362 L F
.562 .117 .151 r
.26551 .56431 m .26373 .56459 L .26699 .56268 L F
.26551 .56431 m .26699 .56268 L .2658 .56187 L F
0 0 .36 r
.26602 .56286 m .26608 .56363 L .26587 .56388 L F
.26568 .56383 m .26587 .56388 L .26551 .56431 L F
.26602 .56286 m .26587 .56388 L .26568 .56383 L F
.26702 .56 m .26705 .56249 L .26608 .56363 L F
.26702 .56 m .26608 .56363 L .26602 .56286 L F
.951 .663 .217 r
.26494 .55829 m .26597 .56199 L .26572 .55995 L F
0 0 .36 r
.26702 .56 m .26602 .56286 L .2658 .56187 L F
.26602 .56286 m .26551 .56431 L .2658 .56187 L F
.951 .663 .217 r
.26523 .55932 m .2658 .56187 L .26597 .56199 L F
.26494 .55829 m .2658 .56187 L .26523 .55932 L F
.56 0 0 r
.26302 .5544 m .26606 .55641 L .26661 .55654 L F
.26567 .55587 m .26661 .55654 L .26707 .55664 L F
.26302 .5544 m .26661 .55654 L .26567 .55587 L F
.26302 .5544 m .26707 .55664 L .26533 .55562 L F
.357 .439 .808 r
.26528 .55467 m .26606 .55641 L .26302 .5544 L F
.658 .453 .595 r
.26143 .55422 m .26129 .55417 L .26302 .5544 L F
.742 .918 .951 r
.42865 .59104 m .43066 .59108 L .43068 .58858 L F
.746 .694 .801 r
.72325 .41266 m .72309 .41461 L .72565 .41202 L F
.436 0 .058 r
.63272 .44318 m .63125 .44188 L .63025 .44404 L F
.63272 .44318 m .63366 .44161 L .63125 .44188 L F
.638 .383 .517 r
.49053 .62524 m .49385 .62263 L .49255 .62088 L F
.49053 .62524 m .49457 .62476 L .49385 .62263 L F
.353 .029 .269 r
.56503 .63408 m .56552 .63413 L .56398 .63328 L F
.252 .71 .952 r
.20507 .53983 m .20672 .53971 L .20864 .54053 L F
.362 .755 .987 r
.20672 .53971 m .211 .54044 L .20864 .54053 L F
.435 0 0 r
.19333 .5534 m .19187 .55401 L .18954 .55384 L F
.099 0 0 r
.19557 .55306 m .19187 .55401 L .19333 .5534 L F
.506 .317 .558 r
.45419 .57724 m .45649 .57736 L .4565 .57484 L F
.722 .524 .622 r
.47699 .62803 m .48012 .62786 L .48026 .6252 L F
.482 0 0 r
.48098 .62628 m .48026 .6252 L .48012 .62786 L F
.48098 .62628 m .48241 .62582 L .48026 .6252 L F
.513 .385 .643 r
.22979 .57827 m .23158 .57955 L .2319 .57757 L F
.22979 .57827 m .22972 .58047 L .23158 .57955 L F
.298 0 0 r
.20486 .65701 m .20757 .65615 L .20733 .6564 L F
0 0 0 r
.21114 .65414 m .20909 .65567 L .20733 .6564 L F
.21121 .65411 m .20909 .65567 L .21114 .65414 L F
.298 0 0 r
.20757 .65615 m .20909 .65567 L .20733 .6564 L F
.61 .956 .876 r
.20733 .6564 m .20577 .65781 L .20708 .65667 L F
.20733 .6564 m .20708 .65667 L .20929 .65475 L F
0 0 0 r
.21121 .65411 m .20733 .6564 L .20929 .65475 L F
.61 .956 .876 r
.20733 .6564 m .20562 .65758 L .20577 .65781 L F
.452 .882 .812 r
.20733 .6564 m .20486 .65701 L .20336 .65806 L F
.298 0 0 r
.20486 .65701 m .20782 .65661 L .20909 .65567 L F
.20782 .65661 m .20861 .6565 L .20909 .65567 L F
.899 .781 .291 r
.65244 .42429 m .65254 .41993 L .65204 .42242 L F
.859 .631 .095 r
.65218 .42552 m .65244 .42429 L .65204 .42242 L F
.65218 .42552 m .65264 .42658 L .65244 .42429 L F
.219 0 0 r
.221 .54123 m .22303 .54162 L .22485 .54174 L F
.143 0 0 r
.22485 .54174 m .22303 .54162 L .22687 .54201 L F
.728 .61 .726 r
.64236 .43995 m .64372 .44321 L .63989 .44185 L F
.624 .561 .763 r
.645 .43951 m .64372 .44321 L .64236 .43995 L F
.645 .43951 m .6463 .44208 L .64372 .44321 L F
.454 .192 .427 r
.64372 .44321 m .6463 .44208 L .64517 .44439 L F
.581 .909 .978 r
.69304 .46397 m .69747 .46335 L .69479 .46294 L F
.83 .903 .89 r
.69479 .46294 m .69747 .46335 L .6988 .46179 L F
.631 .705 .899 r
.44417 .59183 m .44821 .59271 L .44658 .58904 L F
.497 .305 .55 r
.44821 .59271 m .45057 .58968 L .44658 .58904 L F
.44821 .59271 m .45048 .59218 L .45057 .58968 L F
.44821 .59271 m .45048 .59218 L .45057 .58968 L F
.833 .93 .895 r
.73571 .42788 m .73266 .43045 L .73244 .42895 L F
.502 0 0 r
.7355 .43116 m .73244 .42895 L .73266 .43045 L F
.001 0 .088 r
.39479 .60553 m .39433 .60706 L .39327 .60734 L F
.156 .229 .688 r
.39433 .60706 m .39511 .60923 L .39327 .60734 L F
.41 .272 .581 r
.39327 .60734 m .39511 .60923 L .39326 .60959 L F
.574 .209 .311 r
.46888 .57241 m .46679 .57482 L .4648 .57448 L F
.474 .47 .774 r
.46944 .56828 m .47002 .57315 L .46888 .57241 L F
.714 .281 .219 r
.47002 .57315 m .47064 .57388 L .46888 .57241 L F
.673 .332 .389 r
.47064 .57388 m .46679 .57482 L .46888 .57241 L F
.465 .538 .847 r
.55967 .62765 m .56122 .63125 L .56292 .62937 L F
.466 .54 .848 r
.56122 .63125 m .56398 .63328 L .56292 .62937 L F
.252 0 .033 r
.16707 .56019 m .16908 .55976 L .16672 .56065 L F
.737 .988 .892 r
.5643 .47474 m .56212 .47517 L .56527 .47288 L F
0 0 0 r
.41239 .60484 m .41136 .60544 L .41314 .60407 L F
.55 .929 .904 r
.71041 .45594 m .7081 .45754 L .71066 .45662 L F
.71041 .45594 m .70651 .45749 L .7081 .45754 L F
.474 .284 .542 r
.54389 .56823 m .54384 .56611 L .54655 .56546 L F
.561 .263 .42 r
.48842 .62271 m .49134 .62218 L .49085 .62032 L F
.43 .186 .442 r
.49085 .62032 m .49134 .62218 L .49255 .62088 L F
.019 0 .284 r
.20609 .63046 m .20769 .62733 L .20655 .62816 L F
.485 .514 .812 r
.44672 .57165 m .44763 .56809 L .44551 .57072 L F
.775 .759 .838 r
.64461 .40784 m .64434 .4096 L .64277 .40892 L F
.424 0 0 r
.64555 .41205 m .64277 .40892 L .64434 .4096 L F
.517 .516 .794 r
.64706 .40765 m .64434 .4096 L .64461 .40784 L F
.328 .335 .715 r
.64746 .41053 m .64434 .4096 L .64706 .40765 L F
.64746 .41053 m .64555 .41205 L .64434 .4096 L F
.345 .054 .32 r
.25575 .58943 m .25312 .59197 L .25375 .59004 L F
.065 0 0 r
.16367 .5479 m .16611 .54701 L .16427 .54743 L F
.873 .499 .333 r
.52531 .5809 m .52339 .58043 L .522 .57762 L F
.764 .497 .529 r
.52531 .5809 m .52175 .58299 L .52339 .58043 L F
.52531 .5809 m .5255 .5833 L .52175 .58299 L F
.568 .246 .383 r
.5895 .49634 m .5871 .49467 L .58656 .49759 L F
.5895 .49634 m .5897 .4946 L .5871 .49467 L F
.849 .599 .559 r
.66283 .43313 m .65989 .4346 L .6612 .43193 L F
.66283 .43313 m .66284 .43551 L .65989 .4346 L F
.889 .645 .564 r
.52947 .58375 m .52672 .586 L .5255 .5833 L F
.52947 .58375 m .52954 .58654 L .52672 .586 L F
.509 .341 .588 r
.53197 .58563 m .52947 .58375 L .53128 .58324 L F
.53197 .58563 m .52954 .58654 L .52947 .58375 L F
.223 .73 .894 r
.23722 .55803 m .23523 .55795 L .23508 .5586 L F
.038 .35 .826 r
.2348 .55991 m .23508 .5586 L .23257 .55694 L F
.4 0 0 r
.23508 .5586 m .23164 .55703 L .23257 .55694 L F
.223 .73 .894 r
.23523 .55795 m .23322 .55786 L .23508 .5586 L F
.038 .35 .826 r
.23491 .56006 m .23508 .5586 L .2348 .55991 L F
.24 .568 .939 r
.23491 .56006 m .23624 .55993 L .23508 .5586 L F
.563 .553 .801 r
.23491 .56247 m .23624 .55993 L .23491 .56006 L F
0 .259 .768 r
.37141 .63054 m .37357 .63206 L .37081 .62862 L F
.748 .93 .949 r
.7064 .45032 m .70345 .45087 L .70557 .44929 L F
.603 .842 .989 r
.70958 .44905 m .7064 .45032 L .70557 .44929 L F
.919 .523 .195 r
.19922 .67614 m .1999 .6745 L .19868 .67355 L F
.803 .685 .734 r
.56076 .50589 m .56424 .50665 L .5646 .50428 L F
.796 .702 .761 r
.56076 .50589 m .56172 .50981 L .56424 .50665 L F
.653 .488 .648 r
.5611 .53328 m .55875 .53605 L .55857 .53363 L F
.76 .528 .582 r
.57533 .62468 m .57849 .62738 L .57927 .62524 L F
0 0 0 r
.57927 .62524 m .57849 .62738 L .57979 .62446 L F
.663 .14 0 r
.57849 .62738 m .57927 .62524 L .57979 .62446 L F
.08 .402 .857 r
.76717 .41452 m .76892 .41555 L .76949 .417 L F
0 0 .096 r
.76892 .41555 m .76891 .41573 L .76949 .417 L F
.596 .808 .981 r
.76676 .4177 m .76949 .417 L .77005 .41825 L F
.76676 .4177 m .76949 .417 L .77032 .4183 L F
.619 .646 .854 r
.76717 .41452 m .76949 .417 L .76676 .4177 L F
.56 .389 .607 r
.76949 .417 m .76702 .42016 L .76676 .4177 L F
.76949 .417 m .76702 .42016 L .76676 .4177 L F
.284 .047 .368 r
.76949 .417 m .76863 .41932 L .76702 .42016 L F
0 0 .096 r
.76891 .41573 m .76863 .41932 L .76949 .417 L F
.596 .808 .981 r
.77005 .41825 m .76949 .417 L .77032 .4183 L F
0 0 0 r
.22274 .58991 m .22173 .58872 L .22532 .58933 L F
.22274 .58991 m .22134 .58892 L .22173 .58872 L F
.737 .609 .715 r
.22334 .58808 m .22532 .58933 L .2275 .58642 L F
.22173 .58872 m .2231 .58895 L .22334 .58808 L F
.2231 .58895 m .22532 .58933 L .22334 .58808 L F
.462 .465 .776 r
.22274 .58991 m .22515 .59162 L .22532 .58933 L F
0 0 0 r
.22302 .58924 m .22236 .5917 L .22327 .58865 L F
.22274 .58991 m .22239 .59153 L .22302 .58924 L F
.22239 .59153 m .22236 .5917 L .22302 .58924 L F
.22274 .58991 m .22327 .58865 L .22134 .58892 L F
.614 .832 .441 r
.21392 .61938 m .2127 .62105 L .21481 .61804 L F
.445 .21 .462 r
.36396 .60123 m .36604 .60081 L .36644 .59847 L F
.408 .212 .501 r
.36644 .59847 m .36843 .59791 L .3686 .59547 L F
.416 .196 .47 r
.36604 .60081 m .36843 .59791 L .36644 .59847 L F
.792 .96 .92 r
.6302 .46802 m .63081 .46892 L .63274 .46731 L F
.915 .969 .791 r
.62895 .46949 m .63081 .46892 L .6302 .46802 L F
.93 .85 .741 r
.6634 .44811 m .66243 .4508 L .66066 .44992 L F
.816 .36 .151 r
.66243 .4508 m .65995 .45114 L .66066 .44992 L F
.66243 .4508 m .66543 .45463 L .65995 .45114 L F
.66543 .45463 m .66474 .4543 L .65995 .45114 L F
.74 .648 .758 r
.66582 .4522 m .66436 .45387 L .66536 .45439 L F
.752 .704 .807 r
.66474 .4543 m .66436 .45387 L .65995 .45114 L F
.66436 .45387 m .66247 .45182 L .66076 .45136 L F
.66436 .45387 m .66076 .45136 L .65995 .45114 L F
.74 .648 .758 r
.66436 .45387 m .66639 .45529 L .66717 .45533 L F
.785 .724 .796 r
.66247 .45182 m .6636 .45305 L .66582 .4522 L F
.66282 .45335 m .66421 .45403 L .66582 .4522 L F
.816 .36 .151 r
.66543 .45463 m .66561 .45487 L .66474 .4543 L F
.752 .704 .807 r
.66561 .45487 m .66247 .45182 L .66474 .4543 L F
.785 .724 .796 r
.66247 .45182 m .66282 .45335 L .6636 .45305 L F
.66282 .45335 m .66323 .45515 L .66421 .45403 L F
.739 .507 .578 r
.66717 .45533 m .66323 .45515 L .66431 .4544 L F
.752 .704 .807 r
.66518 .45445 m .66323 .45515 L .66247 .45182 L F
.718 .47 .551 r
.66431 .4544 m .66323 .45515 L .66561 .45487 L F
.752 .704 .807 r
.66561 .45487 m .66323 .45515 L .66518 .45445 L F
.74 .648 .758 r
.66657 .45395 m .66536 .45439 L .66717 .45533 L F
.66582 .4522 m .66536 .45439 L .66657 .45395 L F
.66436 .45387 m .66323 .45515 L .66639 .45529 L F
.879 .899 .841 r
.54214 .68954 m .54197 .68683 L .54073 .68851 L F
.54214 .68954 m .5433 .68766 L .54197 .68683 L F
.661 .805 .952 r
.69401 .40897 m .69756 .40942 L .69639 .40799 L F
.656 .796 .949 r
.69756 .40942 m .69886 .40697 L .69639 .40799 L F
.69756 .40942 m .7 .40845 L .69886 .40697 L F
.936 .75 .626 r
.45937 .63357 m .46091 .637 L .463 .63678 L F
.45937 .63357 m .45912 .63661 L .46091 .637 L F
0 0 .155 r
.63217 .40092 m .63135 .40063 L .63035 .40056 L F
.63217 .40092 m .63109 .40289 L .63135 .40063 L F
0 0 0 r
.20845 .62413 m .20985 .62377 L .21148 .62243 L F
.34 .141 .457 r
.20985 .62377 m .2127 .62105 L .21148 .62243 L F
.82 .867 .881 r
.4406 .59238 m .44242 .59326 L .44417 .59183 L F
.918 .722 .623 r
.64123 .41982 m .643 .42149 L .64242 .42357 L F
.795 .692 .752 r
.54823 .67489 m .54619 .67789 L .54971 .67812 L F
.93 .85 .741 r
.6634 .44811 m .66066 .44992 L .66159 .44681 L F
.279 0 0 r
.62131 .40268 m .62375 .40222 L .62482 .40068 L F
.604 .255 .35 r
.57883 .50275 m .58142 .50284 L .579 .50109 L F
.534 .297 .501 r
.579 .50109 m .58142 .50284 L .58152 .5006 L F
.317 .404 .794 r
.46819 .56472 m .46805 .56855 L .46596 .56516 L F
.46819 .56472 m .46944 .56828 L .46805 .56855 L F
.562 .379 .59 r
.53044 .67514 m .53316 .67428 L .53088 .67256 L F
.545 .381 .61 r
.54913 .54823 m .5493 .55077 L .54688 .5513 L F
.511 .285 .507 r
.5493 .55077 m .5491 .55317 L .54688 .5513 L F
.346 .296 .658 r
.5491 .55317 m .54748 .55391 L .54688 .5513 L F
.38 .141 .422 r
.23862 .61944 m .23806 .62163 L .23613 .62219 L F
.405 .206 .494 r
.23806 .62163 m .23586 .62482 L .23613 .62219 L F
.438 .34 .647 r
.36396 .60123 m .36617 .60342 L .36604 .60081 L F
.36396 .60123 m .36395 .60479 L .36617 .60342 L F
.975 .747 .53 r
.66088 .42339 m .66233 .42722 L .66094 .4258 L F
.989 .763 .502 r
.66094 .4258 m .66233 .42722 L .66198 .42963 L F
.11 0 0 r
.63125 .43005 m .62762 .43176 L .63019 .43094 L F
.987 .713 .374 r
.63233 .43204 m .63121 .43358 L .63387 .43283 L F
.63019 .43094 m .63063 .43208 L .63233 .43204 L F
.63063 .43208 m .63121 .43358 L .63233 .43204 L F
.519 .127 .238 r
.63236 .43204 m .6337 .43009 L .63125 .43005 L F
.987 .713 .374 r
.63019 .43094 m .63387 .43283 L .63255 .43238 L F
.519 .127 .238 r
.63255 .43238 m .63272 .43203 L .63236 .43204 L F
.63272 .43203 m .6337 .43009 L .63236 .43204 L F
.63255 .43238 m .63125 .43005 L .63019 .43094 L F
.513 .51 .79 r
.3665 .61561 m .36756 .61956 L .36965 .61854 L F
.265 .005 .32 r
.36756 .61956 m .3671 .62194 L .36965 .61854 L F
.981 .721 .324 r
.6284 .43454 m .62638 .43418 L .62622 .43452 L F
.396 .243 .554 r
.25347 .59725 m .25098 .59624 L .2534 .59465 L F
.25347 .59725 m .25116 .5986 L .25098 .59624 L F
.363 0 .17 r
.39377 .58418 m .39548 .58506 L .39636 .58389 L F
.39377 .58418 m .39313 .58561 L .39548 .58506 L F
0 .208 .73 r
.54218 .6738 m .54375 .67364 L .54053 .67388 L F
.54218 .6738 m .54451 .67622 L .54375 .67364 L F
.428 .166 .412 r
.75176 .43272 m .75198 .43519 L .74933 .4361 L F
.193 0 .128 r
.75176 .43272 m .75374 .43158 L .75355 .43128 L F
.111 0 .37 r
.75382 .43347 m .75176 .43272 L .75355 .43128 L F
.75382 .43347 m .75198 .43519 L .75176 .43272 L F
.855 .863 .846 r
.66833 .44932 m .66745 .45298 L .66952 .45054 L F
.777 .978 .705 r
.66952 .45054 m .66745 .45298 L .66771 .45265 L F
.708 .43 .502 r
.66771 .45265 m .67228 .45093 L .66952 .45054 L F
.66771 .45265 m .6729 .45318 L .67228 .45093 L F
.302 .116 .453 r
.61171 .47096 m .61005 .47435 L .6108 .47233 L F
.987 .894 .575 r
.61198 .46673 m .61171 .47096 L .61201 .4706 L F
0 0 0 r
.61201 .4706 m .61171 .47096 L .6108 .47233 L F
.538 .293 .492 r
.59115 .51258 m .59113 .51531 L .58778 .51589 L F
.51 .268 .485 r
.59346 .51221 m .59113 .51531 L .59115 .51258 L F
.672 .831 .96 r
.74138 .41539 m .74228 .41646 L .74492 .41552 L F
.74492 .41552 m .74228 .41646 L .74138 .41539 L F
.74138 .41539 m .74228 .41646 L .74492 .41552 L F
.571 .667 .903 r
.66489 .40485 m .6636 .40879 L .66231 .40804 L F
.66489 .40485 m .66603 .40835 L .6636 .40879 L F
.592 .027 0 r
.61045 .43023 m .61192 .4316 L .61373 .43242 L F
.329 .757 .973 r
.61373 .43242 m .61556 .43213 L .61192 .4316 L F
.61373 .43242 m .61556 .43213 L .61192 .4316 L F
.706 .644 .786 r
.44658 .58904 m .45057 .58968 L .44923 .58627 L F
.767 .675 .761 r
.44923 .58627 m .45057 .58968 L .45143 .58652 L F
.362 .119 .406 r
.45048 .59218 m .45225 .59049 L .45057 .58968 L F
.45048 .59218 m .45225 .59049 L .45057 .58968 L F
.521 .688 .943 r
.69865 .40047 m .69537 .39922 L .69762 .39867 L F
.618 .73 .927 r
.69998 .39802 m .69865 .40047 L .69762 .39867 L F
.69998 .39802 m .70114 .39971 L .69865 .40047 L F
.715 .492 0 r
.74137 .42922 m .74115 .42757 L .7401 .42687 L F
0 0 0 r
.74137 .42922 m .74049 .43078 L .74143 .42965 L F
.715 .492 0 r
.74137 .42922 m .74144 .42962 L .7412 .42785 L F
.74144 .42962 m .74167 .43096 L .74146 .42958 L F
.74144 .42962 m .74146 .42958 L .7412 .42785 L F
0 0 0 r
.74049 .43078 m .7397 .43176 L .74142 .42967 L F
.367 .411 .775 r
.74299 .42878 m .74167 .43096 L .74137 .42922 L F
0 0 0 r
.74143 .42965 m .74142 .42967 L .7421 .42884 L F
.74049 .43078 m .74142 .42967 L .74143 .42965 L F
.74137 .42922 m .74143 .42965 L .7421 .42884 L F
.715 .492 0 r
.74137 .42922 m .7412 .42785 L .74115 .42757 L F
.903 .847 .394 r
.51788 .54345 m .51794 .54537 L .51756 .54644 L F
.722 .789 .905 r
.70047 .45317 m .69859 .45451 L .69708 .4528 L F
.464 .361 .653 r
.26188 .574 m .26211 .57736 L .26007 .5779 L F
.507 .341 .591 r
.26228 .57989 m .26007 .5779 L .26211 .57736 L F
.26228 .57989 m .26012 .58044 L .26007 .5779 L F
0 0 .213 r
.51606 .56806 m .51681 .56891 L .51681 .56863 L F
.51606 .56806 m .51681 .56863 L .51681 .56653 L F
0 .079 .567 r
.51557 .5677 m .51606 .56806 L .51372 .56605 L F
.51701 .56898 m .51606 .56806 L .51557 .5677 L F
.966 .707 .49 r
.51701 .56898 m .51546 .57058 L .51606 .56806 L F
.51701 .56898 m .51701 .57145 L .51546 .57058 L F
.771 .775 .856 r
.48049 .57436 m .47817 .5768 L .47678 .5741 L F
.309 0 .197 r
.39775 .60466 m .39433 .60706 L .39479 .60553 L F
.833 .93 .895 r
.73571 .42788 m .73244 .42895 L .73462 .42644 L F
.75 .875 .937 r
.73792 .42609 m .73571 .42788 L .73462 .42644 L F
.765 .996 .828 r
.46762 .5757 m .46672 .57747 L .46764 .5759 L F
.46762 .5757 m .46672 .57747 L .46764 .5759 L F
.874 .939 .858 r
.45994 .58524 m .46044 .58784 L .45719 .58807 L F
.385 .267 .595 r
.45915 .58901 m .45719 .58807 L .46044 .58784 L F
0 .252 .762 r
.4622 .58711 m .46044 .58784 L .45994 .58524 L F
0 0 0 r
.45915 .58901 m .46044 .58784 L .4622 .58711 L F
.476 .127 .294 r
.19987 .63574 m .203 .63317 L .20142 .63395 L F
.596 .791 .974 r
.36835 .62587 m .37244 .62653 L .3709 .62498 L F
.422 .578 .903 r
.37244 .62653 m .37302 .62427 L .3709 .62498 L F
.37244 .62653 m .37466 .62691 L .37302 .62427 L F
.121 0 0 r
.23257 .55694 m .22926 .55678 L .23095 .55722 L F
.331 0 0 r
.42298 .59258 m .41743 .59359 L .42036 .59271 L F
.19 .462 .884 r
.25511 .54864 m .2539 .54949 L .25205 .54798 L F
.25511 .54864 m .25602 .55027 L .2539 .54949 L F
.764 .98 .722 r
.57361 .46254 m .57104 .46539 L .57203 .46346 L F
.758 .969 .686 r
.57104 .46539 m .56941 .46653 L .57203 .46346 L F
.734 .83 .924 r
.57409 .63329 m .56964 .63302 L .57131 .63429 L F
.57409 .63329 m .57249 .63144 L .56964 .63302 L F
.837 .852 .856 r
.57409 .62952 m .57409 .63329 L .57573 .63044 L F
.57409 .62952 m .57249 .63144 L .57409 .63329 L F
.394 .763 .993 r
.38296 .63429 m .38179 .6335 L .37964 .6337 L F
.149 .491 .904 r
.38296 .63429 m .38378 .6334 L .38179 .6335 L F
.38296 .63429 m .38635 .63606 L .38378 .6334 L F
.82 .867 .881 r
.4406 .59238 m .44417 .59183 L .44339 .59209 L F
.832 .808 .827 r
.44347 .58982 m .44417 .59183 L .44658 .58904 L F
.091 .32 .796 r
.44347 .58982 m .44561 .59107 L .44417 .59183 L F
.331 .797 .689 r
.44561 .59107 m .44339 .59209 L .44417 .59183 L F
.966 .787 .352 r
.51091 .6866 m .51039 .68611 L .51119 .68424 L F
.51119 .68424 m .51039 .68611 L .51091 .6866 L F
.51091 .6866 m .51039 .68611 L .51119 .68424 L F
.781 .986 .897 r
.63387 .43283 m .63526 .43329 L .63672 .43164 L F
.778 .501 .515 r
.57134 .62404 m .57441 .62206 L .57213 .62503 L F
0 .163 .685 r
.51372 .56605 m .51385 .5655 L .51185 .56525 L F
.51372 .56605 m .51606 .56806 L .51385 .5655 L F
.803 .685 .734 r
.56076 .50589 m .5646 .50428 L .56305 .50289 L F
.661 .541 .707 r
.56824 .50717 m .56838 .51006 L .57161 .50959 L F
.55 .269 .443 r
.41898 .58935 m .42196 .58939 L .42217 .58657 L F
.404 .338 .669 r
.42217 .58657 m .42383 .5838 L .42181 .58469 L F
0 0 .068 r
.42217 .58657 m .42227 .58846 L .42424 .58652 L F
.618 .49 .684 r
.42383 .5838 m .42424 .58652 L .42668 .58536 L F
.843 .811 .819 r
.42668 .58536 m .42261 .58672 L .42523 .58542 L F
.42261 .58672 m .42118 .5872 L .42276 .58651 L F
.42261 .58672 m .42276 .58651 L .42523 .58542 L F
0 0 .068 r
.42221 .58729 m .42196 .58939 L .42227 .58846 L F
.42217 .58657 m .42211 .58744 L .42221 .58729 L F
.42211 .58744 m .42196 .58939 L .42221 .58729 L F
.59 .567 .797 r
.43645 .57295 m .43761 .57381 L .4348 .57431 L F
.353 0 0 r
.43364 .57444 m .43761 .57381 L .4348 .57431 L F
.106 .06 .517 r
.43628 .5758 m .4348 .57431 L .43761 .57381 L F
.43628 .5758 m .4348 .57798 L .4348 .57431 L F
0 0 0 r
.74094 .4413 m .74088 .44111 L .74376 .43869 L F
.351 .034 .281 r
.22679 .58271 m .22887 .58248 L .22972 .58047 L F
.58 .437 .651 r
.22679 .58271 m .22996 .58557 L .22887 .58248 L F
.22679 .58271 m .2275 .58642 L .22996 .58557 L F
.413 0 .075 r
.4137 .6342 m .41592 .6341 L .41697 .63312 L F
.484 .052 .142 r
.41592 .6341 m .41955 .63315 L .41697 .63312 L F
.784 .695 .766 r
.55856 .50948 m .56172 .50981 L .56076 .50589 L F
.812 .546 .536 r
.5584 .51155 m .56172 .50981 L .55856 .50948 L F
.5584 .51155 m .56182 .51254 L .56172 .50981 L F
.803 .538 .538 r
.56172 .50981 m .56182 .51254 L .56386 .51206 L F
.684 .464 .581 r
.56809 .51218 m .57161 .50959 L .56838 .51006 L F
.986 .71 .384 r
.54181 .66536 m .54263 .66361 L .54236 .66265 L F
.54181 .66536 m .5431 .66647 L .54263 .66361 L F
.54181 .66536 m .54263 .66361 L .54236 .66265 L F
.54181 .66536 m .5431 .66647 L .54263 .66361 L F
.628 .076 0 r
.48707 .62727 m .48549 .62581 L .48527 .62604 L F
.48707 .62727 m .48853 .62763 L .48549 .62581 L F
.625 .632 .837 r
.6702 .43948 m .67379 .44185 L .67265 .4384 L F
.578 .525 .76 r
.72565 .41202 m .72717 .41572 L .72882 .41506 L F
.574 .789 .98 r
.71955 .41205 m .72119 .40965 L .7197 .41025 L F
.71955 .41205 m .72279 .4118 L .72119 .40965 L F
.654 .608 .79 r
.71955 .41205 m .72325 .41266 L .72279 .4118 L F
.76 .978 .916 r
.63728 .43665 m .6391 .43689 L .63629 .43891 L F
0 0 0 r
.63629 .43891 m .63532 .4405 L .63554 .44042 L F
.387 .125 .391 r
.19223 .67215 m .19349 .67195 L .19396 .66972 L F
.815 .528 .504 r
.19396 .66972 m .19349 .67195 L .19512 .67188 L F
.372 .545 .896 r
.38635 .63606 m .38671 .63731 L .38785 .63563 L F
.292 .435 .834 r
.38671 .63731 m .3895 .63889 L .38785 .63563 L F
.349 .707 .985 r
.74044 .41469 m .7388 .41538 L .73777 .41407 L F
.74044 .41469 m .74138 .41539 L .7388 .41538 L F
.74044 .41469 m .7388 .41538 L .73777 .41407 L F
.74044 .41469 m .74138 .41539 L .7388 .41538 L F
.467 .408 .707 r
.5336 .57509 m .53028 .57425 L .53279 .57477 L F
.977 .713 .462 r
.53265 .5767 m .53418 .57769 L .5336 .57509 L F
.53265 .5767 m .5336 .57509 L .53612 .57425 L F
0 0 .199 r
.22128 .58264 m .22115 .58638 L .22155 .58362 L F
0 0 0 r
.62504 .41004 m .62422 .40988 L .62627 .40769 L F
.62504 .41004 m .62266 .41085 L .62422 .40988 L F
.791 .923 .544 r
.6108 .47233 m .61005 .47435 L .60885 .47563 L F
.552 .249 .407 r
.56367 .53067 m .56608 .53226 L .56357 .53274 L F
.56367 .53067 m .56609 .53065 L .56608 .53226 L F
.458 0 0 r
.73101 .41981 m .73087 .41979 L .7293 .41897 L F
.235 0 .203 r
.22887 .58248 m .23158 .57955 L .22972 .58047 L F
.559 .535 .785 r
.55737 .62825 m .55877 .62445 L .55627 .62519 L F
.55737 .62825 m .55967 .62765 L .55877 .62445 L F
.877 .613 .535 r
.54681 .67157 m .54874 .67234 L .54731 .66934 L F
.694 .551 .687 r
.54731 .66934 m .54874 .67234 L .55094 .66937 L F
.97 .67 .275 r
.71126 .44733 m .71171 .44987 L .71267 .45074 L F
.397 .497 .844 r
.71126 .44733 m .71267 .45074 L .71276 .44816 L F
.933 .933 .778 r
.71267 .45074 m .71171 .44987 L .71276 .44816 L F
0 0 0 r
.74094 .4413 m .74376 .43869 L .74255 .43971 L F
.579 .547 .783 r
.74291 .43536 m .74376 .43869 L .74604 .43734 L F
.74291 .43536 m .74376 .43869 L .74604 .43734 L F
0 0 0 r
.74604 .43734 m .74255 .43971 L .74376 .43869 L F
.576 .713 .936 r
.22464 .55764 m .22745 .55752 L .22578 .55548 L F
.602 .551 .77 r
.52074 .69789 m .52123 .70204 L .52261 .69855 L F
.542 .296 .493 r
.58032 .52366 m .58042 .52158 L .5828 .5233 L F
.596 .264 .376 r
.58042 .52158 m .58313 .52165 L .5828 .5233 L F
.704 .885 .964 r
.71526 .45432 m .714 .45668 L .71623 .45529 L F
.71526 .45432 m .71296 .45561 L .714 .45668 L F
.775 .781 .857 r
.56827 .49479 m .57078 .49572 L .56949 .49089 L F
.877 .832 .799 r
.56949 .49089 m .57078 .49572 L .57202 .49059 L F
0 0 0 r
.46942 .6342 m .4675 .63611 L .46597 .63666 L F
.094 0 0 r
.47028 .63504 m .4675 .63611 L .46942 .6342 L F
.816 .602 .612 r
.4759 .58053 m .47746 .58375 L .47543 .58294 L F
.651 .537 .712 r
.47921 .58143 m .4759 .58053 L .47847 .58035 L F
.706 .671 .813 r
.48171 .58074 m .47748 .58371 L .47921 .58143 L F
.123 0 .256 r
.47748 .58371 m .47746 .58375 L .47921 .58143 L F
.651 .537 .712 r
.47921 .58143 m .47746 .58375 L .4759 .58053 L F
.916 .953 .802 r
.57566 .61817 m .57441 .62206 L .57745 .62201 L F
.539 .375 .606 r
.57441 .62206 m .57533 .62468 L .57745 .62201 L F
.778 .501 .515 r
.57134 .62404 m .57533 .62468 L .57441 .62206 L F
.939 .619 .402 r
.522 .57762 m .5204 .57697 L .51993 .57517 L F
.89 .497 .274 r
.522 .57762 m .52054 .57878 L .5204 .57697 L F
.522 .57762 m .52339 .58043 L .52054 .57878 L F
.154 .554 .928 r
.51293 .54498 m .51461 .54713 L .51125 .54552 L F
.816 .902 .492 r
.51558 .54372 m .51461 .54713 L .51293 .54498 L F
.51558 .54372 m .51467 .5468 L .51461 .54713 L F
.643 .684 .874 r
.51756 .54644 m .51461 .54713 L .51467 .5468 L F
.784 .561 .597 r
.21769 .59667 m .21508 .59773 L .21434 .59546 L F
.21769 .59667 m .21801 .59832 L .21508 .59773 L F
.518 .369 .617 r
.21995 .59534 m .21769 .59667 L .22013 .59261 L F
.558 .412 .639 r
.22041 .59772 m .21769 .59667 L .21995 .59534 L F
.22041 .59772 m .21801 .59832 L .21769 .59667 L F
.944 .786 .656 r
.66866 .43777 m .66957 .44166 L .6702 .43948 L F
.66866 .43777 m .66744 .44114 L .66957 .44166 L F
.898 .792 .735 r
.66641 .44284 m .66957 .44166 L .66744 .44114 L F
.66641 .44284 m .66781 .44433 L .66957 .44166 L F
.91 .978 .702 r
.42217 .58218 m .42181 .58469 L .42383 .5838 L F
.42217 .58218 m .42027 .58549 L .42181 .58469 L F
.407 .188 .466 r
.2405 .61865 m .23806 .62163 L .23862 .61944 L F
.029 0 .404 r
.21232 .61326 m .21323 .61302 L .21386 .60948 L F
.398 .353 .692 r
.21229 .61489 m .21323 .61302 L .21232 .61326 L F
.338 0 0 r
.20374 .5521 m .19989 .5521 L .20197 .55209 L F
.261 .723 .95 r
.22687 .54201 m .22906 .54196 L .23073 .54261 L F
.406 .791 .99 r
.22906 .54196 m .23284 .54241 L .23073 .54261 L F
.047 .187 .688 r
.64278 .43726 m .64236 .43995 L .64116 .43539 L F
.5 .836 .998 r
.64296 .43846 m .64236 .43995 L .64278 .43726 L F
.64296 .43846 m .645 .43951 L .64236 .43995 L F
.798 .714 .772 r
.56584 .49792 m .56956 .49852 L .56827 .49479 L F
.595 .365 .538 r
.49214 .62565 m .49457 .62476 L .49037 .62535 L F
.732 .214 0 r
.4648 .57448 m .46161 .57288 L .46293 .57383 L F
.553 0 0 r
.39432 .64262 m .39252 .6421 L .39018 .64063 L F
.943 .656 .466 r
.39432 .64262 m .39281 .64447 L .39252 .6421 L F
.312 0 .01 r
.39608 .64278 m .39432 .64262 L .39665 .64252 L F
.39608 .64278 m .39281 .64447 L .39432 .64262 L F
.024 0 0 r
.39834 .64241 m .39665 .64252 L .39432 .64262 L F
.096 .019 .47 r
.45835 .63705 m .45937 .63357 L .45705 .63389 L F
.459 .857 .972 r
.6689 .43541 m .67137 .43477 L .6728 .43513 L F
.278 .758 .928 r
.6728 .43513 m .67137 .43477 L .67388 .43507 L F
.562 .253 .403 r
.56945 .52742 m .57186 .52924 L .56912 .52943 L F
.56945 .52742 m .57201 .52719 L .57186 .52924 L F
.715 .978 .765 r
.54271 .67255 m .54053 .67388 L .54152 .67167 L F
.091 .643 .811 r
.61565 .4591 m .61228 .45891 L .61471 .45829 L F
.678 .92 .973 r
.61768 .45779 m .61565 .4591 L .61471 .45829 L F
.784 .738 .81 r
.51061 .54218 m .51125 .54552 L .50886 .54443 L F
.108 .241 .72 r
.51155 .54395 m .51125 .54552 L .51061 .54218 L F
.154 .554 .928 r
.51293 .54498 m .51125 .54552 L .51155 .54395 L F
.836 .997 .772 r
.57608 .45963 m .57361 .46254 L .57431 .46042 L F
.836 .989 .722 r
.57361 .46254 m .57203 .46346 L .57431 .46042 L F
0 0 .315 r
.61305 .46215 m .61204 .46569 L .61254 .46475 L F
.857 .645 .108 r
.61204 .46569 m .61198 .46673 L .61254 .46475 L F
.643 .67 .861 r
.72408 .40435 m .72054 .40298 L .72308 .40223 L F
.613 .662 .874 r
.72559 .40175 m .72408 .40435 L .72308 .40223 L F
.72559 .40175 m .72675 .40357 L .72408 .40435 L F
.715 .731 .863 r
.74743 .41454 m .74868 .4163 L .75101 .41508 L F
.468 0 0 r
.18708 .5404 m .1852 .5409 L .18905 .54119 L F
.323 0 .108 r
.37907 .59194 m .38127 .59142 L .38279 .58923 L F
.477 .043 .136 r
.38127 .59142 m .38502 .58977 L .38279 .58923 L F
0 0 0 r
.41955 .63315 m .42194 .63308 L .42286 .63302 L F
.63 .246 .297 r
.42194 .63308 m .42556 .63246 L .42286 .63302 L F
.542 .361 .586 r
.55267 .54132 m .55374 .54445 L .55127 .5451 L F
.539 .344 .565 r
.55603 .53892 m .55611 .54151 L .55267 .54132 L F
.54 .353 .576 r
.55267 .54132 m .55606 .5437 L .55374 .54445 L F
.55267 .54132 m .55611 .54151 L .55606 .5437 L F
.129 0 .117 r
.40413 .60235 m .40335 .60121 L .40628 .60107 L F
.982 .817 .602 r
.63444 .46523 m .63375 .46131 L .63226 .4648 L F
.889 .863 .808 r
.63274 .46731 m .63444 .46523 L .63226 .4648 L F
0 0 0 r
.63532 .4405 m .63366 .44161 L .63272 .44318 L F
.706 .671 .813 r
.48171 .58074 m .48307 .58364 L .47748 .58371 L F
0 .303 .698 r
.48184 .58585 m .47748 .58371 L .48307 .58364 L F
.634 .687 .882 r
.48349 .58033 m .48307 .58364 L .48171 .58074 L F
.48349 .58033 m .48594 .58332 L .48307 .58364 L F
.817 .612 .625 r
.48594 .58332 m .48184 .58585 L .48307 .58364 L F
.378 .157 .448 r
.36843 .59791 m .37069 .59497 L .3686 .59547 L F
.746 .573 .66 r
.46029 .59254 m .46073 .59564 L .45776 .59521 L F
0 0 0 r
.45776 .59521 m .459 .59485 L .46029 .59254 L F
.73 .36 .35 r
.46029 .59254 m .46295 .59498 L .46261 .59202 L F
.51 .406 .672 r
.46295 .59498 m .46073 .59564 L .46029 .59254 L F
.73 .36 .35 r
.46029 .59254 m .459 .59485 L .46295 .59498 L F
.51 .406 .672 r
.46295 .59498 m .46029 .59254 L .46261 .59202 L F
.476 .816 .999 r
.68054 .39911 m .6794 .39859 L .68216 .39813 L F
.486 .809 1 r
.68437 .39773 m .68054 .39911 L .68216 .39813 L F
.68437 .39773 m .68544 .39862 L .68054 .39911 L F
.666 .499 .648 r
.2321 .56563 m .23534 .56583 L .23491 .56247 L F
.563 .553 .801 r
.23491 .56247 m .2376 .5621 L .23624 .55993 L F
.523 .397 .649 r
.23491 .56247 m .23724 .56517 L .2376 .5621 L F
.23491 .56247 m .23534 .56583 L .23724 .56517 L F
.421 .315 .629 r
.36433 .60735 m .36617 .60342 L .36395 .60479 L F
.111 0 .279 r
.25797 .58363 m .25742 .58592 L .25608 .58657 L F
.504 .323 .569 r
.25801 .5888 m .25608 .58657 L .25742 .58592 L F
.25801 .5888 m .25575 .58943 L .25608 .58657 L F
.9 .69 .181 r
.53265 .5767 m .53314 .5804 L .53418 .57769 L F
0 0 0 r
.41616 .57421 m .41759 .57383 L .41817 .57341 L F
.41616 .57421 m .41543 .57465 L .41759 .57383 L F
.844 .995 .837 r
.53605 .69829 m .53616 .69744 L .5346 .6983 L F
.809 .981 .893 r
.53605 .69829 m .53859 .69608 L .53616 .69744 L F
.076 0 .175 r
.60695 .47679 m .60519 .48041 L .60726 .47865 L F
0 0 .206 r
.60885 .47563 m .60695 .47679 L .60726 .47865 L F
.61 .734 .934 r
.7036 .40939 m .70504 .40693 L .70252 .40761 L F
.7036 .40939 m .70611 .4087 L .70504 .40693 L F
.567 .423 .645 r
.55145 .5477 m .5493 .55077 L .54913 .54823 L F
.603 .287 .408 r
.42846 .6424 m .42448 .64511 L .42461 .64301 L F
.42846 .6424 m .42725 .64528 L .42448 .64511 L F
.527 .21 .373 r
.43058 .64391 m .42846 .6424 L .43061 .64286 L F
.43058 .64391 m .42725 .64528 L .42846 .6424 L F
.731 .966 .698 r
.6758 .40845 m .67735 .40621 L .67435 .40569 L F
.639 .343 .453 r
.67435 .40569 m .67654 .40698 L .6735 .40781 L F
.731 .966 .698 r
.6758 .40845 m .67808 .40595 L .67743 .40619 L F
.6758 .40845 m .67743 .40619 L .67728 .40631 L F
.639 .343 .453 r
.67654 .40698 m .67771 .40767 L .67568 .40774 L F
.67654 .40698 m .67568 .40774 L .6735 .40781 L F
.731 .966 .698 r
.67728 .40631 m .67743 .40619 L .67735 .40621 L F
.232 0 .273 r
.61364 .49177 m .6161 .48891 L .61515 .49038 L F
0 0 0 r
.6161 .48891 m .61881 .48616 L .61758 .48742 L F
.61515 .49038 m .6161 .48891 L .61758 .48742 L F
.704 .712 .185 r
.46374 .58528 m .46269 .58958 L .46505 .58909 L F
.73 .786 .897 r
.71912 .44355 m .71804 .44515 L .71577 .44542 L F
.814 .609 .625 r
.66781 .44433 m .67128 .4475 L .6714 .44479 L F
.66781 .44433 m .66774 .4471 L .67128 .4475 L F
.95 .857 .713 r
.66833 .44932 m .67128 .4475 L .66774 .4471 L F
.66833 .44932 m .66952 .45054 L .67128 .4475 L F
.671 .892 .535 r
.57841 .45654 m .57608 .45963 L .57717 .45782 L F
.723 .982 .776 r
.57608 .45963 m .57431 .46042 L .57717 .45782 L F
.739 .987 .896 r
.72449 .45008 m .72193 .45278 L .72491 .45061 L F
.72449 .45008 m .72133 .45234 L .72193 .45278 L F
.37 .4 .761 r
.45885 .57173 m .46034 .57208 L .46082 .57065 L F
.368 .402 .765 r
.45885 .57173 m .46161 .57288 L .46034 .57208 L F
.572 .801 .986 r
.69537 .39922 m .69133 .39854 L .69417 .39785 L F
.536 .767 .983 r
.69762 .39867 m .69537 .39922 L .69417 .39785 L F
.688 .713 .19 r
.19951 .65937 m .19839 .66354 L .20016 .66067 L F
.744 .583 .676 r
.20016 .66067 m .19839 .66354 L .20009 .66346 L F
.318 .807 .824 r
.20362 .65855 m .19951 .65937 L .20016 .66067 L F
.767 .708 .17 r
.61062 .42799 m .61045 .43023 L .61098 .42606 L F
.379 0 0 r
.44385 .56562 m .44658 .56557 L .44798 .56404 L F
0 0 0 r
.44798 .56404 m .44873 .56448 L .45006 .56351 L F
0 .332 .779 r
.45096 .56344 m .45006 .56351 L .44873 .56448 L F
0 0 0 r
.45006 .56351 m .44873 .56448 L .45096 .56344 L F
.667 .134 0 r
.44689 .56174 m .45096 .56344 L .44873 .56448 L F
.531 .081 .126 r
.45096 .56344 m .45047 .56362 L .44915 .56428 L F
.45096 .56344 m .44915 .56428 L .44907 .56432 L F
0 0 0 r
.44798 .56404 m .44663 .56552 L .44873 .56448 L F
.44663 .56552 m .44658 .56557 L .44873 .56448 L F
.622 .605 .813 r
.44873 .56448 m .44658 .56557 L .44479 .56199 L F
.543 .195 .329 r
.44116 .56599 m .44385 .56562 L .44463 .56351 L F
.58 .584 .821 r
.44416 .5644 m .44658 .56557 L .44385 .56562 L F
.44479 .56199 m .44602 .56445 L .44416 .5644 L F
.44602 .56445 m .44658 .56557 L .44416 .5644 L F
.193 0 0 r
.44873 .56448 m .44472 .5647 L .44658 .56557 L F
.609 .798 .972 r
.44165 .56552 m .44385 .56562 L .44116 .56599 L F
.699 .723 .869 r
.44167 .56538 m .44168 .56552 L .44385 .56562 L F
.609 .798 .972 r
.44185 .56421 m .44127 .56572 L .43973 .56313 L F
.44127 .56572 m .4411 .56586 L .43973 .56313 L F
.44259 .56459 m .44165 .56552 L .44185 .56421 L F
.44165 .56552 m .44116 .56599 L .44185 .56421 L F
.699 .723 .869 r
.44025 .56522 m .44167 .56538 L .44259 .56459 L F
.44167 .56538 m .44385 .56562 L .44259 .56459 L F
.609 .798 .972 r
.44127 .56572 m .44116 .56599 L .4411 .56586 L F
.44259 .56459 m .44385 .56562 L .44165 .56552 L F
.699 .723 .869 r
.44168 .56552 m .44182 .56798 L .44385 .56562 L F
.44025 .56522 m .44138 .5672 L .44167 .56538 L F
.44138 .5672 m .44182 .56798 L .44167 .56538 L F
.659 .658 .838 r
.44385 .56562 m .44182 .56798 L .44428 .56728 L F
.601 .658 .878 r
.44428 .56728 m .44658 .56557 L .44385 .56562 L F
.58 .584 .821 r
.44479 .56199 m .44385 .56562 L .44259 .56459 L F
.37 .76 .988 r
.44385 .56562 m .44472 .5647 L .44259 .56459 L F
.44385 .56562 m .44658 .56557 L .44472 .5647 L F
.6 .238 .326 r
.44516 .56476 m .44337 .56747 L .44116 .56572 L F
.193 0 0 r
.44754 .56476 m .44561 .56476 L .44472 .5647 L F
.457 .1 .27 r
.44472 .5647 m .44722 .56487 L .44565 .56465 L F
.6 .238 .326 r
.44565 .56465 m .44556 .56476 L .44516 .56476 L F
.44556 .56476 m .44337 .56747 L .44516 .56476 L F
.193 0 0 r
.44825 .56451 m .44754 .56476 L .44472 .5647 L F
.44754 .56476 m .44722 .56487 L .44561 .56476 L F
.44873 .56448 m .44859 .56452 L .44825 .56451 L F
.44859 .56452 m .44722 .56487 L .44825 .56451 L F
.622 .605 .813 r
.44804 .56346 m .44479 .56199 L .44689 .56174 L F
.44873 .56448 m .44696 .56337 L .44804 .56346 L F
.44696 .56337 m .44479 .56199 L .44804 .56346 L F
.531 .081 .126 r
.45035 .56368 m .44722 .56487 L .44873 .56448 L F
.45047 .56362 m .44722 .56487 L .45035 .56368 L F
.44907 .56432 m .44915 .56428 L .44873 .56448 L F
.643 .68 .87 r
.44763 .56809 m .44873 .56448 L .44658 .56557 L F
.44763 .56809 m .45015 .56762 L .44873 .56448 L F
.563 .581 .83 r
.45015 .56762 m .45096 .56344 L .44873 .56448 L F
.531 .081 .126 r
.45036 .56367 m .44961 .56518 L .44722 .56487 L F
.45096 .56344 m .45075 .5637 L .45036 .56367 L F
.45075 .5637 m .44961 .56518 L .45036 .56367 L F
.563 .581 .83 r
.45015 .56762 m .45306 .56711 L .45096 .56344 L F
.357 0 .021 r
.45186 .56481 m .44961 .56518 L .45096 .56344 L F
.667 .134 0 r
.44689 .56174 m .45075 .56391 L .45096 .56344 L F
.366 .526 .883 r
.44804 .55952 m .45048 .56348 L .44689 .56174 L F
.45048 .56348 m .45075 .56391 L .45024 .56362 L F
.45048 .56348 m .45024 .56362 L .44689 .56174 L F
.175 0 0 r
.48527 .62604 m .48241 .62582 L .48098 .62628 L F
0 0 .092 r
.21581 .58644 m .21591 .58256 L .21502 .58301 L F
.21581 .58644 m .21598 .58503 L .21591 .58256 L F
.968 .804 .376 r
.21581 .58644 m .2146 .58697 L .21598 .58503 L F
.21581 .58644 m .21544 .58903 L .2146 .58697 L F
.802 .457 .404 r
.5128 .55263 m .50984 .55276 L .50921 .55077 L F
.973 .834 .644 r
.5128 .55263 m .51052 .55517 L .50984 .55276 L F
.5128 .55263 m .51163 .55658 L .51052 .55517 L F
.622 .215 .251 r
.56417 .51425 m .56386 .51206 L .56182 .51254 L F
.56417 .51425 m .56573 .51244 L .56386 .51206 L F
.547 .608 .865 r
.56398 .63328 m .56468 .62921 L .56292 .62937 L F
.56398 .63328 m .56552 .63413 L .56468 .62921 L F
.531 0 0 r
.41241 .64368 m .41092 .6445 L .40952 .64432 L F
.326 0 0 r
.41497 .64427 m .41092 .6445 L .41241 .64368 L F
.746 .966 .686 r
.61881 .48616 m .6213 .48332 L .61978 .48428 L F
.713 .908 .546 r
.61758 .48742 m .61881 .48616 L .61978 .48428 L F
.108 0 0 r
.19755 .6871 m .19557 .68894 L .19548 .68882 L F
0 0 0 r
.19991 .68411 m .19884 .68622 L .19755 .6871 L F
.644 .389 .518 r
.19884 .68622 m .19557 .68894 L .19755 .6871 L F
.728 .85 .939 r
.72325 .41266 m .72565 .41202 L .72492 .41021 L F
.625 .793 .963 r
.72492 .41021 m .72565 .41202 L .72833 .41106 L F
.62 .662 .87 r
.72565 .41202 m .72939 .4128 L .72833 .41106 L F
.578 .525 .76 r
.72565 .41202 m .72882 .41506 L .72939 .4128 L F
.053 0 0 r
.18905 .54119 m .19123 .54093 L .19298 .54032 L F
.226 .744 .85 r
.19123 .54093 m .19516 .54068 L .19298 .54032 L F
.806 .831 .87 r
.6378 .44977 m .6393 .45146 L .64093 .4497 L F
.906 .933 .819 r
.62555 .47618 m .62717 .47423 L .62626 .4731 L F
.199 0 .24 r
.60637 .4984 m .60829 .49741 L .60585 .50019 L F
.942 .948 .624 r
.75119 .42691 m .75373 .42749 L .75261 .42527 L F
.609 .594 .811 r
.75491 .42269 m .75643 .42701 L .75373 .42749 L F
.572 .888 .99 r
.74607 .42077 m .74767 .41924 L .74835 .41998 L F
.643 .393 .525 r
.74607 .42077 m .74903 .42305 L .74767 .41924 L F
.74607 .42077 m .74646 .42369 L .74903 .42305 L F
0 0 0 r
.61095 .49447 m .61364 .49177 L .61281 .49345 L F
.61281 .49345 m .61364 .49177 L .61515 .49038 L F
.689 .851 .435 r
.72196 .43935 m .72038 .44211 L .72144 .43996 L F
.737 .933 .596 r
.71912 .44355 m .72144 .43996 L .72038 .44211 L F
.178 0 0 r
.17435 .5411 m .17707 .54139 L .17446 .54107 L F
.579 .918 .967 r
.19022 .64155 m .18701 .64215 L .18921 .64215 L F
.242 0 0 r
.18921 .64215 m .19261 .64109 L .19022 .64155 L F
.915 .714 .617 r
.63279 .45795 m .63521 .45622 L .63396 .45546 L F
.63279 .45795 m .63465 .45925 L .63521 .45622 L F
.811 .987 .722 r
.62213 .4812 m .6213 .48332 L .62378 .48023 L F
.807 .977 .687 r
.61978 .48428 m .6213 .48332 L .62213 .4812 L F
.736 .547 .637 r
.47748 .58371 m .47715 .58614 L .47746 .58375 L F
.47748 .58371 m .4802 .58513 L .47715 .58614 L F
0 .303 .698 r
.48184 .58585 m .4802 .58513 L .47748 .58371 L F
.632 .884 .547 r
.58086 .45361 m .57841 .45654 L .57964 .45478 L F
.624 .873 .524 r
.57841 .45654 m .57717 .45782 L .57964 .45478 L F
.364 .215 .541 r
.26192 .56276 m .26028 .56558 L .2601 .56371 L F
.519 .374 .624 r
.43168 .63348 m .43422 .63569 L .43539 .63368 L F
.336 0 .105 r
.43539 .63368 m .43632 .6351 L .43759 .63298 L F
.43539 .63368 m .43422 .63569 L .43632 .6351 L F
.54 .167 .282 r
.44357 .63931 m .44749 .63654 L .44565 .63754 L F
.423 .83 .976 r
.45847 .56523 m .45752 .5662 L .45601 .56508 L F
.45847 .56523 m .4597 .56574 L .45752 .5662 L F
.53 .466 .729 r
.23377 .57123 m .23528 .56856 L .23323 .56906 L F
.23377 .57123 m .23587 .57058 L .23528 .56856 L F
.521 .392 .645 r
.23377 .57123 m .23651 .57181 L .23587 .57058 L F
.23377 .57123 m .23392 .57448 L .23651 .57181 L F
.8 .607 .641 r
.47746 .58375 m .47347 .58604 L .47543 .58294 L F
.47746 .58375 m .47715 .58614 L .47347 .58604 L F
.589 .237 .339 r
.4802 .58513 m .47975 .58671 L .47715 .58614 L F
.3 0 .237 r
.48184 .58585 m .47975 .58671 L .4802 .58513 L F
.761 .645 .733 r
.2275 .58642 m .22532 .58933 L .22896 .58945 L F
.628 .364 .499 r
.22515 .59162 m .22896 .58945 L .22532 .58933 L F
.22515 .59162 m .22831 .59188 L .22896 .58945 L F
.721 .628 .754 r
.2275 .58642 m .22896 .58945 L .23062 .58676 L F
.56 .298 .476 r
.22896 .58945 m .22831 .59188 L .23064 .5915 L F
.681 .575 .729 r
.22896 .58945 m .23155 .58955 L .23062 .58676 L F
.641 .305 .386 r
.22896 .58945 m .23064 .5915 L .23155 .58955 L F
.457 0 0 r
.63639 .43093 m .63738 .42992 L .6337 .43009 L F
.959 .894 .512 r
.63672 .43164 m .63738 .42992 L .63639 .43093 L F
.664 .496 .648 r
.57161 .50959 m .57423 .50943 L .57399 .50683 L F
.619 .474 .663 r
.57399 .50683 m .57657 .50639 L .57613 .50342 L F
.501 .376 .641 r
.57399 .50683 m .57649 .5087 L .57657 .50639 L F
.57399 .50683 m .57423 .50943 L .57649 .5087 L F
.462 0 0 r
.19516 .54068 m .19729 .54117 L .19912 .5403 L F
.261 0 0 r
.19912 .5403 m .19729 .54117 L .20109 .54054 L F
.677 .687 .852 r
.56732 .63363 m .56868 .63 L .56552 .63413 L F
.646 .835 .973 r
.6921 .45464 m .68763 .45478 L .69113 .45356 L F
.609 .783 .965 r
.69368 .45266 m .6921 .45464 L .69113 .45356 L F
.69368 .45266 m .69468 .4539 L .6921 .45464 L F
.961 .631 .324 r
.54197 .68683 m .5433 .68766 L .54129 .68423 L F
.871 .68 .642 r
.54681 .67157 m .54823 .67489 L .54874 .67234 L F
.108 .285 .762 r
.21289 .59202 m .21434 .59546 L .21509 .59391 L F
0 0 .519 r
.21434 .59546 m .21559 .59642 L .21509 .59391 L F
.21434 .59546 m .21508 .59773 L .21559 .59642 L F
.417 .653 .956 r
.75601 .40871 m .75731 .40709 L .75502 .40711 L F
.287 .462 .859 r
.75781 .40894 m .75731 .40709 L .75601 .40871 L F
.465 .464 .772 r
.47232 .56976 m .47002 .57315 L .46944 .56828 L F
.645 .634 .825 r
.47232 .56976 m .47064 .57388 L .47002 .57315 L F
.116 0 .223 r
.20239 .67949 m .20214 .67984 L .20086 .68048 L F
.839 .859 .407 r
.20086 .68048 m .19991 .68411 L .19931 .68126 L F
.20086 .68048 m .19984 .683 L .19991 .68411 L F
.116 0 .223 r
.20214 .67984 m .19984 .683 L .20086 .68048 L F
.839 .859 .407 r
.20086 .68048 m .19931 .68126 L .1992 .68073 L F
.091 0 .049 r
.20052 .68551 m .19991 .68411 L .19984 .683 L F
.20052 .68551 m .19884 .68622 L .19991 .68411 L F
.753 .736 .836 r
.66717 .45533 m .66788 .4591 L .67058 .4561 L F
.83 .903 .89 r
.69479 .46294 m .6988 .46179 L .69835 .46099 L F
.777 .982 .906 r
.69835 .46099 m .6988 .46179 L .70197 .45937 L F
.28 .439 .841 r
.75707 .40239 m .76005 .40393 L .7587 .40554 L F
.247 .388 .808 r
.76005 .40393 m .76122 .40692 L .7587 .40554 L F
.27 0 .134 r
.62911 .40621 m .62807 .40734 L .62627 .40769 L F
.121 0 0 r
.62725 .40902 m .62627 .40769 L .62807 .40734 L F
.62725 .40902 m .62504 .41004 L .62627 .40769 L F
.642 .7 .888 r
.71216 .40898 m .71634 .41151 L .71449 .40817 L F
.613 .73 .929 r
.71634 .41151 m .71717 .40778 L .71449 .40817 L F
.71634 .41151 m .7197 .41025 L .71717 .40778 L F
.762 .562 .627 r
.22041 .59772 m .22371 .59812 L .2235 .59549 L F
.39 .233 .544 r
.22371 .59812 m .22587 .59484 L .2235 .59549 L F
.598 .438 .635 r
.39832 .62117 m .39581 .62404 L .39564 .62161 L F
.384 .136 .41 r
.59489 .4917 m .59285 .4926 L .59234 .49451 L F
.494 .903 .902 r
.17315 .55828 m .17114 .55919 L .17229 .55922 L F
.293 0 .074 r
.17315 .55828 m .17248 .55874 L .17114 .55919 L F
.33 .813 .864 r
.17229 .55922 m .17114 .55919 L .16977 .55964 L F
.293 0 .074 r
.17248 .55874 m .1696 .56073 L .17114 .55919 L F
.33 .813 .864 r
.16977 .55964 m .17114 .55919 L .16908 .55976 L F
.494 .903 .902 r
.17315 .55828 m .17229 .55922 L .17432 .55855 L F
.861 .726 .206 r
.51283 .55894 m .51236 .56101 L .5115 .55886 L F
.51283 .55894 m .51259 .56277 L .51236 .56101 L F
.494 .109 .238 r
.40975 .60291 m .40959 .60396 L .41262 .60312 L F
.7 .914 .968 r
.68413 .46488 m .68514 .46575 L .68756 .46439 L F
.464 .769 .996 r
.75188 .39977 m .74971 .39922 L .7509 .40041 L F
.74971 .39922 m .75188 .39977 L .7509 .40041 L F
.754 .815 .901 r
.73177 .40034 m .7327 .40309 L .72918 .40242 L F
.795 .784 .843 r
.72918 .40242 m .7327 .40309 L .73057 .40399 L F
.686 .778 .92 r
.73543 .40061 m .7327 .40309 L .73177 .40034 L F
0 0 0 r
.58197 .45107 m .58086 .45361 L .58195 .45179 L F
.679 .903 .556 r
.58086 .45361 m .57964 .45478 L .58195 .45179 L F
.257 0 .304 r
.58072 .45353 m .58194 .45205 L .58195 .45179 L F
.58194 .45205 m .58344 .45024 L .58195 .45179 L F
0 0 0 r
.58241 .45006 m .58197 .45107 L .58195 .45179 L F
.532 .277 .475 r
.5778 .52402 m .57971 .52536 L .57707 .5269 L F
.5778 .52402 m .58032 .52366 L .57971 .52536 L F
.59 .438 .643 r
.54742 .55616 m .54455 .55943 L .54471 .55691 L F
.672 .775 .928 r
.57131 .63429 m .56732 .63363 L .56939 .63942 L F
.57131 .63429 m .56964 .63302 L .56732 .63363 L F
.574 .852 .996 r
.69021 .39747 m .68867 .39924 L .68775 .39825 L F
.69021 .39747 m .69133 .39854 L .68867 .39924 L F
0 0 0 r
.4978 .57765 m .49761 .58007 L .49631 .57968 L F
0 .388 .832 r
.49828 .5774 m .50059 .57847 L .4978 .57765 L F
.306 0 0 r
.50059 .57847 m .49761 .58007 L .49774 .57843 L F
.49887 .57797 m .49774 .57843 L .4978 .57765 L F
.50059 .57847 m .49774 .57843 L .49887 .57797 L F
0 0 0 r
.4978 .57765 m .49631 .57968 L .49828 .5774 L F
.822 .826 .852 r
.49828 .5774 m .49718 .57867 L .49432 .57752 L F
.49718 .57867 m .49631 .57968 L .49588 .57921 L F
.49718 .57867 m .49588 .57921 L .49432 .57752 L F
.065 .11 .598 r
.26028 .56558 m .2619 .56787 L .26072 .56886 L F
.533 .539 .807 r
.2619 .56787 m .26105 .57155 L .26072 .56886 L F
.923 .929 .795 r
.5214 .52375 m .52251 .52455 L .52033 .52762 L F
.89 .939 .84 r
.52488 .52162 m .52251 .52455 L .5214 .52375 L F
.75 .9 .945 r
.69004 .46435 m .69116 .4654 L .69304 .46397 L F
.527 .333 .561 r
.67808 .40595 m .67771 .40767 L .67735 .40621 L F
.67808 .40595 m .67843 .40863 L .67771 .40767 L F
.67808 .40595 m .68082 .4051 L .67843 .40863 L F
.516 .362 .611 r
.23323 .56906 m .23534 .56583 L .2321 .56563 L F
.427 0 0 r
.64116 .43539 m .64416 .43693 L .64278 .43726 L F
.182 .261 .71 r
.64416 .43693 m .64651 .43636 L .64278 .43726 L F
.64416 .43693 m .64594 .43777 L .64651 .43636 L F
.036 .172 .677 r
.2142 .58062 m .21591 .58256 L .21505 .57906 L F
.135 .2 .666 r
.21502 .58301 m .21591 .58256 L .2142 .58062 L F
.667 .474 .615 r
.48153 .57763 m .48171 .58074 L .47847 .58035 L F
.447 .307 .597 r
.48349 .58033 m .48153 .57763 L .48389 .5771 L F
.48349 .58033 m .48171 .58074 L .48153 .57763 L F
.162 0 0 r
.39862 .58328 m .40092 .58266 L .40216 .58122 L F
.046 0 0 r
.40216 .58122 m .40295 .58192 L .40349 .58124 L F
.40216 .58122 m .40092 .58266 L .40295 .58192 L F
.043 0 0 r
.40216 .58122 m .40349 .58124 L .4047 .58075 L F
.94 .592 .332 r
.68464 .45531 m .68624 .45642 L .68516 .45772 L F
.988 .847 .473 r
.68624 .45642 m .6859 .45862 L .68516 .45772 L F
.799 .829 .875 r
.68763 .45478 m .68624 .45642 L .68464 .45531 L F
.442 .572 .889 r
.64915 .41471 m .64555 .41205 L .64667 .4128 L F
.862 .989 .838 r
.65058 .4117 m .64915 .41471 L .64667 .4128 L F
.65058 .4117 m .65161 .41195 L .64915 .41471 L F
.542 .357 .58 r
.65161 .41195 m .65219 .41443 L .64915 .41471 L F
.975 .731 .505 r
.39511 .60923 m .39645 .61242 L .39326 .60959 L F
.874 .718 .685 r
.67137 .43477 m .67265 .4384 L .67388 .43507 L F
.989 .755 .371 r
.65185 .43385 m .65277 .43476 L .65277 .4328 L F
.879 .896 .475 r
.65185 .43385 m .65277 .4328 L .65283 .43149 L F
.434 .315 .618 r
.5491 .55317 m .54742 .55616 L .54748 .55391 L F
.159 0 .208 r
.60062 .50591 m .60127 .50427 L .60319 .50302 L F
.728 .85 .939 r
.72325 .41266 m .72492 .41021 L .72279 .4118 L F
.643 .306 .386 r
.502 .71777 m .50011 .71794 L .49947 .71911 L F
.653 .704 .884 r
.49947 .71911 m .50317 .72032 L .502 .71777 L F
.703 .524 .643 r
.50317 .72032 m .50526 .71837 L .502 .71777 L F
.905 .77 .702 r
.21835 .56729 m .22256 .56628 L .21906 .56475 L F
.21835 .56729 m .22051 .56865 L .22256 .56628 L F
.5 .186 .366 r
.16908 .55976 m .16592 .56213 L .16672 .56065 L F
.792 .96 .92 r
.6302 .46802 m .63274 .46731 L .63226 .4648 L F
.575 .941 .847 r
.73697 .44208 m .73533 .44363 L .73801 .4426 L F
.73697 .44208 m .73474 .44346 L .73533 .44363 L F
.14 0 .273 r
.23158 .57955 m .23354 .57675 L .2319 .57757 L F
.516 .362 .611 r
.23323 .56906 m .23528 .56856 L .23534 .56583 L F
.367 0 0 r
.21952 .55271 m .2158 .55263 L .21743 .55345 L F
.636 .715 .905 r
.70362 .39885 m .70722 .39987 L .70473 .40071 L F
.652 .175 .108 r
.44918 .6402 m .45105 .64185 L .44901 .64112 L F
.34 .251 .607 r
.45083 .63911 m .45105 .64185 L .44918 .6402 L F
.45083 .63911 m .45105 .64185 L .44918 .6402 L F
.263 0 0 r
.40057 .64236 m .39665 .64252 L .39834 .64241 L F
.478 0 0 r
.40057 .64236 m .39936 .6437 L .39665 .64252 L F
.737 .309 .234 r
.40254 .64284 m .39936 .6437 L .40057 .64236 L F
.291 0 0 r
.37537 .63217 m .37357 .63206 L .37345 .63286 L F
.682 .73 .887 r
.48655 .57345 m .48276 .57194 L .48471 .57138 L F
.135 0 0 r
.48471 .57138 m .48907 .57199 L .48655 .57345 L F
.703 .542 .666 r
.48925 .5726 m .4884 .57238 L .48907 .57199 L F
.315 .373 .764 r
.49156 .57295 m .48907 .57199 L .48942 .57266 L F
0 .532 .828 r
.48951 .57264 m .49156 .57295 L .48962 .57269 L F
.48932 .57262 m .48962 .57269 L .48942 .57266 L F
.315 .373 .764 r
.49156 .57295 m .48988 .57483 L .48925 .5726 L F
.49156 .57295 m .48925 .5726 L .48907 .57199 L F
0 .532 .828 r
.48794 .57189 m .48942 .57266 L .48907 .57199 L F
.48794 .57189 m .49156 .57295 L .48951 .57264 L F
.48794 .57189 m .48962 .57269 L .48932 .57262 L F
.703 .542 .666 r
.48988 .57483 m .48655 .57345 L .4884 .57238 L F
.48988 .57483 m .4884 .57238 L .48925 .5726 L F
.48988 .57483 m .48752 .57576 L .48655 .57345 L F
.533 0 0 r
.39925 .61897 m .40281 .61965 L .40211 .61894 L F
.818 .997 .776 r
.67356 .41917 m .67539 .41829 L .67616 .41726 L F
.9 .846 .39 r
.41527 .60059 m .41436 .60255 L .41484 .60052 L F
.69 .965 .937 r
.75374 .43158 m .75733 .42994 L .75643 .42947 L F
0 0 0 r
.75961 .42678 m .75733 .42994 L .75868 .42833 L F
.689 .964 .938 r
.75643 .42947 m .75733 .42994 L .75868 .42833 L F
.793 .977 .907 r
.7258 .4484 m .72491 .45061 L .72626 .44926 L F
.826 .999 .791 r
.72449 .45008 m .72491 .45061 L .7258 .4484 L F
.591 .838 .991 r
.45725 .63927 m .45695 .63787 L .45835 .63705 L F
.096 .019 .47 r
.45835 .63705 m .45912 .63661 L .45937 .63357 L F
.494 .008 .031 r
.45695 .63787 m .45912 .63661 L .45835 .63705 L F
.424 0 0 r
.64555 .41205 m .6426 .41186 L .64277 .40892 L F
.323 .326 .708 r
.64667 .4128 m .64555 .41205 L .64746 .41053 L F
.957 .948 .7 r
.62312 .47924 m .62378 .48023 L .62555 .47618 L F
.967 .936 .664 r
.62213 .4812 m .62378 .48023 L .62312 .47924 L F
.729 .869 .452 r
.61365 .4087 m .61179 .41208 L .61268 .40999 L F
0 0 0 r
.61365 .4087 m .61547 .40755 L .61648 .40607 L F
.61365 .4087 m .61268 .40999 L .61547 .40755 L F
.425 .154 .397 r
.26017 .58312 m .25742 .58592 L .25797 .58363 L F
.549 .879 .991 r
.52954 .69884 m .53193 .69813 L .53064 .69747 L F
.53064 .69747 m .53193 .69813 L .52954 .69884 L F
.535 .283 .481 r
.58778 .51589 m .59044 .5176 L .58769 .51773 L F
.58778 .51589 m .59113 .51531 L .59044 .5176 L F
.517 .033 .047 r
.40649 .64255 m .4049 .64409 L .40254 .64284 L F
.587 .127 .128 r
.40952 .64432 m .4049 .64409 L .40649 .64255 L F
.551 .424 .661 r
.57657 .50639 m .57883 .50275 L .57613 .50342 L F
.345 0 0 r
.56757 .62398 m .57134 .62404 L .56875 .62348 L F
.495 .274 .508 r
.43845 .59235 m .4406 .59238 L .44073 .5897 L F
.104 0 .057 r
.43986 .59054 m .44073 .5897 L .44057 .59102 L F
0 0 .306 r
.44073 .5897 m .44145 .59021 L .44347 .58982 L F
.44145 .59021 m .4419 .59053 L .44295 .59006 L F
.44145 .59021 m .44295 .59006 L .44347 .58982 L F
.788 .757 .825 r
.43865 .58807 m .44013 .59035 L .44202 .58795 L F
.44013 .59035 m .44057 .59102 L .44093 .59027 L F
0 0 .306 r
.44073 .5897 m .4406 .59238 L .4419 .59053 L F
0 0 0 r
.44057 .59102 m .44073 .5897 L .44202 .58795 L F
.788 .757 .825 r
.44013 .59035 m .44093 .59027 L .44202 .58795 L F
.676 .69 .856 r
.66866 .43777 m .6702 .43948 L .67265 .4384 L F
0 0 .355 r
.40089 .62652 m .39937 .62864 L .39882 .62688 L F
.40089 .62652 m .40079 .63019 L .39937 .62864 L F
.744 .422 .437 r
.62039 .42404 m .61674 .42555 L .61895 .42227 L F
.62039 .42404 m .61991 .42611 L .61674 .42555 L F
.584 .651 .882 r
.62177 .4203 m .62039 .42404 L .61895 .42227 L F
.62177 .4203 m .62302 .42344 L .62039 .42404 L F
0 0 .156 r
.62179 .42441 m .62039 .42404 L .62302 .42344 L F
.62179 .42441 m .61991 .42611 L .62039 .42404 L F
.797 .691 .748 r
.68082 .4051 m .68184 .40908 L .67843 .40863 L F
.719 .646 .775 r
.68082 .4051 m .6844 .40739 L .68184 .40908 L F
.523 .283 .493 r
.6844 .40739 m .68455 .40864 L .68184 .40908 L F
.634 .692 .886 r
.72198 .39956 m .72054 .40298 L .71945 .40046 L F
.72198 .39956 m .72308 .40223 L .72054 .40298 L F
.456 .309 .592 r
.24668 .60921 m .24462 .6074 L .2465 .60678 L F
.24668 .60921 m .24466 .60983 L .24462 .6074 L F
.364 .215 .541 r
.26192 .56276 m .26192 .565 L .26028 .56558 L F
.358 .199 .525 r
.26192 .565 m .2619 .56787 L .26028 .56558 L F
.653 .159 .065 r
.40395 .63272 m .40631 .63383 L .40764 .63331 L F
.591 .079 .002 r
.40631 .63383 m .4096 .63405 L .40764 .63331 L F
.746 .875 .939 r
.72939 .4128 m .73051 .41045 L .72833 .41106 L F
.72939 .4128 m .7315 .41176 L .73051 .41045 L F
.64 .473 .641 r
.72882 .41506 m .7315 .41176 L .72939 .4128 L F
.374 .817 .95 r
.71492 .44478 m .71596 .44499 L .71577 .44542 L F
.551 .93 .83 r
.71577 .44542 m .71907 .44316 L .71912 .44355 L F
.716 .972 .929 r
.64116 .43539 m .63728 .43665 L .63953 .43379 L F
.899 .805 .747 r
.64123 .43312 m .64116 .43539 L .63953 .43379 L F
.659 .598 .775 r
.63969 .43508 m .64156 .43261 L .63953 .43379 L F
.716 .972 .929 r
.64116 .43539 m .6391 .43689 L .63805 .43675 L F
.64116 .43539 m .63805 .43675 L .63857 .43623 L F
.659 .598 .775 r
.63984 .43623 m .64103 .43372 L .63969 .43508 L F
.64103 .43372 m .64156 .43261 L .63969 .43508 L F
.716 .972 .929 r
.63857 .43623 m .63805 .43675 L .63728 .43665 L F
.575 .909 .676 r
.40729 .60002 m .40628 .60107 L .41014 .5981 L F
0 0 0 r
.40966 .59917 m .41014 .5981 L .41095 .59767 L F
.40966 .59917 m .40729 .60002 L .41014 .5981 L F
0 0 .423 r
.19557 .68894 m .19585 .68995 L .19548 .68882 L F
.342 .241 .593 r
.19585 .68995 m .19714 .6922 L .19547 .69287 L F
.328 .813 .838 r
.49081 .58008 m .49023 .57998 L .48767 .58076 L F
.896 .967 .649 r
.49174 .57675 m .49023 .57998 L .49081 .58008 L F
.957 .948 .7 r
.62312 .47924 m .62555 .47618 L .6248 .47618 L F
.906 .933 .819 r
.62555 .47618 m .62626 .4731 L .6248 .47618 L F
.584 .061 0 r
.44749 .63654 m .45027 .63797 L .45199 .63708 L F
.99 .874 .615 r
.45027 .63797 m .45083 .63911 L .45199 .63708 L F
0 0 0 r
.58241 .45006 m .58195 .45179 L .58246 .44987 L F
.89 .939 .84 r
.52488 .52162 m .5214 .52375 L .5237 .52099 L F
.85 .98 .864 r
.52738 .51899 m .52488 .52162 L .52534 .51939 L F
.809 .952 .912 r
.52534 .51939 m .52488 .52162 L .5237 .52099 L F
.514 .478 .754 r
.23062 .58676 m .23155 .58955 L .23352 .58881 L F
.599 .368 .537 r
.23064 .5915 m .23352 .58881 L .23155 .58955 L F
.684 .464 .581 r
.56809 .51218 m .57147 .51207 L .57161 .50959 L F
.627 .343 .468 r
.57388 .51161 m .57161 .50959 L .57147 .51207 L F
.57388 .51161 m .57423 .50943 L .57161 .50959 L F
.416 .066 .261 r
.47699 .62803 m .48024 .62736 L .48012 .62786 L F
.717 .963 .701 r
.48098 .62628 m .48012 .62786 L .48024 .62736 L F
0 0 0 r
.6129 .46392 m .61305 .46215 L .61254 .46475 L F
.33 .377 .76 r
.61228 .45891 m .61305 .46215 L .61518 .461 L F
0 0 .101 r
.61518 .461 m .61305 .46215 L .6129 .46392 L F
.788 .674 .125 r
.66804 .42727 m .66826 .4269 L .66953 .42571 L F
.66804 .42727 m .6681 .42939 L .66826 .4269 L F
.346 .738 .985 r
.23284 .54241 m .23515 .54227 L .23683 .54325 L F
.486 .768 .993 r
.23711 .54164 m .23683 .54325 L .23515 .54227 L F
.23711 .54164 m .23908 .54287 L .23683 .54325 L F
.36 .144 .444 r
.24916 .60058 m .24855 .60403 L .24662 .60423 L F
.442 .284 .571 r
.24855 .60403 m .2465 .60678 L .24662 .60423 L F
.321 .143 .477 r
.20123 .67748 m .20086 .68048 L .1992 .68073 L F
.623 .156 .124 r
.4096 .63405 m .41202 .6356 L .4137 .6342 L F
.142 0 0 r
.4137 .6342 m .41451 .63497 L .41592 .6341 L F
.4137 .6342 m .41202 .6356 L .41451 .63497 L F
.412 .195 .472 r
.2427 .61302 m .24235 .61539 L .24035 .61588 L F
.353 .226 .565 r
.24214 .61789 m .24035 .61588 L .24235 .61539 L F
.24214 .61789 m .2405 .61865 L .24035 .61588 L F
.99 .729 .415 r
.54181 .66536 m .5431 .66647 L .54292 .66799 L F
.54292 .66799 m .5431 .66647 L .54181 .66536 L F
.843 .643 .633 r
.60213 .44389 m .60367 .44713 L .60367 .44462 L F
0 0 0 r
.43628 .5758 m .43428 .57981 L .4348 .57798 L F
.75961 .42678 m .75899 .42566 L .75643 .42701 L F
.75961 .42678 m .75868 .42833 L .75899 .42566 L F
.603 .49 .697 r
.7621 .42372 m .75961 .42678 L .75899 .42566 L F
.7621 .42372 m .76217 .42649 L .75961 .42678 L F
.607 .259 .353 r
.76217 .42649 m .75899 .42566 L .75961 .42678 L F
.905 .798 .731 r
.75293 .40212 m .75297 .40605 L .75286 .40424 L F
.136 .114 .568 r
.75286 .40424 m .75289 .40401 L .75293 .40212 L F
.945 .615 .373 r
.75295 .40117 m .75445 .40313 L .75293 .40212 L F
.905 .798 .731 r
.75293 .40212 m .75445 .40313 L .75297 .40605 L F
.449 .641 .939 r
.75188 .39977 m .75707 .40239 L .75445 .40313 L F
.136 .114 .568 r
.75289 .40401 m .75337 .40068 L .75293 .40212 L F
.945 .615 .373 r
.75188 .39977 m .75295 .40117 L .75293 .40212 L F
.797 .573 .597 r
.58337 .61888 m .58312 .62165 L .58664 .62196 L F
.311 .644 .967 r
.24856 .5465 m .25053 .54663 L .25011 .54792 L F
.329 .663 .974 r
.25053 .54663 m .25205 .54798 L .25011 .54792 L F
.53 .187 .33 r
.59144 .49582 m .5897 .4946 L .5895 .49634 L F
.59144 .49582 m .59234 .49451 L .5897 .4946 L F
.747 .956 .941 r
.18701 .64215 m .18477 .64375 L .18291 .64408 L F
.18701 .64215 m .18676 .64236 L .18477 .64375 L F
0 0 0 r
.48024 .62736 m .47946 .62789 L .48098 .62628 L F
.876 .513 .358 r
.47946 .62789 m .48124 .62892 L .48098 .62628 L F
.48124 .62892 m .48259 .6297 L .4823 .62909 L F
.48124 .62892 m .4823 .62909 L .48098 .62628 L F
.213 .592 .947 r
.48309 .62977 m .4844 .62942 L .48217 .62945 L F
.4844 .62942 m .48489 .62929 L .48393 .62935 L F
.4844 .62942 m .48393 .62935 L .48217 .62945 L F
.48309 .62977 m .48611 .63072 L .48489 .62929 L F
.527 .603 .873 r
.43586 .58256 m .43416 .58375 L .43202 .58049 L F
0 0 0 r
.4343 .58449 m .43416 .58375 L .43586 .58256 L F
.677 .886 .975 r
.43091 .58654 m .43326 .58594 L .43199 .58502 L F
.709 .565 .69 r
.43326 .58594 m .43068 .58858 L .43091 .58654 L F
.154 .637 .922 r
.42726 .58579 m .43091 .58654 L .43017 .58495 L F
.615 .068 0 r
.42726 .58579 m .42961 .58802 L .43068 .58858 L F
.394 .483 .833 r
.43017 .58495 m .43091 .58654 L .43199 .58502 L F
.461 .211 .448 r
.43326 .58594 m .42961 .58802 L .43199 .58502 L F
.43326 .58594 m .43068 .58858 L .42961 .58802 L F
0 0 .219 r
.43419 .58624 m .43372 .58702 L .43326 .58594 L F
.43372 .58702 m .43291 .58836 L .4331 .58706 L F
.43372 .58702 m .4331 .58706 L .43326 .58594 L F
.566 .493 .732 r
.43419 .58624 m .43318 .59069 L .43291 .58836 L F
.43419 .58624 m .43553 .59037 L .43318 .59069 L F
.858 .597 .543 r
.43715 .58643 m .43986 .59054 L .43677 .58916 L F
.188 .139 .567 r
.43677 .58916 m .43953 .58579 L .43715 .58643 L F
.43677 .58916 m .43804 .58493 L .43953 .58579 L F
.43677 .58916 m .43865 .58807 L .43804 .58493 L F
.104 0 .057 r
.43986 .59054 m .44057 .59102 L .43677 .58916 L F
.384 .572 .912 r
.43677 .58916 m .44057 .59102 L .43865 .58807 L F
.496 .451 .736 r
.43715 .58928 m .43509 .58716 L .43835 .58832 L F
.43509 .58716 m .43419 .58624 L .43651 .5874 L F
.43509 .58716 m .43651 .5874 L .43835 .58832 L F
.43715 .58928 m .43553 .59037 L .43446 .58709 L F
.43509 .58716 m .43446 .58709 L .43419 .58624 L F
.43715 .58928 m .43446 .58709 L .43509 .58716 L F
.013 .572 .812 r
.4327 .58656 m .43651 .5874 L .43419 .58624 L F
.4345 .58696 m .43527 .5869 L .43608 .58718 L F
.4345 .58696 m .43608 .58718 L .43645 .58731 L F
.43651 .5874 m .437 .58751 L .43419 .58624 L F
.43651 .5874 m .43686 .58746 L .437 .58751 L F
.749 .394 .381 r
.43586 .58256 m .4371 .58391 L .4343 .58449 L F
.4371 .58391 m .43804 .58493 L .43711 .58482 L F
.4371 .58391 m .43711 .58482 L .4343 .58449 L F
.74 .574 .669 r
.43817 .57999 m .43916 .58352 L .43586 .58256 L F
.972 .774 .577 r
.43916 .58352 m .43804 .58493 L .43586 .58256 L F
.728 .497 .577 r
.43804 .58493 m .43419 .58624 L .4343 .58449 L F
.43804 .58493 m .43865 .58807 L .43702 .5874 L F
0 0 .063 r
.437 .58751 m .43702 .58739 L .43703 .58726 L F
.6 .647 .868 r
.43419 .58624 m .437 .58751 L .43692 .58718 L F
.728 .497 .577 r
.43708 .58526 m .43703 .58722 L .43692 .58718 L F
.43505 .58594 m .43692 .58718 L .43419 .58624 L F
.43708 .58526 m .43692 .58718 L .43505 .58594 L F
0 0 .063 r
.43692 .58718 m .43752 .58262 L .43586 .58307 L F
.437 .58751 m .43703 .58726 L .43692 .58718 L F
.728 .497 .577 r
.43804 .58493 m .43702 .5874 L .43708 .58526 L F
0 0 .063 r
.43703 .58726 m .43752 .58262 L .43692 .58718 L F
.6 .647 .868 r
.43419 .58624 m .43692 .58718 L .43586 .58307 L F
.728 .497 .577 r
.43703 .58722 m .43702 .58739 L .43419 .58624 L F
.43702 .58739 m .43701 .5874 L .43419 .58624 L F
0 0 .063 r
.43703 .58726 m .43712 .58689 L .43712 .58641 L F
.43702 .58739 m .43712 .58689 L .43703 .58726 L F
.43728 .58483 m .43746 .58514 L .43752 .58262 L F
.43712 .58641 m .43746 .58514 L .43728 .58483 L F
.43712 .58689 m .43746 .58514 L .43712 .58641 L F
.496 .451 .736 r
.43835 .58832 m .43673 .58751 L .43865 .58807 L F
.43673 .58751 m .43419 .58624 L .43701 .5874 L F
.721 .979 .914 r
.437 .58751 m .43687 .58746 L .43702 .58739 L F
.496 .451 .736 r
.43673 .58751 m .43701 .5874 L .43865 .58807 L F
.721 .979 .914 r
.43702 .58739 m .435 .58681 L .43746 .58514 L F
.54 .023 0 r
.43714 .58506 m .4377 .58556 L .43746 .58514 L F
.108 .294 .77 r
.44039 .58454 m .44202 .58795 L .43953 .58579 L F
.8 .676 .728 r
.44039 .58454 m .43865 .58807 L .44202 .58795 L F
0 0 .163 r
.44 .5863 m .43865 .58807 L .44039 .58454 L F
.302 .035 .331 r
.44 .5863 m .43715 .58928 L .43865 .58807 L F
.44 .5863 m .43949 .58878 L .43715 .58928 L F
.357 .027 .262 r
.44247 .58599 m .43949 .58878 L .44 .5863 L F
0 0 0 r
.43512 .58672 m .43558 .58657 L .43746 .58514 L F
.783 .644 .708 r
.43817 .57999 m .43586 .58256 L .43428 .57981 L F
.527 .603 .873 r
.43586 .58256 m .43202 .58049 L .43428 .57981 L F
.371 .217 .539 r
.43586 .58307 m .43755 .58007 L .43539 .58055 L F
.43586 .58307 m .43752 .58262 L .43755 .58007 L F
0 0 .214 r
.43645 .58164 m .4356 .58656 L .43613 .58107 L F
.43606 .58509 m .4356 .58656 L .43645 .58164 L F
.4356 .58656 m .43558 .58657 L .43613 .58107 L F
0 0 0 r
.43555 .58659 m .43707 .58548 L .43746 .58514 L F
.43429 .58446 m .43326 .58594 L .43416 .58375 L F
.4343 .58449 m .43426 .58455 L .43429 .58446 L F
.43426 .58455 m .43326 .58594 L .43429 .58446 L F
0 0 .219 r
.43419 .58624 m .43326 .58594 L .4343 .58449 L F
.873 .703 .668 r
.43216 .58403 m .43419 .58624 L .4343 .58449 L F
.6 .647 .868 r
.43419 .58624 m .43586 .58307 L .4343 .58449 L F
.846 .733 .738 r
.43216 .58403 m .4343 .58449 L .43287 .58107 L F
.383 .484 .839 r
.43287 .58107 m .4343 .58449 L .43586 .58307 L F
.43287 .58107 m .43586 .58307 L .43539 .58055 L F
.836 .652 .654 r
.43613 .58107 m .43558 .58657 L .43241 .58357 L F
.43558 .58657 m .43552 .58661 L .43241 .58357 L F
.013 .572 .812 r
.4327 .58656 m .435 .58681 L .43527 .5869 L F
.4327 .58656 m .43527 .5869 L .4345 .58696 L F
.041 .602 .804 r
.43017 .58495 m .43199 .58502 L .42829 .58462 L F
.48 .869 .972 r
.43017 .58495 m .42668 .58536 L .42726 .58579 L F
.42957 .58502 m .42829 .58462 L .42668 .58536 L F
.43017 .58495 m .42829 .58462 L .42957 .58502 L F
.404 .408 .749 r
.42668 .58536 m .42829 .58462 L .42595 .58245 L F
.46 .117 .297 r
.42829 .58462 m .42695 .58334 L .4267 .58413 L F
.671 .93 .97 r
.42726 .58579 m .42424 .58652 L .42668 .58536 L F
.42726 .58579 m .42424 .58652 L .42668 .58536 L F
.096 .252 .735 r
.42829 .58462 m .42726 .58579 L .42668 .58536 L F
.564 .514 .758 r
.42383 .5838 m .42668 .58536 L .42595 .58245 L F
.215 0 .033 r
.42424 .58652 m .42227 .58846 L .42668 .58536 L F
.843 .811 .819 r
.42668 .58536 m .42227 .58846 L .42118 .5872 L F
.993 .764 .481 r
.42695 .58334 m .42595 .58245 L .42606 .58288 L F
.42695 .58334 m .42606 .58288 L .42668 .58536 L F
.42758 .58287 m .42829 .58462 L .42845 .58223 L F
.587 .537 .765 r
.4258 .58045 m .4289 .58116 L .42717 .57644 L F
.645 .483 .649 r
.4258 .58045 m .42845 .58223 L .4289 .58116 L F
.4258 .58045 m .42595 .58245 L .42845 .58223 L F
.993 .764 .481 r
.42638 .58283 m .42845 .58223 L .42595 .58245 L F
.42695 .58334 m .42746 .58287 L .42638 .58283 L F
.42758 .58287 m .42845 .58223 L .42638 .58283 L F
.564 .514 .758 r
.42383 .5838 m .42595 .58245 L .42217 .58218 L F
.735 .551 .643 r
.42217 .58218 m .4258 .58045 L .42235 .57971 L F
.42217 .58218 m .42595 .58245 L .4258 .58045 L F
.667 .463 .6 r
.42695 .58334 m .4235 .5814 L .42729 .58302 L F
.993 .764 .481 r
.4274 .58301 m .42743 .58306 L .42758 .58287 L F
.42743 .58306 m .42771 .58358 L .4276 .58296 L F
.42743 .58306 m .4276 .58296 L .42758 .58287 L F
.667 .463 .6 r
.42695 .58334 m .42729 .58302 L .42741 .58307 L F
.993 .764 .481 r
.4275 .58387 m .42829 .58462 L .4274 .58301 L F
.667 .463 .6 r
.42695 .58334 m .42741 .58307 L .42805 .58335 L F
.712 .605 .735 r
.42717 .57644 m .4289 .58116 L .43139 .57964 L F
.503 .465 .748 r
.42919 .58058 m .42889 .58189 L .42699 .57967 L F
.523 .328 .557 r
.42845 .58223 m .42829 .58462 L .43092 .58186 L F
.734 .418 .445 r
.42821 .58335 m .43092 .58186 L .42949 .58336 L F
.993 .764 .481 r
.42771 .58358 m .42829 .58462 L .42758 .58287 L F
.42695 .58334 m .4275 .58387 L .4274 .58301 L F
.734 .418 .445 r
.42695 .58334 m .42949 .58336 L .42829 .58462 L F
.667 .463 .6 r
.42695 .58334 m .42805 .58335 L .42851 .58354 L F
.751 .651 .75 r
.43199 .58502 m .4312 .58601 L .43142 .58496 L F
.4312 .58601 m .42961 .58802 L .43142 .58496 L F
.43142 .58496 m .42961 .58802 L .42829 .58462 L F
.873 .703 .668 r
.43221 .5841 m .43199 .58434 L .43251 .58457 L F
.46 .117 .297 r
.43201 .58434 m .43213 .58433 L .43188 .58429 L F
.873 .703 .668 r
.43199 .58434 m .4305 .58596 L .43251 .58457 L F
.46 .117 .297 r
.43201 .58434 m .43188 .58429 L .42695 .58334 L F
.42829 .58462 m .4305 .58596 L .43213 .58433 L F
.873 .703 .668 r
.43198 .58423 m .4305 .58596 L .43221 .5841 L F
.708 .445 .525 r
.43213 .58433 m .4305 .58596 L .43192 .5843 L F
.631 .377 .515 r
.43092 .58186 m .43206 .58419 L .43216 .58403 L F
.873 .703 .668 r
.43216 .58403 m .43198 .58423 L .43206 .58419 L F
.43216 .58403 m .43206 .58419 L .43221 .5841 L F
.631 .377 .515 r
.43206 .58419 m .43213 .58433 L .43216 .58403 L F
.734 .418 .445 r
.43198 .58423 m .43213 .58433 L .43206 .58419 L F
.708 .445 .525 r
.43213 .58433 m .43192 .5843 L .43198 .58423 L F
.734 .418 .445 r
.43188 .58429 m .43213 .58433 L .43198 .58423 L F
.708 .445 .525 r
.43213 .58433 m .43198 .58423 L .43216 .58403 L F
.46 .117 .297 r
.42829 .58462 m .43201 .58434 L .43149 .58424 L F
.42723 .58361 m .43149 .58424 L .42695 .58334 L F
.42829 .58462 m .43149 .58424 L .42723 .58361 L F
.873 .703 .668 r
.43251 .58457 m .4305 .58596 L .43357 .58619 L F
.734 .418 .445 r
.42805 .58335 m .42833 .58309 L .42821 .58335 L F
.705 .573 .705 r
.42833 .58309 m .42805 .58335 L .42741 .58307 L F
.734 .418 .445 r
.42695 .58334 m .42833 .58309 L .42805 .58335 L F
.705 .573 .705 r
.42833 .58309 m .42851 .58354 L .42805 .58335 L F
.734 .418 .445 r
.42848 .58277 m .43092 .58186 L .42821 .58335 L F
.503 .465 .748 r
.42864 .58291 m .42851 .58354 L .42825 .58289 L F
.705 .573 .705 r
.4273 .58219 m .42833 .58309 L .42741 .58307 L F
.734 .418 .445 r
.42695 .58334 m .42848 .58277 L .42833 .58309 L F
.42848 .58277 m .4292 .58278 L .42879 .58265 L F
.42695 .58334 m .42865 .58292 L .42848 .58277 L F
.42865 .58292 m .4292 .58278 L .42848 .58277 L F
.503 .465 .748 r
.42866 .58291 m .42864 .58291 L .42699 .57967 L F
.42864 .58291 m .42825 .58289 L .42807 .58243 L F
.42864 .58291 m .42807 .58243 L .42699 .57967 L F
.42866 .58291 m .42865 .58292 L .42864 .58291 L F
.42865 .58292 m .42851 .58354 L .42864 .58291 L F
.734 .418 .445 r
.42865 .58292 m .43176 .58358 L .4292 .58278 L F
.833 .796 .817 r
.42695 .58334 m .42851 .58354 L .42865 .58292 L F
.734 .418 .445 r
.42695 .58334 m .4293 .58346 L .42865 .58292 L F
.4293 .58346 m .43176 .58358 L .42865 .58292 L F
.705 .573 .705 r
.42699 .57967 m .42807 .58243 L .4273 .58219 L F
.42807 .58243 m .42833 .58309 L .4273 .58219 L F
.503 .465 .748 r
.42889 .58189 m .42866 .58291 L .42853 .58266 L F
.42889 .58189 m .42853 .58266 L .42699 .57967 L F
.993 .764 .481 r
.42729 .58302 m .42758 .58287 L .42746 .58287 L F
.42695 .58334 m .4274 .58301 L .42729 .58302 L F
.4274 .58301 m .42758 .58287 L .42729 .58302 L F
.706 .479 .577 r
.42235 .57971 m .4258 .58045 L .42555 .57975 L F
.587 .537 .765 r
.4258 .58045 m .42717 .57644 L .42555 .57975 L F
.705 .573 .705 r
.42699 .57967 m .4274 .58301 L .4235 .5814 L F
.4274 .58301 m .42741 .58307 L .42729 .58302 L F
.4274 .58301 m .42729 .58302 L .4235 .5814 L F
.512 .291 .516 r
.42845 .58223 m .43139 .57964 L .4289 .58116 L F
.42845 .58223 m .43092 .58186 L .43139 .57964 L F
.833 .796 .817 r
.42695 .58334 m .42865 .58292 L .42919 .58058 L F
.734 .418 .445 r
.42695 .58334 m .43188 .58429 L .43176 .58358 L F
.43188 .58429 m .43206 .58419 L .43176 .58358 L F
.42879 .58265 m .43176 .58358 L .43092 .58186 L F
.849 .896 .87 r
.42401 .57849 m .42555 .57975 L .42717 .57644 L F
.503 .465 .748 r
.42667 .57796 m .42699 .57967 L .42607 .57733 L F
.42919 .58058 m .42699 .57967 L .42667 .57796 L F
.541 .814 .996 r
.42235 .57971 m .42555 .57975 L .42401 .57849 L F
.705 .573 .705 r
.42607 .57733 m .42699 .57967 L .4235 .5814 L F
.444 .059 .214 r
.42774 .58319 m .4275 .58363 L .42695 .58334 L F
.829 .999 .79 r
.42695 .58334 m .42668 .58536 L .42523 .58542 L F
.46 .117 .297 r
.42829 .58462 m .4267 .58413 L .42598 .5865 L F
.444 .059 .214 r
.42698 .58462 m .42658 .58454 L .42695 .58334 L F
.584 .429 .638 r
.42463 .58525 m .42105 .58586 L .4232 .58485 L F
.42523 .58542 m .42443 .58551 L .42463 .58525 L F
.42443 .58551 m .42105 .58586 L .42463 .58525 L F
.994 .865 .589 r
.42695 .58334 m .4251 .58466 L .42576 .58382 L F
.584 .429 .638 r
.42523 .58542 m .42118 .5872 L .42105 .58586 L F
.994 .865 .589 r
.42575 .58382 m .42289 .58625 L .4232 .58485 L F
.4251 .58466 m .42576 .58381 L .42289 .58625 L F
.42695 .58334 m .42579 .5838 L .4251 .58466 L F
.42579 .5838 m .42576 .58381 L .4251 .58466 L F
.42695 .58334 m .42598 .5865 L .42576 .58381 L F
.444 .059 .214 r
.4275 .58363 m .42698 .58462 L .42695 .58334 L F
.42698 .58462 m .42598 .5865 L .42658 .58454 L F
.42774 .58319 m .42576 .58381 L .42598 .5865 L F
.42774 .58319 m .42796 .58485 L .42576 .58381 L F
0 .309 .743 r
.42576 .58381 m .42778 .58477 L .42616 .58359 L F
.42778 .58477 m .42796 .58485 L .42786 .58478 L F
.42778 .58477 m .42786 .58478 L .42616 .58359 L F
.873 .703 .668 r
.43375 .58576 m .43357 .58619 L .43419 .58624 L F
.43216 .58403 m .43357 .58619 L .43375 .58576 L F
.434 0 0 r
.4305 .58596 m .4327 .58656 L .43419 .58624 L F
.424 0 .12 r
.4327 .58656 m .43175 .58828 L .435 .58681 L F
0 0 .214 r
.4356 .58656 m .43557 .58666 L .43558 .58657 L F
.836 .652 .654 r
.43558 .58657 m .43557 .58666 L .43553 .58661 L F
0 0 0 r
.435 .58681 m .43457 .58747 L .43555 .58659 L F
.836 .652 .654 r
.43555 .58659 m .43553 .58661 L .43552 .58661 L F
.43558 .58657 m .43553 .58661 L .43555 .58659 L F
0 0 0 r
.435 .58681 m .4342 .58775 L .43457 .58747 L F
.43555 .58659 m .43457 .58747 L .43593 .58644 L F
.43714 .58506 m .43557 .58666 L .43689 .58243 L F
.43714 .58506 m .43593 .58644 L .43557 .58666 L F
.703 .547 .673 r
.43593 .58644 m .43241 .58357 L .43557 .58666 L F
.43591 .58642 m .43325 .5875 L .43241 .58357 L F
0 0 0 r
.43555 .58659 m .43593 .58644 L .43707 .58548 L F
.703 .547 .673 r
.43593 .58644 m .43591 .58645 L .43591 .58642 L F
0 0 0 r
.435 .58681 m .43555 .58659 L .43558 .58657 L F
.435 .58681 m .43558 .58657 L .43512 .58672 L F
.703 .547 .673 r
.43591 .58645 m .43325 .5875 L .43591 .58642 L F
0 0 .214 r
.43689 .58243 m .43606 .58509 L .43645 .58164 L F
.54 .023 0 r
.43714 .58506 m .43746 .58514 L .43593 .58644 L F
.966 .666 .408 r
.43834 .58685 m .43991 .58754 L .43714 .58506 L F
0 0 .166 r
.43854 .58637 m .43922 .58725 L .43834 .58685 L F
.54 .023 0 r
.43838 .58617 m .43991 .58754 L .43786 .58554 L F
.972 .774 .577 r
.43916 .58352 m .43953 .58579 L .43804 .58493 L F
0 .04 .573 r
.44039 .58454 m .43953 .58579 L .43916 .58352 L F
.583 .355 .536 r
.43752 .58262 m .43746 .58514 L .43991 .58469 L F
.596 .391 .575 r
.43746 .58514 m .43991 .58754 L .43991 .58469 L F
0 0 .166 r
.43934 .58444 m .43922 .5872 L .43854 .58637 L F
.43922 .5872 m .43922 .58725 L .43854 .58637 L F
.54 .023 0 r
.4377 .58556 m .43838 .58617 L .43746 .58514 L F
.43838 .58617 m .43786 .58554 L .43746 .58514 L F
.721 .979 .914 r
.43687 .58746 m .435 .58681 L .43702 .58739 L F
.728 .497 .577 r
.43702 .58739 m .43702 .5874 L .43701 .5874 L F
.013 .572 .812 r
.43587 .58725 m .43645 .58731 L .43686 .58746 L F
.4345 .58696 m .43645 .58731 L .43587 .58725 L F
.4345 .58696 m .43686 .58746 L .43651 .5874 L F
.354 .139 .442 r
.25067 .60269 m .24916 .60058 L .25098 .59992 L F
.25067 .60269 m .24855 .60403 L .24916 .60058 L F
.477 .179 .381 r
.46073 .59564 m .45786 .59802 L .45776 .59521 L F
.46073 .59564 m .46028 .59761 L .45786 .59802 L F
.341 .06 .334 r
.46228 .59683 m .46073 .59564 L .46295 .59498 L F
.46228 .59683 m .46028 .59761 L .46073 .59564 L F
.834 .971 .886 r
.43151 .56944 m .43103 .57175 L .43323 .56902 L F
.797 .944 .921 r
.43151 .56944 m .42966 .57118 L .43103 .57175 L F
.133 .135 .593 r
.21405 .60661 m .21508 .60629 L .21408 .60402 L F
.209 .102 .506 r
.21386 .60948 m .21508 .60629 L .21405 .60661 L F
0 0 .148 r
.22041 .59367 m .22013 .59261 L .22236 .5917 L F
.22041 .59367 m .21995 .59534 L .22013 .59261 L F
.748 .991 .879 r
.53616 .69744 m .53859 .69608 L .53905 .69449 L F
.629 .701 .898 r
.39403 .61765 m .39508 .61945 L .39153 .61847 L F
.428 .594 .912 r
.3961 .61764 m .39508 .61945 L .39403 .61765 L F
.526 .718 .961 r
.3961 .61764 m .39764 .61931 L .39508 .61945 L F
.407 .143 .398 r
.61722 .41583 m .61562 .41455 L .61773 .41489 L F
.61722 .41583 m .61502 .4167 L .61562 .41455 L F
.653 .488 .648 r
.5611 .53328 m .56143 .53607 L .55875 .53605 L F
.526 .396 .646 r
.5637 .53531 m .5611 .53328 L .56357 .53274 L F
.5637 .53531 m .56143 .53607 L .5611 .53328 L F
.167 0 0 r
.59559 .50954 m .59904 .50741 L .5978 .50871 L F
0 0 0 r
.5978 .50871 m .59904 .50741 L .60062 .50591 L F
.052 .502 .89 r
.22395 .55281 m .22401 .55201 L .22195 .55209 L F
.22395 .55281 m .22555 .55325 L .22401 .55201 L F
.352 0 0 r
.41341 .59735 m .41224 .59694 L .41413 .59514 L F
.41341 .59735 m .41095 .59767 L .41224 .59694 L F
.108 0 .08 r
.19547 .69287 m .19714 .6922 L .19485 .69406 L F
.774 .598 .661 r
.76193 .40883 m .76176 .4115 L .76006 .41214 L F
.383 .579 .917 r
.76122 .40692 m .76328 .40711 L .76193 .40883 L F
.258 .396 .812 r
.76328 .40711 m .76495 .41068 L .76193 .40883 L F
.496 .359 .624 r
.76193 .40883 m .76495 .41068 L .76176 .4115 L F
0 0 0 r
.61913 .40367 m .61648 .40607 L .61839 .40472 L F
.234 0 .082 r
.61839 .40472 m .62131 .40268 L .61913 .40367 L F
.639 .626 .821 r
.64573 .44595 m .64725 .44792 L .64517 .44439 L F
.69 .789 .926 r
.64383 .44742 m .64725 .44792 L .64573 .44595 L F
0 0 0 r
.42724 .59078 m .42588 .59133 L .42865 .59104 L F
.42724 .59078 m .42504 .5918 L .42588 .59133 L F
.938 .964 .689 r
.61179 .41208 m .61015 .41509 L .61012 .41304 L F
.8 .986 .723 r
.61179 .41208 m .61012 .41304 L .61268 .40999 L F
.672 .831 .96 r
.74138 .41539 m .74492 .41552 L .74431 .41432 L F
.74492 .41552 m .74138 .41539 L .74431 .41432 L F
.661 .859 .975 r
.74431 .41432 m .74492 .41552 L .74743 .41454 L F
.74431 .41432 m .74492 .41552 L .74743 .41454 L F
.04 .371 .839 r
.39018 .64063 m .39171 .64065 L .3895 .63889 L F
.39018 .64063 m .39252 .6421 L .39171 .64065 L F
.977 .713 .462 r
.53265 .5767 m .53612 .57425 L .53589 .57374 L F
.577 .562 .801 r
.53612 .57425 m .53503 .57124 L .53589 .57374 L F
.632 .817 .972 r
.72119 .40965 m .72279 .4118 L .72492 .41021 L F
.784 .914 .928 r
.73027 .43718 m .72831 .43865 L .72731 .43761 L F
.253 .098 .469 r
.61502 .4167 m .61325 .42029 L .61243 .4179 L F
.706 .763 .897 r
.74346 .42287 m .73962 .42062 L .74156 .41987 L F
.656 .805 .954 r
.7443 .41913 m .74346 .42287 L .74156 .41987 L F
.7443 .41913 m .74546 .42213 L .74346 .42287 L F
.456 .885 .881 r
.74462 .42167 m .74346 .42287 L .74546 .42213 L F
.74462 .42167 m .74211 .42271 L .74346 .42287 L F
0 0 .416 r
.65266 .41214 m .65161 .41195 L .65058 .4117 L F
.93 .953 .778 r
.6557 .40753 m .65649 .40846 L .65486 .41091 L F
.6557 .40753 m .65486 .41091 L .65386 .41001 L F
0 0 .572 r
.65486 .41091 m .65596 .41162 L .65446 .41048 L F
.65429 .4104 m .65446 .41048 L .65386 .41001 L F
.65486 .41091 m .65446 .41048 L .65429 .4104 L F
0 0 0 r
.65478 .41062 m .65336 .41201 L .65266 .41214 L F
.022 .342 .821 r
.65444 .41039 m .65596 .41162 L .65548 .41011 L F
0 0 0 r
.65548 .41011 m .65487 .41066 L .65478 .41062 L F
0 .206 .702 r
.65386 .41001 m .65596 .41162 L .65444 .41039 L F
0 0 0 r
.65487 .41066 m .65336 .41201 L .65478 .41062 L F
0 0 .416 r
.65266 .41214 m .65219 .41443 L .65169 .41232 L F
.781 .802 .314 r
.65148 .41657 m .65219 .41443 L .65266 .41214 L F
.65148 .41657 m .6521 .41424 L .65196 .41418 L F
.6521 .41424 m .65266 .41214 L .65196 .41418 L F
0 0 .1 r
.6518 .41412 m .65196 .41418 L .65169 .4135 L F
.012 .264 .766 r
.65211 .41841 m .65219 .41443 L .65148 .41657 L F
0 0 .1 r
.65213 .41602 m .65192 .4172 L .65196 .41418 L F
.65213 .41602 m .65196 .41418 L .6518 .41412 L F
0 0 0 r
.65336 .41201 m .65169 .4135 L .65266 .41214 L F
0 0 .416 r
.65266 .41214 m .65169 .41232 L .65161 .41195 L F
.384 0 .083 r
.37298 .59465 m .37538 .59431 L .37681 .59247 L F
.235 0 0 r
.37538 .59431 m .37907 .59194 L .37681 .59247 L F
.268 .096 .453 r
.20845 .62413 m .20969 .62637 L .20985 .62377 L F
.20845 .62413 m .20769 .62733 L .20969 .62637 L F
0 0 0 r
.58486 .447 m .5869 .44601 L .58782 .44444 L F
.58486 .447 m .58435 .44877 L .5869 .44601 L F
.807 .612 .053 r
.65239 .4268 m .65264 .42658 L .65218 .42552 L F
.65239 .4268 m .65279 .42916 L .65264 .42658 L F
0 0 0 r
.58782 .44444 m .58935 .44299 L .59054 .44171 L F
.58782 .44444 m .58882 .44479 L .58935 .44299 L F
.58782 .44444 m .5869 .44601 L .58882 .44479 L F
.619 .732 .927 r
.71698 .40201 m .71335 .40037 L .71573 .39933 L F
.649 .74 .916 r
.71945 .40046 m .71698 .40201 L .71573 .39933 L F
.721 .628 .754 r
.2275 .58642 m .23062 .58676 L .22996 .58557 L F
.21 .44 .864 r
.23062 .58676 m .23144 .58563 L .22996 .58557 L F
.23062 .58676 m .23352 .58881 L .23144 .58563 L F
.038 0 0 r
.48898 .5757 m .48752 .57576 L .48988 .57483 L F
.551 .563 .82 r
.49156 .57295 m .4903 .57705 L .48988 .57483 L F
.928 .812 .711 r
.50921 .55077 m .50693 .55098 L .5083 .54756 L F
.787 .353 .217 r
.50921 .55077 m .50798 .55227 L .50693 .55098 L F
.888 .504 .301 r
.50984 .55276 m .50798 .55227 L .50921 .55077 L F
0 0 0 r
.61648 .40607 m .61765 .4064 L .61839 .40472 L F
.61648 .40607 m .61547 .40755 L .61765 .4064 L F
.612 .453 .643 r
.54389 .56823 m .54464 .57161 L .54123 .57156 L F
.609 .431 .617 r
.54461 .57405 m .54123 .57156 L .54464 .57161 L F
.54461 .57405 m .54244 .57516 L .54123 .57156 L F
.646 .595 .784 r
.47847 .58035 m .48171 .58074 L .47921 .58143 L F
.654 .277 .317 r
.56372 .62312 m .56541 .62138 L .5634 .62078 L F
.56372 .62312 m .56757 .62398 L .56541 .62138 L F
.638 .234 .262 r
.56819 .51425 m .56573 .51244 L .56417 .51425 L F
.563 .294 .465 r
.56819 .51425 m .56809 .51218 L .56573 .51244 L F
.521 .339 .574 r
.58549 .51827 m .58571 .52091 L .58313 .52165 L F
.465 .208 .439 r
.58313 .52165 m .58529 .52305 L .5828 .5233 L F
.58313 .52165 m .58571 .52091 L .58529 .52305 L F
.807 .768 .816 r
.51226 .53826 m .50911 .53844 L .51131 .53745 L F
.51226 .53826 m .51117 .53918 L .50911 .53844 L F
.765 .9 .937 r
.51415 .53521 m .51226 .53826 L .51131 .53745 L F
.51415 .53521 m .51552 .53612 L .51226 .53826 L F
.105 .553 .914 r
.67303 .41461 m .67113 .41473 L .66953 .41469 L F
.67303 .41461 m .67401 .41572 L .67113 .41473 L F
.424 .714 .984 r
.37706 .62653 m .37835 .62778 L .37912 .62636 L F
.37706 .62653 m .37835 .62778 L .37912 .62636 L F
.497 .682 .949 r
.37964 .6337 m .38067 .63184 L .3781 .6326 L F
.37964 .6337 m .38179 .6335 L .38067 .63184 L F
.786 .924 .928 r
.64461 .40784 m .64277 .40892 L .64281 .40695 L F
.831 .923 .895 r
.64461 .40784 m .64535 .40453 L .64706 .40765 L F
.64461 .40784 m .64281 .40695 L .64535 .40453 L F
.656 .655 .837 r
.19456 .66186 m .19772 .6641 L .19841 .66267 L F
.803 .808 .854 r
.19772 .6641 m .19839 .66354 L .19841 .66267 L F
.981 .721 .324 r
.6284 .43454 m .62762 .43176 L .62638 .43418 L F
.785 .667 .115 r
.64277 .40892 m .64262 .40813 L .64281 .40695 L F
.64277 .40892 m .6426 .41186 L .64262 .40813 L F
.918 .722 .623 r
.64123 .41982 m .64242 .42357 L .64063 .42328 L F
.859 .478 0 r
.64242 .42357 m .64263 .42544 L .64063 .42328 L F
.64242 .42357 m .64335 .42583 L .64263 .42544 L F
0 0 0 r
.63532 .4405 m .63272 .44318 L .63554 .44042 L F
.264 .397 .811 r
.6463 .44208 m .64713 .44004 L .64442 .44286 L F
.6463 .44208 m .64835 .44342 L .64713 .44004 L F
.42 .829 .975 r
.67821 .39809 m .67579 .39905 L .6757 .3985 L F
.67821 .39809 m .6794 .39859 L .67579 .39905 L F
.294 0 .056 r
.17191 .54362 m .17319 .54433 L .17371 .54271 L F
.17191 .54362 m .17101 .54489 L .17319 .54433 L F
.634 .587 .784 r
.57992 .61912 m .58312 .62165 L .58337 .61888 L F
.556 .893 .983 r
.72378 .43788 m .72477 .43843 L .72196 .43935 L F
.72378 .43788 m .72196 .43935 L .72144 .43996 L F
.608 .276 .382 r
.55875 .53605 m .56111 .53798 L .55852 .53848 L F
.55875 .53605 m .56143 .53607 L .56111 .53798 L F
.767 .737 .826 r
.69933 .44982 m .70047 .45317 L .69708 .4528 L F
.748 .736 .841 r
.70192 .44898 m .70047 .45317 L .69933 .44982 L F
.70192 .44898 m .70345 .45087 L .70047 .45317 L F
.397 0 0 r
.18146 .55615 m .17589 .55839 L .17773 .55738 L F
.18146 .55615 m .1782 .55822 L .17589 .55839 L F
0 0 0 r
.17997 .55751 m .18146 .55615 L .1833 .5564 L F
.17997 .55751 m .1782 .55822 L .18146 .55615 L F
.508 .313 .551 r
.46632 .67767 m .46619 .68052 L .46857 .67752 L F
.708 .646 .785 r
.48947 .62542 m .49134 .62218 L .48842 .62271 L F
.48947 .62542 m .49053 .62524 L .49134 .62218 L F
.658 .415 .542 r
.48853 .62763 m .49053 .62524 L .48947 .62542 L F
.48853 .62763 m .49053 .62524 L .48947 .62542 L F
.779 .551 .59 r
.51117 .53918 m .50877 .54081 L .50911 .53844 L F
.51117 .53918 m .51253 .54263 L .50877 .54081 L F
.351 .66 .972 r
.73934 .43201 m .74049 .43078 L .73849 .43046 L F
.73934 .43201 m .74148 .4321 L .74049 .43078 L F
.597 .567 .792 r
.73934 .43201 m .74291 .43536 L .74148 .4321 L F
.8 .998 .852 r
.7315 .41176 m .73284 .40916 L .73051 .41045 L F
.7315 .41176 m .73425 .4092 L .73284 .40916 L F
.38 .168 .462 r
.2446 .61236 m .24235 .61539 L .2427 .61302 L F
.432 .122 .338 r
.38746 .58947 m .38968 .58887 L .39091 .58564 L F
.465 .139 .328 r
.38968 .58887 m .39313 .58561 L .39091 .58564 L F
.188 0 .104 r
.22111 .64521 m .21818 .64766 L .21923 .64599 L F
.827 .788 .816 r
.6378 .44977 m .64093 .4497 L .64028 .44676 L F
.728 .729 .851 r
.64028 .44676 m .64093 .4497 L .64383 .44742 L F
.217 0 0 r
.17707 .54139 m .1792 .54172 L .18093 .54174 L F
.358 0 0 r
.1792 .54172 m .18332 .54193 L .18093 .54174 L F
.356 0 0 r
.20109 .54054 m .20327 .54073 L .20507 .53983 L F
.253 0 0 r
.20327 .54073 m .20672 .53971 L .20507 .53983 L F
.654 .68 .862 r
.72885 .40236 m .72675 .40357 L .72559 .40175 L F
.72892 .40237 m .72892 .40254 L .72885 .40236 L F
.72905 .40248 m .72892 .40254 L .72892 .40237 L F
.72892 .40254 m .72675 .40357 L .72885 .40236 L F
.647 .579 .764 r
.72902 .40245 m .72864 .40274 L .72882 .40229 L F
.73177 .40034 m .72902 .40245 L .72915 .40207 L F
.654 .68 .862 r
.72918 .40242 m .72905 .40248 L .72892 .40237 L F
.678 .653 .818 r
.72864 .40274 m .72918 .40242 L .72892 .40237 L F
.72864 .40274 m .72892 .40237 L .72559 .40175 L F
.647 .579 .764 r
.73118 .39935 m .72915 .40207 L .73045 .39814 L F
.73177 .40034 m .72915 .40207 L .73118 .39935 L F
.72902 .40245 m .72882 .40229 L .73045 .39814 L F
.728 .718 .841 r
.73045 .39814 m .72882 .40229 L .72689 .39752 L F
.72882 .40229 m .72874 .4025 L .72735 .39876 L F
.72882 .40229 m .72735 .39876 L .72689 .39752 L F
.72874 .4025 m .72864 .40274 L .72854 .40245 L F
.72874 .4025 m .72854 .40245 L .72689 .39752 L F
.677 .749 .906 r
.73057 .40399 m .72675 .40357 L .72892 .40254 L F
.72938 .40265 m .72892 .40254 L .72918 .40242 L F
.73057 .40399 m .72892 .40254 L .72938 .40265 L F
.771 .775 .856 r
.48049 .57436 m .47678 .5741 L .47922 .57357 L F
.554 .862 .997 r
.48134 .57345 m .48149 .57284 L .48276 .57194 L F
0 0 0 r
.48276 .57194 m .48149 .57284 L .48365 .5718 L F
.785 .947 .607 r
.48149 .57284 m .48249 .57064 L .48365 .5718 L F
.083 0 .227 r
.48149 .57284 m .48275 .57381 L .4816 .57236 L F
.785 .947 .607 r
.48186 .57203 m .4815 .57223 L .48249 .57064 L F
.48149 .57284 m .4815 .57223 L .48186 .57203 L F
.083 0 .227 r
.48149 .57284 m .4816 .57236 L .4815 .57223 L F
.839 .503 .418 r
.48275 .57381 m .48101 .57251 L .4815 .57223 L F
.48101 .57251 m .47885 .57091 L .4815 .57223 L F
.554 .862 .997 r
.48049 .57436 m .48149 .57284 L .48134 .57345 L F
.48049 .57436 m .47922 .57357 L .48149 .57284 L F
.583 .561 .795 r
.19349 .67195 m .19731 .67441 L .19512 .67188 L F
.321 .232 .597 r
.19512 .67188 m .19767 .67098 L .19595 .66884 L F
.611 .427 .608 r
.19512 .67188 m .19868 .67355 L .19767 .67098 L F
.19512 .67188 m .19731 .67441 L .19868 .67355 L F
0 0 .317 r
.19839 .66354 m .19875 .66216 L .19841 .66267 L F
.688 .713 .19 r
.19951 .65937 m .19875 .66216 L .19839 .66354 L F
.988 .873 .626 r
.44011 .63545 m .44088 .63673 L .4418 .63408 L F
.902 .972 .81 r
.44199 .60022 m .44036 .60371 L .44436 .60084 L F
.389 .242 .558 r
.58764 .51997 m .58549 .51827 L .58769 .51773 L F
.58764 .51997 m .58571 .52091 L .58549 .51827 L F
.421 .387 .715 r
.36578 .61313 m .36699 .60915 L .36526 .60974 L F
.36578 .61313 m .3676 .61287 L .36699 .60915 L F
.427 .45 .781 r
.36578 .61313 m .36869 .61482 L .3676 .61287 L F
.492 .437 .723 r
.36578 .61313 m .3665 .61561 L .36869 .61482 L F
.231 0 0 r
.18702 .55574 m .18555 .55637 L .1833 .5564 L F
.235 0 0 r
.18917 .55513 m .18555 .55637 L .18702 .55574 L F
.812 .755 .8 r
.49134 .62218 m .49053 .62524 L .49255 .62088 L F
.817 .716 .754 r
.52033 .52762 m .5162 .52939 L .51858 .52639 L F
.52033 .52762 m .51815 .53045 L .5162 .52939 L F
.923 .929 .795 r
.5214 .52375 m .52033 .52762 L .51858 .52639 L F
.546 .299 .493 r
.68655 .40736 m .6844 .40739 L .68685 .40666 L F
.68655 .40736 m .68455 .40864 L .6844 .40739 L F
.038 0 0 r
.48898 .5757 m .48638 .57635 L .48752 .57576 L F
.537 .347 .571 r
.55127 .5451 m .55362 .54699 L .55145 .5477 L F
.55127 .5451 m .55374 .54445 L .55362 .54699 L F
.589 .276 .406 r
.57186 .52924 m .57201 .52719 L .5745 .52894 L F
.596 .271 .389 r
.57201 .52719 m .57463 .52713 L .5745 .52894 L F
.53 .327 .55 r
.55627 .62519 m .55877 .62445 L .55876 .62183 L F
.614 .451 .637 r
.55877 .62445 m .5612 .62137 L .55876 .62183 L F
.79 .766 .832 r
.44826 .59929 m .44948 .60112 L .44664 .6002 L F
.825 .42 .28 r
.44948 .60112 m .44774 .60262 L .44664 .6002 L F
.602 .696 .909 r
.45186 .60056 m .44948 .60112 L .44826 .59929 L F
.476 0 0 r
.45114 .60216 m .44948 .60112 L .45186 .60056 L F
.45114 .60216 m .44774 .60262 L .44948 .60112 L F
.416 .066 .261 r
.47699 .62803 m .47614 .62954 L .48024 .62736 L F
.421 .315 .629 r
.36433 .60735 m .36635 .60704 L .36617 .60342 L F
.437 .408 .728 r
.36433 .60735 m .36699 .60915 L .36635 .60704 L F
.407 .41 .751 r
.36526 .60974 m .36699 .60915 L .36433 .60735 L F
.49 .098 .224 r
.63639 .43093 m .6337 .43009 L .63255 .43238 L F
.359 0 0 r
.73492 .42308 m .73527 .42346 L .73664 .42361 L F
.73527 .42346 m .73534 .42349 L .73664 .42361 L F
.858 .997 .8 r
.73664 .42361 m .7385 .41946 L .73962 .42062 L F
.359 0 0 r
.73527 .42346 m .73529 .42348 L .73534 .42349 L F
.649 .482 .644 r
.73529 .42348 m .73563 .42414 L .73559 .42315 L F
.73529 .42348 m .73559 .42315 L .73547 .42092 L F
.858 .997 .8 r
.73664 .42361 m .73534 .42349 L .73578 .42292 L F
.73816 .42023 m .73624 .4224 L .7385 .41946 L F
.73624 .4224 m .73635 .4222 L .7385 .41946 L F
.73664 .42361 m .73578 .42292 L .73816 .42023 L F
.73534 .42349 m .73584 .42279 L .7385 .41946 L F
.556 .402 .627 r
.7385 .41946 m .73584 .42279 L .73547 .42092 L F
.73584 .42279 m .73529 .42348 L .73547 .42092 L F
.478 .35 .627 r
.73658 .42176 m .7359 .42305 L .73807 .4229 L F
.7359 .42305 m .73561 .42359 L .73598 .42349 L F
.7359 .42305 m .73598 .42349 L .73807 .4229 L F
.73744 .42014 m .73807 .4229 L .73759 .42008 L F
.73547 .42092 m .73658 .42176 L .73744 .42014 L F
.73658 .42176 m .73807 .4229 L .73744 .42014 L F
.858 .997 .8 r
.73624 .4224 m .73578 .42292 L .73635 .4222 L F
.73534 .42349 m .73529 .42348 L .73584 .42279 L F
.478 .35 .627 r
.73547 .42092 m .73559 .42315 L .73658 .42176 L F
.73559 .42315 m .73561 .42359 L .73658 .42176 L F
.73561 .42359 m .73563 .42414 L .73623 .42384 L F
.73561 .42359 m .73623 .42384 L .73807 .4229 L F
.23 .742 .714 r
.16233 .54807 m .16611 .54701 L .16367 .5479 L F
0 0 0 r
.41062 .57785 m .41089 .5779 L .41266 .57691 L F
.41062 .57785 m .40887 .57904 L .41089 .5779 L F
.439 .289 .58 r
.26211 .58235 m .26012 .58044 L .26228 .57989 L F
.26211 .58235 m .26017 .58312 L .26012 .58044 L F
.418 0 0 r
.73902 .43555 m .74362 .43631 L .74291 .43536 L F
0 .473 .786 r
.74226 .43116 m .74369 .43145 L .74514 .43213 L F
.74167 .43096 m .74369 .43145 L .74226 .43116 L F
.584 .243 .358 r
.74672 .4306 m .74471 .43166 L .74369 .43145 L F
.507 .348 .6 r
.74291 .43536 m .74369 .43145 L .74148 .4321 L F
.74291 .43536 m .74514 .43213 L .74369 .43145 L F
.584 .243 .358 r
.74471 .43166 m .7433 .43241 L .74369 .43145 L F
.507 .348 .6 r
.74291 .43536 m .74546 .43473 L .74514 .43213 L F
.579 .547 .783 r
.74291 .43536 m .74604 .43734 L .74546 .43473 L F
.74291 .43536 m .74604 .43734 L .74546 .43473 L F
.031 0 0 r
.74362 .43631 m .74546 .43473 L .74291 .43536 L F
.879 .576 .471 r
.52672 .586 m .52954 .58654 L .52919 .58853 L F
.757 .625 .713 r
.53197 .58563 m .52919 .58853 L .52954 .58654 L F
.79 .643 .086 r
.21489 .56778 m .21475 .56904 L .21577 .56844 L F
.21489 .56778 m .2149 .57169 L .21475 .56904 L F
.47 .077 .211 r
.17371 .54271 m .17707 .54139 L .17435 .5411 L F
.777 .982 .906 r
.69835 .46099 m .70197 .45937 L .70099 .45863 L F
.589 .889 .99 r
.70099 .45863 m .70197 .45937 L .70437 .45844 L F
.599 .642 .865 r
.71222 .39805 m .71075 .40099 L .70971 .39892 L F
.71222 .39805 m .71335 .40037 L .71075 .40099 L F
.549 .16 .257 r
.66953 .41469 m .66801 .4142 L .66763 .41511 L F
.518 .746 .978 r
.6686 .41307 m .66763 .41511 L .66953 .41469 L F
.66953 .41469 m .66763 .41511 L .6686 .41307 L F
.285 0 0 r
.21706 .54097 m .21921 .54134 L .221 .54123 L F
.296 0 0 r
.221 .54123 m .21921 .54134 L .22303 .54162 L F
0 0 0 r
.59054 .44171 m .59217 .44015 L .59323 .43902 L F
.59054 .44171 m .59131 .4419 L .59217 .44015 L F
.59054 .44171 m .58935 .44299 L .59131 .4419 L F
.817 .612 .625 r
.48594 .58332 m .48531 .58619 L .48184 .58585 L F
.607 .139 0 r
.48499 .58226 m .48594 .58332 L .48349 .58033 L F
0 0 .097 r
.48648 .58426 m .48594 .58332 L .48499 .58226 L F
.48648 .58426 m .48531 .58619 L .48594 .58332 L F
.188 0 .142 r
.60829 .49741 m .61095 .49447 L .61003 .49614 L F
0 0 0 r
.61003 .49614 m .61095 .49447 L .61281 .49345 L F
.904 .728 .654 r
.67719 .44477 m .67652 .44578 L .67667 .44493 L F
.441 .137 .354 r
.18954 .55384 m .1911 .55532 L .18917 .55513 L F
.545 .123 .19 r
.19187 .55401 m .1911 .55532 L .18954 .55384 L F
.507 .077 .157 r
.43061 .64286 m .43294 .64406 L .43058 .64391 L F
.503 .09 .191 r
.43411 .64229 m .43294 .64406 L .43061 .64286 L F
.83 .693 .713 r
.65989 .4346 m .66284 .43551 L .66145 .43677 L F
.474 .284 .542 r
.54389 .56823 m .54655 .56546 L .54616 .5677 L F
.559 .419 .647 r
.54675 .57095 m .54389 .56823 L .54616 .5677 L F
.54675 .57095 m .54464 .57161 L .54389 .56823 L F
.357 .137 .437 r
.23372 .62776 m .23322 .63034 L .23138 .63089 L F
.151 0 .354 r
.23237 .63236 m .23138 .63089 L .23322 .63034 L F
.23237 .63236 m .23098 .63341 L .23138 .63089 L F
.627 .78 .955 r
.7 .40845 m .70142 .40609 L .69886 .40697 L F
.7 .40845 m .70252 .40761 L .70142 .40609 L F
.063 0 .155 r
.19206 .678 m .19358 .67732 L .19438 .67504 L F
.751 .641 .739 r
.19095 .6801 m .19358 .67732 L .19206 .678 L F
.632 .693 .889 r
.70611 .4087 m .70983 .40994 L .70861 .40805 L F
.643 .724 .907 r
.70861 .40805 m .70983 .40994 L .71216 .40898 L F
.799 .952 .918 r
.51788 .54345 m .51467 .5468 L .51558 .54372 L F
.903 .847 .394 r
.51788 .54345 m .51756 .54644 L .51467 .5468 L F
.742 .61 .711 r
.43563 .56816 m .43645 .57295 L .4393 .56861 L F
.69 .965 .937 r
.75374 .43158 m .75643 .42947 L .75355 .43128 L F
.583 .561 .795 r
.19349 .67195 m .19438 .67504 L .19731 .67441 L F
.322 0 .199 r
.19358 .67732 m .19731 .67441 L .19438 .67504 L F
.992 .862 .602 r
.51751 .54024 m .51585 .54184 L .51626 .54172 L F
.478 .251 .491 r
.58152 .5006 m .58142 .50284 L .58394 .50002 L F
.404 .147 .408 r
.57649 .5087 m .57423 .50943 L .57388 .51161 L F
.561 .372 .583 r
.55852 .53848 m .55611 .54151 L .55603 .53892 L F
.307 .128 .468 r
.23354 .57675 m .23651 .57181 L .23392 .57448 L F
.419 .305 .617 r
.54777 .55902 m .54575 .56273 L .54455 .55943 L F
.54777 .55902 m .54761 .56205 L .54575 .56273 L F
.419 .306 .617 r
.54761 .56205 m .54809 .56456 L .54575 .56273 L F
.348 .31 .674 r
.54809 .56456 m .54655 .56546 L .54575 .56273 L F
.912 .705 .609 r
.19723 .65912 m .19951 .65937 L .19978 .65846 L F
.678 .976 .819 r
.19951 .65937 m .19874 .65932 L .19978 .65846 L F
.318 .807 .824 r
.20362 .65855 m .19874 .65932 L .19951 .65937 L F
.562 .932 .919 r
.20336 .65806 m .20362 .65855 L .20562 .65758 L F
.20336 .65806 m .19874 .65932 L .20362 .65855 L F
.513 .51 .79 r
.3665 .61561 m .36965 .61854 L .36869 .61482 L F
.336 .217 .566 r
.23534 .56583 m .2369 .56703 L .23724 .56517 L F
.23534 .56583 m .23528 .56856 L .2369 .56703 L F
.92 .908 .51 r
.58298 .4723 m .58286 .4745 L .58301 .47359 L F
.875 .911 .85 r
.58298 .4723 m .58176 .47627 L .58286 .4745 L F
.734 .265 .134 r
.22926 .55678 m .22578 .55548 L .22745 .55752 L F
.975 .731 .505 r
.39511 .60923 m .39602 .61236 L .39645 .61242 L F
.577 .34 .519 r
.39602 .61236 m .39263 .61447 L .39645 .61242 L F
.526 .521 .793 r
.423 .59679 m .42171 .60018 L .42026 .59745 L F
.423 .59679 m .424 .60021 L .42171 .60018 L F
0 0 0 r
.42257 .59994 m .42171 .60018 L .424 .60021 L F
.42257 .59994 m .42008 .60065 L .42171 .60018 L F
.608 .32 .455 r
.47715 .58614 m .47336 .58884 L .47347 .58604 L F
.47715 .58614 m .47638 .58868 L .47336 .58884 L F
.048 0 0 r
.47975 .58671 m .47638 .58868 L .47715 .58614 L F
.24 .554 .932 r
.24747 .54503 m .24591 .54573 L .24457 .54458 L F
.24747 .54503 m .24856 .5465 L .24591 .54573 L F
.728 .806 .913 r
.6821 .41187 m .68585 .41234 L .68427 .41047 L F
.898 .975 .676 r
.6859 .45862 m .68365 .46106 L .68516 .45772 L F
.6859 .45862 m .6839 .46191 L .68365 .46106 L F
.406 .449 .793 r
.3671 .62194 m .36835 .62587 L .36947 .62318 L F
.635 .714 .904 r
.36947 .62318 m .36835 .62587 L .3709 .62498 L F
.166 0 0 r
.74933 .4361 m .7514 .43611 L .74868 .43657 L F
.74933 .4361 m .75198 .43519 L .7514 .43611 L F
0 0 0 r
.59323 .43902 m .59339 .43886 L .59445 .43735 L F
.59323 .43902 m .59217 .44015 L .59339 .43886 L F
.88 .968 .845 r
.52882 .51722 m .52738 .51899 L .52534 .51939 L F
.688 .772 .915 r
.6904 .40837 m .69401 .40897 L .69277 .40732 L F
.662 .775 .933 r
.69401 .40897 m .6953 .40638 L .69277 .40732 L F
.69401 .40897 m .69639 .40799 L .6953 .40638 L F
.818 .997 .776 r
.67356 .41917 m .67616 .41726 L .67698 .41573 L F
.31 .367 .76 r
.67698 .41573 m .67616 .41726 L .67852 .41562 L F
.933 .624 .432 r
.52801 .51411 m .52964 .51552 L .52816 .51685 L F
.934 .955 .636 r
.52816 .51685 m .52964 .51552 L .52882 .51722 L F
.827 .863 .873 r
.53052 .51202 m .52964 .51552 L .52801 .51411 L F
.53052 .51202 m .53144 .51363 L .52964 .51552 L F
.987 .713 .371 r
.66641 .44284 m .66774 .4471 L .66781 .44433 L F
.441 .217 .477 r
.59346 .51221 m .59559 .50954 L .59548 .51182 L F
.38 .208 .519 r
.59822 .51105 m .59559 .50954 L .5978 .50871 L F
.59822 .51105 m .59548 .51182 L .59559 .50954 L F
0 0 .199 r
.22123 .58392 m .2215 .58624 L .22115 .58638 L F
0 0 .218 r
.22164 .58744 m .22115 .58638 L .2215 .58624 L F
.898 .709 .639 r
.21982 .58361 m .22163 .58742 L .2215 .58624 L F
.22163 .58742 m .22164 .58744 L .2215 .58624 L F
0 0 .199 r
.22128 .58264 m .2215 .58624 L .22123 .58392 L F
0 0 .218 r
.22164 .58744 m .22134 .58892 L .22115 .58638 L F
.59 .438 .643 r
.54742 .55616 m .54777 .55902 L .54455 .55943 L F
0 0 0 r
.41413 .59514 m .41607 .59423 L .4164 .59391 L F
.704 .564 .694 r
.46374 .58528 m .46817 .58659 L .46613 .58272 L F
.651 .588 .772 r
.46613 .58272 m .4698 .58308 L .46893 .57964 L F
.459 .454 .766 r
.46613 .58272 m .46969 .58549 L .4698 .58308 L F
.46613 .58272 m .46817 .58659 L .46969 .58549 L F
.271 0 0 r
.19557 .55306 m .1911 .55532 L .19187 .55401 L F
.19557 .55306 m .19322 .55515 L .1911 .55532 L F
.164 0 0 r
.19548 .55453 m .19557 .55306 L .19762 .55277 L F
.19548 .55453 m .19322 .55515 L .19557 .55306 L F
.757 .914 .943 r
.64594 .43777 m .645 .43951 L .64296 .43846 L F
.331 0 0 r
.42298 .59258 m .42176 .59375 L .41743 .59359 L F
.832 .901 .487 r
.42331 .59071 m .42298 .59258 L .42504 .5918 L F
.42317 .59151 m .42232 .59286 L .42298 .59258 L F
.42232 .59286 m .42176 .59375 L .4227 .59285 L F
.42232 .59286 m .4227 .59285 L .42298 .59258 L F
.42255 .59221 m .42176 .59375 L .42317 .59151 L F
.645 .147 .052 r
.42586 .59387 m .4219 .59287 L .42346 .59318 L F
.746 .569 .655 r
.41974 .59014 m .42111 .59259 L .42346 .59318 L F
.42111 .59259 m .42176 .59375 L .42346 .59318 L F
.645 .147 .052 r
.4219 .59287 m .42152 .59278 L .42196 .59287 L F
.4219 .59287 m .42196 .59287 L .42346 .59318 L F
.746 .569 .655 r
.41974 .59014 m .42243 .59234 L .42152 .59278 L F
.42243 .59234 m .42346 .59318 L .42196 .59287 L F
.42243 .59234 m .42196 .59287 L .42152 .59278 L F
.832 .901 .487 r
.42331 .59071 m .42255 .59221 L .42317 .59151 L F
.979 .775 .558 r
.45776 .59521 m .45786 .59802 L .45646 .59706 L F
.45776 .59521 m .45646 .59706 L .459 .59485 L F
.303 .012 .294 r
.21557 .65051 m .21376 .65118 L .21645 .64849 L F
.201 0 .232 r
.21818 .64766 m .21557 .65051 L .21645 .64849 L F
0 0 0 r
.41744 .59067 m .42196 .58939 L .41898 .58935 L F
.444 .271 .551 r
.25347 .59725 m .25098 .59992 L .25116 .5986 L F
.253 .763 .765 r
.62087 .41414 m .62064 .41409 L .61773 .41489 L F
.102 0 0 r
.62504 .41004 m .62425 .41166 L .62189 .41204 L F
.87 .798 .777 r
.62178 .41205 m .62064 .41409 L .62266 .41085 L F
.102 0 0 r
.62195 .41195 m .62189 .41204 L .62178 .41205 L F
.62504 .41004 m .62189 .41204 L .62195 .41195 L F
.755 .909 .529 r
.62234 .41143 m .62093 .41364 L .62087 .41414 L F
.375 0 .126 r
.62398 .41381 m .62185 .4121 L .62425 .41166 L F
.62185 .4121 m .62178 .41205 L .62189 .41204 L F
.62185 .4121 m .62189 .41204 L .62425 .41166 L F
.755 .909 .529 r
.62093 .41364 m .62064 .41409 L .62066 .41409 L F
.62093 .41364 m .62066 .41409 L .62087 .41414 L F
.62266 .41085 m .62206 .41181 L .62234 .41143 L F
.375 0 .126 r
.62398 .41381 m .62153 .41433 L .62177 .41221 L F
.62185 .4121 m .62177 .41221 L .62178 .41205 L F
.62398 .41381 m .62177 .41221 L .62185 .4121 L F
.755 .909 .529 r
.62206 .41181 m .62199 .41192 L .62234 .41143 L F
.62199 .41192 m .62064 .41409 L .62221 .41163 L F
.62199 .41192 m .62221 .41163 L .62234 .41143 L F
.711 .647 .784 r
.76558 .41434 m .76676 .4177 L .76306 .41734 L F
.678 .533 .681 r
.76702 .42016 m .76306 .41734 L .76676 .4177 L F
.619 .646 .854 r
.76717 .41452 m .76676 .4177 L .76558 .41434 L F
.899 .873 .802 r
.53897 .50345 m .5355 .50545 L .53868 .50257 L F
.53897 .50345 m .53685 .50658 L .5355 .50545 L F
.873 .992 .743 r
.54123 .50033 m .53897 .50345 L .53933 .50138 L F
.84 .991 .856 r
.53933 .50138 m .53897 .50345 L .53868 .50257 L F
.322 .102 .417 r
.23586 .62482 m .23548 .62715 L .23372 .62776 L F
.304 .091 .416 r
.23492 .62953 m .23372 .62776 L .23548 .62715 L F
.23492 .62953 m .23322 .63034 L .23372 .62776 L F
.52 .234 .42 r
.56609 .53065 m .56828 .53197 L .56608 .53226 L F
.56609 .53065 m .56912 .52943 L .56828 .53197 L F
.827 .653 .667 r
.47543 .58294 m .47347 .58604 L .47202 .58375 L F
.682 .934 .967 r
.71623 .45529 m .71744 .45333 L .71526 .45432 L F
.71623 .45529 m .71937 .45383 L .71744 .45333 L F
.567 .423 .645 r
.55145 .5477 m .5518 .55025 L .5493 .55077 L F
.492 .211 .416 r
.5493 .55077 m .55117 .55256 L .5491 .55317 L F
.5493 .55077 m .5518 .55025 L .55117 .55256 L F
.51 .268 .485 r
.59346 .51221 m .59355 .51432 L .59113 .51531 L F
.514 .274 .489 r
.59548 .51182 m .59355 .51432 L .59346 .51221 L F
.871 .68 .642 r
.54681 .67157 m .54542 .67451 L .54823 .67489 L F
.799 .699 .754 r
.54451 .67622 m .54823 .67489 L .54542 .67451 L F
.54451 .67622 m .54619 .67789 L .54823 .67489 L F
.702 .601 .741 r
.44182 .56798 m .44295 .57155 L .44551 .57072 L F
.82 .572 .564 r
.22075 .60011 m .22371 .59812 L .22041 .59772 L F
.22075 .60011 m .22327 .60052 L .22371 .59812 L F
.39 .233 .544 r
.22371 .59812 m .22562 .59744 L .22587 .59484 L F
.332 .12 .435 r
.22371 .59812 m .22504 .59978 L .22562 .59744 L F
.22371 .59812 m .22327 .60052 L .22504 .59978 L F
.92 .972 .773 r
.60808 .43311 m .60782 .43583 L .60942 .4336 L F
.024 .295 .789 r
.5175 .5733 m .51546 .57058 L .51701 .57145 L F
0 0 .478 r
.21408 .60402 m .21508 .60629 L .21407 .60264 L F
.936 .75 .626 r
.45937 .63357 m .463 .63678 L .46232 .63349 L F
0 0 0 r
.463 .63678 m .4656 .63321 L .46232 .63349 L F
.551 .424 .661 r
.57657 .50639 m .57899 .50582 L .57883 .50275 L F
.493 .259 .487 r
.57885 .50804 m .57657 .50639 L .57649 .5087 L F
.57885 .50804 m .57899 .50582 L .57657 .50639 L F
.744 .977 .728 r
.54218 .49852 m .54385 .49755 L .54123 .50033 L F
.746 .981 .746 r
.53933 .50138 m .54218 .49852 L .54123 .50033 L F
.878 .992 .801 r
.59305 .46052 m .59257 .46277 L .59485 .45994 L F
.275 .067 .405 r
.59305 .46052 m .59087 .46432 L .59257 .46277 L F
.799 .829 .875 r
.68763 .45478 m .68464 .45531 L .68737 .453 L F
.665 .795 .944 r
.68999 .45207 m .68763 .45478 L .68737 .453 L F
.68999 .45207 m .69113 .45356 L .68763 .45478 L F
.58 .205 .295 r
.44604 .64198 m .44492 .64423 L .44267 .64259 L F
.472 .134 .312 r
.44901 .64112 m .44492 .64423 L .44604 .64198 L F
.821 .612 .62 r
.21726 .57363 m .21989 .57163 L .21881 .5709 L F
.21726 .57363 m .22046 .57434 L .21989 .57163 L F
.595 .447 .651 r
.22515 .59162 m .22814 .59429 L .22831 .59188 L F
.22515 .59162 m .22587 .59484 L .22814 .59429 L F
.362 .119 .406 r
.45048 .59218 m .45278 .59174 L .45225 .59049 L F
.428 .33 .642 r
.45048 .59218 m .45279 .59414 L .45278 .59174 L F
.362 .119 .406 r
.45048 .59218 m .45278 .59174 L .45225 .59049 L F
.428 .33 .642 r
.45048 .59218 m .45279 .59414 L .45278 .59174 L F
.727 .589 .701 r
.76176 .4115 m .76329 .41554 L .75937 .41437 L F
.753 .598 .685 r
.76329 .41554 m .76134 .41741 L .75937 .41437 L F
.76329 .41554 m .76306 .41734 L .76134 .41741 L F
.602 .523 .738 r
.76558 .41434 m .76329 .41554 L .76176 .4115 L F
.711 .647 .784 r
.76558 .41434 m .76306 .41734 L .76329 .41554 L F
.981 .721 .324 r
.6284 .43454 m .62774 .43431 L .62762 .43176 L F
.536 .92 .921 r
.63016 .43314 m .6284 .43454 L .63121 .43358 L F
.63016 .43314 m .62774 .43431 L .6284 .43454 L F
.96 .876 .709 r
.66831 .4346 m .66866 .43777 L .6689 .43541 L F
.708 .639 .777 r
.66866 .43777 m .67137 .43477 L .6689 .43541 L F
0 0 0 r
.203 .63317 m .2046 .63244 L .20609 .63046 L F
.019 0 .284 r
.20609 .63046 m .20749 .62969 L .20769 .62733 L F
.451 .182 .414 r
.2046 .63244 m .20749 .62969 L .20609 .63046 L F
.484 .052 .142 r
.41592 .6341 m .41802 .63584 L .41955 .63315 L F
.269 0 .036 r
.41955 .63315 m .42077 .63462 L .42194 .63308 L F
.41955 .63315 m .41802 .63584 L .42077 .63462 L F
.729 .439 .488 r
.46732 .58849 m .46374 .58528 L .46505 .58909 L F
.46732 .58849 m .46817 .58659 L .46374 .58528 L F
.737 .309 .234 r
.40254 .64284 m .40123 .64455 L .39936 .6437 L F
.515 .051 .091 r
.4049 .64409 m .40123 .64455 L .40254 .64284 L F
.342 .368 .743 r
.26105 .57155 m .26336 .57351 L .26188 .574 L F
.543 .421 .663 r
.2643 .57675 m .26188 .574 L .26336 .57351 L F
.2643 .57675 m .26211 .57736 L .26188 .574 L F
.755 .588 .016 r
.22075 .57656 m .22083 .57906 L .22093 .57919 L F
.983 .883 .65 r
.22083 .57906 m .22128 .58264 L .22093 .57919 L F
.646 .745 .921 r
.70243 .39732 m .70114 .39971 L .69998 .39802 L F
.70243 .39732 m .70362 .39885 L .70114 .39971 L F
0 .049 .615 r
.65699 .41477 m .6587 .41799 L .65834 .41609 L F
0 0 .142 r
.65834 .41609 m .6587 .41799 L .65858 .41727 L F
.691 .318 0 r
.6587 .41799 m .65869 .41819 L .65858 .41727 L F
.6587 .41799 m .65953 .4198 L .65869 .41819 L F
.243 0 .279 r
.21291 .65325 m .21121 .65411 L .21376 .65118 L F
0 0 0 r
.21557 .65051 m .21291 .65325 L .21376 .65118 L F
.905 .937 .821 r
.53348 .50887 m .53458 .50966 L .53144 .51363 L F
.883 .877 .824 r
.5355 .50545 m .53458 .50966 L .53432 .50727 L F
.5355 .50545 m .53685 .50658 L .53458 .50966 L F
.917 .933 .804 r
.53432 .50727 m .53458 .50966 L .53348 .50887 L F
.911 .875 .445 r
.60941 .41741 m .61012 .41304 L .61015 .41509 L F
.817 .834 .863 r
.76006 .41214 m .75886 .41097 L .75781 .40894 L F
.76006 .41214 m .76176 .4115 L .75886 .41097 L F
.85 .798 .8 r
.75886 .41097 m .76176 .4115 L .75937 .41437 L F
.602 .523 .738 r
.76558 .41434 m .76176 .4115 L .76495 .41068 L F
.745 .611 .709 r
.55616 .50912 m .55856 .50948 L .55845 .50674 L F
.674 .39 .483 r
.55605 .51189 m .55856 .50948 L .55616 .50912 L F
.55605 .51189 m .5584 .51155 L .55856 .50948 L F
.784 .695 .766 r
.55856 .50948 m .56076 .50589 L .55845 .50674 L F
0 0 0 r
.59619 .45811 m .59305 .46052 L .59485 .45994 L F
.72 .222 .052 r
.66741 .43071 m .6681 .42939 L .66804 .42727 L F
.66741 .43071 m .66985 .43143 L .6681 .42939 L F
.059 0 .238 r
.63095 .40413 m .62911 .40621 L .63109 .40289 L F
0 0 0 r
.63095 .40413 m .62807 .40734 L .62911 .40621 L F
.332 0 0 r
.63071 .40077 m .63035 .40056 L .62841 .40038 L F
.157 0 0 r
.62628 .40191 m .63071 .40077 L .62837 .40037 L F
.332 0 0 r
.63071 .40077 m .62841 .40038 L .62725 .40027 L F
.157 0 0 r
.62837 .40037 m .63071 .40077 L .62854 .40025 L F
.332 0 0 r
.63071 .40077 m .62725 .40027 L .62854 .40025 L F
.235 0 .203 r
.22887 .58248 m .23115 .58188 L .23158 .57955 L F
.14 0 .273 r
.23158 .57955 m .23304 .57983 L .23354 .57675 L F
0 0 .031 r
.23115 .58188 m .23304 .57983 L .23158 .57955 L F
.627 .949 .942 r
.26707 .55664 m .26606 .55641 L .26778 .55534 L F
.69 .946 .67 r
.26778 .55534 m .26494 .55829 L .26707 .55664 L F
.901 .754 .257 r
.60227 .44124 m .60174 .44287 L .60213 .44389 L F
0 0 0 r
.60492 .43844 m .60401 .43993 L .60227 .44124 L F
.60401 .43993 m .60174 .44287 L .60227 .44124 L F
.733 .435 .475 r
.43663 .64222 m .43294 .64406 L .43411 .64229 L F
.275 .743 .944 r
.22303 .54162 m .2252 .54148 L .22687 .54201 L F
.379 .779 .985 r
.2252 .54148 m .22906 .54196 L .22687 .54201 L F
.605 .442 .635 r
.40116 .62392 m .39832 .62117 L .40143 .62204 L F
.648 .41 .545 r
.40432 .62126 m .40116 .62392 L .40143 .62204 L F
.917 .91 .798 r
.58066 .47525 m .57971 .47942 L .58176 .47627 L F
.875 .911 .85 r
.58298 .4723 m .58066 .47525 L .58176 .47627 L F
.355 0 0 r
.19748 .66749 m .20039 .66767 L .20123 .66638 L F
.953 .614 .329 r
.20039 .66767 m .20228 .66896 L .20123 .66638 L F
.63 .855 .985 r
.18854 .66267 m .18917 .66093 L .18683 .66146 L F
.18854 .66267 m .19017 .66177 L .18917 .66093 L F
0 .321 .697 r
.39665 .64252 m .39819 .64308 L .39608 .64278 L F
.39665 .64252 m .39936 .6437 L .39819 .64308 L F
.655 .97 .887 r
.73284 .40916 m .73425 .4092 L .73631 .40779 L F
.894 .827 .773 r
.5739 .48459 m .57743 .48256 L .57613 .4813 L F
.5739 .48459 m .57533 .48605 L .57743 .48256 L F
.883 .866 .818 r
.57613 .4813 m .57743 .48256 L .57971 .47942 L F
.345 .054 .32 r
.25575 .58943 m .2551 .59142 L .25312 .59197 L F
.528 .27 .468 r
.25801 .5888 m .2551 .59142 L .25575 .58943 L F
.799 .728 .786 r
.55725 .50512 m .55504 .50651 L .55845 .50674 L F
.745 .611 .709 r
.55616 .50912 m .55845 .50674 L .55504 .50651 L F
.727 .712 .836 r
.55725 .50512 m .55845 .50674 L .56076 .50589 L F
0 0 .277 r
.73492 .42308 m .73563 .42414 L .73529 .42348 L F
.73492 .42308 m .73462 .42644 L .73563 .42414 L F
.238 .588 .947 r
.19922 .67614 m .20083 .6766 L .20123 .67748 L F
.261 .093 .455 r
.20239 .67949 m .20123 .67748 L .20083 .6766 L F
.20239 .67949 m .20086 .68048 L .20123 .67748 L F
.883 .866 .818 r
.57613 .4813 m .57971 .47942 L .57854 .47845 L F
.917 .91 .798 r
.58066 .47525 m .57854 .47845 L .57971 .47942 L F
0 0 .442 r
.63217 .40092 m .63095 .40413 L .63109 .40289 L F
0 0 .355 r
.40089 .62652 m .40129 .62903 L .40079 .63019 L F
.787 .299 .054 r
.40079 .63019 m .40231 .63247 L .40395 .63272 L F
0 .017 .583 r
.40129 .62903 m .40231 .63247 L .40079 .63019 L F
.434 .223 .491 r
.48767 .58076 m .49023 .57998 L .4903 .57705 L F
.116 .527 .914 r
.4903 .57705 m .49111 .57638 L .48898 .5757 L F
.115 0 .403 r
.4903 .57705 m .49023 .57998 L .49174 .57675 L F
.29 0 0 r
.21156 .65532 m .21121 .65411 L .21291 .65325 L F
.21156 .65532 m .20909 .65567 L .21121 .65411 L F
.314 0 .088 r
.39548 .58506 m .39862 .58328 L .39636 .58389 L F
0 .533 .711 r
.52348 .58313 m .5255 .5833 L .52373 .58315 L F
.876 .445 .046 r
.5255 .5833 m .52519 .58469 L .52373 .58315 L F
0 .055 .61 r
.52373 .58315 m .5246 .58337 L .52445 .58319 L F
.52373 .58315 m .52445 .58319 L .52283 .58133 L F
0 .533 .711 r
.52175 .58299 m .52348 .58313 L .52373 .58315 L F
.876 .445 .046 r
.5255 .5833 m .52672 .586 L .52519 .58469 L F
.533 .539 .807 r
.2619 .56787 m .26298 .57098 L .26105 .57155 L F
.487 .376 .653 r
.26298 .57098 m .26336 .57351 L .26105 .57155 L F
.597 .598 .823 r
.43323 .56902 m .43645 .57295 L .43563 .56816 L F
.39 .541 .886 r
.43761 .57381 m .43919 .57354 L .43645 .57295 L F
.43761 .57381 m .43919 .57354 L .43645 .57295 L F
.784 .914 .928 r
.73027 .43718 m .72731 .43761 L .72931 .43529 L F
.682 .764 .913 r
.73214 .43384 m .73027 .43718 L .72931 .43529 L F
.73214 .43384 m .73349 .4356 L .73027 .43718 L F
.235 .472 .882 r
.75297 .40605 m .75502 .40711 L .75286 .40424 L F
.019 0 .115 r
.46969 .58549 m .46817 .58659 L .46732 .58849 L F
.46969 .58549 m .46817 .58659 L .46732 .58849 L F
.882 .808 .771 r
.57162 .48763 m .57202 .49059 L .57283 .48866 L F
.891 .898 .827 r
.5739 .48459 m .57283 .48866 L .57533 .48605 L F
.5739 .48459 m .57162 .48763 L .57283 .48866 L F
.557 .48 .723 r
.39916 .62533 m .3965 .62737 L .39581 .62404 L F
.39916 .62533 m .39882 .62688 L .3965 .62737 L F
.611 .896 .988 r
.71041 .45594 m .71066 .45662 L .71296 .45561 L F
.702 .601 .741 r
.44182 .56798 m .44551 .57072 L .44428 .56728 L F
.654 .609 .792 r
.44428 .56728 m .44551 .57072 L .44763 .56809 L F
.985 .887 .641 r
.22041 .59367 m .22041 .59772 L .21995 .59534 L F
.65 .717 .897 r
.6688 .40701 m .66603 .40835 L .66489 .40485 L F
.778 .594 .651 r
.47064 .57388 m .46764 .5759 L .46679 .57482 L F
.645 .634 .825 r
.47232 .56976 m .47352 .57293 L .47064 .57388 L F
.647 .645 .834 r
.47352 .57293 m .47437 .57436 L .47064 .57388 L F
.88 .968 .845 r
.52882 .51722 m .52534 .51939 L .52816 .51685 L F
.584 .049 0 r
.46028 .59761 m .45646 .59706 L .45786 .59802 L F
.985 .844 .62 r
.65074 .43695 m .65277 .43476 L .65185 .43385 L F
.65074 .43695 m .65186 .43776 L .65277 .43476 L F
.989 .763 .502 r
.66094 .4258 m .66198 .42963 L .66112 .42866 L F
.965 .862 .687 r
.66198 .42963 m .66007 .43054 L .66112 .42866 L F
.66198 .42963 m .6612 .43193 L .66007 .43054 L F
.405 .206 .494 r
.23806 .62163 m .2378 .62426 L .23586 .62482 L F
.221 .018 .379 r
.23702 .62627 m .23586 .62482 L .2378 .62426 L F
.23702 .62627 m .23548 .62715 L .23586 .62482 L F
.927 .858 .753 r
.65146 .4408 m .65182 .44394 L .65281 .44175 L F
.096 .252 .735 r
.42829 .58462 m .42961 .58802 L .42726 .58579 L F
.9 .69 .181 r
.53265 .5767 m .5326 .57918 L .53314 .5804 L F
.598 .438 .635 r
.39832 .62117 m .39916 .62533 L .39581 .62404 L F
.783 .694 .766 r
.6688 .40701 m .67198 .40843 L .67184 .40512 L F
.689 .621 .775 r
.67435 .40569 m .67198 .40843 L .67184 .40512 L F
.165 .603 .936 r
.67222 .40831 m .67198 .40843 L .6688 .40701 L F
.722 .972 .73 r
.54599 .49431 m .547 .49256 L .5487 .49159 L F
.715 .985 .885 r
.54531 .49397 m .547 .49256 L .54599 .49431 L F
.857 .997 .79 r
.54403 .49514 m .54599 .49431 L .54385 .49755 L F
.54403 .49514 m .54531 .49397 L .54599 .49431 L F
.749 .563 .643 r
.76306 .41734 m .7611 .42025 L .76134 .41741 L F
.75 .564 .644 r
.76306 .41734 m .76473 .42103 L .7611 .42025 L F
.678 .533 .681 r
.76702 .42016 m .76473 .42103 L .76306 .41734 L F
.5 .186 .366 r
.16908 .55976 m .16749 .56237 L .16592 .56213 L F
0 0 0 r
.1696 .56073 m .16908 .55976 L .17114 .55919 L F
.1696 .56073 m .16749 .56237 L .16908 .55976 L F
.853 .998 .8 r
.60522 .42394 m .60281 .42683 L .60335 .4246 L F
.851 .953 .604 r
.60335 .4246 m .60281 .42683 L .60175 .42828 L F
.974 .83 .64 r
.51259 .56277 m .51057 .56412 L .51236 .56101 L F
.51259 .56277 m .51185 .56525 L .51057 .56412 L F
.748 .683 .789 r
.57466 .62706 m .57573 .63044 L .57849 .62738 L F
.926 .764 .662 r
.57409 .62952 m .57573 .63044 L .57466 .62706 L F
0 0 0 r
.5504 .48808 m .5497 .48986 L .55003 .48732 L F
.719 .969 .934 r
.5504 .48808 m .55003 .48732 L .55112 .48624 L F
.681 .938 .965 r
.74835 .41998 m .74767 .41924 L .74988 .41794 L F
.574 .245 .374 r
.56111 .53798 m .56143 .53607 L .56367 .53775 L F
.48 .284 .537 r
.56367 .53775 m .56143 .53607 L .5637 .53531 L F
.786 .572 .61 r
.42907 .63508 m .43195 .6364 L .43168 .63348 L F
.611 .933 .961 r
.43168 .63348 m .43042 .63316 L .43271 .63208 L F
.505 .307 .545 r
.43271 .63208 m .43042 .63316 L .43168 .63348 L F
.519 .374 .624 r
.43168 .63348 m .43195 .6364 L .43422 .63569 L F
.843 .643 .633 r
.60213 .44389 m .60069 .44668 L .60367 .44713 L F
.743 .474 .523 r
.59997 .44906 m .60367 .44713 L .60069 .44668 L F
.59997 .44906 m .60375 .44943 L .60367 .44713 L F
.799 .978 .902 r
.7258 .4484 m .72626 .44926 L .72949 .44665 L F
.63 .246 .297 r
.42194 .63308 m .42448 .63347 L .42556 .63246 L F
.7 .777 .911 r
.66231 .40804 m .6602 .4093 L .65892 .40757 L F
.197 0 .081 r
.41167 .60648 m .41063 .60592 L .41239 .60484 L F
.192 0 0 r
.41322 .60666 m .41167 .60648 L .41239 .60484 L F
.448 .8 .997 r
.46597 .63666 m .46443 .63585 L .463 .63678 L F
.719 .982 .905 r
.46189 .63849 m .46283 .63662 L .46443 .63585 L F
.558 .353 .558 r
.46443 .63585 m .46457 .63834 L .46189 .63849 L F
.675 .154 0 r
.46283 .63662 m .46439 .63705 L .46443 .63585 L F
.504 .312 .553 r
.46443 .63585 m .46457 .63834 L .46671 .63769 L F
.675 .154 0 r
.46439 .63705 m .46671 .63769 L .46443 .63585 L F
0 0 0 r
.46448 .63475 m .46443 .63585 L .4656 .63321 L F
.463 .63678 m .46443 .63585 L .46448 .63475 L F
.658 .378 .485 r
.46443 .63585 m .46796 .63293 L .4656 .63321 L F
.376 .576 .918 r
.38635 .63606 m .38563 .63293 L .38378 .6334 L F
.38635 .63606 m .38785 .63563 L .38563 .63293 L F
.416 .196 .47 r
.36604 .60081 m .36809 .60026 L .36843 .59791 L F
.502 .371 .634 r
.36617 .60342 m .36809 .60026 L .36604 .60081 L F
.559 .688 .926 r
.73904 .40288 m .73543 .40061 L .73771 .40157 L F
.961 .827 .664 r
.73818 .40503 m .73904 .40288 L .73771 .40157 L F
.602 .181 .215 r
.44267 .64259 m .44492 .64423 L .44251 .64394 L F
.415 .702 .981 r
.26057 .55077 m .26005 .55243 L .25683 .55025 L F
.26057 .55077 m .26206 .55224 L .26005 .55243 L F
.812 .717 .761 r
.64383 .44742 m .64573 .44595 L .64517 .44439 L F
.268 0 0 r
.20797 .55243 m .20586 .55246 L .20374 .5521 L F
.271 0 0 r
.20797 .55243 m .20978 .5528 L .20586 .55246 L F
.353 0 0 r
.43364 .57444 m .4356 .57522 L .43761 .57381 L F
.215 0 .111 r
.43761 .57381 m .43628 .5758 L .43919 .57354 L F
.988 .883 .627 r
.43628 .5758 m .4356 .57522 L .43761 .57381 L F
.215 0 .111 r
.43919 .57354 m .43628 .5758 L .43761 .57381 L F
.988 .883 .627 r
.43761 .57381 m .4356 .57522 L .43628 .5758 L F
.43761 .57381 m .4356 .57522 L .43628 .5758 L F
.403 .242 .546 r
.24644 .61153 m .24466 .60983 L .24668 .60921 L F
.24644 .61153 m .2446 .61236 L .24466 .60983 L F
.708 .639 .777 r
.66866 .43777 m .67265 .4384 L .67137 .43477 L F
.727 .712 .836 r
.55725 .50512 m .56076 .50589 L .5595 .50256 L F
.795 .716 .777 r
.5595 .50256 m .56076 .50589 L .56305 .50289 L F
.578 .793 .981 r
.66715 .40365 m .66738 .40452 L .66648 .40391 L F
.642 .149 .064 r
.6673 .40217 m .67124 .40269 L .6701 .40366 L F
.6673 .40217 m .6701 .40366 L .66953 .40365 L F
.6673 .40217 m .66985 .40387 L .66738 .40452 L F
.591 .598 .828 r
.66736 .4039 m .66903 .39968 L .6673 .40217 L F
.66738 .40452 m .66766 .4037 L .66736 .4039 L F
.66766 .4037 m .66903 .39968 L .66736 .4039 L F
.66738 .40452 m .66985 .40387 L .66903 .39968 L F
.413 .863 .843 r
.66727 .40309 m .66899 .40282 L .66648 .40391 L F
.66899 .40282 m .66967 .40271 L .66847 .40316 L F
.66899 .40282 m .66847 .40316 L .66648 .40391 L F
.578 .793 .981 r
.66967 .40271 m .66847 .40365 L .66715 .40365 L F
.66847 .40365 m .66738 .40452 L .66715 .40365 L F
.642 .149 .064 r
.66953 .40365 m .6701 .40366 L .66985 .40387 L F
.084 .105 .584 r
.67124 .40269 m .67184 .40512 L .67276 .40546 L F
.808 .373 .21 r
.66985 .40387 m .67124 .40269 L .67276 .40546 L F
.902 .959 .821 r
.19755 .70446 m .19666 .70346 L .19573 .70468 L F
.869 .501 .01 r
.19602 .70134 m .19673 .70354 L .19697 .70327 L F
.565 .387 .599 r
.19573 .70468 m .19666 .70346 L .1978 .7023 L F
.19573 .70468 m .1967 .70357 L .19566 .70476 L F
.1967 .70357 m .1978 .7023 L .19635 .70396 L F
.1967 .70357 m .19635 .70396 L .19566 .70476 L F
.869 .501 .01 r
.19602 .70134 m .19666 .70346 L .19673 .70354 L F
.19697 .70327 m .19673 .70354 L .19755 .70446 L F
.902 .959 .821 r
.19755 .70446 m .19573 .70468 L .19734 .70701 L F
.909 .843 .767 r
.66275 .44484 m .66058 .44509 L .66341 .44232 L F
.66275 .44484 m .66159 .44681 L .66058 .44509 L F
.546 .88 .989 r
.47399 .63294 m .47014 .6334 L .47184 .63374 L F
.926 .972 .706 r
.54218 .49852 m .54403 .49514 L .54385 .49755 L F
.192 .694 .91 r
.4597 .56574 m .46256 .56578 L .4634 .56611 L F
.69 .949 .957 r
.4634 .56611 m .4644 .56461 L .46596 .56516 L F
.4634 .56611 m .46256 .56578 L .4644 .56461 L F
.741 .74 .851 r
.64835 .44342 m .65182 .44394 L .65146 .4408 L F
.777 .671 .746 r
.64959 .44693 m .65182 .44394 L .64835 .44342 L F
0 .192 .615 r
.66814 .39991 m .66802 .39986 L .66608 .3986 L F
.939 .748 .619 r
.66608 .3986 m .66802 .39986 L .6673 .40217 L F
.706 .911 .559 r
.74546 .43473 m .74771 .43165 L .74514 .43213 L F
.973 .861 .468 r
.51091 .6866 m .50982 .68847 L .51039 .68611 L F
.51039 .68611 m .50982 .68847 L .51091 .6866 L F
.808 .684 .727 r
.41063 .60592 m .40735 .60639 L .40959 .60396 L F
.721 .38 .401 r
.41063 .60592 m .40903 .60842 L .40735 .60639 L F
.197 0 .081 r
.41167 .60648 m .40903 .60842 L .41063 .60592 L F
.851 .514 0 r
.65953 .4198 m .66088 .42339 L .66028 .42142 L F
.991 .732 .408 r
.66088 .42339 m .65984 .42474 L .66028 .42142 L F
.66088 .42339 m .66094 .4258 L .65984 .42474 L F
.849 .797 .8 r
.75937 .41437 m .75646 .41373 L .75886 .41097 L F
.824 .625 .633 r
.75937 .41437 m .75592 .41603 L .75646 .41373 L F
.75937 .41437 m .75784 .41715 L .75592 .41603 L F
.791 .58 .615 r
.75937 .41437 m .76134 .41741 L .75784 .41715 L F
.417 .304 .618 r
.2552 .59395 m .25312 .59197 L .2551 .59142 L F
.2552 .59395 m .2534 .59465 L .25312 .59197 L F
.574 .573 .814 r
.75899 .42566 m .75643 .42701 L .75491 .42269 L F
.477 .043 .136 r
.38127 .59142 m .38391 .59134 L .38502 .58977 L F
.324 0 .047 r
.38502 .58977 m .38692 .59013 L .38746 .58947 L F
.38502 .58977 m .38391 .59134 L .38692 .59013 L F
.347 0 0 r
.37081 .62862 m .37318 .62859 L .37466 .62691 L F
.537 .658 .913 r
.37466 .62691 m .3749 .62401 L .37302 .62427 L F
.37466 .62691 m .37706 .62653 L .3749 .62401 L F
.75 .9 .945 r
.69004 .46435 m .69304 .46397 L .69221 .46294 L F
.643 .874 .984 r
.69221 .46294 m .69304 .46397 L .69479 .46294 L F
.408 .334 .662 r
.52985 .56494 m .53238 .56428 L .53031 .56305 L F
.339 .134 .449 r
.52985 .56494 m .53064 .56547 L .53238 .56428 L F
.237 .167 .572 r
.53031 .56305 m .53064 .56547 L .52985 .56494 L F
.88 .754 .718 r
.63279 .45795 m .63375 .46131 L .63465 .45925 L F
0 0 0 r
.41817 .57341 m .41966 .57285 L .42122 .57143 L F
.42122 .57143 m .42244 .57052 L .4231 .57014 L F
.42122 .57143 m .41966 .57285 L .42244 .57052 L F
.908 .887 .8 r
.51763 .53298 m .51415 .53521 L .51649 .53232 L F
.51763 .53298 m .51552 .53612 L .51415 .53521 L F
.643 .917 .979 r
.51763 .53298 m .51649 .53232 L .5186 .5313 L F
.597 .719 .93 r
.70611 .4087 m .70754 .4062 L .70504 .40693 L F
.70611 .4087 m .70861 .40805 L .70754 .4062 L F
.307 .128 .468 r
.23354 .57675 m .23544 .57625 L .23651 .57181 L F
.456 .221 .468 r
.23304 .57983 m .23544 .57625 L .23354 .57675 L F
.797 .712 .771 r
.56189 .49958 m .5595 .50256 L .56305 .50289 L F
.809 .718 .764 r
.56189 .49958 m .56305 .50289 L .56365 .50078 L F
0 0 0 r
.21508 .59773 m .21486 .5988 L .21559 .59642 L F
.21508 .59773 m .21389 .60032 L .21486 .5988 L F
.638 .466 .634 r
.67652 .44578 m .6802 .44673 L .67667 .44493 L F
.135 0 0 r
.48743 .57176 m .48794 .57189 L .48907 .57199 L F
.767 .257 0 r
.48855 .57205 m .48794 .57189 L .48855 .57164 L F
0 0 .234 r
.49111 .57638 m .49193 .57658 L .49156 .57295 L F
.77 .361 .278 r
.48794 .57189 m .49193 .57658 L .49156 .57295 L F
.767 .257 0 r
.48856 .5738 m .49193 .57658 L .48794 .57189 L F
.48856 .5738 m .48794 .57189 L .48855 .57205 L F
.135 0 0 r
.48471 .57138 m .48794 .57189 L .48743 .57176 L F
.976 .73 .496 r
.51163 .55658 m .51004 .558 L .51052 .55517 L F
.51163 .55658 m .5115 .55886 L .51004 .558 L F
.684 .447 .558 r
.57707 .5269 m .5745 .52894 L .57463 .52713 L F
.7 .914 .968 r
.68413 .46488 m .68756 .46439 L .68639 .46366 L F
.298 .729 .969 r
.68756 .46439 m .69004 .46435 L .68639 .46366 L F
.81 .591 .605 r
.66717 .45533 m .67058 .4561 L .66771 .45265 L F
.712 .588 .715 r
.66771 .45265 m .67058 .4561 L .6729 .45318 L F
.781 .986 .897 r
.63387 .43283 m .63672 .43164 L .63639 .43093 L F
.968 .81 .385 r
.64263 .42544 m .64335 .42583 L .64287 .42943 L F
.501 .114 .238 r
.43068 .58858 m .42724 .59078 L .42865 .59104 L F
.244 .356 .779 r
.44763 .56809 m .44884 .57153 L .45006 .57006 L F
.474 .7 .968 r
.44884 .57153 m .4519 .57172 L .45006 .57006 L F
0 0 0 r
.68293 .46342 m .6839 .46191 L .68134 .46508 L F
.913 .859 .416 r
.68365 .46106 m .6839 .46191 L .68293 .46342 L F
.798 .701 .758 r
.43185 .5677 m .43563 .56816 L .43416 .56716 L F
.43185 .5677 m .43323 .56902 L .43563 .56816 L F
.661 .598 .775 r
.40628 .60107 m .40798 .60522 L .40959 .60396 L F
.868 .545 .03 r
.51993 .57517 m .51965 .5755 L .5175 .5733 L F
.51993 .57517 m .5204 .57697 L .51965 .5755 L F
.481 .734 .982 r
.68134 .46508 m .68413 .46488 L .68293 .46342 L F
.33 .377 .76 r
.61228 .45891 m .61518 .461 L .61471 .45829 L F
.869 .976 .85 r
.58835 .46683 m .58662 .47022 L .58931 .46667 L F
.535 .921 .805 r
.5903 .46556 m .58931 .46667 L .59087 .46432 L F
.5903 .46556 m .58835 .46683 L .58931 .46667 L F
.905 .937 .821 r
.53348 .50887 m .53144 .51363 L .53052 .51202 L F
.476 .127 .294 r
.19987 .63574 m .20226 .63545 L .203 .63317 L F
.284 0 .219 r
.203 .63317 m .20422 .63478 L .2046 .63244 L F
.203 .63317 m .20226 .63545 L .20422 .63478 L F
.759 .995 .823 r
.60599 .43649 m .60492 .43844 L .60782 .43583 L F
0 0 0 r
.60527 .43832 m .60492 .43844 L .60599 .43649 L F
.60527 .43832 m .60401 .43993 L .60492 .43844 L F
.519 .542 .82 r
.21529 .57417 m .21726 .57363 L .21475 .56904 L F
.275 .196 .583 r
.21529 .57417 m .21735 .57455 L .21726 .57363 L F
.21529 .57417 m .2158 .5769 L .21735 .57455 L F
.737 .933 .596 r
.71912 .44355 m .71907 .44316 L .72144 .43996 L F
.76 .528 .582 r
.57533 .62468 m .57466 .62706 L .57849 .62738 L F
.796 .567 .591 r
.57121 .62655 m .57533 .62468 L .57134 .62404 L F
.57121 .62655 m .57466 .62706 L .57533 .62468 L F
.407 .188 .466 r
.2405 .61865 m .24008 .62105 L .23806 .62163 L F
.38 .185 .486 r
.23965 .6235 m .23806 .62163 L .24008 .62105 L F
.23965 .6235 m .2378 .62426 L .23806 .62163 L F
.571 .838 .995 r
.69269 .39666 m .69133 .39854 L .69021 .39747 L F
.69269 .39666 m .69417 .39785 L .69133 .39854 L F
0 .091 .607 r
.46382 .5928 m .46524 .59447 L .46261 .59202 L F
.49 .372 .645 r
.46261 .59202 m .46524 .59447 L .46295 .59498 L F
0 .091 .607 r
.46382 .5928 m .46261 .59202 L .46295 .59498 L F
.562 .488 .729 r
.55967 .62765 m .56114 .62356 L .55877 .62445 L F
.55967 .62765 m .56229 .62703 L .56114 .62356 L F
.568 .517 .758 r
.55967 .62765 m .56292 .62937 L .56229 .62703 L F
.489 .595 .886 r
.26409 .55201 m .26302 .5544 L .26206 .55224 L F
.747 .956 .941 r
.18701 .64215 m .18291 .64408 L .18416 .6421 L F
.257 0 0 r
.18737 .64294 m .18701 .64215 L .18416 .6421 L F
.18737 .64294 m .18921 .64215 L .18701 .64215 L F
.855 .863 .846 r
.66833 .44932 m .66582 .4522 L .66745 .45298 L F
.952 .709 .534 r
.66582 .4522 m .66717 .45533 L .66745 .45298 L F
.81 .591 .605 r
.66717 .45533 m .66771 .45265 L .66745 .45298 L F
.596 .55 .773 r
.67652 .44578 m .67784 .4479 L .6802 .44673 L F
.734 .732 .85 r
.70557 .44929 m .70345 .45087 L .70192 .44898 L F
0 0 0 r
.4055 .60561 m .4031 .60682 L .40406 .60622 L F
.57 .752 .963 r
.74616 .41847 m .74546 .42213 L .7443 .41913 L F
.74643 .41852 m .74546 .42213 L .74616 .41847 L F
.859 .978 .678 r
.74647 .41835 m .74462 .42167 L .74546 .42213 L F
.588 .733 .944 r
.74297 .41775 m .7443 .41913 L .74156 .41987 L F
.577 .256 .389 r
.74527 .42051 m .74326 .42159 L .74462 .42167 L F
.74435 .42053 m .74326 .42159 L .74527 .42051 L F
.74564 .41919 m .74326 .42159 L .74631 .41863 L F
.74631 .41863 m .74435 .42053 L .74527 .42051 L F
.74647 .41835 m .74564 .41919 L .74631 .41863 L F
.74647 .41835 m .74542 .42104 L .74326 .42159 L F
.753 .265 0 r
.7451 .42143 m .74542 .42104 L .74401 .42053 L F
.74343 .42055 m .74401 .42053 L .7422 .41989 L F
.7451 .42143 m .74401 .42053 L .74343 .42055 L F
.728 .392 .41 r
.7422 .41989 m .74401 .42053 L .74308 .4179 L F
.74401 .42053 m .74542 .42104 L .74465 .42001 L F
.74401 .42053 m .74465 .42001 L .74308 .4179 L F
.74292 .41787 m .74308 .4179 L .74297 .41775 L F
.7422 .41989 m .74308 .4179 L .74292 .41787 L F
.57 .752 .963 r
.74647 .41835 m .74643 .41852 L .74616 .41847 L F
.378 .157 .448 r
.36843 .59791 m .3704 .59727 L .37069 .59497 L F
.516 .335 .573 r
.36809 .60026 m .3704 .59727 L .36843 .59791 L F
.576 .548 .787 r
.75592 .41603 m .75482 .4202 L .7548 .4164 L F
.75592 .41603 m .75727 .41965 L .75482 .4202 L F
.512 .309 .542 r
.75727 .41965 m .75491 .42269 L .75482 .4202 L F
.766 .493 .521 r
.53064 .69747 m .53435 .69536 L .53193 .69813 L F
.166 .658 .919 r
.53193 .69813 m .5346 .6983 L .53064 .69747 L F
.92 .796 .707 r
.55303 .5066 m .55554 .50928 L .55504 .50651 L F
.863 .871 .843 r
.55095 .51041 m .55554 .50928 L .55303 .5066 L F
.55095 .51041 m .55239 .5116 L .55554 .50928 L F
.721 .676 .805 r
.55554 .50928 m .55616 .50912 L .55504 .50651 L F
.67 .436 .558 r
.55239 .5116 m .55616 .50912 L .55554 .50928 L F
.79 .673 .734 r
.7611 .42025 m .7621 .42372 L .75926 .42303 L F
.603 .49 .697 r
.7621 .42372 m .75899 .42566 L .75926 .42303 L F
.712 .629 .762 r
.76465 .42319 m .7621 .42372 L .7611 .42025 L F
.701 .568 .702 r
.76465 .42319 m .76217 .42649 L .7621 .42372 L F
.67 .436 .558 r
.55239 .5116 m .55605 .51189 L .55616 .50912 L F
.922 .677 .55 r
.50886 .54443 m .50877 .54081 L .51061 .54218 L F
.50886 .54443 m .50681 .54119 L .50877 .54081 L F
.50886 .54443 m .50695 .54392 L .50681 .54119 L F
.886 .676 .614 r
.50886 .54443 m .50655 .54635 L .50695 .54392 L F
.50886 .54443 m .5083 .54756 L .50655 .54635 L F
.53 .197 .348 r
.45225 .59049 m .45278 .59174 L .45517 .59113 L F
.45517 .59113 m .45278 .59174 L .45225 .59049 L F
.732 .26 .127 r
.56115 .51362 m .56182 .51254 L .5584 .51155 L F
.67 .186 .092 r
.56115 .51362 m .56417 .51425 L .56182 .51254 L F
.703 .436 .516 r
.47221 .63109 m .47399 .63294 L .47398 .63027 L F
.511 .315 .551 r
.47399 .63294 m .47614 .62954 L .47398 .63027 L F
.434 .315 .618 r
.5491 .55317 m .54941 .55567 L .54742 .55616 L F
.475 .37 .656 r
.54941 .55567 m .54777 .55902 L .54742 .55616 L F
.853 .973 .868 r
.58298 .4723 m .58662 .47022 L .58581 .46955 L F
.58298 .4723 m .58301 .47359 L .58662 .47022 L F
.869 .976 .85 r
.58835 .46683 m .58581 .46955 L .58662 .47022 L F
.902 .767 .703 r
.61254 .46475 m .61137 .46576 L .6129 .46392 L F
.61254 .46475 m .61198 .46673 L .60998 .46668 L F
.61254 .46475 m .60998 .46668 L .61137 .46576 L F
0 0 0 r
.41817 .57341 m .41759 .57383 L .41966 .57285 L F
.43 .464 .794 r
.4145 .58861 m .41561 .59025 L .41341 .58866 L F
.697 .399 .467 r
.41561 .59025 m .41514 .59119 L .41341 .58866 L F
.51 .212 .397 r
.58032 .52366 m .5826 .52467 L .57971 .52536 L F
.58032 .52366 m .5828 .5233 L .5826 .52467 L F
.406 .791 .99 r
.22906 .54196 m .23118 .54164 L .23284 .54241 L F
.369 .733 .989 r
.23346 .54121 m .23284 .54241 L .23118 .54164 L F
.23346 .54121 m .23515 .54227 L .23284 .54241 L F
.667 .7 .871 r
.43807 .56707 m .44182 .56798 L .44025 .56522 L F
.796 .303 .006 r
.20169 .67051 m .20228 .66896 L .20039 .66767 L F
.388 .222 .531 r
.2034 .67081 m .2042 .67163 L .20591 .6704 L F
.37 .192 .505 r
.20591 .6704 m .2042 .67163 L .2034 .67081 L F
.138 .186 .65 r
.20228 .66896 m .2042 .67163 L .2034 .67081 L F
.796 .303 .006 r
.20169 .67051 m .2042 .67163 L .20228 .66896 L F
.677 .687 .852 r
.56732 .63363 m .56964 .63302 L .56868 .63 L F
.83 .693 .713 r
.65989 .4346 m .66145 .43677 L .66015 .43646 L F
.155 .13 .575 r
.66145 .43677 m .66238 .44064 L .66398 .43799 L F
.66145 .43677 m .66398 .43799 L .66015 .43646 L F
.578 .885 .991 r
.28734 .75945 m .28681 .76085 L .28899 .76024 L F
.28734 .75945 m .28518 .76024 L .28681 .76085 L F
.28734 .75945 m .28681 .76085 L .28899 .76024 L F
.28734 .75945 m .28518 .76024 L .28681 .76085 L F
.605 .181 0 r
.63917 .41665 m .64123 .41982 L .63951 .41901 L F
.904 .72 .644 r
.64123 .41982 m .64063 .42328 L .63951 .41901 L F
.805 .972 .671 r
.43803 .56357 m .43898 .56139 L .43973 .56313 L F
.712 .629 .762 r
.76465 .42319 m .7611 .42025 L .76473 .42103 L F
.618 .453 .637 r
.76465 .42319 m .76537 .42603 L .76217 .42649 L F
.7 .599 .74 r
.76702 .42016 m .76465 .42319 L .76473 .42103 L F
.555 .397 .621 r
.76702 .42016 m .76755 .42271 L .76465 .42319 L F
.354 .168 .484 r
.76755 .42271 m .76537 .42603 L .76465 .42319 L F
.377 .235 .558 r
.55362 .54699 m .5518 .55025 L .55145 .5477 L F
.678 .92 .973 r
.61768 .45779 m .61471 .45829 L .61738 .45801 L F
.524 .919 .852 r
.61908 .45655 m .61768 .45779 L .61738 .45801 L F
.61908 .45655 m .62155 .45593 L .61768 .45779 L F
0 0 0 r
.60174 .44287 m .60069 .44668 L .60213 .44389 L F
.74604 .43734 m .74566 .43778 L .74255 .43971 L F
.057 0 0 r
.74868 .43657 m .74804 .43711 L .74604 .43734 L F
.033 0 0 r
.74604 .43734 m .74804 .43711 L .74566 .43778 L F
.634 .409 .559 r
.57186 .52924 m .56828 .53197 L .56912 .52943 L F
.631 .939 .96 r
.73949 .44081 m .73801 .4426 L .74094 .4413 L F
.73949 .44081 m .73697 .44208 L .73801 .4426 L F
.726 .814 .919 r
.69572 .45151 m .69468 .4539 L .69368 .45266 L F
.69572 .45151 m .69708 .4528 L .69468 .4539 L F
.554 .922 .763 r
.55318 .48493 m .55437 .48372 L .55547 .4834 L F
0 0 0 r
.55437 .48372 m .55332 .48526 L .55554 .48254 L F
.89 .982 .7 r
.55547 .4834 m .55437 .48372 L .55644 .48043 L F
0 0 0 r
.55437 .48372 m .55554 .48254 L .55578 .48225 L F
.554 .922 .763 r
.55286 .48514 m .55437 .48372 L .55318 .48493 L F
.528 .883 .654 r
.55286 .48514 m .55112 .48624 L .55437 .48372 L F
.605 .442 .635 r
.40116 .62392 m .39916 .62533 L .39832 .62117 L F
.734 .955 .661 r
.21544 .58903 m .21399 .59073 L .21385 .59024 L F
.977 .921 .633 r
.21544 .58903 m .21385 .59024 L .2146 .58697 L F
.881 .829 .358 r
.21385 .59024 m .21426 .58666 L .2146 .58697 L F
.21385 .59024 m .21348 .58939 L .21426 .58666 L F
0 0 .518 r
.21385 .59024 m .21562 .59241 L .21367 .58966 L F
.21385 .59024 m .21367 .58966 L .21348 .58939 L F
.734 .955 .661 r
.21399 .59073 m .21289 .59202 L .21385 .59024 L F
.172 .298 .753 r
.21289 .59202 m .21509 .59391 L .21385 .59024 L F
.731 .487 .559 r
.56819 .51425 m .57147 .51207 L .56809 .51218 L F
.607 .259 .353 r
.76217 .42649 m .75868 .42833 L .75899 .42566 L F
.76217 .42649 m .76234 .4283 L .75868 .42833 L F
.664 .399 .509 r
.76537 .42603 m .76234 .4283 L .76217 .42649 L F
.75 .231 0 r
.21726 .57363 m .22075 .57656 L .22046 .57434 L F
.253 .098 .469 r
.61502 .4167 m .61471 .41949 L .61325 .42029 L F
0 0 .289 r
.61453 .42162 m .61325 .42029 L .61471 .41949 L F
.61453 .42162 m .61266 .42469 L .61325 .42029 L F
.325 .526 .897 r
.16636 .56435 m .16757 .56461 L .16703 .56534 L F
.634 .95 .944 r
.16703 .56534 m .16757 .56461 L .16626 .56532 L F
.016 .59 .739 r
.4644 .56461 m .46819 .56472 L .46596 .56516 L F
.614 .667 .877 r
.72444 .39855 m .72308 .40223 L .72198 .39956 L F
.72444 .39855 m .72559 .40175 L .72308 .40223 L F
.513 .393 .653 r
.54809 .56456 m .54616 .5677 L .54655 .56546 L F
.23 .742 .714 r
.16233 .54807 m .16462 .54738 L .16611 .54701 L F
.355 .821 .911 r
.16611 .54701 m .16666 .54639 L .16816 .54652 L F
.453 .881 .801 r
.16611 .54701 m .16462 .54738 L .16666 .54639 L F
.952 .946 .729 r
.22327 .58865 m .22041 .59367 L .22236 .5917 L F
.656 .707 .885 r
.70605 .39796 m .70722 .39987 L .70362 .39885 L F
.66 .719 .893 r
.70854 .39655 m .70722 .39987 L .70605 .39796 L F
.70854 .39655 m .70971 .39892 L .70722 .39987 L F
.731 .545 .64 r
.43632 .6351 m .44064 .63292 L .43759 .63298 L F
.828 .998 .775 r
.60752 .42117 m .60522 .42394 L .60598 .42182 L F
.825 1 .808 r
.60522 .42394 m .60335 .4246 L .60598 .42182 L F
.96 .876 .709 r
.66831 .4346 m .6673 .43672 L .66866 .43777 L F
.989 .88 .621 r
.66696 .43808 m .66866 .43777 L .6673 .43672 L F
.66696 .43808 m .66744 .44114 L .66866 .43777 L F
.191 0 .214 r
.60519 .48041 m .60285 .4824 L .60446 .48218 L F
.367 .129 .415 r
.60446 .48218 m .60285 .4824 L .60232 .48536 L F
0 0 0 r
.53771 .56755 m .53715 .56812 L .54021 .5651 L F
.29 .767 .66 r
.54088 .56615 m .5386 .56714 L .53771 .56755 L F
.121 0 0 r
.23257 .55694 m .23164 .55703 L .22926 .55678 L F
.766 .493 .521 r
.53064 .69747 m .5346 .6983 L .53435 .69536 L F
.478 .294 .552 r
.53435 .69536 m .53682 .69537 L .53667 .6924 L F
.476 .278 .532 r
.5346 .6983 m .53682 .69537 L .53435 .69536 L F
.591 .079 .002 r
.40631 .63383 m .40823 .63517 L .4096 .63405 L F
.623 .117 .027 r
.40823 .63517 m .41202 .6356 L .4096 .63405 L F
.746 .56 .643 r
.76134 .41741 m .75727 .41965 L .75784 .41715 L F
.76134 .41741 m .7611 .42025 L .75727 .41965 L F
.733 .435 .475 r
.43663 .64222 m .43671 .64392 L .43294 .64406 L F
.354 0 0 r
.43364 .57444 m .43239 .57546 L .4356 .57522 L F
.609 .703 .911 r
.47585 .57241 m .47437 .57436 L .47352 .57293 L F
.47585 .57241 m .47678 .5741 L .47437 .57436 L F
.633 .902 .985 r
.67918 .41347 m .67955 .41445 L .67852 .41562 L F
.817 .982 .887 r
.67918 .41347 m .67955 .41445 L .6821 .41187 L F
.951 .883 .481 r
.67852 .41562 m .67955 .41445 L .67918 .41347 L F
.818 .861 .412 r
.68709 .44983 m .6873 .44995 L .68632 .45157 L F
.642 .931 .668 r
.68868 .44818 m .6873 .44995 L .68709 .44983 L F
0 0 0 r
.68632 .45157 m .6873 .44995 L .68868 .44818 L F
.444 .288 .574 r
.2643 .57675 m .26228 .57989 L .26211 .57736 L F
.362 .755 .987 r
.20672 .53971 m .20927 .53958 L .211 .54044 L F
.335 .748 .979 r
.20927 .53958 m .21332 .54026 L .211 .54044 L F
.769 .679 .764 r
.43356 .60331 m .43492 .60674 L .43119 .60631 L F
.312 .757 .962 r
.43119 .60631 m .43492 .60674 L .43407 .60617 L F
.962 .649 .244 r
.43407 .60617 m .43492 .60674 L .43356 .60331 L F
.399 .175 .454 r
.37069 .59497 m .3725 .59656 L .37298 .59465 L F
.37069 .59497 m .3704 .59727 L .3725 .59656 L F
.545 .838 .999 r
.19017 .66177 m .19456 .66186 L .19112 .66024 L F
.673 .874 .974 r
.19112 .66024 m .19456 .66186 L .19515 .65996 L F
.656 .655 .837 r
.19456 .66186 m .19841 .66267 L .19515 .65996 L F
.96 .866 .701 r
.66007 .43054 m .6612 .43193 L .65989 .4346 L F
.385 .72 .988 r
.46064 .56453 m .4597 .56574 L .45847 .56523 L F
.46064 .56453 m .46256 .56578 L .4597 .56574 L F
.625 .793 .963 r
.72492 .41021 m .72833 .41106 L .72696 .41012 L F
.492 .825 .999 r
.72696 .41012 m .72833 .41106 L .73051 .41045 L F
0 0 0 r
.53653 .56951 m .53503 .57124 L .53715 .56812 L F
.036 .117 .619 r
.53721 .5715 m .53503 .57124 L .53653 .56951 L F
.53721 .5715 m .53589 .57374 L .53503 .57124 L F
.633 .34 .456 r
.46796 .63293 m .47014 .6334 L .47221 .63109 L F
.703 .436 .516 r
.47221 .63109 m .47014 .6334 L .47399 .63294 L F
.732 .214 0 r
.4648 .57448 m .46305 .57419 L .46161 .57288 L F
.606 .038 0 r
.4648 .57448 m .46374 .5749 L .46305 .57419 L F
.503 0 0 r
.46762 .5757 m .46374 .5749 L .4648 .57448 L F
.591 .395 .585 r
.46679 .57482 m .46762 .5757 L .4648 .57448 L F
.939 .868 .741 r
.6426 .41186 m .64106 .41077 L .64262 .40813 L F
.6426 .41186 m .64138 .41356 L .64106 .41077 L F
0 0 0 r
.19353 .64115 m .19555 .64022 L .19261 .64109 L F
.1956 .64043 m .19555 .64022 L .19353 .64115 L F
.1956 .64043 m .19797 .63944 L .19555 .64022 L F
.616 .63 .841 r
.4698 .58308 m .47065 .57908 L .46893 .57964 L F
.4698 .58308 m .4723 .58275 L .47065 .57908 L F
.579 .369 .56 r
.4698 .58308 m .47202 .58375 L .4723 .58275 L F
.4698 .58308 m .47202 .58375 L .4723 .58275 L F
.221 0 .125 r
.59445 .49358 m .59234 .49451 L .59144 .49582 L F
.384 .136 .41 r
.59489 .4917 m .59234 .49451 L .59445 .49358 L F
.933 .776 .664 r
.66159 .44681 m .65884 .44862 L .66058 .44509 L F
.66159 .44681 m .66066 .44992 L .65884 .44862 L F
.419 .486 .823 r
.2376 .5621 m .23898 .56137 L .23624 .55993 L F
.405 .31 .634 r
.23724 .56517 m .23898 .56137 L .2376 .5621 L F
.302 .098 .428 r
.24177 .62032 m .2405 .61865 L .24214 .61789 L F
.24177 .62032 m .24008 .62105 L .2405 .61865 L F
.605 .042 0 r
.40231 .63247 m .40631 .63383 L .40395 .63272 L F
0 .093 .611 r
.41662 .63432 m .41802 .63584 L .41592 .6341 L F
.41662 .63432 m .41592 .6341 L .41451 .63497 L F
.917 .747 .656 r
.54375 .67364 m .54681 .67157 L .54428 .67114 L F
.54375 .67364 m .54542 .67451 L .54681 .67157 L F
.983 .883 .65 r
.22083 .57906 m .21968 .58186 L .22128 .58264 L F
.978 .678 .331 r
.21982 .58361 m .22128 .58264 L .21968 .58186 L F
.21982 .58361 m .2215 .58624 L .22128 .58264 L F
0 0 0 r
.52339 .58043 m .52283 .58133 L .52054 .57878 L F
0 0 .501 r
.52283 .58133 m .52382 .58231 L .52328 .58065 L F
0 0 0 r
.52339 .58043 m .52238 .582 L .52283 .58133 L F
0 0 .501 r
.52283 .58133 m .52328 .58065 L .52303 .5799 L F
0 0 0 r
.52238 .582 m .52175 .58299 L .52283 .58133 L F
.577 .34 .519 r
.39602 .61236 m .39634 .61565 L .39263 .61447 L F
.471 .376 .666 r
.39634 .61565 m .39403 .61765 L .39263 .61447 L F
.54 .167 .282 r
.44357 .63931 m .44432 .63937 L .44749 .63654 L F
.584 .224 .323 r
.44749 .63654 m .44432 .63937 L .45027 .63797 L F
0 .07 .633 r
.19841 .66267 m .19723 .65912 L .19515 .65996 L F
.19841 .66267 m .19875 .66216 L .19723 .65912 L F
.219 .738 .738 r
.67468 .41544 m .67401 .41572 L .67303 .41461 L F
.67468 .41544 m .67706 .41493 L .67401 .41572 L F
.259 .76 .716 r
.54278 .68369 m .54129 .68423 L .54035 .68284 L F
.54278 .68369 m .54381 .68341 L .54129 .68423 L F
0 0 0 r
.54129 .68423 m .54182 .68433 L .54197 .68683 L F
.54129 .68423 m .54381 .68341 L .54182 .68433 L F
.731 .487 .559 r
.56819 .51425 m .57145 .51398 L .57147 .51207 L F
.564 .359 .56 r
.57145 .51398 m .57388 .51161 L .57147 .51207 L F
.374 .127 .406 r
.59708 .49077 m .59489 .4917 L .59445 .49358 L F
.34 .141 .457 r
.20985 .62377 m .21208 .62074 L .2127 .62105 L F
.923 .609 .429 r
.21393 .61527 m .21449 .61784 L .21235 .6168 L F
0 0 0 r
.21449 .61784 m .21458 .61807 L .21398 .61641 L F
.883 .946 .586 r
.21481 .61804 m .2132 .62002 L .21449 .61784 L F
0 0 0 r
.21458 .61807 m .21482 .61874 L .21451 .61788 L F
.21458 .61807 m .21451 .61788 L .21398 .61641 L F
.545 .907 .963 r
.2127 .62105 m .2132 .62002 L .21464 .61825 L F
.21465 .61827 m .21464 .61825 L .21481 .61804 L F
.2127 .62105 m .21464 .61825 L .21465 .61827 L F
.2127 .62105 m .21208 .62074 L .2132 .62002 L F
.501 .469 .753 r
.23528 .56856 m .23815 .57011 L .2369 .56703 L F
.522 .461 .729 r
.23587 .57058 m .23815 .57011 L .23528 .56856 L F
.745 .944 .947 r
.71744 .45333 m .71937 .45383 L .72133 .45234 L F
.798 .722 .78 r
.56189 .49958 m .56365 .50078 L .56584 .49792 L F
.242 0 0 r
.18921 .64215 m .19156 .6419 L .19261 .64109 L F
0 0 0 r
.19353 .64115 m .19261 .64109 L .19156 .6419 L F
.536 .767 .983 r
.69762 .39867 m .69417 .39785 L .69658 .39726 L F
.595 .77 .963 r
.69885 .39661 m .69762 .39867 L .69658 .39726 L F
.69885 .39661 m .69998 .39802 L .69762 .39867 L F
.999 .786 .472 r
.48611 .63072 m .48473 .63186 L .48489 .62929 L F
.48489 .62929 m .48611 .63072 L .48847 .62978 L F
.48489 .62929 m .48473 .63186 L .48611 .63072 L F
.554 .526 .778 r
.39721 .60867 m .39602 .61236 L .39511 .60923 L F
.39721 .60867 m .39833 .6121 L .39602 .61236 L F
.569 .334 .519 r
.39826 .61447 m .39602 .61236 L .39833 .6121 L F
.39826 .61447 m .39634 .61565 L .39602 .61236 L F
.12 0 0 r
.4419 .59053 m .44561 .59107 L .44347 .58982 L F
.313 .06 .361 r
.36965 .61854 m .3671 .62194 L .36926 .62099 L F
.234 .276 .701 r
.36965 .61854 m .3702 .6147 L .36869 .61482 L F
.36965 .61854 m .37084 .61819 L .3702 .6147 L F
.565 .275 .434 r
.36965 .61854 m .37172 .62054 L .37084 .61819 L F
.36965 .61854 m .36926 .62099 L .37172 .62054 L F
.398 .824 .963 r
.68072 .39771 m .6794 .39859 L .67821 .39809 L F
.68072 .39771 m .68216 .39813 L .6794 .39859 L F
.478 .363 .645 r
.23651 .57181 m .23815 .57011 L .23587 .57058 L F
.634 .71 .901 r
.6495 .40951 m .64667 .4128 L .64746 .41053 L F
.6495 .40951 m .65058 .4117 L .64667 .4128 L F
0 .394 .835 r
.71126 .44733 m .71254 .44737 L .71352 .44586 L F
.945 .869 .732 r
.71246 .44671 m .71352 .44586 L .71254 .44737 L F
0 0 0 r
.71446 .44511 m .71126 .44733 L .71352 .44586 L F
.945 .869 .732 r
.71218 .44436 m .71352 .44586 L .71246 .44671 L F
0 0 0 r
.71492 .44478 m .71446 .44511 L .71352 .44586 L F
0 .394 .835 r
.71126 .44733 m .71276 .44816 L .71254 .44737 L F
.881 .872 .824 r
.56477 .49693 m .56827 .49479 L .56713 .49397 L F
.56477 .49693 m .56584 .49792 L .56827 .49479 L F
.775 .781 .857 r
.56827 .49479 m .56949 .49089 L .56713 .49397 L F
.298 .058 .372 r
.20769 .62733 m .20931 .62893 L .20969 .62637 L F
.20769 .62733 m .20749 .62969 L .20931 .62893 L F
.434 .756 .995 r
.24297 .54346 m .24254 .5448 L .24134 .54291 L F
.24297 .54346 m .24457 .54458 L .24254 .5448 L F
.589 .418 .618 r
.56608 .53226 m .5637 .53531 L .56357 .53274 L F
.829 .643 .095 r
.65283 .43149 m .65279 .42916 L .65239 .4268 L F
.985 .887 .641 r
.22041 .59367 m .21914 .59658 L .22041 .59772 L F
.959 .737 .559 r
.21914 .59658 m .22075 .60011 L .22041 .59772 L F
.799 .978 .902 r
.7258 .4484 m .72949 .44665 L .72888 .44597 L F
.79 .984 .898 r
.73082 .44414 m .72949 .44665 L .73249 .4447 L F
.73082 .44414 m .72888 .44597 L .72949 .44665 L F
.919 .719 .227 r
.61198 .46673 m .61148 .46813 L .60998 .46668 L F
.61198 .46673 m .61201 .4706 L .61148 .46813 L F
.731 .697 .819 r
.54465 .57678 m .54605 .58019 L .54217 .5798 L F
.667 .441 .569 r
.54527 .58157 m .54217 .5798 L .54605 .58019 L F
.601 .523 .739 r
.54806 .57722 m .54605 .58019 L .54465 .57678 L F
.54806 .57722 m .54896 .57981 L .54605 .58019 L F
.571 .186 .274 r
.54605 .58019 m .5483 .5817 L .54527 .58157 L F
.523 .229 .408 r
.54896 .57981 m .5483 .5817 L .54605 .58019 L F
.717 .626 .755 r
.50877 .54081 m .51253 .54263 L .51061 .54218 L F
.912 .98 .724 r
.51253 .54263 m .51104 .54279 L .51155 .54395 L F
.301 .776 .673 r
.4047 .58075 m .40349 .58124 L .40674 .57986 L F
.451 .807 .997 r
.68678 .39744 m .68544 .39862 L .68437 .39773 L F
.68678 .39744 m .68775 .39825 L .68544 .39862 L F
.975 .667 .324 r
.31286 .73058 m .31442 .73399 L .31384 .73111 L F
.31286 .73058 m .31442 .73399 L .31384 .73111 L F
.681 .22 .151 r
.21357 .55331 m .21141 .55471 L .20978 .5528 L F
.634 .782 .952 r
.44019 .57878 m .44135 .58006 L .43817 .57999 L F
.681 .54 .687 r
.44142 .58266 m .43817 .57999 L .44135 .58006 L F
.707 .807 .928 r
.44269 .5795 m .44135 .58006 L .44019 .57878 L F
.433 .306 .607 r
.44524 .58062 m .44135 .58006 L .44269 .5795 L F
.44524 .58062 m .44142 .58266 L .44135 .58006 L F
.414 .448 .787 r
.46082 .57065 m .46034 .57208 L .46222 .56984 L F
.355 .374 .743 r
.46161 .57288 m .46222 .56984 L .46034 .57208 L F
.234 .087 .468 r
.48564 .57879 m .48389 .5771 L .48638 .57635 L F
.48564 .57879 m .48349 .58033 L .48389 .5771 L F
.08 0 .307 r
.67832 .45732 m .6769 .45899 L .67722 .45772 L F
.67832 .45732 m .6769 .45899 L .67722 .45772 L F
.902 .763 .698 r
.63096 .46045 m .63375 .46131 L .63279 .45795 L F
.902 .763 .697 r
.63226 .4648 m .63375 .46131 L .63096 .46045 L F
.999 .808 .468 r
.44011 .63545 m .43988 .63787 L .44088 .63673 L F
.734 .277 .166 r
.43988 .63787 m .44357 .63931 L .44088 .63673 L F
.999 .808 .468 r
.44011 .63545 m .43988 .63787 L .44088 .63673 L F
.964 .889 .507 r
.60886 .41929 m .6083 .41871 L .60941 .41741 L F
.911 .875 .445 r
.60941 .41741 m .60926 .41658 L .61012 .41304 L F
.917 .913 .519 r
.60941 .41741 m .6083 .41871 L .60926 .41658 L F
.987 .713 .371 r
.66641 .44284 m .66645 .44582 L .66774 .4471 L F
.906 .522 .089 r
.66645 .44582 m .66833 .44932 L .66774 .4471 L F
.798 .722 .78 r
.56189 .49958 m .56584 .49792 L .56477 .49693 L F
.635 .836 .978 r
.74431 .41432 m .74138 .41539 L .74044 .41469 L F
.74431 .41432 m .74138 .41539 L .74044 .41469 L F
.603 .842 .989 r
.70958 .44905 m .70557 .44929 L .70806 .4489 L F
.496 0 0 r
.70806 .4489 m .71171 .44987 L .70958 .44905 L F
.767 .708 .17 r
.61062 .42799 m .61098 .42606 L .61104 .42618 L F
.367 0 0 r
.21952 .55271 m .2183 .55301 L .2158 .55263 L F
.352 .823 .769 r
.22028 .55223 m .21952 .55271 L .22195 .55209 L F
.22028 .55223 m .2183 .55301 L .21952 .55271 L F
.973 .759 .554 r
.22164 .58744 m .22327 .58865 L .22134 .58892 L F
.9 .964 .821 r
.5346 .6983 m .53616 .69744 L .53682 .69537 L F
.748 .991 .879 r
.53616 .69744 m .53905 .69449 L .53682 .69537 L F
.991 .844 .478 r
.68335 .40973 m .68427 .41047 L .68455 .40864 L F
.68335 .40973 m .68455 .40864 L .68655 .40736 L F
.502 0 0 r
.7355 .43116 m .73414 .43031 L .73244 .42895 L F
.726 .904 .958 r
.73766 .42831 m .7355 .43116 L .73849 .43046 L F
.73766 .42831 m .73414 .43031 L .7355 .43116 L F
.449 .641 .939 r
.75348 .40013 m .7568 .40088 L .75336 .40052 L F
.481 .63 .918 r
.75368 .39839 m .7568 .40088 L .75188 .39977 L F
.75409 .39808 m .75507 .39908 L .75368 .39839 L F
.75507 .39908 m .7568 .40088 L .75368 .39839 L F
.449 .641 .939 r
.75336 .40052 m .7568 .40088 L .75707 .40239 L F
.75188 .39977 m .75348 .40013 L .75336 .40052 L F
.481 .63 .918 r
.75409 .39808 m .75188 .39977 L .75293 .40212 L F
.582 .626 .861 r
.75036 .39675 m .75321 .39903 L .74971 .39922 L F
.7507 .39546 m .75227 .3977 L .75036 .39675 L F
.75227 .3977 m .75321 .39903 L .75036 .39675 L F
0 0 .566 r
.75337 .40068 m .75474 .40244 L .75365 .39994 L F
.481 .63 .918 r
.75399 .39844 m .75324 .40106 L .75337 .40068 L F
0 0 .566 r
.75337 .40068 m .75365 .39994 L .7535 .3996 L F
.481 .63 .918 r
.75324 .40106 m .75293 .40212 L .75337 .40068 L F
.75409 .39808 m .75391 .39871 L .75399 .39844 L F
.75391 .39871 m .75293 .40212 L .75399 .39844 L F
.398 .6 .928 r
.7568 .40088 m .75839 .40068 L .75707 .40239 L F
.286 .439 .839 r
.75839 .40068 m .76005 .40393 L .75707 .40239 L F
.502 .752 .985 r
.44082 .59891 m .44199 .60022 L .43965 .60051 L F
.528 .34 .569 r
.43965 .60051 m .44199 .60022 L .44082 .59891 L F
.43965 .60051 m .43969 .60328 L .44199 .60022 L F
.755 .692 .791 r
.64028 .44676 m .64383 .44742 L .64306 .44439 L F
.812 .717 .761 r
.64383 .44742 m .64442 .44286 L .64306 .44439 L F
.64383 .44742 m .64517 .44439 L .64442 .44286 L F
.192 0 0 r
.41322 .60666 m .41417 .60703 L .41167 .60648 L F
0 0 .137 r
.41646 .60234 m .41485 .6056 L .41322 .60666 L F
0 0 0 r
.41485 .6056 m .41417 .60703 L .41322 .60666 L F
.442 .284 .571 r
.24855 .60403 m .24845 .60688 L .2465 .60678 L F
.484 .319 .581 r
.24866 .60856 m .2465 .60678 L .24845 .60688 L F
.24866 .60856 m .24668 .60921 L .2465 .60678 L F
.739 .636 .745 r
.57745 .62201 m .57992 .61912 L .57566 .61817 L F
.99 .729 .415 r
.54181 .66536 m .54292 .66799 L .54013 .66752 L F
.552 .554 .81 r
.54152 .67167 m .54013 .66752 L .54292 .66799 L F
.99 .729 .415 r
.54292 .66799 m .54181 .66536 L .5425 .66785 L F
.788 .387 0 r
.5425 .66785 m .54428 .67114 L .54292 .66799 L F
.425 .154 .397 r
.26017 .58312 m .2596 .58536 L .25742 .58592 L F
.484 .208 .419 r
.26188 .58482 m .26017 .58312 L .26211 .58235 L F
.26188 .58482 m .2596 .58536 L .26017 .58312 L F
.92 .972 .773 r
.60808 .43311 m .60599 .43649 L .60782 .43583 L F
.501 .114 .238 r
.43068 .58858 m .42944 .59092 L .42724 .59078 L F
.672 .297 .327 r
.43318 .59069 m .43068 .58858 L .43291 .58836 L F
.43318 .59069 m .42944 .59092 L .43068 .58858 L F
.836 .665 .67 r
.47336 .58884 m .4747 .59185 L .4712 .59108 L F
.137 .65 .895 r
.4747 .59185 m .47326 .59132 L .4712 .59108 L F
.163 0 .054 r
.47859 .58806 m .47561 .59031 L .47638 .58868 L F
.616 .931 .699 r
.47664 .589 m .47661 .58902 L .47561 .59031 L F
.112 .269 .746 r
.47561 .59031 m .47459 .59161 L .47336 .58884 L F
.47561 .59031 m .47336 .58884 L .47638 .58868 L F
.836 .665 .67 r
.47336 .58884 m .4712 .59108 L .47127 .58876 L F
.897 .662 .574 r
.47097 .58959 m .4712 .59108 L .46948 .59056 L F
.47122 .59019 m .4712 .59108 L .47096 .58946 L F
.47127 .58876 m .47122 .59019 L .4709 .58912 L F
.048 0 0 r
.47975 .58671 m .47859 .58806 L .47638 .58868 L F
.769 .634 .712 r
.47336 .58884 m .47127 .58876 L .47347 .58604 L F
.768 .633 .711 r
.47347 .58604 m .46969 .58549 L .47202 .58375 L F
.47347 .58604 m .46931 .58848 L .46969 .58549 L F
.47347 .58604 m .47127 .58876 L .46931 .58848 L F
.716 .569 .687 r
.46931 .58848 m .4709 .58949 L .47094 .58925 L F
.46931 .58848 m .47094 .58925 L .4709 .58912 L F
.897 .662 .574 r
.47074 .58869 m .47055 .58898 L .46931 .58848 L F
.716 .569 .687 r
.46931 .58848 m .4709 .58912 L .47023 .58687 L F
.763 .409 .385 r
.46948 .59056 m .4709 .58949 L .46931 .58848 L F
.897 .662 .574 r
.47055 .58898 m .46948 .59056 L .46931 .58848 L F
.47127 .58876 m .47094 .58909 L .47074 .58869 L F
.47094 .58909 m .46948 .59056 L .47074 .58869 L F
.416 .284 .592 r
.47202 .58375 m .47096 .58915 L .47663 .58869 L F
.47096 .58915 m .47094 .58925 L .47101 .58925 L F
.47096 .58915 m .47101 .58925 L .47663 .58869 L F
.47094 .58925 m .4709 .58949 L .47095 .58948 L F
.897 .662 .574 r
.47098 .58936 m .47096 .58946 L .47095 .58942 L F
.47098 .58936 m .47095 .58942 L .47094 .58925 L F
.416 .284 .592 r
.47094 .58925 m .47095 .58948 L .47663 .58869 L F
.897 .662 .574 r
.47094 .58925 m .47095 .58942 L .4709 .58912 L F
.47122 .59019 m .47096 .58946 L .47098 .58936 L F
.663 .17 .068 r
.47318 .59131 m .47118 .5909 L .4712 .59108 L F
.47118 .5909 m .46948 .59056 L .47065 .59091 L F
.47118 .5909 m .47065 .59091 L .4712 .59108 L F
.304 .143 .491 r
.47663 .58869 m .47587 .58973 L .47664 .589 L F
.616 .931 .699 r
.47654 .58911 m .47587 .58973 L .47561 .59031 L F
.47587 .58973 m .47552 .59006 L .47561 .59031 L F
.304 .143 .491 r
.47587 .58973 m .47527 .59054 L .47664 .589 L F
.616 .931 .699 r
.47587 .58973 m .47551 .59005 L .47552 .59006 L F
.47551 .59005 m .47469 .59081 L .47473 .59078 L F
.47551 .59005 m .47473 .59078 L .47561 .59031 L F
.444 .334 .634 r
.4766 .58891 m .47616 .58945 L .47664 .589 L F
.47616 .58945 m .47527 .59054 L .47664 .589 L F
.535 .438 .692 r
.4711 .5903 m .47663 .58869 L .47095 .58948 L F
.4753 .58923 m .47663 .58869 L .4711 .5903 L F
.416 .284 .592 r
.47202 .58375 m .47548 .58746 L .47439 .58432 L F
.47548 .58746 m .47663 .58869 L .47611 .58769 L F
.47548 .58746 m .47611 .58769 L .47439 .58432 L F
.734 .589 .694 r
.47632 .58776 m .47931 .58399 L .47709 .58451 L F
.47623 .5881 m .47645 .58781 L .47632 .58776 L F
.47645 .58781 m .47931 .58399 L .47632 .58776 L F
.444 .334 .634 r
.47623 .5881 m .47584 .5891 L .4766 .58891 L F
.535 .438 .692 r
.47566 .58977 m .47587 .58973 L .47663 .58869 L F
.47484 .59067 m .47551 .59005 L .47566 .58977 L F
.47551 .59005 m .47587 .58973 L .47566 .58977 L F
.444 .334 .634 r
.47551 .59005 m .47616 .58945 L .4766 .58891 L F
.616 .931 .699 r
.47661 .58902 m .47469 .59081 L .47551 .59005 L F
.4766 .58903 m .47551 .59005 L .47654 .58911 L F
.47661 .58902 m .47551 .59005 L .4766 .58903 L F
.444 .334 .634 r
.47584 .5891 m .47527 .59054 L .47602 .58905 L F
.663 .17 .068 r
.47326 .59132 m .4712 .5909 L .47318 .59131 L F
.763 .409 .385 r
.46948 .59056 m .47118 .5909 L .47092 .58962 L F
.663 .17 .068 r
.4712 .5909 m .46948 .59056 L .47118 .5909 L F
.4712 .5909 m .47118 .5909 L .47318 .59131 L F
.535 .438 .692 r
.47118 .5909 m .47095 .58948 L .47092 .58962 L F
.47136 .59178 m .47121 .59091 L .47118 .5909 L F
.47121 .59091 m .4712 .5909 L .47118 .5909 L F
.663 .17 .068 r
.47326 .59132 m .47225 .59211 L .47184 .59164 L F
.47254 .59117 m .47184 .59164 L .4712 .5909 L F
.47326 .59132 m .47184 .59164 L .47254 .59117 L F
.112 .269 .746 r
.47561 .59031 m .4747 .59185 L .47459 .59161 L F
.607 .902 .986 r
.47561 .59031 m .47326 .59132 L .4747 .59185 L F
0 0 0 r
.47407 .59114 m .47326 .59132 L .47561 .59031 L F
.616 .931 .699 r
.47483 .59068 m .47407 .59114 L .47469 .59081 L F
.535 .438 .692 r
.47176 .59155 m .47484 .59067 L .47663 .58869 L F
.616 .931 .699 r
.47661 .58902 m .47407 .59114 L .47483 .59068 L F
.178 0 .141 r
.47484 .59067 m .47407 .59114 L .47527 .59054 L F
.47188 .59161 m .47407 .59114 L .47484 .59067 L F
.47136 .59178 m .47178 .59168 L .47188 .59161 L F
.47178 .59168 m .47407 .59114 L .47188 .59161 L F
.535 .438 .692 r
.47136 .59178 m .47188 .59161 L .47176 .59155 L F
.47188 .59161 m .47484 .59067 L .47176 .59155 L F
.763 .409 .385 r
.46948 .59056 m .47136 .59178 L .47118 .5909 L F
.563 0 0 r
.46948 .59056 m .4719 .5924 L .47136 .59178 L F
.663 .17 .068 r
.47031 .59072 m .4719 .5924 L .46948 .59056 L F
.4712 .5909 m .4714 .59135 L .47031 .59072 L F
.4714 .59135 m .4719 .5924 L .47031 .59072 L F
.47225 .59211 m .4719 .5924 L .47176 .59155 L F
0 0 0 r
.47407 .59114 m .4719 .5924 L .47326 .59132 L F
.178 0 .141 r
.47178 .59168 m .4719 .5924 L .47407 .59114 L F
.47136 .59178 m .4719 .5924 L .47178 .59168 L F
.535 .438 .692 r
.47136 .59178 m .47291 .59087 L .4712 .5909 L F
.663 .17 .068 r
.47176 .59155 m .4719 .5924 L .4712 .5909 L F
.535 .438 .692 r
.47121 .59091 m .4712 .5909 L .4712 .5909 L F
.4712 .5909 m .47095 .58948 L .47118 .5909 L F
.444 .334 .634 r
.47602 .58905 m .47551 .59005 L .4766 .58891 L F
.535 .438 .692 r
.47484 .59067 m .47527 .59054 L .47587 .58973 L F
.444 .334 .634 r
.47551 .59005 m .47527 .59054 L .47616 .58945 L F
.535 .438 .692 r
.4712 .5909 m .4753 .58923 L .4711 .5903 L F
.47291 .59087 m .47663 .58869 L .4712 .5909 L F
.47092 .58962 m .47095 .58948 L .4709 .58949 L F
.763 .409 .385 r
.46948 .59056 m .47092 .58962 L .4709 .58949 L F
.897 .662 .574 r
.4709 .58912 m .47097 .58959 L .46948 .59056 L F
.716 .569 .687 r
.47023 .58687 m .47094 .58925 L .47202 .58375 L F
.451 .318 .608 r
.53238 .56428 m .53064 .56547 L .53031 .56305 L F
.492 .296 .542 r
.53261 .56179 m .53238 .56428 L .53031 .56305 L F
.53261 .56179 m .53238 .56428 L .53031 .56305 L F
.472 .197 .415 r
.59113 .51531 m .59306 .51689 L .59044 .5176 L F
.59113 .51531 m .59355 .51432 L .59306 .51689 L F
.866 .56 .038 r
.21481 .61804 m .21449 .61784 L .21393 .61527 L F
0 0 0 r
.48276 .57194 m .48365 .5718 L .48471 .57138 L F
.47 .077 .211 r
.17371 .54271 m .17589 .54355 L .17707 .54139 L F
0 0 0 r
.17707 .54139 m .17719 .54241 L .1792 .54172 L F
.17707 .54139 m .17589 .54355 L .17719 .54241 L F
.652 .503 .667 r
.57883 .50275 m .57899 .50582 L .58142 .50284 L F
.641 .503 .679 r
.54675 .57095 m .54461 .57405 L .54464 .57161 L F
.336 0 .14 r
.62064 .41409 m .61722 .41583 L .61773 .41489 L F
0 0 0 r
.5978 .50871 m .60062 .50591 L .60046 .5079 L F
.60062 .50591 m .60319 .50302 L .60247 .50468 L F
0 0 .136 r
.60046 .5079 m .60062 .50591 L .60247 .50468 L F
.596 .78 .968 r
.73666 .43614 m .73349 .4356 L .73573 .4343 L F
.586 .639 .87 r
.73833 .43362 m .73666 .43614 L .73573 .4343 L F
.73833 .43362 m .73902 .43555 L .73666 .43614 L F
0 0 0 r
.59619 .45811 m .59534 .45968 L .59305 .46052 L F
.59872 .45543 m .59764 .45675 L .59619 .45811 L F
.59764 .45675 m .59534 .45968 L .59619 .45811 L F
.309 0 .197 r
.39775 .60466 m .39692 .60636 L .39433 .60706 L F
.462 .107 .276 r
.39938 .60576 m .39775 .60466 L .39958 .60326 L F
.39938 .60576 m .39692 .60636 L .39775 .60466 L F
.991 .844 .478 r
.68335 .40973 m .68655 .40736 L .68536 .40818 L F
.209 .102 .506 r
.21386 .60948 m .21513 .60881 L .21508 .60629 L F
.286 .166 .536 r
.21386 .60948 m .21533 .61153 L .21513 .60881 L F
.21386 .60948 m .21323 .61302 L .21533 .61153 L F
.355 .43 .8 r
.47085 .56629 m .46944 .56828 L .46819 .56472 L F
.391 .478 .83 r
.47085 .56629 m .47232 .56976 L .46944 .56828 L F
.898 .953 .828 r
.67771 .40767 m .67843 .40863 L .67634 .4112 L F
.094 0 0 r
.43539 .58055 m .4376 .57962 L .43691 .57976 L F
.49 .891 .943 r
.43817 .57999 m .43691 .57976 L .43918 .57895 L F
.094 0 0 r
.4376 .57962 m .43918 .57895 L .43691 .57976 L F
.783 .644 .708 r
.43817 .57999 m .43623 .5799 L .43691 .57976 L F
.43623 .5799 m .43428 .57981 L .43691 .57976 L F
.49 .891 .943 r
.43817 .57999 m .43918 .57895 L .44019 .57878 L F
.681 .54 .687 r
.44142 .58266 m .43916 .58352 L .43817 .57999 L F
.735 .707 .172 r
.65204 .42242 m .65254 .41993 L .65217 .42145 L F
.541 .881 .988 r
.72641 .43698 m .72477 .43843 L .72378 .43788 L F
.72641 .43698 m .72731 .43761 L .72477 .43843 L F
.444 .271 .551 r
.25347 .59725 m .25323 .59951 L .25098 .59992 L F
.482 .255 .493 r
.25323 .59951 m .25067 .60269 L .25098 .59992 L F
.31 .298 .683 r
.22996 .58557 m .23115 .58188 L .22887 .58248 L F
.22996 .58557 m .23144 .58563 L .23115 .58188 L F
0 0 0 r
.1842 .55612 m .1833 .5564 L .18555 .55637 L F
.1842 .55612 m .17997 .55751 L .1833 .5564 L F
.757 .625 .713 r
.53197 .58563 m .5327 .58901 L .52919 .58853 L F
.84 .646 .641 r
.5327 .58901 m .52952 .59075 L .52919 .58853 L F
.5327 .58901 m .53304 .59192 L .52952 .59075 L F
.632 .776 .95 r
.53434 .58678 m .5327 .58901 L .53197 .58563 L F
.53434 .58678 m .53536 .58857 L .5327 .58901 L F
.556 .393 .616 r
.53536 .58857 m .53304 .59192 L .5327 .58901 L F
.82 .96 .63 r
.48512 .58328 m .48428 .58457 L .48434 .58538 L F
.415 .813 .984 r
.48184 .58585 m .4844 .5861 L .48434 .58538 L F
.196 0 0 r
.48434 .58538 m .48043 .58694 L .48184 .58585 L F
.48434 .58538 m .48301 .58653 L .48043 .58694 L F
.82 .96 .63 r
.48428 .58457 m .48301 .58653 L .48434 .58538 L F
.415 .813 .984 r
.4844 .5861 m .48531 .58619 L .48434 .58538 L F
.668 .94 .964 r
.48434 .58538 m .48531 .58619 L .48648 .58426 L F
0 .091 .649 r
.62244 .42105 m .62302 .42344 L .62177 .4203 L F
.987 .879 .532 r
.62244 .42105 m .62179 .42441 L .62302 .42344 L F
.374 .073 .32 r
.58656 .49759 m .58394 .50002 L .5862 .49926 L F
.43 .09 .286 r
.58864 .49866 m .58656 .49759 L .5862 .49926 L F
.58864 .49866 m .5895 .49634 L .58656 .49759 L F
.462 .296 .569 r
.22831 .59188 m .22993 .59375 L .23064 .5915 L F
.22831 .59188 m .22814 .59429 L .22993 .59375 L F
.13 .639 .899 r
.17432 .55855 m .17589 .55839 L .17546 .55834 L F
.882 .808 .771 r
.57162 .48763 m .56949 .49089 L .57202 .49059 L F
.361 .49 .854 r
.23624 .55993 m .23722 .55803 L .23508 .5586 L F
.23624 .55993 m .23898 .56137 L .23722 .55803 L F
.591 .838 .991 r
.45725 .63927 m .45338 .63883 L .45695 .63787 L F
.575 .14 .177 r
.45725 .63927 m .45384 .63965 L .45338 .63883 L F
.45725 .63927 m .45572 .64119 L .45384 .63965 L F
.489 .089 .209 r
.45959 .63888 m .45572 .64119 L .45725 .63927 L F
.523 .341 .576 r
.45912 .63661 m .45959 .63888 L .45725 .63927 L F
.801 .57 .587 r
.48707 .62727 m .48847 .62978 L .48853 .62763 L F
.285 .03 .341 r
.22562 .59744 m .22814 .59429 L .22587 .59484 L F
.615 .786 .963 r
.53323 .58212 m .53427 .58239 L .53128 .58324 L F
.534 .333 .554 r
.53427 .58239 m .53419 .58506 L .53128 .58324 L F
.41 .376 .71 r
.53419 .58506 m .53197 .58563 L .53128 .58324 L F
.527 .467 .733 r
.39692 .60636 m .39511 .60923 L .39433 .60706 L F
.434 .225 .494 r
.55606 .5437 m .55362 .54699 L .55374 .54445 L F
.465 .139 .328 r
.38968 .58887 m .39208 .5888 L .39313 .58561 L F
.437 .115 .321 r
.39208 .5888 m .39548 .58506 L .39313 .58561 L F
0 0 .096 r
.76892 .41555 m .76886 .41841 L .76863 .41932 L F
.964 .934 .625 r
.76886 .41841 m .76702 .42016 L .76863 .41932 L F
.76886 .41841 m .76835 .42116 L .76702 .42016 L F
.166 .138 .579 r
.76835 .42116 m .76755 .42271 L .76702 .42016 L F
.929 .967 .759 r
.55733 .48099 m .55644 .48043 L .55836 .47963 L F
.727 .975 .738 r
.56097 .47694 m .55836 .47963 L .55939 .47786 L F
.732 .988 .804 r
.55836 .47963 m .55644 .48043 L .55939 .47786 L F
.602 .696 .909 r
.45186 .60056 m .44826 .59929 L .45132 .59676 L F
0 0 .152 r
.45134 .59689 m .45178 .59941 L .45186 .60056 L F
.117 .111 .574 r
.45178 .59941 m .45114 .60216 L .45186 .60056 L F
.172 0 0 r
.447 .59898 m .45132 .59676 L .44826 .59929 L F
.117 .111 .574 r
.45178 .59941 m .45262 .60159 L .45114 .60216 L F
.654 .577 .756 r
.44894 .59867 m .45208 .60116 L .45178 .59941 L F
.45208 .60116 m .45262 .60159 L .45178 .59941 L F
0 0 .152 r
.45132 .59676 m .45178 .59941 L .45134 .59689 L F
.64 .751 .929 r
.43188 .56485 m .43091 .56566 L .42814 .56468 L F
.452 .882 .812 r
.20733 .6564 m .20336 .65806 L .20562 .65758 L F
.898 .953 .828 r
.67771 .40767 m .67634 .4112 L .67526 .41013 L F
.548 0 0 r
.67634 .4112 m .67675 .41181 L .67526 .41013 L F
.67634 .4112 m .67918 .41347 L .67675 .41181 L F
.948 .826 .691 r
.6323 .45458 m .63502 .45245 L .634 .4514 L F
.6323 .45458 m .63396 .45546 L .63502 .45245 L F
.874 .93 .857 r
.63652 .44849 m .63502 .45245 L .6378 .44977 L F
.63652 .44849 m .634 .4514 L .63502 .45245 L F
.106 .402 .855 r
.25511 .54864 m .25633 .54883 L .25602 .55027 L F
.291 .607 .953 r
.25633 .54883 m .25683 .55025 L .25602 .55027 L F
.358 0 0 r
.1792 .54172 m .18115 .54234 L .18332 .54193 L F
.575 .152 .201 r
.18115 .54234 m .1852 .5409 L .18332 .54193 L F
.23 0 .255 r
.60319 .50302 m .60585 .50019 L .6052 .50162 L F
0 0 0 r
.60247 .50468 m .60319 .50302 L .6052 .50162 L F
.44025 .56522 m .43631 .566 L .43807 .56707 L F
.818 .826 .855 r
.69933 .44982 m .69708 .4528 L .69572 .45151 L F
.663 .818 .958 r
.69639 .40799 m .69761 .40557 L .6953 .40638 L F
.69639 .40799 m .69886 .40697 L .69761 .40557 L F
0 0 0 r
.19714 .6922 m .19414 .69488 L .19485 .69406 L F
.234 0 .082 r
.61839 .40472 m .62073 .40461 L .62131 .40268 L F
.257 0 .025 r
.62073 .40461 m .62375 .40222 L .62131 .40268 L F
.826 .937 .567 r
.62219 .45407 m .62336 .45291 L .62221 .45476 L F
.846 .948 .884 r
.62454 .45136 m .62336 .45291 L .62279 .45168 L F
.986 .875 .522 r
.62279 .45168 m .62336 .45291 L .62219 .45407 L F
.748 .676 .781 r
.57249 .63144 m .56868 .63 L .56964 .63302 L F
.494 .008 .031 r
.45695 .63787 m .45801 .63812 L .45912 .63661 L F
.521 .34 .577 r
.45912 .63661 m .46189 .63849 L .45959 .63888 L F
.22 .717 .914 r
.45801 .63812 m .46189 .63849 L .45912 .63661 L F
.298 .702 .975 r
.23947 .54183 m .23908 .54287 L .23711 .54164 L F
.23947 .54183 m .24134 .54291 L .23908 .54287 L F
0 0 .071 r
.53883 .57387 m .5391 .57418 L .54011 .5735 L F
.736 .556 .65 r
.54244 .57516 m .53878 .57659 L .53883 .57387 L F
0 0 .071 r
.53883 .57387 m .53878 .57659 L .53909 .57425 L F
.736 .556 .65 r
.54244 .57516 m .54209 .57719 L .53878 .57659 L F
.788 .663 .725 r
.54209 .57719 m .53843 .5784 L .53878 .57659 L F
.786 .83 .886 r
.53843 .5784 m .53623 .57987 L .53597 .57765 L F
.568 0 0 r
.53597 .57765 m .537 .5783 L .53843 .5784 L F
.53597 .57765 m .537 .5783 L .53843 .5784 L F
0 0 .516 r
.53771 .57873 m .537 .5783 L .53851 .57719 L F
.53839 .57769 m .53851 .57719 L .53893 .57688 L F
.53771 .57873 m .53851 .57719 L .53839 .57769 L F
.345 .41 .786 r
.53843 .5784 m .53887 .57561 L .53878 .57659 L F
.53887 .57561 m .53908 .57429 L .53895 .57525 L F
.53887 .57561 m .53895 .57525 L .53878 .57659 L F
0 0 .071 r
.53908 .57417 m .53909 .57425 L .5391 .57418 L F
.345 .41 .786 r
.53908 .57429 m .5391 .57418 L .53909 .57425 L F
.53908 .57429 m .53909 .57425 L .53878 .57659 L F
.788 .663 .725 r
.54209 .57719 m .54217 .5798 L .53843 .5784 L F
.345 .41 .786 r
.53843 .5784 m .54005 .57832 L .5391 .57418 L F
.006 0 .263 r
.5391 .57483 m .53893 .57688 L .53851 .57719 L F
.53891 .57515 m .53851 .57719 L .537 .5783 L F
.5391 .57483 m .53851 .57719 L .53891 .57515 L F
.53933 .57446 m .53913 .57565 L .5391 .57483 L F
.53913 .57565 m .53893 .57688 L .5391 .57483 L F
0 0 .071 r
.53883 .57387 m .53909 .57425 L .53908 .57417 L F
.76 .971 .694 r
.40959 .60396 m .40735 .60639 L .40785 .60517 L F
.662 .894 .98 r
.41262 .60312 m .40959 .60396 L .41014 .60214 L F
.821 .982 .7 r
.40959 .60396 m .40785 .60517 L .41014 .60214 L F
.235 0 0 r
.37538 .59431 m .3775 .59379 L .37907 .59194 L F
.429 0 .105 r
.37907 .59194 m .38076 .59307 L .38127 .59142 L F
.37907 .59194 m .3775 .59379 L .38076 .59307 L F
0 .465 .7 r
.21332 .54026 m .21528 .54063 L .21706 .54097 L F
.317 .741 .974 r
.21528 .54063 m .21921 .54134 L .21706 .54097 L F
.643 .724 .907 r
.70861 .40805 m .71216 .40898 L .71111 .40718 L F
.615 .71 .913 r
.71111 .40718 m .71216 .40898 L .71449 .40817 L F
.635 .125 .019 r
.42448 .64511 m .42324 .64627 L .42075 .64455 L F
.599 .083 0 r
.42672 .64663 m .42324 .64627 L .42448 .64511 L F
.567 .175 .259 r
.42725 .64528 m .42672 .64663 L .42448 .64511 L F
.405 .31 .634 r
.23724 .56517 m .23936 .56429 L .23898 .56137 L F
.429 .248 .532 r
.2369 .56703 m .23936 .56429 L .23724 .56517 L F
0 0 0 r
.60585 .50019 m .60829 .49741 L .6067 .49954 L F
.003 0 .03 r
.6067 .49954 m .60829 .49741 L .61003 .49614 L F
0 0 0 r
.63095 .40413 m .62976 .40604 L .62807 .40734 L F
.62976 .40604 m .62725 .40902 L .62807 .40734 L F
.874 .994 .763 r
.60752 .42117 m .6083 .41871 L .60886 .41929 L F
.60752 .42117 m .60598 .42182 L .6083 .41871 L F
.225 .612 .953 r
.51185 .56525 m .51301 .56443 L .51057 .56412 L F
.51185 .56525 m .51385 .5655 L .51301 .56443 L F
.707 .807 .928 r
.44269 .5795 m .44019 .57878 L .44244 .57798 L F
.353 .698 .983 r
.44244 .57798 m .44507 .57794 L .44269 .5795 L F
.44507 .57794 m .44525 .57795 L .44269 .5795 L F
.537 .641 .9 r
.44527 .57793 m .44524 .58062 L .44269 .5795 L F
.203 .728 .736 r
.44019 .57878 m .43918 .57895 L .44154 .57839 L F
.361 0 0 r
.43918 .57895 m .44393 .57912 L .44154 .57839 L F
.43918 .57895 m .4389 .57914 L .44393 .57912 L F
.584 .223 .324 r
.44393 .57912 m .4428 .57937 L .44265 .57925 L F
.788 .555 .584 r
.43839 .58031 m .44301 .58162 L .44393 .57912 L F
.584 .223 .324 r
.44393 .57912 m .44358 .57997 L .4428 .57937 L F
.535 .248 .426 r
.44301 .57926 m .44358 .57997 L .44381 .57928 L F
.44265 .57925 m .4428 .57937 L .44301 .57926 L F
.4428 .57937 m .44358 .57997 L .44301 .57926 L F
.788 .555 .584 r
.43755 .58007 m .43839 .58031 L .4428 .57937 L F
.44301 .57926 m .4428 .57937 L .44393 .57912 L F
.43755 .58007 m .4428 .57937 L .44301 .57926 L F
.361 0 0 r
.4389 .57914 m .44301 .57926 L .44393 .57912 L F
.584 .223 .324 r
.44393 .57912 m .44265 .57925 L .44154 .57839 L F
.361 0 0 r
.44265 .57925 m .43755 .58007 L .44301 .57926 L F
.4389 .57914 m .4381 .5797 L .44265 .57925 L F
.4381 .5797 m .43755 .58007 L .44265 .57925 L F
.535 .248 .426 r
.44154 .57839 m .44265 .57925 L .44427 .57789 L F
.44265 .57925 m .44381 .57928 L .44427 .57789 L F
.486 .434 .724 r
.44431 .57776 m .44527 .57793 L .44244 .57798 L F
.535 .248 .426 r
.44385 .57786 m .44427 .57789 L .44431 .57776 L F
.44154 .57839 m .44427 .57789 L .44385 .57786 L F
.353 .698 .983 r
.44507 .57794 m .44527 .57793 L .44525 .57795 L F
.292 .059 .378 r
.58529 .52305 m .58571 .52091 L .58764 .51997 L F
.69 .826 .949 r
.6904 .40837 m .69149 .40594 L .68915 .40694 L F
.6904 .40837 m .69277 .40732 L .69149 .40594 L F
.514 .274 .489 r
.59548 .51182 m .59581 .51337 L .59355 .51432 L F
.21 0 .308 r
.59581 .51337 m .59757 .51162 L .59767 .51343 L F
.073 0 .156 r
.59822 .51105 m .59757 .51162 L .59581 .51337 L F
.59822 .51105 m .59581 .51337 L .59548 .51182 L F
.487 .424 .712 r
.3671 .62194 m .36947 .62318 L .36926 .62099 L F
.85 .547 .475 r
.40918 .5888 m .40911 .59128 L .40876 .59021 L F
.40918 .5888 m .40911 .59128 L .40876 .59021 L F
.639 .807 .964 r
.70466 .44801 m .70557 .44929 L .70192 .44898 L F
.518 .745 .978 r
.70806 .4489 m .70557 .44929 L .70466 .44801 L F
.599 .368 .537 r
.23064 .5915 m .23318 .59123 L .23352 .58881 L F
.45 .798 .998 r
.23432 .58731 m .23592 .58677 L .2351 .58666 L F
.405 .488 .832 r
.23144 .58563 m .23432 .58731 L .23302 .58405 L F
.276 .48 .877 r
.23144 .58563 m .23316 .58826 L .23432 .58731 L F
.45 .798 .998 r
.23432 .58731 m .23217 .58628 L .23302 .58405 L F
.23432 .58731 m .2351 .58666 L .23217 .58628 L F
.276 .48 .877 r
.23316 .58826 m .23352 .58881 L .23432 .58731 L F
.56 .535 .784 r
.23318 .59123 m .23432 .58731 L .23352 .58881 L F
0 0 .109 r
.6052 .50162 m .60585 .50019 L .6067 .49954 L F
.594 .754 .954 r
.70252 .40761 m .70403 .40533 L .70142 .40609 L F
.70252 .40761 m .70504 .40693 L .70403 .40533 L F
.904 .867 .792 r
.41262 .60312 m .4123 .59907 L .41436 .60255 L F
.41262 .60312 m .41014 .60214 L .4123 .59907 L F
.589 .889 .99 r
.70099 .45863 m .70437 .45844 L .7034 .45766 L F
.632 .898 .986 r
.7034 .45766 m .70437 .45844 L .70651 .45749 L F
.825 .663 .683 r
.55056 .51461 m .5534 .51483 L .55239 .5116 L F
.632 .361 .489 r
.55011 .51729 m .5534 .51483 L .55056 .51461 L F
.55011 .51729 m .55339 .5165 L .5534 .51483 L F
.588 .46 .673 r
.5534 .51483 m .55605 .51189 L .55239 .5116 L F
.5534 .51483 m .55596 .51435 L .55605 .51189 L F
.604 .388 .561 r
.55339 .5165 m .55596 .51435 L .5534 .51483 L F
.434 .829 .983 r
.459 .59485 m .46179 .59429 L .46295 .59498 L F
.703 .946 .958 r
.46295 .59498 m .46179 .59429 L .46382 .5928 L F
.378 .071 .312 r
.46524 .59447 m .46228 .59683 L .46295 .59498 L F
.869 .799 .778 r
.21835 .56729 m .21881 .5709 L .22051 .56865 L F
.502 .371 .634 r
.36617 .60342 m .36837 .60283 L .36809 .60026 L F
.488 .367 .641 r
.36617 .60342 m .36875 .60552 L .36837 .60283 L F
.36617 .60342 m .36635 .60704 L .36875 .60552 L F
.235 0 0 r
.18917 .55513 m .18763 .55609 L .18555 .55637 L F
.586 .213 .301 r
.1911 .55532 m .18763 .55609 L .18917 .55513 L F
.665 .918 .609 r
.73462 .42644 m .73244 .42895 L .73354 .42721 L F
.114 .263 .74 r
.73244 .42895 m .73414 .43031 L .73354 .42721 L F
.412 .634 .946 r
.38067 .63184 m .38179 .6335 L .38269 .63179 L F
.41 .631 .945 r
.38179 .6335 m .38378 .6334 L .38269 .63179 L F
0 .074 .636 r
.3895 .63889 m .38971 .63783 L .38785 .63563 L F
0 .25 .763 r
.3895 .63889 m .39171 .64065 L .38971 .63783 L F
.444 .839 .98 r
.41892 .59685 m .423 .59679 L .42026 .59745 L F
.475 .329 .603 r
.25555 .59649 m .2534 .59465 L .2552 .59395 L F
.25555 .59649 m .25347 .59725 L .2534 .59465 L F
.454 .284 .56 r
.62762 .43176 m .63016 .43314 L .63019 .43094 L F
.62762 .43176 m .62774 .43431 L .63016 .43314 L F
.744 .514 0 r
.76519 .4123 m .76558 .41434 L .76495 .41068 L F
.37 .61 .942 r
.76665 .41266 m .76558 .41434 L .76519 .4123 L F
.76665 .41266 m .76717 .41452 L .76558 .41434 L F
.561 .372 .583 r
.55852 .53848 m .55861 .54096 L .55611 .54151 L F
.557 .377 .593 r
.56111 .53798 m .55861 .54096 L .55852 .53848 L F
.471 .376 .666 r
.39634 .61565 m .3961 .61764 L .39403 .61765 L F
.598 .877 .993 r
.6557 .40753 m .65892 .40757 L .65649 .40846 L F
.565 .738 .957 r
.4406 .59238 m .44339 .59209 L .4419 .59053 L F
.616 .651 .862 r
.71573 .39933 m .71335 .40037 L .71222 .39805 L F
.336 .743 .981 r
.46443 .63585 m .4675 .63611 L .46597 .63666 L F
.689 .621 .775 r
.67435 .40569 m .67222 .40646 L .6735 .40781 L F
.67435 .40569 m .67276 .40546 L .67222 .40646 L F
.67435 .40569 m .67184 .40512 L .67276 .40546 L F
.639 .343 .453 r
.67435 .40569 m .67735 .40621 L .67771 .40767 L F
.961 .827 .664 r
.73818 .40503 m .73771 .40157 L .73531 .40459 L F
.655 .97 .887 r
.73322 .40879 m .73631 .40779 L .73524 .40681 L F
.73396 .40727 m .73524 .40681 L .73521 .40679 L F
.846 .587 .547 r
.7346 .40609 m .73573 .40664 L .73531 .40459 L F
.73412 .40709 m .73521 .40679 L .7346 .40609 L F
.73521 .40679 m .73573 .40664 L .7346 .40609 L F
.655 .162 0 r
.73521 .40679 m .73631 .40779 L .73594 .40761 L F
.655 .97 .887 r
.73396 .40727 m .73521 .40679 L .73406 .40711 L F
.73284 .40916 m .73524 .40681 L .73396 .40727 L F
.846 .587 .547 r
.73412 .40709 m .73594 .40761 L .73573 .40664 L F
.655 .162 0 r
.73459 .40622 m .73521 .40679 L .73594 .40761 L F
.655 .97 .887 r
.73406 .40711 m .73521 .40679 L .73459 .40622 L F
.846 .587 .547 r
.73227 .40656 m .73412 .40709 L .73531 .40459 L F
.752 .775 .872 r
.73459 .40622 m .73594 .40761 L .73412 .40709 L F
.73459 .40622 m .73412 .40709 L .73227 .40656 L F
.655 .97 .887 r
.73284 .40916 m .73307 .40907 L .73322 .40879 L F
.73307 .40907 m .73631 .40779 L .73322 .40879 L F
.825 .967 .649 r
.73573 .40664 m .73818 .40503 L .73531 .40459 L F
.73594 .40761 m .73725 .4061 L .73573 .40664 L F
.73725 .4061 m .73818 .40503 L .73573 .40664 L F
.73594 .40761 m .73631 .40779 L .73818 .40503 L F
.834 .971 .886 r
.43151 .56944 m .43323 .56902 L .43185 .5677 L F
.613 .705 .91 r
.36947 .62318 m .3709 .62498 L .37302 .62427 L F
.675 .299 0 r
.65869 .41819 m .65953 .4198 L .66028 .42142 L F
.444 .288 .574 r
.2643 .57675 m .2642 .57928 L .26228 .57989 L F
.445 .255 .527 r
.26414 .58173 m .26228 .57989 L .2642 .57928 L F
.26414 .58173 m .26211 .58235 L .26228 .57989 L F
.659 .773 .934 r
.70513 .39602 m .70362 .39885 L .70243 .39732 L F
.70513 .39602 m .70605 .39796 L .70362 .39885 L F
.165 .603 .936 r
.67222 .40831 m .6688 .40701 L .66922 .41045 L F
.951 .9 .738 r
.6686 .41307 m .67222 .40831 L .66922 .41045 L F
.986 .842 .615 r
.66752 .41185 m .6686 .41307 L .66922 .41045 L F
.168 .559 .932 r
.66765 .41191 m .6686 .41307 L .66752 .41185 L F
.951 .9 .738 r
.6686 .41307 m .66966 .41438 L .67222 .40831 L F
.168 .559 .932 r
.67167 .4138 m .6686 .41307 L .66765 .41191 L F
.951 .9 .738 r
.6686 .41307 m .66953 .41469 L .66966 .41438 L F
.336 .624 .957 r
.2526 .54652 m .25205 .54798 L .25053 .54663 L F
.2526 .54652 m .25511 .54864 L .25205 .54798 L F
.903 .614 .114 r
.5204 .57697 m .52001 .57689 L .51965 .5755 L F
.5204 .57697 m .52054 .57878 L .52001 .57689 L F
.45 .388 .696 r
.16722 .5626 m .16592 .56213 L .16749 .56237 L F
.16722 .5626 m .16636 .56435 L .16592 .56213 L F
.128 .367 .826 r
.40043 .61943 m .40191 .62035 L .39925 .61897 L F
.876 .536 .404 r
.42814 .63611 m .43195 .6364 L .42907 .63508 L F
.42814 .63611 m .43057 .63841 L .43195 .6364 L F
.574 .154 .207 r
.43195 .6364 m .43057 .63841 L .43384 .63794 L F
.447 .202 .449 r
.43195 .6364 m .43384 .63794 L .43422 .63569 L F
0 0 .354 r
.59955 .4518 m .59872 .45543 L .60116 .45255 L F
.59955 .4518 m .59976 .45398 L .59872 .45543 L F
.59 .833 .459 r
.59976 .45398 m .59764 .45675 L .59872 .45543 L F
.316 .093 .408 r
.24405 .61474 m .24235 .61539 L .2446 .61236 L F
.365 .185 .5 r
.24395 .61719 m .24235 .61539 L .24405 .61474 L F
.24395 .61719 m .24214 .61789 L .24235 .61539 L F
.666 .935 .968 r
.73082 .44414 m .73249 .4447 L .73474 .44346 L F
0 0 0 r
.5386 .56714 m .53653 .56951 L .53715 .56812 L F
.881 .967 .844 r
.62221 .45476 m .62155 .45593 L .61908 .45655 L F
.632 .776 .95 r
.53434 .58678 m .53197 .58563 L .53419 .58506 L F
.543 .322 .53 r
.55611 .54151 m .55859 .54341 L .55606 .5437 L F
.55611 .54151 m .55861 .54096 L .55859 .54341 L F
.537 .881 .634 r
.41266 .57691 m .41383 .57572 L .41543 .57465 L F
.629 .923 .657 r
.41543 .57465 m .41542 .5741 L .41759 .57383 L F
.41543 .57465 m .41383 .57572 L .41542 .5741 L F
.413 .648 .955 r
.52175 .58299 m .52373 .58315 L .52283 .58133 L F
.464 .769 .996 r
.75188 .39977 m .75321 .39903 L .74971 .39922 L F
.74971 .39922 m .75321 .39903 L .75188 .39977 L F
.478 .363 .645 r
.23651 .57181 m .2383 .57256 L .23815 .57011 L F
.5 .303 .544 r
.23544 .57625 m .2383 .57256 L .23651 .57181 L F
.89 .982 .7 r
.55547 .4834 m .55644 .48043 L .55733 .48099 L F
.352 .137 .442 r
.61722 .41583 m .61471 .41949 L .61502 .4167 L F
.614 .451 .637 r
.55877 .62445 m .56114 .62356 L .5612 .62137 L F
.888 .99 .76 r
.50681 .54119 m .50756 .53883 L .50911 .53844 L F
.755 .617 .706 r
.50877 .54081 m .50681 .54119 L .50911 .53844 L F
.636 .838 .978 r
.51131 .53745 m .50911 .53844 L .50994 .53649 L F
.801 1 .824 r
.50911 .53844 m .50756 .53883 L .50994 .53649 L F
.266 .441 .849 r
.22578 .55548 m .22401 .55201 L .22555 .55325 L F
.523 .415 .673 r
.2596 .58536 m .25999 .58806 L .25742 .58592 L F
.494 .416 .697 r
.25999 .58806 m .25801 .5888 L .25742 .58592 L F
.377 .235 .558 r
.55362 .54699 m .55376 .54947 L .5518 .55025 L F
.21 0 .27 r
.55376 .54947 m .55117 .55256 L .5518 .55025 L F
.498 .346 .605 r
.26373 .56459 m .2619 .56787 L .26192 .565 L F
.271 .749 .933 r
.21921 .54134 m .22123 .54117 L .22303 .54162 L F
.222 .721 .91 r
.22123 .54117 m .2252 .54148 L .22303 .54162 L F
.527 .467 .733 r
.39692 .60636 m .39721 .60867 L .39511 .60923 L F
0 0 0 r
.59704 .43457 m .59445 .43735 L .5962 .43599 L F
.59445 .43735 m .59339 .43886 L .5962 .43599 L F
.405 .675 .971 r
.67303 .41461 m .66953 .41469 L .6686 .41307 L F
0 0 0 r
.48043 .58694 m .47975 .58671 L .48184 .58585 L F
.48043 .58694 m .47859 .58806 L .47975 .58671 L F
.854 .799 .796 r
.63025 .44404 m .62988 .44585 L .62677 .44568 L F
.855 .797 .793 r
.62988 .44585 m .6276 .44893 L .62677 .44568 L F
.601 .658 .878 r
.44428 .56728 m .44763 .56809 L .44658 .56557 L F
.482 .586 .882 r
.74903 .42305 m .75127 .42038 L .74767 .41924 L F
.74903 .42305 m .75197 .4229 L .75127 .42038 L F
.859 .618 .573 r
.74903 .42305 m .74997 .42611 L .75197 .4229 L F
.808 .83 .868 r
.54375 .67364 m .54451 .67622 L .54542 .67451 L F
.774 .71 .792 r
.44989 .58297 m .4515 .58562 L .44794 .58518 L F
.706 .266 .203 r
.4515 .58562 m .45008 .58724 L .44794 .58518 L F
.147 .386 .837 r
.4528 .58504 m .4515 .58562 L .44989 .58297 L F
0 0 0 r
.4528 .58504 m .45008 .58724 L .4515 .58562 L F
.389 .168 .454 r
.67119 .42225 m .67137 .42011 L .67356 .41917 L F
.45 .388 .696 r
.16722 .5626 m .16757 .56461 L .16636 .56435 L F
.648 .41 .545 r
.40432 .62126 m .4038 .624 L .40116 .62392 L F
.406 .19 .47 r
.40587 .62324 m .40432 .62126 L .40577 .62054 L F
.40587 .62324 m .4038 .624 L .40432 .62126 L F
.686 .213 .122 r
.42194 .63308 m .42077 .63462 L .42406 .63495 L F
.636 .264 .323 r
.42194 .63308 m .42406 .63495 L .42448 .63347 L F
.475 .37 .656 r
.54941 .55567 m .55016 .55894 L .54777 .55902 L F
.714 .951 .662 r
.55016 .55894 m .54761 .56205 L .54777 .55902 L F
.294 0 0 r
.63071 .40077 m .63217 .40092 L .63035 .40056 L F
.63 .959 .808 r
.67989 .41282 m .68427 .41047 L .68335 .40973 L F
.67989 .41282 m .6821 .41187 L .68427 .41047 L F
.597 .418 .611 r
.54461 .57405 m .54209 .57719 L .54244 .57516 L F
.531 .568 .837 r
.47585 .57241 m .47352 .57293 L .47232 .56976 L F
.578 .061 0 r
.1852 .5409 m .18703 .54214 L .18905 .54119 L F
.436 0 0 r
.18703 .54214 m .19123 .54093 L .18905 .54119 L F
.655 .531 .701 r
.56114 .62356 m .5634 .62078 L .5612 .62137 L F
.736 .506 .579 r
.39252 .6421 m .39608 .64278 L .3937 .64057 L F
.39252 .6421 m .39281 .64447 L .39608 .64278 L F
.023 .466 .875 r
.39608 .64278 m .39648 .64172 L .3937 .64057 L F
.39608 .64278 m .39819 .64308 L .39648 .64172 L F
.83 .902 .89 r
.55557 .50416 m .55504 .50651 L .55725 .50512 L F
.888 .889 .826 r
.55803 .50115 m .55725 .50512 L .5595 .50256 L F
.55803 .50115 m .55557 .50416 L .55725 .50512 L F
.635 .701 .893 r
.69232 .45074 m .69113 .45356 L .68999 .45207 L F
.69232 .45074 m .69368 .45266 L .69113 .45356 L F
.923 .631 .473 r
.51104 .54279 m .51293 .54498 L .51155 .54395 L F
.619 .839 .984 r
.43139 .57964 m .43202 .58049 L .43428 .57981 L F
.004 0 0 r
.43202 .58049 m .43287 .58107 L .43428 .57981 L F
.43202 .58049 m .43092 .58186 L .43287 .58107 L F
.633 .805 .965 r
.66089 .40689 m .66231 .40804 L .65892 .40757 L F
.768 .835 .903 r
.66489 .40485 m .66231 .40804 L .66089 .40689 L F
.12 0 .239 r
.22516 .64127 m .22292 .64438 L .22369 .64219 L F
0 .04 .573 r
.44039 .58454 m .43916 .58352 L .44142 .58266 L F
0 0 .517 r
.21323 .61302 m .21435 .61373 L .21533 .61153 L F
.547 .903 .694 r
.41266 .57691 m .41089 .5779 L .41383 .57572 L F
.54 .328 .541 r
.60737 .45252 m .60992 .45218 L .60996 .44955 L F
.60737 .45252 m .60992 .45218 L .60996 .44955 L F
.498 .294 .534 r
.61236 .45145 m .60996 .44955 L .61217 .44884 L F
.61236 .45145 m .60992 .45218 L .60996 .44955 L F
.60996 .44955 m .61236 .45145 L .61217 .44884 L F
.60996 .44955 m .60992 .45218 L .61236 .45145 L F
.987 .713 .374 r
.63019 .43094 m .63016 .43314 L .63121 .43358 L F
.815 .467 .397 r
.53304 .59192 m .52989 .59299 L .52952 .59075 L F
.53304 .59192 m .53278 .59355 L .52989 .59299 L F
.582 .245 .363 r
.53304 .59192 m .53521 .59362 L .53278 .59355 L F
.556 .393 .616 r
.53536 .58857 m .53537 .59136 L .53304 .59192 L F
.512 .273 .49 r
.53537 .59136 m .53521 .59362 L .53304 .59192 L F
.871 .801 .778 r
.7611 .42025 m .75758 .42214 L .75727 .41965 L F
.7611 .42025 m .75926 .42303 L .75758 .42214 L F
.267 0 .187 r
.21998 .64698 m .21818 .64766 L .22111 .64521 L F
0 0 0 r
.22292 .64438 m .21998 .64698 L .22111 .64521 L F
.791 .998 .807 r
.54182 .68433 m .54381 .68341 L .54278 .68369 L F
.556 .241 .389 r
.58769 .51773 m .59007 .51941 L .58764 .51997 L F
.58769 .51773 m .59044 .5176 L .59007 .51941 L F
.291 .038 .346 r
.5978 .50871 m .5999 .50992 L .59822 .51105 L F
.5978 .50871 m .60046 .5079 L .5999 .50992 L F
.535 .921 .805 r
.5903 .46556 m .59087 .46432 L .5909 .46378 L F
.275 .067 .405 r
.59305 .46052 m .5909 .46378 L .59087 .46432 L F
.41 .146 .399 r
.40729 .60002 m .40413 .60235 L .40628 .60107 L F
.946 .589 .281 r
.50984 .55276 m .5089 .55429 L .50798 .55227 L F
.50984 .55276 m .51052 .55517 L .5089 .55429 L F
.648 .672 .859 r
.72689 .39752 m .72864 .40274 L .72559 .40175 L F
.647 .579 .764 r
.73177 .40034 m .72918 .40242 L .72864 .40274 L F
.583 .92 .966 r
.7425 .4397 m .74094 .4413 L .74255 .43971 L F
.7425 .4397 m .73949 .44081 L .74094 .4413 L F
.967 .758 .569 r
.65 .43941 m .65186 .43776 L .65074 .43695 L F
.65 .43941 m .65146 .4408 L .65186 .43776 L F
.181 .034 .432 r
.64287 .42943 m .64123 .43312 L .64182 .43068 L F
.899 .805 .747 r
.64123 .43312 m .63953 .43379 L .64182 .43068 L F
.427 .655 .955 r
.71717 .40778 m .7197 .41025 L .72119 .40965 L F
.126 0 .161 r
.58394 .50002 m .58142 .50284 L .58337 .50173 L F
.355 .023 .258 r
.58394 .50002 m .58585 .50099 L .5862 .49926 L F
.58394 .50002 m .58337 .50173 L .58585 .50099 L F
.471 .855 .981 r
.41648 .60905 m .41773 .60848 L .41844 .60861 L F
.41773 .60848 m .41883 .60797 L .41844 .60861 L F
.587 .473 .691 r
.41907 .60847 m .41783 .61029 L .41648 .60905 L F
.397 .448 .796 r
.41648 .60905 m .41783 .61029 L .41883 .60797 L F
.471 .855 .981 r
.41844 .60861 m .41883 .60797 L .41907 .60847 L F
.538 .41 .654 r
.42132 .60845 m .41783 .61029 L .41907 .60847 L F
.299 .73 .969 r
.41883 .60797 m .42132 .60845 L .41907 .60847 L F
.67 .766 .922 r
.41883 .60797 m .41783 .61029 L .42132 .60845 L F
.168 0 0 r
.41845 .60992 m .41496 .61112 L .41647 .61078 L F
.871 .474 .277 r
.41845 .60992 m .41637 .61061 L .41471 .60789 L F
.41845 .60992 m .41471 .60789 L .41576 .60809 L F
.41845 .60992 m .41417 .60703 L .41883 .60797 L F
0 0 .25 r
.41883 .60797 m .41926 .60944 L .41845 .60992 L F
.285 .773 .7 r
.41854 .60987 m .41637 .61061 L .41845 .60992 L F
.41628 .61064 m .41496 .61112 L .41845 .60992 L F
.847 .659 .648 r
.41496 .61112 m .41263 .6091 L .41622 .61066 L F
.285 .773 .7 r
.41574 .61082 m .41496 .61112 L .41628 .61064 L F
.847 .659 .648 r
.41496 .61112 m .41622 .61066 L .41647 .61078 L F
.871 .474 .277 r
.41845 .60992 m .41647 .61078 L .41637 .61061 L F
.285 .773 .7 r
.41904 .60957 m .41845 .60992 L .41926 .60944 L F
.232 0 0 r
.41904 .60957 m .41753 .61125 L .41538 .61114 L F
.41556 .61089 m .41538 .61114 L .41496 .61112 L F
.85 .483 .356 r
.41637 .61061 m .41647 .61078 L .41622 .61066 L F
.285 .773 .7 r
.41904 .60957 m .41574 .61082 L .41637 .61061 L F
.41904 .60957 m .41637 .61061 L .41854 .60987 L F
.232 0 0 r
.41904 .60957 m .41538 .61114 L .41556 .61089 L F
.85 .483 .356 r
.41417 .60703 m .41609 .61015 L .41263 .6091 L F
.41609 .61015 m .41637 .61061 L .4159 .61042 L F
.41609 .61015 m .4159 .61042 L .41263 .6091 L F
.41637 .61061 m .41622 .61066 L .41263 .6091 L F
.871 .474 .277 r
.41576 .60809 m .41471 .60789 L .41417 .60703 L F
.18 0 .21 r
.22775 .63845 m .22516 .64127 L .22603 .63929 L F
0 0 .379 r
.42364 .59835 m .424 .60021 L .423 .59679 L F
.94 .929 .766 r
.42364 .59835 m .42257 .59994 L .424 .60021 L F
.824 .736 .767 r
.6839 .45174 m .68464 .45531 L .68154 .4547 L F
.836 .523 .459 r
.68154 .4547 m .68464 .45531 L .68516 .45772 L F
.702 .659 .805 r
.68737 .453 m .68464 .45531 L .6839 .45174 L F
.254 0 .203 r
.53589 .57374 m .53456 .57645 L .53265 .5767 L F
0 0 0 r
.53627 .57485 m .53589 .57374 L .53721 .5715 L F
.53627 .57485 m .53456 .57645 L .53589 .57374 L F
.468 .257 .509 r
.58142 .50284 m .57899 .50582 L .58133 .50516 L F
.457 .229 .48 r
.58133 .50516 m .57899 .50582 L .57885 .50804 L F
.198 0 .274 r
.58246 .44987 m .58195 .45179 L .58435 .44877 L F
.925 .667 .18 r
.52745 .51372 m .52801 .51411 L .52816 .51685 L F
.707 .985 .862 r
.53052 .51202 m .52801 .51411 L .52745 .51372 L F
.442 .12 .324 r
.17319 .54433 m .17589 .54355 L .17371 .54271 L F
.613 .705 .91 r
.47922 .57357 m .47678 .5741 L .47585 .57241 L F
.684 .447 .558 r
.57707 .5269 m .57703 .5294 L .5745 .52894 L F
.571 .332 .514 r
.57707 .5269 m .57971 .5287 L .57703 .5294 L F
.57707 .5269 m .57971 .52536 L .57971 .5287 L F
.902 .915 .82 r
.62967 .46625 m .6302 .46802 L .63226 .4648 L F
.92 .919 .797 r
.62895 .46949 m .6302 .46802 L .62967 .46625 L F
.775 .33 .195 r
.73892 .42763 m .74137 .42922 L .7401 .42687 L F
0 0 .482 r
.63917 .41665 m .63899 .41288 L .64138 .41356 L F
.63917 .41665 m .63992 .41535 L .63899 .41288 L F
.806 .565 .005 r
.63917 .41665 m .63951 .41901 L .63922 .41851 L F
.63917 .41665 m .63922 .41851 L .63992 .41535 L F
.372 .153 .446 r
.24644 .61153 m .24405 .61474 L .2446 .61236 L F
.414 .413 .749 r
.46893 .57964 m .47065 .57908 L .46764 .5759 L F
.745 .744 .851 r
.51585 .52613 m .5162 .52939 L .51255 .52893 L F
.789 .523 .536 r
.5162 .52939 m .51261 .5313 L .51255 .52893 L F
.5162 .52939 m .51649 .53232 L .51261 .5313 L F
.848 .822 .822 r
.51706 .52508 m .5162 .52939 L .51585 .52613 L F
.51706 .52508 m .51858 .52639 L .5162 .52939 L F
.499 .311 .557 r
.5186 .5313 m .51649 .53232 L .5162 .52939 L F
0 .166 .683 r
.37357 .63206 m .37318 .62859 L .37081 .62862 L F
.291 0 0 r
.37537 .63217 m .37437 .63237 L .37357 .63206 L F
0 .166 .683 r
.37357 .63206 m .37437 .63237 L .37318 .62859 L F
0 0 0 r
.59704 .43457 m .59934 .43113 L .59924 .43116 L F
.59704 .43457 m .59837 .4328 L .59934 .43113 L F
.59704 .43457 m .5962 .43599 L .59837 .4328 L F
.214 0 0 r
.19783 .554 m .19548 .55453 L .19762 .55277 L F
0 0 .572 r
.65486 .41091 m .65645 .41311 L .65596 .41162 L F
.886 .475 .051 r
.65486 .41091 m .65699 .41477 L .65645 .41311 L F
.44 .141 .361 r
.61307 .42732 m .61104 .42618 L .6132 .42524 L F
.61307 .42732 m .61062 .42799 L .61104 .42618 L F
.854 .796 .794 r
.62677 .44568 m .6276 .44893 L .62457 .44865 L F
.834 .827 .841 r
.62457 .44865 m .6276 .44893 L .62454 .45136 L F
.677 .252 .229 r
.4184 .64434 m .41698 .64617 L .41497 .64427 L F
.624 .223 .263 r
.42075 .64455 m .41698 .64617 L .4184 .64434 L F
.322 0 .199 r
.19358 .67732 m .19538 .67715 L .19731 .67441 L F
.656 .343 .429 r
.19731 .67441 m .19922 .67614 L .19868 .67355 L F
.19731 .67441 m .19538 .67715 L .19922 .67614 L F
.488 0 0 r
.45027 .63797 m .45338 .63883 L .45083 .63911 L F
.701 .522 .643 r
.45384 .63965 m .45083 .63911 L .45338 .63883 L F
.45384 .63965 m .45105 .64185 L .45083 .63911 L F
.312 .134 .471 r
.58337 .50173 m .58142 .50284 L .58133 .50516 L F
.533 .661 .918 r
.64848 .40515 m .64706 .40765 L .64535 .40453 L F
.64848 .40515 m .64933 .40712 L .64706 .40765 L F
.424 .298 .603 r
.6495 .40951 m .64706 .40765 L .64933 .40712 L F
.6495 .40951 m .64746 .41053 L .64706 .40765 L F
.826 .681 .703 r
.63951 .41901 m .64063 .42328 L .63752 .42161 L F
.688 .143 0 r
.63752 .42161 m .64063 .42328 L .63992 .42378 L F
.726 .196 0 r
.64063 .42328 m .64263 .42544 L .63992 .42378 L F
.328 0 .159 r
.61765 .4064 m .62073 .40461 L .61839 .40472 L F
0 0 0 r
.59924 .43116 m .60058 .42953 L .60175 .42828 L F
.59924 .43116 m .59934 .43113 L .60058 .42953 L F
.237 .005 .345 r
.60726 .47865 m .60519 .48041 L .60446 .48218 L F
.031 0 0 r
.74362 .43631 m .74544 .43552 L .74546 .43473 L F
.587 .246 .359 r
.74773 .4311 m .74598 .43272 L .74672 .4306 L F
.706 .911 .559 r
.74546 .43473 m .74666 .43238 L .74771 .43165 L F
.74666 .43238 m .74668 .43236 L .74771 .43165 L F
.953 .937 .735 r
.74771 .43165 m .74853 .42778 L .74987 .42874 L F
.74771 .43165 m .74672 .4306 L .74853 .42778 L F
.006 0 0 r
.74771 .43165 m .74911 .43178 L .74672 .4306 L F
.74771 .43165 m .74668 .43236 L .74911 .43178 L F
.587 .246 .359 r
.74911 .43178 m .74672 .4324 L .74668 .43236 L F
.604 .514 .726 r
.74667 .43236 m .74672 .4324 L .74911 .43178 L F
.74672 .4324 m .74886 .43398 L .74911 .43178 L F
.587 .246 .359 r
.74911 .43178 m .7468 .43247 L .74672 .4324 L F
.39 .357 .702 r
.74544 .43552 m .74711 .43568 L .74675 .43294 L F
.74647 .43291 m .74675 .43294 L .74667 .4324 L F
.74544 .43552 m .74675 .43294 L .74647 .43291 L F
.604 .514 .726 r
.74672 .4324 m .74711 .43568 L .74886 .43398 L F
.587 .246 .359 r
.74672 .4324 m .74666 .43238 L .74668 .43236 L F
.74667 .4324 m .74666 .43238 L .74672 .4324 L F
.74651 .43256 m .74598 .43272 L .74773 .4311 L F
.706 .911 .559 r
.74666 .43238 m .74667 .43236 L .74668 .43236 L F
.604 .514 .726 r
.74667 .43236 m .74667 .4324 L .74672 .4324 L F
.74667 .4324 m .74711 .43568 L .74672 .4324 L F
.587 .246 .359 r
.7468 .43247 m .74667 .4324 L .74672 .4324 L F
.39 .006 .185 r
.74763 .43305 m .74868 .43392 L .74594 .4345 L F
.74875 .43209 m .74871 .43318 L .74763 .43305 L F
.006 0 0 r
.74668 .43236 m .74667 .43236 L .74911 .43178 L F
.587 .246 .359 r
.74911 .43178 m .74668 .43236 L .74773 .4311 L F
.39 .357 .702 r
.74544 .43552 m .74667 .4324 L .74666 .43239 L F
.74667 .43238 m .74667 .43237 L .74546 .43473 L F
.39 .006 .185 r
.74663 .43253 m .74594 .4345 L .74598 .43272 L F
.74875 .43189 m .74614 .43433 L .74663 .43253 L F
.74875 .43209 m .74614 .43433 L .74875 .43189 L F
.811 .621 .065 r
.74876 .43338 m .74868 .43392 L .74849 .4317 L F
.74886 .43398 m .74876 .43395 L .74876 .43338 L F
.74876 .43395 m .74868 .43392 L .74876 .43338 L F
.39 .006 .185 r
.74911 .43178 m .74875 .43209 L .74875 .43189 L F
.74614 .43433 m .74594 .4345 L .74663 .43253 L F
.39 .357 .702 r
.74544 .43552 m .74667 .43238 L .74546 .43473 L F
.74667 .43238 m .74667 .43236 L .74667 .43237 L F
.811 .621 .065 r
.74871 .43309 m .74868 .43392 L .74849 .4317 L F
.74886 .43398 m .74868 .43392 L .74871 .43309 L F
.39 .006 .185 r
.74911 .43178 m .74883 .43319 L .74871 .43318 L F
.74911 .43178 m .74871 .43318 L .74875 .43209 L F
.74883 .43319 m .74868 .43392 L .74763 .43305 L F
.587 .246 .359 r
.7468 .43247 m .74651 .43256 L .74666 .43238 L F
.39 .357 .702 r
.74666 .43239 m .74667 .4324 L .74667 .43236 L F
.825 .803 .83 r
.64138 .41356 m .63899 .41288 L .64106 .41077 L F
.88 .943 .851 r
.54197 .68683 m .53827 .68903 L .54073 .68851 L F
.977 .699 .434 r
.66094 .4258 m .65965 .42723 L .65984 .42474 L F
.66094 .4258 m .66112 .42866 L .65965 .42723 L F
.115 0 .245 r
.22994 .63531 m .22775 .63845 L .22849 .63622 L F
.98 .687 .334 r
.45523 .59358 m .45651 .59458 L .45517 .59113 L F
.995 .825 .56 r
.45651 .59458 m .4554 .59509 L .45523 .59358 L F
.981 .726 .473 r
.45651 .59458 m .45646 .59706 L .4554 .59509 L F
.98 .687 .334 r
.45523 .59358 m .45651 .59458 L .45517 .59113 L F
.995 .825 .56 r
.45651 .59458 m .4554 .59509 L .45523 .59358 L F
.734 .265 .134 r
.22926 .55678 m .22739 .5576 L .22578 .55548 L F
.298 .77 .653 r
.22983 .5565 m .22926 .55678 L .23164 .55703 L F
.22983 .5565 m .22739 .5576 L .22926 .55678 L F
.404 .147 .408 r
.57649 .5087 m .57388 .51161 L .57618 .51089 L F
.492 .245 .467 r
.57618 .51089 m .57885 .50804 L .57649 .5087 L F
.642 .174 .126 r
.74369 .43145 m .74049 .43078 L .74148 .4321 L F
0 0 0 r
.41744 .59067 m .41974 .59014 L .42196 .58939 L F
.958 .916 .726 r
.42196 .58939 m .42118 .5872 L .42227 .58846 L F
.42196 .58939 m .41974 .59014 L .42118 .5872 L F
.005 .141 .656 r
.42196 .58939 m .42331 .59071 L .42227 .58846 L F
.31 .525 .901 r
.51385 .5655 m .51606 .56806 L .51681 .56653 L F
0 0 .213 r
.51606 .56806 m .51546 .57058 L .51681 .56891 L F
.74 .975 .923 r
.44826 .59929 m .44664 .6002 L .447 .59898 L F
.56 .342 .541 r
.44524 .58062 m .44039 .58454 L .44142 .58266 L F
.816 .595 .604 r
.22075 .60011 m .22328 .60304 L .22327 .60052 L F
.281 .162 .535 r
.22327 .60052 m .22488 .60199 L .22504 .59978 L F
.22327 .60052 m .22328 .60304 L .22488 .60199 L F
.511 .315 .551 r
.47399 .63294 m .47633 .63244 L .47614 .62954 L F
0 0 0 r
.47614 .62954 m .47817 .62875 L .48024 .62736 L F
.421 .248 .54 r
.47614 .62954 m .47841 .63067 L .47817 .62875 L F
.649 .74 .916 r
.71945 .40046 m .71573 .39933 L .71826 .39856 L F
.632 .742 .927 r
.7208 .39773 m .71945 .40046 L .71826 .39856 L F
.7208 .39773 m .72198 .39956 L .71945 .40046 L F
.584 .049 0 r
.46028 .59761 m .45855 .59851 L .45646 .59706 L F
.544 .108 .164 r
.46228 .59683 m .45855 .59851 L .46028 .59761 L F
.712 .68 .817 r
.64713 .44004 m .64835 .44342 L .65146 .4408 L F
.664 .399 .509 r
.76537 .42603 m .76515 .42808 L .76234 .4283 L F
.354 .168 .484 r
.76755 .42271 m .76756 .42494 L .76537 .42603 L F
.395 .169 .449 r
.76751 .4273 m .76537 .42603 L .76756 .42494 L F
.76751 .4273 m .76515 .42808 L .76537 .42603 L F
0 0 0 r
.7514 .43611 m .75198 .43519 L .75382 .43347 L F
.788 .664 .727 r
.54217 .5798 m .54 .58254 L .53843 .5784 L F
.596 .391 .573 r
.54217 .5798 m .54249 .58261 L .54 .58254 L F
.621 .531 .731 r
.54209 .57719 m .54465 .57678 L .54217 .5798 L F
.667 .441 .569 r
.54527 .58157 m .54249 .58261 L .54217 .5798 L F
.934 .845 .732 r
.55056 .51461 m .55239 .5116 L .55095 .51041 L F
.545 .838 .999 r
.19017 .66177 m .19112 .66024 L .18917 .66093 L F
.344 0 .054 r
.59026 .4979 m .5895 .49634 L .58864 .49866 L F
.59026 .4979 m .59144 .49582 L .5895 .49634 L F
.528 .27 .468 r
.25801 .5888 m .25747 .59106 L .2551 .59142 L F
.436 .186 .435 r
.25968 .59046 m .25801 .5888 L .25999 .58806 L F
.25968 .59046 m .25747 .59106 L .25801 .5888 L F
.934 .939 .776 r
.71276 .44816 m .71083 .44898 L .71254 .44737 L F
.71276 .44816 m .71171 .44987 L .71083 .44898 L F
.226 .744 .85 r
.19123 .54093 m .19331 .54063 L .19516 .54068 L F
.122 .652 .87 r
.19331 .54063 m .19729 .54117 L .19516 .54068 L F
.632 .948 .742 r
.67117 .39713 m .67066 .39815 L .66814 .39991 L F
0 .192 .615 r
.66814 .39991 m .66608 .3986 L .66817 .39825 L F
.632 .948 .742 r
.67117 .39713 m .66814 .39991 L .66817 .39825 L F
.329 .356 .738 r
.66817 .39825 m .66608 .3986 L .66903 .39968 L F
.263 .756 .677 r
.66924 .39783 m .66853 .39811 L .66745 .39938 L F
.66853 .39811 m .66817 .39825 L .6681 .39837 L F
.66853 .39811 m .6681 .39837 L .66745 .39938 L F
.939 .748 .619 r
.66709 .39897 m .6673 .40217 L .66903 .39968 L F
.66608 .3986 m .66636 .3994 L .66709 .39897 L F
.66636 .3994 m .6673 .40217 L .66709 .39897 L F
.563 .764 .973 r
.68154 .4547 m .67893 .45544 L .6778 .45403 L F
.68154 .4547 m .67893 .45544 L .6778 .45403 L F
0 0 0 r
.48024 .62736 m .47817 .62875 L .47946 .62789 L F
.33 .735 .981 r
.67454 .398 m .67066 .39815 L .67117 .39713 L F
.387 .767 .991 r
.6757 .3985 m .67066 .39815 L .67454 .398 L F
.732 .707 .827 r
.21475 .56904 m .21881 .5709 L .21835 .56729 L F
.797 .659 .71 r
.21475 .56904 m .21726 .57363 L .21881 .5709 L F
.516 .293 .514 r
.57971 .52536 m .58255 .52829 L .57971 .5287 L F
.57971 .52536 m .5826 .52467 L .58255 .52829 L F
.829 .4 0 r
.75781 .40894 m .75771 .40973 L .75731 .40709 L F
.75781 .40894 m .75886 .41097 L .75771 .40973 L F
.301 .381 .779 r
.46764 .5759 m .46944 .57546 L .46762 .5757 L F
.46764 .5759 m .47065 .57908 L .46944 .57546 L F
.464 .297 .569 r
.40116 .62392 m .39882 .62688 L .39916 .62533 L F
.40116 .62392 m .40089 .62652 L .39882 .62688 L F
.399 .67 .97 r
.75502 .40711 m .75642 .40566 L .75286 .40424 L F
.75502 .40711 m .75731 .40709 L .75642 .40566 L F
.418 .64 .949 r
.39171 .64065 m .39252 .6421 L .3937 .64057 L F
.829 .419 0 r
.5115 .55886 m .5115 .56012 L .51004 .558 L F
.5115 .55886 m .51236 .56101 L .5115 .56012 L F
.875 .691 .65 r
.65995 .45114 m .65884 .44862 L .66066 .44992 L F
.431 .291 .59 r
.55117 .55256 m .54941 .55567 L .5491 .55317 L F
.96 .866 .701 r
.65992 .43396 m .65989 .4346 L .65934 .4336 L F
0 0 .471 r
.65989 .4346 m .66166 .43653 L .65934 .4336 L F
.87 .864 .831 r
.66186 .43364 m .66127 .43585 L .66332 .43493 L F
0 0 .471 r
.66166 .43653 m .66177 .43665 L .66161 .43644 L F
.66177 .43665 m .66176 .43662 L .66161 .43644 L F
.66166 .43653 m .66161 .43644 L .65934 .4336 L F
.65989 .4346 m .66015 .43646 L .66181 .4367 L F
.522 0 0 r
.66015 .43646 m .6628 .43752 L .66069 .43788 L F
.6628 .43752 m .66398 .43799 L .66069 .43788 L F
.66015 .43646 m .66069 .43788 L .66163 .43667 L F
.666 .158 0 r
.65847 .43306 m .65934 .4336 L .66161 .43644 L F
.65847 .43306 m .66161 .43644 L .66153 .43638 L F
.66164 .4365 m .66176 .43662 L .66171 .43658 L F
.65847 .43306 m .66167 .43653 L .66164 .4365 L F
.66167 .43653 m .66176 .43662 L .66164 .4365 L F
.728 .616 .732 r
.66071 .43794 m .65832 .44096 L .65773 .43464 L F
.87 .865 .831 r
.65832 .44096 m .65832 .44096 L .6595 .43847 L F
.87 .864 .831 r
.66178 .43667 m .66071 .43794 L .6618 .43669 L F
.522 0 0 r
.66163 .43667 m .66071 .43794 L .66177 .43669 L F
.87 .864 .831 r
.66176 .43662 m .66071 .43794 L .66178 .43667 L F
.522 0 0 r
.66177 .43669 m .66071 .43794 L .66181 .4367 L F
.66069 .43788 m .66071 .43794 L .66163 .43667 L F
.728 .616 .732 r
.66071 .43794 m .65773 .43464 L .66163 .43661 L F
.87 .864 .831 r
.66171 .43658 m .66071 .43794 L .66176 .43662 L F
.666 .158 0 r
.66171 .43658 m .66163 .43661 L .66153 .43655 L F
.87 .864 .831 r
.66167 .43655 m .66163 .43661 L .66171 .43658 L F
.66163 .43661 m .66071 .43794 L .66171 .43658 L F
.666 .158 0 r
.66164 .4365 m .66171 .43658 L .66153 .43655 L F
.66171 .43658 m .66181 .4367 L .66163 .43661 L F
.728 .616 .732 r
.66071 .43794 m .66163 .43661 L .66181 .4367 L F
.666 .158 0 r
.65809 .43264 m .6615 .43635 L .65773 .43464 L F
.6615 .43635 m .66164 .4365 L .66142 .4364 L F
.6615 .43635 m .66142 .4364 L .65773 .43464 L F
.66164 .4365 m .66153 .43655 L .65773 .43464 L F
.87 .864 .831 r
.6612 .43613 m .66071 .43794 L .66167 .43655 L F
.896 .905 .824 r
.65899 .43955 m .65837 .44085 L .65953 .43846 L F
.65952 .43847 m .65953 .43846 L .66016 .43717 L F
.65899 .43955 m .65953 .43846 L .65952 .43847 L F
.65837 .44086 m .65837 .44085 L .65899 .43955 L F
.87 .864 .831 r
.65973 .43804 m .65832 .44096 L .66071 .43794 L F
.87 .865 .831 r
.66071 .43794 m .65832 .44096 L .65832 .44096 L F
.87 .864 .831 r
.65832 .44096 m .65832 .44096 L .66071 .43794 L F
.87 .865 .831 r
.66071 .43794 m .65832 .44096 L .6595 .43847 L F
.66071 .43794 m .6595 .43847 L .65918 .43922 L F
0 0 .319 r
.65773 .43464 m .65811 .43866 L .65833 .43548 L F
.65811 .43866 m .65832 .44096 L .65832 .43899 L F
.65811 .43866 m .65832 .43899 L .65833 .43548 L F
.87 .865 .831 r
.65832 .43899 m .65832 .44096 L .65725 .43947 L F
.65832 .43906 m .65725 .43947 L .65759 .43942 L F
.65836 .43904 m .65725 .43947 L .65832 .43906 L F
.6595 .43847 m .65832 .44096 L .65832 .43899 L F
.6595 .43847 m .65832 .43899 L .65836 .43904 L F
.65832 .43899 m .65725 .43947 L .65836 .43904 L F
0 0 .319 r
.65833 .43548 m .65832 .43899 L .65842 .4356 L F
.65832 .43899 m .65832 .44096 L .65836 .43904 L F
.65832 .43899 m .65836 .43904 L .65842 .4356 L F
.896 .905 .824 r
.65837 .43827 m .65834 .43971 L .65973 .43804 L F
.65834 .43971 m .65832 .44092 L .65882 .43988 L F
.65834 .43971 m .65882 .43988 L .65973 .43804 L F
.87 .865 .831 r
.65836 .43904 m .65759 .43942 L .65853 .4393 L F
.65836 .43904 m .65853 .4393 L .65918 .43922 L F
.961 .658 .243 r
.65583 .43629 m .65725 .43947 L .65619 .4387 L F
.403 .81 .98 r
.65619 .4387 m .65725 .43947 L .65583 .43629 L F
.65619 .4387 m .65918 .43922 L .65759 .43942 L F
.65678 .43912 m .65759 .43942 L .65725 .43947 L F
.65619 .4387 m .65759 .43942 L .65678 .43912 L F
.87 .865 .831 r
.6595 .43847 m .65836 .43904 L .65918 .43922 L F
.728 .616 .732 r
.66071 .43794 m .65832 .44096 L .65832 .44096 L F
.87 .865 .831 r
.65832 .44096 m .65832 .44096 L .65832 .43899 L F
.896 .905 .824 r
.65832 .44092 m .65837 .44086 L .65899 .43955 L F
.66015 .43717 m .66016 .43717 L .66081 .43581 L F
.65832 .44092 m .66016 .43717 L .66015 .43717 L F
.87 .864 .831 r
.66103 .43678 m .65973 .43804 L .66071 .43794 L F
.6612 .43613 m .66053 .437 L .66103 .43678 L F
.66053 .437 m .65973 .43804 L .66103 .43678 L F
.66186 .43364 m .66081 .43581 L .6612 .43613 L F
.66081 .43581 m .65973 .43804 L .6612 .43613 L F
.522 0 0 r
.66069 .43788 m .66116 .43789 L .66071 .43794 L F
.66116 .43789 m .66398 .43799 L .66071 .43794 L F
.896 .905 .824 r
.65842 .4356 m .65837 .43827 L .66081 .43581 L F
.65837 .43827 m .65973 .43804 L .66081 .43581 L F
.65832 .44092 m .65832 .44096 L .65837 .44085 L F
.66037 .43546 m .66081 .43581 L .66101 .43541 L F
.65842 .4356 m .66081 .43581 L .66037 .43546 L F
.666 .158 0 r
.66153 .43638 m .66161 .43644 L .66176 .43662 L F
.87 .864 .831 r
.66127 .43585 m .6618 .43669 L .66332 .43493 L F
0 0 .471 r
.66177 .43665 m .66181 .4367 L .66176 .43662 L F
.666 .158 0 r
.66171 .43658 m .66176 .43662 L .66181 .4367 L F
.87 .864 .831 r
.66127 .43585 m .6612 .43613 L .66176 .43662 L F
.896 .905 .824 r
.66045 .43445 m .66101 .43541 L .66186 .43364 L F
.65842 .4356 m .66101 .43541 L .66045 .43445 L F
.666 .158 0 r
.65809 .43264 m .65934 .4336 L .65847 .43306 L F
.96 .866 .701 r
.66007 .43054 m .65992 .43396 L .65934 .4336 L F
.473 .321 .593 r
.47065 .57908 m .47307 .58046 L .47265 .57853 L F
.485 .693 .96 r
.4723 .58275 m .47307 .58046 L .47138 .5795 L F
.678 .509 .65 r
.47207 .58042 m .47265 .57853 L .47307 .58046 L F
.47243 .57924 m .47489 .57761 L .47265 .57853 L F
.47207 .58042 m .47351 .57899 L .47243 .57924 L F
.47351 .57899 m .47489 .57761 L .47243 .57924 L F
.485 .693 .96 r
.47089 .57961 m .47138 .5795 L .47065 .57908 L F
.4723 .58275 m .47138 .5795 L .47089 .57961 L F
.408 .204 .489 r
.47202 .58375 m .47439 .58432 L .4723 .58275 L F
.522 .16 .294 r
.47439 .58432 m .47467 .58281 L .4723 .58275 L F
.611 .896 .988 r
.71041 .45594 m .71296 .45561 L .71225 .45489 L F
.628 .954 .927 r
.71526 .45432 m .71447 .45399 L .71296 .45561 L F
.594 .891 .99 r
.71447 .45399 m .71225 .45489 L .71296 .45561 L F
.314 0 .088 r
.39548 .58506 m .39775 .58458 L .39862 .58328 L F
.35 0 .151 r
.39775 .58458 m .40092 .58266 L .39862 .58328 L F
.54 .28 .47 r
.53719 .58734 m .53712 .58547 L .53965 .58432 L F
.449 .672 .958 r
.53727 .58827 m .53536 .58857 L .53459 .58722 L F
.53624 .58774 m .53459 .58722 L .53526 .58725 L F
.53727 .58827 m .53609 .58781 L .53624 .58774 L F
.53609 .58781 m .53459 .58722 L .53624 .58774 L F
.53526 .58725 m .53459 .58722 L .53434 .58678 L F
.654 .098 0 r
.53594 .58853 m .5365 .58842 L .53434 .58678 L F
.53645 .5883 m .53727 .58827 L .53624 .58774 L F
.54 .28 .47 r
.53645 .5883 m .53719 .58734 L .53866 .58676 L F
.53849 .58702 m .53866 .58676 L .53928 .58652 L F
.53645 .5883 m .53866 .58676 L .53849 .58702 L F
.53719 .58734 m .53965 .58432 L .53929 .58644 L F
.53719 .58734 m .53929 .58644 L .53928 .58652 L F
.53634 .58837 m .53662 .58731 L .53719 .58734 L F
.53662 .58731 m .53712 .58547 L .53719 .58734 L F
.736 .474 .533 r
.53419 .58506 m .53712 .58547 L .53638 .58821 L F
.53614 .58806 m .53638 .58821 L .53634 .58837 L F
.579 .432 .645 r
.53614 .58806 m .53634 .58837 L .53434 .58678 L F
0 .323 .81 r
.53434 .58678 m .53634 .58837 L .53624 .58821 L F
.654 .098 0 r
.53558 .58771 m .53564 .58771 L .53434 .58678 L F
.53564 .58771 m .53624 .58774 L .53434 .58678 L F
.579 .432 .645 r
.53419 .58506 m .53614 .58806 L .53434 .58678 L F
.654 .098 0 r
.53643 .58824 m .53624 .58774 L .53556 .58771 L F
.736 .474 .533 r
.53419 .58506 m .53638 .58821 L .53614 .58806 L F
.54 .28 .47 r
.53634 .58837 m .53643 .58826 L .53645 .5883 L F
.611 .734 .933 r
.53624 .58821 m .53634 .58837 L .53645 .5883 L F
.654 .098 0 r
.5365 .58842 m .53643 .58824 L .53556 .58771 L F
0 .323 .81 r
.53434 .58678 m .53624 .58821 L .53501 .58607 L F
.654 .098 0 r
.53556 .58771 m .53558 .58771 L .53434 .58678 L F
.611 .734 .933 r
.53501 .58607 m .53624 .58821 L .53928 .58652 L F
.54 .28 .47 r
.53643 .58826 m .53719 .58734 L .53645 .5883 L F
.611 .734 .933 r
.53624 .58821 m .53645 .5883 L .53928 .58652 L F
0 .045 .607 r
.53501 .58607 m .53594 .58853 L .53434 .58678 L F
.964 .698 .482 r
.53501 .58607 m .535 .58856 L .53594 .58853 L F
.773 .526 .562 r
.53774 .58814 m .535 .58856 L .53501 .58607 L F
.616 .442 .623 r
.53866 .59008 m .53536 .58857 L .53727 .58827 L F
.705 .465 .558 r
.53727 .58827 m .54036 .59002 L .53866 .59008 L F
.424 .113 .332 r
.54036 .59002 m .53969 .59074 L .53885 .59007 L F
.53969 .59074 m .53804 .59291 L .53761 .59298 L F
.54036 .59002 m .53975 .59078 L .53969 .59074 L F
.53975 .59078 m .53804 .59291 L .53969 .59074 L F
.705 .465 .558 r
.53727 .58827 m .53975 .59078 L .54036 .59002 L F
.53975 .59078 m .54042 .59146 L .54036 .59002 L F
0 .167 .696 r
.54019 .59111 m .54023 .59117 L .54009 .59103 L F
.54023 .59117 m .54042 .59146 L .53977 .5908 L F
.424 .113 .332 r
.53975 .59078 m .53993 .59262 L .53804 .59291 L F
.54036 .59002 m .54018 .5911 L .53975 .59078 L F
0 .167 .696 r
.54023 .59117 m .53977 .5908 L .53975 .59078 L F
.54023 .59117 m .53975 .59078 L .54009 .59103 L F
.424 .113 .332 r
.54018 .5911 m .53993 .59262 L .53975 .59078 L F
0 .167 .696 r
.54009 .59103 m .53975 .59078 L .53727 .58827 L F
.53877 .58892 m .54019 .59111 L .53727 .58827 L F
.54019 .59111 m .54009 .59103 L .53727 .58827 L F
.424 .113 .332 r
.53885 .59007 m .53761 .59298 L .53866 .59008 L F
.53969 .59074 m .53761 .59298 L .53885 .59007 L F
0 .167 .696 r
.53877 .58892 m .53727 .58827 L .53594 .58853 L F
.773 .526 .562 r
.53877 .58892 m .53731 .58878 L .53774 .58814 L F
.654 .098 0 r
.5365 .58842 m .53664 .58839 L .53645 .5883 L F
.53664 .58839 m .53727 .58827 L .53645 .5883 L F
.241 0 0 r
.53594 .58853 m .535 .58856 L .53877 .58892 L F
.773 .526 .562 r
.53731 .58878 m .535 .58856 L .53774 .58814 L F
.616 .442 .623 r
.53866 .59008 m .53537 .59136 L .53536 .58857 L F
.95 .944 .625 r
.54152 .67167 m .54053 .67388 L .53993 .67324 L F
.552 .554 .81 r
.54152 .67167 m .5425 .66785 L .54013 .66752 L F
.54152 .67167 m .54428 .67114 L .5425 .66785 L F
.502 .324 .571 r
.54375 .67364 m .54152 .67167 L .53993 .67324 L F
0 0 .012 r
.23237 .63236 m .22994 .63531 L .23098 .63341 L F
.837 .948 .892 r
.52011 .52315 m .51858 .52639 L .51706 .52508 L F
.52011 .52315 m .5214 .52375 L .51858 .52639 L F
.244 .356 .779 r
.44763 .56809 m .45006 .57006 L .45015 .56762 L F
.046 0 .457 r
.61062 .42799 m .60972 .42986 L .60876 .42977 L F
.61062 .42799 m .61072 .43043 L .60972 .42986 L F
.652 .731 .908 r
.71101 .39572 m .70971 .39892 L .70854 .39655 L F
.71101 .39572 m .71222 .39805 L .70971 .39892 L F
.488 .141 .304 r
.5828 .5233 m .5854 .52414 L .5826 .52467 L F
.5828 .5233 m .58529 .52305 L .5854 .52414 L F
.253 0 0 r
.20327 .54073 m .20554 .54058 L .20672 .53971 L F
0 0 0 r
.20672 .53971 m .20765 .53989 L .20927 .53958 L F
.20672 .53971 m .20554 .54058 L .20765 .53989 L F
.071 0 0 r
.18933 .64262 m .18921 .64215 L .18737 .64294 L F
.18933 .64262 m .19156 .6419 L .18921 .64215 L F
.472 .134 .312 r
.44901 .64112 m .44734 .64396 L .44492 .64423 L F
.009 0 0 r
.45105 .64185 m .44734 .64396 L .44901 .64112 L F
.637 .833 .976 r
.42331 .59071 m .42504 .5918 L .42724 .59078 L F
.626 .541 .738 r
.4145 .58861 m .41821 .58991 L .41561 .59025 L F
.658 .378 .485 r
.46443 .63585 m .4675 .63611 L .46796 .63293 L F
.53 .264 .457 r
.46796 .63293 m .47028 .63504 L .47014 .6334 L F
.46796 .63293 m .4675 .63611 L .47028 .63504 L F
.603 .141 .129 r
.4123 .59907 m .40966 .59917 L .41095 .59767 L F
.549 .149 .237 r
.41341 .59735 m .4123 .59907 L .41095 .59767 L F
.556 .813 .993 r
.69519 .39594 m .69417 .39785 L .69269 .39666 L F
.69519 .39594 m .69658 .39726 L .69417 .39785 L F
.648 .672 .859 r
.72689 .39752 m .72559 .40175 L .72444 .39855 L F
.79 .764 .829 r
.53703 .68529 m .53943 .68768 L .53593 .68905 L F
.876 .755 .725 r
.54035 .68284 m .53943 .68768 L .53703 .68529 L F
.754 .719 .82 r
.19767 .67098 m .19868 .67355 L .20166 .67152 L F
.923 .73 .623 r
.75926 .42303 m .75899 .42566 L .75758 .42214 L F
.571 .74 .956 r
.49366 .57472 m .49264 .57676 L .49156 .57295 L F
.49366 .57472 m .49499 .57623 L .49264 .57676 L F
.682 .22 .148 r
.49432 .57752 m .49264 .57676 L .49499 .57623 L F
.49432 .57752 m .49111 .57638 L .49264 .57676 L F
.706 .47 .565 r
.56713 .62623 m .57134 .62404 L .56757 .62398 L F
.56713 .62623 m .57121 .62655 L .57134 .62404 L F
.726 .779 .895 r
.73573 .4343 m .73349 .4356 L .73214 .43384 L F
.546 .278 .46 r
.45384 .63965 m .45369 .64193 L .45105 .64185 L F
.44 .192 .439 r
.45572 .64119 m .45369 .64193 L .45384 .63965 L F
.207 0 .235 r
.23492 .62953 m .23237 .63236 L .23322 .63034 L F
0 0 0 r
.21557 .65051 m .21442 .65268 L .21291 .65325 L F
.201 0 .232 r
.21818 .64766 m .21712 .64992 L .21557 .65051 L F
.164 0 .062 r
.21625 .65198 m .21557 .65051 L .21712 .64992 L F
.21625 .65198 m .21442 .65268 L .21557 .65051 L F
.698 .895 .526 r
.60175 .42828 m .60058 .42953 L .60259 .42663 L F
0 0 0 r
.60058 .42953 m .60195 .42849 L .60259 .42663 L F
.60195 .42849 m .60229 .42823 L .60259 .42663 L F
.851 .953 .604 r
.60335 .4246 m .60304 .42533 L .60259 .42663 L F
.60304 .42533 m .60175 .42828 L .60259 .42663 L F
.818 .993 .747 r
.56097 .47694 m .5618 .47499 L .56212 .47517 L F
.56097 .47694 m .55939 .47786 L .5618 .47499 L F
0 0 .513 r
.44664 .6002 m .44774 .60262 L .447 .59898 L F
.722 .551 .658 r
.61991 .42611 m .61674 .42795 L .61674 .42555 L F
.61991 .42611 m .61759 .42818 L .61674 .42795 L F
.61991 .42611 m .62057 .4286 L .61759 .42818 L F
0 0 .516 r
.62098 .4262 m .61991 .42611 L .62179 .42441 L F
.62098 .4262 m .62057 .4286 L .61991 .42611 L F
.649 .568 .75 r
.56229 .62703 m .56292 .62937 L .56484 .62675 L F
.495 .362 .628 r
.56292 .62937 m .56468 .62921 L .56484 .62675 L F
.324 .715 .981 r
.71083 .44898 m .71171 .44987 L .70806 .4489 L F
.042 0 .364 r
.42401 .57849 m .42217 .58218 L .42235 .57971 L F
.505 .303 .539 r
.1978 .7023 m .19599 .70107 L .1975 .70043 L F
0 0 .524 r
.19903 .70258 m .1978 .7023 L .19757 .70085 L F
.19763 .70062 m .19757 .70085 L .1975 .70043 L F
.19903 .70258 m .19757 .70085 L .19763 .70062 L F
.214 .002 .361 r
.19773 .70028 m .19599 .70107 L .19444 .69873 L F
.196 .326 .77 r
.1986 .69936 m .1975 .70043 L .19811 .70046 L F
.424 .55 .879 r
.19498 .69575 m .19794 .7002 L .19444 .69873 L F
.19794 .7002 m .19811 .70046 L .19786 .70034 L F
.19794 .7002 m .19786 .70034 L .19444 .69873 L F
.343 .507 .876 r
.1986 .69936 m .19811 .70046 L .19794 .7002 L F
0 0 .524 r
.1985 .69949 m .19816 .69981 L .1986 .69936 L F
.19816 .69981 m .1975 .70043 L .19818 .69977 L F
.19816 .69981 m .19818 .69977 L .1986 .69936 L F
.19763 .70062 m .1975 .70043 L .19861 .69939 L F
.343 .507 .876 r
.1986 .69936 m .19794 .7002 L .19498 .69575 L F
0 0 .524 r
.19861 .69939 m .1985 .69949 L .1986 .69936 L F
.214 .002 .361 r
.19811 .70046 m .1975 .70043 L .19599 .70107 L F
.19811 .70046 m .19766 .70059 L .19786 .70034 L F
0 0 .524 r
.19903 .70258 m .19763 .70062 L .19861 .69939 L F
.214 .002 .361 r
.19786 .70034 m .19764 .70059 L .19773 .70028 L F
.19766 .70059 m .19764 .70059 L .19786 .70034 L F
.19764 .70059 m .19599 .70107 L .19773 .70028 L F
.505 .303 .539 r
.1978 .7023 m .19602 .70134 L .19599 .70107 L F
.379 .779 .985 r
.2252 .54148 m .22721 .5412 L .22906 .54196 L F
.259 0 0 r
.22721 .5412 m .23118 .54164 L .22906 .54196 L F
0 0 0 r
.21998 .64698 m .21712 .64992 L .21818 .64766 L F
0 0 .442 r
.63217 .40092 m .6323 .40318 L .63095 .40413 L F
0 0 0 r
.6323 .40318 m .62976 .40604 L .63095 .40413 L F
.589 .418 .618 r
.56608 .53226 m .56622 .53489 L .5637 .53531 L F
.571 .356 .55 r
.5637 .53531 m .56617 .5375 L .56367 .53775 L F
.5637 .53531 m .56622 .53489 L .56617 .5375 L F
0 0 .043 r
.2158 .5769 m .21505 .57906 L .21735 .57455 L F
0 0 0 r
.19714 .6922 m .19546 .69439 L .19414 .69488 L F
.677 .529 .677 r
.19274 .69156 m .19661 .6916 L .19557 .68894 L F
.598 .946 .92 r
.19223 .69396 m .19295 .6936 L .19274 .69156 L F
.193 .69294 m .19667 .69176 L .19309 .69157 L F
.19387 .69315 m .19667 .69176 L .193 .69294 L F
.19295 .6936 m .19387 .69315 L .193 .69294 L F
.19295 .6936 m .19309 .69157 L .19274 .69156 L F
.19223 .69396 m .19282 .69302 L .19662 .69173 L F
.19223 .69396 m .19662 .69173 L .19667 .69176 L F
.19667 .69176 m .19661 .6916 L .19274 .69156 L F
.838 .474 0 r
.19614 .69012 m .19669 .69178 L .19706 .69202 L F
.621 .959 .873 r
.19656 .69169 m .19282 .69302 L .19394 .69222 L F
.598 .946 .92 r
.19667 .69176 m .19699 .6916 L .19661 .6916 L F
.621 .959 .873 r
.19699 .6916 m .19662 .69173 L .19656 .69169 L F
.19662 .69173 m .19282 .69302 L .19656 .69169 L F
.838 .474 0 r
.19661 .6916 m .19668 .69177 L .19614 .69012 L F
.19668 .69177 m .19674 .69193 L .19669 .69178 L F
.19668 .69177 m .19669 .69178 L .19614 .69012 L F
.599 .572 .795 r
.19635 .69165 m .19546 .69439 L .19714 .6922 L F
.19635 .69165 m .19822 .69387 L .19743 .69402 L F
.19572 .6936 m .19743 .69402 L .19546 .69439 L F
.19635 .69165 m .19743 .69402 L .19572 .6936 L F
.296 0 0 r
.19292 .69534 m .19283 .69317 L .19223 .69396 L F
.19289 .69454 m .19268 .69571 L .19283 .69317 L F
.19292 .69534 m .19282 .69549 L .19289 .69454 L F
.19282 .69549 m .19268 .69571 L .19289 .69454 L F
.598 .946 .92 r
.19667 .69176 m .19662 .69173 L .19699 .6916 L F
.838 .474 0 r
.19706 .69202 m .19674 .69193 L .19714 .6922 L F
.19669 .69178 m .19674 .69193 L .19706 .69202 L F
.19557 .68894 m .19661 .6916 L .19614 .69012 L F
.677 .529 .677 r
.19661 .6916 m .19699 .6916 L .19557 .68894 L F
.838 .474 0 r
.19557 .68894 m .19635 .69165 L .19666 .69171 L F
.621 .959 .873 r
.19699 .6916 m .19656 .69169 L .19635 .69165 L F
.19656 .69169 m .19394 .69222 L .19635 .69165 L F
.838 .474 0 r
.19666 .69171 m .19635 .69165 L .19674 .69193 L F
.817 .982 .887 r
.67918 .41347 m .6821 .41187 L .67989 .41282 L F
.497 .517 .807 r
.26471 .56914 m .26298 .57098 L .2619 .56787 L F
.558 .426 .657 r
.26569 .5729 m .26298 .57098 L .26471 .56914 L F
.26569 .5729 m .26336 .57351 L .26298 .57098 L F
.178 0 .181 r
.48754 .5778 m .48638 .57635 L .48898 .5757 L F
.48754 .5778 m .48564 .57879 L .48638 .57635 L F
.936 .843 .727 r
.63279 .45795 m .63396 .45546 L .6323 .45458 L F
.8 .411 .318 r
.50681 .54119 m .50569 .543 L .5058 .54179 L F
.888 .99 .76 r
.50681 .54119 m .5058 .54179 L .50756 .53883 L F
.987 .733 .454 r
.50681 .54119 m .50695 .54392 L .50569 .543 L F
.751 .641 .739 r
.19095 .6801 m .19453 .68033 L .19358 .67732 L F
.521 .868 .99 r
.1906 .68045 m .19453 .68033 L .19095 .6801 L F
.1906 .68045 m .19304 .67975 L .19453 .68033 L F
.888 .92 .839 r
.19453 .68033 m .19538 .67715 L .19358 .67732 L F
.19453 .68033 m .19304 .67975 L .19538 .67715 L F
.862 .863 .838 r
.63652 .44849 m .6378 .44977 L .64028 .44676 L F
.629 .759 .94 r
.45006 .57006 m .4519 .57172 L .4522 .56937 L F
.415 .262 .564 r
.25067 .60533 m .24855 .60403 L .25067 .60269 L F
.25067 .60533 m .24845 .60688 L .24855 .60403 L F
0 0 0 r
.73462 .42644 m .73555 .42636 L .73563 .42414 L F
.73462 .42644 m .73354 .42721 L .73555 .42636 L F
.874 .939 .858 r
.45994 .58524 m .45719 .58807 L .45755 .58569 L F
.338 0 .09 r
.45875 .58695 m .45755 .58569 L .45719 .58807 L F
.45875 .58695 m .45994 .58524 L .45755 .58569 L F
.505 .303 .539 r
.1978 .7023 m .19666 .70346 L .19602 .70134 L F
.759 .624 .71 r
.57121 .62655 m .57409 .62952 L .57466 .62706 L F
.88 .943 .851 r
.54197 .68683 m .54072 .6863 L .53827 .68903 L F
.918 .928 .802 r
.54197 .68683 m .54182 .68433 L .54072 .6863 L F
.243 0 0 r
.41821 .58991 m .41514 .59119 L .41561 .59025 L F
.879 .576 .471 r
.52672 .586 m .52919 .58853 L .52641 .58783 L F
.802 .427 .347 r
.52919 .58853 m .52765 .59034 L .52641 .58783 L F
.894 .57 .427 r
.52952 .59075 m .52765 .59034 L .52919 .58853 L F
0 0 0 r
.19729 .54117 m .1995 .54084 L .20109 .54054 L F
.288 .777 .904 r
.1995 .54084 m .20327 .54073 L .20109 .54054 L F
.476 .205 .423 r
.21442 .65268 m .21156 .65532 L .21291 .65325 L F
.597 .418 .611 r
.54461 .57405 m .54465 .57678 L .54209 .57719 L F
.641 .503 .679 r
.54675 .57095 m .54714 .57353 L .54461 .57405 L F
.623 .439 .613 r
.54714 .57353 m .54465 .57678 L .54461 .57405 L F
.714 .951 .662 r
.55016 .55894 m .55065 .5584 L .54761 .56205 L F
.505 .372 .633 r
.55065 .5584 m .54809 .56456 L .54761 .56205 L F
.564 .359 .56 r
.57145 .51398 m .57389 .51384 L .57388 .51161 L F
.458 .276 .545 r
.57389 .51384 m .57618 .51089 L .57388 .51161 L F
.65 .717 .897 r
.6688 .40701 m .66489 .40485 L .66738 .40452 L F
.642 .664 .856 r
.66985 .40387 m .6688 .40701 L .66738 .40452 L F
.66985 .40387 m .67222 .40646 L .6688 .40701 L F
.176 0 0 r
.6688 .40701 m .6685 .40961 L .66922 .41045 L F
.6688 .40701 m .67035 .40746 L .6685 .40961 L F
.755 .835 .377 r
.66736 .41178 m .66897 .40799 L .66665 .41146 L F
.66752 .41185 m .66777 .41118 L .66736 .41178 L F
.66777 .41118 m .66897 .40799 L .66736 .41178 L F
.176 0 0 r
.67035 .40746 m .67059 .40753 L .66965 .40847 L F
.67035 .40746 m .66965 .40847 L .6685 .40961 L F
.6688 .40701 m .67222 .40646 L .67059 .40753 L F
0 0 .127 r
.49631 .57968 m .49729 .58064 L .49432 .57752 L F
.49631 .57968 m .49761 .58007 L .49729 .58064 L F
.399 .371 .711 r
.36699 .60915 m .3676 .61287 L .36943 .61115 L F
.386 .394 .746 r
.36869 .61482 m .36943 .61115 L .3676 .61287 L F
.92 .796 .707 r
.55303 .5066 m .55504 .50651 L .55407 .50581 L F
.851 .922 .877 r
.55407 .50581 m .55504 .50651 L .55557 .50416 L F
.344 0 .199 r
.59355 .51432 m .59479 .51576 L .59306 .51689 L F
.59355 .51432 m .59581 .51337 L .59479 .51576 L F
.621 .296 .399 r
.5681 .5164 m .57145 .51398 L .56819 .51425 L F
.5681 .5164 m .57065 .51641 L .57145 .51398 L F
.573 .248 .381 r
.57145 .51398 m .57347 .51604 L .57389 .51384 L F
.57145 .51398 m .57065 .51641 L .57347 .51604 L F
.605 .042 0 r
.40231 .63247 m .40473 .63409 L .40631 .63383 L F
.574 .003 0 r
.40473 .63409 m .40823 .63517 L .40631 .63383 L F
.513 .393 .653 r
.54809 .56456 m .54844 .56715 L .54616 .5677 L F
.538 .455 .709 r
.54844 .56715 m .54675 .57095 L .54616 .5677 L F
.644 .743 .921 r
.70754 .4062 m .70861 .40805 L .71111 .40718 L F
0 0 0 r
.22993 .59375 m .23318 .59123 L .23064 .5915 L F
.307 0 0 r
.38692 .59013 m .38931 .58977 L .38746 .58947 L F
.324 0 .117 r
.38746 .58947 m .38931 .58977 L .38968 .58887 L F
.533 .349 .577 r
.56828 .53197 m .56622 .53489 L .56608 .53226 L F
.432 .785 .997 r
.4543 .56461 m .45847 .56523 L .45601 .56508 L F
.924 .833 .736 r
.74997 .42611 m .74987 .42874 L .74853 .42778 L F
.662 .895 .549 r
.43206 .60485 m .43119 .60631 L .43356 .60331 L F
.43356 .60331 m .43119 .60631 L .43206 .60485 L F
.43356 .60331 m .43119 .60631 L .43206 .60485 L F
.461 .747 .991 r
.43119 .60631 m .43407 .60617 L .43206 .60485 L F
.37 .425 .788 r
.53456 .57645 m .53597 .57765 L .53265 .5767 L F
.482 .234 .461 r
.53597 .57765 m .5326 .57918 L .53265 .5767 L F
.938 .828 .71 r
.5083 .54756 m .50552 .54972 L .50655 .54635 L F
.5083 .54756 m .50693 .55098 L .50552 .54972 L F
.644 .535 .715 r
.40264 .60702 m .40028 .60547 L .4031 .60682 L F
.209 0 0 r
.4055 .60561 m .40264 .60702 L .4031 .60682 L F
.386 .394 .746 r
.36869 .61482 m .3702 .6147 L .36943 .61115 L F
.77 .368 .29 r
.40735 .60639 m .40578 .60775 L .40785 .60517 L F
.40735 .60639 m .40903 .60842 L .40578 .60775 L F
.413 .412 .749 r
.21407 .60264 m .21486 .5988 L .21389 .60032 L F
.396 .013 .19 r
.16722 .5626 m .16626 .56532 L .16757 .56461 L F
.16722 .5626 m .16441 .56518 L .16626 .56532 L F
.677 .786 .932 r
.61108 .45777 m .61471 .45829 L .6139 .45664 L F
.61108 .45777 m .61471 .45829 L .6139 .45664 L F
0 .058 .618 r
.61514 .45792 m .61471 .45829 L .6139 .45664 L F
.61514 .45792 m .61471 .45829 L .6139 .45664 L F
.559 .38 .595 r
.61471 .45829 m .61518 .461 L .61738 .45801 L F
.418 .431 .767 r
.44126 .56038 m .43973 .56313 L .43898 .56139 L F
.44126 .56038 m .44259 .56459 L .43973 .56313 L F
.916 .974 .689 r
.41798 .59937 m .41787 .60148 L .42008 .60065 L F
.691 .823 .946 r
.75278 .42993 m .75026 .43109 L .75355 .43128 L F
.911 .591 .11 r
.75278 .42993 m .75355 .43128 L .75026 .43109 L F
.75278 .42993 m .75382 .43347 L .75355 .43128 L F
.772 .857 .914 r
.75278 .42993 m .75355 .43128 L .75643 .42947 L F
.745 .944 .947 r
.71744 .45333 m .72133 .45234 L .72049 .45151 L F
.751 .944 .945 r
.72227 .45011 m .72133 .45234 L .72449 .45008 L F
.72227 .45011 m .72049 .45151 L .72133 .45234 L F
.184 .411 .848 r
.65699 .41477 m .65834 .41609 L .65645 .41311 L F
.876 .536 .404 r
.42814 .63611 m .42907 .63508 L .42864 .63544 L F
.626 .43 .597 r
.55596 .51435 m .5584 .51155 L .55605 .51189 L F
.55596 .51435 m .55856 .51405 L .5584 .51155 L F
.732 .26 .127 r
.56115 .51362 m .5584 .51155 L .55856 .51405 L F
.902 .915 .82 r
.62967 .46625 m .63226 .4648 L .63076 .46353 L F
.902 .763 .697 r
.63226 .4648 m .63096 .46045 L .63076 .46353 L F
.902 .707 .628 r
.59955 .4518 m .60116 .45255 L .59997 .44906 L F
.625 .57 .772 r
.59997 .44906 m .60116 .45255 L .60371 .45191 L F
.482 .266 .508 r
.60388 .45372 m .60116 .45255 L .60371 .45191 L F
.60388 .45372 m .60127 .45454 L .60116 .45255 L F
.60388 .45372 m .60116 .45255 L .60371 .45191 L F
.60388 .45372 m .60127 .45454 L .60116 .45255 L F
.653 .929 .972 r
.71485 .44425 m .71596 .44499 L .71492 .44478 L F
.695 .944 .96 r
.71907 .44316 m .71596 .44499 L .71485 .44425 L F
.625 .57 .772 r
.59997 .44906 m .60371 .45191 L .60375 .44943 L F
.876 .755 .725 r
.54035 .68284 m .53703 .68529 L .53831 .68465 L F
.539 .68421 m .53831 .68465 L .5388 .68441 L F
.54035 .68284 m .53831 .68465 L .539 .68421 L F
.267 .518 .906 r
.54115 .68165 m .54035 .68284 L .5392 .68226 L F
.755 .657 .753 r
.54047 .68327 m .54115 .68165 L .5392 .68226 L F
.267 .518 .906 r
.54115 .68165 m .54278 .68369 L .54035 .68284 L F
.755 .657 .753 r
.54182 .68433 m .5414 .68266 L .54047 .68327 L F
.5414 .68266 m .54115 .68165 L .54047 .68327 L F
.876 .755 .725 r
.54035 .68284 m .5388 .68441 L .5392 .68226 L F
.655 .531 .701 r
.56114 .62356 m .56372 .62312 L .5634 .62078 L F
.646 .53 .708 r
.56229 .62703 m .56372 .62312 L .56114 .62356 L F
.367 .411 .775 r
.74299 .42878 m .74369 .43145 L .74167 .43096 L F
0 0 0 r
.42429 .56925 m .42307 .57086 L .42469 .56886 L F
.56 .868 .569 r
.42429 .56925 m .42538 .568 L .42693 .56664 L F
0 0 0 r
.42429 .56925 m .42469 .56886 L .42538 .568 L F
.439 .845 .66 r
.42391 .56963 m .42429 .56925 L .42615 .56823 L F
.4231 .57014 m .42429 .56925 L .42391 .56963 L F
.724 .975 .741 r
.42615 .56823 m .42693 .56664 L .42748 .56668 L F
.42615 .56823 m .42429 .56925 L .42693 .56664 L F
.802 .81 .858 r
.66584 .44024 m .66341 .44232 L .66641 .44284 L F
.891 .608 .501 r
.66381 .44483 m .66641 .44284 L .66341 .44232 L F
.66381 .44483 m .66645 .44582 L .66641 .44284 L F
.882 .852 .809 r
.66584 .44024 m .66641 .44284 L .66744 .44114 L F
.285 .03 .341 r
.22562 .59744 m .22717 .59693 L .22814 .59429 L F
.523 .26 .458 r
.22814 .59429 m .22989 .59618 L .22993 .59375 L F
.22814 .59429 m .22717 .59693 L .22989 .59618 L F
.385 .154 .436 r
.23688 .62883 m .23548 .62715 L .23702 .62627 L F
.23688 .62883 m .23492 .62953 L .23548 .62715 L F
.686 .778 .92 r
.73543 .40061 m .73177 .40034 L .7344 .39913 L F
.524 .537 .811 r
.73654 .39801 m .73543 .40061 L .7344 .39913 L F
.73654 .39801 m .73771 .40157 L .73543 .40061 L F
.643 .874 .984 r
.69221 .46294 m .69479 .46294 L .69409 .46173 L F
.768 .822 .894 r
.69479 .46294 m .69682 .45984 L .69409 .46173 L F
.69479 .46294 m .69835 .46099 L .69682 .45984 L F
.846 .948 .884 r
.62454 .45136 m .62279 .45168 L .62457 .44865 L F
0 0 0 r
.7566 .42093 m .75491 .42269 L .75727 .41965 L F
.788 .661 .723 r
.75784 .41715 m .75727 .41965 L .75592 .41603 L F
.957 .651 .229 r
.75727 .41965 m .75758 .42214 L .7566 .42093 L F
.355 .374 .743 r
.46161 .57288 m .46305 .57419 L .46222 .56984 L F
.944 .639 .428 r
.43206 .60485 m .43407 .60617 L .43356 .60331 L F
.292 .649 .969 r
.24896 .54532 m .24856 .5465 L .24747 .54503 L F
.24896 .54532 m .25053 .54663 L .24856 .5465 L F
.973 .759 .554 r
.22164 .58744 m .22139 .58936 L .22327 .58865 L F
.901 .889 .81 r
.22139 .58936 m .22041 .59367 L .22327 .58865 L F
.063 0 0 r
.16666 .54639 m .17101 .54489 L .16816 .54652 L F
.16666 .54639 m .16869 .546 L .17101 .54489 L F
.069 0 0 r
.17101 .54489 m .17266 .54481 L .17319 .54433 L F
.17101 .54489 m .16869 .546 L .17266 .54481 L F
.748 .676 .781 r
.57249 .63144 m .57081 .62893 L .56868 .63 L F
.74 .674 .786 r
.57409 .62952 m .57081 .62893 L .57249 .63144 L F
.336 .237 .591 r
.36699 .60915 m .36875 .60552 L .36635 .60704 L F
.523 .221 .396 r
.3725 .59656 m .37538 .59431 L .37298 .59465 L F
.385 .406 .759 r
.21508 .60629 m .2159 .6025 L .21407 .60264 L F
.21508 .60629 m .21707 .60554 L .2159 .6025 L F
.364 .249 .586 r
.21513 .60881 m .21707 .60554 L .21508 .60629 L F
.396 .566 .903 r
.76282 .40527 m .76122 .40692 L .76005 .40393 L F
.76282 .40527 m .76328 .40711 L .76122 .40692 L F
.518 .486 .76 r
.26582 .57582 m .2643 .57675 L .26336 .57351 L F
.301 .148 .5 r
.26582 .57582 m .2642 .57928 L .2643 .57675 L F
.854 .816 .811 r
.55803 .50115 m .56189 .49958 L .56074 .49861 L F
.55803 .50115 m .5595 .50256 L .56189 .49958 L F
.822 .932 .904 r
.56351 .49613 m .56189 .49958 L .56477 .49693 L F
.56351 .49613 m .56074 .49861 L .56189 .49958 L F
.881 .967 .844 r
.62221 .45476 m .61908 .45655 L .62219 .45407 L F
.862 .863 .838 r
.63652 .44849 m .64028 .44676 L .63887 .44544 L F
.79 .77 .835 r
.64028 .44676 m .64125 .44246 L .63887 .44544 L F
.64028 .44676 m .64306 .44439 L .64125 .44246 L F
.322 .106 .422 r
.22562 .59744 m .22703 .59893 L .22717 .59693 L F
.22562 .59744 m .22504 .59978 L .22703 .59893 L F
.801 .568 .586 r
.48527 .62604 m .48489 .62929 L .48707 .62727 L F
.801 .57 .587 r
.48707 .62727 m .48489 .62929 L .48847 .62978 L F
.34 0 0 r
.37555 .63228 m .37537 .63217 L .3781 .6326 L F
.37555 .63228 m .37437 .63237 L .37537 .63217 L F
.019 0 .115 r
.46969 .58549 m .46732 .58849 L .46931 .58848 L F
.603 .314 .451 r
.46732 .58849 m .46948 .59056 L .46931 .58848 L F
.019 0 .115 r
.46969 .58549 m .46732 .58849 L .46931 .58848 L F
.603 .314 .451 r
.46732 .58849 m .46948 .59056 L .46931 .58848 L F
.622 .427 .597 r
.54377 .51966 m .54459 .51748 L .5417 .52025 L F
.247 0 .327 r
.54377 .51966 m .54565 .51771 L .54459 .51748 L F
.358 .123 .415 r
.54233 .52302 m .54377 .51966 L .5417 .52025 L F
.54233 .52302 m .54458 .52022 L .54377 .51966 L F
.247 0 .327 r
.54483 .51856 m .54496 .51861 L .54565 .51771 L F
.204 0 .345 r
.54459 .51909 m .54565 .51771 L .54459 .51748 L F
.54458 .52022 m .54565 .51771 L .54459 .51909 L F
.54458 .52022 m .54625 .51932 L .54565 .51771 L F
.54625 .51932 m .54652 .51918 L .5464 .51898 L F
.54625 .51932 m .5464 .51898 L .54565 .51771 L F
.247 0 .327 r
.54496 .51861 m .54652 .51918 L .54565 .51771 L F
.54437 .51955 m .54652 .51918 L .54483 .51856 L F
.292 .145 .503 r
.54458 .52022 m .54652 .51918 L .54437 .51955 L F
.54458 .52022 m .54437 .51955 L .54377 .51966 L F
.509 .265 .481 r
.5417 .52025 m .54406 .52023 L .54426 .51919 L F
.54393 .51812 m .54426 .51919 L .54459 .51748 L F
.5417 .52025 m .54426 .51919 L .54393 .51812 L F
.355 .268 .618 r
.54596 .5214 m .54652 .51918 L .54458 .52022 L F
.918 .79 .704 r
.54549 .52102 m .54504 .51793 L .54439 .52016 L F
.54596 .5214 m .54572 .52049 L .54549 .52102 L F
.54572 .52049 m .54504 .51793 L .54549 .52102 L F
.247 0 .327 r
.54377 .51966 m .54437 .51955 L .54483 .51856 L F
.509 .265 .481 r
.54406 .52023 m .54458 .52022 L .54459 .51909 L F
.54406 .52023 m .54459 .51909 L .54459 .51748 L F
.254 .458 .866 r
.54565 .51771 m .54588 .51569 L .54459 .51748 L F
0 0 .425 r
.43517 .56313 m .43559 .56572 L .43498 .56505 L F
.278 0 .282 r
.23965 .6235 m .23702 .62627 L .2378 .62426 L F
.754 .719 .82 r
.19767 .67098 m .20166 .67152 L .199 .67079 L F
.28 .705 .969 r
.20166 .67152 m .20169 .67051 L .199 .67079 L F
.142 0 0 r
.48217 .62945 m .47916 .63113 L .47841 .63067 L F
.413 .818 .98 r
.67454 .398 m .67821 .39809 L .6757 .3985 L F
.854 .799 .796 r
.63025 .44404 m .62677 .44568 L .62902 .44241 L F
.683 .727 .883 r
.63272 .44318 m .63025 .44404 L .62902 .44241 L F
.382 .816 .96 r
.68437 .39773 m .68216 .39813 L .68072 .39771 L F
.794 .888 .468 r
.62548 .474 m .62626 .4731 L .62592 .47184 L F
.62548 .474 m .6248 .47618 L .62626 .4731 L F
.906 .966 .81 r
.62626 .4731 m .62814 .46873 L .62592 .47184 L F
.62626 .4731 m .62895 .46949 L .62814 .46873 L F
.336 .237 .591 r
.36699 .60915 m .36871 .6089 L .36875 .60552 L F
.359 .368 .734 r
.36699 .60915 m .36943 .61115 L .36871 .6089 L F
.547 .3 .493 r
.40028 .60547 m .39938 .60576 L .39958 .60326 L F
.92 .919 .797 r
.62895 .46949 m .62967 .46625 L .62814 .46873 L F
.807 .914 .521 r
.19987 .63574 m .19797 .63944 L .19981 .6385 L F
.379 .826 .705 r
.19981 .6385 m .19797 .63944 L .1956 .64043 L F
.284 .768 .682 r
.47778 .58157 m .47467 .58281 L .47773 .58162 L F
.555 .189 .302 r
.47773 .58162 m .47439 .58432 L .47709 .58451 L F
.47773 .58162 m .47467 .58281 L .47439 .58432 L F
.154 .694 .731 r
.47841 .5814 m .47778 .58157 L .47773 .58162 L F
.523 .488 .758 r
.47709 .58451 m .47841 .5814 L .47773 .58162 L F
.532 .793 .993 r
.7566 .42093 m .75758 .42214 L .75491 .42269 L F
.574 .573 .814 r
.75899 .42566 m .75491 .42269 L .75758 .42214 L F
.606 .292 .411 r
.43058 .64391 m .42672 .64663 L .42725 .64528 L F
.538 .455 .709 r
.54844 .56715 m .54885 .57062 L .54675 .57095 L F
.632 .55 .744 r
.54885 .57062 m .54714 .57353 L .54675 .57095 L F
.416 .231 .519 r
.24835 .61077 m .24668 .60921 L .24866 .60856 L F
.24835 .61077 m .24644 .61153 L .24668 .60921 L F
.646 .53 .708 r
.56229 .62703 m .56484 .62675 L .56372 .62312 L F
.516 .335 .573 r
.36809 .60026 m .37039 .59978 L .3704 .59727 L F
.459 .301 .578 r
.36837 .60283 m .37039 .59978 L .36809 .60026 L F
.338 0 0 r
.20374 .5521 m .20206 .55237 L .19989 .5521 L F
.379 0 0 r
.20586 .55246 m .20206 .55237 L .20374 .5521 L F
.642 .809 .963 r
.69149 .40594 m .69277 .40732 L .6953 .40638 L F
.793 .55 .57 r
.37318 .62859 m .37621 .63039 L .37706 .62653 L F
.766 .29 .111 r
.37912 .62636 m .3749 .62401 L .37706 .62653 L F
0 0 .215 r
.37706 .62653 m .37728 .62645 L .37912 .62636 L F
.37706 .62653 m .37797 .62777 L .37728 .62645 L F
.728 .698 .822 r
.37797 .62777 m .37911 .6296 L .38129 .62837 L F
0 .46 .832 r
.37941 .62859 m .37833 .62809 L .37797 .62777 L F
0 0 .215 r
.37698 .6269 m .37621 .63039 L .37797 .62777 L F
.596 .644 .869 r
.37621 .63039 m .37911 .6296 L .37797 .62777 L F
0 .46 .832 r
.37833 .62809 m .3758 .62692 L .37797 .62777 L F
0 0 .215 r
.37706 .62653 m .37698 .6269 L .37797 .62777 L F
.716 .569 .687 r
.46931 .58848 m .47202 .58375 L .46969 .58549 L F
.85 .919 .878 r
.54004 .56801 m .53755 .57058 L .53653 .56951 L F
.78 .283 .021 r
.53755 .57058 m .54011 .5735 L .53958 .57397 L F
.429 .421 .749 r
.55041 .57877 m .54896 .57981 L .54806 .57722 L F
.787 .839 .891 r
.54587 .57793 m .54341 .58067 L .54867 .58106 L F
.54871 .58101 m .54867 .58106 L .54877 .58106 L F
.54587 .57793 m .54867 .58106 L .54871 .58101 L F
.054 0 .186 r
.55041 .57877 m .54917 .5805 L .54896 .57981 L F
.719 .419 .468 r
.54527 .58157 m .54235 .58397 L .54249 .58261 L F
.54527 .58157 m .54488 .58439 L .54235 .58397 L F
.517 .185 .344 r
.5483 .5817 m .54488 .58439 L .54527 .58157 L F
.516 .022 .022 r
.54345 .58292 m .54649 .58306 L .54867 .58115 L F
.54865 .5811 m .54867 .58115 L .54877 .58106 L F
.54345 .58292 m .54867 .58115 L .54865 .5811 L F
.517 .185 .344 r
.5483 .5817 m .55006 .58257 L .54488 .58439 L F
.777 .286 0 r
.5486 .5825 m .54875 .58117 L .54649 .58306 L F
0 0 .343 r
.54877 .58106 m .54888 .58133 L .54875 .58089 L F
.777 .286 0 r
.54876 .58114 m .54877 .58106 L .5487 .58116 L F
.486 .301 .554 r
.55041 .57877 m .55087 .58064 L .5487 .58116 L F
.55087 .58064 m .55106 .58141 L .5487 .58116 L F
.516 .022 .022 r
.54345 .58292 m .54865 .5811 L .54341 .58067 L F
.54865 .5811 m .54877 .58106 L .54867 .58106 L F
.054 0 .186 r
.54867 .58106 m .54865 .5811 L .54864 .58108 L F
.516 .022 .022 r
.54865 .5811 m .54867 .58106 L .54341 .58067 L F
.054 0 .186 r
.54875 .58096 m .54868 .58118 L .54865 .5811 L F
.54875 .58096 m .54865 .5811 L .54867 .58106 L F
.54917 .5805 m .54879 .58103 L .54875 .58096 L F
.777 .286 0 r
.5487 .58116 m .54877 .58106 L .54867 .58115 L F
.054 0 .186 r
.54879 .58103 m .54868 .58118 L .54875 .58096 L F
.429 .421 .749 r
.55041 .57877 m .54806 .57722 L .54976 .57519 L F
0 0 .343 r
.54875 .58089 m .54879 .58103 L .54829 .57693 L F
.486 .301 .554 r
.54883 .58117 m .55106 .58141 L .54898 .58163 L F
0 0 .343 r
.54879 .58103 m .54889 .58135 L .54887 .58117 L F
.54879 .58103 m .54887 .58117 L .54829 .57693 L F
.54888 .58133 m .54889 .58135 L .54875 .58089 L F
.486 .301 .554 r
.5487 .58116 m .54883 .58117 L .5483 .5817 L F
.697 .557 .691 r
.55106 .58141 m .55006 .58257 L .5483 .5817 L F
.777 .286 0 r
.5486 .5825 m .54889 .58135 L .54888 .58133 L F
.54876 .58114 m .54888 .58133 L .54877 .58106 L F
.5486 .5825 m .54888 .58133 L .54876 .58114 L F
.486 .301 .554 r
.5488 .5812 m .54898 .58163 L .5483 .5817 L F
.54883 .58117 m .54888 .58133 L .5488 .5812 L F
.54888 .58133 m .54898 .58163 L .5488 .5812 L F
.777 .286 0 r
.54875 .58117 m .54876 .58114 L .5487 .58116 L F
.054 0 .186 r
.5486 .58113 m .5483 .5817 L .54844 .58131 L F
.54861 .58114 m .5483 .5817 L .5486 .58113 L F
.54868 .58118 m .5483 .5817 L .54864 .58108 L F
.777 .286 0 r
.54875 .58117 m .54867 .58115 L .54649 .58306 L F
.054 0 .186 r
.54864 .58108 m .54861 .58114 L .5486 .58113 L F
.751 .618 .712 r
.54714 .57353 m .54806 .57722 L .54465 .57678 L F
.517 .47 .743 r
.54976 .57519 m .54806 .57722 L .54714 .57353 L F
0 0 .343 r
.54871 .58101 m .54829 .57693 L .54587 .57793 L F
.54877 .58106 m .54875 .58096 L .54871 .58101 L F
.054 0 .186 r
.54871 .58101 m .54845 .58127 L .54896 .57981 L F
0 0 .343 r
.54875 .58096 m .54829 .57693 L .54871 .58101 L F
.054 0 .186 r
.54917 .5805 m .54871 .58101 L .54896 .57981 L F
.54871 .58101 m .54844 .58131 L .54845 .58127 L F
.685 .755 .904 r
.68639 .46366 m .69004 .46435 L .68905 .46261 L F
.709 .765 .896 r
.68905 .46261 m .69004 .46435 L .69221 .46294 L F
.891 .62 .107 r
.21505 .57906 m .21591 .58256 L .21534 .58127 L F
0 0 .109 r
.21591 .58256 m .21621 .58326 L .21534 .58127 L F
.21591 .58256 m .21598 .58503 L .21621 .58326 L F
.753 .451 .473 r
.20909 .55476 m .20586 .55246 L .20978 .5528 L F
.542 .224 .379 r
.20978 .5528 m .21141 .55471 L .20909 .55476 L F
.712 .627 .761 r
.53843 .5784 m .54 .58254 L .53662 .58256 L F
.67 .351 .424 r
.53662 .58256 m .54 .58254 L .53965 .58432 L F
.47 .169 .372 r
.53965 .58432 m .54 .58254 L .54235 .58397 L F
.519 .114 .213 r
.54 .58254 m .54249 .58261 L .54235 .58397 L F
.882 .852 .809 r
.66584 .44024 m .66744 .44114 L .66696 .43808 L F
.633 .8 .963 r
.70141 .3955 m .69998 .39802 L .69885 .39661 L F
.70141 .3955 m .70243 .39732 L .69998 .39802 L F
.782 .814 .878 r
.61674 .42555 m .61798 .42205 L .61895 .42227 L F
0 0 0 r
.61895 .42227 m .62009 .42176 L .62177 .4203 L F
.55 .23 .379 r
.61798 .42205 m .62009 .42176 L .61895 .42227 L F
.634 .409 .559 r
.57186 .52924 m .57193 .53146 L .56828 .53197 L F
.638 .423 .574 r
.57186 .52924 m .57442 .53146 L .57193 .53146 L F
.57186 .52924 m .5745 .52894 L .57442 .53146 L F
.818 .826 .855 r
.69933 .44982 m .69572 .45151 L .69838 .449 L F
.64 .924 .975 r
.70084 .44824 m .69933 .44982 L .69838 .449 L F
.70084 .44824 m .70192 .44898 L .69933 .44982 L F
.722 .965 .702 r
.56212 .47517 m .56421 .47237 L .56527 .47288 L F
.56212 .47517 m .5618 .47499 L .56421 .47237 L F
.425 .244 .529 r
.25555 .59649 m .25323 .59951 L .25347 .59725 L F
.526 .266 .463 r
.25747 .59106 m .257 .59336 L .2551 .59142 L F
.389 .259 .58 r
.2551 .59142 m .257 .59336 L .2552 .59395 L F
.968 .81 .385 r
.64263 .42544 m .64287 .42943 L .64379 .42682 L F
.853 .976 .672 r
.64379 .42682 m .64287 .42943 L .64182 .43068 L F
.221 0 .125 r
.59445 .49358 m .59144 .49582 L .59361 .4953 L F
.036 0 0 r
.59361 .4953 m .59144 .49582 L .59026 .4979 L F
.606 .292 .411 r
.43058 .64391 m .4291 .64686 L .42672 .64663 L F
.59 .283 .416 r
.43294 .64406 m .4291 .64686 L .43058 .64391 L F
.835 .422 0 r
.65645 .41311 m .65834 .41609 L .65858 .41727 L F
0 0 .351 r
.76835 .42116 m .76756 .42494 L .76755 .42271 L F
.355 .628 .956 r
.25818 .54857 m .25683 .55025 L .25633 .54883 L F
.25818 .54857 m .26057 .55077 L .25683 .55025 L F
.433 .834 .63 r
.4231 .57014 m .42244 .57052 L .42429 .56925 L F
.674 .285 .301 r
.43671 .64392 m .4351 .64618 L .43294 .64406 L F
.621 .214 .252 r
.43887 .64462 m .4351 .64618 L .43671 .64392 L F
.703 .837 .947 r
.68293 .46342 m .68413 .46488 L .68639 .46366 L F
.582 .626 .861 r
.7507 .39546 m .74971 .39922 L .74846 .39828 L F
.075 .637 .75 r
.74971 .39922 m .75216 .39899 L .74846 .39828 L F
.7513 .39913 m .75321 .39903 L .75216 .39899 L F
.973 .679 .287 r
.75321 .39903 m .75337 .40068 L .75216 .39899 L F
0 .375 .804 r
.7525 .39894 m .75216 .39899 L .7535 .3996 L F
.75079 .39781 m .75216 .39899 L .7525 .39894 L F
.075 .637 .75 r
.74971 .39922 m .7513 .39913 L .75216 .39899 L F
.948 .942 .744 r
.62312 .47924 m .6248 .47618 L .62328 .47623 L F
.837 .993 .852 r
.62328 .47623 m .6248 .47618 L .62548 .474 L F
.206 .62 .95 r
.48666 .57099 m .48794 .57189 L .48471 .57138 L F
.48666 .57099 m .48471 .57138 L .48365 .5718 L F
.34 .141 .457 r
.20985 .62377 m .2116 .62325 L .21208 .62074 L F
.417 .262 .562 r
.20969 .62637 m .2116 .62325 L .20985 .62377 L F
.135 0 .386 r
.16077 .54882 m .16462 .54738 L .16233 .54807 L F
.548 .9 .974 r
.70338 .44744 m .70466 .44801 L .70192 .44898 L F
.532 .876 .988 r
.70338 .44744 m .70192 .44898 L .70084 .44824 L F
.968 .935 .654 r
.48564 .57879 m .48499 .58226 L .48349 .58033 L F
.895 .949 .596 r
.42748 .56668 m .42693 .56664 L .42844 .56387 L F
.42847 .56399 m .42844 .56387 L .42867 .56345 L F
.42748 .56668 m .42867 .56345 L .42814 .56468 L F
.42748 .56668 m .42844 .56387 L .42847 .56399 L F
.64 .751 .929 r
.43188 .56485 m .42863 .5647 L .43037 .56438 L F
.42863 .5647 m .42814 .56468 L .42861 .56462 L F
.42863 .5647 m .42861 .56462 L .43037 .56438 L F
.092 .316 .793 r
.43263 .56386 m .43188 .56485 L .43037 .56438 L F
.792 .34 .171 r
.21735 .57455 m .21549 .57452 L .21726 .57363 L F
.779 .705 .166 r
.21505 .57906 m .21549 .57452 L .21735 .57455 L F
.757 .287 .13 r
.21549 .57452 m .21892 .57568 L .21726 .57363 L F
.75 .231 0 r
.21726 .57363 m .21892 .57568 L .22075 .57656 L F
.317 .76 .963 r
.53993 .67324 m .54053 .67388 L .54375 .67364 L F
0 0 0 r
.59629 .49259 m .59708 .49077 L .59445 .49358 L F
.59629 .49259 m .59445 .49358 L .59361 .4953 L F
.402 .746 .993 r
.26246 .55088 m .26206 .55224 L .26057 .55077 L F
.26246 .55088 m .26409 .55201 L .26206 .55224 L F
.721 .468 .543 r
.62057 .4286 m .62043 .43086 L .61759 .42818 L F
.978 .719 .47 r
.61907 .42903 m .62057 .4286 L .62098 .4262 L F
.61907 .42903 m .62043 .43086 L .62057 .4286 L F
.631 .769 .946 r
.37555 .63228 m .3781 .6326 L .38067 .63184 L F
0 0 0 r
.43215 .56821 m .43185 .5677 L .43416 .56716 L F
.43215 .56821 m .43151 .56944 L .43185 .5677 L F
.867 .995 .805 r
.5214 .52375 m .52183 .52164 L .5237 .52099 L F
.788 .948 .926 r
.52011 .52315 m .52183 .52164 L .5214 .52375 L F
.73 .642 .761 r
.53623 .57987 m .53662 .58256 L .53427 .58239 L F
.739 .505 .576 r
.53662 .58256 m .53419 .58506 L .53427 .58239 L F
.53662 .58256 m .53712 .58547 L .53419 .58506 L F
.712 .627 .761 r
.53843 .5784 m .53662 .58256 L .53623 .57987 L F
.67 .351 .424 r
.53662 .58256 m .53965 .58432 L .53712 .58547 L F
.829 .643 .095 r
.65283 .43149 m .65239 .4268 L .65204 .43047 L F
.984 .906 .619 r
.65185 .43385 m .65283 .43149 L .65204 .43047 L F
.382 .167 .458 r
.24156 .62278 m .24008 .62105 L .24177 .62032 L F
.24156 .62278 m .23965 .6235 L .24008 .62105 L F
.013 0 0 r
.22401 .55201 m .22028 .55223 L .22195 .55209 L F
.242 0 0 r
.2158 .55263 m .21381 .55427 L .21141 .55471 L F
.62 .164 .148 r
.2158 .55263 m .21769 .55455 L .21381 .55427 L F
.576 .174 .244 r
.2183 .55301 m .21769 .55455 L .2158 .55263 L F
0 0 0 r
.60174 .44287 m .60116 .44528 L .60069 .44668 L F
0 0 .207 r
.60142 .44764 m .60069 .44668 L .60116 .44528 L F
.60142 .44764 m .59997 .44906 L .60069 .44668 L F
.601 .548 .767 r
.40004 .60865 m .39833 .6121 L .39721 .60867 L F
.40004 .60865 m .4008 .61169 L .39833 .6121 L F
.431 .261 .548 r
.40082 .61271 m .39833 .6121 L .4008 .61169 L F
.40082 .61271 m .39826 .61447 L .39833 .6121 L F
.485 .828 .998 r
.46222 .56984 m .4584 .5695 L .46082 .57065 L F
.505 .748 .983 r
.42867 .56345 m .43037 .56438 L .42814 .56468 L F
.992 .862 .602 r
.51751 .54024 m .51788 .54345 L .51681 .54132 L F
.482 .139 .308 r
.51373 .54435 m .51376 .54432 L .51558 .54372 L F
.061 0 0 r
.51404 .54409 m .51348 .54444 L .515 .5433 L F
.51619 .54231 m .51411 .54375 L .51585 .54184 L F
.482 .139 .308 r
.5162 .54232 m .51681 .54132 L .51637 .54219 L F
.799 .952 .918 r
.51702 .54173 m .51637 .54219 L .51681 .54132 L F
.061 0 0 r
.5164 .5426 m .5162 .54232 L .51681 .54132 L F
.5162 .54232 m .51585 .54184 L .51681 .54132 L F
.636 .21 .217 r
.51585 .54184 m .51348 .54444 L .51104 .54279 L F
.748 .726 .831 r
.5212 .54071 m .51788 .54345 L .51751 .54024 L F
.992 .862 .602 r
.51751 .54024 m .51681 .54132 L .51585 .54184 L F
0 0 .038 r
.51891 .53848 m .51681 .54132 L .51937 .54174 L F
.799 .952 .918 r
.51788 .54345 m .51558 .54372 L .51637 .54219 L F
.51788 .54345 m .51637 .54219 L .51702 .54173 L F
.139 0 .198 r
.51681 .54132 m .51807 .54296 L .51937 .54174 L F
.51681 .54132 m .5162 .54416 L .51807 .54296 L F
0 0 .038 r
.51891 .53848 m .5164 .5426 L .51681 .54132 L F
.845 .789 .796 r
.51631 .53869 m .51705 .54153 L .51891 .53848 L F
.51589 .53872 m .51606 .53912 L .51631 .53869 L F
.51606 .53912 m .51705 .54153 L .51631 .53869 L F
.51373 .53889 m .51497 .53987 L .51589 .53872 L F
.51497 .53987 m .51705 .54153 L .51589 .53872 L F
.51373 .53889 m .51891 .53848 L .51748 .53982 L F
.669 .592 .761 r
.51487 .53572 m .51903 .53723 L .51779 .53469 L F
.731 .468 .531 r
.51487 .53572 m .51675 .53889 L .51903 .53723 L F
.394 .451 .8 r
.51779 .53469 m .51903 .53723 L .51962 .53459 L F
.379 .208 .52 r
.51962 .53459 m .51675 .53889 L .5172 .53709 L F
.51856 .53465 m .5172 .53709 L .51779 .53469 L F
.51962 .53459 m .5172 .53709 L .51856 .53465 L F
.613 .432 .613 r
.51779 .53469 m .5172 .53709 L .51487 .53572 L F
.5172 .53709 m .51675 .53889 L .51633 .53818 L F
.5172 .53709 m .51633 .53818 L .51487 .53572 L F
.383 .846 .823 r
.51452 .53927 m .51432 .53935 L .51373 .53889 L F
.51432 .53935 m .51197 .54029 L .51373 .53889 L F
.482 .139 .308 r
.51545 .54294 m .51681 .54132 L .5162 .54232 L F
.51547 .54264 m .51681 .54132 L .51545 .54294 L F
.5139 .54427 m .51637 .54219 L .51558 .54372 L F
.51376 .54432 m .51404 .54409 L .5139 .54427 L F
.51404 .54409 m .51637 .54219 L .5139 .54427 L F
.51373 .54435 m .5162 .54416 L .51657 .54244 L F
.768 .631 .709 r
.5155 .54213 m .51636 .54257 L .51556 .54142 L F
.061 0 0 r
.5164 .5426 m .51411 .54375 L .51619 .54231 L F
.768 .631 .709 r
.51636 .54257 m .5164 .5426 L .51638 .54257 L F
.482 .139 .308 r
.51547 .54264 m .51657 .54244 L .51681 .54132 L F
.768 .631 .709 r
.51636 .54257 m .51638 .54257 L .51556 .54142 L F
.482 .139 .308 r
.51376 .54432 m .51547 .54264 L .51545 .54294 L F
.51417 .54392 m .51636 .54257 L .51547 .54264 L F
.51636 .54257 m .51657 .54244 L .51547 .54264 L F
.061 0 0 r
.5164 .5426 m .51404 .54409 L .515 .5433 L F
.768 .631 .709 r
.5155 .54213 m .51404 .54409 L .5164 .5426 L F
.482 .139 .308 r
.51373 .54435 m .51657 .54244 L .51417 .54392 L F
.768 .631 .709 r
.514 .54402 m .51348 .54444 L .51404 .54409 L F
.299 .358 .756 r
.51104 .54279 m .51348 .54444 L .51336 .54413 L F
.51108 .54268 m .51336 .54413 L .51197 .54029 L F
.51104 .54279 m .51336 .54413 L .51108 .54268 L F
.768 .631 .709 r
.51336 .54413 m .51345 .54436 L .5136 .54427 L F
.923 .631 .473 r
.51104 .54279 m .51138 .54533 L .51293 .54498 L F
.976 .673 .352 r
.50986 .542 m .51138 .54533 L .51104 .54279 L F
.299 .358 .756 r
.51104 .54279 m .51197 .54029 L .50986 .542 L F
.598 .593 .818 r
.51373 .54435 m .51138 .54533 L .50986 .542 L F
.51365 .5443 m .51301 .54391 L .51245 .54364 L F
.061 0 0 r
.515 .5433 m .51348 .54444 L .51411 .54375 L F
.768 .631 .709 r
.51345 .54436 m .51348 .54444 L .514 .54402 L F
.598 .593 .818 r
.51373 .54435 m .51348 .5442 L .51365 .5443 L F
.51348 .5442 m .51301 .54391 L .51365 .5443 L F
.51301 .54391 m .50986 .542 L .51064 .54249 L F
.51301 .54391 m .51064 .54249 L .51245 .54364 L F
.768 .631 .709 r
.51197 .54029 m .51336 .54413 L .514 .54402 L F
.51336 .54413 m .5136 .54427 L .514 .54402 L F
.51197 .54029 m .51404 .54409 L .5155 .54213 L F
.383 .846 .823 r
.51432 .53935 m .51409 .53942 L .51197 .54029 L F
.768 .631 .709 r
.51197 .54029 m .5155 .54213 L .51403 .53944 L F
.51197 .54029 m .51403 .53944 L .51373 .53889 L F
.5155 .54213 m .51556 .54142 L .51411 .53941 L F
.51403 .53944 m .51411 .53941 L .51373 .53889 L F
.5155 .54213 m .51411 .53941 L .51403 .53944 L F
.383 .846 .823 r
.51452 .53927 m .51425 .53935 L .51432 .53935 L F
.51425 .53935 m .51329 .53963 L .51411 .53941 L F
.845 .789 .796 r
.51373 .53889 m .51411 .53941 L .51432 .53935 L F
.383 .846 .823 r
.51425 .53935 m .51411 .53941 L .51432 .53935 L F
.673 .578 .74 r
.50934 .53912 m .50986 .542 L .51197 .54029 L F
.50934 .53912 m .51197 .54029 L .51113 .54027 L F
.383 .846 .823 r
.51409 .53942 m .51113 .54027 L .51197 .54029 L F
.51329 .53963 m .51113 .54027 L .51432 .53935 L F
.845 .789 .796 r
.51432 .53935 m .5164 .5426 L .51705 .54153 L F
.51411 .53941 m .5164 .5426 L .51432 .53935 L F
.536 .877 .989 r
.68925 .39683 m .68775 .39825 L .68678 .39744 L F
.68925 .39683 m .69021 .39747 L .68775 .39825 L F
.434 .225 .494 r
.55606 .5437 m .55625 .54627 L .55362 .54699 L F
.463 .3 .573 r
.55362 .54699 m .55602 .54885 L .55376 .54947 L F
.55362 .54699 m .55625 .54627 L .55602 .54885 L F
.879 .869 .824 r
.67356 .41917 m .67698 .41573 L .67468 .41544 L F
.117 .66 .835 r
.67468 .41544 m .67698 .41573 L .67852 .41562 L F
.629 .794 .962 r
.69886 .40697 m .70028 .4046 L .69761 .40557 L F
.69886 .40697 m .70142 .40609 L .70028 .4046 L F
.455 0 0 r
.72119 .40965 m .72492 .41021 L .72373 .4104 L F
.034 0 0 r
.72373 .4104 m .72492 .41021 L .72696 .41012 L F
.016 .59 .739 r
.4644 .56461 m .46674 .56465 L .46819 .56472 L F
.078 .401 .856 r
.46964 .56434 m .46819 .56472 L .46674 .56465 L F
.46964 .56434 m .47085 .56629 L .46819 .56472 L F
.335 .748 .979 r
.20927 .53958 m .21147 .53946 L .21332 .54026 L F
.039 .562 .866 r
.21147 .53946 m .21528 .54063 L .21332 .54026 L F
.024 .295 .789 r
.5175 .5733 m .51791 .57243 L .51546 .57058 L F
.01 .276 .776 r
.5175 .5733 m .51965 .5755 L .51791 .57243 L F
.469 .356 .642 r
.73849 .43046 m .73892 .42763 L .73766 .42831 L F
.73849 .43046 m .74137 .42922 L .73892 .42763 L F
.73849 .43046 m .74049 .43078 L .74137 .42922 L F
.776 .748 .828 r
.69835 .46099 m .6999 .45657 L .69682 .45984 L F
.69835 .46099 m .70099 .45863 L .6999 .45657 L F
.803 .771 .824 r
.64125 .44246 m .64306 .44439 L .64442 .44286 L F
.009 0 0 r
.45105 .64185 m .44968 .64327 L .44734 .64396 L F
.68 .891 .528 r
.45187 .64027 m .45105 .64185 L .45369 .64193 L F
.45187 .64027 m .44968 .64327 L .45105 .64185 L F
0 0 .351 r
.65192 .4172 m .65148 .41657 L .65196 .41418 L F
0 0 .15 r
.65212 .41738 m .65192 .4172 L .65213 .41602 L F
0 0 .351 r
.65192 .4172 m .6526 .41905 L .65167 .41698 L F
.88 .792 .302 r
.65211 .41898 m .6526 .41905 L .65192 .4172 L F
0 0 .15 r
.65211 .41898 m .65192 .4172 L .65212 .41738 L F
0 0 .351 r
.65192 .4172 m .65167 .41698 L .65148 .41657 L F
.338 .48 .855 r
.22532 .55271 m .22557 .55309 L .22809 .55356 L F
.22557 .55309 m .22703 .55525 L .22809 .55356 L F
.543 .697 .94 r
.22983 .5565 m .22974 .55387 L .22809 .55356 L F
.213 0 0 r
.22974 .55387 m .22972 .55386 L .22809 .55356 L F
.609 .447 .637 r
.22703 .55525 m .22983 .5565 L .22809 .55356 L F
.213 0 0 r
.22972 .55386 m .22623 .55341 L .22809 .55356 L F
.382 0 0 r
.22532 .55271 m .22809 .55356 L .22724 .55345 L F
.266 .441 .849 r
.22578 .55548 m .22532 .55271 L .22414 .55225 L F
.22578 .55548 m .22703 .55525 L .22532 .55271 L F
.382 0 0 r
.22532 .55271 m .22724 .55345 L .2242 .55304 L F
.266 .441 .849 r
.22414 .55225 m .22532 .55271 L .22401 .55201 L F
.224 .177 .592 r
.22578 .55548 m .22739 .5576 L .22703 .55525 L F
.266 .64 .964 r
.24518 .5435 m .24457 .54458 L .24297 .54346 L F
.24518 .5435 m .24747 .54503 L .24457 .54458 L F
.549 .344 .555 r
.5417 .52025 m .54233 .52302 L .54115 .52261 L F
.52 .325 .557 r
.54233 .52302 m .54458 .52022 L .5417 .52025 L F
.358 .123 .415 r
.54233 .52302 m .5417 .52025 L .54115 .52261 L F
.65 .473 .632 r
.55859 .54341 m .55625 .54627 L .55606 .5437 L F
.477 .237 .471 r
.61538 .42602 m .6132 .42524 L .61573 .42546 L F
.61538 .42602 m .61573 .42546 L .61674 .42555 L F
.525 .673 .931 r
.61538 .42602 m .61674 .42795 L .61805 .42604 L F
.28 .732 .958 r
.61805 .42604 m .61689 .42532 L .61538 .42602 L F
0 0 0 r
.61689 .42532 m .61483 .42688 L .61538 .42602 L F
.61483 .42688 m .61421 .42735 L .61538 .42602 L F
.184 0 0 r
.6132 .42524 m .61419 .42538 L .61674 .42555 L F
.782 .814 .878 r
.61674 .42555 m .61419 .42538 L .61798 .42205 L F
.964 .689 .465 r
.21911 .578 m .22075 .57656 L .21892 .57568 L F
.21911 .578 m .22083 .57906 L .22075 .57656 L F
.379 0 0 r
.1792 .54172 m .17719 .54241 L .18115 .54234 L F
.664 .776 .932 r
.70854 .39655 m .70605 .39796 L .70513 .39602 L F
.912 .888 .795 r
.61148 .46813 m .61201 .4706 L .6108 .47233 L F
.789 .491 .484 r
.48098 .62628 m .48489 .62929 L .48527 .62604 L F
0 .212 .729 r
.61759 .42818 m .61907 .42903 L .61674 .42795 L F
.61759 .42818 m .62043 .43086 L .61907 .42903 L F
.386 .209 .514 r
.37039 .59978 m .3725 .59656 L .3704 .59727 L F
.883 .99 .798 r
.5237 .52099 m .52429 .51857 L .52534 .51939 L F
.5237 .52099 m .52183 .52164 L .52429 .51857 L F
.864 .979 .682 r
.42814 .57226 m .42788 .57394 L .42966 .57118 L F
.647 .406 .539 r
.42953 .57598 m .42788 .57394 L .42814 .57226 L F
.42953 .57598 m .42717 .57644 L .42788 .57394 L F
.42788 .57394 m .42717 .57644 L .42953 .57598 L F
.619 .839 .984 r
.43139 .57964 m .43428 .57981 L .43191 .57935 L F
.825 .805 .832 r
.4356 .57522 m .43428 .57981 L .43628 .5758 L F
.4356 .57522 m .43191 .57935 L .43428 .57981 L F
.211 0 0 r
.43428 .57981 m .43539 .58055 L .43691 .57976 L F
.43428 .57981 m .43287 .58107 L .43539 .58055 L F
.742 .931 .589 r
.63724 .42135 m .63951 .41901 L .63752 .42161 L F
.826 .955 .614 r
.63922 .41851 m .63951 .41901 L .63724 .42135 L F
0 0 0 r
.60247 .50468 m .6052 .50162 L .60421 .50332 L F
0 0 .109 r
.6052 .50162 m .6067 .49954 L .6068 .50073 L F
0 0 0 r
.60421 .50332 m .6052 .50162 L .6068 .50073 L F
.47 0 0 r
.67852 .41562 m .67706 .41493 L .67468 .41544 L F
.39 .173 .46 r
.67918 .41347 m .67706 .41493 L .67852 .41562 L F
.945 .862 .727 r
.63096 .46045 m .63279 .45795 L .63153 .45677 L F
.936 .843 .727 r
.63279 .45795 m .6323 .45458 L .63153 .45677 L F
.208 0 0 r
.7514 .43611 m .74804 .43711 L .74868 .43657 L F
.618 .916 .648 r
.43074 .56978 m .42966 .57118 L .43151 .56944 L F
.43074 .56978 m .42814 .57226 L .42966 .57118 L F
.003 0 .03 r
.6067 .49954 m .61003 .49614 L .6091 .49765 L F
0 0 0 r
.6068 .50073 m .6067 .49954 L .6091 .49765 L F
.56688 .46995 m .56527 .47288 L .56636 .47112 L F
.682 .95 .956 r
.56527 .47288 m .56421 .47237 L .56636 .47112 L F
.097 0 0 r
.56636 .47112 m .56518 .47249 L .56583 .47229 L F
.56636 .47112 m .56583 .47229 L .56749 .47175 L F
0 0 0 r
.56717 .46942 m .56688 .46995 L .56636 .47112 L F
.81 .756 .802 r
.56818 .46773 m .56717 .46942 L .56941 .46653 L F
.509 .208 .391 r
.20156 .63731 m .19987 .63574 L .19981 .6385 L F
.20156 .63731 m .20226 .63545 L .19987 .63574 L F
.012 0 0 r
.40349 .58124 m .40504 .5811 L .40674 .57986 L F
0 0 0 r
.40674 .57986 m .40725 .58039 L .40887 .57904 L F
.40674 .57986 m .40504 .5811 L .40725 .58039 L F
.632 .898 .986 r
.7034 .45766 m .70651 .45749 L .70561 .45656 L F
.721 .912 .96 r
.70561 .45656 m .70651 .45749 L .71041 .45594 L F
.822 .826 .852 r
.49828 .5774 m .49432 .57752 L .49665 .57621 L F
0 .422 .841 r
.49665 .57621 m .50059 .57847 L .49828 .5774 L F
.437 .115 .321 r
.39208 .5888 m .39405 .58859 L .39548 .58506 L F
.413 .093 .31 r
.39405 .58859 m .39775 .58458 L .39548 .58506 L F
.644 .389 .518 r
.19884 .68622 m .19841 .68879 L .19557 .68894 L F
.077 0 .321 r
.19961 .68773 m .19884 .68622 L .20052 .68551 L F
.19961 .68773 m .19841 .68879 L .19884 .68622 L F
.604 .388 .561 r
.55339 .5165 m .55613 .51694 L .55596 .51435 L F
.617 .398 .561 r
.55596 .51435 m .55613 .51694 L .55856 .51405 L F
0 0 0 r
.72931 .43529 m .72731 .43761 L .72883 .43585 L F
.629 .92 .977 r
.72883 .43585 m .72731 .43761 L .72641 .43698 L F
0 0 0 r
.59891 .48916 m .59873 .4893 L .5982 .49141 L F
.062 0 .113 r
.60232 .48536 m .59982 .48826 L .60129 .4866 L F
.597 .873 .547 r
.60129 .4866 m .59873 .4893 L .59929 .48794 L F
0 0 0 r
.59929 .48794 m .59873 .4893 L .59891 .48916 L F
.59982 .48826 m .59841 .48955 L .59873 .4893 L F
.59841 .48955 m .59708 .49077 L .59873 .4893 L F
.59873 .4893 m .59708 .49077 L .59629 .49259 L F
.757 .914 .943 r
.64594 .43777 m .64713 .44004 L .64651 .43636 L F
.64594 .43777 m .64296 .43846 L .64713 .44004 L F
.721 .912 .96 r
.70561 .45656 m .71041 .45594 L .70914 .45376 L F
.611 .849 .989 r
.70914 .45376 m .71041 .45594 L .71225 .45489 L F
.521 .634 .903 r
.74051 .43328 m .73902 .43555 L .73833 .43362 L F
.74051 .43328 m .74362 .43631 L .73902 .43555 L F
.731 .57 0 r
.65206 .4238 m .65204 .42242 L .65217 .42145 L F
.65206 .4238 m .65218 .42552 L .65204 .42242 L F
.799 .968 .911 r
.72537 .44774 m .72449 .45008 L .7258 .4484 L F
.72537 .44774 m .72227 .45011 L .72449 .45008 L F
.367 .129 .415 r
.60446 .48218 m .60232 .48536 L .60411 .48398 L F
.237 .005 .345 r
.60726 .47865 m .60446 .48218 L .60593 .48075 L F
.105 0 .293 r
.60593 .48075 m .60446 .48218 L .60411 .48398 L F
.518 .486 .76 r
.26582 .57582 m .26336 .57351 L .26569 .5729 L F
.49 .818 1 r
.23346 .54121 m .23711 .54164 L .23515 .54227 L F
.772 .857 .914 r
.75278 .42993 m .75643 .42947 L .75573 .42897 L F
.814 .71 .75 r
.75869 .43059 m .75648 .43337 L .75601 .4306 L F
.614 .122 .061 r
.75643 .42947 m .75869 .43059 L .75676 .43059 L F
.75643 .42947 m .75681 .43076 L .75564 .43052 L F
.75643 .42947 m .75564 .43052 L .75573 .42897 L F
.689 .964 .938 r
.75643 .42947 m .75868 .42833 L .75869 .43059 L F
.814 .71 .75 r
.75869 .43059 m .75601 .4306 L .75573 .42897 L F
.614 .122 .061 r
.75676 .43059 m .75869 .43059 L .75681 .43076 L F
.676 .618 .783 r
.75547 .43341 m .75648 .43337 L .75573 .42897 L F
.614 .122 .061 r
.75564 .43052 m .75681 .43076 L .75536 .4309 L F
.676 .618 .783 r
.75382 .43347 m .75547 .43341 L .75564 .43052 L F
.75512 .43041 m .75564 .43052 L .75573 .42897 L F
.75382 .43347 m .75564 .43052 L .75512 .43041 L F
.614 .122 .061 r
.75564 .43052 m .75536 .4309 L .75573 .42897 L F
.396 .013 .19 r
.16722 .5626 m .16709 .56441 L .16441 .56518 L F
.209 .016 .386 r
.1696 .56073 m .16722 .5626 L .16749 .56237 L F
.1696 .56073 m .16917 .56341 L .16722 .5626 L F
.275 0 .173 r
.16917 .56341 m .16709 .56441 L .16722 .5626 L F
.706 .83 .941 r
.4644 .56461 m .46256 .56578 L .46064 .56453 L F
.759 .624 .71 r
.57121 .62655 m .57081 .62893 L .57409 .62952 L F
.557 .377 .593 r
.56111 .53798 m .56106 .5405 L .55861 .54096 L F
.584 .379 .569 r
.56106 .5405 m .55859 .54341 L .55861 .54096 L F
.12 0 0 r
.44561 .59107 m .4419 .59053 L .44339 .59209 L F
.912 .705 .609 r
.19723 .65912 m .19875 .66216 L .19951 .65937 L F
.632 .55 .744 r
.54885 .57062 m .54974 .57296 L .54714 .57353 L F
.517 .47 .743 r
.54976 .57519 m .54714 .57353 L .54974 .57296 L F
.655 .969 .895 r
.74044 .41469 m .73806 .41572 L .73926 .41435 L F
.645 .305 .381 r
.74044 .41469 m .74118 .41557 L .73788 .41579 L F
.085 .205 .693 r
.74193 .41345 m .74044 .41469 L .73926 .41435 L F
.74193 .41345 m .74207 .41517 L .74044 .41469 L F
.094 .193 .676 r
.74044 .41469 m .74207 .41517 L .74118 .41557 L F
.65 .317 .395 r
.74118 .41557 m .74027 .4174 L .73788 .41579 L F
0 0 0 r
.74207 .41517 m .74027 .4174 L .74118 .41557 L F
.74 .659 .77 r
.73926 .41435 m .74027 .4174 L .74207 .41517 L F
.73926 .41435 m .74207 .41517 L .74157 .41563 L F
.653 .887 .982 r
.7406 .41235 m .74193 .41345 L .73926 .41435 L F
.328 .444 .827 r
.73926 .41435 m .74157 .41563 L .7407 .41271 L F
.73926 .41435 m .7407 .41271 L .7406 .41235 L F
.655 .969 .895 r
.73806 .41572 m .73788 .41579 L .73926 .41435 L F
.647 .11 0 r
.46762 .5757 m .46596 .57606 L .46374 .5749 L F
.332 .812 .771 r
.46813 .57524 m .46762 .5757 L .46944 .57546 L F
.46813 .57524 m .46596 .57606 L .46762 .5757 L F
.413 .123 .359 r
.59044 .5176 m .59242 .51881 L .59007 .51941 L F
.59044 .5176 m .59306 .51689 L .59242 .51881 L F
.704 .794 .92 r
.73573 .4343 m .73214 .43384 L .73517 .43249 L F
.261 .664 .966 r
.73517 .43249 m .73833 .43362 L .73573 .4343 L F
.964 .94 .658 r
.62213 .4812 m .62312 .47924 L .62328 .47623 L F
.596 .222 .304 r
.38076 .59307 m .38337 .59317 L .38127 .59142 L F
.559 .239 .382 r
.38127 .59142 m .38337 .59317 L .38391 .59134 L F
.102 0 0 r
.62504 .41004 m .62178 .41205 L .62266 .41085 L F
.989 .762 .502 r
.52641 .58783 m .52519 .58469 L .52672 .586 L F
.79 .764 .829 r
.53703 .68529 m .53593 .68905 L .53605 .68802 L F
.439 .6 .913 r
.53593 .68905 m .53827 .68903 L .53605 .68802 L F
.742 .874 .941 r
.53407 .68818 m .53605 .68802 L .53593 .68905 L F
.651 .533 .707 r
.56484 .62675 m .56757 .62398 L .56372 .62312 L F
0 0 0 r
.40283 .6251 m .40089 .62652 L .40116 .62392 L F
.554 .126 .183 r
.4038 .624 m .40283 .6251 L .40116 .62392 L F
.574 .352 .542 r
.54013 .66752 m .5425 .66785 L .54181 .66536 L F
.336 .776 .964 r
.72696 .41012 m .73051 .41045 L .72974 .40987 L F
.677 .826 .955 r
.73153 .4082 m .73051 .41045 L .73284 .40916 L F
.817 .987 .879 r
.72974 .40987 m .73051 .41045 L .73153 .4082 L F
.444 .839 .98 r
.41892 .59685 m .42097 .59632 L .423 .59679 L F
0 .151 .608 r
.42097 .59632 m .42364 .59835 L .42283 .59782 L F
.751 .239 0 r
.42097 .59632 m .42285 .59772 L .423 .59679 L F
0 .151 .608 r
.42097 .59632 m .42306 .59781 L .42339 .59812 L F
.42097 .59632 m .42339 .59812 L .42364 .59835 L F
.751 .239 0 r
.42097 .59632 m .42283 .59782 L .42285 .59772 L F
0 0 .379 r
.42364 .59835 m .423 .59679 L .42283 .59782 L F
.702 .659 .805 r
.68737 .453 m .6839 .45174 L .68632 .45157 L F
.644 .801 .958 r
.68999 .45207 m .68737 .453 L .68632 .45157 L F
.172 0 0 r
.447 .59898 m .44894 .59867 L .45132 .59676 L F
.828 .487 .41 r
.44894 .59867 m .45178 .59941 L .45132 .59676 L F
.489 .089 .209 r
.45959 .63888 m .45828 .64096 L .45572 .64119 L F
.22 .717 .914 r
.45801 .63812 m .46189 .63849 L .45959 .63888 L F
.257 0 .025 r
.62073 .40461 m .62301 .40405 L .62375 .40222 L F
.245 0 .021 r
.62375 .40222 m .62514 .40334 L .62628 .40191 L F
.62375 .40222 m .62301 .40405 L .62514 .40334 L F
.831 .698 .717 r
.64125 .44246 m .64442 .44286 L .64296 .43846 L F
.698 .629 .776 r
.64296 .43846 m .64442 .44286 L .64713 .44004 L F
.666 .935 .968 r
.73082 .44414 m .73474 .44346 L .73413 .44304 L F
.674 .955 .949 r
.73614 .44158 m .73474 .44346 L .73697 .44208 L F
.688 .976 .904 r
.73614 .44158 m .73413 .44304 L .73474 .44346 L F
.481 .453 .749 r
.23815 .57011 m .23921 .56646 L .2369 .56703 L F
.23815 .57011 m .24001 .56979 L .23921 .56646 L F
.481 .375 .657 r
.2383 .57256 m .24001 .56979 L .23815 .57011 L F
.772 .707 .791 r
.53623 .57987 m .53427 .58239 L .53323 .58212 L F
.661 .519 .679 r
.45278 .59174 m .45279 .59414 L .45517 .59113 L F
.45278 .59174 m .45279 .59414 L .45517 .59113 L F
.75 .577 .66 r
.76234 .4283 m .75869 .43059 L .75868 .42833 L F
.091 .286 .768 r
.76328 .40711 m .76566 .409 L .76495 .41068 L F
.276 .349 .758 r
.76566 .409 m .76519 .4123 L .76495 .41068 L F
.429 .248 .532 r
.2369 .56703 m .23921 .56646 L .23936 .56429 L F
.488 .531 .828 r
.61453 .42162 m .6132 .42524 L .61266 .42469 L F
.239 .465 .876 r
.65266 .41214 m .65058 .4117 L .6495 .40951 L F
.713 .642 .777 r
.36947 .62318 m .37302 .62427 L .37172 .62054 L F
.382 .442 .798 r
.37172 .62054 m .37302 .62427 L .37428 .62216 L F
.496 .59 .878 r
.37302 .62427 m .3749 .62401 L .37428 .62216 L F
.624 .223 .263 r
.42075 .64455 m .41932 .64664 L .41698 .64617 L F
.614 .212 .256 r
.42324 .64627 m .41932 .64664 L .42075 .64455 L F
.734 .461 .515 r
.56452 .51633 m .56819 .51425 L .56417 .51425 L F
.56452 .51633 m .5681 .5164 L .56819 .51425 L F
.431 .291 .59 r
.55117 .55256 m .55151 .55515 L .54941 .55567 L F
.539 .448 .7 r
.55151 .55515 m .55016 .55894 L .54941 .55567 L F
.723 .379 .396 r
.66238 .44064 m .65953 .44225 L .66398 .43799 L F
.66238 .44064 m .66341 .44232 L .65953 .44225 L F
.625 .707 .904 r
.71111 .40718 m .71449 .40817 L .71366 .40638 L F
.58 .682 .91 r
.71366 .40638 m .71449 .40817 L .71613 .40583 L F
.55 .64 .892 r
.71449 .40817 m .71717 .40778 L .71613 .40583 L F
.496 0 0 r
.76816 .4157 m .76892 .41555 L .76717 .41452 L F
.76816 .4157 m .76717 .41452 L .76665 .41266 L F
.758 .825 .904 r
.65784 .40599 m .65892 .40757 L .6557 .40753 L F
.627 .828 .978 r
.66001 .40553 m .65892 .40757 L .65784 .40599 L F
.66001 .40553 m .66089 .40689 L .65892 .40757 L F
.09 0 0 r
.18763 .55609 m .1842 .55612 L .18555 .55637 L F
.681 .451 .566 r
.44251 .64394 m .43887 .64462 L .43788 .64374 L F
.929 .972 .724 r
.6108 .47233 m .60838 .47475 L .60974 .47138 L F
.6108 .47233 m .60885 .47563 L .60838 .47475 L F
.912 .888 .795 r
.61148 .46813 m .6108 .47233 L .60974 .47138 L F
.731 .545 .64 r
.43632 .6351 m .44011 .63545 L .44064 .63292 L F
.849 .834 .832 r
.53785 .5289 m .54047 .52907 L .53976 .52727 L F
.784 .358 .237 r
.53909 .53034 m .54047 .52907 L .53785 .5289 L F
.953 .65 .423 r
.54047 .52907 m .54111 .53182 L .53909 .53034 L F
.327 .526 .897 r
.53976 .52727 m .54047 .52907 L .54156 .52745 L F
.647 .901 .577 r
.54156 .52745 m .54047 .52907 L .53909 .53034 L F
.953 .65 .423 r
.53909 .53034 m .54111 .53182 L .54047 .52907 L F
.317 .741 .974 r
.21528 .54063 m .21744 .54054 L .21921 .54134 L F
.268 .725 .954 r
.21744 .54054 m .22123 .54117 L .21921 .54134 L F
.85 .919 .878 r
.54004 .56801 m .53653 .56951 L .5386 .56714 L F
.651 .874 .982 r
.54088 .56615 m .54004 .56801 L .5386 .56714 L F
.157 0 0 r
.62628 .40191 m .62892 .40176 L .63071 .40077 L F
.987 .713 .393 r
.63104 .40199 m .63071 .40077 L .62892 .40176 L F
.63104 .40199 m .63217 .40092 L .63071 .40077 L F
.273 .333 .743 r
.51546 .57058 m .51791 .57243 L .51681 .56891 L F
.93 .813 .707 r
.55011 .51729 m .55056 .51461 L .5492 .51377 L F
.519 .211 .384 r
.55003 .51947 m .55339 .5165 L .55011 .51729 L F
.747 .721 .828 r
.55011 .51729 m .5492 .51377 L .54565 .51771 L F
.984 .709 .408 r
.54873 .51842 m .55011 .51729 L .54565 .51771 L F
.54873 .51842 m .55003 .51947 L .55011 .51729 L F
.445 .244 .512 r
.2639 .58416 m .26211 .58235 L .26414 .58173 L F
.2639 .58416 m .26188 .58482 L .26211 .58235 L F
.403 .113 .354 r
.53866 .59008 m .53521 .59362 L .53537 .59136 L F
.575 .152 .201 r
.18115 .54234 m .18345 .54295 L .1852 .5409 L F
.553 .126 .185 r
.1852 .5409 m .18345 .54295 L .18703 .54214 L F
.627 .809 .97 r
.74156 .41987 m .73962 .42062 L .7385 .41946 L F
.553 .352 .563 r
.5745 .52894 m .57687 .53103 L .57442 .53146 L F
.668 .319 .373 r
.5745 .52894 m .57703 .5294 L .57687 .53103 L F
.816 .595 .604 r
.22075 .60011 m .22022 .60265 L .22328 .60304 L F
.756 .55 .618 r
.22022 .60265 m .22298 .60544 L .22328 .60304 L F
.574 .317 .489 r
.22328 .60304 m .22543 .60508 L .22488 .60199 L F
.22328 .60304 m .22298 .60544 L .22543 .60508 L F
.391 0 .172 r
.19546 .69439 m .19292 .69534 L .19414 .69488 L F
.519 .211 .384 r
.55003 .51947 m .55227 .51876 L .55339 .5165 L F
.743 .585 .68 r
.55227 .51876 m .55613 .51694 L .55339 .5165 L F
.352 .137 .442 r
.61722 .41583 m .61731 .41892 L .61471 .41949 L F
.227 0 .15 r
.61666 .42037 m .61471 .41949 L .61731 .41892 L F
.61666 .42037 m .61453 .42162 L .61471 .41949 L F
.952 .892 .733 r
.66804 .42727 m .66953 .42571 L .66934 .4236 L F
.727 .217 0 r
.50693 .55098 m .50655 .55131 L .50552 .54972 L F
.50693 .55098 m .50798 .55227 L .50655 .55131 L F
.012 0 .281 r
.56941 .46653 m .57204 .46243 L .57203 .46346 L F
.56941 .46653 m .57134 .46529 L .57204 .46243 L F
0 0 0 r
.56941 .46653 m .56873 .46807 L .57134 .46529 L F
.611 .349 .495 r
.56111 .53798 m .56352 .53994 L .56106 .5405 L F
.56111 .53798 m .56367 .53775 L .56352 .53994 L F
.935 .742 .618 r
.59742 .45051 m .59997 .44906 L .5989 .44858 L F
.59742 .45051 m .59955 .4518 L .59997 .44906 L F
.565 .907 .974 r
.5989 .44858 m .59997 .44906 L .60142 .44764 L F
.613 .705 .91 r
.47922 .57357 m .47585 .57241 L .47792 .5723 L F
.593 .801 .979 r
.48149 .57284 m .47922 .57357 L .47792 .5723 L F
.476 .852 .985 r
.18683 .66146 m .18516 .66127 L .18507 .66132 L F
.18683 .66146 m .18685 .66033 L .18516 .66127 L F
.18683 .66146 m .18917 .66093 L .18685 .66033 L F
.606 .752 .948 r
.70504 .40693 m .70641 .40458 L .70403 .40533 L F
.70504 .40693 m .70754 .4062 L .70641 .40458 L F
.863 .725 .708 r
.37318 .62859 m .37555 .63228 L .37621 .63039 L F
.37318 .62859 m .37437 .63237 L .37555 .63228 L F
.596 .644 .869 r
.37621 .63039 m .37555 .63228 L .37911 .6296 L F
.631 .769 .946 r
.37555 .63228 m .38067 .63184 L .37911 .6296 L F
0 0 0 r
.22993 .59375 m .23158 .5927 L .23318 .59123 L F
.56 .535 .784 r
.23318 .59123 m .23535 .5907 L .23432 .58731 L F
0 0 0 r
.23158 .5927 m .23535 .5907 L .23318 .59123 L F
.21 0 .308 r
.59581 .51337 m .59767 .51343 L .59479 .51576 L F
.382 .175 .469 r
.24374 .61957 m .24214 .61789 L .24395 .61719 L F
.24374 .61957 m .24177 .62032 L .24214 .61789 L F
0 .055 .61 r
.52373 .58315 m .52519 .58469 L .5246 .58337 L F
.528 .278 .479 r
.26551 .56431 m .26392 .56744 L .26373 .56459 L F
.26551 .56431 m .26584 .56798 L .26392 .56744 L F
.033 0 .4 r
.26762 .56461 m .26551 .56431 L .26705 .56249 L F
.26762 .56461 m .26584 .56798 L .26551 .56431 L F
.964 .736 .546 r
.45429 .61491 m .45277 .61456 L .45294 .61148 L F
.111 .278 .755 r
.45538 .6138 m .45429 .61491 L .45294 .61148 L F
.492 .872 .976 r
.45429 .61491 m .45277 .61456 L .45538 .6138 L F
0 0 0 r
.62153 .41433 m .62064 .41409 L .62178 .41205 L F
.724 .734 .859 r
.69232 .45074 m .69572 .45151 L .69368 .45266 L F
.336 0 .14 r
.62064 .41409 m .61954 .41621 L .61722 .41583 L F
.518 .358 .603 r
.61954 .41621 m .61731 .41892 L .61722 .41583 L F
.637 .687 .88 r
.6999 .45657 m .70099 .45863 L .7034 .45766 L F
0 0 0 r
.57204 .46243 m .57431 .46042 L .57203 .46346 L F
.568 .56 .805 r
.26778 .55534 m .26606 .55641 L .26409 .55201 L F
.34 .557 .915 r
.38785 .63563 m .38918 .63435 L .38563 .63293 L F
.124 .198 .669 r
.38785 .63563 m .38971 .63783 L .38918 .63435 L F
.012 0 0 r
.40349 .58124 m .40295 .58192 L .40504 .5811 L F
.959 .946 .668 r
.57488 .48022 m .5739 .48459 L .57613 .4813 L F
.869 .899 .851 r
.57488 .48022 m .57613 .4813 L .57854 .47845 L F
.663 .552 .719 r
.56713 .62623 m .56757 .62398 L .56484 .62675 L F
.702 .57 .703 r
.56468 .62921 m .56713 .62623 L .56484 .62675 L F
.243 0 0 r
.41821 .58991 m .41744 .59067 L .41514 .59119 L F
.2 .024 .405 r
.42048 .58791 m .41821 .58991 L .42027 .58549 L F
.525 .368 .611 r
.42048 .58791 m .41744 .59067 L .41821 .58991 L F
0 0 0 r
.62153 .41433 m .61954 .41621 L .62064 .41409 L F
.534 .869 .602 r
.45646 .59706 m .45713 .59633 L .459 .59485 L F
.624 .299 .399 r
.45713 .59633 m .46179 .59429 L .459 .59485 L F
.799 .702 .758 r
.75886 .41097 m .75467 .41265 L .75771 .40973 L F
.75886 .41097 m .75646 .41373 L .75467 .41265 L F
.6 .414 .602 r
.40911 .59128 m .41111 .5927 L .40876 .59021 L F
.40876 .59021 m .41111 .5927 L .40911 .59128 L F
.533 .655 .913 r
.23898 .56137 m .2387 .55824 L .23722 .55803 L F
.23898 .56137 m .24101 .56086 L .2387 .55824 L F
.43 .328 .638 r
.23898 .56137 m .24114 .56356 L .24101 .56086 L F
.23898 .56137 m .23936 .56429 L .24114 .56356 L F
.712 .68 .817 r
.64713 .44004 m .65146 .4408 L .65 .43941 L F
.864 .987 .84 r
.44989 .58297 m .44794 .58518 L .44772 .58325 L F
0 .19 .722 r
.44794 .58518 m .45008 .58724 L .44772 .58325 L F
.678 .529 .675 r
.44957 .58133 m .44925 .58189 L .44772 .58325 L F
.602 .843 .99 r
.44666 .58419 m .44794 .58518 L .44772 .58325 L F
.147 .386 .837 r
.4528 .58504 m .44989 .58297 L .45254 .58315 L F
.765 .689 .779 r
.44772 .58325 m .45254 .58315 L .44989 .58297 L F
.44772 .58325 m .4528 .58504 L .45254 .58315 L F
.77 .684 .768 r
.44772 .58325 m .45008 .58724 L .4528 .58504 L F
.678 .529 .675 r
.44925 .58189 m .44724 .58534 L .44772 .58325 L F
.602 .843 .99 r
.44606 .58372 m .44666 .58419 L .44772 .58325 L F
.717 .977 .759 r
.5355 .50545 m .53649 .50381 L .53868 .50257 L F
.786 .993 .771 r
.53868 .50257 m .53922 .50097 L .53933 .50138 L F
.53868 .50257 m .53649 .50381 L .53922 .50097 L F
.67 .47 .606 r
.43384 .63794 m .43632 .6351 L .43422 .63569 L F
.801 .868 .897 r
.51415 .53521 m .51131 .53745 L .50994 .53649 L F
.694 .719 .869 r
.63133 .44144 m .63272 .44318 L .62902 .44241 L F
.835 .878 .875 r
.63417 .43932 m .63272 .44318 L .63133 .44144 L F
.63417 .43932 m .63554 .44042 L .63272 .44318 L F
0 0 0 r
.74566 .43778 m .74439 .43919 L .74255 .43971 L F
.2 .721 .7 r
.74255 .43971 m .74439 .43919 L .7425 .4397 L F
.624 .648 .853 r
.71475 .39727 m .71573 .39933 L .71222 .39805 L F
.626 .659 .863 r
.71715 .3966 m .71573 .39933 L .71475 .39727 L F
.71715 .3966 m .71826 .39856 L .71573 .39933 L F
.186 .008 .392 r
.21208 .62074 m .21296 .62257 L .2132 .62002 L F
.21208 .62074 m .2116 .62325 L .21296 .62257 L F
.43 .214 .484 r
.45279 .59414 m .45523 .59358 L .45517 .59113 L F
.45279 .59414 m .45523 .59358 L .45517 .59113 L F
.633 .956 .926 r
.71648 .45276 m .71526 .45432 L .71744 .45333 L F
.71648 .45276 m .71447 .45399 L .71526 .45432 L F
.774 .71 .792 r
.63387 .43283 m .63639 .43093 L .63255 .43238 L F
.574 .135 .168 r
.41497 .64427 m .41334 .64608 L .41092 .6445 L F
.674 .254 .241 r
.41698 .64617 m .41334 .64608 L .41497 .64427 L F
.931 .766 .654 r
.50695 .54392 m .5049 .54545 L .50569 .543 L F
.50695 .54392 m .50655 .54635 L .5049 .54545 L F
.865 .724 .704 r
.75592 .41603 m .75309 .41553 L .75467 .41265 L F
.792 .835 .884 r
.75592 .41603 m .7548 .4164 L .75309 .41553 L F
.805 .699 .748 r
.75646 .41373 m .75592 .41603 L .75467 .41265 L F
.81 .955 .619 r
.57932 .47626 m .58066 .47525 L .58032 .47501 L F
.57932 .47626 m .57854 .47845 L .58066 .47525 L F
.648 .965 .806 r
.58195 .47357 m .58066 .47525 L .58298 .4723 L F
.58195 .47357 m .58032 .47501 L .58066 .47525 L F
.934 .845 .732 r
.55056 .51461 m .55095 .51041 L .5492 .51377 L F
.533 .349 .577 r
.56828 .53197 m .56865 .53439 L .56622 .53489 L F
.611 .341 .483 r
.56828 .53197 m .5706 .53395 L .56865 .53439 L F
.56828 .53197 m .57193 .53146 L .5706 .53395 L F
.541 .342 .559 r
.56865 .53439 m .56617 .5375 L .56622 .53489 L F
.63 .734 .922 r
.71346 .39502 m .71222 .39805 L .71101 .39572 L F
.71346 .39502 m .71475 .39727 L .71222 .39805 L F
.856 .694 .68 r
.41484 .60052 m .41436 .60255 L .4123 .59907 L F
.973 .666 .357 r
.73308 .40425 m .73531 .40459 L .73403 .40295 L F
.846 .587 .547 r
.73227 .40656 m .73531 .40459 L .73308 .40425 L F
.884 .987 .808 r
.73531 .40459 m .73707 .4009 L .73403 .40295 L F
.73531 .40459 m .73771 .40157 L .73707 .4009 L F
.973 .666 .357 r
.73308 .40425 m .73531 .40459 L .73403 .40295 L F
.676 .677 .843 r
.73293 .39744 m .73177 .40034 L .73045 .39814 L F
.73293 .39744 m .7344 .39913 L .73177 .40034 L F
.844 .563 .513 r
.51261 .5313 m .51062 .53116 L .51255 .52893 L F
.758 .993 .876 r
.51585 .52613 m .51255 .52893 L .51204 .52839 L F
.921 .967 .666 r
.51255 .52893 m .51062 .53116 L .51204 .52839 L F
.844 .563 .513 r
.51261 .5313 m .51062 .53116 L .51255 .52893 L F
.436 0 0 r
.18703 .54214 m .18928 .54236 L .19123 .54093 L F
.141 0 0 r
.18928 .54236 m .19331 .54063 L .19123 .54093 L F
.488 0 0 r
.45027 .63797 m .45178 .63869 L .45338 .63883 L F
.977 .902 .673 r
.45495 .64099 m .45338 .63883 L .45178 .63869 L F
.45495 .64099 m .45695 .63787 L .45338 .63883 L F
.518 .745 .978 r
.70806 .4489 m .70466 .44801 L .7074 .44746 L F
.377 .632 .954 r
.70952 .44753 m .70806 .4489 L .7074 .44746 L F
.416 .696 .979 r
.70952 .44753 m .71083 .44898 L .70806 .4489 L F
0 0 0 r
.44019 .57878 m .44154 .57839 L .44244 .57798 L F
.794 .698 .759 r
.66502 .45139 m .66247 .45182 L .66582 .4522 L F
.772 .699 .782 r
.66502 .45139 m .66582 .4522 L .66833 .44932 L F
.789 .93 .563 r
.53432 .50727 m .53416 .50689 L .5355 .50545 L F
.668 .889 .533 r
.53416 .50689 m .53649 .50381 L .5355 .50545 L F
.498 .346 .605 r
.26373 .56459 m .26392 .56744 L .2619 .56787 L F
.497 .517 .807 r
.26471 .56914 m .2619 .56787 L .26392 .56744 L F
.206 .001 .367 r
.42105 .58586 m .42027 .58549 L .42217 .58218 L F
.108 .08 .542 r
.42105 .58586 m .42118 .5872 L .42027 .58549 L F
.52 .245 .438 r
.42118 .5872 m .42048 .58791 L .42027 .58549 L F
.77 .79 .869 r
.18412 .64035 m .18291 .64408 L .18184 .64124 L F
.18412 .64035 m .18416 .6421 L .18291 .64408 L F
.459 .301 .578 r
.36837 .60283 m .37046 .60232 L .37039 .59978 L F
.419 .308 .621 r
.36837 .60283 m .37055 .60482 L .37046 .60232 L F
.36837 .60283 m .36875 .60552 L .37055 .60482 L F
.67 .946 .687 r
.61003 .49614 m .61281 .49345 L .61104 .4946 L F
0 0 0 r
.6091 .49765 m .61003 .49614 L .61104 .4946 L F
.445 .359 .666 r
.26182 .58734 m .2596 .58536 L .26188 .58482 L F
.26182 .58734 m .25999 .58806 L .2596 .58536 L F
.413 .412 .749 r
.21407 .60264 m .2159 .6025 L .21486 .5988 L F
.66 .969 .905 r
.41759 .57383 m .41838 .57234 L .41966 .57285 L F
.41759 .57383 m .41542 .5741 L .41838 .57234 L F
.909 .964 .646 r
.60885 .47563 m .60726 .47865 L .60733 .47683 L F
.956 .941 .628 r
.60838 .47475 m .60885 .47563 L .60733 .47683 L F
.832 .988 .718 r
.61363 .49136 m .61281 .49345 L .61515 .49038 L F
.83 .984 .705 r
.61104 .4946 m .61281 .49345 L .61363 .49136 L F
.505 .372 .633 r
.55065 .5584 m .5503 .56403 L .54809 .56456 L F
.513 .4 .661 r
.5503 .56403 m .55078 .56654 L .54809 .56456 L F
.52 .398 .654 r
.54809 .56456 m .55078 .56654 L .54844 .56715 L F
.385 0 0 r
.74779 .43853 m .74566 .43778 L .74804 .43711 L F
.74779 .43853 m .74439 .43919 L .74566 .43778 L F
.979 .772 .556 r
.5089 .55429 m .51052 .55517 L .51004 .558 L F
.914 .871 .782 r
.56829 .48974 m .57162 .48763 L .57067 .48688 L F
.56829 .48974 m .56949 .49089 L .57162 .48763 L F
.884 .959 .844 r
.57327 .48386 m .57162 .48763 L .5739 .48459 L F
.57327 .48386 m .57067 .48688 L .57162 .48763 L F
.959 .737 .559 r
.21914 .59658 m .21882 .59952 L .22075 .60011 L F
.849 .631 .606 r
.21792 .60181 m .22075 .60011 L .21882 .59952 L F
.21792 .60181 m .22022 .60265 L .22075 .60011 L F
.481 .253 .491 r
.45517 .59113 m .45523 .59358 L .45753 .59075 L F
.45517 .59113 m .45523 .59358 L .45753 .59075 L F
.019 .255 .757 r
.45646 .59706 m .45855 .59851 L .45713 .59633 L F
.035 .533 .878 r
.23947 .54183 m .24133 .54225 L .24134 .54291 L F
0 .437 .837 r
.24133 .54225 m .24297 .54346 L .24134 .54291 L F
.647 .776 .942 r
.47307 .58046 m .47467 .58281 L .47778 .58157 L F
.772 .707 .791 r
.53623 .57987 m .53323 .58212 L .53597 .57765 L F
.933 .859 .745 r
.74997 .42611 m .74853 .42778 L .74761 .42594 L F
.704 .953 .952 r
.74997 .42611 m .75086 .42412 L .7514 .42362 L F
0 0 0 r
.7514 .42362 m .75086 .42412 L .75087 .42411 L F
.732 .904 .527 r
.75169 .42335 m .74997 .42611 L .7514 .42362 L F
.363 .709 .986 r
.7514 .42362 m .75403 .42388 L .75307 .4228 L F
0 0 0 r
.7514 .42362 m .75307 .4228 L .75403 .42388 L F
.7514 .42362 m .75087 .42411 L .75307 .4228 L F
.732 .904 .527 r
.75197 .4229 m .75169 .42335 L .7514 .42362 L F
.704 .953 .952 r
.74997 .42611 m .74761 .42594 L .75086 .42412 L F
.682 .673 .836 r
.67276 .40546 m .67222 .40646 L .66985 .40387 L F
.746 .274 .126 r
.67059 .40753 m .67222 .40646 L .67409 .40871 L F
.694 .172 0 r
.67222 .40646 m .6735 .40781 L .67409 .40871 L F
.394 .288 .615 r
.24997 .608 m .24845 .60688 L .25067 .60533 L F
.24997 .608 m .24866 .60856 L .24845 .60688 L F
0 0 0 r
.57204 .46243 m .57308 .46184 L .57431 .46042 L F
.57431 .46042 m .57601 .45912 L .57717 .45782 L F
.57431 .46042 m .57308 .46184 L .57601 .45912 L F
.473 .186 .396 r
.58529 .52305 m .58761 .52421 L .5854 .52414 L F
.58529 .52305 m .58778 .52254 L .58761 .52421 L F
.292 .059 .378 r
.58529 .52305 m .58764 .51997 L .58778 .52254 L F
.638 .549 .737 r
.39938 .60576 m .39721 .60867 L .39692 .60636 L F
.614 .515 .719 r
.39938 .60576 m .40004 .60865 L .39721 .60867 L F
.862 .802 .789 r
.65953 .44225 m .66058 .44509 L .65777 .4448 L F
0 0 0 r
.66058 .44509 m .65884 .44862 L .6599 .44673 L F
.66058 .44509 m .6599 .44673 L .65777 .4448 L F
.747 .75 .854 r
.66341 .44232 m .66058 .44509 L .65953 .44225 L F
.456 .221 .468 r
.23304 .57983 m .23513 .57943 L .23544 .57625 L F
.5 .303 .544 r
.23544 .57625 m .23825 .57584 L .2383 .57256 L F
.48 .24 .473 r
.23513 .57943 m .23825 .57584 L .23544 .57625 L F
.042 0 .364 r
.42401 .57849 m .4235 .5814 L .42217 .58218 L F
.319 .169 .514 r
.4235 .5814 m .42105 .58586 L .42217 .58218 L F
.222 .721 .91 r
.22123 .54117 m .22336 .54086 L .2252 .54148 L F
.019 .589 .768 r
.22336 .54086 m .22721 .5412 L .2252 .54148 L F
.276 0 0 r
.73744 .40076 m .73879 .39879 L .73771 .40157 L F
.73654 .39801 m .73803 .39853 L .73744 .40076 L F
.73803 .39853 m .73879 .39879 L .73744 .40076 L F
.14 0 0 r
.73825 .39851 m .73654 .39801 L .73803 .39853 L F
.276 0 0 r
.73654 .39801 m .7401 .39856 L .73899 .39868 L F
.73825 .39851 m .73899 .39868 L .73887 .3987 L F
.73654 .39801 m .73899 .39868 L .73825 .39851 L F
.14 0 0 r
.73962 .39843 m .73654 .39801 L .73825 .39851 L F
.03 .588 .813 r
.73948 .39832 m .7401 .39856 L .73654 .39801 L F
.14 0 0 r
.73962 .39843 m .73948 .39832 L .73654 .39801 L F
.428 .566 .89 r
.73835 .39729 m .73679 .39818 L .73443 .3938 L F
.712 .685 .822 r
.73293 .39744 m .73654 .39801 L .7344 .39913 L F
.748 .579 .665 r
.73593 .39866 m .73654 .39801 L .73293 .39744 L F
.428 .566 .89 r
.73679 .39818 m .73593 .39866 L .7357 .39793 L F
.73679 .39818 m .7357 .39793 L .73443 .3938 L F
.73962 .39843 m .73825 .39851 L .73835 .39729 L F
.73825 .39851 m .73803 .39853 L .73804 .39846 L F
.73825 .39851 m .73804 .39846 L .73835 .39729 L F
.276 0 0 r
.73804 .39846 m .73887 .3987 L .73882 .3987 L F
.73654 .39801 m .73825 .39851 L .73804 .39846 L F
.73825 .39851 m .73887 .3987 L .73804 .39846 L F
.14 0 0 r
.73803 .39853 m .73654 .39801 L .73593 .39866 L F
.276 0 0 r
.73654 .39801 m .73882 .3987 L .73879 .39879 L F
.428 .566 .89 r
.73803 .39853 m .73593 .39866 L .73835 .39729 L F
.8 .986 .892 r
.73707 .4009 m .73771 .40157 L .73882 .3987 L F
.589 .281 .416 r
.60388 .45372 m .60605 .45373 L .60371 .45191 L F
.60388 .45372 m .60605 .45373 L .60371 .45191 L F
.895 .965 .827 r
.565 .49452 m .56477 .49693 L .56713 .49397 L F
.832 .925 .895 r
.56351 .49613 m .56477 .49693 L .565 .49452 L F
.301 .148 .5 r
.26582 .57582 m .26601 .57861 L .2642 .57928 L F
.41 .238 .535 r
.26621 .58087 m .2642 .57928 L .26601 .57861 L F
.26621 .58087 m .26414 .58173 L .2642 .57928 L F
.433 .504 .833 r
.47418 .56958 m .47232 .56976 L .47085 .56629 L F
.531 .568 .837 r
.47585 .57241 m .47232 .56976 L .47418 .56958 L F
.462 .008 .086 r
.44251 .64394 m .44121 .64574 L .43887 .64462 L F
.737 .378 .372 r
.44492 .64423 m .44121 .64574 L .44251 .64394 L F
.647 .749 .924 r
.72444 .39855 m .72198 .39956 L .7208 .39773 L F
.773 .934 .936 r
.19978 .65846 m .20336 .65806 L .20117 .65749 L F
.19978 .65846 m .19874 .65932 L .20336 .65806 L F
.327 .795 .93 r
.20591 .65711 m .20336 .65806 L .20486 .65701 L F
.20591 .65711 m .20117 .65749 L .20336 .65806 L F
.959 .946 .668 r
.57488 .48022 m .57327 .48386 L .5739 .48459 L F
.485 .848 .6 r
.41181 .59404 m .41349 .59265 L .4164 .59391 L F
.27 .767 .892 r
.4164 .59391 m .41395 .59372 L .41181 .59404 L F
.602 .071 0 r
.41349 .59265 m .41736 .59315 L .4164 .59391 L F
.546 .109 .162 r
.41736 .59315 m .41395 .59372 L .4164 .59391 L F
.65 .61 .796 r
.53597 .57765 m .53323 .58212 L .5326 .57918 L F
0 0 0 r
.44025 .56522 m .43873 .56558 L .43631 .566 L F
.441 0 0 r
.44259 .56459 m .43873 .56558 L .44025 .56522 L F
.616 .899 .987 r
.66648 .40391 m .66738 .40452 L .66489 .40485 L F
.578 .793 .981 r
.66967 .40271 m .66985 .40387 L .66738 .40452 L F
.715 .876 .956 r
.61137 .46576 m .60998 .46668 L .60878 .46558 L F
.51 0 0 r
.60878 .46558 m .60998 .46668 L .61148 .46813 L F
.727 .639 .761 r
.21906 .56475 m .21452 .5652 L .2144 .56425 L F
.187 .523 .919 r
.21743 .56261 m .21906 .56475 L .21601 .56239 L F
.974 .827 .636 r
.21702 .5661 m .21906 .56475 L .21743 .56261 L F
.21702 .5661 m .21835 .56729 L .21906 .56475 L F
0 0 .4 r
.19548 .68882 m .19194 .68587 L .19261 .68884 L F
.677 .529 .677 r
.19274 .69156 m .19548 .68882 L .19261 .68884 L F
.707 .985 .862 r
.53052 .51202 m .52745 .51372 L .52889 .51239 L F
.874 .956 .856 r
.53103 .50948 m .53348 .50887 L .53052 .51202 L F
.907 .978 .789 r
.53103 .50948 m .53052 .51202 L .52889 .51239 L F
.067 0 .06 r
.60411 .48398 m .60232 .48536 L .60129 .4866 L F
.632 .383 .523 r
.57971 .5287 m .57687 .53103 L .57703 .5294 L F
.749 .959 .661 r
.61515 .49038 m .61758 .48742 L .61618 .48841 L F
.76 .976 .713 r
.61363 .49136 m .61515 .49038 L .61618 .48841 L F
.663 .962 .763 r
.53103 .50948 m .53432 .50727 L .53348 .50887 L F
.481 .375 .657 r
.2383 .57256 m .24 .5739 L .24001 .56979 L F
.485 .246 .476 r
.23825 .57584 m .24 .5739 L .2383 .57256 L F
.869 .899 .851 r
.57488 .48022 m .57854 .47845 L .5778 .478 L F
.807 .995 .864 r
.57932 .47626 m .5778 .478 L .57854 .47845 L F
.868 .988 .832 r
.66934 .4236 m .67119 .42225 L .67057 .42154 L F
.89 .985 .804 r
.67057 .42154 m .67119 .42225 L .67356 .41917 L F
.182 0 0 r
.20004 .55344 m .19989 .5521 L .20206 .55237 L F
.20004 .55344 m .19783 .554 L .19989 .5521 L F
.542 .83 .998 r
.51933 .68154 m .51832 .68314 L .51676 .68218 L F
.524 .341 .574 r
.51933 .68154 m .51676 .68218 L .51832 .68314 L F
.409 .499 .84 r
.19194 .68587 m .19251 .68335 L .19035 .68335 L F
.19194 .68587 m .19381 .68573 L .19251 .68335 L F
0 0 .4 r
.19548 .68882 m .19381 .68573 L .19194 .68587 L F
.884 .918 .843 r
.56716 .49132 m .56713 .49397 L .56949 .49089 L F
.922 .939 .796 r
.565 .49452 m .56713 .49397 L .56716 .49132 L F
.295 0 .049 r
.49193 .57658 m .48898 .5757 L .49111 .57638 L F
0 .166 .695 r
.49111 .57638 m .49238 .5768 L .49193 .57658 L F
.682 .22 .148 r
.49381 .57734 m .49315 .57815 L .49111 .57638 L F
.49432 .57752 m .49315 .57815 L .49381 .57734 L F
.999 .813 .47 r
.49315 .57815 m .49208 .57961 L .4921 .57944 L F
0 .166 .695 r
.49111 .57638 m .49231 .57743 L .49238 .5768 L F
.515 .357 .605 r
.49207 .5795 m .4946 .57879 L .49506 .5804 L F
.767 .561 .619 r
.49238 .5768 m .49212 .57926 L .48837 .57871 L F
.49212 .57926 m .49208 .57961 L .49208 .57934 L F
.153 0 0 r
.4946 .57879 m .49208 .57961 L .49315 .57815 L F
.515 .357 .605 r
.49208 .57934 m .49208 .57961 L .4946 .57879 L F
.49176 .57941 m .49208 .57961 L .49208 .57934 L F
.58 .895 .987 r
.49125 .58302 m .49026 .58463 L .48883 .58373 L F
.49125 .58302 m .4931 .58374 L .49026 .58463 L F
.231 .713 .932 r
.49506 .5836 m .4931 .58374 L .49125 .58302 L F
.27 .264 .669 r
.48781 .58771 m .48883 .58373 L .49026 .58463 L F
.612 .429 .609 r
.49026 .58463 m .49054 .58769 L .48781 .58771 L F
.487 .336 .602 r
.49275 .58693 m .49026 .58463 L .4931 .58374 L F
.49275 .58693 m .49054 .58769 L .49026 .58463 L F
.571 .478 .71 r
.48962 .58729 m .49125 .58302 L .48883 .58373 L F
.323 .136 .464 r
.49482 .58607 m .4931 .58374 L .49506 .5836 L F
.49482 .58607 m .49275 .58693 L .4931 .58374 L F
.661 .543 .71 r
.49125 .58302 m .49482 .58607 L .49506 .5836 L F
.396 0 0 r
.49054 .58769 m .48933 .5886 L .48781 .58771 L F
0 0 0 r
.49275 .58693 m .48933 .5886 L .49054 .58769 L F
.732 .521 .607 r
.48962 .58729 m .48933 .5886 L .49275 .58693 L F
.48962 .58729 m .49275 .58693 L .4918 .58728 L F
.571 .478 .71 r
.48962 .58729 m .4918 .58728 L .49125 .58302 L F
.661 .543 .71 r
.49125 .58302 m .4918 .58728 L .49482 .58607 L F
.458 .136 .331 r
.49506 .5804 m .49104 .58347 L .49168 .57983 L F
.49201 .57949 m .49168 .57983 L .49176 .57941 L F
.767 .561 .619 r
.49201 .57949 m .49208 .57961 L .49197 .57958 L F
.49208 .57941 m .49208 .57961 L .49201 .57949 L F
.458 .136 .331 r
.49506 .5804 m .49168 .57983 L .49201 .57949 L F
.767 .561 .619 r
.49208 .57934 m .49208 .57941 L .49201 .57949 L F
.515 .357 .605 r
.49176 .57941 m .49208 .57934 L .49201 .57949 L F
.626 .101 0 r
.48837 .57871 m .49176 .57941 L .48983 .58217 L F
.534 .212 .368 r
.49176 .57941 m .49105 .58037 L .48983 .58217 L F
.582 .552 .786 r
.48788 .5809 m .48983 .58217 L .48747 .58275 L F
.48837 .57871 m .48928 .58088 L .48788 .5809 L F
.48928 .58088 m .48983 .58217 L .48788 .5809 L F
.24 0 0 r
.48747 .58275 m .48983 .58217 L .48848 .58382 L F
.534 .212 .368 r
.49105 .58037 m .48848 .58382 L .48909 .58308 L F
.49105 .58037 m .48909 .58308 L .48983 .58217 L F
.49069 .58086 m .49104 .58347 L .48848 .58382 L F
.49176 .57941 m .49151 .58084 L .49069 .58086 L F
.49151 .58084 m .49104 .58347 L .49069 .58086 L F
.767 .561 .619 r
.49212 .57926 m .49197 .57958 L .49167 .57951 L F
.626 .101 0 r
.48837 .57871 m .49208 .57961 L .49176 .57941 L F
.767 .561 .619 r
.49187 .57923 m .49167 .57951 L .48837 .57871 L F
.49212 .57926 m .49167 .57951 L .49187 .57923 L F
.515 .357 .605 r
.49201 .57949 m .4921 .57934 L .49207 .5795 L F
.49208 .57934 m .4921 .57934 L .49201 .57949 L F
.4921 .57934 m .4946 .57879 L .49207 .5795 L F
.999 .813 .47 r
.49315 .57815 m .4921 .57944 L .49212 .57926 L F
.49257 .57713 m .49212 .57926 L .49238 .5768 L F
.49315 .57815 m .49212 .57926 L .49257 .57713 L F
.295 0 .049 r
.49193 .57658 m .48754 .5778 L .48898 .5757 L F
.764 .448 .451 r
.56452 .51633 m .56417 .51425 L .56115 .51362 L F
.909 .826 .752 r
.65965 .42723 m .66112 .42866 L .66007 .43054 L F
.101 0 0 r
.40587 .62324 m .40283 .6251 L .4038 .624 L F
.133 .362 .821 r
.25555 .54697 m .25511 .54864 L .2526 .54652 L F
.25555 .54697 m .25633 .54883 L .25511 .54864 L F
.65 .546 .724 r
.36926 .62099 m .36947 .62318 L .37172 .62054 L F
.644 .743 .921 r
.70754 .4062 m .71111 .40718 L .70998 .40554 L F
.623 .761 .945 r
.71111 .40718 m .71248 .40476 L .70998 .40554 L F
.71111 .40718 m .71366 .40638 L .71248 .40476 L F
.558 .344 .545 r
.50982 .68847 m .51248 .68824 L .51039 .68611 L F
.50982 .68847 m .51248 .68824 L .51039 .68611 L F
.661 .457 .598 r
.55856 .51405 m .55613 .51694 L .55862 .51652 L F
.623 .43 .6 r
.55862 .51652 m .56115 .51362 L .55856 .51405 L F
0 0 .4 r
.19548 .68882 m .19557 .68894 L .19381 .68573 L F
.677 .529 .677 r
.19274 .69156 m .19557 .68894 L .19548 .68882 L F
.482 .255 .493 r
.25323 .59951 m .25296 .60227 L .25067 .60269 L F
.425 .244 .529 r
.25555 .59649 m .2555 .59921 L .25323 .59951 L F
.41 .196 .474 r
.2551 .60158 m .25323 .59951 L .2555 .59921 L F
.2551 .60158 m .25296 .60227 L .25323 .59951 L F
.493 .271 .506 r
.63728 .43665 m .63984 .43623 L .63953 .43379 L F
.014 0 .141 r
.63953 .43379 m .64156 .43261 L .64182 .43068 L F
.903 .613 .113 r
.64247 .43837 m .64278 .43726 L .64195 .43636 L F
.64247 .43837 m .64296 .43846 L .64278 .43726 L F
.595 .821 .986 r
.64278 .43726 m .6449 .43519 L .64195 .43636 L F
.64278 .43726 m .64651 .43636 L .6449 .43519 L F
.504 .906 .91 r
.74162 .39745 m .7401 .39856 L .73948 .39832 L F
.484 .896 .794 r
.73882 .3987 m .7401 .39856 L .74162 .39745 L F
.145 .246 .711 r
.39737 .61753 m .39842 .62074 L .3961 .61764 L F
.39842 .62074 m .39846 .62087 L .39838 .62075 L F
.39842 .62074 m .39838 .62075 L .3961 .61764 L F
.664 .949 .706 r
.39846 .62087 m .39841 .62088 L .40043 .61943 L F
.952 .638 .212 r
.39737 .61753 m .39824 .62092 L .39846 .62087 L F
.664 .949 .706 r
.39841 .62088 m .39824 .62092 L .39856 .62071 L F
.39841 .62088 m .39856 .62071 L .40043 .61943 L F
.469 .392 .687 r
.39971 .61935 m .39737 .61753 L .39928 .61807 L F
.39997 .62013 m .39947 .61963 L .39971 .61935 L F
.39947 .61963 m .39737 .61753 L .39971 .61935 L F
0 0 0 r
.40043 .61943 m .39859 .62068 L .39997 .62013 L F
.39859 .62068 m .39824 .62092 L .39918 .62049 L F
.39859 .62068 m .39918 .62049 L .39997 .62013 L F
.40043 .61943 m .39997 .62013 L .40191 .62035 L F
.597 .873 .547 r
.60129 .4866 m .59982 .48826 L .59873 .4893 L F
.4 0 0 r
.23508 .5586 m .23322 .55786 L .23164 .55703 L F
.462 .081 .231 r
.38931 .58977 m .39208 .5888 L .38968 .58887 L F
.122 .652 .87 r
.19423 .54076 m .19521 .54065 L .19729 .54117 L F
.024 0 0 r
.19347 .54086 m .19639 .54052 L .19521 .54065 L F
.219 .727 .893 r
.19521 .54065 m .19744 .54039 L .1995 .54084 L F
.024 0 0 r
.19639 .54052 m .19744 .54039 L .19521 .54065 L F
.122 .652 .87 r
.19331 .54063 m .19521 .54065 L .19423 .54076 L F
.219 .727 .893 r
.19521 .54065 m .1995 .54084 L .19729 .54117 L F
.715 .597 .723 r
.39867 .61748 m .39634 .61565 L .39826 .61447 L F
.39867 .61748 m .3961 .61764 L .39634 .61565 L F
.145 .246 .711 r
.39737 .61753 m .3961 .61764 L .39867 .61748 L F
0 0 0 r
.40082 .61271 m .39867 .61748 L .39826 .61447 L F
.40082 .61271 m .39931 .61634 L .39867 .61748 L F
.437 .231 .501 r
.39931 .61634 m .39737 .61753 L .39867 .61748 L F
.458 .276 .545 r
.57389 .51384 m .57622 .5133 L .57618 .51089 L F
.588 .385 .573 r
.57347 .51604 m .57622 .5133 L .57389 .51384 L F
.895 .58 .444 r
.25794 .82569 m .25935 .82518 L .25747 .82694 L F
.203 .73 .823 r
.25864 .82544 m .25935 .82518 L .25794 .82569 L F
.34 .793 .95 r
.25935 .82518 m .25898 .82437 L .25827 .82558 L F
.25935 .82518 m .25864 .82544 L .25747 .82694 L F
.259 0 .192 r
.26055 .82476 m .25864 .82544 L .25747 .82694 L F
.25864 .82544 m .25794 .82569 L .25747 .82694 L F
.34 .793 .95 r
.25864 .82544 m .25827 .82558 L .25747 .82694 L F
.25935 .82518 m .2617 .82484 L .25898 .82437 L F
.203 .73 .823 r
.26055 .82476 m .2617 .82484 L .25935 .82518 L F
.26055 .82476 m .25935 .82518 L .25864 .82544 L F
0 0 0 r
.46429 .59557 m .46228 .59683 L .46524 .59447 L F
.629 .804 .966 r
.46722 .59345 m .46524 .59447 L .46382 .5928 L F
.36 .325 .684 r
.46382 .5928 m .46524 .59447 L .46722 .59345 L F
.46382 .5928 m .46429 .59557 L .46524 .59447 L F
.675 .299 0 r
.65869 .41819 m .66028 .42142 L .65991 .4206 L F
.928 .801 .335 r
.66028 .42142 m .65956 .42238 L .65991 .4206 L F
.66028 .42142 m .65984 .42474 L .65956 .42238 L F
.772 .699 .782 r
.66502 .45139 m .66833 .44932 L .66708 .4487 L F
.322 .43 .816 r
.6696 .44754 m .66833 .44932 L .66645 .44582 L F
.662 .909 .979 r
.66833 .44932 m .66708 .4487 L .6696 .44754 L F
.365 .513 .873 r
.51385 .5655 m .51521 .56348 L .51301 .56443 L F
.51385 .5655 m .51681 .56653 L .51521 .56348 L F
.64 .804 .962 r
.70513 .39602 m .70243 .39732 L .70141 .3955 L F
.457 .229 .48 r
.58133 .50516 m .57885 .50804 L .58129 .50751 L F
.312 .134 .471 r
.58337 .50173 m .58133 .50516 L .58375 .50459 L F
.557 .363 .573 r
.58129 .50751 m .58375 .50459 L .58133 .50516 L F
.75 .577 .66 r
.76234 .4283 m .76243 .4309 L .75869 .43059 L F
.582 .366 .554 r
.76515 .42808 m .76243 .4309 L .76234 .4283 L F
.775 .694 .773 r
.6659 .4337 m .66831 .4346 L .66741 .43071 L F
.898 .768 .71 r
.66503 .43602 m .66831 .4346 L .6659 .4337 L F
.66503 .43602 m .6673 .43672 L .66831 .4346 L F
.798 .707 .764 r
.66741 .43071 m .66831 .4346 L .66985 .43143 L F
0 0 0 r
.61897 .4859 m .61758 .48742 L .61978 .48428 L F
.573 .893 .629 r
.61618 .48841 m .61758 .48742 L .61897 .4859 L F
.69 .764 .908 r
.60761 .4563 m .61108 .45777 L .61005 .45613 L F
.79 .321 .121 r
.61108 .45777 m .60997 .45899 L .60761 .4563 L F
.676 .758 .913 r
.6139 .45664 m .61108 .45777 L .61005 .45613 L F
.207 0 0 r
.61253 .45813 m .61108 .45777 L .6139 .45664 L F
.61253 .45813 m .60997 .45899 L .61108 .45777 L F
.372 .153 .446 r
.24644 .61153 m .24602 .61443 L .24405 .61474 L F
.475 .316 .585 r
.24602 .61443 m .24395 .61719 L .24405 .61474 L F
.803 .7 .751 r
.6839 .45174 m .68011 .45319 L .6827 .45052 L F
.6839 .45174 m .68154 .4547 L .68011 .45319 L F
.599 .817 .983 r
.6851 .44983 m .6839 .45174 L .6827 .45052 L F
.457 .166 .383 r
.68709 .44983 m .68632 .45157 L .6839 .45174 L F
.481 .663 .942 r
.6851 .44983 m .68632 .45157 L .6839 .45174 L F
.621 .214 .252 r
.43887 .64462 m .4378 .64653 L .4351 .64618 L F
.453 .04 .164 r
.44121 .64574 m .4378 .64653 L .43887 .64462 L F
.849 .655 .639 r
.21686 .59593 m .22041 .59367 L .21894 .59276 L F
.21686 .59593 m .21914 .59658 L .22041 .59367 L F
.901 .889 .81 r
.22139 .58936 m .21894 .59276 L .22041 .59367 L F
.442 .353 .66 r
.257 .59336 m .25555 .59649 L .2552 .59395 L F
.515 .227 .414 r
.58585 .50099 m .58864 .49866 L .5862 .49926 L F
.532 .356 .587 r
.59007 .51941 m .58778 .52254 L .58764 .51997 L F
.59007 .51941 m .58778 .52254 L .58764 .51997 L F
.505 .307 .545 r
.43271 .63208 m .43231 .63494 L .43042 .63316 L F
0 .035 .529 r
.43042 .63316 m .43122 .63387 L .43271 .63208 L F
.43042 .63316 m .43231 .63494 L .43122 .63387 L F
.89 .985 .804 r
.67057 .42154 m .67356 .41917 L .67272 .41825 L F
.879 .869 .824 r
.67356 .41917 m .67468 .41544 L .67272 .41825 L F
.909 .968 .658 r
.60733 .47683 m .60726 .47865 L .60593 .48075 L F
.578 .823 .991 r
.69885 .39661 m .69658 .39726 L .69519 .39594 L F
.251 .288 .706 r
.3702 .6147 m .37084 .61819 L .37238 .61667 L F
.578 .457 .679 r
.37084 .61819 m .37411 .62003 L .37238 .61667 L F
.37084 .61819 m .37172 .62054 L .37411 .62003 L F
.523 .221 .396 r
.3725 .59656 m .37495 .59625 L .37538 .59431 L F
.337 .058 .334 r
.37538 .59431 m .377 .59552 L .3775 .59379 L F
.37538 .59431 m .37495 .59625 L .377 .59552 L F
.701 .419 .494 r
.53865 .58106 m .53843 .5784 L .537 .5783 L F
.53865 .58106 m .54005 .57832 L .53843 .5784 L F
.492 .245 .467 r
.57618 .51089 m .57875 .51032 L .57885 .50804 L F
.503 .279 .507 r
.58122 .50979 m .57885 .50804 L .57875 .51032 L F
.58122 .50979 m .58129 .50751 L .57885 .50804 L F
.708 .573 .701 r
.56713 .62623 m .56868 .63 L .57121 .62655 L F
.712 .579 .704 r
.56868 .63 m .57081 .62893 L .57121 .62655 L F
.488 .531 .828 r
.61453 .42162 m .61419 .42538 L .6132 .42524 L F
.477 .237 .471 r
.61538 .42602 m .61307 .42732 L .6132 .42524 L F
.709 .765 .896 r
.68905 .46261 m .69221 .46294 L .69083 .46179 L F
.683 .827 .952 r
.69083 .46179 m .69221 .46294 L .69409 .46173 L F
.702 .57 .703 r
.56468 .62921 m .56868 .63 L .56713 .62623 L F
.895 .942 .833 r
.61267 .46162 m .61518 .461 L .6129 .46392 L F
.921 .95 .795 r
.61267 .46162 m .6129 .46392 L .61137 .46576 L F
0 0 0 r
.22292 .64438 m .2215 .64659 L .21998 .64698 L F
.082 0 .206 r
.22462 .64296 m .22292 .64438 L .22516 .64127 L F
.244 0 .078 r
.22362 .64591 m .22292 .64438 L .22462 .64296 L F
.22362 .64591 m .2215 .64659 L .22292 .64438 L F
.697 .819 .94 r
.74988 .41794 m .74767 .41924 L .74658 .4179 L F
.107 .525 .911 r
.74767 .41924 m .74965 .41896 L .74658 .4179 L F
.74767 .41924 m .75127 .42038 L .74965 .41896 L F
.549 .266 .438 r
.46385 .59838 m .46335 .60047 L .46111 .59867 L F
.138 .279 .747 r
.46111 .59867 m .46335 .60047 L .46318 .59998 L F
.544 .108 .164 r
.46228 .59683 m .46111 .59867 L .45991 .5979 L F
.572 .336 .52 r
.46429 .59557 m .46111 .59867 L .46228 .59683 L F
.46429 .59557 m .46385 .59838 L .46111 .59867 L F
.138 .279 .747 r
.46111 .59867 m .46318 .59998 L .46212 .59677 L F
.544 .108 .164 r
.45991 .5979 m .46111 .59867 L .45855 .59851 L F
.406 .56 .895 r
.49633 .57448 m .49499 .57623 L .49366 .57472 L F
.49633 .57448 m .49665 .57621 L .49499 .57623 L F
.364 0 .174 r
.49665 .57621 m .49432 .57752 L .49499 .57623 L F
.582 .366 .554 r
.76515 .42808 m .76542 .4304 L .76243 .4309 L F
.197 .097 .508 r
.76688 .42892 m .76515 .42808 L .76751 .4273 L F
.76688 .42892 m .76542 .4304 L .76515 .42808 L F
.451 .182 .414 r
.2046 .63244 m .20682 .63199 L .20749 .62969 L F
.394 .129 .39 r
.20749 .62969 m .20887 .63138 L .20931 .62893 L F
.20749 .62969 m .20682 .63199 L .20887 .63138 L F
.35 0 .151 r
.39775 .58458 m .39998 .5841 L .40092 .58266 L F
.197 0 .059 r
.40092 .58266 m .39998 .5841 L .40295 .58192 L F
.804 .998 .852 r
.72809 .44516 m .7258 .4484 L .72888 .44597 L F
.72809 .44516 m .72537 .44774 L .7258 .4484 L F
.364 .249 .586 r
.21513 .60881 m .21717 .60796 L .21707 .60554 L F
.285 .078 .413 r
.21513 .60881 m .21647 .6101 L .21717 .60796 L F
.133 .077 .522 r
.21513 .60881 m .21533 .61153 L .21647 .6101 L F
.523 .291 .506 r
.5826 .52467 m .58472 .52763 L .58255 .52829 L F
.5826 .52467 m .5854 .52414 L .58472 .52763 L F
.586 .213 .301 r
.1911 .55532 m .18968 .55758 L .18763 .55609 L F
.708 .354 .375 r
.19336 .55762 m .1911 .55532 L .19322 .55515 L F
.19336 .55762 m .18968 .55758 L .1911 .55532 L F
.892 .933 .836 r
.52534 .51939 m .52663 .51564 L .52816 .51685 L F
.52534 .51939 m .52429 .51857 L .52663 .51564 L F
.667 .301 .342 r
.45114 .60216 m .45023 .60456 L .44774 .60262 L F
0 0 .032 r
.45262 .60159 m .45023 .60456 L .45114 .60216 L F
.283 .773 .706 r
.19353 .64115 m .19156 .6419 L .18933 .64262 L F
.768 .786 .868 r
.68293 .46342 m .68639 .46366 L .6843 .46277 L F
.686 .767 .913 r
.68639 .46366 m .68824 .46032 L .6843 .46277 L F
.68639 .46366 m .68905 .46261 L .68824 .46032 L F
.855 .546 .018 r
.64232 .40534 m .64281 .40695 L .64224 .40585 L F
.97 .763 .331 r
.64281 .40695 m .64262 .40813 L .64224 .40585 L F
.696 .612 .758 r
.64535 .40453 m .64281 .40695 L .64179 .40361 L F
.099 0 .438 r
.64262 .40813 m .64445 .40544 L .64224 .40585 L F
.739 .436 .469 r
.64445 .40544 m .64211 .40669 L .64224 .40585 L F
.64211 .40669 m .64093 .40732 L .64224 .40585 L F
.855 .546 .018 r
.64179 .40361 m .64232 .40534 L .64224 .40585 L F
0 0 0 r
.21998 .64698 m .2188 .64908 L .21712 .64992 L F
.085 0 0 r
.22064 .64821 m .21998 .64698 L .2215 .64659 L F
.22064 .64821 m .2188 .64908 L .21998 .64698 L F
.312 .778 .939 r
.42724 .59078 m .42597 .59036 L .42331 .59071 L F
.319 0 .051 r
.42944 .59092 m .42597 .59036 L .42724 .59078 L F
.521 .689 .944 r
.38378 .6334 m .38495 .63142 L .38269 .63179 L F
.38378 .6334 m .38563 .63293 L .38495 .63142 L F
0 0 .121 r
.5497 .48986 m .55112 .48624 L .55003 .48732 L F
.705 .747 .885 r
.69476 .44862 m .69572 .45151 L .69232 .45074 L F
.782 .789 .858 r
.69838 .449 m .69572 .45151 L .69476 .44862 L F
.511 .265 .479 r
.56352 .53994 m .56367 .53775 L .56599 .53946 L F
.539 .254 .431 r
.56367 .53775 m .56617 .5375 L .56599 .53946 L F
.836 .523 .459 r
.68154 .4547 m .68516 .45772 L .68418 .45647 L F
0 0 0 r
.68516 .45772 m .68365 .46106 L .68456 .45912 L F
.975 .692 .297 r
.68418 .45647 m .68516 .45772 L .68456 .45912 L F
0 0 0 r
.57717 .45782 m .57864 .45664 L .57964 .45478 L F
.57717 .45782 m .57781 .45794 L .57864 .45664 L F
.57717 .45782 m .57601 .45912 L .57781 .45794 L F
0 .155 .679 r
.21385 .59024 m .21509 .59391 L .21562 .59241 L F
0 .147 .673 r
.21509 .59391 m .21686 .59593 L .21562 .59241 L F
.247 .224 .634 r
.21559 .59642 m .21686 .59593 L .21509 .59391 L F
.491 .326 .584 r
.61217 .44884 m .61236 .45145 L .61465 .4506 L F
.61465 .4506 m .61236 .45145 L .61217 .44884 L F
.399 .596 .925 r
.7584 .39924 m .7568 .40088 L .75409 .39808 L F
.7584 .39924 m .75839 .40068 L .7568 .40088 L F
.49 .826 .535 r
.54412 .49504 m .54531 .49397 L .54403 .49514 L F
0 0 0 r
.54412 .49504 m .547 .49256 L .54531 .49397 L F
.537 .026 0 r
.17266 .54481 m .17483 .54545 L .17319 .54433 L F
.442 .12 .324 r
.17319 .54433 m .17483 .54545 L .17589 .54355 L F
.369 .773 .984 r
.42257 .59994 m .41798 .59937 L .42008 .60065 L F
.419 .193 .462 r
.24813 .61362 m .24644 .61153 L .24835 .61077 L F
.24813 .61362 m .24602 .61443 L .24644 .61153 L F
.916 .861 .771 r
.63728 .43665 m .63554 .44042 L .63417 .43932 L F
.747 .499 .556 r
.41092 .6445 m .40715 .64446 L .40952 .64432 L F
.641 .195 .175 r
.41092 .6445 m .40744 .64551 L .40715 .64446 L F
.41092 .6445 m .40939 .64618 L .40744 .64551 L F
.579 .122 .131 r
.41334 .64608 m .40939 .64618 L .41092 .6445 L F
.466 .499 .809 r
.47706 .56993 m .47585 .57241 L .47418 .56958 L F
.47706 .56993 m .47792 .5723 L .47585 .57241 L F
.59 .283 .416 r
.43294 .64406 m .43196 .64698 L .4291 .64686 L F
.61 .303 .424 r
.4351 .64618 m .43196 .64698 L .43294 .64406 L F
.989 .762 .502 r
.52641 .58783 m .5251 .58724 L .52519 .58469 L F
.773 .418 .384 r
.52641 .58783 m .52417 .58969 L .5251 .58724 L F
.52641 .58783 m .52765 .59034 L .52417 .58969 L F
.95 .761 .612 r
.50655 .54635 m .50422 .54852 L .5049 .54545 L F
.50655 .54635 m .50552 .54972 L .50422 .54852 L F
.901 .971 .813 r
.61978 .48428 m .62133 .4805 L .61959 .48338 L F
.61978 .48428 m .62213 .4812 L .62133 .4805 L F
.899 .834 .371 r
.61897 .4859 m .61978 .48428 L .61959 .48338 L F
0 0 0 r
.21449 .61784 m .21398 .61641 L .21235 .6168 L F
.21449 .61784 m .2132 .62002 L .21482 .61874 L F
.258 .257 .667 r
.23115 .58188 m .23144 .58563 L .23302 .58405 L F
.964 .94 .658 r
.62213 .4812 m .62328 .47623 L .62133 .4805 L F
0 0 0 r
.61012 .41304 m .60926 .41658 L .60976 .41507 L F
.60926 .41658 m .6093 .41671 L .60976 .41507 L F
.60926 .41658 m .6083 .41871 L .6093 .41671 L F
.717 .972 .735 r
.58403 .47046 m .58298 .4723 L .58581 .46955 L F
.655 .856 .465 r
.58403 .47046 m .58195 .47357 L .58298 .4723 L F
.563 .33 .521 r
.64179 .40361 m .64224 .40585 L .63948 .40439 L F
.64179 .40361 m .64224 .40585 L .63948 .40439 L F
.853 .976 .672 r
.64379 .42682 m .64182 .43068 L .64374 .43065 L F
.055 0 .152 r
.64182 .43068 m .64329 .43086 L .64374 .43065 L F
.64182 .43068 m .64156 .43261 L .64329 .43086 L F
0 .051 .607 r
.40129 .62903 m .40286 .6311 L .40231 .63247 L F
.072 .332 .81 r
.40286 .6311 m .40473 .63409 L .40231 .63247 L F
.233 .285 .711 r
.46222 .56984 m .46305 .57419 L .46446 .57181 L F
0 0 .367 r
.46374 .5749 m .46446 .57181 L .46305 .57419 L F
.905 .935 .821 r
.61738 .45801 m .61518 .461 L .61531 .45788 L F
.902 .934 .824 r
.61531 .45788 m .61518 .461 L .61267 .46162 L F
.351 .825 .877 r
.18879 .68042 m .19304 .67975 L .1906 .68045 L F
.968 .935 .654 r
.48564 .57879 m .48406 .58097 L .48499 .58226 L F
.731 .228 0 r
.48512 .58328 m .48499 .58226 L .48406 .58097 L F
.48512 .58328 m .48648 .58426 L .48499 .58226 L F
0 .252 .762 r
.4622 .58711 m .45994 .58524 L .46189 .58451 L F
.718 .566 .683 r
.45875 .58695 m .46189 .58451 L .45994 .58524 L F
.288 .777 .904 r
.1995 .54084 m .20145 .54053 L .20327 .54073 L F
.057 .622 .764 r
.20145 .54053 m .20554 .54058 L .20327 .54073 L F
.48 0 0 r
.20586 .55246 m .20458 .55346 L .20206 .55237 L F
0 .157 .617 r
.20647 .55497 m .20458 .55346 L .20586 .55246 L F
.753 .451 .473 r
.20909 .55476 m .20647 .55497 L .20586 .55246 L F
0 0 0 r
.58195 .45179 m .57964 .45478 L .58072 .45353 L F
.122 0 0 r
.57964 .45478 m .58086 .45561 L .58072 .45353 L F
.57964 .45478 m .57864 .45664 L .58086 .45561 L F
.461 .207 .442 r
.25921 .59281 m .25747 .59106 L .25968 .59046 L F
.25921 .59281 m .257 .59336 L .25747 .59106 L F
.722 .967 .936 r
.61908 .45655 m .61738 .45801 L .61531 .45788 L F
.866 .849 .824 r
.51649 .53232 m .51263 .53404 L .51261 .5313 L F
.51649 .53232 m .51415 .53521 L .51263 .53404 L F
0 0 .167 r
.65239 .4268 m .65218 .42552 L .65206 .4238 L F
.603 .305 .435 r
.22028 .55223 m .21769 .55455 L .2183 .55301 L F
.353 .149 .459 r
.26182 .58734 m .25968 .59046 L .25999 .58806 L F
.422 .44 .773 r
.40911 .59128 m .41181 .59404 L .41111 .5927 L F
.41111 .5927 m .41181 .59404 L .40911 .59128 L F
.556 .327 .523 r
.54293 .52688 m .54233 .52302 L .54115 .52261 L F
.54115 .52261 m .54233 .52302 L .54293 .52688 L F
.803 .675 .723 r
.42829 .58462 m .42584 .58754 L .42961 .58802 L F
.227 .718 .922 r
.42584 .58754 m .42878 .5876 L .42897 .58794 L F
.256 0 0 r
.42683 .5882 m .42878 .5876 L .42584 .58754 L F
.65 .343 .438 r
.42683 .5882 m .42853 .58716 L .42878 .5876 L F
.1 .255 .737 r
.42829 .58462 m .42961 .58802 L .4305 .58596 L F
.65 .343 .438 r
.42853 .58716 m .4305 .58596 L .42878 .5876 L F
.227 .718 .922 r
.42897 .58794 m .42878 .5876 L .42961 .58802 L F
.727 .972 .929 r
.42961 .58802 m .42878 .5876 L .4305 .58596 L F
.741 .525 .601 r
.43632 .6351 m .43988 .63787 L .44011 .63545 L F
.801 .868 .897 r
.51415 .53521 m .50994 .53649 L .51263 .53404 L F
.34 .819 .797 r
.20927 .53958 m .20968 .53917 L .21147 .53946 L F
.20927 .53958 m .20765 .53989 L .20968 .53917 L F
.169 0 .2 r
.22775 .63845 m .2265 .6407 L .22516 .64127 L F
.332 .047 .322 r
.2261 .64237 m .22516 .64127 L .2265 .6407 L F
.2261 .64237 m .22462 .64296 L .22516 .64127 L F
.641 .826 .972 r
.19937 .55766 m .20113 .55882 L .20327 .55795 L F
.19937 .55766 m .20113 .55882 L .20327 .55795 L F
.638 .324 .422 r
.46359 .58202 m .46491 .58403 L .46311 .58237 L F
.695 .944 .96 r
.71907 .44316 m .71485 .44425 L .71797 .4421 L F
.883 .992 .77 r
.72144 .43996 m .71907 .44316 L .71977 .44064 L F
.779 .91 .93 r
.71977 .44064 m .71907 .44316 L .71797 .4421 L F
.259 0 0 r
.22721 .5412 m .22932 .54169 L .23118 .54164 L F
.281 0 0 r
.22932 .54169 m .23346 .54121 L .23118 .54164 L F
.571 .559 .802 r
.55153 .56946 m .54974 .57296 L .54885 .57062 L F
.55153 .56946 m .55223 .57226 L .54974 .57296 L F
.492 .337 .599 r
.55223 .57226 m .54976 .57519 L .54974 .57296 L F
.533 .533 .801 r
.53761 .59298 m .53993 .59262 L .53988 .59248 L F
.403 .113 .354 r
.53866 .59008 m .53761 .59298 L .53537 .59347 L F
.533 .533 .801 r
.53761 .59298 m .53988 .59248 L .53877 .58892 L F
.403 .113 .354 r
.53537 .59347 m .53761 .59298 L .53521 .59362 L F
.642 .809 .963 r
.69149 .40594 m .6953 .40638 L .69431 .40487 L F
.607 .779 .963 r
.69431 .40487 m .6953 .40638 L .69761 .40557 L F
.21 0 .27 r
.55376 .54947 m .55333 .55153 L .55117 .55256 L F
.51 .408 .674 r
.55333 .55153 m .55151 .55515 L .55117 .55256 L F
.712 .605 .735 r
.42717 .57644 m .43139 .57964 L .42953 .57598 L F
.223 .174 .589 r
.43139 .57964 m .43239 .57546 L .42953 .57598 L F
.43139 .57964 m .43191 .57935 L .43239 .57546 L F
.096 0 .341 r
.43139 .57964 m .43092 .58186 L .43191 .57935 L F
.43139 .57964 m .43092 .58186 L .43191 .57935 L F
.41 .146 .399 r
.40729 .60002 m .40672 .60174 L .40413 .60235 L F
.58 .524 .756 r
.40672 .60174 m .4055 .60561 L .40413 .60235 L F
.981 .913 .627 r
.65033 .4348 m .65074 .43695 L .65185 .43385 L F
.984 .906 .619 r
.65185 .43385 m .65204 .43047 L .65162 .43308 L F
.87 .983 .697 r
.65033 .4348 m .65185 .43385 L .65162 .43308 L F
.158 0 .282 r
.22917 .63736 m .22775 .63845 L .22994 .63531 L F
.572 .381 .584 r
.22917 .63736 m .2265 .6407 L .22775 .63845 L F
.275 .067 .405 r
.59305 .46052 m .59275 .4627 L .5909 .46378 L F
.17 0 .232 r
.59275 .4627 m .5903 .46556 L .5909 .46378 L F
.779 .705 .166 r
.21505 .57906 m .21501 .57781 L .21549 .57452 L F
.087 .255 .74 r
.21534 .58127 m .21501 .57781 L .21505 .57906 L F
.916 .861 .771 r
.63728 .43665 m .63417 .43932 L .63772 .43951 L F
.454 .096 .266 r
.63764 .43895 m .63984 .43623 L .63728 .43665 L F
.63818 .4388 m .63984 .43623 L .63764 .43895 L F
.63772 .43951 m .63934 .43862 L .63984 .43623 L F
.659 .598 .775 r
.63984 .43623 m .64195 .43636 L .64156 .43261 L F
.915 .541 .111 r
.64133 .43715 m .63984 .43623 L .63934 .43862 L F
.64133 .43715 m .64195 .43636 L .63984 .43623 L F
.595 .522 .743 r
.64133 .43715 m .63957 .43845 L .63821 .43459 L F
.63957 .43845 m .63934 .43862 L .63931 .43851 L F
.63957 .43845 m .63931 .43851 L .63821 .43459 L F
.454 .096 .266 r
.63772 .43951 m .63818 .4388 L .63764 .43895 L F
0 .137 .682 r
.52054 .57878 m .52222 .57986 L .52001 .57689 L F
.52054 .57878 m .52283 .58133 L .52222 .57986 L F
.46 .511 .824 r
.38067 .63184 m .38129 .62837 L .37911 .6296 L F
.38067 .63184 m .38269 .63179 L .38129 .62837 L F
.663 .962 .763 r
.53103 .50948 m .53416 .50689 L .53432 .50727 L F
.6 .08 0 r
.40823 .63517 m .41047 .63663 L .41202 .6356 L F
.657 .151 .031 r
.41047 .63663 m .41423 .63737 L .41202 .6356 L F
.504 .274 .498 r
.41202 .6356 m .41423 .63737 L .41451 .63497 L F
.984 .852 .629 r
.66007 .43054 m .65809 .43264 L .65906 .42954 L F
.66007 .43054 m .65934 .4336 L .65809 .43264 L F
.909 .826 .752 r
.65965 .42723 m .66007 .43054 L .65906 .42954 L F
.456 .356 .652 r
.40264 .60702 m .4008 .61169 L .40004 .60865 L F
.40264 .60702 m .40234 .6127 L .4008 .61169 L F
.673 .322 .371 r
.40234 .6127 m .40082 .61271 L .4008 .61169 L F
.769 .842 .907 r
.66108 .45053 m .66502 .45139 L .66314 .44752 L F
.66108 .45053 m .66247 .45182 L .66502 .45139 L F
.7 .741 .883 r
.66314 .44752 m .66502 .45139 L .66708 .4487 L F
.371 .196 .51 r
.22993 .59375 m .23188 .59524 L .23158 .5927 L F
.22993 .59375 m .22989 .59618 L .23188 .59524 L F
.742 .931 .589 r
.63724 .42135 m .63752 .42161 L .63612 .42108 L F
0 .249 .708 r
.63992 .42378 m .63612 .42108 L .63752 .42161 L F
.691 .252 .201 r
.21835 .56729 m .21445 .56665 L .21577 .56844 L F
.732 .707 .827 r
.21475 .56904 m .21835 .56729 L .21577 .56844 L F
.815 .987 .881 r
.72378 .43788 m .72144 .43996 L .72214 .43772 L F
.844 .998 .783 r
.72214 .43772 m .72144 .43996 L .71977 .44064 L F
.69 .949 .679 r
.43215 .56821 m .43074 .56978 L .43151 .56944 L F
.484 .323 .586 r
.22488 .60199 m .22703 .59893 L .22504 .59978 L F
.445 0 0 r
.42644 .63476 m .42814 .63611 L .42864 .63544 L F
.915 .962 .642 r
.2146 .58697 m .21426 .58666 L .21598 .58503 L F
.849 .965 .637 r
.21598 .58503 m .21426 .58666 L .21621 .58326 L F
.449 .251 .519 r
.25296 .60227 m .25067 .60533 L .25067 .60269 L F
.385 .267 .595 r
.45719 .58807 m .45915 .58901 L .45875 .58695 L F
.45719 .58807 m .45753 .59075 L .45915 .58901 L F
.45915 .58901 m .45753 .59075 L .45719 .58807 L F
.417 .262 .562 r
.20969 .62637 m .21159 .62581 L .2116 .62325 L F
.318 .115 .44 r
.20969 .62637 m .21103 .62822 L .21159 .62581 L F
.20969 .62637 m .20931 .62893 L .21103 .62822 L F
.479 .629 .919 r
.65078 .40498 m .64933 .40712 L .64848 .40515 L F
.65078 .40498 m .65162 .40595 L .64933 .40712 L F
.474 .39 .68 r
.65162 .40595 m .6495 .40951 L .64933 .40712 L F
0 0 0 r
.40283 .6251 m .402 .62586 L .40089 .62652 L F
0 0 .195 r
.402 .62586 m .40129 .62903 L .40089 .62652 L F
0 .144 .679 r
.19609 .66744 m .19767 .67098 L .19815 .66961 L F
.195 .475 .891 r
.19767 .67098 m .199 .67079 L .19815 .66961 L F
.884 .918 .843 r
.56716 .49132 m .56949 .49089 L .56829 .48974 L F
.781 .783 .854 r
.54565 .51771 m .54736 .51239 L .54588 .51569 L F
.54565 .51771 m .5492 .51377 L .54736 .51239 L F
.241 0 0 r
.54504 .51793 m .54565 .51771 L .54588 .51569 L F
.54504 .51793 m .54873 .51842 L .54565 .51771 L F
.293 0 .074 r
.17315 .55828 m .1716 .56029 L .1696 .56073 L F
.632 .286 .367 r
.17546 .55834 m .1716 .56029 L .17315 .55828 L F
.204 .195 .626 r
.26569 .5729 m .26745 .57488 L .26582 .57582 L F
.329 .168 .505 r
.26794 .57744 m .26582 .57582 L .26745 .57488 L F
.26794 .57744 m .26601 .57861 L .26582 .57582 L F
.623 .318 .433 r
.57193 .53146 m .57442 .5337 L .5706 .53395 L F
.57193 .53146 m .57442 .53146 L .57442 .5337 L F
0 0 0 r
.58435 .44877 m .58195 .45179 L .58344 .45024 L F
.777 .988 .749 r
.58674 .46755 m .58581 .46955 L .58835 .46683 L F
.776 .985 .737 r
.58674 .46755 m .58403 .47046 L .58581 .46955 L F
.737 .378 .372 r
.44492 .64423 m .44266 .64736 L .44121 .64574 L F
0 0 0 r
.44526 .64548 m .44492 .64423 L .44734 .64396 L F
.578 .414 .623 r
.4455 .64759 m .44266 .64736 L .44526 .64548 L F
.4455 .64759 m .44326 .64819 L .44266 .64736 L F
0 0 0 r
.44526 .64548 m .44275 .6473 L .44492 .64423 L F
.44275 .6473 m .4427 .6473 L .44492 .64423 L F
.012 .159 .671 r
.44235 .64467 m .44326 .64819 L .4455 .64759 L F
.44302 .64725 m .44418 .64711 L .44326 .64819 L F
.44235 .64467 m .44415 .64707 L .44302 .64725 L F
.44415 .64707 m .44418 .64711 L .44302 .64725 L F
0 0 0 r
.44275 .6473 m .44266 .64736 L .4427 .6473 L F
.352 0 0 r
.52421 .53371 m .52848 .53177 L .52701 .53052 L F
.52421 .53371 m .52686 .53365 L .52848 .53177 L F
0 0 0 r
.52848 .53177 m .52686 .53365 L .52846 .5322 L F
.52848 .53177 m .52846 .5322 L .52701 .53052 L F
.432 .785 .997 r
.4543 .56461 m .45674 .56435 L .45847 .56523 L F
.434 .818 .989 r
.45674 .56435 m .46064 .56453 L .45847 .56523 L F
.23 .289 .717 r
.64651 .43636 m .64713 .44004 L .64878 .43823 L F
.552 .793 .988 r
.64713 .44004 m .65 .43941 L .64878 .43823 L F
0 0 .177 r
.49156 .57295 m .49209 .57245 L .49366 .57472 L F
.49156 .57295 m .49193 .57658 L .49209 .57245 L F
.711 .603 .735 r
.6735 .40781 m .67526 .41013 L .67409 .40871 L F
.6735 .40781 m .67771 .40767 L .67526 .41013 L F
.115 .28 .755 r
.67526 .41013 m .67669 .40904 L .67409 .40871 L F
.67526 .41013 m .67675 .41181 L .67669 .40904 L F
.454 .109 .29 r
.38337 .59317 m .38692 .59013 L .38391 .59134 L F
.38337 .59317 m .38578 .59281 L .38692 .59013 L F
.353 0 .192 r
.38578 .59281 m .38931 .58977 L .38692 .59013 L F
.556 .402 .627 r
.7385 .41946 m .73547 .42092 L .73759 .42008 L F
.473 .207 .429 r
.55602 .54885 m .55333 .55153 L .55376 .54947 L F
.587 .127 .128 r
.40952 .64432 m .40715 .64446 L .4049 .64409 L F
.447 .86 .701 r
.58989 .46571 m .58835 .46683 L .5903 .46556 L F
.58989 .46571 m .58674 .46755 L .58835 .46683 L F
.005 .05 .557 r
.68365 .46106 m .6843 .46277 L .68456 .45912 L F
.614 .373 .529 r
.68293 .46342 m .6843 .46277 L .68365 .46106 L F
.437 .257 .537 r
.24997 .608 m .24835 .61077 L .24866 .60856 L F
.641 .157 0 r
.52989 .59299 m .52765 .59034 L .52952 .59075 L F
.8 .418 .332 r
.53278 .59355 m .5316 .59543 L .52989 .59299 L F
.782 .51 .525 r
.53521 .59362 m .5316 .59543 L .53278 .59355 L F
.113 0 0 r
.68319 .39782 m .68437 .39773 L .68072 .39771 L F
0 0 0 r
.68525 .39773 m .68437 .39773 L .68319 .39782 L F
.68525 .39773 m .68678 .39744 L .68437 .39773 L F
.459 .365 .662 r
.55078 .56654 m .54885 .57062 L .54844 .56715 L F
.55078 .56654 m .55153 .56946 L .54885 .57062 L F
0 0 .39 r
.61195 .42861 m .61062 .42799 L .61307 .42732 L F
.61195 .42861 m .61072 .43043 L .61062 .42799 L F
.64 .328 .426 r
.44576 .64065 m .45027 .63797 L .44432 .63937 L F
.44576 .64065 m .44916 .64059 L .45027 .63797 L F
.551 .234 .384 r
.45027 .63797 m .45187 .64027 L .45178 .63869 L F
.45027 .63797 m .44916 .64059 L .45187 .64027 L F
.706 .83 .941 r
.4644 .56461 m .46064 .56453 L .4632 .56417 L F
.328 .725 .982 r
.46546 .56367 m .4644 .56461 L .4632 .56417 L F
.46546 .56367 m .46674 .56465 L .4644 .56461 L F
0 0 0 r
.19538 .67715 m .19753 .67663 L .19922 .67614 L F
.472 .892 .813 r
.19922 .67614 m .19944 .67563 L .20119 .6766 L F
.19922 .67614 m .19753 .67663 L .19944 .67563 L F
.238 .588 .947 r
.19922 .67614 m .20119 .6766 L .20083 .6766 L F
0 0 0 r
.5869 .44601 m .58435 .44877 L .58606 .44752 L F
.315 .068 .37 r
.58344 .45024 m .58606 .44752 L .58435 .44877 L F
.27 0 0 r
.67724 .39831 m .67821 .39809 L .67454 .398 L F
.468 0 0 r
.6812 .39888 m .68221 .39802 L .6801 .39793 L F
0 0 0 r
.6807 .39781 m .68072 .39771 L .67821 .39809 L F
.68061 .39782 m .67821 .39809 L .67724 .39831 L F
.6807 .39781 m .68064 .39781 L .68061 .39782 L F
.68064 .39781 m .67821 .39809 L .68061 .39782 L F
.225 .731 .894 r
.6807 .39781 m .67724 .39831 L .6761 .39782 L F
.468 0 0 r
.67921 .39811 m .6801 .39793 L .67856 .39786 L F
.6812 .39888 m .6801 .39793 L .67921 .39811 L F
.574 .619 .859 r
.40498 .61102 m .40447 .61462 L .403 .61368 L F
.40498 .61102 m .40698 .61441 L .40447 .61462 L F
.745 .346 .294 r
.40698 .61441 m .403 .61368 L .40447 .61462 L F
.953 .693 .504 r
.40403 .62226 m .40577 .62054 L .40191 .62035 L F
.40403 .62226 m .40587 .62324 L .40577 .62054 L F
.533 .356 .588 r
.40804 .62266 m .40587 .62324 L .40577 .62054 L F
.40804 .62266 m .40587 .62324 L .40577 .62054 L F
.403 .826 .965 r
.7074 .44746 m .70466 .44801 L .70338 .44744 L F
.028 0 0 r
.68536 .40818 m .68915 .40694 L .68829 .40598 L F
.666 .807 .95 r
.68915 .40694 m .69059 .40447 L .68829 .40598 L F
.68915 .40694 m .69149 .40594 L .69059 .40447 L F
.386 .209 .514 r
.37039 .59978 m .37231 .59914 L .3725 .59656 L F
.414 .277 .584 r
.37039 .59978 m .37243 .60171 L .37231 .59914 L F
.429 .277 .573 r
.37046 .60232 m .37243 .60171 L .37039 .59978 L F
.563 .764 .973 r
.68154 .4547 m .6778 .45403 L .68011 .45319 L F
.68154 .4547 m .6778 .45403 L .68011 .45319 L F
.016 .348 .825 r
.68154 .4547 m .68337 .45487 L .68011 .45319 L F
.68154 .4547 m .68418 .45647 L .68337 .45487 L F
.789 .491 .484 r
.48098 .62628 m .48259 .6297 L .48489 .62929 L F
.136 .114 .568 r
.75286 .40424 m .75474 .40244 L .75337 .40068 L F
.37 .496 .855 r
.75286 .40424 m .75642 .40566 L .75474 .40244 L F
.269 .059 .399 r
.2046 .63244 m .20591 .63394 L .20682 .63199 L F
.2046 .63244 m .20422 .63478 L .20591 .63394 L F
.958 .765 .601 r
.68709 .44983 m .68632 .45157 L .68577 .4482 L F
.727 .775 .891 r
.68868 .44818 m .68709 .44983 L .68577 .4482 L F
.385 .215 .525 r
.23921 .56646 m .24114 .56356 L .23936 .56429 L F
.113 .327 .797 r
.76094 .40246 m .76005 .40393 L .75839 .40068 L F
.196 .44 .867 r
.76094 .40246 m .76282 .40527 L .76005 .40393 L F
.493 .42 .703 r
.55174 .55981 m .5503 .56403 L .55056 .55972 L F
.55083 .55868 m .55056 .55972 L .55064 .55845 L F
.55174 .55981 m .55056 .55972 L .55083 .55868 L F
.539 .448 .7 r
.55151 .55515 m .55163 .55556 L .55016 .55894 L F
.55163 .55556 m .5523 .55801 L .55084 .55865 L F
.408 .159 .421 r
.55016 .55894 m .55084 .55865 L .55065 .5584 L F
.539 .448 .7 r
.55163 .55556 m .55084 .55865 L .55016 .55894 L F
.408 .159 .421 r
.55016 .55894 m .55083 .55868 L .55174 .55981 L F
.55083 .55868 m .55233 .5581 L .55174 .55981 L F
.539 .448 .7 r
.5523 .55801 m .55233 .5581 L .55083 .55868 L F
.55084 .55865 m .55083 .55868 L .55016 .55894 L F
.5523 .55801 m .55083 .55868 L .55084 .55865 L F
.493 .42 .703 r
.55084 .55865 m .55064 .55845 L .55065 .5584 L F
.55174 .55981 m .55083 .55868 L .55084 .55865 L F
.55083 .55868 m .55064 .55845 L .55084 .55865 L F
.408 .159 .421 r
.55016 .55894 m .55174 .55981 L .55084 .55865 L F
.873 .558 .451 r
.597 .453 m .59955 .4518 L .59742 .45051 L F
.597 .453 m .59976 .45398 L .59955 .4518 L F
.829 .906 .892 r
.21601 .56239 m .2144 .56425 L .21329 .5631 L F
.987 .739 .355 r
.2144 .56425 m .21352 .5651 L .21329 .5631 L F
.2144 .56425 m .21445 .56665 L .21352 .5651 L F
.206 0 .271 r
.2315 .63431 m .22994 .63531 L .23237 .63236 L F
.572 .399 .609 r
.2315 .63431 m .22917 .63736 L .22994 .63531 L F
.3 .029 .323 r
.23424 .63147 m .23237 .63236 L .23492 .62953 L F
.339 .064 .342 r
.23605 .63072 m .23492 .62953 L .23688 .62883 L F
.23605 .63072 m .23424 .63147 L .23492 .62953 L F
.79 .909 .923 r
.66189 .40284 m .66089 .40689 L .66001 .40553 L F
.66189 .40284 m .66405 .4049 L .66089 .40689 L F
.768 .835 .903 r
.66489 .40485 m .66089 .40689 L .66405 .4049 L F
.424 .55 .879 r
.19498 .69575 m .19444 .69873 L .19279 .69954 L F
.325 .032 .304 r
.20422 .63478 m .20226 .63545 L .20156 .63731 L F
.313 .021 .299 r
.58606 .44752 m .58882 .44479 L .5869 .44601 L F
.565 .387 .599 r
.19573 .70468 m .19566 .70476 L .19393 .70465 L F
.623 .197 .213 r
.43318 .59069 m .43174 .59248 L .42944 .59092 L F
.719 .439 .501 r
.43553 .59037 m .43174 .59248 L .43318 .59069 L F
.875 .691 .65 r
.65995 .45114 m .6584 .4513 L .65884 .44862 L F
.3 .643 .967 r
.65995 .45114 m .66108 .45053 L .6584 .4513 L F
.65995 .45114 m .66247 .45182 L .66108 .45053 L F
.632 .267 .333 r
.62177 .4203 m .62009 .42176 L .62244 .42105 L F
.504 .263 .482 r
.62177 .4203 m .62244 .42105 L .62401 .41869 L F
.952 .782 .635 r
.52745 .51372 m .52816 .51685 L .52663 .51564 L F
.52745 .51372 m .52816 .51685 L .52663 .51564 L F
.352 .436 .808 r
.61674 .42795 m .61907 .42903 L .61805 .42604 L F
.645 .438 .589 r
.76243 .4309 m .76003 .43338 L .75869 .43059 L F
.76243 .4309 m .76258 .43343 L .76003 .43338 L F
.564 .36 .562 r
.76542 .4304 m .76258 .43343 L .76243 .4309 L F
.952 .711 .536 r
.54111 .53182 m .54063 .53399 L .53909 .53034 L F
.54111 .53182 m .54063 .53399 L .53909 .53034 L F
.916 .607 .126 r
.75771 .40973 m .75642 .40566 L .75731 .40709 L F
.597 .873 .547 r
.60129 .4866 m .59929 .48794 L .60101 .48621 L F
.788 .999 .836 r
.60328 .48386 m .60129 .4866 L .60101 .48621 L F
.60328 .48386 m .60411 .48398 L .60129 .4866 L F
.212 0 .33 r
.59943 .51209 m .59757 .51162 L .59822 .51105 L F
.216 0 .309 r
.59767 .51343 m .59757 .51162 L .59943 .51209 L F
.964 .636 .271 r
.5058 .54179 m .50569 .543 L .50475 .53992 L F
.75 .713 .817 r
.50756 .53883 m .5058 .54179 L .50475 .53992 L F
.61 .751 .945 r
.70142 .40609 m .70272 .40335 L .70028 .4046 L F
.70142 .40609 m .70403 .40533 L .70272 .40335 L F
.355 0 0 r
.4049 .64409 m .40497 .64501 L .40123 .64455 L F
0 .486 .729 r
.40744 .64551 m .40497 .64501 L .4049 .64409 L F
.589 .132 .135 r
.40715 .64446 m .40744 .64551 L .4049 .64409 L F
.812 .781 .824 r
.62783 .4397 m .62902 .44241 L .62578 .44227 L F
.828 .732 .758 r
.62578 .44227 m .62902 .44241 L .62677 .44568 L F
.698 .751 .892 r
.63036 .43874 m .62902 .44241 L .62783 .4397 L F
.63036 .43874 m .63133 .44144 L .62902 .44241 L F
.276 .349 .758 r
.76566 .409 m .76665 .41266 L .76519 .4123 L F
.986 .842 .615 r
.66752 .41185 m .66922 .41045 L .6685 .40961 L F
.012 0 .082 r
.61012 .41304 m .61233 .41185 L .61268 .40999 L F
0 0 .08 r
.60976 .41507 m .61233 .41185 L .61012 .41304 L F
.504 .312 .552 r
.57618 .51089 m .57861 .51276 L .57875 .51032 L F
.57618 .51089 m .57622 .5133 L .57861 .51276 L F
.543 .579 .841 r
.18142 .64036 m .18412 .64035 L .18184 .64124 L F
.653 .929 .972 r
.71485 .44425 m .71492 .44478 L .71352 .44586 L F
.267 .002 .313 r
.58935 .44299 m .58882 .44479 L .59131 .4419 L F
.841 .636 .626 r
.67852 .41562 m .67918 .41347 L .67675 .41181 L F
.475 .663 .944 r
.67675 .41181 m .67918 .41347 L .67989 .41282 L F
.841 .636 .626 r
.67852 .41562 m .67918 .41347 L .67675 .41181 L F
0 0 .143 r
.23308 .63281 m .23237 .63236 L .23424 .63147 L F
.23308 .63281 m .2315 .63431 L .23237 .63236 L F
0 0 0 r
.61268 .40999 m .61467 .4091 L .61547 .40755 L F
0 0 .069 r
.61268 .40999 m .614 .41049 L .61467 .4091 L F
.61268 .40999 m .61233 .41185 L .614 .41049 L F
0 .144 .679 r
.19609 .66744 m .19815 .66961 L .20039 .66767 L F
.756 .387 .356 r
.19815 .66961 m .20169 .67051 L .20039 .66767 L F
.695 .855 .959 r
.20591 .6704 m .2042 .67163 L .20195 .67063 L F
.20591 .6704 m .20195 .67063 L .20205 .6705 L F
.20591 .6704 m .20169 .67051 L .20465 .66785 L F
.532 .625 .889 r
.20723 .66945 m .20591 .6704 L .20465 .66785 L F
.838 .937 .892 r
.20465 .66785 m .20169 .67051 L .20272 .66812 L F
.517 .587 .864 r
.20358 .66848 m .20297 .67103 L .20607 .66952 L F
.20272 .66812 m .20283 .66947 L .20358 .66848 L F
.20283 .66947 m .20297 .67103 L .20358 .66848 L F
.695 .855 .959 r
.20205 .6705 m .20195 .67063 L .20169 .67051 L F
.548 0 0 r
.2042 .67163 m .20297 .67103 L .20169 .67051 L F
.2042 .67163 m .2057 .67294 L .20297 .67103 L F
.37 .192 .505 r
.20591 .6704 m .2057 .67294 L .2042 .67163 L F
.084 0 0 r
.61547 .40755 m .61675 .40813 L .61765 .4064 L F
.61547 .40755 m .61467 .4091 L .61675 .40813 L F
.7 .705 .851 r
.73354 .42721 m .73414 .43031 L .73766 .42831 L F
.777 .533 .567 r
.41369 .61172 m .4129 .61419 L .40906 .6136 L F
.41369 .61172 m .41086 .61286 L .41184 .6131 L F
.996 .837 .566 r
.41369 .61172 m .4129 .61419 L .41184 .6131 L F
.314 .131 .466 r
.41275 .61332 m .41184 .6131 L .41219 .61163 L F
.41294 .6139 m .41184 .6131 L .41275 .61332 L F
.777 .533 .567 r
.41086 .61286 m .40906 .6136 L .41184 .6131 L F
.379 .826 .705 r
.19981 .6385 m .1956 .64043 L .19739 .63876 L F
.618 .955 .911 r
.20156 .63731 m .19981 .6385 L .19739 .63876 L F
.546 .882 .988 r
.69269 .39666 m .69021 .39747 L .68925 .39683 L F
0 0 0 r
.2188 .64908 m .21625 .65198 L .21712 .64992 L F
.584 .379 .569 r
.56106 .5405 m .56102 .54294 L .55859 .54341 L F
.509 .272 .49 r
.56106 .5405 m .5634 .54222 L .56102 .54294 L F
.56106 .5405 m .56352 .53994 L .5634 .54222 L F
.408 0 0 r
.43748 .56596 m .436 .56622 L .43495 .56609 L F
.062 .294 .782 r
.43495 .56609 m .43416 .56716 L .43359 .56593 L F
.597 .934 .74 r
.43495 .56609 m .43215 .56821 L .43416 .56716 L F
.576 .93 .945 r
.43353 .56666 m .43215 .56821 L .43495 .56609 L F
.408 0 0 r
.436 .56622 m .43353 .56666 L .43495 .56609 L F
.062 .294 .782 r
.43495 .56609 m .43359 .56593 L .43263 .56386 L F
0 0 .047 r
.20239 .67949 m .20143 .682 L .19984 .683 L F
0 0 .361 r
.20062 .68409 m .19984 .683 L .20143 .682 L F
.20062 .68409 m .20052 .68551 L .19984 .683 L F
.308 .426 .819 r
.20119 .6766 m .20239 .67949 L .20083 .6766 L F
.347 .316 .682 r
.2035 .67573 m .20239 .67949 L .20119 .6766 L F
.2035 .67573 m .20386 .67901 L .20239 .67949 L F
.286 0 .22 r
.20343 .68136 m .20239 .67949 L .20386 .67901 L F
.20343 .68136 m .20143 .682 L .20239 .67949 L F
.67 .47 .606 r
.43384 .63794 m .43651 .63827 L .43632 .6351 L F
.741 .525 .601 r
.43632 .6351 m .43651 .63827 L .43988 .63787 L F
.49 .818 1 r
.23346 .54121 m .23543 .54078 L .23711 .54164 L F
.256 .653 .965 r
.23775 .54066 m .23711 .54164 L .23543 .54078 L F
.23775 .54066 m .23947 .54183 L .23711 .54164 L F
.576 .456 .679 r
.58375 .50459 m .58585 .50099 L .58337 .50173 L F
.535 .538 .805 r
.47065 .57908 m .47167 .57515 L .46944 .57546 L F
.47065 .57908 m .47265 .57853 L .47167 .57515 L F
.982 .879 .652 r
.2188 .58051 m .21968 .58186 L .22083 .57906 L F
.963 .741 .555 r
.21911 .578 m .2188 .58051 L .22083 .57906 L F
.497 .704 .962 r
.43066 .56182 m .43037 .56438 L .4305 .56182 L F
.43066 .56182 m .43263 .56386 L .43037 .56438 L F
.43069 .56165 m .43086 .56184 L .43066 .56182 L F
.43086 .56184 m .43263 .56386 L .43066 .56182 L F
.658 .773 .934 r
.43517 .56313 m .43263 .56386 L .43218 .56334 L F
.43311 .56245 m .43218 .56334 L .43069 .56165 L F
.43517 .56313 m .43218 .56334 L .43311 .56245 L F
.43517 .56313 m .43069 .56165 L .43391 .5616 L F
.549 .704 .942 r
.43754 .5614 m .43517 .56313 L .43391 .5616 L F
.24 .756 .825 r
.43391 .5616 m .43552 .56105 L .43622 .56111 L F
.549 .704 .942 r
.43754 .5614 m .43391 .5616 L .43622 .56111 L F
0 0 .004 r
.43403 .56156 m .43449 .56306 L .43552 .56105 L F
.43391 .5616 m .43393 .56166 L .43403 .56156 L F
.43393 .56166 m .43449 .56306 L .43403 .56156 L F
.062 .294 .782 r
.43495 .56609 m .43263 .56386 L .43517 .56313 L F
.267 .212 .608 r
.43046 .5619 m .43279 .5642 L .43366 .56218 L F
.43137 .56191 m .43366 .56218 L .43377 .56192 L F
.43046 .5619 m .43366 .56218 L .43137 .56191 L F
.4312 .56184 m .43377 .56192 L .43391 .5616 L F
.43046 .5619 m .43377 .56192 L .4312 .56184 L F
.497 .704 .962 r
.4305 .56182 m .43037 .56438 L .42867 .56345 L F
.43069 .56165 m .43066 .56182 L .4305 .56182 L F
.512 .804 .998 r
.71183 .44169 m .70936 .44228 L .70879 .44119 L F
.473 .275 .53 r
.71218 .44436 m .70936 .44228 L .71183 .44169 L F
0 .219 .729 r
.70879 .44119 m .70936 .44228 L .71218 .44436 L F
.352 .13 .431 r
.59503 .4614 m .59305 .46052 L .59534 .45968 L F
.59503 .4614 m .59275 .4627 L .59305 .46052 L F
.416 .411 .745 r
.26657 .56885 m .26569 .5729 L .26471 .56914 L F
.26657 .56885 m .26744 .57251 L .26569 .5729 L F
.368 .226 .553 r
.26744 .57251 m .26745 .57488 L .26569 .5729 L F
.759 .993 .877 r
.40963 .60664 m .40903 .60842 L .41167 .60648 L F
.181 .715 .768 r
.41286 .6061 m .41167 .60648 L .41417 .60703 L F
.41286 .6061 m .40963 .60664 L .41167 .60648 L F
.57 .827 .994 r
.63899 .41288 m .63476 .41278 L .63888 .41106 L F
.306 0 0 r
.63899 .41288 m .63733 .41335 L .63476 .41278 L F
.838 .398 .182 r
.6389 .41143 m .64106 .41077 L .63899 .41288 L F
.585 .374 .561 r
.63863 .41168 m .63733 .41335 L .63964 .41144 L F
.6365 .41219 m .63715 .41311 L .63863 .41168 L F
.63715 .41311 m .63733 .41335 L .63863 .41168 L F
.838 .398 .182 r
.63888 .41106 m .63935 .411 L .6389 .41143 L F
.63935 .411 m .64106 .41077 L .6389 .41143 L F
0 0 .49 r
.63899 .41288 m .63964 .41144 L .63733 .41335 L F
.63899 .41288 m .63992 .41535 L .63964 .41144 L F
.135 0 .386 r
.16077 .54882 m .16231 .54753 L .16462 .54738 L F
.322 0 0 r
.16231 .54753 m .16666 .54639 L .16462 .54738 L F
.532 .823 .999 r
.50392 .7085 m .50763 .70887 L .50538 .70948 L F
.50392 .7085 m .50763 .70887 L .50538 .70948 L F
.09 0 0 r
.18763 .55609 m .18537 .55634 L .1842 .55612 L F
.479 .797 .999 r
.18968 .55758 m .18782 .55704 L .189 .55708 L F
.18782 .55704 m .18537 .55634 L .189 .55708 L F
.18968 .55758 m .18803 .55686 L .18537 .55634 L F
.946 .643 .431 r
.18803 .55686 m .18344 .55775 L .18537 .55634 L F
.18803 .55686 m .18576 .55682 L .1854 .55696 L F
.18719 .55702 m .1854 .55696 L .18344 .55775 L F
.18803 .55686 m .1854 .55696 L .18719 .55702 L F
.479 .797 .999 r
.189 .55708 m .18537 .55634 L .18763 .55609 L F
.558 .331 .527 r
.41798 .59937 m .42097 .59632 L .41892 .59685 L F
.616 .899 .987 r
.66648 .40391 m .66489 .40485 L .66405 .4049 L F
.644 .801 .958 r
.68999 .45207 m .68632 .45157 L .68882 .45068 L F
.74 .842 .927 r
.69232 .45074 m .68999 .45207 L .68882 .45068 L F
.623 .766 .948 r
.72517 .4352 m .72378 .43788 L .72214 .43772 L F
.72517 .4352 m .72641 .43698 L .72378 .43788 L F
.406 .656 .961 r
.39171 .64065 m .39354 .63957 L .38971 .63783 L F
.39171 .64065 m .3937 .64057 L .39354 .63957 L F
.623 .43 .6 r
.55862 .51652 m .56118 .51606 L .56115 .51362 L F
.764 .448 .451 r
.56452 .51633 m .56115 .51362 L .56118 .51606 L F
.608 .85 .99 r
.66648 .40391 m .66405 .4049 L .66189 .40284 L F
.025 0 0 r
.19566 .70476 m .1978 .7023 L .19903 .70258 L F
.632 .782 .954 r
.73563 .42414 m .7387 .42446 L .73807 .4229 L F
.778 .594 .651 r
.73555 .42636 m .7387 .42446 L .73563 .42414 L F
.73555 .42636 m .73892 .42763 L .7387 .42446 L F
.758 .851 .92 r
.73807 .4229 m .7387 .42446 L .74211 .42271 L F
0 .022 .561 r
.51965 .5755 m .51987 .57225 L .51791 .57243 L F
.51965 .5755 m .52072 .57451 L .51987 .57225 L F
.832 .997 .842 r
.52001 .57689 m .52072 .57451 L .51965 .5755 L F
.898 .847 .392 r
.76774 .42213 m .76756 .42494 L .76835 .42116 L F
0 0 0 r
.76753 .42619 m .76756 .42494 L .76774 .42213 L F
.76753 .42619 m .76751 .4273 L .76756 .42494 L F
.809 .536 .525 r
.66434 .43856 m .6673 .43672 L .66503 .43602 L F
.66434 .43856 m .66696 .43808 L .6673 .43672 L F
.442 .353 .66 r
.257 .59336 m .2574 .59583 L .25555 .59649 L F
.26 .115 .486 r
.25698 .59843 m .25555 .59649 L .2574 .59583 L F
.25698 .59843 m .2555 .59921 L .25555 .59649 L F
.801 .952 .917 r
.72969 .44348 m .72888 .44597 L .73082 .44414 L F
.818 .968 .9 r
.72969 .44348 m .72809 .44516 L .72888 .44597 L F
.627 .809 .97 r
.74156 .41987 m .7385 .41946 L .74027 .4174 L F
.588 .733 .944 r
.74297 .41775 m .74156 .41987 L .74027 .4174 L F
.341 .413 .791 r
.73788 .41579 m .74027 .4174 L .73926 .41435 L F
.838 .398 .182 r
.63888 .41106 m .63964 .41144 L .64106 .41077 L F
.54 .137 .227 r
.64262 .40813 m .64331 .41029 L .64474 .40776 L F
.64262 .40813 m .6421 .41067 L .64331 .41029 L F
.784 .68 .748 r
.64331 .41029 m .64271 .40953 L .64474 .40776 L F
0 0 0 r
.64106 .41077 m .64203 .41068 L .64262 .40813 L F
.64203 .41068 m .64213 .41051 L .64262 .40813 L F
.099 0 .438 r
.64262 .40813 m .64474 .40776 L .64445 .40544 L F
.784 .68 .748 r
.64271 .40953 m .64093 .40732 L .64382 .40766 L F
.64271 .40953 m .64382 .40766 L .64474 .40776 L F
0 0 0 r
.64203 .41068 m .6421 .41067 L .64213 .41051 L F
.64106 .41077 m .63964 .41144 L .6421 .41067 L F
.707 .966 .938 r
.73851 .43998 m .73697 .44208 L .73949 .44081 L F
.73851 .43998 m .73614 .44158 L .73697 .44208 L F
.382 .442 .798 r
.37172 .62054 m .37428 .62216 L .37411 .62003 L F
.12 0 0 r
.4419 .59053 m .4435 .59078 L .44561 .59107 L F
.44561 .59107 m .4435 .59078 L .4419 .59053 L F
.567 .875 .994 r
.4477 .59025 m .4435 .59078 L .44561 .59107 L F
.4477 .59025 m .4435 .59078 L .44561 .59107 L F
.209 0 0 r
.4055 .60561 m .404 .60723 L .40264 .60702 L F
.58 .524 .756 r
.40672 .60174 m .40785 .60517 L .4055 .60561 L F
.92 .601 .422 r
.40578 .60775 m .4055 .60561 L .40785 .60517 L F
.40578 .60775 m .404 .60723 L .4055 .60561 L F
.38 .114 .38 r
.23899 .62562 m .23702 .62627 L .23965 .6235 L F
.347 .084 .365 r
.24096 .62466 m .23965 .6235 L .24156 .62278 L F
.24096 .62466 m .23899 .62562 L .23965 .6235 L F
.691 .152 0 r
.75424 .42169 m .75127 .42038 L .75197 .4229 L F
.363 .709 .986 r
.7514 .42362 m .75424 .42169 L .75197 .4229 L F
.481 .373 .654 r
.36871 .6089 m .37055 .60482 L .36875 .60552 L F
.371 .194 .508 r
.21486 .5988 m .21686 .59593 L .21559 .59642 L F
.614 .808 .974 r
.45187 .64027 m .45369 .64193 L .45572 .64119 L F
.473 .591 .89 r
.7507 .39546 m .75409 .39808 L .75321 .39903 L F
0 .475 .72 r
.40903 .60842 m .40798 .60817 L .40578 .60775 L F
.739 .981 .912 r
.40963 .60664 m .40798 .60817 L .40903 .60842 L F
.66 .465 .609 r
.43988 .63787 m .44353 .64028 L .44357 .63931 L F
.64 .203 .194 r
.44353 .64028 m .44576 .64065 L .44357 .63931 L F
.574 .316 .487 r
.44357 .63931 m .44576 .64065 L .44432 .63937 L F
.399 .716 .987 r
.251 .54526 m .25053 .54663 L .24896 .54532 L F
.251 .54526 m .2526 .54652 L .25053 .54663 L F
.291 0 0 r
.74988 .4375 m .74804 .43711 L .7514 .43611 L F
.586 .439 .649 r
.75382 .43347 m .75418 .43531 L .7514 .43611 L F
.111 0 0 r
.75418 .43531 m .74988 .4375 L .7514 .43611 L F
.335 .318 .692 r
.3702 .6147 m .3713 .61066 L .36943 .61115 L F
.3702 .6147 m .37175 .61419 L .3713 .61066 L F
.328 .298 .672 r
.3702 .6147 m .37238 .61667 L .37175 .61419 L F
.53 .276 .474 r
.22703 .59893 m .22989 .59618 L .22717 .59693 L F
0 .109 .663 r
.19557 .68894 m .19585 .68819 L .19381 .68573 L F
.907 .502 .118 r
.19699 .6916 m .19635 .69165 L .19557 .68894 L F
.623 .32 .436 r
.19841 .68879 m .19635 .69165 L .19557 .68894 L F
0 0 .33 r
.19557 .68894 m .19635 .69165 L .19585 .68819 L F
.491 .849 .992 r
.18917 .66093 m .18917 .65964 L .18685 .66033 L F
.18917 .66093 m .19112 .66024 L .18917 .65964 L F
0 0 .553 r
.37728 .62645 m .37797 .62777 L .37777 .62719 L F
.766 .29 .111 r
.37912 .62636 m .37728 .62645 L .37608 .62467 L F
0 0 .553 r
.37728 .62645 m .37777 .62719 L .37684 .62449 L F
.766 .29 .111 r
.37608 .62467 m .37728 .62645 L .3749 .62401 L F
0 0 .031 r
.23115 .58188 m .23235 .58131 L .23304 .57983 L F
.258 .257 .667 r
.23115 .58188 m .23302 .58405 L .23235 .58131 L F
.376 .014 .218 r
.23304 .57983 m .23461 .58066 L .23513 .57943 L F
.23304 .57983 m .23235 .58131 L .23461 .58066 L F
.715 .876 .956 r
.61137 .46576 m .60878 .46558 L .6107 .46466 L F
.921 .95 .795 r
.61267 .46162 m .61137 .46576 L .6107 .46466 L F
0 0 0 r
.51236 .56101 m .51057 .56412 L .51163 .56275 L F
.51236 .56101 m .51163 .56275 L .5115 .56012 L F
.034 0 0 r
.72373 .4104 m .72696 .41012 L .72613 .4096 L F
.477 .753 .99 r
.72696 .41012 m .72874 .40851 L .72613 .4096 L F
.72696 .41012 m .72974 .40987 L .72874 .40851 L F
.079 .586 .889 r
.21147 .53946 m .21343 .53978 L .21528 .54063 L F
.177 0 0 r
.21343 .53978 m .21744 .54054 L .21528 .54063 L F
.427 .655 .955 r
.71717 .40778 m .72119 .40965 L .71979 .40683 L F
.449 .565 .88 r
.71979 .40683 m .72119 .40965 L .7224 .40855 L F
.467 .595 .897 r
.72119 .40965 m .72373 .4104 L .7224 .40855 L F
.691 .252 .201 r
.21835 .56729 m .21657 .56873 L .21445 .56665 L F
.985 .797 .569 r
.21702 .5661 m .21657 .56873 L .21835 .56729 L F
.261 .664 .966 r
.73517 .43249 m .73719 .43258 L .73833 .43362 L F
.457 .653 .944 r
.7397 .43176 m .74051 .43328 L .73833 .43362 L F
.599 .854 .992 r
.73833 .43362 m .73719 .43258 L .7397 .43176 L F
.849 .721 .722 r
.64019 .43946 m .64296 .43846 L .64247 .43837 L F
.64019 .43946 m .64125 .44246 L .64296 .43846 L F
.646 .666 .854 r
.64315 .4018 m .64535 .40453 L .64179 .40361 L F
.526 .621 .889 r
.64703 .40216 m .64535 .40453 L .64315 .4018 L F
.496 .579 .869 r
.64703 .40216 m .64848 .40515 L .64535 .40453 L F
.849 .896 .87 r
.42401 .57849 m .42717 .57644 L .42607 .57733 L F
.533 .109 .182 r
.42953 .57598 m .42607 .57733 L .42717 .57644 L F
.34 .615 .952 r
.51057 .56412 m .51301 .56443 L .51163 .56275 L F
.903 .494 .189 r
.5089 .55429 m .50655 .55131 L .50798 .55227 L F
.771 .785 .864 r
.61798 .42205 m .61419 .42538 L .61453 .42162 L F
.433 0 0 r
.65645 .41311 m .6577 .41408 L .65596 .41162 L F
.835 .422 0 r
.65645 .41311 m .65858 .41727 L .65914 .41474 L F
.861 .537 .018 r
.6577 .41408 m .65813 .41591 L .65746 .41405 L F
.433 0 0 r
.65645 .41311 m .65815 .41413 L .6577 .41408 L F
0 0 .557 r
.65548 .41011 m .65596 .41162 L .6577 .41408 L F
.861 .537 .018 r
.6577 .41408 m .65746 .41405 L .65685 .41234 L F
.433 0 0 r
.65815 .41413 m .65914 .41474 L .6577 .41408 L F
.317 .072 .375 r
.22236 .55279 m .22028 .55223 L .22401 .55201 L F
.245 0 0 r
.22532 .55271 m .22236 .55279 L .22401 .55201 L F
.173 .389 .833 r
.76282 .40527 m .76454 .40579 L .76328 .40711 L F
.176 .3 .753 r
.76599 .40753 m .76328 .40711 L .76454 .40579 L F
.76599 .40753 m .76566 .409 L .76328 .40711 L F
.768 .51 .544 r
.70074 .44559 m .69727 .44724 L .70082 .44461 L F
.70074 .44559 m .70084 .44824 L .69727 .44724 L F
.491 .747 .985 r
.70221 .44386 m .70074 .44559 L .70082 .44461 L F
.599 .587 .811 r
.70221 .44386 m .70084 .44824 L .70074 .44559 L F
.413 .093 .31 r
.39405 .58859 m .39602 .58882 L .39775 .58458 L F
.369 .051 .289 r
.39775 .58458 m .39887 .5871 L .39998 .5841 L F
.39775 .58458 m .39602 .58882 L .39887 .5871 L F
.628 .265 .335 r
.46443 .63585 m .46671 .63769 L .4675 .63611 L F
.743 .585 .68 r
.55227 .51876 m .55616 .51949 L .55613 .51694 L F
.607 .432 .619 r
.55616 .51949 m .55862 .51652 L .55613 .51694 L F
.964 .934 .625 r
.76886 .41841 m .76794 .42063 L .76835 .42116 L F
.898 .847 .392 r
.76774 .42213 m .76835 .42116 L .76794 .42063 L F
.68 .459 .579 r
.57687 .53103 m .57442 .5337 L .57442 .53146 L F
.665 .869 .487 r
.72931 .43529 m .73109 .4326 L .73214 .43384 L F
.701 .853 .955 r
.73517 .43249 m .73214 .43384 L .73109 .4326 L F
.898 .735 .671 r
.54182 .68433 m .54278 .68369 L .54115 .68165 L F
.946 .589 .284 r
.64179 .40361 m .64224 .40585 L .64065 .40465 L F
.817 .994 .862 r
.64315 .4018 m .64179 .40361 L .64282 .40076 L F
.798 .927 .553 r
.64179 .40361 m .64065 .40465 L .64282 .40076 L F
.946 .589 .284 r
.64179 .40361 m .64224 .40585 L .64065 .40465 L F
.82 .994 .86 r
.51628 .52451 m .51706 .52508 L .51585 .52613 L F
.741 .908 .951 r
.51865 .52229 m .51706 .52508 L .51628 .52451 L F
.51865 .52229 m .52011 .52315 L .51706 .52508 L F
.39 .22 .527 r
.2386 .62791 m .23702 .62627 L .23899 .62562 L F
.2386 .62791 m .23688 .62883 L .23702 .62627 L F
.778 .288 .054 r
.66381 .44483 m .6657 .44679 L .66645 .44582 L F
0 .346 .796 r
.66818 .44617 m .6696 .44754 L .66645 .44582 L F
.66818 .44617 m .66645 .44582 L .6657 .44679 L F
.537 .641 .9 r
.44527 .57793 m .44633 .58211 L .44524 .58062 L F
.434 .069 .244 r
.44633 .58211 m .44259 .58527 L .44524 .58062 L F
.44633 .58211 m .44606 .58372 L .44259 .58527 L F
.482 .602 .895 r
.44797 .57953 m .44633 .58211 L .44527 .57793 L F
.614 .544 .752 r
.44797 .57953 m .44606 .58372 L .44633 .58211 L F
0 0 0 r
.40887 .57904 m .40988 .57832 L .41089 .5779 L F
.40887 .57904 m .40725 .58039 L .40988 .57832 L F
.907 .75 .254 r
.65858 .41727 m .65869 .41819 L .6582 .41743 L F
.665 .273 0 r
.6582 .41743 m .65869 .41819 L .65991 .4206 L F
.002 .377 .841 r
.26445 .55106 m .26409 .55201 L .26246 .55088 L F
.26445 .55106 m .26584 .55298 L .26409 .55201 L F
.568 .56 .805 r
.26778 .55534 m .26409 .55201 L .26584 .55298 L F
.945 .862 .727 r
.63096 .46045 m .63153 .45677 L .63046 .46023 L F
.954 .787 .637 r
.62936 .46222 m .63096 .46045 L .63046 .46023 L F
.62936 .46222 m .63076 .46353 L .63096 .46045 L F
.22 .717 .914 r
.45801 .63812 m .46125 .63812 L .46189 .63849 L F
.45801 .63812 m .46125 .63812 L .46189 .63849 L F
.719 .982 .905 r
.46189 .63849 m .46125 .63812 L .46283 .63662 L F
.269 0 0 r
.46293 .63961 m .46189 .63849 L .46457 .63834 L F
.46293 .63961 m .46056 .64007 L .46189 .63849 L F
.677 .826 .955 r
.73153 .4082 m .73284 .40916 L .73227 .40656 L F
.752 .775 .872 r
.73459 .40622 m .73227 .40656 L .73284 .40916 L F
.492 .337 .599 r
.55223 .57226 m .55234 .57499 L .54976 .57519 L F
.499 .427 .706 r
.55234 .57499 m .55041 .57877 L .54976 .57519 L F
.924 .975 .724 r
.60593 .48075 m .60411 .48398 L .60328 .48386 L F
.644 .535 .715 r
.40264 .60702 m .39938 .60576 L .40028 .60547 L F
.40264 .60702 m .40004 .60865 L .39938 .60576 L F
.261 0 0 r
.62628 .40191 m .62514 .40334 L .62892 .40176 L F
0 0 .341 r
.53501 .58607 m .53434 .58678 L .53419 .58506 L F
.953 .91 .738 r
.63222 .4516 m .634 .4514 L .633 .45039 L F
.63222 .4516 m .6323 .45458 L .634 .4514 L F
.874 .932 .857 r
.633 .45039 m .634 .4514 L .63652 .44849 L F
.698 .604 .748 r
.55132 .52269 m .55227 .51876 L .55003 .51947 L F
.55132 .52269 m .55384 .52263 L .55227 .51876 L F
.671 .401 .505 r
.55108 .52602 m .55132 .52269 L .5495 .52673 L F
.5537 .52483 m .5531 .52429 L .55108 .52602 L F
.5531 .52429 m .55132 .52269 L .55108 .52602 L F
.763 .666 .755 r
.55146 .52808 m .55108 .52602 L .5493 .52755 L F
.681 .595 .753 r
.55146 .52808 m .5537 .52483 L .55108 .52602 L F
.671 .401 .505 r
.5537 .52483 m .5495 .52673 L .54927 .52724 L F
.5493 .52764 m .54927 .52724 L .54901 .52783 L F
.791 .547 .568 r
.5493 .52755 m .54943 .52775 L .55146 .52808 L F
.54943 .52775 m .55155 .53085 L .5515 .52944 L F
.54943 .52775 m .5515 .52944 L .55146 .52808 L F
.54934 .52812 m .55155 .53085 L .5493 .52755 L F
.671 .401 .505 r
.5537 .52483 m .54927 .52724 L .5493 .52764 L F
.763 .666 .755 r
.55108 .52602 m .55089 .52499 L .5493 .52755 L F
.681 .595 .753 r
.55108 .52602 m .5537 .52483 L .55089 .52499 L F
.703 .581 .715 r
.55089 .52499 m .5537 .52483 L .5493 .52764 L F
.54919 .52755 m .5493 .52764 L .54901 .52783 L F
.759 .579 .653 r
.54901 .52783 m .55132 .52269 L .54766 .52215 L F
.763 .666 .755 r
.5493 .52755 m .55089 .52499 L .54912 .527 L F
.489 .408 .691 r
.54766 .52215 m .54897 .52383 L .54901 .52768 L F
.549 .52776 m .54901 .52768 L .54901 .52783 L F
.754 .651 .748 r
.54876 .52741 m .54901 .52783 L .54755 .52728 L F
.843 .693 .697 r
.54901 .52783 m .54901 .52768 L .54755 .52728 L F
.489 .408 .691 r
.54766 .52215 m .54901 .52768 L .549 .52776 L F
.763 .666 .755 r
.5489 .52745 m .54884 .52733 L .54876 .52741 L F
.754 .651 .748 r
.54876 .52741 m .54888 .52745 L .54901 .52783 L F
.791 .547 .568 r
.54876 .52741 m .54934 .52812 L .5493 .52759 L F
.54876 .52741 m .5493 .52759 L .5493 .52755 L F
.754 .651 .748 r
.54876 .52741 m .54884 .52733 L .54888 .52745 L F
.843 .693 .697 r
.54901 .52768 m .54897 .52383 L .54824 .52561 L F
.763 .666 .755 r
.54905 .52748 m .54912 .527 L .54884 .52733 L F
.54905 .52748 m .54884 .52733 L .5489 .52745 L F
.5493 .52755 m .54912 .527 L .54905 .52748 L F
.754 .651 .748 r
.54884 .52733 m .55089 .52499 L .54901 .52783 L F
.843 .693 .697 r
.54884 .52733 m .54824 .52561 L .54813 .52587 L F
.54901 .52768 m .54824 .52561 L .54884 .52733 L F
.54901 .52768 m .54813 .52587 L .54755 .52728 L F
.703 .581 .715 r
.55089 .52499 m .5493 .52764 L .54919 .52755 L F
.671 .401 .505 r
.5537 .52483 m .55384 .52263 L .55132 .52269 L F
.753 .617 .708 r
.54766 .52215 m .55132 .52269 L .55003 .51947 L F
.88 .792 .302 r
.65211 .41898 m .65217 .42145 L .6526 .41905 L F
.832 .997 .842 r
.52001 .57689 m .51788 .57737 L .52072 .57451 L F
.62 .146 0 r
.52001 .57689 m .52079 .57821 L .51788 .57737 L F
.52001 .57689 m .52222 .57986 L .52079 .57821 L F
0 0 .021 r
.59217 .44015 m .59131 .4419 L .59339 .43886 L F
.958 .745 .293 r
.76825 .41739 m .76892 .41555 L .76816 .4157 L F
.76825 .41739 m .76886 .41841 L .76892 .41555 L F
.533 .109 .182 r
.42953 .57598 m .42894 .57807 L .42607 .57733 L F
.107 .292 .768 r
.43025 .57399 m .42953 .57598 L .42814 .57226 L F
.188 0 .08 r
.43074 .57721 m .42953 .57598 L .43025 .57399 L F
.728 .632 .751 r
.43239 .57546 m .43191 .57935 L .4356 .57522 L F
.717 .479 .564 r
.43296 .57628 m .43249 .57648 L .43074 .57721 L F
.188 0 .08 r
.43074 .57721 m .42894 .57807 L .42898 .57795 L F
.401 .739 .992 r
.42424 .57661 m .42881 .57803 L .428 .57701 L F
.42881 .57803 m .42894 .57807 L .42888 .57799 L F
.42881 .57803 m .42888 .57799 L .428 .57701 L F
.717 .479 .564 r
.43249 .57648 m .43053 .5773 L .43074 .57721 L F
.822 .627 .075 r
.42871 .57807 m .42894 .57807 L .43074 .57721 L F
.717 .479 .564 r
.43053 .5773 m .42871 .57807 L .42997 .57754 L F
.43053 .5773 m .42997 .57754 L .43074 .57721 L F
.188 0 .08 r
.43074 .57721 m .42898 .57795 L .42953 .57598 L F
.579 .706 .929 r
.6999 .45657 m .7034 .45766 L .70232 .45587 L F
.674 .752 .909 r
.70232 .45587 m .7034 .45766 L .70561 .45656 L F
.664 .776 .932 r
.70854 .39655 m .70513 .39602 L .70748 .39508 L F
.622 .798 .967 r
.70998 .39438 m .70854 .39655 L .70748 .39508 L F
.70998 .39438 m .71101 .39572 L .70854 .39655 L F
.812 .723 .767 r
.62578 .44227 m .62677 .44568 L .62353 .44537 L F
.812 .724 .768 r
.62677 .44568 m .62457 .44865 L .62353 .44537 L F
0 .331 .699 r
.39936 .6437 m .39908 .64346 L .39819 .64308 L F
.39936 .6437 m .40123 .64455 L .39908 .64346 L F
.64 .194 .176 r
.48428 .63347 m .48303 .63521 L .48386 .63441 L F
.896 .718 .653 r
.48468 .63081 m .48391 .63418 L .48199 .63003 L F
.48391 .63418 m .48386 .63441 L .4838 .63427 L F
.48391 .63418 m .4838 .63427 L .48199 .63003 L F
.607 .378 .542 r
.48483 .63337 m .4838 .63427 L .48428 .63347 L F
.4838 .63427 m .48364 .63435 L .48428 .63347 L F
.878 .822 .347 r
.48428 .63347 m .48386 .63441 L .48468 .63081 L F
.778 .664 .111 r
.48488 .62947 m .48473 .63186 L .48468 .63081 L F
0 0 .515 r
.48468 .63081 m .48473 .63186 L .48489 .62929 L F
0 0 .126 r
.48488 .62947 m .48511 .63151 L .48473 .63186 L F
.48489 .62929 m .48511 .63151 L .48488 .62947 L F
0 0 .515 r
.48468 .63081 m .48511 .63151 L .48473 .63186 L F
.59 .583 .813 r
.48446 .6312 m .48516 .63192 L .48511 .63151 L F
.229 .222 .643 r
.48511 .63151 m .48631 .63312 L .48428 .63347 L F
.59 .583 .813 r
.48516 .63192 m .48631 .63312 L .48511 .63151 L F
.48199 .63003 m .48422 .63162 L .48446 .6312 L F
.878 .822 .347 r
.48428 .63347 m .48468 .63081 L .48473 .63186 L F
.229 .222 .643 r
.48511 .63151 m .48428 .63347 L .48473 .63186 L F
.59 .583 .813 r
.48422 .63162 m .48631 .63312 L .48446 .6312 L F
.4838 .63427 m .48386 .63441 L .48631 .63312 L F
.607 .378 .542 r
.48631 .63312 m .48351 .63453 L .48483 .63337 L F
.59 .583 .813 r
.48199 .63003 m .4838 .63427 L .48631 .63312 L F
.607 .378 .542 r
.4838 .63427 m .48351 .63453 L .48364 .63435 L F
.48303 .63521 m .48631 .63312 L .48386 .63441 L F
.48631 .63312 m .48303 .63521 L .48351 .63453 L F
.787 .309 .095 r
.48199 .63003 m .48462 .63127 L .48468 .63081 L F
.48462 .63127 m .48511 .63151 L .48468 .63081 L F
.778 .664 .111 r
.48489 .62929 m .48488 .62947 L .48468 .63081 L F
.782 .789 .858 r
.69838 .449 m .69476 .44862 L .69727 .44724 L F
.602 .727 .933 r
.70084 .44824 m .69838 .449 L .69727 .44724 L F
.613 .452 .64 r
.45532 .60847 m .45551 .61122 L .45294 .61148 L F
.523 .346 .582 r
.45538 .6138 m .45294 .61148 L .45551 .61122 L F
.45538 .6138 m .45277 .61456 L .45294 .61148 L F
.613 .452 .64 r
.45532 .60847 m .45551 .61122 L .45294 .61148 L F
.111 .278 .755 r
.45538 .6138 m .45294 .61148 L .45551 .61122 L F
.773 .679 .76 r
.62093 .44829 m .62279 .45168 L .61867 .45076 L F
.971 .807 .622 r
.62279 .45168 m .62078 .4529 L .61867 .45076 L F
.62279 .45168 m .62219 .45407 L .62078 .4529 L F
.777 .68 .757 r
.62457 .44865 m .62279 .45168 L .62093 .44829 L F
.298 0 .076 r
.62703 .41067 m .62504 .41004 L .62725 .40902 L F
.62703 .41067 m .62425 .41166 L .62504 .41004 L F
.758 .993 .876 r
.51585 .52613 m .51204 .52839 L .51327 .52664 L F
.82 .994 .86 r
.51628 .52451 m .51585 .52613 L .51327 .52664 L F
.326 .737 .979 r
.18177 .63939 m .18142 .64036 L .17961 .64006 L F
.18177 .63939 m .18412 .64035 L .18142 .64036 L F
.3 0 .181 r
.74988 .4375 m .74779 .43853 L .74804 .43711 L F
.635 .664 .861 r
.71954 .39595 m .71826 .39856 L .71715 .3966 L F
.71954 .39595 m .7208 .39773 L .71826 .39856 L F
.35 .204 .537 r
.26368 .5865 m .26188 .58482 L .2639 .58416 L F
.26368 .5865 m .26182 .58734 L .26188 .58482 L F
.307 .628 .961 r
.18598 .64151 m .18416 .6421 L .18412 .64035 L F
.18598 .64151 m .18737 .64294 L .18416 .6421 L F
.65 .473 .632 r
.55859 .54341 m .55866 .54588 L .55625 .54627 L F
.576 .355 .544 r
.55859 .54341 m .56096 .54526 L .55866 .54588 L F
.55859 .54341 m .56102 .54294 L .56096 .54526 L F
.857 .919 .871 r
.55407 .50581 m .55212 .5058 L .55303 .5066 L F
.852 .922 .877 r
.55448 .5032 m .55407 .50581 L .55557 .50416 L F
.55448 .5032 m .55212 .5058 L .55407 .50581 L F
.317 .805 .792 r
.4522 .56937 m .45006 .57006 L .45224 .56932 L F
.501 .226 .429 r
.44946 .57168 m .45224 .56932 L .45006 .57006 L F
.763 .64 .725 r
.45224 .56932 m .44946 .57168 L .45006 .57006 L F
.612 .738 .935 r
.71594 .39441 m .71475 .39727 L .71346 .39502 L F
.71594 .39441 m .71715 .3966 L .71475 .39727 L F
.605 .741 .941 r
.70754 .4062 m .70883 .40345 L .70641 .40458 L F
.70754 .4062 m .70998 .40554 L .70883 .40345 L F
.688 .951 .687 r
.54042 .49966 m .53933 .50138 L .53922 .50097 L F
.54042 .49966 m .54218 .49852 L .53933 .50138 L F
.499 .427 .706 r
.55234 .57499 m .5531 .57936 L .55041 .57877 L F
.691 .569 .712 r
.5531 .57936 m .55106 .58141 L .55042 .57877 L F
.788 .703 .771 r
.5486 .5825 m .55063 .57911 L .54898 .58123 L F
.54887 .58142 m .54898 .58123 L .54889 .58135 L F
.5486 .5825 m .54898 .58123 L .54887 .58142 L F
.691 .569 .712 r
.55042 .57877 m .55042 .57877 L .55041 .57877 L F
.5531 .57936 m .55042 .57877 L .55042 .57877 L F
.924 .975 .724 r
.60593 .48075 m .60328 .48386 L .60453 .48163 L F
.909 .968 .658 r
.60733 .47683 m .60593 .48075 L .60604 .48045 L F
.567 .9 .658 r
.60604 .48045 m .60593 .48075 L .60453 .48163 L F
.799 .541 .547 r
.4779 .57443 m .48149 .57284 L .47792 .5723 L F
.4779 .57443 m .48059 .57544 L .48149 .57284 L F
.083 0 .227 r
.48149 .57284 m .48059 .57544 L .48275 .57381 L F
.47 .169 .372 r
.53965 .58432 m .54235 .58397 L .54096 .58336 L F
.862 .731 .717 r
.54096 .58336 m .53928 .58652 L .53965 .58432 L F
.733 .622 .734 r
.55227 .51876 m .55384 .52263 L .55616 .51949 L F
.569 .398 .609 r
.55384 .52263 m .55619 .52214 L .55616 .51949 L F
.617 .401 .567 r
.5537 .52483 m .55619 .52214 L .55384 .52263 L F
.559 .922 .947 r
.67951 .45252 m .6778 .45403 L .68011 .45319 L F
.67951 .45252 m .6778 .45403 L .68011 .45319 L F
.789 .715 .782 r
.53827 .68903 m .53703 .68529 L .53605 .68802 L F
0 0 0 r
.23158 .5927 m .23323 .59226 L .23535 .5907 L F
.328 .383 .767 r
.23432 .58731 m .23535 .5907 L .23654 .5896 L F
.12 0 0 r
.23535 .5907 m .23545 .59169 L .23654 .5896 L F
.23535 .5907 m .23323 .59226 L .23545 .59169 L F
.268 .725 .954 r
.21744 .54054 m .21946 .54047 L .22123 .54117 L F
0 .547 .741 r
.21946 .54047 m .22336 .54086 L .22123 .54117 L F
.618 .726 .923 r
.68824 .46032 m .68905 .46261 L .69083 .46179 L F
.27 0 .277 r
.37231 .59914 m .37495 .59625 L .3725 .59656 L F
.895 .781 .728 r
.74853 .42778 m .74605 .42752 L .74761 .42594 L F
.74853 .42778 m .74672 .4306 L .74605 .42752 L F
.632 .383 .523 r
.57971 .5287 m .57962 .53081 L .57687 .53103 L F
.577 .374 .569 r
.58255 .52829 m .57962 .53081 L .57971 .5287 L F
.722 .611 .733 r
.40966 .59917 m .40672 .60174 L .40729 .60002 L F
.418 0 0 r
.20458 .55346 m .20004 .55344 L .20206 .55237 L F
.212 0 .33 r
.59943 .51209 m .59822 .51105 L .5999 .50992 L F
.562 .411 .633 r
.45551 .61122 m .45772 .60797 L .45532 .60847 L F
.45551 .61122 m .45772 .60797 L .45532 .60847 L F
.934 .855 .74 r
.62795 .4653 m .63076 .46353 L .62936 .46222 L F
.62795 .4653 m .62967 .46625 L .63076 .46353 L F
.758 .851 .92 r
.73807 .4229 m .74211 .42271 L .74068 .42223 L F
.293 .791 .839 r
.74462 .42167 m .74068 .42223 L .74211 .42271 L F
.984 .888 .546 r
.65 .43941 m .65074 .43695 L .65033 .4348 L F
.242 .271 .692 r
.26702 .56 m .2658 .56187 L .26494 .55829 L F
.758 .881 .465 r
.75467 .41265 m .75389 .41337 L .75387 .41136 L F
.75467 .41265 m .75309 .41553 L .75389 .41337 L F
.825 .945 .902 r
.75467 .41265 m .75695 .40864 L .75771 .40973 L F
.75467 .41265 m .75387 .41136 L .75695 .40864 L F
0 0 0 r
.54354 .4971 m .54403 .49514 L .54218 .49852 L F
.54354 .4971 m .54412 .49504 L .54403 .49514 L F
.766 .926 .94 r
.42306 .59781 m .42257 .59994 L .42364 .59835 L F
.607 .432 .619 r
.55616 .51949 m .55873 .51897 L .55862 .51652 L F
.588 .393 .585 r
.55873 .51897 m .56118 .51606 L .55862 .51652 L F
.335 .162 .492 r
.24312 .62192 m .24177 .62032 L .24374 .61957 L F
.24312 .62192 m .24156 .62278 L .24177 .62032 L F
.397 0 0 r
.42077 .63462 m .42272 .63508 L .42406 .63495 L F
.641 .231 .251 r
.42272 .63508 m .42644 .63476 L .42406 .63495 L F
.847 .641 .624 r
.21792 .60181 m .21974 .60533 L .22022 .60265 L F
.756 .55 .618 r
.22022 .60265 m .21974 .60533 L .22298 .60544 L F
.489 .259 .492 r
.26778 .55534 m .26787 .55888 L .26494 .55829 L F
.586 .65 .88 r
.26982 .55453 m .26778 .55534 L .26584 .55298 L F
.855 .552 .475 r
.2671 .55793 m .26787 .55888 L .26778 .55534 L F
.2671 .55793 m .26778 .55534 L .26982 .55453 L F
.231 .098 .484 r
.2116 .62325 m .21292 .62506 L .21296 .62257 L F
.194 .088 .498 r
.21159 .62581 m .21292 .62506 L .2116 .62325 L F
.27 .264 .669 r
.48781 .58771 m .48962 .58729 L .48883 .58373 L F
.202 .029 .41 r
.48781 .58771 m .48933 .5886 L .48962 .58729 L F
.626 .101 0 r
.74049 .43078 m .7433 .43241 L .7397 .43176 L F
.642 .174 .126 r
.74369 .43145 m .7433 .43241 L .74049 .43078 L F
.77 .702 .788 r
.62353 .44537 m .62457 .44865 L .62093 .44829 L F
.676 .288 .304 r
.56693 .51832 m .5681 .5164 L .56452 .51633 L F
.758 .388 .353 r
.56693 .51832 m .57065 .51895 L .5681 .5164 L F
.654 .422 .555 r
.5681 .5164 m .57065 .51895 L .57065 .51641 L F
.012 .243 .749 r
.3749 .62401 m .3764 .62207 L .37428 .62216 L F
.3749 .62401 m .37684 .62449 L .3764 .62207 L F
.3749 .62401 m .37728 .62645 L .37684 .62449 L F
.846 .992 .736 r
.60331 .44012 m .60174 .44287 L .60401 .43993 L F
.204 .005 .373 r
.60541 .43791 m .60401 .43993 L .60527 .43832 L F
.60541 .43791 m .60331 .44012 L .60401 .43993 L F
.642 .142 .047 r
.40497 .64501 m .39908 .64346 L .40123 .64455 L F
.169 .341 .793 r
.54829 .57693 m .54889 .58135 L .55063 .57911 L F
.558 .896 .655 r
.54042 .49966 m .54354 .4971 L .54218 .49852 L F
.541 .342 .559 r
.56865 .53439 m .56862 .53708 L .56617 .5375 L F
.576 .385 .586 r
.5706 .53395 m .56862 .53708 L .56865 .53439 L F
.368 .121 .402 r
.65444 .41039 m .6557 .40753 L .65386 .41001 L F
.932 .771 .66 r
.65413 .40579 m .6557 .40753 L .65444 .41039 L F
.745 .781 .882 r
.65784 .40599 m .6557 .40753 L .65413 .40579 L F
.932 .771 .66 r
.65413 .40579 m .6557 .40753 L .65444 .41039 L F
.614 .437 .62 r
.55619 .52214 m .55873 .51897 L .55616 .51949 L F
.75 .231 0 r
.63992 .42378 m .64263 .42544 L .64379 .42682 L F
.676 .618 .783 r
.75382 .43347 m .75573 .42897 L .75278 .42993 L F
.276 0 .122 r
.75573 .42897 m .75342 .43155 L .75278 .42993 L F
.54 .657 .912 r
.75342 .43155 m .75186 .4309 L .75278 .42993 L F
.481 .048 .139 r
.75186 .4309 m .75573 .42897 L .75278 .42993 L F
.801 .97 .909 r
.71933 .45045 m .71744 .45333 L .72049 .45151 L F
.71933 .45045 m .71648 .45276 L .71744 .45333 L F
.525 .368 .611 r
.42048 .58791 m .41974 .59014 L .41744 .59067 L F
.506 .31 .55 r
.41974 .59014 m .41736 .59315 L .41744 .59067 L F
.616 .783 .962 r
.42003 .60706 m .42132 .60845 L .41883 .60797 L F
.662 .167 .064 r
.42132 .60845 m .41926 .60944 L .41883 .60797 L F
.64 .793 .956 r
.42377 .60747 m .42132 .60845 L .42003 .60706 L F
.42377 .60747 m .42003 .60706 L .42231 .60673 L F
.721 .98 .769 r
.42231 .60673 m .42132 .60845 L .42377 .60747 L F
.42231 .60673 m .41926 .60944 L .42132 .60845 L F
.87 .824 .8 r
.6636 .4324 m .6659 .4337 L .66741 .43071 L F
.943 .713 .56 r
.66503 .43602 m .6659 .4337 L .6636 .4324 L F
.633 .779 .951 r
.72927 .39674 m .73045 .39814 L .72689 .39752 L F
.671 .776 .928 r
.73282 .39435 m .73045 .39814 L .72927 .39674 L F
.73282 .39435 m .73293 .39744 L .73045 .39814 L F
.885 .736 .227 r
.65956 .42238 m .65984 .42474 L .65965 .42723 L F
.742 .596 .694 r
.76003 .43338 m .75648 .43337 L .75869 .43059 L F
.688 .474 .591 r
.75994 .43509 m .75648 .43337 L .76003 .43338 L F
.535 .207 .359 r
.76258 .43343 m .75994 .43509 L .76003 .43338 L F
.397 .126 .382 r
.60345 .44423 m .60174 .44287 L .60331 .44012 L F
.60345 .44423 m .60116 .44528 L .60174 .44287 L F
0 0 0 r
.21533 .61153 m .21435 .61373 L .21647 .6101 L F
.81 .582 .592 r
.43607 .64011 m .43988 .63787 L .43651 .63827 L F
.43607 .64011 m .44004 .64115 L .43988 .63787 L F
.66 .465 .609 r
.43988 .63787 m .44004 .64115 L .44353 .64028 L F
.489 .26 .494 r
.26787 .55888 m .26702 .56 L .26494 .55829 L F
0 0 0 r
.19961 .68773 m .19635 .69165 L .19841 .68879 L F
.86 .779 .77 r
.43898 .56139 m .43517 .56313 L .43754 .5614 L F
.673 .907 .977 r
.44126 .56038 m .43898 .56139 L .4398 .55959 L F
.027 0 0 r
.43898 .56139 m .4396 .56144 L .4398 .55959 L F
.43898 .56139 m .43754 .5614 L .4396 .56144 L F
.721 .369 .381 r
.20909 .55476 m .20749 .55693 L .20647 .55497 L F
.722 .371 .383 r
.21134 .55717 m .20909 .55476 L .21141 .55471 L F
.21134 .55717 m .20749 .55693 L .20909 .55476 L F
.658 .639 .82 r
.74605 .42752 m .74369 .43145 L .74299 .42878 L F
.74605 .42752 m .74672 .4306 L .74369 .43145 L F
.142 0 .233 r
.59242 .51881 m .59306 .51689 L .59479 .51576 L F
0 0 .239 r
.65884 .44862 m .65969 .44929 L .6599 .44673 L F
.65884 .44862 m .6584 .4513 L .65969 .44929 L F
.676 .758 .913 r
.6139 .45664 m .61005 .45613 L .61233 .45501 L F
.2 .168 .595 r
.61484 .45298 m .6139 .45664 L .61233 .45501 L F
.213 .169 .59 r
.61514 .45792 m .61531 .45788 L .6139 .45664 L F
.2 .168 .595 r
.61484 .45298 m .61514 .45792 L .6139 .45664 L F
.542 .132 .214 r
.6139 .45664 m .61531 .45788 L .61253 .45813 L F
.852 .709 .704 r
.66569 .42702 m .66804 .42727 L .66747 .42421 L F
.883 .73 .687 r
.66534 .42955 m .66804 .42727 L .66569 .42702 L F
.66534 .42955 m .66741 .43071 L .66804 .42727 L F
.764 .655 .741 r
.66747 .42421 m .66804 .42727 L .66934 .4236 L F
.608 .616 .834 r
.7433 .43241 m .74362 .43631 L .74051 .43328 L F
.7433 .43241 m .74544 .43552 L .74362 .43631 L F
.828 .94 .899 r
.66254 .44147 m .66341 .44232 L .66584 .44024 L F
.92 .579 .377 r
.66216 .44387 m .66341 .44232 L .66254 .44147 L F
.66216 .44387 m .66381 .44483 L .66341 .44232 L F
.349 .151 .464 r
.26621 .58087 m .2639 .58416 L .26414 .58173 L F
.5 .314 .561 r
.42597 .59036 m .42346 .59318 L .42331 .59071 L F
.997 .799 .516 r
.43122 .63387 m .43231 .63494 L .43271 .63208 L F
.471 .449 .752 r
.24001 .56979 m .24106 .5659 L .23921 .56646 L F
.24001 .56979 m .24178 .56927 L .24106 .5659 L F
.347 .266 .621 r
.24001 .56979 m .24198 .57176 L .24178 .56927 L F
.24001 .56979 m .24 .5739 L .24198 .57176 L F
.401 .855 .812 r
.51293 .54498 m .51373 .54435 L .51558 .54372 L F
.51293 .54498 m .51138 .54533 L .51373 .54435 L F
.141 0 0 r
.18928 .54236 m .1915 .54193 L .19331 .54063 L F
0 0 0 r
.19331 .54063 m .19347 .54086 L .19521 .54065 L F
.19331 .54063 m .1915 .54193 L .19347 .54086 L F
.814 .71 .75 r
.75869 .43059 m .75573 .42897 L .75536 .4309 L F
.866 .921 .863 r
.55698 .50043 m .55557 .50416 L .55803 .50115 L F
.824 .969 .895 r
.55999 .49776 m .55803 .50115 L .56074 .49861 L F
.55999 .49776 m .55698 .50043 L .55803 .50115 L F
.795 .975 .687 r
.42598 .5865 m .42584 .58754 L .42829 .58462 L F
.928 .86 .753 r
.62814 .46873 m .62967 .46625 L .62795 .4653 L F
.155 .501 .909 r
.24747 .54364 m .24747 .54503 L .24518 .5435 L F
.24747 .54364 m .24896 .54532 L .24747 .54503 L F
.874 .932 .857 r
.633 .45039 m .63652 .44849 L .63497 .44725 L F
.844 .8 .808 r
.63497 .44725 m .63652 .44849 L .63887 .44544 L F
.442 .45 .772 r
.26392 .56744 m .26657 .56885 L .26471 .56914 L F
.891 .893 .824 r
.54766 .52215 m .55003 .51947 L .54873 .51842 L F
.509 .484 .765 r
.44774 .60262 m .44894 .59867 L .447 .59898 L F
.44774 .60262 m .44986 .60211 L .44894 .59867 L F
.48 .37 .652 r
.44774 .60262 m .45023 .60456 L .44986 .60211 L F
.713 .759 .888 r
.63417 .43932 m .63133 .44144 L .63036 .43874 L F
.916 .831 .747 r
.5492 .51377 m .55095 .51041 L .54959 .50926 L F
.894 .841 .785 r
.54959 .50926 m .55095 .51041 L .55303 .5066 L F
.485 .828 .998 r
.46222 .56984 m .46057 .56899 L .4584 .5695 L F
.478 .824 .998 r
.46475 .56929 m .46057 .56899 L .46222 .56984 L F
.233 .285 .711 r
.46222 .56984 m .46446 .57181 L .46475 .56929 L F
.994 .763 .404 r
.6722 .41351 m .67167 .4138 L .6728 .41246 L F
.405 .675 .971 r
.67303 .41461 m .67129 .414 L .67167 .4138 L F
0 .299 .692 r
.67167 .4138 m .67468 .41544 L .67303 .41461 L F
.83 .702 .723 r
.67272 .41825 m .67468 .41544 L .67167 .4138 L F
.67272 .41825 m .67167 .4138 L .6716 .41714 L F
.994 .763 .404 r
.67067 .41617 m .6716 .41714 L .67167 .4138 L F
.67067 .41617 m .67167 .4138 L .6722 .41351 L F
.405 .675 .971 r
.67129 .414 m .6686 .41307 L .67167 .4138 L F
.655 .18 .112 r
.42672 .64663 m .42525 .64792 L .42324 .64627 L F
.549 .069 .068 r
.4291 .64686 m .42525 .64792 L .42672 .64663 L F
.441 0 0 r
.44259 .56459 m .44116 .56572 L .43873 .56558 L F
.686 .596 .749 r
.44479 .56199 m .44259 .56459 L .44126 .56038 L F
.308 0 0 r
.44565 .56465 m .44259 .56459 L .44472 .5647 L F
.44565 .56465 m .44116 .56572 L .44259 .56459 L F
.603 .305 .435 r
.22028 .55223 m .22009 .55443 L .21769 .55455 L F
.317 .072 .375 r
.22236 .55279 m .22009 .55443 L .22028 .55223 L F
.647 .749 .924 r
.72444 .39855 m .7208 .39773 L .72326 .39674 L F
.682 .73 .887 r
.72326 .39674 m .72689 .39752 L .72444 .39855 L F
.619 .676 .882 r
.71717 .40778 m .71979 .40683 L .71613 .40583 L F
.782 .51 .525 r
.53521 .59362 m .53524 .59596 L .5316 .59543 L F
.667 .524 .68 r
.53761 .59298 m .53524 .59596 L .53521 .59362 L F
.454 .258 .524 r
.59004 .52178 m .58778 .52254 L .59007 .51941 L F
.387 .117 .377 r
.58761 .52421 m .58778 .52254 L .59004 .52178 L F
.894 .841 .785 r
.54959 .50926 m .55303 .5066 L .55212 .5058 L F
.673 .874 .974 r
.19295 .66011 m .19515 .65996 L .19327 .65977 L F
.797 .543 .553 r
.19723 .65912 m .19327 .65977 L .19515 .65996 L F
.19723 .65912 m .19695 .66108 L .19327 .65977 L F
.167 .618 .936 r
.19327 .65977 m .19695 .66108 L .19366 .65936 L F
.19327 .65977 m .19366 .65936 L .19269 .65885 L F
.673 .874 .974 r
.19112 .66024 m .19295 .66011 L .19327 .65977 L F
.839 .804 .817 r
.69388 .45952 m .69682 .45984 L .69642 .45661 L F
.817 .831 .86 r
.69409 .46173 m .69682 .45984 L .69388 .45952 L F
.827 .797 .823 r
.69682 .45984 m .6999 .45657 L .69642 .45661 L F
.611 .849 .989 r
.70914 .45376 m .71225 .45489 L .71079 .45357 L F
.626 .833 .98 r
.71079 .45357 m .71225 .45489 L .71447 .45399 L F
.357 .714 .986 r
.2847 .78511 m .28685 .78647 L .28411 .78622 L F
.28411 .78622 m .28685 .78647 L .2847 .78511 L F
.361 .188 .508 r
.43191 .57935 m .43092 .58186 L .43287 .58107 L F
.979 .772 .556 r
.5089 .55429 m .51004 .558 L .50949 .55694 L F
.709 .229 0 r
.51004 .558 m .51034 .55905 L .50949 .55694 L F
.51004 .558 m .51128 .55981 L .51034 .55905 L F
.977 .727 .492 r
.51034 .55905 m .50897 .55562 L .50949 .55694 L F
.51034 .55905 m .50888 .55825 L .50897 .55562 L F
0 .35 .824 r
.51034 .55905 m .51093 .55835 L .50937 .55827 L F
.51034 .55905 m .50937 .55827 L .50888 .55825 L F
.709 .229 0 r
.51128 .55981 m .5115 .56012 L .51034 .55905 L F
.436 .451 .777 r
.26584 .56798 m .26657 .56885 L .26392 .56744 L F
.804 .74 .793 r
.63685 .44413 m .63887 .44544 L .63806 .44231 L F
.844 .8 .808 r
.63497 .44725 m .63887 .44544 L .63685 .44413 L F
.806 .742 .792 r
.63806 .44231 m .63887 .44544 L .64125 .44246 L F
.482 .18 .377 r
.56617 .5375 m .56843 .53891 L .56599 .53946 L F
.56617 .5375 m .56862 .53708 L .56843 .53891 L F
.632 .286 .367 r
.17546 .55834 m .17549 .56042 L .1716 .56029 L F
.753 .386 .36 r
.17758 .56045 m .17546 .55834 L .1782 .55822 L F
.597 .302 .438 r
.17589 .55839 m .1782 .55822 L .17546 .55834 L F
.753 .386 .36 r
.17758 .56045 m .17549 .56042 L .17546 .55834 L F
.758 .773 .865 r
.45413 .58222 m .4562 .58468 L .4528 .58504 L F
.38 .616 .943 r
.45715 .58316 m .4562 .58468 L .45413 .58222 L F
.437 .263 .545 r
.45715 .58316 m .45527 .58456 L .4562 .58468 L F
.45715 .58316 m .45703 .5842 L .45527 .58456 L F
.263 .769 .854 r
.45312 .58501 m .4562 .58468 L .45527 .58456 L F
.437 .263 .545 r
.45703 .5842 m .45684 .5859 L .45527 .58456 L F
.263 .769 .854 r
.4528 .58504 m .45312 .58501 L .45527 .58456 L F
0 0 .195 r
.402 .62586 m .40205 .6282 L .40129 .62903 L F
0 .035 .6 r
.40205 .6282 m .40286 .6311 L .40129 .62903 L F
.806 .879 .899 r
.71485 .44425 m .71352 .44586 L .71218 .44436 L F
.776 .597 .657 r
.73555 .42636 m .73766 .42831 L .73892 .42763 L F
.681 .436 .545 r
.45224 .56932 m .45628 .57023 L .45306 .56711 L F
.108 .398 .852 r
.23164 .55703 m .23203 .55602 L .22983 .5565 L F
.23164 .55703 m .23322 .55786 L .23203 .55602 L F
.571 .736 .954 r
.71248 .40476 m .71366 .40638 L .71613 .40583 L F
.549 .887 .638 r
.41966 .57285 m .42069 .57174 L .42244 .57052 L F
.498 .872 .979 r
.41966 .57285 m .41838 .57234 L .42069 .57174 L F
.032 0 0 r
.63476 .41278 m .6365 .41219 L .63888 .41106 L F
.382 .315 .657 r
.6365 .41219 m .63733 .41335 L .63476 .41278 L F
.987 .713 .393 r
.63104 .40199 m .6323 .40318 L .63217 .40092 L F
.789 .715 .782 r
.53827 .68903 m .5388 .68441 L .53703 .68529 L F
.8 .843 .883 r
.69642 .45661 m .6999 .45657 L .69867 .45486 L F
.574 .753 .962 r
.69867 .45486 m .6999 .45657 L .70232 .45587 L F
.612 .353 .501 r
.55625 .54627 m .55845 .54811 L .55602 .54885 L F
.55625 .54627 m .55866 .54588 L .55845 .54811 L F
0 0 0 r
.54412 .49504 m .54565 .49385 L .547 .49256 L F
.552 .858 .552 r
.547 .49256 m .54834 .49108 L .5497 .48986 L F
.544 .846 .529 r
.547 .49256 m .54565 .49385 L .54834 .49108 L F
.829 .906 .892 r
.21601 .56239 m .21296 .56078 L .21553 .55996 L F
.21601 .56239 m .21329 .5631 L .21296 .56078 L F
0 0 .196 r
.21777 .55974 m .21601 .56239 L .21553 .55996 L F
.21777 .55974 m .21743 .56261 L .21601 .56239 L F
.697 .819 .94 r
.74988 .41794 m .74658 .4179 L .74863 .41667 L F
.737 .989 .885 r
.75185 .41545 m .74988 .41794 L .74863 .41667 L F
.75185 .41545 m .75309 .41553 L .74988 .41794 L F
.631 .43 .592 r
.75648 .43337 m .75418 .43531 L .75382 .43347 L F
.668 .92 .611 r
.19304 .67975 m .19367 .6786 L .19538 .67715 L F
.561 .87 .576 r
.19538 .67715 m .19486 .67737 L .19753 .67663 L F
.19538 .67715 m .19367 .6786 L .19486 .67737 L F
0 0 0 r
.59934 .43113 m .59837 .4328 L .60058 .42953 L F
0 0 .197 r
.66903 .39968 m .66975 .40338 L .66967 .40271 L F
.66903 .39968 m .66967 .40271 L .67111 .39964 L F
.783 .99 .888 r
.66948 .40131 m .66967 .40271 L .66727 .40309 L F
.6702 .40074 m .66967 .40271 L .66948 .40131 L F
0 0 .197 r
.66975 .40338 m .66985 .40387 L .66967 .40271 L F
.797 .769 .828 r
.69127 .44781 m .69232 .45074 L .68882 .45068 L F
.689 .713 .867 r
.69476 .44862 m .69232 .45074 L .69127 .44781 L F
.578 .823 .991 r
.69885 .39661 m .69519 .39594 L .69782 .39519 L F
.614 .833 .984 r
.70141 .3955 m .69885 .39661 L .69782 .39519 L F
.977 .902 .673 r
.45495 .64099 m .45572 .64119 L .45695 .63787 L F
0 0 .123 r
.45695 .63787 m .45696 .64015 L .45801 .63812 L F
.45695 .63787 m .45572 .64119 L .45696 .64015 L F
.676 .758 .269 r
.60599 .43649 m .60541 .43791 L .60527 .43832 L F
0 0 .04 r
.60808 .43311 m .60755 .43527 L .60599 .43649 L F
0 0 0 r
.60755 .43527 m .60541 .43791 L .60599 .43649 L F
.821 .483 .415 r
.51261 .5313 m .51071 .53237 L .51062 .53116 L F
.903 .65 .546 r
.51261 .5313 m .51263 .53404 L .51071 .53237 L F
0 0 0 r
.60335 .4246 m .60498 .42299 L .60598 .42182 L F
0 0 .191 r
.60259 .42663 m .60498 .42299 L .60335 .4246 L F
.493 .296 .542 r
.17483 .54545 m .17719 .54241 L .17589 .54355 L F
.445 .393 .705 r
.36943 .61115 m .37056 .60838 L .36871 .6089 L F
.36943 .61115 m .3713 .61066 L .37056 .60838 L F
.866 .921 .863 r
.55698 .50043 m .55448 .5032 L .55557 .50416 L F
.815 .706 .745 r
.63806 .44231 m .64125 .44246 L .64019 .43946 L F
.322 .476 .858 r
.24101 .56086 m .24181 .55889 L .2387 .55824 L F
.24101 .56086 m .24222 .56053 L .24181 .55889 L F
.288 .322 .723 r
.24101 .56086 m .24329 .56296 L .24222 .56053 L F
.483 .342 .613 r
.24114 .56356 m .24329 .56296 L .24101 .56086 L F
.408 .522 .862 r
.47134 .56312 m .47085 .56629 L .46964 .56434 L F
.47134 .56312 m .47277 .56618 L .47085 .56629 L F
.433 .504 .833 r
.47418 .56958 m .47085 .56629 L .47277 .56618 L F
.438 .876 .836 r
.18047 .55728 m .1842 .55612 L .18197 .55656 L F
.18047 .55728 m .17997 .55751 L .1842 .55612 L F
.072 0 0 r
.1842 .55612 m .18537 .55634 L .18197 .55656 L F
.534 .431 .683 r
.61236 .45145 m .61484 .45298 L .61465 .4506 L F
.481 .373 .654 r
.36871 .6089 m .37056 .60838 L .37055 .60482 L F
.868 .988 .832 r
.66934 .4236 m .67057 .42154 L .66747 .42421 L F
.732 .566 .667 r
.21974 .60533 m .223 .60788 L .22298 .60544 L F
.494 .344 .606 r
.22298 .60544 m .22498 .60732 L .22543 .60508 L F
.22298 .60544 m .223 .60788 L .22498 .60732 L F
.213 .091 .488 r
.54036 .59002 m .54245 .58736 L .54308 .58953 L F
.247 0 .28 r
.54096 .59036 m .54036 .59002 L .54203 .58972 L F
.213 .091 .488 r
.54036 .59002 m .54096 .59036 L .54245 .58736 L F
.842 .839 .843 r
.54245 .58736 m .54096 .59036 L .53877 .58892 L F
.213 .091 .488 r
.54036 .59002 m .54042 .59146 L .54096 .59036 L F
.247 0 .28 r
.54205 .59191 m .53993 .59262 L .54018 .59111 L F
.54077 .59048 m .54018 .59111 L .54036 .59002 L F
.842 .839 .843 r
.54096 .59036 m .54042 .59146 L .54019 .59111 L F
.54096 .59036 m .54019 .59111 L .54077 .59048 L F
.247 0 .28 r
.54205 .59191 m .54018 .59111 L .54077 .59048 L F
.842 .839 .843 r
.54077 .59048 m .54019 .59111 L .54006 .59091 L F
.54096 .59036 m .54006 .59091 L .53877 .58892 L F
.247 0 .28 r
.54237 .59118 m .54096 .59036 L .54308 .58953 L F
.54096 .59036 m .54203 .58972 L .54308 .58953 L F
.54205 .59191 m .54036 .59002 L .54237 .59118 L F
.618 .522 .723 r
.41743 .59359 m .41974 .59014 L .41736 .59315 L F
.41743 .59359 m .42176 .59375 L .41974 .59014 L F
.333 .392 .774 r
.53627 .57485 m .53597 .57765 L .53456 .57645 L F
.223 .73 .894 r
.23722 .55803 m .23573 .55772 L .23322 .55786 L F
.161 .533 .922 r
.23722 .55803 m .23756 .55691 L .23573 .55772 L F
.23722 .55803 m .2387 .55824 L .23756 .55691 L F
.67 .291 .319 r
.42991 .63958 m .43384 .63794 L .43057 .63841 L F
.42991 .63958 m .43238 .63996 L .43384 .63794 L F
.683 .307 .328 r
.43384 .63794 m .43238 .63996 L .43607 .64011 L F
.65 .32 .399 r
.43384 .63794 m .43607 .64011 L .43651 .63827 L F
.591 .677 .9 r
.73443 .3938 m .73593 .39866 L .73293 .39744 L F
.493 .42 .703 r
.55174 .55981 m .55235 .56343 L .5503 .56403 L F
.444 .336 .637 r
.55235 .56343 m .55078 .56654 L .5503 .56403 L F
.732 .762 .258 r
.20062 .68409 m .19961 .68773 L .20052 .68551 L F
.624 .299 .399 r
.45713 .59633 m .46018 .59735 L .46179 .59429 L F
.636 .312 .406 r
.46179 .59429 m .46429 .59557 L .46382 .5928 L F
.46179 .59429 m .46018 .59735 L .46429 .59557 L F
0 0 .136 r
.60046 .5079 m .60247 .50468 L .60182 .50668 L F
.002 0 .21 r
.5999 .50992 m .60046 .5079 L .60182 .50668 L F
.641 .826 .972 r
.19937 .55766 m .20327 .55795 L .20155 .55698 L F
.19937 .55766 m .20327 .55795 L .20155 .55698 L F
.492 .288 .531 r
.59004 .52178 m .59007 .51941 L .59242 .51881 L F
.848 .997 .77 r
.68011 .45319 m .68171 .4497 L .6827 .45052 L F
.68011 .45319 m .67951 .45252 L .68171 .4497 L F
.428 0 0 r
.68337 .45487 m .67951 .45252 L .68011 .45319 L F
.475 .316 .585 r
.24602 .61443 m .24594 .61669 L .24395 .61719 L F
.475 .269 .519 r
.24582 .61882 m .24395 .61719 L .24594 .61669 L F
.24582 .61882 m .24374 .61957 L .24395 .61719 L F
0 0 0 r
.42244 .57052 m .42307 .57086 L .42429 .56925 L F
.42244 .57052 m .42069 .57174 L .42307 .57086 L F
.557 .363 .573 r
.58129 .50751 m .5838 .50705 L .58375 .50459 L F
.576 .456 .679 r
.58375 .50459 m .58625 .50406 L .58585 .50099 L F
.482 .19 .394 r
.58572 .50609 m .58375 .50459 L .5838 .50705 L F
.58572 .50609 m .58625 .50406 L .58375 .50459 L F
.55 0 0 r
.67339 .39836 m .67454 .398 L .67117 .39713 L F
.044 .594 .831 r
.6761 .39782 m .67454 .398 L .67339 .39836 L F
.6761 .39782 m .67724 .39831 L .67454 .398 L F
.683 .827 .952 r
.69083 .46179 m .69409 .46173 L .69388 .45952 L F
.319 0 .051 r
.42944 .59092 m .42611 .59309 L .42597 .59036 L F
.42944 .59092 m .42817 .59269 L .42611 .59309 L F
.62 .205 .234 r
.43174 .59248 m .42817 .59269 L .42944 .59092 L F
.828 .94 .899 r
.66254 .44147 m .66584 .44024 L .66434 .43856 L F
.852 .801 .8 r
.66434 .43856 m .66584 .44024 L .66696 .43808 L F
.019 .589 .768 r
.22336 .54086 m .22549 .54097 L .22721 .5412 L F
0 .463 .696 r
.22549 .54097 m .22932 .54169 L .22721 .5412 L F
.789 .715 .782 r
.53827 .68903 m .54072 .6863 L .5388 .68441 L F
.678 .509 .65 r
.47207 .58042 m .47534 .58052 L .47489 .57761 L F
.738 .948 .636 r
.47567 .58019 m .47528 .58059 L .47539 .58079 L F
.47573 .58005 m .47534 .58052 L .47567 .58019 L F
.47534 .58052 m .47528 .58059 L .47567 .58019 L F
.647 .776 .942 r
.47307 .58046 m .47551 .58103 L .47539 .58079 L F
.287 .222 .608 r
.47445 .58143 m .47307 .58046 L .47539 .58079 L F
.47397 .58175 m .47373 .5814 L .47445 .58143 L F
.47373 .5814 m .47307 .58046 L .47445 .58143 L F
.738 .948 .636 r
.47531 .58064 m .47397 .58175 L .47539 .58079 L F
.398 0 0 r
.47485 .58101 m .47534 .58052 L .47207 .58042 L F
.738 .948 .636 r
.47514 .58032 m .47397 .58175 L .47531 .58064 L F
.647 .776 .942 r
.47551 .58103 m .47778 .58157 L .47539 .58079 L F
.033 .575 .844 r
.47539 .58079 m .47778 .58157 L .47841 .5814 L F
.3 .696 .976 r
.47539 .58079 m .47841 .5814 L .47785 .58089 L F
.398 0 0 r
.47485 .58101 m .47397 .58175 L .47739 .58058 L F
.47348 .58125 m .47397 .58175 L .47485 .58101 L F
.808 .632 .664 r
.47207 .58042 m .47217 .5831 L .46845 .58259 L F
.46852 .58227 m .46845 .58259 L .46801 .58253 L F
.47207 .58042 m .46845 .58259 L .46852 .58227 L F
.499 .096 .207 r
.46801 .58253 m .46996 .58186 L .47207 .58042 L F
.403 .097 .329 r
.47217 .5831 m .46925 .58556 L .46801 .58253 L F
.722 .554 .661 r
.46799 .58276 m .46801 .58253 L .46925 .58556 L F
.46799 .58276 m .46996 .58186 L .46801 .58253 L F
.581 .609 .846 r
.46784 .58282 m .46925 .58556 L .46687 .58602 L F
.46789 .58268 m .46799 .5829 L .46784 .58282 L F
.46799 .5829 m .46925 .58556 L .46784 .58282 L F
.719 .27 .183 r
.46853 .58626 m .4715 .58763 L .46777 .587 L F
.509 .347 .596 r
.47155 .58496 m .4715 .58763 L .46925 .58556 L F
.722 .554 .661 r
.46807 .58608 m .47155 .58496 L .4715 .58486 L F
.719 .27 .183 r
.46925 .58556 m .46952 .5858 L .46887 .58593 L F
.722 .554 .661 r
.46808 .58609 m .47155 .58496 L .46807 .58608 L F
.581 .609 .846 r
.46799 .58276 m .46925 .58556 L .46789 .58268 L F
.722 .554 .661 r
.46911 .58353 m .46996 .58186 L .46799 .58276 L F
.581 .609 .846 r
.46802 .58225 m .46925 .58556 L .46792 .58259 L F
.137 0 0 r
.46777 .587 m .46687 .58602 L .46925 .58556 L F
.722 .554 .661 r
.46776 .5862 m .46799 .58276 L .46925 .58556 L F
.46776 .5862 m .46925 .58556 L .46834 .58311 L F
.403 .097 .329 r
.47217 .5831 m .47155 .58496 L .46925 .58556 L F
.722 .554 .661 r
.46776 .5862 m .4715 .58486 L .46911 .58353 L F
.447 .881 .862 r
.46922 .58544 m .47155 .58496 L .46808 .58609 L F
.722 .554 .661 r
.46776 .5862 m .46808 .58609 L .46807 .58608 L F
.447 .881 .862 r
.46789 .58613 m .46808 .58609 L .46776 .5862 L F
.46922 .58544 m .46808 .58609 L .46789 .58613 L F
.719 .27 .183 r
.46887 .58593 m .47106 .58722 L .46853 .58626 L F
.46952 .5858 m .47106 .58722 L .46887 .58593 L F
.47106 .58722 m .4715 .58763 L .46853 .58626 L F
.722 .554 .661 r
.46911 .58353 m .4715 .58486 L .46996 .58186 L F
.46776 .5862 m .46828 .58295 L .46799 .58276 L F
.4678 .58558 m .46802 .58458 L .46802 .58225 L F
.46802 .58458 m .46834 .58311 L .46828 .58295 L F
.46802 .58458 m .46828 .58295 L .46802 .58225 L F
.46776 .5862 m .46834 .58311 L .4678 .58558 L F
.46776 .5862 m .46911 .58353 L .46828 .58295 L F
.581 .609 .846 r
.46792 .58259 m .46799 .58276 L .46789 .58268 L F
.287 .222 .608 r
.47287 .58136 m .47217 .5831 L .4721 .58108 L F
.398 0 0 r
.47286 .58136 m .47287 .58136 L .47083 .58127 L F
.287 .222 .608 r
.47373 .5814 m .47348 .58125 L .47307 .58046 L F
.398 0 0 r
.47287 .58136 m .47485 .58101 L .47269 .58115 L F
.47287 .58136 m .47269 .58115 L .47083 .58127 L F
.287 .222 .608 r
.47397 .58175 m .47351 .5821 L .47287 .58136 L F
.47351 .5821 m .47217 .5831 L .47287 .58136 L F
.398 0 0 r
.47287 .58136 m .47397 .58175 L .47348 .58125 L F
.287 .222 .608 r
.47287 .58136 m .4721 .58108 L .47207 .58042 L F
.398 0 0 r
.47083 .58127 m .47269 .58115 L .47207 .58042 L F
.47269 .58115 m .47325 .58112 L .47207 .58042 L F
.287 .222 .608 r
.47397 .58175 m .47287 .58136 L .47207 .58042 L F
.398 0 0 r
.46996 .58186 m .47397 .58175 L .47287 .58136 L F
.287 .222 .608 r
.47348 .58125 m .47207 .58042 L .47268 .58045 L F
.47348 .58125 m .47268 .58045 L .47307 .58046 L F
.47397 .58175 m .47207 .58042 L .47373 .5814 L F
.398 0 0 r
.47325 .58112 m .47485 .58101 L .47207 .58042 L F
.46996 .58186 m .47286 .58136 L .47083 .58127 L F
.738 .948 .636 r
.47758 .58058 m .47539 .58079 L .47785 .58089 L F
.678 .509 .65 r
.47573 .58005 m .47733 .58051 L .47633 .57932 L F
.738 .948 .636 r
.47621 .57901 m .47573 .58005 L .47758 .58058 L F
.47573 .58005 m .47539 .58079 L .47758 .58058 L F
.678 .509 .65 r
.47534 .58052 m .47739 .58058 L .47733 .58051 L F
.47534 .58052 m .47733 .58051 L .47573 .58005 L F
.398 0 0 r
.47485 .58101 m .47739 .58058 L .47534 .58052 L F
.678 .509 .65 r
.47534 .58052 m .47633 .57932 L .47489 .57761 L F
.266 .389 .801 r
.47489 .57761 m .47739 .58058 L .47668 .57686 L F
.738 .948 .636 r
.47621 .57901 m .47514 .58032 L .47528 .58059 L F
.47621 .57901 m .47528 .58059 L .47573 .58005 L F
.515 .227 .414 r
.58585 .50099 m .58828 .50068 L .58864 .49866 L F
.456 .255 .517 r
.58828 .50068 m .59026 .4979 L .58864 .49866 L F
.369 .773 .984 r
.42257 .59994 m .42121 .59919 L .41798 .59937 L F
.766 .926 .94 r
.42306 .59781 m .42121 .59919 L .42257 .59994 L F
.408 .293 .61 r
.43092 .58186 m .43216 .58403 L .43287 .58107 L F
.43092 .58186 m .43216 .58403 L .43287 .58107 L F
.61 .843 .468 r
.6083 .41871 m .60598 .42182 L .60728 .41993 L F
.614 .849 .477 r
.60598 .42182 m .60498 .42299 L .60728 .41993 L F
.808 .855 .884 r
.71254 .44737 m .71083 .44898 L .70952 .44753 L F
.51 .408 .674 r
.55333 .55153 m .55392 .55452 L .55151 .55515 L F
.514 .423 .69 r
.55151 .55515 m .55392 .55452 L .55429 .55705 L F
.502 .425 .701 r
.55151 .55515 m .55429 .55705 L .55233 .5581 L F
.089 0 0 r
.19744 .54039 m .20145 .54053 L .1995 .54084 L F
.918 .861 .769 r
.59885 .45011 m .59742 .45051 L .5989 .44858 L F
0 0 .056 r
.59766 .45145 m .59742 .45051 L .59885 .45011 L F
0 0 0 r
.60142 .44764 m .59885 .45011 L .5989 .44858 L F
.60142 .44764 m .60083 .44924 L .59885 .45011 L F
.562 .278 .442 r
.60083 .44924 m .59766 .45145 L .59885 .45011 L F
.787 .715 .784 r
.54072 .6863 m .54182 .68433 L .5388 .68441 L F
.547 .332 .539 r
.58373 .50938 m .58129 .50751 L .58122 .50979 L F
.58373 .50938 m .5838 .50705 L .58129 .50751 L F
.631 .404 .555 r
.57065 .51895 m .57347 .51604 L .57065 .51641 L F
.048 0 0 r
.45385 .56511 m .45674 .56435 L .4543 .56461 L F
.82 .96 .63 r
.48512 .58328 m .48434 .58538 L .48648 .58426 L F
.864 .938 .868 r
.53785 .5289 m .53976 .52727 L .5379 .52686 L F
0 .555 .782 r
.5379 .52686 m .53976 .52727 L .54156 .52745 L F
0 .093 .572 r
.64651 .43636 m .6474 .43699 L .6449 .43519 L F
.64651 .43636 m .64878 .43823 L .6474 .43699 L F
.654 .825 .965 r
.69149 .40594 m .69291 .40347 L .69059 .40447 L F
.69149 .40594 m .69431 .40487 L .69291 .40347 L F
.385 .215 .525 r
.23921 .56646 m .24106 .5659 L .24114 .56356 L F
.425 .277 .576 r
.37055 .60482 m .37243 .60171 L .37046 .60232 L F
.363 .709 .986 r
.7514 .42362 m .75398 .42235 L .75424 .42169 L F
.691 .152 0 r
.75424 .42169 m .75398 .42235 L .75127 .42038 L F
.54 .88 .988 r
.25898 .82437 m .2617 .82484 L .26208 .82366 L F
.672 .974 .897 r
.26208 .82366 m .2617 .82484 L .26055 .82476 L F
.977 .893 .671 r
.63055 .45572 m .6323 .45458 L .63222 .4516 L F
.63055 .45572 m .63153 .45677 L .6323 .45458 L F
.23 .057 .428 r
.2132 .62002 m .21489 .6216 L .21482 .61874 L F
.2132 .62002 m .21296 .62257 L .21489 .6216 L F
.866 .64 .594 r
.21665 .5984 m .21914 .59658 L .21686 .59593 L F
.21665 .5984 m .21882 .59952 L .21914 .59658 L F
.066 .253 .745 r
.40291 .61892 m .40191 .62035 L .39997 .62013 L F
.40291 .61892 m .40403 .62226 L .40191 .62035 L F
.485 .246 .476 r
.23825 .57584 m .24047 .57543 L .24 .5739 L F
.374 .184 .49 r
.24 .5739 m .24184 .57488 L .24198 .57176 L F
.24 .5739 m .24047 .57543 L .24184 .57488 L F
0 0 .167 r
.65239 .4268 m .65206 .4238 L .65181 .4261 L F
.945 .804 .35 r
.65161 .42858 m .65239 .4268 L .65181 .4261 L F
.65161 .42858 m .65204 .43047 L .65239 .4268 L F
.87 .824 .8 r
.6636 .4324 m .66741 .43071 L .66534 .42955 L F
.335 .011 .258 r
.3775 .59379 m .37945 .59454 L .38076 .59307 L F
.3775 .59379 m .377 .59552 L .37945 .59454 L F
.087 .255 .74 r
.21534 .58127 m .21634 .58088 L .21501 .57781 L F
0 0 .443 r
.21534 .58127 m .21621 .58326 L .21634 .58088 L F
.609 .447 .637 r
.22703 .55525 m .22739 .5576 L .22983 .5565 L F
.564 .36 .562 r
.76542 .4304 m .76551 .43315 L .76258 .43343 L F
.309 .166 .518 r
.7672 .43137 m .76542 .4304 L .76688 .42892 L F
.7672 .43137 m .76551 .43315 L .76542 .4304 L F
.351 .825 .877 r
.18879 .68042 m .19122 .67976 L .19039 .68017 L F
.692 .393 .464 r
.18697 .68031 m .19122 .67976 L .18879 .68042 L F
.18697 .68031 m .18932 .68066 L .19122 .67976 L F
.607 .306 .433 r
.18932 .68066 m .19167 .67955 L .19122 .67976 L F
.19167 .67955 m .19367 .6786 L .19122 .67976 L F
.351 .825 .877 r
.19039 .68017 m .19122 .67976 L .19304 .67975 L F
.605 .945 .93 r
.19304 .67975 m .19122 .67976 L .19367 .6786 L F
.533 .294 .499 r
.5854 .52414 m .58641 .52787 L .58472 .52763 L F
.5854 .52414 m .58761 .52421 L .58641 .52787 L F
.778 .649 .72 r
.4123 .59907 m .41014 .60214 L .40966 .59917 L F
0 0 .253 r
.47841 .63067 m .47946 .62789 L .47817 .62875 L F
.47841 .63067 m .47916 .63113 L .47946 .62789 L F
.704 .877 .483 r
.6083 .41871 m .60728 .41993 L .6093 .41671 L F
.124 0 .42 r
.61195 .42861 m .60984 .43191 L .61072 .43043 L F
.993 .87 .597 r
.62076 .42353 m .62244 .42105 L .62009 .42176 L F
.62076 .42353 m .62179 .42441 L .62244 .42105 L F
.268 0 .19 r
.60993 .43426 m .60808 .43311 L .60984 .43191 L F
.60993 .43426 m .60755 .43527 L .60808 .43311 L F
.322 0 0 r
.16231 .54753 m .16465 .54749 L .16666 .54639 L F
.342 0 0 r
.16465 .54749 m .16869 .546 L .16666 .54639 L F
0 .43 .83 r
.48666 .57099 m .48855 .57164 L .48794 .57189 L F
.474 .39 .68 r
.65162 .40595 m .65153 .40925 L .6495 .40951 L F
.239 .465 .876 r
.65266 .41214 m .6495 .40951 L .65153 .40925 L F
0 0 0 r
.55112 .48624 m .55332 .48526 L .55437 .48372 L F
.058 0 .186 r
.55112 .48624 m .55277 .48687 L .55332 .48526 L F
.55112 .48624 m .55102 .48851 L .55277 .48687 L F
0 0 0 r
.4046 .62448 m .40283 .6251 L .40587 .62324 L F
.665 .244 .235 r
.40587 .62324 m .4079 .62509 L .4046 .62448 L F
.533 0 0 r
.40403 .62226 m .40804 .62266 L .40587 .62324 L F
.507 .291 .52 r
.40804 .62266 m .4079 .62509 L .40587 .62324 L F
0 0 0 r
.55437 .48372 m .55578 .48225 L .55644 .48043 L F
.716 .982 .788 r
.55939 .47786 m .55644 .48043 L .55768 .47845 L F
0 0 0 r
.55644 .48043 m .55578 .48225 L .55768 .47845 L F
.66 .111 0 r
.21445 .56665 m .21449 .56764 L .21352 .5651 L F
.21445 .56665 m .21657 .56873 L .21449 .56764 L F
.843 .882 .869 r
.7507 .39546 m .74846 .39828 L .74742 .39683 L F
.267 .594 .949 r
.74742 .39683 m .74846 .39828 L .75216 .39899 L F
.449 .251 .519 r
.25296 .60227 m .2527 .60478 L .25067 .60533 L F
.364 .222 .552 r
.25244 .60696 m .25067 .60533 L .2527 .60478 L F
.25244 .60696 m .24997 .608 L .25067 .60533 L F
.631 .43 .592 r
.75648 .43337 m .75662 .43599 L .75418 .43531 L F
.688 .474 .591 r
.75994 .43509 m .75662 .43599 L .75648 .43337 L F
.755 .451 .47 r
.54619 .52405 m .54766 .52215 L .54596 .5214 L F
.54619 .52405 m .54897 .52383 L .54766 .52215 L F
.891 .893 .824 r
.54766 .52215 m .54873 .51842 L .54596 .5214 L F
.773 .687 .768 r
.41423 .63737 m .41662 .63432 L .41451 .63497 L F
.878 .89 .837 r
.50569 .543 m .50756 .53883 L .50475 .53992 L F
.749 .976 .719 r
.50665 .53962 m .50418 .54217 L .50508 .54042 L F
.551 .004 0 r
.50508 .54042 m .50549 .54047 L .50665 .53962 L F
.878 .89 .837 r
.50569 .543 m .50665 .53962 L .50748 .53902 L F
.50569 .543 m .50418 .54217 L .50665 .53962 L F
.551 .004 0 r
.50549 .54047 m .50867 .54087 L .50665 .53962 L F
.878 .89 .837 r
.50748 .53902 m .50665 .53962 L .50756 .53883 L F
.194 .137 .56 r
.50756 .53883 m .50932 .5357 L .50994 .53649 L F
.50756 .53883 m .50934 .53912 L .50932 .5357 L F
.995 .76 .46 r
.50867 .54087 m .50756 .53883 L .50665 .53962 L F
.50867 .54087 m .50934 .53912 L .50756 .53883 L F
.53 .418 .671 r
.40498 .61102 m .40264 .60702 L .404 .60723 L F
.40498 .61102 m .40234 .6127 L .40264 .60702 L F
.98 .903 .658 r
.41181 .59404 m .40989 .59459 L .41113 .59455 L F
.485 .848 .6 r
.41349 .59265 m .41181 .59404 L .41395 .59372 L F
.41349 .59265 m .41113 .59455 L .41181 .59404 L F
.41181 .59404 m .41113 .59455 L .41349 .59265 L F
0 0 0 r
.74137 .42922 m .7421 .42884 L .74299 .42878 L F
.353 0 .192 r
.38578 .59281 m .38803 .59225 L .38931 .58977 L F
.395 .003 .174 r
.38803 .59225 m .39167 .58961 L .38931 .58977 L F
.462 .081 .231 r
.38931 .58977 m .39167 .58961 L .39208 .5888 L F
.319 .169 .514 r
.4235 .5814 m .4232 .58485 L .42105 .58586 L F
.283 .773 .706 r
.19353 .64115 m .18933 .64262 L .19131 .64152 L F
.354 .829 .827 r
.1956 .64043 m .19353 .64115 L .19131 .64152 L F
.712 .795 .916 r
.68747 .44665 m .68868 .44818 L .68577 .4482 L F
.764 .647 .732 r
.68577 .4482 m .68632 .45157 L .68868 .44818 L F
.768 .515 .551 r
.6851 .44983 m .68868 .44818 L .68747 .44665 L F
.6851 .44983 m .68882 .45068 L .68868 .44818 L F
.481 .693 .961 r
.69007 .4464 m .68868 .44818 L .68747 .44665 L F
.476 .291 .551 r
.69127 .44781 m .68868 .44818 L .69007 .4464 L F
.69127 .44781 m .68882 .45068 L .68868 .44818 L F
.034 0 .187 r
.52889 .51239 m .52745 .51372 L .52663 .51564 L F
.567 .059 .005 r
.44923 .64527 m .44526 .64548 L .44734 .64396 L F
.38 .202 .51 r
.44968 .64327 m .44923 .64527 L .44734 .64396 L F
.588 .393 .585 r
.55873 .51897 m .56127 .51865 L .56118 .51606 L F
.628 .218 .245 r
.5638 .51763 m .56118 .51606 L .56127 .51865 L F
.5638 .51763 m .56452 .51633 L .56118 .51606 L F
.613 .058 0 r
.40473 .63409 m .40715 .63575 L .40823 .63517 L F
.583 .021 0 r
.40715 .63575 m .41047 .63663 L .40823 .63517 L F
.925 .882 .463 r
.73308 .40425 m .73403 .40295 L .73303 .4041 L F
.711 .957 .685 r
.73576 .40171 m .73707 .4009 L .73882 .3987 L F
.73576 .40171 m .73882 .3987 L .73801 .39866 L F
.73576 .40171 m .73801 .39866 L .73834 .40099 L F
.439 .03 .164 r
.73576 .40171 m .73834 .40099 L .73894 .40214 L F
.248 .603 .953 r
.73658 .40111 m .73576 .40171 L .73894 .40214 L F
.73511 .40047 m .73576 .40171 L .73658 .40111 L F
.424 .826 .62 r
.73403 .40295 m .73455 .4026 L .73576 .40171 L F
.73455 .4026 m .73707 .4009 L .73576 .40171 L F
0 0 0 r
.73303 .4041 m .73403 .40295 L .73576 .40171 L F
.745 .962 .937 r
.72166 .44937 m .72049 .45151 L .72227 .45011 L F
.672 .874 .975 r
.71933 .45045 m .72049 .45151 L .72166 .44937 L F
.257 0 .304 r
.58072 .45353 m .58344 .45262 L .58344 .45024 L F
.315 .068 .37 r
.58344 .45024 m .58597 .44993 L .58606 .44752 L F
.413 .161 .42 r
.58344 .45262 m .58597 .44993 L .58344 .45024 L F
.671 .869 .974 r
.73082 .44414 m .73301 .44173 L .72969 .44348 L F
.73082 .44414 m .73413 .44304 L .73301 .44173 L F
.879 .581 .478 r
.21685 .57709 m .21892 .57568 L .21549 .57452 L F
.21685 .57709 m .21911 .578 L .21892 .57568 L F
0 0 .566 r
.75337 .40068 m .7535 .3996 L .75216 .39899 L F
.535 .207 .359 r
.76258 .43343 m .76225 .43495 L .75994 .43509 L F
0 0 0 r
.76551 .43315 m .76225 .43495 L .76258 .43343 L F
.47 .882 .938 r
.47051 .57441 m .46944 .57546 L .47167 .57515 L F
.47051 .57441 m .46813 .57524 L .46944 .57546 L F
.057 .622 .764 r
.20145 .54053 m .20338 .54046 L .20554 .54058 L F
.263 .772 .826 r
.20338 .54046 m .20765 .53989 L .20554 .54058 L F
.723 .81 .918 r
.67669 .40904 m .67675 .41181 L .68004 .40942 L F
.475 .663 .944 r
.67675 .41181 m .67989 .41282 L .68004 .40942 L F
.745 .346 .294 r
.40698 .61441 m .40492 .61563 L .403 .61368 L F
.576 .62 .859 r
.40906 .6136 m .40698 .61441 L .40498 .61102 L F
.688 .628 .784 r
.40492 .61563 m .40906 .6136 L .40698 .61441 L F
.097 .638 .849 r
.19251 .68335 m .18857 .68284 L .19035 .68335 L F
.71 .915 .965 r
.17493 .56311 m .17658 .56376 L .17689 .56186 L F
.17493 .56311 m .17658 .56376 L .17689 .56186 L F
.49 .166 .344 r
.39167 .58961 m .39405 .58859 L .39208 .5888 L F
.46 .225 .469 r
.55845 .54811 m .55866 .54588 L .56096 .54526 L F
.848 .909 .877 r
.73027 .42854 m .73125 .42986 L .72784 .43055 L F
.761 .511 .556 r
.73125 .42986 m .72758 .43195 L .72784 .43055 L F
.73125 .42986 m .73109 .4326 L .72758 .43195 L F
.845 .698 .164 r
.73093 .43053 m .73125 .42986 L .73027 .42854 L F
.73093 .43053 m .73109 .4326 L .73125 .42986 L F
.674 .582 .744 r
.21707 .60554 m .21792 .60181 L .2159 .6025 L F
.21707 .60554 m .21974 .60533 L .21792 .60181 L F
.702 .54 .666 r
.21717 .60796 m .21974 .60533 L .21707 .60554 L F
.898 .709 .639 r
.21982 .58361 m .2201 .58715 L .22164 .58744 L F
.906 .683 .589 r
.22007 .58846 m .22164 .58744 L .2201 .58715 L F
.22007 .58846 m .22139 .58936 L .22164 .58744 L F
.53 .276 .474 r
.22703 .59893 m .22965 .59862 L .22989 .59618 L F
.342 .121 .426 r
.22989 .59618 m .23147 .59792 L .23188 .59524 L F
.22989 .59618 m .22965 .59862 L .23147 .59792 L F
.665 .869 .487 r
.72931 .43529 m .72883 .43585 L .73109 .4326 L F
.572 .381 .584 r
.22917 .63736 m .22941 .64268 L .2265 .6407 L F
.572 .399 .609 r
.2315 .63431 m .23196 .63736 L .22917 .63736 L F
.121 .042 .485 r
.23089 .63948 m .22917 .63736 L .23196 .63736 L F
.23089 .63948 m .22941 .64268 L .22917 .63736 L F
.484 .323 .586 r
.22488 .60199 m .22716 .60168 L .22703 .59893 L F
.41 .345 .674 r
.22488 .60199 m .22702 .60424 L .22716 .60168 L F
.22488 .60199 m .22543 .60508 L .22702 .60424 L F
.46 .185 .41 r
.73759 .42008 m .74027 .4174 L .7385 .41946 L F
.607 .779 .963 r
.69431 .40487 m .69761 .40557 L .69661 .40426 L F
.633 .832 .977 r
.69761 .40557 m .69915 .40333 L .69661 .40426 L F
.69761 .40557 m .70028 .4046 L .69915 .40333 L F
0 0 0 r
.61421 .42735 m .61307 .42732 L .61538 .42602 L F
.61421 .42735 m .61195 .42861 L .61307 .42732 L F
.485 .533 .831 r
.38563 .63293 m .38744 .63075 L .38495 .63142 L F
.38563 .63293 m .38918 .63435 L .38744 .63075 L F
.591 .677 .9 r
.73443 .3938 m .73293 .39744 L .73282 .39435 L F
.98 .913 .612 r
.5047 .58153 m .50289 .5833 L .50344 .58053 L F
.5047 .58153 m .50368 .58489 L .50289 .5833 L F
.53 .375 .615 r
.5047 .58153 m .50509 .58459 L .50368 .58489 L F
0 .131 .677 r
.50616 .58213 m .5047 .58153 L .50344 .58053 L F
.50616 .58213 m .50647 .58315 L .5047 .58153 L F
.303 .214 .586 r
.50647 .58315 m .50509 .58459 L .5047 .58153 L F
0 0 0 r
.40295 .58192 m .39998 .5841 L .40193 .583 L F
.40193 .583 m .40504 .5811 L .40295 .58192 L F
.675 .836 .961 r
.21553 .55996 m .21296 .56078 L .2119 .55938 L F
0 0 .174 r
.21296 .56078 m .21332 .56187 L .2119 .55938 L F
.21296 .56078 m .21329 .5631 L .21332 .56187 L F
.153 0 .259 r
.60182 .50668 m .60247 .50468 L .60421 .50332 L F
.705 .573 .705 r
.42607 .57733 m .4235 .5814 L .42401 .57849 L F
.367 .579 .923 r
.26155 .54935 m .26057 .55077 L .25818 .54857 L F
.26155 .54935 m .26246 .55088 L .26057 .55077 L F
.285 0 0 r
.16869 .546 m .17089 .54596 L .17266 .54481 L F
.29 .788 .853 r
.17089 .54596 m .17483 .54545 L .17266 .54481 L F
.222 0 .35 r
.26182 .58734 m .26128 .58975 L .25968 .59046 L F
.466 .225 .464 r
.26138 .59227 m .25968 .59046 L .26128 .58975 L F
.26138 .59227 m .25921 .59281 L .25968 .59046 L F
.437 .257 .537 r
.24997 .608 m .25026 .61037 L .24835 .61077 L F
.448 .232 .491 r
.25003 .61237 m .24835 .61077 L .25026 .61037 L F
.25003 .61237 m .24813 .61362 L .24835 .61077 L F
.283 .774 .899 r
.73109 .4326 m .73364 .43223 L .73517 .43249 L F
.561 .829 .996 r
.73364 .43223 m .73719 .43258 L .73517 .43249 L F
.947 .893 .742 r
.66569 .42702 m .66747 .42421 L .6663 .42286 L F
.8 .899 .912 r
.6663 .42286 m .66747 .42421 L .67057 .42154 L F
.656 .636 .818 r
.68456 .45912 m .6843 .46277 L .68824 .46032 L F
.84 .476 .365 r
.53653 .56951 m .53481 .57118 L .53721 .5715 L F
.881 .7 .654 r
.53481 .57118 m .53627 .57485 L .53721 .5715 L F
.832 .464 .357 r
.53653 .56951 m .53958 .57397 L .53481 .57118 L F
.48 .24 .473 r
.23513 .57943 m .23775 .57902 L .23825 .57584 L F
.434 .201 .459 r
.23825 .57584 m .23978 .5778 L .24047 .57543 L F
.23825 .57584 m .23775 .57902 L .23978 .5778 L F
.296 0 0 r
.19292 .69534 m .19316 .69602 L .19268 .69571 L F
.19292 .69534 m .19498 .69575 L .19316 .69602 L F
.391 0 .172 r
.19546 .69439 m .19498 .69575 L .19292 .69534 L F
.122 0 0 r
.68221 .39802 m .68072 .39771 L .6807 .39781 L F
.68221 .39802 m .68319 .39782 L .68072 .39771 L F
.488 .185 .379 r
.44039 .58454 m .44247 .58599 L .44 .5863 L F
.56 .342 .541 r
.44524 .58062 m .44259 .58527 L .44039 .58454 L F
.566 .115 .14 r
.44259 .58527 m .44247 .58599 L .44039 .58454 L F
.7 .705 .851 r
.73354 .42721 m .73766 .42831 L .73555 .42636 L F
.562 .411 .633 r
.45551 .61122 m .45827 .61099 L .45772 .60797 L F
.371 .169 .471 r
.45725 .61243 m .45551 .61122 L .45827 .61099 L F
.45725 .61243 m .45538 .6138 L .45551 .61122 L F
.562 .411 .633 r
.45551 .61122 m .45827 .61099 L .45772 .60797 L F
.371 .169 .471 r
.45725 .61243 m .45551 .61122 L .45827 .61099 L F
.45725 .61243 m .45538 .6138 L .45551 .61122 L F
.622 .946 .751 r
.47664 .589 m .47561 .59031 L .47859 .58806 L F
.861 .451 .254 r
.47439 .58432 m .47663 .58869 L .47623 .5881 L F
.734 .589 .694 r
.47623 .5881 m .47872 .58785 L .47931 .58399 L F
.422 0 .102 r
.48043 .58694 m .4788 .58783 L .47859 .58806 L F
.4788 .58783 m .47771 .58841 L .47796 .58831 L F
.4788 .58783 m .47796 .58831 L .47859 .58806 L F
.325 .222 .58 r
.48005 .5871 m .48148 .58252 L .47931 .58399 L F
.422 0 .102 r
.47771 .58841 m .47664 .589 L .47692 .58886 L F
.47771 .58841 m .47692 .58886 L .47859 .58806 L F
.41 0 .068 r
.47978 .58785 m .48019 .5877 L .47992 .58773 L F
.041 0 0 r
.48019 .5877 m .47924 .58894 L .48137 .58792 L F
.094 0 0 r
.48137 .58792 m .47924 .58894 L .48001 .58765 L F
.48062 .58713 m .48001 .58765 L .48043 .58694 L F
.325 .222 .58 r
.48019 .5877 m .48021 .58761 L .48017 .58761 L F
.094 0 0 r
.482 .58738 m .48085 .58687 L .48301 .58653 L F
.48137 .58792 m .48109 .58736 L .482 .58738 L F
.48109 .58736 m .48085 .58687 L .482 .58738 L F
.325 .222 .58 r
.48028 .58733 m .48211 .58697 L .48148 .58252 L F
.041 0 0 r
.48019 .5877 m .48137 .58792 L .48109 .58736 L F
.094 0 0 r
.48137 .58792 m .48001 .58765 L .48015 .58753 L F
.48082 .58735 m .48015 .58753 L .48062 .58713 L F
.325 .222 .58 r
.48019 .5877 m .48109 .58736 L .48082 .58735 L F
.48019 .5877 m .48082 .58735 L .48024 .58751 L F
.094 0 0 r
.48137 .58792 m .48015 .58753 L .48082 .58735 L F
.325 .222 .58 r
.48024 .58751 m .48082 .58735 L .48028 .58733 L F
.094 0 0 r
.48137 .58792 m .48043 .58694 L .48085 .58687 L F
.325 .222 .58 r
.48109 .58736 m .48211 .58697 L .48028 .58733 L F
.041 0 0 r
.48109 .58736 m .48137 .58792 L .48211 .58697 L F
.41 0 .068 r
.47664 .589 m .47978 .58785 L .47979 .58774 L F
.47978 .58785 m .47992 .58773 L .47979 .58774 L F
.422 0 .102 r
.4788 .58783 m .4789 .58809 L .47664 .589 L F
.41 0 .068 r
.47664 .589 m .47924 .58894 L .48019 .5877 L F
.422 0 .102 r
.48002 .58764 m .47924 .58894 L .4788 .58783 L F
.304 .143 .491 r
.47663 .58869 m .47664 .589 L .47623 .5881 L F
.41 0 .068 r
.47664 .589 m .47979 .58774 L .47623 .5881 L F
.422 0 .102 r
.4789 .58809 m .47924 .58894 L .47664 .589 L F
.48043 .58694 m .48002 .58764 L .4788 .58783 L F
.325 .222 .58 r
.48017 .58761 m .48039 .5869 L .48005 .5871 L F
.48021 .58761 m .48039 .5869 L .48017 .58761 L F
.48039 .5869 m .48148 .58252 L .48005 .5871 L F
.734 .589 .694 r
.47872 .58785 m .48019 .5877 L .48005 .5871 L F
.47872 .58785 m .48005 .5871 L .47931 .58399 L F
.683 .279 .274 r
.5638 .51763 m .56693 .51832 L .56452 .51633 L F
.916 .831 .747 r
.5492 .51377 m .54959 .50926 L .54736 .51239 L F
0 .381 .79 r
.49821 .57649 m .49665 .57621 L .49633 .57448 L F
.4997 .57745 m .50082 .57817 L .4992 .57741 L F
0 .422 .841 r
.49665 .57621 m .50082 .57817 L .50059 .57847 L F
.885 .8 .761 r
.49729 .58064 m .49914 .57943 L .49982 .57944 L F
.49914 .57943 m .50059 .57847 L .49982 .57944 L F
.088 .596 .891 r
.49982 .57944 m .50344 .58053 L .50235 .57988 L F
.999 .811 .517 r
.50344 .58053 m .50235 .57988 L .49982 .57944 L F
.207 0 0 r
.49982 .57944 m .50235 .57988 L .50085 .57982 L F
.5 .548 .836 r
.50081 .57946 m .49982 .57944 L .50085 .57982 L F
.885 .8 .761 r
.49729 .58064 m .49761 .58007 L .50059 .57847 L F
0 0 0 r
.50096 .57812 m .49982 .57944 L .50059 .57847 L F
0 .283 .702 r
.4997 .57745 m .50096 .57812 L .50082 .57817 L F
.49821 .57649 m .50003 .57757 L .4997 .57745 L F
.50003 .57757 m .50096 .57812 L .4997 .57745 L F
0 0 0 r
.50082 .57817 m .50096 .57812 L .50059 .57847 L F
0 .381 .79 r
.49821 .57649 m .4997 .57745 L .49665 .57621 L F
.4997 .57745 m .4992 .57741 L .49665 .57621 L F
.616 .617 .829 r
.49821 .57649 m .49982 .57944 L .50096 .57812 L F
.5 .548 .836 r
.50038 .57619 m .50235 .57988 L .49982 .57944 L F
.50058 .57777 m .49982 .57944 L .50081 .57946 L F
.50055 .57753 m .50047 .57773 L .50058 .57777 L F
.50047 .57773 m .49982 .57944 L .50058 .57777 L F
.50038 .57619 m .50016 .57749 L .50055 .57753 L F
.50016 .57749 m .49982 .57944 L .50055 .57753 L F
.83 .877 .878 r
.62078 .4529 m .62219 .45407 L .61908 .45655 L F
.777 .65 .093 r
.65206 .4238 m .65217 .42145 L .65211 .41898 L F
0 .484 .707 r
.20968 .53917 m .21343 .53978 L .21147 .53946 L F
.73 .518 .605 r
.37426 .63487 m .3749 .63806 L .37237 .63659 L F
.553 .259 .422 r
.37426 .63487 m .37237 .63659 L .37377 .63563 L F
.024 .045 .543 r
.37546 .63678 m .3749 .63806 L .37426 .63487 L F
.502 .2 .387 r
.37377 .63563 m .37546 .63678 L .37426 .63487 L F
.755 .657 .753 r
.54182 .68433 m .5392 .68226 L .5388 .68441 L F
.997 .826 .548 r
.62548 .474 m .62592 .47184 L .62448 .47289 L F
.91 .952 .812 r
.62592 .47184 m .62721 .46782 L .62537 .47092 L F
.62592 .47184 m .62814 .46873 L .62721 .46782 L F
.965 .935 .631 r
.62448 .47289 m .62592 .47184 L .62537 .47092 L F
.681 .595 .753 r
.55146 .52808 m .55459 .52761 L .5537 .52483 L F
.597 .363 .532 r
.55155 .53085 m .55459 .52761 L .55146 .52808 L F
.943 .767 .635 r
.2188 .58051 m .21982 .58361 L .21968 .58186 L F
.773 .687 .768 r
.41423 .63737 m .41827 .63799 L .41662 .63432 L F
.7 .248 .175 r
.41423 .63737 m .41654 .63949 L .41827 .63799 L F
.72 .694 .824 r
.42077 .63462 m .41802 .63584 L .41662 .63432 L F
.508 .552 .836 r
.41662 .63432 m .41827 .63799 L .41998 .63699 L F
.312 0 .077 r
.41654 .63949 m .41998 .63699 L .41827 .63799 L F
.722 .967 .936 r
.61908 .45655 m .61531 .45788 L .61872 .45629 L F
.83 .877 .878 r
.62078 .4529 m .61908 .45655 L .61872 .45629 L F
.456 .259 .523 r
.56096 .54526 m .56102 .54294 L .5634 .54222 L F
.575 .645 .882 r
.7224 .40855 m .72373 .4104 L .72613 .4096 L F
.328 .383 .767 r
.23432 .58731 m .23654 .5896 L .23592 .58677 L F
.924 .597 .135 r
.53565 .52963 m .53693 .53112 L .53549 .52754 L F
.995 .787 .42 r
.53668 .53353 m .53693 .53112 L .53565 .52963 L F
.808 .703 .75 r
.53549 .52754 m .53693 .53112 L .53785 .5289 L F
.473 .266 .518 r
.53668 .53353 m .53909 .53034 L .53693 .53112 L F
.52 .373 .622 r
.53693 .53112 m .53909 .53034 L .53785 .5289 L F
.271 0 .257 r
.58072 .45353 m .58302 .45463 L .58344 .45262 L F
.58072 .45353 m .58086 .45561 L .58302 .45463 L F
.719 .439 .501 r
.43553 .59037 m .43481 .5928 L .43174 .59248 L F
.324 .059 .348 r
.43718 .59183 m .43553 .59037 L .43715 .58928 L F
.43718 .59183 m .43481 .5928 L .43553 .59037 L F
.47 .74 .987 r
.46758 .56284 m .46674 .56465 L .46546 .56367 L F
.46758 .56284 m .46964 .56434 L .46674 .56465 L F
.458 .265 .53 r
.20472 .66461 m .20656 .66653 L .20677 .664 L F
.20472 .66461 m .20656 .66653 L .20677 .664 L F
.475 .266 .516 r
.20472 .66461 m .20465 .66785 L .20656 .66653 L F
.907 .75 .254 r
.65858 .41727 m .6582 .41743 L .65914 .41474 L F
.745 .781 .882 r
.65784 .40599 m .65413 .40579 L .65667 .40465 L F
.535 .771 .985 r
.66001 .40553 m .65784 .40599 L .65667 .40465 L F
.343 .678 .978 r
.24345 .54214 m .24297 .54346 L .24133 .54225 L F
.24345 .54214 m .24518 .5435 L .24297 .54346 L F
.573 .785 .979 r
.6584 .4513 m .66108 .45053 L .65969 .44929 L F
.29 0 .27 r
.22554 .64519 m .22462 .64296 L .2261 .64237 L F
.22554 .64519 m .22362 .64591 L .22462 .64296 L F
.296 .056 .37 r
.5668 .46899 m .56636 .47112 L .56873 .46807 L F
.111 0 0 r
.75418 .43531 m .75371 .43637 L .74988 .4375 L F
.436 0 0 r
.75418 .43531 m .75579 .43651 L .75371 .43637 L F
.75418 .43531 m .75662 .43599 L .75579 .43651 L F
.064 0 .429 r
.23308 .63281 m .23196 .63736 L .2315 .63431 L F
.639 .739 .921 r
.68882 .45068 m .68632 .45157 L .6851 .44983 L F
.431 .292 .59 r
.25244 .60696 m .25026 .61037 L .24997 .608 L F
.485 .305 .562 r
.2551 .60158 m .2527 .60478 L .25296 .60227 L F
.726 .755 .876 r
.41635 .60636 m .41883 .60797 L .41417 .60703 L F
.6 .743 .945 r
.42003 .60706 m .41883 .60797 L .41635 .60636 L F
.627 .891 .987 r
.2035 .67573 m .20119 .6766 L .20168 .675 L F
.555 .823 .996 r
.20168 .675 m .20119 .6766 L .19944 .67563 L F
.928 .86 .753 r
.62814 .46873 m .62795 .4653 L .62721 .46782 L F
.078 0 .306 r
.37411 .62003 m .37588 .61916 L .37238 .61667 L F
.37411 .62003 m .37507 .61983 L .37588 .61916 L F
.17 .301 .756 r
.37411 .62003 m .3764 .62207 L .37507 .61983 L F
.47 .338 .618 r
.37428 .62216 m .3764 .62207 L .37411 .62003 L F
.739 .59 .69 r
.5391 .57418 m .53958 .57409 L .54011 .5735 L F
.537 .547 .812 r
.53945 .5742 m .54289 .57634 L .54257 .57441 L F
.5391 .57418 m .53924 .57426 L .53945 .5742 L F
.53924 .57426 m .54289 .57634 L .53945 .5742 L F
.418 .866 .843 r
.54248 .57353 m .53955 .57418 L .53956 .57417 L F
.54248 .57353 m .53956 .57417 L .54174 .57352 L F
.739 .59 .69 r
.5391 .57418 m .53945 .5742 L .54248 .57353 L F
.53945 .5742 m .54257 .57441 L .54248 .57353 L F
.418 .866 .843 r
.54248 .57353 m .53933 .57446 L .53955 .57418 L F
.54174 .57352 m .53956 .57417 L .54011 .5735 L F
.577 .222 .33 r
.53933 .57446 m .53942 .57427 L .5395 .57418 L F
.53949 .57426 m .5395 .57418 L .54011 .5735 L F
.53933 .57446 m .5395 .57418 L .53949 .57426 L F
.537 .547 .812 r
.53946 .57439 m .54005 .57832 L .54289 .57634 L F
.5391 .57418 m .53932 .57515 L .53946 .57439 L F
.53932 .57515 m .54005 .57832 L .53946 .57439 L F
.739 .59 .69 r
.53958 .57409 m .54248 .57353 L .54011 .5735 L F
.577 .222 .33 r
.53942 .57427 m .53958 .57397 L .54011 .5735 L F
.686 .596 .749 r
.44479 .56199 m .44126 .56038 L .44355 .56002 L F
.587 .636 .867 r
.4462 .55923 m .44479 .56199 L .44355 .56002 L F
.4462 .55923 m .44689 .56174 L .44479 .56199 L F
.42 .429 .763 r
.55153 .56946 m .55383 .57214 L .55223 .57226 L F
.344 .286 .648 r
.55383 .57214 m .55445 .5744 L .55223 .57226 L F
.435 .294 .589 r
.55223 .57226 m .55445 .5744 L .55234 .57499 L F
.583 .608 .843 r
.47517 .56569 m .47418 .56958 L .47277 .56618 L F
.47517 .56569 m .47706 .56993 L .47418 .56958 L F
.514 .274 .488 r
.56352 .53994 m .56587 .54162 L .5634 .54222 L F
.56352 .53994 m .56599 .53946 L .56587 .54162 L F
.981 .693 .388 r
.53681 .53597 m .53818 .537 L .53668 .53353 L F
.759 .673 .768 r
.54063 .53399 m .53818 .537 L .53668 .53353 L F
.876 .901 .845 r
.54063 .53399 m .53818 .537 L .53681 .53597 L F
.673 .322 .371 r
.40234 .6127 m .403 .61368 L .40082 .61271 L F
.444 .265 .542 r
.40498 .61102 m .403 .61368 L .40234 .6127 L F
.363 .709 .986 r
.7514 .42362 m .75307 .4228 L .75398 .42235 L F
.588 .385 .573 r
.57347 .51604 m .57633 .5158 L .57622 .5133 L F
.52 .333 .567 r
.57622 .5133 m .57861 .51508 L .57861 .51276 L F
.57622 .5133 m .57633 .5158 L .57861 .51508 L F
.547 .095 .131 r
.37945 .59454 m .38337 .59317 L .38076 .59307 L F
.717 .363 .376 r
.21156 .65532 m .20861 .6565 L .20909 .65567 L F
.434 .818 .989 r
.45674 .56435 m .45901 .56403 L .46064 .56453 L F
.242 .738 .91 r
.45901 .56403 m .4632 .56417 L .46064 .56453 L F
.651 .564 .744 r
.21486 .5988 m .2159 .6025 L .21792 .60181 L F
.403 .793 .989 r
.44126 .56038 m .4398 .55959 L .44355 .56002 L F
.64 .804 .962 r
.70513 .39602 m .70141 .3955 L .70393 .39464 L F
.638 .814 .967 r
.70748 .39508 m .70513 .39602 L .70393 .39464 L F
.511 .365 .618 r
.19548 .55453 m .19336 .55762 L .19322 .55515 L F
.417 .788 .994 r
.44448 .6171 m .44584 .61605 L .44287 .61631 L F
.44287 .61631 m .44584 .61605 L .44448 .6171 L F
0 0 0 r
.5618 .47499 m .55939 .47786 L .56088 .47618 L F
.326 0 .185 r
.55768 .47845 m .56088 .47618 L .55939 .47786 L F
.864 .938 .868 r
.53785 .5289 m .5379 .52686 L .53549 .52754 L F
0 .563 .765 r
.22941 .64268 m .2261 .64237 L .2265 .6407 L F
.595 .446 .649 r
.55429 .55705 m .55174 .55981 L .55233 .5581 L F
.614 .437 .62 r
.55619 .52214 m .55904 .52172 L .55873 .51897 L F
.625 .463 .643 r
.55904 .52172 m .56127 .51865 L .55873 .51897 L F
.872 .972 .85 r
.56122 .49646 m .56074 .49861 L .56351 .49613 L F
.56122 .49646 m .55999 .49776 L .56074 .49861 L F
.614 .808 .974 r
.45187 .64027 m .45572 .64119 L .45495 .64099 L F
.446 .006 .108 r
.45572 .64119 m .45828 .64096 L .45808 .64202 L F
.197 .382 .821 r
.45696 .64015 m .45572 .64119 L .45808 .64202 L F
.993 .871 .598 r
.62098 .4262 m .62179 .42441 L .62076 .42353 L F
.646 .899 .983 r
.73851 .43998 m .73949 .44081 L .7425 .4397 L F
.973 .862 .67 r
.62919 .45914 m .63153 .45677 L .63055 .45572 L F
.62919 .45914 m .63046 .46023 L .63153 .45677 L F
.554 .889 .986 r
.16441 .56518 m .16394 .56409 L .16254 .56511 L F
.16441 .56518 m .16709 .56441 L .16394 .56409 L F
.969 .933 .648 r
.50994 .53649 m .51071 .53237 L .51263 .53404 L F
.50994 .53649 m .50932 .5357 L .51071 .53237 L F
.546 .882 .988 r
.69269 .39666 m .68925 .39683 L .6917 .39594 L F
.543 .869 .994 r
.6942 .39515 m .69269 .39666 L .6917 .39594 L F
.6942 .39515 m .69519 .39594 L .69269 .39666 L F
.616 .753 .943 r
.70403 .40533 m .70526 .40266 L .70272 .40335 L F
.70403 .40533 m .70641 .40458 L .70526 .40266 L F
.331 .005 .252 r
.20887 .63138 m .20682 .63199 L .20591 .63394 L F
.716 .359 .37 r
.45187 .64027 m .45495 .64099 L .45178 .63869 L F
.794 .558 .579 r
.20297 .67103 m .20591 .6704 L .20723 .66945 L F
.20297 .67103 m .2057 .67294 L .20591 .6704 L F
.294 .792 .834 r
.68857 .39675 m .68678 .39744 L .68525 .39773 L F
.68857 .39675 m .68925 .39683 L .68678 .39744 L F
.299 .794 .788 r
.74299 .42878 m .74459 .42808 L .74605 .42752 L F
.74299 .42878 m .7421 .42884 L .74459 .42808 L F
.256 0 0 r
.42683 .5882 m .42584 .58754 L .42598 .5865 L F
.771 .785 .864 r
.61798 .42205 m .61453 .42162 L .61666 .42037 L F
.267 .383 .796 r
.61918 .41974 m .61798 .42205 L .61666 .42037 L F
.55 .23 .379 r
.61798 .42205 m .62076 .42353 L .62009 .42176 L F
.267 .383 .796 r
.61918 .41974 m .62076 .42353 L .61798 .42205 L F
0 0 .098 r
.19793 .65835 m .19723 .65912 L .19978 .65846 L F
.19793 .65835 m .19695 .66108 L .19723 .65912 L F
.328 0 .159 r
.61765 .4064 m .62009 .40571 L .62073 .40461 L F
.419 .083 .286 r
.62009 .40571 m .62301 .40405 L .62073 .40461 L F
.723 .605 .725 r
.41014 .60214 m .40785 .60517 L .40672 .60174 L F
.606 .808 .977 r
.18047 .55728 m .1782 .55822 L .17997 .55751 L F
.409 .2 .482 r
.18047 .55728 m .17758 .56045 L .1782 .55822 L F
.914 .854 .769 r
.71218 .44436 m .71254 .44737 L .71129 .44601 L F
.808 .855 .884 r
.71254 .44737 m .70952 .44753 L .71129 .44601 L F
.289 .085 .42 r
.20931 .62893 m .21054 .63054 L .21103 .62822 L F
.20931 .62893 m .20887 .63138 L .21054 .63054 L F
.281 0 0 r
.22932 .54169 m .23155 .54183 L .23346 .54121 L F
0 0 0 r
.23155 .54183 m .23543 .54078 L .23346 .54121 L F
.486 .253 .486 r
.57861 .51276 m .58122 .50979 L .57875 .51032 L F
.242 .752 .871 r
.60761 .4563 m .60881 .45593 L .61005 .45613 L F
.482 .891 .928 r
.61005 .45613 m .61117 .45496 L .61233 .45501 L F
.61005 .45613 m .60881 .45593 L .61117 .45496 L F
.784 .968 .919 r
.52094 .52099 m .52011 .52315 L .51865 .52229 L F
.52094 .52099 m .52183 .52164 L .52011 .52315 L F
.039 0 .179 r
.42867 .56345 m .42693 .56664 L .42818 .56556 L F
0 0 0 r
.43069 .56165 m .42867 .56345 L .43046 .5619 L F
.548 .424 .663 r
.42818 .56556 m .43046 .5619 L .42867 .56345 L F
.512 .34 .583 r
.25921 .59281 m .2592 .59535 L .257 .59336 L F
.421 .338 .657 r
.257 .59336 m .2592 .59535 L .2574 .59583 L F
.68 .459 .579 r
.57687 .53103 m .57688 .5335 L .57442 .5337 L F
.718 .544 .652 r
.57962 .53081 m .57688 .5335 L .57687 .53103 L F
.984 .888 .546 r
.65 .43941 m .65033 .4348 L .64878 .43823 L F
.88 .505 .328 r
.42814 .63611 m .42991 .63958 L .43057 .63841 L F
.674 .752 .909 r
.70232 .45587 m .70561 .45656 L .70445 .45514 L F
.709 .814 .93 r
.70445 .45514 m .70561 .45656 L .70914 .45376 L F
.077 0 .013 r
.48754 .5778 m .48406 .58097 L .48564 .57879 L F
.242 .226 .64 r
.64379 .42682 m .64374 .43065 L .64561 .42886 L F
.554 .892 .649 r
.64374 .43065 m .64329 .43086 L .64561 .42886 L F
.444 .336 .637 r
.55235 .56343 m .55275 .56593 L .55078 .56654 L F
.429 .294 .594 r
.55275 .56593 m .55303 .56845 L .55078 .56654 L F
.349 .294 .654 r
.55078 .56654 m .55303 .56845 L .55153 .56946 L F
.135 0 .386 r
.16077 .54882 m .16157 .5483 L .16231 .54753 L F
.391 .806 .606 r
.16035 .54908 m .16157 .5483 L .16077 .54882 L F
.898 .578 .434 r
.50655 .55131 m .50422 .54852 L .50552 .54972 L F
.71 .799 .92 r
.63157 .43124 m .63277 .43294 L .629 .43251 L F
.788 .495 .493 r
.629 .43251 m .63277 .43294 L .63096 .43315 L F
.534 .719 .958 r
.63508 .4324 m .63277 .43294 L .63157 .43124 L F
.754 .411 .402 r
.63096 .43315 m .63277 .43294 L .63257 .43522 L F
.722 .538 .642 r
.63508 .4324 m .63257 .43522 L .63277 .43294 L F
.801 .996 .863 r
.75389 .41337 m .75309 .41553 L .75185 .41545 L F
.542 .834 .503 r
.5618 .47499 m .56305 .47357 L .56421 .47237 L F
0 0 0 r
.5618 .47499 m .56247 .47517 L .56305 .47357 L F
.5618 .47499 m .56088 .47618 L .56247 .47517 L F
.549 .069 .068 r
.4291 .64686 m .42746 .64842 L .42525 .64792 L F
.577 .101 .089 r
.43129 .64832 m .42746 .64842 L .4291 .64686 L F
.547 .154 .247 r
.43196 .64698 m .43129 .64832 L .4291 .64686 L F
.631 .404 .555 r
.57065 .51895 m .57342 .51893 L .57347 .51604 L F
.647 .455 .61 r
.57342 .51893 m .57633 .5158 L .57347 .51604 L F
.384 .164 .451 r
.17097 .56269 m .1696 .56073 L .1716 .56029 L F
.17097 .56269 m .16917 .56341 L .1696 .56073 L F
.125 .335 .801 r
.75941 .39929 m .75839 .40068 L .7584 .39924 L F
.14 .33 .793 r
.76072 .40071 m .75839 .40068 L .75941 .39929 L F
.76072 .40071 m .76094 .40246 L .75839 .40068 L F
.722 .611 .733 r
.40966 .59917 m .41014 .60214 L .40672 .60174 L F
.476 .205 .423 r
.21442 .65268 m .21378 .65488 L .21156 .65532 L F
.309 .052 .352 r
.21625 .65198 m .21378 .65488 L .21442 .65268 L F
0 0 .04 r
.52519 .58469 m .5253 .5857 L .5246 .58337 L F
.52519 .58469 m .5251 .58724 L .5253 .5857 L F
.096 .034 .49 r
.57204 .46243 m .57321 .46413 L .57308 .46184 L F
.291 .085 .418 r
.57204 .46243 m .57134 .46529 L .57321 .46413 L F
.393 .188 .478 r
.26368 .5865 m .26128 .58975 L .26182 .58734 L F
.806 .67 .714 r
.42118 .5872 m .41974 .59014 L .42048 .58791 L F
.603 .338 .488 r
.403 .61368 m .39931 .61634 L .40082 .61271 L F
.133 .318 .784 r
.49432 .57752 m .4951 .57835 L .49615 .57775 L F
.4951 .57835 m .49729 .58064 L .49615 .57775 L F
.614 .632 .845 r
.49615 .57775 m .49982 .57944 L .49821 .57649 L F
.594 .249 .353 r
.49821 .57649 m .49684 .57736 L .49615 .57775 L F
.49684 .57736 m .4946 .57879 L .49615 .57775 L F
.133 .318 .784 r
.49432 .57752 m .49615 .57775 L .49315 .57815 L F
.349 0 .122 r
.61675 .40813 m .62009 .40571 L .61765 .4064 L F
.617 .401 .567 r
.5537 .52483 m .55614 .52458 L .55619 .52214 L F
.698 .536 .664 r
.55614 .52458 m .55904 .52172 L .55619 .52214 L F
.723 .965 .939 r
.54307 .54584 m .53944 .54718 L .54053 .54887 L F
.919 .885 .783 r
.54546 .54281 m .54416 .54177 L .54213 .54529 L F
.163 0 .082 r
.54377 .54366 m .54351 .54393 L .54213 .54529 L F
.723 .965 .939 r
.54307 .54584 m .54213 .54529 L .54067 .54672 L F
.163 0 .082 r
.54351 .54393 m .54081 .54676 L .54213 .54529 L F
.723 .965 .939 r
.54067 .54672 m .54213 .54529 L .53944 .54718 L F
.645 .448 .603 r
.54053 .54887 m .54322 .54836 L .54307 .54584 L F
.919 .885 .783 r
.54546 .54281 m .54213 .54529 L .54307 .54584 L F
.642 .491 .663 r
.54307 .54584 m .54606 .54586 L .54546 .54281 L F
.613 .325 .456 r
.54555 .54788 m .54307 .54584 L .54322 .54836 L F
.54555 .54788 m .54606 .54586 L .54307 .54584 L F
.213 0 0 r
.17698 .54495 m .18115 .54234 L .17719 .54241 L F
.17713 .54485 m .17912 .5444 L .18115 .54234 L F
.021 0 0 r
.17912 .5444 m .18345 .54295 L .18115 .54234 L F
.17912 .5444 m .18128 .54396 L .18345 .54295 L F
.584 .942 .907 r
.17912 .5444 m .17959 .5434 L .1812 .54393 L F
.17912 .5444 m .1812 .54393 L .18128 .54396 L F
.213 0 0 r
.17698 .54495 m .17912 .5444 L .17713 .54485 L F
.456 .158 .37 r
.23605 .63072 m .23308 .63281 L .23424 .63147 L F
.861 .451 .254 r
.47439 .58432 m .47623 .5881 L .47709 .58451 L F
.599 .705 .918 r
.74594 .4345 m .74596 .43437 L .74598 .43272 L F
.74596 .43437 m .74669 .43009 L .74598 .43272 L F
.584 .243 .358 r
.746 .43098 m .74598 .43272 L .7433 .43241 L F
.74672 .4306 m .74598 .43272 L .746 .43098 L F
.786 .727 .797 r
.67989 .41282 m .68335 .40973 L .68004 .40942 L F
.27 0 .277 r
.37231 .59914 m .37419 .59849 L .37495 .59625 L F
.486 .181 .374 r
.37495 .59625 m .37683 .59786 L .377 .59552 L F
.37495 .59625 m .37419 .59849 L .37683 .59786 L F
.718 .649 .779 r
.19251 .68335 m .19381 .68573 L .19369 .68396 L F
0 0 .491 r
.19381 .68573 m .19492 .68695 L .19369 .68396 L F
.19381 .68573 m .19585 .68819 L .19492 .68695 L F
0 0 .454 r
.19381 .68573 m .19492 .68695 L .19369 .68396 L F
0 0 0 r
.59275 .4627 m .59216 .46445 L .5903 .46556 L F
.389 .824 .675 r
.59216 .46445 m .58989 .46571 L .5903 .46556 L F
.777 .746 .824 r
.68004 .40942 m .68335 .40973 L .68214 .40849 L F
.73 .739 .859 r
.68214 .40849 m .68335 .40973 L .68536 .40818 L F
0 0 0 r
.4046 .62448 m .402 .62586 L .40283 .6251 L F
.51 0 0 r
.60878 .46558 m .61148 .46813 L .60903 .46541 L F
.942 .914 .761 r
.61148 .46813 m .60875 .47033 L .60903 .46541 L F
.61148 .46813 m .60974 .47138 L .60875 .47033 L F
.695 .422 .507 r
.47433 .57437 m .47792 .5723 L .47709 .57052 L F
.47433 .57437 m .4779 .57443 L .47792 .5723 L F
0 0 0 r
.76751 .4273 m .76735 .42869 L .76688 .42892 L F
.738 .64 .079 r
.76753 .42619 m .76735 .42869 L .76751 .4273 L F
.094 0 0 r
.43539 .58055 m .43755 .58007 L .43918 .57895 L F
.948 .642 .423 r
.50509 .58459 m .50289 .5833 L .50368 .58489 L F
.685 .728 .883 r
.72605 .39586 m .72689 .39752 L .72326 .39674 L F
.631 .669 .868 r
.72986 .39623 m .72689 .39752 L .72605 .39586 L F
.72986 .39623 m .72927 .39674 L .72689 .39752 L F
.997 .822 .544 r
.4305 .59731 m .42907 .59835 L .42942 .59509 L F
.4305 .59731 m .42991 .59985 L .42907 .59835 L F
.656 .689 .869 r
.43185 .59503 m .4305 .59731 L .42942 .59509 L F
.534 .53 .797 r
.43185 .59503 m .43292 .59592 L .4305 .59731 L F
.448 .271 .547 r
.43292 .59592 m .43016 .59951 L .4305 .59731 L F
.43016 .59951 m .43 .59944 L .4305 .59731 L F
.43292 .59592 m .43473 .59828 L .42991 .59985 L F
.636 .738 .922 r
.43473 .59828 m .43235 .60109 L .42991 .59985 L F
0 .328 .791 r
.43078 .59977 m .43193 .60003 L .42907 .59835 L F
.43235 .60109 m .43204 .60032 L .43078 .59977 L F
.43194 .60028 m .43193 .60003 L .43078 .59977 L F
.448 .271 .547 r
.43016 .59951 m .42991 .59985 L .43 .59944 L F
.328 .59 .94 r
.42991 .59985 m .43235 .60109 L .42907 .59835 L F
.731 .961 .681 r
.43018 .59647 m .42907 .59835 L .43193 .60003 L F
.757 .296 .153 r
.43539 .59787 m .43473 .59828 L .43292 .59592 L F
.765 .663 .75 r
.43018 .59647 m .43193 .60003 L .43401 .59684 L F
.974 .784 .586 r
.43193 .60003 m .43033 .60017 L .43188 .59941 L F
.43193 .60003 m .43188 .59941 L .43273 .599 L F
0 .328 .791 r
.43204 .60032 m .43193 .60003 L .43194 .60028 L F
.576 .385 .586 r
.5706 .53395 m .57076 .53652 L .56862 .53708 L F
.638 .447 .607 r
.57442 .5337 m .57076 .53652 L .5706 .53395 L F
0 0 .367 r
.46374 .5749 m .46447 .57402 L .46446 .57181 L F
.282 .525 .908 r
.46374 .5749 m .46596 .57606 L .46447 .57402 L F
.158 .277 .737 r
.60761 .4563 m .60997 .45899 L .60881 .45593 L F
.301 .026 .319 r
.23772 .62993 m .23688 .62883 L .2386 .62791 L F
.23772 .62993 m .23605 .63072 L .23688 .62883 L F
.668 .786 .937 r
.72883 .43585 m .72641 .43698 L .72517 .4352 L F
.682 .724 .881 r
.72228 .39421 m .7208 .39773 L .71954 .39595 L F
.72228 .39421 m .72326 .39674 L .7208 .39773 L F
.702 .54 .666 r
.21717 .60796 m .2196 .60818 L .21974 .60533 L F
.732 .566 .667 r
.21974 .60533 m .2196 .60818 L .223 .60788 L F
.242 0 .219 r
.20422 .63478 m .20156 .63731 L .20342 .63648 L F
0 0 0 r
.20342 .63648 m .20591 .63394 L .20422 .63478 L F
.716 .501 .597 r
.19822 .69387 m .19498 .69575 L .19546 .69439 L F
.876 .901 .845 r
.54063 .53399 m .53681 .53597 L .53668 .53353 L F
.763 .658 .746 r
.53909 .53034 m .54063 .53399 L .53668 .53353 L F
.313 .021 .299 r
.58606 .44752 m .58862 .44692 L .58882 .44479 L F
.261 0 .308 r
.59131 .4419 m .58882 .44479 L .59087 .44361 L F
.279 .007 .309 r
.58862 .44692 m .59087 .44361 L .58882 .44479 L F
.763 .64 .725 r
.45224 .56932 m .45317 .57238 L .44946 .57168 L F
0 0 0 r
.45317 .57238 m .44943 .5745 L .44946 .57168 L F
.45317 .57238 m .45157 .57375 L .44943 .5745 L F
.281 .338 .744 r
.45224 .56932 m .45459 .57158 L .45317 .57238 L F
.793 .662 .719 r
.45459 .57158 m .45157 .57375 L .45317 .57238 L F
.791 .306 0 r
.52989 .59299 m .53027 .59456 L .52928 .59255 L F
0 0 .558 r
.52928 .59255 m .53027 .59456 L .52981 .59329 L F
.52928 .59255 m .52981 .59329 L .52902 .5911 L F
.641 .157 0 r
.52781 .59053 m .52928 .59255 L .52765 .59034 L F
.52989 .59299 m .52928 .59255 L .52781 .59053 L F
.791 .306 0 r
.52989 .59299 m .5316 .59543 L .53027 .59456 L F
.473 .591 .89 r
.7507 .39546 m .75512 .39697 L .75409 .39808 L F
.629 .942 .724 r
.75409 .39808 m .75512 .39697 L .75592 .39606 L F
.446 .579 .893 r
.75592 .39606 m .7584 .39924 L .75409 .39808 L F
.932 .881 .465 r
.65169 .4135 m .65196 .41418 L .65266 .41214 L F
.215 .221 .649 r
.65413 .40579 m .65444 .41039 L .65515 .40838 L F
.022 .342 .821 r
.65444 .41039 m .65548 .41011 L .65515 .40838 L F
.458 .517 .831 r
.65548 .41011 m .65266 .41214 L .65153 .40925 L F
.086 .266 .751 r
.38129 .62837 m .38269 .63179 L .3834 .63026 L F
.49 .762 .991 r
.38269 .63179 m .38495 .63142 L .3834 .63026 L F
.16 .269 .729 r
.597 .453 m .59764 .45675 L .59976 .45398 L F
.671 .267 .272 r
.45801 .63812 m .46056 .64007 L .46125 .63812 L F
.47 .36 .646 r
.45801 .63812 m .45828 .64096 L .46056 .64007 L F
.671 .267 .272 r
.45801 .63812 m .45696 .64015 L .46056 .64007 L F
.47 .36 .646 r
.45801 .63812 m .46056 .64007 L .46125 .63812 L F
.342 0 .004 r
.54783 .53979 m .54416 .54177 L .54546 .54281 L F
.625 .473 .656 r
.54546 .54281 m .54835 .54249 L .54783 .53979 L F
.461 .274 .539 r
.54606 .54586 m .54835 .54249 L .54546 .54281 L F
.691 .24 .178 r
.4129 .61419 m .41127 .61559 L .40906 .6136 L F
.996 .84 .571 r
.41184 .6131 m .41127 .61559 L .4129 .61419 L F
.091 0 .298 r
.21159 .62581 m .21103 .62822 L .21292 .62506 L F
.635 .267 .328 r
.2196 .60818 m .22171 .61014 L .223 .60788 L F
.243 0 .111 r
.223 .60788 m .22375 .60939 L .22498 .60732 L F
.223 .60788 m .22171 .61014 L .22375 .60939 L F
.41 .234 .53 r
.24813 .61362 m .24594 .61669 L .24602 .61443 L F
.239 .141 .537 r
.47265 .57853 m .47433 .57437 L .47167 .57515 L F
.47265 .57853 m .47489 .57761 L .47433 .57437 L F
.4 .093 .325 r
.39887 .5871 m .40193 .583 L .39998 .5841 L F
.527 .494 .762 r
.4528 .58504 m .45413 .58222 L .45254 .58315 L F
.4528 .58504 m .45527 .58456 L .45413 .58222 L F
.758 .773 .865 r
.45413 .58222 m .4528 .58504 L .45254 .58315 L F
.916 .607 .126 r
.75771 .40973 m .75695 .40864 L .75642 .40566 L F
.122 0 .284 r
.22498 .60732 m .22702 .60424 L .22543 .60508 L F
.403 .826 .965 r
.7074 .44746 m .70338 .44744 L .70568 .44615 L F
.309 .668 .974 r
.70952 .44753 m .7074 .44746 L .70568 .44615 L F
.222 .036 .405 r
.25698 .59843 m .2551 .60158 L .2555 .59921 L F
.555 .362 .574 r
.21381 .55427 m .21134 .55717 L .21141 .55471 L F
.306 .093 .417 r
.59339 .43886 m .59131 .4419 L .59328 .44078 L F
.362 .127 .417 r
.59087 .44361 m .59328 .44078 L .59131 .4419 L F
.482 .225 .448 r
.55602 .54885 m .55802 .55053 L .55568 .55099 L F
.55602 .54885 m .55845 .54811 L .55802 .55053 L F
.473 .207 .429 r
.55602 .54885 m .55568 .55099 L .55333 .55153 L F
0 .122 .644 r
.40501 .60921 m .40578 .60775 L .40798 .60817 L F
.40501 .60921 m .404 .60723 L .40578 .60775 L F
.611 .477 .674 r
.45994 .60497 m .46052 .608 L .45772 .60797 L F
.38 .287 .623 r
.45993 .60994 m .45772 .60797 L .46052 .608 L F
.45993 .60994 m .45827 .61099 L .45772 .60797 L F
.611 .477 .674 r
.45994 .60497 m .46052 .608 L .45772 .60797 L F
.38 .287 .623 r
.45993 .60994 m .45772 .60797 L .46052 .608 L F
.45993 .60994 m .45827 .61099 L .45772 .60797 L F
.905 .96 .631 r
.41481 .60373 m .41485 .6056 L .41646 .60234 L F
.98 .782 .567 r
.41286 .6061 m .41485 .6056 L .41481 .60373 L F
.41286 .6061 m .41417 .60703 L .41485 .6056 L F
.552 .23 .376 r
.41635 .60636 m .41417 .60703 L .41485 .6056 L F
.806 .879 .899 r
.71485 .44425 m .71218 .44436 L .71404 .44176 L F
.773 .893 .929 r
.71687 .44098 m .71485 .44425 L .71404 .44176 L F
.71687 .44098 m .71797 .4421 L .71485 .44425 L F
.545 .632 .888 r
.4945 .57157 m .49366 .57472 L .49209 .57245 L F
.4945 .57157 m .49633 .57448 L .49366 .57472 L F
0 0 0 r
.59407 .46302 m .59275 .4627 L .59503 .4614 L F
.59407 .46302 m .59216 .46445 L .59275 .4627 L F
.094 .336 .809 r
.51521 .56348 m .51681 .56653 L .51729 .56492 L F
0 0 .169 r
.51681 .56653 m .5173 .56767 L .51729 .56492 L F
.51681 .56653 m .51681 .56891 L .5173 .56767 L F
.618 .955 .911 r
.20045 .6377 m .19739 .63876 L .20039 .63787 L F
0 0 0 r
.2002 .6384 m .20039 .63787 L .1983 .63812 L F
.20039 .63843 m .20039 .63787 L .2002 .6384 L F
.618 .955 .911 r
.20156 .63731 m .20045 .6377 L .20039 .63787 L F
.068 0 0 r
.20039 .63787 m .20342 .63648 L .20156 .63731 L F
.597 .786 .971 r
.71346 .39502 m .71101 .39572 L .70998 .39438 L F
.628 .769 .947 r
.7187 .39372 m .71715 .3966 L .71594 .39441 L F
.7187 .39372 m .71954 .39595 L .71715 .3966 L F
.558 .331 .527 r
.41798 .59937 m .42121 .59919 L .42097 .59632 L F
.46 .26 .521 r
.42097 .59632 m .42121 .59919 L .42306 .59781 L F
.597 .363 .532 r
.55155 .53085 m .55504 .52968 L .55459 .52761 L F
.582 .498 .725 r
.55459 .52761 m .55614 .52458 L .5537 .52483 L F
.55459 .52761 m .55714 .52748 L .55614 .52458 L F
.624 .43 .599 r
.55504 .52968 m .55714 .52748 L .55459 .52761 L F
0 .415 .849 r
.20538 .55402 m .20805 .55526 L .20657 .55384 L F
.20538 .55402 m .20657 .55384 L .20554 .55401 L F
.20538 .55402 m .20554 .55401 L .20406 .55424 L F
0 .157 .617 r
.20529 .55403 m .20538 .55402 L .20458 .55346 L F
.20647 .55497 m .20538 .55402 L .20529 .55403 L F
.778 .335 0 r
.20647 .55497 m .20749 .55693 L .20538 .55402 L F
.988 .718 .369 r
.53877 .58892 m .53993 .59262 L .54042 .59146 L F
.505 .244 .452 r
.59771 .45889 m .59534 .45968 L .59764 .45675 L F
.16 .269 .729 r
.597 .453 m .59883 .4551 L .59764 .45675 L F
.651 .621 .806 r
.59883 .4551 m .59771 .45889 L .59764 .45675 L F
0 .032 .592 r
.41554 .59844 m .41646 .60234 L .41798 .59937 L F
.41554 .59844 m .41726 .6015 L .41646 .60234 L F
.352 .144 .452 r
.24106 .5659 m .24329 .56296 L .24114 .56356 L F
.385 .037 .246 r
.25747 .82694 m .25794 .82569 L .25532 .82739 L F
0 0 .08 r
.60976 .41507 m .61164 .41364 L .61233 .41185 L F
0 0 0 r
.60976 .41507 m .6093 .41671 L .61164 .41364 L F
.46543 .6385 m .46293 .63961 L .46457 .63834 L F
.46671 .63769 m .46543 .6385 L .46457 .63834 L F
.513 .372 .627 r
.26845 .58012 m .26601 .57861 L .26794 .57744 L F
.26845 .58012 m .26621 .58087 L .26601 .57861 L F
.177 0 0 r
.21343 .53978 m .21553 .54025 L .21744 .54054 L F
0 .562 .724 r
.21553 .54025 m .21946 .54047 L .21744 .54054 L F
0 0 .085 r
.74598 .43272 m .74544 .43552 L .7433 .43241 L F
.74598 .43272 m .74594 .4345 L .74544 .43552 L F
.204 .594 .946 r
.74594 .4345 m .74711 .43568 L .74544 .43552 L F
.381 .315 .657 r
.58585 .50099 m .58797 .50293 L .58828 .50068 L F
.58585 .50099 m .58625 .50406 L .58797 .50293 L F
.31 0 .206 r
.23513 .57943 m .23678 .57994 L .23775 .57902 L F
.23513 .57943 m .23461 .58066 L .23678 .57994 L F
.864 .805 .79 r
.65953 .44225 m .65593 .44398 L .65832 .44096 L F
.65953 .44225 m .65777 .4448 L .65593 .44398 L F
.795 .781 .839 r
.66071 .43794 m .65953 .44225 L .65832 .44096 L F
.66071 .43794 m .66398 .43799 L .65953 .44225 L F
.625 .738 .928 r
.70998 .40554 m .71134 .40256 L .70883 .40345 L F
.70998 .40554 m .71248 .40476 L .71134 .40256 L F
.371 .194 .508 r
.21486 .5988 m .21665 .5984 L .21686 .59593 L F
.651 .564 .744 r
.21486 .5988 m .21792 .60181 L .21665 .5984 L F
.997 .831 .487 r
.65079 .43174 m .65204 .43047 L .65161 .42858 L F
.65079 .43174 m .65162 .43308 L .65204 .43047 L F
.324 .498 .876 r
.25716 .54703 m .25633 .54883 L .25555 .54697 L F
.426 .621 .934 r
.25716 .54703 m .25818 .54857 L .25633 .54883 L F
.608 .85 .99 r
.66648 .40391 m .66189 .40284 L .66532 .4034 L F
.413 .863 .843 r
.66727 .40309 m .66648 .40391 L .66532 .4034 L F
.405 .166 .435 r
.58597 .44993 m .58862 .44692 L .58606 .44752 L F
.618 .726 .923 r
.68824 .46032 m .69083 .46179 L .69006 .45887 L F
.696 .681 .832 r
.69006 .45887 m .69083 .46179 L .69388 .45952 L F
.333 .392 .774 r
.53627 .57485 m .537 .5783 L .53597 .57765 L F
.701 .419 .494 r
.53865 .58106 m .54106 .58077 L .54005 .57832 L F
.705 .62 .759 r
.54106 .58077 m .54289 .57634 L .54005 .57832 L F
.915 .541 .111 r
.64133 .43715 m .64247 .43837 L .64195 .43636 L F
.579 .538 .773 r
.64156 .43261 m .64195 .43636 L .6449 .43519 L F
.488 .639 .922 r
.51791 .57243 m .51944 .57042 L .51681 .56891 L F
.51791 .57243 m .51987 .57225 L .51944 .57042 L F
.964 .898 .709 r
.60974 .47138 m .60734 .47352 L .60875 .47033 L F
.60974 .47138 m .60838 .47475 L .60734 .47352 L F
.604 .817 .982 r
.28867 .78555 m .28685 .78647 L .2847 .78511 L F
.28867 .78555 m .28685 .78647 L .2847 .78511 L F
.626 .802 .967 r
.48451 .56977 m .48365 .5718 L .48249 .57064 L F
.48451 .56977 m .48666 .57099 L .48365 .5718 L F
0 0 0 r
.59339 .43886 m .59556 .43759 L .5962 .43599 L F
.033 0 .184 r
.5962 .43599 m .59813 .43486 L .59837 .4328 L F
.166 0 .035 r
.5962 .43599 m .59775 .43674 L .59813 .43486 L F
.5962 .43599 m .59556 .43759 L .59775 .43674 L F
.868 .877 .842 r
.61973 .44716 m .62093 .44829 L .61867 .45076 L F
.855 .878 .855 r
.62353 .44537 m .62093 .44829 L .61973 .44716 L F
.474 .719 .977 r
.18933 .64262 m .18737 .64294 L .18598 .64151 L F
.062 0 0 r
.74658 .4179 m .74647 .41835 L .7443 .41913 L F
.618 .955 .912 r
.74863 .41667 m .74658 .4179 L .74869 .416 L F
.532 .904 .959 r
.74863 .41667 m .75071 .41512 L .75185 .41545 L F
.74863 .41667 m .74869 .416 L .75071 .41512 L F
.358 .421 .79 r
.74658 .4179 m .74965 .41896 L .74869 .416 L F
.474 0 0 r
.74658 .4179 m .74965 .41896 L .74647 .41835 L F
0 0 0 r
.41089 .5779 m .41235 .5775 L .41383 .57572 L F
.41089 .5779 m .40988 .57832 L .41235 .5775 L F
.394 .851 .875 r
.18703 .54214 m .18345 .54295 L .18541 .54226 L F
.431 .827 .983 r
.18541 .54226 m .18928 .54236 L .18703 .54214 L F
.338 .662 .973 r
.25315 .5452 m .2526 .54652 L .251 .54526 L F
.25315 .5452 m .25555 .54697 L .2526 .54652 L F
.705 .391 .443 r
.74297 .41775 m .74647 .41835 L .7443 .41913 L F
.432 .302 .603 r
.37243 .60171 m .37419 .59849 L .37231 .59914 L F
.867 .918 .521 r
.57367 .48166 m .57327 .48386 L .57488 .48022 L F
.727 .989 .866 r
.57598 .47835 m .57488 .48022 L .5778 .478 L F
.664 .87 .491 r
.57598 .47835 m .57367 .48166 L .57488 .48022 L F
.454 .244 .503 r
.22716 .60168 m .22965 .59862 L .22703 .59893 L F
.332 .076 .368 r
.24261 .62392 m .24156 .62278 L .24312 .62192 L F
.24261 .62392 m .24096 .62466 L .24156 .62278 L F
.902 .8 .737 r
.50569 .543 m .50268 .54428 L .50418 .54217 L F
.50569 .543 m .5049 .54545 L .50268 .54428 L F
.442 .35 .656 r
.54835 .54249 m .55034 .54175 L .54783 .53979 L F
.342 0 .004 r
.54783 .53979 m .54865 .54144 L .54416 .54177 L F
.969 .772 .584 r
.55034 .54175 m .54865 .54144 L .54783 .53979 L F
.745 .736 .844 r
.55648 .58477 m .5582 .58724 L .55485 .58571 L F
.837 .434 .281 r
.55485 .58571 m .5582 .58724 L .55693 .58875 L F
.304 .526 .904 r
.55648 .58477 m .55961 .58613 L .5582 .58724 L F
0 0 0 r
.5582 .58724 m .55961 .58613 L .55693 .58875 L F
.675 .836 .961 r
.21553 .55996 m .21134 .55717 L .21356 .55675 L F
.21553 .55996 m .2119 .55938 L .21134 .55717 L F
.683 .656 .817 r
.21693 .55741 m .21553 .55996 L .21356 .55675 L F
.471 .394 .688 r
.21693 .55741 m .21777 .55974 L .21553 .55996 L F
.828 .907 .893 r
.72874 .40851 m .72974 .40987 L .73153 .4082 L F
.364 .165 .471 r
.24038 .62688 m .23899 .62562 L .24096 .62466 L F
.24038 .62688 m .2386 .62791 L .23899 .62562 L F
.978 .788 .579 r
.5049 .54545 m .50309 .54709 L .50268 .54428 L F
.5049 .54545 m .50422 .54852 L .50309 .54709 L F
.885 .736 .227 r
.65956 .42238 m .65965 .42723 L .65859 .42605 L F
.989 .841 .605 r
.65859 .42605 m .65965 .42723 L .65906 .42954 L F
.738 .894 .95 r
.73301 .44173 m .73413 .44304 L .73614 .44158 L F
.512 .804 .998 r
.71183 .44169 m .70879 .44119 L .71071 .44006 L F
.533 .727 .963 r
.71323 .43988 m .71183 .44169 L .71071 .44006 L F
.392 .522 .869 r
.71404 .44176 m .71183 .44169 L .71323 .43988 L F
.426 .242 .527 r
.71218 .44436 m .71183 .44169 L .71404 .44176 L F
.848 .913 .878 r
.37377 .63563 m .37049 .63708 L .37237 .63659 L F
.299 0 .127 r
.37237 .63659 m .37409 .63678 L .37377 .63563 L F
.848 .913 .878 r
.37377 .63563 m .37049 .63708 L .37237 .63659 L F
.588 .091 .041 r
.37377 .63563 m .37409 .63678 L .37546 .63678 L F
.976 .917 .669 r
.76718 .41945 m .76794 .42063 L .76886 .41841 L F
.96 .944 .691 r
.76825 .41739 m .76718 .41945 L .76886 .41841 L F
.817 .994 .862 r
.64315 .4018 m .64282 .40076 L .64293 .39974 L F
.438 .685 .969 r
.64615 .40059 m .64315 .4018 L .64293 .39974 L F
.64615 .40059 m .64703 .40216 L .64315 .4018 L F
.279 .764 .92 r
.19336 .55762 m .19188 .55726 L .18968 .55758 L F
.511 .365 .618 r
.19548 .55453 m .1955 .55716 L .19336 .55762 L F
.649 .938 .965 r
.1936 .55624 m .19336 .55762 L .1955 .55716 L F
.1936 .55624 m .19188 .55726 L .19336 .55762 L F
.322 .163 .504 r
.59328 .44078 m .59556 .43759 L .59339 .43886 L F
.482 .602 .895 r
.44797 .57953 m .44527 .57793 L .44861 .57846 L F
.551 0 0 r
.44527 .57793 m .44532 .57796 L .44861 .57846 L F
.844 .788 .798 r
.44861 .57846 m .44943 .5745 L .45117 .57831 L F
.44861 .57846 m .44532 .57796 L .44567 .57767 L F
.421 .139 .377 r
.44548 .57779 m .44619 .57911 L .44572 .57779 L F
.476 .203 .421 r
.44572 .57779 m .44527 .57793 L .44431 .57776 L F
.421 .139 .377 r
.44431 .57776 m .44489 .57817 L .44548 .57779 L F
.844 .788 .798 r
.44925 .57536 m .44567 .57767 L .44943 .5745 L F
.44861 .57846 m .44567 .57767 L .44925 .57536 L F
.599 .341 .498 r
.44572 .57779 m .44943 .5745 L .44532 .57796 L F
.476 .203 .421 r
.44572 .57779 m .44532 .57796 L .44527 .57793 L F
.421 .139 .377 r
.44489 .57817 m .44619 .57911 L .44548 .57779 L F
.676 .286 .301 r
.45117 .57831 m .44797 .57953 L .44861 .57846 L F
.641 .231 .251 r
.42272 .63508 m .42539 .63672 L .42644 .63476 L F
.838 .502 .418 r
.42843 .63906 m .42991 .63958 L .42814 .63611 L F
.42843 .63906 m .42814 .63611 L .42862 .6365 L F
.978 .714 .31 r
.42813 .63826 m .42747 .63892 L .42843 .63906 L F
.625 .214 .243 r
.42644 .63476 m .42539 .63672 L .42794 .63654 L F
.42807 .63606 m .42794 .63654 L .42862 .6365 L F
.593 .868 .994 r
.42862 .6365 m .42539 .63672 L .42722 .63577 L F
.978 .714 .31 r
.42722 .63577 m .42843 .63906 L .42862 .6365 L F
.855 .71 .701 r
.42451 .63901 m .42689 .63904 L .42747 .63892 L F
.42689 .63904 m .42843 .63906 L .42747 .63892 L F
.337 0 .085 r
.42949 .63783 m .42797 .63881 L .42747 .63892 L F
.855 .71 .701 r
.42451 .63901 m .42638 .64197 L .42843 .63906 L F
.337 0 .085 r
.42797 .63881 m .42688 .6395 L .42747 .63892 L F
.42688 .6395 m .4259 .64014 L .42747 .63892 L F
.978 .714 .31 r
.42776 .63724 m .42747 .63892 L .42813 .63826 L F
.42722 .63577 m .42744 .63847 L .42776 .63724 L F
.42744 .63847 m .42747 .63892 L .42776 .63724 L F
.625 .214 .243 r
.42644 .63476 m .42794 .63654 L .42807 .63606 L F
.445 0 0 r
.42644 .63476 m .42862 .6365 L .42814 .63611 L F
.728 .258 .134 r
.43607 .64011 m .43851 .64233 L .44004 .64115 L F
.681 .196 .092 r
.43851 .64233 m .4421 .6429 L .44004 .64115 L F
.584 .279 .418 r
.44004 .64115 m .4421 .6429 L .44353 .64028 L F
.599 .587 .811 r
.70221 .44386 m .70338 .44744 L .70084 .44824 L F
.868 .877 .842 r
.61973 .44716 m .61867 .45076 L .61686 .44999 L F
.649 .38 .499 r
.61867 .45076 m .61876 .45287 L .61686 .44999 L F
.61867 .45076 m .62078 .4529 L .61876 .45287 L F
.645 .276 .329 r
.42324 .64627 m .42141 .64861 L .41932 .64664 L F
.609 .232 .303 r
.42525 .64792 m .42141 .64861 L .42324 .64627 L F
.546 .109 .162 r
.41736 .59315 m .41679 .5944 L .41507 .59399 L F
.41736 .59315 m .41507 .59399 L .41411 .5937 L F
.909 .666 .558 r
.41349 .59265 m .41513 .59401 L .41647 .59395 L F
.41513 .59401 m .41709 .59564 L .41666 .59448 L F
.546 .109 .162 r
.41411 .5937 m .41507 .59399 L .41395 .59372 L F
.261 .6 .952 r
.41474 .5938 m .41679 .5944 L .41647 .59395 L F
.41395 .59372 m .41513 .59401 L .41474 .5938 L F
.41513 .59401 m .41679 .5944 L .41474 .5938 L F
.909 .666 .558 r
.4151 .59399 m .41554 .59844 L .41709 .59564 L F
.261 .6 .952 r
.41395 .59372 m .41474 .5938 L .41349 .59265 L F
.909 .666 .558 r
.41349 .59265 m .41474 .5938 L .4151 .59399 L F
.261 .6 .952 r
.41474 .5938 m .41647 .59395 L .41349 .59265 L F
.909 .666 .558 r
.41349 .59265 m .4137 .59325 L .41474 .5938 L F
.4137 .59325 m .41554 .59844 L .4151 .59399 L F
.41513 .59401 m .41666 .59448 L .41647 .59395 L F
.602 .071 0 r
.41349 .59265 m .41647 .59395 L .41736 .59315 L F
0 0 0 r
.41867 .59157 m .41736 .59315 L .41974 .59014 L F
.992 .803 .425 r
.41647 .59395 m .41709 .59564 L .41736 .59315 L F
0 0 0 r
.41851 .59176 m .41679 .5944 L .41736 .59315 L F
.41822 .59224 m .41679 .5944 L .41851 .59176 L F
.41867 .59157 m .41822 .59224 L .41851 .59176 L F
.355 .161 .474 r
.41867 .59157 m .41647 .59395 L .41679 .5944 L F
.275 .511 .9 r
.41709 .59564 m .41808 .59407 L .41647 .59395 L F
.41709 .59564 m .41808 .59407 L .41647 .59395 L F
.393 .141 .409 r
.41767 .59634 m .4168 .59462 L .41808 .59407 L F
.4168 .59462 m .41647 .59395 L .41717 .594 L F
.4168 .59462 m .41717 .594 L .41808 .59407 L F
.639 .079 0 r
.65593 .44398 m .65777 .4448 L .6599 .44673 L F
0 .251 .72 r
.64703 .40216 m .65078 .40498 L .64848 .40515 L F
0 0 0 r
.41383 .57572 m .41425 .57633 L .41542 .5741 L F
.41383 .57572 m .41235 .5775 L .41425 .57633 L F
.547 .095 .131 r
.37945 .59454 m .38179 .59489 L .38337 .59317 L F
.491 .074 .177 r
.38179 .59489 m .38578 .59281 L .38337 .59317 L F
.617 .146 .112 r
.41698 .64617 m .41558 .6475 L .41334 .64608 L F
.669 .24 .221 r
.41932 .64664 m .41558 .6475 L .41698 .64617 L F
.285 .014 .316 r
.63228 .40456 m .62976 .40604 L .6323 .40318 L F
.55 .754 .972 r
.6335 .40116 m .6323 .40318 L .63104 .40199 L F
.6335 .40116 m .63468 .40263 L .6323 .40318 L F
.352 .063 .327 r
.6348 .40319 m .6323 .40318 L .63468 .40263 L F
.6348 .40319 m .63228 .40456 L .6323 .40318 L F
.598 .946 .92 r
.19223 .69396 m .19283 .69317 L .19282 .69302 L F
.245 0 0 r
.22532 .55271 m .2242 .55304 L .22236 .55279 L F
.518 .358 .603 r
.61954 .41621 m .61963 .41827 L .61731 .41892 L F
.358 0 .197 r
.61963 .41827 m .61666 .42037 L .61731 .41892 L F
.125 .425 .867 r
.52222 .57986 m .52283 .58133 L .52303 .5799 L F
0 0 .501 r
.52283 .58133 m .5246 .58337 L .52382 .58231 L F
.801 .723 .779 r
.21665 .5984 m .21792 .60181 L .21882 .59952 L F
.865 .643 .601 r
.47946 .62789 m .47916 .63113 L .48259 .6297 L F
.349 .151 .464 r
.26621 .58087 m .26589 .58362 L .2639 .58416 L F
.509 .271 .489 r
.26594 .58601 m .2639 .58416 L .26589 .58362 L F
.26594 .58601 m .26368 .5865 L .2639 .58416 L F
.015 .582 .785 r
.45502 .60187 m .45569 .60184 L .45635 .60203 L F
.666 .2 .135 r
.45635 .60203 m .4546 .60326 L .45262 .60159 L F
0 0 0 r
.45569 .60184 m .4546 .60326 L .45602 .60183 L F
.672 .976 .863 r
.45728 .60055 m .45569 .60184 L .45635 .60203 L F
0 0 0 r
.45569 .60184 m .45602 .60183 L .45728 .60055 L F
.015 .582 .785 r
.45262 .60159 m .45569 .60184 L .45502 .60187 L F
.674 .943 .674 r
.45728 .60055 m .4546 .60326 L .45635 .60203 L F
.676 .286 .301 r
.45117 .57831 m .45086 .58074 L .44797 .57953 L F
.45086 .58074 m .45008 .581 L .44797 .57953 L F
0 0 .118 r
.45203 .57926 m .45077 .58148 L .45117 .57831 L F
.464 .403 .704 r
.44797 .57953 m .45008 .581 L .44901 .57771 L F
.676 .286 .301 r
.45086 .58074 m .45077 .58148 L .45008 .581 L F
.464 .403 .704 r
.45008 .581 m .45077 .58148 L .45039 .58065 L F
.45007 .58096 m .45038 .58065 L .44901 .57771 L F
.591 .466 .678 r
.44901 .57771 m .45077 .58148 L .45203 .57926 L F
.656 .265 .292 r
.44878 .58042 m .45139 .57949 L .44989 .58107 L F
.44946 .58121 m .44989 .58107 L .44957 .58133 L F
.711 .986 .832 r
.4499 .58066 m .44957 .58133 L .45041 .58063 L F
.656 .265 .292 r
.45139 .57949 m .45203 .57926 L .45041 .58063 L F
.711 .986 .832 r
.45129 .57975 m .45041 .58063 L .45203 .57926 L F
.656 .265 .292 r
.45139 .57949 m .45041 .58063 L .44989 .58107 L F
.711 .986 .832 r
.4499 .58066 m .45041 .58063 L .45129 .57975 L F
.464 .403 .704 r
.45008 .581 m .45039 .58065 L .45038 .58065 L F
.45008 .581 m .45038 .58065 L .45007 .58096 L F
.656 .265 .292 r
.44878 .58042 m .44989 .58107 L .44946 .58121 L F
.546 .567 .827 r
.45317 .57688 m .45117 .57831 L .44943 .5745 L F
0 0 .118 r
.45203 .57926 m .45117 .57831 L .45317 .57688 L F
.244 .71 .946 r
.52765 .59034 m .52608 .58971 L .52417 .58969 L F
0 .004 .579 r
.52765 .59034 m .52902 .5911 L .52608 .58971 L F
.52765 .59034 m .52928 .59255 L .52902 .5911 L F
.346 .097 .386 r
.62976 .40604 m .62932 .40824 L .62725 .40902 L F
.348 .106 .398 r
.63228 .40456 m .62932 .40824 L .62976 .40604 L F
.997 .769 .46 r
.43122 .63387 m .43101 .6364 L .43231 .63494 L F
.43122 .63387 m .43101 .6364 L .43231 .63494 L F
.918 .828 .741 r
.61991 .4791 m .62328 .47623 L .6221 .47545 L F
.61991 .4791 m .62133 .4805 L .62328 .47623 L F
.852 .916 .875 r
.62328 .47623 m .62448 .47289 L .6221 .47545 L F
.62328 .47623 m .62548 .474 L .62448 .47289 L F
.361 .619 .95 r
.39354 .63957 m .3937 .64057 L .39463 .63914 L F
.263 .487 .886 r
.3937 .64057 m .39648 .64172 L .39463 .63914 L F
0 0 0 r
.18507 .66132 m .18516 .66127 L .18501 .66139 L F
.888 .862 .809 r
.62578 .44227 m .62229 .44414 L .62412 .44088 L F
.62578 .44227 m .62353 .44537 L .62229 .44414 L F
.813 .782 .824 r
.62783 .4397 m .62578 .44227 L .62412 .44088 L F
.718 .544 .652 r
.57962 .53081 m .57925 .53173 L .57688 .5335 L F
.577 .374 .569 r
.58255 .52829 m .58244 .5308 L .57962 .53081 L F
.578 .385 .584 r
.58244 .5308 m .57925 .53173 L .57962 .53081 L F
.514 .123 .238 r
.17833 .61681 m .18115 .61697 L .18169 .61594 L F
.178 .704 .685 r
.17896 .61665 m .17833 .61681 L .18169 .61594 L F
0 0 0 r
.18259 .61576 m .18115 .61697 L .18169 .61594 L F
.18169 .61594 m .18259 .61576 L .17896 .61665 L F
.6 .453 .654 r
.42597 .59036 m .42611 .59309 L .42346 .59318 L F
.509 .127 .251 r
.42611 .59309 m .42586 .59387 L .42346 .59318 L F
.36 .028 .259 r
.62891 .40984 m .62725 .40902 L .62932 .40824 L F
.62891 .40984 m .62703 .41067 L .62725 .40902 L F
0 .271 .748 r
.18369 .63937 m .18412 .64035 L .18177 .63939 L F
.18369 .63937 m .18598 .64151 L .18412 .64035 L F
.348 .134 .44 r
.2592 .59535 m .25698 .59843 L .2574 .59583 L F
.426 .837 .654 r
.21647 .6101 m .2196 .60818 L .21717 .60796 L F
.555 .331 .531 r
.56862 .53708 m .57082 .53911 L .56843 .53891 L F
.56862 .53708 m .57076 .53652 L .57082 .53911 L F
.076 .16 .649 r
.38918 .63435 m .38971 .63783 L .39082 .63624 L F
.344 .537 .9 r
.38971 .63783 m .39354 .63957 L .39082 .63624 L F
.717 .363 .376 r
.21156 .65532 m .21089 .65932 L .20861 .6565 L F
0 0 0 r
.21178 .65614 m .21156 .65532 L .21378 .65488 L F
.21178 .65614 m .21089 .65932 L .21156 .65532 L F
0 0 .554 r
.41974 .59014 m .42176 .59375 L .42152 .59278 L F
.815 .369 .179 r
.41974 .59014 m .42152 .59278 L .41867 .59157 L F
.717 .407 .452 r
.54235 .58397 m .54488 .58439 L .54477 .58643 L F
.468 .102 .261 r
.54488 .58439 m .54752 .58648 L .54477 .58643 L F
.54488 .58439 m .55006 .58257 L .54752 .58648 L F
.785 .756 .827 r
.77853 .4241 m .77955 .42703 L .77672 .42591 L F
.81 .362 .175 r
.77955 .42703 m .77883 .42849 L .77672 .42591 L F
.358 .435 .804 r
.77968 .42352 m .77955 .42703 L .77853 .4241 L F
.77968 .42352 m .78168 .42546 L .77955 .42703 L F
0 0 0 r
.77955 .42703 m .78066 .42716 L .77883 .42849 L F
.77955 .42703 m .78168 .42546 L .78066 .42716 L F
.425 .277 .576 r
.37055 .60482 m .37249 .60423 L .37243 .60171 L F
.437 .338 .644 r
.37055 .60482 m .37289 .60682 L .37249 .60423 L F
.37055 .60482 m .37056 .60838 L .37289 .60682 L F
.7 .741 .883 r
.66314 .44752 m .66708 .4487 L .6657 .44679 L F
.685 .762 .91 r
.6657 .44679 m .66708 .4487 L .6696 .44754 L F
.904 .876 .799 r
.63682 .44111 m .64019 .43946 L .63934 .43862 L F
.63682 .44111 m .63806 .44231 L .64019 .43946 L F
.617 .901 .986 r
.63934 .43862 m .64019 .43946 L .64247 .43837 L F
.429 .638 .943 r
.26631 .55048 m .26584 .55298 L .26445 .55106 L F
.26631 .55048 m .26997 .55359 L .26584 .55298 L F
.586 .65 .88 r
.26982 .55453 m .26584 .55298 L .26997 .55359 L F
.121 0 .252 r
.59837 .4328 m .60053 .43171 L .60058 .42953 L F
.218 0 .233 r
.59837 .4328 m .60017 .43385 L .60053 .43171 L F
.59837 .4328 m .59813 .43486 L .60017 .43385 L F
.682 .823 .951 r
.6107 .46466 m .60878 .46558 L .60732 .46438 L F
.864 .651 .613 r
.60903 .46541 m .60732 .46438 L .60878 .46558 L F
.954 .882 .724 r
.62936 .46222 m .63046 .46023 L .62919 .45914 L F
.843 .882 .869 r
.7507 .39546 m .74742 .39683 L .75001 .39364 L F
.482 .589 .884 r
.75232 .39334 m .7507 .39546 L .75001 .39364 L F
.75232 .39334 m .75512 .39697 L .7507 .39546 L F
0 0 0 r
.58195 .47357 m .57932 .47626 L .58032 .47501 L F
.357 0 .021 r
.45186 .56481 m .45096 .56344 L .45329 .56289 L F
.033 0 0 r
.45096 .56344 m .45321 .56291 L .45329 .56289 L F
.45096 .56344 m .45075 .56391 L .4534 .56287 L F
.608 .651 .867 r
.45328 .5628 m .45075 .56391 L .44804 .55952 L F
.662 .558 .727 r
.45411 .56154 m .45328 .5628 L .45329 .56289 L F
.45328 .5628 m .4532 .56292 L .45321 .56292 L F
.45328 .5628 m .45321 .56292 L .45329 .56289 L F
.608 .651 .867 r
.45331 .56276 m .44876 .55997 L .45142 .56062 L F
.4534 .56287 m .45328 .5628 L .45331 .56276 L F
.45328 .5628 m .44804 .55952 L .45331 .56276 L F
.033 0 0 r
.45321 .56291 m .4534 .56287 L .45329 .56289 L F
.608 .651 .867 r
.4534 .56287 m .45318 .56296 L .45328 .5628 L F
.662 .558 .727 r
.45425 .56131 m .45328 .5628 L .45411 .56154 L F
0 0 0 r
.45329 .56289 m .4534 .56287 L .45425 .56131 L F
.574 .65 .887 r
.45425 .56131 m .4534 .56287 L .45331 .56276 L F
.45425 .56131 m .45331 .56276 L .4499 .5589 L F
.662 .558 .727 r
.45425 .56131 m .4532 .56292 L .45328 .5628 L F
.45425 .56131 m .45314 .56294 L .4532 .56292 L F
.45314 .56294 m .45186 .56481 L .45329 .56289 L F
.45425 .56132 m .4533 .56459 L .45186 .56481 L F
.608 .651 .867 r
.45142 .56062 m .44804 .55952 L .4499 .5589 L F
.44876 .55997 m .44804 .55952 L .45142 .56062 L F
.45318 .56296 m .45075 .56391 L .45328 .5628 L F
.717 .566 .683 r
.46491 .58403 m .4622 .58711 L .46189 .58451 L F
.46491 .58403 m .4622 .58711 L .46189 .58451 L F
.516 .122 .233 r
.75994 .43509 m .75932 .43604 L .75662 .43599 L F
.294 0 .1 r
.76128 .43621 m .75994 .43509 L .76225 .43495 L F
.76128 .43621 m .75932 .43604 L .75994 .43509 L F
.312 0 .258 r
.44159 .59282 m .44373 .5923 L .4435 .59078 L F
.4435 .59078 m .44373 .5923 L .44159 .59282 L F
.46 .09 .248 r
.4435 .59078 m .44373 .5923 L .44623 .59177 L F
.4435 .59078 m .44373 .5923 L .44623 .59177 L F
.626 .833 .98 r
.71079 .45357 m .71447 .45399 L .71329 .45282 L F
.692 .871 .966 r
.71329 .45282 m .71447 .45399 L .71648 .45276 L F
.77 .777 .274 r
.26997 .55359 m .26996 .55333 L .26982 .55453 L F
0 0 0 r
.27032 .55509 m .26982 .55453 L .26996 .55333 L F
.27032 .55509 m .2671 .55793 L .26982 .55453 L F
.738 .673 .787 r
.61805 .42604 m .61907 .42903 L .62098 .4262 L F
.209 0 .269 r
.60058 .42953 m .60247 .43069 L .60229 .42823 L F
.60058 .42953 m .60053 .43171 L .60247 .43069 L F
.426 .837 .654 r
.21647 .6101 m .21754 .60933 L .2196 .60818 L F
.693 .219 .121 r
.21754 .60933 m .22171 .61014 L .2196 .60818 L F
.826 .929 .9 r
.56405 .49364 m .56351 .49613 L .565 .49452 L F
.56405 .49364 m .56122 .49646 L .56351 .49613 L F
.225 .334 .766 r
.6374 .41924 m .63612 .42108 L .63494 .41989 L F
.6374 .41924 m .63724 .42135 L .63612 .42108 L F
.601 .046 0 r
.63612 .42108 m .63555 .42213 L .63494 .41989 L F
0 .249 .708 r
.63992 .42378 m .63876 .42273 L .63612 .42108 L F
.601 .046 0 r
.63612 .42108 m .63876 .42273 L .63555 .42213 L F
.527 .331 .558 r
.58472 .52763 m .58244 .5308 L .58255 .52829 L F
0 0 0 r
.56421 .47237 m .56518 .47249 L .56636 .47112 L F
.56421 .47237 m .56305 .47357 L .56518 .47249 L F
.151 .551 .927 r
.23977 .54087 m .23947 .54183 L .23775 .54066 L F
.23977 .54087 m .24133 .54225 L .23947 .54183 L F
.956 .897 .727 r
.22007 .58846 m .21894 .59276 L .22139 .58936 L F
.376 .18 .483 r
.21235 .6168 m .21398 .61641 L .21435 .61373 L F
.791 .886 .914 r
.18501 .66139 m .18344 .66038 L .18324 .66063 L F
.18501 .66139 m .18516 .66127 L .18344 .66038 L F
.96 .639 .363 r
.64224 .40585 m .64093 .40732 L .64065 .40465 L F
.113 .647 .862 r
.17833 .61681 m .18115 .61697 L .17896 .61665 L F
.486 .434 .724 r
.44431 .57776 m .44244 .57798 L .44154 .57839 L F
.081 .208 .697 r
.76566 .409 m .76753 .41126 L .76665 .41266 L F
.004 .048 .556 r
.76806 .41407 m .76665 .41266 L .76753 .41126 L F
.76806 .41407 m .76816 .4157 L .76665 .41266 L F
.501 .226 .429 r
.44946 .57168 m .45203 .57137 L .45224 .56932 L F
.658 .361 .456 r
.45203 .57137 m .45459 .57158 L .45224 .56932 L F
.431 .825 .984 r
.19112 .66024 m .19145 .65923 L .18917 .65964 L F
.19112 .66024 m .19327 .65977 L .19145 .65923 L F
.704 .411 .476 r
.54235 .58397 m .5417 .58528 L .54096 .58336 L F
.54235 .58397 m .54477 .58643 L .5417 .58528 L F
.803 .546 .549 r
.54755 .52985 m .54876 .52741 L .54755 .52728 L F
.54755 .52985 m .55155 .53085 L .54876 .52741 L F
.302 .783 .699 r
.74081 .39772 m .74162 .39745 L .73948 .39832 L F
.7412 .39755 m .7413 .39753 L .74081 .39772 L F
.7413 .39753 m .74162 .39745 L .74081 .39772 L F
.428 .566 .89 r
.73953 .39824 m .73443 .3938 L .73686 .39278 L F
.302 .783 .699 r
.74083 .39772 m .74162 .39745 L .73948 .39832 L F
.7412 .39755 m .74129 .39753 L .74083 .39772 L F
.74129 .39753 m .74162 .39745 L .74083 .39772 L F
.537 .521 .786 r
.73937 .39184 m .73961 .39821 L .73686 .39278 L F
.302 .783 .699 r
.7412 .39755 m .74083 .39772 L .73962 .39843 L F
.74083 .39772 m .73948 .39832 L .73962 .39843 L F
.537 .521 .786 r
.73961 .39821 m .73962 .39843 L .73953 .39824 L F
.73961 .39821 m .73953 .39824 L .73686 .39278 L F
.428 .566 .89 r
.73962 .39843 m .73945 .39827 L .73953 .39824 L F
.73945 .39827 m .73443 .3938 L .73953 .39824 L F
.855 .878 .855 r
.62353 .44537 m .61973 .44716 L .62229 .44414 L F
.801 .642 .685 r
.54755 .52728 m .54897 .52383 L .54619 .52405 L F
.46 .185 .41 r
.73759 .42008 m .74014 .42008 L .74027 .4174 L F
.457 .119 .303 r
.74014 .42008 m .74297 .41775 L .74027 .4174 L F
.29 .402 .804 r
.19644 .68328 m .19579 .68463 L .19369 .68396 L F
.718 .649 .779 r
.19452 .68413 m .19369 .68396 L .19579 .68463 L F
.297 .52 .901 r
.19452 .68413 m .19579 .68463 L .19522 .68398 L F
.21 .088 .486 r
.19369 .68396 m .19483 .6842 L .19644 .68328 L F
.444 .59 .903 r
.19522 .68398 m .19579 .68463 L .19644 .68328 L F
.21 .088 .486 r
.19483 .6842 m .19596 .68444 L .19644 .68328 L F
.444 .59 .903 r
.19251 .68084 m .19522 .68398 L .19644 .68328 L F
.297 .52 .901 r
.19251 .68335 m .19452 .68413 L .19251 .68084 L F
.19452 .68413 m .19522 .68398 L .19251 .68084 L F
.21 .088 .486 r
.19452 .68413 m .19492 .68695 L .19596 .68444 L F
.19369 .68396 m .19383 .68429 L .19452 .68413 L F
.19383 .68429 m .19492 .68695 L .19452 .68413 L F
.718 .649 .779 r
.19251 .68335 m .19369 .68396 L .19452 .68413 L F
.67 .377 .467 r
.44353 .64028 m .44578 .64266 L .44576 .64065 L F
.44353 .64028 m .4421 .6429 L .44578 .64266 L F
.686 .93 .968 r
.6827 .45052 m .68396 .44889 L .6851 .44983 L F
.6827 .45052 m .68171 .4497 L .68396 .44889 L F
.576 .829 .993 r
.18685 .66033 m .18645 .65817 L .18446 .66048 L F
.666 .871 .976 r
.18344 .66038 m .18446 .66048 L .18332 .65862 L F
.611 .843 .987 r
.18332 .65862 m .18446 .66048 L .18505 .6598 L F
.1854 .65832 m .18505 .6598 L .18645 .65817 L F
.18332 .65862 m .18505 .6598 L .1854 .65832 L F
.634 .864 .985 r
.18491 .66036 m .18516 .66127 L .18685 .66033 L F
.18344 .66038 m .18475 .66105 L .18491 .66036 L F
.18491 .66036 m .18685 .66033 L .18494 .66045 L F
.18491 .66036 m .18494 .66045 L .18446 .66048 L F
.18344 .66038 m .18491 .66036 L .18446 .66048 L F
.18475 .66105 m .18516 .66127 L .18491 .66036 L F
.827 .993 .743 r
.569 .48782 m .56829 .48974 L .57067 .48688 L F
.827 .997 .768 r
.57144 .48482 m .57067 .48688 L .57327 .48386 L F
.827 .993 .743 r
.57144 .48482 m .569 .48782 L .57067 .48688 L F
.217 .103 .502 r
.20569 .67547 m .20386 .67901 L .2035 .67573 L F
.20569 .67547 m .20562 .6782 L .20386 .67901 L F
.204 0 .324 r
.20562 .6782 m .20343 .68136 L .20386 .67901 L F
.348 .174 .497 r
.58572 .50609 m .5838 .50705 L .58373 .50938 L F
.307 .335 .727 r
.26872 .57088 m .26744 .57251 L .26657 .56885 L F
.559 .376 .59 r
.27004 .57412 m .26744 .57251 L .26872 .57088 L F
.27004 .57412 m .26745 .57488 L .26744 .57251 L F
.524 .341 .574 r
.51933 .68154 m .51923 .6844 L .51676 .68218 L F
0 .053 .54 r
.51676 .68218 m .51802 .68327 L .51933 .68154 L F
.51676 .68218 m .51923 .6844 L .51802 .68327 L F
.122 0 .248 r
.58797 .50293 m .58625 .50406 L .58572 .50609 L F
.713 .759 .888 r
.63417 .43932 m .63036 .43874 L .63268 .43731 L F
.407 .583 .913 r
.63772 .43951 m .63417 .43932 L .63268 .43731 L F
0 .268 .772 r
.39819 .64308 m .39853 .64191 L .39648 .64172 L F
.39819 .64308 m .39908 .64346 L .39853 .64191 L F
.973 .889 .683 r
.60734 .47352 m .60838 .47475 L .60733 .47683 L F
.623 .674 .878 r
.71613 .40583 m .71979 .40683 L .71859 .40508 L F
.707 .733 .871 r
.71979 .40683 m .72123 .40403 L .71859 .40508 L F
.71979 .40683 m .72222 .40592 L .72123 .40403 L F
.449 .565 .88 r
.71979 .40683 m .7224 .40855 L .72222 .40592 L F
.794 .537 0 r
.45994 .60497 m .46096 .60348 L .46272 .60678 L F
.45994 .60497 m .46052 .608 L .45995 .60612 L F
.511 .41 .676 r
.46272 .60678 m .46052 .608 L .45994 .60497 L F
.794 .537 0 r
.45994 .60497 m .45995 .60612 L .46096 .60348 L F
.387 0 0 r
.46057 .56899 m .45723 .56839 L .4584 .5695 L F
.565 .481 .718 r
.55333 .55153 m .5562 .55396 L .55392 .55452 L F
.55333 .55153 m .55568 .55099 L .5562 .55396 L F
.868 .72 .695 r
.53783 .54805 m .54053 .54887 L .53944 .54718 L F
.879 .585 .487 r
.53921 .55049 m .54053 .54887 L .53783 .54805 L F
.613 .223 .28 r
.53921 .55049 m .54307 .55033 L .54053 .54887 L F
.582 .281 .423 r
.54053 .54887 m .54307 .55033 L .54322 .54836 L F
.293 .791 .839 r
.74462 .42167 m .74326 .42159 L .74068 .42223 L F
.61 .362 .517 r
.57688 .5335 m .57925 .53173 L .57945 .53561 L F
.578 .385 .584 r
.58244 .5308 m .58218 .53284 L .57925 .53173 L F
.594 .349 .515 r
.57925 .53173 m .58247 .5354 L .57945 .53561 L F
.57925 .53173 m .58218 .53284 L .58247 .5354 L F
.814 .979 .893 r
.72456 .44682 m .72227 .45011 L .72537 .44774 L F
.72456 .44682 m .72166 .44937 L .72227 .45011 L F
.764 .669 .758 r
.19783 .554 m .19937 .55766 L .1955 .55716 L F
.489 .804 1 r
.19937 .55766 m .19766 .5567 L .1955 .55716 L F
.585 .579 .812 r
.20155 .55698 m .19937 .55766 L .19783 .554 L F
.20155 .55698 m .20051 .55614 L .19966 .555 L F
.20051 .55614 m .19783 .554 L .19966 .555 L F
.981 .826 .616 r
.20004 .55344 m .19966 .555 L .19783 .554 L F
.20004 .55344 m .19899 .5541 L .19966 .555 L F
.19899 .5541 m .1981 .55466 L .19966 .555 L F
.803 .879 .902 r
.19966 .555 m .19937 .55766 L .20155 .55698 L F
.19966 .555 m .19766 .5567 L .19937 .55766 L F
.692 .726 .876 r
.74426 .41156 m .74457 .41531 L .74207 .41517 L F
.425 .515 .846 r
.74719 .41263 m .74457 .41531 L .74426 .41156 L F
.308 .761 .956 r
.74207 .41517 m .74457 .41531 L .74469 .41455 L F
.637 .959 .792 r
.74469 .41455 m .74457 .41531 L .74719 .41263 L F
.623 .759 .943 r
.51163 .56275 m .51301 .56443 L .51521 .56348 L F
.167 .514 .915 r
.37237 .63659 m .3749 .63806 L .37409 .63678 L F
.718 .566 .683 r
.45875 .58695 m .4622 .58711 L .46189 .58451 L F
.646 .899 .983 r
.73851 .43998 m .7425 .4397 L .74099 .43914 L F
.42 .844 .956 r
.74439 .43919 m .74099 .43914 L .7425 .4397 L F
0 0 .083 r
.23302 .58405 m .23461 .58066 L .23235 .58131 L F
.571 .736 .954 r
.71248 .40476 m .71613 .40583 L .71503 .40397 L F
.625 .721 .916 r
.71613 .40583 m .71761 .40256 L .71503 .40397 L F
.71613 .40583 m .71859 .40508 L .71761 .40256 L F
.69 .898 .539 r
.51327 .52664 m .51204 .52839 L .51289 .52682 L F
.831 .919 .895 r
.51062 .53116 m .51289 .52682 L .51204 .52839 L F
.556 .933 .882 r
.52097 .53074 m .52005 .53068 L .52243 .52939 L F
.52243 .52939 m .52005 .53068 L .52097 .53074 L F
.178 0 .055 r
.45808 .64202 m .45828 .64096 L .46056 .64007 L F
.559 .786 .984 r
.69291 .40347 m .69431 .40487 L .69661 .40426 L F
.75 .231 0 r
.63992 .42378 m .64379 .42682 L .64233 .42573 L F
.638 .114 0 r
.64233 .42573 m .64379 .42682 L .64561 .42886 L F
.873 .836 .806 r
.72874 .40851 m .73153 .4082 L .73227 .40656 L F
.508 .552 .836 r
.41662 .63432 m .41998 .63699 L .42077 .63462 L F
0 0 0 r
.41998 .63699 m .42272 .63508 L .42077 .63462 L F
.925 .928 .792 r
.56603 .49064 m .56716 .49132 L .56829 .48974 L F
.814 .996 .856 r
.569 .48782 m .56603 .49064 L .56829 .48974 L F
.888 .99 .757 r
.57367 .48166 m .57144 .48482 L .57327 .48386 L F
.761 .54 .598 r
.44578 .64266 m .44916 .64059 L .44576 .64065 L F
.897 .968 .822 r
.52429 .51857 m .52094 .52099 L .52343 .51813 L F
.52429 .51857 m .52183 .52164 L .52094 .52099 L F
.881 .989 .809 r
.52429 .51857 m .52597 .51497 L .52663 .51564 L F
.52429 .51857 m .52343 .51813 L .52597 .51497 L F
.78 .541 .575 r
.20168 .675 m .2057 .67294 L .2035 .67573 L F
.479 .298 .557 r
.2057 .67294 m .20569 .67547 L .2035 .67573 L F
0 0 .435 r
.68418 .45647 m .68546 .45724 L .68337 .45487 L F
.68418 .45647 m .68456 .45912 L .68546 .45724 L F
.887 .851 .802 r
.66919 .42003 m .67272 .41825 L .6716 .41714 L F
.66919 .42003 m .67057 .42154 L .67272 .41825 L F
.437 .234 .504 r
.41002 .62438 m .40804 .62266 L .41095 .62243 L F
.41002 .62438 m .4079 .62509 L .40804 .62266 L F
.573 .767 .971 r
.40706 .62356 m .41095 .62243 L .40804 .62266 L F
.40706 .62356 m .4079 .62509 L .41002 .62438 L F
.40706 .62356 m .41002 .62438 L .41095 .62243 L F
0 .032 .599 r
.40768 .62256 m .40832 .62472 L .40706 .62356 L F
.40832 .62472 m .40873 .62609 L .40706 .62356 L F
.533 0 0 r
.40585 .62244 m .40706 .62356 L .40804 .62266 L F
.40403 .62226 m .40706 .62356 L .40585 .62244 L F
.666 .752 .915 r
.537 .68116 m .5392 .68226 L .5359 .68228 L F
.895 .903 .825 r
.63472 .44417 m .63685 .44413 L .63806 .44231 L F
.915 .872 .781 r
.63472 .44417 m .63497 .44725 L .63685 .44413 L F
.825 .623 .63 r
.53524 .59596 m .53161 .59795 L .5316 .59543 L F
.53524 .59596 m .53508 .59891 L .53161 .59795 L F
.667 .524 .68 r
.53761 .59298 m .54031 .59653 L .53524 .59596 L F
.666 .417 .534 r
.53524 .59596 m .53784 .59877 L .53508 .59891 L F
.53524 .59596 m .54031 .59653 L .53784 .59877 L F
.503 .465 .748 r
.42919 .58058 m .42607 .57733 L .42894 .57807 L F
.369 .159 .459 r
.24504 .6209 m .24374 .61957 L .24582 .61882 L F
.24504 .6209 m .24312 .62192 L .24374 .61957 L F
.746 .274 .126 r
.67059 .40753 m .67409 .40871 L .67287 .40749 L F
.421 .719 .986 r
.67287 .40749 m .67409 .40871 L .67517 .40724 L F
.332 .597 .943 r
.67517 .40724 m .67409 .40871 L .67669 .40904 L F
.691 .212 .108 r
.63992 .42378 m .63882 .42534 L .63876 .42273 L F
.63992 .42378 m .64233 .42573 L .63882 .42534 L F
.905 .619 .492 r
.5081 .5308 m .50873 .53108 L .51062 .53116 L F
.831 .919 .895 r
.51062 .53116 m .50873 .53108 L .50876 .53105 L F
.738 .455 .5 r
.50876 .53105 m .5081 .5308 L .51062 .53116 L F
.82 .881 .889 r
.51289 .52682 m .50876 .53105 L .50833 .52815 L F
.50876 .53105 m .50873 .53108 L .50872 .53104 L F
.50876 .53105 m .50872 .53104 L .50833 .52815 L F
.738 .455 .5 r
.50874 .53105 m .50872 .53104 L .50876 .53105 L F
.50872 .53104 m .5081 .5308 L .50876 .53105 L F
.721 .818 .925 r
.50872 .53104 m .50873 .53108 L .5081 .5308 L F
.738 .455 .5 r
.50849 .53103 m .5081 .5308 L .50874 .53105 L F
.721 .818 .925 r
.50833 .52815 m .50872 .53104 L .5081 .5308 L F
.831 .919 .895 r
.51062 .53116 m .50876 .53105 L .51289 .52682 L F
.738 .455 .5 r
.51071 .53237 m .50849 .53103 L .51062 .53116 L F
.392 .792 .985 r
.21894 .59276 m .21766 .59202 L .21562 .59241 L F
.777 .663 .737 r
.21562 .59241 m .21686 .59593 L .21894 .59276 L F
.956 .897 .727 r
.22007 .58846 m .21766 .59202 L .21894 .59276 L F
.392 .016 .201 r
.15866 .55021 m .16157 .5483 L .16035 .54908 L F
.947 .893 .742 r
.66569 .42702 m .6663 .42286 L .66475 .42642 L F
.998 .829 .549 r
.66475 .42642 m .66534 .42955 L .66569 .42702 L F
.8 .899 .912 r
.6663 .42286 m .67057 .42154 L .66919 .42003 L F
.505 .004 0 r
.16917 .56341 m .16394 .56409 L .16709 .56441 L F
.667 .463 .6 r
.42695 .58334 m .4232 .58485 L .4235 .5814 L F
.24 0 0 r
.75662 .43599 m .75822 .43665 L .75579 .43651 L F
.75662 .43599 m .75932 .43604 L .75822 .43665 L F
.005 .335 .818 r
.51681 .56891 m .51944 .57042 L .5173 .56767 L F
.461 .274 .539 r
.54606 .54586 m .54841 .54493 L .54835 .54249 L F
.449 .249 .515 r
.54815 .54736 m .54606 .54586 L .54555 .54788 L F
.54815 .54736 m .54841 .54493 L .54606 .54586 L F
0 0 .146 r
.21435 .61373 m .216 .61254 L .21647 .6101 L F
.03 0 .344 r
.21435 .61373 m .21556 .61534 L .216 .61254 L F
.21435 .61373 m .21398 .61641 L .21556 .61534 L F
.387 .117 .377 r
.58761 .52421 m .59004 .52178 L .58958 .52409 L F
.492 .288 .531 r
.59004 .52178 m .59242 .51881 L .59233 .52105 L F
.476 .249 .49 r
.58958 .52409 m .59004 .52178 L .59233 .52105 L F
.73 .739 .859 r
.68214 .40849 m .68536 .40818 L .6851 .40645 L F
.776 .979 .911 r
.68536 .40818 m .68734 .40554 L .6851 .40645 L F
.68536 .40818 m .68829 .40598 L .68734 .40554 L F
.594 .576 .803 r
.478 .56487 m .47706 .56993 L .47517 .56569 L F
.478 .56487 m .47965 .56936 L .47706 .56993 L F
.397 .036 .23 r
.47965 .56936 m .47709 .57052 L .47706 .56993 L F
.089 0 0 r
.19744 .54039 m .19959 .54054 L .20145 .54053 L F
.156 0 0 r
.19959 .54054 m .20338 .54046 L .20145 .54053 L F
.752 .976 .718 r
.52597 .51497 m .52889 .51239 L .52663 .51564 L F
0 0 .191 r
.60259 .42663 m .60446 .42505 L .60498 .42299 L F
0 0 0 r
.60259 .42663 m .60229 .42823 L .60446 .42505 L F
.903 .494 .189 r
.5089 .55429 m .50731 .55347 L .50655 .55131 L F
.796 .503 0 r
.5089 .55429 m .50897 .55562 L .50731 .55347 L F
.5089 .55429 m .50936 .55637 L .50897 .55562 L F
0 .137 .664 r
.50897 .55562 m .50588 .55227 L .50731 .55347 L F
.50897 .55562 m .50882 .55502 L .50588 .55227 L F
0 .447 .858 r
.50897 .55562 m .50833 .55441 L .50882 .55502 L F
0 0 .29 r
.50897 .55562 m .50998 .55652 L .50835 .55444 L F
0 .138 .594 r
.50823 .55447 m .5041 .55147 L .50588 .55227 L F
.50882 .55502 m .5085 .55479 L .50823 .55447 L F
.5085 .55479 m .5041 .55147 L .50823 .55447 L F
0 0 .29 r
.50857 .55487 m .50838 .55449 L .50833 .55441 L F
.50858 .55488 m .50835 .55444 L .50857 .55487 L F
.347 0 0 r
.50833 .55441 m .50773 .55414 L .50859 .55484 L F
.741 .257 0 r
.50833 .55441 m .50833 .55473 L .50772 .55413 L F
.50833 .55441 m .50772 .55413 L .50765 .55407 L F
.347 0 0 r
.50833 .55441 m .50769 .55409 L .50773 .55414 L F
0 .179 .688 r
.50765 .55407 m .50772 .55413 L .5076 .55395 L F
.347 0 0 r
.50769 .55409 m .50765 .55407 L .50764 .55406 L F
.50833 .55441 m .50765 .55407 L .50769 .55409 L F
0 .179 .688 r
.5076 .55395 m .50777 .55413 L .50733 .55331 L F
.50777 .55413 m .50833 .55473 L .508 .55426 L F
.50777 .55413 m .508 .55426 L .50733 .55331 L F
.347 0 0 r
.50769 .55409 m .50771 .55412 L .50773 .55414 L F
0 .138 .594 r
.50536 .55242 m .50764 .55406 L .5041 .55147 L F
.50882 .55502 m .50771 .55412 L .50536 .55242 L F
.50771 .55412 m .50764 .55406 L .50536 .55242 L F
0 .179 .688 r
.50772 .55413 m .50833 .55473 L .50786 .55423 L F
.50771 .55412 m .50786 .55423 L .5076 .55395 L F
.50772 .55413 m .50786 .55423 L .50771 .55412 L F
.347 0 0 r
.50769 .55409 m .50764 .55406 L .50771 .55412 L F
.50833 .55441 m .50859 .55484 L .50882 .55502 L F
0 0 .29 r
.50838 .55449 m .50835 .55444 L .50833 .55441 L F
.50897 .55562 m .50858 .55488 L .50857 .55487 L F
.796 .503 0 r
.50936 .55637 m .50949 .55694 L .50897 .55562 L F
.727 .539 .636 r
.21769 .55455 m .21356 .55675 L .21381 .55427 L F
.21769 .55455 m .21693 .55741 L .21356 .55675 L F
0 0 0 r
.22009 .55443 m .21693 .55741 L .21769 .55455 L F
.767 .996 .861 r
.57874 .47607 m .5778 .478 L .57932 .47626 L F
.57874 .47607 m .57598 .47835 L .5778 .478 L F
.716 .302 .261 r
.17758 .56045 m .17689 .56186 L .17549 .56042 L F
.409 .2 .482 r
.18047 .55728 m .18018 .56004 L .17758 .56045 L F
.31 0 .076 r
.17862 .56128 m .17758 .56045 L .18018 .56004 L F
.17862 .56128 m .17689 .56186 L .17758 .56045 L F
.436 0 0 r
.46475 .56929 m .46332 .56974 L .46057 .56899 L F
.475 .28 .535 r
.46475 .56929 m .46446 .57181 L .46672 .57108 L F
0 .048 .539 r
.46475 .56929 m .46533 .56976 L .46332 .56974 L F
.523 .88 .649 r
.46632 .56876 m .46523 .56962 L .46533 .56976 L F
.468 0 0 r
.46511 .5698 m .46394 .57066 L .46115 .57046 L F
.46533 .56976 m .46394 .57066 L .46511 .5698 L F
0 .048 .539 r
.46475 .56929 m .46544 .56992 L .46533 .56976 L F
.468 0 0 r
.46533 .56976 m .46115 .57046 L .46332 .56974 L F
.528 .295 .506 r
.46632 .56876 m .46353 .57097 L .46394 .57066 L F
.527 .372 .614 r
.46331 .57114 m .46115 .57046 L .46394 .57066 L F
.528 .295 .506 r
.46353 .57097 m .46331 .57114 L .46394 .57066 L F
.523 .88 .649 r
.46523 .56962 m .46394 .57066 L .46533 .56976 L F
0 .048 .539 r
.46544 .56992 m .46672 .57108 L .46533 .56976 L F
.688 .783 .923 r
.7433 .43241 m .74051 .43328 L .7397 .43176 L F
.533 .533 .801 r
.53761 .59298 m .53877 .58892 L .53864 .5918 L F
.413 .793 .992 r
.53864 .5918 m .53993 .59262 L .53761 .59298 L F
.761 .537 .594 r
.54124 .59593 m .53761 .59298 L .53993 .59262 L F
.54124 .59593 m .54031 .59653 L .53761 .59298 L F
.697 .557 .691 r
.55106 .58141 m .55079 .58385 L .55006 .58257 L F
.691 .569 .712 r
.5531 .57936 m .554 .58085 L .55106 .58141 L F
.694 .559 .698 r
.554 .58085 m .55079 .58385 L .55106 .58141 L F
.424 .406 .735 r
.26762 .56461 m .26657 .56885 L .26584 .56798 L F
.42 .429 .763 r
.55153 .56946 m .55303 .56845 L .55383 .57214 L F
.366 .526 .883 r
.44804 .55952 m .44689 .56174 L .4462 .55923 L F
.505 .64 .915 r
.23203 .55602 m .23322 .55786 L .23406 .55556 L F
.545 .684 .93 r
.23322 .55786 m .23573 .55772 L .23406 .55556 L F
.91 .837 .76 r
.53535 .68192 m .537 .68116 L .53551 .67995 L F
.13 .655 .877 r
.53493 .68182 m .5359 .68228 L .53315 .68191 L F
.53535 .68192 m .5359 .68228 L .53493 .68182 L F
.53535 .68192 m .53535 .68192 L .53535 .68192 L F
.53535 .68192 m .5359 .68228 L .53535 .68192 L F
.749 .465 .502 r
.53315 .68191 m .5359 .68228 L .53515 .68433 L F
.717 .467 .547 r
.53315 .68191 m .53515 .68433 L .53232 .68453 L F
.91 .837 .76 r
.53515 .68433 m .53535 .68192 L .53385 .68348 L F
.406 .69 .977 r
.53268 .68012 m .53457 .68145 L .53192 .68151 L F
.53465 .68145 m .5349 .68178 L .53192 .68151 L F
.13 .655 .877 r
.53517 .68181 m .53315 .68191 L .53192 .68151 L F
.873 .747 .721 r
.53268 .68012 m .53385 .68348 L .53474 .68158 L F
.53268 .68012 m .53474 .68158 L .53551 .67995 L F
.406 .69 .977 r
.53268 .68012 m .53465 .68145 L .53457 .68145 L F
.91 .837 .76 r
.53535 .68192 m .53474 .68158 L .53491 .68179 L F
.406 .69 .977 r
.53465 .68145 m .53517 .68181 L .5349 .68178 L F
.91 .837 .76 r
.53535 .68192 m .53551 .67995 L .53474 .68158 L F
.53491 .68179 m .53474 .68158 L .53468 .68172 L F
.53535 .68192 m .53468 .68172 L .53385 .68348 L F
0 0 .134 r
.537 .68116 m .5359 .68228 L .53515 .68433 L F
.91 .837 .76 r
.53515 .68433 m .5364 .68219 L .53535 .68192 L F
.725 .989 .864 r
.537 .68116 m .5359 .68228 L .53535 .68192 L F
.91 .837 .76 r
.53535 .68192 m .537 .68116 L .53535 .68192 L F
.725 .989 .864 r
.537 .68116 m .53535 .68192 L .53517 .68181 L F
.91 .837 .76 r
.5364 .68219 m .537 .68116 L .53535 .68192 L F
.13 .655 .877 r
.53517 .68181 m .53535 .68192 L .53493 .68182 L F
.864 .842 .821 r
.61484 .45298 m .61344 .45102 L .61465 .4506 L F
.713 .981 .784 r
.61465 .4506 m .61584 .44878 L .61686 .44999 L F
.61465 .4506 m .61344 .45102 L .61584 .44878 L F
.642 .545 .73 r
.61686 .44999 m .61484 .45298 L .61465 .4506 L F
.995 .81 .444 r
.76718 .41945 m .76774 .42213 L .76794 .42063 L F
.625 .463 .643 r
.55904 .52172 m .56219 .52175 L .56127 .51865 L F
.609 .479 .678 r
.56219 .52175 m .5638 .51763 L .56127 .51865 L F
.933 .562 .176 r
.40347 .63305 m .40473 .63409 L .40286 .6311 L F
.423 0 0 r
.40556 .63475 m .40473 .63409 L .40347 .63305 L F
.40556 .63475 m .40715 .63575 L .40473 .63409 L F
0 0 0 r
.59629 .49259 m .59361 .4953 L .5953 .49368 L F
.59873 .4893 m .59629 .49259 L .5982 .49141 L F
.5982 .49141 m .59629 .49259 L .5953 .49368 L F
.342 0 0 r
.16465 .54749 m .16708 .54727 L .16869 .546 L F
.042 0 0 r
.16708 .54727 m .17089 .54596 L .16869 .546 L F
0 .197 .666 r
.75127 .42038 m .75398 .42235 L .74965 .41896 L F
.403 .338 .67 r
.55445 .5744 m .5531 .57936 L .55234 .57499 L F
.314 .077 .386 r
.59242 .51881 m .59479 .51576 L .59432 .51796 L F
.376 .196 .506 r
.59233 .52105 m .59242 .51881 L .59432 .51796 L F
.246 .289 .71 r
.24106 .5659 m .24178 .56927 L .24312 .56787 L F
.176 .128 .561 r
.24198 .57176 m .24312 .56787 L .24178 .56927 L F
.048 0 0 r
.45385 .56511 m .45677 .56468 L .45674 .56435 L F
.264 .765 .725 r
.45677 .56468 m .45901 .56403 L .45674 .56435 L F
.923 .532 .2 r
.55006 .58257 m .54984 .58507 L .54752 .58648 L F
.55006 .58257 m .55079 .58385 L .54984 .58507 L F
.813 .782 .824 r
.62783 .4397 m .62412 .44088 L .6269 .43828 L F
.664 .805 .951 r
.6269 .43828 m .63036 .43874 L .62783 .4397 L F
.401 .328 .659 r
.3713 .61066 m .37289 .60682 L .37056 .60838 L F
.949 .83 .692 r
.63992 .41535 m .63778 .41682 L .63952 .41309 L F
.63992 .41535 m .63922 .41851 L .63778 .41682 L F
.347 .368 .74 r
.63964 .41144 m .63992 .41535 L .64134 .41396 L F
.63964 .41144 m .64134 .41396 L .64108 .4124 L F
.645 .769 .939 r
.63888 .41106 m .6365 .41219 L .63964 .41144 L F
.575 .829 .993 r
.63964 .41144 m .6389 .41039 L .6421 .41067 L F
.347 .368 .74 r
.63964 .41144 m .64219 .41313 L .6421 .41067 L F
.627 .429 .595 r
.64078 .41056 m .63952 .41309 L .6389 .41039 L F
.6421 .41067 m .64097 .41172 L .64078 .41056 L F
.64097 .41172 m .63952 .41309 L .64078 .41056 L F
.347 .368 .74 r
.64108 .4124 m .64134 .41396 L .64219 .41313 L F
.557 .717 .947 r
.64219 .41313 m .63992 .41535 L .63952 .41309 L F
.097 .638 .849 r
.19251 .68335 m .19077 .68296 L .18857 .68284 L F
.297 .52 .901 r
.19251 .68335 m .19251 .68084 L .19077 .68296 L F
.588 .531 .758 r
.54477 .58643 m .54308 .58953 L .54245 .58736 L F
.54477 .58643 m .54571 .58954 L .54308 .58953 L F
.512 .109 .213 r
.54478 .5914 m .54308 .58953 L .54571 .58954 L F
.54478 .5914 m .54205 .59191 L .54308 .58953 L F
.698 .536 .664 r
.55614 .52458 m .55971 .52479 L .55904 .52172 L F
.675 .559 .716 r
.55971 .52479 m .56219 .52175 L .55904 .52172 L F
.395 .003 .174 r
.38803 .59225 m .39037 .59187 L .39167 .58961 L F
.437 .044 .195 r
.39037 .59187 m .39403 .58944 L .39167 .58961 L F
.49 .166 .344 r
.39167 .58961 m .39403 .58944 L .39405 .58859 L F
.921 .923 .796 r
.61851 .48082 m .61959 .48338 L .62133 .4805 L F
.995 .858 .525 r
.61897 .4859 m .61959 .48338 L .61851 .48082 L F
.574 .753 .962 r
.69867 .45486 m .70232 .45587 L .70127 .45428 L F
.608 .775 .96 r
.70127 .45428 m .70232 .45587 L .70445 .45514 L F
.685 .753 .903 r
.7247 .39325 m .72326 .39674 L .72228 .39421 L F
.7247 .39325 m .72605 .39586 L .72326 .39674 L F
.689 .713 .867 r
.69476 .44862 m .69127 .44781 L .69362 .44685 L F
.751 .708 .812 r
.69727 .44724 m .69476 .44862 L .69362 .44685 L F
.948 .642 .423 r
.50509 .58459 m .50331 .58551 L .50289 .5833 L F
.079 0 0 r
.50563 .58508 m .50509 .58459 L .50647 .58315 L F
.50563 .58508 m .50331 .58551 L .50509 .58459 L F
.638 .305 .39 r
.4351 .64618 m .43129 .64832 L .43196 .64698 L F
.4351 .64618 m .43368 .64862 L .43129 .64832 L F
.664 .334 .405 r
.43732 .64841 m .43368 .64862 L .4351 .64618 L F
.656 .336 .419 r
.4378 .64653 m .43732 .64841 L .4351 .64618 L F
.543 .697 .94 r
.22983 .5565 m .23203 .55602 L .22974 .55387 L F
.437 .231 .501 r
.39931 .61634 m .39928 .61807 L .39737 .61753 L F
.469 .392 .687 r
.39997 .62013 m .39824 .62092 L .39737 .61753 L F
.652 .25 .271 r
.19961 .68773 m .19585 .68819 L .19635 .69165 L F
.672 .841 .424 r
.19394 .69222 m .1941 .69178 L .1948 .69064 L F
.652 .25 .271 r
.19961 .68773 m .19841 .69046 L .1962 .6885 L F
.19645 .68812 m .1962 .6885 L .19585 .68819 L F
.19961 .68773 m .1962 .6885 L .19645 .68812 L F
0 .225 .742 r
.19585 .68819 m .19841 .69046 L .19647 .68791 L F
.672 .841 .424 r
.19546 .68963 m .1948 .69064 L .19647 .68791 L F
.19394 .69222 m .1948 .69064 L .19546 .68963 L F
.732 .762 .258 r
.20062 .68409 m .19979 .68668 L .19961 .68773 L F
.709 .522 .634 r
.19894 .68877 m .19647 .68791 L .19785 .68823 L F
.20018 .68939 m .19899 .68891 L .19898 .68889 L F
.744 .803 .324 r
.19899 .68891 m .19841 .69046 L .19903 .68904 L F
.709 .522 .634 r
.19899 .68891 m .19841 .69046 L .19647 .68791 L F
.19899 .68891 m .19841 .69046 L .19647 .68791 L F
.20018 .68939 m .19841 .69046 L .19899 .68891 L F
.744 .803 .324 r
.19904 .68877 m .19903 .68904 L .19961 .68773 L F
.19898 .68889 m .19899 .68891 L .19904 .68877 L F
.19899 .68891 m .19903 .68904 L .19904 .68877 L F
.19898 .68889 m .19841 .69046 L .19899 .68891 L F
.709 .522 .634 r
.20018 .68939 m .19841 .69046 L .19899 .68891 L F
.761 .632 .719 r
.20018 .68939 m .19841 .69046 L .19898 .68889 L F
.744 .803 .324 r
.19979 .68668 m .19898 .68889 L .19961 .68773 L F
.761 .632 .719 r
.20018 .68939 m .19898 .68889 L .19979 .68668 L F
.709 .522 .634 r
.20018 .68939 m .19898 .68889 L .19894 .68877 L F
.19899 .68891 m .19647 .68791 L .19894 .68877 L F
.497 .276 .508 r
.26815 .58306 m .26621 .58087 L .26845 .58012 L F
.26815 .58306 m .26589 .58362 L .26621 .58087 L F
.654 .577 .756 r
.44894 .59867 m .44986 .60211 L .45262 .60159 L F
.634 .479 .654 r
.44986 .60211 m .45023 .60456 L .45262 .60159 L F
.716 .6 .726 r
.45875 .58695 m .45915 .58901 L .4622 .58711 L F
.844 .959 .884 r
.4284 .56986 m .42814 .57226 L .43074 .56978 L F
0 .174 .689 r
.42918 .57253 m .42814 .57226 L .4284 .56986 L F
.42918 .57253 m .43025 .57399 L .42814 .57226 L F
.47 .14 .323 r
.58761 .52421 m .58965 .5262 L .58641 .52787 L F
.58761 .52421 m .58958 .52409 L .58965 .5262 L F
.636 .738 .922 r
.43473 .59828 m .43444 .60184 L .43235 .60109 L F
.327 0 0 r
.43444 .60184 m .43308 .60147 L .43235 .60109 L F
0 .093 .621 r
.43528 .60018 m .43444 .60184 L .43473 .59828 L F
.677 .963 .937 r
.43528 .60018 m .43308 .60147 L .43444 .60184 L F
.318 0 0 r
.4779 .57443 m .48072 .57555 L .48059 .57544 L F
.218 0 .257 r
.48072 .57555 m .48275 .57381 L .48059 .57544 L F
.41 .234 .53 r
.24813 .61362 m .24758 .61621 L .24594 .61669 L F
.438 .254 .532 r
.2478 .61801 m .24594 .61669 L .24758 .61621 L F
.2478 .61801 m .24582 .61882 L .24594 .61669 L F
.504 .895 .95 r
.23011 .6417 m .22941 .64268 L .23089 .63948 L F
.23011 .6417 m .22834 .6425 L .22941 .64268 L F
.206 0 .212 r
.23011 .6417 m .22929 .64254 L .22834 .6425 L F
.22929 .64254 m .22745 .64446 L .22834 .6425 L F
0 .563 .765 r
.22663 .64242 m .22834 .6425 L .2261 .64237 L F
.22941 .64268 m .22834 .6425 L .22663 .64242 L F
.285 0 .261 r
.22745 .64446 m .2261 .64237 L .22834 .6425 L F
.22745 .64446 m .22554 .64519 L .2261 .64237 L F
.595 .446 .649 r
.55429 .55705 m .55447 .55916 L .55174 .55981 L F
.596 .449 .651 r
.55174 .55981 m .55482 .56259 L .55235 .56343 L F
.55174 .55981 m .55447 .55916 L .55482 .56259 L F
.948 .953 .732 r
.63922 .41851 m .6374 .41924 L .63778 .41682 L F
.63922 .41851 m .63724 .42135 L .6374 .41924 L F
.692 .726 .876 r
.74426 .41156 m .74207 .41517 L .74193 .41345 L F
.308 .761 .956 r
.74207 .41517 m .74469 .41455 L .74157 .41563 L F
0 0 0 r
.68525 .39773 m .68319 .39782 L .68221 .39802 L F
.523 .488 .758 r
.47709 .58451 m .47931 .58399 L .47841 .5814 L F
.676 .196 .103 r
.56927 .52017 m .57065 .51895 L .56693 .51832 L F
.68 .201 .106 r
.56927 .52017 m .57321 .52087 L .57065 .51895 L F
.608 .311 .44 r
.57065 .51895 m .57321 .52087 L .57342 .51893 L F
0 0 0 r
.59479 .51576 m .59767 .51343 L .59721 .51449 L F
.226 .002 .35 r
.59432 .51796 m .59479 .51576 L .59721 .51449 L F
.526 .522 .794 r
.52417 .58969 m .5253 .5857 L .5251 .58724 L F
.36 .325 .684 r
.46429 .59557 m .46593 .5949 L .46382 .5928 L F
.46382 .5928 m .46593 .5949 L .46429 .59557 L F
.218 .359 .793 r
.76409 .40373 m .76282 .40527 L .76094 .40246 L F
.76409 .40373 m .76454 .40579 L .76282 .40527 L F
.591 .687 .908 r
.46447 .57402 m .46596 .57606 L .46813 .57524 L F
.798 .996 .866 r
.19753 .67663 m .19776 .67494 L .19944 .67563 L F
.19753 .67663 m .19486 .67737 L .19776 .67494 L F
.7 .845 .952 r
.37409 .63678 m .3749 .63806 L .37546 .63678 L F
.417 .38 .71 r
.3713 .61066 m .37175 .61419 L .37381 .6127 L F
.398 .344 .681 r
.37238 .61667 m .37381 .6127 L .37175 .61419 L F
0 0 0 r
.59269 .49675 m .59361 .4953 L .59026 .4979 L F
.5953 .49368 m .59361 .4953 L .59269 .49675 L F
.895 .903 .825 r
.63472 .44417 m .63806 .44231 L .63682 .44111 L F
.708 .199 .019 r
.55079 .58385 m .55313 .58607 L .54984 .58507 L F
.694 .559 .698 r
.554 .58085 m .55386 .58403 L .55079 .58385 L F
.644 .276 .332 r
.55386 .58403 m .55313 .58607 L .55079 .58385 L F
.794 .774 .834 r
.70082 .44461 m .69628 .44598 L .6985 .44299 L F
.70082 .44461 m .69727 .44724 L .69628 .44598 L F
.492 .748 .986 r
.70221 .44386 m .70082 .44461 L .6985 .44299 L F
.72 .755 .88 r
.69628 .44598 m .69727 .44724 L .69362 .44685 L F
.921 .923 .796 r
.61851 .48082 m .62133 .4805 L .61991 .4791 L F
.48 .897 .896 r
.20117 .65749 m .19793 .65835 L .19978 .65846 L F
.256 0 .244 r
.54913 .5442 m .54835 .54249 L .54841 .54493 L F
.54913 .5442 m .55034 .54175 L .54835 .54249 L F
.263 .756 .677 r
.66924 .39783 m .67117 .39713 L .66817 .39825 L F
.603 .338 .488 r
.403 .61368 m .40359 .61634 L .39931 .61634 L F
.665 .377 .474 r
.40492 .61563 m .40359 .61634 L .403 .61368 L F
.777 .894 .927 r
.71977 .44064 m .71797 .4421 L .71687 .44098 L F
.649 .586 .77 r
.7224 .40855 m .72478 .40527 L .72222 .40592 L F
.7224 .40855 m .72613 .4096 L .72478 .40527 L F
.113 0 .302 r
.60108 .50902 m .5999 .50992 L .60182 .50668 L F
.126 0 .322 r
.59943 .51209 m .5999 .50992 L .60108 .50902 L F
.658 .843 .971 r
.69915 .40333 m .70028 .4046 L .70272 .40335 L F
.92 .603 .427 r
.18815 .55691 m .1875 .55856 L .18803 .55686 L F
.737 .728 .204 r
.18781 .5585 m .18804 .55734 L .18805 .5573 L F
.18751 .55997 m .18781 .5585 L .18781 .5585 L F
.18781 .5585 m .18804 .55734 L .18781 .5585 L F
.86 .902 .862 r
.18805 .5573 m .18751 .55997 L .18968 .55758 L F
.92 .603 .427 r
.18968 .55758 m .18776 .55845 L .18805 .5573 L F
.18968 .55758 m .18805 .5573 L .18815 .55691 L F
.86 .902 .862 r
.18807 .55722 m .18805 .5573 L .18968 .55758 L F
.737 .728 .204 r
.18751 .55997 m .18688 .56259 L .18804 .55734 L F
.18807 .55722 m .18688 .56259 L .18751 .55997 L F
.377 .82 .684 r
.19055 .55702 m .18775 .55844 L .18968 .55758 L F
.92 .603 .427 r
.18776 .55845 m .1875 .55856 L .18815 .55691 L F
.377 .82 .684 r
.18775 .55844 m .1875 .55856 L .18776 .55845 L F
.18775 .55844 m .18776 .55845 L .18968 .55758 L F
.737 .728 .204 r
.18805 .5573 m .18804 .55734 L .18807 .55722 L F
.9 .716 .644 r
.75573 .42897 m .75342 .43155 L .75536 .4309 L F
.75536 .4309 m .75342 .43155 L .75573 .42897 L F
0 0 0 r
.75573 .42897 m .75453 .43095 L .75342 .43155 L F
.481 .048 .139 r
.75186 .4309 m .75453 .43095 L .75573 .42897 L F
.92 .929 .799 r
.56405 .49364 m .56716 .49132 L .56603 .49064 L F
.56405 .49364 m .565 .49452 L .56716 .49132 L F
0 0 .201 r
.52889 .51239 m .53117 .50861 L .53103 .50948 L F
.658 .96 .758 r
.53234 .50773 m .53103 .50948 L .53117 .50861 L F
.53234 .50773 m .53416 .50689 L .53103 .50948 L F
.403 .338 .67 r
.55445 .5744 m .5547 .57804 L .5531 .57936 L F
.118 .295 .768 r
.55476 .58051 m .5531 .57936 L .5547 .57804 L F
.55476 .58051 m .554 .58085 L .5531 .57936 L F
.502 .887 .709 r
.45855 .59851 m .46018 .59735 L .45713 .59633 L F
.45855 .59851 m .45966 .59754 L .46018 .59735 L F
.408 .749 .994 r
.45855 .59851 m .46111 .59867 L .45966 .59754 L F
.79 .994 .875 r
.66897 .40799 m .6696 .40851 L .67059 .40753 L F
.156 0 0 r
.67059 .40753 m .67097 .40791 L .66897 .40799 L F
.468 .216 .448 r
.67182 .40915 m .66897 .40799 L .67097 .40791 L F
0 .365 .756 r
.66831 .40744 m .66897 .40799 L .67182 .40915 L F
.66813 .40735 m .66897 .40799 L .66831 .40744 L F
.79 .994 .875 r
.66897 .40799 m .6685 .40961 L .6696 .40851 L F
.755 .835 .377 r
.66752 .41185 m .6685 .40961 L .66897 .40799 L F
.124 0 .42 r
.61195 .42861 m .61192 .43087 L .60984 .43191 L F
.052 0 .261 r
.61192 .43087 m .60993 .43426 L .60984 .43191 L F
0 .033 .602 r
.7564 .40561 m .75639 .40471 L .75474 .40244 L F
.769 .698 .157 r
.75639 .40395 m .75639 .40471 L .75607 .40694 L F
0 .152 .684 r
.75474 .40244 m .75639 .40471 L .7565 .40295 L F
.769 .698 .157 r
.7565 .40295 m .75639 .40471 L .75639 .40395 L F
0 .033 .602 r
.75642 .40566 m .75639 .40471 L .7564 .40561 L F
.783 .706 .168 r
.75607 .40694 m .75642 .40566 L .75695 .40864 L F
.75607 .40694 m .75639 .40471 L .75642 .40566 L F
.517 .459 .73 r
.73759 .42008 m .73807 .4229 L .74068 .42223 L F
.864 .842 .821 r
.61484 .45298 m .61204 .45259 L .61344 .45102 L F
.987 .899 .618 r
.61233 .45501 m .61204 .45259 L .61484 .45298 L F
.642 .545 .73 r
.61686 .44999 m .61876 .45287 L .61484 .45298 L F
.495 .396 .672 r
.61558 .45358 m .61484 .45298 L .61876 .45287 L F
.61558 .45358 m .61514 .45792 L .61484 .45298 L F
.486 .253 .486 r
.57861 .51276 m .58082 .51214 L .58122 .50979 L F
.299 0 .246 r
.58082 .51214 m .58373 .50938 L .58122 .50979 L F
0 0 0 r
.76551 .43315 m .76467 .43433 L .76225 .43495 L F
.76621 .43221 m .76551 .43315 L .7672 .43137 L F
.76621 .43221 m .76467 .43433 L .76551 .43315 L F
.269 .249 .651 r
.55476 .58051 m .55386 .58403 L .554 .58085 L F
.761 .54 .598 r
.44578 .64266 m .44968 .64327 L .44916 .64059 L F
.619 .447 .627 r
.44916 .64059 m .44968 .64327 L .45187 .64027 L F
.943 .767 .635 r
.2188 .58051 m .21808 .58303 L .21982 .58361 L F
.994 .775 .495 r
.21839 .58547 m .21982 .58361 L .21808 .58303 L F
.21839 .58547 m .2201 .58715 L .21982 .58361 L F
.88 .962 .847 r
.72693 .44387 m .72537 .44774 L .72809 .44516 L F
.72693 .44387 m .72456 .44682 L .72537 .44774 L F
0 .225 .62 r
.67244 .39783 m .67339 .39836 L .67278 .39803 L F
.67244 .39783 m .67278 .39803 L .67117 .39713 L F
.67244 .39783 m .67117 .39713 L .67027 .39745 L F
.67016 .39783 m .67027 .39745 L .66924 .39783 L F
.67244 .39783 m .67027 .39745 L .67016 .39783 L F
.581 .92 .966 r
.66999 .39842 m .66885 .39903 L .66861 .39957 L F
.534 .228 .395 r
.66885 .39903 m .67244 .39783 L .66924 .39783 L F
.581 .92 .966 r
.67091 .39765 m .67244 .39783 L .66885 .39903 L F
.67091 .39765 m .67004 .39823 L .66999 .39842 L F
.67004 .39823 m .66885 .39903 L .66999 .39842 L F
.085 .634 .827 r
.67208 .39763 m .67244 .39783 L .67091 .39765 L F
.67402 .39759 m .67244 .39783 L .67208 .39763 L F
.504 .347 .601 r
.62178 .41727 m .61954 .41621 L .62153 .41433 L F
.62178 .41727 m .61963 .41827 L .61954 .41621 L F
.591 .428 .629 r
.19783 .554 m .1955 .55716 L .19548 .55453 L F
.669 .24 .221 r
.41932 .64664 m .41773 .64841 L .41558 .6475 L F
.681 .255 .23 r
.42141 .64861 m .41773 .64841 L .41932 .64664 L F
.525 .786 .992 r
.53331 .54543 m .53577 .54527 L .53376 .54388 L F
.623 .318 .432 r
.5331 .54752 m .53571 .54746 L .53331 .54543 L F
.593 .329 .486 r
.53571 .54746 m .53577 .54527 L .53331 .54543 L F
.402 .441 .786 r
.53267 .54602 m .5331 .54752 L .53293 .54606 L F
.623 .318 .432 r
.5331 .54752 m .53331 .54543 L .53339 .54518 L F
.53339 .54594 m .53339 .54518 L .53376 .54388 L F
.5331 .54752 m .53339 .54518 L .53339 .54594 L F
.5331 .54752 m .53339 .54594 L .53294 .54617 L F
.53339 .54594 m .53376 .54388 L .53299 .54604 L F
.53339 .54594 m .53299 .54604 L .53294 .54617 L F
.87 .847 .819 r
.53339 .54607 m .53333 .54611 L .53293 .54606 L F
.53299 .54604 m .53293 .54606 L .53267 .54602 L F
.53339 .54607 m .53293 .54606 L .53299 .54604 L F
.489 .417 .702 r
.53376 .54388 m .53537 .54619 L .53299 .54604 L F
.53376 .54388 m .53299 .54604 L .53267 .54602 L F
.53376 .54388 m .53267 .54602 L .53285 .54538 L F
.623 .318 .432 r
.53294 .54617 m .53376 .54388 L .53285 .54538 L F
.402 .441 .786 r
.53267 .54602 m .53293 .54606 L .53285 .54538 L F
.983 .713 .331 r
.5327 .54944 m .5331 .54752 L .53267 .54602 L F
.953 .661 .445 r
.53068 .5483 m .5327 .54944 L .53267 .54602 L F
.87 .847 .819 r
.53333 .54611 m .53068 .5483 L .53267 .54602 L F
.53537 .54619 m .53339 .54708 L .53339 .54607 L F
.53339 .54708 m .53068 .5483 L .53339 .54607 L F
.807 .899 .907 r
.62937 .43665 m .6261 .43691 L .62759 .4354 L F
.787 .481 .47 r
.63007 .43464 m .6294 .43484 L .629 .43251 L F
0 0 .362 r
.629 .43251 m .62952 .43554 L .6294 .43357 L F
.807 .899 .907 r
.62939 .43484 m .62759 .4354 L .6294 .43357 L F
.62937 .43665 m .62759 .4354 L .62939 .43484 L F
.787 .481 .47 r
.63096 .43315 m .63007 .43464 L .629 .43251 L F
.63007 .43464 m .62952 .43554 L .6294 .43484 L F
.963 .921 .578 r
.63096 .43315 m .62937 .43665 L .62952 .43554 L F
.738 .703 .818 r
.63268 .43731 m .63096 .43315 L .63257 .43522 L F
.63268 .43731 m .62937 .43665 L .63096 .43315 L F
.37 .16 .459 r
.44943 .5745 m .45203 .57137 L .44946 .57168 L F
.859 .839 .824 r
.63353 .44628 m .63497 .44725 L .63472 .44417 L F
.935 .909 .771 r
.63198 .44928 m .63497 .44725 L .63353 .44628 L F
.63198 .44928 m .633 .45039 L .63497 .44725 L F
.798 .739 .798 r
.54098 .56824 m .54488 .56875 L .5426 .5662 L F
.941 .701 .547 r
.53932 .56761 m .54132 .57075 L .54098 .56824 L F
.53932 .56761 m .53907 .57123 L .54132 .57075 L F
.995 .762 .464 r
.54132 .57075 m .54035 .57107 L .54098 .56824 L F
.92 .849 .756 r
.54035 .57107 m .54488 .56875 L .54098 .56824 L F
.702 .213 .083 r
.53907 .57123 m .53934 .57146 L .54132 .57075 L F
.53934 .57146 m .54012 .57213 L .54083 .57131 L F
.92 .849 .756 r
.54059 .57134 m .54248 .57353 L .54374 .57102 L F
.699 .548 .679 r
.54488 .56875 m .54248 .57353 L .54552 .57221 L F
.29 .789 .804 r
.54328 .57303 m .54248 .57353 L .54059 .57134 L F
.702 .213 .083 r
.54059 .57134 m .54083 .57131 L .54025 .57113 L F
.54025 .57113 m .54083 .57131 L .54132 .57075 L F
.92 .849 .756 r
.54035 .57107 m .54059 .57134 L .54072 .57126 L F
.769 .352 .259 r
.54083 .57131 m .54035 .57107 L .54132 .57075 L F
.92 .849 .756 r
.54035 .57107 m .54072 .57126 L .54488 .56875 L F
.769 .352 .259 r
.54012 .57213 m .54035 .57107 L .54083 .57131 L F
.92 .849 .756 r
.54059 .57134 m .54374 .57102 L .54488 .56875 L F
.29 .789 .804 r
.54265 .57261 m .54059 .57134 L .54035 .57107 L F
.54328 .57303 m .54059 .57134 L .54265 .57261 L F
.702 .213 .083 r
.53934 .57146 m .54059 .57134 L .54025 .57113 L F
.792 .323 .12 r
.54674 .56875 m .5426 .5662 L .54488 .56875 L F
.577 .494 .724 r
.54552 .57221 m .54674 .56875 L .54488 .56875 L F
.637 .429 .585 r
.54307 .55033 m .54555 .54788 L .54322 .54836 L F
.399 .097 .333 r
.39405 .58859 m .39627 .58881 L .39602 .58882 L F
.39405 .58859 m .39403 .58944 L .39627 .58881 L F
0 0 0 r
.59721 .51449 m .59767 .51343 L .59943 .51209 L F
.29 .788 .853 r
.17089 .54596 m .17291 .54551 L .17483 .54545 L F
.493 .296 .542 r
.17483 .54545 m .17698 .54495 L .17719 .54241 L F
.197 .727 .783 r
.17291 .54551 m .17698 .54495 L .17483 .54545 L F
.651 .587 .77 r
.66216 .44387 m .6657 .44679 L .66381 .44483 L F
0 0 0 r
.46018 .59735 m .46212 .59677 L .46429 .59557 L F
.492 .338 .6 r
.46593 .5949 m .46385 .59838 L .46429 .59557 L F
.808 .58 .593 r
.46212 .59677 m .46593 .5949 L .46429 .59557 L F
0 0 0 r
.46018 .59735 m .46212 .59677 L .46429 .59557 L F
.263 .772 .826 r
.20338 .54046 m .20562 .53997 L .20765 .53989 L F
.353 0 0 r
.20562 .53997 m .20968 .53917 L .20765 .53989 L F
.465 .275 .538 r
.55235 .56343 m .5546 .56536 L .55275 .56593 L F
.55235 .56343 m .55482 .56259 L .5546 .56536 L F
.943 .713 .56 r
.66503 .43602 m .6636 .4324 L .66332 .43493 L F
.902 .756 .69 r
.66332 .43493 m .66434 .43856 L .66503 .43602 L F
.873 .836 .806 r
.72874 .40851 m .73227 .40656 L .73152 .40571 L F
.925 .882 .463 r
.73308 .40425 m .73303 .4041 L .73227 .40656 L F
.847 .937 .884 r
.73152 .40571 m .73227 .40656 L .73303 .4041 L F
.354 .829 .827 r
.1956 .64043 m .19131 .64152 L .19401 .64035 L F
.573 .895 .634 r
.19739 .63876 m .1956 .64043 L .19619 .63959 L F
.438 .87 .918 r
.19619 .63959 m .1956 .64043 L .19401 .64035 L F
.614 .833 .984 r
.70141 .3955 m .69782 .39519 L .6999 .39449 L F
.601 .856 .992 r
.70292 .39366 m .70141 .3955 L .6999 .39449 L F
.70292 .39366 m .70393 .39464 L .70141 .3955 L F
.517 .327 .562 r
.56599 .53946 m .56843 .54136 L .56587 .54162 L F
.56599 .53946 m .56843 .53891 L .56843 .54136 L F
.489 .382 .659 r
.23158 .5927 m .23395 .59458 L .23323 .59226 L F
.23158 .5927 m .23188 .59524 L .23395 .59458 L F
.424 .406 .735 r
.26762 .56461 m .26832 .56842 L .26657 .56885 L F
.307 .335 .727 r
.26872 .57088 m .26657 .56885 L .26832 .56842 L F
0 0 .056 r
.59766 .45145 m .597 .453 L .59742 .45051 L F
.638 .447 .607 r
.57442 .5337 m .57442 .53611 L .57076 .53652 L F
.667 .458 .592 r
.57688 .5335 m .57442 .53611 L .57442 .5337 L F
0 0 0 r
.42772 .56596 m .42834 .56625 L .42818 .56556 L F
0 .201 .638 r
.4268 .56505 m .42891 .56653 L .42834 .56625 L F
.572 0 0 r
.42834 .56625 m .43087 .5679 L .43095 .56752 L F
0 .201 .638 r
.42891 .56653 m .43087 .5679 L .42834 .56625 L F
0 0 0 r
.42693 .56664 m .42834 .56625 L .42772 .56596 L F
.42693 .56664 m .42538 .568 L .42834 .56625 L F
.516 .874 .984 r
.6967 .39453 m .69519 .39594 L .6942 .39515 L F
.6967 .39453 m .69782 .39519 L .69519 .39594 L F
.245 .101 .479 r
.21292 .62506 m .21489 .6216 L .21296 .62257 L F
.777 .65 .093 r
.65206 .4238 m .65211 .41898 L .65189 .42248 L F
.862 .734 .216 r
.65181 .4261 m .65206 .4238 L .65189 .42248 L F
.981 .763 .535 r
.5379 .52686 m .53909 .53034 L .53797 .528 L F
.826 .759 .789 r
.53797 .528 m .53909 .53034 L .53668 .53353 L F
.764 .694 .786 r
.54156 .52745 m .53909 .53034 L .5379 .52686 L F
.602 .772 .961 r
.75525 .4171 m .75882 .41785 L .75806 .41632 L F
.75806 .41632 m .75882 .41785 L .75525 .4171 L F
.647 .455 .61 r
.57342 .51893 m .57631 .51812 L .57633 .5158 L F
.361 .226 .559 r
.57633 .5158 m .57866 .51739 L .57861 .51508 L F
.57633 .5158 m .57631 .51812 L .57866 .51739 L F
.064 0 .429 r
.23308 .63281 m .23338 .63677 L .23196 .63736 L F
0 0 0 r
.2324 .63854 m .23196 .63736 L .23338 .63677 L F
.2324 .63854 m .23089 .63948 L .23196 .63736 L F
.338 .085 .376 r
.24047 .57543 m .24156 .57713 L .24184 .57488 L F
.24047 .57543 m .23978 .5778 L .24156 .57713 L F
.98 .866 .652 r
.65906 .42954 m .65716 .43079 L .65807 .42842 L F
.65906 .42954 m .65809 .43264 L .65716 .43079 L F
.989 .841 .605 r
.65859 .42605 m .65906 .42954 L .65807 .42842 L F
.606 .657 .874 r
.72222 .40592 m .72367 .40256 L .72123 .40403 L F
.72222 .40592 m .72478 .40527 L .72367 .40256 L F
.669 .411 .521 r
.54124 .59593 m .53784 .59877 L .54031 .59653 L F
.54124 .59593 m .54138 .5985 L .53784 .59877 L F
.63 .614 .816 r
.54365 .5953 m .54124 .59593 L .53993 .59262 L F
.683 .421 .52 r
.54409 .59795 m .54124 .59593 L .54365 .5953 L F
.54409 .59795 m .54138 .5985 L .54124 .59593 L F
.429 .663 .959 r
.24957 .54357 m .24896 .54532 L .24747 .54364 L F
.43 .664 .959 r
.24957 .54357 m .251 .54526 L .24896 .54532 L F
.753 .949 .629 r
.61104 .4946 m .61363 .49136 L .6134 .49106 L F
.723 .956 .67 r
.6134 .49106 m .61363 .49136 L .61618 .48841 L F
.979 .683 .346 r
.21329 .5631 m .21208 .56376 L .21332 .56187 L F
.21329 .5631 m .21352 .5651 L .21208 .56376 L F
.663 .724 .895 r
.19815 .66961 m .199 .67079 L .20169 .67051 L F
0 0 .196 r
.21777 .55974 m .21779 .56223 L .21743 .56261 L F
.709 .646 .089 r
.21714 .56496 m .21702 .5661 L .21743 .56261 L F
.21714 .56496 m .21743 .56261 L .21779 .56223 L F
.15 0 .155 r
.526 .53227 m .52421 .53371 L .52701 .53052 L F
.482 .173 .364 r
.52701 .53052 m .52846 .5322 L .526 .53227 L F
.995 .787 .42 r
.53668 .53353 m .53565 .52963 L .53282 .53338 L F
.975 .702 .297 r
.53432 .53293 m .5353 .53347 L .53282 .53338 L F
.799 .715 .772 r
.52846 .5322 m .53282 .53338 L .53167 .5294 L F
.819 .437 .331 r
.52877 .53261 m .53282 .53338 L .52846 .5322 L F
.52877 .53261 m .53318 .53517 L .53282 .53338 L F
.677 .645 .811 r
.53167 .5294 m .53282 .53338 L .53565 .52963 L F
.975 .702 .297 r
.53568 .53252 m .5353 .53347 L .53432 .53293 L F
.53568 .53252 m .53282 .53338 L .53318 .53517 L F
.723 .63 .754 r
.52877 .53261 m .53084 .53872 L .53318 .53517 L F
.949 .848 .708 r
.53318 .53517 m .53139 .53431 L .53289 .53213 L F
.53334 .53238 m .53289 .53213 L .5334 .53139 L F
.53318 .53517 m .53289 .53213 L .53334 .53238 L F
.975 .702 .297 r
.53568 .53252 m .53668 .53353 L .5353 .53347 L F
.53568 .53252 m .53681 .53597 L .53668 .53353 L F
.826 .759 .789 r
.53797 .528 m .53668 .53353 L .53568 .53252 L F
.975 .702 .297 r
.53668 .53353 m .53681 .53597 L .53568 .53252 L F
.269 .249 .651 r
.55476 .58051 m .55562 .58285 L .55386 .58403 L F
.44 .594 .907 r
.55386 .58403 m .55485 .58571 L .55313 .58607 L F
.55386 .58403 m .55648 .58477 L .55485 .58571 L F
.55386 .58403 m .55562 .58285 L .55648 .58477 L F
.638 .814 .967 r
.70748 .39508 m .70393 .39464 L .70644 .39385 L F
.586 .804 .983 r
.70894 .39309 m .70748 .39508 L .70644 .39385 L F
.70894 .39309 m .70998 .39438 L .70748 .39508 L F
.242 .738 .91 r
.45901 .56403 m .46049 .56336 L .4632 .56417 L F
.486 .878 .964 r
.4632 .56417 m .46383 .56288 L .46546 .56367 L F
.4632 .56417 m .46049 .56336 L .46383 .56288 L F
.46 .225 .469 r
.55845 .54811 m .56096 .54526 L .56082 .5475 L F
.456 .259 .523 r
.56096 .54526 m .5634 .54222 L .56314 .54453 L F
.391 .173 .459 r
.56082 .5475 m .56096 .54526 L .56314 .54453 L F
.485 .305 .562 r
.2551 .60158 m .25489 .60428 L .2527 .60478 L F
.447 .223 .48 r
.25489 .60428 m .25244 .60696 L .2527 .60478 L F
.753 .831 .911 r
.19269 .65885 m .19695 .66108 L .19793 .65835 L F
.503 .176 .346 r
.55374 .53222 m .55155 .53085 L .55128 .53268 L F
.55374 .53222 m .55504 .52968 L .55155 .53085 L F
.617 .291 .396 r
.5487 .53252 m .55155 .53085 L .54755 .52985 L F
.5487 .53252 m .55128 .53268 L .55155 .53085 L F
.957 .716 .532 r
.54619 .52405 m .54596 .5214 L .54439 .52016 L F
.758 .709 .806 r
.54596 .5214 m .54873 .51842 L .54504 .51793 L F
.673 .795 .94 r
.72228 .39421 m .71954 .39595 L .7187 .39372 L F
.62 .755 .943 r
.70526 .40266 m .70641 .40458 L .70883 .40345 L F
.679 .767 .917 r
.73282 .39435 m .72927 .39674 L .72986 .39623 L F
.667 .458 .592 r
.57688 .5335 m .57707 .53622 L .57442 .53611 L F
.61 .362 .517 r
.57688 .5335 m .57945 .53561 L .57707 .53622 L F
.67 .173 .06 r
.41047 .63663 m .41283 .6385 L .41423 .63737 L F
.709 .224 .093 r
.41283 .6385 m .41654 .63949 L .41423 .63737 L F
.204 .005 .373 r
.60541 .43791 m .60493 .4399 L .60331 .44012 L F
.547 .392 .622 r
.60554 .44335 m .60331 .44012 L .60493 .4399 L F
.60554 .44335 m .60345 .44423 L .60331 .44012 L F
.78 .541 .575 r
.20168 .675 m .20569 .67547 L .2057 .67294 L F
.728 .716 .839 r
.65413 .40579 m .65162 .40595 L .65078 .40498 L F
.644 .906 .982 r
.65413 .40579 m .65531 .40393 L .65667 .40465 L F
.931 .55 .205 r
.65413 .40579 m .65317 .40677 L .65531 .40393 L F
.65413 .40579 m .65515 .40838 L .65317 .40677 L F
.752 .976 .718 r
.52597 .51497 m .52829 .51248 L .52889 .51239 L F
0 0 .201 r
.52889 .51239 m .53049 .51133 L .53117 .50861 L F
.435 .867 .764 r
.52889 .51239 m .52829 .51248 L .53049 .51133 L F
.543 .431 .676 r
.60386 .4468 m .60116 .44528 L .60345 .44423 L F
.60386 .4468 m .60142 .44764 L .60116 .44528 L F
.93 .815 .71 r
.62795 .4653 m .62936 .46222 L .628 .46075 L F
.954 .882 .724 r
.62936 .46222 m .62919 .45914 L .628 .46075 L F
.535 .771 .985 r
.66001 .40553 m .65667 .40465 L .65897 .40409 L F
.743 .847 .928 r
.66189 .40284 m .66001 .40553 L .65897 .40409 L F
.665 .273 0 r
.6582 .41743 m .65991 .4206 L .65904 .41952 L F
.999 .821 .485 r
.65904 .41952 m .65991 .4206 L .65956 .42238 L F
.937 .838 .395 r
.46052 .608 m .45997 .6074 L .45995 .60612 L F
.46052 .608 m .45993 .60994 L .45997 .6074 L F
.278 0 .293 r
.46272 .60678 m .45993 .60994 L .46052 .608 L F
.994 .764 .478 r
.21839 .58547 m .22007 .58846 L .2201 .58715 L F
.786 .82 .879 r
.68004 .40942 m .68214 .40849 L .68009 .40621 L F
.695 .797 .928 r
.68009 .40621 m .68214 .40849 L .6851 .40645 L F
.576 .62 .859 r
.40906 .6136 m .40498 .61102 L .40744 .61311 L F
.688 .628 .784 r
.40492 .61563 m .40744 .61311 L .40906 .6136 L F
.572 .302 .468 r
.40906 .6136 m .41046 .61313 L .41184 .6131 L F
.40906 .6136 m .40744 .61311 L .41046 .61313 L F
.40906 .6136 m .40873 .61577 L .40744 .61311 L F
.40906 .6136 m .41127 .61559 L .40873 .61577 L F
0 0 0 r
.45993 .60994 m .45725 .61243 L .45827 .61099 L F
.45827 .61099 m .45725 .61243 L .45993 .60994 L F
.517 .459 .73 r
.73759 .42008 m .74068 .42223 L .74014 .42008 L F
.717 .625 .754 r
.21501 .57781 m .21911 .578 L .21685 .57709 L F
.21501 .57781 m .2188 .58051 L .21911 .578 L F
.006 0 .263 r
.53933 .57446 m .537 .5783 L .53627 .57485 L F
0 0 .516 r
.53771 .57873 m .53865 .58106 L .537 .5783 L F
.421 .255 .549 r
.5562 .55396 m .55429 .55705 L .55392 .55452 L F
.401 .328 .659 r
.3713 .61066 m .37304 .61023 L .37289 .60682 L F
.415 .38 .712 r
.3713 .61066 m .37381 .6127 L .37304 .61023 L F
0 0 0 r
.23194 .54172 m .23372 .54141 L .23543 .54078 L F
.321 .789 .933 r
.23211 .54109 m .23546 .5411 L .23372 .54141 L F
0 0 0 r
.23394 .54137 m .23592 .54111 L .23775 .54066 L F
.23372 .54141 m .23592 .54111 L .23394 .54137 L F
.134 0 0 r
.23543 .54078 m .23372 .54141 L .23775 .54066 L F
.451 .841 .982 r
.23384 .54065 m .23786 .54085 L .23592 .54111 L F
.172 .708 .811 r
.23592 .54111 m .23977 .54087 L .23775 .54066 L F
.451 .841 .982 r
.23786 .54085 m .23803 .54086 L .23592 .54111 L F
.321 .789 .933 r
.23546 .5411 m .23592 .54111 L .23372 .54141 L F
0 0 0 r
.23155 .54183 m .23372 .54141 L .23194 .54172 L F
.666 .431 .554 r
.21549 .57452 m .21501 .57781 L .21685 .57709 L F
.844 .959 .884 r
.4284 .56986 m .43074 .56978 L .42922 .56908 L F
.728 .933 .956 r
.43129 .56782 m .43074 .56978 L .43215 .56821 L F
.43129 .56782 m .42922 .56908 L .43074 .56978 L F
.993 .871 .598 r
.62098 .4262 m .62076 .42353 L .61805 .42604 L F
.623 .39 .543 r
.57076 .53652 m .57421 .53844 L .57082 .53911 L F
.57076 .53652 m .57442 .53611 L .57421 .53844 L F
0 0 .083 r
.23302 .58405 m .23389 .5832 L .23461 .58066 L F
.451 .324 .616 r
.23217 .58628 m .23389 .5832 L .23302 .58405 L F
.557 .225 .362 r
.53549 .52754 m .53797 .528 L .53565 .52963 L F
.546 .433 .676 r
.53549 .52754 m .5379 .52686 L .53797 .528 L F
.629 .463 .639 r
.21356 .55675 m .21134 .55717 L .21381 .55427 L F
0 0 0 r
.40193 .583 m .4034 .58242 L .40504 .5811 L F
.343 0 .005 r
.4034 .58242 m .40725 .58039 L .40504 .5811 L F
.377 .82 .684 r
.19055 .55702 m .18968 .55758 L .19188 .55726 L F
.669 .24 .22 r
.21134 .55717 m .2095 .55879 L .20749 .55693 L F
.9 .592 .454 r
.2119 .55938 m .2095 .55879 L .21134 .55717 L F
.938 .929 .77 r
.65033 .4348 m .65162 .43308 L .65079 .43174 L F
.432 .302 .603 r
.37243 .60171 m .37439 .60111 L .37419 .59849 L F
.438 .319 .62 r
.37243 .60171 m .37464 .6037 L .37439 .60111 L F
.478 .319 .586 r
.37249 .60423 m .37464 .6037 L .37243 .60171 L F
.785 .653 .717 r
.72758 .43195 m .72883 .43585 L .72517 .4352 L F
.746 .633 .734 r
.73109 .4326 m .72883 .43585 L .72758 .43195 L F
.573 .377 .578 r
.55714 .52748 m .55971 .52479 L .55614 .52458 L F
0 .484 .707 r
.20968 .53917 m .21169 .53949 L .21343 .53978 L F
.439 0 0 r
.21169 .53949 m .21553 .54025 L .21343 .53978 L F
.392 .016 .201 r
.15866 .55021 m .16231 .54753 L .16157 .5483 L F
.386 .805 .974 r
.73259 .43169 m .73109 .4326 L .73093 .43053 L F
.73259 .43169 m .73364 .43223 L .73109 .4326 L F
.898 .578 .434 r
.50655 .55131 m .50467 .55103 L .50422 .54852 L F
.695 .168 0 r
.50655 .55131 m .50588 .55227 L .50467 .55103 L F
.904 .492 .126 r
.50655 .55131 m .50731 .55347 L .50588 .55227 L F
.464 .85 .981 r
.20891 .66344 m .20685 .66354 L .20677 .664 L F
.529 .342 .572 r
.59748 .46049 m .59534 .45968 L .59771 .45889 L F
.59748 .46049 m .59503 .4614 L .59534 .45968 L F
.336 .114 .422 r
.57861 .51508 m .58082 .51214 L .57861 .51276 L F
.4 .093 .325 r
.39887 .5871 m .40133 .5864 L .40193 .583 L F
.359 .059 .313 r
.40193 .583 m .40354 .58543 L .4034 .58242 L F
.40193 .583 m .40133 .5864 L .40354 .58543 L F
.153 0 .259 r
.60182 .50668 m .60421 .50332 L .60381 .50555 L F
0 0 0 r
.60421 .50332 m .60627 .50126 L .60566 .50211 L F
.746 .843 .394 r
.60505 .50296 m .60566 .50211 L .60645 .49983 L F
0 0 .03 r
.60381 .50555 m .60421 .50332 L .60566 .50211 L F
.746 .843 .394 r
.60479 .50354 m .60566 .50211 L .60505 .50296 L F
0 0 0 r
.60627 .50126 m .6068 .50073 L .60566 .50211 L F
.511 .903 .765 r
.74605 .42752 m .7467 .42671 L .74761 .42594 L F
.513 .909 .794 r
.74761 .42594 m .74944 .42446 L .74946 .4249 L F
.04 0 .313 r
.7467 .42671 m .74854 .42563 L .74944 .42446 L F
.728 .869 .454 r
.74854 .42563 m .74942 .42414 L .74944 .42446 L F
.743 .666 .775 r
.75219 .42184 m .74944 .42446 L .74843 .42114 L F
0 0 .509 r
.74944 .42446 m .74964 .42375 L .74843 .42114 L F
.728 .869 .454 r
.74942 .42414 m .74964 .42375 L .74944 .42446 L F
.513 .909 .794 r
.74946 .4249 m .74944 .42446 L .75086 .42412 L F
0 0 0 r
.74761 .42594 m .7467 .42671 L .74944 .42446 L F
.6 .743 .945 r
.42003 .60706 m .41635 .60636 L .41892 .60559 L F
.469 .731 .984 r
.42106 .60543 m .42003 .60706 L .41892 .60559 L F
.42106 .60543 m .42231 .60673 L .42003 .60706 L F
.412 .26 .563 r
.26113 .59466 m .25921 .59281 L .26138 .59227 L F
.26113 .59466 m .2592 .59535 L .25921 .59281 L F
0 .486 .729 r
.40744 .64551 m .40581 .64516 L .40497 .64501 L F
.349 0 0 r
.40744 .64551 m .40939 .64618 L .40581 .64516 L F
.398 .855 .85 r
.6917 .39594 m .68925 .39683 L .68857 .39675 L F
.427 .442 .772 r
.45385 .56511 m .45628 .57023 L .45723 .56839 L F
.765 .934 .94 r
.47259 .5729 m .47167 .57515 L .47433 .57437 L F
.47259 .5729 m .47051 .57441 L .47167 .57515 L F
.707 .984 .882 r
.51419 .52496 m .51327 .52664 L .51289 .52682 L F
.51419 .52496 m .51628 .52451 L .51327 .52664 L F
.652 .97 .863 r
.68829 .40598 m .69059 .40447 L .68963 .40437 L F
.634 .942 .957 r
.68734 .40554 m .68829 .40598 L .68963 .40437 L F
.534 .305 .514 r
.56082 .5475 m .55802 .55053 L .55845 .54811 L F
.575 .109 .109 r
.21746 .61126 m .22321 .61163 L .22171 .61014 L F
.04 0 .193 r
.21647 .6101 m .21739 .61178 L .21743 .61115 L F
.21697 .60973 m .21743 .61115 L .21754 .60933 L F
.21647 .6101 m .21743 .61115 L .21697 .60973 L F
.21647 .6101 m .216 .61254 L .21739 .61178 L F
.787 .481 .471 r
.21667 .61147 m .21754 .60933 L .21739 .61178 L F
.575 .109 .109 r
.21667 .61147 m .21754 .61149 L .21746 .61126 L F
.21754 .61149 m .22321 .61163 L .21746 .61126 L F
.498 .311 .557 r
.43949 .58878 m .43718 .59183 L .43715 .58928 L F
.69 .756 .902 r
.63994 .43061 m .64156 .43261 L .63748 .43158 L F
.673 .162 .016 r
.63748 .43158 m .64156 .43261 L .64013 .43367 L F
.745 .772 .875 r
.64329 .43086 m .64156 .43261 L .63994 .43061 L F
.875 .456 .215 r
.64156 .43261 m .64237 .43495 L .64013 .43367 L F
.579 .538 .773 r
.64156 .43261 m .6449 .43519 L .64237 .43495 L F
.89 .928 .838 r
.55065 .50517 m .54959 .50926 L .55212 .5058 L F
.834 .962 .891 r
.55365 .5027 m .55212 .5058 L .55448 .5032 L F
.55365 .5027 m .55065 .50517 L .55212 .5058 L F
.472 .103 .257 r
.44606 .58372 m .44247 .58599 L .44259 .58527 L F
0 0 0 r
.22009 .55443 m .21867 .5561 L .21693 .55741 L F
.89 .937 .565 r
.21912 .55401 m .22009 .55443 L .22236 .55279 L F
.21912 .55401 m .21867 .5561 L .22009 .55443 L F
0 0 0 r
.18345 .54295 m .18343 .54336 L .18541 .54226 L F
.18345 .54295 m .18128 .54396 L .18343 .54336 L F
.034 0 .258 r
.60108 .50902 m .60182 .50668 L .60381 .50555 L F
.673 .416 .524 r
.44121 .64574 m .43732 .64841 L .4378 .64653 L F
.423 .6 .919 r
.21592 .806 m .21698 .80608 L .2162 .80639 L F
.334 .816 .806 r
.2162 .80639 m .21698 .80608 L .21589 .80644 L F
.265 .301 .713 r
.23654 .5896 m .23808 .58872 L .23592 .58677 L F
0 0 0 r
.23654 .5896 m .23545 .59169 L .23808 .58872 L F
.717 .467 .547 r
.53315 .68191 m .53207 .68475 L .53192 .68151 L F
.53315 .68191 m .53232 .68453 L .53207 .68475 L F
.276 0 0 r
.74779 .43853 m .74682 .43924 L .74439 .43919 L F
0 0 0 r
.75009 .43789 m .74779 .43853 L .74988 .4375 L F
.75009 .43789 m .74682 .43924 L .74779 .43853 L F
.051 .036 .518 r
.65317 .40677 m .65153 .40925 L .65162 .40595 L F
0 .201 .729 r
.65548 .41011 m .65347 .4072 L .65515 .40838 L F
.65347 .4072 m .65317 .40677 L .65354 .40707 L F
.65347 .4072 m .65354 .40707 L .65515 .40838 L F
.65548 .41011 m .65542 .40887 L .65317 .40677 L F
.363 .578 .923 r
.65338 .40697 m .65548 .41011 L .65153 .40925 L F
.814 .828 .353 r
.6532 .40767 m .65161 .41294 L .65169 .4135 L F
.65338 .40697 m .65314 .40777 L .6532 .40767 L F
.65314 .40777 m .65161 .41294 L .6532 .40767 L F
.363 .578 .923 r
.65338 .40697 m .65153 .40925 L .65317 .40677 L F
.926 .917 .787 r
.54959 .50926 m .54636 .51159 L .54736 .51239 L F
.54959 .50926 m .54828 .50819 L .54636 .51159 L F
.89 .928 .838 r
.55065 .50517 m .54828 .50819 L .54959 .50926 L F
.368 .634 .957 r
.2387 .55824 m .23927 .55647 L .23756 .55691 L F
.2387 .55824 m .24181 .55889 L .23927 .55647 L F
.456 .255 .517 r
.58828 .50068 m .59037 .50021 L .59026 .4979 L F
.237 0 .291 r
.58797 .50293 m .59037 .50021 L .58828 .50068 L F
.548 .338 .548 r
.5115 .56012 m .51253 .56058 L .51034 .55905 L F
.5115 .56012 m .51398 .56181 L .51253 .56058 L F
.5115 .56012 m .51163 .56275 L .51398 .56181 L F
.352 .144 .452 r
.24106 .5659 m .24287 .56532 L .24329 .56296 L F
.246 .289 .71 r
.24106 .5659 m .24312 .56787 L .24287 .56532 L F
.387 .526 .874 r
.24181 .55889 m .24222 .56053 L .2435 .55881 L F
.238 .302 .727 r
.24329 .56296 m .2435 .55881 L .24222 .56053 L F
.716 .501 .597 r
.19822 .69387 m .19757 .69597 L .19498 .69575 L F
.445 .521 .842 r
.19952 .69298 m .19822 .69387 L .19635 .69165 L F
.467 .25 .5 r
.20017 .69589 m .19822 .69387 L .19952 .69298 L F
.20017 .69589 m .19757 .69597 L .19822 .69387 L F
.431 .292 .59 r
.25244 .60696 m .25274 .60975 L .25026 .61037 L F
.392 .196 .491 r
.25274 .60975 m .25003 .61237 L .25026 .61037 L F
.728 .698 .822 r
.37797 .62777 m .38129 .62837 L .37941 .62859 L F
.365 0 0 r
.3834 .63026 m .37941 .62859 L .38129 .62837 L F
.657 .927 .973 r
.71071 .44006 m .70879 .44119 L .70746 .44047 L F
.69 .384 .452 r
.70879 .44119 m .70841 .44377 L .70746 .44047 L F
.70879 .44119 m .71009 .44278 L .70841 .44377 L F
0 .219 .729 r
.70879 .44119 m .71218 .44436 L .71009 .44278 L F
.682 .823 .951 r
.6107 .46466 m .60732 .46438 L .60973 .46139 L F
.774 .675 .755 r
.61267 .46162 m .6107 .46466 L .60973 .46139 L F
.456 .158 .37 r
.23605 .63072 m .23483 .63252 L .23308 .63281 L F
.458 .209 .447 r
.23772 .62993 m .23483 .63252 L .23605 .63072 L F
.061 0 .424 r
.59026 .4979 m .59201 .49852 L .59269 .49675 L F
.59026 .4979 m .59037 .50021 L .59201 .49852 L F
0 .122 .644 r
.40501 .60921 m .40798 .60817 L .40654 .60737 L F
.716 .91 .962 r
.4087 .60606 m .40798 .60817 L .40963 .60664 L F
.4087 .60606 m .40654 .60737 L .40798 .60817 L F
.338 0 .207 r
.2227 .64766 m .2215 .64659 L .22362 .64591 L F
.2227 .64766 m .22064 .64821 L .2215 .64659 L F
.472 .103 .257 r
.44606 .58372 m .44491 .58577 L .44247 .58599 L F
.614 .544 .752 r
.44797 .57953 m .44772 .58325 L .44606 .58372 L F
.47 .119 .288 r
.44772 .58325 m .44491 .58577 L .44606 .58372 L F
.757 .586 .664 r
.17549 .56042 m .17097 .56269 L .1716 .56029 L F
.934 .731 .606 r
.21449 .56764 m .21702 .5661 L .21714 .56496 L F
.21449 .56764 m .21657 .56873 L .21702 .5661 L F
.427 .442 .772 r
.45385 .56511 m .45723 .56839 L .45677 .56468 L F
.839 .771 .786 r
.66367 .4282 m .66534 .42955 L .66475 .42642 L F
.866 .762 .746 r
.6636 .4324 m .66534 .42955 L .66367 .4282 L F
.51 .259 .47 r
.46125 .63812 m .46293 .63961 L .46283 .63662 L F
.46125 .63812 m .46056 .64007 L .46293 .63961 L F
.801 .642 .685 r
.54755 .52728 m .54619 .52405 L .54383 .52669 L F
.772 .541 .585 r
.54755 .52985 m .54755 .52728 L .54383 .52669 L F
.624 .43 .599 r
.55504 .52968 m .55732 .52977 L .55714 .52748 L F
.573 .377 .578 r
.55714 .52748 m .55966 .52714 L .55971 .52479 L F
.637 .479 .652 r
.55732 .52977 m .55966 .52714 L .55714 .52748 L F
.566 .603 .849 r
.47323 .56259 m .47277 .56618 L .47134 .56312 L F
.47323 .56259 m .47517 .56569 L .47277 .56618 L F
.675 .559 .716 r
.55971 .52479 m .56224 .52419 L .56219 .52175 L F
.553 .361 .575 r
.55966 .52714 m .56215 .52656 L .55971 .52479 L F
.602 .34 .493 r
.56215 .52656 m .56224 .52419 L .55971 .52479 L F
.971 .808 .623 r
.6577 .41408 m .65914 .41474 L .6582 .41743 L F
.774 .699 .78 r
.7397 .43176 m .7433 .43241 L .7421 .42884 L F
.669 .175 .064 r
.7397 .43176 m .74232 .4337 L .7433 .43241 L F
.571 .571 .814 r
.7433 .43241 m .74459 .42808 L .7421 .42884 L F
.7433 .43241 m .74598 .43272 L .74459 .42808 L F
.764 .416 .396 r
.74232 .4337 m .74598 .43272 L .7433 .43241 L F
.398 .344 .681 r
.37238 .61667 m .37418 .61645 L .37381 .6127 L F
.407 .476 .819 r
.37238 .61667 m .37588 .61916 L .37418 .61645 L F
.349 0 .122 r
.61675 .40813 m .6193 .40757 L .62009 .40571 L F
.279 0 .056 r
.6193 .40757 m .62256 .40516 L .62009 .40571 L F
.419 .083 .286 r
.62009 .40571 m .62256 .40516 L .62301 .40405 L F
.857 .992 .737 r
.59922 .48724 m .60101 .48621 L .59929 .48794 L F
.761 .986 .751 r
.60186 .48444 m .60328 .48386 L .60101 .48621 L F
.76 .982 .737 r
.60186 .48444 m .60101 .48621 L .59922 .48724 L F
.236 .416 .837 r
.48707 .569 m .48666 .57099 L .48451 .56977 L F
.48707 .569 m .48855 .57164 L .48666 .57099 L F
.695 .908 .559 r
.6079 .49882 m .6068 .50073 L .6091 .49765 L F
.667 .867 .481 r
.60566 .50211 m .6068 .50073 L .6079 .49882 L F
.3 0 0 r
.19393 .70465 m .19566 .70476 L .19336 .70513 L F
.738 .894 .95 r
.73301 .44173 m .73614 .44158 L .73503 .44029 L F
.732 .86 .941 r
.73503 .44029 m .73614 .44158 L .73851 .43998 L F
.075 0 0 r
.20762 .63313 m .20887 .63138 L .20591 .63394 L F
.22 0 .152 r
.20762 .63313 m .21054 .63054 L .20887 .63138 L F
.101 .296 .774 r
.38744 .63075 m .38918 .63435 L .38995 .63295 L F
0 .134 .656 r
.38918 .63435 m .39082 .63624 L .38995 .63295 L F
.091 0 0 r
.41542 .5741 m .41712 .57408 L .41838 .57234 L F
.073 0 0 r
.41542 .5741 m .41623 .5753 L .41712 .57408 L F
.41542 .5741 m .41425 .57633 L .41623 .5753 L F
.397 0 .149 r
.62503 .40457 m .62892 .40176 L .62514 .40334 L F
.62503 .40457 m .62746 .40421 L .62892 .40176 L F
.548 .147 .233 r
.62892 .40176 m .63085 .40388 L .63104 .40199 L F
.62892 .40176 m .62746 .40421 L .63085 .40388 L F
.422 0 0 r
.41334 .64608 m .41193 .64676 L .40939 .64618 L F
.207 .674 .941 r
.41558 .6475 m .41193 .64676 L .41334 .64608 L F
.689 .177 .014 r
.46283 .63662 m .46584 .6388 L .46671 .63769 L F
.028 0 0 r
.46923 .63705 m .46543 .6385 L .46671 .63769 L F
.46923 .63705 m .46543 .6385 L .46671 .63769 L F
.723 .81 .918 r
.67669 .40904 m .68004 .40942 L .67841 .40815 L F
.786 .82 .879 r
.68004 .40942 m .68009 .40621 L .67841 .40815 L F
.016 0 0 r
.76225 .43495 m .76467 .43433 L .76128 .43621 L F
0 0 0 r
.5354 .50532 m .53649 .50381 L .53416 .50689 L F
.646 .955 .756 r
.5354 .50532 m .53416 .50689 L .53234 .50773 L F
.421 .255 .549 r
.5562 .55396 m .55629 .55655 L .55429 .55705 L F
.509 .414 .683 r
.55629 .55655 m .55447 .55916 L .55429 .55705 L F
.454 .244 .503 r
.22716 .60168 m .22926 .60126 L .22965 .59862 L F
.163 0 .331 r
.22702 .60424 m .22926 .60126 L .22716 .60168 L F
.648 .462 .618 r
.54257 .57441 m .54552 .57221 L .54248 .57353 L F
.54257 .57441 m .54548 .57388 L .54552 .57221 L F
.577 .494 .724 r
.54552 .57221 m .54765 .57198 L .54674 .56875 L F
.65 .533 .708 r
.54548 .57388 m .54765 .57198 L .54552 .57221 L F
.617 .722 .921 r
.71248 .40476 m .71385 .4017 L .71134 .40256 L F
.71248 .40476 m .71503 .40397 L .71385 .4017 L F
.646 .192 .159 r
.42289 .58625 m .42598 .5865 L .42523 .58542 L F
.779 .645 .714 r
.61267 .46162 m .60997 .45899 L .61253 .45813 L F
.61267 .46162 m .60973 .46139 L .60997 .45899 L F
.686 .564 .712 r
.61531 .45788 m .61267 .46162 L .61253 .45813 L F
0 0 0 r
.61872 .45629 m .61514 .45792 L .61558 .45358 L F
.61872 .45629 m .61531 .45788 L .61514 .45792 L F
.644 .528 .708 r
.61872 .45629 m .61514 .45792 L .61558 .45358 L F
.286 .756 .94 r
.66903 .39968 m .67111 .39964 L .66745 .39938 L F
0 0 0 r
.41998 .63699 m .42101 .63675 L .42272 .63508 L F
.641 .23 .249 r
.42272 .63508 m .42101 .63675 L .42539 .63672 L F
.051 .036 .518 r
.65317 .40677 m .65162 .40595 L .65078 .40498 L F
.596 .649 .873 r
.20169 .67051 m .20297 .67103 L .20272 .66812 L F
.794 .558 .579 r
.20297 .67103 m .20723 .66945 L .20607 .66952 L F
.424 .55 .879 r
.19498 .69575 m .19279 .69954 L .19308 .69933 L F
0 0 0 r
.19254 .69974 m .19308 .69933 L .19279 .69954 L F
.637 .85 .981 r
.54156 .52745 m .54383 .52669 L .54207 .52567 L F
.661 .155 .031 r
.54027 .52866 m .54156 .52745 L .54207 .52567 L F
.54027 .52866 m .54403 .52933 L .54156 .52745 L F
.529 .299 .51 r
.54156 .52745 m .54403 .52933 L .54383 .52669 L F
0 .122 .644 r
.40501 .60921 m .40498 .61102 L .404 .60723 L F
.141 .326 .789 r
.40592 .60936 m .40498 .61102 L .40501 .60921 L F
.40592 .60936 m .40744 .61311 L .40498 .61102 L F
.426 .107 .32 r
.62256 .40516 m .62514 .40334 L .62301 .40405 L F
.505 .257 .472 r
.5634 .54222 m .56551 .54425 L .56314 .54453 L F
.5634 .54222 m .56587 .54162 L .56551 .54425 L F
.685 .762 .91 r
.6657 .44679 m .6696 .44754 L .66818 .44617 L F
.818 .769 .807 r
.62765 .42925 m .629 .43251 L .62642 .43143 L F
0 0 .362 r
.629 .43251 m .6294 .43357 L .62642 .43143 L F
.694 .711 .861 r
.63157 .43124 m .629 .43251 L .62765 .42925 L F
.586 .877 .568 r
.53649 .50381 m .53772 .5023 L .53922 .50097 L F
0 0 0 r
.5354 .50532 m .53772 .5023 L .53649 .50381 L F
.987 .899 .618 r
.61233 .45501 m .61117 .45496 L .61204 .45259 L F
.575 .541 .78 r
.72478 .40527 m .72613 .4096 L .72874 .40851 L F
.189 0 .041 r
.60345 .44823 m .60142 .44764 L .60386 .4468 L F
.60345 .44823 m .60083 .44924 L .60142 .44764 L F
.35 .173 .495 r
.23504 .63602 m .23308 .63281 L .23483 .63252 L F
.23504 .63602 m .23338 .63677 L .23308 .63281 L F
.597 .786 .971 r
.71346 .39502 m .70998 .39438 L .71254 .39368 L F
.582 .762 .964 r
.71497 .39288 m .71346 .39502 L .71254 .39368 L F
.71497 .39288 m .71594 .39441 L .71346 .39502 L F
0 0 0 r
.56636 .47112 m .56796 .47007 L .56873 .46807 L F
.097 0 0 r
.56636 .47112 m .56749 .47175 L .56796 .47007 L F
0 0 0 r
.57134 .46529 m .56873 .46807 L .57039 .46678 L F
.033 0 .007 r
.57039 .46678 m .57321 .46413 L .57134 .46529 L F
.563 .287 .455 r
.42817 .59269 m .42586 .59387 L .42611 .59309 L F
.122 0 .284 r
.22498 .60732 m .22666 .60674 L .22702 .60424 L F
.416 .134 .375 r
.22375 .60939 m .22666 .60674 L .22498 .60732 L F
.569 .273 .426 r
.4398 .55959 m .4396 .56144 L .44225 .56001 L F
.583 .931 .749 r
.44225 .56001 m .44075 .56061 L .44123 .56017 L F
.569 .273 .426 r
.4398 .55959 m .44225 .56001 L .44277 .55993 L F
.583 .931 .749 r
.44225 .56001 m .44123 .56017 L .44205 .55942 L F
.569 .273 .426 r
.44277 .55993 m .44225 .56001 L .44355 .56002 L F
.439 .875 .893 r
.44355 .56002 m .44449 .55918 L .4462 .55923 L F
.44355 .56002 m .44225 .56001 L .44449 .55918 L F
.861 .846 .828 r
.65969 .44929 m .66108 .45053 L .66314 .44752 L F
.511 .903 .765 r
.74605 .42752 m .74459 .42808 L .7467 .42671 L F
.014 0 0 r
.73882 .3987 m .74162 .39745 L .74066 .39845 L F
.776 .928 .564 r
.74397 .39362 m .74162 .39745 L .7412 .39755 L F
.044 0 0 r
.74066 .39845 m .74162 .39745 L .74404 .39681 L F
.516 .361 .609 r
.74404 .39681 m .74162 .39745 L .74397 .39362 L F
.418 .866 .843 r
.54218 .57362 m .54066 .57382 L .53933 .57446 L F
.199 0 .341 r
.54095 .57368 m .53893 .57688 L .53933 .57446 L F
.943 .939 .757 r
.53967 .57395 m .53787 .57607 L .53893 .57688 L F
.743 .643 .75 r
.53958 .57397 m .53627 .57485 L .53481 .57118 L F
.943 .939 .757 r
.54012 .57213 m .53904 .57403 L .53967 .57395 L F
.577 .222 .33 r
.53933 .57446 m .53627 .57485 L .53958 .57397 L F
.943 .939 .757 r
.53904 .57403 m .53787 .57607 L .53967 .57395 L F
.418 .866 .843 r
.54248 .57353 m .54095 .57368 L .54066 .57382 L F
.54248 .57353 m .54066 .57382 L .54218 .57362 L F
.29 .789 .804 r
.54328 .57303 m .54095 .57368 L .54248 .57353 L F
.758 .683 .779 r
.66071 .43794 m .66434 .43856 L .66332 .43493 L F
.921 .912 .793 r
.66151 .44025 m .66434 .43856 L .66071 .43794 L F
.66151 .44025 m .66254 .44147 L .66434 .43856 L F
.586 .879 .573 r
.53772 .5023 m .54042 .49966 L .53922 .50097 L F
.83 .786 .81 r
.69388 .45952 m .69642 .45661 L .69488 .45514 L F
.782 .785 .855 r
.69488 .45514 m .69642 .45661 L .69867 .45486 L F
.133 0 .281 r
.54354 .4971 m .54565 .49385 L .54412 .49504 L F
.701 .674 .82 r
.69006 .45887 m .69388 .45952 L .69298 .45648 L F
.83 .786 .81 r
.69388 .45952 m .69488 .45514 L .69298 .45648 L F
.807 .9 .907 r
.72693 .44387 m .72809 .44516 L .72969 .44348 L F
.346 .106 .4 r
.24038 .62688 m .23772 .62993 L .2386 .62791 L F
.561 .829 .996 r
.73364 .43223 m .73621 .43153 L .73719 .43258 L F
.603 .849 .991 r
.73719 .43258 m .73621 .43153 L .7397 .43176 L F
.835 .968 .648 r
.60453 .48163 m .60328 .48386 L .60422 .48129 L F
.848 .991 .734 r
.60422 .48129 m .60328 .48386 L .60186 .48444 L F
.794 .892 .477 r
.67111 .39964 m .66967 .40271 L .6702 .40074 L F
.369 .58 .923 r
.26321 .54929 m .26246 .55088 L .26155 .54935 L F
.383 .598 .931 r
.26321 .54929 m .26445 .55106 L .26246 .55088 L F
.172 .008 .402 r
.18159 .55886 m .18047 .55728 L .18197 .55656 L F
.18159 .55886 m .18018 .56004 L .18047 .55728 L F
.222 .036 .405 r
.25698 .59843 m .25659 .60084 L .2551 .60158 L F
.436 .264 .549 r
.25693 .60364 m .2551 .60158 L .25659 .60084 L F
.25693 .60364 m .25489 .60428 L .2551 .60158 L F
.623 .721 .917 r
.72724 .39242 m .72605 .39586 L .7247 .39325 L F
.72724 .39242 m .72986 .39623 L .72605 .39586 L F
.347 .186 .516 r
.49275 .58693 m .49482 .58607 L .4918 .58728 L F
.49275 .58693 m .49475 .58849 L .49482 .58607 L F
.49482 .58607 m .49475 .58849 L .49275 .58693 L F
.393 .173 .456 r
.23188 .59524 m .23339 .59728 L .23395 .59458 L F
.23188 .59524 m .23147 .59792 L .23339 .59728 L F
.566 .272 .428 r
.45262 .60159 m .4546 .60326 L .45569 .60184 L F
.37 .535 .888 r
.19841 .69046 m .19635 .69165 L .19394 .69222 L F
.19841 .69046 m .19952 .69298 L .19635 .69165 L F
.358 .025 .257 r
.54289 .57634 m .54548 .57388 L .54257 .57441 L F
.42 .844 .956 r
.74439 .43919 m .74354 .43859 L .74099 .43914 L F
.3 .677 .975 r
.74439 .43919 m .74582 .43819 L .74354 .43859 L F
.74439 .43919 m .74682 .43924 L .74582 .43819 L F
.946 .862 .725 r
.60733 .47683 m .60462 .4787 L .60657 .47583 L F
.60733 .47683 m .60604 .48045 L .60462 .4787 L F
.973 .889 .683 r
.60734 .47352 m .60733 .47683 L .60657 .47583 L F
.698 .696 .845 r
.54628 .5932 m .54739 .59586 L .54365 .5953 L F
.735 .546 .638 r
.54739 .59586 m .54409 .59795 L .54365 .5953 L F
.54739 .59586 m .54737 .59838 L .54409 .59795 L F
.685 .69 .849 r
.54989 .59528 m .54739 .59586 L .54628 .5932 L F
.607 .421 .604 r
.54989 .59528 m .54737 .59838 L .54739 .59586 L F
.951 .901 .739 r
.63222 .4516 m .633 .45039 L .63198 .44928 L F
.402 .211 .503 r
.22926 .60126 m .23147 .59792 L .22965 .59862 L F
.431 .827 .983 r
.18541 .54226 m .18747 .54179 L .18928 .54236 L F
.149 .685 .845 r
.18747 .54179 m .1915 .54193 L .18928 .54236 L F
.527 .331 .558 r
.58472 .52763 m .58511 .52974 L .58244 .5308 L F
.538 .354 .579 r
.58641 .52787 m .58511 .52974 L .58472 .52763 L F
.977 .678 .373 r
.6288 .41762 m .62767 .4188 L .62762 .41613 L F
.152 .132 .579 r
.63003 .41342 m .6288 .41762 L .62762 .41613 L F
.63003 .41342 m .63035 .41768 L .6288 .41762 L F
.057 0 0 r
.63013 .41798 m .6288 .41762 L .63035 .41768 L F
.63013 .41798 m .62767 .4188 L .6288 .41762 L F
.692 .876 .967 r
.41635 .60636 m .41417 .60703 L .41286 .6061 L F
.85 .483 .356 r
.41417 .60703 m .41263 .6091 L .41286 .6061 L F
.362 .666 .973 r
.2456 .5421 m .24518 .5435 L .24345 .54214 L F
.2456 .5421 m .24747 .54364 L .24518 .5435 L F
.532 .625 .889 r
.20723 .66945 m .20465 .66785 L .20656 .66653 L F
.257 .33 .748 r
.20656 .66653 m .20895 .6688 L .20723 .66945 L F
.619 .348 .485 r
.20895 .6688 m .20607 .66952 L .20723 .66945 L F
1 .812 .491 r
.66123 .4429 m .66254 .44147 L .66151 .44025 L F
.66123 .4429 m .66216 .44387 L .66254 .44147 L F
.372 .2 .514 r
.24991 .615 m .24813 .61362 L .25003 .61237 L F
.24991 .615 m .24758 .61621 L .24813 .61362 L F
.491 .074 .177 r
.38179 .59489 m .38452 .59471 L .38578 .59281 L F
.338 0 .088 r
.38578 .59281 m .38722 .59374 L .38803 .59225 L F
.38578 .59281 m .38452 .59471 L .38722 .59374 L F
.737 .31 .234 r
.53508 .59891 m .53194 .59949 L .53161 .59795 L F
.53508 .59891 m .53416 .60083 L .53194 .59949 L F
.504 .061 .129 r
.53913 .60018 m .53416 .60083 L .53508 .59891 L F
.511 .158 .306 r
.53784 .59877 m .53913 .60018 L .53508 .59891 L F
.131 0 0 r
.43873 .56558 m .43748 .56596 L .43495 .56609 L F
.16 0 0 r
.43997 .56601 m .43873 .56558 L .44116 .56572 L F
.43997 .56601 m .43748 .56596 L .43873 .56558 L F
.732 .991 .854 r
.53783 .54805 m .53944 .54718 L .53819 .54723 L F
.631 .069 0 r
.53577 .54527 m .53944 .54718 L .53819 .54723 L F
0 0 0 r
.53944 .54718 m .54081 .54676 L .53819 .54723 L F
.53944 .54718 m .54213 .54529 L .54081 .54676 L F
.174 0 .096 r
.56873 .46807 m .57016 .46905 L .57039 .46678 L F
.56873 .46807 m .56796 .47007 L .57016 .46905 L F
.723 .8 .912 r
.69362 .44685 m .69127 .44781 L .69007 .4464 L F
.558 .432 .665 r
.27035 .57689 m .26745 .57488 L .27004 .57412 L F
.27035 .57689 m .26794 .57744 L .26745 .57488 L F
.656 .636 .818 r
.68456 .45912 m .68824 .46032 L .68686 .45857 L F
.788 .808 .869 r
.68824 .46032 m .69006 .45887 L .68686 .45857 L F
.798 .546 .556 r
.20582 .68356 m .20514 .6857 L .20292 .68251 L F
.832 .724 .746 r
.20514 .6857 m .20357 .68277 L .20292 .68251 L F
.042 0 .162 r
.20292 .68251 m .20156 .68196 L .20343 .68136 L F
0 0 0 r
.20502 .68072 m .20292 .68251 L .20343 .68136 L F
.783 .605 .659 r
.20502 .68072 m .20582 .68356 L .20292 .68251 L F
.832 .724 .746 r
.20357 .68277 m .20199 .67983 L .20292 .68251 L F
.042 0 .162 r
.20292 .68251 m .20143 .682 L .20156 .68196 L F
.20292 .68251 m .20062 .68409 L .20143 .682 L F
.504 .188 .364 r
.57321 .52087 m .57631 .51812 L .57342 .51893 L F
.919 .943 .8 r
.54736 .51239 m .54426 .51468 L .54588 .51569 L F
.54736 .51239 m .54636 .51159 L .54426 .51468 L F
.67 .526 .68 r
.61876 .45287 m .61872 .45629 L .61558 .45358 L F
.62078 .4529 m .61558 .45358 L .61876 .45287 L F
.62078 .4529 m .61872 .45629 L .61558 .45358 L F
.789 .94 .588 r
.60989 .49569 m .6091 .49765 L .61104 .4946 L F
.784 .933 .572 r
.6079 .49882 m .6091 .49765 L .60989 .49569 L F
.864 .651 .613 r
.60903 .46541 m .60753 .4673 L .60732 .46438 L F
.877 .674 .624 r
.60903 .46541 m .60875 .47033 L .60753 .4673 L F
0 .136 .66 r
.43235 .60109 m .43308 .60147 L .43193 .60003 L F
.894 .97 .824 r
.68747 .44665 m .68647 .44589 L .6881 .44391 L F
.911 .592 .428 r
.68992 .44348 m .68831 .44362 L .68939 .44281 L F
.68866 .44377 m .68831 .44362 L .68992 .44348 L F
.894 .97 .824 r
.68747 .44665 m .68856 .44381 L .68831 .44362 L F
.68856 .44381 m .68888 .44296 L .68831 .44362 L F
.481 .693 .961 r
.69061 .44539 m .68831 .44362 L .69094 .44477 L F
.68845 .44385 m .68747 .44665 L .68831 .44362 L F
.69007 .4464 m .68747 .44665 L .68845 .44385 L F
.68845 .44385 m .68831 .44362 L .68856 .44381 L F
.894 .97 .824 r
.68856 .44381 m .68846 .44383 L .68856 .4438 L F
.68846 .44383 m .6881 .44391 L .68846 .44382 L F
.68846 .44383 m .68846 .44382 L .68856 .4438 L F
.68747 .44665 m .68809 .44397 L .68856 .44381 L F
.68809 .44397 m .6881 .44391 L .68856 .44381 L F
.481 .693 .961 r
.69007 .4464 m .68845 .44385 L .69061 .44539 L F
.68845 .44385 m .68856 .44381 L .69061 .44539 L F
.894 .97 .824 r
.68856 .4438 m .6881 .44391 L .68888 .44296 L F
.911 .592 .428 r
.69094 .44477 m .68866 .44377 L .68992 .44348 L F
.539 .572 .836 r
.69262 .44336 m .69094 .44477 L .68939 .44281 L F
.792 .478 .458 r
.69362 .44685 m .69094 .44477 L .69262 .44336 L F
.69362 .44685 m .69007 .4464 L .69094 .44477 L F
.476 .719 .976 r
.68546 .45724 m .68456 .45912 L .68686 .45857 L F
.008 0 .144 r
.47489 .57761 m .4779 .57443 L .47433 .57437 L F
.47759 .57476 m .47673 .57503 L .47764 .5747 L F
.47489 .57761 m .47673 .57503 L .47759 .57476 L F
.84 .405 .193 r
.47414 .57598 m .47383 .57588 L .47673 .57503 L F
.264 0 0 r
.47673 .57503 m .47383 .57588 L .47416 .57586 L F
.008 0 .144 r
.47489 .57761 m .47668 .57686 L .47673 .57503 L F
.84 .405 .193 r
.47668 .57686 m .47414 .57598 L .47673 .57503 L F
.264 0 0 r
.47673 .57503 m .47416 .57586 L .47875 .57571 L F
.008 0 .144 r
.47764 .5747 m .47673 .57503 L .4779 .57443 L F
.254 0 0 r
.47673 .57503 m .48072 .57555 L .4779 .57443 L F
0 0 .369 r
.76634 .40691 m .76566 .409 L .76599 .40753 L F
0 .096 .653 r
.76656 .40894 m .76566 .409 L .76634 .40691 L F
.76656 .40894 m .76753 .41126 L .76566 .409 L F
.526 .522 .794 r
.52417 .58969 m .52608 .58971 L .5253 .5857 L F
.612 .809 .976 r
.3834 .63026 m .38495 .63142 L .38744 .63075 L F
.393 .164 .444 r
.24201 .62621 m .24096 .62466 L .24261 .62392 L F
.24201 .62621 m .24038 .62688 L .24096 .62466 L F
.44 .023 .151 r
.21576 .80621 m .21698 .80608 L .21592 .806 L F
0 0 .314 r
.21722 .55764 m .21693 .55741 L .21867 .5561 L F
.21722 .55764 m .21777 .55974 L .21693 .55741 L F
.582 .396 .595 r
.37683 .59786 m .37945 .59454 L .377 .59552 L F
.595 .275 .398 r
.5564 .53192 m .55504 .52968 L .55374 .53222 L F
.5564 .53192 m .55732 .52977 L .55504 .52968 L F
.282 .014 .317 r
.21801 .65119 m .21625 .65198 L .2188 .64908 L F
0 0 0 r
.22064 .64821 m .21801 .65119 L .2188 .64908 L F
.312 0 .077 r
.41654 .63949 m .4196 .63932 L .41998 .63699 L F
0 0 .007 r
.41998 .63699 m .4196 .63932 L .42101 .63675 L F
.873 .843 .812 r
.68747 .44665 m .68396 .44889 L .68647 .44589 L F
.68747 .44665 m .6851 .44983 L .68396 .44889 L F
.652 .733 .909 r
.73099 .39318 m .72986 .39623 L .72724 .39242 L F
.679 .767 .917 r
.73282 .39435 m .72986 .39623 L .73099 .39318 L F
.799 .793 .847 r
.48249 .57064 m .4815 .57223 L .47885 .57091 L F
.239 0 .286 r
.26914 .55875 m .26787 .55888 L .2671 .55793 L F
.483 .322 .586 r
.2721 .55576 m .2671 .55793 L .27032 .55509 L F
.2721 .55576 m .26914 .55875 L .2671 .55793 L F
.534 .719 .958 r
.63508 .4324 m .63157 .43124 L .63387 .43069 L F
.722 .538 .642 r
.63508 .4324 m .63536 .43485 L .63257 .43522 L F
.638 .68 .873 r
.63673 .4279 m .63508 .4324 L .63387 .43069 L F
.63673 .4279 m .63748 .43158 L .63508 .4324 L F
.575 .435 .654 r
.63748 .43158 m .63536 .43485 L .63508 .4324 L F
.752 .507 .561 r
.42942 .59509 m .4256 .59727 L .4287 .59393 L F
.42942 .59509 m .42907 .59835 L .4256 .59727 L F
.751 .671 .773 r
.43174 .59248 m .42942 .59509 L .42817 .59269 L F
0 .393 .847 r
.4287 .59393 m .42997 .59435 L .42942 .59509 L F
.739 .349 0 r
.42817 .59269 m .42942 .59509 L .4287 .59393 L F
0 .393 .847 r
.4287 .59393 m .42997 .59435 L .42942 .59509 L F
.656 .689 .869 r
.43185 .59503 m .42942 .59509 L .43174 .59248 L F
.692 .876 .967 r
.41635 .60636 m .41286 .6061 L .41481 .60373 L F
.564 .686 .922 r
.41892 .60559 m .41635 .60636 L .41481 .60373 L F
.884 .619 .533 r
.50926 .58986 m .50807 .59226 L .50833 .58942 L F
.50926 .58986 m .50833 .58942 L .50897 .59009 L F
.232 0 .192 r
.50926 .58986 m .51005 .59204 L .50807 .59226 L F
.443 .011 .122 r
.51326 .59093 m .51005 .59204 L .50926 .58986 L F
.322 0 0 r
.50897 .59009 m .51326 .59093 L .50926 .58986 L F
.994 .764 .478 r
.21839 .58547 m .21818 .58796 L .22007 .58846 L F
.844 .67 .666 r
.21532 .59041 m .22007 .58846 L .21818 .58796 L F
.21532 .59041 m .21766 .59202 L .22007 .58846 L F
.138 .279 .747 r
.46111 .59867 m .46212 .59677 L .45966 .59754 L F
.068 0 0 r
.20039 .63787 m .20266 .63718 L .20342 .63648 L F
0 0 0 r
.20342 .63648 m .2045 .63628 L .20591 .63394 L F
.20342 .63648 m .20266 .63718 L .2045 .63628 L F
.818 .738 .777 r
.48622 .57487 m .4845 .57722 L .48754 .5778 L F
.844 .992 .848 r
.48418 .58 m .48754 .5778 L .4845 .57722 L F
.48418 .58 m .48406 .58097 L .48754 .5778 L F
.621 .646 .854 r
.48622 .57487 m .48754 .5778 L .49193 .57658 L F
.408 .173 .442 r
.21556 .65403 m .21378 .65488 L .21625 .65198 L F
.563 .838 .492 r
.21801 .65119 m .21556 .65403 L .21625 .65198 L F
.898 .875 .805 r
.60462 .4787 m .60604 .48045 L .60453 .48163 L F
.588 .168 .213 r
.21556 .65403 m .21178 .65614 L .21378 .65488 L F
.473 .802 1 r
.23592 .58677 m .23413 .58577 L .23217 .58628 L F
0 .211 .737 r
.23592 .58677 m .23613 .58547 L .23413 .58577 L F
.23592 .58677 m .23808 .58872 L .23613 .58547 L F
0 .562 .724 r
.21553 .54025 m .21772 .54035 L .21946 .54047 L F
.188 .702 .889 r
.21772 .54035 m .22166 .54065 L .21946 .54047 L F
0 .547 .741 r
.21946 .54047 m .22166 .54065 L .22336 .54086 L F
.132 0 0 r
.57864 .45664 m .57781 .45794 L .58086 .45561 L F
.669 .807 .949 r
.47134 .56312 m .46964 .56434 L .46758 .56284 L F
.673 .416 .524 r
.44121 .64574 m .4403 .64863 L .43732 .64841 L F
.662 .405 .52 r
.44326 .64819 m .44121 .64574 L .44266 .64736 L F
.44326 .64819 m .4403 .64863 L .44121 .64574 L F
.183 0 0 r
.44722 .56487 m .44337 .56747 L .44565 .56465 L F
.668 .628 .801 r
.70568 .44615 m .70338 .44744 L .70221 .44386 L F
.723 .956 .67 r
.6134 .49106 m .61618 .48841 L .61585 .48821 L F
.837 .957 .891 r
.61618 .48841 m .61808 .48496 L .61685 .48611 L F
.61618 .48841 m .61897 .4859 L .61808 .48496 L F
.828 .939 .572 r
.61585 .48821 m .61618 .48841 L .61685 .48611 L F
.284 .408 .812 r
.49679 .57077 m .49633 .57448 L .4945 .57157 L F
.49679 .57077 m .49785 .573 L .49633 .57448 L F
.151 .191 .65 r
.49785 .573 m .49821 .57649 L .49633 .57448 L F
.777 .894 .927 r
.71977 .44064 m .71687 .44098 L .71902 .43974 L F
.88 .963 .847 r
.72214 .43772 m .71977 .44064 L .71902 .43974 L F
.279 .007 .309 r
.58862 .44692 m .59065 .446 L .59087 .44361 L F
.362 .127 .417 r
.59087 .44361 m .59325 .44341 L .59328 .44078 L F
.362 .07 .329 r
.59087 .44361 m .59292 .44524 L .59325 .44341 L F
.59087 .44361 m .59065 .446 L .59292 .44524 L F
.532 .876 .988 r
.61931 .42455 m .61805 .42604 L .62076 .42353 L F
.61931 .42455 m .61689 .42532 L .61805 .42604 L F
.44 .161 .392 r
.58244 .5308 m .58472 .53185 L .58218 .53284 L F
.58244 .5308 m .58511 .52974 L .58472 .53185 L F
.881 .859 .815 r
.47259 .5729 m .47433 .57437 L .47709 .57052 L F
.393 .188 .478 r
.26368 .5865 m .26334 .58912 L .26128 .58975 L F
.404 .257 .566 r
.26334 .58912 m .26138 .59227 L .26128 .58975 L F
0 0 .16 r
.21103 .62822 m .21247 .62728 L .21292 .62506 L F
0 0 .175 r
.21054 .63054 m .21247 .62728 L .21103 .62822 L F
0 0 .423 r
.76735 .42869 m .7672 .43137 L .76688 .42892 L F
.505 .004 0 r
.16917 .56341 m .16698 .56482 L .16394 .56409 L F
0 0 0 r
.16888 .56367 m .16917 .56341 L .17097 .56269 L F
.16888 .56367 m .16698 .56482 L .16917 .56341 L F
0 .463 .696 r
.22549 .54097 m .22761 .54137 L .22932 .54169 L F
.047 .605 .81 r
.22761 .54137 m .23155 .54183 L .22932 .54169 L F
.239 0 .286 r
.26914 .55875 m .26702 .56 L .26787 .55888 L F
.707 .322 .317 r
.45187 .64027 m .45423 .64231 L .45495 .64099 L F
.995 .81 .444 r
.76718 .41945 m .76673 .4216 L .76774 .42213 L F
.809 .682 .137 r
.76743 .42499 m .76774 .42213 L .76673 .4216 L F
.998 .787 .481 r
.76628 .42021 m .76673 .4216 L .76691 .42073 L F
.76628 .42021 m .76691 .42073 L .76718 .41945 L F
.89 .667 .595 r
.76497 .41911 m .76508 .41922 L .76628 .42021 L F
.523 .442 .705 r
.7675 .42154 m .76673 .4216 L .76628 .42021 L F
.89 .667 .595 r
.76508 .41922 m .76903 .4232 L .76628 .42021 L F
.523 .442 .705 r
.76903 .4232 m .76752 .42215 L .7675 .42154 L F
.76752 .42215 m .76673 .4216 L .7675 .42154 L F
.809 .682 .137 r
.76743 .42499 m .76753 .42619 L .76759 .42507 L F
.76756 .4238 m .76759 .42507 L .76774 .42213 L F
.76743 .42499 m .76759 .42507 L .76756 .4238 L F
.311 .756 .962 r
.19766 .5567 m .1936 .55624 L .1955 .55716 L F
.619 .514 .713 r
.56219 .52175 m .56224 .52419 L .56444 .52116 L F
.59 .474 .69 r
.56224 .52419 m .56515 .52354 L .56444 .52116 L F
.646 .449 .602 r
.56215 .52656 m .56515 .52354 L .56224 .52419 L F
.659 .69 .868 r
.74651 .39262 m .74762 .39435 L .74397 .39362 L F
.765 .595 .667 r
.74762 .39435 m .74404 .39681 L .74397 .39362 L F
.74762 .39435 m .74742 .39683 L .74404 .39681 L F
.677 .76 .914 r
.74916 .39185 m .74762 .39435 L .74651 .39262 L F
.74916 .39185 m .75001 .39364 L .74762 .39435 L F
.627 .474 .655 r
.75001 .39364 m .74742 .39683 L .74762 .39435 L F
0 0 .399 r
.51987 .57225 m .52066 .57292 L .51944 .57042 L F
.51987 .57225 m .52072 .57451 L .52066 .57292 L F
.522 .272 .477 r
.53819 .54723 m .53577 .54527 L .53571 .54746 L F
.492 0 0 r
.53376 .54388 m .53577 .54527 L .53819 .54723 L F
.572 .813 .99 r
.18011 .63831 m .17961 .64006 L .17916 .63986 L F
.18011 .63831 m .18177 .63939 L .17961 .64006 L F
.241 0 0 r
.47885 .57091 m .47804 .57167 L .47515 .57152 L F
.668 .394 .497 r
.47563 .57163 m .47528 .57138 L .47515 .57152 L F
.47528 .57138 m .47349 .57014 L .47515 .57152 L F
.881 .859 .815 r
.47259 .5729 m .47509 .57158 L .47515 .57152 L F
.47509 .57158 m .47709 .57052 L .47515 .57152 L F
.241 0 0 r
.47885 .57091 m .47515 .57152 L .47709 .57052 L F
.397 .036 .23 r
.47965 .56936 m .47885 .57091 L .47709 .57052 L F
.957 .716 .532 r
.54619 .52405 m .54439 .52016 L .54299 .52338 L F
.856 .792 .787 r
.54383 .52669 m .54619 .52405 L .54299 .52338 L F
.862 .731 .717 r
.54096 .58336 m .5417 .58528 L .53928 .58652 L F
.747 .992 .877 r
.53928 .58652 m .5417 .58528 L .5393 .58647 L F
.53928 .58652 m .54096 .58336 L .5371 .58303 L F
.872 .743 .717 r
.5381 .58707 m .5417 .58528 L .53877 .58892 L F
.747 .992 .877 r
.53928 .58652 m .5393 .58647 L .54096 .58336 L F
.5393 .58647 m .53982 .58529 L .54092 .58342 L F
.5393 .58647 m .54092 .58342 L .54096 .58336 L F
.611 .734 .933 r
.53501 .58607 m .53928 .58652 L .53735 .58503 L F
.872 .743 .717 r
.53735 .58503 m .53999 .58518 L .5381 .58707 L F
.53999 .58518 m .5417 .58528 L .5393 .58647 L F
.53999 .58518 m .5393 .58647 L .5381 .58707 L F
.747 .992 .877 r
.5393 .58647 m .5417 .58528 L .53982 .58529 L F
.842 .839 .843 r
.54245 .58736 m .53877 .58892 L .5417 .58528 L F
.652 .538 .712 r
.5417 .58528 m .54477 .58643 L .54245 .58736 L F
.66 .473 .621 r
.43481 .5928 m .43185 .59503 L .43174 .59248 L F
.43481 .5928 m .4353 .59535 L .43185 .59503 L F
.579 .42 .63 r
.43773 .59489 m .43481 .5928 L .43718 .59183 L F
.43773 .59489 m .4353 .59535 L .43481 .5928 L F
.692 .871 .966 r
.71329 .45282 m .71648 .45276 L .71568 .45178 L F
.811 .935 .912 r
.71568 .45178 m .71648 .45276 L .71933 .45045 L F
0 .552 .813 r
.66401 .41107 m .66752 .41185 L .66665 .41146 L F
.66401 .41107 m .66752 .41185 L .66665 .41146 L F
.345 .619 .953 r
.66925 .41069 m .66752 .41185 L .66665 .41146 L F
.66925 .41069 m .67059 .41236 L .66752 .41185 L F
.168 .559 .932 r
.67167 .4138 m .66752 .41185 L .67059 .41236 L F
.358 0 .197 r
.61963 .41827 m .61918 .41974 L .61666 .42037 L F
.387 .016 .207 r
.6217 .41888 m .61963 .41827 L .62178 .41727 L F
.6217 .41888 m .61918 .41974 L .61963 .41827 L F
.133 0 .277 r
.23461 .58066 m .23538 .58213 L .23678 .57994 L F
.23461 .58066 m .23389 .5832 L .23538 .58213 L F
.911 .587 .42 r
.50422 .54852 m .5021 .54937 L .50309 .54709 L F
.50422 .54852 m .50467 .55103 L .5021 .54937 L F
.238 .302 .727 r
.24329 .56296 m .24435 .56222 L .2435 .55881 L F
.154 .142 .59 r
.24329 .56296 m .24483 .56471 L .24435 .56222 L F
.393 .18 .467 r
.24287 .56532 m .24483 .56471 L .24329 .56296 L F
0 0 0 r
.5546 .56536 m .55303 .56845 L .55275 .56593 L F
.546 .445 .691 r
.52686 .53365 m .52421 .53371 L .526 .53227 L F
.52686 .53365 m .52464 .5361 L .52421 .53371 L F
.52421 .53371 m .52464 .5361 L .52686 .53365 L F
.599 .341 .498 r
.44572 .57779 m .44901 .57771 L .44943 .5745 L F
.37 .16 .459 r
.44943 .5745 m .45157 .57375 L .45203 .57137 L F
.546 .567 .827 r
.45317 .57688 m .44943 .5745 L .45157 .57375 L F
.293 .083 .413 r
.44943 .5745 m .45099 .5761 L .45157 .57375 L F
.44943 .5745 m .44901 .57771 L .45099 .5761 L F
.259 0 .192 r
.26055 .82476 m .25747 .82694 L .25898 .82437 L F
.459 .888 .87 r
.68963 .40437 m .69059 .40447 L .69291 .40347 L F
.485 .681 .952 r
.21562 .59241 m .21532 .59041 L .21348 .58939 L F
.21562 .59241 m .21766 .59202 L .21532 .59041 L F
.757 .586 .664 r
.17549 .56042 m .17493 .56311 L .17097 .56269 L F
.274 .778 .801 r
.17862 .56128 m .17819 .56136 L .17689 .56186 L F
.491 .329 .588 r
.17689 .56186 m .17504 .56257 L .17549 .56042 L F
.17689 .56186 m .17493 .56311 L .17549 .56042 L F
.274 .778 .801 r
.17819 .56136 m .17522 .56191 L .17689 .56186 L F
.491 .329 .588 r
.17689 .56186 m .17493 .56311 L .17504 .56257 L F
.833 .92 .893 r
.61973 .44716 m .61686 .44999 L .61584 .44878 L F
.268 .579 .942 r
.25583 .54541 m .25555 .54697 L .25315 .5452 L F
.25583 .54541 m .25716 .54703 L .25555 .54697 L F
.695 .426 .512 r
.20272 .66812 m .20656 .66653 L .20465 .66785 L F
.782 .785 .855 r
.69488 .45514 m .69867 .45486 L .69615 .45305 L F
.559 .771 .977 r
.69867 .45486 m .69981 .453 L .69615 .45305 L F
.69867 .45486 m .70127 .45428 L .69981 .453 L F
.609 .479 .678 r
.56219 .52175 m .56444 .52116 L .5638 .51763 L F
.999 .8 .461 r
.65716 .43079 m .65809 .43264 L .65773 .43464 L F
.767 .715 .804 r
.62937 .43665 m .63036 .43874 L .6269 .43828 L F
.738 .703 .818 r
.63268 .43731 m .63036 .43874 L .62937 .43665 L F
.789 .94 .588 r
.60989 .49569 m .61104 .4946 L .61102 .49404 L F
.753 .949 .629 r
.61104 .4946 m .6134 .49106 L .61102 .49404 L F
.126 0 .073 r
.57601 .45912 m .57308 .46184 L .57515 .46066 L F
.343 .072 .35 r
.57515 .46066 m .57781 .45794 L .57601 .45912 L F
.377 .163 .456 r
.24504 .6209 m .24261 .62392 L .24312 .62192 L F
.607 .631 .849 r
.21589 .80644 m .21698 .80608 L .21576 .80621 L F
.312 0 .086 r
.59748 .46049 m .59407 .46302 L .59503 .4614 L F
.407 .651 .958 r
.6728 .41246 m .67167 .4138 L .67059 .41236 L F
.182 0 .097 r
.61467 .4091 m .614 .41049 L .61675 .40813 L F
.474 .719 .977 r
.18933 .64262 m .18598 .64151 L .18759 .6415 L F
.704 .914 .967 r
.18972 .64083 m .18933 .64262 L .18759 .6415 L F
.18972 .64083 m .19131 .64152 L .18933 .64262 L F
.686 .76 .908 r
.71859 .40508 m .72003 .40161 L .71761 .40256 L F
.71859 .40508 m .72123 .40403 L .72003 .40161 L F
.955 .798 .647 r
.54504 .51793 m .54588 .51569 L .54426 .51468 L F
.013 0 .137 r
.61233 .41185 m .61164 .41364 L .614 .41049 L F
.611 .251 .334 r
.43228 .6422 m .43607 .64011 L .43238 .63996 L F
.43228 .6422 m .43516 .64259 L .43607 .64011 L F
.678 .32 .361 r
.43607 .64011 m .43516 .64259 L .43851 .64233 L F
.163 0 .331 r
.22702 .60424 m .22883 .60348 L .22926 .60126 L F
.234 0 .322 r
.22702 .60424 m .22836 .60583 L .22883 .60348 L F
.22702 .60424 m .22666 .60674 L .22836 .60583 L F
.116 .567 .918 r
.45567 .58206 m .45715 .58316 L .45413 .58222 L F
.45567 .58206 m .45413 .58222 L .45527 .58456 L F
.896 .986 .788 r
.45527 .58456 m .45333 .58521 L .45567 .58206 L F
.661 .149 .016 r
.45527 .58456 m .45684 .5859 L .45333 .58521 L F
.521 .739 .974 r
.6335 .40116 m .63596 .40076 L .63468 .40263 L F
0 0 .378 r
.63574 .40107 m .6348 .40319 L .63468 .40263 L F
.63572 .40125 m .6348 .40319 L .63574 .40107 L F
.63596 .40076 m .63599 .40306 L .6348 .40319 L F
.56 .277 .443 r
.6335 .40116 m .63345 .40349 L .63551 .40314 L F
.63556 .40273 m .63551 .40314 L .63599 .40306 L F
.6335 .40116 m .63551 .40314 L .63556 .40273 L F
0 0 .378 r
.63596 .40076 m .63572 .40125 L .63574 .40107 L F
.264 .765 .725 r
.45677 .56468 m .45789 .56427 L .45901 .56403 L F
.43 .128 .349 r
.45789 .56427 m .46049 .56336 L .45901 .56403 L F
.738 .455 .5 r
.51071 .53237 m .50722 .53324 L .5081 .5308 L F
0 0 0 r
.51071 .53237 m .5071 .53344 L .50947 .53365 L F
.738 .455 .5 r
.51071 .53237 m .50947 .53365 L .50758 .5333 L F
0 0 0 r
.51071 .53237 m .50932 .5357 L .51019 .53408 L F
.908 .529 .295 r
.50482 .53192 m .50722 .53324 L .5061 .53296 L F
.09 .618 .871 r
.50722 .53324 m .50758 .5333 L .5061 .53296 L F
.50758 .5333 m .50947 .53365 L .508 .53334 L F
.908 .529 .295 r
.50482 .53192 m .50513 .53254 L .50587 .53279 L F
.347 0 0 r
.5061 .53296 m .50607 .53295 L .50482 .53192 L F
.50607 .53295 m .50606 .53295 L .50587 .53279 L F
.50607 .53295 m .50587 .53279 L .50482 .53192 L F
.908 .529 .295 r
.50482 .53192 m .50587 .53279 L .50722 .53324 L F
.875 .876 .833 r
.50675 .53308 m .50587 .53279 L .5061 .5312 L F
.50587 .53279 m .50513 .53254 L .50528 .53233 L F
.50587 .53279 m .50528 .53233 L .5061 .5312 L F
.347 0 0 r
.50584 .53277 m .50519 .53225 L .50482 .53192 L F
.878 .882 .833 r
.50833 .52815 m .50528 .53233 L .50408 .53074 L F
.50528 .53233 m .50513 .53254 L .50475 .5319 L F
.71 .32 0 r
.50408 .53074 m .50513 .53254 L .50482 .53192 L F
0 .106 .628 r
.50482 .53192 m .50492 .53191 L .50408 .53074 L F
.878 .882 .833 r
.50528 .53233 m .50515 .53222 L .50408 .53074 L F
0 .106 .628 r
.50492 .53191 m .50522 .53187 L .50408 .53074 L F
.878 .882 .833 r
.50515 .53222 m .50475 .5319 L .50408 .53074 L F
.347 0 0 r
.50606 .53295 m .50596 .53294 L .50519 .53225 L F
.50606 .53295 m .50519 .53225 L .50584 .53277 L F
.875 .876 .833 r
.50722 .53324 m .50675 .53308 L .50833 .52815 L F
.50675 .53308 m .5061 .5312 L .50833 .52815 L F
0 0 0 r
.50711 .53344 m .51019 .53408 L .5071 .53344 L F
.50758 .5333 m .50779 .53337 L .50711 .53344 L F
.664 .771 .929 r
.50947 .53365 m .5071 .53344 L .50752 .5334 L F
0 0 0 r
.50779 .53337 m .51019 .53408 L .50711 .53344 L F
.664 .771 .929 r
.50752 .5334 m .5071 .53344 L .50682 .53331 L F
.50675 .53309 m .50682 .53331 L .5061 .53296 L F
.09 .618 .871 r
.50758 .5333 m .508 .53334 L .5061 .53296 L F
0 0 0 r
.51071 .53237 m .50711 .53344 L .5071 .53344 L F
.50711 .53344 m .5071 .53344 L .5071 .53344 L F
.664 .771 .929 r
.508 .53334 m .50682 .53331 L .50675 .53309 L F
.50947 .53365 m .50752 .5334 L .508 .53334 L F
.50752 .5334 m .50682 .53331 L .508 .53334 L F
0 0 0 r
.51071 .53237 m .51034 .53358 L .50758 .5333 L F
.51034 .53358 m .51019 .53408 L .50758 .5333 L F
.738 .455 .5 r
.51071 .53237 m .50758 .5333 L .50722 .53324 L F
.176 .128 .561 r
.24198 .57176 m .24316 .57112 L .24312 .56787 L F
.545 .5 .756 r
.24184 .57488 m .24316 .57112 L .24198 .57176 L F
.608 .863 .991 r
.20433 .6555 m .202 .65628 L .20346 .65659 L F
.248 .603 .953 r
.20619 .65643 m .20486 .65701 L .20861 .6565 L F
.20565 .65646 m .20486 .65701 L .20619 .65643 L F
.20572 .65641 m .20591 .65711 L .20486 .65701 L F
.608 .863 .991 r
.20529 .65648 m .20346 .65659 L .20591 .65711 L F
.20433 .6555 m .20346 .65659 L .20529 .65648 L F
.248 .603 .953 r
.20572 .65641 m .20565 .65646 L .20619 .65643 L F
.681 .497 .631 r
.62703 .41067 m .62398 .41381 L .62425 .41166 L F
.769 .979 .913 r
.55527 .50113 m .55448 .5032 L .55698 .50043 L F
.55527 .50113 m .55365 .5027 L .55448 .5032 L F
.503 .209 .4 r
.23678 .57994 m .23978 .5778 L .23775 .57902 L F
.991 .731 .403 r
.5316 .59543 m .53055 .59697 L .53027 .59456 L F
.5316 .59543 m .53161 .59795 L .53055 .59697 L F
.581 .307 .465 r
.40398 .62729 m .40205 .6282 L .402 .62586 L F
.562 .316 .501 r
.4046 .62448 m .40398 .62729 L .402 .62586 L F
.179 0 0 r
.75822 .43665 m .75932 .43604 L .76128 .43621 L F
.925 .838 .739 r
.6474 .43699 m .65033 .4348 L .65 .43401 L F
.6474 .43699 m .64878 .43823 L .65033 .4348 L F
.938 .929 .77 r
.65033 .4348 m .65079 .43174 L .65 .43401 L F
.905 .872 .794 r
.72636 .43035 m .72758 .43195 L .72517 .4352 L F
.909 .871 .788 r
.72784 .43055 m .72758 .43195 L .72636 .43035 L F
.322 .163 .504 r
.59328 .44078 m .59553 .4399 L .59556 .43759 L F
.401 .156 .424 r
.59328 .44078 m .5956 .44254 L .59553 .4399 L F
.59328 .44078 m .59325 .44341 L .5956 .44254 L F
.745 .985 .904 r
.19317 .69816 m .19254 .69974 L .19066 .7005 L F
.19317 .69816 m .19308 .69933 L .19254 .69974 L F
.818 .761 .799 r
.68686 .45857 m .69006 .45887 L .68914 .45547 L F
.715 .703 .837 r
.68914 .45547 m .69006 .45887 L .69298 .45648 L F
.799 .675 .727 r
.6599 .44673 m .66314 .44752 L .66216 .44387 L F
.861 .846 .828 r
.65969 .44929 m .66314 .44752 L .6599 .44673 L F
.651 .587 .77 r
.66216 .44387 m .66314 .44752 L .6657 .44679 L F
.413 .259 .561 r
.26914 .55875 m .26705 .56249 L .26702 .56 L F
.509 .414 .683 r
.55629 .55655 m .55701 .55894 L .55447 .55916 L F
.455 .322 .61 r
.55701 .55894 m .55482 .56259 L .55447 .55916 L F
.504 .188 .364 r
.57321 .52087 m .57595 .52055 L .57631 .51812 L F
.427 .191 .452 r
.57595 .52055 m .57866 .51739 L .57631 .51812 L F
.452 .14 .344 r
.2045 .63628 m .20762 .63313 L .20591 .63394 L F
.657 .471 .621 r
.40359 .61634 m .39928 .61807 L .39931 .61634 L F
.383 .262 .59 r
.55802 .55053 m .5562 .55396 L .55568 .55099 L F
.55802 .55053 m .55844 .55314 L .5562 .55396 L F
.406 .263 .572 r
.55844 .55314 m .55629 .55655 L .5562 .55396 L F
.691 .981 .843 r
.58063 .47445 m .57932 .47626 L .58195 .47357 L F
.58063 .47445 m .57874 .47607 L .57932 .47626 L F
.56 .7 .934 r
.37588 .61916 m .37507 .61983 L .37742 .61822 L F
.532 .534 .803 r
.3764 .62207 m .37742 .61822 L .37507 .61983 L F
.794 .892 .477 r
.67111 .39964 m .6702 .40074 L .66745 .39938 L F
.457 .119 .303 r
.74014 .42008 m .7422 .41989 L .74297 .41775 L F
.705 .391 .443 r
.74297 .41775 m .74542 .42104 L .74647 .41835 L F
.309 .668 .974 r
.70952 .44753 m .70568 .44615 L .70818 .44551 L F
.579 .409 .615 r
.71218 .44436 m .70952 .44753 L .70818 .44551 L F
.71218 .44436 m .71129 .44601 L .70952 .44753 L F
.866 .762 .746 r
.6636 .4324 m .66367 .4282 L .66296 .43168 L F
.962 .75 .571 r
.66186 .43364 m .6636 .4324 L .66296 .43168 L F
.66186 .43364 m .66332 .43493 L .6636 .4324 L F
.299 0 .246 r
.58082 .51214 m .58339 .51142 L .58373 .50938 L F
.348 .174 .497 r
.58572 .50609 m .58373 .50938 L .58577 .50828 L F
.323 .096 .407 r
.58339 .51142 m .58577 .50828 L .58373 .50938 L F
.464 .479 .789 r
.55481 .5684 m .55383 .57214 L .55303 .56845 L F
.55481 .5684 m .55609 .57021 L .55383 .57214 L F
.364 .312 .665 r
.55383 .57214 m .55644 .57455 L .55445 .5744 L F
.55383 .57214 m .55609 .57021 L .55644 .57455 L F
.714 .652 .786 r
.51891 .53848 m .52226 .53912 L .52095 .53563 L F
.014 0 .473 r
.51891 .53848 m .52144 .5386 L .52226 .53912 L F
.308 .068 .377 r
.52464 .5361 m .52226 .53912 L .52449 .5381 L F
.955 .646 .222 r
.52226 .53912 m .52144 .5386 L .52095 .53563 L F
.308 .068 .377 r
.52464 .5361 m .52226 .53912 L .52449 .5381 L F
.77 .68 .764 r
.52095 .53563 m .52226 .53912 L .52464 .5361 L F
.534 .897 .971 r
.52226 .53912 m .52144 .5386 L .52449 .5381 L F
.417 .282 .588 r
.52226 .53912 m .52401 .54132 L .52449 .5381 L F
0 .023 .592 r
.52346 .53976 m .52226 .53912 L .52144 .5386 L F
.52346 .53976 m .52401 .54132 L .52226 .53912 L F
.8 .993 .875 r
.51686 .52257 m .51865 .52229 L .51628 .52451 L F
.802 .994 .871 r
.51686 .52257 m .51628 .52451 L .51419 .52496 L F
.7 .28 .245 r
.44578 .64266 m .44792 .64497 L .44968 .64327 L F
0 0 .233 r
.44968 .64327 m .45043 .64442 L .44923 .64527 L F
.776 .928 .564 r
.74397 .39362 m .7412 .39755 L .7431 .39255 L F
.659 .845 .971 r
.74532 .39135 m .74397 .39362 L .7431 .39255 L F
.74532 .39135 m .74651 .39262 L .74397 .39362 L F
.405 .157 .421 r
.2478 .61801 m .24504 .6209 L .24582 .61882 L F
.617 .901 .986 r
.63934 .43862 m .64247 .43837 L .64133 .43715 L F
.634 .303 .394 r
.57442 .53611 m .57684 .53802 L .57421 .53844 L F
.57442 .53611 m .57707 .53622 L .57684 .53802 L F
.711 .667 .805 r
.69628 .44598 m .69362 .44685 L .69262 .44336 L F
.684 .817 .946 r
.18259 .61576 m .18115 .61697 L .17896 .61665 L F
.59 .463 .676 r
.46447 .57402 m .46672 .57108 L .46446 .57181 L F
.343 .507 .876 r
.1986 .69936 m .19498 .69575 L .19757 .69597 L F
0 .073 .614 r
.19926 .69805 m .1986 .69936 L .19757 .69597 L F
0 .006 .559 r
.19961 .70073 m .1986 .69936 L .19926 .69805 L F
.078 .06 .533 r
.19961 .70073 m .19903 .70258 L .1986 .69936 L F
.656 .532 .701 r
.4353 .59535 m .43292 .59592 L .43185 .59503 L F
.685 .69 .849 r
.54989 .59528 m .54628 .5932 L .54896 .59336 L F
.607 .421 .604 r
.54989 .59528 m .55003 .59822 L .54737 .59838 L F
0 .49 .802 r
.54896 .59336 m .55236 .5945 L .54989 .59528 L F
.58 .414 .621 r
.55236 .5945 m .55003 .59822 L .54989 .59528 L F
.358 .025 .257 r
.54289 .57634 m .54458 .5765 L .54548 .57388 L F
.65 .533 .708 r
.54548 .57388 m .54825 .57447 L .54765 .57198 L F
.778 .441 .417 r
.54548 .57388 m .54829 .57693 L .54825 .57447 L F
.54548 .57388 m .54458 .5765 L .54829 .57693 L F
.576 .829 .993 r
.18685 .66033 m .18917 .65964 L .18645 .65817 L F
0 .546 .726 r
.22166 .54065 m .22549 .54097 L .22336 .54086 L F
.521 .287 .501 r
.27698 .56284 m .27901 .56478 L .27919 .5623 L F
.27698 .56284 m .27644 .56546 L .27901 .56478 L F
.27698 .56284 m .27901 .56478 L .27919 .5623 L F
.27698 .56284 m .27644 .56546 L .27901 .56478 L F
.833 .796 .817 r
.42695 .58334 m .42919 .58058 L .42774 .58319 L F
.586 .813 .986 r
.75525 .4171 m .75806 .41632 L .75663 .41527 L F
.75663 .41527 m .75806 .41632 L .75525 .4171 L F
.75525 .4171 m .75806 .41632 L .75663 .41527 L F
.995 .858 .525 r
.61897 .4859 m .61851 .48082 L .61808 .48496 L F
.788 .555 .584 r
.43755 .58007 m .43752 .58262 L .44301 .58162 L F
.583 .355 .536 r
.43752 .58262 m .43991 .58469 L .44301 .58162 L F
0 0 .48 r
.44301 .58162 m .44358 .57997 L .44393 .57912 L F
.44301 .58162 m .44393 .58051 L .44358 .57997 L F
.559 .286 .458 r
.43991 .58469 m .44393 .58051 L .44301 .58162 L F
.725 .989 .864 r
.537 .68116 m .53517 .68181 L .53551 .67995 L F
.152 .243 .705 r
.54674 .58819 m .54571 .58954 L .54477 .58643 L F
0 0 0 r
.54674 .58819 m .54478 .5914 L .54571 .58954 L F
.58 .011 0 r
.40939 .64618 m .40803 .6466 L .40581 .64516 L F
.545 .003 0 r
.41193 .64676 m .40803 .6466 L .40939 .64618 L F
.614 .632 .845 r
.49615 .57775 m .49729 .58064 L .49982 .57944 L F
.994 .759 .466 r
.51802 .68327 m .51923 .6844 L .51933 .68154 L F
.485 .266 .506 r
.26548 .58845 m .26368 .5865 L .26594 .58601 L F
.26548 .58845 m .26334 .58912 L .26368 .5865 L F
.571 .696 .926 r
.23406 .55556 m .23573 .55772 L .23756 .55691 L F
.457 .841 .984 r
.6449 .43519 m .64344 .43469 L .64237 .43495 L F
.125 .329 .796 r
.6449 .43519 m .64684 .43525 L .64344 .43469 L F
.6449 .43519 m .6474 .43699 L .64684 .43525 L F
.93 .815 .71 r
.62795 .4653 m .628 .46075 L .62643 .46427 L F
.921 .765 .672 r
.62572 .46631 m .62795 .4653 L .62643 .46427 L F
.62572 .46631 m .62721 .46782 L .62795 .4653 L F
.669 .88 .977 r
.70914 .45376 m .71079 .45357 L .70999 .45255 L F
.622 .784 .959 r
.71079 .45357 m .71215 .45135 L .70999 .45255 L F
.71079 .45357 m .71329 .45282 L .71215 .45135 L F
.714 .426 .488 r
.5669 .52047 m .5638 .51763 L .56444 .52116 L F
.5669 .52047 m .56693 .51832 L .5638 .51763 L F
.63 .614 .816 r
.54365 .5953 m .53993 .59262 L .54205 .59191 L F
.713 .729 .864 r
.54628 .5932 m .54365 .5953 L .54205 .59191 L F
.153 0 0 r
.4946 .57879 m .49315 .57815 L .49615 .57775 L F
.47 .119 .288 r
.44772 .58325 m .44724 .58534 L .44491 .58577 L F
.363 .325 .682 r
.44957 .58133 m .44772 .58325 L .44797 .57953 L F
.68 .941 .661 r
.68939 .44281 m .68831 .44362 L .68888 .44296 L F
.25 0 0 r
.68888 .44296 m .69262 .44336 L .68939 .44281 L F
.588 .293 .435 r
.52449 .5381 m .52701 .53799 L .52464 .5361 L F
.52449 .5381 m .52701 .53799 L .52464 .5361 L F
.156 0 0 r
.67059 .40753 m .67287 .40749 L .67097 .40791 L F
.951 .901 .739 r
.63222 .4516 m .63198 .44928 L .63114 .45078 L F
.97 .909 .694 r
.62963 .45475 m .63222 .4516 L .63114 .45078 L F
.62963 .45475 m .63055 .45572 L .63222 .4516 L F
.179 0 .376 r
.21621 .58326 m .21426 .58666 L .21599 .58549 L F
0 0 .19 r
.21426 .58666 m .21507 .58765 L .21599 .58549 L F
.21426 .58666 m .21348 .58939 L .21507 .58765 L F
.998 .847 .542 r
.48933 .5886 m .48872 .58866 L .48962 .58729 L F
.509 .316 .555 r
.41551 .59707 m .41349 .59265 L .41647 .59395 L F
.909 .666 .558 r
.41349 .59265 m .4132 .59773 L .41554 .59844 L F
.509 .316 .555 r
.41551 .59707 m .4132 .59773 L .41349 .59265 L F
.387 0 0 r
.46057 .56899 m .46005 .56929 L .45723 .56839 L F
.585 .046 0 r
.46332 .56974 m .46005 .56929 L .46057 .56899 L F
.476 .249 .49 r
.58958 .52409 m .59233 .52105 L .59213 .52336 L F
.376 .196 .506 r
.59233 .52105 m .59432 .51796 L .59448 .52009 L F
.062 0 .197 r
.59213 .52336 m .59233 .52105 L .59448 .52009 L F
.382 .844 .882 r
.75371 .43637 m .75217 .4365 L .74988 .4375 L F
0 0 0 r
.75217 .4365 m .75009 .43789 L .74988 .4375 L F
.75 .576 .659 r
.5371 .58303 m .54106 .58077 L .53865 .58106 L F
.5371 .58303 m .54096 .58336 L .54106 .58077 L F
.705 .62 .759 r
.54106 .58077 m .54341 .58067 L .54289 .57634 L F
.532 .297 .503 r
.54096 .58336 m .54341 .58067 L .54106 .58077 L F
.405 .553 .889 r
.75592 .39606 m .75512 .39697 L .75232 .39334 L F
.554 .552 .807 r
.4813 .56781 m .47965 .56936 L .478 .56487 L F
.799 .793 .847 r
.48249 .57064 m .47965 .56936 L .4813 .56781 L F
.48249 .57064 m .47885 .57091 L .47965 .56936 L F
.841 .556 .505 r
.19498 .69575 m .19317 .69816 L .19316 .69602 L F
.436 .229 .498 r
.19316 .69602 m .194 .69671 L .19369 .69433 L F
.844 .944 .582 r
.19498 .69575 m .19373 .6981 L .19391 .69718 L F
.436 .229 .498 r
.194 .69671 m .1952 .69768 L .19423 .69553 L F
.194 .69671 m .19423 .69553 L .19369 .69433 L F
.844 .944 .582 r
.19391 .69718 m .19308 .69933 L .19317 .69816 L F
.19373 .6981 m .19308 .69933 L .19391 .69718 L F
0 0 0 r
.58321 .47188 m .58195 .47357 L .58403 .47046 L F
.647 .927 .651 r
.58321 .47188 m .58063 .47445 L .58195 .47357 L F
.366 .47 .834 r
.40593 .62075 m .40403 .62226 L .40291 .61892 L F
.352 .443 .815 r
.40593 .62075 m .40706 .62356 L .40403 .62226 L F
.576 .93 .945 r
.43353 .56666 m .43129 .56782 L .43215 .56821 L F
.201 .728 .755 r
.74594 .4345 m .74886 .43398 L .74711 .43568 L F
.606 .166 0 r
.55485 .58571 m .55588 .58728 L .55313 .58607 L F
.55485 .58571 m .55693 .58875 L .55588 .58728 L F
0 0 0 r
.41838 .57234 m .41902 .57285 L .42069 .57174 L F
.41838 .57234 m .41712 .57408 L .41902 .57285 L F
.167 .618 .936 r
.19327 .65977 m .19269 .65885 L .19145 .65923 L F
.225 0 .299 r
.58965 .5262 m .58958 .52409 L .59213 .52336 L F
.623 .759 .943 r
.51163 .56275 m .51521 .56348 L .51398 .56181 L F
.048 .326 .809 r
.51521 .56348 m .51545 .56207 L .51398 .56181 L F
.51521 .56348 m .51729 .56492 L .51545 .56207 L F
.532 .297 .503 r
.54096 .58336 m .54345 .58292 L .54341 .58067 L F
.629 .564 .763 r
.54289 .57634 m .54341 .58067 L .54587 .57793 L F
.27 .042 .373 r
.2592 .59535 m .2587 .59771 L .25698 .59843 L F
.447 .276 .555 r
.2587 .59771 m .25659 .60084 L .25698 .59843 L F
.421 .139 .377 r
.44431 .57776 m .44358 .57997 L .44619 .57911 L F
.905 .757 .687 r
.37684 .62449 m .37797 .62777 L .3758 .62692 L F
.37684 .62449 m .37797 .62777 L .3758 .62692 L F
.522 .337 .571 r
.74911 .43178 m .74886 .43398 L .75186 .4309 L F
.74911 .43178 m .74886 .43398 L .75186 .4309 L F
.437 .044 .195 r
.39037 .59187 m .39274 .59156 L .39403 .58944 L F
.467 .119 .292 r
.39274 .59156 m .39627 .58881 L .39403 .58944 L F
.808 .353 0 r
.4156 .59971 m .41554 .59844 L .4132 .59773 L F
.4156 .59971 m .41726 .6015 L .41554 .59844 L F
.879 .443 .114 r
.21352 .5651 m .21277 .56664 L .21208 .56376 L F
.21352 .5651 m .21449 .56764 L .21277 .56664 L F
.608 .775 .96 r
.70127 .45428 m .70445 .45514 L .70353 .454 L F
.64 .862 .983 r
.70353 .454 m .70445 .45514 L .70661 .45412 L F
.709 .814 .93 r
.70445 .45514 m .70914 .45376 L .70661 .45412 L F
.545 .783 .986 r
.21882 .59788 m .21665 .5984 L .21727 .59663 L F
0 .322 .809 r
.64887 .40229 m .64703 .40216 L .64615 .40059 L F
.64887 .40229 m .64965 .40382 L .64703 .40216 L F
0 .251 .72 r
.64703 .40216 m .64965 .40382 L .65078 .40498 L F
.102 .249 .73 r
.59766 .45145 m .59883 .4551 L .597 .453 L F
.651 .621 .806 r
.59883 .4551 m .60025 .45862 L .59771 .45889 L F
.664 .469 .611 r
.60025 .45862 m .59748 .46049 L .59771 .45889 L F
.76 .993 .797 r
.75086 .42412 m .75219 .42184 L .75307 .4228 L F
.75086 .42412 m .74944 .42446 L .75219 .42184 L F
.527 .284 .49 r
.40706 .62656 m .4046 .62448 L .4079 .62509 L F
.40706 .62656 m .40398 .62729 L .4046 .62448 L F
.841 .392 .149 r
.71573 .43338 m .71904 .43527 L .71817 .43642 L F
.688 .143 0 r
.71849 .4354 m .71904 .43527 L .71573 .43338 L F
.18 .706 .69 r
.72168 .43459 m .71904 .43527 L .71849 .4354 L F
.679 .174 .035 r
.71904 .43527 m .72109 .43682 L .71817 .43642 L F
.74 .914 .952 r
.74426 .41156 m .74193 .41345 L .7406 .41235 L F
.414 .289 .6 r
.37419 .59849 m .37646 .60031 L .37683 .59786 L F
.37419 .59849 m .37439 .60111 L .37646 .60031 L F
.407 .583 .913 r
.63772 .43951 m .63268 .43731 L .63257 .43522 L F
.676 .196 .103 r
.56927 .52017 m .56693 .51832 L .5669 .52047 L F
.348 .106 .398 r
.63228 .40456 m .63207 .40722 L .62932 .40824 L F
.364 .118 .402 r
.63444 .4057 m .63228 .40456 L .6348 .40319 L F
.63444 .4057 m .63207 .40722 L .63228 .40456 L F
.793 .662 .719 r
.45459 .57158 m .45567 .57461 L .45157 .57375 L F
.577 .353 .54 r
.45567 .57461 m .45317 .57688 L .45157 .57375 L F
.45567 .57461 m .45528 .5769 L .45317 .57688 L F
0 0 .28 r
.45696 .57054 m .45567 .57461 L .45459 .57158 L F
.45696 .57054 m .45674 .57325 L .45567 .57461 L F
.157 .106 .545 r
.45674 .57325 m .45528 .5769 L .45567 .57461 L F
.559 .786 .984 r
.69291 .40347 m .69661 .40426 L .69558 .40326 L F
.593 .868 .994 r
.69558 .40326 m .69661 .40426 L .69915 .40333 L F
.269 0 0 r
.42399 .57915 m .42894 .57807 L .42424 .57661 L F
.563 .514 .758 r
.4329 .57889 m .43143 .58253 L .42909 .5787 L F
.4311 .57854 m .42909 .5787 L .42871 .57807 L F
.4329 .57889 m .42909 .5787 L .4311 .57854 L F
.269 0 0 r
.42399 .57915 m .42552 .57914 L .4262 .57892 L F
.42436 .57907 m .4262 .57892 L .42894 .57807 L F
.42399 .57915 m .4262 .57892 L .42436 .57907 L F
.42552 .57914 m .42637 .57913 L .4267 .57899 L F
.42552 .57914 m .4267 .57899 L .42894 .57807 L F
.822 .627 .075 r
.42871 .57807 m .42919 .58058 L .42894 .57807 L F
.35 .808 .696 r
.42894 .57807 m .42637 .57913 L .42871 .57807 L F
.736 .661 .777 r
.42871 .57807 m .42774 .58319 L .42919 .58058 L F
.42858 .57876 m .43143 .58253 L .42774 .58319 L F
.42871 .57807 m .42909 .5787 L .42858 .57876 L F
.42909 .5787 m .43143 .58253 L .42858 .57876 L F
.265 .758 .909 r
.74404 .39681 m .74742 .39683 L .74754 .39607 L F
0 .498 .859 r
.74754 .39607 m .74742 .39683 L .75079 .39781 L F
.267 .594 .949 r
.74742 .39683 m .75216 .39899 L .75079 .39781 L F
.571 .475 .707 r
.2703 .57938 m .26794 .57744 L .27035 .57689 L F
.2703 .57938 m .26845 .58012 L .26794 .57744 L F
.579 .409 .615 r
.71218 .44436 m .70818 .44551 L .71009 .44278 L F
.968 .833 .656 r
.72168 .43459 m .72214 .43772 L .72109 .43682 L F
.88 .963 .847 r
.72214 .43772 m .71902 .43974 L .72109 .43682 L F
.76 .712 .807 r
.72168 .43459 m .72517 .4352 L .72214 .43772 L F
.426 .663 .96 r
.25872 .54702 m .25818 .54857 L .25716 .54703 L F
.25872 .54702 m .26155 .54935 L .25818 .54857 L F
0 .268 .758 r
.64965 .40382 m .65317 .40677 L .65078 .40498 L F
.23 .457 .872 r
.20538 .55402 m .20749 .55693 L .20805 .55526 L F
.043 .233 .733 r
.20749 .55693 m .2095 .55879 L .20805 .55526 L F
.611 .488 .687 r
.63207 .40722 m .62891 .40984 L .62932 .40824 L F
.999 .821 .485 r
.65904 .41952 m .65956 .42238 L .65952 .42192 L F
.989 .892 .588 r
.65956 .42238 m .65811 .42456 L .65952 .42192 L F
.65956 .42238 m .65859 .42605 L .65811 .42456 L F
.392 .016 .201 r
.15866 .55021 m .1608 .54992 L .16231 .54753 L F
.271 0 .007 r
.1608 .54992 m .16465 .54749 L .16231 .54753 L F
0 0 .482 r
.21398 .61641 m .21495 .61715 L .21556 .61534 L F
.21398 .61641 m .21482 .61874 L .21495 .61715 L F
.349 .256 .606 r
.40706 .62356 m .40706 .62656 L .4079 .62509 L F
.906 .964 .643 r
.62412 .44088 m .62229 .44414 L .62271 .44179 L F
.809 .985 .888 r
.6269 .43828 m .62412 .44088 L .6249 .43831 L F
.84 .972 .661 r
.62412 .44088 m .62271 .44179 L .6249 .43831 L F
.698 .974 .77 r
.55809 .49873 m .55698 .50043 L .55999 .49776 L F
.698 .976 .78 r
.55809 .49873 m .55527 .50113 L .55698 .50043 L F
.757 .296 .153 r
.43539 .59787 m .43292 .59592 L .4353 .59535 L F
.615 .927 .686 r
.75387 .41136 m .75557 .40947 L .75695 .40864 L F
.511 .457 .733 r
.75389 .41337 m .75557 .40947 L .75387 .41136 L F
.739 .436 .469 r
.64445 .40544 m .64474 .40776 L .64093 .40732 L F
.711 .667 .805 r
.69628 .44598 m .69262 .44336 L .69511 .44285 L F
.78 .791 .862 r
.6985 .44299 m .69628 .44598 L .69511 .44285 L F
.989 .825 .587 r
.19585 .68819 m .1942 .68927 L .19492 .68695 L F
0 .225 .742 r
.19585 .68819 m .19647 .68791 L .19492 .68695 L F
.612 .337 .476 r
.54737 .59838 m .54468 .60019 L .54409 .59795 L F
.54737 .59838 m .54724 .60055 L .54468 .60019 L F
.56 .282 .451 r
.55003 .59822 m .54724 .60055 L .54737 .59838 L F
.432 .218 .486 r
.50595 .59243 m .50807 .59226 L .50833 .58942 L F
.50595 .59243 m .50807 .59226 L .50833 .58942 L F
.387 .246 .564 r
.37289 .60682 m .37464 .6037 L .37249 .60423 L F
.516 .853 .996 r
.20168 .675 m .19944 .67563 L .19776 .67494 L F
.999 .811 .517 r
.50344 .58053 m .50289 .5833 L .50235 .57988 L F
.657 .617 .798 r
.50235 .57988 m .50616 .58213 L .50344 .58053 L F
.954 .678 .477 r
.21549 .56056 m .21777 .55974 L .21722 .55764 L F
.21549 .56056 m .21779 .56223 L .21777 .55974 L F
.157 0 .361 r
.57321 .46413 m .57515 .46066 L .57308 .46184 L F
0 .073 .614 r
.19926 .69805 m .19757 .69597 L .20017 .69589 L F
.336 .114 .422 r
.57861 .51508 m .58075 .51455 L .58082 .51214 L F
.311 .053 .352 r
.58045 .51651 m .57861 .51508 L .57866 .51739 L F
.58045 .51651 m .58075 .51455 L .57861 .51508 L F
.418 0 0 r
.20458 .55346 m .20191 .55374 L .20004 .55344 L F
.525 0 0 r
.20458 .55346 m .20538 .55402 L .20191 .55374 L F
.811 .935 .912 r
.71568 .45178 m .71933 .45045 L .7186 .4498 L F
.633 .925 .974 r
.7186 .4498 m .71933 .45045 L .72166 .44937 L F
.407 .583 .913 r
.63772 .43951 m .63257 .43522 L .63536 .43485 L F
.575 .435 .654 r
.63748 .43158 m .63821 .43459 L .63536 .43485 L F
.716 .79 .91 r
.64043 .43703 m .63934 .43862 L .64133 .43715 L F
.751 .616 .709 r
.63821 .43459 m .6378 .43871 L .63536 .43485 L F
.63821 .43459 m .63934 .43862 L .63772 .43951 L F
.716 .79 .91 r
.6378 .43668 m .63887 .43803 L .64043 .43703 L F
.63887 .43803 m .63934 .43862 L .64043 .43703 L F
.751 .616 .709 r
.6378 .43871 m .63772 .43951 L .63744 .43895 L F
.6378 .43871 m .63744 .43895 L .63536 .43485 L F
.745 .772 .875 r
.64329 .43086 m .63994 .43061 L .64287 .42751 L F
.719 .739 .867 r
.64561 .42886 m .64329 .43086 L .64287 .42751 L F
.328 0 0 r
.64282 .40076 m .64615 .40059 L .64293 .39974 L F
.532 .534 .803 r
.3764 .62207 m .37849 .6215 L .37742 .61822 L F
.467 .307 .58 r
.3764 .62207 m .37684 .62449 L .37849 .6215 L F
.829 .859 .868 r
.77853 .4241 m .77672 .42591 L .77515 .42522 L F
0 0 .469 r
.77672 .42591 m .77772 .42706 L .77515 .42522 L F
.77672 .42591 m .77883 .42849 L .77772 .42706 L F
.344 .55 .909 r
.39354 .63957 m .3925 .63628 L .39082 .63624 L F
.39354 .63957 m .39463 .63914 L .3925 .63628 L F
.109 .396 .85 r
.75941 .39929 m .7584 .39924 L .75592 .39606 L F
.694 .711 .861 r
.63157 .43124 m .62765 .42925 L .63017 .42852 L F
.592 .655 .881 r
.63266 .42781 m .63157 .43124 L .63017 .42852 L F
.63266 .42781 m .63387 .43069 L .63157 .43124 L F
0 .06 .615 r
.48418 .58 m .48512 .58328 L .48406 .58097 L F
.856 .792 .787 r
.54383 .52669 m .54299 .52338 L .54207 .52567 L F
.772 .541 .585 r
.54755 .52985 m .54383 .52669 L .54403 .52933 L F
.289 .12 .471 r
.26983 .58186 m .26845 .58012 L .2703 .57938 L F
.26983 .58186 m .26815 .58306 L .26845 .58012 L F
.818 .938 .907 r
.65667 .40465 m .65777 .40167 L .65897 .40409 L F
.65667 .40465 m .65531 .40393 L .65777 .40167 L F
0 0 0 r
.58674 .46755 m .58573 .46893 L .58403 .47046 L F
.58921 .46649 m .58674 .46755 L .58989 .46571 L F
.585 .272 .404 r
.58921 .46649 m .58573 .46893 L .58674 .46755 L F
.642 .142 .047 r
.40497 .64501 m .40187 .64504 L .39908 .64346 L F
.405 .841 .945 r
.40448 .6444 m .40497 .64501 L .40581 .64516 L F
.40448 .6444 m .40187 .64504 L .40497 .64501 L F
.345 .73 .985 r
.24165 .54115 m .24133 .54225 L .23977 .54087 L F
.24165 .54115 m .24345 .54214 L .24133 .54225 L F
.459 .527 .84 r
.40494 .62998 m .40286 .6311 L .40205 .6282 L F
.347 .253 .604 r
.40603 .6316 m .40286 .6311 L .40494 .62998 L F
.40603 .6316 m .40347 .63305 L .40286 .6311 L F
.631 .225 0 r
.2119 .55938 m .21141 .55864 L .2095 .55879 L F
.2119 .55938 m .21332 .56187 L .21141 .55864 L F
.448 .198 .441 r
.26088 .59715 m .2592 .59535 L .26113 .59466 L F
.26088 .59715 m .2587 .59771 L .2592 .59535 L F
.559 .503 .749 r
.54815 .54736 m .54913 .5442 L .54841 .54493 L F
.44 .512 .837 r
.55793 .58241 m .55648 .58477 L .55562 .58285 L F
.55793 .58241 m .55961 .58613 L .55648 .58477 L F
.498 .761 .989 r
.44393 .61467 m .44584 .61605 L .44287 .61631 L F
.44287 .61631 m .44584 .61605 L .44393 .61467 L F
.604 .621 .841 r
.48451 .56977 m .48249 .57064 L .4813 .56781 L F
0 0 0 r
.65832 .44096 m .65593 .44398 L .65773 .4421 L F
.483 .499 .798 r
.65593 .44398 m .65891 .44575 L .65773 .4421 L F
.639 .079 0 r
.65593 .44398 m .6599 .44673 L .65891 .44575 L F
.516 .875 .984 r
.6999 .39449 m .69782 .39519 L .6967 .39453 L F
.855 .606 .563 r
.40605 .6166 m .40492 .61563 L .40873 .61577 L F
.40605 .6166 m .4055 .61884 L .40492 .61563 L F
.149 0 .381 r
.40605 .6166 m .40593 .62075 L .4055 .61884 L F
.40605 .6166 m .4077 .61996 L .40593 .62075 L F
.437 .034 .175 r
.41127 .61559 m .40605 .6166 L .40873 .61577 L F
.41127 .61559 m .41052 .61758 L .40605 .6166 L F
.546 .139 .221 r
.4097 .61967 m .40605 .6166 L .41052 .61758 L F
.4097 .61967 m .4077 .61996 L .40605 .6166 L F
.595 .842 .991 r
.70539 .39277 m .70393 .39464 L .70292 .39366 L F
.70539 .39277 m .70644 .39385 L .70393 .39464 L F
.546 .687 .932 r
.75167 .39143 m .75001 .39364 L .74916 .39185 L F
.524 .655 .918 r
.75232 .39334 m .75001 .39364 L .75167 .39143 L F
.245 .101 .479 r
.21292 .62506 m .21479 .62411 L .21489 .6216 L F
.138 0 .241 r
.21292 .62506 m .21389 .62655 L .21479 .62411 L F
.21292 .62506 m .21247 .62728 L .21389 .62655 L F
.901 .887 .809 r
.51903 .53723 m .51675 .53889 L .51891 .53848 L F
.45 .299 .584 r
.52095 .53563 m .52144 .5386 L .51891 .53848 L F
.772 .3 .122 r
.51985 .54042 m .51891 .53848 L .52144 .5386 L F
.014 0 .473 r
.51891 .53848 m .51937 .54174 L .51985 .54042 L F
.772 .3 .122 r
.51985 .54042 m .51748 .53982 L .51891 .53848 L F
.014 0 .473 r
.51891 .53848 m .51985 .54042 L .52144 .5386 L F
.162 0 .354 r
.50807 .59226 m .50897 .59009 L .50833 .58942 L F
.95 .775 .631 r
.54351 .53177 m .54535 .5331 L .54403 .52933 L F
.72 .447 .512 r
.5423 .53505 m .54535 .5331 L .54351 .53177 L F
.5423 .53505 m .5453 .53536 L .54535 .5331 L F
.799 .722 .779 r
.54535 .5331 m .54755 .52985 L .54403 .52933 L F
.695 .572 .713 r
.54535 .5331 m .5487 .53252 L .54755 .52985 L F
.189 0 .045 r
.5453 .53536 m .5487 .53252 L .54535 .5331 L F
.717 .625 .754 r
.21501 .57781 m .21634 .58088 L .2188 .58051 L F
.581 .371 .561 r
.21621 .58326 m .2188 .58051 L .21634 .58088 L F
.21621 .58326 m .21808 .58303 L .2188 .58051 L F
.545 .5 .756 r
.24184 .57488 m .24512 .57416 L .24316 .57112 L F
.488 .242 .467 r
.24156 .57713 m .24512 .57416 L .24184 .57488 L F
.807 .9 .907 r
.72693 .44387 m .72969 .44348 L .72857 .44257 L F
.724 .809 .918 r
.72969 .44348 m .73174 .44013 L .72857 .44257 L F
.72969 .44348 m .73301 .44173 L .73174 .44013 L F
.543 .059 0 r
.75307 .4228 m .74965 .41896 L .75398 .42235 L F
.777 .674 .75 r
.60973 .46139 m .60829 .45743 L .60997 .45899 L F
.60973 .46139 m .60608 .46089 L .60829 .45743 L F
.779 .667 .74 r
.60973 .46139 m .60732 .46438 L .60608 .46089 L F
.591 .266 .387 r
.57684 .53802 m .57707 .53622 L .57944 .53801 L F
.526 .295 .507 r
.57707 .53622 m .57945 .53561 L .57944 .53801 L F
.637 .479 .652 r
.55732 .52977 m .55989 .52988 L .55966 .52714 L F
.608 .296 .416 r
.55969 .53181 m .55732 .52977 L .5564 .53192 L F
.55969 .53181 m .55989 .52988 L .55732 .52977 L F
.549 .575 .833 r
.18857 .68284 m .18713 .68073 L .1869 .68106 L F
.18857 .68284 m .18932 .68066 L .18713 .68073 L F
.18857 .68284 m .19077 .68296 L .18932 .68066 L F
.353 0 0 r
.20562 .53997 m .20778 .54016 L .20968 .53917 L F
.054 0 0 r
.20778 .54016 m .21169 .53949 L .20968 .53917 L F
.25 0 0 r
.17097 .56269 m .17493 .56311 L .17261 .56309 L F
.688 .954 .952 r
.17261 .56309 m .17493 .56311 L .17689 .56186 L F
.697 .418 .498 r
.42638 .64197 m .42991 .63958 L .42843 .63906 L F
.42638 .64197 m .43082 .64167 L .42991 .63958 L F
.693 .417 .5 r
.43082 .64167 m .43228 .6422 L .42991 .63958 L F
.699 .416 .492 r
.42991 .63958 m .43228 .6422 L .43238 .63996 L F
0 .032 .541 r
.6051 .44495 m .60345 .44423 L .60554 .44335 L F
.6051 .44495 m .60386 .4468 L .60345 .44423 L F
.675 .705 .87 r
.26208 .82366 m .26055 .82476 L .25898 .82437 L F
.712 .296 .257 r
.20168 .675 m .20354 .67715 L .20569 .67547 L F
.247 .348 .771 r
.20742 .6774 m .20562 .6782 L .20569 .67547 L F
.276 .394 .803 r
.20786 .67622 m .20724 .67733 L .20742 .6774 L F
.247 .348 .771 r
.20742 .6774 m .20691 .67791 L .20562 .6782 L F
.276 .394 .803 r
.20724 .67733 m .20691 .67791 L .20742 .6774 L F
.247 .348 .771 r
.20742 .6774 m .20569 .67547 L .20471 .67623 L F
.2074 .6774 m .20471 .67623 L .20354 .67715 L F
.20742 .6774 m .20724 .67733 L .2074 .6774 L F
.20724 .67733 m .20471 .67623 L .2074 .6774 L F
.591 .681 .904 r
.20369 .67411 m .2074 .67739 L .20354 .67715 L F
.2074 .67739 m .20742 .6774 L .2074 .6774 L F
.2074 .67739 m .2074 .6774 L .20354 .67715 L F
.978 .744 .515 r
.20724 .67733 m .20739 .67752 L .20691 .67791 L F
.20739 .67752 m .20906 .6797 L .20731 .67825 L F
.20739 .67752 m .20731 .67825 L .20691 .67791 L F
.20786 .67622 m .20845 .67791 L .20724 .67733 L F
.20845 .67791 m .20906 .6797 L .20724 .67733 L F
.329 .561 .921 r
.54364 .58471 m .54477 .58643 L .54752 .58648 L F
0 .142 .679 r
.54674 .58819 m .54477 .58643 L .54364 .58471 L F
.883 .684 .629 r
.60881 .45593 m .60997 .45899 L .60829 .45743 L F
.935 .726 .597 r
.21449 .56764 m .216 .57111 L .21657 .56873 L F
.21449 .56764 m .216 .57111 L .21657 .56873 L F
.369 .838 .834 r
.1983 .63812 m .19739 .63876 L .19619 .63959 L F
.1983 .63812 m .20039 .63787 L .19739 .63876 L F
.525 .609 .879 r
.72367 .40256 m .72478 .40527 L .72711 .40479 L F
.575 .541 .78 r
.72478 .40527 m .72874 .40851 L .72711 .40479 L F
.444 .303 .595 r
.24991 .615 m .2478 .61801 L .24758 .61621 L F
.722 .449 .512 r
.45528 .5769 m .45203 .57926 L .45317 .57688 L F
.392 .196 .491 r
.25274 .60975 m .2524 .61222 L .25003 .61237 L F
.449 .243 .507 r
.2524 .61222 m .24991 .615 L .25003 .61237 L F
.285 .31 .712 r
.19504 .71273 m .19589 .7134 L .19536 .71402 L F
.344 .311 .678 r
.1967 .71249 m .19617 .71361 L .19504 .71273 L F
.745 .972 .709 r
.19636 .71285 m .19322 .71573 L .19489 .71439 L F
.1967 .71249 m .19653 .71265 L .19636 .71285 L F
.19653 .71265 m .19322 .71573 L .19636 .71285 L F
.285 .31 .712 r
.19536 .71402 m .19617 .71361 L .19537 .71407 L F
.19589 .7134 m .19617 .71361 L .19536 .71402 L F
0 0 0 r
.19537 .71407 m .19617 .71361 L .19489 .71439 L F
.572 .813 .99 r
.18011 .63831 m .17916 .63986 L .17827 .63908 L F
.658 .884 .981 r
.17783 .63929 m .17827 .63908 L .17916 .63986 L F
0 0 0 r
.59721 .51449 m .59943 .51209 L .5984 .51356 L F
.126 0 .322 r
.59943 .51209 m .60108 .50902 L .60156 .50865 L F
.59943 .51209 m .60156 .50865 L .60048 .51031 L F
.627 .825 .416 r
.5984 .51356 m .59943 .51209 L .60048 .51031 L F
.186 .432 .863 r
.39908 .64346 m .39997 .64217 L .39853 .64191 L F
.39908 .64346 m .40187 .64504 L .39997 .64217 L F
.197 .727 .783 r
.17291 .54551 m .1747 .54512 L .17698 .54495 L F
.261 .77 .807 r
.1747 .54512 m .17912 .5444 L .17698 .54495 L F
.37 .782 .981 r
.37513 .63095 m .37388 .63027 L .37135 .63053 L F
.37513 .63095 m .37388 .63027 L .37135 .63053 L F
.457 .828 .992 r
.37513 .63095 m .37388 .63027 L .37752 .6305 L F
.848 .923 .88 r
.72954 .42719 m .73027 .42854 L .72784 .43055 L F
.856 .491 0 r
.72977 .42857 m .73027 .42854 L .72954 .42719 L F
.72977 .42857 m .73093 .43053 L .73027 .42854 L F
.446 .477 .798 r
.53877 .58892 m .53993 .59262 L .54205 .59191 L F
.457 .816 .996 r
.53864 .5918 m .53993 .59262 L .54205 .59191 L F
.061 .542 .893 r
.23406 .55556 m .22974 .55387 L .23203 .55602 L F
.548 .424 .663 r
.42818 .56556 m .43095 .56752 L .43046 .5619 L F
.572 0 0 r
.42834 .56625 m .43095 .56752 L .42818 .56556 L F
.995 .797 .428 r
.65082 .42733 m .65161 .42858 L .65181 .4261 L F
.862 .734 .216 r
.65181 .4261 m .65189 .42248 L .6519 .42543 L F
.781 .895 .486 r
.65082 .42733 m .65181 .4261 L .6519 .42543 L F
.792 .323 .12 r
.54674 .56875 m .54519 .56864 L .5426 .5662 L F
.923 .861 .762 r
.54443 .56703 m .54519 .56864 L .54674 .56875 L F
.028 .313 .801 r
.5426 .5662 m .54519 .56864 L .54472 .56721 L F
.54263 .56621 m .54472 .56721 L .54447 .56645 L F
.5426 .5662 m .54472 .56721 L .54263 .56621 L F
0 .329 .726 r
.54674 .56875 m .54784 .56902 L .54477 .56723 L F
.346 .571 .923 r
.54447 .56645 m .54472 .56721 L .54443 .56703 L F
0 .329 .726 r
.54456 .56713 m .54472 .56721 L .54443 .56703 L F
.346 .571 .923 r
.54472 .56721 m .54519 .56864 L .54443 .56703 L F
0 .329 .726 r
.54472 .56721 m .54477 .56723 L .54443 .56703 L F
.54674 .56875 m .54477 .56723 L .54456 .56713 L F
.54674 .56875 m .54929 .56993 L .54784 .56902 L F
.393 .376 .722 r
.54674 .56875 m .54765 .57198 L .54929 .56993 L F
.476 .141 .318 r
.59216 .46445 m .58921 .46649 L .58989 .46571 L F
.351 0 .181 r
.45157 .57375 m .45459 .57158 L .45203 .57137 L F
.717 .245 .127 r
.40715 .63575 m .40941 .63774 L .41047 .63663 L F
.534 0 0 r
.40941 .63774 m .41283 .6385 L .41047 .63663 L F
0 0 0 r
.65832 .44096 m .65773 .4421 L .65725 .43947 L F
.591 .687 .908 r
.46447 .57402 m .46813 .57524 L .46693 .57374 L F
.604 .695 .907 r
.46693 .57374 m .46813 .57524 L .47051 .57441 L F
.586 .793 .978 r
.71148 .39229 m .70998 .39438 L .70894 .39309 L F
.71148 .39229 m .71254 .39368 L .70998 .39438 L F
.611 .479 .676 r
.55989 .52988 m .56215 .52656 L .55966 .52714 L F
.563 .418 .642 r
.62398 .41381 m .62178 .41727 L .62153 .41433 L F
.964 .634 .285 r
.53922 .55275 m .5407 .5538 L .53921 .55049 L F
.716 .623 .752 r
.53921 .55049 m .5407 .5538 L .54307 .55033 L F
.14 .304 .769 r
.54175 .55226 m .5407 .5538 L .53922 .55275 L F
.589 .452 .662 r
.5407 .5538 m .54347 .5535 L .54307 .55033 L F
.535 .253 .434 r
.5407 .5538 m .5431 .55551 L .54347 .5535 L F
.14 .304 .769 r
.54175 .55226 m .5431 .55551 L .5407 .5538 L F
.539 .345 .566 r
.56843 .53891 m .57088 .54088 L .56843 .54136 L F
.638 .308 .396 r
.56843 .53891 m .57082 .53911 L .57088 .54088 L F
.447 .223 .48 r
.25489 .60428 m .25455 .60661 L .25244 .60696 L F
.35 .234 .578 r
.25419 .60904 m .25244 .60696 L .25455 .60661 L F
.25419 .60904 m .25274 .60975 L .25244 .60696 L F
.344 .311 .678 r
.1967 .71249 m .19504 .71273 L .19336 .7112 L F
0 0 0 r
.59728 .49281 m .5982 .49141 L .5953 .49368 L F
.905 .907 .502 r
.59929 .48794 m .5982 .49141 L .59823 .48941 L F
.891 .873 .435 r
.59823 .48941 m .5982 .49141 L .59728 .49281 L F
0 0 0 r
.20039 .63843 m .20266 .63718 L .20039 .63787 L F
.58573 .46893 m .58321 .47188 L .58403 .47046 L F
.379 .148 .433 r
.58075 .51455 m .58339 .51142 L .58082 .51214 L F
.122 0 .248 r
.58797 .50293 m .58572 .50609 L .58798 .50508 L F
.231 .038 .4 r
.58766 .50737 m .58572 .50609 L .58577 .50828 L F
.58766 .50737 m .58798 .50508 L .58572 .50609 L F
.783 .961 .924 r
.67669 .40904 m .67841 .40815 L .67753 .40695 L F
.776 .959 .928 r
.67753 .40695 m .67841 .40815 L .68009 .40621 L F
.658 .843 .971 r
.69915 .40333 m .70272 .40335 L .70174 .40214 L F
.613 .771 .956 r
.70272 .40335 m .70422 .40115 L .70174 .40214 L F
.70272 .40335 m .70526 .40266 L .70422 .40115 L F
.637 .429 .585 r
.54307 .55033 m .54581 .55046 L .54555 .54788 L F
.11 0 .199 r
.54581 .55046 m .54815 .54736 L .54555 .54788 L F
.38 .198 .506 r
.58247 .5354 m .58218 .53284 L .58472 .53185 L F
0 0 0 r
.19566 .70476 m .1937 .70729 L .19336 .70513 L F
0 0 .299 r
.54825 .57447 m .54929 .56993 L .54765 .57198 L F
.092 .56 .907 r
.44337 .56747 m .43997 .56601 L .44116 .56572 L F
.669 .88 .977 r
.70914 .45376 m .70999 .45255 L .70661 .45412 L F
.343 .618 .953 r
.18759 .6415 m .18598 .64151 L .18369 .63937 L F
.426 .107 .32 r
.62256 .40516 m .62503 .40457 L .62514 .40334 L F
.764 .416 .396 r
.74232 .4337 m .74594 .4345 L .74598 .43272 L F
.114 .255 .732 r
.74459 .42808 m .74598 .43272 L .74669 .43009 L F
.458 .209 .447 r
.23772 .62993 m .23794 .63313 L .23483 .63252 L F
.409 .165 .43 r
.23714 .6354 m .23483 .63252 L .23794 .63313 L F
.23714 .6354 m .23504 .63602 L .23483 .63252 L F
.527 .379 .623 r
.26815 .58542 m .26589 .58362 L .26815 .58306 L F
.26815 .58542 m .26594 .58601 L .26589 .58362 L F
.96 .911 .723 r
.53771 .57873 m .5371 .58303 L .53865 .58106 L F
.713 .762 .89 r
.72371 .4337 m .72517 .4352 L .72168 .43459 L F
.905 .872 .794 r
.72636 .43035 m .72517 .4352 L .72371 .4337 L F
.695 .426 .512 r
.20272 .66812 m .20607 .66952 L .20656 .66653 L F
.624 .36 .498 r
.20895 .6688 m .20607 .66952 L .20656 .66653 L F
.034 0 .258 r
.60108 .50902 m .60381 .50555 L .60156 .50865 L F
.189 0 .045 r
.5453 .53536 m .5479 .53425 L .5487 .53252 L F
.793 .532 .543 r
.5479 .53425 m .55128 .53268 L .5487 .53252 L F
.668 .628 .801 r
.70568 .44615 m .70221 .44386 L .70465 .4431 L F
.658 .611 .791 r
.70818 .44551 m .70568 .44615 L .70465 .4431 L F
.699 .563 .697 r
.54468 .60019 m .54138 .5985 L .54409 .59795 L F
.692 .252 .201 r
.52846 .5322 m .52686 .53365 L .526 .53227 L F
.856 .499 .374 r
.65918 .43922 m .66151 .44025 L .66071 .43794 L F
.48 .897 .896 r
.20117 .65749 m .20015 .65743 L .19793 .65835 L F
.497 .837 .998 r
.20591 .65711 m .202 .65628 L .20117 .65749 L F
.612 .954 .903 r
.202 .65628 m .20015 .65743 L .20117 .65749 L F
.226 .002 .35 r
.59432 .51796 m .59721 .51449 L .59644 .51692 L F
.107 0 .273 r
.59448 .52009 m .59432 .51796 L .59644 .51692 L F
.791 .998 .854 r
.47527 .59054 m .47407 .59114 L .47664 .589 L F
.732 .86 .941 r
.73503 .44029 m .73851 .43998 L .73745 .43896 L F
.696 .87 .964 r
.74041 .43725 m .73851 .43998 L .74099 .43914 L F
.74041 .43725 m .73745 .43896 L .73851 .43998 L F
.775 .661 .737 r
.45696 .64015 m .45808 .64202 L .46056 .64007 L F
.503 .241 .45 r
.46293 .63961 m .46263 .64174 L .46056 .64007 L F
.46056 .64007 m .46263 .64174 L .46293 .63961 L F
.591 .86 .994 r
.53232 .68453 m .53515 .68433 L .53385 .68348 L F
.991 .794 .542 r
.51075 .53759 m .51019 .53408 L .50932 .5357 L F
.174 .12 .552 r
.50932 .5357 m .50934 .53912 L .51075 .53759 L F
.414 .414 .75 r
.77017 .42786 m .7672 .43137 L .76735 .42869 L F
.77025 .42798 m .7672 .43137 L .77017 .42786 L F
.573 .866 .554 r
.77043 .42778 m .76621 .43221 L .7672 .43137 L F
.845 .929 .885 r
.76538 .43159 m .76621 .43221 L .77043 .42778 L F
.414 .414 .75 r
.77043 .42778 m .77025 .42798 L .77017 .42786 L F
.845 .929 .885 r
.76538 .43159 m .76951 .42848 L .76944 .42833 L F
.76951 .42848 m .77043 .42778 L .76944 .42833 L F
.944 .774 .311 r
.76682 .42749 m .76735 .42869 L .76736 .42862 L F
.76682 .42749 m .76736 .42862 L .76753 .42619 L F
.98 .775 .557 r
.76535 .42603 m .76682 .42749 L .76743 .42499 L F
.771 .552 .602 r
.76535 .42603 m .7664 .42662 L .76682 .42749 L F
.944 .774 .311 r
.76682 .42749 m .76753 .42619 L .76743 .42499 L F
.441 .765 .996 r
.77043 .42778 m .76735 .42869 L .76682 .42749 L F
.77043 .42778 m .76682 .42749 L .76944 .42833 L F
.519 .313 .541 r
.76682 .42749 m .76944 .42833 L .77009 .42552 L F
.771 .552 .602 r
.7664 .42662 m .76944 .42833 L .76682 .42749 L F
.77 .788 .868 r
.76503 .42872 m .76538 .43159 L .76944 .42833 L F
.721 .239 0 r
.76944 .42833 m .76922 .4288 L .76927 .42796 L F
.76944 .42833 m .76927 .42796 L .76933 .4271 L F
.929 .58 .346 r
.77129 .42961 m .77045 .42956 L .76944 .42833 L F
.7717 .42989 m .77143 .42982 L .77129 .42961 L F
.77143 .42982 m .77045 .42956 L .77129 .42961 L F
.657 .565 .74 r
.47841 .5814 m .47931 .58399 L .48148 .58252 L F
.655 .717 .894 r
.71546 .43928 m .71404 .44176 L .71323 .43988 L F
.71546 .43928 m .71687 .44098 L .71404 .44176 L F
.235 0 0 r
.53982 .58529 m .54345 .58292 L .54096 .58336 L F
0 0 0 r
.46018 .59735 m .45966 .59754 L .46212 .59677 L F
.287 .422 .824 r
.7535 .3996 m .75474 .40244 L .75618 .40079 L F
0 .152 .684 r
.75474 .40244 m .7565 .40295 L .75618 .40079 L F
.833 .92 .893 r
.61973 .44716 m .61584 .44878 L .6186 .44622 L F
.875 .922 .853 r
.62229 .44414 m .61973 .44716 L .6186 .44622 L F
.848 .923 .88 r
.72954 .42719 m .72784 .43055 L .72715 .42922 L F
.909 .871 .788 r
.72784 .43055 m .72636 .43035 L .72715 .42922 L F
.042 0 0 r
.16708 .54727 m .16929 .54679 L .17089 .54596 L F
.002 0 0 r
.16929 .54679 m .17291 .54551 L .17089 .54596 L F
.745 .743 .85 r
.43869 .5728 m .44001 .57448 L .4365 .57374 L F
.662 .15 .014 r
.44001 .57448 m .43751 .5755 L .4365 .57374 L F
.574 .576 .817 r
.44097 .57047 m .44001 .57448 L .43869 .5728 L F
.44097 .57047 m .44233 .57394 L .44001 .57448 L F
.321 0 0 r
.44085 .57543 m .44001 .57448 L .44233 .57394 L F
.44085 .57543 m .43751 .5755 L .44001 .57448 L F
.022 .539 .864 r
.44688 .55889 m .4462 .55923 L .44449 .55918 L F
.44688 .55889 m .44804 .55952 L .4462 .55923 L F
.898 .875 .805 r
.60462 .4787 m .60453 .48163 L .60422 .48129 L F
.331 .636 .963 r
.39648 .64172 m .39774 .64061 L .39463 .63914 L F
.39648 .64172 m .39853 .64191 L .39774 .64061 L F
.893 .858 .799 r
.62373 .4697 m .62537 .47092 L .62721 .46782 L F
.943 .824 .697 r
.62448 .47289 m .62537 .47092 L .62373 .4697 L F
0 0 .299 r
.54825 .57447 m .54925 .57269 L .54929 .56993 L F
.618 .614 .825 r
.54829 .57693 m .54925 .57269 L .54825 .57447 L F
.398 .855 .85 r
.6917 .39594 m .68857 .39675 L .69081 .39584 L F
.392 .85 .881 r
.6942 .39515 m .6917 .39594 L .69081 .39584 L F
.104 .473 .894 r
.52079 .57821 m .52222 .57986 L .52303 .5799 L F
0 0 0 r
.40988 .57832 m .40725 .58039 L .40909 .57917 L F
.081 0 0 r
.40909 .57917 m .41235 .5775 L .40988 .57832 L F
.511 .301 .531 r
.56444 .52116 m .56689 .52284 L .5669 .52047 L F
.367 .336 .692 r
.56444 .52116 m .56515 .52354 L .56689 .52284 L F
.829 .859 .868 r
.77853 .4241 m .77515 .42522 L .77743 .4222 L F
.612 .661 .874 r
.77743 .4222 m .77968 .42352 L .77853 .4241 L F
0 0 0 r
.2242 .55304 m .21912 .55401 L .22236 .55279 L F
.942 .835 .709 r
.6277 .45792 m .63055 .45572 L .62963 .45475 L F
.6277 .45792 m .62919 .45914 L .63055 .45572 L F
.69 .587 .735 r
.44526 .64548 m .44959 .64608 L .44923 .64527 L F
.424 .856 .937 r
.45043 .64442 m .44792 .64497 L .44923 .64527 L F
0 0 .32 r
.45043 .64442 m .44959 .64608 L .44923 .64527 L F
.404 .257 .566 r
.26334 .58912 m .26321 .59172 L .26138 .59227 L F
.558 .4 .624 r
.26321 .59172 m .26113 .59466 L .26138 .59227 L F
.563 .287 .455 r
.42817 .59269 m .4287 .59393 L .42586 .59387 L F
0 .112 .635 r
.1937 .70729 m .19407 .70784 L .19392 .70806 L F
.596 .844 .479 r
.19392 .70806 m .19407 .70784 L .1936 .70844 L F
.372 .159 .456 r
.25646 .60587 m .25489 .60428 L .25693 .60364 L F
.25646 .60587 m .25455 .60661 L .25489 .60428 L F
.563 .376 .586 r
.50616 .58213 m .50563 .58508 L .50647 .58315 L F
.346 .106 .4 r
.24038 .62688 m .24011 .62995 L .23772 .62993 L F
.353 .134 .436 r
.23974 .63242 m .23772 .62993 L .24011 .62995 L F
.23974 .63242 m .23794 .63313 L .23772 .62993 L F
.751 .72 .823 r
.20891 .66344 m .20685 .66354 L .20904 .66195 L F
.596 .15 .161 r
.20891 .66344 m .20699 .66518 L .20685 .66354 L F
.625 .608 .813 r
.21057 .66174 m .20891 .66344 L .20904 .66195 L F
.746 .949 .634 r
.20897 .66253 m .20891 .66344 L .21057 .66174 L F
.20897 .66253 m .20699 .66518 L .20891 .66344 L F
.859 .703 .688 r
.60732 .46438 m .60449 .46404 L .60608 .46089 L F
.827 .656 .67 r
.60732 .46438 m .60357 .4666 L .60449 .46404 L F
.60732 .46438 m .60563 .467 L .60357 .4666 L F
.778 .585 .639 r
.60732 .46438 m .60753 .4673 L .60563 .467 L F
.254 0 0 r
.47673 .57503 m .47875 .57571 L .48072 .57555 L F
.218 0 .257 r
.48072 .57555 m .48215 .57549 L .48275 .57381 L F
.09 0 0 r
.48072 .57555 m .4809 .57574 L .48088 .57554 L F
.802 .412 .315 r
.48275 .57381 m .4809 .57574 L .47962 .57378 L F
.839 .503 .418 r
.48275 .57381 m .47962 .57378 L .47885 .57091 L F
.776 .938 .587 r
.48346 .57189 m .4809 .57574 L .48275 .57381 L F
0 0 0 r
.48228 .57388 m .48091 .57589 L .4809 .57574 L F
.599 .084 0 r
.48023 .5769 m .48344 .57732 L .4809 .57574 L F
0 0 0 r
.48091 .57589 m .48023 .5769 L .4809 .57574 L F
.09 0 0 r
.48088 .57554 m .4809 .57574 L .48215 .57549 L F
.48072 .57555 m .47875 .57571 L .4809 .57574 L F
.56 .304 .484 r
.56587 .54162 m .56831 .54365 L .56551 .54425 L F
.56587 .54162 m .56843 .54136 L .56831 .54365 L F
0 0 0 r
.6657 .42438 m .66475 .42642 L .6663 .42286 L F
.693 .962 .72 r
.66748 .42102 m .6663 .42286 L .66919 .42003 L F
0 0 0 r
.6657 .42438 m .6663 .42286 L .66748 .42102 L F
.577 .746 .957 r
.48907 .707 m .48806 .70895 L .49058 .70813 L F
.48907 .707 m .48671 .70754 L .48806 .70895 L F
.48907 .707 m .48806 .70895 L .49058 .70813 L F
.48907 .707 m .48671 .70754 L .48806 .70895 L F
.633 .4 .547 r
.21599 .58549 m .21808 .58303 L .21621 .58326 L F
.343 0 .005 r
.4034 .58242 m .40574 .58209 L .40725 .58039 L F
.464 .126 .307 r
.40574 .58209 m .40909 .57917 L .40725 .58039 L F
.875 .954 .855 r
.55997 .4953 m .55999 .49776 L .56122 .49646 L F
.856 .955 .875 r
.56284 .49265 m .56122 .49646 L .56405 .49364 L F
.56284 .49265 m .55997 .4953 L .56122 .49646 L F
.724 .879 .953 r
.51964 .51986 m .51865 .52229 L .51686 .52257 L F
.51964 .51986 m .52094 .52099 L .51865 .52229 L F
.612 .809 .976 r
.3834 .63026 m .38744 .63075 L .38632 .6293 L F
.369 .633 .956 r
.38744 .63075 m .38852 .62938 L .38632 .6293 L F
.148 .308 .771 r
.38744 .63075 m .38995 .63295 L .38852 .62938 L F
.545 .884 .987 r
.46758 .56284 m .46546 .56367 L .46383 .56288 L F
.185 .168 .605 r
.27099 .57015 m .27004 .57412 L .26872 .57088 L F
.27099 .57015 m .27131 .5737 L .27004 .57412 L F
.178 .146 .582 r
.27131 .5737 m .27159 .57629 L .27004 .57412 L F
.202 .153 .576 r
.27004 .57412 m .27159 .57629 L .27035 .57689 L F
.749 .542 .615 r
.43889 .59744 m .4353 .59535 L .43773 .59489 L F
.43889 .59744 m .43539 .59787 L .4353 .59535 L F
.645 .147 .052 r
.42586 .59387 m .4241 .59449 L .42152 .59278 L F
.284 0 0 r
.4287 .59393 m .4241 .59449 L .42586 .59387 L F
0 .054 .601 r
.26877 .55155 m .26997 .55359 L .26631 .55048 L F
.26877 .55155 m .26996 .55333 L .26997 .55359 L F
.657 .927 .973 r
.71071 .44006 m .70746 .44047 L .70964 .43723 L F
.587 .543 .773 r
.71253 .43781 m .71071 .44006 L .70964 .43723 L F
.71253 .43781 m .71323 .43988 L .71071 .44006 L F
.62 .916 .979 r
.19207 .63978 m .19131 .64152 L .18972 .64083 L F
.19207 .63978 m .19401 .64035 L .19131 .64152 L F
.931 .969 .748 r
.55997 .4953 m .55809 .49873 L .55999 .49776 L F
.237 0 .291 r
.58797 .50293 m .59034 .50225 L .59037 .50021 L F
.019 0 .266 r
.58797 .50293 m .58933 .50385 L .59034 .50225 L F
.58797 .50293 m .58798 .50508 L .58933 .50385 L F
.523 .168 .306 r
.43889 .59744 m .43528 .60018 L .43539 .59787 L F
.43889 .59744 m .43781 .60003 L .43528 .60018 L F
0 0 0 r
.44122 .59322 m .44109 .59336 L .43954 .59433 L F
.555 .641 .891 r
.43954 .59433 m .43889 .59744 L .43793 .59534 L F
.43954 .59433 m .44116 .59737 L .43889 .59744 L F
.212 .433 .858 r
.43954 .59433 m .44236 .5963 L .44116 .59737 L F
.724 .337 .317 r
.43859 .59584 m .44236 .5963 L .43954 .59433 L F
0 0 0 r
.44109 .59336 m .43859 .59584 L .43954 .59433 L F
.555 .641 .891 r
.43954 .59433 m .43793 .59534 L .43773 .59489 L F
.365 .017 .234 r
.44012 .59942 m .43889 .59744 L .44116 .59737 L F
.44012 .59942 m .43781 .60003 L .43889 .59744 L F
.403 .686 .976 r
.25149 .54366 m .251 .54526 L .24957 .54357 L F
.25149 .54366 m .25315 .5452 L .251 .54526 L F
.65 .343 .438 r
.42683 .5882 m .42924 .58889 L .4305 .58596 L F
.446 .133 .34 r
.4305 .58596 m .43175 .58828 L .4327 .58656 L F
.4305 .58596 m .42924 .58889 L .43175 .58828 L F
.59 .463 .676 r
.46447 .57402 m .46693 .57374 L .46672 .57108 L F
.485 .864 .98 r
.73554 .43094 m .73364 .43223 L .73259 .43169 L F
.73554 .43094 m .73621 .43153 L .73364 .43223 L F
.362 .428 .795 r
.55644 .57455 m .5577 .57727 L .55445 .5744 L F
.5 .449 .732 r
.55445 .5744 m .55623 .57939 L .5547 .57804 L F
.55445 .5744 m .5577 .57727 L .55623 .57939 L F
.893 .858 .799 r
.62373 .4697 m .62721 .46782 L .62572 .46631 L F
.659 .747 .915 r
.72003 .40161 m .72123 .40403 L .72367 .40256 L F
.79 .6 .643 r
.49209 .57245 m .48856 .5738 L .49095 .57078 L F
.49209 .57245 m .49193 .57658 L .48856 .5738 L F
.658 .737 .908 r
.4945 .57157 m .49209 .57245 L .49095 .57078 L F
0 0 0 r
.19566 .70476 m .19407 .70784 L .1937 .70729 L F
.097 0 .266 r
.54213 .54529 m .54416 .54177 L .54377 .54366 L F
.491 .687 .954 r
.54416 .54177 m .54865 .54144 L .54559 .54022 L F
.067 .031 .503 r
.54416 .54177 m .54566 .54291 L .54377 .54366 L F
.54416 .54177 m .54559 .54022 L .54566 .54291 L F
.995 .76 .46 r
.50867 .54087 m .50986 .542 L .50934 .53912 L F
.535 0 0 r
.50867 .54087 m .51245 .54364 L .50986 .542 L F
.455 .322 .61 r
.55701 .55894 m .55766 .56177 L .55482 .56259 L F
.386 .191 .49 r
.55766 .56177 m .5546 .56536 L .55482 .56259 L F
.972 .707 .47 r
.46461 .60897 m .46207 .609 L .46219 .60839 L F
.46207 .609 m .46101 .60902 L .46219 .60839 L F
.009 0 .042 r
.46219 .60839 m .45993 .60994 L .46247 .60706 L F
.46219 .60839 m .46247 .60706 L .46272 .60678 L F
.73 .325 .282 r
.46341 .60541 m .46699 .6059 L .46497 .60851 L F
.46364 .60608 m .46497 .60851 L .46461 .60897 L F
.46341 .60541 m .46497 .60851 L .46364 .60608 L F
0 .256 .762 r
.46364 .60608 m .46272 .60678 L .46199 .60541 L F
.46378 .60614 m .4637 .60619 L .46364 .60608 L F
.4637 .60619 m .46272 .60678 L .46364 .60608 L F
.049 .222 .721 r
.46341 .60541 m .46364 .60608 L .46378 .60614 L F
0 .138 .671 r
.46378 .60614 m .46461 .60897 L .46272 .60678 L F
.46378 .60614 m .46461 .60897 L .46272 .60678 L F
.049 .222 .721 r
.46364 .60608 m .46461 .60897 L .46378 .60614 L F
0 .256 .762 r
.46311 .60551 m .46199 .60541 L .46096 .60348 L F
.901 .791 .73 r
.46096 .60348 m .45995 .60612 L .45786 .60495 L F
0 .256 .762 r
.46378 .60614 m .46096 .60348 L .46341 .60541 L F
.545 .515 .772 r
.45983 .60429 m .46323 .60536 L .46178 .60437 L F
.46323 .60536 m .46341 .60541 L .46326 .60532 L F
.46323 .60536 m .46326 .60532 L .46178 .60437 L F
0 .256 .762 r
.46378 .60614 m .46291 .60579 L .46311 .60551 L F
.46291 .60579 m .46199 .60541 L .46311 .60551 L F
.678 .278 .28 r
.46272 .60678 m .46461 .60897 L .46219 .60839 L F
.72 .813 .922 r
.7397 .43176 m .73621 .43153 L .73849 .43029 L F
.149 .143 .594 r
.74102 .42863 m .7397 .43176 L .73849 .43029 L F
.74102 .42863 m .74156 .43027 L .7397 .43176 L F
.51 0 0 r
.74066 .43275 m .74232 .4337 L .74164 .4332 L F
.74066 .43275 m .74164 .4332 L .7397 .43176 L F
.74066 .43275 m .7397 .43176 L .74156 .43027 L F
.91 .851 .773 r
.73955 .43224 m .74066 .43275 L .74041 .43138 L F
.73771 .43407 m .74066 .43275 L .73955 .43224 L F
.917 .934 .804 r
.6599 .44673 m .66216 .44387 L .66123 .4429 L F
.664 .469 .611 r
.60025 .45862 m .60017 .46145 L .59748 .46049 L F
.838 .469 .353 r
.59972 .45731 m .59956 .45811 L .60009 .45823 L F
.59972 .45731 m .60218 .45873 L .60025 .45862 L F
.59972 .45731 m .60009 .45823 L .60218 .45873 L F
0 0 0 r
.60015 .45575 m .59974 .45738 L .59972 .45731 L F
.59974 .45738 m .59956 .45811 L .59972 .45731 L F
.658 .322 0 r
.59972 .45731 m .60025 .45862 L .59969 .45723 L F
.59972 .45731 m .59969 .45723 L .59895 .4554 L F
.59972 .45731 m .59895 .4554 L .59883 .4551 L F
.674 .477 .611 r
.60413 .46096 m .60025 .45862 L .60218 .45873 L F
.60413 .46096 m .60017 .46145 L .60025 .45862 L F
.74 .473 .526 r
.44235 .64467 m .44578 .64266 L .4421 .6429 L F
.44235 .64467 m .44526 .64548 L .44578 .64266 L F
.553 .298 .483 r
.44578 .64266 m .44526 .64548 L .44792 .64497 L F
.775 .592 .652 r
.40492 .61563 m .40291 .61892 L .40359 .61634 L F
.717 .516 .617 r
.4055 .61884 m .40291 .61892 L .40492 .61563 L F
.688 .628 .784 r
.40492 .61563 m .40873 .61577 L .40744 .61311 L F
.279 0 .056 r
.6193 .40757 m .62161 .40693 L .62256 .40516 L F
.445 .06 .214 r
.62161 .40693 m .62503 .40457 L .62256 .40516 L F
.492 .338 .6 r
.46593 .5949 m .46611 .59776 L .46385 .59838 L F
.334 .043 .314 r
.46611 .59776 m .46335 .60047 L .46385 .59838 L F
.014 0 0 r
.73882 .3987 m .74066 .39845 L .73801 .39866 L F
.876 .803 .774 r
.70841 .44377 m .71009 .44278 L .70818 .44551 L F
.801 .631 .672 r
.53797 .528 m .53568 .53252 L .53565 .52963 L F
.413 .161 .42 r
.58344 .45262 m .58574 .45197 L .58597 .44993 L F
.405 .166 .435 r
.58597 .44993 m .58831 .4491 L .58862 .44692 L F
.428 .187 .445 r
.58574 .45197 m .58831 .4491 L .58597 .44993 L F
.534 .305 .514 r
.56082 .5475 m .56092 .55022 L .55802 .55053 L F
.391 .173 .459 r
.56082 .5475 m .56314 .54453 L .56341 .54694 L F
.556 .322 .516 r
.56345 .54968 m .56082 .5475 L .56341 .54694 L F
.56345 .54968 m .56092 .55022 L .56082 .5475 L F
.814 .623 .645 r
.19268 .69571 m .19282 .69302 L .19283 .69317 L F
.639 .733 .916 r
.71385 .4017 m .71503 .40397 L .71761 .40256 L F
.434 .642 .945 r
.47841 .5814 m .47975 .58044 L .47785 .58089 L F
.47841 .5814 m .48148 .58252 L .47975 .58044 L F
0 .143 .683 r
.20861 .6565 m .21089 .65932 L .21033 .65687 L F
.20861 .6565 m .21033 .65687 L .20572 .65641 L F
.685 .712 .869 r
.63994 .43061 m .63748 .43158 L .63673 .4279 L F
.673 .162 .016 r
.63748 .43158 m .64013 .43367 L .63821 .43459 L F
.351 0 .181 r
.45157 .57375 m .45431 .57319 L .45459 .57158 L F
.336 .105 .409 r
.45723 .56839 m .45459 .57158 L .45696 .57054 L F
.672 .471 .604 r
.45431 .57319 m .45696 .57054 L .45459 .57158 L F
.336 .105 .409 r
.45723 .56839 m .45459 .57158 L .45696 .57054 L F
.628 .913 .628 r
.51788 .57737 m .51885 .57597 L .52072 .57451 L F
.276 .556 .929 r
.51788 .57737 m .52079 .57821 L .51885 .57597 L F
.451 .324 .616 r
.23217 .58628 m .23413 .58577 L .23389 .5832 L F
.588 .168 .213 r
.21556 .65403 m .21414 .65622 L .21178 .65614 L F
.214 .167 .586 r
.21735 .65473 m .21628 .65566 L .21594 .65349 L F
.21618 .6532 m .21594 .65349 L .21582 .65273 L F
.563 .838 .492 r
.21629 .65307 m .21594 .65349 L .2159 .65363 L F
.214 .167 .586 r
.21735 .65473 m .21594 .65349 L .21618 .6532 L F
.21735 .65473 m .21618 .6532 L .21714 .65235 L F
.21618 .6532 m .21582 .65273 L .21682 .65244 L F
.563 .838 .492 r
.21801 .65119 m .21631 .65305 L .2159 .65363 L F
.214 .167 .586 r
.21618 .6532 m .21631 .65305 L .21714 .65235 L F
.563 .838 .492 r
.21631 .65305 m .21629 .65307 L .21628 .65308 L F
.21629 .65307 m .21595 .65344 L .21594 .65349 L F
0 0 0 r
.21714 .65235 m .21595 .65344 L .21631 .65305 L F
.21714 .65235 m .21631 .65305 L .21801 .65119 L F
.214 .167 .586 r
.21631 .65305 m .21682 .65244 L .21714 .65235 L F
.563 .838 .492 r
.21631 .65305 m .21628 .65308 L .2159 .65363 L F
0 0 .134 r
.21582 .65273 m .21594 .65349 L .21595 .65344 L F
.21594 .65349 m .21628 .65566 L .21595 .65344 L F
.563 .838 .492 r
.2159 .65363 m .21595 .65344 L .21556 .65403 L F
.258 0 .03 r
.21628 .65566 m .21556 .65403 L .21595 .65344 L F
.21628 .65566 m .21414 .65622 L .21556 .65403 L F
0 0 0 r
.18541 .54226 m .18558 .54276 L .18747 .54179 L F
.18541 .54226 m .18343 .54336 L .18558 .54276 L F
0 .125 .67 r
.53879 .54847 m .53783 .54805 L .53819 .54723 L F
.53879 .54847 m .53921 .55049 L .53783 .54805 L F
.397 .16 .433 r
.58862 .44692 m .59053 .44826 L .59065 .446 L F
.58862 .44692 m .58831 .4491 L .59053 .44826 L F
.971 .808 .623 r
.6577 .41408 m .6582 .41743 L .65813 .41591 L F
0 0 .491 r
.6582 .41743 m .65904 .41952 L .65813 .41591 L F
0 0 0 r
.53937 .59973 m .53784 .59877 L .54138 .5985 L F
.53937 .59973 m .53913 .60018 L .53784 .59877 L F
.763 .787 .872 r
.45579 .5919 m .4523 .59202 L .45511 .58989 L F
.129 .676 .794 r
.45579 .5919 m .45499 .59181 L .4523 .59202 L F
.239 .44 .856 r
.45628 .58976 m .45579 .5919 L .45511 .58989 L F
.851 .997 .77 r
.45628 .58976 m .45499 .59181 L .45579 .5919 L F
.31 .517 .895 r
.76203 .40094 m .76094 .40246 L .76072 .40071 L F
.76203 .40094 m .76409 .40373 L .76094 .40246 L F
.992 .874 .601 r
.75695 .40864 m .75557 .40947 L .75607 .40694 L F
.503 .209 .4 r
.23678 .57994 m .23905 .57967 L .23978 .5778 L F
.301 .016 .301 r
.23978 .5778 m .23905 .57967 L .24156 .57713 L F
.118 .295 .768 r
.55476 .58051 m .5547 .57804 L .55482 .57897 L F
.465 0 0 r
.55623 .57939 m .55482 .57897 L .5547 .57804 L F
.483 .841 .994 r
.41286 .6061 m .4087 .60606 L .40963 .60664 L F
0 0 0 r
.5546 .56536 m .55415 .56691 L .55303 .56845 L F
.365 .59 .931 r
.55303 .56845 m .55415 .56691 L .55481 .5684 L F
.681 .497 .631 r
.62703 .41067 m .6278 .41402 L .62398 .41381 L F
.636 .468 .639 r
.63003 .41342 m .62703 .41067 L .62891 .40984 L F
.63003 .41342 m .6278 .41402 L .62703 .41067 L F
0 0 0 r
.60755 .43527 m .60658 .43694 L .60541 .43791 L F
.424 .062 .244 r
.60993 .43426 m .60658 .43694 L .60755 .43527 L F
.576 .571 .81 r
.60658 .43694 m .60493 .4399 L .60541 .43791 L F
.969 .772 .584 r
.55034 .54175 m .54915 .53822 L .54865 .54144 L F
0 0 .385 r
.54913 .5442 m .5494 .54169 L .55034 .54175 L F
.728 .438 .489 r
.55093 .5408 m .54915 .53822 L .55034 .54175 L F
.605 .954 .866 r
.5494 .54169 m .55093 .5408 L .55034 .54175 L F
.591 .762 .96 r
.71755 .39212 m .71594 .39441 L .71497 .39288 L F
.71755 .39212 m .7187 .39372 L .71594 .39441 L F
.864 .809 .795 r
.50268 .54428 m .50273 .54063 L .50418 .54217 L F
.486 .708 .968 r
.50508 .54042 m .50418 .54217 L .50273 .54063 L F
.50508 .54042 m .50418 .54217 L .50273 .54063 L F
.986 .841 .614 r
.60881 .45593 m .60829 .45743 L .60716 .45617 L F
.888 .985 .809 r
.60881 .45593 m .60938 .4535 L .61117 .45496 L F
.60881 .45593 m .60716 .45617 L .60938 .4535 L F
0 0 0 r
.48512 .58328 m .4843 .58528 L .48301 .58653 L F
.025 0 0 r
.48358 .58717 m .48301 .58653 L .4843 .58528 L F
.48358 .58717 m .48137 .58792 L .48301 .58653 L F
.418 .124 .356 r
.58344 .45262 m .58542 .45396 L .58574 .45197 L F
.58344 .45262 m .58302 .45463 L .58542 .45396 L F
.627 .598 .801 r
.62283 .42247 m .62076 .42353 L .61918 .41974 L F
.307 0 0 r
.62283 .42247 m .61931 .42455 L .62076 .42353 L F
.812 .771 .261 r
.65859 .42605 m .65817 .42696 L .65811 .42456 L F
.65859 .42605 m .65807 .42842 L .65817 .42696 L F
0 .064 .625 r
.21482 .61874 m .21649 .62094 L .21495 .61715 L F
.367 .251 .587 r
.21482 .61874 m .21489 .6216 L .21649 .62094 L F
.357 .027 .262 r
.44247 .58599 m .44142 .58833 L .43949 .58878 L F
.583 .285 .429 r
.44491 .58577 m .44142 .58833 L .44247 .58599 L F
.702 .655 .8 r
.48148 .58252 m .48512 .58328 L .48418 .58 L F
0 .471 .721 r
.48426 .58306 m .48512 .58328 L .48148 .58252 L F
.994 .781 .411 r
.48426 .58306 m .4843 .58528 L .48512 .58328 L F
.249 0 .188 r
.22554 .64519 m .2227 .64766 L .22362 .64591 L F
0 0 .372 r
.5253 .5857 m .52608 .58971 L .52599 .58811 L F
0 .382 .818 r
.52608 .58971 m .52797 .59 L .52599 .58811 L F
.52608 .58971 m .52902 .5911 L .52797 .59 L F
.815 .444 .354 r
.44017 .64415 m .4421 .6429 L .43851 .64233 L F
.44017 .64415 m .44235 .64467 L .4421 .6429 L F
.741 .98 .915 r
.41184 .6131 m .41046 .61313 L .41219 .61163 L F
.314 .131 .466 r
.41294 .6139 m .41127 .61559 L .41184 .6131 L F
.538 .354 .579 r
.58641 .52787 m .58679 .52887 L .58511 .52974 L F
.375 .267 .602 r
.58939 .52858 m .58641 .52787 L .58965 .5262 L F
.58939 .52858 m .58679 .52887 L .58641 .52787 L F
.201 0 0 r
.22809 .55356 m .22623 .55341 L .2242 .55304 L F
.765 .913 .939 r
.428 .57701 m .42894 .57807 L .42869 .5756 L F
.35 .808 .696 r
.42894 .57807 m .42871 .57807 L .42869 .5756 L F
.875 .922 .853 r
.62229 .44414 m .6186 .44622 L .62015 .44471 L F
.871 .972 .851 r
.62229 .44414 m .62015 .44471 L .62271 .44179 L F
.784 .631 .691 r
.54138 .5985 m .54144 .60163 L .53937 .59973 L F
.699 .563 .697 r
.54468 .60019 m .54144 .60163 L .54138 .5985 L F
.361 .6 .938 r
.24181 .55889 m .24239 .55716 L .23927 .55647 L F
.24181 .55889 m .2435 .55881 L .24239 .55716 L F
.678 .65 .815 r
.478 .56487 m .47517 .56569 L .47323 .56259 L F
.245 .62 .957 r
.66533 .41023 m .66401 .41107 L .66665 .41146 L F
.66665 .41146 m .66401 .41107 L .66533 .41023 L F
.608 .341 .486 r
.57082 .53911 m .57347 .54101 L .57088 .54088 L F
.57082 .53911 m .57421 .53844 L .57347 .54101 L F
.62 .755 .943 r
.70526 .40266 m .70883 .40345 L .70782 .4017 L F
.643 .706 .893 r
.70883 .40345 m .71027 .40059 L .70782 .4017 L F
.70883 .40345 m .71134 .40256 L .71027 .40059 L F
.223 0 .287 r
.16254 .56511 m .16456 .56429 L .16229 .56528 L F
.16254 .56511 m .16394 .56409 L .16456 .56429 L F
.406 .69 .977 r
.53268 .68012 m .53192 .68151 L .53032 .68058 L F
.971 .741 .532 r
.53192 .68151 m .53207 .68475 L .53032 .68058 L F
.328 0 .245 r
.58511 .52974 m .58654 .53112 L .58472 .53185 L F
.58511 .52974 m .58679 .52887 L .58654 .53112 L F
0 0 .22 r
.59037 .50021 m .59168 .50057 L .59201 .49852 L F
.59037 .50021 m .59034 .50225 L .59168 .50057 L F
.202 .32 .762 r
.6051 .44495 m .60621 .44856 L .60386 .4468 L F
.657 .175 .096 r
.60621 .44856 m .60345 .44823 L .60386 .4468 L F
.431 .187 .442 r
.24201 .62621 m .24011 .62995 L .24038 .62688 L F
.874 .673 .628 r
.60753 .4673 m .60875 .47033 L .60699 .46885 L F
.87 .746 .723 r
.60875 .47033 m .60523 .47228 L .60699 .46885 L F
.60875 .47033 m .60734 .47352 L .60523 .47228 L F
.874 .521 .024 r
.5246 .58337 m .5253 .5857 L .52382 .58231 L F
.377 .163 .456 r
.24504 .6209 m .24505 .62387 L .24261 .62392 L F
.412 .212 .496 r
.24505 .62387 m .24201 .62621 L .24261 .62392 L F
.905 .907 .502 r
.59929 .48794 m .59823 .48941 L .59922 .48724 L F
.907 .78 .71 r
.54504 .51793 m .54426 .51468 L .5427 .51691 L F
.908 .777 .705 r
.54439 .52016 m .54504 .51793 L .5427 .51691 L F
.385 .78 .987 r
.51245 .54364 m .5162 .54416 L .51373 .54435 L F
.781 .737 .812 r
.51344 .70209 m .5143 .70455 L .51099 .70499 L F
0 0 0 r
.5143 .70455 m .51395 .70467 L .51099 .70499 L F
.887 .587 .077 r
.51344 .70209 m .51395 .70467 L .5143 .70455 L F
.84 .632 .622 r
.42139 .59288 m .41867 .59157 L .42152 .59278 L F
.641 .121 0 r
.42152 .59278 m .4241 .59449 L .42139 .59288 L F
.464 .403 .704 r
.44797 .57953 m .44572 .57779 L .44619 .57911 L F
.44797 .57953 m .44901 .57771 L .44572 .57779 L F
0 0 .478 r
.44878 .58042 m .44797 .57953 L .44766 .57946 L F
.44878 .58042 m .44766 .57946 L .44764 .57985 L F
.44878 .58042 m .44957 .58133 L .44797 .57953 L F
.57 .267 .416 r
.44592 .58026 m .44878 .58042 L .44619 .57911 L F
0 0 0 r
.44983 .57897 m .44762 .58046 L .44772 .57981 L F
.727 .465 .53 r
.44393 .58051 m .44727 .58396 L .44592 .58026 L F
.274 .313 .721 r
.44592 .58026 m .44839 .58216 L .44878 .58042 L F
.44637 .58061 m .44727 .58396 L .44839 .58216 L F
.44592 .58026 m .44609 .58071 L .44637 .58061 L F
.44609 .58071 m .44727 .58396 L .44637 .58061 L F
0 0 0 r
.44762 .58046 m .44561 .58181 L .44721 .58029 L F
.44763 .58014 m .44721 .58029 L .44764 .57988 L F
.44762 .58046 m .44721 .58029 L .44763 .58014 L F
.44762 .58046 m .44764 .57988 L .44772 .57981 L F
0 0 .478 r
.44764 .57985 m .44766 .57946 L .44619 .57911 L F
0 .546 .726 r
.22166 .54065 m .22375 .5408 L .22549 .54097 L F
.194 0 0 r
.22375 .5408 m .22761 .54137 L .22549 .54097 L F
.915 .636 .144 r
.64065 .40465 m .64093 .40732 L .64012 .40437 L F
.328 0 0 r
.64282 .40076 m .64396 .40129 L .64615 .40059 L F
.887 .886 .825 r
.64396 .40129 m .64282 .40141 L .64387 .40027 L F
0 0 0 r
.64169 .40278 m .64234 .40199 L .64282 .40076 L F
.887 .886 .825 r
.64282 .40141 m .6409 .40163 L .64369 .40036 L F
.64282 .40141 m .64369 .40036 L .64387 .40027 L F
0 0 0 r
.64065 .40465 m .64201 .40285 L .64234 .40199 L F
.64065 .40465 m .64234 .40199 L .64169 .40278 L F
.664 .973 .84 r
.64065 .40465 m .64012 .40437 L .64201 .40285 L F
.915 .636 .144 r
.64065 .40465 m .64093 .40732 L .64012 .40437 L F
.353 0 .119 r
.38722 .59374 m .39037 .59187 L .38803 .59225 L F
.595 .435 .634 r
.56551 .54425 m .56341 .54694 L .56314 .54453 L F
.546 .498 .754 r
.74068 .42223 m .7422 .41989 L .74014 .42008 L F
.74068 .42223 m .74326 .42159 L .7422 .41989 L F
.332 .597 .943 r
.67517 .40724 m .67669 .40904 L .67506 .40966 L F
.783 .961 .924 r
.67669 .40904 m .67896 .4098 L .67506 .40966 L F
.67669 .40904 m .67753 .40695 L .67896 .4098 L F
.149 .685 .845 r
.18747 .54179 m .18963 .5417 L .1915 .54193 L F
.519 .064 .11 r
.18963 .5417 m .19347 .54086 L .1915 .54193 L F
0 0 0 r
.5953 .49368 m .59269 .49675 L .59409 .4949 L F
.681 .444 .557 r
.59409 .4949 m .59728 .49281 L .5953 .49368 L F
.201 .728 .755 r
.74594 .4345 m .74868 .43392 L .74886 .43398 L F
.619 .251 .323 r
.42525 .64792 m .42363 .65046 L .42141 .64861 L F
.611 .242 .318 r
.42769 .65018 m .42525 .64792 L .42746 .64842 L F
.42769 .65018 m .42363 .65046 L .42525 .64792 L F
.591 .86 .994 r
.53232 .68453 m .53385 .68348 L .53207 .68475 L F
.604 .777 .964 r
.74805 .39033 m .74651 .39262 L .74532 .39135 L F
.74805 .39033 m .74916 .39185 L .74651 .39262 L F
.413 .259 .561 r
.26914 .55875 m .26888 .56237 L .26705 .56249 L F
.415 .273 .578 r
.26888 .56237 m .269 .56455 L .26705 .56249 L F
.261 .249 .656 r
.26705 .56249 m .269 .56455 L .26762 .56461 L F
.387 .246 .564 r
.37289 .60682 m .37472 .60621 L .37464 .6037 L F
.397 .325 .658 r
.37289 .60682 m .37512 .60886 L .37472 .60621 L F
.37289 .60682 m .37304 .61023 L .37512 .60886 L F
.898 .731 .666 r
.53932 .56761 m .54098 .56824 L .54001 .56518 L F
.75 .66 .762 r
.54098 .56824 m .5426 .5662 L .54001 .56518 L F
.044 0 0 r
.74066 .39845 m .74404 .39681 L .74321 .39717 L F
0 0 0 r
.74321 .39717 m .74404 .39681 L .74754 .39607 L F
.805 .315 0 r
.54144 .60163 m .54091 .6024 L .53937 .59973 L F
.547 .109 .159 r
.54468 .60019 m .54091 .6024 L .54144 .60163 L F
.537 .521 .786 r
.73937 .39184 m .7412 .39755 L .73962 .39843 L F
.558 .275 .443 r
.63085 .40388 m .6335 .40116 L .63104 .40199 L F
.884 .974 .669 r
.52072 .57451 m .51885 .57597 L .52066 .57292 L F
.429 .451 .781 r
.269 .56455 m .26832 .56842 L .26762 .56461 L F
.269 .56455 m .27028 .56864 L .26832 .56842 L F
.436 .431 .755 r
.27028 .56864 m .27099 .57015 L .26832 .56842 L F
.507 .419 .691 r
.26832 .56842 m .27099 .57015 L .26872 .57088 L F
.608 .863 .991 r
.20433 .6555 m .20591 .65711 L .20572 .65641 L F
.918 .961 .794 r
.63272 .44488 m .63353 .44628 L .63472 .44417 L F
.95 .947 .636 r
.63156 .44838 m .63353 .44628 L .63272 .44488 L F
.63156 .44838 m .63198 .44928 L .63353 .44628 L F
.581 .202 .289 r
.54307 .55033 m .54566 .55274 L .54581 .55046 L F
.268 .219 .616 r
.54347 .5535 m .54566 .55274 L .54307 .55033 L F
.492 .756 .989 r
.68174 .45397 m .68454 .45371 L .68309 .45252 L F
0 0 0 r
.68309 .45252 m .68174 .4541 L .68174 .45397 L F
.68174 .4541 m .68058 .45545 L .68174 .45397 L F
.428 0 0 r
.68173 .45387 m .68174 .45397 L .67951 .45252 L F
.68337 .45487 m .68174 .45397 L .68173 .45387 L F
.037 .191 .696 r
.68337 .45487 m .68454 .45371 L .68174 .45397 L F
.68337 .45487 m .68546 .45724 L .68454 .45371 L F
.402 .211 .503 r
.22926 .60126 m .23116 .60064 L .23147 .59792 L F
.227 .008 .358 r
.22926 .60126 m .23046 .60266 L .23116 .60064 L F
.22926 .60126 m .22883 .60348 L .23046 .60266 L F
.312 0 .086 r
.59748 .46049 m .59648 .46249 L .59407 .46302 L F
.433 .013 .141 r
.59894 .46177 m .59748 .46049 L .60017 .46145 L F
.59894 .46177 m .59648 .46249 L .59748 .46049 L F
.646 .449 .602 r
.56215 .52656 m .56507 .52618 L .56515 .52354 L F
.452 .29 .57 r
.56515 .52354 m .5673 .52554 L .56689 .52284 L F
.56515 .52354 m .56507 .52618 L .5673 .52554 L F
.754 .479 .516 r
.42722 .63577 m .43122 .63387 L .42862 .6365 L F
.555 .342 .546 r
.43122 .63387 m .43101 .6364 L .42862 .6365 L F
.47 .32 .594 r
.42949 .63783 m .42862 .6365 L .43067 .63641 L F
.42949 .63783 m .43067 .63641 L .43101 .6364 L F
.824 .58 .57 r
.43122 .63387 m .42881 .63702 L .43101 .6364 L F
.47 .32 .594 r
.42899 .63706 m .42722 .63577 L .42862 .6365 L F
.42949 .63783 m .42852 .63695 L .42899 .63706 L F
0 0 .083 r
.42722 .63577 m .42843 .63701 L .42881 .63702 L F
.47 .32 .594 r
.42852 .63695 m .42843 .63701 L .42722 .63577 L F
.42931 .63792 m .42747 .63892 L .42738 .63778 L F
.42843 .63701 m .42738 .63778 L .42722 .63577 L F
.42931 .63792 m .42738 .63778 L .42843 .63701 L F
0 0 .083 r
.42782 .63639 m .42738 .63701 L .42843 .63701 L F
.42722 .63577 m .42738 .63701 L .42782 .63639 L F
.621 .432 .605 r
.42451 .63901 m .42747 .63892 L .42722 .63577 L F
.918 .978 .742 r
.4259 .64014 m .42559 .63844 L .42738 .63701 L F
.314 0 .153 r
.42559 .63844 m .4269 .6377 L .42738 .63701 L F
0 0 .451 r
.42778 .63677 m .42852 .63695 L .42738 .63701 L F
.42852 .63695 m .42843 .63701 L .42738 .63701 L F
.47 .32 .594 r
.42881 .63702 m .42722 .63577 L .42899 .63706 L F
.754 .479 .516 r
.42722 .63577 m .42881 .63702 L .43122 .63387 L F
0 0 .451 r
.42936 .63633 m .42852 .63695 L .42778 .63677 L F
0 0 .083 r
.42722 .63577 m .42881 .63702 L .42881 .63702 L F
.47 .32 .594 r
.42852 .63695 m .42722 .63577 L .42881 .63702 L F
0 0 .083 r
.42722 .63577 m .42729 .63665 L .42738 .63701 L F
.42729 .63665 m .42747 .63892 L .42738 .63701 L F
.42722 .63577 m .42747 .63892 L .42738 .63701 L F
.944 .958 .675 r
.42747 .63892 m .4259 .64014 L .42738 .63701 L F
.314 0 .153 r
.4269 .6377 m .42747 .63737 L .42738 .63701 L F
.42747 .63737 m .42949 .63621 L .42738 .63701 L F
0 0 .451 r
.42852 .63695 m .42881 .63702 L .42843 .63701 L F
.43017 .63534 m .42936 .63633 L .42778 .63677 L F
.42936 .63633 m .42881 .63702 L .42852 .63695 L F
.47 .32 .594 r
.42949 .63783 m .42931 .63792 L .42843 .63701 L F
.42949 .63783 m .42843 .63701 L .42852 .63695 L F
0 0 .451 r
.43017 .63534 m .42881 .63702 L .42881 .63702 L F
.504 .014 .025 r
.42881 .63702 m .42949 .63783 L .43101 .6364 L F
0 0 .451 r
.43017 .63534 m .42949 .63783 L .42881 .63702 L F
.337 0 .085 r
.42949 .63783 m .42825 .63971 L .4259 .64014 L F
.472 .252 .498 r
.43017 .63534 m .42862 .63887 L .42949 .63783 L F
.42862 .63887 m .42825 .63971 L .42949 .63783 L F
.605 .834 .987 r
.45942 .58244 m .45715 .58316 L .45567 .58206 L F
.57 .394 .604 r
.45942 .58244 m .45684 .5859 L .45715 .58316 L F
.465 0 0 r
.55623 .57939 m .55634 .57971 L .55482 .57897 L F
.395 .314 .646 r
.5577 .57727 m .55969 .57598 L .55623 .57939 L F
.236 .229 .648 r
.55482 .57897 m .55562 .58285 L .55476 .58051 L F
.545 .477 .73 r
.55634 .57971 m .55562 .58285 L .5549 .57937 L F
.55588 .57949 m .5549 .57937 L .55482 .57897 L F
.55634 .57971 m .5549 .57937 L .55588 .57949 L F
.711 .295 .257 r
.55317 .58268 m .55643 .57956 L .55491 .57977 L F
.011 0 .185 r
.55623 .57939 m .55684 .57923 L .55634 .57971 L F
.711 .295 .257 r
.55643 .57956 m .55646 .57953 L .55636 .57955 L F
.55643 .57956 m .55636 .57955 L .55491 .57977 L F
.55317 .58268 m .55383 .5828 L .55646 .57953 L F
.545 .477 .73 r
.55634 .57971 m .55793 .58241 L .55562 .58285 L F
.406 .452 .795 r
.55649 .57965 m .55793 .58241 L .55634 .57971 L F
.011 0 .185 r
.55684 .57923 m .55654 .57959 L .55642 .57964 L F
.55684 .57923 m .55871 .57874 L .55649 .57965 L F
.343 .471 .845 r
.55646 .57953 m .55658 .57958 L .55871 .57874 L F
.55658 .57958 m .55994 .58081 L .55871 .57874 L F
.011 0 .185 r
.55642 .57964 m .55649 .57965 L .55634 .57971 L F
.55654 .57959 m .55649 .57965 L .55642 .57964 L F
.006 0 0 r
.55644 .57962 m .55994 .58081 L .55646 .57953 L F
.406 .452 .795 r
.55651 .57965 m .55822 .58106 L .55649 .57965 L F
.55833 .58052 m .55822 .58106 L .55651 .57965 L F
.55822 .58106 m .55793 .58241 L .55649 .57965 L F
.55833 .58052 m .55981 .58226 L .55793 .58241 L F
.006 0 0 r
.5589 .58079 m .55994 .58081 L .55644 .57962 L F
.406 .452 .795 r
.55943 .58103 m .55954 .5814 L .55914 .58111 L F
.55954 .5814 m .55936 .58173 L .55833 .58052 L F
.535 .545 .812 r
.5601 .58104 m .55981 .58226 L .55938 .58089 L F
.006 0 0 r
.55583 .58315 m .55817 .58239 L .55979 .58094 L F
.406 .452 .795 r
.55938 .58089 m .55943 .58103 L .55833 .58052 L F
.006 0 0 r
.55968 .58096 m .55994 .58081 L .5589 .58079 L F
.535 .545 .812 r
.55999 .58086 m .55938 .58089 L .55871 .57874 L F
.5601 .58104 m .55968 .58096 L .55999 .58086 L F
.006 0 0 r
.55968 .58096 m .55983 .58091 L .55994 .58081 L F
.535 .545 .812 r
.55968 .58096 m .55938 .58089 L .55999 .58086 L F
.006 0 0 r
.55964 .58098 m .55979 .58094 L .55983 .58091 L F
.55964 .58098 m .55983 .58091 L .55968 .58096 L F
.55583 .58315 m .55979 .58094 L .55964 .58098 L F
.406 .452 .795 r
.55943 .58103 m .55914 .58111 L .55833 .58052 L F
.55954 .5814 m .55981 .58226 L .55936 .58173 L F
.006 0 0 r
.55949 .58107 m .55968 .58096 L .5589 .58079 L F
0 0 0 r
.55994 .58081 m .56075 .57835 L .55871 .57874 L F
.55994 .58081 m .56008 .58048 L .56075 .57835 L F
.535 .545 .812 r
.56075 .57835 m .56034 .58003 L .56025 .57995 L F
0 0 0 r
.56008 .58048 m .56074 .57887 L .56075 .57835 L F
.535 .545 .812 r
.56075 .57835 m .56025 .57995 L .55871 .57874 L F
.759 .939 .598 r
.55994 .58081 m .55983 .58091 L .56008 .58048 L F
.535 .545 .812 r
.56034 .58003 m .5601 .58104 L .55992 .58075 L F
.56034 .58003 m .55992 .58075 L .55871 .57874 L F
.759 .939 .598 r
.56008 .58048 m .55979 .58094 L .56018 .58023 L F
.55983 .58091 m .55979 .58094 L .56008 .58048 L F
.406 .452 .795 r
.55871 .57874 m .55938 .58089 L .55833 .58052 L F
.006 0 0 r
.55583 .58315 m .55949 .58107 L .55833 .58052 L F
.535 .545 .812 r
.56075 .57835 m .56228 .58023 L .55981 .58226 L F
.759 .939 .598 r
.56018 .58023 m .55817 .58239 L .56074 .57887 L F
.55979 .58094 m .55817 .58239 L .56018 .58023 L F
.006 0 0 r
.55641 .57983 m .55833 .58052 L .55644 .57962 L F
.55583 .58315 m .55833 .58052 L .55641 .57983 L F
.406 .452 .795 r
.55871 .57874 m .55833 .58052 L .55651 .57965 L F
.711 .295 .257 r
.55383 .5828 m .55642 .57973 L .55644 .57962 L F
.55641 .57959 m .55644 .57962 L .55646 .57953 L F
.55383 .5828 m .55644 .57962 L .55641 .57959 L F
.55383 .5828 m .55583 .58315 L .55642 .57973 L F
.011 0 .185 r
.55623 .57939 m .55969 .57598 L .55871 .57874 L F
.563 .418 .642 r
.62398 .41381 m .62426 .4169 L .62178 .41727 L F
.402 .072 .288 r
.62426 .4169 m .6217 .41888 L .62178 .41727 L F
0 0 0 r
.60728 .41993 m .60498 .42299 L .60609 .42175 L F
.041 0 .284 r
.60446 .42505 m .60609 .42175 L .60498 .42299 L F
.76 .656 .747 r
.45808 .64202 m .45423 .64231 L .45696 .64015 L F
.55 .253 .416 r
.45808 .64202 m .45435 .6452 L .45423 .64231 L F
.45808 .64202 m .45681 .64521 L .45435 .6452 L F
.611 .202 0 r
.45696 .64015 m .45797 .64185 L .45808 .64202 L F
.272 0 .279 r
.45916 .64408 m .45681 .64521 L .45808 .64202 L F
.45916 .64408 m .45808 .64202 L .45797 .64185 L F
.545 .585 .845 r
.45997 .6074 m .45993 .60994 L .46219 .60839 L F
.864 .809 .795 r
.50268 .54428 m .50053 .54358 L .50273 .54063 L F
.956 .693 .495 r
.50268 .54428 m .50095 .54585 L .50053 .54358 L F
.50268 .54428 m .50309 .54709 L .50095 .54585 L F
.634 .539 .73 r
.40291 .61892 m .39997 .62013 L .39928 .61807 L F
.606 .916 .661 r
.42069 .57174 m .42199 .57013 L .42307 .57086 L F
.42069 .57174 m .41902 .57285 L .42199 .57013 L F
.743 .854 .417 r
.42106 .60543 m .41926 .60944 L .42231 .60673 L F
.407 .698 .98 r
.42106 .60543 m .42231 .60673 L .42279 .60527 L F
.42106 .60543 m .42231 .60673 L .42279 .60527 L F
0 0 0 r
.54354 .4971 m .54478 .49561 L .54565 .49385 L F
.617 .933 .705 r
.54181 .49807 m .54478 .49561 L .54354 .4971 L F
.609 .93 .703 r
.54181 .49807 m .54354 .4971 L .54042 .49966 L F
.946 .643 .431 r
.18803 .55686 m .1875 .55856 L .18576 .55682 L F
.505 .104 .214 r
.75071 .41512 m .75389 .41337 L .75185 .41545 L F
.547 .109 .159 r
.54468 .60019 m .54367 .60241 L .54091 .6024 L F
.64 .205 .199 r
.54755 .60186 m .54468 .60019 L .54724 .60055 L F
.54755 .60186 m .54367 .60241 L .54468 .60019 L F
.492 .748 .986 r
.70221 .44386 m .6985 .44299 L .70057 .44259 L F
.696 .72 .867 r
.70365 .44005 m .70221 .44386 L .70057 .44259 L F
.70365 .44005 m .70465 .4431 L .70221 .44386 L F
.259 .122 .496 r
.37464 .6037 m .37646 .60031 L .37439 .60111 L F
.673 .578 .74 r
.50934 .53912 m .51113 .54027 L .51075 .53759 L F
.625 .802 .967 r
.63312 .41907 m .63494 .41989 L .63131 .41935 L F
.684 .221 .147 r
.63494 .41989 m .63368 .42061 L .63131 .41935 L F
.587 .586 .818 r
.63632 .41571 m .63494 .41989 L .63312 .41907 L F
.63632 .41571 m .6374 .41924 L .63494 .41989 L F
.838 .457 .328 r
.63494 .41989 m .63555 .42213 L .63368 .42061 L F
.743 .746 .854 r
.63364 .41395 m .63003 .41342 L .63238 .41244 L F
.612 .089 0 r
.63364 .41395 m .63237 .41491 L .63115 .41359 L F
.504 .47 .752 r
.63477 .40974 m .63364 .41395 L .63238 .41244 L F
0 0 0 r
.63492 .414 m .63237 .41491 L .63364 .41395 L F
.604 .906 .984 r
.63492 .414 m .6338 .41328 L .63237 .41491 L F
.75 .729 .203 r
.6338 .41328 m .6333 .41591 L .63237 .41491 L F
.6333 .41591 m .63297 .41765 L .63237 .41491 L F
.612 .089 0 r
.63115 .41359 m .63237 .41491 L .63003 .41342 L F
.504 .47 .752 r
.63477 .40974 m .63641 .41403 L .63364 .41395 L F
0 0 0 r
.63492 .414 m .63364 .41395 L .63641 .41403 L F
.657 .471 .621 r
.40359 .61634 m .40291 .61892 L .39928 .61807 L F
.715 .703 .837 r
.68914 .45547 m .69298 .45648 L .69157 .4544 L F
.734 .676 .794 r
.69298 .45648 m .69488 .45514 L .69157 .4544 L F
.696 .339 .366 r
.43129 .64832 m .42981 .65064 L .42746 .64842 L F
.688 .329 .361 r
.4335 .65064 m .42981 .65064 L .43129 .64832 L F
.645 .338 .436 r
.43368 .64862 m .4335 .65064 L .43129 .64832 L F
.582 .396 .595 r
.37683 .59786 m .37929 .59758 L .37945 .59454 L F
.517 .292 .511 r
.37929 .59758 m .38179 .59489 L .37945 .59454 L F
.629 .564 .763 r
.54289 .57634 m .54587 .57793 L .54458 .5765 L F
.917 .884 .786 r
.61868 .47797 m .6221 .47545 L .62089 .47475 L F
.61868 .47797 m .61991 .4791 L .6221 .47545 L F
.837 .833 .843 r
.6221 .47545 m .62262 .47199 L .62089 .47475 L F
.6221 .47545 m .62448 .47289 L .62262 .47199 L F
.807 .899 .907 r
.62937 .43665 m .6294 .43357 L .62952 .43554 L F
.62937 .43665 m .6269 .43828 L .6261 .43691 L F
.561 .256 .408 r
.56224 .53158 m .55989 .52988 L .55969 .53181 L F
.611 .479 .676 r
.55989 .52988 m .56245 .52966 L .56215 .52656 L F
.555 .259 .42 r
.56224 .53158 m .56245 .52966 L .55989 .52988 L F
.577 .773 .972 r
.53537 .54619 m .53571 .54746 L .5331 .54752 L F
.53537 .54619 m .5331 .54752 L .5327 .54944 L F
.949 .912 .746 r
.6269 .43828 m .6249 .43831 L .6261 .43691 L F
.673 .795 .94 r
.72228 .39421 m .7187 .39372 L .7212 .39275 L F
.644 .802 .959 r
.7247 .39325 m .72228 .39421 L .7212 .39275 L F
.586 .879 .573 r
.53772 .5023 m .54055 .49939 L .54042 .49966 L F
.578 .884 .594 r
.54055 .49939 m .54181 .49807 L .54042 .49966 L F
.695 .797 .928 r
.68009 .40621 m .6851 .40645 L .6838 .40634 L F
.46 .888 .867 r
.6851 .40645 m .68647 .40582 L .6838 .40634 L F
.6851 .40645 m .68683 .40575 L .68647 .40582 L F
.515 0 0 r
.68394 .40637 m .68647 .40582 L .68627 .40676 L F
.6838 .40634 m .68647 .40582 L .68394 .40637 L F
.46 .888 .867 r
.68683 .40575 m .68734 .40554 L .68647 .40582 L F
.927 .963 .773 r
.66297 .42688 m .66367 .4282 L .66475 .42642 L F
.982 .852 .47 r
.66296 .43168 m .66367 .4282 L .66297 .42688 L F
.724 .988 .878 r
.20685 .66354 m .20661 .66283 L .20904 .66195 L F
.772 .536 0 r
.20685 .66354 m .20699 .66518 L .20661 .66283 L F
.531 .258 .446 r
.46543 .6385 m .46263 .64174 L .46293 .63961 L F
.46543 .6385 m .46523 .64148 L .46263 .64174 L F
0 0 .296 r
.46584 .6388 m .46523 .64148 L .46543 .6385 L F
.525 .391 .64 r
.46283 .63662 m .46293 .63961 L .46584 .6388 L F
0 0 0 r
.67097 .40791 m .67287 .40749 L .67517 .40724 L F
.155 0 .23 r
.66924 .39783 m .66745 .39938 L .66885 .39903 L F
.313 .409 .8 r
.66745 .39938 m .6702 .40074 L .66885 .39903 L F
.878 .518 .363 r
.42456 .60398 m .42279 .60527 L .42266 .60364 L F
.82 .883 .89 r
.42456 .60398 m .42523 .60068 L .42687 .60346 L F
.42456 .60398 m .42266 .60364 L .42523 .60068 L F
.683 .351 .408 r
.42687 .60346 m .42279 .60527 L .42456 .60398 L F
.025 0 0 r
.19566 .70476 m .19903 .70258 L .19702 .70391 L F
.892 .931 .837 r
.19702 .70391 m .19903 .70258 L .19961 .70073 L F
.102 0 0 r
.1995 .70236 m .19702 .70391 L .19961 .70073 L F
.19943 .70346 m .19702 .70391 L .1995 .70236 L F
.025 0 0 r
.19566 .70476 m .19566 .70476 L .19702 .70391 L F
.108 0 0 r
.1936 .55624 m .19055 .55702 L .19188 .55726 L F
.997 .857 .558 r
.76736 .41619 m .76825 .41739 L .76816 .4157 L F
.962 .91 .718 r
.76637 .4182 m .76825 .41739 L .76736 .41619 L F
.76637 .4182 m .76718 .41945 L .76825 .41739 L F
.431 .754 .995 r
.18217 .63807 m .18177 .63939 L .18011 .63831 L F
.351 .671 .976 r
.18217 .63807 m .18369 .63937 L .18177 .63939 L F
.119 .654 .861 r
.22761 .54137 m .22983 .54142 L .23155 .54183 L F
.311 .785 .926 r
.22983 .54142 m .23372 .54141 L .23155 .54183 L F
.707 .752 .887 r
.43069 .56165 m .43046 .5619 L .43391 .5616 L F
0 0 .004 r
.43391 .5616 m .43279 .5642 L .43449 .56306 L F
.484 .513 .812 r
.37418 .61645 m .37588 .61916 L .37742 .61822 L F
0 .49 .802 r
.54896 .59336 m .55087 .59381 L .55236 .5945 L F
.58 .414 .621 r
.55236 .5945 m .55276 .59785 L .55003 .59822 L F
.478 .853 .986 r
.55236 .5945 m .55326 .5932 L .55487 .59412 L F
.55236 .5945 m .55087 .59381 L .55326 .5932 L F
.492 .351 .617 r
.55495 .59709 m .55236 .5945 L .55487 .59412 L F
.55495 .59709 m .55276 .59785 L .55236 .5945 L F
.845 .864 .856 r
.72874 .40851 m .73005 .40456 L .72711 .40479 L F
.72874 .40851 m .73152 .40571 L .73005 .40456 L F
.795 .722 .783 r
.18324 .66063 m .18344 .66038 L .18306 .66031 L F
0 .005 .57 r
.46005 .56929 m .46072 .56817 L .45831 .56653 L F
.626 .207 .229 r
.46072 .56817 m .45974 .56826 L .45831 .56653 L F
.039 .109 .609 r
.45677 .56468 m .45723 .56839 L .45831 .56653 L F
.355 .525 .886 r
.45723 .56839 m .46005 .56929 L .45831 .56653 L F
.626 .207 .229 r
.45974 .56826 m .45641 .56855 L .45831 .56653 L F
.039 .109 .609 r
.45677 .56468 m .45677 .56468 L .45831 .56653 L F
.563 .297 .47 r
.45723 .56839 m .45696 .57054 L .46005 .56929 L F
.853 .639 .1 r
.53879 .54847 m .53922 .55275 L .53921 .55049 L F
.666 .871 .976 r
.18344 .66038 m .18155 .65901 L .18306 .66031 L F
.18344 .66038 m .18332 .65862 L .18155 .65901 L F
.56 .282 .451 r
.55003 .59822 m .5498 .6003 L .54724 .60055 L F
.531 .254 .439 r
.55003 .59822 m .55234 .59996 L .5498 .6003 L F
.55003 .59822 m .55276 .59785 L .55234 .59996 L F
.451 .411 .722 r
.37381 .6127 m .37512 .60886 L .37304 .61023 L F
.445 .326 .624 r
.24312 .56787 m .24483 .56471 L .24287 .56532 L F
.349 .615 .95 r
.26193 .54758 m .26155 .54935 L .25872 .54702 L F
.26193 .54758 m .26321 .54929 L .26155 .54935 L F
.441 .341 .645 r
.23395 .59458 m .23545 .59169 L .23323 .59226 L F
.23395 .59458 m .23584 .59423 L .23545 .59169 L F
.411 .188 .463 r
.23339 .59728 m .23584 .59423 L .23395 .59458 L F
.694 .53 .661 r
.55135 .53523 m .55374 .53222 L .55128 .53268 L F
.793 .532 .543 r
.5479 .53425 m .55135 .53523 L .55128 .53268 L F
.573 .406 .617 r
.56092 .55022 m .55844 .55314 L .55802 .55053 L F
.999 .8 .461 r
.65716 .43079 m .65773 .43464 L .65663 .43385 L F
0 0 .319 r
.65773 .43464 m .65842 .4356 L .65663 .43385 L F
.797 .999 .841 r
.66297 .42688 m .66475 .42642 L .6657 .42438 L F
0 .436 .718 r
.17097 .56269 m .17116 .56264 L .16888 .56367 L F
.17097 .56269 m .17261 .56309 L .17116 .56264 L F
.268 .135 .508 r
.44537 .56767 m .44543 .56751 L .44929 .56551 L F
.604 .415 .599 r
.44477 .56847 m .44337 .56747 L .44537 .56767 L F
.268 .135 .508 r
.44458 .5681 m .44543 .56751 L .44537 .56767 L F
.44458 .5681 m .44537 .56767 L .44558 .56739 L F
.44537 .56767 m .44929 .56551 L .44558 .56739 L F
.604 .415 .599 r
.44537 .56767 m .44337 .56747 L .44548 .56739 L F
.44499 .56862 m .44477 .56847 L .44537 .56767 L F
.4459 .56927 m .44499 .56862 L .44558 .56739 L F
.44499 .56862 m .44548 .56739 L .44558 .56739 L F
.268 .135 .508 r
.44458 .5681 m .44505 .56771 L .44543 .56751 L F
.4448 .56784 m .44565 .56728 L .44929 .56551 L F
.514 .057 .106 r
.44929 .56551 m .44565 .56728 L .44722 .56487 L F
.268 .135 .508 r
.44565 .56728 m .44844 .56545 L .44929 .56551 L F
.514 .057 .106 r
.44929 .56551 m .44558 .56739 L .44565 .56728 L F
.49 .542 .837 r
.44546 .56736 m .44458 .5681 L .44558 .56739 L F
.183 0 0 r
.44722 .56487 m .44565 .56728 L .44445 .56738 L F
.44455 .56668 m .44445 .56738 L .44337 .56747 L F
.44722 .56487 m .44445 .56738 L .44455 .56668 L F
.092 .56 .907 r
.44337 .56747 m .44193 .56645 L .43997 .56601 L F
.982 .736 .486 r
.44337 .56747 m .44338 .57003 L .44193 .56645 L F
.604 .415 .599 r
.4459 .56927 m .44338 .57003 L .44337 .56747 L F
.49 .542 .837 r
.44193 .56645 m .44338 .57003 L .44458 .5681 L F
.529 0 0 r
.44437 .56797 m .44052 .56659 L .44193 .56645 L F
.44458 .5681 m .44436 .56802 L .44437 .56797 L F
.44436 .56802 m .44052 .56659 L .44437 .56797 L F
.183 0 0 r
.44565 .56728 m .44548 .56739 L .44337 .56747 L F
.422 .67 .964 r
.44548 .56739 m .44193 .56645 L .44337 .56747 L F
.183 0 0 r
.44565 .56728 m .44558 .56739 L .44548 .56739 L F
.422 .67 .964 r
.44558 .56739 m .44546 .56736 L .44548 .56739 L F
.268 .135 .508 r
.44548 .56739 m .44685 .56534 L .44844 .56545 L F
.44546 .56736 m .44685 .56534 L .44548 .56739 L F
.422 .67 .964 r
.44477 .56718 m .44564 .56655 L .44193 .56645 L F
.44546 .56736 m .44557 .5669 L .44477 .56718 L F
.44557 .5669 m .44564 .56655 L .44477 .56718 L F
.268 .135 .508 r
.44536 .56715 m .44557 .5669 L .44546 .56736 L F
.44557 .5669 m .44685 .56534 L .44546 .56736 L F
.422 .67 .964 r
.44558 .56739 m .44562 .56688 L .44546 .56736 L F
.44562 .56688 m .44564 .56655 L .44557 .5669 L F
.44562 .56688 m .44557 .5669 L .44546 .56736 L F
0 0 .097 r
.44685 .56534 m .44558 .56739 L .44929 .56551 L F
.627 .37 .51 r
.44929 .56551 m .44694 .56811 L .44558 .56739 L F
.44694 .56811 m .4459 .56927 L .4457 .56809 L F
.44694 .56811 m .4457 .56809 L .44558 .56739 L F
.268 .135 .508 r
.44458 .5681 m .44658 .5679 L .44673 .56649 L F
0 0 .097 r
.44685 .56534 m .44626 .56666 L .44558 .56739 L F
.268 .135 .508 r
.44557 .5669 m .44626 .56666 L .44685 .56534 L F
.44626 .56666 m .44673 .56649 L .44685 .56534 L F
.44685 .56534 m .44673 .56649 L .44557 .5669 L F
0 0 .097 r
.44685 .56534 m .44634 .56657 L .44626 .56666 L F
.268 .135 .508 r
.44685 .56534 m .44557 .5669 L .44634 .56657 L F
.422 .67 .964 r
.44562 .56688 m .44634 .56657 L .44564 .56655 L F
.44558 .56739 m .44634 .56657 L .44562 .56688 L F
.44546 .56736 m .44486 .5672 L .44548 .56739 L F
.44486 .5672 m .44193 .56645 L .44479 .56721 L F
.44486 .5672 m .44479 .56721 L .44548 .56739 L F
.49 .542 .837 r
.44308 .56727 m .44558 .56739 L .44337 .56747 L F
.44193 .56645 m .44477 .56718 L .44308 .56727 L F
.44477 .56718 m .44558 .56739 L .44308 .56727 L F
.268 .135 .508 r
.44536 .56715 m .44673 .56649 L .44557 .5669 L F
.49 .542 .837 r
.44477 .56718 m .44458 .5681 L .44546 .56736 L F
.44193 .56645 m .44458 .5681 L .44477 .56718 L F
.268 .135 .508 r
.4448 .56784 m .44536 .56715 L .44548 .56739 L F
.44458 .5681 m .4448 .56784 L .44505 .56771 L F
.44458 .5681 m .44588 .56713 L .44536 .56715 L F
.44588 .56713 m .44673 .56649 L .44536 .56715 L F
.44673 .56649 m .44658 .5679 L .44557 .5669 L F
.44557 .5669 m .44536 .56715 L .44634 .56657 L F
.44557 .5669 m .44658 .5679 L .44458 .5681 L F
.44536 .56715 m .44458 .5681 L .44572 .56712 L F
.44536 .56715 m .44572 .56712 L .44634 .56657 L F
.529 0 0 r
.44458 .5681 m .44193 .56645 L .44634 .56657 L F
.44187 .56709 m .44274 .56798 L .44052 .56659 L F
.44458 .5681 m .44274 .56798 L .44187 .56709 L F
.562 .37 .579 r
.4459 .56927 m .44336 .57334 L .44338 .57003 L F
0 0 .201 r
.44338 .57003 m .44385 .57059 L .44458 .5681 L F
.44385 .57059 m .44403 .5708 L .44418 .57005 L F
.44385 .57059 m .44418 .57005 L .44458 .5681 L F
.627 .37 .51 r
.44929 .56551 m .45094 .5687 L .4459 .56927 L F
.261 .027 .358 r
.45176 .56683 m .45094 .5687 L .44929 .56551 L F
.634 .169 .133 r
.44961 .56518 m .45176 .56683 L .44929 .56551 L F
.426 0 .118 r
.44658 .5679 m .45035 .56582 L .44685 .56534 L F
.804 .569 .582 r
.45035 .56582 m .44854 .56581 L .44685 .56534 L F
.514 .057 .106 r
.44929 .56551 m .44722 .56487 L .44961 .56518 L F
.477 .761 .993 r
.44685 .56534 m .44854 .56581 L .44767 .56395 L F
0 0 .29 r
.44797 .5651 m .44658 .5679 L .44685 .56534 L F
.807 .974 .902 r
.44797 .5651 m .44613 .56688 L .44658 .5679 L F
.758 .473 .502 r
.44274 .56798 m .44658 .5679 L .44489 .56807 L F
.98 .693 .395 r
.44458 .5681 m .4445 .56849 L .44274 .56798 L F
.4445 .56849 m .44403 .5708 L .44347 .56958 L F
.4445 .56849 m .44347 .56958 L .44274 .56798 L F
0 0 .384 r
.44338 .57003 m .44233 .57394 L .44097 .57047 L F
.689 .361 .415 r
.4372 .57237 m .44097 .57047 L .43869 .5728 L F
.4372 .57237 m .43957 .57268 L .44097 .57047 L F
.737 .533 .617 r
.43957 .57268 m .44338 .57003 L .44097 .57047 L F
.674 .192 .097 r
.44316 .56991 m .44121 .57135 L .43908 .56936 L F
0 0 .384 r
.44338 .57003 m .44336 .57334 L .44233 .57394 L F
.737 .533 .617 r
.43957 .57268 m .44336 .57334 L .44338 .57003 L F
0 0 .201 r
.44338 .57003 m .44336 .57334 L .44403 .5708 L F
.219 0 .247 r
.44458 .5681 m .44403 .5708 L .44658 .5679 L F
.872 .869 .831 r
.44658 .5679 m .44491 .56979 L .44379 .56914 L F
.44491 .56979 m .44403 .5708 L .4439 .56989 L F
.44491 .56979 m .4439 .56989 L .44379 .56914 L F
.562 .37 .579 r
.4459 .56927 m .44592 .57286 L .44336 .57334 L F
.549 .291 .477 r
.45094 .5687 m .44592 .57286 L .4459 .56927 L F
.473 .295 .558 r
.4439 .56989 m .44653 .57054 L .44379 .56914 L F
0 .116 .655 r
.44379 .56914 m .44449 .57008 L .44374 .56918 L F
.44379 .56914 m .44374 .56918 L .44274 .56798 L F
.758 .473 .502 r
.44373 .56805 m .44489 .56807 L .44458 .5681 L F
.44274 .56798 m .44489 .56807 L .44373 .56805 L F
.807 .318 .006 r
.44458 .5681 m .44379 .56914 L .44274 .56798 L F
.758 .473 .502 r
.44274 .56798 m .44379 .56914 L .44658 .5679 L F
.807 .974 .902 r
.44613 .56688 m .44379 .56914 L .4451 .56855 L F
.44613 .56688 m .4451 .56855 L .44658 .5679 L F
0 0 0 r
.44623 .56678 m .44596 .56755 L .44379 .56914 L F
.44797 .5651 m .44596 .56755 L .44623 .56678 L F
.749 .456 .487 r
.44379 .56914 m .44653 .57054 L .44658 .5679 L F
.713 .472 .56 r
.44671 .56901 m .4458 .56802 L .44596 .56755 L F
.423 .82 .602 r
.44596 .56755 m .44434 .56868 L .44379 .56914 L F
.44434 .56868 m .44387 .56901 L .44379 .56914 L F
.801 .665 .714 r
.44374 .56918 m .44289 .56814 L .44274 .56798 L F
.44449 .57008 m .44374 .56918 L .44374 .56918 L F
.44374 .56918 m .44289 .56814 L .44374 .56918 L F
.316 .806 .824 r
.43997 .56601 m .43605 .56687 L .43748 .56596 L F
.43749 .56656 m .43825 .56621 L .43605 .56687 L F
.43997 .56601 m .43825 .56621 L .43749 .56656 L F
.333 0 0 r
.44193 .56645 m .43825 .56621 L .43997 .56601 L F
.997 .816 .539 r
.439 .56587 m .43825 .56621 L .44052 .56659 L F
.43709 .56497 m .43825 .56621 L .439 .56587 L F
.283 0 0 r
.43969 .56631 m .44052 .56659 L .43825 .56621 L F
.44193 .56645 m .44052 .56659 L .43969 .56631 L F
0 .305 .798 r
.44052 .56659 m .44274 .56798 L .44204 .56711 L F
.44052 .56659 m .44204 .56711 L .44092 .56573 L F
.801 .665 .714 r
.44289 .56814 m .44092 .56573 L .44274 .56798 L F
.44449 .57008 m .44432 .57006 L .44092 .56573 L F
.44432 .57006 m .43908 .56936 L .44066 .56624 L F
.44432 .57006 m .44066 .56624 L .44092 .56573 L F
.616 .232 .294 r
.4415 .56992 m .44133 .5708 L .43908 .56936 L F
.44133 .5708 m .44121 .57135 L .44091 .57108 L F
.44133 .5708 m .44091 .57108 L .43908 .56936 L F
0 0 .302 r
.44092 .56573 m .4415 .56992 L .44193 .56712 L F
.915 .924 .806 r
.44133 .5708 m .44193 .56712 L .4415 .56992 L F
.44121 .57135 m .44132 .57079 L .44133 .5708 L F
.98 .821 .614 r
.44379 .56914 m .44132 .57079 L .44121 .57135 L F
.44132 .57079 m .44073 .57119 L .44121 .57135 L F
.915 .924 .806 r
.44121 .57135 m .44131 .57079 L .44132 .57079 L F
.44131 .57079 m .44193 .56712 L .44133 .5708 L F
.423 .82 .602 r
.44387 .56901 m .4413 .57079 L .44216 .57023 L F
.621 .444 .622 r
.43908 .56936 m .4415 .56992 L .44092 .56573 L F
.915 .924 .806 r
.44131 .57079 m .44073 .57119 L .44193 .56712 L F
.423 .82 .602 r
.44131 .57079 m .44073 .57119 L .44132 .57079 L F
.915 .924 .806 r
.44121 .57135 m .44073 .57119 L .44131 .57079 L F
.423 .82 .602 r
.4413 .57079 m .44073 .57119 L .44131 .57079 L F
.4413 .57079 m .44132 .57079 L .44216 .57023 L F
.44378 .56913 m .44216 .57023 L .44375 .56916 L F
.44387 .56901 m .44216 .57023 L .44378 .56913 L F
.44387 .56901 m .44375 .56916 L .44379 .56914 L F
.692 .24 .172 r
.44542 .56479 m .44193 .56712 L .44596 .56755 L F
.76 .754 .846 r
.44193 .56712 m .44073 .57119 L .44596 .56755 L F
.713 .472 .56 r
.4458 .56802 m .44457 .56668 L .44596 .56755 L F
.473 .295 .558 r
.44403 .5708 m .44493 .57071 L .4439 .56989 L F
.44493 .57071 m .4457 .57063 L .44432 .57006 L F
.44493 .57071 m .44432 .57006 L .4439 .56989 L F
.674 .192 .097 r
.44449 .57008 m .44443 .57011 L .44434 .57007 L F
.473 .295 .558 r
.4457 .57063 m .44653 .57054 L .4439 .56989 L F
.674 .192 .097 r
.44434 .57007 m .44213 .571 L .44311 .56997 L F
.44443 .57011 m .44213 .571 L .44434 .57007 L F
.4434 .56994 m .44311 .56997 L .44316 .56991 L F
.44449 .57008 m .44311 .56997 L .4434 .56994 L F
.44213 .571 m .44121 .57135 L .44316 .56991 L F
.344 .1 .393 r
.18344 .55775 m .18197 .55656 L .18537 .55634 L F
.18344 .55775 m .18159 .55886 L .18197 .55656 L F
.492 .705 .965 r
.26499 .54912 m .26445 .55106 L .26321 .54929 L F
.26499 .54912 m .26631 .55048 L .26445 .55106 L F
.734 .674 .791 r
.54001 .56518 m .5426 .5662 L .54248 .56266 L F
.293 .314 .712 r
.54248 .56266 m .5426 .5662 L .54418 .56406 L F
.028 .313 .801 r
.5426 .5662 m .54447 .56645 L .54418 .56406 L F
.406 .821 .973 r
.6761 .39782 m .67339 .39836 L .67244 .39783 L F
.743 .854 .417 r
.42106 .60543 m .41904 .60957 L .41926 .60944 L F
.669 .807 .949 r
.47134 .56312 m .46758 .56284 L .47038 .56257 L F
.56 .836 .997 r
.47228 .56169 m .47134 .56312 L .47038 .56257 L F
.47228 .56169 m .47323 .56259 L .47134 .56312 L F
.22 0 .152 r
.20762 .63313 m .20967 .63277 L .21054 .63054 L F
0 0 .175 r
.21054 .63054 m .21187 .62964 L .21247 .62728 L F
0 0 .05 r
.21054 .63054 m .2111 .63186 L .21187 .62964 L F
.21054 .63054 m .20967 .63277 L .2111 .63186 L F
.881 .929 .849 r
.68171 .4497 m .67951 .45252 L .67872 .45125 L F
.601 .131 .111 r
.67951 .45252 m .67811 .45383 L .67872 .45125 L F
.67951 .45252 m .68174 .45397 L .67811 .45383 L F
.4 .172 .449 r
.26751 .58773 m .26594 .58601 L .26815 .58542 L F
.26751 .58773 m .26548 .58845 L .26594 .58601 L F
.227 0 .109 r
.39602 .58882 m .3984 .58795 L .39887 .5871 L F
.39602 .58882 m .39627 .58881 L .3984 .58795 L F
.257 0 0 r
.46923 .63705 m .46584 .6388 L .46543 .6385 L F
0 0 0 r
.54565 .49385 m .54717 .49248 L .54834 .49108 L F
.54565 .49385 m .54478 .49561 L .54717 .49248 L F
.483 0 0 r
.48418 .58 m .47975 .58044 L .48148 .58252 L F
0 0 .332 r
.48148 .58252 m .48241 .58126 L .48426 .58306 L F
.48148 .58252 m .48295 .58465 L .48241 .58126 L F
.48148 .58252 m .48211 .58697 L .48276 .58517 L F
.661 .869 .491 r
.48211 .58697 m .48137 .58792 L .48174 .58728 L F
.561 .67 .911 r
.48207 .58675 m .47629 .58414 L .47801 .58265 L F
.661 .869 .491 r
.48211 .58697 m .48174 .58728 L .48226 .58645 L F
.561 .67 .911 r
.48233 .587 m .48201 .58685 L .48207 .58675 L F
.48201 .58685 m .47629 .58414 L .48207 .58675 L F
0 0 .332 r
.48267 .58425 m .48276 .58517 L .48295 .58465 L F
.48148 .58252 m .48276 .58517 L .48267 .58425 L F
.661 .869 .491 r
.48211 .58697 m .48226 .58646 L .48295 .58465 L F
.887 .971 .66 r
.48295 .58465 m .48251 .58633 L .48236 .58619 L F
.48251 .58633 m .48233 .587 L .48236 .58619 L F
.48295 .58465 m .48212 .5868 L .47801 .58265 L F
.661 .869 .491 r
.48226 .58646 m .4823 .5863 L .48295 .58465 L F
.887 .971 .66 r
.48295 .58465 m .4823 .5863 L .48233 .587 L F
.74 .572 .666 r
.48504 .58911 m .4823 .5863 L .48291 .58671 L F
.48402 .58775 m .48291 .58671 L .48358 .58717 L F
.48504 .58911 m .48291 .58671 L .48402 .58775 L F
.887 .971 .66 r
.48236 .58619 m .48233 .587 L .48212 .5868 L F
.661 .869 .491 r
.48226 .58645 m .48201 .58685 L .4823 .5863 L F
.561 .67 .911 r
.48181 .58716 m .47877 .58807 L .48201 .58685 L F
.661 .869 .491 r
.48201 .58685 m .48174 .58728 L .48181 .58716 L F
.48201 .58685 m .48181 .58716 L .4823 .5863 L F
.561 .67 .911 r
.48201 .58685 m .47877 .58807 L .47629 .58414 L F
.48233 .587 m .48181 .58716 L .48201 .58685 L F
0 0 0 r
.48233 .587 m .47622 .58894 L .47877 .58807 L F
.48233 .587 m .48024 .58774 L .47622 .58894 L F
.47929 .58803 m .47852 .58834 L .47657 .58885 L F
.48024 .58774 m .47657 .58885 L .47622 .58894 L F
.77 .757 .842 r
.47629 .58414 m .47877 .58807 L .47426 .58767 L F
.346 .133 .441 r
.47622 .58894 m .47426 .58767 L .47877 .58807 L F
0 0 .251 r
.47693 .58958 m .47714 .58936 L .47714 .58902 L F
.635 .522 .708 r
.47399 .58338 m .47426 .58767 L .4715 .58763 L F
.576 .307 .471 r
.47426 .58767 m .47146 .58998 L .4715 .58763 L F
.77 .757 .842 r
.47629 .58414 m .47426 .58767 L .47399 .58338 L F
.576 .307 .471 r
.47426 .58767 m .47429 .5897 L .47146 .58998 L F
.346 .133 .441 r
.47622 .58894 m .47429 .5897 L .47426 .58767 L F
.359 .16 .469 r
.47622 .58894 m .47418 .59208 L .47429 .5897 L F
.719 .61 .735 r
.47145 .5878 m .47595 .58926 L .47609 .58508 L F
0 0 0 r
.47803 .58858 m .47668 .58882 L .47852 .58834 L F
.47696 .58893 m .47668 .58882 L .47803 .58858 L F
.391 .281 .608 r
.47716 .5849 m .47714 .589 L .47967 .58722 L F
.47714 .589 m .47714 .58936 L .47771 .58888 L F
0 0 0 r
.47718 .58899 m .47696 .58893 L .47803 .58858 L F
.116 .358 .821 r
.47818 .58849 m .47748 .58878 L .47801 .58859 L F
.47748 .58878 m .47697 .58899 L .47743 .58881 L F
.47748 .58878 m .47743 .58881 L .47801 .58859 L F
.391 .281 .608 r
.47714 .589 m .47718 .58899 L .47967 .58722 L F
.116 .358 .821 r
.47852 .58834 m .47967 .58722 L .4774 .58871 L F
.47852 .58834 m .4774 .58871 L .47727 .58886 L F
.391 .281 .608 r
.47718 .58899 m .47771 .58888 L .47967 .58722 L F
0 0 0 r
.47715 .589 m .47714 .589 L .47718 .58899 L F
.47714 .589 m .47696 .58893 L .47718 .58899 L F
0 0 .251 r
.47682 .58898 m .47716 .5849 L .47609 .58508 L F
.47693 .58958 m .47696 .58893 L .47682 .58898 L F
.47696 .58893 m .47716 .5849 L .47682 .58898 L F
.47696 .58893 m .47714 .589 L .47716 .5849 L F
.47695 .58925 m .47714 .589 L .47696 .58893 L F
.116 .358 .821 r
.47801 .58859 m .47697 .58899 L .47637 .58938 L F
.47852 .58834 m .47818 .58849 L .47801 .58859 L F
.719 .61 .735 r
.47595 .58926 m .47659 .58947 L .47682 .58898 L F
.47659 .58947 m .47693 .58958 L .47688 .5893 L F
.47659 .58947 m .47688 .5893 L .47682 .58898 L F
0 0 0 r
.47654 .58907 m .47622 .58894 L .47668 .58882 L F
.47629 .58915 m .47622 .58894 L .47654 .58907 L F
.719 .61 .735 r
.47595 .58926 m .47682 .58898 L .47609 .58508 L F
0 0 0 r
.47637 .58938 m .47629 .58915 L .47654 .58907 L F
.47637 .58938 m .47668 .58882 L .47715 .589 L F
0 0 .251 r
.47695 .58925 m .47714 .58902 L .47714 .589 L F
.47693 .58958 m .47714 .58902 L .47695 .58925 L F
.116 .358 .821 r
.47727 .58886 m .4774 .58871 L .47697 .58899 L F
0 0 0 r
.48024 .58774 m .47852 .58834 L .47929 .58803 L F
.74 .572 .666 r
.48293 .58695 m .48032 .58954 L .48169 .5873 L F
.864 .75 .735 r
.4823 .5863 m .47852 .58834 L .48233 .587 L F
.74 .572 .666 r
.48292 .58693 m .48169 .5873 L .4823 .5863 L F
.48293 .58695 m .48169 .5873 L .48292 .58693 L F
.48504 .58911 m .48316 .58928 L .48293 .58695 L F
.48316 .58928 m .48032 .58954 L .48293 .58695 L F
.347 .716 .985 r
.24782 .54242 m .24747 .54364 L .2456 .5421 L F
.24782 .54242 m .24957 .54357 L .24747 .54364 L F
.465 .216 .452 r
.37683 .59786 m .37877 .59964 L .37929 .59758 L F
.37683 .59786 m .37646 .60031 L .37877 .59964 L F
.311 .756 .962 r
.19766 .5567 m .19621 .55607 L .1936 .55624 L F
.76 .936 .943 r
.1981 .55466 m .19766 .5567 L .19966 .555 L F
.1981 .55466 m .19621 .55607 L .19766 .5567 L F
.668 .804 .948 r
.71329 .45282 m .71568 .45178 L .71215 .45135 L F
.658 .611 .791 r
.70818 .44551 m .70465 .4431 L .70841 .44377 L F
.908 .777 .705 r
.54439 .52016 m .5427 .51691 L .54262 .51834 L F
.95 .815 .676 r
.54299 .52338 m .54439 .52016 L .54262 .51834 L F
.481 .841 .586 r
.18159 .55886 m .17862 .56128 L .18018 .56004 L F
.033 0 .007 r
.57039 .46678 m .5725 .46596 L .57321 .46413 L F
.273 0 .251 r
.57039 .46678 m .5723 .46811 L .5725 .46596 L F
.57039 .46678 m .57016 .46905 L .5723 .46811 L F
.779 .349 .229 r
.63555 .42213 m .63876 .42273 L .63746 .42429 L F
.963 .658 .4 r
.63746 .42429 m .63876 .42273 L .63882 .42534 L F
.157 0 .361 r
.57321 .46413 m .57509 .46325 L .57515 .46066 L F
.401 .132 .388 r
.5725 .46596 m .57509 .46325 L .57321 .46413 L F
.808 .58 .593 r
.46212 .59677 m .46611 .59776 L .46593 .5949 L F
.125 .065 .511 r
.46593 .5949 m .46736 .59758 L .46611 .59776 L F
.46593 .5949 m .46736 .59758 L .46611 .59776 L F
.937 .593 .165 r
.5361 .58208 m .53735 .58503 L .5371 .58303 L F
.96 .911 .723 r
.53771 .57873 m .5361 .58208 L .5371 .58303 L F
.61 .305 .428 r
.53735 .58503 m .53982 .58529 L .5371 .58303 L F
.937 .593 .165 r
.5361 .58208 m .53735 .58503 L .5371 .58303 L F
.61 .305 .428 r
.53735 .58503 m .53982 .58529 L .5371 .58303 L F
.446 .097 .279 r
.23538 .58213 m .23905 .57967 L .23678 .57994 L F
.787 .481 .471 r
.21667 .61147 m .22171 .61014 L .21754 .60933 L F
.387 .124 .389 r
.22171 .61014 m .22321 .61163 L .22375 .60939 L F
.239 .751 .74 r
.20191 .55374 m .1981 .55466 L .20004 .55344 L F
.139 0 .005 r
.58086 .45561 m .57781 .45794 L .58006 .45687 L F
.238 0 .06 r
.58086 .45561 m .58284 .45585 L .58302 .45463 L F
.58086 .45561 m .58006 .45687 L .58284 .45585 L F
.919 .549 .121 r
.53161 .59795 m .53107 .59872 L .53055 .59697 L F
.53161 .59795 m .53194 .59949 L .53107 .59872 L F
.607 .306 .433 r
.18932 .68066 m .19251 .68084 L .19367 .6786 L F
0 0 0 r
.19367 .6786 m .19338 .67938 L .19486 .67737 L F
.19367 .6786 m .19251 .68084 L .19338 .67938 L F
.406 .263 .572 r
.55844 .55314 m .55841 .55587 L .55629 .55655 L F
.438 .351 .66 r
.55841 .55587 m .55882 .55837 L .55629 .55655 L F
.411 .354 .684 r
.55629 .55655 m .55882 .55837 L .55701 .55894 L F
.271 0 .007 r
.1608 .54992 m .16294 .54947 L .16465 .54749 L F
.125 0 0 r
.16294 .54947 m .16708 .54727 L .16465 .54749 L F
.894 .944 .834 r
.51903 .53723 m .51675 .53889 L .51962 .53459 L F
.888 .94 .842 r
.66919 .42003 m .67067 .41617 L .66846 .41881 L F
.66919 .42003 m .6716 .41714 L .67067 .41617 L F
.984 .899 .641 r
.66748 .42102 m .66919 .42003 L .66846 .41881 L F
0 0 0 r
.55332 .48526 m .55485 .48396 L .55578 .48225 L F
.55277 .48687 m .55485 .48396 L .55332 .48526 L F
.54834 .49108 m .54984 .48982 L .55102 .48851 L F
.54834 .49108 m .54717 .49248 L .54984 .48982 L F
.204 0 .324 r
.20562 .6782 m .20502 .68072 L .20343 .68136 L F
0 0 0 r
.22064 .64821 m .21926 .65038 L .21801 .65119 L F
.21714 .65235 m .21801 .65119 L .21926 .65038 L F
.516 .628 .9 r
.2013 .6923 m .19952 .69298 L .19841 .69046 L F
0 0 .418 r
.20044 .69508 m .19952 .69298 L .2013 .6923 L F
.20044 .69508 m .20017 .69589 L .19952 .69298 L F
.443 .245 .515 r
.23147 .59792 m .23325 .59986 L .23339 .59728 L F
.23147 .59792 m .23116 .60064 L .23325 .59986 L F
.665 .363 .451 r
.64233 .42573 m .63871 .42766 L .63882 .42534 L F
.64233 .42573 m .64287 .42751 L .63871 .42766 L F
.638 .114 0 r
.64233 .42573 m .64561 .42886 L .64485 .42747 L F
.555 .3 .485 r
.64485 .42747 m .64287 .42751 L .64233 .42573 L F
.97 .846 .664 r
.61851 .48082 m .61991 .4791 L .61868 .47797 L F
.887 .802 .759 r
.62262 .47199 m .62448 .47289 L .62373 .4697 L F
.26 .763 .879 r
.19407 .70784 m .19184 .70775 L .1936 .70844 L F
.024 0 0 r
.19347 .54086 m .19571 .54069 L .19744 .54039 L F
.228 0 0 r
.19744 .54039 m .19571 .54069 L .19959 .54054 L F
.43 .422 .749 r
.27159 .57629 m .2703 .57938 L .27035 .57689 L F
.27159 .57629 m .27221 .57895 L .2703 .57938 L F
.521 .31 .534 r
.27221 .57895 m .26983 .58186 L .2703 .57938 L F
.745 .972 .709 r
.1967 .71249 m .19489 .71439 L .19617 .71361 L F
.827 .865 .874 r
.73005 .40456 m .73152 .40571 L .73303 .4041 L F
.662 .352 .437 r
.43812 .65021 m .43368 .64862 L .43732 .64841 L F
.725 .358 .355 r
.43732 .64841 m .43972 .65096 L .43812 .65021 L F
.665 .373 .467 r
.4403 .64863 m .43972 .65096 L .43732 .64841 L F
.802 .688 .739 r
.19145 .65923 m .18645 .65817 L .18917 .65964 L F
.623 .806 .97 r
.43275 .57327 m .43025 .57399 L .42918 .57253 L F
.551 .425 .661 r
.43296 .57628 m .43025 .57399 L .43275 .57327 L F
.611 .76 .95 r
.43513 .57242 m .4365 .57374 L .43275 .57327 L F
.615 .451 .636 r
.43584 .57584 m .43275 .57327 L .4365 .57374 L F
.43584 .57584 m .43296 .57628 L .43275 .57327 L F
.615 .311 .43 r
.43258 .57343 m .43513 .57242 L .43275 .57327 L F
.551 .425 .661 r
.43296 .57628 m .43074 .57721 L .4303 .5743 L F
.43296 .57628 m .4303 .5743 L .43052 .57422 L F
.615 .311 .43 r
.43063 .57526 m .43494 .57254 L .43258 .57343 L F
.43494 .57254 m .43513 .57242 L .43258 .57343 L F
.551 .425 .661 r
.43052 .57422 m .4303 .5743 L .43025 .57399 L F
.481 .737 .984 r
.69981 .453 m .70127 .45428 L .70353 .454 L F
.874 .673 .628 r
.60753 .4673 m .60699 .46885 L .60563 .467 L F
0 0 0 r
.19566 .70476 m .19439 .70745 L .19407 .70784 L F
.26 .763 .879 r
.19407 .70784 m .19439 .70745 L .19184 .70775 L F
.713 .729 .864 r
.54628 .5932 m .54205 .59191 L .54478 .5914 L F
.104 .641 .857 r
.54734 .59291 m .54628 .5932 L .54478 .5914 L F
.54734 .59291 m .54896 .59336 L .54628 .5932 L F
.893 .888 .819 r
.62663 .45979 m .62919 .45914 L .6277 .45792 L F
.62663 .45979 m .628 .46075 L .62919 .45914 L F
.633 .925 .974 r
.7186 .4498 m .72166 .44937 L .72076 .44838 L F
.826 .937 .901 r
.72076 .44838 m .72166 .44937 L .72456 .44682 L F
.699 .714 .86 r
.69157 .4544 m .69488 .45514 L .69446 .45169 L F
.735 .74 .855 r
.69446 .45169 m .69488 .45514 L .69615 .45305 L F
.487 .324 .585 r
.59553 .4399 m .59775 .43674 L .59556 .43759 L F
.326 0 .185 r
.55768 .47845 m .55983 .47798 L .56088 .47618 L F
0 0 0 r
.56088 .47618 m .55983 .47798 L .56247 .47517 L F
.2209 .64951 m .22064 .64821 L .2227 .64766 L F
.2209 .64951 m .21926 .65038 L .22064 .64821 L F
.613 .856 .989 r
.74157 .41563 m .7433 .41334 L .7406 .41235 L F
.74157 .41563 m .74469 .41455 L .7433 .41334 L F
.409 .4 .739 r
.74965 .41896 m .75071 .41512 L .74869 .416 L F
.74965 .41896 m .75144 .4202 L .75071 .41512 L F
.543 .059 0 r
.75307 .4228 m .75219 .42184 L .74965 .41896 L F
.592 .357 .529 r
.74965 .41896 m .75219 .42184 L .75144 .4202 L F
.547 .295 .486 r
.57421 .53844 m .57656 .54069 L .57347 .54101 L F
.57421 .53844 m .57684 .53802 L .57656 .54069 L F
.773 .526 .562 r
.53877 .58892 m .53501 .58607 L .53735 .58503 L F
.917 .934 .804 r
.6599 .44673 m .66123 .4429 L .65891 .44575 L F
.405 .157 .421 r
.2478 .61801 m .24747 .62095 L .24504 .6209 L F
.416 .196 .469 r
.24747 .62095 m .24505 .62387 L .24504 .6209 L F
.267 .212 .608 r
.43046 .5619 m .43095 .56752 L .43279 .5642 L F
.459 .888 .87 r
.68963 .40437 m .69291 .40347 L .69214 .40387 L F
.092 0 0 r
.69214 .40387 m .69291 .40347 L .69558 .40326 L F
.034 0 .265 r
.53117 .50861 m .53049 .51133 L .53234 .50773 L F
.815 .71 .749 r
.64028 .40551 m .63599 .40306 L .63855 .4027 L F
.64028 .40551 m .63611 .40501 L .63599 .40306 L F
.609 .552 .765 r
.63599 .40306 m .63611 .40501 L .63444 .4057 L F
0 0 0 r
.63599 .40306 m .63467 .40369 L .6373 .40267 L F
.63599 .40306 m .63782 .40247 L .63855 .4027 L F
.63599 .40306 m .6373 .40267 L .63782 .40247 L F
.609 .552 .765 r
.63599 .40306 m .63444 .4057 L .63476 .40343 L F
.63599 .40306 m .63476 .40343 L .6348 .40319 L F
.045 0 0 r
.16456 .56429 m .1606 .5657 L .16229 .56528 L F
.765 .821 .897 r
.73174 .44013 m .73301 .44173 L .73503 .44029 L F
.953 .849 .701 r
.62643 .46427 m .628 .46075 L .62663 .45979 L F
0 0 0 r
.55102 .48851 m .55161 .48851 L .55277 .48687 L F
.55102 .48851 m .54984 .48982 L .55161 .48851 L F
.754 .559 .633 r
.62762 .41613 m .62398 .41381 L .6278 .41402 L F
.62762 .41613 m .62426 .4169 L .62398 .41381 L F
.245 0 0 r
.62767 .4188 m .62426 .4169 L .62762 .41613 L F
.67 .595 .762 r
.63003 .41342 m .62762 .41613 L .6278 .41402 L F
.722 .449 .512 r
.45528 .5769 m .45509 .57979 L .45203 .57926 L F
.157 .106 .545 r
.45674 .57325 m .4568 .57608 L .45528 .5769 L F
.079 0 .361 r
.45673 .5785 m .45528 .5769 L .4568 .57608 L F
.45673 .5785 m .45509 .57979 L .45528 .5769 L F
.688 .731 .883 r
.46127 .58019 m .46319 .58309 L .45942 .58244 L F
.323 .224 .585 r
.4614 .58433 m .45942 .58244 L .46319 .58309 L F
.458 .509 .823 r
.46387 .57912 m .46319 .58309 L .46127 .58019 L F
.46387 .57912 m .46642 .58389 L .46319 .58309 L F
.352 0 0 r
.464 .58392 m .46319 .58309 L .46642 .58389 L F
.464 .58392 m .4614 .58433 L .46319 .58309 L F
0 0 0 r
.60728 .41993 m .60873 .41849 L .6093 .41671 L F
.60609 .42175 m .60873 .41849 L .60728 .41993 L F
.404 .817 .976 r
.4229 .58811 m .42598 .5865 L .42289 .58625 L F
.4229 .58811 m .42683 .5882 L .42598 .5865 L F
.085 0 .224 r
.40654 .60737 m .40592 .60936 L .40501 .60921 L F
.633 .4 .547 r
.21599 .58549 m .21839 .58547 L .21808 .58303 L F
.84 .632 .622 r
.42139 .59288 m .41808 .59407 L .41867 .59157 L F
.608 .183 .21 r
.42139 .59288 m .42041 .59427 L .41808 .59407 L F
.528 .006 0 r
.4241 .59449 m .42041 .59427 L .42139 .59288 L F
.194 .085 .493 r
.60745 .43948 m .60554 .44335 L .60493 .4399 L F
.60745 .43948 m .60759 .44242 L .60554 .44335 L F
0 0 0 r
.60759 .44242 m .6051 .44495 L .60554 .44335 L F
.68 .809 .944 r
.52243 .52939 m .52005 .53068 L .51844 .52894 L F
.51844 .52894 m .52005 .53068 L .52243 .52939 L F
.668 .195 .121 r
.62655 .43201 m .62317 .432 L .62445 .43087 L F
.575 .014 0 r
.62932 .43351 m .62655 .43201 L .62642 .43143 L F
0 0 .05 r
.62642 .43143 m .62662 .42778 L .62765 .42925 L F
.62642 .43143 m .62655 .43201 L .62662 .42778 L F
.684 .743 .896 r
.62662 .42778 m .63017 .42852 L .62765 .42925 L F
.836 .852 .857 r
.62689 .42978 m .62964 .43006 L .62781 .42838 L F
0 0 .112 r
.62662 .42778 m .62655 .43201 L .62677 .43063 L F
.62686 .42996 m .62677 .43063 L .62687 .43004 L F
.743 .684 .794 r
.6291 .42474 m .63017 .42852 L .62662 .42778 L F
.694 .981 .826 r
.62912 .42646 m .62729 .4278 L .62781 .42838 L F
0 0 .112 r
.62662 .42778 m .62672 .42963 L .6268 .42938 L F
.62662 .42778 m .62687 .43004 L .62695 .42882 L F
.62662 .42778 m .62703 .42908 L .62709 .4285 L F
.86 .912 .866 r
.6291 .42474 m .62662 .42778 L .62648 .42605 L F
0 0 .112 r
.62662 .42778 m .62708 .42848 L .62648 .42605 L F
.694 .981 .826 r
.62729 .4278 m .62704 .4286 L .62781 .42838 L F
0 0 .112 r
.62708 .42848 m .62712 .42853 L .62709 .42841 L F
.62708 .42848 m .62709 .42841 L .62648 .42605 L F
.62672 .42963 m .62677 .43063 L .6268 .42938 L F
.668 .195 .121 r
.62655 .43201 m .62538 .43006 L .62658 .43004 L F
.62655 .43201 m .6266 .42898 L .62677 .43063 L F
.836 .852 .857 r
.62592 .43123 m .62681 .43095 L .62687 .43004 L F
0 0 .112 r
.6268 .42938 m .62677 .43063 L .62686 .42996 L F
.836 .852 .857 r
.62671 .43004 m .62687 .43004 L .62689 .42978 L F
.62592 .43123 m .62687 .43004 L .62671 .43004 L F
.668 .195 .121 r
.62655 .43201 m .62445 .43087 L .62538 .43006 L F
.62658 .43004 m .62538 .43006 L .6266 .42898 L F
.935 .964 .75 r
.62667 .42965 m .62671 .43004 L .62689 .42978 L F
.362 .201 .524 r
.62579 .42968 m .62317 .432 L .62318 .43194 L F
.62661 .42897 m .6258 .42969 L .62579 .42968 L F
.6258 .42969 m .62317 .432 L .62579 .42968 L F
.668 .195 .121 r
.62655 .43201 m .62726 .43262 L .62622 .43246 L F
.62628 .43201 m .62622 .43246 L .62317 .432 L F
.62655 .43201 m .62622 .43246 L .62628 .43201 L F
.503 .776 .993 r
.62651 .43533 m .62317 .432 L .62726 .43262 L F
.362 .201 .524 r
.6266 .42898 m .62317 .432 L .62661 .42897 L F
0 0 .112 r
.62695 .42882 m .62687 .43004 L .62703 .42908 L F
.935 .964 .75 r
.62676 .42869 m .62689 .42978 L .62704 .4286 L F
.362 .201 .524 r
.62679 .42862 m .62318 .43194 L .62343 .42951 L F
.62676 .42869 m .62318 .43194 L .62679 .42862 L F
.694 .981 .826 r
.62692 .42854 m .62676 .42869 L .62704 .4286 L F
.362 .201 .524 r
.62712 .42853 m .62318 .43194 L .62685 .4286 L F
.935 .964 .75 r
.62566 .42901 m .62636 .42945 L .62676 .42869 L F
.62636 .42945 m .62689 .42978 L .62676 .42869 L F
.362 .201 .524 r
.62685 .4286 m .62676 .42869 L .62679 .42862 L F
.668 .195 .121 r
.62655 .43201 m .62726 .43262 L .62317 .432 L F
.883 .816 .778 r
.62566 .42901 m .62415 .43274 L .62606 .43379 L F
0 .303 .786 r
.62567 .43321 m .62606 .43379 L .62415 .43274 L F
.86 .654 .119 r
.62616 .4329 m .62606 .43379 L .62636 .43424 L F
.62592 .43123 m .62606 .43376 L .62616 .4329 L F
.62606 .43376 m .62606 .43379 L .62616 .4329 L F
.883 .816 .778 r
.62583 .43047 m .62606 .43379 L .62592 .43123 L F
.6259 .43186 m .62606 .43379 L .62583 .43047 L F
.87 .994 .765 r
.6294 .43357 m .62651 .43533 L .62726 .43262 L F
.575 .014 0 r
.6294 .43357 m .62655 .43201 L .62932 .43351 L F
.6294 .43357 m .62726 .43262 L .62655 .43201 L F
.75 .566 .646 r
.62651 .43533 m .63038 .43304 L .62726 .43262 L F
.86 .654 .119 r
.62592 .43123 m .62651 .43533 L .62726 .43262 L F
0 .303 .786 r
.62719 .43368 m .62606 .43379 L .62567 .43321 L F
.86 .654 .119 r
.62636 .43424 m .62606 .43379 L .62651 .43533 L F
.883 .816 .778 r
.62566 .42901 m .6259 .43186 L .62583 .43047 L F
.935 .964 .75 r
.62704 .4286 m .62689 .42978 L .62781 .42838 L F
0 0 .112 r
.62709 .4285 m .62703 .42908 L .62712 .42853 L F
.668 .195 .121 r
.62677 .43063 m .6266 .42898 L .62712 .42853 L F
.935 .964 .75 r
.62636 .42945 m .62592 .43123 L .62671 .43004 L F
.62636 .42945 m .62671 .43004 L .62667 .42965 L F
.62566 .42901 m .62583 .43047 L .62636 .42945 L F
.62583 .43047 m .62592 .43123 L .62636 .42945 L F
.362 .201 .524 r
.62712 .42853 m .6266 .42898 L .62661 .42897 L F
.26 0 .246 r
.62648 .42605 m .62709 .42841 L .62343 .42951 L F
.694 .981 .826 r
.62708 .42848 m .62694 .42853 L .62704 .4286 L F
.62694 .42853 m .62693 .42854 L .62704 .4286 L F
.26 0 .246 r
.62709 .42841 m .62712 .42853 L .62685 .4286 L F
.62709 .42841 m .62685 .4286 L .62343 .42951 L F
.694 .981 .826 r
.62694 .42853 m .62692 .42854 L .62693 .42854 L F
.62692 .42854 m .62566 .42901 L .62676 .42869 L F
.62729 .4278 m .62713 .42793 L .62708 .42848 L F
.62713 .42793 m .62566 .42901 L .62708 .42848 L F
.836 .852 .857 r
.62681 .43095 m .62964 .43006 L .62689 .42978 L F
.62681 .43095 m .62726 .43262 L .62964 .43006 L F
.62592 .43123 m .62669 .43203 L .62681 .43095 L F
.62669 .43203 m .62726 .43262 L .62681 .43095 L F
.87 .994 .765 r
.6294 .43357 m .6261 .43691 L .62651 .43533 L F
.841 .454 .317 r
.19829 .68372 m .19953 .68576 L .20062 .68409 L F
.98 .862 .482 r
.19953 .68576 m .19979 .68668 L .20062 .68409 L F
.786 .875 .912 r
.20139 .68125 m .20062 .68409 L .20292 .68251 L F
.20139 .68125 m .19829 .68372 L .20062 .68409 L F
.98 .862 .482 r
.19953 .68576 m .19979 .68668 L .20062 .68409 L F
.665 .114 0 r
.50467 .55103 m .5041 .55147 L .5021 .54937 L F
.50467 .55103 m .50588 .55227 L .5041 .55147 L F
.181 0 .097 r
.61675 .40813 m .614 .41049 L .61631 .40938 L F
.363 0 .165 r
.61675 .40813 m .61631 .40938 L .61884 .40872 L F
.364 0 .153 r
.61675 .40813 m .61884 .40872 L .6193 .40757 L F
.692 .252 .201 r
.52846 .5322 m .52877 .53261 L .52686 .53365 L F
.404 .206 .496 r
.52686 .53365 m .52877 .53261 L .52846 .5322 L F
.52686 .53365 m .52877 .53261 L .52846 .5322 L F
.287 .413 .815 r
.76409 .40373 m .76599 .40753 L .76454 .40579 L F
.854 .876 .855 r
.6356 .43979 m .63934 .43862 L .6378 .43668 L F
.6356 .43979 m .63682 .44111 L .63934 .43862 L F
0 0 .15 r
.65211 .41898 m .65213 .41602 L .65211 .41839 L F
0 0 .082 r
.65225 .42087 m .65211 .41898 L .65211 .41839 L F
.65225 .42087 m .65189 .42248 L .65211 .41898 L F
.99 .886 .574 r
.65024 .42933 m .65161 .42858 L .65082 .42733 L F
.65024 .42933 m .65079 .43174 L .65161 .42858 L F
.875 .876 .833 r
.50722 .53324 m .50833 .52815 L .5081 .5308 L F
.78 .66 .73 r
.52701 .53799 m .53084 .53872 L .52877 .53261 L F
.489 .146 .312 r
.52701 .53799 m .52966 .53964 L .53084 .53872 L F
.524 .37 .615 r
.53084 .53872 m .53321 .5381 L .53318 .53517 L F
.355 0 0 r
.53084 .53872 m .53179 .53686 L .53321 .5381 L F
.53084 .53872 m .53068 .53958 L .53179 .53686 L F
.53084 .53872 m .52966 .53964 L .53068 .53958 L F
.903 .892 .808 r
.63446 .4414 m .63682 .44111 L .6356 .43979 L F
.63446 .4414 m .63472 .44417 L .63682 .44111 L F
.591 .342 .508 r
.57945 .53561 m .58221 .53776 L .57944 .53801 L F
.57945 .53561 m .58247 .5354 L .58221 .53776 L F
0 0 0 r
.19702 .70391 m .19698 .70426 L .19566 .70476 L F
.336 0 .213 r
.19641 .70664 m .19566 .70476 L .19698 .70426 L F
.19641 .70664 m .19439 .70745 L .19566 .70476 L F
.736 .634 .746 r
.78012 .41933 m .77968 .42352 L .77743 .4222 L F
.234 .186 .596 r
.78084 .42138 m .77968 .42352 L .78012 .41933 L F
.282 .412 .817 r
.78281 .42338 m .77968 .42352 L .78084 .42138 L F
.78281 .42338 m .78168 .42546 L .77968 .42352 L F
.557 .324 .518 r
.20661 .66283 m .2096 .65944 L .20904 .66195 L F
.625 .608 .813 r
.21057 .66174 m .20904 .66195 L .2096 .65944 L F
.444 .303 .595 r
.24991 .615 m .24945 .61749 L .2478 .61801 L F
.393 .148 .418 r
.2495 .62035 m .2478 .61801 L .24945 .61749 L F
.2495 .62035 m .24747 .62095 L .2478 .61801 L F
.451 .411 .722 r
.37381 .6127 m .37567 .6121 L .37512 .60886 L F
.378 .329 .677 r
.37381 .6127 m .37608 .61463 L .37567 .6121 L F
.37381 .6127 m .37418 .61645 L .37608 .61463 L F
.156 0 0 r
.19959 .54054 m .20173 .54066 L .20338 .54046 L F
0 0 0 r
.20173 .54066 m .20562 .53997 L .20338 .54046 L F
.569 .777 .977 r
.46672 .57108 m .46767 .56911 L .46533 .56976 L F
.46672 .57108 m .46907 .57052 L .46767 .56911 L F
.683 .608 .766 r
.46693 .57374 m .46907 .57052 L .46672 .57108 L F
.784 .68 .748 r
.64331 .41029 m .6421 .41067 L .64093 .40732 L F
.374 .307 .652 r
.40603 .6316 m .40556 .63475 L .40347 .63305 L F
0 0 .053 r
.6093 .41671 m .61116 .41554 L .61164 .41364 L F
.107 0 .048 r
.6093 .41671 m .61076 .41741 L .61116 .41554 L F
.6093 .41671 m .60873 .41849 L .61076 .41741 L F
.774 .438 .419 r
.57291 .5227 m .57321 .52087 L .56927 .52017 L F
.497 .169 .342 r
.57544 .52228 m .57321 .52087 L .57291 .5227 L F
.57544 .52228 m .57595 .52055 L .57321 .52087 L F
.67 .697 .867 r
.53451 .55913 m .53408 .55916 L .53465 .55686 L F
.53408 .55916 m .53221 .5593 L .53465 .55686 L F
.921 .947 .604 r
.53525 .55467 m .53513 .55491 L .53465 .55686 L F
.53513 .55491 m .53369 .55804 L .53465 .55686 L F
0 0 0 r
.53369 .55804 m .53221 .5593 L .53465 .55686 L F
0 0 .248 r
.53291 .55944 m .53221 .5593 L .53369 .55804 L F
.608 .395 .567 r
.53383 .55918 m .5347 .56123 L .53451 .55913 L F
.53221 .5593 m .53322 .56009 L .53383 .55918 L F
.53322 .56009 m .5347 .56123 L .53383 .55918 L F
.53221 .5593 m .53221 .56177 L .5347 .56123 L F
0 0 .248 r
.53291 .55944 m .53221 .56177 L .53221 .5593 L F
.863 .955 .609 r
.53291 .55944 m .53055 .56351 L .53186 .56213 L F
.53229 .56148 m .53186 .56213 L .53221 .56177 L F
.53291 .55944 m .53186 .56213 L .53229 .56148 L F
.605 .675 .891 r
.485 .5745 m .48622 .57487 L .48546 .57309 L F
.379 .085 .334 r
.48379 .57413 m .48536 .57287 L .48622 .57487 L F
.48275 .57381 m .48524 .57291 L .48379 .57413 L F
.48524 .57291 m .48536 .57287 L .48379 .57413 L F
.913 .81 .732 r
.48536 .57287 m .48622 .57487 L .48562 .57246 L F
.48536 .57287 m .48622 .57487 L .48562 .57246 L F
.579 .367 .557 r
.4857 .57431 m .48818 .57127 L .486 .57228 L F
.48562 .5726 m .486 .57228 L .48562 .57246 L F
.4857 .57431 m .486 .57228 L .48562 .5726 L F
0 0 0 r
.4849 .57555 m .4857 .57431 L .48562 .5726 L F
.48549 .573 m .48562 .5726 L .48562 .57246 L F
.4849 .57555 m .48562 .5726 L .48549 .573 L F
.605 .675 .891 r
.48275 .57381 m .485 .5745 L .48536 .57287 L F
.485 .5745 m .48546 .57309 L .48536 .57287 L F
.908 .975 .795 r
.4849 .57555 m .4845 .57722 L .48622 .57487 L F
.621 .646 .854 r
.48622 .57487 m .49193 .57658 L .48856 .5738 L F
.684 .437 .542 r
.48856 .5738 m .4849 .57555 L .48622 .57487 L F
.688 .954 .952 r
.17261 .56309 m .17689 .56186 L .17522 .56191 L F
.133 0 .293 r
.20691 .67791 m .20502 .68072 L .20562 .6782 L F
.20691 .67791 m .20502 .68072 L .20562 .6782 L F
.162 0 .232 r
.59775 .43674 m .60017 .43385 L .59813 .43486 L F
.551 .381 .604 r
.61421 .42735 m .61192 .43087 L .61195 .42861 L F
.814 .623 .645 r
.19268 .69571 m .19316 .69602 L .19282 .69302 L F
.564 .931 .792 r
.19394 .69222 m .19282 .69302 L .1941 .69178 L F
.672 .841 .424 r
.19394 .69222 m .19647 .68791 L .19841 .69046 L F
0 0 .351 r
.19282 .69302 m .19369 .69433 L .1941 .69178 L F
.19282 .69302 m .19316 .69602 L .19369 .69433 L F
0 0 .495 r
.17529 .62679 m .17561 .62721 L .17584 .6276 L F
.96 .945 .68 r
.17584 .6276 m .17561 .62721 L .17517 .62813 L F
.484 .513 .812 r
.37418 .61645 m .37742 .61822 L .37608 .61463 L F
.381 .206 .515 r
.4656 .58773 m .46526 .5855 L .46687 .58602 L F
.581 .609 .846 r
.46802 .58225 m .46687 .58602 L .46526 .5855 L F
.137 0 0 r
.46777 .587 m .4656 .58773 L .46687 .58602 L F
.719 .739 .867 r
.64561 .42886 m .64287 .42751 L .64485 .42747 L F
.889 .724 .671 r
.60734 .47352 m .60657 .47583 L .60523 .47228 L F
.64 .862 .983 r
.70353 .454 m .70661 .45412 L .70583 .45321 L F
.694 .887 .969 r
.70661 .45412 m .70909 .45145 L .70583 .45321 L F
.70661 .45412 m .70999 .45255 L .70909 .45145 L F
.609 .601 .818 r
.18932 .68066 m .19077 .68296 L .19251 .68084 L F
.515 .729 .971 r
.53537 .54619 m .53819 .54723 L .53571 .54746 L F
.678 .65 .815 r
.478 .56487 m .47323 .56259 L .47673 .56325 L F
.354 .671 .975 r
.47854 .56337 m .478 .56487 L .47673 .56325 L F
.47854 .56337 m .47973 .56463 L .478 .56487 L F
.554 .552 .807 r
.4813 .56781 m .478 .56487 L .47973 .56463 L F
.685 .712 .869 r
.63994 .43061 m .63673 .4279 L .63871 .42766 L F
.702 .672 .817 r
.64287 .42751 m .63994 .43061 L .63871 .42766 L F
.756 .771 .865 r
.68396 .44889 m .68009 .4483 L .68301 .44546 L F
.68396 .44889 m .68171 .4497 L .68009 .4483 L F
.754 .752 .85 r
.68647 .44589 m .68396 .44889 L .68301 .44546 L F
.498 0 0 r
.40581 .64516 m .40663 .64605 L .40448 .6444 L F
.40581 .64516 m .40803 .6466 L .40663 .64605 L F
.748 .749 .852 r
.70746 .44047 m .70465 .4431 L .70365 .44005 L F
.671 .604 .771 r
.70746 .44047 m .70841 .44377 L .70465 .4431 L F
.95 .911 .744 r
.63272 .44488 m .63472 .44417 L .63446 .4414 L F
.692 .729 .879 r
.71902 .43974 m .71687 .44098 L .71546 .43928 L F
.592 .843 .992 r
.48346 .57189 m .48275 .57381 L .48536 .57287 L F
.379 .085 .334 r
.48275 .57381 m .48215 .57549 L .48536 .57287 L F
.469 .404 .701 r
.4849 .57555 m .48418 .58 L .4845 .57722 L F
.87 .896 .849 r
.52343 .51813 m .52094 .52099 L .51964 .51986 L F
.447 .276 .555 r
.2587 .59771 m .25861 .60026 L .25659 .60084 L F
.457 .304 .585 r
.25861 .60026 m .25865 .60285 L .25659 .60084 L F
.402 .3 .624 r
.25865 .60285 m .25693 .60364 L .25659 .60084 L F
.54 .657 .912 r
.75342 .43155 m .75453 .43095 L .75186 .4309 L F
.69 .767 .91 r
.73329 .39209 m .73282 .39435 L .73099 .39318 L F
.73329 .39209 m .73443 .3938 L .73282 .39435 L F
.747 .778 .878 r
.54458 .5765 m .54587 .57793 L .54829 .57693 L F
0 .093 .621 r
.43528 .60018 m .43473 .59828 L .43539 .59787 L F
.411 .798 .99 r
.68888 .44296 m .69142 .44266 L .69262 .44336 L F
.446 .817 .993 r
.69262 .44336 m .69142 .44266 L .69511 .44285 L F
.69262 .44336 m .69142 .44266 L .69511 .44285 L F
0 0 0 r
.42907 .59835 m .42523 .60068 L .4256 .59727 L F
.42907 .59835 m .42661 .60009 L .42523 .60068 L F
.731 .961 .681 r
.42942 .59776 m .42661 .60009 L .42907 .59835 L F
.42756 .59913 m .42661 .60009 L .42942 .59776 L F
.231 .451 .867 r
.42774 .60198 m .42687 .60346 L .42523 .60068 L F
.322 .451 .836 r
.42661 .60009 m .42774 .60198 L .42523 .60068 L F
.731 .961 .681 r
.43018 .59647 m .42756 .59913 L .42942 .59776 L F
.983 .784 .56 r
.42706 .59964 m .42638 .6018 L .42774 .60198 L F
.42696 .59974 m .42638 .6018 L .42706 .59964 L F
.42696 .59957 m .42638 .6018 L .42702 .59952 L F
.464 .222 .461 r
.42904 .60085 m .42638 .6018 L .4269 .5998 L F
0 0 0 r
.42709 .59961 m .42661 .60009 L .42756 .59913 L F
.42869 .598 m .42745 .59924 L .42917 .59751 L F
.42745 .59924 m .42709 .59961 L .42917 .59751 L F
.42709 .59961 m .42756 .59913 L .43018 .59647 L F
.644 .696 .883 r
.427 .59943 m .42661 .60009 L .42869 .598 L F
.983 .784 .56 r
.42702 .59952 m .42696 .59974 L .42706 .59964 L F
.427 .59943 m .42696 .59957 L .42702 .59952 L F
.464 .222 .461 r
.42716 .59954 m .4269 .5998 L .427 .59943 L F
.42904 .60085 m .4269 .5998 L .42716 .59954 L F
0 0 0 r
.42917 .59751 m .42709 .59961 L .43018 .59647 L F
0 .051 .531 r
.40713 .63573 m .40715 .63575 L .40556 .63475 L F
.40713 .63573 m .40941 .63774 L .40715 .63575 L F
0 0 .14 r
.55768 .47845 m .55578 .48225 L .55731 .48091 L F
0 0 0 r
.55578 .48225 m .55671 .48279 L .55731 .48091 L F
.55578 .48225 m .55485 .48396 L .55671 .48279 L F
.467 .119 .292 r
.39274 .59156 m .39516 .59123 L .39627 .58881 L F
.354 .01 .236 r
.39627 .58881 m .39756 .59054 L .3984 .58795 L F
.39627 .58881 m .39516 .59123 L .39756 .59054 L F
.294 0 .238 r
.58654 .53112 m .58679 .52887 L .58939 .52858 L F
.399 .254 .565 r
.26507 .59102 m .26334 .58912 L .26548 .58845 L F
.26507 .59102 m .26321 .59172 L .26334 .58912 L F
.526 .826 .999 r
.43562 .61547 m .43937 .61577 L .43797 .61483 L F
.43797 .61483 m .43937 .61577 L .43562 .61547 L F
.584 .458 .675 r
.56215 .52656 m .56523 .52912 L .56507 .52618 L F
.56215 .52656 m .56245 .52966 L .56523 .52912 L F
.806 .626 .659 r
.55125 .57655 m .55482 .57897 L .55287 .57609 L F
.55125 .57655 m .55063 .57911 L .55482 .57897 L F
.386 .076 .311 r
.55338 .58038 m .55482 .57897 L .55063 .57911 L F
.55338 .58038 m .55491 .57977 L .55482 .57897 L F
.423 .688 .974 r
.55482 .57897 m .55665 .57742 L .55287 .57609 L F
.55482 .57897 m .55777 .5787 L .55665 .57742 L F
.464 .339 .625 r
.55646 .57953 m .55482 .57897 L .55491 .57977 L F
.55646 .57953 m .55777 .5787 L .55482 .57897 L F
.564 .686 .922 r
.41892 .60559 m .41481 .60373 L .41739 .60271 L F
.475 .329 .602 r
.42185 .60434 m .41892 .60559 L .41739 .60271 L F
.42185 .60434 m .42106 .60543 L .41892 .60559 L F
.446 .477 .798 r
.53877 .58892 m .54205 .59191 L .54118 .59095 L F
.547 .328 .533 r
.54118 .59095 m .53864 .5918 L .53877 .58892 L F
.589 .599 .83 r
.53982 .58529 m .53877 .58892 L .53735 .58503 L F
.679 .439 .551 r
.63266 .42781 m .63673 .4279 L .63387 .43069 L F
.611 .488 .687 r
.63207 .40722 m .633 .41094 L .62891 .40984 L F
.675 .516 .662 r
.63238 .41244 m .62891 .40984 L .633 .41094 L F
.63238 .41244 m .63003 .41342 L .62891 .40984 L F
.593 .868 .994 r
.69558 .40326 m .69915 .40333 L .69799 .40274 L F
.595 .932 .955 r
.69915 .40333 m .70056 .40177 L .69799 .40274 L F
.69915 .40333 m .70174 .40214 L .70056 .40177 L F
0 0 0 r
.614 .41049 m .61164 .41364 L .61323 .41177 L F
.2 0 .139 r
.61164 .41364 m .61334 .41452 L .61323 .41177 L F
.61164 .41364 m .61116 .41554 L .61334 .41452 L F
.896 .85 .79 r
.63952 .41309 m .63778 .41682 L .63632 .41571 L F
.967 .773 .591 r
.63778 .41682 m .6374 .41924 L .63632 .41571 L F
.236 0 .21 r
.56305 .47357 m .56247 .47517 L .56518 .47249 L F
.347 0 0 r
.5061 .53296 m .5071 .53344 L .50596 .53294 L F
0 .41 .686 r
.51019 .53408 m .50596 .53294 L .5071 .53344 L F
.604 .621 .841 r
.48451 .56977 m .4813 .56781 L .4837 .56724 L F
.621 .714 .912 r
.48576 .56689 m .48451 .56977 L .4837 .56724 L F
.48576 .56689 m .48707 .569 L .48451 .56977 L F
.761 .643 .731 r
.60608 .46089 m .60218 .45873 L .60544 .45787 L F
.60608 .46089 m .60413 .46096 L .60218 .45873 L F
.907 .775 .703 r
.60608 .46089 m .60277 .46275 L .60413 .46096 L F
.60608 .46089 m .60449 .46404 L .60277 .46275 L F
.879 .835 .799 r
.60829 .45743 m .60608 .46089 L .60544 .45787 L F
.60829 .45743 m .60544 .45787 L .60716 .45617 L F
.662 .352 .437 r
.43812 .65021 m .4335 .65064 L .43368 .64862 L F
0 .251 .745 r
.7316 .43033 m .73093 .43053 L .72977 .42857 L F
.7316 .43033 m .73259 .43169 L .73093 .43053 L F
.452 .14 .344 r
.2045 .63628 m .20685 .63586 L .20762 .63313 L F
.3 .005 .286 r
.20762 .63313 m .20883 .635 L .20967 .63277 L F
.20762 .63313 m .20685 .63586 L .20883 .635 L F
0 0 0 r
.53937 .59973 m .53942 .59997 L .53913 .60018 L F
.422 .206 .479 r
.53937 .59973 m .54046 .60258 L .53942 .59997 L F
.53937 .59973 m .54091 .6024 L .54046 .60258 L F
.64 .714 .901 r
.66156 .4027 m .65897 .40409 L .65777 .40167 L F
.743 .847 .928 r
.66189 .40284 m .65897 .40409 L .66156 .4027 L F
.971 .741 .532 r
.53032 .68058 m .53207 .68475 L .53024 .68321 L F
.676 .824 .955 r
.53207 .68475 m .53385 .68348 L .53024 .68321 L F
0 .46 .832 r
.37941 .62859 m .37812 .62768 L .3758 .62692 L F
.025 .393 .851 r
.37941 .62859 m .38083 .62817 L .37812 .62768 L F
.365 0 0 r
.3834 .63026 m .38226 .62994 L .37941 .62859 L F
.025 .393 .851 r
.37941 .62859 m .38226 .62994 L .38083 .62817 L F
.584 .043 0 r
.65317 .40677 m .65408 .40762 L .65332 .40699 L F
.65408 .40762 m .65542 .40887 L .65375 .40737 L F
.65408 .40762 m .65375 .40737 L .65332 .40699 L F
.814 .828 .353 r
.65356 .40723 m .65169 .4135 L .65548 .41011 L F
.65338 .40697 m .65335 .40708 L .65356 .40723 L F
.65335 .40708 m .65169 .4135 L .65356 .40723 L F
0 0 .235 r
.65222 .41438 m .65169 .4135 L .65161 .41294 L F
.65222 .41438 m .65213 .41602 L .65169 .4135 L F
.88 .969 .651 r
.37684 .62449 m .37675 .62302 L .37849 .6215 L F
0 0 .415 r
.3758 .62692 m .37675 .62302 L .37684 .62449 L F
.879 .912 .847 r
.56533 .48973 m .56405 .49364 L .56603 .49064 L F
.811 .964 .906 r
.56836 .48748 m .56603 .49064 L .569 .48782 L F
.56836 .48748 m .56533 .48973 L .56603 .49064 L F
.11 0 .199 r
.54581 .55046 m .54771 .54918 L .54815 .54736 L F
.559 .503 .749 r
.54815 .54736 m .55052 .54663 L .54913 .5442 L F
.467 .249 .499 r
.55035 .54909 m .54815 .54736 L .54771 .54918 L F
.55035 .54909 m .55052 .54663 L .54815 .54736 L F
.675 .844 .964 r
.20168 .675 m .19776 .67494 L .20012 .67383 L F
.721 .293 .231 r
.19971 .67666 m .20168 .675 L .20012 .67383 L F
.19971 .67666 m .20354 .67715 L .20168 .675 L F
.579 .835 .993 r
.70894 .39309 m .70644 .39385 L .70539 .39277 L F
.881 .929 .849 r
.68171 .4497 m .67872 .45125 L .68009 .4483 L F
.898 .921 .531 r
.52778 .68101 m .52645 .6827 L .52737 .68097 L F
.612 .945 .763 r
.52778 .68101 m .52737 .68097 L .52885 .67969 L F
0 0 0 r
.52885 .67969 m .52645 .6827 L .52778 .68101 L F
.188 0 .344 r
.60053 .43171 m .60186 .43267 L .60247 .43069 L F
.60053 .43171 m .60017 .43385 L .60186 .43267 L F
.49 .138 .296 r
.44326 .64819 m .43972 .65096 L .4403 .64863 L F
.44326 .64819 m .44236 .65064 L .43972 .65096 L F
.305 0 .218 r
.44499 .64952 m .44326 .64819 L .44418 .64711 L F
.44499 .64952 m .44236 .65064 L .44326 .64819 L F
.494 .31 .56 r
.26271 .78496 m .26477 .78729 L .2626 .78789 L F
.26271 .78496 m .26477 .78729 L .2626 .78789 L F
0 0 0 r
.45696 .64015 m .45423 .64231 L .45581 .64142 L F
.596 .185 .235 r
.45581 .64142 m .45797 .64185 L .45696 .64015 L F
.78 .791 .862 r
.6985 .44299 m .69511 .44285 L .69788 .44034 L F
.681 .73 .887 r
.70057 .44259 m .6985 .44299 L .69788 .44034 L F
.272 0 .105 r
.64282 .40076 m .64201 .40285 L .64396 .40129 L F
.66 .645 .824 r
.49095 .57078 m .48855 .57164 L .48707 .569 L F
.586 .415 .617 r
.49095 .57078 m .48856 .5738 L .48855 .57164 L F
.595 .522 .743 r
.64133 .43715 m .63821 .43459 L .64013 .43367 L F
.618 .614 .825 r
.54829 .57693 m .55125 .57655 L .54925 .57269 L F
.169 .341 .793 r
.54829 .57693 m .55063 .57911 L .55125 .57655 L F
.433 .276 .567 r
.27111 .5609 m .26914 .55875 L .2721 .55576 L F
.27111 .5609 m .26888 .56237 L .26914 .55875 L F
.87 .896 .849 r
.52343 .51813 m .51964 .51986 L .52185 .51647 L F
.834 .794 .813 r
.52597 .51497 m .52343 .51813 L .52185 .51647 L F
.153 0 .303 r
.5431 .55551 m .54566 .55274 L .54347 .5535 L F
.571 .696 .926 r
.23406 .55556 m .23756 .55691 L .23605 .55571 L F
.012 .556 .837 r
.23927 .55647 m .23605 .55571 L .23756 .55691 L F
.333 .159 .489 r
.25419 .60904 m .2524 .61222 L .25274 .60975 L F
.621 .14 .091 r
.42141 .64861 m .4199 .64998 L .41773 .64841 L F
.668 .198 .128 r
.42141 .64861 m .42363 .65046 L .4199 .64998 L F
0 0 0 r
.53024 .53113 m .52846 .5322 L .53167 .5294 L F
.789 .38 .277 r
.53167 .5294 m .5334 .53139 L .53024 .53113 L F
.812 .64 .669 r
.53565 .52963 m .5334 .53139 L .53167 .5294 L F
.575 .35 .537 r
.57088 .54088 m .56831 .54365 L .56843 .54136 L F
.515 .423 .689 r
.23413 .58577 m .23538 .58213 L .23389 .5832 L F
.655 .872 .98 r
.74582 .43819 m .74682 .43924 L .75009 .43789 L F
.998 .787 .481 r
.76628 .42021 m .76718 .41945 L .76637 .4182 L F
.344 .642 .964 r
.51398 .56181 m .51505 .56046 L .51253 .56058 L F
.201 .434 .862 r
.51398 .56181 m .51545 .56207 L .51505 .56046 L F
.879 .912 .847 r
.56533 .48973 m .56284 .49265 L .56405 .49364 L F
.652 .765 .932 r
.70526 .40266 m .70666 .40004 L .70422 .40115 L F
.70526 .40266 m .70782 .4017 L .70666 .40004 L F
.355 .161 .474 r
.41867 .59157 m .41808 .59407 L .41647 .59395 L F
.393 .141 .409 r
.41767 .59634 m .41551 .59707 L .41647 .59395 L F
.244 .1 .478 r
.21489 .6216 m .2162 .62337 L .21649 .62094 L F
.21489 .6216 m .21479 .62411 L .2162 .62337 L F
.765 .746 .226 r
.21738 .56313 m .21779 .56223 L .21549 .56056 L F
.21738 .56313 m .21714 .56496 L .21779 .56223 L F
.59 .477 .693 r
.53451 .55913 m .53701 .55567 L .53465 .55686 L F
.53451 .55913 m .53726 .55865 L .53701 .55567 L F
.662 .479 .626 r
.5347 .56123 m .53726 .55865 L .53451 .55913 L F
.83 .766 .792 r
.61344 .45102 m .60985 .45133 L .61215 .45047 L F
.61344 .45102 m .61204 .45259 L .60985 .45133 L F
.7 .96 .946 r
.61344 .45102 m .61387 .44934 L .61584 .44878 L F
.61344 .45102 m .61215 .45047 L .61387 .44934 L F
.698 .71 .858 r
.49379 .56976 m .4945 .57157 L .49095 .57078 L F
.506 .598 .88 r
.49584 .5695 m .4945 .57157 L .49379 .56976 L F
.47 .55 .856 r
.49584 .5695 m .49679 .57077 L .4945 .57157 L F
.32 .21 .568 r
.43956 .59138 m .43773 .59489 L .43718 .59183 L F
.43956 .59138 m .43954 .59433 L .43773 .59489 L F
0 0 .105 r
.59644 .51692 m .59721 .51449 L .5984 .51356 L F
0 0 .539 r
.7657 .40346 m .76599 .40753 L .76409 .40373 L F
.7657 .40346 m .76634 .40691 L .76599 .40753 L F
.827 .865 .874 r
.73005 .40456 m .73303 .4041 L .73217 .40314 L F
.828 .946 .899 r
.73303 .4041 m .73511 .40047 L .73217 .40314 L F
.73303 .4041 m .73576 .40171 L .73511 .40047 L F
.794 .523 .528 r
.49238 .5768 m .48856 .5738 L .49193 .57658 L F
.879 .69 .168 r
.65156 .42306 m .65189 .42248 L .65225 .42087 L F
.65156 .42306 m .6519 .42543 L .65189 .42248 L F
.558 .58 .831 r
.40839 .60874 m .40744 .61311 L .40592 .60936 L F
.40839 .60874 m .41046 .61313 L .40744 .61311 L F
.498 .311 .557 r
.43949 .58878 m .43956 .59138 L .43718 .59183 L F
.18 .706 .69 r
.72168 .43459 m .71849 .4354 L .72006 .43316 L F
.714 .768 .895 r
.72336 .43095 m .72168 .43459 L .72006 .43316 L F
.72336 .43095 m .72371 .4337 L .72168 .43459 L F
.559 .35 .554 r
.46263 .64174 m .46584 .6388 L .46293 .63961 L F
.476 .141 .318 r
.59216 .46445 m .59159 .46609 L .58921 .46649 L F
.558 .342 .543 r
.59407 .46302 m .59159 .46609 L .59216 .46445 L F
.279 0 .119 r
.39887 .5871 m .40055 .58729 L .40133 .5864 L F
.39887 .5871 m .3984 .58795 L .40055 .58729 L F
.119 0 .214 r
.54566 .55274 m .54771 .54918 L .54581 .55046 L F
.837 .999 .806 r
.52722 .51329 m .52829 .51248 L .52597 .51497 L F
0 0 0 r
.53049 .51133 m .52829 .51248 L .52722 .51329 L F
.857 .879 .443 r
.65716 .42966 m .65807 .42842 L .65716 .43079 L F
.873 .878 .441 r
.65817 .42696 m .65807 .42842 L .65716 .42966 L F
.637 .594 .789 r
.65773 .4421 m .65891 .44575 L .66123 .4429 L F
.516 .875 .984 r
.6999 .39449 m .6967 .39453 L .69916 .39395 L F
.522 .878 .984 r
.70158 .393 m .6999 .39449 L .69916 .39395 L F
.70158 .393 m .70292 .39366 L .6999 .39449 L F
.235 0 0 r
.53982 .58529 m .54211 .5848 L .54345 .58292 L F
.987 .731 .45 r
.54345 .58292 m .54211 .5848 L .54364 .58471 L F
.329 .561 .921 r
.54364 .58471 m .54649 .58306 L .54345 .58292 L F
.162 0 .354 r
.50807 .59226 m .50984 .59112 L .50897 .59009 L F
.502 .015 .032 r
.50897 .59009 m .50984 .59112 L .51326 .59093 L F
.593 .395 .583 r
.45099 .5761 m .45431 .57319 L .45157 .57375 L F
.51 0 0 r
.60017 .46145 m .60277 .46275 L .59894 .46177 L F
.542 .142 .233 r
.60413 .46096 m .60277 .46275 L .60017 .46145 L F
.657 .617 .798 r
.50235 .57988 m .50289 .5833 L .50616 .58213 L F
.57 .394 .603 r
.50289 .5833 m .50563 .58508 L .50616 .58213 L F
.50289 .5833 m .50331 .58551 L .50563 .58508 L F
.343 .072 .35 r
.57515 .46066 m .57735 .46015 L .57781 .45794 L F
.412 .18 .45 r
.57509 .46325 m .57735 .46015 L .57515 .46066 L F
.261 .77 .807 r
.1747 .54512 m .17687 .54461 L .17912 .5444 L F
.584 .942 .907 r
.17912 .5444 m .17687 .54461 L .17959 .5434 L F
.773 .674 .754 r
.6421 .41067 m .6389 .41039 L .64093 .40732 L F
.627 .429 .595 r
.6421 .41067 m .64219 .41313 L .63952 .41309 L F
.683 .608 .766 r
.46693 .57374 m .47051 .57441 L .46907 .57052 L F
.834 .794 .813 r
.5249 .51536 m .52185 .51647 L .52393 .51564 L F
.786 .935 .577 r
.52185 .51647 m .51964 .51986 L .52037 .51795 L F
.659 .963 .775 r
.52037 .51795 m .52393 .51564 L .52185 .51647 L F
.52037 .51795 m .5229 .51593 L .52393 .51564 L F
.5229 .51593 m .52315 .51574 L .52393 .51564 L F
.834 .794 .813 r
.52597 .51497 m .5249 .51536 L .52393 .51564 L F
0 0 0 r
.5268 .51395 m .52722 .51329 L .52597 .51497 L F
.5268 .51395 m .52597 .51497 L .52393 .51564 L F
.054 0 0 r
.20778 .54016 m .20994 .53999 L .21169 .53949 L F
.454 0 0 r
.21169 .53949 m .20994 .53999 L .21383 .54038 L F
.439 0 0 r
.21169 .53949 m .21383 .54038 L .21553 .54025 L F
.99 .887 .574 r
.50309 .54709 m .50147 .54863 L .50095 .54585 L F
.50309 .54709 m .5021 .54937 L .50147 .54863 L F
.436 .18 .426 r
.57735 .46015 m .58006 .45687 L .57781 .45794 L F
.548 .766 .978 r
.64237 .43495 m .64344 .43469 L .64013 .43367 L F
.576 .665 .898 r
.48206 .5644 m .4813 .56781 L .47973 .56463 L F
.48206 .5644 m .4837 .56724 L .4813 .56781 L F
.408 0 0 r
.43748 .56596 m .43605 .56687 L .43353 .56666 L F
.805 .52 .506 r
.42135 .63799 m .42539 .63672 L .42101 .63675 L F
.42135 .63799 m .42451 .63901 L .42539 .63672 L F
.204 0 .237 r
.42539 .63672 m .42451 .63901 L .42722 .63577 L F
.74 .914 .952 r
.74426 .41156 m .7406 .41235 L .74296 .41077 L F
.287 .54 .917 r
.74635 .4108 m .74426 .41156 L .74296 .41077 L F
.74635 .4108 m .74719 .41263 L .74426 .41156 L F
.264 0 0 r
.20538 .55402 m .20406 .55424 L .20191 .55374 L F
.431 .296 .595 r
.26999 .58462 m .26815 .58306 L .26983 .58186 L F
.26999 .58462 m .26815 .58542 L .26815 .58306 L F
.347 .252 .604 r
.55907 .56093 m .55701 .55894 L .55882 .55837 L F
.55907 .56093 m .55766 .56177 L .55701 .55894 L F
.787 .725 .795 r
.20894 .68095 m .20502 .68072 L .20691 .67791 L F
.33 .325 .702 r
.20703 .68268 m .20502 .68072 L .20894 .68095 L F
0 .27 .777 r
.20691 .67791 m .20906 .6797 L .20894 .68095 L F
.549 .387 .614 r
.20906 .6797 m .20703 .68268 L .20894 .68095 L F
.123 0 0 r
.21553 .54025 m .21383 .54038 L .21772 .54035 L F
.206 0 .049 r
.44221 .59877 m .44116 .59737 L .44236 .5963 L F
.44221 .59877 m .44012 .59942 L .44116 .59737 L F
.981 .718 .452 r
.4256 .59727 m .42523 .60068 L .42407 .59866 L F
.922 .565 .126 r
.4256 .59727 m .42461 .59664 L .4241 .59449 L F
.786 .722 .793 r
.4287 .59393 m .4256 .59727 L .4241 .59449 L F
.994 .872 .553 r
.4256 .59727 m .42407 .59866 L .42461 .59664 L F
.189 .528 .921 r
.25583 .54541 m .25743 .54571 L .25716 .54703 L F
.292 .637 .965 r
.25743 .54571 m .25872 .54702 L .25716 .54703 L F
.366 .47 .834 r
.40593 .62075 m .40291 .61892 L .4055 .61884 L F
.479 .563 .863 r
.67182 .40915 m .67059 .41236 L .66925 .41069 L F
.67182 .40915 m .6728 .41246 L .67059 .41236 L F
.361 .758 .986 r
.66156 .4027 m .66532 .4034 L .66189 .40284 L F
.37 .101 .369 r
.61323 .41177 m .61631 .40938 L .614 .41049 L F
.445 .326 .624 r
.24312 .56787 m .24507 .5673 L .24483 .56471 L F
.389 .299 .631 r
.24312 .56787 m .24518 .56986 L .24507 .5673 L F
.24312 .56787 m .24316 .57112 L .24518 .56986 L F
0 0 0 r
.41164 .61672 m .41127 .61559 L .41294 .6139 L F
.41164 .61672 m .41052 .61758 L .41127 .61559 L F
.2045 .63628 m .20266 .63718 L .20039 .63843 L F
.259 .122 .496 r
.37464 .6037 m .37629 .60304 L .37646 .60031 L F
.312 .248 .623 r
.37464 .6037 m .37661 .60563 L .37629 .60304 L F
.4 .256 .567 r
.37472 .60621 m .37661 .60563 L .37464 .6037 L F
.838 .558 .514 r
.60563 .467 m .60376 .46876 L .60357 .4666 L F
.60563 .467 m .60699 .46885 L .60376 .46876 L F
.852 .821 .818 r
.68546 .45724 m .68686 .45857 L .68914 .45547 L F
.826 .937 .901 r
.72076 .44838 m .72456 .44682 L .72325 .44541 L F
.85 .857 .847 r
.72325 .44541 m .72456 .44682 L .72693 .44387 L F
.605 .802 .976 r
.71497 .39288 m .71254 .39368 L .71148 .39229 L F
.625 .888 .988 r
.38366 .62871 m .3834 .63026 L .38632 .6293 L F
.759 .982 .91 r
.38366 .62871 m .38226 .62994 L .3834 .63026 L F
.002 0 0 r
.16929 .54679 m .17164 .54623 L .17291 .54551 L F
0 0 0 r
.17327 .54541 m .17321 .546 L .17331 .54539 L F
.17327 .54541 m .1736 .54348 L .17531 .54451 L F
.17327 .54541 m .17331 .54539 L .1736 .54348 L F
.17323 .54544 m .17327 .54541 L .1747 .54512 L F
.17291 .54551 m .17327 .54541 L .17323 .54544 L F
.17291 .54551 m .17164 .54623 L .17327 .54541 L F
.569 .456 .686 r
.27286 .55567 m .27347 .55574 L .27032 .55509 L F
.27286 .55567 m .27032 .55509 L .26996 .55333 L F
.396 .499 .846 r
.27113 .55115 m .27285 .55565 L .26996 .55333 L F
.27285 .55565 m .27286 .55567 L .27281 .55563 L F
.27285 .55565 m .27281 .55563 L .26996 .55333 L F
.594 .51 .729 r
.27268 .55557 m .2721 .55576 L .27032 .55509 L F
.524 .582 .855 r
.27289 .55566 m .27347 .55574 L .27286 .55567 L F
.594 .51 .729 r
.27347 .55574 m .27285 .55565 L .27268 .55557 L F
.524 .582 .855 r
.27542 .55424 m .27347 .55574 L .27289 .55566 L F
.594 .51 .729 r
.27347 .55574 m .27306 .55574 L .27285 .55565 L F
.27306 .55574 m .2721 .55576 L .27268 .55557 L F
.886 .718 .669 r
.61204 .45259 m .61117 .45496 L .60985 .45133 L F
.753 .831 .911 r
.19269 .65885 m .19793 .65835 L .19627 .65725 L F
.642 .79 .953 r
.19793 .65835 m .19812 .65589 L .19627 .65725 L F
.19793 .65835 m .20015 .65743 L .19812 .65589 L F
.581 .515 .746 r
.71545 .43701 m .71323 .43988 L .71253 .43781 L F
.71545 .43701 m .71546 .43928 L .71323 .43988 L F
.039 .109 .609 r
.45677 .56468 m .45831 .56653 L .45789 .56427 L F
.647 .305 .379 r
.45423 .64231 m .45155 .64447 L .45043 .64442 L F
.851 .638 .613 r
.45423 .64231 m .45435 .6452 L .45155 .64447 L F
.647 .305 .379 r
.45423 .64231 m .45043 .64442 L .45276 .64392 L F
.261 0 0 r
.45423 .64231 m .45547 .64304 L .45581 .64142 L F
.45423 .64231 m .45276 .64392 L .45547 .64304 L F
.448 .481 .8 r
.21348 .58939 m .21532 .59041 L .21507 .58765 L F
.997 .857 .558 r
.76736 .41619 m .76816 .4157 L .76806 .41407 L F
.765 .351 .265 r
.41283 .6385 m .41496 .64104 L .41654 .63949 L F
.373 .657 .968 r
.41758 .63874 m .4196 .63932 L .41654 .63949 L F
.521 .22 .397 r
.41496 .64104 m .41758 .63874 L .41654 .63949 L F
.175 0 .245 r
.55768 .47845 m .55911 .47983 L .55983 .47798 L F
.55768 .47845 m .55731 .48091 L .55911 .47983 L F
.242 0 0 r
.16394 .56409 m .16698 .56482 L .16456 .56429 L F
.207 .674 .941 r
.41558 .6475 m .41413 .64683 L .41193 .64676 L F
.696 .163 0 r
.41773 .64841 m .41413 .64683 L .41558 .6475 L F
0 .375 .804 r
.75079 .39781 m .7535 .3996 L .75262 .39845 L F
0 .414 .852 r
.75262 .39845 m .7535 .3996 L .75618 .40079 L F
.39 .018 .208 r
.15829 .55089 m .1608 .54992 L .15866 .55021 L F
.627 .598 .801 r
.62283 .42247 m .61918 .41974 L .6217 .41888 L F
.307 0 0 r
.62283 .42247 m .6217 .42407 L .61931 .42455 L F
.384 .344 .691 r
.62428 .41824 m .62283 .42247 L .6217 .41888 L F
.62428 .41824 m .62483 .42264 L .62283 .42247 L F
.766 .587 .656 r
.62483 .42264 m .6217 .42407 L .62283 .42247 L F
.584 .628 .862 r
.37849 .6215 m .37872 .61781 L .37742 .61822 L F
.37849 .6215 m .38089 .62107 L .37872 .61781 L F
.503 .017 .035 r
.37849 .6215 m .3798 .62262 L .38089 .62107 L F
.37849 .6215 m .37675 .62302 L .3798 .62262 L F
.884 .701 .65 r
.44724 .58534 m .44885 .58916 L .44691 .58862 L F
.83 .409 .24 r
.44885 .58916 m .44708 .59023 L .44691 .58862 L F
.565 .556 .802 r
.45101 .58827 m .44885 .58916 L .44724 .58534 L F
.122 0 0 r
.45101 .58827 m .44708 .59023 L .44885 .58916 L F
.513 .876 .982 r
.19619 .63959 m .19401 .64035 L .19207 .63978 L F
.568 .339 .528 r
.56689 .52284 m .56927 .52017 L .5669 .52047 L F
.812 .64 .669 r
.53565 .52963 m .53568 .53252 L .5334 .53139 L F
.776 .81 .881 r
.73395 .43866 m .73174 .44013 L .73503 .44029 L F
.705 .785 .914 r
.73395 .43866 m .73503 .44029 L .73745 .43896 L F
.98 .844 .635 r
.53932 .56761 m .54001 .56518 L .53816 .56625 L F
.842 .968 .882 r
.53911 .56449 m .54001 .56518 L .54248 .56266 L F
.967 .925 .7 r
.53816 .56625 m .54001 .56518 L .53911 .56449 L F
.432 .543 .869 r
.75391 .39109 m .75232 .39334 L .75167 .39143 L F
.75391 .39109 m .75631 .39466 L .75232 .39334 L F
.405 .553 .889 r
.75592 .39606 m .75232 .39334 L .75631 .39466 L F
.685 .764 .911 r
.73577 .39112 m .73443 .3938 L .73329 .39209 L F
.73577 .39112 m .73686 .39278 L .73443 .3938 L F
.188 .702 .889 r
.21772 .54035 m .21988 .54027 L .22166 .54065 L F
.038 .596 .813 r
.21988 .54027 m .22375 .5408 L .22166 .54065 L F
.663 .597 .771 r
.46907 .57052 m .47051 .57441 L .47259 .5729 L F
.754 .731 .831 r
.77662 .41889 m .77743 .4222 L .77377 .42179 L F
.78 .662 .733 r
.77743 .4222 m .77515 .42522 L .77377 .42179 L F
.807 .762 .811 r
.78012 .41933 m .77743 .4222 L .77662 .41889 L F
0 0 0 r
.68735 .39742 m .68857 .39675 L .68525 .39773 L F
.69081 .39584 m .68857 .39675 L .68735 .39742 L F
.85 .563 .503 r
.19268 .69571 m .19317 .69816 L .19316 .69602 L F
.19268 .69571 m .19317 .69816 L .19316 .69602 L F
.436 .229 .498 r
.19316 .69602 m .19317 .69816 L .1952 .69768 L F
.576 .571 .81 r
.60658 .43694 m .60745 .43948 L .60493 .4399 L F
.585 .046 0 r
.46332 .56974 m .46115 .57046 L .46005 .56929 L F
.786 .358 .233 r
.54984 .58507 m .55313 .58607 L .55198 .5875 L F
.575 .1 .09 r
.55313 .58607 m .55588 .58728 L .55198 .5875 L F
.681 .73 .887 r
.70057 .44259 m .69788 .44034 L .6997 .43896 L F
.656 .657 .839 r
.70365 .44005 m .70057 .44259 L .6997 .43896 L F
.459 .527 .84 r
.40494 .62998 m .40205 .6282 L .40398 .62729 L F
.722 .612 .733 r
.40706 .62656 m .40494 .62998 L .40398 .62729 L F
0 0 .525 r
.65813 .41591 m .65904 .41952 L .65913 .41823 L F
.765 .5 0 r
.65904 .41952 m .65917 .42086 L .65913 .41823 L F
.65904 .41952 m .65952 .42192 L .65917 .42086 L F
.626 .525 .72 r
.55228 .53834 m .55374 .53469 L .55135 .53523 L F
.55228 .53834 m .55471 .53779 L .55374 .53469 L F
.513 .209 .388 r
.55367 .54002 m .55228 .53834 L .55093 .5408 L F
.55367 .54002 m .55471 .53779 L .55228 .53834 L F
.746 .644 .748 r
.55228 .53834 m .55135 .53523 L .54915 .53822 L F
.728 .438 .489 r
.55093 .5408 m .55228 .53834 L .54915 .53822 L F
.189 .451 .876 r
.5173 .56767 m .51944 .57042 L .52029 .56918 L F
0 0 .501 r
.51944 .57042 m .52066 .57292 L .52029 .56918 L F
.694 .409 .488 r
.42638 .64197 m .42859 .64464 L .43082 .64167 L F
.618 .313 .432 r
.43082 .64167 m .43251 .64385 L .43228 .6422 L F
.43082 .64167 m .42859 .64464 L .43251 .64385 L F
.949 .848 .708 r
.53318 .53517 m .5334 .53139 L .53568 .53252 L F
.988 .756 .497 r
.53318 .53517 m .53179 .53686 L .53139 .53431 L F
.53318 .53517 m .53321 .5381 L .53179 .53686 L F
.473 .295 .558 r
.44142 .58833 m .43956 .59138 L .43949 .58878 L F
.018 .564 .837 r
.24165 .54115 m .2456 .5421 L .24345 .54214 L F
.274 .439 .844 r
.21079 .66075 m .21057 .66174 L .2096 .65944 L F
.776 .434 .408 r
.21201 .66463 m .21057 .66174 L .21079 .66075 L F
.21201 .66463 m .20897 .66253 L .21057 .66174 L F
0 0 .557 r
.65688 .41261 m .6577 .41408 L .65685 .41234 L F
0 0 .311 r
.65685 .41234 m .65721 .41333 L .65768 .41444 L F
.65721 .41333 m .65813 .41591 L .65768 .41444 L F
0 0 .336 r
.65813 .41591 m .65843 .41618 L .65768 .41444 L F
.706 .324 0 r
.65833 .41597 m .65768 .41444 L .65843 .41618 L F
.65703 .41337 m .65768 .41444 L .65833 .41597 L F
.753 .388 0 r
.65685 .41234 m .65768 .41444 L .65703 .41337 L F
.65685 .41234 m .65703 .41337 L .6568 .41198 L F
.65685 .41234 m .6568 .41198 L .6566 .41075 L F
0 0 .557 r
.65548 .41011 m .65688 .41261 L .65685 .41234 L F
.871 .959 .858 r
.51156 .70314 m .51344 .70209 L .51099 .70499 L F
.544 .617 .876 r
.51099 .70499 m .51395 .70467 L .51156 .70314 L F
.432 .142 .371 r
.44393 .58051 m .44619 .57911 L .44358 .57997 L F
0 .35 .824 r
.51034 .55905 m .51253 .56058 L .51093 .55835 L F
.516 .397 .656 r
.44866 .59274 m .44847 .59372 L .44623 .59177 L F
.44866 .59274 m .44847 .59372 L .44623 .59177 L F
0 0 0 r
.44336 .57334 m .44085 .57543 L .44233 .57394 L F
.505 .104 .214 r
.75071 .41512 m .7534 .41504 L .75389 .41337 L F
.511 .457 .733 r
.75389 .41337 m .75635 .41334 L .75557 .40947 L F
.168 0 0 r
.7534 .41504 m .75635 .41334 L .75389 .41337 L F
.811 .554 .551 r
.41286 .6061 m .41027 .60806 L .4087 .60606 L F
.41286 .6061 m .41263 .6091 L .41027 .60806 L F
.138 .67 .863 r
.43513 .57242 m .43869 .5728 L .4365 .57374 L F
.657 .218 0 r
.4365 .57374 m .43706 .57491 L .43584 .57584 L F
.4365 .57374 m .43751 .5755 L .43706 .57491 L F
.574 .318 .49 r
.56224 .53158 m .56523 .52912 L .56245 .52966 L F
.546 .274 .453 r
.5423 .53723 m .5453 .53536 L .5423 .53505 L F
.5423 .53723 m .54563 .53766 L .5453 .53536 L F
.488 .323 .583 r
.54706 .53751 m .5479 .53425 L .5453 .53536 L F
.649 .345 .443 r
.54563 .53766 m .54706 .53751 L .5453 .53536 L F
.553 .111 .154 r
.52449 .5381 m .52346 .53976 L .52144 .5386 L F
.21 0 .255 r
.52401 .54132 m .52701 .53799 L .52449 .5381 L F
.308 0 0 r
.52701 .53799 m .52346 .53976 L .52449 .5381 L F
.63 .943 .954 r
.68647 .40582 m .68734 .40554 L .68963 .40437 L F
.392 .85 .881 r
.6942 .39515 m .69081 .39584 L .69327 .39518 L F
.273 .778 .81 r
.6967 .39453 m .6942 .39515 L .69327 .39518 L F
.283 .177 .553 r
.42997 .59435 m .43018 .59647 L .4287 .59393 L F
.42997 .59435 m .43018 .59647 L .4287 .59393 L F
.975 .728 .499 r
.76598 .41247 m .76753 .41126 L .76656 .40894 L F
.76598 .41247 m .76806 .41407 L .76753 .41126 L F
.274 .778 .801 r
.17862 .56128 m .17756 .56129 L .17522 .56191 L F
.57 .91 .687 r
.18159 .55886 m .1795 .56015 L .17862 .56128 L F
.539 .925 .837 r
.1795 .56015 m .17756 .56129 L .17862 .56128 L F
.212 0 0 r
.75579 .43651 m .75217 .4365 L .75371 .43637 L F
.517 .292 .511 r
.37929 .59758 m .38165 .59715 L .38179 .59489 L F
.52 .243 .434 r
.38165 .59715 m .38452 .59471 L .38179 .59489 L F
.583 .285 .429 r
.44491 .58577 m .44459 .58815 L .44142 .58833 L F
.783 .47 .458 r
.44491 .58577 m .44691 .58862 L .44459 .58815 L F
.884 .701 .65 r
.44724 .58534 m .44691 .58862 L .44491 .58577 L F
.601 .74 .942 r
.74099 .43914 m .74214 .43687 L .74041 .43725 L F
.74099 .43914 m .74354 .43859 L .74214 .43687 L F
.109 .396 .85 r
.75941 .39929 m .75592 .39606 L .75914 .39745 L F
.292 .497 .886 r
.75981 .39639 m .75592 .39606 L .75631 .39466 L F
.75981 .39639 m .75914 .39745 L .75592 .39606 L F
.634 .702 .895 r
.71134 .40256 m .71385 .4017 L .71027 .40059 L F
.462 .274 .539 r
.26088 .59715 m .25861 .60026 L .2587 .59771 L F
.713 .328 .318 r
.42746 .64842 m .42981 .65064 L .42769 .65018 L F
.788 .703 .771 r
.5486 .5825 m .55338 .58038 L .55063 .57911 L F
.423 .01 .149 r
.55045 .58388 m .55338 .58038 L .5486 .5825 L F
.01 0 0 r
.55045 .58388 m .55491 .57977 L .55338 .58038 L F
.329 .561 .921 r
.54364 .58471 m .54752 .58648 L .54649 .58306 L F
.692 .541 .677 r
.54752 .58648 m .5486 .5825 L .54649 .58306 L F
.667 .443 .572 r
.5498 .6003 m .54755 .60186 L .54724 .60055 L F
.975 .674 .303 r
.42153 .58465 m .4229 .58811 L .42289 .58625 L F
.798 .872 .902 r
.42153 .58465 m .42289 .58625 L .42576 .58381 L F
.361 .758 .986 r
.66156 .4027 m .66424 .40258 L .66532 .4034 L F
.287 .741 .956 r
.66424 .40258 m .66727 .40309 L .66532 .4034 L F
.492 .331 .591 r
.56507 .52618 m .56739 .52837 L .5673 .52554 L F
.56507 .52618 m .56523 .52912 L .56739 .52837 L F
.748 .956 .654 r
.56998 .48587 m .569 .48782 L .57144 .48482 L F
.746 .988 .893 r
.56998 .48587 m .56836 .48748 L .569 .48782 L F
.795 .685 .743 r
.63952 .41309 m .63641 .41403 L .6389 .41039 L F
.896 .85 .79 r
.63952 .41309 m .63632 .41571 L .63641 .41403 L F
0 .132 .664 r
.59766 .45145 m .59948 .45331 L .59883 .4551 L F
0 0 .47 r
.59948 .45331 m .59972 .45731 L .59883 .4551 L F
.729 .312 .256 r
.17489 .62711 m .17561 .62721 L .17529 .62679 L F
.935 .56 .196 r
.47885 .57091 m .47962 .57378 L .47804 .57167 L F
.79 .708 .773 r
.68593 .45485 m .68914 .45547 L .68773 .45383 L F
.852 .821 .818 r
.68546 .45724 m .68914 .45547 L .68593 .45485 L F
.759 .781 .87 r
.68914 .45547 m .69084 .45118 L .68773 .45383 L F
.68914 .45547 m .69157 .4544 L .69084 .45118 L F
.818 .739 .777 r
.78012 .41933 m .77662 .41889 L .77861 .41597 L F
.534 .599 .865 r
.78143 .41822 m .78012 .41933 L .77861 .41597 L F
.234 .186 .596 r
.78084 .42138 m .78012 .41933 L .78143 .41822 L F
.72 .756 .881 r
.69084 .45118 m .69157 .4544 L .69446 .45169 L F
0 0 0 r
.2242 .55304 m .22227 .55349 L .21912 .55401 L F
.351 0 0 r
.2244 .55372 m .2242 .55304 L .22623 .55341 L F
.2244 .55372 m .22227 .55349 L .2242 .55304 L F
.79 .928 .926 r
.45511 .58989 m .4523 .59202 L .45312 .58894 L F
.854 .982 .859 r
.4523 .59202 m .45141 .59143 L .45312 .58894 L F
.244 0 0 r
.45499 .59181 m .45126 .59305 L .4523 .59202 L F
.386 .191 .49 r
.55766 .56177 m .55742 .5644 L .5546 .56536 L F
.372 .16 .457 r
.5546 .56536 m .55618 .56583 L .55415 .56691 L F
.5546 .56536 m .55742 .5644 L .55618 .56583 L F
.731 .412 .44 r
.18679 .68071 m .18713 .68073 L .18697 .68031 L F
.692 .393 .464 r
.18697 .68031 m .18713 .68073 L .18932 .68066 L F
.856 .694 .681 r
.60699 .46885 m .60523 .47228 L .60376 .46876 L F
.117 .214 .689 r
.2435 .55881 m .24435 .56222 L .24538 .56069 L F
0 0 .392 r
.24483 .56471 m .24538 .56069 L .24435 .56222 L F
.708 .965 .718 r
.55693 .58875 m .55961 .58613 L .55805 .58692 L F
.32 .082 .388 r
.56221 .58604 m .56192 .58502 L .55961 .58613 L F
.725 .319 .278 r
.56245 .58689 m .56192 .58502 L .56415 .58716 L F
.32 .082 .388 r
.56232 .58603 m .56192 .58502 L .56221 .58604 L F
.725 .319 .278 r
.56142 .58549 m .56192 .58502 L .56221 .58604 L F
0 0 0 r
.55961 .58613 m .56192 .58502 L .56142 .58549 L F
.32 .082 .388 r
.56221 .58604 m .55961 .58613 L .55833 .5833 L F
0 0 0 r
.55961 .58613 m .56142 .58549 L .5603 .58654 L F
.32 .082 .388 r
.56232 .58603 m .56221 .58604 L .56152 .58545 L F
.56159 .58543 m .56152 .58545 L .55793 .58241 L F
.56232 .58603 m .56152 .58545 L .56159 .58543 L F
.56221 .58604 m .55833 .5833 L .55793 .58241 L F
.725 .319 .278 r
.5603 .58654 m .56142 .58549 L .56245 .58689 L F
.56142 .58549 m .56221 .58604 L .56245 .58689 L F
0 0 0 r
.55961 .58613 m .5603 .58654 L .55805 .58692 L F
.744 .222 0 r
.45701 .58814 m .45333 .58521 L .45684 .5859 L F
.57 .394 .604 r
.45942 .58244 m .45995 .58581 L .45684 .5859 L F
.557 .326 .52 r
.45995 .58581 m .45701 .58814 L .45684 .5859 L F
.138 .67 .863 r
.43513 .57242 m .4372 .57237 L .43869 .5728 L F
0 0 .518 r
.65548 .41011 m .65685 .41234 L .65542 .40887 L F
.708 .965 .718 r
.55693 .58875 m .55805 .58692 L .55588 .58728 L F
.445 .06 .214 r
.62161 .40693 m .62427 .40656 L .62503 .40457 L F
.356 0 .138 r
.62427 .40656 m .62746 .40421 L .62503 .40457 L F
.469 .185 .399 r
.40839 .60874 m .40654 .60737 L .4087 .60606 L F
.40839 .60874 m .40592 .60936 L .40654 .60737 L F
.558 .4 .624 r
.26321 .59172 m .26341 .59428 L .26113 .59466 L F
.478 .272 .522 r
.26305 .59652 m .26113 .59466 L .26341 .59428 L F
.26305 .59652 m .26088 .59715 L .26113 .59466 L F
.439 .859 .717 r
.4396 .56144 m .44075 .56061 L .44225 .56001 L F
.583 .931 .749 r
.44225 .56001 m .44205 .55942 L .44449 .55918 L F
.537 .377 .612 r
.25646 .60587 m .25419 .60904 L .25455 .60661 L F
.081 0 0 r
.40909 .57917 m .41113 .57856 L .41235 .5775 L F
.248 0 .096 r
.41113 .57856 m .41425 .57633 L .41235 .5775 L F
.239 .751 .74 r
.20191 .55374 m .20034 .55402 L .1981 .55466 L F
.023 .594 .761 r
.20406 .55424 m .20034 .55402 L .20191 .55374 L F
.591 .466 .678 r
.44901 .57771 m .45203 .57926 L .45099 .5761 L F
.996 .802 .529 r
.76628 .415 m .76806 .41407 L .76598 .41247 L F
.76628 .415 m .76736 .41619 L .76806 .41407 L F
.409 .198 .478 r
.48638 .59171 m .48853 .59127 L .48872 .58866 L F
.48638 .59171 m .48853 .59127 L .48872 .58866 L F
.431 .187 .442 r
.24201 .62621 m .24226 .62944 L .24011 .62995 L F
.412 .212 .496 r
.24505 .62387 m .24481 .62652 L .24201 .62621 L F
.364 .115 .397 r
.24481 .62652 m .24226 .62944 L .24201 .62621 L F
.125 0 0 r
.16294 .54947 m .16511 .54897 L .16708 .54727 L F
0 0 0 r
.16708 .54727 m .16697 .54795 L .16929 .54679 L F
.16708 .54727 m .16511 .54897 L .16697 .54795 L F
.987 .898 .612 r
.64926 .43292 m .65079 .43174 L .65024 .42933 L F
.64926 .43292 m .65 .43401 L .65079 .43174 L F
.605 .834 .987 r
.45942 .58244 m .45567 .58206 L .45824 .58101 L F
.762 .861 .923 r
.46127 .58019 m .45942 .58244 L .45824 .58101 L F
.323 .224 .585 r
.4614 .58433 m .45995 .58581 L .45942 .58244 L F
.704 .928 .965 r
.73849 .43029 m .73621 .43153 L .73754 .42941 L F
.739 .975 .924 r
.73754 .42941 m .73621 .43153 L .73554 .43094 L F
.692 .252 .201 r
.52846 .5322 m .52815 .53384 L .52877 .53261 L F
0 0 .2 r
.52813 .53625 m .52701 .53799 L .52877 .53261 L F
.52804 .53675 m .52789 .53694 L .52813 .53625 L F
.52789 .53694 m .52701 .53799 L .52813 .53625 L F
.728 .625 .743 r
.53024 .53113 m .53139 .53431 L .52894 .53396 L F
0 0 .2 r
.52804 .53675 m .52877 .53261 L .52815 .53384 L F
.728 .625 .743 r
.52968 .53186 m .52894 .53396 L .52815 .53384 L F
.53024 .53113 m .52894 .53396 L .52968 .53186 L F
0 0 .029 r
.53024 .53113 m .52815 .53384 L .52846 .5322 L F
.63 .943 .954 r
.68647 .40582 m .68963 .40437 L .68895 .40593 L F
.163 0 0 r
.68627 .40676 m .68647 .40582 L .68895 .40593 L F
.315 .238 .608 r
.50807 .59226 m .51005 .59204 L .50984 .59112 L F
.839 .723 .737 r
.54151 .53469 m .5423 .53723 L .5423 .53505 L F
.54151 .53469 m .53987 .53763 L .5423 .53723 L F
.722 .353 .349 r
.53987 .53763 m .5416 .53977 L .5423 .53723 L F
.348 0 .068 r
.5416 .53977 m .54563 .53766 L .5423 .53723 L F
.693 .894 .527 r
.57243 .48298 m .57144 .48482 L .57367 .48166 L F
.726 .95 .652 r
.57243 .48298 m .56998 .48587 L .57144 .48482 L F
0 .142 .679 r
.54674 .58819 m .54364 .58471 L .54539 .5859 L F
.718 .266 .175 r
.54211 .5848 m .54539 .5859 L .54364 .58471 L F
.536 .253 .432 r
.45186 .56481 m .45176 .56683 L .44961 .56518 L F
.545 .003 0 r
.41193 .64676 m .41017 .6473 L .40803 .6466 L F
.19 0 0 r
.41413 .64683 m .41017 .6473 L .41193 .64676 L F
.061 .542 .893 r
.23406 .55556 m .2326 .55456 L .22974 .55387 L F
.233 .661 .958 r
.23406 .55556 m .23605 .55571 L .2326 .55456 L F
.472 .46 .764 r
.24316 .57112 m .24611 .57312 L .24518 .56986 L F
.453 .461 .777 r
.24316 .57112 m .24512 .57416 L .24611 .57312 L F
.694 .53 .661 r
.55135 .53523 m .55374 .53469 L .55374 .53222 L F
.661 .499 .654 r
.55374 .53469 m .5564 .53192 L .55374 .53222 L F
.353 0 .119 r
.38722 .59374 m .38897 .59392 L .39037 .59187 L F
.556 .158 .243 r
.39037 .59187 m .38897 .59392 L .39232 .59342 L F
.501 .183 .36 r
.39037 .59187 m .39232 .59342 L .39274 .59156 L F
.858 .861 .842 r
.72636 .43035 m .72371 .4337 L .72336 .43095 L F
.831 .747 .771 r
.71817 .43642 m .72109 .43682 L .71902 .43974 L F
.922 .839 .746 r
.47668 .57686 m .47739 .58058 L .47621 .57901 L F
.563 .712 .941 r
.47785 .58089 m .47855 .57837 L .47621 .57901 L F
.47785 .58089 m .47975 .58044 L .47855 .57837 L F
.72 .447 .512 r
.5423 .53505 m .54351 .53177 L .54151 .53469 L F
.827 .7 .724 r
.60523 .47228 m .60657 .47583 L .60336 .47529 L F
.917 .874 .78 r
.60657 .47583 m .60355 .47757 L .60336 .47529 L F
.60657 .47583 m .60462 .4787 L .60355 .47757 L F
.525 .609 .879 r
.72367 .40256 m .72711 .40479 L .72585 .40213 L F
.46 .552 .862 r
.72585 .40213 m .72711 .40479 L .72869 .4026 L F
.551 .68 .924 r
.72711 .40479 m .73005 .40456 L .72869 .4026 L F
.481 .172 .365 r
.37929 .59758 m .38114 .59911 L .38165 .59715 L F
.37929 .59758 m .37877 .59964 L .38114 .59911 L F
.483 0 0 r
.48418 .58 m .48241 .58126 L .47975 .58044 L F
.469 .404 .701 r
.4849 .57555 m .48688 .57992 L .48418 .58 L F
.466 .336 .62 r
.48688 .57992 m .4859 .58144 L .48418 .58 L F
.693 .234 .158 r
.4859 .58144 m .48241 .58126 L .48418 .58 L F
.104 .473 .894 r
.52079 .57821 m .52303 .5799 L .52306 .57872 L F
.044 .081 .575 r
.52303 .5799 m .52511 .58067 L .52306 .57872 L F
.52303 .5799 m .52382 .58231 L .52511 .58067 L F
.241 .572 .94 r
.39853 .64191 m .39906 .64067 L .39774 .64061 L F
.14 .449 .881 r
.39853 .64191 m .39997 .64217 L .39906 .64067 L F
.951 .954 .676 r
.63114 .45078 m .63198 .44928 L .6304 .45024 L F
.938 .964 .685 r
.6304 .45024 m .63198 .44928 L .63156 .44838 L F
.75 .729 .203 r
.6338 .41328 m .63309 .41674 L .63297 .41765 L F
.437 .008 .125 r
.63297 .41765 m .63452 .41676 L .63312 .41907 L F
.63452 .41676 m .63632 .41571 L .63522 .41687 L F
.63452 .41676 m .63522 .41687 L .63312 .41907 L F
.983 .892 .651 r
.63492 .414 m .63368 .41661 L .6338 .41328 L F
.566 .844 .997 r
.63312 .41907 m .63278 .41912 L .63297 .41765 L F
.611 .252 .336 r
.63286 .41851 m .63326 .41864 L .63297 .41765 L F
.63326 .41864 m .63513 .41926 L .63371 .4182 L F
.63326 .41864 m .63371 .4182 L .63297 .41765 L F
.437 .008 .125 r
.63297 .41765 m .6327 .41867 L .63338 .41811 L F
.077 .493 .897 r
.63349 .41804 m .63331 .41803 L .63297 .41765 L F
.437 .008 .125 r
.63297 .41765 m .63338 .41811 L .63632 .41571 L F
.077 .493 .897 r
.63371 .4182 m .63301 .418 L .63349 .41804 L F
.932 .773 .662 r
.63601 .41597 m .6327 .41867 L .6363 .41569 L F
.077 .493 .897 r
.63513 .41926 m .63284 .41799 L .63301 .418 L F
.63513 .41926 m .63301 .418 L .63371 .4182 L F
.932 .773 .662 r
.6363 .41569 m .63338 .41811 L .63492 .414 L F
.63338 .41811 m .6327 .41867 L .63301 .418 L F
.63338 .41811 m .63301 .418 L .63492 .414 L F
.63632 .41571 m .63601 .41597 L .6363 .41569 L F
.077 .493 .897 r
.63331 .41803 m .63284 .41799 L .63297 .41765 L F
.63513 .41926 m .63282 .41802 L .63284 .41799 L F
.983 .892 .651 r
.63368 .41661 m .63301 .418 L .63314 .41652 L F
.566 .844 .997 r
.63278 .41912 m .63131 .41935 L .63297 .41765 L F
.162 .483 .899 r
.63131 .41935 m .63286 .41851 L .63297 .41765 L F
.75 .729 .203 r
.63284 .41799 m .6327 .41867 L .63297 .41765 L F
.983 .892 .651 r
.63301 .418 m .6327 .41867 L .63284 .41799 L F
.75 .729 .203 r
.63309 .41674 m .63284 .41799 L .63297 .41765 L F
.983 .892 .651 r
.63301 .418 m .63284 .41799 L .63314 .41652 L F
.63368 .41661 m .63314 .41652 L .6338 .41328 L F
.077 .493 .897 r
.63282 .41802 m .63115 .41711 L .63297 .41765 L F
.162 .483 .899 r
.63131 .41935 m .63368 .42061 L .63286 .41851 L F
0 .08 .623 r
.39082 .63624 m .39155 .63496 L .38995 .63295 L F
.263 .56 .933 r
.39082 .63624 m .3925 .63628 L .39155 .63496 L F
.746 .653 .757 r
.71192 .43673 m .71253 .43781 L .70964 .43723 L F
.62 .603 .812 r
.71545 .43701 m .71253 .43781 L .71192 .43673 L F
.343 .618 .953 r
.18759 .6415 m .18369 .63937 L .18521 .63907 L F
.606 .754 .949 r
.18802 .63889 m .18759 .6415 L .18521 .63907 L F
.18802 .63889 m .18972 .64083 L .18759 .6415 L F
.176 .609 .94 r
.47608 .56236 m .47323 .56259 L .47228 .56169 L F
.47608 .56236 m .47673 .56325 L .47323 .56259 L F
.426 .317 .626 r
.48614 .58434 m .4859 .58144 L .48747 .58275 L F
.582 .552 .786 r
.48837 .57871 m .48747 .58275 L .4859 .58144 L F
.24 0 0 r
.48747 .58275 m .48848 .58382 L .48614 .58434 L F
.558 .275 .443 r
.63085 .40388 m .63345 .40349 L .6335 .40116 L F
.56 .277 .443 r
.6335 .40116 m .63599 .40306 L .63596 .40076 L F
.494 0 0 r
.51245 .54364 m .51377 .54435 L .5162 .54416 L F
.485 .897 .912 r
.5162 .54416 m .51774 .54298 L .51807 .54296 L F
.5162 .54416 m .51377 .54435 L .51774 .54298 L F
.501 .393 .663 r
.21556 .61534 m .21739 .61178 L .216 .61254 L F
.903 .982 .719 r
.51937 .54174 m .51807 .54296 L .51985 .54042 L F
.627 .842 .452 r
.57598 .47835 m .57476 .47992 L .57367 .48166 L F
.649 .877 .517 r
.57476 .47992 m .57243 .48298 L .57367 .48166 L F
.549 .831 .489 r
.23808 .58872 m .23545 .59169 L .23678 .59016 L F
.377 .515 .869 r
.23613 .58547 m .23808 .58872 L .2393 .58772 L F
.368 .078 .335 r
.23678 .59016 m .2393 .58772 L .23808 .58872 L F
.545 .884 .987 r
.46758 .56284 m .46383 .56288 L .46693 .56263 L F
.133 .681 .778 r
.46929 .56261 m .46758 .56284 L .46693 .56263 L F
.46929 .56261 m .47038 .56257 L .46758 .56284 L F
.945 .958 .724 r
.60989 .49569 m .61102 .49404 L .60915 .4949 L F
.89 .98 .817 r
.61102 .49404 m .6134 .49106 L .61118 .49167 L F
.912 .981 .749 r
.60915 .4949 m .61102 .49404 L .61118 .49167 L F
0 0 0 r
.43129 .56782 m .4284 .56986 L .42922 .56908 L F
0 .154 .695 r
.51545 .56207 m .51729 .56492 L .51735 .56375 L F
0 0 .305 r
.51729 .56492 m .51826 .56602 L .51735 .56375 L F
.51729 .56492 m .5173 .56767 L .51826 .56602 L F
.809 .619 .645 r
.54351 .53177 m .54403 .52933 L .54027 .52866 L F
.6 .784 .968 r
.75071 .41512 m .74869 .416 L .74929 .41384 L F
.75071 .41512 m .74869 .416 L .74929 .41384 L F
.864 .695 .672 r
.77377 .42179 m .77515 .42522 L .77385 .42459 L F
.864 .468 .285 r
.77385 .42459 m .77515 .42522 L .77573 .427 L F
.583 .312 .471 r
.77515 .42522 m .77772 .42706 L .77573 .427 L F
.649 .792 .951 r
.72004 .39119 m .7187 .39372 L .71755 .39212 L F
.72004 .39119 m .7212 .39275 L .7187 .39372 L F
.181 .339 .788 r
.52382 .58231 m .5253 .5857 L .52637 .58418 L F
.04 .1 .599 r
.52599 .58811 m .52637 .58418 L .5253 .5857 L F
.52 .196 .359 r
.43251 .64385 m .43467 .6437 L .43228 .6422 L F
.569 .127 .162 r
.43228 .6422 m .43467 .6437 L .43516 .64259 L F
.256 .499 .896 r
.3925 .63628 m .39463 .63914 L .39545 .63773 L F
.234 .47 .881 r
.39463 .63914 m .39774 .64061 L .39545 .63773 L F
.96 .765 .596 r
.43308 .60147 m .43148 .60241 L .43193 .60003 L F
.721 .774 .894 r
.43193 .60003 m .43308 .60147 L .43528 .60018 L F
.402 .072 .288 r
.62426 .4169 m .62428 .41824 L .6217 .41888 L F
.245 0 0 r
.62767 .4188 m .62428 .41824 L .62426 .4169 L F
.605 .929 .705 r
.57874 .47607 m .57723 .47687 L .57598 .47835 L F
0 0 0 r
.57723 .47687 m .57476 .47992 L .57598 .47835 L F
.996 .761 .447 r
.77772 .42706 m .77883 .42849 L .77859 .4305 L F
.322 .112 .431 r
.77859 .4305 m .77883 .42849 L .78066 .42716 L F
.193 .716 .696 r
.18558 .54276 m .18963 .5417 L .18747 .54179 L F
.108 0 0 r
.1936 .55624 m .19187 .55706 L .19055 .55702 L F
.315 .805 .815 r
.19621 .55607 m .19187 .55706 L .1936 .55624 L F
0 0 0 r
.43095 .56752 m .43201 .56742 L .43279 .5642 L F
.43095 .56752 m .43087 .5679 L .43201 .56742 L F
.856 .634 .6 r
.65918 .43922 m .66123 .4429 L .66151 .44025 L F
.666 .804 .949 r
.71215 .45135 m .71568 .45178 L .71462 .45034 L F
.769 .831 .9 r
.71568 .45178 m .71737 .44803 L .71462 .45034 L F
.71568 .45178 m .7186 .4498 L .71737 .44803 L F
.644 .802 .959 r
.7247 .39325 m .7212 .39275 L .72361 .39174 L F
.623 .771 .951 r
.72611 .39087 m .7247 .39325 L .72361 .39174 L F
.72611 .39087 m .72724 .39242 L .7247 .39325 L F
.269 .006 .317 r
.23191 .64087 m .23089 .63948 L .2324 .63854 L F
.23191 .64087 m .23011 .6417 L .23089 .63948 L F
.334 .043 .314 r
.46335 .60047 m .46611 .59776 L .46212 .59677 L F
.46335 .60047 m .46575 .59973 L .46611 .59776 L F
.46611 .59776 m .46575 .59973 L .46335 .60047 L F
.08 0 .227 r
.46736 .59758 m .46575 .59973 L .46611 .59776 L F
.46736 .59758 m .46575 .59973 L .46611 .59776 L F
.391 .192 .486 r
.25865 .60285 m .25646 .60587 L .25693 .60364 L F
.497 .27 .499 r
.48872 .58866 m .49086 .59069 L .49091 .58806 L F
.48872 .58866 m .48853 .59127 L .49086 .59069 L F
.48872 .58866 m .49086 .59069 L .49091 .58806 L F
.48872 .58866 m .48853 .59127 L .49086 .59069 L F
.287 .317 .718 r
.23545 .59169 m .23766 .59365 L .23678 .59016 L F
.424 .329 .643 r
.23584 .59423 m .23766 .59365 L .23545 .59169 L F
.398 .78 .991 r
.22375 .5408 m .22584 .54053 L .22761 .54137 L F
.301 .721 .973 r
.22584 .54053 m .22983 .54142 L .22761 .54137 L F
.394 .134 .396 r
.55234 .59996 m .55276 .59785 L .55495 .59709 L F
.63 .413 .569 r
.42918 .57253 m .43063 .57526 L .43275 .57327 L F
.876 .973 .845 r
.61368 .48862 m .6134 .49106 L .61585 .48821 L F
.892 .979 .816 r
.61118 .49167 m .6134 .49106 L .61368 .48862 L F
.85 .857 .847 r
.72325 .44541 m .72693 .44387 L .72585 .44252 L F
.799 .854 .892 r
.72585 .44252 m .72693 .44387 L .72857 .44257 L F
.121 0 .105 r
.23395 .63788 m .23338 .63677 L .23504 .63602 L F
.23395 .63788 m .2324 .63854 L .23338 .63677 L F
.408 .327 .653 r
.63237 .41491 m .63035 .41768 L .63003 .41342 L F
.594 .513 .732 r
.74148 .40001 m .73834 .40099 L .73801 .39866 L F
.996 .762 .423 r
.74148 .40001 m .73894 .40214 L .73834 .40099 L F
.238 0 .293 r
.74459 .42808 m .74702 .42774 L .7467 .42671 L F
.315 .295 .677 r
.74459 .42808 m .74669 .43009 L .74702 .42774 L F
.725 .492 .574 r
.21507 .58765 m .21839 .58547 L .21599 .58549 L F
.82 .881 .889 r
.51289 .52682 m .50833 .52815 L .50924 .52703 L F
.856 .944 .876 r
.51419 .52496 m .51289 .52682 L .51308 .5242 L F
.88 .959 .849 r
.51308 .5242 m .51289 .52682 L .50924 .52703 L F
.647 .82 .395 r
.78066 .42716 m .78168 .42546 L .78281 .42338 L F
.684 .437 .542 r
.48856 .5738 m .48869 .5763 L .4849 .57555 L F
.794 .523 .528 r
.49238 .5768 m .48869 .5763 L .48856 .5738 L F
.711 .609 .741 r
.41739 .60271 m .41481 .60373 L .41726 .6015 L F
0 0 0 r
.24156 .57713 m .23905 .57967 L .24076 .57866 L F
.438 .045 .196 r
.24076 .57866 m .24317 .5785 L .24156 .57713 L F
.488 .242 .467 r
.24156 .57713 m .24422 .57682 L .24512 .57416 L F
.415 .051 .236 r
.24156 .57713 m .24317 .5785 L .24422 .57682 L F
.464 .126 .307 r
.40574 .58209 m .40835 .58186 L .40909 .57917 L F
.378 .071 .313 r
.40835 .58186 m .41113 .57856 L .40909 .57917 L F
.659 .747 .915 r
.72003 .40161 m .72367 .40256 L .72248 .40051 L F
.561 .678 .917 r
.72248 .40051 m .72367 .40256 L .72585 .40213 L F
.762 .653 .741 r
.7431 .39255 m .7412 .39755 L .73937 .39184 L F
.046 0 .367 r
.19492 .68695 m .19606 .68625 L .19644 .68328 L F
.346 .531 .894 r
.19492 .68695 m .19647 .68791 L .19606 .68625 L F
.71 .473 .564 r
.19492 .68695 m .1942 .68927 L .19647 .68791 L F
.573 .406 .617 r
.56092 .55022 m .56098 .5525 L .55844 .55314 L F
.509 .346 .595 r
.56087 .55501 m .55844 .55314 L .56098 .5525 L F
.56087 .55501 m .55841 .55587 L .55844 .55314 L F
.842 .95 .598 r
.54636 .51159 m .54828 .50819 L .54693 .50945 L F
.853 .992 .735 r
.54636 .51159 m .54693 .50945 L .54453 .5126 L F
.886 .987 .728 r
.54426 .51468 m .54636 .51159 L .54453 .5126 L F
.646 .67 .859 r
.17773 .63912 m .17827 .63908 L .17783 .63929 L F
.222 0 .249 r
.47399 .58338 m .47217 .5831 L .47397 .58175 L F
.47399 .58338 m .47155 .58496 L .47217 .5831 L F
.548 .086 .109 r
.43467 .6437 m .43851 .64233 L .43516 .64259 L F
.43467 .6437 m .43678 .64405 L .43851 .64233 L F
.752 .341 .272 r
.43851 .64233 m .43678 .64405 L .44017 .64415 L F
.751 .929 .577 r
.60446 .42505 m .60229 .42823 L .60336 .42599 L F
.478 .476 .777 r
.60247 .43069 m .60336 .42599 L .60229 .42823 L F
.873 .731 .702 r
.53268 .68012 m .53551 .67995 L .53517 .68181 L F
.528 .739 .972 r
.75167 .39143 m .74916 .39185 L .74805 .39033 L F
.389 .664 .968 r
.25347 .54348 m .25315 .5452 L .25149 .54366 L F
.25347 .54348 m .25583 .54541 L .25315 .5452 L F
.93 .966 .76 r
.66665 .41146 m .66897 .40799 L .66813 .40735 L F
.677 .358 0 r
.52902 .5911 m .53027 .59456 L .52981 .5933 L F
.72 .519 0 r
.53027 .59456 m .53035 .59565 L .52981 .5933 L F
.53027 .59456 m .53055 .59697 L .53035 .59565 L F
.396 .499 .846 r
.27113 .55115 m .26996 .55333 L .26877 .55155 L F
.595 .435 .634 r
.56551 .54425 m .56597 .54676 L .56341 .54694 L F
.592 .399 .59 r
.56597 .54676 m .56345 .54968 L .56341 .54694 L F
.38 .102 .36 r
.59325 .44341 m .59519 .44447 L .5956 .44254 L F
.59325 .44341 m .59292 .44524 L .59519 .44447 L F
.38 .198 .506 r
.58247 .5354 m .58472 .53185 L .58498 .53443 L F
.394 .176 .46 r
.58221 .53776 m .58247 .5354 L .58498 .53443 L F
.446 .097 .279 r
.23538 .58213 m .2378 .58196 L .23905 .57967 L F
.457 .108 .285 r
.23905 .57967 m .24075 .58138 L .24076 .57866 L F
.23905 .57967 m .2378 .58196 L .24075 .58138 L F
.599 .291 .419 r
.57684 .53802 m .57927 .54022 L .57656 .54069 L F
.57684 .53802 m .57944 .53801 L .57927 .54022 L F
.708 .795 .321 r
.20044 .69508 m .19926 .69805 L .20017 .69589 L F
.416 .134 .375 r
.22375 .60939 m .2259 .60881 L .22666 .60674 L F
.428 .146 .381 r
.22666 .60674 m .22808 .60829 L .22836 .60583 L F
.22666 .60674 m .2259 .60881 L .22808 .60829 L F
.953 .849 .701 r
.62643 .46427 m .62663 .45979 L .62485 .46306 L F
.908 .799 .728 r
.62485 .46306 m .62572 .46631 L .62643 .46427 L F
.901 .791 .73 r
.46096 .60348 m .45786 .60495 L .45983 .60429 L F
.505 0 0 r
.46178 .60437 m .46096 .60348 L .45983 .60429 L F
.46178 .60437 m .46341 .60541 L .46096 .60348 L F
.424 .062 .244 r
.60993 .43426 m .60899 .43635 L .60658 .43694 L F
.303 .123 .463 r
.61179 .43321 m .60993 .43426 L .61192 .43087 L F
.998 .794 .497 r
.60839 .43508 m .60993 .43426 L .61179 .43321 L F
.60839 .43508 m .60899 .43635 L .60993 .43426 L F
.229 .392 .819 r
.75914 .39745 m .76072 .40071 L .75941 .39929 L F
.302 .167 .524 r
.26507 .59102 m .26341 .59428 L .26321 .59172 L F
.75 .687 .791 r
.42451 .63901 m .42245 .64179 L .42638 .64197 L F
.749 .43 .443 r
.42237 .64342 m .42638 .64197 L .42245 .64179 L F
.42237 .64342 m .42479 .64445 L .42638 .64197 L F
.731 .407 .432 r
.42638 .64197 m .42479 .64445 L .42859 .64464 L F
.724 .685 .812 r
.71817 .43642 m .71902 .43974 L .71546 .43928 L F
0 0 0 r
.59269 .49675 m .59201 .49852 L .59409 .4949 L F
.163 0 .082 r
.54377 .54366 m .54288 .54576 L .54081 .54676 L F
.63 .393 .54 r
.54566 .54291 m .54288 .54576 L .54377 .54366 L F
.754 .638 .732 r
.1869 .68106 m .18713 .68073 L .18679 .68071 L F
.519 .064 .11 r
.18963 .5417 m .19159 .54262 L .19347 .54086 L F
.104 0 0 r
.19347 .54086 m .19371 .54193 L .19571 .54069 L F
.19347 .54086 m .19159 .54262 L .19371 .54193 L F
.62 .538 .74 r
.41943 .60009 m .41739 .60271 L .41726 .6015 L F
.41943 .60009 m .42185 .60434 L .41739 .60271 L F
.776 .959 .928 r
.67753 .40695 m .68009 .40621 L .67983 .40599 L F
.095 .64 .84 r
.68009 .40621 m .6838 .40634 L .67983 .40599 L F
.783 .762 .834 r
.63477 .40974 m .63238 .41244 L .633 .41094 L F
.102 0 0 r
.19943 .70346 m .19698 .70426 L .19702 .70391 L F
.955 .932 .731 r
.5427 .51691 m .54426 .51468 L .54198 .51575 L F
.874 .994 .791 r
.54426 .51468 m .54453 .5126 L .54198 .51575 L F
.66 .645 .824 r
.49095 .57078 m .48707 .569 L .48995 .56896 L F
.702 .749 .888 r
.49379 .56976 m .49095 .57078 L .48995 .56896 L F
0 0 .415 r
.3758 .62692 m .37694 .62565 L .37675 .62302 L F
.247 .502 .9 r
.3758 .62692 m .37812 .62768 L .37694 .62565 L F
.428 .187 .445 r
.58574 .45197 m .58804 .45124 L .58831 .4491 L F
.445 .202 .45 r
.58831 .4491 m .59038 .45053 L .59053 .44826 L F
.58831 .4491 m .58804 .45124 L .59038 .45053 L F
.62 .603 .812 r
.71545 .43701 m .71422 .43354 L .71573 .43338 L F
.529 .577 .847 r
.71671 .43128 m .71573 .43338 L .71422 .43354 L F
.71671 .43128 m .71849 .4354 L .71573 .43338 L F
.63 .453 .625 r
.71817 .43642 m .71545 .43701 L .71573 .43338 L F
0 0 0 r
.68525 .39773 m .68221 .39802 L .68484 .3981 L F
.68735 .39742 m .68525 .39773 L .68484 .3981 L F
.643 .681 .871 r
.18011 .63831 m .17773 .63912 L .17623 .63665 L F
.18011 .63831 m .17827 .63908 L .17773 .63912 L F
0 0 .121 r
.65716 .43079 m .65725 .43379 L .65716 .42966 L F
0 .153 .694 r
.65663 .43385 m .65842 .4356 L .65746 .43356 L F
.65663 .43385 m .65746 .43356 L .65725 .43379 L F
0 0 .121 r
.65716 .43079 m .65663 .43385 L .65725 .43379 L F
.572 .47 .699 r
.63259 .42513 m .63017 .42852 L .6291 .42474 L F
.63259 .42513 m .63266 .42781 L .63017 .42852 L F
.767 .561 .619 r
.49238 .5768 m .48837 .57871 L .48869 .5763 L F
.982 .852 .47 r
.66296 .43168 m .66297 .42688 L .66287 .42954 L F
.945 .959 .686 r
.66186 .43364 m .66296 .43168 L .66287 .42954 L F
.863 .486 .329 r
.54774 .53957 m .54915 .53822 L .54706 .53751 L F
.998 .817 .533 r
.54865 .54144 m .54915 .53822 L .54774 .53957 L F
.758 .663 .756 r
.54915 .53822 m .5479 .53425 L .54706 .53751 L F
.54915 .53822 m .55135 .53523 L .5479 .53425 L F
.815 .71 .749 r
.64028 .40551 m .63855 .4027 L .64012 .40437 L F
.825 .602 .6 r
.64028 .40551 m .63756 .40703 L .63611 .40501 L F
0 0 .464 r
.64012 .40437 m .64093 .40732 L .64028 .40551 L F
.81 .729 .775 r
.64093 .40732 m .63756 .40703 L .64028 .40551 L F
.683 .351 .408 r
.42687 .60346 m .42727 .60582 L .42279 .60527 L F
.663 .338 .412 r
.42923 .60543 m .42687 .60346 L .42774 .60198 L F
.42923 .60543 m .42727 .60582 L .42687 .60346 L F
0 .026 .573 r
.2007 .7002 m .19961 .70073 L .1994 .69915 L F
.376 .292 .632 r
.2007 .7002 m .19943 .70346 L .19961 .70073 L F
.2007 .7002 m .20114 .70293 L .19943 .70346 L F
.118 .11 .572 r
.20225 .70141 m .20114 .70293 L .2007 .7002 L F
.20185 .70114 m .2007 .7002 L .19922 .69936 L F
.20225 .70141 m .2007 .7002 L .20185 .70114 L F
0 .026 .573 r
.2007 .7002 m .1994 .69915 L .19926 .69805 L F
0 0 0 r
.22554 .64519 m .22405 .64722 L .2227 .64766 L F
.252 0 .096 r
.22745 .64446 m .22405 .64722 L .22554 .64519 L F
0 0 .216 r
.52431 .5422 m .52401 .54132 L .52346 .53976 L F
.482 .463 .76 r
.52461 .54346 m .52632 .54136 L .52401 .54132 L F
.583 .531 .762 r
.52959 .54236 m .52683 .54318 L .52644 .54149 L F
.52959 .54236 m .52631 .54145 L .52665 .54072 L F
.489 .146 .312 r
.52701 .53799 m .52677 .54071 L .52966 .53964 L F
.583 .531 .762 r
.52733 .54066 m .52665 .54072 L .52684 .54029 L F
.587 .549 .778 r
.52708 .54068 m .52959 .54236 L .52966 .53964 L F
.583 .531 .762 r
.52959 .54236 m .52665 .54072 L .52708 .54068 L F
.587 .549 .778 r
.52677 .54081 m .52959 .54236 L .52708 .54068 L F
.583 .531 .762 r
.52959 .54236 m .52708 .54068 L .52733 .54066 L F
.489 .146 .312 r
.52677 .54071 m .52677 .54081 L .52708 .54068 L F
.52677 .54071 m .52708 .54068 L .52966 .53964 L F
.482 .463 .76 r
.52639 .54127 m .52683 .54318 L .52677 .54081 L F
.52461 .54346 m .52683 .54318 L .52639 .54127 L F
.583 .531 .762 r
.52644 .54149 m .52683 .54318 L .52631 .54145 L F
.482 .463 .76 r
.52632 .54136 m .52639 .54127 L .52639 .54088 L F
.52639 .54127 m .52659 .54084 L .52639 .54088 L F
.52632 .54136 m .52639 .54088 L .52401 .54132 L F
.21 0 .255 r
.52401 .54132 m .52639 .54088 L .52701 .53799 L F
.772 .641 .717 r
.5257 .53943 m .52621 .54112 L .52431 .5422 L F
.52621 .54112 m .52631 .54145 L .5258 .54164 L F
.52621 .54112 m .5258 .54164 L .52431 .5422 L F
.21 0 .255 r
.52639 .54088 m .52659 .54084 L .52663 .54057 L F
.52639 .54088 m .52663 .54057 L .52701 .53799 L F
.52659 .54084 m .52677 .54081 L .52677 .54071 L F
.52659 .54084 m .52677 .54071 L .52701 .53799 L F
.583 .531 .762 r
.52684 .54029 m .52659 .54084 L .5257 .53943 L F
.52659 .54084 m .52631 .54145 L .52621 .54112 L F
.52659 .54084 m .52621 .54112 L .5257 .53943 L F
.482 .463 .76 r
.52639 .54127 m .52677 .54081 L .52659 .54084 L F
.772 .641 .717 r
.52631 .54145 m .52683 .54318 L .52609 .54289 L F
.52631 .54145 m .52609 .54289 L .52431 .5422 L F
0 0 .216 r
.52431 .5422 m .52461 .54346 L .52401 .54132 L F
.357 .755 .985 r
.24849 .77503 m .24789 .77591 L .24616 .77508 L F
.24849 .77503 m .24789 .77591 L .24616 .77508 L F
.79 .53 .544 r
.51156 .70314 m .51395 .70467 L .51344 .70209 L F
.895 .903 .825 r
.51156 .70314 m .51344 .70209 L .51243 .70096 L F
.753 .265 0 r
.7451 .42143 m .7422 .41989 L .74217 .42139 L F
.527 .363 .602 r
.41551 .59707 m .4156 .59971 L .4132 .59773 L F
.766 .98 .724 r
.54954 .50581 m .54828 .50819 L .55065 .50517 L F
.54954 .50581 m .5481 .50779 L .54828 .50819 L F
.827 .949 .598 r
.54828 .50819 m .5481 .50779 L .54693 .50945 L F
.685 .751 .901 r
.64013 .43367 m .64344 .43469 L .64276 .43254 L F
.486 .622 .91 r
.64276 .43254 m .64344 .43469 L .64495 .43227 L F
.481 .615 .907 r
.64344 .43469 m .64684 .43525 L .64495 .43227 L F
.345 0 0 r
.43622 .56111 m .4396 .56144 L .43754 .5614 L F
.597 .898 .616 r
.43821 .56154 m .43685 .56256 L .43744 .56198 L F
.345 0 0 r
.43622 .56111 m .43821 .56154 L .43857 .56134 L F
.203 0 0 r
.43552 .56105 m .43821 .56154 L .43622 .56111 L F
.663 .794 .945 r
.4371 .55918 m .43821 .56154 L .43552 .56105 L F
.633 .778 .95 r
.44075 .56061 m .43821 .56154 L .4371 .55918 L F
.44075 .56061 m .43797 .55952 L .43975 .55973 L F
.43797 .55952 m .4371 .55918 L .43975 .55973 L F
.345 0 0 r
.43857 .56134 m .43821 .56154 L .4396 .56144 L F
.448 .88 .895 r
.4396 .56144 m .43821 .56154 L .44075 .56061 L F
.597 .898 .616 r
.43821 .56154 m .43975 .55973 L .44075 .56061 L F
.177 0 0 r
.43821 .56154 m .43964 .56206 L .44075 .56061 L F
0 0 0 r
.44075 .56061 m .44236 .55935 L .44205 .55942 L F
.483 .822 .999 r
.43975 .55973 m .44236 .55935 L .44075 .56061 L F
.527 .234 .413 r
.43975 .55973 m .4411 .5615 L .44199 .56 L F
.43975 .55973 m .44199 .56 L .44236 .55935 L F
.597 .898 .616 r
.43821 .56154 m .43744 .56198 L .43975 .55973 L F
.842 .968 .882 r
.53911 .56449 m .54248 .56266 L .54082 .56121 L F
.715 .738 .87 r
.54248 .56266 m .54322 .55959 L .54082 .56121 L F
.54248 .56266 m .54481 .562 L .54322 .55959 L F
.582 .29 .438 r
.54248 .56266 m .54418 .56406 L .54481 .562 L F
.349 .099 .388 r
.26999 .58462 m .26751 .58773 L .26815 .58542 L F
.515 .423 .689 r
.23413 .58577 m .23613 .58547 L .23538 .58213 L F
.788 .691 .758 r
.6378 .43668 m .64133 .43715 L .64013 .43367 L F
.591 .82 .987 r
.6098 .44893 m .60621 .44856 L .60872 .44772 L F
.784 .534 .559 r
.6098 .44893 m .6062 .4508 L .60621 .44856 L F
.6098 .44893 m .60985 .45133 L .60818 .45108 L F
.6098 .44893 m .60818 .45108 L .60749 .45013 L F
.61 .379 .542 r
.60633 .44852 m .60989 .4497 L .60872 .44772 L F
.60621 .44856 m .60641 .44863 L .60633 .44852 L F
.60641 .44863 m .60989 .4497 L .60633 .44852 L F
.784 .534 .559 r
.60749 .45013 m .60818 .45108 L .6062 .4508 L F
.491 .302 .551 r
.61215 .45047 m .6098 .44893 L .60872 .44772 L F
.61215 .45047 m .60985 .45133 L .6098 .44893 L F
.449 .243 .507 r
.2524 .61222 m .25209 .6147 L .24991 .615 L F
.364 .181 .495 r
.25209 .6147 m .24945 .61749 L .24991 .615 L F
.311 .785 .926 r
.22983 .54142 m .23211 .54109 L .23372 .54141 L F
.859 .675 .651 r
.73515 .39763 m .73801 .39866 L .73626 .39859 L F
.305 .574 .935 r
.73515 .39763 m .73626 .39859 L .73587 .39812 L F
.836 .432 .278 r
.73561 .39819 m .73612 .39829 L .73515 .39763 L F
.73587 .39812 m .73801 .39866 L .73515 .39763 L F
.748 .776 .876 r
.73462 .39659 m .73587 .39812 L .73988 .39527 L F
.73587 .39812 m .73626 .39859 L .73651 .39836 L F
.73587 .39812 m .73651 .39836 L .73988 .39527 L F
.836 .432 .278 r
.73612 .39829 m .73651 .39836 L .73587 .39812 L F
.73651 .39836 m .73801 .39866 L .73587 .39812 L F
.305 .574 .935 r
.73515 .39763 m .73587 .39812 L .73462 .39659 L F
.561 .575 .825 r
.73801 .39866 m .73988 .39527 L .73651 .39836 L F
.73801 .39866 m .73651 .39836 L .73626 .39859 L F
.836 .432 .278 r
.7375 .40047 m .73801 .39866 L .73561 .39819 L F
.561 .575 .825 r
.73801 .39866 m .74066 .39845 L .73988 .39527 L F
.996 .762 .423 r
.74148 .40001 m .74098 .40283 L .73894 .40214 L F
.51 .231 .427 r
.74047 .40195 m .73801 .39866 L .7375 .40047 L F
.594 .513 .732 r
.74148 .40001 m .73801 .39866 L .74066 .39845 L F
.51 .231 .427 r
.74047 .40195 m .74066 .39845 L .73801 .39866 L F
.012 .159 .671 r
.44235 .64467 m .4455 .64759 L .44526 .64548 L F
.69 .587 .735 r
.44959 .64608 m .4455 .64759 L .44526 .64548 L F
.44526 .64548 m .4455 .64759 L .44959 .64608 L F
.064 0 .25 r
.24512 .57416 m .24544 .57563 L .24611 .57312 L F
.24512 .57416 m .24422 .57682 L .24544 .57563 L F
.464 .213 .448 r
.58542 .45396 m .58804 .45124 L .58574 .45197 L F
.689 .39 .464 r
.42101 .63675 m .4196 .63932 L .41758 .63874 L F
.42101 .63675 m .41758 .63874 L .42135 .63799 L F
.313 .724 .977 r
.74537 .43374 m .74594 .4345 L .74232 .4337 L F
.599 .705 .918 r
.74594 .4345 m .74708 .4321 L .74669 .43009 L F
.74594 .4345 m .74868 .43392 L .74708 .4321 L F
.74708 .4321 m .74594 .4345 L .74537 .43374 L F
.74708 .4321 m .74868 .43392 L .74594 .4345 L F
.793 .644 .696 r
.17517 .62813 m .17561 .62721 L .17489 .62711 L F
.661 .499 .654 r
.55374 .53469 m .55699 .53479 L .5564 .53192 L F
.637 .372 .501 r
.5597 .53405 m .5564 .53192 L .55699 .53479 L F
.5597 .53405 m .55969 .53181 L .5564 .53192 L F
.735 .74 .855 r
.69446 .45169 m .69615 .45305 L .69637 .45124 L F
.611 .687 .896 r
.69615 .45305 m .69885 .45048 L .69637 .45124 L F
.69615 .45305 m .69981 .453 L .69885 .45048 L F
.58 .649 .883 r
.39997 .64217 m .40187 .64504 L .40448 .6444 L F
0 0 0 r
.19571 .54069 m .19577 .54099 L .19798 .54071 L F
.458 .887 .866 r
.19798 .54071 m .19577 .54099 L .1958 .54097 L F
.095 0 0 r
.19571 .54069 m .19798 .54071 L .19941 .54054 L F
.458 .887 .866 r
.19798 .54071 m .1958 .54097 L .19802 .54 L F
.095 0 0 r
.19941 .54054 m .19798 .54071 L .19959 .54054 L F
.391 .822 .961 r
.19798 .54071 m .20173 .54066 L .19959 .54054 L F
.847 .659 .648 r
.41496 .61112 m .41219 .61163 L .41263 .6091 L F
.084 0 .169 r
.41496 .61112 m .41294 .6139 L .41219 .61163 L F
.41496 .61112 m .41458 .61402 L .41294 .6139 L F
.303 0 .222 r
.41677 .61316 m .41496 .61112 L .41753 .61125 L F
.41677 .61316 m .41458 .61402 L .41496 .61112 L F
.95 .815 .676 r
.54299 .52338 m .54262 .51834 L .54123 .52229 L F
.893 .776 .726 r
.54207 .52567 m .54299 .52338 L .54123 .52229 L F
.847 .968 .877 r
.42307 .57086 m .42357 .56832 L .42538 .568 L F
.42307 .57086 m .42199 .57013 L .42357 .56832 L F
.716 .856 .948 r
.71192 .43673 m .70857 .43612 L .71022 .43495 L F
.71192 .43673 m .70964 .43723 L .70857 .43612 L F
.844 .82 .825 r
.71422 .43354 m .71192 .43673 L .71022 .43495 L F
.62 .603 .812 r
.71545 .43701 m .71192 .43673 L .71422 .43354 L F
.944 .811 .682 r
.62438 .46485 m .62572 .46631 L .62485 .46306 L F
.91 .827 .752 r
.62373 .4697 m .62572 .46631 L .62438 .46485 L F
.639 .733 .916 r
.71385 .4017 m .71761 .40256 L .7164 .40091 L F
.68 .768 .917 r
.71761 .40256 m .71889 .3999 L .7164 .40091 L F
.71761 .40256 m .72003 .40161 L .71889 .3999 L F
.454 .883 .813 r
.22881 .55322 m .22748 .55391 L .22822 .55386 L F
.39 0 0 r
.22822 .55386 m .22701 .55415 L .2244 .55372 L F
.454 .883 .813 r
.22748 .55391 m .22701 .55415 L .22822 .55386 L F
.213 0 0 r
.22923 .5538 m .22822 .55386 L .22623 .55341 L F
.22974 .55387 m .22822 .55386 L .22923 .5538 L F
.449 .791 .998 r
.2326 .55456 m .22822 .55386 L .22974 .55387 L F
.802 .688 .739 r
.19145 .65923 m .19146 .65974 L .18645 .65817 L F
.497 .771 .993 r
.18645 .65817 m .19146 .65974 L .18842 .65722 L F
.617 .821 .979 r
.18842 .65722 m .19146 .65974 L .19098 .65677 L F
.853 .697 .167 r
.19098 .65677 m .19146 .65974 L .19145 .65923 L F
0 0 0 r
.57954 .47575 m .57874 .47607 L .58063 .47445 L F
.57954 .47575 m .57723 .47687 L .57874 .47607 L F
.041 0 .284 r
.60446 .42505 m .60633 .4238 L .60609 .42175 L F
.486 .186 .383 r
.60336 .42599 m .60633 .4238 L .60446 .42505 L F
.536 .349 .574 r
.56831 .54365 m .56597 .54676 L .56551 .54425 L F
.705 .892 .965 r
.70909 .45145 m .70999 .45255 L .71215 .45135 L F
.487 .324 .585 r
.59553 .4399 m .59784 .43926 L .59775 .43674 L F
.46 .275 .542 r
.59553 .4399 m .59783 .44166 L .59784 .43926 L F
.59553 .4399 m .5956 .44254 L .59783 .44166 L F
.379 .148 .433 r
.58075 .51455 m .58314 .5136 L .58339 .51142 L F
.382 .155 .44 r
.58282 .51583 m .58075 .51455 L .58045 .51651 L F
.58282 .51583 m .58314 .5136 L .58075 .51455 L F
.682 .532 .675 r
.63477 .40974 m .63207 .40722 L .63444 .4057 L F
.63477 .40974 m .633 .41094 L .63207 .40722 L F
.426 .216 .49 r
.59065 .446 m .59278 .44746 L .59292 .44524 L F
.59065 .446 m .59053 .44826 L .59278 .44746 L F
.901 .958 .823 r
.61368 .48862 m .61585 .48821 L .61685 .48611 L F
.727 .682 .807 r
.72006 .43316 m .71849 .4354 L .71671 .43128 L F
.797 .835 .88 r
.72954 .42719 m .72715 .42922 L .72587 .42762 L F
.88 .844 .805 r
.72715 .42922 m .72636 .43035 L .72587 .42762 L F
.492 0 0 r
.53376 .54388 m .53819 .54723 L .53537 .54619 L F
.48 .477 .777 r
.55805 .57433 m .5577 .57727 L .55644 .57455 L F
.55805 .57433 m .55969 .57598 L .5577 .57727 L F
.748 .749 .852 r
.70746 .44047 m .70365 .44005 L .70585 .43892 L F
.838 .788 .803 r
.70964 .43723 m .70746 .44047 L .70585 .43892 L F
.427 .191 .452 r
.57595 .52055 m .57835 .51965 L .57866 .51739 L F
.27 .061 .401 r
.57866 .51739 m .58019 .51869 L .58045 .51651 L F
.57866 .51739 m .57835 .51965 L .58019 .51869 L F
.827 .591 .581 r
.53588 .56737 m .53932 .56761 L .53816 .56625 L F
.53588 .56737 m .53907 .57123 L .53932 .56761 L F
0 .444 .714 r
.54734 .59291 m .55087 .59381 L .54896 .59336 L F
.718 .774 .897 r
.41943 .60009 m .41726 .6015 L .4156 .59971 L F
0 0 0 r
.43129 .56782 m .4299 .56926 L .4284 .56986 L F
0 0 .033 r
.4299 .56926 m .42918 .57253 L .4284 .56986 L F
.983 .696 .363 r
.43562 .61547 m .43416 .61458 L .43417 .61182 L F
.56 .569 .82 r
.43797 .61483 m .43562 .61547 L .43417 .61182 L F
.674 .921 .974 r
.43588 .61423 m .43562 .61547 L .43797 .61483 L F
.43588 .61423 m .43416 .61458 L .43562 .61547 L F
.83 .817 .837 r
.72587 .42762 m .72636 .43035 L .72539 .42848 L F
.858 .861 .842 r
.72636 .43035 m .72336 .43095 L .72539 .42848 L F
.585 .272 .404 r
.58921 .46649 m .58821 .46894 L .58573 .46893 L F
.704 .398 .456 r
.59232 .46856 m .58921 .46649 L .59159 .46609 L F
.59232 .46856 m .58821 .46894 L .58921 .46649 L F
.641 .948 .731 r
.55365 .5027 m .55193 .50356 L .55065 .50517 L F
0 0 0 r
.55586 .49913 m .55519 .50044 L .55508 .50095 L F
.638 .941 .709 r
.55508 .50095 m .55365 .5027 L .55497 .50142 L F
0 0 0 r
.55409 .50258 m .55365 .5027 L .55508 .50095 L F
.55519 .50044 m .55409 .50258 L .55508 .50095 L F
.638 .941 .709 r
.55508 .50095 m .55497 .50142 L .55527 .50113 L F
0 0 0 r
.55409 .50258 m .55193 .50356 L .55365 .5027 L F
.779 .516 .538 r
.45043 .64442 m .45218 .6466 L .45244 .64538 L F
.76 .292 .136 r
.45435 .6452 m .45304 .64584 L .45155 .64447 L F
.45304 .64584 m .45244 .64538 L .45155 .64447 L F
.779 .516 .538 r
.45101 .64429 m .45244 .64538 L .45276 .64392 L F
.45043 .64442 m .45218 .6466 L .45244 .64538 L F
.45043 .64442 m .45294 .64589 L .45244 .64538 L F
.45043 .64442 m .45244 .64538 L .45155 .64447 L F
.45043 .64442 m .45244 .64538 L .45276 .64392 L F
.45043 .64442 m .45244 .64538 L .45101 .64429 L F
.76 .292 .136 r
.45304 .64584 m .45294 .64589 L .45244 .64538 L F
.744 .982 .751 r
.45507 .64363 m .45435 .6452 L .45681 .64521 L F
.45507 .64363 m .45294 .64589 L .45435 .6452 L F
.871 .843 .815 r
.47739 .58058 m .47397 .58175 L .47621 .57901 L F
.829 .815 .837 r
.72585 .44252 m .72857 .44257 L .72744 .4414 L F
.763 .809 .889 r
.72857 .44257 m .73044 .43863 L .72744 .4414 L F
.72857 .44257 m .73174 .44013 L .73044 .43863 L F
.575 .405 .614 r
.50331 .58551 m .50348 .58824 L .50093 .58862 L F
.50331 .58551 m .50348 .58824 L .50093 .58862 L F
.344 .805 .934 r
.50093 .58862 m .50293 .58804 L .50348 .58824 L F
.50348 .58824 m .50293 .58804 L .50093 .58862 L F
.50348 .58824 m .50293 .58804 L .50093 .58862 L F
.404 .817 .976 r
.4229 .58811 m .42512 .58764 L .42683 .5882 L F
.551 .883 .989 r
.42683 .5882 m .42512 .58764 L .42768 .58703 L F
0 0 .485 r
.42768 .58703 m .4283 .58848 L .42683 .5882 L F
.833 .5 .424 r
.42857 .5886 m .43175 .58828 L .42924 .58889 L F
.4283 .58848 m .42889 .58845 L .42857 .5886 L F
.42889 .58845 m .43175 .58828 L .42857 .5886 L F
.42889 .58845 m .43046 .58981 L .43175 .58828 L F
.4283 .58848 m .42878 .58878 L .42889 .58845 L F
.42878 .58878 m .43046 .58981 L .42889 .58845 L F
0 .438 .735 r
.42757 .58841 m .42857 .5886 L .42924 .58889 L F
.755 .626 .717 r
.42994 .5871 m .43046 .58981 L .4283 .58848 L F
.823 .669 .692 r
.42994 .5871 m .42824 .58987 L .43046 .58981 L F
.42824 .58987 m .42814 .59003 L .42824 .59002 L F
.42824 .58987 m .42824 .59002 L .43046 .58981 L F
.612 .347 .492 r
.42799 .59171 m .43046 .58981 L .42814 .59003 L F
.42799 .59171 m .43057 .59223 L .43046 .58981 L F
.289 .234 .621 r
.42953 .58891 m .42971 .59148 L .42824 .59168 L F
.42824 .59126 m .42824 .59168 L .42799 .59171 L F
.42953 .58891 m .42824 .59168 L .42824 .59126 L F
0 0 .075 r
.42956 .58878 m .42898 .58867 L .4292 .5883 L F
.42972 .58806 m .4292 .5883 L .42994 .5871 L F
.42956 .58878 m .4292 .5883 L .42972 .58806 L F
.42953 .58891 m .42814 .59003 L .42898 .58867 L F
.42953 .58891 m .42898 .58867 L .42956 .58878 L F
0 .438 .735 r
.42683 .5882 m .4283 .58848 L .42857 .5886 L F
.42683 .5882 m .42857 .5886 L .42757 .58841 L F
.373 .661 .97 r
.43876 .58136 m .43752 .58262 L .43613 .58107 L F
.43876 .58136 m .43752 .58262 L .43613 .58107 L F
.562 .278 .442 r
.60083 .44924 m .60037 .45126 L .59766 .45145 L F
.388 .121 .383 r
.60286 .45038 m .60083 .44924 L .60345 .44823 L F
.60286 .45038 m .60037 .45126 L .60083 .44924 L F
.501 .45 .732 r
.55374 .53469 m .55693 .53737 L .55699 .53479 L F
.55374 .53469 m .55471 .53779 L .55693 .53737 L F
0 0 0 r
.53049 .51133 m .52722 .51329 L .52892 .51243 L F
.52892 .51243 m .52722 .51329 L .5268 .51395 L F
.853 .697 .167 r
.19098 .65677 m .19145 .65923 L .19269 .65885 L F
.573 .352 .542 r
.22321 .61163 m .2259 .60881 L .22375 .60939 L F
.344 .311 .678 r
.1967 .71249 m .19336 .7112 L .19557 .71056 L F
.127 0 0 r
.19188 .71244 m .19557 .71056 L .19336 .7112 L F
.89 .961 .627 r
.61584 .44878 m .61729 .44477 L .6186 .44622 L F
.61584 .44878 m .61551 .4482 L .61729 .44477 L F
.746 .993 .855 r
.61584 .44878 m .61387 .44934 L .61551 .4482 L F
.33 .112 .425 r
.22883 .60348 m .23011 .60516 L .23046 .60266 L F
.22883 .60348 m .22836 .60583 L .23011 .60516 L F
.172 .708 .811 r
.23592 .54111 m .23803 .54086 L .23977 .54087 L F
.091 .639 .829 r
.23803 .54086 m .24165 .54115 L .23977 .54087 L F
.622 .918 .647 r
.55193 .50356 m .54954 .50581 L .55065 .50517 L F
.108 .634 .876 r
.74326 .42159 m .7451 .42143 L .74217 .42139 L F
.74326 .42159 m .74601 .4219 L .7451 .42143 L F
.649 .767 .935 r
.74189 .3909 m .7431 .39255 L .73937 .39184 L F
.697 .787 .92 r
.74532 .39135 m .7431 .39255 L .74189 .3909 L F
.574 .398 .605 r
.56345 .54968 m .56098 .5525 L .56092 .55022 L F
.663 .597 .771 r
.46907 .57052 m .47259 .5729 L .47145 .56984 L F
.724 .677 .804 r
.47145 .56984 m .47259 .5729 L .47515 .57152 L F
.267 .731 .949 r
.55326 .5932 m .55697 .59377 L .55487 .59412 L F
.543 .401 .638 r
.55697 .59377 m .55495 .59709 L .55487 .59412 L F
0 .024 .579 r
.45997 .6074 m .45786 .60495 L .45995 .60612 L F
.678 .529 .675 r
.44957 .58133 m .45084 .5857 L .44724 .58534 L F
.679 .529 .675 r
.45333 .58521 m .44957 .58133 L .4499 .58066 L F
.45333 .58521 m .45084 .5857 L .44957 .58133 L F
.601 .952 .871 r
.42538 .568 m .42644 .56671 L .42834 .56625 L F
.603 .953 .86 r
.42538 .568 m .42357 .56832 L .42644 .56671 L F
.574 .348 .535 r
.23046 .60266 m .23325 .59986 L .23116 .60064 L F
.861 .709 .692 r
.60985 .45133 m .61117 .45496 L .60938 .4535 L F
.413 .587 .913 r
.38632 .6293 m .38634 .62661 L .38366 .62871 L F
.38632 .6293 m .38852 .62938 L .38634 .62661 L F
.823 .77 .802 r
.54322 .55959 m .54481 .562 L .54676 .55858 L F
.411 .253 .555 r
.54676 .55858 m .54481 .562 L .54682 .56121 L F
.298 .025 .32 r
.54481 .562 m .54418 .56406 L .54682 .56121 L F
.827 .798 .823 r
.64684 .43525 m .6474 .43699 L .65 .43401 L F
.15 0 0 r
.22296 .64893 m .2227 .64766 L .22405 .64722 L F
.22296 .64893 m .2209 .64951 L .2227 .64766 L F
.43 .198 .458 r
.57802 .52189 m .57595 .52055 L .57544 .52228 L F
.57802 .52189 m .57835 .51965 L .57595 .52055 L F
.37 .101 .369 r
.61323 .41177 m .61607 .41164 L .61631 .40938 L F
.322 .045 .328 r
.61323 .41177 m .61552 .41362 L .61607 .41164 L F
.61323 .41177 m .61334 .41452 L .61552 .41362 L F
.896 .783 .728 r
.60449 .46404 m .60357 .4666 L .60277 .46275 L F
.619 .348 .485 r
.20895 .6688 m .2082 .67124 L .20607 .66952 L F
.20895 .6688 m .2082 .67124 L .20607 .66952 L F
.554 0 0 r
.20607 .66952 m .2082 .67124 L .20659 .67029 L F
.969 .723 .509 r
.53055 .56351 m .53223 .56444 L .53221 .56177 L F
.659 .483 .635 r
.53223 .56444 m .5347 .56123 L .53221 .56177 L F
.308 0 0 r
.52701 .53799 m .5257 .53943 L .52346 .53976 L F
.681 .473 .598 r
.52804 .53675 m .5257 .53943 L .52701 .53799 L F
.745 .972 .709 r
.1967 .71249 m .19342 .71553 L .19322 .71573 L F
.758 .561 .631 r
.1939 .71196 m .19595 .71246 L .19621 .71129 L F
.582 .653 .885 r
.19857 .71169 m .1967 .71249 L .19557 .71056 L F
.208 0 0 r
.19804 .71297 m .1967 .71249 L .19857 .71169 L F
.758 .561 .631 r
.19595 .71246 m .19804 .71297 L .19651 .71156 L F
.19595 .71246 m .19651 .71156 L .19621 .71129 L F
.745 .972 .709 r
.19484 .71422 m .1935 .71485 L .19342 .71553 L F
.1967 .71249 m .19526 .71355 L .19484 .71422 L F
.19526 .71355 m .1935 .71485 L .19484 .71422 L F
.208 0 0 r
.19804 .71297 m .1935 .71485 L .1967 .71249 L F
.49 .842 .995 r
.59956 .45811 m .60544 .45787 L .60218 .45873 L F
.63 .435 .599 r
.55367 .54002 m .55693 .53737 L .55471 .53779 L F
.358 0 .18 r
.61884 .40872 m .62161 .40693 L .6193 .40757 L F
.921 .947 .604 r
.53525 .55467 m .53465 .55686 L .53701 .55567 L F
.462 .38 .678 r
.53726 .55865 m .53973 .55759 L .53701 .55567 L F
.745 .235 0 r
.53973 .55759 m .53525 .55467 L .53701 .55567 L F
.214 0 0 r
.64396 .40129 m .64887 .40229 L .64615 .40059 L F
.568 .339 .528 r
.56689 .52284 m .56938 .52248 L .56927 .52017 L F
.774 .438 .419 r
.57291 .5227 m .56927 .52017 L .56938 .52248 L F
.389 .032 .232 r
.15759 .5522 m .15998 .55133 L .15829 .55089 L F
.39 .018 .208 r
.15829 .55089 m .15998 .55133 L .1608 .54992 L F
.753 .265 0 r
.7451 .42143 m .74601 .4219 L .74542 .42104 L F
.69 .587 .735 r
.44959 .64608 m .44526 .64548 L .44792 .64497 L F
.518 .909 .93 r
.70174 .40214 m .70301 .40091 L .70056 .40177 L F
.70174 .40214 m .70422 .40115 L .70301 .40091 L F
0 .075 .634 r
.40593 .62075 m .40768 .62256 L .40706 .62356 L F
.349 .256 .606 r
.40706 .62356 m .40873 .62609 L .40706 .62656 L F
0 0 0 r
.20173 .54066 m .20388 .5404 L .20562 .53997 L F
.266 0 0 r
.20562 .53997 m .20388 .5404 L .20778 .54016 L F
.601 .546 .765 r
.55287 .57609 m .54925 .57269 L .55125 .57655 L F
.696 .163 0 r
.41773 .64841 m .41573 .64836 L .41413 .64683 L F
.83 .375 .138 r
.41773 .64841 m .41626 .64922 L .41573 .64836 L F
.621 .083 0 r
.41773 .64841 m .4199 .64998 L .41626 .64922 L F
.367 .162 .465 r
.26729 .59008 m .26548 .58845 L .26751 .58773 L F
.26729 .59008 m .26507 .59102 L .26548 .58845 L F
.947 .849 .712 r
.62833 .45348 m .63114 .45078 L .6304 .45024 L F
.62833 .45348 m .62963 .45475 L .63114 .45078 L F
.069 0 0 r
.75822 .43665 m .76128 .43621 L .76146 .4364 L F
.577 .942 .842 r
.76128 .43621 m .76467 .43433 L .7629 .43468 L F
0 0 0 r
.76146 .4364 m .76128 .43621 L .7629 .43468 L F
.673 .759 .915 r
.73577 .39112 m .73937 .39184 L .73686 .39278 L F
.697 .675 .825 r
.63756 .40703 m .6389 .41039 L .63477 .40974 L F
.731 .592 .701 r
.6389 .41039 m .63641 .41403 L .63477 .40974 L F
.81 .729 .775 r
.64093 .40732 m .6389 .41039 L .63756 .40703 L F
.588 .785 .974 r
.46767 .56911 m .46907 .57052 L .47145 .56984 L F
0 0 0 r
.19647 .68791 m .1941 .69178 L .19488 .69056 L F
.711 .474 .564 r
.19647 .68791 m .1941 .69178 L .1942 .68927 L F
.052 0 .04 r
.19647 .68791 m .19953 .68576 L .19606 .68625 L F
.19647 .68791 m .19785 .68823 L .19953 .68576 L F
.709 .522 .634 r
.20018 .68939 m .19647 .68791 L .19785 .68823 L F
.658 .472 .622 r
.19488 .69056 m .19785 .68823 L .19647 .68791 L F
.821 .755 .79 r
.68888 .44296 m .68563 .4434 L .68782 .44241 L F
.68888 .44296 m .68647 .44589 L .68563 .4434 L F
.442 .794 .997 r
.69031 .44175 m .68888 .44296 L .68782 .44241 L F
.69031 .44175 m .69142 .44266 L .68888 .44296 L F
0 .22 .733 r
.54984 .58507 m .55198 .5875 L .55045 .58388 L F
.768 .42 0 r
.55045 .58388 m .55198 .5875 L .55152 .58681 L F
0 0 .147 r
.55179 .58433 m .55184 .58493 L .55181 .58417 L F
.55152 .58681 m .55184 .58493 L .55179 .58433 L F
.55152 .58681 m .55183 .58404 L .55171 .58374 L F
.01 0 0 r
.55158 .58284 m .55317 .58268 L .55491 .57977 L F
.55141 .583 m .55317 .58268 L .55158 .58284 L F
.103 .629 .876 r
.55179 .58234 m .55336 .58266 L .55317 .58268 L F
.55336 .58266 m .55583 .58315 L .55317 .58268 L F
.01 0 0 r
.55045 .58388 m .55156 .58339 L .55141 .583 L F
.55156 .58339 m .55317 .58268 L .55141 .583 L F
.56 .839 .997 r
.55179 .58234 m .55317 .58268 L .55045 .58388 L F
0 0 .147 r
.55152 .58681 m .55179 .58234 L .55045 .58388 L F
.263 0 0 r
.55198 .5875 m .55588 .58728 L .55496 .58807 L F
.361 .03 .263 r
.55588 .58728 m .55712 .58936 L .55496 .58807 L F
.669 .679 .851 r
.55712 .58936 m .55652 .58807 L .55496 .58807 L F
.55712 .58936 m .55496 .58807 L .55366 .58807 L F
.361 .03 .263 r
.55496 .58807 m .55712 .58936 L .55495 .58808 L F
.263 0 0 r
.55488 .58807 m .55496 .58807 L .55495 .58808 L F
.55198 .5875 m .55496 .58807 L .55488 .58807 L F
.153 0 0 r
.55198 .5875 m .55488 .58807 L .55264 .58769 L F
.361 .03 .263 r
.55588 .58728 m .55805 .58692 L .55712 .58936 L F
.669 .679 .851 r
.55652 .58807 m .55535 .58553 L .55366 .58807 L F
.153 0 0 r
.55488 .58807 m .55495 .58808 L .55264 .58769 L F
.669 .679 .851 r
.55366 .58807 m .55378 .58788 L .55264 .58769 L F
.55378 .58788 m .55535 .58553 L .55264 .58769 L F
.153 0 0 r
.55198 .5875 m .55264 .58769 L .55152 .58681 L F
.114 .318 .789 r
.55152 .58681 m .55264 .58769 L .55184 .58493 L F
.963 .855 .687 r
.55184 .58493 m .55264 .58769 L .55033 .58811 L F
.514 .281 .499 r
.55033 .58811 m .55196 .58764 L .55184 .58493 L F
.144 0 0 r
.5481 .58689 m .55184 .58493 L .55033 .58811 L F
.906 .519 .274 r
.55069 .58625 m .55203 .58714 L .55184 .58493 L F
.514 .281 .499 r
.55196 .58764 m .55253 .58748 L .55184 .58493 L F
.906 .519 .274 r
.55203 .58714 m .55253 .58748 L .55184 .58493 L F
0 0 .147 r
.55181 .58417 m .55184 .58493 L .55183 .58404 L F
.55171 .58374 m .55183 .58404 L .55179 .58234 L F
.438 .739 .991 r
.42424 .57661 m .428 .57701 L .42497 .57529 L F
0 .543 .727 r
.42429 .57894 m .42502 .57897 L .42637 .57913 L F
.899 .913 .823 r
.42497 .57529 m .42404 .57894 L .42424 .57661 L F
.42404 .57894 m .42399 .57915 L .42401 .57894 L F
.42404 .57894 m .42401 .57894 L .42424 .57661 L F
.42497 .57529 m .42245 .57877 L .42399 .57915 L F
0 .543 .727 r
.42245 .57877 m .42467 .57894 L .42429 .57894 L F
.42467 .57894 m .42502 .57897 L .42429 .57894 L F
.999 .801 .463 r
.60422 .48129 m .60355 .47757 L .60462 .4787 L F
0 .245 .725 r
.55481 .56766 m .55481 .5684 L .55415 .56691 L F
.55481 .56769 m .55719 .56994 L .55481 .5684 L F
.5549 .56774 m .55719 .56994 L .55481 .56769 L F
.141 .326 .789 r
.55481 .5684 m .55719 .56994 L .55609 .57021 L F
.499 .475 .761 r
.55882 .57032 m .55719 .56994 L .55481 .56766 L F
.79 .667 .727 r
.55974 .56541 m .55882 .57032 L .55493 .56774 L F
.55493 .5676 m .55493 .56774 L .55481 .56766 L F
.55974 .56541 m .55493 .56774 L .55493 .5676 L F
.222 .184 .602 r
.55481 .57046 m .5561 .57036 L .55567 .56819 L F
.55429 .57182 m .55477 .57144 L .55481 .57046 L F
.55477 .57144 m .5561 .57036 L .55481 .57046 L F
.55544 .56806 m .55567 .56819 L .55557 .56765 L F
.55429 .57182 m .55567 .56819 L .55544 .56806 L F
0 .245 .725 r
.55481 .56766 m .5549 .56774 L .55481 .56769 L F
.554 .38 .6 r
.50563 .58508 m .50348 .58824 L .50331 .58551 L F
.50563 .58508 m .50348 .58824 L .50331 .58551 L F
.351 .594 .937 r
.24239 .55716 m .2435 .55881 L .24418 .55721 L F
.026 .193 .7 r
.2435 .55881 m .24538 .56069 L .24418 .55721 L F
.403 .81 .98 r
.65725 .43947 m .65918 .43922 L .65619 .4387 L F
.651 .571 .752 r
.65773 .4421 m .65918 .43922 L .65725 .43947 L F
.271 0 .262 r
.56796 .47007 m .56749 .47175 L .57016 .46905 L F
.913 .824 .746 r
.53544 .57843 m .53893 .57688 L .53787 .57607 L F
.53544 .57843 m .53771 .57873 L .53893 .57688 L F
.943 .939 .757 r
.54012 .57213 m .53893 .57688 L .54095 .57368 L F
.594 .249 .353 r
.49821 .57649 m .49721 .57867 L .4946 .57879 L F
.526 .581 .853 r
.49924 .5733 m .49821 .57649 L .49785 .573 L F
.49924 .5733 m .50038 .57619 L .49821 .57649 L F
.705 .497 .604 r
.50038 .57619 m .49721 .57867 L .49821 .57649 L F
.184 .666 .928 r
.45312 .58894 m .45628 .58976 L .45511 .58989 L F
.465 0 0 r
.53194 .59949 m .53239 .60003 L .53107 .59872 L F
.53194 .59949 m .53416 .60083 L .53239 .60003 L F
.722 .612 .733 r
.40706 .62656 m .40774 .63016 L .40494 .62998 L F
.497 .104 .224 r
.40774 .63016 m .40603 .6316 L .40494 .62998 L F
.40774 .63016 m .40689 .63201 L .40603 .6316 L F
.599 .594 .818 r
.40873 .62609 m .40774 .63016 L .40706 .62656 L F
.40873 .62609 m .41058 .63024 L .40774 .63016 L F
.513 .119 .231 r
.40947 .6313 m .40689 .63201 L .40774 .63016 L F
.523 .108 .194 r
.41058 .63024 m .40947 .6313 L .40774 .63016 L F
0 0 0 r
.60609 .42175 m .60809 .42018 L .60873 .41849 L F
.251 0 .302 r
.60609 .42175 m .60837 .42273 L .60809 .42018 L F
.60609 .42175 m .60633 .4238 L .60837 .42273 L F
.323 .096 .407 r
.58339 .51142 m .58543 .51053 L .58577 .50828 L F
.222 .022 .383 r
.58339 .51142 m .58487 .51255 L .58543 .51053 L F
.58339 .51142 m .58314 .5136 L .58487 .51255 L F
0 0 .05 r
.21231 .56416 m .21332 .56187 L .21208 .56376 L F
.598 .645 .867 r
.21141 .55864 m .21332 .56187 L .21549 .56056 L F
.181 0 .205 r
.21549 .56056 m .21332 .56187 L .21231 .56416 L F
.563 .376 .586 r
.50616 .58213 m .50893 .58491 L .50563 .58508 L F
.698 .161 0 r
.50667 .58368 m .50893 .58491 L .50823 .58421 L F
.50667 .58368 m .50823 .58421 L .50616 .58213 L F
.50667 .58368 m .50616 .58213 L .50565 .585 L F
.757 .564 .635 r
.50525 .58133 m .50667 .58368 L .50298 .58323 L F
0 .02 .586 r
.50716 .58003 m .5068 .58273 L .50525 .58133 L F
.5068 .58273 m .50667 .58368 L .50583 .58229 L F
.5068 .58273 m .50583 .58229 L .50525 .58133 L F
.50716 .58003 m .50882 .58295 L .50667 .58368 L F
.538 .04 .02 r
.50709 .58313 m .50552 .5833 L .50667 .58368 L F
.50552 .5833 m .5051 .58334 L .50667 .58368 L F
.50882 .58295 m .50709 .58313 L .50667 .58368 L F
.698 .161 0 r
.50667 .58368 m .50565 .585 L .50563 .58508 L F
.415 .29 .601 r
.50563 .58508 m .50808 .5862 L .50893 .58491 L F
.50563 .58508 m .50808 .5862 L .50667 .58368 L F
.606 .833 .986 r
.50882 .58295 m .50893 .58491 L .50667 .58368 L F
.94 .752 .621 r
.50667 .58368 m .50893 .58491 L .50882 .58295 L F
.50667 .58368 m .50808 .5862 L .50893 .58491 L F
.538 .04 .02 r
.50759 .58308 m .50802 .58456 L .5051 .58334 L F
.50882 .58295 m .50854 .58351 L .50759 .58308 L F
.50854 .58351 m .50802 .58456 L .50759 .58308 L F
.439 .056 .214 r
.43 .58411 m .42774 .58319 L .43143 .58253 L F
.563 .514 .758 r
.4329 .57889 m .43375 .582 L .43143 .58253 L F
.233 0 0 r
.43241 .58357 m .43143 .58253 L .43375 .582 L F
.43241 .58357 m .43 .58411 L .43143 .58253 L F
.421 .54 .871 r
.2095 .55879 m .21053 .55676 L .20805 .55526 L F
.2095 .55879 m .21141 .55864 L .21053 .55676 L F
.651 .571 .752 r
.65773 .4421 m .66123 .4429 L .65918 .43922 L F
0 0 .16 r
.21247 .62728 m .21294 .62858 L .21389 .62655 L F
.21247 .62728 m .21187 .62964 L .21294 .62858 L F
.457 .816 .996 r
.53864 .5918 m .54205 .59191 L .54118 .59095 L F
.691 .792 .927 r
.54118 .59095 m .54205 .59191 L .54478 .5914 L F
.54118 .59095 m .54205 .59191 L .54478 .5914 L F
.52 .243 .434 r
.38165 .59715 m .38406 .59682 L .38452 .59471 L F
.491 .195 .39 r
.38406 .59682 m .38722 .59374 L .38452 .59471 L F
.782 .908 .928 r
.7433 .41334 m .74469 .41455 L .74719 .41263 L F
.359 .363 .728 r
.75356 .41757 m .75144 .4202 L .75071 .41512 L F
.75071 .41512 m .75144 .4202 L .75356 .41757 L F
.717 .981 .778 r
.75144 .4202 m .75099 .42005 L .75356 .41757 L F
.575 .81 .422 r
.63237 .41491 m .63013 .41798 L .63035 .41768 L F
.377 .685 .979 r
.18521 .63907 m .18369 .63937 L .18217 .63807 L F
.688 .78 .921 r
.70782 .4017 m .71027 .40059 L .70666 .40004 L F
.364 .181 .495 r
.25209 .6147 m .25179 .61734 L .24945 .61749 L F
.338 .109 .412 r
.25179 .61734 m .2495 .62035 L .24945 .61749 L F
.839 .555 .509 r
.44017 .64415 m .44055 .64704 L .44235 .64467 L F
.691 .353 .399 r
.44235 .64467 m .44055 .64704 L .44418 .64711 L F
.29 .432 .831 r
.76205 .399 m .76072 .40071 L .75914 .39745 L F
.261 .389 .804 r
.76203 .40094 m .76072 .40071 L .76205 .399 L F
.838 .788 .803 r
.70964 .43723 m .70585 .43892 L .70857 .43612 L F
0 0 .392 r
.24483 .56471 m .24562 .56418 L .24538 .56069 L F
0 .226 .743 r
.24483 .56471 m .24695 .56667 L .24562 .56418 L F
.434 .318 .622 r
.24507 .5673 m .24695 .56667 L .24483 .56471 L F
0 0 0 r
.54081 .54676 m .53879 .54847 L .53819 .54723 L F
.481 .737 .984 r
.69981 .453 m .70353 .454 L .70248 .4525 L F
.621 .747 .937 r
.70248 .4525 m .70353 .454 L .70583 .45321 L F
.96 .742 .563 r
.20895 .6688 m .21051 .67067 L .21014 .66806 L F
.483 .216 .432 r
.21051 .67067 m .2082 .67124 L .20895 .6688 L F
.96 .742 .563 r
.20895 .6688 m .20894 .66939 L .21051 .67067 L F
.20895 .6688 m .2082 .67124 L .20659 .67029 L F
.20895 .6688 m .20659 .67029 L .20894 .66939 L F
.483 .216 .432 r
.21051 .67067 m .20895 .6688 L .21014 .66806 L F
.29 .742 .958 r
.4883 .56821 m .48707 .569 L .48576 .56689 L F
.4883 .56821 m .48995 .56896 L .48707 .569 L F
.628 .623 .827 r
.27109 .5643 m .27028 .56864 L .269 .56455 L F
.27109 .5643 m .27317 .56839 L .27028 .56864 L F
.225 0 .236 r
.27317 .56839 m .27099 .57015 L .27028 .56864 L F
.768 .729 .817 r
.68563 .4434 m .68647 .44589 L .68301 .44546 L F
.672 .471 .604 r
.45431 .57319 m .45674 .57325 L .45696 .57054 L F
.47 .297 .564 r
.45696 .57054 m .45674 .57325 L .45895 .57222 L F
.45696 .57054 m .45674 .57325 L .45895 .57222 L F
.556 .282 .456 r
.45696 .57054 m .45895 .57222 L .46005 .56929 L F
0 0 0 r
.55277 .48687 m .55405 .48559 L .55485 .48396 L F
.55277 .48687 m .55161 .48851 L .55405 .48559 L F
.398 .566 .903 r
.76203 .40094 m .7657 .40346 L .76409 .40373 L F
.372 .636 .957 r
.20572 .65641 m .2069 .65481 L .20433 .6555 L F
.20572 .65641 m .21033 .65687 L .2069 .65481 L F
.798 .872 .902 r
.42153 .58465 m .42576 .58381 L .42381 .58435 L F
0 .309 .743 r
.42576 .58381 m .42616 .58359 L .42381 .58435 L F
.189 .09 .504 r
.58633 .53335 m .58472 .53185 L .58654 .53112 L F
.58633 .53335 m .58498 .53443 L .58472 .53185 L F
.411 .188 .463 r
.23339 .59728 m .2354 .59674 L .23584 .59423 L F
.406 .228 .525 r
.23339 .59728 m .23516 .59921 L .2354 .59674 L F
.23339 .59728 m .23325 .59986 L .23516 .59921 L F
.998 .788 .481 r
.54207 .52567 m .54123 .52229 L .54105 .52456 L F
.949 .895 .74 r
.54027 .52866 m .54207 .52567 L .54105 .52456 L F
.077 .638 .776 r
.75579 .43651 m .75447 .43644 L .75217 .4365 L F
.102 0 0 r
.75822 .43665 m .75447 .43644 L .75579 .43651 L F
.408 .319 .643 r
.37472 .60621 m .37693 .60814 L .37661 .60563 L F
.37472 .60621 m .37512 .60886 L .37693 .60814 L F
.259 .645 .964 r
.24996 .5425 m .24957 .54357 L .24782 .54242 L F
.24996 .5425 m .25149 .54366 L .24957 .54357 L F
.332 .002 .246 r
.61689 .42532 m .61646 .42677 L .61421 .42735 L F
.325 0 .244 r
.6191 .42576 m .61689 .42532 L .61931 .42455 L F
.6191 .42576 m .61646 .42677 L .61689 .42532 L F
.827 .798 .823 r
.64684 .43525 m .65 .43401 L .64805 .43405 L F
.902 .953 .824 r
.64805 .43405 m .65 .43401 L .64926 .43292 L F
.705 .785 .914 r
.73395 .43866 m .73745 .43896 L .73679 .43683 L F
.685 .776 .92 r
.73679 .43683 m .73745 .43896 L .74041 .43725 L F
.471 .326 .602 r
.27111 .5609 m .269 .56455 L .26888 .56237 L F
.395 .488 .836 r
.52079 .57821 m .52131 .57531 L .51885 .57597 L F
.52079 .57821 m .52306 .57872 L .52131 .57531 L F
.528 .414 .667 r
.21231 .56416 m .21371 .56519 L .21435 .56291 L F
.849 .867 .854 r
.21336 .56641 m .21449 .56764 L .21714 .56496 L F
.21277 .56664 m .21714 .56496 L .21493 .56609 L F
.528 .414 .667 r
.21371 .56519 m .21493 .56609 L .21436 .56295 L F
.21371 .56519 m .21436 .56295 L .21435 .56291 L F
.849 .867 .854 r
.21277 .56664 m .21322 .5669 L .21336 .56641 L F
.21322 .5669 m .21449 .56764 L .21336 .56641 L F
.725 .492 .574 r
.21507 .58765 m .21818 .58796 L .21839 .58547 L F
.551 .381 .604 r
.61421 .42735 m .61441 .43033 L .61192 .43087 L F
.313 .034 .32 r
.61441 .43033 m .61179 .43321 L .61192 .43087 L F
.398 .428 .775 r
.55052 .54663 m .5523 .54615 L .54913 .5442 L F
.739 .664 .777 r
.5523 .54615 m .54896 .54557 L .54913 .5442 L F
0 0 .385 r
.54913 .5442 m .54963 .54481 L .5494 .54169 L F
.264 0 .073 r
.54896 .54557 m .54963 .54481 L .54913 .5442 L F
0 .024 .579 r
.45997 .6074 m .45983 .60429 L .45786 .60495 L F
.714 .299 .259 r
.46219 .60839 m .46101 .60902 L .45997 .6074 L F
0 .024 .579 r
.45997 .6074 m .46101 .60902 L .45983 .60429 L F
.912 .963 .803 r
.61685 .48611 m .61808 .48496 L .61618 .48549 L F
.995 .866 .544 r
.61794 .48172 m .61808 .48496 L .61851 .48082 L F
.963 .864 .694 r
.61618 .48549 m .61808 .48496 L .61794 .48172 L F
.337 .376 .754 r
.37742 .61822 m .37791 .61411 L .37608 .61463 L F
.37742 .61822 m .37872 .61781 L .37791 .61411 L F
.605 .953 .836 r
.74081 .42819 m .73849 .43029 L .73754 .42941 L F
.74081 .42819 m .74102 .42863 L .73849 .43029 L F
.565 .556 .802 r
.45101 .58827 m .44724 .58534 L .45084 .5857 L F
.575 .35 .537 r
.57088 .54088 m .57089 .54325 L .56831 .54365 L F
.674 .444 .564 r
.57088 .54088 m .57314 .54336 L .57089 .54325 L F
.57088 .54088 m .57347 .54101 L .57314 .54336 L F
.662 .479 .626 r
.5347 .56123 m .53931 .56351 L .53726 .55865 L F
.723 .507 .597 r
.53726 .55865 m .54082 .56121 L .53973 .55759 L F
.53726 .55865 m .53931 .56351 L .54082 .56121 L F
.469 .161 .36 r
.58284 .45585 m .58542 .45396 L .58302 .45463 L F
0 0 .018 r
.65211 .41839 m .65213 .41602 L .65222 .41438 L F
.115 .213 .689 r
.55609 .57021 m .55805 .57433 L .55644 .57455 L F
.55609 .57021 m .55719 .56994 L .55805 .57433 L F
.582 .77 .968 r
.54012 .57213 m .54095 .57368 L .54328 .57303 L F
.7 .676 .823 r
.21507 .58765 m .21532 .59041 L .21818 .58796 L F
.118 0 .291 r
.54674 .58819 m .54649 .59109 L .54478 .5914 L F
.215 .366 .8 r
.54649 .59109 m .54734 .59291 L .54478 .5914 L F
.795 .726 .788 r
.60277 .46275 m .60357 .4666 L .6003 .46582 L F
.847 .498 .392 r
.60376 .46876 m .6003 .46582 L .60357 .4666 L F
.594 .51 .729 r
.27347 .55574 m .27414 .55746 L .2721 .55576 L F
.67 .481 .621 r
.27425 .55827 m .2721 .55576 L .27414 .55746 L F
.27425 .55827 m .27111 .5609 L .2721 .55576 L F
.333 .159 .489 r
.25419 .60904 m .25405 .61154 L .2524 .61222 L F
.349 .159 .475 r
.25391 .61396 m .2524 .61222 L .25405 .61154 L F
.25391 .61396 m .25209 .6147 L .2524 .61222 L F
.783 .749 .822 r
.18576 .55682 m .19055 .55702 L .1884 .55604 L F
.18576 .55682 m .1875 .55856 L .19055 .55702 L F
.13 .621 .912 r
.19187 .55706 m .1884 .55604 L .19055 .55702 L F
.225 0 .236 r
.27317 .56839 m .27255 .56982 L .27099 .57015 L F
.42 .347 .669 r
.27354 .57234 m .27099 .57015 L .27255 .56982 L F
.27354 .57234 m .27131 .5737 L .27099 .57015 L F
.556 .894 .983 r
.70539 .39277 m .70292 .39366 L .70158 .393 L F
0 0 .32 r
.44959 .64608 m .45043 .64442 L .44792 .64497 L F
.44959 .64608 m .45027 .64687 L .45043 .64442 L F
.45043 .64442 m .45027 .64687 L .44959 .64608 L F
.482 .296 .551 r
.21389 .62655 m .2162 .62337 L .21479 .62411 L F
.722 .815 .923 r
.71737 .44803 m .7186 .4498 L .72076 .44838 L F
.93 .966 .76 r
.66665 .41146 m .66813 .40735 L .66533 .41023 L F
.531 .882 .984 r
.6687 .40981 m .66665 .41146 L .66533 .41023 L F
.6687 .40981 m .66925 .41069 L .66665 .41146 L F
.393 .173 .457 r
.23584 .59423 m .23738 .59611 L .23766 .59365 L F
.23584 .59423 m .2354 .59674 L .23738 .59611 L F
0 0 0 r
.43217 .56819 m .43129 .56782 L .43353 .56666 L F
.43217 .56819 m .4299 .56926 L .43129 .56782 L F
.495 .807 1 r
.49301 .58748 m .49473 .58849 L .49091 .58806 L F
.811 .559 .557 r
.49479 .59128 m .49091 .58806 L .49475 .58849 L F
.49479 .59128 m .49086 .59069 L .49091 .58806 L F
0 0 0 r
.49086 .59069 m .49301 .58748 L .49091 .58806 L F
.49187 .58918 m .4916 .5896 L .49301 .58748 L F
.49086 .59069 m .4916 .5896 L .49187 .58918 L F
.918 .945 .802 r
.49595 .5871 m .49479 .59128 L .49475 .58849 L F
.49595 .5871 m .4934 .59086 L .49479 .59128 L F
.203 0 .318 r
.49512 .58937 m .4934 .59086 L .49595 .5871 L F
.534 .047 .045 r
.49512 .58937 m .4916 .5896 L .4934 .59086 L F
0 .39 .793 r
.4916 .5896 m .4932 .58985 L .49125 .59014 L F
0 .018 .535 r
.48933 .59159 m .48826 .58948 L .4916 .5896 L F
.48933 .59159 m .48969 .59128 L .49054 .59025 L F
.48969 .59128 m .4916 .5896 L .49054 .59025 L F
0 .39 .793 r
.4916 .5896 m .49125 .59014 L .49054 .59025 L F
.968 .746 .548 r
.49301 .58748 m .4916 .5896 L .49114 .58637 L F
.393 .706 .985 r
.49086 .59069 m .4934 .59086 L .4916 .5896 L F
.495 .807 1 r
.49301 .58748 m .49475 .58849 L .49473 .58849 L F
.53 .821 .999 r
.49595 .5871 m .49475 .58849 L .49301 .58748 L F
.008 0 0 r
.49301 .58748 m .4916 .5896 L .49455 .58716 L F
.534 .047 .045 r
.49512 .58937 m .49438 .59075 L .4916 .5896 L F
.709 .576 .703 r
.49107 .58587 m .4916 .5896 L .48826 .58948 L F
.968 .746 .548 r
.49301 .58748 m .49114 .58637 L .49107 .58587 L F
.682 .557 .707 r
.49455 .58716 m .4916 .5896 L .49107 .58587 L F
0 .39 .793 r
.4916 .5896 m .49438 .59075 L .4932 .58985 L F
.55 .632 .885 r
.49054 .59025 m .4932 .58985 L .49233 .5881 L F
.49054 .59025 m .49233 .5881 L .49177 .58696 L F
.652 .733 .909 r
.73099 .39318 m .72724 .39242 L .72965 .39132 L F
.677 .717 .879 r
.72965 .39132 m .73329 .39209 L .73099 .39318 L F
.37 .206 .524 r
.61646 .42677 m .61441 .43033 L .61421 .42735 L F
.667 .443 .572 r
.5498 .6003 m .54979 .60283 L .54755 .60186 L F
.342 .187 .521 r
.55178 .6018 m .5498 .6003 L .55234 .59996 L F
.55178 .6018 m .54979 .60283 L .5498 .6003 L F
.918 .821 .734 r
.48346 .57189 m .48562 .57246 L .48636 .57131 L F
.48346 .57189 m .48536 .57287 L .48562 .57246 L F
0 0 0 r
.4849 .57555 m .48562 .57246 L .48536 .57287 L F
.327 .666 .974 r
.48562 .57246 m .48818 .57127 L .48636 .57131 L F
.852 .998 .783 r
.21738 .56313 m .21493 .56609 L .21714 .56496 L F
.12 0 0 r
.67479 .39792 m .6761 .39782 L .67244 .39783 L F
.182 0 0 r
.67772 .39829 m .6761 .39782 L .67479 .39792 L F
.67772 .39829 m .67856 .39786 L .6761 .39782 L F
.225 .731 .894 r
.6807 .39781 m .6761 .39782 L .67856 .39786 L F
.366 .675 .976 r
.26353 .54772 m .26321 .54929 L .26193 .54758 L F
.26353 .54772 m .26499 .54912 L .26321 .54929 L F
.699 .846 .953 r
.50191 .53924 m .50273 .54063 L .49922 .54029 L F
.946 .761 .621 r
.50053 .54358 m .49922 .54029 L .50273 .54063 L F
.022 .535 .866 r
.50191 .53924 m .50508 .54042 L .50273 .54063 L F
.579 .835 .993 r
.70894 .39309 m .70539 .39277 L .7079 .39195 L F
.588 .829 .99 r
.71148 .39229 m .70894 .39309 L .7079 .39195 L F
0 .498 .859 r
.74754 .39607 m .75079 .39781 L .74932 .39706 L F
.256 .512 .905 r
.75079 .39781 m .75198 .39654 L .74932 .39706 L F
.75079 .39781 m .75262 .39845 L .75198 .39654 L F
.086 0 .039 r
.41458 .61402 m .41164 .61672 L .41294 .6139 L F
.786 .665 .73 r
.63882 .42534 m .63871 .42766 L .63499 .42718 L F
.787 .661 .724 r
.63871 .42766 m .63673 .4279 L .63499 .42718 L F
.595 .635 .86 r
.54929 .56993 m .55042 .5665 L .54784 .56902 L F
.54929 .56993 m .55226 .56935 L .55042 .5665 L F
.593 .42 .616 r
.54925 .57269 m .55226 .56935 L .54929 .56993 L F
.896 .905 .824 r
.65842 .4356 m .66186 .43364 L .6609 .43324 L F
.945 .959 .686 r
.66186 .43364 m .66287 .42954 L .662 .43224 L F
.821 .996 .766 r
.6609 .43324 m .66186 .43364 L .662 .43224 L F
.86 .838 .823 r
.71422 .43354 m .71137 .43325 L .71317 .432 L F
.844 .82 .825 r
.71422 .43354 m .71022 .43495 L .71137 .43325 L F
.733 .805 .908 r
.71671 .43128 m .71422 .43354 L .71317 .432 L F
.401 .091 .32 r
.39756 .59054 m .40055 .58729 L .3984 .58795 L F
.592 .099 .053 r
.67856 .39786 m .68221 .39802 L .6807 .39781 L F
.203 0 0 r
.68364 .39857 m .68221 .39802 L .6812 .39888 L F
.68364 .39857 m .68484 .3981 L .68221 .39802 L F
.106 0 .326 r
.58577 .50828 m .58677 .50943 L .58766 .50737 L F
.58577 .50828 m .58543 .51053 L .58677 .50943 L F
.147 0 .079 r
.19486 .67737 m .19515 .67728 L .19776 .67494 L F
.19515 .67728 m .19705 .67624 L .19776 .67494 L F
.676 .82 .952 r
.20012 .67383 m .19776 .67494 L .19598 .67375 L F
.20012 .67383 m .19598 .67375 L .19822 .67299 L F
.682 .547 .694 r
.19598 .67375 m .19829 .67556 L .19822 .67299 L F
.19829 .67556 m .19971 .67666 L .19909 .67512 L F
.19829 .67556 m .19909 .67512 L .19822 .67299 L F
.147 0 .079 r
.19515 .67728 m .19673 .67682 L .19705 .67624 L F
.724 .677 .804 r
.47145 .56984 m .47515 .57152 L .47349 .57014 L F
.668 .394 .497 r
.47563 .57163 m .47515 .57152 L .47804 .57167 L F
.809 .619 .645 r
.54351 .53177 m .54027 .52866 L .54034 .53131 L F
.818 .729 .766 r
.54151 .53469 m .54351 .53177 L .54034 .53131 L F
.821 .954 .614 r
.60761 .49852 m .60989 .49569 L .60915 .4949 L F
.60761 .49852 m .6079 .49882 L .60989 .49569 L F
.605 .316 .452 r
.4533 .56459 m .45176 .56683 L .45186 .56481 L F
0 .3 .79 r
.65177 .40439 m .64965 .40382 L .64887 .40229 L F
.65177 .40439 m .65317 .40634 L .64965 .40382 L F
0 .268 .758 r
.64965 .40382 m .65317 .40634 L .65317 .40677 L F
.719 .509 .605 r
.43496 .60243 m .43193 .60003 L .43528 .60018 L F
.531 .255 .442 r
.43781 .60003 m .43496 .60243 L .43528 .60018 L F
.128 0 0 r
.68963 .40437 m .69104 .40486 L .68895 .40593 L F
.68963 .40437 m .69214 .40387 L .69104 .40486 L F
.68 .537 .683 r
.48215 .57549 m .4849 .57555 L .48536 .57287 L F
.6 .097 .03 r
.4809 .57574 m .4849 .57555 L .48215 .57549 L F
.68 .537 .683 r
.48215 .57549 m .4849 .57555 L .48536 .57287 L F
.84 .934 .889 r
.21815 .55375 m .21867 .5561 L .21912 .55401 L F
.935 .85 .734 r
.21583 .55665 m .21867 .5561 L .21815 .55375 L F
.21583 .55665 m .21722 .55764 L .21867 .5561 L F
.542 .851 .998 r
.4499 .5589 m .44804 .55952 L .44688 .55889 L F
.837 .622 .612 r
.67517 .40724 m .67182 .40915 L .67097 .40791 L F
.67517 .40724 m .67506 .40966 L .67182 .40915 L F
.661 .581 .754 r
.71817 .43642 m .71546 .43928 L .71545 .43701 L F
.702 .749 .888 r
.49379 .56976 m .48995 .56896 L .49247 .56819 L F
.153 .607 .931 r
.49247 .56819 m .49584 .5695 L .49379 .56976 L F
.722 .53 .631 r
.19338 .67938 m .19673 .67682 L .19486 .67737 L F
.559 .286 .458 r
.43991 .58469 m .44243 .58446 L .44393 .58051 L F
.432 .142 .371 r
.44393 .58051 m .44592 .58026 L .44619 .57911 L F
.727 .465 .53 r
.44393 .58051 m .44243 .58446 L .44727 .58396 L F
.97 .891 .692 r
.65082 .42733 m .6519 .42543 L .65156 .42306 L F
.655 .872 .98 r
.74582 .43819 m .75009 .43789 L .74884 .437 L F
.749 .904 .946 r
.74884 .437 m .75009 .43789 L .75217 .4365 L F
.838 .999 .821 r
.7629 .43468 m .76467 .43433 L .76621 .43221 L F
0 0 0 r
.1813 .55911 m .18159 .55886 L .18344 .55775 L F
.1813 .55911 m .1795 .56015 L .18159 .55886 L F
.419 .252 .546 r
.37646 .60031 m .37859 .60135 L .37877 .59964 L F
.37646 .60031 m .37629 .60304 L .37859 .60135 L F
.225 0 .299 r
.58965 .5262 m .59213 .52336 L .59164 .5252 L F
.324 .122 .444 r
.58939 .52858 m .58965 .5262 L .59164 .5252 L F
.286 .427 .828 r
.50394 .57881 m .50235 .57988 L .50038 .57619 L F
.479 .892 .921 r
.50085 .57982 m .50235 .57988 L .50394 .57881 L F
.516 .628 .9 r
.2013 .6923 m .19841 .69046 L .20018 .68939 L F
0 0 0 r
.20359 .68931 m .2013 .6923 L .20018 .68939 L F
.20359 .68931 m .20195 .69197 L .2013 .6923 L F
.153 0 .32 r
.20247 .69369 m .2013 .6923 L .20195 .69197 L F
.20247 .69369 m .20044 .69508 L .2013 .6923 L F
.675 .798 .941 r
.19812 .65589 m .20015 .65743 L .202 .65628 L F
.59 .344 .512 r
.56219 .53388 m .55969 .53181 L .5597 .53405 L F
.56219 .53388 m .56224 .53158 L .55969 .53181 L F
0 0 0 r
.60156 .50865 m .60381 .50555 L .60285 .50703 L F
.666 .817 .38 r
.60479 .50354 m .60381 .50555 L .60566 .50211 L F
.675 .831 .402 r
.60285 .50703 m .60381 .50555 L .60479 .50354 L F
0 0 0 r
.60048 .51031 m .60156 .50865 L .60285 .50703 L F
.53049 .51133 m .53168 .50989 L .53234 .50773 L F
.603 .91 .645 r
.52892 .51243 m .53168 .50989 L .53049 .51133 L F
.969 .923 .598 r
.59823 .48941 m .59783 .48842 L .59922 .48724 L F
.739 .973 .716 r
.60186 .48444 m .59922 .48724 L .6003 .4853 L F
.717 .935 .613 r
.59922 .48724 m .59783 .48842 L .6003 .4853 L F
.969 .726 .513 r
.63641 .41403 m .63632 .41571 L .63492 .414 L F
.695 .429 .517 r
.41027 .60806 m .40839 .60874 L .4087 .60606 L F
.492 .322 .578 r
.4034 .58242 m .40566 .5845 L .40574 .58209 L F
.4034 .58242 m .40354 .58543 L .40566 .5845 L F
.3 .115 .454 r
.55035 .54909 m .5523 .54615 L .55052 .54663 L F
.562 .26 .414 r
.57927 .54022 m .57944 .53801 L .58187 .53967 L F
.561 .261 .418 r
.57944 .53801 m .58221 .53776 L .58187 .53967 L F
.23 .516 .912 r
.26795 .55017 m .26631 .55048 L .26499 .54912 L F
.26795 .55017 m .26877 .55155 L .26631 .55048 L F
.781 .706 .781 r
.53024 .68321 m .53385 .68348 L .53268 .68012 L F
.819 .831 .858 r
.68454 .45371 m .68773 .45383 L .68737 .45069 L F
.68454 .45371 m .68593 .45485 L .68773 .45383 L F
.717 .768 .893 r
.68737 .45069 m .68773 .45383 L .69084 .45118 L F
.439 .056 .214 r
.43 .58411 m .42796 .58485 L .42774 .58319 L F
.797 .835 .88 r
.72954 .42719 m .72587 .42762 L .7279 .42538 L F
.218 .576 .942 r
.7279 .42538 m .72954 .42719 L .72861 .42584 L F
.926 .607 .142 r
.72977 .42857 m .72954 .42719 L .72861 .42584 L F
.67 .67 .841 r
.20243 .68654 m .20018 .68939 L .19979 .68668 L F
.20243 .68654 m .20359 .68931 L .20018 .68939 L F
0 0 .282 r
.21208 .56376 m .21277 .56664 L .21231 .56416 L F
.117 0 0 r
.69214 .40387 m .69558 .40326 L .69481 .40365 L F
.146 0 0 r
.69558 .40326 m .69716 .4039 L .69481 .40365 L F
.69558 .40326 m .69799 .40274 L .69716 .4039 L F
0 0 .048 r
.65317 .40677 m .65332 .40699 L .65531 .40393 L F
.777 .856 .411 r
.65531 .40393 m .65647 .40066 L .65777 .40167 L F
.65531 .40393 m .6555 .40299 L .65647 .40066 L F
0 0 0 r
.65531 .40393 m .6557 .4043 L .6555 .40299 L F
.65531 .40393 m .65332 .40699 L .6557 .4043 L F
.294 .116 .461 r
.55898 .56335 m .55766 .56177 L .55907 .56093 L F
.55898 .56335 m .55742 .5644 L .55766 .56177 L F
0 0 0 r
.41712 .57408 m .41623 .5753 L .41902 .57285 L F
.162 0 .232 r
.59775 .43674 m .59952 .43604 L .60017 .43385 L F
.503 .336 .588 r
.59775 .43674 m .6002 .43831 L .59952 .43604 L F
.59775 .43674 m .59784 .43926 L .6002 .43831 L F
.869 .798 .778 r
.77377 .42179 m .77139 .42115 L .77292 .4186 L F
.911 .72 .631 r
.77385 .42459 m .77139 .42115 L .77377 .42179 L F
.758 .739 .835 r
.77662 .41889 m .77377 .42179 L .77292 .4186 L F
.607 .378 .542 r
.48303 .63521 m .48564 .63548 L .48631 .63312 L F
.48631 .63312 m .48564 .63548 L .48303 .63521 L F
.154 0 .129 r
.56518 .47249 m .56247 .47517 L .56435 .47424 L F
.179 0 .064 r
.56435 .47424 m .56749 .47175 L .56518 .47249 L F
.343 .471 .845 r
.55646 .57953 m .55871 .57874 L .55777 .5787 L F
.052 .619 .748 r
.21383 .54038 m .2161 .54031 L .21772 .54035 L F
.392 .847 .9 r
.21772 .54035 m .21819 .53967 L .21988 .54027 L F
.21772 .54035 m .2161 .54031 L .21819 .53967 L F
.462 .274 .539 r
.26088 .59715 m .26068 .5997 L .25861 .60026 L F
.453 .301 .584 r
.26064 .60222 m .25861 .60026 L .26068 .5997 L F
.26064 .60222 m .25865 .60285 L .25861 .60026 L F
.888 .758 .713 r
.53975 .53378 m .54151 .53469 L .54034 .53131 L F
.811 .685 .725 r
.53796 .53652 m .54151 .53469 L .53975 .53378 L F
.53796 .53652 m .53987 .53763 L .54151 .53469 L F
.624 .55 .75 r
.63756 .40703 m .63477 .40974 L .63444 .4057 L F
.692 .541 .677 r
.54752 .58648 m .54984 .58507 L .5486 .5825 L F
.423 .01 .149 r
.55045 .58388 m .5486 .5825 L .54984 .58507 L F
.794 .598 .635 r
.42266 .60364 m .41943 .60009 L .42121 .60062 L F
.42266 .60364 m .42185 .60434 L .41943 .60009 L F
.873 .99 .818 r
.42266 .60364 m .42106 .60543 L .42185 .60434 L F
.42 .166 .421 r
.42266 .60364 m .42279 .60527 L .42106 .60543 L F
.747 .737 .843 r
.42523 .60068 m .42266 .60364 L .42121 .60062 L F
.558 .342 .543 r
.59407 .46302 m .59417 .46574 L .59159 .46609 L F
.613 .442 .626 r
.59648 .46249 m .59417 .46574 L .59407 .46302 L F
.869 .69 .658 r
.5334 .53139 m .53139 .53431 L .53024 .53113 L F
0 0 0 r
.2045 .63628 m .20039 .63843 L .20246 .63762 L F
.117 0 0 r
.20461 .6371 m .2045 .63628 L .20246 .63762 L F
.20461 .6371 m .20685 .63586 L .2045 .63628 L F
.276 .47 .869 r
.37872 .61781 m .38089 .62107 L .38205 .61958 L F
.324 .205 .559 r
.3798 .62262 m .38205 .61958 L .38089 .62107 L F
.912 .97 .669 r
.60186 .48444 m .60328 .4803 L .60422 .48129 L F
.60186 .48444 m .60117 .48449 L .60328 .4803 L F
.883 .982 .7 r
.60186 .48444 m .6003 .4853 L .60117 .48449 L F
.241 .747 .887 r
.17959 .5434 m .18343 .54336 L .18128 .54396 L F
.717 .479 .564 r
.43296 .57628 m .4329 .57889 L .42871 .57807 L F
.578 .364 .555 r
.43396 .57636 m .43296 .57628 L .43584 .57584 L F
.43396 .57636 m .4329 .57889 L .43296 .57628 L F
0 .201 .728 r
.54666 .58737 m .54674 .58819 L .54539 .5859 L F
.48 .35 .627 r
.54666 .58737 m .54649 .59109 L .54674 .58819 L F
.397 .605 .932 r
.19251 .68084 m .19635 .6826 L .19338 .67938 L F
.444 .59 .903 r
.19251 .68084 m .19644 .68328 L .19635 .6826 L F
.69 .541 .678 r
.57656 .54069 m .57314 .54336 L .57347 .54101 L F
.813 .924 .541 r
.65952 .42192 m .65811 .42456 L .6584 .42309 L F
0 0 .126 r
.6584 .42309 m .65811 .42456 L .65817 .42696 L F
0 .005 .57 r
.46005 .56929 m .46115 .57046 L .46072 .56817 L F
.304 .038 .334 r
.46005 .56929 m .45895 .57222 L .46115 .57046 L F
.543 .79 .99 r
.74354 .43859 m .74504 .43694 L .74214 .43687 L F
.74354 .43859 m .74582 .43819 L .74504 .43694 L F
0 0 .336 r
.65813 .41591 m .65913 .41823 L .65843 .41618 L F
.436 .18 .426 r
.57735 .46015 m .57989 .45961 L .58006 .45687 L F
.456 .204 .443 r
.57989 .45961 m .58284 .45585 L .58006 .45687 L F
.359 .263 .609 r
.27354 .57234 m .27159 .57629 L .27131 .5737 L F
.523 .58 .854 r
.27542 .55424 m .27286 .55567 L .27113 .55115 L F
0 0 0 r
.5341 .50676 m .5354 .50532 L .53234 .50773 L F
.53655 .50393 m .53772 .5023 L .5354 .50532 L F
.53563 .50531 m .5354 .50532 L .5341 .50676 L F
.53563 .50531 m .53655 .50393 L .5354 .50532 L F
.534 0 0 r
.40941 .63774 m .4113 .63873 L .41283 .6385 L F
.714 .18 0 r
.4113 .63873 m .41496 .64104 L .41283 .6385 L F
.911 .72 .631 r
.77385 .42459 m .77086 .42365 L .77139 .42115 L F
.878 .802 .771 r
.77385 .42459 m .77156 .42706 L .77086 .42365 L F
.864 .468 .285 r
.77385 .42459 m .77573 .427 L .77156 .42706 L F
.828 .97 .657 r
.60645 .49983 m .60566 .50211 L .6079 .49882 L F
.795 .967 .659 r
.60645 .49983 m .6079 .49882 L .60761 .49852 L F
.605 .802 .976 r
.71497 .39288 m .71148 .39229 L .71393 .39134 L F
.597 .772 .963 r
.71755 .39212 m .71497 .39288 L .71393 .39134 L F
.797 .848 .889 r
.62015 .44471 m .6186 .44622 L .61729 .44477 L F
0 0 .29 r
.50897 .55562 m .50888 .55825 L .50998 .55652 L F
.786 .665 .73 r
.63882 .42534 m .63501 .42462 L .63746 .42429 L F
.63882 .42534 m .63499 .42718 L .63501 .42462 L F
0 0 0 r
.69081 .39584 m .68735 .39742 L .68983 .39672 L F
.077 0 0 r
.69236 .39609 m .69081 .39584 L .68983 .39672 L F
.69236 .39609 m .69327 .39518 L .69081 .39584 L F
.97 .846 .664 r
.61851 .48082 m .61868 .47797 L .6176 .48125 L F
.995 .866 .544 r
.61794 .48172 m .61851 .48082 L .6176 .48125 L F
.946 .761 .621 r
.50053 .54358 m .49888 .54286 L .49922 .54029 L F
.958 .618 .3 r
.50053 .54358 m .49956 .54479 L .49888 .54286 L F
.50053 .54358 m .50095 .54585 L .49956 .54479 L F
.524 .338 .57 r
.55693 .53737 m .5597 .53405 L .55699 .53479 L F
.045 0 0 r
.16456 .56429 m .16161 .56576 L .1606 .5657 L F
0 0 0 r
.16376 .56488 m .16516 .56442 L .16698 .56482 L F
.16525 .5644 m .16376 .56488 L .16599 .56433 L F
.16525 .5644 m .16351 .56497 L .16376 .56488 L F
.16376 .56488 m .16161 .56576 L .16456 .56429 L F
.413 .857 .774 r
.16376 .56488 m .16173 .56585 L .16161 .56576 L F
.16376 .56488 m .16319 .56507 L .16173 .56585 L F
0 0 0 r
.16351 .56497 m .16319 .56507 L .16376 .56488 L F
.16376 .56488 m .16456 .56429 L .16516 .56442 L F
.574 .318 .49 r
.56224 .53158 m .56494 .5311 L .56523 .52912 L F
.45 .209 .457 r
.56523 .52912 m .56728 .53056 L .56739 .52837 L F
.56523 .52912 m .56494 .5311 L .56728 .53056 L F
.632 .703 .897 r
.71027 .40059 m .71385 .4017 L .7128 .39977 L F
.63 .714 .907 r
.71385 .4017 m .71537 .39901 L .7128 .39977 L F
.71385 .4017 m .7164 .40091 L .71537 .39901 L F
.067 .251 .743 r
.38852 .62938 m .38995 .63295 L .39062 .63137 L F
0 .089 .624 r
.38995 .63295 m .39155 .63496 L .39062 .63137 L F
.329 .659 .972 r
.51253 .56058 m .51467 .55938 L .51093 .55835 L F
.51253 .56058 m .51505 .56046 L .51467 .55938 L F
.502 .58 .866 r
.48451 .56365 m .4837 .56724 L .48206 .5644 L F
.48451 .56365 m .48576 .56689 L .4837 .56724 L F
.162 0 0 r
.40133 .5864 m .40055 .58729 L .40354 .58543 L F
.461 0 0 r
.18924 .70052 m .19167 .70094 L .19066 .7005 L F
.745 .985 .904 r
.19317 .69816 m .19066 .7005 L .19167 .70094 L F
.302 .167 .524 r
.26507 .59102 m .26506 .59355 L .26341 .59428 L F
.397 .168 .445 r
.26513 .59583 m .26341 .59428 L .26506 .59355 L F
.26513 .59583 m .26305 .59652 L .26341 .59428 L F
.443 .559 .878 r
.5431 .55551 m .54676 .55858 L .54615 .55572 L F
.756 .962 .666 r
.54636 .55669 m .54919 .55561 L .54615 .55572 L F
.54676 .55858 m .54787 .55722 L .54636 .55669 L F
.54787 .55722 m .54919 .55561 L .54636 .55669 L F
.443 .559 .878 r
.5431 .55551 m .54674 .5569 L .54676 .55858 L F
.325 0 0 r
.54413 .55611 m .54674 .5569 L .54419 .55593 L F
.54324 .55559 m .54419 .55593 L .5431 .55551 L F
.54413 .55611 m .54419 .55593 L .54324 .55559 L F
.823 .77 .802 r
.54322 .55959 m .54676 .55858 L .54674 .5569 L F
.756 .962 .666 r
.54676 .55858 m .54781 .55637 L .54919 .55561 L F
.167 .317 .773 r
.54919 .56053 m .54781 .55637 L .54676 .55858 L F
.51 .33 .572 r
.54682 .56121 m .54919 .56053 L .54676 .55858 L F
.631 .618 .818 r
.41219 .61163 m .41046 .61313 L .40839 .60874 L F
.508 .199 .377 r
.39232 .59342 m .39516 .59123 L .39274 .59156 L F
.953 .9 .518 r
.65917 .42086 m .65952 .42192 L .6584 .42309 L F
.491 .195 .39 r
.38406 .59682 m .38651 .59646 L .38722 .59374 L F
.473 .212 .438 r
.38651 .59646 m .38897 .59392 L .38722 .59374 L F
.848 .801 .804 r
.68009 .4483 m .67765 .44779 L .67952 .44487 L F
.933 .839 .728 r
.68009 .4483 m .67718 .45018 L .67765 .44779 L F
.68009 .4483 m .67872 .45125 L .67718 .45018 L F
.761 .746 .839 r
.68301 .44546 m .68009 .4483 L .67952 .44487 L F
.354 0 .187 r
.1608 .54992 m .15998 .55133 L .16294 .54947 L F
.523 .442 .705 r
.76903 .4232 m .76743 .42499 L .76673 .4216 L F
0 0 0 r
.53313 .50805 m .53234 .50773 L .53168 .50989 L F
.53313 .50805 m .5341 .50676 L .53234 .50773 L F
.53927 .50086 m .54055 .49939 L .53772 .5023 L F
.53927 .50086 m .54181 .49807 L .54055 .49939 L F
.734 .731 .848 r
.69511 .44285 m .69142 .44266 L .6928 .44159 L F
.751 .727 .83 r
.69788 .44034 m .69511 .44285 L .6928 .44159 L F
.473 .295 .558 r
.44142 .58833 m .44097 .59116 L .43956 .59138 L F
.256 .159 .548 r
.44122 .59322 m .43956 .59138 L .44097 .59116 L F
.44122 .59322 m .43954 .59433 L .43956 .59138 L F
.64 .714 .901 r
.66156 .4027 m .65777 .40167 L .65995 .40117 L F
.286 .663 .971 r
.65995 .40117 m .66424 .40258 L .66156 .4027 L F
.632 .279 .354 r
.43812 .65021 m .43576 .65264 L .4335 .65064 L F
.558 .135 .195 r
.43972 .65096 m .43576 .65264 L .43812 .65021 L F
.605 .316 .452 r
.4533 .56459 m .45411 .56681 L .45176 .56683 L F
.673 .647 .817 r
.45645 .56097 m .4533 .56459 L .45425 .56131 L F
.45645 .56097 m .45789 .56427 L .4533 .56459 L F
.681 .356 .417 r
.45831 .56653 m .4533 .56459 L .45789 .56427 L F
.45831 .56653 m .45411 .56681 L .4533 .56459 L F
.659 .483 .635 r
.53223 .56444 m .5368 .56556 L .5347 .56123 L F
.751 .648 .747 r
.5368 .56556 m .53931 .56351 L .5347 .56123 L F
0 0 .114 r
.53868 .50295 m .53772 .5023 L .53655 .50393 L F
.53868 .50295 m .53927 .50086 L .53772 .5023 L F
.093 0 .201 r
.60017 .43385 m .59952 .43604 L .60186 .43267 L F
.919 .852 .761 r
.62059 .47153 m .62373 .4697 L .62212 .46846 L F
.62059 .47153 m .62262 .47199 L .62373 .4697 L F
.91 .827 .752 r
.62373 .4697 m .62438 .46485 L .62212 .46846 L F
.581 .784 .976 r
.73432 .42939 m .73259 .43169 L .7316 .43033 L F
.73432 .42939 m .73554 .43094 L .73259 .43169 L F
.989 .734 .441 r
.60684 .4379 m .60745 .43948 L .60689 .43784 L F
.988 .74 .465 r
.60612 .43604 m .60583 .43886 L .60745 .43948 L F
.507 .876 .979 r
.60745 .43948 m .60583 .43886 L .60992 .43877 L F
.482 .299 .555 r
.60983 .44151 m .60745 .43948 L .60992 .43877 L F
.60983 .44151 m .60759 .44242 L .60754 .44141 L F
.60847 .44035 m .60754 .44141 L .60745 .43948 L F
.60983 .44151 m .60754 .44141 L .60847 .44035 L F
.642 .165 .104 r
.60594 .43886 m .60795 .44012 L .60992 .43877 L F
.683 .592 .748 r
.60795 .44012 m .61101 .43657 L .61001 .43858 L F
.60974 .4389 m .61001 .43858 L .60992 .43877 L F
.60795 .44012 m .61001 .43858 L .60974 .4389 L F
.642 .165 .104 r
.60583 .43886 m .6059 .4389 L .60594 .43886 L F
.6059 .4389 m .60795 .44012 L .60594 .43886 L F
.989 .734 .441 r
.60612 .43604 m .60684 .4379 L .60658 .43694 L F
.60684 .4379 m .60689 .43784 L .60658 .43694 L F
.339 .296 .664 r
.37567 .6121 m .37693 .60814 L .37512 .60886 L F
.37567 .6121 m .37714 .61184 L .37693 .60814 L F
.343 .318 .687 r
.37567 .6121 m .37791 .61411 L .37714 .61184 L F
.415 .324 .644 r
.37608 .61463 m .37791 .61411 L .37567 .6121 L F
.443 .81 .995 r
.18155 .65901 m .18174 .65787 L .17981 .6579 L F
.18155 .65901 m .18332 .65862 L .18174 .65787 L F
.483 .355 .629 r
.41856 .62395 m .42093 .62563 L .42077 .62314 L F
.41856 .62395 m .42093 .62563 L .42077 .62314 L F
0 0 0 r
.42359 .64052 m .42245 .64179 L .42451 .63901 L F
.313 .229 .599 r
.42359 .64052 m .42237 .64342 L .42245 .64179 L F
0 .419 .835 r
.19829 .68372 m .19635 .6826 L .19644 .68328 L F
.668 .447 .576 r
.19644 .68328 m .19953 .68576 L .19829 .68372 L F
.19644 .68328 m .19606 .68625 L .19953 .68576 L F
.57 .345 .535 r
.56938 .52489 m .56938 .52248 L .56689 .52284 L F
.45 .358 .66 r
.56689 .52284 m .5673 .52554 L .56938 .52489 L F
.57 .345 .535 r
.56938 .52489 m .56938 .52248 L .56689 .52284 L F
.43 .345 .659 r
.5609 .55765 m .55841 .55587 L .56087 .55501 L F
.5609 .55765 m .55882 .55837 L .55841 .55587 L F
.6 .097 .03 r
.4809 .57574 m .48344 .57732 L .4849 .57555 L F
.6 .837 .461 r
.4849 .57555 m .48344 .57732 L .4857 .57431 L F
.705 .517 .632 r
.48837 .57871 m .4849 .57555 L .48869 .5763 L F
.48837 .57871 m .48688 .57992 L .4849 .57555 L F
.702 .98 .901 r
.51308 .5242 m .51686 .52257 L .51419 .52496 L F
.805 .681 .728 r
.54919 .55561 m .54566 .55274 L .54615 .55572 L F
.54919 .55561 m .54877 .55264 L .54566 .55274 L F
.32 .121 .446 r
.55047 .55389 m .54877 .55264 L .54919 .55561 L F
.664 .647 .822 r
.5431 .55551 m .54615 .55572 L .54566 .55274 L F
.5431 .55551 m .54615 .55572 L .54566 .55274 L F
.996 .806 .444 r
.54557 .55367 m .54615 .55572 L .54566 .55274 L F
.802 .623 .659 r
.54566 .55274 m .54877 .55264 L .54771 .54918 L F
.541 .563 .826 r
.54673 .55135 m .54853 .55502 L .54557 .55367 L F
.54853 .55502 m .54819 .55524 L .54557 .55367 L F
.54882 .55561 m .5488 .55563 L .54557 .55367 L F
.74 .252 .082 r
.54557 .55367 m .5488 .55563 L .54778 .5557 L F
.679 .481 .611 r
.54882 .55561 m .55047 .55389 L .54845 .55602 L F
.807 .545 .543 r
.54673 .55135 m .55047 .55389 L .54882 .55561 L F
.74 .252 .082 r
.54591 .55445 m .54778 .5557 L .54649 .55578 L F
.54557 .55367 m .54778 .5557 L .54591 .55445 L F
.5488 .55563 m .54874 .55567 L .54649 .55578 L F
.541 .563 .826 r
.54853 .55502 m .54882 .55561 L .54819 .55524 L F
.511 .907 .788 r
.55047 .55389 m .54649 .55578 L .54874 .55567 L F
.679 .481 .611 r
.54901 .55539 m .55047 .55389 L .54882 .55561 L F
.54845 .55602 m .55047 .55389 L .54919 .55561 L F
.807 .545 .543 r
.54882 .55561 m .55047 .55389 L .54884 .55566 L F
.74 .252 .082 r
.5488 .55563 m .54884 .55566 L .54874 .55567 L F
.541 .563 .826 r
.54882 .55561 m .54884 .55566 L .5488 .55563 L F
.511 .907 .788 r
.55047 .55389 m .54874 .55567 L .54884 .55566 L F
.679 .481 .611 r
.54973 .55458 m .55047 .55389 L .54901 .55539 L F
.54822 .55599 m .54973 .55458 L .5488 .55563 L F
.54822 .55599 m .5488 .55563 L .54845 .55602 L F
.54822 .55599 m .55072 .55644 L .55047 .55389 L F
.54781 .55637 m .54822 .55599 L .54845 .55602 L F
.54781 .55637 m .54883 .5564 L .54822 .55599 L F
.54883 .5564 m .55072 .55644 L .54822 .55599 L F
.511 .907 .788 r
.54975 .55423 m .54956 .55407 L .54649 .55578 L F
.55047 .55389 m .5502 .55394 L .54975 .55423 L F
.5502 .55394 m .54956 .55407 L .54975 .55423 L F
0 0 0 r
.41987 .60794 m .41904 .60957 L .42106 .60543 L F
.042 0 .043 r
.42151 .60707 m .42106 .60543 L .42279 .60527 L F
.42151 .60707 m .41987 .60794 L .42106 .60543 L F
.708 .621 .758 r
.53439 .58379 m .53735 .58503 L .5361 .58208 L F
.578 .002 0 r
.53628 .58458 m .53672 .58504 L .53735 .58503 L F
.53439 .58379 m .5366 .58497 L .53628 .58458 L F
.5366 .58497 m .53672 .58504 L .53628 .58458 L F
.518 0 0 r
.53666 .58504 m .53982 .58529 L .53735 .58503 L F
.604 .456 .654 r
.5366 .58497 m .53676 .58588 L .53474 .5841 L F
.53531 .58428 m .53474 .5841 L .53439 .58379 L F
.5366 .58497 m .53474 .5841 L .53531 .58428 L F
0 0 .44 r
.53689 .58533 m .53676 .58588 L .5366 .58497 L F
.53689 .58533 m .5366 .58497 L .53655 .58469 L F
.53681 .58499 m .53655 .58469 L .5361 .58208 L F
.53689 .58533 m .53655 .58469 L .53681 .58499 L F
.53692 .58512 m .53689 .58533 L .53683 .58509 L F
.518 0 0 r
.53582 .58505 m .53822 .58523 L .53808 .58519 L F
0 0 .44 r
.53694 .58512 m .53693 .58514 L .53692 .58512 L F
.53693 .58514 m .53689 .58533 L .53692 .58512 L F
.518 0 0 r
.53693 .58514 m .53885 .58544 L .53822 .58523 L F
.013 0 .229 r
.53693 .58514 m .53582 .58505 L .53676 .58588 L F
.518 0 0 r
.53582 .58505 m .53699 .5852 L .53693 .58514 L F
.53699 .5852 m .53885 .58544 L .53693 .58514 L F
.53582 .58505 m .53692 .58512 L .53666 .58504 L F
0 0 .44 r
.5373 .58356 m .53694 .58512 L .5361 .58208 L F
.53694 .58512 m .53683 .58509 L .5361 .58208 L F
.604 .456 .654 r
.5361 .58208 m .5366 .58497 L .53439 .58379 L F
.578 .002 0 r
.53439 .58379 m .53582 .58505 L .53672 .58504 L F
.013 0 .229 r
.5373 .58356 m .53582 .58505 L .53693 .58514 L F
.518 0 0 r
.53582 .58505 m .53638 .58582 L .53738 .58566 L F
.53699 .5852 m .53738 .58566 L .53885 .58544 L F
.53582 .58505 m .53738 .58566 L .53699 .5852 L F
.53808 .58519 m .53885 .58544 L .53982 .58529 L F
.53692 .58512 m .53982 .58529 L .53666 .58504 L F
.537 .377 .612 r
.25646 .60587 m .2566 .60867 L .25419 .60904 L F
.437 .204 .461 r
.2566 .60867 m .25405 .61154 L .25419 .60904 L F
.529 .375 .617 r
.63555 .42213 m .63501 .42462 L .63368 .42061 L F
.63555 .42213 m .63746 .42429 L .63501 .42462 L F
.909 .669 .167 r
.51807 .54296 m .51748 .53982 L .51985 .54042 L F
.774 .483 .494 r
.46367 .58856 m .4593 .5901 L .46166 .5881 L F
.46367 .58856 m .46307 .5906 L .4593 .5901 L F
.381 .206 .515 r
.46526 .5855 m .46367 .58856 L .4656 .58773 L F
.4656 .58773 m .46367 .58856 L .46526 .5855 L F
.561 .091 .096 r
.46166 .5881 m .4656 .58773 L .46367 .58856 L F
.276 .006 .31 r
.4656 .58773 m .46307 .5906 L .46367 .58856 L F
.356 0 .138 r
.62427 .40656 m .62692 .40594 L .62746 .40421 L F
.343 0 .134 r
.62746 .40421 m .62692 .40594 L .62971 .40479 L F
.321 0 0 r
.62746 .40421 m .62971 .40479 L .63085 .40388 L F
.185 .465 .886 r
.19953 .68576 m .20086 .6856 L .19979 .68668 L F
.369 .747 .989 r
.20086 .6856 m .20243 .68654 L .19979 .68668 L F
.999 .801 .463 r
.60422 .48129 m .60328 .4803 L .60355 .47757 L F
.824 .351 0 r
.66885 .39903 m .6702 .40074 L .66861 .39957 L F
.919 .864 .769 r
.6277 .45792 m .62963 .45475 L .62833 .45348 L F
.534 .201 .349 r
.60037 .45126 m .59948 .45331 L .59766 .45145 L F
.60037 .45126 m .59948 .45331 L .59766 .45145 L F
.685 .557 .703 r
.45333 .58521 m .45101 .58827 L .45084 .5857 L F
.419 .148 .394 r
.74264 .41277 m .74296 .41077 L .7406 .41235 L F
.275 .46 .861 r
.74264 .41277 m .7406 .41235 L .7433 .41334 L F
.521 .31 .534 r
.27221 .57895 m .27216 .58149 L .26983 .58186 L F
.341 .36 .735 r
.27159 .57629 m .27398 .57821 L .27221 .57895 L F
.477 .275 .527 r
.27421 .58047 m .27221 .57895 L .27398 .57821 L F
.27421 .58047 m .27216 .58149 L .27221 .57895 L F
.438 0 .039 r
.51452 .53927 m .51356 .5404 L .51113 .54027 L F
.203 .621 .949 r
.51373 .53889 m .51748 .53982 L .51452 .53927 L F
.047 0 0 r
.51748 .53982 m .51356 .5404 L .51452 .53927 L F
.805 .841 .878 r
.66861 .39957 m .6702 .40074 L .66972 .40112 L F
.66795 .40131 m .66972 .40112 L .66727 .40309 L F
.66861 .39957 m .66972 .40112 L .66795 .40131 L F
.66861 .39957 m .66795 .40131 L .66901 .40194 L F
.66795 .40131 m .66727 .40309 L .66795 .40264 L F
.66795 .40131 m .66795 .40264 L .66901 .40194 L F
.287 .741 .956 r
.66424 .40258 m .66761 .40277 L .66727 .40309 L F
.939 .633 .434 r
.66648 .40533 m .66813 .40735 L .66727 .40309 L F
.506 .354 .608 r
.66727 .40309 m .67023 .40553 L .66901 .40194 L F
.66727 .40309 m .66813 .40735 L .67023 .40553 L F
.939 .633 .434 r
.66648 .40533 m .66727 .40309 L .66761 .40277 L F
.472 .774 .997 r
.66314 .40152 m .66761 .40277 L .66424 .40258 L F
.861 .611 .56 r
.66397 .40175 m .66648 .40533 L .66761 .40277 L F
.66314 .40152 m .6634 .40181 L .66397 .40175 L F
.286 .663 .971 r
.65995 .40117 m .66314 .40152 L .66424 .40258 L F
.861 .611 .56 r
.6634 .40181 m .66648 .40533 L .66397 .40175 L F
.885 .94 .845 r
.63368 .42061 m .6308 .42144 L .63286 .41851 L F
.63368 .42061 m .63165 .42223 L .6308 .42144 L F
.706 .56 .687 r
.63368 .42061 m .63259 .42513 L .63165 .42223 L F
.63368 .42061 m .63501 .42462 L .63259 .42513 L F
.245 0 0 r
.62767 .4188 m .62669 .41879 L .62428 .41824 L F
.206 .729 .726 r
.63013 .41798 m .62669 .41879 L .62767 .4188 L F
.146 .074 .51 r
.78143 .41822 m .78196 .42139 L .78084 .42138 L F
.143 .22 .685 r
.78196 .42139 m .78281 .42338 L .78084 .42138 L F
.04 .1 .599 r
.52599 .58811 m .52662 .58796 L .52637 .58418 L F
.065 .208 .703 r
.52599 .58811 m .52797 .59 L .52662 .58796 L F
.593 .815 .985 r
.50742 .53968 m .50867 .54087 L .50508 .54042 L F
.50742 .53968 m .50867 .54087 L .50508 .54042 L F
.581 .811 .986 r
.51113 .54027 m .50867 .54087 L .50742 .53968 L F
.535 0 0 r
.50867 .54087 m .51106 .54282 L .51245 .54364 L F
.39 0 0 r
.22822 .55386 m .2244 .55372 L .22623 .55341 L F
.745 .985 .904 r
.19317 .69816 m .19167 .70094 L .19297 .70097 L F
.565 .416 .638 r
.19297 .70097 m .1952 .69768 L .19317 .69816 L F
.646 .451 .606 r
.4447 .59042 m .44142 .58833 L .44459 .58815 L F
.4447 .59042 m .44097 .59116 L .44142 .58833 L F
.834 .687 .7 r
.60376 .46876 m .60523 .47228 L .60225 .47147 L F
.92 .859 .764 r
.60523 .47228 m .60232 .47403 L .60225 .47147 L F
.60523 .47228 m .60336 .47529 L .60232 .47403 L F
.686 .77 .915 r
.72003 .40161 m .72248 .40051 L .71889 .3999 L F
.33 .325 .702 r
.20703 .68268 m .20582 .68356 L .20502 .68072 L F
.727 .682 .807 r
.72006 .43316 m .71671 .43128 L .71961 .43029 L F
.71 .76 .891 r
.72336 .43095 m .72006 .43316 L .71961 .43029 L F
.947 .926 .752 r
.67067 .41617 m .6728 .41246 L .67177 .41095 L F
.802 .763 .817 r
.67506 .40966 m .6728 .41246 L .67182 .40915 L F
.477 .293 .552 r
.67515 .41203 m .6728 .41246 L .67506 .40966 L F
.482 .769 .994 r
.67177 .41095 m .6728 .41246 L .67515 .41203 L F
.592 .399 .59 r
.56597 .54676 m .566 .54918 L .56345 .54968 L F
.536 .349 .574 r
.56831 .54365 m .56832 .54616 L .56597 .54676 L F
.58 .411 .617 r
.56832 .54616 m .566 .54918 L .56597 .54676 L F
.122 0 0 r
.45101 .58827 m .44929 .58974 L .44708 .59023 L F
.259 .019 .347 r
.45333 .58521 m .45294 .58781 L .45101 .58827 L F
.301 0 0 r
.45294 .58781 m .44929 .58974 L .45101 .58827 L F
.574 .398 .605 r
.56345 .54968 m .56345 .55204 L .56098 .5525 L F
.546 .312 .512 r
.56098 .5525 m .56339 .55441 L .56087 .55501 L F
.56098 .5525 m .56345 .55204 L .56339 .55441 L F
.363 .204 .528 r
.5431 .55551 m .54566 .55274 L .54557 .55367 L F
.354 .002 .222 r
.5442 .55146 m .54175 .55226 L .5443 .55139 L F
.852 .636 .609 r
.54424 .55142 m .5442 .55146 L .5443 .55139 L F
.678 .67 .835 r
.5442 .55146 m .5422 .55335 L .54175 .55226 L F
.852 .636 .609 r
.54077 .55316 m .5442 .55146 L .54424 .55142 L F
.678 .67 .835 r
.5442 .55146 m .5431 .55551 L .5422 .55335 L F
.5442 .55146 m .54566 .55274 L .5431 .55551 L F
.325 0 0 r
.54413 .55611 m .5431 .55551 L .54557 .55367 L F
.458 .756 .994 r
.4244 .63142 m .42612 .63268 L .42354 .63283 L F
.4244 .63142 m .42612 .63268 L .42354 .63283 L F
.958 .904 .726 r
.53535 .58059 m .53771 .57873 L .53544 .57843 L F
.53535 .58059 m .5361 .58208 L .53771 .57873 L F
.273 .778 .81 r
.6967 .39453 m .69327 .39518 L .6959 .39465 L F
.266 .773 .81 r
.69837 .39394 m .6967 .39453 L .6959 .39465 L F
.69837 .39394 m .69916 .39395 L .6967 .39453 L F
.601 .752 .95 r
.19207 .63978 m .18972 .64083 L .18802 .63889 L F
.91 .864 .782 r
.62089 .47475 m .62262 .47199 L .62059 .47153 L F
.778 .542 .579 r
.48241 .58126 m .47855 .57837 L .47975 .58044 L F
.513 .876 .982 r
.19619 .63959 m .19207 .63978 L .19383 .63919 L F
.745 .929 .95 r
.1983 .63812 m .19619 .63959 L .19383 .63919 L F
0 .297 .778 r
.51331 .54348 m .51245 .54364 L .51106 .54282 L F
.51331 .54348 m .51377 .54435 L .51245 .54364 L F
.396 .344 .681 r
.23538 .58213 m .23738 .58357 L .2378 .58196 L F
.23538 .58213 m .23613 .58547 L .23738 .58357 L F
.196 0 0 r
.46929 .56261 m .47228 .56169 L .47038 .56257 L F
.311 .082 .397 r
.26305 .59652 m .26068 .5997 L .26088 .59715 L F
.576 .352 .539 r
.56831 .54365 m .57087 .54564 L .56832 .54616 L F
.56831 .54365 m .57089 .54325 L .57087 .54564 L F
.578 .458 .68 r
.46526 .5855 m .46776 .5862 L .46802 .58225 L F
.449 .251 .519 r
.46526 .5855 m .46777 .587 L .46776 .5862 L F
.46526 .5855 m .4656 .58773 L .46777 .587 L F
.138 0 .155 r
.55983 .47798 m .56185 .47728 L .56247 .47517 L F
.307 .006 .28 r
.56185 .47728 m .56435 .47424 L .56247 .47517 L F
.018 .564 .837 r
.24165 .54115 m .24403 .54149 L .2456 .5421 L F
0 .441 .707 r
.24403 .54149 m .24782 .54242 L .2456 .5421 L F
.623 .069 0 r
.74226 .43401 m .74232 .4337 L .74066 .43275 L F
.181 0 0 r
.74226 .43401 m .74537 .43374 L .74232 .4337 L F
.6 .632 .855 r
.20476 .68798 m .20359 .68931 L .20243 .68654 L F
.373 .067 .312 r
.20476 .68798 m .20195 .69197 L .20359 .68931 L F
.559 .35 .554 r
.46263 .64174 m .46523 .64148 L .46584 .6388 L F
.66 .78 .938 r
.72252 .39013 m .7212 .39275 L .72004 .39119 L F
.72252 .39013 m .72361 .39174 L .7212 .39275 L F
.332 .014 .266 r
.61607 .41164 m .61884 .40872 L .61631 .40938 L F
.442 .148 .369 r
.38165 .59715 m .38344 .59856 L .38406 .59682 L F
.38165 .59715 m .38114 .59911 L .38344 .59856 L F
.6 .675 .893 r
.69981 .453 m .70136 .44982 L .69885 .45048 L F
.69981 .453 m .70248 .4525 L .70136 .44982 L F
.749 .594 .684 r
.45509 .57979 m .4499 .58066 L .45203 .57926 L F
.45509 .57979 m .45175 .58111 L .45192 .58032 L F
.222 0 .055 r
.45216 .57912 m .45304 .58055 L .45307 .57817 L F
.45203 .57926 m .45211 .57937 L .45216 .57912 L F
.45211 .57937 m .45304 .58055 L .45216 .57912 L F
.749 .594 .684 r
.45509 .57979 m .45567 .58206 L .45175 .58111 L F
.45192 .58032 m .45175 .58111 L .45019 .58073 L F
.739 .623 .73 r
.45567 .58206 m .45333 .58521 L .45003 .58083 L F
.45019 .58073 m .45003 .58083 L .4499 .58066 L F
.45567 .58206 m .45003 .58083 L .45019 .58073 L F
.222 0 .055 r
.45218 .57945 m .45082 .58129 L .45304 .58055 L F
.45211 .57937 m .45196 .57959 L .45218 .57945 L F
.45196 .57959 m .45082 .58129 L .45218 .57945 L F
.45203 .57926 m .45186 .57955 L .45211 .57937 L F
.45186 .57955 m .45082 .58129 L .45211 .57937 L F
.749 .594 .684 r
.45041 .58057 m .45019 .58073 L .4499 .58066 L F
.45192 .58032 m .45019 .58073 L .45041 .58057 L F
.596 .5 .716 r
.45824 .58101 m .45509 .57979 L .45673 .5785 L F
.45824 .58101 m .45567 .58206 L .45509 .57979 L F
.929 .891 .772 r
.21093 .65657 m .21167 .65655 L .21178 .65614 L F
.21033 .65687 m .21178 .65614 L .2105 .65662 L F
.213 .737 .818 r
.21414 .65622 m .2105 .65662 L .21178 .65614 L F
.21414 .65622 m .21249 .65625 L .21071 .65658 L F
.2109 .65657 m .21071 .65658 L .2105 .65662 L F
.21414 .65622 m .21071 .65658 L .2109 .65657 L F
.929 .891 .772 r
.21033 .65687 m .21089 .65932 L .21167 .65655 L F
.21033 .65687 m .21167 .65655 L .21093 .65657 L F
0 0 0 r
.16929 .54679 m .16903 .54726 L .17164 .54623 L F
.16929 .54679 m .16697 .54795 L .16903 .54726 L F
.611 .922 .973 r
.44205 .55942 m .44688 .55889 L .44449 .55918 L F
.937 .784 .665 r
.68454 .45371 m .68546 .45724 L .68593 .45485 L F
.557 .324 .518 r
.20661 .66283 m .20897 .66253 L .2096 .65944 L F
.274 .439 .844 r
.21079 .66075 m .2096 .65944 L .21141 .6602 L F
0 0 .272 r
.2096 .65944 m .21045 .66138 L .21141 .6602 L F
.2096 .65944 m .20897 .66253 L .21045 .66138 L F
.423 .863 .784 r
.17261 .56309 m .17311 .56251 L .17116 .56264 L F
.17261 .56309 m .17522 .56191 L .17311 .56251 L F
.538 .807 .996 r
.52885 .67969 m .53268 .68012 L .53032 .68058 L F
.066 0 .334 r
.58933 .50385 m .58798 .50508 L .58766 .50737 L F
.337 .183 .519 r
.22143 .61461 m .22321 .61163 L .21776 .61149 L F
.2175 .61202 m .21776 .61149 L .21667 .61147 L F
.501 .393 .663 r
.21556 .61534 m .21592 .61524 L .21739 .61178 L F
.21592 .61524 m .21728 .61247 L .21739 .61178 L F
.752 .628 .723 r
.21739 .61178 m .21687 .61497 L .22143 .61461 L F
.21739 .61178 m .22143 .61461 L .21667 .61147 L F
.337 .183 .519 r
.22143 .61461 m .21776 .61149 L .2175 .61202 L F
.501 .393 .663 r
.21592 .61524 m .21687 .61497 L .21728 .61247 L F
.378 .112 .379 r
.21495 .61715 m .21687 .61497 L .21556 .61534 L F
.643 .681 .871 r
.18011 .63831 m .17623 .63665 L .17824 .63568 L F
.507 .642 .916 r
.18217 .63807 m .18011 .63831 L .17824 .63568 L F
.455 .047 .175 r
.56938 .52489 m .57291 .5227 L .56938 .52248 L F
.56938 .52489 m .57189 .52447 L .57291 .5227 L F
.516 .245 .442 r
.57519 .52449 m .57291 .5227 L .57189 .52447 L F
.57519 .52449 m .57544 .52228 L .57291 .5227 L F
.44 .793 .997 r
.22204 .53992 m .22375 .5408 L .21988 .54027 L F
.455 .79 .999 r
.22204 .53992 m .22584 .54053 L .22375 .5408 L F
.734 .655 .771 r
.21495 .61715 m .21649 .62094 L .21862 .61775 L F
.498 .345 .604 r
.21649 .62094 m .21856 .62046 L .21862 .61775 L F
.178 .012 .404 r
.21649 .62094 m .21774 .62242 L .21856 .62046 L F
.21649 .62094 m .2162 .62337 L .21774 .62242 L F
.612 .318 .447 r
.54755 .60186 m .54361 .60513 L .54367 .60241 L F
.54755 .60186 m .54622 .60521 L .54361 .60513 L F
.691 .308 .317 r
.54755 .60186 m .54893 .60499 L .54622 .60521 L F
.54755 .60186 m .54979 .60283 L .54893 .60499 L F
0 0 0 r
.54439 .60276 m .54567 .60206 L .54498 .60219 L F
.54567 .60206 m .54733 .60114 L .54498 .60219 L F
.134 .68 .729 r
.54418 .60234 m .54498 .60219 L .54367 .60241 L F
.54755 .60186 m .54498 .60219 L .54418 .60234 L F
0 0 .47 r
.59948 .45331 m .60015 .45575 L .59972 .45731 L F
0 0 0 r
.65317 .40677 m .65194 .40824 L .65338 .40697 L F
.77 .913 .531 r
.65317 .40634 m .65194 .40824 L .65317 .40677 L F
.98 .775 .557 r
.76535 .42603 m .76743 .42499 L .76903 .4232 L F
.52 .025 0 r
.5021 .54937 m .50295 .55029 L .50147 .54863 L F
.5021 .54937 m .5041 .55147 L .50295 .55029 L F
.705 .892 .965 r
.70909 .45145 m .71215 .45135 L .71101 .45009 L F
.667 .784 .937 r
.71215 .45135 m .7134 .44886 L .71101 .45009 L F
.71215 .45135 m .71462 .45034 L .7134 .44886 L F
.677 .805 .943 r
.42497 .57529 m .428 .57701 L .42869 .5756 L F
.528 .006 0 r
.4241 .59449 m .42222 .59534 L .42041 .59427 L F
.883 .536 .385 r
.4241 .59449 m .42461 .59664 L .42222 .59534 L F
.155 .326 .784 r
.49679 .57077 m .49924 .5733 L .49785 .573 L F
.293 0 .113 r
.55983 .47798 m .56148 .47915 L .56185 .47728 L F
.55983 .47798 m .55911 .47983 L .56148 .47915 L F
.671 .432 .551 r
.5377 .60248 m .53416 .60083 L .53913 .60018 L F
.708 .527 .641 r
.53942 .59997 m .5377 .60248 L .53913 .60018 L F
.521 .514 .789 r
.27542 .55424 m .27414 .55746 L .27347 .55574 L F
.062 0 .197 r
.59213 .52336 m .59448 .52009 L .59357 .52191 L F
.012 0 .218 r
.59164 .5252 m .59213 .52336 L .59357 .52191 L F
.248 0 .096 r
.41113 .57856 m .41333 .5785 L .41425 .57633 L F
.162 0 .06 r
.41425 .57633 m .41527 .57756 L .41623 .5753 L F
.41425 .57633 m .41333 .5785 L .41527 .57756 L F
.224 .345 .777 r
.52382 .58231 m .52637 .58418 L .52511 .58067 L F
.718 .774 .897 r
.41943 .60009 m .4156 .59971 L .41624 .5997 L F
.216 .469 .884 r
.42022 .59863 m .41943 .60009 L .41624 .5997 L F
.42022 .59863 m .42121 .60062 L .41943 .60009 L F
.091 .632 .851 r
.49479 .59128 m .4934 .59086 L .49086 .59069 L F
.519 .871 .988 r
.74601 .4219 m .7471 .42058 L .7451 .42143 L F
.683 .929 .969 r
.75099 .42005 m .74843 .42114 L .7471 .42058 L F
.519 .871 .988 r
.74646 .42176 m .74843 .42114 L .7471 .42058 L F
.74601 .4219 m .74843 .42114 L .7471 .42058 L F
.655 .291 0 r
.74843 .42114 m .74861 .4216 L .7471 .42058 L F
.683 .929 .969 r
.75099 .42005 m .7471 .42058 L .75011 .41709 L F
.848 .876 .861 r
.75011 .41709 m .7471 .42058 L .74658 .41856 L F
.057 .305 .791 r
.74748 .4199 m .7471 .42058 L .74861 .4216 L F
.74658 .41856 m .7471 .42058 L .74748 .4199 L F
.519 .871 .988 r
.74601 .4219 m .74646 .42176 L .7471 .42058 L F
.74601 .4219 m .7471 .42058 L .7451 .42143 L F
.495 .146 .304 r
.44691 .58862 m .4447 .59042 L .44459 .58815 L F
.44691 .58862 m .44708 .59023 L .4447 .59042 L F
.769 .352 .259 r
.54012 .57213 m .54328 .57303 L .54035 .57107 L F
.239 0 0 r
.43175 .58828 m .4342 .58775 L .435 .58681 L F
0 0 0 r
.53977 .54764 m .53955 .54823 L .53879 .54847 L F
.943 .677 .212 r
.53912 .54939 m .53955 .54823 L .53896 .54709 L F
.63 .596 .797 r
.53955 .54823 m .53922 .55275 L .53879 .54847 L F
.943 .677 .212 r
.53918 .55023 m .53955 .54823 L .53912 .54939 L F
0 0 0 r
.54081 .54676 m .53955 .54823 L .53977 .54764 L F
.392 .219 .524 r
.27216 .58149 m .26999 .58462 L .26983 .58186 L F
0 0 0 r
.19931 .67933 m .19829 .68372 L .20139 .68125 L F
.19931 .67933 m .19841 .68344 L .19829 .68372 L F
0 .419 .835 r
.19829 .68372 m .19841 .68344 L .19635 .6826 L F
.856 .48 .335 r
.53719 .60306 m .53239 .60003 L .53416 .60083 L F
.671 .432 .551 r
.5377 .60248 m .53719 .60306 L .53416 .60083 L F
.337 .646 .967 r
.25936 .54562 m .25872 .54702 L .25743 .54571 L F
.25936 .54562 m .26193 .54758 L .25872 .54702 L F
.593 .395 .583 r
.45099 .5761 m .45446 .57576 L .45431 .57319 L F
.159 .238 .697 r
.45099 .5761 m .45307 .57817 L .45446 .57576 L F
.45099 .5761 m .45203 .57926 L .45307 .57817 L F
.478 .476 .777 r
.60247 .43069 m .60608 .42925 L .60336 .42599 L F
.14 0 .156 r
.60186 .43267 m .60608 .42925 L .60247 .43069 L F
.733 .668 .786 r
.45592 .58877 m .4593 .5901 L .45548 .58926 L F
.643 .345 .451 r
.45333 .58521 m .45646 .58867 L .45294 .58781 L F
.45646 .58867 m .45645 .58867 L .45294 .58781 L F
.744 .222 0 r
.45701 .58814 m .45646 .58867 L .45333 .58521 L F
.67 .871 .489 r
.45779 .58668 m .45701 .58814 L .45995 .58581 L F
.733 .668 .786 r
.45779 .58668 m .45646 .58867 L .45646 .58867 L F
.67 .871 .489 r
.45779 .58668 m .45646 .58867 L .45646 .58867 L F
.45779 .58668 m .45646 .58867 L .45701 .58814 L F
.733 .668 .786 r
.45779 .58668 m .45849 .58827 L .45646 .58867 L F
.648 .482 .645 r
.45645 .58867 m .45312 .58894 L .45294 .58781 L F
.733 .668 .786 r
.45849 .58827 m .4593 .5901 L .45592 .58877 L F
.648 .482 .645 r
.45646 .58867 m .45645 .58867 L .45645 .58867 L F
.45645 .58867 m .45312 .58894 L .45645 .58867 L F
.733 .668 .786 r
.45618 .58848 m .45646 .58867 L .45592 .58877 L F
.45779 .58668 m .45646 .58867 L .45618 .58848 L F
.643 .345 .451 r
.45646 .58867 m .45646 .58867 L .45645 .58867 L F
.656 .265 .292 r
.44878 .58042 m .45082 .58129 L .45203 .57926 L F
.459 .32 .604 r
.24507 .5673 m .24698 .56928 L .24695 .56667 L F
.24507 .5673 m .24518 .56986 L .24698 .56928 L F
.323 .423 .81 r
.21141 .6602 m .21377 .66112 L .21079 .66075 L F
.133 .002 .423 r
.21377 .66112 m .21201 .66463 L .21079 .66075 L F
.776 .691 .77 r
.6051 .44495 m .60345 .44823 L .60621 .44856 L F
.61 .379 .542 r
.60621 .44856 m .6062 .4508 L .60989 .4497 L F
.785 .523 .54 r
.60621 .44856 m .6062 .4508 L .60345 .44823 L F
.678 .338 .391 r
.43376 .65196 m .42981 .65064 L .4335 .65064 L F
.643 .273 .328 r
.4335 .65064 m .43576 .65264 L .43376 .65196 L F
.845 .649 .637 r
.53594 .537 m .53987 .53763 L .53796 .53652 L F
.76 .532 .588 r
.53558 .53975 m .53987 .53763 L .53594 .537 L F
.53558 .53975 m .53905 .53989 L .53987 .53763 L F
.588 .348 .519 r
.53905 .53989 m .5416 .53977 L .53987 .53763 L F
.521 .514 .789 r
.27542 .55424 m .27635 .55767 L .27414 .55746 L F
.29 0 .039 r
.27635 .55767 m .27425 .55827 L .27414 .55746 L F
.464 .512 .823 r
.46577 .58043 m .46642 .58389 L .46387 .57912 L F
.82 .757 .793 r
.464 .58392 m .46642 .58389 L .46577 .58043 L F
.543 .343 .558 r
.566 .54918 m .56345 .55204 L .56345 .54968 L F
.753 .577 .658 r
.45446 .57576 m .45674 .57325 L .45431 .57319 L F
.688 .798 .933 r
.72611 .39087 m .72965 .39132 L .72724 .39242 L F
.406 .464 .808 r
.55981 .58226 m .56232 .58603 L .55793 .58241 L F
0 .518 .823 r
.47854 .56337 m .48206 .5644 L .47973 .56463 L F
.12 0 0 r
.63085 .40388 m .63234 .40418 L .63345 .40349 L F
.63085 .40388 m .62971 .40479 L .63234 .40418 L F
.912 .98 .768 r
.45989 .58333 m .45995 .58581 L .4614 .58433 L F
.45989 .58333 m .45779 .58668 L .45995 .58581 L F
.021 0 .217 r
.20703 .68268 m .20514 .6857 L .20582 .68356 L F
.881 .87 .822 r
.2169 .61692 m .22143 .61461 L .21687 .61497 L F
.2169 .61692 m .21862 .61775 L .22143 .61461 L F
.694 .527 .658 r
.21862 .61775 m .22149 .61772 L .22143 .61461 L F
.337 .183 .519 r
.22143 .61461 m .22304 .6144 L .22321 .61163 L F
.452 .335 .63 r
.22143 .61461 m .22362 .61702 L .22304 .6144 L F
.22143 .61461 m .22149 .61772 L .22362 .61702 L F
.244 0 0 r
.45499 .59181 m .45364 .59281 L .45126 .59305 L F
.099 0 0 r
.45603 .59217 m .45499 .59181 L .45628 .58976 L F
.45603 .59217 m .45364 .59281 L .45499 .59181 L F
.697 .787 .92 r
.74532 .39135 m .74189 .3909 L .74429 .38999 L F
.658 .794 .947 r
.74697 .38854 m .74532 .39135 L .74429 .38999 L F
.74697 .38854 m .74805 .39033 L .74532 .39135 L F
.972 .707 .47 r
.46461 .60897 m .46306 .60847 L .46101 .60902 L F
.46461 .60897 m .4646 .6115 L .46306 .60847 L F
.613 .463 .654 r
.46699 .6059 m .46733 .60882 L .46461 .60897 L F
.469 .205 .431 r
.46733 .60882 m .4646 .6115 L .46461 .60897 L F
.013 0 .229 r
.5373 .58356 m .53646 .58562 L .53582 .58505 L F
0 .05 .53 r
.53676 .58588 m .53582 .58505 L .53514 .58445 L F
.013 0 .229 r
.53646 .58562 m .53638 .58582 L .53582 .58505 L F
0 .05 .53 r
.53514 .58445 m .53582 .58505 L .53439 .58379 L F
.012 .556 .837 r
.23927 .55647 m .23876 .55625 L .23605 .55571 L F
.203 .633 .949 r
.23927 .55647 m .24067 .55611 L .23876 .55625 L F
.23927 .55647 m .24239 .55716 L .24067 .55611 L F
.776 .812 .881 r
.73044 .43863 m .73174 .44013 L .73395 .43866 L F
.933 .836 .725 r
.53931 .56351 m .53911 .56449 L .54082 .56121 L F
.921 .974 .699 r
.54322 .55959 m .53973 .55759 L .54082 .56121 L F
.967 .728 .292 r
.5427 .51691 m .54208 .51807 L .54262 .51834 L F
.5427 .51691 m .54198 .51575 L .54208 .51807 L F
.782 .908 .928 r
.7433 .41334 m .74719 .41263 L .74664 .41227 L F
0 .27 .776 r
.74764 .41163 m .74719 .41263 L .74635 .4108 L F
.598 .95 .842 r
.74664 .41227 m .74719 .41263 L .74764 .41163 L F
.277 .455 .856 r
.5173 .56767 m .52029 .56918 L .51826 .56602 L F
.13 .23 .7 r
.41987 .60794 m .42077 .61177 L .41904 .60957 L F
.744 .369 .343 r
.41904 .60957 m .42077 .61177 L .41753 .61125 L F
.322 .112 .431 r
.77859 .4305 m .78066 .42716 L .78074 .42744 L F
.647 .82 .395 r
.78066 .42716 m .78281 .42338 L .78322 .42584 L F
0 0 0 r
.78074 .42744 m .78066 .42716 L .78322 .42584 L F
.427 .271 .565 r
.59417 .46574 m .59232 .46856 L .59159 .46609 L F
0 .215 .737 r
.52981 .5933 m .52797 .59 L .52902 .5911 L F
.679 .439 .551 r
.63266 .42781 m .63601 .4299 L .63673 .4279 L F
.655 .767 .932 r
.73834 .39016 m .73937 .39184 L .73577 .39112 L F
.649 .773 .939 r
.74102 .38921 m .73937 .39184 L .73834 .39016 L F
.74102 .38921 m .74189 .3909 L .73937 .39184 L F
.558 .135 .195 r
.43972 .65096 m .4388 .65284 L .43576 .65264 L F
.431 .01 .137 r
.44193 .65202 m .4388 .65284 L .43972 .65096 L F
.429 .014 .147 r
.44236 .65064 m .44193 .65202 L .43972 .65096 L F
0 0 0 r
.19571 .54069 m .19371 .54193 L .19577 .54099 L F
.227 .117 .513 r
.20079 .69754 m .19926 .69805 L .20044 .69508 L F
.235 .14 .537 r
.2007 .7002 m .19926 .69805 L .20079 .69754 L F
.629 .555 .752 r
.43613 .58107 m .4329 .57889 L .43396 .57636 L F
.593 .44 .643 r
.43063 .57526 m .43217 .57616 L .43454 .57513 L F
.477 .499 .802 r
.43696 .57499 m .43396 .57636 L .43584 .57584 L F
.43682 .57502 m .43396 .57636 L .43696 .57499 L F
.43706 .57491 m .43682 .57502 L .43696 .57499 L F
.43706 .57491 m .43833 .57841 L .43396 .57636 L F
.57 .453 .681 r
.43833 .57841 m .43613 .58107 L .43396 .57636 L F
.593 .44 .643 r
.43217 .57616 m .4342 .57736 L .43447 .5756 L F
.43217 .57616 m .43447 .5756 L .43454 .57513 L F
.87 .847 .819 r
.53537 .54619 m .5327 .54944 L .53068 .5483 L F
.998 .817 .533 r
.54865 .54144 m .54774 .53957 L .54559 .54022 L F
.385 .163 .449 r
.24174 .6317 m .24011 .62995 L .24226 .62944 L F
.24174 .6317 m .23974 .63242 L .24011 .62995 L F
0 0 .539 r
.7657 .40346 m .76655 .40573 L .76634 .40691 L F
.973 .888 .684 r
.76655 .40573 m .76656 .40894 L .76634 .40691 L F
0 0 0 r
.59034 .50225 m .58933 .50385 L .59168 .50057 L F
.636 .372 .501 r
.62475 .4371 m .6261 .43691 L .6249 .43831 L F
.62475 .4371 m .62651 .43533 L .6261 .43691 L F
.63 .596 .797 r
.53955 .54823 m .54175 .55226 L .53922 .55275 L F
.996 .761 .447 r
.77772 .42706 m .77859 .4305 L .77523 .43005 L F
.214 .703 .925 r
.77859 .4305 m .77842 .43008 L .77523 .43005 L F
.322 .112 .431 r
.77859 .4305 m .78074 .42744 L .78027 .42763 L F
.786 .97 .673 r
.78027 .42763 m .77842 .43008 L .77859 .4305 L F
.991 .794 .542 r
.51075 .53759 m .50969 .53677 L .51019 .53408 L F
.984 .702 .384 r
.51075 .53759 m .51113 .54027 L .50969 .53677 L F
.258 0 .296 r
.23898 .63446 m .23794 .63313 L .23974 .63242 L F
.23898 .63446 m .23714 .6354 L .23794 .63313 L F
.718 .75 .878 r
.72869 .4026 m .73005 .40456 L .73217 .40314 L F
.711 .58 .707 r
.63501 .42462 m .63266 .42781 L .63259 .42513 L F
.622 .458 .64 r
.63499 .42718 m .63266 .42781 L .63501 .42462 L F
.561 .678 .917 r
.72248 .40051 m .72585 .40213 L .72503 .39966 L F
.463 .548 .858 r
.72585 .40213 m .72743 .39961 L .72503 .39966 L F
.72585 .40213 m .72869 .4026 L .72743 .39961 L F
.732 .478 0 r
.53107 .59872 m .53035 .59565 L .53055 .59697 L F
.996 .762 .423 r
.74148 .40001 m .74197 .40378 L .74098 .40283 L F
.594 .554 .78 r
.74381 .39942 m .74197 .40378 L .74148 .40001 L F
.74381 .39942 m .74453 .40311 L .74197 .40378 L F
.56 .837 .997 r
.74197 .40378 m .74361 .40205 L .74098 .40283 L F
.74197 .40378 m .74453 .40311 L .74361 .40205 L F
0 0 0 r
.19269 .65885 m .19627 .65725 L .19501 .65817 L F
.19269 .65885 m .19501 .65817 L .19098 .65677 L F
.391 .709 .986 r
.19098 .65677 m .19269 .65885 L .19501 .65817 L F
.483 0 0 r
.18602 .5418 m .18854 .54195 L .18768 .54219 L F
.193 .716 .696 r
.18679 .54244 m .18768 .54219 L .18963 .5417 L F
.494 0 0 r
.18963 .5417 m .18768 .54219 L .19159 .54262 L F
.483 0 0 r
.18854 .54195 m .18996 .54204 L .18768 .54219 L F
.193 .716 .696 r
.18558 .54276 m .18768 .54219 L .18679 .54244 L F
.416 .196 .469 r
.24747 .62095 m .24708 .62336 L .24505 .62387 L F
.393 .196 .491 r
.24668 .6259 m .24505 .62387 L .24708 .62336 L F
.24668 .6259 m .24481 .62652 L .24505 .62387 L F
0 .201 .638 r
.4268 .56505 m .42834 .56625 L .42644 .56671 L F
.728 .629 .747 r
.63165 .42223 m .63259 .42513 L .6291 .42474 L F
.526 .89 .974 r
.6322 .42732 m .63266 .42781 L .63499 .42718 L F
.679 .439 .551 r
.63266 .42781 m .63283 .43015 L .63601 .4299 L F
.574 .65 .887 r
.45425 .56131 m .4499 .5589 L .4526 .55876 L F
.516 .642 .911 r
.45567 .55922 m .45425 .56131 L .4526 .55876 L F
.45567 .55922 m .45645 .56097 L .45425 .56131 L F
.534 .599 .865 r
.78143 .41822 m .77861 .41597 L .78105 .41528 L F
.242 .327 .752 r
.78105 .41528 m .78316 .41705 L .78143 .41822 L F
.156 .08 .513 r
.78384 .41911 m .78143 .41822 L .78316 .41705 L F
.78384 .41911 m .78196 .42139 L .78143 .41822 L F
.054 .281 .773 r
.27317 .56609 m .27317 .56839 L .27109 .5643 L F
.14 0 .19 r
.27387 .56909 m .27317 .56839 L .27317 .56609 L F
.27387 .56909 m .27255 .56982 L .27317 .56839 L F
.904 .493 .174 r
.53055 .56351 m .53115 .56521 L .53223 .56444 L F
.889 .464 .153 r
.53115 .56521 m .53265 .56613 L .53223 .56444 L F
.774 .699 .78 r
.53265 .56613 m .5368 .56556 L .53223 .56444 L F
.521 .546 .822 r
.42381 .58435 m .4229 .58811 L .42153 .58465 L F
.42381 .58435 m .42512 .58764 L .4229 .58811 L F
.554 .38 .6 r
.50563 .58508 m .50625 .5879 L .50348 .58824 L F
.50563 .58508 m .50625 .5879 L .50348 .58824 L F
.676 .391 .481 r
.50625 .5879 m .50293 .58804 L .50348 .58824 L F
.50293 .58804 m .50625 .5879 L .50348 .58824 L F
.359 .263 .609 r
.27354 .57234 m .2731 .57591 L .27159 .57629 L F
.387 .363 .71 r
.2731 .57591 m .27398 .57821 L .27159 .57629 L F
.908 .906 .809 r
.61754 .47692 m .62089 .47475 L .61974 .47377 L F
.61754 .47692 m .61868 .47797 L .62089 .47475 L F
.91 .864 .782 r
.62089 .47475 m .62059 .47153 L .61974 .47377 L F
.901 .958 .823 r
.61368 .48862 m .61685 .48611 L .61618 .48549 L F
.702 .98 .901 r
.51308 .5242 m .51662 .522 L .51686 .52257 L F
.785 .998 .817 r
.51756 .52077 m .51964 .51986 L .51686 .52257 L F
.782 .998 .83 r
.51686 .52257 m .51662 .522 L .51756 .52077 L F
.635 .801 .963 r
.70666 .40004 m .71027 .40059 L .70918 .39914 L F
.622 .814 .974 r
.71027 .40059 m .71169 .39839 L .70918 .39914 L F
.71027 .40059 m .7128 .39977 L .71169 .39839 L F
.631 .618 .818 r
.41219 .61163 m .41027 .60806 L .41263 .6091 L F
.399 .275 .594 r
.54877 .55264 m .55035 .54909 L .54771 .54918 L F
.391 .192 .486 r
.25865 .60285 m .25837 .6053 L .25646 .60587 L F
.431 .296 .596 r
.25837 .6053 m .2566 .60867 L .25646 .60587 L F
.772 .774 .854 r
.63697 .43301 m .64013 .43367 L .63855 .43232 L F
.845 .788 .797 r
.63624 .43524 m .64013 .43367 L .63697 .43301 L F
.63624 .43524 m .6378 .43668 L .64013 .43367 L F
.687 .82 .947 r
.64013 .43367 m .64152 .43105 L .63855 .43232 L F
.64013 .43367 m .64276 .43254 L .64152 .43105 L F
.471 .326 .602 r
.27111 .5609 m .27109 .5643 L .269 .56455 L F
.168 0 0 r
.7534 .41504 m .75596 .41435 L .75635 .41334 L F
.693 .666 .819 r
.75635 .41334 m .75686 .40902 L .75557 .40947 L F
.75635 .41334 m .75919 .41244 L .75686 .40902 L F
.248 .752 .71 r
.75685 .41311 m .75635 .41334 L .75596 .41435 L F
.75685 .41311 m .75919 .41244 L .75635 .41334 L F
.293 0 0 r
.23605 .55571 m .23434 .55521 L .2326 .55456 L F
.187 .635 .943 r
.23605 .55571 m .23647 .55495 L .23434 .55521 L F
.23605 .55571 m .23876 .55625 L .23647 .55495 L F
.928 .814 .713 r
.60777 .45234 m .60494 .45433 L .60579 .45338 L F
.96 .823 .663 r
.60975 .45131 m .60777 .45234 L .6062 .4508 L F
.872 .984 .702 r
.60777 .45234 m .60989 .4497 L .6062 .4508 L F
.928 .814 .713 r
.60777 .45234 m .60579 .45338 L .60751 .45145 L F
.96 .823 .663 r
.60985 .45133 m .60777 .45234 L .60975 .45131 L F
.60985 .45133 m .60938 .4535 L .60777 .45234 L F
.55 .48 .73 r
.46996 .58186 m .47399 .58338 L .47397 .58175 L F
.46996 .58186 m .47155 .58496 L .47399 .58338 L F
.615 .311 .43 r
.43063 .57526 m .43454 .57513 L .43513 .57242 L F
.617 .398 .561 r
.43454 .57513 m .4372 .57237 L .43513 .57242 L F
.755 .496 .541 r
.45916 .64408 m .45507 .64363 L .45681 .64521 L F
.334 .159 .488 r
.41767 .59634 m .4156 .59971 L .41551 .59707 L F
.798 .783 .839 r
.4859 .58144 m .48426 .58306 L .48241 .58126 L F
.426 .317 .626 r
.48614 .58434 m .48426 .58306 L .4859 .58144 L F
.48614 .58434 m .4843 .58528 L .48426 .58306 L F
.769 .698 .157 r
.7565 .40295 m .75607 .40694 L .75663 .40531 L F
0 0 .335 r
.75607 .40694 m .75721 .40766 L .75663 .40531 L F
.75607 .40694 m .75557 .40947 L .75721 .40766 L F
.375 0 .184 r
.42041 .59427 m .41767 .59634 L .41808 .59407 L F
.415 .29 .601 r
.50563 .58508 m .50625 .5879 L .50808 .5862 L F
.50563 .58508 m .50625 .5879 L .50808 .5862 L F
.718 .645 .775 r
.46736 .59758 m .46928 .60149 L .46575 .59973 L F
.605 .034 0 r
.46575 .59973 m .46928 .60149 L .46808 .60129 L F
.662 .62 .796 r
.47127 .59924 m .46928 .60149 L .46736 .59758 L F
.827 .972 .891 r
.46808 .60129 m .46928 .60149 L .47127 .59924 L F
.22 .135 .541 r
.4077 .61996 m .40768 .62256 L .40593 .62075 L F
.797 .848 .889 r
.62015 .44471 m .61729 .44477 L .6187 .44408 L F
.824 .806 .833 r
.62271 .44179 m .62015 .44471 L .6187 .44408 L F
.74 .493 .555 r
.45547 .64304 m .45797 .64185 L .45581 .64142 L F
.982 .872 .648 r
.44847 .59372 m .447 .59266 L .44866 .59274 L F
.934 .567 .172 r
.44847 .59372 m .44854 .59567 L .447 .59266 L F
.666 .269 .284 r
.44847 .59372 m .45118 .59613 L .44854 .59567 L F
.934 .567 .172 r
.44847 .59372 m .44854 .59567 L .447 .59266 L F
.617 .494 .689 r
.45126 .59305 m .44847 .59372 L .44866 .59274 L F
.554 .31 .5 r
.45126 .59305 m .45118 .59613 L .44847 .59372 L F
.407 .277 .59 r
.56107 .56017 m .55882 .55837 L .5609 .55765 L F
.56107 .56017 m .55907 .56093 L .55882 .55837 L F
.481 .495 .795 r
.74148 .40001 m .74381 .39942 L .74066 .39845 L F
.74066 .39845 m .74381 .39942 L .74148 .40001 L F
.057 .21 .708 r
.51545 .56207 m .51749 .56234 L .51505 .56046 L F
.51545 .56207 m .51735 .56375 L .51749 .56234 L F
.892 .976 .821 r
.44866 .59274 m .44929 .58974 L .45141 .59143 L F
.44866 .59274 m .447 .59266 L .44929 .58974 L F
.617 .494 .689 r
.45126 .59305 m .44866 .59274 L .45141 .59143 L F
.986 .84 .612 r
.6176 .48125 m .61868 .47797 L .61754 .47692 L F
.546 .565 .825 r
.41259 .62931 m .41058 .63024 L .40873 .62609 L F
0 0 0 r
.41259 .62931 m .40947 .6313 L .41058 .63024 L F
.749 .904 .946 r
.74884 .437 m .75217 .4365 L .75131 .4363 L F
.149 .685 .847 r
.75447 .43644 m .75131 .4363 L .75217 .4365 L F
.361 .425 .792 r
.19635 .6826 m .19702 .68015 L .19338 .67938 L F
.19635 .6826 m .19841 .68344 L .19702 .68015 L F
0 0 0 r
.59563 .51879 m .59448 .52009 L .59644 .51692 L F
.59357 .52191 m .59448 .52009 L .59563 .51879 L F
.301 .721 .973 r
.22584 .54053 m .22793 .5405 L .22983 .54142 L F
.019 .582 .8 r
.22793 .5405 m .23211 .54109 L .22983 .54142 L F
.554 .45 .691 r
.56739 .52837 m .56938 .52489 L .5673 .52554 L F
.612 .553 .764 r
.75302 .40844 m .75071 .41512 L .74929 .41384 L F
.75302 .40844 m .7534 .41504 L .75071 .41512 L F
.819 .533 .506 r
.7534 .41504 m .74929 .41384 L .75071 .41512 L F
.359 .363 .728 r
.75356 .41757 m .75071 .41512 L .7534 .41504 L F
.72 .507 .601 r
.5494 .54169 m .54559 .54022 L .54774 .53957 L F
.5494 .54169 m .54566 .54291 L .54559 .54022 L F
.5494 .54169 m .54963 .54481 L .54566 .54291 L F
.756 .355 .293 r
.54843 .54211 m .5494 .54169 L .54774 .53957 L F
.54843 .54211 m .55093 .5408 L .5494 .54169 L F
.956 .707 .52 r
.53068 .5483 m .5327 .54944 L .53254 .55186 L F
.53254 .55186 m .5327 .54944 L .53068 .5483 L F
.085 .634 .827 r
.67402 .39759 m .67479 .39792 L .67244 .39783 L F
.549 .341 .55 r
.19943 .70346 m .19641 .70664 L .19698 .70426 L F
0 .306 .743 r
.41002 .63767 m .40941 .63774 L .40713 .63573 L F
.41002 .63767 m .4113 .63873 L .40941 .63774 L F
.394 .134 .396 r
.55234 .59996 m .55495 .59709 L .55474 .59952 L F
.543 .401 .638 r
.55697 .59377 m .5571 .59653 L .55495 .59709 L F
.556 .349 .554 r
.5571 .59653 m .55474 .59952 L .55495 .59709 L F
.96 .803 .643 r
.67872 .45125 m .67811 .45383 L .67718 .45018 L F
.617 .214 .257 r
.67506 .40966 m .67743 .41121 L .67515 .41203 L F
.67506 .40966 m .67896 .4098 L .67743 .41121 L F
.727 .86 .944 r
.53849 .5291 m .54027 .52866 L .53764 .52765 L F
.772 .557 .608 r
.53641 .53083 m .54027 .52866 L .53849 .5291 L F
.53641 .53083 m .54034 .53131 L .54027 .52866 L F
.949 .895 .74 r
.5383 .5279 m .53998 .52553 L .53764 .52765 L F
.825 .711 .739 r
.53764 .52765 m .53998 .52553 L .53787 .52428 L F
.601 .798 .975 r
.53802 .5283 m .5382 .52804 L .53849 .5291 L F
.53764 .52765 m .5382 .52804 L .53802 .5283 L F
.53764 .52765 m .53785 .52675 L .5382 .52804 L F
0 0 .4 r
.53814 .52782 m .53661 .53029 L .5382 .52804 L F
.53785 .52675 m .53696 .52929 L .53814 .52782 L F
.53696 .52929 m .53661 .53029 L .53814 .52782 L F
.5382 .52804 m .53641 .53083 L .53849 .5291 L F
.53661 .53029 m .53641 .53083 L .5382 .52804 L F
.53785 .52675 m .5379 .52928 L .53674 .53049 L F
.53696 .52929 m .53674 .53049 L .53641 .53083 L F
.53785 .52675 m .53674 .53049 L .53696 .52929 L F
.825 .711 .739 r
.53767 .52539 m .53787 .52428 L .53768 .52417 L F
.53764 .52765 m .53787 .52428 L .53767 .52539 L F
.53998 .52553 m .54105 .52456 L .54078 .52453 L F
.53998 .52553 m .54078 .52453 L .53768 .52417 L F
.949 .895 .74 r
.54027 .52866 m .54105 .52456 L .53998 .52553 L F
.54027 .52866 m .53998 .52553 L .5383 .5279 L F
.385 .845 .886 r
.16599 .56433 m .16698 .56482 L .16888 .56367 L F
.16599 .56433 m .16376 .56488 L .16698 .56482 L F
0 .543 .727 r
.42245 .57877 m .42637 .57913 L .42399 .57915 L F
.624 .55 .75 r
.63756 .40703 m .63444 .4057 L .63611 .40501 L F
.874 .896 .845 r
.66846 .41881 m .66953 .41463 L .6683 .41693 L F
.66846 .41881 m .67067 .41617 L .66953 .41463 L F
.959 .926 .586 r
.66748 .42102 m .66846 .41881 L .6683 .41693 L F
.399 .275 .594 r
.54877 .55264 m .55072 .55169 L .55035 .54909 L F
.32 .121 .446 r
.55047 .55389 m .55072 .55169 L .54877 .55264 L F
.74 .935 .599 r
.55712 .4981 m .55527 .50113 L .55809 .49873 L F
.55712 .4981 m .55508 .50095 L .55527 .50113 L F
.611 .536 .745 r
.5296 .55248 m .52985 .55509 L .52721 .55536 L F
.563 .305 .482 r
.52721 .55536 m .52959 .55727 L .52985 .55509 L F
.611 .536 .745 r
.52721 .55536 m .52985 .55509 L .5296 .55248 L F
.563 .305 .482 r
.52721 .55536 m .52959 .55727 L .52985 .55509 L F
.904 .751 .254 r
.52431 .5422 m .52418 .54501 L .52461 .54346 L F
.305 .202 .57 r
.52418 .54501 m .52431 .5422 L .52461 .54346 L F
.888 .752 .706 r
.74849 .4317 m .74868 .43392 L .74708 .4321 L F
.74708 .4321 m .74868 .43392 L .74849 .4317 L F
.74849 .4317 m .74868 .43392 L .74708 .4321 L F
.2 0 .21 r
.58321 .47188 m .58293 .4738 L .58063 .47445 L F
.348 0 .104 r
.58293 .4738 m .57954 .47575 L .58063 .47445 L F
.412 .18 .45 r
.57509 .46325 m .57742 .46246 L .57735 .46015 L F
.425 .19 .452 r
.57735 .46015 m .5797 .46171 L .57989 .45961 L F
.57735 .46015 m .57742 .46246 L .5797 .46171 L F
.102 0 0 r
.75822 .43665 m .75727 .43669 L .75447 .43644 L F
.188 .72 .813 r
.76146 .4364 m .75727 .43669 L .75822 .43665 L F
.919 .864 .769 r
.6277 .45792 m .62833 .45348 L .62718 .45563 L F
.936 .945 .769 r
.62575 .4588 m .6277 .45792 L .62718 .45563 L F
.62575 .4588 m .62663 .45979 L .6277 .45792 L F
.72 .756 .881 r
.69084 .45118 m .69446 .45169 L .69257 .45037 L F
.649 .714 .896 r
.69446 .45169 m .69637 .45124 L .69257 .45037 L F
.955 .935 .731 r
.62485 .46306 m .62663 .45979 L .62575 .4588 L F
.647 .429 .574 r
.56219 .53388 m .56494 .5311 L .56224 .53158 L F
.826 .907 .895 r
.54867 .59773 m .54628 .59748 L .54464 .59902 L F
.175 0 .094 r
.54498 .60219 m .54867 .59773 L .54464 .59902 L F
.54498 .60219 m .54733 .60114 L .54867 .59773 L F
.478 .269 .517 r
.54733 .60114 m .54985 .59792 L .54867 .59773 L F
.102 0 0 r
.54867 .59773 m .54985 .59792 L .54628 .59748 L F
.321 .789 .933 r
.23211 .54109 m .23384 .54065 L .23592 .54111 L F
.602 .731 .935 r
.19184 .70775 m .19236 .70567 L .19146 .7069 L F
.19184 .70775 m .19439 .70745 L .19236 .70567 L F
.93 .587 .147 r
.63411 .43617 m .6378 .43668 L .63624 .43524 L F
.63411 .43617 m .6356 .43979 L .6378 .43668 L F
.753 .577 .658 r
.45446 .57576 m .4568 .57608 L .45674 .57325 L F
.674 .72 .883 r
.73207 .39009 m .73329 .39209 L .72965 .39132 L F
.685 .751 .901 r
.73457 .3889 m .73329 .39209 L .73207 .39009 L F
.73457 .3889 m .73577 .39112 L .73329 .39209 L F
.461 .841 .986 r
.65963 .40039 m .65777 .40167 L .65647 .40066 L F
.65963 .40039 m .65995 .40117 L .65777 .40167 L F
.579 .619 .857 r
.4586 .56063 m .45789 .56427 L .45645 .56097 L F
.43 .128 .349 r
.45789 .56427 m .46023 .56372 L .46049 .56336 L F
.579 .619 .857 r
.4586 .56063 m .46023 .56372 L .45789 .56427 L F
.73 .325 .282 r
.46341 .60541 m .46532 .609 L .46699 .6059 L F
.56 .628 .876 r
.46815 .60591 m .46733 .60882 L .46699 .6059 L F
0 0 0 r
.46699 .6059 m .46807 .60597 L .46815 .60591 L F
.46699 .6059 m .46532 .609 L .46807 .60597 L F
.783 .327 .162 r
.42813 .57183 m .42961 .5732 L .42964 .57158 L F
.63 .413 .569 r
.43063 .57526 m .42918 .57253 L .42964 .57158 L F
.046 .047 .534 r
.43196 .57104 m .43063 .57526 L .42964 .57158 L F
.43196 .57104 m .43244 .57402 L .43063 .57526 L F
.783 .327 .162 r
.42961 .5732 m .43127 .57473 L .42964 .57158 L F
0 0 .033 r
.42965 .5704 m .42964 .57158 L .42918 .57253 L F
.4299 .56926 m .42964 .57158 L .42965 .5704 L F
.63 .413 .569 r
.43063 .57526 m .42869 .5756 L .42918 .57253 L F
.42918 .57253 m .42869 .5756 L .43063 .57526 L F
.523 .88 .649 r
.46632 .56876 m .46533 .56976 L .46767 .56911 L F
.389 .173 .46 r
.24907 .6227 m .24747 .62095 L .2495 .62035 L F
.24907 .6227 m .24708 .62336 L .24747 .62095 L F
.929 .923 .784 r
.63337 .44034 m .6356 .43979 L .63462 .43872 L F
.63337 .44034 m .63446 .4414 L .6356 .43979 L F
.93 .587 .147 r
.63411 .43617 m .63462 .43872 L .6356 .43979 L F
.701 .386 0 r
.74081 .42819 m .74156 .43027 L .74102 .42863 L F
.789 .411 .341 r
.42135 .63799 m .42359 .64052 L .42451 .63901 L F
.55 .926 .92 r
.70422 .40115 m .70578 .3998 L .70301 .40091 L F
.70422 .40115 m .70666 .40004 L .70578 .3998 L F
.455 .419 .729 r
.23613 .58547 m .23828 .58515 L .23738 .58357 L F
.377 .515 .869 r
.23613 .58547 m .2393 .58772 L .23828 .58515 L F
.029 .008 .494 r
.24611 .57312 m .24698 .56928 L .24518 .56986 L F
.24611 .57312 m .24727 .57215 L .24698 .56928 L F
0 0 .221 r
.24611 .57312 m .24692 .57397 L .24727 .57215 L F
.24611 .57312 m .24544 .57563 L .24692 .57397 L F
.711 .588 .717 r
.70249 .43584 m .70365 .44005 L .6997 .43896 L F
.651 .552 .73 r
.70585 .43892 m .70365 .44005 L .70249 .43584 L F
.47 .297 .564 r
.6801 .45514 m .67811 .45383 L .681 .45491 L F
.87 .584 .501 r
.67811 .45383 m .67844 .45652 L .67547 .45514 L F
.47 .297 .564 r
.68058 .45545 m .67844 .45652 L .67811 .45383 L F
.774 .96 .929 r
.67937 .45421 m .67752 .45569 L .67761 .45576 L F
.67887 .45544 m .67761 .45576 L .67844 .45652 L F
.67937 .45421 m .67761 .45576 L .67887 .45544 L F
.47 .297 .564 r
.681 .45491 m .67811 .45383 L .68174 .45397 L F
.68058 .45545 m .6801 .45514 L .681 .45491 L F
.509 .225 .419 r
.74264 .41277 m .74635 .4108 L .74296 .41077 L F
0 0 0 r
.43193 .60003 m .43273 .599 L .43401 .59684 L F
.974 .784 .586 r
.43193 .60003 m .43148 .60241 L .43033 .60017 L F
.719 .509 .605 r
.43496 .60243 m .43148 .60241 L .43193 .60003 L F
.414 0 0 r
.6812 .39888 m .67856 .39786 L .67772 .39829 L F
.04 0 .313 r
.7467 .42671 m .74702 .42774 L .74854 .42563 L F
.528 .739 .972 r
.75167 .39143 m .74805 .39033 L .75058 .38977 L F
.49 .684 .952 r
.75391 .39109 m .75167 .39143 L .75058 .38977 L F
.776 .812 .881 r
.73044 .43863 m .73395 .43866 L .73286 .43707 L F
.709 .811 .929 r
.73286 .43707 m .73395 .43866 L .73679 .43683 L F
.943 .878 .742 r
.76529 .41697 m .76736 .41619 L .76628 .415 L F
.76529 .41697 m .76637 .4182 L .76736 .41619 L F
.531 .255 .442 r
.43781 .60003 m .43745 .60212 L .43496 .60243 L F
.53 .254 .441 r
.43781 .60003 m .4399 .60182 L .43745 .60212 L F
.481 .263 .505 r
.44012 .59942 m .4399 .60182 L .43781 .60003 L F
.95 .688 .506 r
.43807 .62966 m .43817 .63258 L .43626 .6316 L F
.727 .444 .499 r
.43417 .61182 m .43416 .61458 L .43588 .61423 L F
.56 .569 .82 r
.43797 .61483 m .43417 .61182 L .43588 .61423 L F
.444 .285 .57 r
.44009 .63155 m .43817 .63258 L .43807 .62966 L F
.028 .6 .724 r
.43626 .6316 m .44009 .63155 L .43807 .62966 L F
.136 0 .313 r
.59805 .51547 m .59644 .51692 L .5984 .51356 L F
0 0 .079 r
.59563 .51879 m .59644 .51692 L .59805 .51547 L F
.273 .214 .606 r
.40724 .63276 m .40556 .63475 L .40603 .6316 L F
.356 .331 .693 r
.40724 .63276 m .40713 .63573 L .40556 .63475 L F
.303 0 .195 r
.23714 .6354 m .23395 .63788 L .23504 .63602 L F
0 0 .44 r
.5373 .58356 m .5361 .58208 L .53535 .58059 L F
.774 .766 .846 r
.71737 .44803 m .72076 .44838 L .71921 .44689 L F
.81 .767 .813 r
.71921 .44689 m .72076 .44838 L .72325 .44541 L F
.652 .635 .821 r
.73988 .39527 m .74066 .39845 L .74321 .39717 L F
.034 .517 .881 r
.7423 .39832 m .74381 .39942 L .74066 .39845 L F
.7423 .39832 m .74066 .39845 L .74047 .40195 L F
.224 0 .229 r
.22922 .64369 m .22745 .64446 L .23011 .6417 L F
.142 0 .151 r
.23191 .64087 m .22922 .64369 L .23011 .6417 L F
.973 .888 .684 r
.76655 .40573 m .76529 .40872 L .76656 .40894 L F
.99 .8 .556 r
.76656 .40894 m .76498 .41119 L .76598 .41247 L F
.76656 .40894 m .76529 .40872 L .76498 .41119 L F
.391 .822 .961 r
.19798 .54071 m .20007 .54025 L .20173 .54066 L F
.327 .782 .949 r
.20007 .54025 m .20388 .5404 L .20173 .54066 L F
.315 .805 .815 r
.19621 .55607 m .19382 .55643 L .19187 .55706 L F
.421 .867 .86 r
.19617 .55552 m .1965 .55585 L .1981 .55466 L F
.363 0 0 r
.19666 .55534 m .19832 .55555 L .19617 .55552 L F
.20034 .55402 m .19832 .55555 L .19666 .55534 L F
.438 0 .015 r
.2024 .55409 m .20054 .55591 L .19832 .55555 L F
.147 .599 .93 r
.19832 .55555 m .20054 .55591 L .20037 .5558 L F
.023 .594 .761 r
.20406 .55424 m .2024 .55409 L .20034 .55402 L F
.438 0 .015 r
.2024 .55409 m .19832 .55555 L .20034 .55402 L F
.147 .599 .93 r
.19832 .55555 m .20037 .5558 L .19883 .55481 L F
.43 .81 .991 r
.19832 .55555 m .19601 .55536 L .19617 .55552 L F
.19601 .55536 m .19436 .55523 L .19617 .55552 L F
.421 .867 .86 r
.19617 .55552 m .19621 .55607 L .1965 .55585 L F
.19617 .55552 m .19382 .55643 L .19621 .55607 L F
.387 .551 .895 r
.75557 .40947 m .75686 .40902 L .75721 .40766 L F
0 .106 .628 r
.50482 .53192 m .50596 .53294 L .50522 .53187 L F
.703 .628 .769 r
.67983 .40599 m .67896 .4098 L .67753 .40695 L F
.67983 .40599 m .68116 .40955 L .67896 .4098 L F
.317 .797 .905 r
.67896 .4098 m .68116 .40955 L .68053 .40927 L F
.67896 .4098 m .68053 .40927 L .67743 .41121 L F
.947 .926 .752 r
.67067 .41617 m .67177 .41095 L .66953 .41463 L F
.394 .176 .46 r
.58221 .53776 m .58498 .53443 L .58478 .53691 L F
.369 .096 .362 r
.58187 .53967 m .58221 .53776 L .58478 .53691 L F
.721 .823 .928 r
.64201 .40285 m .64012 .40437 L .63855 .4027 L F
.375 0 .184 r
.42041 .59427 m .41995 .59599 L .41767 .59634 L F
.495 .099 .22 r
.42222 .59534 m .41995 .59599 L .42041 .59427 L F
.755 .54 .604 r
.77523 .43005 m .77156 .42706 L .77573 .427 L F
.602 .447 .645 r
.77573 .427 m .77772 .42706 L .77523 .43005 L F
.092 .218 .704 r
.46056 .58047 m .4599 .5806 L .46221 .58091 L F
.762 .861 .923 r
.46127 .58019 m .45933 .58072 L .4599 .5806 L F
.816 1 .832 r
.46127 .58019 m .4599 .5806 L .4626 .57808 L F
.857 .974 .865 r
.4626 .57808 m .4599 .5806 L .45978 .58053 L F
.46056 .5792 m .45978 .58053 L .45901 .58005 L F
.4626 .57808 m .45978 .58053 L .46056 .5792 L F
.816 1 .832 r
.46127 .58019 m .4626 .57808 L .46387 .57912 L F
.652 .781 .942 r
.46648 .57852 m .46387 .57912 L .4626 .57808 L F
.635 .495 .674 r
.46648 .57852 m .46577 .58043 L .46387 .57912 L F
.652 .781 .942 r
.46648 .57852 m .4626 .57808 L .4655 .57638 L F
.857 .974 .865 r
.4626 .57808 m .45901 .58005 L .46138 .57715 L F
.606 .875 .992 r
.4626 .57808 m .46335 .57653 L .4655 .57638 L F
.4626 .57808 m .46138 .57715 L .46335 .57653 L F
.481 .451 .748 r
.46165 .57734 m .46221 .58091 L .46533 .57981 L F
.46138 .57715 m .46148 .57763 L .46165 .57734 L F
.46148 .57763 m .46221 .58091 L .46165 .57734 L F
.092 .218 .704 r
.45901 .58005 m .4599 .5806 L .46056 .58047 L F
.762 .861 .923 r
.45933 .58072 m .45824 .58101 L .4599 .5806 L F
.973 .815 .626 r
.52737 .68097 m .52645 .6827 L .52567 .67969 L F
.7 .873 .963 r
.52885 .67969 m .52737 .68097 L .52567 .67969 L F
.409 .691 .977 r
.20805 .55526 m .20847 .5537 L .20657 .55384 L F
.154 .411 .854 r
.20805 .55526 m .21053 .55676 L .20847 .5537 L F
.352 .113 .406 r
.58535 .47099 m .58321 .47188 L .58573 .46893 L F
.21 0 .184 r
.58535 .47099 m .58293 .4738 L .58321 .47188 L F
.555 .574 .828 r
.17704 .63335 m .17623 .63665 L .17541 .63529 L F
.17704 .63335 m .17824 .63568 L .17623 .63665 L F
.909 .669 .167 r
.51807 .54296 m .51774 .54298 L .51748 .53982 L F
.527 .301 .516 r
.59519 .44447 m .59783 .44166 L .5956 .44254 L F
.552 .347 .557 r
.27425 .55827 m .27109 .5643 L .27111 .5609 L F
.27425 .55827 m .27297 .56552 L .27109 .5643 L F
.29 0 .039 r
.27635 .55767 m .27519 .55919 L .27425 .55827 L F
.496 .297 .539 r
.2764 .56344 m .27425 .55827 L .27519 .55919 L F
.2764 .56344 m .27297 .56552 L .27425 .55827 L F
.783 .704 .777 r
.69855 .43545 m .6997 .43896 L .69609 .43853 L F
.776 .721 .801 r
.6997 .43896 m .69788 .44034 L .69609 .43853 L F
.78 .703 .778 r
.70249 .43584 m .6997 .43896 L .69855 .43545 L F
.675 .791 .937 r
.43018 .59647 m .43401 .59684 L .43301 .59527 L F
.265 .554 .929 r
.43401 .59684 m .43563 .59562 L .43301 .59527 L F
.163 0 .017 r
.43401 .59684 m .43495 .5981 L .43563 .59562 L F
.43401 .59684 m .43273 .599 L .43495 .5981 L F
.751 .727 .83 r
.69788 .44034 m .6928 .44159 L .69609 .43853 L F
.974 .7 .447 r
.60336 .47529 m .6021 .47657 L .60232 .47403 L F
.60336 .47529 m .60355 .47757 L .6021 .47657 L F
.358 0 .18 r
.61884 .40872 m .62137 .40812 L .62161 .40693 L F
.476 .101 .248 r
.62137 .40812 m .62427 .40656 L .62161 .40693 L F
.985 .72 .344 r
.48853 .59127 m .48825 .59233 L .48793 .59214 L F
.55 .767 .979 r
.49845 .56881 m .49938 .57016 L .49584 .5695 L F
.513 .017 0 r
.49679 .57077 m .49938 .57016 L .49584 .5695 L F
.49679 .57077 m .49845 .56881 L .49938 .57016 L F
.956 .934 .604 r
.60716 .45617 m .60777 .45234 L .60938 .4535 L F
.748 .759 .25 r
.65024 .42933 m .65082 .42733 L .65027 .42884 L F
.97 .891 .692 r
.65082 .42733 m .65156 .42306 L .65092 .42635 L F
.773 .763 .253 r
.65027 .42884 m .65082 .42733 L .65092 .42635 L F
.573 .352 .542 r
.22321 .61163 m .22564 .6113 L .2259 .60881 L F
.483 .276 .522 r
.22564 .6113 m .22808 .60829 L .2259 .60881 L F
.485 .764 .993 r
.56287 .58369 m .56485 .58515 L .56192 .58502 L F
.639 .358 .476 r
.56192 .58502 m .56485 .58515 L .56415 .58716 L F
.485 .764 .993 r
.56287 .58369 m .56192 .58502 L .56232 .58603 L F
0 0 0 r
.24422 .57682 m .24317 .5785 L .24544 .57563 L F
.863 .89 .854 r
.48837 .57871 m .4859 .58144 L .48688 .57992 L F
.231 .341 .77 r
.68261 .40789 m .68116 .40955 L .67983 .40599 L F
.636 .963 .897 r
.68053 .40927 m .68116 .40955 L .68261 .40789 L F
.554 .318 .513 r
.59053 .44826 m .59294 .45 L .59278 .44746 L F
.59053 .44826 m .59038 .45053 L .59294 .45 L F
.866 .698 .673 r
.77749 .41212 m .77861 .41597 L .77733 .41421 L F
.834 .766 .786 r
.77861 .41597 m .77504 .41742 L .77733 .41421 L F
.77861 .41597 m .77662 .41889 L .77504 .41742 L F
.567 .457 .688 r
.78027 .41344 m .77861 .41597 L .77749 .41212 L F
.78027 .41344 m .78105 .41528 L .77861 .41597 L F
.758 .739 .835 r
.77662 .41889 m .77292 .4186 L .77504 .41742 L F
.252 0 .096 r
.22745 .64446 m .22619 .64667 L .22405 .64722 L F
.086 0 .008 r
.22799 .64578 m .22745 .64446 L .22922 .64369 L F
.22799 .64578 m .22619 .64667 L .22745 .64446 L F
.926 .607 .142 r
.72977 .42857 m .72861 .42584 L .73045 .42872 L F
0 .101 .633 r
.73045 .42872 m .7316 .43033 L .72977 .42857 L F
.905 .604 .466 r
.43674 .64573 m .44017 .64415 L .43678 .64405 L F
.43674 .64573 m .44055 .64704 L .44017 .64415 L F
.464 .213 .448 r
.58542 .45396 m .5878 .45334 L .58804 .45124 L F
.441 .194 .442 r
.58804 .45124 m .5878 .45334 L .59038 .45053 L F
.553 .09 .109 r
.41413 .64683 m .41266 .64873 L .41017 .6473 L F
.754 .375 .337 r
.41573 .64836 m .41266 .64873 L .41413 .64683 L F
.222 .514 .912 r
.25631 .54403 m .25583 .54541 L .25347 .54348 L F
.25631 .54403 m .25743 .54571 L .25583 .54541 L F
.734 .655 .771 r
.21495 .61715 m .21862 .61775 L .2169 .61692 L F
.514 .246 .446 r
.21856 .62046 m .22149 .61772 L .21862 .61775 L F
.621 .747 .937 r
.70248 .4525 m .70583 .45321 L .70531 .45055 L F
.707 .751 .887 r
.70583 .45321 m .70745 .44964 L .70531 .45055 L F
.70583 .45321 m .70909 .45145 L .70745 .44964 L F
.653 .946 .956 r
.67182 .40915 m .66925 .41069 L .6687 .40981 L F
.49 .842 .995 r
.59956 .45811 m .60434 .4572 L .60544 .45787 L F
.742 .935 .95 r
.60544 .45787 m .6064 .45577 L .60716 .45617 L F
.60544 .45787 m .60434 .4572 L .6064 .45577 L F
.555 .094 .113 r
.59232 .46856 m .59061 .47028 L .58821 .46894 L F
.427 .271 .565 r
.59417 .46574 m .59434 .46813 L .59232 .46856 L F
.53 .065 .095 r
.59454 .46984 m .59232 .46856 L .59434 .46813 L F
.59454 .46984 m .59061 .47028 L .59232 .46856 L F
.127 0 0 r
.19188 .71244 m .1939 .71196 L .19557 .71056 L F
.582 .653 .885 r
.19857 .71169 m .19557 .71056 L .19772 .7096 L F
.123 0 0 r
.19557 .71056 m .19621 .71129 L .19772 .7096 L F
.19557 .71056 m .1939 .71196 L .19621 .71129 L F
0 0 0 r
.55474 .59952 m .55178 .6018 L .55234 .59996 L F
.349 .099 .388 r
.26999 .58462 m .26957 .58723 L .26751 .58773 L F
.392 .219 .524 r
.27216 .58149 m .27214 .58422 L .26999 .58462 L F
.445 .217 .473 r
.27214 .58422 m .26957 .58723 L .26999 .58462 L F
.588 .785 .974 r
.46767 .56911 m .47145 .56984 L .47009 .56862 L F
.78 .356 .242 r
.47349 .57014 m .47009 .56862 L .47145 .56984 L F
.926 .96 .78 r
.55935 .49473 m .55809 .49873 L .55997 .4953 L F
.55935 .49473 m .55712 .4981 L .55809 .49873 L F
.332 .74 .98 r
.19822 .67299 m .20029 .67288 L .20012 .67383 L F
.943 .705 .548 r
.19822 .67299 m .20012 .67383 L .20029 .67288 L F
.19822 .67299 m .19971 .67666 L .20012 .67383 L F
.766 .736 .825 r
.70249 .43584 m .69855 .43545 L .70089 .43287 L F
.505 .58 .864 r
.70346 .4322 m .70249 .43584 L .70089 .43287 L F
.70346 .4322 m .70477 .43543 L .70249 .43584 L F
.651 .552 .73 r
.70585 .43892 m .70249 .43584 L .70477 .43543 L F
.58 .649 .883 r
.39997 .64217 m .40448 .6444 L .40286 .64343 L F
0 .148 .625 r
.40448 .6444 m .40443 .64414 L .40286 .64343 L F
.40448 .6444 m .40663 .64605 L .40443 .64414 L F
.406 .2 .485 r
.26064 .60222 m .25837 .6053 L .25865 .60285 L F
.825 .957 .62 r
.59409 .4949 m .59201 .49852 L .59274 .49649 L F
.698 .718 .195 r
.59168 .50057 m .59274 .49649 L .59201 .49852 L F
.716 .643 .775 r
.62741 .42159 m .6291 .42474 L .6253 .42433 L F
.86 .912 .866 r
.6291 .42474 m .62648 .42605 L .6253 .42433 L F
.742 .653 .762 r
.63165 .42223 m .6291 .42474 L .62741 .42159 L F
.389 .195 .492 r
.22836 .60583 m .22996 .60762 L .23011 .60516 L F
.22836 .60583 m .22808 .60829 L .22996 .60762 L F
.378 .071 .313 r
.40835 .58186 m .41059 .5812 L .41113 .57856 L F
.332 .033 .299 r
.41113 .57856 m .41268 .58034 L .41333 .5785 L F
.41113 .57856 m .41059 .5812 L .41268 .58034 L F
.313 .034 .32 r
.61441 .43033 m .61416 .43237 L .61179 .43321 L F
.37 .206 .524 r
.61646 .42677 m .61687 .42931 L .61441 .43033 L F
.547 .355 .572 r
.61687 .42931 m .61416 .43237 L .61441 .43033 L F
.445 .855 .964 r
.20778 .54016 m .20388 .5404 L .20597 .53984 L F
.119 .665 .825 r
.20597 .53984 m .20994 .53999 L .20778 .54016 L F
.366 .519 .877 r
.55871 .57874 m .55665 .57742 L .55777 .5787 L F
.824 .806 .833 r
.62271 .44179 m .6187 .44408 L .6222 .44132 L F
.895 .981 .701 r
.62271 .44179 m .62475 .4371 L .6249 .43831 L F
.62271 .44179 m .6222 .44132 L .62475 .4371 L F
.414 .847 .944 r
.17522 .56191 m .17521 .56106 L .17311 .56251 L F
.17522 .56191 m .17756 .56129 L .17521 .56106 L F
.784 .906 .926 r
.6928 .44159 m .69142 .44266 L .69224 .44024 L F
.811 .935 .912 r
.69224 .44024 m .69142 .44266 L .69031 .44175 L F
0 .111 .66 r
.19772 .7096 m .19919 .71128 L .19857 .71169 L F
0 0 0 r
.19919 .71128 m .19804 .71297 L .19857 .71169 L F
.596 .346 .508 r
.54118 .59095 m .54346 .59259 L .54196 .59278 L F
.574 .348 .535 r
.23046 .60266 m .23293 .60248 L .23325 .59986 L F
.424 .219 .496 r
.23325 .59986 m .23497 .60175 L .23516 .59921 L F
.23325 .59986 m .23293 .60248 L .23497 .60175 L F
.708 .527 .641 r
.53942 .59997 m .54046 .60258 L .5377 .60248 L F
0 0 0 r
.59983 .51201 m .5984 .51356 L .60048 .51031 L F
0 0 .155 r
.59805 .51547 m .5984 .51356 L .59983 .51201 L F
0 .411 .732 r
.40803 .6466 m .41017 .6473 L .40663 .64605 L F
.512 .631 .905 r
.64495 .43227 m .64684 .43525 L .64805 .43405 L F
.472 .259 .508 r
.40574 .58209 m .40791 .58384 L .40835 .58186 L F
.40574 .58209 m .40566 .5845 L .40791 .58384 L F
.807 1 .816 r
.52037 .51795 m .51964 .51986 L .51756 .52077 L F
.756 .987 .897 r
.53982 .58529 m .54076 .58341 L .54211 .5848 L F
.53982 .58529 m .53638 .58582 L .54076 .58341 L F
.48 .284 .536 r
.59783 .44166 m .6002 .43831 L .59784 .43926 L F
.72 .702 .832 r
.75099 .42005 m .75219 .42184 L .74843 .42114 L F
.771 .731 .816 r
.68194 .44245 m .68301 .44546 L .67952 .44487 L F
.769 .73 .817 r
.68563 .4434 m .68301 .44546 L .68194 .44245 L F
.388 .158 .44 r
.23388 .64022 m .2324 .63854 L .23395 .63788 L F
.23388 .64022 m .23191 .64087 L .2324 .63854 L F
.12 0 .011 r
.54081 .54676 m .54288 .54576 L .53955 .54823 L F
.862 .794 .782 r
.77086 .42365 m .77156 .42706 L .77009 .42552 L F
.916 .668 .548 r
.77156 .42706 m .76944 .42833 L .77009 .42552 L F
.77156 .42706 m .7717 .42989 L .76944 .42833 L F
.755 .54 .604 r
.77523 .43005 m .7717 .42989 L .77156 .42706 L F
.473 .481 .785 r
.55719 .56994 m .56038 .57174 L .55805 .57433 L F
.298 .425 .822 r
.56101 .57459 m .55805 .57433 L .56038 .57174 L F
.56101 .57459 m .55969 .57598 L .55805 .57433 L F
0 .232 .751 r
.7562 .39298 m .75631 .39466 L .75391 .39109 L F
.118 .445 .88 r
.7562 .39298 m .75981 .39639 L .75631 .39466 L F
.629 .555 .752 r
.43613 .58107 m .43375 .582 L .4329 .57889 L F
.836 .652 .654 r
.43613 .58107 m .43241 .58357 L .43375 .582 L F
.403 .277 .594 r
.37661 .60563 m .37859 .60135 L .37629 .60304 L F
.201 0 .226 r
.48614 .58434 m .48358 .58717 L .4843 .58528 L F
.664 .39 .495 r
.55147 .54262 m .55367 .54002 L .55093 .5408 L F
.756 .355 .293 r
.54843 .54211 m .55147 .54262 L .55093 .5408 L F
.517 .32 .552 r
.59278 .44746 m .59519 .44447 L .59292 .44524 L F
.083 0 0 r
.68613 .39851 m .68484 .3981 L .68364 .39857 L F
.68613 .39851 m .68735 .39742 L .68484 .3981 L F
.63 .727 .917 r
.60658 .43694 m .60839 .43508 L .60612 .43604 L F
.60658 .43694 m .60899 .43635 L .60839 .43508 L F
.479 .12 .277 r
.6217 .42407 m .6191 .42576 L .61931 .42455 L F
.277 .381 .789 r
.19146 .7069 m .19236 .70567 L .19034 .70409 L F
.401 .132 .388 r
.5725 .46596 m .57483 .46526 L .57509 .46325 L F
.32 .067 .365 r
.57509 .46325 m .57694 .46425 L .57742 .46246 L F
.57509 .46325 m .57483 .46526 L .57694 .46425 L F
.993 .829 .576 r
.76497 .41911 m .76628 .42021 L .76637 .4182 L F
.852 .985 .704 r
.54262 .51834 m .53995 .52115 L .54123 .52229 L F
.54262 .51834 m .54208 .51807 L .53995 .52115 L F
.436 .281 .572 r
.26729 .59008 m .26506 .59355 L .26507 .59102 L F
.639 .96 .92 r
.47399 .58338 m .47155 .58496 L .46922 .58544 L F
.635 .522 .708 r
.47399 .58338 m .4715 .58763 L .47155 .58496 L F
.828 .407 .24 r
.47962 .57378 m .47854 .5744 L .47804 .57167 L F
.47962 .57378 m .4809 .57574 L .47854 .5744 L F
.74 .42 .441 r
.54386 .5395 m .54706 .53751 L .54563 .53766 L F
.54386 .5395 m .54774 .53957 L .54706 .53751 L F
.735 .324 .27 r
.19971 .67666 m .20152 .67883 L .20354 .67715 L F
.949 .956 .679 r
.20354 .67715 m .20152 .67883 L .20278 .67668 L F
.379 .237 .559 r
.20152 .67883 m .20179 .67843 L .20278 .67668 L F
.20179 .67843 m .20373 .67543 L .20278 .67668 L F
.591 .681 .904 r
.20369 .67411 m .20364 .67518 L .20278 .67668 L F
.20364 .67518 m .20354 .67715 L .20278 .67668 L F
.514 .246 .446 r
.21856 .62046 m .22095 .62013 L .22149 .61772 L F
.432 .172 .418 r
.22149 .61772 m .22311 .6195 L .22362 .61702 L F
.22149 .61772 m .22095 .62013 L .22311 .6195 L F
.431 .088 .281 r
.58821 .46894 m .58535 .47099 L .58573 .46893 L F
.595 .481 .694 r
.20661 .66283 m .20699 .66518 L .20897 .66253 L F
.766 .587 .656 r
.62483 .42264 m .6253 .42433 L .6217 .42407 L F
.622 .52 .717 r
.62741 .42159 m .62483 .42264 L .62428 .41824 L F
.614 .497 .696 r
.62741 .42159 m .6253 .42433 L .62483 .42264 L F
.956 .934 .604 r
.60716 .45617 m .6064 .45577 L .60777 .45234 L F
.941 .839 .716 r
.59823 .48941 m .59579 .49164 L .59783 .48842 L F
.59823 .48941 m .59728 .49281 L .59579 .49164 L F
.272 .065 .405 r
.58019 .51869 m .57835 .51965 L .57802 .52189 L F
.681 .444 .557 r
.59409 .4949 m .59705 .49516 L .59728 .49281 L F
.98 .741 .502 r
.59728 .49281 m .59705 .49516 L .59579 .49164 L F
0 0 0 r
.18356 .5583 m .18344 .55775 L .18576 .55682 L F
.18356 .5583 m .1813 .55911 L .18344 .55775 L F
.52 .865 .992 r
.49066 .56752 m .48995 .56896 L .4883 .56821 L F
.49066 .56752 m .49247 .56819 L .48995 .56896 L F
0 0 .018 r
.65211 .41839 m .65222 .41438 L .65225 .41463 L F
.763 .583 .012 r
.65209 .41988 m .65211 .41839 L .65225 .41463 L F
.65209 .41988 m .65225 .42087 L .65211 .41839 L F
0 0 0 r
.16161 .56576 m .15965 .5664 L .1606 .5657 L F
.513 .017 0 r
.49679 .57077 m .49794 .57197 L .49845 .56881 L F
.49679 .57077 m .49924 .5733 L .49794 .57197 L F
.348 0 .068 r
.5416 .53977 m .54386 .5395 L .54563 .53766 L F
.993 .829 .576 r
.76497 .41911 m .76637 .4182 L .76529 .41697 L F
.084 0 .207 r
.20967 .63277 m .20883 .635 L .2111 .63186 L F
.942 .891 .751 r
.63165 .44378 m .63446 .4414 L .63337 .44034 L F
.63165 .44378 m .63272 .44488 L .63446 .4414 L F
.085 0 .064 r
.54893 .60499 m .54979 .60283 L .55178 .6018 L F
.445 .805 .996 r
.18924 .70052 m .19167 .70094 L .19106 .69997 L F
.412 .194 .47 r
.19029 .70368 m .19167 .70094 L .18924 .70052 L F
.19029 .70368 m .19232 .70323 L .19167 .70094 L F
.617 .312 .431 r
.19167 .70094 m .19232 .70323 L .19297 .70097 L F
0 .126 .671 r
.75686 .40902 m .75919 .41244 L .75862 .41109 L F
.915 .938 .806 r
.75862 .41109 m .75919 .41244 L .75685 .41311 L F
.81 .767 .813 r
.71921 .44689 m .72325 .44541 L .72172 .444 L F
.813 .781 .823 r
.72325 .44541 m .72424 .44101 L .72172 .444 L F
.72325 .44541 m .72585 .44252 L .72424 .44101 L F
.556 .894 .983 r
.70539 .39277 m .70158 .393 L .70411 .39218 L F
.51 .886 .97 r
.7079 .39195 m .70539 .39277 L .70411 .39218 L F
.831 .823 .841 r
.72585 .44252 m .72744 .4414 L .72695 .43819 L F
.745 .768 .872 r
.72695 .43819 m .72744 .4414 L .73044 .43863 L F
.72 .382 .406 r
.42971 .65242 m .42769 .65018 L .42981 .65064 L F
.678 .338 .391 r
.43376 .65196 m .42971 .65242 L .42981 .65064 L F
.421 .866 .821 r
.1747 .54512 m .17531 .54451 L .17687 .54461 L F
.1747 .54512 m .17327 .54541 L .17531 .54451 L F
.421 .25 .542 r
.25391 .61396 m .25179 .61734 L .25209 .6147 L F
.654 .85 .975 r
.74504 .43694 m .74582 .43819 L .74884 .437 L F
.779 .516 .538 r
.45043 .64442 m .45027 .64687 L .45218 .6466 L F
.45043 .64442 m .45276 .64392 L .45294 .64589 L F
.45043 .64442 m .45027 .64687 L .45218 .6466 L F
.593 .42 .616 r
.54925 .57269 m .55246 .57256 L .55226 .56935 L F
.601 .546 .765 r
.55287 .57609 m .55246 .57256 L .54925 .57269 L F
.56 .845 .997 r
.76051 .39573 m .75914 .39745 L .75981 .39639 L F
.277 .432 .837 r
.76051 .39573 m .76205 .399 L .75914 .39745 L F
.853 .76 .76 r
.21395 .55811 m .21722 .55764 L .21583 .55665 L F
.21395 .55811 m .21549 .56056 L .21722 .55764 L F
.146 0 .238 r
.55618 .56583 m .55898 .56335 L .55974 .56541 L F
.55618 .56583 m .55742 .5644 L .55898 .56335 L F
.79 .667 .727 r
.55974 .56541 m .55481 .56766 L .55618 .56583 L F
0 .245 .725 r
.55481 .56766 m .55415 .56691 L .55618 .56583 L F
.355 .566 .917 r
.62428 .41824 m .62669 .41879 L .62529 .41641 L F
.62428 .41824 m .62669 .41879 L .62529 .41641 L F
.622 .52 .717 r
.62741 .42159 m .62428 .41824 L .62669 .41879 L F
.39 .156 .435 r
.26928 .58937 m .26751 .58773 L .26957 .58723 L F
.26928 .58937 m .26729 .59008 L .26751 .58773 L F
.742 .653 .762 r
.63165 .42223 m .62741 .42159 L .6308 .42144 L F
.71 .489 .587 r
.50984 .59112 m .51005 .59204 L .51326 .59093 L F
.737 .593 .695 r
.53469 .57117 m .53907 .57123 L .53588 .56737 L F
.346 0 0 r
.53469 .57117 m .53581 .57158 L .53907 .57123 L F
.141 .666 .878 r
.53581 .57158 m .54012 .57213 L .53907 .57123 L F
.838 .999 .821 r
.7629 .43468 m .76621 .43221 L .76538 .43159 L F
0 0 0 r
.1562 .55287 m .15998 .55133 L .15759 .5522 L F
.526 .89 .974 r
.6322 .42732 m .63499 .42718 L .6339 .42597 L F
.077 .407 .86 r
.63499 .42718 m .63401 .42471 L .6339 .42597 L F
.63499 .42718 m .63793 .42872 L .63401 .42471 L F
.45 .377 .683 r
.63499 .42718 m .63601 .4299 L .63793 .42872 L F
.626 .792 .962 r
.71889 .3999 m .72248 .40051 L .72141 .39905 L F
.624 .791 .962 r
.72141 .39905 m .72248 .40051 L .72503 .39966 L F
.807 .982 .894 r
.5623 .49226 m .55997 .4953 L .56284 .49265 L F
.803 .99 .738 r
.56367 .49059 m .56284 .49265 L .56533 .48973 L F
.801 .999 .81 r
.56367 .49059 m .5623 .49226 L .56284 .49265 L F
.247 .735 .922 r
.23843 .84041 m .2423 .8407 L .24069 .84027 L F
.23843 .84041 m .2423 .8407 L .24069 .84027 L F
.675 .798 .941 r
.19812 .65589 m .202 .65628 L .20033 .65587 L F
.539 .895 .976 r
.20433 .6555 m .20256 .65511 L .202 .65628 L F
.529 .886 .98 r
.202 .65628 m .20256 .65511 L .20033 .65587 L F
.323 0 0 r
.69214 .40387 m .69348 .40491 L .69104 .40486 L F
.69214 .40387 m .69481 .40365 L .69348 .40491 L F
.847 .498 .392 r
.60376 .46876 m .60094 .46822 L .6003 .46582 L F
.897 .782 .726 r
.60376 .46876 m .60043 .47064 L .60094 .46822 L F
.60376 .46876 m .60225 .47147 L .60043 .47064 L F
.469 .161 .36 r
.58284 .45585 m .58518 .45563 L .58542 .45396 L F
.416 .117 .347 r
.58542 .45396 m .58755 .45495 L .5878 .45334 L F
.58542 .45396 m .58518 .45563 L .58755 .45495 L F
.705 .497 .604 r
.50038 .57619 m .50085 .57982 L .49721 .57867 L F
.474 .549 .853 r
.50239 .57451 m .50038 .57619 L .49924 .5733 L F
.414 .442 .78 r
.50239 .57451 m .50394 .57881 L .50038 .57619 L F
.322 0 .251 r
.37859 .60135 m .38114 .59911 L .37877 .59964 L F
.542 .851 .998 r
.4499 .5589 m .44688 .55889 L .44914 .55813 L F
.452 .731 .987 r
.4513 .55765 m .4499 .5589 L .44914 .55813 L F
.4513 .55765 m .4526 .55876 L .4499 .5589 L F
.69 .541 .678 r
.57656 .54069 m .57697 .54313 L .57314 .54336 L F
.644 .535 .716 r
.57927 .54022 m .57697 .54313 L .57656 .54069 L F
.998 .794 .497 r
.60839 .43508 m .61179 .43321 L .61088 .4346 L F
.16 0 0 r
.61416 .43237 m .61088 .4346 L .61179 .43321 L F
.111 0 .386 r
.58478 .53691 m .58498 .53443 L .58633 .53335 L F
.688 .441 .544 r
.57314 .54336 m .57087 .54564 L .57089 .54325 L F
.352 0 .184 r
.4447 .59042 m .44122 .59322 L .44097 .59116 L F
0 0 .022 r
.60157 .45139 m .60037 .45126 L .60286 .45038 L F
.60157 .45139 m .59948 .45331 L .60037 .45126 L F
.684 .801 .937 r
.55511 .59247 m .55584 .59315 L .55449 .59349 L F
.55625 .59061 m .55584 .59315 L .55511 .59247 L F
.267 .731 .949 r
.55639 .59368 m .55584 .59315 L .55697 .59377 L F
.55326 .5932 m .55584 .59315 L .55639 .59368 L F
.752 .983 .908 r
.55786 .59155 m .55697 .59377 L .55584 .59315 L F
.55786 .59155 m .55931 .59144 L .55697 .59377 L F
.677 .502 .641 r
.55697 .59377 m .55871 .59385 L .5571 .59653 L F
.55697 .59377 m .55836 .59447 L .55871 .59385 L F
.55836 .59447 m .56015 .59537 L .55871 .59385 L F
.488 .288 .534 r
.55871 .59385 m .55711 .59667 L .5571 .59653 L F
.573 .562 .803 r
.55836 .59447 m .55897 .59439 L .56015 .59537 L F
.566 .438 .666 r
.56218 .59265 m .55871 .59385 L .56015 .59537 L F
.538 .291 .489 r
.56023 .59434 m .5588 .59437 L .55871 .59385 L F
.607 .524 .735 r
.56073 .59349 m .56218 .59265 L .56015 .59537 L F
.566 .438 .666 r
.56098 .59306 m .55961 .59414 L .55871 .59385 L F
.56218 .59265 m .56073 .59349 L .56098 .59306 L F
.56073 .59349 m .55961 .59414 L .56098 .59306 L F
.607 .524 .735 r
.56175 .59019 m .56073 .59349 L .55931 .59144 L F
.56073 .59349 m .56052 .59416 L .56044 .59398 L F
.566 .438 .666 r
.56218 .59265 m .5617 .59481 L .56023 .59434 L F
.56073 .59349 m .56023 .59434 L .55961 .59414 L F
.607 .524 .735 r
.56052 .59416 m .56023 .59434 L .56044 .59398 L F
.566 .438 .666 r
.56218 .59265 m .56023 .59434 L .56073 .59349 L F
.607 .524 .735 r
.56044 .59398 m .55997 .5945 L .55931 .59144 L F
.56023 .59434 m .55997 .5945 L .56044 .59398 L F
.56073 .59349 m .56044 .59398 L .55931 .59144 L F
.56175 .59019 m .56218 .59265 L .56073 .59349 L F
.538 .291 .489 r
.5611 .59461 m .55997 .5945 L .56023 .59434 L F
.55997 .5945 m .5588 .59437 L .56023 .59434 L F
.607 .524 .735 r
.56052 .59416 m .56015 .59537 L .55997 .5945 L F
.573 .562 .803 r
.55897 .59439 m .55992 .59427 L .55997 .5945 L F
.55897 .59439 m .55997 .5945 L .56015 .59537 L F
.538 .291 .489 r
.5617 .59481 m .55955 .59847 L .5588 .59437 L F
.5617 .59481 m .5588 .59437 L .5611 .59461 L F
.488 .288 .534 r
.55856 .59444 m .55955 .59847 L .55733 .59916 L F
.55871 .59385 m .5588 .59437 L .55856 .59444 L F
.5588 .59437 m .55955 .59847 L .55856 .59444 L F
.573 .562 .803 r
.55697 .59377 m .55931 .59144 L .55988 .59407 L F
.55945 .59419 m .55988 .59407 L .55992 .59427 L F
.55697 .59377 m .55988 .59407 L .55945 .59419 L F
.488 .288 .534 r
.55871 .59385 m .55856 .59444 L .55836 .59447 L F
.573 .562 .803 r
.55697 .59377 m .55992 .59427 L .55836 .59447 L F
.488 .288 .534 r
.55836 .59447 m .55733 .59916 L .55711 .59667 L F
.55856 .59444 m .55733 .59916 L .55836 .59447 L F
.745 .929 .95 r
.1983 .63812 m .19383 .63919 L .19648 .63744 L F
.13 0 0 r
.19855 .63824 m .1983 .63812 L .19648 .63744 L F
.19855 .63824 m .20039 .63843 L .1983 .63812 L F
0 0 .02 r
.46049 .56336 m .46173 .5624 L .46383 .56288 L F
.545 .843 .999 r
.46693 .56263 m .46383 .56288 L .46173 .5624 L F
.887 .886 .825 r
.64396 .40129 m .64201 .40285 L .6409 .40163 L F
.214 0 0 r
.64741 .40199 m .64694 .40201 L .64887 .40229 L F
.64396 .40129 m .64694 .40201 L .64741 .40199 L F
0 .408 .81 r
.64387 .40027 m .64694 .40201 L .64396 .40129 L F
.345 0 0 r
.64624 .40204 m .64694 .40201 L .64538 .40089 L F
.64639 .40224 m .64694 .40201 L .64624 .40204 L F
.588 .829 .99 r
.71148 .39229 m .7079 .39195 L .71039 .39108 L F
.634 .848 .982 r
.71288 .39022 m .71148 .39229 L .71039 .39108 L F
.71288 .39022 m .71393 .39134 L .71148 .39229 L F
.3 .756 .954 r
.20994 .53999 m .21209 .53981 L .21383 .54038 L F
.322 .758 .968 r
.21209 .53981 m .2161 .54031 L .21383 .54038 L F
.706 .424 .495 r
.45307 .57817 m .4568 .57608 L .45446 .57576 L F
.45307 .57817 m .45673 .5785 L .4568 .57608 L F
.769 .73 .817 r
.68563 .4434 m .68194 .44245 L .68415 .44123 L F
.658 .733 .905 r
.68782 .44241 m .68563 .4434 L .68415 .44123 L F
.241 .496 .898 r
.20139 .68125 m .20292 .68251 L .20199 .67983 L F
.508 .199 .377 r
.39232 .59342 m .39476 .59312 L .39516 .59123 L F
.475 .199 .415 r
.39476 .59312 m .39756 .59054 L .39516 .59123 L F
.807 .982 .894 r
.5623 .49226 m .55935 .49473 L .55997 .4953 L F
.703 .271 .221 r
.42363 .65046 m .42217 .65213 L .4199 .64998 L F
.652 .207 .183 r
.42363 .65046 m .42592 .65231 L .42217 .65213 L F
.612 .246 .323 r
.42769 .65018 m .42592 .65231 L .42363 .65046 L F
.18 .66 .929 r
.54734 .59291 m .5512 .5936 L .55087 .59381 L F
.742 .764 .87 r
.5512 .5936 m .55326 .5932 L .55087 .59381 L F
.498 .545 .835 r
.75262 .39845 m .7547 .39577 L .75198 .39654 L F
.75262 .39845 m .75595 .39888 L .7547 .39577 L F
0 .414 .852 r
.75262 .39845 m .75618 .40079 L .75595 .39888 L F
.401 .091 .32 r
.39756 .59054 m .3999 .58998 L .40055 .58729 L F
.078 0 0 r
.40354 .58543 m .40055 .58729 L .40274 .58641 L F
.352 .048 .303 r
.40055 .58729 m .40207 .58928 L .40274 .58641 L F
.40055 .58729 m .3999 .58998 L .40207 .58928 L F
.669 .801 .945 r
.7164 .40091 m .71788 .39835 L .71537 .39901 L F
.7164 .40091 m .71889 .3999 L .71788 .39835 L F
0 0 0 r
.63234 .40418 m .63599 .40306 L .63345 .40349 L F
.72 .382 .406 r
.42971 .65242 m .42592 .65231 L .42769 .65018 L F
.671 .972 .805 r
.56836 .48748 m .56654 .48808 L .56533 .48973 L F
.503 .902 .776 r
.56857 .48677 m .56836 .48748 L .56998 .48587 L F
.56857 .48677 m .56654 .48808 L .56836 .48748 L F
.688 .441 .544 r
.57314 .54336 m .57354 .54573 L .57087 .54564 L F
.665 .412 .528 r
.57314 .54336 m .57675 .54546 L .57354 .54573 L F
.57314 .54336 m .57697 .54313 L .57675 .54546 L F
.779 .432 .4 r
.6253 .42433 m .62194 .42539 L .6217 .42407 L F
.6253 .42433 m .62648 .42605 L .62194 .42539 L F
.662 .955 .73 r
.56654 .48808 m .56367 .49059 L .56533 .48973 L F
.543 .343 .558 r
.566 .54918 m .56594 .55162 L .56345 .55204 L F
.54 .33 .545 r
.56345 .55204 m .56594 .55404 L .56339 .55441 L F
.56345 .55204 m .56594 .55162 L .56594 .55404 L F
.747 .737 .843 r
.42523 .60068 m .42121 .60062 L .42407 .59866 L F
.345 .521 .887 r
.42407 .59866 m .42661 .60009 L .42523 .60068 L F
.322 .451 .836 r
.42661 .60009 m .42523 .60068 L .42407 .59866 L F
.58 .411 .617 r
.56832 .54616 m .56848 .54876 L .566 .54918 L F
.546 .335 .544 r
.56848 .54876 m .56594 .55162 L .566 .54918 L F
.286 0 .113 r
.40274 .58641 m .40566 .5845 L .40354 .58543 L F
.631 .618 .818 r
.41219 .61163 m .40839 .60874 L .41027 .60806 L F
.378 .112 .379 r
.21495 .61715 m .2169 .61692 L .21687 .61497 L F
.225 .495 .9 r
.3925 .63628 m .3934 .63508 L .39155 .63496 L F
.3925 .63628 m .39545 .63773 L .3934 .63508 L F
.224 .025 .386 r
.58487 .51255 m .58314 .5136 L .58282 .51583 L F
.091 .639 .829 r
.23803 .54086 m .24007 .54083 L .24165 .54115 L F
.174 .607 .94 r
.24251 .54044 m .24165 .54115 L .24007 .54083 L F
.24251 .54044 m .24403 .54149 L .24165 .54115 L F
.305 .574 .935 r
.73515 .39763 m .73462 .39659 L .73431 .39678 L F
.812 .455 .382 r
.73364 .39908 m .73515 .39763 L .73431 .39678 L F
.73364 .39908 m .7375 .40047 L .73515 .39763 L F
.543 .836 .506 r
.54418 .56406 m .5455 .56257 L .54682 .56121 L F
0 0 0 r
.5437 .56545 m .54418 .56406 L .54447 .56645 L F
.5437 .56545 m .5455 .56257 L .54418 .56406 L F
.669 .12 0 r
.40286 .64343 m .39906 .64067 L .39997 .64217 L F
.91 .69 .188 r
.65843 .41618 m .65913 .41823 L .65917 .42086 L F
.555 .024 0 r
.42419 .64496 m .42859 .64464 L .42479 .64445 L F
.42419 .64496 m .427 .64568 L .42859 .64464 L F
.588 .063 0 r
.427 .64568 m .4307 .64611 L .42859 .64464 L F
.541 .157 .263 r
.42859 .64464 m .4307 .64611 L .43251 .64385 L F
0 .054 .62 r
.65542 .40887 m .65685 .41234 L .6566 .41075 L F
.028 .313 .801 r
.55226 .56935 m .55294 .56818 L .55042 .5665 L F
0 .132 .673 r
.55429 .57182 m .55294 .56818 L .55226 .56935 L F
.431 .297 .597 r
.55246 .57256 m .55429 .57182 L .55226 .56935 L F
.616 .287 .389 r
.4307 .64611 m .43467 .6437 L .43251 .64385 L F
.685 .689 .848 r
.69257 .45037 m .69637 .45124 L .69542 .44854 L F
.614 .627 .841 r
.69637 .45124 m .6976 .44717 L .69542 .44854 L F
.69637 .45124 m .69885 .45048 L .6976 .44717 L F
.446 .272 .55 r
.22321 .61163 m .225 .61372 L .22564 .6113 L F
.22321 .61163 m .22304 .6144 L .225 .61372 L F
.591 .856 .994 r
.60992 .43877 m .61101 .43657 L .61234 .43795 L F
0 0 0 r
.61234 .43795 m .60983 .44151 L .60992 .43877 L F
.437 .189 .439 r
.58019 .51869 m .58282 .51583 L .58045 .51651 L F
.357 0 .027 r
.5455 .56257 m .54919 .56053 L .54682 .56121 L F
.996 .758 .427 r
.66287 .42954 m .66297 .42688 L .66183 .42826 L F
.756 .993 .802 r
.66297 .42688 m .6657 .42438 L .66412 .42495 L F
.664 .866 .481 r
.66183 .42826 m .66297 .42688 L .66412 .42495 L F
.253 0 0 r
.77523 .43005 m .7721 .43155 L .7717 .42989 L F
.77523 .43005 m .77474 .43127 L .7721 .43155 L F
.094 0 0 r
.77523 .43005 m .77591 .43036 L .77474 .43127 L F
0 0 .29 r
.77596 .43037 m .77494 .43401 L .77474 .43127 L F
.094 0 0 r
.77523 .43005 m .77842 .43008 L .77609 .43034 L F
.77573 .43028 m .77609 .43034 L .77591 .43036 L F
.77523 .43005 m .77609 .43034 L .77573 .43028 L F
0 0 .29 r
.77648 .43041 m .77658 .4324 L .77494 .43401 L F
.891 .958 .835 r
.77591 .43036 m .77842 .43008 L .78027 .42763 L F
0 0 .29 r
.77676 .42977 m .77671 .43045 L .77648 .43041 L F
.77671 .43045 m .77658 .4324 L .77648 .43041 L F
.77676 .42977 m .77648 .43041 L .77596 .43037 L F
.77648 .43041 m .77494 .43401 L .77596 .43037 L F
.094 0 0 r
.7759 .43036 m .77591 .43036 L .77591 .43036 L F
.77523 .43005 m .77591 .43036 L .7759 .43036 L F
.685 .776 .92 r
.73679 .43683 m .74041 .43725 L .73892 .43546 L F
.591 .519 .743 r
.74041 .43725 m .74226 .43401 L .73892 .43546 L F
.74041 .43725 m .74214 .43687 L .74226 .43401 L F
0 0 0 r
.20883 .635 m .20685 .63586 L .20461 .6371 L F
.518 .853 .575 r
.19322 .71573 m .19342 .71553 L .19294 .71596 L F
0 0 0 r
.57016 .46905 m .56749 .47175 L .56931 .4705 L F
.181 0 .093 r
.56931 .4705 m .5723 .46811 L .57016 .46905 L F
.428 .191 .45 r
.5725 .46596 m .5723 .46811 L .57483 .46526 L F
.205 .378 .814 r
.65332 .40699 m .656 .40689 L .6557 .4043 L F
.65332 .40699 m .65542 .40887 L .656 .40689 L F
.98 .897 .556 r
.62356 .46437 m .62438 .46485 L .62485 .46306 L F
.955 .935 .731 r
.62485 .46306 m .62575 .4588 L .62372 .46183 L F
.994 .768 .48 r
.62356 .46437 m .62485 .46306 L .62372 .46183 L F
.545 .843 .999 r
.46693 .56263 m .46173 .5624 L .46484 .56133 L F
.533 .795 .993 r
.46719 .56066 m .46693 .56263 L .46484 .56133 L F
.46719 .56066 m .46929 .56261 L .46693 .56263 L F
.386 .591 .925 r
.50888 .55825 m .51093 .55835 L .50998 .55652 L F
.63 .435 .599 r
.55367 .54002 m .5574 .53967 L .55693 .53737 L F
.524 .338 .57 r
.55693 .53737 m .55974 .53705 L .5597 .53405 L F
.656 .549 .722 r
.5574 .53967 m .55974 .53705 L .55693 .53737 L F
.429 .482 .813 r
.37812 .62768 m .37912 .62494 L .37694 .62565 L F
.37812 .62768 m .38083 .62817 L .37912 .62494 L F
.362 .641 .961 r
.19931 .67933 m .20139 .68125 L .20199 .67983 L F
.521 .22 .397 r
.41496 .64104 m .41719 .64092 L .41758 .63874 L F
.551 .246 .405 r
.41758 .63874 m .42007 .64042 L .42135 .63799 L F
.41758 .63874 m .41719 .64092 L .42007 .64042 L F
.469 .287 .551 r
.23516 .59921 m .23738 .59611 L .2354 .59674 L F
0 0 0 r
.46736 .59758 m .46575 .59973 L .46681 .59846 L F
.272 .427 .834 r
.46575 .59973 m .46808 .60129 L .46681 .59846 L F
.445 .046 .186 r
.42637 .57913 m .4288 .57989 L .42871 .57807 L F
.475 .355 .636 r
.42871 .57807 m .43063 .57526 L .42869 .5756 L F
.42871 .57807 m .43097 .57814 L .43063 .57526 L F
.218 .675 .948 r
.43097 .57814 m .4329 .57889 L .42871 .57807 L F
.706 .421 .489 r
.4288 .57989 m .43097 .57814 L .42871 .57807 L F
.413 .023 .187 r
.42871 .57807 m .4288 .57989 L .43097 .57814 L F
0 0 .075 r
.21187 .62964 m .2111 .63186 L .21294 .62858 L F
.989 .771 .518 r
.54105 .52456 m .54123 .52229 L .53995 .52115 L F
.745 .681 .789 r
.70857 .43612 m .70585 .43892 L .70477 .43543 L F
.177 0 0 r
.43821 .56154 m .43685 .56256 L .43964 .56206 L F
.022 .535 .866 r
.50191 .53924 m .50418 .53975 L .50508 .54042 L F
.842 .976 .876 r
.50508 .54042 m .50567 .53837 L .50742 .53968 L F
.50508 .54042 m .50418 .53975 L .50567 .53837 L F
.822 .923 .536 r
.60394 .44622 m .60345 .44823 L .6051 .44495 L F
.934 .942 .775 r
.60394 .44622 m .60286 .45038 L .60345 .44823 L F
.327 .806 .75 r
.69799 .40274 m .70056 .40177 L .69964 .40199 L F
0 0 0 r
.69716 .4039 m .69799 .40274 L .69964 .40199 L F
.656 .788 .945 r
.72869 .4026 m .73217 .40314 L .73115 .40163 L F
.811 .836 .87 r
.73217 .40314 m .73364 .39908 L .73115 .40163 L F
.73217 .40314 m .73511 .40047 L .73364 .39908 L F
.241 .747 .887 r
.17959 .5434 m .18156 .54316 L .18343 .54336 L F
.134 0 0 r
.18156 .54316 m .18558 .54276 L .18343 .54336 L F
.967 .804 .629 r
.67718 .45018 m .67811 .45383 L .67662 .45259 L F
.87 .584 .501 r
.67811 .45383 m .67547 .45514 L .67662 .45259 L F
0 0 .318 r
.75618 .40079 m .75678 .40185 L .75595 .39888 L F
.75618 .40079 m .7565 .40295 L .75678 .40185 L F
.675 .804 .944 r
.72854 .38981 m .72965 .39132 L .72611 .39087 L F
.689 .81 .939 r
.73207 .39009 m .72965 .39132 L .72854 .38981 L F
.384 .776 .988 r
.50742 .53968 m .50982 .53931 L .51113 .54027 L F
.175 .332 .783 r
.50969 .53677 m .51113 .54027 L .51217 .53855 L F
.607 .889 .99 r
.51113 .54027 m .50982 .53931 L .51217 .53855 L F
.382 .107 .367 r
.51356 .5404 m .51106 .54282 L .51113 .54027 L F
.406 .564 .898 r
.54784 .56902 m .54447 .56645 L .54443 .56703 L F
.774 .699 .78 r
.53265 .56613 m .53588 .56737 L .5368 .56556 L F
.955 .852 .701 r
.53382 .56984 m .53588 .56737 L .53265 .56613 L F
.53382 .56984 m .53469 .57117 L .53588 .56737 L F
.632 .521 .71 r
.5368 .56556 m .53588 .56737 L .53816 .56625 L F
.139 0 0 r
.695 .39552 m .69327 .39518 L .69236 .39609 L F
.695 .39552 m .6959 .39465 L .69327 .39518 L F
.831 .823 .841 r
.72585 .44252 m .72695 .43819 L .72424 .44101 L F
.771 .818 .889 r
.7134 .44886 m .71462 .45034 L .71737 .44803 L F
.273 .214 .606 r
.40724 .63276 m .40603 .6316 L .40689 .63201 L F
0 0 .126 r
.6584 .42309 m .65817 .42696 L .65752 .42477 L F
.954 .91 .54 r
.65817 .42696 m .6567 .42892 L .65752 .42477 L F
.65817 .42696 m .65716 .42966 L .6567 .42892 L F
.565 .416 .638 r
.19297 .70097 m .19564 .70062 L .1952 .69768 L F
.556 .281 .454 r
.19232 .70323 m .19564 .70062 L .19297 .70097 L F
.135 .613 .92 r
.26795 .55017 m .27113 .55115 L .26877 .55155 L F
.469 .205 .431 r
.46733 .60882 m .46697 .61099 L .4646 .6115 L F
.56 .628 .876 r
.46815 .60591 m .46977 .60839 L .46733 .60882 L F
.346 .101 .392 r
.46899 .6101 m .46733 .60882 L .46977 .60839 L F
.46899 .6101 m .46697 .61099 L .46733 .60882 L F
.643 .551 .736 r
.20247 .69369 m .20079 .69754 L .20044 .69508 L F
.61 .587 .803 r
.5443 .55139 m .54175 .55226 L .53955 .54823 L F
.508 0 0 r
.47608 .56236 m .47854 .56337 L .47673 .56325 L F
.598 .645 .867 r
.21141 .55864 m .21549 .56056 L .21395 .55811 L F
.181 0 .205 r
.21549 .56056 m .21231 .56416 L .21435 .56291 L F
.715 .377 .403 r
.21435 .56291 m .21738 .56313 L .21549 .56056 L F
.825 .922 .9 r
.69609 .43853 m .6928 .44159 L .69224 .44024 L F
.519 .343 .582 r
.57087 .54564 m .56848 .54876 L .56832 .54616 L F
.47 .893 .885 r
.38344 .59856 m .38554 .59759 L .38406 .59682 L F
.303 0 0 r
.38406 .59682 m .38554 .59759 L .38651 .59646 L F
.35 .554 .91 r
.38852 .62938 m .38985 .62812 L .38634 .62661 L F
.187 .281 .729 r
.38852 .62938 m .39062 .63137 L .38985 .62812 L F
.006 .421 .859 r
.50596 .53294 m .50667 .53239 L .50522 .53187 L F
.8 .522 .517 r
.50685 .53317 m .50319 .53152 L .50667 .53239 L F
.50726 .53501 m .50433 .5325 L .50685 .53317 L F
.50433 .5325 m .50319 .53152 L .50685 .53317 L F
0 .41 .686 r
.51019 .53408 m .50978 .53396 L .50596 .53294 L F
.50978 .53396 m .50962 .53391 L .50851 .53362 L F
.50978 .53396 m .50851 .53362 L .50596 .53294 L F
.006 .421 .859 r
.50596 .53294 m .50962 .53391 L .50667 .53239 L F
.737 .922 .954 r
.50957 .53448 m .50969 .53677 L .50872 .53472 L F
.50962 .53393 m .50963 .53446 L .50954 .53398 L F
.50963 .53446 m .50969 .53677 L .50957 .53448 L F
.50963 .53446 m .50957 .53448 L .50954 .53398 L F
.845 .769 .262 r
.51019 .53408 m .50969 .53677 L .50963 .53446 L F
.50988 .534 m .50963 .53446 L .50962 .53393 L F
.51019 .53408 m .50963 .53446 L .50988 .534 L F
.566 .425 .649 r
.50667 .53239 m .50922 .53413 L .50726 .53501 L F
.50667 .53239 m .50927 .53416 L .50726 .53501 L F
.669 .739 .903 r
.50962 .53391 m .50954 .53398 L .50726 .53501 L F
.50954 .53398 m .50613 .53705 L .50726 .53501 L F
.737 .922 .954 r
.50954 .53398 m .50957 .53448 L .50872 .53472 L F
.566 .425 .649 r
.50922 .53413 m .50996 .53464 L .50726 .53501 L F
.183 0 0 r
.50926 .53507 m .50932 .53504 L .50816 .53489 L F
.50932 .53504 m .50996 .53464 L .5095 .5347 L F
.50932 .53504 m .5095 .5347 L .50816 .53489 L F
.50769 .53502 m .50816 .53489 L .50726 .53501 L F
.50926 .53507 m .50816 .53489 L .50769 .53502 L F
.50926 .53507 m .50996 .53464 L .50816 .53489 L F
.50769 .53502 m .50816 .53489 L .50726 .53501 L F
.50926 .53507 m .50816 .53489 L .50769 .53502 L F
.737 .922 .954 r
.50872 .53472 m .50969 .53677 L .50613 .53705 L F
.50962 .53391 m .50962 .53393 L .50954 .53398 L F
.566 .425 .649 r
.50927 .53416 m .50955 .53436 L .50851 .53465 L F
.50927 .53416 m .50851 .53465 L .50726 .53501 L F
.50955 .53436 m .50996 .53464 L .5095 .5347 L F
.50955 .53436 m .5095 .5347 L .50726 .53501 L F
.845 .769 .262 r
.50962 .53392 m .50962 .53393 L .50962 .53391 L F
.51019 .53408 m .50962 .53393 L .50962 .53392 L F
.742 .548 .631 r
.42923 .60543 m .42716 .60815 L .42727 .60582 L F
.736 .539 .627 r
.42923 .60543 m .42901 .60842 L .42716 .60815 L F
.783 .713 .785 r
.43148 .60241 m .42923 .60543 L .42774 .60198 L F
.609 .462 .657 r
.43148 .60241 m .43212 .60507 L .42923 .60543 L F
.631 .448 .616 r
.43205 .60784 m .42923 .60543 L .43212 .60507 L F
.43205 .60784 m .42901 .60842 L .42923 .60543 L F
.953 .851 .704 r
.63017 .44579 m .63272 .44488 L .63165 .44378 L F
.63017 .44579 m .63156 .44838 L .63272 .44488 L F
0 0 0 r
.23011 .60516 m .23293 .60248 L .23046 .60266 L F
.196 0 0 r
.46929 .56261 m .47131 .56266 L .47228 .56169 L F
.316 0 0 r
.47228 .56169 m .47559 .56198 L .47608 .56236 L F
.47228 .56169 m .47131 .56266 L .47559 .56198 L F
.635 .769 .944 r
.72252 .39013 m .72611 .39087 L .72361 .39174 L F
.842 .882 .87 r
.53596 .53547 m .53594 .537 L .53796 .53652 L F
.881 .87 .822 r
.53596 .53547 m .53796 .53652 L .53975 .53378 L F
.77 .614 .686 r
.59894 .46177 m .6003 .46582 L .59667 .46532 L F
.668 .39 .491 r
.6003 .46582 m .59672 .46812 L .59667 .46532 L F
.6003 .46582 m .60094 .46822 L .59672 .46812 L F
.7 .577 .714 r
.60277 .46275 m .6003 .46582 L .59894 .46177 L F
.751 .648 .747 r
.5368 .56556 m .53911 .56449 L .53931 .56351 L F
.632 .521 .71 r
.5368 .56556 m .53816 .56625 L .53911 .56449 L F
.153 .607 .931 r
.49247 .56819 m .49444 .56843 L .49584 .5695 L F
.513 .824 1 r
.49584 .5695 m .49444 .56843 L .49845 .56881 L F
.984 .708 .343 r
.61692 .48087 m .61794 .48172 L .6176 .48125 L F
.974 .897 .682 r
.61618 .48549 m .61794 .48172 L .61692 .48087 L F
.884 .714 .666 r
.43353 .56666 m .43201 .56742 L .43279 .5642 L F
.546 .083 .106 r
.43605 .56687 m .43217 .56819 L .43353 .56666 L F
.399 .805 .981 r
.21819 .53967 m .22204 .53992 L .21988 .54027 L F
.294 0 .238 r
.58654 .53112 m .58939 .52858 L .58878 .53044 L F
.324 .122 .444 r
.58939 .52858 m .59164 .5252 L .59146 .5276 L F
.265 0 .281 r
.58878 .53044 m .58939 .52858 L .59146 .5276 L F
.74 .493 .555 r
.45547 .64304 m .45916 .64408 L .45797 .64185 L F
.733 .805 .908 r
.71671 .43128 m .71317 .432 L .71575 .4295 L F
.62 .682 .887 r
.71804 .42859 m .71671 .43128 L .71575 .4295 L F
.71804 .42859 m .71961 .43029 L .71671 .43128 L F
.606 .72 .925 r
.60257 .45511 m .59956 .45811 L .60015 .45575 L F
.60257 .45511 m .60434 .4572 L .59956 .45811 L F
.739 .215 0 r
.39906 .64067 m .39545 .63773 L .39774 .64061 L F
.612 .814 .978 r
.56655 .58414 m .56485 .58515 L .56287 .58369 L F
.193 0 .273 r
.56415 .58716 m .56485 .58515 L .56655 .58414 L F
.564 .825 .995 r
.20659 .67029 m .2082 .67124 L .21051 .67067 L F
.311 .082 .397 r
.26305 .59652 m .2626 .599 L .26068 .5997 L F
.368 .216 .539 r
.2626 .599 m .26064 .60222 L .26068 .5997 L F
.62 .469 .656 r
.43385 .60408 m .43148 .60241 L .43496 .60243 L F
.557 .272 .438 r
.43745 .60212 m .43385 .60408 L .43496 .60243 L F
.766 .579 .644 r
.63038 .43304 m .63411 .43617 L .63473 .43573 L F
.63038 .43304 m .63047 .43617 L .63411 .43617 L F
.174 0 0 r
.63047 .43617 m .6339 .43642 L .63411 .43617 L F
.83 .532 0 r
.63368 .43592 m .6337 .43598 L .63411 .43617 L F
.6337 .43598 m .63391 .43641 L .63411 .43617 L F
.63368 .43592 m .63411 .43617 L .63417 .43644 L F
.704 .588 .723 r
.63038 .43304 m .63473 .43573 L .63283 .43015 L F
.221 .571 .94 r
.63357 .43469 m .63368 .43592 L .63417 .43644 L F
.63357 .43469 m .63417 .43644 L .63374 .43605 L F
.63309 .43468 m .63367 .43592 L .6322 .43467 L F
.63367 .43592 m .63368 .436 L .6322 .43467 L F
.957 .931 .727 r
.63357 .43469 m .63368 .43595 L .63368 .43592 L F
.221 .571 .94 r
.63357 .43469 m .63374 .43605 L .63309 .43468 L F
0 0 0 r
.63047 .43617 m .6322 .43467 L .63374 .43605 L F
.83 .532 0 r
.63374 .43605 m .6339 .43642 L .63391 .43641 L F
.63386 .43646 m .63462 .43872 L .63411 .43617 L F
.174 0 0 r
.6339 .43642 m .63417 .43644 L .63411 .43617 L F
0 0 0 r
.6339 .43642 m .63374 .43605 L .63417 .43644 L F
.63047 .43617 m .63374 .43605 L .6339 .43642 L F
.83 .532 0 r
.6337 .43598 m .63386 .43646 L .6339 .43642 L F
.6337 .43598 m .6339 .43642 L .63374 .43605 L F
.957 .931 .727 r
.63357 .43469 m .63268 .43935 L .63368 .43595 L F
.221 .571 .94 r
.63368 .43595 m .63374 .43605 L .63368 .436 L F
.6337 .43598 m .63374 .43605 L .63368 .43595 L F
.965 .824 .655 r
.6337 .43598 m .63268 .43935 L .63462 .43872 L F
.63368 .43592 m .63368 .43595 L .6337 .43598 L F
.63368 .43595 m .63268 .43935 L .6337 .43598 L F
.221 .571 .94 r
.63367 .43592 m .6337 .43598 L .63368 .43595 L F
.41 .138 .387 r
.63473 .43573 m .63411 .43617 L .63624 .43524 L F
.613 .442 .626 r
.59648 .46249 m .59667 .46532 L .59417 .46574 L F
.677 .49 .626 r
.59894 .46177 m .59667 .46532 L .59648 .46249 L F
.63 .393 .54 r
.54566 .54291 m .54613 .54532 L .54288 .54576 L F
.746 .432 .451 r
.54566 .54291 m .54963 .54481 L .54896 .54557 L F
.54566 .54291 m .54896 .54557 L .54785 .54457 L F
.54566 .54291 m .54785 .54457 L .54613 .54532 L F
.332 .014 .266 r
.61607 .41164 m .61829 .41099 L .61884 .40872 L F
.398 .066 .281 r
.61829 .41099 m .62137 .40812 L .61884 .40872 L F
.206 .729 .726 r
.63013 .41798 m .63006 .41794 L .62669 .41879 L F
.468 .846 .618 r
.63115 .41711 m .63013 .41798 L .63237 .41491 L F
.63115 .41711 m .63006 .41794 L .63013 .41798 L F
.597 .772 .963 r
.71755 .39212 m .71393 .39134 L .71642 .39034 L F
.646 .744 .921 r
.71893 .38947 m .71755 .39212 L .71642 .39034 L F
.71893 .38947 m .72004 .39119 L .71755 .39212 L F
.53 .256 .445 r
.57519 .52449 m .57772 .52401 L .57544 .52228 L F
.527 .257 .449 r
.57772 .52401 m .57802 .52189 L .57544 .52228 L F
.554 .45 .691 r
.56739 .52837 m .56993 .52781 L .56938 .52489 L F
.488 .25 .48 r
.56728 .53056 m .56993 .52781 L .56739 .52837 L F
0 0 0 r
.2209 .64951 m .21714 .65235 L .21926 .65038 L F
.644 .535 .716 r
.57927 .54022 m .57994 .54333 L .57697 .54313 L F
.527 .293 .504 r
.57675 .54546 m .57697 .54313 L .57929 .54477 L F
.603 .242 .331 r
.57697 .54313 m .57994 .54333 L .57929 .54477 L F
.647 .429 .574 r
.56219 .53388 m .56506 .53379 L .56494 .5311 L F
.469 .293 .56 r
.56494 .5311 m .56732 .53304 L .56728 .53056 L F
.56494 .5311 m .56506 .53379 L .56732 .53304 L F
0 0 0 r
.19501 .65817 m .19627 .65725 L .19812 .65589 L F
.179 0 .064 r
.56435 .47424 m .56675 .4734 L .56749 .47175 L F
.308 0 .261 r
.56675 .4734 m .56931 .4705 L .56749 .47175 L F
.816 .796 .833 r
.72587 .42762 m .72539 .42848 L .72175 .42914 L F
.821 .737 .772 r
.72175 .42914 m .72539 .42848 L .72336 .43095 L F
.664 .39 .495 r
.55147 .54262 m .55413 .54219 L .55367 .54002 L F
.604 .34 .49 r
.55752 .54208 m .55367 .54002 L .55413 .54219 L F
.55752 .54208 m .5574 .53967 L .55367 .54002 L F
.623 .83 .43 r
.55035 .54909 m .55138 .54741 L .5523 .54615 L F
.581 .861 .995 r
.54898 .5482 m .55035 .54909 L .55072 .55169 L F
.54898 .5482 m .55138 .54741 L .55035 .54909 L F
0 0 0 r
.66672 .42253 m .6657 .42438 L .66748 .42102 L F
.843 .999 .789 r
.66412 .42495 m .6657 .42438 L .66672 .42253 L F
.654 .742 .915 r
.73747 .38758 m .73577 .39112 L .73457 .3889 L F
.73747 .38758 m .73834 .39016 L .73577 .39112 L F
.64 .412 .556 r
.24076 .57866 m .24321 .58112 L .24317 .5785 L F
.24076 .57866 m .24075 .58138 L .24321 .58112 L F
.198 .586 .943 r
.76461 .40062 m .76203 .40094 L .76205 .399 L F
0 0 .336 r
.76438 .39956 m .76461 .40062 L .76434 .39983 L F
.76438 .39956 m .76434 .39983 L .76349 .39732 L F
0 0 .522 r
.76486 .39776 m .76438 .39956 L .76349 .39732 L F
.904 .743 .244 r
.76443 .39915 m .76438 .39956 L .76486 .39776 L F
.198 .586 .943 r
.76461 .40062 m .76488 .40166 L .76203 .40094 L F
.218 .337 .772 r
.76461 .40062 m .76205 .399 L .76349 .39732 L F
.904 .743 .244 r
.76387 .40102 m .76438 .39956 L .76443 .39915 L F
.925 .696 .207 r
.76437 .3997 m .76461 .40062 L .76438 .39956 L F
.398 .566 .903 r
.76203 .40094 m .76558 .40183 L .7657 .40346 L F
.925 .696 .207 r
.76418 .4025 m .76461 .40062 L .76437 .3997 L F
.198 .586 .943 r
.76461 .40062 m .76558 .40183 L .76488 .40166 L F
.482 .296 .551 r
.21389 .62655 m .21605 .62602 L .2162 .62337 L F
.369 .037 .266 r
.21389 .62655 m .21294 .62858 L .21605 .62602 L F
.013 0 0 r
.16294 .54947 m .15998 .55133 L .16189 .5505 L F
0 0 0 r
.16189 .5505 m .16511 .54897 L .16294 .54947 L F
.443 .207 .46 r
.61076 .41741 m .61334 .41452 L .61116 .41554 L F
.021 0 .2 r
.58677 .50943 m .58543 .51053 L .58487 .51255 L F
.56 .846 .997 r
.18332 .65862 m .18395 .65708 L .18174 .65787 L F
.18332 .65862 m .18578 .65788 L .18395 .65708 L F
.611 .843 .987 r
.18332 .65862 m .18645 .65817 L .18578 .65788 L F
.45 .708 .977 r
.64152 .43105 m .64276 .43254 L .64495 .43227 L F
.647 .702 .886 r
.70136 .44982 m .70248 .4525 L .70531 .45055 L F
.031 0 .072 r
.46776 .5862 m .46777 .587 L .46922 .58544 L F
.437 .204 .461 r
.2566 .60867 m .2562 .61108 L .25405 .61154 L F
.231 0 .317 r
.2562 .61108 m .25391 .61396 L .25405 .61154 L F
.431 .296 .596 r
.25837 .6053 m .25856 .60802 L .2566 .60867 L F
.3 .087 .413 r
.25794 .61027 m .2566 .60867 L .25856 .60802 L F
.25794 .61027 m .2562 .61108 L .2566 .60867 L F
.878 .882 .833 r
.50833 .52815 m .50408 .53074 L .50741 .5274 L F
.825 .918 .899 r
.5123 .52389 m .5089 .52712 L .50805 .52546 L F
.606 .509 .718 r
.50741 .5274 m .50887 .52711 L .50833 .52815 L F
.825 .918 .899 r
.5089 .52712 m .50856 .52744 L .50887 .52711 L F
.606 .509 .718 r
.5089 .52712 m .50924 .52703 L .50909 .52721 L F
.514 .334 .574 r
.50924 .52703 m .5089 .52712 L .5123 .52389 L F
.606 .509 .718 r
.50887 .52711 m .50924 .52703 L .5089 .52712 L F
.50887 .52711 m .50909 .52721 L .50833 .52815 L F
.514 .334 .574 r
.50924 .52703 m .50856 .52744 L .5089 .52712 L F
.606 .509 .718 r
.50887 .52711 m .50856 .52744 L .50924 .52703 L F
.50741 .5274 m .50856 .52744 L .50887 .52711 L F
.825 .918 .899 r
.50887 .52711 m .50856 .52744 L .50843 .52691 L F
.5089 .52712 m .50843 .52691 L .50805 .52546 L F
.381 .801 .974 r
.45901 .58005 m .45824 .58101 L .45673 .5785 L F
.45901 .58005 m .4599 .5806 L .45824 .58101 L F
.352 .151 .461 r
.4531 .59517 m .45126 .59305 L .45364 .59281 L F
.4531 .59517 m .45118 .59613 L .45126 .59305 L F
.89 .667 .595 r
.76497 .41911 m .76441 .4225 L .76903 .4232 L F
.914 .853 .769 r
.76402 .4249 m .76903 .4232 L .76441 .4225 L F
.76402 .4249 m .76535 .42603 L .76903 .4232 L F
.231 .341 .77 r
.68261 .40789 m .67983 .40599 L .6838 .40634 L F
0 .49 .72 r
.6838 .40634 m .68627 .40676 L .68527 .40654 L F
.6838 .40634 m .68527 .40654 L .68261 .40789 L F
.507 .338 .587 r
.44499 .64952 m .44478 .65281 L .44236 .65064 L F
.727 .526 .619 r
.44499 .64952 m .44193 .65202 L .44236 .65064 L F
.438 .161 .394 r
.19439 .70745 m .19641 .70664 L .19236 .70567 L F
.19439 .70745 m .19618 .70868 L .19641 .70664 L F
.19641 .70664 m .19618 .70868 L .19439 .70745 L F
0 0 0 r
.60048 .51031 m .60285 .50703 L .60181 .50865 L F
.59983 .51201 m .60048 .51031 L .60181 .50865 L F
.299 .637 .965 r
.24239 .55716 m .24258 .55574 L .24067 .55611 L F
.24239 .55716 m .24418 .55721 L .24258 .55574 L F
0 .188 .715 r
.50147 .54863 m .49956 .54479 L .50095 .54585 L F
.239 0 0 r
.43175 .58828 m .43046 .58981 L .4342 .58775 L F
0 0 0 r
.65248 .41062 m .65187 .41208 L .65338 .40697 L F
.65248 .41062 m .65338 .40697 L .65194 .40824 L F
.787 .628 .068 r
.65177 .40439 m .65194 .40824 L .65317 .40634 L F
.042 .177 .68 r
.65179 .40701 m .65331 .40865 L .65248 .41062 L F
.65331 .40865 m .65338 .40873 L .65248 .41062 L F
0 0 0 r
.65248 .41062 m .65161 .41294 L .65187 .41208 L F
0 0 .394 r
.65247 .41303 m .65161 .41294 L .65248 .41062 L F
.65247 .41303 m .65222 .41438 L .65161 .41294 L F
.403 .277 .594 r
.37661 .60563 m .37844 .60509 L .37859 .60135 L F
.417 .318 .635 r
.37661 .60563 m .37884 .60764 L .37844 .60509 L F
.422 .318 .631 r
.37693 .60814 m .37884 .60764 L .37661 .60563 L F
.334 .159 .488 r
.41767 .59634 m .41772 .59931 L .4156 .59971 L F
.26 0 .238 r
.4156 .59971 m .41772 .59931 L .41624 .5997 L F
.665 .404 .516 r
.61928 .4291 m .61646 .42677 L .6191 .42576 L F
.61928 .4291 m .61687 .42931 L .61646 .42677 L F
.418 .695 .977 r
.25214 .54225 m .25149 .54366 L .24996 .5425 L F
.25214 .54225 m .25347 .54348 L .25149 .54366 L F
.919 .978 .732 r
.62164 .46755 m .62438 .46485 L .62356 .46437 L F
.62164 .46755 m .62212 .46846 L .62438 .46485 L F
.391 .048 .258 r
.60873 .41849 m .61057 .41942 L .61076 .41741 L F
.60873 .41849 m .60809 .42018 L .61057 .41942 L F
.947 .59 .273 r
.77561 .40896 m .77749 .41212 L .77594 .41104 L F
.81 .648 .682 r
.77749 .41212 m .77342 .41353 L .77594 .41104 L F
.77749 .41212 m .77733 .41421 L .77342 .41353 L F
.723 .631 .755 r
.77982 .40914 m .77749 .41212 L .77561 .40896 L F
.686 .577 .727 r
.77982 .40914 m .78027 .41344 L .77749 .41212 L F
.405 .206 .494 r
.44243 .58446 m .44451 .58615 L .44727 .58396 L F
.331 0 0 r
.44727 .58396 m .44671 .58577 L .44839 .58216 L F
.44727 .58396 m .44451 .58615 L .44671 .58577 L F
.456 .204 .443 r
.57989 .45961 m .58235 .45896 L .58284 .45585 L F
.475 .213 .436 r
.58235 .45896 m .58518 .45563 L .58284 .45585 L F
.661 .564 .735 r
.63283 .43015 m .63473 .43573 L .63697 .43301 L F
.41 .138 .387 r
.63473 .43573 m .63624 .43524 L .63697 .43301 L F
.725 .774 .892 r
.38083 .62817 m .38226 .62994 L .38366 .62871 L F
.38083 .62817 m .38226 .62994 L .38366 .62871 L F
.384 .193 .495 r
.55409 .57432 m .55246 .57256 L .55287 .57609 L F
0 .406 .738 r
.55287 .57609 m .55428 .5764 L .55409 .57432 L F
.55287 .57609 m .55665 .57742 L .55428 .5764 L F
.407 .86 .839 r
.70158 .393 m .69916 .39395 L .69837 .39394 L F
.368 .078 .335 r
.23678 .59016 m .23884 .58958 L .2393 .58772 L F
.416 .498 .836 r
.2393 .58772 m .24106 .58736 L .23828 .58515 L F
.319 .049 .338 r
.23884 .58958 m .24106 .58736 L .2393 .58772 L F
.597 .639 .864 r
.74939 .38685 m .74805 .39033 L .74697 .38854 L F
.74939 .38685 m .75058 .38977 L .74805 .39033 L F
.248 .762 .811 r
.21628 .65566 m .21249 .65625 L .21414 .65622 L F
0 .086 .645 r
.4125 .63915 m .41317 .6374 L .41424 .64002 L F
.851 .882 .861 r
.41317 .6374 m .41424 .64002 L .41523 .63619 L F
.52 .728 .968 r
.41478 .63632 m .41261 .63565 L .41331 .63508 L F
.41261 .63565 m .41062 .63504 L .41331 .63508 L F
.093 .209 .693 r
.41421 .63395 m .4143 .63427 L .41331 .63508 L F
0 0 0 r
.41432 .63627 m .41478 .63632 L .41331 .63508 L F
.867 .989 .83 r
.41478 .63632 m .41424 .64002 L .41518 .63637 L F
.41478 .63632 m .4125 .63915 L .41424 .64002 L F
0 0 0 r
.41515 .63724 m .41347 .63838 L .41401 .63752 L F
.41515 .63724 m .41401 .63752 L .41478 .63632 L F
.797 .683 .739 r
.41829 .63433 m .41512 .63472 L .41834 .63136 L F
.586 .518 .744 r
.41825 .63477 m .41512 .63472 L .41829 .63433 L F
.79 .682 .745 r
.41613 .6272 m .41732 .63246 L .41312 .63061 L F
.41732 .63246 m .41731 .63247 L .41312 .63061 L F
.357 .688 .981 r
.41312 .63061 m .41731 .63247 L .41593 .63087 L F
.79 .682 .745 r
.41732 .63246 m .41733 .63248 L .41731 .63247 L F
.357 .688 .981 r
.41731 .63247 m .41733 .63248 L .41732 .63247 L F
.41731 .63247 m .41732 .63247 L .41593 .63087 L F
0 0 0 r
.41712 .63265 m .41512 .63472 L .41564 .6342 L F
.41834 .63136 m .41698 .63278 L .41712 .63265 L F
.41698 .63278 m .41512 .63472 L .41712 .63265 L F
.41777 .632 m .41564 .6342 L .41674 .63314 L F
.164 .251 .708 r
.41868 .6297 m .41735 .63243 L .41613 .6272 L F
.41735 .63243 m .41733 .63248 L .41732 .63246 L F
.41735 .63243 m .41732 .63246 L .41613 .6272 L F
0 0 0 r
.41834 .63136 m .41709 .63267 L .41777 .632 L F
.41709 .63267 m .41564 .6342 L .41732 .63246 L F
.41709 .63267 m .41732 .63246 L .41777 .632 L F
.586 .518 .744 r
.41512 .63472 m .41523 .63619 L .41825 .63477 L F
.41825 .63477 m .41523 .63619 L .41512 .63472 L F
.41512 .63472 m .41825 .63477 L .41674 .63314 L F
.566 .495 .735 r
.41656 .63298 m .41754 .6368 L .41515 .63724 L F
.507 .031 .061 r
.41754 .6368 m .41584 .63707 L .41515 .63724 L F
0 0 0 r
.41322 .63825 m .41347 .63838 L .4125 .63915 L F
.41478 .63632 m .414 .63754 L .41322 .63825 L F
.414 .63754 m .41347 .63838 L .41322 .63825 L F
.851 .882 .861 r
.41317 .6374 m .41523 .63619 L .41478 .63632 L F
.093 .209 .693 r
.4143 .63427 m .41498 .63664 L .41331 .63508 L F
0 0 0 r
.41515 .63724 m .41478 .63632 L .41432 .63627 L F
.093 .209 .693 r
.41498 .63664 m .41515 .63724 L .41479 .63681 L F
.52 .728 .968 r
.41478 .63632 m .41317 .6374 L .41062 .63504 L F
.093 .209 .693 r
.41498 .63664 m .41479 .63681 L .41331 .63508 L F
.507 .031 .061 r
.41584 .63707 m .41353 .63743 L .41515 .63724 L F
.867 .989 .83 r
.41478 .63632 m .41518 .63637 L .41523 .63619 L F
.609 .401 .574 r
.55974 .53705 m .56219 .53388 L .5597 .53405 L F
.521 .309 .533 r
.56087 .55501 m .56333 .55698 L .5609 .55765 L F
.56087 .55501 m .56339 .55441 L .56333 .55698 L F
.261 .497 .893 r
.4696 .55988 m .46929 .56261 L .46719 .56066 L F
.4696 .55988 m .47131 .56266 L .46929 .56261 L F
.377 .685 .979 r
.18521 .63907 m .18217 .63807 L .18417 .63784 L F
.533 .732 .966 r
.18635 .63742 m .18521 .63907 L .18417 .63784 L F
.18635 .63742 m .18802 .63889 L .18521 .63907 L F
.209 .262 .699 r
.23678 .59016 m .23766 .59365 L .23864 .59277 L F
.437 .231 .501 r
.23766 .59365 m .23935 .5955 L .23864 .59277 L F
.23766 .59365 m .23738 .59611 L .23935 .5955 L F
.394 .523 .869 r
.21053 .55676 m .21141 .55864 L .21218 .55654 L F
.548 .695 .937 r
.21141 .55864 m .21395 .55811 L .21218 .55654 L F
0 0 .027 r
.55871 .57874 m .55969 .57598 L .56101 .57459 L F
.601 .4 .581 r
.59667 .46532 m .59434 .46813 L .59417 .46574 L F
.439 .192 .441 r
.26474 .59844 m .26305 .59652 L .26513 .59583 L F
.26474 .59844 m .2626 .599 L .26305 .59652 L F
.363 0 0 r
.20034 .55402 m .19617 .55552 L .1981 .55466 L F
.874 .543 .422 r
.53641 .53083 m .53975 .53378 L .54034 .53131 L F
.992 .742 .391 r
.76558 .40183 m .76655 .40573 L .7657 .40346 L F
.727 .394 .416 r
.53958 .54276 m .53905 .53989 L .53558 .53975 L F
.57 .283 .441 r
.54069 .54227 m .53905 .53989 L .53958 .54276 L F
.54069 .54227 m .5416 .53977 L .53905 .53989 L F
.325 .657 .972 r
.23876 .55625 m .23848 .55446 L .23647 .55495 L F
.23876 .55625 m .24067 .55611 L .23848 .55446 L F
.819 .533 .506 r
.7534 .41504 m .75011 .41709 L .74929 .41384 L F
.7534 .41504 m .75356 .41757 L .75011 .41709 L F
.536 .537 .803 r
.7555 .40948 m .7534 .41504 L .75302 .40844 L F
.7555 .40948 m .75596 .41435 L .7534 .41504 L F
.451 .253 .52 r
.75596 .41435 m .75356 .41757 L .7534 .41504 L F
.75596 .41435 m .75356 .41757 L .7534 .41504 L F
.776 .532 .566 r
.54046 .60258 m .53644 .60514 L .5377 .60248 L F
.54046 .60258 m .54017 .60529 L .53644 .60514 L F
.066 .63 .736 r
.54367 .60241 m .54046 .60258 L .54091 .6024 L F
.301 .209 .581 r
.54367 .60241 m .54464 .59902 L .54187 .60248 L F
.601 .899 .987 r
.54353 .60089 m .54187 .60248 L .54464 .59902 L F
.54353 .60089 m .54145 .60154 L .54187 .60248 L F
.186 0 0 r
.54242 .60239 m .54187 .60248 L .54145 .60154 L F
.066 .63 .736 r
.54367 .60241 m .54187 .60248 L .54168 .60252 L F
.846 .685 .682 r
.54367 .60241 m .54361 .60513 L .54187 .60248 L F
.186 0 0 r
.54313 .603 m .54439 .60276 L .54187 .60248 L F
.54313 .603 m .54187 .60248 L .54242 .60239 L F
.066 .63 .736 r
.54168 .60252 m .54187 .60248 L .54046 .60258 L F
.754 .667 .766 r
.54187 .60248 m .54017 .60529 L .54046 .60258 L F
.636 .766 .941 r
.74429 .38999 m .74189 .3909 L .74102 .38921 L F
.6 .632 .855 r
.20476 .68798 m .20243 .68654 L .20514 .6857 L F
.531 .283 .485 r
.20717 .68802 m .20647 .69044 L .20419 .69076 L F
.588 .641 .87 r
.20419 .69076 m .20647 .69044 L .20625 .69009 L F
.373 .067 .312 r
.20476 .68798 m .20419 .69076 L .20238 .69136 L F
.386 .301 .637 r
.20514 .6857 m .20717 .68802 L .20476 .68798 L F
.531 .283 .485 r
.20717 .68802 m .20419 .69076 L .20476 .68798 L F
.588 .641 .87 r
.20419 .69076 m .20625 .69009 L .20445 .68715 L F
.373 .067 .312 r
.20238 .69136 m .20419 .69076 L .20195 .69197 L F
.31 0 .243 r
.5377 .60248 m .53644 .60514 L .53719 .60306 L F
.369 .19 .503 r
.55898 .56335 m .55907 .56093 L .56107 .56017 L F
.921 .974 .699 r
.54272 .55931 m .54347 .55663 L .53973 .55759 L F
.54347 .55663 m .54349 .55658 L .54325 .55664 L F
.54347 .55663 m .54325 .55664 L .53973 .55759 L F
.856 .96 .873 r
.54649 .55578 m .54498 .55655 L .54413 .55611 L F
.79 .916 .53 r
.54369 .55662 m .54343 .55735 L .54413 .55611 L F
.921 .974 .699 r
.54322 .55959 m .54342 .55739 L .54272 .55931 L F
.54342 .55739 m .54349 .55658 L .54272 .55931 L F
.54322 .55959 m .54201 .55987 L .54349 .55658 L F
.79 .916 .53 r
.5428 .55766 m .54343 .55735 L .54369 .55662 L F
.92 .974 .7 r
.54413 .55611 m .54322 .55959 L .54674 .5569 L F
.54413 .55611 m .54201 .55987 L .54322 .55959 L F
.816 .781 .82 r
.54349 .55658 m .54201 .55987 L .53832 .55936 L F
.856 .96 .873 r
.54498 .55655 m .5428 .55766 L .54369 .55662 L F
.54498 .55655 m .54369 .55662 L .54413 .55611 L F
.79 .916 .53 r
.5428 .55766 m .54201 .55987 L .54343 .55735 L F
.42 .771 .996 r
.17343 .6313 m .17655 .63188 L .17478 .63232 L F
.612 .862 .99 r
.173 .63147 m .17343 .6313 L .17478 .63232 L F
.42 .771 .996 r
.17343 .6313 m .17655 .63188 L .17478 .63232 L F
.554 .527 .779 r
.17655 .63188 m .17541 .63529 L .17478 .63232 L F
.939 .916 .54 r
.74041 .43138 m .74066 .43275 L .74156 .43027 L F
.998 .81 .464 r
.74041 .43138 m .74156 .43027 L .74081 .42819 L F
.408 .232 .528 r
.27414 .58342 m .27216 .58149 L .27421 .58047 L F
.27414 .58342 m .27214 .58422 L .27216 .58149 L F
.86 .598 .541 r
.44772 .57981 m .44297 .57767 L .44739 .5769 L F
.44772 .57981 m .443 .58035 L .44297 .57767 L F
.546 .208 .347 r
.44561 .58181 m .443 .58035 L .44772 .57981 L F
.363 .44 .807 r
.44911 .5771 m .44772 .57981 L .44739 .5769 L F
.44911 .5771 m .44983 .57897 L .44772 .57981 L F
.286 0 0 r
.53304 .57093 m .53469 .57117 L .53382 .56984 L F
.53304 .57093 m .53581 .57158 L .53469 .57117 L F
.957 .653 .415 r
.42279 .60527 m .4232 .60864 L .42151 .60707 L F
.736 .488 .553 r
.42716 .60815 m .42279 .60527 L .42727 .60582 L F
.42716 .60815 m .4232 .60864 L .42279 .60527 L F
.922 .839 .746 r
.47668 .57686 m .47621 .57901 L .47383 .57588 L F
.621 .721 .918 r
.47571 .57687 m .47621 .57901 L .47855 .57837 L F
.47558 .5768 m .4756 .57687 L .47571 .57687 L F
.4756 .57687 m .47621 .57901 L .47571 .57687 L F
.47383 .57588 m .47855 .57837 L .47875 .57571 L F
.244 0 0 r
.47962 .5768 m .4794 .5768 L .47927 .57674 L F
.4794 .5768 m .47909 .57676 L .47927 .57674 L F
.006 .11 .623 r
.47898 .5758 m .48023 .5769 L .47927 .57674 L F
.162 .15 .596 r
.47887 .57571 m .48023 .5769 L .4809 .57574 L F
.006 .11 .623 r
.47854 .5744 m .48023 .5769 L .47898 .5758 L F
.162 .15 .596 r
.47875 .57571 m .48023 .5769 L .47887 .57571 L F
.47875 .57571 m .47867 .57672 L .48023 .5769 L F
.621 .721 .918 r
.47383 .57588 m .47453 .5768 L .47558 .5768 L F
.47453 .5768 m .47621 .57901 L .47558 .5768 L F
.741 .398 .4 r
.47898 .57669 m .47356 .57701 L .47383 .57588 L F
.47927 .57674 m .47901 .57675 L .47898 .57669 L F
.162 .15 .596 r
.47867 .57672 m .47855 .57837 L .47943 .57759 L F
.741 .398 .4 r
.47901 .57675 m .47356 .57701 L .47898 .57669 L F
.162 .15 .596 r
.47901 .57676 m .47943 .57759 L .48023 .5769 L F
.47867 .57672 m .47943 .57759 L .47901 .57676 L F
.244 0 0 r
.4794 .5768 m .47873 .57681 L .47909 .57676 L F
.48023 .5769 m .47628 .57718 L .47873 .57681 L F
.47628 .57718 m .47598 .57718 L .47873 .57681 L F
.163 0 0 r
.47777 .57681 m .47571 .57722 L .47356 .57701 L F
.47927 .57674 m .47873 .57681 L .47777 .57681 L F
.47873 .57681 m .47571 .57722 L .47777 .57681 L F
.768 .601 .672 r
.47854 .5744 m .47368 .57213 L .47563 .57163 L F
.47854 .5744 m .47383 .57588 L .47368 .57213 L F
.741 .398 .4 r
.47927 .57674 m .47383 .57588 L .47854 .5744 L F
.108 0 0 r
.47571 .57722 m .47879 .5773 L .47857 .57724 L F
.244 0 0 r
.47628 .57718 m .47711 .57723 L .47571 .57722 L F
.48023 .5769 m .4793 .57726 L .47876 .57724 L F
.4776 .57708 m .47876 .57724 L .47628 .57718 L F
.48023 .5769 m .47876 .57724 L .4776 .57708 L F
.836 .6 .582 r
.47804 .57167 m .47854 .5744 L .47563 .57163 L F
.795 .321 .102 r
.4809 .57574 m .48023 .5769 L .47854 .5744 L F
.355 .476 .844 r
.47659 .57292 m .47876 .57724 L .47983 .57485 L F
.47876 .57724 m .47879 .5773 L .47881 .57725 L F
.47876 .57724 m .47881 .57725 L .47983 .57485 L F
.244 0 0 r
.47628 .57718 m .47571 .57722 L .47598 .57718 L F
.108 0 0 r
.47571 .57722 m .47857 .57724 L .47479 .57611 L F
.47571 .57722 m .47907 .57735 L .47879 .5773 L F
.244 0 0 r
.47711 .57723 m .47907 .57735 L .47571 .57722 L F
.642 .634 .827 r
.47857 .57724 m .47879 .5773 L .47876 .57724 L F
.778 .542 .579 r
.48241 .58126 m .47864 .58087 L .47855 .57837 L F
.571 .55 .792 r
.47864 .58087 m .48023 .5769 L .47855 .57837 L F
.47864 .58087 m .481 .58034 L .48023 .5769 L F
0 .419 .846 r
.48019 .57848 m .47907 .57735 L .48023 .5769 L F
.48019 .57848 m .48047 .5778 L .47907 .57735 L F
.293 0 0 r
.47907 .57735 m .48047 .5778 L .4796 .57763 L F
.244 0 0 r
.47888 .57725 m .47907 .57735 L .47628 .57718 L F
.293 0 0 r
.47907 .57735 m .4796 .57763 L .47698 .5771 L F
.244 0 0 r
.4793 .57726 m .47907 .57735 L .47888 .57725 L F
.642 .634 .827 r
.47827 .57715 m .47857 .57724 L .47871 .57714 L F
.47857 .57724 m .47876 .57724 L .47871 .57714 L F
.47479 .57611 m .47827 .57715 L .47659 .57292 L F
.47827 .57715 m .47871 .57714 L .47659 .57292 L F
.244 0 0 r
.48023 .5769 m .47873 .57681 L .47962 .5768 L F
0 .153 .694 r
.52306 .57872 m .5233 .57736 L .52131 .57531 L F
0 .197 .725 r
.52306 .57872 m .52511 .58067 L .5233 .57736 L F
.554 .527 .779 r
.17655 .63188 m .17704 .63335 L .17541 .63529 L F
.924 .716 .603 r
.49888 .54286 m .4976 .53929 L .49922 .54029 L F
.705 .784 .913 r
.50191 .53924 m .49922 .54029 L .4976 .53929 L F
.855 .861 .844 r
.60351 .44372 m .60759 .44242 L .60646 .44135 L F
.60351 .44372 m .6051 .44495 L .60759 .44242 L F
.841 .972 .88 r
.60795 .44012 m .60759 .44242 L .60983 .44151 L F
.60795 .44012 m .60646 .44135 L .60759 .44242 L F
.523 .336 .569 r
.52985 .55509 m .53254 .55186 L .5296 .55248 L F
.52985 .55509 m .53275 .55471 L .53254 .55186 L F
.471 .227 .461 r
.52985 .55509 m .53196 .55554 L .53275 .55471 L F
.52985 .55509 m .52959 .55727 L .53196 .55554 L F
.523 .336 .569 r
.53254 .55186 m .52985 .55509 L .5296 .55248 L F
.53254 .55186 m .53275 .55471 L .52985 .55509 L F
.471 .227 .461 r
.53196 .55554 m .52985 .55509 L .53275 .55471 L F
.53196 .55554 m .52959 .55727 L .52985 .55509 L F
.313 .359 .749 r
.37791 .61411 m .37872 .61781 L .38032 .61611 L F
.384 .468 .823 r
.37872 .61781 m .38205 .61958 L .38032 .61611 L F
.487 .428 .717 r
.77982 .40914 m .78286 .41074 L .78027 .41344 L F
.42 .35 .672 r
.78286 .41074 m .78105 .41528 L .78027 .41344 L F
.616 .822 .419 r
.19953 .68576 m .19861 .687 L .20086 .6856 L F
.19953 .68576 m .19785 .68823 L .19861 .687 L F
.184 .666 .928 r
.45312 .58894 m .45548 .58926 L .45628 .58976 L F
.099 0 0 r
.45603 .59217 m .45628 .58976 L .45548 .58926 L F
.751 .853 .926 r
.73754 .42941 m .73554 .43094 L .73432 .42939 L F
.785 .743 .814 r
.62964 .43006 m .62726 .43262 L .63038 .43304 L F
.75 .566 .646 r
.62651 .43533 m .63047 .43617 L .63038 .43304 L F
.806 .755 .805 r
.62964 .43006 m .63038 .43304 L .63283 .43015 L F
.449 .791 .998 r
.2326 .55456 m .23072 .55362 L .22822 .55386 L F
0 .414 .792 r
.2326 .55456 m .23216 .55398 L .23072 .55362 L F
.2326 .55456 m .23434 .55521 L .23216 .55398 L F
.761 .754 .846 r
.43148 .60241 m .42774 .60198 L .43033 .60017 L F
.62 .469 .656 r
.43385 .60408 m .43212 .60507 L .43148 .60241 L F
.234 .564 .937 r
.26547 .54787 m .26499 .54912 L .26353 .54772 L F
.26547 .54787 m .26795 .55017 L .26499 .54912 L F
.352 0 .184 r
.4447 .59042 m .4435 .59278 L .44122 .59322 L F
.682 .319 .353 r
.447 .59266 m .4447 .59042 L .44708 .59023 L F
.447 .59266 m .4435 .59278 L .4447 .59042 L F
.528 .414 .667 r
.21231 .56416 m .21277 .56664 L .21493 .56609 L F
0 0 0 r
.54181 .49807 m .54382 .49705 L .54478 .49561 L F
.082 0 .183 r
.54717 .49248 m .54478 .49561 L .54646 .49424 L F
0 0 0 r
.54478 .49561 m .54575 .49616 L .54646 .49424 L F
.54478 .49561 m .54382 .49705 L .54575 .49616 L F
.771 .507 .535 r
.60253 .43749 m .60583 .43886 L .60612 .43604 L F
.60253 .43749 m .60612 .43604 L .60486 .43699 L F
.647 .297 .365 r
.60839 .43508 m .60486 .43699 L .60612 .43604 L F
.959 .926 .586 r
.66748 .42102 m .6683 .41693 L .66721 .41992 L F
.942 .907 .521 r
.66672 .42253 m .66748 .42102 L .66721 .41992 L F
.544 .237 .397 r
.21774 .62242 m .22095 .62013 L .21856 .62046 L F
0 0 0 r
.21141 .6602 m .21239 .65982 L .21377 .66112 L F
.21141 .6602 m .21045 .66138 L .21239 .65982 L F
0 .215 .737 r
.52981 .5933 m .53012 .59203 L .52797 .59 L F
0 0 .265 r
.52981 .5933 m .53035 .59565 L .53012 .59203 L F
.369 .346 .702 r
.74702 .42774 m .74669 .43009 L .7493 .42821 L F
.122 .02 .455 r
.74708 .4321 m .7493 .42821 L .74669 .43009 L F
.874 .543 .422 r
.53641 .53083 m .53691 .53334 L .53975 .53378 L F
.881 .87 .822 r
.53596 .53547 m .53975 .53378 L .53691 .53334 L F
.71 .76 .891 r
.72336 .43095 m .71961 .43029 L .72175 .42914 L F
.773 .813 .884 r
.45312 .58894 m .45141 .59143 L .44929 .58974 L F
.519 .296 .516 r
.43991 .58754 m .44243 .58446 L .43991 .58469 L F
.445 .211 .464 r
.58633 .53335 m .58654 .53112 L .58878 .53044 L F
.445 .265 .542 r
.2162 .62337 m .21805 .62533 L .21774 .62242 L F
.2162 .62337 m .21605 .62602 L .21805 .62533 L F
.748 .661 .765 r
.4599 .5806 m .464 .58392 L .46221 .58091 L F
.4599 .5806 m .4614 .58433 L .464 .58392 L F
.88 .843 .804 r
.46221 .58091 m .464 .58392 L .46577 .58043 L F
.738 .431 .462 r
.42135 .63799 m .42007 .64042 L .42359 .64052 L F
.468 .846 .618 r
.63115 .41711 m .63237 .41491 L .63297 .41765 L F
0 0 0 r
.1884 .55604 m .18641 .55675 L .18576 .55682 L F
.18576 .55682 m .18578 .55774 L .18356 .5583 L F
.18576 .55682 m .18641 .55675 L .18578 .55774 L F
.261 .027 .358 r
.45176 .56683 m .45215 .56803 L .45094 .5687 L F
.666 .246 .238 r
.45176 .56683 m .45404 .56876 L .45215 .56803 L F
.597 .29 .419 r
.45411 .56681 m .45404 .56876 L .45176 .56683 L F
.181 0 0 r
.16903 .54726 m .17327 .54541 L .17164 .54623 L F
.797 .575 .601 r
.45027 .64687 m .45031 .64947 L .45218 .6466 L F
.45218 .6466 m .45031 .64947 L .45027 .64687 L F
.45027 .64687 m .45031 .64947 L .45218 .6466 L F
0 0 .015 r
.5348 .55685 m .53369 .55804 L .53525 .55467 L F
.719 .322 .295 r
.53525 .55467 m .5378 .55722 L .5348 .55685 L F
.745 .235 0 r
.53973 .55759 m .5378 .55722 L .53679 .55568 L F
.372 .809 .96 r
.53973 .55759 m .54349 .55658 L .5378 .55722 L F
.816 .781 .82 r
.54349 .55658 m .53898 .559 L .5378 .55722 L F
.53898 .559 m .53832 .55936 L .5378 .55722 L F
.745 .235 0 r
.53679 .55568 m .5378 .55722 L .53525 .55467 L F
.456 .882 .905 r
.70666 .40004 m .70918 .39914 L .70821 .39897 L F
.455 .879 .918 r
.70578 .3998 m .70666 .40004 L .70821 .39897 L F
.816 .796 .833 r
.72587 .42762 m .72175 .42914 L .72425 .42651 L F
.269 .432 .84 r
.72707 .42462 m .72655 .42597 L .72626 .42373 L F
.8 .998 .847 r
.7279 .42538 m .72595 .42754 L .72655 .42597 L F
.872 .58 .491 r
.72655 .42597 m .72861 .42584 L .7279 .42538 L F
.624 .192 0 r
.72939 .42717 m .72861 .42584 L .72655 .42597 L F
.269 .432 .84 r
.72939 .42717 m .72655 .42597 L .72707 .42462 L F
.8 .998 .847 r
.72595 .42754 m .72587 .42762 L .72655 .42597 L F
.6 .8 .976 r
.72655 .42597 m .72587 .42762 L .72425 .42651 L F
.391 0 .057 r
.45831 .56653 m .45404 .56876 L .45411 .56681 L F
.45831 .56653 m .45641 .56855 L .45404 .56876 L F
.473 .562 .865 r
.48753 .56518 m .48576 .56689 L .48451 .56365 L F
.364 .384 .747 r
.48753 .56518 m .4883 .56821 L .48576 .56689 L F
0 0 0 r
.54984 .48982 m .54717 .49248 L .54889 .49089 L F
.094 0 0 r
.54889 .49089 m .55161 .48851 L .54984 .48982 L F
.497 .771 .993 r
.18645 .65817 m .18842 .65722 L .18578 .65788 L F
0 0 .062 r
.59331 .52379 m .59164 .5252 L .59357 .52191 L F
0 0 .354 r
.59146 .5276 m .59164 .5252 L .59331 .52379 L F
.579 .428 .64 r
.42077 .62314 m .42093 .62563 L .42318 .62295 L F
.42318 .62295 m .42093 .62563 L .42077 .62314 L F
.478 .394 .682 r
.19034 .70409 m .19232 .70323 L .19029 .70368 L F
.601 .804 .978 r
.71169 .39839 m .7128 .39977 L .71537 .39901 L F
.168 0 .117 r
.41902 .57285 m .41623 .5753 L .41817 .57453 L F
.108 0 .116 r
.42199 .57013 m .41902 .57285 L .42089 .57182 L F
.104 0 .093 r
.41817 .57453 m .42089 .57182 L .41902 .57285 L F
.967 .658 .378 r
.60351 .44372 m .60394 .44622 L .6051 .44495 L F
.60351 .44372 m .60394 .44622 L .6051 .44495 L F
.965 .866 .691 r
.63017 .44579 m .6304 .45024 L .63156 .44838 L F
.804 .672 .718 r
.77733 .41421 m .77504 .41742 L .77342 .41353 L F
.669 .339 .406 r
.4946 .57879 m .49716 .58126 L .49506 .5804 L F
.63 .349 .474 r
.49721 .57867 m .49716 .58126 L .4946 .57879 L F
.164 .261 .719 r
.27649 .55398 m .27635 .55767 L .27542 .55424 L F
.27649 .55398 m .27763 .55638 L .27635 .55767 L F
.338 .137 .453 r
.27763 .55638 m .27519 .55919 L .27635 .55767 L F
.59 .419 .618 r
.37675 .62302 m .37912 .62494 L .3798 .62262 L F
.324 .205 .559 r
.3798 .62262 m .38208 .62223 L .38205 .61958 L F
.664 .55 .715 r
.37912 .62494 m .38208 .62223 L .3798 .62262 L F
.099 .317 .792 r
.46306 .60847 m .4646 .6115 L .46505 .60994 L F
.339 0 .125 r
.4646 .6115 m .46697 .61099 L .46576 .61299 L F
.4646 .6115 m .46576 .61299 L .46505 .60994 L F
.213 0 .192 r
.54101 .49985 m .54382 .49705 L .54181 .49807 L F
0 0 0 r
.53927 .50086 m .54101 .49985 L .54181 .49807 L F
.507 .642 .916 r
.18217 .63807 m .17824 .63568 L .18019 .63506 L F
.487 .591 .884 r
.18417 .63784 m .18217 .63807 L .18019 .63506 L F
.747 .735 .841 r
.68902 .44989 m .69257 .45037 L .69167 .44723 L F
.757 .721 .819 r
.69084 .45118 m .69257 .45037 L .68902 .44989 L F
.689 .701 .856 r
.69167 .44723 m .69257 .45037 L .69542 .44854 L F
.455 .79 .999 r
.22204 .53992 m .22407 .53957 L .22584 .54053 L F
.158 .648 .919 r
.22407 .53957 m .22793 .5405 L .22584 .54053 L F
.593 .417 .613 r
.23738 .58357 m .24075 .58138 L .2378 .58196 L F
.662 .62 .796 r
.47127 .59924 m .46736 .59758 L .47013 .59702 L F
.827 .972 .891 r
.46808 .60129 m .47127 .59924 L .4701 .60086 L F
.305 .226 .6 r
.47277 .59589 m .47127 .59924 L .47013 .59702 L F
.47277 .59589 m .47316 .59908 L .47127 .59924 L F
.169 0 0 r
.47316 .59908 m .4701 .60086 L .47127 .59924 L F
.154 .319 .779 r
.19369 .69433 m .1952 .69768 L .19628 .69638 L F
.111 .253 .731 r
.1952 .69768 m .19696 .69804 L .19628 .69638 L F
.163 .133 .575 r
.1952 .69768 m .19564 .70062 L .19696 .69804 L F
.965 .745 .556 r
.60355 .47757 m .60172 .47902 L .6021 .47657 L F
.60355 .47757 m .60328 .4803 L .60172 .47902 L F
.116 0 .307 r
.54646 .49424 m .54889 .49089 L .54717 .49248 L F
.177 0 .247 r
.55731 .48091 m .55671 .48279 L .55911 .47983 L F
.605 .405 .584 r
.65583 .43629 m .65842 .4356 L .65619 .4387 L F
.225 .311 .743 r
.1941 .69178 m .19621 .69362 L .19488 .69056 L F
.528 .328 .554 r
.19369 .69433 m .19621 .69362 L .1941 .69178 L F
.655 .291 0 r
.74843 .42114 m .74964 .42375 L .74861 .4216 L F
0 0 .007 r
.58933 .50385 m .58766 .50737 L .58901 .50577 L F
0 0 0 r
.58901 .50577 m .58766 .50737 L .58677 .50943 L F
.427 .246 .531 r
.19246 .71456 m .19294 .71596 L .19342 .71553 L F
.715 .662 .11 r
.19308 .7153 m .19188 .71244 L .19129 .71407 L F
.19342 .71553 m .19323 .71515 L .19308 .7153 L F
.19323 .71515 m .19188 .71244 L .19308 .7153 L F
.427 .246 .531 r
.19281 .71557 m .19115 .71745 L .19294 .71596 L F
.715 .662 .11 r
.19342 .71553 m .19308 .7153 L .19246 .71456 L F
.19308 .7153 m .19129 .71407 L .19246 .71456 L F
.427 .246 .531 r
.19246 .71456 m .19135 .71701 L .19281 .71557 L F
.19135 .71701 m .19115 .71745 L .19281 .71557 L F
.551 .832 .998 r
.74361 .40205 m .74453 .40311 L .74381 .39942 L F
.74361 .40205 m .74702 .40246 L .74453 .40311 L F
.74453 .40311 m .74702 .40246 L .74361 .40205 L F
.431 .088 .281 r
.58821 .46894 m .58805 .47064 L .58535 .47099 L F
.529 .167 .297 r
.59061 .47028 m .58805 .47064 L .58821 .46894 L F
.717 .768 .893 r
.68737 .45069 m .69084 .45118 L .68902 .44989 L F
.545 .515 .772 r
.45983 .60429 m .46101 .60902 L .46306 .60847 L F
0 .546 .787 r
.67772 .39829 m .67479 .39792 L .67402 .39759 L F
.478 .394 .682 r
.19034 .70409 m .19236 .70567 L .19232 .70323 L F
.38 .273 .606 r
.27387 .56909 m .27445 .57178 L .27255 .56982 L F
.18 .238 .687 r
.27255 .56982 m .27445 .57178 L .27354 .57234 L F
.815 .695 .732 r
.71317 .432 m .70953 .43186 L .71223 .42894 L F
.71317 .432 m .71137 .43325 L .70953 .43186 L F
.722 .765 .887 r
.71575 .4295 m .71317 .432 L .71223 .42894 L F
.506 .744 .98 r
.73511 .40047 m .7375 .40047 L .73364 .39908 L F
.248 .603 .953 r
.73511 .40047 m .73894 .40214 L .7375 .40047 L F
.695 .529 .659 r
.53139 .53431 m .52804 .53675 L .52815 .53384 L F
.53139 .53431 m .53179 .53686 L .52804 .53675 L F
.082 .096 .574 r
.53179 .53686 m .53305 .53561 L .53139 .53431 L F
.95 .944 .626 r
.62059 .47153 m .62212 .46846 L .62164 .46755 L F
.732 .478 0 r
.53107 .59872 m .53095 .59856 L .53035 .59565 L F
0 .007 .511 r
.53107 .59872 m .53239 .60003 L .53095 .59856 L F
.556 .349 .554 r
.5571 .59653 m .55733 .59916 L .55474 .59952 L F
.311 .545 .915 r
.73894 .40214 m .74047 .40195 L .7375 .40047 L F
.73894 .40214 m .74098 .40283 L .74047 .40195 L F
.001 0 0 r
.46681 .59846 m .47013 .59702 L .46736 .59758 L F
.72 .718 .847 r
.70723 .43464 m .70857 .43612 L .70477 .43543 L F
.77 .726 .811 r
.71022 .43495 m .70857 .43612 L .70723 .43464 L F
.085 0 .098 r
.55485 .48396 m .55405 .48559 L .55671 .48279 L F
0 0 .009 r
.41623 .5753 m .4169 .57646 L .41817 .57453 L F
.41623 .5753 m .41527 .57756 L .4169 .57646 L F
.115 .667 .769 r
.20657 .55384 m .2024 .55409 L .20406 .55424 L F
0 .422 .774 r
.42732 .57913 m .42637 .57913 L .42502 .57897 L F
.42732 .57913 m .4288 .57989 L .42637 .57913 L F
0 0 .02 r
.46049 .56336 m .46023 .56372 L .46173 .5624 L F
.975 .738 .514 r
.19772 .7096 m .19621 .71129 L .19618 .70868 L F
.154 .199 .656 r
.19914 .70849 m .19919 .71128 L .19772 .7096 L F
.702 .93 .611 r
.54889 .5063 m .5481 .50779 L .54954 .50581 L F
.672 .867 .479 r
.54693 .50945 m .5481 .50779 L .54889 .5063 L F
.451 .862 .701 r
.52393 .51564 m .52531 .51459 L .5268 .51395 L F
.458 .881 .784 r
.52393 .51564 m .52315 .51574 L .52531 .51459 L F
.209 .262 .699 r
.23678 .59016 m .23864 .59277 L .23884 .58958 L F
.615 .92 .976 r
.431 .59561 m .43018 .59647 L .43301 .59527 L F
.802 .572 .59 r
.431 .59561 m .42869 .598 L .43018 .59647 L F
.593 .781 .97 r
.6796 .46155 m .68344 .4625 L .68182 .4614 L F
.6796 .46155 m .68344 .4625 L .68182 .4614 L F
0 0 .214 r
.43689 .58243 m .43613 .58107 L .43876 .58136 L F
.373 .661 .97 r
.43876 .58136 m .43613 .58107 L .43833 .57841 L F
.706 .878 .962 r
.20514 .6857 m .20243 .68654 L .20086 .6856 L F
.491 .302 .551 r
.61215 .45047 m .61046 .44912 L .61101 .44946 L F
.61046 .44912 m .60872 .44772 L .61032 .44894 L F
.61046 .44912 m .61032 .44894 L .61101 .44946 L F
.225 .327 .759 r
.60989 .4497 m .61101 .44946 L .60872 .44772 L F
.744 .966 .687 r
.60989 .4497 m .60751 .45145 L .61003 .44857 L F
.6101 .44866 m .61003 .44857 L .61015 .44843 L F
.60989 .4497 m .61003 .44857 L .6101 .44866 L F
.545 .515 .772 r
.45983 .60429 m .46306 .60847 L .46341 .60541 L F
.355 .184 .506 r
.46306 .60847 m .46532 .609 L .46341 .60541 L F
.77 .726 .811 r
.71022 .43495 m .70723 .43464 L .70953 .43186 L F
.745 .711 .819 r
.71137 .43325 m .71022 .43495 L .70953 .43186 L F
.652 .635 .821 r
.73988 .39527 m .74321 .39717 L .74216 .39409 L F
.611 .621 .837 r
.74321 .39717 m .74453 .39307 L .74216 .39409 L F
0 0 0 r
.74321 .39717 m .74754 .39607 L .74775 .39651 L F
.611 .621 .837 r
.74321 .39717 m .74775 .39651 L .74453 .39307 L F
.458 .887 .866 r
.19798 .54071 m .19802 .54 L .20007 .54025 L F
.832 .724 .746 r
.20514 .6857 m .20086 .6856 L .20199 .67983 L F
0 0 0 r
.20703 .68268 m .2057 .68506 L .20514 .6857 L F
0 .157 .693 r
.2057 .68506 m .20717 .68802 L .20514 .6857 L F
0 0 0 r
.1562 .55287 m .15781 .55248 L .15998 .55133 L F
.15998 .55133 m .16101 .5511 L .16189 .5505 L F
.15998 .55133 m .15781 .55248 L .16101 .5511 L F
.654 .809 .958 r
.67844 .45652 m .6819 .45678 L .68058 .45545 L F
.054 .112 .606 r
.52637 .58418 m .52662 .58796 L .52728 .58683 L F
0 0 .38 r
.52797 .59 m .52728 .58683 L .52662 .58796 L F
.794 .695 .755 r
.63123 .42852 m .63283 .43015 L .6322 .42732 L F
.806 .755 .805 r
.62964 .43006 m .63283 .43015 L .63123 .42852 L F
.661 .564 .735 r
.63283 .43015 m .63697 .43301 L .63601 .4299 L F
.739 .893 .949 r
.61215 .45047 m .61288 .44827 L .61387 .44934 L F
.61215 .45047 m .61101 .44946 L .61288 .44827 L F
.074 0 .119 r
.4653 .58899 m .46307 .5906 L .4656 .58773 L F
.199 0 0 r
.464 .5916 m .46307 .5906 L .4653 .58899 L F
0 0 0 r
.46516 .58944 m .464 .5916 L .4653 .58899 L F
.561 .091 .096 r
.46166 .5881 m .46516 .58944 L .4656 .58773 L F
.471 .303 .571 r
.4656 .58773 m .46775 .58968 L .46777 .587 L F
.726 .712 .181 r
.4656 .58773 m .46516 .58944 L .4653 .58899 L F
.149 .685 .847 r
.75447 .43644 m .75375 .43612 L .75131 .4363 L F
.402 .785 .991 r
.75727 .43669 m .75375 .43612 L .75447 .43644 L F
.807 .692 .737 r
.67177 .41095 m .67515 .41203 L .67303 .40996 L F
.619 .672 .879 r
.67303 .40996 m .67515 .41203 L .67743 .41121 L F
.856 .48 .335 r
.53719 .60306 m .53399 .60354 L .53239 .60003 L F
.845 .393 .131 r
.53454 .60394 m .53402 .60495 L .53405 .60447 L F
.984 .741 .487 r
.53505 .60338 m .53454 .60394 L .53399 .60354 L F
0 .049 .611 r
.53399 .60354 m .53454 .60394 L .53417 .60226 L F
.845 .393 .131 r
.53454 .60394 m .53405 .60447 L .53417 .60226 L F
.984 .741 .487 r
.53719 .60306 m .53454 .60394 L .53505 .60338 L F
.53719 .60306 m .53644 .60514 L .53454 .60394 L F
.715 .662 .11 r
.19342 .71553 m .1939 .71196 L .19188 .71244 L F
.19342 .71553 m .1935 .71485 L .1939 .71196 L F
.504 .656 .927 r
.20786 .67622 m .20742 .6774 L .20369 .67411 L F
.611 .922 .973 r
.44205 .55942 m .44295 .55856 L .44688 .55889 L F
.545 .901 .971 r
.44688 .55889 m .44739 .55708 L .44914 .55813 L F
.44688 .55889 m .44295 .55856 L .44739 .55708 L F
.487 .5 .796 r
.62945 .41914 m .62741 .42159 L .62669 .41879 L F
.576 .633 .871 r
.62945 .41914 m .6308 .42144 L .62741 .42159 L F
.487 .5 .796 r
.62945 .41914 m .62741 .42159 L .62669 .41879 L F
.764 .493 .523 r
.4715 .58763 m .46775 .58968 L .46777 .587 L F
.4715 .58763 m .47146 .58998 L .46775 .58968 L F
.41 .815 .98 r
.29118 .78655 m .28737 .78637 L .28896 .78694 L F
.29118 .78655 m .28737 .78637 L .28896 .78694 L F
.867 .674 .639 r
.42461 .59664 m .42407 .59866 L .42222 .59534 L F
.311 .8 .773 r
.1695 .56327 m .16888 .56367 L .17116 .56264 L F
.1695 .56327 m .16599 .56433 L .16888 .56367 L F
.604 .775 .962 r
.43201 .56742 m .43087 .5679 L .4268 .56505 L F
.711 .557 .677 r
.63601 .4299 m .63855 .43232 L .63793 .42872 L F
.63601 .4299 m .63697 .43301 L .63855 .43232 L F
0 0 0 r
.63234 .40418 m .63467 .40369 L .63599 .40306 L F
.694 .249 .191 r
.46307 .5906 m .46162 .59215 L .4593 .5901 L F
.199 0 0 r
.464 .5916 m .46162 .59215 L .46307 .5906 L F
.88 .64 .572 r
.60225 .47147 m .60023 .47319 L .60043 .47064 L F
.60225 .47147 m .60232 .47403 L .60023 .47319 L F
.902 .906 .501 r
.65121 .42203 m .65156 .42306 L .65225 .42087 L F
.894 .802 .32 r
.65074 .42402 m .65156 .42306 L .65121 .42203 L F
.65074 .42402 m .65092 .42635 L .65156 .42306 L F
.129 0 .115 r
.21582 .65273 m .21595 .65344 L .21714 .65235 L F
.984 .88 .643 r
.64822 .43191 m .65024 .42933 L .65027 .42884 L F
.64822 .43191 m .64926 .43292 L .65024 .42933 L F
.676 .391 .481 r
.50625 .5879 m .5056 .58978 L .50293 .58804 L F
.50293 .58804 m .5056 .58978 L .50625 .5879 L F
.092 0 .216 r
.50625 .5879 m .5056 .58978 L .50808 .5862 L F
.50625 .5879 m .5056 .58978 L .50808 .5862 L F
.307 .144 .49 r
.43279 .5642 m .43201 .56742 L .43449 .56306 L F
.593 .432 .633 r
.52066 .57292 m .51885 .57597 L .52131 .57531 L F
.028 .092 .595 r
.52029 .56918 m .52066 .57292 L .52178 .5713 L F
0 0 .381 r
.52131 .57531 m .52178 .5713 L .52066 .57292 L F
.803 .708 .761 r
.6187 .44408 m .61579 .4412 L .61829 .44046 L F
.6187 .44408 m .61729 .44477 L .61579 .4412 L F
.701 .721 .865 r
.6222 .44132 m .6187 .44408 L .61829 .44046 L F
.307 .006 .28 r
.56185 .47728 m .56409 .47642 L .56435 .47424 L F
.336 .029 .287 r
.56435 .47424 m .56638 .47561 L .56675 .4734 L F
.56435 .47424 m .56409 .47642 L .56638 .47561 L F
.572 .916 .966 r
.46847 .56773 m .46767 .56911 L .47009 .56862 L F
.46847 .56773 m .46632 .56876 L .46767 .56911 L F
.121 .607 .912 r
.65963 .40039 m .66314 .40152 L .65995 .40117 L F
.047 0 0 r
.51748 .53982 m .51596 .54016 L .51356 .5404 L F
.988 .719 .388 r
.51748 .53982 m .51642 .54176 L .51596 .54016 L F
.51748 .53982 m .51774 .54298 L .51642 .54176 L F
.541 .563 .826 r
.54673 .55135 m .54566 .55274 L .5442 .55146 L F
.54673 .55135 m .54557 .55367 L .54566 .55274 L F
.476 .101 .248 r
.62137 .40812 m .62389 .40793 L .62427 .40656 L F
.47 .132 .309 r
.62389 .40793 m .62692 .40594 L .62427 .40656 L F
.572 .382 .586 r
.6027 .437 m .60292 .43704 L .60186 .43267 L F
.075 .068 .545 r
.60186 .43267 m .60292 .43704 L .60381 .43372 L F
.525 .533 .806 r
.60293 .437 m .60486 .43699 L .60381 .43372 L F
.075 .068 .545 r
.60292 .43704 m .60293 .43711 L .60381 .43372 L F
.525 .533 .806 r
.6027 .437 m .60293 .437 L .60381 .43372 L F
.60253 .43749 m .60389 .4372 L .6027 .437 L F
.60389 .4372 m .60486 .43699 L .6027 .437 L F
.572 .382 .586 r
.59977 .43568 m .6027 .437 L .60186 .43267 L F
.6027 .437 m .60293 .43711 L .60292 .43704 L F
.525 .533 .806 r
.60253 .43749 m .6027 .437 L .60293 .43711 L F
.6027 .437 m .60381 .43372 L .60293 .43711 L F
.572 .382 .586 r
.59952 .43604 m .60293 .43711 L .59977 .43568 L F
.14 0 .156 r
.60186 .43267 m .6043 .43172 L .60608 .42925 L F
.075 .068 .545 r
.60186 .43267 m .60381 .43372 L .6043 .43172 L F
.724 .617 .738 r
.77942 .4052 m .77982 .40914 L .77561 .40896 L F
.453 .413 .724 r
.78191 .40859 m .77982 .40914 L .77942 .4052 L F
.459 .438 .748 r
.78191 .40859 m .78286 .41074 L .77982 .40914 L F
.485 0 0 r
.41017 .6473 m .40825 .64701 L .40663 .64605 L F
0 .346 .681 r
.41266 .64873 m .40825 .64701 L .41017 .6473 L F
.317 .785 .934 r
.25087 .77464 m .25222 .77502 L .24849 .77503 L F
.25087 .77464 m .25222 .77502 L .24849 .77503 L F
.682 .547 .694 r
.19598 .67375 m .19673 .67682 L .19971 .67666 L F
.728 .756 .875 r
.70745 .44964 m .70909 .45145 L .71101 .45009 L F
.866 .439 .011 r
.20897 .66253 m .20992 .66472 L .20892 .66413 L F
.20865 .66374 m .20892 .66413 L .2086 .66395 L F
.20897 .66253 m .20892 .66413 L .20865 .66374 L F
.776 .434 .408 r
.21201 .66463 m .20992 .66472 L .20897 .66253 L F
.699 .268 .222 r
.21201 .66463 m .21239 .6672 L .20992 .66472 L F
.765 .319 .192 r
.21235 .66718 m .2125 .66792 L .2134 .66786 L F
.699 .268 .222 r
.21235 .66718 m .2125 .66792 L .21163 .66684 L F
.747 .242 .015 r
.20992 .66472 m .2125 .66792 L .20878 .66485 L F
.765 .319 .192 r
.20878 .66485 m .2125 .66792 L .21235 .66718 L F
.699 .268 .222 r
.21239 .6672 m .2125 .66792 L .21235 .66718 L F
.21239 .6672 m .21163 .66684 L .20992 .66472 L F
.768 .325 .198 r
.2134 .66786 m .2125 .66792 L .21239 .6672 L F
.2133 .66763 m .21239 .6672 L .21201 .66463 L F
.765 .319 .192 r
.20983 .6655 m .21311 .66767 L .2093 .66471 L F
.768 .325 .198 r
.2134 .66786 m .21311 .66767 L .2133 .66763 L F
.765 .319 .192 r
.21311 .66767 m .2134 .66786 L .21315 .66767 L F
.21311 .66767 m .21315 .66767 L .2093 .66471 L F
.20986 .66556 m .2134 .66786 L .20983 .6655 L F
.768 .325 .198 r
.2134 .66766 m .21201 .66463 L .2134 .66503 L F
.2134 .66786 m .2133 .66763 L .2134 .66766 L F
.2133 .66763 m .21201 .66463 L .2134 .66766 L F
.974 .726 .497 r
.215 .66717 m .215 .66722 L .21444 .66735 L F
.215 .66722 m .21503 .66974 L .21444 .66735 L F
.21444 .66735 m .21503 .66974 L .21373 .66843 L F
.21357 .66805 m .21373 .66843 L .21345 .66815 L F
.21444 .66735 m .21373 .66843 L .21357 .66805 L F
.21444 .66735 m .21345 .66815 L .21351 .66766 L F
.544 .302 .499 r
.21522 .66454 m .21623 .66762 L .2149 .66774 L F
.21359 .66766 m .2149 .66774 L .21349 .66786 L F
.659 .275 0 r
.21502 .66722 m .21444 .66735 L .21351 .66766 L F
.21502 .66722 m .21351 .66766 L .21352 .66766 L F
.21502 .66722 m .21345 .66768 L .21347 .66768 L F
.544 .302 .499 r
.21352 .66765 m .21349 .66786 L .2134 .66786 L F
.581 .587 .823 r
.21349 .66786 m .2149 .66774 L .21342 .66769 L F
0 0 .315 r
.21566 .66859 m .21503 .66974 L .215 .66717 L F
.2157 .66867 m .21562 .6688 L .21566 .66859 L F
.21562 .6688 m .21503 .66974 L .21566 .66859 L F
.659 .275 0 r
.21522 .66775 m .21502 .66722 L .21344 .66769 L F
.21502 .66722 m .215 .66717 L .21444 .66735 L F
.544 .302 .499 r
.21522 .66454 m .2149 .66774 L .21359 .66766 L F
.21522 .66454 m .2134 .66786 L .2134 .66503 L F
.581 .587 .823 r
.2134 .66786 m .21349 .66786 L .2134 .66764 L F
.974 .726 .497 r
.21351 .66766 m .21345 .66815 L .2131 .66779 L F
.659 .275 0 r
.21352 .66766 m .21351 .66766 L .21345 .66768 L F
.544 .302 .499 r
.21522 .66454 m .21349 .66786 L .21352 .66765 L F
.659 .275 0 r
.21529 .66792 m .2157 .66867 L .21566 .66859 L F
.21522 .66775 m .21566 .66859 L .215 .66717 L F
.21529 .66792 m .21566 .66859 L .21522 .66775 L F
.581 .587 .823 r
.21342 .66769 m .21517 .66765 L .2134 .66764 L F
.21517 .66765 m .21586 .66763 L .21516 .66763 L F
.21517 .66765 m .21516 .66763 L .2134 .66764 L F
.21586 .66763 m .21623 .66762 L .21586 .66762 L F
.21586 .66763 m .21586 .66762 L .2134 .66764 L F
.659 .275 0 r
.21524 .66779 m .21522 .66775 L .21344 .66769 L F
.21522 .66775 m .21344 .66769 L .21344 .66769 L F
.581 .587 .823 r
.2149 .66774 m .21623 .66762 L .21342 .66769 L F
.133 .002 .423 r
.21377 .66112 m .2134 .66503 L .21201 .66463 L F
.681 .461 .581 r
.21522 .66454 m .2134 .66503 L .21377 .66112 L F
.581 .587 .823 r
.2134 .66764 m .21623 .66762 L .21335 .66361 L F
.21332 .66768 m .21335 .66361 L .21179 .66408 L F
.2134 .66786 m .2134 .66769 L .21332 .66768 L F
.2134 .66769 m .21335 .66361 L .21332 .66768 L F
.659 .275 0 r
.21347 .66768 m .21345 .66768 L .21342 .66769 L F
.768 .325 .198 r
.21311 .66767 m .21239 .6672 L .2133 .66763 L F
.765 .319 .192 r
.21276 .66738 m .2134 .66786 L .2133 .66763 L F
.659 .275 0 r
.21344 .66769 m .21342 .66769 L .2131 .66779 L F
.21347 .66768 m .21342 .66769 L .21344 .66769 L F
.21529 .66792 m .21524 .66779 L .2131 .66779 L F
.21524 .66779 m .21344 .66769 L .2131 .66779 L F
.765 .319 .192 r
.2093 .66471 m .21276 .66738 L .21179 .66408 L F
.21276 .66738 m .2133 .66763 L .21179 .66408 L F
.20878 .66485 m .20986 .66556 L .2093 .66471 L F
0 0 0 r
.21045 .66138 m .20861 .66388 L .21239 .65982 L F
.20861 .66388 m .20854 .66396 L .2086 .6639 L F
.20861 .66388 m .2086 .6639 L .21239 .65982 L F
.866 .439 .011 r
.20861 .66388 m .2086 .66395 L .20859 .66394 L F
.459 .082 .234 r
.20768 .66326 m .20776 .66321 L .20854 .66396 L F
.866 .439 .011 r
.20897 .66253 m .20861 .6639 L .20861 .66388 L F
.20861 .6639 m .2086 .6639 L .20861 .66388 L F
.459 .082 .234 r
.20776 .66321 m .20811 .66349 L .20854 .66396 L F
.866 .439 .011 r
.20897 .66253 m .20811 .66349 L .20854 .66396 L F
.459 .082 .234 r
.20811 .66349 m .2086 .6639 L .20854 .66396 L F
.512 .781 .993 r
.20878 .66485 m .20842 .66402 L .20768 .66326 L F
.747 .242 .015 r
.20831 .66378 m .20878 .66485 L .20801 .66361 L F
.20992 .66472 m .20878 .66485 L .20831 .66378 L F
.512 .781 .993 r
.20878 .66485 m .20887 .66449 L .20842 .66402 L F
.866 .439 .011 r
.20811 .66349 m .20806 .66354 L .20854 .66396 L F
.66 .154 0 r
.20768 .66326 m .20854 .66396 L .20826 .66378 L F
.512 .781 .993 r
.20887 .66449 m .20826 .66378 L .20768 .66326 L F
.66 .154 0 r
.20768 .66326 m .20826 .66378 L .20801 .66361 L F
.512 .781 .993 r
.20826 .66378 m .20778 .66321 L .20768 .66326 L F
.866 .439 .011 r
.20806 .66354 m .20826 .66378 L .20854 .66396 L F
.20897 .66253 m .20854 .66396 L .20861 .66388 L F
.20897 .66253 m .20859 .66394 L .20831 .66378 L F
.20806 .66354 m .20801 .66361 L .20826 .66378 L F
.20806 .66354 m .20831 .66378 L .20801 .66361 L F
.20897 .66253 m .20831 .66378 L .20806 .66354 L F
.20897 .66253 m .20861 .66388 L .21045 .66138 L F
.459 .082 .234 r
.20776 .66321 m .21239 .65982 L .2086 .6639 L F
.512 .781 .993 r
.20806 .66354 m .20843 .66322 L .20782 .66326 L F
.459 .082 .234 r
.20768 .66326 m .20924 .66316 L .21064 .66167 L F
.20924 .66316 m .20975 .66311 L .21239 .65982 L F
.725 .212 0 r
.21335 .66361 m .21021 .66255 L .21179 .66408 L F
0 0 0 r
.21239 .65982 m .20975 .66311 L .21274 .65942 L F
.512 .781 .993 r
.20878 .66485 m .21042 .66303 L .20924 .66316 L F
0 0 0 r
.20975 .66311 m .20973 .66313 L .20976 .66309 L F
.20975 .66311 m .20976 .66309 L .21274 .65942 L F
.20973 .66313 m .20994 .66287 L .21274 .65942 L F
.459 .082 .234 r
.21043 .66125 m .21064 .66167 L .21239 .65982 L F
.20768 .66326 m .21064 .66167 L .21043 .66125 L F
.837 .788 .804 r
.21274 .65942 m .20995 .66286 L .2083 .6611 L F
.512 .781 .993 r
.20924 .66316 m .20975 .66311 L .20961 .66269 L F
.20924 .66316 m .20961 .66269 L .20939 .66259 L F
0 0 0 r
.20973 .66313 m .20935 .66361 L .20994 .66287 L F
.459 .082 .234 r
.20924 .66316 m .20973 .66313 L .20975 .66311 L F
.837 .788 .804 r
.20995 .66286 m .20935 .66361 L .2088 .6623 L F
.439 .619 .927 r
.2083 .6611 m .20768 .66326 L .20918 .66246 L F
.837 .788 .804 r
.20995 .66286 m .20921 .6625 L .2083 .6611 L F
.439 .619 .927 r
.2083 .6611 m .20918 .66246 L .20947 .6623 L F
.837 .788 .804 r
.20921 .6625 m .2088 .6623 L .2083 .6611 L F
.512 .781 .993 r
.20939 .66259 m .20961 .66269 L .20947 .6623 L F
.20975 .66311 m .21042 .66303 L .21005 .66275 L F
.20975 .66311 m .21005 .66275 L .20947 .6623 L F
.725 .212 0 r
.21021 .66255 m .20947 .6623 L .21005 .66275 L F
.21021 .66255 m .21005 .66275 L .21179 .66408 L F
.21335 .66361 m .21199 .66406 L .21178 .66391 L F
.21127 .66291 m .21178 .66391 L .20947 .6623 L F
.21335 .66361 m .21178 .66391 L .21127 .66291 L F
.512 .781 .993 r
.20878 .66485 m .21179 .66408 L .21042 .66303 L F
.866 .439 .011 r
.20861 .6639 m .2086 .66395 L .2086 .6639 L F
.512 .781 .993 r
.20891 .66436 m .20947 .6623 L .20806 .66354 L F
.459 .082 .234 r
.20768 .66326 m .20935 .66361 L .20973 .66313 L F
.512 .781 .993 r
.20782 .66326 m .20947 .6623 L .20778 .66321 L F
.20843 .66322 m .20947 .6623 L .20782 .66326 L F
.20887 .66449 m .20891 .66436 L .20806 .66354 L F
.625 .943 .732 r
.5268 .51395 m .52709 .51301 L .52892 .51243 L F
.5268 .51395 m .52531 .51459 L .52709 .51301 L F
.929 .58 .346 r
.7717 .42989 m .7721 .43155 L .77045 .42956 L F
.825 .957 .62 r
.59409 .4949 m .59274 .49649 L .59343 .49468 L F
.665 .625 .8 r
.59579 .49164 m .59409 .4949 L .59343 .49468 L F
.59579 .49164 m .59705 .49516 L .59409 .4949 L F
.313 .229 .599 r
.42359 .64052 m .42395 .64313 L .42237 .64342 L F
.644 .103 0 r
.42237 .64342 m .42419 .64496 L .42479 .64445 L F
.316 .243 .614 r
.42395 .64313 m .42419 .64496 L .42237 .64342 L F
.364 .115 .397 r
.24481 .62652 m .24427 .62882 L .24226 .62944 L F
.24 .007 .346 r
.24341 .63081 m .24226 .62944 L .24427 .62882 L F
.24341 .63081 m .24174 .6317 L .24226 .62944 L F
.451 .841 .982 r
.23384 .54065 m .2362 .54012 L .23803 .54086 L F
.226 .667 .954 r
.23857 .53991 m .23803 .54086 L .2362 .54012 L F
.23857 .53991 m .24007 .54083 L .23803 .54086 L F
.619 .162 .146 r
.44009 .63155 m .43626 .6316 L .43817 .63258 L F
.217 0 .336 r
.24589 .6279 m .24481 .62652 L .24668 .6259 L F
.24589 .6279 m .24427 .62882 L .24481 .62652 L F
.601 .752 .95 r
.19207 .63978 m .18802 .63889 L .19014 .63815 L F
.578 .736 .95 r
.19383 .63919 m .19207 .63978 L .19014 .63815 L F
.019 .582 .8 r
.22793 .5405 m .23019 .54067 L .23211 .54109 L F
.179 .709 .848 r
.23019 .54067 m .23384 .54065 L .23211 .54109 L F
.181 0 0 r
.74226 .43401 m .74391 .43429 L .74537 .43374 L F
0 0 0 r
.74537 .43374 m .74653 .43355 L .74708 .4321 L F
.74537 .43374 m .74391 .43429 L .74653 .43355 L F
.486 .213 .424 r
.41208 .61907 m .41052 .61758 L .41164 .61672 L F
.41208 .61907 m .4097 .61967 L .41052 .61758 L F
.684 .67 .83 r
.46173 .5624 m .46023 .56372 L .4586 .56063 L F
.678 .845 .963 r
.64201 .40285 m .63855 .4027 L .6409 .40163 L F
.251 .549 .928 r
.26121 .54516 m .26193 .54758 L .25936 .54562 L F
.26121 .54516 m .26353 .54772 L .26193 .54758 L F
0 0 0 r
.59357 .52191 m .59563 .51879 L .59518 .52062 L F
0 0 .061 r
.59331 .52379 m .59357 .52191 L .59518 .52062 L F
.778 .693 .771 r
.66533 .41023 m .66813 .40735 L .66648 .40533 L F
.01 .343 .822 r
.66813 .40735 m .66918 .40669 L .67023 .40553 L F
0 .365 .756 r
.66813 .40735 m .67182 .40915 L .67018 .40863 L F
.01 .343 .822 r
.66813 .40735 m .67018 .40863 L .66918 .40669 L F
.479 .12 .277 r
.6217 .42407 m .62194 .42539 L .6191 .42576 L F
.832 .775 .797 r
.46896 .5756 m .4655 .57638 L .46773 .57474 L F
.46896 .5756 m .46648 .57852 L .4655 .57638 L F
.569 .371 .573 r
.46896 .5756 m .46908 .57831 L .46648 .57852 L F
.592 .622 .851 r
.46998 .57175 m .46896 .5756 L .46773 .57474 L F
.46998 .57175 m .47168 .57556 L .46896 .5756 L F
.382 .229 .546 r
.47111 .57686 m .46896 .5756 L .47168 .57556 L F
.47111 .57686 m .46908 .57831 L .46896 .5756 L F
.98 .711 .445 r
.45989 .58333 m .4614 .58433 L .45997 .58079 L F
0 0 .078 r
.4614 .58295 m .4598 .58599 L .45989 .58333 L F
.4598 .58599 m .45971 .58615 L .45989 .58333 L F
.98 .711 .445 r
.45989 .58333 m .45997 .58079 L .4599 .5806 L F
.417 .358 .684 r
.37693 .60814 m .37714 .61184 L .3794 .61021 L F
.379 .32 .665 r
.37791 .61411 m .3794 .61021 L .37714 .61184 L F
.373 .839 .866 r
.68527 .40654 m .68627 .40676 L .68895 .40593 L F
.457 .2 .435 r
.38897 .59392 m .3911 .59525 L .39232 .59342 L F
.329 0 .083 r
.39232 .59342 m .39351 .59465 L .39476 .59312 L F
.39232 .59342 m .3911 .59525 L .39351 .59465 L F
.518 .628 .899 r
.74214 .43687 m .74391 .43429 L .74226 .43401 L F
.74214 .43687 m .74504 .43694 L .74391 .43429 L F
.42 .667 .964 r
.74754 .39607 m .74932 .39706 L .74837 .39554 L F
.501 .716 .968 r
.74837 .39554 m .74932 .39706 L .7509 .39523 L F
.513 .735 .974 r
.7509 .39523 m .74932 .39706 L .75198 .39654 L F
.365 .07 .325 r
.24101 .6338 m .23974 .63242 L .24174 .6317 L F
.24101 .6338 m .23898 .63446 L .23974 .63242 L F
.534 .377 .614 r
.45895 .57222 m .46143 .57234 L .46115 .57046 L F
.45895 .57222 m .46143 .57234 L .46115 .57046 L F
.75 .487 .534 r
.44055 .64704 m .44499 .64952 L .44418 .64711 L F
.965 .694 .469 r
.24695 .56667 m .24528 .56598 L .24562 .56418 L F
.589 .88 .993 r
.24744 .56514 m .24695 .56667 L .24893 .56614 L F
.24744 .56514 m .24528 .56598 L .24695 .56667 L F
.578 .431 .646 r
.24695 .56667 m .24957 .56855 L .24893 .56614 L F
.24695 .56667 m .24698 .56928 L .24957 .56855 L F
.926 .908 .785 r
.77292 .4186 m .77096 .41863 L .77145 .41684 L F
.77292 .4186 m .77139 .42115 L .77096 .41863 L F
.74 .755 .865 r
.77504 .41742 m .77292 .4186 L .77145 .41684 L F
.536 .43 .68 r
.41156 .62438 m .40873 .62609 L .40768 .62256 L F
.41156 .62438 m .41102 .62562 L .40873 .62609 L F
.546 .565 .825 r
.41259 .62931 m .40873 .62609 L .41102 .62562 L F
.466 .354 .642 r
.5523 .54615 m .55413 .54219 L .55147 .54262 L F
.5523 .54615 m .55461 .54543 L .55413 .54219 L F
.689 .424 .517 r
.55138 .54741 m .55461 .54543 L .5523 .54615 L F
.739 .664 .777 r
.5523 .54615 m .55147 .54262 L .54896 .54557 L F
.764 .794 .877 r
.75356 .41757 m .75099 .42005 L .75011 .41709 L F
.438 .812 .993 r
.42869 .5756 m .4272 .57488 L .42497 .57529 L F
.665 .156 .024 r
.43063 .57526 m .4272 .57488 L .42869 .5756 L F
.42 .35 .672 r
.78286 .41074 m .78247 .41481 L .78105 .41528 L F
.176 .315 .767 r
.78363 .41548 m .78105 .41528 L .78247 .41481 L F
.78363 .41548 m .78316 .41705 L .78105 .41528 L F
.322 0 .251 r
.37859 .60135 m .38058 .60077 L .38114 .59911 L F
.3 0 .169 r
.38058 .60077 m .38344 .59856 L .38114 .59911 L F
.436 .281 .572 r
.26729 .59008 m .26703 .59301 L .26506 .59355 L F
.517 .334 .571 r
.26738 .59532 m .26506 .59355 L .26703 .59301 L F
.26738 .59532 m .26513 .59583 L .26506 .59355 L F
.608 .92 .975 r
.20467 .6541 m .20433 .6555 L .2069 .65481 L F
.20467 .6541 m .20256 .65511 L .20433 .6555 L F
.681 .473 .598 r
.52804 .53675 m .52966 .53964 L .5257 .53943 L F
.795 .506 .499 r
.53068 .53958 m .52804 .53675 L .53179 .53686 L F
.53068 .53958 m .52966 .53964 L .52804 .53675 L F
.778 .693 .771 r
.66533 .41023 m .66648 .40533 L .66415 .40807 L F
.525 .653 .916 r
.6687 .40981 m .66533 .41023 L .66415 .40807 L F
.581 .412 .617 r
.5257 .53943 m .52431 .5422 L .52346 .53976 L F
.605 .366 .528 r
.42022 .59863 m .41767 .59634 L .41995 .59599 L F
0 0 0 r
.41624 .5997 m .41772 .59931 L .42022 .59863 L F
.605 .366 .528 r
.42022 .59863 m .41772 .59931 L .41767 .59634 L F
.661 .547 .714 r
.58187 .53967 m .57994 .54333 L .57927 .54022 L F
.584 .427 .634 r
.44221 .59877 m .4399 .60182 L .44012 .59942 L F
.425 0 0 r
.64991 .40308 m .64887 .40229 L .64694 .40201 L F
.64991 .40308 m .65177 .40439 L .64887 .40229 L F
.456 .305 .587 r
.58215 .54232 m .57994 .54333 L .58187 .53967 L F
.212 0 .145 r
.57929 .54477 m .57994 .54333 L .58215 .54232 L F
0 0 0 r
.50085 .57982 m .49716 .58126 L .49721 .57867 L F
.389 .561 .902 r
.45754 .55915 m .45645 .56097 L .45567 .55922 L F
.504 .71 .963 r
.45754 .55915 m .4586 .56063 L .45645 .56097 L F
.986 .84 .612 r
.6176 .48125 m .61754 .47692 L .61666 .47933 L F
.984 .708 .343 r
.61692 .48087 m .6176 .48125 L .61666 .47933 L F
.848 .8 .804 r
.67952 .44487 m .67765 .44779 L .67572 .44668 L F
.986 .846 .467 r
.67765 .44779 m .67668 .44877 L .67572 .44668 L F
.67765 .44779 m .67718 .45018 L .67668 .44877 L F
.384 .172 .463 r
.24867 .62522 m .24708 .62336 L .24907 .6227 L F
.24867 .62522 m .24668 .6259 L .24708 .62336 L F
.597 .59 .815 r
.63793 .42872 m .63855 .43232 L .64152 .43105 L F
.473 .212 .438 r
.38651 .59646 m .38884 .59593 L .38897 .59392 L F
.457 .2 .435 r
.38897 .59392 m .38884 .59593 L .3911 .59525 L F
.622 .22 .261 r
.43376 .65196 m .43185 .65446 L .42971 .65242 L F
.709 .352 .369 r
.43576 .65264 m .43185 .65446 L .43376 .65196 L F
.633 .9 .985 r
.51774 .54298 m .51377 .54435 L .51331 .54348 L F
0 0 0 r
.55474 .59952 m .554 .6007 L .55178 .6018 L F
.708 .411 .472 r
.55733 .59916 m .554 .6007 L .55474 .59952 L F
.209 0 .327 r
.22564 .6113 m .22667 .61295 L .22783 .6108 L F
.22564 .6113 m .225 .61372 L .22667 .61295 L F
.483 .276 .522 r
.22564 .6113 m .22783 .6108 L .22808 .60829 L F
.635 .434 .593 r
.24544 .57563 m .24317 .5785 L .24565 .57812 L F
.466 .385 .681 r
.24565 .57812 m .24692 .57397 L .24544 .57563 L F
.821 .847 .868 r
.68309 .45252 m .68454 .45371 L .68737 .45069 L F
.168 .692 .873 r
.19183 .55629 m .19225 .55609 L .19013 .55617 L F
.19382 .55643 m .19225 .55609 L .19183 .55629 L F
.034 0 0 r
.19436 .55523 m .1927 .55588 L .19225 .55609 L F
.13 .621 .912 r
.19187 .55706 m .19013 .55617 L .18859 .55609 L F
.168 .692 .873 r
.19382 .55643 m .19013 .55617 L .19187 .55706 L F
0 0 0 r
.19225 .55609 m .19005 .55692 L .18789 .55744 L F
.034 0 0 r
.1927 .55588 m .19005 .55692 L .19225 .55609 L F
0 0 0 r
.19225 .55609 m .19172 .55626 L .19013 .55617 L F
.19172 .55626 m .18789 .55744 L .19013 .55617 L F
.13 .621 .912 r
.18859 .55609 m .19013 .55617 L .1884 .55604 L F
.616 .287 .389 r
.4307 .64611 m .43348 .64633 L .43467 .6437 L F
.394 .062 .279 r
.43467 .6437 m .43544 .64583 L .43678 .64405 L F
.43467 .6437 m .43348 .64633 L .43544 .64583 L F
.811 .75 .795 r
.52567 .67969 m .52645 .6827 L .52885 .67969 L F
.989 .771 .518 r
.54105 .52456 m .53995 .52115 L .53768 .52417 L F
.925 .747 .642 r
.69505 .43504 m .69609 .43853 L .6945 .43728 L F
.825 .922 .9 r
.69609 .43853 m .69224 .44024 L .6945 .43728 L F
.761 .669 .761 r
.69855 .43545 m .69609 .43853 L .69505 .43504 L F
.417 .358 .684 r
.37693 .60814 m .3794 .61021 L .37884 .60764 L F
.73 .586 .694 r
.43957 .57268 m .44085 .57543 L .44336 .57334 L F
.461 .12 .3 r
.44592 .57286 m .44551 .57466 L .44336 .57334 L F
0 .213 .666 r
.44336 .57334 m .44399 .57346 L .44403 .5708 L F
.44336 .57334 m .44551 .57466 L .44399 .57346 L F
.722 .53 .631 r
.19338 .67938 m .19702 .68015 L .19673 .67682 L F
.625 .458 .637 r
.19673 .67682 m .19931 .67933 L .19971 .67666 L F
.19673 .67682 m .19702 .68015 L .19931 .67933 L F
.709 .811 .929 r
.73286 .43707 m .73679 .43683 L .73555 .43541 L F
.762 .83 .905 r
.73555 .43541 m .73679 .43683 L .73892 .43546 L F
.91 .851 .773 r
.73771 .43407 m .73892 .43546 L .74066 .43275 L F
.623 .069 0 r
.74226 .43401 m .74066 .43275 L .73892 .43546 L F
.611 .84 .987 r
.71889 .3999 m .72032 .3979 L .71788 .39835 L F
.71889 .3999 m .72141 .39905 L .72032 .3979 L F
0 0 0 r
.53369 .55804 m .53277 .55972 L .53291 .55944 L F
.53458 .55871 m .53369 .55804 L .5348 .55685 L F
.53458 .55871 m .53277 .55972 L .53369 .55804 L F
.872 .984 .702 r
.60777 .45234 m .60751 .45145 L .60989 .4497 L F
.744 .966 .687 r
.60989 .4497 m .61015 .44843 L .61101 .44946 L F
.141 .666 .878 r
.53581 .57158 m .53822 .5717 L .54012 .57213 L F
.832 .941 .577 r
.53833 .57431 m .53787 .57607 L .54012 .57213 L F
.931 .658 .501 r
.53822 .5717 m .53833 .57431 L .54012 .57213 L F
.974 .857 .464 r
.77139 .42115 m .77044 .4225 L .77096 .41863 L F
.77139 .42115 m .77086 .42365 L .77044 .4225 L F
.391 .199 .496 r
.22808 .60829 m .22783 .6108 L .22996 .60762 L F
0 0 0 r
.46908 .57831 m .46577 .58043 L .46648 .57852 L F
.406 .564 .898 r
.54784 .56902 m .54708 .56658 L .54447 .56645 L F
.782 .765 .837 r
.54784 .56902 m .54929 .56476 L .54708 .56658 L F
.54784 .56902 m .55042 .5665 L .54929 .56476 L F
.096 0 0 r
.17531 .54451 m .17959 .5434 L .17687 .54461 L F
0 0 .198 r
.75678 .40185 m .7565 .40295 L .75663 .40531 L F
.546 .335 .544 r
.56848 .54876 m .56848 .55119 L .56594 .55162 L F
.519 .343 .582 r
.57087 .54564 m .57092 .54821 L .56848 .54876 L F
.505 .303 .539 r
.57092 .54821 m .56848 .55119 L .56848 .54876 L F
.546 .083 .106 r
.43605 .56687 m .43524 .56835 L .43217 .56819 L F
0 0 0 r
.43668 .56747 m .43605 .56687 L .43825 .56621 L F
.43668 .56747 m .43524 .56835 L .43605 .56687 L F
.269 0 .019 r
.68955 .39764 m .68735 .39742 L .68613 .39851 L F
.68955 .39764 m .68983 .39672 L .68735 .39742 L F
.672 .632 .801 r
.42768 .58703 m .42512 .58764 L .42381 .58435 L F
.774 .802 .875 r
.42407 .59866 m .42121 .60062 L .42022 .59863 L F
0 0 .413 r
.76699 .41286 m .76598 .41247 L .76498 .41119 L F
.76699 .41286 m .76628 .415 L .76598 .41247 L F
.705 .784 .913 r
.50191 .53924 m .4976 .53929 L .50009 .53625 L F
0 0 .111 r
.50252 .53574 m .50191 .53924 L .50009 .53625 L F
.50252 .53574 m .5024 .53825 L .50194 .53908 L F
.467 0 0 r
.49875 .53456 m .50252 .53574 L .50009 .53625 L F
.994 .746 .418 r
.5015 .53576 m .5024 .53825 L .50252 .53574 L F
.5015 .53576 m .5024 .53825 L .50252 .53574 L F
.766 .698 .788 r
.50009 .53625 m .4976 .53929 L .49631 .53582 L F
.73 .699 .821 r
.4988 .53702 m .5024 .53825 L .5015 .53576 L F
.651 .109 0 r
.4988 .53702 m .50085 .53857 L .5024 .53825 L F
.442 .867 .936 r
.50297 .53726 m .5024 .53825 L .50085 .53857 L F
.503 .53724 m .5024 .53825 L .50297 .53726 L F
0 0 .111 r
.50194 .53908 m .5024 .53825 L .50191 .53924 L F
.18 .568 .936 r
.5024 .53825 m .50418 .53975 L .50191 .53924 L F
.609 .401 .574 r
.55974 .53705 m .56221 .53638 L .56219 .53388 L F
.57 .318 .496 r
.56221 .53638 m .56506 .53379 L .56219 .53388 L F
.587 .325 .486 r
.27297 .56552 m .27317 .56609 L .27109 .5643 L F
.658 .733 .905 r
.68782 .44241 m .68415 .44123 L .68674 .43999 L F
.593 .661 .885 r
.68926 .43959 m .68782 .44241 L .68674 .43999 L F
.68926 .43959 m .69031 .44175 L .68782 .44241 L F
.748 .776 .876 r
.73462 .39659 m .73988 .39527 L .73847 .39312 L F
.661 .737 .906 r
.73847 .39312 m .73988 .39527 L .74216 .39409 L F
.338 .109 .412 r
.25179 .61734 m .25137 .61967 L .2495 .62035 L F
.283 .069 .401 r
.25077 .62193 m .2495 .62035 L .25137 .61967 L F
.25077 .62193 m .24907 .6227 L .2495 .62035 L F
0 .441 .707 r
.24403 .54149 m .24609 .54197 L .24782 .54242 L F
.313 .751 .967 r
.24609 .54197 m .24996 .5425 L .24782 .54242 L F
.88 .843 .804 r
.46221 .58091 m .46577 .58043 L .4646 .58112 L F
0 0 0 r
.46908 .57831 m .4681 .57997 L .46577 .58043 L F
.155 0 0 r
.4681 .57997 m .4646 .58112 L .46577 .58043 L F
0 0 0 r
.19501 .65817 m .19812 .65589 L .1966 .65607 L F
.165 .685 .883 r
.19812 .65589 m .19885 .65548 L .1966 .65607 L F
.19812 .65589 m .20033 .65587 L .19885 .65548 L F
.718 .266 .175 r
.54211 .5848 m .54428 .58661 L .54539 .5859 L F
.869 .502 .351 r
.54428 .58661 m .54666 .58737 L .54539 .5859 L F
.406 .2 .485 r
.26064 .60222 m .26036 .60469 L .25837 .6053 L F
.432 .263 .55 r
.26036 .60469 m .26029 .60721 L .25837 .6053 L F
.381 .259 .586 r
.26029 .60721 m .25856 .60802 L .25837 .6053 L F
.924 .716 .603 r
.49888 .54286 m .49711 .54237 L .4976 .53929 L F
.893 .528 .342 r
.49888 .54286 m .49749 .54429 L .49711 .54237 L F
.867 .483 .315 r
.49956 .54479 m .49749 .54429 L .49888 .54286 L F
.301 .209 .581 r
.54367 .60241 m .54498 .60219 L .54464 .59902 L F
.846 .685 .682 r
.54367 .60241 m .54439 .60276 L .54498 .60219 L F
.54367 .60241 m .54187 .60248 L .54439 .60276 L F
.344 0 .111 r
.40947 .6313 m .40724 .63276 L .40689 .63201 L F
.40947 .6313 m .40806 .63375 L .40724 .63276 L F
.18 0 .027 r
.41126 .63154 m .40806 .63375 L .40947 .6313 L F
.41126 .63154 m .40947 .6313 L .40946 .63184 L F
.001 0 0 r
.41259 .62931 m .40946 .63184 L .40947 .6313 L F
.965 .92 .581 r
.63697 .43301 m .63562 .43445 L .63624 .43524 L F
.592 .687 .907 r
.6002 .43831 m .60293 .43711 L .59952 .43604 L F
.777 .702 .781 r
.74945 .39943 m .74989 .40216 L .74702 .40246 L F
.62 .2 .224 r
.74702 .40246 m .74989 .40216 L .74972 .40417 L F
.427 .453 .784 r
.7526 .40095 m .74989 .40216 L .74945 .39943 L F
.127 0 .152 r
.75124 .40248 m .74989 .40216 L .7526 .40095 L F
0 .356 .77 r
.75105 .39981 m .7526 .40095 L .74945 .39943 L F
.127 0 .152 r
.74972 .40417 m .7526 .40095 L .75226 .4035 L F
.54 .392 .629 r
.75001 .40028 m .75159 .40254 L .75105 .39981 L F
.75159 .40254 m .75226 .4035 L .75197 .40261 L F
.75159 .40254 m .75197 .40261 L .75105 .39981 L F
.127 0 .152 r
.74972 .40417 m .74989 .40222 L .75124 .40248 L F
.74989 .40222 m .74989 .40216 L .75124 .40248 L F
.905 .906 .5 r
.65121 .42203 m .65225 .42087 L .65209 .41988 L F
.388 .465 .818 r
.41267 .62686 m .41259 .62931 L .41102 .62562 L F
.164 0 0 r
.41312 .63061 m .41259 .62931 L .41267 .62686 L F
.41287 .62998 m .40946 .63184 L .41259 .62931 L F
.41154 .63114 m .40946 .63184 L .41287 .62998 L F
.471 .316 .589 r
.41312 .63061 m .41126 .63154 L .40946 .63184 L F
.878 .993 .777 r
.41161 .62923 m .40969 .63201 L .41099 .63162 L F
.41129 .63136 m .41099 .63162 L .41126 .63154 L F
.41161 .62923 m .41099 .63162 L .41129 .63136 L F
.164 0 0 r
.41312 .63061 m .41154 .63114 L .41287 .62998 L F
.527 .301 .516 r
.59519 .44447 m .59778 .44396 L .59783 .44166 L F
.48 .284 .536 r
.59783 .44166 m .60016 .44103 L .6002 .43831 L F
0 0 .332 r
.59783 .44166 m .59913 .44149 L .60016 .44103 L F
.59783 .44166 m .59778 .44396 L .59913 .44149 L F
.771 .818 .889 r
.7134 .44886 m .71737 .44803 L .7158 .44653 L F
.774 .766 .846 r
.71737 .44803 m .71851 .44366 L .7158 .44653 L F
.71737 .44803 m .71921 .44689 L .71851 .44366 L F
.205 .296 .736 r
.53179 .53686 m .53381 .53866 L .53305 .53561 L F
.993 .768 .492 r
.53305 .53561 m .53381 .53866 L .53179 .53686 L F
.787 .663 .727 r
.77643 .40609 m .77561 .40896 L .77438 .40757 L F
.947 .59 .273 r
.77561 .40896 m .77594 .41104 L .77438 .40757 L F
.724 .617 .738 r
.77942 .4052 m .77561 .40896 L .77643 .40609 L F
.593 .417 .613 r
.23738 .58357 m .24079 .58418 L .24075 .58138 L F
.595 .513 .732 r
.23828 .58515 m .24079 .58418 L .23738 .58357 L F
.727 .431 .478 r
.42901 .60842 m .42906 .61065 L .42716 .60815 L F
.574 .302 .466 r
.43205 .60784 m .42906 .61065 L .42901 .60842 L F
.592 .687 .907 r
.6002 .43831 m .60253 .43749 L .60293 .43711 L F
.539 .363 .591 r
.60016 .44103 m .60253 .43749 L .6002 .43831 L F
.673 .499 .642 r
.59667 .46532 m .59672 .46812 L .59434 .46813 L F
.787 .718 .787 r
.7755 .40288 m .77643 .40609 L .77323 .40566 L F
.787 .663 .727 r
.77643 .40609 m .77276 .40873 L .77323 .40566 L F
.77643 .40609 m .77438 .40757 L .77276 .40873 L F
.716 .678 .812 r
.77942 .4052 m .77643 .40609 L .7755 .40288 L F
.327 .782 .949 r
.20007 .54025 m .20203 .53995 L .20388 .5404 L F
.201 .725 .849 r
.20203 .53995 m .20597 .53984 L .20388 .5404 L F
.445 .805 .996 r
.18924 .70052 m .19106 .69997 L .19028 .70003 L F
.719 .896 .96 r
.4371 .55918 m .43552 .56105 L .43485 .55925 L F
.955 .892 .503 r
.43449 .56306 m .43485 .55925 L .43552 .56105 L F
.123 0 .092 r
.20778 .68406 m .20703 .68268 L .20931 .68252 L F
.20778 .68406 m .2057 .68506 L .20703 .68268 L F
.549 .387 .614 r
.20906 .6797 m .20931 .68252 L .20703 .68268 L F
.345 .792 .955 r
.44312 .61673 m .44389 .61725 L .44094 .61698 L F
.44094 .61698 m .44389 .61725 L .44312 .61673 L F
.365 .805 .958 r
.44312 .61673 m .44628 .61691 L .44389 .61725 L F
.44389 .61725 m .44628 .61691 L .44312 .61673 L F
.146 0 .03 r
.22475 .64825 m .22405 .64722 L .22619 .64667 L F
.22475 .64825 m .22296 .64893 L .22405 .64722 L F
.656 .549 .722 r
.5574 .53967 m .56001 .53963 L .55974 .53705 L F
.637 .395 .534 r
.55987 .542 m .5574 .53967 L .55752 .54208 L F
.55987 .542 m .56001 .53963 L .5574 .53967 L F
.188 .72 .813 r
.76146 .4364 m .75986 .43636 L .75727 .43669 L F
.799 .989 .884 r
.76252 .43396 m .76146 .4364 L .7629 .43468 L F
.76252 .43396 m .75986 .43636 L .76146 .4364 L F
.414 .487 .826 r
.24538 .56069 m .24565 .55687 L .24418 .55721 L F
.24538 .56069 m .24682 .56042 L .24565 .55687 L F
.517 .385 .64 r
.24538 .56069 m .2481 .56282 L .24682 .56042 L F
.24538 .56069 m .24562 .56418 L .2481 .56282 L F
.312 .76 .96 r
.22227 .55349 m .21815 .55375 L .21912 .55401 L F
.276 0 .166 r
.23714 .6354 m .23611 .63724 L .23395 .63788 L F
.331 0 .197 r
.23822 .63665 m .23714 .6354 L .23898 .63446 L F
.23822 .63665 m .23611 .63724 L .23714 .6354 L F
.852 .636 .609 r
.54077 .55316 m .54557 .55367 L .5442 .55146 L F
.567 .01 0 r
.54077 .55316 m .54355 .55411 L .54557 .55367 L F
.982 .811 .597 r
.54355 .55411 m .54413 .55611 L .54557 .55367 L F
.318 0 0 r
.54544 .55264 m .5442 .55146 L .54557 .55367 L F
0 0 .316 r
.54649 .55578 m .54557 .55367 L .54413 .55611 L F
.54649 .55578 m .54544 .55264 L .54557 .55367 L F
.74 .252 .082 r
.54557 .55367 m .54649 .55578 L .54413 .55611 L F
.286 .003 .296 r
.59038 .45053 m .5878 .45334 L .58981 .45245 L F
0 0 .037 r
.59038 .45053 m .59124 .45084 L .59294 .45 L F
.59038 .45053 m .58981 .45245 L .59124 .45084 L F
.913 .867 .781 r
.61729 .44477 m .61551 .4482 L .61476 .44538 L F
.849 .907 .875 r
.61551 .4482 m .61288 .44827 L .61476 .44538 L F
.61551 .4482 m .61387 .44934 L .61288 .44827 L F
0 0 0 r
.47941 .56438 m .4815 .5638 L .48078 .56386 L F
.353 .771 .977 r
.48206 .5644 m .48078 .56386 L .48318 .56334 L F
0 0 0 r
.4815 .5638 m .48318 .56334 L .48078 .56386 L F
0 .518 .823 r
.48034 .5639 m .48078 .56386 L .48206 .5644 L F
.47854 .56337 m .48078 .56386 L .48034 .5639 L F
.353 .771 .977 r
.48206 .5644 m .48318 .56334 L .48451 .56365 L F
.654 .85 .975 r
.74504 .43694 m .74884 .437 L .74765 .43585 L F
.329 .776 .958 r
.75131 .4363 m .74765 .43585 L .74884 .437 L F
.674 .169 .036 r
.41626 .64922 m .4199 .64998 L .41856 .65098 L F
.721 .231 .077 r
.4199 .64998 m .42217 .65213 L .41856 .65098 L F
.119 .665 .825 r
.20597 .53984 m .20803 .53976 L .20994 .53999 L F
.23 .738 .886 r
.20803 .53976 m .21209 .53981 L .20994 .53999 L F
.549 .341 .55 r
.19943 .70346 m .19949 .7063 L .19641 .70664 L F
0 0 .357 r
.20018 .70526 m .19943 .70346 L .20114 .70293 L F
.20018 .70526 m .19949 .7063 L .19943 .70346 L F
.103 .038 .491 r
.27467 .57422 m .27354 .57234 L .27445 .57178 L F
.27467 .57422 m .2731 .57591 L .27354 .57234 L F
.711 .754 .886 r
.69688 .43395 m .69855 .43545 L .69505 .43504 L F
.78 .761 .836 r
.70089 .43287 m .69855 .43545 L .69688 .43395 L F
.393 0 .113 r
.50211 .5992 m .50087 .60115 L .50192 .59992 L F
.533 .889 .978 r
.50192 .59992 m .5048 .59955 L .50211 .5992 L F
.50192 .59992 m .50247 .59956 L .5048 .59955 L F
.041 0 0 r
.50256 .59956 m .50211 .5992 L .5048 .59955 L F
.533 .889 .978 r
.50247 .59956 m .5042 .59841 L .5048 .59955 L F
.041 0 0 r
.5031 .59999 m .50256 .59956 L .5048 .59955 L F
.781 .666 .737 r
.50037 .59524 m .50188 .59981 L .49703 .59847 L F
.50188 .59981 m .50192 .59992 L .5018 .59988 L F
.50188 .59981 m .5018 .59988 L .49703 .59847 L F
.041 0 0 r
.5031 .59999 m .50087 .60115 L .50154 .60009 L F
.334 .38 .76 r
.5018 .59453 m .5042 .59841 L .50226 .59969 L F
.50192 .5998 m .50226 .59969 L .50192 .59992 L F
.041 0 0 r
.50238 .59941 m .50189 .59981 L .50211 .5992 L F
.334 .38 .76 r
.5018 .59453 m .50226 .59969 L .50192 .5998 L F
.963 .753 .571 r
.5018 .59988 m .49925 .60022 L .49703 .59847 L F
.50192 .59992 m .50179 .59993 L .5018 .59988 L F
.041 0 0 r
.5018 .59983 m .50154 .60009 L .50168 .59987 L F
.5018 .59988 m .50154 .60009 L .5018 .59983 L F
.963 .753 .571 r
.50179 .59993 m .49925 .60022 L .5018 .59988 L F
.041 0 0 r
.50189 .59981 m .5018 .59988 L .5018 .59983 L F
.50189 .59981 m .50168 .59987 L .50211 .5992 L F
.5031 .59999 m .50154 .60009 L .50238 .59941 L F
.656 .771 .934 r
.72869 .4026 m .73047 .39976 L .72743 .39961 L F
.72869 .4026 m .73115 .40163 L .73047 .39976 L F
.122 .02 .455 r
.74708 .4321 m .74941 .43082 L .7493 .42821 L F
0 0 0 r
.74708 .4321 m .74653 .43355 L .74941 .43082 L F
.714 .18 0 r
.4113 .63873 m .41304 .64067 L .41496 .64104 L F
.448 0 0 r
.41304 .64067 m .41719 .64092 L .41496 .64104 L F
.384 .193 .495 r
.55409 .57432 m .55429 .57182 L .55246 .57256 L F
.002 0 0 r
.62697 .43784 m .63047 .43617 L .62651 .43533 L F
.62697 .43784 m .62978 .437 L .63047 .43617 L F
0 0 0 r
.63047 .43617 m .62978 .437 L .6322 .43467 L F
.185 .241 .688 r
.27534 .57639 m .2731 .57591 L .27467 .57422 L F
.27534 .57639 m .27398 .57821 L .2731 .57591 L F
.82 .793 .827 r
.71851 .44366 m .71921 .44689 L .72172 .444 L F
.51 .886 .97 r
.7079 .39195 m .70427 .39217 L .70657 .39157 L F
.484 .888 .941 r
.71039 .39108 m .7079 .39195 L .70657 .39157 L F
.71039 .39108 m .70657 .39157 L .709 .39088 L F
.171 0 0 r
.70888 .39096 m .70657 .39157 L .70559 .39312 L F
.709 .39088 m .70657 .39157 L .70888 .39096 L F
.51 .886 .97 r
.70427 .39217 m .70411 .39218 L .70657 .39157 L F
.514 .345 .589 r
.43385 .60408 m .43205 .60784 L .43212 .60507 L F
.624 .791 .962 r
.72141 .39905 m .72503 .39966 L .72398 .39832 L F
.411 .699 .98 r
.72398 .39832 m .72503 .39966 L .72743 .39961 L F
.11 .636 .876 r
.38366 .62871 m .38283 .62823 L .38083 .62817 L F
.911 .982 .744 r
.38527 .62484 m .38366 .62871 L .38634 .62661 L F
.38527 .62484 m .38283 .62823 L .38366 .62871 L F
.421 .25 .542 r
.25391 .61396 m .25376 .61673 L .25179 .61734 L F
.276 .057 .389 r
.25308 .61886 m .25179 .61734 L .25376 .61673 L F
.25308 .61886 m .25137 .61967 L .25179 .61734 L F
.65 .877 .982 r
.71535 .3893 m .71393 .39134 L .71288 .39022 L F
.71535 .3893 m .71642 .39034 L .71393 .39134 L F
.658 .937 .967 r
.17521 .56106 m .17756 .56129 L .1795 .56015 L F
.868 .732 .71 r
.61579 .4412 m .61729 .44477 L .61537 .44374 L F
.913 .867 .781 r
.61729 .44477 m .61476 .44538 L .61537 .44374 L F
0 0 0 r
.23011 .60516 m .23159 .60412 L .23293 .60248 L F
.281 0 .072 r
.23159 .60412 m .23497 .60175 L .23293 .60248 L F
.773 .685 .766 r
.28951 .56359 m .28549 .56326 L .28794 .56003 L F
.535 .831 .999 r
.28777 .56259 m .28549 .56326 L .28951 .56359 L F
0 0 .145 r
.29025 .55949 m .28951 .56359 L .28794 .56003 L F
.29025 .55949 m .29011 .56203 L .28951 .56359 L F
.552 .838 .998 r
.29011 .56203 m .28777 .56259 L .28951 .56359 L F
.499 .475 .761 r
.55882 .57032 m .56038 .57174 L .55719 .56994 L F
.065 .614 .831 r
.54447 .56645 m .54522 .56616 L .5437 .56545 L F
.54447 .56645 m .54708 .56658 L .54522 .56616 L F
.848 .8 .804 r
.67952 .44487 m .67572 .44668 L .67824 .44364 L F
.821 .84 .863 r
.68194 .44245 m .67952 .44487 L .67824 .44364 L F
0 0 0 r
.58933 .50385 m .59094 .5025 L .59168 .50057 L F
0 0 .052 r
.58933 .50385 m .58901 .50577 L .59094 .5025 L F
.72 .805 .918 r
.65746 .43356 m .65842 .4356 L .6609 .43324 L F
.754 .667 .766 r
.54187 .60248 m .54361 .60513 L .54017 .60529 L F
.589 .138 .15 r
.54017 .60529 m .54361 .60513 L .54244 .60686 L F
.544 .125 .197 r
.54361 .60513 m .54575 .60654 L .54244 .60686 L F
.54361 .60513 m .54622 .60521 L .54575 .60654 L F
.819 .898 .897 r
.53955 .54823 m .54176 .54453 L .53896 .54709 L F
.53955 .54823 m .54288 .54576 L .54176 .54453 L F
.795 .358 .21 r
.53918 .55023 m .5443 .55139 L .53955 .54823 L F
.689 .81 .939 r
.73207 .39009 m .72854 .38981 L .73109 .38877 L F
.662 .839 .968 r
.73457 .3889 m .73207 .39009 L .73109 .38877 L F
.26 0 .246 r
.62648 .42605 m .62343 .42951 L .62194 .42539 L F
.942 .677 .506 r
.65716 .42966 m .65539 .43195 L .6567 .42892 L F
.65716 .42966 m .65725 .43379 L .65539 .43195 L F
.842 .456 .317 r
.2069 .65481 m .2105 .65662 L .20851 .65495 L F
.2069 .65481 m .21033 .65687 L .2105 .65662 L F
.479 .65 .933 r
.2105 .65662 m .21088 .6541 L .20851 .65495 L F
.2105 .65662 m .21249 .65625 L .21088 .6541 L F
.228 0 .2 r
.42199 .57013 m .42288 .57087 L .42357 .56832 L F
.42199 .57013 m .42089 .57182 L .42288 .57087 L F
.463 .491 .801 r
.56287 .58369 m .56232 .58603 L .55981 .58226 L F
.738 .685 .8 r
.19236 .70567 m .19641 .70664 L .19497 .70273 L F
.909 .596 .11 r
.19497 .70273 m .19641 .70664 L .19558 .70552 L F
0 0 0 r
.19641 .70664 m .19642 .70743 L .19558 .70552 L F
.606 .365 .526 r
.19949 .7063 m .19618 .70868 L .19641 .70664 L F
.19949 .7063 m .19914 .70849 L .19618 .70868 L F
.83 .833 .85 r
.19621 .71129 m .19642 .70743 L .19618 .70868 L F
0 0 0 r
.19633 .70733 m .19618 .70868 L .19642 .70743 L F
.83 .833 .85 r
.19621 .71129 m .19364 .71094 L .19642 .70743 L F
.501 0 0 r
.19022 .71434 m .19246 .71456 L .19129 .71407 L F
.576 .357 .546 r
.19077 .71728 m .19246 .71456 L .19022 .71434 L F
0 0 0 r
.18573 .71494 m .18776 .71443 L .18757 .71311 L F
.895 .911 .827 r
.19024 .71376 m .19056 .71597 L .18778 .71589 L F
.19091 .71318 m .19086 .7136 L .19024 .71376 L F
.19086 .7136 m .19056 .71597 L .19024 .71376 L F
.19102 .71314 m .19056 .71597 L .19091 .71318 L F
.19281 .71218 m .19056 .71597 L .19103 .71308 L F
.19103 .71308 m .19102 .71314 L .19091 .71318 L F
.19103 .71308 m .19024 .71376 L .19115 .71226 L F
.19024 .71376 m .18778 .71589 L .18963 .71389 L F
.19024 .71376 m .18963 .71389 L .19072 .71272 L F
.19035 .71271 m .18778 .71589 L .18872 .71365 L F
.19115 .71226 m .19041 .71306 L .19035 .71271 L F
.19041 .71306 m .18778 .71589 L .19035 .71271 L F
0 0 0 r
.19049 .71335 m .19108 .71358 L .19053 .71333 L F
.18776 .71443 m .19055 .71372 L .19049 .71335 L F
.19055 .71372 m .19108 .71358 L .19049 .71335 L F
.902 .986 .753 r
.1906 .71374 m .19056 .71597 L .19217 .71325 L F
0 0 .17 r
.19078 .71498 m .19081 .71543 L .19081 .71544 L F
0 0 0 r
.18776 .71443 m .19057 .71374 L .1906 .71374 L F
.19055 .71372 m .1906 .71374 L .19111 .71358 L F
.18776 .71443 m .1906 .71374 L .19055 .71372 L F
0 0 .17 r
.1906 .71374 m .19081 .71544 L .19059 .71414 L F
.705 .355 .382 r
.19053 .71333 m .19099 .71337 L .19067 .71326 L F
0 0 0 r
.19108 .71358 m .19099 .71337 L .19053 .71333 L F
.895 .911 .827 r
.19078 .71286 m .19072 .71272 L .19115 .71226 L F
.705 .355 .382 r
.19099 .71337 m .191 .71331 L .19067 .71326 L F
.895 .911 .827 r
.19358 .71087 m .19103 .71308 L .19115 .71226 L F
0 0 0 r
.19108 .71358 m .19113 .71357 L .19099 .71337 L F
.19113 .71357 m .19138 .71339 L .19099 .71337 L F
.19108 .71358 m .19111 .71358 L .19113 .71357 L F
.705 .355 .382 r
.19099 .71337 m .19173 .71342 L .191 .71331 L F
.895 .911 .827 r
.19358 .71087 m .19281 .71218 L .19103 .71308 L F
.19024 .71376 m .19072 .71272 L .19078 .71286 L F
.727 .501 .584 r
.18775 .71281 m .19358 .71087 L .18872 .71365 L F
.18775 .71281 m .1914 .71337 L .19358 .71087 L F
.902 .986 .753 r
.19165 .71308 m .19261 .71251 L .19358 .71087 L F
.19163 .7132 m .19261 .71251 L .19165 .71308 L F
.19141 .71337 m .19261 .71251 L .19141 .71336 L F
.19141 .71336 m .19163 .7132 L .19165 .71308 L F
.19139 .71338 m .19141 .71337 L .19141 .71336 L F
.727 .501 .584 r
.1914 .71337 m .19173 .71342 L .19358 .71087 L F
.902 .986 .753 r
.19113 .71357 m .19139 .71338 L .19358 .71087 L F
.1906 .71374 m .19113 .71357 L .19358 .71087 L F
.19113 .71357 m .19217 .71325 L .19261 .71251 L F
.952 .906 .738 r
.19358 .71087 m .19173 .71342 L .19187 .71242 L F
.19358 .71087 m .19187 .71242 L .19226 .70971 L F
.681 .656 .818 r
.19226 .70971 m .19203 .71133 L .19175 .71005 L F
.19203 .71133 m .19187 .71242 L .1918 .71112 L F
.19203 .71133 m .1918 .71112 L .19175 .71005 L F
.863 .983 .848 r
.19174 .71107 m .19203 .71125 L .19175 .71005 L F
.681 .656 .818 r
.19187 .71242 m .19173 .71271 L .19175 .71005 L F
.863 .983 .848 r
.19173 .71271 m .19193 .71176 L .19174 .71107 L F
.19193 .71176 m .19203 .71125 L .19174 .71107 L F
.902 .986 .753 r
.19229 .71156 m .19253 .71182 L .19358 .71087 L F
.1906 .71358 m .1906 .71374 L .19125 .71311 L F
.19134 .71291 m .19125 .71311 L .19358 .71087 L F
.1906 .71358 m .19125 .71311 L .19134 .71291 L F
.952 .906 .738 r
.19358 .71087 m .19226 .70971 L .19364 .71094 L F
.867 .922 .862 r
.19371 .71085 m .19364 .71094 L .19286 .71024 L F
.19371 .71085 m .19286 .71024 L .19226 .70971 L F
.19642 .70743 m .19371 .71085 L .19226 .70971 L F
.336 .277 .642 r
.19268 .70997 m .19383 .71175 L .19358 .70989 L F
.758 .561 .631 r
.1939 .71196 m .1935 .71485 L .19804 .71297 L F
.855 .521 .419 r
.19621 .71129 m .19382 .71319 L .19364 .71094 L F
.336 .277 .642 r
.19383 .71175 m .194 .71201 L .19399 .71194 L F
.19383 .71175 m .19399 .71194 L .19358 .70989 L F
.19175 .71005 m .19239 .71061 L .19268 .70997 L F
.902 .986 .753 r
.19229 .71156 m .19358 .71087 L .19379 .71291 L F
.952 .906 .738 r
.19358 .71087 m .19364 .71094 L .19382 .71319 L F
.336 .277 .642 r
.19239 .71061 m .194 .71201 L .19268 .70997 L F
.902 .986 .753 r
.19221 .71282 m .19229 .71156 L .19382 .71319 L F
.19229 .71156 m .19379 .71291 L .19382 .71319 L F
.19062 .71247 m .1906 .71358 L .19253 .71182 L F
.863 .983 .848 r
.19173 .71342 m .19251 .71326 L .19188 .71235 L F
.902 .986 .753 r
.19152 .71216 m .19253 .71182 L .19166 .7119 L F
.681 .656 .818 r
.19187 .71242 m .19173 .71342 L .19173 .71271 L F
.863 .983 .848 r
.19173 .71342 m .19203 .71125 L .19173 .71271 L F
.902 .986 .753 r
.19062 .71247 m .19221 .71282 L .19251 .71326 L F
.19221 .71282 m .19382 .71319 L .19251 .71326 L F
.19166 .7119 m .19253 .71182 L .19229 .71156 L F
.19193 .71176 m .19229 .71156 L .19221 .71282 L F
.863 .983 .848 r
.19188 .71235 m .19251 .71326 L .19203 .71125 L F
.405 .278 .592 r
.19239 .71061 m .19251 .71326 L .194 .71201 L F
.19175 .71005 m .19203 .71125 L .19239 .71061 L F
.19203 .71125 m .19251 .71326 L .19239 .71061 L F
.902 .986 .753 r
.19062 .71247 m .19152 .71216 L .19166 .7119 L F
.19062 .71247 m .19193 .71176 L .19221 .71282 L F
0 0 0 r
.19113 .71357 m .19173 .71342 L .19138 .71339 L F
.19113 .71357 m .19057 .71374 L .19173 .71342 L F
.863 .983 .848 r
.19173 .71342 m .1906 .71374 L .19062 .71247 L F
0 0 .17 r
.19062 .71247 m .1906 .71374 L .1906 .71374 L F
0 0 0 r
.18776 .71443 m .19111 .71358 L .19108 .71358 L F
.18776 .71443 m .18789 .7145 L .19057 .71374 L F
.18776 .71443 m .19053 .71333 L .18757 .71311 L F
.705 .355 .382 r
.18757 .71311 m .19053 .71333 L .18775 .71281 L F
.19053 .71333 m .19067 .71326 L .18775 .71281 L F
.863 .983 .848 r
.1906 .71374 m .18789 .7145 L .19062 .71247 L F
0 0 .17 r
.19062 .71247 m .1907 .71378 L .1906 .71374 L F
.1907 .71378 m .19081 .71544 L .1906 .71374 L F
.19062 .71247 m .19078 .71501 L .19078 .71498 L F
.19078 .71501 m .19081 .71543 L .19078 .71498 L F
.19059 .71414 m .19081 .71544 L .19056 .71597 L F
0 0 0 r
.18573 .71494 m .18617 .71485 L .18776 .71443 L F
.18617 .71485 m .18789 .7145 L .18776 .71443 L F
.19642 .70743 m .19358 .70989 L .19648 .70752 L F
.487 .46 .753 r
.19642 .70743 m .19832 .70756 L .19733 .70366 L F
0 0 0 r
.19642 .70743 m .19676 .70729 L .19832 .70756 L F
.19642 .70743 m .19648 .70752 L .19676 .70729 L F
.19641 .70664 m .19633 .70733 L .19642 .70743 L F
.903 .663 .565 r
.53381 .53866 m .53567 .54178 L .53558 .53975 L F
.908 .793 .722 r
.53381 .53866 m .53558 .53975 L .53594 .537 L F
.727 .394 .416 r
.53958 .54276 m .53558 .53975 L .53567 .54178 L F
.905 .933 .821 r
.64805 .43405 m .64926 .43292 L .64822 .43191 L F
.755 .496 .541 r
.45507 .64363 m .45916 .64408 L .45547 .64304 L F
.45507 .64363 m .45879 .64637 L .45916 .64408 L F
.45916 .64408 m .45879 .64637 L .45507 .64363 L F
.39 .166 .449 r
.45916 .64408 m .45879 .64637 L .46118 .64336 L F
.45916 .64408 m .45879 .64637 L .46118 .64336 L F
.096 0 0 r
.17531 .54451 m .17752 .54424 L .17959 .5434 L F
0 0 0 r
.17752 .54424 m .18156 .54316 L .17959 .5434 L F
.476 .344 .621 r
.22304 .6144 m .22525 .61627 L .225 .61372 L F
.402 .344 .678 r
.22304 .6144 m .22362 .61702 L .22525 .61627 L F
.008 0 0 r
.49301 .58748 m .49455 .58716 L .49595 .5871 L F
.612 .497 .697 r
.45276 .64392 m .45507 .64363 L .45547 .64304 L F
.45276 .64392 m .45294 .64589 L .45507 .64363 L F
.994 .749 .433 r
.44132 .59649 m .44236 .5963 L .43859 .59584 L F
.44132 .59649 m .44221 .59877 L .44236 .5963 L F
.142 0 .151 r
.23191 .64087 m .23096 .64354 L .22922 .64369 L F
.165 0 .161 r
.23268 .64256 m .23191 .64087 L .23388 .64022 L F
.23268 .64256 m .23096 .64354 L .23191 .64087 L F
.665 .156 .024 r
.43063 .57526 m .42984 .57678 L .4272 .57488 L F
.593 .44 .643 r
.43063 .57526 m .43097 .57814 L .4342 .57736 L F
0 0 0 r
.43244 .57402 m .42984 .57678 L .43063 .57526 L F
.592 .397 .587 r
.56848 .55119 m .56594 .55404 L .56594 .55162 L F
.999 .832 .507 r
.48825 .59233 m .48701 .59447 L .48793 .59214 L F
.434 .027 .166 r
.48898 .594 m .48701 .59447 L .48825 .59233 L F
.758 .274 0 r
.48793 .59214 m .48898 .594 L .48825 .59233 L F
.751 .762 .862 r
.72695 .43819 m .73044 .43863 L .72921 .43691 L F
.746 .774 .875 r
.73044 .43863 m .73179 .43465 L .72921 .43691 L F
.73044 .43863 m .73286 .43707 L .73179 .43465 L F
.427 .163 .409 r
.5797 .46171 m .58235 .45896 L .57989 .45961 L F
.383 .138 .414 r
.40835 .58186 m .41 .58307 L .41059 .5812 L F
.40835 .58186 m .40791 .58384 L .41 .58307 L F
.779 .425 .386 r
.54447 .5892 m .54666 .58737 L .54428 .58661 L F
.48 .35 .627 r
.54666 .58737 m .54859 .59033 L .54649 .59109 L F
.779 .425 .386 r
.54447 .5892 m .54859 .59033 L .54666 .58737 L F
.6 .597 .82 r
.17704 .63335 m .18019 .63506 L .17824 .63568 L F
0 0 .079 r
.59563 .51879 m .59805 .51547 L .59695 .51718 L F
0 0 .155 r
.59805 .51547 m .59983 .51201 L .59916 .51361 L F
.62 .81 .391 r
.59695 .51718 m .59805 .51547 L .59916 .51361 L F
0 0 0 r
.42077 .61177 m .41677 .61316 L .41753 .61125 L F
.42077 .61177 m .4186 .61279 L .41677 .61316 L F
.69 .621 .774 r
.4232 .60864 m .42077 .61177 L .41987 .60794 L F
.617 .516 .717 r
.4232 .60864 m .42427 .61158 L .42077 .61177 L F
.467 .036 .136 r
.42427 .61158 m .4233 .61266 L .42077 .61177 L F
.847 .997 .772 r
.4215 .60944 m .42077 .61177 L .4233 .61266 L F
.4215 .60944 m .4186 .61279 L .42077 .61177 L F
.708 .698 .838 r
.54346 .59259 m .54734 .59291 L .54612 .59149 L F
.896 .735 .674 r
.54409 .59474 m .54734 .59291 L .54346 .59259 L F
.54409 .59474 m .54628 .59748 L .54734 .59291 L F
.752 .751 .852 r
.54854 .5906 m .55029 .59347 L .5512 .5936 L F
.55029 .59347 m .55032 .59351 L .5512 .5936 L F
.789 .767 .256 r
.55015 .59341 m .55029 .59347 L .55047 .5935 L F
.55048 .59347 m .55047 .5935 L .5512 .5936 L F
.55015 .59341 m .55047 .5935 L .55048 .59347 L F
.742 .764 .87 r
.5512 .5936 m .55032 .59351 L .55104 .59344 L F
.752 .751 .852 r
.55106 .59343 m .5512 .5936 L .55104 .59344 L F
.742 .764 .87 r
.5512 .5936 m .55104 .59344 L .55326 .5932 L F
.752 .751 .852 r
.55104 .59344 m .5512 .5936 L .5505 .59355 L F
.099 0 0 r
.55047 .59351 m .55047 .5935 L .55032 .59351 L F
.095 .641 .836 r
.55035 .5935 m .55032 .59351 L .55029 .59347 L F
.789 .767 .256 r
.54893 .59328 m .54802 .59344 L .5512 .5936 L F
.54757 .59309 m .54802 .59344 L .54893 .59328 L F
.54734 .59291 m .54628 .59748 L .54657 .59544 L F
.54658 .59537 m .54657 .59544 L .54657 .5954 L F
.54734 .59291 m .54657 .59544 L .54658 .59537 L F
.478 .269 .517 r
.54985 .59792 m .54733 .60114 L .54603 .59792 L F
.691 .967 .744 r
.54464 .59902 m .54628 .59748 L .54581 .59738 L F
.478 .269 .517 r
.54614 .59742 m .54603 .59792 L .54581 .59738 L F
0 .517 .726 r
.54628 .59748 m .54985 .59792 L .54581 .59738 L F
.478 .269 .517 r
.54985 .59792 m .54603 .59792 L .54614 .59742 L F
.789 .767 .256 r
.54734 .59291 m .54657 .5954 L .54802 .59344 L F
.867 .969 .647 r
.54802 .59344 m .54723 .59359 L .54724 .59357 L F
.099 0 0 r
.55076 .5935 m .55104 .59344 L .55047 .5935 L F
.752 .751 .852 r
.54854 .5906 m .55106 .59343 L .55069 .59351 L F
.095 .641 .836 r
.55044 .59347 m .55069 .59351 L .55032 .59351 L F
.099 0 0 r
.55449 .59349 m .55047 .5935 L .55047 .59351 L F
.752 .751 .852 r
.55044 .59347 m .55069 .59351 L .5505 .59355 L F
.54854 .5906 m .55069 .59351 L .55044 .59347 L F
.099 0 0 r
.55449 .59349 m .55326 .5932 L .55104 .59344 L F
.55449 .59349 m .55104 .59344 L .55076 .5935 L F
.095 .641 .836 r
.55137 .59312 m .55449 .59349 L .55069 .59351 L F
.55137 .59312 m .55069 .59351 L .55044 .59347 L F
.55044 .59347 m .55035 .5935 L .54854 .5906 L F
.55035 .5935 m .55029 .59347 L .54854 .5906 L F
.789 .767 .256 r
.54734 .59291 m .54757 .59309 L .55029 .59347 L F
.54734 .59291 m .55029 .59347 L .55015 .59341 L F
.752 .751 .852 r
.54854 .5906 m .55051 .59356 L .54802 .59344 L F
.095 .641 .836 r
.55137 .59312 m .55044 .59347 L .54946 .59198 L F
.54939 .59136 m .54946 .59198 L .54854 .5906 L F
.55137 .59312 m .54946 .59198 L .54939 .59136 L F
.253 0 0 r
.55148 .58954 m .54854 .5906 L .54859 .59033 L F
.481 .899 .853 r
.55155 .58928 m .54854 .5906 L .55148 .58954 L F
0 0 .524 r
.55158 .58957 m .54854 .5906 L .54934 .59018 L F
.55158 .58957 m .55137 .59312 L .54854 .5906 L F
.867 .969 .647 r
.54802 .59344 m .54934 .59018 L .54854 .5906 L F
.54802 .59344 m .54724 .59357 L .54928 .59027 L F
.567 .867 .996 r
.55033 .58811 m .55155 .58928 L .54859 .59033 L F
.422 .866 .889 r
.55155 .58928 m .55148 .58954 L .54859 .59033 L F
.672 .914 .976 r
.55033 .58811 m .54854 .5906 L .55155 .58928 L F
.867 .969 .647 r
.54929 .59031 m .54928 .59027 L .54934 .59018 L F
.54802 .59344 m .54928 .59027 L .54929 .59031 L F
.752 .751 .852 r
.5505 .59355 m .5512 .5936 L .55051 .59356 L F
.287 0 0 r
.69348 .40491 m .69481 .40365 L .69716 .4039 L F
.915 .886 .79 r
.60328 .4803 m .60117 .48449 L .59996 .48226 L F
.996 .857 .527 r
.6003 .4853 m .59996 .48226 L .60117 .48449 L F
.79 .666 .727 r
.77342 .41353 m .77504 .41742 L .77145 .41684 L F
.617 .398 .561 r
.43454 .57513 m .43706 .57491 L .4372 .57237 L F
.611 .811 .977 r
.43706 .57491 m .43957 .57268 L .4372 .57237 L F
.288 .781 .736 r
.69964 .40199 m .70056 .40177 L .70301 .40091 L F
.463 .491 .801 r
.56287 .58369 m .55981 .58226 L .56228 .58023 L F
.286 0 .113 r
.40274 .58641 m .40495 .58576 L .40566 .5845 L F
.337 0 .17 r
.40495 .58576 m .40791 .58384 L .40566 .5845 L F
.699 .383 .438 r
.42716 .60815 m .42572 .60937 L .4232 .60864 L F
.735 .241 0 r
.42716 .60815 m .42765 .60956 L .42572 .60937 L F
.42716 .60815 m .42906 .61065 L .42765 .60956 L F
.653 .946 .956 r
.67182 .40915 m .66981 .4102 L .67177 .41095 L F
.67182 .40915 m .6687 .40981 L .66981 .4102 L F
.21 .437 .862 r
.67182 .40915 m .67268 .408 L .67018 .40863 L F
.67182 .40915 m .67303 .40996 L .67268 .408 L F
.517 .32 .552 r
.59278 .44746 m .59524 .44688 L .59519 .44447 L F
.54 .386 .621 r
.59278 .44746 m .59294 .45 L .59524 .44688 L F
.549 .291 .477 r
.45094 .5687 m .45053 .57248 L .44592 .57286 L F
0 0 .183 r
.45094 .57165 m .45094 .5687 L .45215 .56803 L F
.45094 .57165 m .45053 .57248 L .45094 .5687 L F
.605 .622 .842 r
.6976 .44717 m .69885 .45048 L .70136 .44982 L F
0 0 0 r
.54069 .54227 m .54386 .5395 L .5416 .53977 L F
.53224 .5614 m .53055 .56351 L .53242 .56028 L F
.53224 .5614 m .53242 .56028 L .53291 .55944 L F
.462 .418 .724 r
.53224 .5614 m .53115 .56521 L .53055 .56351 L F
.53224 .5614 m .5347 .56636 L .53115 .56521 L F
.784 .44 .404 r
.53201 .56273 m .53224 .5614 L .53056 .56108 L F
.53254 .56334 m .53224 .5614 L .53201 .56273 L F
0 0 0 r
.53224 .5614 m .53291 .55944 L .53277 .55972 L F
.368 .216 .539 r
.2626 .599 m .26251 .60154 L .26064 .60222 L F
.46 .291 .564 r
.26251 .60154 m .26036 .60469 L .26064 .60222 L F
.52 .32 .55 r
.19971 .67666 m .19931 .67933 L .20152 .67883 L F
.14 .685 .746 r
.54288 .54576 m .543 .54563 L .54176 .54453 L F
.54288 .54576 m .54613 .54532 L .543 .54563 L F
.49 .684 .952 r
.75391 .39109 m .75058 .38977 L .75342 .38913 L F
.502 .599 .883 r
.75589 .38891 m .75391 .39109 L .75342 .38913 L F
.311 .307 .694 r
.7562 .39298 m .75391 .39109 L .75589 .38891 L F
.716 .678 .812 r
.77942 .4052 m .7755 .40288 L .77764 .40178 L F
.466 .434 .739 r
.78078 .40252 m .77942 .4052 L .77764 .40178 L F
.78078 .40252 m .78142 .40485 L .77942 .4052 L F
.453 .413 .724 r
.78191 .40859 m .77942 .4052 L .78142 .40485 L F
.557 .272 .438 r
.43745 .60212 m .43709 .60469 L .43385 .60408 L F
.489 .214 .422 r
.43957 .60398 m .43745 .60212 L .4399 .60182 L F
.43957 .60398 m .43709 .60469 L .43745 .60212 L F
.393 .671 .971 r
.17981 .6579 m .18175 .65681 L .1781 .65644 L F
.17981 .6579 m .18174 .65787 L .18175 .65681 L F
.673 .6 .766 r
.19702 .68015 m .19841 .68344 L .19931 .67933 L F
.741 .434 0 r
.77065 .43852 m .77034 .43787 L .76949 .43496 L F
.768 .996 .86 r
.77201 .43625 m .77065 .43852 L .76949 .43496 L F
.77201 .43625 m .77034 .43787 L .77065 .43852 L F
.36 .812 .942 r
.54346 .59259 m .54211 .59215 L .54196 .59278 L F
.561 .251 .4 r
.54196 .59278 m .54409 .59474 L .54346 .59259 L F
0 .135 .676 r
.54211 .59215 m .54409 .59474 L .54196 .59278 L F
0 .227 .732 r
.5041 .55147 m .50605 .55222 L .50295 .55029 L F
.5041 .55147 m .50764 .55406 L .50605 .55222 L F
.009 .332 .816 r
.4086 .63573 m .40713 .63573 L .40724 .63276 L F
.4086 .63573 m .41002 .63767 L .40713 .63573 L F
.894 .855 .797 r
.62697 .45225 m .6304 .45024 L .62928 .44917 L F
.62697 .45225 m .62833 .45348 L .6304 .45024 L F
.965 .866 .691 r
.63017 .44579 m .62928 .44917 L .6304 .45024 L F
.151 0 .172 r
.58755 .45495 m .58981 .45245 L .5878 .45334 L F
.562 .414 .637 r
.56993 .52781 m .57189 .52447 L .56938 .52489 L F
.445 .304 .595 r
.37844 .60509 m .38058 .60077 L .37859 .60135 L F
0 0 0 r
.59518 .52062 m .59563 .51879 L .59695 .51718 L F
0 .131 .649 r
.78369 .42168 m .78196 .42139 L .78384 .41911 L F
.78369 .42168 m .78281 .42338 L .78196 .42139 L F
.254 .119 .497 r
.59519 .44447 m .59675 .44526 L .59778 .44396 L F
.59519 .44447 m .59524 .44688 L .59675 .44526 L F
.611 .811 .977 r
.43706 .57491 m .44085 .57543 L .43957 .57268 L F
0 0 0 r
.50085 .57982 m .4996 .5804 L .49716 .58126 L F
.407 0 0 r
.50085 .57982 m .50306 .58039 L .4996 .5804 L F
.479 .892 .921 r
.50085 .57982 m .50394 .57881 L .50306 .58039 L F
.961 .687 .469 r
.43841 .6465 m .44055 .64704 L .43674 .64573 L F
.43841 .6465 m .44046 .64954 L .44055 .64704 L F
.75 .487 .534 r
.44055 .64704 m .44046 .64954 L .44499 .64952 L F
.135 .613 .92 r
.26795 .55017 m .26949 .5502 L .27113 .55115 L F
.094 .495 .901 r
.27133 .54999 m .27113 .55115 L .26949 .5502 L F
.27133 .54999 m .27274 .55141 L .27113 .55115 L F
.523 .58 .854 r
.27542 .55424 m .27113 .55115 L .27274 .55141 L F
0 0 0 r
.48228 .57388 m .4809 .57574 L .48346 .57189 L F
.477 .847 .989 r
.48636 .57131 m .48429 .57082 L .48346 .57189 L F
.767 .613 .688 r
.48429 .57082 m .48228 .57388 L .48346 .57189 L F
.599 .904 .984 r
.63645 .41231 m .6338 .41328 L .63492 .414 L F
.63645 .41231 m .6338 .41328 L .63492 .414 L F
0 0 0 r
.61234 .43795 m .61091 .44081 L .60983 .44151 L F
.692 .899 .971 r
.61234 .43795 m .61423 .43591 L .615 .43738 L F
.61234 .43795 m .61101 .43657 L .61423 .43591 L F
.763 .459 .471 r
.61579 .4412 m .61234 .43795 L .615 .43738 L F
.61579 .4412 m .61091 .44081 L .61234 .43795 L F
.534 .375 .611 r
.52683 .54318 m .52937 .5448 L .52959 .54236 L F
.587 .549 .778 r
.52677 .54081 m .52683 .54318 L .52959 .54236 L F
.534 .375 .611 r
.52683 .54318 m .52937 .5448 L .52959 .54236 L F
.611 .811 .977 r
.43706 .57491 m .43751 .5755 L .44085 .57543 L F
.13 0 .017 r
.22983 .64502 m .22922 .64369 L .23096 .64354 L F
.22983 .64502 m .22799 .64578 L .22922 .64369 L F
.272 .065 .405 r
.58019 .51869 m .57802 .52189 L .58017 .52111 L F
.364 .119 .403 r
.58017 .52111 m .57802 .52189 L .57772 .52401 L F
.985 .849 .624 r
.662 .43224 m .66287 .42954 L .66183 .42826 L F
.564 .825 .995 r
.20659 .67029 m .21051 .67067 L .20894 .66939 L F
.59 .419 .618 r
.37675 .62302 m .37694 .62565 L .37912 .62494 L F
.806 .706 .754 r
.54898 .5482 m .55072 .55169 L .54673 .55135 L F
.807 .545 .543 r
.54673 .55135 m .55072 .55169 L .55047 .55389 L F
.227 0 .237 r
.61607 .41164 m .6177 .41244 L .61829 .41099 L F
.61607 .41164 m .61552 .41362 L .6177 .41244 L F
.532 .264 .454 r
.74664 .41227 m .74264 .41277 L .7433 .41334 L F
.74664 .41227 m .74635 .4108 L .74264 .41277 L F
.692 .477 .591 r
.57354 .54573 m .57092 .54821 L .57087 .54564 L F
.21 0 .184 r
.58535 .47099 m .58443 .47331 L .58293 .4738 L F
.654 .314 .384 r
.58802 .47319 m .58535 .47099 L .58805 .47064 L F
.58802 .47319 m .58443 .47331 L .58535 .47099 L F
.099 0 0 r
.55449 .59349 m .55584 .59315 L .55326 .5932 L F
.978 .744 .515 r
.20786 .67622 m .20767 .67944 L .20906 .6797 L F
.503 .353 .61 r
.20906 .6797 m .2116 .68206 L .20931 .68252 L F
.553 0 0 r
.20767 .67944 m .2116 .68206 L .20906 .6797 L F
.635 .691 .885 r
.73978 .38665 m .73834 .39016 L .73747 .38758 L F
.73978 .38665 m .74102 .38921 L .73834 .39016 L F
.988 .813 .426 r
.6566 .41075 m .656 .40689 L .65542 .40887 L F
.061 .592 .864 r
.49066 .56752 m .49444 .56843 L .49247 .56819 L F
.642 .331 .43 r
.44839 .58216 m .45082 .58129 L .44878 .58042 L F
.621 .061 0 r
.54243 .58562 m .54211 .5848 L .54076 .58341 L F
.54243 .58562 m .54428 .58661 L .54211 .5848 L F
.853 .829 .823 r
.53468 .57693 m .53787 .57607 L .536 .57449 L F
.53468 .57693 m .53544 .57843 L .53787 .57607 L F
.488 .701 .964 r
.536 .57449 m .53787 .57607 L .53833 .57431 L F
.617 .774 .956 r
.72503 .38933 m .72611 .39087 L .72252 .39013 L F
.673 .83 .959 r
.72751 .3884 m .72611 .39087 L .72503 .38933 L F
.72751 .3884 m .72854 .38981 L .72611 .39087 L F
.931 .584 .349 r
.5353 .53192 m .53691 .53334 L .53641 .53083 L F
.521 .83 .513 r
.53641 .53083 m .5379 .52928 L .5353 .53192 L F
.677 .758 .912 r
.71893 .38947 m .72252 .39013 L .72004 .39119 L F
.698 .718 .195 r
.59168 .50057 m .59171 .50039 L .59274 .49649 L F
.695 .761 .266 r
.59168 .50057 m .59094 .5025 L .59171 .50039 L F
.576 .225 .338 r
.38554 .59759 m .38884 .59593 L .38651 .59646 L F
.469 .287 .551 r
.23516 .59921 m .23726 .59865 L .23738 .59611 L F
.461 .266 .529 r
.23516 .59921 m .23497 .60175 L .23726 .59865 L F
.495 .896 .934 r
.20246 .63762 m .20039 .63843 L .19855 .63824 L F
.751 .853 .926 r
.73754 .42941 m .73432 .42939 L .73637 .42798 L F
.66 .775 .934 r
.7397 .42665 m .73754 .42941 L .73637 .42798 L F
.7397 .42665 m .74081 .42819 L .73754 .42941 L F
.867 .683 .651 r
.53918 .55023 m .54077 .55316 L .5443 .55139 L F
.95 .848 .707 r
.62697 .45225 m .62718 .45563 L .62833 .45348 L F
.316 .205 .565 r
.58381 .54125 m .58187 .53967 L .58405 .53898 L F
.58381 .54125 m .58215 .54232 L .58187 .53967 L F
.369 .096 .362 r
.58187 .53967 m .58478 .53691 L .58405 .53898 L F
.357 0 .027 r
.5455 .56257 m .54797 .56233 L .54919 .56053 L F
.678 .611 .773 r
.55162 .55997 m .54781 .55637 L .54919 .56053 L F
.245 0 0 r
.5501 .56176 m .54919 .56053 L .54797 .56233 L F
.5501 .56176 m .55162 .55997 L .54919 .56053 L F
.318 0 0 r
.54544 .55264 m .54673 .55135 L .5442 .55146 L F
.379 .32 .665 r
.37791 .61411 m .37963 .61371 L .3794 .61021 L F
.39 .366 .711 r
.37791 .61411 m .38032 .61611 L .37963 .61371 L F
.99 .89 .605 r
.76554 .40452 m .76529 .40872 L .76655 .40573 L F
.992 .742 .391 r
.76558 .40183 m .76554 .40452 L .76655 .40573 L F
.269 .432 .84 r
.72939 .42717 m .72626 .42373 L .72859 .42613 L F
.72876 .42632 m .72859 .42613 L .72873 .42627 L F
.72939 .42717 m .72859 .42613 L .72876 .42632 L F
.624 .192 0 r
.72939 .42717 m .72981 .42771 L .72861 .42584 L F
.711 .545 .662 r
.72919 .42691 m .7319 .42652 L .72939 .42717 L F
.617 .78 .959 r
.73432 .42939 m .73045 .42872 L .73308 .42785 L F
.624 .192 0 r
.72939 .42717 m .73045 .42872 L .72981 .42771 L F
.638 .773 .945 r
.72939 .42717 m .73308 .42785 L .73045 .42872 L F
.578 .785 .978 r
.7319 .42652 m .73308 .42785 L .72939 .42717 L F
.711 .545 .662 r
.72929 .4269 m .73214 .42833 L .7319 .42652 L F
.62 .899 .595 r
.72873 .42627 m .72794 .42709 L .72939 .42717 L F
.711 .545 .662 r
.72794 .42709 m .72919 .42691 L .72939 .42717 L F
.893 .6 .482 r
.72794 .42709 m .7296 .42995 L .72939 .42717 L F
.711 .545 .662 r
.72794 .42709 m .73004 .42771 L .72929 .4269 L F
.73004 .42771 m .73214 .42833 L .72929 .4269 L F
.438 .225 .491 r
.50969 .53677 m .50982 .53931 L .50742 .53968 L F
.822 .763 .797 r
.50969 .53677 m .50742 .53968 L .50567 .53837 L F
.466 .324 .604 r
.24698 .56928 m .24919 .57136 L .24957 .56855 L F
.24698 .56928 m .24727 .57215 L .24919 .57136 L F
.188 .049 .449 r
.23011 .60516 m .23141 .6067 L .23159 .60412 L F
.23011 .60516 m .22996 .60762 L .23141 .6067 L F
0 .188 .715 r
.50147 .54863 m .50153 .54697 L .49956 .54479 L F
0 .118 .665 r
.50147 .54863 m .50295 .55029 L .50153 .54697 L F
.322 .758 .968 r
.21209 .53981 m .21434 .53961 L .2161 .54031 L F
.439 .835 .981 r
.21434 .53961 m .21819 .53967 L .2161 .54031 L F
.692 .477 .591 r
.57354 .54573 m .57356 .54816 L .57092 .54821 L F
.653 .404 .53 r
.57354 .54573 m .57663 .54779 L .57356 .54816 L F
.57354 .54573 m .57675 .54546 L .57663 .54779 L F
.369 .346 .702 r
.74702 .42774 m .7493 .42821 L .74854 .42563 L F
.519 .296 .516 r
.43991 .58754 m .44237 .58705 L .44243 .58446 L F
.405 .206 .494 r
.44243 .58446 m .44237 .58705 L .44451 .58615 L F
.493 .344 .607 r
.56341 .55961 m .5609 .55765 L .56333 .55698 L F
.56341 .55961 m .56107 .56017 L .5609 .55765 L F
.134 0 0 r
.18156 .54316 m .18329 .54328 L .18558 .54276 L F
.597 .951 .862 r
.18558 .54276 m .18602 .5418 L .18768 .54219 L F
.18558 .54276 m .18329 .54328 L .18602 .5418 L F
.639 .96 .92 r
.47399 .58338 m .46922 .58544 L .47237 .58437 L F
.349 0 0 r
.47516 .58405 m .47399 .58338 L .47237 .58437 L F
.47516 .58405 m .47629 .58414 L .47399 .58338 L F
.475 .199 .415 r
.39476 .59312 m .39715 .59264 L .39756 .59054 L F
.406 .14 .393 r
.39756 .59054 m .39933 .59201 L .3999 .58998 L F
.39756 .59054 m .39715 .59264 L .39933 .59201 L F
.556 .281 .454 r
.19232 .70323 m .19497 .70273 L .19564 .70062 L F
0 0 0 r
.19564 .70062 m .19497 .70273 L .19696 .69804 L F
.508 0 0 r
.47608 .56236 m .47692 .56288 L .47854 .56337 L F
.586 .033 0 r
.47692 .56288 m .48078 .56386 L .47854 .56337 L F
.774 .636 .709 r
.7721 .43155 m .77335 .43569 L .76949 .43496 L F
.79 .515 .521 r
.76949 .43496 m .77034 .43787 L .76634 .43654 L F
.654 .12 0 r
.76634 .43654 m .77034 .43787 L .76863 .43821 L F
.777 .997 .854 r
.76863 .43821 m .77034 .43787 L .77112 .43642 L F
.77054 .43654 m .77112 .43642 L .7715 .43571 L F
.76863 .43821 m .77112 .43642 L .77054 .43654 L F
.768 .996 .86 r
.77213 .4362 m .76949 .43496 L .77335 .43569 L F
.77201 .43625 m .77197 .43623 L .77213 .4362 L F
.77197 .43623 m .76949 .43496 L .77213 .4362 L F
.028 0 .459 r
.77474 .43127 m .77335 .43569 L .7721 .43155 L F
.77474 .43127 m .77494 .43401 L .77335 .43569 L F
.603 .936 .737 r
.77494 .43401 m .77201 .43625 L .77335 .43569 L F
.77 .851 .403 r
.65647 .40066 m .6555 .40299 L .65602 .40121 L F
0 0 .153 r
.6555 .40299 m .65601 .40325 L .65602 .40121 L F
.6555 .40299 m .6557 .4043 L .65601 .40325 L F
.299 .282 .672 r
.27398 .57821 m .27603 .58012 L .27421 .58047 L F
.322 .158 .497 r
.27603 .58012 m .27414 .58342 L .27421 .58047 L F
.575 .417 .63 r
.42426 .61397 m .42444 .61706 L .42198 .61719 L F
.42426 .61397 m .42444 .61706 L .42198 .61719 L F
.741 .966 .69 r
.48491 .5851 m .48358 .58717 L .48614 .58434 L F
.936 .597 .361 r
.48614 .58434 m .48597 .58652 L .48491 .5851 L F
.685 .34 .385 r
.48852 .5864 m .48614 .58434 L .48848 .58382 L F
.48852 .5864 m .48597 .58652 L .48614 .58434 L F
.213 .399 .83 r
.27603 .55258 m .27542 .55424 L .27274 .55141 L F
.27603 .55258 m .27649 .55398 L .27542 .55424 L F
.811 .663 .699 r
.42407 .59866 m .42022 .59863 L .42222 .59534 L F
.36 .059 .313 r
.57742 .46246 m .57694 .46425 L .5797 .46171 L F
.824 .785 .816 r
.71851 .44366 m .72172 .444 L .72099 .44059 L F
.808 .776 .823 r
.72099 .44059 m .72172 .444 L .72424 .44101 L F
.762 .83 .905 r
.73555 .43541 m .73892 .43546 L .73771 .43407 L F
.898 .547 .07 r
.74849 .41314 m .74929 .41384 L .75011 .41709 L F
.904 .979 .795 r
.75302 .40844 m .74929 .41384 L .74849 .41314 L F
.822 .763 .797 r
.50969 .53677 m .50567 .53837 L .50613 .53705 L F
.541 .301 .501 r
.51217 .53855 m .50982 .53931 L .50969 .53677 L F
.091 0 .371 r
.5861 .53578 m .58478 .53691 L .58633 .53335 L F
0 0 .143 r
.58405 .53898 m .58478 .53691 L .5861 .53578 L F
.001 0 0 r
.46681 .59846 m .46811 .59824 L .47013 .59702 L F
.042 0 0 r
.47013 .59702 m .47138 .59733 L .47277 .59589 L F
.47013 .59702 m .46811 .59824 L .47138 .59733 L F
.486 .186 .383 r
.60336 .42599 m .60582 .42566 L .60633 .4238 L F
.242 0 .287 r
.60633 .4238 m .60582 .42566 L .60837 .42273 L F
.05 0 0 r
.69837 .39394 m .6959 .39465 L .695 .39552 L F
.382 .107 .367 r
.51356 .5404 m .51325 .54277 L .51106 .54282 L F
0 0 .146 r
.51413 .54031 m .51356 .5404 L .51596 .54016 L F
.51413 .54031 m .51325 .54277 L .51356 .5404 L F
.731 .38 .386 r
.48241 .58126 m .47801 .58265 L .47864 .58087 L F
.48241 .58126 m .48295 .58465 L .47801 .58265 L F
.518 .82 1 r
.48168 .58118 m .481 .58034 L .47864 .58087 L F
.444 .153 .376 r
.48076 .58243 m .481 .58034 L .47864 .58087 L F
.978 .731 .319 r
.48034 .57952 m .481 .58034 L .48076 .58243 L F
.48019 .57848 m .481 .58034 L .48034 .57952 L F
.518 .82 1 r
.48241 .58126 m .481 .58034 L .48168 .58118 L F
.374 .612 .943 r
.25807 .544 m .25743 .54571 L .25631 .54403 L F
.404 .646 .955 r
.25807 .544 m .25936 .54562 L .25743 .54571 L F
0 0 .015 r
.75721 .40766 m .75686 .40902 L .75686 .41011 L F
.829 .357 .051 r
.75686 .40902 m .75862 .41109 L .75686 .41011 L F
0 0 .015 r
.75721 .40766 m .75686 .40902 L .75686 .41011 L F
.894 .923 .833 r
.61118 .49167 m .61368 .48862 L .6126 .48765 L F
.886 .899 .833 r
.61368 .48862 m .61493 .48446 L .6126 .48765 L F
.61368 .48862 m .61618 .48549 L .61493 .48446 L F
.909 .599 .112 r
.66861 .39957 m .66901 .40194 L .66777 .39822 L F
.365 .836 .85 r
.66777 .39822 m .67091 .39765 L .66861 .39957 L F
.695 .413 .492 r
.59434 .46813 m .59669 .47048 L .59454 .46984 L F
.66 .419 .545 r
.59672 .46812 m .59669 .47048 L .59434 .46813 L F
.715 .768 .895 r
.70745 .44964 m .71101 .45009 L .70984 .44847 L F
.718 .77 .893 r
.70984 .44847 m .71101 .45009 L .7134 .44886 L F
.48 .698 .965 r
.50028 .57166 m .49924 .5733 L .49794 .57197 L F
.50028 .57166 m .50194 .57313 L .49924 .5733 L F
.474 .549 .853 r
.50239 .57451 m .49924 .5733 L .50194 .57313 L F
.773 .813 .884 r
.45312 .58894 m .44929 .58974 L .4517 .5894 L F
.301 0 0 r
.45294 .58781 m .4517 .5894 L .44929 .58974 L F
0 .086 .645 r
.4125 .63915 m .4113 .63873 L .41002 .63767 L F
.4125 .63915 m .41304 .64067 L .4113 .63873 L F
0 0 .249 r
.53322 .56768 m .53265 .56613 L .53115 .56521 L F
.53322 .56768 m .53382 .56984 L .53265 .56613 L F
0 0 0 r
.20883 .635 m .20461 .6371 L .20679 .63672 L F
0 0 .123 r
.2111 .63186 m .20883 .635 L .21033 .63367 L F
.483 .83 .553 r
.21033 .63367 m .20883 .635 L .20679 .63672 L F
.331 .691 .981 r
.45468 .558 m .4526 .55876 L .4513 .55765 L F
.45468 .558 m .45567 .55922 L .4526 .55876 L F
.951 .923 .743 r
.78027 .42763 m .78074 .42744 L .77948 .42657 L F
.709 .933 .962 r
.77948 .42657 m .78074 .42744 L .78322 .42584 L F
.691 .264 0 r
.51826 .56602 m .52029 .56918 L .5193 .56784 L F
0 .022 .585 r
.52029 .56918 m .5217 .56984 L .5193 .56784 L F
.52029 .56918 m .52178 .5713 L .5217 .56984 L F
.974 .897 .682 r
.61618 .48549 m .61692 .48087 L .61493 .48446 L F
0 .116 .58 r
.51505 .56046 m .51625 .56133 L .51467 .55938 L F
.51505 .56046 m .51749 .56234 L .51625 .56133 L F
.595 .513 .732 r
.23828 .58515 m .24106 .58736 L .24079 .58418 L F
0 .196 .671 r
.40663 .64605 m .40677 .64579 L .40443 .64414 L F
0 .24 .694 r
.40663 .64605 m .40825 .64701 L .40677 .64579 L F
.937 .95 .625 r
.60774 .49598 m .60761 .49852 L .60915 .4949 L F
.875 .927 .541 r
.61047 .49088 m .60915 .4949 L .61118 .49167 L F
.61047 .49088 m .60891 .49437 L .60915 .4949 L F
.849 .967 .644 r
.60915 .4949 m .60891 .49437 L .60774 .49598 L F
.604 .775 .962 r
.43201 .56742 m .4268 .56505 L .43086 .5655 L F
.905 .92 .818 r
.43449 .56306 m .43201 .56742 L .43086 .5655 L F
.467 .265 .522 r
.44929 .58974 m .447 .59266 L .44708 .59023 L F
.162 0 .225 r
.57201 .4845 m .56998 .48587 L .57243 .48298 L F
0 0 0 r
.57144 .48531 m .56998 .48587 L .57201 .4845 L F
.57144 .48531 m .56857 .48677 L .56998 .48587 L F
.514 .345 .589 r
.43385 .60408 m .43483 .60724 L .43205 .60784 L F
.583 .384 .577 r
.43695 .60608 m .43385 .60408 L .43709 .60469 L F
.43695 .60608 m .43483 .60724 L .43385 .60408 L F
.394 .53 .875 r
.21053 .55676 m .21033 .55328 L .20847 .5537 L F
.21053 .55676 m .21218 .55654 L .21033 .55328 L F
.514 .334 .574 r
.50924 .52703 m .5123 .52389 L .51308 .5242 L F
.77 .952 .934 r
.51389 .52211 m .51308 .5242 L .5123 .52389 L F
.51389 .52211 m .51662 .522 L .51308 .5242 L F
.42 .667 .964 r
.74754 .39607 m .74837 .39554 L .74775 .39651 L F
.718 .701 .833 r
.70723 .43464 m .70477 .43543 L .70346 .4322 L F
.67 .874 .975 r
.74511 .39723 m .74381 .39942 L .7423 .39832 L F
.985 .725 .449 r
.74361 .40205 m .74381 .39942 L .7423 .39832 L F
.656 .219 .2 r
.54614 .54107 m .54774 .53957 L .54386 .5395 L F
.874 .533 .402 r
.54614 .54107 m .54843 .54211 L .54774 .53957 L F
.407 .214 .504 r
.23611 .63724 m .23388 .64022 L .23395 .63788 L F
.775 .724 .806 r
.54896 .54557 m .54843 .54211 L .54785 .54457 L F
.54896 .54557 m .55147 .54262 L .54843 .54211 L F
.672 .632 .801 r
.42768 .58703 m .42381 .58435 L .42616 .58359 L F
.735 .762 .874 r
.42616 .58359 m .42796 .58485 L .43 .58411 L F
.773 .706 .788 r
.43 .58411 m .42768 .58703 L .42616 .58359 L F
.522 .347 .585 r
.43 .58411 m .42994 .5871 L .42768 .58703 L F
.755 .626 .717 r
.42994 .5871 m .4283 .58848 L .42768 .58703 L F
.412 .451 .791 r
.51325 .54277 m .51331 .54348 L .51106 .54282 L F
.94 .776 .651 r
.54929 .56476 m .55042 .5665 L .54837 .56287 L F
.6 .688 .904 r
.55042 .5665 m .5505 .56235 L .54837 .56287 L F
.55042 .5665 m .55287 .5659 L .5505 .56235 L F
.507 .278 .503 r
.55042 .5665 m .55294 .56818 L .55287 .5659 L F
.777 .826 .891 r
.63094 .42583 m .63123 .42852 L .6322 .42732 L F
.706 .859 .955 r
.63094 .42583 m .6322 .42732 L .6339 .42597 L F
.57 .318 .496 r
.56221 .53638 m .56483 .53592 L .56506 .53379 L F
.5 .292 .529 r
.56483 .53592 m .56732 .53304 L .56506 .53379 L F
.613 .797 .97 r
.18849 .6369 m .18802 .63889 L .18635 .63742 L F
.18849 .6369 m .19014 .63815 L .18802 .63889 L F
.908 .793 .722 r
.53381 .53866 m .53594 .537 L .53596 .53547 L F
.701 .974 .763 r
.73431 .39678 m .73462 .39659 L .73577 .39464 L F
.438 .456 .78 r
.73577 .39464 m .73644 .39119 L .73394 .3936 L F
0 .101 .645 r
.7354 .3943 m .73577 .39464 L .73394 .3936 L F
.701 .979 .796 r
.73577 .39464 m .73628 .3951 L .73847 .39312 L F
.73577 .39464 m .73847 .39312 L .73708 .39617 L F
.438 .456 .78 r
.73577 .39464 m .73708 .39617 L .73644 .39119 L F
0 .101 .645 r
.7366 .39487 m .73577 .39464 L .7354 .3943 L F
.701 .979 .796 r
.73577 .39464 m .73462 .39659 L .73628 .3951 L F
0 0 0 r
.16161 .56576 m .16173 .56585 L .15965 .5664 L F
.46 .182 .404 r
.16173 .56585 m .15868 .56847 L .15965 .5664 L F
.868 .985 .707 r
.60598 .49951 m .60761 .49852 L .60774 .49598 L F
.60598 .49951 m .60645 .49983 L .60761 .49852 L F
.691 .587 .734 r
.48491 .5851 m .48504 .58911 L .48358 .58717 L F
.342 .071 .35 r
.58231 .51793 m .58282 .51583 L .58019 .51869 L F
0 0 .184 r
.58487 .51255 m .58282 .51583 L .58423 .51469 L F
0 0 .203 r
.58423 .51469 m .58282 .51583 L .58231 .51793 L F
.066 .55 .894 r
.67844 .45652 m .67752 .45569 L .67547 .45514 L F
.774 .96 .929 r
.67937 .45421 m .67844 .45652 L .68058 .45545 L F
.204 .268 .708 r
.27534 .57639 m .27603 .58012 L .27398 .57821 L F
.894 .923 .833 r
.61118 .49167 m .6126 .48765 L .61047 .49088 L F
.633 .667 .866 r
.439 .57563 m .43833 .57841 L .43706 .57491 L F
.439 .57563 m .44085 .57798 L .43833 .57841 L F
.474 .372 .659 r
.44076 .58045 m .43833 .57841 L .44085 .57798 L F
.44076 .58045 m .43876 .58136 L .43833 .57841 L F
.649 .49 .654 r
.24317 .5785 m .24321 .58112 L .24565 .57812 L F
.592 .789 .974 r
.62669 .41879 m .62719 .41694 L .62529 .41641 L F
.62669 .41879 m .63006 .41794 L .62719 .41694 L F
.407 .598 .923 r
.62719 .41694 m .62669 .41879 L .62529 .41641 L F
.524 .311 .533 r
.63006 .41794 m .62945 .41914 L .62669 .41879 L F
.407 .598 .923 r
.62719 .41694 m .62945 .41914 L .62669 .41879 L F
.567 .342 .534 r
.56339 .55441 m .56587 .55647 L .56333 .55698 L F
.56339 .55441 m .56594 .55404 L .56587 .55647 L F
.559 .627 .876 r
.47184 .6076 m .46977 .60839 L .46815 .60591 L F
.262 0 .205 r
.47184 .6076 m .46899 .6101 L .46977 .60839 L F
.78 .356 .242 r
.47349 .57014 m .47208 .5708 L .47009 .56862 L F
.748 .454 .485 r
.47349 .57014 m .47368 .57213 L .46998 .57175 L F
.47349 .57014 m .46998 .57175 L .47208 .5708 L F
.668 .394 .497 r
.47563 .57163 m .47368 .57213 L .47349 .57014 L F
.821 .84 .863 r
.68194 .44245 m .67824 .44364 L .6808 .44124 L F
.742 .84 .925 r
.68415 .44123 m .68194 .44245 L .6808 .44124 L F
.61 .642 .857 r
.75202 .38613 m .75058 .38977 L .74939 .38685 L F
.75202 .38613 m .75342 .38913 L .75058 .38977 L F
.91 .69 .188 r
.65843 .41618 m .65917 .42086 L .65843 .4187 L F
.991 .882 .605 r
.65843 .4187 m .65917 .42086 L .6584 .42309 L F
.658 .55 .722 r
.55974 .53705 m .56001 .53963 L .56221 .53638 L F
.572 .438 .66 r
.56001 .53963 m .56249 .539 L .56221 .53638 L F
.625 .437 .608 r
.55987 .542 m .56249 .539 L .56001 .53963 L F
.636 .766 .941 r
.74429 .38999 m .74102 .38921 L .7437 .38814 L F
.688 .809 .94 r
.74697 .38854 m .74429 .38999 L .7437 .38814 L F
.684 .67 .83 r
.46173 .5624 m .4586 .56063 L .46076 .56072 L F
.272 .731 .952 r
.46076 .56072 m .46484 .56133 L .46173 .5624 L F
.934 .942 .775 r
.60394 .44622 m .60209 .44997 L .60286 .45038 L F
.054 0 0 r
.60415 .45059 m .60286 .45038 L .60209 .44997 L F
.60415 .45059 m .60157 .45139 L .60286 .45038 L F
0 0 .381 r
.52131 .57531 m .5221 .57378 L .52178 .5713 L F
.028 .199 .705 r
.52131 .57531 m .5233 .57736 L .5221 .57378 L F
.455 .232 .485 r
.22362 .61702 m .22523 .61898 L .22525 .61627 L F
.22362 .61702 m .22311 .6195 L .22523 .61898 L F
.231 0 .317 r
.2562 .61108 m .25555 .61332 L .25391 .61396 L F
.412 .243 .539 r
.25565 .61601 m .25391 .61396 L .25555 .61332 L F
.25565 .61601 m .25376 .61673 L .25391 .61396 L F
.786 .861 .418 r
.77009 .42552 m .77004 .42491 L .77086 .42365 L F
.874 .856 .401 r
.76944 .42833 m .77004 .42491 L .77009 .42552 L F
.154 .319 .779 r
.19369 .69433 m .19628 .69638 L .19621 .69362 L F
.398 .066 .281 r
.61829 .41099 m .62077 .41036 L .62137 .40812 L F
.381 .05 .275 r
.62137 .40812 m .62317 .40968 L .62389 .40793 L F
.62137 .40812 m .62077 .41036 L .62317 .40968 L F
.617 .78 .959 r
.73432 .42939 m .7316 .43033 L .73045 .42872 L F
.399 .805 .981 r
.21819 .53967 m .22026 .53931 L .22204 .53992 L F
.071 .628 .805 r
.22026 .53931 m .22407 .53957 L .22204 .53992 L F
.436 .203 .46 r
.74764 .41163 m .74635 .4108 L .74664 .41227 L F
.488 .25 .48 r
.56728 .53056 m .56973 .53002 L .56993 .52781 L F
.562 .414 .637 r
.56993 .52781 m .572 .52751 L .57189 .52447 L F
.506 .23 .431 r
.57208 .52951 m .56993 .52781 L .56973 .53002 L F
.57208 .52951 m .572 .52751 L .56993 .52781 L F
.824 .632 .643 r
.52966 .53964 m .52959 .54236 L .53068 .53958 L F
.53068 .53958 m .52959 .54236 L .52966 .53964 L F
.52966 .53964 m .52959 .54236 L .53068 .53958 L F
.305 0 .077 r
.77438 .40757 m .77287 .40936 L .77276 .40873 L F
0 0 .571 r
.77438 .40757 m .77594 .41104 L .77588 .40939 L F
.77438 .40757 m .77588 .40939 L .77287 .40936 L F
.238 0 .328 r
.57476 .47992 m .57452 .48196 L .57243 .48298 L F
.447 .239 .503 r
.57452 .48196 m .57201 .4845 L .57243 .48298 L F
.544 .237 .397 r
.21774 .62242 m .22029 .62215 L .22095 .62013 L F
.58 .344 .523 r
.22029 .62215 m .22311 .6195 L .22095 .62013 L F
.915 .886 .79 r
.60328 .4803 m .59996 .48226 L .60172 .47902 L F
.777 .826 .891 r
.63094 .42583 m .62781 .42838 L .63123 .42852 L F
.829 .713 .737 r
.62781 .42838 m .62964 .43006 L .63123 .42852 L F
.53 .827 .999 r
.18578 .65788 m .1849 .65691 L .18395 .65708 L F
.18578 .65788 m .18842 .65722 L .1849 .65691 L F
.872 .684 .645 r
.2811 .55874 m .27763 .55638 L .27868 .5558 L F
.2811 .55874 m .27686 .55894 L .27763 .55638 L F
.774 .961 .65 r
.2811 .55874 m .27796 .5622 L .27686 .55894 L F
.2811 .55874 m .27878 .56046 L .27796 .5622 L F
.701 .248 0 r
.27905 .55626 m .27992 .55782 L .2811 .55874 L F
.27868 .5558 m .27992 .55782 L .27905 .55626 L F
.169 .034 .442 r
.28058 .5577 m .28019 .5583 L .27992 .55782 L F
.912 .961 .638 r
.27992 .55782 m .27838 .56075 L .2811 .55874 L F
.169 .034 .442 r
.28019 .5583 m .28 .55858 L .27992 .55782 L F
.28207 .55743 m .28018 .56033 L .28 .55858 L F
.28207 .55743 m .28 .55858 L .28058 .5577 L F
.774 .961 .65 r
.27878 .56046 m .27838 .56075 L .27822 .56131 L F
.27878 .56046 m .27822 .56131 L .27796 .5622 L F
0 0 0 r
.57483 .46526 m .5723 .46811 L .5741 .46651 L F
.327 .002 .253 r
.5741 .46651 m .57694 .46425 L .57483 .46526 L F
.086 0 .317 r
.21294 .62858 m .2111 .63186 L .21268 .6303 L F
0 0 .067 r
.21268 .6303 m .2111 .63186 L .21033 .63367 L F
.882 .639 .566 r
.60232 .47403 m .60016 .47487 L .60023 .47319 L F
.60232 .47403 m .6021 .47657 L .60016 .47487 L F
.622 .938 .958 r
.5448 .59066 m .54346 .59259 L .54612 .59149 L F
.5448 .59066 m .54211 .59215 L .54346 .59259 L F
.178 0 .066 r
.21294 .62858 m .21488 .62807 L .21605 .62602 L F
.272 0 .117 r
.21605 .62602 m .21522 .62909 L .21805 .62533 L F
.21605 .62602 m .21488 .62807 L .21522 .62909 L F
.703 .163 0 r
.4701 .60086 m .46681 .59846 L .46808 .60129 L F
.248 .762 .811 r
.21628 .65566 m .21473 .65577 L .21249 .65625 L F
.388 .849 .867 r
.21694 .65503 m .21628 .65566 L .21735 .65473 L F
.21694 .65503 m .21473 .65577 L .21628 .65566 L F
.503 .776 .993 r
.62651 .43533 m .62329 .4344 L .62317 .432 L F
.62651 .43533 m .62606 .43379 L .62329 .4344 L F
.636 .372 .501 r
.62475 .4371 m .62697 .43784 L .62651 .43533 L F
.181 0 .093 r
.56931 .4705 m .57167 .47001 L .5723 .46811 L F
.136 0 .077 r
.5723 .46811 m .57367 .46902 L .5741 .46651 L F
.5723 .46811 m .57167 .47001 L .57367 .46902 L F
.275 .741 .945 r
.18768 .54219 m .18996 .54204 L .18978 .54242 L F
.483 0 0 r
.18602 .5418 m .18771 .54273 L .18996 .54204 L F
.253 0 0 r
.18771 .54273 m .19014 .54166 L .18996 .54204 L F
.19014 .54166 m .19198 .54085 L .18996 .54204 L F
.275 .741 .945 r
.18978 .54242 m .18996 .54204 L .19159 .54262 L F
.688 .923 .97 r
.19159 .54262 m .19198 .54085 L .19371 .54193 L F
.19159 .54262 m .18996 .54204 L .19198 .54085 L F
.384 .782 .986 r
.55665 .57742 m .5582 .57688 L .55428 .5764 L F
.366 .519 .877 r
.55871 .57874 m .5582 .57688 L .55665 .57742 L F
.691 .445 .545 r
.5603 .58654 m .55712 .58936 L .55805 .58692 L F
.35 .568 .92 r
.39545 .63773 m .39684 .63661 L .3934 .63508 L F
.739 .215 0 r
.39906 .64067 m .39741 .64001 L .39545 .63773 L F
.161 .222 .678 r
.39545 .63773 m .39741 .64001 L .39684 .63661 L F
.787 .802 .864 r
.68857 .44715 m .68571 .44965 L .68902 .44989 L F
.773 .817 .887 r
.68571 .44965 m .68737 .45069 L .68902 .44989 L F
.777 .795 .868 r
.68857 .44715 m .68902 .44989 L .69167 .44723 L F
0 0 .537 r
.52637 .58418 m .52658 .58293 L .52511 .58067 L F
0 0 .514 r
.52637 .58418 m .52774 .58512 L .52658 .58293 L F
.52637 .58418 m .52728 .58683 L .52774 .58512 L F
.513 .331 .571 r
.65697 .39905 m .65821 .39986 L .65816 .40012 L F
0 0 0 r
.65809 .40052 m .65816 .40012 L .65963 .40039 L F
0 .499 .725 r
.65816 .40012 m .66176 .40072 L .65963 .40039 L F
.121 .607 .912 r
.65963 .40039 m .66176 .40072 L .66314 .40152 L F
.619 .096 0 r
.65816 .40012 m .66095 .40164 L .66176 .40072 L F
.513 .331 .571 r
.65821 .39986 m .66095 .40164 L .65816 .40012 L F
0 0 0 r
.65647 .40066 m .65816 .40012 L .65809 .40052 L F
.65647 .40066 m .65602 .40121 L .65816 .40012 L F
.247 .109 .487 r
.23738 .59611 m .23854 .59746 L .23935 .5955 L F
.23738 .59611 m .23726 .59865 L .23854 .59746 L F
.737 .71 .826 r
.71804 .42859 m .72175 .42914 L .71961 .43029 L F
.531 .391 .635 r
.26928 .58937 m .26703 .59301 L .26729 .59008 L F
0 0 .439 r
.46115 .57046 m .46221 .57093 L .46072 .56817 L F
.527 .372 .614 r
.46331 .57114 m .46143 .57234 L .46115 .57046 L F
0 0 .439 r
.46115 .57046 m .46143 .57234 L .46221 .57093 L F
.523 .284 .495 r
.57675 .54546 m .5792 .54734 L .57663 .54779 L F
.57675 .54546 m .57929 .54477 L .5792 .54734 L F
.296 .792 .79 r
.70918 .39914 m .71077 .39846 L .70821 .39897 L F
.70918 .39914 m .71169 .39839 L .71077 .39846 L F
.235 .14 .537 r
.2007 .7002 m .20079 .69754 L .19922 .69936 L F
.643 .551 .736 r
.20247 .69369 m .20309 .69705 L .20079 .69754 L F
.563 .296 .47 r
.20079 .69754 m .20254 .69941 L .19922 .69936 L F
.20079 .69754 m .20309 .69705 L .20254 .69941 L F
.574 .302 .466 r
.43205 .60784 m .43173 .61059 L .42906 .61065 L F
.415 .168 .429 r
.43397 .61 m .43205 .60784 L .43483 .60724 L F
.43397 .61 m .43173 .61059 L .43205 .60784 L F
.069 .128 .617 r
.53644 .57912 m .53544 .57843 L .53468 .57693 L F
.53644 .57912 m .53535 .58059 L .53544 .57843 L F
.821 .847 .868 r
.68309 .45252 m .68737 .45069 L .68571 .44965 L F
.369 .19 .503 r
.55898 .56335 m .56107 .56017 L .56118 .56272 L F
.469 .354 .64 r
.56118 .56272 m .56148 .56531 L .55898 .56335 L F
.432 .357 .672 r
.55898 .56335 m .56148 .56531 L .55974 .56541 L F
.351 .07 .34 r
.40274 .58641 m .4042 .58858 L .40495 .58576 L F
.40274 .58641 m .40207 .58928 L .4042 .58858 L F
.718 .701 .833 r
.70723 .43464 m .70346 .4322 L .70623 .43132 L F
.807 .791 .838 r
.70953 .43186 m .70723 .43464 L .70623 .43132 L F
.823 .993 .744 r
.54693 .50945 m .54403 .5121 L .54453 .5126 L F
.54693 .50945 m .54658 .509 L .54403 .5121 L F
.672 .867 .479 r
.54693 .50945 m .54889 .5063 L .54658 .509 L F
.407 .86 .839 r
.70158 .393 m .69837 .39394 L .70088 .39324 L F
0 0 0 r
.70411 .39218 m .70158 .393 L .70088 .39324 L F
.689 .493 .617 r
.24075 .58138 m .24345 .58375 L .24321 .58112 L F
.24075 .58138 m .24079 .58418 L .24345 .58375 L F
.358 .003 .218 r
.44193 .65202 m .44499 .64952 L .44046 .64954 L F
.727 .526 .619 r
.44499 .64952 m .44478 .65281 L .44193 .65202 L F
.725 .366 .371 r
.44193 .65202 m .44478 .65281 L .44392 .65441 L F
.358 .003 .218 r
.44193 .65202 m .4428 .65238 L .44499 .64952 L F
0 .065 .581 r
.44499 .64952 m .44792 .65248 L .44478 .65281 L F
.44499 .64952 m .44759 .65197 L .44792 .65248 L F
.611 .291 .403 r
.4428 .65238 m .44759 .65197 L .44499 .64952 L F
.365 .836 .85 r
.66777 .39822 m .67031 .3974 L .67091 .39765 L F
.106 0 0 r
.67031 .3974 m .67402 .39759 L .67091 .39765 L F
.419 .236 .524 r
.58017 .52111 m .58231 .51793 L .58019 .51869 L F
.927 .881 .77 r
.76414 .43124 m .76538 .43159 L .76503 .42872 L F
.927 .96 .646 r
.76414 .43124 m .7629 .43468 L .76538 .43159 L F
.224 .337 .77 r
.60983 .44151 m .61091 .44081 L .60795 .44012 L F
.838 .702 .713 r
.61579 .4412 m .61228 .44294 L .61091 .44081 L F
0 0 0 r
.61091 .44081 m .61061 .44175 L .61133 .44004 L F
.61091 .44081 m .61133 .44004 L .61228 .43781 L F
.224 .337 .77 r
.60983 .44151 m .61036 .44181 L .61091 .44081 L F
.61036 .44181 m .61228 .44294 L .61091 .44081 L F
.61091 .44081 m .61228 .44294 L .60983 .44151 L F
.475 .213 .436 r
.58235 .45896 m .58495 .45841 L .58518 .45563 L F
.388 .143 .416 r
.58518 .45563 m .58703 .45757 L .58755 .45495 L F
.58518 .45563 m .58495 .45841 L .58703 .45757 L F
.601 .899 .987 r
.54353 .60089 m .54464 .59902 L .54349 .59791 L F
.691 .967 .744 r
.54464 .59902 m .54581 .59738 L .54349 .59791 L F
.725 .319 .278 r
.5603 .58654 m .56415 .58716 L .56287 .58369 L F
.905 .949 .819 r
.56298 .58665 m .56415 .58716 L .56175 .59019 L F
.686 .532 .671 r
.56415 .58716 m .56475 .58987 L .56175 .59019 L F
.579 .832 .465 r
.56415 .58716 m .56527 .58566 L .56287 .58369 L F
.56415 .58716 m .56655 .58414 L .56527 .58566 L F
.183 .359 .805 r
.56527 .58566 m .56415 .58716 L .56298 .58665 L F
.56527 .58566 m .56688 .58922 L .56415 .58716 L F
.453 .379 .683 r
.56688 .58922 m .56475 .58987 L .56415 .58716 L F
.689 .701 .856 r
.69167 .44723 m .69542 .44854 L .69406 .44611 L F
.644 .641 .832 r
.69406 .44611 m .69542 .44854 L .6976 .44717 L F
.306 0 0 r
.43301 .59527 m .43563 .59562 L .431 .59561 L F
0 0 0 r
.39187 .63088 m .39171 .63145 L .39298 .62963 L F
.003 .136 .652 r
.39121 .63204 m .39155 .63496 L .39244 .63345 L F
.39062 .63137 m .39244 .63345 L .39187 .63088 L F
.39062 .63137 m .39089 .63241 L .39121 .63204 L F
.39089 .63241 m .39155 .63496 L .39121 .63204 L F
.444 .036 .17 r
.38863 .63299 m .39187 .63088 L .39244 .63345 L F
0 0 0 r
.39171 .63145 m .39127 .63301 L .39256 .63046 L F
.39171 .63145 m .39256 .63046 L .39298 .62963 L F
.302 .543 .915 r
.39155 .63496 m .3934 .63508 L .39244 .63345 L F
.47 .732 .984 r
.54613 .54532 m .54585 .54358 L .543 .54563 L F
.54613 .54532 m .54785 .54457 L .54585 .54358 L F
.728 .476 .546 r
.60043 .47064 m .59672 .46812 L .60094 .46822 L F
.60043 .47064 m .59669 .47048 L .59672 .46812 L F
.512 .631 .905 r
.64495 .43227 m .64805 .43405 L .64678 .433 L F
.905 .933 .821 r
.64805 .43405 m .64822 .43191 L .64678 .433 L F
.754 .375 .337 r
.41573 .64836 m .41626 .64922 L .41266 .64873 L F
.95 .944 .626 r
.62059 .47153 m .62164 .46755 L .62052 .46937 L F
.903 .801 .737 r
.6186 .47217 m .62059 .47153 L .62052 .46937 L F
.6186 .47217 m .61974 .47377 L .62059 .47153 L F
.538 .116 .188 r
.43544 .64583 m .43674 .64573 L .43678 .64405 L F
.495 .303 .549 r
.56728 .53056 m .56974 .53234 L .56973 .53002 L F
.56728 .53056 m .56732 .53304 L .56974 .53234 L F
.785 .949 .927 r
.51756 .52077 m .51662 .522 L .51389 .52211 L F
.561 .398 .618 r
.47575 .64018 m .47344 .64333 L .47351 .64073 L F
.47575 .64018 m .47344 .64333 L .47351 .64073 L F
.174 0 .244 r
.57723 .47687 m .57676 .47908 L .57476 .47992 L F
.542 .381 .612 r
.57676 .47908 m .57452 .48196 L .57476 .47992 L F
.454 .883 .813 r
.22881 .55322 m .22822 .55386 L .23072 .55362 L F
.876 .994 .775 r
.54453 .5126 m .54198 .51487 L .54198 .51575 L F
.54453 .5126 m .54403 .5121 L .54198 .51487 L F
.036 .033 .521 r
.78468 .42384 m .78281 .42338 L .78369 .42168 L F
.78468 .42384 m .78322 .42584 L .78281 .42338 L F
.689 .745 .894 r
.73179 .43465 m .73286 .43707 L .73555 .43541 L F
.601 .804 .978 r
.71169 .39839 m .71537 .39901 L .71428 .39765 L F
.54 .825 .998 r
.71537 .39901 m .71675 .3973 L .71428 .39765 L F
.71537 .39901 m .71788 .39835 L .71675 .3973 L F
.308 0 .261 r
.56675 .4734 m .56907 .47268 L .56931 .4705 L F
.251 0 .248 r
.56931 .4705 m .57111 .47184 L .57167 .47001 L F
.56931 .4705 m .56907 .47268 L .57111 .47184 L F
.661 .424 .55 r
.56175 .59019 m .56471 .59235 L .56218 .59265 L F
.434 .269 .556 r
.56471 .59235 m .5617 .59481 L .56218 .59265 L F
.115 .667 .769 r
.20657 .55384 m .20488 .55387 L .2024 .55409 L F
.632 .955 .929 r
.20671 .55269 m .20657 .55384 L .20847 .5537 L F
.20671 .55269 m .20488 .55387 L .20657 .55384 L F
.434 .269 .556 r
.56471 .59235 m .56481 .5949 L .5617 .59481 L F
.43 .223 .495 r
.5617 .59481 m .5646 .59757 L .56228 .5981 L F
.5617 .59481 m .56481 .5949 L .5646 .59757 L F
.538 .291 .489 r
.5617 .59481 m .56228 .5981 L .55955 .59847 L F
.521 .851 .997 r
.67023 .40553 m .67242 .40407 L .66901 .40194 L F
.67023 .40553 m .67272 .40487 L .67242 .40407 L F
.162 0 0 r
.67118 .40647 m .67023 .40553 L .66918 .40669 L F
.67118 .40647 m .67272 .40487 L .67023 .40553 L F
.709 .352 .369 r
.43576 .65264 m .43489 .65483 L .43185 .65446 L F
.604 .241 .326 r
.43795 .65453 m .43489 .65483 L .43576 .65264 L F
.598 .244 .34 r
.4388 .65284 m .43795 .65453 L .43576 .65264 L F
.78 .761 .836 r
.70089 .43287 m .69688 .43395 L .69997 .43113 L F
.567 .681 .917 r
.70346 .4322 m .70089 .43287 L .69997 .43113 L F
.966 .666 .408 r
.43834 .58685 m .4395 .58959 L .43991 .58754 L F
.417 .103 .322 r
.43991 .58754 m .44186 .58882 L .44237 .58705 L F
.43991 .58754 m .4395 .58959 L .44186 .58882 L F
.583 .531 .762 r
.52959 .54236 m .5257 .53943 L .52966 .53964 L F
0 0 .38 r
.52797 .59 m .52815 .58887 L .52728 .58683 L F
0 .187 .72 r
.52797 .59 m .53012 .59203 L .52815 .58887 L F
.535 .891 .978 r
.5048 .59955 m .506 .59841 L .5073 .59901 L F
.5048 .59955 m .5042 .59841 L .506 .59841 L F
.19 0 0 r
.5073 .59901 m .5062 .5997 L .5048 .59955 L F
.87 .993 .751 r
.5042 .59841 m .5048 .59955 L .5062 .5997 L F
.5042 .59841 m .5031 .59999 L .5048 .59955 L F
.223 0 .262 r
.57883 .47766 m .57723 .47687 L .57954 .47575 L F
.57883 .47766 m .57676 .47908 L .57723 .47687 L F
.397 0 .094 r
.45304 .58055 m .45673 .5785 L .45307 .57817 L F
.45304 .58055 m .45554 .58025 L .45673 .5785 L F
.601 .179 .213 r
.45554 .58025 m .45901 .58005 L .45673 .5785 L F
0 0 .336 r
.49631 .53582 m .4976 .53929 L .49664 .53657 L F
.962 .808 .642 r
.49711 .54237 m .49664 .53657 L .4976 .53929 L F
.616 .131 .081 r
.53644 .60514 m .54017 .60529 L .53883 .60673 L F
.598 .111 .069 r
.53883 .60673 m .54017 .60529 L .54244 .60686 L F
.763 .681 .772 r
.46166 .5881 m .4593 .5901 L .45779 .58668 L F
.46166 .5881 m .45779 .58668 L .46004 .58757 L F
0 .432 .822 r
.46254 .58786 m .46166 .5881 L .46004 .58757 L F
.46208 .58799 m .46516 .58944 L .46166 .5881 L F
.46357 .58848 m .46516 .58944 L .46208 .58799 L F
.553 .767 .977 r
.465 .58746 m .46516 .58944 L .46254 .58786 L F
.349 .339 .707 r
.465 .58746 m .464 .5916 L .46516 .58944 L F
.46467 .58885 m .46543 .59188 L .464 .5916 L F
.465 .58746 m .46515 .58901 L .46467 .58885 L F
.46515 .58901 m .46543 .59188 L .46467 .58885 L F
0 .432 .822 r
.46254 .58786 m .46357 .58848 L .46208 .58799 L F
.511 .236 .434 r
.45603 .59217 m .4531 .59517 L .45364 .59281 L F
.445 .217 .473 r
.27214 .58422 m .27167 .58675 L .26957 .58723 L F
.516 .331 .568 r
.27414 .58342 m .27167 .58675 L .27214 .58422 L F
.175 0 .276 r
.56185 .47728 m .56329 .47786 L .56409 .47642 L F
.56185 .47728 m .56148 .47915 L .56329 .47786 L F
.822 .776 .27 r
.54198 .51575 m .54142 .5173 L .54208 .51807 L F
.54198 .51575 m .54198 .51487 L .54142 .5173 L F
.304 .798 .82 r
.17311 .56251 m .1695 .56327 L .17116 .56264 L F
.073 0 0 r
.42357 .56832 m .42569 .56767 L .42644 .56671 L F
.342 .078 .36 r
.42357 .56832 m .42651 .56815 L .42569 .56767 L F
.42357 .56832 m .42288 .57087 L .42651 .56815 L F
.391 0 .17 r
.4593 .5901 m .45603 .59217 L .45548 .58926 L F
.4593 .5901 m .45812 .59179 L .45603 .59217 L F
.653 .287 .339 r
.4593 .5901 m .46162 .59215 L .45812 .59179 L F
.232 0 .114 r
.54859 .59033 m .54612 .59149 L .54649 .59109 L F
.622 .295 .396 r
.42971 .65242 m .42584 .65484 L .42592 .65231 L F
.42971 .65242 m .42854 .65519 L .42584 .65484 L F
.565 .236 .369 r
.43185 .65446 m .42854 .65519 L .42971 .65242 L F
.425 .192 .456 r
.27167 .58675 m .26928 .58937 L .26957 .58723 L F
.597 .474 .683 r
.62194 .42539 m .61928 .4291 L .6191 .42576 L F
.612 .814 .978 r
.56655 .58414 m .56287 .58369 L .56582 .58329 L F
.995 .839 .487 r
.56527 .58566 m .56655 .58414 L .56582 .58329 L F
.966 .826 .404 r
.77086 .42365 m .77004 .42491 L .77044 .4225 L F
.494 .078 .179 r
.54622 .60521 m .54862 .60643 L .54575 .60654 L F
.481 .109 .256 r
.54622 .60521 m .54893 .60499 L .54862 .60643 L F
.288 .048 .366 r
.74945 .39943 m .74702 .40246 L .75001 .40028 L F
.471 .333 .611 r
.75001 .40028 m .74702 .40246 L .74972 .40417 L F
0 0 0 r
.16189 .5505 m .16287 .55018 L .16511 .54897 L F
.16511 .54897 m .16497 .54962 L .16697 .54795 L F
.16511 .54897 m .16287 .55018 L .16497 .54962 L F
.085 0 .064 r
.54893 .60499 m .55178 .6018 L .55176 .60393 L F
.385 .837 .74 r
.554 .6007 m .55352 .60083 L .55178 .6018 L F
.457 .367 .666 r
.55352 .60083 m .55176 .60393 L .55178 .6018 L F
.438 .807 .994 r
.55178 .6018 m .55352 .60083 L .54965 .60053 L F
.255 .005 .329 r
.25794 .61027 m .25555 .61332 L .2562 .61108 L F
.738 .697 .812 r
.47368 .57213 m .47168 .57556 L .46998 .57175 L F
.493 .385 .66 r
.47368 .57213 m .47383 .57588 L .47168 .57556 L F
.563 .225 .353 r
.47383 .57588 m .47111 .57686 L .47168 .57556 L F
.892 .844 .79 r
.7721 .43155 m .76819 .43369 L .77045 .42956 L F
.7721 .43155 m .76949 .43496 L .76819 .43369 L F
.596 .054 0 r
.39906 .64067 m .39974 .64177 L .39741 .64001 L F
.39906 .64067 m .40121 .64274 L .39974 .64177 L F
.669 .12 0 r
.40286 .64343 m .40121 .64274 L .39906 .64067 L F
.41 .56 .893 r
.51093 .55835 m .51192 .55619 L .50998 .55652 L F
.51093 .55835 m .51467 .55938 L .51192 .55619 L F
.608 .72 .924 r
.74047 .40195 m .74098 .40283 L .74361 .40205 L F
.443 .207 .46 r
.61076 .41741 m .61313 .41666 L .61334 .41452 L F
.381 .156 .443 r
.61334 .41452 m .61313 .41666 L .61552 .41362 L F
.821 .752 .787 r
.72099 .44059 m .72424 .44101 L .7233 .43757 L F
.757 .717 .815 r
.7233 .43757 m .72424 .44101 L .72695 .43819 L F
.132 0 .012 r
.46674 .61211 m .46697 .61099 L .46899 .6101 L F
.46624 .6122 m .46697 .61099 L .46674 .61211 L F
.46576 .61299 m .46899 .6101 L .46834 .61231 L F
.532 .405 .653 r
.46505 .60994 m .4678 .61193 L .46666 .60879 L F
.4678 .61193 m .46834 .61231 L .46813 .61187 L F
.4678 .61193 m .46813 .61187 L .46666 .60879 L F
.132 0 .012 r
.46576 .61299 m .46624 .6122 L .46674 .61211 L F
.246 .515 .908 r
.26761 .54797 m .26795 .55017 L .26547 .54787 L F
.26761 .54797 m .26949 .5502 L .26795 .55017 L F
.619 .672 .879 r
.67303 .40996 m .67743 .41121 L .67645 .40962 L F
.78 .904 .928 r
.67743 .41121 m .67833 .40853 L .67645 .40962 L F
.67743 .41121 m .68053 .40927 L .67833 .40853 L F
.226 0 .243 r
.58878 .53044 m .59146 .5276 L .59075 .52955 L F
0 0 .354 r
.59146 .5276 m .59331 .52379 L .59288 .52609 L F
0 0 0 r
.59075 .52955 m .59146 .5276 L .59288 .52609 L F
.345 .014 .253 r
.4342 .57736 m .43706 .57491 L .43454 .57513 L F
.401 .129 .381 r
.24562 .56418 m .24528 .56598 L .24744 .56514 L F
.384 .144 .423 r
.24562 .56418 m .24744 .56514 L .2481 .56282 L F
.659 .518 .681 r
.43241 .58357 m .42994 .5871 L .43 .58411 L F
.975 .817 .622 r
.67718 .45018 m .67662 .45259 L .6755 .45113 L F
.963 .929 .711 r
.67718 .45018 m .6755 .45113 L .67668 .44877 L F
.445 .211 .464 r
.58633 .53335 m .58878 .53044 L .58849 .53258 L F
.312 .089 .405 r
.58849 .53258 m .58878 .53044 L .59075 .52955 L F
.633 .9 .985 r
.51774 .54298 m .51331 .54348 L .51483 .54272 L F
.848 .911 .877 r
.51642 .54176 m .51774 .54298 L .51483 .54272 L F
.651 .483 .643 r
.57189 .52447 m .575 .52667 L .57519 .52449 L F
.57189 .52447 m .572 .52751 L .575 .52667 L F
.492 .873 .671 r
.42774 .60198 m .42904 .60085 L .43033 .60017 L F
.49 .892 .941 r
.42774 .60198 m .42638 .6018 L .42904 .60085 L F
.532 .341 .567 r
.55461 .54543 m .55752 .54208 L .55413 .54219 L F
.05 0 .17 r
.42448 .57758 m .42245 .57877 L .42497 .57529 L F
.418 .489 .826 r
.42448 .57758 m .42502 .57897 L .42245 .57877 L F
.882 .853 .81 r
.61619 .47566 m .61974 .47377 L .6186 .47217 L F
.61619 .47566 m .61754 .47692 L .61974 .47377 L F
.163 .182 .633 r
.60608 .42925 m .60582 .42566 L .60336 .42599 L F
.445 0 .081 r
.39476 .59312 m .39638 .59418 L .39715 .59264 L F
.39476 .59312 m .39351 .59465 L .39638 .59418 L F
.702 .28 .24 r
.49444 .56843 m .49665 .57064 L .49845 .56881 L F
.984 .771 .537 r
.49665 .57064 m .49794 .57197 L .49845 .56881 L F
.743 .7 .81 r
.72069 .42577 m .72175 .42914 L .71804 .42859 L F
.755 .707 .806 r
.72425 .42651 m .72175 .42914 L .72069 .42577 L F
.531 .711 .954 r
.67303 .40996 m .67503 .40762 L .67268 .408 L F
.67303 .40996 m .67645 .40962 L .67503 .40762 L F
.279 .339 .746 r
.46306 .60847 m .46505 .60994 L .46532 .609 L F
.861 .611 .56 r
.66314 .40152 m .66303 .40433 L .66648 .40533 L F
0 .157 .677 r
.66303 .40433 m .66415 .40807 L .66648 .40533 L F
.963 .805 .639 r
.61666 .47933 m .61754 .47692 L .61619 .47566 L F
.436 .193 .445 r
.61076 .41741 m .61057 .41942 L .61313 .41666 L F
.904 .979 .795 r
.75302 .40844 m .74926 .41234 L .75123 .41148 L F
.545 .119 .183 r
.75389 .41076 m .75302 .40844 L .75123 .41148 L F
.615 .698 .903 r
.75285 .40819 m .75373 .41039 L .75123 .41148 L F
.75373 .41039 m .75389 .41076 L .75123 .41148 L F
.904 .979 .795 r
.74926 .41234 m .74849 .41314 L .75123 .41148 L F
.545 .119 .183 r
.75389 .41076 m .7555 .40948 L .75302 .40844 L F
.236 0 0 r
.23647 .55495 m .23216 .55398 L .23434 .55521 L F
.111 0 0 r
.44739 .55708 m .4513 .55765 L .44914 .55813 L F
.401 .149 .413 r
.26738 .59532 m .26474 .59844 L .26513 .59583 L F
.867 .841 .818 r
.66349 .42177 m .66672 .42253 L .66574 .41882 L F
.89 .812 .766 r
.66412 .42495 m .66672 .42253 L .66349 .42177 L F
.888 .85 .801 r
.66574 .41882 m .66672 .42253 L .66721 .41992 L F
.374 .432 .792 r
.27595 .56759 m .27387 .56909 L .27317 .56609 L F
.426 .303 .609 r
.27512 .57136 m .27387 .56909 L .27595 .56759 L F
.27512 .57136 m .27445 .57178 L .27387 .56909 L F
.949 .902 .742 r
.76428 .41583 m .76628 .415 L .76699 .41286 L F
.76428 .41583 m .76529 .41697 L .76628 .415 L F
.16 0 0 r
.61416 .43237 m .61324 .43389 L .61088 .4346 L F
.547 .355 .572 r
.61687 .42931 m .61692 .43182 L .61416 .43237 L F
.495 .04 .102 r
.61646 .43359 m .61416 .43237 L .61692 .43182 L F
.61646 .43359 m .61324 .43389 L .61416 .43237 L F
.706 .421 .489 r
.4288 .57989 m .43103 .58084 L .43097 .57814 L F
.527 .274 .475 r
.43103 .58084 m .4342 .57736 L .43097 .57814 L F
.329 .776 .958 r
.75131 .4363 m .75044 .43557 L .74765 .43585 L F
.281 0 0 r
.75375 .43612 m .75044 .43557 L .75131 .4363 L F
.116 0 .307 r
.54646 .49424 m .54849 .49352 L .54889 .49089 L F
0 0 0 r
.54646 .49424 m .54575 .49616 L .54849 .49352 L F
.905 .949 .819 r
.56298 .58665 m .56175 .59019 L .56101 .58921 L F
.167 0 0 r
.56064 .59174 m .56175 .59019 L .55931 .59144 L F
.998 .824 .482 r
.56064 .59174 m .56101 .58921 L .56175 .59019 L F
.661 .424 .55 r
.56175 .59019 m .56475 .58987 L .56471 .59235 L F
.77 .78 .862 r
.19621 .71129 m .19804 .71297 L .19919 .71128 L F
0 0 .128 r
.73512 .3972 m .73431 .39678 L .73577 .39464 L F
.73512 .3972 m .73364 .39908 L .73431 .39678 L F
.259 .634 .962 r
.25476 .54262 m .25347 .54348 L .25214 .54225 L F
.25476 .54262 m .25631 .54403 L .25347 .54348 L F
.199 0 .223 r
.42626 .57657 m .42497 .57529 L .4272 .57488 L F
.42626 .57657 m .42448 .57758 L .42497 .57529 L F
.003 0 .185 r
.58677 .50943 m .58487 .51255 L .58688 .51128 L F
.009 0 .196 r
.58688 .51128 m .58487 .51255 L .58423 .51469 L F
.95 .848 .707 r
.62697 .45225 m .62555 .45566 L .62718 .45563 L F
.929 .849 .743 r
.62446 .45759 m .62718 .45563 L .62555 .45566 L F
.62446 .45759 m .62575 .4588 L .62718 .45563 L F
.257 .016 .345 r
.26029 .60721 m .25794 .61027 L .25856 .60802 L F
.069 .128 .617 r
.53644 .57912 m .53611 .58116 L .53535 .58059 L F
0 .136 .664 r
.53611 .58116 m .5373 .58356 L .53535 .58059 L F
.768 .74 .827 r
.21218 .55654 m .21395 .55811 L .21583 .55665 L F
.47 .132 .309 r
.62389 .40793 m .62645 .40757 L .62692 .40594 L F
.402 .052 .253 r
.62645 .40757 m .62971 .40479 L .62692 .40594 L F
.45 .708 .977 r
.64152 .43105 m .64495 .43227 L .64418 .43064 L F
.316 .552 .918 r
.64495 .43227 m .64672 .431 L .64418 .43064 L F
.64495 .43227 m .64678 .433 L .64672 .431 L F
.648 .482 .645 r
.45646 .58867 m .45548 .58926 L .45312 .58894 L F
.632 .072 0 r
.40443 .64414 m .40121 .64274 L .40286 .64343 L F
.581 .601 .837 r
.17888 .63202 m .17704 .63335 L .17655 .63188 L F
.17888 .63202 m .18019 .63506 L .17704 .63335 L F
.706 .625 .764 r
.62194 .42539 m .62343 .42951 L .61928 .4291 L F
.724 .515 .607 r
.62343 .42951 m .61936 .4317 L .61928 .4291 L F
.62343 .42951 m .62317 .432 L .61936 .4317 L F
.158 .648 .919 r
.22407 .53957 m .22643 .53967 L .22793 .5405 L F
.21 .671 .944 r
.22643 .53967 m .23019 .54067 L .22793 .5405 L F
0 0 .394 r
.7547 .39577 m .75595 .39888 L .75579 .39793 L F
0 0 .471 r
.75595 .39888 m .75733 .39979 L .75579 .39793 L F
.75595 .39888 m .75678 .40185 L .75733 .39979 L F
.817 .771 .809 r
.6945 .43728 m .69394 .43378 L .69505 .43504 L F
.73 .891 .953 r
.69688 .43395 m .69505 .43504 L .69394 .43378 L F
.647 .297 .365 r
.60839 .43508 m .6082 .43733 L .60486 .43699 L F
.546 .212 .353 r
.61101 .43657 m .60839 .43508 L .61088 .4346 L F
.61101 .43657 m .6082 .43733 L .60839 .43508 L F
.092 .218 .704 r
.45901 .58005 m .45989 .58333 L .4599 .5806 L F
.578 .736 .95 r
.19383 .63919 m .19014 .63815 L .19232 .63783 L F
.77 .802 .879 r
.19648 .63744 m .19383 .63919 L .19232 .63783 L F
.742 .941 .614 r
.59294 .45 m .5939 .44795 L .59524 .44688 L F
.758 .98 .731 r
.59294 .45 m .59124 .45084 L .5939 .44795 L F
.59 .408 .604 r
.24565 .57812 m .24321 .58112 L .2457 .58068 L F
.466 .385 .681 r
.24565 .57812 m .24758 .57756 L .24692 .57397 L F
.492 .331 .591 r
.24565 .57812 m .24786 .58005 L .24758 .57756 L F
.24565 .57812 m .2457 .58068 L .24786 .58005 L F
.305 .202 .57 r
.52431 .5422 m .52567 .54433 L .52418 .54501 L F
.52418 .54501 m .52567 .54433 L .52431 .5422 L F
.365 .159 .461 r
.43217 .56819 m .42964 .57158 L .4299 .56926 L F
.009 .332 .816 r
.4086 .63573 m .40724 .63276 L .40806 .63375 L F
0 0 0 r
.16189 .5505 m .16101 .5511 L .16287 .55018 L F
.757 .946 .619 r
.55586 .49913 m .55508 .50095 L .55712 .4981 L F
0 0 0 r
.58901 .50577 m .58677 .50943 L .58839 .50789 L F
0 0 .167 r
.58677 .50943 m .58688 .51128 L .58839 .50789 L F
.247 0 .044 r
.22296 .64893 m .22075 .65179 L .21978 .65138 L F
0 .23 .748 r
.21978 .65138 m .22075 .65179 L .22065 .65162 L F
.103 0 0 r
.2209 .64951 m .21978 .65138 L .21878 .65111 L F
.247 0 .044 r
.22296 .64893 m .21978 .65138 L .2209 .64951 L F
0 .23 .748 r
.21978 .65138 m .22065 .65162 L .21982 .6502 L F
.103 0 0 r
.21878 .65111 m .21978 .65138 L .21714 .65235 L F
.439 .223 .488 r
.5861 .53578 m .58633 .53335 L .58849 .53258 L F
.386 .055 .277 r
.44784 .57381 m .44592 .57286 L .45053 .57248 L F
.44784 .57381 m .44551 .57466 L .44592 .57286 L F
.363 .672 .975 r
.24418 .55721 m .24462 .5558 L .24258 .55574 L F
.329 .636 .963 r
.24418 .55721 m .24565 .55687 L .24462 .5558 L F
.488 .84 .576 r
.5506 .50484 m .54954 .50581 L .55193 .50356 L F
0 0 0 r
.55248 .50385 m .55299 .50308 L .55409 .50258 L F
.55434 .5021 m .55503 .50111 L .55409 .50258 L F
.55586 .49913 m .55503 .50111 L .55434 .5021 L F
.55738 .49785 m .55503 .50111 L .55586 .49913 L F
.606 .863 .517 r
.55621 .49948 m .556 .49972 L .55503 .50111 L F
.556 .49972 m .55379 .50238 L .55503 .50111 L F
.679 .938 .652 r
.55503 .50111 m .55248 .50385 L .55409 .50258 L F
0 0 0 r
.55379 .50238 m .55194 .50469 L .55248 .50385 L F
.55194 .50469 m .55157 .50515 L .55248 .50385 L F
.55248 .50385 m .55193 .50356 L .55299 .50308 L F
.55248 .50385 m .5506 .50484 L .55193 .50356 L F
.332 .049 .325 r
.575 .52667 m .57772 .52401 L .57519 .52449 L F
.663 .919 .613 r
.42092 .64341 m .42359 .64052 L .42007 .64042 L F
.42092 .64341 m .42178 .64201 L .42359 .64052 L F
.381 .207 .516 r
.4259 .64014 m .42395 .64313 L .42359 .64052 L F
.067 0 0 r
.42359 .64052 m .42437 .64123 L .4259 .64014 L F
.42359 .64052 m .42178 .64201 L .42437 .64123 L F
.48 .539 .84 r
.38634 .62661 m .38766 .62428 L .38527 .62484 L F
.38634 .62661 m .38985 .62812 L .38766 .62428 L F
.696 .473 .58 r
.61936 .4317 m .61687 .42931 L .61928 .4291 L F
.61936 .4317 m .61692 .43182 L .61687 .42931 L F
.585 .594 .828 r
.42569 .56767 m .4268 .56505 L .42644 .56671 L F
.979 .683 .33 r
.44022 .59138 m .44122 .59322 L .4395 .58959 L F
.823 .786 .817 r
.43794 .59244 m .44122 .59322 L .44022 .59138 L F
.43794 .59244 m .43859 .59584 L .44122 .59322 L F
.544 .571 .832 r
.44122 .59322 m .44186 .58882 L .4395 .58959 L F
.44122 .59322 m .4435 .59278 L .44186 .58882 L F
.227 .573 .941 r
.24454 .5404 m .24403 .54149 L .24251 .54044 L F
.24454 .5404 m .24609 .54197 L .24403 .54149 L F
0 .356 .77 r
.75105 .39981 m .74945 .39943 L .75001 .40028 L F
.708 .411 .472 r
.55733 .59916 m .557 .60123 L .554 .6007 L F
.55 .317 .515 r
.55955 .59847 m .557 .60123 L .55733 .59916 L F
.521 .394 .648 r
.24321 .58112 m .24554 .58302 L .2457 .58068 L F
.24321 .58112 m .24345 .58375 L .24554 .58302 L F
.932 .947 .778 r
.63462 .43872 m .63268 .43935 L .63337 .44034 L F
.167 0 0 r
.56064 .59174 m .55931 .59144 L .55786 .59155 L F
.742 .84 .925 r
.68415 .44123 m .6808 .44124 L .68301 .43984 L F
.877 .866 .824 r
.68655 .43813 m .68415 .44123 L .68301 .43984 L F
.638 .48 .653 r
.68674 .43999 m .68415 .44123 L .68655 .43813 L F
.561 .503 .748 r
.60157 .45139 m .60015 .45575 L .59948 .45331 L F
.963 .872 .699 r
.74861 .4216 m .74964 .42375 L .74854 .42563 L F
.877 .866 .824 r
.68655 .43813 m .68301 .43984 L .68505 .4386 L F
.188 .45 .876 r
.68786 .43712 m .68655 .43813 L .68505 .4386 L F
.68786 .43712 m .68926 .43959 L .68655 .43813 L F
.538 .407 .65 r
.68655 .43813 m .68926 .43959 L .68674 .43999 L F
.603 .871 .992 r
.71784 .38848 m .71893 .38947 L .71642 .39034 L F
.589 .85 .994 r
.71784 .38848 m .71642 .39034 L .71535 .3893 L F
.485 .31 .568 r
.26467 .60083 m .2626 .599 L .26474 .59844 L F
.26467 .60083 m .26251 .60154 L .2626 .599 L F
.65 .762 .931 r
.74658 .41856 m .7471 .42058 L .7451 .42143 L F
.74658 .41856 m .7471 .42058 L .7451 .42143 L F
.445 .304 .595 r
.37844 .60509 m .38062 .60485 L .38058 .60077 L F
.493 .393 .67 r
.37884 .60764 m .38062 .60485 L .37844 .60509 L F
.516 .504 .782 r
.50533 .57754 m .50394 .57881 L .50239 .57451 L F
0 0 0 r
.50533 .57754 m .50306 .58039 L .50394 .57881 L F
.471 .626 .919 r
.54657 .5954 m .54628 .59748 L .54409 .59474 L F
.718 .77 .893 r
.70984 .44847 m .7134 .44886 L .71247 .44614 L F
.784 .774 .843 r
.7134 .44886 m .7158 .44653 L .71247 .44614 L F
.487 .591 .884 r
.18417 .63784 m .18019 .63506 L .18225 .63507 L F
.555 .683 .924 r
.18469 .63557 m .18417 .63784 L .18225 .63507 L F
.18469 .63557 m .18635 .63742 L .18417 .63784 L F
.766 .713 .802 r
.63286 .41851 m .6308 .42144 L .62945 .41914 L F
.659 .741 .911 r
.54447 .5892 m .54612 .59149 L .54859 .59033 L F
.05 0 0 r
.54859 .59033 m .54854 .5906 L .54612 .59149 L F
.066 0 0 r
.43932 .58191 m .43876 .58136 L .44076 .58045 L F
.43932 .58191 m .43689 .58243 L .43876 .58136 L F
.853 .803 .801 r
.43794 .59244 m .43563 .59562 L .43859 .59584 L F
.322 0 0 r
.43563 .59562 m .43741 .59596 L .43859 .59584 L F
.032 .54 .872 r
.43954 .59547 m .43859 .59584 L .43741 .59596 L F
.43954 .59547 m .44132 .59649 L .43859 .59584 L F
.716 .757 .885 r
.6064 .45577 m .60434 .4572 L .60257 .45511 L F
.319 .049 .338 r
.23884 .58958 m .24064 .58915 L .24106 .58736 L F
.368 .262 .601 r
.23884 .58958 m .24092 .59161 L .24064 .58915 L F
.23884 .58958 m .23864 .59277 L .24092 .59161 L F
.641 .803 .366 r
.46992 .57668 m .46908 .57831 L .47111 .57686 L F
.46992 .57668 m .4681 .57997 L .46908 .57831 L F
.718 .542 .65 r
.46775 .58968 m .46922 .58544 L .46777 .587 L F
0 0 0 r
.439 .62975 m .43856 .6306 L .44122 .63026 L F
.47 .735 .985 r
.43797 .6301 m .43856 .6306 L .43626 .6316 L F
.43856 .6306 m .43939 .63129 L .43805 .63142 L F
.43856 .6306 m .43805 .63142 L .43626 .6316 L F
.43946 .63129 m .4392 .63154 L .43626 .6316 L F
.028 .6 .724 r
.43785 .63158 m .4392 .63154 L .44009 .63155 L F
.43626 .6316 m .43796 .63157 L .43785 .63158 L F
.43796 .63157 m .4392 .63154 L .43785 .63158 L F
.619 .162 .146 r
.44009 .63155 m .43766 .63236 L .43626 .6316 L F
0 0 0 r
.43856 .6306 m .43766 .63236 L .43943 .63132 L F
.43808 .63155 m .43795 .6324 L .43766 .63236 L F
.43856 .6306 m .43825 .63153 L .43808 .63155 L F
.43825 .63153 m .43795 .6324 L .43808 .63155 L F
.43856 .6306 m .43943 .63132 L .44122 .63026 L F
.591 .948 .869 r
.44122 .63026 m .43943 .63132 L .44009 .63155 L F
.725 .852 .942 r
.44122 .63026 m .43967 .63153 L .4387 .63038 L F
0 0 0 r
.439 .62975 m .43891 .62998 L .43856 .6306 L F
.43891 .62998 m .4387 .63038 L .43856 .6306 L F
.725 .852 .942 r
.43891 .62998 m .4387 .63038 L .43826 .62985 L F
.44122 .63026 m .4387 .63038 L .43893 .62994 L F
0 0 0 r
.43891 .62998 m .43884 .63016 L .4387 .63038 L F
.47 .735 .985 r
.43826 .62985 m .43939 .63129 L .43797 .6301 L F
0 0 0 r
.43884 .63016 m .43795 .6324 L .43856 .6306 L F
.47 .735 .985 r
.43826 .62985 m .43946 .63129 L .43939 .63129 L F
.868 .706 .679 r
.43826 .62985 m .43795 .6324 L .43891 .62998 L F
.43826 .62985 m .43891 .62998 L .439 .62975 L F
.725 .852 .942 r
.43893 .62994 m .43891 .62998 L .43826 .62985 L F
.591 .948 .869 r
.43943 .63132 m .4392 .63154 L .44009 .63155 L F
.47 .735 .985 r
.43946 .63129 m .43967 .63153 L .4392 .63154 L F
.591 .948 .869 r
.43943 .63132 m .43905 .63154 L .4392 .63154 L F
.43905 .63154 m .43766 .63236 L .44009 .63155 L F
.028 .6 .724 r
.4392 .63154 m .43967 .63153 L .44009 .63155 L F
.591 .931 .738 r
.44122 .63026 m .43967 .63153 L .44009 .63155 L F
.39 .207 .508 r
.56471 .59235 m .56475 .58987 L .56688 .58922 L F
.3 0 .169 r
.38058 .60077 m .38254 .60052 L .38344 .59856 L F
.47 .893 .885 r
.38344 .59856 m .38462 .59763 L .38554 .59759 L F
.439 .29 .581 r
.38254 .60052 m .38462 .59763 L .38344 .59856 L F
.37 .807 .648 r
.4342 .58775 m .43046 .58981 L .43233 .58872 L F
.706 .933 .963 r
.4342 .58775 m .43325 .5875 L .43593 .58644 L F
.961 .694 .484 r
.4342 .58775 m .43233 .58872 L .43325 .5875 L F
.547 .365 .586 r
.5056 .58978 m .50799 .58957 L .50808 .5862 L F
.266 0 0 r
.19013 .55617 m .18641 .55675 L .1884 .55604 L F
.873 .978 .679 r
.59783 .48842 m .59579 .49164 L .59626 .4895 L F
.86 .997 .785 r
.6003 .4853 m .59783 .48842 L .59823 .48648 L F
.869 .978 .68 r
.59783 .48842 m .59626 .4895 L .59823 .48648 L F
.966 .648 .351 r
.48793 .59214 m .48657 .59172 L .486 .58924 L F
.989 .774 .52 r
.48793 .59214 m .48701 .59447 L .48657 .59172 L F
.788 .288 0 r
.48657 .59172 m .48898 .594 L .48793 .59214 L F
.629 .944 .952 r
.63782 .40247 m .6409 .40163 L .63855 .4027 L F
.99 .89 .605 r
.76554 .40452 m .76471 .40773 L .76529 .40872 L F
.996 .857 .526 r
.76529 .40872 m .76402 .41021 L .76498 .41119 L F
.76529 .40872 m .76471 .40773 L .76402 .41021 L F
.629 .515 .705 r
.19232 .70323 m .19236 .70567 L .19497 .70273 L F
.604 .855 .991 r
.42616 .58359 m .42381 .58435 L .4224 .58348 L F
.4224 .58348 m .42381 .58435 L .42616 .58359 L F
.575 .823 .992 r
.72032 .3979 m .72141 .39905 L .72398 .39832 L F
.333 0 0 r
.19802 .54 m .20203 .53995 L .20007 .54025 L F
.825 .711 .739 r
.53764 .52765 m .53768 .52417 L .53785 .52675 L F
.055 0 .109 r
.51991 .53401 m .51985 .53504 L .52131 .53256 L F
0 0 0 r
.52111 .5328 m .51991 .53401 L .52131 .53256 L F
0 0 .071 r
.52111 .5328 m .51985 .53504 L .51991 .53401 L F
.891 .958 .835 r
.77591 .43036 m .78027 .42763 L .77948 .42657 L F
.728 .574 .682 r
.41352 .62247 m .4097 .61967 L .41208 .61907 L F
.41352 .62247 m .41156 .62438 L .4097 .61967 L F
.842 .791 .803 r
.41352 .62247 m .41102 .62562 L .41156 .62438 L F
.366 .128 .415 r
.41312 .62493 m .41102 .62562 L .41352 .62247 L F
.41312 .62493 m .41102 .62562 L .41352 .62247 L F
.456 .443 .755 r
.4144 .61853 m .41352 .62247 L .41208 .61907 L F
.4144 .61853 m .41545 .62211 L .41352 .62247 L F
.372 .133 .417 r
.41545 .62211 m .41312 .62493 L .41352 .62247 L F
.38 .809 .966 r
.21583 .55665 m .21432 .55614 L .21218 .55654 L F
.21583 .55665 m .21432 .55614 L .21218 .55654 L F
.852 .94 .879 r
.21708 .55359 m .21583 .55665 L .21815 .55375 L F
.21708 .55359 m .21432 .55614 L .21583 .55665 L F
.999 .837 .517 r
.76399 .41796 m .76529 .41697 L .76428 .41583 L F
.76399 .41796 m .76497 .41911 L .76529 .41697 L F
.978 .836 .635 r
.77287 .40936 m .77342 .41353 L .77218 .41263 L F
.958 .921 .728 r
.77145 .41684 m .77218 .41263 L .77342 .41353 L F
.743 .696 .807 r
.77594 .41104 m .77342 .41353 L .77287 .40936 L F
.69 .621 .774 r
.4232 .60864 m .41987 .60794 L .42151 .60707 L F
.669 .544 .703 r
.42572 .60937 m .42427 .61158 L .4232 .60864 L F
.638 .153 .085 r
.4232 .60864 m .4215 .60944 L .42572 .60937 L F
.495 .662 .936 r
.4232 .60864 m .42383 .60655 L .42151 .60707 L F
.4232 .60864 m .42572 .60937 L .42383 .60655 L F
.448 0 0 r
.41304 .64067 m .41579 .64157 L .41719 .64092 L F
.772 .275 .031 r
.41719 .64092 m .41579 .64157 L .4179 .64199 L F
.79 .647 .705 r
.4179 .64199 m .42007 .64042 L .41719 .64092 L F
.627 .594 .797 r
.75686 .41011 m .75596 .41435 L .7555 .40948 L F
.75686 .41011 m .75685 .41311 L .75596 .41435 L F
.582 .425 .633 r
.56249 .539 m .56483 .53592 L .56221 .53638 L F
.718 .542 .65 r
.46775 .58968 m .47016 .59043 L .47015 .59038 L F
.718 .335 .323 r
.47146 .58998 m .47101 .59063 L .47015 .59038 L F
.46986 .58985 m .47015 .59038 L .46775 .58968 L F
.47146 .58998 m .47015 .59038 L .46986 .58985 L F
.022 .063 .564 r
.46922 .58544 m .47015 .59038 L .47145 .5878 L F
.47015 .59038 m .47016 .59043 L .47017 .59041 L F
.47015 .59038 m .47017 .59041 L .47145 .5878 L F
.718 .542 .65 r
.46775 .58968 m .47015 .59038 L .46922 .58544 L F
.72 .333 .315 r
.46775 .58968 m .4701 .59195 L .47016 .59043 L F
.718 .335 .323 r
.47101 .59063 m .4701 .59195 L .47017 .59039 L F
.601 .567 .788 r
.4701 .59195 m .47145 .5878 L .47017 .59041 L F
.4701 .59195 m .47017 .59041 L .47016 .59043 L F
.718 .335 .323 r
.47017 .59039 m .4701 .59195 L .46775 .58968 L F
.675 .283 .296 r
.47418 .59208 m .4701 .59195 L .47146 .58998 L F
.587 .344 .515 r
.47429 .5897 m .47418 .59208 L .47146 .58998 L F
.387 .283 .613 r
.56161 .56774 m .55882 .57032 L .55974 .56541 L F
.27 .226 .624 r
.56161 .56774 m .56038 .57174 L .55882 .57032 L F
.361 0 0 r
.44792 .65248 m .44392 .65441 L .44478 .65281 L F
.44792 .65248 m .44644 .65413 L .44392 .65441 L F
.908 .941 .579 r
.44759 .65197 m .44644 .65413 L .44792 .65248 L F
.824 .859 .873 r
.73047 .39976 m .73115 .40163 L .73364 .39908 L F
.406 0 .056 r
.6921 .39749 m .68983 .39672 L .68955 .39764 L F
.398 .039 .235 r
.6921 .39749 m .69236 .39609 L .68983 .39672 L F
.634 .812 .968 r
.50009 .53625 m .49631 .53582 L .49875 .53456 L F
0 0 0 r
.55405 .48559 m .556 .48466 L .55671 .48279 L F
.55671 .48279 m .55847 .48174 L .55911 .47983 L F
.035 0 .003 r
.55671 .48279 m .55785 .48356 L .55847 .48174 L F
.55671 .48279 m .556 .48466 L .55785 .48356 L F
.094 0 0 r
.54889 .49089 m .55072 .49031 L .55161 .48851 L F
0 0 .004 r
.55161 .48851 m .55343 .48751 L .55405 .48559 L F
.026 0 0 r
.55161 .48851 m .55271 .48921 L .55343 .48751 L F
.55161 .48851 m .55072 .49031 L .55271 .48921 L F
.458 .136 .331 r
.49506 .5804 m .49391 .58295 L .49104 .58347 L F
.667 .257 .258 r
.49506 .5804 m .49537 .58233 L .49391 .58295 L F
.49506 .5804 m .49716 .58126 L .49537 .58233 L F
.025 .243 .746 r
.47009 .56862 m .47086 .56737 L .46847 .56773 L F
.47009 .56862 m .47208 .5708 L .47086 .56737 L F
.849 .873 .432 r
.59274 .49649 m .59251 .49606 L .59343 .49468 L F
.87 .986 .833 r
.59343 .49468 m .59522 .49119 L .59579 .49164 L F
.59343 .49468 m .59306 .49367 L .59522 .49119 L F
.95 .849 .423 r
.59343 .49468 m .59251 .49606 L .59306 .49367 L F
.158 .335 .792 r
.18094 .63348 m .18019 .63506 L .17888 .63202 L F
.422 .662 .96 r
.18094 .63348 m .18225 .63507 L .18019 .63506 L F
.181 0 0 r
.16903 .54726 m .17129 .54684 L .17327 .54541 L F
0 0 0 r
.17327 .54541 m .17129 .54684 L .17321 .546 L F
.442 .26 .538 r
.44353 .60726 m .44347 .60976 L .44145 .60819 L F
.44145 .60819 m .44347 .60976 L .44353 .60726 L F
.475 .328 .602 r
.44353 .60726 m .44145 .60819 L .44393 .60465 L F
.191 0 .288 r
.53868 .50295 m .54101 .49985 L .53927 .50086 L F
.926 .914 .786 r
.66673 .41647 m .6683 .41693 L .66953 .41463 L F
.969 .848 .666 r
.66721 .41992 m .6683 .41693 L .66673 .41647 L F
.633 .385 .524 r
.44632 .6178 m .44872 .61628 L .44628 .61691 L F
.44632 .6178 m .44872 .61628 L .44628 .61691 L F
0 .078 .616 r
.51735 .56375 m .51826 .56602 L .51749 .56234 L F
.283 .436 .838 r
.76349 .39732 m .76205 .399 L .76051 .39573 L F
.661 .737 .906 r
.73847 .39312 m .74216 .39409 L .74113 .39195 L F
.631 .677 .875 r
.74113 .39195 m .74216 .39409 L .74453 .39307 L F
.705 .902 .966 r
.67833 .40853 m .68053 .40927 L .68261 .40789 L F
.178 0 0 r
.47176 .58492 m .47237 .58437 L .46922 .58544 L F
.022 .063 .564 r
.46922 .58544 m .47145 .5878 L .47176 .58492 L F
.698 .52 .643 r
.4097 .61967 m .40768 .62256 L .4077 .61996 L F
.743 .581 .675 r
.4097 .61967 m .41156 .62438 L .40768 .62256 L F
.742 .747 .856 r
.71452 .4277 m .71575 .4295 L .71223 .42894 L F
.693 .73 .879 r
.71804 .42859 m .71575 .4295 L .71452 .4277 L F
.526 .385 .632 r
.47521 .59821 m .47277 .59589 L .4755 .59522 L F
.47521 .59821 m .47316 .59908 L .47277 .59589 L F
.682 .429 .532 r
.47138 .59733 m .4755 .59522 L .47277 .59589 L F
.095 0 .058 r
.55911 .47983 m .5604 .48067 L .56148 .47915 L F
.55911 .47983 m .55847 .48174 L .5604 .48067 L F
.388 .465 .818 r
.41267 .62686 m .41102 .62562 L .41312 .62493 L F
.948 .857 .433 r
.65021 .42476 m .65092 .42635 L .65074 .42402 L F
.65021 .42476 m .65027 .42884 L .65092 .42635 L F
.488 .84 .576 r
.5506 .50484 m .54889 .5063 L .54954 .50581 L F
.647 .702 .886 r
.70136 .44982 m .70531 .45055 L .70394 .44892 L F
.709 .667 .807 r
.70531 .45055 m .70745 .44964 L .70394 .44892 L F
.675 .761 .916 r
.1755 .63041 m .17655 .63188 L .17343 .6313 L F
.328 .7 .981 r
.17734 .63098 m .17655 .63188 L .1755 .63041 L F
.17734 .63098 m .17888 .63202 L .17655 .63188 L F
.434 .285 .578 r
.60253 .43749 m .60486 .43699 L .60583 .43886 L F
.824 .575 .562 r
.60486 .43699 m .60795 .44012 L .60583 .43886 L F
.69 .501 .626 r
.42222 .59534 m .42022 .59863 L .41995 .59599 L F
.698 .753 .894 r
.43273 .599 m .43033 .60017 L .42869 .598 L F
.544 .386 .617 r
.56341 .55961 m .56118 .56272 L .56107 .56017 L F
.377 .332 .681 r
.41834 .63136 m .42082 .6338 L .41829 .63433 L F
.032 0 0 r
.42082 .6338 m .41825 .63477 L .41829 .63433 L F
.373 .839 .866 r
.68527 .40654 m .68895 .40593 L .68749 .40672 L F
0 0 0 r
.68749 .40672 m .68895 .40593 L .69104 .40486 L F
.137 0 .033 r
.53563 .50531 m .53868 .50295 L .53655 .50393 L F
.824 .736 .768 r
.77764 .40178 m .77414 .40142 L .77652 .39816 L F
.797 .788 .844 r
.77764 .40178 m .7755 .40288 L .77414 .40142 L F
.662 .647 .824 r
.7801 .3993 m .77764 .40178 L .77652 .39816 L F
.611 .561 .774 r
.7801 .3993 m .78078 .40252 L .77764 .40178 L F
.422 .294 .6 r
.38083 .62817 m .38276 .62525 L .37912 .62494 L F
.38083 .62817 m .38283 .62823 L .38276 .62525 L F
0 0 0 r
.55842 .49658 m .55712 .4981 L .55935 .49473 L F
.56117 .49328 m .55935 .49473 L .5623 .49226 L F
.56024 .4948 m .55935 .49473 L .56117 .49328 L F
.56024 .4948 m .55842 .49658 L .55935 .49473 L F
.754 .635 .728 r
.44854 .59567 m .44388 .59779 L .447 .59266 L F
.704 .469 .566 r
.44854 .59567 m .44462 .59828 L .44388 .59779 L F
.44854 .59567 m .44802 .59838 L .44462 .59828 L F
.537 .213 .365 r
.45118 .59613 m .44802 .59838 L .44854 .59567 L F
.636 .775 .947 r
.72141 .38853 m .72252 .39013 L .71893 .38947 L F
.619 .757 .944 r
.72394 .38769 m .72252 .39013 L .72141 .38853 L F
.72394 .38769 m .72503 .38933 L .72252 .39013 L F
.626 .399 .554 r
.51199 .595 m .50932 .5929 L .51199 .59201 L F
.51199 .595 m .50927 .5954 L .50932 .5929 L F
0 0 .291 r
.50932 .5929 m .50988 .59345 L .51029 .59317 L F
.50974 .59276 m .51029 .59317 L .51199 .59201 L F
.50932 .5929 m .51029 .59317 L .50974 .59276 L F
.883 .496 .035 r
.51045 .59329 m .51062 .59352 L .51034 .59321 L F
0 0 .291 r
.50964 .59398 m .50927 .5954 L .50983 .59462 L F
.5093 .59402 m .50927 .5954 L .50964 .59398 L F
.50932 .5929 m .50983 .59462 L .50986 .59392 L F
.50932 .5929 m .50986 .59392 L .50974 .59331 L F
.50986 .59392 m .51005 .5943 L .50987 .5937 L F
.50986 .59392 m .50987 .5937 L .50974 .59331 L F
.50932 .5929 m .5093 .59402 L .50964 .59398 L F
.721 .498 .588 r
.50883 .59394 m .50552 .59471 L .50988 .5934 L F
.50988 .59344 m .50988 .5934 L .51011 .59333 L F
.50883 .59394 m .50988 .5934 L .50988 .59344 L F
.726 .491 .571 r
.51034 .5939 m .50642 .59613 L .50994 .59394 L F
.51034 .5939 m .50994 .59394 L .51062 .59352 L F
0 0 .291 r
.50986 .59392 m .50983 .59462 L .51005 .5943 L F
.721 .498 .588 r
.50989 .59324 m .50552 .59471 L .50478 .59124 L F
.51011 .59333 m .50988 .5934 L .50989 .59324 L F
.50988 .5934 m .50552 .59471 L .50989 .59324 L F
.469 .084 .225 r
.50642 .59613 m .50552 .59471 L .50987 .5937 L F
.50994 .59394 m .50987 .5937 L .51062 .59352 L F
.50642 .59613 m .50987 .5937 L .50994 .59394 L F
.721 .498 .588 r
.51062 .59352 m .50987 .5937 L .51011 .59333 L F
0 0 .291 r
.50974 .59331 m .50987 .5937 L .50988 .59344 L F
.721 .498 .588 r
.50987 .5937 m .50883 .59394 L .50988 .59344 L F
.50987 .5937 m .50988 .59344 L .51011 .59333 L F
0 0 .291 r
.50988 .59344 m .51005 .5943 L .51034 .5939 L F
.50987 .5937 m .51005 .5943 L .50988 .59344 L F
.883 .496 .035 r
.51045 .59329 m .51034 .5939 L .51062 .59352 L F
0 0 .291 r
.50993 .59342 m .51047 .59314 L .51049 .59303 L F
.883 .496 .035 r
.51045 .59329 m .51034 .59321 L .50863 .5913 L F
.721 .498 .588 r
.51034 .59321 m .50478 .59124 L .50863 .5913 L F
.51062 .59352 m .51011 .59333 L .51034 .59321 L F
.51011 .59333 m .50478 .59124 L .51034 .59321 L F
.883 .496 .035 r
.50956 .5921 m .51034 .5939 L .51045 .59329 L F
0 0 .291 r
.51049 .59303 m .51144 .59264 L .51199 .59201 L F
.51047 .59314 m .51144 .59264 L .51049 .59303 L F
.50988 .59345 m .51011 .59333 L .50993 .59342 L F
.51011 .59333 m .51144 .59264 L .50993 .59342 L F
.883 .496 .035 r
.50956 .5921 m .51045 .59329 L .50863 .5913 L F
0 0 .291 r
.50988 .59345 m .51034 .5939 L .51144 .59264 L F
.201 .725 .849 r
.20203 .53995 m .20403 .53962 L .20597 .53984 L F
.285 0 0 r
.20403 .53962 m .20803 .53976 L .20597 .53984 L F
.744 .643 .748 r
.21435 .56291 m .21493 .56609 L .21738 .56313 L F
0 .08 .595 r
.53322 .56768 m .53304 .57093 L .53382 .56984 L F
.871 .791 .769 r
.75862 .41109 m .75685 .41311 L .75686 .41011 L F
.175 0 .318 r
.22996 .60762 m .22783 .6108 L .2294 .60983 L F
.174 0 .128 r
.22783 .6108 m .22814 .61198 L .2294 .60983 L F
.22783 .6108 m .22667 .61295 L .22814 .61198 L F
.099 .16 .64 r
.20398 .69538 m .20309 .69705 L .20247 .69369 L F
0 0 .012 r
.20254 .69941 m .20309 .69705 L .20398 .69538 L F
.871 .994 .76 r
.59626 .4895 m .59579 .49164 L .59522 .49119 L F
.941 .907 .76 r
.62446 .45759 m .62372 .46183 L .62575 .4588 L F
0 0 0 r
.2116 .68206 m .20778 .68406 L .20931 .68252 L F
.829 .742 .768 r
.6678 .41333 m .67177 .41095 L .66981 .4102 L F
.6678 .41333 m .66953 .41463 L .67177 .41095 L F
0 0 .027 r
.55871 .57874 m .56101 .57459 L .56075 .57835 L F
.55871 .57874 m .56075 .57835 L .5582 .57688 L F
.514 .626 .9 r
.55871 .57874 m .56075 .57835 L .5582 .57688 L F
.79 .808 .866 r
.70953 .43186 m .70623 .43132 L .7089 .42876 L F
.782 .802 .87 r
.71223 .42894 m .70953 .43186 L .7089 .42876 L F
0 0 0 r
.15526 .55348 m .15781 .55248 L .1562 .55287 L F
.642 .331 .43 r
.44839 .58216 m .45041 .58322 L .45082 .58129 L F
.371 .088 .349 r
.45082 .58129 m .45041 .58322 L .45304 .58055 L F
.558 .372 .586 r
.45388 .60754 m .45112 .61092 L .45381 .61033 L F
.584 .363 .547 r
.45381 .61033 m .45092 .61314 L .45112 .61092 L F
.558 .372 .586 r
.45388 .60754 m .45112 .61092 L .45381 .61033 L F
.584 .363 .547 r
.45381 .61033 m .45092 .61314 L .45112 .61092 L F
.576 .264 .403 r
.44221 .60368 m .43957 .60398 L .4399 .60182 L F
.584 .427 .634 r
.44221 .59877 m .44232 .60162 L .4399 .60182 L F
.546 .275 .456 r
.44232 .60162 m .44221 .60368 L .4399 .60182 L F
.071 0 .057 r
.55405 .48559 m .55531 .48641 L .556 .48466 L F
.55405 .48559 m .55343 .48751 L .55531 .48641 L F
.642 .816 .967 r
.73109 .38877 m .72854 .38981 L .72751 .3884 L F
.577 .892 .619 r
.53017 .51101 m .53168 .50989 L .52892 .51243 L F
.61 .952 .81 r
.53017 .51101 m .52892 .51243 L .52709 .51301 L F
.051 0 .126 r
.21268 .6303 m .21488 .62807 L .21294 .62858 L F
.927 .96 .646 r
.76414 .43124 m .76252 .43396 L .7629 .43468 L F
.281 .227 .618 r
.78473 .41205 m .78247 .41481 L .78286 .41074 L F
.076 0 .393 r
.78473 .41205 m .78363 .41548 L .78247 .41481 L F
.01 .002 .497 r
.60809 .42018 m .60956 .421 L .61057 .41942 L F
.60809 .42018 m .60837 .42273 L .60956 .421 L F
.711 .6 .731 r
.24079 .58418 m .24106 .58736 L .24345 .58375 L F
.52 .353 .596 r
.24345 .58375 m .24106 .58736 L .24318 .58682 L F
.52 .263 .467 r
.24064 .58915 m .24318 .58682 L .24106 .58736 L F
.104 0 .093 r
.41817 .57453 m .41996 .57432 L .42089 .57182 L F
.131 0 .104 r
.42089 .57182 m .42195 .57295 L .42288 .57087 L F
.42089 .57182 m .41996 .57432 L .42195 .57295 L F
.348 0 .104 r
.58293 .4738 m .58212 .47521 L .57954 .47575 L F
.593 .325 .479 r
.58443 .47331 m .58212 .47521 L .58293 .4738 L F
.675 .831 .402 r
.60285 .50703 m .60479 .50354 L .60383 .50553 L F
0 0 0 r
.60181 .50865 m .60285 .50703 L .60383 .50553 L F
.592 .397 .587 r
.56848 .55119 m .56853 .55371 L .56594 .55404 L F
.589 .268 .394 r
.56848 .55119 m .57089 .55304 L .56853 .55371 L F
.56848 .55119 m .57115 .55108 L .57089 .55304 L F
.642 .486 .656 r
.57092 .54821 m .57115 .55108 L .56848 .55119 L F
.928 .814 .713 r
.60777 .45234 m .6064 .45577 L .60494 .45433 L F
.985 .849 .624 r
.662 .43224 m .66183 .42826 L .66103 .432 L F
.92 .893 .786 r
.65965 .43338 m .662 .43224 L .66103 .432 L F
.65965 .43338 m .6609 .43324 L .662 .43224 L F
.658 .937 .967 r
.17521 .56106 m .1795 .56015 L .17755 .56048 L F
.175 .708 .728 r
.17951 .56004 m .1795 .56015 L .1813 .55911 L F
.17951 .56004 m .17755 .56048 L .1795 .56015 L F
.362 .641 .961 r
.19931 .67933 m .20199 .67983 L .20152 .67883 L F
.661 .12 0 r
.65119 .40718 m .65164 .4075 L .65179 .40701 L F
.787 .628 .068 r
.65187 .40674 m .65179 .40701 L .65194 .40824 L F
.042 .177 .68 r
.65179 .40701 m .65248 .41062 L .65194 .40824 L F
.661 .12 0 r
.65164 .4075 m .65338 .40873 L .65179 .40701 L F
.787 .628 .068 r
.65177 .40439 m .65179 .40701 L .65187 .40674 L F
0 0 .198 r
.75678 .40185 m .75663 .40531 L .75641 .40392 L F
.755 .467 0 r
.75663 .40531 m .75686 .40675 L .75641 .40392 L F
.75663 .40531 m .75721 .40766 L .75686 .40675 L F
.633 .668 .865 r
.44297 .57767 m .44085 .57798 L .439 .57563 L F
.608 .391 .561 r
.44297 .57767 m .44076 .58045 L .44085 .57798 L F
.374 .224 .546 r
.45388 .60754 m .45565 .6096 L .45571 .60709 L F
.45388 .60754 m .45381 .61033 L .45565 .6096 L F
.45565 .6096 m .45388 .60754 L .45571 .60709 L F
.45565 .6096 m .45381 .61033 L .45388 .60754 L F
.938 .699 .552 r
.53359 .57315 m .53581 .57158 L .53304 .57093 L F
.53359 .57315 m .536 .57449 L .53581 .57158 L F
.602 .441 .637 r
.53581 .57158 m .536 .57449 L .53822 .5717 L F
.416 .587 .912 r
.76051 .39573 m .75981 .39639 L .7562 .39298 L F
.691 .471 .584 r
.57092 .54821 m .57354 .55089 L .57115 .55108 L F
.57092 .54821 m .57356 .54816 L .57354 .55089 L F
.609 .682 .893 r
.74391 .43429 m .74504 .43694 L .74765 .43585 L F
.388 .12 .381 r
.45301 .57035 m .45215 .56803 L .45404 .56876 L F
.45301 .57035 m .45094 .57165 L .45215 .56803 L F
.768 .745 .833 r
.69224 .44024 m .69031 .44175 L .68926 .43959 L F
.926 .914 .786 r
.66673 .41647 m .66953 .41463 L .6678 .41333 L F
.771 .936 .585 r
.42572 .60937 m .4233 .61266 L .42427 .61158 L F
.466 .265 .523 r
.28794 .56003 m .28549 .56326 L .28777 .56259 L F
.415 .863 .876 r
.7115 .39008 m .71039 .39108 L .709 .39088 L F
.7115 .39008 m .71288 .39022 L .71039 .39108 L F
.387 .283 .613 r
.56161 .56774 m .55974 .56541 L .56148 .56531 L F
.3 .002 .28 r
.24867 .62522 m .24589 .6279 L .24668 .6259 L F
.86 .858 .837 r
.7755 .40288 m .77323 .40566 L .77204 .40455 L F
.957 .816 .664 r
.77323 .40566 m .77276 .40873 L .77204 .40455 L F
.941 .907 .76 r
.62446 .45759 m .62265 .46083 L .62372 .46183 L F
.997 .775 .463 r
.62265 .46083 m .62356 .46437 L .62372 .46183 L F
.77 .802 .879 r
.19648 .63744 m .19232 .63783 L .19447 .63808 L F
.36 0 0 r
.19631 .63786 m .19648 .63744 L .19447 .63808 L F
.19631 .63786 m .19855 .63824 L .19648 .63744 L F
.43 .869 .898 r
.48451 .56365 m .48638 .56275 L .48703 .563 L F
.473 .562 .865 r
.48753 .56518 m .48451 .56365 L .48703 .563 L F
.384 .843 .895 r
.48703 .563 m .48638 .56275 L .48908 .56227 L F
.47 .374 .664 r
.48908 .56227 m .48753 .56518 L .48703 .563 L F
.68 .966 .931 r
.46221 .57093 m .46143 .57234 L .46331 .57114 L F
.988 .813 .426 r
.6566 .41075 m .65564 .41001 L .656 .40689 L F
0 0 .179 r
.6566 .41075 m .65695 .41165 L .65564 .41001 L F
.6566 .41075 m .65703 .41337 L .65695 .41165 L F
.983 .745 .344 r
.76471 .40343 m .76558 .40183 L .76461 .40062 L F
.76471 .40343 m .76554 .40452 L .76558 .40183 L F
.572 .027 0 r
.68018 .39975 m .6812 .39888 L .67772 .39829 L F
.261 0 0 r
.68261 .39979 m .6812 .39888 L .68018 .39975 L F
.68261 .39979 m .68364 .39857 L .6812 .39888 L F
.626 .625 .83 r
.74453 .39307 m .74775 .39651 L .74837 .39554 L F
.666 .624 .797 r
.43303 .56426 m .43709 .56497 L .4356 .56201 L F
.955 .892 .503 r
.43449 .56306 m .43379 .56338 L .43485 .55925 L F
.666 .624 .797 r
.43404 .56317 m .4356 .56201 L .43543 .56168 L F
.43303 .56426 m .4356 .56201 L .43404 .56317 L F
.905 .92 .818 r
.43449 .56306 m .43163 .56498 L .43379 .56338 L F
.43163 .56498 m .43086 .5655 L .43316 .56383 L F
.43163 .56498 m .43316 .56383 L .43379 .56338 L F
.402 .052 .253 r
.62645 .40757 m .62902 .40696 L .62971 .40479 L F
.043 0 0 r
.62971 .40479 m .63184 .40455 L .63234 .40418 L F
.041 0 .109 r
.62971 .40479 m .63077 .40559 L .63184 .40455 L F
.62971 .40479 m .62902 .40696 L .63077 .40559 L F
0 0 .04 r
.53313 .50805 m .53563 .50531 L .5341 .50676 L F
.321 0 0 r
.45754 .55915 m .46076 .56072 L .4586 .56063 L F
.59 .37 .549 r
.57663 .54779 m .57354 .55089 L .57356 .54816 L F
.518 .356 .601 r
.24692 .57397 m .24919 .57136 L .24727 .57215 L F
.537 .213 .365 r
.45118 .59613 m .45033 .59815 L .44802 .59838 L F
.204 0 .201 r
.4531 .59517 m .45033 .59815 L .45118 .59613 L F
.204 0 .283 r
.24341 .63081 m .24101 .6338 L .24174 .6317 L F
.561 .817 .447 r
.53189 .50958 m .53168 .50989 L .53017 .51101 L F
.53189 .50958 m .53313 .50805 L .53168 .50989 L F
.503 .368 .631 r
.24957 .56855 m .25157 .56561 L .24893 .56614 L F
.24957 .56855 m .2518 .56818 L .25157 .56561 L F
.489 .287 .533 r
.24919 .57136 m .2518 .56818 L .24957 .56855 L F
.129 0 .187 r
.24589 .6279 m .24341 .63081 L .24427 .62882 L F
.504 .656 .927 r
.20786 .67622 m .20369 .67411 L .20559 .67472 L F
.938 .627 .425 r
.20559 .67472 m .20767 .67944 L .20786 .67622 L F
.159 .676 .89 r
.48636 .57131 m .48818 .57127 L .48429 .57082 L F
.605 .622 .842 r
.6976 .44717 m .70136 .44982 L .7002 .44641 L F
.678 .628 .792 r
.70136 .44982 m .70256 .44545 L .7002 .44641 L F
.70136 .44982 m .70394 .44892 L .70256 .44545 L F
.662 .839 .968 r
.73457 .3889 m .73109 .38877 L .73371 .38751 L F
.65 .839 .973 r
.73747 .38758 m .73457 .3889 L .73371 .38751 L F
.288 .781 .736 r
.69964 .40199 m .70301 .40091 L .70248 .40163 L F
.138 0 0 r
.70301 .40091 m .70506 .40089 L .70248 .40163 L F
.70301 .40091 m .70578 .3998 L .70506 .40089 L F
.714 .749 .879 r
.72319 .42452 m .72425 .42651 L .72069 .42577 L F
.624 .717 .913 r
.72626 .42373 m .72425 .42651 L .72319 .42452 L F
.72626 .42373 m .72655 .42597 L .72425 .42651 L F
.619 .429 .603 r
.49107 .58587 m .48848 .58382 L .49104 .58347 L F
.49107 .58587 m .48852 .5864 L .48848 .58382 L F
.802 .572 .59 r
.431 .59561 m .43273 .599 L .42869 .598 L F
.527 .461 .726 r
.43495 .5981 m .431 .59561 L .43563 .59562 L F
.43495 .5981 m .43273 .599 L .431 .59561 L F
0 0 .374 r
.53239 .60003 m .53307 .60104 L .53095 .59856 L F
.53239 .60003 m .53399 .60354 L .53307 .60104 L F
.586 .885 .589 r
.55842 .49658 m .55586 .49913 L .55712 .4981 L F
.978 .917 .612 r
.65776 .42211 m .6584 .42309 L .65752 .42477 L F
.991 .882 .605 r
.65843 .4187 m .6584 .42309 L .65776 .42211 L F
.86 .997 .785 r
.6003 .4853 m .59823 .48648 L .59944 .48461 L F
.996 .857 .527 r
.6003 .4853 m .59944 .48461 L .59996 .48226 L F
.79 .515 .521 r
.76949 .43496 m .76634 .43654 L .76819 .43369 L F
.457 .532 .846 r
.63793 .42872 m .63853 .42481 L .63401 .42471 L F
.63793 .42872 m .63999 .42834 L .63853 .42481 L F
.597 .59 .815 r
.63793 .42872 m .64152 .43105 L .63999 .42834 L F
.557 .781 .983 r
.50761 .55707 m .50998 .55652 L .50652 .55576 L F
.571 .868 .995 r
.20033 .65587 m .20069 .65441 L .19885 .65548 L F
.20033 .65587 m .20256 .65511 L .20069 .65441 L F
.075 0 0 r
.41817 .57453 m .4169 .57646 L .41996 .57432 L F
.701 .721 .865 r
.6222 .44132 m .61829 .44046 L .62066 .43967 L F
.825 .748 .778 r
.62475 .4371 m .6222 .44132 L .62066 .43967 L F
.733 .908 .537 r
.59913 .44149 m .59778 .44396 L .59675 .44526 L F
.345 .014 .253 r
.4342 .57736 m .4365 .57671 L .43706 .57491 L F
.454 .112 .295 r
.43706 .57491 m .43909 .57604 L .439 .57563 L F
.43706 .57491 m .4365 .57671 L .43909 .57604 L F
.453 .176 .402 r
.57929 .54477 m .58215 .54232 L .58162 .54435 L F
.133 0 .267 r
.58162 .54435 m .58215 .54232 L .58381 .54125 L F
.833 .751 .772 r
.77204 .40455 m .77276 .40873 L .77007 .40704 L F
.799 .305 0 r
.77276 .40873 m .76881 .40627 L .77007 .40704 L F
.77276 .40873 m .77287 .40936 L .76881 .40627 L F
.792 .85 .895 r
.5364 .52141 m .53995 .52115 L .53871 .51977 L F
.83 .747 .771 r
.53768 .52417 m .53995 .52115 L .5364 .52141 L F
.818 .979 .891 r
.54208 .51807 m .53871 .51977 L .53995 .52115 L F
.533 .321 .538 r
.28794 .56003 m .29011 .56203 L .29025 .55949 L F
.28794 .56003 m .28777 .56259 L .29011 .56203 L F
.539 .363 .591 r
.60016 .44103 m .60276 .44049 L .60253 .43749 L F
.77 .557 .61 r
.59913 .44149 m .60276 .44049 L .60016 .44103 L F
.385 .846 .804 r
.48576 .56282 m .48451 .56365 L .48318 .56334 L F
.48576 .56282 m .48638 .56275 L .48451 .56365 L F
.583 .366 .552 r
.56594 .55404 m .56851 .55615 L .56587 .55647 L F
.56594 .55404 m .56853 .55371 L .56851 .55615 L F
.299 .19 .559 r
.52567 .54433 m .52572 .54683 L .52418 .54501 L F
.52567 .54433 m .52572 .54683 L .52418 .54501 L F
.997 .816 .539 r
.43709 .56497 m .43668 .56747 L .43825 .56621 L F
.148 .615 .927 r
.24258 .55574 m .23848 .55446 L .24067 .55611 L F
.031 .535 .874 r
.45468 .558 m .45754 .55915 L .45567 .55922 L F
.23 .738 .886 r
.20803 .53976 m .21005 .53942 L .21209 .53981 L F
.125 .669 .825 r
.21005 .53942 m .21434 .53961 L .21209 .53981 L F
.363 .318 .674 r
.23864 .59277 m .24074 .59464 L .24092 .59161 L F
.23864 .59277 m .23935 .5955 L .24074 .59464 L F
.957 .934 .608 r
.60383 .50553 m .60479 .50354 L .60331 .50481 L F
.917 .952 .612 r
.60479 .50354 m .60598 .49951 L .60485 .50192 L F
.60479 .50354 m .60645 .49983 L .60598 .49951 L F
.896 .96 .626 r
.60331 .50481 m .60479 .50354 L .60485 .50192 L F
.737 .743 .857 r
.7233 .43757 m .72695 .43819 L .72559 .43647 L F
.755 .777 .872 r
.72695 .43819 m .72832 .43408 L .72559 .43647 L F
.72695 .43819 m .72921 .43691 L .72832 .43408 L F
0 0 .113 r
.77096 .41863 m .77057 .41584 L .77145 .41684 L F
.958 .921 .728 r
.77145 .41684 m .77057 .41584 L .77218 .41263 L F
.531 .391 .635 r
.26928 .58937 m .26946 .59258 L .26703 .59301 L F
.57 .446 .672 r
.26946 .59258 m .26738 .59532 L .26703 .59301 L F
.272 .073 .417 r
.25032 .62428 m .24907 .6227 L .25077 .62193 L F
.25032 .62428 m .24867 .62522 L .24907 .6227 L F
.003 .534 .848 r
.6687 .40981 m .66981 .4102 L .66717 .40909 L F
.525 .653 .916 r
.6687 .40981 m .66808 .40957 L .66717 .40909 L F
.66808 .40957 m .66415 .40807 L .66717 .40909 L F
.108 .493 .902 r
.66627 .40786 m .66717 .40909 L .66415 .40807 L F
.998 .799 .454 r
.66621 .40857 m .66717 .40909 L .66627 .40786 L F
.66604 .41071 m .66717 .40909 L .66621 .40857 L F
.905 .789 .723 r
.6678 .41333 m .66981 .4102 L .66717 .40909 L F
.761 .97 .927 r
.59524 .44688 m .59528 .44551 L .59675 .44526 L F
.882 .954 .607 r
.59524 .44688 m .5939 .44795 L .59528 .44551 L F
.356 .449 .819 r
.39062 .63137 m .39066 .62761 L .38985 .62812 L F
.39062 .63137 m .39187 .63088 L .39066 .62761 L F
.963 .753 .571 r
.50192 .59992 m .50087 .60115 L .49925 .60022 L F
.334 .38 .76 r
.5018 .59453 m .50192 .59992 L .50037 .59524 L F
.114 .594 .912 r
.19098 .65677 m .19501 .65817 L .18997 .65626 L F
.738 .734 .848 r
.18997 .65626 m .19501 .65817 L .1966 .65607 L F
.658 .472 .622 r
.19488 .69056 m .19816 .69074 L .19785 .68823 L F
.468 .336 .618 r
.19785 .68823 m .20013 .68854 L .19861 .687 L F
.19785 .68823 m .19816 .69074 L .20013 .68854 L F
.614 .68 .889 r
.7437 .38814 m .74102 .38921 L .73978 .38665 L F
.313 .751 .967 r
.24609 .54197 m .24823 .54182 L .24996 .5425 L F
.293 .752 .952 r
.24823 .54182 m .25214 .54225 L .24996 .5425 L F
.208 0 .212 r
.52131 .53256 m .51985 .53504 L .52284 .53214 L F
0 0 0 r
.52131 .53256 m .52111 .5328 L .52284 .53214 L F
.487 .231 .452 r
.41458 .61402 m .41445 .61705 L .41164 .61672 L F
.462 .211 .447 r
.41663 .61582 m .41458 .61402 L .41677 .61316 L F
.41663 .61582 m .41445 .61705 L .41458 .61402 L F
.007 0 .111 r
.47629 .58414 m .47864 .58087 L .47801 .58265 L F
.47629 .58414 m .47864 .58087 L .47801 .58265 L F
.444 .153 .376 r
.48076 .58243 m .47864 .58087 L .47801 .58265 L F
0 0 0 r
.17752 .54424 m .17969 .54376 L .18156 .54316 L F
.241 .757 .82 r
.17969 .54376 m .18329 .54328 L .18156 .54316 L F
.834 .665 .672 r
.4215 .60944 m .4233 .61266 L .42572 .60937 L F
.589 .328 .49 r
.4233 .61266 m .42489 .61316 L .42572 .60937 L F
.42572 .60937 m .42489 .61316 L .4233 .61266 L F
.028 .548 .865 r
.42572 .60937 m .42426 .60842 L .42383 .60655 L F
.42572 .60937 m .42765 .60956 L .42426 .60842 L F
0 0 .015 r
.42572 .60937 m .42426 .60842 L .42765 .60956 L F
.704 .602 .74 r
.42765 .60956 m .42489 .61316 L .42572 .60937 L F
0 0 .015 r
.42572 .60937 m .42489 .61316 L .426 .61106 L F
.834 .665 .672 r
.4215 .60944 m .4233 .61266 L .42572 .60937 L F
0 0 .015 r
.42572 .60937 m .426 .61106 L .42426 .60842 L F
.686 .694 .852 r
.70394 .44892 m .70745 .44964 L .70634 .44641 L F
.701 .703 .848 r
.70634 .44641 m .70745 .44964 L .70984 .44847 L F
.434 .285 .578 r
.60253 .43749 m .60486 .43949 L .60486 .43699 L F
.60253 .43749 m .60276 .44049 L .60486 .43949 L F
.834 .995 .849 r
.50741 .5274 m .50408 .53074 L .50418 .52953 L F
0 .235 .747 r
.50408 .53074 m .50522 .53187 L .50418 .52953 L F
.417 .284 .591 r
.20419 .69076 m .20247 .69369 L .20195 .69197 L F
.20419 .69076 m .20431 .69349 L .20247 .69369 L F
.099 .16 .64 r
.20398 .69538 m .20247 .69369 L .20431 .69349 L F
.732 .666 .786 r
.45779 .58668 m .45548 .58926 L .45646 .58867 L F
.139 0 .353 r
.21978 .65138 m .21735 .65473 L .21714 .65235 L F
.744 .326 .256 r
.51596 .54016 m .51642 .54176 L .51413 .54031 L F
.903 .663 .565 r
.53381 .53866 m .53326 .5417 L .53567 .54178 L F
.827 .429 .294 r
.53326 .5417 m .53443 .54338 L .53567 .54178 L F
.84 .447 .304 r
.53443 .54338 m .53806 .54524 L .53567 .54178 L F
.693 .448 .548 r
.53567 .54178 m .53806 .54524 L .53958 .54276 L F
.139 .318 .782 r
.38032 .61611 m .38205 .61958 L .38286 .61821 L F
0 0 .521 r
.38205 .61958 m .38329 .62176 L .38286 .61821 L F
.158 .077 .507 r
.38208 .62223 m .38329 .62176 L .38205 .61958 L F
.495 .896 .934 r
.20246 .63762 m .19855 .63824 L .20012 .63789 L F
.369 .828 .918 r
.20327 .63688 m .20246 .63762 L .20012 .63789 L F
.20327 .63688 m .20461 .6371 L .20246 .63762 L F
.639 .34 .447 r
.44193 .65202 m .4406 .65286 L .44032 .65244 L F
.44193 .65202 m .44122 .65477 L .43795 .65453 L F
0 0 .105 r
.44202 .65384 m .44122 .65477 L .44193 .65202 L F
.113 .052 .503 r
.4412 .65154 m .44122 .65376 L .44202 .65384 L F
.44122 .65376 m .44122 .65477 L .4416 .65433 L F
.44122 .65376 m .4416 .65433 L .44202 .65384 L F
.639 .34 .447 r
.44032 .65244 m .43795 .65453 L .4388 .65284 L F
.4406 .65286 m .43795 .65453 L .44032 .65244 L F
.86 .858 .837 r
.7755 .40288 m .77204 .40455 L .77414 .40142 L F
.69 .228 .149 r
.41626 .64922 m .41476 .65044 L .41266 .64873 L F
.319 0 0 r
.41856 .65098 m .41476 .65044 L .41626 .64922 L F
.837 .721 .736 r
.63028 .4423 m .63017 .44579 L .63165 .44378 L F
.863 .784 .771 r
.63028 .4423 m .63165 .44378 L .63337 .44034 L F
.79 .647 .705 r
.4179 .64199 m .42092 .64341 L .42007 .64042 L F
.71 .182 0 r
.4179 .64199 m .41998 .64414 L .42092 .64341 L F
.751 .623 .717 r
.41998 .64414 m .42178 .64201 L .42092 .64341 L F
.337 0 .17 r
.40495 .58576 m .40677 .58616 L .40791 .58384 L F
.357 0 .18 r
.40791 .58384 m .40935 .58468 L .41 .58307 L F
.40791 .58384 m .40677 .58616 L .40935 .58468 L F
.904 .806 .742 r
.67547 .45514 m .6755 .45113 L .67662 .45259 L F
.623 .281 .37 r
.46335 .57653 m .46773 .57474 L .4655 .57638 L F
.276 .039 .363 r
.22996 .60762 m .23124 .60894 L .23141 .6067 L F
.22996 .60762 m .2294 .60983 L .23124 .60894 L F
.598 .63 .854 r
.44354 .59535 m .44221 .59877 L .44132 .59649 L F
.918 .897 .792 r
.447 .59266 m .44388 .59779 L .44354 .59535 L F
.18 .353 .801 r
.44388 .59779 m .44462 .59828 L .44354 .59535 L F
.598 .63 .854 r
.44354 .59535 m .44462 .59828 L .44221 .59877 L F
.474 .342 .62 r
.44378 .5988 m .44221 .59877 L .44462 .59828 L F
.44378 .5988 m .44232 .60162 L .44221 .59877 L F
.372 .08 .334 r
.24101 .6338 m .23822 .63665 L .23898 .63446 L F
.281 0 .072 r
.23159 .60412 m .2334 .60367 L .23497 .60175 L F
.018 0 .143 r
.23726 .59865 m .23497 .60175 L .23629 .60094 L F
.422 .02 .17 r
.23497 .60175 m .2361 .60317 L .23629 .60094 L F
.23497 .60175 m .2334 .60367 L .2361 .60317 L F
.401 .701 .982 r
.21815 .55375 m .21892 .55239 L .21708 .55359 L F
.21815 .55375 m .22137 .55324 L .21892 .55239 L F
.312 .76 .96 r
.22227 .55349 m .22137 .55324 L .21815 .55375 L F
0 0 0 r
.54069 .54227 m .54288 .54116 L .54386 .5395 L F
.654 .224 .213 r
.54288 .54116 m .54614 .54107 L .54386 .5395 L F
.863 .784 .771 r
.63028 .4423 m .63337 .44034 L .63268 .43935 L F
.565 .275 .434 r
.575 .52667 m .572 .52751 L .57208 .52951 L F
.61 .471 .666 r
.21774 .62242 m .21805 .62533 L .22029 .62215 L F
.853 .654 .633 r
.62475 .4371 m .62069 .43726 L .62329 .4344 L F
.825 .748 .778 r
.62475 .4371 m .62066 .43967 L .62069 .43726 L F
.567 .549 .794 r
.62554 .43446 m .62475 .4371 L .62329 .4344 L F
.547 .528 .786 r
.62554 .43446 m .62697 .43784 L .62475 .4371 L F
.576 .225 .338 r
.38554 .59759 m .38822 .59769 L .38884 .59593 L F
.641 .402 .54 r
.38822 .59769 m .3911 .59525 L .38884 .59593 L F
.4 .178 .458 r
.45879 .64637 m .46101 .64582 L .46118 .64336 L F
.451 .319 .609 r
.45879 .64637 m .46108 .64842 L .46101 .64582 L F
.4 .178 .458 r
.45879 .64637 m .46101 .64582 L .46118 .64336 L F
.451 .319 .609 r
.45879 .64637 m .46108 .64842 L .46101 .64582 L F
.272 .194 .583 r
.225 .61372 m .22619 .61387 L .22667 .61295 L F
.225 .61372 m .22525 .61627 L .22619 .61387 L F
.721 .239 0 r
.76944 .42833 m .77045 .42956 L .76922 .4288 L F
.97 .889 .69 r
.77045 .42956 m .76718 .43242 L .76922 .4288 L F
.77045 .42956 m .76819 .43369 L .76718 .43242 L F
.594 .086 0 r
.49956 .54479 m .50018 .54575 L .49749 .54429 L F
.49956 .54479 m .50153 .54697 L .50018 .54575 L F
.413 .172 .436 r
.2764 .56344 m .27317 .56609 L .27297 .56552 L F
.811 .731 .203 r
.19913 .70755 m .19949 .7063 L .20018 .70526 L F
.19913 .70755 m .19914 .70849 L .19949 .7063 L F
.491 .326 .585 r
.24318 .58682 m .24554 .58302 L .24345 .58375 L F
.364 .09 .359 r
.41059 .5812 m .41 .58307 L .41268 .58034 L F
.775 .736 .817 r
.69148 .4369 m .69224 .44024 L .68926 .43959 L F
.822 .763 .798 r
.6945 .43728 m .69224 .44024 L .69148 .4369 L F
.795 .756 .817 r
.71247 .44614 m .7158 .44653 L .71499 .44317 L F
.757 .734 .831 r
.71499 .44317 m .7158 .44653 L .71851 .44366 L F
.46 .291 .564 r
.26251 .60154 m .26238 .60414 L .26036 .60469 L F
.478 .308 .572 r
.26238 .60414 m .26029 .60721 L .26036 .60469 L F
.284 .569 .935 r
.74174 .42697 m .74081 .42819 L .7397 .42665 L F
0 0 .182 r
.74041 .43138 m .74081 .42819 L .74174 .42697 L F
.512 .747 .98 r
.64152 .43105 m .64285 .42912 L .63999 .42834 L F
.64152 .43105 m .64418 .43064 L .64285 .42912 L F
.163 .182 .633 r
.60608 .42925 m .60676 .42863 L .60582 .42566 L F
0 0 0 r
.60608 .42925 m .6058 .43046 L .60676 .42863 L F
.60608 .42925 m .6043 .43172 L .6058 .43046 L F
.427 .163 .409 r
.5797 .46171 m .58206 .46098 L .58235 .45896 L F
.412 .15 .404 r
.58235 .45896 m .58438 .46022 L .58495 .45841 L F
.58235 .45896 m .58206 .46098 L .58438 .46022 L F
.818 .979 .891 r
.54208 .51807 m .54142 .5173 L .53871 .51977 L F
.804 .515 .499 r
.60023 .47319 m .59669 .47048 L .60043 .47064 L F
0 0 .007 r
.56367 .49059 m .56117 .49328 L .5623 .49226 L F
.541 .474 .729 r
.55164 .55421 m .55047 .55389 L .55072 .55644 L F
.55164 .55421 m .54956 .55407 L .55047 .55389 L F
.73 .891 .953 r
.69688 .43395 m .69394 .43378 L .69597 .43283 L F
.822 .952 .903 r
.69997 .43113 m .69688 .43395 L .69597 .43283 L F
.777 .795 .868 r
.68857 .44715 m .69167 .44723 L .69018 .44571 L F
.746 .755 .859 r
.69018 .44571 m .69167 .44723 L .69406 .44611 L F
.618 .824 .979 r
.24744 .56514 m .24893 .56614 L .25157 .56561 L F
.339 .072 .355 r
.41333 .5785 m .41268 .58034 L .41527 .57756 L F
0 0 .218 r
.20369 .67411 m .20278 .67668 L .20373 .67543 L F
.838 .702 .713 r
.61579 .4412 m .61537 .44374 L .61228 .44294 L F
.638 .545 .733 r
.61829 .44046 m .61579 .4412 L .615 .43738 L F
.222 .184 .602 r
.55429 .57182 m .55557 .56765 L .55294 .56818 L F
.154 .071 .501 r
.55581 .57373 m .55429 .57182 L .55409 .57432 L F
.55581 .57373 m .5561 .57036 L .55429 .57182 L F
.525 .759 .982 r
.19064 .63642 m .19014 .63815 L .18849 .6369 L F
.19064 .63642 m .19232 .63783 L .19014 .63815 L F
0 0 0 r
.65247 .41303 m .65225 .41463 L .65222 .41438 L F
.835 .588 .565 r
.42592 .65231 m .42275 .65336 L .42217 .65213 L F
.42592 .65231 m .42584 .65484 L .42275 .65336 L F
.625 .437 .608 r
.55987 .542 m .56244 .54188 L .56249 .539 L F
.582 .425 .633 r
.56249 .539 m .56517 .53855 L .56483 .53592 L F
.55 .364 .581 r
.56244 .54188 m .56517 .53855 L .56249 .539 L F
.804 .632 .668 r
.61476 .44538 m .61228 .44294 L .61537 .44374 L F
.359 .45 .818 r
.24565 .55687 m .24682 .56042 L .24833 .5586 L F
.367 .409 .773 r
.2481 .56282 m .24833 .5586 L .24682 .56042 L F
.678 .611 .773 r
.55162 .55997 m .55072 .55644 L .54781 .55637 L F
.246 .317 .74 r
.55162 .55997 m .55312 .5584 L .55072 .55644 L F
.105 .099 .566 r
.55334 .56186 m .55162 .55997 L .5501 .56176 L F
.55334 .56186 m .55312 .5584 L .55162 .55997 L F
.176 .677 .911 r
.41674 .63314 m .42082 .6338 L .41834 .63136 L F
.75 .757 .246 r
.59274 .49649 m .59208 .49844 L .59251 .49606 L F
.59274 .49649 m .59171 .50039 L .59208 .49844 L F
.547 .334 .543 r
.58162 .54435 m .5792 .54734 L .57929 .54477 L F
.254 .016 .346 r
.25308 .61886 m .25077 .62193 L .25137 .61967 L F
.696 .676 .827 r
.19816 .69074 m .20195 .69197 L .20013 .68854 L F
.564 0 0 r
.19816 .69074 m .20033 .69206 L .20195 .69197 L F
.692 .697 .85 r
.20195 .69197 m .20209 .69093 L .2014 .69094 L F
.20195 .69197 m .20419 .69076 L .20249 .68792 L F
.486 .017 .066 r
.20033 .69206 m .20419 .69076 L .20195 .69197 L F
.20033 .69206 m .20224 .69248 L .20404 .69089 L F
.20379 .6909 m .20404 .69089 L .20419 .69076 L F
.20033 .69206 m .20404 .69089 L .20379 .6909 L F
.692 .697 .85 r
.2014 .69094 m .20249 .68792 L .20013 .68854 L F
.20209 .69093 m .20249 .68792 L .2014 .69094 L F
.771 .552 .602 r
.76535 .42603 m .76503 .42872 L .76944 .42833 L F
.874 .856 .401 r
.76944 .42833 m .76933 .4271 L .77004 .42491 L F
.247 0 0 r
.62317 .40968 m .62645 .40757 L .62389 .40793 L F
.403 .855 .886 r
.75198 .39654 m .75421 .39547 L .7509 .39523 L F
.75198 .39654 m .7547 .39577 L .75421 .39547 L F
.689 .424 .517 r
.55138 .54741 m .55362 .5475 L .55461 .54543 L F
.532 .341 .567 r
.55461 .54543 m .55721 .54462 L .55752 .54208 L F
.652 .467 .621 r
.55362 .5475 m .55721 .54462 L .55461 .54543 L F
.982 .733 .479 r
.66176 .40072 m .66303 .40433 L .66314 .40152 L F
.562 .31 .492 r
.46118 .64336 m .46101 .64582 L .46347 .64539 L F
.46118 .64336 m .46101 .64582 L .46347 .64539 L F
.22 .531 .922 r
.26121 .54516 m .26397 .54637 L .26353 .54772 L F
.306 .628 .962 r
.26397 .54637 m .26547 .54787 L .26353 .54772 L F
.817 .771 .809 r
.6945 .43728 m .69148 .4369 L .69394 .43378 L F
.191 .212 .653 r
.78345 .40657 m .78191 .40859 L .78142 .40485 L F
.141 .253 .719 r
.78413 .40898 m .78191 .40859 L .78345 .40657 L F
.78413 .40898 m .78286 .41074 L .78191 .40859 L F
.684 .801 .937 r
.55625 .59061 m .55786 .59155 L .55584 .59315 L F
.215 .593 .947 r
.21239 .65982 m .21425 .66004 L .21377 .66112 L F
.268 .654 .967 r
.21425 .66004 m .21609 .66124 L .21377 .66112 L F
.681 .461 .581 r
.21522 .66454 m .21377 .66112 L .21609 .66124 L F
.538 .348 .571 r
.56287 .58369 m .56298 .58665 L .5603 .58654 L F
.539 .354 .578 r
.5603 .58654 m .56298 .58665 L .56101 .58921 L F
.691 .445 .545 r
.5603 .58654 m .56101 .58921 L .55712 .58936 L F
.407 .214 .504 r
.23611 .63724 m .23582 .63967 L .23388 .64022 L F
.251 0 .136 r
.23468 .64187 m .23388 .64022 L .23582 .63967 L F
.23468 .64187 m .23268 .64256 L .23388 .64022 L F
.403 .586 .916 r
.55196 .56379 m .55117 .56269 L .5505 .56235 L F
.55343 .56523 m .55188 .5635 L .55196 .56379 L F
.55188 .5635 m .55117 .56269 L .55196 .56379 L F
.648 .548 .727 r
.5505 .56235 m .55334 .56186 L .5501 .56176 L F
.505 .631 .908 r
.5501 .56176 m .55034 .56177 L .5509 .5626 L F
.403 .586 .916 r
.55287 .5659 m .55343 .56523 L .5505 .56235 L F
.505 .631 .908 r
.55069 .56253 m .5509 .5626 L .55205 .5643 L F
.5501 .56176 m .5509 .5626 L .55069 .56253 L F
.648 .548 .727 r
.5505 .56235 m .5518 .56245 L .55184 .56212 L F
.5505 .56235 m .55117 .56269 L .5518 .56245 L F
.5518 .56245 m .55402 .56366 L .55334 .56186 L F
.55117 .56269 m .55176 .56289 L .5518 .56245 L F
.55176 .56289 m .55402 .56366 L .5518 .56245 L F
.505 .631 .908 r
.55034 .56177 m .55153 .56179 L .55188 .5635 L F
.994 .87 .547 r
.55159 .56317 m .55148 .56197 L .55126 .5628 L F
.505 .631 .908 r
.55034 .56177 m .55188 .5635 L .55205 .5643 L F
.558 .686 .925 r
.5501 .56176 m .5505 .56235 L .54837 .56287 L F
.574 .662 .897 r
.5501 .56176 m .55205 .5643 L .54929 .56476 L F
.294 0 0 r
.54929 .56476 m .55205 .5643 L .5503 .56637 L F
.994 .87 .547 r
.55159 .56317 m .55126 .5628 L .5503 .56637 L F
.55166 .56391 m .55159 .56317 L .5503 .56637 L F
.55188 .5635 m .55175 .56299 L .55166 .56391 L F
.648 .548 .727 r
.55117 .56269 m .55424 .56425 L .55402 .56366 L F
.994 .87 .547 r
.55188 .5635 m .55176 .56289 L .55175 .56299 L F
.403 .586 .916 r
.55343 .56523 m .55424 .56425 L .55117 .56269 L F
.994 .87 .547 r
.55175 .56299 m .55148 .56197 L .55166 .56391 L F
.55175 .56299 m .55153 .56179 L .55148 .56197 L F
.55176 .56289 m .55153 .56179 L .55175 .56299 L F
.648 .548 .727 r
.55184 .56212 m .5518 .56245 L .55334 .56186 L F
.994 .87 .547 r
.55205 .5643 m .55188 .5635 L .5503 .56637 L F
.662 .638 .816 r
.55294 .56818 m .55424 .56425 L .55287 .5659 L F
.554 .905 .971 r
.19436 .55523 m .19382 .55643 L .19617 .55552 L F
.19436 .55523 m .19225 .55609 L .19382 .55643 L F
.652 .292 .349 r
.59454 .46984 m .59293 .47223 L .59061 .47028 L F
.774 .488 .502 r
.59669 .47048 m .59293 .47223 L .59454 .46984 L F
0 0 .416 r
.52728 .58683 m .52815 .58887 L .52774 .58512 L F
.411 .699 .98 r
.72398 .39832 m .72743 .39961 L .72644 .39809 L F
.402 .687 .977 r
.72743 .39961 m .72875 .39827 L .72644 .39809 L F
.72743 .39961 m .73047 .39976 L .72875 .39827 L F
.709 .933 .962 r
.77948 .42657 m .78322 .42584 L .78279 .42583 L F
.619 .442 .62 r
.78468 .42384 m .78279 .42583 L .78322 .42584 L F
.439 .835 .981 r
.21434 .53961 m .21647 .53913 L .21819 .53967 L F
.11 0 0 r
.21647 .53913 m .22026 .53931 L .21819 .53967 L F
0 .309 .72 r
.73364 .39908 m .73525 .39965 L .73324 .39938 L F
.218 .58 .943 r
.73458 .39931 m .73324 .39938 L .73525 .39965 L F
.322 .442 .828 r
.73512 .3972 m .73642 .40049 L .73364 .39908 L F
.218 .58 .943 r
.73188 .39798 m .73324 .39938 L .73458 .39931 L F
.824 .859 .873 r
.73047 .39976 m .73191 .39945 L .73324 .39938 L F
.73191 .39945 m .73364 .39908 L .73324 .39938 L F
0 .309 .72 r
.73364 .39908 m .73642 .40049 L .73525 .39965 L F
.599 .847 .991 r
.18175 .65681 m .18174 .65787 L .18395 .65708 L F
.264 .335 .749 r
.19488 .69056 m .19735 .69286 L .19816 .69074 L F
.19488 .69056 m .19621 .69362 L .19735 .69286 L F
.573 .44 .661 r
.4144 .61853 m .41164 .61672 L .41445 .61705 L F
.4144 .61853 m .41208 .61907 L .41164 .61672 L F
.315 .044 .333 r
.25565 .61601 m .25308 .61886 L .25376 .61673 L F
0 0 .042 r
.19621 .69362 m .1963 .69453 L .19735 .69286 L F
.19621 .69362 m .19628 .69638 L .1963 .69453 L F
.666 .389 .491 r
.43046 .58981 m .43351 .59192 L .43233 .58872 L F
.43046 .58981 m .43057 .59223 L .43351 .59192 L F
.521 .074 .129 r
.62945 .41914 m .63186 .41976 L .63286 .41851 L F
1 .813 .5 r
.63368 .42085 m .63286 .41851 L .63186 .41976 L F
.63368 .42085 m .63513 .41926 L .63286 .41851 L F
.999 .822 .484 r
.76371 .41988 m .76497 .41911 L .76399 .41796 L F
.76371 .41988 m .76441 .4225 L .76497 .41911 L F
.608 .72 .924 r
.74047 .40195 m .74361 .40205 L .7423 .39832 L F
.464 .32 .599 r
.38058 .60077 m .38289 .60333 L .38254 .60052 L F
.38058 .60077 m .38062 .60485 L .38289 .60333 L F
.838 .749 .765 r
.53628 .52418 m .53768 .52417 L .5364 .52141 L F
.907 .655 .546 r
.53621 .52651 m .53768 .52417 L .53628 .52418 L F
.53621 .52651 m .53785 .52675 L .53768 .52417 L F
.017 0 .142 r
.23726 .59865 m .23838 .59899 L .23854 .59746 L F
.23726 .59865 m .23629 .60094 L .23838 .59899 L F
.279 .657 .969 r
.2069 .65481 m .20679 .65378 L .20467 .6541 L F
.2069 .65481 m .20851 .65495 L .20679 .65378 L F
.969 .769 .578 r
.61451 .48113 m .61692 .48087 L .61666 .47933 L F
.957 .892 .723 r
.61493 .48446 m .61692 .48087 L .61451 .48113 L F
.093 0 0 r
.19919 .71128 m .19833 .7114 L .19621 .71129 L F
.976 .894 .539 r
.19913 .70755 m .19919 .71128 L .19914 .70849 L F
.19913 .70755 m .19833 .7114 L .19919 .71128 L F
.743 .696 .807 r
.77594 .41104 m .77287 .40936 L .77588 .40939 L F
.493 .393 .67 r
.37884 .60764 m .3809 .60704 L .38062 .60485 L F
.47 .327 .604 r
.37884 .60764 m .38109 .60964 L .3809 .60704 L F
.383 .324 .667 r
.3794 .61021 m .38109 .60964 L .37884 .60764 L F
.901 .493 .099 r
.4412 .65154 m .44193 .65202 L .44046 .64954 L F
.133 .247 .716 r
.44193 .65202 m .44392 .65441 L .4428 .65238 L F
0 0 .105 r
.44202 .65384 m .44193 .65202 L .4412 .65154 L F
0 0 .319 r
.51749 .56234 m .51826 .56602 L .51812 .56436 L F
.106 .273 .752 r
.5193 .56784 m .51812 .56436 L .51826 .56602 L F
.561 .503 .748 r
.60157 .45139 m .60257 .45511 L .60015 .45575 L F
.735 .766 .878 r
.72832 .43408 m .72921 .43691 L .73179 .43465 L F
.272 .731 .952 r
.46076 .56072 m .46385 .56067 L .46484 .56133 L F
.408 0 0 r
.46385 .56067 m .46719 .56066 L .46484 .56133 L F
0 0 0 r
.22799 .64578 m .22475 .64825 L .22619 .64667 L F
.862 .879 .848 r
.67937 .45421 m .68058 .45545 L .68309 .45252 L F
.05 0 0 r
.69837 .39394 m .695 .39552 L .69748 .39477 L F
.118 0 0 r
.69999 .3942 m .69837 .39394 L .69748 .39477 L F
.69999 .3942 m .70088 .39324 L .69837 .39394 L F
0 .157 .677 r
.66303 .40433 m .66545 .40739 L .66415 .40807 L F
.108 .493 .902 r
.66627 .40786 m .66415 .40807 L .66545 .40739 L F
.746 .755 .859 r
.69018 .44571 m .69406 .44611 L .69328 .44333 L F
.766 .779 .863 r
.69328 .44333 m .69406 .44611 L .69658 .44341 L F
.673 .615 .782 r
.69406 .44611 m .6976 .44717 L .69658 .44341 L F
.545 .722 .956 r
.66918 .40669 m .67018 .40863 L .67268 .408 L F
.773 .446 .433 r
.437 .65104 m .44046 .64954 L .43841 .6465 L F
.437 .65104 m .4412 .65154 L .44046 .64954 L F
.693 .73 .879 r
.71804 .42859 m .71452 .4277 L .71727 .42534 L F
.766 .741 .83 r
.72069 .42577 m .71804 .42859 L .71727 .42534 L F
.989 .746 .469 r
.49717 .59557 m .49569 .59732 L .49568 .59378 L F
.49717 .59557 m .49703 .59847 L .49569 .59732 L F
.564 .761 .97 r
.49806 .5936 m .49717 .59557 L .49568 .59378 L F
.583 .782 .974 r
.49806 .5936 m .50037 .59524 L .49717 .59557 L F
.781 .666 .737 r
.50037 .59524 m .49703 .59847 L .49717 .59557 L F
.505 .583 .867 r
.75589 .38891 m .75342 .38913 L .75202 .38613 L F
.237 .326 .753 r
.50194 .57313 m .50375 .57416 L .50239 .57451 L F
.516 .504 .782 r
.50533 .57754 m .50239 .57451 L .50375 .57416 L F
0 .241 .753 r
.5233 .57736 m .52511 .58067 L .52564 .57942 L F
0 0 .564 r
.52511 .58067 m .52658 .58293 L .52564 .57942 L F
.918 .897 .792 r
.447 .59266 m .44354 .59535 L .4435 .59278 L F
.339 .088 .379 r
.42972 .61204 m .42866 .61333 L .42906 .61065 L F
.53 .169 .299 r
.43173 .61059 m .42972 .61204 L .42906 .61065 L F
.217 0 .303 r
.56675 .4734 m .56825 .47443 L .56907 .47268 L F
.56675 .4734 m .56638 .47561 L .56825 .47443 L F
.834 .995 .849 r
.50741 .5274 m .50418 .52953 L .50593 .5265 L F
.502 .717 .968 r
.50805 .52546 m .50856 .52744 L .50741 .5274 L F
.661 .881 .98 r
.50741 .5274 m .50593 .5265 L .50805 .52546 L F
.27 .226 .624 r
.56161 .56774 m .56199 .57133 L .56038 .57174 L F
.288 .295 .694 r
.56199 .57133 m .56264 .57369 L .56038 .57174 L F
.366 .301 .65 r
.56264 .57369 m .56101 .57459 L .56038 .57174 L F
.151 0 .172 r
.58755 .45495 m .58967 .45417 L .58981 .45245 L F
0 0 .089 r
.58981 .45245 m .58967 .45417 L .59124 .45084 L F
.208 0 .291 r
.54673 .55135 m .54883 .55008 L .54898 .5482 L F
.655 .43 .566 r
.54883 .55008 m .55138 .54741 L .54898 .5482 L F
.821 .816 .845 r
.50567 .53837 m .50418 .53975 L .5024 .53825 L F
.133 .241 .711 r
.78413 .40898 m .78473 .41205 L .78286 .41074 L F
.144 0 0 r
.1755 .63041 m .173 .63147 L .17116 .63121 L F
.1755 .63041 m .17343 .6313 L .173 .63147 L F
.664 .55 .715 r
.37912 .62494 m .38276 .62525 L .38208 .62223 L F
.356 .077 .345 r
.3999 .58998 m .40143 .59128 L .40207 .58928 L F
.3999 .58998 m .39933 .59201 L .40143 .59128 L F
.561 .381 .594 r
.44094 .61698 m .44026 .61941 L .44312 .61673 L F
.688 .809 .94 r
.74697 .38854 m .7437 .38814 L .74575 .38621 L F
.725 .687 .814 r
.74575 .38621 m .74939 .38685 L .74697 .38854 L F
.868 .654 .611 r
.6021 .47657 m .60172 .47902 L .60016 .47487 L F
.718 .887 .958 r
.64672 .431 m .64678 .433 L .64822 .43191 L F
.393 .744 .992 r
.51302 .59062 m .51423 .59171 L .51199 .59201 L F
.582 .841 .484 r
.51199 .59201 m .51034 .5939 L .51302 .59062 L F
.413 .247 .544 r
.51423 .59171 m .51199 .595 L .51199 .59201 L F
.564 .731 .953 r
.21249 .65625 m .21286 .65384 L .21088 .6541 L F
.21249 .65625 m .21473 .65577 L .21286 .65384 L F
.706 .859 .955 r
.63094 .42583 m .6339 .42597 L .63279 .42488 L F
.863 .912 .863 r
.63279 .42488 m .6339 .42597 L .63401 .42471 L F
.628 .88 .539 r
.67824 .44364 m .67572 .44668 L .67701 .44487 L F
.779 .375 0 r
.67572 .44668 m .67668 .44877 L .67586 .44777 L F
.67572 .44668 m .67586 .44777 L .67701 .44487 L F
.676 .414 .519 r
.44839 .58216 m .45041 .58566 L .45041 .58322 L F
.44839 .58216 m .44671 .58577 L .45041 .58566 L F
.612 .577 .79 r
.69658 .44341 m .6976 .44717 L .7002 .44641 L F
.731 .525 .613 r
.506 .59841 m .50927 .5954 L .5073 .59901 L F
.633 .526 .715 r
.51048 .59751 m .5073 .59901 L .50927 .5954 L F
.159 0 0 r
.50958 .59863 m .5073 .59901 L .51048 .59751 L F
.50958 .59863 m .5062 .5997 L .5073 .59901 L F
.546 .374 .6 r
.59056 .4725 m .58805 .47064 L .59061 .47028 L F
.59056 .4725 m .58802 .47319 L .58805 .47064 L F
.373 .747 .99 r
.23216 .55398 m .22881 .55322 L .23072 .55362 L F
.499 .628 .908 r
.61647 .43524 m .615 .43738 L .61423 .43591 L F
.386 .473 .827 r
.61647 .43524 m .61702 .43728 L .615 .43738 L F
.638 .545 .733 r
.61829 .44046 m .615 .43738 L .61702 .43728 L F
.583 .567 .801 r
.48959 .5646 m .4883 .56821 L .48753 .56518 L F
.48959 .5646 m .49066 .56752 L .4883 .56821 L F
.939 .591 .176 r
.20369 .67411 m .20373 .67543 L .2025 .67216 L F
.67 .287 .312 r
.20369 .67411 m .20373 .67543 L .20559 .67472 L F
.381 .207 .516 r
.4259 .64014 m .42585 .64274 L .42395 .64313 L F
.605 .575 .793 r
.42585 .64274 m .42419 .64496 L .42395 .64313 L F
.806 .502 .476 r
.62329 .4344 m .61936 .4317 L .62317 .432 L F
.856 .554 .476 r
.76402 .41021 m .76699 .41286 L .76498 .41119 L F
0 0 .143 r
.58405 .53898 m .5861 .53578 L .58595 .53821 L F
.334 .124 .438 r
.58381 .54125 m .58405 .53898 L .58595 .53821 L F
.821 .815 .844 r
.50567 .53837 m .5024 .53825 L .5041 .53674 L F
.77 .809 .884 r
.50613 .53705 m .50567 .53837 L .5041 .53674 L F
.58 .344 .523 r
.22029 .62215 m .22279 .62192 L .22311 .6195 L F
.419 .205 .479 r
.22311 .6195 m .2248 .62132 L .22523 .61898 L F
.22311 .6195 m .22279 .62192 L .2248 .62132 L F
.501 .326 .576 r
.24554 .58302 m .24786 .58005 L .2457 .58068 L F
.426 0 .118 r
.44658 .5679 m .44942 .56758 L .45035 .56582 L F
.746 .835 .92 r
.45099 .5631 m .45035 .56582 L .45268 .56528 L F
.45099 .5631 m .44854 .56581 L .45035 .56582 L F
0 0 0 r
.45035 .56582 m .45116 .56654 L .45268 .56528 L F
.45035 .56582 m .44942 .56758 L .45116 .56654 L F
.529 .344 .574 r
.46727 .64328 m .46974 .64545 L .46961 .64279 L F
.46727 .64328 m .46728 .64591 L .46974 .64545 L F
.46727 .64328 m .46974 .64545 L .46961 .64279 L F
.46727 .64328 m .46728 .64591 L .46974 .64545 L F
.502 .139 .283 r
.47516 .58405 m .47801 .58265 L .47629 .58414 L F
0 .316 .802 r
.47585 .56126 m .47608 .56236 L .47559 .56198 L F
.47585 .56126 m .47692 .56288 L .47608 .56236 L F
.243 0 .193 r
.5797 .46171 m .57694 .46425 L .57921 .46327 L F
.336 0 .229 r
.5797 .46171 m .58159 .46253 L .58206 .46098 L F
.5797 .46171 m .57921 .46327 L .58159 .46253 L F
.664 .376 .474 r
.55976 .54414 m .55752 .54208 L .55721 .54462 L F
.55976 .54414 m .55987 .542 L .55752 .54208 L F
.837 .91 .506 r
.19696 .69804 m .19497 .70273 L .19496 .70156 L F
0 0 .194 r
.19497 .70273 m .19533 .7039 L .19496 .70156 L F
.19497 .70273 m .19558 .70552 L .19533 .7039 L F
.314 0 .147 r
.61829 .41099 m .62024 .41164 L .62077 .41036 L F
.61829 .41099 m .6177 .41244 L .62024 .41164 L F
.579 .633 .869 r
.56358 .58043 m .56287 .58369 L .56228 .58023 L F
.56358 .58043 m .56582 .58329 L .56287 .58369 L F
.481 .304 .564 r
.56527 .58566 m .56298 .58665 L .56287 .58369 L F
.179 .709 .848 r
.23019 .54067 m .23232 .54048 L .23384 .54065 L F
.197 0 0 r
.23232 .54048 m .2362 .54012 L .23384 .54065 L F
.604 .281 .397 r
.57089 .55304 m .57115 .55108 L .57345 .55283 L F
.58 .295 .448 r
.57115 .55108 m .57354 .55089 L .57345 .55283 L F
.785 .949 .927 r
.51756 .52077 m .51389 .52211 L .51676 .52002 L F
.808 1 .817 r
.51855 .51854 m .51756 .52077 L .51676 .52002 L F
.51855 .51854 m .52037 .51795 L .51756 .52077 L F
.596 .932 .732 r
.60514 .4422 m .60351 .44372 L .60646 .44135 L F
.296 .206 .581 r
.60578 .44434 m .60351 .44372 L .60514 .4422 L F
.60578 .44434 m .60394 .44622 L .60351 .44372 L F
.071 .628 .805 r
.22026 .53931 m .22219 .53928 L .22407 .53957 L F
.263 .741 .935 r
.22219 .53928 m .22643 .53967 L .22407 .53957 L F
.962 .808 .642 r
.49711 .54237 m .49569 .54196 L .49664 .53657 L F
.89 .525 .345 r
.49711 .54237 m .49566 .54378 L .49569 .54196 L F
.49711 .54237 m .49749 .54429 L .49566 .54378 L F
.561 .398 .618 r
.47575 .64018 m .47594 .64327 L .47344 .64333 L F
.47575 .64018 m .47594 .64327 L .47344 .64333 L F
.631 .84 .98 r
.19577 .54099 m .19371 .54193 L .19198 .54085 L F
.572 0 0 r
.53644 .60514 m .53591 .60585 L .53454 .60394 L F
.53644 .60514 m .53883 .60673 L .53591 .60585 L F
.5 .292 .529 r
.56483 .53592 m .5672 .5354 L .56732 .53304 L F
.486 .356 .629 r
.56483 .53592 m .56736 .53784 L .5672 .5354 L F
.56483 .53592 m .56517 .53855 L .56736 .53784 L F
.956 .931 .728 r
.48777 .57441 m .48819 .57634 L .48991 .57554 L F
.48777 .57441 m .48665 .57677 L .48819 .57634 L F
.785 .321 .138 r
.48665 .57677 m .48954 .57773 L .48819 .57634 L F
.445 .405 .719 r
.48819 .57634 m .48954 .57773 L .48991 .57554 L F
.465 .245 .495 r
.57772 .52401 m .57997 .52334 L .58017 .52111 L F
.419 .236 .524 r
.58017 .52111 m .58227 .52035 L .58231 .51793 L F
.258 .022 .353 r
.57997 .52334 m .58227 .52035 L .58017 .52111 L F
.559 .627 .876 r
.47184 .6076 m .46815 .60591 L .46996 .60532 L F
0 0 0 r
.46996 .60532 m .46815 .60591 L .46807 .60597 L F
.711 .443 .518 r
.427 .64568 m .42915 .64803 L .4307 .64611 L F
.647 .285 .344 r
.42915 .64803 m .43288 .64819 L .4307 .64611 L F
.618 .294 .399 r
.4307 .64611 m .43288 .64819 L .43348 .64633 L F
.281 .782 .786 r
.71077 .39846 m .71169 .39839 L .71428 .39765 L F
.212 0 0 r
.23857 .53991 m .24251 .54044 L .24007 .54083 L F
.588 .195 .265 r
.43233 .58872 m .42953 .58891 L .42994 .5871 L F
.659 .518 .681 r
.43241 .58357 m .43325 .5875 L .42994 .5871 L F
.6 .178 .213 r
.43325 .5875 m .43233 .58872 L .42994 .5871 L F
.633 .668 .865 r
.44297 .57767 m .439 .57563 L .4411 .57599 L F
.608 .391 .561 r
.44297 .57767 m .443 .58035 L .44076 .58045 L F
.809 .856 .884 r
.44551 .57466 m .44297 .57767 L .4411 .57599 L F
.708 .674 .815 r
.44739 .5769 m .44297 .57767 L .44551 .57466 L F
.332 .049 .325 r
.575 .52667 m .5773 .52593 L .57772 .52401 L F
.447 .166 .394 r
.5773 .52593 m .57997 .52334 L .57772 .52401 L F
.716 .757 .885 r
.6064 .45577 m .60257 .45511 L .60494 .45433 L F
0 .124 .66 r
.66777 .39822 m .66901 .40194 L .6688 .3999 L F
.166 .407 .849 r
.66901 .40194 m .67 .40063 L .6688 .3999 L F
.66901 .40194 m .67242 .40407 L .67 .40063 L F
.684 .437 .543 r
.55176 .60393 m .54862 .60643 L .54893 .60499 L F
.599 .323 .47 r
.55976 .54414 m .56244 .54188 L .55987 .542 L F
.632 .604 .803 r
.70256 .44545 m .70394 .44892 L .70634 .44641 L F
.566 .35 .547 r
.56333 .55698 m .56577 .55892 L .56341 .55961 L F
.56333 .55698 m .56587 .55647 L .56577 .55892 L F
0 0 .504 r
.78363 .41548 m .78384 .41911 L .78316 .41705 L F
.677 .343 .402 r
.45823 .56982 m .45641 .56855 L .46072 .56817 L F
.708 .366 .395 r
.46072 .56817 m .46221 .57093 L .45823 .56982 L F
.393 .103 .349 r
.44186 .58882 m .44451 .58615 L .44237 .58705 L F
.402 .785 .991 r
.75727 .43669 m .75616 .43593 L .75375 .43612 L F
.525 .769 .986 r
.75727 .43669 m .75875 .43508 L .75616 .43593 L F
.75727 .43669 m .75986 .43636 L .75875 .43508 L F
.855 .972 .867 r
.51828 .536 m .51726 .53544 L .51858 .53389 L F
.51828 .536 m .51726 .53544 L .51858 .53389 L F
.963 .805 .639 r
.61666 .47933 m .61619 .47566 L .61563 .47849 L F
.969 .769 .578 r
.61451 .48113 m .61666 .47933 L .61563 .47849 L F
.464 .222 .461 r
.42904 .60085 m .427 .59943 L .42869 .598 L F
.565 .275 .434 r
.575 .52667 m .57208 .52951 L .5744 .5289 L F
.532 .263 .452 r
.5744 .5289 m .5773 .52593 L .575 .52667 L F
.542 .382 .613 r
.74664 .41227 m .74849 .41314 L .74764 .41163 L F
.732 .354 .335 r
.49716 .58126 m .49943 .58377 L .49537 .58233 L F
.777 .305 .12 r
.50061 .58355 m .49716 .58126 L .4996 .5804 L F
.50061 .58355 m .49943 .58377 L .49716 .58126 L F
.871 .472 .012 r
.5378 .55722 m .53458 .55871 L .5348 .55685 L F
.5378 .55722 m .53676 .55656 L .53458 .55871 L F
.5378 .55722 m .53832 .55936 L .53676 .55656 L F
.552 .379 .6 r
.58703 .45757 m .58967 .45417 L .58755 .45495 L F
.349 .334 .701 r
.78271 .40063 m .78142 .40485 L .78078 .40252 L F
.78271 .40063 m .7837 .40319 L .78142 .40485 L F
.282 .214 .601 r
.7837 .40319 m .78345 .40657 L .78142 .40485 L F
0 0 0 r
.20018 .70526 m .20114 .70293 L .20225 .70141 L F
.338 .137 .453 r
.27763 .55638 m .27686 .55894 L .27519 .55919 L F
.592 .463 .674 r
.27796 .5622 m .27519 .55919 L .27686 .55894 L F
.27796 .5622 m .2764 .56344 L .27519 .55919 L F
.518 .385 .638 r
.41574 .6246 m .41267 .62686 L .41312 .62493 L F
.41574 .6246 m .41613 .6272 L .41267 .62686 L F
.79 .682 .745 r
.41613 .6272 m .41312 .63061 L .41267 .62686 L F
.511 .236 .434 r
.45603 .59217 m .4555 .59483 L .4531 .59517 L F
.553 .295 .479 r
.45812 .59179 m .4555 .59483 L .45603 .59217 L F
.57 .154 .214 r
.45404 .56876 m .45647 .57026 L .45301 .57035 L F
.518 .22 .401 r
.45641 .56855 m .45647 .57026 L .45404 .56876 L F
.571 .392 .6 r
.5672 .5354 m .56974 .53234 L .56732 .53304 L F
.806 .502 .476 r
.62329 .4344 m .61929 .43387 L .61936 .4317 L F
0 0 0 r
.62329 .4344 m .62069 .43726 L .62245 .43545 L F
.62329 .4344 m .62245 .43545 L .61929 .43387 L F
.567 .549 .794 r
.62554 .43446 m .62329 .4344 L .62606 .43379 L F
.483 .83 .553 r
.21033 .63367 m .20679 .63672 L .20877 .63558 L F
0 0 .067 r
.21268 .6303 m .21033 .63367 L .21147 .63319 L F
0 0 0 r
.21147 .63319 m .21033 .63367 L .20877 .63558 L F
.769 .819 .892 r
.73308 .42785 m .73637 .42798 L .73432 .42939 L F
.007 0 0 r
.54929 .56476 m .54522 .56616 L .54708 .56658 L F
.294 0 0 r
.54929 .56476 m .5503 .56637 L .54806 .5654 L F
.963 .658 .247 r
.5503 .56637 m .54971 .56515 L .54806 .5654 L F
.007 0 0 r
.54929 .56476 m .54806 .5654 L .54696 .56556 L F
.558 .686 .925 r
.5501 .56176 m .54837 .56287 L .54797 .56233 L F
.574 .662 .897 r
.5501 .56176 m .54929 .56476 L .54797 .56233 L F
.963 .658 .247 r
.54971 .56515 m .54842 .56246 L .54806 .5654 L F
.007 0 0 r
.54696 .56556 m .54806 .5654 L .54522 .56616 L F
.973 .758 .553 r
.7637 .42734 m .76535 .42603 L .76402 .4249 L F
.7637 .42734 m .76503 .42872 L .76535 .42603 L F
.051 0 .183 r
.40495 .58576 m .40583 .58734 L .40677 .58616 L F
.40495 .58576 m .4042 .58858 L .40583 .58734 L F
0 0 .148 r
.20086 .6856 m .20143 .68481 L .20199 .67983 L F
.604 .933 .722 r
.20086 .6856 m .19861 .687 L .20143 .68481 L F
.924 .614 .438 r
.74854 .42563 m .74751 .42746 L .74752 .42449 L F
.74854 .42563 m .7493 .42821 L .74751 .42746 L F
.963 .872 .699 r
.74861 .4216 m .74854 .42563 L .74752 .42449 L F
.948 .932 .748 r
.61101 .44946 m .61205 .44538 L .61288 .44827 L F
.61101 .44946 m .61015 .44843 L .61205 .44538 L F
.862 .879 .848 r
.67937 .45421 m .68309 .45252 L .68156 .45117 L F
.818 .804 .838 r
.68156 .45117 m .68309 .45252 L .68571 .44965 L F
.586 .033 0 r
.47692 .56288 m .47941 .56438 L .48078 .56386 L F
0 0 0 r
.20258 .55487 m .2024 .55409 L .20488 .55387 L F
.20475 .55401 m .20258 .55487 L .20488 .55387 L F
.641 .813 .966 r
.20442 .55397 m .20258 .55487 L .20475 .55401 L F
0 0 0 r
.20258 .55487 m .2006 .55584 L .2024 .55409 L F
.641 .813 .966 r
.20086 .55361 m .20258 .55487 L .20442 .55397 L F
0 0 0 r
.20258 .55487 m .20054 .55591 L .2006 .55584 L F
.271 .053 .388 r
.23854 .59746 m .24074 .59464 L .23935 .5955 L F
.798 .716 .774 r
.5353 .53192 m .53305 .53561 L .53596 .53547 L F
.8 .695 .749 r
.53305 .53561 m .53381 .53866 L .53596 .53547 L F
.84 .741 .755 r
.5353 .53192 m .53596 .53547 L .53691 .53334 L F
.72 .805 .918 r
.65746 .43356 m .6609 .43324 L .65965 .43338 L F
.689 .745 .894 r
.73179 .43465 m .73555 .43541 L .73429 .43364 L F
.739 .769 .877 r
.73555 .43541 m .73771 .43407 L .73429 .43364 L F
.451 .489 .807 r
.20874 .68728 m .20717 .68802 L .2057 .68506 L F
.473 .228 .462 r
.20881 .68857 m .20717 .68802 L .20874 .68728 L F
.20881 .68857 m .20647 .69044 L .20717 .68802 L F
.565 .869 .995 r
.2226 .55344 m .22227 .55349 L .2244 .55372 L F
.073 .615 .849 r
.22701 .55415 m .2226 .55344 L .2244 .55372 L F
.832 .967 .89 r
.6808 .44124 m .67824 .44364 L .67773 .4426 L F
.978 .892 .538 r
.67773 .4426 m .67824 .44364 L .67701 .44487 L F
.385 .625 .948 r
.65539 .43195 m .65725 .43379 L .65746 .43356 L F
.527 .274 .475 r
.43103 .58084 m .4338 .5803 L .4342 .57736 L F
.529 .312 .529 r
.4338 .5803 m .4365 .57671 L .4342 .57736 L F
.934 .936 .583 r
.67242 .40407 m .67272 .40487 L .67118 .40647 L F
.626 .625 .83 r
.74453 .39307 m .74837 .39554 L .74708 .39217 L F
.539 .582 .846 r
.74708 .39217 m .74837 .39554 L .7509 .39523 L F
.001 0 0 r
.54774 .55199 m .54673 .55135 L .54544 .55264 L F
.54774 .55199 m .54883 .55008 L .54673 .55135 L F
.774 .488 .502 r
.59669 .47048 m .59662 .47268 L .59293 .47223 L F
.804 .515 .499 r
.60023 .47319 m .59662 .47268 L .59669 .47048 L F
.463 .101 .265 r
.21805 .62533 m .21959 .62629 L .22036 .62494 L F
.21805 .62533 m .21522 .62909 L .21578 .62873 L F
.051 0 .126 r
.21268 .6303 m .214 .63043 L .21488 .62807 L F
.052 0 .106 r
.21147 .63319 m .214 .63043 L .21268 .6303 L F
0 0 .098 r
.21491 .62817 m .21587 .62842 L .21522 .62909 L F
.21488 .62807 m .21587 .62842 L .21491 .62817 L F
.21488 .62807 m .214 .63043 L .21587 .62842 L F
.732 .977 .743 r
.21587 .62842 m .21488 .62949 L .21184 .63181 L F
.463 .101 .265 r
.21909 .62598 m .21578 .62873 L .21959 .62629 L F
.21805 .62533 m .21578 .62873 L .21909 .62598 L F
.696 .982 .836 r
.21959 .62629 m .21635 .62837 L .21587 .62842 L F
.21635 .62837 m .21522 .62909 L .21587 .62842 L F
.732 .977 .743 r
.21488 .62949 m .214 .63043 L .21291 .63113 L F
.21488 .62949 m .21291 .63113 L .21184 .63181 L F
.776 .989 .753 r
.21184 .63181 m .214 .63043 L .21147 .63319 L F
.732 .977 .743 r
.21587 .62842 m .21184 .63181 L .21396 .63112 L F
.21587 .62842 m .21396 .63112 L .21414 .62849 L F
.153 0 0 r
.21414 .62849 m .21496 .62852 L .21587 .62842 L F
.21496 .62852 m .21643 .62857 L .21587 .62842 L F
.21643 .62857 m .21794 .62861 L .21587 .62842 L F
.546 .387 .617 r
.21805 .62533 m .22036 .62494 L .22029 .62215 L F
.605 .826 .985 r
.1849 .65691 m .18842 .65722 L .18842 .65708 L F
.617 .821 .979 r
.18842 .65722 m .19098 .65677 L .18842 .65708 L F
.46 .204 .438 r
.57183 .53162 m .56973 .53002 L .56974 .53234 L F
.57183 .53162 m .57208 .52951 L .56973 .53002 L F
.737 .533 .616 r
.53806 .54524 m .54069 .54227 L .53958 .54276 L F
.39 .254 .573 r
.27512 .57136 m .27467 .57422 L .27445 .57178 L F
.438 .442 .765 r
.78271 .40063 m .78078 .40252 L .7801 .3993 L F
.382 .187 .487 r
.26467 .60083 m .26238 .60414 L .26251 .60154 L F
.59 .37 .549 r
.57663 .54779 m .57673 .55024 L .57354 .55089 L F
.569 .38 .586 r
.5792 .54734 m .57673 .55024 L .57663 .54779 L F
.767 .75 .838 r
.53806 .54524 m .53896 .54709 L .53992 .54621 L F
.53806 .54524 m .53992 .54621 L .54176 .54453 L F
.613 .528 .735 r
.53443 .54338 m .53525 .54378 L .53806 .54524 L F
.737 .533 .616 r
.53806 .54524 m .54176 .54453 L .54069 .54227 L F
.613 .528 .735 r
.53525 .54378 m .53896 .54559 L .53806 .54524 L F
0 .136 .683 r
.53896 .54559 m .53881 .54678 L .53806 .54524 L F
.53896 .54559 m .53896 .54709 L .53881 .54678 L F
0 0 .077 r
.53918 .55023 m .53896 .54709 L .53896 .54559 L F
.53918 .55023 m .53896 .54559 L .53697 .54951 L F
.613 .528 .735 r
.53443 .54338 m .53541 .54676 L .53896 .54559 L F
.616 .363 .511 r
.53361 .54888 m .53896 .54559 L .53541 .54676 L F
.53641 .54715 m .53697 .54951 L .53896 .54559 L F
.53361 .54888 m .53697 .54951 L .53641 .54715 L F
.94 .571 .236 r
.53622 .54854 m .53697 .54951 L .53361 .54888 L F
.53622 .54854 m .53715 .55027 L .53697 .54951 L F
.53715 .55027 m .53774 .55136 L .53697 .54951 L F
.948 .667 .471 r
.53896 .54559 m .53828 .54837 L .53907 .54471 L F
.53896 .54559 m .53907 .54471 L .53911 .54452 L F
.798 .591 .622 r
.60016 .47487 m .59662 .47268 L .60023 .47319 L F
.804 .915 .523 r
.53451 .57629 m .536 .57449 L .53359 .57315 L F
.53451 .57629 m .53468 .57693 L .536 .57449 L F
.612 .858 .501 r
.536 .57449 m .53697 .57306 L .53822 .5717 L F
.438 .745 .992 r
.536 .57449 m .53833 .57431 L .53697 .57306 L F
.444 .752 .994 r
.53437 .57262 m .53697 .57306 L .536 .57449 L F
.173 .334 .785 r
.50355 .57269 m .50194 .57313 L .50028 .57166 L F
.50355 .57269 m .50375 .57416 L .50194 .57313 L F
.767 .637 .718 r
.69658 .44341 m .69992 .44359 L .69893 .44327 L F
.612 .577 .79 r
.69658 .44341 m .7002 .44641 L .69992 .44359 L F
.63 .612 .814 r
.69992 .44359 m .70144 .43978 L .69893 .44327 L F
.69992 .44359 m .70254 .44324 L .70144 .43978 L F
.607 .436 .624 r
.69992 .44359 m .7002 .44641 L .70254 .44324 L F
.413 .172 .436 r
.2764 .56344 m .27513 .5656 L .27317 .56609 L F
.493 .396 .674 r
.27513 .5656 m .27595 .56759 L .27317 .56609 L F
.969 .848 .666 r
.66721 .41992 m .66673 .41647 L .66574 .41882 L F
.377 .193 .5 r
.45989 .58333 m .45971 .58615 L .45779 .58668 L F
.408 .277 .589 r
.45971 .58615 m .46004 .58757 L .45779 .58668 L F
.629 .944 .952 r
.63782 .40247 m .64003 .40122 L .6409 .40163 L F
.571 .93 .939 r
.6409 .40163 m .64231 .40021 L .64387 .40027 L F
.563 .916 .96 r
.6409 .40163 m .64003 .40122 L .64231 .40021 L F
.703 .782 .913 r
.62719 .41694 m .63006 .41794 L .63115 .41711 L F
.061 .592 .864 r
.49066 .56752 m .49281 .56781 L .49444 .56843 L F
0 .091 .632 r
.49551 .56898 m .49444 .56843 L .49281 .56781 L F
.49551 .56898 m .49665 .57064 L .49444 .56843 L F
.703 .163 0 r
.4701 .60086 m .46883 .60057 L .46681 .59846 L F
.285 .251 .644 r
.46681 .59846 m .46883 .60057 L .46811 .59824 L F
.694 .731 .88 r
.47559 .56198 m .47131 .56266 L .4696 .55988 L F
.534 .923 .892 r
.73847 .39312 m .74113 .39195 L .73999 .39178 L F
.73847 .39312 m .73999 .39178 L .73708 .39617 L F
.008 0 .066 r
.60837 .42273 m .60582 .42566 L .60748 .42434 L F
0 0 .218 r
.60732 .42643 m .60748 .42434 L .60582 .42566 L F
.219 .217 .643 r
.60582 .42566 m .60676 .42863 L .60732 .42643 L F
.358 .012 .233 r
.39638 .59418 m .39933 .59201 L .39715 .59264 L F
.524 .547 .822 r
.44784 .57381 m .44739 .5769 L .44551 .57466 L F
.44784 .57381 m .44911 .5771 L .44739 .5769 L F
.724 .816 .922 r
.54076 .58341 m .5373 .58356 L .53868 .58272 L F
.771 .584 .645 r
.54076 .58341 m .53638 .58582 L .5373 .58356 L F
.471 .789 .999 r
.54179 .58195 m .54076 .58341 L .53868 .58272 L F
.929 .719 .234 r
.54179 .58195 m .54243 .58562 L .54076 .58341 L F
.425 .192 .456 r
.27167 .58675 m .27135 .58877 L .26928 .58937 L F
.516 .379 .633 r
.27155 .59194 m .26928 .58937 L .27135 .58877 L F
.27155 .59194 m .26946 .59258 L .26928 .58937 L F
.729 .434 .48 r
.61936 .4317 m .61646 .43359 L .61692 .43182 L F
.61936 .4317 m .61929 .43387 L .61646 .43359 L F
.412 .723 .989 r
.25965 .54406 m .25936 .54562 L .25807 .544 L F
.25965 .54406 m .26121 .54516 L .25936 .54562 L F
.518 .356 .601 r
.24692 .57397 m .24931 .57401 L .24919 .57136 L F
.381 .264 .593 r
.24758 .57756 m .24931 .57401 L .24692 .57397 L F
.401 .149 .413 r
.26738 .59532 m .26683 .59784 L .26474 .59844 L F
.57 .446 .672 r
.26946 .59258 m .26961 .59492 L .26738 .59532 L F
.388 .138 .408 r
.26907 .59697 m .26738 .59532 L .26961 .59492 L F
.26907 .59697 m .26683 .59784 L .26738 .59532 L F
.088 0 .024 r
.47112 .60946 m .46899 .6101 L .47184 .6076 L F
.302 0 .105 r
.47337 .60824 m .47184 .6076 L .4741 .60703 L F
.47337 .60824 m .47112 .60946 L .47184 .6076 L F
.584 .687 .912 r
.4741 .60703 m .47184 .6076 L .46996 .60532 L F
.757 .512 .563 r
.54081 .58898 m .54428 .58661 L .54243 .58562 L F
.54081 .58898 m .54447 .5892 L .54428 .58661 L F
.407 .838 .952 r
.47125 .60002 m .4701 .60086 L .47316 .59908 L F
.327 .782 .951 r
.47507 .60013 m .47125 .60002 L .47316 .59908 L F
.375 .089 .345 r
.47521 .59821 m .47507 .60013 L .47316 .59908 L F
0 0 .197 r
.54176 .54453 m .54288 .54116 L .54069 .54227 L F
.615 .939 .732 r
.5216 .51647 m .52315 .51574 L .52037 .51795 L F
.623 .957 .814 r
.5216 .51647 m .52037 .51795 L .51855 .51854 L F
0 0 0 r
.70411 .39218 m .70088 .39324 L .70308 .39345 L F
.198 0 0 r
.70559 .39312 m .70411 .39218 L .70308 .39345 L F
.70559 .39312 m .70657 .39157 L .70411 .39218 L F
.69 .827 .949 r
.44604 .60416 m .44393 .60465 L .44221 .60368 L F
.681 .198 .097 r
.44604 .60416 m .44221 .60368 L .44393 .60465 L F
.683 .519 .658 r
.44604 .60416 m .44353 .60726 L .44393 .60465 L F
.447 .239 .503 r
.57452 .48196 m .57461 .48413 L .57201 .4845 L F
.468 .119 .29 r
.57461 .48413 m .57144 .48531 L .57201 .4845 L F
.701 .703 .848 r
.70634 .44641 m .70984 .44847 L .70878 .44553 L F
.723 .719 .846 r
.70878 .44553 m .70984 .44847 L .71247 .44614 L F
.379 .153 .441 r
.23822 .63665 m .23582 .63967 L .23611 .63724 L F
.395 .293 .619 r
.60748 .42434 m .60956 .421 L .60837 .42273 L F
.37 0 .08 r
.16497 .54962 m .16903 .54726 L .16697 .54795 L F
.128 0 0 r
.70578 .3998 m .70754 .39999 L .70506 .40089 L F
.70578 .3998 m .70821 .39897 L .70754 .39999 L F
.608 .873 .992 r
.72141 .38853 m .71893 .38947 L .71784 .38848 L F
1 .801 .486 r
.43626 .6316 m .43584 .63213 L .43527 .63049 L F
.47 .735 .985 r
.43826 .62985 m .43626 .6316 L .43527 .63049 L F
.09 0 0 r
.43766 .63236 m .43584 .63213 L .43626 .6316 L F
.604 .855 .991 r
.42616 .58359 m .42333 .5835 L .42477 .58278 L F
.4224 .58348 m .42616 .58359 L .42477 .58278 L F
0 0 0 r
.42477 .58278 m .42318 .58442 L .42614 .58209 L F
.583 .574 .809 r
.42333 .57913 m .42477 .58278 L .42754 .5816 L F
0 0 0 r
.42477 .58278 m .42624 .582 L .42754 .5816 L F
.42477 .58278 m .42614 .58209 L .42624 .582 L F
.604 .855 .991 r
.42333 .5835 m .4224 .58348 L .42477 .58278 L F
.487 .798 .999 r
.71675 .3973 m .71788 .39835 L .72032 .3979 L F
.865 .673 .64 r
.54785 .54457 m .54843 .54211 L .54614 .54107 L F
.826 .484 .409 r
.44451 .58615 m .44956 .58874 L .44671 .58577 L F
.44451 .58615 m .44429 .5882 L .44956 .58874 L F
.465 0 .043 r
.44432 .59088 m .44956 .58874 L .44429 .5882 L F
.44432 .59088 m .44683 .59088 L .44956 .58874 L F
0 0 .327 r
.44956 .58874 m .45041 .58566 L .44671 .58577 L F
.44956 .58874 m .45088 .58799 L .45041 .58566 L F
.849 .51 .411 r
.44956 .58874 m .44879 .59073 L .45088 .58799 L F
.44956 .58874 m .44683 .59088 L .44879 .59073 L F
.673 .568 .729 r
.49391 .58295 m .49107 .58587 L .49104 .58347 L F
.531 .582 .851 r
.61324 .43389 m .61423 .43591 L .61088 .4346 L F
.689 .394 .47 r
.61423 .43591 m .61101 .43657 L .61088 .4346 L F
.327 .002 .253 r
.5741 .46651 m .57652 .46564 L .57694 .46425 L F
.411 .139 .387 r
.57652 .46564 m .57921 .46327 L .57694 .46425 L F
.528 .295 .506 r
.46632 .56876 m .46612 .571 L .46331 .57114 L F
.613 .151 .131 r
.46612 .571 m .46221 .57093 L .46331 .57114 L F
.494 .26 .488 r
.47594 .64327 m .47816 .64009 L .47575 .64018 L F
.47594 .64327 m .47816 .64009 L .47575 .64018 L F
.618 .824 .979 r
.24744 .56514 m .25157 .56561 L .24949 .56235 L F
.285 .454 .853 r
.25157 .56561 m .25261 .56402 L .24949 .56235 L F
.25157 .56561 m .25272 .56499 L .25261 .56402 L F
.465 .438 .744 r
.2518 .56818 m .25272 .56499 L .25157 .56561 L F
.325 .416 .801 r
.49455 .58716 m .49698 .58824 L .49512 .58937 L F
.491 .246 .471 r
.49698 .58824 m .49438 .59075 L .49512 .58937 L F
.633 .385 .524 r
.44632 .6178 m .44845 .61899 L .44872 .61628 L F
.44632 .6178 m .44845 .61899 L .44872 .61628 L F
.464 .24 .488 r
.44872 .61628 m .44845 .61899 L .45081 .61816 L F
.45081 .61816 m .44845 .61899 L .44872 .61628 L F
.69 .827 .949 r
.44604 .60416 m .44232 .60162 L .44378 .5988 L F
.44604 .60416 m .44221 .60368 L .44232 .60162 L F
.681 .198 .097 r
.44604 .60416 m .44434 .60564 L .44221 .60368 L F
.433 .453 .781 r
.44823 .60301 m .44604 .60416 L .44378 .5988 L F
.179 0 0 r
.44823 .60301 m .44434 .60564 L .44604 .60416 L F
.741 .257 0 r
.50833 .55441 m .50998 .55652 L .50833 .55473 L F
.461 .383 .683 r
.3794 .61021 m .38193 .61245 L .38109 .60964 L F
.3794 .61021 m .37963 .61371 L .38193 .61245 L F
.876 .482 .286 r
.50061 .58355 m .49926 .58507 L .49943 .58377 L F
.555 .382 .601 r
.50306 .58039 m .50061 .58355 L .4996 .5804 L F
.50306 .58039 m .50298 .58323 L .50061 .58355 L F
0 0 0 r
.50112 .58361 m .50061 .58355 L .50298 .58323 L F
.50112 .58361 m .49926 .58507 L .50061 .58355 L F
.367 .409 .773 r
.2481 .56282 m .24949 .56235 L .24833 .5586 L F
.21 0 .342 r
.2481 .56282 m .24744 .56514 L .24949 .56235 L F
.097 0 .299 r
.54889 .49089 m .54998 .49179 L .55072 .49031 L F
.54889 .49089 m .54849 .49352 L .54998 .49179 L F
.516 .331 .568 r
.27414 .58342 m .27405 .58631 L .27167 .58675 L F
.28 0 .256 r
.27405 .58631 m .27135 .58877 L .27167 .58675 L F
.945 .938 .599 r
.65338 .40873 m .65247 .41303 L .65248 .41062 L F
0 0 .53 r
.53451 .57629 m .53644 .57912 L .53468 .57693 L F
.993 .768 .492 r
.53305 .53561 m .53256 .53783 L .53381 .53866 L F
.938 .81 .354 r
.53301 .54019 m .53381 .53866 L .53256 .53783 L F
.53301 .54019 m .53326 .5417 L .53381 .53866 L F
.714 .983 .794 r
.75421 .39547 m .7547 .39577 L .75593 .39384 L F
0 .048 .557 r
.75593 .39384 m .7547 .39577 L .75579 .39793 L F
.304 .798 .82 r
.17311 .56251 m .17192 .56258 L .1695 .56327 L F
.693 .975 .915 r
.17354 .56111 m .17311 .56251 L .17521 .56106 L F
.724 .989 .868 r
.17354 .56111 m .17192 .56258 L .17311 .56251 L F
.985 .712 .411 r
.53697 .57306 m .53833 .57431 L .53822 .5717 L F
0 .408 .81 r
.64387 .40027 m .64538 .40089 L .64694 .40201 L F
.345 0 0 r
.64639 .40224 m .64991 .40308 L .64694 .40201 L F
0 0 .451 r
.43017 .63534 m .42738 .63701 L .43008 .6345 L F
.472 .252 .498 r
.43017 .63534 m .43067 .63933 L .42825 .63971 L F
.671 .898 .977 r
.43187 .63421 m .43017 .63534 L .43008 .6345 L F
.282 .123 .479 r
.43249 .63823 m .43017 .63534 L .43187 .63421 L F
.43249 .63823 m .43067 .63933 L .43017 .63534 L F
.824 .84 .373 r
.59171 .50039 m .59125 .50044 L .59208 .49844 L F
.59171 .50039 m .59094 .5025 L .59125 .50044 L F
.016 0 .104 r
.42738 .63701 m .42949 .63621 L .43008 .6345 L F
.904 .806 .742 r
.67547 .45514 m .67359 .45505 L .6755 .45113 L F
.262 .594 .949 r
.67547 .45514 m .67608 .45411 L .67359 .45505 L F
.67547 .45514 m .67752 .45569 L .67608 .45411 L F
.55 .317 .515 r
.55955 .59847 m .55952 .60096 L .557 .60123 L F
.48 .226 .452 r
.56228 .5981 m .55952 .60096 L .55955 .59847 L F
.38 .107 .369 r
.43609 .60912 m .43483 .60724 L .43695 .60608 L F
.43609 .60912 m .43397 .61 L .43483 .60724 L F
0 0 0 r
.54859 .59033 m .54854 .5906 L .55033 .58811 L F
0 .546 .787 r
.67772 .39829 m .67402 .39759 L .67636 .39803 L F
.723 .283 .207 r
.67636 .39803 m .68018 .39975 L .67772 .39829 L F
.319 .012 .277 r
.5741 .46651 m .57591 .46817 L .57652 .46564 L F
.5741 .46651 m .57367 .46902 L .57591 .46817 L F
.52 .329 .562 r
.5347 .56636 m .53322 .56768 L .53115 .56521 L F
.981 .844 .632 r
.66287 .42407 m .66412 .42495 L .66349 .42177 L F
.93 .931 .568 r
.66287 .42407 m .66183 .42826 L .66412 .42495 L F
.817 .35 0 r
.49664 .53657 m .49515 .53586 L .49631 .53582 L F
.44 .872 .785 r
.49631 .53582 m .49832 .53453 L .49875 .53456 L F
.717 .499 .592 r
.49515 .53586 m .49832 .53453 L .49631 .53582 L F
.111 0 0 r
.44739 .55708 m .4502 .5575 L .4513 .55765 L F
.537 0 0 r
.4502 .5575 m .45468 .558 L .4513 .55765 L F
0 0 .203 r
.58423 .51469 m .58231 .51793 L .58484 .51671 L F
.305 .134 .478 r
.58227 .52035 m .58484 .51671 L .58231 .51793 L F
.534 .485 .747 r
.38032 .61611 m .38193 .61245 L .37963 .61371 L F
.06 0 0 r
.63234 .40418 m .63184 .40455 L .63467 .40369 L F
.47 .374 .664 r
.48908 .56227 m .48959 .5646 L .48753 .56518 L F
.418 .768 .996 r
.20847 .5537 m .21033 .55328 L .20671 .55269 L F
.20847 .5537 m .21033 .55328 L .20671 .55269 L F
.543 .253 .425 r
.19735 .69286 m .20033 .69206 L .19816 .69074 L F
.424 .176 .433 r
.61313 .41666 m .61057 .41942 L .61289 .41841 L F
.227 0 .307 r
.61552 .41362 m .61313 .41666 L .61503 .41572 L F
.443 .265 .543 r
.61289 .41841 m .61503 .41572 L .61313 .41666 L F
.652 .244 .257 r
.4272 .57488 m .42984 .57678 L .42626 .57657 L F
.605 .826 .985 r
.1849 .65691 m .18842 .65708 L .19022 .65604 L F
.374 .819 .686 r
.19022 .65604 m .18842 .65708 L .18997 .65626 L F
.114 .594 .912 r
.19098 .65677 m .18997 .65626 L .18842 .65708 L F
.457 .135 .331 r
.69473 .39717 m .69236 .39609 L .6921 .39749 L F
.69473 .39717 m .695 .39552 L .69236 .39609 L F
.605 .575 .793 r
.42585 .64274 m .427 .64568 L .42419 .64496 L F
.057 .582 .869 r
.43742 .55898 m .4371 .55918 L .43485 .55925 L F
.43742 .55898 m .43975 .55973 L .4371 .55918 L F
.14 .055 .489 r
.22619 .61387 m .22525 .61627 L .2266 .6157 L F
.502 .338 .591 r
.22525 .61627 m .22745 .61844 L .2266 .6157 L F
.22525 .61627 m .22523 .61898 L .22745 .61844 L F
.719 .695 .827 r
.74827 .38338 m .74939 .38685 L .74575 .38621 L F
.609 .576 .791 r
.75092 .3826 m .74939 .38685 L .74827 .38338 L F
.75092 .3826 m .75202 .38613 L .74939 .38685 L F
.536 .626 .888 r
.21218 .55654 m .21219 .55302 L .21033 .55328 L F
.21218 .55654 m .21432 .55614 L .21219 .55302 L F
.134 0 .147 r
.46834 .61231 m .46899 .6101 L .47112 .60946 L F
.763 .715 .808 r
.69493 .44208 m .69893 .44327 L .69779 .4392 L F
.69493 .44208 m .69658 .44341 L .69893 .44327 L F
.726 .729 .853 r
.69779 .4392 m .69893 .44327 L .70144 .43978 L F
.514 .43 .698 r
.46847 .56773 m .46897 .57053 L .46632 .56876 L F
.63 .382 .524 r
.46897 .57053 m .46612 .571 L .46632 .56876 L F
.46897 .57053 m .46612 .571 L .46632 .56876 L F
0 0 0 r
.69716 .4039 m .69964 .40199 L .69965 .4037 L F
.46 .096 .26 r
.69964 .40199 m .70216 .40304 L .69965 .4037 L F
.69964 .40199 m .70248 .40163 L .70216 .40304 L F
.419 .456 .792 r
.51483 .54272 m .51331 .54348 L .51325 .54277 L F
.677 .672 .838 r
.62069 .43726 m .61829 .44046 L .61702 .43728 L F
.684 .683 .843 r
.62066 .43967 m .61829 .44046 L .62069 .43726 L F
.236 0 0 r
.23647 .55495 m .23462 .55465 L .23216 .55398 L F
.141 0 0 r
.23848 .55446 m .23462 .55465 L .23647 .55495 L F
.462 .27 .534 r
.56851 .55615 m .56853 .55371 L .57089 .55304 L F
.462 .665 .95 r
.1781 .65644 m .17828 .65413 L .17637 .65508 L F
.1781 .65644 m .18175 .65681 L .17828 .65413 L F
0 0 0 r
.22475 .64825 m .22321 .64916 L .22296 .64893 L F
.005 0 0 r
.22367 .64931 m .22358 .64934 L .22321 .64916 L F
0 0 0 r
.22321 .64916 m .22075 .65179 L .2229 .649 L F
.906 .835 .764 r
.21982 .6502 m .22075 .65179 L .22321 .64916 L F
.005 0 0 r
.22358 .64934 m .22183 .64992 L .22321 .64916 L F
0 0 0 r
.22321 .64916 m .2229 .649 L .22296 .64893 L F
.694 .731 .88 r
.47075 .56029 m .4696 .55988 L .47216 .55937 L F
.139 0 0 r
.4685 .56066 m .47067 .56032 L .47216 .55937 L F
.46828 .56074 m .47067 .56032 L .4685 .56066 L F
.356 0 .078 r
.47067 .56032 m .47321 .55869 L .47216 .55937 L F
.694 .731 .88 r
.47559 .56198 m .47075 .56029 L .47216 .55937 L F
0 .104 .658 r
.47436 .55795 m .47559 .56198 L .47216 .55937 L F
.139 0 0 r
.46828 .56074 m .47216 .55937 L .4696 .55988 L F
.356 0 .078 r
.47321 .55869 m .47436 .55795 L .47216 .55937 L F
.47067 .56032 m .47311 .55999 L .47436 .55795 L F
.564 .917 .961 r
.47067 .56032 m .47158 .55895 L .47303 .55994 L F
.47067 .56032 m .47303 .55994 L .47311 .55999 L F
0 .104 .658 r
.47436 .55795 m .47585 .56126 L .47559 .56198 L F
.453 .077 .234 r
.47176 .58492 m .47516 .58405 L .47237 .58437 L F
.659 .427 .556 r
.58212 .47521 m .57883 .47766 L .57954 .47575 L F
.961 .783 .618 r
.42855 .56794 m .42813 .57183 L .42964 .57158 L F
.775 .706 .787 r
.42855 .56794 m .42964 .57158 L .43217 .56819 L F
0 0 .423 r
.42964 .57158 m .43045 .57238 L .43196 .57104 L F
.43013 .57253 m .43127 .57473 L .43045 .57238 L F
.248 .188 .59 r
.43395 .57275 m .43244 .57402 L .43196 .57104 L F
.6 .112 .067 r
.43045 .57238 m .43395 .57275 L .43196 .57104 L F
.78 .303 .1 r
.42629 .57241 m .43127 .57473 L .42813 .57183 L F
.771 .696 .78 r
.43045 .57238 m .43127 .57473 L .42629 .57241 L F
.854 .752 .238 r
.43192 .57416 m .43395 .57275 L .43045 .57238 L F
0 0 0 r
.43045 .57238 m .4313 .57138 L .43192 .57416 L F
.073 0 .087 r
.43244 .57402 m .43198 .5759 L .42984 .57678 L F
.058 0 0 r
.43034 .57763 m .42984 .57678 L .43198 .5759 L F
.947 .958 .705 r
.43192 .57416 m .43034 .57763 L .43198 .5759 L F
0 0 0 r
.43116 .57615 m .43034 .57763 L .43192 .57416 L F
.484 .492 .79 r
.42919 .57562 m .43116 .57615 L .43038 .57322 L F
0 0 0 r
.43045 .57238 m .42896 .57539 L .43081 .57222 L F
.42896 .57539 m .42891 .5755 L .42905 .57525 L F
.42896 .57539 m .42905 .57525 L .43081 .57222 L F
.43045 .57238 m .43081 .57222 L .4313 .57138 L F
0 0 .423 r
.42964 .57158 m .43013 .57253 L .43045 .57238 L F
.689 .301 .307 r
.42629 .57241 m .42891 .5755 L .43045 .57238 L F
.935 .888 .761 r
.4313 .57138 m .42891 .5755 L .42861 .57489 L F
.4313 .57138 m .42861 .57489 L .4293 .57289 L F
.4313 .57138 m .42809 .5738 L .42807 .57376 L F
.544 .565 .826 r
.43426 .57231 m .43192 .57416 L .4313 .57138 L F
.935 .888 .761 r
.4313 .57138 m .42807 .57377 L .43023 .57265 L F
.544 .565 .826 r
.43426 .57231 m .4313 .57138 L .43364 .57054 L F
.008 0 0 r
.43023 .57265 m .43364 .57054 L .4313 .57138 L F
.43023 .57265 m .43217 .572 L .43364 .57054 L F
.416 .307 .622 r
.43023 .57265 m .43217 .572 L .43014 .57043 L F
.42996 .57097 m .43014 .57043 L .42983 .57018 L F
.43023 .57265 m .43014 .57043 L .42996 .57097 L F
.935 .888 .761 r
.4293 .57289 m .42861 .57489 L .42809 .5738 L F
.42807 .57376 m .42809 .5738 L .42807 .57377 L F
.484 .492 .79 r
.42919 .57562 m .43023 .57265 L .42816 .574 L F
0 .032 .596 r
.42807 .57377 m .42891 .5755 L .42629 .57241 L F
.484 .492 .79 r
.42856 .57515 m .42816 .574 L .42754 .57439 L F
.42919 .57562 m .42816 .574 L .42856 .57515 L F
.42962 .57438 m .43038 .57322 L .43023 .57265 L F
.42919 .57562 m .43038 .57322 L .42962 .57438 L F
.7 .526 .649 r
.48852 .5864 m .486 .58924 L .48597 .58652 L F
.48852 .5864 m .48826 .58948 L .486 .58924 L F
.709 .576 .703 r
.49107 .58587 m .48826 .58948 L .48852 .5864 L F
.822 .952 .903 r
.69997 .43113 m .69597 .43283 L .69851 .42998 L F
.632 .837 .979 r
.70246 .43046 m .69997 .43113 L .69851 .42998 L F
.567 .681 .917 r
.70346 .4322 m .69997 .43113 L .70246 .43046 L F
.645 .631 .822 r
.70623 .43132 m .70346 .4322 L .70246 .43046 L F
.564 .686 .922 r
.18849 .6369 m .18635 .63742 L .18469 .63557 L F
.322 .158 .497 r
.27603 .58012 m .27584 .58272 L .27414 .58342 L F
.459 .285 .557 r
.27611 .58549 m .27414 .58342 L .27584 .58272 L F
.27611 .58549 m .27405 .58631 L .27414 .58342 L F
.571 .325 .504 r
.59061 .47028 m .59293 .47223 L .59056 .4725 L F
.46 .182 .404 r
.16173 .56585 m .16111 .568 L .15868 .56847 L F
.15 0 .268 r
.16319 .56507 m .16111 .568 L .16173 .56585 L F
.737 .488 .553 r
.20371 .67864 m .20559 .67472 L .20373 .67543 L F
.20371 .67864 m .20638 .67955 L .20559 .67472 L F
.938 .627 .425 r
.20559 .67472 m .20638 .67955 L .20767 .67944 L F
.736 .525 .607 r
.50799 .58957 m .50459 .5896 L .5064 .58827 L F
.50799 .58957 m .50478 .59124 L .50459 .5896 L F
.50799 .58957 m .50863 .5913 L .50478 .59124 L F
.871 .827 .802 r
.50938 .58667 m .50799 .58957 L .5064 .58827 L F
0 0 .544 r
.50799 .58957 m .50956 .5921 L .50863 .5913 L F
.603 .49 .697 r
.50938 .58667 m .51115 .58957 L .50799 .58957 L F
.559 .24 .383 r
.51115 .58957 m .50956 .5921 L .50799 .58957 L F
.702 .574 .709 r
.38208 .62223 m .38276 .62525 L .38527 .62484 L F
.686 .501 .631 r
.38276 .62525 m .38283 .62823 L .38527 .62484 L F
.702 .574 .709 r
.38208 .62223 m .38527 .62484 L .38329 .62176 L F
.439 .223 .488 r
.5861 .53578 m .58849 .53258 L .58813 .53456 L F
.312 .089 .405 r
.58849 .53258 m .59075 .52955 L .59045 .53157 L F
.013 0 .123 r
.58813 .53456 m .58849 .53258 L .59045 .53157 L F
.818 .804 .838 r
.68156 .45117 m .68571 .44965 L .68429 .44801 L F
.775 .772 .85 r
.68429 .44801 m .68571 .44965 L .68857 .44715 L F
.544 .386 .617 r
.56341 .55961 m .56356 .56218 L .56118 .56272 L F
.51 .362 .616 r
.56356 .56218 m .56148 .56531 L .56118 .56272 L F
.782 .802 .87 r
.71223 .42894 m .7089 .42876 L .71096 .42748 L F
.752 .798 .89 r
.71452 .4277 m .71223 .42894 L .71096 .42748 L F
.805 .949 .604 r
.60237 .50688 m .60383 .50553 L .60331 .50481 L F
.60237 .50688 m .60181 .50865 L .60383 .50553 L F
.584 .363 .547 r
.45381 .61033 m .45366 .61297 L .45092 .61314 L F
.45381 .61033 m .45366 .61297 L .45092 .61314 L F
.382 .199 .503 r
.45381 .61033 m .4556 .61211 L .45565 .6096 L F
.45381 .61033 m .45366 .61297 L .4556 .61211 L F
.4556 .61211 m .45381 .61033 L .45565 .6096 L F
.4556 .61211 m .45366 .61297 L .45381 .61033 L F
.93 .933 .783 r
.64783 .42951 m .64822 .43191 L .65027 .42884 L F
.938 .921 .769 r
.64783 .42951 m .65027 .42884 L .65021 .42476 L F
.915 .597 .427 r
.62719 .41694 m .62728 .41908 L .62945 .41914 L F
.655 .115 0 r
.62728 .41908 m .628 .41982 L .62945 .41914 L F
.328 0 0 r
.628 .41982 m .63186 .41976 L .62945 .41914 L F
.544 .221 .371 r
.60956 .421 m .61289 .41841 L .61057 .41942 L F
0 0 .172 r
.60342 .44832 m .60209 .44997 L .60394 .44622 L F
.054 0 0 r
.60415 .45059 m .60209 .44997 L .60342 .44832 L F
.709 .584 .713 r
.50533 .57754 m .50525 .58133 L .50306 .58039 L F
.757 .564 .635 r
.50525 .58133 m .50298 .58323 L .50306 .58039 L F
.206 .166 .589 r
.50716 .58003 m .50525 .58133 L .50533 .57754 L F
.918 .978 .742 r
.4259 .64014 m .42525 .63941 L .42559 .63844 L F
.969 .92 .588 r
.4259 .64014 m .42437 .64123 L .42525 .63941 L F
.438 .217 .478 r
.42825 .63971 m .42585 .64274 L .4259 .64014 L F
.588 .641 .87 r
.20419 .69076 m .20445 .68715 L .20249 .68792 L F
.536 .298 .501 r
.20647 .69044 m .20614 .69286 L .20419 .69076 L F
.42 .286 .592 r
.20614 .69286 m .20431 .69349 L .20419 .69076 L F
.7 .279 .244 r
.20224 .69248 m .20614 .69286 L .20419 .69076 L F
.536 .298 .501 r
.20647 .69044 m .20614 .69286 L .20419 .69076 L F
.358 .804 .66 r
.52531 .51459 m .52315 .51574 L .5216 .51647 L F
.756 .83 .909 r
.73518 .4265 m .73637 .42798 L .73308 .42785 L F
.68 .784 .929 r
.73833 .42465 m .73637 .42798 L .73518 .4265 L F
.73833 .42465 m .7397 .42665 L .73637 .42798 L F
.259 0 .139 r
.56409 .47642 m .56329 .47786 L .56638 .47561 L F
0 .08 .595 r
.53322 .56768 m .534 .57019 L .53304 .57093 L F
.206 .167 .59 r
.534 .57019 m .53359 .57315 L .53304 .57093 L F
.281 .681 .972 r
.25643 .54291 m .25631 .54403 L .25476 .54262 L F
.25643 .54291 m .25807 .544 L .25631 .54403 L F
.892 .764 .713 r
.62222 .4628 m .62356 .46437 L .62265 .46083 L F
.899 .863 .795 r
.62013 .46625 m .62356 .46437 L .62222 .4628 L F
.62013 .46625 m .62164 .46755 L .62356 .46437 L F
.942 .841 .715 r
.62052 .46937 m .62164 .46755 L .62013 .46625 L F
.517 .331 .567 r
.43957 .60398 m .43695 .60608 L .43709 .60469 L F
.478 .334 .607 r
.22029 .62215 m .22241 .62434 L .22279 .62192 L F
.22029 .62215 m .22036 .62494 L .22241 .62434 L F
.092 .218 .704 r
.45901 .58005 m .4614 .58295 L .45989 .58333 L F
0 0 0 r
.59916 .51361 m .59983 .51201 L .59919 .51383 L F
.769 .913 .532 r
.59983 .51201 m .60181 .50865 L .60047 .51019 L F
0 0 0 r
.59919 .51383 m .59983 .51201 L .60047 .51019 L F
.477 .272 .522 r
.25771 .61278 m .25555 .61332 L .25794 .61027 L F
.504 .347 .601 r
.25771 .61278 m .25781 .61545 L .25555 .61332 L F
.497 .347 .607 r
.25781 .61545 m .25565 .61601 L .25555 .61332 L F
.523 .718 .961 r
.49906 .57004 m .49794 .57197 L .49665 .57064 L F
.49906 .57004 m .50028 .57166 L .49794 .57197 L F
.694 .981 .822 r
.63094 .42583 m .62912 .42646 L .62781 .42838 L F
.563 .225 .353 r
.47383 .57588 m .47356 .57701 L .47111 .57686 L F
.139 0 .353 r
.21978 .65138 m .21904 .65434 L .21735 .65473 L F
0 0 0 r
.21904 .65434 m .21694 .65503 L .21735 .65473 L F
.61 .685 .896 r
.74113 .39195 m .74453 .39307 L .74337 .39125 L F
.624 .692 .892 r
.74337 .39125 m .74453 .39307 L .74708 .39217 L F
.482 .307 .566 r
.26681 .60018 m .26474 .59844 L .26683 .59784 L F
.26681 .60018 m .26467 .60083 L .26474 .59844 L F
.817 .669 .699 r
.43834 .58685 m .44022 .59138 L .4395 .58959 L F
.43834 .58685 m .4356 .59145 L .44022 .59138 L F
.816 .694 .73 r
.4356 .59145 m .43794 .59244 L .44022 .59138 L F
.589 .663 .89 r
.38329 .62176 m .38527 .62484 L .38766 .62428 L F
.494 .26 .488 r
.47594 .64327 m .47829 .64293 L .47816 .64009 L F
.47594 .64327 m .47829 .64293 L .47816 .64009 L F
.294 .114 .458 r
.48008 .64123 m .47816 .64009 L .48098 .6394 L F
.48008 .64123 m .47829 .64293 L .47816 .64009 L F
.47816 .64009 m .48008 .64123 L .48098 .6394 L F
.47816 .64009 m .47829 .64293 L .48008 .64123 L F
.343 .092 .382 r
.61503 .41572 m .6177 .41244 L .61552 .41362 L F
.705 .902 .966 r
.67833 .40853 m .68261 .40789 L .68164 .40714 L F
.659 .908 .979 r
.68164 .40714 m .68261 .40789 L .68527 .40654 L F
0 0 0 r
.44983 .57897 m .44735 .58096 L .44561 .58181 L F
0 0 .535 r
.45069 .57907 m .44983 .57897 L .44911 .5771 L F
.574 .233 .353 r
.45069 .57907 m .44735 .58096 L .44983 .57897 L F
.298 .356 .754 r
.53797 .57915 m .53611 .58116 L .53644 .57912 L F
.594 .474 .685 r
.53868 .58272 m .53611 .58116 L .53797 .57915 L F
.53868 .58272 m .5373 .58356 L .53611 .58116 L F
.801 .504 .486 r
.42732 .57913 m .43115 .58164 L .4288 .57989 L F
.69 .227 .147 r
.4288 .57989 m .43115 .58164 L .43103 .58084 L F
.379 .237 .559 r
.20152 .67883 m .20371 .67864 L .20373 .67543 L F
.377 .224 .543 r
.20152 .67883 m .2048 .68134 L .20371 .67864 L F
.2048 .68134 m .20491 .68124 L .20371 .67864 L F
0 .139 .629 r
.20478 .68165 m .20152 .67883 L .20199 .67983 L F
.20478 .68165 m .205 .68155 L .20152 .67883 L F
.205 .68155 m .20505 .68153 L .20486 .68138 L F
.205 .68155 m .20486 .68138 L .20152 .67883 L F
.737 .382 .378 r
.20371 .67864 m .20505 .68153 L .20638 .67955 L F
.931 .802 .696 r
.20428 .68073 m .20626 .68072 L .20613 .67913 L F
.20393 .68104 m .20449 .68096 L .20428 .68073 L F
.20449 .68096 m .20626 .68072 L .20428 .68073 L F
.20559 .68065 m .20393 .68104 L .20472 .68057 L F
.20626 .68072 m .20537 .68084 L .20559 .68065 L F
.20537 .68084 m .20393 .68104 L .20559 .68065 L F
.377 .224 .543 r
.2048 .68134 m .20505 .68153 L .20491 .68124 L F
.575 .823 .992 r
.72032 .3979 m .72398 .39832 L .72284 .39714 L F
.447 .75 .993 r
.72284 .39714 m .72398 .39832 L .72644 .39809 L F
.773 .705 .787 r
.71499 .44317 m .71851 .44366 L .71755 .44018 L F
.78 .709 .784 r
.71755 .44018 m .71851 .44366 L .72099 .44059 L F
.52 .263 .467 r
.24064 .58915 m .24304 .58899 L .24318 .58682 L F
.491 .326 .585 r
.24318 .58682 m .24575 .58627 L .24554 .58302 L F
.421 .183 .446 r
.24318 .58682 m .24521 .58826 L .24575 .58627 L F
.24318 .58682 m .24304 .58899 L .24521 .58826 L F
.194 .054 .451 r
.588 .53701 m .5861 .53578 L .58813 .53456 L F
.588 .53701 m .58595 .53821 L .5861 .53578 L F
.39 .207 .508 r
.56471 .59235 m .56688 .58922 L .56677 .59167 L F
.381 .228 .546 r
.56675 .59417 m .56471 .59235 L .56677 .59167 L F
.56675 .59417 m .56481 .5949 L .56471 .59235 L F
.639 .766 .94 r
.72751 .3884 m .72503 .38933 L .72394 .38769 L F
.427 .22 .494 r
.26002 .60964 m .25794 .61027 L .26029 .60721 L F
.378 .169 .464 r
.26002 .60964 m .25771 .61278 L .25794 .61027 L F
.788 .772 .839 r
.53832 .55936 m .53938 .56259 L .53603 .56182 L F
.757 .296 .156 r
.53938 .56259 m .53698 .56328 L .53603 .56182 L F
.95 .691 .234 r
.53832 .55936 m .53871 .56175 L .53938 .56259 L F
.906 .971 .805 r
.53871 .56175 m .53698 .56328 L .53938 .56259 L F
.289 .234 .621 r
.42953 .58891 m .42799 .59171 L .42814 .59003 L F
.282 .65 .968 r
.42971 .59148 m .43057 .59223 L .42799 .59171 L F
.073 .156 .647 r
.38985 .62812 m .38995 .62384 L .38766 .62428 L F
.38985 .62812 m .39066 .62761 L .38995 .62384 L F
.237 .409 .831 r
.50375 .57416 m .50643 .57598 L .50533 .57754 L F
0 .075 .614 r
.50699 .57822 m .50533 .57754 L .50643 .57598 L F
.50699 .57822 m .50716 .58003 L .50533 .57754 L F
.706 .324 0 r
.65703 .41337 m .65843 .41618 L .65731 .41562 L F
.993 .754 .455 r
.65843 .41618 m .65736 .41764 L .65731 .41562 L F
.65843 .41618 m .65843 .4187 L .65736 .41764 L F
.534 .485 .747 r
.38032 .61611 m .38261 .61565 L .38193 .61245 L F
.139 .318 .782 r
.38032 .61611 m .38286 .61821 L .38261 .61565 L F
0 0 .285 r
.44205 .55942 m .4428 .55794 L .44295 .55856 L F
.44205 .55942 m .44236 .55935 L .4428 .55794 L F
.592 .704 .921 r
.62819 .43519 m .62697 .43784 L .62554 .43446 L F
.62819 .43519 m .62978 .437 L .62697 .43784 L F
.214 .363 .798 r
.44186 .58882 m .4435 .59278 L .44432 .59088 L F
0 0 .295 r
.4435 .59278 m .44452 .59366 L .44432 .59088 L F
.4435 .59278 m .44354 .59535 L .44452 .59366 L F
.515 .727 .97 r
.1849 .65691 m .19022 .65604 L .18612 .65444 L F
.491 0 0 r
.189 .65563 m .19022 .65604 L .1905 .65624 L F
.18612 .65444 m .18939 .65571 L .189 .65563 L F
.18939 .65571 m .19022 .65604 L .189 .65563 L F
.738 .734 .848 r
.19079 .65603 m .1966 .65607 L .19326 .65535 L F
.18997 .65626 m .19159 .65621 L .19079 .65603 L F
.19159 .65621 m .1966 .65607 L .19079 .65603 L F
.433 .845 .967 r
.19326 .65535 m .1966 .65607 L .19885 .65548 L F
0 0 0 r
.68749 .40672 m .69104 .40486 L .69138 .40584 L F
.499 .071 .158 r
.69138 .40584 m .69104 .40486 L .69374 .40593 L F
.499 .055 .125 r
.69104 .40486 m .69348 .40491 L .69374 .40593 L F
.338 .815 .77 r
.71404 .38949 m .71288 .39022 L .7115 .39008 L F
.71404 .38949 m .71535 .3893 L .71288 .39022 L F
.453 .777 .998 r
.1736 .54348 m .17752 .54424 L .17531 .54451 L F
0 0 0 r
.75733 .39979 m .75678 .40185 L .75641 .40392 L F
.12 .33 .798 r
.1793 .63036 m .17888 .63202 L .17734 .63098 L F
.1793 .63036 m .18094 .63348 L .17888 .63202 L F
.868 .881 .843 r
.61706 .47092 m .6186 .47217 L .61799 .46971 L F
.952 .912 .74 r
.61706 .47092 m .61619 .47566 L .6186 .47217 L F
.859 .877 .85 r
.61799 .46971 m .6186 .47217 L .62052 .46937 L F
.832 .967 .89 r
.6808 .44124 m .67773 .4426 L .67962 .43998 L F
.744 .875 .94 r
.68301 .43984 m .6808 .44124 L .67962 .43998 L F
0 .008 .534 r
.53012 .59203 m .53035 .59565 L .53085 .59477 L F
0 0 .322 r
.53035 .59565 m .5308 .59647 L .53085 .59477 L F
.53035 .59565 m .53095 .59856 L .5308 .59647 L F
.395 0 0 r
.68511 .39983 m .68364 .39857 L .68261 .39979 L F
.68511 .39983 m .68613 .39851 L .68364 .39857 L F
.994 .828 .57 r
.75721 .40766 m .75686 .41011 L .75571 .40871 L F
.926 .968 .677 r
.75686 .40675 m .75721 .40766 L .75571 .40871 L F
.238 .316 .742 r
.55072 .55644 m .55312 .5584 L .55164 .55421 L F
.003 0 .452 r
.56222 .57613 m .56101 .57459 L .56264 .57369 L F
.56222 .57613 m .56075 .57835 L .56101 .57459 L F
.427 .246 .531 r
.19246 .71456 m .19262 .71705 L .19115 .71745 L F
.576 .357 .546 r
.19077 .71728 m .19262 .71705 L .19246 .71456 L F
.415 .733 .991 r
.24643 .54054 m .24609 .54197 L .24454 .5404 L F
.24643 .54054 m .24823 .54182 L .24609 .54197 L F
.515 .614 .889 r
.27808 .5522 m .27649 .55398 L .27603 .55258 L F
.309 .303 .69 r
.27808 .5522 m .27868 .5558 L .27649 .55398 L F
.222 .295 .728 r
.27649 .55398 m .27868 .5558 L .27763 .55638 L F
.721 .616 .74 r
.51199 .595 m .513 .59833 L .51048 .59751 L F
.9 .95 .827 r
.51431 .59459 m .513 .59833 L .51199 .595 L F
.566 .397 .611 r
.51279 .59585 m .51185 .59716 L .51194 .59762 L F
.235 0 .148 r
.51194 .59762 m .51048 .59751 L .51201 .59801 L F
.51194 .59762 m .50958 .59863 L .51048 .59751 L F
.721 .616 .74 r
.51199 .595 m .51048 .59751 L .50927 .5954 L F
.965 .727 .529 r
.51194 .59762 m .51032 .5964 L .50958 .59863 L F
.51194 .59762 m .51041 .59916 L .51032 .5964 L F
.566 .397 .611 r
.51185 .59716 m .51041 .59916 L .51194 .59762 L F
.235 0 .148 r
.51194 .59762 m .51201 .59801 L .513 .59833 L F
.9 .95 .827 r
.51431 .59459 m .51194 .59762 L .513 .59833 L F
.775 .353 .247 r
.41856 .65098 m .42217 .65213 L .42061 .65369 L F
.764 .337 .237 r
.42061 .65369 m .42217 .65213 L .42275 .65336 L F
.863 .752 .739 r
.47759 .59538 m .4755 .59522 L .47749 .59232 L F
.623 .563 .767 r
.47789 .59766 m .4755 .59522 L .47759 .59538 L F
.698 .624 .771 r
.48113 .59524 m .47759 .59538 L .47749 .59232 L F
.44 .076 .249 r
.48113 .59524 m .47789 .59766 L .47759 .59538 L F
.642 .816 .967 r
.73109 .38877 m .72751 .3884 L .72999 .38752 L F
.654 .838 .971 r
.73371 .38751 m .73109 .38877 L .72999 .38752 L F
.745 .768 .872 r
.7194 .42407 m .72069 .42577 L .71727 .42534 L F
.716 .759 .887 r
.72319 .42452 m .72069 .42577 L .7194 .42407 L F
.623 .281 .37 r
.46335 .57653 m .46717 .57664 L .46773 .57474 L F
.107 0 .221 r
.46998 .57175 m .46773 .57474 L .46951 .57383 L F
.641 .5 .675 r
.46717 .57664 m .46951 .57383 L .46773 .57474 L F
.883 .748 .708 r
.62359 .45417 m .62697 .45225 L .6257 .45062 L F
.62359 .45417 m .62555 .45566 L .62697 .45225 L F
.842 .792 .803 r
.6257 .45062 m .62697 .45225 L .62928 .44917 L F
.638 .821 .97 r
.73429 .43364 m .73771 .43407 L .73677 .43269 L F
.843 .894 .875 r
.73677 .43269 m .73771 .43407 L .74041 .43138 L F
.731 .525 .613 r
.506 .59841 m .50958 .59863 L .50927 .5954 L F
0 0 .368 r
.50927 .5954 m .51032 .5964 L .51034 .5939 L F
.50927 .5954 m .50958 .59863 L .51032 .5964 L F
.879 .53 .036 r
.50295 .55029 m .50206 .549 L .50153 .54697 L F
0 .248 .712 r
.50295 .55029 m .50401 .5506 L .50206 .549 L F
.50295 .55029 m .50605 .55222 L .50401 .5506 L F
0 .426 .844 r
.54649 .55578 m .54355 .55411 L .54413 .55611 L F
.632 .072 0 r
.40443 .64414 m .40352 .64454 L .40121 .64274 L F
.614 .05 0 r
.40443 .64414 m .40677 .64579 L .40352 .64454 L F
0 0 .007 r
.56367 .49059 m .56302 .49263 L .56117 .49328 L F
0 0 0 r
.56654 .48808 m .56568 .48988 L .56367 .49059 L F
.147 0 .063 r
.56518 .49165 m .56367 .49059 L .56568 .48988 L F
.56518 .49165 m .56302 .49263 L .56367 .49059 L F
0 0 .04 r
.53313 .50805 m .535 .50743 L .53563 .50531 L F
0 0 0 r
.53189 .50958 m .535 .50743 L .53313 .50805 L F
.451 .489 .807 r
.20874 .68728 m .2057 .68506 L .20778 .68406 L F
.792 .919 .537 r
.60047 .51019 m .60181 .50865 L .60237 .50688 L F
.984 .86 .487 r
.5364 .52141 m .53547 .52249 L .53628 .52418 L F
.985 .889 .55 r
.53628 .52418 m .53467 .52602 L .53621 .52651 L F
.53628 .52418 m .53547 .52249 L .53467 .52602 L F
.333 0 0 r
.19802 .54 m .20022 .54037 L .20203 .53995 L F
.189 .719 .741 r
.20022 .54037 m .20403 .53962 L .20203 .53995 L F
.837 .721 .736 r
.63028 .4423 m .62809 .44575 L .63017 .44579 L F
.837 .714 .728 r
.62809 .44575 m .62928 .44917 L .63017 .44579 L F
.407 .838 .952 r
.47125 .60002 m .46883 .60057 L .4701 .60086 L F
.589 .367 .547 r
.57354 .55089 m .57682 .5528 L .57345 .55283 L F
.57354 .55089 m .57673 .55024 L .57682 .5528 L F
.654 .109 0 r
.41773 .6425 m .4179 .64199 L .41579 .64157 L F
.41773 .6425 m .41998 .64414 L .4179 .64199 L F
.147 0 0 r
.56148 .47915 m .56272 .47994 L .56329 .47786 L F
.56148 .47915 m .5604 .48067 L .56272 .47994 L F
.515 .758 .985 r
.49806 .5936 m .5018 .59453 L .50037 .59524 L F
.381 .264 .593 r
.24758 .57756 m .24913 .57713 L .24931 .57401 L F
.408 .348 .679 r
.24758 .57756 m .24985 .57953 L .24913 .57713 L F
.473 .35 .631 r
.24786 .58005 m .24985 .57953 L .24758 .57756 L F
.467 0 0 r
.49875 .53456 m .5015 .53576 L .50252 .53574 L F
.183 .711 .712 r
.50576 .53467 m .50455 .53494 L .50383 .53457 L F
.974 .926 .647 r
.50252 .53574 m .50279 .53403 L .50383 .53457 L F
.50252 .53574 m .5015 .53576 L .50319 .53152 L F
.994 .746 .418 r
.5015 .53576 m .50252 .53574 L .50383 .53457 L F
.183 .711 .712 r
.50455 .53494 m .50193 .53553 L .50383 .53457 L F
.974 .926 .647 r
.50279 .53403 m .50319 .53152 L .50383 .53457 L F
.988 .736 .453 r
.62809 .44575 m .62801 .44814 L .62928 .44917 L F
.842 .792 .803 r
.6257 .45062 m .62928 .44917 L .62801 .44814 L F
.719 .975 .745 r
.4377 .56095 m .43685 .56256 L .43975 .55973 L F
.567 .855 .997 r
.4377 .56095 m .43543 .56168 L .43685 .56256 L F
.63 .385 .529 r
.43685 .56256 m .43952 .56444 L .43964 .56206 L F
.43685 .56256 m .43709 .56497 L .43952 .56444 L F
.914 .864 .776 r
.76306 .42963 m .76414 .43124 L .76503 .42872 L F
.933 .816 .706 r
.76118 .43266 m .76414 .43124 L .76306 .42963 L F
.76118 .43266 m .76252 .43396 L .76414 .43124 L F
.429 .593 .911 r
.18298 .63295 m .18225 .63507 L .18094 .63348 L F
.18298 .63295 m .18469 .63557 L .18225 .63507 L F
.009 0 .196 r
.58688 .51128 m .58423 .51469 L .58638 .51352 L F
.176 .048 .457 r
.58423 .51469 m .58616 .51589 L .58638 .51352 L F
.58423 .51469 m .58484 .51671 L .58616 .51589 L F
.978 .917 .612 r
.65776 .42211 m .65752 .42477 L .65657 .42393 L F
.989 .869 .62 r
.65752 .42477 m .65568 .42767 L .65657 .42393 L F
.65752 .42477 m .6567 .42892 L .65568 .42767 L F
.166 .57 .934 r
.27429 .55117 m .27274 .55141 L .27133 .54999 L F
.27429 .55117 m .27603 .55258 L .27274 .55141 L F
0 0 0 r
.56302 .49263 m .56024 .4948 L .56117 .49328 L F
.695 .463 .567 r
.44802 .59838 m .44378 .5988 L .44462 .59828 L F
.44802 .59838 m .44808 .60101 L .44378 .5988 L F
.64 .42 .567 r
.45058 .60065 m .44802 .59838 L .45033 .59815 L F
.45058 .60065 m .44808 .60101 L .44802 .59838 L F
0 0 0 r
.59075 .52955 m .59288 .52609 L .59231 .5282 L F
0 0 .095 r
.59045 .53157 m .59075 .52955 L .59231 .5282 L F
.39 .254 .573 r
.27512 .57136 m .27647 .57364 L .27467 .57422 L F
.578 .626 .864 r
.2777 .56752 m .27512 .57136 L .27595 .56759 L F
.2777 .56752 m .27956 .57167 L .27512 .57136 L F
.304 0 .106 r
.27956 .57167 m .27647 .57364 L .27512 .57136 L F
.489 .197 .396 r
.43288 .64819 m .43544 .64583 L .43348 .64633 L F
.676 .458 .582 r
.20199 .67983 m .20462 .6831 L .20478 .68165 L F
0 0 .051 r
.20462 .6831 m .20626 .68072 L .20478 .68165 L F
0 0 0 r
.20626 .68072 m .20505 .68153 L .20478 .68165 L F
.676 .458 .582 r
.20199 .67983 m .20143 .68481 L .20462 .6831 L F
.599 .323 .47 r
.55976 .54414 m .56237 .544 L .56244 .54188 L F
.55 .364 .581 r
.56244 .54188 m .56514 .54132 L .56517 .53855 L F
.554 .312 .503 r
.56237 .544 m .56514 .54132 L .56244 .54188 L F
.636 .176 .144 r
.44076 .58045 m .44286 .58231 L .43932 .58191 L F
.556 .217 .349 r
.443 .58035 m .44286 .58231 L .44076 .58045 L F
.385 .625 .948 r
.65539 .43195 m .65746 .43356 L .65612 .43276 L F
.433 .787 .997 r
.65746 .43356 m .65853 .43249 L .65612 .43276 L F
.65746 .43356 m .65965 .43338 L .65853 .43249 L F
.635 .761 .939 r
.67503 .40762 m .67645 .40962 L .67833 .40853 L F
.517 .331 .567 r
.43957 .60398 m .43942 .60608 L .43695 .60608 L F
.559 .273 .438 r
.43942 .60608 m .43609 .60912 L .43695 .60608 L F
.589 .926 .961 r
.2029 .65397 m .20256 .65511 L .20467 .6541 L F
.474 .831 .995 r
.20069 .65441 m .20256 .65511 L .2029 .65397 L F
.895 .765 .711 r
.50522 .53187 m .50319 .53152 L .50418 .52953 L F
.348 0 0 r
.50522 .53187 m .50667 .53239 L .50319 .53152 L F
.895 .765 .711 r
.50522 .53187 m .50319 .53152 L .50418 .52953 L F
.213 0 .192 r
.54101 .49985 m .54295 .49895 L .54382 .49705 L F
.186 0 .177 r
.54382 .49705 m .54295 .49895 L .54575 .49616 L F
0 0 .044 r
.5437 .56545 m .54495 .56464 L .5455 .56257 L F
.19 0 0 r
.54495 .56464 m .54797 .56233 L .5455 .56257 L F
.478 .308 .572 r
.26238 .60414 m .2624 .60665 L .26029 .60721 L F
.476 .261 .507 r
.26222 .60909 m .26029 .60721 L .2624 .60665 L F
.26222 .60909 m .26002 .60964 L .26029 .60721 L F
.684 .437 .543 r
.55176 .60393 m .55135 .60703 L .54862 .60643 L F
.457 .367 .666 r
.55352 .60083 m .55331 .60334 L .55176 .60393 L F
.475 .279 .534 r
.55331 .60334 m .55135 .60703 L .55176 .60393 L F
.83 .793 .295 r
.66122 .4297 m .66103 .432 L .66183 .42826 L F
.93 .931 .568 r
.66287 .42407 m .66161 .42723 L .66183 .42826 L F
.893 .784 .294 r
.66161 .42723 m .66122 .4297 L .66183 .42826 L F
.492 .839 .996 r
.53832 .55936 m .54201 .55987 L .54068 .5591 L F
.735 .926 .955 r
.54068 .5591 m .54201 .55987 L .5428 .55766 L F
.698 .624 .771 r
.48113 .59524 m .47749 .59232 L .48002 .59157 L F
.44 .076 .249 r
.48113 .59524 m .48067 .59735 L .47789 .59766 L F
.498 .209 .405 r
.48638 .59208 m .48113 .59524 L .48002 .59157 L F
.48638 .59208 m .48559 .59492 L .48113 .59524 L F
.125 0 .154 r
.48238 .5965 m .48113 .59524 L .48559 .59492 L F
.473 .315 .585 r
.48092 .59967 m .47789 .59766 L .48067 .59735 L F
.48092 .59967 m .47823 .60067 L .47789 .59766 L F
.705 .482 .583 r
.47789 .59766 m .47823 .60067 L .47507 .60013 L F
.633 .638 .837 r
.48092 .59967 m .47881 .60324 L .47823 .60067 L F
.606 .571 .789 r
.47823 .60067 m .47881 .60324 L .47638 .60383 L F
.47823 .60067 m .47638 .60383 L .4772 .60267 L F
.47823 .60067 m .4772 .60267 L .47507 .60013 L F
.568 .349 .543 r
.47829 .59795 m .4781 .60091 L .47839 .60078 L F
.971 .92 .687 r
.47941 .59875 m .47932 .59891 L .48034 .5994 L F
.215 0 0 r
.48078 .59973 m .48092 .59967 L .47932 .59891 L F
.568 .349 .543 r
.47932 .59891 m .47839 .60078 L .48078 .59973 L F
.215 0 0 r
.48078 .59973 m .47932 .59891 L .47927 .59889 L F
.568 .349 .543 r
.47941 .59875 m .47932 .59891 L .48078 .59973 L F
.47829 .59795 m .47839 .60078 L .47941 .59875 L F
.971 .92 .687 r
.48069 .59743 m .47941 .59875 L .48034 .5994 L F
.47941 .59875 m .47927 .59889 L .47932 .59891 L F
.568 .349 .543 r
.47829 .59795 m .47941 .59875 L .47927 .59889 L F
.47941 .59875 m .48078 .59973 L .47927 .59889 L F
.971 .92 .687 r
.48104 .59543 m .47927 .59889 L .48069 .59743 L F
.48095 .59842 m .48034 .5994 L .48092 .59967 L F
.125 0 .154 r
.48224 .59635 m .48067 .59735 L .48113 .59524 L F
.48204 .59667 m .48067 .59735 L .48224 .59635 L F
.304 .143 .49 r
.48238 .5965 m .48092 .59967 L .48067 .59735 L F
.971 .92 .687 r
.48104 .59543 m .48034 .5994 L .48095 .59842 L F
.125 0 .154 r
.48238 .5965 m .48204 .59667 L .48224 .59635 L F
.898 .547 .07 r
.74849 .41314 m .75011 .41709 L .7467 .41583 L F
.848 .876 .861 r
.75011 .41709 m .74658 .41856 L .7467 .41583 L F
.971 .744 .536 r
.21503 .66974 m .21458 .67226 L .2131 .66779 L F
0 0 .078 r
.2157 .66867 m .21458 .67226 L .21503 .66974 L F
.785 .716 .787 r
.72005 .43722 m .7233 .43757 L .72197 .43589 L F
.79 .701 .766 r
.72005 .43722 m .72099 .44059 L .7233 .43757 L F
.734 .729 .846 r
.7233 .43757 m .7246 .43341 L .72197 .43589 L F
.7233 .43757 m .72559 .43647 L .7246 .43341 L F
.93 .662 .508 r
.53598 .52806 m .53785 .52675 L .53621 .52651 L F
.53598 .52806 m .5379 .52928 L .53785 .52675 L F
0 0 0 r
.65247 .41303 m .65221 .41535 L .65225 .41463 L F
.94 .782 .317 r
.65155 .4175 m .65209 .41988 L .65225 .41463 L F
.65155 .4175 m .65225 .41463 L .65221 .41535 L F
.281 0 .147 r
.16111 .568 m .15832 .56958 L .15868 .56847 L F
.54 .392 .629 r
.75001 .40028 m .74972 .40417 L .75226 .4035 L F
.33 0 0 r
.43909 .57604 m .4411 .57599 L .439 .57563 L F
.387 .847 .88 r
.73999 .39178 m .74113 .39195 L .74337 .39125 L F
.785 .932 .929 r
.44767 .56395 m .44854 .56581 L .45099 .5631 L F
.801 .328 0 r
.56074 .57887 m .56228 .58023 L .56075 .57835 L F
.074 .495 .896 r
.56358 .58043 m .56228 .58023 L .56074 .57887 L F
.419 .456 .792 r
.51483 .54272 m .51325 .54277 L .51413 .54031 L F
.992 .881 .599 r
.66673 .41647 m .6678 .41333 L .66692 .41211 L F
.905 .789 .723 r
.6678 .41333 m .66717 .40909 L .66692 .41211 L F
0 0 .113 r
.77096 .41863 m .77092 .41822 L .77057 .41584 L F
.977 .917 .613 r
.77044 .4225 m .77092 .41822 L .77096 .41863 L F
.784 .697 .768 r
.72005 .43722 m .71755 .44018 L .72099 .44059 L F
.071 0 .258 r
.6043 .43172 m .60381 .43372 L .6058 .43046 L F
.04 .599 .811 r
.50667 .58368 m .5051 .58334 L .50298 .58323 L F
.244 .2 .608 r
.77591 .43036 m .77676 .42977 L .77474 .43127 L F
.408 0 .032 r
.18356 .5583 m .17951 .56004 L .1813 .55911 L F
.8 .713 .768 r
.61476 .44538 m .61288 .44827 L .61205 .44538 L F
.542 .381 .612 r
.57676 .47908 m .5772 .48147 L .57452 .48196 L F
.539 .309 .514 r
.57717 .48349 m .57452 .48196 L .5772 .48147 L F
.57717 .48349 m .57461 .48413 L .57452 .48196 L F
.01 .468 .871 r
.41107 .64808 m .40677 .64579 L .40825 .64701 L F
0 .346 .681 r
.41266 .64873 m .41107 .64808 L .40825 .64701 L F
.383 0 0 r
.554 .6007 m .557 .60123 L .55352 .60083 L F
.437 .792 .997 r
.21093 .67458 m .21266 .67565 L .21003 .67575 L F
.601 .333 .483 r
.21266 .67565 m .21219 .67794 L .21003 .67575 L F
.96 .76 .589 r
.21219 .67794 m .21093 .67458 L .21003 .67575 L F
.551 .402 .632 r
.56514 .54132 m .56736 .53784 L .56517 .53855 L F
.997 .816 .539 r
.43709 .56497 m .44052 .56659 L .43952 .56444 L F
0 .305 .798 r
.44052 .56659 m .44179 .56416 L .43952 .56444 L F
.44052 .56659 m .44092 .56573 L .44179 .56416 L F
.752 .798 .89 r
.71452 .4277 m .71096 .42748 L .71396 .42449 L F
.757 .801 .888 r
.71727 .42534 m .71452 .4277 L .71396 .42449 L F
0 0 .197 r
.54176 .54453 m .54291 .54279 L .54288 .54116 L F
0 0 0 r
.54167 .54543 m .54176 .54453 L .543 .54563 L F
.54167 .54543 m .54291 .54279 L .54176 .54453 L F
.512 .124 .241 r
.58802 .47319 m .58449 .47497 L .58443 .47331 L F
.58802 .47319 m .58678 .47488 L .58449 .47497 L F
.649 .39 .514 r
.59056 .4725 m .58678 .47488 L .58802 .47319 L F
.006 .579 .761 r
.47111 .57686 m .47356 .57701 L .46992 .57668 L F
.47111 .57686 m .47356 .57701 L .46992 .57668 L F
.293 .752 .952 r
.24823 .54182 m .25065 .54167 L .25214 .54225 L F
.179 .599 .941 r
.25309 .5414 m .25214 .54225 L .25065 .54167 L F
.25309 .5414 m .25476 .54262 L .25214 .54225 L F
.553 0 0 r
.20767 .67944 m .20984 .68128 L .2116 .68206 L F
.161 0 .324 r
.20939 .68341 m .21088 .68286 L .21088 .68285 L F
0 0 0 r
.2116 .68206 m .20939 .68341 L .2081 .68389 L F
.524 .874 .987 r
.2116 .68206 m .20984 .68128 L .21168 .68059 L F
.786 .99 .754 r
.21168 .68059 m .20939 .68341 L .2116 .68206 L F
.161 0 .324 r
.20939 .68341 m .21088 .68285 L .21168 .68059 L F
0 0 0 r
.2081 .68389 m .20939 .68341 L .20778 .68406 L F
.074 0 0 r
.56762 .48885 m .56654 .48808 L .56857 .48677 L F
.56762 .48885 m .56568 .48988 L .56654 .48808 L F
.979 .913 .607 r
.65121 .42203 m .65209 .41988 L .65155 .4175 L F
.715 .59 .715 r
.48504 .58911 m .48638 .59208 L .48002 .59157 L F
0 0 .458 r
.486 .58924 m .48638 .59208 L .48504 .58911 L F
.486 .58924 m .48657 .59172 L .48638 .59208 L F
.547 .33 .537 r
.48657 .59172 m .48559 .59492 L .48638 .59208 L F
.45 .821 .993 r
.62719 .41694 m .63115 .41711 L .63047 .41615 L F
.352 .53 .891 r
.63115 .41711 m .63284 .41512 L .63047 .41615 L F
.63115 .41711 m .63504 .41872 L .63284 .41512 L F
.077 .493 .897 r
.63513 .41926 m .63504 .41872 L .63115 .41711 L F
.064 .021 .492 r
.19262 .71705 m .19183 .72045 L .19115 .71745 L F
.19262 .71705 m .19304 .71953 L .19183 .72045 L F
.509 .901 .94 r
.19183 .72045 m .19304 .71953 L .19074 .72039 L F
.212 .359 .795 r
.47806 .56105 m .47692 .56288 L .47585 .56126 L F
.47806 .56105 m .47941 .56438 L .47692 .56288 L F
.433 .452 .779 r
.76471 .40343 m .76471 .40773 L .76554 .40452 L F
.489 .652 .931 r
.50998 .55652 m .51131 .55451 L .50833 .55473 L F
.50998 .55652 m .51192 .55619 L .51131 .55451 L F
.329 .037 .308 r
.45041 .58322 m .45261 .58265 L .45304 .58055 L F
.462 .15 .35 r
.45304 .58055 m .45261 .58265 L .45509 .58197 L F
.482 .138 .305 r
.45304 .58055 m .45509 .58197 L .45554 .58025 L F
.804 .632 .668 r
.61476 .44538 m .61205 .44538 L .61228 .44294 L F
.489 .287 .533 r
.24919 .57136 m .25164 .57084 L .2518 .56818 L F
.375 .182 .487 r
.24931 .57401 m .25164 .57084 L .24919 .57136 L F
.641 .402 .54 r
.38822 .59769 m .39084 .59782 L .3911 .59525 L F
.562 .349 .548 r
.39084 .59782 m .39351 .59465 L .3911 .59525 L F
.371 .596 .933 r
.19275 .63595 m .19232 .63783 L .19064 .63642 L F
.19275 .63595 m .19447 .63808 L .19232 .63783 L F
.807 .629 .662 r
.60172 .47902 m .59799 .47857 L .60016 .47487 L F
.781 .63 .693 r
.60172 .47902 m .59817 .48161 L .59799 .47857 L F
.60172 .47902 m .59996 .48226 L .59817 .48161 L F
.53 .549 .82 r
.3934 .63508 m .39549 .63324 L .39244 .63345 L F
.3934 .63508 m .39684 .63661 L .39549 .63324 L F
.773 .431 .407 r
.55352 .60083 m .557 .60123 L .55644 .60257 L F
.486 .141 .306 r
.557 .60123 m .55879 .60258 L .55644 .60257 L F
.557 .60123 m .55952 .60096 L .55879 .60258 L F
.77 .557 .61 r
.59913 .44149 m .60258 .44207 L .60276 .44049 L F
.411 .239 .536 r
.60276 .44049 m .60258 .44207 L .60486 .43949 L F
.885 .494 .288 r
.20638 .67955 m .20626 .68072 L .20767 .67944 L F
.611 .114 .045 r
.20626 .68072 m .20984 .68128 L .20767 .67944 L F
.201 .288 .73 r
.5437 .56545 m .54522 .56616 L .54495 .56464 L F
.777 .7 .778 r
.43086 .5655 m .42855 .56794 L .43217 .56819 L F
.663 .595 .769 r
.43217 .56819 m .43303 .56426 L .43086 .5655 L F
.43217 .56819 m .43524 .56835 L .43303 .56426 L F
.65 .353 .455 r
.43217 .56819 m .43428 .5705 L .43524 .56835 L F
.43217 .56819 m .43428 .5705 L .43524 .56835 L F
.568 .305 .476 r
.45366 .61297 m .4532 .61514 L .45092 .61314 L F
.45092 .61314 m .4532 .61514 L .45366 .61297 L F
.676 .752 .908 r
.46612 .571 m .46998 .57175 L .46897 .57053 L F
.46612 .571 m .46998 .57175 L .46897 .57053 L F
.973 .693 .435 r
.46998 .57175 m .46951 .57383 L .46897 .57053 L F
.754 .775 .87 r
.47208 .5708 m .46998 .57175 L .46897 .57053 L F
.53 .079 .126 r
.18578 .55774 m .19013 .55617 L .18789 .55744 L F
.18578 .55774 m .18641 .55675 L .19013 .55617 L F
.454 .318 .605 r
.5657 .56153 m .56341 .55961 L .56577 .55892 L F
.5657 .56153 m .56356 .56218 L .56341 .55961 L F
.089 0 .048 r
.42288 .57087 m .42195 .57295 L .42651 .56815 L F
.662 .647 .824 r
.7801 .3993 m .77652 .39816 L .77908 .39741 L F
.374 .456 .816 r
.78147 .39728 m .7801 .3993 L .77908 .39741 L F
.78147 .39728 m .78271 .40063 L .7801 .3993 L F
.204 0 0 r
.43397 .61 m .42972 .61204 L .43173 .61059 L F
.225 .239 .665 r
.75811 .39077 m .7562 .39298 L .75589 .38891 L F
.45 .575 .888 r
.75811 .39077 m .75975 .39413 L .7562 .39298 L F
.416 .587 .912 r
.76051 .39573 m .7562 .39298 L .75975 .39413 L F
.472 .346 .627 r
.4186 .61279 m .41897 .6145 L .41677 .61316 L F
.548 .304 .497 r
.41897 .6145 m .41663 .61582 L .41677 .61316 L F
.683 .139 0 r
.56075 .57835 m .56074 .57887 L .5582 .57688 L F
0 0 0 r
.56222 .57613 m .56074 .57887 L .56075 .57835 L F
.433 .453 .781 r
.44823 .60301 m .44378 .5988 L .44808 .60101 L F
.587 .018 0 r
.41476 .65044 m .41107 .64808 L .41266 .64873 L F
.864 .75 .735 r
.4823 .5863 m .48032 .58954 L .47852 .58834 L F
.976 .727 .311 r
.48023 .5769 m .481 .58034 L .48019 .57848 L F
.718 .887 .958 r
.64672 .431 m .64822 .43191 L .64783 .42951 L F
0 0 0 r
.53563 .50531 m .53758 .50452 L .53868 .50295 L F
.54018 .50137 m .54101 .49985 L .53868 .50295 L F
.082 0 .03 r
.53758 .50452 m .54018 .50137 L .53868 .50295 L F
.08 0 0 r
.38554 .59759 m .38462 .59763 L .38822 .59769 L F
.625 .763 .945 r
.76269 .3933 m .76051 .39573 L .75975 .39413 L F
.76269 .3933 m .76313 .39497 L .76051 .39573 L F
.283 .436 .838 r
.76349 .39732 m .76051 .39573 L .76313 .39497 L F
.483 .759 .991 r
.20503 .6355 m .20461 .6371 L .20327 .63688 L F
.20503 .6355 m .20679 .63672 L .20461 .6371 L F
.823 .664 .685 r
.48597 .58652 m .486 .58924 L .48491 .5851 L F
.501 .326 .576 r
.24554 .58302 m .24803 .58258 L .24786 .58005 L F
.442 .29 .578 r
.24554 .58302 m .24753 .58557 L .24803 .58258 L F
.24554 .58302 m .24575 .58627 L .24753 .58557 L F
.675 .576 .736 r
.53458 .55871 m .53224 .5614 L .53277 .55972 L F
.189 0 .274 r
.24092 .59161 m .24304 .58899 L .24064 .58915 L F
.247 0 0 r
.62317 .40968 m .62562 .40903 L .62645 .40757 L F
.327 0 .052 r
.62562 .40903 m .62902 .40696 L .62645 .40757 L F
.073 .615 .849 r
.22701 .55415 m .22521 .55365 L .2226 .55344 L F
.509 .871 .985 r
.22734 .5532 m .22701 .55415 L .22881 .55322 L F
.22734 .5532 m .22521 .55365 L .22701 .55415 L F
.144 0 0 r
.1755 .63041 m .17116 .63121 L .17345 .63045 L F
0 .472 .859 r
.1755 .62972 m .1755 .63041 L .17345 .63045 L F
.1755 .62972 m .17734 .63098 L .1755 .63041 L F
.78 .303 .1 r
.42275 .65336 m .42584 .65484 L .4246 .65584 L F
.57 .034 0 r
.4246 .65584 m .42584 .65484 L .42841 .65635 L F
.568 .127 .162 r
.42584 .65484 m .42854 .65519 L .42841 .65635 L F
.798 .591 .622 r
.60016 .47487 m .59659 .47506 L .59662 .47268 L F
.803 .624 .66 r
.60016 .47487 m .59799 .47857 L .59659 .47506 L F
.652 .467 .621 r
.55362 .5475 m .55734 .54726 L .55721 .54462 L F
.633 .472 .647 r
.55734 .54726 m .55976 .54414 L .55721 .54462 L F
.754 .775 .87 r
.47208 .5708 m .47087 .56998 L .47086 .56737 L F
.47208 .5708 m .46897 .57053 L .47087 .56998 L F
.593 .325 .479 r
.58443 .47331 m .58449 .47497 L .58212 .47521 L F
.596 .373 .547 r
.56587 .55647 m .56855 .55858 L .56577 .55892 L F
.56587 .55647 m .56851 .55615 L .56855 .55858 L F
.008 0 0 r
.19625 .7123 m .19621 .71129 L .19833 .7114 L F
.19625 .7123 m .19382 .71319 L .19621 .71129 L F
.285 0 0 r
.20403 .53962 m .20624 .53998 L .20803 .53976 L F
.179 0 0 r
.20624 .53998 m .21005 .53942 L .20803 .53976 L F
.871 .827 .802 r
.50938 .58667 m .5064 .58827 L .50909 .58431 L F
.306 .41 .805 r
.51104 .58511 m .50938 .58667 L .50909 .58431 L F
.51104 .58511 m .5123 .58835 L .50938 .58667 L F
.389 .4 .751 r
.5123 .58835 m .51115 .58957 L .50938 .58667 L F
.959 .853 .694 r
.6567 .42892 m .65539 .43195 L .65438 .42994 L F
.95 .91 .743 r
.65568 .42767 m .6567 .42892 L .65438 .42994 L F
.77 .809 .884 r
.50613 .53705 m .5041 .53674 L .50726 .53501 L F
.594 .068 0 r
.48954 .57773 m .48808 .57873 L .49184 .5792 L F
.875 .761 .734 r
.4877 .58054 m .49184 .5792 L .48808 .57873 L F
0 0 .087 r
.48808 .57979 m .48808 .57873 L .48927 .57746 L F
.4877 .58054 m .48808 .57873 L .48808 .57979 L F
.785 .321 .138 r
.48808 .57724 m .48808 .57873 L .48954 .57773 L F
.48665 .57677 m .48808 .57873 L .48808 .57724 L F
.526 .481 .749 r
.48991 .57554 m .48954 .57773 L .49176 .57665 L F
.433 .277 .569 r
.48954 .57773 m .49184 .5792 L .49176 .57665 L F
.455 .285 .561 r
.29025 .55949 m .29227 .56183 L .29011 .56203 L F
.29025 .55949 m .29227 .56183 L .29011 .56203 L F
.904 .92 .819 r
.6126 .48765 m .61493 .48446 L .61369 .4836 L F
.957 .892 .723 r
.61493 .48446 m .61451 .48113 L .61369 .4836 L F
.715 .59 .715 r
.48504 .58911 m .48002 .59157 L .48032 .58954 L F
.691 .587 .734 r
.48491 .5851 m .486 .58924 L .48504 .58911 L F
.452 .356 .656 r
.27143 .59422 m .26946 .59258 L .27155 .59194 L F
.27143 .59422 m .26961 .59492 L .26946 .59258 L F
.073 0 .098 r
.41527 .57756 m .41268 .58034 L .4144 .57928 L F
.052 0 .093 r
.4144 .57928 m .4169 .57646 L .41527 .57756 L F
.521 .729 .968 r
.41062 .63504 m .41317 .6374 L .4086 .63573 L F
.704 .699 .842 r
.41317 .6374 m .41002 .63767 L .4086 .63573 L F
0 .086 .645 r
.4125 .63915 m .41002 .63767 L .41317 .6374 L F
.806 .792 .839 r
.69148 .4369 m .68926 .43959 L .68786 .43712 L F
.751 .638 .735 r
.27796 .5622 m .27513 .5656 L .2764 .56344 L F
.58 .931 .944 r
.44194 .59519 m .44132 .59649 L .43954 .59547 L F
.44194 .59519 m .44354 .59535 L .44132 .59649 L F
.699 .327 0 r
.64991 .40308 m .65179 .40701 L .65177 .40439 L F
0 0 0 r
.15526 .55348 m .15636 .55317 L .15781 .55248 L F
.15419 .55396 m .15636 .55317 L .15526 .55348 L F
.276 .335 .743 r
.46532 .609 m .46505 .60994 L .46666 .60879 L F
.532 .405 .653 r
.46505 .60994 m .46576 .61299 L .46834 .61231 L F
.766 .779 .863 r
.69328 .44333 m .69658 .44341 L .69493 .44208 L F
.691 .55 .689 r
.70254 .44324 m .7002 .44641 L .70256 .44545 L F
.582 .491 .717 r
.70254 .44324 m .70437 .44025 L .70144 .43978 L F
.70254 .44324 m .70509 .44262 L .70437 .44025 L F
.654 .575 .754 r
.70256 .44545 m .70509 .44262 L .70254 .44324 L F
.465 .438 .744 r
.2518 .56818 m .25368 .56751 L .25272 .56499 L F
.301 .135 .482 r
.2518 .56818 m .25326 .57008 L .25368 .56751 L F
.2518 .56818 m .25164 .57084 L .25326 .57008 L F
.372 .08 .334 r
.24101 .6338 m .24034 .63607 L .23822 .63665 L F
.313 .073 .381 r
.24341 .63081 m .24287 .63319 L .24101 .6338 L F
.393 .099 .343 r
.24239 .63553 m .24101 .6338 L .24287 .63319 L F
.24239 .63553 m .24034 .63607 L .24101 .6338 L F
.649 .814 .962 r
.20679 .65378 m .20851 .65495 L .21088 .6541 L F
.927 .633 .466 r
.74751 .42746 m .7493 .42821 L .74759 .42966 L F
.932 .645 .474 r
.7493 .42821 m .74941 .43082 L .74759 .42966 L F
.118 .11 .572 r
.20225 .70141 m .19922 .69936 L .20254 .69941 L F
0 0 .012 r
.20254 .69941 m .20398 .69538 L .20441 .6991 L F
.298 .02 .312 r
.20441 .6991 m .20225 .70141 L .20254 .69941 L F
.774 .995 .869 r
.7715 .43571 m .77034 .43787 L .77201 .43625 L F
.333 .052 .328 r
.41268 .58034 m .41 .58307 L .41198 .58229 L F
0 0 .067 r
.41198 .58229 m .4144 .57928 L .41268 .58034 L F
.849 .869 .856 r
.77652 .39816 m .77353 .39866 L .77537 .39671 L F
.91 .912 .809 r
.77652 .39816 m .7732 .40023 L .77353 .39866 L F
.77652 .39816 m .77414 .40142 L .7732 .40023 L F
.613 .723 .924 r
.77786 .39571 m .77652 .39816 L .77537 .39671 L F
.77786 .39571 m .77908 .39741 L .77652 .39816 L F
.756 .573 .649 r
.48826 .58948 m .48657 .59172 L .486 .58924 L F
.843 .894 .875 r
.73677 .43269 m .74041 .43138 L .73934 .43228 L F
0 0 .182 r
.74041 .43138 m .74174 .42697 L .74247 .43022 L F
0 0 0 r
.73934 .43228 m .74041 .43138 L .74247 .43022 L F
.627 .463 .641 r
.41574 .6246 m .41312 .62493 L .41545 .62211 L F
.88 .984 .707 r
.61015 .49019 m .6126 .48765 L .61182 .48683 L F
.61015 .49019 m .61047 .49088 L .6126 .48765 L F
.904 .92 .819 r
.6126 .48765 m .61369 .4836 L .61182 .48683 L F
.599 .847 .991 r
.18175 .65681 m .18395 .65708 L .18141 .6562 L F
.581 .846 .995 r
.18395 .65708 m .18448 .65544 L .18141 .6562 L F
.18395 .65708 m .1849 .65691 L .18448 .65544 L F
.429 .352 .668 r
.41671 .61812 m .41545 .62211 L .4144 .61853 L F
.41671 .61812 m .41707 .62175 L .41545 .62211 L F
.439 .392 .709 r
.41707 .62175 m .41813 .62388 L .41545 .62211 L F
.507 .377 .637 r
.41813 .62388 m .41574 .6246 L .41545 .62211 L F
.21 .671 .944 r
.22643 .53967 m .22848 .53983 L .23019 .54067 L F
.102 .633 .869 r
.22848 .53983 m .23232 .54048 L .23019 .54067 L F
.051 0 .026 r
.54018 .50137 m .54295 .49895 L .54101 .49985 L F
.609 .682 .893 r
.74391 .43429 m .74765 .43585 L .74653 .43355 L F
0 .418 .821 r
.75044 .43557 m .74653 .43355 L .74765 .43585 L F
.695 .454 .553 r
.51642 .54176 m .51483 .54272 L .51413 .54031 L F
.661 .111 0 r
.19696 .69804 m .19922 .69936 L .19779 .69931 L F
.19779 .69931 m .19922 .69936 L .19696 .69804 L F
.19696 .69804 m .19779 .69931 L .19628 .69638 L F
.19779 .69931 m .19696 .69804 L .19496 .70156 L F
0 .154 .637 r
.5582 .57688 m .55893 .57714 L .55645 .57678 L F
.843 .882 .869 r
.55893 .57714 m .56074 .57887 L .56222 .57613 L F
.55893 .57714 m .56222 .57613 L .56173 .57702 L F
.038 .505 .884 r
.56173 .57702 m .56173 .57696 L .56005 .57579 L F
.642 .212 0 r
.56175 .57702 m .56005 .57579 L .56173 .57696 L F
.038 .505 .884 r
.5611 .57655 m .56005 .57579 L .56039 .57602 L F
.56173 .57702 m .56005 .57579 L .5611 .57655 L F
0 0 0 r
.5611 .57655 m .55893 .57714 L .56173 .57702 L F
.642 .212 0 r
.56019 .57601 m .56005 .57579 L .5611 .57655 L F
0 0 0 r
.56039 .57602 m .56031 .57608 L .5611 .57655 L F
.56031 .57608 m .55893 .57714 L .5611 .57655 L F
.56031 .57608 m .55905 .57706 L .55893 .57714 L F
.56039 .57602 m .56028 .57611 L .56031 .57608 L F
.56028 .57611 m .55905 .57706 L .56031 .57608 L F
.074 .495 .896 r
.56358 .58043 m .56074 .57887 L .56272 .57879 L F
0 .154 .637 r
.55872 .57729 m .56074 .57887 L .55893 .57714 L F
.742 .243 .046 r
.55924 .57783 m .56272 .57879 L .56074 .57887 L F
.55924 .57783 m .56223 .57982 L .56272 .57879 L F
.224 .191 .609 r
.56223 .57982 m .56173 .57696 L .56272 .57879 L F
.56223 .57982 m .5631 .58054 L .56173 .57696 L F
.642 .212 0 r
.5631 .58054 m .56026 .57612 L .56175 .57702 L F
0 0 0 r
.55905 .57706 m .55825 .57768 L .55893 .57714 L F
0 .154 .637 r
.5582 .57688 m .55872 .57729 L .55893 .57714 L F
.536 0 0 r
.55893 .57714 m .5552 .57707 L .55645 .57678 L F
.55893 .57714 m .55825 .57768 L .5552 .57707 L F
.793 .413 .337 r
.56005 .57579 m .5599 .57611 L .55861 .57583 L F
.724 .97 .932 r
.56019 .57617 m .55861 .57583 L .55825 .57768 L F
.793 .413 .337 r
.5599 .57611 m .55889 .57821 L .55861 .57583 L F
.724 .97 .932 r
.56028 .57611 m .55861 .57583 L .56019 .57617 L F
.642 .212 0 r
.56028 .57611 m .56019 .57601 L .56031 .57608 L F
.56025 .5761 m .56019 .57601 L .56028 .57611 L F
.724 .97 .932 r
.56039 .57602 m .559 .57587 L .56028 .57611 L F
.559 .57587 m .55861 .57583 L .56028 .57611 L F
.642 .212 0 r
.56026 .57612 m .56025 .5761 L .56028 .57611 L F
.56026 .57612 m .56031 .57608 L .56175 .57702 L F
.56019 .57601 m .5611 .57655 L .56175 .57702 L F
.189 0 0 r
.55428 .5764 m .5582 .57688 L .55645 .57678 L F
.707 .714 .854 r
.7246 .43341 m .72559 .43647 L .72832 .43408 L F
.87 .994 .765 r
.54198 .51487 m .54403 .5121 L .54218 .51299 L F
.874 .931 .55 r
.54198 .51487 m .54064 .5163 L .54142 .5173 L F
.54198 .51487 m .54218 .51299 L .54064 .5163 L F
.673 .568 .729 r
.49391 .58295 m .49455 .58716 L .49107 .58587 L F
.355 .007 .228 r
.45094 .57165 m .44784 .57381 L .45053 .57248 L F
0 .216 .732 r
.51467 .55938 m .51418 .55803 L .51192 .55619 L F
.652 .142 0 r
.51467 .55938 m .51484 .56013 L .51418 .55803 L F
.51467 .55938 m .51625 .56133 L .51484 .56013 L F
.004 0 .048 r
.535 .50743 m .53758 .50452 L .53563 .50531 L F
.199 0 0 r
.70308 .39345 m .70088 .39324 L .69999 .3942 L F
.504 .163 .322 r
.43115 .58164 m .4338 .5803 L .43103 .58084 L F
.824 .575 .562 r
.60486 .43699 m .60486 .43949 L .60795 .44012 L F
.642 .61 .801 r
.60514 .4422 m .60795 .44012 L .60646 .44135 L F
.60514 .4422 m .60486 .43949 L .60795 .44012 L F
.683 .592 .748 r
.60795 .44012 m .61091 .44081 L .61101 .43657 L F
.764 .696 .787 r
.48002 .59157 m .47749 .59232 L .48032 .58954 L F
.65 .839 .973 r
.73747 .38758 m .73371 .38751 L .73614 .38627 L F
.706 .796 .921 r
.73872 .385 m .73747 .38758 L .73614 .38627 L F
.73872 .385 m .73978 .38665 L .73747 .38758 L F
.11 0 .093 r
.55419 .57638 m .55409 .57432 L .55284 .57609 L F
.55419 .57638 m .55581 .57373 L .55409 .57432 L F
.41 .287 .6 r
.3809 .60704 m .38289 .60333 L .38062 .60485 L F
1 .813 .5 r
.63368 .42085 m .63484 .42214 L .63513 .41926 L F
.451 0 0 r
.63629 .41955 m .63504 .41872 L .63513 .41926 L F
.55 .378 .6 r
.63513 .41926 m .63825 .42131 L .63629 .41955 L F
.63513 .41926 m .63484 .42214 L .63825 .42131 L F
.321 0 0 r
.45754 .55915 m .45997 .56035 L .46076 .56072 L F
.421 0 0 r
.45997 .56035 m .46385 .56067 L .46076 .56072 L F
0 0 0 r
.59441 .52261 m .59331 .52379 L .59518 .52062 L F
0 0 .225 r
.59288 .52609 m .59331 .52379 L .59441 .52261 L F
.426 .578 .901 r
.27035 .54815 m .26949 .5502 L .26761 .54797 L F
.27035 .54815 m .27133 .54999 L .26949 .5502 L F
.24 0 .218 r
.24778 .62717 m .24589 .6279 L .24867 .62522 L F
.339 .022 .272 r
.24985 .62657 m .24867 .62522 L .25032 .62428 L F
.24985 .62657 m .24778 .62717 L .24867 .62522 L F
.456 .308 .591 r
.23159 .60412 m .23279 .60545 L .2334 .60367 L F
.23159 .60412 m .23141 .6067 L .23279 .60545 L F
.895 .981 .807 r
.65965 .43338 m .66103 .432 L .66122 .4297 L F
.585 .594 .828 r
.42569 .56767 m .42669 .5646 L .4268 .56505 L F
.47 .758 .993 r
.42882 .564 m .4268 .56505 L .42669 .5646 L F
.42882 .564 m .43086 .5655 L .4268 .56505 L F
.585 .594 .828 r
.42569 .56767 m .42855 .56794 L .42669 .5646 L F
.715 .549 .663 r
.42651 .56815 m .42855 .56794 L .42569 .56767 L F
.854 .67 .652 r
.54585 .54358 m .54785 .54457 L .54614 .54107 L F
.77 .725 .811 r
.72832 .43408 m .73179 .43465 L .73065 .43288 L F
.675 .699 .865 r
.73179 .43465 m .73307 .43081 L .73065 .43288 L F
.73179 .43465 m .73429 .43364 L .73307 .43081 L F
.928 .951 .619 r
.60903 .49205 m .60891 .49437 L .61047 .49088 L F
.906 .958 .626 r
.60903 .49205 m .61047 .49088 L .61015 .49019 L F
.422 .159 .407 r
.4531 .59517 m .45264 .59768 L .45033 .59815 L F
.428 .164 .409 r
.45478 .59688 m .4531 .59517 L .4555 .59483 L F
.45478 .59688 m .45264 .59768 L .4531 .59517 L F
.452 .206 .449 r
.41868 .6297 m .41593 .63087 L .41733 .63248 L F
.368 .066 .315 r
.58495 .45841 m .58671 .45946 L .58703 .45757 L F
.58495 .45841 m .58438 .46022 L .58671 .45946 L F
.775 .772 .85 r
.68429 .44801 m .68857 .44715 L .68691 .44538 L F
.802 .776 .829 r
.68691 .44538 m .68857 .44715 L .69018 .44571 L F
.853 .495 .373 r
.43742 .55898 m .4377 .56095 L .43975 .55973 L F
.287 .181 .555 r
.43964 .56206 m .4411 .5615 L .43975 .55973 L F
.553 .295 .479 r
.45812 .59179 m .45805 .59481 L .4555 .59483 L F
.532 .279 .476 r
.46057 .59437 m .45812 .59179 L .46162 .59215 L F
.46057 .59437 m .45805 .59481 L .45812 .59179 L F
0 .072 .632 r
.51812 .56436 m .51625 .56133 L .51749 .56234 L F
.403 .501 .845 r
.5681 .58729 m .56688 .58922 L .56527 .58566 L F
0 0 .316 r
.56677 .59167 m .56688 .58922 L .5681 .58729 L F
.176 0 .316 r
.60526 .44724 m .60394 .44622 L .60578 .44434 L F
.60526 .44724 m .60342 .44832 L .60394 .44622 L F
.51 .362 .616 r
.56356 .56218 m .56384 .56473 L .56148 .56531 L F
.534 .389 .63 r
.56384 .56473 m .56161 .56774 L .56148 .56531 L F
.598 .783 .969 r
.7443 .38428 m .74575 .38621 L .74212 .38519 L F
.779 .703 .78 r
.74212 .38519 m .74575 .38621 L .7437 .38814 L F
.806 .861 .89 r
.74827 .38338 m .74575 .38621 L .7443 .38428 L F
.756 .573 .649 r
.48826 .58948 m .48898 .594 L .48657 .59172 L F
0 .018 .535 r
.48933 .59159 m .48898 .594 L .48826 .58948 L F
.855 .693 .681 r
.76881 .40627 m .77287 .40936 L .77218 .41263 L F
.448 .746 .992 r
.77588 .40939 m .77287 .40936 L .77474 .40814 L F
.77474 .40814 m .77287 .40936 L .77588 .40939 L F
.626 .575 .777 r
.27846 .57907 m .27603 .58012 L .27534 .57639 L F
.245 0 .327 r
.27846 .57907 m .27584 .58272 L .27603 .58012 L F
.712 .485 .58 r
.55146 .5499 m .55362 .5475 L .55138 .54741 L F
.655 .43 .566 r
.54883 .55008 m .55146 .5499 L .55138 .54741 L F
0 0 .358 r
.19558 .70552 m .19642 .70743 L .19533 .7039 L F
.976 .738 .512 r
.66176 .40072 m .66166 .40371 L .66303 .40433 L F
0 0 .455 r
.66251 .40358 m .66303 .40433 L .66166 .40371 L F
.66251 .40358 m .66545 .40739 L .66303 .40433 L F
.689 .424 .517 r
.42329 .64818 m .427 .64568 L .42523 .64486 L F
.42329 .64818 m .4269 .64848 L .427 .64568 L F
.711 .443 .518 r
.427 .64568 m .4269 .64848 L .42915 .64803 L F
0 0 .205 r
.656 .40689 m .65601 .40325 L .6557 .4043 L F
.567 .659 .899 r
.44919 .5738 m .44911 .5771 L .44784 .57381 L F
.4503 .57391 m .44911 .5771 L .44919 .5738 L F
.45034 .57379 m .45153 .57675 L .44911 .5771 L F
.581 .521 .752 r
.45265 .57288 m .45153 .57675 L .45034 .57379 L F
.377 0 .031 r
.44872 .57519 m .45113 .57494 L .45178 .57406 L F
.45081 .57396 m .45178 .57406 L .45265 .57288 L F
.44872 .57519 m .45178 .57406 L .45081 .57396 L F
.567 .659 .899 r
.45034 .57379 m .4503 .57391 L .44919 .5738 L F
0 0 .535 r
.45069 .57907 m .44911 .5771 L .45153 .57675 L F
.114 0 .075 r
.40935 .58468 m .41198 .58229 L .41 .58307 L F
.413 .247 .544 r
.51423 .59171 m .51431 .59459 L .51199 .595 L F
.37 .388 .749 r
.62606 .43379 m .62819 .43519 L .62554 .43446 L F
.267 .619 .959 r
.75571 .40871 m .75686 .41011 L .7555 .40948 L F
.125 .669 .825 r
.21005 .53942 m .2123 .53937 L .21434 .53961 L F
.058 .624 .721 r
.2123 .53937 m .21647 .53913 L .21434 .53961 L F
0 0 .153 r
.65731 .41562 m .65695 .41165 L .65703 .41337 L F
0 0 0 r
.15781 .55248 m .15989 .55192 L .16101 .5511 L F
.15989 .55192 m .16287 .55018 L .16101 .5511 L F
.443 .224 .485 r
.22814 .61198 m .23124 .60894 L .2294 .60983 L F
.614 .68 .889 r
.7437 .38814 m .73978 .38665 L .74212 .38519 L F
.632 .837 .979 r
.70246 .43046 m .69851 .42998 L .70138 .42762 L F
.679 .739 .896 r
.70494 .42822 m .70246 .43046 L .70138 .42762 L F
.645 .631 .822 r
.70623 .43132 m .70246 .43046 L .70494 .42822 L F
.495 .334 .592 r
.42426 .60842 m .42151 .60707 L .42383 .60655 L F
.42426 .60842 m .4215 .60944 L .42151 .60707 L F
.751 .638 .735 r
.27796 .5622 m .27687 .56709 L .27513 .5656 L F
.141 0 0 r
.27687 .56709 m .27595 .56759 L .27513 .5656 L F
.27687 .56709 m .2777 .56752 L .27595 .56759 L F
0 0 .253 r
.27886 .5628 m .27687 .56709 L .27796 .5622 L F
.502 .426 .703 r
.27886 .5628 m .2777 .56752 L .27687 .56709 L F
.368 .125 .409 r
.24536 .63018 m .24341 .63081 L .24589 .6279 L F
.398 .159 .431 r
.24536 .63018 m .24287 .63319 L .24341 .63081 L F
.654 .575 .754 r
.70256 .44545 m .70634 .44641 L .70509 .44262 L F
.728 .615 .731 r
.45901 .58005 m .46221 .58091 L .46138 .57715 L F
.451 .365 .667 r
.46221 .58091 m .4646 .58112 L .46533 .57981 L F
.382 .187 .487 r
.26467 .60083 m .26435 .60361 L .26238 .60414 L F
.503 .369 .631 r
.26435 .60361 m .2624 .60665 L .26238 .60414 L F
.991 .834 .589 r
.61513 .47468 m .61563 .47849 L .61619 .47566 L F
.952 .912 .74 r
.61706 .47092 m .61513 .47468 L .61619 .47566 L F
.712 .485 .58 r
.55146 .5499 m .55485 .55017 L .55362 .5475 L F
.692 .518 .647 r
.55485 .55017 m .55734 .54726 L .55362 .5475 L F
.548 .411 .646 r
.45041 .58566 m .45261 .58265 L .45041 .58322 L F
.677 .343 .402 r
.45823 .56982 m .45647 .57026 L .45641 .56855 L F
.383 .236 .554 r
.27647 .57364 m .27648 .57634 L .27467 .57422 L F
.22 .201 .624 r
.27467 .57422 m .27648 .57634 L .27534 .57639 L F
.515 .302 .528 r
.53638 .58582 m .53767 .58605 L .5373 .58356 L F
.558 .331 .527 r
.5373 .58356 m .53767 .58605 L .53478 .58607 L F
.5373 .58356 m .53767 .58605 L .53478 .58607 L F
.547 .334 .543 r
.58162 .54435 m .58155 .54682 L .5792 .54734 L F
.133 0 .267 r
.58162 .54435 m .58381 .54125 L .58377 .54359 L F
.418 .231 .518 r
.58368 .54622 m .58162 .54435 L .58377 .54359 L F
.58368 .54622 m .58155 .54682 L .58162 .54435 L F
.532 .837 .999 r
.19767 .71591 m .19726 .71721 L .19527 .71637 L F
.549 .306 .5 r
.19767 .71591 m .19527 .71637 L .19726 .71721 L F
.805 .771 .822 r
.68843 .44483 m .68691 .44538 L .69018 .44571 L F
.748 .788 .885 r
.68843 .44483 m .69018 .44571 L .69328 .44333 L F
0 0 .145 r
.6688 .3999 m .67031 .3974 L .66777 .39822 L F
.9 .918 .524 r
.60676 .42863 m .6058 .43046 L .60732 .42643 L F
.11 0 0 r
.21647 .53913 m .21845 .53933 L .22026 .53931 L F
.392 0 0 r
.21845 .53933 m .22219 .53928 L .22026 .53931 L F
.887 .9 .832 r
.59675 .44526 m .59822 .44206 L .59913 .44149 L F
.59675 .44526 m .59528 .44551 L .59822 .44206 L F
.914 .864 .776 r
.76306 .42963 m .76503 .42872 L .7637 .42734 L F
.694 .665 .817 r
.61646 .43359 m .61423 .43591 L .61324 .43389 L F
.499 .628 .908 r
.61647 .43524 m .61423 .43591 L .61646 .43359 L F
.383 .157 .443 r
.24778 .62717 m .24536 .63018 L .24589 .6279 L F
.626 .231 .275 r
.54575 .60654 m .54453 .60862 L .54244 .60686 L F
.503 .098 .206 r
.54862 .60643 m .54453 .60862 L .54575 .60654 L F
.682 .591 .748 r
.61101 .43657 m .61091 .44081 L .61228 .43781 L F
.907 .512 .246 r
.61091 .44081 m .61228 .44294 L .61061 .44175 L F
.977 .917 .613 r
.77044 .4225 m .76971 .42117 L .77092 .41822 L F
.957 .823 .39 r
.77044 .4225 m .76957 .42386 L .76971 .42117 L F
.77044 .4225 m .77004 .42491 L .76957 .42386 L F
.604 .746 .945 r
.21286 .65384 m .21473 .65577 L .21694 .65503 L F
.921 .898 .788 r
.5448 .59066 m .54409 .59474 L .54211 .59215 L F
.5448 .59066 m .54348 .59436 L .54409 .59474 L F
0 .522 .835 r
.54451 .59451 m .54409 .59474 L .54348 .59436 L F
.54451 .59451 m .54657 .5954 L .54409 .59474 L F
.664 .737 .904 r
.63683 .41192 m .6338 .41328 L .63645 .41231 L F
.63683 .41192 m .6338 .41328 L .63645 .41231 L F
.515 .727 .97 r
.1849 .65691 m .18612 .65444 L .18448 .65544 L F
.659 .24 0 r
.52815 .58887 m .53012 .59203 L .52929 .5908 L F
.75 .455 0 r
.53012 .59203 m .5303 .5934 L .52929 .5908 L F
.53012 .59203 m .53085 .59477 L .5303 .5934 L F
.925 .974 .712 r
.60774 .49598 m .60891 .49437 L .60903 .49205 L F
.579 .367 .557 r
.48818 .57127 m .4857 .57431 L .48429 .57082 L F
.48818 .57127 m .48777 .57441 L .4857 .57431 L F
.4857 .57431 m .48777 .57441 L .48818 .57127 L F
.741 .652 .761 r
.52284 .53214 m .51985 .53504 L .52111 .5328 L F
.654 .456 .603 r
.57976 .48122 m .57676 .47908 L .57883 .47766 L F
.57976 .48122 m .5772 .48147 L .57676 .47908 L F
.747 .677 .783 r
.48228 .57388 m .48344 .57732 L .48023 .5769 L F
.751 .679 .781 r
.4857 .57431 m .48344 .57732 L .48228 .57388 L F
.819 .672 .701 r
.53787 .55318 m .54077 .55316 L .53918 .55023 L F
.706 .287 .248 r
.53901 .55449 m .54077 .55316 L .53787 .55318 L F
.351 0 0 r
.54181 .55383 m .54077 .55316 L .53901 .55449 L F
.54181 .55383 m .54355 .55411 L .54077 .55316 L F
.863 .912 .863 r
.63279 .42488 m .63401 .42471 L .63523 .42402 L F
.507 .691 .951 r
.63401 .42471 m .6377 .42337 L .63523 .42402 L F
.63401 .42471 m .63853 .42481 L .6377 .42337 L F
.216 .518 .915 r
.41285 .63886 m .41304 .64067 L .4125 .63915 L F
.41285 .63886 m .41579 .64157 L .41304 .64067 L F
.505 .509 .794 r
.42626 .57657 m .42502 .57897 L .42448 .57758 L F
.42626 .57657 m .42732 .57913 L .42502 .57897 L F
.888 .619 .525 r
.53027 .5373 m .53305 .53561 L .53227 .5349 L F
.53027 .5373 m .53256 .53783 L .53305 .53561 L F
.9 .984 .722 r
.53342 .53316 m .53305 .53561 L .5353 .53192 L F
.885 .989 .802 r
.53342 .53316 m .53227 .5349 L .53305 .53561 L F
.857 .859 .841 r
.62961 .43981 m .62739 .44239 L .63028 .4423 L F
.882 .794 .758 r
.62739 .44239 m .62809 .44575 L .63028 .4423 L F
.826 .844 .861 r
.62961 .43981 m .63028 .4423 L .63268 .43935 L F
0 0 .506 r
.19628 .69638 m .19779 .69931 L .1963 .69453 L F
.611 .535 .744 r
.60494 .45433 m .60257 .45511 L .60157 .45139 L F
0 0 0 r
.5478 .50776 m .54658 .509 L .54889 .5063 L F
.54942 .50629 m .54889 .5063 L .5506 .50484 L F
.54942 .50629 m .5478 .50776 L .54889 .5063 L F
.536 .166 .287 r
.69348 .40491 m .69716 .4039 L .69628 .40611 L F
.491 .134 .288 r
.69716 .4039 m .69898 .40591 L .69628 .40611 L F
.69716 .4039 m .69965 .4037 L .69898 .40591 L F
.456 .552 .865 r
.49102 .56444 m .49066 .56752 L .48959 .5646 L F
.49102 .56444 m .49281 .56781 L .49066 .56752 L F
.809 .877 .896 r
.75875 .43508 m .75986 .43636 L .76252 .43396 L F
.959 .947 .688 r
.67668 .44877 m .6747 .4503 L .67586 .44777 L F
.67668 .44877 m .6755 .45113 L .6747 .4503 L F
.403 .841 .941 r
.17521 .56106 m .17548 .56019 L .17354 .56111 L F
.17521 .56106 m .17755 .56048 L .17548 .56019 L F
.076 0 0 r
.63184 .40455 m .63389 .40377 L .63467 .40369 L F
.305 .786 .708 r
.63467 .40369 m .63644 .4029 L .63782 .40247 L F
.322 .807 .784 r
.63467 .40369 m .63389 .40377 L .63644 .4029 L F
.625 .875 .53 r
.54658 .509 m .54512 .51053 L .54403 .5121 L F
.674 .966 .764 r
.54403 .5121 m .54512 .51053 L .54218 .51299 L F
.924 .922 .792 r
.77204 .40455 m .7732 .40023 L .77414 .40142 L F
.116 0 .123 r
.27143 .59422 m .26907 .59697 L .26961 .59492 L F
.558 .015 0 r
.49925 .60022 m .49569 .59732 L .49703 .59847 L F
.212 0 0 r
.23857 .53991 m .24054 .5403 L .24251 .54044 L F
.402 .818 .973 r
.24054 .5403 m .24454 .5404 L .24251 .54044 L F
.284 .603 .952 r
.64418 .43064 m .64523 .42943 L .64285 .42912 L F
.64418 .43064 m .64672 .431 L .64523 .42943 L F
.271 .053 .388 r
.23854 .59746 m .24087 .59784 L .24074 .59464 L F
.33 .055 .336 r
.23838 .59899 m .24087 .59784 L .23854 .59746 L F
.433 .452 .779 r
.76471 .40343 m .7675 .40541 L .76471 .40773 L F
.477 .84 .588 r
.76471 .40773 m .76326 .4088 L .76402 .41021 L F
.76471 .40773 m .7675 .40541 L .76326 .4088 L F
.716 .759 .887 r
.72319 .42452 m .7194 .42407 L .72223 .42226 L F
.612 .692 .9 r
.72451 .42129 m .72319 .42452 L .72223 .42226 L F
.72451 .42129 m .72626 .42373 L .72319 .42452 L F
.106 .273 .752 r
.5193 .56784 m .52016 .56642 L .51812 .56436 L F
.16 .347 .801 r
.5193 .56784 m .5217 .56984 L .52016 .56642 L F
.797 .482 0 r
.5221 .57378 m .5233 .57736 L .52262 .57565 L F
.088 .27 .755 r
.5233 .57736 m .52418 .57587 L .52262 .57565 L F
.5233 .57736 m .52564 .57942 L .52418 .57587 L F
.967 .753 .563 r
.60381 .43372 m .60486 .43699 L .60345 .43564 L F
.808 .671 .711 r
.60486 .43949 m .60345 .43564 L .60486 .43699 L F
.511 .32 .558 r
.60486 .43699 m .60723 .43924 L .60486 .43949 L F
.648 .3 .368 r
.6082 .43733 m .60723 .43924 L .60486 .43699 L F
.511 .32 .558 r
.60486 .43949 m .60723 .43924 L .60486 .43699 L F
.272 .515 .904 r
.45099 .5631 m .45268 .56528 L .4534 .56374 L F
.729 .941 .623 r
.45268 .56528 m .45116 .56654 L .4534 .56374 L F
.918 .877 .779 r
.75321 .39679 m .7526 .40095 L .75105 .39981 L F
.4 .751 .993 r
.75374 .39981 m .7526 .40095 L .75105 .39981 L F
0 0 .192 r
.75226 .4035 m .7526 .40095 L .75374 .39981 L F
.629 .815 .972 r
.19026 .69228 m .19185 .69346 L .18794 .69308 L F
.18794 .69308 m .19185 .69346 L .19026 .69228 L F
.379 .71 .986 r
.19226 .69216 m .19185 .69346 L .19026 .69228 L F
.19026 .69228 m .19185 .69346 L .19226 .69216 L F
.631 .84 .98 r
.19577 .54099 m .19198 .54085 L .19414 .54026 L F
.301 .788 .898 r
.19414 .54026 m .19802 .54 L .19577 .54099 L F
.825 .918 .899 r
.5123 .52389 m .50805 .52546 L .51112 .523 L F
.851 .94 .88 r
.51389 .52211 m .5123 .52389 L .51112 .523 L F
.434 .484 .812 r
.43303 .56426 m .43524 .56835 L .43668 .56747 L F
.033 0 .128 r
.43668 .56747 m .43428 .5705 L .43524 .56835 L F
.43668 .56747 m .43428 .5705 L .43524 .56835 L F
.197 0 0 r
.23232 .54048 m .23447 .54055 L .2362 .54012 L F
.149 .691 .733 r
.23447 .54055 m .23857 .53991 L .2362 .54012 L F
.809 .856 .884 r
.44551 .57466 m .4411 .57599 L .44399 .57346 L F
.645 .817 .966 r
.44399 .57346 m .44551 .57466 L .44784 .57381 L F
.499 0 0 r
.44399 .57346 m .44784 .57381 L .44551 .57466 L F
.986 .788 .555 r
.55933 .59045 m .56101 .58921 L .56064 .59174 L F
.473 0 0 r
.55712 .58936 m .56101 .58921 L .55933 .59045 L F
0 .049 .582 r
.39684 .63661 m .39741 .64001 L .39827 .63845 L F
.131 .311 .779 r
.39741 .64001 m .39974 .64177 L .39827 .63845 L F
.751 .674 .775 r
.70878 .44553 m .71247 .44614 L .71127 .44255 L F
.745 .671 .778 r
.71127 .44255 m .71247 .44614 L .71499 .44317 L F
.383 .167 .458 r
.25272 .62126 m .25077 .62193 L .25308 .61886 L F
.327 .094 .4 r
.25272 .62126 m .25032 .62428 L .25077 .62193 L F
.985 .789 .559 r
.76278 .42378 m .76441 .4225 L .76371 .41988 L F
.76278 .42378 m .76402 .4249 L .76441 .4225 L F
.87 .993 .751 r
.5042 .59841 m .5062 .5997 L .506 .59841 L F
.708 .693 .834 r
.506 .59841 m .5062 .5997 L .50958 .59863 L F
.428 0 .067 r
.68877 .39926 m .68955 .39764 L .68613 .39851 L F
.478 .101 .245 r
.69119 .39957 m .68955 .39764 L .68877 .39926 L F
.69119 .39957 m .6921 .39749 L .68955 .39764 L F
.673 .87 .973 r
.74389 .39596 m .7423 .39832 L .7414 .39757 L F
.74389 .39596 m .74511 .39723 L .7423 .39832 L F
.33 0 .136 r
.7423 .39832 m .7416 .39996 L .7414 .39757 L F
.7423 .39832 m .74483 .39922 L .7416 .39996 L F
.7423 .39832 m .74511 .39723 L .74483 .39922 L F
.437 .082 .264 r
.62024 .41164 m .62317 .40968 L .62077 .41036 L F
.563 .313 .495 r
.44392 .65441 m .44759 .65197 L .4428 .65238 L F
.623 .563 .767 r
.47789 .59766 m .47521 .59821 L .4755 .59522 L F
.705 .482 .583 r
.47789 .59766 m .47507 .60013 L .47521 .59821 L F
0 .237 .687 r
.24565 .55687 m .24644 .55712 L .24462 .5558 L F
.24565 .55687 m .24833 .5586 L .24644 .55712 L F
.942 .841 .715 r
.62052 .46937 m .62013 .46625 L .6193 .4682 L F
.859 .877 .85 r
.61799 .46971 m .62052 .46937 L .6193 .4682 L F
0 0 0 r
.21959 .62629 m .22241 .62434 L .22036 .62494 L F
.464 .878 .748 r
.63782 .40247 m .63862 .40162 L .64003 .40122 L F
.63782 .40247 m .63644 .4029 L .63862 .40162 L F
.267 .619 .959 r
.75571 .40871 m .7555 .40948 L .75389 .41076 L F
0 0 .29 r
.44797 .5651 m .44685 .56534 L .44767 .56395 L F
0 0 0 r
.59094 .5025 m .58901 .50577 L .59052 .50398 L F
0 0 .065 r
.59052 .50398 m .58901 .50577 L .58839 .50789 L F
.571 .392 .6 r
.5672 .5354 m .56989 .53498 L .56974 .53234 L F
.515 .312 .544 r
.56736 .53784 m .56989 .53498 L .5672 .5354 L F
.744 .875 .94 r
.68301 .43984 m .67962 .43998 L .68184 .43868 L F
.744 .879 .942 r
.68505 .4386 m .68301 .43984 L .68184 .43868 L F
0 0 0 r
.54661 .50901 m .54658 .509 L .5478 .50776 L F
.54661 .50901 m .54512 .51053 L .54658 .509 L F
.427 .066 .247 r
.464 .5916 m .46057 .59437 L .46162 .59215 L F
.662 .638 .816 r
.55294 .56818 m .55557 .56765 L .55424 .56425 L F
.451 .213 .46 r
.22523 .61898 m .22695 .62079 L .22745 .61844 L F
.22523 .61898 m .2248 .62132 L .22695 .62079 L F
.419 .342 .664 r
.49537 .58233 m .49455 .58716 L .49391 .58295 L F
.49537 .58233 m .49701 .58615 L .49455 .58716 L F
.429 .368 .687 r
.49701 .58615 m .49698 .58824 L .49455 .58716 L F
.41 .287 .6 r
.3809 .60704 m .38271 .60646 L .38289 .60333 L F
.393 .264 .584 r
.38109 .60964 m .38271 .60646 L .3809 .60704 L F
.382 .126 .396 r
.25511 .61825 m .25308 .61886 L .25565 .61601 L F
.419 .159 .41 r
.25724 .61769 m .25565 .61601 L .25781 .61545 L F
.25724 .61769 m .25511 .61825 L .25565 .61601 L F
.452 .29 .57 r
.24786 .58005 m .24992 .58199 L .24985 .57953 L F
.24786 .58005 m .24803 .58258 L .24992 .58199 L F
.415 .195 .468 r
.22279 .62192 m .22241 .62434 L .2248 .62132 L F
.684 .654 .815 r
.41663 .61582 m .4144 .61853 L .41445 .61705 L F
.608 .541 .753 r
.41671 .61812 m .4144 .61853 L .41663 .61582 L F
.447 .166 .394 r
.5773 .52593 m .57979 .52553 L .57997 .52334 L F
.258 .022 .353 r
.57997 .52334 m .58244 .52234 L .58227 .52035 L F
.382 .172 .466 r
.57979 .52553 m .58244 .52234 L .57997 .52334 L F
.536 .166 .287 r
.69348 .40491 m .69628 .40611 L .69374 .40593 L F
.12 0 .009 r
.58159 .46253 m .58438 .46022 L .58206 .46098 L F
.869 .93 .862 r
.76874 .40605 m .77204 .40455 L .77007 .40704 L F
.76874 .40605 m .77107 .40354 L .77204 .40455 L F
.924 .922 .792 r
.77204 .40455 m .77107 .40354 L .7732 .40023 L F
0 0 0 r
.74758 .41488 m .74849 .41314 L .7467 .41583 L F
.715 .954 .95 r
.74995 .41093 m .75116 .41153 L .74849 .41314 L F
0 0 0 r
.74995 .41093 m .74849 .41314 L .74758 .41488 L F
.906 .849 .776 r
.74758 .41488 m .74895 .41044 L .74995 .41093 L F
.74895 .41044 m .74907 .41005 L .74995 .41093 L F
.715 .954 .95 r
.74995 .41093 m .75123 .41148 L .75116 .41153 L F
.857 .763 .758 r
.62359 .45417 m .62446 .45759 L .62555 .45566 L F
.294 0 0 r
.71077 .39846 m .71428 .39765 L .71312 .39878 L F
.173 0 0 r
.71312 .39878 m .71428 .39765 L .71675 .3973 L F
.669 .679 .851 r
.55712 .58936 m .55264 .58769 L .55495 .58808 L F
.845 .553 .495 r
.55625 .59061 m .55712 .58936 L .55495 .58808 L F
.919 .672 .549 r
.55712 .58936 m .55625 .59061 L .55495 .58808 L F
.55712 .58936 m .55786 .59155 L .55625 .59061 L F
.351 .494 .862 r
.55712 .58936 m .55867 .5872 L .55535 .58553 L F
.473 0 0 r
.55712 .58936 m .56064 .59174 L .55786 .59155 L F
.55911 .5907 m .55933 .59045 L .56064 .59174 L F
.55712 .58936 m .55933 .59045 L .55911 .5907 L F
0 0 .352 r
.55897 .59154 m .55961 .59014 L .55933 .59045 L F
.55961 .59014 m .56004 .58921 L .55933 .59045 L F
.191 .271 .717 r
.55933 .59045 m .55712 .58936 L .55625 .59061 L F
.55933 .59045 m .55867 .5872 L .55712 .58936 L F
.474 .319 .589 r
.20614 .69286 m .20398 .69538 L .20431 .69349 L F
.148 .615 .927 r
.24258 .55574 m .24094 .55478 L .23848 .55446 L F
.267 .69 .967 r
.24258 .55574 m .24462 .5558 L .24094 .55478 L F
.343 .055 .323 r
.40207 .58928 m .40143 .59128 L .4042 .58858 L F
.05 .241 .739 r
.5217 .56984 m .52178 .5713 L .52266 .56999 L F
.095 .054 .516 r
.52178 .5713 m .52376 .57223 L .52266 .56999 L F
.52178 .5713 m .5221 .57378 L .52376 .57223 L F
.596 .375 .551 r
.19044 .7198 m .19262 .71705 L .19077 .71728 L F
.839 .63 .62 r
.43802 .65414 m .4412 .65154 L .437 .65104 L F
.43802 .65414 m .44122 .65477 L .4412 .65154 L F
.373 .747 .99 r
.23216 .55398 m .23036 .55305 L .22881 .55322 L F
.01 .513 .866 r
.23462 .55465 m .23036 .55305 L .23216 .55398 L F
.178 .217 .665 r
.78363 .41548 m .78552 .4172 L .78384 .41911 L F
0 0 .358 r
.78543 .41971 m .78384 .41911 L .78552 .4172 L F
.78543 .41971 m .78369 .42168 L .78384 .41911 L F
.408 0 0 r
.46385 .56067 m .46587 .56115 L .46719 .56066 L F
.124 0 0 r
.46587 .56115 m .4696 .55988 L .46719 .56066 L F
.379 .153 .441 r
.23822 .63665 m .2378 .63907 L .23582 .63967 L F
.338 0 .181 r
.23686 .64134 m .23582 .63967 L .2378 .63907 L F
.23686 .64134 m .23468 .64187 L .23582 .63967 L F
.546 .208 .347 r
.44561 .58181 m .44286 .58231 L .443 .58035 L F
.369 .68 .978 r
.26595 .54648 m .26547 .54787 L .26397 .54637 L F
.26595 .54648 m .26761 .54797 L .26547 .54787 L F
.281 0 0 r
.75375 .43612 m .75293 .43616 L .75044 .43557 L F
.431 .872 .83 r
.7553 .43513 m .75375 .43612 L .75616 .43593 L F
.7553 .43513 m .75293 .43616 L .75375 .43612 L F
.857 .811 .804 r
.43584 .63213 m .43274 .63356 L .43527 .63049 L F
.592 .325 .48 r
.43584 .63213 m .43187 .63421 L .43274 .63356 L F
.43584 .63213 m .43592 .63598 L .43187 .63421 L F
.09 0 0 r
.43766 .63236 m .43795 .6324 L .43584 .63213 L F
.269 .082 .433 r
.43756 .635 m .43584 .63213 L .43795 .6324 L F
.43756 .635 m .43592 .63598 L .43584 .63213 L F
.499 .392 .663 r
.2179 .66377 m .21522 .66454 L .21609 .66124 L F
.398 .198 .489 r
.2179 .66377 m .21623 .66762 L .21522 .66454 L F
.931 .771 .662 r
.49664 .53657 m .49367 .54035 L .49515 .53586 L F
.49664 .53657 m .49569 .54196 L .49367 .54035 L F
.453 .077 .234 r
.47176 .58492 m .47609 .58508 L .47516 .58405 L F
.719 .61 .735 r
.47145 .5878 m .47609 .58508 L .47176 .58492 L F
.587 .35 .524 r
.568 .58523 m .56527 .58566 L .56582 .58329 L F
0 0 .339 r
.56613 .58389 m .56527 .58566 L .56582 .58329 L F
.638 .175 0 r
.56358 .58043 m .56613 .58389 L .56582 .58329 L F
.751 .236 0 r
.40352 .64454 m .39974 .64177 L .40121 .64274 L F
.62 .83 .433 r
.47749 .59232 m .4755 .59522 L .47634 .59393 L F
.116 .358 .821 r
.47852 .58834 m .48024 .58961 L .47967 .58722 L F
.48024 .58961 m .481 .59017 L .48059 .58926 L F
.48024 .58961 m .48059 .58926 L .47967 .58722 L F
.498 .818 .505 r
.47968 .59016 m .47749 .59232 L .47891 .59092 L F
.48032 .58954 m .47945 .59039 L .47968 .59016 L F
.47945 .59039 m .47749 .59232 L .47968 .59016 L F
0 0 0 r
.47749 .59232 m .47806 .59278 L .47891 .59092 L F
.47749 .59232 m .47634 .59393 L .47806 .59278 L F
.252 0 0 r
.22692 .6479 m .22475 .64825 L .22799 .64578 L F
.124 0 .092 r
.22983 .64502 m .22692 .6479 L .22799 .64578 L F
.739 .702 .815 r
.7089 .42876 m .70623 .43132 L .70494 .42822 L F
.814 1 .819 r
.63413 .42238 m .63094 .42583 L .63279 .42488 L F
.63413 .42238 m .62912 .42646 L .63094 .42583 L F
.93 .554 .261 r
.50087 .60115 m .49851 .60109 L .49925 .60022 L F
.564 .08 .064 r
.5031 .59999 m .49851 .60109 L .50087 .60115 L F
.179 0 0 r
.70821 .39897 m .70981 .39927 L .70754 .39999 L F
.70821 .39897 m .71077 .39846 L .70981 .39927 L F
.724 .918 .959 r
.52284 .53214 m .52111 .5328 L .52178 .53132 L F
.52178 .53132 m .52111 .5328 L .52284 .53214 L F
.52284 .53214 m .52111 .5328 L .52178 .53132 L F
.033 .203 .708 r
.53095 .59856 m .53299 .59901 L .5308 .59647 L F
.53095 .59856 m .53307 .60104 L .53299 .59901 L F
.409 .86 .823 r
.16717 .56356 m .16599 .56433 L .1695 .56327 L F
.172 .704 .715 r
.17192 .56258 m .16717 .56356 L .1695 .56327 L F
.042 0 0 r
.23268 .64256 m .22983 .64502 L .23096 .64354 L F
.444 .036 .17 r
.38863 .63299 m .39127 .63301 L .39187 .63088 L F
.053 .239 .736 r
.39187 .63088 m .39298 .62963 L .39066 .62761 L F
.902 .967 .65 r
.43552 .59029 m .43834 .58685 L .4371 .58824 L F
.43552 .59029 m .4356 .59145 L .43834 .58685 L F
0 0 .166 r
.43934 .58444 m .43834 .58685 L .43714 .58506 L F
0 0 0 r
.43922 .58725 m .4371 .58824 L .43834 .58685 L F
.649 .495 .661 r
.43794 .59244 m .43741 .59596 L .43563 .59562 L F
.833 .669 .68 r
.4356 .59145 m .43741 .59596 L .43794 .59244 L F
.741 .99 .883 r
.59913 .44149 m .60147 .4393 L .60258 .44207 L F
.772 .781 .861 r
.60486 .43949 m .60258 .44207 L .60147 .4393 L F
.597 .482 .693 r
.45264 .59768 m .45058 .60065 L .45033 .59815 L F
0 0 .115 r
.59682 .51916 m .59518 .52062 L .59695 .51718 L F
0 0 0 r
.59441 .52261 m .59518 .52062 L .59682 .51916 L F
.48 .345 .619 r
.56989 .53498 m .57183 .53162 L .56974 .53234 L F
.031 .535 .874 r
.45468 .558 m .45603 .55825 L .45754 .55915 L F
.366 0 0 r
.45603 .55825 m .45997 .56035 L .45754 .55915 L F
.431 0 0 r
.64231 .40021 m .64538 .40089 L .64387 .40027 L F
.586 .9 .634 r
.53871 .51977 m .53547 .52249 L .5364 .52141 L F
.428 0 .06 r
.5051 .58334 m .50112 .58361 L .50298 .58323 L F
.95 .929 .581 r
.53598 .52806 m .5353 .53192 L .5379 .52928 L F
.53598 .52806 m .53464 .53158 L .5353 .53192 L F
.879 .988 .725 r
.53464 .53158 m .53342 .53316 L .5353 .53192 L F
.608 .873 .992 r
.72141 .38853 m .71784 .38848 L .72019 .38741 L F
.629 .787 .957 r
.72272 .38612 m .72141 .38853 L .72019 .38741 L F
.72272 .38612 m .72394 .38769 L .72141 .38853 L F
.64 .219 .229 r
.54109 .5904 m .54447 .5892 L .54081 .58898 L F
.54109 .5904 m .54304 .59126 L .54447 .5892 L F
.578 .222 .329 r
.5448 .59066 m .54699 .59089 L .54447 .5892 L F
.722 .318 .282 r
.54447 .5892 m .54304 .59126 L .5448 .59066 L F
.887 .924 .536 r
.5448 .59066 m .54329 .59295 L .54348 .59436 L F
.806 .471 .421 r
.54304 .59126 m .54329 .59295 L .5448 .59066 L F
.459 0 0 r
.54699 .59089 m .54304 .59126 L .5448 .59066 L F
.606 .181 .209 r
.54447 .5892 m .54304 .59126 L .54699 .59089 L F
.647 .502 .672 r
.43741 .59596 m .43495 .5981 L .43563 .59562 L F
.762 .828 .903 r
.67608 .45411 m .67752 .45569 L .67937 .45421 L F
.454 .244 .504 r
.25511 .61825 m .25272 .62126 L .25308 .61886 L F
.044 .531 .885 r
.47257 .60599 m .4741 .60703 L .46996 .60532 L F
.882 .889 .832 r
.47638 .60383 m .4741 .60703 L .47257 .60599 L F
.364 0 .085 r
.4766 .60676 m .47337 .60824 L .4741 .60703 L F
.561 .403 .624 r
.47638 .60383 m .4766 .60676 L .4741 .60703 L F
.334 .124 .438 r
.58381 .54125 m .58595 .53821 L .5864 .54032 L F
.337 .153 .478 r
.58377 .54359 m .58381 .54125 L .5864 .54032 L F
0 0 0 r
.15781 .55248 m .15636 .55317 L .15989 .55192 L F
.603 .438 .631 r
.46101 .64582 m .46108 .64842 L .46347 .64539 L F
.46347 .64539 m .46108 .64842 L .46101 .64582 L F
.449 .243 .507 r
.26646 .60299 m .26467 .60083 L .26681 .60018 L F
.26646 .60299 m .26435 .60361 L .26467 .60083 L F
.492 .225 .437 r
.44221 .60368 m .43942 .60608 L .43957 .60398 L F
.563 .158 .231 r
.45509 .58197 m .45901 .58005 L .45554 .58025 L F
.45509 .58197 m .45757 .58217 L .45901 .58005 L F
.728 .35 .335 r
.45757 .58217 m .4614 .58295 L .45901 .58005 L F
.653 .962 .926 r
.19779 .69931 m .19922 .69936 L .19973 .69807 L F
.505 .369 .629 r
.19779 .69931 m .19973 .69807 L .19922 .69936 L F
.15 .329 .789 r
.63853 .42481 m .63999 .42834 L .63963 .42635 L F
.302 .531 .907 r
.63999 .42834 m .64104 .42693 L .63963 .42635 L F
.63999 .42834 m .64285 .42912 L .64104 .42693 L F
.996 .856 .573 r
.65843 .4187 m .65683 .4209 L .65736 .41764 L F
.65843 .4187 m .65776 .42211 L .65683 .4209 L F
.441 .295 .586 r
.22667 .61295 m .22619 .61387 L .22834 .61529 L F
.548 .435 .676 r
.2266 .6157 m .22834 .61529 L .22619 .61387 L F
.796 .594 .628 r
.59996 .48226 m .59944 .48461 L .59817 .48161 L F
.276 .335 .743 r
.46532 .609 m .46666 .60879 L .46807 .60597 L F
.75 .574 .657 r
.46666 .60879 m .47093 .60563 L .46807 .60597 L F
0 0 0 r
.46996 .60532 m .46807 .60597 L .47093 .60563 L F
0 0 .253 r
.27886 .5628 m .27796 .5622 L .27838 .56075 L F
.106 0 0 r
.67031 .3974 m .6727 .39758 L .67402 .39759 L F
.254 0 0 r
.67402 .39759 m .6727 .39758 L .67636 .39803 L F
.502 .139 .283 r
.47516 .58405 m .47716 .5849 L .47801 .58265 L F
.559 .24 .384 r
.47716 .5849 m .48076 .58243 L .47801 .58265 L F
.569 .38 .586 r
.5792 .54734 m .57919 .54988 L .57673 .55024 L F
.538 .31 .517 r
.5792 .54734 m .58152 .54936 L .57919 .54988 L F
.5792 .54734 m .58155 .54682 L .58152 .54936 L F
.339 0 .049 r
.21093 .67458 m .21458 .67226 L .21266 .67565 L F
.479 .342 .616 r
.21458 .67226 m .21485 .67511 L .21266 .67565 L F
.041 0 .064 r
.21485 .67511 m .21219 .67794 L .21266 .67565 L F
.909 .773 .699 r
.50279 .59126 m .50233 .59126 L .50295 .5908 L F
.671 .467 .6 r
.50478 .59124 m .5018 .59453 L .50233 .59126 L F
.692 .966 .738 r
.50459 .5896 m .50233 .59126 L .50291 .59051 L F
.799 .83 .358 r
.5018 .59453 m .50291 .59051 L .50233 .59126 L F
.50233 .59261 m .50199 .59275 L .50291 .59051 L F
.5018 .59453 m .50186 .59396 L .50233 .59261 L F
.50186 .59396 m .50199 .59275 L .50233 .59261 L F
.909 .773 .699 r
.50478 .59124 m .50279 .59126 L .50459 .5896 L F
.50279 .59126 m .50295 .5908 L .50459 .5896 L F
.671 .467 .6 r
.50478 .59124 m .50552 .59471 L .5018 .59453 L F
.119 .372 .832 r
.20445 .68715 m .20647 .69044 L .20711 .68906 L F
0 0 .186 r
.20714 .69068 m .20647 .69044 L .20826 .68901 L F
.20841 .68908 m .20826 .68901 L .20881 .68857 L F
.20714 .69068 m .20826 .68901 L .20841 .68908 L F
.493 .08 .186 r
.21087 .68953 m .20714 .69068 L .20881 .68857 L F
.763 .675 .766 r
.20711 .68906 m .20714 .69068 L .21087 .68953 L F
.20921 .68946 m .21087 .68953 L .20931 .68947 L F
.20711 .68906 m .20883 .68928 L .20921 .68946 L F
.20883 .68928 m .21087 .68953 L .20921 .68946 L F
0 0 .186 r
.20647 .69044 m .20714 .69068 L .20711 .68906 L F
.20647 .69044 m .20614 .69286 L .20714 .69068 L F
.20714 .69068 m .20614 .69286 L .20647 .69044 L F
.608 .408 .586 r
.57919 .54988 m .57682 .5528 L .57673 .55024 L F
.582 .826 .991 r
.42282 .58143 m .4224 .58348 L .42477 .58278 L F
.376 0 .018 r
.42085 .58465 m .4224 .58348 L .42282 .58143 L F
.42085 .58465 m .42477 .58278 L .4224 .58348 L F
.611 .535 .744 r
.60494 .45433 m .60157 .45139 L .60415 .45059 L F
.178 0 0 r
.48576 .56282 m .48908 .56227 L .48638 .56275 L F
.48741 .56255 m .48853 .56272 L .48908 .56227 L F
.246 .224 .635 r
.48908 .56227 m .49102 .56444 L .48959 .5646 L F
0 0 .527 r
.49017 .56328 m .48908 .56227 L .48853 .56272 L F
0 .326 .737 r
.48724 .56159 m .48945 .56287 L .48853 .56272 L F
.48945 .56287 m .49017 .56328 L .48853 .56272 L F
.178 0 0 r
.48576 .56282 m .48853 .56272 L .48741 .56255 L F
0 0 .527 r
.49017 .56328 m .49102 .56444 L .48908 .56227 L F
.647 .723 .904 r
.19861 .687 m .20013 .68854 L .20249 .68792 L F
0 0 0 r
.20475 .55401 m .20488 .55387 L .20671 .55269 L F
.751 .729 .203 r
.59094 .5025 m .59052 .50398 L .59125 .50044 L F
.541 .761 .978 r
.73047 .39976 m .73188 .39798 L .72875 .39827 L F
.73047 .39976 m .73324 .39938 L .73188 .39798 L F
.934 .797 .686 r
.62307 .45631 m .62446 .45759 L .62359 .45417 L F
.887 .801 .759 r
.62096 .45953 m .62446 .45759 L .62307 .45631 L F
.62096 .45953 m .62265 .46083 L .62446 .45759 L F
.342 .093 .383 r
.24034 .63607 m .2378 .63907 L .23822 .63665 L F
.43 .148 .382 r
.57426 .53082 m .57208 .52951 L .57183 .53162 L F
.57426 .53082 m .5744 .5289 L .57208 .52951 L F
.241 .037 .39 r
.56379 .59913 m .56228 .5981 L .5646 .59757 L F
.56379 .59913 m .56209 .6005 L .56228 .5981 L F
.48 .226 .452 r
.56228 .5981 m .56209 .6005 L .55952 .60096 L F
.984 .752 .506 r
.48682 .59487 m .48746 .59816 L .48603 .59651 L F
.48705 .59481 m .48746 .59816 L .48682 .59487 L F
.48701 .59447 m .48705 .59481 L .48682 .59487 L F
.652 .524 .695 r
.49067 .59708 m .48701 .59447 L .48966 .59467 L F
.49067 .59708 m .48746 .59816 L .48701 .59447 L F
.538 .388 .625 r
.48603 .59651 m .48966 .59467 L .48701 .59447 L F
.669 .579 .745 r
.48657 .59172 m .48701 .59447 L .48898 .594 L F
.63 .438 .604 r
.48898 .594 m .48966 .59467 L .48701 .59447 L F
.538 .388 .625 r
.48849 .59526 m .48829 .5937 L .48966 .59467 L F
.547 .33 .537 r
.48657 .59172 m .48772 .59474 L .48559 .59492 L F
.538 .388 .625 r
.4874 .59531 m .48829 .5937 L .48849 .59526 L F
.316 .209 .571 r
.48827 .59367 m .48772 .59474 L .48657 .59172 L F
.48829 .5937 m .48823 .59381 L .48827 .59367 L F
.48823 .59381 m .48772 .59474 L .48827 .59367 L F
.625 .095 0 r
.48829 .5937 m .48898 .594 L .48657 .59172 L F
.984 .894 .647 r
.48732 .59288 m .48867 .59201 L .48863 .58948 L F
.48867 .59201 m .48933 .59159 L .48901 .59063 L F
.48867 .59201 m .48901 .59063 L .48863 .58948 L F
.547 .33 .537 r
.48772 .59474 m .48711 .59533 L .48559 .59492 L F
.538 .388 .625 r
.48698 .59533 m .48829 .5937 L .4874 .59531 L F
.316 .209 .571 r
.48829 .5937 m .48804 .59558 L .48772 .59474 L F
.547 .33 .537 r
.48772 .59474 m .48804 .59558 L .48711 .59533 L F
.538 .388 .625 r
.48603 .59651 m .48655 .59586 L .48849 .59526 L F
.48655 .59586 m .48698 .59533 L .48711 .59533 L F
.48655 .59586 m .48711 .59533 L .48849 .59526 L F
.48603 .59651 m .48825 .59596 L .48826 .59567 L F
.48698 .59533 m .48788 .59557 L .48829 .5937 L F
.48603 .59651 m .48826 .59567 L .48698 .59533 L F
0 0 0 r
.48697 .59533 m .48609 .59505 L .48711 .59533 L F
.48464 .59542 m .486 .59508 L .48697 .59533 L F
.486 .59508 m .48609 .59505 L .48697 .59533 L F
.48489 .59543 m .48711 .59533 L .48804 .59558 L F
.48464 .59542 m .48711 .59533 L .48489 .59543 L F
.48458 .59545 m .48464 .59542 L .48804 .59558 L F
.48464 .59542 m .48559 .59492 L .48609 .59505 L F
.831 .678 .693 r
.48458 .59545 m .48788 .59557 L .48829 .5937 L F
.48788 .59557 m .48804 .59558 L .48829 .5937 L F
.538 .388 .625 r
.48788 .59557 m .48826 .59567 L .48829 .5937 L F
.533 .285 .485 r
.23629 .60094 m .23805 .6028 L .23838 .59899 L F
.23629 .60094 m .2361 .60317 L .23805 .6028 L F
.713 .799 .918 r
.74212 .38519 m .73978 .38665 L .73872 .385 L F
.481 .451 .748 r
.46138 .57715 m .46533 .57981 L .46335 .57653 L F
.488 .499 .795 r
.75417 .38558 m .75202 .38613 L .75092 .3826 L F
.505 .583 .867 r
.75589 .38891 m .75202 .38613 L .75417 .38558 L F
.861 .713 .697 r
.61205 .44538 m .61061 .44175 L .61228 .44294 L F
.806 .792 .839 r
.69148 .4369 m .68786 .43712 L .69031 .43508 L F
.832 .798 .819 r
.69394 .43378 m .69148 .4369 L .69031 .43508 L F
.791 .699 .762 r
.43351 .59192 m .42971 .59148 L .43233 .58872 L F
.644 .828 .971 r
.43351 .59192 m .43057 .59223 L .42971 .59148 L F
0 0 .218 r
.60732 .42643 m .60758 .42651 L .60748 .42434 L F
.395 .293 .619 r
.60748 .42434 m .60998 .42344 L .60956 .421 L F
.382 .159 .446 r
.60758 .42651 m .60998 .42344 L .60748 .42434 L F
.545 .722 .956 r
.66918 .40669 m .67268 .408 L .67118 .40647 L F
.493 .737 .981 r
.67118 .40647 m .67268 .408 L .67503 .40762 L F
.45 .347 .646 r
.43952 .56444 m .4411 .5615 L .43964 .56206 L F
.37 0 .08 r
.16497 .54962 m .16734 .54939 L .16903 .54726 L F
.068 0 0 r
.16903 .54726 m .16927 .54853 L .17129 .54684 L F
.16903 .54726 m .16734 .54939 L .16927 .54853 L F
.468 .21 .439 r
.69737 .39677 m .695 .39552 L .69473 .39717 L F
.69737 .39677 m .69748 .39477 L .695 .39552 L F
.419 0 0 r
.68877 .39926 m .68613 .39851 L .68511 .39983 L F
.913 .88 .788 r
.76819 .43369 m .765 .43562 L .76718 .43242 L F
.76819 .43369 m .76634 .43654 L .765 .43562 L F
.738 .484 .546 r
.43489 .65483 m .43414 .65719 L .43185 .65446 L F
.508 .25 .459 r
.43728 .65657 m .43489 .65483 L .43795 .65453 L F
.43728 .65657 m .43414 .65719 L .43489 .65483 L F
.64 .342 .45 r
.44122 .65477 m .44028 .65674 L .43795 .65453 L F
0 0 .012 r
.43782 .65614 m .43795 .65453 L .43802 .65414 L F
.43782 .65614 m .43728 .65657 L .43795 .65453 L F
.64 .342 .45 r
.44122 .65477 m .44028 .65674 L .43795 .65453 L F
.985 .724 .446 r
.54353 .60089 m .54439 .60276 L .54313 .603 L F
.75 .7 .804 r
.54353 .60089 m .54733 .60114 L .54439 .60276 L F
.981 .911 .611 r
.20018 .70526 m .19832 .70756 L .19913 .70755 L F
0 0 0 r
.20018 .70526 m .20225 .70141 L .20101 .70409 L F
.593 .838 .469 r
.20101 .70409 m .19832 .70756 L .20018 .70526 L F
.372 .508 .865 r
.7575 .38705 m .75589 .38891 L .75417 .38558 L F
.193 .237 .68 r
.75811 .39077 m .75589 .38891 L .7575 .38705 L F
.287 .568 .934 r
.74174 .42697 m .7397 .42665 L .73833 .42465 L F
.552 .912 .96 r
.77872 .4287 m .77591 .43036 L .77948 .42657 L F
.77872 .4287 m .77948 .42657 L .77838 .42578 L F
.573 .615 .857 r
.77948 .42657 m .78091 .42327 L .77838 .42578 L F
.77948 .42657 m .78279 .42583 L .78091 .42327 L F
.28 0 .256 r
.27405 .58631 m .27322 .58822 L .27135 .58877 L F
.456 .344 .638 r
.27365 .59078 m .27135 .58877 L .27322 .58822 L F
.27365 .59078 m .27155 .59194 L .27135 .58877 L F
.143 .68 .844 r
.47418 .59208 m .47409 .5919 L .4701 .59195 L F
0 0 .048 r
.47561 .59067 m .47418 .59208 L .47622 .58894 L F
.607 .927 .699 r
.47561 .59067 m .47409 .5919 L .47418 .59208 L F
.393 .103 .349 r
.44186 .58882 m .44429 .5882 L .44451 .58615 L F
.441 .295 .586 r
.22667 .61295 m .22834 .61529 L .22814 .61198 L F
.855 .693 .681 r
.76881 .40627 m .77218 .41263 L .77051 .41193 L F
.955 .951 .694 r
.77218 .41263 m .77022 .41445 L .77051 .41193 L F
.77218 .41263 m .77057 .41584 L .77022 .41445 L F
.358 .012 .233 r
.39638 .59418 m .39841 .59365 L .39933 .59201 L F
.275 0 .184 r
.39841 .59365 m .40143 .59128 L .39933 .59201 L F
.305 .134 .478 r
.58227 .52035 m .58489 .51907 L .58484 .51671 L F
.207 0 .292 r
.58402 .52146 m .58227 .52035 L .58244 .52234 L F
.58402 .52146 m .58489 .51907 L .58227 .52035 L F
.486 0 0 r
.50018 .54575 m .49566 .54378 L .49749 .54429 L F
0 0 0 r
.5123 .58835 m .50956 .5921 L .51115 .58957 L F
.478 .269 .517 r
.54985 .59792 m .54965 .60053 L .54733 .60114 L F
.54733 .60114 m .54965 .60053 L .54985 .59792 L F
.483 .273 .518 r
.55207 .59985 m .54965 .60053 L .54985 .59792 L F
.554 .822 .996 r
.54965 .60053 m .55207 .59985 L .54985 .59792 L F
.529 .312 .529 r
.4338 .5803 m .43622 .57991 L .4365 .57671 L F
.516 .284 .502 r
.43622 .57991 m .43909 .57604 L .4365 .57671 L F
.363 .163 .47 r
.65602 .40121 m .65601 .40325 L .65816 .40012 L F
.766 .619 .696 r
.54581 .59738 m .54353 .60089 L .54349 .59791 L F
.507 .587 .87 r
.54179 .58195 m .53868 .58272 L .53797 .57915 L F
.416 .268 .571 r
.41813 .62388 m .41613 .6272 L .41574 .6246 L F
0 0 .29 r
.76881 .40627 m .76874 .40605 L .77007 .40704 L F
.667 .583 .751 r
.70509 .44262 m .70634 .44641 L .70878 .44553 L F
.532 .911 .943 r
.15989 .56973 m .15782 .57061 L .15832 .56958 L F
.281 0 .147 r
.16111 .568 m .15989 .56973 L .15832 .56958 L F
.766 .619 .696 r
.54581 .59738 m .54733 .60114 L .54353 .60089 L F
.465 .199 .426 r
.27611 .58549 m .27322 .58822 L .27405 .58631 L F
.415 .275 .58 r
.5657 .56153 m .56384 .56473 L .56356 .56218 L F
.755 .496 .542 r
.43185 .65446 m .42841 .65635 L .42854 .65519 L F
.659 .427 .556 r
.58212 .47521 m .58243 .47816 L .57883 .47766 L F
.614 .394 .559 r
.58449 .47497 m .58243 .47816 L .58212 .47521 L F
.399 .071 .29 r
.70248 .40163 m .70471 .40247 L .70216 .40304 L F
.70248 .40163 m .70506 .40089 L .70471 .40247 L F
.358 .804 .66 r
.52531 .51459 m .5216 .51647 L .52302 .51504 L F
.529 .922 .852 r
.52302 .51504 m .52664 .5134 L .52531 .51459 L F
0 0 0 r
.52621 .51376 m .52664 .5134 L .52499 .51414 L F
.474 .82 .536 r
.52531 .51459 m .52664 .5134 L .52692 .51317 L F
0 0 0 r
.52731 .51342 m .52664 .5134 L .52621 .51376 L F
.474 .82 .536 r
.52692 .51317 m .52664 .5134 L .52709 .51301 L F
.654 .967 .811 r
.40969 .63201 m .40806 .63375 L .41126 .63154 L F
.878 .993 .777 r
.41161 .62923 m .41126 .63154 L .41312 .63061 L F
.979 .913 .607 r
.65121 .42203 m .65155 .4175 L .65134 .4196 L F
.91 .858 .414 r
.65134 .4196 m .65074 .42402 L .65121 .42203 L F
.724 .397 .426 r
.43544 .64583 m .43841 .6465 L .43674 .64573 L F
.43544 .64583 m .43528 .64782 L .43841 .6465 L F
.849 .68 .672 r
.43528 .64782 m .437 .65104 L .43841 .6465 L F
.269 0 .036 r
.61101 .43657 m .60723 .43924 L .6082 .43733 L F
.93 .85 .742 r
.6755 .45113 m .67359 .45505 L .67235 .45337 L F
.6755 .45113 m .67235 .45337 L .67608 .45411 L F
.6755 .45113 m .67608 .45411 L .6747 .4503 L F
.895 .981 .807 r
.65965 .43338 m .66122 .4297 L .65853 .43249 L F
.539 .582 .846 r
.74708 .39217 m .7509 .39523 L .74986 .39171 L F
.548 .525 .781 r
.7509 .39523 m .75229 .39086 L .74986 .39171 L F
.7509 .39523 m .75421 .39547 L .75229 .39086 L F
.671 .898 .977 r
.43187 .63421 m .43008 .6345 L .43274 .63356 L F
.653 .401 .525 r
.43592 .63598 m .43249 .63823 L .43187 .63421 L F
.462 .27 .534 r
.56851 .55615 m .57089 .55304 L .57094 .55561 L F
.491 .29 .535 r
.56855 .55858 m .56851 .55615 L .57094 .55561 L F
.751 .595 .683 r
.59659 .47506 m .59293 .47223 L .59662 .47268 L F
.487 .798 .999 r
.71675 .3973 m .72032 .3979 L .71935 .397 L F
.61 .76 .951 r
.72032 .3979 m .72152 .39564 L .71935 .397 L F
.72032 .3979 m .72284 .39714 L .72152 .39564 L F
.894 .755 .7 r
.43485 .55925 m .43379 .56338 L .43129 .56082 L F
.43485 .55925 m .43129 .56082 L .43301 .56079 L F
.174 0 0 r
.43485 .55925 m .4377 .56095 L .43742 .55898 L F
.43485 .55925 m .43608 .56022 L .4377 .56095 L F
.43485 .55925 m .43301 .56079 L .43608 .56022 L F
.767 .613 .688 r
.48429 .57082 m .4857 .57431 L .48228 .57388 L F
.583 .42 .626 r
.4857 .57431 m .48665 .57677 L .48777 .57441 L F
.682 .94 .964 r
.40808 .62603 m .40708 .62771 L .40984 .62651 L F
.612 .394 .561 r
.40708 .62771 m .41036 .62782 L .40984 .62651 L F
.593 .298 .438 r
.40708 .62771 m .4093 .62973 L .41036 .62782 L F
.171 .28 .734 r
.40808 .62603 m .4093 .62973 L .40708 .62771 L F
.173 .016 .413 r
.5864 .54032 m .58595 .53821 L .588 .53701 L F
.544 .221 .371 r
.60956 .421 m .61249 .42078 L .61289 .41841 L F
.443 .265 .543 r
.61289 .41841 m .61484 .41764 L .61503 .41572 L F
.491 .226 .44 r
.61249 .42078 m .61484 .41764 L .61289 .41841 L F
0 .116 .668 r
.50206 .549 m .50018 .54575 L .50153 .54697 L F
.474 .274 .528 r
.23141 .6067 m .23344 .60828 L .23279 .60545 L F
.23141 .6067 m .23124 .60894 L .23344 .60828 L F
.453 .073 .227 r
.38457 .60011 m .38822 .59769 L .38462 .59763 L F
.38457 .60011 m .38699 .59975 L .38822 .59769 L F
.484 .063 .166 r
.38699 .59975 m .39084 .59782 L .38822 .59769 L F
.989 .812 .425 r
.76328 .4169 m .76428 .41583 L .76373 .41473 L F
.76328 .4169 m .76399 .41796 L .76428 .41583 L F
.98 .873 .502 r
.76427 .41227 m .76428 .41583 L .76699 .41286 L F
.76427 .41227 m .76373 .41473 L .76428 .41583 L F
.266 .479 .879 r
.48991 .57554 m .49051 .57439 L .48777 .57441 L F
.48991 .57554 m .49176 .57665 L .49051 .57439 L F
.439 .29 .581 r
.38254 .60052 m .38457 .60011 L .38462 .59763 L F
.479 .368 .65 r
.38289 .60333 m .38457 .60011 L .38254 .60052 L F
.586 .9 .634 r
.53871 .51977 m .53721 .52081 L .53547 .52249 L F
.632 .934 .69 r
.53871 .51977 m .54142 .5173 L .53964 .51844 L F
.628 .918 .643 r
.53871 .51977 m .53964 .51844 L .53721 .52081 L F
.784 .603 .656 r
.54585 .54358 m .54614 .54107 L .54288 .54116 L F
.291 .786 .759 r
.71784 .38848 m .71535 .3893 L .71404 .38949 L F
.348 .156 .472 r
.5646 .59757 m .56481 .5949 L .56675 .59417 L F
.975 .675 .305 r
.62577 .4177 m .62728 .41908 L .62719 .41694 L F
.163 .703 .787 r
.62434 .42018 m .62548 .41975 L .62577 .4177 L F
.62548 .41975 m .62728 .41908 L .62668 .41853 L F
.62548 .41975 m .62668 .41853 L .62577 .4177 L F
0 0 0 r
.62939 .41585 m .62719 .41694 L .63047 .41615 L F
.62939 .41585 m .62657 .41916 L .62677 .41844 L F
.62927 .41591 m .62677 .41844 L .62719 .41694 L F
.62939 .41585 m .62677 .41844 L .62927 .41591 L F
.975 .675 .305 r
.62577 .4177 m .62719 .41694 L .62657 .41916 L F
.741 .679 .79 r
.71127 .44255 m .71499 .44317 L .71387 .43967 L F
.765 .692 .781 r
.71387 .43967 m .71499 .44317 L .71755 .44018 L F
.206 0 .161 r
.56907 .47268 m .56825 .47443 L .57111 .47184 L F
.639 .766 .94 r
.72751 .3884 m .72394 .38769 L .72646 .38686 L F
.625 .766 .947 r
.72999 .38752 m .72751 .3884 L .72646 .38686 L F
.103 .606 .898 r
.27429 .55117 m .27808 .5522 L .27603 .55258 L F
.633 .472 .647 r
.55734 .54726 m .55997 .54688 L .55976 .54414 L F
.557 .368 .581 r
.55997 .54688 m .56237 .544 L .55976 .54414 L F
.874 .917 .854 r
.59799 .47857 m .59566 .48163 L .59466 .48038 L F
.68 .581 .737 r
.59799 .47857 m .59817 .48161 L .59566 .48163 L F
.845 .612 .586 r
.59817 .48161 m .59761 .4833 L .59566 .48163 L F
.888 .627 .537 r
.59761 .4833 m .59466 .48038 L .59566 .48163 L F
0 .155 .674 r
.20801 .66361 m .20878 .66485 L .20768 .66326 L F
.851 .94 .88 r
.51389 .52211 m .51112 .523 L .51267 .5212 L F
.776 .884 .924 r
.51541 .51893 m .51389 .52211 L .51267 .5212 L F
.51541 .51893 m .51676 .52002 L .51389 .52211 L F
.598 .111 .069 r
.53883 .60673 m .54244 .60686 L .54204 .60602 L F
.99 .751 .374 r
.54244 .60686 m .54251 .60962 L .54137 .60804 L F
.424 .284 .586 r
.54453 .60862 m .54251 .60962 L .54244 .60686 L F
.669 .159 .022 r
.54137 .60804 m .54453 .60862 L .54244 .60686 L F
.54137 .60804 m .54244 .60686 L .54204 .60602 L F
.54137 .60804 m .54453 .60862 L .54244 .60686 L F
.801 .512 .498 r
.55535 .58553 m .55583 .58315 L .55179 .58234 L F
.386 .124 .39 r
.55535 .58553 m .55817 .58239 L .55583 .58315 L F
.978 .681 .363 r
.48746 .59816 m .48702 .60023 L .48603 .59651 L F
.572 .21 .316 r
.49012 .59963 m .48746 .59816 L .49067 .59708 L F
.49012 .59963 m .48702 .60023 L .48746 .59816 L F
.375 .182 .487 r
.24931 .57401 m .25143 .57327 L .25164 .57084 L F
.347 .236 .582 r
.24931 .57401 m .25128 .57584 L .25143 .57327 L F
.24931 .57401 m .24913 .57713 L .25128 .57584 L F
.692 .518 .647 r
.55485 .55017 m .55749 .5499 L .55734 .54726 L F
.633 .473 .648 r
.55734 .54726 m .55749 .5499 L .55997 .54688 L F
.186 0 0 r
.42082 .6338 m .41674 .63314 L .41825 .63477 L F
.438 .217 .478 r
.42825 .63971 m .42803 .6422 L .42585 .64274 L F
.469 .242 .486 r
.43067 .63933 m .42803 .6422 L .42825 .63971 L F
.734 .824 .921 r
.21895 .65977 m .21609 .66124 L .21425 .66004 L F
.499 .392 .663 r
.2179 .66377 m .21609 .66124 L .21895 .65977 L F
.319 .292 .671 r
.20874 .68728 m .21087 .68953 L .20881 .68857 L F
.251 0 .272 r
.57167 .47001 m .57111 .47184 L .57367 .46902 L F
.564 .686 .922 r
.18849 .6369 m .18469 .63557 L .18724 .63476 L F
.562 .65 .894 r
.19064 .63642 m .18849 .6369 L .18724 .63476 L F
.589 .663 .89 r
.38329 .62176 m .38766 .62428 L .38554 .62166 L F
.378 0 0 r
.38995 .62384 m .38554 .62166 L .38766 .62428 L F
.945 .938 .599 r
.65338 .40873 m .65209 .41206 L .65247 .41303 L F
.998 .781 .454 r
.65119 .41412 m .65247 .41303 L .65209 .41206 L F
.65119 .41412 m .65221 .41535 L .65247 .41303 L F
.489 .197 .396 r
.43288 .64819 m .43528 .64782 L .43544 .64583 L F
.87 .485 .309 r
.61228 .43781 m .61009 .43848 L .61101 .43657 L F
.974 .873 .673 r
.61228 .43781 m .61061 .44175 L .61009 .43848 L F
.882 .889 .832 r
.47638 .60383 m .47257 .60599 L .47568 .60391 L F
.604 .943 .772 r
.47638 .60383 m .47568 .60391 L .4772 .60267 L F
.527 .36 .598 r
.47881 .60324 m .4766 .60676 L .47638 .60383 L F
.798 .736 .795 r
.46992 .57668 m .47356 .57701 L .47204 .57363 L F
.241 .301 .725 r
.47356 .57701 m .47424 .57328 L .47204 .57363 L F
.47356 .57701 m .47479 .57611 L .47424 .57328 L F
.317 .446 .834 r
.47356 .57701 m .47571 .57722 L .47479 .57611 L F
.624 .692 .892 r
.74337 .39125 m .74708 .39217 L .74592 .3888 L F
.656 .637 .819 r
.74708 .39217 m .74849 .38798 L .74592 .3888 L F
.74708 .39217 m .74986 .39171 L .74849 .38798 L F
.613 .151 .131 r
.46612 .571 m .46471 .57254 L .46221 .57093 L F
.33 0 0 r
.46737 .57198 m .46612 .571 L .46897 .57053 L F
.46737 .57198 m .46471 .57254 L .46612 .571 L F
.374 .819 .686 r
.19022 .65604 m .18997 .65626 L .1905 .65624 L F
.491 0 0 r
.18982 .6565 m .1905 .65624 L .19091 .65711 L F
.18612 .65444 m .1905 .65624 L .18982 .6565 L F
0 0 0 r
.1905 .65624 m .18997 .65626 L .19178 .65576 L F
.1905 .65624 m .19178 .65576 L .19326 .65535 L F
.356 0 0 r
.54349 .55476 m .54355 .55411 L .54181 .55383 L F
0 .426 .844 r
.54649 .55578 m .54568 .55483 L .54355 .55411 L F
.356 0 0 r
.54349 .55476 m .54568 .55483 L .54355 .55411 L F
.412 .821 .977 r
.20012 .63789 m .19855 .63824 L .19631 .63786 L F
.563 .313 .495 r
.44392 .65441 m .44644 .65413 L .44759 .65197 L F
.785 .717 .788 r
.71823 .43571 m .72197 .43589 L .72097 .43278 L F
.71823 .43571 m .72005 .43722 L .72197 .43589 L F
.719 .724 .854 r
.72097 .43278 m .72197 .43589 L .7246 .43341 L F
.832 .798 .819 r
.69394 .43378 m .69031 .43508 L .69298 .43275 L F
.847 .863 .854 r
.6973 .42874 m .69502 .4326 L .69455 .42887 L F
.831 .735 .758 r
.69298 .43275 m .69576 .43283 L .69394 .43378 L F
.69576 .43283 m .69597 .43283 L .69589 .43287 L F
.69298 .43275 m .69453 .43342 L .69597 .43283 L F
.847 .863 .854 r
.69502 .4326 m .69453 .43342 L .69454 .43246 L F
.69502 .4326 m .69454 .43246 L .69455 .42887 L F
.831 .735 .758 r
.69576 .43283 m .69589 .43287 L .69394 .43378 L F
.607 .927 .699 r
.47561 .59067 m .47555 .59069 L .47409 .5919 L F
.613 .934 .713 r
.47409 .5919 m .47555 .59069 L .47145 .5878 L F
.707 .954 .68 r
.47568 .59055 m .47555 .59069 L .47561 .59067 L F
.613 .934 .713 r
.47555 .59069 m .47563 .59062 L .47562 .59061 L F
.47555 .59069 m .47562 .59061 L .47145 .5878 L F
0 0 0 r
.47629 .58915 m .47561 .59067 L .47622 .58894 L F
.47568 .59055 m .47561 .59067 L .47629 .58915 L F
.613 .934 .713 r
.47564 .59063 m .47621 .58935 L .47145 .5878 L F
.47564 .59063 m .47693 .58958 L .47621 .58935 L F
0 0 0 r
.47637 .58938 m .47568 .59055 L .47629 .58915 L F
.707 .954 .68 r
.47637 .58938 m .47514 .59082 L .47555 .59069 L F
.47637 .58938 m .47555 .59069 L .47568 .59055 L F
.607 .927 .699 r
.47555 .59069 m .47514 .59082 L .47409 .5919 L F
.613 .934 .713 r
.47409 .5919 m .47564 .59063 L .47563 .59062 L F
0 .057 .617 r
.65438 .42994 m .65539 .43195 L .65612 .43276 L F
0 0 0 r
.75733 .39979 m .75641 .40392 L .75589 .40296 L F
.958 .644 .388 r
.75641 .40392 m .75509 .40532 L .75589 .40296 L F
.75641 .40392 m .75686 .40675 L .75509 .40532 L F
.426 .186 .445 r
.42803 .6422 m .42523 .64486 L .42585 .64274 L F
.875 .923 .854 r
.19328 .72777 m .19305 .72905 L .19255 .72833 L F
.19361 .72599 m .194 .72699 L .19305 .72905 L F
0 0 0 r
.194 .72699 m .19174 .72985 L .19305 .72905 L F
.19379 .72738 m .19142 .73185 L .19353 .72758 L F
.224 .671 .953 r
.19172 .73248 m .19012 .73288 L .19134 .73191 L F
0 0 0 r
.19142 .73185 m .19122 .73222 L .1914 .73187 L F
.19142 .73185 m .1914 .73187 L .19353 .72758 L F
.224 .671 .953 r
.19172 .73248 m .19009 .7331 L .19012 .73288 L F
.19134 .73191 m .19012 .73288 L .19046 .73057 L F
.323 0 .193 r
.19597 .72748 m .19145 .732 L .194 .72699 L F
.19145 .732 m .19122 .73222 L .19138 .73193 L F
.19145 .732 m .19138 .73193 L .194 .72699 L F
0 0 0 r
.19353 .72758 m .19137 .73192 L .19174 .72985 L F
.19137 .73192 m .19129 .73189 L .19174 .72985 L F
.52 .307 .531 r
.18955 .73285 m .19112 .73259 L .19063 .73015 L F
.224 .671 .953 r
.19138 .73193 m .19132 .73184 L .19142 .73192 L F
.83 .658 .669 r
.19137 .73173 m .19145 .732 L .19597 .72748 L F
.224 .671 .953 r
.19143 .73194 m .19142 .73192 L .19148 .73196 L F
.19138 .73193 m .19142 .73192 L .19143 .73194 L F
.875 .923 .854 r
.19361 .72599 m .19328 .72777 L .19195 .72746 L F
.19328 .72777 m .19255 .72833 L .19195 .72746 L F
.83 .658 .669 r
.19261 .72766 m .19137 .73173 L .19597 .72748 L F
.224 .671 .953 r
.19132 .73184 m .19135 .73178 L .19148 .73196 L F
0 0 0 r
.19137 .73192 m .19122 .73222 L .19129 .73189 L F
.83 .658 .669 r
.19138 .73176 m .19122 .73222 L .19145 .732 L F
.224 .671 .953 r
.19172 .73248 m .19134 .73191 L .19148 .73196 L F
.52 .307 .531 r
.19112 .73259 m .19172 .73248 L .19138 .73176 L F
.19131 .73194 m .19138 .73176 L .19137 .73174 L F
.224 .671 .953 r
.19134 .73191 m .19128 .73181 L .19138 .73193 L F
.83 .658 .669 r
.19131 .73194 m .19122 .73222 L .19138 .73176 L F
.52 .307 .531 r
.19112 .73259 m .19138 .73176 L .19131 .73194 L F
.83 .658 .669 r
.19137 .73173 m .19131 .73194 L .19138 .73176 L F
0 0 0 r
.19129 .73189 m .19122 .73222 L .19137 .73173 L F
.224 .671 .953 r
.19132 .73184 m .19046 .73057 L .19135 .73178 L F
.19128 .73181 m .19046 .73057 L .19138 .73193 L F
.19148 .73196 m .19046 .73057 L .19063 .73015 L F
.52 .307 .531 r
.19112 .73259 m .19137 .73174 L .19063 .73015 L F
0 0 0 r
.19174 .72985 m .19129 .73189 L .19196 .72976 L F
.1925 .72794 m .19196 .72976 L .19261 .72766 L F
.19174 .72985 m .19196 .72976 L .1925 .72794 L F
.19129 .73189 m .19137 .73173 L .19261 .72766 L F
.194 .72699 m .19379 .72738 L .19353 .72758 L F
.856 .96 .873 r
.54649 .55578 m .54568 .55483 L .5428 .55766 L F
.744 .782 .884 r
.54649 .55578 m .54774 .55199 L .54544 .55264 L F
.54649 .55578 m .54956 .55407 L .54774 .55199 L F
0 0 .205 r
.656 .40689 m .65623 .40577 L .65601 .40325 L F
.966 .806 .376 r
.656 .40689 m .6552 .40759 L .65623 .40577 L F
.656 .40689 m .65577 .40889 L .6552 .40759 L F
.972 .906 .688 r
.65623 .40577 m .6552 .40759 L .65451 .40637 L F
0 .342 .821 r
.6552 .40759 m .65692 .40782 L .65472 .4065 L F
.6552 .40759 m .65472 .4065 L .65451 .40637 L F
.966 .806 .376 r
.65577 .40889 m .65564 .41001 L .6552 .40759 L F
.516 .244 .441 r
.46576 .61299 m .46305 .61549 L .46552 .61506 L F
.46576 .61299 m .46305 .61549 L .46552 .61506 L F
.488 .24 .465 r
.46834 .61231 m .46552 .61506 L .46576 .61299 L F
.46834 .61231 m .46552 .61506 L .46576 .61299 L F
.378 .169 .464 r
.26002 .60964 m .25967 .61218 L .25771 .61278 L F
.423 .285 .587 r
.2597 .61472 m .25771 .61278 L .25967 .61218 L F
.2597 .61472 m .25781 .61545 L .25771 .61278 L F
.327 .261 .629 r
.24092 .59161 m .24074 .59464 L .24278 .59325 L F
.324 .09 .397 r
.24074 .59464 m .24259 .59673 L .24278 .59325 L F
.24074 .59464 m .24087 .59784 L .24259 .59673 L F
.319 .807 .842 r
.19056 .71597 m .18745 .71625 L .18778 .71589 L F
.19056 .71597 m .19081 .71543 L .18745 .71625 L F
.78 .717 .793 r
.21219 .55302 m .21432 .55614 L .21708 .55359 L F
.275 .572 .938 r
.50115 .57019 m .50028 .57166 L .49906 .57004 L F
.50115 .57019 m .50355 .57269 L .50028 .57166 L F
.651 .147 .036 r
.1736 .54348 m .17506 .54519 L .17752 .54424 L F
.318 0 0 r
.17506 .54519 m .17969 .54376 L .17752 .54424 L F
.659 .908 .979 r
.68164 .40714 m .68527 .40654 L .6836 .40682 L F
.528 .12 .211 r
.68527 .40654 m .68442 .40738 L .6836 .40682 L F
.68527 .40654 m .68754 .40792 L .68442 .40738 L F
.68527 .40654 m .68749 .40672 L .68754 .40792 L F
0 0 .197 r
.51484 .593 m .51431 .59459 L .51423 .59171 L F
.51484 .593 m .51423 .59171 L .51302 .59062 L F
.912 .809 .732 r
.62739 .44239 m .6265 .44534 L .62809 .44575 L F
.993 .754 .396 r
.62702 .44693 m .62809 .44575 L .6265 .44534 L F
.62702 .44693 m .62801 .44814 L .62809 .44575 L F
0 0 .498 r
.50882 .58295 m .50974 .58372 L .50977 .58163 L F
.238 .348 .774 r
.50699 .57822 m .50917 .58257 L .50716 .58003 L F
.50917 .58257 m .50974 .58372 L .50906 .58274 L F
0 0 0 r
.50941 .58219 m .50906 .58274 L .50882 .58295 L F
.458 .471 .785 r
.50977 .58163 m .50974 .58372 L .50917 .58257 L F
0 0 0 r
.50952 .58205 m .50917 .58257 L .50941 .58219 L F
.50917 .58257 m .50906 .58274 L .50941 .58219 L F
.50977 .58163 m .50952 .58205 L .50882 .58295 L F
.458 .471 .785 r
.50977 .58163 m .50917 .58257 L .50699 .57822 L F
.238 .348 .774 r
.50917 .58257 m .50906 .58274 L .50716 .58003 L F
0 0 0 r
.50952 .58205 m .50918 .58262 L .50906 .58274 L F
.50918 .58262 m .50802 .58456 L .50882 .58295 L F
0 .02 .586 r
.50716 .58003 m .50906 .58274 L .50882 .58295 L F
.50906 .58274 m .50974 .58372 L .50882 .58295 L F
.409 .86 .823 r
.16717 .56356 m .16525 .5644 L .16599 .56433 L F
.565 .869 .995 r
.2226 .55344 m .22137 .55324 L .22227 .55349 L F
.324 .087 .391 r
.4556 .61211 m .4532 .61514 L .45366 .61297 L F
.45366 .61297 m .4532 .61514 L .4556 .61211 L F
.638 .7 .891 r
.73429 .43364 m .73568 .43027 L .73307 .43081 L F
.73429 .43364 m .73677 .43269 L .73568 .43027 L F
.873 .912 .853 r
.59522 .49119 m .59306 .49367 L .59268 .4911 L F
.98 .799 .588 r
.59306 .49367 m .5911 .49489 L .59268 .4911 L F
.59306 .49367 m .59251 .49606 L .5911 .49489 L F
.585 .577 .811 r
.63645 .41978 m .63576 .42135 L .63424 .42064 L F
.457 0 0 r
.63266 .41994 m .63645 .41978 L .63368 .42085 L F
0 .435 .794 r
.63588 .4214 m .63517 .4207 L .63337 .41995 L F
.63593 .42143 m .63592 .42142 L .63588 .4214 L F
.63592 .42142 m .63517 .4207 L .63588 .4214 L F
.585 .577 .811 r
.63645 .41978 m .63598 .4214 L .63576 .42135 L F
.63424 .42064 m .63576 .42135 L .63368 .42085 L F
.87 .991 .82 r
.63588 .4214 m .63566 .42141 L .63593 .42143 L F
.911 .555 .1 r
.63368 .42085 m .63398 .42146 L .63484 .42214 L F
.63398 .42146 m .63491 .42245 L .63484 .42214 L F
.87 .991 .82 r
.63377 .42125 m .6346 .42213 L .63593 .42143 L F
.911 .555 .1 r
.6346 .42213 m .63523 .42402 L .63491 .42245 L F
.518 .339 .577 r
.63413 .42238 m .63523 .42402 L .6346 .42213 L F
.911 .555 .1 r
.63398 .42146 m .63523 .42402 L .6346 .42213 L F
.46 .193 .422 r
.63523 .42402 m .63825 .42131 L .63484 .42214 L F
.518 .339 .577 r
.6346 .42213 m .63523 .42402 L .63593 .42143 L F
.585 .577 .811 r
.63598 .4214 m .63523 .42402 L .63398 .42146 L F
.63598 .4214 m .63398 .42146 L .63368 .42085 L F
.87 .991 .82 r
.63337 .41995 m .63377 .42125 L .63566 .42141 L F
.63337 .41995 m .63566 .42141 L .63588 .4214 L F
.63377 .42125 m .63413 .42238 L .6346 .42213 L F
.534 .389 .63 r
.56384 .56473 m .56412 .56722 L .56161 .56774 L F
.534 .422 .672 r
.56388 .56798 m .56161 .56774 L .56412 .56722 L F
.56388 .56798 m .56199 .57133 L .56161 .56774 L F
.773 .995 .87 r
.77367 .43379 m .77201 .43625 L .77494 .43401 L F
.77367 .43379 m .7715 .43571 L .77201 .43625 L F
.532 .263 .452 r
.5744 .5289 m .57691 .52846 L .5773 .52593 L F
.623 .424 .592 r
.57691 .52846 m .57979 .52553 L .5773 .52593 L F
.269 0 .036 r
.61101 .43657 m .61009 .43848 L .60723 .43924 L F
.562 .349 .548 r
.39084 .59782 m .39327 .59762 L .39351 .59465 L F
.468 .27 .527 r
.39351 .59465 m .3956 .59686 L .39638 .59418 L F
.39351 .59465 m .39327 .59762 L .3956 .59686 L F
.897 .666 .582 r
.74687 .42071 m .74538 .42151 L .74601 .42105 L F
.057 .305 .791 r
.74658 .41856 m .74777 .42034 L .74687 .42071 L F
.18 .051 .456 r
.74868 .41722 m .74658 .41856 L .74687 .42071 L F
.74868 .41722 m .74687 .42071 L .74829 .4194 L F
.897 .666 .582 r
.74687 .42071 m .74601 .42105 L .74829 .4194 L F
.057 .305 .791 r
.74777 .42034 m .74861 .4216 L .74687 .42071 L F
.976 .923 .635 r
.74861 .4216 m .74694 .42331 L .74687 .42071 L F
.74861 .4216 m .74752 .42449 L .74694 .42331 L F
.629 .08 0 r
.21892 .55239 m .22137 .55324 L .2226 .55344 L F
.495 0 0 r
.2226 .55344 m .22062 .55316 L .21892 .55239 L F
.323 .757 .969 r
.22521 .55365 m .22062 .55316 L .2226 .55344 L F
.625 .095 0 r
.48829 .5937 m .48966 .59467 L .48898 .594 L F
.48829 .5937 m .48898 .594 L .48933 .59159 L F
.48829 .5937 m .48966 .59467 L .48898 .594 L F
.306 0 .029 r
.57144 .48531 m .57155 .48628 L .56857 .48677 L F
.481 0 .011 r
.57144 .48531 m .57368 .48625 L .57155 .48628 L F
.468 .119 .29 r
.57461 .48413 m .57368 .48625 L .57144 .48531 L F
0 .254 .713 r
.76863 .43821 m .765 .43562 L .76634 .43654 L F
.141 0 0 r
.23848 .55446 m .23687 .55473 L .23462 .55465 L F
.226 0 0 r
.24094 .55478 m .23687 .55473 L .23848 .55446 L F
.411 .139 .387 r
.57652 .46564 m .57887 .46591 L .57921 .46327 L F
.427 .104 .313 r
.57591 .46817 m .57887 .46591 L .57652 .46564 L F
.319 0 0 r
.41856 .65098 m .41683 .65095 L .41476 .65044 L F
.791 .344 .182 r
.41856 .65098 m .41772 .65296 L .41683 .65095 L F
.41856 .65098 m .42061 .65369 L .41772 .65296 L F
0 0 0 r
.59916 .51361 m .5981 .51537 L .59695 .51718 L F
0 0 .062 r
.59682 .51916 m .59695 .51718 L .5981 .51537 L F
.882 .837 .797 r
.67808 .4528 m .68156 .45117 L .68043 .44994 L F
.67808 .4528 m .67937 .45421 L .68156 .45117 L F
.873 .915 .854 r
.68043 .44994 m .68156 .45117 L .68429 .44801 L F
.815 .464 0 r
.4356 .59145 m .43637 .59441 L .43741 .59596 L F
.711 .319 .304 r
.43637 .59441 m .44194 .59519 L .43954 .59547 L F
.588 .093 .045 r
.44172 .59522 m .44025 .59602 L .44189 .59521 L F
.43896 .59525 m .44025 .59602 L .44172 .59522 L F
.527 .377 .62 r
.43649 .59744 m .43676 .5988 L .43415 .59797 L F
.43676 .5988 m .43693 .59962 L .43633 .59927 L F
.43676 .5988 m .43633 .59927 L .43415 .59797 L F
.644 .464 .625 r
.43189 .59602 m .4342 .59288 L .43196 .59348 L F
.43189 .59602 m .4346 .59618 L .4342 .59288 L F
.007 0 .4 r
.43309 .59461 m .43196 .59348 L .43254 .59332 L F
.43309 .59461 m .43254 .59332 L .4342 .59288 L F
.611 .278 .382 r
.43269 .59607 m .43365 .59732 L .4346 .59618 L F
.43189 .59602 m .43283 .59683 L .43269 .59607 L F
.43283 .59683 m .43415 .59797 L .43269 .59607 L F
.43365 .59732 m .43438 .59706 L .4346 .59618 L F
.269 .301 .71 r
.43309 .59461 m .43415 .59797 L .43347 .59738 L F
.43309 .59461 m .43347 .59738 L .43189 .59602 L F
.007 0 .4 r
.43309 .59461 m .43189 .59602 L .43196 .59348 L F
.897 .635 .534 r
.42873 .59373 m .43254 .59771 L .43309 .59461 L F
.43254 .59771 m .43293 .59812 L .43296 .59757 L F
.43254 .59771 m .43296 .59757 L .43309 .59461 L F
.611 .278 .382 r
.43365 .59732 m .43415 .59797 L .43438 .59706 L F
.303 .363 .759 r
.43296 .59757 m .43337 .59527 L .43309 .59461 L F
.43293 .59812 m .43299 .59775 L .43296 .59757 L F
.43299 .59775 m .43337 .59527 L .43296 .59757 L F
.798 .388 .271 r
.4342 .59288 m .43637 .59441 L .4356 .59145 L F
.425 .775 .996 r
.43715 .59467 m .43954 .59547 L .43649 .5946 L F
.711 .319 .304 r
.43637 .59441 m .43824 .59525 L .44194 .59519 L F
.706 .508 .619 r
.4342 .59288 m .43824 .59525 L .43637 .59441 L F
.425 .775 .996 r
.43649 .5946 m .43954 .59547 L .43741 .59596 L F
.43637 .59441 m .43715 .59467 L .43649 .5946 L F
.706 .508 .619 r
.4342 .59288 m .4346 .59618 L .43824 .59525 L F
.469 .23 .469 r
.4359 .59189 m .43309 .59461 L .4342 .59288 L F
.4359 .59189 m .43597 .59406 L .43309 .59461 L F
.284 0 .027 r
.43415 .59797 m .43824 .59525 L .4346 .59618 L F
.558 .493 .739 r
.43597 .59406 m .43415 .59797 L .43309 .59461 L F
.303 .363 .759 r
.43337 .59527 m .43374 .59287 L .43309 .59461 L F
.284 0 .027 r
.43415 .59797 m .43649 .59744 L .43824 .59525 L F
.558 .493 .739 r
.43597 .59406 m .43649 .59744 L .43415 .59797 L F
.672 .73 .222 r
.43789 .59321 m .43649 .59744 L .43597 .59406 L F
.258 .334 .752 r
.43374 .59287 m .4358 .5982 L .43678 .5955 L F
.4358 .5982 m .43624 .59933 L .43637 .59839 L F
.418 0 0 r
.43649 .59744 m .43621 .59828 L .44025 .59602 L F
.43621 .59828 m .43619 .59833 L .43624 .5983 L F
.43621 .59828 m .43624 .5983 L .44025 .59602 L F
.43619 .59833 m .43652 .59844 L .44025 .59602 L F
.771 .99 .762 r
.43827 .59713 m .43651 .59841 L .43702 .59782 L F
.429 .828 .62 r
.43624 .59933 m .43696 .5988 L .43637 .59839 L F
.418 0 0 r
.43619 .59833 m .43606 .59874 L .43652 .59844 L F
.771 .99 .762 r
.43651 .59841 m .43606 .59874 L .4366 .59822 L F
.43651 .59841 m .4366 .59822 L .43702 .59782 L F
.418 0 0 r
.43649 .59744 m .44025 .59602 L .43824 .59525 L F
.672 .73 .222 r
.43789 .59321 m .43643 .59761 L .43649 .59744 L F
.258 .334 .752 r
.4358 .5982 m .43619 .59833 L .43678 .5955 L F
.672 .73 .222 r
.43643 .59761 m .43642 .59765 L .43621 .59828 L F
.43642 .59765 m .43619 .59833 L .43621 .59828 L F
.43643 .59761 m .43621 .59828 L .43649 .59744 L F
.588 .093 .045 r
.43824 .59525 m .44025 .59602 L .43896 .59525 L F
.43824 .59525 m .44189 .59521 L .4417 .59519 L F
.709 .53 .645 r
.44082 .59418 m .4367 .59812 L .43789 .59321 L F
.258 .334 .752 r
.43619 .59833 m .43637 .59839 L .43647 .59772 L F
.43619 .59833 m .43647 .59772 L .43642 .59765 L F
.43619 .59833 m .43652 .59734 L .43678 .5955 L F
.672 .73 .222 r
.43642 .59765 m .43606 .59874 L .43619 .59833 L F
.429 .828 .62 r
.43637 .59839 m .43651 .59841 L .43655 .59801 L F
.709 .53 .645 r
.4367 .59812 m .43647 .59772 L .43789 .59321 L F
.43647 .59772 m .43642 .59765 L .43643 .59761 L F
.43647 .59772 m .43643 .59761 L .43789 .59321 L F
.429 .828 .62 r
.43647 .59772 m .43664 .59697 L .43652 .59734 L F
.43637 .59839 m .43648 .59779 L .43647 .59772 L F
.43648 .59779 m .43664 .59697 L .43647 .59772 L F
.43648 .59779 m .43655 .59801 L .43664 .59697 L F
.43637 .59839 m .43655 .59801 L .43648 .59779 L F
.709 .53 .645 r
.43647 .59772 m .43606 .59874 L .43642 .59765 L F
.4367 .59812 m .4366 .59822 L .43647 .59772 L F
.4366 .59822 m .43606 .59874 L .43647 .59772 L F
.258 .334 .752 r
.43642 .59765 m .43647 .59772 L .43652 .59734 L F
.429 .828 .62 r
.43652 .59734 m .43664 .59697 L .43678 .5955 L F
.771 .99 .762 r
.43787 .59756 m .43606 .59874 L .43827 .59713 L F
.429 .828 .62 r
.43651 .59841 m .43732 .59853 L .43709 .59723 L F
.43651 .59841 m .43709 .59723 L .43678 .5955 L F
.43696 .5988 m .43732 .59853 L .43637 .59839 L F
.771 .99 .762 r
.44025 .59602 m .43787 .59756 L .43827 .59713 L F
.44025 .59602 m .43702 .59782 L .44082 .59418 L F
.597 .177 .215 r
.44025 .59602 m .44386 .59559 L .44194 .59519 L F
.44025 .59602 m .44245 .5974 L .44386 .59559 L F
.771 .99 .762 r
.44025 .59602 m .44082 .59418 L .44241 .59732 L F
.44025 .59602 m .44241 .59732 L .44245 .5974 L F
.588 .093 .045 r
.4417 .59519 m .44189 .59521 L .44194 .59519 L F
.773 .742 .221 r
.20939 .68341 m .20874 .68728 L .20778 .68406 L F
.20939 .68341 m .2086 .68662 L .20874 .68728 L F
0 .027 .561 r
.2086 .68662 m .21087 .68953 L .20874 .68728 L F
.757 .801 .888 r
.71727 .42534 m .71396 .42449 L .71596 .42389 L F
.756 .821 .903 r
.7194 .42407 m .71727 .42534 L .71596 .42389 L F
.418 .695 .978 r
.29011 .56203 m .29227 .56183 L .29071 .56047 L F
.29011 .56203 m .29227 .56183 L .29071 .56047 L F
0 .049 .611 r
.53399 .60354 m .53417 .60226 L .53307 .60104 L F
.365 0 0 r
.21694 .55213 m .215 .55275 L .21522 .55305 L F
.78 .717 .793 r
.21219 .55302 m .21548 .5534 L .21522 .55305 L F
.587 .039 0 r
.21522 .55305 m .21083 .55199 L .21219 .55302 L F
.21522 .55305 m .21304 .55337 L .21083 .55199 L F
.365 0 0 r
.215 .55275 m .21304 .55337 L .21522 .55305 L F
.78 .717 .793 r
.21548 .5534 m .21708 .55359 L .21522 .55305 L F
.675 .926 .972 r
.21694 .55213 m .21708 .55359 L .21892 .55239 L F
.21694 .55213 m .21522 .55305 L .21708 .55359 L F
.495 .797 .999 r
.61929 .43387 m .61727 .43271 L .61646 .43359 L F
.845 .859 .854 r
.62073 .42975 m .61929 .43387 L .62178 .43313 L F
.62073 .42975 m .61727 .43271 L .61929 .43387 L F
.523 .45 .716 r
.61929 .43387 m .62245 .43545 L .62178 .43313 L F
.554 .312 .503 r
.56237 .544 m .56503 .5436 L .56514 .54132 L F
.551 .402 .632 r
.56514 .54132 m .56769 .54086 L .56736 .53784 L F
.467 .218 .453 r
.56503 .5436 m .56769 .54086 L .56514 .54132 L F
.333 .187 .528 r
.47086 .56737 m .46897 .57053 L .46847 .56773 L F
.91 .785 .711 r
.62096 .45953 m .62222 .4628 L .62265 .46083 L F
.649 .814 .962 r
.20679 .65378 m .21088 .6541 L .20889 .6532 L F
.492 .583 .874 r
.21088 .6541 m .21377 .65313 L .20889 .6532 L F
.21088 .6541 m .21286 .65384 L .21377 .65313 L F
.809 .877 .896 r
.75875 .43508 m .76252 .43396 L .76118 .43266 L F
.387 .847 .88 r
.73999 .39178 m .74337 .39125 L .74254 .39091 L F
0 0 0 r
.74518 .38996 m .74337 .39125 L .74592 .3888 L F
.453 .882 .901 r
.74254 .39091 m .74337 .39125 L .74518 .38996 L F
.276 .773 .886 r
.20467 .6541 m .20679 .65378 L .2029 .65397 L F
.288 .442 .842 r
.55557 .56765 m .55676 .56588 L .55424 .56425 L F
.55557 .56765 m .55699 .56765 L .55676 .56588 L F
.277 .211 .6 r
.5561 .57036 m .55699 .56765 L .55557 .56765 L F
.65 .471 .628 r
.4215 .60944 m .42114 .61368 L .4186 .61279 L F
.49 .333 .595 r
.4244 .61242 m .4215 .60944 L .42426 .60842 L F
.4244 .61242 m .42114 .61368 L .4215 .60944 L F
.399 .187 .471 r
.45253 .65405 m .45488 .65098 L .45254 .65149 L F
.45253 .65405 m .45488 .65098 L .45254 .65149 L F
.653 .14 0 r
.73525 .39965 m .73642 .40049 L .7366 .40087 L F
.562 .587 .837 r
.73866 .39833 m .73642 .40049 L .73512 .3972 L F
.73866 .39833 m .73878 .40006 L .73642 .40049 L F
.651 .405 .535 r
.7366 .40087 m .73878 .40006 L .73642 .40049 L F
.434 .167 .407 r
.57887 .46591 m .58159 .46253 L .57921 .46327 L F
.861 .713 .697 r
.61205 .44538 m .60874 .4446 L .61061 .44175 L F
.929 .865 .756 r
.61205 .44538 m .60877 .4471 L .60874 .4446 L F
.61205 .44538 m .61015 .44843 L .60877 .4471 L F
.328 0 .074 r
.55952 .60096 m .56107 .60234 L .55879 .60258 L F
.55952 .60096 m .56209 .6005 L .56107 .60234 L F
.744 .648 .754 r
.42047 .61668 m .41663 .61582 L .41897 .6145 L F
.42047 .61668 m .41671 .61812 L .41663 .61582 L F
.611 .488 .688 r
.42045 .61892 m .41671 .61812 L .42047 .61668 L F
.457 .481 .795 r
.4214 .61415 m .42047 .61668 L .41897 .6145 L F
.4214 .61415 m .42274 .6175 L .42047 .61668 L F
.503 .201 .388 r
.42274 .6175 m .42045 .61892 L .42047 .61668 L F
.744 .879 .942 r
.68505 .4386 m .68184 .43868 L .68439 .43634 L F
.675 .763 .917 r
.68786 .43712 m .68505 .4386 L .68439 .43634 L F
.755 .496 .542 r
.43185 .65446 m .43177 .6567 L .42841 .65635 L F
.74 .484 .542 r
.43185 .65446 m .43414 .65719 L .43177 .6567 L F
.373 .727 .989 r
.50833 .55473 m .50991 .55337 L .50733 .55331 L F
.50833 .55473 m .51131 .55451 L .50991 .55337 L F
.83 .993 .747 r
.50459 .5896 m .50554 .58768 L .5064 .58827 L F
.50459 .5896 m .50291 .59051 L .50554 .58768 L F
.355 .007 .228 r
.45094 .57165 m .45034 .57379 L .44784 .57381 L F
.619 .246 .314 r
.45265 .57288 m .45094 .57165 L .45301 .57035 L F
.45265 .57288 m .45034 .57379 L .45094 .57165 L F
.365 .424 .789 r
.40969 .63201 m .41062 .63504 L .40806 .63375 L F
.521 .729 .968 r
.41062 .63504 m .4086 .63573 L .40806 .63375 L F
.558 0 0 r
.40984 .62651 m .41074 .62731 L .40808 .62603 L F
.016 .075 .581 r
.40984 .62651 m .41036 .62782 L .41074 .62731 L F
.91 .785 .711 r
.62096 .45953 m .61952 .46283 L .62222 .4628 L F
.913 .813 .735 r
.61861 .46503 m .62222 .4628 L .61952 .46283 L F
.61861 .46503 m .62013 .46625 L .62222 .4628 L F
.649 .39 .514 r
.59056 .4725 m .59073 .47497 L .58678 .47488 L F
.574 .334 .515 r
.59293 .47223 m .59073 .47497 L .59056 .4725 L F
.809 .85 .88 r
.43379 .56338 m .43086 .5655 L .42882 .564 L F
.628 .947 .748 r
.43175 .56419 m .43086 .5655 L .43303 .56426 L F
.809 .85 .88 r
.43379 .56338 m .42882 .564 L .43129 .56082 L F
.056 0 0 r
.42934 .56308 m .43109 .56314 L .43274 .56288 L F
.716 .956 .677 r
.42855 .56413 m .42868 .56312 L .43004 .5623 L F
.056 0 0 r
.42868 .56312 m .42926 .56313 L .42934 .56308 L F
.42926 .56313 m .43109 .56314 L .42934 .56308 L F
.607 .849 .482 r
.43129 .56082 m .4297 .56287 L .43004 .5623 L F
.4297 .56287 m .42882 .564 L .42958 .56294 L F
.4297 .56287 m .42958 .56294 L .43004 .5623 L F
.202 .728 .84 r
.43109 .56314 m .43203 .56287 L .43274 .56288 L F
.793 .728 .792 r
.43004 .5623 m .43274 .56288 L .43301 .56079 L F
.456 .474 .789 r
.43491 .56142 m .43357 .56267 L .43301 .56079 L F
.202 .728 .84 r
.43203 .56287 m .43552 .56187 L .43344 .56262 L F
.43203 .56287 m .43344 .56262 L .43274 .56288 L F
.731 .979 .751 r
.43476 .5624 m .43357 .56267 L .43303 .56426 L F
.43543 .56168 m .43377 .56257 L .43476 .5624 L F
.43377 .56257 m .43357 .56267 L .43476 .5624 L F
.709 .985 .828 r
.43357 .56267 m .43175 .56419 L .43303 .56426 L F
.434 .484 .812 r
.43303 .56426 m .43668 .56747 L .43709 .56497 L F
0 0 0 r
.21239 .65982 m .21274 .65942 L .21425 .66004 L F
0 0 .078 r
.4614 .58295 m .46079 .58528 L .45971 .58615 L F
.498 .627 .908 r
.46079 .58528 m .46004 .58757 L .45971 .58615 L F
.391 .465 .816 r
.39549 .63324 m .39684 .63661 L .39808 .63587 L F
0 .049 .582 r
.39684 .63661 m .39827 .63845 L .39808 .63587 L F
.189 0 .274 r
.24092 .59161 m .24244 .59101 L .24304 .58899 L F
.327 .261 .629 r
.24092 .59161 m .24278 .59325 L .24244 .59101 L F
.778 .977 .703 r
.54657 .5954 m .54723 .59359 L .54802 .59344 L F
.583 .858 .995 r
.54451 .59451 m .54723 .59359 L .54657 .5954 L F
.699 .327 0 r
.64991 .40308 m .65087 .40555 L .65179 .40701 L F
.661 .12 0 r
.65119 .40718 m .65179 .40701 L .65087 .40555 L F
.816 .812 .846 r
.69435 .43891 m .69176 .44167 L .69493 .44208 L F
.825 .8 .828 r
.69176 .44167 m .69328 .44333 L .69493 .44208 L F
.757 .775 .868 r
.69435 .43891 m .69493 .44208 L .69779 .4392 L F
.677 .483 .615 r
.45058 .60065 m .44823 .60301 L .44808 .60101 L F
.922 .963 .654 r
.6062 .49703 m .60774 .49598 L .60736 .49555 L F
.6062 .49703 m .60598 .49951 L .60774 .49598 L F
.925 .974 .712 r
.60774 .49598 m .60903 .49205 L .60736 .49555 L F
.845 .612 .586 r
.59817 .48161 m .59944 .48461 L .59761 .4833 L F
.786 .701 .77 r
.71645 .43681 m .72005 .43722 L .71823 .43571 L F
.71645 .43681 m .71755 .44018 L .72005 .43722 L F
0 .303 .786 r
.62719 .43368 m .62819 .43519 L .62606 .43379 L F
.462 .299 .573 r
.26907 .59697 m .26681 .60018 L .26683 .59784 L F
0 .097 .652 r
.53301 .54019 m .53443 .54338 L .53326 .5417 L F
.132 0 0 r
.56329 .47786 m .56556 .47738 L .56638 .47561 L F
.064 0 0 r
.56638 .47561 m .56758 .47634 L .56825 .47443 L F
.56638 .47561 m .56556 .47738 L .56758 .47634 L F
.257 .489 .888 r
.76369 .39316 m .76313 .39497 L .76269 .3933 L F
0 0 .439 r
.7646 .39543 m .76313 .39497 L .76369 .39316 L F
.7646 .39543 m .76349 .39732 L .76313 .39497 L F
.655 .44 .581 r
.57089 .55304 m .57345 .55283 L .57094 .55561 L F
.712 .66 .797 r
.70144 .43978 m .70437 .44025 L .70409 .43881 L F
.597 .582 .807 r
.70409 .43881 m .70437 .44025 L .70622 .43813 L F
.654 .534 .705 r
.70437 .44025 m .70756 .44196 L .70622 .43813 L F
.70437 .44025 m .70509 .44262 L .70756 .44196 L F
.613 .686 .894 r
.18724 .63476 m .18469 .63557 L .18298 .63295 L F
.902 .93 .552 r
.53774 .55136 m .53918 .55023 L .53697 .54951 L F
.53774 .55136 m .53787 .55318 L .53918 .55023 L F
.58 .102 0 r
.50764 .55406 m .50765 .55407 L .50605 .55222 L F
0 .179 .688 r
.50765 .55407 m .50733 .55331 L .50605 .55222 L F
.766 .69 .779 r
.71387 .43967 m .71755 .44018 L .71645 .43681 L F
.856 .554 .476 r
.76402 .41021 m .76427 .41227 L .76699 .41286 L F
.626 .575 .777 r
.27846 .57907 m .27534 .57639 L .27648 .57634 L F
.516 .197 .366 r
.19942 .69383 m .19735 .69286 L .1963 .69453 L F
.19942 .69383 m .20033 .69206 L .19735 .69286 L F
.252 0 0 r
.22692 .6479 m .22321 .64916 L .22475 .64825 L F
.867 .916 .86 r
.59626 .4895 m .59522 .49119 L .59268 .4911 L F
.826 .844 .861 r
.62961 .43981 m .63268 .43935 L .6318 .43849 L F
.957 .931 .727 r
.63357 .43469 m .6318 .43849 L .63268 .43935 L F
.492 .225 .437 r
.44221 .60368 m .44186 .60581 L .43942 .60608 L F
.539 .266 .45 r
.44221 .60368 m .44434 .60564 L .44186 .60581 L F
.772 .516 .548 r
.54774 .55199 m .55146 .5499 L .54883 .55008 L F
.929 .719 .234 r
.54179 .58195 m .54178 .58454 L .54243 .58562 L F
.946 .898 .747 r
.53958 .5875 m .54243 .58562 L .54178 .58454 L F
.53958 .5875 m .54081 .58898 L .54243 .58562 L F
.715 .549 .663 r
.42651 .56815 m .42813 .57183 L .42855 .56794 L F
.758 .666 .76 r
.42669 .5646 m .42855 .56794 L .43086 .5655 L F
.992 .881 .599 r
.66682 .41443 m .66692 .41211 L .66678 .41444 L F
0 0 .302 r
.66822 .41245 m .66678 .41444 L .66692 .41211 L F
.587 .825 .445 r
.66822 .41245 m .66671 .41447 L .66678 .41444 L F
.66671 .41447 m .66584 .41563 L .66678 .41444 L F
.992 .881 .599 r
.66673 .41647 m .66682 .41443 L .66678 .41444 L F
.893 .923 .533 r
.66617 .41643 m .66673 .41647 L .66678 .41444 L F
.66617 .41643 m .66574 .41882 L .66673 .41647 L F
.596 .375 .551 r
.19044 .7198 m .19304 .71953 L .19262 .71705 L F
.447 .75 .993 r
.72284 .39714 m .72644 .39809 L .72542 .39641 L F
.617 .755 .944 r
.72542 .39641 m .72644 .39809 L .72808 .39581 L F
.47 .546 .852 r
.72808 .39581 m .72644 .39809 L .72875 .39827 L F
.327 .296 .671 r
.38261 .61565 m .38378 .61167 L .38193 .61245 L F
.38261 .61565 m .38397 .61514 L .38378 .61167 L F
.305 .236 .613 r
.38261 .61565 m .38452 .6176 L .38397 .61514 L F
.352 .242 .587 r
.38286 .61821 m .38452 .6176 L .38261 .61565 L F
.19 0 0 r
.54495 .56464 m .54842 .56246 L .54797 .56233 L F
.019 0 0 r
.54842 .56246 m .5501 .56176 L .54797 .56233 L F
.044 .531 .885 r
.47257 .60599 m .46996 .60532 L .47093 .60563 L F
.475 .279 .534 r
.55331 .60334 m .55362 .60629 L .55135 .60703 L F
.773 .431 .407 r
.55352 .60083 m .55644 .60257 L .55331 .60334 L F
.458 .186 .413 r
.55644 .60257 m .55362 .60629 L .55331 .60334 L F
.601 .945 .925 r
.77494 .43401 m .77658 .4324 L .77367 .43379 L F
.675 .576 .736 r
.53458 .55871 m .53603 .56182 L .53224 .5614 L F
.954 .9 .733 r
.53248 .55772 m .53224 .5614 L .53487 .56081 L F
.53248 .55772 m .53056 .56108 L .53224 .5614 L F
.577 .474 .7 r
.53613 .56393 m .53224 .5614 L .53603 .56182 L F
.53613 .56393 m .5347 .56636 L .53224 .5614 L F
.784 .44 .404 r
.53254 .56334 m .53487 .56081 L .53224 .5614 L F
.044 .459 .88 r
.17828 .65413 m .18175 .65681 L .18141 .6562 L F
.789 .887 .916 r
.4428 .55794 m .44236 .55935 L .44094 .55776 L F
.98 .902 .66 r
.44236 .55935 m .44106 .55897 L .44094 .55776 L F
.44236 .55935 m .4411 .5615 L .44106 .55897 L F
0 .385 .715 r
.54976 .57493 m .55183 .57564 L .55284 .57609 L F
.999 .797 .467 r
.55284 .57609 m .55183 .57564 L .55183 .57565 L F
.465 .87 .959 r
.55284 .57609 m .55371 .57647 L .55369 .57647 L F
.55284 .57609 m .55369 .57647 L .55077 .57681 L F
.55284 .57609 m .55428 .5764 L .55077 .57681 L F
.999 .797 .467 r
.55284 .57609 m .55019 .57813 L .55077 .57681 L F
.55284 .57609 m .55169 .57725 L .55019 .57813 L F
.55169 .57725 m .55162 .57733 L .55127 .57753 L F
.55169 .57725 m .55127 .57753 L .55019 .57813 L F
.378 0 0 r
.55284 .57609 m .55392 .57695 L .55184 .57565 L F
.55284 .57609 m .55184 .57565 L .55183 .57564 L F
.387 0 0 r
.55645 .57678 m .5539 .57629 L .55428 .5764 L F
.5539 .57629 m .55284 .57609 L .55363 .57626 L F
.5539 .57629 m .55363 .57626 L .55428 .5764 L F
0 0 0 r
.55422 .57633 m .55775 .5723 L .55581 .57373 L F
.55419 .57638 m .55423 .57633 L .55422 .57633 L F
.55423 .57633 m .55775 .5723 L .55422 .57633 L F
.465 .87 .959 r
.55284 .57609 m .55428 .5764 L .55371 .57647 L F
.387 0 0 r
.55645 .57678 m .5552 .57707 L .55284 .57609 L F
.714 .827 .935 r
.55183 .57564 m .55419 .57638 L .55284 .57609 L F
.378 0 0 r
.55284 .57609 m .5552 .57707 L .55392 .57695 L F
.714 .827 .935 r
.55183 .57564 m .55406 .57426 L .55419 .57638 L F
.496 .319 .57 r
.55303 .5764 m .55406 .57426 L .55183 .57564 L F
.55392 .57695 m .55398 .57579 L .55303 .5764 L F
.55398 .57579 m .55406 .57426 L .55303 .5764 L F
0 .385 .715 r
.54976 .57493 m .55284 .57609 L .55077 .57681 L F
.999 .797 .467 r
.55284 .57609 m .55183 .57565 L .55162 .57733 L F
.407 .193 .473 r
.26171 .61151 m .26002 .60964 L .26222 .60909 L F
.26171 .61151 m .25967 .61218 L .26002 .60964 L F
.241 .757 .82 r
.17969 .54376 m .18187 .54333 L .18329 .54328 L F
.302 .797 .846 r
.18329 .54328 m .18388 .54285 L .18602 .5418 L F
.18329 .54328 m .18187 .54333 L .18388 .54285 L F
0 0 0 r
.5024 .53825 m .50387 .53733 L .5041 .53674 L F
.442 .867 .936 r
.503 .53724 m .50387 .53733 L .5024 .53825 L F
.519 .225 .407 r
.54353 .60089 m .54313 .603 L .54145 .60154 L F
.403 .735 .992 r
.74744 .39701 m .74511 .39723 L .74389 .39596 L F
.354 0 .14 r
.74483 .39922 m .74511 .39723 L .74744 .39701 L F
.707 .866 .457 r
.50593 .5265 m .50418 .52953 L .50484 .52801 L F
.711 .905 .964 r
.50319 .53152 m .50484 .52801 L .50418 .52953 L F
.155 .638 .923 r
.24643 .54054 m .25065 .54167 L .24823 .54182 L F
.925 .696 .207 r
.76418 .4025 m .76471 .40343 L .76461 .40062 L F
.542 .406 .645 r
.46811 .59824 m .47125 .60002 L .47138 .59733 L F
.46811 .59824 m .46883 .60057 L .47125 .60002 L F
.758 .666 .76 r
.42669 .5646 m .43086 .5655 L .42898 .56645 L F
.628 .947 .748 r
.43175 .56419 m .42898 .56645 L .43086 .5655 L F
.617 .346 .484 r
.44658 .5679 m .4495 .56922 L .44942 .56758 L F
.44658 .5679 m .44653 .57054 L .4495 .56922 L F
0 0 .145 r
.6688 .3999 m .66986 .39962 L .67031 .3974 L F
.044 .226 .726 r
.6688 .3999 m .67 .40063 L .66986 .39962 L F
.146 .044 .472 r
.42972 .61204 m .42913 .61583 L .42866 .61333 L F
.42972 .61204 m .42995 .61546 L .42913 .61583 L F
.416 .173 .436 r
.43609 .60912 m .43584 .61128 L .43397 .61 L F
.008 .234 .742 r
.43397 .61 m .43584 .61128 L .43484 .61042 L F
.358 0 .176 r
.43484 .61042 m .42972 .61204 L .43397 .61 L F
.282 .142 .506 r
.43227 .61386 m .42972 .61204 L .43484 .61042 L F
.43227 .61386 m .42995 .61546 L .42972 .61204 L F
.425 .114 .332 r
.39638 .59418 m .39797 .5963 L .39841 .59365 L F
.39638 .59418 m .3956 .59686 L .39797 .5963 L F
.917 .95 .802 r
.55033 .58811 m .55264 .58769 L .55155 .58928 L F
.503 .098 .206 r
.54862 .60643 m .54711 .60847 L .54453 .60862 L F
.683 .306 .326 r
.54862 .60643 m .55076 .60856 L .54711 .60847 L F
.671 .31 .354 r
.55135 .60703 m .55076 .60856 L .54862 .60643 L F
.245 0 .327 r
.27846 .57907 m .27759 .58211 L .27584 .58272 L F
.424 .525 .856 r
.27864 .57583 m .27846 .57907 L .27648 .57634 L F
.27864 .57583 m .28033 .57906 L .27846 .57907 L F
.417 .152 .402 r
.28033 .57906 m .27759 .58211 L .27846 .57907 L F
.941 .704 .233 r
.77092 .41822 m .77022 .41445 L .77057 .41584 L F
.694 .425 .513 r
.50112 .58361 m .49923 .58764 L .49926 .58507 L F
.50112 .58361 m .50285 .5879 L .49923 .58764 L F
.428 0 .06 r
.5051 .58334 m .50492 .58425 L .50112 .58361 L F
.739 .446 .485 r
.50554 .58768 m .50112 .58361 L .50492 .58425 L F
.50554 .58768 m .50285 .5879 L .50112 .58361 L F
0 0 0 r
.5041 .53674 m .50698 .53572 L .50726 .53501 L F
.5041 .53674 m .50387 .53733 L .50698 .53572 L F
.563 .783 .981 r
.55535 .58553 m .55184 .58493 L .55264 .58769 L F
.654 .838 .971 r
.73371 .38751 m .72999 .38752 L .73283 .38594 L F
.699 .772 .908 r
.73505 .38459 m .73371 .38751 L .73283 .38594 L F
.73505 .38459 m .73614 .38627 L .73371 .38751 L F
.648 .856 .979 r
.19078 .65457 m .19579 .65496 L .19445 .65405 L F
.726 .715 .839 r
.19139 .65448 m .19138 .65454 L .19146 .65452 L F
.433 .845 .967 r
.19605 .65489 m .19885 .65548 L .19681 .65468 L F
.19429 .65538 m .19611 .65542 L .19605 .65489 L F
.19611 .65542 m .19885 .65548 L .19605 .65489 L F
.667 .909 .978 r
.19589 .65415 m .19885 .65548 L .20069 .65441 L F
.46 .786 .999 r
.19278 .65293 m .19516 .65435 L .19591 .65342 L F
.19516 .65435 m .19605 .65489 L .19598 .65413 L F
.19516 .65435 m .19598 .65413 L .19591 .65342 L F
.667 .909 .978 r
.19602 .65412 m .20069 .65441 L .19893 .65408 L F
.19541 .65413 m .19589 .65415 L .19602 .65412 L F
.19589 .65415 m .20069 .65441 L .19602 .65412 L F
.19541 .65413 m .196 .65436 L .19589 .65415 L F
.196 .65436 m .19885 .65548 L .19589 .65415 L F
.46 .786 .999 r
.19591 .65342 m .19603 .65401 L .19608 .65344 L F
.576 .882 .992 r
.19541 .65413 m .19602 .65412 L .19608 .65344 L F
.19602 .65412 m .19893 .65408 L .19608 .65344 L F
.46 .786 .999 r
.19603 .65401 m .19616 .65467 L .19608 .65344 L F
.433 .845 .967 r
.19579 .65496 m .19681 .65468 L .19541 .65413 L F
.648 .856 .979 r
.19579 .65496 m .19623 .65499 L .19605 .65489 L F
.536 .852 .998 r
.1956 .65433 m .19623 .65499 L .19579 .65496 L F
.648 .856 .979 r
.19579 .65496 m .19605 .65489 L .19278 .65293 L F
.125 .12 .581 r
.19146 .65452 m .19145 .65454 L .19105 .65455 L F
.536 .852 .998 r
.19105 .65455 m .1914 .65459 L .19078 .65457 L F
.1914 .65459 m .19579 .65496 L .19137 .65461 L F
.1914 .65459 m .19137 .65461 L .19078 .65457 L F
.19555 .65443 m .19579 .65496 L .19105 .65455 L F
0 0 0 r
.1905 .65624 m .19326 .65535 L .19076 .65457 L F
.726 .715 .839 r
.18685 .65228 m .18899 .65482 L .19139 .65448 L F
0 0 0 r
.19072 .65458 m .19076 .65457 L .19073 .65456 L F
.1905 .65624 m .19076 .65457 L .19072 .65458 L F
.125 .12 .581 r
.19142 .6546 m .19091 .65711 L .1905 .65624 L F
.19145 .65454 m .19144 .65457 L .19142 .6546 L F
.19144 .65457 m .19091 .65711 L .19142 .6546 L F
.536 .852 .998 r
.19551 .65434 m .19555 .65443 L .19105 .65455 L F
.726 .715 .839 r
.19074 .65457 m .19138 .65453 L .19139 .65448 L F
.19061 .65459 m .19086 .65457 L .19074 .65457 L F
.19086 .65457 m .19138 .65453 L .19074 .65457 L F
.125 .12 .581 r
.19146 .65452 m .19105 .65455 L .19073 .65456 L F
.536 .852 .998 r
.19541 .65413 m .1956 .65433 L .19073 .65456 L F
.648 .856 .979 r
.19073 .65456 m .19078 .65457 L .19139 .65407 L F
.596 .763 .959 r
.18894 .65208 m .19139 .65445 L .19278 .65293 L F
.648 .856 .979 r
.19135 .65449 m .19445 .65405 L .19278 .65293 L F
.596 .763 .959 r
.19139 .65445 m .19146 .65452 L .19278 .65293 L F
.726 .715 .839 r
.18685 .65228 m .19139 .65448 L .18894 .65208 L F
.19139 .65448 m .19139 .65445 L .18894 .65208 L F
.648 .856 .979 r
.19078 .65457 m .19135 .65449 L .19278 .65293 L F
.19139 .65404 m .19139 .65407 L .19278 .65293 L F
.19073 .65456 m .19139 .65407 L .19139 .65404 L F
.726 .715 .839 r
.19139 .65448 m .19146 .65452 L .19139 .65445 L F
.648 .856 .979 r
.19073 .65456 m .19278 .65293 L .19146 .65452 L F
.536 .852 .998 r
.19151 .65449 m .19073 .65456 L .19076 .65457 L F
.125 .12 .581 r
.19145 .65454 m .19142 .6546 L .19073 .65456 L F
.536 .852 .998 r
.19142 .6546 m .19076 .65457 L .1913 .65474 L F
.19086 .65457 m .19076 .65457 L .19142 .6546 L F
.125 .12 .581 r
.19142 .6546 m .1905 .65624 L .19073 .65456 L F
.536 .852 .998 r
.19145 .65456 m .19086 .65457 L .19142 .6546 L F
.125 .12 .581 r
.19146 .65452 m .19146 .65453 L .19145 .65454 L F
.726 .715 .839 r
.18899 .65482 m .19138 .65453 L .19061 .65459 L F
.19138 .65454 m .19146 .65453 L .19146 .65452 L F
.536 .852 .998 r
.1956 .65433 m .19078 .65457 L .19073 .65456 L F
.19151 .65449 m .19076 .65457 L .19145 .65456 L F
.19541 .65413 m .19151 .65449 L .19326 .65535 L F
.19151 .65449 m .1913 .65474 L .19326 .65535 L F
.726 .715 .839 r
.19055 .65463 m .19091 .65711 L .19138 .65453 L F
.18899 .65482 m .18914 .65501 L .19055 .65463 L F
.18914 .65501 m .19091 .65711 L .19055 .65463 L F
.125 .12 .581 r
.19146 .65453 m .19091 .65711 L .19145 .65454 L F
.536 .852 .998 r
.1956 .65433 m .19579 .65496 L .19551 .65434 L F
.433 .845 .967 r
.19429 .65538 m .19579 .65496 L .19541 .65413 L F
.46 .786 .999 r
.19616 .65467 m .19623 .65499 L .19621 .65476 L F
.19616 .65467 m .19621 .65476 L .19608 .65344 L F
.19605 .65489 m .19623 .65499 L .19591 .65342 L F
.726 .715 .839 r
.19138 .65454 m .19091 .65711 L .19146 .65453 L F
.433 .845 .967 r
.19326 .65535 m .19429 .65538 L .19541 .65413 L F
0 .413 .806 r
.49952 .53449 m .49875 .53456 L .49832 .53453 L F
.49952 .53449 m .5015 .53576 L .49875 .53456 L F
.757 .927 .944 r
.73427 .4254 m .73308 .42785 L .7319 .42652 L F
.73427 .4254 m .73518 .4265 L .73308 .42785 L F
.583 .898 .986 r
.64522 .41148 m .64237 .41247 L .6437 .41234 L F
.478 .285 .54 r
.64237 .41247 m .6442 .41326 L .6437 .41234 L F
.498 .525 .815 r
.6437 .41234 m .64717 .41111 L .64522 .41148 L F
.238 0 .197 r
.6437 .41234 m .6442 .41326 L .64717 .41111 L F
.978 .702 .431 r
.20234 .6953 m .20398 .69538 L .20224 .69248 L F
.20234 .6953 m .20398 .69538 L .20224 .69248 L F
.474 .319 .589 r
.20614 .69286 m .20627 .69545 L .20398 .69538 L F
.374 .311 .658 r
.2064 .69823 m .20398 .69538 L .20627 .69545 L F
.2064 .69823 m .20441 .6991 L .20398 .69538 L F
.971 .931 .66 r
.60485 .50192 m .60598 .49951 L .60428 .5006 L F
.921 .973 .696 r
.60428 .5006 m .60598 .49951 L .6062 .49703 L F
.848 .855 .848 r
.68368 .44536 m .68145 .44814 L .68429 .44801 L F
.873 .915 .854 r
.68043 .44994 m .68429 .44801 L .68145 .44814 L F
.801 .831 .874 r
.68368 .44536 m .68429 .44801 L .68691 .44538 L F
.733 .98 .914 r
.42489 .61316 m .4244 .61242 L .426 .61106 L F
.754 .398 0 r
.42489 .61316 m .42559 .61519 L .4244 .61242 L F
.704 .602 .74 r
.42765 .60956 m .42866 .61333 L .42489 .61316 L F
.819 .613 .625 r
.42866 .61333 m .42559 .61519 L .42489 .61316 L F
.333 .187 .528 r
.47086 .56737 m .47087 .56998 L .46897 .57053 L F
.628 .562 .761 r
.46951 .57383 m .47087 .56998 L .46897 .57053 L F
.362 0 .096 r
.47087 .56998 m .46737 .57198 L .46897 .57053 L F
.635 .761 .939 r
.67503 .40762 m .67833 .40853 L .67779 .40761 L F
.514 .914 .891 r
.67833 .40853 m .68023 .40704 L .67779 .40761 L F
.67833 .40853 m .68164 .40714 L .68023 .40704 L F
.512 .08 .157 r
.47516 .58405 m .47609 .58508 L .47716 .5849 L F
.405 .032 .214 r
.16231 .56662 m .16085 .56931 L .16084 .56931 L F
0 0 0 r
.16231 .56662 m .16111 .568 L .16305 .56527 L F
.405 .032 .214 r
.16231 .56662 m .15989 .56973 L .16111 .568 L F
.16231 .56662 m .15855 .56965 L .15989 .56973 L F
.16231 .56662 m .16084 .56931 L .15855 .56965 L F
0 0 0 r
.16231 .56662 m .16305 .56527 L .16319 .56507 L F
.669 .739 .903 r
.50962 .53391 m .50726 .53501 L .50667 .53239 L F
.819 .613 .625 r
.42866 .61333 m .42913 .61583 L .42559 .61519 L F
.767 .425 .406 r
.42651 .56815 m .42629 .57241 L .42299 .57192 L F
.78 .303 .1 r
.42629 .57241 m .42813 .57183 L .42651 .56815 L F
.182 0 .141 r
.42898 .56645 m .42609 .56946 L .42615 .56859 L F
0 0 0 r
.42195 .57295 m .42293 .57198 L .42355 .57132 L F
.42196 .57294 m .4231 .57177 L .42651 .56815 L F
.4231 .57177 m .42393 .57091 L .42651 .56815 L F
.42293 .57198 m .42318 .57172 L .42651 .56815 L F
.691 .6 .75 r
.42633 .56624 m .42615 .56859 L .42291 .56901 L F
.42615 .56859 m .42609 .56946 L .42541 .56937 L F
.42615 .56859 m .42541 .56937 L .42291 .56901 L F
0 0 0 r
.4231 .57177 m .42355 .57132 L .42393 .57091 L F
.42195 .57295 m .42355 .57132 L .42196 .57294 L F
.678 .973 .796 r
.42633 .56624 m .42291 .56901 L .42439 .56736 L F
.658 .256 .271 r
.42609 .56946 m .42521 .57107 L .42291 .56901 L F
.3 .295 .686 r
.42291 .56901 m .42446 .57039 L .42439 .56736 L F
.42446 .57039 m .42521 .57107 L .42495 .56989 L F
.42446 .57039 m .42495 .56989 L .42439 .56736 L F
.182 0 .141 r
.42824 .5664 m .42615 .56859 L .42633 .56624 L F
.42898 .56645 m .42615 .56859 L .42824 .5664 L F
0 0 0 r
.42293 .57198 m .42299 .57192 L .42318 .57172 L F
.739 .702 .815 r
.7089 .42876 m .70494 .42822 L .70755 .42711 L F
.773 .776 .855 r
.71096 .42748 m .7089 .42876 L .70755 .42711 L F
.051 0 .026 r
.54018 .50137 m .54232 .50084 L .54295 .49895 L F
.049 0 .019 r
.53953 .50346 m .54232 .50084 L .54018 .50137 L F
.082 0 .03 r
.53758 .50452 m .53953 .50346 L .54018 .50137 L F
.343 .092 .382 r
.61503 .41572 m .61752 .41485 L .6177 .41244 L F
.424 .148 .389 r
.61752 .41485 m .62024 .41164 L .6177 .41244 L F
.509 .48 .76 r
.63645 .41231 m .63874 .41197 L .63683 .41192 L F
.63683 .41192 m .63874 .41197 L .63645 .41231 L F
.749 .3 .186 r
.4246 .65584 m .42061 .65369 L .42275 .65336 L F
.922 .537 .243 r
.61735 .43514 m .61702 .43728 L .61647 .43524 L F
.61735 .43514 m .61934 .43686 L .61702 .43728 L F
.61735 .43514 m .61771 .43604 L .61934 .43686 L F
.677 .672 .838 r
.62014 .43727 m .61702 .43728 L .61934 .43686 L F
.922 .537 .243 r
.61771 .43604 m .6183 .43756 L .61934 .43686 L F
.677 .672 .838 r
.62069 .43726 m .62014 .43727 L .61934 .43686 L F
.991 .834 .589 r
.61513 .47468 m .61444 .47767 L .61563 .47849 L F
0 0 0 r
.61523 .47953 m .61563 .47849 L .61444 .47767 L F
.61523 .47953 m .61451 .48113 L .61563 .47849 L F
.763 .827 .902 r
.67808 .4528 m .67608 .45411 L .67937 .45421 L F
.308 0 .23 r
.43008 .6345 m .43167 .63538 L .43274 .63356 L F
.43008 .6345 m .42949 .63621 L .43167 .63538 L F
.152 .609 .93 r
.25782 .54298 m .25807 .544 L .25643 .54291 L F
.25782 .54298 m .25965 .54406 L .25807 .544 L F
.508 .397 .663 r
.44186 .58882 m .44432 .59088 L .44429 .5882 L F
.503 .369 .631 r
.26435 .60361 m .26452 .60613 L .2624 .60665 L F
.492 .287 .53 r
.2644 .60856 m .2624 .60665 L .26452 .60613 L F
.2644 .60856 m .26222 .60909 L .2624 .60665 L F
.667 .583 .751 r
.70509 .44262 m .70878 .44553 L .70756 .44196 L F
.606 .437 .627 r
.49926 .58507 m .49537 .58233 L .49943 .58377 L F
.49926 .58507 m .49701 .58615 L .49537 .58233 L F
0 0 0 r
.59916 .51361 m .59919 .51383 L .5981 .51537 L F
.709 .607 .741 r
.60751 .45145 m .60494 .45433 L .60415 .45059 L F
.708 .606 .741 r
.70756 .44196 m .70878 .44553 L .71127 .44255 L F
.682 .429 .532 r
.47138 .59733 m .47413 .59762 L .4755 .59522 L F
.252 0 .26 r
.4755 .59522 m .47625 .59667 L .47634 .59393 L F
.4755 .59522 m .47413 .59762 L .47625 .59667 L F
.444 .467 .789 r
.24949 .56235 m .25023 .55838 L .24833 .5586 L F
.24949 .56235 m .25113 .56196 L .25023 .55838 L F
.449 .498 .817 r
.24949 .56235 m .25261 .56402 L .25113 .56196 L F
.335 0 .135 r
.45805 .59481 m .45478 .59688 L .4555 .59483 L F
.6 .352 .513 r
.57976 .48122 m .57717 .48349 L .5772 .48147 L F
.304 0 .106 r
.27956 .57167 m .27861 .57322 L .27647 .57364 L F
.274 .438 .843 r
.28007 .56896 m .27956 .57167 L .2777 .56752 L F
.504 .448 .728 r
.28007 .56896 m .27861 .57322 L .27956 .57167 L F
.554 .822 .996 r
.54965 .60053 m .55352 .60083 L .55207 .59985 L F
.55207 .59985 m .55352 .60083 L .54965 .60053 L F
.504 .163 .322 r
.43115 .58164 m .43313 .58209 L .4338 .5803 L F
.779 .645 .714 r
.43313 .58209 m .43622 .57991 L .4338 .5803 L F
.615 .698 .903 r
.75285 .40819 m .75123 .41148 L .74995 .41093 L F
.549 .344 .555 r
.23279 .60545 m .2361 .60317 L .2334 .60367 L F
.076 0 0 r
.63184 .40455 m .63077 .40559 L .63389 .40377 L F
.76 .754 .847 r
.6322 .43467 m .62978 .437 L .62819 .43519 L F
.501 .257 .478 r
.24244 .59101 m .24521 .58826 L .24304 .58899 L F
.741 .99 .883 r
.59937 .44127 m .59941 .44104 L .60147 .4393 L F
0 0 0 r
.59933 .44047 m .60147 .4393 L .59822 .44206 L F
.576 .38 .579 r
.59953 .44039 m .60127 .44376 L .6 .44019 L F
.59933 .44047 m .59947 .44071 L .59953 .44039 L F
.59947 .44071 m .60127 .44376 L .59953 .44039 L F
.741 .99 .883 r
.59913 .44149 m .59822 .44206 L .59941 .44104 L F
.59913 .44149 m .59941 .44104 L .59937 .44127 L F
.242 .162 .562 r
.7467 .41583 m .74868 .41722 L .74758 .41488 L F
.7467 .41583 m .74658 .41856 L .74868 .41722 L F
.513 .331 .571 r
.65697 .39905 m .65947 .40097 L .66095 .40164 L F
.349 .777 .972 r
.66095 .40164 m .65947 .40097 L .66023 .40104 L F
.986 .771 .373 r
.66095 .40164 m .66171 .40227 L .66176 .40072 L F
.349 .777 .972 r
.66095 .40164 m .66023 .40104 L .66318 .40133 L F
.986 .771 .373 r
.66095 .40164 m .66166 .40371 L .66171 .40227 L F
.813 .727 .198 r
.76933 .4271 m .76957 .42386 L .77004 .42491 L F
.482 0 0 r
.18602 .5418 m .18388 .54285 L .18771 .54273 L F
0 .23 .748 r
.21978 .65138 m .22075 .65179 L .21982 .6502 L F
.541 .439 .688 r
.22075 .65179 m .21904 .65434 L .21978 .65138 L F
.339 0 .049 r
.21093 .67458 m .21174 .67489 L .21458 .67226 L F
.21174 .67489 m .21332 .67438 L .21458 .67226 L F
.673 .618 .786 r
.2131 .66779 m .21458 .67226 L .2157 .66867 L F
.339 0 .049 r
.21174 .67489 m .21278 .67529 L .21332 .67438 L F
.244 .083 .454 r
.21277 .67047 m .21297 .67325 L .21093 .67458 L F
.21317 .67123 m .21297 .67325 L .21277 .67047 L F
.21297 .67325 m .21278 .67529 L .21174 .67489 L F
.21297 .67325 m .21174 .67489 L .21093 .67458 L F
.896 .75 .249 r
.21289 .67133 m .21278 .67529 L .21337 .66913 L F
.992 .829 .459 r
.21458 .67226 m .21278 .67529 L .21289 .67133 L F
.109 .071 .529 r
.21458 .67226 m .21606 .67493 L .21485 .67511 L F
.992 .829 .459 r
.21458 .67226 m .21336 .67159 L .21606 .67493 L F
.21336 .67159 m .21289 .67133 L .21371 .67227 L F
.21492 .67352 m .21488 .67359 L .21606 .67493 L F
.709 .707 .847 r
.21659 .67242 m .21638 .6734 L .21544 .67284 L F
.21585 .67229 m .21544 .67284 L .21395 .67196 L F
.21659 .67242 m .21544 .67284 L .21585 .67229 L F
.21659 .67242 m .21395 .67196 L .21414 .6717 L F
.992 .829 .459 r
.21336 .67159 m .21371 .67227 L .21488 .67359 L F
.21336 .67159 m .21488 .67359 L .21492 .67352 L F
.709 .707 .847 r
.21638 .6734 m .21508 .67382 L .21289 .67133 L F
.21659 .67242 m .21289 .67133 L .21728 .67037 L F
.499 .376 .643 r
.21728 .67037 m .21969 .6718 L .21659 .67242 L F
0 0 0 r
.21728 .67037 m .21753 .67015 L .21969 .6718 L F
.21734 .67032 m .21462 .67403 L .21753 .67015 L F
.21728 .67037 m .21672 .67113 L .21734 .67032 L F
.21672 .67113 m .21462 .67403 L .21734 .67032 L F
.21462 .67403 m .21455 .67413 L .21461 .67404 L F
.21462 .67403 m .21461 .67404 L .21753 .67015 L F
.244 .083 .454 r
.21337 .66913 m .21317 .67123 L .21277 .67047 L F
.709 .707 .847 r
.21414 .6717 m .21395 .67196 L .21289 .67133 L F
.21638 .6734 m .21606 .67493 L .21508 .67382 L F
.327 0 .052 r
.62562 .40903 m .62795 .40861 L .62902 .40696 L F
.284 0 .029 r
.62902 .40696 m .63054 .40781 L .63077 .40559 L F
.62902 .40696 m .62795 .40861 L .63054 .40781 L F
.947 .71 .245 r
.49569 .54196 m .49488 .54197 L .49367 .54035 L F
.49569 .54196 m .49566 .54378 L .49488 .54197 L F
.328 0 0 r
.628 .41982 m .63031 .42022 L .63186 .41976 L F
.516 0 0 r
.63031 .42022 m .63368 .42085 L .63186 .41976 L F
0 0 .153 r
.65729 .41542 m .65727 .41406 L .65695 .41165 L F
.777 .721 .189 r
.6568 .41626 m .65724 .41263 L .65727 .41406 L F
.315 .405 .796 r
.6552 .40759 m .65695 .41165 L .65842 .40974 L F
0 0 .265 r
.65695 .41165 m .65758 .40991 L .65842 .40974 L F
.65695 .41165 m .65727 .41406 L .65758 .40991 L F
.777 .721 .189 r
.65724 .41263 m .65758 .40991 L .65727 .41406 L F
0 0 .153 r
.65731 .41562 m .65727 .41406 L .65729 .41542 L F
.895 .668 .154 r
.65731 .41562 m .6568 .41626 L .65727 .41406 L F
.65731 .41562 m .65736 .41764 L .6568 .41626 L F
.613 .415 .589 r
.56855 .55858 m .5657 .56153 L .56577 .55892 L F
.762 .697 .79 r
.72689 .43252 m .73065 .43288 L .7296 .42995 L F
.72689 .43252 m .72832 .43408 L .73065 .43288 L F
.683 .726 .883 r
.7296 .42995 m .73065 .43288 L .73307 .43081 L F
0 0 0 r
.44122 .65477 m .44028 .65674 L .44202 .65384 L F
.44122 .65477 m .44028 .65674 L .44202 .65384 L F
.934 .941 .774 r
.65566 .42286 m .65776 .42211 L .65657 .42393 L F
.948 .916 .749 r
.65683 .4209 m .65776 .42211 L .65566 .42286 L F
.296 .367 .767 r
.53697 .5756 m .53644 .57912 L .53451 .57629 L F
.53697 .5756 m .53797 .57915 L .53644 .57912 L F
.754 .913 .945 r
.63019 .42383 m .62912 .42646 L .63413 .42238 L F
.392 .77 .991 r
.63031 .42022 m .63266 .41994 L .63368 .42085 L F
.457 0 0 r
.63413 .41988 m .63517 .4207 L .63645 .41978 L F
.63266 .41994 m .63336 .42015 L .63413 .41988 L F
.63336 .42015 m .63517 .4207 L .63413 .41988 L F
.87 .991 .82 r
.63343 .42013 m .63019 .42383 L .63413 .42238 L F
.321 .772 .957 r
.63138 .41944 m .63266 .41994 L .63031 .42022 L F
.63166 .41923 m .63193 .41942 L .63138 .41944 L F
.63193 .41942 m .63266 .41994 L .63138 .41944 L F
.236 0 0 r
.62675 .41985 m .63031 .42022 L .628 .41982 L F
.535 .818 .998 r
.62675 .41985 m .62919 .41917 L .63031 .42022 L F
.321 .772 .957 r
.63166 .41923 m .63031 .42022 L .62919 .41917 L F
.399 0 0 r
.63069 .41945 m .62816 .42016 L .63206 .41972 L F
.62919 .41917 m .62884 .4195 L .63069 .41945 L F
.62884 .4195 m .62816 .42016 L .63069 .41945 L F
0 .399 .697 r
.63206 .41972 m .63266 .41994 L .63166 .41923 L F
.63206 .41972 m .63244 .41984 L .63266 .41994 L F
.63238 .41982 m .63336 .42015 L .63266 .41994 L F
.889 .987 .801 r
.63206 .41972 m .63019 .42383 L .63324 .42011 L F
.63206 .41972 m .63324 .42011 L .63337 .41995 L F
0 .399 .697 r
.63206 .41972 m .63238 .41982 L .63244 .41984 L F
.87 .991 .82 r
.63324 .42011 m .63336 .42015 L .63343 .42013 L F
0 .399 .697 r
.63238 .41982 m .63517 .4207 L .63336 .42015 L F
.87 .991 .82 r
.63337 .41995 m .63324 .42011 L .63343 .42013 L F
.63324 .42011 m .63314 .42023 L .63336 .42015 L F
.63314 .42023 m .63019 .42383 L .63343 .42013 L F
.518 .339 .577 r
.63413 .42238 m .63279 .42488 L .63523 .42402 L F
.248 .076 .441 r
.27365 .59078 m .27143 .59422 L .27155 .59194 L F
.437 .369 .683 r
.46335 .57653 m .46636 .57896 L .46717 .57664 L F
.46335 .57653 m .46533 .57981 L .46636 .57896 L F
.393 .264 .584 r
.38109 .60964 m .38297 .60925 L .38271 .60646 L F
.451 .41 .722 r
.38109 .60964 m .38378 .61167 L .38297 .60925 L F
.38109 .60964 m .38193 .61245 L .38378 .61167 L F
.624 .763 .946 r
.20671 .55269 m .21033 .55328 L .20912 .55193 L F
.332 .619 .955 r
.21033 .55328 m .21083 .55199 L .20912 .55193 L F
.432 .731 .989 r
.21033 .55328 m .21219 .55302 L .21083 .55199 L F
.263 .741 .935 r
.22219 .53928 m .22457 .53918 L .22643 .53967 L F
0 .514 .739 r
.22457 .53918 m .22848 .53983 L .22643 .53967 L F
.557 .251 .405 r
.57717 .48349 m .57368 .48625 L .57461 .48413 L F
.748 .788 .885 r
.68843 .44483 m .69328 .44333 L .69176 .44167 L F
.714 .625 .756 r
.52806 .54377 m .52572 .54683 L .52862 .54556 L F
.203 0 .282 r
.52629 .54942 m .52862 .54556 L .52572 .54683 L F
.167 0 .208 r
.5288 .54691 m .52788 .54872 L .52629 .54942 L F
.203 0 .282 r
.52629 .54942 m .52788 .54872 L .52826 .54709 L F
0 0 .508 r
.52862 .54556 m .52886 .54548 L .52806 .54377 L F
0 0 .012 r
.52862 .54556 m .52832 .54683 L .52886 .54548 L F
.41 .3 .617 r
.52882 .54653 m .52873 .54659 L .52836 .54506 L F
.52843 .54511 m .52836 .54506 L .52806 .54377 L F
.52882 .54653 m .52836 .54506 L .52843 .54511 L F
.52886 .54548 m .52882 .54653 L .52866 .54597 L F
.52882 .54653 m .5288 .54691 L .52873 .54659 L F
.538 .381 .617 r
.52806 .54377 m .52861 .5461 L .52572 .54683 L F
.52861 .5461 m .52873 .54659 L .52843 .54661 L F
.203 0 .282 r
.52758 .54727 m .52832 .54683 L .52862 .54556 L F
.538 .381 .617 r
.52861 .5461 m .52843 .54661 L .52572 .54683 L F
0 0 .012 r
.52832 .54683 m .52826 .54709 L .52861 .5461 L F
.538 .381 .617 r
.52873 .54659 m .52843 .5469 L .52572 .54683 L F
.203 0 .282 r
.52665 .54882 m .52826 .54709 L .52832 .54683 L F
.52665 .54882 m .52832 .54683 L .52758 .54727 L F
.52629 .54942 m .52826 .54709 L .52665 .54882 L F
.167 0 .208 r
.52833 .5469 m .52629 .54942 L .52572 .54683 L F
.5288 .54691 m .52808 .54764 L .52833 .5469 L F
0 0 .012 r
.52826 .54709 m .52826 .54711 L .52833 .5469 L F
.167 0 .208 r
.52808 .54764 m .52629 .54942 L .52833 .5469 L F
0 0 .012 r
.52833 .5469 m .52788 .54872 L .52861 .5461 L F
.52826 .54711 m .52788 .54872 L .52833 .5469 L F
.52861 .5461 m .52788 .54872 L .52886 .54548 L F
.538 .381 .617 r
.52873 .54659 m .5288 .54691 L .52843 .5469 L F
.928 .739 .626 r
.52886 .54548 m .52788 .54872 L .5288 .54691 L F
.515 .292 .514 r
.52788 .54872 m .53184 .54804 L .52886 .54548 L F
.53184 .54804 m .53202 .54801 L .52886 .54548 L F
.41 .3 .617 r
.52886 .54548 m .52866 .54597 L .52806 .54377 L F
.28 .036 .355 r
.24575 .58627 m .24703 .58746 L .24753 .58557 L F
.24575 .58627 m .24521 .58826 L .24703 .58746 L F
.489 .589 .881 r
.78125 .3952 m .77908 .39741 L .77786 .39571 L F
.78125 .3952 m .78147 .39728 L .77908 .39741 L F
.473 .295 .558 r
.44403 .5708 m .44399 .57346 L .44653 .57054 L F
.611 .488 .688 r
.42045 .61892 m .41707 .62175 L .41671 .61812 L F
.784 .603 .656 r
.54585 .54358 m .54288 .54116 L .54291 .54279 L F
.84 .805 .817 r
.543 .54563 m .54585 .54358 L .54291 .54279 L F
.477 .642 .929 r
.41674 .63314 m .41938 .63325 L .41807 .63137 L F
.794 .941 .923 r
.41943 .63302 m .41938 .63325 L .42082 .6338 L F
.477 .642 .929 r
.41938 .63325 m .41989 .63327 L .41947 .63284 L F
.41938 .63325 m .41943 .63302 L .41807 .63137 L F
.176 .677 .911 r
.41674 .63314 m .41938 .63325 L .42082 .6338 L F
.186 0 0 r
.42082 .6338 m .4186 .63352 L .41674 .63314 L F
.783 .748 .821 r
.41807 .63137 m .4186 .63352 L .41943 .63302 L F
.41807 .63137 m .41943 .63302 L .42128 .6319 L F
.477 .642 .929 r
.41943 .63302 m .41947 .63284 L .41807 .63137 L F
.794 .941 .923 r
.42128 .6319 m .41943 .63302 L .42082 .6338 L F
.41943 .63302 m .41918 .63318 L .41938 .63325 L F
.41918 .63318 m .4186 .63352 L .42082 .6338 L F
.176 .677 .911 r
.41938 .63325 m .41989 .63327 L .42082 .6338 L F
.854 .986 .853 r
.42082 .6338 m .41989 .63327 L .42128 .6319 L F
.199 0 .13 r
.56329 .47786 m .56483 .47901 L .56556 .47738 L F
.56329 .47786 m .56272 .47994 L .56483 .47901 L F
.978 .775 .562 r
.76242 .42608 m .76402 .4249 L .76278 .42378 L F
.76242 .42608 m .7637 .42734 L .76402 .4249 L F
.727 .538 .635 r
.58449 .47497 m .58531 .47872 L .58243 .47816 L F
.634 .478 .654 r
.58835 .47778 m .58449 .47497 L .58678 .47488 L F
.58835 .47778 m .58531 .47872 L .58449 .47497 L F
.274 0 .166 r
.16525 .5644 m .16231 .56662 L .16319 .56507 L F
.443 .224 .485 r
.22814 .61198 m .23102 .6123 L .23124 .60894 L F
.367 .217 .542 r
.22814 .61198 m .23075 .61416 L .23102 .6123 L F
.22814 .61198 m .22834 .61529 L .23075 .61416 L F
.611 .772 .957 r
.67235 .45337 m .67359 .45505 L .67608 .45411 L F
.645 .817 .966 r
.44399 .57346 m .44784 .57381 L .44653 .57054 L F
.499 0 0 r
.44399 .57346 m .44638 .5746 L .44784 .57381 L F
.411 .328 .652 r
.44784 .57381 m .4495 .56922 L .44653 .57054 L F
.44784 .57381 m .45034 .57379 L .4495 .56922 L F
.653 .276 .317 r
.44638 .5746 m .45034 .57379 L .44784 .57381 L F
.783 .761 .833 r
.71096 .42748 m .70755 .42711 L .70962 .42577 L F
.728 .748 .868 r
.71396 .42449 m .71096 .42748 L .70962 .42577 L F
.642 .61 .801 r
.60514 .4422 m .60723 .43924 L .60486 .43949 L F
.60514 .4422 m .60851 .44211 L .60723 .43924 L F
.623 .408 .57 r
.60851 .44211 m .60578 .44434 L .60514 .4422 L F
0 0 .406 r
.61708 .43391 m .61646 .43359 L .61727 .43271 L F
.61708 .43391 m .61735 .43514 L .61646 .43359 L F
.017 0 .394 r
.61646 .43359 m .61735 .43514 L .61647 .43524 L F
.887 .513 .043 r
.53958 .5875 m .54109 .5904 L .54081 .58898 L F
.8 .639 .682 r
.55147 .55247 m .55485 .55017 L .55146 .5499 L F
.55147 .55247 m .55508 .55288 L .55485 .55017 L F
.699 .563 .698 r
.55485 .55017 m .55508 .55288 L .55749 .5499 L F
.594 .434 .635 r
.46305 .61549 m .46336 .61847 L .46069 .61862 L F
.56 .284 .455 r
.46336 .61847 m .46295 .62052 L .46069 .61862 L F
.594 .434 .635 r
.46305 .61549 m .46336 .61847 L .46069 .61862 L F
.56 .284 .455 r
.46069 .61862 m .46295 .62052 L .46336 .61847 L F
.46336 .61847 m .46295 .62052 L .46069 .61862 L F
.384 .332 .676 r
.27759 .58211 m .27807 .58488 L .27584 .58272 L F
.463 .34 .627 r
.27584 .58272 m .27807 .58488 L .27611 .58549 L F
.271 .075 .421 r
.6058 .43046 m .60381 .43372 L .60537 .43241 L F
.481 .263 .505 r
.60381 .43372 m .60656 .43288 L .60537 .43241 L F
.60381 .43372 m .60345 .43564 L .60656 .43288 L F
.484 .063 .166 r
.38699 .59975 m .3895 .59956 L .39084 .59782 L F
.461 .039 .152 r
.39084 .59782 m .3895 .59956 L .39259 .59907 L F
.449 .046 .183 r
.39084 .59782 m .39259 .59907 L .39327 .59762 L F
.446 .164 .391 r
.69965 .4037 m .70233 .40427 L .69898 .40591 L F
.69965 .4037 m .70216 .40304 L .70233 .40427 L F
.622 .119 .035 r
.4186 .61279 m .4214 .61415 L .41897 .6145 L F
.4186 .61279 m .42114 .61368 L .4214 .61415 L F
.15 .073 .507 r
.24985 .57953 m .25128 .57584 L .24913 .57713 L F
.679 .237 .194 r
.48825 .59596 m .48966 .59467 L .48829 .5937 L F
.235 .309 .736 r
.48966 .59467 m .492 .59665 L .49067 .59708 L F
.679 .237 .194 r
.48825 .59596 m .492 .59665 L .48966 .59467 L F
.647 .723 .904 r
.19861 .687 m .20249 .68792 L .20087 .68678 L F
.473 0 0 r
.20445 .68715 m .20087 .68678 L .20249 .68792 L F
.977 .916 .664 r
.54142 .5173 m .54064 .5163 L .53964 .51844 L F
.756 .821 .903 r
.7194 .42407 m .71596 .42389 L .71833 .42263 L F
.706 .81 .93 r
.72223 .42226 m .7194 .42407 L .71833 .42263 L F
.806 .861 .89 r
.74827 .38338 m .7443 .38428 L .74714 .38192 L F
.657 .894 .981 r
.74998 .3811 m .74827 .38338 L .74714 .38192 L F
.588 .722 .937 r
.75243 .38044 m .75362 .38198 L .75092 .3826 L F
.488 .499 .795 r
.75417 .38558 m .75092 .3826 L .75362 .38198 L F
.708 .506 .614 r
.74993 .38365 m .75325 .3834 L .75252 .38075 L F
.75213 .38083 m .75252 .38075 L .75243 .38044 L F
.657 .894 .981 r
.74981 .38133 m .75092 .3826 L .74827 .38338 L F
.75008 .38127 m .75092 .3826 L .74981 .38133 L F
.588 .722 .937 r
.75243 .38044 m .75092 .3826 L .74998 .3811 L F
.708 .506 .614 r
.74993 .38365 m .75252 .38075 L .75213 .38083 L F
.657 .894 .981 r
.74998 .3811 m .75008 .38127 L .74981 .38133 L F
.896 .726 .663 r
.59823 .48648 m .59761 .4833 L .59944 .48461 L F
.425 .257 .548 r
.61484 .41764 m .61752 .41485 L .61503 .41572 L F
.559 .273 .438 r
.43942 .60608 m .4389 .60898 L .43609 .60912 L F
.482 .205 .416 r
.44017 .60851 m .43942 .60608 L .44186 .60581 L F
.44017 .60851 m .4389 .60898 L .43942 .60608 L F
.854 .863 .848 r
.62534 .44735 m .62268 .45062 L .6257 .45062 L F
.899 .8 .742 r
.62198 .45305 m .6257 .45062 L .62268 .45062 L F
.62198 .45305 m .62359 .45417 L .6257 .45062 L F
.807 .834 .872 r
.62534 .44735 m .6257 .45062 L .62801 .44814 L F
.594 .835 .46 r
.66349 .42177 m .66574 .41882 L .66477 .41999 L F
0 0 0 r
.66406 .41974 m .66349 .42177 L .66477 .41999 L F
.66406 .41974 m .66287 .42407 L .66349 .42177 L F
.087 .259 .745 r
.50355 .57269 m .50471 .57309 L .50375 .57416 L F
.175 .397 .84 r
.50471 .57309 m .50643 .57598 L .50375 .57416 L F
.738 .713 .828 r
.69779 .4392 m .70144 .43978 L .70011 .43815 L F
.722 .71 .838 r
.70011 .43815 m .70144 .43978 L .70409 .43881 L F
.515 .312 .544 r
.56736 .53784 m .56991 .53726 L .56989 .53498 L F
.52 .369 .615 r
.56769 .54086 m .56991 .53726 L .56736 .53784 L F
.548 .411 .646 r
.45041 .58566 m .45278 .58521 L .45261 .58265 L F
.348 .093 .379 r
.45041 .58566 m .45169 .58766 L .45278 .58521 L F
.45041 .58566 m .45088 .58799 L .45169 .58766 L F
.075 0 .289 r
.25143 .57327 m .25326 .57008 L .25164 .57084 L F
.284 .54 .918 r
.26287 .54461 m .26121 .54516 L .25965 .54406 L F
.26287 .54461 m .26397 .54637 L .26121 .54516 L F
0 .368 .835 r
.54329 .59295 m .54451 .59451 L .54348 .59436 L F
.684 .482 .607 r
.57345 .55283 m .57355 .55543 L .57094 .55561 L F
.659 .47 .617 r
.57682 .5528 m .57355 .55543 L .57345 .55283 L F
.334 .728 .983 r
.20509 .67156 m .20722 .67141 L .2051 .67032 L F
.20509 .67156 m .20722 .67141 L .2051 .67032 L F
.677 .483 .615 r
.45058 .60065 m .45073 .60323 L .44823 .60301 L F
.597 .482 .693 r
.45264 .59768 m .45321 .60027 L .45058 .60065 L F
.581 .408 .613 r
.45321 .60027 m .45073 .60323 L .45058 .60065 L F
.45321 .60027 m .45073 .60323 L .45058 .60065 L F
.601 .567 .788 r
.4701 .59195 m .47409 .5919 L .47145 .5878 L F
.306 .786 .915 r
.23036 .55305 m .22734 .5532 L .22881 .55322 L F
.655 .47 .622 r
.45823 .56982 m .45631 .57341 L .45647 .57026 L F
.45823 .56982 m .45985 .57356 L .45631 .57341 L F
.515 .234 .427 r
.46221 .57093 m .45985 .57356 L .45823 .56982 L F
.775 .612 .678 r
.59659 .47506 m .59799 .47857 L .59453 .4779 L F
.874 .917 .854 r
.59799 .47857 m .59466 .48038 L .59453 .4779 L F
.877 .899 .482 r
.66477 .41999 m .66574 .41882 L .66617 .41643 L F
.472 .416 .713 r
.5648 .57293 m .56199 .57133 L .56388 .56798 L F
.5648 .57293 m .56264 .57369 L .56199 .57133 L F
.772 .516 .548 r
.54774 .55199 m .55147 .55247 L .55146 .5499 L F
.562 .373 .583 r
.55508 .55288 m .55761 .55257 L .55749 .5499 L F
.645 .489 .657 r
.55749 .5499 m .56043 .54998 L .55997 .54688 L F
.535 .353 .581 r
.55749 .5499 m .56012 .55191 L .56043 .54998 L F
.55749 .5499 m .55761 .55257 L .56012 .55191 L F
.725 .692 .818 r
.7246 .43341 m .72832 .43408 L .72689 .43252 L F
0 0 .316 r
.56677 .59167 m .5681 .58729 L .56813 .59074 L F
.19 .068 .473 r
.56803 .59299 m .56677 .59167 L .56813 .59074 L F
.56803 .59299 m .56675 .59417 L .56677 .59167 L F
0 0 .152 r
.58839 .50789 m .58688 .51128 L .58783 .51001 L F
0 0 .19 r
.58783 .51001 m .58688 .51128 L .58638 .51352 L F
.253 0 0 r
.18771 .54273 m .19001 .54239 L .19198 .54085 L F
.53 .83 .999 r
.19198 .54085 m .19236 .53934 L .19414 .54026 L F
.171 0 0 r
.19198 .54085 m .19275 .54157 L .19236 .53934 L F
.19095 .54166 m .19001 .54239 L .19275 .54157 L F
.083 0 0 r
.18984 .54213 m .19406 .5415 L .19275 .54157 L F
.19406 .5415 m .19458 .54142 L .19275 .54157 L F
.171 0 0 r
.19198 .54085 m .19095 .54166 L .19275 .54157 L F
.581 .521 .752 r
.45265 .57288 m .45391 .57654 L .45153 .57675 L F
.388 .036 .242 r
.45323 .57819 m .45153 .57675 L .45391 .57654 L F
.45323 .57819 m .45069 .57907 L .45153 .57675 L F
.21 0 0 r
.61934 .43686 m .62245 .43545 L .62069 .43726 L F
.557 .368 .581 r
.55997 .54688 m .56247 .54635 L .56237 .544 L F
.517 .369 .619 r
.56043 .54998 m .56247 .54635 L .55997 .54688 L F
.555 .166 .26 r
.55164 .55421 m .55508 .55288 L .55147 .55247 L F
.55164 .55421 m .55437 .55469 L .55508 .55288 L F
.29 0 0 r
.55601 .5531 m .55508 .55288 L .55437 .55469 L F
.55601 .5531 m .55761 .55257 L .55508 .55288 L F
.085 0 .269 r
.492 .59665 m .49012 .59963 L .49067 .59708 L F
.77 .27 .021 r
.20143 .68481 m .20445 .68715 L .20462 .6831 L F
0 0 .051 r
.20462 .6831 m .20528 .68303 L .20626 .68072 L F
.141 .126 .579 r
.20445 .68715 m .20528 .68303 L .20462 .6831 L F
.952 .654 .436 r
.53435 .52694 m .53621 .52651 L .53467 .52602 L F
.53435 .52694 m .53598 .52806 L .53621 .52651 L F
.011 .289 .786 r
.51131 .55451 m .51192 .55619 L .51223 .55478 L F
0 .258 .768 r
.51192 .55619 m .51383 .5567 L .51223 .55478 L F
.51192 .55619 m .51418 .55803 L .51383 .5567 L F
.003 0 0 r
.50593 .5265 m .50684 .52709 L .50805 .52546 L F
.50593 .5265 m .50484 .52801 L .50684 .52709 L F
.639 .847 .98 r
.44739 .55708 m .44295 .55856 L .4428 .55794 L F
.751 .595 .683 r
.59659 .47506 m .59469 .47549 L .59293 .47223 L F
.743 .566 .655 r
.59659 .47506 m .59453 .4779 L .59469 .47549 L F
.694 .769 .909 r
.54956 .55407 m .55147 .55247 L .54774 .55199 L F
.541 .474 .729 r
.55164 .55421 m .55147 .55247 L .54956 .55407 L F
0 .042 .604 r
.5308 .59647 m .5303 .5934 L .53085 .59477 L F
.058 .624 .721 r
.2123 .53937 m .21451 .53923 L .21647 .53913 L F
.129 .672 .827 r
.21451 .53923 m .21845 .53933 L .21647 .53913 L F
.179 0 .224 r
.55847 .48174 m .55978 .4825 L .5604 .48067 L F
.55847 .48174 m .55785 .48356 L .55978 .4825 L F
.416 .268 .571 r
.41813 .62388 m .41822 .62661 L .41613 .6272 L F
.164 .251 .708 r
.41868 .6297 m .41613 .6272 L .41822 .62661 L F
.717 .84 .94 r
.21895 .65977 m .21425 .66004 L .21693 .65863 L F
0 .341 .668 r
.21693 .65863 m .22024 .65988 L .21895 .65977 L F
.43 .264 .553 r
.22024 .65988 m .2179 .66377 L .21895 .65977 L F
.674 .951 .701 r
.74941 .43082 m .74699 .43312 L .74753 .43202 L F
.74941 .43082 m .74753 .43202 L .74759 .42966 L F
.211 .418 .847 r
.74753 .43202 m .74968 .43177 L .74796 .43113 L F
.813 .508 .474 r
.74426 .42924 m .74759 .42966 L .74753 .43202 L F
.211 .418 .847 r
.74753 .43202 m .74796 .43113 L .74686 .43072 L F
.674 .951 .701 r
.74699 .43312 m .74653 .43355 L .74753 .43202 L F
.249 .451 .862 r
.74653 .43355 m .7495 .43471 L .74753 .43202 L F
0 .418 .821 r
.75044 .43557 m .7495 .43471 L .74653 .43355 L F
.916 .715 .617 r
.74752 .42449 m .74493 .4265 L .74694 .42331 L F
.74752 .42449 m .74751 .42746 L .74493 .4265 L F
.455 .142 .344 r
.44194 .59519 m .44452 .59366 L .44354 .59535 L F
.587 .399 .594 r
.56247 .54635 m .56503 .5436 L .56237 .544 L F
.58 .65 .884 r
.76269 .3933 m .75975 .39413 L .75811 .39077 L F
.714 .829 .936 r
.20877 .63558 m .20679 .63672 L .20503 .6355 L F
.537 0 0 r
.4502 .5575 m .45231 .5581 L .45468 .558 L F
.248 0 0 r
.45468 .558 m .45231 .5581 L .45603 .55825 L F
.563 .583 .832 r
.74849 .38798 m .74986 .39171 L .75229 .39086 L F
.462 .675 .956 r
.67046 .4049 m .67118 .40647 L .66918 .40669 L F
.67046 .4049 m .67118 .40647 L .66918 .40669 L F
.45 .347 .646 r
.43952 .56444 m .44179 .56416 L .4411 .5615 L F
.47 .294 .56 r
.59528 .44551 m .59933 .44047 L .59822 .44206 L F
.33 .339 .719 r
.52262 .57565 m .52376 .57223 L .5221 .57378 L F
.48 .345 .619 r
.56989 .53498 m .57213 .53431 L .57183 .53162 L F
.431 .221 .491 r
.57196 .53662 m .56989 .53498 L .56991 .53726 L F
.57196 .53662 m .57213 .53431 L .56989 .53498 L F
.638 .116 0 r
.49831 .59384 m .5018 .59453 L .49806 .5936 L F
.567 .008 0 r
.49831 .59384 m .5005 .59543 L .5018 .59453 L F
.875 .729 .696 r
.5022 .59568 m .5018 .59453 L .5005 .59543 L F
0 .201 .716 r
.50411 .59674 m .5018 .59453 L .50552 .59471 L F
.50411 .59674 m .5042 .59841 L .50196 .59478 L F
.50411 .59674 m .50196 .59478 L .5018 .59453 L F
.525 0 0 r
.50628 .59844 m .50512 .59766 L .50411 .59674 L F
.19 .388 .828 r
.50411 .59674 m .5059 .60001 L .5042 .59841 L F
0 0 0 r
.5042 .59841 m .50346 .60016 L .5031 .59999 L F
.858 .718 .707 r
.50411 .59674 m .50346 .60016 L .5059 .60001 L F
.968 .839 .661 r
.5022 .59784 m .50411 .59674 L .5022 .59568 L F
.5022 .59784 m .50409 .59683 L .50401 .59679 L F
.525 0 0 r
.50628 .59844 m .50568 .59846 L .50278 .59615 L F
.50628 .59844 m .50278 .59615 L .50325 .59639 L F
.968 .839 .661 r
.50401 .59679 m .50409 .59683 L .50411 .59674 L F
.525 0 0 r
.50512 .59766 m .5022 .59568 L .50411 .59674 L F
.968 .839 .661 r
.50362 .59709 m .50397 .59748 L .50409 .59683 L F
0 .139 .644 r
.50257 .59591 m .5056 .5984 L .50481 .5976 L F
.50369 .59659 m .50481 .5976 L .50398 .59676 L F
.50257 .59591 m .50481 .5976 L .50369 .59659 L F
.525 0 0 r
.50325 .59639 m .50278 .59615 L .5022 .59568 L F
0 .139 .644 r
.50278 .59615 m .50568 .59846 L .50257 .59591 L F
.968 .839 .661 r
.5022 .59784 m .50346 .60016 L .50397 .59748 L F
.564 .08 .064 r
.5031 .59999 m .50182 .60137 L .49851 .60109 L F
0 0 0 r
.5031 .59999 m .50346 .60016 L .50182 .60137 L F
.5031 .59999 m .50346 .60016 L .50182 .60137 L F
.89 .847 .795 r
.50182 .60137 m .50346 .60016 L .5022 .59784 L F
.558 .015 0 r
.49925 .60022 m .4976 .59914 L .49569 .59732 L F
0 0 0 r
.49925 .60022 m .49823 .60134 L .4976 .59914 L F
.611 .604 .819 r
.49823 .60134 m .50037 .59858 L .4976 .59914 L F
0 0 0 r
.49925 .60022 m .49851 .60109 L .49823 .60134 L F
.583 .755 .96 r
.49851 .60109 m .50182 .60137 L .50062 .60057 L F
.49851 .60109 m .50062 .60057 L .49823 .60134 L F
.611 .604 .819 r
.49823 .60134 m .50062 .60057 L .50037 .59858 L F
.89 .847 .795 r
.50182 .60137 m .5022 .59784 L .50062 .60057 L F
.76 .712 .807 r
.50037 .59858 m .50062 .60057 L .5022 .59784 L F
.78 .971 .918 r
.5059 .60001 m .50352 .60061 L .50628 .59844 L F
0 0 .294 r
.50352 .60061 m .50568 .59846 L .50628 .59844 L F
.50352 .60061 m .50519 .60001 L .50568 .59846 L F
.774 .703 .785 r
.50568 .59846 m .50519 .60001 L .50441 .59791 L F
.50488 .59766 m .50441 .59791 L .50398 .59676 L F
0 .139 .644 r
.5056 .5984 m .50568 .59846 L .50553 .59831 L F
.5056 .5984 m .50553 .59831 L .5053 .59808 L F
.50508 .59787 m .50509 .59787 L .50398 .59676 L F
.755 .556 .627 r
.51032 .5964 m .50628 .59844 L .50642 .59613 L F
.631 .413 .569 r
.50642 .59613 m .50628 .59844 L .50411 .59674 L F
0 0 0 r
.50552 .598 m .50541 .59812 L .50537 .59811 L F
.50552 .598 m .50537 .59811 L .50531 .59805 L F
.25 .065 .424 r
.50543 .59794 m .50529 .59824 L .50552 .598 L F
0 .428 .749 r
.50516 .59786 m .50552 .598 L .50515 .59786 L F
.50543 .59794 m .50552 .598 L .50516 .59786 L F
0 .139 .644 r
.50528 .59807 m .5053 .59808 L .50509 .59787 L F
.50528 .59807 m .50509 .59787 L .50508 .59787 L F
.5056 .5984 m .5053 .59808 L .50528 .59807 L F
.46 .524 .837 r
.50572 .59803 m .50519 .60001 L .50655 .59829 L F
.774 .703 .785 r
.50568 .59846 m .50441 .59791 L .50488 .59766 L F
0 0 0 r
.50537 .59811 m .50522 .59827 L .50503 .59837 L F
.50486 .59824 m .50049 .60174 L .49965 .60042 L F
.50531 .59805 m .50496 .59832 L .50486 .59824 L F
.50496 .59832 m .50049 .60174 L .50486 .59824 L F
.46 .524 .837 r
.50428 .59758 m .50441 .59791 L .50494 .59796 L F
.50428 .59758 m .50494 .59796 L .50505 .59782 L F
.968 .839 .661 r
.5022 .59784 m .50397 .59748 L .50362 .59709 L F
.676 .465 .592 r
.5005 .59543 m .5022 .59784 L .5022 .59568 L F
.5005 .59543 m .50037 .59858 L .5022 .59784 L F
.687 .868 .967 r
.50302 .59703 m .50505 .59782 L .49907 .59952 L F
.50505 .59782 m .50515 .59786 L .50498 .5979 L F
.50505 .59782 m .50498 .5979 L .49907 .59952 L F
.50515 .59786 m .50552 .598 L .50531 .59805 L F
.46 .524 .837 r
.50505 .59782 m .50494 .59796 L .50572 .59803 L F
.687 .868 .967 r
.50515 .59786 m .50531 .59805 L .50477 .59818 L F
.46 .524 .837 r
.50441 .59791 m .50459 .59841 L .50477 .59818 L F
.687 .868 .967 r
.50498 .5979 m .50477 .59818 L .49907 .59952 L F
.50515 .59786 m .50477 .59818 L .50498 .5979 L F
.46 .524 .837 r
.50477 .59818 m .50465 .59855 L .50503 .59837 L F
.50459 .59841 m .50465 .59855 L .50477 .59818 L F
.50441 .59791 m .50503 .59837 L .50572 .59803 L F
0 0 0 r
.50537 .59811 m .50503 .59837 L .50531 .59805 L F
.46 .524 .837 r
.50465 .59855 m .50519 .60001 L .50553 .59874 L F
0 0 0 r
.50503 .59837 m .50049 .60174 L .50496 .59832 L F
.50503 .59837 m .50496 .59832 L .50531 .59805 L F
.46 .524 .837 r
.50503 .59837 m .50553 .59874 L .50572 .59803 L F
.50465 .59855 m .50553 .59874 L .50503 .59837 L F
.608 .291 .406 r
.50346 .60016 m .50352 .60061 L .50182 .60137 L F
0 0 0 r
.50503 .59837 m .50293 .60073 L .50049 .60174 L F
.50522 .59827 m .50293 .60073 L .50503 .59837 L F
.46 .524 .837 r
.50428 .59758 m .50655 .59829 L .50687 .59788 L F
.50398 .59676 m .50428 .59758 L .50552 .59772 L F
0 .428 .749 r
.50487 .59754 m .50528 .59783 L .50302 .59703 L F
.50528 .59783 m .50515 .59786 L .50302 .59703 L F
0 0 0 r
.50541 .59812 m .50293 .60073 L .50537 .59811 L F
.50531 .59805 m .49965 .60042 L .50321 .59855 L F
.25 .065 .424 r
.50487 .59754 m .50293 .60073 L .50529 .59824 L F
0 .428 .749 r
.50528 .59783 m .50543 .59794 L .50516 .59786 L F
.25 .065 .424 r
.50487 .59754 m .50529 .59824 L .50543 .59794 L F
.46 .524 .837 r
.50566 .59741 m .50552 .59772 L .50687 .59788 L F
.50398 .59676 m .50552 .59772 L .50566 .59741 L F
0 0 0 r
.50321 .59855 m .49965 .60042 L .49907 .59952 L F
0 .139 .644 r
.5022 .59568 m .50278 .59615 L .50257 .59591 L F
.875 .729 .696 r
.5022 .59568 m .50199 .59275 L .5018 .59453 L F
.49 .405 .686 r
.43932 .58191 m .43714 .58506 L .43689 .58243 L F
.43932 .58191 m .43934 .58444 L .43714 .58506 L F
.685 .568 .717 r
.51363 .53109 m .51192 .52849 L .51398 .52895 L F
.694 .574 .716 r
.51192 .52849 m .51297 .53193 L .51346 .53185 L F
.51363 .53109 m .51346 .53185 L .51407 .53174 L F
.51192 .52849 m .51346 .53185 L .51363 .53109 L F
.51387 .53005 m .51425 .53036 L .51398 .52895 L F
.51425 .53036 m .51565 .53147 L .51461 .52989 L F
.51425 .53036 m .51461 .52989 L .51398 .52895 L F
.51398 .52895 m .51565 .53147 L .51565 .52931 L F
.51425 .53036 m .51407 .53174 L .51565 .53147 L F
.662 .875 .503 r
.51387 .53005 m .51363 .53109 L .51398 .52895 L F
.694 .574 .716 r
.51192 .52849 m .51368 .53116 L .51425 .53036 L F
.51368 .53116 m .51407 .53174 L .51425 .53036 L F
.662 .875 .503 r
.51379 .53085 m .51361 .53126 L .51363 .53109 L F
.694 .574 .716 r
.514 .52877 m .51565 .52931 L .51565 .52899 L F
.51398 .52895 m .51565 .52931 L .514 .52877 L F
.51192 .52849 m .51398 .52895 L .514 .52877 L F
.778 .532 .564 r
.51192 .52849 m .514 .52877 L .51399 .52892 L F
.514 .52877 m .51565 .52899 L .51399 .52892 L F
.353 .322 .685 r
.51565 .52899 m .51707 .52797 L .51809 .52764 L F
.006 0 .335 r
.51565 .53147 m .51627 .53163 L .51702 .52817 L F
.51697 .52822 m .51702 .52817 L .51707 .52797 L F
.51565 .53147 m .51702 .52817 L .51697 .52822 L F
.353 .322 .685 r
.51697 .52822 m .51809 .52764 L .5178 .52773 L F
.51565 .52899 m .51679 .52835 L .51697 .52822 L F
.51679 .52835 m .51809 .52764 L .51697 .52822 L F
.006 0 .335 r
.51697 .52822 m .51707 .52797 L .51565 .52899 L F
0 0 .249 r
.51714 .52805 m .51627 .53163 L .51825 .52929 L F
.51707 .52797 m .51702 .52817 L .51714 .52805 L F
.51702 .52817 m .51627 .53163 L .51714 .52805 L F
.353 .322 .685 r
.51565 .52899 m .51699 .5282 L .51399 .52892 L F
.412 .54 .876 r
.51809 .52764 m .51707 .52797 L .51909 .52679 L F
0 0 .249 r
.51707 .52797 m .51714 .52805 L .51909 .52679 L F
.353 .322 .685 r
.51699 .5282 m .5178 .52773 L .51753 .52781 L F
.51699 .5282 m .51753 .52781 L .51714 .52805 L F
0 0 .249 r
.51714 .52805 m .51825 .52929 L .51906 .52686 L F
.51714 .52805 m .51849 .52722 L .51909 .52679 L F
.998 .785 .482 r
.51909 .52679 m .51581 .5277 L .5179 .52764 L F
.51909 .52679 m .5179 .52764 L .51809 .52764 L F
0 0 .249 r
.51849 .52722 m .51906 .52686 L .51909 .52679 L F
.353 .322 .685 r
.51714 .52805 m .51753 .52781 L .51731 .52788 L F
.51699 .5282 m .51731 .52788 L .51399 .52892 L F
.006 0 .335 r
.51565 .53147 m .51697 .52822 L .51565 .52899 L F
.662 .875 .503 r
.51581 .5277 m .51399 .52892 L .5144 .52879 L F
.51581 .5277 m .5144 .52879 L .51809 .52764 L F
.144 .543 .923 r
.51658 .52694 m .51666 .52703 L .51581 .5277 L F
.998 .785 .482 r
.51909 .52679 m .51773 .52819 L .51581 .5277 L F
.144 .543 .923 r
.51666 .52703 m .51773 .52819 L .51581 .5277 L F
.662 .875 .503 r
.51581 .5277 m .51381 .53081 L .51415 .52881 L F
.51381 .53081 m .51363 .53109 L .51389 .52996 L F
.51381 .53081 m .51389 .52996 L .51415 .52881 L F
.51581 .5277 m .51377 .53099 L .51379 .53085 L F
.51377 .53099 m .51361 .53126 L .51379 .53085 L F
.51581 .5277 m .51426 .52992 L .51368 .53112 L F
.51377 .53099 m .51368 .53112 L .51361 .53126 L F
.51581 .5277 m .51368 .53112 L .51377 .53099 L F
.51415 .52881 m .51387 .53005 L .51399 .52892 L F
.51387 .53005 m .51398 .52895 L .51399 .52892 L F
.694 .574 .716 r
.51192 .52849 m .51387 .53005 L .51398 .52895 L F
.685 .568 .717 r
.51361 .53126 m .51192 .52849 L .51363 .53109 L F
.51398 .52895 m .51192 .52849 L .51399 .52892 L F
.604 .746 .945 r
.21286 .65384 m .21694 .65503 L .21498 .65334 L F
.616 .756 .945 r
.21498 .65334 m .21694 .65503 L .21904 .65434 L F
.502 .166 .33 r
.69456 .39876 m .6921 .39749 L .69119 .39957 L F
.69456 .39876 m .69473 .39717 L .6921 .39749 L F
.588 .391 .581 r
.42691 .65157 m .42915 .64803 L .4269 .64848 L F
.42691 .65157 m .42945 .65127 L .42915 .64803 L F
.648 .435 .58 r
.42915 .64803 m .43296 .65058 L .43288 .64819 L F
.42915 .64803 m .42945 .65127 L .43296 .65058 L F
0 0 0 r
.54575 .49616 m .54736 .49488 L .54849 .49352 L F
.54849 .49352 m .54937 .49395 L .54998 .49179 L F
.54849 .49352 m .54736 .49488 L .54937 .49395 L F
.102 .633 .869 r
.22848 .53983 m .23055 .53996 L .23232 .54048 L F
.143 .661 .889 r
.23055 .53996 m .23447 .54055 L .23232 .54048 L F
.43 .81 .991 r
.19832 .55555 m .19651 .55484 L .19436 .55523 L F
.147 .599 .93 r
.19832 .55555 m .19883 .55481 L .19651 .55484 L F
.552 .379 .6 r
.58703 .45757 m .58976 .45717 L .58967 .45417 L F
.414 .128 .367 r
.58703 .45757 m .58905 .45873 L .58976 .45717 L F
.58703 .45757 m .58671 .45946 L .58905 .45873 L F
.808 .671 .711 r
.60486 .43949 m .60147 .4393 L .60345 .43564 L F
.053 0 .122 r
.53832 .55936 m .53603 .56182 L .53719 .56145 L F
.866 .648 .606 r
.53458 .55871 m .53603 .56182 L .53487 .56081 L F
.198 .144 .568 r
.53603 .56182 m .53698 .56328 L .53719 .56145 L F
0 0 .286 r
.53603 .56182 m .53613 .56393 L .53676 .56305 L F
.53603 .56182 m .53676 .56305 L .53487 .56081 L F
.409 .209 .494 r
.58152 .54936 m .58155 .54682 L .58368 .54622 L F
0 0 .225 r
.59288 .52609 m .59441 .52261 L .59445 .52464 L F
0 0 .112 r
.59231 .5282 m .59288 .52609 L .59445 .52464 L F
.953 .864 .449 r
.65657 .42393 m .6554 .42547 L .65566 .42286 L F
.65657 .42393 m .65568 .42767 L .6554 .42547 L F
.627 .632 .836 r
.19074 .72039 m .19304 .71953 L .19044 .7198 L F
.483 .353 .627 r
.46556 .61768 m .46305 .61549 L .46552 .61506 L F
.515 .318 .552 r
.46794 .61464 m .46556 .61768 L .46552 .61506 L F
.431 .315 .62 r
.46305 .61549 m .46624 .61669 L .46552 .61506 L F
.483 .353 .627 r
.46556 .61768 m .46336 .61847 L .46305 .61549 L F
.431 .315 .62 r
.46305 .61549 m .46336 .61847 L .46624 .61669 L F
.138 0 .164 r
.55343 .48751 m .55271 .48921 L .55531 .48641 L F
0 .422 .837 r
.66445 .41038 m .66526 .41083 L .66604 .41071 L F
.998 .799 .454 r
.66604 .41071 m .66692 .41211 L .66705 .41055 L F
0 0 .302 r
.66822 .41245 m .66692 .41211 L .66604 .41071 L F
0 .422 .837 r
.66526 .41083 m .66822 .41245 L .66604 .41071 L F
.998 .799 .454 r
.66604 .41071 m .66705 .41055 L .66717 .40909 L F
.489 .314 .57 r
.24753 .58557 m .24992 .58199 L .24803 .58258 L F
.479 .368 .65 r
.38289 .60333 m .385 .60281 L .38457 .60011 L F
.407 .285 .6 r
.38289 .60333 m .38503 .60534 L .385 .60281 L F
.38289 .60333 m .38271 .60646 L .38503 .60534 L F
.497 .641 .92 r
.19485 .63557 m .19447 .63808 L .19275 .63595 L F
.19485 .63557 m .19631 .63786 L .19447 .63808 L F
.458 .186 .413 r
.55644 .60257 m .55604 .60575 L .55362 .60629 L F
.386 .074 .308 r
.55879 .60258 m .55604 .60575 L .55644 .60257 L F
0 0 0 r
.54295 .49895 m .5449 .49799 L .54575 .49616 L F
.061 0 0 r
.54575 .49616 m .5469 .49695 L .54736 .49488 L F
.54575 .49616 m .5449 .49799 L .5469 .49695 L F
0 0 0 r
.78473 .41205 m .78454 .41373 L .78363 .41548 L F
.067 .202 .696 r
.78454 .41373 m .78552 .4172 L .78363 .41548 L F
.298 .02 .312 r
.20441 .6991 m .2037 .70185 L .20225 .70141 L F
.473 .175 .378 r
.20629 .70128 m .20441 .6991 L .2064 .69823 L F
.20629 .70128 m .2037 .70185 L .20441 .6991 L F
0 0 0 r
.15989 .55192 m .16093 .55206 L .16287 .55018 L F
.044 0 0 r
.16093 .55206 m .16497 .54962 L .16287 .55018 L F
.806 .806 .851 r
.68551 .44395 m .68843 .44483 L .68821 .44196 L F
.68551 .44395 m .68691 .44538 L .68843 .44483 L F
.776 .856 .91 r
.68821 .44196 m .68843 .44483 L .69176 .44167 L F
.585 .883 .992 r
.7553 .43513 m .75616 .43593 L .75875 .43508 L F
.022 0 .025 r
.54998 .49179 m .55271 .48921 L .55072 .49031 L F
.157 0 .195 r
.556 .48466 m .55531 .48641 L .55785 .48356 L F
.549 .344 .555 r
.23279 .60545 m .23577 .60562 L .2361 .60317 L F
.486 .268 .507 r
.23344 .60828 m .23577 .60562 L .23279 .60545 L F
.161 0 0 r
.15636 .55317 m .15869 .55284 L .15989 .55192 L F
0 0 0 r
.15989 .55192 m .15869 .55284 L .16093 .55206 L F
.124 0 0 r
.46587 .56115 m .46828 .56074 L .4696 .55988 L F
.352 0 .221 r
.5531 .60793 m .55135 .60703 L .55362 .60629 L F
.5531 .60793 m .55076 .60856 L .55135 .60703 L F
.608 .408 .586 r
.57919 .54988 m .57933 .55238 L .57682 .5528 L F
.572 .424 .642 r
.58152 .54936 m .57933 .55238 L .57919 .54988 L F
.367 .685 .98 r
.63683 .41192 m .63874 .41197 L .63755 .41066 L F
.63683 .41192 m .63874 .41197 L .63755 .41066 L F
.569 .711 .938 r
.60615 .45005 m .60751 .45145 L .60415 .45059 L F
.813 .769 .812 r
.61015 .44843 m .60751 .45145 L .60615 .45005 L F
.484 .282 .53 r
.5648 .57293 m .56222 .57613 L .56264 .57369 L F
.896 .726 .663 r
.59823 .48648 m .59595 .48645 L .59761 .4833 L F
.88 .823 .788 r
.59823 .48648 m .59626 .4895 L .59595 .48645 L F
.6 .352 .513 r
.57976 .48122 m .5796 .48321 L .57717 .48349 L F
.618 .498 .693 r
.58243 .47816 m .57976 .48122 L .57883 .47766 L F
.58243 .47816 m .58236 .48129 L .57976 .48122 L F
.452 .228 .482 r
.57976 .48122 m .58205 .48262 L .5796 .48321 L F
.54 .144 .24 r
.58236 .48129 m .58205 .48262 L .57976 .48122 L F
.114 0 .075 r
.40935 .58468 m .41114 .58451 L .41198 .58229 L F
0 0 .067 r
.41198 .58229 m .41375 .58152 L .4144 .57928 L F
0 0 .008 r
.41198 .58229 m .41114 .58451 L .41375 .58152 L F
.516 .284 .502 r
.43622 .57991 m .43886 .57937 L .43909 .57604 L F
.384 .099 .352 r
.43886 .57937 m .4411 .57599 L .43909 .57604 L F
.415 .275 .58 r
.5657 .56153 m .56586 .56418 L .56384 .56473 L F
.45 .381 .688 r
.56586 .56418 m .56643 .56655 L .56384 .56473 L F
.508 .37 .628 r
.56643 .56655 m .56412 .56722 L .56384 .56473 L F
.801 .504 .486 r
.42732 .57913 m .42754 .5816 L .43115 .58164 L F
.649 .168 .097 r
.42754 .5816 m .42958 .58243 L .43115 .58164 L F
.468 0 0 r
.42958 .58243 m .43313 .58209 L .43115 .58164 L F
.695 .639 .79 r
.70756 .44196 m .71127 .44255 L .71005 .43898 L F
.729 .658 .779 r
.71005 .43898 m .71127 .44255 L .71387 .43967 L F
0 .048 .557 r
.75593 .39384 m .75579 .39793 L .75321 .39679 L F
.71 .362 .385 r
.75579 .39793 m .75374 .39981 L .75321 .39679 L F
.75579 .39793 m .75733 .39979 L .75374 .39981 L F
.308 0 .241 r
.2037 .70185 m .20101 .70409 L .20225 .70141 L F
.455 .479 .795 r
.60526 .44724 m .60615 .45005 L .60342 .44832 L F
.569 .711 .938 r
.60615 .45005 m .60415 .45059 L .60342 .44832 L F
.531 .721 .96 r
.78573 .44227 m .78486 .4432 L .78266 .44155 L F
.659 .126 0 r
.78486 .4432 m .78494 .44383 L .78266 .44155 L F
.657 .971 .882 r
.78757 .4408 m .78486 .4432 L .78573 .44227 L F
.518 .304 .529 r
.78757 .4408 m .78494 .44383 L .78486 .4432 L F
.179 .688 .901 r
.39244 .63345 m .39127 .63301 L .38863 .63299 L F
.93 .941 .783 r
.39298 .62963 m .39244 .63345 L .39549 .63324 L F
.39298 .62963 m .39127 .63301 L .39244 .63345 L F
.149 .691 .733 r
.23447 .54055 m .23673 .54016 L .23857 .53991 L F
.318 0 0 r
.23857 .53991 m .23673 .54016 L .24054 .5403 L F
.129 0 0 r
.40677 .58616 m .40792 .58652 L .40935 .58468 L F
.075 0 0 r
.40935 .58468 m .40792 .58652 L .41114 .58451 L F
.513 .428 .697 r
.42217 .6223 m .41707 .62175 L .42045 .61892 L F
.42217 .6223 m .41813 .62388 L .41707 .62175 L F
.052 0 .093 r
.4144 .57928 m .41626 .57871 L .4169 .57646 L F
0 0 0 r
.4169 .57646 m .41855 .57551 L .41996 .57432 L F
0 0 .066 r
.4169 .57646 m .41774 .57752 L .41855 .57551 L F
.4169 .57646 m .41626 .57871 L .41774 .57752 L F
.696 .982 .836 r
.21959 .62629 m .21587 .62842 L .21794 .62861 L F
0 0 0 r
.21959 .62629 m .22067 .62634 L .22241 .62434 L F
0 0 .046 r
.21998 .62793 m .21959 .62629 L .21794 .62861 L F
.21998 .62793 m .22067 .62634 L .21959 .62629 L F
.747 .411 .413 r
.74268 .38762 m .74212 .38519 L .73872 .385 L F
.742 .577 .67 r
.74268 .38762 m .7443 .38428 L .74212 .38519 L F
0 0 0 r
.55248 .50385 m .54942 .50629 L .5506 .50484 L F
.722 .71 .838 r
.70011 .43815 m .70409 .43881 L .70288 .43601 L F
.615 .71 .913 r
.70288 .43601 m .70409 .43881 L .70622 .43813 L F
.786 .57 .608 r
.49568 .59378 m .49438 .59479 L .49492 .59383 L F
.49568 .59378 m .49569 .59732 L .492 .59665 L F
.564 .761 .97 r
.49806 .5936 m .49568 .59378 L .49831 .59384 L F
.91 .975 .691 r
.49568 .59378 m .49675 .5905 L .49831 .59384 L F
.49568 .59378 m .49492 .59383 L .49675 .5905 L F
.483 .274 .519 r
.49492 .59383 m .49683 .59571 L .49585 .59215 L F
.764 .896 .496 r
.49675 .5905 m .49492 .59383 L .49575 .59179 L F
.483 .274 .519 r
.49492 .59383 m .49585 .59215 L .49575 .59179 L F
.786 .57 .608 r
.49438 .59479 m .492 .59665 L .49492 .59383 L F
.684 .979 .84 r
.51784 .5184 m .51855 .51854 L .51676 .52002 L F
.533 .805 .996 r
.51784 .5184 m .51676 .52002 L .51541 .51893 L F
.51784 .5184 m .51676 .52002 L .51541 .51893 L F
.97 .651 .316 r
.76301 .41088 m .76402 .41021 L .76326 .4088 L F
.76301 .41088 m .76427 .41227 L .76402 .41021 L F
.665 .514 .67 r
.42766 .61687 m .42559 .61519 L .42913 .61583 L F
.253 .299 .717 r
.42995 .61546 m .43121 .61748 L .42913 .61583 L F
.64 .211 .212 r
.42913 .61583 m .43121 .61748 L .42766 .61687 L F
.521 .283 .494 r
.43288 .64819 m .43296 .65058 L .43528 .64782 L F
.001 0 .3 r
.60732 .42643 m .60757 .42872 L .60758 .42651 L F
.60732 .42643 m .6058 .43046 L .60757 .42872 L F
.788 .714 .783 r
.74047 .42316 m .74206 .4253 L .73833 .42465 L F
.287 .568 .934 r
.74174 .42697 m .73833 .42465 L .74206 .4253 L F
.506 .616 .895 r
.74289 .42423 m .74206 .4253 L .74047 .42316 L F
0 0 .242 r
.74174 .42697 m .74206 .4253 L .74289 .42423 L F
.497 .584 .873 r
.67 .40063 m .67242 .40407 L .67371 .39923 L F
.513 .011 .001 r
.6727 .39758 m .67166 .39882 L .67541 .39866 L F
0 0 .167 r
.67166 .39882 m .67162 .3983 L .67291 .39899 L F
.756 .704 .803 r
.67371 .39923 m .67046 .4049 L .66965 .40121 L F
.638 .416 .565 r
.67371 .39923 m .66986 .39962 L .67 .40063 L F
.67371 .39923 m .67166 .39882 L .66986 .39962 L F
.67371 .39923 m .66965 .40121 L .67166 .39882 L F
.47 0 0 r
.67166 .39882 m .67451 .39985 L .67541 .39866 L F
0 0 .167 r
.67321 .39938 m .67291 .39899 L .67451 .39985 L F
.67166 .39882 m .67291 .39899 L .67321 .39938 L F
.981 .881 .657 r
.67242 .40407 m .67046 .4049 L .67345 .39969 L F
.67355 .39982 m .67345 .39969 L .67371 .39923 L F
.67242 .40407 m .67345 .39969 L .67355 .39982 L F
.67242 .40407 m .67118 .40647 L .67046 .4049 L F
0 0 0 r
.66986 .39962 m .6727 .39758 L .67031 .3974 L F
0 .023 .583 r
.53835 .55311 m .53787 .55318 L .53774 .55136 L F
.599 .656 .877 r
.53966 .55154 m .53901 .55449 L .53835 .55311 L F
.53966 .55154 m .54181 .55383 L .53901 .55449 L F
0 .072 .63 r
.53835 .55311 m .54026 .55597 L .53899 .55246 L F
.53835 .55311 m .53899 .55246 L .53866 .55292 L F
0 .023 .583 r
.53835 .55311 m .53901 .55449 L .538 .55333 L F
.368 .387 .749 r
.53676 .55656 m .53835 .55311 L .53546 .55472 L F
.53676 .55656 m .53896 .55773 L .53835 .55311 L F
.139 .209 .674 r
.53835 .55311 m .53896 .55773 L .54026 .55597 L F
0 .072 .63 r
.53835 .55311 m .53866 .55292 L .53671 .55561 L F
0 .023 .583 r
.53835 .55311 m .538 .55333 L .53787 .55318 L F
.131 .589 .923 r
.75044 .43557 m .75293 .43616 L .7495 .43471 L F
.89 .896 .827 r
.50909 .58431 m .5064 .58827 L .50554 .58768 L F
0 0 0 r
.54295 .49895 m .54401 .49947 L .5449 .49799 L F
.54295 .49895 m .54232 .50084 L .54401 .49947 L F
.535 .143 .245 r
.68749 .40672 m .69138 .40584 L .69017 .40798 L F
.637 .297 .379 r
.69374 .40593 m .69017 .40798 L .69138 .40584 L F
.623 .808 .971 r
.72516 .38477 m .72394 .38769 L .72272 .38612 L F
.72516 .38477 m .72646 .38686 L .72394 .38769 L F
0 0 .497 r
.49051 .57439 m .49176 .57665 L .4917 .57597 L F
.557 .373 .587 r
.49176 .57665 m .49316 .57739 L .4917 .57597 L F
.49176 .57665 m .49437 .57861 L .49316 .57739 L F
.49176 .57665 m .49184 .5792 L .49437 .57861 L F
.454 .378 .681 r
.60537 .43241 m .60757 .42872 L .6058 .43046 L F
.623 .794 .964 r
.17162 .62902 m .17116 .63121 L .1699 .62979 L F
.17162 .62902 m .17345 .63045 L .17116 .63121 L F
.701 .907 .968 r
.73833 .42465 m .73518 .4265 L .73427 .4254 L F
.602 .821 .984 r
.17637 .65508 m .17634 .65307 L .1756 .65392 L F
.17637 .65508 m .17661 .65303 L .17634 .65307 L F
.17637 .65508 m .17828 .65413 L .17661 .65303 L F
.617 .878 .99 r
.64382 .41048 m .64237 .41247 L .64522 .41148 L F
.478 .285 .54 r
.6442 .41326 m .64237 .41247 L .64382 .41048 L F
.6442 .41326 m .64242 .41484 L .64237 .41247 L F
.64237 .41247 m .64242 .41484 L .6442 .41326 L F
.628 .367 .504 r
.57155 .48628 m .56762 .48885 L .56857 .48677 L F
.289 .777 .906 r
.17548 .56019 m .17755 .56048 L .17951 .56004 L F
.427 .066 .247 r
.464 .5916 m .46295 .59376 L .46057 .59437 L F
.491 .159 .332 r
.46543 .59188 m .46295 .59376 L .464 .5916 L F
.863 .763 .751 r
.48438 .57578 m .48665 .57677 L .48777 .57441 L F
.48438 .57578 m .48777 .57441 L .48651 .57569 L F
.278 .772 .719 r
.49051 .57439 m .48651 .57569 L .48777 .57441 L F
.408 0 .032 r
.18356 .5583 m .18163 .55995 L .17951 .56004 L F
.343 0 .019 r
.18578 .55774 m .18163 .55995 L .18356 .5583 L F
.053 0 .096 r
.4144 .57928 m .41375 .58152 L .41626 .57871 L F
.437 .082 .264 r
.62024 .41164 m .62274 .41127 L .62317 .40968 L F
.518 .218 .397 r
.62274 .41127 m .62562 .40903 L .62317 .40968 L F
.16 0 0 r
.63862 .40162 m .64231 .40021 L .64003 .40122 L F
.915 .795 .714 r
.50319 .53152 m .49952 .53449 L .50195 .53043 L F
.50319 .53152 m .5015 .53576 L .49952 .53449 L F
.711 .905 .964 r
.50319 .53152 m .50452 .52963 L .50484 .52801 L F
.50319 .53152 m .50195 .53043 L .50452 .52963 L F
.8 .522 .517 r
.50726 .53501 m .50383 .53457 L .50319 .53152 L F
.681 .618 .779 r
.70622 .43813 m .70756 .44196 L .71005 .43898 L F
.905 .948 .597 r
.43552 .59029 m .4342 .59288 L .4356 .59145 L F
.412 .561 .893 r
.25261 .56402 m .25272 .56499 L .254 .56346 L F
.017 .172 .682 r
.25272 .56499 m .25428 .56598 L .254 .56346 L F
.25272 .56499 m .25458 .56686 L .25428 .56598 L F
.047 .178 .679 r
.25368 .56751 m .25458 .56686 L .25272 .56499 L F
.788 .773 .839 r
.53248 .55772 m .53458 .55871 L .5336 .55615 L F
.954 .9 .733 r
.53248 .55772 m .53487 .56081 L .53458 .55871 L F
.747 .753 .857 r
.5336 .55615 m .53458 .55871 L .53676 .55656 L F
.219 .308 .742 r
.78413 .40898 m .78653 .41075 L .78473 .41205 L F
.17 0 .063 r
.78729 .41208 m .78473 .41205 L .78653 .41075 L F
.78729 .41208 m .78454 .41373 L .78473 .41205 L F
.301 .788 .898 r
.19414 .54026 m .19629 .53987 L .19802 .54 L F
.182 0 0 r
.19629 .53987 m .20022 .54037 L .19802 .54 L F
.552 .912 .96 r
.77872 .4287 m .77676 .42977 L .77591 .43036 L F
.515 .234 .427 r
.46221 .57093 m .46242 .5731 L .45985 .57356 L F
.546 .257 .427 r
.46471 .57254 m .46242 .5731 L .46221 .57093 L F
.364 0 .085 r
.4766 .60676 m .47587 .6079 L .47337 .60824 L F
.179 0 0 r
.47885 .60637 m .47587 .6079 L .4766 .60676 L F
.527 .36 .598 r
.47881 .60324 m .47885 .60637 L .4766 .60676 L F
.45 .222 .476 r
.5939 .44795 m .59622 .44734 L .59528 .44551 L F
.47 .294 .56 r
.59528 .44551 m .59914 .44662 L .59933 .44047 L F
0 0 0 r
.59622 .44734 m .59914 .44662 L .59528 .44551 L F
0 .239 .753 r
.49102 .56444 m .4932 .5663 L .49281 .56781 L F
.173 .482 .898 r
.4932 .5663 m .49551 .56898 L .49281 .56781 L F
.645 .421 .564 r
.19942 .69383 m .20224 .69248 L .20033 .69206 L F
.734 .638 .751 r
.51353 .53491 m .51726 .53544 L .51565 .53147 L F
.342 .1 .396 r
.51353 .53491 m .51589 .5343 L .51726 .53544 L F
.688 .615 .769 r
.51565 .53147 m .51726 .53544 L .51858 .53389 L F
.845 .908 .879 r
.51858 .53389 m .51726 .53544 L .51589 .5343 L F
.313 0 0 r
.70981 .39927 m .71077 .39846 L .71312 .39878 L F
.185 .461 .883 r
.72451 .42129 m .72714 .42248 L .72626 .42373 L F
.803 .743 .797 r
.72714 .42248 m .72873 .42627 L .72626 .42373 L F
0 0 .339 r
.56613 .58389 m .56643 .58484 L .56527 .58566 L F
.427 .839 .969 r
.56527 .58566 m .56643 .58484 L .568 .58523 L F
.403 .501 .845 r
.5681 .58729 m .56527 .58566 L .568 .58523 L F
.459 0 0 r
.6727 .39758 m .67541 .39866 L .67636 .39803 L F
.716 .188 0 r
.67541 .39866 m .67862 .40008 L .67636 .39803 L F
.723 .283 .207 r
.67636 .39803 m .67862 .40008 L .68018 .39975 L F
.552 .586 .842 r
.18298 .63295 m .18094 .63348 L .1793 .63036 L F
.378 .351 .702 r
.38286 .61821 m .38329 .62176 L .38476 .61999 L F
.496 .521 .812 r
.38329 .62176 m .38554 .62166 L .38476 .61999 L F
.605 .823 .984 r
.54137 .60804 m .54251 .60962 L .54453 .60862 L F
0 .154 .685 r
.78147 .39728 m .78254 .39884 L .78271 .40063 L F
.527 .444 .705 r
.78602 .40158 m .7855 .40474 L .78519 .40212 L F
.296 .439 .836 r
.78394 .39744 m .786 .40169 L .78254 .39884 L F
.485 .552 .85 r
.78759 .40057 m .786 .40169 L .78394 .39744 L F
.575 .759 .965 r
.78759 .40057 m .78519 .40212 L .786 .40169 L F
.527 .444 .705 r
.78759 .40057 m .78702 .40171 L .78602 .40158 L F
.78702 .40171 m .7855 .40474 L .78602 .40158 L F
.395 .283 .608 r
.78584 .40156 m .78271 .40063 L .78254 .39884 L F
.786 .40169 m .78541 .4015 L .78584 .40156 L F
.78541 .4015 m .78271 .40063 L .78584 .40156 L F
.786 .40169 m .78519 .40212 L .78271 .40063 L F
.307 .309 .698 r
.78271 .40063 m .78519 .40212 L .7837 .40319 L F
.84 .852 .854 r
.69597 .43283 m .6973 .42874 L .69851 .42998 L F
.69597 .43283 m .69453 .43342 L .6973 .42874 L F
.096 0 .346 r
.58967 .45417 m .59081 .4538 L .59124 .45084 L F
.21 .27 .707 r
.58967 .45417 m .5919 .45622 L .59081 .4538 L F
.438 .291 .583 r
.58967 .45417 m .58976 .45717 L .5919 .45622 L F
.816 .396 .249 r
.53883 .60673 m .53738 .60802 L .53591 .60585 L F
.712 .426 .491 r
.54204 .60602 m .53738 .60802 L .53883 .60673 L F
.999 .818 .479 r
.76287 .41891 m .76399 .41796 L .76328 .4169 L F
.76287 .41891 m .76371 .41988 L .76399 .41796 L F
.813 .769 .812 r
.61015 .44843 m .60615 .45005 L .60877 .4471 L F
.398 .159 .431 r
.24536 .63018 m .24493 .63261 L .24287 .63319 L F
.383 .157 .443 r
.24778 .62717 m .24736 .6296 L .24536 .63018 L F
.41 .182 .454 r
.24736 .6296 m .24493 .63261 L .24536 .63018 L F
.752 .606 .696 r
.45647 .57026 m .45265 .57288 L .45301 .57035 L F
.726 .627 .747 r
.42984 .57678 m .42732 .57913 L .42626 .57657 L F
.504 .834 .539 r
.42984 .57678 m .42809 .57836 L .42732 .57913 L F
.949 .628 .387 r
.42587 .57954 m .42732 .57913 L .42809 .57836 L F
.42587 .57954 m .42754 .5816 L .42732 .57913 L F
.327 .094 .4 r
.25272 .62126 m .25226 .6236 L .25032 .62428 L F
.433 .221 .489 r
.25226 .6236 m .24985 .62657 L .25032 .62428 L F
.498 .627 .908 r
.46079 .58528 m .46254 .58786 L .46004 .58757 L F
.889 .923 .839 r
.67962 .43998 m .67773 .4426 L .67668 .44136 L F
.991 .862 .607 r
.67668 .44136 m .67773 .4426 L .67701 .44487 L F
.589 .727 .939 r
.49906 .57004 m .49665 .57064 L .49551 .56898 L F
.44 .433 .755 r
.2266 .6157 m .22745 .61844 L .2291 .61775 L F
.519 .348 .589 r
.22695 .62079 m .2291 .61775 L .22745 .61844 L F
.882 .825 .786 r
.59595 .48645 m .59626 .4895 L .59388 .48961 L F
.867 .916 .86 r
.59626 .4895 m .59268 .4911 L .59388 .48961 L F
.575 .798 .984 r
.1793 .63036 m .17734 .63098 L .1755 .62972 L F
.582 .826 .991 r
.42282 .58143 m .42477 .58278 L .42333 .57913 L F
.376 0 .018 r
.42327 .58349 m .42318 .58442 L .42477 .58278 L F
.653 .301 .364 r
.42301 .58577 m .42624 .582 L .42318 .58442 L F
.547 .522 .779 r
.42395 .58258 m .42308 .58553 L .42318 .58442 L F
.42308 .58553 m .42301 .58577 L .42318 .58442 L F
.376 0 .018 r
.42085 .58465 m .42318 .58442 L .42327 .58349 L F
.122 0 .173 r
.43274 .63356 m .43388 .6334 L .43527 .63049 L F
.618 .324 .448 r
.43527 .63049 m .43795 .6324 L .43826 .62985 L F
.43527 .63049 m .43388 .6334 L .43795 .6324 L F
.105 .164 .641 r
.52774 .58512 m .52815 .58887 L .52936 .58709 L F
.766 .65 .092 r
.52929 .5908 m .52936 .58709 L .52815 .58887 L F
.75 .574 .657 r
.46666 .60879 m .47112 .60946 L .47093 .60563 L F
.57 .465 .695 r
.47112 .60946 m .47257 .60599 L .47093 .60563 L F
.752 .61 .7 r
.58587 .48113 m .58243 .47816 L .58531 .47872 L F
.58587 .48113 m .58236 .48129 L .58243 .47816 L F
.294 0 0 r
.58587 .48113 m .58205 .48262 L .58236 .48129 L F
.58587 .48113 m .58466 .48236 L .58205 .48262 L F
.527 .498 .767 r
.58826 .48023 m .58587 .48113 L .58531 .47872 L F
.508 0 0 r
.58818 .48238 m .58587 .48113 L .58826 .48023 L F
.58818 .48238 m .58466 .48236 L .58587 .48113 L F
.448 .231 .49 r
.25368 .56751 m .25539 .56946 L .25458 .56686 L F
.25368 .56751 m .25326 .57008 L .25539 .56946 L F
.551 0 0 r
.64231 .40021 m .64481 .40163 L .64538 .40089 L F
.755 .238 0 r
.64538 .40089 m .64481 .40163 L .64639 .40224 L F
.701 .548 .677 r
.43233 .58872 m .42971 .59148 L .42953 .58891 L F
.421 .158 .406 r
.25942 .61705 m .25781 .61545 L .2597 .61472 L F
.25942 .61705 m .25724 .61769 L .25781 .61545 L F
0 0 .018 r
.41347 .63838 m .41285 .63886 L .4125 .63915 L F
.874 .472 .017 r
.78346 .42246 m .78468 .42384 L .78461 .42369 L F
.78346 .42246 m .78461 .42369 L .78369 .42168 L F
0 0 0 r
.78346 .42246 m .78369 .42168 L .78543 .41971 L F
.878 .895 .84 r
.78229 .42122 m .78346 .42246 L .78543 .41971 L F
.78223 .42125 m .78346 .42246 L .78229 .42122 L F
0 0 0 r
.23268 .64256 m .23138 .6443 L .22983 .64502 L F
.249 0 .095 r
.23468 .64187 m .23138 .6443 L .23268 .64256 L F
.767 .6 .672 r
.59293 .47223 m .59469 .47549 L .59073 .47497 L F
.729 .554 .654 r
.59469 .47549 m .59041 .47771 L .59073 .47497 L F
.59469 .47549 m .59453 .4779 L .59041 .47771 L F
.129 0 0 r
.40677 .58616 m .40583 .58734 L .40792 .58652 L F
.344 .358 .731 r
.38995 .62384 m .39066 .62761 L .3925 .62613 L F
.295 .273 .664 r
.39066 .62761 m .39298 .62963 L .3925 .62613 L F
0 0 .065 r
.59052 .50398 m .58839 .50789 L .59016 .5065 L F
0 0 0 r
.58839 .50789 m .5888 .50823 L .59016 .5065 L F
.58839 .50789 m .58783 .51001 L .5888 .50823 L F
.854 .752 .238 r
.43192 .57416 m .43244 .57402 L .43395 .57275 L F
.43192 .57416 m .43198 .5759 L .43244 .57402 L F
.751 .623 .717 r
.41998 .64414 m .42391 .64652 L .42178 .64201 L F
.827 .711 .737 r
.41991 .64712 m .42391 .64652 L .41998 .64414 L F
.41991 .64712 m .42329 .64818 L .42391 .64652 L F
.7 .6 .742 r
.42178 .64201 m .42391 .64652 L .42523 .64486 L F
.586 .439 .649 r
.42391 .64652 m .42329 .64818 L .42523 .64486 L F
.378 .689 .98 r
.26878 .54664 m .26761 .54797 L .26595 .54648 L F
.26878 .54664 m .27035 .54815 L .26761 .54797 L F
.068 0 0 r
.15282 .55471 m .15636 .55317 L .15419 .55396 L F
0 0 0 r
.22241 .62434 m .22315 .62364 L .2248 .62132 L F
.384 .071 .306 r
.22067 .62634 m .22315 .62364 L .22241 .62434 L F
.641 .5 .675 r
.46717 .57664 m .46992 .57668 L .46951 .57383 L F
.858 .821 .811 r
.46636 .57896 m .46992 .57668 L .46717 .57664 L F
.421 0 0 r
.45997 .56035 m .46209 .56088 L .46385 .56067 L F
.369 0 0 r
.46385 .56067 m .46209 .56088 L .46587 .56115 L F
0 0 0 r
.41036 .62782 m .4093 .62973 L .41074 .62731 L F
.532 .911 .943 r
.15989 .56973 m .15855 .56965 L .15782 .57061 L F
.581 .943 .841 r
.15782 .57061 m .15855 .56965 L .15628 .57103 L F
0 0 .561 r
.48651 .57569 m .48665 .57677 L .48438 .57578 L F
.48651 .57569 m .48808 .57873 L .48665 .57677 L F
0 0 0 r
.52664 .5134 m .53017 .51101 L .52709 .51301 L F
.088 0 .45 r
.19954 .70983 m .19833 .7114 L .19913 .70755 L F
.72 .476 .556 r
.19954 .70983 m .19625 .7123 L .19833 .7114 L F
.277 .211 .6 r
.5561 .57036 m .55756 .56974 L .55699 .56765 L F
.243 .143 .536 r
.55581 .57373 m .55756 .56974 L .5561 .57036 L F
.312 .05 .347 r
.24493 .63261 m .24239 .63553 L .24287 .63319 L F
.132 0 0 r
.17129 .54684 m .17138 .54796 L .17321 .546 L F
.17129 .54684 m .16927 .54853 L .17138 .54796 L F
.521 .265 .467 r
.69737 .39677 m .69999 .3942 L .69748 .39477 L F
.402 .818 .973 r
.24054 .5403 m .24269 .53989 L .24454 .5404 L F
.125 .645 .885 r
.24269 .53989 m .24643 .54054 L .24454 .5404 L F
.153 .263 .725 r
.52564 .57942 m .52658 .58293 L .52699 .58168 L F
0 0 .552 r
.52774 .58512 m .52699 .58168 L .52658 .58293 L F
.36 .382 .749 r
.56521 .57813 m .56358 .58043 L .56272 .57879 L F
.56521 .57813 m .56613 .58389 L .56358 .58043 L F
.12 0 .009 r
.58159 .46253 m .58389 .46165 L .58438 .46022 L F
0 0 0 r
.58389 .46165 m .58671 .45946 L .58438 .46022 L F
.92 .534 .248 r
.41991 .64712 m .42287 .65115 L .42329 .64818 L F
.768 .621 .697 r
.42287 .65115 m .4269 .64848 L .42329 .64818 L F
.116 0 .123 r
.27143 .59422 m .27065 .59628 L .26907 .59697 L F
.248 .076 .441 r
.27365 .59078 m .27333 .59352 L .27143 .59422 L F
.535 .322 .537 r
.27333 .59352 m .27065 .59628 L .27143 .59422 L F
.92 .969 .779 r
.56074 .57887 m .55817 .58239 L .55924 .57783 L F
.538 .127 .21 r
.68754 .40792 m .68749 .40672 L .69017 .40798 L F
0 0 0 r
.41996 .57432 m .42038 .57453 L .42195 .57295 L F
.41996 .57432 m .41855 .57551 L .42038 .57453 L F
.47941 .56438 m .48177 .56384 L .48318 .56334 L F
.491 .899 .793 r
.48318 .56334 m .48424 .56258 L .48576 .56282 L F
.48318 .56334 m .48177 .56384 L .48424 .56258 L F
.206 .167 .59 r
.534 .57019 m .53437 .57262 L .53359 .57315 L F
.215 .182 .604 r
.53437 .57262 m .53451 .57629 L .53359 .57315 L F
0 0 0 r
.20684 .55304 m .20671 .55269 L .20912 .55193 L F
.028 0 0 r
.21083 .55199 m .20916 .55268 L .20684 .55304 L F
.024 0 0 r
.20916 .55268 m .20758 .55281 L .20684 .55304 L F
0 0 0 r
.20684 .55304 m .20563 .55342 L .20671 .55269 L F
.024 0 0 r
.20758 .55281 m .2052 .55299 L .20684 .55304 L F
0 0 0 r
.20684 .55304 m .20475 .55401 L .20563 .55342 L F
0 0 .192 r
.75226 .4035 m .75374 .39981 L .75105 .39981 L F
.599 .914 .662 r
.5346 .5661 m .53322 .56768 L .5347 .56636 L F
0 .004 .581 r
.53459 .56856 m .53322 .56768 L .5346 .5661 L F
.53459 .56856 m .53483 .56987 L .53322 .56768 L F
.095 .145 .624 r
.53322 .56768 m .53483 .56987 L .534 .57019 L F
0 .072 .632 r
.51812 .56436 m .51811 .56345 L .51625 .56133 L F
0 .153 .693 r
.51812 .56436 m .52016 .56642 L .51811 .56345 L F
.786 .869 .91 r
.70138 .42762 m .69851 .42998 L .6973 .42874 L F
.173 0 0 r
.71312 .39878 m .71675 .3973 L .71557 .39834 L F
.41 .791 .991 r
.71675 .3973 m .71774 .39719 L .71873 .39619 L F
.71774 .39719 m .71935 .397 L .71873 .39619 L F
.838 .985 .869 r
.71873 .39619 m .71935 .397 L .72051 .3943 L F
0 0 0 r
.71901 .39592 m .71873 .39619 L .72051 .3943 L F
.71749 .39755 m .71873 .39619 L .71901 .39592 L F
.41 .791 .991 r
.71675 .3973 m .71873 .39619 L .71557 .39834 L F
.538 .099 .152 r
.44653 .5929 m .44879 .59073 L .44683 .59088 L F
.44653 .5929 m .4495 .59293 L .44879 .59073 L F
.2 .045 .434 r
.44879 .59073 m .45169 .58766 L .45088 .58799 L F
.44879 .59073 m .45197 .58965 L .45169 .58766 L F
.335 0 .216 r
.44879 .59073 m .45197 .5921 L .45197 .58965 L F
.44879 .59073 m .4495 .59293 L .45197 .5921 L F
.462 .299 .573 r
.26907 .59697 m .26879 .59969 L .26681 .60018 L F
.455 .243 .501 r
.26866 .60219 m .26681 .60018 L .26879 .59969 L F
.26866 .60219 m .26646 .60299 L .26681 .60018 L F
.394 .184 .473 r
.23124 .60894 m .23342 .61137 L .23344 .60828 L F
.23124 .60894 m .23102 .6123 L .23342 .61137 L F
.633 .638 .837 r
.48092 .59967 m .48125 .60271 L .47881 .60324 L F
.632 .443 .609 r
.48237 .60434 m .47881 .60324 L .48125 .60271 L F
.48237 .60434 m .47885 .60637 L .47881 .60324 L F
.445 0 0 r
.24462 .5558 m .24304 .55566 L .24094 .55478 L F
.644 .097 0 r
.24644 .55712 m .24304 .55566 L .24462 .5558 L F
.171 0 .027 r
.22315 .62364 m .22695 .62079 L .2248 .62132 L F
.42 .19 .457 r
.24985 .62657 m .24736 .6296 L .24778 .62717 L F
.725 .852 .942 r
.44122 .63026 m .43826 .62985 L .439 .62975 L F
.55 .371 .591 r
.44877 .65364 m .44639 .65669 L .44644 .65413 L F
.44877 .65364 m .44639 .65669 L .44644 .65413 L F
.785 .932 .929 r
.44767 .56395 m .45099 .5631 L .45007 .56311 L F
.249 0 0 r
.4534 .56374 m .45007 .56311 L .45099 .5631 L F
.48 .61 .903 r
.27255 .54795 m .27133 .54999 L .27035 .54815 L F
.446 .565 .881 r
.27255 .54795 m .27429 .55117 L .27133 .54999 L F
.923 .966 .666 r
.60286 .5041 m .60485 .50192 L .60428 .5006 L F
.60286 .5041 m .60331 .50481 L .60485 .50192 L F
.983 .777 .551 r
.59251 .49606 m .59075 .49737 L .5911 .49489 L F
.59251 .49606 m .59208 .49844 L .59075 .49737 L F
.763 .678 .768 r
.52886 .54548 m .53176 .54671 L .53443 .54338 L F
.725 .201 0 r
.53202 .54801 m .53176 .54671 L .52886 .54548 L F
.53202 .54801 m .53361 .54888 L .53176 .54671 L F
.699 .579 .718 r
.53176 .54671 m .53541 .54676 L .53443 .54338 L F
.656 .328 .406 r
.53361 .54888 m .53541 .54676 L .53176 .54671 L F
.791 .665 .724 r
.43296 .65058 m .437 .65104 L .43528 .64782 L F
.751 .458 .486 r
.43292 .65294 m .437 .65104 L .43296 .65058 L F
.43292 .65294 m .43559 .65366 L .437 .65104 L F
.837 .568 .531 r
.43559 .65366 m .43802 .65414 L .437 .65104 L F
.504 .305 .544 r
.55449 .59349 m .55662 .59358 L .55625 .59061 L F
0 0 0 r
.55662 .59358 m .55933 .59045 L .55625 .59061 L F
.15 .073 .507 r
.24985 .57953 m .25101 .579 L .25128 .57584 L F
.195 .181 .615 r
.24985 .57953 m .25154 .5815 L .25101 .579 L F
.353 .214 .549 r
.24992 .58199 m .25154 .5815 L .24985 .57953 L F
.66 .118 0 r
.41593 .63087 m .41161 .62923 L .41312 .63061 L F
0 .057 .617 r
.65438 .42994 m .65612 .43276 L .65504 .43172 L F
.456 .774 .998 r
.65612 .43276 m .65853 .43249 L .65504 .43172 L F
0 0 0 r
.55738 .49785 m .55586 .49913 L .55842 .49658 L F
.776 .506 .528 r
.52914 .5397 m .53256 .53783 L .53027 .5373 L F
.52914 .5397 m .53301 .54019 L .53256 .53783 L F
.34 .02 .268 r
.19861 .687 m .20087 .68678 L .20143 .68481 L F
.473 0 0 r
.20445 .68715 m .20394 .68736 L .20087 .68678 L F
.724 .381 .398 r
.20087 .68678 m .20394 .68736 L .20143 .68481 L F
.77 .27 .021 r
.20143 .68481 m .20394 .68736 L .20445 .68715 L F
.088 0 .45 r
.19954 .70983 m .19913 .70755 L .19832 .70756 L F
.554 .323 .519 r
.57687 .53075 m .5744 .5289 L .57426 .53082 L F
.57687 .53075 m .57691 .52846 L .5744 .5289 L F
.056 .611 .818 r
.50726 .53501 m .50576 .53467 L .50383 .53457 L F
.454 .244 .504 r
.25511 .61825 m .25483 .62071 L .25272 .62126 L F
.442 .194 .441 r
.25441 .62303 m .25272 .62126 L .25483 .62071 L F
.25441 .62303 m .25226 .6236 L .25272 .62126 L F
.451 0 0 r
.63629 .41955 m .63645 .41978 L .63504 .41872 L F
.336 .467 .845 r
.63629 .41955 m .63825 .42131 L .63936 .42037 L F
.257 0 0 r
.63629 .41955 m .63936 .42037 L .63645 .41978 L F
.058 0 0 r
.43034 .57763 m .42809 .57836 L .42984 .57678 L F
.512 .354 .603 r
.27861 .57322 m .27648 .57634 L .27647 .57364 L F
.01 .468 .871 r
.41107 .64808 m .41088 .64745 L .40677 .64579 L F
.864 .771 .267 r
.41107 .64808 m .41059 .6478 L .41088 .64745 L F
0 .095 .56 r
.41107 .64808 m .4122 .64896 L .41059 .6478 L F
.587 .018 0 r
.41476 .65044 m .41339 .64994 L .41107 .64808 L F
.636 .198 0 r
.4122 .64896 m .41383 .65151 L .4119 .6487 L F
0 .095 .56 r
.41107 .64808 m .41248 .64921 L .4122 .64896 L F
0 .273 .735 r
.41059 .6478 m .4122 .64896 L .41122 .64795 L F
.636 .198 0 r
.4122 .64896 m .4119 .6487 L .41178 .64852 L F
0 .095 .56 r
.41248 .64921 m .41339 .64994 L .4122 .64896 L F
.179 0 0 r
.44823 .60301 m .44596 .60526 L .44434 .60564 L F
.061 0 0 r
.44912 .60344 m .44823 .60301 L .45073 .60323 L F
.443 0 0 r
.45176 .60402 m .44982 .60373 L .44912 .60344 L F
.44982 .60373 m .44793 .60346 L .44912 .60344 L F
.061 0 0 r
.44912 .60344 m .44596 .60526 L .44819 .60304 L F
.44912 .60344 m .44819 .60304 L .44823 .60301 L F
.155 0 0 r
.4681 .57997 m .46575 .58137 L .4646 .58112 L F
.858 .821 .811 r
.46636 .57896 m .4681 .57997 L .46992 .57668 L F
.936 .73 .598 r
.46636 .57896 m .46575 .58137 L .4681 .57997 L F
.916 .623 .474 r
.74493 .4265 m .74751 .42746 L .74759 .42966 L F
.337 .153 .478 r
.58377 .54359 m .5864 .54032 L .58626 .5427 L F
.353 .186 .511 r
.58368 .54622 m .58377 .54359 L .58626 .5427 L F
.801 .831 .874 r
.68368 .44536 m .68691 .44538 L .68551 .44395 L F
.469 .084 .225 r
.50642 .59613 m .50411 .59674 L .50552 .59471 L F
0 0 0 r
.66266 .42564 m .66161 .42723 L .66287 .42407 L F
.66266 .42564 m .66287 .42407 L .66406 .41974 L F
.321 .122 .447 r
.1736 .54348 m .17321 .546 L .17506 .54519 L F
.438 .294 .587 r
.26646 .60299 m .26452 .60613 L .26435 .60361 L F
0 0 .27 r
.58484 .51671 m .58539 .518 L .58616 .51589 L F
.58484 .51671 m .58489 .51907 L .58539 .518 L F
.753 .979 .917 r
.63679 .41301 m .6355 .41553 L .63778 .41545 L F
.492 .608 .896 r
.63284 .41512 m .63601 .41436 L .6355 .41553 L F
.63601 .41436 m .63656 .41423 L .6355 .41553 L F
.347 0 0 r
.6355 .41553 m .63487 .41526 L .63284 .41512 L F
.753 .979 .917 r
.63638 .4138 m .63601 .41436 L .6355 .41553 L F
.388 .543 .888 r
.63656 .41423 m .63778 .41545 L .6355 .41553 L F
.492 .608 .896 r
.63601 .41436 m .63618 .41535 L .63656 .41423 L F
.63284 .41512 m .63539 .4153 L .63601 .41436 L F
.753 .979 .917 r
.63601 .41436 m .63529 .41545 L .6355 .41553 L F
.492 .608 .896 r
.63539 .4153 m .63618 .41535 L .63601 .41436 L F
.347 0 0 r
.6355 .41553 m .63529 .41545 L .63487 .41526 L F
.63487 .41526 m .63219 .41413 L .63284 .41512 L F
.63474 .41525 m .63402 .41499 L .63487 .41526 L F
.492 .608 .896 r
.63284 .41512 m .63412 .41721 L .63539 .4153 L F
.347 0 0 r
.63529 .41545 m .63474 .41525 L .63487 .41526 L F
.753 .979 .917 r
.63652 .4132 m .63402 .41499 L .63529 .41545 L F
.63652 .4132 m .63529 .41545 L .63601 .41436 L F
.347 0 0 r
.63487 .41526 m .63402 .41499 L .63219 .41413 L F
.492 .608 .896 r
.63539 .4153 m .63537 .41549 L .63618 .41535 L F
.63537 .41549 m .63504 .41872 L .63603 .41579 L F
.63537 .41549 m .63603 .41579 L .63618 .41535 L F
.63412 .41721 m .63504 .41872 L .63539 .4153 L F
.753 .979 .917 r
.63679 .41301 m .63652 .4132 L .63601 .41436 L F
.63679 .41301 m .63601 .41436 L .63638 .4138 L F
.023 .082 .585 r
.63504 .41872 m .63645 .41978 L .63656 .41423 L F
.204 0 0 r
.68164 .40714 m .68274 .40781 L .68023 .40704 L F
.68164 .40714 m .6836 .40682 L .68274 .40781 L F
.171 0 0 r
.709 .39088 m .70559 .39312 L .70817 .3925 L F
.097 0 0 r
.7115 .39008 m .709 .39088 L .71108 .39055 L F
.127 0 0 r
.71108 .39055 m .709 .39088 L .70817 .3925 L F
.548 .435 .676 r
.2266 .6157 m .2291 .61775 L .22834 .61529 L F
.752 .606 .696 r
.45647 .57026 m .45631 .57341 L .45265 .57288 L F
.378 .351 .702 r
.38286 .61821 m .38476 .61999 L .38452 .6176 L F
.659 .47 .617 r
.57682 .5528 m .57687 .55528 L .57355 .55543 L F
.583 .391 .587 r
.57933 .55238 m .57687 .55528 L .57682 .5528 L F
.054 0 .035 r
.4042 .58858 m .40143 .59128 L .40322 .5902 L F
.2 0 .241 r
.40322 .5902 m .40583 .58734 L .4042 .58858 L F
.136 0 .17 r
.56024 .4948 m .55738 .49785 L .55842 .49658 L F
0 .471 .764 r
.41476 .65044 m .41683 .65095 L .41339 .64994 L F
.412 .821 .977 r
.20012 .63789 m .19631 .63786 L .1992 .63688 L F
.663 .865 .976 r
.20121 .63596 m .20012 .63789 L .1992 .63688 L F
.20121 .63596 m .20327 .63688 L .20012 .63789 L F
.76 .754 .847 r
.6322 .43467 m .62819 .43519 L .63077 .434 L F
.121 .637 .89 r
.63077 .434 m .63357 .43469 L .6322 .43467 L F
.717 .779 .901 r
.73505 .38459 m .73872 .385 L .73614 .38627 L F
.616 .655 .865 r
.72284 .39714 m .72422 .39321 L .72152 .39564 L F
.72284 .39714 m .72542 .39641 L .72422 .39321 L F
.398 .64 .953 r
.24833 .5586 m .2483 .55626 L .24644 .55712 L F
.24833 .5586 m .25023 .55838 L .2483 .55626 L F
.952 .847 .701 r
.76242 .42608 m .76306 .42963 L .7637 .42734 L F
.76242 .42608 m .76097 .42945 L .76306 .42963 L F
.918 .824 .738 r
.7599 .43143 m .76306 .42963 L .76097 .42945 L F
.7599 .43143 m .76118 .43266 L .76306 .42963 L F
.124 0 .092 r
.22983 .64502 m .22896 .64728 L .22692 .6479 L F
0 0 0 r
.2301 .6463 m .22983 .64502 L .23138 .6443 L F
.2301 .6463 m .22896 .64728 L .22983 .64502 L F
.336 0 .139 r
.43274 .63356 m .43381 .63488 L .43388 .6334 L F
.43274 .63356 m .43167 .63538 L .43381 .63488 L F
.768 .621 .697 r
.42287 .65115 m .42691 .65157 L .4269 .64848 L F
.291 .786 .759 r
.71784 .38848 m .71404 .38949 L .71641 .38895 L F
.638 .966 .869 r
.72173 .38564 m .72019 .38741 L .71961 .38713 L F
0 0 0 r
.72173 .38564 m .71961 .38713 L .7193 .38764 L F
.352 .814 .714 r
.72019 .38741 m .71784 .38848 L .71721 .38869 L F
0 0 0 r
.72 .38728 m .7193 .38764 L .71885 .38838 L F
.72173 .38564 m .7193 .38764 L .72 .38728 L F
.352 .814 .714 r
.71789 .38834 m .71721 .38869 L .71641 .38895 L F
.72019 .38741 m .71721 .38869 L .71789 .38834 L F
.345 .823 .806 r
.17127 .56237 m .16934 .56308 L .17192 .56258 L F
.168 0 0 r
.17104 .56269 m .16934 .56308 L .17127 .56237 L F
.172 .704 .715 r
.17192 .56258 m .16934 .56308 L .16795 .5634 L F
.168 0 0 r
.16967 .5646 m .16934 .56308 L .17104 .56269 L F
.172 .704 .715 r
.16795 .5634 m .16934 .56308 L .16717 .56356 L F
.345 .823 .806 r
.17127 .56237 m .17192 .56258 L .17354 .56111 L F
.645 .74 .919 r
.19249 .72469 m .19195 .72746 L .19016 .72702 L F
.19249 .72469 m .19361 .72599 L .19195 .72746 L F
.559 .24 .384 r
.47716 .5849 m .47992 .58495 L .48076 .58243 L F
.978 .731 .319 r
.48019 .57848 m .48076 .58243 L .48332 .58224 L F
.551 .232 .381 r
.48076 .58243 m .48185 .58411 L .48332 .58224 L F
.48076 .58243 m .47992 .58495 L .48185 .58411 L F
0 .4 .734 r
.40677 .64579 m .40503 .64505 L .40352 .64454 L F
.332 0 0 r
.40677 .64579 m .40792 .64645 L .40503 .64505 L F
.40677 .64579 m .41088 .64745 L .40792 .64645 L F
.44 .225 .49 r
.25724 .61769 m .25483 .62071 L .25511 .61825 L F
.89 .896 .827 r
.50909 .58431 m .50554 .58768 L .50802 .58456 L F
.46 0 0 r
.50802 .58456 m .51104 .58511 L .50909 .58431 L F
.5 .28 .512 r
.70506 .40089 m .70733 .40255 L .70471 .40247 L F
.70506 .40089 m .70754 .39999 L .70733 .40255 L F
.988 .731 .445 r
.48197 .57988 m .48047 .5778 L .48019 .57848 L F
.629 .873 .523 r
.48332 .58224 m .48434 .58072 L .48197 .57988 L F
.425 0 0 r
.48197 .57988 m .48434 .58072 L .4836 .58065 L F
.978 .731 .319 r
.48096 .5794 m .48332 .58224 L .48197 .57988 L F
.425 0 0 r
.48197 .57988 m .4836 .58065 L .48055 .58036 L F
.978 .731 .319 r
.48019 .57848 m .48096 .5794 L .48197 .57988 L F
0 .146 .682 r
.65564 .41001 m .65695 .41165 L .6552 .40759 L F
.84 .805 .817 r
.543 .54563 m .54291 .54279 L .54167 .54543 L F
.645 .421 .564 r
.19942 .69383 m .20234 .6953 L .20224 .69248 L F
.343 .801 .68 r
.20445 .69273 m .20457 .69272 L .20206 .69381 L F
.2055 .69225 m .20457 .69272 L .20445 .69273 L F
.084 0 0 r
.20457 .69272 m .20614 .69286 L .20469 .69272 L F
.20457 .69272 m .20469 .69272 L .20224 .69248 L F
0 0 .409 r
.20742 .69447 m .20627 .69545 L .20614 .69286 L F
.20742 .69447 m .20614 .69286 L .20457 .69272 L F
.384 .099 .352 r
.43886 .57937 m .44007 .57888 L .4411 .57599 L F
0 0 0 r
.4411 .57599 m .44266 .5749 L .44399 .57346 L F
.189 0 .258 r
.4411 .57599 m .44268 .57753 L .44266 .5749 L F
.4411 .57599 m .44007 .57888 L .44268 .57753 L F
.888 .627 .537 r
.59761 .4833 m .59461 .48289 L .59466 .48038 L F
.892 .719 .661 r
.59761 .4833 m .59595 .48645 L .59461 .48289 L F
.625 .766 .947 r
.72999 .38752 m .72646 .38686 L .73026 .38524 L F
.692 .831 .95 r
.73283 .38594 m .72999 .38752 L .73026 .38524 L F
.086 .406 .858 r
.19361 .72599 m .19597 .72748 L .194 .72699 L F
.956 .867 .458 r
.65221 .41535 m .65121 .41656 L .65155 .4175 L F
.991 .739 .38 r
.65119 .41412 m .65121 .41656 L .65221 .41535 L F
.623 .408 .57 r
.60851 .44211 m .60874 .4446 L .60578 .44434 L F
.705 .64 .782 r
.61061 .44175 m .60851 .44211 L .60723 .43924 L F
.662 .437 .568 r
.61061 .44175 m .60874 .4446 L .60851 .44211 L F
.751 .624 .719 r
.54806 .5654 m .54495 .56464 L .54522 .56616 L F
.7 .6 .742 r
.42178 .64201 m .42523 .64486 L .42437 .64123 L F
.757 .696 .793 r
.42437 .64123 m .42523 .64486 L .42803 .6422 L F
.859 .786 .777 r
.61861 .46503 m .6193 .4682 L .62013 .46625 L F
.517 .369 .619 r
.56043 .54998 m .5628 .54944 L .56247 .54635 L F
.383 .118 .383 r
.56043 .54998 m .56234 .55122 L .5628 .54944 L F
.56043 .54998 m .56012 .55191 L .56234 .55122 L F
.273 .403 .812 r
.53676 .55656 m .53832 .55936 L .53896 .55773 L F
.901 .698 .618 r
.53719 .56145 m .53871 .56175 L .53832 .55936 L F
.612 .792 .968 r
.53832 .55936 m .54068 .5591 L .53896 .55773 L F
0 0 0 r
.52664 .5134 m .52875 .51223 L .53017 .51101 L F
.52875 .51223 m .53189 .50958 L .53017 .51101 L F
.628 .562 .761 r
.46951 .57383 m .47204 .57363 L .47087 .56998 L F
.622 .487 .676 r
.46951 .57383 m .46992 .57668 L .47204 .57363 L F
.784 .44 .404 r
.53254 .56334 m .53608 .56396 L .53487 .56081 L F
.222 .152 .563 r
.53487 .56081 m .53608 .56396 L .53676 .56305 L F
.724 .526 .623 r
.59041 .47771 m .58678 .47488 L .59073 .47497 L F
.59041 .47771 m .58835 .47778 L .58678 .47488 L F
.393 0 0 r
.55077 .57681 m .54679 .57841 L .54976 .57493 L F
.55077 .57681 m .55019 .57813 L .54679 .57841 L F
.409 .306 .625 r
.45261 .58265 m .45465 .58438 L .45509 .58197 L F
.45261 .58265 m .45278 .58521 L .45465 .58438 L F
.465 .199 .426 r
.27611 .58549 m .27547 .58774 L .27322 .58822 L F
.418 .173 .434 r
.27807 .58488 m .27547 .58774 L .27611 .58549 L F
.28 .775 .888 r
.2029 .65397 m .20679 .65378 L .20549 .65354 L F
.399 .847 .919 r
.20549 .65354 m .20679 .65378 L .20889 .6532 L F
.55 .65 .901 r
.73568 .43027 m .73677 .43269 L .73934 .43228 L F
.342 .093 .383 r
.24034 .63607 m .23996 .63895 L .2378 .63907 L F
.316 0 .232 r
.23894 .64067 m .2378 .63907 L .23996 .63895 L F
.23894 .64067 m .23686 .64134 L .2378 .63907 L F
.285 .047 .366 r
.24166 .63794 m .24034 .63607 L .24239 .63553 L F
.24166 .63794 m .23996 .63895 L .24034 .63607 L F
.751 .624 .719 r
.54806 .5654 m .54842 .56246 L .54495 .56464 L F
.213 0 .256 r
.5939 .44795 m .59124 .45084 L .59326 .44977 L F
.283 .081 .42 r
.59124 .45084 m .59329 .45213 L .59326 .44977 L F
.59124 .45084 m .59081 .4538 L .59329 .45213 L F
.44 .315 .613 r
.38297 .60925 m .38503 .60534 L .38271 .60646 L F
.613 .415 .589 r
.56855 .55858 m .56858 .56111 L .5657 .56153 L F
.685 .553 .699 r
.57094 .55561 m .57144 .5586 L .56855 .55858 L F
.663 .392 .5 r
.56855 .55858 m .57117 .56084 L .56858 .56111 L F
.56855 .55858 m .57144 .5586 L .57117 .56084 L F
.974 .721 .489 r
.74513 .38913 m .74592 .3888 L .7443 .38428 L F
.68 .175 .035 r
.74518 .38996 m .74592 .3888 L .74513 .38913 L F
.647 .707 .89 r
.74592 .3888 m .74755 .38603 L .7443 .38428 L F
.74592 .3888 m .74849 .38798 L .74755 .38603 L F
.779 .645 .714 r
.43313 .58209 m .43689 .58243 L .43622 .57991 L F
.248 .733 .926 r
.43427 .5822 m .43582 .58196 L .43689 .58243 L F
.025 .142 .65 r
.43622 .57991 m .43689 .58243 L .4377 .58067 L F
.158 0 .072 r
.43499 .58212 m .4366 .58316 L .43726 .58167 L F
.718 .964 .94 r
.43689 .58243 m .43582 .58196 L .4377 .58067 L F
.158 0 .072 r
.43499 .58212 m .43512 .58205 L .43582 .58196 L F
.43512 .58205 m .4377 .58067 L .43582 .58196 L F
.248 .733 .926 r
.43512 .58205 m .43582 .58196 L .43427 .5822 L F
.43549 .58198 m .43582 .58196 L .43512 .58205 L F
.158 0 .072 r
.43512 .58205 m .43726 .58167 L .4377 .58067 L F
.43499 .58212 m .43726 .58167 L .43512 .58205 L F
.248 .733 .926 r
.43313 .58209 m .43549 .58198 L .43427 .5822 L F
.514 .322 .557 r
.43663 .56997 m .43428 .5705 L .43668 .56747 L F
.399 .187 .471 r
.45253 .65405 m .45457 .65349 L .45488 .65098 L F
.441 .294 .585 r
.45457 .65349 m .45468 .65605 L .45253 .65405 L F
.399 .187 .471 r
.45253 .65405 m .45457 .65349 L .45488 .65098 L F
.441 .294 .585 r
.45457 .65349 m .45468 .65605 L .45253 .65405 L F
.317 0 .249 r
.4214 .61415 m .42114 .61368 L .4244 .61242 L F
0 0 .367 r
.65601 .40325 m .65697 .39905 L .65816 .40012 L F
.65601 .40325 m .65712 .40168 L .65697 .39905 L F
.955 .95 .671 r
.65623 .40577 m .65712 .40168 L .65601 .40325 L F
.679 .739 .896 r
.70494 .42822 m .70138 .42762 L .70386 .42657 L F
.696 .764 .904 r
.70755 .42711 m .70494 .42822 L .70386 .42657 L F
.656 .193 .143 r
.42526 .65294 m .42691 .65157 L .42287 .65115 L F
.525 .036 .037 r
.42904 .65287 m .42691 .65157 L .42526 .65294 L F
.483 .108 .252 r
.42904 .65287 m .42945 .65127 L .42691 .65157 L F
.824 .514 .466 r
.43414 .65719 m .4306 .65855 L .43177 .6567 L F
.43414 .65719 m .43411 .65939 L .4306 .65855 L F
.541 .298 .497 r
.43728 .65657 m .43411 .65939 L .43414 .65719 L F
.189 .719 .741 r
.20118 .54018 m .20241 .53989 L .20403 .53962 L F
.349 0 0 r
.20403 .53962 m .20241 .53989 L .20624 .53998 L F
.482 .84 .994 r
.20241 .53989 m .20449 .53935 L .20624 .53998 L F
0 0 0 r
.20241 .53989 m .20236 .54015 L .2041 .5395 L F
.20241 .53989 m .2041 .5395 L .20449 .53935 L F
.189 .719 .741 r
.20022 .54037 m .20241 .53989 L .20118 .54018 L F
.491 .226 .44 r
.61249 .42078 m .61545 .42036 L .61484 .41764 L F
.425 .257 .548 r
.61484 .41764 m .61645 .41771 L .61752 .41485 L F
.354 .143 .449 r
.61484 .41764 m .61692 .41941 L .61645 .41771 L F
.61484 .41764 m .61545 .42036 L .61692 .41941 L F
.807 .834 .872 r
.62534 .44735 m .62801 .44814 L .62702 .44693 L F
.413 .359 .688 r
.45506 .5995 m .45264 .59768 L .45478 .59688 L F
.45506 .5995 m .45321 .60027 L .45264 .59768 L F
.868 .984 .702 r
.65074 .42402 m .6493 .42496 L .65021 .42476 L F
.65074 .42402 m .65049 .42343 L .6493 .42496 L F
.91 .858 .414 r
.65134 .4196 m .65049 .42343 L .65074 .42402 L F
.763 .678 .768 r
.52886 .54548 m .53443 .54338 L .53285 .54265 L F
.963 .717 .515 r
.53285 .54265 m .53443 .54338 L .53301 .54019 L F
.75 .614 .708 r
.45631 .57341 m .45391 .57654 L .45265 .57288 L F
.61 .419 .598 r
.45631 .57341 m .45637 .57649 L .45391 .57654 L F
.569 .325 .506 r
.45985 .57356 m .45637 .57649 L .45631 .57341 L F
.889 .923 .839 r
.67962 .43998 m .67668 .44136 L .67839 .43856 L F
.738 .838 .926 r
.68184 .43868 m .67962 .43998 L .67839 .43856 L F
.562 .65 .894 r
.19064 .63642 m .18724 .63476 L .1892 .63444 L F
.556 .668 .912 r
.19275 .63595 m .19064 .63642 L .1892 .63444 L F
.463 .673 .955 r
.47688 .5594 m .47585 .56126 L .47436 .55795 L F
.47688 .5594 m .47806 .56105 L .47585 .56126 L F
.041 0 .064 r
.21485 .67511 m .21385 .67735 L .21219 .67794 L F
.032 0 .059 r
.21606 .67493 m .21385 .67735 L .21485 .67511 L F
.745 .688 .796 r
.72097 .43278 m .7246 .43341 L .72337 .42998 L F
.721 .675 .805 r
.72337 .42998 m .7246 .43341 L .72689 .43252 L F
.295 .03 .331 r
.23577 .60562 m .23805 .6028 L .2361 .60317 L F
.889 .769 .723 r
.53719 .56145 m .53698 .56328 L .53871 .56175 L F
.705 .64 .782 r
.61061 .44175 m .60723 .43924 L .61009 .43848 L F
.489 .621 .908 r
.39298 .62963 m .39549 .63324 L .39702 .63241 L F
.391 .465 .816 r
.39549 .63324 m .39808 .63587 L .39702 .63241 L F
.303 .163 .519 r
.4495 .56922 m .45116 .56654 L .44942 .56758 L F
.906 .835 .764 r
.21982 .6502 m .22321 .64916 L .22183 .64992 L F
.005 0 0 r
.22367 .64931 m .22321 .64916 L .22591 .64983 L F
.345 0 .06 r
.22692 .6479 m .22647 .64967 L .22321 .64916 L F
0 0 0 r
.22789 .64951 m .22685 .65005 L .22591 .64983 L F
.345 0 .06 r
.22647 .64967 m .2264 .64995 L .22591 .64983 L F
.22647 .64967 m .22591 .64983 L .22321 .64916 L F
.423 0 .079 r
.22789 .64951 m .2264 .64995 L .22647 .64967 L F
.22789 .64951 m .22647 .64967 L .22692 .6479 L F
0 0 0 r
.22715 .64947 m .22647 .64967 L .22367 .64931 L F
.22647 .64967 m .22591 .64983 L .22562 .64976 L F
.22647 .64967 m .22562 .64976 L .22367 .64931 L F
.22789 .64951 m .22591 .64983 L .22715 .64947 L F
.22685 .65005 m .22431 .65137 L .22367 .64931 L F
.005 0 0 r
.22367 .64931 m .22591 .64983 L .2264 .64995 L F
.697 .538 .668 r
.22365 .65203 m .22075 .65179 L .2235 .6515 L F
.22365 .65203 m .22128 .65399 L .22075 .65179 L F
.74 .692 .15 r
.22128 .65399 m .2235 .6515 L .22075 .65179 L F
.22145 .65275 m .22136 .65277 L .22183 .64992 L F
.22128 .65399 m .22131 .65353 L .22145 .65275 L F
.22131 .65353 m .22136 .65277 L .22145 .65275 L F
.505 .203 .389 r
.22321 .64916 m .2235 .6515 L .22164 .65169 L F
.22182 .65064 m .22164 .65169 L .22075 .65179 L F
.22321 .64916 m .22164 .65169 L .22182 .65064 L F
.96 .76 .589 r
.21219 .67794 m .21005 .67736 L .21093 .67458 L F
.952 .662 .452 r
.21219 .67794 m .21168 .68059 L .21005 .67736 L F
.373 .702 .984 r
.21219 .67794 m .21385 .67735 L .21228 .67632 L F
.21219 .67794 m .21385 .67735 L .21228 .67632 L F
.113 0 .256 r
.21385 .67735 m .21168 .68059 L .21219 .67794 L F
.275 0 .184 r
.39841 .59365 m .40055 .59348 L .40143 .59128 L F
.363 .069 .325 r
.40055 .59348 m .40322 .5902 L .40143 .59128 L F
0 0 0 r
.55312 .5584 m .55437 .55469 L .55164 .55421 L F
.55312 .5584 m .55381 .55681 L .55437 .55469 L F
.362 .65 .966 r
.55312 .5584 m .55495 .55807 L .55381 .55681 L F
.611 .586 .8 r
.55334 .56186 m .55495 .55807 L .55312 .5584 L F
.416 .381 .712 r
.27963 .55278 m .27868 .5558 L .27808 .5522 L F
.256 .215 .618 r
.27963 .55278 m .27992 .55782 L .27868 .5558 L F
.735 .643 .757 r
.71005 .43898 m .71387 .43967 L .71249 .43597 L F
.739 .645 .755 r
.71249 .43597 m .71387 .43967 L .71645 .43681 L F
.98 .821 .614 r
.44379 .56914 m .44121 .57135 L .44449 .57008 L F
.318 0 0 r
.17506 .54519 m .17761 .54501 L .17969 .54376 L F
.225 0 0 r
.17761 .54501 m .18187 .54333 L .17969 .54376 L F
.512 .327 .566 r
.47322 .56944 m .47086 .56737 L .47329 .56669 L F
.47322 .56944 m .47087 .56998 L .47086 .56737 L F
.47322 .56944 m .47086 .56737 L .47329 .56669 L F
.47322 .56944 m .47087 .56998 L .47086 .56737 L F
.895 .725 .217 r
.76922 .4288 m .76888 .42839 L .76933 .4271 L F
.813 .727 .198 r
.76933 .4271 m .76927 .42603 L .76957 .42386 L F
.824 .749 .229 r
.76933 .4271 m .76888 .42839 L .76927 .42603 L F
.027 .301 .793 r
.5217 .56984 m .52232 .56854 L .52016 .56642 L F
.5217 .56984 m .52266 .56999 L .52232 .56854 L F
.688 .615 .769 r
.51565 .53147 m .51858 .53389 L .51589 .5343 L F
.019 0 0 r
.54842 .56246 m .549 .56288 L .5501 .56176 L F
.963 .658 .247 r
.5503 .56637 m .549 .56288 L .54842 .56246 L F
.19 .35 .794 r
.63853 .42481 m .64044 .42257 L .63784 .42333 L F
.46 .193 .422 r
.63523 .42402 m .6377 .42337 L .63825 .42131 L F
.481 .213 .43 r
.63825 .42131 m .64044 .42257 L .63936 .42037 L F
.63825 .42131 m .6377 .42337 L .64044 .42257 L F
.459 0 0 r
.64044 .42257 m .63671 .42174 L .6377 .42337 L F
.614 .595 .807 r
.63842 .42116 m .63715 .42156 L .63645 .41978 L F
.63784 .42333 m .63751 .42284 L .63717 .42186 L F
.63728 .42188 m .63717 .42186 L .63645 .41978 L F
.63784 .42333 m .63717 .42186 L .63728 .42188 L F
.459 0 0 r
.64044 .42257 m .63717 .42186 L .63671 .42174 L F
.583 .567 .801 r
.63523 .42402 m .63671 .42174 L .63593 .42143 L F
.63523 .42402 m .6377 .42337 L .63671 .42174 L F
.585 .577 .811 r
.63717 .42186 m .6377 .42337 L .63593 .42157 L F
.459 0 0 r
.63717 .42186 m .63679 .42178 L .63677 .42177 L F
.63717 .42186 m .63677 .42177 L .63671 .42174 L F
.585 .577 .811 r
.63593 .42157 m .6377 .42337 L .63523 .42402 L F
.63631 .42158 m .63664 .42174 L .63593 .42157 L F
.63708 .42158 m .63668 .42172 L .63631 .42158 L F
0 .435 .794 r
.63593 .42143 m .63671 .42174 L .63668 .42172 L F
.585 .577 .811 r
.63668 .42172 m .63664 .42174 L .63631 .42158 L F
0 .435 .794 r
.63592 .42142 m .63668 .42172 L .63517 .4207 L F
.63593 .42143 m .63668 .42172 L .63592 .42142 L F
.015 .285 .782 r
.63668 .42172 m .63673 .42169 L .63667 .42171 L F
.63671 .42174 m .63673 .42171 L .63668 .42172 L F
.63673 .42171 m .63673 .42169 L .63668 .42172 L F
.585 .577 .811 r
.63645 .41978 m .63708 .42158 L .63593 .42157 L F
.63708 .42158 m .63677 .42177 L .63673 .42171 L F
.015 .285 .782 r
.63673 .42171 m .63679 .42178 L .63673 .42169 L F
.63671 .42174 m .63677 .42177 L .63673 .42171 L F
.63677 .42177 m .63679 .42178 L .63673 .42171 L F
.585 .577 .811 r
.63708 .42158 m .63717 .42186 L .63677 .42177 L F
.63673 .42171 m .63677 .42177 L .63664 .42174 L F
.614 .595 .807 r
.64044 .42257 m .63784 .42333 L .63715 .42156 L F
.459 0 0 r
.64044 .42257 m .63955 .4232 L .63679 .42178 L F
.342 .73 .985 r
.63936 .42037 m .63922 .41988 L .63645 .41978 L F
0 0 .406 r
.63936 .42037 m .64044 .42257 L .63922 .41988 L F
.614 .595 .807 r
.64044 .42257 m .63645 .41978 L .63922 .41988 L F
.015 .285 .782 r
.63667 .42171 m .63757 .41983 L .63517 .4207 L F
.63673 .42169 m .63757 .41983 L .63667 .42171 L F
.614 .595 .807 r
.64044 .42257 m .63715 .42156 L .63842 .42116 L F
.63784 .42333 m .6377 .42337 L .63751 .42284 L F
.015 .285 .782 r
.63673 .42169 m .6375 .42215 L .63712 .42082 L F
.63679 .42178 m .6375 .42215 L .63673 .42169 L F
.63712 .42082 m .63955 .4232 L .63757 .41983 L F
.6375 .42215 m .63955 .4232 L .63712 .42082 L F
.19 .35 .794 r
.63801 .42392 m .63784 .42333 L .6377 .42337 L F
.63853 .42481 m .63784 .42333 L .63801 .42392 L F
.63853 .42481 m .64073 .42468 L .64044 .42257 L F
.63853 .42481 m .63963 .42635 L .64073 .42468 L F
.599 .914 .662 r
.5346 .5661 m .5347 .56636 L .53613 .56393 L F
.984 .902 .637 r
.60237 .50688 m .60331 .50481 L .60165 .50604 L F
.916 .973 .687 r
.60165 .50604 m .60331 .50481 L .60286 .5041 L F
0 .116 .668 r
.50206 .549 m .50225 .54803 L .50018 .54575 L F
0 .232 .751 r
.50206 .549 m .50401 .5506 L .50225 .54803 L F
.681 .175 .031 r
.64639 .40224 m .64814 .40313 L .64991 .40308 L F
.544 .248 .416 r
.64814 .40313 m .65087 .40555 L .64991 .40308 L F
.749 .842 .921 r
.49952 .53449 m .4988 .53702 L .5015 .53576 L F
.724 .923 .959 r
.49736 .53648 m .4988 .53702 L .5015 .53576 L F
.691 .15 0 r
.49736 .53648 m .50085 .53857 L .4988 .53702 L F
.527 .498 .767 r
.58826 .48023 m .58531 .47872 L .58835 .47778 L F
.854 .884 .86 r
.77537 .39671 m .77353 .39866 L .77429 .39536 L F
.991 .831 .587 r
.77353 .39866 m .77213 .399 L .77429 .39536 L F
.77353 .39866 m .7732 .40023 L .77213 .399 L F
.588 .42 .622 r
.57355 .55543 m .57144 .5586 L .57094 .55561 L F
.765 .348 .258 r
.55315 .59433 m .55449 .59349 L .55137 .59312 L F
.463 0 .045 r
.55315 .59433 m .55662 .59358 L .55449 .59349 L F
.459 .34 .63 r
.42669 .5646 m .42898 .56645 L .42882 .564 L F
.176 .588 .939 r
.25491 .54166 m .25476 .54262 L .25309 .5414 L F
.25491 .54166 m .25643 .54291 L .25476 .54262 L F
.493 .737 .981 r
.67118 .40647 m .67503 .40762 L .67446 .40693 L F
.652 .125 0 r
.67779 .40761 m .67446 .40693 L .67503 .40762 L F
.539 .014 0 r
.67862 .40008 m .67893 .40095 L .68018 .39975 L F
.418 0 0 r
.68159 .40112 m .68018 .39975 L .67893 .40095 L F
.68159 .40112 m .68261 .39979 L .68018 .39975 L F
.738 .683 .798 r
.71481 .43514 m .71823 .43571 L .71734 .43212 L F
.753 .648 .745 r
.71481 .43514 m .71645 .43681 L .71823 .43571 L F
.731 .679 .8 r
.71734 .43212 m .71823 .43571 L .72097 .43278 L F
.483 .329 .596 r
.57183 .53162 m .57431 .53355 L .57426 .53082 L F
.463 .332 .617 r
.57183 .53162 m .57213 .53431 L .57431 .53355 L F
0 0 .028 r
.42217 .6223 m .41822 .62661 L .41813 .62388 L F
.775 .638 .71 r
.50996 .53464 m .51353 .53491 L .51297 .53193 L F
.962 .783 .341 r
.51266 .53501 m .51353 .53491 L .50996 .53464 L F
.51266 .53501 m .51321 .53694 L .51353 .53491 L F
.697 .587 .729 r
.51297 .53193 m .51353 .53491 L .51565 .53147 L F
.342 .1 .396 r
.51353 .53491 m .51321 .53694 L .51589 .5343 L F
0 0 0 r
.48458 .59545 m .48238 .5965 L .48559 .59492 L F
.15 .084 .521 r
.78519 .40212 m .78345 .40657 L .7837 .40319 L F
.78519 .40212 m .7855 .40474 L .78345 .40657 L F
.328 .322 .7 r
.7855 .40474 m .78413 .40898 L .78345 .40657 L F
.943 .809 .681 r
.6216 .45471 m .62359 .45417 L .62198 .45305 L F
.6216 .45471 m .62307 .45631 L .62359 .45417 L F
.471 .393 .687 r
.47891 .59092 m .481 .59017 L .47852 .58834 L F
0 .101 .645 r
.7366 .39487 m .73708 .39617 L .73577 .39464 L F
.659 .495 .651 r
.73708 .39617 m .73512 .3972 L .73577 .39464 L F
.557 .251 .405 r
.57717 .48349 m .57644 .48588 L .57368 .48625 L F
.378 .016 .217 r
.5796 .48321 m .57644 .48588 L .57717 .48349 L F
.467 .218 .453 r
.56503 .5436 m .56749 .54303 L .56769 .54086 L F
.52 .369 .615 r
.56769 .54086 m .5702 .54034 L .56991 .53726 L F
.429 .187 .443 r
.56769 .54086 m .56969 .54243 L .5702 .54034 L F
.56769 .54086 m .56749 .54303 L .56969 .54243 L F
.714 .829 .936 r
.20877 .63558 m .20503 .6355 L .20714 .63466 L F
.82 .891 .893 r
.21147 .63319 m .20877 .63558 L .20714 .63466 L F
.28 .028 .342 r
.45271 .60217 m .45073 .60323 L .45321 .60027 L F
.392 0 0 r
.45271 .60217 m .44912 .60344 L .45073 .60323 L F
.33 .339 .719 r
.52262 .57565 m .52418 .57587 L .52376 .57223 L F
0 0 .522 r
.76486 .39776 m .76349 .39732 L .7646 .39543 L F
0 .042 .604 r
.5308 .59647 m .53142 .59548 L .5303 .5934 L F
0 .135 .678 r
.5308 .59647 m .53299 .59901 L .53142 .59548 L F
.765 .959 .652 r
.51279 .59585 m .51194 .59762 L .51431 .59459 L F
.719 .502 .594 r
.59466 .48038 m .59041 .47771 L .59453 .4779 L F
.619 .521 .721 r
.51484 .593 m .51279 .59585 L .51431 .59459 L F
.333 0 0 r
.549 .56288 m .55153 .56179 L .5501 .56176 L F
.09 0 .317 r
.4646 .58112 m .46636 .57896 L .46533 .57981 L F
.4646 .58112 m .46575 .58137 L .46636 .57896 L F
.393 .828 .953 r
.20069 .65441 m .20135 .65357 L .19893 .65408 L F
.20069 .65441 m .2029 .65397 L .20135 .65357 L F
.692 .281 .263 r
.43177 .6567 m .4306 .65855 L .42841 .65635 L F
0 0 0 r
.60345 .43564 m .60147 .4393 L .60284 .43766 L F
.354 0 .193 r
.60345 .43564 m .60564 .43685 L .60656 .43288 L F
.60345 .43564 m .60284 .43766 L .60564 .43685 L F
.527 .608 .877 r
.19317 .73431 m .19532 .73405 L .19332 .73455 L F
.065 0 0 r
.19332 .73455 m .19532 .73405 L .19314 .73468 L F
.597 .93 .723 r
.43491 .56142 m .43543 .56168 L .4377 .56095 L F
.43491 .56142 m .43357 .56267 L .43543 .56168 L F
.895 .839 .783 r
.61642 .46824 m .61706 .47092 L .61799 .46971 L F
.61642 .46824 m .61438 .47143 L .61706 .47092 L F
.903 .814 .75 r
.61372 .47332 m .61706 .47092 L .61438 .47143 L F
.61372 .47332 m .61513 .47468 L .61706 .47092 L F
.344 .452 .827 r
.41674 .63314 m .4186 .63352 L .41807 .63137 L F
.546 .446 .691 r
.56643 .56655 m .56388 .56798 L .56412 .56722 L F
.904 .805 .74 r
.75509 .40532 m .75686 .40675 L .75571 .40871 L F
.721 .675 .805 r
.72337 .42998 m .72689 .43252 L .72592 .42914 L F
.709 .71 .849 r
.72592 .42914 m .72689 .43252 L .7296 .42995 L F
.546 .446 .691 r
.56643 .56655 m .56726 .5699 L .56388 .56798 L F
.567 .433 .659 r
.56726 .5699 m .5648 .57293 L .56388 .56798 L F
.103 .606 .898 r
.27429 .55117 m .27576 .55117 L .27808 .5522 L F
.789 .892 .918 r
.27808 .5522 m .27808 .54962 L .27984 .55165 L F
.27808 .5522 m .27576 .55117 L .27808 .54962 L F
.416 .381 .712 r
.27963 .55278 m .27808 .5522 L .27984 .55165 L F
.588 .42 .622 r
.57355 .55543 m .5737 .55807 L .57144 .5586 L F
.652 .432 .572 r
.57355 .55543 m .5766 .55781 L .5737 .55807 L F
.57355 .55543 m .57687 .55528 L .5766 .55781 L F
.398 .198 .489 r
.2179 .66377 m .2175 .66685 L .21623 .66762 L F
0 0 .327 r
.21781 .66624 m .2179 .66377 L .22051 .66353 L F
.21781 .66624 m .21738 .66777 L .2175 .66685 L F
.21781 .66624 m .2175 .66685 L .2179 .66377 L F
.394 .157 .432 r
.22236 .66228 m .21781 .66624 L .22051 .66353 L F
.772 .785 .864 r
.21892 .66413 m .21781 .66624 L .21993 .66439 L F
.21705 .66365 m .21781 .66624 L .21892 .66413 L F
.22192 .6624 m .21993 .66439 L .22236 .66228 L F
.43 .264 .553 r
.22024 .65988 m .22051 .66353 L .2179 .66377 L F
.487 .306 .56 r
.22236 .66228 m .22051 .66353 L .22024 .65988 L F
.772 .785 .864 r
.21705 .66365 m .21993 .66439 L .22192 .6624 L F
.398 .198 .489 r
.2175 .66685 m .21738 .66777 L .21668 .66768 L F
.2175 .66685 m .21668 .66768 L .21623 .66762 L F
.801 .512 .498 r
.55535 .58553 m .55179 .58234 L .55184 .58493 L F
.644 .857 .981 r
.75221 .39538 m .75321 .39679 L .74993 .39632 L F
.837 .719 .734 r
.74993 .39632 m .75321 .39679 L .75105 .39981 L F
.4 .751 .993 r
.75374 .39981 m .75105 .39981 L .75321 .39679 L F
.638 .573 .765 r
.75229 .39086 m .75421 .39547 L .75593 .39384 L F
.838 .926 .89 r
.75593 .39384 m .75321 .39679 L .75221 .39538 L F
.769 .759 .844 r
.69651 .43755 m .69435 .43891 L .69779 .4392 L F
.746 .753 .858 r
.69651 .43755 m .69779 .4392 L .70011 .43815 L F
.859 .786 .777 r
.61861 .46503 m .61642 .46824 L .6193 .4682 L F
.853 .808 .806 r
.61642 .46824 m .61799 .46971 L .6193 .4682 L F
.348 .156 .472 r
.5646 .59757 m .56675 .59417 L .56665 .59663 L F
.206 0 .163 r
.56379 .59913 m .5646 .59757 L .56665 .59663 L F
.622 .782 .958 r
.66227 .44185 m .66155 .44254 L .65998 .44099 L F
.362 .336 .695 r
.66227 .44185 m .66379 .44412 L .66155 .44254 L F
.633 .092 0 r
.66155 .44254 m .66032 .44318 L .65998 .44099 L F
.66155 .44254 m .66379 .44412 L .66032 .44318 L F
.46 .235 .485 r
.60998 .42344 m .61249 .42078 L .60956 .421 L F
.714 .529 .638 r
.5737 .55807 m .57117 .56084 L .57144 .5586 L F
.222 0 .152 r
.59326 .44977 m .59622 .44734 L .5939 .44795 L F
.243 .143 .536 r
.55581 .57373 m .55775 .5723 L .55756 .56974 L F
0 0 0 r
.59441 .52261 m .59682 .51916 L .59544 .52096 L F
0 0 .146 r
.59445 .52464 m .59441 .52261 L .59544 .52096 L F
.675 .763 .917 r
.68786 .43712 m .68439 .43634 L .68682 .43531 L F
.819 .828 .857 r
.69031 .43508 m .68786 .43712 L .68682 .43531 L F
.668 .83 .962 r
.73525 .39965 m .73878 .40006 L .73806 .39871 L F
.651 .405 .535 r
.73878 .40006 m .7366 .40087 L .73525 .39965 L F
.73878 .40006 m .73897 .40251 L .7366 .40087 L F
.7366 .40087 m .73897 .40251 L .73878 .40006 L F
.738 .724 .838 r
.7414 .39757 m .73878 .40006 L .73866 .39833 L F
.118 .021 .459 r
.73878 .40006 m .74005 .39848 L .73806 .39871 L F
.663 .587 .76 r
.7414 .39757 m .7416 .39996 L .73878 .40006 L F
.118 .021 .459 r
.73878 .40006 m .74103 .39943 L .74005 .39848 L F
.717 .511 .611 r
.7416 .39996 m .73897 .40251 L .73878 .40006 L F
.118 .021 .459 r
.73878 .40006 m .73897 .40251 L .74103 .39943 L F
.797 .82 .87 r
.64523 .42943 m .64672 .431 L .64783 .42951 L F
.38 .126 .397 r
.46336 .61847 m .46556 .61768 L .46624 .61669 L F
.46336 .61847 m .46295 .62052 L .46556 .61768 L F
.46556 .61768 m .46295 .62052 L .46336 .61847 L F
.362 .072 .331 r
.39841 .59365 m .40017 .5956 L .40055 .59348 L F
.39841 .59365 m .39797 .5963 L .40017 .5956 L F
.19 .349 .794 r
.63963 .42635 m .64104 .42693 L .64073 .42468 L F
.691 .718 .87 r
.77688 .39286 m .77537 .39671 L .77429 .39536 L F
.77688 .39286 m .77786 .39571 L .77537 .39671 L F
.613 .686 .894 r
.18724 .63476 m .18298 .63295 L .1849 .63296 L F
.467 .763 .995 r
.18812 .63329 m .18724 .63476 L .1849 .63296 L F
.18812 .63329 m .1892 .63444 L .18724 .63476 L F
.488 .24 .465 r
.46834 .61231 m .46794 .61464 L .46552 .61506 L F
.46834 .61231 m .46794 .61464 L .46552 .61506 L F
.134 0 .147 r
.46834 .61231 m .47112 .60946 L .47033 .61154 L F
.514 .525 .805 r
.46666 .60879 m .46834 .61231 L .47033 .61154 L F
.409 .172 .44 r
.4701 .61395 m .46834 .61231 L .47033 .61154 L F
.4701 .61395 m .46794 .61464 L .46834 .61231 L F
.4701 .61395 m .46834 .61231 L .47033 .61154 L F
.4701 .61395 m .46794 .61464 L .46834 .61231 L F
.314 .222 .589 r
.55424 .56425 m .55532 .5612 L .55334 .56186 L F
.55424 .56425 m .55576 .56437 L .55532 .5612 L F
.283 .378 .783 r
.55424 .56425 m .55676 .56588 L .55576 .56437 L F
.212 .668 .947 r
.22062 .55316 m .21694 .55213 L .21892 .55239 L F
.741 .783 .887 r
.69455 .42887 m .69453 .43342 L .69298 .43275 L F
.46 .172 .387 r
.47264 .61105 m .47112 .60946 L .47337 .60824 L F
.507 .202 .385 r
.47587 .6079 m .47264 .61105 L .47337 .60824 L F
.652 .45 .597 r
.60874 .4446 m .60526 .44724 L .60578 .44434 L F
.611 .586 .8 r
.55334 .56186 m .55532 .5612 L .55495 .55807 L F
.907 .62 .488 r
.41285 .63886 m .41437 .64206 L .41579 .64157 L F
.642 .157 .086 r
.41437 .64206 m .41773 .6425 L .41579 .64157 L F
0 0 0 r
.66187 .42601 m .66161 .42723 L .66266 .42564 L F
.66187 .42601 m .66122 .4297 L .66161 .42723 L F
.739 .645 .755 r
.71249 .43597 m .71645 .43681 L .71481 .43514 L F
.48 .155 .338 r
.39259 .59907 m .3956 .59686 L .39327 .59762 L F
.508 .224 .417 r
.47125 .60002 m .47413 .59762 L .47138 .59733 L F
.163 .703 .787 r
.62434 .42018 m .628 .41982 L .62728 .41908 L F
.4 .25 .56 r
.27547 .58774 m .27365 .59078 L .27322 .58822 L F
.025 .142 .65 r
.43622 .57991 m .4377 .58067 L .43886 .57937 L F
.574 .395 .6 r
.56855 .56361 m .5657 .56153 L .56858 .56111 L F
.56855 .56361 m .56586 .56418 L .5657 .56153 L F
.757 .696 .793 r
.42437 .64123 m .42803 .6422 L .42656 .64232 L F
0 0 0 r
.43067 .63933 m .42991 .64106 L .42803 .6422 L F
.43 .022 .161 r
.42991 .64106 m .42656 .64232 L .42803 .6422 L F
.179 0 0 r
.20624 .53998 m .20849 .5399 L .21005 .53942 L F
.222 0 0 r
.21005 .53942 m .20849 .5399 L .2123 .53937 L F
.982 .912 .626 r
.77092 .41822 m .76936 .4192 L .7703 .41708 L F
.77092 .41822 m .76971 .42117 L .76936 .4192 L F
.941 .704 .233 r
.77092 .41822 m .7703 .41708 L .77022 .41445 L F
.819 .828 .857 r
.69031 .43508 m .68682 .43531 L .68918 .43356 L F
.782 .856 .906 r
.69298 .43275 m .69031 .43508 L .68918 .43356 L F
.503 .326 .574 r
.45506 .5995 m .45271 .60217 L .45321 .60027 L F
.33 .055 .336 r
.23838 .59899 m .24028 .59914 L .24087 .59784 L F
.177 .04 .444 r
.23805 .6028 m .24028 .59914 L .23838 .59899 L F
.378 0 0 r
.38995 .62384 m .38822 .62307 L .38554 .62166 L F
0 .129 .646 r
.38995 .62384 m .38995 .62325 L .38822 .62307 L F
.38995 .62384 m .3925 .62613 L .38995 .62325 L F
.335 0 .135 r
.45805 .59481 m .45746 .59643 L .45478 .59688 L F
.48 .073 .189 r
.46006 .59607 m .45746 .59643 L .45805 .59481 L F
.454 .098 .271 r
.46057 .59437 m .46006 .59607 L .45805 .59481 L F
0 0 .331 r
.66318 .40133 m .66166 .40371 L .66095 .40164 L F
.66318 .40133 m .66251 .40358 L .66166 .40371 L F
.085 0 .005 r
.4322 .63929 m .43067 .63933 L .43249 .63823 L F
.43203 .63917 m .43249 .63823 L .42883 .63765 L F
.713 .343 .346 r
.43249 .63823 m .43187 .6395 L .43208 .63971 L F
.43249 .63823 m .43208 .63971 L .43237 .64 L F
.085 0 .005 r
.43227 .63929 m .4322 .63929 L .43249 .63823 L F
.43227 .63929 m .43249 .63823 L .43203 .63917 L F
.713 .343 .346 r
.43249 .63823 m .43116 .63878 L .43187 .6395 L F
.085 0 .005 r
.43227 .63929 m .42991 .64106 L .43067 .63933 L F
.466 0 0 r
.76458 .40357 m .76471 .40343 L .76418 .4025 L F
.76458 .40357 m .7675 .40541 L .76471 .40343 L F
.514 .525 .805 r
.46666 .60879 m .47033 .61154 L .47112 .60946 L F
.57 .465 .695 r
.47112 .60946 m .47289 .60924 L .47257 .60599 L F
.46 .172 .387 r
.47264 .61105 m .47112 .60946 L .47289 .60924 L F
.47264 .61105 m .47033 .61154 L .47112 .60946 L F
.47264 .61105 m .47033 .61154 L .47112 .60946 L F
.365 .781 .979 r
.19345 .73346 m .19317 .73431 L .19253 .73418 L F
.19306 .73374 m .19253 .73418 L .19246 .73416 L F
.19345 .73346 m .19253 .73418 L .19306 .73374 L F
.53 .854 .997 r
.19306 .73374 m .19347 .73339 L .19303 .73337 L F
.19314 .73468 m .19347 .73339 L .19306 .73374 L F
.19314 .73468 m .19306 .73374 L .19246 .73416 L F
.19306 .73374 m .19303 .73337 L .19246 .73416 L F
.365 .781 .979 r
.19347 .73339 m .19345 .73346 L .19246 .73416 L F
.19347 .73339 m .19532 .73405 L .19317 .73431 L F
.434 .167 .407 r
.57887 .46591 m .58134 .46524 L .58159 .46253 L F
.374 .118 .392 r
.58159 .46253 m .58366 .46431 L .58389 .46165 L F
.58159 .46253 m .58134 .46524 L .58366 .46431 L F
.658 .573 .748 r
.55634 .58335 m .55924 .57783 L .55817 .58239 L F
.855 .997 .797 r
.55634 .58335 m .55817 .58239 L .55535 .58553 L F
.845 .393 .131 r
.53454 .60394 m .53591 .60585 L .53402 .60495 L F
.883 .927 .847 r
.42559 .63844 m .42525 .63941 L .42415 .63766 L F
0 0 .103 r
.42437 .64123 m .42415 .63766 L .42525 .63941 L F
.024 0 .133 r
.58959 .53372 m .58813 .53456 L .59045 .53157 L F
.188 .046 .445 r
.588 .53701 m .58813 .53456 L .58959 .53372 L F
.434 .183 .433 r
.26377 .61084 m .26222 .60909 L .2644 .60856 L F
.26377 .61084 m .26171 .61151 L .26222 .60909 L F
.605 .415 .598 r
.51302 .59062 m .50956 .5921 L .5123 .58835 L F
.301 .407 .804 r
.51386 .58687 m .5123 .58835 L .51104 .58511 L F
0 0 .495 r
.51386 .58687 m .51302 .59062 L .5123 .58835 L F
.145 0 .172 r
.57367 .46902 m .57111 .47184 L .57318 .47059 L F
.416 .125 .36 r
.57318 .47059 m .57591 .46817 L .57367 .46902 L F
0 0 0 r
.56107 .60234 m .56209 .6005 L .56379 .59913 L F
.575 .572 .813 r
.48043 .56026 m .47941 .56438 L .47806 .56105 L F
.48043 .56026 m .48177 .56384 L .47941 .56438 L F
.141 .126 .579 r
.20445 .68715 m .20569 .68662 L .20528 .68303 L F
.242 .398 .819 r
.20445 .68715 m .20711 .68906 L .20569 .68662 L F
0 0 0 r
.44266 .5749 m .44638 .5746 L .44399 .57346 L F
.812 .8 .84 r
.75571 .40871 m .75389 .41076 L .75285 .40819 L F
.503 .201 .388 r
.42274 .6175 m .42282 .61883 L .42045 .61892 L F
.595 .45 .653 r
.42559 .61519 m .42274 .6175 L .4214 .61415 L F
.42559 .61519 m .42516 .61802 L .42274 .6175 L F
.622 .309 .418 r
.42516 .61802 m .42282 .61883 L .42274 .6175 L F
.372 .628 .953 r
.1756 .65392 m .17634 .65307 L .17471 .65297 L F
.211 0 .117 r
.47891 .59092 m .47806 .59278 L .481 .59017 L F
.639 .542 .729 r
.51192 .52849 m .51316 .53211 L .51297 .53193 L F
.775 .638 .71 r
.50996 .53464 m .51297 .53193 L .51316 .53211 L F
.727 .82 .922 r
.53896 .55773 m .54068 .5591 L .5428 .55766 L F
.263 .281 .691 r
.7561 .38299 m .75417 .38558 L .75362 .38198 L F
.42 .499 .834 r
.7561 .38299 m .7575 .38705 L .75417 .38558 L F
.724 .923 .959 r
.49736 .53648 m .5015 .53576 L .49952 .53449 L F
.579 .071 .011 r
.50383 .53457 m .49952 .53449 L .5015 .53576 L F
.746 .753 .858 r
.69651 .43755 m .70011 .43815 L .69933 .43541 L F
.689 .764 .909 r
.69933 .43541 m .70011 .43815 L .70288 .43601 L F
0 0 .242 r
.74174 .42697 m .74289 .42423 L .74493 .4265 L F
.503 .341 .594 r
.74493 .4265 m .74426 .42924 L .74174 .42697 L F
.382 .336 .683 r
.74426 .42924 m .74247 .43022 L .74174 .42697 L F
0 .391 .798 r
.5051 .58334 m .50802 .58456 L .50636 .58346 L F
.5051 .58334 m .50636 .58346 L .50492 .58425 L F
.088 .133 .614 r
.47347 .59979 m .47475 .60039 L .47528 .59933 L F
.47347 .59979 m .47528 .59933 L .47572 .59844 L F
.327 .782 .951 r
.47242 .60005 m .47347 .59979 L .47125 .60002 L F
.47507 .60013 m .47347 .59979 L .47242 .60005 L F
.786 .319 .131 r
.47507 .60013 m .47429 .6012 L .47347 .59979 L F
.47507 .60013 m .4772 .60267 L .47429 .6012 L F
.954 .666 .45 r
.568 .58523 m .56643 .58484 L .56616 .58619 L F
.472 .344 .625 r
.57014 .58458 m .5681 .58729 L .568 .58523 L F
.557 .934 .857 r
.56616 .58619 m .57014 .58458 L .568 .58523 L F
.587 .399 .594 r
.56247 .54635 m .56522 .54602 L .56503 .5436 L F
.462 .278 .544 r
.56522 .54602 m .56749 .54303 L .56503 .5436 L F
.392 0 0 r
.21845 .53933 m .22063 .53974 L .22219 .53928 L F
.146 0 0 r
.22219 .53928 m .22063 .53974 L .22457 .53918 L F
.423 0 .079 r
.22789 .64951 m .22692 .6479 L .22896 .64728 L F
.529 .378 .62 r
.56247 .54635 m .56534 .54854 L .56522 .54602 L F
.56247 .54635 m .5628 .54944 L .56534 .54854 L F
.232 0 .104 r
.51316 .53211 m .5116 .53459 L .50996 .53464 L F
.685 .568 .717 r
.51361 .53126 m .51316 .53211 L .51192 .52849 L F
.698 .852 .432 r
.51305 .53172 m .51316 .53211 L .51361 .53126 L F
.51305 .53172 m .5116 .53459 L .51316 .53211 L F
.421 .238 .525 r
.385 .60281 m .38699 .59975 L .38457 .60011 L F
.9 .84 .776 r
.61957 .45823 m .62307 .45631 L .6216 .45471 L F
.61957 .45823 m .62096 .45953 L .62307 .45631 L F
.155 .638 .923 r
.24643 .54054 m .24875 .54079 L .25065 .54167 L F
.03 .589 .812 r
.24875 .54079 m .25309 .5414 L .25065 .54167 L F
.424 .148 .389 r
.61752 .41485 m .61955 .41427 L .62024 .41164 L F
.65 .361 .467 r
.62024 .41164 m .6229 .41401 L .62274 .41127 L F
.62024 .41164 m .61955 .41427 L .6229 .41401 L F
.469 .833 .578 r
.50984 .52396 m .51112 .523 L .50805 .52546 L F
.177 0 0 r
.50805 .52546 m .50904 .52631 L .50984 .52396 L F
.50805 .52546 m .50684 .52709 L .50904 .52631 L F
.581 .776 .972 r
.21377 .65313 m .21286 .65384 L .21498 .65334 L F
.623 .424 .592 r
.57691 .52846 m .5793 .52764 L .57979 .52553 L F
.382 .172 .466 r
.57979 .52553 m .58226 .52482 L .58244 .52234 L F
.36 .12 .409 r
.58178 .527 m .57979 .52553 L .5793 .52764 L F
.58178 .527 m .58226 .52482 L .57979 .52553 L F
.48 .14 .312 r
.69456 .39876 m .69737 .39677 L .69473 .39717 L F
.496 .085 .19 r
.45391 .57654 m .45615 .57764 L .45323 .57819 L F
.498 .077 .172 r
.45637 .57649 m .45615 .57764 L .45391 .57654 L F
.619 .442 .62 r
.78468 .42384 m .78433 .42663 L .78279 .42583 L F
0 0 .525 r
.78624 .42448 m .78468 .42384 L .78346 .42246 L F
.78624 .42448 m .78576 .42478 L .78468 .42384 L F
.031 0 .4 r
.78576 .42478 m .78433 .42663 L .78468 .42384 L F
.466 .35 .637 r
.27065 .59628 m .26879 .59969 L .26907 .59697 L F
0 0 0 r
.55248 .50385 m .55157 .50515 L .54942 .50629 L F
.539 .833 .502 r
.55503 .50111 m .55379 .50238 L .55248 .50385 L F
.1 0 .052 r
.57111 .47184 m .56825 .47443 L .57092 .47275 L F
.366 .088 .353 r
.57092 .47275 m .57318 .47059 L .57111 .47184 L F
0 .514 .739 r
.22457 .53918 m .22667 .53948 L .22848 .53983 L F
.038 .598 .806 r
.22667 .53948 m .23055 .53996 L .22848 .53983 L F
.296 .789 .754 r
.2131 .66779 m .21351 .66749 L .21529 .66792 L F
.2131 .66779 m .2114 .66822 L .21351 .66749 L F
.21351 .66749 m .2131 .66779 L .21529 .66792 L F
.21351 .66749 m .2114 .66822 L .2131 .66779 L F
.673 .618 .786 r
.2131 .66779 m .2157 .66867 L .21529 .66792 L F
.629 .873 .523 r
.48332 .58224 m .48572 .57926 L .48434 .58072 L F
.803 .537 .535 r
.48185 .58411 m .48358 .58483 L .48332 .58224 L F
.679 .538 .686 r
.48332 .58224 m .4862 .58161 L .48572 .57926 L F
.732 .543 .636 r
.48358 .58483 m .4862 .58161 L .48332 .58224 L F
.409 .701 .981 r
.38943 .63157 m .39127 .63301 L .38863 .63299 L F
.38943 .63157 m .39127 .63301 L .38863 .63299 L F
.988 .864 .623 r
.76287 .41891 m .76278 .42378 L .76371 .41988 L F
.619 .273 .362 r
.55601 .5531 m .56005 .55435 L .55761 .55257 L F
.524 .323 .55 r
.55761 .55257 m .56005 .55435 L .56012 .55191 L F
.659 .495 .651 r
.73708 .39617 m .73866 .39833 L .73512 .3972 L F
.591 .023 0 r
.78279 .42583 m .78346 .42246 L .78091 .42327 L F
.78279 .42583 m .78107 .4258 L .78346 .42246 L F
.78279 .42583 m .78433 .42663 L .78107 .4258 L F
.212 .22 .65 r
.48572 .57926 m .4862 .58161 L .4877 .58054 L F
.436 .136 .356 r
.48572 .57926 m .4877 .58054 L .48434 .58072 L F
.48572 .57926 m .48808 .57873 L .4877 .58054 L F
.212 .22 .65 r
.48572 .57926 m .4877 .58054 L .48808 .57873 L F
.977 .744 .518 r
.52431 .55071 m .526 .55206 L .52629 .54942 L F
.218 .057 .437 r
.526 .55206 m .52759 .55236 L .52629 .54942 L F
.746 .299 .19 r
.52629 .54942 m .52759 .55236 L .52431 .55071 L F
.657 .849 .448 r
.51426 .52992 m .51305 .53172 L .51361 .53126 L F
.402 .746 .993 r
.53571 .57202 m .534 .57019 L .53483 .56987 L F
.53571 .57202 m .53437 .57262 L .534 .57019 L F
.343 0 .019 r
.18578 .55774 m .18383 .55969 L .18163 .55995 L F
0 0 0 r
.1859 .55874 m .18578 .55774 L .18789 .55744 L F
.1859 .55874 m .18383 .55969 L .18578 .55774 L F
.71 .925 .591 r
.46624 .61669 m .46794 .61464 L .46552 .61506 L F
.585 .883 .992 r
.7553 .43513 m .75875 .43508 L .7576 .43389 L F
.839 .893 .879 r
.7576 .43389 m .75875 .43508 L .76118 .43266 L F
.611 .757 .948 r
.21498 .65334 m .21904 .65434 L .21626 .65173 L F
.556 .571 .824 r
.21904 .65434 m .21982 .6502 L .21626 .65173 L F
.541 .439 .688 r
.22075 .65179 m .22128 .65399 L .21904 .65434 L F
.556 .571 .824 r
.21904 .65434 m .22128 .65399 L .21982 .6502 L F
0 .032 .553 r
.4411 .5615 m .44275 .5621 L .44106 .55897 L F
.4411 .5615 m .44179 .56416 L .44275 .5621 L F
.937 .91 .768 r
.6126 .48251 m .61182 .48683 L .61369 .4836 L F
.95 .885 .734 r
.6126 .48251 m .61369 .4836 L .61451 .48113 L F
.629 .96 .819 r
.51966 .51706 m .51855 .51854 L .51784 .5184 L F
.51966 .51706 m .5216 .51647 L .51855 .51854 L F
.413 .258 .559 r
.26171 .61151 m .2597 .61472 L .25967 .61218 L F
.21 0 0 r
.61934 .43686 m .62094 .4368 L .62245 .43545 L F
0 0 0 r
.61934 .43686 m .62068 .43659 L .62094 .4368 L F
.61934 .43686 m .6183 .43756 L .62068 .43659 L F
.454 .378 .681 r
.60537 .43241 m .60752 .43217 L .60757 .42872 L F
.133 .028 .459 r
.60656 .43288 m .60752 .43217 L .60537 .43241 L F
.68 .593 .752 r
.62124 .42137 m .61979 .4228 L .6215 .42228 L F
.61976 .41614 m .61978 .42096 L .62124 .42137 L F
.61978 .42096 m .61979 .4228 L .62124 .42137 L F
.98 .809 .599 r
.62144 .42143 m .6215 .42228 L .62179 .42116 L F
.6215 .42228 m .62153 .4227 L .62158 .4224 L F
.6215 .42228 m .62158 .4224 L .62179 .42116 L F
.995 .833 .569 r
.62179 .42116 m .62153 .4227 L .62264 .42433 L F
.686 .252 .213 r
.62438 .42206 m .62179 .42116 L .62434 .42018 L F
.62439 .42241 m .62362 .42204 L .62438 .42206 L F
.62362 .42204 m .62179 .42116 L .62438 .42206 L F
.437 .542 .865 r
.62179 .42116 m .62264 .42433 L .62421 .42261 L F
.686 .252 .213 r
.62328 .42188 m .62144 .42143 L .62179 .42116 L F
.62292 .42184 m .62144 .42143 L .62328 .42188 L F
.437 .542 .865 r
.62179 .42116 m .62439 .42241 L .62434 .42018 L F
.68 .593 .752 r
.62146 .41994 m .62151 .42198 L .6233 .42173 L F
.62151 .42198 m .62152 .42227 L .6224 .422 L F
.62151 .42198 m .6224 .422 L .6233 .42173 L F
.163 .703 .787 r
.62434 .42018 m .62675 .41985 L .628 .41982 L F
.474 .257 .503 r
.62434 .42018 m .62439 .42241 L .62675 .41985 L F
.62434 .42018 m .62439 .42241 L .62675 .41985 L F
.68 .593 .752 r
.62141 .41771 m .62146 .41994 L .62506 .42119 L F
.62146 .41994 m .6233 .42173 L .62506 .42119 L F
.437 .542 .865 r
.62362 .42204 m .62421 .42261 L .62439 .42241 L F
.62179 .42116 m .62421 .42261 L .62362 .42204 L F
.686 .252 .213 r
.62362 .42204 m .62292 .42184 L .62328 .42188 L F
.68 .593 .752 r
.61976 .41614 m .6215 .42228 L .62149 .42218 L F
.61976 .41614 m .62152 .42227 L .62141 .41771 L F
.686 .252 .213 r
.62261 .42182 m .6211 .42169 L .62144 .42143 L F
.62439 .42241 m .62144 .42143 L .62362 .42204 L F
.442 .163 .393 r
.62657 .41916 m .62434 .42018 L .62577 .4177 L F
.62657 .41916 m .62675 .41985 L .62434 .42018 L F
.68 .593 .752 r
.61976 .41614 m .62506 .42119 L .62197 .41543 L F
0 0 0 r
.62096 .42148 m .62331 .41882 L .62178 .42174 L F
.61979 .4228 m .62096 .42148 L .6215 .42228 L F
.98 .809 .599 r
.62064 .42204 m .62153 .4227 L .62144 .42143 L F
.68 .593 .752 r
.62149 .42218 m .6215 .42228 L .62152 .42227 L F
0 0 0 r
.6211 .42169 m .62178 .42174 L .6215 .42228 L F
.62096 .42148 m .62178 .42174 L .6211 .42169 L F
.6215 .42228 m .62178 .42174 L .62292 .42184 L F
.686 .252 .213 r
.62439 .42241 m .62064 .42204 L .6211 .42169 L F
.62439 .42241 m .6211 .42169 L .62261 .42182 L F
0 0 0 r
.62292 .42184 m .62331 .41882 L .62506 .42119 L F
.62178 .42174 m .62331 .41882 L .62292 .42184 L F
.98 .809 .599 r
.62064 .42204 m .6213 .42402 L .62153 .4227 L F
.995 .833 .569 r
.62153 .4227 m .6213 .42402 L .62156 .42408 L F
.62153 .4227 m .62156 .42408 L .62264 .42433 L F
.813 .985 .885 r
.6213 .42402 m .62139 .42385 L .62264 .42433 L F
.678 .961 .941 r
.62264 .42433 m .62139 .42385 L .62439 .42241 L F
.069 .324 .804 r
.49566 .54378 m .49622 .54242 L .49488 .54197 L F
.486 0 0 r
.50018 .54575 m .49827 .5453 L .49566 .54378 L F
.069 .324 .804 r
.49566 .54378 m .49827 .5453 L .49622 .54242 L F
0 .057 .618 r
.51625 .56133 m .51625 .5604 L .51484 .56013 L F
.51625 .56133 m .51811 .56345 L .51625 .5604 L F
.438 .294 .587 r
.26646 .60299 m .26647 .60554 L .26452 .60613 L F
.447 .264 .539 r
.26646 .60789 m .26452 .60613 L .26647 .60554 L F
.26646 .60789 m .2644 .60856 L .26452 .60613 L F
.465 0 0 r
.41773 .6425 m .41948 .64385 L .41998 .64414 L F
.931 .739 .258 r
.41907 .64507 m .41998 .64414 L .41948 .64385 L F
.41907 .64507 m .41991 .64712 L .41998 .64414 L F
0 0 0 r
.51589 .5343 m .51627 .53163 L .51565 .53147 L F
.767 .859 .918 r
.48863 .58948 m .48933 .59159 L .49054 .59025 L F
.984 .894 .647 r
.48732 .59288 m .48829 .5937 L .48933 .59159 L F
.53 .854 .997 r
.19314 .73468 m .19532 .73405 L .19347 .73339 L F
.637 .297 .379 r
.69374 .40593 m .69443 .40728 L .69017 .40798 L F
.595 .28 .406 r
.69374 .40593 m .69622 .40762 L .69443 .40728 L F
.613 .263 .352 r
.69374 .40593 m .69628 .40611 L .69622 .40762 L F
.656 .342 .429 r
.45278 .58521 m .45491 .58659 L .45465 .58438 L F
.45278 .58521 m .45169 .58766 L .45491 .58659 L F
.306 .786 .915 r
.23036 .55305 m .22923 .55264 L .22734 .5532 L F
.016 .515 .87 r
.23036 .55305 m .23135 .55268 L .22923 .55264 L F
.23036 .55305 m .23315 .55377 L .23135 .55268 L F
.01 .513 .866 r
.23462 .55465 m .23315 .55377 L .23036 .55305 L F
.254 .521 .911 r
.26287 .54461 m .26448 .54482 L .26397 .54637 L F
.357 .637 .96 r
.26448 .54482 m .26595 .54648 L .26397 .54637 L F
.789 .887 .916 r
.4428 .55794 m .44094 .55776 L .44109 .55708 L F
.549 .863 .996 r
.4428 .55794 m .44516 .55625 L .44675 .55676 L F
.4428 .55794 m .44109 .55708 L .44516 .55625 L F
.639 .847 .98 r
.44739 .55708 m .4428 .55794 L .44675 .55676 L F
.222 .074 .458 r
.56832 .59552 m .56675 .59417 L .56803 .59299 L F
.56832 .59552 m .56665 .59663 L .56675 .59417 L F
.491 .246 .471 r
.49698 .58824 m .49675 .5905 L .49438 .59075 L F
.547 .466 .715 r
.49923 .58764 m .49698 .58824 L .49701 .58615 L F
.599 .403 .588 r
.49923 .58764 m .49675 .5905 L .49698 .58824 L F
.747 .753 .857 r
.5336 .55615 m .53676 .55656 L .53546 .55472 L F
.726 .529 .624 r
.42282 .61883 m .42217 .6223 L .42045 .61892 L F
.034 0 0 r
.19436 .55523 m .19203 .55645 L .19005 .55692 L F
0 0 0 r
.19582 .55498 m .19436 .55523 L .19651 .55484 L F
.19582 .55498 m .19203 .55645 L .19436 .55523 L F
.682 .469 .591 r
.59041 .47771 m .58826 .48023 L .58835 .47778 L F
.59041 .47771 m .59018 .48045 L .58826 .48023 L F
.719 .502 .594 r
.59466 .48038 m .59018 .48045 L .59041 .47771 L F
.422 .278 .579 r
.426 .61106 m .4244 .61242 L .42426 .60842 L F
.644 .584 .773 r
.62073 .42975 m .62178 .43313 L .62415 .43274 L F
.635 .519 .704 r
.62178 .43313 m .62245 .43545 L .62415 .43274 L F
.323 .757 .969 r
.22521 .55365 m .22321 .55284 L .22062 .55316 L F
.267 .753 .92 r
.22734 .5532 m .22321 .55284 L .22521 .55365 L F
.934 .83 .718 r
.67701 .44487 m .67403 .44678 L .67601 .44375 L F
.67701 .44487 m .67586 .44777 L .67403 .44678 L F
.991 .862 .607 r
.67668 .44136 m .67701 .44487 L .67601 .44375 L F
0 0 .552 r
.52774 .58512 m .52829 .5837 L .52699 .58168 L F
0 .101 .645 r
.52774 .58512 m .52936 .58709 L .52829 .5837 L F
.068 0 0 r
.15282 .55471 m .15477 .55431 L .15636 .55317 L F
0 0 0 r
.15477 .55431 m .15869 .55284 L .15636 .55317 L F
.744 .873 .94 r
.20503 .6355 m .20327 .63688 L .20121 .63596 L F
.508 .224 .417 r
.47125 .60002 m .47347 .59979 L .47413 .59762 L F
.286 .019 .322 r
.47413 .59762 m .47347 .59979 L .47625 .59667 L F
.489 .314 .57 r
.24753 .58557 m .24998 .58495 L .24992 .58199 L F
.554 .32 .516 r
.24703 .58746 m .24998 .58495 L .24753 .58557 L F
.501 .257 .478 r
.24244 .59101 m .24473 .59059 L .24521 .58826 L F
.306 .085 .406 r
.24521 .58826 m .24473 .59059 L .24703 .58746 L F
.583 .391 .587 r
.57933 .55238 m .57935 .55481 L .57687 .55528 L F
.572 .424 .642 r
.58152 .54936 m .58176 .55187 L .57933 .55238 L F
.521 .275 .483 r
.57933 .55238 m .58129 .55398 L .57935 .55481 L F
.57933 .55238 m .58176 .55187 L .58129 .55398 L F
.549 .306 .5 r
.19527 .71637 m .19726 .71864 L .19767 .71591 L F
.19767 .71591 m .19726 .71864 L .19527 .71637 L F
.647 .159 .08 r
.73763 .38629 m .73872 .385 L .73505 .38459 L F
.873 .467 .252 r
.73915 .38701 m .73872 .385 L .73763 .38629 L F
.747 .411 .413 r
.74268 .38762 m .73872 .385 L .73915 .38701 L F
.044 .459 .88 r
.17828 .65413 m .18141 .6562 L .18037 .65345 L F
.643 .743 .922 r
.18141 .6562 m .18258 .65326 L .18037 .65345 L F
.18141 .6562 m .18448 .65544 L .18258 .65326 L F
.78 .707 .783 r
.73644 .39119 m .73708 .39617 L .73999 .39178 L F
.476 .803 1 r
.7402 .39542 m .73708 .39617 L .7366 .39487 L F
.739 .745 .857 r
.7402 .39542 m .73866 .39833 L .73708 .39617 L F
.488 .225 .441 r
.70216 .40304 m .70467 .40423 L .70233 .40427 L F
.70216 .40304 m .70471 .40247 L .70467 .40423 L F
.577 .655 .89 r
.72875 .39827 m .7322 .3977 L .72808 .39581 L F
.72875 .39827 m .73188 .39798 L .7322 .3977 L F
.938 .909 .765 r
.61182 .48683 m .60899 .4888 L .61015 .49019 L F
.61182 .48683 m .61069 .48585 L .60899 .4888 L F
.937 .91 .768 r
.6126 .48251 m .61069 .48585 L .61182 .48683 L F
0 .368 .754 r
.50347 .57233 m .50355 .57269 L .50115 .57019 L F
.50347 .57233 m .50471 .57309 L .50355 .57269 L F
.126 0 .054 r
.56825 .47443 m .56968 .47531 L .57092 .47275 L F
.56825 .47443 m .56758 .47634 L .56968 .47531 L F
.615 .71 .913 r
.70288 .43601 m .70622 .43813 L .70521 .43484 L F
.754 .74 .84 r
.70521 .43484 m .70622 .43813 L .70878 .43535 L F
.682 .617 .777 r
.70622 .43813 m .71005 .43898 L .70878 .43535 L F
.875 .761 .734 r
.4877 .58054 m .48963 .58265 L .49184 .5792 L F
.73 .55 .647 r
.48963 .58265 m .4926 .58226 L .49184 .5792 L F
.48 .341 .613 r
.4926 .58226 m .49437 .57861 L .49184 .5792 L F
.075 0 .289 r
.25143 .57327 m .25275 .57243 L .25326 .57008 L F
.366 .21 .534 r
.25143 .57327 m .25311 .57507 L .25275 .57243 L F
.25143 .57327 m .25128 .57584 L .25311 .57507 L F
0 0 .033 r
.59208 .53007 m .59045 .53157 L .59231 .5282 L F
0 0 0 r
.58959 .53372 m .59045 .53157 L .59208 .53007 L F
.868 .802 .784 r
.7732 .40023 m .7696 .40194 L .77213 .399 L F
.7732 .40023 m .77107 .40354 L .7696 .40194 L F
.489 .346 .612 r
.56991 .53726 m .57232 .53944 L .57196 .53662 L F
.56991 .53726 m .5702 .54034 L .57232 .53944 L F
.664 .826 .398 r
.65568 .42767 m .6556 .42747 L .6554 .42547 L F
.65568 .42767 m .65438 .42994 L .6556 .42747 L F
.423 .786 .995 r
.64522 .41148 m .64717 .41111 L .64382 .41048 L F
.993 .836 .471 r
.65736 .41764 m .65615 .41887 L .6568 .41626 L F
.65736 .41764 m .65683 .4209 L .65615 .41887 L F
.67 .794 .941 r
.29071 .56047 m .29227 .56183 L .29456 .56093 L F
.29456 .56093 m .29227 .56183 L .29071 .56047 L F
.826 .803 .83 r
.7696 .40194 m .76874 .40605 L .76766 .40479 L F
.7696 .40194 m .77107 .40354 L .76874 .40605 L F
0 0 .29 r
.76881 .40627 m .76941 .40813 L .76874 .40605 L F
.912 .586 .109 r
.76909 .40762 m .77051 .41193 L .76975 .41074 L F
.76881 .40627 m .76942 .4083 L .76909 .40762 L F
.76942 .4083 m .77051 .41193 L .76909 .40762 L F
.76936 .40798 m .76975 .41074 L .76941 .40813 L F
.76881 .40627 m .76909 .40762 L .76936 .40798 L F
.76909 .40762 m .76975 .41074 L .76936 .40798 L F
0 0 .253 r
.76881 .40627 m .77051 .41193 L .76941 .40813 L F
.895 .859 .798 r
.76835 .4006 m .7696 .40194 L .76766 .40479 L F
.76835 .4006 m .76766 .40479 L .76708 .40336 L F
0 0 .379 r
.76874 .40605 m .76941 .40813 L .76986 .40847 L F
.76992 .40822 m .76986 .40847 L .7702 .40872 L F
.76874 .40605 m .76986 .40847 L .76992 .40822 L F
.76874 .40605 m .76992 .40822 L .76766 .40479 L F
.76992 .40822 m .7702 .40872 L .76988 .40822 L F
.76992 .40822 m .76988 .40822 L .76766 .40479 L F
.75 .851 .41 r
.76999 .40796 m .76988 .40822 L .76996 .40794 L F
.76999 .40796 m .76996 .40794 L .77003 .40777 L F
.671 .774 .927 r
.77145 .40456 m .77252 .40609 L .76893 .40545 L F
.76893 .40545 m .77252 .40609 L .77145 .40456 L F
.64 .574 .765 r
.77145 .40456 m .7702 .40872 L .76993 .40802 L F
.77145 .40456 m .76993 .40802 L .76893 .40545 L F
.75 .851 .41 r
.77003 .40777 m .76996 .40794 L .77016 .40727 L F
0 0 .478 r
.76718 .4036 m .76798 .40529 L .76988 .40822 L F
.76718 .4036 m .76988 .40822 L .76988 .40817 L F
.76925 .40709 m .76924 .40709 L .76988 .40817 L F
.76988 .40817 m .76988 .40817 L .7702 .40872 L F
.76925 .40709 m .76988 .40817 L .76988 .40817 L F
.76708 .40336 m .76988 .40817 L .76893 .40545 L F
.76988 .40817 m .7702 .40872 L .76993 .40802 L F
.76988 .40817 m .76993 .40802 L .76893 .40545 L F
.75 .851 .41 r
.77145 .40456 m .76988 .40822 L .76988 .40817 L F
.77021 .40716 m .76988 .40817 L .76988 .40785 L F
.77145 .40456 m .76988 .40817 L .77021 .40716 L F
.282 .361 .768 r
.76993 .40802 m .76964 .40876 L .76893 .40545 L F
.75 .851 .41 r
.76988 .40785 m .76964 .40876 L .76973 .40816 L F
.76988 .40822 m .76964 .40876 L .76988 .40785 L F
.76988 .40822 m .76964 .40876 L .76985 .40822 L F
0 0 .478 r
.76988 .40817 m .76988 .40822 L .7702 .40872 L F
0 0 .159 r
.76941 .40813 m .76964 .40876 L .7702 .40872 L F
.282 .361 .768 r
.7702 .40872 m .76964 .40876 L .76993 .40802 L F
.75 .851 .41 r
.76985 .40822 m .76964 .40876 L .76983 .40822 L F
.76988 .40822 m .76983 .40822 L .77016 .40727 L F
.76988 .40785 m .76964 .40876 L .76973 .40816 L F
.77016 .40727 m .76988 .40808 L .76988 .40785 L F
.76988 .40808 m .76964 .40876 L .76988 .40785 L F
.77145 .40456 m .76999 .40796 L .77016 .40727 L F
.671 .774 .927 r
.76928 .40709 m .76973 .40816 L .76964 .40876 L F
.76893 .40545 m .76941 .40708 L .76928 .40709 L F
.76941 .40708 m .76973 .40816 L .76928 .40709 L F
0 0 .478 r
.76708 .40336 m .76718 .4036 L .76924 .40709 L F
.76708 .40336 m .76924 .40709 L .76925 .40709 L F
.76718 .4036 m .76766 .40479 L .76798 .40529 L F
.801 .512 .498 r
.55535 .58553 m .55184 .58493 L .55421 .5843 L F
.563 .783 .981 r
.55535 .58553 m .55421 .5843 L .55184 .58493 L F
.855 .997 .797 r
.55634 .58335 m .55535 .58553 L .55421 .5843 L F
.431 .486 .815 r
.55535 .58553 m .55634 .58335 L .55421 .5843 L F
.55535 .58553 m .55867 .5872 L .55634 .58335 L F
.69 .68 .835 r
.48304 .6002 m .48125 .60271 L .48092 .59967 L F
.664 .643 .818 r
.48304 .6002 m .48474 .60299 L .48125 .60271 L F
.671 .48 .618 r
.48474 .60299 m .48237 .60434 L .48125 .60271 L F
.976 .903 .677 r
.62566 .44329 m .6265 .44534 L .62739 .44239 L F
.741 .348 .307 r
.62339 .44642 m .6265 .44534 L .62566 .44329 L F
.62339 .44642 m .62702 .44693 L .6265 .44534 L F
.465 .803 .999 r
.19236 .53934 m .19629 .53987 L .19414 .54026 L F
.82 .891 .893 r
.21147 .63319 m .20714 .63466 L .20908 .63353 L F
.707 .977 .914 r
.21184 .63181 m .21147 .63319 L .20908 .63353 L F
.274 0 .166 r
.16525 .5644 m .16421 .56602 L .16231 .56662 L F
.29 0 .221 r
.16717 .56356 m .16421 .56602 L .16525 .5644 L F
.647 .394 .523 r
.44436 .60817 m .44186 .60581 L .44434 .60564 L F
.44436 .60817 m .44017 .60851 L .44186 .60581 L F
.87 .895 .848 r
.62734 .43968 m .62739 .44239 L .62961 .43981 L F
.962 .936 .706 r
.62734 .43968 m .62566 .44329 L .62739 .44239 L F
.485 .182 .377 r
.4389 .60898 m .43584 .61128 L .43609 .60912 L F
0 0 0 r
.59933 .44047 m .6 .44019 L .60147 .4393 L F
.576 .38 .579 r
.59933 .44047 m .59914 .44662 L .60127 .44376 L F
.154 .342 .799 r
.49935 .59218 m .49831 .59384 L .49675 .5905 L F
.733 .636 .751 r
.49935 .59218 m .5005 .59543 L .49831 .59384 L F
0 0 0 r
.63077 .40559 m .63313 .40455 L .63389 .40377 L F
.418 .122 .353 r
.63077 .40559 m .63333 .40694 L .63313 .40455 L F
.63077 .40559 m .63054 .40781 L .63333 .40694 L F
.59 .784 .972 r
.1755 .62972 m .17345 .63045 L .17162 .62902 L F
0 0 .19 r
.58783 .51001 m .58638 .51352 L .58725 .51174 L F
0 0 .155 r
.58725 .51174 m .58638 .51352 L .58616 .51589 L F
.401 .577 .91 r
.64285 .42912 m .64437 .42785 L .64104 .42693 L F
.64285 .42912 m .64523 .42943 L .64437 .42785 L F
.791 .584 .621 r
.4495 .56922 m .45265 .57288 L .45115 .56924 L F
.4495 .56922 m .45034 .57379 L .45265 .57288 L F
.377 0 .031 r
.44872 .57519 m .45265 .57288 L .45034 .57379 L F
.775 .546 .587 r
.45771 .56892 m .45311 .56855 L .45362 .56617 L F
0 0 0 r
.45439 .56801 m .4535 .56869 L .45311 .56855 L F
.22 .404 .832 r
.45115 .56924 m .45265 .57288 L .45374 .57112 L F
.45115 .56924 m .45374 .57112 L .45311 .56855 L F
.335 0 .052 r
.45374 .57112 m .45771 .56892 L .45311 .56855 L F
0 0 0 r
.4535 .56869 m .45185 .56993 L .45264 .56906 L F
.4535 .56869 m .45264 .56906 L .45311 .56855 L F
.22 .404 .832 r
.45156 .56954 m .45265 .57288 L .45374 .57112 L F
.45115 .56924 m .45132 .56965 L .45156 .56954 L F
.45132 .56965 m .45265 .57288 L .45156 .56954 L F
.698 .562 .697 r
.45113 .57494 m .45374 .57112 L .45265 .57288 L F
.766 .65 .092 r
.52929 .5908 m .52922 .58955 L .52936 .58709 L F
0 0 .407 r
.52929 .5908 m .53021 .59182 L .52922 .58955 L F
.52929 .5908 m .5303 .5934 L .53021 .59182 L F
0 0 0 r
.66986 .39962 m .67166 .39882 L .6727 .39758 L F
.738 .647 .759 r
.70878 .43535 m .71005 .43898 L .71249 .43597 L F
.418 .771 .996 r
.49438 .59075 m .49675 .5905 L .4932 .58985 L F
.386 .074 .308 r
.55879 .60258 m .55849 .60516 L .55604 .60575 L F
.246 0 .19 r
.55879 .60258 m .56029 .60399 L .55849 .60516 L F
.55879 .60258 m .56107 .60234 L .56029 .60399 L F
.738 .605 .71 r
.44286 .58231 m .43934 .58444 L .43932 .58191 L F
.719 .564 .679 r
.44286 .58231 m .44282 .58556 L .43934 .58444 L F
.584 .453 .668 r
.44616 .58489 m .44286 .58231 L .44561 .58181 L F
.44616 .58489 m .44282 .58556 L .44286 .58231 L F
.374 .434 .795 r
.25261 .56402 m .25272 .55989 L .25113 .56196 L F
.25261 .56402 m .254 .56346 L .25272 .55989 L F
.738 .838 .926 r
.68184 .43868 m .67839 .43856 L .68061 .43749 L F
.813 .881 .895 r
.68439 .43634 m .68184 .43868 L .68061 .43749 L F
.108 0 0 r
.63313 .40455 m .63644 .4029 L .63389 .40377 L F
.95 .885 .734 r
.6126 .48251 m .61451 .48113 L .61523 .47953 L F
.706 .81 .93 r
.72223 .42226 m .71833 .42263 L .72101 .42055 L F
.668 .731 .896 r
.72343 .41939 m .72223 .42226 L .72101 .42055 L F
.72343 .41939 m .72451 .42129 L .72223 .42226 L F
.022 0 .025 r
.54998 .49179 m .55201 .49121 L .55271 .48921 L F
.029 0 .047 r
.54998 .49179 m .54937 .49395 L .55201 .49121 L F
.732 .543 .636 r
.48358 .58483 m .48792 .58507 L .4862 .58161 L F
.669 .517 .67 r
.4862 .58161 m .48942 .58486 L .4877 .58054 L F
.4862 .58161 m .48792 .58507 L .48942 .58486 L F
.967 .918 .703 r
.60818 .4911 m .61015 .49019 L .60899 .4888 L F
.60818 .4911 m .60903 .49205 L .61015 .49019 L F
.044 0 0 r
.16093 .55206 m .16302 .55134 L .16497 .54962 L F
.029 0 0 r
.16497 .54962 m .16508 .55058 L .16734 .54939 L F
.16497 .54962 m .16302 .55134 L .16508 .55058 L F
.786 .869 .91 r
.70138 .42762 m .6973 .42874 L .70046 .42645 L F
.665 .788 .94 r
.70259 .42507 m .70138 .42762 L .70046 .42645 L F
.70259 .42507 m .70386 .42657 L .70138 .42762 L F
.62 .807 .972 r
.73026 .38524 m .72646 .38686 L .72516 .38477 L F
.692 .622 .773 r
.6747 .4503 m .67608 .45411 L .67808 .4528 L F
.436 .181 .428 r
.57935 .55481 m .5766 .55781 L .57687 .55528 L F
.573 .817 .991 r
.7436 .38144 m .74109 .38217 L .74006 .38095 L F
.7436 .38144 m .74109 .38217 L .74006 .38095 L F
.319 .137 .47 r
.62415 .43274 m .62245 .43545 L .6239 .43345 L F
.804 .981 .703 r
.62245 .43545 m .62094 .4368 L .6239 .43345 L F
.263 .717 .955 r
.49569 .59732 m .49446 .59664 L .492 .59665 L F
.064 .162 .656 r
.49569 .59732 m .49683 .59571 L .49446 .59664 L F
.49569 .59732 m .4976 .59914 L .49683 .59571 L F
.569 .325 .506 r
.45985 .57356 m .45894 .57677 L .45637 .57649 L F
.668 .423 .541 r
.46243 .57542 m .45985 .57356 L .46242 .5731 L F
.46243 .57542 m .45894 .57677 L .45985 .57356 L F
.873 .681 .64 r
.61181 .47656 m .61513 .47468 L .61372 .47332 L F
.61181 .47656 m .61444 .47767 L .61513 .47468 L F
.836 .767 .786 r
.75509 .40532 m .75571 .40871 L .75285 .40819 L F
0 .341 .668 r
.21693 .65863 m .21847 .65921 L .22024 .65988 L F
.195 .724 .824 r
.21847 .65921 m .2218 .65897 L .22024 .65988 L F
.487 .306 .56 r
.22236 .66228 m .22024 .65988 L .2218 .65897 L F
.211 0 .158 r
.58976 .45717 m .58905 .45873 L .5919 .45622 L F
.717 .511 .611 r
.7416 .39996 m .74056 .40406 L .73897 .40251 L F
.453 .254 .519 r
.74456 .40163 m .7416 .39996 L .74483 .39922 L F
.74456 .40163 m .74056 .40406 L .7416 .39996 L F
.498 .773 .993 r
.39974 .64177 m .40177 .64071 L .39827 .63845 L F
.39974 .64177 m .40166 .6412 L .40177 .64071 L F
.751 .236 0 r
.40352 .64454 m .4018 .64408 L .39974 .64177 L F
.429 .304 .608 r
.39974 .64177 m .4018 .64408 L .40166 .6412 L F
.236 .312 .739 r
.47087 .56998 m .47204 .57363 L .473 .57234 L F
.93 .587 .361 r
.47424 .57328 m .473 .57234 L .47204 .57363 L F
.496 .191 .379 r
.60656 .43288 m .60742 .43435 L .60705 .43481 L F
.242 .041 .395 r
.60705 .43481 m .6104 .43202 L .61053 .43107 L F
.60742 .43435 m .61053 .43107 L .60991 .4313 L F
.60705 .43481 m .60746 .43436 L .60742 .43435 L F
.60746 .43436 m .61053 .43107 L .60742 .43435 L F
.60715 .43424 m .60991 .4313 L .60752 .43217 L F
.60705 .43481 m .60742 .43435 L .60715 .43424 L F
.60742 .43435 m .60991 .4313 L .60715 .43424 L F
.496 .191 .379 r
.60748 .43445 m .60813 .43556 L .60705 .43481 L F
.26 .092 .454 r
.60813 .43556 m .61022 .43328 L .60751 .43459 L F
.60813 .43556 m .60751 .43459 L .60705 .43481 L F
.496 .191 .379 r
.60742 .43435 m .60748 .43445 L .60705 .43481 L F
.60742 .43435 m .60746 .43451 L .60748 .43445 L F
.60746 .43451 m .60777 .43574 L .60751 .43459 L F
.242 .041 .395 r
.60705 .43481 m .60751 .43459 L .60748 .43445 L F
.496 .191 .379 r
.60746 .43451 m .60751 .43459 L .60748 .43445 L F
.133 .028 .459 r
.60656 .43288 m .60705 .43481 L .60715 .43424 L F
.496 .191 .379 r
.60656 .43288 m .60715 .43424 L .60742 .43435 L F
.133 .028 .459 r
.60656 .43288 m .60715 .43424 L .60752 .43217 L F
.496 .191 .379 r
.60656 .43288 m .60713 .43424 L .60715 .43424 L F
.60713 .43424 m .60777 .43574 L .60742 .43435 L F
.60713 .43424 m .60564 .43685 L .60777 .43574 L F
.60656 .43288 m .60632 .43392 L .60713 .43424 L F
.60632 .43392 m .60564 .43685 L .60713 .43424 L F
.60748 .43445 m .60777 .43574 L .60813 .43556 L F
.242 .041 .395 r
.60748 .43445 m .61022 .43328 L .6104 .43202 L F
.60751 .43459 m .61022 .43328 L .60748 .43445 L F
.547 .466 .715 r
.49923 .58764 m .49701 .58615 L .49926 .58507 L F
.867 .922 .862 r
.19642 .70743 m .19226 .70971 L .19358 .70989 L F
.487 .46 .753 r
.19642 .70743 m .19733 .70366 L .19533 .7039 L F
.776 .739 .819 r
.70962 .42577 m .70588 .42555 L .709 .42288 L F
.70962 .42577 m .70755 .42711 L .70588 .42555 L F
.737 .78 .888 r
.71243 .42335 m .70962 .42577 L .709 .42288 L F
.728 .748 .868 r
.71396 .42449 m .70962 .42577 L .71243 .42335 L F
.378 .016 .217 r
.5796 .48321 m .57853 .48537 L .57644 .48588 L F
.771 .619 .692 r
.58205 .48262 m .57853 .48537 L .5796 .48321 L F
.303 .163 .519 r
.4495 .56922 m .45115 .56924 L .45116 .56654 L F
.655 .816 .961 r
.19706 .63547 m .19631 .63786 L .19485 .63557 L F
.19706 .63547 m .1992 .63688 L .19631 .63786 L F
.494 .249 .472 r
.27986 .58153 m .27759 .58211 L .28033 .57906 L F
.385 .504 .856 r
.28161 .57706 m .28033 .57906 L .27864 .57583 L F
.28161 .57706 m .28159 .57835 L .28033 .57906 L F
.397 .163 .439 r
.28194 .58076 m .28033 .57906 L .28159 .57835 L F
.28194 .58076 m .27986 .58153 L .28033 .57906 L F
.479 .798 1 r
.53896 .54559 m .53911 .54452 L .54082 .54586 L F
.782 .564 .605 r
.54082 .54586 m .53961 .54891 L .53896 .54559 L F
.5 .808 1 r
.54082 .54586 m .54167 .54543 L .53911 .54452 L F
.138 0 .279 r
.54082 .54586 m .54167 .54543 L .53961 .54891 L F
.54082 .54586 m .54167 .54543 L .53961 .54891 L F
.613 .934 .713 r
.47409 .5919 m .47514 .59082 L .47693 .58958 L F
.727 .735 .857 r
.70588 .42555 m .70755 .42711 L .70386 .42657 L F
.404 .44 .784 r
.25023 .55838 m .25113 .56196 L .25272 .55989 L F
0 0 0 r
.73934 .43228 m .74247 .43022 L .7419 .43184 L F
.062 0 .1 r
.7419 .43184 m .74247 .43022 L .74426 .42924 L F
.413 0 0 r
.68274 .40781 m .6836 .40682 L .68442 .40738 L F
0 0 0 r
.55738 .49785 m .55621 .49948 L .55503 .50111 L F
.12 .257 .732 r
.39702 .63241 m .39808 .63587 L .39919 .63444 L F
0 0 .427 r
.39808 .63587 m .39944 .63685 L .39919 .63444 L F
.39808 .63587 m .39827 .63845 L .39944 .63685 L F
.105 .574 .912 r
.7495 .43471 m .75293 .43616 L .75218 .43536 L F
.605 .905 .984 r
.75218 .43536 m .75293 .43616 L .7553 .43513 L F
.096 .262 .745 r
.53307 .60104 m .53417 .60226 L .53299 .59901 L F
.703 .916 .967 r
.21693 .65863 m .21425 .66004 L .21274 .65942 L F
.87 .895 .848 r
.62734 .43968 m .62961 .43981 L .62857 .43828 L F
.729 .843 .934 r
.62857 .43828 m .62961 .43981 L .6318 .43849 L F
.554 .275 .447 r
.57966 .53036 m .57691 .52846 L .57687 .53075 L F
.57966 .53036 m .5793 .52764 L .57691 .52846 L F
0 0 0 r
.5346 .5661 m .53613 .56393 L .53676 .56305 L F
.118 .655 .853 r
.62719 .43368 m .63077 .434 L .62819 .43519 L F
.403 .735 .992 r
.74744 .39701 m .74389 .39596 L .74553 .39707 L F
.354 0 .14 r
.74483 .39922 m .74744 .39701 L .74553 .39707 L F
.242 .704 .948 r
.23462 .55465 m .23505 .554 L .23315 .55377 L F
.23462 .55465 m .23687 .55473 L .23505 .554 L F
.927 .813 .713 r
.53285 .53018 m .53598 .52806 L .53435 .52694 L F
.53285 .53018 m .53464 .53158 L .53598 .52806 L F
.583 .574 .809 r
.42333 .57913 m .42448 .5798 L .42587 .57954 L F
.42448 .5798 m .42754 .5816 L .42587 .57954 L F
0 0 0 r
.42809 .57836 m .4266 .5794 L .42587 .57954 L F
.4266 .5794 m .42501 .5805 L .42587 .57954 L F
.411 .144 .395 r
.42501 .5805 m .42333 .57913 L .42587 .57954 L F
.42501 .5805 m .42282 .58143 L .42333 .57913 L F
0 0 0 r
.42195 .57295 m .42038 .57453 L .42299 .57192 L F
.642 .5 .674 r
.51302 .59062 m .51034 .5939 L .50956 .5921 L F
.683 .726 .883 r
.7296 .42995 m .73307 .43081 L .73214 .42833 L F
.603 .621 .842 r
.73307 .43081 m .73467 .4279 L .73214 .42833 L F
.73307 .43081 m .73568 .43027 L .73467 .4279 L F
.463 .299 .573 r
.24278 .59325 m .24473 .59059 L .24244 .59101 L F
0 .207 .721 r
.52418 .57587 m .52564 .57942 L .52561 .57802 L F
0 .163 .688 r
.52564 .57942 m .52758 .58015 L .52561 .57802 L F
.52564 .57942 m .52699 .58168 L .52758 .58015 L F
.378 0 0 r
.24094 .55478 m .23895 .55539 L .23687 .55473 L F
.395 0 0 r
.24304 .55566 m .23895 .55539 L .24094 .55478 L F
.823 .954 .902 r
.7393 .42213 m .74047 .42316 L .73833 .42465 L F
.779 .947 .931 r
.74265 .42123 m .74047 .42316 L .7393 .42213 L F
.506 .616 .895 r
.74289 .42423 m .74047 .42316 L .74265 .42123 L F
.984 .874 .513 r
.76313 .41371 m .76427 .41227 L .76301 .41088 L F
.76313 .41371 m .76373 .41473 L .76427 .41227 L F
.585 .517 .744 r
.46449 .58512 m .46254 .58786 L .46079 .58528 L F
.46449 .58512 m .465 .58746 L .46254 .58786 L F
.305 .572 .933 r
.75481 .38149 m .75362 .38198 L .75243 .38044 L F
.263 .281 .691 r
.7561 .38299 m .75362 .38198 L .75481 .38149 L F
.74 .964 .937 r
.53016 .54361 m .52886 .54548 L .53285 .54265 L F
.544 0 0 r
.53054 .54719 m .53202 .54801 L .52886 .54548 L F
.53054 .54719 m .52886 .54548 L .53016 .54361 L F
.034 0 0 r
.45231 .5581 m .45469 .5582 L .45603 .55825 L F
0 .354 .822 r
.4574 .55827 m .45603 .55825 L .45469 .5582 L F
.366 0 0 r
.45603 .55825 m .45864 .55969 L .45997 .56035 L F
0 .354 .822 r
.4574 .55827 m .45864 .55969 L .45603 .55825 L F
.422 .554 .883 r
.55676 .56588 m .55699 .56765 L .55876 .56578 L F
.22 .205 .628 r
.55756 .56974 m .55876 .56578 L .55699 .56765 L F
.784 .996 .795 r
.47693 .58958 m .47637 .58938 L .47714 .58936 L F
.47693 .58958 m .47514 .59082 L .47637 .58938 L F
.449 .283 .563 r
.24992 .58199 m .25185 .58406 L .25154 .5815 L F
.24992 .58199 m .24998 .58495 L .25185 .58406 L F
.4 .25 .56 r
.27547 .58774 m .27552 .59029 L .27365 .59078 L F
.361 .169 .48 r
.27521 .59275 m .27365 .59078 L .27552 .59029 L F
.27521 .59275 m .27333 .59352 L .27365 .59078 L F
.328 .322 .7 r
.7855 .40474 m .78608 .40715 L .78413 .40898 L F
.32 .309 .69 r
.78413 .40898 m .78608 .40715 L .78653 .41075 L F
.253 .253 .665 r
.22834 .61529 m .2302 .61715 L .23075 .61416 L F
.22834 .61529 m .2291 .61775 L .2302 .61715 L F
.406 .074 .287 r
.55362 .60629 m .55541 .60737 L .5531 .60793 L F
.55362 .60629 m .55604 .60575 L .55541 .60737 L F
.295 .03 .331 r
.23577 .60562 m .23841 .6051 L .23805 .6028 L F
.177 .04 .444 r
.23805 .6028 m .24005 .60179 L .24028 .59914 L F
.266 .012 .331 r
.23805 .6028 m .23976 .60435 L .24005 .60179 L F
.23805 .6028 m .23841 .6051 L .23976 .60435 L F
.21 0 0 r
.60147 .4393 m .60268 .43983 L .60284 .43766 L F
.60147 .4393 m .6 .44019 L .60268 .43983 L F
.352 .316 .678 r
.38378 .61167 m .38397 .61514 L .38609 .61369 L F
.497 .444 .728 r
.38452 .6176 m .38609 .61369 L .38397 .61514 L F
.743 .669 .779 r
.71498 .43305 m .71249 .43597 L .71481 .43514 L F
.738 .683 .798 r
.71481 .43514 m .71734 .43212 L .71498 .43305 L F
.335 .026 .284 r
.19721 .70124 m .19779 .69931 L .19496 .70156 L F
.437 .404 .724 r
.19496 .70156 m .19733 .70366 L .19721 .70124 L F
.512 .409 .674 r
.19533 .7039 m .19733 .70366 L .19496 .70156 L F
.16 .671 .899 r
.23055 .53996 m .23271 .54002 L .23447 .54055 L F
.099 .651 .809 r
.23271 .54002 m .23673 .54016 L .23447 .54055 L F
.745 .397 .392 r
.42841 .65635 m .42658 .65858 L .4246 .65584 L F
.665 .293 .331 r
.42841 .65635 m .4306 .65855 L .42658 .65858 L F
.662 .607 .783 r
.60877 .4471 m .60615 .45005 L .60526 .44724 L F
.733 .758 .872 r
.71243 .42335 m .71596 .42389 L .71396 .42449 L F
.163 0 0 r
.19629 .53987 m .19848 .54022 L .20022 .54037 L F
.499 0 0 r
.19848 .54022 m .20241 .53989 L .20022 .54037 L F
.521 .265 .467 r
.69737 .39677 m .69992 .39627 L .69999 .3942 L F
.562 .297 .473 r
.69992 .39627 m .70308 .39345 L .69999 .3942 L F
.179 0 0 r
.47885 .60637 m .47809 .60764 L .47587 .6079 L F
.113 .202 .679 r
.47885 .60637 m .48001 .60499 L .47772 .60605 L F
.117 0 0 r
.48237 .60434 m .48118 .6065 L .47885 .60637 L F
.113 .202 .679 r
.47885 .60637 m .48118 .6065 L .48001 .60499 L F
.296 .592 .946 r
.50401 .5506 m .50605 .55222 L .506 .55091 L F
0 .278 .781 r
.50605 .55222 m .50733 .55331 L .506 .55091 L F
.575 .798 .984 r
.1793 .63036 m .1755 .62972 L .17763 .62912 L F
.358 .701 .984 r
.18103 .63004 m .1793 .63036 L .17763 .62912 L F
.552 .586 .842 r
.18298 .63295 m .1793 .63036 L .18103 .63004 L F
.275 0 .144 r
.16295 .56855 m .16231 .56662 L .16421 .56602 L F
.16295 .56855 m .16085 .56931 L .16231 .56662 L F
.904 .777 .71 r
.61769 .4617 m .62096 .45953 L .61957 .45823 L F
.61769 .4617 m .61952 .46283 L .62096 .45953 L F
.518 .218 .397 r
.62274 .41127 m .62531 .41097 L .62562 .40903 L F
.342 .069 .347 r
.62562 .40903 m .6276 .40999 L .62795 .40861 L F
.62562 .40903 m .62531 .41097 L .6276 .40999 L F
.495 0 0 r
.44675 .55676 m .4502 .5575 L .44739 .55708 L F
.028 0 0 r
.21083 .55199 m .20684 .55304 L .20912 .55193 L F
.771 .706 .79 r
.71472 .42043 m .71596 .42389 L .71243 .42335 L F
.717 .678 .811 r
.71833 .42263 m .71596 .42389 L .71472 .42043 L F
.839 .893 .879 r
.7576 .43389 m .76118 .43266 L .7599 .43143 L F
.16 0 0 r
.63862 .40162 m .64109 .40118 L .64231 .40021 L F
.58 .057 0 r
.64109 .40118 m .64481 .40163 L .64231 .40021 L F
.765 .484 .509 r
.55381 .55681 m .55601 .5531 L .55437 .55469 L F
.55381 .55681 m .55746 .55729 L .55601 .5531 L F
.603 .399 .577 r
.55746 .55729 m .56005 .55435 L .55601 .5531 L F
.843 .563 .514 r
.43492 .65552 m .43802 .65414 L .43559 .65366 L F
.43492 .65552 m .43782 .65614 L .43802 .65414 L F
.136 0 .17 r
.56024 .4948 m .55953 .4975 L .55738 .49785 L F
.042 0 0 r
.55953 .4975 m .55621 .49948 L .55738 .49785 L F
.501 .774 .993 r
.48724 .56159 m .48576 .56282 L .48424 .56258 L F
.48724 .56159 m .48853 .56272 L .48576 .56282 L F
.279 .415 .821 r
.78125 .3952 m .78281 .39539 L .78147 .39728 L F
.209 .298 .737 r
.78281 .39539 m .78254 .39884 L .78147 .39728 L F
.779 .839 .898 r
.64629 .4289 m .64523 .42943 L .64783 .42951 L F
.864 .795 .78 r
.64629 .4289 m .64783 .42951 L .65021 .42476 L F
.744 .5 .561 r
.42904 .65287 m .43296 .65058 L .42945 .65127 L F
.53 .844 .54 r
.52302 .51504 m .5216 .51647 L .52282 .51519 L F
.577 .939 .81 r
.52282 .51519 m .5216 .51647 L .51966 .51706 L F
0 0 .112 r
.59231 .5282 m .59445 .52464 L .59331 .52642 L F
0 0 0 r
.59208 .53007 m .59231 .5282 L .59331 .52642 L F
.032 .142 .647 r
.20742 .69447 m .20795 .69758 L .20627 .69545 L F
.339 .23 .581 r
.20795 .69758 m .2064 .69823 L .20627 .69545 L F
.566 .59 .837 r
.77987 .39205 m .77786 .39571 L .77688 .39286 L F
.77987 .39205 m .78125 .3952 L .77786 .39571 L F
.671 .48 .618 r
.48474 .60299 m .48473 .60548 L .48237 .60434 L F
.743 .671 .78 r
.48702 .60023 m .48474 .60299 L .48304 .6002 L F
.704 .61 .749 r
.48702 .60023 m .48753 .60299 L .48474 .60299 L F
.626 .389 .539 r
.48753 .60299 m .48473 .60548 L .48474 .60299 L F
.512 .354 .603 r
.27861 .57322 m .27864 .57583 L .27648 .57634 L F
.589 .727 .939 r
.49906 .57004 m .49551 .56898 L .49777 .56877 L F
.267 .629 .962 r
.49777 .56877 m .49972 .56886 L .49906 .57004 L F
.24 .596 .95 r
.49972 .56886 m .50115 .57019 L .49906 .57004 L F
0 0 0 r
.50233 .59126 m .50199 .59275 L .50291 .59051 L F
.846 .915 .881 r
.74615 .38076 m .74714 .38192 L .7443 .38428 L F
.508 .786 .995 r
.74998 .3811 m .74714 .38192 L .74615 .38076 L F
.382 .159 .446 r
.60758 .42651 m .60996 .42584 L .60998 .42344 L F
.438 .238 .509 r
.60757 .42872 m .60996 .42584 L .60758 .42651 L F
.252 .614 .956 r
.67118 .40647 m .67367 .4059 L .67046 .4049 L F
.67118 .40647 m .67446 .40693 L .67367 .4059 L F
.719 .697 .828 r
.71734 .43212 m .72097 .43278 L .72014 .42939 L F
.768 .727 .814 r
.72014 .42939 m .72097 .43278 L .72337 .42998 L F
.786 .662 .727 r
.41074 .62731 m .4093 .62973 L .40808 .62603 L F
.626 .389 .539 r
.48753 .60299 m .4874 .60552 L .48473 .60548 L F
.559 .398 .62 r
.49012 .59963 m .48753 .60299 L .48702 .60023 L F
.49012 .59963 m .49044 .6025 L .48753 .60299 L F
.478 .237 .47 r
.49044 .6025 m .4874 .60552 L .48753 .60299 L F
.927 .708 .22 r
.59125 .50044 m .59075 .49737 L .59208 .49844 L F
.35 .032 .278 r
.5604 .48067 m .55978 .4825 L .56272 .47994 L F
.23 0 .089 r
.45465 .58438 m .45757 .58217 L .45509 .58197 L F
0 0 0 r
.58783 .51001 m .58725 .51174 L .5888 .50823 L F
.988 .761 .506 r
.58324 .48648 m .58253 .48651 L .58205 .48262 L F
.926 .552 .281 r
.58324 .48648 m .58227 .48767 L .58253 .48651 L F
.468 .505 .813 r
.5848 .48515 m .58324 .48648 L .58205 .48262 L F
.54 .238 .404 r
.5848 .48515 m .58227 .48767 L .58324 .48648 L F
.472 .344 .625 r
.57014 .58458 m .57039 .58722 L .5681 .58729 L F
.332 .19 .533 r
.57039 .58722 m .56813 .59074 L .5681 .58729 L F
.837 .719 .734 r
.74993 .39632 m .75105 .39981 L .75116 .39827 L F
.228 .718 .923 r
.75105 .39981 m .7528 .39931 L .75116 .39827 L F
.75105 .39981 m .75374 .39981 L .7528 .39931 L F
.214 .415 .843 r
.27414 .54836 m .27429 .55117 L .27255 .54795 L F
.27414 .54836 m .27576 .55117 L .27429 .55117 L F
.672 .925 .621 r
.51267 .5212 m .51112 .523 L .50984 .52396 L F
.812 .575 .58 r
.5059 .60001 m .50182 .60137 L .50352 .60061 L F
.5059 .60001 m .50552 .60246 L .50182 .60137 L F
.353 .157 .47 r
.50768 .60195 m .5059 .60001 L .50628 .59844 L F
.50768 .60195 m .50552 .60246 L .5059 .60001 L F
0 0 .281 r
.58244 .52234 m .58311 .52348 L .58402 .52146 L F
.58244 .52234 m .58226 .52482 L .58311 .52348 L F
.407 .567 .9 r
.74755 .38603 m .74849 .38798 L .75047 .38769 L F
.409 .538 .875 r
.74849 .38798 m .7515 .38883 L .75047 .38769 L F
.563 .583 .832 r
.74849 .38798 m .75229 .39086 L .7515 .38883 L F
.55 .371 .591 r
.44877 .65364 m .449 .65632 L .44639 .65669 L F
.44877 .65364 m .449 .65632 L .44639 .65669 L F
.926 .741 .632 r
.5503 .56637 m .55153 .56179 L .549 .56288 L F
.723 .678 .805 r
.70878 .43535 m .71249 .43597 L .71144 .43259 L F
.76 .698 .793 r
.71144 .43259 m .71249 .43597 L .71498 .43305 L F
.592 .377 .557 r
.56762 .48885 m .56518 .49165 L .56568 .48988 L F
0 0 .25 r
.77757 .42985 m .77676 .42977 L .77872 .4287 L F
.77757 .42985 m .77658 .4324 L .77676 .42977 L F
.92 .534 .248 r
.41991 .64712 m .42179 .65174 L .42287 .65115 L F
.948 .597 .297 r
.42179 .65174 m .42152 .65212 L .42287 .65115 L F
.656 .133 0 r
.42152 .65212 m .42526 .65294 L .42287 .65115 L F
.407 .201 .485 r
.57431 .53355 m .57213 .53431 L .57196 .53662 L F
.445 .285 .57 r
.44432 .59088 m .44653 .5929 L .44683 .59088 L F
.44432 .59088 m .44452 .59366 L .44653 .5929 L F
.494 .595 .883 r
.41126 .63222 m .41062 .63504 L .40969 .63201 L F
.41126 .63222 m .41331 .63508 L .41062 .63504 L F
.274 .494 .888 r
.18361 .6313 m .18298 .63295 L .18103 .63004 L F
.406 .647 .956 r
.1849 .63296 m .18298 .63295 L .18361 .6313 L F
.275 .309 .716 r
.43237 .61595 m .42995 .61546 L .43227 .61386 L F
.43237 .61595 m .43121 .61748 L .42995 .61546 L F
.936 .827 .711 r
.67403 .44678 m .67586 .44777 L .6747 .4503 L F
.409 .209 .494 r
.58152 .54936 m .58368 .54622 L .58369 .5485 L F
.402 .299 .622 r
.58357 .5508 m .58152 .54936 L .58369 .5485 L F
.58357 .5508 m .58176 .55187 L .58152 .54936 L F
.883 .927 .847 r
.42559 .63844 m .42415 .63766 L .42545 .63606 L F
.314 0 .153 r
.42559 .63844 m .42883 .63765 L .42949 .63621 L F
.264 .599 .951 r
.42545 .63606 m .42883 .63765 L .42559 .63844 L F
0 .133 .68 r
.54071 .58892 m .54109 .5904 L .53958 .5875 L F
.626 .342 .468 r
.54109 .5904 m .54329 .59295 L .54304 .59126 L F
.669 .152 0 r
.54179 .59177 m .54109 .5904 L .54071 .58892 L F
.54179 .59177 m .54329 .59295 L .54109 .5904 L F
.338 .435 .814 r
.21623 .66762 m .21594 .6639 L .21335 .66361 L F
.21623 .66762 m .21738 .66777 L .21594 .6639 L F
.043 .567 .867 r
.40503 .64505 m .4018 .64408 L .40352 .64454 L F
.352 .814 .714 r
.72019 .38741 m .71641 .38895 L .71961 .38713 L F
.63 .95 .941 r
.72173 .38564 m .72272 .38612 L .72019 .38741 L F
.402 .746 .993 r
.53571 .57202 m .53697 .57306 L .53437 .57262 L F
.538 .336 .554 r
.53697 .57306 m .53451 .57629 L .53437 .57262 L F
.53697 .57306 m .53697 .5756 L .53451 .57629 L F
.898 .698 .188 r
.53654 .5735 m .53697 .57306 L .53571 .57202 L F
.53654 .5735 m .53697 .5756 L .53697 .57306 L F
.594 .54 .764 r
.1963 .69453 m .19779 .69931 L .19973 .69807 L F
.626 .297 .394 r
.19721 .70124 m .19996 .70075 L .19779 .69931 L F
.505 .369 .629 r
.19779 .69931 m .19996 .70075 L .19973 .69807 L F
.511 .178 .34 r
.43584 .61128 m .43227 .61386 L .43484 .61042 L F
.449 .594 .905 r
.7515 .38883 m .75229 .39086 L .75379 .38885 L F
.397 .521 .866 r
.75229 .39086 m .7547 .39142 L .75379 .38885 L F
.638 .573 .765 r
.75229 .39086 m .75593 .39384 L .7547 .39142 L F
.434 .161 .399 r
.44127 .58663 m .43934 .58444 L .44282 .58556 L F
.53 .001 0 r
.4452 .58681 m .44127 .58663 L .44282 .58556 L F
.486 .181 .374 r
.44616 .58489 m .4452 .58681 L .44282 .58556 L F
.158 0 .041 r
.47568 .60391 m .47257 .60599 L .47541 .60455 L F
.507 .202 .385 r
.47481 .60894 m .4752 .61077 L .47264 .61105 L F
.47587 .6079 m .47565 .60886 L .47481 .60894 L F
.47565 .60886 m .4752 .61077 L .47481 .60894 L F
.466 .225 .463 r
.47809 .60764 m .4752 .61077 L .47587 .6079 L F
.573 .467 .695 r
.47257 .60599 m .47287 .60911 L .476 .60858 L F
.47287 .60911 m .47289 .60924 L .47396 .60901 L F
.47287 .60911 m .47396 .60901 L .476 .60858 L F
.47257 .60599 m .476 .60858 L .47541 .60455 L F
.447 .463 .782 r
.16953 .62871 m .17162 .62902 L .1699 .62979 L F
.512 .843 .998 r
.24054 .5403 m .23673 .54016 L .23891 .53957 L F
.485 .823 .999 r
.23891 .53957 m .24269 .53989 L .24054 .5403 L F
.267 .753 .92 r
.22734 .5532 m .22528 .55262 L .22321 .55284 L F
.348 .798 .95 r
.22923 .55264 m .22528 .55262 L .22734 .5532 L F
0 0 0 r
.59919 .51383 m .60047 .51019 L .59998 .51196 L F
.805 .924 .544 r
.5981 .51537 m .59919 .51383 L .59998 .51196 L F
.705 .556 .682 r
.48603 .59651 m .49012 .59963 L .48825 .59596 L F
.48603 .59651 m .48702 .60023 L .49012 .59963 L F
.672 .629 .798 r
.4244 .61242 m .42559 .61519 L .4214 .61415 L F
.714 .529 .638 r
.5737 .55807 m .5742 .56061 L .57117 .56084 L F
.546 .363 .585 r
.5766 .55781 m .5742 .56061 L .5737 .55807 L F
.397 .76 .993 r
.2051 .67032 m .20722 .67012 L .20722 .67141 L F
.2051 .67032 m .20722 .67012 L .20722 .67141 L F
.421 .238 .525 r
.385 .60281 m .38695 .60224 L .38699 .59975 L F
.419 .254 .549 r
.38503 .60534 m .38695 .60224 L .385 .60281 L F
.173 .016 .413 r
.5864 .54032 m .588 .53701 L .5877 .53929 L F
.117 0 .407 r
.58626 .5427 m .5864 .54032 L .5877 .53929 L F
.524 .32 .545 r
.57104 .56306 m .56855 .56361 L .56858 .56111 L F
.574 .305 .471 r
.57117 .56084 m .57104 .56306 L .56858 .56111 L F
0 0 0 r
.17342 .56165 m .17354 .56111 L .17548 .56019 L F
.17342 .56165 m .17127 .56237 L .17354 .56111 L F
.19174 .72985 m .19063 .73015 L .19046 .73057 L F
.19174 .72985 m .19261 .72766 L .19063 .73015 L F
.547 .792 .989 r
.62073 .42975 m .62436 .43001 L .6229 .42851 L F
.644 .584 .773 r
.62073 .42975 m .62415 .43274 L .62436 .43001 L F
.762 .872 .928 r
.6229 .42851 m .62436 .43001 L .62566 .42901 L F
.574 .452 .676 r
.62436 .43001 m .62415 .43274 L .62566 .42901 L F
.653 .301 .364 r
.42301 .58577 m .42474 .58641 L .42624 .582 L F
.59 .041 0 r
.42944 .58278 m .42754 .5816 L .42624 .582 L F
.596 .244 .343 r
.42624 .582 m .42803 .58602 L .42944 .58278 L F
.42624 .582 m .42474 .58641 L .42803 .58602 L F
.494 .114 .247 r
.69628 .40611 m .69876 .40726 L .69622 .40762 L F
.69628 .40611 m .69898 .40591 L .69876 .40726 L F
.46 .235 .485 r
.60998 .42344 m .61224 .42435 L .61249 .42078 L F
.333 .122 .436 r
.60998 .42344 m .61203 .42482 L .61224 .42435 L F
.60998 .42344 m .60996 .42584 L .61203 .42482 L F
.62 .417 .585 r
.70981 .39927 m .70733 .40255 L .70754 .39999 L F
.742 .577 .67 r
.74268 .38762 m .74513 .38913 L .7443 .38428 L F
.846 .915 .881 r
.74615 .38076 m .7443 .38428 L .74624 .38343 L F
.468 .503 .811 r
.7443 .38428 m .74755 .38603 L .74624 .38343 L F
.425 .177 .433 r
.25326 .57008 m .25275 .57243 L .25539 .56946 L F
.434 .161 .399 r
.44127 .58663 m .43922 .58725 L .43934 .58444 L F
.701 .907 .968 r
.73833 .42465 m .73427 .4254 L .73691 .42478 L F
.86 .993 .828 r
.7393 .42213 m .73833 .42465 L .73691 .42478 L F
.988 .894 .619 r
.60237 .50688 m .6007 .50964 L .60047 .51019 L F
.60237 .50688 m .60165 .50604 L .6007 .50964 L F
.44 .315 .613 r
.38297 .60925 m .385 .60886 L .38503 .60534 L F
.465 .42 .723 r
.38297 .60925 m .38563 .61111 L .385 .60886 L F
.446 .421 .737 r
.38378 .61167 m .38563 .61111 L .38297 .60925 L F
.78 .613 .673 r
.50554 .58768 m .50291 .59051 L .50285 .5879 L F
.63 .609 .81 r
.50802 .58456 m .50554 .58768 L .50492 .58425 L F
.831 .981 .693 r
.76659 .43153 m .76922 .4288 L .76718 .43242 L F
.76659 .43153 m .76888 .42839 L .76922 .4288 L F
.849 .516 .422 r
.48473 .60548 m .48118 .6065 L .48237 .60434 L F
.354 .242 .586 r
.47634 .59393 m .47831 .59573 L .47806 .59278 L F
.415 .243 .538 r
.47634 .59393 m .47625 .59667 L .47831 .59573 L F
0 0 0 r
.55531 .48641 m .55698 .48536 L .55785 .48356 L F
.338 .029 .285 r
.55698 .48536 m .55978 .4825 L .55785 .48356 L F
.477 .052 .155 r
.76971 .43652 m .76777 .43711 L .76771 .43729 L F
0 .254 .713 r
.76764 .4375 m .76771 .43729 L .765 .43562 L F
.628 .146 .089 r
.76771 .43729 m .76417 .43705 L .765 .43562 L F
.477 .052 .155 r
.76777 .43711 m .76701 .43734 L .76771 .43729 L F
0 .254 .713 r
.76863 .43821 m .76771 .43729 L .76764 .4375 L F
0 0 0 r
.7715 .43571 m .76771 .43729 L .76863 .43821 L F
.043 0 .071 r
.55271 .48921 m .55457 .48856 L .55531 .48641 L F
.025 0 .026 r
.55271 .48921 m .55389 .48996 L .55457 .48856 L F
.55271 .48921 m .55201 .49121 L .55389 .48996 L F
.228 0 .144 r
.55531 .48641 m .55685 .48762 L .55698 .48536 L F
.55531 .48641 m .55457 .48856 L .55685 .48762 L F
.665 .514 .67 r
.42766 .61687 m .42516 .61802 L .42559 .61519 L F
.623 .598 .805 r
.72542 .39641 m .72667 .3925 L .72422 .39321 L F
.72542 .39641 m .72808 .39581 L .72667 .3925 L F
.345 .031 .281 r
.56307 .49372 m .56024 .4948 L .56302 .49263 L F
.326 0 .239 r
.56193 .49663 m .56024 .4948 L .56307 .49372 L F
.56193 .49663 m .55953 .4975 L .56024 .4948 L F
.862 .996 .79 r
.5336 .55615 m .53209 .55657 L .53248 .55772 L F
0 0 .222 r
.53209 .55657 m .53056 .56108 L .53248 .55772 L F
.486 .268 .507 r
.23344 .60828 m .23555 .60773 L .23577 .60562 L F
.288 .077 .409 r
.23555 .60773 m .23841 .6051 L .23577 .60562 L F
.78 .707 .783 r
.73644 .39119 m .73999 .39178 L .73902 .39029 L F
.613 .789 .966 r
.73902 .39029 m .73999 .39178 L .74254 .39091 L F
.159 .674 .893 r
.20449 .53935 m .20849 .5399 L .20624 .53998 L F
.951 .702 .526 r
.52935 .54059 m .53301 .54019 L .52914 .5397 L F
.52935 .54059 m .53008 .54102 L .53301 .54019 L F
.74 .964 .937 r
.53016 .54361 m .53285 .54265 L .52935 .54059 L F
.827 .839 .857 r
.52852 .54201 m .53016 .54361 L .52935 .54059 L F
.52852 .54201 m .52935 .54059 L .52982 .54029 L F
.068 0 0 r
.52941 .54084 m .5262 .54166 L .52852 .54201 L F
.52982 .54029 m .52881 .54067 L .52941 .54084 L F
.52881 .54067 m .5262 .54166 L .52941 .54084 L F
.951 .702 .526 r
.53008 .54102 m .53285 .54265 L .5329 .54178 L F
.53008 .54102 m .5329 .54178 L .53301 .54019 L F
.962 .783 .341 r
.51266 .53501 m .50996 .53464 L .50926 .53507 L F
.533 .285 .485 r
.5116 .53459 m .50926 .53507 L .50996 .53464 L F
.468 0 0 r
.42958 .58243 m .43164 .58331 L .43313 .58209 L F
.374 0 0 r
.43313 .58209 m .43499 .58212 L .43582 .58196 L F
.43313 .58209 m .43164 .58331 L .43499 .58212 L F
.236 0 .288 r
.23342 .61137 m .23555 .60773 L .23344 .60828 L F
.302 .106 .44 r
.58178 .527 m .5793 .52764 L .57966 .53036 L F
.352 .316 .678 r
.38378 .61167 m .38609 .61369 L .38563 .61111 L F
.67 .667 .838 r
.74538 .42151 m .74289 .42423 L .74265 .42123 L F
.74538 .42151 m .74694 .42331 L .74289 .42423 L F
.624 .442 .615 r
.74289 .42423 m .74694 .42331 L .74493 .4265 L F
.764 .62 .701 r
.42883 .63765 m .43167 .63538 L .42949 .63621 L F
.082 .192 .68 r
.65504 .43172 m .6556 .42747 L .65438 .42994 L F
.249 0 .095 r
.23468 .64187 m .23346 .64412 L .23138 .6443 L F
.112 0 .026 r
.23525 .64326 m .23468 .64187 L .23686 .64134 L F
.23525 .64326 m .23346 .64412 L .23468 .64187 L F
.399 .847 .919 r
.20549 .65354 m .20889 .6532 L .20738 .6523 L F
.307 .769 .946 r
.20889 .6532 m .21093 .65221 L .20738 .6523 L F
.20889 .6532 m .21259 .65315 L .21093 .65221 L F
.21259 .65315 m .21347 .65314 L .21272 .65287 L F
.21259 .65315 m .21272 .65287 L .21093 .65221 L F
.639 .885 .543 r
.21311 .652 m .21318 .65225 L .21381 .65115 L F
.819 .947 .906 r
.21093 .65221 m .21377 .65313 L .21318 .65225 L F
.95 .94 .612 r
.21264 .65243 m .21318 .65225 L .21284 .6526 L F
.307 .769 .946 r
.21347 .65314 m .21328 .65297 L .21093 .65221 L F
.95 .94 .612 r
.21264 .65243 m .21284 .6526 L .21134 .65415 L F
.819 .947 .906 r
.21093 .65221 m .21318 .65225 L .2123 .65254 L F
.639 .885 .543 r
.21134 .65415 m .21284 .6526 L .21311 .652 L F
.21284 .6526 m .21318 .65225 L .21311 .652 L F
.95 .94 .612 r
.2123 .65254 m .21264 .65243 L .21134 .65415 L F
.307 .769 .946 r
.21347 .65314 m .21377 .65313 L .21328 .65297 L F
.58 .65 .884 r
.76269 .3933 m .75811 .39077 L .76134 .39127 L F
.254 .535 .92 r
.76369 .39316 m .76269 .3933 L .76134 .39127 L F
.776 .856 .91 r
.68821 .44196 m .69176 .44167 L .69024 .4403 L F
.806 .789 .837 r
.69024 .4403 m .69176 .44167 L .69435 .43891 L F
.353 .186 .511 r
.58368 .54622 m .58626 .5427 L .58593 .54504 L F
.114 .016 .456 r
.58542 .54729 m .58368 .54622 L .58593 .54504 L F
.58542 .54729 m .58369 .5485 L .58368 .54622 L F
.548 .348 .562 r
.56518 .49165 m .56307 .49372 L .56302 .49263 L F
.907 .963 .811 r
.765 .43562 m .76659 .43153 L .76718 .43242 L F
.35 0 0 r
.503 .53724 m .50698 .53572 L .50387 .53733 L F
.503 .53724 m .50527 .53744 L .50698 .53572 L F
.034 .466 .879 r
.50698 .53572 m .50814 .53541 L .50576 .53467 L F
0 0 0 r
.50698 .53572 m .50527 .53744 L .50814 .53541 L F
.558 .07 .053 r
.68534 .40118 m .68261 .39979 L .68159 .40112 L F
.549 .158 .252 r
.68534 .40118 m .68511 .39983 L .68261 .39979 L F
0 .537 .709 r
.46209 .56088 m .46461 .56106 L .46587 .56115 L F
.313 .798 .891 r
.46461 .56106 m .46828 .56074 L .46587 .56115 L F
.555 .414 .644 r
.45746 .59643 m .45506 .5995 L .45478 .59688 L F
.25 .133 .518 r
.44735 .58096 m .44736 .58361 L .44561 .58181 L F
.17 .126 .561 r
.44736 .58361 m .44616 .58489 L .44561 .58181 L F
.666 .851 .97 r
.19883 .55481 m .20054 .55591 L .20258 .55487 L F
.645 .862 .982 r
.62939 .41585 m .63047 .41615 L .63284 .41512 L F
.171 0 .027 r
.22315 .62364 m .22564 .62318 L .22695 .62079 L F
.075 0 0 r
.22695 .62079 m .2274 .62215 L .22919 .62029 L F
.22695 .62079 m .22564 .62318 L .2274 .62215 L F
.519 .348 .589 r
.22695 .62079 m .22919 .62029 L .2291 .61775 L F
.864 .795 .78 r
.64629 .4289 m .65021 .42476 L .6493 .42496 L F
.141 .644 .906 r
.45992 .58231 m .4614 .58295 L .45854 .58237 L F
.022 0 0 r
.45911 .58327 m .46105 .58227 L .45992 .58231 L F
.542 .875 .991 r
.4623 .58162 m .4614 .58295 L .45992 .58231 L F
.022 0 0 r
.46105 .58227 m .4623 .58162 L .45992 .58231 L F
.141 .644 .906 r
.45992 .58231 m .45854 .58237 L .45757 .58217 L F
.542 .875 .991 r
.4623 .58162 m .46375 .58221 L .4614 .58295 L F
.746 .612 .709 r
.46375 .58221 m .46079 .58528 L .4614 .58295 L F
.692 .622 .773 r
.6747 .4503 m .67808 .4528 L .6765 .45161 L F
.788 .737 .805 r
.6765 .45161 m .67808 .4528 L .68043 .44994 L F
.712 .426 .491 r
.54204 .60602 m .54137 .60804 L .53738 .60802 L F
.907 .963 .811 r
.765 .43562 m .76443 .43447 L .76659 .43153 L F
.972 .801 .378 r
.765 .43562 m .76417 .43705 L .76443 .43447 L F
.593 .083 0 r
.50018 .54575 m .501 .54694 L .49827 .5453 L F
.50018 .54575 m .50225 .54803 L .501 .54694 L F
.999 .836 .537 r
.77051 .41193 m .76931 .41313 L .76975 .41074 L F
.77051 .41193 m .77022 .41445 L .76931 .41313 L F
.6 .821 .984 r
.17661 .65303 m .17828 .65413 L .18037 .65345 L F
.376 .394 .752 r
.5683 .58038 m .56613 .58389 L .56521 .57813 L F
.113 0 .334 r
.56923 .5819 m .56613 .58389 L .5683 .58038 L F
.56923 .5819 m .56643 .58484 L .56613 .58389 L F
.836 .729 .746 r
.78433 .42663 m .78216 .42937 L .78107 .4258 L F
.616 .405 .572 r
.78433 .42663 m .78473 .42959 L .78216 .42937 L F
.127 .064 .51 r
.78576 .42478 m .78473 .42959 L .78433 .42663 L F
.835 .564 .528 r
.66251 .40358 m .66627 .40786 L .66545 .40739 L F
.922 .962 .785 r
.6239 .43345 m .62317 .43187 L .62415 .43274 L F
.305 .493 .878 r
.62556 .43103 m .62415 .43274 L .62317 .43187 L F
.62556 .43103 m .62719 .43368 L .62415 .43274 L F
.833 .9 .485 r
.75733 .39979 m .75635 .40097 L .75374 .39981 L F
.75733 .39979 m .75589 .40296 L .75635 .40097 L F
.253 .704 .956 r
.65504 .43172 m .65853 .43249 L .65758 .43178 L F
.764 .988 .758 r
.65853 .43249 m .66122 .4297 L .65951 .43052 L F
.7 .941 .961 r
.65758 .43178 m .65853 .43249 L .65951 .43052 L F
.27 .664 .968 r
.26102 .54335 m .25965 .54406 L .25782 .54298 L F
.26102 .54335 m .26287 .54461 L .25965 .54406 L F
.838 .926 .89 r
.75593 .39384 m .75221 .39538 L .75547 .39351 L F
.383 .532 .881 r
.7547 .39142 m .75593 .39384 L .75748 .39199 L F
.665 .974 .863 r
.75748 .39199 m .75593 .39384 L .75547 .39351 L F
.726 .491 .571 r
.51034 .5939 m .51032 .5964 L .50642 .59613 L F
0 .07 .629 r
.50635 .57487 m .50643 .57598 L .50471 .57309 L F
0 0 .371 r
.50736 .57715 m .50643 .57598 L .50635 .57487 L F
.50736 .57715 m .50699 .57822 L .50662 .57675 L F
.23 0 0 r
.50805 .57753 m .50736 .57715 L .50584 .57645 L F
.35 .532 .893 r
.50956 .57736 m .50973 .58018 L .50736 .57715 L F
.23 0 0 r
.50857 .57779 m .50736 .57715 L .50805 .57753 L F
0 0 .371 r
.50736 .57715 m .50662 .57675 L .50643 .57598 L F
.594 .54 .764 r
.1963 .69453 m .19973 .69807 L .19942 .69383 L F
.61 .457 .65 r
.19942 .69383 m .19973 .69807 L .20234 .6953 L F
.515 .247 .447 r
.48942 .58486 m .4926 .58226 L .48963 .58265 L F
.641 .337 .44 r
.49196 .58451 m .49427 .58649 L .49447 .58378 L F
.49363 .58593 m .49196 .58451 L .49043 .58314 L F
.49427 .58649 m .49196 .58451 L .49363 .58593 L F
.515 .247 .447 r
.49093 .58363 m .49196 .58451 L .4926 .58226 L F
.48942 .58486 m .49196 .58451 L .49093 .58363 L F
.48 .341 .613 r
.4926 .58226 m .4947 .58127 L .49437 .57861 L F
.491 .224 .437 r
.4926 .58226 m .49447 .58378 L .4947 .58127 L F
.4926 .58226 m .49196 .58451 L .49447 .58378 L F
0 0 .06 r
.47289 .60924 m .47264 .61105 L .47362 .60971 L F
.803 .936 .573 r
.47362 .60971 m .47223 .61114 L .4727 .61035 L F
0 0 .06 r
.47289 .60924 m .47362 .60971 L .47491 .60881 L F
.803 .936 .573 r
.47362 .60971 m .4727 .61035 L .47438 .60755 L F
0 0 .06 r
.47491 .60881 m .47362 .60971 L .476 .60858 L F
.522 .518 .793 r
.55495 .55807 m .55532 .5612 L .55815 .56 L F
.473 .349 .631 r
.55576 .56437 m .55815 .56 L .55532 .5612 L F
.507 .587 .87 r
.54179 .58195 m .53797 .57915 L .54073 .57839 L F
.232 0 .277 r
.54438 .57895 m .54179 .58195 L .54073 .57839 L F
.54438 .57895 m .54423 .58095 L .54179 .58195 L F
.418 .275 .579 r
.54423 .58095 m .54178 .58454 L .54179 .58195 L F
.897 .666 .582 r
.74687 .42071 m .74694 .42331 L .74538 .42151 L F
.516 .281 .497 r
.61249 .42078 m .61505 .42267 L .61545 .42036 L F
.61249 .42078 m .61224 .42435 L .61505 .42267 L F
.739 .745 .857 r
.7402 .39542 m .7414 .39757 L .73866 .39833 L F
.759 .912 .942 r
.7428 .39497 m .7414 .39757 L .7402 .39542 L F
.7428 .39497 m .74389 .39596 L .7414 .39757 L F
.484 .282 .53 r
.5648 .57293 m .56478 .57571 L .56222 .57613 L F
.645 .782 .947 r
.56521 .57813 m .56222 .57613 L .56478 .57571 L F
.56521 .57813 m .56173 .57702 L .56222 .57613 L F
.516 .094 .178 r
.45894 .57677 m .45615 .57764 L .45654 .57651 L F
.45894 .57677 m .45858 .57782 L .45615 .57764 L F
.376 .712 .987 r
.45615 .57764 m .45858 .57782 L .45715 .57657 L F
.574 .456 .681 r
.45715 .57657 m .45557 .57932 L .45615 .57764 L F
.45557 .57932 m .45507 .58017 L .45615 .57764 L F
.516 .094 .178 r
.45654 .57651 m .45615 .57764 L .45637 .57649 L F
.916 .623 .474 r
.74493 .4265 m .74759 .42966 L .74426 .42924 L F
0 0 .028 r
.42217 .6223 m .41956 .62584 L .41822 .62661 L F
.158 .064 .49 r
.41956 .62584 m .41917 .6292 L .41822 .62661 L F
0 0 .472 r
.41822 .62661 m .41917 .6292 L .41868 .6297 L F
0 0 0 r
.58389 .46165 m .58565 .46093 L .58671 .45946 L F
.114 0 0 r
.58671 .45946 m .58797 .46015 L .58905 .45873 L F
.58671 .45946 m .58565 .46093 L .58797 .46015 L F
.652 .45 .597 r
.60874 .4446 m .60877 .4471 L .60526 .44724 L F
.749 .883 .94 r
.72051 .3943 m .71935 .397 L .72152 .39564 L F
.599 .789 .972 r
.54345 .57754 m .54438 .57895 L .54073 .57839 L F
.559 .769 .976 r
.54345 .57754 m .54679 .57841 L .54438 .57895 L F
.182 .213 .658 r
.54345 .57754 m .54423 .58095 L .54438 .57895 L F
.016 .54 .857 r
.45864 .55969 m .46209 .56088 L .45997 .56035 L F
.351 .571 .922 r
.17003 .62679 m .16953 .62871 L .16781 .62713 L F
.17003 .62679 m .17162 .62902 L .16953 .62871 L F
.579 .071 .011 r
.50383 .53457 m .50193 .53553 L .49952 .53449 L F
0 .389 .793 r
.51131 .55451 m .51097 .55392 L .50991 .55337 L F
.51131 .55451 m .51223 .55478 L .51097 .55392 L F
.642 .634 .827 r
.47479 .57611 m .47659 .57292 L .47424 .57328 L F
.622 .782 .958 r
.66227 .44185 m .65998 .44099 L .66277 .43991 L F
.486 .885 .951 r
.66558 .44277 m .66227 .44185 L .66277 .43991 L F
.66558 .44277 m .66379 .44412 L .66227 .44185 L F
.66 .953 .727 r
.61961 .42989 m .61727 .43271 L .62073 .42975 L F
.085 0 0 r
.62239 .42992 m .62073 .42975 L .6229 .42851 L F
.62239 .42992 m .61961 .42989 L .62073 .42975 L F
.466 .389 .686 r
.28002 .58416 m .27759 .58211 L .27986 .58153 L F
.28002 .58416 m .27807 .58488 L .27759 .58211 L F
.773 .363 .275 r
.41683 .65095 m .41506 .65252 L .41339 .64994 L F
.784 .379 .285 r
.41683 .65095 m .41772 .65296 L .41506 .65252 L F
.418 .718 .987 r
.27065 .54645 m .27035 .54815 L .26878 .54664 L F
.27065 .54645 m .27255 .54795 L .27035 .54815 L F
.744 .5 .561 r
.42904 .65287 m .43292 .65294 L .43296 .65058 L F
.66 .118 0 r
.41593 .63087 m .41435 .63152 L .41161 .62923 L F
.333 0 0 r
.41807 .63137 m .41435 .63152 L .41593 .63087 L F
.452 .206 .449 r
.41868 .6297 m .41807 .63137 L .41593 .63087 L F
.466 .35 .637 r
.27065 .59628 m .27114 .59918 L .26879 .59969 L F
.424 .227 .508 r
.27082 .60148 m .26879 .59969 L .27114 .59918 L F
.27082 .60148 m .26866 .60219 L .26879 .59969 L F
.362 0 .096 r
.47087 .56998 m .46938 .5716 L .46737 .57198 L F
.731 .379 .383 r
.47087 .56998 m .473 .57234 L .46938 .5716 L F
.391 .716 .988 r
.78315 .44011 m .78573 .44227 L .78266 .44155 L F
.683 .841 .959 r
.78677 .44068 m .78573 .44227 L .78315 .44011 L F
.78757 .4408 m .78315 .44011 L .78697 .44016 L F
.535 0 0 r
.78609 .44167 m .78697 .44016 L .78315 .44011 L F
.772 .815 .337 r
.78745 .43756 m .78717 .43906 L .78609 .44167 L F
.78717 .43906 m .78697 .44016 L .78684 .44038 L F
.78717 .43906 m .78684 .44038 L .78609 .44167 L F
.683 .841 .959 r
.78757 .4408 m .78653 .44163 L .78677 .44068 L F
.78653 .44163 m .78573 .44227 L .78677 .44068 L F
.765 .624 .705 r
.20528 .68303 m .20984 .68128 L .20626 .68072 L F
.20528 .68303 m .20939 .68341 L .20984 .68128 L F
.468 .336 .618 r
.20984 .68128 m .20939 .68341 L .21168 .68059 L F
.491 .159 .332 r
.46543 .59188 m .46635 .59305 L .46295 .59376 L F
.404 .382 .72 r
.46758 .58934 m .46543 .59188 L .465 .58746 L F
.533 .441 .697 r
.46758 .58934 m .46635 .59305 L .46543 .59188 L F
.42 .057 .239 r
.17138 .54796 m .17506 .54519 L .17321 .546 L F
.873 .783 .286 r
.53676 .56305 m .53698 .56328 L .53719 .56145 L F
.863 .983 .848 r
.19173 .71342 m .19062 .71247 L .19251 .71326 L F
.44 .225 .49 r
.25724 .61769 m .25686 .62015 L .25483 .62071 L F
.409 .172 .441 r
.25658 .62238 m .25483 .62071 L .25686 .62015 L F
.25658 .62238 m .25441 .62303 L .25483 .62071 L F
.477 .45 .749 r
.38554 .62166 m .38721 .62128 L .38476 .61999 L F
.38554 .62166 m .38822 .62307 L .38721 .62128 L F
.717 .678 .811 r
.71833 .42263 m .71472 .42043 L .7173 .41956 L F
.658 .671 .852 r
.72101 .42055 m .71833 .42263 L .7173 .41956 L F
.167 .705 .761 r
.20849 .5399 m .21066 .53953 L .2123 .53937 L F
.161 .701 .793 r
.21066 .53953 m .21451 .53923 L .2123 .53937 L F
.98 .826 .426 r
.65121 .41656 m .65134 .4196 L .65155 .4175 L F
.599 .817 .983 r
.43908 .56936 m .43663 .56997 L .43506 .56881 L F
.43908 .56936 m .43663 .56997 L .43506 .56881 L F
.951 .923 .566 r
.65184 .41011 m .65119 .41412 L .65209 .41206 L F
.97 .93 .674 r
.6516 .4097 m .65209 .41206 L .65338 .40873 L F
.6516 .4097 m .65282 .40904 L .65119 .40718 L F
.951 .923 .566 r
.65165 .40855 m .65209 .41206 L .6516 .4097 L F
.65165 .40855 m .65149 .41051 L .65184 .41011 L F
.65149 .41051 m .65119 .41412 L .65184 .41011 L F
.97 .93 .674 r
.65282 .40904 m .65338 .40873 L .65321 .4086 L F
.65282 .40904 m .65321 .4086 L .65119 .40718 L F
.42 .19 .457 r
.24985 .62657 m .24947 .62907 L .24736 .6296 L F
.433 .221 .489 r
.25226 .6236 m .25192 .62603 L .24985 .62657 L F
.445 .22 .477 r
.25192 .62603 m .24947 .62907 L .24985 .62657 L F
.973 .824 .41 r
.59998 .51196 m .60047 .51019 L .59957 .51165 L F
.665 .821 .388 r
.59957 .51165 m .60047 .51019 L .6007 .50964 L F
.948 .667 .471 r
.53896 .54559 m .53961 .54891 L .53828 .54837 L F
.704 .351 .376 r
.54453 .60862 m .54112 .61056 L .54137 .60804 L F
.54453 .60862 m .54348 .61111 L .54112 .61056 L F
.708 .356 .378 r
.54722 .6111 m .54348 .61111 L .54453 .60862 L F
.608 .387 .556 r
.54711 .60847 m .54722 .6111 L .54453 .60862 L F
.66 .75 .916 r
.53785 .57548 m .53797 .57915 L .53697 .5756 L F
.53804 .57545 m .53803 .57574 L .53785 .57548 L F
.53803 .57574 m .53797 .57915 L .53785 .57548 L F
.53805 .57548 m .53797 .57915 L .53804 .57545 L F
.53805 .57548 m .54073 .57839 L .53797 .57915 L F
.5381 .5755 m .54073 .57839 L .53805 .57548 L F
.805 .515 .498 r
.53748 .57445 m .53804 .57545 L .53957 .57655 L F
.598 .792 .973 r
.53957 .57655 m .54073 .57839 L .5381 .5755 L F
.805 .515 .498 r
.53804 .57545 m .53878 .5768 L .53957 .57655 L F
.598 .792 .973 r
.53957 .57655 m .5381 .5755 L .53805 .57545 L F
.66 .75 .916 r
.53805 .57545 m .5381 .5755 L .53805 .57548 L F
.805 .515 .498 r
.53785 .57542 m .53771 .57713 L .53878 .5768 L F
.53654 .5735 m .53804 .57545 L .53748 .57445 L F
.53654 .5735 m .53805 .57545 L .53804 .57545 L F
.53654 .5735 m .53804 .57545 L .53697 .5756 L F
.53654 .5735 m .53878 .5768 L .53804 .57545 L F
.53654 .5735 m .53709 .5752 L .53785 .57542 L F
.53709 .5752 m .53771 .57713 L .53785 .57542 L F
.748 .397 .387 r
.53771 .57713 m .53806 .57901 L .53912 .57728 L F
.53878 .5768 m .53912 .57728 L .53957 .57655 L F
.53771 .57713 m .53912 .57728 L .53878 .5768 L F
.66 .75 .916 r
.53805 .57545 m .53805 .57548 L .53804 .57545 L F
.624 .926 .972 r
.73427 .4254 m .7319 .42652 L .7334 .42477 L F
.33 .474 .853 r
.7319 .42652 m .73467 .4279 L .7334 .42477 L F
.529 .415 .668 r
.7319 .42652 m .73214 .42833 L .73467 .4279 L F
.779 .531 .56 r
.59466 .48038 m .59082 .48229 L .59018 .48045 L F
.59466 .48038 m .59461 .48289 L .59082 .48229 L F
.818 .985 .713 r
.53227 .5349 m .53084 .53568 L .53027 .5373 L F
.979 .916 .624 r
.5319 .53253 m .53227 .5349 L .53342 .53316 L F
.5319 .53253 m .53084 .53568 L .53227 .5349 L F
0 0 0 r
.53673 .50601 m .53758 .50452 L .535 .50743 L F
.08 0 .043 r
.53673 .50601 m .53953 .50346 L .53758 .50452 L F
.727 .82 .922 r
.53896 .55773 m .5428 .55766 L .54144 .55938 L F
.103 0 .106 r
.5428 .55766 m .54568 .55483 L .54435 .55692 L F
.549 .878 .61 r
.54435 .55692 m .54144 .55938 L .5428 .55766 L F
.278 .772 .719 r
.49051 .57439 m .48915 .57478 L .48651 .57569 L F
.705 .198 .029 r
.49051 .57439 m .4917 .57597 L .48915 .57478 L F
.427 .104 .313 r
.57591 .46817 m .57838 .46761 L .57887 .46591 L F
.302 0 .264 r
.57887 .46591 m .58062 .4667 L .58134 .46524 L F
.57887 .46591 m .57838 .46761 L .58062 .4667 L F
.402 .226 .525 r
.26866 .60219 m .26647 .60554 L .26646 .60299 L F
.929 .864 .433 r
.53541 .52275 m .53451 .52415 L .53467 .52602 L F
0 0 0 r
.53451 .52415 m .53558 .5227 L .53417 .52468 L F
.946 .956 .667 r
.53467 .52602 m .53451 .52415 L .53334 .52584 L F
0 0 0 r
.53451 .52415 m .53417 .52468 L .53334 .52584 L F
.929 .864 .433 r
.53547 .52249 m .53451 .52415 L .53541 .52275 L F
0 0 0 r
.53547 .52249 m .53558 .5227 L .53451 .52415 L F
.53547 .52249 m .53721 .52081 L .53558 .5227 L F
.391 .281 .608 r
.47716 .5849 m .47967 .58722 L .47992 .58495 L F
.212 .668 .947 r
.22062 .55316 m .21869 .55218 L .21694 .55213 L F
.244 .709 .947 r
.22321 .55284 m .21869 .55218 L .22062 .55316 L F
0 .198 .725 r
.49264 .5651 m .49102 .56444 L .49017 .56328 L F
.49264 .5651 m .4932 .5663 L .49102 .56444 L F
.922 .962 .785 r
.6239 .43345 m .62158 .43465 L .62317 .43187 L F
.896 .954 .609 r
.62094 .4368 m .62158 .43465 L .6239 .43345 L F
.413 .258 .559 r
.26171 .61151 m .26161 .61414 L .2597 .61472 L F
.499 .318 .566 r
.26161 .61414 m .25942 .61705 L .2597 .61472 L F
.41 .182 .454 r
.24736 .6296 m .247 .63206 L .24493 .63261 L F
.453 .231 .486 r
.24947 .62907 m .247 .63206 L .24736 .6296 L F
.187 .511 .913 r
.21125 .68832 m .21087 .68953 L .2086 .68662 L F
.65 .96 .928 r
.21125 .68832 m .20931 .68947 L .21087 .68953 L F
.782 .856 .906 r
.69298 .43275 m .68918 .43356 L .6914 .43142 L F
.741 .783 .887 r
.69455 .42887 m .69298 .43275 L .6914 .43142 L F
.872 .918 .856 r
.6806 .44688 m .68145 .44814 L .68368 .44536 L F
.947 .943 .746 r
.67959 .449 m .68145 .44814 L .6806 .44688 L F
.67959 .449 m .68043 .44994 L .68145 .44814 L F
.598 .478 .687 r
.56855 .56361 m .56643 .56655 L .56586 .56418 L F
.312 .05 .347 r
.24493 .63261 m .24431 .63549 L .24239 .63553 L F
.381 .11 .373 r
.24635 .63473 m .24493 .63261 L .247 .63206 L F
.24635 .63473 m .24431 .63549 L .24493 .63261 L F
.391 .716 .988 r
.78315 .44011 m .78266 .44155 L .78156 .44103 L F
.684 .4 .485 r
.78266 .44155 m .78245 .44268 L .78156 .44103 L F
.78266 .44155 m .78494 .44383 L .78245 .44268 L F
.535 .286 .485 r
.38695 .60224 m .3895 .59956 L .38699 .59975 L F
.408 .24 .539 r
.61752 .41485 m .61976 .41614 L .61955 .41427 L F
.61752 .41485 m .61645 .41771 L .61976 .41614 L F
.171 0 .222 r
.24338 .63702 m .24239 .63553 L .24431 .63549 L F
.24338 .63702 m .24166 .63794 L .24239 .63553 L F
.484 .784 .998 r
.2029 .65397 m .20349 .65243 L .20135 .65357 L F
.2029 .65397 m .20549 .65354 L .20349 .65243 L F
.692 .831 .95 r
.73283 .38594 m .73026 .38524 L .73183 .38476 L F
.717 .969 .933 r
.73429 .38402 m .73283 .38594 L .73183 .38476 L F
.73429 .38402 m .73505 .38459 L .73283 .38594 L F
.813 .881 .895 r
.68439 .43634 m .68061 .43749 L .68172 .438 L F
.622 .908 .983 r
.68593 .43462 m .68439 .43634 L .68172 .438 L F
.68593 .43462 m .68682 .43531 L .68439 .43634 L F
.788 .337 .174 r
.41772 .65296 m .42061 .65369 L .41907 .65478 L F
.754 .287 .139 r
.42061 .65369 m .42319 .65631 L .41907 .65478 L F
.749 .3 .186 r
.4246 .65584 m .42319 .65631 L .42061 .65369 L F
.567 .433 .659 r
.56726 .5699 m .5673 .57246 L .5648 .57293 L F
.557 .352 .558 r
.5673 .57246 m .56478 .57571 L .5648 .57293 L F
.642 .282 .345 r
.48582 .60174 m .49012 .59963 L .48702 .60023 L F
.48582 .60174 m .4886 .60213 L .49012 .59963 L F
.726 .634 .755 r
.48825 .59596 m .49012 .59963 L .492 .59665 L F
0 0 .285 r
.49012 .59963 m .49044 .6025 L .49078 .60228 L F
.602 .237 .322 r
.4886 .60213 m .49078 .60228 L .49012 .59963 L F
.676 .418 .523 r
.46295 .59376 m .46006 .59607 L .46057 .59437 L F
.994 .814 .557 r
.76223 .41587 m .76373 .41473 L .76313 .41371 L F
.76223 .41587 m .76328 .4169 L .76373 .41473 L F
.376 .171 .469 r
.25894 .61929 m .25724 .61769 L .25942 .61705 L F
.25894 .61929 m .25686 .62015 L .25724 .61769 L F
.465 .14 .329 r
.20569 .68662 m .20939 .68341 L .20528 .68303 L F
.20569 .68662 m .2086 .68662 L .20939 .68341 L F
.233 .118 .51 r
.21088 .68286 m .21082 .68539 L .20939 .68341 L F
.161 0 .324 r
.20939 .68341 m .21088 .68286 L .21168 .68059 L F
.233 .118 .51 r
.21088 .68286 m .21082 .68539 L .20939 .68341 L F
.653 .401 .525 r
.43592 .63598 m .43537 .63826 L .43249 .63823 L F
.4 .164 .437 r
.43751 .63761 m .43592 .63598 L .43756 .635 L F
.43751 .63761 m .43537 .63826 L .43592 .63598 L F
.677 .495 .632 r
.44179 .56416 m .44542 .56479 L .44275 .5621 L F
.44179 .56416 m .44092 .56573 L .44542 .56479 L F
.144 0 0 r
.5481 .58689 m .55069 .58625 L .55184 .58493 L F
.59 .041 0 r
.42944 .58278 m .42958 .58243 L .42754 .5816 L F
.899 .83 .77 r
.53285 .53018 m .53342 .53316 L .53464 .53158 L F
.332 .19 .533 r
.57039 .58722 m .57056 .58971 L .56813 .59074 L F
.204 .028 .406 r
.57056 .58971 m .56803 .59299 L .56813 .59074 L F
.803 .743 .797 r
.72714 .42248 m .7247 .42548 L .72873 .42627 L F
.823 .699 .728 r
.7247 .42548 m .72592 .42914 L .72873 .42627 L F
.62 .899 .595 r
.72873 .42627 m .72592 .42914 L .72794 .42709 L F
0 0 0 r
.53189 .50958 m .5338 .50902 L .535 .50743 L F
.232 0 .121 r
.5338 .50902 m .53673 .50601 L .535 .50743 L F
.504 .448 .728 r
.28007 .56896 m .28086 .57261 L .27861 .57322 L F
.481 .338 .609 r
.28086 .57261 m .27864 .57583 L .27861 .57322 L F
.556 .668 .912 r
.19275 .63595 m .1892 .63444 L .19139 .63388 L F
.266 .521 .909 r
.19327 .63441 m .19275 .63595 L .19139 .63388 L F
.494 .772 .994 r
.19327 .63441 m .19485 .63557 L .19275 .63595 L F
.462 .278 .544 r
.56522 .54602 m .56756 .54544 L .56749 .54303 L F
.374 .212 .529 r
.56522 .54602 m .56725 .54765 L .56756 .54544 L F
.56522 .54602 m .56534 .54854 L .56725 .54765 L F
.365 .781 .979 r
.19347 .73339 m .19246 .73416 L .19303 .73337 L F
.468 .815 .998 r
.19009 .7331 m .19303 .73337 L .19246 .73416 L F
.19246 .73416 m .19303 .73337 L .19009 .7331 L F
.743 .671 .78 r
.48702 .60023 m .48304 .6002 L .48582 .60174 L F
1 .813 .486 r
.76971 .42117 m .76861 .42268 L .76936 .4192 L F
.76971 .42117 m .76957 .42386 L .76861 .42268 L F
.746 .762 .865 r
.64717 .41111 m .6442 .41326 L .64382 .41048 L F
0 0 0 r
.58539 .518 m .58489 .51907 L .58402 .52146 L F
.677 .291 .308 r
.54711 .60847 m .55076 .60856 L .54991 .61084 L F
.328 0 .171 r
.54991 .61084 m .55076 .60856 L .5531 .60793 L F
.121 .637 .89 r
.63077 .434 m .633 .43424 L .63357 .43469 L F
.833 .724 .745 r
.63077 .434 m .63357 .43469 L .633 .43424 L F
.63077 .434 m .6318 .43849 L .63357 .43469 L F
.519 .198 .363 r
.5628 .54944 m .56494 .55083 L .56534 .54854 L F
.5628 .54944 m .56234 .55122 L .56494 .55083 L F
.795 .977 .905 r
.47879 .5773 m .47698 .5771 L .47983 .57485 L F
.628 .367 .504 r
.57155 .48628 m .56982 .48873 L .56762 .48885 L F
.637 .378 .511 r
.57377 .48841 m .57155 .48628 L .57368 .48625 L F
.57377 .48841 m .56982 .48873 L .57155 .48628 L F
.751 .574 .655 r
.48358 .58483 m .48669 .58664 L .48792 .58507 L F
.534 .271 .463 r
.48669 .58664 m .48942 .58486 L .48792 .58507 L F
.125 .645 .885 r
.24269 .53989 m .24496 .54003 L .24643 .54054 L F
.349 .742 .985 r
.24496 .54003 m .24875 .54079 L .24643 .54054 L F
.041 .283 .776 r
.17634 .65307 m .173 .65135 L .17471 .65297 L F
.225 0 0 r
.17761 .54501 m .17993 .5447 L .18187 .54333 L F
0 0 0 r
.18187 .54333 m .18181 .54371 L .18388 .54285 L F
.18187 .54333 m .17993 .5447 L .18181 .54371 L F
.922 .976 .722 r
.65951 .43052 m .66122 .4297 L .66187 .42601 L F
.48 .14 .312 r
.69456 .39876 m .69733 .39842 L .69737 .39677 L F
.588 .225 .32 r
.69733 .39842 m .69992 .3984 L .69737 .39677 L F
.527 .281 .486 r
.69992 .3984 m .69992 .39627 L .69737 .39677 L F
.622 .309 .418 r
.42516 .61802 m .42515 .61985 L .42282 .61883 L F
.766 .558 .617 r
.42766 .61687 m .42515 .61985 L .42516 .61802 L F
.235 .132 .527 r
.2291 .61775 m .23049 .61966 L .2302 .61715 L F
.2291 .61775 m .22919 .62029 L .23049 .61966 L F
.609 .921 .974 r
.43853 .55945 m .43608 .56022 L .4377 .56095 L F
.67 .973 .9 r
.43853 .55945 m .43491 .56142 L .4377 .56095 L F
.463 .299 .573 r
.24278 .59325 m .24479 .59316 L .24473 .59059 L F
.421 .238 .525 r
.24278 .59325 m .24441 .59573 L .24479 .59316 L F
.24278 .59325 m .24259 .59673 L .24441 .59573 L F
.495 0 0 r
.44675 .55676 m .44852 .5574 L .4502 .5575 L F
.475 0 0 r
.44852 .5574 m .45231 .5581 L .4502 .5575 L F
0 0 0 r
.52875 .51223 m .53065 .51099 L .53189 .50958 L F
.53065 .51099 m .5338 .50902 L .53189 .50958 L F
.642 .157 .086 r
.41437 .64206 m .41662 .64372 L .41773 .6425 L F
.662 .182 .101 r
.41773 .6425 m .41662 .64372 L .41948 .64385 L F
.383 .145 .425 r
.25441 .62303 m .25192 .62603 L .25226 .6236 L F
.598 .296 .428 r
.59018 .48045 m .58818 .48238 L .58826 .48023 L F
.767 .859 .918 r
.48863 .58948 m .49054 .59025 L .48913 .58733 L F
.55 .632 .885 r
.49054 .59025 m .49177 .58696 L .48913 .58733 L F
0 0 .495 r
.51386 .58687 m .51422 .58935 L .51302 .59062 L F
.103 .172 .651 r
.51422 .58935 m .51484 .593 L .51302 .59062 L F
.757 .705 .803 r
.71365 .43165 m .71144 .43259 L .71498 .43305 L F
.726 .701 .826 r
.71365 .43165 m .71498 .43305 L .71734 .43212 L F
.709 .71 .849 r
.72592 .42914 m .7296 .42995 L .72794 .42709 L F
.702 .564 .696 r
.72794 .42709 m .7296 .42995 L .73214 .42833 L F
.771 .585 .648 r
.72592 .42914 m .7296 .42995 L .72794 .42709 L F
.581 .776 .972 r
.21377 .65313 m .21498 .65334 L .21318 .65225 L F
.668 .848 .969 r
.21318 .65225 m .21498 .65334 L .21626 .65173 L F
.541 .298 .497 r
.43728 .65657 m .43671 .65908 L .43411 .65939 L F
.05 0 .29 r
.43782 .65614 m .43671 .65908 L .43728 .65657 L F
.591 .624 .853 r
.19958 .71354 m .19767 .71591 L .19795 .71485 L F
.19958 .71354 m .20027 .71524 L .19767 .71591 L F
.485 .25 .482 r
.19767 .71591 m .20027 .71524 L .19795 .71485 L F
.19767 .71591 m .19726 .71864 L .20027 .71524 L F
.20027 .71524 m .19726 .71864 L .19767 .71591 L F
0 0 .572 r
.19625 .7123 m .19767 .71591 L .19795 .71485 L F
0 0 0 r
.4772 .60267 m .47568 .60391 L .47541 .60455 L F
.815 .43 .325 r
.5443 .55684 m .54568 .55483 L .54349 .55476 L F
.679 .849 .437 r
.54435 .55692 m .54568 .55483 L .5443 .55684 L F
.618 .196 .219 r
.47436 .55795 m .47311 .55999 L .47688 .5594 L F
.988 .864 .623 r
.76287 .41891 m .76181 .42267 L .76278 .42378 L F
.999 .827 .539 r
.76181 .42267 m .76242 .42608 L .76278 .42378 L F
.955 .95 .671 r
.65623 .40577 m .65563 .40484 L .65712 .40168 L F
.972 .906 .688 r
.65623 .40577 m .65451 .40637 L .65563 .40484 L F
.664 .502 .655 r
.64481 .40163 m .64814 .40313 L .64639 .40224 L F
.822 .709 .74 r
.50977 .58163 m .51104 .58511 L .50802 .58456 L F
0 .023 .594 r
.50977 .58163 m .51137 .58398 L .51104 .58511 L F
0 .291 .758 r
.51261 .58562 m .51104 .58511 L .51137 .58398 L F
.51261 .58562 m .51386 .58687 L .51104 .58511 L F
0 0 0 r
.7715 .43571 m .76971 .43652 L .76878 .43684 L F
.946 .958 .676 r
.7711 .43494 m .76971 .43652 L .7715 .43571 L F
0 0 .039 r
.77159 .43494 m .77079 .43613 L .76971 .43652 L F
.77079 .43613 m .76949 .43808 L .76971 .43652 L F
0 0 0 r
.76878 .43684 m .76971 .43652 L .76771 .43729 L F
.864 .986 .841 r
.77222 .43297 m .7715 .43571 L .77367 .43379 L F
.77222 .43297 m .7711 .43494 L .7715 .43571 L F
.347 0 .089 r
.71108 .39055 m .71404 .38949 L .7115 .39008 L F
.129 .672 .827 r
.21451 .53923 m .21669 .53914 L .21845 .53933 L F
.189 .687 .915 r
.21669 .53914 m .22063 .53974 L .21845 .53933 L F
0 0 .103 r
.42437 .64123 m .42444 .64093 L .42415 .63766 L F
0 .321 .742 r
.42437 .64123 m .42656 .64232 L .42444 .64093 L F
.717 .499 .592 r
.49515 .53586 m .49736 .53648 L .49832 .53453 L F
.373 .543 .894 r
.49808 .53201 m .49952 .53449 L .49832 .53453 L F
.958 .626 .241 r
.49952 .53449 m .49808 .53201 L .49832 .53453 L F
.794 .401 .31 r
.53591 .60585 m .53437 .60722 L .53402 .60495 L F
.53591 .60585 m .53738 .60802 L .53437 .60722 L F
.55 .65 .901 r
.73568 .43027 m .73934 .43228 L .7383 .4297 L F
.573 .638 .877 r
.73934 .43228 m .7408 .42977 L .7383 .4297 L F
.73934 .43228 m .7419 .43184 L .7408 .42977 L F
.418 .173 .434 r
.27807 .58488 m .2776 .58716 L .27547 .58774 L F
.344 .109 .407 r
.28002 .58416 m .2776 .58716 L .27807 .58488 L F
.244 .083 .454 r
.21337 .66913 m .21093 .67458 L .21043 .67369 L F
.41 .161 .422 r
.21093 .67458 m .21228 .67632 L .21043 .67369 L F
.21093 .67458 m .21005 .67736 L .21228 .67632 L F
.744 .873 .94 r
.20503 .6355 m .20121 .63596 L .20331 .63522 L F
.554 .907 .969 r
.20714 .63466 m .20503 .6355 L .20331 .63522 L F
.788 .737 .805 r
.6765 .45161 m .68043 .44994 L .67959 .449 L F
.172 .539 .926 r
.25672 .54169 m .25643 .54291 L .25491 .54166 L F
.25672 .54169 m .25782 .54298 L .25643 .54291 L F
.672 .925 .621 r
.51267 .5212 m .50984 .52396 L .51223 .52164 L F
.503 .855 .598 r
.51381 .52011 m .51541 .51893 L .51267 .5212 L F
0 0 0 r
.51381 .52011 m .51267 .5212 L .51223 .52164 L F
.548 .318 .518 r
.77838 .42578 m .78091 .42327 L .78107 .4258 L F
.595 .825 .987 r
.78091 .42327 m .78346 .42246 L .78223 .42125 L F
.909 .89 .799 r
.78223 .42125 m .78107 .4258 L .78091 .42327 L F
0 0 0 r
.61961 .42989 m .61708 .43391 L .61727 .43271 L F
.311 .446 .835 r
.51484 .56013 m .51383 .5567 L .51418 .55803 L F
.805 .892 .906 r
.62813 .42547 m .62566 .42901 L .62912 .42646 L F
.754 .913 .945 r
.63019 .42383 m .62813 .42547 L .62912 .42646 L F
.798 .682 .736 r
.59461 .48289 m .59595 .48645 L .5939 .48544 L F
.855 .777 .774 r
.59595 .48645 m .5921 .48833 L .5939 .48544 L F
.59595 .48645 m .59388 .48961 L .5921 .48833 L F
.502 .426 .703 r
.27886 .5628 m .27923 .56825 L .2777 .56752 L F
.516 .417 .681 r
.27923 .56825 m .28007 .56896 L .2777 .56752 L F
.781 .705 .779 r
.72014 .42939 m .72337 .42998 L .72248 .42857 L F
.654 .661 .844 r
.72248 .42857 m .72337 .42998 L .72592 .42914 L F
.459 .677 .958 r
.49653 .5672 m .49551 .56898 L .4932 .5663 L F
.49653 .5672 m .49777 .56877 L .49551 .56898 L F
.436 .181 .428 r
.57935 .55481 m .57884 .55737 L .5766 .55781 L F
.238 .012 .355 r
.58133 .5561 m .57935 .55481 L .58129 .55398 L F
.58133 .5561 m .57884 .55737 L .57935 .55481 L F
.638 .741 .923 r
.18258 .65326 m .18448 .65544 L .18612 .65444 L F
.902 .753 .687 r
.4877 .58054 m .48942 .58486 L .48963 .58265 L F
.806 .789 .837 r
.69024 .4403 m .69435 .43891 L .69313 .43755 L F
.789 .851 .898 r
.69313 .43755 m .69435 .43891 L .69651 .43755 L F
.45 .28 .558 r
.2776 .58716 m .27552 .59029 L .27547 .58774 L F
.819 .716 .752 r
.63077 .434 m .62857 .43828 L .6318 .43849 L F
.425 .051 .222 r
.4377 .58067 m .44007 .57888 L .43886 .57937 L F
0 0 .555 r
.52699 .58168 m .52829 .5837 L .52758 .58015 L F
.448 .41 .724 r
.72623 .42016 m .72451 .42129 L .72343 .41939 L F
.72623 .42016 m .72714 .42248 L .72451 .42129 L F
.534 .271 .463 r
.48669 .58664 m .48913 .58733 L .48942 .58486 L F
0 0 .162 r
.48942 .58486 m .49043 .58314 L .49196 .58451 L F
.48942 .58486 m .49019 .58579 L .49043 .58314 L F
.48942 .58486 m .48913 .58733 L .49019 .58579 L F
.498 .301 .543 r
.46572 .64997 m .46332 .653 L .46341 .65048 L F
.46572 .64997 m .46332 .653 L .46341 .65048 L F
0 0 .554 r
.55933 .59045 m .56004 .58921 L .55867 .5872 L F
0 0 0 r
.55662 .59358 m .55897 .59154 L .55933 .59045 L F
.762 .872 .928 r
.6229 .42851 m .62566 .42901 L .62341 .42838 L F
.805 .892 .906 r
.62813 .42547 m .62341 .42838 L .62566 .42901 L F
.751 .574 .655 r
.48358 .58483 m .48321 .58737 L .48669 .58664 L F
.582 .308 .465 r
.48359 .58995 m .48669 .58664 L .48321 .58737 L F
.48359 .58995 m .486 .59025 L .48669 .58664 L F
.709 .426 .495 r
.48669 .58664 m .48863 .58948 L .48913 .58733 L F
.48669 .58664 m .486 .59025 L .48863 .58948 L F
.463 .183 .402 r
.22365 .65203 m .22388 .6536 L .22128 .65399 L F
.218 .549 .93 r
.22431 .65137 m .22365 .65203 L .2235 .6515 L F
0 0 .301 r
.22431 .65137 m .22388 .6536 L .22365 .65203 L F
.663 .435 .564 r
.57644 .48588 m .57377 .48841 L .57368 .48625 L F
.756 .738 .837 r
.70797 .43225 m .70521 .43484 L .70878 .43535 L F
.757 .739 .836 r
.70797 .43225 m .70878 .43535 L .71144 .43259 L F
.958 .713 .264 r
.77022 .41445 m .76958 .41587 L .76931 .41313 L F
.77022 .41445 m .7703 .41708 L .76958 .41587 L F
.755 .253 .025 r
.74518 .38996 m .74513 .38913 L .74268 .38762 L F
.951 .953 .712 r
.60715 .49317 m .60903 .49205 L .60818 .4911 L F
.60715 .49317 m .60736 .49555 L .60903 .49205 L F
.325 .222 .58 r
.25128 .57584 m .25306 .57747 L .25311 .57507 L F
.25128 .57584 m .25101 .579 L .25306 .57747 L F
.724 .63 .752 r
.61692 .41941 m .61976 .41614 L .61645 .41771 L F
.679 .969 .769 r
.54512 .51053 m .5433 .51135 L .54218 .51299 L F
.613 .849 .477 r
.54218 .51299 m .5433 .51135 L .54095 .51445 L F
.853 .92 .524 r
.54218 .51299 m .54095 .51445 L .54182 .51376 L F
.463 .199 .428 r
.5423 .51308 m .54009 .51514 L .54095 .51445 L F
.54009 .51514 m .53963 .51557 L .54095 .51445 L F
.853 .92 .524 r
.54182 .51376 m .54095 .51445 L .54064 .5163 L F
.801 .517 .508 r
.19249 .72469 m .19597 .72748 L .19361 .72599 L F
0 0 0 r
.54942 .50629 m .54661 .50901 L .5478 .50776 L F
.243 .758 .816 r
.22063 .53974 m .2228 .53929 L .22457 .53918 L F
.357 .793 .964 r
.2228 .53929 m .22667 .53948 L .22457 .53918 L F
.463 0 .045 r
.55315 .59433 m .5556 .59517 L .55662 .59358 L F
.247 .083 .452 r
.55845 .59358 m .55662 .59358 L .5556 .59517 L F
.55845 .59358 m .55897 .59154 L .55662 .59358 L F
.956 .935 .728 r
.60736 .49555 m .60538 .49633 L .6062 .49703 L F
.94 .956 .75 r
.60715 .49317 m .60538 .49633 L .60736 .49555 L F
.362 .098 .372 r
.26646 .60789 m .26377 .61084 L .2644 .60856 L F
.363 .069 .325 r
.40055 .59348 m .40277 .59289 L .40322 .5902 L F
.2 0 .241 r
.40322 .5902 m .40521 .58974 L .40583 .58734 L F
.313 .028 .31 r
.40322 .5902 m .40482 .5921 L .40521 .58974 L F
.40322 .5902 m .40277 .59289 L .40482 .5921 L F
.219 0 0 r
.19005 .55692 m .1859 .55874 L .18789 .55744 L F
.255 .039 .381 r
.58129 .55398 m .58176 .55187 L .58357 .5508 L F
.938 .964 .735 r
.53376 .55392 m .5336 .55615 L .53546 .55472 L F
.53376 .55392 m .53209 .55657 L .5336 .55615 L F
.986 .865 .501 r
.49367 .54035 m .49368 .53642 L .49515 .53586 L F
.49367 .54035 m .49257 .5394 L .49368 .53642 L F
.68 .186 0 r
.49367 .54035 m .49362 .54086 L .49257 .5394 L F
.49367 .54035 m .49488 .54197 L .49362 .54086 L F
0 0 .331 r
.66318 .40133 m .66332 .40378 L .66251 .40358 L F
.835 .564 .528 r
.66251 .40358 m .66414 .40775 L .66627 .40786 L F
.86 .791 .782 r
.66332 .40378 m .66414 .40775 L .66251 .40358 L F
.562 .297 .473 r
.69992 .39627 m .70261 .3959 L .70308 .39345 L F
.566 .301 .474 r
.70308 .39345 m .70583 .39512 L .70559 .39312 L F
.70308 .39345 m .70261 .3959 L .70583 .39512 L F
.525 .304 .521 r
.56969 .54243 m .57232 .53944 L .5702 .54034 L F
.931 .802 .696 r
.20626 .68072 m .20528 .68303 L .20393 .68104 L F
.816 .977 .894 r
.20626 .68072 m .20472 .68057 L .20613 .67913 L F
.931 .802 .696 r
.20393 .68104 m .20528 .68303 L .20626 .68072 L F
.816 .571 .569 r
.4547 .61116 m .45801 .61163 L .45458 .61331 L F
.808 .554 .554 r
.45801 .61163 m .45802 .61428 L .45458 .61331 L F
.486 .294 .545 r
.46029 .61108 m .45802 .61428 L .45801 .61163 L F
.867 .834 .811 r
.45654 .61285 m .45802 .61428 L .45935 .6124 L F
.575 .025 0 r
.45791 .61237 m .45801 .61163 L .45748 .61156 L F
.45756 .61224 m .45748 .61156 L .4547 .61116 L F
.45791 .61237 m .45748 .61156 L .45756 .61224 L F
.867 .834 .811 r
.45829 .61203 m .45935 .6124 L .46029 .61108 L F
.575 .025 0 r
.45816 .61238 m .45801 .61163 L .45791 .61237 L F
.867 .834 .811 r
.45757 .61237 m .45816 .61238 L .45829 .61203 L F
.45816 .61238 m .45935 .6124 L .45829 .61203 L F
.45654 .61285 m .45935 .6124 L .45791 .61237 L F
.666 .283 .31 r
.45654 .61285 m .45791 .61237 L .4547 .61116 L F
.867 .834 .811 r
.45654 .61285 m .45791 .61237 L .45757 .61237 L F
.666 .283 .31 r
.45654 .61285 m .45818 .61248 L .45791 .61237 L F
.867 .834 .811 r
.45757 .61237 m .45829 .61203 L .45811 .61222 L F
.45757 .61237 m .45811 .61222 L .45758 .61244 L F
.509 .819 1 r
.45914 .61012 m .46029 .61108 L .45801 .61163 L F
.45914 .61012 m .45887 .61048 L .45831 .6121 L F
.45914 .61012 m .45831 .6121 L .45832 .61214 L F
.45887 .61048 m .45801 .61163 L .45816 .61238 L F
.45887 .61048 m .45816 .61238 L .45818 .61248 L F
.821 .827 .854 r
.45914 .61012 m .45832 .61214 L .45654 .61285 L F
.509 .819 1 r
.45832 .61214 m .45831 .6121 L .45818 .61248 L F
.575 .025 0 r
.45818 .61248 m .45816 .61238 L .45791 .61237 L F
.821 .827 .854 r
.45832 .61214 m .45818 .61248 L .45654 .61285 L F
.867 .834 .811 r
.45758 .61244 m .45811 .61222 L .45762 .61276 L F
.45829 .61203 m .46029 .61108 L .45836 .61229 L F
.45829 .61203 m .45836 .61229 L .45762 .61276 L F
.45762 .61276 m .46029 .61108 L .45883 .61265 L F
.45654 .61285 m .45757 .61237 L .45762 .61276 L F
.188 .046 .445 r
.588 .53701 m .58959 .53372 L .5896 .53571 L F
.185 0 .381 r
.5877 .53929 m .588 .53701 L .5896 .53571 L F
.726 .701 .826 r
.71365 .43165 m .71734 .43212 L .71655 .42927 L F
.763 .785 .871 r
.71655 .42927 m .71734 .43212 L .72014 .42939 L F
.494 .778 .995 r
.19139 .63388 m .1892 .63444 L .18812 .63329 L F
.766 .558 .617 r
.42766 .61687 m .42851 .62045 L .42515 .61985 L F
.638 .479 .65 r
.43116 .62001 m .42766 .61687 L .43121 .61748 L F
.43116 .62001 m .42851 .62045 L .42766 .61687 L F
.703 .916 .967 r
.21693 .65863 m .21274 .65942 L .21592 .65726 L F
.317 .41 .799 r
.21698 .65545 m .21693 .65863 L .21592 .65726 L F
.21698 .65545 m .21847 .65921 L .21693 .65863 L F
.325 .734 .979 r
.68007 .43675 m .68172 .438 L .68061 .43749 L F
.724 .924 .959 r
.68593 .43462 m .68172 .438 L .68007 .43675 L F
.693 .363 .412 r
.68534 .40118 m .68877 .39926 L .68511 .39983 L F
.68534 .40118 m .68786 .40166 L .68877 .39926 L F
.636 .303 .389 r
.68877 .39926 m .68786 .40166 L .69137 .40121 L F
.634 .305 .397 r
.69137 .40121 m .69119 .39957 L .68877 .39926 L F
.982 .755 .521 r
.54329 .59295 m .54319 .59568 L .54451 .59451 L F
.336 0 0 r
.54451 .59451 m .54638 .59508 L .54723 .59359 L F
.54451 .59451 m .54319 .59568 L .54638 .59508 L F
.617 .751 .942 r
.54329 .59295 m .54723 .59359 L .54451 .59451 L F
.182 .694 .895 r
.21351 .66749 m .21742 .66789 L .21529 .66792 L F
.21529 .66792 m .21742 .66789 L .21351 .66749 L F
.516 .302 .528 r
.21742 .66789 m .21728 .67037 L .21529 .66792 L F
.21742 .66789 m .21728 .67037 L .21529 .66792 L F
.521 .353 .595 r
.56005 .55435 m .56234 .55122 L .56012 .55191 L F
.298 .258 .644 r
.27984 .55165 m .28178 .55352 L .27963 .55278 L F
.282 .235 .626 r
.28216 .55639 m .27963 .55278 L .28178 .55352 L F
.28216 .55639 m .27992 .55782 L .27963 .55278 L F
.598 .296 .428 r
.59018 .48045 m .59082 .48229 L .58818 .48238 L F
.499 .797 .999 r
.49437 .57861 m .49664 .57811 L .49316 .57739 L F
.397 .281 .603 r
.49437 .57861 m .49659 .58061 L .49664 .57811 L F
.49437 .57861 m .4947 .58127 L .4963 .58071 L F
.49437 .57861 m .4963 .58071 L .49627 .58033 L F
.782 .533 .559 r
.4961 .578 m .49279 .58014 L .49316 .57739 L F
.49664 .57811 m .49613 .57838 L .4961 .578 L F
.49613 .57838 m .49279 .58014 L .4961 .578 L F
.397 .281 .603 r
.49627 .58033 m .4963 .58071 L .49659 .58061 L F
.55 .5 .753 r
.38476 .61999 m .38652 .61721 L .38452 .6176 L F
.38476 .61999 m .38721 .62128 L .38652 .61721 L F
.936 .827 .711 r
.67403 .44678 m .6747 .4503 L .67429 .44874 L F
.28 .474 .871 r
.6747 .4503 m .67641 .44889 L .67429 .44874 L F
.6747 .4503 m .6765 .45161 L .67641 .44889 L F
.576 .449 .67 r
.56855 .56361 m .56896 .5661 L .56643 .56655 L F
.551 .434 .673 r
.56896 .5661 m .56726 .5699 L .56643 .56655 L F
.701 .429 .509 r
.5742 .56061 m .57104 .56306 L .57117 .56084 L F
.5742 .56061 m .57445 .56303 L .57104 .56306 L F
.546 .363 .585 r
.5766 .55781 m .57688 .56034 L .5742 .56061 L F
.625 .433 .603 r
.57688 .56034 m .57445 .56303 L .5742 .56061 L F
.73 .69 .812 r
.7303 .39323 m .73394 .3936 L .73276 .39027 L F
.599 .522 .739 r
.7303 .39323 m .7341 .39627 L .73394 .3936 L F
.728 .688 .812 r
.73276 .39027 m .73394 .3936 L .73644 .39119 L F
.506 .297 .531 r
.7366 .39487 m .73394 .3936 L .7341 .39627 L F
.858 .618 .575 r
.66249 .408 m .66627 .40786 L .66414 .40775 L F
.66249 .408 m .66604 .41071 L .66627 .40786 L F
.738 .662 .776 r
.48424 .56258 m .48177 .56384 L .48043 .56026 L F
.414 .696 .979 r
.48438 .57578 m .48651 .57569 L .48534 .57433 L F
.48438 .57578 m .48651 .57569 L .48534 .57433 L F
.831 .678 .693 r
.48458 .59545 m .48829 .5937 L .48732 .59288 L F
.325 .495 .873 r
.2083 .6611 m .20935 .66361 L .20768 .66326 L F
.767 .8 .313 r
.75635 .40097 m .75589 .40296 L .75509 .40532 L F
.835 .893 .881 r
.6816 .44525 m .68551 .44395 L .68437 .44275 L F
.6816 .44525 m .68368 .44536 L .68551 .44395 L F
.753 .894 .941 r
.68437 .44275 m .68551 .44395 L .68821 .44196 L F
.9 .781 .721 r
.61769 .4617 m .61861 .46503 L .61952 .46283 L F
.912 .882 .457 r
.66678 .41444 m .66584 .41563 L .66617 .41643 L F
.946 .956 .667 r
.53467 .52602 m .53334 .52584 L .53435 .52694 L F
.508 .35 .602 r
.62274 .41127 m .62522 .41318 L .62531 .41097 L F
.62274 .41127 m .6229 .41401 L .62522 .41318 L F
.738 .662 .776 r
.48424 .56258 m .48043 .56026 L .48277 .56013 L F
.557 .722 .951 r
.48518 .55998 m .48424 .56258 L .48277 .56013 L F
.48518 .55998 m .48724 .56159 L .48424 .56258 L F
.904 .743 .244 r
.76387 .40102 m .76418 .4025 L .76438 .39956 L F
.793 .728 .792 r
.43004 .5623 m .43301 .56079 L .43129 .56082 L F
.365 .616 .948 r
.47901 .55958 m .47806 .56105 L .47688 .5594 L F
.57 .876 .994 r
.48043 .56026 m .47806 .56105 L .47901 .55958 L F
.48043 .56026 m .47806 .56105 L .47901 .55958 L F
.814 .846 .873 r
.76326 .4088 m .76458 .40357 L .76299 .4068 L F
.76326 .4088 m .7675 .40541 L .76458 .40357 L F
.881 .751 .244 r
.76301 .41088 m .76326 .4088 L .76299 .4068 L F
.982 .696 .38 r
.41907 .64507 m .42179 .65174 L .41991 .64712 L F
.23 0 .089 r
.45465 .58438 m .45685 .58358 L .45757 .58217 L F
.165 0 0 r
.45685 .58358 m .45992 .58231 L .45757 .58217 L F
.789 .851 .898 r
.69313 .43755 m .69651 .43755 L .69591 .43507 L F
.723 .804 .915 r
.69591 .43507 m .69651 .43755 L .69933 .43541 L F
.733 .491 .562 r
.48182 .58091 m .47684 .58256 L .47909 .58008 L F
.4813 .58053 m .48054 .57997 L .48055 .58036 L F
.48054 .57997 m .47973 .57937 L .48055 .58036 L F
.4813 .58053 m .47909 .58008 L .47973 .57937 L F
.48182 .58091 m .4813 .58053 L .48055 .58036 L F
.665 .141 0 r
.48055 .58036 m .48057 .58038 L .48182 .58091 L F
.517 .188 .348 r
.48182 .58091 m .47696 .58511 L .47684 .58256 L F
.48182 .58091 m .47965 .58502 L .47696 .58511 L F
.388 .038 .245 r
.48289 .58221 m .47965 .58502 L .48182 .58091 L F
.665 .141 0 r
.48057 .58038 m .48289 .58221 L .48182 .58091 L F
.733 .491 .562 r
.48182 .58091 m .47909 .58008 L .48057 .58038 L F
.48182 .58091 m .48057 .58038 L .4813 .58053 L F
.662 .203 .154 r
.48434 .58072 m .48398 .58109 L .48055 .58036 L F
.48398 .58109 m .48394 .58113 L .4813 .58053 L F
.48398 .58109 m .4813 .58053 L .48055 .58036 L F
.48394 .58113 m .48289 .58221 L .48055 .58036 L F
.988 .731 .445 r
.48053 .57789 m .48055 .58036 L .48047 .5778 L F
.48197 .57988 m .48055 .58036 L .48053 .57789 L F
.485 .182 .377 r
.4389 .60898 m .43824 .61097 L .43584 .61128 L F
.524 .236 .419 r
.44017 .60851 m .43824 .61097 L .4389 .60898 L F
.499 .354 .614 r
.45007 .56311 m .44797 .5651 L .44767 .56395 L F
0 0 .302 r
.44092 .56573 m .44193 .56712 L .44542 .56479 L F
.684 .285 .284 r
.51266 .53501 m .51589 .5343 L .51321 .53694 L F
.724 .419 .461 r
.61153 .47926 m .61444 .47767 L .61181 .47656 L F
.61153 .47926 m .61523 .47953 L .61444 .47767 L F
0 .207 .734 r
.52016 .56642 m .52043 .56547 L .51811 .56345 L F
.96 .65 .395 r
.52232 .56854 m .52043 .56547 L .52016 .56642 L F
.849 .516 .422 r
.48473 .60548 m .48368 .60794 L .48118 .6065 L F
.593 .225 .313 r
.48674 .60725 m .48368 .60794 L .48473 .60548 L F
.582 .229 .336 r
.4874 .60552 m .48674 .60725 L .48473 .60548 L F
.597 .058 0 r
.67608 .40045 m .67862 .40008 L .67541 .39866 L F
.67608 .40045 m .67893 .40095 L .67862 .40008 L F
.48 .155 .338 r
.39259 .59907 m .39501 .59872 L .3956 .59686 L F
.542 .269 .45 r
.39501 .59872 m .39797 .5963 L .3956 .59686 L F
.317 .331 .716 r
.75998 .38886 m .75811 .39077 L .7575 .38705 L F
.477 .584 .883 r
.75998 .38886 m .76134 .39127 L .75811 .39077 L F
.304 .792 .888 r
.19635 .73344 m .19532 .73405 L .19347 .73339 L F
.19635 .73344 m .19748 .73362 L .19532 .73405 L F
.19635 .73344 m .19532 .73405 L .19347 .73339 L F
.19635 .73344 m .19748 .73362 L .19532 .73405 L F
.757 .379 .339 r
.74144 .38922 m .74268 .38762 L .73915 .38701 L F
.755 .253 .025 r
.74518 .38996 m .74268 .38762 L .74144 .38922 L F
.537 .335 .554 r
.47193 .64742 m .47192 .65004 L .46948 .65038 L F
.46948 .65038 m .47192 .65004 L .47193 .64742 L F
.422 .14 .378 r
.4749 .64734 m .47192 .65004 L .47193 .64742 L F
.47192 .65004 m .4749 .64734 L .47193 .64742 L F
.57 .349 .54 r
.57431 .53355 m .57687 .53075 L .57426 .53082 L F
.222 0 .152 r
.59326 .44977 m .59587 .44894 L .59622 .44734 L F
0 0 0 r
.59622 .44734 m .59797 .44694 L .59914 .44662 L F
.209 0 .148 r
.59622 .44734 m .5979 .44809 L .59797 .44694 L F
.59622 .44734 m .59587 .44894 L .5979 .44809 L F
.533 .893 .975 r
.31302 .7632 m .31138 .76275 L .31074 .76391 L F
.31074 .76391 m .31138 .76275 L .31302 .7632 L F
.31302 .7632 m .31138 .76275 L .31074 .76391 L F
.392 0 0 r
.45271 .60217 m .45176 .60402 L .44912 .60344 L F
.503 .326 .574 r
.45506 .5995 m .45516 .60188 L .45271 .60217 L F
.763 .449 .455 r
.45516 .60188 m .45176 .60402 L .45271 .60217 L F
.628 .809 .969 r
.20121 .63596 m .1992 .63688 L .19706 .63547 L F
.038 0 .429 r
.53084 .53568 m .52914 .5397 L .53027 .5373 L F
.323 .169 .511 r
.20791 .70028 m .2064 .69823 L .20795 .69758 L F
.20791 .70028 m .20629 .70128 L .2064 .69823 L F
.218 .58 .943 r
.73188 .39798 m .73525 .39965 L .7341 .39627 L F
.667 .644 .818 r
.73525 .39965 m .7366 .39487 L .7341 .39627 L F
.73525 .39965 m .73806 .39871 L .7366 .39487 L F
.529 .404 .653 r
.44596 .60526 m .44436 .60817 L .44434 .60564 L F
.74 .813 .909 r
.70588 .42555 m .70386 .42657 L .70259 .42507 L F
.351 .045 .299 r
.40521 .58974 m .40792 .58652 L .40583 .58734 L F
.615 .056 0 r
.73631 .3863 m .73505 .38459 L .73429 .38402 L F
.73631 .3863 m .73763 .38629 L .73505 .38459 L F
0 .419 .845 r
.74167 .40423 m .74056 .40406 L .74456 .40163 L F
.471 .291 .554 r
.73897 .40251 m .74167 .40423 L .74103 .39943 L F
.79 .585 .624 r
.74056 .40406 m .7391 .40489 L .73897 .40251 L F
.74056 .40406 m .74275 .40546 L .7391 .40489 L F
0 .419 .845 r
.74167 .40423 m .74275 .40546 L .74056 .40406 L F
.471 .291 .554 r
.73897 .40251 m .7391 .40489 L .74167 .40423 L F
.896 .839 .379 r
.65566 .42286 m .65615 .41887 L .65683 .4209 L F
.476 .282 .538 r
.46471 .57254 m .46243 .57542 L .46242 .5731 L F
.288 .445 .844 r
.48927 .57746 m .48808 .57873 L .48651 .57569 L F
0 0 .087 r
.4877 .58054 m .48808 .57873 L .48927 .57746 L F
.518 .306 .53 r
.492 .59665 m .49446 .59664 L .49492 .59383 L F
.72 .476 .556 r
.19954 .70983 m .19958 .71354 L .19625 .7123 L F
.594 .623 .85 r
.2009 .70714 m .19954 .70983 L .19832 .70756 L F
.2009 .70714 m .20199 .70993 L .19954 .70983 L F
.687 .449 .557 r
.20207 .71262 m .19954 .70983 L .20199 .70993 L F
.20207 .71262 m .19958 .71354 L .19954 .70983 L F
.725 .354 .346 r
.43411 .65939 m .43043 .66101 L .4306 .65855 L F
.43411 .65939 m .43341 .66157 L .43043 .66101 L F
.376 .018 .224 r
.43524 .66092 m .43411 .65939 L .43671 .65908 L F
.43524 .66092 m .43341 .66157 L .43411 .65939 L F
.653 .276 .317 r
.44638 .5746 m .44872 .57519 L .45034 .57379 L F
.878 .556 .047 r
.53299 .59901 m .53417 .60226 L .53356 .60164 L F
.985 .758 .36 r
.53417 .60226 m .53325 .60404 L .53356 .60164 L F
.53417 .60226 m .53402 .60495 L .53325 .60404 L F
0 .455 .855 r
.52431 .55071 m .52759 .55236 L .526 .55206 L F
.144 .264 .73 r
.526 .55206 m .52831 .55431 L .52759 .55236 L F
.52759 .55236 m .52831 .55431 L .526 .55206 L F
.497 .444 .728 r
.38452 .6176 m .38652 .61721 L .38609 .61369 L F
.872 .918 .856 r
.6806 .44688 m .68368 .44536 L .6816 .44525 L F
.74 .692 .15 r
.22128 .65399 m .22183 .64992 L .2235 .6515 L F
.952 .759 .606 r
.22388 .6536 m .22136 .65277 L .22128 .65399 L F
.397 .228 .532 r
.56749 .54303 m .56957 .5446 L .56969 .54243 L F
.56749 .54303 m .56756 .54544 L .56957 .5446 L F
.331 .069 .357 r
.45885 .58793 m .45643 .59065 L .45867 .58975 L F
.45867 .58975 m .45643 .59065 L .45885 .58793 L F
.549 .246 .406 r
.45885 .58793 m .46112 .58959 L .45867 .58975 L F
.45885 .58793 m .46112 .58959 L .45867 .58975 L F
.852 .778 .779 r
.59388 .48961 m .59268 .4911 L .5921 .48833 L F
0 .262 .709 r
.42658 .65858 m .42319 .65631 L .4246 .65584 L F
.289 .777 .906 r
.17548 .56019 m .17951 .56004 L .17779 .55981 L F
.189 .71 .872 r
.17951 .56004 m .18163 .55995 L .17779 .55981 L F
.438 .179 .422 r
.59326 .44977 m .59563 .45142 L .59587 .44894 L F
.59326 .44977 m .59329 .45213 L .59563 .45142 L F
.775 .698 .778 r
.78107 .4258 m .78216 .42937 L .77872 .4287 L F
.242 0 0 r
.78216 .42937 m .78118 .42928 L .77872 .4287 L F
.049 .613 .783 r
.78216 .42937 m .78401 .42925 L .78118 .42928 L F
.012 0 .438 r
.7866 .42696 m .78538 .42711 L .78576 .42478 L F
.78506 .42912 m .78487 .42894 L .78576 .42478 L F
.7866 .42696 m .78576 .42478 L .78624 .42448 L F
.978 .679 .327 r
.78533 .4257 m .7866 .42696 L .78624 .42448 L F
.419 .451 .787 r
.78533 .4257 m .78781 .42682 L .7866 .42696 L F
.78781 .42682 m .7882 .42699 L .7866 .42696 L F
.012 0 .438 r
.7866 .42696 m .78506 .42912 L .78538 .42711 L F
.78506 .42912 m .78473 .42959 L .78487 .42894 L F
.267 .666 .968 r
.78747 .43048 m .78473 .42959 L .7866 .42696 L F
.049 .613 .783 r
.78216 .42937 m .78524 .42939 L .78401 .42925 L F
.267 .666 .968 r
.7855 .42952 m .78401 .42925 L .78524 .42939 L F
.78747 .43048 m .78524 .42939 L .78473 .42959 L F
.78747 .43048 m .78596 .42995 L .7855 .42952 L F
.78596 .42995 m .78401 .42925 L .7855 .42952 L F
.159 .666 .903 r
.78473 .42959 m .78524 .42939 L .78216 .42937 L F
.71 .925 .591 r
.46624 .61669 m .46556 .61768 L .46794 .61464 L F
.88 .699 .653 r
.4808 .58544 m .48358 .58483 L .48185 .58411 L F
.4808 .58544 m .48321 .58737 L .48358 .58483 L F
0 0 0 r
.56107 .60234 m .56379 .59913 L .56318 .60147 L F
.222 0 .18 r
.56665 .59663 m .56586 .59902 L .56379 .59913 L F
.209 0 .114 r
.56379 .59913 m .5652 .60043 L .56318 .60147 L F
.56379 .59913 m .56586 .59902 L .5652 .60043 L F
.976 .699 .3 r
.74275 .40546 m .74167 .40423 L .7391 .40489 L F
.74275 .40546 m .74293 .40785 L .74167 .40423 L F
.74167 .40423 m .74293 .40785 L .74275 .40546 L F
.397 .832 .69 r
.54539 .51019 m .54512 .51053 L .54661 .50901 L F
.54539 .51019 m .5433 .51135 L .54512 .51053 L F
.41 .381 .716 r
.59081 .4538 m .5933 .45438 L .59329 .45213 L F
.59081 .4538 m .5919 .45622 L .5933 .45438 L F
.722 .374 .389 r
.20087 .68678 m .20257 .68898 L .20394 .68736 L F
.511 .243 .444 r
.70467 .40423 m .70471 .40247 L .70727 .4039 L F
.561 .17 .258 r
.70471 .40247 m .70733 .40255 L .70727 .4039 L F
.558 .382 .599 r
.77838 .42578 m .78107 .4258 L .77872 .4287 L F
.726 .529 .624 r
.42282 .61883 m .42248 .62286 L .42217 .6223 L F
.594 .413 .606 r
.42457 .62255 m .42282 .61883 L .42515 .61985 L F
.42457 .62255 m .42248 .62286 L .42282 .61883 L F
.209 .298 .737 r
.78281 .39539 m .78394 .39744 L .78254 .39884 L F
.376 .155 .446 r
.45643 .59065 m .458 .59197 L .45867 .58975 L F
.45867 .58975 m .458 .59197 L .45643 .59065 L F
.162 0 0 r
.44852 .5574 m .45088 .55787 L .45231 .5581 L F
.096 .643 .832 r
.45088 .55787 m .45469 .5582 L .45231 .5581 L F
.32 0 .219 r
.56843 .59826 m .56665 .59663 L .56832 .59552 L F
.56843 .59826 m .56586 .59902 L .56665 .59663 L F
.993 .818 .448 r
.76957 .42386 m .76851 .42486 L .76861 .42268 L F
.76957 .42386 m .76927 .42603 L .76851 .42486 L F
.647 .9 .575 r
.42882 .564 m .42855 .56413 L .43004 .5623 L F
.919 .698 .203 r
.42882 .564 m .42898 .56645 L .42855 .56413 L F
.42882 .564 m .42898 .56645 L .42855 .56413 L F
.559 .92 .951 r
.72516 .38477 m .72272 .38612 L .72173 .38564 L F
.533 .881 .985 r
.19625 .7123 m .194 .71201 L .19382 .71319 L F
.692 .98 .889 r
.194 .71201 m .19251 .71326 L .19382 .71319 L F
.942 .849 .722 r
.53285 .53018 m .5319 .53253 L .53342 .53316 L F
.62 .417 .585 r
.70981 .39927 m .71018 .40152 L .70733 .40255 L F
.568 .238 .369 r
.70981 .39927 m .71295 .40117 L .71018 .40152 L F
.70981 .39927 m .71312 .39878 L .71295 .40117 L F
.599 .403 .588 r
.49923 .58764 m .49926 .59019 L .49675 .5905 L F
.758 .596 .676 r
.50285 .5879 m .49926 .59019 L .49923 .58764 L F
.984 .725 .338 r
.45116 .56654 m .45007 .56311 L .4534 .56374 L F
.45116 .56654 m .45028 .56576 L .45007 .56311 L F
.919 .717 .224 r
.45116 .56654 m .45071 .56781 L .45028 .56576 L F
.45116 .56654 m .45115 .56924 L .45071 .56781 L F
.22 .205 .628 r
.55756 .56974 m .5589 .57039 L .55876 .56578 L F
.323 .201 .555 r
.55756 .56974 m .55938 .57118 L .5589 .57039 L F
.55756 .56974 m .55775 .5723 L .55938 .57118 L F
.783 .893 .922 r
.72051 .3943 m .72152 .39564 L .72422 .39321 L F
0 .22 .681 r
.7428 .39497 m .74553 .39707 L .74389 .39596 L F
.787 .517 .528 r
.68442 .40738 m .68754 .40792 L .68639 .41091 L F
.616 .374 .528 r
.68754 .40792 m .69021 .41022 L .68639 .41091 L F
.68754 .40792 m .69017 .40798 L .69021 .41022 L F
.552 .571 .827 r
.25023 .55838 m .25112 .5548 L .2483 .55626 L F
.25023 .55838 m .2519 .55765 L .25112 .5548 L F
.499 .423 .702 r
.25023 .55838 m .25272 .55989 L .2519 .55765 L F
.551 .403 .632 r
.57884 .55737 m .57688 .56034 L .5766 .55781 L F
.031 .602 .715 r
.18388 .54285 m .18459 .54281 L .18771 .54273 L F
0 0 0 r
.18771 .54273 m .18731 .54275 L .19001 .54239 L F
.18771 .54273 m .18459 .54281 L .18731 .54275 L F
.826 .867 .421 r
.54064 .5163 m .53938 .51859 L .53964 .51844 L F
.54064 .5163 m .54095 .51445 L .53938 .51859 L F
.576 .882 .992 r
.19541 .65413 m .19608 .65344 L .19623 .65499 L F
.416 .125 .36 r
.57318 .47059 m .57555 .46993 L .57591 .46817 L F
.387 .1 .35 r
.57591 .46817 m .57773 .46902 L .57838 .46761 L F
.57591 .46817 m .57555 .46993 L .57773 .46902 L F
.634 .824 .41 r
.21337 .66913 m .21043 .67369 L .21163 .67167 L F
.896 .75 .249 r
.21289 .67133 m .21337 .66913 L .21318 .67101 L F
.634 .824 .41 r
.21337 .66913 m .21163 .67167 L .21318 .67101 L F
.292 0 0 r
.19883 .55481 m .19582 .55498 L .19651 .55484 L F
.547 .073 .08 r
.43164 .58331 m .43425 .58391 L .43499 .58212 L F
.215 0 0 r
.43499 .58212 m .43425 .58391 L .4366 .58316 L F
.542 .042 0 r
.44542 .56479 m .44472 .56421 L .44275 .5621 L F
.692 .24 .172 r
.44542 .56479 m .44596 .56755 L .44472 .56421 L F
.652 .125 0 r
.67779 .40761 m .67674 .40797 L .67446 .40693 L F
0 0 0 r
.68023 .40704 m .67674 .40797 L .67779 .40761 L F
.678 .857 .454 r
.42282 .58143 m .42156 .58317 L .42085 .58465 L F
.469 .79 .999 r
.42156 .58317 m .42318 .58442 L .42085 .58465 L F
.763 .708 .8 r
.42999 .62646 m .42616 .62623 L .4283 .62325 L F
.565 .045 0 r
.42999 .62646 m .4285 .62786 L .42616 .62623 L F
.574 .622 .862 r
.43229 .62584 m .42999 .62646 L .4283 .62325 L F
.71 .356 .375 r
.43229 .62584 m .4285 .62786 L .42999 .62646 L F
.384 .071 .306 r
.22067 .62634 m .22293 .62585 L .22315 .62364 L F
.279 0 .283 r
.22315 .62364 m .22482 .625 L .22564 .62318 L F
.22315 .62364 m .22293 .62585 L .22482 .625 L F
.668 .745 .249 r
.58561 .51737 m .58616 .51589 L .58539 .518 L F
0 0 .155 r
.58725 .51174 m .58616 .51589 L .58606 .51495 L F
.852 .775 .27 r
.58606 .51495 m .58616 .51589 L .58561 .51737 L F
.313 .122 .454 r
.41161 .62923 m .41126 .63222 L .40969 .63201 L F
.864 .778 .764 r
.53961 .54891 m .54167 .54543 L .53911 .54452 L F
.758 .596 .676 r
.50285 .5879 m .50291 .59051 L .49926 .59019 L F
.13 0 0 r
.23203 .64552 m .23138 .6443 L .23346 .64412 L F
.23203 .64552 m .2301 .6463 L .23138 .6443 L F
.288 .787 .852 r
.51667 .51838 m .51541 .51893 L .51381 .52011 L F
.51667 .51838 m .51784 .5184 L .51541 .51893 L F
.835 .823 .837 r
.62115 .44946 m .62268 .45062 L .62534 .44735 L F
.913 .792 .714 r
.62115 .44946 m .62198 .45305 L .62268 .45062 L F
0 0 .524 r
.55158 .58957 m .55232 .59215 L .55137 .59312 L F
.22 .478 .889 r
.55137 .59312 m .55232 .59215 L .55315 .59433 L F
.379 .154 .442 r
.23342 .61137 m .23102 .6123 L .23075 .61416 L F
.927 .708 .22 r
.59125 .50044 m .59077 .49975 L .59075 .49737 L F
.977 .888 .528 r
.59125 .50044 m .58995 .50201 L .59077 .49975 L F
.59125 .50044 m .59052 .50398 L .58995 .50201 L F
.796 .727 .788 r
.41807 .63137 m .41989 .63327 L .42128 .6319 L F
0 .034 .586 r
.42074 .62974 m .42019 .63138 L .41917 .6292 L F
.226 .079 .462 r
.42074 .62974 m .42011 .63098 L .42019 .63138 L F
.141 .662 .885 r
.42025 .63173 m .42019 .63138 L .41807 .63137 L F
.342 0 .016 r
.42019 .63138 m .41656 .63298 L .41807 .63137 L F
.42019 .63138 m .41916 .63282 L .41656 .63298 L F
.226 .079 .462 r
.42011 .63098 m .41916 .63282 L .42019 .63138 L F
.141 .662 .885 r
.42128 .6319 m .42019 .63138 L .42025 .63173 L F
.698 .347 .377 r
.43756 .635 m .43388 .6334 L .43795 .6324 L F
.434 .241 .517 r
.43966 .63439 m .43756 .635 L .43795 .6324 L F
.43795 .6324 m .43756 .635 L .43966 .63439 L F
.299 0 .131 r
.45197 .58965 m .45491 .58659 L .45169 .58766 L F
.45197 .58965 m .45399 .58936 L .45491 .58659 L F
.049 0 .327 r
.45491 .58659 m .45685 .58358 L .45465 .58438 L F
.45491 .58659 m .45675 .58645 L .45685 .58358 L F
0 0 .025 r
.45491 .58659 m .45583 .58803 L .45675 .58645 L F
.45491 .58659 m .45399 .58936 L .45583 .58803 L F
.375 .78 .983 r
.22667 .53948 m .22882 .53922 L .23055 .53996 L F
.353 .747 .985 r
.22882 .53922 m .23271 .54002 L .23055 .53996 L F
.273 .197 .585 r
.43237 .61595 m .43116 .62001 L .43121 .61748 L F
.371 0 .157 r
.46932 .614 m .47033 .61154 L .4701 .61395 L F
.532 .316 .533 r
.47264 .61105 m .4701 .61395 L .47033 .61154 L F
.371 0 .157 r
.46932 .614 m .47264 .61105 L .47033 .61154 L F
.767 .739 .827 r
.45362 .56617 m .45674 .5668 L .45575 .56464 L F
.775 .546 .587 r
.45771 .56892 m .45362 .56617 L .45674 .5668 L F
.337 .496 .869 r
.45575 .56464 m .45674 .5668 L .45824 .56511 L F
.01 .107 .619 r
.45674 .5668 m .45807 .56766 L .45824 .56511 L F
.45674 .5668 m .45771 .56892 L .45807 .56766 L F
.302 .139 .486 r
.46706 .58423 m .465 .58746 L .46449 .58512 L F
.46706 .58423 m .46711 .58723 L .465 .58746 L F
.336 .381 .76 r
.46711 .58723 m .46758 .58934 L .465 .58746 L F
.329 .255 .62 r
.25154 .5815 m .25306 .57747 L .25101 .579 L F
.754 .648 .744 r
.19996 .70075 m .2037 .70185 L .20158 .70018 L F
.19996 .70075 m .20101 .70409 L .2037 .70185 L F
.383 0 .174 r
.20629 .70128 m .20471 .70325 L .2037 .70185 L F
0 0 .436 r
.2037 .70185 m .20507 .7025 L .20158 .70018 L F
.2037 .70185 m .20471 .70325 L .20507 .7025 L F
.779 .947 .931 r
.74265 .42123 m .7393 .42213 L .74076 .42068 L F
.454 .704 .975 r
.74439 .4196 m .74265 .42123 L .74076 .42068 L F
.74439 .4196 m .74538 .42151 L .74265 .42123 L F
.645 .782 .947 r
.56521 .57813 m .56173 .57696 L .56173 .57702 L F
.56521 .57813 m .56272 .57879 L .56173 .57696 L F
.489 .621 .908 r
.39298 .62963 m .39702 .63241 L .39528 .62908 L F
.373 .501 .859 r
.39528 .62908 m .39702 .63241 L .39838 .63113 L F
.239 .281 .704 r
.39702 .63241 m .39919 .63444 L .39838 .63113 L F
.625 .957 .811 r
.7322 .3977 m .73188 .39798 L .7341 .39627 L F
.338 0 .012 r
.19275 .54157 m .19629 .53987 L .19236 .53934 L F
.19275 .54157 m .19458 .54142 L .19629 .53987 L F
.457 .013 .105 r
.19629 .53987 m .19808 .5409 L .19848 .54022 L F
.19629 .53987 m .19458 .54142 L .19808 .5409 L F
.483 .274 .519 r
.49492 .59383 m .49446 .59664 L .49683 .59571 L F
.389 .184 .477 r
.27992 .55782 m .28018 .56033 L .27838 .56075 L F
.169 .034 .442 r
.28207 .55743 m .27992 .55782 L .28216 .55639 L F
.59 .784 .972 r
.1755 .62972 m .17162 .62902 L .17363 .62889 L F
.527 .847 .998 r
.1758 .62834 m .1755 .62972 L .17363 .62889 L F
.1758 .62834 m .17763 .62912 L .1755 .62972 L F
.664 .502 .655 r
.64481 .40163 m .64686 .40381 L .64814 .40313 L F
.805 .392 .264 r
.64686 .40381 m .64919 .40615 L .64814 .40313 L F
.379 0 .136 r
.65087 .40555 m .65 .40536 L .65119 .40718 L F
0 0 .147 r
.6515 .40859 m .65119 .40718 L .65 .40536 L F
.544 .248 .416 r
.64814 .40313 m .64919 .40615 L .6494 .40506 L F
.64943 .40427 m .6494 .40506 L .64953 .40436 L F
.64814 .40313 m .6494 .40506 L .64943 .40427 L F
.756 .426 .427 r
.64686 .40381 m .64864 .40675 L .64936 .40602 L F
.6494 .40506 m .65 .40536 L .64919 .40615 L F
.6494 .40506 m .64936 .40602 L .65 .40536 L F
.64686 .40381 m .6494 .40506 L .64919 .40615 L F
.64686 .40381 m .64936 .40602 L .6494 .40506 L F
.875 .438 .129 r
.64977 .4076 m .64995 .40578 L .64864 .40675 L F
.379 0 .136 r
.65087 .40555 m .64999 .40587 L .65 .40536 L F
.64999 .40587 m .64919 .40615 L .65 .40536 L F
.544 .248 .416 r
.65076 .40545 m .64997 .40581 L .65087 .40555 L F
.64997 .40581 m .64919 .40615 L .64999 .40587 L F
.64997 .40581 m .64999 .40587 L .65087 .40555 L F
.875 .438 .129 r
.64977 .4076 m .64994 .4077 L .64999 .40587 L F
.64995 .40578 m .64999 .40587 L .65 .40536 L F
.64977 .4076 m .64999 .40587 L .64995 .40578 L F
.544 .248 .416 r
.64953 .40436 m .64951 .40448 L .65076 .40545 L F
.875 .438 .129 r
.64995 .40578 m .65 .40536 L .64936 .40602 L F
.544 .248 .416 r
.64951 .40448 m .6492 .40608 L .64995 .40578 L F
.64951 .40448 m .64995 .40578 L .65076 .40545 L F
.875 .438 .129 r
.64999 .40587 m .6515 .40859 L .65 .40536 L F
.64994 .4077 m .65078 .40818 L .64999 .40587 L F
0 0 .147 r
.6515 .40859 m .6516 .4097 L .65119 .40718 L F
.875 .438 .129 r
.65078 .40818 m .6515 .40859 L .64999 .40587 L F
.544 .248 .416 r
.6492 .40608 m .64919 .40615 L .65076 .40545 L F
.875 .438 .129 r
.64995 .40578 m .64936 .40602 L .64864 .40675 L F
0 .22 .645 r
.50991 .55337 m .506 .55091 L .50733 .55331 L F
.943 .578 .241 r
.41256 .64058 m .41437 .64206 L .41285 .63886 L F
0 0 .018 r
.41347 .63838 m .41256 .64058 L .41285 .63886 L F
.698 .347 .377 r
.43756 .635 m .43381 .63488 L .43388 .6334 L F
.43388 .6334 m .43381 .63488 L .43756 .635 L F
.43388 .6334 m .43381 .63488 L .43756 .635 L F
.003 0 .04 r
.24028 .59914 m .24259 .59673 L .24087 .59784 L F
.585 .587 .821 r
.73568 .43027 m .73742 .42709 L .73467 .4279 L F
.73568 .43027 m .7383 .4297 L .73742 .42709 L F
.93 .587 .361 r
.47424 .57328 m .47314 .57442 L .473 .57234 L F
.327 0 0 r
.47659 .57292 m .47314 .57442 L .47424 .57328 L F
.786 .543 .57 r
.71764 .41741 m .71357 .41886 L .71621 .41677 L F
.71764 .41741 m .7173 .41956 L .71357 .41886 L F
.175 .389 .833 r
.71866 .41586 m .71764 .41741 L .71621 .41677 L F
.71866 .41586 m .71974 .41868 L .71764 .41741 L F
.55 .324 .525 r
.71974 .41868 m .7173 .41956 L .71764 .41741 L F
.831 .947 .897 r
.75285 .40819 m .74995 .41093 L .74907 .41005 L F
.38 0 .181 r
.69898 .40591 m .70233 .40427 L .70129 .40662 L F
.47 .105 .263 r
.70233 .40427 m .70387 .40651 L .70129 .40662 L F
.70233 .40427 m .70467 .40423 L .70387 .40651 L F
.343 .486 .859 r
.39827 .63845 m .40177 .64071 L .39944 .63685 L F
.352 .14 .446 r
.24703 .58746 m .24473 .59059 L .24666 .58984 L F
.384 .208 .515 r
.24473 .59059 m .2464 .59257 L .24666 .58984 L F
.333 .199 .544 r
.24479 .59316 m .2464 .59257 L .24473 .59059 L F
.455 .874 .747 r
.21369 .66312 m .21335 .66361 L .21594 .6639 L F
.21369 .66312 m .21199 .66406 L .21335 .66361 L F
.535 .286 .485 r
.38695 .60224 m .38948 .60192 L .3895 .59956 L F
.435 .208 .47 r
.3895 .59956 m .39165 .60131 L .39259 .59907 L F
.3895 .59956 m .38948 .60192 L .39165 .60131 L F
.108 0 0 r
.63313 .40455 m .63537 .40397 L .63644 .4029 L F
.367 0 0 r
.63644 .4029 m .63936 .40354 L .63862 .40162 L F
.63644 .4029 m .63537 .40397 L .63936 .40354 L F
.246 0 0 r
.23687 .55473 m .23699 .5549 L .23505 .554 L F
.23687 .55473 m .23895 .55539 L .23699 .5549 L F
.311 .557 .923 r
.28032 .54957 m .27984 .55165 L .27808 .54962 L F
0 .199 .714 r
.28032 .54957 m .28178 .55352 L .27984 .55165 L F
.677 .291 .308 r
.54711 .60847 m .54991 .61084 L .54722 .6111 L F
.605 .905 .984 r
.75218 .43536 m .7553 .43513 L .75425 .43394 L F
.711 .868 .956 r
.75425 .43394 m .7553 .43513 L .7576 .43389 L F
.442 .281 .566 r
.26373 .61345 m .26171 .61151 L .26377 .61084 L F
.26373 .61345 m .26161 .61414 L .26171 .61151 L F
.409 0 .126 r
.46243 .57542 m .45858 .57782 L .45894 .57677 L F
.46243 .57542 m .46111 .57743 L .45858 .57782 L F
.476 .282 .538 r
.46471 .57254 m .46468 .57496 L .46243 .57542 L F
.119 0 0 r
.46333 .57654 m .46243 .57542 L .46468 .57496 L F
.46333 .57654 m .46111 .57743 L .46214 .57586 L F
.547 .357 .575 r
.46333 .57654 m .46081 .57958 L .46111 .57743 L F
.46333 .57654 m .46345 .57943 L .46081 .57958 L F
.468 .297 .565 r
.46653 .57795 m .46345 .57943 L .46333 .57654 L F
.593 .108 .072 r
.46792 .57535 m .46737 .57616 L .46468 .57496 L F
0 0 0 r
.46585 .57516 m .46468 .57496 L .46635 .57571 L F
.46585 .57516 m .46635 .57571 L .46737 .57616 L F
.718 .534 .639 r
.46737 .57198 m .46792 .57535 L .46468 .57496 L F
.473 .766 .995 r
.46585 .57516 m .46665 .57368 L .46521 .57444 L F
0 0 0 r
.46585 .57516 m .46412 .57561 L .46468 .57496 L F
.46585 .57516 m .46333 .57654 L .46412 .57561 L F
.718 .534 .639 r
.46737 .57198 m .46468 .57496 L .46471 .57254 L F
.473 .766 .995 r
.46585 .57516 m .46521 .57444 L .46304 .57557 L F
.46585 .57516 m .46304 .57557 L .46264 .57601 L F
.551 .932 .855 r
.46264 .57601 m .46333 .57654 L .46585 .57516 L F
.46176 .57624 m .4622 .57632 L .46264 .57601 L F
.4622 .57632 m .46333 .57654 L .46264 .57601 L F
.136 0 .005 r
.46459 .57996 m .46345 .57943 L .46653 .57795 L F
.119 0 0 r
.46333 .57654 m .46214 .57586 L .46243 .57542 L F
.473 .766 .995 r
.46264 .57601 m .46304 .57557 L .46176 .57624 L F
.568 .429 .651 r
.46938 .5716 m .46792 .57535 L .46737 .57198 L F
.46938 .5716 m .4705 .57487 L .46792 .57535 L F
.313 .599 .947 r
.46737 .57616 m .46839 .57483 L .46585 .57516 L F
.473 .766 .995 r
.46585 .57516 m .46839 .57483 L .46665 .57368 L F
.846 .718 .723 r
.46839 .57483 m .46176 .57624 L .46665 .57368 L F
.468 .297 .565 r
.46457 .57725 m .46333 .57654 L .4622 .57632 L F
.46392 .57701 m .4622 .57632 L .46176 .57624 L F
.46457 .57725 m .4622 .57632 L .46392 .57701 L F
.46653 .57795 m .46333 .57654 L .46457 .57725 L F
.403 0 .085 r
.4705 .57487 m .46737 .57616 L .46792 .57535 L F
.4705 .57487 m .46928 .57635 L .46737 .57616 L F
.313 .599 .947 r
.46737 .57616 m .46928 .57635 L .46839 .57483 L F
.846 .718 .723 r
.46839 .57483 m .46653 .57795 L .46176 .57624 L F
.783 .629 .69 r
.46839 .57483 m .46792 .57852 L .46653 .57795 L F
.598 .56 .783 r
.46817 .57994 m .46706 .58423 L .46589 .58063 L F
.055 0 0 r
.46474 .58091 m .46817 .57994 L .46589 .58063 L F
.46698 .58028 m .46707 .58049 L .46817 .57994 L F
.46474 .58091 m .46707 .58049 L .46698 .58028 L F
.598 .56 .783 r
.46817 .57994 m .46939 .58386 L .46706 .58423 L F
.479 .465 .764 r
.47009 .57939 m .46939 .58386 L .46817 .57994 L F
.536 .129 .216 r
.46707 .58049 m .47009 .57939 L .46817 .57994 L F
.46707 .58049 m .46937 .5821 L .47009 .57939 L F
.182 .243 .691 r
.46707 .58049 m .46792 .57852 L .46653 .57795 L F
.46707 .58049 m .46653 .57795 L .4673 .58104 L F
.46707 .58049 m .4673 .58104 L .46738 .58138 L F
.74 .932 .952 r
.46589 .58063 m .46375 .58221 L .4623 .58162 L F
.636 .544 .734 r
.46706 .58423 m .46375 .58221 L .46589 .58063 L F
.119 0 0 r
.46474 .58091 m .46654 .58119 L .46707 .58049 L F
.182 .243 .691 r
.46707 .58049 m .46738 .58138 L .46654 .58119 L F
.724 .45 .513 r
.46653 .57795 m .46738 .58138 L .46459 .57996 L F
.488 .609 .899 r
.46779 .57756 m .4666 .57809 L .46462 .57624 L F
.46707 .57508 m .46304 .57557 L .46665 .57368 L F
.46779 .57756 m .46381 .5759 L .46707 .57508 L F
.46381 .5759 m .46304 .57557 L .46707 .57508 L F
.786 .972 .915 r
.46538 .57345 m .46328 .57507 L .46665 .57368 L F
.46328 .57507 m .46176 .57624 L .46303 .57557 L F
.46328 .57507 m .46303 .57557 L .46665 .57368 L F
.707 .697 .839 r
.46132 .57278 m .46332 .57499 L .4651 .5734 L F
.786 .972 .915 r
.46347 .57485 m .46329 .57502 L .46538 .57345 L F
.46252 .57559 m .46317 .57516 L .46538 .57345 L F
.636 .438 .598 r
.45989 .57436 m .46184 .57605 L .46327 .57509 L F
.45989 .57436 m .46327 .57509 L .46286 .5746 L F
.46327 .57509 m .46332 .57499 L .46132 .57278 L F
.786 .972 .915 r
.4651 .5734 m .46286 .5753 L .46538 .57345 L F
.707 .697 .839 r
.46332 .57499 m .46344 .57512 L .4651 .5734 L F
.786 .972 .915 r
.46286 .5753 m .46252 .57559 L .46329 .57502 L F
.46286 .5753 m .46329 .57502 L .46347 .57485 L F
.46252 .57559 m .46176 .57624 L .46317 .57516 L F
.636 .438 .598 r
.45989 .57436 m .46038 .5769 L .46184 .57605 L F
.488 .609 .899 r
.46212 .57632 m .46286 .5753 L .46176 .57624 L F
.771 .757 .84 r
.46267 .57557 m .46381 .5759 L .46344 .57512 L F
.46184 .57605 m .46234 .57601 L .46267 .57557 L F
.46205 .57641 m .46517 .57872 L .46381 .5759 L F
.46038 .5769 m .46381 .5759 L .46083 .57664 L F
.488 .609 .899 r
.4666 .57809 m .46445 .57722 L .46381 .5759 L F
.46462 .57624 m .46381 .5759 L .46344 .57512 L F
.4666 .57809 m .46381 .5759 L .46462 .57624 L F
.46779 .57756 m .46176 .57624 L .46304 .57557 L F
.771 .757 .84 r
.46234 .57601 m .46381 .5759 L .46267 .57557 L F
.488 .609 .899 r
.46779 .57756 m .46325 .57548 L .46212 .57632 L F
.636 .438 .598 r
.46252 .57559 m .46267 .57557 L .46344 .57512 L F
.488 .609 .899 r
.46325 .57548 m .46286 .5753 L .46267 .57557 L F
.771 .757 .84 r
.46115 .57656 m .46381 .5759 L .46184 .57605 L F
.488 .609 .899 r
.46325 .57548 m .46267 .57557 L .46212 .57632 L F
.636 .438 .598 r
.46327 .57509 m .46252 .57559 L .46344 .57512 L F
.46252 .57559 m .46184 .57605 L .46267 .57557 L F
.488 .609 .899 r
.46779 .57756 m .46462 .57624 L .46362 .5753 L F
.46779 .57756 m .46362 .5753 L .46367 .57526 L F
.46779 .57756 m .46344 .57513 L .46344 .57513 L F
.46779 .57756 m .46344 .57512 L .4651 .5734 L F
.46779 .57756 m .46729 .57679 L .46286 .5753 L F
.46729 .57679 m .4651 .5734 L .46338 .57486 L F
.636 .438 .598 r
.46327 .57509 m .46344 .57512 L .46332 .57499 L F
.488 .609 .899 r
.46367 .57526 m .46362 .5753 L .46344 .57513 L F
.46344 .57513 m .46344 .57513 L .46344 .57512 L F
.46729 .57679 m .46338 .57486 L .46286 .5753 L F
.636 .438 .598 r
.46066 .57351 m .46286 .5746 L .46132 .57278 L F
.45989 .57436 m .46286 .5746 L .46066 .57351 L F
.771 .757 .84 r
.46083 .57664 m .46115 .57656 L .46184 .57605 L F
.46038 .5769 m .46141 .57729 L .46205 .57641 L F
.46141 .57729 m .46517 .57872 L .46205 .57641 L F
.488 .609 .899 r
.4666 .57809 m .46517 .57872 L .46445 .57722 L F
.895 .8 .747 r
.59268 .4911 m .59066 .49131 L .5921 .48833 L F
.958 .896 .723 r
.59268 .4911 m .59009 .49376 L .59066 .49131 L F
.59268 .4911 m .5911 .49489 L .59009 .49376 L F
.81 .738 .784 r
.61769 .4617 m .61528 .46448 L .61861 .46503 L F
.862 .79 .779 r
.61492 .4668 m .61861 .46503 L .61528 .46448 L F
.61492 .4668 m .61642 .46824 L .61861 .46503 L F
.69 .68 .835 r
.48304 .6002 m .48092 .59967 L .48227 .60008 L F
0 .279 .699 r
.48444 .60078 m .48304 .6002 L .48227 .60008 L F
.48444 .60078 m .48582 .60174 L .48304 .6002 L F
.846 .864 .856 r
.69615 .42731 m .6973 .42874 L .69455 .42887 L F
.762 .847 .915 r
.70046 .42645 m .6973 .42874 L .69615 .42731 L F
0 .323 .81 r
.50736 .57715 m .50973 .58018 L .50699 .57822 L F
.458 .471 .785 r
.50977 .58163 m .50699 .57822 L .50973 .58018 L F
0 0 0 r
.59544 .52096 m .59682 .51916 L .59575 .52057 L F
.59763 .51725 m .59682 .51916 L .5981 .51537 L F
.723 .872 .462 r
.59575 .52057 m .59682 .51916 L .59763 .51725 L F
.38 0 .181 r
.69898 .40591 m .70129 .40662 L .69876 .40726 L F
.111 0 0 r
.15204 .5563 m .15477 .55431 L .15282 .55471 L F
.557 .934 .857 r
.56616 .58619 m .56886 .5848 L .57014 .58458 L F
.123 .145 .61 r
.5713 .58306 m .57014 .58458 L .56886 .5848 L F
.5713 .58306 m .57039 .58722 L .57014 .58458 L F
.952 .802 .354 r
.58995 .50201 m .59052 .50398 L .59016 .5065 L F
0 .308 .676 r
.7528 .39931 m .75374 .39981 L .75635 .40097 L F
.598 .792 .973 r
.53957 .57655 m .54345 .57754 L .54073 .57839 L F
.054 0 0 r
.16508 .55058 m .16927 .54853 L .16734 .54939 L F
.382 .679 .976 r
.26643 .54489 m .26595 .54648 L .26448 .54482 L F
.26643 .54489 m .26878 .54664 L .26595 .54648 L F
.935 .801 .688 r
.62063 .45166 m .62198 .45305 L .62115 .44946 L F
.879 .756 .723 r
.62063 .45166 m .6216 .45471 L .62198 .45305 L F
.625 .326 .443 r
.69443 .40728 m .69021 .41022 L .69017 .40798 L F
.69443 .40728 m .69272 .41039 L .69021 .41022 L F
.598 .296 .428 r
.6964 .40919 m .69443 .40728 L .69622 .40762 L F
.6964 .40919 m .69272 .41039 L .69443 .40728 L F
.458 0 0 r
.42944 .58278 m .43164 .58331 L .42958 .58243 L F
0 0 .222 r
.53209 .55657 m .53179 .55909 L .53056 .56108 L F
0 .15 .693 r
.53213 .56157 m .53056 .56108 L .53179 .55909 L F
.53213 .56157 m .53254 .56334 L .53056 .56108 L F
.189 .417 .852 r
.74753 .43202 m .7495 .43471 L .75089 .43383 L F
.279 .606 .954 r
.7495 .43471 m .75218 .43536 L .75089 .43383 L F
.75 .661 .763 r
.72667 .3925 m .72808 .39581 L .7303 .39323 L F
.689 .567 .712 r
.72808 .39581 m .7322 .3977 L .7303 .39323 L F
.719 .838 .938 r
.77367 .43379 m .77524 .43088 L .77222 .43297 L F
.77367 .43379 m .77658 .4324 L .77524 .43088 L F
0 .012 .55 r
.52376 .57223 m .52418 .57587 L .52503 .57431 L F
0 .108 .662 r
.52418 .57587 m .52581 .57668 L .52503 .57431 L F
.52418 .57587 m .52561 .57802 L .52581 .57668 L F
.272 .598 .951 r
.64104 .42693 m .64385 .42631 L .64073 .42468 L F
.64104 .42693 m .64437 .42785 L .64385 .42631 L F
.931 .575 .327 r
.53225 .54923 m .53361 .54888 L .53202 .54801 L F
.53225 .54923 m .53415 .55109 L .53361 .54888 L F
.94 .571 .236 r
.53622 .54854 m .53361 .54888 L .53415 .55109 L F
.42 .107 .326 r
.47806 .59278 m .48079 .59267 L .481 .59017 L F
.823 .785 .816 r
.47967 .58722 m .481 .59017 L .48321 .58737 L F
.637 .287 .36 r
.481 .59017 m .48079 .59267 L .48323 .5924 L F
.576 .414 .624 r
.481 .59017 m .48359 .58995 L .48321 .58737 L F
.548 .298 .489 r
.481 .59017 m .48323 .5924 L .48359 .58995 L F
.775 .735 .816 r
.71243 .42335 m .709 .42288 L .71157 .42034 L F
.795 .746 .807 r
.71472 .42043 m .71243 .42335 L .71157 .42034 L F
.577 .577 .816 r
.62197 .41543 m .62506 .42119 L .6268 .41851 L F
.905 .98 .787 r
.62724 .41724 m .62657 .41916 L .62918 .41574 L F
0 0 .292 r
.62687 .41832 m .62675 .41985 L .62657 .41916 L F
.577 .577 .816 r
.62689 .41826 m .62687 .41832 L .62695 .41829 L F
.62687 .41832 m .62687 .41841 L .62695 .41829 L F
.62197 .41543 m .6268 .41851 L .62689 .41826 L F
.638 .269 .328 r
.62331 .41882 m .62688 .4183 L .62506 .42119 L F
.62688 .4183 m .62695 .41829 L .62687 .41841 L F
0 0 .292 r
.62688 .4183 m .62687 .41839 L .62687 .41832 L F
.577 .577 .816 r
.62687 .41832 m .6268 .41851 L .62687 .41841 L F
.638 .269 .328 r
.62688 .4183 m .62687 .41841 L .62506 .42119 L F
0 0 .292 r
.62688 .4183 m .62688 .41854 L .62687 .41839 L F
.62688 .4183 m .62687 .41839 L .62688 .4183 L F
.62688 .41854 m .62688 .41875 L .62688 .41856 L F
.62688 .41854 m .62688 .41856 L .62687 .41832 L F
.62717 .41744 m .62657 .41916 L .62796 .41515 L F
.62687 .41832 m .62657 .41916 L .6273 .41707 L F
.779 .815 .336 r
.6269 .41823 m .62796 .41515 L .62431 .41516 L F
.62695 .41829 m .62796 .41515 L .6269 .41823 L F
.905 .98 .787 r
.62796 .41515 m .62724 .41724 L .62918 .41574 L F
0 0 .292 r
.6273 .41707 m .62717 .41744 L .62796 .41515 L F
.696 .43 .517 r
.6269 .41841 m .62697 .41802 L .62695 .41829 L F
.638 .269 .328 r
.62564 .41848 m .62627 .42011 L .6269 .41841 L F
.62688 .4183 m .6269 .41841 L .62695 .41829 L F
.577 .577 .816 r
.62197 .41543 m .62695 .41829 L .62431 .41516 L F
0 0 .292 r
.62697 .41802 m .62692 .41846 L .62688 .4183 L F
.696 .43 .517 r
.62627 .42011 m .62697 .41802 L .6269 .41841 L F
.638 .269 .328 r
.62564 .41848 m .6269 .41841 L .62688 .4183 L F
0 0 .292 r
.62692 .41846 m .62688 .41875 L .62688 .4183 L F
.62688 .41875 m .62675 .41985 L .62687 .41832 L F
.62697 .41802 m .62687 .41832 L .6273 .41707 L F
.638 .269 .328 r
.62331 .41882 m .62452 .41934 L .62564 .41848 L F
.62452 .41934 m .62627 .42011 L .62564 .41848 L F
.905 .98 .787 r
.62918 .41574 m .62657 .41916 L .62939 .41585 L F
.872 .988 .825 r
.63039 .41216 m .62939 .41585 L .63219 .41413 L F
.63039 .41216 m .62796 .41515 L .62939 .41585 L F
.645 .862 .982 r
.62939 .41585 m .63284 .41512 L .63219 .41413 L F
.419 .254 .549 r
.38503 .60534 m .38697 .60478 L .38695 .60224 L F
.387 .272 .6 r
.38503 .60534 m .38712 .60716 L .38697 .60478 L F
.38503 .60534 m .385 .60886 L .38712 .60716 L F
.361 .262 .606 r
.19973 .69807 m .19996 .70075 L .2014 .70025 L F
.20142 .7 m .2014 .70025 L .20158 .70018 L F
.19973 .69807 m .2014 .70025 L .20142 .7 L F
.698 .282 .253 r
.19973 .69807 m .20158 .70018 L .19887 .70003 L F
.19973 .69807 m .19887 .70003 L .19754 .69996 L F
.675 .52 .667 r
.20062 .69877 m .20257 .69922 L .20336 .69654 L F
.19967 .69955 m .19995 .69952 L .20062 .69877 L F
.19995 .69952 m .20257 .69922 L .20062 .69877 L F
0 0 0 r
.20234 .6953 m .19973 .69807 L .20039 .69902 L F
.20048 .69893 m .20039 .69902 L .20041 .69905 L F
.20234 .6953 m .20039 .69902 L .20048 .69893 L F
.994 .841 .486 r
.20208 .69398 m .20234 .6953 L .20173 .69649 L F
.698 .282 .253 r
.19973 .69807 m .19967 .69955 L .20041 .69905 L F
.675 .52 .667 r
.19967 .69955 m .20048 .69888 L .20041 .69905 L F
.20048 .69888 m .20336 .69654 L .20041 .69905 L F
.994 .841 .486 r
.20189 .69456 m .2018 .69562 L .20041 .69905 L F
.2018 .69562 m .20173 .69649 L .20041 .69905 L F
.20208 .69398 m .20173 .69649 L .20189 .69456 L F
.698 .282 .253 r
.19973 .69807 m .19754 .69996 L .19967 .69955 L F
.74 .813 .909 r
.70588 .42555 m .70259 .42507 L .70553 .42251 L F
.745 .782 .883 r
.709 .42288 m .70588 .42555 L .70553 .42251 L F
.339 0 .173 r
.62795 .40861 m .63008 .40925 L .63054 .40781 L F
.62795 .40861 m .6276 .40999 L .63008 .40925 L F
.524 .236 .419 r
.44017 .60851 m .44067 .61061 L .43824 .61097 L F
.479 .102 .246 r
.44436 .60817 m .44067 .61061 L .44017 .60851 L F
.709 .273 .211 r
.49675 .5905 m .49575 .59179 L .4932 .58985 L F
.616 .162 .15 r
.49575 .59179 m .49935 .59218 L .49675 .5905 L F
.401 0 0 r
.49675 .5905 m .49799 .59135 L .49575 .59179 L F
.49675 .5905 m .49837 .59155 L .49799 .59135 L F
.553 .259 .423 r
.49926 .59019 m .49935 .59218 L .49675 .5905 L F
.473 .526 .831 r
.49575 .59179 m .49799 .59135 L .49712 .58961 L F
.49667 .5895 m .49712 .58961 L .49684 .58905 L F
.49575 .59179 m .49712 .58961 L .49667 .5895 L F
.283 .394 .799 r
.4932 .58985 m .49575 .59179 L .49483 .58904 L F
.473 .526 .831 r
.49575 .59179 m .49684 .58905 L .49483 .58904 L F
.869 .897 .477 r
.49712 .58961 m .49895 .58782 L .49684 .58905 L F
.49799 .59135 m .49841 .58981 L .49712 .58961 L F
.49841 .58981 m .49895 .58782 L .49712 .58961 L F
.512 .012 .006 r
.49807 .59024 m .49239 .5904 L .49451 .58922 L F
.49578 .58941 m .49451 .58922 L .49481 .58905 L F
.49807 .59024 m .49451 .58922 L .49578 .58941 L F
.784 .523 .542 r
.49758 .59135 m .49239 .5904 L .49654 .59029 L F
.733 .636 .751 r
.49935 .59218 m .49683 .59571 L .5005 .59543 L F
.708 .6 .733 r
.49575 .59179 m .49683 .59571 L .49935 .59218 L F
.784 .523 .542 r
.49758 .59135 m .49277 .59294 L .49239 .5904 L F
.304 0 .082 r
.49758 .59135 m .49377 .5947 L .49277 .59294 L F
.49377 .5947 m .49286 .59551 L .4928 .59378 L F
.49377 .5947 m .4928 .59378 L .49277 .59294 L F
.49641 .59238 m .49518 .59497 L .49286 .59551 L F
.49758 .59135 m .49696 .59229 L .49641 .59238 L F
.49696 .59229 m .49518 .59497 L .49641 .59238 L F
.76 .452 .463 r
.50291 .59051 m .49935 .59218 L .49926 .59019 L F
.50291 .59051 m .50199 .59275 L .49935 .59218 L F
.767 .62 .696 r
.50199 .59275 m .50528 .58998 L .50291 .59051 L F
.50256 .59227 m .5053 .59342 L .50528 .58998 L F
.50199 .59275 m .50254 .59286 L .50256 .59227 L F
.50254 .59286 m .5053 .59342 L .50256 .59227 L F
.875 .729 .696 r
.5022 .59568 m .50411 .59674 L .50199 .59275 L F
.251 0 .119 r
.5022 .59568 m .50199 .59275 L .50411 .59674 L F
.5022 .59568 m .5053 .59342 L .50199 .59275 L F
.5022 .59568 m .50523 .59558 L .5053 .59342 L F
.50523 .59558 m .5056 .59557 L .50557 .59534 L F
.50523 .59558 m .50557 .59534 L .5053 .59342 L F
.323 .249 .617 r
.50248 .59492 m .50525 .5955 L .50352 .59208 L F
.50525 .5955 m .5056 .59557 L .50533 .59511 L F
.50525 .5955 m .50533 .59511 L .50352 .59208 L F
.403 .324 .652 r
.50528 .58998 m .5053 .59342 L .50765 .59195 L F
.078 0 .13 r
.5053 .59342 m .50541 .59422 L .50765 .59195 L F
.50541 .59422 m .50647 .59386 L .50765 .59195 L F
.50557 .59534 m .50602 .59483 L .50765 .59195 L F
.50541 .59422 m .50557 .59534 L .50647 .59386 L F
.50557 .59534 m .5056 .59557 L .50602 .59483 L F
.64 .364 .485 r
.50765 .59195 m .5056 .59557 L .50352 .59208 L F
.33 .466 .846 r
.50628 .59232 m .50703 .59367 L .50884 .59292 L F
.50703 .59367 m .50739 .59432 L .50862 .59313 L F
.50703 .59367 m .50862 .59313 L .50884 .59292 L F
.769 .681 .765 r
.50582 .59268 m .5068 .59394 L .50628 .59232 L F
.5068 .59394 m .50707 .59428 L .50689 .59384 L F
.5068 .59394 m .50689 .59384 L .50628 .59232 L F
.50424 .59391 m .50554 .59408 L .50582 .59268 L F
.50554 .59408 m .50707 .59428 L .50582 .59268 L F
.50707 .59428 m .50739 .59432 L .50728 .59413 L F
.50707 .59428 m .50728 .59413 L .50628 .59232 L F
.323 .249 .617 r
.5022 .59568 m .50246 .59567 L .50248 .59492 L F
.50246 .59567 m .5056 .59557 L .50248 .59492 L F
.267 0 .237 r
.50291 .59051 m .50199 .59275 L .50352 .59208 L F
.323 .249 .617 r
.5022 .59568 m .50352 .59208 L .50199 .59275 L F
.5022 .59568 m .50199 .59275 L .50303 .59459 L F
.678 .206 .123 r
.50199 .59275 m .50303 .59459 L .49935 .59218 L F
.606 .036 0 r
.49935 .59218 m .50303 .59459 L .50014 .59357 L F
.505 .51 .795 r
.50014 .59357 m .50344 .59282 L .4996 .59183 L F
.61 .08 0 r
.49799 .59135 m .49861 .59199 L .49779 .59132 L F
.401 0 0 r
.49837 .59155 m .49935 .59218 L .49799 .59135 L F
.606 .036 0 r
.49935 .59218 m .50014 .59357 L .49799 .59135 L F
.505 .51 .795 r
.49832 .59205 m .4996 .59183 L .49736 .59125 L F
.61 .08 0 r
.49779 .59132 m .50014 .59357 L .49796 .59175 L F
.49774 .59131 m .49796 .59175 L .49736 .59125 L F
.49779 .59132 m .49796 .59175 L .49774 .59131 L F
.586 .349 .524 r
.4981 .59203 m .49518 .59497 L .49758 .59135 L F
.49821 .59217 m .49819 .5922 L .4981 .59203 L F
.49819 .5922 m .49518 .59497 L .4981 .59203 L F
.61 .08 0 r
.49861 .59199 m .50014 .59357 L .49779 .59132 L F
.505 .51 .795 r
.50014 .59357 m .4996 .59183 L .49832 .59205 L F
.776 .604 .666 r
.486 .59025 m .48732 .59288 L .48863 .58948 L F
.625 .343 .47 r
.48659 .59065 m .48956 .59207 L .48988 .58985 L F
.48659 .59065 m .48956 .59207 L .48988 .58985 L F
.753 .502 .552 r
.49239 .5904 m .49043 .59155 L .49014 .59067 L F
.49043 .59155 m .48956 .59207 L .48973 .59085 L F
.49043 .59155 m .48976 .59088 L .48981 .59045 L F
.49043 .59155 m .48981 .59045 L .49 .59024 L F
.49239 .5904 m .49277 .59294 L .48956 .59207 L F
.636 .447 .61 r
.48988 .58985 m .48956 .59207 L .48947 .59061 L F
.728 .607 .722 r
.49156 .59262 m .4905 .59609 L .48956 .59207 L F
.49277 .59294 m .49241 .59345 L .49156 .59262 L F
.49241 .59345 m .4905 .59609 L .49156 .59262 L F
.482 .284 .534 r
.49277 .59294 m .49286 .59551 L .4905 .59609 L F
0 .145 .658 r
.48986 .59092 m .49425 .59479 L .49413 .59432 L F
.48958 .59071 m .49005 .59111 L .48986 .59092 L F
.49005 .59111 m .49425 .59479 L .48986 .59092 L F
.48962 .59067 m .49413 .59432 L .49533 .59293 L F
.48947 .59061 m .48958 .59071 L .48962 .59067 L F
.48958 .59071 m .49413 .59432 L .48962 .59067 L F
.753 .502 .552 r
.49 .59024 m .48981 .59045 L .48988 .58985 L F
.48976 .59088 m .48973 .59085 L .48974 .59083 L F
.48976 .59088 m .48974 .59083 L .48988 .58985 L F
.4918 .59027 m .49014 .59067 L .48988 .58985 L F
.17 .129 .565 r
.4932 .58985 m .49427 .58649 L .49177 .58696 L F
.4932 .58985 m .49483 .58904 L .49427 .58649 L F
.861 .571 .497 r
.49427 .58649 m .49483 .58904 L .49052 .58753 L F
.85 .499 .388 r
.49483 .58904 m .49239 .5904 L .49052 .58753 L F
.8 .502 .485 r
.49052 .58753 m .49239 .5904 L .48988 .58985 L F
.413 .342 .668 r
.48958 .59052 m .49347 .58801 L .49134 .58913 L F
.48947 .59061 m .48959 .59053 L .48958 .59052 L F
.48959 .59053 m .49347 .58801 L .48958 .59052 L F
.742 .592 .689 r
.48323 .5924 m .48732 .59288 L .486 .59025 L F
.625 .343 .47 r
.48659 .59065 m .48653 .59275 L .48956 .59207 L F
.48659 .59065 m .48653 .59275 L .48956 .59207 L F
.48956 .59207 m .48653 .59275 L .48659 .59065 L F
.724 .665 .791 r
.48323 .5924 m .48458 .59545 L .48732 .59288 L F
.713 .598 .726 r
.48956 .59207 m .48786 .59602 L .48653 .59275 L F
.816 .64 .663 r
.48786 .59602 m .4846 .59572 L .48653 .59275 L F
.002 0 0 r
.48547 .59498 m .48956 .59207 L .48653 .59275 L F
.48547 .59498 m .48755 .59403 L .48956 .59207 L F
.696 .342 .371 r
.48755 .59403 m .48947 .59061 L .48956 .59207 L F
.713 .598 .726 r
.48956 .59207 m .4905 .59609 L .48786 .59602 L F
.696 .342 .371 r
.48755 .59403 m .49425 .59479 L .48966 .59078 L F
.48932 .59087 m .48966 .59078 L .48947 .59061 L F
.48755 .59403 m .48966 .59078 L .48932 .59087 L F
.753 .502 .552 r
.49239 .5904 m .49014 .59067 L .4918 .59027 L F
0 .145 .658 r
.48956 .59069 m .4896 .59072 L .48958 .59071 L F
.4896 .59072 m .49425 .59479 L .48958 .59071 L F
.48947 .59061 m .48966 .59078 L .48956 .59069 L F
.48966 .59078 m .49425 .59479 L .48956 .59069 L F
.784 .523 .542 r
.49765 .5912 m .49654 .59029 L .49807 .59025 L F
.49758 .59135 m .49654 .59029 L .49765 .5912 L F
.49758 .59135 m .49807 .59025 L .49805 .59032 L F
.878 .901 .485 r
.49895 .58782 m .49807 .59024 L .49684 .58905 L F
.512 .012 .006 r
.49807 .59025 m .49239 .5904 L .49807 .59024 L F
.49808 .59025 m .49481 .58905 L .49498 .58909 L F
.49807 .59024 m .49483 .58904 L .49684 .58905 L F
.49807 .59024 m .49483 .58904 L .49807 .59024 L F
.869 .897 .477 r
.49881 .58833 m .49745 .59104 L .49895 .58782 L F
.49841 .58981 m .49807 .59024 L .49881 .58833 L F
.49807 .59024 m .49745 .59104 L .49881 .58833 L F
.49806 .59028 m .49807 .59024 L .49841 .58981 L F
.512 .012 .006 r
.49808 .59025 m .49807 .59024 L .49807 .59024 L F
.878 .901 .485 r
.49895 .58782 m .49808 .59025 L .49807 .59024 L F
.869 .897 .477 r
.49839 .58985 m .49806 .59028 L .49841 .58981 L F
.49806 .59028 m .49745 .59104 L .49807 .59024 L F
.55 .041 0 r
.49736 .59125 m .49758 .59135 L .49805 .59032 L F
.869 .897 .477 r
.49799 .59135 m .49749 .59107 L .49839 .58985 L F
.49749 .59107 m .49745 .59104 L .49839 .58985 L F
.784 .523 .542 r
.49805 .59032 m .49807 .59025 L .49808 .59025 L F
.55 .041 0 r
.49736 .59125 m .49805 .59032 L .49808 .59025 L F
.869 .897 .477 r
.49781 .59125 m .49744 .59107 L .49745 .59104 L F
.49799 .59135 m .49781 .59125 L .49781 .59125 L F
.49781 .59125 m .49744 .59107 L .49781 .59125 L F
.512 .012 .006 r
.49808 .59025 m .49807 .59025 L .49807 .59024 L F
.49498 .58909 m .49481 .58905 L .49483 .58904 L F
.869 .897 .477 r
.49799 .59135 m .49736 .59125 L .49744 .59107 L F
.402 .226 .525 r
.26866 .60219 m .26864 .6049 L .26647 .60554 L F
.446 .295 .582 r
.26864 .6049 m .26646 .60789 L .26647 .60554 L F
.554 .32 .516 r
.24703 .58746 m .24942 .58718 L .24998 .58495 L F
.472 .27 .524 r
.24942 .58718 m .25185 .58406 L .24998 .58495 L F
.731 .636 .753 r
.19733 .70366 m .20101 .70409 L .19996 .70075 L F
.735 .618 .728 r
.19733 .70366 m .19832 .70756 L .20101 .70409 L F
.29 0 .221 r
.16717 .56356 m .16598 .56648 L .16421 .56602 L F
.049 0 .104 r
.16761 .56534 m .16717 .56356 L .16934 .56308 L F
.16761 .56534 m .16598 .56648 L .16717 .56356 L F
.958 .859 .701 r
.66354 .41872 m .66617 .41643 L .66584 .41563 L F
.66354 .41872 m .66477 .41999 L .66617 .41643 L F
.365 .791 .972 r
.19922 .70658 m .19832 .70756 L .19676 .70729 L F
.19922 .70658 m .2009 .70714 L .19832 .70756 L F
0 .105 .646 r
.44094 .55776 m .44149 .55723 L .44109 .55708 L F
.338 .819 .811 r
.44106 .55897 m .44149 .55723 L .44094 .55776 L F
.551 .434 .673 r
.56896 .5661 m .56931 .56926 L .56726 .5699 L F
.481 .338 .609 r
.56931 .56926 m .5673 .57246 L .56726 .5699 L F
.704 .97 .931 r
.47714 .58936 m .47637 .58938 L .47967 .58722 L F
.476 0 0 r
.19483 .68041 m .19459 .68019 L .19591 .68138 L F
.232 0 0 r
.19572 .68014 m .19459 .68019 L .19181 .67975 L F
.19181 .67975 m .19459 .68019 L .19572 .68014 L F
.19181 .67975 m .19459 .68019 L .19572 .68014 L F
.19181 .67975 m .19459 .68019 L .1944 .68001 L F
.414 .657 .959 r
.19245 .67829 m .19459 .68019 L .19181 .67975 L F
.19245 .67829 m .19459 .68019 L .19181 .67975 L F
.476 0 0 r
.19245 .67829 m .19459 .68019 L .19483 .68041 L F
.232 0 0 r
.1944 .68001 m .19459 .68019 L .19572 .68014 L F
.647 .967 .891 r
.19572 .68014 m .19459 .68019 L .19641 .67884 L F
.598 .029 0 r
.19591 .68138 m .19572 .68014 L .19641 .67884 L F
.19591 .68138 m .19459 .68019 L .19572 .68014 L F
.868 .734 .712 r
.21594 .6639 m .21781 .66624 L .21705 .66365 L F
.21594 .6639 m .21738 .66777 L .21781 .66624 L F
.76 .661 .752 r
.21422 .68009 m .21168 .68059 L .21385 .67735 L F
.838 .637 .631 r
.21332 .6832 m .21168 .68059 L .21422 .68009 L F
.553 .374 .592 r
.21659 .677 m .21422 .68009 L .21385 .67735 L F
.21659 .677 m .21655 .68028 L .21422 .68009 L F
0 0 0 r
.21655 .68028 m .21332 .6832 L .21422 .68009 L F
.746 .612 .709 r
.46375 .58221 m .46449 .58512 L .46079 .58528 L F
.636 .544 .734 r
.46706 .58423 m .46449 .58512 L .46375 .58221 L F
.27 0 0 r
.44516 .55625 m .44852 .5574 L .44675 .55676 L F
.338 .819 .811 r
.44106 .55897 m .44072 .5587 L .44149 .55723 L F
.44106 .55897 m .43853 .55945 L .44072 .5587 L F
.723 .195 0 r
.44275 .5621 m .43853 .55945 L .44106 .55897 L F
.099 .651 .809 r
.23271 .54002 m .23458 .5399 L .23673 .54016 L F
.147 .691 .778 r
.23458 .5399 m .23891 .53957 L .23673 .54016 L F
.746 .224 0 r
.506 .55091 m .50225 .54803 L .50401 .5506 L F
.956 .826 .676 r
.76125 .42462 m .76242 .42608 L .76181 .42267 L F
.943 .83 .704 r
.75965 .42813 m .76242 .42608 L .76125 .42462 L F
.75965 .42813 m .76097 .42945 L .76242 .42608 L F
.499 0 0 r
.19848 .54022 m .20041 .54115 L .20241 .53989 L F
0 0 0 r
.20241 .53989 m .20041 .54115 L .20236 .54015 L F
.252 .281 .697 r
.74993 .39632 m .75269 .39668 L .75221 .39538 L F
.74993 .39632 m .75116 .39827 L .75269 .39668 L F
.366 .088 .353 r
.57092 .47275 m .57288 .47333 L .57318 .47059 L F
.243 0 .223 r
.57288 .47333 m .57555 .46993 L .57318 .47059 L F
.267 0 .237 r
.50291 .59051 m .50352 .59208 L .50528 .58998 L F
.787 .666 .73 r
.50182 .60137 m .50552 .60246 L .50302 .60469 L F
.692 .501 .624 r
.50552 .60246 m .50572 .60516 L .50302 .60469 L F
.581 .508 .738 r
.50768 .60195 m .50572 .60516 L .50552 .60246 L F
.676 .418 .523 r
.46295 .59376 m .46303 .59594 L .46006 .59607 L F
.43 .144 .376 r
.46635 .59305 m .46303 .59594 L .46295 .59376 L F
.37 .041 .27 r
.55604 .60575 m .55849 .60516 L .55541 .60737 L F
.978 .742 .511 r
.78245 .44268 m .7818 .44433 L .78156 .44103 L F
.967 .733 .533 r
.78156 .44103 m .78175 .44352 L .78009 .44237 L F
.78175 .44352 m .7818 .44433 L .78141 .44388 L F
.78175 .44352 m .78141 .44388 L .78009 .44237 L F
.96 .623 .302 r
.78009 .44237 m .7818 .44433 L .78124 .44431 L F
.999 .803 .506 r
.78124 .44431 m .7818 .44433 L .78245 .44268 L F
.505 0 0 r
.78214 .4431 m .78393 .44378 L .78124 .44431 L F
.78245 .44268 m .7825 .44271 L .78214 .4431 L F
.7825 .44271 m .78393 .44378 L .78214 .4431 L F
.78245 .44268 m .78494 .44383 L .78393 .44378 L F
.268 0 .15 r
.57092 .47275 m .57185 .47451 L .57288 .47333 L F
.57092 .47275 m .56968 .47531 L .57185 .47451 L F
.455 .142 .344 r
.44194 .59519 m .44386 .59559 L .44452 .59366 L F
0 0 .514 r
.52266 .56999 m .52376 .57223 L .52232 .56854 L F
.481 .338 .609 r
.28086 .57261 m .28067 .57591 L .27864 .57583 L F
.47 .471 .777 r
.28067 .57591 m .28161 .57706 L .27864 .57583 L F
.007 .465 .869 r
.75107 .37811 m .75245 .3794 L .74929 .37733 L F
.993 .773 .498 r
.75245 .3794 m .75107 .37811 L .74929 .37733 L F
.75245 .3794 m .75243 .38044 L .75107 .37811 L F
.632 .656 .856 r
.75319 .37419 m .75245 .3794 L .75107 .37811 L F
.75319 .37419 m .75515 .3782 L .75245 .3794 L F
.595 .487 .7 r
.75515 .3782 m .75243 .38044 L .75245 .3794 L F
.57 .349 .54 r
.57431 .53355 m .57701 .53312 L .57687 .53075 L F
.31 .157 .505 r
.57687 .53075 m .5787 .53231 L .57966 .53036 L F
.57687 .53075 m .57701 .53312 L .5787 .53231 L F
0 0 0 r
.15855 .56965 m .1556 .572 L .15628 .57103 L F
0 0 .341 r
.58499 .54944 m .58369 .5485 L .58542 .54729 L F
.58499 .54944 m .58357 .5508 L .58369 .5485 L F
.689 .764 .909 r
.69933 .43541 m .70288 .43601 L .70152 .43416 L F
.706 .72 .861 r
.70152 .43416 m .70288 .43601 L .70521 .43484 L F
.413 0 0 r
.45864 .55969 m .46059 .56056 L .46209 .56088 L F
.035 .596 .803 r
.46274 .56067 m .46209 .56088 L .46059 .56056 L F
.46274 .56067 m .46461 .56106 L .46209 .56088 L F
.581 .262 .394 r
.6938 .40159 m .69119 .39957 L .69137 .40121 L F
.6938 .40159 m .69456 .39876 L .69119 .39957 L F
0 0 0 r
.15477 .55431 m .15678 .55369 L .15869 .55284 L F
.236 0 0 r
.15678 .55369 m .16093 .55206 L .15869 .55284 L F
.897 .747 .245 r
.6554 .42547 m .65513 .4243 L .65566 .42286 L F
.896 .839 .379 r
.65566 .42286 m .65543 .42201 L .65615 .41887 L F
.871 .757 .249 r
.65566 .42286 m .65513 .4243 L .65543 .42201 L F
.932 .956 .641 r
.44617 .64419 m .4443 .64572 L .44542 .64417 L F
.75 .446 .468 r
.43292 .65294 m .43492 .65552 L .43559 .65366 L F
.038 0 .429 r
.53084 .53568 m .53088 .53837 L .52914 .5397 L F
0 0 0 r
.52982 .54029 m .52914 .5397 L .53088 .53837 L F
.52982 .54029 m .52935 .54059 L .52914 .5397 L F
.946 .898 .747 r
.53958 .5875 m .54178 .58454 L .54238 .5873 L F
0 .133 .68 r
.54071 .58892 m .53958 .5875 L .54238 .5873 L F
.574 .233 .353 r
.45069 .57907 m .45002 .58077 L .44735 .58096 L F
.627 .377 .52 r
.45323 .57819 m .45002 .58077 L .45069 .57907 L F
.17 0 .145 r
.56556 .47738 m .56483 .47901 L .56758 .47634 L F
.864 .778 .764 r
.53961 .54891 m .53911 .54452 L .53828 .54837 L F
.88 .699 .653 r
.4808 .58544 m .48185 .58411 L .47992 .58495 L F
.581 .187 .26 r
.4377 .58067 m .4366 .58316 L .43983 .58146 L F
.4377 .58067 m .43983 .58146 L .43738 .58242 L F
.425 .051 .222 r
.4377 .58067 m .43738 .58242 L .44007 .57888 L F
.673 .337 .398 r
.44007 .57888 m .43738 .58242 L .43983 .58146 L F
.009 0 0 r
.44007 .57888 m .43738 .58242 L .44268 .57753 L F
.425 .051 .222 r
.4377 .58067 m .43738 .58242 L .44007 .57888 L F
.6 .821 .984 r
.17661 .65303 m .18037 .65345 L .17897 .65248 L F
.461 .675 .956 r
.18037 .65345 m .18123 .65169 L .17897 .65248 L F
.18037 .65345 m .18258 .65326 L .18123 .65169 L F
.838 .637 .631 r
.21332 .6832 m .21088 .68286 L .21168 .68059 L F
.696 .384 .444 r
.21332 .6832 m .21082 .68539 L .21088 .68286 L F
.21332 .6832 m .21387 .68554 L .21082 .68539 L F
0 0 0 r
.21655 .68028 m .21492 .68224 L .21387 .6827 L F
.637 .532 .719 r
.21228 .68193 m .21492 .68224 L .21494 .67856 L F
.438 .72 .984 r
.21416 .68159 m .21492 .68224 L .21228 .68193 L F
.03 0 0 r
.21416 .68159 m .21431 .68227 L .215 .68226 L F
.082 .316 .795 r
.21706 .68223 m .21492 .68224 L .21565 .68192 L F
.03 0 0 r
.2153 .68184 m .215 .68226 L .21706 .68223 L F
0 0 0 r
.21549 .68159 m .21492 .68224 L .21513 .68199 L F
.21596 .68106 m .21545 .68164 L .21549 .68159 L F
.21545 .68164 m .21492 .68224 L .21549 .68159 L F
.21596 .68106 m .21513 .68199 L .21655 .68028 L F
.085 .121 .602 r
.21596 .68106 m .21494 .67856 L .21492 .68224 L F
.082 .316 .795 r
.21565 .68192 m .21492 .68224 L .21416 .68159 L F
.03 0 0 r
.21416 .68159 m .215 .68226 L .2153 .68184 L F
.243 0 0 r
.21913 .6806 m .21682 .68132 L .21596 .68106 L F
.085 .121 .602 r
.21596 .68106 m .21682 .68132 L .21635 .68062 L F
.21596 .68106 m .21635 .68062 L .21494 .67856 L F
0 0 0 r
.21387 .6827 m .21492 .68224 L .21332 .6832 L F
.513 .27 .483 r
.21561 .68488 m .21332 .6832 L .21492 .68224 L F
.21561 .68488 m .21387 .68554 L .21332 .6832 L F
.719 .187 0 r
.41256 .64058 m .41662 .64372 L .41437 .64206 L F
.757 .647 .74 r
.21659 .677 m .21385 .67735 L .21606 .67493 L F
.587 .539 .768 r
.21814 .67416 m .21659 .677 L .21606 .67493 L F
.21814 .67416 m .21934 .6766 L .21659 .677 L F
.477 .313 .579 r
.21897 .67948 m .21659 .677 L .21934 .6766 L F
.21897 .67948 m .21655 .68028 L .21659 .677 L F
.798 .981 .899 r
.50195 .53043 m .50352 .52789 L .50452 .52963 L F
.473 .389 .68 r
.50484 .52801 m .50452 .52963 L .50684 .52709 L F
.774 .897 .929 r
.50684 .52709 m .50452 .52963 L .50352 .52789 L F
.304 .003 .278 r
.44452 .59366 m .44386 .59559 L .44653 .5929 L F
.644 .097 0 r
.24644 .55712 m .24502 .55726 L .24304 .55566 L F
.49 .903 .874 r
.24681 .55609 m .24644 .55712 L .2483 .55626 L F
.24681 .55609 m .24502 .55726 L .24644 .55712 L F
.666 .851 .97 r
.19883 .55481 m .20258 .55487 L .20086 .55361 L F
.151 0 .194 r
.47625 .59667 m .47347 .59979 L .47572 .59844 L F
.088 .133 .614 r
.47347 .59979 m .47429 .6012 L .47475 .60039 L F
.204 .028 .406 r
.57056 .58971 m .57033 .59207 L .56803 .59299 L F
.382 .272 .603 r
.57033 .59207 m .56832 .59552 L .56803 .59299 L F
.511 .178 .34 r
.43584 .61128 m .43494 .61362 L .43227 .61386 L F
.531 .223 .39 r
.43824 .61097 m .43494 .61362 L .43584 .61128 L F
.535 .322 .537 r
.27333 .59352 m .273 .59597 L .27065 .59628 L F
.499 .338 .593 r
.27521 .59275 m .273 .59597 L .27333 .59352 L F
.573 .552 .793 r
.78789 .41607 m .78552 .4172 L .78454 .41373 L F
.067 0 .435 r
.7868 .41792 m .78552 .4172 L .78789 .41607 L F
.7868 .41792 m .78543 .41971 L .78552 .4172 L F
.195 .724 .824 r
.21847 .65921 m .22112 .65887 L .2218 .65897 L F
.517 .376 .628 r
.22416 .66102 m .2218 .65897 L .22516 .65897 L F
.055 0 0 r
.2242 .65895 m .22516 .65897 L .22403 .65897 L F
.2242 .65895 m .22498 .65903 L .22516 .65897 L F
0 0 .351 r
.22505 .65744 m .22466 .659 L .22516 .65897 L F
.22466 .659 m .22416 .66102 L .22516 .65897 L F
.22509 .65882 m .22514 .66034 L .22469 .65888 L F
.055 0 0 r
.22444 .65901 m .22497 .65903 L .22498 .65903 L F
.2242 .65895 m .22403 .65897 L .2218 .65897 L F
.22112 .65887 m .22442 .65901 L .22444 .65901 L F
.22442 .65901 m .22497 .65903 L .22444 .65901 L F
.22112 .65887 m .2242 .65895 L .2218 .65897 L F
.22112 .65887 m .22498 .65903 L .2242 .65895 L F
0 0 .351 r
.22466 .659 m .22514 .66034 L .22416 .66102 L F
.22469 .65888 m .22473 .659 L .22466 .659 L F
.22473 .659 m .22514 .66034 L .22466 .659 L F
.798 .675 .127 r
.22516 .65897 m .22498 .65903 L .22505 .65744 L F
0 0 .351 r
.22505 .65744 m .22498 .65884 L .22469 .65888 L F
.798 .675 .127 r
.22498 .65903 m .22497 .65903 L .22505 .65744 L F
0 0 .351 r
.22505 .65744 m .22509 .65882 L .22498 .65884 L F
.517 .376 .628 r
.22416 .66102 m .22236 .66228 L .2218 .65897 L F
.487 .256 .489 r
.24703 .58746 m .24666 .58984 L .24882 .58928 L F
.532 .255 .44 r
.24703 .58746 m .24882 .58928 L .24942 .58718 L F
.367 .827 .741 r
.49515 .53586 m .49593 .5354 L .49736 .53648 L F
.49515 .53586 m .49368 .53642 L .49593 .5354 L F
.998 .844 .55 r
.76185 .41767 m .76328 .4169 L .76223 .41587 L F
.76185 .41767 m .76287 .41891 L .76328 .4169 L F
.742 .862 .936 r
.67641 .44889 m .6765 .45161 L .67959 .449 L F
.839 .686 .692 r
.43492 .65552 m .43671 .65908 L .43782 .65614 L F
.555 .414 .644 r
.45746 .59643 m .45757 .59905 L .45506 .5995 L F
.637 .489 .665 r
.45757 .59905 m .45516 .60188 L .45506 .5995 L F
.392 .299 .629 r
.27277 .59841 m .27065 .59628 L .273 .59597 L F
.27277 .59841 m .27114 .59918 L .27065 .59628 L F
.273 0 .151 r
.16513 .56779 m .16421 .56602 L .16598 .56648 L F
.16513 .56779 m .16295 .56855 L .16421 .56602 L F
.691 .15 0 r
.49736 .53648 m .49962 .53858 L .50085 .53857 L F
.911 .975 .787 r
.50085 .53857 m .50193 .53553 L .503 .53724 L F
.50085 .53857 m .49962 .53858 L .50193 .53553 L F
.082 .192 .68 r
.65504 .43172 m .65631 .43038 L .6556 .42747 L F
.396 .694 .98 r
.65504 .43172 m .65758 .43178 L .65631 .43038 L F
.043 .567 .867 r
.40503 .64505 m .40439 .64455 L .4018 .64408 L F
.029 .422 .864 r
.40503 .64505 m .40727 .64529 L .40439 .64455 L F
.40503 .64505 m .40792 .64645 L .40727 .64529 L F
.698 .727 .872 r
.72667 .3925 m .7303 .39323 L .72915 .39048 L F
.774 .764 .844 r
.72915 .39048 m .7303 .39323 L .73276 .39027 L F
.599 .522 .739 r
.7303 .39323 m .7322 .3977 L .7341 .39627 L F
.85 .77 .774 r
.67839 .43856 m .67468 .44024 L .67722 .43694 L F
.67839 .43856 m .67668 .44136 L .67468 .44024 L F
.699 .876 .964 r
.67952 .43635 m .67839 .43856 L .67722 .43694 L F
.67952 .43635 m .68061 .43749 L .67839 .43856 L F
.79 .785 .848 r
.71864 .428 m .72248 .42857 L .7215 .42536 L F
.71864 .428 m .72014 .42939 L .72248 .42857 L F
.808 .823 .862 r
.7215 .42536 m .72248 .42857 L .7247 .42548 L F
.654 .661 .844 r
.72248 .42857 m .72592 .42914 L .7247 .42548 L F
0 0 0 r
.43623 .58938 m .43552 .59029 L .4371 .58824 L F
.075 0 .317 r
.43623 .58938 m .4342 .59288 L .43552 .59029 L F
0 0 0 r
.51589 .5343 m .51595 .53408 L .51627 .53163 L F
0 0 .069 r
.51627 .53163 m .51595 .53408 L .51825 .52929 L F
.395 0 0 r
.24304 .55566 m .24103 .55594 L .23895 .55539 L F
0 .121 .615 r
.24304 .55566 m .24327 .55554 L .24103 .55594 L F
.24304 .55566 m .24502 .55726 L .24327 .55554 L F
.999 .81 .514 r
.5911 .49489 m .59075 .49737 L .59009 .49376 L F
.478 .237 .47 r
.49044 .6025 m .48974 .60501 L .4874 .60552 L F
.603 .558 .777 r
.49078 .60228 m .48974 .60501 L .49044 .6025 L F
.236 0 .288 r
.23342 .61137 m .23503 .6103 L .23555 .60773 L F
.288 .077 .409 r
.23555 .60773 m .2376 .60801 L .23841 .6051 L F
.294 .016 .308 r
.23555 .60773 m .2368 .60971 L .2376 .60801 L F
.23555 .60773 m .23503 .6103 L .2368 .60971 L F
.211 .356 .792 r
.75871 .38529 m .7575 .38705 L .7561 .38299 L F
.189 .324 .771 r
.75998 .38886 m .7575 .38705 L .75871 .38529 L F
.52 .28 .491 r
.47572 .59844 m .47831 .59573 L .47625 .59667 L F
.796 .656 .708 r
.20569 .68662 m .20711 .68906 L .20257 .68898 L F
.712 .317 .297 r
.20711 .68906 m .20503 .69063 L .20257 .68898 L F
.659 .939 .677 r
.20706 .68847 m .20711 .68906 L .20931 .68947 L F
.20706 .68847 m .20503 .69063 L .20711 .68906 L F
.971 .92 .687 r
.48104 .59543 m .48092 .59967 L .48238 .5965 L F
.215 0 0 r
.48078 .59973 m .48227 .60008 L .48092 .59967 L F
.663 .435 .564 r
.57644 .48588 m .57643 .48848 L .57377 .48841 L F
.598 .383 .56 r
.5796 .48714 m .57644 .48588 L .57853 .48537 L F
.5796 .48714 m .57643 .48848 L .57644 .48588 L F
.495 .196 .389 r
.18181 .54371 m .18459 .54281 L .18388 .54285 L F
.764 .62 .701 r
.42883 .63765 m .43249 .63823 L .43167 .63538 L F
.126 .031 .467 r
.43249 .63823 m .43381 .63488 L .43167 .63538 L F
.43249 .63823 m .43396 .63783 L .43381 .63488 L F
.713 .343 .346 r
.43299 .63872 m .43489 .64054 L .43273 .63951 L F
.645 .369 .486 r
.43537 .63826 m .43489 .64054 L .43249 .63823 L F
.748 .497 .552 r
.43381 .63488 m .43396 .63783 L .43451 .63779 L F
.43547 .6361 m .43451 .63779 L .43751 .63761 L F
.43381 .63488 m .43451 .63779 L .43547 .6361 L F
.447 .354 .657 r
.43396 .63783 m .43611 .63661 L .43751 .63761 L F
0 0 .053 r
.43419 .63835 m .4351 .63862 L .43611 .63661 L F
.11 0 0 r
.43063 .64192 m .42991 .64106 L .43225 .6393 L F
.345 0 .025 r
.43063 .64192 m .43237 .64 L .4319 .63988 L F
.11 0 0 r
.43063 .64192 m .43225 .6393 L .43227 .63929 L F
.345 0 .025 r
.43063 .64192 m .4319 .63988 L .43063 .63954 L F
.91 .547 .335 r
.43116 .63878 m .43063 .63954 L .43188 .63988 L F
.43191 .63954 m .43188 .63988 L .43237 .64 L F
.43116 .63878 m .43188 .63988 L .43191 .63954 L F
.12 0 0 r
.43273 .63951 m .43184 .64053 L .43227 .63929 L F
.43184 .64053 m .43063 .64192 L .43188 .63991 L F
.43184 .64053 m .43188 .63991 L .43227 .63929 L F
.43246 .64043 m .43205 .64146 L .43241 .64043 L F
.43489 .64054 m .43222 .64141 L .43246 .64043 L F
.43222 .64141 m .43205 .64146 L .43246 .64043 L F
.43322 .63974 m .43241 .64043 L .43273 .63951 L F
.43489 .64054 m .43241 .64043 L .43322 .63974 L F
.43489 .64054 m .43285 .64159 L .43063 .64192 L F
.359 .153 .458 r
.43285 .64159 m .4351 .63862 L .4326 .63989 L F
.43248 .64037 m .4326 .63989 L .43237 .64 L F
.43285 .64159 m .4326 .63989 L .43248 .64037 L F
.345 0 .025 r
.43063 .64192 m .43248 .64037 L .43237 .64 L F
0 0 .053 r
.43237 .64 m .4326 .63989 L .43264 .63975 L F
.12 0 0 r
.43205 .64146 m .43063 .64192 L .43273 .63951 L F
.345 0 .025 r
.43063 .64192 m .43285 .64159 L .43248 .64037 L F
0 0 .053 r
.43264 .63975 m .4326 .63988 L .43265 .63975 L F
.4326 .63989 m .4326 .63988 L .43264 .63975 L F
.43265 .63975 m .43366 .63928 L .43419 .63835 L F
.43366 .63928 m .4351 .63862 L .43419 .63835 L F
.4326 .63988 m .4351 .63862 L .43265 .63975 L F
.713 .343 .346 r
.43249 .63823 m .43299 .63872 L .43257 .63943 L F
.43299 .63872 m .43273 .63951 L .43257 .63943 L F
.43249 .63823 m .43237 .64 L .43259 .63969 L F
.43249 .63823 m .43257 .63943 L .43227 .63929 L F
.43249 .63823 m .43259 .63969 L .43396 .63783 L F
.43249 .63823 m .43227 .63929 L .43116 .63878 L F
.878 .808 .777 r
.61283 .47012 m .61642 .46824 L .61492 .4668 L F
.61283 .47012 m .61438 .47143 L .61642 .46824 L F
0 0 .159 r
.76941 .40813 m .76975 .41074 L .76964 .40876 L F
.295 .767 .647 r
.52499 .51414 m .52664 .5134 L .52302 .51504 L F
0 0 0 r
.52731 .51342 m .52875 .51223 L .52664 .5134 L F
.765 .745 .835 r
.70997 .43104 m .71365 .43165 L .71298 .42902 L F
.70997 .43104 m .71144 .43259 L .71365 .43165 L F
.706 .775 .906 r
.71298 .42902 m .71365 .43165 L .71655 .42927 L F
.186 .007 .39 r
.28194 .58076 m .28002 .58416 L .27986 .58153 L F
.53 .398 .645 r
.57104 .56306 m .56896 .5661 L .56855 .56361 L F
.823 .785 .816 r
.47967 .58722 m .48321 .58737 L .4808 .58544 L F
.592 .377 .557 r
.56762 .48885 m .56765 .49137 L .56518 .49165 L F
.608 .372 .534 r
.56982 .48873 m .56765 .49137 L .56762 .48885 L F
.432 .311 .614 r
.28018 .56033 m .28052 .56263 L .27838 .56075 L F
.357 .308 .666 r
.27838 .56075 m .28052 .56263 L .27886 .5628 L F
.533 .276 .472 r
.69722 .4004 m .69456 .39876 L .6938 .40159 L F
.69722 .4004 m .69733 .39842 L .69456 .39876 L F
.485 .823 .999 r
.23891 .53957 m .24104 .53914 L .24269 .53989 L F
.202 .671 .939 r
.24104 .53914 m .24496 .54003 L .24269 .53989 L F
.387 0 .159 r
.71312 .39878 m .71534 .40016 L .71295 .40117 L F
.71312 .39878 m .71557 .39834 L .71534 .40016 L F
.835 .823 .837 r
.62115 .44946 m .62534 .44735 L .62339 .44642 L F
.694 .784 .92 r
.62339 .44642 m .62534 .44735 L .62702 .44693 L F
.646 .788 .95 r
.55381 .55681 m .55495 .55807 L .55746 .55729 L F
.522 .518 .793 r
.55495 .55807 m .55815 .56 L .55746 .55729 L F
.473 .349 .631 r
.55576 .56437 m .55837 .56348 L .55815 .56 L F
.437 .377 .692 r
.55676 .56588 m .55837 .56348 L .55576 .56437 L F
.771 .768 .85 r
.64437 .42785 m .64629 .4289 L .64596 .42707 L F
.64437 .42785 m .64523 .42943 L .64629 .4289 L F
.886 .967 .838 r
.64596 .42707 m .64629 .4289 L .6493 .42496 L F
.684 .285 .284 r
.51266 .53501 m .51424 .53584 L .51589 .5343 L F
.462 .312 .592 r
.51424 .53584 m .51595 .53408 L .51589 .5343 L F
.407 .201 .485 r
.57431 .53355 m .57196 .53662 L .57446 .5361 L F
.501 .347 .604 r
.57232 .53944 m .57446 .5361 L .57196 .53662 L F
.771 .619 .692 r
.58205 .48262 m .58253 .48651 L .57853 .48537 L F
.468 .505 .813 r
.5848 .48515 m .58205 .48262 L .58466 .48236 L F
.802 .902 .912 r
.68781 .43241 m .68682 .43531 L .68593 .43462 L F
.68781 .43241 m .68918 .43356 L .68682 .43531 L F
.159 .674 .893 r
.20588 .53954 m .20669 .53938 L .20849 .5399 L F
.262 0 0 r
.20473 .53995 m .20745 .53922 L .20669 .53938 L F
.448 .831 .988 r
.20669 .53938 m .2085 .53894 L .21066 .53953 L F
.262 0 0 r
.20745 .53922 m .2085 .53894 L .20669 .53938 L F
.159 .674 .893 r
.20449 .53935 m .20669 .53938 L .20588 .53954 L F
.448 .831 .988 r
.20669 .53938 m .21066 .53953 L .20849 .5399 L F
.216 0 .162 r
.5919 .45622 m .58905 .45873 L .59122 .45764 L F
.318 .12 .447 r
.59122 .45764 m .5933 .45438 L .5919 .45622 L F
.104 .261 .741 r
.49854 .53499 m .49736 .53648 L .49593 .5354 L F
.49854 .53499 m .49962 .53858 L .49736 .53648 L F
.462 .369 .664 r
.60752 .43217 m .60982 .42806 L .60757 .42872 L F
.60752 .43217 m .61053 .43107 L .60982 .42806 L F
.751 .271 0 r
.41339 .64994 m .41383 .65151 L .4122 .64896 L F
.41339 .64994 m .41506 .65252 L .41383 .65151 L F
.117 0 .407 r
.58626 .5427 m .5877 .53929 L .58742 .54157 L F
0 0 .273 r
.58593 .54504 m .58626 .5427 L .58742 .54157 L F
0 .342 .821 r
.6552 .40759 m .65719 .40892 L .65692 .40782 L F
.072 .39 .85 r
.65451 .40637 m .65692 .40782 L .65665 .40632 L F
.945 .868 .732 r
.6557 .41119 m .65661 .40652 L .65692 .40782 L F
.65661 .40652 m .65665 .40632 L .65692 .40782 L F
0 .342 .821 r
.65719 .40892 m .65842 .40974 L .65692 .40782 L F
.293 .047 .36 r
.47992 .58495 m .47967 .58722 L .4808 .58544 L F
.272 0 .124 r
.48974 .60501 m .48674 .60725 L .4874 .60552 L F
.755 .556 .627 r
.51032 .5964 m .51041 .59916 L .50628 .59844 L F
.813 .759 .802 r
.42898 .56645 m .42633 .56624 L .42855 .56413 L F
.182 0 .141 r
.42898 .56645 m .42841 .56873 L .42609 .56946 L F
.108 0 .085 r
.43103 .56533 m .42898 .56645 L .43175 .56419 L F
0 0 .009 r
.42981 .5669 m .42898 .56645 L .43103 .56533 L F
.42981 .5669 m .42841 .56873 L .42898 .56645 L F
.969 .891 .518 r
.67668 .44136 m .67548 .44297 L .67468 .44024 L F
.67668 .44136 m .67601 .44375 L .67548 .44297 L F
.452 .841 .983 r
.73691 .42478 m .73427 .4254 L .7334 .42477 L F
.144 0 0 r
.22919 .62029 m .22938 .62155 L .23049 .61966 L F
.22919 .62029 m .2274 .62215 L .22938 .62155 L F
.313 .798 .891 r
.46461 .56106 m .46711 .56055 L .46828 .56074 L F
.427 .851 .952 r
.46711 .56055 m .47067 .56032 L .46828 .56074 L F
0 0 0 r
.44736 .58361 m .4452 .58681 L .44616 .58489 L F
.98 .826 .426 r
.65121 .41656 m .65081 .41894 L .65134 .4196 L F
.962 .891 .509 r
.65013 .41996 m .65134 .4196 L .65081 .41894 L F
.65013 .41996 m .65049 .42343 L .65134 .4196 L F
.896 .985 .727 r
.65049 .42343 m .6488 .42431 L .6493 .42496 L F
.962 .943 .682 r
.65013 .41996 m .6488 .42431 L .65049 .42343 L F
0 .385 .732 r
.55416 .59449 m .55315 .59433 L .55232 .59215 L F
.55416 .59449 m .5556 .59517 L .55315 .59433 L F
.166 .565 .933 r
.26297 .54347 m .26287 .54461 L .26102 .54335 L F
.26297 .54347 m .26448 .54482 L .26287 .54461 L F
.03 .589 .812 r
.24875 .54079 m .25103 .54095 L .25309 .5414 L F
0 .523 .76 r
.25103 .54095 m .25491 .54166 L .25309 .5414 L F
.645 .223 .227 r
.58253 .48651 m .5796 .48714 L .57853 .48537 L F
.58253 .48651 m .58227 .48767 L .5796 .48714 L F
.127 0 .12 r
.24166 .63794 m .23894 .64067 L .23996 .63895 L F
.372 .035 .259 r
.43922 .58725 m .43623 .58938 L .4371 .58824 L F
.478 .753 .99 r
.40177 .64071 m .40166 .6412 L .40302 .63992 L F
.204 .133 .549 r
.40166 .6412 m .40347 .64252 L .40302 .63992 L F
.40166 .6412 m .4018 .64408 L .40347 .64252 L F
0 0 .358 r
.61708 .43391 m .6183 .43756 L .61735 .43514 L F
.728 .688 .812 r
.73276 .39027 m .73644 .39119 L .7353 .38932 L F
.655 .729 .903 r
.73644 .39119 m .73902 .39029 L .7353 .38932 L F
.108 0 .029 r
.56272 .47994 m .55978 .4825 L .56198 .48123 L F
.396 .088 .322 r
.56198 .48123 m .56483 .47901 L .56272 .47994 L F
0 0 .41 r
.53459 .56856 m .53571 .57202 L .53483 .56987 L F
.986 .901 .6 r
.65165 .40855 m .65121 .41656 L .65119 .41412 L F
0 .406 .847 r
.54153 .55305 m .54181 .55383 L .53966 .55154 L F
.54153 .55305 m .54349 .55476 L .54181 .55383 L F
.917 .731 .636 r
.53376 .55392 m .53546 .55472 L .53415 .55109 L F
.075 .237 .728 r
.53415 .55109 m .53546 .55472 L .53629 .55265 L F
.589 .513 .737 r
.53835 .55311 m .53546 .55472 L .53774 .55136 L F
0 .023 .583 r
.53835 .55311 m .53774 .55136 L .53546 .55472 L F
.589 .513 .737 r
.53835 .55311 m .53546 .55472 L .53774 .55136 L F
.594 .021 0 r
.41088 .64745 m .41059 .6478 L .40792 .64645 L F
.349 .686 .98 r
.18571 .63166 m .1849 .63296 L .18361 .6313 L F
.18571 .63166 m .18812 .63329 L .1849 .63296 L F
.63 .609 .81 r
.50802 .58456 m .50492 .58425 L .50636 .58346 L F
.602 .407 .589 r
.70583 .39512 m .70817 .3925 L .70559 .39312 L F
.613 .789 .966 r
.73902 .39029 m .74254 .39091 L .74144 .38922 L F
.642 .753 .929 r
.74254 .39091 m .74518 .38996 L .74144 .38922 L F
.894 .571 .076 r
.25458 .56686 m .25539 .56946 L .25428 .56598 L F
.702 .435 .517 r
.42898 .6554 m .43292 .65294 L .42904 .65287 L F
.42898 .6554 m .43267 .65576 L .43292 .65294 L F
.714 .445 .518 r
.43292 .65294 m .43267 .65576 L .43492 .65552 L F
.227 0 .25 r
.25539 .56946 m .25275 .57243 L .25454 .5717 L F
.522 .478 .748 r
.25428 .56598 m .25539 .56946 L .25746 .56882 L F
.268 0 .27 r
.25539 .56946 m .25652 .57078 L .25746 .56882 L F
.25539 .56946 m .25454 .5717 L .25652 .57078 L F
.418 .275 .579 r
.54423 .58095 m .54426 .58389 L .54178 .58454 L F
.643 .819 .396 r
.54426 .58389 m .54345 .58525 L .54178 .58454 L F
.337 .269 .632 r
.54345 .58525 m .54238 .5873 L .54178 .58454 L F
.208 0 0 r
.23727 .64273 m .23686 .64134 L .23894 .64067 L F
.23727 .64273 m .23525 .64326 L .23686 .64134 L F
.757 .739 .836 r
.70797 .43225 m .71144 .43259 L .70997 .43104 L F
.874 .619 .549 r
.5939 .48544 m .59082 .48229 L .59461 .48289 L F
.5939 .48544 m .59082 .48478 L .59082 .48229 L F
.866 .724 .704 r
.5939 .48544 m .5921 .48833 L .59082 .48478 L F
.59 .05 0 r
.21083 .55199 m .21304 .55337 L .20916 .55268 L F
.666 .764 .924 r
.75333 .40405 m .75509 .40532 L .75137 .40468 L F
.763 .647 .734 r
.75137 .40468 m .75509 .40532 L .75285 .40819 L F
.767 .8 .313 r
.75635 .40097 m .75509 .40532 L .75333 .40405 L F
.846 .831 .832 r
.20457 .69272 m .20234 .6953 L .20208 .69398 L F
0 0 0 r
.53964 .51844 m .53872 .52017 L .53721 .52081 L F
.53721 .52081 m .53872 .52017 L .53558 .5227 L F
.429 .872 .867 r
.66277 .43991 m .65998 .44099 L .66054 .44039 L F
.937 .63 .174 r
.65998 .44099 m .66032 .44318 L .65944 .4419 L F
.65998 .44099 m .65944 .4419 L .66054 .44039 L F
.495 .275 .509 r
.41435 .63152 m .41126 .63222 L .41161 .62923 L F
.773 .6 .664 r
.74993 .38365 m .75243 .38044 L .74998 .3811 L F
.586 .711 .929 r
.75243 .38044 m .75388 .37748 L .75107 .37811 L F
.595 .487 .7 r
.75515 .3782 m .75487 .38012 L .75243 .38044 L F
.586 .711 .929 r
.75243 .38044 m .75487 .38012 L .75388 .37748 L F
.605 .405 .584 r
.75325 .3834 m .75481 .38149 L .75243 .38044 L F
.562 .298 .473 r
.70255 .39799 m .69992 .39627 L .69992 .3984 L F
.70255 .39799 m .70261 .3959 L .69992 .39627 L F
.533 .285 .485 r
.5116 .53459 m .51266 .53501 L .50926 .53507 L F
0 0 0 r
.58959 .53372 m .59208 .53007 L .59119 .53215 L F
0 0 .38 r
.59092 .53413 m .58959 .53372 L .59119 .53215 L F
.59092 .53413 m .5896 .53571 L .58959 .53372 L F
.795 .746 .807 r
.71472 .42043 m .71157 .42034 L .71357 .41886 L F
.685 .762 .91 r
.7173 .41956 m .71472 .42043 L .71357 .41886 L F
.365 0 0 r
.21694 .55213 m .21552 .55343 L .21304 .55337 L F
0 0 0 r
.21738 .55211 m .21694 .55213 L .21869 .55218 L F
.21738 .55211 m .21552 .55343 L .21694 .55213 L F
.85 .761 .764 r
.50195 .53043 m .49808 .53201 L .50069 .53034 L F
.50195 .53043 m .49952 .53449 L .49808 .53201 L F
.798 .981 .899 r
.50195 .53043 m .50122 .52978 L .50352 .52789 L F
.986 .897 .579 r
.50195 .53043 m .50069 .53034 L .50122 .52978 L F
0 0 .006 r
.41917 .6292 m .41807 .63137 L .41868 .6297 L F
.557 .352 .558 r
.5673 .57246 m .56732 .57524 L .56478 .57571 L F
.481 .338 .609 r
.56931 .56926 m .56952 .57192 L .5673 .57246 L F
.521 .323 .553 r
.56979 .57458 m .5673 .57246 L .56952 .57192 L F
.56979 .57458 m .56732 .57524 L .5673 .57246 L F
0 0 .004 r
.18983 .72759 m .19249 .72469 L .19016 .72702 L F
.419 .496 .831 r
.7366 .39487 m .73806 .39871 L .74005 .39848 L F
.768 .388 .335 r
.53254 .56334 m .53296 .56513 L .53608 .56396 L F
.882 .861 .815 r
.53296 .56513 m .53676 .56305 L .53608 .56396 L F
.458 .214 .455 r
.61955 .41427 m .62197 .41543 L .6229 .41401 L F
.61955 .41427 m .61976 .41614 L .62197 .41543 L F
.35 0 .119 r
.58797 .46015 m .59122 .45764 L .58905 .45873 L F
.469 .124 .297 r
.70733 .40255 m .70988 .4036 L .70727 .4039 L F
.70733 .40255 m .71018 .40152 L .70988 .4036 L F
.195 .131 .553 r
.55867 .5872 m .55947 .58393 L .55634 .58335 L F
.55867 .5872 m .55986 .58663 L .55947 .58393 L F
.18 .098 .52 r
.55867 .5872 m .56004 .58921 L .55986 .58663 L F
.627 .464 .642 r
.54679 .57841 m .55019 .57813 L .54976 .57493 L F
.637 .578 .771 r
.54679 .57841 m .5505 .58136 L .5468 .58091 L F
.594 .33 .486 r
.54679 .57841 m .54945 .58076 L .5468 .58091 L F
.637 .578 .771 r
.54679 .57841 m .55019 .57813 L .5505 .58136 L F
.594 .33 .486 r
.54679 .57841 m .55019 .57813 L .54945 .58076 L F
.236 .347 .774 r
.53896 .55773 m .54144 .55938 L .54026 .55597 L F
.921 .908 .792 r
.48323 .5924 m .48238 .5965 L .48458 .59545 L F
.48323 .5924 m .48104 .59543 L .48238 .5965 L F
.438 .238 .509 r
.60757 .42872 m .60982 .42806 L .60996 .42584 L F
.939 .939 .596 r
.60286 .5041 m .60428 .5006 L .60298 .50161 L F
.927 .972 .707 r
.60381 .49979 m .60428 .5006 L .6062 .49703 L F
.956 .928 .585 r
.60298 .50161 m .60428 .5006 L .60381 .49979 L F
.295 .767 .647 r
.52499 .51414 m .52302 .51504 L .52282 .51519 L F
.604 .628 .849 r
.20421 .70953 m .20199 .70993 L .2009 .70714 L F
0 0 .187 r
.20246 .71125 m .20199 .70993 L .20421 .70953 L F
.20246 .71125 m .20207 .71262 L .20199 .70993 L F
.729 .515 .601 r
.42851 .62045 m .42457 .62255 L .42515 .61985 L F
.42851 .62045 m .4283 .62325 L .42457 .62255 L F
.538 .308 .514 r
.43116 .62001 m .4283 .62325 L .42851 .62045 L F
.521 .439 .704 r
.47541 .60455 m .47809 .60764 L .47772 .60605 L F
.47541 .60455 m .476 .60858 L .47809 .60764 L F
.652 .508 .674 r
.47541 .60455 m .47772 .60605 L .4772 .60267 L F
.479 .102 .246 r
.44436 .60817 m .44317 .61039 L .44067 .61061 L F
.529 .404 .653 r
.44596 .60526 m .44663 .60769 L .44436 .60817 L F
.468 .091 .24 r
.44638 .60948 m .44436 .60817 L .44663 .60769 L F
.44638 .60948 m .44317 .61039 L .44436 .60817 L F
.115 0 .369 r
.58389 .46165 m .58532 .46275 L .58565 .46093 L F
.58389 .46165 m .58366 .46431 L .58532 .46275 L F
.731 .635 .752 r
.19721 .70124 m .19733 .70366 L .19996 .70075 L F
0 0 .117 r
.58311 .52348 m .58226 .52482 L .58178 .527 L F
.443 .658 .952 r
.3925 .62613 m .39405 .62416 L .38995 .62325 L F
.3925 .62613 m .39403 .62561 L .39405 .62416 L F
.594 .492 .707 r
.3925 .62613 m .39528 .62908 L .39403 .62561 L F
.3925 .62613 m .39298 .62963 L .39528 .62908 L F
.328 0 0 r
.66032 .44318 m .66339 .44401 L .66243 .44398 L F
.014 .422 .861 r
.65944 .4419 m .66032 .44318 L .66243 .44398 L F
.65944 .4419 m .66243 .44398 L .66148 .444 L F
0 0 0 r
.66243 .44398 m .66402 .44346 L .66171 .44395 L F
.66243 .44398 m .66171 .44395 L .66148 .444 L F
.328 0 0 r
.66339 .44401 m .66379 .44412 L .66243 .44398 L F
.486 .885 .951 r
.66558 .44277 m .66619 .44329 L .66379 .44412 L F
.66379 .44412 m .66558 .44277 L .66243 .44398 L F
.66379 .44412 m .66619 .44329 L .66558 .44277 L F
.499 .354 .614 r
.45007 .56311 m .45028 .56576 L .44797 .5651 L F
.704 .307 .293 r
.45071 .56781 m .44797 .5651 L .45028 .56576 L F
.45071 .56781 m .44596 .56755 L .44797 .5651 L F
.304 0 .119 r
.39165 .60131 m .39501 .59872 L .39259 .59907 L F
.161 .701 .793 r
.21066 .53953 m .21286 .53926 L .21451 .53923 L F
.201 .725 .85 r
.21286 .53926 m .21669 .53914 L .21451 .53923 L F
.66 .599 .775 r
.74624 .38343 m .74755 .38603 L .74993 .38365 L F
.407 .567 .9 r
.74755 .38603 m .75047 .38769 L .74993 .38365 L F
.461 .264 .526 r
.4947 .58127 m .49678 .58306 L .49659 .58061 L F
.4947 .58127 m .49447 .58378 L .49678 .58306 L F
.437 .377 .692 r
.55676 .56588 m .55876 .56578 L .55837 .56348 L F
.183 .711 .712 r
.50576 .53467 m .5044 .53494 L .50193 .53553 L F
.343 0 0 r
.50576 .53467 m .50814 .53541 L .5044 .53494 L F
.561 .61 .859 r
.254 .56346 m .25423 .55959 L .25272 .55989 L F
.254 .56346 m .25616 .56291 L .25423 .55959 L F
.504 .413 .686 r
.25428 .56598 m .25616 .56291 L .254 .56346 L F
.443 .398 .713 r
.28052 .56263 m .27923 .56825 L .27886 .5628 L F
.28052 .56263 m .28089 .56773 L .27923 .56825 L F
.302 .228 .604 r
.28089 .56773 m .28007 .56896 L .27923 .56825 L F
.188 .7 .894 r
.31523 .7631 m .31138 .76275 L .31302 .7632 L F
.31302 .7632 m .31138 .76275 L .31523 .7631 L F
.846 .831 .832 r
.20457 .69272 m .20208 .69398 L .20206 .69381 L F
0 0 .409 r
.20742 .69447 m .20457 .69272 L .2055 .69225 L F
.896 .954 .609 r
.62094 .4368 m .62068 .43659 L .62158 .43465 L F
.51 .301 .533 r
.55162 .57733 m .54976 .57493 L .55019 .57813 L F
.55162 .57733 m .55183 .57564 L .54976 .57493 L F
.549 .366 .586 r
.55033 .58811 m .55253 .58748 L .55206 .58851 L F
.55116 .58908 m .55206 .58851 L .55158 .58957 L F
.55033 .58811 m .55206 .58851 L .55116 .58908 L F
.285 .377 .782 r
.5523 .58732 m .55187 .58867 L .55253 .58748 L F
.55187 .58867 m .55158 .58957 L .55206 .58851 L F
.55187 .58867 m .55206 .58851 L .55253 .58748 L F
.508 .36 .614 r
.55033 .58811 m .55158 .58957 L .55193 .58846 L F
.285 0 0 r
.54609 .59185 m .54934 .59018 L .54723 .59359 L F
.508 .36 .614 r
.55033 .58811 m .55193 .58846 L .5481 .58689 L F
.55193 .58846 m .55214 .58851 L .55178 .58836 L F
.55193 .58846 m .55178 .58836 L .55069 .58793 L F
.55193 .58846 m .55069 .58793 L .55062 .58792 L F
.541 .398 .636 r
.55185 .58868 m .55158 .58957 L .54934 .59018 L F
0 0 0 r
.55108 .58914 m .55143 .58902 L .55185 .58868 L F
.581 .635 .87 r
.5481 .58689 m .55178 .58836 L .55069 .58625 L F
.285 .377 .782 r
.55069 .58625 m .55143 .58902 L .55177 .58834 L F
.55069 .58625 m .55177 .58834 L .55227 .5873 L F
.55143 .58902 m .55185 .58868 L .55227 .5873 L F
.581 .635 .87 r
.55178 .58836 m .55214 .58851 L .55069 .58625 L F
.285 .377 .782 r
.55192 .58845 m .55193 .58846 L .5523 .58732 L F
.53 0 0 r
.55203 .58822 m .55069 .58625 L .55214 .58851 L F
.285 .377 .782 r
.55227 .5873 m .55192 .58845 L .5523 .58732 L F
.55069 .58625 m .55162 .58696 L .55115 .58795 L F
.55162 .58696 m .55304 .58806 L .55196 .588 L F
.55162 .58696 m .55196 .588 L .55115 .58795 L F
.55143 .58902 m .55158 .58957 L .55185 .58868 L F
.55192 .58845 m .55158 .58957 L .55193 .58846 L F
.508 .36 .614 r
.55193 .58846 m .55158 .58957 L .55214 .58851 L F
.541 .398 .636 r
.55214 .58851 m .55158 .58957 L .55185 .58868 L F
.285 .377 .782 r
.55143 .58902 m .55187 .58888 L .55158 .58957 L F
.69 .385 0 r
.55232 .5891 m .55214 .58851 L .55185 .58887 L F
.285 .377 .782 r
.55187 .58888 m .55242 .5887 L .55212 .589 L F
.55187 .58888 m .55212 .589 L .55158 .58957 L F
0 0 .288 r
.55191 .59071 m .55282 .59072 L .55232 .59215 L F
.55158 .58957 m .55282 .59072 L .55191 .59071 L F
.365 0 .148 r
.55537 .58969 m .55368 .5905 L .55282 .59072 L F
.285 .377 .782 r
.55232 .58864 m .55304 .58806 L .55242 .5887 L F
.55188 .58799 m .55304 .58806 L .55232 .58864 L F
.55069 .58625 m .5531 .58799 L .55304 .58806 L F
.69 .385 0 r
.55282 .59072 m .55232 .5891 L .5522 .5892 L F
0 0 .288 r
.55158 .58957 m .55212 .589 L .55282 .59072 L F
.69 .385 0 r
.55282 .59072 m .5522 .5892 L .55005 .59106 L F
0 0 .288 r
.55212 .589 m .55225 .58887 L .55282 .59072 L F
.69 .385 0 r
.55282 .59072 m .55225 .58887 L .55232 .5891 L F
0 0 .288 r
.55225 .58887 m .5531 .58799 L .55282 .59072 L F
.69 .385 0 r
.55282 .59072 m .55203 .58822 L .55225 .58887 L F
.53 0 0 r
.55173 .58741 m .5531 .58799 L .55069 .58625 L F
.504 .505 .791 r
.55415 .58431 m .5531 .58799 L .55173 .58741 L F
.55415 .58431 m .55536 .58779 L .5531 .58799 L F
.465 .242 .489 r
.5531 .58799 m .55536 .58779 L .55282 .59072 L F
.369 .121 .401 r
.55536 .58779 m .55537 .58969 L .55282 .59072 L F
.219 .352 .785 r
.55173 .58741 m .55034 .58426 L .55415 .58431 L F
0 0 .176 r
.55377 .594 m .5528 .59367 L .55416 .59449 L F
.55232 .59215 m .5528 .59367 L .55377 .594 L F
.374 0 0 r
.55165 .59325 m .55195 .59338 L .5528 .59367 L F
0 .348 .701 r
.55488 .59466 m .55416 .59449 L .5528 .59367 L F
.374 0 0 r
.55195 .59338 m .55488 .59466 L .5528 .59367 L F
0 0 .176 r
.55232 .59215 m .55282 .59072 L .5528 .59367 L F
.773 .551 .598 r
.5528 .59367 m .55282 .59072 L .55005 .59106 L F
.365 0 .148 r
.55537 .58969 m .55515 .59125 L .55141 .59158 L F
.55515 .59125 m .55503 .59208 L .55345 .592 L F
.55503 .59208 m .55472 .59226 L .55345 .592 L F
.55515 .59125 m .55345 .592 L .55141 .59158 L F
.368 .008 .216 r
.55141 .59158 m .55472 .59226 L .55456 .5906 L F
.792 .678 .739 r
.55435 .59253 m .55678 .59123 L .55361 .59305 L F
.368 .008 .216 r
.55472 .59226 m .55494 .5921 L .55456 .5906 L F
.365 0 .148 r
.55368 .5905 m .5532 .59073 L .55285 .59072 L F
.55368 .5905 m .55285 .59072 L .55282 .59072 L F
.5532 .59073 m .55141 .59158 L .55282 .59072 L F
.69 .385 0 r
.55232 .5891 m .55185 .58887 L .55005 .59106 L F
.55232 .5891 m .55203 .58822 L .55214 .58851 L F
.285 .377 .782 r
.55115 .58795 m .55242 .5887 L .55143 .58902 L F
0 0 0 r
.55185 .58868 m .54805 .59181 L .55214 .58851 L F
.54805 .59181 m .55005 .59106 L .55214 .58851 L F
.69 .385 0 r
.55282 .59072 m .55173 .58741 L .55203 .58822 L F
.53 0 0 r
.55173 .58741 m .55069 .58625 L .55203 .58822 L F
.285 .377 .782 r
.55115 .58795 m .55188 .58799 L .55232 .58864 L F
0 0 0 r
.54819 .59168 m .54805 .59181 L .55185 .58868 L F
.946 .755 .612 r
.55141 .59158 m .55173 .58741 L .55282 .59072 L F
.19 .31 .757 r
.55456 .5906 m .55173 .58741 L .55141 .59158 L F
.792 .305 .056 r
.55456 .5906 m .55494 .5921 L .55278 .59086 L F
.792 .678 .739 r
.55496 .59211 m .55504 .59216 L .55357 .59294 L F
.55503 .59208 m .55504 .59216 L .55496 .59211 L F
.365 0 .148 r
.55503 .59208 m .55499 .59232 L .55472 .59226 L F
.368 .008 .216 r
.55472 .59226 m .55499 .59232 L .55494 .5921 L F
.426 .018 .159 r
.55678 .59123 m .55503 .59208 L .55537 .58969 L F
.792 .678 .739 r
.55278 .59086 m .5565 .5912 L .55357 .59294 L F
.792 .305 .056 r
.55494 .5921 m .55499 .59232 L .55278 .59086 L F
.792 .678 .739 r
.55503 .59208 m .55678 .59123 L .55504 .59216 L F
.5565 .5912 m .55678 .59123 L .55503 .59208 L F
.426 .018 .159 r
.55678 .59123 m .55499 .59232 L .55503 .59208 L F
.374 0 0 r
.55165 .59325 m .55416 .59449 L .55488 .59466 L F
.792 .678 .739 r
.55361 .59305 m .55678 .59123 L .55416 .59449 L F
.55357 .59294 m .55435 .59253 L .55361 .59305 L F
.773 .551 .598 r
.5528 .59367 m .55005 .59106 L .54947 .59242 L F
.305 .395 .791 r
.55278 .59086 m .55192 .59268 L .55062 .59206 L F
.55192 .59268 m .55165 .59325 L .55137 .59292 L F
.773 .551 .598 r
.5528 .59367 m .54947 .59242 L .55165 .59325 L F
.685 .341 .387 r
.54947 .59242 m .55165 .59325 L .55141 .59158 L F
.305 .395 .791 r
.55192 .59268 m .55137 .59292 L .55062 .59206 L F
.19 .31 .757 r
.55431 .59032 m .55294 .58574 L .55173 .58741 L F
.55456 .5906 m .55446 .59028 L .55431 .59032 L F
.55446 .59028 m .55294 .58574 L .55431 .59032 L F
0 0 0 r
.55068 .58938 m .54819 .59168 L .55143 .58902 L F
.55068 .58938 m .55143 .58902 L .55108 .58914 L F
.508 .36 .614 r
.55062 .58792 m .55069 .58793 L .5481 .58689 L F
0 0 0 r
.54934 .59018 m .54927 .59027 L .55068 .58938 L F
.54927 .59027 m .54805 .59181 L .55068 .58938 L F
.452 .223 .475 r
.38697 .60478 m .38948 .60192 L .38695 .60224 L F
.45 .28 .558 r
.2776 .58716 m .27755 .5897 L .27552 .59029 L F
.342 .117 .42 r
.27755 .5897 m .27521 .59275 L .27552 .59029 L F
.996 .777 .486 r
.45468 .65605 m .45446 .65896 L .45334 .65776 L F
.466 .285 .551 r
.45468 .65605 m .45715 .65829 L .45446 .65896 L F
.668 .229 .198 r
.45334 .65776 m .45715 .65829 L .45468 .65605 L F
.177 .33 .78 r
.21005 .67736 m .21168 .68059 L .21256 .67921 L F
0 0 .229 r
.21168 .68059 m .21228 .68193 L .21256 .67921 L F
.21168 .68059 m .21088 .68286 L .21228 .68193 L F
.329 .255 .62 r
.25154 .5815 m .25312 .58115 L .25306 .57747 L F
.353 .355 .723 r
.25154 .5815 m .25393 .58347 L .25312 .58115 L F
.49 .356 .626 r
.25185 .58406 m .25393 .58347 L .25154 .5815 L F
.52 .553 .83 r
.74758 .41488 m .74868 .41722 L .74976 .41571 L F
0 0 .189 r
.74976 .41571 m .74868 .41722 L .74829 .4194 L F
.504 .413 .686 r
.25428 .56598 m .25648 .56546 L .25616 .56291 L F
.522 .478 .748 r
.25428 .56598 m .25746 .56882 L .25648 .56546 L F
.127 0 0 r
.71108 .39055 m .70817 .3925 L .71089 .39216 L F
.347 0 .089 r
.71108 .39055 m .71365 .39 L .71404 .38949 L F
.465 .15 .347 r
.71358 .39165 m .71108 .39055 L .71089 .39216 L F
.71358 .39165 m .71365 .39 L .71108 .39055 L F
.914 .865 .777 r
.77349 .39363 m .77429 .39536 L .77213 .399 L F
.809 .821 .86 r
.77529 .3918 m .77429 .39536 L .77349 .39363 L F
.77529 .3918 m .77688 .39286 L .77429 .39536 L F
.764 .832 .369 r
.53964 .51844 m .53938 .51859 L .53872 .52017 L F
.511 .311 .546 r
.27069 .60421 m .26866 .60219 L .27082 .60148 L F
.27069 .60421 m .26864 .6049 L .26866 .60219 L F
.927 .972 .707 r
.60381 .49979 m .6062 .49703 L .60538 .49633 L F
.479 .05 .146 r
.55406 .57426 m .55775 .5723 L .55419 .57638 L F
.608 .608 .826 r
.21814 .67416 m .21606 .67493 L .21659 .67242 L F
.554 .907 .969 r
.20714 .63466 m .20331 .63522 L .20556 .63476 L F
.039 .606 .769 r
.20778 .63415 m .20769 .63427 L .20595 .63409 L F
.38 .812 .647 r
.20908 .63353 m .2076 .63439 L .20769 .63427 L F
.446 .853 .676 r
.21184 .63181 m .20908 .63353 L .20769 .63427 L F
.21184 .63181 m .20769 .63427 L .21031 .6339 L F
.039 .606 .769 r
.20883 .63419 m .20769 .63427 L .20778 .63415 L F
.38 .812 .647 r
.2076 .63439 m .20714 .63466 L .20769 .63427 L F
.269 .775 .817 r
.20769 .63427 m .20714 .63466 L .20556 .63476 L F
.308 .755 .961 r
.5468 .58091 m .54945 .58076 L .5505 .58136 L F
.168 0 .306 r
.55019 .57813 m .54945 .58076 L .5505 .58136 L F
.899 .799 .741 r
.61283 .47012 m .61372 .47332 L .61438 .47143 L F
.041 .283 .776 r
.17634 .65307 m .17704 .65283 L .173 .65135 L F
.17634 .65307 m .17661 .65303 L .17704 .65283 L F
.256 0 0 r
.42395 .58258 m .42282 .58143 L .42501 .5805 L F
.42395 .58258 m .42156 .58317 L .42282 .58143 L F
.488 .132 .288 r
.62197 .41543 m .62522 .41318 L .6229 .41401 L F
.523 .326 .554 r
.57446 .5361 m .57701 .53312 L .57431 .53355 L F
.831 .947 .897 r
.75285 .40819 m .74907 .41005 L .7514 .40707 L F
.763 .647 .734 r
.75137 .40468 m .75285 .40819 L .7514 .40707 L F
.879 .756 .723 r
.62063 .45166 m .61873 .45499 L .6216 .45471 L F
.876 .789 .761 r
.61873 .45499 m .61957 .45823 L .6216 .45471 L F
.293 .038 .345 r
.54736 .49488 m .5469 .49695 L .54937 .49395 L F
0 0 .283 r
.25311 .57507 m .25454 .5717 L .25275 .57243 L F
.91 .803 .729 r
.61283 .47012 m .61241 .47303 L .61372 .47332 L F
.866 .739 .72 r
.61024 .47557 m .61372 .47332 L .61241 .47303 L F
.61024 .47557 m .61181 .47656 L .61372 .47332 L F
.093 0 0 r
.17572 .56105 m .17548 .56019 L .17779 .55981 L F
.17572 .56105 m .17342 .56165 L .17548 .56019 L F
.444 .857 .697 r
.476 .60858 m .47617 .60815 L .47809 .60764 L F
.476 .60858 m .47362 .60971 L .47617 .60815 L F
.472 .219 .448 r
.25867 .62182 m .25686 .62015 L .25894 .61929 L F
.25867 .62182 m .25658 .62238 L .25686 .62015 L F
.285 0 0 r
.54609 .59185 m .54805 .59181 L .54934 .59018 L F
.277 .482 .878 r
.41126 .63222 m .41421 .63395 L .41331 .63508 L F
.478 .448 .747 r
.38652 .61721 m .38721 .62128 L .38948 .61891 L F
.289 .357 .76 r
.38721 .62128 m .3896 .62146 L .38948 .61891 L F
.38721 .62128 m .38822 .62307 L .3896 .62146 L F
.513 .331 .571 r
.65697 .39905 m .65712 .40168 L .65947 .40097 L F
.711 .18 0 r
.47429 .6012 m .4772 .60267 L .47629 .60296 L F
.076 .637 .745 r
.4772 .60267 m .47736 .60259 L .47629 .60296 L F
.4772 .60267 m .47923 .60254 L .47736 .60259 L F
.564 .446 .677 r
.4772 .60267 m .48001 .60499 L .47923 .60254 L F
.4772 .60267 m .47772 .60605 L .48001 .60499 L F
.837 .904 .885 r
.6914 .43142 m .68918 .43356 L .68781 .43241 L F
.853 .862 .847 r
.77213 .399 m .7696 .40194 L .76835 .4006 L F
.207 .449 .872 r
.50347 .57233 m .50635 .57487 L .50471 .57309 L F
.499 .318 .566 r
.26161 .61414 m .26152 .61655 L .25942 .61705 L F
.451 .192 .429 r
.26152 .61655 m .25894 .61929 L .25942 .61705 L F
.6 .518 .734 r
.56732 .57524 m .56521 .57813 L .56478 .57571 L F
.616 .54 .746 r
.56732 .57524 m .56781 .57816 L .56521 .57813 L F
.376 .394 .752 r
.5683 .58038 m .56521 .57813 L .56781 .57816 L F
.34 0 0 r
.18163 .55995 m .18024 .56019 L .17779 .55981 L F
.339 .819 .807 r
.18231 .55947 m .18163 .55995 L .18383 .55969 L F
.18231 .55947 m .18024 .56019 L .18163 .55995 L F
.108 0 .051 r
.5449 .49799 m .54401 .49947 L .5469 .49695 L F
.435 .699 .976 r
.19544 .634 m .19485 .63557 L .19327 .63441 L F
.19544 .634 m .19706 .63547 L .19485 .63557 L F
.386 .134 .404 r
.43751 .63761 m .43489 .64054 L .43537 .63826 L F
.349 .475 .846 r
.51123 .57992 m .50977 .58163 L .50973 .58018 L F
0 0 .555 r
.51097 .5825 m .50977 .58163 L .51123 .57992 L F
.51097 .5825 m .51137 .58398 L .50977 .58163 L F
.584 .434 .644 r
.56494 .55083 m .56725 .54765 L .56534 .54854 L F
.963 .658 .247 r
.5503 .56637 m .54932 .56528 L .549 .56288 L F
.926 .741 .632 r
.5503 .56637 m .549 .56288 L .54932 .56528 L F
.548 .348 .562 r
.56518 .49165 m .56504 .49413 L .56307 .49372 L F
.153 0 .161 r
.56399 .49536 m .56307 .49372 L .56504 .49413 L F
.56399 .49536 m .56193 .49663 L .56307 .49372 L F
.215 .591 .946 r
.22431 .65137 m .2235 .6515 L .22183 .64992 L F
.675 .317 .359 r
.54137 .60804 m .53964 .61021 L .53738 .60802 L F
.897 .635 .533 r
.54137 .60804 m .54112 .61056 L .53964 .61021 L F
.999 .811 .512 r
.76927 .42603 m .76789 .42722 L .76851 .42486 L F
.76927 .42603 m .76888 .42839 L .76789 .42722 L F
0 0 0 r
.54942 .50629 m .54863 .50826 L .54661 .50901 L F
.54863 .50826 m .54539 .51019 L .54661 .50901 L F
.608 .372 .534 r
.56982 .48873 m .5699 .49137 L .56765 .49137 L F
.649 .404 .535 r
.57379 .49036 m .56982 .48873 L .57377 .48841 L F
.57379 .49036 m .5699 .49137 L .56982 .48873 L F
.354 0 .14 r
.74483 .39922 m .74553 .39707 L .74511 .39806 L F
0 0 .278 r
.7456 .4002 m .74483 .39922 L .74511 .39806 L F
.7456 .4002 m .74456 .40163 L .74483 .39922 L F
.16 .297 .755 r
.28161 .57706 m .28279 .57736 L .28159 .57835 L F
.52 .527 .803 r
.28279 .57736 m .28194 .58076 L .28159 .57835 L F
.447 .255 .526 r
.62522 .41318 m .6276 .40999 L .62531 .41097 L F
.745 .646 .75 r
.50182 .60137 m .50302 .60469 L .49967 .6035 L F
.772 .37 .291 r
.50302 .60469 m .50211 .6055 L .49967 .6035 L F
.737 .235 0 r
.50302 .60469 m .50414 .60676 L .50211 .6055 L F
.50302 .60469 m .50552 .60774 L .50414 .60676 L F
.694 .449 .548 r
.50572 .60516 m .50552 .60774 L .50302 .60469 L F
.72 .684 .815 r
.56923 .5819 m .56616 .58619 L .56643 .58484 L F
.305 0 .143 r
.40792 .58652 m .4101 .58664 L .41114 .58451 L F
.039 0 .092 r
.41375 .58152 m .41114 .58451 L .41281 .58324 L F
.259 0 .121 r
.41114 .58451 m .41225 .58596 L .41281 .58324 L F
.41114 .58451 m .4101 .58664 L .41225 .58596 L F
.965 .866 .689 r
.53159 .52897 m .53435 .52694 L .53334 .52584 L F
.53159 .52897 m .53285 .53018 L .53435 .52694 L F
0 0 0 r
.59938 .51328 m .5981 .51537 L .59998 .51196 L F
.59763 .51725 m .5981 .51537 L .59938 .51328 L F
.097 0 0 r
.58062 .4667 m .58366 .46431 L .58134 .46524 L F
.641 .337 .44 r
.49427 .58649 m .49177 .58696 L .49196 .58451 L F
.49196 .58451 m .49177 .58696 L .49427 .58649 L F
.291 .392 .794 r
.78146 .39186 m .78125 .3952 L .77987 .39205 L F
.78146 .39186 m .78281 .39539 L .78125 .3952 L F
.445 .22 .477 r
.25192 .62603 m .2516 .62853 L .24947 .62907 L F
.383 .145 .425 r
.25441 .62303 m .25393 .62546 L .25192 .62603 L F
.404 .187 .468 r
.25393 .62546 m .2516 .62853 L .25192 .62603 L F
.638 .741 .923 r
.18258 .65326 m .18612 .65444 L .18491 .65277 L F
.433 .605 .919 r
.18612 .65444 m .18685 .65228 L .18491 .65277 L F
.18612 .65444 m .19091 .65711 L .18685 .65228 L F
.426 .191 .452 r
.25658 .62238 m .25393 .62546 L .25441 .62303 L F
.003 0 .04 r
.24028 .59914 m .24161 .59848 L .24259 .59673 L F
.277 .121 .481 r
.24028 .59914 m .24157 .60107 L .24161 .59848 L F
.24028 .59914 m .24005 .60179 L .24157 .60107 L F
.328 0 .171 r
.54991 .61084 m .5531 .60793 L .55208 .6099 L F
0 0 0 r
.55541 .60737 m .55208 .6099 L .5531 .60793 L F
.958 .626 .241 r
.49952 .53449 m .49854 .53499 L .49808 .53201 L F
.501 0 0 r
.50193 .53553 m .49854 .53499 L .49952 .53449 L F
.213 0 .263 r
.41855 .57551 m .41774 .57752 L .42038 .57453 L F
.53 .398 .645 r
.57104 .56306 m .57112 .56568 L .56896 .5661 L F
.489 .388 .668 r
.57159 .5687 m .56896 .5661 L .57112 .56568 L F
.57159 .5687 m .56931 .56926 L .56896 .5661 L F
.763 .785 .871 r
.71655 .42927 m .72014 .42939 L .71864 .428 L F
.254 .535 .92 r
.76369 .39316 m .76134 .39127 L .76366 .39179 L F
0 0 .475 r
.76366 .39179 m .7646 .39543 L .76369 .39316 L F
0 0 0 r
.41626 .57871 m .41375 .58152 L .4153 .58012 L F
.226 0 .209 r
.41375 .58152 m .41485 .58124 L .4153 .58012 L F
.41375 .58152 m .41281 .58324 L .41485 .58124 L F
.072 0 0 r
.41626 .57871 m .41719 .57913 L .41774 .57752 L F
.41626 .57871 m .4153 .58012 L .41719 .57913 L F
0 .126 .675 r
.52561 .57802 m .52758 .58015 L .52581 .57668 L F
.123 .145 .61 r
.5713 .58306 m .57146 .58645 L .57039 .58722 L F
.062 .004 .471 r
.57146 .58645 m .57056 .58971 L .57039 .58722 L F
.857 .84 .828 r
.68712 .4406 m .69024 .4403 L .68889 .43908 L F
.837 .875 .87 r
.68712 .4406 m .68821 .44196 L .69024 .4403 L F
.794 .84 .886 r
.68889 .43908 m .69024 .4403 L .69313 .43755 L F
.311 .446 .835 r
.51484 .56013 m .51644 .55868 L .51383 .5567 L F
.51484 .56013 m .51625 .5604 L .51644 .55868 L F
.397 .521 .866 r
.75379 .38885 m .7547 .39142 L .75748 .39199 L F
.422 .14 .378 r
.4749 .64734 m .47422 .64943 L .47192 .65004 L F
.47192 .65004 m .47422 .64943 L .4749 .64734 L F
.172 0 .262 r
.4749 .64734 m .47422 .64943 L .47659 .64638 L F
.4749 .64734 m .47422 .64943 L .47659 .64638 L F
.984 .823 .603 r
.66406 .41974 m .66477 .41999 L .66354 .41872 L F
.896 .859 .797 r
.75832 .43042 m .7599 .43143 L .75965 .42813 L F
.862 .868 .842 r
.75665 .43244 m .7599 .43143 L .75832 .43042 L F
.75665 .43244 m .7576 .43389 L .7599 .43143 L F
.885 .852 .806 r
.75965 .42813 m .7599 .43143 L .76097 .42945 L F
.881 .751 .244 r
.76301 .41088 m .76299 .4068 L .76261 .40856 L F
.977 .726 .313 r
.76227 .41247 m .76301 .41088 L .76261 .40856 L F
.76227 .41247 m .76313 .41371 L .76301 .41088 L F
.216 0 .333 r
.40055 .59348 m .40188 .59469 L .40277 .59289 L F
.40055 .59348 m .40017 .5956 L .40188 .59469 L F
.909 .89 .799 r
.78223 .42125 m .78346 .42246 L .78107 .4258 L F
.633 .08 0 r
.78392 .42382 m .78346 .42246 L .78223 .42125 L F
.78392 .42382 m .78624 .42448 L .78346 .42246 L F
0 0 0 r
.53953 .50346 m .54111 .50254 L .54232 .50084 L F
.273 0 .179 r
.54111 .50254 m .54401 .49947 L .54232 .50084 L F
.843 .865 .859 r
.77524 .43088 m .77658 .4324 L .77757 .42985 L F
.852 .616 .581 r
.68442 .40738 m .68435 .41018 L .68274 .40781 L F
.787 .517 .528 r
.68442 .40738 m .68639 .41091 L .68435 .41018 L F
.777 .721 .8 r
.20207 .71262 m .20027 .71524 L .19958 .71354 L F
.869 .906 .855 r
.19795 .71485 m .20027 .71524 L .201 .7129 L F
.891 .931 .838 r
.201 .7129 m .20027 .71524 L .20207 .71262 L F
.514 .286 .507 r
.61545 .42036 m .61698 .42191 L .61692 .41941 L F
.61545 .42036 m .61505 .42267 L .61698 .42191 L F
.704 .722 .863 r
.70152 .43416 m .70521 .43484 L .70456 .43195 L F
.766 .761 .848 r
.70456 .43195 m .70521 .43484 L .70797 .43225 L F
.465 .258 .514 r
.46572 .64997 m .46561 .65259 L .46332 .653 L F
.46332 .653 m .46561 .65259 L .46572 .64997 L F
.615 .887 .99 r
.19721 .70124 m .19996 .70075 L .19754 .69996 L F
.19721 .70124 m .19996 .70075 L .19754 .69996 L F
.942 .961 .726 r
.601 .5051 m .60286 .5041 L .60298 .50161 L F
.601 .5051 m .60165 .50604 L .60286 .5041 L F
.189 .687 .915 r
.21669 .53914 m .21885 .53918 L .22063 .53974 L F
.273 .758 .92 r
.21885 .53918 m .2228 .53929 L .22063 .53974 L F
.255 .723 .945 r
.47901 .55958 m .48277 .56013 L .48043 .56026 L F
.256 .187 .584 r
.38563 .61111 m .38712 .60716 L .385 .60886 L F
.336 .277 .642 r
.19175 .71005 m .19358 .70989 L .19226 .70971 L F
.937 .734 .602 r
.61111 .48135 m .6126 .48251 L .61153 .47926 L F
.869 .781 .762 r
.60913 .48466 m .6126 .48251 L .61111 .48135 L F
.60913 .48466 m .61069 .48585 L .6126 .48251 L F
.738 .647 .758 r
.61153 .47926 m .6126 .48251 L .61523 .47953 L F
.597 .39 .572 r
.55746 .55729 m .56 .55687 L .56005 .55435 L F
.521 .353 .595 r
.56005 .55435 m .56246 .55373 L .56234 .55122 L F
.612 .456 .646 r
.56 .55687 m .56246 .55373 L .56005 .55435 L F
.465 .56 .868 r
.75047 .38769 m .7515 .38883 L .75379 .38885 L F
.57 .426 .646 r
.73902 .39029 m .73915 .38701 L .73763 .38629 L F
.73902 .39029 m .74144 .38922 L .73915 .38701 L F
.711 .868 .956 r
.75425 .43394 m .7576 .43389 L .75665 .43244 L F
.017 .217 .725 r
.52376 .57223 m .52444 .57072 L .52232 .56854 L F
0 0 .544 r
.52376 .57223 m .52503 .57431 L .52444 .57072 L F
.874 .915 .852 r
.7419 .43184 m .74288 .42799 L .7408 .42977 L F
.7419 .43184 m .74426 .42924 L .74288 .42799 L F
.761 .908 .94 r
.20549 .65354 m .20501 .65099 L .20349 .65243 L F
.20549 .65354 m .20738 .6523 L .20501 .65099 L F
.753 .894 .941 r
.68437 .44275 m .68821 .44196 L .68712 .4406 L F
.459 .839 .987 r
.19893 .65408 m .19949 .65302 L .19608 .65344 L F
.19893 .65408 m .20135 .65357 L .19949 .65302 L F
.538 .232 .397 r
.47871 .59454 m .47806 .59278 L .47831 .59573 L F
.47871 .59454 m .48079 .59267 L .47806 .59278 L F
.338 .029 .285 r
.55698 .48536 m .55946 .48475 L .55978 .4825 L F
.262 0 .265 r
.55978 .4825 m .56154 .48378 L .56198 .48123 L F
.55978 .4825 m .55946 .48475 L .56154 .48378 L F
.478 .291 .548 r
.56758 .49306 m .56518 .49165 L .56765 .49137 L F
.56758 .49306 m .56504 .49413 L .56518 .49165 L F
.453 .231 .486 r
.24947 .62907 m .24914 .63152 L .247 .63206 L F
.354 .112 .402 r
.2516 .62853 m .24914 .63152 L .24947 .62907 L F
.734 .862 .941 r
.74829 .4194 m .74538 .42151 L .74439 .4196 L F
.547 .522 .779 r
.42395 .58258 m .42318 .58442 L .42156 .58317 L F
0 .285 .734 r
.74288 .42799 m .74426 .42924 L .74686 .43072 L F
.813 .508 .474 r
.74426 .42924 m .74753 .43202 L .74686 .43072 L F
.36 .094 .368 r
.24846 .63401 m .247 .63206 L .24914 .63152 L F
.24846 .63401 m .24635 .63473 L .247 .63206 L F
0 0 .037 r
.53886 .50543 m .54111 .50254 L .53953 .50346 L F
.08 0 .043 r
.53673 .50601 m .53886 .50543 L .53953 .50346 L F
.504 .219 .414 r
.69622 .40762 m .69868 .409 L .6964 .40919 L F
.69622 .40762 m .69876 .40726 L .69868 .409 L F
.15 0 0 r
.20569 .68662 m .20257 .68898 L .20449 .68846 L F
.631 .128 0 r
.2055 .68696 m .20569 .68662 L .20449 .68846 L F
.2055 .68696 m .20706 .68847 L .20569 .68662 L F
.438 .061 .224 r
.20569 .68662 m .20706 .68847 L .2086 .68662 L F
.255 .039 .381 r
.58129 .55398 m .58357 .5508 L .58298 .55271 L F
0 0 .204 r
.58133 .5561 m .58129 .55398 L .58298 .55271 L F
.457 .63 .928 r
.17231 .62707 m .17162 .62902 L .17003 .62679 L F
.446 .617 .923 r
.17231 .62707 m .17363 .62889 L .17162 .62902 L F
.427 .17 .42 r
.71018 .40152 m .71271 .40319 L .70988 .4036 L F
.71018 .40152 m .71295 .40117 L .71271 .40319 L F
.924 .698 .578 r
.43492 .65552 m .43472 .65871 L .43671 .65908 L F
.922 .678 .551 r
.43472 .65871 m .43524 .66092 L .43671 .65908 L F
.658 .671 .852 r
.72101 .42055 m .7173 .41956 L .71974 .41868 L F
.712 .676 .814 r
.72343 .41939 m .72101 .42055 L .71974 .41868 L F
.217 .628 .953 r
.23315 .55377 m .23345 .55282 L .23135 .55268 L F
.23315 .55377 m .23505 .554 L .23345 .55282 L F
.083 .49 .897 r
.27258 .54683 m .27255 .54795 L .27065 .54645 L F
.27258 .54683 m .27414 .54836 L .27255 .54795 L F
.594 .912 .978 r
.59914 .44662 m .60074 .44539 L .60127 .44376 L F
.172 .102 .53 r
.60127 .44376 m .60268 .43983 L .6 .44019 L F
.60127 .44376 m .60301 .44239 L .60268 .43983 L F
.441 .241 .511 r
.60074 .44539 m .60301 .44239 L .60127 .44376 L F
.518 .304 .529 r
.78757 .4408 m .78754 .44318 L .78494 .44383 L F
.509 .539 .823 r
.7892 .43972 m .78757 .4408 L .78697 .44016 L F
.183 .016 .406 r
.7892 .43972 m .78754 .44318 L .78757 .4408 L F
.743 .986 .9 r
.78937 .43738 m .78697 .44016 L .78745 .43756 L F
.509 .539 .823 r
.7892 .43972 m .78697 .44016 L .78937 .43738 L F
.578 .349 .533 r
.46962 .58637 m .46706 .58423 L .46939 .58386 L F
.46962 .58637 m .46711 .58723 L .46706 .58423 L F
.479 .05 .146 r
.55406 .57426 m .55671 .5742 L .55775 .5723 L F
.244 0 .033 r
.55775 .5723 m .5592 .57343 L .55938 .57118 L F
.55775 .5723 m .55671 .5742 L .5592 .57343 L F
.977 .92 .625 r
.76936 .4192 m .76881 .41814 L .7703 .41708 L F
.989 .893 .604 r
.7703 .41708 m .76881 .41814 L .76958 .41587 L F
.534 .315 .528 r
.46572 .64997 m .46561 .65259 L .46803 .65203 L F
.46572 .64997 m .46561 .65259 L .46803 .65203 L F
.051 .619 .735 r
.18984 .54213 m .18841 .54214 L .18956 .54211 L F
.25 .762 .784 r
.19071 .54218 m .18984 .54213 L .19275 .54157 L F
.083 0 0 r
.18984 .54213 m .19195 .54204 L .19458 .54142 L F
.051 .619 .735 r
.18984 .54213 m .18956 .54211 L .19195 .54204 L F
.25 .762 .784 r
.19001 .54239 m .18984 .54213 L .19071 .54218 L F
.19001 .54239 m .18731 .54275 L .18984 .54213 L F
.256 .187 .584 r
.38563 .61111 m .38706 .61067 L .38712 .60716 L F
.277 .251 .649 r
.38563 .61111 m .38764 .61314 L .38706 .61067 L F
.327 .258 .625 r
.38609 .61369 m .38764 .61314 L .38563 .61111 L F
0 0 .004 r
.18983 .72759 m .19144 .72675 L .19249 .72469 L F
.894 .596 .475 r
.19144 .72675 m .19261 .72766 L .19249 .72469 L F
.801 .517 .508 r
.19249 .72469 m .19261 .72766 L .19597 .72748 L F
.734 .58 .683 r
.42237 .62354 m .42217 .6223 L .42248 .62286 L F
.42237 .62354 m .41956 .62584 L .42217 .6223 L F
.232 0 .121 r
.5338 .50902 m .53605 .50813 L .53673 .50601 L F
.066 0 .002 r
.5379 .50687 m .53673 .50601 L .53605 .50813 L F
.5379 .50687 m .53886 .50543 L .53673 .50601 L F
.335 0 .081 r
.71365 .39 m .71641 .38895 L .71404 .38949 L F
.493 .282 .522 r
.60996 .42584 m .61222 .42747 L .61203 .42482 L F
.60996 .42584 m .60982 .42806 L .61222 .42747 L F
.476 .803 1 r
.7402 .39542 m .7366 .39487 L .73915 .39456 L F
.209 .735 .805 r
.74207 .3949 m .7402 .39542 L .73915 .39456 L F
.74207 .3949 m .7428 .39497 L .7402 .39542 L F
0 .205 .732 r
.51811 .56345 m .51849 .56241 L .51625 .5604 L F
0 .231 .749 r
.51811 .56345 m .51999 .56387 L .51849 .56241 L F
.51811 .56345 m .52043 .56547 L .51999 .56387 L F
.983 .853 .634 r
.76075 .42147 m .76287 .41891 L .76185 .41767 L F
.76075 .42147 m .76181 .42267 L .76287 .41891 L F
0 0 0 r
.59938 .51328 m .59998 .51196 L .59957 .51165 L F
.307 .385 .779 r
.38822 .62307 m .38995 .62325 L .3896 .62146 L F
.77 .841 .384 r
.58315 .52296 m .58402 .52146 L .58311 .52348 L F
.695 .78 .299 r
.58539 .518 m .58402 .52146 L .58466 .51963 L F
.726 .83 .377 r
.58466 .51963 m .58402 .52146 L .58315 .52296 L F
0 0 .399 r
.53299 .59901 m .53258 .59761 L .53142 .59548 L F
.848 .538 .006 r
.53299 .59901 m .53282 .60037 L .53258 .59761 L F
.53299 .59901 m .53356 .60164 L .53282 .60037 L F
.856 .417 .167 r
.66249 .408 m .66445 .41038 L .66604 .41071 L F
.437 .159 .391 r
.58818 .48238 m .5848 .48515 L .58466 .48236 L F
.58818 .48238 m .5871 .48457 L .5848 .48515 L F
.673 .45 .574 r
.59082 .48229 m .5871 .48457 L .58818 .48238 L F
.576 .771 .971 r
.45458 .61331 m .45802 .61428 L .45654 .61285 L F
.351 .045 .299 r
.40521 .58974 m .40743 .58912 L .40792 .58652 L F
.245 0 .266 r
.40792 .58652 m .40933 .5883 L .4101 .58664 L F
.40792 .58652 m .40743 .58912 L .40933 .5883 L F
.853 .862 .847 r
.77213 .399 m .76835 .4006 L .77131 .39697 L F
.914 .865 .777 r
.77349 .39363 m .77213 .399 L .77131 .39697 L F
.349 .742 .985 r
.24496 .54003 m .2475 .53981 L .24875 .54079 L F
0 .431 .741 r
.2475 .53981 m .25103 .54095 L .24875 .54079 L F
.075 0 .317 r
.43623 .58938 m .4359 .59189 L .4342 .59288 L F
.322 .129 .456 r
.26373 .61345 m .26152 .61655 L .26161 .61414 L F
.737 .379 0 r
.42457 .62255 m .42616 .62623 L .42539 .62469 L F
.705 .622 .762 r
.4283 .62325 m .42616 .62623 L .42457 .62255 L F
.735 .216 0 r
.4285 .62786 m .42539 .62469 L .42616 .62623 L F
0 0 0 r
.15855 .56965 m .15705 .57129 L .1556 .572 L F
.15861 .57019 m .15855 .56965 L .16085 .56931 L F
.15861 .57019 m .15705 .57129 L .15855 .56965 L F
.86 .791 .782 r
.66332 .40378 m .66106 .4069 L .66414 .40775 L F
.892 .712 .651 r
.66106 .4069 m .66249 .408 L .66414 .40775 L F
.663 .498 .651 r
.46023 .59881 m .45746 .59643 L .46006 .59607 L F
.46023 .59881 m .45757 .59905 L .45746 .59643 L F
.525 .304 .521 r
.56969 .54243 m .57228 .5418 L .57232 .53944 L F
.501 .347 .604 r
.57232 .53944 m .57483 .53877 L .57446 .5361 L F
.438 .221 .485 r
.57228 .5418 m .57483 .53877 L .57232 .53944 L F
.358 .701 .984 r
.18103 .63004 m .17763 .62912 L .17987 .62909 L F
.339 .495 .868 r
.18184 .62833 m .18103 .63004 L .17987 .62909 L F
.18184 .62833 m .18361 .6313 L .18103 .63004 L F
.6 .091 .012 r
.76458 .40357 m .76418 .4025 L .76356 .40353 L F
.941 .811 .357 r
.76356 .40353 m .76418 .4025 L .76387 .40102 L F
.325 .734 .979 r
.68007 .43675 m .68061 .43749 L .67952 .43635 L F
.54 .238 .404 r
.5848 .48515 m .58468 .48757 L .58227 .48767 L F
.732 .538 .631 r
.5871 .48457 m .58468 .48757 L .5848 .48515 L F
.658 .573 .748 r
.55634 .58335 m .55947 .58393 L .55924 .57783 L F
.219 0 0 r
.19005 .55692 m .18811 .5584 L .1859 .55874 L F
.162 0 0 r
.19203 .55645 m .18811 .5584 L .19005 .55692 L F
.724 .63 .752 r
.61692 .41941 m .61979 .4228 L .61976 .41614 L F
.524 .8 .996 r
.61698 .42191 m .61979 .4228 L .61692 .41941 L F
0 0 0 r
.62087 .42158 m .62064 .42204 L .62331 .41882 L F
.61979 .4228 m .62064 .42204 L .62087 .42158 L F
.524 .8 .996 r
.61698 .42191 m .62064 .42204 L .61979 .4228 L F
.592 .442 .647 r
.61698 .42191 m .6201 .4231 L .62064 .42204 L F
.6201 .4231 m .62023 .42315 L .62064 .42204 L F
.581 .508 .738 r
.50768 .60195 m .50823 .60461 L .50572 .60516 L F
.569 .365 .565 r
.50823 .60461 m .50552 .60774 L .50572 .60516 L F
.625 .433 .603 r
.57688 .56034 m .5769 .56283 L .57445 .56303 L F
.551 .403 .632 r
.57884 .55737 m .57911 .55971 L .57688 .56034 L F
.369 .158 .457 r
.57911 .55971 m .5769 .56283 L .57688 .56034 L F
.527 .351 .587 r
.56725 .54765 m .56957 .5446 L .56756 .54544 L F
.44 .089 .272 r
.63008 .40925 m .63333 .40694 L .63054 .40781 L F
.542 .269 .45 r
.39501 .59872 m .39751 .59848 L .39797 .5963 L F
.397 .139 .402 r
.39797 .5963 m .39963 .59782 L .40017 .5956 L F
.39797 .5963 m .39751 .59848 L .39963 .59782 L F
.237 .131 .525 r
.42156 .62754 m .41956 .62584 L .42237 .62354 L F
.537 .336 .555 r
.42457 .62255 m .42237 .62354 L .42248 .62286 L F
.42457 .62255 m .42539 .62469 L .42237 .62354 L F
.677 .4 .494 r
.42539 .62469 m .42156 .62754 L .42237 .62354 L F
.787 .963 .92 r
.77729 .42928 m .77757 .42985 L .77872 .4287 L F
.268 .622 .96 r
.77872 .4287 m .78046 .42794 L .77729 .42928 L F
.77872 .4287 m .78118 .42928 L .78046 .42794 L F
0 .398 .711 r
.44641 .55668 m .44693 .55682 L .44852 .5574 L F
.313 0 0 r
.44542 .5565 m .44796 .55709 L .44693 .55682 L F
0 .437 .715 r
.44693 .55682 m .45006 .55758 L .45088 .55787 L F
.313 0 0 r
.44796 .55709 m .45006 .55758 L .44693 .55682 L F
0 .398 .711 r
.44516 .55625 m .44693 .55682 L .44641 .55668 L F
0 .437 .715 r
.44693 .55682 m .45088 .55787 L .44852 .5574 L F
.628 .809 .969 r
.20121 .63596 m .19706 .63547 L .19922 .63516 L F
.529 .893 .973 r
.20168 .63489 m .20121 .63596 L .19922 .63516 L F
.20168 .63489 m .20331 .63522 L .20121 .63596 L F
.549 .878 .61 r
.54435 .55692 m .5443 .55684 L .54144 .55938 L F
.215 .591 .946 r
.22431 .65137 m .22183 .64992 L .22367 .64931 L F
.55 .176 .285 r
.22367 .64931 m .2264 .64995 L .22789 .64951 L F
.866 .534 .423 r
.22367 .64931 m .22431 .65137 L .22183 .64992 L F
.465 0 0 r
.22367 .64931 m .22183 .64992 L .2264 .64995 L F
.907 .979 .704 r
.67601 .44375 m .67363 .4461 L .67548 .44297 L F
.67601 .44375 m .67403 .44678 L .67363 .4461 L F
.886 .967 .838 r
.64596 .42707 m .6493 .42496 L .6488 .42431 L F
.888 .514 .326 r
.74511 .39806 m .74553 .39707 L .7428 .39497 L F
.428 .216 .487 r
.45311 .56855 m .45115 .56924 L .45362 .56617 L F
.45311 .56855 m .45115 .56924 L .45362 .56617 L F
.579 .78 .975 r
.45071 .56781 m .45115 .56924 L .45311 .56855 L F
.997 .791 .506 r
.45883 .61265 m .46029 .61108 L .45914 .61012 L F
.99 .87 .617 r
.19635 .73344 m .19748 .73362 L .19611 .73145 L F
.19635 .73344 m .19748 .73362 L .19611 .73145 L F
.856 .78 .776 r
.61873 .45499 m .61659 .45808 L .61957 .45823 L F
.864 .749 .734 r
.61659 .45808 m .61769 .4617 L .61957 .45823 L F
.237 0 0 r
.78494 .44383 m .7866 .44466 L .78393 .44378 L F
.78494 .44383 m .78754 .44318 L .7866 .44466 L F
.42 .057 .239 r
.17138 .54796 m .17374 .54763 L .17506 .54519 L F
.282 0 .164 r
.17506 .54519 m .17586 .54689 L .17761 .54501 L F
.17506 .54519 m .17374 .54763 L .17586 .54689 L F
.357 .793 .964 r
.2228 .53929 m .22501 .53896 L .22667 .53948 L F
.436 .816 .99 r
.22501 .53896 m .22882 .53922 L .22667 .53948 L F
.534 .396 .639 r
.24441 .59573 m .2464 .59257 L .24479 .59316 L F
.326 .087 .39 r
.28002 .58416 m .27951 .58649 L .2776 .58716 L F
.398 .248 .559 r
.27951 .58649 m .27949 .58906 L .2776 .58716 L F
.412 .249 .549 r
.2776 .58716 m .27949 .58906 L .27755 .5897 L F
.095 .481 .896 r
.64073 .42468 m .63955 .4232 L .64044 .42257 L F
.748 .497 .552 r
.43381 .63488 m .43751 .63761 L .43756 .635 L F
.36 .196 .519 r
.4394 .63658 m .43756 .635 L .43966 .63439 L F
.4394 .63658 m .43751 .63761 L .43756 .635 L F
.4394 .63658 m .43756 .635 L .43966 .63439 L F
.4394 .63658 m .43751 .63761 L .43756 .635 L F
.372 .045 .276 r
.21998 .62793 m .22293 .62585 L .22067 .62634 L F
.574 .548 .788 r
.63645 .41978 m .63778 .41545 L .63656 .41423 L F
.63645 .41978 m .63922 .41988 L .63778 .41545 L F
.026 0 0 r
.63757 .41983 m .63645 .41978 L .63517 .4207 L F
.63757 .41983 m .63922 .41988 L .63645 .41978 L F
.613 .851 .989 r
.18745 .71625 m .18789 .7145 L .18573 .71494 L F
.18745 .71625 m .19081 .71543 L .18789 .7145 L F
.762 .847 .915 r
.70046 .42645 m .69615 .42731 L .69935 .42507 L F
.746 .862 .933 r
.70259 .42507 m .70046 .42645 L .69935 .42507 L F
.689 .701 .856 r
.54609 .59185 m .54723 .59359 L .54329 .59295 L F
.54609 .59185 m .54723 .59359 L .54329 .59295 L F
.211 .418 .847 r
.74753 .43202 m .75089 .43383 L .74968 .43177 L F
.62 .807 .972 r
.73026 .38524 m .72516 .38477 L .72891 .38377 L F
.38 .844 .855 r
.73047 .38475 m .73026 .38524 L .72891 .38377 L F
.73047 .38475 m .73183 .38476 L .73026 .38524 L F
.668 .557 .721 r
.28337 .57205 m .28086 .57261 L .28007 .56896 L F
.499 .291 .528 r
.28337 .57205 m .28067 .57591 L .28086 .57261 L F
.612 .836 .985 r
.78034 .39063 m .77688 .39286 L .77529 .3918 L F
.78034 .39063 m .77987 .39205 L .77688 .39286 L F
.362 .098 .372 r
.26646 .60789 m .26572 .61042 L .26377 .61084 L F
.446 .295 .582 r
.26864 .6049 m .26849 .60726 L .26646 .60789 L F
.511 .286 .509 r
.26849 .60726 m .26572 .61042 L .26646 .60789 L F
.837 .904 .885 r
.6914 .43142 m .68781 .43241 L .68979 .43029 L F
.769 .847 .91 r
.69455 .42887 m .6914 .43142 L .68979 .43029 L F
.852 .394 .08 r
.51383 .5567 m .51097 .55392 L .51223 .55478 L F
.715 .365 .383 r
.50051 .60377 m .50352 .60061 L .50182 .60137 L F
.50051 .60377 m .50393 .60406 L .50352 .60061 L F
.536 .236 .405 r
.50352 .60061 m .50639 .6035 L .50519 .60001 L F
.50352 .60061 m .50393 .60406 L .50639 .6035 L F
.562 .41 .633 r
.2301 .6463 m .22789 .64951 L .22896 .64728 L F
.484 .586 .881 r
.62781 .43064 m .62934 .4337 L .62719 .43368 L F
.871 .838 .81 r
.62779 .43335 m .62934 .4337 L .62826 .43286 L F
.118 .655 .853 r
.62719 .43368 m .62934 .4337 L .63053 .43397 L F
.871 .838 .81 r
.62562 .43562 m .62934 .4337 L .62779 .43335 L F
.118 .655 .853 r
.63053 .43397 m .62934 .4337 L .63077 .434 L F
.886 .812 .771 r
.62707 .43678 m .63077 .434 L .62934 .4337 L F
.62707 .43678 m .62857 .43828 L .63077 .434 L F
.002 .569 .789 r
.63077 .434 m .633 .43424 L .62934 .4337 L F
.63077 .434 m .633 .43424 L .62934 .4337 L F
.188 0 .152 r
.24259 .59673 m .24161 .59848 L .24441 .59573 L F
.335 0 .052 r
.45374 .57112 m .45626 .57067 L .45771 .56892 L F
.466 .216 .45 r
.45626 .57067 m .45807 .56766 L .45771 .56892 L F
.185 0 .381 r
.5877 .53929 m .5896 .53571 L .58926 .53783 L F
0 0 .266 r
.58742 .54157 m .5877 .53929 L .58926 .53783 L F
.67 .514 .665 r
.74624 .38343 m .74998 .3811 L .74615 .38076 L F
.74624 .38343 m .74993 .38365 L .74998 .3811 L F
.691 .89 .97 r
.72422 .39321 m .72667 .3925 L .72563 .39112 L F
.758 .915 .943 r
.72563 .39112 m .72667 .3925 L .72915 .39048 L F
.816 .571 .569 r
.4547 .61116 m .45458 .61331 L .45654 .61285 L F
.538 .308 .514 r
.43116 .62001 m .43087 .62296 L .4283 .62325 L F
.273 .197 .585 r
.43237 .61595 m .43265 .61923 L .43116 .62001 L F
.454 .237 .493 r
.43305 .62224 m .43116 .62001 L .43265 .61923 L F
.43305 .62224 m .43087 .62296 L .43116 .62001 L F
.997 .806 .527 r
.67046 .4049 m .66937 .40422 L .66965 .40121 L F
.232 .523 .916 r
.67046 .4049 m .67233 .40412 L .66937 .40422 L F
.67046 .4049 m .67367 .4059 L .67233 .40412 L F
.429 .416 .743 r
.2519 .55765 m .25321 .55375 L .25112 .5548 L F
.2519 .55765 m .25434 .55689 L .25321 .55375 L F
.317 .257 .631 r
.25272 .55989 m .25434 .55689 L .2519 .55765 L F
.773 .735 .818 r
.7334 .42477 m .73467 .4279 L .73691 .42478 L F
.575 .454 .677 r
.73467 .4279 m .73742 .42709 L .73691 .42478 L F
.647 .939 .964 r
.19335 .72166 m .19502 .72195 L .19535 .72056 L F
.19335 .72166 m .19502 .72195 L .19535 .72056 L F
.441 .282 .568 r
.27277 .59841 m .27082 .60148 L .27114 .59918 L F
.477 .437 .734 r
.74993 .38365 m .75047 .38769 L .7529 .38652 L F
.465 .56 .868 r
.75047 .38769 m .75379 .38885 L .7529 .38652 L F
0 0 0 r
.20791 .70028 m .20471 .70325 L .20629 .70128 L F
.272 0 .204 r
.57773 .46902 m .58062 .4667 L .57838 .46761 L F
.379 .154 .442 r
.23342 .61137 m .23075 .61416 L .2326 .61318 L F
.395 .273 .594 r
.23075 .61416 m .23352 .61571 L .2326 .61318 L F
.23075 .61416 m .2302 .61715 L .23352 .61571 L F
.699 .952 .681 r
.55369 .50251 m .55157 .50515 L .55379 .50238 L F
.55369 .50251 m .55123 .50506 L .55157 .50515 L F
0 0 0 r
.55259 .50372 m .55193 .50456 L .55123 .50506 L F
.55193 .50456 m .55003 .50699 L .55123 .50506 L F
.455 .88 .784 r
.54982 .50608 m .55123 .50506 L .54942 .50629 L F
.55157 .50515 m .55123 .50506 L .54982 .50608 L F
0 0 0 r
.55003 .50699 m .54942 .50629 L .55123 .50506 L F
.55003 .50699 m .54863 .50826 L .54942 .50629 L F
.961 .626 .304 r
.473 .57234 m .4705 .57487 L .46938 .5716 L F
.473 .57234 m .47173 .57335 L .47086 .57451 L F
.473 .57234 m .47314 .57442 L .47173 .57335 L F
.637 .957 .927 r
.4728 .57193 m .47173 .57335 L .47405 .57271 L F
.47271 .57187 m .47173 .57335 L .4728 .57193 L F
.961 .626 .304 r
.47086 .57451 m .47173 .57335 L .4705 .57487 L F
.085 0 .005 r
.43227 .63929 m .43155 .63894 L .43116 .63878 L F
.43155 .63894 m .42883 .63765 L .43116 .63878 L F
.783 .663 .731 r
.4297 .63658 m .43026 .63834 L .42883 .63765 L F
.4297 .63658 m .43028 .63842 L .43116 .63878 L F
.43028 .63842 m .43063 .63954 L .43116 .63878 L F
0 .126 .651 r
.42883 .63765 m .42948 .63697 L .4297 .63658 L F
.264 .599 .951 r
.42545 .63606 m .42948 .63697 L .42883 .63765 L F
0 0 .496 r
.52829 .5837 m .52936 .58709 L .52938 .58609 L F
0 .03 .537 r
.52922 .58955 m .52938 .58609 L .52936 .58709 L F
.627 .377 .52 r
.45323 .57819 m .45295 .58055 L .45002 .58077 L F
.376 .037 .257 r
.45615 .57764 m .45295 .58055 L .45323 .57819 L F
.783 .893 .922 r
.72051 .3943 m .72422 .39321 L .72323 .39224 L F
.671 .861 .972 r
.72323 .39224 m .72422 .39321 L .72563 .39112 L F
0 0 0 r
.54238 .5873 m .5412 .58875 L .54073 .58891 L F
.896 .983 .713 r
.54141 .58672 m .5412 .58875 L .54313 .58569 L F
.161 .227 .685 r
.54141 .58672 m .54148 .58865 L .5412 .58875 L F
0 0 .395 r
.5412 .58875 m .54179 .59177 L .54071 .58892 L F
.772 .532 0 r
.54161 .59086 m .54159 .59133 L .54179 .59177 L F
.5412 .58875 m .54159 .59133 L .54161 .59086 L F
.451 .367 .67 r
.54262 .58971 m .54157 .5917 L .54159 .59133 L F
.844 .887 .458 r
.54159 .59133 m .54058 .59357 L .54179 .59177 L F
.451 .367 .67 r
.54157 .5917 m .54058 .59357 L .54159 .59133 L F
.161 .227 .685 r
.54148 .58865 m .54159 .59133 L .5412 .58875 L F
0 0 0 r
.54073 .58891 m .5412 .58875 L .54071 .58892 L F
.532 .316 .533 r
.47264 .61105 m .47257 .61359 L .4701 .61395 L F
.53 .036 .028 r
.47257 .61359 m .46932 .614 L .4701 .61395 L F
.46971 .61395 m .47102 .61501 L .46932 .614 L F
.47257 .61359 m .47102 .61501 L .46971 .61395 L F
.521 .218 .394 r
.47367 .61469 m .473 .61674 L .47102 .61501 L F
.778 .566 .613 r
.473 .61674 m .47246 .61617 L .47102 .61501 L F
.423 .004 .137 r
.47473 .61272 m .47102 .61501 L .47257 .61359 L F
.47473 .61272 m .47367 .61469 L .47102 .61501 L F
.371 0 .157 r
.46983 .61355 m .47025 .61387 L .47264 .61105 L F
.588 .844 .485 r
.47264 .61105 m .47025 .61387 L .47362 .60971 L F
.631 .878 .533 r
.47362 .60971 m .47025 .61387 L .47223 .61114 L F
.88 .926 .54 r
.47116 .61455 m .47223 .61114 L .47025 .61387 L F
.47102 .61501 m .47079 .61438 L .47223 .61114 L F
.778 .566 .613 r
.47246 .61617 m .47079 .61438 L .47102 .61501 L F
.88 .926 .54 r
.47102 .61501 m .47116 .61455 L .47025 .61387 L F
.371 0 .157 r
.46932 .614 m .47025 .61387 L .46983 .61355 L F
.431 .236 .513 r
.47473 .61272 m .47264 .61105 L .4752 .61077 L F
.47473 .61272 m .47257 .61359 L .47264 .61105 L F
.668 .972 .903 r
.44793 .60346 m .44596 .60526 L .44912 .60344 L F
.508 .464 .743 r
.44793 .60346 m .44663 .60769 L .44596 .60526 L F
.782 .533 .559 r
.49664 .57811 m .49659 .58061 L .49279 .58014 L F
.481 .285 .537 r
.49664 .57811 m .49659 .58061 L .49894 .57756 L F
.49664 .57811 m .49659 .58061 L .49894 .57756 L F
.152 0 .134 r
.43357 .56267 m .43103 .56533 L .43175 .56419 L F
.612 .353 .501 r
.51041 .59916 m .50768 .60195 L .50628 .59844 L F
.51041 .59916 m .51033 .60143 L .50768 .60195 L F
.566 .397 .611 r
.51279 .59585 m .51309 .59897 L .51041 .59916 L F
.297 .104 .44 r
.51252 .60002 m .51041 .59916 L .51309 .59897 L F
.51252 .60002 m .51033 .60143 L .51041 .59916 L F
.594 .912 .978 r
.59914 .44662 m .59797 .44694 L .60074 .44539 L F
.454 .193 .428 r
.5979 .44809 m .60074 .44539 L .59797 .44694 L F
.302 .228 .604 r
.28089 .56773 m .28134 .56909 L .28007 .56896 L F
.266 .369 .782 r
.28134 .56909 m .2827 .57094 L .28007 .56896 L F
.668 .557 .721 r
.28337 .57205 m .28007 .56896 L .2827 .57094 L F
.605 .405 .584 r
.75325 .3834 m .7561 .38299 L .75481 .38149 L F
.324 .343 .726 r
.75481 .38149 m .7561 .38299 L .75767 .38297 L F
.75767 .38297 m .7561 .38299 L .75481 .38149 L F
.75767 .38297 m .7561 .38299 L .75481 .38149 L F
.871 .78 .759 r
.60899 .4888 m .61069 .48585 L .60913 .48466 L F
.569 .357 .553 r
.60268 .43983 m .60564 .43685 L .60284 .43766 L F
.186 .007 .39 r
.28194 .58076 m .28176 .58332 L .28002 .58416 L F
.435 .183 .432 r
.28174 .58589 m .28002 .58416 L .28176 .58332 L F
.28174 .58589 m .27951 .58649 L .28002 .58416 L F
.982 .706 .418 r
.21706 .65779 m .21847 .65921 L .21698 .65545 L F
.755 .362 .31 r
.21706 .65779 m .22112 .65887 L .21847 .65921 L F
0 .076 .58 r
.50223 .571 m .50115 .57019 L .49972 .56886 L F
.50223 .571 m .50347 .57233 L .50115 .57019 L F
.915 .616 .462 r
.21005 .67736 m .20869 .67934 L .20848 .67697 L F
.636 .238 .272 r
.21256 .67921 m .20869 .67934 L .21005 .67736 L F
.535 .104 .168 r
.20848 .67697 m .21228 .67632 L .21005 .67736 L F
.376 .247 .575 r
.47809 .60764 m .47988 .60694 L .47772 .60605 L F
.47809 .60764 m .47988 .60694 L .47772 .60605 L F
.922 .886 .779 r
.42545 .63606 m .42415 .63766 L .42293 .63645 L F
.388 .574 .912 r
.42585 .63374 m .42545 .63606 L .42293 .63645 L F
.42585 .63374 m .42948 .63697 L .42545 .63606 L F
.638 .958 .924 r
.1952 .74473 m .19618 .74522 L .19659 .74402 L F
.163 .703 .785 r
.19499 .74515 m .19376 .74553 L .19241 .7432 L F
.19493 .74526 m .19376 .74553 L .19499 .74515 L F
0 0 0 r
.19376 .74553 m .19618 .74522 L .19335 .74567 L F
0 .129 .589 r
.19303 .74362 m .19495 .74512 L .19241 .7432 L F
.638 .958 .924 r
.19493 .74526 m .19618 .74522 L .1952 .74473 L F
.163 .703 .785 r
.19493 .74526 m .19618 .74522 L .19376 .74553 L F
.638 .958 .924 r
.19485 .74543 m .19618 .74522 L .19493 .74526 L F
.163 .703 .785 r
.19509 .74523 m .19618 .74522 L .19493 .74526 L F
0 .129 .589 r
.19495 .74512 m .19509 .74523 L .19499 .74515 L F
.19495 .74512 m .19499 .74515 L .19241 .7432 L F
.638 .958 .924 r
.19335 .74567 m .19485 .74543 L .19499 .74515 L F
.19495 .74512 m .19499 .74515 L .19503 .74508 L F
.639 .724 .909 r
.19659 .74402 m .19509 .74523 L .19495 .74512 L F
.19659 .74402 m .19495 .74512 L .19303 .74362 L F
.638 .958 .924 r
.19476 .74495 m .19495 .74512 L .1952 .74473 L F
.19495 .74512 m .19503 .74508 L .1952 .74473 L F
.19335 .74567 m .19499 .74515 L .19476 .74495 L F
.163 .703 .785 r
.19509 .74523 m .19493 .74526 L .19499 .74515 L F
0 0 0 r
.19376 .74553 m .19335 .74567 L .19211 .74658 L F
.44266 .5749 m .44419 .57478 L .44638 .5746 L F
.621 .169 .156 r
.44419 .57478 m .44872 .57519 L .44638 .5746 L F
.781 .545 .578 r
.42533 .65496 m .42904 .65287 L .42526 .65294 L F
.42533 .65496 m .42898 .6554 L .42904 .65287 L F
.837 .788 .804 r
.21274 .65942 m .2083 .6611 L .21095 .66041 L F
.648 .968 .844 r
.21592 .65726 m .21274 .65942 L .21395 .65804 L F
.34 .049 .316 r
.21095 .66041 m .21395 .65804 L .21274 .65942 L F
.882 .881 .828 r
.62614 .4385 m .62857 .43828 L .62707 .43678 L F
.62614 .4385 m .62734 .43968 L .62857 .43828 L F
.339 .712 .984 r
.17796 .62791 m .17763 .62912 L .1758 .62834 L F
.17796 .62791 m .17987 .62909 L .17763 .62912 L F
.723 .804 .915 r
.69591 .43507 m .69933 .43541 L .69793 .43365 L F
.739 .757 .867 r
.69793 .43365 m .69933 .43541 L .70152 .43416 L F
.236 0 0 r
.15678 .55369 m .159 .55344 L .16093 .55206 L F
.129 0 0 r
.159 .55344 m .16302 .55134 L .16093 .55206 L F
0 .326 .737 r
.48724 .56159 m .48878 .56232 L .49017 .56328 L F
0 .281 .783 r
.49171 .5634 m .49017 .56328 L .48878 .56232 L F
.49171 .5634 m .49264 .5651 L .49017 .56328 L F
.624 .216 .248 r
.21982 .6502 m .21573 .6513 L .21626 .65173 L F
.21982 .6502 m .21812 .65249 L .21573 .6513 L F
0 0 0 r
.22045 .64965 m .21982 .6502 L .22183 .64992 L F
.22045 .64965 m .21812 .65249 L .21982 .6502 L F
.879 .93 .851 r
.18936 .72925 m .18983 .72759 L .18819 .72864 L F
.18936 .72925 m .19144 .72675 L .18983 .72759 L F
.677 .825 .954 r
.48651 .57569 m .48915 .57478 L .48534 .57433 L F
.48534 .57433 m .48915 .57478 L .48651 .57569 L F
.288 .445 .844 r
.48927 .57746 m .48651 .57569 L .48915 .57478 L F
0 .045 .607 r
.5303 .5934 m .53142 .59548 L .53021 .59182 L F
.886 .556 .419 r
.63333 .40694 m .6372 .41048 L .63554 .40633 L F
.63333 .40694 m .63275 .40877 L .6372 .41048 L F
.464 0 0 r
.63287 .41141 m .6372 .41048 L .63275 .40877 L F
.63287 .41141 m .63533 .41159 L .6372 .41048 L F
.22 .404 .832 r
.63554 .40633 m .6372 .41048 L .63788 .40784 L F
.669 .512 .664 r
.63533 .41159 m .63788 .40784 L .6372 .41048 L F
.464 .285 .552 r
.63333 .40694 m .63537 .40397 L .63313 .40455 L F
.742 .592 .689 r
.48323 .5924 m .486 .59025 L .48359 .58995 L F
.874 .794 .302 r
.76975 .41074 m .76923 .41116 L .76964 .40876 L F
.76975 .41074 m .76931 .41313 L .76923 .41116 L F
.341 .763 .976 r
.78454 .41373 m .78402 .41311 L .78094 .41322 L F
.605 .082 0 r
.78094 .41322 m .78314 .41494 L .78454 .41373 L F
.521 .711 .958 r
.78094 .41322 m .78402 .41311 L .78342 .41103 L F
.974 .885 .515 r
.78454 .41373 m .78388 .41294 L .78421 .41205 L F
0 0 .35 r
.78421 .41205 m .78456 .41309 L .78454 .41373 L F
.521 .711 .958 r
.78402 .41311 m .78456 .41309 L .78372 .41158 L F
.285 .261 .656 r
.78395 .41275 m .78342 .41103 L .78421 .41205 L F
.521 .711 .958 r
.78402 .41311 m .78395 .41275 L .78342 .41103 L F
.285 .261 .656 r
.78314 .41494 m .78342 .41103 L .78395 .41275 L F
.521 .711 .958 r
.78395 .41275 m .78372 .41158 L .78342 .41103 L F
.974 .885 .515 r
.78402 .41311 m .78314 .41494 L .78388 .41294 L F
.78454 .41373 m .7842 .41403 L .78402 .41311 L F
.7842 .41403 m .78314 .41494 L .78402 .41311 L F
.341 .763 .976 r
.78454 .41373 m .78456 .41309 L .78402 .41311 L F
.573 .552 .793 r
.78789 .41607 m .78454 .41373 L .78729 .41208 L F
.38 .262 .592 r
.57159 .57082 m .56931 .56926 L .57159 .5687 L F
.57159 .57082 m .56952 .57192 L .56931 .56926 L F
.668 .969 .915 r
.51966 .51706 m .51784 .5184 L .51667 .51838 L F
.798 .413 .326 r
.53738 .60802 m .53611 .61006 L .53437 .60722 L F
.707 .299 .272 r
.53738 .60802 m .53964 .61021 L .53611 .61006 L F
.455 .536 .851 r
.4018 .64408 m .40439 .64455 L .40347 .64252 L F
.878 .895 .84 r
.78223 .42125 m .78543 .41971 L .78445 .42229 L F
.816 .849 .39 r
.7845 .42132 m .78543 .41971 L .7868 .41792 L F
.7845 .42132 m .78445 .42229 L .78543 .41971 L F
.7845 .42132 m .78445 .42229 L .78543 .41971 L F
.58 .398 .601 r
.56234 .55122 m .56496 .55315 L .56494 .55083 L F
.56234 .55122 m .56246 .55373 L .56496 .55315 L F
.68 .969 .925 r
.75379 .39338 m .75547 .39351 L .75221 .39538 L F
0 0 .251 r
.75379 .39338 m .75221 .39538 L .75269 .39668 L F
0 0 0 r
.45575 .56464 m .45472 .5659 L .45362 .56617 L F
0 0 .251 r
.45472 .5659 m .45311 .56855 L .45362 .56617 L F
.371 .532 .886 r
.49895 .56703 m .49777 .56877 L .49653 .5672 L F
.49895 .56703 m .49972 .56886 L .49777 .56877 L F
.497 .296 .538 r
.26597 .61281 m .26377 .61084 L .26572 .61042 L F
.26597 .61281 m .26373 .61345 L .26377 .61084 L F
.58 .365 .554 r
.56957 .5446 m .57228 .5418 L .56969 .54243 L F
.165 0 .024 r
.42721 .5697 m .42609 .56946 L .42841 .56873 L F
.42721 .5697 m .42521 .57107 L .42609 .56946 L F
.88 .774 .74 r
.59009 .49376 m .59075 .49737 L .58899 .49658 L F
.877 .609 .529 r
.59075 .49737 m .58802 .49872 L .58899 .49658 L F
.59075 .49737 m .59077 .49975 L .58802 .49872 L F
.695 .78 .299 r
.58539 .518 m .58466 .51963 L .58561 .51737 L F
.327 0 0 r
.47659 .57292 m .47594 .5745 L .47314 .57442 L F
.75 .712 .816 r
.47643 .57219 m .47786 .57333 L .47651 .57217 L F
.063 0 0 r
.47786 .57333 m .47659 .57292 L .47954 .57468 L F
.47786 .57333 m .47954 .57468 L .47959 .57471 L F
.47786 .57333 m .47594 .5745 L .47659 .57292 L F
.75 .712 .816 r
.47405 .57271 m .47786 .57333 L .47643 .57219 L F
.372 .598 .934 r
.47314 .57442 m .47594 .5745 L .47482 .57344 L F
.4737 .57336 m .47482 .57344 L .47405 .57271 L F
.47314 .57442 m .47482 .57344 L .4737 .57336 L F
.75 .712 .816 r
.47405 .57271 m .47594 .5745 L .47786 .57333 L F
.465 .422 .726 r
.47476 .57565 m .47649 .57223 L .47786 .57333 L F
.806 .862 .891 r
.47983 .57485 m .47698 .5771 L .47476 .57565 L F
.063 0 0 r
.47786 .57333 m .47959 .57471 L .47983 .57485 L F
.806 .862 .891 r
.47983 .57485 m .47476 .57565 L .47786 .57333 L F
.465 .422 .726 r
.47476 .57565 m .47777 .57552 L .47706 .57361 L F
.47584 .57352 m .47706 .57361 L .47651 .57217 L F
.47476 .57565 m .47706 .57361 L .47584 .57352 L F
.47649 .57223 m .47651 .57217 L .47786 .57333 L F
.581 .36 .545 r
.57377 .48841 m .57618 .49049 L .57379 .49036 L F
.642 .343 .449 r
.57643 .48848 m .57618 .49049 L .57377 .48841 L F
.474 .411 .706 r
.55746 .55729 m .56005 .55929 L .56 .55687 L F
.55746 .55729 m .55815 .56 L .56005 .55929 L F
.472 .27 .524 r
.24942 .58718 m .25165 .58663 L .25185 .58406 L F
.425 .155 .398 r
.24942 .58718 m .24882 .58928 L .25165 .58663 L F
.965 .751 .564 r
.21426 .61347 m .21375 .61604 L .21552 .61698 L F
.21426 .61347 m .21375 .61604 L .21552 .61698 L F
.75 .762 .254 r
.59486 .52257 m .59544 .52096 L .59575 .52057 L F
.59486 .52257 m .59445 .52464 L .59544 .52096 L F
.43 .144 .376 r
.46635 .59305 m .46525 .59585 L .46303 .59594 L F
.533 .441 .697 r
.46758 .58934 m .4672 .59245 L .46635 .59305 L F
0 0 .118 r
.46693 .59402 m .46635 .59305 L .4672 .59245 L F
.46693 .59402 m .46525 .59585 L .46635 .59305 L F
.774 .764 .844 r
.72915 .39048 m .73276 .39027 L .73194 .38983 L F
.452 .883 .881 r
.73276 .39027 m .7348 .3891 L .73194 .38983 L F
.73276 .39027 m .7353 .38932 L .7348 .3891 L F
.619 .521 .721 r
.51484 .593 m .51533 .59555 L .51279 .59585 L F
.589 .407 .603 r
.51533 .59555 m .51309 .59897 L .51279 .59585 L F
.096 .643 .832 r
.4518 .55795 m .45281 .55781 L .45469 .5582 L F
0 0 0 r
.45281 .55781 m .45203 .5582 L .45399 .55764 L F
.308 .705 .978 r
.45543 .55711 m .45469 .5582 L .45281 .55781 L F
0 0 0 r
.45281 .55781 m .45399 .55764 L .45436 .55754 L F
.096 .643 .832 r
.45088 .55787 m .45281 .55781 L .4518 .55795 L F
.308 .705 .978 r
.45543 .55711 m .4574 .55827 L .45469 .5582 L F
.574 .622 .862 r
.43229 .62584 m .4283 .62325 L .43087 .62296 L F
.71 .356 .375 r
.43229 .62584 m .43116 .62808 L .4285 .62786 L F
.385 .426 .781 r
.43305 .62224 m .43229 .62584 L .43087 .62296 L F
.43305 .62224 m .43476 .62684 L .43229 .62584 L F
.553 .184 .295 r
.43432 .62711 m .43116 .62808 L .43229 .62584 L F
.562 .171 .259 r
.43476 .62684 m .43432 .62711 L .43229 .62584 L F
.702 .309 .301 r
.21622 .63073 m .21794 .62861 L .21414 .62849 L F
.162 0 0 r
.21998 .62793 m .21794 .62861 L .21622 .63073 L F
.463 .223 .465 r
.40872 .60697 m .40893 .60817 L .40649 .60846 L F
.40872 .60697 m .40893 .60817 L .40649 .60846 L F
.759 .404 .381 r
.54026 .55597 m .54349 .55476 L .54153 .55305 L F
.54026 .55597 m .5443 .55684 L .54349 .55476 L F
.659 .726 .899 r
.72255 .4179 m .72343 .41939 L .71974 .41868 L F
.629 .712 .906 r
.72666 .41893 m .72343 .41939 L .72255 .4179 L F
.638 .651 .846 r
.72666 .41893 m .72623 .42016 L .72343 .41939 L F
.76 .611 .693 r
.78009 .44237 m .78315 .44011 L .78156 .44103 L F
.5 .014 .033 r
.19808 .5409 m .20041 .54115 L .19848 .54022 L F
.371 .249 .581 r
.2302 .61715 m .23356 .61832 L .23352 .61571 L F
.2302 .61715 m .23049 .61966 L .23356 .61832 L F
.696 .874 .479 r
.54313 .58569 m .54238 .5873 L .54345 .58525 L F
.54313 .58569 m .5412 .58875 L .54238 .5873 L F
.949 .949 .732 r
.58812 .50756 m .59016 .5065 L .5888 .50823 L F
.952 .802 .354 r
.58995 .50201 m .59016 .5065 L .58953 .50572 L F
.915 .979 .759 r
.58953 .50572 m .59016 .5065 L .58812 .50756 L F
.378 .355 .707 r
.38609 .61369 m .38652 .61721 L .38862 .61575 L F
.432 .457 .786 r
.38652 .61721 m .38948 .61891 L .38862 .61575 L F
.641 .813 .966 r
.20086 .55361 m .20475 .55401 L .20303 .55306 L F
.619 .858 .988 r
.20684 .55304 m .20303 .55306 L .20475 .55401 L F
.376 .037 .257 r
.45615 .57764 m .45507 .58017 L .45295 .58055 L F
.309 .369 .762 r
.75116 .39827 m .7528 .39931 L .75269 .39668 L F
.808 .991 .877 r
.20059 .71255 m .201 .7129 L .20207 .71262 L F
.683 .97 .923 r
.20246 .71125 m .20059 .71255 L .20207 .71262 L F
.43 .022 .161 r
.42991 .64106 m .42831 .64298 L .42656 .64232 L F
.11 0 0 r
.43063 .64192 m .42831 .64298 L .42991 .64106 L F
.649 .148 .043 r
.41662 .64372 m .41907 .64507 L .41948 .64385 L F
.592 .616 .845 r
.7383 .4297 m .73966 .42656 L .73742 .42709 L F
.7383 .4297 m .7408 .42977 L .73966 .42656 L F
.667 .455 .588 r
.57445 .56303 m .57112 .56568 L .57104 .56306 L F
.57445 .56303 m .57437 .56561 L .57112 .56568 L F
.562 .335 .529 r
.5769 .56283 m .57437 .56561 L .57445 .56303 L F
.432 .777 .997 r
.16781 .62564 m .16781 .62713 L .16592 .62725 L F
.16781 .62564 m .17003 .62679 L .16781 .62713 L F
.925 .844 .746 r
.62514 .44036 m .62734 .43968 L .62614 .4385 L F
.62514 .44036 m .62566 .44329 L .62734 .43968 L F
.952 .759 .606 r
.22388 .6536 m .22135 .65448 L .22136 .65277 L F
.753 .995 .852 r
.22411 .65228 m .22388 .6536 L .22431 .65137 L F
.22411 .65228 m .22135 .65448 L .22388 .6536 L F
0 0 0 r
.42809 .57836 m .42677 .57934 L .42501 .5805 L F
.893 .945 .585 r
.42818 .57734 m .42809 .57836 L .43034 .57763 L F
.42818 .57734 m .42677 .57934 L .42809 .57836 L F
.763 .449 .455 r
.45516 .60188 m .45322 .60444 L .45176 .60402 L F
.637 .489 .665 r
.45757 .59905 m .45776 .60164 L .45516 .60188 L F
.563 .2 .31 r
.45731 .60362 m .45516 .60188 L .45776 .60164 L F
.45731 .60362 m .45322 .60444 L .45516 .60188 L F
.905 .594 .104 r
.53437 .60722 m .53325 .60404 L .53402 .60495 L F
0 .304 .786 r
.4574 .55827 m .45892 .55908 L .45864 .55969 L F
0 .431 .853 r
.45892 .55908 m .46059 .56056 L .45864 .55969 L F
.489 .184 .375 r
.70467 .40423 m .70728 .40534 L .70387 .40651 L F
.70467 .40423 m .70727 .4039 L .70728 .40534 L F
.855 .944 .58 r
.59331 .52642 m .59445 .52464 L .59486 .52257 L F
0 0 0 r
.58298 .55271 m .58357 .5508 L .58499 .54944 L F
.43 .422 .75 r
.72849 .41824 m .72623 .42016 L .72666 .41893 L F
.279 .311 .717 r
.72886 .41884 m .72623 .42016 L .72849 .41824 L F
.72862 .41918 m .72623 .42016 L .72886 .41884 L F
.72898 .41904 m .72714 .42248 L .72623 .42016 L F
.865 .987 .838 r
.72753 .41906 m .72666 .4203 L .72757 .4207 L F
.72764 .4206 m .72757 .4207 L .72765 .42073 L F
.72753 .41906 m .72757 .4207 L .72764 .4206 L F
.279 .311 .717 r
.72898 .41904 m .72862 .41918 L .72886 .41884 L F
.876 .449 .185 r
.67541 .39866 m .67451 .39985 L .67608 .40045 L F
.353 .747 .985 r
.22882 .53922 m .23098 .53906 L .23271 .54002 L F
.249 .642 .962 r
.23358 .53898 m .23271 .54002 L .23098 .53906 L F
.23358 .53898 m .23458 .5399 L .23271 .54002 L F
.557 .289 .465 r
.70255 .39799 m .70583 .39512 L .70261 .3959 L F
.98 .902 .57 r
.6007 .50964 m .60165 .50604 L .601 .5051 L F
.737 .689 .804 r
.27808 .54962 m .27576 .55117 L .27414 .54836 L F
0 0 .283 r
.25311 .57507 m .25409 .57433 L .25454 .5717 L F
.135 .176 .64 r
.25311 .57507 m .25482 .57692 L .25409 .57433 L F
.362 .215 .543 r
.25306 .57747 m .25482 .57692 L .25311 .57507 L F
.772 .785 .864 r
.21705 .66365 m .22236 .66228 L .22077 .66191 L F
.724 .95 .951 r
.22077 .66191 m .22236 .66228 L .22416 .66102 L F
.494 .778 .995 r
.19139 .63388 m .18812 .63329 L .1895 .63298 L F
.038 .512 .884 r
.19157 .63324 m .19139 .63388 L .1895 .63298 L F
.19157 .63324 m .19327 .63441 L .19139 .63388 L F
.861 .736 .723 r
.64225 .40586 m .64195 .4104 L .64304 .40885 L F
.751 .922 .56 r
.64304 .40885 m .64195 .4104 L .64245 .40935 L F
.941 .573 .241 r
.64304 .40885 m .64382 .41048 L .64245 .40935 L F
.312 .175 .529 r
.64304 .40885 m .64498 .40414 L .64225 .40586 L F
.866 .781 .765 r
.64554 .40754 m .64751 .40626 L .64864 .40675 L F
.635 .392 .533 r
.64857 .4067 m .64853 .40671 L .64864 .40675 L F
.64853 .40671 m .64554 .40754 L .64864 .40675 L F
.875 .438 .129 r
.64801 .40656 m .64864 .40675 L .64751 .40626 L F
.64977 .4076 m .64864 .40675 L .64801 .40656 L F
.465 0 0 r
.64801 .40656 m .64625 .40726 L .64977 .4076 L F
.64751 .40626 m .64734 .40639 L .64801 .40656 L F
.635 .392 .533 r
.64739 .4064 m .64554 .40754 L .64857 .4067 L F
.465 0 0 r
.64734 .40639 m .64625 .40726 L .64801 .40656 L F
.635 .392 .533 r
.6478 .40615 m .64739 .4064 L .64857 .4067 L F
.64551 .40736 m .64554 .40754 L .64596 .40712 L F
.312 .175 .529 r
.64304 .40885 m .64554 .40754 L .64551 .40736 L F
.866 .781 .765 r
.64554 .40754 m .64428 .40805 L .64596 .40712 L F
.64554 .40754 m .64596 .40712 L .64751 .40626 L F
.635 .392 .533 r
.64596 .40712 m .64554 .40754 L .6478 .40615 L F
0 0 0 r
.64596 .40712 m .64734 .40639 L .64751 .40626 L F
.635 .392 .533 r
.64498 .40414 m .64551 .40736 L .6478 .40615 L F
0 0 0 r
.64562 .4073 m .64692 .40672 L .64734 .40639 L F
.64562 .4073 m .64734 .40639 L .64596 .40712 L F
.64428 .40805 m .64625 .40726 L .64692 .40672 L F
.64428 .40805 m .64692 .40672 L .64562 .4073 L F
.312 .175 .529 r
.64324 .40837 m .64551 .40736 L .64498 .40414 L F
.64304 .40885 m .64551 .40736 L .64324 .40837 L F
.962 .825 .661 r
.64055 .40588 m .64195 .4104 L .64225 .40586 L F
0 0 0 r
.64304 .40885 m .64245 .40935 L .64428 .40805 L F
.479 0 0 r
.64055 .40588 m .64428 .40805 L .64245 .40935 L F
.64055 .40588 m .64403 .40805 L .64428 .40805 L F
0 0 0 r
.64304 .40885 m .64428 .40805 L .64454 .40806 L F
.479 0 0 r
.64403 .40805 m .64436 .40825 L .64428 .40805 L F
0 0 0 r
.64454 .40806 m .64428 .40805 L .64554 .40754 L F
.709 .479 .575 r
.63936 .40354 m .64109 .40118 L .63862 .40162 L F
.168 0 0 r
.16967 .5646 m .16761 .56534 L .16934 .56308 L F
.33 .153 .484 r
.25185 .58406 m .25332 .58577 L .25393 .58347 L F
.25185 .58406 m .25165 .58663 L .25332 .58577 L F
.295 .793 .832 r
.17704 .65283 m .17661 .65303 L .17897 .65248 L F
0 0 .024 r
.58926 .53783 m .5896 .53571 L .59092 .53413 L F
0 0 .327 r
.75137 .40468 m .75247 .40492 L .75333 .40405 L F
.75137 .40468 m .7514 .40707 L .75247 .40492 L F
.252 .695 .959 r
.20501 .65099 m .20738 .6523 L .21093 .65221 L F
.771 .266 0 r
.41772 .65296 m .41761 .65397 L .41506 .65252 L F
.41772 .65296 m .41907 .65478 L .41761 .65397 L F
.994 .804 .543 r
.49368 .53642 m .49257 .5394 L .49189 .53757 L F
0 0 0 r
.49189 .53757 m .49593 .5354 L .49368 .53642 L F
.627 .529 .724 r
.41656 .63298 m .41435 .63152 L .41807 .63137 L F
.453 .337 .632 r
.41917 .6292 m .42019 .63138 L .41807 .63137 L F
.671 .408 .514 r
.42803 .58602 m .43164 .58331 L .42944 .58278 L F
.226 .167 .578 r
.58109 .5586 m .57884 .55737 L .58133 .5561 L F
.58109 .5586 m .57911 .55971 L .57884 .55737 L F
.794 .358 .211 r
.74758 .41488 m .7468 .41565 L .74692 .41489 L F
.906 .849 .776 r
.74758 .41488 m .74692 .41489 L .74907 .41005 L F
.631 .145 .08 r
.74976 .41571 m .7468 .41565 L .74758 .41488 L F
.431 0 .076 r
.45824 .56511 m .45472 .5659 L .45575 .56464 L F
.75 .639 .738 r
.7353 .38932 m .73902 .39029 L .73763 .38629 L F
.961 .78 .612 r
.51305 .53172 m .51266 .53501 L .5116 .53459 L F
.054 0 0 r
.16508 .55058 m .16717 .55 L .16927 .54853 L F
.191 0 0 r
.16717 .55 m .17138 .54796 L .16927 .54853 L F
.74 .932 .952 r
.46589 .58063 m .4623 .58162 L .46474 .58091 L F
.277 0 0 r
.54722 .6111 m .54608 .61173 L .54348 .61111 L F
.638 .17 .127 r
.54991 .61084 m .54608 .61173 L .54722 .6111 L F
.641 .193 0 r
.19625 .7123 m .19668 .71312 L .194 .71201 L F
.19625 .7123 m .19795 .71485 L .19668 .71312 L F
.591 .624 .853 r
.19958 .71354 m .19795 .71485 L .19625 .7123 L F
.03 .501 .88 r
.49488 .54197 m .4949 .54137 L .49362 .54086 L F
.49488 .54197 m .49622 .54242 L .4949 .54137 L F
.168 0 .306 r
.54945 .58076 m .55162 .57733 L .55019 .57813 L F
.55019 .57813 m .55162 .57733 L .54945 .58076 L F
.985 .758 .513 r
.53459 .56856 m .53435 .57106 L .53571 .57202 L F
.93 .594 .378 r
.53435 .57106 m .53654 .5735 L .53571 .57202 L F
.709 .173 0 r
.79184 .43016 m .79459 .43154 L .7937 .43212 L F
.551 0 0 r
.79184 .43016 m .79388 .43139 L .79459 .43154 L F
.403 .488 .833 r
.79575 .4275 m .79459 .43154 L .79388 .43139 L F
.79575 .4275 m .79687 .43034 L .79459 .43154 L F
.6 .303 .436 r
.79687 .43034 m .7937 .43212 L .79459 .43154 L F
.499 .338 .593 r
.27521 .59275 m .27518 .59547 L .273 .59597 L F
.483 .273 .517 r
.27518 .59547 m .27277 .59841 L .273 .59597 L F
.507 .743 .98 r
.48913 .58733 m .49177 .58696 L .49019 .58579 L F
0 0 0 r
.21596 .68106 m .21655 .68028 L .21744 .67998 L F
.21596 .68106 m .21744 .67998 L .21696 .68054 L F
.21696 .68054 m .21744 .67998 L .21897 .67948 L F
.094 0 .37 r
.22021 .67829 m .21897 .67948 L .21934 .6766 L F
.636 .958 .787 r
.22021 .67829 m .21672 .68057 L .21897 .67948 L F
.21672 .68057 m .21596 .68106 L .21696 .68054 L F
.21672 .68057 m .21696 .68054 L .21897 .67948 L F
.774 .267 0 r
.21494 .67856 m .21634 .68061 L .21472 .67979 L F
.21634 .68061 m .21658 .68096 L .21608 .68065 L F
.21634 .68061 m .21608 .68065 L .21472 .67979 L F
.21658 .68096 m .21682 .68132 L .21649 .68107 L F
.243 0 0 r
.21913 .6806 m .21596 .68106 L .22021 .67829 L F
.774 .267 0 r
.21658 .68096 m .21649 .68107 L .21472 .67979 L F
.651 .315 .389 r
.68023 .40704 m .67687 .40933 L .67674 .40797 L F
.68023 .40704 m .67931 .40918 L .67687 .40933 L F
.769 .534 .578 r
.68274 .40781 m .67931 .40918 L .68023 .40704 L F
.512 .457 .732 r
.55924 .57783 m .55947 .58393 L .56213 .58307 L F
.296 .202 .575 r
.55947 .58393 m .56206 .58636 L .56213 .58307 L F
.55947 .58393 m .55986 .58663 L .56206 .58636 L F
.838 .556 .512 r
.4306 .65855 m .42712 .6592 L .42658 .65858 L F
.4306 .65855 m .43043 .66101 L .42712 .6592 L F
.745 .782 .883 r
.709 .42288 m .70553 .42251 L .70734 .42142 L F
.785 .755 .826 r
.71157 .42034 m .709 .42288 L .70734 .42142 L F
.505 .404 .673 r
.75726 .37693 m .75487 .38012 L .75515 .3782 L F
.617 .649 .859 r
.75726 .37693 m .75515 .3782 L .75319 .37419 L F
.792 .826 .878 r
.75388 .37748 m .75487 .38012 L .75726 .37693 L F
.477 .437 .734 r
.74993 .38365 m .7529 .38652 L .75325 .3834 L F
.507 .242 .448 r
.7529 .38652 m .7561 .38299 L .75325 .3834 L F
.531 .223 .39 r
.43824 .61097 m .43897 .61324 L .43494 .61362 L F
.629 .277 .356 r
.44051 .61293 m .43897 .61324 L .43824 .61097 L F
.549 .304 .496 r
.44067 .61061 m .44051 .61293 L .43824 .61097 L F
.499 .291 .528 r
.28337 .57205 m .28207 .57664 L .28067 .57591 L F
.177 .526 .92 r
.2827 .57094 m .28372 .57083 L .28337 .57205 L F
.216 .027 .395 r
.28433 .57405 m .28337 .57205 L .28372 .57083 L F
.28433 .57405 m .28207 .57664 L .28337 .57205 L F
.258 0 0 r
.23358 .53898 m .23692 .53961 L .23458 .5399 L F
.171 0 0 r
.23527 .53943 m .23636 .53959 L .23692 .53961 L F
.23636 .53959 m .23914 .54 L .23692 .53961 L F
.147 .691 .778 r
.23787 .53965 m .23692 .53961 L .23891 .53957 L F
.23458 .5399 m .23692 .53961 L .23787 .53965 L F
.424 0 0 r
.23692 .53961 m .24104 .53914 L .23891 .53957 L F
.004 .5 .865 r
.173 .65135 m .17356 .65058 L .1712 .65064 L F
.173 .65135 m .17704 .65283 L .17356 .65058 L F
.056 0 0 r
.42868 .56312 m .43274 .56288 L .43004 .5623 L F
.33 .814 .849 r
.43357 .56267 m .43552 .56187 L .43274 .56288 L F
.336 0 .108 r
.49802 .60409 m .50182 .60137 L .49967 .6035 L F
0 .19 .685 r
.49967 .6035 m .50211 .6055 L .50051 .60377 L F
.49967 .6035 m .5005 .60377 L .50039 .60378 L F
.49872 .60384 m .50039 .60378 L .49802 .60409 L F
.49967 .6035 m .50039 .60378 L .49872 .60384 L F
.336 0 .108 r
.49877 .60355 m .50046 .60376 L .50182 .60137 L F
.913 .649 .524 r
.4974 .60287 m .49611 .60191 L .50042 .60382 L F
.50042 .60383 m .50042 .60382 L .50051 .60386 L F
.4974 .60287 m .50042 .60382 L .50042 .60383 L F
.336 0 .108 r
.50046 .60376 m .50051 .60377 L .5007 .60343 L F
.50046 .60376 m .5007 .60343 L .50182 .60137 L F
0 .19 .685 r
.5005 .60377 m .50048 .60377 L .49802 .60409 L F
.336 0 .108 r
.49802 .60409 m .50044 .60378 L .49877 .60355 L F
0 .19 .685 r
.5005 .60377 m .50051 .60377 L .50048 .60377 L F
.336 0 .108 r
.50044 .60378 m .50051 .60377 L .49877 .60355 L F
.522 .337 .571 r
.4976 .59914 m .5005 .59543 L .49683 .59571 L F
.4976 .59914 m .50037 .59858 L .5005 .59543 L F
.538 .351 .575 r
.50293 .60073 m .50251 .60124 L .50049 .60174 L F
.254 .446 .857 r
.50049 .60174 m .50051 .60378 L .49947 .60199 L F
.50051 .60378 m .50046 .60378 L .49769 .59894 L F
.901 .737 .669 r
.49769 .59894 m .50046 .60378 L .49611 .60191 L F
.50046 .60378 m .50038 .6038 L .49611 .60191 L F
.254 .446 .857 r
.50051 .60378 m .50051 .60386 L .50046 .60378 L F
.901 .737 .669 r
.50046 .60378 m .50051 .60386 L .50038 .6038 L F
.482 .098 .236 r
.50049 .60174 m .4974 .60287 L .50051 .60386 L F
.538 .351 .575 r
.50251 .60124 m .5002 .604 L .50049 .60174 L F
.254 .446 .857 r
.50049 .60174 m .49947 .60199 L .49769 .59894 L F
.155 0 .236 r
.41515 .63724 m .41256 .64058 L .41347 .63838 L F
.364 .559 .91 r
.76281 .38983 m .76134 .39127 L .75998 .38886 L F
.76281 .38983 m .76366 .39179 L .76134 .39127 L F
.808 .823 .862 r
.7215 .42536 m .7247 .42548 L .72359 .42389 L F
.854 .84 .831 r
.72359 .42389 m .7247 .42548 L .72714 .42248 L F
.615 .287 .391 r
.50528 .58998 m .50765 .59195 L .50352 .59208 L F
.523 .326 .554 r
.57446 .5361 m .57702 .53564 L .57701 .53312 L F
.489 .23 .447 r
.5766 .53782 m .57446 .5361 L .57483 .53877 L F
.5766 .53782 m .57702 .53564 L .57446 .5361 L F
.604 .628 .849 r
.20421 .70953 m .2009 .70714 L .20337 .70583 L F
0 0 .074 r
.20552 .70592 m .20421 .70953 L .20337 .70583 L F
.20484 .70779 m .20505 .70836 L .20421 .70953 L F
.569 .372 .575 r
.20505 .70836 m .20246 .71125 L .20421 .70953 L F
.20505 .70836 m .20499 .71119 L .20246 .71125 L F
0 0 .395 r
.20616 .70979 m .20499 .71119 L .20505 .70836 L F
.382 .498 .852 r
.2032 .7075 m .20535 .70917 L .20505 .70836 L F
.20535 .70917 m .20616 .70979 L .20505 .70836 L F
0 0 .074 r
.20552 .70592 m .20505 .70836 L .20484 .70779 L F
.882 .861 .815 r
.53296 .56513 m .5346 .5661 L .53676 .56305 L F
0 0 .36 r
.5356 .56438 m .53459 .56856 L .5346 .5661 L F
.532 .394 .639 r
.55815 .56 m .56061 .56284 L .56005 .55929 L F
.55815 .56 m .55837 .56348 L .56061 .56284 L F
.382 .432 .788 r
.21814 .67416 m .22077 .67598 L .21934 .6766 L F
.094 0 .37 r
.22021 .67829 m .21934 .6766 L .22077 .67598 L F
.786 .507 .514 r
.42152 .65212 m .42533 .65496 L .42526 .65294 L F
.782 .381 .294 r
.54184 .57939 m .54345 .57754 L .53957 .57655 L F
.182 .213 .658 r
.54345 .57754 m .54549 .58031 L .54423 .58095 L F
.754 .344 .272 r
.54184 .57939 m .54549 .58031 L .54345 .57754 L F
.871 .78 .759 r
.60899 .4888 m .60913 .48466 L .60839 .48623 L F
.956 .831 .68 r
.6068 .48996 m .60899 .4888 L .60839 .48623 L F
.6068 .48996 m .60818 .4911 L .60899 .4888 L F
.565 .287 .453 r
.61203 .42482 m .61505 .42267 L .61224 .42435 L F
.802 .556 .566 r
.64109 .40118 m .64498 .40414 L .64481 .40163 L F
.664 .502 .655 r
.64481 .40163 m .64498 .40414 L .64686 .40381 L F
.221 0 0 r
.44109 .55708 m .44149 .55723 L .44516 .55625 L F
.237 .131 .525 r
.42156 .62754 m .41917 .6292 L .41956 .62584 L F
.715 .322 .302 r
.67446 .40693 m .67674 .40797 L .67687 .40933 L F
.837 .533 .475 r
.67687 .40933 m .67367 .4059 L .67446 .40693 L F
.495 .577 .867 r
.62064 .42204 m .62139 .42385 L .6213 .42402 L F
.244 .709 .947 r
.22321 .55284 m .22135 .55208 L .21869 .55218 L F
.27 .735 .947 r
.22528 .55262 m .22135 .55208 L .22321 .55284 L F
.665 .511 .665 r
.46023 .59881 m .45776 .60164 L .45757 .59905 L F
.891 .728 .674 r
.54179 .59177 m .54319 .59568 L .54329 .59295 L F
.801 .616 .652 r
.5308 .55296 m .53415 .55109 L .53225 .54923 L F
.5308 .55296 m .53376 .55392 L .53415 .55109 L F
.773 .726 .809 r
.53622 .54854 m .53415 .55109 L .53225 .54923 L F
.119 .238 .714 r
.53415 .55109 m .53537 .54954 L .53225 .54923 L F
.53415 .55109 m .53629 .55265 L .53537 .54954 L F
.092 0 0 r
.20236 .54015 m .20669 .53938 L .20449 .53935 L F
.797 .694 .752 r
.5921 .48833 m .5885 .4877 L .59082 .48478 L F
.864 .755 .741 r
.5921 .48833 m .58838 .49027 L .5885 .4877 L F
.5921 .48833 m .59066 .49131 L .58838 .49027 L F
.533 .302 .51 r
.46303 .59594 m .46023 .59881 L .46006 .59607 L F
.376 .505 .861 r
.39944 .63685 m .40177 .64071 L .40302 .63992 L F
.619 .807 .972 r
.42521 .57107 m .42629 .57241 L .42299 .57192 L F
0 .032 .596 r
.42807 .57377 m .42629 .57241 L .42521 .57107 L F
0 0 0 r
.73284 .38466 m .73183 .38476 L .73047 .38475 L F
.73284 .38466 m .73429 .38402 L .73183 .38476 L F
.317 .257 .631 r
.25272 .55989 m .25423 .55959 L .25434 .55689 L F
.243 0 .223 r
.57288 .47333 m .57497 .47236 L .57555 .46993 L F
.256 0 .228 r
.57555 .46993 m .57713 .4713 L .57773 .46902 L F
.57555 .46993 m .57497 .47236 L .57713 .4713 L F
.738 .837 .926 r
.75089 .43383 m .75218 .43536 L .75425 .43394 L F
.063 0 0 r
.71557 .39834 m .71873 .39619 L .71749 .39755 L F
.162 0 .118 r
.71534 .40016 m .71557 .39834 L .71749 .39755 L F
.566 .656 .897 r
.20827 .69436 m .20795 .69758 L .20742 .69447 L F
.20827 .69436 m .21036 .69729 L .20795 .69758 L F
.25 .118 .499 r
.2094 .69935 m .20795 .69758 L .21036 .69729 L F
.2094 .69935 m .20791 .70028 L .20795 .69758 L F
.64 .589 .781 r
.56979 .57458 m .56781 .57816 L .56732 .57524 L F
.56979 .57458 m .5709 .5779 L .56781 .57816 L F
.717 .428 .487 r
.57123 .5805 m .56781 .57816 L .5709 .5779 L F
.57123 .5805 m .5683 .58038 L .56781 .57816 L F
.759 .83 .907 r
.52852 .54201 m .52537 .54408 L .53016 .54361 L F
.682 .352 .409 r
.52542 .54662 m .53016 .54361 L .52537 .54408 L F
.52542 .54662 m .52783 .54683 L .53016 .54361 L F
.76 .452 .464 r
.52783 .54683 m .53054 .54719 L .53016 .54361 L F
.605 .411 .593 r
.44994 .58324 m .44735 .58096 L .45002 .58077 L F
.44994 .58324 m .44736 .58361 L .44735 .58096 L F
.645 .256 .293 r
.4877 .58054 m .48663 .58264 L .48434 .58072 L F
0 0 .087 r
.4877 .58054 m .48927 .57746 L .48922 .5797 L F
.77 .652 .731 r
.48922 .5797 m .48663 .58264 L .4877 .58054 L F
.972 .799 .61 r
.45716 .59116 m .458 .59197 L .45867 .58975 L F
.582 .354 .535 r
.45867 .58975 m .458 .59197 L .46112 .58959 L F
.45867 .58975 m .458 .59197 L .46112 .58959 L F
.292 0 0 r
.19883 .55481 m .19832 .55528 L .19582 .55498 L F
.688 .867 .469 r
.19862 .55472 m .19883 .55481 L .20086 .55361 L F
.19862 .55472 m .19832 .55528 L .19883 .55481 L F
.938 .744 .615 r
.61024 .47557 m .61153 .47926 L .61181 .47656 L F
.201 0 .113 r
.15705 .57129 m .15412 .57361 L .1556 .572 L F
.249 .342 .764 r
.47429 .6012 m .47629 .60296 L .47475 .60039 L F
.445 .673 .961 r
.25856 .5413 m .25782 .54298 L .25672 .54169 L F
.25856 .5413 m .26102 .54335 L .25782 .54298 L F
.673 .45 .574 r
.59082 .48229 m .59082 .48478 L .5871 .48457 L F
.596 .245 .346 r
.69995 .40003 m .69733 .39842 L .69722 .4004 L F
.69995 .40003 m .69992 .3984 L .69733 .39842 L F
.533 .302 .51 r
.46303 .59594 m .46312 .59848 L .46023 .59881 L F
.069 0 .411 r
.46405 .5976 m .46303 .59594 L .46525 .59585 L F
.46405 .5976 m .46312 .59848 L .46303 .59594 L F
0 0 0 r
.21082 .68539 m .21228 .68193 L .21088 .68286 L F
.228 .318 .749 r
.42656 .64232 m .42761 .64009 L .42444 .64093 L F
.42656 .64232 m .42831 .64298 L .42761 .64009 L F
.27 .167 .549 r
.78857 .4065 m .78653 .41075 L .78608 .40715 L F
.78857 .4065 m .78886 .40887 L .78653 .41075 L F
.499 .492 .78 r
.78886 .40887 m .78729 .41208 L .78653 .41075 L F
0 0 .332 r
.20208 .69398 m .20336 .69654 L .20206 .69381 L F
.994 .841 .486 r
.20208 .69398 m .20041 .69905 L .20336 .69654 L F
.236 0 .185 r
.56029 .60399 m .56107 .60234 L .56318 .60147 L F
.998 .822 .479 r
.65 .41773 m .65081 .41894 L .65121 .41656 L F
.986 .901 .6 r
.65165 .40855 m .65054 .41538 L .65121 .41656 L F
.991 .858 .503 r
.65054 .41538 m .65 .41773 L .65121 .41656 L F
.119 .26 .735 r
.39403 .62561 m .39528 .62908 L .39625 .62769 L F
.339 .569 .924 r
.39528 .62908 m .39706 .62897 L .39625 .62769 L F
.373 .501 .859 r
.39528 .62908 m .39838 .63113 L .39706 .62897 L F
.766 .761 .848 r
.70456 .43195 m .70797 .43225 L .70646 .43053 L F
.755 .745 .843 r
.70646 .43053 m .70797 .43225 L .70997 .43104 L F
.709 .782 .909 r
.69793 .43365 m .70152 .43416 L .70035 .43245 L F
.729 .789 .901 r
.70035 .43245 m .70152 .43416 L .70456 .43195 L F
.305 .156 .509 r
.57701 .53312 m .57865 .53462 L .5787 .53231 L F
.57701 .53312 m .57702 .53564 L .57865 .53462 L F
.165 0 0 r
.45685 .58358 m .45911 .58327 L .45992 .58231 L F
0 0 0 r
.52731 .51342 m .53065 .51099 L .52875 .51223 L F
.256 .024 .358 r
.55698 .48536 m .55877 .48638 L .55946 .48475 L F
.55698 .48536 m .55685 .48762 L .55877 .48638 L F
.519 .234 .421 r
.5796 .48714 m .57618 .49049 L .57643 .48848 L F
.511 .3 .53 r
.43494 .61362 m .43237 .61595 L .43227 .61386 L F
.378 .355 .707 r
.38609 .61369 m .38862 .61575 L .38764 .61314 L F
.737 .689 .804 r
.27808 .54962 m .27414 .54836 L .27675 .54853 L F
.372 0 0 r
.27675 .54853 m .28032 .54957 L .27808 .54962 L F
0 0 .176 r
.67403 .44678 m .67419 .44713 L .67363 .4461 L F
.67403 .44678 m .67429 .44874 L .67419 .44713 L F
.528 .223 .393 r
.56765 .49137 m .5701 .49288 L .56758 .49306 L F
.555 .193 .308 r
.5699 .49137 m .5701 .49288 L .56765 .49137 L F
.854 .84 .831 r
.72359 .42389 m .72714 .42248 L .72765 .42073 L F
.795 .962 .917 r
.72765 .42073 m .72714 .42248 L .72898 .41904 L F
.637 .926 .658 r
.42633 .56624 m .42681 .56537 L .42855 .56413 L F
.716 .956 .677 r
.42855 .56413 m .42681 .56537 L .42868 .56312 L F
.938 .744 .615 r
.61024 .47557 m .60998 .47873 L .61153 .47926 L F
.868 .723 .7 r
.60998 .47873 m .61111 .48135 L .61153 .47926 L F
.304 0 .119 r
.39165 .60131 m .39382 .60078 L .39501 .59872 L F
.442 .043 .185 r
.39382 .60078 m .39751 .59848 L .39501 .59872 L F
0 .18 .715 r
.49622 .54242 m .49827 .5453 L .49786 .54392 L F
.745 .233 0 r
.501 .54694 m .49786 .54392 L .49827 .5453 L F
.432 .829 .982 r
.46502 .55987 m .46461 .56106 L .46274 .56067 L F
.46502 .55987 m .46711 .56055 L .46461 .56106 L F
.828 .732 .758 r
.6158 .46037 m .61769 .4617 L .61659 .45808 L F
.812 .741 .786 r
.61366 .46334 m .61769 .4617 L .6158 .46037 L F
.61366 .46334 m .61528 .46448 L .61769 .4617 L F
.985 .726 .449 r
.44266 .5749 m .4412 .57406 L .44121 .57135 L F
.44266 .5749 m .4412 .57406 L .44121 .57135 L F
.513 .288 .51 r
.44268 .57753 m .44419 .57478 L .44266 .5749 L F
.302 .106 .44 r
.58178 .527 m .57966 .53036 L .58114 .52908 L F
0 0 .011 r
.58114 .52908 m .57966 .53036 L .5787 .53231 L F
.98 .902 .57 r
.6007 .50964 m .601 .5051 L .60047 .50751 L F
.953 .946 .639 r
.59957 .51165 m .6007 .50964 L .60047 .50751 L F
.599 .786 .97 r
.53899 .54994 m .53966 .55154 L .53774 .55136 L F
.738 .595 .696 r
.53774 .55136 m .53966 .55154 L .53835 .55311 L F
.715 .192 0 r
.53899 .55246 m .53966 .55154 L .53899 .54994 L F
.53899 .55246 m .54153 .55305 L .53966 .55154 L F
.152 0 .134 r
.43357 .56267 m .43337 .56456 L .43103 .56533 L F
0 0 0 r
.43378 .56301 m .43357 .56267 L .43552 .56187 L F
.43378 .56301 m .43337 .56456 L .43357 .56267 L F
.261 .771 .819 r
.47311 .55999 m .4754 .55947 L .47688 .5594 L F
.365 .835 .856 r
.47688 .5594 m .47766 .55874 L .47901 .55958 L F
.47688 .5594 m .4754 .55947 L .47766 .55874 L F
.427 .851 .952 r
.46711 .56055 m .46941 .55992 L .47067 .56032 L F
.564 .917 .961 r
.47067 .56032 m .46941 .55992 L .47158 .55895 L F
.418 .432 .767 r
.21969 .6718 m .21814 .67416 L .21659 .67242 L F
.21969 .6718 m .22077 .67598 L .21814 .67416 L F
.275 .034 .355 r
.2464 .59257 m .24882 .58928 L .24666 .58984 L F
.927 .858 .421 r
.6568 .41626 m .65615 .41887 L .65589 .41752 L F
.777 .721 .189 r
.6568 .41626 m .6568 .41549 L .65758 .40991 L F
.827 .875 .436 r
.6568 .41626 m .65589 .41752 L .6568 .41549 L F
.586 .408 .607 r
.54572 .58287 m .54423 .58095 L .54549 .58031 L F
.54572 .58287 m .54426 .58389 L .54423 .58095 L F
.677 .149 0 r
.50225 .54803 m .5029 .54945 L .501 .54694 L F
.50225 .54803 m .50445 .55047 L .5029 .54945 L F
.746 .224 0 r
.506 .55091 m .50445 .55047 L .50225 .54803 L F
0 0 0 r
.77222 .43297 m .77247 .4329 L .7711 .43494 L F
.77159 .43494 m .7711 .43494 L .77247 .4329 L F
.77159 .43494 m .76971 .43652 L .7711 .43494 L F
.134 0 0 r
.76771 .43729 m .76701 .43734 L .76417 .43705 L F
.817 .787 .824 r
.62514 .44036 m .62252 .44308 L .62566 .44329 L F
.828 .761 .789 r
.62252 .44308 m .62339 .44642 L .62566 .44329 L F
.857 .629 .592 r
.6556 .42747 m .65513 .4243 L .6554 .42547 L F
.815 .755 .796 r
.62252 .44308 m .62033 .44578 L .62339 .44642 L F
.821 .745 .78 r
.62033 .44578 m .62115 .44946 L .62339 .44642 L F
.272 0 .124 r
.48974 .60501 m .48916 .60664 L .48674 .60725 L F
.603 .558 .777 r
.49078 .60228 m .49225 .60465 L .48974 .60501 L F
.671 .379 .469 r
.49225 .60465 m .48916 .60664 L .48974 .60501 L F
.668 .848 .969 r
.21318 .65225 m .21626 .65173 L .21573 .6513 L F
.749 .717 .823 r
.62439 .42241 m .62139 .42385 L .62064 .42204 L F
.435 .468 .796 r
.5044 .53494 m .503 .53724 L .50193 .53553 L F
.5044 .53494 m .50527 .53744 L .503 .53724 L F
.443 .35 .655 r
.45212 .61916 m .45418 .61867 L .45149 .61714 L F
.45212 .61916 m .45418 .61867 L .45149 .61714 L F
.484 .586 .881 r
.62781 .43064 m .62719 .43368 L .62556 .43103 L F
.452 .223 .475 r
.38697 .60478 m .38918 .60429 L .38948 .60192 L F
.447 .219 .474 r
.38948 .60192 m .39139 .60368 L .39165 .60131 L F
.38948 .60192 m .38918 .60429 L .39139 .60368 L F
.183 0 0 r
.2085 .53894 m .21286 .53926 L .21066 .53953 L F
.111 0 0 r
.15204 .5563 m .1538 .55571 L .15477 .55431 L F
.421 .072 .265 r
.1538 .55571 m .15678 .55369 L .15477 .55431 L F
.683 .622 .781 r
.62068 .43659 m .6183 .43756 L .61708 .43391 L F
.554 .324 .521 r
.44386 .59559 m .44652 .5955 L .44653 .5929 L F
.725 .462 .53 r
.44653 .5929 m .44974 .59516 L .4495 .59293 L F
.44653 .5929 m .44652 .5955 L .44974 .59516 L F
.794 .84 .886 r
.68889 .43908 m .69313 .43755 L .69172 .43609 L F
.781 .81 .875 r
.69172 .43609 m .69313 .43755 L .69591 .43507 L F
.916 .914 .801 r
.68038 .44436 m .6806 .44688 L .6816 .44525 L F
.905 .79 .723 r
.67821 .44752 m .6806 .44688 L .68038 .44436 L F
.67821 .44752 m .67959 .449 L .6806 .44688 L F
.249 0 0 r
.71563 .39044 m .71365 .39 L .71358 .39165 L F
.71563 .39044 m .71641 .38895 L .71365 .39 L F
.291 0 .166 r
.2454 .63644 m .24431 .63549 L .24635 .63473 L F
.2454 .63644 m .24338 .63702 L .24431 .63549 L F
0 .22 .645 r
.5092 .55292 m .50857 .55245 L .506 .55091 L F
.50991 .55337 m .50857 .55245 L .5092 .55292 L F
0 .298 .732 r
.50857 .55245 m .50845 .55204 L .50782 .55189 L F
0 .279 .647 r
.50857 .55245 m .50445 .55047 L .506 .55091 L F
0 .298 .732 r
.50857 .55245 m .50782 .55189 L .50703 .5517 L F
.319 .115 .438 r
.38712 .60716 m .38918 .60429 L .38697 .60478 L F
.904 .932 .821 r
.76659 .43153 m .76443 .43447 L .76358 .43329 L F
.999 .797 .488 r
.76443 .43447 m .76314 .43574 L .76358 .43329 L F
.76443 .43447 m .76417 .43705 L .76314 .43574 L F
.602 .441 .635 r
.42677 .57934 m .42395 .58258 L .42501 .5805 L F
0 0 .422 r
.51261 .58562 m .51422 .58935 L .51386 .58687 L F
.286 0 0 r
.64596 .42707 m .64385 .42631 L .64437 .42785 L F
.455 .257 .522 r
.2326 .61318 m .23503 .6103 L .23342 .61137 L F
.302 .078 .399 r
.45685 .58358 m .45861 .58544 L .45911 .58327 L F
.368 .099 .368 r
.45911 .58327 m .45861 .58544 L .46078 .58465 L F
.547 .527 .785 r
.46078 .58465 m .45861 .58544 L .4568 .58174 L F
.069 0 0 r
.46078 .58465 m .4603 .58474 L .45861 .58544 L F
.302 .078 .399 r
.45685 .58358 m .45675 .58621 L .45861 .58544 L F
.775 .545 .586 r
.45861 .58544 m .45474 .58218 L .4568 .58174 L F
.45861 .58544 m .45477 .58541 L .45474 .58218 L F
.069 0 0 r
.4603 .58474 m .45714 .58532 L .45861 .58544 L F
.302 .078 .399 r
.45675 .58621 m .45675 .58645 L .45861 .58544 L F
.047 0 0 r
.17761 .54501 m .1778 .54612 L .17993 .5447 L F
.17761 .54501 m .17586 .54689 L .1778 .54612 L F
.113 0 0 r
.15175 .55673 m .1538 .55571 L .15204 .5563 L F
.372 .035 .259 r
.43922 .58725 m .43852 .58884 L .43623 .58938 L F
.45 .139 .347 r
.44127 .58663 m .43852 .58884 L .43922 .58725 L F
.071 0 0 r
.71885 .38838 m .71961 .38713 L .71641 .38895 L F
.128 0 .121 r
.24067 .63987 m .23894 .64067 L .24166 .63794 L F
.335 .054 .329 r
.24338 .63702 m .24067 .63987 L .24166 .63794 L F
.658 .368 .468 r
.44419 .57478 m .4483 .57684 L .44872 .57519 L F
.465 .099 .259 r
.44872 .57519 m .4483 .57684 L .45122 .57617 L F
.467 .092 .245 r
.44872 .57519 m .45122 .57617 L .45113 .57494 L F
.033 0 0 r
.55541 .60737 m .55849 .60516 L .55741 .60641 L F
.151 0 .076 r
.56029 .60399 m .55741 .60641 L .55849 .60516 L F
.815 .741 .783 r
.61946 .44846 m .62115 .44946 L .62033 .44578 L F
.873 .718 .687 r
.61946 .44846 m .62063 .45166 L .62115 .44946 L F
.795 .814 .867 r
.7013 .42356 m .70259 .42507 L .69935 .42507 L F
.77 .809 .884 r
.70553 .42251 m .70259 .42507 L .7013 .42356 L F
.813 .653 .684 r
.61142 .46643 m .61528 .46448 L .61366 .46334 L F
.61142 .46643 m .61492 .4668 L .61528 .46448 L F
.904 .932 .821 r
.76659 .43153 m .76358 .43329 L .76559 .43035 L F
.901 .913 .821 r
.76789 .42722 m .76659 .43153 L .76559 .43035 L F
.76789 .42722 m .76888 .42839 L .76659 .43153 L F
.985 .878 .526 r
.76818 .41994 m .76936 .4192 L .76861 .42268 L F
.76818 .41994 m .76881 .41814 L .76936 .4192 L F
.521 .781 .992 r
.45446 .65896 m .45715 .65829 L .45334 .65776 L F
.88 .608 .523 r
.42415 .63766 m .42163 .63932 L .42293 .63645 L F
.42415 .63766 m .42444 .64093 L .42163 .63932 L F
.543 .494 .751 r
.78979 .41238 m .78789 .41607 L .78729 .41208 L F
.78979 .41238 m .78972 .41413 L .78789 .41607 L F
.394 .156 .431 r
.78972 .41413 m .7868 .41792 L .78789 .41607 L F
.8 .718 .774 r
.49447 .58378 m .49043 .58314 L .49279 .58014 L F
.641 .337 .44 r
.49427 .58649 m .49043 .58314 L .49447 .58378 L F
.568 .606 .851 r
.49678 .58306 m .49447 .58378 L .49279 .58014 L F
.563 .41 .632 r
.49427 .58649 m .49678 .58306 L .49447 .58378 L F
.49427 .58649 m .49678 .58306 L .49447 .58378 L F
.527 .444 .705 r
.78759 .40057 m .78799 .4041 L .7855 .40474 L F
.537 .465 .722 r
.78799 .4041 m .78608 .40715 L .7855 .40474 L F
.52 .527 .803 r
.28279 .57736 m .28407 .58038 L .28194 .58076 L F
.533 .283 .482 r
.2843 .5828 m .28194 .58076 L .28407 .58038 L F
.2843 .5828 m .28176 .58332 L .28194 .58076 L F
.393 .709 .986 r
.26916 .54519 m .26878 .54664 L .26643 .54489 L F
.26916 .54519 m .27065 .54645 L .26878 .54664 L F
.183 .266 .716 r
.28207 .57664 m .28161 .57706 L .28067 .57591 L F
.805 .827 .868 r
.6816 .44525 m .68297 .44153 L .68038 .44436 L F
.6816 .44525 m .68437 .44275 L .68297 .44153 L F
.574 .733 .95 r
.21594 .6639 m .21694 .66141 L .21369 .66312 L F
.21594 .6639 m .21705 .66365 L .21694 .66141 L F
.533 .445 .702 r
.42439 .56736 m .42681 .56537 L .42633 .56624 L F
.712 .976 .919 r
.75748 .39199 m .75547 .39351 L .75379 .39338 L F
.224 .671 .953 r
.19172 .73248 m .19303 .73337 L .19127 .7332 L F
.19172 .73248 m .19347 .73339 L .19303 .73337 L F
.396 0 .014 r
.19303 .73337 m .1896 .73557 L .19009 .7331 L F
.19303 .73337 m .19165 .73516 L .1896 .73557 L F
.526 .612 .881 r
.19411 .73019 m .19347 .73339 L .19172 .73248 L F
.702 .973 .758 r
.19411 .73019 m .19172 .73248 L .19244 .73117 L F
.546 .536 .795 r
.19165 .73516 m .19238 .73142 L .19172 .73248 L F
.19238 .73142 m .19244 .73117 L .19172 .73248 L F
.224 .671 .953 r
.19172 .73248 m .19127 .7332 L .19009 .7331 L F
.396 0 .014 r
.19303 .73337 m .19347 .73339 L .19165 .73516 L F
.721 .778 .897 r
.70646 .43053 m .70997 .43104 L .70878 .42985 L F
.72 .778 .898 r
.70878 .42985 m .70997 .43104 L .71298 .42902 L F
0 .285 .699 r
.50991 .55337 m .51097 .55392 L .50857 .55245 L F
.29 .223 .607 r
.46921 .59113 m .4672 .59245 L .46736 .59116 L F
.46832 .59015 m .46736 .59116 L .46758 .58934 L F
.46921 .59113 m .46736 .59116 L .46832 .59015 L F
.449 .32 .612 r
.46962 .58637 m .46758 .58934 L .46711 .58723 L F
.46962 .58637 m .46947 .58905 L .46758 .58934 L F
.29 .223 .607 r
.46957 .59153 m .46758 .58934 L .46947 .58905 L F
.996 .791 .509 r
.46851 .58721 m .46775 .59022 L .46918 .58924 L F
.46917 .58847 m .46918 .58924 L .46947 .58905 L F
.46851 .58721 m .46918 .58924 L .46917 .58847 L F
0 0 0 r
.46947 .58905 m .47209 .58577 L .46962 .58637 L F
.759 .65 .741 r
.47209 .58577 m .46947 .58905 L .46962 .58637 L F
.605 .912 .648 r
.47006 .58832 m .46775 .59022 L .47066 .58758 L F
.46947 .58905 m .46918 .58924 L .47006 .58832 L F
.46918 .58924 m .46775 .59022 L .47006 .58832 L F
.29 .223 .607 r
.46957 .59153 m .46922 .59166 L .46921 .59113 L F
.46922 .59166 m .4672 .59245 L .46921 .59113 L F
.059 0 .051 r
.46693 .59402 m .4672 .59245 L .46957 .59153 L F
.994 .787 .518 r
.66187 .42601 m .66266 .42564 L .66098 .42587 L F
.703 .708 .179 r
.66317 .42335 m .66266 .42564 L .66406 .41974 L F
.852 .997 .81 r
.66098 .42587 m .66266 .42564 L .66317 .42335 L F
.66 .714 .888 r
.72255 .4179 m .71974 .41868 L .71866 .41586 L F
.707 .839 .946 r
.65631 .43038 m .65758 .43178 L .65951 .43052 L F
.139 0 .114 r
.56483 .47901 m .56683 .47815 L .56758 .47634 L F
.417 .128 .364 r
.56683 .47815 m .56968 .47531 L .56758 .47634 L F
.202 .671 .939 r
.24104 .53914 m .24306 .5392 L .24496 .54003 L F
.005 .572 .791 r
.24306 .5392 m .2475 .53981 L .24496 .54003 L F
.509 .895 .954 r
.21381 .65115 m .21318 .65225 L .21573 .6513 L F
.462 .602 .904 r
.49366 .56399 m .4932 .5663 L .49264 .5651 L F
.49366 .56399 m .49653 .5672 L .4932 .5663 L F
.785 .755 .826 r
.71157 .42034 m .70734 .42142 L .71022 .41886 L F
.783 .822 .883 r
.71357 .41886 m .71157 .42034 L .71022 .41886 L F
0 0 0 r
.18024 .56019 m .17572 .56105 L .17779 .55981 L F
.228 .647 .957 r
.41907 .65478 m .42319 .65631 L .42192 .65514 L F
.451 0 0 r
.42319 .65631 m .42533 .65496 L .42192 .65514 L F
0 .262 .709 r
.42658 .65858 m .42604 .65798 L .42319 .65631 L F
.451 0 0 r
.42319 .65631 m .42604 .65798 L .42348 .65686 L F
.42319 .65631 m .42348 .65686 L .42533 .65496 L F
.689 .431 0 r
.53213 .56157 m .53296 .56513 L .53254 .56334 L F
.602 .407 .589 r
.70583 .39512 m .70827 .39497 L .70817 .3925 L F
.591 .319 .474 r
.71075 .39425 m .70817 .3925 L .70827 .39497 L F
.71075 .39425 m .71089 .39216 L .70817 .3925 L F
.916 .723 .626 r
.59066 .49131 m .58812 .49281 L .58838 .49027 L F
.59066 .49131 m .59009 .49376 L .58812 .49281 L F
.858 .983 .853 r
.21592 .65726 m .21526 .65456 L .21698 .65545 L F
.21592 .65726 m .21544 .65578 L .21526 .65456 L F
.21592 .65726 m .21395 .65804 L .21544 .65578 L F
.508 .848 .996 r
.18258 .65326 m .1832 .65217 L .18123 .65169 L F
.18258 .65326 m .18491 .65277 L .1832 .65217 L F
.537 .465 .722 r
.78799 .4041 m .78857 .4065 L .78608 .40715 L F
.211 .735 .753 r
.1859 .55874 m .18231 .55947 L .18383 .55969 L F
.722 .509 .601 r
.49316 .57739 m .48915 .57478 L .4917 .57597 L F
.49316 .57739 m .48927 .57746 L .48915 .57478 L F
.96 .938 .626 r
.53285 .53018 m .53131 .53153 L .5319 .53253 L F
.994 .802 .541 r
.53159 .52897 m .53131 .53153 L .53285 .53018 L F
.438 .207 .465 r
.40872 .60697 m .40893 .60817 L .41122 .60728 L F
.40872 .60697 m .40893 .60817 L .41122 .60728 L F
.52 .28 .491 r
.47572 .59844 m .47829 .59795 L .47831 .59573 L F
.535 .307 .516 r
.47829 .59795 m .47871 .59454 L .47831 .59573 L F
.873 .784 .759 r
.18789 .7145 m .19081 .71543 L .19062 .71247 L F
.439 .099 .291 r
.24067 .63987 m .23727 .64273 L .23894 .64067 L F
.718 .985 .891 r
.66742 .44135 m .66619 .44329 L .66558 .44277 L F
.66558 .44277 m .66619 .44329 L .66742 .44135 L F
.977 .861 .656 r
.76125 .42462 m .76181 .42267 L .76075 .42147 L F
.525 .316 .539 r
.46023 .59881 m .46023 .60134 L .45776 .60164 L F
.45 .257 .527 r
.46249 .60064 m .46023 .59881 L .46312 .59848 L F
.46249 .60064 m .46023 .60134 L .46023 .59881 L F
.342 .474 .848 r
.64245 .40935 m .64195 .4104 L .64055 .40588 L F
.615 .207 .245 r
.65463 .40353 m .65712 .40168 L .65563 .40484 L F
.65463 .40353 m .65687 .40452 L .65712 .40168 L F
0 0 .074 r
.65712 .40168 m .6584 .40037 L .65947 .40097 L F
.65712 .40168 m .65687 .40452 L .6584 .40037 L F
.508 .464 .743 r
.44793 .60346 m .44885 .6071 L .44663 .60769 L F
.594 .382 .562 r
.44885 .6071 m .44638 .60948 L .44663 .60769 L F
.308 0 .084 r
.53835 .55311 m .53414 .55605 L .53629 .55265 L F
.53835 .55311 m .53671 .55561 L .53414 .55605 L F
0 .527 .764 r
.25103 .54095 m .2531 .54126 L .25491 .54166 L F
.24 .66 .96 r
.25529 .54074 m .25491 .54166 L .2531 .54126 L F
.25529 .54074 m .25672 .54169 L .25491 .54166 L F
.447 .354 .657 r
.43396 .63783 m .43237 .64 L .43611 .63661 L F
0 0 0 r
.55541 .60737 m .55409 .6087 L .55208 .6099 L F
.334 0 .048 r
.55741 .60641 m .55409 .6087 L .55541 .60737 L F
.599 .786 .97 r
.53899 .54994 m .53774 .55136 L .53622 .54854 L F
.343 .801 .68 r
.2055 .69225 m .20206 .69381 L .20452 .69315 L F
.051 .3 .788 r
.20827 .69436 m .20742 .69447 L .2055 .69225 L F
.66 .131 0 r
.20452 .69315 m .20827 .69436 L .2055 .69225 L F
.685 .478 .601 r
.62341 .42838 m .62239 .42992 L .6229 .42851 L F
.201 .725 .85 r
.21286 .53926 m .21496 .53903 L .21669 .53914 L F
.132 .673 .836 r
.21496 .53903 m .21885 .53918 L .21669 .53914 L F
.777 .922 .933 r
.20337 .70583 m .19922 .70658 L .20104 .70498 L F
.20337 .70583 m .2009 .70714 L .19922 .70658 L F
.815 .901 .902 r
.20337 .70583 m .20104 .70498 L .2034 .70352 L F
.723 .278 .193 r
.20452 .70345 m .20458 .70345 L .20471 .70325 L F
.815 .901 .902 r
.20452 .70345 m .2034 .70352 L .20474 .70315 L F
.723 .278 .193 r
.20335 .70473 m .20452 .70345 L .20561 .70177 L F
.20452 .70345 m .20471 .70325 L .20474 .70315 L F
.815 .901 .902 r
.20458 .70345 m .20474 .70315 L .20471 .70325 L F
.20474 .70315 m .20507 .7025 L .20471 .70325 L F
.723 .278 .193 r
.20474 .70315 m .20471 .70325 L .20498 .70281 L F
.20452 .70345 m .20498 .70281 L .20561 .70177 L F
.815 .901 .902 r
.20474 .70315 m .2034 .70352 L .20507 .7025 L F
.20458 .70345 m .20452 .70345 L .20474 .70315 L F
.20337 .70583 m .2034 .70352 L .20458 .70345 L F
.723 .278 .193 r
.20335 .70473 m .20375 .70479 L .20458 .70345 L F
.20335 .70473 m .20458 .70345 L .20452 .70345 L F
.815 .901 .902 r
.20337 .70583 m .20458 .70345 L .20471 .70325 L F
.482 .431 .723 r
.20471 .70325 m .20552 .70592 L .20337 .70583 L F
.44 .404 .722 r
.20724 .70527 m .20552 .70592 L .20471 .70325 L F
.723 .278 .193 r
.20375 .70479 m .20724 .70527 L .20471 .70325 L F
.342 .117 .42 r
.27755 .5897 m .27712 .59209 L .27521 .59275 L F
.505 .343 .595 r
.27746 .5949 m .27521 .59275 L .27712 .59209 L F
.27746 .5949 m .27518 .59547 L .27521 .59275 L F
.479 .465 .764 r
.47009 .57939 m .47171 .58348 L .46939 .58386 L F
.74 .457 .502 r
.47171 .58348 m .46962 .58637 L .46939 .58386 L F
.562 .335 .529 r
.5769 .56283 m .57673 .56524 L .57437 .56561 L F
.369 .158 .457 r
.57911 .55971 m .57872 .56206 L .5769 .56283 L F
.302 .096 .425 r
.57872 .56206 m .57673 .56524 L .5769 .56283 L F
.665 .235 .217 r
.4452 .58681 m .44369 .58859 L .44127 .58663 L F
.521 .378 .627 r
.44751 .58624 m .4452 .58681 L .44736 .58361 L F
.542 .092 .132 r
.44628 .58813 m .4452 .58681 L .44751 .58624 L F
.44628 .58813 m .44369 .58859 L .4452 .58681 L F
.348 .798 .95 r
.22923 .55264 m .22748 .55223 L .22528 .55262 L F
.223 .714 .922 r
.23135 .55268 m .22748 .55223 L .22923 .55264 L F
.35 0 .119 r
.58797 .46015 m .59046 .4596 L .59122 .45764 L F
.318 .12 .447 r
.59122 .45764 m .59355 .45714 L .5933 .45438 L F
.484 .065 .169 r
.59122 .45764 m .59316 .45928 L .59355 .45714 L F
.59122 .45764 m .59046 .4596 L .59316 .45928 L F
0 .342 .767 r
.48745 .56125 m .48724 .56159 L .48518 .55998 L F
.48745 .56125 m .48878 .56232 L .48724 .56159 L F
.864 .883 .849 r
.73839 .4207 m .7393 .42213 L .73691 .42478 L F
.73839 .4207 m .73691 .42478 L .73884 .42529 L F
.378 .432 .79 r
.73691 .42478 m .73966 .42656 L .73884 .42529 L F
.516 .415 .679 r
.73691 .42478 m .73742 .42709 L .73966 .42656 L F
.772 .558 .609 r
.43116 .65838 m .43492 .65552 L .43267 .65576 L F
.43116 .65838 m .43472 .65871 L .43492 .65552 L F
.43 .42 .747 r
.25648 .56546 m .25746 .56882 L .25907 .56764 L F
.12 0 .188 r
.25652 .57078 m .25907 .56764 L .25746 .56882 L F
.967 .654 .368 r
.54782 .56416 m .54932 .56528 L .549 .56288 L F
.549 .56288 m .54932 .56528 L .54782 .56416 L F
.394 .207 .505 r
.24005 .60179 m .24161 .60365 L .24157 .60107 L F
.24005 .60179 m .23976 .60435 L .24161 .60365 L F
0 0 .176 r
.58744 .54355 m .58593 .54504 L .58742 .54157 L F
0 0 .173 r
.58542 .54729 m .58593 .54504 L .58744 .54355 L F
.865 .46 .264 r
.62697 .41802 m .62919 .41917 L .62675 .41985 L F
.514 .173 .327 r
.45776 .60164 m .45978 .60325 L .45731 .60362 L F
.482 .184 .384 r
.46023 .60134 m .45978 .60325 L .45776 .60164 L F
.851 .616 .583 r
.68274 .40781 m .68435 .41018 L .6824 .4098 L F
.844 .548 .488 r
.6824 .4098 m .68435 .41018 L .68294 .41264 L F
.61 .261 .354 r
.68294 .41264 m .68435 .41018 L .68676 .412 L F
.661 .163 .055 r
.68435 .41018 m .68639 .41091 L .68676 .412 L F
.48 .385 .67 r
.28207 .55743 m .28052 .56263 L .28018 .56033 L F
.858 .997 .794 r
.42658 .65858 m .42457 .65918 L .42604 .65798 L F
.296 0 .09 r
.42877 .65847 m .42712 .6592 L .42658 .65858 L F
.42877 .65847 m .42658 .65858 L .42457 .65918 L F
.091 .335 .809 r
.25616 .56291 m .25669 .5614 L .25423 .55959 L F
.073 .314 .795 r
.25616 .56291 m .25851 .56478 L .25669 .5614 L F
.436 .364 .677 r
.25648 .56546 m .25851 .56478 L .25616 .56291 L F
.488 .132 .288 r
.62197 .41543 m .62431 .41516 L .62522 .41318 L F
.447 .255 .526 r
.62522 .41318 m .62791 .41274 L .6276 .40999 L F
.694 .533 .665 r
.62431 .41516 m .62791 .41274 L .62522 .41318 L F
.451 .192 .429 r
.26152 .61655 m .26106 .61879 L .25894 .61929 L F
.322 .129 .456 r
.26373 .61345 m .26334 .61582 L .26152 .61655 L F
.449 .247 .513 r
.26334 .61582 m .26106 .61879 L .26152 .61655 L F
.444 .461 .783 r
.20257 .68898 m .20503 .69063 L .20449 .68846 L F
.382 .272 .603 r
.57033 .59207 m .57068 .5951 L .56832 .59552 L F
.182 0 .379 r
.56993 .59686 m .56832 .59552 L .57068 .5951 L F
.56993 .59686 m .56843 .59826 L .56832 .59552 L F
.636 .278 .347 r
.48466 .6036 m .48582 .60174 L .48444 .60078 L F
.48466 .6036 m .48816 .60373 L .48582 .60174 L F
.64 .276 .337 r
.48582 .60174 m .48816 .60373 L .4886 .60213 L F
.138 .251 .719 r
.76606 .39372 m .7646 .39543 L .76366 .39179 L F
0 0 .214 r
.76509 .39725 m .7646 .39543 L .76606 .39372 L F
.76509 .39725 m .76486 .39776 L .7646 .39543 L F
0 0 .352 r
.55897 .59154 m .55981 .59191 L .56004 .58921 L F
.249 .211 .619 r
.55845 .59358 m .55981 .59191 L .55897 .59154 L F
.49 .084 .197 r
.68781 .40329 m .69137 .40121 L .68786 .40166 L F
.68781 .40329 m .69064 .40311 L .69137 .40121 L F
.41 0 0 r
.69319 .40232 m .69137 .40121 L .69064 .40311 L F
.69319 .40232 m .6938 .40159 L .69137 .40121 L F
.752 .988 .774 r
.75635 .40097 m .75333 .40405 L .75355 .40299 L F
.774 .891 .481 r
.75355 .40299 m .75333 .40405 L .75247 .40492 L F
.488 .353 .623 r
.5933 .45438 m .59563 .45142 L .59329 .45213 L F
.458 0 0 r
.56814 .49493 m .56504 .49413 L .56758 .49306 L F
.56814 .49493 m .56399 .49536 L .56504 .49413 L F
.098 0 0 r
.71885 .38838 m .71641 .38895 L .71563 .39044 L F
.612 .456 .646 r
.56 .55687 m .56258 .55658 L .56246 .55373 L F
.577 .363 .554 r
.56005 .55929 m .56258 .55658 L .56 .55687 L F
.977 .906 .673 r
.76223 .41587 m .76313 .41371 L .76139 .41461 L F
.979 .9 .667 r
.76139 .41461 m .76313 .41371 L .76227 .41247 L F
.873 .718 .687 r
.61946 .44846 m .61753 .45146 L .62063 .45166 L F
.87 .743 .719 r
.61753 .45146 m .61873 .45499 L .62063 .45166 L F
.852 .394 .08 r
.51383 .5567 m .51204 .55585 L .51097 .55392 L F
0 .419 .853 r
.51644 .55868 m .51204 .55585 L .51383 .5567 L F
.48 .049 .143 r
.62534 .42719 m .6251 .4272 L .62465 .42761 L F
.62813 .42547 m .6251 .4272 L .62534 .42719 L F
.784 .5 .506 r
.62309 .42604 m .62483 .42721 L .6251 .4272 L F
.48 .049 .143 r
.62813 .42547 m .62608 .42801 L .6251 .4272 L F
.62465 .42761 m .6251 .4272 L .62341 .42838 L F
.354 .393 .763 r
.62615 .42798 m .62341 .42838 L .6251 .4272 L F
.62754 .42902 m .62566 .42873 L .62615 .42798 L F
.62566 .42873 m .62341 .42838 L .62615 .42798 L F
.662 .872 .495 r
.6293 .42352 m .62707 .42659 L .62813 .42547 L F
.48 .049 .143 r
.62608 .42801 m .62566 .42853 L .6251 .4272 L F
.784 .5 .506 r
.62558 .42771 m .62604 .42802 L .6251 .4272 L F
.62604 .42802 m .62629 .42819 L .62608 .42801 L F
.62604 .42802 m .62608 .42801 L .6251 .4272 L F
.662 .872 .495 r
.62707 .42659 m .62602 .42803 L .62638 .42764 L F
.784 .5 .506 r
.62309 .42604 m .62335 .42845 L .62549 .42874 L F
.662 .872 .495 r
.62604 .42802 m .62566 .42853 L .62608 .42801 L F
.62572 .42844 m .62566 .42853 L .62604 .42802 L F
.784 .5 .506 r
.62604 .42802 m .62549 .42874 L .62754 .42902 L F
0 0 .327 r
.6251 .4272 m .62566 .42853 L .62566 .42841 L F
.784 .5 .506 r
.62558 .42771 m .62566 .42841 L .62604 .42802 L F
.749 .576 .66 r
.62566 .42841 m .62566 .42853 L .62572 .42844 L F
.784 .5 .506 r
.62566 .42841 m .62567 .42851 L .62572 .42844 L F
.62566 .42841 m .62572 .42844 L .62604 .42802 L F
.62629 .42819 m .62754 .42902 L .6251 .4272 L F
.749 .576 .66 r
.6256 .42289 m .62566 .42841 L .6293 .42352 L F
.62566 .42841 m .62572 .42844 L .6293 .42352 L F
0 0 .327 r
.62558 .42771 m .62566 .42841 L .62565 .42778 L F
.6251 .4272 m .62566 .42841 L .62558 .42771 L F
.784 .5 .506 r
.62309 .42604 m .62549 .42874 L .62567 .42851 L F
.62309 .42604 m .62567 .42851 L .62558 .42771 L F
.662 .872 .495 r
.62602 .42803 m .62572 .42844 L .62604 .42802 L F
.62602 .42803 m .62608 .42801 L .62638 .42764 L F
.62707 .42659 m .62638 .42764 L .62813 .42547 L F
0 0 .327 r
.6251 .4272 m .62565 .42778 L .62564 .42669 L F
.784 .5 .506 r
.62483 .42721 m .62558 .42771 L .6251 .4272 L F
0 0 .327 r
.6251 .4272 m .62564 .42669 L .6256 .42289 L F
.723 .982 .908 r
.6293 .42352 m .62813 .42547 L .63019 .42383 L F
.441 .253 .528 r
.27069 .60421 m .26849 .60726 L .26864 .6049 L F
.588 .228 .326 r
.68639 .41091 m .69021 .41022 L .68901 .41245 L F
.572 .162 .226 r
.69021 .41022 m .6929 .41177 L .68901 .41245 L F
.69021 .41022 m .69272 .41039 L .6929 .41177 L F
.995 .755 .412 r
.77894 .44623 m .77763 .44662 L .77819 .44471 L F
.531 .673 .928 r
.78114 .4444 m .77894 .44623 L .77819 .44471 L F
.559 .923 .755 r
.78114 .4444 m .77763 .44662 L .77894 .44623 L F
.323 .249 .617 r
.5022 .59568 m .50303 .59459 L .50424 .59391 L F
0 .139 .644 r
.5022 .59568 m .50398 .59676 L .50424 .59391 L F
.19 0 .212 r
.43852 .58884 m .4359 .59189 L .43623 .58938 L F
.802 .556 .566 r
.64109 .40118 m .64112 .40361 L .64498 .40414 L F
.785 .709 .78 r
.64112 .40361 m .64225 .40586 L .64498 .40414 L F
.635 .392 .533 r
.64498 .40414 m .64864 .40675 L .64686 .40381 L F
0 .034 .586 r
.42074 .62974 m .41917 .6292 L .42156 .62754 L F
.797 .867 .9 r
.74076 .42068 m .7393 .42213 L .73839 .4207 L F
.72 .187 0 r
.66423 .44267 m .66277 .43991 L .66054 .44039 L F
.66472 .44297 m .66457 .44273 L .66423 .44267 L F
.66457 .44273 m .66277 .43991 L .66423 .44267 L F
.6 .939 .758 r
.6649 .4432 m .66742 .44135 L .66648 .44273 L F
0 0 0 r
.66243 .44398 m .66558 .44277 L .66402 .44346 L F
.6 .939 .758 r
.66402 .44346 m .66558 .44277 L .66502 .44289 L F
.66402 .44346 m .6649 .44291 L .6649 .4432 L F
.72 .187 0 r
.66483 .44304 m .66558 .44277 L .66477 .44294 L F
.6 .939 .758 r
.66502 .44289 m .66558 .44277 L .66657 .442 L F
.66531 .44266 m .66657 .442 L .66742 .44135 L F
.72 .187 0 r
.6649 .44275 m .66558 .44277 L .66491 .44209 L F
.6 .939 .758 r
.66402 .44346 m .66657 .442 L .66531 .44266 L F
.548 .904 .698 r
.66742 .44135 m .66558 .44277 L .6649 .44301 L F
.6 .939 .758 r
.6649 .44291 m .66742 .44135 L .6649 .44301 L F
.548 .904 .698 r
.66742 .44135 m .6649 .44301 L .66483 .44304 L F
.6 .939 .758 r
.6649 .44301 m .66742 .44135 L .6649 .4432 L F
.72 .187 0 r
.66464 .44274 m .6649 .44275 L .66285 .43999 L F
.6649 .44275 m .66491 .44209 L .66285 .43999 L F
.66477 .44294 m .66488 .44292 L .66464 .44274 L F
.66488 .44292 m .66558 .44277 L .66464 .44274 L F
.66463 .44274 m .66285 .43999 L .66283 .44 L F
.66477 .44294 m .66464 .44274 L .66463 .44274 L F
.66464 .44274 m .66285 .43999 L .66463 .44274 L F
.66483 .44304 m .66477 .44294 L .66472 .44297 L F
.66477 .44294 m .66277 .43991 L .66472 .44297 L F
.285 .361 .766 r
.66342 .44017 m .66483 .44304 L .66423 .44267 L F
.66342 .44017 m .66423 .44267 L .66054 .44039 L F
.572 .489 .723 r
.66233 .44232 m .6628 .44141 L .6608 .44205 L F
.6628 .44141 m .66342 .44017 L .66225 .44102 L F
.6628 .44141 m .66225 .44102 L .6608 .44205 L F
.6608 .44205 m .66225 .44102 L .6603 .44059 L F
.66225 .44102 m .66342 .44017 L .66145 .44044 L F
.66225 .44102 m .66145 .44044 L .6603 .44059 L F
.66148 .444 m .66233 .44232 L .6608 .44205 L F
.285 .361 .766 r
.66145 .44044 m .66054 .44039 L .6603 .44059 L F
.66342 .44017 m .66193 .44028 L .66145 .44044 L F
.66193 .44028 m .66054 .44039 L .66145 .44044 L F
.72 .187 0 r
.66283 .44 m .66285 .43999 L .66277 .43991 L F
.396 .088 .322 r
.56198 .48123 m .56457 .4808 L .56483 .47901 L F
.536 .34 .562 r
.56457 .4808 m .56683 .47815 L .56483 .47901 L F
.862 .9 .484 r
.58311 .52348 m .58178 .527 L .58198 .52508 L F
.814 .805 .315 r
.58198 .52508 m .58178 .527 L .58114 .52908 L F
.375 .157 .45 r
.23841 .6051 m .23936 .60682 L .23976 .60435 L F
.23841 .6051 m .2376 .60801 L .23936 .60682 L F
.773 .726 .809 r
.53622 .54854 m .53225 .54923 L .53559 .547 L F
.594 .072 0 r
.53537 .54954 m .53622 .54854 L .53559 .547 L F
.53537 .54954 m .53899 .54994 L .53622 .54854 L F
.64 .33 .43 r
.68165 .40348 m .68534 .40118 L .68159 .40112 L F
.68165 .40348 m .68435 .40368 L .68534 .40118 L F
.655 .346 .437 r
.68435 .40368 m .68781 .40329 L .68534 .40118 L F
.685 .327 .36 r
.68781 .40329 m .68786 .40166 L .68534 .40118 L F
.331 .815 .852 r
.21963 .55148 m .21869 .55218 L .22135 .55208 L F
.21963 .55148 m .21738 .55211 L .21869 .55218 L F
.321 .015 .281 r
.41281 .58324 m .41445 .5852 L .41485 .58124 L F
.252 .066 .423 r
.41485 .58124 m .41719 .57913 L .4153 .58012 L F
.41485 .58124 m .41719 .58247 L .41719 .57913 L F
.163 0 .254 r
.41485 .58124 m .41626 .58393 L .41719 .58247 L F
.41485 .58124 m .41445 .5852 L .41626 .58393 L F
.393 .707 .985 r
.1895 .63298 m .18812 .63329 L .18571 .63166 L F
.533 .457 .716 r
.55876 .56578 m .5589 .57039 L .56195 .56806 L F
.317 .14 .477 r
.55938 .57118 m .56195 .56806 L .5589 .57039 L F
.062 .004 .471 r
.57146 .58645 m .57167 .58891 L .57056 .58971 L F
.308 .196 .559 r
.57167 .58891 m .57033 .59207 L .57056 .58971 L F
.376 .544 .894 r
.67429 .44874 m .67641 .44889 L .67419 .44713 L F
.603 .251 .346 r
.69995 .40003 m .70252 .40011 L .69992 .3984 L F
.553 .296 .481 r
.70252 .40011 m .70255 .39799 L .69992 .3984 L F
.518 .279 .492 r
.57437 .56561 m .57159 .5687 L .57112 .56568 L F
.72 .684 .815 r
.56923 .5819 m .56886 .5848 L .56616 .58619 L F
.809 .686 .728 r
.61142 .46643 m .61283 .47012 L .61492 .4668 L F
0 0 0 r
.66796 .40035 m .67166 .39882 L .66965 .40121 L F
.66796 .40035 m .67094 .39927 L .67166 .39882 L F
.67094 .39927 m .67113 .3992 L .67118 .39916 L F
.67094 .39927 m .67118 .39916 L .67166 .39882 L F
.863 .566 .484 r
.67196 .39882 m .67143 .40158 L .67429 .40243 L F
0 0 .167 r
.67166 .39882 m .67175 .39891 L .67162 .3983 L F
.863 .566 .484 r
.67162 .3983 m .67175 .39891 L .67196 .39882 L F
0 0 .167 r
.67175 .39891 m .67179 .39896 L .67162 .3983 L F
.863 .566 .484 r
.67162 .3983 m .67158 .39898 L .67175 .39891 L F
.67158 .39898 m .67143 .40158 L .67196 .39882 L F
.967 .68 .433 r
.67088 .39894 m .67162 .3983 L .66988 .39793 L F
.527 .766 .985 r
.66978 .39806 m .67113 .3992 L .66796 .40035 L F
.66988 .39793 m .67098 .39905 L .66978 .39806 L F
.67098 .39905 m .67113 .3992 L .66978 .39806 L F
.967 .68 .433 r
.66987 .40034 m .67143 .40158 L .67155 .39952 L F
0 0 0 r
.67113 .3992 m .67115 .39919 L .67174 .3989 L F
.967 .68 .433 r
.67115 .39919 m .67155 .39952 L .67158 .39898 L F
0 0 0 r
.67115 .39919 m .67179 .39896 L .67174 .39891 L F
.67115 .39919 m .67174 .39891 L .67174 .3989 L F
.967 .68 .433 r
.67098 .39905 m .67115 .39919 L .67162 .3983 L F
0 0 0 r
.67113 .3992 m .67174 .3989 L .67166 .39882 L F
.967 .68 .433 r
.67115 .39919 m .67158 .39898 L .67162 .3983 L F
.66987 .40034 m .67155 .39952 L .67098 .39905 L F
.67066 .39942 m .67162 .3983 L .66987 .3998 L F
.527 .766 .985 r
.66988 .39793 m .67179 .39896 L .67113 .3992 L F
.967 .68 .433 r
.66987 .3998 m .67088 .39894 L .66988 .39793 L F
.66987 .40034 m .67066 .39942 L .66987 .3998 L F
.598 .776 .965 r
.51164 .5405 m .5133 .54188 L .51517 .53994 L F
.51517 .53994 m .5133 .54188 L .51164 .5405 L F
.183 .266 .716 r
.28207 .57664 m .28279 .57736 L .28161 .57706 L F
.438 .137 .356 r
.69876 .40726 m .70137 .40848 L .69868 .409 L F
.69876 .40726 m .70129 .40662 L .70137 .40848 L F
.519 .234 .421 r
.5796 .48714 m .57869 .4903 L .57618 .49049 L F
.562 .275 .437 r
.58068 .48986 m .5796 .48714 L .58227 .48767 L F
.58068 .48986 m .57869 .4903 L .5796 .48714 L F
.513 .288 .51 r
.44268 .57753 m .44492 .57705 L .44419 .57478 L F
.658 .368 .468 r
.44419 .57478 m .44492 .57705 L .4483 .57684 L F
.603 .361 .523 r
.45295 .58055 m .44994 .58324 L .45002 .58077 L F
.006 0 .306 r
.58052 .5608 m .57911 .55971 L .58109 .5586 L F
.58052 .5608 m .57872 .56206 L .57911 .55971 L F
.565 .287 .453 r
.61203 .42482 m .61453 .42452 L .61505 .42267 L F
.691 .501 .625 r
.61453 .42452 m .61698 .42191 L .61505 .42267 L F
.578 .483 .711 r
.57159 .57082 m .56979 .57458 L .56952 .57192 L F
.955 .843 .692 r
.6064 .49183 m .60818 .4911 L .6068 .48996 L F
.6064 .49183 m .60715 .49317 L .60818 .4911 L F
.466 .225 .463 r
.47809 .60764 m .47758 .61023 L .4752 .61077 L F
0 .457 .781 r
.47617 .60815 m .47988 .60694 L .47809 .60764 L F
.413 .177 .445 r
.4798 .60946 m .47809 .60764 L .47988 .60694 L F
.4798 .60946 m .47758 .61023 L .47809 .60764 L F
.963 .679 .254 r
.76931 .41313 m .76863 .41447 L .76923 .41116 L F
.76931 .41313 m .76958 .41587 L .76863 .41447 L F
.851 .823 .821 r
.44245 .5974 m .44652 .5955 L .44386 .59559 L F
.903 .937 .824 r
.67601 .43621 m .67722 .43694 L .67468 .44024 L F
.49 .843 .994 r
.67952 .43635 m .67722 .43694 L .67601 .43621 L F
.584 .434 .644 r
.56494 .55083 m .56759 .55028 L .56725 .54765 L F
.581 .397 .597 r
.56496 .55315 m .56759 .55028 L .56494 .55083 L F
.651 .195 .156 r
.21125 .68832 m .20706 .68847 L .20931 .68947 L F
.397 .828 .958 r
.20373 .6344 m .20331 .63522 L .20168 .63489 L F
.20373 .6344 m .20556 .63476 L .20331 .63522 L F
.557 .289 .465 r
.70255 .39799 m .70525 .39753 L .70583 .39512 L F
.828 .733 .76 r
.70525 .39753 m .70827 .39497 L .70583 .39512 L F
.383 .592 .927 r
.78146 .39186 m .77987 .39205 L .78034 .39063 L F
.788 .535 .554 r
.66167 .4013 m .66318 .40133 L .65947 .40097 L F
.66167 .4013 m .66332 .40378 L .66318 .40133 L F
.162 0 0 r
.19203 .55645 m .1902 .55797 L .18811 .5584 L F
0 0 0 r
.19196 .55717 m .19203 .55645 L .19582 .55498 L F
.19196 .55717 m .1902 .55797 L .19203 .55645 L F
.982 .696 .38 r
.41907 .64507 m .41951 .65032 L .42179 .65174 L F
.928 .553 .275 r
.41988 .65128 m .42179 .65174 L .41951 .65032 L F
.41988 .65128 m .42152 .65212 L .42179 .65174 L F
.361 .133 .427 r
.27949 .58906 m .27712 .59209 L .27755 .5897 L F
.589 .407 .603 r
.51533 .59555 m .51831 .5992 L .51309 .59897 L F
.141 .184 .646 r
.51484 .593 m .51661 .59472 L .51533 .59555 L F
0 .065 .624 r
.51717 .59736 m .51533 .59555 L .51661 .59472 L F
.51717 .59736 m .51831 .5992 L .51533 .59555 L F
.675 .22 .164 r
.48434 .58072 m .48663 .58264 L .48289 .58221 L F
.87 .748 .725 r
.61129 .46876 m .61241 .47303 L .61283 .47012 L F
.61129 .46876 m .60912 .47193 L .61241 .47303 L F
.859 .766 .759 r
.60912 .47193 m .61024 .47557 L .61241 .47303 L F
.711 .496 .596 r
.48047 .5778 m .47973 .57937 L .47698 .5771 L F
.48047 .5778 m .48055 .58036 L .47973 .57937 L F
.499 .492 .78 r
.78886 .40887 m .78979 .41238 L .78729 .41208 L F
.668 .908 .978 r
.19949 .65302 m .20135 .65357 L .20349 .65243 L F
.673 .232 .193 r
.74692 .41489 m .7432 .41544 L .74457 .41238 L F
.74692 .41489 m .7468 .41565 L .7432 .41544 L F
.813 .722 .764 r
.74907 .41005 m .74692 .41489 L .74457 .41238 L F
.555 .468 .711 r
.41435 .63152 m .41421 .63395 L .41126 .63222 L F
.526 .612 .881 r
.19358 .73283 m .19635 .73344 L .19347 .73339 L F
.19533 .73196 m .19635 .73344 L .19358 .73283 L F
.332 0 0 r
.19347 .73339 m .19635 .73344 L .19375 .73463 L F
.638 .66 .855 r
.19611 .73145 m .19635 .73344 L .19411 .73019 L F
.955 .864 .711 r
.19375 .73463 m .19635 .73344 L .19611 .73145 L F
.19375 .73463 m .19635 .73344 L .19611 .73145 L F
.19375 .73463 m .19596 .73165 L .19659 .73195 L F
.19596 .73165 m .19611 .73145 L .19619 .73153 L F
.19596 .73165 m .19619 .73153 L .19659 .73195 L F
.526 .612 .881 r
.19411 .73019 m .19533 .73196 L .19358 .73283 L F
.332 0 0 r
.19347 .73339 m .19375 .73463 L .19165 .73516 L F
.095 .481 .896 r
.64073 .42468 m .64093 .42354 L .63955 .4232 L F
.012 .385 .846 r
.64073 .42468 m .64385 .42631 L .64093 .42354 L F
.769 .534 .578 r
.68274 .40781 m .6824 .4098 L .67931 .40918 L F
.665 .972 .892 r
.19509 .74523 m .19618 .74522 L .19659 .74402 L F
.588 .228 .326 r
.68639 .41091 m .68901 .41245 L .68676 .412 L F
.46 .438 .747 r
.5144 .59127 m .51484 .593 L .51422 .58935 L F
0 .134 .678 r
.51664 .59385 m .51484 .593 L .5144 .59127 L F
.51664 .59385 m .51661 .59472 L .51484 .593 L F
.993 .748 .445 r
.67343 .43694 m .67468 .44024 L .67356 .43977 L F
.903 .937 .824 r
.67601 .43621 m .67468 .44024 L .67343 .43694 L F
.881 .526 .037 r
.67468 .44024 m .67409 .44001 L .67356 .43977 L F
.67468 .44024 m .67548 .44297 L .67409 .44001 L F
.321 .015 .281 r
.41281 .58324 m .41225 .58596 L .41445 .5852 L F
.774 .897 .929 r
.50684 .52709 m .50352 .52789 L .50536 .52586 L F
.668 .815 .954 r
.50904 .52631 m .50684 .52709 L .50536 .52586 L F
.512 .401 .665 r
.60982 .42806 m .61232 .43038 L .61222 .42747 L F
.60982 .42806 m .61053 .43107 L .61232 .43038 L F
.419 .496 .831 r
.7366 .39487 m .74005 .39848 L .73915 .39456 L F
0 0 0 r
.73708 .38764 m .7353 .38932 L .73763 .38629 L F
.73708 .38764 m .73763 .38629 L .73631 .3863 L F
.214 0 .119 r
.55457 .48856 m .55389 .48996 L .55685 .48762 L F
.984 .823 .603 r
.66406 .41974 m .66354 .41872 L .66278 .42043 L F
.703 .708 .179 r
.66317 .42335 m .66406 .41974 L .66278 .42043 L F
.609 .627 .844 r
.73966 .42656 m .7408 .42977 L .74288 .42799 L F
.341 .676 .977 r
.78046 .42794 m .78118 .42928 L .78401 .42925 L F
0 0 .247 r
.2498 .55308 m .2483 .55626 L .25112 .5548 L F
.2498 .55308 m .24936 .55545 L .2483 .55626 L F
.446 .879 .896 r
.2483 .55626 m .24936 .55545 L .24681 .55609 L F
.43 .42 .747 r
.25648 .56546 m .25907 .56764 L .25851 .56478 L F
.456 .474 .789 r
.43491 .56142 m .43301 .56079 L .43608 .56022 L F
.706 .775 .906 r
.71298 .42902 m .71655 .42927 L .71521 .42763 L F
.763 .781 .868 r
.71521 .42763 m .71655 .42927 L .71864 .428 L F
.247 0 .255 r
.56198 .48123 m .56363 .48276 L .56457 .4808 L F
.56198 .48123 m .56154 .48378 L .56363 .48276 L F
.134 0 0 r
.43235 .56573 m .43103 .56533 L .43337 .56456 L F
.43235 .56573 m .42981 .5669 L .43103 .56533 L F
.454 .531 .847 r
.74953 .37342 m .75107 .37811 L .74929 .37733 L F
.74953 .37342 m .74929 .37733 L .74997 .37619 L F
.243 .534 .921 r
.74997 .37619 m .75107 .37811 L .74929 .37733 L F
.273 .758 .92 r
.21885 .53918 m .22096 .5389 L .2228 .53929 L F
.269 .76 .91 r
.22096 .5389 m .22501 .53896 L .2228 .53929 L F
.593 .949 .859 r
.7348 .3891 m .7353 .38932 L .73708 .38764 L F
.633 .472 .647 r
.56246 .55373 m .565 .55595 L .56496 .55315 L F
.56246 .55373 m .56258 .55658 L .565 .55595 L F
.35 .532 .893 r
.50956 .57736 m .51123 .57992 L .50973 .58018 L F
.509 .449 .725 r
.28323 .56439 m .28089 .56773 L .28052 .56263 L F
.442 .346 .651 r
.28323 .56439 m .28134 .56909 L .28089 .56773 L F
.77 .836 .903 r
.71357 .41886 m .71022 .41886 L .71242 .41736 L F
.799 .844 .885 r
.71621 .41677 m .71357 .41886 L .71242 .41736 L F
.916 .851 .764 r
.53117 .55483 m .53376 .55392 L .5308 .55296 L F
.53117 .55483 m .53209 .55657 L .53376 .55392 L F
.766 .703 .164 r
.53131 .53153 m .53084 .53568 L .5319 .53253 L F
.77 .409 .373 r
.67608 .40045 m .678 .40295 L .67893 .40095 L F
.782 .521 .541 r
.678 .40295 m .68159 .40112 L .67893 .40095 L F
0 .419 .845 r
.74167 .40423 m .74456 .40163 L .74405 .40219 L F
.63 .875 .526 r
.7456 .4002 m .74405 .40219 L .74456 .40163 L F
.685 .478 .601 r
.62341 .42838 m .62556 .43103 L .62239 .42992 L F
.354 .393 .763 r
.62754 .42902 m .62556 .43103 L .62341 .42838 L F
.629 .712 .906 r
.72666 .41893 m .72255 .4179 L .72503 .41593 L F
.454 .499 .816 r
.7273 .41469 m .72666 .41893 L .72503 .41593 L F
.7273 .41469 m .72849 .41824 L .72666 .41893 L F
.683 .622 .781 r
.62068 .43659 m .61708 .43391 L .61987 .43359 L F
.881 .822 .785 r
.62158 .43465 m .62068 .43659 L .61987 .43359 L F
.878 .895 .84 r
.78223 .42125 m .78445 .42229 L .7845 .42132 L F
0 .121 .672 r
.7845 .42132 m .78624 .42448 L .78445 .42229 L F
.569 .365 .565 r
.50823 .60461 m .50796 .60775 L .50552 .60774 L F
.482 .323 .589 r
.51033 .60143 m .50823 .60461 L .50768 .60195 L F
.51033 .60143 m .51046 .60388 L .50823 .60461 L F
.556 .355 .562 r
.50984 .60437 m .50823 .60461 L .51046 .60388 L F
.50984 .60437 m .50796 .60775 L .50823 .60461 L F
.896 .775 .72 r
.77337 .40333 m .77594 .40426 L .77475 .40085 L F
.157 .648 .918 r
.77557 .40375 m .77581 .40421 L .77337 .40333 L F
.441 0 0 r
.77462 .40424 m .77557 .40375 L .77337 .40333 L F
.86 .956 .61 r
.77534 .40333 m .77557 .40375 L .77462 .40424 L F
.574 .609 .85 r
.77475 .40085 m .77594 .40426 L .77698 .40125 L F
.86 .956 .61 r
.77698 .40125 m .77557 .40375 L .77534 .40333 L F
.157 .648 .918 r
.77557 .40375 m .77594 .40426 L .77581 .40421 L F
.536 .349 .575 r
.77594 .40426 m .77854 .40379 L .77836 .40122 L F
.892 .968 .651 r
.77698 .40125 m .77594 .40426 L .77557 .40375 L F
.536 .349 .575 r
.77594 .40426 m .77854 .40379 L .77836 .40122 L F
.583 .619 .854 r
.77698 .40125 m .77854 .40379 L .77594 .40426 L F
.808 .799 .843 r
.67641 .44889 m .67959 .449 L .67821 .44752 L F
.959 .943 .644 r
.74976 .41571 m .7485 .41615 L .7468 .41565 L F
.74976 .41571 m .74829 .4194 L .7485 .41615 L F
.488 .353 .623 r
.5933 .45438 m .59587 .45341 L .59563 .45142 L F
.388 .169 .455 r
.5933 .45438 m .59561 .45616 L .59587 .45341 L F
.5933 .45438 m .59355 .45714 L .59561 .45616 L F
.524 .742 .974 r
.19759 .63358 m .19706 .63547 L .19544 .634 L F
.19759 .63358 m .19922 .63516 L .19706 .63547 L F
.559 .92 .951 r
.72516 .38477 m .72173 .38564 L .72408 .38453 L F
0 0 0 r
.72694 .38451 m .72516 .38477 L .72408 .38453 L F
.72694 .38451 m .72891 .38377 L .72516 .38477 L F
.441 .282 .568 r
.27277 .59841 m .27281 .60088 L .27082 .60148 L F
.462 .312 .592 r
.27293 .60333 m .27082 .60148 L .27281 .60088 L F
.27293 .60333 m .27069 .60421 L .27082 .60148 L F
.977 .861 .656 r
.76125 .42462 m .76075 .42147 L .76011 .42381 L F
.942 .831 .706 r
.75837 .42682 m .76125 .42462 L .76011 .42381 L F
.75837 .42682 m .75965 .42813 L .76125 .42462 L F
.261 .149 .531 r
.54638 .59508 m .54805 .59181 L .54609 .59185 L F
.71 .238 .129 r
.54348 .61111 m .53964 .61021 L .54112 .61056 L F
.553 .423 .657 r
.4495 .59293 m .45213 .5942 L .45197 .5921 L F
.4495 .59293 m .44974 .59516 L .45213 .5942 L F
.295 .793 .832 r
.17704 .65283 m .17897 .65248 L .1772 .65154 L F
.517 .879 .981 r
.17929 .65138 m .17897 .65248 L .18123 .65169 L F
.384 .758 .991 r
.1772 .65154 m .17897 .65248 L .17929 .65138 L F
.1772 .65154 m .17897 .65248 L .17929 .65138 L F
0 0 0 r
.22789 .64951 m .22619 .6511 L .22431 .65137 L F
.004 0 0 r
.22619 .6511 m .22411 .65228 L .22431 .65137 L F
.507 .242 .448 r
.7529 .38652 m .75627 .38574 L .7561 .38299 L F
.211 .356 .792 r
.75871 .38529 m .7561 .38299 L .75767 .38297 L F
.757 .608 .693 r
.75767 .38297 m .75627 .38574 L .7561 .38299 L F
0 0 .481 r
.53142 .59548 m .53151 .59413 L .53021 .59182 L F
.931 .642 .17 r
.53258 .59761 m .53151 .59413 L .53168 .59595 L F
.53258 .59761 m .5319 .59668 L .53151 .59413 L F
0 0 .149 r
.53151 .59413 m .5319 .59668 L .53141 .593 L F
.53151 .59413 m .53141 .593 L .5314 .59291 L F
.931 .642 .17 r
.53168 .59595 m .53151 .59413 L .53142 .59548 L F
.255 .723 .945 r
.47901 .55958 m .48133 .55954 L .48277 .56013 L F
.29 .753 .947 r
.48353 .55948 m .48277 .56013 L .48133 .55954 L F
.48353 .55948 m .48518 .55998 L .48277 .56013 L F
.573 .434 .654 r
.59563 .45142 m .5979 .44809 L .59587 .44894 L F
0 0 0 r
.1608 .56956 m .16085 .56931 L .16295 .56855 L F
.1608 .56956 m .15861 .57019 L .16085 .56931 L F
.264 .651 .966 r
.26488 .54374 m .26448 .54482 L .26297 .54347 L F
.26488 .54374 m .26643 .54489 L .26448 .54482 L F
.769 .847 .91 r
.69455 .42887 m .68979 .43029 L .69311 .42729 L F
.844 .86 .854 r
.69571 .42477 m .69455 .42887 L .69311 .42729 L F
.69571 .42477 m .69615 .42731 L .69455 .42887 L F
.544 .329 .539 r
.47475 .60039 m .47829 .59795 L .47572 .59844 L F
.553 .443 .682 r
.48001 .60499 m .48227 .60008 L .47923 .60254 L F
.48001 .60499 m .48243 .60441 L .48227 .60008 L F
.105 .529 .911 r
.48118 .6065 m .48243 .60441 L .48001 .60499 L F
.785 .952 .926 r
.47736 .60259 m .47923 .60254 L .48227 .60008 L F
.098 0 0 r
.21184 .63181 m .21224 .63305 L .21396 .63112 L F
.21184 .63181 m .21031 .6339 L .21224 .63305 L F
.724 .95 .951 r
.22077 .66191 m .22416 .66102 L .22265 .66075 L F
.327 .799 .919 r
.22416 .66102 m .22514 .66034 L .22265 .66075 L F
.592 .559 .786 r
.63778 .41545 m .63922 .41988 L .6416 .41856 L F
.566 .937 .893 r
.6416 .41856 m .63922 .41988 L .63757 .41983 L F
0 .078 .591 r
.49622 .54242 m .49674 .54264 L .4949 .54137 L F
.49622 .54242 m .49786 .54392 L .49674 .54264 L F
.183 .016 .406 r
.7892 .43972 m .7898 .44204 L .78754 .44318 L F
.073 0 .183 r
.78754 .44318 m .78931 .44373 L .7866 .44466 L F
.78754 .44318 m .7898 .44204 L .78931 .44373 L F
.818 .729 .767 r
.78342 .41103 m .78314 .41494 L .78094 .41322 L F
0 0 .097 r
.21723 .65662 m .21698 .65545 L .21526 .65456 L F
.21723 .65662 m .21706 .65779 L .21698 .65545 L F
.787 .963 .92 r
.77729 .42928 m .77524 .43088 L .77757 .42985 L F
.132 0 .185 r
.41774 .57752 m .41982 .57677 L .42038 .57453 L F
.443 .257 .533 r
.41719 .57913 m .41982 .57677 L .41774 .57752 L F
.736 .794 .899 r
.69935 .42507 m .69615 .42731 L .69571 .42477 L F
.769 .825 .896 r
.68297 .44153 m .68437 .44275 L .68712 .4406 L F
.38 .296 .634 r
.25306 .57747 m .25527 .57969 L .25482 .57692 L F
.25306 .57747 m .25312 .58115 L .25527 .57969 L F
.249 .027 .368 r
.40521 .58974 m .40661 .59106 L .40743 .58912 L F
.40521 .58974 m .40482 .5921 L .40661 .59106 L F
.96 .65 .395 r
.52232 .56854 m .52078 .56774 L .52043 .56547 L F
0 .077 .62 r
.52232 .56854 m .52369 .56943 L .52078 .56774 L F
.52348 .56973 m .52444 .57072 L .52369 .56943 L F
.706 .317 0 r
.52369 .56943 m .5241 .57069 L .52395 .56907 L F
.52369 .56943 m .52395 .56907 L .52386 .56813 L F
0 .077 .62 r
.52232 .56854 m .52348 .56973 L .52369 .56943 L F
.813 .776 .819 r
.47462 .57834 m .47267 .57778 L .4733 .57723 L F
.47462 .57834 m .47009 .57939 L .47079 .57724 L F
.47462 .57834 m .47214 .58054 L .47009 .57939 L F
.753 .85 .923 r
.47698 .5771 m .47462 .57834 L .4733 .57723 L F
.741 .859 .936 r
.47476 .57565 m .47698 .5771 L .4733 .57723 L F
.424 .137 .37 r
.47212 .57902 m .47396 .57666 L .4733 .57723 L F
.47383 .57677 m .47476 .57565 L .4733 .57723 L F
.47397 .57665 m .4742 .57636 L .47383 .57677 L F
.47421 .57636 m .47476 .57565 L .4741 .57646 L F
.372 .598 .934 r
.47314 .57442 m .47405 .57271 L .47173 .57335 L F
.418 .122 .353 r
.47423 .57642 m .47455 .57855 L .47212 .57902 L F
.683 .552 .699 r
.47973 .57937 m .47462 .57834 L .47698 .5771 L F
.412 .127 .368 r
.47476 .57565 m .47622 .57778 L .47777 .57552 L F
.47476 .57565 m .47469 .57668 L .47622 .57778 L F
.403 .112 .353 r
.47622 .57778 m .47553 .57731 L .47553 .57729 L F
.47622 .57778 m .47455 .57855 L .47423 .57642 L F
.412 .127 .368 r
.47469 .57668 m .47455 .57855 L .47622 .57778 L F
.403 .112 .353 r
.47622 .57778 m .47553 .57729 L .47571 .57415 L F
.47553 .57731 m .47423 .57642 L .47427 .57637 L F
.424 .137 .37 r
.47457 .5766 m .47469 .57668 L .4747 .57647 L F
.47421 .57636 m .4747 .57647 L .47476 .57565 L F
.403 .112 .353 r
.47553 .57731 m .47427 .57637 L .47571 .57415 L F
.424 .137 .37 r
.47212 .57902 m .47455 .57855 L .47469 .57668 L F
.47212 .57902 m .47469 .57668 L .47457 .5766 L F
.287 .441 .841 r
.47427 .57637 m .47423 .57642 L .47421 .57636 L F
.703 .715 .858 r
.4742 .57636 m .47423 .57642 L .47417 .57639 L F
.424 .137 .37 r
.4742 .57636 m .47421 .57636 L .47421 .57636 L F
.703 .715 .858 r
.47421 .57635 m .47421 .57636 L .4742 .57636 L F
.47421 .57636 m .47423 .57642 L .4742 .57636 L F
.418 .122 .353 r
.47423 .57642 m .47212 .57902 L .47417 .57639 L F
.424 .137 .37 r
.47212 .57902 m .4747 .57647 L .47421 .57636 L F
.47212 .57902 m .47421 .57636 L .4742 .57636 L F
.287 .441 .841 r
.47437 .57621 m .47427 .57637 L .47421 .57635 L F
.47427 .57637 m .47421 .57636 L .47421 .57635 L F
.47571 .57415 m .47437 .57621 L .47271 .57187 L F
.47437 .57621 m .47421 .57635 L .47271 .57187 L F
.424 .137 .37 r
.4742 .57636 m .47421 .57636 L .47383 .57677 L F
.47421 .57636 m .4741 .57646 L .47383 .57677 L F
.554 .817 .452 r
.47173 .57335 m .46928 .57635 L .4705 .57487 L F
.872 .885 .841 r
.46839 .57483 m .46928 .57635 L .46943 .57617 L F
.46839 .57483 m .46943 .57617 L .47173 .57335 L F
.776 .847 .905 r
.46665 .57368 m .46839 .57483 L .47069 .57306 L F
.684 .836 .956 r
.46767 .5739 m .46839 .57483 L .46665 .57368 L F
.872 .885 .841 r
.46897 .57439 m .47173 .57335 L .47069 .57306 L F
.46839 .57483 m .46898 .57457 L .46897 .57439 L F
.46898 .57457 m .47173 .57335 L .46897 .57439 L F
.779 .859 .91 r
.46839 .57483 m .46928 .57635 L .46998 .57473 L F
.46897 .57439 m .46998 .57473 L .47069 .57306 L F
.46839 .57483 m .46998 .57473 L .46897 .57439 L F
.708 .668 .808 r
.47008 .57441 m .46839 .57483 L .47069 .57306 L F
.47008 .57441 m .46839 .57483 L .47069 .57306 L F
.684 .836 .956 r
.47008 .57441 m .46895 .57417 L .46949 .57335 L F
.46895 .57417 m .46665 .57368 L .46889 .57342 L F
.46895 .57417 m .46889 .57342 L .46949 .57335 L F
.47008 .57441 m .46839 .57483 L .46767 .5739 L F
.637 .957 .927 r
.47271 .57187 m .47069 .57306 L .47173 .57335 L F
.703 .715 .858 r
.47271 .57187 m .47421 .57635 L .47008 .57441 L F
.47421 .57635 m .47417 .57639 L .47008 .57441 L F
.813 .776 .819 r
.47267 .57778 m .47079 .57724 L .4733 .57723 L F
.973 .74 .524 r
.46928 .57635 m .47079 .57724 L .4705 .57487 L F
.105 0 0 r
.47009 .57939 m .4733 .57723 L .47079 .57724 L F
.47009 .57939 m .47212 .57902 L .4733 .57723 L F
.418 .122 .353 r
.47417 .57639 m .47212 .57902 L .47008 .57441 L F
.424 .137 .37 r
.47212 .57902 m .47397 .57665 L .47396 .57666 L F
.709 .572 .699 r
.47462 .57834 m .4747 .58101 L .47214 .58054 L F
.683 .552 .699 r
.47973 .57937 m .4747 .58101 L .47462 .57834 L F
.398 .112 .358 r
.24161 .59848 m .24379 .59791 L .24441 .59573 L F
.431 .142 .371 r
.24441 .59573 m .24379 .59791 L .24595 .59725 L F
.534 .396 .639 r
.24441 .59573 m .24677 .59525 L .2464 .59257 L F
.442 .141 .358 r
.24441 .59573 m .24595 .59725 L .24677 .59525 L F
.354 .112 .402 r
.2516 .62853 m .25125 .63156 L .24914 .63152 L F
.146 0 .241 r
.25011 .63293 m .24914 .63152 L .25125 .63156 L F
.25011 .63293 m .24846 .63401 L .24914 .63152 L F
.565 .338 .531 r
.6276 .40999 m .63039 .41216 L .63008 .40925 L F
.6276 .40999 m .62791 .41274 L .63039 .41216 L F
.404 .187 .468 r
.25393 .62546 m .25358 .62861 L .2516 .62853 L F
.334 .096 .396 r
.25303 .63045 m .2516 .62853 L .25358 .62861 L F
.25303 .63045 m .25125 .63156 L .2516 .62853 L F
.155 .148 .598 r
.21197 .68764 m .21082 .68539 L .21387 .68554 L F
.681 .36 .425 r
.21622 .68724 m .21387 .68554 L .21561 .68488 L F
.21622 .68724 m .21197 .68764 L .21387 .68554 L F
0 0 .216 r
.51388 .58791 m .5144 .59127 L .51422 .58935 L F
.51388 .58791 m .51445 .59044 L .51419 .5899 L F
0 0 .422 r
.51261 .58562 m .51388 .58791 L .51422 .58935 L F
0 0 .22 r
.51373 .5867 m .51445 .59044 L .51388 .58791 L F
.832 .584 .034 r
.51373 .5867 m .51369 .58883 L .51445 .59044 L F
0 0 .328 r
.51369 .58883 m .51468 .5909 L .51445 .59044 L F
0 0 .551 r
.51445 .59044 m .51664 .59385 L .5144 .59127 L F
.854 .437 0 r
.51558 .59279 m .51664 .59385 L .51445 .59044 L F
0 0 .328 r
.51468 .5909 m .51558 .59279 L .51445 .59044 L F
0 0 .216 r
.51419 .5899 m .51445 .59044 L .5144 .59127 L F
.961 .78 .612 r
.51305 .53172 m .51424 .53584 L .51266 .53501 L F
.569 .479 .713 r
.55876 .56578 m .56061 .56284 L .55837 .56348 L F
.386 .103 .357 r
.47704 .61199 m .4752 .61077 L .47758 .61023 L F
.47704 .61199 m .47473 .61272 L .4752 .61077 L F
.136 0 .169 r
.43658 .63961 m .43489 .64054 L .43751 .63761 L F
.162 0 .184 r
.4394 .63658 m .43658 .63961 L .43751 .63761 L F
.732 .538 .631 r
.5871 .48457 m .5885 .4877 L .58468 .48757 L F
.677 .514 .658 r
.59082 .48478 m .5885 .4877 L .5871 .48457 L F
.513 .332 .572 r
.77854 .40379 m .78109 .40293 L .77836 .40122 L F
.982 .702 .404 r
.77836 .40122 m .77854 .40379 L .77729 .4007 L F
.513 .332 .572 r
.77836 .40122 m .78109 .40293 L .77854 .40379 L F
.479 .223 .448 r
.22938 .62155 m .23356 .61832 L .23049 .61966 L F
.958 .931 .725 r
.65451 .40637 m .65463 .40353 L .65563 .40484 L F
.754 .493 .538 r
.21318 .67101 m .21728 .67037 L .21289 .67133 L F
.21318 .67101 m .21455 .67413 L .21728 .67037 L F
.097 0 0 r
.58062 .4667 m .58264 .46584 L .58366 .46431 L F
0 0 0 r
.58366 .46431 m .58264 .46584 L .58532 .46275 L F
.71 .238 .129 r
.54348 .61111 m .54208 .61247 L .53964 .61021 L F
0 0 0 r
.54463 .61144 m .54348 .61111 L .54608 .61173 L F
.54463 .61144 m .54208 .61247 L .54348 .61111 L F
.426 .191 .452 r
.25658 .62238 m .25637 .62495 L .25393 .62546 L F
.408 .176 .447 r
.25827 .62424 m .25658 .62238 L .25867 .62182 L F
.25827 .62424 m .25637 .62495 L .25658 .62238 L F
.74 .462 .508 r
.42604 .65798 m .42898 .6554 L .42533 .65496 L F
.42604 .65798 m .42877 .65847 L .42898 .6554 L F
.74 .494 .557 r
.42877 .65847 m .43267 .65576 L .42898 .6554 L F
.862 .9 .484 r
.58311 .52348 m .58198 .52508 L .58315 .52296 L F
.051 0 0 r
.54401 .49947 m .54612 .49879 L .5469 .49695 L F
0 0 0 r
.54937 .49395 m .5469 .49695 L .54843 .49538 L F
.058 0 0 r
.5469 .49695 m .54806 .49776 L .54843 .49538 L F
.5469 .49695 m .54612 .49879 L .54806 .49776 L F
0 .16 .692 r
.51625 .5604 m .51767 .56098 L .51644 .55868 L F
.51625 .5604 m .51849 .56241 L .51767 .56098 L F
0 0 0 r
.75103 .40837 m .7514 .40707 L .74907 .41005 L F
.75247 .40492 m .7514 .40707 L .75103 .40837 L F
.74 .494 .557 r
.42877 .65847 m .43116 .65838 L .43267 .65576 L F
.624 .597 .803 r
.57228 .57416 m .5709 .5779 L .56979 .57458 L F
.57228 .57416 m .57308 .57752 L .5709 .5779 L F
.595 .453 .659 r
.57308 .57752 m .57123 .5805 L .5709 .5779 L F
.686 .395 .476 r
.57379 .49036 m .5701 .49288 L .5699 .49137 L F
.57379 .49036 m .57293 .49338 L .5701 .49288 L F
.433 .101 .301 r
.57618 .49049 m .57293 .49338 L .57379 .49036 L F
0 0 0 r
.54937 .49395 m .55103 .49282 L .55201 .49121 L F
.161 0 .273 r
.54843 .49538 m .55103 .49282 L .54937 .49395 L F
.789 .839 .89 r
.20472 .68057 m .20393 .68104 L .20613 .67913 L F
.375 .153 .444 r
.26106 .61879 m .25867 .62182 L .25894 .61929 L F
.167 0 .041 r
.15044 .55861 m .1538 .55571 L .15175 .55673 L F
.672 .974 .816 r
.74453 .39303 m .7428 .39497 L .74207 .3949 L F
.878 .463 .034 r
.74343 .39725 m .7428 .39497 L .74207 .3949 L F
.888 .514 .326 r
.74511 .39806 m .7428 .39497 L .74343 .39725 L F
.611 .232 .3 r
.45858 .57782 m .46081 .57958 L .45711 .5798 L F
.98 .795 .584 r
.45858 .57782 m .45711 .5798 L .45715 .57657 L F
.54 .268 .451 r
.46111 .57743 m .46081 .57958 L .45858 .57782 L F
.511 .3 .53 r
.43494 .61362 m .43511 .61544 L .43237 .61595 L F
.509 .372 .63 r
.43532 .61856 m .43237 .61595 L .43511 .61544 L F
.43532 .61856 m .43265 .61923 L .43237 .61595 L F
.047 0 0 r
.55201 .49121 m .55314 .49185 L .55389 .48996 L F
.55201 .49121 m .55103 .49282 L .55314 .49185 L F
.098 0 0 r
.23407 .64477 m .23346 .64412 L .23525 .64326 L F
.23407 .64477 m .23203 .64552 L .23346 .64412 L F
.553 .504 .754 r
.20947 .6623 m .21095 .66041 L .2083 .6611 L F
.20947 .6623 m .21199 .66406 L .21095 .66041 L F
.535 .104 .168 r
.20848 .67697 m .21049 .67819 L .21228 .67632 L F
.63 .632 .834 r
.21043 .67369 m .21228 .67632 L .21487 .67601 L F
.861 .773 .763 r
.21049 .67819 m .21487 .67601 L .21228 .67632 L F
.709 .479 .575 r
.63936 .40354 m .64112 .40361 L .64109 .40118 L F
.978 .683 .379 r
.5267 .55263 m .52831 .55431 L .52759 .55236 L F
.649 .577 .76 r
.52759 .55236 m .52831 .55431 L .53048 .55313 L F
.5303 .55287 m .53048 .55313 L .5308 .55296 L F
.52759 .55236 m .53048 .55313 L .5303 .55287 L F
.719 .824 .93 r
.5267 .55263 m .52831 .55431 L .53048 .55313 L F
.53032 .55292 m .53048 .55313 L .5308 .55296 L F
.5267 .55263 m .53048 .55313 L .53032 .55292 L F
0 0 0 r
.52759 .55236 m .52969 .55194 L .5308 .55296 L F
.52759 .55236 m .5267 .55263 L .52969 .55194 L F
.719 .824 .93 r
.5267 .55263 m .5308 .55296 L .52969 .55194 L F
.676 .228 0 r
.52817 .55031 m .53005 .55298 L .5298 .55227 L F
.52885 .55106 m .5298 .55227 L .52972 .55202 L F
.52817 .55031 m .5298 .55227 L .52885 .55106 L F
.52958 .55183 m .52972 .55202 L .52969 .55194 L F
.52817 .55031 m .52972 .55202 L .52958 .55183 L F
.671 .253 .244 r
.4747 .58101 m .47416 .58282 L .47214 .58054 L F
.614 .196 .227 r
.47684 .58256 m .4747 .58101 L .47973 .57937 L F
.47684 .58256 m .47416 .58282 L .4747 .58101 L F
.777 .342 .217 r
.45311 .56855 m .45185 .56993 L .45071 .56781 L F
0 0 .251 r
.45472 .5659 m .45439 .56801 L .45311 .56855 L F
0 0 0 r
.59289 .52833 m .59208 .53007 L .59331 .52642 L F
.59119 .53215 m .59208 .53007 L .59289 .52833 L F
.519 .825 1 r
.47416 .58282 m .47009 .57939 L .47214 .58054 L F
.734 .862 .941 r
.74829 .4194 m .74439 .4196 L .74727 .41851 L F
.927 .942 .787 r
.7485 .41615 m .74829 .4194 L .74727 .41851 L F
.862 .831 .815 r
.62317 .43187 m .62158 .43465 L .61987 .43359 L F
.702 .309 .301 r
.21622 .63073 m .21414 .62849 L .21396 .63112 L F
.712 .781 .295 r
.58725 .51174 m .58606 .51495 L .58655 .51335 L F
.87 .926 .539 r
.5888 .50823 m .58725 .51174 L .58716 .51093 L F
.847 .807 .319 r
.58725 .51174 m .58655 .51335 L .58716 .51093 L F
.738 .837 .926 r
.75089 .43383 m .75425 .43394 L .7531 .43265 L F
.758 .862 .926 r
.7531 .43265 m .75425 .43394 L .75665 .43244 L F
.79 .934 .926 r
.51831 .5992 m .51252 .60002 L .51309 .59897 L F
.649 .773 .939 r
.2498 .55308 m .25112 .5548 L .25321 .55375 L F
.58 .365 .554 r
.56957 .5446 m .57228 .54431 L .57228 .5418 L F
.438 .221 .485 r
.57228 .5418 m .57465 .5411 L .57483 .53877 L F
.439 .255 .533 r
.57228 .5418 m .57457 .54349 L .57465 .5411 L F
.57228 .5418 m .57228 .54431 L .57457 .54349 L F
.871 .786 .291 r
.58606 .51495 m .58547 .51529 L .58655 .51335 L F
.58606 .51495 m .58561 .51737 L .58547 .51529 L F
0 0 .278 r
.52758 .58015 m .52829 .5837 L .52817 .58244 L F
0 0 .488 r
.52938 .58609 m .52817 .58244 L .52829 .5837 L F
.939 .632 .43 r
.53068 .54901 m .53202 .54801 L .53054 .54719 L F
.53068 .54901 m .53225 .54923 L .53202 .54801 L F
.518 .279 .492 r
.57437 .56561 m .57397 .56822 L .57159 .5687 L F
.537 .288 .486 r
.57673 .56524 m .57397 .56822 L .57437 .56561 L F
.583 .22 .318 r
.58486 .48955 m .58227 .48767 L .58468 .48757 L F
.58486 .48955 m .58068 .48986 L .58227 .48767 L F
.452 .234 .492 r
.25637 .62495 m .25358 .62861 L .25393 .62546 L F
.677 .814 .949 r
.21694 .66141 m .21705 .66365 L .22077 .66191 L F
.962 .825 .661 r
.64055 .40588 m .64225 .40586 L .64112 .40361 L F
.618 .077 0 r
.45006 .55758 m .45281 .55781 L .45088 .55787 L F
.196 .025 .409 r
.25454 .5717 m .25594 .57314 L .25652 .57078 L F
.25454 .5717 m .25409 .57433 L .25594 .57314 L F
.76 .784 .872 r
.71731 .42683 m .71521 .42763 L .71864 .428 L F
.763 .784 .871 r
.71731 .42683 m .71864 .428 L .7215 .42536 L F
.279 0 0 r
.43562 .64104 m .43489 .64054 L .43658 .63961 L F
.43562 .64104 m .43285 .64159 L .43489 .64054 L F
.479 .205 .419 r
.44317 .61039 m .44051 .61293 L .44067 .61061 L F
.87 .926 .539 r
.5888 .50823 m .58716 .51093 L .58812 .50756 L F
0 0 0 r
.42299 .57192 m .42038 .57453 L .42239 .57292 L F
.321 0 .253 r
.42038 .57453 m .42191 .57604 L .42239 .57292 L F
.42038 .57453 m .41982 .57677 L .42191 .57604 L F
0 .03 .537 r
.52922 .58955 m .53052 .58825 L .52938 .58609 L F
0 .082 .597 r
.53021 .59182 m .53052 .58825 L .52922 .58955 L F
.326 .032 .303 r
.45418 .61867 m .4514 .62151 L .45212 .61916 L F
.45418 .61867 m .4514 .62151 L .45212 .61916 L F
.788 .326 .145 r
.73284 .38466 m .73631 .3863 L .73429 .38402 L F
.525 .374 .619 r
.73429 .38402 m .73631 .3863 L .73654 .38267 L F
.998 .785 .482 r
.51909 .52679 m .51836 .52895 L .51773 .52819 L F
.63 .827 .977 r
.51672 .52696 m .51773 .52819 L .52002 .52752 L F
.51658 .52694 m .51773 .52819 L .51672 .52696 L F
.998 .785 .482 r
.51836 .52895 m .51825 .52929 L .51773 .52819 L F
.273 0 .179 r
.54111 .50254 m .54346 .50168 L .54401 .49947 L F
.151 0 .14 r
.54401 .49947 m .54544 .50058 L .54612 .49879 L F
.54401 .49947 m .54346 .50168 L .54544 .50058 L F
.491 .05 .128 r
.48674 .60725 m .48571 .60901 L .48368 .60794 L F
.631 .342 .46 r
.48916 .60664 m .48571 .60901 L .48674 .60725 L F
.587 .275 .407 r
.6964 .40919 m .6956 .41196 L .69272 .41039 L F
.468 .159 .358 r
.69868 .409 m .6956 .41196 L .6964 .40919 L F
.512 .457 .732 r
.55924 .57783 m .56213 .58307 L .56223 .57982 L F
.891 .728 .674 r
.54179 .59177 m .54084 .59533 L .54319 .59568 L F
.841 .383 .111 r
.54084 .59533 m .5431 .59749 L .54319 .59568 L F
.574 .246 .375 r
.5431 .59749 m .54638 .59508 L .54319 .59568 L F
.551 0 0 r
.23699 .5549 m .23345 .55282 L .23505 .554 L F
.568 .606 .851 r
.49678 .58306 m .49279 .58014 L .49659 .58061 L F
.448 .31 .6 r
.49678 .58306 m .49888 .58256 L .49659 .58061 L F
.49678 .58306 m .49888 .58256 L .49659 .58061 L F
.436 .816 .99 r
.22501 .53896 m .22715 .53851 L .22882 .53922 L F
.354 .747 .986 r
.22888 .53809 m .22882 .53922 L .22715 .53851 L F
.22888 .53809 m .23098 .53906 L .22882 .53922 L F
.519 .816 .999 r
.50414 .60676 m .50552 .60774 L .5071 .60617 L F
.462 .72 .98 r
.50552 .60774 m .50796 .60775 L .5071 .60617 L F
.569 .479 .713 r
.55876 .56578 m .5612 .56519 L .56061 .56284 L F
.533 .457 .716 r
.55876 .56578 m .56195 .56806 L .5612 .56519 L F
.507 .102 .207 r
.48816 .60373 m .49078 .60228 L .4886 .60213 L F
.455 .257 .522 r
.2326 .61318 m .23468 .61305 L .23503 .6103 L F
.329 .205 .555 r
.2326 .61318 m .23441 .6152 L .23468 .61305 L F
.2326 .61318 m .23352 .61571 L .23441 .6152 L F
.632 .603 .803 r
.5713 .58306 m .56886 .5848 L .56923 .5819 L F
.277 0 0 r
.20303 .55306 m .19862 .55472 L .20086 .55361 L F
.758 .915 .943 r
.72563 .39112 m .72915 .39048 L .72771 .38819 L F
.613 .783 .963 r
.72915 .39048 m .73067 .38771 L .72771 .38819 L F
.72915 .39048 m .73194 .38983 L .73067 .38771 L F
.247 0 .182 r
.40277 .59289 m .40188 .59469 L .40482 .5921 L F
.527 .351 .587 r
.56725 .54765 m .56971 .5471 L .56957 .5446 L F
.504 .356 .613 r
.56759 .55028 m .56971 .5471 L .56725 .54765 L F
.963 .876 .481 r
.65615 .41887 m .65504 .41971 L .65589 .41752 L F
.65615 .41887 m .65543 .42201 L .65504 .41971 L F
.777 .758 .837 r
.66106 .4069 m .65842 .40974 L .66249 .408 L F
.244 0 0 r
.65842 .40974 m .66057 .41026 L .66249 .408 L F
.413 0 0 r
.66057 .41026 m .66445 .41038 L .66249 .408 L F
.11 .341 .81 r
.39403 .62561 m .39475 .62427 L .39405 .62416 L F
.034 .238 .74 r
.39403 .62561 m .39625 .62769 L .39475 .62427 L F
0 0 0 r
.71749 .39755 m .72051 .3943 L .71963 .39594 L F
.025 0 0 r
.72051 .3943 m .72323 .39224 L .72298 .39348 L F
0 0 0 r
.71963 .39594 m .72051 .3943 L .72298 .39348 L F
.813 .722 .764 r
.74757 .41081 m .74457 .41238 L .74656 .41132 L F
.74907 .41005 m .74725 .41099 L .74757 .41081 L F
.74725 .41099 m .74457 .41238 L .74757 .41081 L F
.54 .912 .742 r
.74907 .41005 m .74656 .41132 L .75103 .40837 L F
.815 .778 .819 r
.74656 .41132 m .74686 .41109 L .74457 .41238 L F
0 0 0 r
.74625 .41147 m .74457 .41238 L .74686 .41109 L F
.54 .912 .742 r
.74656 .41132 m .74625 .41147 L .74686 .41109 L F
.815 .778 .819 r
.7482 .41044 m .74827 .4103 L .74686 .41109 L F
0 0 0 r
.74625 .41147 m .74686 .41109 L .74827 .4103 L F
.54 .912 .742 r
.74686 .41109 m .74625 .41147 L .74702 .41098 L F
.74656 .41132 m .74702 .41098 L .75103 .40837 L F
.815 .778 .819 r
.7482 .41044 m .74686 .41109 L .74656 .41132 L F
.228 0 0 r
.74698 .41576 m .7468 .41565 L .7485 .41615 L F
.092 .643 .815 r
.7432 .41544 m .7468 .41565 L .74576 .41545 L F
.815 .778 .819 r
.74576 .41545 m .74687 .41578 L .74688 .41572 L F
.228 0 0 r
.74576 .41545 m .74663 .41562 L .74688 .41572 L F
.74663 .41562 m .7468 .41565 L .74696 .41575 L F
.74692 .41574 m .74696 .41575 L .74698 .41576 L F
.74663 .41562 m .74696 .41575 L .74692 .41574 L F
.815 .778 .819 r
.74576 .41545 m .74688 .41572 L .74827 .4103 L F
.26 .709 .958 r
.74662 .41466 m .74685 .41572 L .74576 .41545 L F
.74685 .41572 m .74687 .41578 L .74576 .41545 L F
.228 0 0 r
.74576 .41545 m .74688 .41572 L .74698 .41576 L F
0 0 .228 r
.74832 .41037 m .74688 .41572 L .74871 .41088 L F
.74688 .41572 m .74687 .41578 L .74689 .41572 L F
.74688 .41572 m .74689 .41572 L .74871 .41088 L F
.74827 .4103 m .74824 .41042 L .74832 .41037 L F
.74824 .41042 m .74687 .41578 L .74832 .41037 L F
.815 .778 .819 r
.74576 .41545 m .7482 .41044 L .74457 .41238 L F
.813 .722 .764 r
.74656 .41132 m .74457 .41238 L .74625 .41147 L F
.653 .742 .915 r
.19641 .67884 m .19459 .68019 L .19245 .67829 L F
.238 0 .094 r
.44149 .55723 m .44283 .55795 L .44516 .55625 L F
0 0 0 r
.44516 .55625 m .44542 .5565 L .44693 .55682 L F
.44516 .55625 m .44283 .55795 L .44542 .5565 L F
.808 .991 .877 r
.20059 .71255 m .19795 .71485 L .201 .7129 L F
0 .129 .589 r
.19303 .74362 m .19241 .7432 L .19052 .74386 L F
.44 .089 .272 r
.63008 .40925 m .63275 .40877 L .63333 .40694 L F
.464 .285 .552 r
.63333 .40694 m .63554 .40633 L .63537 .40397 L F
.855 .944 .58 r
.59331 .52642 m .5938 .52521 L .59355 .52597 L F
.731 .746 .232 r
.59324 .52692 m .59355 .52597 L .59396 .52409 L F
0 0 0 r
.59289 .52833 m .59331 .52642 L .59355 .52597 L F
.731 .746 .232 r
.59289 .52833 m .59355 .52597 L .59324 .52692 L F
.855 .944 .58 r
.5938 .52521 m .59486 .52257 L .59355 .52597 L F
.249 .211 .619 r
.55845 .59358 m .5606 .59442 L .55981 .59191 L F
.395 0 .081 r
.55667 .59564 m .5606 .59442 L .55845 .59358 L F
.235 0 0 r
.5556 .59517 m .55667 .59564 L .55845 .59358 L F
.461 .131 .319 r
.71294 .39329 m .71089 .39216 L .71075 .39425 L F
.71294 .39329 m .71358 .39165 L .71089 .39216 L F
.187 .511 .913 r
.21125 .68832 m .2086 .68662 L .21082 .68539 L F
.048 0 0 r
.2086 .68662 m .20953 .68709 L .21082 .68539 L F
0 0 0 r
.21082 .68539 m .21137 .68434 L .21228 .68193 L F
.655 .851 .455 r
.21082 .68539 m .20953 .68709 L .21137 .68434 L F
.155 .148 .598 r
.21197 .68764 m .21125 .68832 L .21082 .68539 L F
.33 .49 .867 r
.18571 .63166 m .18361 .6313 L .18184 .62833 L F
.879 .93 .851 r
.18936 .72925 m .19063 .73015 L .19261 .72766 L F
.52 .307 .531 r
.18955 .73285 m .19063 .73015 L .18936 .72925 L F
.981 .774 .363 r
.76861 .42268 m .76779 .42364 L .76818 .41994 L F
.76861 .42268 m .76851 .42486 L .76779 .42364 L F
.028 0 0 r
.55953 .4975 m .5589 .49845 L .55621 .49948 L F
.31 0 .055 r
.56193 .49663 m .5589 .49845 L .55953 .4975 L F
.364 .401 .766 r
.39919 .63444 m .39976 .63066 L .39838 .63113 L F
.39919 .63444 m .40072 .63387 L .39976 .63066 L F
.343 .269 .628 r
.39944 .63685 m .40072 .63387 L .39919 .63444 L F
.924 .749 .646 r
.59077 .49975 m .58824 .50109 L .58802 .49872 L F
.59077 .49975 m .58995 .50201 L .58824 .50109 L F
.85 .982 .862 r
.51223 .52164 m .50984 .52396 L .50998 .52204 L F
.965 .865 .69 r
.50984 .52396 m .5084 .52343 L .50998 .52204 L F
.50984 .52396 m .50904 .52631 L .5084 .52343 L F
.681 .966 .755 r
.51313 .52023 m .51223 .52164 L .50998 .52204 L F
.51313 .52023 m .51381 .52011 L .51223 .52164 L F
.762 .546 .606 r
.49316 .57739 m .48922 .5797 L .48927 .57746 L F
.49316 .57739 m .49279 .58014 L .48922 .5797 L F
.868 .723 .7 r
.60998 .47873 m .60803 .481 L .61111 .48135 L F
.857 .768 .764 r
.60803 .481 m .60913 .48466 L .61111 .48135 L F
.832 .739 .762 r
.50193 .53553 m .49962 .53858 L .49854 .53499 L F
.782 .521 .541 r
.678 .40295 m .68165 .40348 L .68159 .40112 L F
.569 .357 .553 r
.60268 .43983 m .60539 .43959 L .60564 .43685 L F
.464 .216 .452 r
.60539 .43959 m .60813 .43556 L .60564 .43685 L F
.997 .813 .456 r
.76185 .41767 m .76223 .41587 L .76139 .41461 L F
.361 .307 .662 r
.50211 .6055 m .50393 .60406 L .50051 .60377 L F
.50211 .6055 m .50414 .60676 L .50393 .60406 L F
.129 0 0 r
.159 .55344 m .16113 .55288 L .16302 .55134 L F
.19 0 0 r
.16113 .55288 m .16508 .55058 L .16302 .55134 L F
.781 .81 .875 r
.69172 .43609 m .69591 .43507 L .69475 .43376 L F
.789 .857 .901 r
.69475 .43376 m .69591 .43507 L .69793 .43365 L F
.213 0 .329 r
.40017 .5956 m .39963 .59782 L .40188 .59469 L F
.905 .594 .104 r
.53437 .60722 m .53363 .6066 L .53325 .60404 L F
.818 .346 0 r
.53437 .60722 m .53445 .60883 L .53363 .6066 L F
.53437 .60722 m .53611 .61006 L .53445 .60883 L F
.468 .27 .528 r
.49593 .5354 m .49854 .53499 L .49808 .53201 L F
.96 .625 .262 r
.49808 .53201 m .49854 .53499 L .49695 .5315 L F
0 0 0 r
.49695 .5315 m .50069 .53034 L .49808 .53201 L F
0 0 .266 r
.58742 .54157 m .58926 .53783 L .58876 .54008 L F
0 0 .167 r
.58744 .54355 m .58742 .54157 L .58876 .54008 L F
.305 .365 .76 r
.74183 .39635 m .74046 .39672 L .73915 .39456 L F
.323 .364 .75 r
.73915 .39456 m .73948 .39601 L .74067 .39557 L F
.73961 .39657 m .74001 .39833 L .74039 .39673 L F
.375 0 0 r
.74052 .39676 m .74044 .39674 L .74046 .39672 L F
.686 .249 .206 r
.74046 .39672 m .74044 .39674 L .7404 .39671 L F
.375 0 0 r
.74052 .39676 m .74046 .39672 L .74183 .39635 L F
.323 .364 .75 r
.74067 .39557 m .7404 .3968 L .74183 .39635 L F
.7404 .3968 m .74005 .39848 L .74183 .39635 L F
.427 .518 .849 r
.74005 .39848 m .74255 .39897 L .74201 .39698 L F
.74134 .39693 m .74201 .39698 L .74183 .39635 L F
.74005 .39848 m .74201 .39698 L .74134 .39693 L F
.735 .784 .892 r
.7404 .39668 m .74046 .39672 L .7404 .39671 L F
.323 .364 .75 r
.74001 .39833 m .74005 .39848 L .74067 .39557 L F
.375 0 0 r
.74153 .39755 m .73852 .39871 L .74033 .39685 L F
.74062 .39688 m .74033 .39685 L .74044 .39674 L F
.74153 .39755 m .74033 .39685 L .74062 .39688 L F
.74153 .39755 m .74052 .39676 L .74183 .39635 L F
.74153 .39755 m .74044 .39674 L .74052 .39676 L F
.323 .364 .75 r
.73948 .39601 m .73961 .39657 L .7404 .39671 L F
.73961 .39657 m .74039 .39673 L .7404 .39671 L F
.73948 .39601 m .7404 .39671 L .74067 .39557 L F
.686 .249 .206 r
.7404 .39671 m .73852 .39871 L .73565 .39639 L F
.74044 .39674 m .73852 .39871 L .7404 .39671 L F
.735 .784 .892 r
.73805 .39537 m .7404 .39668 L .73565 .39639 L F
.7404 .39668 m .7404 .39671 L .73565 .39639 L F
.442 .502 .825 r
.74005 .39848 m .74103 .39943 L .74255 .39897 L F
.668 .969 .915 r
.51966 .51706 m .51667 .51838 L .51983 .51734 L F
0 0 0 r
.52163 .51633 m .52282 .51519 L .51966 .51706 L F
.51983 .51734 m .52163 .51633 L .51966 .51706 L F
.583 .645 .877 r
.17444 .62613 m .17363 .62889 L .17231 .62707 L F
.17444 .62613 m .1758 .62834 L .17363 .62889 L F
.279 .093 .44 r
.57483 .53877 m .57465 .5411 L .5766 .53782 L F
.876 .712 .676 r
.61129 .46876 m .61283 .47012 L .61142 .46643 L F
.93 .594 .378 r
.53435 .57106 m .53471 .57333 L .53654 .5735 L F
0 0 .279 r
.53718 .57507 m .53771 .57713 L .53654 .5735 L F
.53722 .57516 m .5373 .57551 L .53718 .57507 L F
.5373 .57551 m .53771 .57713 L .53718 .57507 L F
.805 .515 .498 r
.53654 .5735 m .53957 .57655 L .53805 .57545 L F
.566 .569 .815 r
.53762 .56944 m .53836 .57291 L .53698 .57436 L F
0 0 .279 r
.53722 .57516 m .53654 .5735 L .53471 .57333 L F
.566 .569 .815 r
.53683 .57382 m .53698 .57436 L .53667 .57469 L F
.53762 .56944 m .53698 .57436 L .53683 .57382 L F
.544 .494 .75 r
.75379 .38885 m .75627 .38574 L .7529 .38652 L F
.75379 .38885 m .75629 .38833 L .75627 .38574 L F
.397 .521 .866 r
.75379 .38885 m .75748 .39199 L .75629 .38833 L F
0 0 0 r
.52353 .51521 m .52282 .51519 L .52163 .51633 L F
.52353 .51521 m .52499 .51414 L .52282 .51519 L F
.026 0 .469 r
.55986 .58663 m .56156 .58776 L .56206 .58636 L F
.55986 .58663 m .56004 .58921 L .56156 .58776 L F
.182 .715 .747 r
.19195 .54204 m .19645 .5413 L .19458 .54142 L F
.068 0 0 r
.19458 .54142 m .19645 .5413 L .19808 .5409 L F
.755 .362 .31 r
.21706 .65779 m .21929 .65933 L .22112 .65887 L F
.659 .518 .68 r
.21929 .65933 m .22497 .65903 L .22112 .65887 L F
.286 0 .135 r
.42239 .57292 m .42521 .57107 L .42299 .57192 L F
.969 .876 .688 r
.77053 .3943 m .77131 .39697 L .76852 .39891 L F
.854 .995 .756 r
.76852 .39891 m .77131 .39697 L .76835 .4006 L F
.889 .861 .807 r
.77349 .39363 m .77131 .39697 L .77053 .3943 L F
.238 0 .094 r
.44149 .55723 m .44072 .5587 L .44283 .55795 L F
0 .29 .649 r
.40792 .64645 m .40895 .6469 L .40727 .64529 L F
.40792 .64645 m .41122 .64795 L .40895 .6469 L F
0 .273 .735 r
.41059 .6478 m .41122 .64795 L .40792 .64645 L F
.34 .574 .927 r
.23895 .55539 m .23991 .55436 L .23699 .5549 L F
.23895 .55539 m .24103 .55594 L .23991 .55436 L F
.799 .844 .885 r
.71621 .41677 m .71242 .41736 L .71524 .41564 L F
.664 .882 .979 r
.71621 .41677 m .71765 .41446 L .71866 .41586 L F
.71621 .41677 m .71524 .41564 L .71765 .41446 L F
.671 .913 .588 r
.22726 .64971 m .22789 .64951 L .22761 .65049 L F
.22726 .64971 m .22619 .6511 L .22789 .64951 L F
.562 .41 .633 r
.2301 .6463 m .23057 .64917 L .22789 .64951 L F
.196 0 0 r
.23057 .64917 m .22761 .65049 L .22789 .64951 L F
.833 .86 .865 r
.45716 .59116 m .45574 .59222 L .458 .59197 L F
.624 .286 .377 r
.45488 .59436 m .458 .59197 L .45574 .59222 L F
.45488 .59436 m .45754 .59451 L .458 .59197 L F
.587 .795 .978 r
.45716 .59116 m .458 .59197 L .46027 .59115 L F
.507 .237 .44 r
.45754 .59451 m .46027 .59115 L .458 .59197 L F
.615 .194 .219 r
.69272 .41039 m .6956 .41196 L .6929 .41177 L F
.614 .45 .635 r
.44994 .58324 m .44751 .58624 L .44736 .58361 L F
.643 .819 .396 r
.54426 .58389 m .54313 .58569 L .54345 .58525 L F
.603 .361 .523 r
.45295 .58055 m .45282 .58321 L .44994 .58324 L F
.374 .176 .479 r
.45474 .58218 m .45295 .58055 L .45507 .58017 L F
.45474 .58218 m .45282 .58321 L .45295 .58055 L F
.506 .17 .332 r
.70727 .4039 m .70994 .40503 L .70728 .40534 L F
.70727 .4039 m .70988 .4036 L .70994 .40503 L F
.371 .125 .406 r
.26597 .61281 m .26334 .61582 L .26373 .61345 L F
.191 0 0 r
.16717 .55 m .16951 .54956 L .17138 .54796 L F
0 0 0 r
.17138 .54796 m .17143 .54849 L .17374 .54763 L F
.17138 .54796 m .16951 .54956 L .17143 .54849 L F
.052 0 0 r
.22171 .62707 m .22293 .62585 L .21998 .62793 L F
.072 0 0 r
.22482 .625 m .22293 .62585 L .22171 .62707 L F
.501 .653 .927 r
.28318 .55212 m .28178 .55352 L .28091 .55117 L F
.28171 .55081 m .28091 .55117 L .28032 .54957 L F
.28318 .55212 m .28091 .55117 L .28171 .55081 L F
.806 .339 .121 r
.27854 .54924 m .28171 .55081 L .28032 .54957 L F
.28171 .55081 m .28182 .55086 L .28032 .54957 L F
0 .259 .762 r
.28075 .54903 m .28178 .55078 L .27854 .54924 L F
.501 .653 .927 r
.28322 .55208 m .28174 .5508 L .28182 .55086 L F
.28174 .5508 m .28032 .54957 L .28182 .55086 L F
0 .259 .762 r
.28174 .5508 m .28182 .55086 L .28171 .55081 L F
.28178 .55078 m .28182 .55086 L .28174 .5508 L F
.28178 .55078 m .28171 .55081 L .27854 .54924 L F
.501 .653 .927 r
.28322 .55208 m .28318 .55212 L .28032 .54957 L F
.28322 .55208 m .28365 .55312 L .28178 .55352 L F
.477 .364 .646 r
.28427 .55569 m .28178 .55352 L .28365 .55312 L F
.28427 .55569 m .28216 .55639 L .28178 .55352 L F
.215 0 .11 r
.44227 .64635 m .4443 .64572 L .44542 .64417 L F
.446 .264 .54 r
.44227 .64635 m .44446 .64829 L .4443 .64572 L F
.44227 .64635 m .44221 .64889 L .44446 .64829 L F
.215 0 .11 r
.44542 .64417 m .4443 .64572 L .44227 .64635 L F
.446 .264 .54 r
.44446 .64829 m .44227 .64635 L .4443 .64572 L F
.44446 .64829 m .44221 .64889 L .44227 .64635 L F
.958 .931 .725 r
.65451 .40637 m .65351 .40558 L .65463 .40353 L F
.072 .39 .85 r
.65451 .40637 m .65665 .40632 L .65351 .40558 L F
.464 .216 .452 r
.60539 .43959 m .60796 .43901 L .60813 .43556 L F
.26 .092 .454 r
.60813 .43556 m .61013 .43538 L .61022 .43328 L F
.442 .198 .448 r
.60813 .43556 m .61058 .43805 L .61013 .43538 L F
.60813 .43556 m .60796 .43901 L .61058 .43805 L F
.234 .28 .706 r
.25312 .58115 m .25523 .58188 L .25527 .57969 L F
.25312 .58115 m .25393 .58347 L .25523 .58188 L F
.555 .322 .517 r
.58532 .46275 m .58797 .46015 L .58565 .46093 L F
.424 0 0 r
.23692 .53961 m .23914 .54 L .24104 .53914 L F
.104 0 0 r
.23914 .54 m .24306 .5392 L .24104 .53914 L F
.874 .899 .846 r
.77275 .39167 m .77349 .39363 L .77053 .3943 L F
.853 .916 .874 r
.7739 .39058 m .77349 .39363 L .77275 .39167 L F
.7739 .39058 m .77529 .3918 L .77349 .39363 L F
.39 .316 .652 r
.79136 .43583 m .7892 .43972 L .78937 .43738 L F
.79136 .43583 m .79202 .43862 L .7892 .43972 L F
.29 .075 .405 r
.79188 .44078 m .7892 .43972 L .79202 .43862 L F
.79188 .44078 m .7898 .44204 L .7892 .43972 L F
.369 .45 .813 r
.53073 .53447 m .53087 .53428 L .52997 .53543 L F
.53239 .53238 m .53386 .53609 L .53087 .53428 L F
.53239 .53238 m .53087 .53428 L .53073 .53447 L F
.766 .703 .164 r
.53102 .53406 m .53087 .53428 L .53084 .53568 L F
.53131 .53153 m .53087 .53428 L .53102 .53406 L F
.069 .177 .67 r
.53087 .53428 m .53088 .53837 L .53084 .53568 L F
.66 .714 .888 r
.72255 .4179 m .71866 .41586 L .72121 .41492 L F
.646 .725 .906 r
.72503 .41593 m .72255 .4179 L .72121 .41492 L F
.797 .867 .9 r
.74076 .42068 m .73839 .4207 L .74079 .41982 L F
.479 .882 .951 r
.74296 .41925 m .74076 .42068 L .74079 .41982 L F
.74296 .41925 m .74439 .4196 L .74076 .42068 L F
.272 0 .204 r
.57773 .46902 m .57998 .46874 L .58062 .4667 L F
.439 .134 .35 r
.57713 .4713 m .57998 .46874 L .57773 .46902 L F
.162 0 0 r
.21998 .62793 m .21622 .63073 L .2184 .63018 L F
.148 0 .059 r
.22053 .62957 m .21998 .62793 L .2184 .63018 L F
.22053 .62957 m .22171 .62707 L .21998 .62793 L F
0 0 0 r
.19676 .70729 m .19358 .70989 L .19574 .70835 L F
.211 0 0 r
.19574 .70835 m .19922 .70658 L .19676 .70729 L F
.363 .796 .966 r
.19754 .69996 m .20158 .70018 L .19967 .69955 L F
.657 .107 0 r
.20158 .70018 m .20151 .70165 L .19967 .69955 L F
.20158 .70018 m .20507 .7025 L .20151 .70165 L F
.663 .586 .758 r
.45197 .5921 m .45399 .58936 L .45197 .58965 L F
.511 .286 .509 r
.26849 .60726 m .26828 .61007 L .26572 .61042 L F
.441 .253 .528 r
.27069 .60421 m .27061 .60678 L .26849 .60726 L F
.505 .281 .508 r
.27053 .60951 m .26849 .60726 L .27061 .60678 L F
.27053 .60951 m .26828 .61007 L .26849 .60726 L F
.471 .115 .279 r
.58062 .4667 m .58309 .46798 L .58264 .46584 L F
.58062 .4667 m .57998 .46874 L .58309 .46798 L F
.442 .043 .185 r
.39382 .60078 m .39622 .60049 L .39751 .59848 L F
.404 .004 .163 r
.39751 .59848 m .39851 .60007 L .39963 .59782 L F
.39751 .59848 m .39622 .60049 L .39851 .60007 L F
.646 .539 .718 r
.44652 .5955 m .44936 .59802 L .44974 .59516 L F
.263 .023 .35 r
.44936 .59802 m .45213 .5942 L .44974 .59516 L F
.994 .793 .424 r
.65013 .41996 m .65081 .41894 L .65 .41773 L F
.398 0 0 r
.6584 .40037 m .66167 .4013 L .65947 .40097 L F
.6584 .40037 m .66127 .4017 L .66167 .4013 L F
.87 .811 .788 r
.65962 .40551 m .66332 .40378 L .66167 .4013 L F
0 0 .016 r
.66165 .40356 m .65962 .40551 L .66167 .4013 L F
.66165 .40356 m .66167 .4013 L .66127 .4017 L F
.638 .17 .127 r
.54991 .61084 m .54857 .6123 L .54608 .61173 L F
.119 0 0 r
.55208 .6099 m .54857 .6123 L .54991 .61084 L F
.343 0 .188 r
.54572 .58287 m .54313 .58569 L .54426 .58389 L F
0 0 .002 r
.53356 .60164 m .53368 .60265 L .53282 .60037 L F
.53356 .60164 m .53325 .60404 L .53368 .60265 L F
.063 .627 .758 r
.20684 .55304 m .2052 .55299 L .20303 .55306 L F
.519 .306 .531 r
.43679 .615 m .43494 .61362 L .43897 .61324 L F
.43679 .615 m .43511 .61544 L .43494 .61362 L F
.479 .287 .541 r
.4511 .65829 m .45104 .66087 L .45334 .65776 L F
.4511 .65829 m .45104 .66087 L .45334 .65776 L F
.233 0 .2 r
.25165 .58663 m .24882 .58928 L .25087 .58834 L F
.462 .22 .461 r
.25087 .58834 m .25332 .58577 L .25165 .58663 L F
.609 .438 .625 r
.61203 .42482 m .61456 .42675 L .61453 .42452 L F
.61203 .42482 m .61222 .42747 L .61456 .42675 L F
0 0 .36 r
.5356 .56438 m .53574 .56705 L .53459 .56856 L F
0 0 .269 r
.53558 .56941 m .53459 .56856 L .53574 .56705 L F
.53558 .56941 m .53435 .57106 L .53459 .56856 L F
.751 .486 .531 r
.43341 .66157 m .43251 .6639 L .43043 .66101 L F
.275 0 .229 r
.43524 .66092 m .43251 .6639 L .43341 .66157 L F
.241 .611 .955 r
.46274 .56067 m .46059 .56056 L .45892 .55908 L F
.317 .14 .477 r
.55938 .57118 m .56192 .5707 L .56195 .56806 L F
.171 0 .241 r
.55938 .57118 m .56106 .57255 L .56192 .5707 L F
.55938 .57118 m .5592 .57343 L .56106 .57255 L F
.736 .673 .789 r
.74167 .40423 m .74255 .39897 L .74103 .39943 L F
.74167 .40423 m .74405 .40219 L .74255 .39897 L F
.743 .882 .944 r
.62239 .42992 m .6183 .42978 L .61961 .42989 L F
.539 .539 .802 r
.6183 .42978 m .61708 .43391 L .61961 .42989 L F
.854 .692 .68 r
.62239 .42992 m .61987 .43359 L .6183 .42978 L F
.862 .831 .815 r
.62317 .43187 m .61987 .43359 L .62239 .42992 L F
.653 .537 .71 r
.62556 .43103 m .62317 .43187 L .62239 .42992 L F
.484 .31 .569 r
.24161 .59848 m .24366 .6005 L .24379 .59791 L F
.24161 .59848 m .24157 .60107 L .24366 .6005 L F
.417 .18 .445 r
.60301 .44239 m .60539 .43959 L .60268 .43983 L F
.708 .248 .156 r
.42894 .59921 m .43318 .60011 L .43293 .59812 L F
.981 .724 .464 r
.4339 .59948 m .43374 .60044 L .43453 .59892 L F
.43453 .59892 m .43374 .60044 L .43553 .60144 L F
.43415 .59797 m .43405 .59859 L .43453 .59892 L F
.43405 .59859 m .4339 .59948 L .43424 .59918 L F
.43405 .59859 m .43424 .59918 L .43453 .59892 L F
.319 .42 .808 r
.43415 .59797 m .43553 .60144 L .43693 .59962 L F
.603 .321 .462 r
.43693 .59962 m .43581 .59991 L .43415 .59797 L F
.43581 .59991 m .43374 .60044 L .43405 .59859 L F
.43581 .59991 m .43405 .59859 L .43415 .59797 L F
.303 .363 .759 r
.43325 .59606 m .43624 .59933 L .43374 .59287 L F
.43293 .59812 m .43403 .59852 L .43325 .59606 L F
.43403 .59852 m .43624 .59933 L .43325 .59606 L F
.708 .248 .156 r
.43318 .60011 m .43441 .60037 L .43385 .59952 L F
.43318 .60011 m .43385 .59952 L .43293 .59812 L F
.961 .629 .325 r
.43374 .60044 m .43413 .60196 L .43553 .60144 L F
.736 .593 .696 r
.43413 .60196 m .43693 .59962 L .43553 .60144 L F
.202 .253 .693 r
.43553 .60144 m .43796 .60324 L .43693 .59962 L F
0 0 0 r
.49189 .53757 m .49378 .5369 L .49593 .5354 L F
.091 0 0 r
.49593 .5354 m .4969 .5358 L .49854 .53499 L F
.49593 .5354 m .49378 .5369 L .4969 .5358 L F
.415 .167 .428 r
.56971 .5471 m .57228 .54431 L .56957 .5446 L F
0 0 .347 r
.53117 .55483 m .53179 .55909 L .53209 .55657 L F
.574 .246 .375 r
.5431 .59749 m .54573 .59749 L .54638 .59508 L F
.261 .149 .531 r
.54638 .59508 m .54826 .59443 L .54805 .59181 L F
.14 0 .214 r
.54638 .59508 m .54573 .59749 L .54826 .59443 L F
.712 .968 .726 r
.20561 .70177 m .20471 .70325 L .20624 .70183 L F
0 0 0 r
.20561 .70177 m .20646 .70185 L .20491 .70171 L F
.802 .681 .73 r
.20151 .70165 m .20561 .70177 L .20356 .70159 L F
0 0 0 r
.20561 .70177 m .20491 .70171 L .20356 .70159 L F
.712 .968 .726 r
.20561 .70177 m .20624 .70183 L .20791 .70028 L F
0 0 0 r
.20561 .70177 m .20791 .70028 L .2094 .69935 L F
.671 .379 .469 r
.49225 .60465 m .49191 .6068 L .48916 .60664 L F
.456 .493 .809 r
.49354 .60323 m .49225 .60465 L .49078 .60228 L F
0 0 .242 r
.49354 .60323 m .49191 .6068 L .49225 .60465 L F
0 0 0 r
.55621 .49948 m .55536 .50102 L .55379 .50238 L F
.55536 .50102 m .55369 .50251 L .55379 .50238 L F
.479 .615 .907 r
.21168 .6964 m .21036 .69729 L .20827 .69436 L F
0 0 .054 r
.21168 .6964 m .2094 .69935 L .21036 .69729 L F
.631 .932 .968 r
.51128 .59985 m .51033 .60143 L .51252 .60002 L F
.679 .222 .162 r
.50891 .60296 m .51033 .60143 L .51128 .59985 L F
.465 .31 .587 r
.51265 .6034 m .51046 .60388 L .51033 .60143 L F
.679 .222 .162 r
.50891 .60296 m .51265 .6034 L .51033 .60143 L F
.268 .685 .968 r
.76417 .43705 m .76692 .43634 L .76314 .43574 L F
.76417 .43705 m .76701 .43734 L .76692 .43634 L F
.828 .733 .76 r
.70525 .39753 m .70808 .39592 L .70827 .39497 L F
.381 .067 .302 r
.70539 .39998 m .70808 .39592 L .70525 .39753 L F
.70539 .39998 m .70789 .39914 L .70808 .39592 L F
.259 .185 .579 r
.70827 .39497 m .70808 .39592 L .71071 .39616 L F
.372 .06 .301 r
.70808 .39592 m .71035 .39836 L .71071 .39616 L F
.70808 .39592 m .70789 .39914 L .71035 .39836 L F
.539 .539 .802 r
.6183 .42978 m .61987 .43359 L .61708 .43391 L F
.87 .912 .856 r
.68712 .4406 m .68889 .43908 L .68889 .43626 L F
.826 .883 .885 r
.68889 .43626 m .68889 .43908 L .69172 .43609 L F
.377 .635 .955 r
.27471 .54664 m .27414 .54836 L .27258 .54683 L F
.27471 .54664 m .27675 .54853 L .27414 .54836 L F
.48 .385 .67 r
.28207 .55743 m .28266 .56224 L .28052 .56263 L F
.509 .449 .725 r
.28323 .56439 m .28052 .56263 L .28266 .56224 L F
.698 .562 .697 r
.45113 .57494 m .45558 .57668 L .45374 .57112 L F
.363 .363 .725 r
.45374 .57112 m .4563 .57474 L .45626 .57067 L F
.45374 .57112 m .45558 .57668 L .4563 .57474 L F
.293 .462 .857 r
.39838 .63113 m .39976 .63066 L .39706 .62897 L F
.786 .331 0 r
.51097 .55392 m .51004 .55326 L .50857 .55245 L F
.51097 .55392 m .51204 .55585 L .51004 .55326 L F
.602 .825 .985 r
.18184 .62833 m .17987 .62909 L .17796 .62791 L F
.543 .275 .459 r
.63554 .40633 m .63936 .40354 L .63537 .40397 L F
.516 .339 .58 r
.41753 .64177 m .41566 .64397 L .4157 .64387 L F
.839 .98 .688 r
.4157 .64387 m .41491 .64485 L .41662 .64372 L F
.516 .339 .58 r
.41566 .64397 m .41491 .64485 L .4157 .64387 L F
.719 .187 0 r
.41596 .64321 m .4157 .64387 L .41662 .64372 L F
.41256 .64058 m .4157 .64387 L .41596 .64321 L F
.494 .821 1 r
.41491 .64485 m .41818 .64525 L .41662 .64372 L F
.649 .148 .043 r
.41662 .64372 m .41818 .64525 L .41907 .64507 L F
.671 .408 .514 r
.42803 .58602 m .43243 .58804 L .43164 .58331 L F
.287 .151 .515 r
.43164 .58331 m .43354 .58558 L .43425 .58391 L F
.43164 .58331 m .43243 .58804 L .43354 .58558 L F
.717 .865 .952 r
.17395 .65069 m .17704 .65283 L .1772 .65154 L F
.17356 .65058 m .1772 .65154 L .1759 .65127 L F
.682 .65 .812 r
.17672 .64931 m .1759 .65127 L .17782 .65 L F
.17355 .64732 m .17518 .65007 L .17672 .64931 L F
.17518 .65007 m .1759 .65127 L .17672 .64931 L F
.717 .865 .952 r
.17356 .65058 m .17382 .65075 L .17395 .65069 L F
.17382 .65075 m .17704 .65283 L .17395 .65069 L F
.891 .782 .735 r
.58899 .49658 m .58812 .49281 L .59009 .49376 L F
.28 .385 .792 r
.78439 .39368 m .78281 .39539 L .78146 .39186 L F
.294 .407 .807 r
.78439 .39368 m .78576 .39704 L .78281 .39539 L F
.392 .392 .74 r
.78576 .39704 m .78394 .39744 L .78281 .39539 L F
.782 .372 0 r
.52795 .54958 m .52969 .55194 L .53068 .54901 L F
.52795 .54958 m .52817 .55031 L .52969 .55194 L F
.645 .495 .665 r
.52969 .55194 m .53225 .54923 L .53068 .54901 L F
.52969 .55194 m .5308 .55296 L .53225 .54923 L F
.895 .561 .072 r
.53005 .55298 m .5308 .55296 L .52969 .55194 L F
.735 .907 .954 r
.65506 .42848 m .6527 .42993 L .6538 .43089 L F
.6538 .43089 m .6527 .42993 L .65506 .42848 L F
.565 .695 .928 r
.6538 .43089 m .65631 .43038 L .65506 .42848 L F
.764 .47 .487 r
.74255 .39897 m .74511 .39806 L .74343 .39725 L F
.74255 .39897 m .7456 .4002 L .74511 .39806 L F
.203 0 .109 r
.40583 .61519 m .40376 .61592 L .40698 .61327 L F
.402 .233 .535 r
.40583 .61519 m .40382 .61338 L .40698 .61327 L F
.40583 .61519 m .40376 .61592 L .40382 .61338 L F
.40382 .61338 m .40583 .61519 L .40698 .61327 L F
.40382 .61338 m .40376 .61592 L .40583 .61519 L F
.434 .251 .532 r
.28174 .58589 m .27949 .58906 L .27951 .58649 L F
.319 .115 .438 r
.38712 .60716 m .38888 .6066 L .38918 .60429 L F
.417 .319 .636 r
.38712 .60716 m .38942 .60924 L .38888 .6066 L F
.38712 .60716 m .38706 .61067 L .38942 .60924 L F
.95 .764 .304 r
.59938 .51328 m .59957 .51165 L .59889 .51332 L F
.953 .946 .639 r
.59957 .51165 m .60047 .50751 L .59962 .51084 L F
.788 .788 .29 r
.59889 .51332 m .59957 .51165 L .59962 .51084 L F
0 .308 .676 r
.7528 .39931 m .75635 .40097 L .75564 .39993 L F
.752 .988 .774 r
.75635 .40097 m .75355 .40299 L .75564 .39993 L F
.691 .501 .625 r
.61453 .42452 m .61771 .42448 L .61698 .42191 L F
.592 .442 .647 r
.61698 .42191 m .61771 .42448 L .62023 .42315 L F
.483 .273 .517 r
.27518 .59547 m .27498 .59794 L .27277 .59841 L F
.407 .211 .5 r
.27498 .59794 m .27281 .60088 L .27277 .59841 L F
.032 0 .2 r
.6515 .40859 m .65165 .40855 L .6516 .4097 L F
.45 .823 .992 r
.1832 .65217 m .18491 .65277 L .18685 .65228 L F
.422 .175 .433 r
.47079 .57724 m .47009 .57939 L .46817 .57994 L F
.47079 .57724 m .47009 .57939 L .46817 .57994 L F
.55 .389 .616 r
.62023 .42315 m .62331 .41882 L .62064 .42204 L F
.77 .809 .884 r
.70553 .42251 m .7013 .42356 L .70402 .42105 L F
.776 .791 .865 r
.70734 .42142 m .70553 .42251 L .70402 .42105 L F
.813 .747 .791 r
.60997 .48238 m .60913 .48466 L .60803 .481 L F
.882 .64 .568 r
.606 .48644 m .60913 .48466 L .60997 .48238 L F
.606 .48644 m .60839 .48623 L .60913 .48466 L F
.461 .705 .974 r
.24327 .55554 m .24502 .55726 L .24681 .55609 L F
.577 .363 .554 r
.56005 .55929 m .56261 .55916 L .56258 .55658 L F
.538 .303 .507 r
.56261 .55916 m .565 .55595 L .56258 .55658 L F
.695 .213 .101 r
.45324 .57694 m .45113 .57494 L .45122 .57617 L F
.45324 .57694 m .45558 .57668 L .45113 .57494 L F
.022 0 0 r
.45911 .58327 m .46126 .58259 L .4623 .58162 L F
.204 0 0 r
.4623 .58162 m .46402 .582 L .46474 .58091 L F
.4623 .58162 m .46126 .58259 L .46402 .582 L F
0 0 0 r
.53232 .51023 m .5338 .50902 L .53065 .51099 L F
.036 0 0 r
.53476 .50964 m .5338 .50902 L .53232 .51023 L F
.53476 .50964 m .53605 .50813 L .5338 .50902 L F
.227 .104 .495 r
.25332 .58577 m .25523 .58188 L .25393 .58347 L F
.748 .235 0 r
.66937 .40422 m .66796 .40035 L .66965 .40121 L F
.75 .532 .6 r
.57123 .5805 m .56923 .5819 L .5683 .58038 L F
.57123 .5805 m .5713 .58306 L .56923 .5819 L F
.595 .453 .659 r
.57308 .57752 m .57386 .58011 L .57123 .5805 L F
.582 .399 .599 r
.57386 .58011 m .5713 .58306 L .57123 .5805 L F
.57386 .58011 m .5713 .58306 L .57123 .5805 L F
.5 .287 .522 r
.27733 .59736 m .27518 .59547 L .27746 .5949 L F
.27733 .59736 m .27498 .59794 L .27518 .59547 L F
.09 .445 .88 r
.50592 .57232 m .50347 .57233 L .50223 .571 L F
.50592 .57232 m .50633 .57356 L .50388 .57251 L F
.207 .449 .872 r
.50591 .57448 m .50633 .57356 L .50635 .57487 L F
.50347 .57233 m .50633 .57356 L .50591 .57448 L F
.532 .799 .995 r
.50714 .5719 m .50633 .57356 L .50592 .57232 L F
.715 .911 .554 r
.50714 .5719 m .50701 .57208 L .50633 .57356 L F
.50701 .57208 m .50516 .5747 L .50633 .57356 L F
.843 .985 .704 r
.50498 .57354 m .50668 .57225 L .50592 .57232 L F
.50668 .57225 m .50714 .5719 L .50592 .57232 L F
.09 .445 .88 r
.50592 .57232 m .50388 .57251 L .50347 .57233 L F
.275 .034 .355 r
.2464 .59257 m .24819 .59194 L .24882 .58928 L F
.307 .061 .368 r
.24882 .58928 m .25055 .59066 L .25087 .58834 L F
.24882 .58928 m .24819 .59194 L .25055 .59066 L F
.648 .151 .056 r
.55825 .57768 m .55595 .57729 L .55533 .5771 L F
.55825 .57768 m .55646 .57875 L .55392 .57695 L F
.261 .171 .56 r
.55751 .57764 m .55861 .57583 L .55671 .5742 L F
.648 .151 .056 r
.55533 .5771 m .55392 .57695 L .5552 .57707 L F
.55595 .57729 m .55392 .57695 L .55533 .5771 L F
.573 .367 .564 r
.55392 .57695 m .5574 .57777 L .55671 .5742 L F
.536 .39 .63 r
.55844 .57668 m .55704 .5784 L .55825 .57768 L F
.55861 .57583 m .55747 .57769 L .55844 .57668 L F
.55747 .57769 m .55704 .5784 L .55844 .57668 L F
.55751 .57764 m .55673 .57859 L .55704 .5784 L F
.579 .275 .417 r
.5574 .57777 m .55646 .57875 L .55754 .57781 L F
.55392 .57695 m .55646 .57875 L .5574 .57777 L F
.573 .367 .564 r
.5574 .57777 m .55754 .57781 L .55751 .57764 L F
.5574 .57777 m .55751 .57764 L .55671 .5742 L F
.536 .39 .63 r
.55861 .57583 m .55646 .57875 L .55673 .57859 L F
.55861 .57583 m .55673 .57859 L .55751 .57764 L F
.261 .171 .56 r
.55754 .57779 m .55861 .57583 L .55751 .57764 L F
.55754 .57781 m .55755 .57779 L .55754 .57779 L F
.55755 .57779 m .55861 .57583 L .55754 .57779 L F
.352 .061 .323 r
.48079 .59267 m .48104 .59543 L .48323 .5924 L F
.861 .571 .497 r
.49427 .58649 m .49019 .58579 L .49177 .58696 L F
.49427 .58649 m .49052 .58753 L .49019 .58579 L F
.563 .41 .632 r
.49427 .58649 m .49703 .58628 L .49678 .58306 L F
.471 .268 .522 r
.49703 .58628 m .49483 .58904 L .49427 .58649 L F
.563 .41 .632 r
.49427 .58649 m .49703 .58628 L .49678 .58306 L F
.471 .268 .522 r
.49703 .58628 m .49483 .58904 L .49427 .58649 L F
.668 .815 .954 r
.50904 .52631 m .50536 .52586 L .5084 .52343 L F
.789 .857 .901 r
.69475 .43376 m .69793 .43365 L .69675 .43225 L F
.713 .838 .942 r
.69675 .43225 m .69793 .43365 L .70035 .43245 L F
.724 .924 .959 r
.68593 .43462 m .68007 .43675 L .68468 .43307 L F
.834 .863 .866 r
.68781 .43241 m .68593 .43462 L .68468 .43307 L F
.287 0 .152 r
.5652 .60043 m .56586 .59902 L .56843 .59826 L F
.879 .93 .851 r
.18936 .72925 m .19261 .72766 L .19144 .72675 L F
.201 0 .342 r
.57865 .53462 m .57702 .53564 L .5766 .53782 L F
.9 .783 .723 r
.60912 .47193 m .60757 .4749 L .61024 .47557 L F
.907 .714 .63 r
.60698 .47744 m .61024 .47557 L .60757 .4749 L F
.60698 .47744 m .60998 .47873 L .61024 .47557 L F
.556 .614 .866 r
.77595 .39211 m .77878 .39572 L .77771 .39207 L F
.948 .605 .203 r
.77771 .39207 m .77705 .39331 L .77703 .39201 L F
0 0 0 r
.777 .3917 m .77848 .39106 L .77529 .3918 L F
.77756 .39166 m .77813 .39129 L .777 .3917 L F
.77813 .39129 m .77848 .39106 L .777 .3917 L F
.697 .816 .939 r
.77595 .39211 m .77598 .39207 L .77353 .39361 L F
0 0 0 r
.77684 .39141 m .77529 .3918 L .7739 .39058 L F
.77746 .39159 m .777 .3917 L .77684 .39141 L F
.252 .502 .899 r
.7772 .39081 m .77746 .39159 L .7739 .39058 L F
.77721 .39081 m .77727 .391 L .7772 .39081 L F
.77727 .391 m .77746 .39159 L .7772 .39081 L F
.697 .816 .939 r
.77661 .39101 m .77746 .39159 L .777 .39035 L F
.77746 .39159 m .77727 .391 L .777 .39035 L F
.252 .502 .899 r
.77666 .38987 m .77721 .39081 L .7739 .39058 L F
.948 .605 .203 r
.77727 .391 m .77701 .39099 L .777 .39035 L F
.697 .816 .939 r
.77746 .39159 m .77754 .39164 L .77727 .391 L F
.948 .605 .203 r
.77754 .39164 m .77751 .3916 L .77727 .391 L F
.77751 .3916 m .77701 .39099 L .77727 .391 L F
.252 .502 .899 r
.77721 .39081 m .7777 .39166 L .77746 .39159 L F
0 0 0 r
.77751 .3916 m .77749 .3916 L .77746 .39159 L F
.77749 .3916 m .777 .3917 L .77746 .39159 L F
.697 .816 .939 r
.77598 .39207 m .77755 .39167 L .77754 .39164 L F
0 0 0 r
.77756 .39166 m .777 .3917 L .77751 .3916 L F
.777 .3917 m .77529 .3918 L .77684 .39141 L F
.697 .816 .939 r
.77598 .39207 m .77754 .39164 L .77661 .39101 L F
.77595 .39211 m .77771 .39207 L .77755 .39167 L F
.948 .605 .203 r
.77755 .39167 m .77703 .39201 L .77701 .39099 L F
.77755 .39167 m .77701 .39099 L .77754 .39164 L F
0 0 0 r
.7777 .39166 m .77756 .39166 L .77751 .3916 L F
.697 .816 .939 r
.77598 .39207 m .77661 .39101 L .77467 .39254 L F
.77661 .39101 m .777 .39035 L .7765 .39082 L F
.77661 .39101 m .7765 .39082 L .77467 .39254 L F
.77598 .39207 m .77467 .39254 L .77353 .39361 L F
.948 .605 .203 r
.77771 .39207 m .77703 .39201 L .77755 .39167 L F
0 0 0 r
.77757 .39166 m .78034 .39063 L .77848 .39106 L F
.77757 .39166 m .77848 .39106 L .77756 .39166 L F
.7777 .39166 m .77789 .39158 L .77757 .39166 L F
.77789 .39158 m .78034 .39063 L .77757 .39166 L F
.697 .816 .939 r
.77595 .39211 m .77755 .39167 L .77598 .39207 L F
.478 .311 .575 r
.23468 .61305 m .2368 .60971 L .23503 .6103 L F
.466 .216 .45 r
.45626 .57067 m .45859 .57023 L .45807 .56766 L F
.837 .739 .217 r
.45807 .56766 m .45786 .56731 L .45824 .56511 L F
.758 .482 0 r
.45807 .56766 m .45816 .56898 L .45786 .56731 L F
.45807 .56766 m .45859 .57023 L .45816 .56898 L F
.759 .65 .741 r
.47209 .58577 m .47335 .58942 L .46947 .58905 L F
.493 .292 .535 r
.47191 .59094 m .46947 .58905 L .47335 .58942 L F
.58 .593 .83 r
.47365 .58413 m .47335 .58942 L .47209 .58577 L F
.47365 .58413 m .47645 .58957 L .47335 .58942 L F
.436 0 0 r
.47335 .58942 m .47469 .59099 L .47191 .59094 L F
.47335 .58942 m .47617 .58956 L .47469 .59099 L F
.496 0 0 r
.47359 .59225 m .47191 .59094 L .47469 .59099 L F
.47359 .59225 m .46966 .59249 L .47191 .59094 L F
.579 .318 .485 r
.47268 .58912 m .47251 .59199 L .47328 .59186 L F
.003 0 .36 r
.47511 .58897 m .47374 .59191 L .47469 .59099 L F
.47496 .5892 m .47374 .59191 L .47511 .58897 L F
.47374 .59191 m .47359 .59225 L .47469 .59099 L F
.47514 .5888 m .47496 .5892 L .47511 .58897 L F
.436 0 0 r
.47617 .58956 m .47645 .58957 L .47469 .59099 L F
.093 0 0 r
.47469 .59099 m .47645 .58957 L .47779 .58955 L F
.47469 .59099 m .47779 .58955 L .47633 .58963 L F
.003 0 .36 r
.47514 .5888 m .47469 .59099 L .47633 .58963 L F
.47514 .5888 m .475 .59158 L .47359 .59225 L F
.579 .318 .485 r
.47408 .5906 m .47328 .59186 L .475 .59158 L F
.47268 .58912 m .47328 .59186 L .47408 .5906 L F
.942 .706 .553 r
.42831 .64298 m .42977 .64558 L .43063 .64192 L F
.42831 .64298 m .42841 .64551 L .42977 .64558 L F
.467 .195 .417 r
.42977 .64558 m .42901 .64863 L .42841 .64551 L F
.42977 .64558 m .43146 .64835 L .42901 .64863 L F
.463 .424 .729 r
.43285 .64159 m .42977 .64558 L .43063 .64192 L F
.43285 .64159 m .43391 .64551 L .42977 .64558 L F
.659 .906 .581 r
.43391 .64551 m .43146 .64835 L .42977 .64558 L F
.942 .706 .553 r
.42977 .64558 m .42841 .64551 L .42831 .64298 L F
.399 .445 .792 r
.75269 .39668 m .7528 .39931 L .75564 .39993 L F
.048 0 0 r
.2086 .68662 m .20706 .68847 L .20953 .68709 L F
0 0 0 r
.18024 .56019 m .1777 .56073 L .17654 .56089 L F
.337 .816 .787 r
.17979 .55995 m .1777 .56073 L .18024 .56019 L F
0 0 0 r
.17931 .5605 m .1777 .56073 L .17979 .55995 L F
.17813 .56185 m .1777 .56073 L .17931 .5605 L F
.17654 .56089 m .1777 .56073 L .17572 .56105 L F
.337 .816 .787 r
.17979 .55995 m .18024 .56019 L .18231 .55947 L F
.43 .197 .458 r
.61053 .43107 m .6127 .43245 L .61232 .43038 L F
.61053 .43107 m .61022 .43328 L .6127 .43245 L F
.105 .529 .911 r
.48118 .6065 m .48368 .60794 L .48161 .60647 L F
.753 .622 .714 r
.48161 .60647 m .48619 .60783 L .48466 .6036 L F
.676 .582 .742 r
.48466 .6036 m .48619 .60783 L .48878 .60674 L F
.528 .92 .894 r
.48878 .60674 m .48619 .60783 L .48546 .60774 L F
.48826 .60699 m .48546 .60774 L .48703 .60757 L F
.48878 .60674 m .4871 .60725 L .48826 .60699 L F
.4871 .60725 m .48546 .60774 L .48826 .60699 L F
.481 .073 .188 r
.48368 .60794 m .4841 .60792 L .48161 .60647 L F
.4841 .60792 m .48619 .60783 L .48547 .60761 L F
.4841 .60792 m .48547 .60761 L .48161 .60647 L F
.48368 .60794 m .48571 .60901 L .48619 .60783 L F
.286 0 .094 r
.17342 .56165 m .16967 .5646 L .17127 .56237 L F
.504 0 0 r
.41761 .65397 m .41383 .65151 L .41506 .65252 L F
.391 .304 .637 r
.2464 .59257 m .24844 .59436 L .24819 .59194 L F
.406 .305 .626 r
.2464 .59257 m .24677 .59525 L .24844 .59436 L F
.744 .987 .775 r
.20848 .67697 m .20613 .67913 L .20657 .6778 L F
.566 .349 .545 r
.20613 .67913 m .20869 .67934 L .20848 .67697 L F
.551 .013 0 r
.20657 .6778 m .21049 .67819 L .20848 .67697 L F
.654 .744 .916 r
.42818 .57734 m .43034 .57763 L .42919 .57562 L F
.343 .566 .921 r
.42919 .57562 m .43034 .57763 L .43116 .57615 L F
.202 .359 .799 r
.21492 .68224 m .21723 .68447 L .21561 .68488 L F
.214 .214 .643 r
.21723 .68447 m .21622 .68724 L .21561 .68488 L F
.716 .834 .938 r
.65829 .42925 m .65631 .43038 L .65951 .43052 L F
.885 .856 .808 r
.65829 .42925 m .65951 .43052 L .66187 .42601 L F
.767 .801 .88 r
.70682 .41867 m .70734 .42142 L .70402 .42105 L F
.771 .803 .879 r
.71022 .41886 m .70734 .42142 L .70682 .41867 L F
.284 .672 .972 r
.16977 .62566 m .17003 .62679 L .16781 .62564 L F
.16977 .62566 m .17231 .62707 L .17003 .62679 L F
.382 .069 .306 r
.44268 .57753 m .43738 .58242 L .44249 .579 L F
.602 .253 .351 r
.44249 .579 m .44483 .57941 L .44268 .57753 L F
.509 .277 .498 r
.44268 .57753 m .44483 .57941 L .44492 .57705 L F
.658 .409 .531 r
.65758 .40991 m .65692 .40782 L .65842 .40974 L F
.773 .752 .834 r
.65692 .40782 m .65842 .40974 L .66106 .4069 L F
.649 .099 0 r
.65692 .40782 m .66057 .41026 L .65842 .40974 L F
.738 .235 .034 r
.7937 .43212 m .79006 .42984 L .79184 .43016 L F
.7937 .43212 m .79239 .43196 L .79136 .43102 L F
.79211 .43113 m .79136 .43102 L .79006 .42984 L F
.7937 .43212 m .79136 .43102 L .79211 .43113 L F
.654 .099 0 r
.79102 .43068 m .79388 .43139 L .79184 .43016 L F
.838 .893 .879 r
.79575 .4275 m .79389 .43137 L .79102 .43068 L F
.79389 .43137 m .79388 .43139 L .79368 .43134 L F
.79389 .43137 m .79368 .43134 L .79102 .43068 L F
.654 .099 0 r
.79102 .43068 m .79184 .43016 L .79006 .42984 L F
.45 .139 .347 r
.44127 .58663 m .44121 .58833 L .43852 .58884 L F
.622 .276 .363 r
.44127 .58663 m .44369 .58859 L .44121 .58833 L F
.259 .185 .579 r
.70827 .39497 m .71071 .39616 L .71075 .39425 L F
.45 .234 .493 r
.50984 .60437 m .51027 .609 L .50796 .60775 L F
.449 .352 .653 r
.51265 .6034 m .50984 .60437 L .51046 .60388 L F
.51265 .6034 m .51308 .60667 L .50984 .60437 L F
.409 .1 .326 r
.51308 .60667 m .51027 .609 L .50984 .60437 L F
.499 .254 .474 r
.4443 .64572 m .44712 .64268 L .44542 .64417 L F
.44712 .64268 m .4443 .64572 L .44542 .64417 L F
.643 .767 .298 r
.76835 .4006 m .76708 .40336 L .76767 .40207 L F
.854 .995 .756 r
.76852 .39891 m .76835 .4006 L .76834 .39974 L F
.715 .957 .948 r
.7658 .39989 m .76804 .40039 L .76479 .40191 L F
.756 .626 .716 r
.76805 .40055 m .76767 .40207 L .76479 .40191 L F
.812 .794 .298 r
.76834 .39974 m .76835 .4006 L .76799 .40139 L F
.76802 .40086 m .76799 .40139 L .76767 .40207 L F
.76834 .39974 m .76799 .40139 L .76802 .40086 L F
.756 .626 .716 r
.76829 .40045 m .76767 .40207 L .76805 .40055 L F
.787 .78 .278 r
.76813 .40021 m .76834 .39974 L .76802 .40086 L F
.76855 .39793 m .76841 .39909 L .76813 .40021 L F
.76841 .39909 m .76834 .39974 L .76813 .40021 L F
.715 .957 .948 r
.76804 .40039 m .76807 .4004 L .76803 .40055 L F
.76807 .4004 m .76805 .40055 L .76803 .40055 L F
.787 .78 .278 r
.76855 .39793 m .76813 .40021 L .76811 .39999 L F
.76813 .40021 m .76802 .40086 L .76805 .40055 L F
.76813 .40021 m .76805 .40055 L .76811 .39999 L F
.756 .626 .716 r
.76805 .40055 m .76767 .40207 L .76829 .40045 L F
.76479 .40191 m .76767 .40207 L .76805 .40055 L F
.715 .957 .948 r
.76479 .40191 m .76716 .40092 L .7658 .39989 L F
.76716 .40092 m .76829 .40045 L .76777 .40033 L F
.76716 .40092 m .76777 .40033 L .7658 .39989 L F
.787 .78 .278 r
.76912 .39901 m .76767 .40207 L .77036 .40157 L F
.469 .411 .711 r
.76767 .40207 m .77017 .40347 L .77033 .40158 L F
.77017 .40347 m .77049 .40365 L .77035 .40186 L F
.77017 .40347 m .77035 .40186 L .77033 .40158 L F
.87 .714 .686 r
.7704 .40154 m .77049 .40365 L .77035 .40186 L F
.469 .411 .711 r
.77033 .40158 m .77049 .40365 L .77036 .40157 L F
.971 .789 .6 r
.77036 .40178 m .77049 .40365 L .77037 .4018 L F
.76965 .40065 m .7702 .40261 L .77036 .40178 L F
.611 .899 .987 r
.76893 .40545 m .77049 .40365 L .76767 .40207 L F
.87 .714 .686 r
.77035 .40186 m .77049 .40365 L .76993 .40462 L F
.971 .789 .6 r
.7702 .40261 m .77049 .40365 L .77036 .40178 L F
.87 .714 .686 r
.77038 .40162 m .77034 .40186 L .76948 .40467 L F
.77034 .40186 m .76993 .40462 L .76983 .40463 L F
.77034 .40186 m .76983 .40463 L .76948 .40467 L F
.971 .789 .6 r
.77033 .40146 m .77038 .40167 L .7704 .40154 L F
.77038 .40167 m .77042 .40187 L .7704 .40154 L F
.87 .714 .686 r
.7704 .40154 m .77035 .40186 L .77037 .40173 L F
.7704 .40154 m .77037 .40173 L .77038 .40162 L F
.77035 .40186 m .76993 .40462 L .77038 .40162 L F
.971 .789 .6 r
.77037 .4018 m .77049 .40365 L .77042 .40187 L F
.469 .411 .711 r
.77036 .40157 m .77049 .40365 L .77049 .40155 L F
.971 .789 .6 r
.76965 .40065 m .77042 .40187 L .77033 .40146 L F
.787 .78 .278 r
.77027 .40113 m .77036 .40157 L .77049 .40155 L F
.76912 .39901 m .77036 .40157 L .77027 .40113 L F
.947 .935 .592 r
.76936 .39548 m .77053 .3943 L .76852 .39891 L F
.811 .826 .35 r
.76852 .39891 m .76834 .39974 L .76855 .39793 L F
.787 .78 .278 r
.76855 .39793 m .76811 .39999 L .76912 .39901 L F
.76811 .39999 m .76802 .40086 L .76767 .40207 L F
.715 .957 .948 r
.76807 .4004 m .76829 .40045 L .76805 .40055 L F
.787 .78 .278 r
.76811 .39999 m .76767 .40207 L .76912 .39901 L F
.715 .957 .948 r
.76804 .40039 m .76803 .40055 L .76479 .40191 L F
0 0 .496 r
.4122 .64896 m .41178 .64852 L .41122 .64795 L F
.428 .493 .824 r
.40439 .64455 m .40558 .64166 L .40347 .64252 L F
.40439 .64455 m .40727 .64529 L .40558 .64166 L F
.562 .356 .559 r
.57397 .56822 m .57159 .57082 L .57159 .5687 L F
.803 .713 .765 r
.61517 .45436 m .61873 .45499 L .61753 .45146 L F
.803 .694 .745 r
.61482 .45669 m .61873 .45499 L .61517 .45436 L F
.61482 .45669 m .61659 .45808 L .61873 .45499 L F
.544 .329 .539 r
.47475 .60039 m .4781 .60091 L .47829 .59795 L F
.414 .322 .643 r
.47629 .60296 m .4781 .60091 L .47475 .60039 L F
.592 .877 .993 r
.73207 .39589 m .73328 .39681 L .73062 .39771 L F
.73062 .39771 m .73328 .39681 L .73207 .39589 L F
.73207 .39589 m .73328 .39681 L .73062 .39771 L F
.93 .918 .537 r
.7566 .39077 m .75691 .3914 L .75588 .39225 L F
.147 .281 .745 r
.75629 .38833 m .75748 .39199 L .75764 .38864 L F
.93 .918 .537 r
.75764 .38864 m .75691 .3914 L .7566 .39077 L F
.712 .976 .919 r
.75748 .39199 m .75724 .39208 L .75691 .3914 L F
.75724 .39208 m .75379 .39338 L .75691 .3914 L F
.955 .936 .607 r
.75764 .38864 m .75748 .39199 L .75691 .3914 L F
.729 .789 .901 r
.70035 .43245 m .70456 .43195 L .70311 .4304 L F
.796 .814 .866 r
.70311 .4304 m .70456 .43195 L .70646 .43053 L F
.394 .463 .813 r
.76176 .38682 m .75998 .38886 L .75871 .38529 L F
.397 .467 .816 r
.76176 .38682 m .76281 .38983 L .75998 .38886 L F
.93 .907 .778 r
.60431 .49533 m .60715 .49317 L .6064 .49183 L F
.60431 .49533 m .60538 .49633 L .60715 .49317 L F
.469 .808 .999 r
.1937 .63313 m .19327 .63441 L .19157 .63324 L F
.1937 .63313 m .19544 .634 L .19327 .63441 L F
.891 .782 .735 r
.58899 .49658 m .58645 .49577 L .58812 .49281 L F
.822 .69 .719 r
.58802 .49872 m .58645 .49577 L .58899 .49658 L F
.298 .647 .968 r
.26147 .54211 m .26102 .54335 L .25856 .5413 L F
.26147 .54211 m .26297 .54347 L .26102 .54335 L F
.507 .102 .207 r
.48816 .60373 m .49065 .60377 L .49078 .60228 L F
.588 .17 .216 r
.49078 .60228 m .49065 .60377 L .49354 .60323 L F
.442 .346 .651 r
.28323 .56439 m .2836 .57053 L .28134 .56909 L F
.149 .08 .516 r
.2836 .57053 m .2827 .57094 L .28134 .56909 L F
.557 .388 .608 r
.26832 .61224 m .26572 .61042 L .26828 .61007 L F
.26832 .61224 m .26597 .61281 L .26572 .61042 L F
.343 0 .188 r
.54572 .58287 m .54553 .58501 L .54313 .58569 L F
.327 .385 .77 r
.54549 .58031 m .54803 .58213 L .54572 .58287 L F
.111 0 .148 r
.54803 .58213 m .54553 .58501 L .54572 .58287 L F
.581 .036 0 r
.21304 .55337 m .21114 .55357 L .20916 .55268 L F
.226 0 0 r
.21552 .55343 m .21114 .55357 L .21304 .55337 L F
.27 .735 .947 r
.22528 .55262 m .22354 .55197 L .22135 .55208 L F
.441 0 0 r
.22748 .55223 m .22354 .55197 L .22528 .55262 L F
.651 .195 .156 r
.21125 .68832 m .20891 .68986 L .20706 .68847 L F
.685 .241 .19 r
.21125 .68832 m .2132 .69028 L .20891 .68986 L F
.213 .243 .676 r
.21197 .68764 m .2132 .69028 L .21125 .68832 L F
.486 .281 .527 r
.53225 .54923 m .53537 .54954 L .53559 .547 L F
.282 .014 .318 r
.22564 .62318 m .22691 .62363 L .2274 .62215 L F
.22564 .62318 m .22482 .625 L .22691 .62363 L F
.758 .862 .926 r
.7531 .43265 m .75665 .43244 L .75616 .43016 L F
.868 .888 .847 r
.75616 .43016 m .75665 .43244 L .75832 .43042 L F
0 0 0 r
.72173 .38564 m .71885 .38838 L .72086 .38702 L F
.003 0 0 r
.72408 .38453 m .72173 .38564 L .72086 .38702 L F
.762 .523 0 r
.23008 .64721 m .23057 .64917 L .23012 .64641 L F
.23008 .64721 m .23012 .64641 L .2301 .6463 L F
.093 0 0 r
.23407 .64477 m .23139 .64738 L .23008 .64721 L F
.067 0 .209 r
.23008 .64721 m .23139 .64738 L .23178 .64663 L F
.651 .351 .45 r
.23178 .64663 m .23005 .64787 L .23008 .64721 L F
.901 .68 .593 r
.22726 .64971 m .23057 .64917 L .23008 .64721 L F
.651 .351 .45 r
.23005 .64787 m .22978 .64806 L .23008 .64721 L F
.762 .523 0 r
.23008 .64721 m .2301 .6463 L .23203 .64552 L F
.172 0 0 r
.55779 .50023 m .55621 .49948 L .5589 .49845 L F
.55779 .50023 m .55536 .50102 L .55621 .49948 L F
.025 0 0 r
.57185 .47451 m .57497 .47236 L .57288 .47333 L F
.37 .694 .982 r
.20613 .67913 m .20869 .67934 L .20657 .6778 L F
.899 .793 .734 r
.61845 .44469 m .61946 .44846 L .62033 .44578 L F
.61845 .44469 m .61652 .44788 L .61946 .44846 L F
.86 .697 .679 r
.61588 .45006 m .61946 .44846 L .61652 .44788 L F
.61588 .45006 m .61753 .45146 L .61946 .44846 L F
.849 .773 .777 r
.61261 .45987 m .61041 .463 L .61366 .46334 L F
.854 .757 .755 r
.61041 .463 m .61142 .46643 L .61366 .46334 L F
.825 .762 .792 r
.61261 .45987 m .61366 .46334 L .6158 .46037 L F
.785 .731 .803 r
.75319 .37419 m .75107 .37811 L .74953 .37342 L F
.585 .744 .952 r
.75107 .37811 m .75255 .37552 L .74997 .37619 L F
.75107 .37811 m .75388 .37748 L .75255 .37552 L F
.589 .341 .508 r
.70252 .40011 m .70525 .39753 L .70255 .39799 L F
.961 .935 .712 r
.60307 .49865 m .60538 .49633 L .60431 .49533 L F
.60307 .49865 m .60381 .49979 L .60538 .49633 L F
.431 0 .082 r
.4366 .58316 m .43832 .58413 L .43983 .58146 L F
.773 .964 .927 r
.44249 .579 m .43983 .58146 L .44307 .57991 L F
.44249 .579 m .43738 .58242 L .43983 .58146 L F
.418 .069 .263 r
.43832 .58413 m .44307 .57991 L .43983 .58146 L F
0 0 0 r
.19645 .5413 m .20041 .54115 L .19808 .5409 L F
.4 0 .124 r
.1778 .54612 m .18181 .54371 L .17993 .5447 L F
.935 .582 .33 r
.44025 .56143 m .44094 .56363 L .43944 .56213 L F
0 0 0 r
.44025 .56143 m .43944 .56213 L .43983 .5619 L F
.723 .195 0 r
.44275 .5621 m .44025 .56143 L .44077 .56086 L F
.915 .576 .385 r
.44275 .5621 m .44094 .56363 L .44025 .56143 L F
0 0 0 r
.44025 .56143 m .43983 .5619 L .44208 .56054 L F
.723 .195 0 r
.44077 .56086 m .44025 .56143 L .43853 .55945 L F
.71 .256 .172 r
.44472 .56421 m .44094 .56363 L .44275 .5621 L F
.539 .377 .609 r
.27293 .60333 m .27061 .60678 L .27069 .60421 L F
.877 .863 .823 r
.41136 .63919 m .41515 .63724 L .41353 .63743 L F
.41136 .63919 m .41256 .64058 L .41515 .63724 L F
.566 .495 .735 r
.41656 .63298 m .41515 .63724 L .41421 .63395 L F
.906 .746 .672 r
.53899 .55246 m .54026 .55597 L .54153 .55305 L F
.617 .649 .859 r
.75726 .37693 m .75319 .37419 L .75549 .37383 L F
.792 .826 .878 r
.75388 .37748 m .75726 .37693 L .75799 .37705 L F
.266 .453 .859 r
.758 .37513 m .75726 .37693 L .75549 .37383 L F
0 0 .348 r
.75799 .37705 m .75726 .37693 L .758 .37513 L F
.421 .072 .265 r
.1538 .55571 m .15599 .55533 L .15678 .55369 L F
.415 .065 .261 r
.15678 .55369 m .15599 .55533 L .159 .55344 L F
.79 .934 .926 r
.51831 .5992 m .5164 .60133 L .51478 .60101 L F
.586 .906 .981 r
.51478 .60101 m .5164 .60133 L .51764 .5998 L F
.79 .934 .926 r
.51831 .5992 m .51478 .60101 L .51252 .60002 L F
.584 .869 .551 r
.51764 .5998 m .5164 .60133 L .51808 .59946 L F
.586 .906 .981 r
.51478 .60101 m .51764 .5998 L .51716 .60239 L F
.833 .365 0 r
.51717 .60016 m .51764 .5998 L .51611 .59887 L F
.259 .147 .53 r
.51886 .60223 m .51716 .60239 L .51764 .5998 L F
.833 .365 0 r
.51886 .60223 m .51764 .5998 L .51717 .60016 L F
.584 .869 .551 r
.51764 .5998 m .51808 .59946 L .51831 .5992 L F
0 .274 .712 r
.45756 .55802 m .4574 .55827 L .45543 .55711 L F
.45756 .55802 m .45892 .55908 L .4574 .55827 L F
0 .184 .717 r
.41367 .64074 m .41256 .64058 L .41136 .63919 L F
.41367 .64074 m .4157 .64387 L .41256 .64058 L F
.803 .445 .378 r
.58838 .49027 m .58468 .48757 L .5885 .4877 L F
.861 .922 .869 r
.4563 .57474 m .45558 .57668 L .45324 .57694 L F
0 .431 .741 r
.2475 .53981 m .24922 .54029 L .25103 .54095 L F
.207 .639 .951 r
.25132 .5401 m .25103 .54095 L .24922 .54029 L F
.25132 .5401 m .2531 .54126 L .25103 .54095 L F
.72 .778 .898 r
.70878 .42985 m .71298 .42902 L .7117 .42726 L F
.721 .801 .914 r
.7117 .42726 m .71298 .42902 L .71521 .42763 L F
.842 .72 .729 r
.61482 .45669 m .6158 .46037 L .61659 .45808 L F
.61482 .45669 m .61261 .45987 L .6158 .46037 L F
.266 0 .172 r
.24846 .63401 m .2454 .63644 L .24635 .63473 L F
.557 .84 .998 r
.47311 .55999 m .47396 .55826 L .4754 .55947 L F
.47311 .55999 m .47158 .55895 L .47396 .55826 L F
.317 0 0 r
.2085 .53894 m .20716 .5398 L .21066 .53929 L F
0 0 0 r
.20934 .53947 m .20993 .53935 L .21066 .53929 L F
.20993 .53935 m .21305 .53872 L .21066 .53929 L F
.183 0 0 r
.2119 .53919 m .21066 .53929 L .21286 .53926 L F
.2085 .53894 m .21066 .53929 L .2119 .53919 L F
.387 .837 .926 r
.21066 .53929 m .21496 .53903 L .21286 .53926 L F
.538 .232 .397 r
.47871 .59454 m .47991 .59561 L .48079 .59267 L F
.352 .061 .323 r
.48079 .59267 m .48237 .59424 L .48104 .59543 L F
.48079 .59267 m .47991 .59561 L .48237 .59424 L F
.581 .397 .597 r
.56496 .55315 m .56791 .55281 L .56759 .55028 L F
.492 .322 .577 r
.565 .55595 m .56791 .55281 L .56496 .55315 L F
.354 .111 .4 r
.71271 .40319 m .71295 .40117 L .71534 .40016 L F
.092 0 0 r
.20236 .54015 m .20473 .53995 L .20669 .53938 L F
.945 .813 .363 r
.65513 .4243 m .65504 .41971 L .65543 .42201 L F
.961 .78 .612 r
.51305 .53172 m .51243 .53485 L .51424 .53584 L F
0 0 .179 r
.51446 .53601 m .51424 .53584 L .51243 .53485 L F
.397 .182 .467 r
.51424 .53584 m .51468 .53807 L .51665 .53475 L F
0 0 .179 r
.51446 .53601 m .51468 .53807 L .51424 .53584 L F
.462 .312 .592 r
.51424 .53584 m .51665 .53475 L .51595 .53408 L F
.769 .842 .907 r
.70524 .42908 m .70311 .4304 L .70646 .43053 L F
.712 .825 .935 r
.70524 .42908 m .70646 .43053 L .70878 .42985 L F
.42 .008 .148 r
.69657 .40204 m .69722 .4004 L .6938 .40159 L F
.477 .111 .264 r
.69889 .40236 m .69722 .4004 L .69657 .40204 L F
.69889 .40236 m .69995 .40003 L .69722 .4004 L F
.659 .637 .817 r
.74255 .39897 m .74405 .40219 L .7456 .4002 L F
.75 .666 .768 r
.54144 .55938 m .5443 .55684 L .54026 .55597 L F
.744 .391 .385 r
.53806 .57901 m .54184 .57939 L .53957 .57655 L F
.704 .301 .283 r
.43126 .66 m .43472 .65871 L .43116 .65838 L F
0 0 .26 r
.43472 .65871 m .43521 .66034 L .43524 .66092 L F
.704 .301 .283 r
.43126 .66 m .43521 .66034 L .43472 .65871 L F
.915 .521 .232 r
.50584 .57645 m .50635 .57487 L .50633 .57356 L F
.50584 .57645 m .50736 .57715 L .50635 .57487 L F
.389 .576 .914 r
.76505 .39 m .76366 .39179 L .76281 .38983 L F
.167 .254 .71 r
.76606 .39372 m .76366 .39179 L .76505 .39 L F
.411 .451 .792 r
.57541 .57602 m .57308 .57752 L .57228 .57416 L F
.24 .236 .653 r
.57573 .57867 m .57308 .57752 L .57541 .57602 L F
.57573 .57867 m .57386 .58011 L .57308 .57752 L F
.889 .987 .801 r
.63206 .41972 m .6293 .42352 L .63019 .42383 L F
.345 .254 .608 r
.38764 .61314 m .38942 .60924 L .38706 .61067 L F
.846 .937 .564 r
.76316 .40572 m .76299 .4068 L .76458 .40357 L F
.969 .933 .642 r
.76316 .40572 m .76261 .40856 L .76299 .4068 L F
.193 0 .095 r
.43339 .57524 m .43192 .57416 L .43426 .57231 L F
.43339 .57524 m .43116 .57615 L .43192 .57416 L F
.519 .834 .999 r
.46788 .55907 m .46711 .56055 L .46502 .55987 L F
.46788 .55907 m .46941 .55992 L .46711 .56055 L F
.839 .55 .5 r
.43043 .66101 m .42875 .66317 L .42712 .6592 L F
.796 .487 .467 r
.43043 .66101 m .43251 .6639 L .42875 .66317 L F
.578 .483 .711 r
.57159 .57082 m .57228 .57416 L .56979 .57458 L F
.643 .425 .573 r
.43608 .56022 m .43491 .56142 L .43853 .55945 L F
.89 .972 .828 r
.50122 .52978 m .50217 .52646 L .50352 .52789 L F
.50122 .52978 m .5006 .52852 L .50217 .52646 L F
.958 .933 .723 r
.50069 .53034 m .5006 .52852 L .50122 .52978 L F
.9 .882 .454 r
.76376 .39929 m .76387 .40102 L .76486 .39776 L F
.645 .835 .427 r
.76376 .39929 m .76486 .39776 L .76509 .39725 L F
.487 .398 .68 r
.56005 .55929 m .56305 .56093 L .56261 .55916 L F
.56005 .55929 m .56061 .56284 L .56305 .56093 L F
.763 .602 .678 r
.67931 .40918 m .6824 .4098 L .68054 .41253 L F
.844 .548 .488 r
.6824 .4098 m .68294 .41264 L .68054 .41253 L F
0 0 0 r
.77468 .43007 m .77222 .43297 L .77524 .43088 L F
.77468 .43007 m .77247 .4329 L .77243 .43272 L F
.683 .912 .577 r
.77468 .43007 m .77351 .43114 L .77247 .4329 L F
.877 .952 .854 r
.77351 .43114 m .77251 .43311 L .77247 .4329 L F
.77251 .43311 m .77159 .43494 L .77247 .4329 L F
0 0 0 r
.77243 .43272 m .77247 .4329 L .77222 .43297 L F
.821 .827 .854 r
.45914 .61012 m .45654 .61285 L .45883 .61265 L F
.504 .356 .613 r
.56759 .55028 m .56991 .54981 L .56971 .5471 L F
.382 .198 .503 r
.56791 .55281 m .56991 .54981 L .56759 .55028 L F
.769 .825 .896 r
.68297 .44153 m .68712 .4406 L .68599 .43905 L F
.87 .912 .856 r
.68712 .4406 m .68889 .43626 L .68599 .43905 L F
.98 .719 .463 r
.44121 .57135 m .4412 .57406 L .44073 .57119 L F
.169 .225 .678 r
.38948 .61891 m .39 .61512 L .38862 .61575 L F
.38948 .61891 m .39065 .61901 L .39 .61512 L F
.174 .199 .646 r
.38948 .61891 m .39136 .6211 L .39065 .61901 L F
.358 .24 .58 r
.3896 .62146 m .39136 .6211 L .38948 .61891 L F
.579 .848 .995 r
.41761 .65397 m .41907 .65478 L .41895 .65335 L F
.331 .643 .966 r
.41907 .65478 m .42192 .65514 L .41895 .65335 L F
.724 .839 .935 r
.42754 .57439 m .42818 .57734 L .42919 .57562 L F
.892 .828 .777 r
.42754 .57439 m .42677 .57934 L .42818 .57734 L F
.895 .858 .797 r
.75616 .43016 m .75832 .43042 L .75965 .42813 L F
.444 .232 .496 r
.23976 .60435 m .24148 .60627 L .24161 .60365 L F
.23976 .60435 m .23936 .60682 L .24148 .60627 L F
.63 .632 .834 r
.21043 .67369 m .21487 .67601 L .21354 .67392 L F
.861 .773 .763 r
.21049 .67819 m .21256 .67921 L .21487 .67601 L F
.495 .267 .497 r
.21487 .67601 m .21256 .67921 L .21494 .67856 L F
.005 .325 .811 r
.21487 .67601 m .21529 .675 L .21354 .67392 L F
.98 .691 .325 r
.21487 .67601 m .21369 .67722 L .21529 .675 L F
.21487 .67601 m .21494 .67856 L .21369 .67722 L F
.579 .848 .995 r
.41761 .65397 m .42152 .65212 L .41988 .65128 L F
.41861 .6535 m .41895 .65335 L .42152 .65212 L F
0 0 .094 r
.42014 .65185 m .41977 .65298 L .41895 .65335 L F
.874 .572 .473 r
.41895 .65335 m .42192 .65514 L .42152 .65212 L F
0 0 .094 r
.41977 .65298 m .41891 .65561 L .41895 .65335 L F
.579 .848 .995 r
.41761 .65397 m .41895 .65335 L .41861 .6535 L F
.786 .507 .514 r
.42152 .65212 m .42192 .65514 L .42533 .65496 L F
.75 .412 .411 r
.67429 .40243 m .67608 .40045 L .67451 .39985 L F
.67429 .40243 m .678 .40295 L .67608 .40045 L F
.33 0 0 r
.69657 .40204 m .6938 .40159 L .69319 .40232 L F
.504 .591 .875 r
.38995 .62325 m .39136 .6211 L .3896 .62146 L F
.38995 .62325 m .39405 .62416 L .39136 .6211 L F
.367 .304 .654 r
.56213 .58307 m .5631 .58054 L .56223 .57982 L F
.477 .602 .898 r
.50119 .56688 m .49972 .56886 L .49895 .56703 L F
.525 0 0 r
.50079 .56998 m .50223 .571 L .49972 .56886 L F
.50079 .56998 m .49972 .56886 L .50119 .56688 L F
.343 .269 .628 r
.39944 .63685 m .40123 .6367 L .40072 .63387 L F
.376 .505 .861 r
.39944 .63685 m .40302 .63992 L .40123 .6367 L F
.459 .722 .982 r
.49787 .56555 m .49653 .5672 L .49366 .56399 L F
.49787 .56555 m .49895 .56703 L .49653 .5672 L F
.871 .838 .81 r
.62562 .43562 m .62707 .43678 L .62934 .4337 L F
.486 .587 .881 r
.63029 .43137 m .62934 .4337 L .62781 .43064 L F
.805 .95 .915 r
.63029 .43137 m .62826 .43286 L .62934 .4337 L F
0 .134 .681 r
.51097 .5825 m .51261 .58562 L .51137 .58398 L F
.895 .561 .072 r
.53005 .55298 m .53117 .55483 L .5308 .55296 L F
.897 .635 .534 r
.42873 .59373 m .42906 .59708 L .43293 .59812 L F
.708 .248 .156 r
.42894 .59921 m .43293 .59812 L .42906 .59708 L F
0 0 0 r
.43627 .5997 m .43374 .60044 L .43693 .59962 L F
.43386 .60039 m .43374 .60044 L .43627 .5997 L F
.43441 .60037 m .4349 .6001 L .43434 .60026 L F
.725 .505 .593 r
.43415 .60032 m .43528 .60003 L .43441 .60037 L F
.4343 .60025 m .43528 .60003 L .43415 .60032 L F
0 0 0 r
.43558 .59979 m .43386 .60039 L .43627 .5997 L F
.4349 .6001 m .43624 .59933 L .43434 .60026 L F
.43434 .60026 m .43624 .59933 L .43293 .59812 L F
.43452 .60015 m .43386 .60039 L .43504 .59998 L F
.435 .59999 m .43504 .59998 L .43558 .59979 L F
.43452 .60015 m .43504 .59998 L .435 .59999 L F
.725 .505 .593 r
.435 .59999 m .43437 .60024 L .43408 .6003 L F
0 0 0 r
.4346 .60016 m .43413 .60196 L .43376 .6005 L F
.43487 .60015 m .43413 .60196 L .4346 .60016 L F
.43504 .60051 m .43413 .60196 L .43479 .60035 L F
.43496 .60021 m .43479 .60035 L .43492 .60003 L F
.43504 .60051 m .43479 .60035 L .43496 .60021 L F
.381 .082 .327 r
.42923 .60226 m .43161 .60182 L .4323 .60149 L F
.43009 .60195 m .4323 .60149 L .43503 .60015 L F
.42923 .60226 m .4323 .60149 L .43009 .60195 L F
.42923 .60226 m .43503 .60015 L .43495 .60015 L F
0 0 0 r
.43492 .60003 m .43487 .60015 L .4346 .60016 L F
.43549 .5998 m .43452 .60015 L .43558 .59979 L F
.43549 .5998 m .43376 .6005 L .43452 .60015 L F
.725 .505 .593 r
.43491 .60002 m .42923 .60226 L .43495 .60015 L F
.42894 .59921 m .435 .59999 L .43408 .6003 L F
.42894 .59921 m .42915 .60138 L .435 .59999 L F
0 0 0 r
.43452 .60015 m .43376 .6005 L .43374 .60044 L F
.725 .505 .593 r
.43408 .6003 m .4343 .60025 L .43415 .60032 L F
.42915 .60138 m .42923 .60226 L .435 .59999 L F
.627 .629 .833 r
.43353 .6005 m .42902 .59712 L .43414 .60048 L F
.552 .924 .78 r
.43407 .60048 m .43161 .60182 L .43353 .6005 L F
.627 .629 .833 r
.43353 .6005 m .43414 .60048 L .43424 .60054 L F
.74 .748 .858 r
.43419 .60044 m .43414 .60048 L .42902 .59712 L F
.552 .924 .78 r
.43421 .6004 m .43407 .60048 L .43353 .6005 L F
.43513 .60007 m .43351 .60087 L .43453 .60023 L F
.74 .748 .858 r
.43419 .60044 m .43424 .60054 L .43414 .60048 L F
.549 .581 .839 r
.43424 .6004 m .43353 .6005 L .43424 .60054 L F
.74 .748 .858 r
.43182 .59548 m .43419 .60044 L .42902 .59712 L F
.374 .541 .892 r
.43437 .59585 m .43424 .6004 L .43182 .59548 L F
.43424 .6004 m .43424 .60054 L .43419 .60044 L F
.43424 .6004 m .43419 .60044 L .43182 .59548 L F
.552 .924 .78 r
.43351 .60087 m .43161 .60182 L .43428 .60037 L F
.43419 .60044 m .43428 .60037 L .43453 .60023 L F
.43351 .60087 m .43428 .60037 L .43419 .60044 L F
.549 .581 .839 r
.43437 .59585 m .43353 .6005 L .43424 .6004 L F
.552 .924 .78 r
.43453 .60023 m .43421 .6004 L .43353 .6005 L F
.43503 .60015 m .43161 .60182 L .43513 .60007 L F
.736 .593 .696 r
.43413 .60196 m .43796 .60324 L .43693 .59962 L F
.717 .258 .161 r
.43413 .60196 m .43641 .60338 L .43796 .60324 L F
0 0 0 r
.43528 .60003 m .43443 .6022 L .43549 .5998 L F
.43514 .60035 m .43443 .6022 L .43413 .60196 L F
1 .804 .494 r
.43526 .60003 m .43443 .6022 L .43528 .60003 L F
0 0 0 r
.43549 .5998 m .43443 .6022 L .43514 .60035 L F
.381 .082 .327 r
.43495 .60015 m .43503 .60015 L .43528 .60003 L F
.552 .924 .78 r
.43528 .60003 m .43503 .60015 L .43513 .60007 L F
.725 .505 .593 r
.435 .59999 m .43491 .60002 L .43507 .60002 L F
.4351 .6 m .43507 .60002 L .43528 .60003 L F
.435 .59999 m .43507 .60002 L .4351 .6 L F
0 0 0 r
.43441 .60037 m .43504 .60004 L .43624 .59933 L F
.43504 .60004 m .43549 .5998 L .436 .59948 L F
.43504 .60004 m .436 .59948 L .43624 .59933 L F
.725 .505 .593 r
.43491 .60002 m .43492 .60004 L .43528 .60003 L F
0 0 0 r
.43528 .60003 m .43504 .60004 L .43441 .60037 L F
.725 .505 .593 r
.43492 .60004 m .43495 .60015 L .43528 .60003 L F
0 0 0 r
.43528 .60003 m .43549 .5998 L .43504 .60004 L F
.43513 .59994 m .43504 .60051 L .43492 .60003 L F
1 .804 .494 r
.43513 .60007 m .43514 .60035 L .43526 .60003 L F
0 0 0 r
.43549 .5998 m .43514 .60035 L .43513 .59994 L F
.43514 .60035 m .43504 .60051 L .43513 .59994 L F
1 .804 .494 r
.43353 .6005 m .43443 .6022 L .43514 .60035 L F
.43353 .6005 m .43514 .60035 L .43513 .60007 L F
.987 .895 .577 r
.4358 .60001 m .43526 .60087 L .43353 .6005 L F
.43526 .60087 m .43443 .6022 L .43388 .60116 L F
.43526 .60087 m .43388 .60116 L .43353 .6005 L F
.712 .825 .935 r
.70524 .42908 m .70878 .42985 L .70726 .42793 L F
.729 .838 .932 r
.70726 .42793 m .70878 .42985 L .7117 .42726 L F
.975 .752 .539 r
.57135 .49653 m .57003 .49617 L .5701 .49288 L F
.614 .598 .811 r
.57339 .49549 m .57135 .49653 L .5701 .49288 L F
.474 0 .022 r
.57339 .49549 m .57003 .49617 L .57135 .49653 L F
.497 .384 .654 r
.28433 .57405 m .28279 .57736 L .28207 .57664 L F
.983 .909 .632 r
.60298 .50161 m .60381 .49979 L .60307 .49865 L F
.849 .861 .85 r
.68981 .42715 m .68979 .43029 L .68733 .42995 L F
.863 .846 .826 r
.68733 .42995 m .68979 .43029 L .68781 .43241 L F
.778 .807 .876 r
.69311 .42729 m .68979 .43029 L .68981 .42715 L F
.134 .137 .596 r
.19358 .70989 m .1955 .71071 L .19574 .70835 L F
.19358 .70989 m .194 .71201 L .1955 .71071 L F
.668 .908 .978 r
.19949 .65302 m .20349 .65243 L .20195 .65233 L F
.681 .971 .92 r
.20394 .65117 m .20349 .65243 L .20501 .65099 L F
.664 .959 .939 r
.20195 .65233 m .20349 .65243 L .20394 .65117 L F
.979 .842 .636 r
.62562 .43562 m .62614 .4385 L .62707 .43678 L F
.48 .807 1 r
.50565 .5351 m .50814 .53541 L .5068 .53455 L F
.774 .665 .743 r
.50814 .53541 m .50527 .53744 L .5044 .53494 L F
.48 .807 1 r
.5044 .53494 m .50517 .53503 L .5068 .53455 L F
.50517 .53503 m .50814 .53541 L .5068 .53455 L F
.693 .833 .398 r
.50907 .53331 m .50873 .53397 L .5068 .53455 L F
.50873 .53397 m .50746 .53637 L .5068 .53455 L F
.773 .651 .728 r
.50746 .53637 m .50907 .53331 L .5068 .53455 L F
.693 .833 .398 r
.50907 .53331 m .5068 .53455 L .50832 .53382 L F
.465 .886 .798 r
.50706 .5341 m .5068 .53455 L .50907 .53331 L F
.50706 .5341 m .50907 .53331 L .50827 .53394 L F
.693 .833 .398 r
.50907 .53331 m .50541 .53579 L .50827 .53394 L F
.687 .588 .739 r
.50218 .53372 m .50706 .5341 L .50492 .52987 L F
.656 .864 .978 r
.50706 .5341 m .50827 .53394 L .50712 .53201 L F
.50706 .5341 m .50708 .53356 L .50492 .52987 L F
.50708 .53356 m .50712 .53201 L .50652 .53142 L F
.50708 .53356 m .50652 .53142 L .50492 .52987 L F
.48 .807 1 r
.5044 .53494 m .50565 .5351 L .5068 .53455 L F
.238 0 .195 r
.50218 .53372 m .50541 .53579 L .50706 .5341 L F
.844 .831 .834 r
.5071 .53366 m .50541 .53579 L .50516 .53426 L F
.238 0 .195 r
.50218 .53372 m .50497 .53314 L .50541 .53579 L F
.693 .833 .398 r
.50832 .53382 m .5068 .53455 L .50615 .53513 L F
.50757 .53433 m .50615 .53513 L .50541 .53579 L F
.58 .871 .56 r
.50706 .5341 m .50541 .53579 L .5068 .53455 L F
.844 .831 .834 r
.50734 .53455 m .50541 .53579 L .5071 .53366 L F
.73 .543 .639 r
.5063 .53445 m .50629 .53583 L .50575 .53472 L F
.844 .831 .834 r
.5071 .53366 m .50516 .53426 L .50652 .53351 L F
.637 .543 .732 r
.50497 .53314 m .5016 .53545 L .5063 .53445 L F
.73 .543 .639 r
.5063 .53445 m .50575 .53472 L .50497 .53314 L F
.844 .831 .834 r
.50652 .53351 m .50516 .53426 L .50497 .53314 L F
.50827 .53394 m .50497 .53314 L .50712 .53201 L F
.50826 .53394 m .50497 .53314 L .50827 .53394 L F
.576 .477 .704 r
.50712 .53201 m .50655 .53463 L .50497 .53314 L F
.78 .295 0 r
.50622 .53453 m .50629 .53583 L .5063 .53445 L F
.576 .477 .704 r
.50622 .53467 m .50629 .53583 L .50575 .53472 L F
.78 .295 0 r
.50614 .5346 m .50629 .53583 L .50622 .53453 L F
.576 .477 .704 r
.50655 .53463 m .50629 .53583 L .50622 .53467 L F
.50655 .53463 m .50575 .53472 L .50497 .53314 L F
.319 0 .04 r
.50575 .53472 m .5063 .53445 L .50433 .53487 L F
.50097 .53715 m .5063 .53445 L .50158 .53669 L F
.693 .833 .398 r
.50832 .53382 m .50615 .53513 L .50757 .53433 L F
.319 0 .04 r
.50097 .53715 m .50145 .53708 L .5063 .53445 L F
.50145 .53708 m .50368 .53671 L .50567 .53499 L F
.50145 .53708 m .50567 .53499 L .5063 .53445 L F
.78 .295 0 r
.50506 .53559 m .50614 .5346 L .50368 .53671 L F
.50614 .5346 m .5063 .53445 L .50567 .53499 L F
.50614 .5346 m .50567 .53499 L .50368 .53671 L F
.788 .687 .752 r
.50568 .53076 m .50614 .5346 L .50712 .53201 L F
.50614 .5346 m .50616 .53475 L .50625 .53451 L F
.50614 .5346 m .50625 .53451 L .50712 .53201 L F
.50616 .53475 m .50629 .53583 L .50657 .53455 L F
.50616 .53475 m .50657 .53455 L .50712 .53201 L F
.50566 .53075 m .50629 .53583 L .50568 .53076 L F
.78 .295 0 r
.50506 .53559 m .50629 .53583 L .50614 .5346 L F
.319 0 .04 r
.50158 .53669 m .50575 .53472 L .50388 .53497 L F
.50575 .53472 m .50433 .53487 L .50388 .53497 L F
.50125 .53642 m .50388 .53497 L .5016 .53545 L F
.50097 .53715 m .50388 .53497 L .50125 .53642 L F
.844 .831 .834 r
.50827 .53394 m .50734 .53455 L .5071 .53366 L F
.50827 .53394 m .50826 .53394 L .50827 .53394 L F
.412 .177 .444 r
.39139 .60368 m .39382 .60078 L .39165 .60131 L F
.158 0 0 r
.72298 .39348 m .72323 .39224 L .72563 .39112 L F
.504 .294 .528 r
.38888 .6066 m .39139 .60368 L .38918 .60429 L F
0 .284 .703 r
.55646 .5954 m .5556 .59517 L .55416 .59449 L F
.55646 .5954 m .55667 .59564 L .5556 .59517 L F
.895 .858 .797 r
.75616 .43016 m .75965 .42813 L .75837 .42682 L F
.376 .35 .702 r
.5713 .58306 m .57384 .58505 L .57146 .58645 L F
.27 .153 .53 r
.57399 .58756 m .57146 .58645 L .57384 .58505 L F
.57399 .58756 m .57167 .58891 L .57146 .58645 L F
.221 .459 .876 r
.21573 .6513 m .21777 .65024 L .21381 .65115 L F
.21573 .6513 m .21812 .65249 L .21777 .65024 L F
0 0 0 r
.56318 .60147 m .56212 .60333 L .56029 .60399 L F
.147 0 0 r
.56434 .60247 m .56318 .60147 L .5652 .60043 L F
.56434 .60247 m .56212 .60333 L .56318 .60147 L F
.874 .695 .657 r
.52388 .54286 m .52542 .54662 L .52537 .54408 L F
.765 .882 .93 r
.52388 .54286 m .52537 .54408 L .52852 .54201 L F
.485 .552 .85 r
.78759 .40057 m .78394 .39744 L .78576 .39704 L F
.441 .238 .507 r
.43853 .55945 m .44025 .56143 L .44072 .5587 L F
.546 .396 .63 r
.43535 .62147 m .43265 .61923 L .43532 .61856 L F
.43535 .62147 m .43305 .62224 L .43265 .61923 L F
0 0 0 r
.52731 .51342 m .5295 .51235 L .53065 .51099 L F
.5295 .51235 m .53232 .51023 L .53065 .51099 L F
.413 0 0 r
.66057 .41026 m .66352 .41083 L .66445 .41038 L F
0 .422 .837 r
.66445 .41038 m .6673 .41153 L .66822 .41245 L F
.446 0 0 r
.66352 .41083 m .6673 .41153 L .66445 .41038 L F
.74 .457 .502 r
.47171 .58348 m .46893 .58586 L .46962 .58637 L F
.945 .953 .65 r
.46893 .58586 m .46851 .58721 L .46962 .58637 L F
.936 .746 .621 r
.66278 .42043 m .66354 .41872 L .66195 .4177 L F
.858 .82 .811 r
.66195 .4177 m .66354 .41872 L .66584 .41563 L F
0 0 0 r
.5433 .51135 m .5423 .51308 L .54095 .51445 L F
.946 .932 .585 r
.54095 .51445 m .53963 .51557 L .53938 .51859 L F
.372 .088 .346 r
.46249 .60064 m .45978 .60325 L .46023 .60134 L F
.389 .179 .47 r
.28427 .55569 m .28207 .55743 L .28216 .55639 L F
0 .161 .694 r
.76767 .40207 m .76708 .40336 L .76893 .40545 L F
.858 .82 .811 r
.66195 .4177 m .66584 .41563 L .66497 .41481 L F
.9 .962 .823 r
.66497 .41481 m .66584 .41563 L .66822 .41245 L F
.634 .554 .747 r
.21095 .66041 m .21199 .66406 L .21369 .66312 L F
.537 .288 .486 r
.57673 .56524 m .57633 .5677 L .57397 .56822 L F
.302 .096 .425 r
.57872 .56206 m .57962 .56414 L .57673 .56524 L F
.278 .046 .371 r
.57673 .56524 m .57884 .56651 L .57633 .5677 L F
.57673 .56524 m .57962 .56414 L .57884 .56651 L F
.929 .799 .696 r
.42097 .59546 m .42215 .5987 L .4211 .59574 L F
.42097 .59546 m .41938 .59897 L .42215 .5987 L F
.807 .392 .261 r
.41938 .59897 m .42059 .60009 L .42215 .5987 L F
.241 .752 .737 r
.42059 .60009 m .42404 .59917 L .42215 .5987 L F
.584 .465 .683 r
.42215 .5987 m .42419 .59514 L .4211 .59574 L F
.42215 .5987 m .42478 .59834 L .42419 .59514 L F
.302 0 0 r
.42215 .5987 m .42404 .59917 L .42478 .59834 L F
.53 .386 .629 r
.49678 .58306 m .4993 .58572 L .49888 .58256 L F
.49678 .58306 m .49703 .58628 L .4993 .58572 L F
0 0 .253 r
.49749 .58407 m .49678 .58306 L .49888 .58256 L F
.49749 .58407 m .49703 .58628 L .49678 .58306 L F
.785 .952 .926 r
.47736 .60259 m .48227 .60008 L .48078 .59973 L F
.068 .533 .898 r
.48227 .60008 m .48312 .59974 L .48078 .59973 L F
.48227 .60008 m .48444 .60078 L .48312 .59974 L F
.48227 .60008 m .48312 .59974 L .48078 .59973 L F
.48227 .60008 m .48444 .60078 L .48312 .59974 L F
.617 .493 .689 r
.48227 .60008 m .48466 .6036 L .48444 .60078 L F
.48227 .60008 m .48243 .60441 L .48466 .6036 L F
.431 .098 .299 r
.44996 .58584 m .44628 .58813 L .44751 .58624 L F
.536 .345 .569 r
.44994 .58324 m .44996 .58584 L .44751 .58624 L F
0 0 .149 r
.46405 .5976 m .46249 .60064 L .46312 .59848 L F
.571 .612 .855 r
.63778 .41545 m .63906 .4116 L .63679 .41301 L F
.63778 .41545 m .64025 .41491 L .63906 .4116 L F
.592 .559 .786 r
.63778 .41545 m .6416 .41856 L .64025 .41491 L F
.785 .847 .898 r
.7761 .42792 m .77524 .43088 L .77729 .42928 L F
.915 .979 .76 r
.77468 .43007 m .77524 .43088 L .7761 .42792 L F
.394 .156 .431 r
.78972 .41413 m .79002 .4172 L .7868 .41792 L F
.388 .36 .707 r
.78979 .41238 m .79273 .4145 L .78972 .41413 L F
.41 .167 .432 r
.79273 .4145 m .79002 .4172 L .78972 .41413 L F
.538 .303 .507 r
.56261 .55916 m .56513 .55871 L .565 .55595 L F
.492 .322 .577 r
.565 .55595 m .56798 .55548 L .56791 .55281 L F
.537 .34 .561 r
.56513 .55871 m .56798 .55548 L .565 .55595 L F
.211 .735 .753 r
.1859 .55874 m .18446 .55897 L .18231 .55947 L F
.081 0 0 r
.18811 .5584 m .18446 .55897 L .1859 .55874 L F
.869 .457 .24 r
.60712 .48104 m .60997 .48238 L .60803 .481 L F
.60712 .48104 m .60675 .48226 L .60997 .48238 L F
.841 .657 .653 r
.60461 .48585 m .60997 .48238 L .60675 .48226 L F
.60461 .48585 m .606 .48644 L .60997 .48238 L F
.677 .4 .494 r
.42539 .62469 m .42668 .62849 L .42156 .62754 L F
.684 .403 .492 r
.42806 .62768 m .42668 .62849 L .42539 .62469 L F
.735 .216 0 r
.4285 .62786 m .42806 .62768 L .42539 .62469 L F
.87 .811 .788 r
.65962 .40551 m .66106 .4069 L .66332 .40378 L F
.132 .673 .836 r
.21496 .53903 m .21689 .53886 L .21885 .53918 L F
.161 .697 .835 r
.21689 .53886 m .22096 .5389 L .21885 .53918 L F
.992 .736 .394 r
.78121 .41805 m .78116 .42041 L .78223 .42125 L F
0 .575 .731 r
.78223 .42125 m .78378 .41798 L .78121 .41805 L F
.78223 .42125 m .78227 .42123 L .78378 .41798 L F
.78223 .42125 m .7845 .42132 L .78227 .42123 L F
.678 .224 0 r
.78278 .42248 m .78223 .42125 L .78116 .42041 L F
.78278 .42248 m .78392 .42382 L .78223 .42125 L F
.715 .664 .798 r
.78124 .44431 m .78393 .44378 L .78009 .44237 L F
.585 .563 .796 r
.28661 .57969 m .28407 .58038 L .28279 .57736 L F
.385 .23 .545 r
.28544 .58191 m .28407 .58038 L .28661 .57969 L F
.28544 .58191 m .2843 .5828 L .28407 .58038 L F
0 0 0 r
.16761 .56534 m .16513 .56779 L .16598 .56648 L F
.851 .823 .821 r
.44245 .5974 m .44429 .59819 L .44652 .5955 L F
.922 .619 .451 r
.44245 .5974 m .44437 .60069 L .44429 .59819 L F
.698 .566 .702 r
.44429 .59819 m .44767 .5986 L .44652 .5955 L F
.708 .448 .529 r
.44437 .60069 m .44767 .5986 L .44429 .59819 L F
.643 .086 0 r
.42268 .63992 m .42444 .64093 L .4229 .64036 L F
.502 .859 .99 r
.4229 .64036 m .42444 .64093 L .42761 .64009 L F
.254 0 0 r
.42505 .64033 m .42331 .64113 L .4229 .64036 L F
.42331 .64113 m .42248 .6415 L .4229 .64036 L F
.643 .086 0 r
.42163 .63932 m .42268 .63992 L .4229 .64036 L F
0 0 0 r
.56124 .60478 m .56029 .60399 L .56212 .60333 L F
.56124 .60478 m .5596 .60608 L .56029 .60399 L F
.151 0 .076 r
.56029 .60399 m .5596 .60608 L .55741 .60641 L F
.573 .434 .654 r
.59563 .45142 m .59837 .45112 L .5979 .44809 L F
.492 .297 .544 r
.59587 .45341 m .59837 .45112 L .59563 .45142 L F
.498 .626 .907 r
.62754 .42902 m .62781 .43064 L .62556 .43103 L F
.594 .562 .788 r
.20449 .68846 m .20503 .69063 L .20706 .68847 L F
.414 .322 .643 r
.47629 .60296 m .47736 .60259 L .4781 .60091 L F
0 .082 .597 r
.53021 .59182 m .53139 .59068 L .53052 .58825 L F
0 0 .485 r
.53021 .59182 m .5314 .59291 L .53139 .59068 L F
.53021 .59182 m .53151 .59413 L .5314 .59291 L F
.275 0 .229 r
.43524 .66092 m .43502 .66309 L .43251 .6639 L F
.759 .653 .096 r
.43521 .66034 m .43502 .66309 L .43524 .66092 L F
.367 .73 .989 r
.4799 .55837 m .47901 .55958 L .47766 .55874 L F
.4799 .55837 m .48133 .55954 L .47901 .55958 L F
.573 .367 .564 r
.55392 .57695 m .55671 .5742 L .55406 .57426 L F
.457 .283 .556 r
.45225 .58495 m .44994 .58324 L .45282 .58321 L F
.45225 .58495 m .44996 .58584 L .44994 .58324 L F
.646 .539 .718 r
.44652 .5955 m .44767 .5986 L .44936 .59802 L F
0 0 .173 r
.58542 .54729 m .58744 .54355 L .58702 .54587 L F
0 0 .182 r
.58499 .54944 m .58542 .54729 L .58702 .54587 L F
.351 .822 .899 r
.20595 .63409 m .20556 .63476 L .20373 .6344 L F
.20595 .63409 m .20769 .63427 L .20556 .63476 L F
.76 .611 .693 r
.78009 .44237 m .78393 .44378 L .78315 .44011 L F
.535 0 0 r
.78609 .44167 m .78315 .44011 L .78393 .44378 L F
.985 .742 .482 r
.4261 .63112 m .42585 .63374 L .42472 .63061 L F
.563 .532 .779 r
.42806 .62768 m .4261 .63112 L .42659 .62965 L F
.42806 .62768 m .42842 .63062 L .4261 .63112 L F
.647 .928 .973 r
.4261 .63112 m .42472 .63061 L .42659 .62965 L F
0 0 .061 r
.42842 .63062 m .42585 .63374 L .4261 .63112 L F
.847 .782 .788 r
.7866 .44466 m .78609 .44167 L .78393 .44378 L F
.346 .788 .623 r
.54539 .51019 m .54501 .51039 L .5433 .51135 L F
.224 0 0 r
.54466 .5124 m .5433 .51135 L .54501 .51039 L F
.54466 .5124 m .5423 .51308 L .5433 .51135 L F
0 0 0 r
.46693 .59402 m .46405 .5976 L .46525 .59585 L F
.625 .277 .36 r
.70129 .40662 m .70394 .40845 L .70137 .40848 L F
.575 .317 .488 r
.70129 .40662 m .70387 .40651 L .70394 .40845 L F
0 .175 .709 r
.52581 .57668 m .52758 .58015 L .52784 .57871 L F
0 0 .341 r
.52817 .58244 m .52784 .57871 L .52758 .58015 L F
.535 .307 .516 r
.47829 .59795 m .48104 .59543 L .47991 .59561 L F
.47829 .59795 m .47927 .59889 L .48104 .59543 L F
.344 .821 .794 r
.48113 .59505 m .48104 .59543 L .48237 .59424 L F
.48113 .59505 m .47991 .59561 L .48104 .59543 L F
.52 .307 .531 r
.18955 .73285 m .18936 .72925 L .18802 .73053 L F
.568 .366 .568 r
.18924 .73541 m .19172 .73248 L .18955 .73285 L F
.498 .583 .871 r
.78948 .39984 m .78759 .40057 L .78576 .39704 L F
.554 .504 .754 r
.78948 .39984 m .78799 .4041 L .78759 .40057 L F
0 0 0 r
.58014 .53072 m .58114 .52908 L .5787 .53231 L F
.814 .805 .315 r
.58198 .52508 m .58114 .52908 L .58118 .5287 L F
.729 .845 .405 r
.58118 .5287 m .58114 .52908 L .58014 .53072 L F
.433 .101 .301 r
.57618 .49049 m .57535 .49296 L .57293 .49338 L F
.466 .132 .314 r
.57907 .49127 m .57618 .49049 L .57869 .4903 L F
.57907 .49127 m .57535 .49296 L .57618 .49049 L F
.627 .57 .771 r
.43735 .62524 m .43476 .62684 L .43305 .62224 L F
.383 .805 .617 r
.43735 .62524 m .43432 .62711 L .43476 .62684 L F
.884 .586 .478 r
.42348 .65686 m .42604 .65798 L .42533 .65496 L F
.162 0 .118 r
.71534 .40016 m .71749 .39755 L .7165 .39895 L F
0 0 0 r
.7165 .39895 m .71749 .39755 L .71963 .39594 L F
.64 .385 .517 r
.46881 .6157 m .46612 .61798 L .46637 .61605 L F
.46881 .6157 m .46612 .61798 L .46637 .61605 L F
.517 .29 .509 r
.46932 .614 m .46881 .6157 L .46637 .61605 L F
.554 .504 .754 r
.78948 .39984 m .79015 .40349 L .78799 .4041 L F
.545 .47 .722 r
.79015 .40349 m .79111 .4058 L .78799 .4041 L F
.544 .47 .722 r
.78799 .4041 m .79111 .4058 L .78857 .4065 L F
.834 .863 .866 r
.68781 .43241 m .68468 .43307 L .68733 .42995 L F
.063 0 .454 r
.58054 .56327 m .57872 .56206 L .58052 .5608 L F
.58054 .56327 m .57962 .56414 L .57872 .56206 L F
.481 .257 .497 r
.2368 .60971 m .23936 .60682 L .2376 .60801 L F
.647 .467 .627 r
.5701 .49288 m .56814 .49493 L .56758 .49306 L F
.996 .867 .561 r
.76851 .42486 m .76708 .42617 L .76779 .42364 L F
.76851 .42486 m .76789 .42722 L .76708 .42617 L F
.367 .304 .654 r
.56213 .58307 m .56429 .58204 L .5631 .58054 L F
.284 .108 .458 r
.56206 .58636 m .56429 .58204 L .56213 .58307 L F
.536 .724 .96 r
.19973 .63297 m .19922 .63516 L .19759 .63358 L F
.19973 .63297 m .20168 .63489 L .19922 .63516 L F
.628 .799 .964 r
.66796 .40035 m .66567 .40066 L .66871 .39859 L F
.621 .136 0 r
.66567 .40066 m .66796 .40356 L .66569 .40097 L F
.748 .235 0 r
.66937 .40422 m .66567 .40066 L .66796 .40035 L F
.66937 .40422 m .66796 .40356 L .66567 .40066 L F
.621 .136 0 r
.66567 .40066 m .66569 .40097 L .66871 .39859 L F
.803 .445 .378 r
.58838 .49027 m .58486 .48955 L .58468 .48757 L F
.556 .033 0 r
.45071 .56781 m .44935 .56925 L .44596 .56755 L F
.585 .01 0 r
.45185 .56993 m .44935 .56925 L .45071 .56781 L F
.499 .64 .918 r
.21043 .67369 m .21354 .67392 L .21163 .67167 L F
.375 .153 .444 r
.26106 .61879 m .26066 .62173 L .25867 .62182 L F
.408 .159 .422 r
.26066 .62173 m .25827 .62424 L .25867 .62182 L F
.114 .569 .917 r
.27094 .5457 m .27065 .54645 L .26916 .54519 L F
.27094 .5457 m .27258 .54683 L .27065 .54645 L F
.149 .08 .516 r
.2836 .57053 m .28372 .57083 L .2827 .57094 L F
.479 .205 .419 r
.44317 .61039 m .4429 .61246 L .44051 .61293 L F
.493 .217 .423 r
.44528 .612 m .44317 .61039 L .44638 .60948 L F
.44528 .612 m .4429 .61246 L .44317 .61039 L F
.388 .466 .819 r
.63219 .41413 m .63287 .41141 L .63039 .41216 L F
.63219 .41413 m .63402 .41499 L .63287 .41141 L F
0 0 .281 r
.76479 .40191 m .76387 .40102 L .76376 .39929 L F
.76479 .40191 m .76356 .40353 L .76387 .40102 L F
0 0 .226 r
.22029 .67363 m .22077 .67598 L .21969 .6718 L F
.077 0 .293 r
.22158 .67701 m .22077 .67598 L .22029 .67363 L F
.22158 .67701 m .22021 .67829 L .22077 .67598 L F
.355 .152 .46 r
.79111 .4058 m .78886 .40887 L .78857 .4065 L F
.407 .825 .644 r
.51532 .5191 m .51667 .51838 L .51381 .52011 L F
0 0 0 r
.51755 .51823 m .51667 .51838 L .51532 .5191 L F
.51755 .51823 m .51983 .51734 L .51667 .51838 L F
.708 .448 .529 r
.44437 .60069 m .44711 .60115 L .44767 .5986 L F
.37 .135 .421 r
.44767 .5986 m .44931 .59979 L .44936 .59802 L F
.44767 .5986 m .44711 .60115 L .44931 .59979 L F
.335 .054 .329 r
.24338 .63702 m .24265 .63931 L .24067 .63987 L F
.371 .086 .345 r
.24469 .6387 m .24338 .63702 L .2454 .63644 L F
.24469 .6387 m .24265 .63931 L .24338 .63702 L F
.535 .307 .516 r
.47829 .59795 m .47991 .59561 L .47871 .59454 L F
.223 .714 .922 r
.23135 .55268 m .22958 .55216 L .22748 .55223 L F
.107 .636 .871 r
.23135 .55268 m .23345 .55282 L .22958 .55216 L F
.664 .455 .592 r
.61456 .42675 m .61771 .42448 L .61453 .42452 L F
.543 .314 .518 r
.74183 .39635 m .74207 .3949 L .73915 .39456 L F
.228 .363 .793 r
.74092 .39371 m .74183 .39635 L .73915 .39456 L F
.74092 .39371 m .73915 .39456 L .73805 .39537 L F
.19 0 .212 r
.43852 .58884 m .43808 .59106 L .4359 .59189 L F
.532 .177 .312 r
.43949 .59073 m .43852 .58884 L .44121 .58833 L F
.43949 .59073 m .43808 .59106 L .43852 .58884 L F
.763 .784 .871 r
.71731 .42683 m .7215 .42536 L .72004 .42377 L F
.785 .769 .839 r
.72004 .42377 m .7215 .42536 L .72359 .42389 L F
0 0 .37 r
.58014 .53072 m .5787 .53231 L .57865 .53462 L F
.9 .962 .823 r
.66497 .41481 m .66822 .41245 L .6673 .41153 L F
.417 .128 .364 r
.56683 .47815 m .56925 .47771 L .56968 .47531 L F
.348 .07 .343 r
.56968 .47531 m .57174 .47656 L .57185 .47451 L F
.56968 .47531 m .56925 .47771 L .57174 .47656 L F
.513 .848 .997 r
.67879 .43549 m .67952 .43635 L .67601 .43621 L F
0 .376 .836 r
.67903 .43526 m .67952 .43635 L .67879 .43549 L F
.67903 .43526 m .68007 .43675 L .67952 .43635 L F
.61 .723 .925 r
.73194 .38983 m .7332 .38686 L .73067 .38771 L F
.73194 .38983 m .7348 .3891 L .7332 .38686 L F
.998 .831 .546 r
.58995 .50201 m .58866 .50327 L .58824 .50109 L F
.58995 .50201 m .58953 .50572 L .58866 .50327 L F
.736 .794 .899 r
.69935 .42507 m .69571 .42477 L .69793 .42352 L F
.789 .797 .858 r
.7006 .42053 m .69935 .42507 L .69793 .42352 L F
.7006 .42053 m .7013 .42356 L .69935 .42507 L F
.058 .41 .861 r
.21723 .65662 m .21929 .65933 L .21706 .65779 L F
.958 .904 .53 r
.76958 .41587 m .76844 .41702 L .76863 .41447 L F
.76958 .41587 m .76881 .41814 L .76844 .41702 L F
0 .285 .734 r
.74288 .42799 m .74686 .43072 L .74651 .42897 L F
.341 .548 .908 r
.74686 .43072 m .74844 .42893 L .74651 .42897 L F
.74686 .43072 m .74968 .43177 L .74844 .42893 L F
.334 0 .048 r
.55741 .60641 m .55644 .60821 L .55409 .6087 L F
.117 0 0 r
.55741 .60641 m .5596 .60608 L .55644 .60821 L F
.831 .901 .889 r
.50536 .52586 m .50352 .52789 L .50217 .52646 L F
.434 .867 .767 r
.51532 .5191 m .51381 .52011 L .51313 .52023 L F
.578 .171 .235 r
.16513 .56779 m .1608 .56956 L .16295 .56855 L F
.927 .91 .518 r
.58547 .51529 m .58561 .51737 L .58466 .51963 L F
.861 .932 .871 r
.51401 .52743 m .51426 .52992 L .51581 .5277 L F
.51401 .52743 m .51426 .52992 L .51581 .5277 L F
.659 .5 .658 r
.61222 .42747 m .61826 .42868 L .61456 .42675 L F
.61222 .42747 m .61232 .43038 L .61826 .42868 L F
.68 .431 .538 r
.63936 .40354 m .64055 .40588 L .64112 .40361 L F
.865 .46 .264 r
.62697 .41802 m .62816 .42016 L .62919 .41917 L F
.399 0 0 r
.62919 .41917 m .63206 .41972 L .63166 .41923 L F
.508 .334 .58 r
.63008 .40925 m .63287 .41141 L .63275 .40877 L F
.63008 .40925 m .63039 .41216 L .63287 .41141 L F
.822 .767 .801 r
.61845 .44469 m .62033 .44578 L .62252 .44308 L F
.308 .196 .559 r
.57167 .58891 m .57186 .59135 L .57033 .59207 L F
.306 .191 .555 r
.57186 .59135 m .57198 .5935 L .57033 .59207 L F
.271 .192 .581 r
.57198 .5935 m .57068 .5951 L .57033 .59207 L F
.726 .836 .933 r
.72256 .4224 m .72004 .42377 L .72359 .42389 L F
.793 .859 .899 r
.72256 .4224 m .72359 .42389 L .72765 .42073 L F
0 0 .476 r
.52043 .56547 m .52208 .56604 L .51999 .56387 L F
.52043 .56547 m .52078 .56774 L .52208 .56604 L F
.773 .874 .921 r
.68468 .43307 m .68007 .43675 L .67903 .43526 L F
.887 .761 .717 r
.60698 .47744 m .60803 .481 L .60998 .47873 L F
.454 .203 .443 r
.40845 .61235 m .40583 .61519 L .40698 .61327 L F
.40845 .61235 m .40583 .61519 L .40698 .61327 L F
.545 .479 .732 r
.5612 .56519 m .56305 .56093 L .56061 .56284 L F
.547 .522 .779 r
.42395 .58258 m .42474 .58641 L .42301 .58577 L F
.324 .363 .748 r
.42649 .58462 m .42474 .58641 L .42395 .58258 L F
.567 .033 0 r
.42635 .58595 m .42474 .58641 L .42649 .58462 L F
.834 .548 .506 r
.42561 .58616 m .42803 .58602 L .42474 .58641 L F
.42561 .58616 m .4277 .58829 L .42803 .58602 L F
.567 .033 0 r
.42567 .58686 m .42474 .58641 L .42561 .58616 L F
.834 .548 .506 r
.42528 .58618 m .42564 .5865 L .42561 .58616 L F
.42564 .5865 m .4277 .58829 L .42561 .58616 L F
.567 .033 0 r
.42623 .58714 m .4277 .58829 L .42564 .5865 L F
.42567 .58686 m .42561 .58616 L .42635 .58595 L F
.42623 .58714 m .42564 .5865 L .42528 .58618 L F
.42623 .58714 m .42567 .58686 L .42581 .58668 L F
.42623 .58714 m .42581 .58668 L .42635 .58595 L F
.834 .548 .506 r
.42528 .58618 m .42561 .58616 L .42474 .58641 L F
.085 .526 .905 r
.42301 .58577 m .42528 .58618 L .42474 .58641 L F
.42301 .58577 m .42528 .58618 L .42474 .58641 L F
.503 0 0 r
.53611 .61006 m .53964 .61021 L .53884 .61121 L F
.711 .192 0 r
.53964 .61021 m .54208 .61247 L .53884 .61121 L F
.105 .529 .911 r
.48118 .6065 m .48161 .60647 L .48243 .60441 L F
.753 .622 .714 r
.48161 .60647 m .48466 .6036 L .48243 .60441 L F
.594 .382 .562 r
.44885 .6071 m .44874 .60929 L .44638 .60948 L F
.577 .509 .742 r
.45121 .60657 m .44885 .6071 L .44793 .60346 L F
.451 .227 .482 r
.45121 .60657 m .44874 .60929 L .44885 .6071 L F
.995 .756 .412 r
.77819 .44471 m .77763 .44662 L .77694 .4439 L F
.36 .782 .975 r
.77819 .44471 m .78114 .4444 L .78009 .44237 L F
.531 .673 .928 r
.78114 .4444 m .77819 .44471 L .78009 .44237 L F
.36 .782 .975 r
.77819 .44471 m .77694 .4439 L .78114 .4444 L F
.543 .275 .459 r
.63554 .40633 m .638 .4061 L .63936 .40354 L F
.68 .431 .538 r
.63936 .40354 m .638 .4061 L .64055 .40588 L F
0 0 .188 r
.25423 .55959 m .25619 .55565 L .25434 .55689 L F
.25423 .55959 m .2553 .55867 L .25619 .55565 L F
.219 .359 .792 r
.25423 .55959 m .25669 .5614 L .2553 .55867 L F
.822 .767 .801 r
.61845 .44469 m .62252 .44308 L .62085 .4416 L F
.797 .745 .805 r
.62085 .4416 m .62252 .44308 L .62514 .44036 L F
.713 .838 .942 r
.69675 .43225 m .70035 .43245 L .69969 .43048 L F
.736 .845 .931 r
.69969 .43048 m .70035 .43245 L .70311 .4304 L F
.309 .095 .418 r
.20724 .70527 m .20505 .70836 L .20552 .70592 L F
.663 .586 .758 r
.45197 .5921 m .45574 .59222 L .45399 .58936 L F
.592 .374 .553 r
.45213 .5942 m .45574 .59222 L .45197 .5921 L F
.54 .006 0 r
.50796 .60775 m .51027 .609 L .50663 .60876 L F
.998 .837 .501 r
.50792 .60768 m .50663 .60876 L .5071 .60617 L F
.507 .842 .998 r
.50425 .60934 m .50463 .60773 L .50663 .60876 L F
.975 .699 .439 r
.50663 .60876 m .50463 .60773 L .50425 .60934 L F
.519 .816 .999 r
.50414 .60676 m .5071 .60617 L .50639 .6035 L F
0 0 .35 r
.50639 .6035 m .5071 .60617 L .50713 .60422 L F
.908 .897 .806 r
.50663 .60876 m .50713 .60422 L .5071 .60617 L F
.975 .699 .439 r
.50663 .60876 m .5051 .61009 L .50463 .60773 L F
.908 .897 .806 r
.50663 .60876 m .50463 .60773 L .50713 .60422 L F
.636 .901 .586 r
.50725 .60762 m .50526 .60991 L .50663 .60876 L F
.50526 .60991 m .5051 .61009 L .50663 .60876 L F
.998 .837 .501 r
.50796 .60775 m .50663 .60876 L .50792 .60768 L F
0 0 .488 r
.52938 .58609 m .52942 .58467 L .52817 .58244 L F
0 0 .464 r
.52938 .58609 m .53052 .58825 L .52942 .58467 L F
.822 .708 .739 r
.51665 .53475 m .51468 .53807 L .51805 .53743 L F
.479 0 0 r
.51468 .53807 m .51658 .53878 L .51805 .53743 L F
.095 .091 .562 r
.51805 .53743 m .51904 .53418 L .51665 .53475 L F
.51805 .53743 m .51964 .53696 L .51904 .53418 L F
.651 .454 .605 r
.51658 .53878 m .51964 .53696 L .51805 .53743 L F
.547 .254 .422 r
.57118 .48141 m .57327 .48286 L .57395 .48066 L F
.57118 .48141 m .57327 .48286 L .57395 .48066 L F
.314 0 .017 r
.21224 .63305 m .21622 .63073 L .21396 .63112 L F
.846 .937 .564 r
.76316 .40572 m .76458 .40357 L .76356 .40353 L F
.39 0 0 r
.63337 .41995 m .63517 .4207 L .63206 .41972 L F
.664 .455 .592 r
.61456 .42675 m .61738 .42743 L .61771 .42448 L F
.308 .149 .495 r
.61771 .42448 m .61963 .4254 L .62023 .42315 L F
.61771 .42448 m .61738 .42743 L .61963 .4254 L F
.753 .643 .739 r
.49279 .58014 m .49043 .58314 L .48922 .5797 L F
0 .45 .837 r
.49035 .56234 m .48878 .56232 L .48745 .56125 L F
.49035 .56234 m .49171 .5634 L .48878 .56232 L F
.627 .529 .724 r
.41656 .63298 m .41421 .63395 L .41435 .63152 L F
.518 .18 .333 r
.70994 .40503 m .70988 .4036 L .71243 .4049 L F
.509 .195 .37 r
.70988 .4036 m .71271 .40319 L .71243 .4049 L F
.979 .842 .636 r
.62562 .43562 m .62525 .43775 L .62614 .4385 L F
.902 .838 .772 r
.62346 .43887 m .62614 .4385 L .62525 .43775 L F
.62346 .43887 m .62514 .44036 L .62614 .4385 L F
.839 .75 .765 r
.60998 .46581 m .61142 .46643 L .61041 .463 L F
.856 .703 .691 r
.60998 .46581 m .61129 .46876 L .61142 .46643 L F
.827 .685 .707 r
.78314 .41494 m .7868 .41792 L .78588 .41479 L F
.78314 .41494 m .78378 .41798 L .7868 .41792 L F
.755 .547 .615 r
.78227 .42123 m .7868 .41792 L .78378 .41798 L F
.78227 .42123 m .7845 .42132 L .7868 .41792 L F
.503 .605 .888 r
.7868 .41792 m .789 .41461 L .78588 .41479 L F
.7868 .41792 m .79002 .4172 L .789 .41461 L F
.449 .247 .513 r
.26334 .61582 m .26319 .61831 L .26106 .61879 L F
.449 .216 .466 r
.26293 .62109 m .26106 .61879 L .26319 .61831 L F
.26293 .62109 m .26066 .62173 L .26106 .61879 L F
.71 .182 0 r
.66937 .40422 m .6684 .40422 L .66796 .40356 L F
.175 0 0 r
.67233 .40412 m .6684 .40422 L .66937 .40422 L F
.885 .856 .808 r
.65829 .42925 m .66187 .42601 L .66098 .42587 L F
.269 .76 .91 r
.22096 .5389 m .22314 .53851 L .22501 .53896 L F
.382 0 0 r
.22314 .53851 m .22715 .53851 L .22501 .53896 L F
.215 0 .183 r
.55946 .48475 m .55877 .48638 L .56154 .48378 L F
0 0 .032 r
.67367 .4059 m .67429 .40243 L .67233 .40412 L F
.67367 .4059 m .67392 .40525 L .67429 .40243 L F
.194 .087 .497 r
.67367 .4059 m .67661 .40561 L .67392 .40525 L F
.837 .533 .475 r
.67687 .40933 m .67412 .40915 L .67367 .4059 L F
.194 .087 .497 r
.67367 .4059 m .67412 .40915 L .67661 .40561 L F
.578 .424 .636 r
.28414 .58546 m .28176 .58332 L .2843 .5828 L F
.28414 .58546 m .28174 .58589 L .28176 .58332 L F
.177 0 .223 r
.24677 .59525 m .24595 .59725 L .24844 .59436 L F
0 .302 .761 r
.4862 .56002 m .48518 .55998 L .48353 .55948 L F
.4862 .56002 m .48745 .56125 L .48518 .55998 L F
.34 .049 .316 r
.21095 .66041 m .21315 .65986 L .21395 .65804 L F
.634 .554 .747 r
.21095 .66041 m .21369 .66312 L .21315 .65986 L F
.267 .666 .968 r
.78747 .43048 m .7864 .42944 L .78401 .42925 L F
.594 .715 .928 r
.78772 .4293 m .78747 .43048 L .78705 .42877 L F
.7882 .42699 m .79006 .42984 L .78747 .43048 L F
.628 .123 .032 r
.79006 .42984 m .7864 .42944 L .78747 .43048 L F
.78812 .42963 m .78917 .43108 L .7864 .42944 L F
.79006 .42984 m .78945 .43069 L .78812 .42963 L F
.78945 .43069 m .78917 .43108 L .78812 .42963 L F
.594 .715 .928 r
.7882 .42699 m .78772 .4293 L .7866 .42696 L F
.78772 .4293 m .78705 .42877 L .7866 .42696 L F
.943 .777 .314 r
.56004 .58921 m .55981 .59191 L .55939 .59043 L F
0 0 0 r
.56004 .58921 m .55939 .59043 L .56156 .58776 L F
.773 .752 .834 r
.65692 .40782 m .66106 .4069 L .65962 .40551 L F
.77 .652 .731 r
.48922 .5797 m .49043 .58314 L .48663 .58264 L F
.814 .591 .601 r
.49043 .58314 m .48665 .58523 L .48663 .58264 L F
.49043 .58314 m .49019 .58579 L .48675 .58525 L F
.723 .519 .614 r
.49052 .58753 m .48967 .58703 L .49019 .58579 L F
.49052 .58753 m .48657 .58774 L .48665 .58523 L F
.36 .128 .421 r
.49065 .58523 m .48972 .58729 L .49347 .58532 L F
.48972 .58729 m .4895 .58779 L .48979 .58761 L F
.48972 .58729 m .48979 .58761 L .49347 .58532 L F
.723 .519 .614 r
.48967 .58703 m .48723 .58558 L .4894 .58573 L F
.48967 .58703 m .4894 .58573 L .49019 .58579 L F
.48723 .58558 m .48665 .58523 L .48675 .58525 L F
.48723 .58558 m .48675 .58525 L .49019 .58579 L F
.705 .5 .608 r
.4867 .58765 m .4895 .58779 L .48972 .58729 L F
.48858 .5865 m .48972 .58729 L .49065 .58523 L F
.4867 .58765 m .48972 .58729 L .48858 .5865 L F
.48657 .58774 m .4867 .58774 L .4867 .58765 L F
.601 .448 .646 r
.48988 .58985 m .48657 .58774 L .49052 .58753 L F
.705 .5 .608 r
.4867 .58774 m .4895 .58779 L .4867 .58765 L F
.814 .591 .601 r
.48675 .58518 m .48675 .58525 L .48665 .58523 L F
.49043 .58314 m .48675 .58525 L .48675 .58518 L F
.206 .223 .657 r
.25409 .57433 m .25623 .57519 L .25594 .57314 L F
.25409 .57433 m .25482 .57692 L .25623 .57519 L F
.693 .752 .898 r
.2498 .55308 m .25321 .55375 L .25177 .55215 L F
.559 .705 .938 r
.25177 .55215 m .25321 .55375 L .25409 .55166 L F
.345 .456 .83 r
.25321 .55375 m .25619 .55565 L .25409 .55166 L F
.487 .451 .743 r
.25321 .55375 m .25434 .55689 L .25619 .55565 L F
0 0 0 r
.46947 .58905 m .47066 .58758 L .47209 .58577 L F
0 0 .147 r
.47365 .58413 m .47209 .58577 L .47416 .58282 L F
.462 .168 .381 r
.47066 .58758 m .47365 .58413 L .47209 .58577 L F
0 0 .147 r
.47365 .58413 m .47209 .58577 L .47416 .58282 L F
.826 .883 .885 r
.68889 .43626 m .69172 .43609 L .69046 .43473 L F
.761 .829 .905 r
.69046 .43473 m .69172 .43609 L .69475 .43376 L F
.516 .325 .561 r
.27949 .58906 m .27939 .5916 L .27712 .59209 L F
.27949 .58906 m .27939 .5916 L .27712 .59209 L F
.472 .33 .607 r
.27939 .5916 m .27746 .5949 L .27712 .59209 L F
.76 .286 .119 r
.78533 .4257 m .78624 .42448 L .78392 .42382 L F
.345 .254 .608 r
.38764 .61314 m .38932 .6128 L .38942 .60924 L F
.364 .336 .694 r
.38764 .61314 m .39 .61512 L .38932 .6128 L F
.325 .333 .714 r
.38862 .61575 m .39 .61512 L .38764 .61314 L F
.286 0 0 r
.64596 .42707 m .64558 .42698 L .64385 .42631 L F
0 0 0 r
.6488 .42431 m .6479 .42582 L .64596 .42707 L F
.451 .879 .792 r
.6479 .42582 m .64558 .42698 L .64596 .42707 L F
.533 .445 .702 r
.42439 .56736 m .42719 .56727 L .42681 .56537 L F
.702 .564 .696 r
.42439 .56736 m .42721 .5697 L .42719 .56727 L F
.42439 .56736 m .42521 .57107 L .42721 .5697 L F
.167 0 .041 r
.15044 .55861 m .15226 .5581 L .1538 .55571 L F
.189 0 .053 r
.1538 .55571 m .15427 .55731 L .15599 .55533 L F
.1538 .55571 m .15226 .5581 L .15427 .55731 L F
.034 .581 .835 r
.1832 .65217 m .17929 .65138 L .18123 .65169 L F
.18 .468 .889 r
.49171 .5634 m .49329 .56377 L .49264 .5651 L F
.689 .97 .762 r
.49264 .5651 m .49329 .56377 L .49366 .56399 L F
.496 .765 .991 r
.2572 .54016 m .25672 .54169 L .25529 .54074 L F
.2572 .54016 m .25856 .5413 L .25672 .54169 L F
.94 .878 .464 r
.54058 .59357 m .54084 .59533 L .54179 .59177 L F
0 0 .554 r
.52444 .57072 m .52503 .57431 L .52543 .57318 L F
0 .053 .572 r
.52503 .57431 m .52688 .57514 L .52543 .57318 L F
.52503 .57431 m .52581 .57668 L .52688 .57514 L F
.393 .707 .985 r
.1895 .63298 m .18571 .63166 L .18704 .6309 L F
.023 .573 .83 r
.18977 .63269 m .1895 .63298 L .18704 .6309 L F
.18977 .63269 m .19157 .63324 L .1895 .63298 L F
.545 .479 .732 r
.5612 .56519 m .56358 .56467 L .56305 .56093 L F
.434 .371 .688 r
.5612 .56519 m .56383 .56722 L .56358 .56467 L F
.5612 .56519 m .56195 .56806 L .56383 .56722 L F
.145 0 .17 r
.71563 .39044 m .71358 .39165 L .71294 .39329 L F
.612 .837 .452 r
.6603 .44059 m .66054 .44039 L .65944 .4419 L F
.94 .92 .548 r
.53938 .51859 m .53861 .51795 L .53872 .52017 L F
.53938 .51859 m .53963 .51557 L .53861 .51795 L F
.477 .052 .155 r
.76971 .43652 m .76949 .43808 L .76701 .43734 L F
.454 .193 .428 r
.5979 .44809 m .60035 .44747 L .60074 .44539 L F
.441 .241 .511 r
.60074 .44539 m .60308 .44469 L .60301 .44239 L F
.47 .208 .433 r
.60074 .44539 m .60269 .4468 L .60308 .44469 L F
.60074 .44539 m .60035 .44747 L .60269 .4468 L F
.439 .099 .291 r
.24067 .63987 m .23957 .64237 L .23727 .64273 L F
.413 .108 .335 r
.24265 .63931 m .23957 .64237 L .24067 .63987 L F
.566 .937 .893 r
.64136 .41863 m .63757 .41983 L .6409 .41783 L F
.064 0 0 r
.6398 .41883 m .6409 .41783 L .63757 .41983 L F
.064 0 .3 r
.6398 .41883 m .64076 .41759 L .6409 .41783 L F
0 .09 .641 r
.64025 .41491 m .64111 .41723 L .64167 .41641 L F
.64111 .41723 m .6416 .41856 L .64167 .41641 L F
.064 0 .3 r
.6398 .41883 m .64207 .41583 L .64167 .41641 L F
0 0 0 r
.6427 .41443 m .64224 .41562 L .64276 .41432 L F
.64167 .41641 m .64224 .41562 L .6427 .41443 L F
.064 0 .3 r
.64207 .41583 m .64224 .41562 L .64167 .41641 L F
.64076 .41759 m .64167 .41641 L .6409 .41783 L F
.893 .987 .79 r
.6416 .41856 m .6409 .41783 L .64167 .41641 L F
.064 0 .3 r
.6398 .41883 m .64168 .41788 L .64224 .41562 L F
.525 .494 .764 r
.64168 .41788 m .64199 .41624 L .64224 .41562 L F
.549 .481 .731 r
.64025 .41491 m .64276 .41432 L .64208 .41034 L F
0 .09 .641 r
.64025 .41491 m .64167 .41641 L .64276 .41432 L F
.525 .494 .764 r
.64199 .41624 m .64248 .41367 L .64224 .41562 L F
.566 .937 .893 r
.6416 .41856 m .64136 .41863 L .6409 .41783 L F
.872 .531 .026 r
.78342 .41103 m .78456 .41309 L .78421 .41205 L F
.797 .745 .805 r
.62085 .4416 m .62514 .44036 L .62346 .43887 L F
.787 .543 .567 r
.42585 .63374 m .4297 .63658 L .42948 .63697 L F
.354 .518 .881 r
.194 .71201 m .19668 .71312 L .1955 .71071 L F
.276 .398 .806 r
.40302 .63992 m .40293 .6364 L .40123 .6367 L F
.40302 .63992 m .40464 .63874 L .40293 .6364 L F
.259 .364 .781 r
.40302 .63992 m .40558 .64166 L .40464 .63874 L F
.412 .358 .688 r
.40302 .63992 m .40347 .64252 L .40558 .64166 L F
.273 .459 .861 r
.39706 .62897 m .3999 .62957 L .39625 .62769 L F
.39706 .62897 m .39976 .63066 L .3999 .62957 L F
.772 .786 .865 r
.70402 .42105 m .7013 .42356 L .7006 .42053 L F
.066 0 0 r
.43432 .62711 m .43083 .63016 L .43116 .62808 L F
.43432 .62711 m .43286 .62943 L .43083 .63016 L F
.564 .126 .166 r
.43553 .62936 m .43432 .62711 L .43584 .62646 L F
.43553 .62936 m .43286 .62943 L .43432 .62711 L F
0 0 0 r
.4372 .62534 m .43597 .62635 L .43432 .62711 L F
.43597 .62635 m .43584 .62646 L .43526 .6267 L F
.43597 .62635 m .43526 .6267 L .43432 .62711 L F
.414 .466 .805 r
.43901 .62493 m .43732 .62679 L .43662 .62602 L F
0 0 0 r
.43735 .62524 m .43584 .62646 L .4372 .62534 L F
.627 .57 .771 r
.43735 .62524 m .43454 .62328 L .43555 .62414 L F
.43454 .62328 m .43305 .62224 L .43555 .62414 L F
.911 .509 .2 r
.43613 .62464 m .43555 .62414 L .43708 .62345 L F
.918 .624 .471 r
.43555 .62414 m .43584 .62646 L .43735 .62524 L F
.911 .509 .2 r
.43578 .62508 m .43555 .62414 L .43613 .62464 L F
.414 .466 .805 r
.43877 .62494 m .43662 .62602 L .43578 .62508 L F
.43901 .62493 m .43662 .62602 L .43877 .62494 L F
.608 .149 .137 r
.43184 .62651 m .43395 .62815 L .43584 .62646 L F
.98 .759 .532 r
.43584 .62646 m .43395 .62815 L .43413 .62786 L F
0 0 .385 r
.43578 .62508 m .43584 .62646 L .43555 .62414 L F
.98 .759 .532 r
.43584 .62646 m .43499 .6264 L .43578 .62508 L F
0 0 0 r
.43578 .62508 m .43499 .6264 L .4354 .62634 L F
.109 .661 .792 r
.43584 .62646 m .43458 .62638 L .43184 .62651 L F
.98 .759 .532 r
.43584 .62646 m .43413 .62786 L .43499 .6264 L F
0 0 0 r
.43499 .6264 m .43395 .62815 L .4354 .62634 L F
.109 .661 .792 r
.43499 .6264 m .4354 .62634 L .43458 .62638 L F
.43584 .62646 m .4354 .62634 L .43499 .6264 L F
.415 .167 .428 r
.56971 .5471 m .57199 .54649 L .57228 .54431 L F
.5 .287 .522 r
.57199 .54649 m .57457 .54349 L .57228 .54431 L F
.927 .973 .744 r
.59575 .52057 m .59763 .51725 L .59584 .51804 L F
.923 .908 .513 r
.59486 .52257 m .59575 .52057 L .59584 .51804 L F
.573 .345 .531 r
.4798 .60946 m .47704 .61199 L .47758 .61023 L F
.332 .096 .398 r
.43981 .65193 m .44221 .64889 L .44189 .65152 L F
.399 .314 .644 r
.44189 .65152 m .44208 .65398 L .43981 .65193 L F
.332 .096 .398 r
.43981 .65193 m .44221 .64889 L .44189 .65152 L F
.399 .314 .644 r
.43981 .65193 m .44208 .65398 L .44189 .65152 L F
.44189 .65152 m .44208 .65398 L .43981 .65193 L F
.468 .159 .358 r
.69868 .409 m .6982 .41133 L .6956 .41196 L F
.551 .232 .382 r
.70159 .41083 m .69868 .409 L .70137 .40848 L F
.70159 .41083 m .6982 .41133 L .69868 .409 L F
.469 .423 .723 r
.73839 .4207 m .73884 .42529 L .74134 .42234 L F
.574 .556 .797 r
.73966 .42656 m .74134 .42234 L .73884 .42529 L F
.493 .292 .535 r
.47191 .59094 m .46957 .59153 L .46947 .58905 L F
0 0 0 r
.59119 .53215 m .59289 .52833 L .59217 .53038 L F
0 0 .126 r
.59092 .53413 m .59119 .53215 L .59217 .53038 L F
.856 .703 .691 r
.60998 .46581 m .60784 .46839 L .61129 .46876 L F
.853 .72 .715 r
.60784 .46839 m .60912 .47193 L .61129 .46876 L F
.929 .881 .766 r
.67356 .44292 m .67548 .44297 L .67363 .4461 L F
.951 .744 .587 r
.67409 .44001 m .67548 .44297 L .67356 .44292 L F
.62 .401 .563 r
.41224 .61279 m .4148 .61264 L .41518 .60999 L F
.41224 .61279 m .4148 .61264 L .41518 .60999 L F
.735 .508 .584 r
.41518 .60999 m .41835 .61272 L .4172 .60919 L F
.41518 .60999 m .4148 .61264 L .41835 .61272 L F
.703 .599 .737 r
.4172 .60919 m .4148 .61264 L .41518 .60999 L F
.896 .727 .664 r
.21256 .67921 m .21049 .67819 L .20869 .67934 L F
.21256 .67921 m .21228 .68193 L .21049 .67819 L F
.21256 .67921 m .21228 .68193 L .21049 .67819 L F
.637 .532 .719 r
.21228 .68193 m .21494 .67856 L .21256 .67921 L F
.19 0 0 r
.16113 .55288 m .16332 .55236 L .16508 .55058 L F
.061 0 0 r
.16508 .55058 m .16526 .55163 L .16717 .55 L F
.16508 .55058 m .16332 .55236 L .16526 .55163 L F
.527 .766 .985 r
.66988 .39793 m .66796 .40035 L .66871 .39859 L F
.142 0 .124 r
.4101 .58664 m .41127 .5872 L .41225 .58596 L F
.4101 .58664 m .40933 .5883 L .41127 .5872 L F
0 0 .337 r
.21348 .67134 m .21455 .67413 L .21318 .67101 L F
.21348 .67134 m .21318 .67101 L .21163 .67167 L F
.514 .378 .634 r
.56991 .54981 m .57199 .54649 L .56971 .5471 L F
.788 .614 .664 r
.67931 .40918 m .67693 .41187 L .67687 .40933 L F
.67931 .40918 m .68054 .41253 L .67693 .41187 L F
.606 .328 .469 r
.45786 .56731 m .45472 .5659 L .45824 .56511 L F
.434 .251 .532 r
.28174 .58589 m .28154 .58842 L .27949 .58906 L F
.373 .185 .491 r
.28154 .58842 m .27939 .5916 L .27949 .58906 L F
.839 .602 .58 r
.58812 .49281 m .58486 .48955 L .58838 .49027 L F
.378 .37 .724 r
.79105 .40805 m .78979 .41238 L .78886 .40887 L F
.79105 .40805 m .79167 .41191 L .78979 .41238 L F
.376 .361 .715 r
.79167 .41191 m .79273 .4145 L .78979 .41238 L F
.997 .813 .456 r
.76185 .41767 m .76139 .41461 L .7611 .41649 L F
.95 .826 .687 r
.75943 .42015 m .76185 .41767 L .7611 .41649 L F
.75943 .42015 m .76075 .42147 L .76185 .41767 L F
.419 .276 .578 r
.24157 .60107 m .24348 .60302 L .24366 .6005 L F
.24157 .60107 m .24161 .60365 L .24348 .60302 L F
.533 .678 .931 r
.17643 .62612 m .1758 .62834 L .17444 .62613 L F
.17643 .62612 m .17796 .62791 L .1758 .62834 L F
.343 .092 .381 r
.57386 .58011 m .57305 .58262 L .5713 .58306 L F
.436 .348 .658 r
.57305 .58262 m .57384 .58505 L .5713 .58306 L F
.277 0 0 r
.20303 .55306 m .20408 .55319 L .19862 .55472 L F
.208 0 0 r
.2052 .55299 m .20408 .55319 L .20303 .55306 L F
0 0 0 r
.55389 .48996 m .55578 .48934 L .55685 .48762 L F
.152 0 0 r
.55685 .48762 m .55812 .48849 L .55877 .48638 L F
.55685 .48762 m .55578 .48934 L .55812 .48849 L F
.371 .125 .406 r
.26597 .61281 m .2656 .61526 L .26334 .61582 L F
.397 .202 .495 r
.2656 .61526 m .26319 .61831 L .26334 .61582 L F
.407 .211 .5 r
.27498 .59794 m .2748 .60027 L .27281 .60088 L F
.445 .307 .598 r
.2749 .60266 m .27281 .60088 L .2748 .60027 L F
.2749 .60266 m .27293 .60333 L .27281 .60088 L F
.606 .328 .469 r
.45786 .56731 m .45439 .56801 L .45472 .5659 L F
.785 .847 .898 r
.7761 .42792 m .77729 .42928 L .77659 .42645 L F
.653 .866 .98 r
.77729 .42928 m .77965 .42677 L .77659 .42645 L F
.77729 .42928 m .78046 .42794 L .77965 .42677 L F
.389 .179 .47 r
.28427 .55569 m .2839 .55746 L .28207 .55743 L F
.549 .435 .676 r
.28475 .56154 m .28207 .55743 L .2839 .55746 L F
.28475 .56154 m .28266 .56224 L .28207 .55743 L F
.482 .382 .665 r
.2149 .68872 m .21197 .68764 L .21622 .68724 L F
.214 .214 .643 r
.21723 .68447 m .21796 .68711 L .21622 .68724 L F
.092 0 0 r
.21796 .68711 m .2149 .68872 L .21622 .68724 L F
.618 .39 .549 r
.44623 .6054 m .44897 .60523 L .44879 .60458 L F
.443 0 0 r
.45176 .60402 m .44961 .60474 L .44793 .60346 L F
.577 .509 .742 r
.45121 .60657 m .44793 .60346 L .44952 .60472 L F
.44959 .60479 m .44952 .60472 L .44956 .60475 L F
.45121 .60657 m .44952 .60472 L .44959 .60479 L F
.618 .39 .549 r
.44696 .60421 m .44879 .60458 L .4486 .60388 L F
.44769 .60304 m .4486 .60388 L .44816 .60226 L F
.44696 .60421 m .4486 .60388 L .44769 .60304 L F
.44623 .6054 m .44879 .60458 L .44696 .60421 L F
.443 0 0 r
.44961 .60474 m .44956 .60475 L .44952 .60472 L F
.44961 .60474 m .44952 .60472 L .44793 .60346 L F
.749 .725 .83 r
.42873 .59373 m .43309 .59461 L .43154 .591 L F
.16 .363 .815 r
.43154 .591 m .43309 .59461 L .43374 .59287 L F
0 0 0 r
.19669 .54158 m .19829 .54127 L .1983 .54125 L F
.19831 .54123 m .1983 .54125 L .20041 .54115 L F
.1983 .54125 m .20236 .54015 L .20041 .54115 L F
.19829 .54127 m .20049 .54084 L .1983 .54125 L F
.19645 .5413 m .1983 .54125 L .19831 .54123 L F
0 0 .175 r
.53325 .60404 m .53362 .60513 L .53368 .60265 L F
.53325 .60404 m .53363 .6066 L .53362 .60513 L F
.785 .755 .826 r
.19668 .71312 m .19795 .71485 L .20059 .71255 L F
.233 .072 .446 r
.57573 .57867 m .57305 .58262 L .57386 .58011 L F
.721 .722 .851 r
.42719 .56727 m .42721 .5697 L .42981 .5669 L F
.816 .978 .892 r
.42981 .5669 m .42721 .5697 L .42841 .56873 L F
.439 .292 .584 r
.42981 .5669 m .42983 .57018 L .42721 .5697 L F
.42981 .5669 m .42983 .57018 L .42721 .5697 L F
.76 .778 .868 r
.71387 .42614 m .71731 .42683 L .71694 .42376 L F
.71387 .42614 m .71521 .42763 L .71731 .42683 L F
.803 .848 .884 r
.71694 .42376 m .71731 .42683 L .72004 .42377 L F
.254 0 .049 r
.23727 .64273 m .23407 .64477 L .23525 .64326 L F
.072 0 0 r
.22482 .625 m .22171 .62707 L .22297 .6266 L F
0 0 0 r
.22297 .6266 m .22171 .62707 L .22053 .62957 L F
.545 0 0 r
.67693 .41187 m .68054 .41253 L .67966 .41332 L F
.437 0 0 r
.68054 .41253 m .6819 .41383 L .67966 .41332 L F
.68054 .41253 m .68294 .41264 L .6819 .41383 L F
.589 .341 .508 r
.70252 .40011 m .70539 .39998 L .70525 .39753 L F
0 0 .347 r
.53117 .55483 m .53215 .55827 L .53179 .55909 L F
0 .225 .746 r
.53215 .55827 m .53413 .56102 L .53179 .55909 L F
.469 .315 .589 r
.53179 .55909 m .53413 .56102 L .53213 .56157 L F
.574 .556 .797 r
.73966 .42656 m .74268 .42594 L .74134 .42234 L F
.579 .634 .87 r
.73966 .42656 m .74288 .42799 L .74268 .42594 L F
.522 .187 .342 r
.44874 .60929 m .44528 .612 L .44638 .60948 L F
.286 0 .135 r
.42239 .57292 m .42437 .57294 L .42521 .57107 L F
.641 .254 .295 r
.42437 .57294 m .42807 .57377 L .42521 .57107 L F
.4 .152 .418 r
.44189 .65152 m .44221 .64889 L .44446 .64829 L F
.44446 .64829 m .44221 .64889 L .44189 .65152 L F
.44189 .65152 m .44221 .64889 L .44446 .64829 L F
.417 .18 .445 r
.60301 .44239 m .60531 .44173 L .60539 .43959 L F
.399 .166 .441 r
.60539 .43959 m .60751 .44079 L .60796 .43901 L F
.60539 .43959 m .60531 .44173 L .60751 .44079 L F
.412 .126 .366 r
.26832 .61224 m .2656 .61526 L .26597 .61281 L F
.263 .023 .35 r
.44936 .59802 m .45154 .59738 L .45213 .5942 L F
.592 .374 .553 r
.45213 .5942 m .45488 .59436 L .45574 .59222 L F
.477 .205 .423 r
.45213 .5942 m .45359 .5966 L .45488 .59436 L F
.45213 .5942 m .45154 .59738 L .45359 .5966 L F
.932 .866 .752 r
.75784 .42329 m .76011 .42381 L .76075 .42147 L F
.948 .831 .695 r
.75837 .42682 m .76011 .42381 L .75784 .42329 L F
.485 .465 .76 r
.53558 .56941 m .53471 .57333 L .53435 .57106 L F
.865 .885 .849 r
.53696 .58304 m .53542 .58225 L .537 .57956 L F
.359 .748 .987 r
.53806 .57901 m .53742 .57816 L .53552 .57817 L F
.105 .232 .712 r
.537 .57956 m .53696 .58304 L .53762 .58212 L F
.537 .57956 m .53762 .58212 L .53753 .58053 L F
.865 .885 .849 r
.537 .57956 m .53542 .58225 L .53696 .58304 L F
.537 .57956 m .53542 .58225 L .53696 .58304 L F
.895 .988 .774 r
.53631 .57971 m .53542 .58225 L .537 .57956 L F
.592 .655 .881 r
.5373 .58072 m .53542 .58225 L .53631 .57971 L F
.105 .232 .712 r
.53753 .58053 m .53762 .58212 L .53806 .58151 L F
.592 .655 .881 r
.53806 .58151 m .53737 .5817 L .5373 .58072 L F
.53737 .5817 m .53542 .58225 L .5373 .58072 L F
.842 .441 .283 r
.53743 .5788 m .53748 .57968 L .53806 .57901 L F
.53552 .57817 m .53748 .57968 L .53743 .5788 L F
.53552 .57817 m .53674 .58052 L .53748 .57968 L F
.984 .879 .525 r
.53748 .57968 m .53724 .57995 L .53739 .57824 L F
.916 .536 .278 r
.537 .57956 m .53806 .58151 L .53631 .57971 L F
.984 .879 .525 r
.53724 .57995 m .53674 .58052 L .53717 .57901 L F
.53724 .57995 m .53717 .57901 L .53739 .57824 L F
.53806 .57901 m .53748 .57968 L .53742 .57816 L F
.53748 .57968 m .53739 .57824 L .53742 .57816 L F
.542 .841 .999 r
.53696 .58304 m .53542 .58225 L .53806 .58151 L F
.668 .247 .236 r
.67805 .40445 m .68165 .40348 L .678 .40295 L F
.67805 .40445 m .68325 .40443 L .68165 .40348 L F
.637 .187 .166 r
.68099 .40624 m .68325 .40443 L .67805 .40445 L F
.624 .178 .172 r
.68343 .40696 m .68325 .40443 L .68099 .40624 L F
.68343 .40696 m .68426 .40528 L .68325 .40443 L F
.649 .127 0 r
.68325 .40443 m .68426 .40528 L .68165 .40348 L F
.621 .264 .343 r
.68165 .40348 m .68426 .40528 L .68435 .40368 L F
.141 0 .245 r
.44936 .59802 m .45109 .59888 L .45154 .59738 L F
.44936 .59802 m .44931 .59979 L .45109 .59888 L F
.63 .591 .791 r
.5356 .56438 m .53296 .56513 L .53213 .56157 L F
.536 .421 .669 r
.24103 .55594 m .24182 .55184 L .23991 .55436 L F
.24103 .55594 m .24309 .55281 L .24182 .55184 L F
.24103 .55594 m .24327 .55554 L .24309 .55281 L F
.528 .367 .607 r
.43769 .618 m .43511 .61544 L .43679 .615 L F
.43769 .618 m .43532 .61856 L .43511 .61544 L F
.005 .572 .791 r
.24306 .5392 m .24528 .53937 L .2475 .53981 L F
0 .473 .735 r
.24528 .53937 m .24922 .54029 L .2475 .53981 L F
.547 .83 .998 r
.1756 .58153 m .17525 .58313 L .17736 .58249 L F
.1756 .58153 m .17525 .58313 L .17736 .58249 L F
.74 .457 .502 r
.47171 .58348 m .47081 .58622 L .46893 .58586 L F
.519 .825 1 r
.47416 .58282 m .47171 .58348 L .47009 .57939 L F
.47416 .58282 m .47302 .58227 L .47171 .58348 L F
0 0 .055 r
.47302 .58227 m .47081 .58622 L .47171 .58348 L F
.563 .427 .654 r
.5979 .44809 m .60061 .45036 L .60035 .44747 L F
.5979 .44809 m .59837 .45112 L .60061 .45036 L F
.12 0 .188 r
.25652 .57078 m .25821 .57024 L .25907 .56764 L F
.493 .449 .736 r
.25851 .56478 m .25907 .56764 L .26096 .56693 L F
.338 .028 .285 r
.25907 .56764 m .26031 .56955 L .26096 .56693 L F
.25907 .56764 m .25821 .57024 L .26031 .56955 L F
.771 .803 .879 r
.71022 .41886 m .70682 .41867 L .70897 .41735 L F
.768 .826 .898 r
.71242 .41736 m .71022 .41886 L .70897 .41735 L F
.332 .129 .448 r
.43789 .59321 m .4359 .59189 L .43808 .59106 L F
.43789 .59321 m .43597 .59406 L .4359 .59189 L F
.901 .68 .593 r
.22726 .64971 m .22761 .65049 L .23057 .64917 L F
.383 .592 .927 r
.78146 .39186 m .78034 .39063 L .78124 .39019 L F
.101 .37 .833 r
.78382 .39196 m .78146 .39186 L .78124 .39019 L F
.78382 .39196 m .78439 .39368 L .78146 .39186 L F
0 0 .367 r
.64905 .4192 m .64971 .41995 L .64879 .41883 L F
0 0 .358 r
.64971 .41995 m .6488 .42431 L .65002 .42032 L F
.64971 .41995 m .65071 .42186 L .6488 .42431 L F
.65071 .42186 m .65076 .42195 L .65066 .42207 L F
.65071 .42186 m .65066 .42207 L .6488 .42431 L F
.107 0 0 r
.65024 .42493 m .6488 .42431 L .65076 .42195 L F
.65024 .42493 m .6479 .42582 L .6488 .42431 L F
0 0 .367 r
.65058 .42131 m .65076 .42195 L .64971 .41995 L F
.745 .749 .855 r
.65058 .42131 m .64655 .42441 L .65003 .4249 L F
.65039 .4233 m .65003 .4249 L .65024 .42493 L F
.65058 .42131 m .65003 .4249 L .65039 .4233 L F
0 0 .367 r
.65058 .42131 m .64971 .41995 L .64905 .4192 L F
0 0 .358 r
.64971 .41995 m .65002 .42032 L .65013 .41996 L F
.986 .741 .476 r
.67343 .43694 m .67356 .43977 L .67228 .43862 L F
.618 .842 .985 r
.67487 .43498 m .67601 .43621 L .67343 .43694 L F
.67487 .43498 m .67343 .43694 L .67228 .43862 L F
.451 .159 .376 r
.46932 .614 m .47102 .61501 L .47025 .61387 L F
.411 .188 .462 r
.47102 .61501 m .46881 .6157 L .46932 .614 L F
.161 0 .273 r
.54843 .49538 m .55063 .49484 L .55103 .49282 L F
.133 0 .181 r
.54843 .49538 m .54806 .49776 L .55063 .49484 L F
0 .069 .631 r
.51185 .58388 m .51261 .58562 L .51097 .5825 L F
0 0 .468 r
.51373 .5867 m .51261 .58562 L .51185 .58388 L F
.51373 .5867 m .51388 .58791 L .51261 .58562 L F
.782 .322 0 r
.49257 .5394 m .49362 .54086 L .49241 .53978 L F
.051 .483 .887 r
.49345 .5407 m .49334 .53984 L .49241 .53978 L F
.825 .761 .248 r
.49334 .53984 m .49282 .54146 L .49325 .53909 L F
.301 .575 .936 r
.49241 .53978 m .49334 .53984 L .49334 .53854 L F
.825 .761 .248 r
.49334 .53984 m .49325 .53909 L .49334 .53854 L F
.051 .483 .887 r
.49362 .54086 m .49334 .53984 L .49345 .5407 L F
.49362 .54086 m .4949 .54137 L .49334 .53984 L F
.636 .629 .827 r
.21315 .65986 m .21369 .66312 L .21694 .66141 L F
.779 .547 .585 r
.67687 .40933 m .67323 .41156 L .67412 .40915 L F
.67687 .40933 m .67693 .41187 L .67323 .41156 L F
.785 .731 .803 r
.75319 .37419 m .74953 .37342 L .75283 .37309 L F
.614 .698 .904 r
.75512 .37188 m .75319 .37419 L .75283 .37309 L F
.75512 .37188 m .75549 .37383 L .75319 .37419 L F
.436 .576 .895 r
.74288 .42799 m .74459 .42624 L .74268 .42594 L F
.74288 .42799 m .74651 .42897 L .74459 .42624 L F
0 .457 .781 r
.47617 .60815 m .4798 .60946 L .47988 .60694 L F
.521 .314 .54 r
.48161 .60647 m .4798 .60946 L .47988 .60694 L F
.48161 .60647 m .4798 .60946 L .47988 .60694 L F
.782 .322 0 r
.49257 .5394 m .49241 .53978 L .49189 .53757 L F
.196 0 0 r
.17143 .54849 m .17586 .54689 L .17374 .54763 L F
.324 .153 .489 r
.60301 .44239 m .60498 .4437 L .60531 .44173 L F
.60301 .44239 m .60308 .44469 L .60498 .4437 L F
.75 .776 .874 r
.71387 .42614 m .7117 .42726 L .71521 .42763 L F
.31 0 .055 r
.56193 .49663 m .56061 .49845 L .5589 .49845 L F
.352 0 .08 r
.56395 .49732 m .56193 .49663 L .56399 .49536 L F
.56395 .49732 m .56061 .49845 L .56193 .49663 L F
.551 .351 .562 r
.7432 .41544 m .74576 .41545 L .74457 .41238 L F
.147 0 .262 r
.25652 .57078 m .25594 .57314 L .25821 .57024 L F
.216 0 .211 r
.40743 .58912 m .40661 .59106 L .40933 .5883 L F
.594 .562 .788 r
.20449 .68846 m .20706 .68847 L .2055 .68696 L F
.701 .742 .883 r
.75089 .43383 m .75251 .42971 L .74968 .43177 L F
.75089 .43383 m .7531 .43265 L .75251 .42971 L F
.94 .956 .653 r
.59779 .51442 m .59763 .51725 L .59938 .51328 L F
.931 .97 .741 r
.59584 .51804 m .59763 .51725 L .59779 .51442 L F
.476 0 0 r
.19245 .67829 m .19591 .68138 L .19641 .67884 L F
.492 .297 .544 r
.59587 .45341 m .59831 .45347 L .59837 .45112 L F
.541 .31 .514 r
.59561 .45616 m .59831 .45347 L .59587 .45341 L F
.776 .696 .775 r
.42626 .64666 m .4262 .64921 L .42484 .64803 L F
.64 .114 0 r
.4262 .64921 m .42659 .64998 L .42484 .64803 L F
.594 .543 .767 r
.42901 .64863 m .4262 .64921 L .42626 .64666 L F
.783 .501 .51 r
.42787 .64887 m .42677 .64982 L .4262 .64921 L F
.42677 .64982 m .42659 .64998 L .42653 .64986 L F
.42677 .64982 m .42653 .64986 L .4262 .64921 L F
.421 .154 .401 r
.4308 .6502 m .42849 .65079 L .42901 .64863 L F
.927 .546 .16 r
.42923 .64941 m .42849 .65079 L .4308 .6502 L F
.783 .501 .51 r
.42901 .64863 m .42714 .64967 L .42787 .64887 L F
.42901 .64863 m .42849 .65079 L .42659 .64998 L F
.927 .546 .16 r
.42686 .64821 m .42777 .64965 L .42923 .64941 L F
.42777 .64965 m .42849 .65079 L .42923 .64941 L F
.783 .501 .51 r
.42714 .64967 m .42659 .64998 L .42787 .64887 L F
.428 .672 .964 r
.42659 .64998 m .42849 .65079 L .42579 .64938 L F
.856 .466 .306 r
.42751 .65148 m .42849 .65079 L .42689 .64995 L F
.42656 .65032 m .42689 .64995 L .42579 .64938 L F
.42751 .65148 m .42689 .64995 L .42656 .65032 L F
.321 .119 .442 r
.4056 .61741 m .40376 .61592 L .40583 .61519 L F
.4056 .61741 m .40347 .61832 L .40376 .61592 L F
.40376 .61592 m .4056 .61741 L .40583 .61519 L F
.40376 .61592 m .40347 .61832 L .4056 .61741 L F
.761 .637 .724 r
.51581 .5277 m .51595 .53408 L .51305 .53172 L F
.632 .535 .726 r
.51825 .52929 m .51595 .53408 L .51581 .5277 L F
0 .222 .735 r
.51595 .53408 m .51663 .53348 L .51305 .53172 L F
.51595 .53408 m .51665 .53475 L .51663 .53348 L F
.17 0 0 r
.52353 .51521 m .52731 .51342 L .52499 .51414 L F
.492 .349 .615 r
.53629 .55265 m .53671 .55561 L .53414 .55605 L F
.119 0 0 r
.46474 .58091 m .46402 .582 L .46654 .58119 L F
.484 .225 .445 r
.22691 .62363 m .22938 .62155 L .2274 .62215 L F
.499 .254 .474 r
.4443 .64572 m .44712 .64537 L .44712 .64268 L F
.44712 .64268 m .44712 .64537 L .4443 .64572 L F
.069 .177 .67 r
.53087 .53428 m .53193 .53723 L .53088 .53837 L F
0 0 0 r
.53088 .53837 m .5309 .53869 L .52982 .54029 L F
.53088 .53837 m .53193 .53723 L .5309 .53869 L F
.588 .573 .804 r
.42761 .64009 m .42831 .64298 L .43063 .64192 L F
.233 .046 .409 r
.42841 .64551 m .43063 .64192 L .42831 .64298 L F
.817 .831 .86 r
.67641 .44889 m .67821 .44752 L .67912 .44376 L F
.89 .904 .831 r
.67912 .44376 m .67821 .44752 L .68038 .44436 L F
.65 .405 .536 r
.44051 .61293 m .43679 .615 L .43897 .61324 L F
.44051 .61293 m .4403 .61529 L .43679 .615 L F
.43 .181 .434 r
.4429 .61246 m .4403 .61529 L .44051 .61293 L F
.084 .623 .855 r
.1712 .65064 m .17147 .65026 L .16934 .65054 L F
.1712 .65064 m .17356 .65058 L .17147 .65026 L F
.718 .888 .959 r
.42097 .59546 m .42419 .59514 L .42321 .59355 L F
.42097 .59546 m .4211 .59574 L .42419 .59514 L F
.658 .756 .922 r
.42321 .59355 m .42419 .59514 L .42681 .59456 L F
.42321 .59355 m .42419 .59514 L .42681 .59456 L F
.534 .43 .683 r
.42419 .59514 m .42681 .59746 L .42681 .59456 L F
.42419 .59514 m .42462 .59748 L .42548 .59628 L F
.76 .334 .239 r
.42681 .59456 m .42494 .59644 L .42321 .59355 L F
.699 .913 .568 r
.42754 .59304 m .42494 .59644 L .42648 .59489 L F
.427 .59417 m .42648 .59489 L .42681 .59456 L F
.42754 .59304 m .42648 .59489 L .427 .59417 L F
.534 .43 .683 r
.42548 .59628 m .42478 .59834 L .42681 .59746 L F
.42462 .59748 m .42478 .59834 L .42548 .59628 L F
.174 0 .058 r
.55389 .48996 m .55527 .491 L .55578 .48934 L F
.55389 .48996 m .55314 .49185 L .55527 .491 L F
.602 .825 .985 r
.18184 .62833 m .17796 .62791 L .1801 .62723 L F
.357 .722 .987 r
.18375 .62811 m .18184 .62833 L .1801 .62723 L F
.33 .49 .867 r
.18571 .63166 m .18184 .62833 L .18375 .62811 L F
.446 .339 .639 r
.45626 .57067 m .45885 .57306 L .45859 .57023 L F
.45626 .57067 m .4563 .57474 L .45885 .57306 L F
.74 .612 .716 r
.45399 .58936 m .45716 .59116 L .45583 .58803 L F
.45399 .58936 m .45574 .59222 L .45716 .59116 L F
.706 .206 .049 r
.46033 .58928 m .45583 .58803 L .45716 .59116 L F
.587 .795 .978 r
.45716 .59116 m .46027 .59115 L .46033 .58928 L F
.319 0 0 r
.22888 .53809 m .23358 .53898 L .23098 .53906 L F
.817 .831 .86 r
.67641 .44889 m .67912 .44376 L .67419 .44713 L F
.857 .822 .814 r
.53334 .52584 m .53293 .52314 L .53055 .52564 L F
.837 .717 .731 r
.52965 .52791 m .53334 .52584 L .53055 .52564 L F
.52965 .52791 m .53159 .52897 L .53334 .52584 L F
.845 .881 .866 r
.53558 .5227 m .53293 .52314 L .53334 .52584 L F
.661 .271 .296 r
.42877 .65847 m .43126 .66 L .43116 .65838 L F
.596 .348 .511 r
.44492 .57705 m .44732 .57876 L .4483 .57684 L F
.44492 .57705 m .44483 .57941 L .44732 .57876 L F
.845 .881 .866 r
.53558 .5227 m .53454 .52153 L .53293 .52314 L F
.693 .959 .947 r
.53872 .52017 m .53454 .52153 L .53558 .5227 L F
.94 .956 .653 r
.59779 .51442 m .59938 .51328 L .59889 .51332 L F
.562 .356 .559 r
.57397 .56822 m .57412 .57027 L .57159 .57082 L F
.529 .312 .53 r
.57633 .5677 m .57412 .57027 L .57397 .56822 L F
0 0 .154 r
.5766 .53782 m .57465 .5411 L .57587 .53999 L F
.117 0 .42 r
.57587 .53999 m .57465 .5411 L .57457 .54349 L F
.22 .404 .832 r
.63554 .40633 m .63788 .40784 L .638 .4061 L F
.677 .814 .949 r
.21694 .66141 m .22077 .66191 L .21929 .65933 L F
.61 .559 .772 r
.21929 .65933 m .22077 .66191 L .22265 .66075 L F
.765 .882 .93 r
.52388 .54286 m .52852 .54201 L .5262 .54166 L F
.78 .718 .795 r
.4394 .63658 m .43611 .63661 L .43841 .63405 L F
.283 .004 .301 r
.4394 .63658 m .43658 .63961 L .43611 .63661 L F
.4394 .63658 m .43892 .63901 L .43658 .63961 L F
.583 .563 .798 r
.44066 .63282 m .4394 .63658 L .43841 .63405 L F
.44066 .63282 m .44194 .63642 L .4394 .63658 L F
.133 0 0 r
.44194 .63642 m .43892 .63901 L .4394 .63658 L F
0 0 .21 r
.58259 .5551 m .58133 .5561 L .58298 .55271 L F
.011 0 .355 r
.58109 .5586 m .58133 .5561 L .58259 .5551 L F
.497 .384 .654 r
.28433 .57405 m .28497 .57695 L .28279 .57736 L F
.585 .563 .796 r
.28661 .57969 m .28279 .57736 L .28497 .57695 L F
.245 0 .116 r
.43425 .58391 m .43589 .58431 L .4366 .58316 L F
.43425 .58391 m .43354 .58558 L .43589 .58431 L F
0 0 0 r
.76394 .40295 m .76356 .40353 L .76479 .40191 L F
.76394 .40295 m .76316 .40572 L .76356 .40353 L F
.443 .257 .533 r
.41719 .57913 m .41966 .57928 L .41982 .57677 L F
.417 .189 .458 r
.41719 .57913 m .41939 .58172 L .41966 .57928 L F
.41719 .57913 m .41719 .58247 L .41939 .58172 L F
.368 .099 .368 r
.45911 .58327 m .46078 .58465 L .46126 .58259 L F
.563 .444 .676 r
.62003 .42869 m .6183 .42978 L .62075 .42903 L F
.865 .587 .515 r
.61826 .42868 m .61738 .42743 L .61456 .42675 L F
.309 .129 .467 r
.61682 .42909 m .61781 .42897 L .61826 .42868 L F
.865 .587 .515 r
.61826 .42868 m .6183 .42978 L .61796 .42892 L F
.61826 .42868 m .61796 .42892 L .61738 .42743 L F
.563 .444 .676 r
.61945 .42841 m .61797 .42895 L .62003 .42869 L F
.122 0 0 r
.61826 .42868 m .61781 .42897 L .61796 .42892 L F
.563 .444 .676 r
.61738 .42743 m .61796 .42892 L .61945 .42841 L F
.61796 .42892 m .61797 .42895 L .61945 .42841 L F
.122 0 0 r
.61796 .42892 m .6145 .4311 L .61573 .43069 L F
.61781 .42897 m .6145 .4311 L .61796 .42892 L F
.61826 .42868 m .61573 .43069 L .61744 .43012 L F
.563 .444 .676 r
.61797 .42895 m .6183 .42978 L .62003 .42869 L F
.309 .129 .467 r
.61232 .43038 m .6145 .4311 L .61781 .42897 L F
.61232 .43038 m .61781 .42897 L .61682 .42909 L F
.61232 .43038 m .6127 .43245 L .6145 .4311 L F
.686 .287 0 r
.67363 .4461 m .67419 .44713 L .67343 .446 L F
.929 .881 .766 r
.67356 .44292 m .67363 .4461 L .6726 .44453 L F
.686 .287 0 r
.67363 .4461 m .67343 .446 L .6726 .44453 L F
.709 .961 .945 r
.67343 .446 m .67419 .44713 L .67912 .44376 L F
.699 .567 .703 r
.42191 .57604 m .42437 .57294 L .42239 .57292 L F
.481 .476 .775 r
.19211 .74658 m .19159 .74388 L .19046 .74456 L F
.19211 .74658 m .19303 .74362 L .19159 .74388 L F
.19211 .74658 m .19335 .74567 L .19303 .74362 L F
.004 0 0 r
.40188 .59469 m .40371 .59383 L .40482 .5921 L F
.42 .119 .346 r
.40371 .59383 m .40661 .59106 L .40482 .5921 L F
.067 0 0 r
.47566 .61379 m .47473 .61272 L .47704 .61199 L F
.47566 .61379 m .47367 .61469 L .47473 .61272 L F
.189 .366 .81 r
.47779 .58955 m .47645 .58957 L .47365 .58413 L F
.94 .959 .664 r
.77337 .40333 m .77475 .40085 L .7742 .40067 L F
.406 0 0 r
.77475 .40085 m .77482 .40158 L .7742 .40067 L F
.77475 .40085 m .77698 .40125 L .77482 .40158 L F
.471 .268 .522 r
.49703 .58628 m .49684 .58905 L .49483 .58904 L F
.49703 .58628 m .49684 .58905 L .49483 .58904 L F
.785 .755 .826 r
.19668 .71312 m .20059 .71255 L .19852 .71094 L F
.7 .78 .913 r
.19852 .71094 m .20059 .71255 L .20246 .71125 L F
.576 .08 .038 r
.1873 .72914 m .18936 .72925 L .18819 .72864 L F
.648 .853 .978 r
.7464 .41719 m .74439 .4196 L .74296 .41925 L F
.7464 .41719 m .74727 .41851 L .74439 .4196 L F
.46 .786 .999 r
.19278 .65293 m .19608 .65344 L .19485 .6529 L F
.503 .844 .996 r
.19608 .65344 m .19758 .65224 L .19485 .6529 L F
.19608 .65344 m .19949 .65302 L .19758 .65224 L F
.522 .739 .974 r
.73448 .39485 m .73328 .39681 L .73207 .39589 L F
.73448 .39485 m .73565 .39639 L .73328 .39681 L F
.73328 .39681 m .73448 .39485 L .73207 .39589 L F
.73328 .39681 m .73565 .39639 L .73448 .39485 L F
.427 .065 .246 r
.44732 .57876 m .45122 .57617 L .4483 .57684 L F
0 0 0 r
.22691 .62363 m .22482 .625 L .22297 .6266 L F
.723 .971 .724 r
.21137 .68434 m .21416 .68159 L .21228 .68193 L F
0 .175 .711 r
.47871 .59454 m .47991 .59561 L .47848 .59306 L F
.47871 .59454 m .47991 .59561 L .47848 .59306 L F
.804 .803 .85 r
.17435 .62459 m .17231 .62707 L .16977 .62566 L F
.538 .398 .638 r
.17444 .62613 m .17231 .62707 L .17435 .62459 L F
.406 .154 .416 r
.43892 .63901 m .43562 .64104 L .43658 .63961 L F
0 0 .037 r
.53886 .50543 m .54048 .50412 L .54111 .50254 L F
.281 0 .194 r
.54111 .50254 m .54048 .50412 L .54346 .50168 L F
.536 .34 .562 r
.56457 .4808 m .5671 .48046 L .56683 .47815 L F
.292 0 .133 r
.56457 .4808 m .56618 .48193 L .5671 .48046 L F
.56457 .4808 m .56363 .48276 L .56618 .48193 L F
.894 .791 .74 r
.6068 .48996 m .60839 .48623 L .606 .48644 L F
.779 .815 .336 r
.62695 .41829 m .62697 .41802 L .62796 .41515 L F
.694 .533 .665 r
.62431 .41516 m .62796 .41515 L .62791 .41274 L F
.607 .464 .661 r
.62791 .41274 m .62796 .41515 L .63039 .41216 L F
.571 .167 .238 r
.70186 .40226 m .69995 .40003 L .69889 .40236 L F
.70186 .40226 m .70252 .40011 L .69995 .40003 L F
.75 .987 .898 r
.51248 .5384 m .51164 .5405 L .51468 .53807 L F
.598 .776 .965 r
.51164 .5405 m .51517 .53994 L .51468 .53807 L F
.565 .812 .991 r
.51248 .5384 m .51517 .53994 L .51164 .5405 L F
.28 0 .14 r
.47009 .57939 m .47161 .58092 L .47212 .57902 L F
.47009 .57939 m .46937 .5821 L .47161 .58092 L F
.941 .964 .716 r
.60298 .50161 m .60061 .5042 L .601 .5051 L F
.60298 .50161 m .60221 .50105 L .60061 .5042 L F
.983 .909 .632 r
.60298 .50161 m .60307 .49865 L .60221 .50105 L F
.315 .361 .75 r
.25851 .56478 m .25898 .5608 L .25669 .5614 L F
.25851 .56478 m .25996 .56441 L .25898 .5608 L F
.493 .449 .736 r
.25851 .56478 m .26096 .56693 L .25996 .56441 L F
.574 .456 .681 r
.45715 .57657 m .45711 .5798 L .45507 .58017 L F
.519 .275 .484 r
.45507 .58017 m .4568 .58174 L .45474 .58218 L F
.45507 .58017 m .45711 .5798 L .4568 .58174 L F
.334 .666 .974 r
.26703 .54359 m .26643 .54489 L .26488 .54374 L F
.26703 .54359 m .26916 .54519 L .26643 .54489 L F
.024 0 0 r
.20916 .55268 m .20738 .55289 L .2052 .55299 L F
0 .351 .737 r
.20916 .55268 m .21013 .55287 L .20738 .55289 L F
.193 .603 .945 r
.21114 .55357 m .21204 .55265 L .21013 .55287 L F
.026 0 0 r
.21204 .55265 m .21051 .55294 L .21013 .55287 L F
.21051 .55294 m .20783 .55345 L .21013 .55287 L F
0 .351 .737 r
.20916 .55268 m .20918 .55269 L .21013 .55287 L F
.20918 .55269 m .21114 .55357 L .21013 .55287 L F
0 0 0 r
.21395 .65804 m .21315 .65986 L .21544 .65578 L F
.783 .663 .731 r
.4297 .63658 m .42761 .64009 L .43063 .63954 L F
.588 .573 .804 r
.42761 .64009 m .43063 .64192 L .43063 .63954 L F
.507 .237 .44 r
.45754 .59451 m .46018 .59408 L .46027 .59115 L F
.411 .336 .662 r
.46033 .58928 m .46027 .59115 L .4626 .59018 L F
.506 .317 .559 r
.46018 .59408 m .4626 .59018 L .46027 .59115 L F
.316 .001 .263 r
.71294 .39329 m .71075 .39425 L .71071 .39616 L F
.547 .389 .618 r
.5671 .48046 m .56925 .47771 L .56683 .47815 L F
.697 .807 .933 r
.7527 .38791 m .75629 .38833 L .7559 .38666 L F
.968 .813 .387 r
.75627 .38574 m .75629 .38833 L .7559 .38666 L F
.099 .346 .815 r
.7559 .38666 m .75629 .38833 L .75764 .38864 L F
.397 .323 .655 r
.78114 .4444 m .78363 .44413 L .78009 .44237 L F
.78114 .4444 m .78363 .44413 L .78009 .44237 L F
.741 .343 .298 r
.65255 .42632 m .65513 .4243 L .65413 .42741 L F
.857 .629 .592 r
.6556 .42747 m .65413 .42741 L .65513 .4243 L F
.981 .762 .534 r
.6556 .42747 m .65631 .43038 L .65506 .42848 L F
.228 0 0 r
.65759 .42767 m .65554 .42729 L .65506 .42848 L F
.65554 .42729 m .65429 .42707 L .65433 .42714 L F
.981 .762 .534 r
.6556 .42747 m .65506 .42848 L .65413 .42741 L F
.228 0 0 r
.65554 .42729 m .65433 .42714 L .65506 .42848 L F
.741 .343 .298 r
.65255 .42632 m .65442 .42715 L .65513 .4243 L F
.65442 .42715 m .65458 .42722 L .65459 .42717 L F
.65442 .42715 m .65459 .42717 L .65513 .4243 L F
.945 .813 .363 r
.65513 .4243 m .65466 .42366 L .65504 .41971 L F
.923 .674 .544 r
.65466 .42366 m .65458 .42722 L .65256 .42173 L F
.228 0 0 r
.65759 .42767 m .65683 .42766 L .65453 .42712 L F
.675 .567 .725 r
.65256 .42173 m .65458 .42722 L .65255 .42632 L F
.228 0 0 r
.65457 .42712 m .65453 .42712 L .65429 .42707 L F
.65759 .42767 m .65453 .42712 L .65457 .42712 L F
.924 .73 .242 r
.65513 .4243 m .6546 .42712 L .65466 .42366 L F
.6546 .42712 m .65458 .42722 L .65459 .42712 L F
.6546 .42712 m .65459 .42712 L .65466 .42366 L F
.908 .85 .774 r
.58866 .50327 m .58953 .50572 L .58812 .50756 L F
.478 .311 .575 r
.23468 .61305 m .23687 .61247 L .2368 .60971 L F
.395 .111 .36 r
.23567 .61487 m .23468 .61305 L .23441 .6152 L F
.23567 .61487 m .23687 .61247 L .23468 .61305 L F
.48 .201 .412 r
.43116 .62808 m .42842 .63062 L .4285 .62786 L F
.43116 .62808 m .43083 .63016 L .42842 .63062 L F
.08 0 .216 r
.57395 .48066 m .57327 .48286 L .57504 .48012 L F
.57504 .48012 m .57327 .48286 L .57395 .48066 L F
.156 .152 .601 r
.25482 .57692 m .25641 .57888 L .25623 .57519 L F
.201 .163 .589 r
.25527 .57969 m .25641 .57888 L .25482 .57692 L F
.555 .322 .517 r
.58532 .46275 m .58816 .46241 L .58797 .46015 L F
.517 .294 .515 r
.58797 .46015 m .58816 .46241 L .59046 .4596 L F
.572 .479 .711 r
.57462 .57354 m .57159 .57082 L .57412 .57027 L F
.57462 .57354 m .57228 .57416 L .57159 .57082 L F
.041 .483 .884 r
.76701 .43734 m .76844 .43697 L .76692 .43634 L F
.76701 .43734 m .76949 .43808 L .76844 .43697 L F
.119 0 0 r
.55208 .6099 m .55088 .61152 L .54857 .6123 L F
0 0 0 r
.55208 .6099 m .55409 .6087 L .55342 .60932 L F
.292 .778 .706 r
.55208 .6099 m .55163 .60989 L .55088 .61152 L F
.55208 .6099 m .55342 .60932 L .55163 .60989 L F
.186 0 .305 r
.40188 .59469 m .39963 .59782 L .40141 .59687 L F
.499 .265 .491 r
.39851 .60007 m .40141 .59687 L .39963 .59782 L F
.599 .218 .293 r
.68718 .40521 m .68781 .40329 L .68435 .40368 L F
.54 .161 .272 r
.69034 .40466 m .68781 .40329 L .68718 .40521 L F
.532 .177 .311 r
.69034 .40466 m .69064 .40311 L .68781 .40329 L F
.969 .933 .642 r
.76316 .40572 m .76201 .40826 L .76261 .40856 L F
.995 .835 .478 r
.76155 .41116 m .76261 .40856 L .76201 .40826 L F
.76155 .41116 m .76227 .41247 L .76261 .40856 L F
.201 .053 .445 r
.56195 .56806 m .56337 .56953 L .56383 .56722 L F
.56195 .56806 m .56192 .5707 L .56337 .56953 L F
.745 .233 0 r
.501 .54694 m .49946 .54602 L .49786 .54392 L F
.689 .193 0 r
.501 .54694 m .50154 .54826 L .49946 .54602 L F
.501 .54694 m .5029 .54945 L .50154 .54826 L F
.575 .365 .56 r
.56305 .56093 m .56513 .55871 L .56261 .55916 L F
.348 .55 .908 r
.28454 .5514 m .28365 .55312 L .28322 .55208 L F
.115 .251 .728 r
.28454 .5514 m .28585 .55494 L .28365 .55312 L F
.315 .266 .643 r
.28365 .55312 m .28585 .55494 L .28427 .55569 L F
.877 .89 .839 r
.67939 .44315 m .68297 .44153 L .68181 .44018 L F
.67939 .44315 m .68038 .44436 L .68297 .44153 L F
.779 .883 .921 r
.68181 .44018 m .68297 .44153 L .68599 .43905 L F
0 0 0 r
.54947 .59242 m .54805 .59181 L .54826 .59443 L F
.54947 .59242 m .55005 .59106 L .54805 .59181 L F
.544 .325 .532 r
.27712 .59984 m .27498 .59794 L .27733 .59736 L F
.27712 .59984 m .2748 .60027 L .27498 .59794 L F
.975 .853 .459 r
.60047 .50751 m .601 .5051 L .59992 .50652 L F
.953 .875 .469 r
.59992 .50652 m .601 .5051 L .60061 .5042 L F
.706 .206 .049 r
.46033 .58928 m .45824 .59013 L .45583 .58803 L F
0 0 0 r
.46049 .58944 m .46033 .58928 L .4626 .59018 L F
.46049 .58944 m .45824 .59013 L .46033 .58928 L F
.542 .389 .622 r
.43535 .62147 m .43555 .62414 L .43305 .62224 L F
.975 .738 .514 r
.50955 .58192 m .51097 .5825 L .51123 .57992 L F
.333 .522 .891 r
.51033 .57749 m .51123 .57992 L .50956 .57736 L F
.997 .833 .559 r
.51033 .57749 m .50955 .58192 L .51123 .57992 L F
.332 .189 .532 r
.24379 .59791 m .24543 .59976 L .24595 .59725 L F
.24379 .59791 m .24366 .6005 L .24543 .59976 L F
.627 .806 .969 r
.71765 .41446 m .72121 .41492 L .71866 .41586 L F
.67 .143 0 r
.72849 .41824 m .72753 .41906 L .72898 .41904 L F
.609 .597 .814 r
.72986 .41396 m .72849 .41824 L .7273 .41469 L F
.72986 .41396 m .73101 .41847 L .72849 .41824 L F
.865 .987 .838 r
.72753 .41906 m .72765 .42073 L .72898 .41904 L F
.435 .81 .992 r
.73135 .41937 m .72753 .41906 L .72849 .41824 L F
.548 .105 .148 r
.72849 .41824 m .73101 .41847 L .73135 .41937 L F
.378 .192 .498 r
.49703 .58628 m .49895 .58782 L .4993 .58572 L F
.49895 .58782 m .49703 .58628 L .49749 .58407 L F
.49895 .58782 m .49684 .58905 L .49703 .58628 L F
.49703 .58628 m .49684 .58905 L .49895 .58782 L F
.098 .618 .883 r
.66259 .45074 m .66398 .45148 L .66029 .45063 L F
.425 .548 .877 r
.66164 .44884 m .66259 .45074 L .6628 .45076 L F
.41 .8 .988 r
.66391 .45007 m .66398 .45148 L .6628 .45076 L F
.425 .548 .877 r
.66387 .45009 m .664 .45003 L .66427 .44817 L F
.505 .488 .771 r
.66427 .44817 m .66396 .45004 L .66387 .45009 L F
.66427 .44817 m .66327 .4504 L .66295 .45032 L F
.66427 .44817 m .66295 .45032 L .66164 .44884 L F
.425 .548 .877 r
.66164 .44884 m .66245 .45018 L .66286 .45022 L F
.66245 .45018 m .6628 .45076 L .66327 .4504 L F
.505 .488 .771 r
.66295 .45032 m .66271 .45071 L .66164 .44884 L F
.425 .548 .877 r
.66164 .44884 m .66286 .45022 L .66344 .45028 L F
.66245 .45018 m .66327 .4504 L .66344 .45028 L F
.505 .488 .771 r
.66427 .44817 m .66387 .45009 L .66327 .4504 L F
.66295 .45032 m .66327 .4504 L .66271 .45071 L F
.425 .548 .877 r
.66344 .45028 m .66387 .45009 L .66427 .44817 L F
.668 .605 .776 r
.66646 .44542 m .66401 .44995 L .66427 .44817 L F
.66646 .44542 m .66782 .4495 L .66406 .45004 L F
.66782 .4495 m .66744 .44988 L .66406 .45004 L F
.66744 .44988 m .66736 .44995 L .66719 .44995 L F
.66744 .44988 m .66719 .44995 L .66406 .45004 L F
.593 .669 .892 r
.67044 .44652 m .66899 .45024 L .66812 .44993 L F
.67044 .44652 m .67163 .44955 L .66899 .45024 L F
.525 .846 .998 r
.66899 .45024 m .67086 .4486 L .6681 .44992 L F
.668 .605 .776 r
.66646 .44542 m .66406 .45004 L .66401 .44995 L F
.807 .896 .906 r
.66483 .44999 m .66661 .44862 L .66427 .44817 L F
.587 .875 .994 r
.66899 .45024 m .66431 .45005 L .66736 .44995 L F
.66431 .45005 m .66457 .45002 L .66736 .44995 L F
.66399 .45004 m .66406 .45004 L .66736 .44995 L F
.41 .8 .988 r
.66396 .45005 m .66666 .45118 L .66398 .45148 L F
.66396 .45004 m .66397 .45004 L .66396 .45005 L F
.66397 .45004 m .66666 .45118 L .66396 .45005 L F
.587 .875 .994 r
.66431 .45005 m .66399 .45004 L .66457 .45002 L F
.425 .548 .877 r
.66344 .45028 m .66483 .44999 L .66407 .45003 L F
.587 .875 .994 r
.66899 .45024 m .66666 .45118 L .66397 .45004 L F
.425 .548 .877 r
.66397 .45004 m .66399 .45004 L .66397 .45004 L F
.587 .875 .994 r
.66399 .45004 m .66397 .45004 L .66396 .45004 L F
.66899 .45024 m .66397 .45004 L .66399 .45004 L F
.425 .548 .877 r
.66396 .45005 m .66397 .45004 L .66397 .45004 L F
.66397 .45004 m .66407 .45003 L .66399 .45004 L F
.41 .8 .988 r
.66396 .45004 m .6628 .45076 L .66327 .4504 L F
.425 .548 .877 r
.66344 .45028 m .66407 .45003 L .66396 .45005 L F
.096 0 0 r
.66398 .45148 m .66666 .45118 L .66538 .45182 L F
.807 .896 .906 r
.66538 .45182 m .66614 .44985 L .66483 .44999 L F
.66614 .44985 m .66661 .44862 L .66483 .44999 L F
.425 .548 .877 r
.66397 .45004 m .66483 .44999 L .66474 .4497 L F
.587 .875 .994 r
.66399 .45004 m .66396 .45004 L .66406 .45004 L F
.41 .8 .988 r
.66396 .45005 m .66398 .45148 L .66391 .45007 L F
.425 .548 .877 r
.66344 .45028 m .66538 .45182 L .66483 .44999 L F
.807 .896 .906 r
.66538 .45182 m .66566 .45161 L .66622 .44986 L F
.66614 .44985 m .66622 .44986 L .66661 .44862 L F
.66538 .45182 m .66622 .44986 L .66614 .44985 L F
.593 .669 .892 r
.67044 .44652 m .66809 .44997 L .66813 .4497 L F
.715 .632 .763 r
.67044 .44652 m .66813 .4497 L .66646 .44542 L F
.664 .841 .968 r
.66749 .44996 m .66799 .44997 L .6695 .44925 L F
.715 .632 .763 r
.66813 .4497 m .66796 .44993 L .6679 .44974 L F
.66813 .4497 m .6679 .44974 L .66646 .44542 L F
.664 .841 .968 r
.66744 .44988 m .66749 .44996 L .66832 .44967 L F
.6679 .44974 m .66832 .44967 L .6695 .44925 L F
.66744 .44988 m .66832 .44967 L .6679 .44974 L F
.587 .875 .994 r
.66817 .45002 m .66749 .44996 L .66799 .44997 L F
.664 .841 .968 r
.66749 .44996 m .66761 .45015 L .66799 .44997 L F
.587 .875 .994 r
.66799 .44997 m .66736 .44995 L .66787 .44994 L F
.66749 .44996 m .66736 .44995 L .66799 .44997 L F
.66899 .45024 m .66736 .44995 L .66817 .45002 L F
.525 .846 .998 r
.66899 .45024 m .6681 .44992 L .66799 .44997 L F
.587 .875 .994 r
.66899 .45024 m .66787 .44994 L .66796 .44993 L F
.525 .846 .998 r
.66899 .45024 m .66799 .44997 L .66761 .45015 L F
.593 .669 .892 r
.66812 .44993 m .66899 .45024 L .66809 .44997 L F
.66813 .4497 m .66809 .44997 L .66796 .44993 L F
.664 .841 .968 r
.66661 .44862 m .66744 .44988 L .66815 .44961 L F
.66831 .44862 m .66815 .44961 L .67086 .4486 L F
.66661 .44862 m .66815 .44961 L .66831 .44862 L F
.66744 .44988 m .6695 .44925 L .67086 .4486 L F
.807 .896 .906 r
.66566 .45161 m .66761 .45015 L .66744 .44988 L F
.66566 .45161 m .66744 .44988 L .66661 .44862 L F
.668 .605 .776 r
.66782 .4495 m .66796 .44993 L .66736 .44995 L F
.425 .548 .877 r
.664 .45003 m .66404 .45001 L .66401 .44995 L F
.668 .605 .776 r
.66401 .44995 m .66406 .45004 L .66396 .45004 L F
.425 .548 .877 r
.66401 .44995 m .66474 .4497 L .66427 .44817 L F
.66404 .45001 m .66474 .4497 L .66401 .44995 L F
.668 .605 .776 r
.66401 .44995 m .66396 .45004 L .66427 .44817 L F
.41 .8 .988 r
.66396 .45004 m .66396 .45005 L .66391 .45007 L F
.425 .548 .877 r
.66164 .44884 m .66344 .45028 L .66427 .44817 L F
.66344 .45028 m .6628 .45076 L .66422 .45089 L F
.41 .8 .988 r
.66327 .4504 m .6628 .45076 L .66271 .45071 L F
.098 .618 .883 r
.66278 .45075 m .6628 .45076 L .66259 .45074 L F
.6628 .45076 m .66398 .45148 L .66259 .45074 L F
.096 0 0 r
.66398 .45148 m .66538 .45182 L .66308 .45173 L F
.425 .548 .877 r
.66422 .45089 m .66308 .45173 L .66538 .45182 L F
.451 0 0 r
.66029 .45063 m .66398 .45148 L .66308 .45173 L F
.425 .548 .877 r
.66259 .45074 m .66308 .45173 L .66422 .45089 L F
.335 .493 .867 r
.66029 .45063 m .66308 .45173 L .66259 .45074 L F
.66029 .45063 m .66259 .45074 L .66164 .44884 L F
.098 .618 .883 r
.66271 .45071 m .66278 .45075 L .66029 .45063 L F
.831 .901 .889 r
.50536 .52586 m .50217 .52646 L .50441 .52497 L F
.819 .958 .904 r
.50536 .52586 m .50667 .52302 L .5084 .52343 L F
.50536 .52586 m .50441 .52497 L .50667 .52302 L F
.462 .275 .54 r
.28368 .58775 m .28174 .58589 L .28414 .58546 L F
.28368 .58775 m .28154 .58842 L .28174 .58589 L F
.821 .713 .745 r
.61355 .45317 m .61128 .45626 L .61482 .45669 L F
.826 .694 .719 r
.61128 .45626 m .61261 .45987 L .61482 .45669 L F
.808 .707 .753 r
.61355 .45317 m .61482 .45669 L .61517 .45436 L F
0 .367 .805 r
.50445 .55047 m .50575 .55051 L .5029 .54945 L F
.50445 .55047 m .50703 .5517 L .50575 .55051 L F
0 .279 .647 r
.50857 .55245 m .50703 .5517 L .50445 .55047 L F
.382 .198 .503 r
.56791 .55281 m .56987 .55213 L .56991 .54981 L F
.451 .307 .593 r
.56798 .55548 m .56987 .55213 L .56791 .55281 L F
.702 .757 .895 r
.65506 .42848 m .65631 .43038 L .65829 .42925 L F
.472 .33 .607 r
.27939 .5916 m .2795 .59432 L .27746 .5949 L F
.333 .165 .499 r
.2791 .59663 m .27746 .5949 L .2795 .59432 L F
.2791 .59663 m .27733 .59736 L .27746 .5949 L F
.716 .419 .473 r
.19832 .55528 m .19196 .55717 L .19582 .55498 L F
.155 .692 .699 r
.18446 .55897 m .17979 .55995 L .18231 .55947 L F
.452 .234 .492 r
.25637 .62495 m .25575 .6281 L .25358 .62861 L F
.455 .237 .493 r
.25794 .62741 m .25637 .62495 L .25827 .62424 L F
.25794 .62741 m .25575 .6281 L .25637 .62495 L F
.641 .38 .508 r
.70728 .40534 m .70394 .40845 L .70387 .40651 L F
.70728 .40534 m .7069 .40864 L .70394 .40845 L F
.526 .267 .466 r
.70728 .40534 m .7094 .40788 L .7069 .40864 L F
.70728 .40534 m .70994 .40503 L .7094 .40788 L F
.182 0 0 r
.1896 .73557 m .19165 .73516 L .1894 .73575 L F
.757 .608 .693 r
.75767 .38297 m .75871 .38529 L .75627 .38574 L F
.968 .813 .387 r
.75627 .38574 m .75797 .38438 L .75871 .38529 L F
.742 .915 .951 r
.76031 .38258 m .75871 .38529 L .75797 .38438 L F
.398 .463 .81 r
.76031 .38258 m .76176 .38682 L .75871 .38529 L F
.742 .915 .951 r
.76031 .38258 m .75871 .38529 L .75797 .38438 L F
.651 .163 0 r
.49786 .54392 m .49826 .54487 L .49674 .54264 L F
.49786 .54392 m .49946 .54602 L .49826 .54487 L F
0 0 0 r
.5379 .50687 m .54048 .50412 L .53886 .50543 L F
.296 0 .09 r
.42877 .65847 m .42764 .65993 L .42712 .6592 L F
0 0 .43 r
.42712 .6592 m .42875 .66317 L .42764 .65993 L F
.937 .814 .359 r
.76886 .41023 m .76964 .40876 L .76923 .41116 L F
.746 .82 .353 r
.76973 .40816 m .76964 .40876 L .76886 .41023 L F
.908 .947 .816 r
.76708 .42617 m .76789 .42722 L .76559 .43035 L F
.983 .9 .577 r
.64999 .41413 m .65054 .41538 L .65165 .40855 L F
.962 .855 .444 r
.64956 .41664 m .65054 .41538 L .64999 .41413 L F
.64956 .41664 m .65 .41773 L .65054 .41538 L F
.602 .387 .561 r
.53629 .55265 m .53899 .54994 L .53537 .54954 L F
.53629 .55265 m .53899 .55246 L .53899 .54994 L F
.603 .936 .738 r
.16629 .62645 m .16592 .62725 L .1648 .62714 L F
.16629 .62645 m .16781 .62564 L .16592 .62725 L F
.676 .582 .742 r
.48466 .6036 m .48878 .60674 L .48816 .60373 L F
.778 .807 .876 r
.69311 .42729 m .68981 .42715 L .69152 .4257 L F
.776 .762 .841 r
.69571 .42477 m .69311 .42729 L .69152 .4257 L F
.928 .944 .786 r
.76358 .43329 m .76473 .42919 L .76559 .43035 L F
.908 .947 .816 r
.76708 .42617 m .76559 .43035 L .76473 .42919 L F
.615 .415 .588 r
.45474 .58218 m .45225 .58495 L .45282 .58321 L F
.507 .031 .061 r
.41754 .6368 m .41499 .63765 L .41353 .63743 L F
.482 .426 .718 r
.41916 .63282 m .41754 .6368 L .41656 .63298 L F
.41916 .63282 m .41983 .63615 L .41754 .6368 L F
.446 .312 .605 r
.41983 .63615 m .41966 .6387 L .41754 .6368 L F
.664 .266 .282 r
.41754 .6368 m .41966 .6387 L .41499 .63765 L F
.094 0 .054 r
.45675 .58645 m .45583 .58803 L .45861 .58544 L F
.939 .879 .465 r
.76783 .41929 m .76881 .41814 L .76818 .41994 L F
.953 .868 .457 r
.76844 .41702 m .76881 .41814 L .76783 .41929 L F
.764 .699 .79 r
.73719 .41748 m .73839 .4207 L .73472 .42055 L F
.577 .596 .836 r
.74079 .41982 m .73839 .4207 L .73719 .41748 L F
.733 .766 .879 r
.73472 .42055 m .73839 .4207 L .73841 .41862 L F
0 .43 .825 r
.74079 .41982 m .73841 .41862 L .73839 .4207 L F
.469 .423 .723 r
.73839 .4207 m .74134 .42234 L .74079 .41982 L F
.673 .168 .034 r
.54184 .57939 m .54433 .58139 L .54549 .58031 L F
.68 .176 .039 r
.54433 .58139 m .54803 .58213 L .54549 .58031 L F
.101 .241 .722 r
.65944 .4419 m .66148 .444 L .6603 .44059 L F
.226 0 0 r
.21552 .55343 m .21352 .55385 L .21114 .55357 L F
.367 0 0 r
.21738 .55211 m .21352 .55385 L .21552 .55343 L F
.821 .778 .812 r
.42293 .63645 m .41983 .63615 L .42235 .63334 L F
.879 .74 .705 r
.42293 .63645 m .41966 .6387 L .41983 .63615 L F
.42293 .63645 m .42163 .63932 L .41966 .6387 L F
.77 .746 .831 r
.42585 .63374 m .42293 .63645 L .42235 .63334 L F
.877 .785 .756 r
.21482 .66041 m .21694 .66141 L .21929 .65933 L F
.21482 .66041 m .21929 .65933 L .21762 .65983 L F
.591 .137 0 r
.21723 .65662 m .21914 .65924 L .21929 .65933 L F
.288 .777 .708 r
.21762 .65983 m .21914 .65924 L .21929 .65933 L F
.659 .518 .68 r
.21929 .65933 m .22265 .66075 L .22497 .65903 L F
.158 0 0 r
.72298 .39348 m .72563 .39112 L .72405 .39199 L F
.755 .697 .796 r
.72526 .38756 m .72563 .39112 L .72771 .38819 L F
.996 .839 .566 r
.72405 .39199 m .72563 .39112 L .72526 .38756 L F
.201 0 .113 r
.15705 .57129 m .15604 .57286 L .15412 .57361 L F
0 0 0 r
.15861 .57019 m .15604 .57286 L .15705 .57129 L F
.66 .805 .952 r
.20657 .6778 m .20869 .67934 L .21049 .67819 L F
.648 .128 0 r
.45322 .60444 m .44956 .60475 L .45176 .60402 L F
.398 .112 .359 r
.45322 .60444 m .44996 .60519 L .45011 .60471 L F
.402 .187 .469 r
.45181 .60465 m .45417 .60425 L .45427 .60177 L F
.45181 .60465 m .45427 .60177 L .4532 .60411 L F
.572 .362 .558 r
.4506 .60316 m .45181 .60465 L .4532 .60411 L F
.44816 .60226 m .45042 .60374 L .4506 .60316 L F
.45042 .60374 m .45181 .60465 L .4506 .60316 L F
.398 .112 .359 r
.45322 .60444 m .45121 .60657 L .44996 .60519 L F
.45011 .60471 m .44996 .60519 L .44956 .60475 L F
.45322 .60444 m .45349 .60601 L .45121 .60657 L F
.329 0 .06 r
.45731 .60362 m .45349 .60601 L .45322 .60444 L F
.567 .033 0 r
.42623 .58714 m .42528 .58618 L .42474 .58641 L F
.23 0 0 r
.50857 .57779 m .50956 .57736 L .50736 .57715 L F
.498 .782 .996 r
.25353 .53955 m .2531 .54126 L .25132 .5401 L F
.25353 .53955 m .25529 .54074 L .2531 .54126 L F
.146 .202 .663 r
.48816 .60373 m .48878 .60674 L .49057 .60531 L F
.803 .678 .725 r
.48703 .60757 m .49057 .60531 L .48878 .60674 L F
.494 .779 .995 r
.19587 .63243 m .19544 .634 L .1937 .63313 L F
.19587 .63243 m .19759 .63358 L .19544 .634 L F
0 0 .327 r
.6251 .4272 m .6256 .42289 L .62309 .42604 L F
.411 .451 .792 r
.57541 .57602 m .57228 .57416 L .57462 .57354 L F
.286 0 .094 r
.17342 .56165 m .17185 .564 L .16967 .5646 L F
.188 0 .037 r
.17384 .56324 m .17342 .56165 L .17572 .56105 L F
.17384 .56324 m .17185 .564 L .17342 .56165 L F
.43 .624 .934 r
.21955 .66956 m .21969 .6718 L .21753 .67015 L F
.21955 .66956 m .22194 .67185 L .21969 .6718 L F
0 0 .226 r
.22029 .67363 m .21969 .6718 L .22194 .67185 L F
.121 0 0 r
.22354 .55197 m .21963 .55148 L .22135 .55208 L F
.45 .823 .992 r
.1832 .65217 m .18685 .65228 L .18514 .65211 L F
.109 .663 .759 r
.18685 .65228 m .18773 .65208 L .18514 .65211 L F
.18685 .65228 m .18894 .65208 L .18773 .65208 L F
.932 .866 .752 r
.75784 .42329 m .76075 .42147 L .75943 .42015 L F
.78 .308 .118 r
.73708 .38764 m .73631 .3863 L .73284 .38466 L F
.462 .22 .461 r
.25087 .58834 m .25275 .58814 L .25332 .58577 L F
.227 .104 .495 r
.25332 .58577 m .25498 .58493 L .25523 .58188 L F
.205 .011 .382 r
.25275 .58814 m .25498 .58493 L .25332 .58577 L F
.928 .944 .786 r
.76358 .43329 m .76281 .43216 L .76473 .42919 L F
.998 .823 .54 r
.76358 .43329 m .76215 .43452 L .76281 .43216 L F
.76358 .43329 m .76319 .43546 L .76215 .43452 L F
.984 .845 .625 r
.76281 .43216 m .76215 .43452 L .761 .43355 L F
.08 .561 .9 r
.76215 .43452 m .76425 .43431 L .7611 .43357 L F
.76215 .43452 m .7611 .43357 L .761 .43355 L F
.998 .823 .54 r
.76319 .43546 m .76314 .43574 L .76215 .43452 L F
.329 0 .06 r
.45404 .60566 m .45393 .60593 L .45349 .60601 L F
.588 .408 .605 r
.45559 .60564 m .45348 .60804 L .45349 .60601 L F
.489 .258 .49 r
.45348 .60804 m .45121 .60657 L .45349 .60601 L F
.45348 .60804 m .45107 .60875 L .45121 .60657 L F
.445 .168 .398 r
.45303 .60836 m .45202 .60847 L .4531 .60815 L F
.45303 .60844 m .45202 .60847 L .45341 .60831 L F
.451 .227 .482 r
.45121 .60657 m .45107 .60875 L .44874 .60929 L F
.842 .591 .559 r
.44897 .60523 m .44871 .60777 L .45297 .6085 L F
.45299 .60846 m .45297 .6085 L .45306 .60852 L F
.44897 .60523 m .45297 .6085 L .45299 .60846 L F
.445 .168 .398 r
.45341 .60831 m .45307 .60835 L .45348 .60804 L F
.45307 .60835 m .45307 .60833 L .45348 .60804 L F
.45303 .60836 m .4531 .60815 L .45348 .60804 L F
.45338 .60843 m .45303 .60844 L .45341 .60831 L F
.769 .801 .314 r
.45308 .60844 m .45417 .60425 L .45303 .60844 L F
.45306 .60852 m .45321 .6076 L .45343 .60709 L F
.445 .168 .398 r
.45307 .60835 m .45303 .60836 L .45307 .60833 L F
.769 .801 .314 r
.45228 .60609 m .45417 .60425 L .45181 .60465 L F
.45303 .60844 m .45417 .60425 L .45228 .60609 L F
.45343 .60709 m .45343 .60635 L .45417 .60425 L F
0 0 .122 r
.45417 .60425 m .45343 .60635 L .45582 .60266 L F
.45417 .60425 m .45582 .60266 L .45582 .60266 L F
.769 .801 .314 r
.45321 .6076 m .45343 .60635 L .45343 .60709 L F
0 0 0 r
.45306 .60848 m .45335 .60893 L .45343 .60635 L F
.45306 .60852 m .45306 .60853 L .45306 .60848 L F
.842 .591 .559 r
.45299 .60846 m .45306 .60852 L .45303 .60844 L F
.769 .801 .314 r
.45306 .60852 m .45308 .60844 L .45303 .60844 L F
.445 .168 .398 r
.45274 .61099 m .45296 .60936 L .45338 .60843 L F
0 0 0 r
.45306 .60852 m .45274 .61099 L .45306 .60853 L F
.445 .168 .398 r
.45254 .61027 m .45202 .60847 L .45297 .60845 L F
.45296 .60855 m .45297 .60845 L .45299 .60845 L F
.45254 .61027 m .45297 .60845 L .45296 .60855 L F
.805 .48 .439 r
.45296 .60855 m .45274 .61099 L .45306 .60852 L F
.445 .168 .398 r
.45274 .61099 m .45254 .61027 L .45296 .60936 L F
.45274 .61099 m .45107 .60875 L .45202 .60847 L F
.522 .187 .342 r
.44874 .60929 m .4479 .61182 L .44528 .612 L F
.517 .231 .42 r
.45107 .60875 m .4479 .61182 L .44874 .60929 L F
.45107 .60875 m .45053 .6115 L .4479 .61182 L F
.445 .168 .398 r
.45245 .61061 m .45053 .6115 L .45107 .60875 L F
.45274 .61099 m .45234 .61109 L .45245 .61061 L F
.45234 .61109 m .45053 .6115 L .45245 .61061 L F
.805 .48 .439 r
.4484 .61 m .45295 .60855 L .44871 .60777 L F
.45295 .60855 m .45296 .60855 L .45295 .60855 L F
.45295 .60855 m .45295 .60855 L .44871 .60777 L F
.4484 .61 m .45274 .61099 L .45296 .60855 L F
.45296 .60855 m .45306 .60852 L .45297 .6085 L F
.445 .168 .398 r
.45254 .61027 m .45299 .60845 L .45338 .60843 L F
.541 .254 .429 r
.45553 .60983 m .45274 .61099 L .45348 .60804 L F
.586 .256 .377 r
.45194 .61003 m .45357 .60869 L .45335 .60893 L F
.541 .254 .429 r
.45553 .60983 m .45348 .60804 L .45595 .60809 L F
.329 0 .06 r
.45731 .60362 m .45559 .60564 L .45393 .60593 L F
.45731 .60362 m .45393 .60593 L .45404 .60566 L F
.588 .408 .605 r
.45559 .60564 m .45595 .60809 L .45348 .60804 L F
.084 0 .377 r
.45427 .60177 m .45417 .60425 L .45582 .60266 L F
.852 .86 .847 r
.45582 .60266 m .45343 .60635 L .45215 .60467 L F
.022 .068 .571 r
.45335 .60893 m .45439 .60801 L .454 .60516 L F
.586 .256 .377 r
.45357 .60869 m .45439 .60801 L .45335 .60893 L F
0 0 0 r
.45306 .60853 m .45296 .60936 L .45335 .60893 L F
.45296 .60936 m .45274 .61099 L .45335 .60893 L F
.805 .48 .439 r
.45296 .60855 m .45297 .6085 L .44871 .60777 L F
0 0 0 r
.45306 .60853 m .45335 .60893 L .45306 .60848 L F
.842 .591 .559 r
.44897 .60523 m .45299 .60846 L .45181 .60465 L F
.45299 .60846 m .45303 .60844 L .45181 .60465 L F
.099 0 0 r
.45978 .60325 m .45559 .60564 L .45731 .60362 L F
.28 0 .113 r
.53476 .50964 m .5379 .50687 L .53605 .50813 L F
.539 .377 .609 r
.27293 .60333 m .27291 .60635 L .27061 .60678 L F
.455 .28 .553 r
.27264 .60864 m .27061 .60678 L .27291 .60635 L F
.27264 .60864 m .27053 .60951 L .27061 .60678 L F
.614 .598 .811 r
.57339 .49549 m .5701 .49288 L .57293 .49338 L F
.474 0 .022 r
.57339 .49549 m .57257 .49711 L .57003 .49617 L F
.243 .103 .482 r
.57535 .49296 m .57339 .49549 L .57293 .49338 L F
.57535 .49296 m .57534 .4949 L .57339 .49549 L F
.497 .011 .032 r
.57855 .49696 m .57339 .49549 L .57534 .4949 L F
.57855 .49696 m .57257 .49711 L .57339 .49549 L F
.262 0 0 r
.20473 .53995 m .20716 .5398 L .2085 .53894 L F
.428 .155 .396 r
.55671 .5742 m .55861 .57583 L .5592 .57343 L F
.631 .342 .46 r
.48916 .60664 m .48863 .60944 L .48571 .60901 L F
.278 .033 .351 r
.49055 .60842 m .48916 .60664 L .49191 .6068 L F
.49055 .60842 m .48863 .60944 L .48916 .60664 L F
.663 .194 .129 r
.41224 .61279 m .40799 .61468 L .41235 .61542 L F
.41224 .61279 m .40845 .61235 L .40799 .61468 L F
.41224 .61279 m .41126 .61465 L .40845 .61235 L F
.552 .383 .605 r
.41224 .61279 m .41324 .61363 L .4148 .61264 L F
.41324 .61363 m .41459 .61478 L .41473 .61329 L F
.41324 .61363 m .41473 .61329 L .4148 .61264 L F
.41324 .61363 m .41235 .61542 L .41459 .61478 L F
.41224 .61279 m .41229 .61386 L .41324 .61363 L F
.41229 .61386 m .41235 .61542 L .41324 .61363 L F
.765 .547 .602 r
.41459 .61478 m .41835 .61272 L .4148 .61264 L F
.214 .736 .748 r
.41712 .61277 m .41238 .61377 L .4148 .61264 L F
.41492 .61323 m .41572 .61297 L .41238 .61377 L F
.41584 .61304 m .41581 .61302 L .41492 .61323 L F
.41581 .61302 m .41572 .61297 L .41492 .61323 L F
.41712 .61277 m .41685 .61281 L .41584 .61304 L F
.41685 .61281 m .41572 .61297 L .41584 .61304 L F
.407 0 .014 r
.41238 .61377 m .41224 .61279 L .4148 .61264 L F
.41238 .61377 m .41126 .61465 L .41224 .61279 L F
.733 .397 .412 r
.72694 .38451 m .73047 .38475 L .72891 .38377 L F
.882 .61 .521 r
.41796 .64811 m .41907 .64507 L .41818 .64525 L F
.41796 .64811 m .41951 .65032 L .41907 .64507 L F
.599 .218 .293 r
.68718 .40521 m .68435 .40368 L .68426 .40528 L F
.435 .222 .489 r
.61013 .43538 m .6127 .43245 L .61022 .43328 L F
0 .151 .686 r
.49695 .5315 m .49864 .53331 L .49933 .53093 L F
.986 .846 .617 r
.49864 .53331 m .49843 .53136 L .49933 .53093 L F
0 0 0 r
.49695 .5315 m .49933 .53093 L .50034 .53045 L F
.986 .846 .617 r
.49843 .53136 m .49827 .52989 L .49933 .53093 L F
0 0 0 r
.50034 .53045 m .49933 .53093 L .50069 .53034 L F
.958 .933 .723 r
.50069 .53034 m .49933 .53093 L .5006 .52852 L F
.104 0 0 r
.23914 .54 m .24151 .53977 L .24306 .5392 L F
.199 0 0 r
.24306 .5392 m .24151 .53977 L .24528 .53937 L F
.981 .897 .656 r
.65758 .40991 m .65687 .41496 L .65583 .41394 L F
.65758 .40991 m .65583 .41394 L .6557 .41119 L F
.939 .689 .534 r
.6557 .41119 m .65583 .41394 L .65402 .41257 L F
0 0 .311 r
.65583 .41394 m .65743 .41423 L .65486 .41298 L F
.65583 .41394 m .65486 .41298 L .65402 .41257 L F
.981 .897 .656 r
.65687 .41496 m .6568 .41549 L .65583 .41394 L F
.976 .914 .594 r
.6568 .41549 m .65535 .41655 L .65583 .41394 L F
.6568 .41549 m .65589 .41752 L .65535 .41655 L F
.52 .441 .706 r
.28475 .56154 m .28323 .56439 L .28266 .56224 L F
.28475 .56154 m .28552 .56386 L .28323 .56439 L F
.407 .319 .644 r
.28531 .56641 m .28323 .56439 L .28552 .56386 L F
.28531 .56641 m .2836 .57053 L .28323 .56439 L F
.936 .746 .621 r
.66278 .42043 m .66195 .4177 L .66276 .42019 L F
.869 .603 .534 r
.66276 .42019 m .66317 .42335 L .66278 .42043 L F
.768 .826 .898 r
.71242 .41736 m .70897 .41735 L .7112 .41597 L F
.73 .818 .92 r
.71524 .41564 m .71242 .41736 L .7112 .41597 L F
.387 .837 .926 r
.21066 .53929 m .21305 .53872 L .21496 .53903 L F
.117 .663 .825 r
.21305 .53872 m .21689 .53886 L .21496 .53903 L F
.517 .375 .627 r
.27039 .61159 m .26828 .61007 L .27053 .60951 L F
.27039 .61159 m .26832 .61224 L .26828 .61007 L F
.533 .713 .955 r
.75388 .37748 m .75525 .37513 L .75255 .37552 L F
.75388 .37748 m .75799 .37705 L .75525 .37513 L F
.327 .049 .33 r
.25502 .62965 m .25358 .62861 L .25575 .6281 L F
.25502 .62965 m .25303 .63045 L .25358 .62861 L F
.89 .904 .831 r
.67912 .44376 m .68038 .44436 L .67939 .44315 L F
.463 .79 .999 r
.42875 .66317 m .43251 .6639 L .43128 .66275 L F
.444 .853 .964 r
.43251 .6639 m .43502 .66309 L .43128 .66275 L F
.43251 .6639 m .432 .66347 L .43502 .66309 L F
.43502 .66309 m .432 .66347 L .43251 .6639 L F
.748 .987 .899 r
.79136 .43583 m .78937 .43738 L .78745 .43756 L F
.003 0 0 r
.72408 .38453 m .72086 .38702 L .72341 .38678 L F
.571 .371 .571 r
.72488 .38728 m .72408 .38453 L .72341 .38678 L F
.72488 .38728 m .72694 .38451 L .72408 .38453 L F
.55 .389 .616 r
.62023 .42315 m .62357 .42367 L .62331 .41882 L F
.719 .564 .678 r
.61963 .4254 m .62357 .42367 L .62023 .42315 L F
.372 0 0 r
.27675 .54853 m .27854 .54924 L .28032 .54957 L F
.214 0 .137 r
.15412 .57361 m .15604 .57286 L .15404 .57377 L F
.801 .709 .764 r
.61355 .45317 m .61753 .45146 L .61588 .45006 L F
.61355 .45317 m .61517 .45436 L .61753 .45146 L F
.793 .859 .899 r
.72256 .4224 m .72765 .42073 L .72666 .4203 L F
.98 .698 .32 r
.66072 .41634 m .66276 .42019 L .66195 .4177 L F
.66072 .41634 m .66027 .41807 L .66276 .42019 L F
.917 .689 .578 r
.65881 .42177 m .66276 .42019 L .66027 .41807 L F
.65881 .42177 m .66049 .42285 L .66276 .42019 L F
.869 .603 .534 r
.66276 .42019 m .66049 .42285 L .66317 .42335 L F
0 0 .251 r
.75379 .39338 m .75269 .39668 L .75415 .39614 L F
.399 .445 .792 r
.75269 .39668 m .75564 .39993 L .75395 .39858 L F
.75394 .39857 m .75395 .39858 L .75395 .39857 L F
.75269 .39668 m .75395 .39858 L .75394 .39857 L F
.872 .656 .606 r
.75415 .39614 m .75218 .39696 L .75158 .39524 L F
.75218 .39696 m .751 .39746 L .75133 .39619 L F
.75218 .39696 m .75133 .39619 L .75158 .39524 L F
.399 .445 .792 r
.75269 .39668 m .75395 .39857 L .75415 .39614 L F
0 .298 .732 r
.50857 .55245 m .51004 .55326 L .50845 .55204 L F
.448 .26 .531 r
.40141 .59687 m .40371 .59383 L .40188 .59469 L F
.727 .716 .841 r
.74183 .39635 m .74255 .39897 L .74343 .39725 L F
0 0 0 r
.20883 .63419 m .21031 .6339 L .20769 .63427 L F
.771 .747 .831 r
.46106 .61504 m .46535 .61814 L .45875 .61774 L F
.083 0 0 r
.46535 .61814 m .45882 .6206 L .45875 .61774 L F
.46535 .61814 m .46118 .62015 L .45882 .6206 L F
0 .186 .711 r
.46309 .61465 m .46535 .61814 L .46106 .61504 L F
.469 .343 .626 r
.46585 .61841 m .46616 .62117 L .46393 .62162 L F
.46612 .61798 m .46613 .61865 L .46585 .61841 L F
.46613 .61865 m .46616 .62117 L .46585 .61841 L F
.46586 .61841 m .46616 .62117 L .46393 .62162 L F
.46612 .61798 m .46612 .61846 L .46586 .61841 L F
.46612 .61846 m .46616 .62117 L .46586 .61841 L F
0 0 0 r
.46335 .61958 m .46517 .61827 L .46595 .61846 L F
.46517 .61827 m .46535 .61814 L .46584 .6184 L F
.46517 .61827 m .46584 .6184 L .46595 .61846 L F
0 .186 .711 r
.46309 .61465 m .46595 .61846 L .46584 .6184 L F
.46511 .61777 m .46584 .6184 L .46535 .61814 L F
.46309 .61465 m .46584 .6184 L .46511 .61777 L F
.543 0 0 r
.46335 .61958 m .46591 .621 L .46263 .62027 L F
0 0 0 r
.46335 .61958 m .46118 .62015 L .46438 .61861 L F
.584 .9 .635 r
.46095 .6199 m .46118 .62015 L .46335 .61958 L F
.543 0 0 r
.46335 .61958 m .46263 .62027 L .46095 .6199 L F
0 0 0 r
.46335 .61958 m .46438 .61861 L .46535 .61814 L F
.791 .507 .506 r
.52783 .54683 m .53068 .54901 L .53054 .54719 L F
.711 .565 .689 r
.4277 .58829 m .43243 .58804 L .42803 .58602 L F
.693 .959 .947 r
.53872 .52017 m .53788 .51954 L .53454 .52153 L F
.921 .973 .768 r
.53872 .52017 m .53861 .51795 L .53788 .51954 L F
.685 .631 .789 r
.4781 .60091 m .47736 .60259 L .48078 .59973 L F
.822 .69 .719 r
.58802 .49872 m .58566 .49846 L .58645 .49577 L F
.851 .597 .554 r
.58802 .49872 m .58581 .50087 L .58566 .49846 L F
.58802 .49872 m .58824 .50109 L .58581 .50087 L F
0 .419 .853 r
.51644 .55868 m .51589 .55763 L .51204 .55585 L F
.966 .892 .516 r
.51567 .55777 m .51589 .55763 L .51644 .55868 L F
.673 .26 0 r
.51644 .55868 m .51683 .5597 L .51567 .55777 L F
.51644 .55868 m .51767 .56098 L .51683 .5597 L F
.182 .715 .747 r
.19195 .54204 m .19438 .54156 L .19645 .5413 L F
.175 0 0 r
.19438 .54156 m .1983 .54125 L .19645 .5413 L F
.265 .016 .337 r
.25087 .58834 m .25204 .58998 L .25275 .58814 L F
.25087 .58834 m .25055 .59066 L .25204 .58998 L F
.572 .385 .589 r
.4443 .64572 m .44689 .64791 L .44712 .64537 L F
.4443 .64572 m .44446 .64829 L .44689 .64791 L F
.44689 .64791 m .4443 .64572 L .44712 .64537 L F
.44689 .64791 m .44446 .64829 L .4443 .64572 L F
.481 .257 .497 r
.2368 .60971 m .23904 .60922 L .23936 .60682 L F
.439 .222 .485 r
.23936 .60682 m .23904 .60922 L .24148 .60627 L F
.934 .826 .714 r
.60546 .48874 m .6064 .49183 L .6068 .48996 L F
.894 .791 .74 r
.6068 .48996 m .606 .48644 L .60546 .48874 L F
.616 .33 .461 r
.42404 .59917 m .42681 .59746 L .42478 .59834 L F
0 0 0 r
.57865 .53462 m .5766 .53782 L .5781 .53638 L F
0 0 .06 r
.5781 .53638 m .57669 .53866 L .57648 .53945 L F
.57669 .53866 m .57587 .53999 L .57648 .53945 L F
0 0 .145 r
.57648 .53945 m .57587 .53999 L .5759 .54194 L F
.756 .737 .215 r
.5764 .53978 m .57648 .53945 L .57638 .53989 L F
.5767 .53774 m .57648 .53945 L .5764 .53978 L F
.57602 .54131 m .57638 .53989 L .5759 .54194 L F
.5767 .53774 m .57638 .53989 L .57602 .54131 L F
0 0 .06 r
.57669 .53866 m .5766 .53782 L .57587 .53999 L F
.5781 .53638 m .577 .53743 L .57669 .53866 L F
.577 .53743 m .5766 .53782 L .57669 .53866 L F
.022 .332 .815 r
.51004 .55326 m .51204 .55585 L .5122 .55451 L F
.332 0 0 r
.51204 .55585 m .51328 .55642 L .51319 .5565 L F
.51328 .55642 m .51589 .55763 L .51319 .5565 L F
.566 .016 0 r
.51319 .5565 m .5141 .55767 L .51311 .55656 L F
.332 0 0 r
.51204 .55585 m .51319 .5565 L .5122 .55451 L F
.566 .016 0 r
.51319 .5565 m .51311 .55656 L .51207 .55541 L F
.564 .82 .993 r
.47766 .55874 m .4754 .55947 L .47396 .55826 L F
.227 .112 .507 r
.57399 .58756 m .57186 .59135 L .57167 .58891 L F
0 0 0 r
.15599 .55533 m .15722 .55487 L .159 .55344 L F
.159 .55344 m .15902 .55409 L .16113 .55288 L F
.159 .55344 m .15722 .55487 L .15902 .55409 L F
.977 .76 .543 r
.43964 .57263 m .4412 .57406 L .44098 .5726 L F
.43964 .57263 m .4412 .57406 L .44098 .5726 L F
.144 .543 .923 r
.51658 .52694 m .51581 .5277 L .51401 .52743 L F
.51658 .52694 m .51581 .5277 L .51401 .52743 L F
.51658 .52694 m .51773 .52819 L .51581 .5277 L F
.632 .535 .726 r
.51825 .52929 m .51581 .5277 L .51773 .52819 L F
.211 0 0 r
.19574 .70835 m .1973 .70846 L .19922 .70658 L F
.2 0 0 r
.19922 .70658 m .20016 .70721 L .20104 .70498 L F
.19922 .70658 m .1973 .70846 L .20016 .70721 L F
.841 .383 .111 r
.54084 .59533 m .54214 .59755 L .5431 .59749 L F
.556 .87 .995 r
.54214 .59755 m .54573 .59749 L .5431 .59749 L F
.87 .773 .753 r
.20953 .68709 m .21197 .68764 L .21137 .68434 L F
.675 .138 0 r
.20953 .68709 m .21173 .68874 L .21197 .68764 L F
.234 .324 .752 r
.21137 .68434 m .21197 .68764 L .21369 .68639 L F
.482 .382 .665 r
.2149 .68872 m .2132 .69028 L .21197 .68764 L F
.873 .463 .018 r
.21173 .68874 m .2132 .69028 L .21197 .68764 L F
0 0 0 r
.21197 .68764 m .21173 .68874 L .21369 .68639 L F
.384 .238 .557 r
.2368 .60971 m .23852 .6114 L .23904 .60922 L F
.2368 .60971 m .23687 .61247 L .23852 .6114 L F
.765 .547 .602 r
.41459 .61478 m .41826 .61541 L .41835 .61272 L F
.588 .562 .792 r
.4172 .60919 m .41835 .61272 L .42076 .61223 L F
.566 .393 .606 r
.41826 .61541 m .42076 .61223 L .41835 .61272 L F
.743 .485 0 r
.53722 .57516 m .53806 .57901 L .53771 .57713 L F
.642 .212 0 r
.5631 .58054 m .56224 .57933 L .56027 .57615 L F
.56049 .57647 m .56027 .57615 L .56005 .57579 L F
.5631 .58054 m .56027 .57615 L .56049 .57647 L F
.974 .732 .508 r
.5592 .57343 m .559 .57425 L .56039 .57602 L F
.714 .182 0 r
.56005 .57579 m .55861 .57583 L .56039 .57602 L F
.974 .732 .508 r
.559 .57425 m .55861 .57583 L .56017 .57599 L F
.559 .57425 m .56017 .57599 L .56039 .57602 L F
.793 .413 .337 r
.56005 .57579 m .56224 .57933 L .55889 .57821 L F
.013 0 .216 r
.58501 .55149 m .58298 .55271 L .58499 .54944 L F
.031 0 .253 r
.58259 .5551 m .58298 .55271 L .58501 .55149 L F
.093 0 0 r
.23407 .64477 m .23008 .64721 L .23203 .64552 L F
.647 .467 .627 r
.5701 .49288 m .57003 .49617 L .56814 .49493 L F
.391 .247 .563 r
.23352 .61571 m .23472 .61739 L .23441 .6152 L F
.23352 .61571 m .23356 .61832 L .23472 .61739 L F
.441 0 0 r
.22748 .55223 m .22605 .55246 L .22354 .55197 L F
.063 0 0 r
.22958 .55216 m .22605 .55246 L .22748 .55223 L F
0 0 .524 r
.54058 .59357 m .54214 .59755 L .54084 .59533 L F
.56 .163 .247 r
.68294 .41264 m .68676 .412 L .68553 .41376 L F
.701 .328 .337 r
.68676 .412 m .68929 .41409 L .68553 .41376 L F
.687 .342 .386 r
.68676 .412 m .68901 .41245 L .68929 .41409 L F
.296 0 .09 r
.42877 .65847 m .42457 .65918 L .42604 .65798 L F
.655 .287 .334 r
.42764 .65993 m .43126 .66 L .42877 .65847 L F
.146 .202 .663 r
.48816 .60373 m .49057 .60531 L .49065 .60377 L F
.966 .652 .261 r
.77535 .39754 m .77647 .39859 L .77613 .39625 L F
.879 .928 .85 r
.77585 .39727 m .77647 .39859 L .77535 .39754 L F
.892 .61 .099 r
.77613 .39625 m .77706 .39982 L .77647 .39859 L F
.77613 .39625 m .77729 .4007 L .77647 .39859 L F
.497 .314 .562 r
.77613 .39625 m .77647 .39859 L .77878 .39572 L F
.879 .928 .85 r
.77878 .39572 m .77647 .39859 L .77585 .39727 L F
.892 .61 .099 r
.77706 .39982 m .77729 .4007 L .77647 .39859 L F
.28 .016 .322 r
.58532 .46275 m .58264 .46584 L .58476 .46454 L F
.605 .446 .64 r
.58309 .46798 m .58476 .46454 L .58264 .46584 L F
.934 .826 .714 r
.60546 .48874 m .60402 .49214 L .6064 .49183 L F
.905 .807 .741 r
.60314 .49374 m .6064 .49183 L .60402 .49214 L F
.60314 .49374 m .60431 .49533 L .6064 .49183 L F
.967 .725 .517 r
.49065 .60377 m .49191 .6068 L .49354 .60323 L F
.49065 .60377 m .49091 .60736 L .49191 .6068 L F
.834 .435 .289 r
.49091 .60736 m .49055 .60842 L .49191 .6068 L F
.584 .334 .503 r
.58476 .46454 m .58816 .46241 L .58532 .46275 L F
.918 .715 .612 r
.52986 .53174 m .53159 .52897 L .52965 .52791 L F
.52986 .53174 m .53131 .53153 L .53159 .52897 L F
.568 .366 .568 r
.18924 .73541 m .19165 .73516 L .19172 .73248 L F
0 0 0 r
.57198 .5935 m .56993 .59686 L .57068 .5951 L F
.658 .409 .531 r
.65758 .40991 m .6557 .41119 L .65692 .40782 L F
.45 0 0 r
.65962 .40551 m .65665 .40632 L .65692 .40782 L F
.139 .277 .744 r
.6587 .40675 m .65692 .40782 L .65665 .40632 L F
.649 .099 0 r
.65692 .40782 m .66011 .41039 L .66057 .41026 L F
.139 .277 .744 r
.6587 .40675 m .66011 .41039 L .65692 .40782 L F
.431 .098 .299 r
.44996 .58584 m .4489 .58853 L .44628 .58813 L F
.406 .103 .335 r
.45225 .58495 m .4489 .58853 L .44996 .58584 L F
.885 .972 .835 r
.44098 .5726 m .43964 .57263 L .44198 .56977 L F
.22 0 0 r
.44098 .5726 m .44167 .57293 L .43964 .57263 L F
.411 .363 .694 r
.44452 .56938 m .44098 .5726 L .44198 .56977 L F
.44452 .56938 m .445 .57272 L .44098 .5726 L F
.526 .142 .256 r
.445 .57272 m .44167 .57293 L .44098 .5726 L F
.044 .576 .859 r
.21093 .65221 m .2123 .65254 L .20981 .65163 L F
.252 .695 .959 r
.20501 .65099 m .21093 .65221 L .20793 .65065 L F
.936 .751 .627 r
.20981 .65163 m .2123 .65254 L .21134 .65415 L F
.441 0 0 r
.77462 .40424 m .77145 .40456 L .77252 .40609 L F
.511 .697 .953 r
.77462 .40424 m .77252 .40609 L .77145 .40456 L F
.77462 .40424 m .77252 .40609 L .77145 .40456 L F
.861 .922 .869 r
.4563 .57474 m .45324 .57694 L .45715 .57657 L F
.109 .223 .702 r
.4563 .57474 m .45854 .57581 L .45885 .57306 L F
.4563 .57474 m .45715 .57657 L .45854 .57581 L F
.624 .874 .989 r
.47158 .55895 m .46941 .55992 L .46788 .55907 L F
.589 .918 .972 r
.42938 .62679 m .42806 .62768 L .4285 .62786 L F
.996 .816 .548 r
.4285 .62786 m .42842 .63062 L .42806 .62768 L F
.589 .918 .972 r
.42938 .62679 m .42806 .62768 L .4285 .62786 L F
0 0 0 r
.15604 .57286 m .15307 .57587 L .15404 .57377 L F
.4 0 .124 r
.1778 .54612 m .18012 .54589 L .18181 .54371 L F
.436 .018 .147 r
.18181 .54371 m .1833 .54463 L .18414 .5434 L F
.18181 .54371 m .18012 .54589 L .1833 .54463 L F
.495 .196 .389 r
.18181 .54371 m .18414 .5434 L .18459 .54281 L F
.136 0 0 r
.57185 .47451 m .57431 .47387 L .57497 .47236 L F
.007 0 0 r
.57497 .47236 m .57608 .47289 L .57713 .4713 L F
.57497 .47236 m .57431 .47387 L .57608 .47289 L F
.773 .785 .863 r
.70268 .41942 m .70402 .42105 L .7006 .42053 L F
.759 .782 .872 r
.70682 .41867 m .70402 .42105 L .70268 .41942 L F
.186 .577 .939 r
.26147 .54211 m .26326 .54241 L .26297 .54347 L F
.204 .597 .946 r
.26326 .54241 m .26488 .54374 L .26297 .54347 L F
.355 .152 .46 r
.79111 .4058 m .79105 .40805 L .78886 .40887 L F
.771 .513 .545 r
.77793 .41961 m .78121 .41805 L .77965 .41691 L F
.77793 .41961 m .78116 .42041 L .78121 .41805 L F
.838 .845 .851 r
.77965 .41691 m .78121 .41805 L .78314 .41494 L F
.645 .57 .756 r
.78121 .41805 m .78378 .41798 L .78314 .41494 L F
.081 0 0 r
.18811 .5584 m .18681 .55876 L .18446 .55897 L F
.195 0 0 r
.1902 .55797 m .18681 .55876 L .18811 .5584 L F
.771 .688 .772 r
.1955 .71071 m .1973 .70846 L .19574 .70835 L F
.341 .676 .977 r
.78046 .42794 m .78401 .42925 L .78285 .42678 L F
.487 .497 .793 r
.78401 .42925 m .78533 .4257 L .78285 .42678 L F
.78401 .42925 m .7864 .42944 L .78533 .4257 L F
.593 .599 .827 r
.18704 .6309 m .18571 .63166 L .18375 .62811 L F
.669 .837 .418 r
.4286 .59136 m .42754 .59304 L .42681 .59456 L F
.67 .693 .862 r
.4286 .59136 m .42681 .59456 L .42873 .59373 L F
.566 .386 .596 r
.42681 .59456 m .42906 .59708 L .42873 .59373 L F
.42681 .59456 m .42681 .59746 L .42906 .59708 L F
.516 .317 .548 r
.59837 .45112 m .60036 .45253 L .60061 .45036 L F
.59837 .45112 m .59831 .45347 L .60036 .45253 L F
.675 .196 .106 r
.49907 .53194 m .49864 .53331 L .49964 .53065 L F
0 .151 .686 r
.49695 .5315 m .49829 .53444 L .49864 .53331 L F
.487 .895 .778 r
.4969 .5358 m .49751 .53245 L .49864 .53331 L F
.986 .846 .617 r
.49864 .53331 m .49751 .53245 L .49827 .52989 L F
.675 .196 .106 r
.49781 .53484 m .49864 .53331 L .49907 .53194 L F
0 .151 .686 r
.49829 .53444 m .49854 .53499 L .49864 .53331 L F
.871 .993 .808 r
.49864 .53331 m .49854 .53499 L .4969 .5358 L F
.595 .603 .829 r
.1894 .73575 m .19165 .73516 L .18924 .73541 L F
0 0 .37 r
.58014 .53072 m .57865 .53462 L .5789 .53414 L F
0 0 0 r
.5789 .53414 m .57865 .53462 L .5781 .53638 L F
.32 .372 .759 r
.39976 .63066 m .40072 .63387 L .40237 .63252 L F
.457 .431 .741 r
.40123 .6367 m .40237 .63252 L .40072 .63387 L F
.387 0 .177 r
.70498 .40094 m .70252 .40011 L .70186 .40226 L F
.39 0 0 r
.70498 .40094 m .70539 .39998 L .70252 .40011 L F
.625 .763 .946 r
.24567 .55245 m .2498 .55308 L .24795 .55164 L F
.769 .568 .627 r
.24546 .555 m .2498 .55308 L .24567 .55245 L F
.24546 .555 m .24936 .55545 L .2498 .55308 L F
.696 .778 .915 r
.24795 .55164 m .2498 .55308 L .25177 .55215 L F
.546 .42 .66 r
.2749 .60266 m .27291 .60635 L .27293 .60333 L F
.412 .177 .444 r
.39139 .60368 m .39352 .60307 L .39382 .60078 L F
.517 .251 .45 r
.39352 .60307 m .39622 .60049 L .39382 .60078 L F
.645 .191 .16 r
.57869 .4903 m .58087 .49189 L .57907 .49127 L F
.564 .278 .44 r
.58068 .48986 m .58087 .49189 L .57869 .4903 L F
0 0 .471 r
.5631 .58054 m .56429 .58204 L .56224 .57933 L F
.267 .392 .805 r
.63955 .4232 m .641 .42158 L .63757 .41983 L F
.63955 .4232 m .64093 .42354 L .641 .42158 L F
.584 .869 .551 r
.51764 .5998 m .51831 .5992 L .51717 .59736 L F
.556 .38 .597 r
.59316 .45928 m .59561 .45616 L .59355 .45714 L F
.287 0 .152 r
.5652 .60043 m .56843 .59826 L .56733 .59933 L F
0 0 0 r
.56993 .59686 m .56733 .59933 L .56843 .59826 L F
.239 .103 .485 r
.28544 .58191 m .28414 .58546 L .2843 .5828 L F
.044 .576 .859 r
.21093 .65221 m .20981 .65163 L .20793 .65065 L F
.519 .866 .991 r
.19949 .65302 m .19961 .65171 L .19758 .65224 L F
.19949 .65302 m .20195 .65233 L .19961 .65171 L F
.183 0 .082 r
.24846 .63401 m .24736 .63579 L .2454 .63644 L F
.417 .142 .385 r
.25011 .63293 m .24736 .63579 L .24846 .63401 L F
.98 .908 .659 r
.76139 .41461 m .76227 .41247 L .76155 .41116 L F
.548 .745 .968 r
.20188 .63265 m .20168 .63489 L .19973 .63297 L F
.20188 .63265 m .20373 .6344 L .20168 .63489 L F
.514 .378 .634 r
.56991 .54981 m .57245 .54915 L .57199 .54649 L F
.461 .253 .509 r
.56987 .55213 m .57245 .54915 L .56991 .54981 L F
.267 .4 .812 r
.52078 .56774 m .52369 .56943 L .52208 .56604 L F
.47 .545 .851 r
.20104 .70498 m .20151 .70165 L .20507 .7025 L F
.504 .294 .528 r
.38888 .6066 m .3912 .60616 L .39139 .60368 L F
.301 .135 .482 r
.38942 .60924 m .3912 .60616 L .38888 .6066 L F
.479 .615 .907 r
.21168 .6964 m .20827 .69436 L .20954 .69426 L F
.514 .316 .55 r
.21168 .6964 m .21151 .69899 L .2094 .69935 L F
.414 .64 .949 r
.2129 .69513 m .21168 .6964 L .20954 .69426 L F
.361 .191 .511 r
.21338 .69902 m .21168 .6964 L .2129 .69513 L F
.21338 .69902 m .21151 .69899 L .21168 .6964 L F
.587 .394 .587 r
.44012 .61761 m .43679 .615 L .4403 .61529 L F
.44012 .61761 m .43769 .618 L .43679 .615 L F
.439 .24 .512 r
.39139 .60368 m .3912 .60616 L .39352 .60307 L F
.463 .719 .98 r
.1772 .65154 m .17929 .65138 L .17782 .65 L F
.713 .97 .932 r
.1759 .65127 m .1772 .65154 L .17782 .65 L F
.463 .719 .98 r
.1772 .65154 m .17929 .65138 L .17782 .65 L F
0 .356 .695 r
.49787 .56555 m .50119 .56688 L .49895 .56703 L F
.409 0 0 r
.4949 .54137 m .49503 .5415 L .49334 .53984 L F
.4949 .54137 m .49674 .54264 L .49503 .5415 L F
.489 0 0 r
.28497 .57695 m .28911 .57977 L .28661 .57969 L F
0 0 0 r
.28911 .57977 m .28544 .58191 L .28661 .57969 L F
.20561 .70177 m .2094 .69935 L .20853 .70044 L F
.305 0 .009 r
.2094 .69935 m .21024 .70081 L .20853 .70044 L F
.2094 .69935 m .21151 .69899 L .21024 .70081 L F
.64 .259 .306 r
.56814 .49493 m .56643 .49733 L .56399 .49536 L F
.668 .292 .325 r
.57018 .49691 m .56814 .49493 L .57003 .49617 L F
.57018 .49691 m .56643 .49733 L .56814 .49493 L F
.664 .395 .504 r
.44307 .57991 m .44483 .57941 L .44249 .579 L F
0 0 .341 r
.52817 .58244 m .5284 .58106 L .52784 .57871 L F
0 0 .507 r
.52817 .58244 m .52942 .58467 L .5284 .58106 L F
.192 .697 .905 r
.48663 .58264 m .48522 .5822 L .48339 .58227 L F
.67 .749 .91 r
.48665 .58523 m .48522 .5822 L .48663 .58264 L F
.748 .332 .26 r
.48778 .58365 m .48522 .5822 L .48784 .58206 L F
.67 .749 .91 r
.48665 .58523 m .49065 .58523 L .48971 .58416 L F
.748 .332 .26 r
.48778 .58365 m .48767 .58366 L .48522 .5822 L F
0 0 0 r
.49001 .58066 m .48778 .58365 L .48784 .58206 L F
.541 .7 .943 r
.48884 .5824 m .49065 .58523 L .49212 .58352 L F
0 0 0 r
.48912 .58198 m .48781 .58363 L .48778 .58365 L F
.541 .7 .943 r
.48884 .5824 m .49212 .58352 L .49001 .58066 L F
0 0 0 r
.48986 .58106 m .48909 .58203 L .48912 .58198 L F
.48909 .58203 m .48781 .58363 L .48912 .58198 L F
.49001 .58066 m .4884 .58288 L .48816 .58314 L F
.541 .7 .943 r
.48784 .58206 m .48884 .5824 L .49001 .58066 L F
.48784 .58206 m .48849 .58278 L .48884 .5824 L F
.48849 .58278 m .49065 .58523 L .48884 .5824 L F
0 0 0 r
.49001 .58066 m .48986 .58106 L .4884 .58288 L F
.48816 .58314 m .4884 .58288 L .48778 .58365 L F
.48986 .58106 m .48923 .58272 L .48781 .58363 L F
.67 .749 .91 r
.48727 .58356 m .48772 .58367 L .48784 .58206 L F
.48772 .58367 m .48777 .58365 L .48784 .58206 L F
.48777 .58368 m .48971 .58416 L .48849 .58278 L F
.509 .148 .29 r
.48781 .58363 m .48776 .58365 L .48778 .58365 L F
.67 .749 .91 r
.48777 .58368 m .48849 .58278 L .48784 .58206 L F
.48665 .58523 m .48971 .58416 L .48767 .58366 L F
.48723 .58369 m .48767 .58366 L .48727 .58356 L F
.48665 .58523 m .48767 .58366 L .48723 .58369 L F
.48596 .58377 m .48727 .58356 L .48522 .5822 L F
.48665 .58523 m .48723 .58369 L .48596 .58377 L F
.48723 .58369 m .48727 .58356 L .48596 .58377 L F
0 0 0 r
.48745 .58368 m .48652 .58386 L .48427 .58398 L F
.48767 .58366 m .4876 .58367 L .48745 .58368 L F
.4876 .58367 m .48652 .58386 L .48745 .58368 L F
.48778 .58365 m .48776 .58365 L .48767 .58366 L F
.48776 .58365 m .48652 .58386 L .48767 .58366 L F
.748 .332 .26 r
.48767 .58366 m .48745 .58368 L .48727 .58356 L F
.48767 .58366 m .48727 .58356 L .48522 .5822 L F
.48745 .58368 m .48427 .58398 L .48522 .5822 L F
.509 .148 .29 r
.48923 .58272 m .48652 .58386 L .48776 .58365 L F
.48923 .58272 m .48776 .58365 L .48781 .58363 L F
.67 .749 .91 r
.48772 .58367 m .48777 .58368 L .48777 .58365 L F
.48727 .58356 m .48782 .5821 L .48522 .5822 L F
.48782 .5821 m .48784 .58206 L .48522 .5822 L F
.192 .697 .905 r
.48339 .58227 m .48522 .5822 L .48289 .58221 L F
.594 .543 .767 r
.42901 .64863 m .42626 .64666 L .42841 .64551 L F
.602 .241 .329 r
.42452 .64776 m .42841 .64551 L .42626 .64666 L F
.749 .986 .764 r
.42484 .64803 m .42452 .64776 L .42626 .64666 L F
.602 .241 .329 r
.42452 .64776 m .42686 .64821 L .42841 .64551 L F
.233 .046 .409 r
.42841 .64551 m .43092 .6449 L .43063 .64192 L F
.438 .068 .236 r
.42841 .64551 m .43037 .64703 L .43092 .6449 L F
.42841 .64551 m .42686 .64821 L .43037 .64703 L F
.942 .958 .663 r
.58466 .51963 m .58296 .52083 L .58449 .51902 L F
.58466 .51963 m .58315 .52296 L .58296 .52083 L F
.927 .91 .518 r
.58547 .51529 m .58466 .51963 L .58449 .51902 L F
.829 .741 .766 r
.60641 .4648 m .60998 .46581 L .61041 .463 L F
.851 .694 .687 r
.60641 .4648 m .60784 .46839 L .60998 .46581 L F
0 0 0 r
.59039 .53618 m .58926 .53783 L .59092 .53413 L F
0 0 .077 r
.58876 .54008 m .58926 .53783 L .59039 .53618 L F
.18 .438 .869 r
.27669 .54657 m .27675 .54853 L .27471 .54664 L F
.27669 .54657 m .27854 .54924 L .27675 .54853 L F
.64 .385 .517 r
.46881 .6157 m .46861 .61804 L .46612 .61798 L F
.46881 .6157 m .46861 .61804 L .46612 .61798 L F
.414 .196 .47 r
.47102 .61501 m .46861 .61804 L .46881 .6157 L F
.47102 .61501 m .46861 .61804 L .46881 .6157 L F
.6 .303 .436 r
.79687 .43034 m .79641 .4322 L .7937 .43212 L F
.559 .583 .835 r
.79887 .42914 m .79687 .43034 L .79575 .4275 L F
.526 .335 .564 r
.79887 .42914 m .79641 .4322 L .79687 .43034 L F
.385 .194 .495 r
.24348 .60302 m .24161 .60365 L .24324 .6054 L F
.36 .192 .513 r
.24161 .60365 m .24148 .60627 L .24324 .6054 L F
.757 .778 .87 r
.75251 .42971 m .7531 .43265 L .75616 .43016 L F
.612 .434 .616 r
.53629 .55265 m .53671 .55561 L .53899 .55246 L F
.402 0 0 r
.67356 .43977 m .67307 .44002 L .67228 .43862 L F
.67356 .43977 m .67409 .44001 L .67307 .44002 L F
0 0 0 r
.54753 .5095 m .54539 .51019 L .54863 .50826 L F
.54753 .5095 m .54501 .51039 L .54539 .51019 L F
.985 .898 .635 r
.58812 .50756 m .58617 .50907 L .58698 .50664 L F
.58812 .50756 m .58716 .51093 L .58617 .50907 L F
.908 .85 .774 r
.58866 .50327 m .58812 .50756 L .58698 .50664 L F
.618 .33 .458 r
.68901 .41245 m .69093 .41409 L .68929 .41409 L F
.68901 .41245 m .6929 .41177 L .69093 .41409 L F
.719 .675 .806 r
.63287 .41141 m .63402 .41499 L .63679 .41301 L F
0 0 .061 r
.42842 .63062 m .42679 .63386 L .42585 .63374 L F
.555 .233 .377 r
.4305 .63259 m .42679 .63386 L .42842 .63062 L F
.495 .24 .456 r
.43083 .63016 m .4305 .63259 L .42842 .63062 L F
.552 .058 0 r
.42484 .64803 m .42659 .64998 L .42452 .64776 L F
.83 .914 .515 r
.58199 .52432 m .58315 .52296 L .58198 .52508 L F
.939 .902 .509 r
.58296 .52083 m .58315 .52296 L .58199 .52432 L F
0 .259 .762 r
.28075 .54903 m .28322 .55208 L .28182 .55086 L F
.243 .453 .865 r
.75604 .37206 m .75549 .37383 L .75512 .37188 L F
.75604 .37206 m .758 .37513 L .75549 .37383 L F
0 0 0 r
.54867 .50838 m .54863 .50826 L .55003 .50699 L F
.54867 .50838 m .54753 .5095 L .54863 .50826 L F
.354 .111 .4 r
.71271 .40319 m .71534 .40016 L .71466 .40216 L F
.227 0 .289 r
.71243 .4049 m .71271 .40319 L .71466 .40216 L F
.86 .956 .61 r
.77698 .40125 m .77462 .40424 L .77482 .40158 L F
.431 .417 .742 r
.79252 .40143 m .79015 .40349 L .78948 .39984 L F
.455 .437 .749 r
.79252 .40143 m .79111 .4058 L .79015 .40349 L F
.903 .583 .43 r
.21338 .65627 m .21526 .65456 L .21544 .65578 L F
.391 .204 .503 r
.21544 .65578 m .21315 .65986 L .21482 .66041 L F
.21544 .65578 m .21482 .66041 L .21338 .65627 L F
.697 .268 .226 r
.21338 .65627 m .21723 .65662 L .21526 .65456 L F
.761 .829 .905 r
.69046 .43473 m .69475 .43376 L .69352 .43244 L F
.788 .865 .906 r
.69475 .43376 m .69675 .43225 L .69352 .43244 L F
.549 .481 .731 r
.64025 .41491 m .64208 .41034 L .63906 .4116 L F
.456 .6 .906 r
.51252 .60002 m .51369 .59884 L .51128 .59985 L F
.51252 .60002 m .51478 .60101 L .51369 .59884 L F
.023 0 .141 r
.44025 .56143 m .44283 .55795 L .44072 .5587 L F
.553 .06 .038 r
.6819 .41383 m .68294 .41264 L .68553 .41376 L F
.968 .813 .387 r
.75627 .38574 m .7559 .38666 L .75797 .38438 L F
.082 .316 .795 r
.21706 .68223 m .21723 .68447 L .21492 .68224 L F
.787 .543 .567 r
.42585 .63374 m .42791 .63832 L .4297 .63658 L F
0 .086 .626 r
.42679 .63386 m .4279 .63817 L .42585 .63374 L F
.938 .939 .769 r
.42765 .63857 m .42761 .64009 L .42836 .63884 L F
.42788 .63835 m .42836 .63884 L .4297 .63658 L F
.42765 .63857 m .42836 .63884 L .42788 .63835 L F
.925 .933 .792 r
.42766 .63812 m .42638 .63948 L .42761 .64009 L F
0 .086 .626 r
.4279 .63817 m .42791 .63832 L .42585 .63374 L F
.787 .543 .567 r
.42791 .63832 m .42799 .63851 L .4297 .63658 L F
0 .086 .626 r
.4279 .63817 m .42799 .63851 L .42791 .63832 L F
.892 .744 .691 r
.42515 .63475 m .4275 .63786 L .42679 .63386 L F
.4275 .63786 m .42766 .63763 L .42679 .63386 L F
.42781 .63827 m .4279 .63817 L .42679 .63386 L F
.723 .273 0 r
.42515 .63475 m .42643 .63683 L .42722 .63765 L F
.4275 .63786 m .42722 .63765 L .42781 .63827 L F
.42515 .63475 m .42722 .63765 L .4275 .63786 L F
.19 .117 .538 r
.42671 .63728 m .42638 .63946 L .42725 .63768 L F
.925 .933 .792 r
.42725 .63768 m .42638 .63948 L .42766 .63812 L F
.723 .273 0 r
.42722 .63765 m .42671 .63728 L .42781 .63827 L F
.42643 .63683 m .42671 .63728 L .42722 .63765 L F
.19 .117 .538 r
.42638 .63946 m .42641 .63943 L .42725 .63768 L F
.42725 .63768 m .42725 .63768 L .42769 .63677 L F
.42638 .63946 m .42725 .63768 L .42725 .63768 L F
.944 .956 .739 r
.4297 .63658 m .4305 .63259 L .43062 .63601 L F
.938 .939 .769 r
.42854 .63669 m .42791 .63832 L .4297 .63658 L F
.729 .654 .775 r
.43027 .63267 m .42854 .63669 L .42679 .63386 L F
.42854 .63669 m .4279 .63817 L .42759 .63695 L F
.42854 .63669 m .42759 .63695 L .42679 .63386 L F
.938 .939 .769 r
.4279 .63817 m .42791 .63832 L .42854 .63669 L F
.729 .654 .775 r
.4286 .63668 m .42799 .63851 L .4279 .63817 L F
.4305 .63259 m .42879 .63662 L .4286 .63668 L F
.42879 .63662 m .42799 .63851 L .4286 .63668 L F
.488 .058 .149 r
.42815 .63665 m .42785 .63673 L .42862 .63667 L F
.42879 .63662 m .42862 .63667 L .4297 .63658 L F
.729 .654 .775 r
.4305 .63259 m .4286 .63668 L .43027 .63267 L F
.4286 .63668 m .4279 .63817 L .42854 .63669 L F
.4286 .63668 m .42854 .63669 L .43027 .63267 L F
.488 .058 .149 r
.42785 .63673 m .42781 .63676 L .42854 .63669 L F
.42862 .63667 m .42854 .63669 L .4297 .63658 L F
.42785 .63673 m .42854 .63669 L .42862 .63667 L F
.42815 .63665 m .42862 .63667 L .42879 .63662 L F
.944 .956 .739 r
.4297 .63658 m .42879 .63662 L .4305 .63259 L F
.488 .058 .149 r
.43062 .63601 m .42815 .63665 L .42879 .63662 L F
.4303 .63621 m .42879 .63662 L .4297 .63658 L F
.43062 .63601 m .42879 .63662 L .4303 .63621 L F
.938 .939 .769 r
.42788 .63676 m .4279 .63817 L .42854 .63669 L F
.944 .956 .739 r
.4297 .63658 m .42799 .63851 L .42879 .63662 L F
0 0 .546 r
.4279 .63817 m .42782 .63683 L .4278 .63668 L F
.42777 .63664 m .4278 .63668 L .42763 .635 L F
.4279 .63817 m .4278 .63668 L .42777 .63664 L F
.488 .058 .149 r
.43062 .63601 m .43056 .63713 L .4279 .6368 L F
0 0 .546 r
.42679 .63386 m .42759 .63695 L .42763 .635 L F
.42759 .63695 m .42778 .63679 L .42763 .635 L F
.985 .903 .6 r
.42781 .63676 m .42692 .63675 L .42763 .635 L F
.488 .058 .149 r
.42785 .63673 m .42773 .63676 L .42781 .63676 L F
.42773 .63676 m .42769 .63677 L .42779 .63676 L F
.42773 .63676 m .42779 .63676 L .42781 .63676 L F
.19 .117 .538 r
.42671 .63728 m .42725 .63768 L .42769 .63677 L F
.723 .273 0 r
.42782 .63829 m .42671 .63728 L .42799 .63851 L F
0 0 .546 r
.42759 .63695 m .4279 .63817 L .42778 .63679 L F
.938 .939 .769 r
.42769 .63677 m .42765 .63843 L .42789 .63819 L F
.723 .273 0 r
.42781 .63827 m .42779 .63825 L .42782 .63829 L F
.42779 .63825 m .42671 .63728 L .42782 .63829 L F
.938 .939 .769 r
.42769 .63677 m .42791 .63832 L .4279 .63817 L F
.892 .744 .691 r
.4275 .63786 m .42781 .63827 L .42766 .63763 L F
.938 .939 .769 r
.42789 .63819 m .42765 .63857 L .42791 .63832 L F
.892 .744 .691 r
.42781 .63827 m .42799 .63851 L .4279 .63817 L F
.925 .933 .792 r
.42769 .63677 m .42725 .63768 L .42766 .63812 L F
.988 .894 .582 r
.42799 .63851 m .42671 .63728 L .42769 .63677 L F
.336 0 0 r
.42772 .63678 m .42671 .63728 L .42769 .63677 L F
.985 .903 .6 r
.42799 .63851 m .42671 .63728 L .42712 .63707 L F
0 0 .546 r
.4279 .63817 m .42799 .63851 L .42782 .63683 L F
.938 .939 .769 r
.42769 .63677 m .4279 .63817 L .42782 .63683 L F
.42769 .63677 m .42782 .63683 L .42779 .63676 L F
.985 .903 .6 r
.42799 .63851 m .42692 .63675 L .42779 .63676 L F
.42782 .63683 m .42779 .63676 L .42781 .63676 L F
.938 .939 .769 r
.42781 .63676 m .4279 .63817 L .42788 .63676 L F
.985 .903 .6 r
.42799 .63851 m .42779 .63676 L .42782 .63683 L F
.938 .939 .769 r
.42779 .63676 m .42782 .63683 L .42781 .63676 L F
.336 0 0 r
.43056 .63713 m .42671 .63728 L .42772 .63678 L F
.985 .903 .6 r
.42712 .63707 m .42671 .63728 L .42692 .63675 L F
.488 .058 .149 r
.42785 .63673 m .4279 .6368 L .42769 .63677 L F
.43062 .63601 m .4279 .6368 L .42785 .63673 L F
.19 .117 .538 r
.42638 .63946 m .42638 .63948 L .42641 .63943 L F
.938 .939 .769 r
.42765 .63843 m .42765 .63857 L .42789 .63819 L F
.551 0 0 r
.23699 .5549 m .23603 .55477 L .23345 .55282 L F
.273 .778 .839 r
.23991 .55436 m .23603 .55477 L .23699 .5549 L F
.691 .648 .802 r
.22136 .65277 m .22188 .64891 L .22045 .64965 L F
.22136 .65277 m .22411 .65228 L .22188 .64891 L F
.673 .527 .678 r
.22136 .65277 m .22135 .65448 L .22411 .65228 L F
.644 .283 0 r
.52543 .57318 m .52369 .56943 L .52444 .57072 L F
.915 .523 .24 r
.53003 .55635 m .53117 .55483 L .53005 .55298 L F
.53003 .55635 m .53215 .55827 L .53117 .55483 L F
.839 .602 .58 r
.58812 .49281 m .58488 .49208 L .58486 .48955 L F
.825 .683 .707 r
.58812 .49281 m .58449 .49483 L .58488 .49208 L F
.58812 .49281 m .58645 .49577 L .58449 .49483 L F
.831 .633 .636 r
.50907 .53331 m .51243 .53485 L .51305 .53172 L F
.50907 .53331 m .51305 .53172 L .51143 .53311 L F
.54 0 0 r
.51305 .53172 m .5129 .53251 L .51143 .53311 L F
.503 .183 .356 r
.50996 .5368 m .51243 .53485 L .50907 .53331 L F
.773 .651 .728 r
.50746 .53637 m .50996 .5368 L .50907 .53331 L F
.693 .833 .398 r
.50907 .53331 m .50784 .53539 L .50746 .53637 L F
.50907 .53331 m .50784 .53539 L .50746 .53637 L F
.515 .128 .245 r
.51143 .53311 m .50784 .53539 L .50907 .53331 L F
.50795 .53532 m .50983 .53513 L .50784 .53539 L F
.51143 .53311 m .50983 .53513 L .50795 .53532 L F
.57 .799 .986 r
.51119 .53318 m .50983 .53513 L .51143 .53311 L F
.91 .814 .74 r
.51116 .53321 m .50983 .53513 L .51198 .53346 L F
.50712 .53201 m .50983 .53513 L .51116 .53321 L F
.57 .799 .986 r
.51071 .5333 m .51005 .53467 L .51116 .53321 L F
.843 .598 .57 r
.51116 .53321 m .51143 .53286 L .51024 .52969 L F
.57 .799 .986 r
.51118 .53318 m .51116 .53321 L .51119 .53318 L F
.51071 .5333 m .51116 .53321 L .51118 .53318 L F
.51005 .53467 m .50983 .53513 L .51119 .53318 L F
.843 .598 .57 r
.50712 .53201 m .51116 .53321 L .51024 .52969 L F
.51116 .53321 m .51152 .53311 L .51119 .53318 L F
0 0 0 r
.51221 .53295 m .51119 .53318 L .51143 .53311 L F
.51222 .53295 m .5122 .53296 L .51221 .53295 L F
.979 .898 .554 r
.51179 .53305 m .51272 .52921 L .51024 .52969 L F
.51198 .53346 m .51206 .53299 L .51179 .53305 L F
0 0 0 r
.51179 .53305 m .51177 .53305 L .51221 .53295 L F
.979 .898 .554 r
.51206 .53299 m .51272 .52921 L .51179 .53305 L F
0 0 0 r
.5122 .53296 m .51179 .53305 L .51221 .53295 L F
.51179 .53305 m .51119 .53318 L .51177 .53305 L F
.843 .598 .57 r
.51121 .53229 m .51133 .53205 L .51024 .52969 L F
.51161 .53335 m .51133 .53205 L .51121 .53229 L F
.51161 .53335 m .51185 .53319 L .51133 .53205 L F
.51119 .53318 m .51152 .53311 L .51143 .53286 L F
.979 .898 .554 r
.51206 .53299 m .51149 .53312 L .51272 .52921 L F
.51149 .53312 m .51145 .5318 L .51272 .52921 L F
.54 0 0 r
.51305 .53172 m .51663 .53348 L .51284 .53282 L F
.693 .567 .709 r
.51272 .52921 m .51284 .53282 L .51414 .53114 L F
.979 .898 .554 r
.51149 .53312 m .51071 .5333 L .51145 .5318 L F
.32 .657 .972 r
.51663 .53348 m .51414 .53114 L .51284 .53282 L F
.51663 .53348 m .51772 .53317 L .51414 .53114 L F
.6 .465 .669 r
.51773 .52819 m .52079 .53042 L .52002 .52752 L F
0 .14 .591 r
.51847 .52866 m .52079 .53042 L .51899 .5291 L F
.51847 .52866 m .51899 .5291 L .51773 .52819 L F
.683 .189 .068 r
.52002 .52752 m .51847 .52866 L .51658 .52694 L F
0 0 .104 r
.52024 .52553 m .51847 .52866 L .52089 .52552 L F
.762 .956 .644 r
.52089 .52552 m .51847 .52866 L .52002 .52752 L F
0 0 .104 r
.52024 .52553 m .51984 .52738 L .51847 .52866 L F
.537 .925 .857 r
.51984 .52738 m .51812 .52837 L .51847 .52866 L F
0 .14 .591 r
.51847 .52866 m .51773 .52819 L .51658 .52694 L F
.668 .216 .169 r
.51658 .52694 m .51503 .52854 L .51847 .52866 L F
.537 .925 .857 r
.51812 .52837 m .51794 .52847 L .51847 .52866 L F
.825 .706 .734 r
.51414 .53114 m .52079 .53042 L .51847 .52866 L F
.51414 .53114 m .51772 .53317 L .52079 .53042 L F
.693 .567 .709 r
.51272 .52921 m .51414 .53114 L .51503 .52854 L F
.771 .765 .847 r
.51694 .52861 m .51414 .53114 L .51847 .52866 L F
.51471 .52949 m .51414 .53114 L .51694 .52861 L F
.575 .258 .394 r
.51362 .52992 m .51071 .5333 L .51502 .53102 L F
.51272 .52921 m .51208 .53053 L .51362 .52992 L F
.51208 .53053 m .51071 .5333 L .51362 .52992 L F
.771 .765 .847 r
.51503 .52854 m .51471 .52949 L .51694 .52861 L F
.575 .258 .394 r
.51272 .52921 m .51071 .5333 L .51502 .53102 L F
.097 .026 .479 r
.51502 .53102 m .51337 .53511 L .51262 .5346 L F
.843 .598 .57 r
.51116 .53321 m .51161 .53335 L .51152 .53311 L F
.51161 .53335 m .51198 .53346 L .51185 .53319 L F
.979 .898 .554 r
.51198 .53346 m .51071 .5333 L .51206 .53299 L F
0 0 0 r
.51284 .53282 m .51071 .5333 L .51119 .53318 L F
.51284 .53282 m .51119 .53318 L .51222 .53295 L F
.54 0 0 r
.5129 .53251 m .51222 .53295 L .51143 .53311 L F
.634 .943 .719 r
.51198 .53346 m .51158 .53324 L .51071 .5333 L F
.097 .026 .479 r
.51254 .53233 m .51257 .53317 L .51071 .5333 L F
.634 .943 .719 r
.51158 .53324 m .51141 .53314 L .51071 .5333 L F
.57 .799 .986 r
.51071 .5333 m .51115 .5336 L .50983 .53513 L F
.634 .943 .719 r
.51198 .53346 m .50983 .53513 L .51096 .53383 L F
.57 .799 .986 r
.51115 .5336 m .51293 .53481 L .50983 .53513 L F
.634 .943 .719 r
.51096 .53383 m .50983 .53513 L .51083 .53387 L F
.097 .026 .479 r
.51158 .53324 m .51115 .5336 L .51071 .5333 L F
.634 .943 .719 r
.51158 .53324 m .51083 .53387 L .51141 .53314 L F
.51198 .53346 m .51083 .53387 L .51158 .53324 L F
.097 .026 .479 r
.51257 .53317 m .51262 .5346 L .51115 .5336 L F
.51257 .53317 m .51115 .5336 L .51158 .53324 L F
.54 0 0 r
.5129 .53251 m .51284 .53282 L .51222 .53295 L F
.097 .026 .479 r
.51502 .53102 m .51262 .5346 L .51254 .53233 L F
.322 .431 .817 r
.51252 .53168 m .51148 .53149 L .51144 .53139 L F
.5135 .53193 m .51252 .53172 L .51252 .53168 L F
.51252 .53172 m .51148 .53149 L .51252 .53168 L F
.291 0 0 r
.51024 .52969 m .51401 .52743 L .51261 .52635 L F
.51024 .52969 m .51272 .52921 L .51401 .52743 L F
0 0 0 r
.51261 .52635 m .50886 .52856 L .51024 .52969 L F
.322 .431 .817 r
.51138 .5297 m .51144 .53139 L .51003 .52828 L F
.678 .228 .174 r
.51141 .53314 m .51502 .53102 L .51071 .5333 L F
.322 .431 .817 r
.5135 .53193 m .51144 .53139 L .51138 .5297 L F
.503 .183 .356 r
.50996 .5368 m .51314 .53686 L .51243 .53485 L F
.437 .148 .375 r
.51243 .53485 m .51314 .53686 L .51446 .53601 L F
.57 .799 .986 r
.51293 .53481 m .51337 .53511 L .50983 .53513 L F
.308 .531 .906 r
.51663 .53348 m .51665 .53475 L .51772 .53317 L F
.528 .822 .999 r
.51665 .53475 m .51904 .53418 L .51772 .53317 L F
.103 .233 .714 r
.52581 .57668 m .52784 .57871 L .52688 .57514 L F
.931 .567 .155 r
.55981 .59191 m .55955 .59375 L .55939 .59043 L F
.55981 .59191 m .5606 .59442 L .55955 .59375 L F
.571 .791 .982 r
.67745 .43417 m .67601 .43621 L .67487 .43498 L F
.67745 .43417 m .67879 .43549 L .67601 .43621 L F
.15 0 .042 r
.56642 .60155 m .5652 .60043 L .56733 .59933 L F
.56642 .60155 m .56434 .60247 L .5652 .60043 L F
.327 .316 .694 r
.20206 .69381 m .20408 .69561 L .20452 .69315 L F
.20206 .69381 m .20336 .69654 L .20408 .69561 L F
.208 .712 .905 r
.48236 .55888 m .48133 .55954 L .47994 .55839 L F
.48236 .55888 m .48353 .55948 L .48133 .55954 L F
.248 0 0 r
.48236 .55888 m .4809 .55894 L .48353 .55911 L F
.21 .668 .946 r
.48236 .55888 m .48472 .55919 L .4862 .56002 L F
.248 0 0 r
.48236 .55888 m .48353 .55911 L .48472 .55919 L F
.208 .712 .905 r
.48236 .55888 m .47994 .55839 L .4799 .55837 L F
.58 .154 .199 r
.44628 .58813 m .446 .59008 L .44369 .58859 L F
.616 .315 .436 r
.4489 .58853 m .446 .59008 L .44628 .58813 L F
.563 .444 .676 r
.61738 .42743 m .62075 .42903 L .61963 .4254 L F
.339 .803 .699 r
.78124 .39019 m .78034 .39063 L .7777 .39166 L F
.719 .692 .823 r
.73455 .41803 m .73101 .41847 L .73344 .41493 L F
.23 .663 .957 r
.73472 .42055 m .73101 .41847 L .73455 .41803 L F
.628 .64 .843 r
.73719 .41748 m .73455 .41803 L .73344 .41493 L F
.597 .452 .656 r
.73719 .41748 m .73472 .42055 L .73455 .41803 L F
.646 .725 .906 r
.72503 .41593 m .72121 .41492 L .72353 .41397 L F
.688 .674 .831 r
.7273 .41469 m .72503 .41593 L .72353 .41397 L F
0 0 0 r
.25303 .63045 m .25011 .63293 L .25125 .63156 L F
.122 0 0 r
.61826 .42868 m .61744 .43012 L .6183 .42978 L F
.804 .803 .85 r
.17435 .62459 m .16977 .62566 L .17266 .62436 L F
0 .292 .79 r
.17468 .62338 m .17435 .62459 L .17266 .62436 L F
.17468 .62338 m .17643 .62612 L .17435 .62459 L F
.456 .335 .626 r
.17435 .62459 m .17643 .62612 L .17444 .62613 L F
.331 .26 .625 r
.24819 .59194 m .25005 .59351 L .25055 .59066 L F
.24819 .59194 m .24844 .59436 L .25005 .59351 L F
.979 .715 .457 r
.44596 .56755 m .44457 .56668 L .44472 .56421 L F
.713 .472 .56 r
.44671 .56901 m .44596 .56755 L .44935 .56925 L F
.868 .69 .659 r
.42348 .65686 m .42457 .65918 L .42604 .65798 L F
.42348 .65686 m .42457 .65918 L .42604 .65798 L F
.321 .347 .733 r
.28603 .57245 m .28433 .57405 L .28372 .57083 L F
.327 .27 .64 r
.2868 .57424 m .28433 .57405 L .28603 .57245 L F
.2868 .57424 m .28497 .57695 L .28433 .57405 L F
.711 .223 .082 r
.20678 .69535 m .20827 .69436 L .20452 .69315 L F
.067 0 0 r
.20954 .69426 m .20827 .69436 L .20678 .69535 L F
.684 .491 .62 r
.62331 .41882 m .6256 .42289 L .62627 .42011 L F
.62331 .41882 m .62357 .42367 L .6256 .42289 L F
.752 .29 .151 r
.53884 .61121 m .53445 .60883 L .53611 .61006 L F
.94 .959 .664 r
.77337 .40333 m .7742 .40067 L .77482 .40158 L F
.441 0 0 r
.77462 .40424 m .77337 .40333 L .77482 .40158 L F
.682 .753 .905 r
.7332 .38686 m .7348 .3891 L .73708 .38764 L F
.639 .519 .701 r
.50393 .60406 m .50414 .60676 L .50639 .6035 L F
.915 .772 .688 r
.60698 .47744 m .60712 .48104 L .60803 .481 L F
.596 .763 .959 r
.18894 .65208 m .19278 .65293 L .19196 .65223 L F
.234 .716 .933 r
.19278 .65293 m .19363 .65232 L .19196 .65223 L F
.19278 .65293 m .19485 .6529 L .19363 .65232 L F
.63 .591 .791 r
.5356 .56438 m .53213 .56157 L .53413 .56102 L F
.768 .701 .788 r
.53814 .56156 m .5356 .56438 L .53413 .56102 L F
.373 .137 .422 r
.53814 .56156 m .538 .56379 L .5356 .56438 L F
.409 .232 .527 r
.538 .56379 m .53574 .56705 L .5356 .56438 L F
.894 .735 .677 r
.60759 .47076 m .60912 .47193 L .60784 .46839 L F
.867 .733 .712 r
.60549 .47381 m .60912 .47193 L .60759 .47076 L F
.60549 .47381 m .60757 .4749 L .60912 .47193 L F
.669 .185 .094 r
.23345 .55282 m .23138 .55392 L .22958 .55216 L F
.444 0 0 r
.23345 .55282 m .23406 .55335 L .23138 .55392 L F
.23345 .55282 m .23603 .55477 L .23406 .55335 L F
.948 .957 .68 r
.22158 .67701 m .21913 .6806 L .22021 .67829 L F
.314 0 .017 r
.21224 .63305 m .21453 .63274 L .21622 .63073 L F
.063 0 0 r
.21622 .63073 m .2165 .63194 L .2184 .63018 L F
.21622 .63073 m .21455 .63272 L .2165 .63194 L F
.123 0 0 r
.22053 .62957 m .2184 .63018 L .2165 .63194 L F
.22053 .62957 m .2165 .63194 L .21857 .63115 L F
.419 .866 .87 r
.21838 .63119 m .2165 .63194 L .21418 .63214 L F
.21857 .63115 m .2165 .63194 L .21838 .63119 L F
.063 0 0 r
.21455 .63272 m .21453 .63274 L .2165 .63194 L F
.427 .065 .246 r
.44732 .57876 m .44967 .57854 L .45122 .57617 L F
.604 .259 .359 r
.45122 .57617 m .44967 .57854 L .45377 .57788 L F
.643 .16 .091 r
.45122 .57617 m .45377 .57788 L .45324 .57694 L F
0 0 0 r
.15599 .55533 m .15617 .5564 L .15722 .55487 L F
.15599 .55533 m .15427 .55731 L .15617 .5564 L F
.368 .123 .406 r
.57174 .47656 m .57431 .47387 L .57185 .47451 L F
.501 .257 .477 r
.46188 .60263 m .45978 .60325 L .46249 .60064 L F
.277 .096 .446 r
.46416 .59976 m .46249 .60064 L .46405 .5976 L F
.039 0 .172 r
.46416 .59976 m .46188 .60263 L .46249 .60064 L F
.477 .732 .982 r
.24182 .55184 m .24309 .55281 L .24392 .55156 L F
.563 .843 .997 r
.24392 .55156 m .24309 .55281 L .24567 .55245 L F
.662 .517 .677 r
.24309 .55281 m .24327 .55554 L .24567 .55245 L F
.755 .484 .522 r
.73067 .38771 m .73047 .38475 L .72694 .38451 L F
.602 .356 .517 r
.7332 .38686 m .73047 .38475 L .73067 .38771 L F
.7332 .38686 m .73284 .38466 L .73047 .38475 L F
0 0 .104 r
.71466 .40216 m .71534 .40016 L .7165 .39895 L F
.791 .697 .761 r
.42585 .63374 m .42235 .63334 L .42472 .63061 L F
.738 .512 .587 r
.47684 .58256 m .47365 .58413 L .47416 .58282 L F
.47684 .58256 m .47696 .58511 L .47365 .58413 L F
.897 .945 .832 r
.21777 .65024 m .21812 .65249 L .22019 .64997 L F
.21777 .65024 m .22019 .64997 L .22045 .64965 L F
.484 0 0 r
.21777 .65024 m .21829 .65043 L .21735 .65029 L F
.493 .826 .999 r
.21381 .65115 m .21777 .65024 L .21419 .64984 L F
.484 0 0 r
.21777 .65024 m .21735 .65029 L .21419 .64984 L F
.897 .945 .832 r
.21777 .65024 m .22045 .64965 L .21829 .65043 L F
.398 .843 .739 r
.21829 .65043 m .22045 .64965 L .22188 .64891 L F
0 0 0 r
.51992 .51759 m .51983 .51734 L .51755 .51823 L F
.51992 .51759 m .52163 .51633 L .51983 .51734 L F
.16566 .56744 m .16513 .56779 L .16761 .56534 L F
.104 0 .053 r
.16823 .5657 m .16761 .56534 L .16967 .5646 L F
.16823 .5657 m .16566 .56744 L .16761 .56534 L F
.507 .042 .084 r
.45377 .57788 m .45715 .57657 L .45324 .57694 L F
.45377 .57788 m .4559 .57826 L .45715 .57657 L F
0 0 0 r
.45715 .57657 m .4559 .57826 L .45854 .57581 L F
.013 .488 .872 r
.49635 .56437 m .49366 .56399 L .49329 .56377 L F
.49635 .56437 m .49787 .56555 L .49366 .56399 L F
.412 .126 .366 r
.26832 .61224 m .26758 .61495 L .2656 .61526 L F
.377 .095 .353 r
.26961 .61416 m .26832 .61224 L .27039 .61159 L F
.26961 .61416 m .26758 .61495 L .26832 .61224 L F
.776 .762 .841 r
.69571 .42477 m .69152 .4257 L .69448 .42323 L F
.733 .813 .914 r
.69448 .42323 m .69793 .42352 L .69571 .42477 L F
.515 .419 .684 r
.28585 .55494 m .2839 .55746 L .28427 .55569 L F
.074 .402 .856 r
.39405 .62416 m .39405 .62279 L .39136 .6211 L F
.39405 .62416 m .39475 .62427 L .39405 .62279 L F
.689 .648 .804 r
.73344 .41493 m .73101 .41847 L .72986 .41396 L F
.23 .663 .957 r
.73472 .42055 m .73135 .41937 L .73101 .41847 L F
.314 .043 .333 r
.24736 .63579 m .24469 .6387 L .2454 .63644 L F
.812 .687 .144 r
.59381 .5239 m .59396 .52409 L .59385 .52113 L F
.796 .854 .402 r
.59396 .52409 m .59355 .52597 L .59417 .52438 L F
.731 .746 .232 r
.59289 .52833 m .59396 .52409 L .59377 .5265 L F
.812 .687 .144 r
.59377 .5265 m .59396 .52409 L .59381 .5239 L F
.796 .854 .402 r
.59396 .52409 m .59417 .52438 L .59486 .52257 L F
.373 .185 .491 r
.28154 .58842 m .28133 .59103 L .27939 .5916 L F
.438 .364 .676 r
.28133 .59103 m .28179 .59378 L .27939 .5916 L F
.518 .366 .614 r
.27939 .5916 m .28179 .59378 L .2795 .59432 L F
.529 .312 .53 r
.57633 .5677 m .5759 .57017 L .57412 .57027 L F
.346 .15 .467 r
.57888 .56899 m .57633 .5677 L .57884 .56651 L F
.57888 .56899 m .5759 .57017 L .57633 .5677 L F
.607 .309 .438 r
.44369 .58859 m .43949 .59073 L .44121 .58833 L F
.068 0 0 r
.52982 .54029 m .52862 .5412 L .5262 .54166 L F
.65 .913 .608 r
.5309 .53869 m .52862 .5412 L .52982 .54029 L F
.618 .077 0 r
.45006 .55758 m .45203 .5582 L .45281 .55781 L F
0 0 0 r
.45281 .55781 m .45436 .55754 L .45543 .55711 L F
.65 .768 .935 r
.20953 .68709 m .20706 .68847 L .2055 .68696 L F
.463 .313 .592 r
.20706 .68847 m .20953 .68709 L .2055 .68696 L F
.20706 .68847 m .20891 .68986 L .20953 .68709 L F
0 0 .126 r
.59092 .53413 m .59217 .53038 L .59129 .53407 L F
0 0 0 r
.59039 .53618 m .59092 .53413 L .59129 .53407 L F
.578 .171 .235 r
.16513 .56779 m .16305 .56986 L .1608 .56956 L F
.359 0 .064 r
.16661 .56776 m .16513 .56779 L .16566 .56744 L F
.16661 .56776 m .16305 .56986 L .16513 .56779 L F
.149 .34 .799 r
.21354 .67392 m .21348 .67134 L .21163 .67167 L F
.804 .83 .871 r
.21753 .67015 m .21455 .67413 L .21348 .67134 L F
.149 .34 .799 r
.21354 .67392 m .21529 .675 L .21348 .67134 L F
.563 .821 .455 r
.46693 .59402 m .46562 .59558 L .46405 .5976 L F
0 0 0 r
.46867 .59286 m .46693 .59402 L .46957 .59153 L F
.097 0 0 r
.46804 .59477 m .46693 .59402 L .46867 .59286 L F
.46804 .59477 m .46562 .59558 L .46693 .59402 L F
.787 .671 .735 r
.72488 .38728 m .72771 .38819 L .72694 .38451 L F
.755 .697 .796 r
.72526 .38756 m .72771 .38819 L .72488 .38728 L F
.755 .484 .522 r
.73067 .38771 m .72694 .38451 L .72771 .38819 L F
.672 .528 .68 r
.67429 .40243 m .67805 .40445 L .678 .40295 L F
.638 .66 .855 r
.19611 .73145 m .19604 .72909 L .19659 .73195 L F
.19611 .73145 m .19411 .73019 L .19604 .72909 L F
.738 .683 .798 r
.18802 .73053 m .18936 .72925 L .1873 .72914 L F
.484 0 0 r
.67323 .41156 m .67693 .41187 L .67609 .41273 L F
.549 0 0 r
.67693 .41187 m .67966 .41332 L .67609 .41273 L F
.314 .234 .604 r
.25523 .58188 m .25641 .57888 L .25527 .57969 L F
.793 .77 .832 r
.61996 .43848 m .61738 .44119 L .62085 .4416 L F
.812 .732 .776 r
.61738 .44119 m .61845 .44469 L .62085 .4416 L F
.735 .737 .853 r
.61996 .43848 m .62085 .4416 L .62346 .43887 L F
.954 .692 .241 r
.53258 .59761 m .53282 .60037 L .5319 .59668 L F
.684 .399 .485 r
.6929 .41177 m .6955 .41405 L .69093 .41409 L F
.6929 .41177 m .6956 .41196 L .6955 .41405 L F
.476 .335 .609 r
.43769 .618 m .43535 .62147 L .43532 .61856 L F
.774 .267 0 r
.21494 .67856 m .21472 .67979 L .21369 .67722 L F
.4 .474 .821 r
.65537 .40172 m .65687 .40452 L .65463 .40353 L F
.388 .299 .633 r
.65351 .40558 m .65537 .40172 L .65463 .40353 L F
0 0 0 r
.55259 .50372 m .55123 .50506 L .55369 .50251 L F
.55259 .50372 m .55369 .50251 L .55536 .50102 L F
.293 .136 .489 r
.79415 .42787 m .79006 .42984 L .7882 .42699 L F
.79415 .42787 m .79102 .43068 L .79006 .42984 L F
.741 .26 .101 r
.79006 .42984 m .79239 .43196 L .78917 .43108 L F
.748 .987 .899 r
.79136 .43583 m .78745 .43756 L .7909 .43541 L F
.811 .998 .783 r
.79244 .43364 m .79136 .43583 L .7909 .43541 L F
.405 .351 .684 r
.79402 .4375 m .79136 .43583 L .79349 .4347 L F
.433 .344 .655 r
.79402 .4375 m .79202 .43862 L .79136 .43583 L F
.53 .665 .923 r
.79349 .4347 m .79136 .43583 L .79244 .43364 L F
.161 .697 .835 r
.21689 .53886 m .21908 .5387 L .22096 .5389 L F
.18 0 0 r
.21908 .5387 m .22314 .53851 L .22096 .5389 L F
0 .195 .719 r
.51849 .56241 m .51999 .56387 L .51767 .56098 L F
.69 .376 .439 r
.45359 .5966 m .4573 .59683 L .45488 .59436 L F
.649 .383 .504 r
.45488 .59436 m .4573 .59683 L .45754 .59451 L F
0 0 .182 r
.58499 .54944 m .58702 .54587 L .58644 .54801 L F
0 0 .183 r
.58501 .55149 m .58499 .54944 L .58644 .54801 L F
.703 .599 .737 r
.4172 .60919 m .41712 .61277 L .4148 .61264 L F
.736 .845 .931 r
.69969 .43048 m .70311 .4304 L .70198 .42922 L F
.772 .871 .921 r
.70198 .42922 m .70311 .4304 L .70524 .42908 L F
.212 .283 .72 r
.46562 .59558 m .46416 .59976 L .46405 .5976 L F
0 0 0 r
.64428 .40805 m .64436 .40825 L .64625 .40726 L F
.588 .562 .792 r
.4172 .60919 m .42076 .61223 L .41929 .60871 L F
.246 .215 .625 r
.41919 .61073 m .41712 .61277 L .4172 .60919 L F
.642 .444 .599 r
.41919 .61073 m .41572 .61297 L .41712 .61277 L F
.455 .437 .749 r
.79252 .40143 m .79317 .40504 L .79111 .4058 L F
.527 .371 .613 r
.79317 .40504 m .79105 .40805 L .79111 .4058 L F
.102 0 0 r
.14982 .55933 m .15226 .5581 L .15044 .55861 L F
.755 .566 .641 r
.46081 .57958 m .4568 .58174 L .45711 .5798 L F
.46081 .57958 m .46126 .58259 L .4568 .58174 L F
.033 .055 .549 r
.46256 .58111 m .46081 .57958 L .46345 .57943 L F
.46256 .58111 m .46126 .58259 L .46081 .57958 L F
.702 .757 .895 r
.65506 .42848 m .65829 .42925 L .65759 .42767 L F
.861 .884 .852 r
.65759 .42767 m .65829 .42925 L .66098 .42587 L F
.19 .117 .538 r
.42671 .63728 m .42575 .63905 L .42638 .63948 L F
.502 .859 .99 r
.4229 .64036 m .4273 .6401 L .42638 .63948 L F
.254 0 0 r
.42505 .64033 m .4229 .64036 L .42638 .63948 L F
.19 .117 .538 r
.42575 .63905 m .42505 .64033 L .42638 .63948 L F
.502 .859 .99 r
.4273 .6401 m .42761 .64009 L .42638 .63948 L F
.958 .796 .354 r
.58655 .51335 m .58617 .50907 L .58716 .51093 L F
.738 .99 .877 r
.22497 .65903 m .22265 .66075 L .22317 .65912 L F
.966 .753 .565 r
.22514 .66034 m .22317 .65912 L .22265 .66075 L F
.024 0 0 r
.4229 .64036 m .41966 .6387 L .42163 .63932 L F
.704 .382 .429 r
.58488 .49208 m .58068 .48986 L .58486 .48955 L F
.58488 .49208 m .58087 .49189 L .58068 .48986 L F
.679 .448 .565 r
.63788 .40784 m .64055 .40588 L .638 .4061 L F
.63788 .40784 m .64274 .40935 L .64055 .40588 L F
.636 .436 .595 r
.64055 .40588 m .64274 .40935 L .64436 .40825 L F
.819 .623 .637 r
.44278 .59998 m .44437 .60069 L .44245 .5974 L F
.692 .551 .69 r
.44278 .59998 m .44332 .60201 L .44437 .60069 L F
.608 .332 .473 r
.44332 .60201 m .44642 .60285 L .44437 .60069 L F
.685 .32 .35 r
.44437 .60069 m .44642 .60285 L .44711 .60115 L F
.2 .567 .937 r
.26003 .54069 m .25856 .5413 L .2572 .54016 L F
.26003 .54069 m .26147 .54211 L .25856 .5413 L F
.659 .747 .916 r
.74844 .42893 m .74968 .43177 L .75251 .42971 L F
0 .152 .69 r
.40727 .64529 m .40768 .64394 L .40558 .64166 L F
0 .135 .677 r
.40727 .64529 m .40895 .6469 L .40768 .64394 L F
.782 .431 .392 r
.77828 .42163 m .78268 .42306 L .78116 .42041 L F
.717 .296 .245 r
.78186 .42538 m .78283 .42314 L .78255 .42319 L F
.78283 .42314 m .783 .42274 L .78281 .42293 L F
.886 .734 .688 r
.78016 .42401 m .78247 .4233 L .77828 .42163 L F
.717 .296 .245 r
.78283 .42314 m .78268 .42306 L .78257 .42319 L F
.856 .693 .678 r
.78295 .42315 m .78186 .42538 L .78255 .42321 L F
.886 .734 .688 r
.78255 .42321 m .78295 .42315 L .78268 .42306 L F
.717 .296 .245 r
.78283 .42314 m .78281 .42293 L .78268 .42306 L F
.886 .734 .688 r
.78247 .4233 m .78268 .42306 L .77828 .42163 L F
.717 .296 .245 r
.78257 .42319 m .78268 .42306 L .78255 .42319 L F
.112 .208 .686 r
.78116 .42041 m .78281 .42293 L .78278 .42248 L F
.717 .296 .245 r
.78255 .42319 m .783 .42274 L .78278 .42248 L F
.112 .208 .686 r
.78281 .42293 m .78295 .42315 L .78278 .42248 L F
.782 .431 .392 r
.78268 .42306 m .78295 .42315 L .78281 .42293 L F
.78268 .42306 m .78281 .42293 L .78116 .42041 L F
.856 .693 .678 r
.78295 .42315 m .78255 .42321 L .78278 .42248 L F
.886 .734 .688 r
.78247 .4233 m .78295 .42315 L .78255 .42321 L F
.717 .296 .245 r
.78186 .42538 m .78392 .42382 L .783 .42274 L F
.78186 .42538 m .78533 .4257 L .78392 .42382 L F
.165 .328 .783 r
.39475 .62427 m .39625 .62769 L .39723 .62611 L F
.294 .502 .889 r
.39625 .62769 m .3999 .62957 L .39723 .62611 L F
.83 .696 .716 r
.61128 .45626 m .60919 .45935 L .61261 .45987 L F
.828 .738 .765 r
.60868 .46151 m .61261 .45987 L .60919 .45935 L F
.60868 .46151 m .61041 .463 L .61261 .45987 L F
.729 .564 .667 r
.49888 .58256 m .5026 .58551 L .50127 .58202 L F
.38 0 0 r
.50062 .58289 m .49888 .58256 L .50127 .58202 L F
.729 .564 .667 r
.49888 .58256 m .4993 .58572 L .5026 .58551 L F
.38 0 0 r
.50062 .58289 m .49749 .58407 L .49888 .58256 L F
.889 .898 .83 r
.2032 .7075 m .20505 .70836 L .20724 .70527 L F
.795 .624 .669 r
.22505 .65744 m .22497 .65903 L .22373 .65727 L F
.464 .81 .998 r
.22373 .65727 m .22588 .65623 L .22505 .65744 L F
.723 .582 .696 r
.22588 .65623 m .22725 .65797 L .22505 .65744 L F
.248 .141 .531 r
.22725 .65797 m .22514 .66034 L .22505 .65744 L F
.464 .81 .998 r
.22373 .65727 m .22588 .65623 L .22505 .65744 L F
0 0 .321 r
.51664 .59385 m .51717 .59736 L .51661 .59472 L F
.102 .486 .899 r
.64385 .42631 m .64403 .42521 L .64093 .42354 L F
.64385 .42631 m .64558 .42698 L .64403 .42521 L F
.099 0 0 r
.45978 .60325 m .45791 .60512 L .45559 .60564 L F
0 0 0 r
.4609 .60287 m .45978 .60325 L .46188 .60263 L F
.4609 .60287 m .45791 .60512 L .45978 .60325 L F
.923 .908 .513 r
.59486 .52257 m .59584 .51804 L .59487 .52197 L F
.796 .854 .402 r
.59396 .52409 m .59486 .52257 L .59487 .52197 L F
.621 .622 .83 r
.22188 .64891 m .22411 .65228 L .22619 .6511 L F
.888 .985 .714 r
.43378 .56301 m .43235 .56573 L .43337 .56456 L F
.098 0 0 r
.71885 .38838 m .71563 .39044 L .71832 .3891 L F
0 0 0 r
.72086 .38702 m .71885 .38838 L .71832 .3891 L F
.034 .581 .835 r
.1832 .65217 m .1817 .65167 L .17929 .65138 L F
.29 .668 .972 r
.1832 .65217 m .18347 .65088 L .1817 .65167 L F
.1832 .65217 m .18514 .65211 L .18347 .65088 L F
.59 .362 .539 r
.6982 .41133 m .6955 .41405 L .6956 .41196 L F
.393 .059 .275 r
.69319 .40232 m .69064 .40311 L .69034 .40466 L F
.696 .43 .517 r
.62627 .42011 m .62816 .42016 L .62697 .41802 L F
.241 .611 .955 r
.46165 .56022 m .45892 .55908 L .4616 .56014 L F
.669 .123 0 r
.45756 .55802 m .4616 .56014 L .45892 .55908 L F
.45756 .55802 m .46019 .56012 L .4616 .56014 L F
.065 .629 .747 r
.46019 .56012 m .46156 .56008 L .4616 .56014 L F
.46156 .56008 m .46397 .56001 L .4616 .56014 L F
.241 .611 .955 r
.46274 .56067 m .46165 .56022 L .4616 .56014 L F
0 0 0 r
.4616 .56014 m .46502 .55987 L .46274 .56067 L F
.874 .695 .657 r
.52388 .54286 m .52267 .54621 L .52542 .54662 L F
.796 .575 .602 r
.52165 .54865 m .52542 .54662 L .52267 .54621 L F
.52165 .54865 m .5254 .5494 L .52542 .54662 L F
.614 .367 .52 r
.5254 .5494 m .52783 .54683 L .52542 .54662 L F
.994 .793 .424 r
.65013 .41996 m .65 .41773 L .64971 .41995 L F
.803 .848 .884 r
.71694 .42376 m .72004 .42377 L .71888 .42225 L F
.724 .816 .922 r
.71888 .42225 m .72004 .42377 L .72256 .4224 L F
.82 .736 .771 r
.61738 .44119 m .61512 .44421 L .61845 .44469 L F
.834 .69 .704 r
.61473 .44661 m .61845 .44469 L .61512 .44421 L F
.61473 .44661 m .61652 .44788 L .61845 .44469 L F
.614 .367 .52 r
.5254 .5494 m .52795 .54958 L .52783 .54683 L F
.791 .507 .506 r
.52783 .54683 m .52795 .54958 L .53068 .54901 L F
.47 .545 .851 r
.20104 .70498 m .20335 .70473 L .20151 .70165 L F
.685 .484 .608 r
.20016 .70721 m .20335 .70473 L .20104 .70498 L F
.382 0 0 r
.22314 .53851 m .22524 .53893 L .22715 .53851 L F
.22 0 0 r
.22524 .53893 m .22888 .53809 L .22715 .53851 L F
.875 .594 .508 r
.75379 .39338 m .75158 .39524 L .753 .39395 L F
.75379 .39338 m .75415 .39614 L .75158 .39524 L F
0 0 0 r
.75588 .39225 m .75691 .3914 L .75379 .39338 L F
.75588 .39225 m .75379 .39338 L .753 .39395 L F
.608 .239 .318 r
.44711 .60115 m .44816 .60226 L .44931 .59979 L F
.44711 .60115 m .44642 .60285 L .44816 .60226 L F
.531 .31 .524 r
.46845 .6005 m .47076 .60249 L .47119 .59961 L F
.46845 .6005 m .47076 .60249 L .47119 .59961 L F
.782 .988 .745 r
.43841 .63405 m .43611 .63661 L .43674 .63478 L F
.188 .131 .558 r
.4351 .63862 m .43674 .63478 L .43611 .63661 L F
.409 .741 .993 r
.27311 .54551 m .27258 .54683 L .27094 .5457 L F
.27311 .54551 m .27471 .54664 L .27258 .54683 L F
.453 .376 .68 r
.57635 .57232 m .57412 .57027 L .5759 .57017 L F
.57635 .57232 m .57462 .57354 L .57412 .57027 L F
.254 0 0 r
.16526 .55163 m .16951 .54956 L .16717 .55 L F
.674 .798 .941 r
.19852 .71094 m .20246 .71125 L .20192 .71014 L F
.566 .603 .849 r
.20246 .71125 m .2032 .7075 L .20192 .71014 L F
.20246 .71125 m .20499 .71119 L .2032 .7075 L F
.804 .499 .475 r
.5365 .56338 m .53814 .56156 L .53413 .56102 L F
.5365 .56338 m .538 .56379 L .53814 .56156 L F
.836 .598 .58 r
.62754 .42902 m .63029 .43137 L .62781 .43064 L F
.824 .911 .898 r
.66072 .41634 m .66195 .4177 L .66497 .41481 L F
.376 .279 .617 r
.56358 .56467 m .56504 .56085 L .56305 .56093 L F
.56358 .56467 m .56564 .56379 L .56504 .56085 L F
.402 .341 .675 r
.56358 .56467 m .56602 .56653 L .56564 .56379 L F
.474 .333 .609 r
.56358 .56467 m .56383 .56722 L .56602 .56653 L F
.451 .358 .66 r
.28531 .56641 m .28372 .57083 L .2836 .57053 L F
.439 .495 .82 r
.76505 .39 m .76281 .38983 L .76176 .38682 L F
.37 .196 .509 r
.24366 .6005 m .24532 .60241 L .24543 .59976 L F
.24366 .6005 m .24348 .60302 L .24532 .60241 L F
.391 0 .118 r
.49895 .58782 m .5026 .58551 L .4993 .58572 L F
.49895 .58782 m .50155 .58747 L .5026 .58551 L F
.138 .295 .761 r
.5026 .58551 m .50363 .58399 L .50127 .58202 L F
.653 .24 .248 r
.5026 .58551 m .50554 .58719 L .50363 .58399 L F
.5026 .58551 m .50155 .58747 L .50554 .58719 L F
.863 .566 .484 r
.67162 .3983 m .67429 .40243 L .67451 .39985 L F
.468 .283 .546 r
.41966 .57928 m .42191 .57604 L .41982 .57677 L F
.422 .044 .213 r
.56061 .49845 m .55779 .50023 L .5589 .49845 L F
.328 .81 .776 r
.50667 .52302 m .50998 .52204 L .5084 .52343 L F
.879 .969 .845 r
.51446 .53601 m .51248 .5384 L .51468 .53807 L F
.347 .341 .71 r
.51468 .53807 m .51517 .53994 L .51658 .53878 L F
.666 .335 .403 r
.201 .55453 m .19862 .55472 L .20408 .55319 L F
.487 .336 .601 r
.20322 .55425 m .201 .55453 L .20408 .55319 L F
.208 0 0 r
.2052 .55299 m .20322 .55425 L .20408 .55319 L F
.133 0 0 r
.44194 .63642 m .44078 .63848 L .43892 .63901 L F
0 0 .217 r
.4429 .63241 m .44194 .63642 L .44066 .63282 L F
.4429 .63241 m .44277 .63497 L .44211 .63569 L F
.987 .775 .378 r
.44178 .63333 m .44277 .63497 L .4429 .63241 L F
.155 .525 .919 r
.44178 .63333 m .44344 .63424 L .44277 .63497 L F
.44344 .63424 m .44355 .6343 L .44277 .63497 L F
0 0 .217 r
.44211 .63569 m .44277 .63497 L .44194 .63642 L F
.093 0 0 r
.44278 .63754 m .44194 .63642 L .44277 .63497 L F
.44278 .63754 m .44078 .63848 L .44194 .63642 L F
.774 .877 .922 r
.69352 .43244 m .69675 .43225 L .69563 .43097 L F
.721 .862 .948 r
.69563 .43097 m .69675 .43225 L .69969 .43048 L F
.397 .202 .495 r
.2656 .61526 m .26549 .6177 L .26319 .61831 L F
.429 .207 .474 r
.26501 .62048 m .26319 .61831 L .26549 .6177 L F
.26501 .62048 m .26293 .62109 L .26319 .61831 L F
.922 .929 .795 r
.7485 .41615 m .74727 .41851 L .7464 .41719 L F
0 0 0 r
.47191 .59094 m .46867 .59286 L .46957 .59153 L F
.20538 .5534 m .2052 .55299 L .20738 .55289 L F
.20538 .5534 m .20322 .55425 L .2052 .55299 L F
.521 .33 .561 r
.24327 .55554 m .24546 .555 L .24567 .55245 L F
.461 .705 .974 r
.24327 .55554 m .24681 .55609 L .24546 .555 L F
.671 .874 .975 r
.77965 .42677 m .78046 .42794 L .78285 .42678 L F
.854 .776 .272 r
.67409 .44001 m .67324 .44295 L .67307 .44002 L F
.67409 .44001 m .67356 .44292 L .67324 .44295 L F
.986 .9 .599 r
.5989 .50897 m .60047 .50751 L .59992 .50652 L F
.5989 .50897 m .59962 .51084 L .60047 .50751 L F
.328 .008 .261 r
.18459 .54281 m .18623 .54267 L .18731 .54275 L F
.324 .808 .875 r
.18623 .54267 m .18984 .54213 L .18731 .54275 L F
.182 .243 .691 r
.46707 .58049 m .46937 .5821 L .46792 .57852 L F
.479 .87 .683 r
.23727 .64273 m .23511 .6439 L .23407 .64477 L F
.359 .821 .921 r
.238 .6436 m .23511 .6439 L .23727 .64273 L F
.27 0 0 r
.23957 .64237 m .238 .6436 L .23727 .64273 L F
.716 .419 .473 r
.19832 .55528 m .1944 .55629 L .19196 .55717 L F
.098 0 0 r
.19719 .55619 m .1944 .55629 L .19832 .55528 L F
.19719 .55619 m .19832 .55528 L .19862 .55472 L F
.239 .103 .485 r
.28544 .58191 m .28559 .58502 L .28414 .58546 L F
.579 .45 .669 r
.28559 .58502 m .28368 .58775 L .28414 .58546 L F
.194 0 0 r
.51248 .5384 m .51658 .53878 L .51517 .53994 L F
.96 .636 .355 r
.51611 .59887 m .51764 .5998 L .51722 .59761 L F
.51611 .59887 m .51722 .59761 L .51717 .59736 L F
.445 0 0 r
.51478 .60101 m .51716 .60239 L .51629 .60217 L F
.51478 .60101 m .51629 .60217 L .51611 .59887 L F
.96 .636 .355 r
.51611 .59887 m .51717 .59736 L .51648 .59636 L F
.973 .761 .558 r
.51611 .59887 m .51764 .5998 L .51648 .59636 L F
.833 .365 0 r
.51886 .60223 m .51611 .59887 L .51629 .60217 L F
.787 .549 .576 r
.51759 .59853 m .51501 .60012 L .51611 .59887 L F
.4 .566 .901 r
.51395 .59937 m .51478 .60101 L .51611 .59887 L F
.787 .549 .576 r
.51501 .60012 m .5146 .60037 L .51611 .59887 L F
.51802 .59826 m .51759 .59853 L .51611 .59887 L F
.4 .566 .901 r
.51369 .59884 m .51395 .59937 L .51611 .59887 L F
.423 0 .118 r
.43589 .58431 m .43832 .58413 L .4366 .58316 L F
.567 .49 .729 r
.43643 .6445 m .43285 .64159 L .43562 .64104 L F
.406 .154 .416 r
.43892 .63901 m .43874 .64126 L .43562 .64104 L F
.386 .22 .531 r
.43843 .64379 m .43562 .64104 L .43874 .64126 L F
.43759 .64297 m .43643 .6445 L .43562 .64104 L F
.443 0 .047 r
.4368 .64287 m .43863 .64136 L .43855 .64009 L F
.43863 .64136 m .43874 .64126 L .43873 .64119 L F
.43863 .64136 m .43873 .64119 L .43855 .64009 L F
.386 .22 .531 r
.43843 .64379 m .43668 .64441 L .43759 .64297 L F
.43668 .64441 m .43643 .6445 L .43759 .64297 L F
.999 .795 .463 r
.64971 .41995 m .65 .41773 L .64879 .41883 L F
.966 .903 .541 r
.64879 .41883 m .65 .41773 L .64956 .41664 L F
.239 .425 .844 r
.3999 .62957 m .39976 .63066 L .40079 .62911 L F
.192 .36 .803 r
.39976 .63066 m .40237 .63252 L .40079 .62911 L F
.97 .818 .398 r
.7611 .41649 m .76139 .41461 L .76085 .41355 L F
.98 .908 .659 r
.76139 .41461 m .76155 .41116 L .76085 .41355 L F
.43 .181 .434 r
.4429 .61246 m .44252 .61483 L .4403 .61529 L F
.609 .338 .482 r
.44538 .61456 m .4429 .61246 L .44528 .612 L F
.44538 .61456 m .44252 .61483 L .4429 .61246 L F
.421 .154 .401 r
.4308 .6502 m .42901 .64863 L .43146 .64835 L F
0 .457 .781 r
.47617 .60815 m .47822 .60871 L .4798 .60946 L F
.573 .345 .531 r
.4798 .60946 m .47956 .61192 L .47704 .61199 L F
.538 .877 .989 r
.4798 .60946 m .47822 .60871 L .47876 .60857 L F
.48028 .60877 m .47876 .60857 L .4808 .60804 L F
.4798 .60946 m .47876 .60857 L .48028 .60877 L F
.075 .249 .739 r
.4808 .60804 m .481 .60864 L .4798 .60946 L F
.481 .60864 m .48206 .61168 L .47994 .60959 L F
.481 .60864 m .47994 .60959 L .4798 .60946 L F
.604 .458 .657 r
.4808 .60804 m .48055 .60881 L .47822 .60871 L F
.552 .326 .526 r
.4798 .60946 m .48206 .61168 L .47956 .61192 L F
.604 .458 .657 r
.48055 .60881 m .47975 .61132 L .47878 .60968 L F
.48055 .60881 m .47878 .60968 L .47822 .60871 L F
.859 .739 .729 r
.47975 .61132 m .48206 .61168 L .481 .60864 L F
.48055 .60881 m .481 .60864 L .4808 .60804 L F
.47975 .61132 m .481 .60864 L .48055 .60881 L F
.645 .65 .84 r
.4808 .60804 m .47822 .60871 L .47802 .60855 L F
.4808 .60804 m .47802 .60855 L .47887 .60761 L F
.48004 .60644 m .4762 .60702 L .47935 .60497 L F
.4808 .60804 m .47887 .60761 L .48004 .60644 L F
.47887 .60761 m .4762 .60702 L .48004 .60644 L F
.683 .734 .226 r
.47991 .6108 m .47991 .61078 L .47975 .61132 L F
.504 .579 .864 r
.48072 .60663 m .4808 .60804 L .48004 .60644 L F
.4824 .60709 m .48154 .6076 L .48072 .60663 L F
.48154 .6076 m .4808 .60804 L .48072 .60663 L F
.4824 .60709 m .48004 .60644 L .48138 .60639 L F
.519 .455 .725 r
.47932 .60938 m .48055 .60642 L .47935 .60497 L F
.48055 .60642 m .48165 .60376 L .47935 .60497 L F
.47932 .60938 m .48059 .60868 L .48131 .60639 L F
.504 .579 .864 r
.4824 .60709 m .48138 .60639 L .48165 .60376 L F
.519 .455 .725 r
.48091 .6064 m .48142 .60604 L .48149 .60531 L F
.683 .734 .226 r
.4808 .60804 m .48057 .60874 L .48055 .60881 L F
.28 .014 .32 r
.48231 .60762 m .4808 .60804 L .4824 .60709 L F
.48202 .60789 m .4808 .60804 L .48231 .60762 L F
.48122 .60863 m .48109 .60845 L .48202 .60789 L F
.48109 .60845 m .4808 .60804 L .48202 .60789 L F
.519 .455 .725 r
.48231 .60762 m .48266 .60754 L .48261 .60735 L F
.48202 .60789 m .48226 .60776 L .48231 .60762 L F
.48226 .60776 m .48266 .60754 L .48231 .60762 L F
0 0 .296 r
.48226 .60776 m .48258 .60755 L .48266 .60754 L F
.48202 .60789 m .48229 .60773 L .48226 .60776 L F
.48229 .60773 m .48258 .60755 L .48226 .60776 L F
0 0 .134 r
.48327 .60786 m .48198 .60967 L .48229 .60773 L F
.48239 .60764 m .48229 .60773 L .48231 .60762 L F
.48327 .60786 m .48229 .60773 L .48239 .60764 L F
.48248 .60717 m .48231 .60762 L .4824 .60709 L F
.48327 .60786 m .48231 .60762 L .48248 .60717 L F
.483 .462 .758 r
.48451 .60647 m .4824 .60709 L .48165 .60376 L F
.519 .455 .725 r
.48202 .60789 m .48261 .60735 L .48255 .60714 L F
.48199 .60733 m .48255 .60714 L .48188 .60462 L F
.48202 .60789 m .48255 .60714 L .48199 .60733 L F
0 0 .515 r
.48165 .60376 m .48255 .60714 L .48316 .60548 L F
.48255 .60714 m .48266 .60754 L .48274 .60721 L F
.48255 .60714 m .48274 .60721 L .48316 .60548 L F
.519 .455 .725 r
.48059 .60868 m .48202 .60789 L .48188 .60462 L F
.48059 .60868 m .48188 .60462 L .48187 .60459 L F
.793 .999 .838 r
.48316 .60548 m .48274 .60721 L .48016 .60804 L F
.48274 .60721 m .48266 .60754 L .48201 .60767 L F
.48274 .60721 m .48201 .60767 L .48016 .60804 L F
0 0 .134 r
.48447 .60651 m .48334 .60683 L .48451 .60647 L F
.48334 .60683 m .4824 .60709 L .48339 .6068 L F
.48334 .60683 m .48339 .6068 L .48451 .60647 L F
.48327 .60786 m .48248 .60717 L .48447 .60651 L F
.48248 .60717 m .4824 .60709 L .48447 .60651 L F
0 0 .296 r
.48155 .60815 m .48211 .60765 L .48258 .60755 L F
.28 .014 .32 r
.48198 .60967 m .48122 .60863 L .48231 .60762 L F
0 0 .296 r
.48155 .60815 m .48258 .60755 L .48202 .60789 L F
.519 .455 .725 r
.47932 .60938 m .48187 .60459 L .48152 .60495 L F
.48105 .6052 m .48181 .60436 L .48165 .60376 L F
.47932 .60938 m .48181 .60436 L .48105 .6052 L F
.504 .579 .864 r
.48138 .60639 m .47935 .60497 L .48165 .60376 L F
.519 .455 .725 r
.48091 .6064 m .48131 .60639 L .48142 .60604 L F
.48149 .60531 m .48142 .60604 L .48187 .60459 L F
.47932 .60938 m .48131 .60639 L .48091 .6064 L F
.504 .579 .864 r
.48138 .60639 m .48004 .60644 L .47935 .60497 L F
0 0 .296 r
.47977 .6091 m .48016 .60804 L .4808 .60791 L F
.48062 .60858 m .4808 .60791 L .48211 .60765 L F
.47977 .6091 m .4808 .60791 L .48062 .60858 L F
.683 .734 .226 r
.48055 .60881 m .48047 .60904 L .47991 .6108 L F
.48057 .60874 m .48047 .60904 L .48055 .60881 L F
.48047 .60904 m .47991 .61078 L .47991 .6108 L F
.519 .455 .725 r
.48152 .60495 m .48187 .60459 L .48181 .60436 L F
.645 .65 .84 r
.47887 .60761 m .47802 .60855 L .4762 .60702 L F
0 0 .296 r
.47932 .60938 m .47941 .60923 L .47977 .6091 L F
.47941 .60923 m .48016 .60804 L .47977 .6091 L F
.28 .014 .32 r
.48198 .60967 m .47991 .61078 L .4808 .60804 L F
0 0 .296 r
.47932 .60938 m .48211 .60765 L .48155 .60815 L F
.414 .426 .764 r
.47815 .60849 m .47967 .6107 L .47932 .60938 L F
.216 .512 .911 r
.4762 .60702 m .47822 .60871 L .47617 .60815 L F
.414 .426 .764 r
.4762 .60702 m .4775 .60841 L .47815 .60849 L F
.4775 .60841 m .47967 .6107 L .47815 .60849 L F
.396 .547 .888 r
.44411 .59605 m .44245 .5974 L .44082 .59418 L F
.437 .349 .658 r
.44682 .59773 m .44245 .5974 L .44411 .59605 L F
.44682 .59773 m .44278 .59998 L .44245 .5974 L F
.484 .225 .445 r
.22691 .62363 m .22908 .62321 L .22938 .62155 L F
.479 .223 .448 r
.22938 .62155 m .23194 .62176 L .23356 .61832 L F
.324 0 .207 r
.22908 .62321 m .23194 .62176 L .22938 .62155 L F
.575 .365 .56 r
.56305 .56093 m .56504 .56085 L .56513 .55871 L F
.537 .34 .561 r
.56513 .55871 m .5681 .55813 L .56798 .55548 L F
.514 .303 .53 r
.56504 .56085 m .5681 .55813 L .56513 .55871 L F
.602 .441 .635 r
.42677 .57934 m .42664 .58215 L .42395 .58258 L F
.324 .363 .748 r
.42649 .58462 m .42395 .58258 L .42664 .58215 L F
.6 .856 .992 r
.24795 .55164 m .24392 .55156 L .24567 .55245 L F
.706 .902 .966 r
.47617 .60815 m .47362 .60971 L .47438 .60755 L F
.266 0 .306 r
.24844 .59436 m .24595 .59725 L .24772 .59651 L F
.398 .193 .481 r
.24772 .59651 m .25005 .59351 L .24844 .59436 L F
.718 .184 0 r
.67162 .3983 m .67179 .39896 L .66988 .39793 L F
.878 .463 .034 r
.74343 .39725 m .74207 .3949 L .74183 .39635 L F
.351 .735 .986 r
.19192 .63213 m .19157 .63324 L .18977 .63269 L F
.19192 .63213 m .1937 .63313 L .19157 .63324 L F
.789 .557 .585 r
.4086 .61751 m .41235 .61542 L .40799 .61468 L F
.4086 .61751 m .41217 .61798 L .41235 .61542 L F
.636 .47 .64 r
.41217 .61798 m .41459 .61478 L .41235 .61542 L F
.205 .619 .95 r
.76314 .43574 m .76541 .4352 L .76215 .43452 L F
.76314 .43574 m .76692 .43634 L .76541 .4352 L F
.18 0 .355 r
.42681 .56537 m .42789 .56523 L .42868 .56312 L F
.715 .566 .686 r
.42681 .56537 m .42981 .5669 L .42789 .56523 L F
.42681 .56537 m .42719 .56727 L .42981 .5669 L F
.738 .99 .877 r
.22497 .65903 m .22317 .65912 L .22373 .65727 L F
0 0 0 r
.56154 .48378 m .55877 .48638 L .56095 .48491 L F
.35 .031 .276 r
.56095 .48491 m .56363 .48276 L .56154 .48378 L F
.615 .711 .914 r
.1801 .62723 m .17796 .62791 L .17643 .62612 L F
.839 .943 .579 r
.74871 .41088 m .74687 .41578 L .74662 .41466 L F
.336 .518 .888 r
.28296 .54874 m .28322 .55208 L .28075 .54903 L F
.28296 .54874 m .28454 .5514 L .28322 .55208 L F
.196 0 0 r
.17143 .54849 m .17361 .54828 L .17586 .54689 L F
0 0 0 r
.17586 .54689 m .17574 .54748 L .1778 .54612 L F
.17586 .54689 m .17361 .54828 L .17574 .54748 L F
.23 .663 .957 r
.73472 .42055 m .73359 .41957 L .73135 .41937 L F
.516 .838 .999 r
.73631 .41887 m .73472 .42055 L .73841 .41862 L F
.73631 .41887 m .73359 .41957 L .73472 .42055 L F
.789 .699 .765 r
.77694 .4439 m .77763 .44662 L .78114 .4444 L F
.391 .282 .609 r
.78114 .4444 m .78284 .44609 L .78363 .44413 L F
.78114 .4444 m .78284 .44609 L .78363 .44413 L F
.746 .993 .837 r
.41246 .63744 m .41136 .63919 L .41353 .63743 L F
.347 .466 .838 r
.41246 .63744 m .41367 .64074 L .41136 .63919 L F
.765 .764 .852 r
.6249 .43281 m .62215 .43505 L .62562 .43562 L F
.805 .667 .711 r
.62215 .43505 m .62525 .43775 L .62562 .43562 L F
.787 .777 .844 r
.6249 .43281 m .62562 .43562 L .62826 .43286 L F
.696 .778 .915 r
.24795 .55164 m .25177 .55215 L .25008 .55128 L F
.483 .82 .999 r
.25409 .55166 m .25008 .55128 L .25177 .55215 L F
.498 .583 .871 r
.78948 .39984 m .78576 .39704 L .79003 .3985 L F
.161 .271 .73 r
.79081 .39842 m .78948 .39984 L .79003 .3985 L F
.268 .44 .847 r
.79081 .39842 m .79252 .40143 L .78948 .39984 L F
.751 .737 .839 r
.1955 .71071 m .19668 .71312 L .19852 .71094 L F
.884 .943 .847 r
.77207 .39049 m .77053 .3943 L .76969 .3935 L F
.77207 .39049 m .77275 .39167 L .77053 .3943 L F
.994 .873 .559 r
.76969 .3935 m .77053 .3943 L .76936 .39548 L F
.539 .427 .675 r
.60035 .44747 m .60289 .44941 L .60269 .4468 L F
.60035 .44747 m .60061 .45036 L .60289 .44941 L F
.749 .725 .83 r
.42873 .59373 m .43154 .591 L .4286 .59136 L F
.162 0 0 r
.41225 .58596 m .41127 .5872 L .41445 .5852 L F
.556 .87 .995 r
.54214 .59755 m .54452 .59674 L .54573 .59749 L F
.759 .936 .943 r
.54573 .59749 m .54661 .59525 L .54826 .59443 L F
.54573 .59749 m .54452 .59674 L .54661 .59525 L F
.745 .48 .529 r
.52771 .53354 m .53131 .53153 L .52986 .53174 L F
.52771 .53354 m .53087 .53428 L .53131 .53153 L F
.709 .762 .894 r
.42789 .56523 m .42981 .5669 L .43235 .56573 L F
.439 .134 .35 r
.57713 .4713 m .57959 .47074 L .57998 .46874 L F
.466 .135 .32 r
.57959 .47074 m .58309 .46798 L .57998 .46874 L F
.98 .735 .493 r
.64977 .4076 m .65084 .41036 L .6515 .40859 L F
.032 0 .2 r
.6515 .40859 m .65084 .41036 L .65165 .40855 L F
.762 .533 .586 r
.43128 .66275 m .43521 .66034 L .43126 .66 L F
.43128 .66275 m .43502 .66309 L .43521 .66034 L F
0 0 0 r
.22691 .62363 m .22297 .6266 L .22528 .62636 L F
.355 0 .164 r
.22528 .62636 m .22908 .62321 L .22691 .62363 L F
.829 .741 .766 r
.60641 .4648 m .61041 .463 L .60868 .46151 L F
.377 .131 .409 r
.24595 .59725 m .24746 .59897 L .24772 .59651 L F
.24595 .59725 m .24543 .59976 L .24746 .59897 L F
.729 .838 .932 r
.70726 .42793 m .7117 .42726 L .71035 .4257 L F
.753 .789 .883 r
.71035 .4257 m .7117 .42726 L .71387 .42614 L F
.773 .874 .921 r
.68468 .43307 m .67903 .43526 L .68342 .43161 L F
.848 .846 .841 r
.68733 .42995 m .68468 .43307 L .68342 .43161 L F
.719 .675 .806 r
.63287 .41141 m .63679 .41301 L .63533 .41159 L F
.648 .673 .86 r
.63679 .41301 m .63906 .4116 L .63533 .41159 L F
.911 .97 .797 r
.75564 .39993 m .75355 .40299 L .75342 .40085 L F
.948 .952 .653 r
.75342 .40085 m .75355 .40299 L .75247 .40492 L F
0 0 0 r
.49241 .53978 m .49378 .5369 L .49189 .53757 L F
.476 .335 .609 r
.43769 .618 m .43797 .62099 L .43535 .62147 L F
.437 .309 .609 r
.43708 .62345 m .43535 .62147 L .43797 .62099 L F
.43708 .62345 m .43555 .62414 L .43535 .62147 L F
.258 0 0 r
.23358 .53898 m .23527 .53943 L .23692 .53961 L F
.889 .898 .83 r
.2032 .7075 m .20724 .70527 L .20335 .70473 L F
.738 .869 .941 r
.65151 .42867 m .6527 .42993 L .65506 .42848 L F
.65151 .42867 m .6527 .42993 L .65506 .42848 L F
.011 0 .355 r
.58109 .5586 m .58259 .5551 L .58262 .55741 L F
.144 0 .313 r
.58262 .55741 m .58052 .5608 L .58109 .5586 L F
.181 0 0 r
.41499 .63765 m .41246 .63744 L .41353 .63743 L F
.17 0 0 r
.52353 .51521 m .52604 .51468 L .52731 .51342 L F
.506 .126 .254 r
.52604 .51468 m .5295 .51235 L .52731 .51342 L F
.772 .871 .921 r
.70198 .42922 m .70524 .42908 L .70415 .42777 L F
.702 .866 .959 r
.70415 .42777 m .70524 .42908 L .70726 .42793 L F
.984 .783 .555 r
.54108 .57679 m .54156 .57812 L .5402 .57883 L F
.326 .767 .964 r
.53957 .57916 m .5402 .57883 L .54184 .57939 L F
.623 .057 0 r
.54247 .58067 m .54184 .57939 L .5402 .57883 L F
.984 .783 .555 r
.54156 .57812 m .54247 .58067 L .5402 .57883 L F
.326 .767 .964 r
.53806 .57901 m .5402 .57883 L .53957 .57916 L F
.623 .057 0 r
.54247 .58067 m .54433 .58139 L .54184 .57939 L F
.193 .603 .945 r
.21114 .55357 m .21352 .55385 L .21204 .55265 L F
.451 .307 .593 r
.56798 .55548 m .57032 .55477 L .56987 .55213 L F
.352 .166 .483 r
.5681 .55813 m .57032 .55477 L .56798 .55548 L F
.994 .859 .518 r
.76923 .41116 m .76799 .41314 L .76886 .41023 L F
.76923 .41116 m .76863 .41447 L .76799 .41314 L F
.328 .008 .261 r
.18459 .54281 m .18414 .5434 L .18623 .54267 L F
.779 .883 .921 r
.68181 .44018 m .68599 .43905 L .68481 .43767 L F
.832 .892 .884 r
.68599 .43905 m .68777 .43507 L .68481 .43767 L F
.68599 .43905 m .68889 .43626 L .68777 .43507 L F
.301 .135 .482 r
.38942 .60924 m .39109 .60861 L .3912 .60616 L F
.369 .274 .615 r
.38942 .60924 m .39146 .61114 L .39109 .60861 L F
.38942 .60924 m .38932 .6128 L .39146 .61114 L F
.852 .989 .722 r
.54385 .58356 m .54313 .58569 L .54553 .58501 L F
.54385 .58356 m .54141 .58672 L .54313 .58569 L F
.335 .493 .867 r
.66029 .45063 m .66164 .44884 L .65922 .4498 L F
.155 .619 .93 r
.65922 .4498 m .66029 .45063 L .66271 .45071 L F
.343 .799 .672 r
.43841 .63405 m .4383 .634 L .44066 .63282 L F
.43841 .63405 m .43674 .63478 L .4383 .634 L F
.306 .328 .72 r
.39 .61512 m .39065 .61901 L .39235 .61712 L F
.299 .295 .687 r
.39136 .6211 m .39235 .61712 L .39065 .61901 L F
.484 .276 .521 r
.28356 .59043 m .28154 .58842 L .28368 .58775 L F
.28356 .59043 m .28133 .59103 L .28154 .58842 L F
.73 .818 .92 r
.71524 .41564 m .7112 .41597 L .71406 .41404 L F
.671 .81 .95 r
.71765 .41446 m .71524 .41564 L .71406 .41404 L F
.682 .229 .171 r
.50891 .60296 m .51128 .60496 L .51265 .6034 L F
.74 .56 .65 r
.51637 .60636 m .51387 .60437 L .51438 .60398 L F
.51387 .60437 m .51265 .6034 L .51438 .60398 L F
.51637 .60636 m .51308 .60667 L .51265 .6034 L F
.755 .747 .845 r
.51788 .60386 m .51637 .60636 L .51438 .60398 L F
.51788 .60386 m .51438 .60398 L .51716 .60239 L F
.391 .083 .319 r
.51527 .60654 m .51308 .60667 L .51637 .60636 L F
.409 .1 .326 r
.51308 .60667 m .51261 .60844 L .51027 .609 L F
.391 .083 .319 r
.51527 .60654 m .51261 .60844 L .51308 .60667 L F
.744 .669 .777 r
.51289 .6056 m .51261 .60844 L .51527 .60654 L F
.51128 .60496 m .51191 .6066 L .51289 .6056 L F
.51191 .6066 m .51261 .60844 L .51289 .6056 L F
.51128 .60496 m .51339 .60579 L .51295 .60575 L F
.51339 .60579 m .51527 .60654 L .51295 .60575 L F
.416 0 0 r
.51128 .60496 m .51438 .60398 L .51265 .6034 L F
.51128 .60496 m .51295 .60575 L .51438 .60398 L F
.019 .265 .765 r
.5119 .60329 m .51295 .60575 L .51128 .60496 L F
0 0 0 r
.5147 .60373 m .51295 .60575 L .51519 .60336 L F
.51438 .60398 m .51399 .60447 L .5147 .60373 L F
.51399 .60447 m .51295 .60575 L .5147 .60373 L F
.51438 .60398 m .51629 .60217 L .51716 .60239 L F
.51438 .60398 m .51519 .60336 L .51629 .60217 L F
.9 .838 .775 r
.515 .60263 m .51295 .60575 L .51221 .60362 L F
.51629 .60217 m .51221 .60362 L .51262 .60296 L F
.607 .386 .554 r
.51115 .6027 m .51262 .60296 L .5146 .60037 L F
.9 .838 .775 r
.51269 .60288 m .51262 .60296 L .51267 .60289 L F
.51629 .60217 m .51262 .60296 L .51269 .60288 L F
.5161 .60198 m .51317 .60225 L .5146 .60037 L F
.605 .419 .604 r
.51137 .60274 m .51244 .60326 L .51262 .60296 L F
.9 .838 .775 r
.51269 .60288 m .51236 .60295 L .5146 .60037 L F
.51236 .60295 m .512 .60302 L .51233 .60269 L F
.51236 .60295 m .51233 .60269 L .5146 .60037 L F
.51629 .60217 m .51269 .60288 L .51317 .60225 L F
.51629 .60217 m .51317 .60225 L .5161 .60198 L F
.607 .386 .554 r
.51269 .60288 m .51457 .60331 L .5146 .60039 L F
.51262 .60296 m .5146 .60039 L .5146 .60037 L F
.713 .841 .943 r
.51077 .59802 m .51128 .59985 L .51101 .59779 L F
.91 .937 .813 r
.51068 .5981 m .50891 .60296 L .51128 .59985 L F
.826 .401 .231 r
.50891 .60296 m .50519 .60001 L .50639 .6035 L F
.50891 .60296 m .50785 .60309 L .50519 .60001 L F
.91 .937 .813 r
.51068 .5981 m .50785 .60309 L .50891 .60296 L F
.569 .749 .962 r
.51068 .5981 m .51128 .59985 L .51067 .59766 L F
.714 .635 .768 r
.50687 .59788 m .50785 .60309 L .51068 .5981 L F
0 0 0 r
.51062 .59811 m .51126 .59817 L .50861 .59855 L F
.51068 .5981 m .51069 .5981 L .51062 .59811 L F
.51069 .5981 m .51126 .59817 L .51062 .59811 L F
.713 .841 .943 r
.51146 .59797 m .51128 .59985 L .51369 .59884 L F
.51101 .59779 m .51104 .59804 L .51146 .59797 L F
.51104 .59804 m .51128 .59985 L .51146 .59797 L F
.812 .732 .776 r
.51031 .5976 m .51219 .59638 L .51068 .5981 L F
.472 .256 .504 r
.50781 .59628 m .51037 .59752 L .50996 .59443 L F
.51037 .59752 m .51058 .59725 L .50996 .59443 L F
.644 .365 .48 r
.51058 .59725 m .51219 .59638 L .50996 .59443 L F
.51067 .59766 m .51219 .59638 L .51058 .59725 L F
.812 .732 .776 r
.50886 .59564 m .5114 .5962 L .51058 .59725 L F
.5102 .59745 m .51058 .59725 L .51031 .5976 L F
.50886 .59564 m .51058 .59725 L .5102 .59745 L F
.5114 .5962 m .51219 .59638 L .51031 .5976 L F
.472 .256 .504 r
.51037 .59752 m .51067 .59766 L .51058 .59725 L F
.713 .841 .943 r
.51067 .59766 m .51077 .59802 L .51101 .59779 L F
0 0 0 r
.51219 .59638 m .51104 .59776 L .51068 .5981 L F
.713 .841 .943 r
.51067 .59766 m .51101 .59779 L .51219 .59638 L F
.51101 .59779 m .51369 .59884 L .51219 .59638 L F
0 0 0 r
.51219 .59638 m .51187 .597 L .51104 .59776 L F
.51187 .597 m .51126 .59817 L .51069 .5981 L F
.51187 .597 m .51069 .5981 L .51068 .5981 L F
.607 .386 .554 r
.51115 .6027 m .5146 .60037 L .512 .60302 L F
.43 .507 .836 r
.51208 .5986 m .51416 .60173 L .51227 .60234 L F
.51187 .59953 m .51227 .60234 L .51115 .6027 L F
.51208 .5986 m .51227 .60234 L .51187 .59953 L F
.786 .656 .719 r
.51115 .6027 m .50759 .59981 L .51017 .59958 L F
.51115 .6027 m .50858 .60303 L .50759 .59981 L F
.43 .507 .836 r
.51208 .5986 m .51115 .6027 L .51017 .59958 L F
.418 0 0 r
.51416 .60173 m .50998 .60247 L .51029 .60253 L F
.51227 .60234 m .51029 .60253 L .51115 .6027 L F
.51416 .60173 m .51029 .60253 L .51227 .60234 L F
.607 .386 .554 r
.51262 .60296 m .51262 .60296 L .51269 .60288 L F
.51262 .60296 m .51457 .60331 L .51269 .60288 L F
.919 .714 .221 r
.5146 .60038 m .51457 .60331 L .51416 .60173 L F
.5146 .60037 m .5146 .60039 L .5146 .60038 L F
.5146 .60039 m .51457 .60331 L .5146 .60038 L F
.9 .838 .775 r
.51629 .60217 m .51513 .60342 L .515 .60263 L F
.51513 .60342 m .51295 .60575 L .515 .60263 L F
.51267 .60289 m .51221 .60362 L .512 .60302 L F
.605 .419 .604 r
.51137 .60274 m .5119 .60329 L .51244 .60326 L F
.51262 .60296 m .51244 .60326 L .51381 .60317 L F
.51381 .60317 m .51335 .60481 L .51457 .60331 L F
.5119 .60329 m .51335 .60481 L .51381 .60317 L F
.019 .265 .765 r
.51079 .60336 m .51128 .60496 L .50988 .60342 L F
.51134 .60333 m .51181 .60354 L .51079 .60336 L F
.51181 .60354 m .51128 .60496 L .51079 .60336 L F
.566 .572 .818 r
.51027 .609 m .51031 .60884 L .50907 .60825 L F
.51031 .60884 m .51128 .60496 L .50907 .60825 L F
.51027 .609 m .51261 .60844 L .51128 .60496 L F
.192 0 .303 r
.51075 .60737 m .50907 .60825 L .51128 .60496 L F
.458 .861 .965 r
.51075 .60737 m .50767 .60759 L .50907 .60825 L F
.50767 .60759 m .50725 .60762 L .50907 .60825 L F
0 .112 .609 r
.50943 .60301 m .51128 .60496 L .50891 .60296 L F
.667 .455 .588 r
.51054 .60332 m .51115 .6027 L .50938 .60293 L F
0 .112 .609 r
.50948 .60301 m .50977 .60331 L .50943 .60301 L F
.667 .455 .588 r
.50963 .60316 m .50938 .60293 L .50876 .60301 L F
.51054 .60332 m .50938 .60293 L .50963 .60316 L F
0 .112 .609 r
.5095 .60302 m .50963 .60316 L .50948 .60301 L F
.50963 .60316 m .50977 .60331 L .50948 .60301 L F
.607 .954 .861 r
.51115 .6027 m .50998 .60247 L .50946 .60275 L F
0 .112 .609 r
.50977 .60331 m .50989 .60344 L .50943 .60301 L F
.50989 .60344 m .51128 .60496 L .50998 .60359 L F
.50989 .60344 m .50998 .60359 L .50943 .60301 L F
.50942 .60302 m .50891 .60296 L .50785 .60309 L F
.5095 .60302 m .50948 .60301 L .50942 .60302 L F
.50948 .60301 m .50891 .60296 L .50942 .60302 L F
.025 .597 .723 r
.50858 .60303 m .5095 .60302 L .50942 .60302 L F
.50858 .60303 m .50942 .60302 L .50785 .60309 L F
.667 .455 .588 r
.50889 .60307 m .5088 .60303 L .50858 .60303 L F
.5088 .60303 m .50876 .60301 L .50858 .60303 L F
.51054 .60332 m .50906 .60306 L .50889 .60307 L F
.50906 .60306 m .50876 .60301 L .50889 .60307 L F
.50904 .60482 m .51054 .60332 L .50858 .60303 L F
.827 .973 .667 r
.50713 .60422 m .50463 .60773 L .50662 .60479 L F
.388 .39 .74 r
.50662 .60479 m .50904 .60482 L .50858 .60303 L F
.025 .597 .723 r
.50858 .60303 m .50785 .60309 L .50713 .60422 L F
.607 .954 .861 r
.50876 .60301 m .50693 .60414 L .50858 .60303 L F
.409 0 0 r
.51115 .6027 m .5095 .60302 L .50858 .60303 L F
.607 .954 .861 r
.51115 .6027 m .51023 .60301 L .50876 .60301 L F
.388 .39 .74 r
.50662 .60479 m .50858 .60303 L .50713 .60422 L F
.607 .954 .861 r
.51023 .60301 m .50693 .60414 L .50876 .60301 L F
.667 .455 .588 r
.51054 .60332 m .51134 .60333 L .51115 .6027 L F
.019 .265 .765 r
.51221 .60362 m .51295 .60575 L .5119 .60329 L F
.459 .842 .619 r
.51295 .60575 m .51075 .60737 L .51128 .60496 L F
.605 .419 .604 r
.51178 .6033 m .51221 .60621 L .51335 .60481 L F
.51115 .6027 m .51134 .60333 L .51178 .6033 L F
.019 .265 .765 r
.5119 .60329 m .51188 .60334 L .51134 .60333 L F
.51188 .60334 m .51181 .60354 L .51134 .60333 L F
.605 .419 .604 r
.51134 .60333 m .51221 .60621 L .51178 .6033 L F
.019 .265 .765 r
.51079 .60302 m .5119 .60329 L .5095 .60302 L F
.605 .419 .604 r
.51115 .6027 m .51335 .60481 L .51137 .60274 L F
.019 .265 .765 r
.512 .60302 m .512 .60302 L .51079 .60302 L F
.512 .60302 m .5119 .60329 L .51079 .60302 L F
.607 .954 .861 r
.50973 .60318 m .50946 .60275 L .50693 .60414 L F
.51115 .6027 m .50946 .60275 L .50973 .60318 L F
.667 .455 .588 r
.50904 .60482 m .51221 .60621 L .5119 .60518 L F
.51045 .60391 m .5119 .60518 L .51134 .60333 L F
.50904 .60482 m .5119 .60518 L .51045 .60391 L F
.50904 .60482 m .51134 .60333 L .51054 .60332 L F
.019 .265 .765 r
.5119 .60329 m .50988 .60342 L .5095 .60302 L F
.512 .60302 m .51221 .60362 L .5119 .60329 L F
.722 .939 .62 r
.51457 .60331 m .5126 .60572 L .51295 .60575 L F
.5126 .60572 m .51221 .60621 L .51295 .60575 L F
.233 .744 .876 r
.20501 .65099 m .20595 .65064 L .20394 .65117 L F
.20501 .65099 m .20793 .65065 L .20595 .65064 L F
.504 0 0 r
.41761 .65397 m .41619 .65324 L .41383 .65151 L F
.57 .873 .994 r
.41895 .65335 m .41761 .65397 L .41988 .65128 L F
.41895 .65335 m .41619 .65324 L .41761 .65397 L F
.389 .11 .365 r
.44344 .63024 m .44066 .63282 L .4406 .63038 L F
.44066 .63282 m .44344 .63024 L .4406 .63038 L F
.971 .882 .686 r
.41881 .59635 m .41938 .59897 L .42097 .59546 L F
0 0 0 r
.42123 .59556 m .42097 .59546 L .42321 .59355 L F
.42123 .59556 m .41881 .59635 L .42097 .59546 L F
.55 .326 .529 r
.60308 .44469 m .60522 .44615 L .60498 .4437 L F
.60308 .44469 m .60269 .4468 L .60522 .44615 L F
.696 .536 .667 r
.58816 .46241 m .59048 .46263 L .59046 .4596 L F
.58 .442 .658 r
.59046 .4596 m .59331 .46176 L .59316 .45928 L F
.59046 .4596 m .59048 .46263 L .59331 .46176 L F
.5 .287 .522 r
.57199 .54649 m .57437 .54591 L .57457 .54349 L F
.117 0 .42 r
.57587 .53999 m .57457 .54349 L .5759 .54194 L F
0 0 .117 r
.57457 .54349 m .57511 .54409 L .5759 .54194 L F
.57457 .54349 m .57437 .54591 L .57511 .54409 L F
.405 .478 .822 r
.78759 .3949 m .78576 .39704 L .78439 .39368 L F
.454 .55 .865 r
.78759 .3949 m .79003 .3985 L .78576 .39704 L F
.496 .198 .39 r
.60796 .43901 m .60998 .44014 L .61058 .43805 L F
.60796 .43901 m .60751 .44079 L .60998 .44014 L F
.464 .199 .427 r
.57199 .54649 m .5736 .54815 L .57437 .54591 L F
.224 .178 .594 r
.57199 .54649 m .57245 .54915 L .5736 .54815 L F
.625 .449 .623 r
.44252 .61483 m .44012 .61761 L .4403 .61529 L F
.485 .787 .998 r
.44635 .62292 m .44819 .62431 L .44544 .62436 L F
.379 .068 .306 r
.44819 .62431 m .44537 .62689 L .44544 .62436 L F
.472 .476 .78 r
.44537 .62689 m .44635 .62292 L .44544 .62436 L F
.7 .633 .779 r
.19335 .74567 m .19659 .74402 L .19303 .74362 L F
.996 .833 .483 r
.50516 .5747 m .50584 .57645 L .50633 .57356 L F
.751 .664 .765 r
.42668 .62849 m .42074 .62974 L .42156 .62754 L F
.547 .389 .618 r
.5671 .48046 m .56955 .48003 L .56925 .47771 L F
.405 0 .115 r
.56618 .48193 m .56955 .48003 L .5671 .48046 L F
.243 .052 .411 r
.43063 .64192 m .4321 .64383 L .43285 .64159 L F
.43063 .64192 m .43092 .6449 L .4321 .64383 L F
.413 .108 .335 r
.24265 .63931 m .24197 .6419 L .23957 .64237 L F
.129 0 .223 r
.24361 .64076 m .24265 .63931 L .24469 .6387 L F
.24361 .64076 m .24197 .6419 L .24265 .63931 L F
.591 .022 0 r
.41122 .64795 m .41178 .64852 L .40895 .6469 L F
.883 .828 .788 r
.75616 .43016 m .75837 .42682 L .75695 .42553 L F
.948 .831 .695 r
.75837 .42682 m .75784 .42329 L .75695 .42553 L F
.765 .629 .709 r
.24681 .55609 m .24936 .55545 L .24546 .555 L F
.874 .578 .484 r
.58824 .50109 m .58618 .50305 L .58581 .50087 L F
.58824 .50109 m .58866 .50327 L .58618 .50305 L F
.202 .728 .84 r
.43109 .56314 m .43378 .56301 L .43552 .56187 L F
0 0 0 r
.43709 .56085 m .43378 .56301 L .43552 .56187 L F
.43709 .56085 m .43378 .56301 L .43552 .56187 L F
.457 .431 .741 r
.40123 .6367 m .40293 .6364 L .40237 .63252 L F
.489 0 0 r
.28497 .57695 m .28831 .57938 L .28911 .57977 L F
.942 .963 .704 r
.2885 .57876 m .28831 .57938 L .28911 .57977 L F
.428 .401 .727 r
.28838 .57914 m .28851 .57953 L .28831 .57938 L F
.28838 .57914 m .28831 .57938 L .28497 .57695 L F
.942 .963 .704 r
.2885 .57876 m .28816 .57931 L .28831 .57938 L F
0 0 0 r
.28911 .57977 m .2871 .58108 L .28544 .58191 L F
.942 .963 .704 r
.28816 .57931 m .2871 .58108 L .28911 .57977 L F
.489 0 0 r
.28831 .57938 m .28851 .57953 L .28911 .57977 L F
.696 .56 .697 r
.28898 .57795 m .28851 .57953 L .2868 .57424 L F
.448 .212 .461 r
.28933 .58038 m .2871 .58108 L .2885 .57876 L F
.942 .963 .704 r
.28898 .57795 m .2885 .57876 L .28911 .57977 L F
.946 .911 .534 r
.28911 .57977 m .28851 .57953 L .28898 .57795 L F
.448 .212 .461 r
.28911 .57883 m .2885 .57876 L .28898 .57795 L F
.28933 .58038 m .2885 .57876 L .28911 .57883 L F
.428 .401 .727 r
.2868 .57424 m .28825 .57873 L .28497 .57695 L F
.28825 .57873 m .28838 .57914 L .28764 .57866 L F
.28825 .57873 m .28764 .57866 L .28497 .57695 L F
.946 .911 .534 r
.28911 .57977 m .28898 .57795 L .29121 .57891 L F
.942 .963 .704 r
.28898 .57795 m .28911 .57977 L .29121 .57891 L F
.985 .834 .445 r
.76818 .41994 m .76722 .42134 L .76783 .41929 L F
.76818 .41994 m .76779 .42364 L .76722 .42134 L F
.246 .215 .625 r
.41919 .61073 m .4172 .60919 L .41929 .60871 L F
.81 .928 .912 r
.7739 .39058 m .77275 .39167 L .77207 .39049 L F
.209 0 .133 r
.55877 .48638 m .56027 .48752 L .56095 .48491 L F
.55877 .48638 m .55812 .48849 L .56027 .48752 L F
.388 .299 .633 r
.65351 .40558 m .65575 .40494 L .65537 .40172 L F
.443 .5 .823 r
.65351 .40558 m .65665 .40632 L .65575 .40494 L F
.316 .001 .263 r
.71294 .39329 m .71071 .39616 L .71253 .39498 L F
.145 0 .17 r
.71563 .39044 m .71294 .39329 L .71532 .39238 L F
.083 0 .046 r
.71489 .39368 m .71294 .39329 L .71253 .39498 L F
.71489 .39368 m .71532 .39238 L .71294 .39329 L F
.485 .465 .76 r
.53558 .56941 m .53667 .57469 L .53471 .57333 L F
.518 .462 .733 r
.53667 .57469 m .53722 .57516 L .53471 .57333 L F
.7 .972 .755 r
.54826 .59443 m .54661 .59525 L .54947 .59242 L F
.277 .01 .316 r
.55103 .49282 m .55063 .49484 L .55314 .49185 L F
.295 0 0 r
.23991 .55436 m .23493 .55732 L .23603 .55477 L F
.23991 .55436 m .23732 .5571 L .23493 .55732 L F
.656 .888 .536 r
.24182 .55184 m .24022 .55356 L .23991 .55436 L F
.193 0 0 r
.23977 .55623 m .23991 .55436 L .24022 .55356 L F
.23977 .55623 m .23732 .5571 L .23991 .55436 L F
.233 .072 .446 r
.57573 .57867 m .57546 .58129 L .57305 .58262 L F
.202 .014 .389 r
.57305 .58262 m .57528 .58339 L .57384 .58505 L F
.57305 .58262 m .57546 .58129 L .57528 .58339 L F
.705 .33 .335 r
.61744 .43012 m .62075 .42903 L .6183 .42978 L F
.992 .834 .583 r
.59774 .51219 m .59962 .51084 L .5989 .50897 L F
.59774 .51219 m .59889 .51332 L .59962 .51084 L F
.335 .503 .876 r
.41383 .65151 m .41557 .65027 L .41178 .64852 L F
.247 .332 .754 r
.41383 .65151 m .41619 .65324 L .41557 .65027 L F
.805 .667 .711 r
.62215 .43505 m .62229 .43752 L .62525 .43775 L F
.807 .644 .68 r
.62229 .43752 m .62346 .43887 L .62525 .43775 L F
0 0 .364 r
.45859 .57023 m .4594 .57195 L .45816 .56898 L F
.45859 .57023 m .45885 .57306 L .4594 .57195 L F
.794 .676 .734 r
.19478 .72583 m .19604 .72909 L .19281 .72838 L F
.176 0 0 r
.19399 .73026 m .19604 .72909 L .19411 .73019 L F
.19422 .73014 m .19604 .72909 L .19399 .73026 L F
.19244 .73117 m .19474 .73036 L .19604 .72909 L F
.791 .435 .384 r
.19604 .72909 m .19474 .73036 L .19281 .72838 L F
.788 .964 .654 r
.19478 .72583 m .19281 .72838 L .19279 .72762 L F
0 .176 .705 r
.19281 .72838 m .19442 .73003 L .19279 .72762 L F
.19442 .73003 m .19474 .73036 L .19449 .73 L F
.19442 .73003 m .19449 .73 L .19279 .72762 L F
.176 0 0 r
.19244 .73117 m .19422 .73014 L .19399 .73026 L F
.227 .112 .507 r
.57399 .58756 m .57411 .59011 L .57186 .59135 L F
.065 0 .373 r
.57411 .59011 m .57198 .5935 L .57186 .59135 L F
.494 .821 1 r
.41491 .64485 m .41724 .64436 L .41818 .64525 L F
.994 .763 .403 r
.41724 .64436 m .41796 .64811 L .41818 .64525 L F
.478 .044 .135 r
.57003 .49617 m .57257 .49711 L .57018 .49691 L F
0 0 .35 r
.50639 .6035 m .50785 .60309 L .50891 .60296 L F
.50639 .6035 m .50713 .60422 L .50785 .60309 L F
.509 .257 .469 r
.4573 .59683 m .46018 .59408 L .45754 .59451 L F
.413 .315 .635 r
.40347 .61832 m .40564 .62014 L .4056 .61741 L F
.4056 .61741 m .40564 .62014 L .40347 .61832 L F
.516 .55 .829 r
.25409 .55166 m .25619 .55565 L .25771 .55481 L F
.338 .151 .473 r
.25619 .55565 m .25749 .5573 L .25771 .55481 L F
.25619 .55565 m .2553 .55867 L .25749 .5573 L F
.54 .364 .591 r
.27712 .59984 m .2749 .60266 L .2748 .60027 L F
.451 .358 .66 r
.28531 .56641 m .28558 .57058 L .28372 .57083 L F
.447 .334 .633 r
.28558 .57058 m .28603 .57245 L .28372 .57083 L F
.962 .87 .699 r
.60162 .4977 m .60431 .49533 L .60314 .49374 L F
.60162 .4977 m .60307 .49865 L .60431 .49533 L F
.972 .929 .653 r
.76156 .40656 m .76201 .40826 L .76316 .40572 L F
.874 .987 .719 r
.76156 .40656 m .76316 .40572 L .76394 .40295 L F
.454 .203 .443 r
.40845 .61235 m .40799 .61468 L .40583 .61519 L F
.40845 .61235 m .40799 .61468 L .40583 .61519 L F
.541 .281 .47 r
.40845 .61235 m .41126 .61465 L .40799 .61468 L F
.439 .491 .816 r
.26096 .56693 m .26294 .56607 L .25996 .56441 L F
.36 .069 .328 r
.26096 .56693 m .2624 .56884 L .26294 .56607 L F
.26096 .56693 m .26031 .56955 L .2624 .56884 L F
.534 .413 .661 r
.2791 .59663 m .27712 .59984 L .27733 .59736 L F
0 0 0 r
.66538 .45182 m .66666 .45118 L .66899 .45024 L F
.801 .818 .865 r
.43471 .56895 m .43364 .57054 L .43615 .56787 L F
0 0 .422 r
.43471 .56895 m .4347 .56906 L .43364 .57054 L F
.695 .605 .752 r
.43495 .56881 m .43479 .56897 L .43471 .56895 L F
.818 .858 .878 r
.43542 .56866 m .43453 .56959 L .43493 .5689 L F
.722 .525 .624 r
.43964 .57263 m .43476 .56898 L .43951 .57017 L F
.43476 .56898 m .43471 .56895 L .43479 .56897 L F
.43476 .56898 m .43479 .56897 L .43951 .57017 L F
.818 .858 .878 r
.43615 .56787 m .43542 .56866 L .4354 .56807 L F
.43542 .56866 m .43493 .5689 L .4354 .56807 L F
.43453 .56959 m .43364 .57054 L .4347 .56906 L F
.43453 .56959 m .43475 .56899 L .43493 .56889 L F
.722 .525 .624 r
.43964 .57263 m .43486 .57412 L .43499 .57321 L F
.4368 .57055 m .43499 .57321 L .43551 .56959 L F
.43964 .57263 m .43499 .57321 L .4368 .57055 L F
.317 .041 .327 r
.43499 .57321 m .43426 .57231 L .43486 .57412 L F
.43499 .57321 m .43483 .57341 L .43426 .57231 L F
0 0 .422 r
.4347 .56906 m .43484 .57342 L .43426 .57231 L F
.43484 .57342 m .43486 .57412 L .43426 .57231 L F
.317 .041 .327 r
.43483 .57341 m .43339 .57524 L .43426 .57231 L F
.469 0 .048 r
.43964 .57263 m .43573 .57411 L .43486 .57412 L F
.317 .041 .327 r
.43573 .57411 m .43499 .57321 L .43486 .57412 L F
.4337 .57509 m .43339 .57524 L .43483 .57341 L F
.43484 .57343 m .43483 .57341 L .43499 .57321 L F
.4337 .57509 m .43483 .57341 L .43484 .57343 L F
0 0 .422 r
.43471 .56901 m .43484 .57343 L .4347 .56906 L F
.43484 .57343 m .43486 .57412 L .43484 .57342 L F
.43484 .57343 m .43484 .57342 L .4347 .56906 L F
.722 .525 .624 r
.43551 .56959 m .43486 .57412 L .43471 .56901 L F
.317 .041 .327 r
.43573 .57411 m .4337 .57509 L .43499 .57321 L F
.722 .525 .624 r
.43476 .56898 m .43471 .56901 L .43471 .56895 L F
.43964 .57263 m .43471 .56901 L .43476 .56898 L F
.818 .858 .878 r
.43453 .56959 m .4347 .56906 L .43475 .56899 L F
.43493 .56889 m .43475 .56899 L .4354 .56807 L F
0 0 .422 r
.43471 .56895 m .43471 .56901 L .4347 .56906 L F
.695 .605 .752 r
.43837 .5668 m .43951 .57017 L .43479 .56897 L F
.43837 .5668 m .43479 .56897 L .43495 .56881 L F
.818 .858 .878 r
.4354 .56807 m .43471 .56904 L .43223 .56891 L F
.43471 .56904 m .43364 .57054 L .43342 .57028 L F
.43471 .56904 m .43342 .57028 L .43223 .56891 L F
0 0 .422 r
.4347 .56906 m .43426 .57231 L .43364 .57054 L F
.611 .18 .199 r
.51923 .60614 m .51527 .60654 L .51637 .60636 L F
.578 .51 .743 r
.51788 .60386 m .51923 .60614 L .51637 .60636 L F
.911 .97 .797 r
.75564 .39993 m .75342 .40085 L .75395 .39857 L F
.82 .689 .719 r
.58645 .49577 m .58566 .49846 L .58449 .49483 L F
.261 .24 .646 r
.57695 .57427 m .57462 .57354 L .57635 .57232 L F
.57695 .57427 m .57541 .57602 L .57462 .57354 L F
.979 .903 .567 r
.65535 .41655 m .65589 .41752 L .65504 .41971 L F
.476 .848 .612 r
.45439 .56801 m .45303 .56892 L .45185 .56993 L F
.392 0 0 r
.45677 .56882 m .45303 .56892 L .45439 .56801 L F
.417 0 .076 r
.45786 .56731 m .45677 .56882 L .45439 .56801 L F
.367 0 0 r
.21738 .55211 m .2154 .55403 L .21352 .55385 L F
.121 0 0 r
.21963 .55148 m .2154 .55403 L .21738 .55211 L F
.466 0 0 r
.50376 .57232 m .50223 .571 L .50079 .56998 L F
.50376 .57232 m .50592 .57232 L .50223 .571 L F
.941 .778 .652 r
.47416 .58282 m .47365 .58413 L .47302 .58227 L F
.588 .291 .432 r
.56399 .49536 m .56643 .49733 L .56395 .49732 L F
.392 .426 .777 r
.74268 .42594 m .74355 .4222 L .74134 .42234 L F
.74268 .42594 m .74459 .42624 L .74355 .4222 L F
0 0 0 r
.1983 .54125 m .20049 .54084 L .20236 .54015 L F
.108 0 0 r
.20049 .54084 m .20473 .53995 L .20236 .54015 L F
.558 .301 .482 r
.70994 .40503 m .71292 .40736 L .7094 .40788 L F
.70994 .40503 m .71243 .4049 L .71292 .40736 L F
.038 0 0 r
.71832 .3891 m .71563 .39044 L .7179 .38964 L F
.164 0 .167 r
.7179 .38964 m .71563 .39044 L .71532 .39238 L F
.638 .804 .963 r
.43364 .57054 m .42983 .57018 L .43223 .56891 L F
.653 .193 .148 r
.42983 .57018 m .43217 .572 L .43364 .57054 L F
.809 .724 .77 r
.61473 .44661 m .61237 .44959 L .61588 .45006 L F
.808 .726 .774 r
.61237 .44959 m .61355 .45317 L .61588 .45006 L F
.784 .711 .783 r
.61473 .44661 m .61588 .45006 L .61652 .44788 L F
.892 .903 .828 r
.41855 .65036 m .41988 .65128 L .41951 .65032 L F
.57 .873 .994 r
.41895 .65335 m .41988 .65128 L .41855 .65036 L F
.317 .247 .619 r
.23441 .6152 m .2364 .61717 L .23567 .61487 L F
.373 .253 .586 r
.23441 .6152 m .23472 .61739 L .2364 .61717 L F
.607 .309 .438 r
.44369 .58859 m .44341 .59061 L .43949 .59073 L F
.515 .229 .418 r
.446 .59008 m .44341 .59061 L .44369 .58859 L F
.704 .651 .795 r
.72615 .41113 m .7273 .41469 L .72353 .41397 L F
.608 .595 .812 r
.72986 .41396 m .7273 .41469 L .72615 .41113 L F
.403 .228 .526 r
.27264 .60864 m .27039 .61159 L .27053 .60951 L F
.72 .758 .883 r
.71985 .41326 m .72121 .41492 L .71765 .41446 L F
.726 .76 .879 r
.72353 .41397 m .72121 .41492 L .71985 .41326 L F
.699 .567 .703 r
.42191 .57604 m .42655 .57704 L .42437 .57294 L F
.738 .487 .549 r
.42191 .57604 m .42496 .57882 L .42655 .57704 L F
.639 .542 .729 r
.42437 .57294 m .42655 .57704 L .42754 .57439 L F
.918 .876 .779 r
.42655 .57704 m .42496 .57882 L .42754 .57439 L F
.892 .828 .777 r
.42754 .57439 m .42496 .57882 L .42677 .57934 L F
0 .126 .675 r
.42496 .57882 m .42664 .58215 L .42677 .57934 L F
.774 .77 .849 r
.69641 .42195 m .69793 .42352 L .69448 .42323 L F
.783 .771 .842 r
.7006 .42053 m .69793 .42352 L .69641 .42195 L F
.759 .782 .872 r
.70682 .41867 m .70268 .41942 L .70551 .41702 L F
.748 .801 .895 r
.70551 .41702 m .70897 .41735 L .70682 .41867 L F
.593 .599 .827 r
.18704 .6309 m .18375 .62811 L .18646 .62896 L F
.368 .519 .877 r
.1882 .62899 m .18704 .6309 L .18646 .62896 L F
.27 .39 .801 r
.1882 .62899 m .18977 .63269 L .18704 .6309 L F
.333 .171 .507 r
.28796 .58335 m .28544 .58191 L .2871 .58108 L F
.28796 .58335 m .28559 .58502 L .28544 .58191 L F
.592 .446 .652 r
.41459 .61478 m .41775 .61693 L .41826 .61541 L F
.392 .335 .674 r
.41775 .61693 m .42053 .61724 L .41826 .61541 L F
.566 .393 .606 r
.41826 .61541 m .42097 .61505 L .42076 .61223 L F
.526 .261 .455 r
.41826 .61541 m .42053 .61724 L .42097 .61505 L F
.636 .629 .827 r
.21315 .65986 m .21694 .66141 L .21482 .66041 L F
0 .473 .735 r
.24528 .53937 m .2473 .5398 L .24922 .54029 L F
.416 .799 .991 r
.2473 .5398 m .25132 .5401 L .24922 .54029 L F
.631 .11 0 r
.50955 .58192 m .51185 .58388 L .51097 .5825 L F
0 0 0 r
.22373 .65727 m .22317 .65912 L .22588 .65623 L F
.382 .123 .391 r
.23356 .61832 m .23382 .62062 L .23472 .61739 L F
.23356 .61832 m .23194 .62176 L .23382 .62062 L F
.903 .583 .43 r
.21338 .65627 m .21544 .65578 L .21113 .6567 L F
.391 .204 .503 r
.21544 .65578 m .21338 .65627 L .21113 .6567 L F
.408 .159 .422 r
.26066 .62173 m .26021 .62373 L .25827 .62424 L F
.456 .248 .508 r
.26009 .6266 m .25827 .62424 L .26021 .62373 L F
.26009 .6266 m .25794 .62741 L .25827 .62424 L F
.932 .653 .488 r
.7937 .43212 m .79244 .43364 L .79239 .43196 L F
.7937 .43212 m .79349 .4347 L .79244 .43364 L F
.607 .349 .5 r
.79635 .43426 m .7937 .43212 L .79641 .4322 L F
.79635 .43426 m .79349 .4347 L .7937 .43212 L F
.546 .42 .66 r
.2749 .60266 m .27519 .60588 L .27291 .60635 L F
.501 .272 .498 r
.27497 .60784 m .27291 .60635 L .27519 .60588 L F
.27497 .60784 m .27264 .60864 L .27291 .60635 L F
.4 .152 .418 r
.44189 .65152 m .44446 .64829 L .44453 .6509 L F
.44446 .64829 m .44189 .65152 L .44453 .6509 L F
.819 .707 .74 r
.42084 .64187 m .41753 .64177 L .41966 .6387 L F
.698 .255 .194 r
.42084 .64187 m .41953 .64373 L .41753 .64177 L F
.024 0 0 r
.4229 .64036 m .42084 .64187 L .41966 .6387 L F
.4229 .64036 m .42248 .6415 L .42084 .64187 L F
.607 .326 .465 r
.42248 .6415 m .41953 .64373 L .42084 .64187 L F
.83 .627 .077 r
.49057 .60531 m .49091 .60736 L .49065 .60377 L F
.48 .096 .234 r
.1777 .56073 m .17384 .56324 L .17572 .56105 L F
.753 .789 .883 r
.71035 .4257 m .71387 .42614 L .71267 .42479 L F
.736 .821 .917 r
.71267 .42479 m .71387 .42614 L .71694 .42376 L F
.78 .308 .118 r
.73708 .38764 m .73284 .38466 L .7332 .38686 L F
.861 .884 .852 r
.65759 .42767 m .66098 .42587 L .66005 .42537 L F
.995 .862 .583 r
.66049 .42285 m .66098 .42587 L .66317 .42335 L F
.66049 .42285 m .66005 .42537 L .66098 .42587 L F
.583 .29 .437 r
.60531 .44173 m .60752 .44335 L .60751 .44079 L F
.60531 .44173 m .60498 .4437 L .60752 .44335 L F
.45 0 0 r
.65962 .40551 m .6587 .40675 L .65665 .40632 L F
0 0 0 r
.66077 .40584 m .65962 .40551 L .66165 .40356 L F
.66077 .40584 m .6587 .40675 L .65962 .40551 L F
.484 .25 .482 r
.26293 .62109 m .26021 .62373 L .26066 .62173 L F
.443 .218 .476 r
.42659 .62965 m .42668 .62849 L .42806 .62768 L F
.175 0 0 r
.67231 .40412 m .67167 .40434 L .6684 .40422 L F
.538 .092 .14 r
.67167 .40434 m .67132 .40536 L .6684 .40422 L F
0 0 .56 r
.67072 .40247 m .67114 .40453 L .67167 .40434 L F
.67114 .40453 m .67132 .40536 L .67167 .40434 L F
.175 0 0 r
.67233 .40412 m .67167 .40434 L .67231 .40412 L F
.975 .73 .312 r
.67143 .40158 m .67233 .40412 L .67429 .40243 L F
.67143 .40158 m .67167 .40434 L .67233 .40412 L F
.155 .692 .699 r
.18446 .55897 m .18241 .55939 L .17979 .55995 L F
.581 .08 .031 r
.18681 .55876 m .18241 .55939 L .18446 .55897 L F
.81 .727 .773 r
.61237 .44959 m .61002 .45268 L .61355 .45317 L F
.817 .706 .742 r
.61002 .45268 m .61128 .45626 L .61355 .45317 L F
.321 0 .186 r
.70739 .40052 m .70539 .39998 L .70498 .40094 L F
.70739 .40052 m .70789 .39914 L .70539 .39998 L F
.735 .834 .926 r
.73805 .39537 m .73565 .39639 L .73448 .39485 L F
0 .176 .683 r
.73565 .39639 m .73736 .39724 L .73448 .39485 L F
.73565 .39639 m .73852 .39871 L .73736 .39724 L F
.177 0 .227 r
.78931 .44373 m .7898 .44204 L .79188 .44078 L F
.79 .631 .683 r
.74953 .37342 m .74717 .37394 L .74798 .37278 L F
.74953 .37342 m .74997 .37619 L .74717 .37394 L F
.405 0 0 r
.75017 .37372 m .74953 .37342 L .74798 .37278 L F
.75182 .37443 m .75283 .37309 L .74953 .37342 L F
.75182 .37443 m .75042 .37381 L .75017 .37372 L F
.75042 .37381 m .74953 .37342 L .75017 .37372 L F
.203 .47 .887 r
.75087 .37246 m .75182 .37443 L .74798 .37278 L F
.318 .092 .405 r
.75087 .37346 m .74798 .37278 L .74717 .37394 L F
.74857 .37358 m .74717 .37394 L .74548 .37373 L F
.709 .184 0 r
.74717 .37394 m .74781 .3751 L .74548 .37373 L F
.74781 .3751 m .74849 .37632 L .74666 .37475 L F
.74781 .3751 m .74666 .37475 L .74548 .37373 L F
.203 .47 .887 r
.75087 .37246 m .74798 .37278 L .75087 .37346 L F
.567 .73 .952 r
.74793 .37152 m .75087 .37346 L .74548 .37373 L F
.74793 .37152 m .74578 .37345 L .74674 .3735 L F
.74578 .37345 m .74548 .37373 L .74674 .3735 L F
.681 .357 .42 r
.74586 .37495 m .74548 .37373 L .74165 .37393 L F
.576 .129 .154 r
.74165 .37393 m .74548 .37373 L .74504 .37446 L F
.502 .673 .941 r
.74452 .37438 m .74586 .37495 L .74165 .37393 L F
.576 .129 .154 r
.74165 .37393 m .74504 .37446 L .74446 .37542 L F
.502 .673 .941 r
.74219 .37339 m .74452 .37438 L .74165 .37393 L F
.734 .31 .241 r
.74548 .37373 m .74733 .37532 L .74602 .37483 L F
.502 .673 .941 r
.74582 .37475 m .74586 .37495 L .74219 .37339 L F
.567 .73 .952 r
.74598 .37475 m .74548 .37373 L .74586 .37495 L F
.734 .31 .241 r
.74486 .37476 m .74654 .37588 L .74446 .37542 L F
.74548 .37373 m .74598 .37475 L .74486 .37476 L F
.789 .864 .904 r
.74598 .37475 m .74586 .37495 L .74582 .37475 L F
.734 .31 .241 r
.74598 .37475 m .74654 .37588 L .74486 .37476 L F
.567 .73 .952 r
.74674 .3735 m .74548 .37373 L .74598 .37475 L F
.789 .864 .904 r
.74609 .37458 m .74598 .37475 L .74575 .37447 L F
.74598 .37475 m .74582 .37475 L .74575 .37447 L F
.502 .673 .941 r
.74473 .37083 m .74582 .37475 L .74219 .37339 L F
.74491 .37086 m .74582 .37475 L .74473 .37083 L F
.789 .864 .904 r
.74793 .37152 m .74674 .3735 L .74487 .37069 L F
.74674 .3735 m .74551 .37344 L .74487 .37069 L F
.672 .748 .908 r
.75087 .37246 m .75087 .37346 L .74793 .37152 L F
.789 .864 .904 r
.74793 .37152 m .74487 .37069 L .74608 .37053 L F
0 .248 .634 r
.74608 .37053 m .74944 .37231 L .74793 .37152 L F
.672 .748 .908 r
.75087 .37246 m .74793 .37152 L .74944 .37231 L F
0 .276 .665 r
.74916 .37207 m .74944 .37231 L .74608 .37053 L F
.57 .164 .233 r
.74916 .37207 m .74731 .37114 L .74498 .37241 L F
.74731 .37114 m .74608 .37053 L .74582 .37096 L F
.74731 .37114 m .74582 .37096 L .74498 .37241 L F
.502 .673 .941 r
.74487 .37069 m .74491 .37086 L .74473 .37083 L F
.734 .31 .241 r
.74602 .37483 m .74849 .37632 L .74654 .37588 L F
.74733 .37532 m .74849 .37632 L .74602 .37483 L F
.789 .864 .904 r
.74674 .3735 m .74609 .37458 L .74551 .37344 L F
.74609 .37458 m .74575 .37447 L .74551 .37344 L F
.318 .092 .405 r
.74964 .37353 m .74917 .3736 L .74857 .37358 L F
.74917 .3736 m .74717 .37394 L .74857 .37358 L F
.75087 .37346 m .74983 .3736 L .74964 .37353 L F
.74983 .3736 m .74717 .37394 L .74964 .37353 L F
.445 0 .071 r
.47956 .61192 m .47566 .61379 L .47704 .61199 L F
.411 .347 .675 r
.2862 .55701 m .28475 .56154 L .2839 .55746 L F
.2862 .55701 m .28661 .56153 L .28475 .56154 L F
.411 .344 .672 r
.28661 .56153 m .2871 .56342 L .28475 .56154 L F
.361 .344 .705 r
.28475 .56154 m .2871 .56342 L .28552 .56386 L F
.631 .11 0 r
.50955 .58192 m .51128 .58387 L .51185 .58388 L F
.853 .403 .008 r
.51128 .58387 m .51373 .5867 L .51185 .58388 L F
.604 .806 .977 r
.50014 .59357 m .50303 .59459 L .50424 .59391 L F
.425 0 0 r
.51004 .55326 m .51026 .55368 L .50845 .55204 L F
.51004 .55326 m .5122 .55451 L .51026 .55368 L F
.52 .538 .815 r
.517 .59512 m .51625 .59831 L .51648 .59636 L F
.51625 .59831 m .51611 .59887 L .51648 .59636 L F
.978 .768 .351 r
.51648 .59636 m .51717 .59736 L .51672 .5944 L F
.51648 .59636 m .51672 .5944 L .51664 .59385 L F
.664 .395 .504 r
.44307 .57991 m .44483 .58139 L .44483 .57941 L F
.656 .427 .56 r
.44483 .58139 m .44732 .57876 L .44483 .57941 L F
.517 .251 .45 r
.39352 .60307 m .39593 .60268 L .39622 .60049 L F
.523 .255 .451 r
.39593 .60268 m .39851 .60007 L .39622 .60049 L F
.228 0 0 r
.74576 .41545 m .7485 .41615 L .74769 .41566 L F
.922 .929 .795 r
.7485 .41615 m .7464 .41719 L .74769 .41566 L F
.19 0 .213 r
.54612 .49879 m .54544 .50058 L .54806 .49776 L F
.611 .899 .987 r
.76893 .40545 m .77145 .40456 L .77049 .40365 L F
.671 .774 .927 r
.76893 .40545 m .77145 .40456 L .76973 .40816 L F
.435 .222 .489 r
.61013 .43538 m .61244 .43477 L .6127 .43245 L F
.238 .056 .42 r
.61058 .43805 m .61244 .43477 L .61013 .43538 L F
.393 0 .076 r
.19037 .74403 m .19159 .74388 L .19052 .74386 L F
0 .129 .589 r
.19303 .74362 m .19052 .74386 L .19159 .74388 L F
0 0 .163 r
.58835 .54216 m .58744 .54355 L .58876 .54008 L F
0 0 .187 r
.58702 .54587 m .58744 .54355 L .58835 .54216 L F
.76 .432 .43 r
.20891 .68986 m .2132 .69028 L .21032 .69166 L F
.74 .859 .936 r
.21173 .68874 m .2132 .69028 L .2149 .68872 L F
.907 .873 .792 r
.21032 .69166 m .2132 .69028 L .21173 .68874 L F
.848 .846 .841 r
.68733 .42995 m .68342 .43161 L .68596 .42863 L F
.843 .845 .846 r
.68981 .42715 m .68733 .42995 L .68596 .42863 L F
.899 .633 .526 r
.58566 .49846 m .58258 .49445 L .58449 .49483 L F
.58566 .49846 m .58273 .49761 L .58258 .49445 L F
.818 .54 .519 r
.58566 .49846 m .58241 .50014 L .58273 .49761 L F
.58566 .49846 m .58581 .50087 L .58241 .50014 L F
.886 .703 .648 r
.60549 .47381 m .60698 .47744 L .60757 .4749 L F
.214 .646 .953 r
.18685 .62297 m .18901 .62427 L .18674 .62385 L F
.18685 .62297 m .18901 .62427 L .18674 .62385 L F
.482 0 0 r
.74902 .37543 m .74997 .37619 L .74917 .3756 L F
.559 .83 .996 r
.74997 .37619 m .75182 .37443 L .74917 .3756 L F
0 0 0 r
.74936 .37583 m .74917 .3756 L .75182 .37443 L F
.74849 .37632 m .74917 .3756 L .74936 .37583 L F
.482 0 0 r
.74717 .37394 m .74902 .37543 L .74917 .3756 L F
.559 .83 .996 r
.74997 .37619 m .75255 .37552 L .75182 .37443 L F
.983 .9 .577 r
.64999 .41413 m .65165 .40855 L .65084 .41036 L F
.655 .524 .692 r
.60036 .45253 m .60289 .44941 L .60061 .45036 L F
.547 .527 .785 r
.46078 .58465 m .4568 .58174 L .46126 .58259 L F
.727 .545 .645 r
.46078 .58465 m .46402 .582 L .46126 .58259 L F
0 0 .099 r
.46256 .58111 m .46078 .58465 L .46126 .58259 L F
0 .348 .701 r
.55488 .59466 m .55646 .5954 L .55416 .59449 L F
.163 0 .22 r
.23852 .6114 m .23687 .61247 L .23567 .61487 L F
.672 .434 .552 r
.70137 .40848 m .70404 .4108 L .70159 .41083 L F
.70137 .40848 m .70394 .40845 L .70404 .4108 L F
.625 .576 .779 r
.44457 .56668 m .44094 .56363 L .44472 .56421 L F
.618 .112 .026 r
.44278 .59998 m .43843 .59992 L .44014 .60321 L F
.44278 .59998 m .44104 .60142 L .43843 .59992 L F
.692 .551 .69 r
.44278 .59998 m .44014 .60321 L .44332 .60201 L F
0 0 0 r
.44323 .6002 m .44278 .59998 L .44682 .59773 L F
.44323 .6002 m .44104 .60142 L .44278 .59998 L F
.757 .778 .87 r
.75251 .42971 m .75616 .43016 L .75457 .42856 L F
.883 .828 .788 r
.75616 .43016 m .75695 .42553 L .75457 .42856 L F
.818 .729 .767 r
.78342 .41103 m .7808 .41441 L .78284 .41487 L F
.78342 .41103 m .78284 .41487 L .78316 .41467 L F
.838 .845 .851 r
.77965 .41691 m .78314 .41494 L .7808 .41441 L F
.207 .234 .669 r
.78342 .41103 m .78516 .4134 L .78399 .4135 L F
.285 .261 .656 r
.78395 .41345 m .78516 .4134 L .78448 .41248 L F
.377 .825 .705 r
.78458 .41302 m .78405 .41345 L .78516 .4134 L F
.78405 .41345 m .78399 .4135 L .78516 .4134 L F
.285 .261 .656 r
.78314 .41494 m .78516 .4134 L .78395 .41345 L F
.72 .577 .694 r
.78399 .4135 m .78376 .41356 L .78342 .41103 L F
.285 .261 .656 r
.78316 .41467 m .78376 .41368 L .78342 .41103 L F
.391 .834 .713 r
.78399 .4135 m .78376 .41368 L .78376 .41356 L F
.285 .261 .656 r
.78376 .41368 m .78377 .41366 L .78376 .41356 L F
.391 .834 .713 r
.78376 .41356 m .77965 .41691 L .7808 .41441 L F
.78382 .41357 m .78003 .41523 L .77924 .41568 L F
.78399 .4135 m .78385 .41356 L .78382 .41357 L F
.285 .261 .656 r
.78377 .4136 m .78448 .41248 L .78342 .41103 L F
.78377 .41366 m .78382 .41357 L .78377 .4136 L F
.78382 .41357 m .78448 .41248 L .78377 .4136 L F
.78375 .41361 m .78376 .41356 L .78342 .41103 L F
.78376 .41361 m .78376 .41356 L .78375 .41361 L F
.72 .577 .694 r
.78376 .41356 m .7808 .41441 L .78342 .41103 L F
.391 .834 .713 r
.78399 .4135 m .78382 .41357 L .78377 .41367 L F
.285 .261 .656 r
.78314 .41494 m .78448 .41248 L .78316 .41467 L F
.377 .825 .705 r
.78458 .41302 m .78003 .41523 L .78385 .41356 L F
.78405 .41345 m .78385 .41356 L .78399 .4135 L F
.78458 .41302 m .78385 .41356 L .78405 .41345 L F
.391 .834 .713 r
.78385 .41356 m .78003 .41523 L .78382 .41357 L F
.285 .261 .656 r
.78376 .41368 m .78376 .41361 L .78375 .41361 L F
.391 .834 .713 r
.78376 .41368 m .77965 .41691 L .78376 .41356 L F
.78377 .41367 m .77924 .41568 L .77964 .41687 L F
.78382 .41357 m .77924 .41568 L .78377 .41367 L F
.77998 .41665 m .77964 .41687 L .77965 .41691 L F
.78399 .4135 m .77964 .41687 L .77998 .41665 L F
.818 .729 .767 r
.78316 .41467 m .78284 .41487 L .78314 .41494 L F
.507 .681 .944 r
.78314 .41494 m .78588 .41479 L .78516 .4134 L F
.093 0 .09 r
.40933 .5883 m .40661 .59106 L .4083 .59009 L F
0 0 0 r
.4083 .59009 m .41127 .5872 L .40933 .5883 L F
.284 .108 .458 r
.56206 .58636 m .56434 .58484 L .56429 .58204 L F
.075 0 .137 r
.56156 .58776 m .56434 .58484 L .56206 .58636 L F
.911 .879 .792 r
.77438 .39618 m .77613 .39625 L .77595 .39211 L F
.966 .652 .261 r
.77535 .39754 m .77613 .39625 L .77438 .39618 L F
.556 .614 .866 r
.77595 .39211 m .77613 .39625 L .77878 .39572 L F
.616 .33 .461 r
.42404 .59917 m .42651 .59959 L .42681 .59746 L F
.55 .273 .447 r
.42681 .59746 m .42894 .59921 L .42906 .59708 L F
.42681 .59746 m .42651 .59959 L .42894 .59921 L F
.595 .611 .838 r
.42076 .61223 m .42162 .60819 L .41929 .60871 L F
.42076 .61223 m .4233 .61193 L .42162 .60819 L F
.464 .317 .595 r
.42076 .61223 m .4231 .61431 L .4233 .61193 L F
.42076 .61223 m .42097 .61505 L .4231 .61431 L F
.548 .904 .698 r
.66742 .44135 m .66483 .44304 L .6672 .44111 L F
.584 .945 .846 r
.66891 .43989 m .66742 .44135 L .6672 .44111 L F
0 0 0 r
.66648 .44273 m .66742 .44135 L .66891 .43989 L F
.433 .873 .837 r
.21224 .63305 m .21031 .6339 L .20883 .63419 L F
.194 0 0 r
.18894 .65208 m .18954 .65258 L .18773 .65208 L F
.18894 .65208 m .19196 .65223 L .18954 .65258 L F
0 0 0 r
.1833 .54463 m .18623 .54267 L .18414 .5434 L F
.873 .913 .853 r
.68889 .43626 m .69046 .43473 L .68936 .43345 L F
.754 .892 .94 r
.68936 .43345 m .69046 .43473 L .69352 .43244 L F
.847 .782 .788 r
.7866 .44466 m .78519 .44262 L .78609 .44167 L F
.797 .996 .777 r
.78284 .44609 m .78519 .44262 L .78363 .44413 L F
.768 .531 .576 r
.78411 .44421 m .78284 .44609 L .78363 .44413 L F
.797 .996 .777 r
.78284 .44609 m .78411 .44421 L .78519 .44262 L F
.768 .531 .576 r
.7866 .44466 m .78284 .44609 L .78411 .44421 L F
.797 .996 .777 r
.78284 .44609 m .78296 .44592 L .78411 .44421 L F
.847 .782 .788 r
.78411 .44421 m .78363 .44413 L .78519 .44262 L F
.797 .996 .777 r
.78296 .44592 m .78523 .44255 L .78519 .44262 L F
.847 .782 .788 r
.7866 .44466 m .78411 .44421 L .78519 .44262 L F
.768 .531 .576 r
.7866 .44466 m .78672 .447 L .78284 .44609 L F
.481 .311 .573 r
.78946 .44614 m .7866 .44466 L .78931 .44373 L F
.78946 .44614 m .78672 .447 L .7866 .44466 L F
.584 .334 .503 r
.58476 .46454 m .58801 .46479 L .58816 .46241 L F
.629 .372 .509 r
.58816 .46241 m .58801 .46479 L .59056 .46449 L F
.674 .353 .423 r
.58816 .46241 m .59056 .46449 L .59048 .46263 L F
.758 .605 .688 r
.43693 .59962 m .44014 .60321 L .43843 .59992 L F
.43693 .59962 m .43796 .60324 L .44014 .60321 L F
.612 .385 .548 r
.43773 .60595 m .44014 .60321 L .43796 .60324 L F
.43773 .60595 m .44021 .60592 L .44014 .60321 L F
.609 .382 .547 r
.44014 .60321 m .44377 .60514 L .44332 .60201 L F
.44014 .60321 m .44021 .60592 L .44377 .60514 L F
0 0 0 r
.54346 .50168 m .54048 .50412 L .54232 .50309 L F
.196 0 .095 r
.54232 .50309 m .54544 .50058 L .54346 .50168 L F
.084 .497 .899 r
.26939 .54426 m .26916 .54519 L .26703 .54359 L F
.26939 .54426 m .27094 .5457 L .26916 .54519 L F
.561 .805 .99 r
.19973 .63297 m .19759 .63358 L .19587 .63243 L F
.383 .327 .671 r
.39 .61512 m .39146 .61114 L .38932 .6128 L F
.727 .545 .645 r
.46078 .58465 m .46673 .58656 L .46402 .582 L F
.504 .462 .743 r
.46402 .582 m .46673 .58656 L .46708 .58463 L F
.781 .583 .631 r
.46043 .58626 m .46673 .58656 L .46078 .58465 L F
.46043 .58626 m .46472 .5876 L .46673 .58656 L F
.851 .797 .798 r
.46673 .58656 m .46472 .5876 L .46708 .58463 L F
.85 .795 .797 r
.46708 .58463 m .46472 .5876 L .46851 .58721 L F
.629 .355 .483 r
.46547 .59037 m .46851 .58721 L .46472 .5876 L F
.46547 .59037 m .46775 .59022 L .46851 .58721 L F
.825 .788 .818 r
.46708 .58463 m .46851 .58721 L .46893 .58586 L F
.504 0 0 r
.45436 .55754 m .45756 .55802 L .45543 .55711 L F
.615 .415 .588 r
.45474 .58218 m .45477 .58541 L .45225 .58495 L F
.388 .038 .245 r
.48289 .58221 m .4821 .58466 L .47965 .58502 L F
.183 0 0 r
.48522 .5822 m .4821 .58466 L .48289 .58221 L F
.004 .494 .866 r
.49035 .56234 m .49329 .56377 L .49171 .5634 L F
.912 .637 .507 r
.72338 .38909 m .72526 .38756 L .72488 .38728 L F
.966 .779 .6 r
.72405 .39199 m .72526 .38756 L .72338 .38909 L F
.734 .637 .751 r
.6256 .42289 m .6293 .42352 L .62816 .42016 L F
.725 .632 .754 r
.62816 .42016 m .6293 .42352 L .63206 .41972 L F
.294 .086 .416 r
.79188 .44078 m .79202 .43862 L .79402 .4375 L F
.528 .247 .432 r
.5592 .57343 m .5613 .57517 L .56106 .57255 L F
.5592 .57343 m .55861 .57583 L .5613 .57517 L F
.654 .491 .65 r
.46612 .61798 m .46616 .62117 L .46861 .61804 L F
.46861 .61804 m .46616 .62117 L .46612 .61798 L F
.473 .231 .466 r
.28179 .59378 m .2791 .59663 L .2795 .59432 L F
.628 .64 .843 r
.73719 .41748 m .73344 .41493 L .73587 .41408 L F
.624 .67 .873 r
.73834 .41376 m .73719 .41748 L .73587 .41408 L F
.73834 .41376 m .74024 .417 L .73719 .41748 L F
.577 .596 .836 r
.74079 .41982 m .73719 .41748 L .74024 .417 L F
.771 .682 .765 r
.72815 .3779 m .72933 .38153 L .72572 .38096 L F
.977 .708 .307 r
.73091 .37713 m .72933 .38153 L .72815 .3779 L F
.722 .753 .877 r
.72572 .38096 m .72933 .38153 L .72896 .3799 L F
.977 .708 .307 r
.73091 .37713 m .73112 .37962 L .72933 .38153 L F
.41 .535 .872 r
.72896 .3799 m .72933 .38153 L .73112 .37962 L F
.144 .676 .86 r
.16823 .62532 m .16781 .62564 L .16629 .62645 L F
.16823 .62532 m .16977 .62566 L .16781 .62564 L F
.314 .234 .604 r
.25523 .58188 m .25676 .5814 L .25641 .57888 L F
.403 .284 .602 r
.25498 .58493 m .25676 .5814 L .25523 .58188 L F
.546 .536 .795 r
.19165 .73516 m .19375 .73463 L .19244 .73117 L F
.121 0 0 r
.22354 .55197 m .22193 .5518 L .21963 .55148 L F
.576 0 0 r
.22519 .55364 m .22193 .5518 L .22354 .55197 L F
.626 .233 .28 r
.22605 .55246 m .22519 .55364 L .22354 .55197 L F
.513 .296 .522 r
.20408 .69561 m .20678 .69535 L .20452 .69315 L F
.336 .105 .408 r
.26758 .61495 m .26549 .6177 L .2656 .61526 L F
.205 .011 .382 r
.25275 .58814 m .25474 .58724 L .25498 .58493 L F
.461 .244 .497 r
.25204 .58998 m .25474 .58724 L .25275 .58814 L F
.463 .213 .449 r
.40799 .61468 m .4056 .61741 L .40583 .61519 L F
.704 .539 .663 r
.4056 .61741 m .40799 .61468 L .40583 .61519 L F
.541 .31 .514 r
.59561 .45616 m .59793 .4557 L .59831 .45347 L F
.711 .556 .677 r
.59793 .4557 m .60036 .45253 L .59831 .45347 L F
.508 .34 .588 r
.42875 .66317 m .43126 .66 L .42764 .65993 L F
.42875 .66317 m .43128 .66275 L .43126 .66 L F
.127 0 0 r
.67392 .40525 m .67376 .40533 L .67642 .40566 L F
.67652 .40566 m .67642 .40566 L .677 .40573 L F
.67392 .40525 m .67595 .40558 L .67633 .40563 L F
.84 .995 .755 r
.67661 .40561 m .67654 .40565 L .67376 .40533 L F
.67654 .40565 m .67424 .40684 L .67376 .40533 L F
.127 0 0 r
.67633 .40563 m .67642 .40566 L .67652 .40566 L F
.67595 .40558 m .67642 .40566 L .67633 .40563 L F
.944 .927 .569 r
.67412 .40915 m .67318 .40994 L .67658 .40565 L F
.67658 .40565 m .67658 .40565 L .67661 .40561 L F
.67412 .40915 m .67658 .40565 L .67658 .40565 L F
.67412 .40915 m .67323 .41156 L .67318 .40994 L F
.357 .449 .818 r
.74651 .42897 m .74781 .42755 L .74459 .42624 L F
.74651 .42897 m .74844 .42893 L .74781 .42755 L F
.964 .756 .574 r
.28579 .56559 m .28552 .56386 L .2871 .56342 L F
.28579 .56559 m .28531 .56641 L .28552 .56386 L F
.466 .37 .662 r
.28781 .56809 m .28531 .56641 L .28579 .56559 L F
.339 .319 .69 r
.2871 .56342 m .28935 .56534 L .28579 .56559 L F
.425 .347 .665 r
.28935 .56534 m .28781 .56809 L .28579 .56559 L F
0 0 .305 r
.20336 .69654 m .20257 .69922 L .20408 .69561 L F
.341 .203 .543 r
.42321 .59355 m .42494 .59644 L .42499 .59355 L F
.536 .337 .558 r
.42139 .59304 m .42123 .59556 L .42321 .59355 L F
.972 .733 .515 r
.42139 .59304 m .42123 .59556 L .42321 .59355 L F
.662 .654 .832 r
.48237 .59424 m .47991 .59561 L .47848 .59306 L F
.296 .459 .853 r
.47848 .59306 m .47991 .59561 L .48113 .59505 L F
.969 .921 .592 r
.77659 .42645 m .775 .4283 L .7761 .42792 L F
0 0 0 r
.77781 .42504 m .77659 .42645 L .77965 .42677 L F
.77781 .42504 m .775 .4283 L .77659 .42645 L F
.764 .547 .603 r
.50424 .59391 m .50781 .59628 L .50739 .59432 L F
.792 .822 .876 r
.50781 .59628 m .50884 .59292 L .50739 .59432 L F
.614 .31 .431 r
.20151 .70165 m .20257 .69922 L .19967 .69955 L F
.515 .419 .684 r
.28585 .55494 m .2862 .55701 L .2839 .55746 L F
.864 .427 .021 r
.51999 .56387 m .51859 .56289 L .51767 .56098 L F
0 0 .497 r
.51999 .56387 m .52084 .56473 L .51859 .56289 L F
.52022 .56411 m .52208 .56604 L .52084 .56473 L F
0 .078 .639 r
.52369 .56943 m .52386 .56813 L .52208 .56604 L F
0 0 .555 r
.52208 .56604 m .52334 .56707 L .52084 .56473 L F
.637 .086 0 r
.52084 .56473 m .52334 .56707 L .52156 .5661 L F
.52084 .56473 m .52156 .5661 L .52145 .56534 L F
.52084 .56473 m .52145 .56534 L .52121 .56363 L F
0 0 .497 r
.51999 .56387 m .52022 .56411 L .52084 .56473 L F
.458 .086 .245 r
.48571 .60901 m .48206 .61168 L .48546 .60774 L F
.48571 .60901 m .48465 .61144 L .48206 .61168 L F
.481 .109 .256 r
.48688 .60991 m .48465 .61144 L .48571 .60901 L F
.544 .066 .071 r
.48571 .60901 m .48863 .60944 L .48688 .60991 L F
.81 .659 .696 r
.6584 .40037 m .65687 .40452 L .65537 .40172 L F
.6584 .40037 m .65537 .40172 L .65734 .40125 L F
.535 .01 0 r
.65734 .40125 m .66127 .4017 L .6584 .40037 L F
.874 .741 .712 r
.60333 .47921 m .60712 .48104 L .60698 .47744 L F
.685 .237 .183 r
.60305 .48173 m .60712 .48104 L .60333 .47921 L F
.60305 .48173 m .60675 .48226 L .60712 .48104 L F
.592 .567 .794 r
.2553 .55867 m .25669 .5614 L .25898 .5608 L F
.723 .971 .724 r
.21137 .68434 m .21189 .68296 L .21416 .68159 L F
.03 0 0 r
.21416 .68159 m .21189 .68296 L .21431 .68227 L F
0 0 0 r
.16113 .55288 m .16118 .55349 L .16332 .55236 L F
.16113 .55288 m .15902 .55409 L .16118 .55349 L F
.56192 .5707 m .56106 .57255 L .56337 .56953 L F
.726 .76 .879 r
.72353 .41397 m .71985 .41326 L .72259 .4106 L F
.75 .73 .834 r
.72615 .41113 m .72353 .41397 L .72259 .4106 L F
.418 .069 .263 r
.43832 .58413 m .44077 .58369 L .44307 .57991 L F
.536 .137 .231 r
.44077 .58369 m .44483 .58139 L .44307 .57991 L F
.42 .119 .346 r
.40371 .59383 m .40626 .59344 L .40661 .59106 L F
.286 .03 .339 r
.40626 .59344 m .4083 .59009 L .40661 .59106 L F
.71 .532 .646 r
.44377 .60514 m .44642 .60285 L .44332 .60201 L F
.099 0 .278 r
.16823 .5657 m .16661 .56776 L .16566 .56744 L F
0 .43 .825 r
.74079 .41982 m .73975 .41883 L .73841 .41862 L F
.544 .813 .996 r
.74177 .41833 m .74079 .41982 L .74024 .417 L F
.74177 .41833 m .74296 .41925 L .74079 .41982 L F
.176 .319 .771 r
.74079 .41982 m .74177 .41833 L .73975 .41883 L F
.74079 .41982 m .74355 .4222 L .74177 .41833 L F
.439 .353 .662 r
.74134 .42234 m .74355 .4222 L .74079 .41982 L F
.069 0 .069 r
.56993 .59686 m .56933 .59898 L .56733 .59933 L F
.052 0 0 r
.56933 .59898 m .56642 .60155 L .56733 .59933 L F
.992 .746 .386 r
.52965 .52791 m .52844 .52963 L .52986 .53174 L F
.882 .948 .59 r
.53099 .52381 m .52965 .52791 L .53055 .52564 L F
.53099 .52381 m .52935 .52717 L .52965 .52791 L F
.896 .88 .449 r
.52935 .52717 m .52844 .52963 L .52965 .52791 L F
.977 .708 .307 r
.73091 .37713 m .73192 .37866 L .73112 .37962 L F
.73112 .37962 m .73192 .37866 L .73091 .37713 L F
.569 .442 .668 r
.56955 .48003 m .57174 .47656 L .56925 .47771 L F
.609 .302 .425 r
.59048 .46263 m .59308 .46419 L .59331 .46176 L F
.59048 .46263 m .59056 .46449 L .59308 .46419 L F
.624 .874 .989 r
.47158 .55895 m .46788 .55907 L .47024 .55849 L F
0 .527 .801 r
.47158 .55895 m .47231 .55881 L .47396 .55826 L F
.47158 .55895 m .47024 .55849 L .47231 .55881 L F
.611 .26 .35 r
.70394 .40845 m .70658 .41021 L .70404 .4108 L F
.70394 .40845 m .7069 .40864 L .70658 .41021 L F
.685 .264 .24 r
.45786 .56731 m .45816 .56898 L .45677 .56882 L F
0 0 .074 r
.24148 .60627 m .23904 .60922 L .24067 .60804 L F
0 0 0 r
.23904 .60922 m .2393 .60997 L .24067 .60804 L F
.23904 .60922 m .23852 .6114 L .2393 .60997 L F
.798 .774 .266 r
.58198 .52508 m .5814 .52668 L .58199 .52432 L F
.58198 .52508 m .58118 .5287 L .5814 .52668 L F
.357 .722 .987 r
.18375 .62811 m .1801 .62723 L .18237 .62708 L F
.406 .569 .902 r
.18453 .62627 m .18375 .62811 L .18237 .62708 L F
.18453 .62627 m .18646 .62896 L .18375 .62811 L F
.735 .834 .926 r
.73805 .39537 m .73448 .39485 L .7369 .39376 L F
.7 .862 .959 r
.73954 .3926 m .73805 .39537 L .7369 .39376 L F
.73954 .3926 m .74092 .39371 L .73805 .39537 L F
.89 .956 .838 r
.21134 .65415 m .21201 .6509 L .20981 .65163 L F
.21134 .65415 m .21381 .65115 L .21201 .6509 L F
.724 .816 .922 r
.71888 .42225 m .72256 .4224 L .72163 .42084 L F
.703 .895 .966 r
.72256 .4224 m .72451 .41956 L .72163 .42084 L F
.72256 .4224 m .72666 .4203 L .72451 .41956 L F
.82 .884 .89 r
.69028 .42428 m .69152 .4257 L .68852 .42587 L F
.837 .865 .865 r
.68852 .42587 m .69152 .4257 L .68981 .42715 L F
.78 .876 .917 r
.69448 .42323 m .69152 .4257 L .69028 .42428 L F
.305 0 .236 r
.25707 .62898 m .25575 .6281 L .25794 .62741 L F
.25707 .62898 m .25502 .62965 L .25575 .6281 L F
.672 .528 .68 r
.67429 .40243 m .67392 .40525 L .67805 .40445 L F
.669 .512 .664 r
.63533 .41159 m .63906 .4116 L .63788 .40784 L F
.696 .528 .655 r
.63788 .40784 m .64208 .41034 L .64274 .40935 L F
.63788 .40784 m .63906 .4116 L .64208 .41034 L F
.264 0 0 r
.50857 .57779 m .51033 .57749 L .50956 .57736 L F
.873 .913 .853 r
.68889 .43626 m .68936 .43345 L .68777 .43507 L F
.384 .578 .916 r
.46552 .61533 m .46595 .61846 L .46309 .61465 L F
.326 0 0 r
.46758 .61929 m .46595 .61846 L .46552 .61533 L F
.705 .582 .715 r
.46975 .61669 m .4656 .61541 L .46607 .61542 L F
.079 0 0 r
.46617 .61552 m .46627 .6155 L .46595 .61541 L F
.4658 .61541 m .46595 .61541 L .46309 .61465 L F
.46617 .61552 m .46595 .61541 L .4658 .61541 L F
.705 .582 .715 r
.46975 .61669 m .46758 .61929 L .4656 .61541 L F
.384 .578 .916 r
.4655 .61522 m .46309 .61465 L .46595 .61541 L F
.705 .582 .715 r
.46607 .61542 m .46595 .61541 L .4655 .61522 L F
.384 .578 .916 r
.4655 .61522 m .46595 .61541 L .46627 .6155 L F
.705 .582 .715 r
.46595 .61541 m .4656 .61541 L .4655 .61522 L F
.326 0 0 r
.4656 .61541 m .46552 .61533 L .4655 .61522 L F
.46758 .61929 m .46552 .61533 L .4656 .61541 L F
.079 0 0 r
.46218 .61622 m .46579 .61558 L .46309 .61465 L F
.46579 .61558 m .46617 .61552 L .46552 .61533 L F
.46579 .61558 m .46552 .61533 L .46309 .61465 L F
.384 .578 .916 r
.4655 .61522 m .46552 .61533 L .46309 .61465 L F
.326 0 0 r
.46758 .61929 m .46335 .61958 L .46595 .61846 L F
.195 0 0 r
.1902 .55797 m .18787 .5593 L .18681 .55876 L F
.142 0 0 r
.19029 .55885 m .1902 .55797 L .19196 .55717 L F
.19029 .55885 m .18787 .5593 L .1902 .55797 L F
.103 .656 .797 r
.45861 .58544 m .45714 .58532 L .45477 .58541 L F
.585 .895 .618 r
.45861 .58544 m .45583 .58803 L .45805 .58583 L F
.54 .203 .345 r
.45805 .58583 m .46078 .58465 L .45861 .58544 L F
.881 .924 .535 r
.5814 .52668 m .58118 .5287 L .58014 .53072 L F
.792 .621 .668 r
.21338 .69902 m .21024 .70081 L .21151 .69899 L F
.328 .81 .776 r
.50667 .52302 m .50935 .52209 L .50998 .52204 L F
.467 .875 .727 r
.50998 .52204 m .51152 .52088 L .51313 .52023 L F
.479 .893 .79 r
.50998 .52204 m .50935 .52209 L .51152 .52088 L F
.713 .915 .964 r
.19961 .65171 m .20195 .65233 L .20394 .65117 L F
.81 .928 .912 r
.7739 .39058 m .77207 .39049 L .77283 .38972 L F
.36 .615 .947 r
.77666 .38986 m .77283 .38972 L .77207 .38783 L F
.86 .728 .716 r
.77666 .38986 m .77667 .38988 L .77619 .38745 L F
.36 .615 .947 r
.77666 .38987 m .77666 .38986 L .77619 .38745 L F
.77666 .38986 m .77207 .38783 L .77619 .38745 L F
.86 .728 .716 r
.77536 .38867 m .77666 .38986 L .77619 .38745 L F
.868 .934 .863 r
.77825 .39064 m .7777 .39166 L .77667 .38987 L F
.86 .728 .716 r
.77667 .38988 m .77694 .39012 L .7769 .38999 L F
.77667 .38988 m .7769 .38999 L .77619 .38745 L F
.783 .951 .928 r
.77911 .38643 m .7769 .38954 L .77619 .38745 L F
.868 .934 .863 r
.77992 .38755 m .77825 .39064 L .7769 .38998 L F
0 .095 .636 r
.7769 .38999 m .777 .39035 L .77689 .38958 L F
.77687 .38972 m .77689 .38958 L .77665 .38794 L F
.868 .934 .863 r
.77992 .38755 m .7769 .38998 L .77687 .38972 L F
0 .095 .636 r
.7769 .38999 m .77689 .38958 L .77687 .38972 L F
.783 .951 .928 r
.77742 .38891 m .77805 .38888 L .77687 .38972 L F
.77911 .38643 m .77687 .38972 L .7769 .38954 L F
.7769 .38954 m .77666 .38987 L .77619 .38745 L F
0 .095 .636 r
.77665 .38794 m .77687 .38948 L .77771 .38907 L F
.77619 .38745 m .7769 .38999 L .77665 .38794 L F
.36 .615 .947 r
.77666 .38987 m .77283 .38972 L .77666 .38986 L F
.252 .502 .899 r
.77666 .38987 m .77431 .39047 L .7738 .38976 L F
.86 .728 .716 r
.77445 .39001 m .77694 .39012 L .77666 .38987 L F
.77509 .38907 m .77666 .38987 L .77536 .38867 L F
.77445 .39001 m .77666 .38987 L .77509 .38907 L F
.77445 .39001 m .77619 .38745 L .77207 .38783 L F
.783 .951 .928 r
.7769 .38954 m .77687 .38972 L .77666 .38987 L F
0 .095 .636 r
.77687 .38948 m .77711 .39017 L .77771 .38907 L F
.868 .934 .863 r
.77687 .38972 m .7769 .38998 L .77666 .38987 L F
.77825 .39064 m .77667 .38987 L .77666 .38987 L F
.36 .615 .947 r
.77666 .38987 m .77666 .38987 L .77666 .38986 L F
.86 .728 .716 r
.77445 .39001 m .777 .39035 L .77694 .39012 L F
.82 .813 .844 r
.77353 .39361 m .777 .39035 L .77445 .39001 L F
.77353 .39361 m .77445 .39001 L .77541 .39155 L F
.65 .226 0 r
.77376 .38904 m .77541 .39155 L .77445 .39001 L F
.713 .764 .892 r
.77771 .38907 m .77541 .39155 L .77376 .38904 L F
.77771 .38907 m .77448 .38904 L .77727 .38928 L F
.77448 .38904 m .77376 .38904 L .77409 .38906 L F
.77448 .38904 m .77409 .38906 L .77727 .38928 L F
.783 .951 .928 r
.77911 .38643 m .77992 .38755 L .77805 .38888 L F
.77911 .38643 m .77805 .38888 L .77742 .38891 L F
0 .095 .636 r
.77687 .38948 m .777 .39035 L .77711 .39017 L F
0 .109 .625 r
.77376 .38904 m .77445 .39001 L .77305 .38872 L F
.77276 .38832 m .77305 .38872 L .77207 .38783 L F
.77376 .38904 m .77305 .38872 L .77276 .38832 L F
.252 .502 .899 r
.7738 .38976 m .7739 .39058 L .77283 .38972 L F
.77431 .39047 m .7739 .39058 L .7738 .38976 L F
.597 .485 .697 r
.19046 .74456 m .19159 .74388 L .19037 .74403 L F
.843 .845 .846 r
.68981 .42715 m .68596 .42863 L .68852 .42587 L F
.446 0 0 r
.22888 .53809 m .22744 .53886 L .23133 .53881 L F
.222 .735 .879 r
.22971 .53872 m .22988 .53872 L .23133 .53881 L F
.319 0 0 r
.22888 .53809 m .23133 .53881 L .23329 .53893 L F
.222 .735 .879 r
.22988 .53872 m .23346 .53869 L .23133 .53881 L F
.319 0 0 r
.23329 .53893 m .23133 .53881 L .23358 .53898 L F
.278 0 0 r
.23133 .53881 m .23527 .53943 L .23358 .53898 L F
.556 .38 .597 r
.59316 .45928 m .5958 .45877 L .59561 .45616 L F
.61 .445 .634 r
.59331 .46176 m .5958 .45877 L .59316 .45928 L F
.887 .863 .81 r
.66372 .4133 m .6673 .41153 L .66352 .41083 L F
.66372 .4133 m .66497 .41481 L .6673 .41153 L F
0 0 .429 r
.53363 .6066 m .53445 .60883 L .53362 .60513 L F
.924 .546 .269 r
.1957 .73831 m .1957 .73979 L .19567 .7382 L F
.1957 .73831 m .19567 .7382 L .19566 .73716 L F
0 0 .53 r
.1957 .73831 m .19757 .74051 L .19576 .73854 L F
.1957 .73831 m .19576 .73854 L .19529 .73803 L F
.516 .232 .423 r
.48546 .60774 m .48465 .61144 L .48206 .61168 L F
.519 .916 .889 r
.48688 .60991 m .48863 .60944 L .49055 .60842 L F
0 0 .317 r
.48703 .60757 m .48688 .60991 L .49055 .60842 L F
.48703 .60757 m .48737 .61061 L .48688 .60991 L F
.412 .14 .388 r
.48546 .60774 m .48737 .61061 L .48703 .60757 L F
.52 .162 .3 r
.48688 .60991 m .48664 .61286 L .48465 .61144 L F
0 0 .16 r
.48737 .61061 m .48664 .61286 L .48688 .60991 L F
.412 .14 .388 r
.48546 .60774 m .48465 .61144 L .48737 .61061 L F
.605 .446 .64 r
.58309 .46798 m .58544 .46805 L .58476 .46454 L F
.579 .429 .642 r
.58476 .46454 m .5881 .46738 L .58801 .46479 L F
.58476 .46454 m .58544 .46805 L .5881 .46738 L F
.634 .924 .975 r
.55955 .59375 m .5606 .59442 L .55667 .59564 L F
.585 .01 0 r
.45185 .56993 m .45094 .57001 L .44935 .56925 L F
1 .807 .491 r
.45185 .56993 m .45045 .57144 L .45094 .57001 L F
.153 0 0 r
.45274 .57081 m .45185 .56993 L .45303 .56892 L F
.45274 .57081 m .45045 .57144 L .45185 .56993 L F
.193 0 .222 r
.5379 .50687 m .54005 .50652 L .54048 .50412 L F
.097 0 0 r
.53897 .50763 m .5379 .50687 L .53714 .50892 L F
.53897 .50763 m .54005 .50652 L .5379 .50687 L F
.28 0 .113 r
.53476 .50964 m .53714 .50892 L .5379 .50687 L F
.56 .807 .991 r
.2572 .54016 m .25529 .54074 L .25353 .53955 L F
.564 .82 .993 r
.47766 .55874 m .47396 .55826 L .47626 .55729 L F
.121 .608 .912 r
.47626 .55729 m .4799 .55837 L .47766 .55874 L F
0 .116 .656 r
.65413 .42741 m .65429 .42707 L .65255 .42632 L F
.65413 .42741 m .65506 .42848 L .65429 .42707 L F
.838 .893 .879 r
.79575 .4275 m .79102 .43068 L .79539 .42718 L F
.4 .585 .916 r
.79796 .42706 m .79575 .4275 L .79539 .42718 L F
.79796 .42706 m .79887 .42914 L .79575 .4275 L F
.279 0 .201 r
.25217 .63227 m .25011 .63293 L .25303 .63045 L F
.45 .166 .389 r
.25502 .62965 m .25217 .63227 L .25303 .63045 L F
.33 0 0 r
.69657 .40204 m .69319 .40232 L .69574 .40195 L F
.118 0 0 r
.69574 .40195 m .69889 .40236 L .69657 .40204 L F
.429 .175 .425 r
.24067 .60804 m .24324 .6054 L .24148 .60627 L F
.782 .431 .392 r
.77828 .42163 m .78116 .42041 L .77793 .41961 L F
.437 .192 .444 r
.15861 .57019 m .15811 .57252 L .15604 .57286 L F
.396 .142 .408 r
.1608 .56956 m .15811 .57252 L .15861 .57019 L F
0 0 .124 r
.52321 .54569 m .52267 .54621 L .52388 .54286 L F
.473 .864 .671 r
.52639 .54108 m .52388 .54286 L .5262 .54166 L F
.833 .569 .539 r
.5214 .54104 m .5243 .54236 L .52639 .54108 L F
.738 .285 0 r
.52342 .54151 m .5243 .54236 L .5214 .54104 L F
.52342 .54151 m .5241 .54239 L .5243 .54236 L F
.473 .864 .671 r
.52465 .54231 m .5243 .54236 L .52388 .54286 L F
.237 0 .309 r
.52561 .54434 m .52388 .54286 L .5243 .54236 L F
.738 .285 0 r
.5241 .54239 m .52561 .54434 L .5243 .54236 L F
.473 .864 .671 r
.52639 .54108 m .5243 .54236 L .52465 .54231 L F
.237 0 .309 r
.52561 .54434 m .52321 .54569 L .52388 .54286 L F
.401 .316 .644 r
.44392 .65276 m .44189 .65152 L .44453 .6509 L F
.44392 .65276 m .44208 .65398 L .44189 .65152 L F
.44392 .65276 m .44189 .65152 L .44453 .6509 L F
.44392 .65276 m .44208 .65398 L .44189 .65152 L F
0 0 0 r
.15604 .57286 m .15437 .57492 L .15307 .57587 L F
.101 0 0 r
.15632 .57418 m .15604 .57286 L .15811 .57252 L F
.15632 .57418 m .15437 .57492 L .15604 .57286 L F
.445 .274 .555 r
.61244 .43477 m .6145 .4311 L .6127 .43245 L F
0 0 0 r
.75415 .3732 m .75283 .37309 L .75182 .37443 L F
.75415 .3732 m .75512 .37188 L .75283 .37309 L F
.443 .831 .985 r
.16407 .62691 m .16629 .62645 L .1648 .62714 L F
.635 .704 .896 r
.73777 .37264 m .73653 .3745 L .73499 .37284 L F
.329 .74 .979 r
.73418 .37543 m .73718 .3755 L .7367 .37454 L F
.635 .704 .896 r
.73653 .3745 m .7365 .37453 L .73626 .37452 L F
.329 .74 .979 r
.73626 .37452 m .7367 .37454 L .73661 .37437 L F
.73418 .37543 m .7367 .37454 L .73626 .37452 L F
.635 .704 .896 r
.73626 .37452 m .73621 .37496 L .73598 .37455 L F
.7365 .37453 m .73621 .37496 L .73626 .37452 L F
.73653 .3745 m .73598 .37455 L .73499 .37284 L F
.329 .74 .979 r
.73418 .37543 m .73626 .37452 L .73279 .375 L F
.73626 .37452 m .73631 .3745 L .73598 .37455 L F
.73626 .37452 m .73598 .37455 L .73279 .375 L F
.522 .602 .875 r
.73499 .37284 m .73598 .37455 L .73279 .375 L F
.329 .74 .979 r
.73631 .3745 m .73661 .37437 L .73279 .375 L F
.522 .602 .875 r
.73598 .37455 m .73621 .37496 L .73279 .375 L F
.213 .707 .92 r
.73621 .37496 m .73418 .37543 L .73279 .375 L F
.73621 .37496 m .73718 .3755 L .73418 .37543 L F
.709 .762 .894 r
.42789 .56523 m .43235 .56573 L .43109 .56314 L F
.78 .76 .835 r
.43109 .56314 m .43235 .56573 L .43378 .56301 L F
.48 .387 .673 r
.43235 .56573 m .43454 .56638 L .43378 .56301 L F
.29 .068 .394 r
.43286 .62943 m .4305 .63259 L .43083 .63016 L F
.107 0 0 r
.44283 .55795 m .44553 .55703 L .44542 .5565 L F
.428 0 0 r
.44553 .55703 m .44793 .55725 L .44542 .5565 L F
.313 0 0 r
.44542 .5565 m .44793 .55725 L .45006 .55758 L F
.642 .949 .948 r
.21201 .6509 m .21381 .65115 L .21419 .64984 L F
.143 .374 .828 r
.22216 .67054 m .22194 .67185 L .21955 .66956 L F
.22216 .67054 m .22303 .67204 L .22194 .67185 L F
.674 .41 .514 r
.22303 .67204 m .22029 .67363 L .22194 .67185 L F
.977 .843 .642 r
.60221 .50105 m .60307 .49865 L .60162 .4977 L F
.189 .366 .81 r
.47779 .58955 m .47365 .58413 L .47696 .58511 L F
0 0 .28 r
.47965 .58502 m .47779 .58955 L .47696 .58511 L F
0 0 0 r
.77596 .43008 m .77468 .43007 L .7761 .42792 L F
.77596 .43008 m .7761 .42792 L .775 .4283 L F
.787 .777 .844 r
.6249 .43281 m .62826 .43286 L .62697 .43139 L F
.802 .839 .879 r
.62697 .43139 m .62826 .43286 L .63029 .43137 L F
.45 .701 .974 r
.20595 .63409 m .20373 .6344 L .20188 .63265 L F
0 0 0 r
.23511 .6439 m .23139 .64738 L .23407 .64477 L F
.824 .911 .898 r
.66072 .41634 m .66497 .41481 L .66372 .4133 L F
.039 0 .172 r
.46416 .59976 m .4636 .60217 L .46188 .60263 L F
.503 .166 .329 r
.4636 .60217 m .4609 .60287 L .46188 .60263 L F
.503 .738 .979 r
.17782 .65 m .17929 .65138 L .1799 .64957 L F
.373 .596 .933 r
.17929 .65138 m .1817 .65167 L .1799 .64957 L F
.461 .253 .509 r
.56987 .55213 m .57229 .55159 L .57245 .54915 L F
.425 .161 .408 r
.57166 .5538 m .56987 .55213 L .57032 .55477 L F
.57166 .5538 m .57229 .55159 L .56987 .55213 L F
0 .262 .767 r
.21137 .68434 m .21369 .68639 L .21189 .68296 L F
.1 0 .215 r
.39352 .60307 m .3912 .60616 L .3931 .6051 L F
.259 .111 .481 r
.39109 .60861 m .3931 .6051 L .3912 .60616 L F
.235 0 .033 r
.22809 .55266 m .22605 .55246 L .22958 .55216 L F
0 .518 .852 r
.23138 .55392 m .22809 .55266 L .22958 .55216 L F
.634 .924 .975 r
.55955 .59375 m .55667 .59564 L .55646 .5954 L F
0 .356 .824 r
.73841 .41862 m .73887 .4178 L .73631 .41887 L F
.73841 .41862 m .73975 .41883 L .73887 .4178 L F
.741 .285 0 r
.56224 .57933 m .56429 .58204 L .56355 .58146 L F
.926 .623 .45 r
.56429 .58204 m .56255 .58364 L .56355 .58146 L F
.56429 .58204 m .56434 .58484 L .56255 .58364 L F
.656 .427 .56 r
.44483 .58139 m .44751 .58209 L .44732 .57876 L F
.486 .298 .551 r
.44732 .57876 m .44973 .5811 L .44967 .57854 L F
.44732 .57876 m .44751 .58209 L .44973 .5811 L F
0 0 .077 r
.58876 .54008 m .59039 .53618 L .59004 .53834 L F
0 0 .104 r
.58835 .54216 m .58876 .54008 L .59004 .53834 L F
.379 .068 .306 r
.44819 .62431 m .44773 .62662 L .44537 .62689 L F
.849 .886 .865 r
.45035 .6212 m .44819 .62431 L .44635 .62292 L F
.672 .608 .775 r
.45078 .62341 m .44819 .62431 L .45035 .6212 L F
.467 .143 .332 r
.45007 .62588 m .44819 .62431 L .45078 .62341 L F
.45007 .62588 m .44773 .62662 L .44819 .62431 L F
.864 .993 .821 r
.53055 .52564 m .53293 .52314 L .53099 .52381 L F
.734 .978 .742 r
.53293 .52314 m .53279 .52238 L .53099 .52381 L F
.53293 .52314 m .53454 .52153 L .53279 .52238 L F
.516 .901 .74 r
.51313 .52023 m .5134 .51957 L .51532 .5191 L F
.51313 .52023 m .51152 .52088 L .5134 .51957 L F
.023 0 .141 r
.44025 .56143 m .44208 .56054 L .44283 .55795 L F
.299 .295 .687 r
.39136 .6211 m .39279 .62116 L .39235 .61712 L F
.283 .384 .79 r
.39136 .6211 m .39405 .62279 L .39279 .62116 L F
.912 .637 .507 r
.72338 .38909 m .72488 .38728 L .72341 .38678 L F
.766 .783 .867 r
.70755 .41581 m .70897 .41735 L .70551 .41702 L F
.763 .81 .89 r
.71046 .41343 m .70897 .41735 L .70755 .41581 L F
.71046 .41343 m .7112 .41597 L .70897 .41735 L F
.501 .246 .459 r
.56383 .56722 m .56599 .569 L .56602 .56653 L F
.56383 .56722 m .56337 .56953 L .56599 .569 L F
.217 0 .23 r
.54048 .50412 m .54212 .50542 L .54232 .50309 L F
.54048 .50412 m .54005 .50652 L .54212 .50542 L F
.888 .771 .727 r
.41499 .63765 m .41367 .64074 L .41246 .63744 L F
.641 .57 .759 r
.41753 .64177 m .41367 .64074 L .41499 .63765 L F
.681 .509 .647 r
.41966 .6387 m .41753 .64177 L .41499 .63765 L F
.21 .668 .946 r
.48236 .55888 m .4862 .56002 L .48353 .55948 L F
.994 .873 .58 r
.76779 .42364 m .76625 .4251 L .76722 .42134 L F
.76779 .42364 m .76708 .42617 L .76625 .4251 L F
0 0 0 r
.25594 .57314 m .25713 .57249 L .25821 .57024 L F
.128 .186 .654 r
.25594 .57314 m .25776 .57482 L .25713 .57249 L F
.329 .199 .547 r
.25623 .57519 m .25776 .57482 L .25594 .57314 L F
.711 .565 .689 r
.4277 .58829 m .43087 .58922 L .43243 .58804 L F
.093 0 0 r
.43243 .58804 m .43296 .58802 L .43354 .58558 L F
.43243 .58804 m .43087 .58922 L .43296 .58802 L F
.751 .664 .765 r
.42668 .62849 m .42472 .63061 L .42074 .62974 L F
.862 .834 .818 r
.42472 .63061 m .42049 .63261 L .42074 .62974 L F
.42472 .63061 m .42235 .63334 L .42049 .63261 L F
.443 .218 .476 r
.42659 .62965 m .42472 .63061 L .42668 .62849 L F
0 0 0 r
.77596 .43008 m .77351 .43114 L .77468 .43007 L F
.26 .709 .958 r
.74662 .41466 m .74576 .41545 L .74769 .41566 L F
.22 0 0 r
.55409 .6087 m .55644 .60821 L .55342 .60932 L F
.395 0 .124 r
.57608 .47289 m .57959 .47074 L .57713 .4713 L F
.635 .475 .649 r
.5958 .45877 m .59793 .4557 L .59561 .45616 L F
.943 .939 .598 r
.58547 .51529 m .58511 .51461 L .58655 .51335 L F
.958 .796 .354 r
.58655 .51335 m .58601 .51243 L .58617 .50907 L F
.966 .921 .585 r
.58655 .51335 m .58511 .51461 L .58601 .51243 L F
.845 .793 .8 r
.77675 .41651 m .77793 .41961 L .77965 .41691 L F
.77675 .41651 m .77965 .41691 L .77924 .41568 L F
.935 .859 .741 r
.77924 .41568 m .7805 .4196 L .77867 .41807 L F
.759 .276 0 r
.77867 .41807 m .77942 .41956 L .7805 .4196 L F
0 .209 .731 r
.77924 .41568 m .78121 .41735 L .7805 .4196 L F
.758 .968 .685 r
.78121 .41735 m .77942 .41956 L .7805 .4196 L F
.683 .687 .847 r
.46893 .58586 m .47081 .58622 L .46937 .5821 L F
.795 .746 .808 r
.46937 .5821 m .47081 .58622 L .47302 .58227 L F
.289 .405 .808 r
.74312 .39438 m .74183 .39635 L .74092 .39371 L F
0 0 .031 r
.74153 .39755 m .74183 .39635 L .74312 .39438 L F
.841 .453 .315 r
.67609 .41273 m .67318 .40994 L .67323 .41156 L F
.383 .327 .671 r
.39 .61512 m .39172 .61466 L .39146 .61114 L F
.385 .334 .677 r
.39 .61512 m .39235 .61712 L .39172 .61466 L F
.462 .168 .381 r
.47066 .58758 m .47314 .58711 L .47365 .58413 L F
.01 .208 .719 r
.47365 .58413 m .47481 .58379 L .47302 .58227 L F
.283 .019 .325 r
.47365 .58413 m .47503 .58633 L .47481 .58379 L F
.47365 .58413 m .47314 .58711 L .47503 .58633 L F
.448 .333 .631 r
.45583 .58803 m .45824 .59013 L .45805 .58583 L F
.519 .473 .745 r
.79423 .41037 m .79167 .41191 L .79105 .40805 L F
.421 .387 .715 r
.79441 .41351 m .79167 .41191 L .79423 .41037 L F
.79441 .41351 m .79273 .4145 L .79167 .41191 L F
.247 .76 .782 r
.19485 .6529 m .19565 .65251 L .19363 .65232 L F
.19485 .6529 m .19758 .65224 L .19565 .65251 L F
.89 .707 .649 r
.60622 .46707 m .60784 .46839 L .60641 .4648 L F
.845 .706 .71 r
.60622 .46707 m .60759 .47076 L .60784 .46839 L F
.085 0 .393 r
.20408 .69561 m .20257 .69922 L .2039 .69825 L F
0 0 .045 r
.2039 .69825 m .20257 .69922 L .20151 .70165 L F
.389 .11 .365 r
.44344 .63024 m .4429 .63241 L .44066 .63282 L F
.44066 .63282 m .4429 .63241 L .44344 .63024 L F
.263 .002 .316 r
.44531 .62942 m .4429 .63241 L .44344 .63024 L F
.44531 .62942 m .4429 .63241 L .44344 .63024 L F
.979 .795 .383 r
.76863 .41447 m .76778 .41594 L .76799 .41314 L F
.76863 .41447 m .76844 .41702 L .76778 .41594 L F
.813 .704 .745 r
.61002 .45268 m .60779 .45576 L .61128 .45626 L F
.799 .649 .697 r
.60784 .45828 m .61128 .45626 L .60779 .45576 L F
.60784 .45828 m .60919 .45935 L .61128 .45626 L F
.087 .471 .891 r
.48839 .56031 m .48745 .56125 L .4862 .56002 L F
.48839 .56031 m .49035 .56234 L .48745 .56125 L F
0 0 0 r
.52216 .51646 m .52163 .51633 L .51992 .51759 L F
.52216 .51646 m .52353 .51521 L .52163 .51633 L F
.97 .818 .398 r
.7611 .41649 m .76085 .41355 L .7602 .41554 L F
.943 .87 .736 r
.75831 .41887 m .7611 .41649 L .7602 .41554 L F
.75831 .41887 m .75943 .42015 L .7611 .41649 L F
0 0 0 r
.59217 .53038 m .59289 .52833 L .59377 .5265 L F
.853 .847 .385 r
.76544 .39469 m .76509 .39725 L .76606 .39372 L F
.922 .965 .658 r
.76376 .39929 m .76509 .39725 L .76544 .39469 L F
.115 0 0 r
.67661 .40561 m .67376 .40533 L .67392 .40525 L F
.547 .179 .295 r
.67424 .40684 m .67132 .40536 L .67376 .40533 L F
.67424 .40684 m .6732 .40706 L .67132 .40536 L F
.624 .264 .34 r
.67132 .40536 m .66988 .40776 L .67164 .40634 L F
.652 .281 .327 r
.67132 .40536 m .67164 .40634 L .6671 .4041 L F
0 .321 .72 r
.67112 .40609 m .67164 .40634 L .67152 .40627 L F
.547 .179 .295 r
.6732 .40706 m .66988 .40776 L .67093 .406 L F
.6732 .40706 m .67093 .406 L .67132 .40536 L F
0 .321 .72 r
.6671 .4041 m .67112 .40609 L .6684 .40446 L F
.67112 .40609 m .67152 .40627 L .6684 .40446 L F
.742 .249 .066 r
.67309 .40655 m .67388 .40682 L .67376 .40533 L F
.84 .995 .755 r
.67617 .4059 m .67318 .40994 L .67411 .40722 L F
.67649 .40577 m .67318 .40994 L .67617 .4059 L F
.67611 .40588 m .67411 .40722 L .67424 .40684 L F
.67661 .40561 m .67411 .40722 L .67611 .40588 L F
.887 .457 .118 r
.67318 .40994 m .67233 .41099 L .67424 .40684 L F
.873 .607 .533 r
.67233 .41099 m .66988 .40776 L .67424 .40684 L F
.742 .249 .066 r
.67388 .40682 m .67603 .40757 L .67487 .40642 L F
.67388 .40682 m .67487 .40642 L .67376 .40533 L F
.84 .995 .755 r
.67661 .40561 m .67649 .40577 L .67617 .4059 L F
.316 0 0 r
.67392 .40525 m .67645 .40565 L .67805 .40445 L F
.67645 .40565 m .677 .40573 L .67784 .4047 L F
.67645 .40565 m .67784 .4047 L .67805 .40445 L F
.199 0 0 r
.54608 .61173 m .54857 .6123 L .54463 .61144 L F
.466 .135 .32 r
.57959 .47074 m .58195 .47031 L .58309 .46798 L F
.628 .305 .404 r
.58309 .46798 m .58572 .46992 L .58544 .46805 L F
.58309 .46798 m .58195 .47031 L .58572 .46992 L F
.375 .268 .603 r
.52566 .54723 m .52568 .54749 L .52385 .54816 L F
.488 .788 .998 r
.52385 .54816 m .5254 .5494 L .52219 .54876 L F
.516 .061 .11 r
.5254 .5494 m .52817 .55031 L .52795 .54958 L F
.7 .173 0 r
.52385 .54816 m .52817 .55031 L .5254 .5494 L F
.52469 .54858 m .52583 .55009 L .52817 .55031 L F
.52385 .54816 m .52583 .55009 L .52469 .54858 L F
.915 .588 .412 r
.52583 .55009 m .52652 .55236 L .52817 .55031 L F
.725 .555 0 r
.52619 .54729 m .52642 .55088 L .52583 .55009 L F
.52642 .55088 m .52652 .55236 L .52583 .55009 L F
.375 .268 .603 r
.52568 .54749 m .52583 .55009 L .52385 .54816 L F
.488 .788 .998 r
.52385 .54816 m .52219 .54876 L .52165 .54865 L F
.299 0 0 r
.16661 .56776 m .16483 .57045 L .16305 .56986 L F
.099 0 .278 r
.16823 .5657 m .16769 .56798 L .16661 .56776 L F
.428 .024 .169 r
.16769 .56798 m .16483 .57045 L .16661 .56776 L F
0 0 .234 r
.51964 .53696 m .51772 .53317 L .51904 .53418 L F
.406 .103 .335 r
.45225 .58495 m .4513 .58778 L .4489 .58853 L F
.401 .099 .334 r
.45389 .58684 m .45225 .58495 L .45477 .58541 L F
.45389 .58684 m .4513 .58778 L .45225 .58495 L F
.728 .199 0 r
.77482 .40158 m .7742 .40067 L .77292 .40059 L F
.77482 .40158 m .7742 .40067 L .77292 .40059 L F
.836 .598 .58 r
.62754 .42902 m .62697 .43139 L .63029 .43137 L F
.705 .5 .608 r
.48657 .58774 m .49065 .58523 L .48665 .58523 L F
.36 .128 .421 r
.49065 .58523 m .49347 .58532 L .49212 .58352 L F
.392 .066 .289 r
.44283 .55795 m .44438 .5598 L .44553 .55703 L F
.44283 .55795 m .44208 .56054 L .44438 .5598 L F
.316 .173 .522 r
.57888 .56899 m .57635 .57232 L .5759 .57017 L F
.403 .228 .526 r
.27264 .60864 m .27227 .61103 L .27039 .61159 L F
.498 .25 .469 r
.27227 .61103 m .26961 .61416 L .27039 .61159 L F
.611 .956 .877 r
.43732 .59853 m .43693 .59962 L .43843 .59992 L F
.429 .828 .62 r
.43624 .59933 m .43549 .5998 L .43732 .59853 L F
.611 .956 .877 r
.43732 .59853 m .43549 .5998 L .43693 .59962 L F
.771 .688 .772 r
.1973 .70846 m .19852 .71094 L .1955 .71071 L F
.1955 .71071 m .19852 .71094 L .1973 .70846 L F
.725 .345 .33 r
.19852 .71094 m .19663 .71151 L .1955 .71071 L F
.977 .682 .388 r
.1973 .70846 m .19684 .71032 L .19852 .71094 L F
.686 .652 .811 r
.1973 .70846 m .19852 .71094 L .20192 .71014 L F
.808 .962 .909 r
.19684 .71032 m .19663 .71151 L .19852 .71094 L F
.477 .239 .473 r
.42514 .59101 m .4277 .58829 L .42623 .58714 L F
.42514 .59101 m .42788 .59047 L .4277 .58829 L F
.766 .785 .868 r
.42788 .59047 m .43087 .58922 L .4277 .58829 L F
0 0 .182 r
.57198 .5935 m .57182 .59591 L .56993 .59686 L F
0 0 .023 r
.57182 .59591 m .56933 .59898 L .56993 .59686 L F
.911 .509 .2 r
.43578 .62508 m .4354 .62634 L .43555 .62414 L F
0 0 .363 r
.40558 .64166 m .40523 .63811 L .40464 .63874 L F
.40558 .64166 m .40587 .64059 L .40523 .63811 L F
0 .12 .671 r
.40558 .64166 m .40768 .64394 L .40587 .64059 L F
.666 .335 .403 r
.201 .55453 m .19719 .55619 L .19862 .55472 L F
0 0 .121 r
.42732 .58113 m .42664 .58215 L .42734 .58203 L F
.42702 .58158 m .42702 .5816 L .42664 .58215 L F
0 .126 .675 r
.42496 .57882 m .42702 .5816 L .42664 .58215 L F
.735 .251 0 r
.426 .58088 m .42708 .58181 L .42597 .58024 L F
.42708 .58181 m .42702 .5816 L .42496 .57882 L F
0 0 0 r
.42643 .58009 m .42604 .58151 L .426 .58088 L F
0 0 .121 r
.42708 .58152 m .42668 .5836 L .42664 .58215 L F
.42668 .5836 m .42649 .58462 L .42651 .58426 L F
.42668 .5836 m .42651 .58426 L .42664 .58215 L F
0 .126 .675 r
.42702 .5816 m .42734 .58203 L .42664 .58215 L F
.954 .609 .242 r
.42708 .58181 m .42708 .58205 L .42734 .58203 L F
.735 .251 0 r
.42708 .58181 m .42734 .58203 L .42702 .5816 L F
.894 .984 .715 r
.42734 .58203 m .42708 .58205 L .42732 .58113 L F
.954 .609 .242 r
.426 .58088 m .42707 .58204 L .42708 .58181 L F
0 0 .121 r
.42708 .58213 m .42649 .58462 L .42708 .58152 L F
.954 .609 .242 r
.42707 .58204 m .42708 .58205 L .42708 .58203 L F
.42707 .58204 m .42708 .58203 L .42708 .58181 L F
.763 .922 .941 r
.42586 .58215 m .42546 .58439 L .42679 .58206 L F
.954 .609 .242 r
.426 .58088 m .42589 .58186 L .42708 .58205 L F
.42589 .58186 m .42586 .58215 L .42683 .58207 L F
.42589 .58186 m .42683 .58207 L .42708 .58205 L F
0 0 .121 r
.42732 .58113 m .42731 .58119 L .42702 .5816 L F
.42732 .58113 m .42702 .5816 L .42702 .58158 L F
.763 .922 .941 r
.42586 .58215 m .42679 .58206 L .42732 .58113 L F
.911 .98 .773 r
.42732 .58113 m .42679 .58206 L .42683 .58207 L F
0 0 .121 r
.42731 .58119 m .42708 .58213 L .42708 .58152 L F
.894 .984 .715 r
.42708 .58205 m .42683 .58207 L .42732 .58113 L F
.911 .98 .773 r
.42732 .58113 m .42683 .58207 L .42708 .58213 L F
.894 .984 .715 r
.42683 .58207 m .42586 .58215 L .42732 .58113 L F
.911 .98 .773 r
.42708 .58213 m .42546 .58439 L .42649 .58462 L F
.42679 .58206 m .42546 .58439 L .42708 .58213 L F
0 0 0 r
.42604 .58151 m .42586 .58215 L .426 .58088 L F
.735 .251 0 r
.426 .58088 m .42597 .58024 L .42496 .57882 L F
.766 .785 .868 r
.42788 .59047 m .43154 .591 L .43087 .58922 L F
.42788 .59047 m .4286 .59136 L .43154 .591 L F
.527 .434 .693 r
.43154 .591 m .43296 .58802 L .43087 .58922 L F
.43154 .591 m .43373 .59046 L .43296 .58802 L F
.16 .363 .815 r
.43154 .591 m .43374 .59287 L .43373 .59046 L F
.644 .283 0 r
.52543 .57318 m .52488 .57201 L .52369 .56943 L F
.57 .121 0 r
.52543 .57318 m .52595 .5739 L .52488 .57201 L F
.52543 .57318 m .52688 .57514 L .52595 .5739 L F
.631 .417 .575 r
.57907 .49127 m .57534 .4949 L .57535 .49296 L F
.59 .362 .539 r
.6982 .41133 m .69811 .41358 L .6955 .41405 L F
.641 .433 .585 r
.70159 .41083 m .69811 .41358 L .6982 .41133 L F
.066 0 0 r
.4383 .634 m .4429 .63241 L .44066 .63282 L F
0 0 .427 r
.43916 .60426 m .43773 .60595 L .43796 .60324 L F
.43916 .60426 m .43796 .60324 L .43641 .60338 L F
.691 .96 .946 r
.53454 .52153 m .53788 .51954 L .53604 .51922 L F
.709 .971 .74 r
.53454 .52153 m .53604 .51922 L .53279 .52238 L F
.891 .979 .818 r
.68028 .43179 m .67903 .43526 L .67879 .43549 L F
.789 .862 .904 r
.68342 .43161 m .67903 .43526 L .68028 .43179 L F
.966 .753 .565 r
.22514 .66034 m .22292 .66166 L .22317 .65912 L F
.22317 .65912 m .22514 .66034 L .22725 .65797 L F
.22317 .65912 m .22292 .66166 L .22514 .66034 L F
0 0 .382 r
.53282 .60037 m .5327 .59902 L .5319 .59668 L F
0 0 .399 r
.53282 .60037 m .53363 .6012 L .5327 .59902 L F
.53282 .60037 m .53368 .60265 L .53363 .6012 L F
.88 .779 .746 r
.75247 .40492 m .74924 .40692 L .75187 .40373 L F
.75247 .40492 m .75103 .40837 L .74924 .40692 L F
.948 .952 .653 r
.75342 .40085 m .75247 .40492 L .75187 .40373 L F
.702 .574 .708 r
.42235 .63334 m .41983 .63615 L .41916 .63282 L F
.226 .079 .462 r
.42074 .62974 m .42049 .63261 L .41916 .63282 L F
.702 .574 .708 r
.42235 .63334 m .41916 .63282 L .42049 .63261 L F
.58 .409 .614 r
.44193 .56712 m .43951 .57017 L .43837 .5668 L F
.44193 .56712 m .44198 .56977 L .43951 .57017 L F
.582 .415 .62 r
.44198 .56977 m .43964 .57263 L .43951 .57017 L F
.069 .304 .788 r
.21706 .68223 m .21818 .68342 L .21723 .68447 L F
.516 .406 .667 r
.21723 .68447 m .22009 .68634 L .21796 .68711 L F
0 0 0 r
.21814 .68705 m .21569 .68655 L .21796 .68711 L F
.22009 .68634 m .21913 .68639 L .21814 .68705 L F
.21913 .68639 m .21569 .68655 L .21814 .68705 L F
.756 .716 .815 r
.21369 .68639 m .2149 .68872 L .21796 .68711 L F
.21369 .68639 m .217 .68695 L .21569 .68655 L F
.217 .68695 m .21796 .68711 L .21569 .68655 L F
.651 .108 0 r
.21569 .68655 m .21492 .68765 L .21429 .68613 L F
.265 .626 .961 r
.21369 .68639 m .21569 .68655 L .2139 .68518 L F
.651 .108 0 r
.21569 .68655 m .21429 .68613 L .2139 .68518 L F
0 0 0 r
.22009 .68634 m .21893 .68749 L .21834 .68841 L F
.21834 .68841 m .21893 .68749 L .22009 .68634 L F
.22009 .68634 m .21834 .68841 L .21569 .68655 L F
.441 .584 .899 r
.22029 .68532 m .22009 .68634 L .21818 .68342 L F
0 0 0 r
.21834 .68841 m .22009 .68634 L .22029 .68532 L F
.21834 .68841 m .21997 .68582 L .22095 .68537 L F
.21997 .68582 m .22013 .68558 L .22047 .68549 L F
.21997 .68582 m .22047 .68549 L .22095 .68537 L F
.22013 .68558 m .22029 .68532 L .22075 .68535 L F
.22013 .68558 m .22075 .68535 L .22095 .68537 L F
.127 .395 .847 r
.21818 .68342 m .21969 .68573 L .21723 .68447 L F
.21969 .68573 m .22009 .68634 L .21934 .68586 L F
.21969 .68573 m .21934 .68586 L .21723 .68447 L F
.738 .896 .505 r
.67356 .44292 m .6726 .44453 L .67324 .44295 L F
0 0 .539 r
.67324 .44295 m .6726 .44453 L .67343 .446 L F
.339 .803 .699 r
.78124 .39019 m .7777 .39166 L .78086 .38886 L F
0 .308 .801 r
.78382 .39196 m .78124 .39019 L .78086 .38886 L F
.627 .797 .964 r
.78018 .40167 m .78367 .40227 L .78288 .4008 L F
.782 .472 .464 r
.78367 .40432 m .78367 .40227 L .78018 .40167 L F
.417 .669 .965 r
.78288 .4008 m .78367 .40227 L .78498 .40079 L F
0 0 .281 r
.78498 .40079 m .78367 .40227 L .78367 .40432 L F
.695 .605 .752 r
.43837 .5668 m .43471 .56895 L .43615 .56787 L F
0 0 0 r
.14884 .56034 m .15226 .5581 L .14982 .55933 L F
.499 .265 .491 r
.39851 .60007 m .40127 .59964 L .40141 .59687 L F
.448 .26 .531 r
.40141 .59687 m .40385 .59639 L .40371 .59383 L F
.416 .199 .473 r
.40141 .59687 m .40371 .59881 L .40385 .59639 L F
.40141 .59687 m .40127 .59964 L .40371 .59881 L F
.54 .364 .591 r
.27712 .59984 m .27722 .6023 L .2749 .60266 L F
.529 .408 .658 r
.27707 .60513 m .2749 .60266 L .27722 .6023 L F
.27707 .60513 m .27519 .60588 L .2749 .60266 L F
0 0 0 r
.55259 .50372 m .55163 .50541 L .55003 .50699 L F
.55163 .50541 m .54867 .50838 L .55003 .50699 L F
.988 .837 .458 r
.76107 .40873 m .76201 .40826 L .76156 .40656 L F
.76107 .40873 m .76155 .41116 L .76201 .40826 L F
.318 .589 .941 r
.39475 .62427 m .39562 .6228 L .39405 .62279 L F
.116 .32 .79 r
.39475 .62427 m .39723 .62611 L .39562 .6228 L F
.882 .989 .808 r
.50217 .52646 m .5006 .52852 L .5006 .52697 L F
.902 .928 .824 r
.49933 .53093 m .5006 .52697 L .5006 .52852 L F
.614 .279 .379 r
.3931 .6051 m .39573 .60504 L .39352 .60307 L F
.534 .298 .502 r
.39352 .60307 m .39573 .60504 L .39593 .60268 L F
.683 .687 .847 r
.46893 .58586 m .46937 .5821 L .46708 .58463 L F
.523 .438 .7 r
.63757 .41983 m .641 .42158 L .6398 .41883 L F
.081 0 .388 r
.57245 .54915 m .57229 .55159 L .5736 .54815 L F
.019 .092 .599 r
.64208 .41034 m .64276 .41432 L .64359 .41112 L F
.74 .77 .269 r
.64276 .41432 m .64224 .41562 L .64359 .41112 L F
.536 .526 .792 r
.43023 .57265 m .43116 .57615 L .43339 .57524 L F
.451 .179 .409 r
.42734 .58203 m .43087 .57829 L .43094 .58116 L F
.321 0 0 r
.43094 .58116 m .42948 .58258 L .42734 .58203 L F
0 0 .056 r
.43087 .57829 m .42974 .58164 L .43007 .58102 L F
.513 .209 .389 r
.4335 .57742 m .43087 .57829 L .43144 .57631 L F
.4335 .57742 m .43087 .57829 L .43116 .57615 L F
0 0 .056 r
.43087 .57829 m .43217 .57708 L .4335 .57742 L F
.345 .128 .433 r
.4335 .57742 m .43094 .58116 L .43087 .57829 L F
0 0 .056 r
.43087 .57829 m .43007 .58102 L .43217 .57708 L F
.513 .209 .389 r
.43144 .57631 m .43087 .57829 L .43116 .57615 L F
.845 .706 .71 r
.60622 .46707 m .60416 .47027 L .60759 .47076 L F
.844 .706 .71 r
.60416 .47027 m .60549 .47381 L .60759 .47076 L F
0 0 .49 r
.52942 .58467 m .53052 .58825 L .53037 .58683 L F
.882 .511 .034 r
.53052 .58825 m .53033 .58944 L .53037 .58683 L F
.53052 .58825 m .53139 .59068 L .53033 .58944 L F
.636 .47 .64 r
.41217 .61798 m .41607 .61888 L .41459 .61478 L F
.592 .446 .652 r
.41459 .61478 m .41607 .61888 L .41775 .61693 L F
.891 .979 .818 r
.68028 .43179 m .67879 .43549 L .67745 .43417 L F
0 .043 .594 r
.25996 .56441 m .26051 .563 L .25898 .5608 L F
.219 .478 .889 r
.25996 .56441 m .26294 .56607 L .26051 .563 L F
.702 .866 .959 r
.70415 .42777 m .70726 .42793 L .70725 .42583 L F
.776 .898 .929 r
.70725 .42583 m .70726 .42793 L .71035 .4257 L F
.735 .737 .853 r
.61996 .43848 m .62346 .43887 L .62229 .43752 L F
.708 .553 .676 r
.62357 .42367 m .62309 .42604 L .6256 .42289 L F
.712 .6 .729 r
.62627 .42011 m .6256 .42289 L .62816 .42016 L F
.534 .855 .997 r
.49383 .57907 m .49755 .57907 L .49703 .57824 L F
.621 .163 .144 r
.49383 .57907 m .49618 .5806 L .49755 .57907 L F
.974 .905 .56 r
.49755 .57907 m .49618 .5806 L .49703 .57824 L F
.836 .669 .675 r
.60546 .48874 m .606 .48644 L .60461 .48585 L F
.617 .439 .618 r
.44025 .62031 m .43769 .618 L .44012 .61761 L F
.44025 .62031 m .43797 .62099 L .43769 .618 L F
.065 0 .373 r
.57411 .59011 m .57385 .59258 L .57198 .5935 L F
0 0 .18 r
.57385 .59258 m .57182 .59591 L .57198 .5935 L F
.621 .622 .83 r
.22188 .64891 m .22619 .6511 L .22447 .64937 L F
.712 .757 .887 r
.22447 .64937 m .22619 .6511 L .22726 .64971 L F
.13 .1 .553 r
.57528 .58339 m .57399 .58756 L .57384 .58505 L F
.393 .059 .275 r
.69319 .40232 m .69034 .40466 L .69307 .40451 L F
.495 .218 .423 r
.69307 .40451 m .69574 .40195 L .69319 .40232 L F
.818 .858 .878 r
.43615 .56787 m .43223 .56891 L .43454 .56638 L F
.721 .747 .873 r
.43837 .5668 m .43615 .56787 L .43454 .56638 L F
.382 .024 .226 r
.17185 .564 m .16823 .5657 L .16967 .5646 L F
.641 .57 .759 r
.41753 .64177 m .4157 .64387 L .41367 .64074 L F
.529 0 0 r
.53884 .61121 m .54208 .61247 L .54096 .61263 L F
.346 .818 .76 r
.54096 .61263 m .54208 .61247 L .54463 .61144 L F
0 0 0 r
.4616 .56014 m .46397 .56001 L .46502 .55987 L F
.411 .86 .808 r
.46502 .55987 m .46618 .55904 L .46788 .55907 L F
.46502 .55987 m .46397 .56001 L .46618 .55904 L F
.417 .142 .385 r
.25011 .63293 m .24945 .63527 L .24736 .63579 L F
.384 .122 .389 r
.25217 .63227 m .24945 .63527 L .25011 .63293 L F
0 0 0 r
.75755 .38529 m .75797 .38438 L .7559 .38666 L F
.247 .297 .718 r
.75755 .38529 m .7559 .38666 L .75881 .38906 L F
.099 .346 .815 r
.7559 .38666 m .75764 .38864 L .75881 .38906 L F
.577 .616 .855 r
.78941 .42424 m .79415 .42787 L .7882 .42699 L F
.78972 .42406 m .79415 .42787 L .78941 .42424 L F
.78949 .42422 m .7882 .42699 L .78891 .42696 L F
.396 .567 .905 r
.79416 .4275 m .78973 .42406 L .79368 .42478 L F
0 0 0 r
.78991 .42392 m .79127 .42283 L .78913 .42433 L F
.437 .838 .639 r
.78792 .42505 m .79127 .42283 L .78955 .42392 L F
.396 .567 .905 r
.78973 .42406 m .78955 .42392 L .78983 .42398 L F
.762 .632 .717 r
.79293 .42177 m .79368 .42478 L .79014 .42404 L F
.79071 .42335 m .79014 .42404 L .78983 .42398 L F
.79293 .42177 m .79014 .42404 L .79071 .42335 L F
.79272 .42093 m .78955 .42392 L .79127 .42283 L F
.711 .932 .61 r
.79272 .42093 m .79181 .42212 L .79124 .42271 L F
0 0 0 r
.7902 .42377 m .79033 .42363 L .78992 .42392 L F
.79035 .42369 m .79033 .42363 L .7902 .42377 L F
.79035 .42369 m .79071 .42335 L .79033 .42363 L F
.711 .932 .61 r
.79181 .42212 m .79127 .42283 L .79086 .42321 L F
.79181 .42212 m .79086 .42321 L .79071 .42335 L F
.79181 .42212 m .79071 .42335 L .79124 .42271 L F
.762 .632 .717 r
.79272 .42093 m .79293 .42177 L .79101 .42299 L F
.79272 .42093 m .79101 .42299 L .78955 .42392 L F
0 0 0 r
.79071 .42335 m .79127 .42283 L .78992 .42392 L F
.78992 .42392 m .78996 .42388 L .78991 .42392 L F
.78996 .42388 m .79127 .42283 L .78991 .42392 L F
.762 .632 .717 r
.79293 .42177 m .78983 .42398 L .78955 .42392 L F
.711 .932 .61 r
.79124 .42271 m .79071 .42335 L .78989 .42412 L F
.577 .616 .855 r
.78941 .42424 m .7882 .42699 L .78949 .42422 L F
.78949 .42422 m .78891 .42696 L .78792 .42505 L F
0 0 0 r
.78848 .42479 m .78868 .42465 L .78792 .42505 L F
.78868 .42465 m .79127 .42283 L .78792 .42505 L F
.79035 .42369 m .78913 .42433 L .78941 .42424 L F
.577 .616 .855 r
.78955 .42392 m .78972 .42406 L .78941 .42424 L F
.78955 .42392 m .78941 .42424 L .78949 .42422 L F
0 0 0 r
.78941 .42424 m .78913 .42433 L .78848 .42479 L F
.577 .616 .855 r
.78955 .42392 m .78949 .42422 L .78792 .42505 L F
.711 .932 .61 r
.79272 .42093 m .79124 .42271 L .78989 .42412 L F
.396 .567 .905 r
.78973 .42406 m .78983 .42398 L .79014 .42404 L F
.79008 .42412 m .79014 .42404 L .79368 .42478 L F
.78973 .42406 m .79014 .42404 L .79008 .42412 L F
.79416 .4275 m .79415 .42787 L .78972 .42406 L F
.78973 .42406 m .78972 .42406 L .78955 .42392 L F
.79416 .4275 m .78972 .42406 L .78973 .42406 L F
0 0 0 r
.78989 .42412 m .79021 .42382 L .78848 .42479 L F
.79021 .42382 m .79035 .42369 L .78972 .42406 L F
.79021 .42382 m .78972 .42406 L .78848 .42479 L F
.419 .451 .787 r
.78533 .4257 m .78891 .42696 L .7882 .42699 L F
.78533 .4257 m .7864 .42944 L .78891 .42696 L F
.382 .392 .746 r
.7864 .42944 m .78917 .43108 L .78891 .42696 L F
.514 .303 .53 r
.56504 .56085 m .56804 .56038 L .5681 .55813 L F
.558 .413 .639 r
.56564 .56379 m .56804 .56038 L .56504 .56085 L F
.382 .498 .852 r
.2032 .7075 m .20499 .71119 L .20616 .70979 L F
.501 .529 .817 r
.76399 .38631 m .76176 .38682 L .76031 .38258 L F
.439 .495 .82 r
.76505 .39 m .76176 .38682 L .76399 .38631 L F
0 0 0 r
.44392 .65276 m .44297 .65345 L .44208 .65398 L F
.714 .245 .134 r
.54463 .61144 m .54857 .6123 L .54708 .61368 L F
0 0 0 r
.54857 .6123 m .54889 .61259 L .54708 .61368 L F
.54857 .6123 m .55088 .61152 L .54889 .61259 L F
.76 .757 .85 r
.42438 .58921 m .42151 .59048 L .42514 .59101 L F
.761 .487 .518 r
.42139 .59304 m .42514 .59101 L .42151 .59048 L F
.42139 .59304 m .42499 .59355 L .42514 .59101 L F
.477 .239 .473 r
.42514 .59101 m .42623 .58714 L .42438 .58921 L F
.56 .314 .5 r
.42514 .59101 m .42754 .59304 L .42788 .59047 L F
.42514 .59101 m .42499 .59355 L .42754 .59304 L F
.382 .816 .657 r
.24392 .55156 m .24022 .55356 L .24182 .55184 L F
.732 .64 .757 r
.44094 .56363 m .44193 .56712 L .43837 .5668 L F
.625 .576 .779 r
.44457 .56668 m .44193 .56712 L .44094 .56363 L F
.511 .308 .542 r
.44457 .56668 m .44198 .56977 L .44193 .56712 L F
.801 .771 .825 r
.789 .41461 m .79002 .4172 L .79273 .4145 L F
0 0 0 r
.75103 .40837 m .74625 .41147 L .74827 .4103 L F
.671 .874 .975 r
.77965 .42677 m .78285 .42678 L .78186 .42538 L F
.672 .828 .958 r
.78285 .42678 m .78533 .4257 L .78186 .42538 L F
0 0 0 r
.71963 .39594 m .72298 .39348 L .72177 .39467 L F
.653 .887 .537 r
.72177 .39467 m .72298 .39348 L .72405 .39199 L F
.398 .843 .739 r
.21829 .65043 m .22188 .64891 L .22023 .64915 L F
.117 .597 .913 r
.22188 .64891 m .22272 .64833 L .22023 .64915 L F
.22188 .64891 m .22447 .64937 L .22272 .64833 L F
.421 .195 .464 r
.79878 .43308 m .79641 .4322 L .79903 .43159 L F
.79878 .43308 m .79635 .43426 L .79641 .4322 L F
.526 .335 .564 r
.79887 .42914 m .79903 .43159 L .79641 .4322 L F
.216 .177 .596 r
.57695 .57427 m .57705 .57789 L .57541 .57602 L F
.258 .185 .579 r
.57541 .57602 m .57705 .57789 L .57573 .57867 L F
.783 .771 .842 r
.7006 .42053 m .69641 .42195 L .69908 .41925 L F
.767 .754 .842 r
.7018 .41639 m .7006 .42053 L .69908 .41925 L F
.7018 .41639 m .70268 .41942 L .7006 .42053 L F
.403 .695 .98 r
.26539 .54218 m .26488 .54374 L .26326 .54241 L F
.26539 .54218 m .26703 .54359 L .26488 .54374 L F
.715 .754 .883 r
.43373 .59046 m .43808 .59106 L .43605 .58938 L F
.717 .484 .571 r
.43374 .59287 m .43808 .59106 L .43373 .59046 L F
.43374 .59287 m .43789 .59321 L .43808 .59106 L F
.698 .752 .893 r
.43605 .58938 m .43808 .59106 L .43949 .59073 L F
.672 .456 .584 r
.43789 .59321 m .43949 .59073 L .43808 .59106 L F
.716 .513 .614 r
.43949 .59073 m .43789 .59321 L .43808 .59106 L F
.361 .174 .487 r
.24532 .60241 m .24348 .60302 L .24324 .6054 L F
.468 .283 .546 r
.41966 .57928 m .42209 .57887 L .42191 .57604 L F
.221 .017 .377 r
.41966 .57928 m .42107 .58056 L .42209 .57887 L F
.41966 .57928 m .41939 .58172 L .42107 .58056 L F
.675 .811 .948 r
.64403 .42521 m .64558 .42698 L .6479 .42582 L F
.527 .793 .994 r
.45109 .59888 m .44931 .59979 L .44729 .59849 L F
.274 0 0 r
.44729 .59849 m .45109 .59888 L .44931 .59979 L F
.477 .358 .638 r
.44816 .60226 m .45109 .59888 L .44931 .59979 L F
.55 .041 0 r
.49736 .59125 m .49821 .59217 L .49758 .59135 L F
.592 .567 .794 r
.2553 .55867 m .25898 .5608 L .25749 .5573 L F
.723 .729 .856 r
.70551 .41702 m .70268 .41942 L .7018 .41639 L F
0 0 0 r
.75103 .40837 m .74827 .4103 L .7497 .40941 L F
.75103 .40837 m .7497 .40941 L .74924 .40692 L F
0 0 .141 r
.57884 .56651 m .57962 .56414 L .58054 .56327 L F
.302 .411 .807 r
.64093 .42354 m .64301 .42192 L .641 .42158 L F
.64093 .42354 m .64403 .42521 L .64301 .42192 L F
.601 .154 .162 r
.68688 .40685 m .68426 .40528 L .68343 .40696 L F
.581 .212 .308 r
.68688 .40685 m .68718 .40521 L .68426 .40528 L F
.877 .536 .4 r
.6684 .40422 m .66569 .40097 L .66796 .40356 L F
.484 .308 .565 r
.44759 .61396 m .44528 .612 L .4479 .61182 L F
.44759 .61396 m .44538 .61456 L .44528 .612 L F
0 .356 .695 r
.49787 .56555 m .49955 .56618 L .50119 .56688 L F
.967 .744 .549 r
.49955 .56618 m .50079 .56998 L .50119 .56688 L F
.33 .066 .354 r
.54675 .51149 m .54501 .51039 L .54753 .5095 L F
.54675 .51149 m .54466 .5124 L .54501 .51039 L F
0 .104 .658 r
.53359 .56248 m .53582 .56592 L .5365 .56338 L F
.53359 .56248 m .53522 .56444 L .53582 .56592 L F
.88 .561 .053 r
.53522 .56444 m .53573 .56593 L .53582 .56592 L F
.756 .94 .602 r
.53582 .56592 m .53574 .56705 L .53653 .5659 L F
0 .073 .611 r
.53582 .56592 m .53647 .56802 L .53558 .56941 L F
.88 .561 .053 r
.53573 .56593 m .53647 .56802 L .53582 .56592 L F
.756 .94 .602 r
.53582 .56592 m .53653 .5659 L .538 .56379 L F
0 .073 .611 r
.53582 .56592 m .53558 .56941 L .53574 .56705 L F
.719 .564 .678 r
.61963 .4254 m .62309 .42604 L .62357 .42367 L F
.706 .777 .907 r
.71406 .41404 m .7112 .41597 L .71046 .41343 L F
.343 0 0 r
.21013 .55287 m .20538 .5534 L .20738 .55289 L F
.589 .295 .438 r
.50127 .58202 m .50363 .58399 L .50062 .58289 L F
.367 .39 .753 r
.50519 .60001 m .50785 .60309 L .50687 .59788 L F
.601 .715 .924 r
.17892 .62537 m .1801 .62723 L .17643 .62612 L F
.048 .372 .839 r
.18047 .62606 m .1801 .62723 L .17892 .62537 L F
.376 .743 .99 r
.18047 .62606 m .18237 .62708 L .1801 .62723 L F
.631 .417 .575 r
.57907 .49127 m .57967 .49496 L .57534 .4949 L F
.703 .467 .564 r
.58054 .49435 m .57907 .49127 L .58087 .49189 L F
.58054 .49435 m .57967 .49496 L .57907 .49127 L F
.447 .447 .766 r
.76773 .39135 m .76606 .39372 L .76505 .39 L F
0 0 0 r
.76544 .39469 m .76606 .39372 L .76773 .39135 L F
.859 .694 .676 r
.60528 .47641 m .60698 .47744 L .60549 .47381 L F
.874 .741 .712 r
.60333 .47921 m .60698 .47744 L .60528 .47641 L F
.136 0 .005 r
.46459 .57996 m .46256 .58111 L .46345 .57943 L F
0 0 0 r
.55259 .50372 m .55536 .50102 L .55482 .50294 L F
.364 .049 .291 r
.55779 .50023 m .55482 .50294 L .55536 .50102 L F
.359 .153 .458 r
.43285 .64159 m .43506 .64089 L .4351 .63862 L F
.567 .49 .729 r
.43643 .6445 m .43391 .64551 L .43285 .64159 L F
.422 .126 .355 r
.4321 .64383 m .43506 .64089 L .43285 .64159 L F
.957 .688 .483 r
.41043 .61684 m .41201 .62043 L .41217 .61798 L F
.742 .48 .533 r
.41217 .61798 m .41724 .62014 L .41607 .61888 L F
.41217 .61798 m .41201 .62043 L .41724 .62014 L F
.659 .906 .581 r
.43391 .64551 m .43173 .64781 L .43146 .64835 L F
.632 .285 .365 r
.43427 .64612 m .43391 .64551 L .43643 .6445 L F
.43427 .64612 m .43173 .64781 L .43391 .64551 L F
.946 .784 .326 r
.49057 .60531 m .49055 .60842 L .49091 .60736 L F
.696 .5 .619 r
.42983 .57018 m .42807 .57377 L .43023 .57265 L F
.45 .303 .589 r
.42983 .57018 m .43217 .572 L .43223 .56891 L F
.395 .581 .915 r
.79796 .42706 m .80041 .42737 L .79887 .42914 L F
.244 .351 .774 r
.80041 .42737 m .80148 .43064 L .79887 .42914 L F
.461 .286 .557 r
.80148 .43064 m .79903 .43159 L .79887 .42914 L F
0 .222 .744 r
.53215 .55827 m .53413 .56018 L .53413 .56102 L F
.926 .678 .543 r
.53413 .56018 m .5365 .56338 L .53413 .56102 L F
.925 .65 .166 r
.53722 .57516 m .53742 .57816 L .53806 .57901 L F
.39 .77 .991 r
.53742 .57816 m .5402 .57883 L .53806 .57901 L F
.235 0 .033 r
.22809 .55266 m .22519 .55364 L .22605 .55246 L F
.721 .862 .948 r
.69563 .43097 m .69969 .43048 L .69812 .42962 L F
.702 .926 .966 r
.69969 .43048 m .70099 .42846 L .69812 .42962 L F
.69969 .43048 m .70198 .42922 L .70099 .42846 L F
.431 .813 .99 r
.50663 .60876 m .51027 .609 L .50907 .60825 L F
.965 .932 .698 r
.77145 .40456 m .76993 .40462 L .77049 .40365 L F
.77145 .40456 m .76973 .40816 L .76993 .40462 L F
.796 .962 .916 r
.77049 .40365 m .77145 .40456 L .77482 .40158 L F
.441 0 0 r
.77462 .40424 m .77482 .40158 L .77145 .40456 L F
.517 .686 .944 r
.774 .4024 m .77145 .40456 L .77049 .40365 L F
.77405 .40246 m .77145 .40456 L .774 .4024 L F
.77405 .40246 m .77462 .40424 L .77145 .40456 L F
.986 .813 .42 r
.77469 .40324 m .77462 .40424 L .77405 .40246 L F
.517 .686 .944 r
.77423 .40231 m .77462 .40424 L .77405 .40246 L F
.796 .962 .916 r
.77049 .40365 m .77482 .40158 L .77292 .40059 L F
.655 .813 .959 r
.77394 .40226 m .77049 .40365 L .77227 .40195 L F
.986 .813 .42 r
.77482 .40158 m .77469 .40324 L .77389 .40227 L F
.655 .813 .959 r
.77423 .40231 m .774 .4024 L .77394 .40226 L F
.774 .4024 m .77049 .40365 L .77394 .40226 L F
.986 .813 .42 r
.774 .4024 m .77462 .40424 L .77389 .40227 L F
.77405 .40246 m .77417 .40283 L .774 .4024 L F
.77417 .40283 m .77462 .40424 L .774 .4024 L F
.77389 .40227 m .77462 .40424 L .77373 .40239 L F
.517 .686 .944 r
.77423 .40231 m .77405 .40246 L .774 .4024 L F
.798 .709 .766 r
.54433 .58139 m .54553 .58501 L .54803 .58213 L F
.596 .501 .717 r
.54803 .58213 m .5508 .58161 L .5499 .5802 L F
.546 .322 .526 r
.54803 .58213 m .5508 .58161 L .55034 .58426 L F
.596 .501 .717 r
.54803 .58213 m .5508 .58161 L .5499 .5802 L F
.546 .322 .526 r
.55034 .58426 m .5508 .58161 L .54803 .58213 L F
.324 .808 .875 r
.18623 .54267 m .18841 .54214 L .18984 .54213 L F
.477 .284 .539 r
.23382 .62062 m .2364 .61717 L .23472 .61739 L F
.98 .735 .493 r
.64977 .4076 m .64959 .40958 L .65084 .41036 L F
.971 .841 .657 r
.64848 .41263 m .65084 .41036 L .64959 .40958 L F
.64848 .41263 m .64999 .41413 L .65084 .41036 L F
.709 .184 0 r
.74717 .37394 m .74917 .3756 L .74849 .37632 L F
.707 .464 .554 r
.45109 .59888 m .45359 .5966 L .45154 .59738 L F
.399 0 0 r
.24795 .55164 m .2461 .55196 L .24392 .55156 L F
.574 .155 .209 r
.25008 .55128 m .2461 .55196 L .24795 .55164 L F
.197 0 0 r
.24197 .6419 m .238 .6436 L .23957 .64237 L F
.187 .688 .911 r
.23527 .53943 m .23734 .53952 L .23914 .54 L F
.521 .856 .995 r
.23914 .54 m .24091 .5391 L .24151 .53977 L F
.23914 .54 m .23734 .53952 L .24091 .5391 L F
.534 .413 .661 r
.2791 .59663 m .27953 .59939 L .27712 .59984 L F
.395 .192 .483 r
.27953 .59939 m .27722 .6023 L .27712 .59984 L F
.658 .538 .706 r
.60289 .44941 m .60522 .44615 L .60269 .4468 L F
.689 .648 .804 r
.73344 .41493 m .72986 .41396 L .73237 .41314 L F
.648 .629 .817 r
.73587 .41408 m .73344 .41493 L .73237 .41314 L F
.6 .906 .983 r
.66569 .40097 m .66543 .39869 L .66871 .39859 L F
.423 .851 .947 r
.66871 .39859 m .66543 .39869 L .66988 .39793 L F
.74 .941 .95 r
.76031 .38258 m .75797 .38438 L .75893 .38206 L F
.667 .772 .296 r
.75893 .38206 m .75797 .38438 L .75755 .38529 L F
.536 .39 .63 r
.55646 .57875 m .55861 .57583 L .55754 .57781 L F
.566 .569 .815 r
.53762 .56944 m .53667 .57469 L .53558 .56941 L F
.441 .394 .71 r
.53836 .57291 m .53722 .57516 L .53667 .57469 L F
.698 .752 .893 r
.43605 .58938 m .43949 .59073 L .43879 .58895 L F
.716 .513 .614 r
.43949 .59073 m .44082 .59418 L .43789 .59321 L F
.46 .243 .497 r
.44341 .59061 m .44082 .59418 L .43949 .59073 L F
.672 .456 .584 r
.43789 .59321 m .44084 .59335 L .43949 .59073 L F
.4 .672 .97 r
.43949 .59073 m .44096 .5889 L .43879 .58895 L F
.474 .544 .848 r
.44084 .59335 m .44096 .5889 L .43949 .59073 L F
.592 .325 .481 r
.7094 .40788 m .70658 .41021 L .7069 .40864 L F
.615 .932 .963 r
.17266 .62436 m .16977 .62566 L .16823 .62532 L F
.355 0 .164 r
.22528 .62636 m .22755 .62589 L .22908 .62321 L F
.312 0 .15 r
.22755 .62589 m .23103 .62267 L .22908 .62321 L F
.324 0 .207 r
.22908 .62321 m .23103 .62267 L .23194 .62176 L F
.872 .656 .606 r
.75415 .39614 m .75395 .39857 L .751 .39746 L F
.522 .317 .543 r
.42868 .56312 m .42789 .56523 L .43109 .56314 L F
.214 0 .357 r
.48115 .58579 m .47957 .5872 L .47965 .58502 L F
.643 .957 .768 r
.4805 .5862 m .47957 .5872 L .48115 .58579 L F
0 0 .28 r
.47965 .58502 m .47957 .5872 L .47811 .58876 L F
.643 .957 .768 r
.47735 .58823 m .47957 .5872 L .4805 .5862 L F
0 0 .28 r
.47811 .58876 m .47957 .5872 L .47779 .58955 L F
.771 .987 .897 r
.47779 .58955 m .47957 .5872 L .47633 .58963 L F
.808 .829 .867 r
.64274 .40935 m .64208 .41034 L .64436 .40825 L F
.266 0 .277 r
.64208 .41034 m .64404 .41 L .64436 .40825 L F
.019 .092 .599 r
.64208 .41034 m .64359 .41112 L .64404 .41 L F
.241 .752 .737 r
.42059 .60009 m .42276 .59944 L .42404 .59917 L F
.899 .984 .79 r
.42404 .59917 m .42494 .59644 L .42651 .59959 L F
.42404 .59917 m .42276 .59944 L .42494 .59644 L F
.504 .462 .743 r
.46402 .582 m .46692 .58449 L .46685 .5839 L F
.46555 .5815 m .46685 .5839 L .46654 .58119 L F
.46402 .582 m .46685 .5839 L .46555 .5815 L F
.46687 .58405 m .467 .58412 L .46654 .58119 L F
.676 .578 .738 r
.46654 .58119 m .467 .58412 L .46769 .58353 L F
.46654 .58119 m .46769 .58353 L .46872 .58189 L F
.467 .58412 m .46728 .58441 L .46937 .5821 L F
.348 .49 .859 r
.46721 .58423 m .46719 .58432 L .46708 .58416 L F
.46719 .58432 m .46719 .58435 L .46714 .58426 L F
.46719 .58432 m .46714 .58426 L .46708 .58416 L F
.4675 .58182 m .46721 .58423 L .46459 .57996 L F
.46721 .58423 m .46708 .58416 L .46459 .57996 L F
.504 .462 .743 r
.46689 .58426 m .46703 .58427 L .467 .58412 L F
.46689 .58426 m .467 .58412 L .46687 .58405 L F
.46692 .58449 m .46701 .58431 L .46689 .58426 L F
.46701 .58431 m .46703 .58427 L .46689 .58426 L F
.522 0 0 r
.46709 .58434 m .46396 .58503 L .46241 .58413 L F
.46227 .58385 m .46241 .58413 L .46184 .5838 L F
.46709 .58434 m .46241 .58413 L .46227 .58385 L F
.972 .748 .541 r
.46043 .58626 m .4626 .59018 L .46472 .5876 L F
.46043 .58626 m .46049 .58944 L .4626 .59018 L F
.287 0 0 r
.46051 .5871 m .45985 .58523 L .46244 .58418 L F
.294 .255 .644 r
.46184 .5838 m .46396 .58503 L .46262 .5841 L F
.287 0 0 r
.46249 .58428 m .46244 .58418 L .46262 .5841 L F
.46051 .5871 m .46244 .58418 L .46249 .58428 L F
.676 .578 .738 r
.46703 .58432 m .46708 .58463 L .46724 .58437 L F
.522 0 0 r
.46714 .58434 m .46714 .58436 L .46709 .58434 L F
.46719 .58435 m .46717 .58435 L .46714 .58434 L F
.46717 .58435 m .46714 .58436 L .46714 .58434 L F
.676 .578 .738 r
.46724 .58437 m .46708 .58463 L .46728 .58441 L F
.384 .009 .197 r
.46719 .58432 m .46717 .58435 L .46719 .58435 L F
.676 .578 .738 r
.46701 .5842 m .46703 .58432 L .46714 .58434 L F
.827 .579 .564 r
.46707 .58427 m .46709 .58434 L .46704 .58424 L F
.46719 .58435 m .46714 .58434 L .46707 .58427 L F
.46714 .58434 m .46709 .58434 L .46707 .58427 L F
.676 .578 .738 r
.467 .58412 m .4671 .58426 L .46714 .58426 L F
.827 .579 .564 r
.46714 .58426 m .46704 .58424 L .46708 .58416 L F
.46719 .58435 m .46707 .58427 L .46714 .58426 L F
.676 .578 .738 r
.46701 .5842 m .46714 .58434 L .46724 .58437 L F
.827 .579 .564 r
.46707 .58427 m .46704 .58424 L .46714 .58426 L F
.676 .578 .738 r
.467 .58412 m .46701 .5842 L .4671 .58426 L F
.46714 .58426 m .4671 .58426 L .46724 .58437 L F
.522 0 0 r
.46714 .58436 m .46396 .58503 L .46709 .58434 L F
.827 .579 .564 r
.46704 .58424 m .46184 .5838 L .46256 .58111 L F
.46709 .58434 m .46184 .5838 L .46704 .58424 L F
.46708 .58416 m .46256 .58111 L .46459 .57996 L F
.46704 .58424 m .46256 .58111 L .46708 .58416 L F
.384 .009 .197 r
.4675 .58182 m .46396 .58503 L .46717 .58435 L F
.4675 .58182 m .46717 .58435 L .46719 .58432 L F
.676 .578 .738 r
.46872 .58189 m .46769 .58353 L .46937 .5821 L F
.504 .462 .743 r
.46692 .58449 m .46708 .58463 L .46703 .58427 L F
.764 .54 .594 r
.68929 .41409 m .68545 .41628 L .68553 .41376 L F
.68929 .41409 m .68943 .41695 L .68545 .41628 L F
.653 .437 .578 r
.69093 .41409 m .68943 .41695 L .68929 .41409 L F
.945 .868 .732 r
.6557 .41119 m .65461 .41047 L .65665 .40632 L F
.939 .689 .534 r
.6557 .41119 m .65402 .41257 L .65461 .41047 L F
.855 .707 .697 r
.75525 .37513 m .75799 .37705 L .758 .37513 L F
.527 .917 .802 r
.50217 .52646 m .50258 .52576 L .50441 .52497 L F
.50217 .52646 m .5006 .52697 L .50258 .52576 L F
.391 .562 .902 r
.27934 .54713 m .27854 .54924 L .27669 .54657 L F
.494 .679 .948 r
.27934 .54713 m .28075 .54903 L .27854 .54924 L F
.34 0 .223 r
.53169 .51167 m .53232 .51023 L .5295 .51235 L F
.097 0 0 r
.53169 .51167 m .53476 .50964 L .53232 .51023 L F
.521 .781 .992 r
.20676 .55949 m .20863 .56068 L .20624 .5612 L F
.20676 .55949 m .20863 .56068 L .20624 .5612 L F
.735 .604 .71 r
.58488 .49208 m .58258 .49445 L .58087 .49189 L F
.58488 .49208 m .58449 .49483 L .58258 .49445 L F
.59 .295 .436 r
.43773 .60595 m .44001 .60795 L .44021 .60592 L F
.237 .298 .723 r
.43916 .60426 m .44001 .60795 L .43773 .60595 L F
.802 .681 .73 r
.20151 .70165 m .20335 .70473 L .20561 .70177 L F
0 0 0 r
.20561 .70177 m .20853 .70044 L .20646 .70185 L F
.709 .961 .945 r
.67343 .446 m .67912 .44376 L .67608 .44442 L F
.887 .83 .786 r
.67608 .44442 m .67912 .44376 L .67939 .44315 L F
0 0 .104 r
.71466 .40216 m .7165 .39895 L .71726 .4003 L F
0 0 0 r
.7165 .39895 m .71963 .39594 L .7188 .39726 L F
.091 0 .362 r
.71726 .4003 m .7165 .39895 L .7188 .39726 L F
.884 .768 .729 r
.58866 .50327 m .58698 .50664 L .58618 .50305 L F
.523 .255 .451 r
.39593 .60268 m .39843 .60232 L .39851 .60007 L F
.428 .15 .387 r
.39843 .60232 m .40127 .59964 L .39851 .60007 L F
.715 .282 .221 r
.41895 .65335 m .41891 .65561 L .41619 .65324 L F
.027 .149 .657 r
.42014 .65185 m .41895 .65335 L .41855 .65036 L F
.976 .887 .521 r
.21913 .6806 m .21802 .67854 L .21816 .67923 L F
.21802 .67854 m .21717 .67696 L .21816 .67923 L F
0 .29 .662 r
.21704 .67908 m .21825 .67967 L .21816 .67923 L F
.976 .887 .521 r
.21888 .68013 m .2195 .67652 L .21717 .67696 L F
.21913 .6806 m .2192 .67989 L .21888 .68013 L F
.2192 .67989 m .2195 .67652 L .21888 .68013 L F
0 0 0 r
.2232 .67622 m .22009 .6792 L .22158 .67701 L F
.948 .957 .68 r
.22158 .67701 m .21938 .67975 L .22008 .67921 L F
.976 .887 .521 r
.21913 .6806 m .21892 .68032 L .2195 .67652 L F
.948 .957 .68 r
.22008 .67922 m .21892 .68032 L .21913 .6806 L F
0 0 0 r
.22009 .6792 m .21892 .68032 L .21938 .67975 L F
.22009 .6792 m .21938 .67975 L .22158 .67701 L F
.22398 .67498 m .22158 .67701 L .22029 .67363 L F
.22445 .67515 m .22397 .67546 L .22398 .67498 L F
.22397 .67546 m .22158 .67701 L .22398 .67498 L F
.22445 .67515 m .2232 .67622 L .22158 .67701 L F
.38 0 .069 r
.22398 .67498 m .222 .67508 L .2232 .67622 L F
.674 .41 .514 r
.22303 .67204 m .22445 .67515 L .22029 .67363 L F
.357 .263 .61 r
.22489 .67352 m .22445 .67515 L .22303 .67204 L F
.38 0 .069 r
.22489 .67352 m .22401 .67399 L .22398 .67498 L F
.22401 .67399 m .222 .67508 L .22398 .67498 L F
.778 .679 .754 r
.2195 .67652 m .21892 .68032 L .2232 .67622 L F
.686 .728 .882 r
.21472 .67979 m .21682 .68132 L .21913 .6806 L F
.815 .579 .582 r
.21706 .68223 m .21472 .67979 L .21913 .6806 L F
.686 .461 .576 r
.21913 .6806 m .21818 .68342 L .21706 .68223 L F
.815 .579 .582 r
.21706 .68223 m .21431 .68227 L .21472 .67979 L F
.938 .759 .634 r
.21662 .68192 m .21913 .6806 L .21816 .67923 L F
.21662 .68192 m .21818 .68342 L .21913 .6806 L F
.21662 .68192 m .21816 .67923 L .22026 .68276 L F
.578 .569 .807 r
.22228 .68007 m .22026 .68276 L .21816 .67923 L F
0 .29 .662 r
.21825 .67967 m .2212 .68111 L .21816 .67923 L F
.254 0 0 r
.16526 .55163 m .16756 .55126 L .16951 .54956 L F
.094 0 0 r
.16951 .54956 m .16975 .55057 L .17143 .54849 L F
.16951 .54956 m .16756 .55126 L .16975 .55057 L F
.93 .918 .537 r
.75764 .38864 m .75588 .39225 L .7575 .39112 L F
.107 0 .229 r
.75881 .38906 m .75764 .38864 L .7575 .39112 L F
.506 .317 .559 r
.46018 .59408 m .46263 .59369 L .4626 .59018 L F
.593 .553 .779 r
.4626 .59018 m .46547 .59037 L .46472 .5876 L F
.381 .22 .535 r
.4626 .59018 m .46439 .59284 L .46547 .59037 L F
.4626 .59018 m .46263 .59369 L .46439 .59284 L F
0 0 .054 r
.25821 .57024 m .25898 .57113 L .26031 .56955 L F
.25821 .57024 m .25713 .57249 L .25898 .57113 L F
.216 .512 .911 r
.4762 .60702 m .47617 .60815 L .47438 .60755 L F
.592 .415 .611 r
.71466 .40216 m .71509 .40461 L .71243 .4049 L F
.71466 .40216 m .71509 .40461 L .71243 .4049 L F
.447 .317 .61 r
.71711 .40412 m .71466 .40216 L .71726 .4003 L F
.71711 .40412 m .71509 .40461 L .71466 .40216 L F
.108 0 0 r
.20049 .54084 m .20262 .54071 L .20473 .53995 L F
.387 0 0 r
.20262 .54071 m .20716 .5398 L .20473 .53995 L F
.808 .369 .2 r
.41601 .59783 m .41938 .59897 L .41881 .59635 L F
.41601 .59783 m .42059 .60009 L .41938 .59897 L F
.575 .349 .535 r
.71243 .4049 m .71517 .40695 L .71292 .40736 L F
.71243 .4049 m .71509 .40461 L .71517 .40695 L F
.945 .87 .733 r
.75784 .42329 m .75943 .42015 L .75831 .41887 L F
.765 .757 .845 r
.77675 .41651 m .77426 .41914 L .77793 .41961 L F
.825 .432 .307 r
.77728 .42182 m .77793 .41961 L .77426 .41914 L F
.77728 .42182 m .77828 .42163 L .77793 .41961 L F
.22 0 0 r
.22524 .53893 m .22744 .53886 L .22888 .53809 L F
.653 .437 .578 r
.69093 .41409 m .69287 .41639 L .68943 .41695 L F
.664 .369 .462 r
.69093 .41409 m .69565 .4162 L .69287 .41639 L F
.69093 .41409 m .6955 .41405 L .69565 .4162 L F
.598 .642 .866 r
.54287 .59352 m .54214 .59755 L .54058 .59357 L F
.54287 .59352 m .54452 .59674 L .54214 .59755 L F
.398 0 0 r
.43443 .6022 m .43641 .60338 L .43413 .60196 L F
0 0 0 r
.47191 .59094 m .46966 .59249 L .46867 .59286 L F
.482 .092 .225 r
.44278 .63754 m .44252 .6377 L .44078 .63848 L F
.29 .063 .386 r
.44078 .63848 m .43874 .64126 L .4389 .63933 L F
.848 .99 .726 r
.43919 .64066 m .43855 .64009 L .43874 .64126 L F
.44078 .63848 m .43855 .64009 L .43919 .64066 L F
.45 0 0 r
.43855 .64009 m .44141 .64229 L .43968 .64103 L F
.43855 .64009 m .43968 .64103 L .43799 .63959 L F
.43855 .64009 m .43799 .63959 L .43742 .63911 L F
.482 .092 .225 r
.44252 .6377 m .43855 .64009 L .44078 .63848 L F
.29 .063 .386 r
.44078 .63848 m .4389 .63933 L .43892 .63901 L F
.637 .151 .082 r
.677 .40573 m .68099 .40624 L .67805 .40445 L F
.114 .402 .854 r
.50857 .57779 m .50584 .57645 L .50516 .5747 L F
.671 .81 .95 r
.71765 .41446 m .71406 .41404 L .71634 .41281 L F
.727 .792 .904 r
.71985 .41326 m .71765 .41446 L .71634 .41281 L F
.175 .506 .911 r
.78679 .39342 m .78439 .39368 L .78382 .39196 L F
.78679 .39342 m .78759 .3949 L .78439 .39368 L F
.44 .272 .555 r
.43354 .58558 m .43506 .58677 L .43589 .58431 L F
.43354 .58558 m .43296 .58802 L .43506 .58677 L F
.801 .771 .825 r
.789 .41461 m .79273 .4145 L .79165 .4141 L F
.406 .355 .689 r
.79441 .41351 m .7952 .41595 L .79273 .4145 L F
.387 0 0 r
.79273 .4145 m .79388 .41526 L .79165 .4141 L F
.79273 .4145 m .7952 .41595 L .79388 .41526 L F
.41 .191 .468 r
.45327 .62042 m .45078 .62341 L .45035 .6212 L F
.45327 .62042 m .45291 .6235 L .45078 .62341 L F
.431 .123 .341 r
.45291 .6235 m .45007 .62588 L .45078 .62341 L F
.738 .487 .549 r
.42191 .57604 m .42209 .57887 L .42496 .57882 L F
0 0 0 r
.7188 .39726 m .71963 .39594 L .72177 .39467 L F
.923 .775 .68 r
.20953 .68709 m .20891 .68986 L .20892 .68822 L F
.20953 .68709 m .20892 .68822 L .21173 .68874 L F
.855 .707 .697 r
.75525 .37513 m .758 .37513 L .75763 .37518 L F
.187 .418 .853 r
.75849 .37396 m .758 .37513 L .75604 .37206 L F
.729 .903 .526 r
.75763 .37518 m .758 .37513 L .75849 .37396 L F
0 0 0 r
.49241 .53978 m .49334 .53854 L .49378 .5369 L F
.568 .059 0 r
.49946 .54602 m .50028 .54711 L .49826 .54487 L F
.49946 .54602 m .50154 .54826 L .50028 .54711 L F
.725 .988 .823 r
.50507 .59226 m .50424 .59391 L .50628 .59232 L F
.213 0 0 r
.50628 .59232 m .50884 .59292 L .50507 .59226 L F
.979 .903 .567 r
.65535 .41655 m .65504 .41971 L .65441 .41867 L F
.884 .717 .67 r
.65504 .41971 m .65256 .42173 L .65441 .41867 L F
.65504 .41971 m .65466 .42366 L .65256 .42173 L F
.232 0 0 r
.75604 .37206 m .75512 .37188 L .75415 .3732 L F
.887 .83 .786 r
.67608 .44442 m .67939 .44315 L .67843 .44191 L F
.884 .928 .845 r
.67843 .44191 m .67939 .44315 L .68181 .44018 L F
.527 .371 .613 r
.79317 .40504 m .79372 .40752 L .79105 .40805 L F
.519 .473 .745 r
.79423 .41037 m .79105 .40805 L .79372 .40752 L F
.639 .542 .729 r
.42437 .57294 m .42754 .57439 L .42807 .57377 L F
.99 .85 .487 r
.50903 .58034 m .51033 .57749 L .50857 .57779 L F
.50903 .58034 m .50955 .58192 L .51033 .57749 L F
.341 .111 .413 r
.40385 .59639 m .40626 .59344 L .40371 .59383 L F
.395 .244 .555 r
.25005 .59351 m .25204 .58998 L .25055 .59066 L F
.753 .809 .897 r
.7348 .40777 m .73122 .40744 L .73403 .4058 L F
.694 .613 .761 r
.73489 .41021 m .73122 .40744 L .7348 .40777 L F
.574 .769 .971 r
.73642 .40546 m .7348 .40777 L .73403 .4058 L F
.73642 .40546 m .73752 .40717 L .7348 .40777 L F
.513 .311 .544 r
.73752 .40717 m .73489 .41021 L .7348 .40777 L F
.711 .556 .677 r
.59793 .4557 m .60148 .45584 L .60036 .45253 L F
.655 .524 .692 r
.60036 .45253 m .60387 .45276 L .60289 .44941 L F
.655 .526 .694 r
.60036 .45253 m .60148 .45584 L .60387 .45276 L F
.472 .476 .78 r
.44537 .62689 m .44773 .62662 L .44635 .62292 L F
.439 .258 .537 r
.44773 .62662 m .44531 .62942 L .44537 .62689 L F
.44537 .62689 m .44531 .62942 L .44773 .62662 L F
.132 .289 .758 r
.52012 .60438 m .51788 .60386 L .51716 .60239 L F
.52012 .60438 m .51923 .60614 L .51788 .60386 L F
.371 .683 .978 r
.2753 .54529 m .27471 .54664 L .27311 .54551 L F
.2753 .54529 m .27669 .54657 L .27471 .54664 L F
.813 .769 .812 r
.19557 .71998 m .19758 .72321 L .19327 .72249 L F
.634 .642 .841 r
.19701 .72522 m .19327 .72249 L .19758 .72321 L F
.824 .772 .804 r
.19961 .71944 m .19758 .72321 L .19557 .71998 L F
.539 .411 .654 r
.19978 .72242 m .19758 .72321 L .19961 .71944 L F
.557 .318 .509 r
.19978 .72242 m .19701 .72522 L .19758 .72321 L F
.445 0 .071 r
.47956 .61192 m .47819 .61366 L .47566 .61379 L F
.33 0 0 r
.48206 .61168 m .47819 .61366 L .47956 .61192 L F
.657 .26 .28 r
.41201 .62043 m .41424 .62241 L .41724 .62014 L F
.357 .333 .695 r
.41724 .62014 m .41775 .61693 L .41607 .61888 L F
.41724 .62014 m .41794 .62017 L .41775 .61693 L F
.538 .104 .164 r
.41724 .62014 m .41807 .6217 L .41794 .62017 L F
.41724 .62014 m .41424 .62241 L .41807 .6217 L F
.945 .897 .749 r
.59779 .51442 m .59889 .51332 L .59774 .51219 L F
.909 .756 .679 r
.54385 .58356 m .54553 .58501 L .54433 .58139 L F
.705 .33 .335 r
.61744 .43012 m .61921 .42964 L .62075 .42903 L F
.491 .287 .531 r
.62075 .42903 m .62309 .42604 L .61963 .4254 L F
.62075 .42903 m .62335 .42845 L .62309 .42604 L F
.673 .517 .665 r
.61921 .42964 m .62335 .42845 L .62075 .42903 L F
.031 0 .253 r
.58259 .5551 m .58501 .55149 L .58455 .55382 L F
.085 .03 .491 r
.58425 .5562 m .58259 .5551 L .58455 .55382 L F
.58425 .5562 m .58262 .55741 L .58259 .5551 L F
.686 .652 .811 r
.1973 .70846 m .20192 .71014 L .20016 .70721 L F
.661 .637 .816 r
.20016 .70721 m .20192 .71014 L .2032 .7075 L F
.405 0 .115 r
.56618 .48193 m .56859 .48166 L .56955 .48003 L F
.569 .442 .668 r
.56955 .48003 m .57197 .47958 L .57174 .47656 L F
.247 0 .034 r
.56955 .48003 m .57093 .48086 L .57197 .47958 L F
.56955 .48003 m .56859 .48166 L .57093 .48086 L F
.581 .08 .031 r
.18681 .55876 m .18463 .55989 L .18241 .55939 L F
.192 0 0 r
.18787 .5593 m .18463 .55989 L .18681 .55876 L F
.735 .92 .955 r
.24742 .55729 m .24912 .55785 L .2509 .55639 L F
.2509 .55639 m .24912 .55785 L .24742 .55729 L F
.491 .512 .807 r
.19742 .72811 m .19604 .72909 L .19478 .72583 L F
.934 .684 .536 r
.19474 .73036 m .19659 .73195 L .19604 .72909 L F
.599 .878 .56 r
.19699 .72786 m .19604 .72909 L .19742 .72811 L F
.19699 .72786 m .19474 .73036 L .19604 .72909 L F
.811 .826 .35 r
.76852 .39891 m .76855 .39793 L .76936 .39548 L F
.019 0 .318 r
.45885 .57306 m .45989 .57436 L .4594 .57195 L F
.45885 .57306 m .45854 .57581 L .45989 .57436 L F
.466 .37 .662 r
.28781 .56809 m .28558 .57058 L .28531 .56641 L F
.161 .227 .685 r
.54141 .58672 m .54262 .58971 L .54159 .59133 L F
.081 0 0 r
.1944 .55629 m .19351 .55709 L .19196 .55717 L F
.123 0 0 r
.19719 .55619 m .19351 .55709 L .1944 .55629 L F
.813 .696 .736 r
.62045 .43374 m .62229 .43752 L .62215 .43505 L F
.62045 .43374 m .61831 .4368 L .62229 .43752 L F
.796 .736 .797 r
.61831 .4368 m .61996 .43848 L .62229 .43752 L F
.265 0 .114 r
.41719 .58247 m .41836 .58319 L .41939 .58172 L F
.41719 .58247 m .41626 .58393 L .41836 .58319 L F
.713 .915 .964 r
.19961 .65171 m .20394 .65117 L .20184 .65098 L F
.378 .83 .929 r
.20184 .65098 m .20394 .65117 L .20595 .65064 L F
.383 0 0 r
.25409 .55166 m .25222 .55179 L .25008 .55128 L F
.653 .31 .379 r
.25428 .55197 m .25222 .55179 L .25409 .55166 L F
.516 .55 .829 r
.25409 .55166 m .25771 .55481 L .25428 .55197 L F
.764 .547 .603 r
.50424 .59391 m .50398 .59676 L .50781 .59628 L F
.46 .524 .837 r
.50398 .59676 m .50687 .59788 L .50781 .59628 L F
.792 .822 .876 r
.50781 .59628 m .50996 .59443 L .50884 .59292 L F
.169 .386 .832 r
.50781 .59628 m .51068 .5981 L .51067 .59766 L F
.048 .363 .834 r
.50886 .59564 m .51068 .5981 L .50781 .59628 L F
.50886 .59564 m .50781 .59628 L .50687 .59788 L F
.463 .199 .428 r
.5423 .51308 m .54197 .51517 L .53963 .51557 L F
.424 .166 .416 r
.54466 .5124 m .54197 .51517 L .5423 .51308 L F
.352 .166 .483 r
.5681 .55813 m .57016 .5572 L .57032 .55477 L F
.333 .16 .49 r
.5681 .55813 m .56999 .55954 L .57016 .5572 L F
.5681 .55813 m .56804 .56038 L .56999 .55954 L F
.572 .489 .723 r
.66148 .444 m .66402 .44346 L .66342 .44017 L F
.516 .339 .58 r
.41753 .64177 m .41724 .64436 L .41491 .64485 L F
0 0 .02 r
.5736 .54815 m .57511 .54409 L .57437 .54591 L F
.212 .283 .72 r
.46562 .59558 m .4658 .59925 L .46416 .59976 L F
.007 0 .16 r
.46528 .60083 m .46416 .59976 L .4658 .59925 L F
.46528 .60083 m .4636 .60217 L .46416 .59976 L F
.902 .928 .824 r
.49933 .53093 m .49827 .52989 L .5006 .52697 L F
.509 .257 .469 r
.4573 .59683 m .45983 .59645 L .46018 .59408 L F
.345 .117 .419 r
.46018 .59408 m .46183 .5955 L .46263 .59369 L F
.46018 .59408 m .45983 .59645 L .46183 .5955 L F
.608 .595 .812 r
.72986 .41396 m .72615 .41113 L .72859 .41024 L F
.666 .581 .75 r
.73235 .41107 m .72986 .41396 L .72859 .41024 L F
.681 .604 .763 r
.73237 .41314 m .72986 .41396 L .73235 .41107 L F
.471 .164 .364 r
.72117 .38859 m .72086 .38702 L .71832 .3891 L F
.696 .313 .318 r
.72117 .38859 m .72338 .38909 L .72086 .38702 L F
.616 .363 .511 r
.72338 .38909 m .72341 .38678 L .72086 .38702 L F
.802 .313 0 r
.49826 .54487 m .49503 .5415 L .49674 .54264 L F
.197 0 .06 r
.56124 .60478 m .56212 .60333 L .56434 .60247 L F
.736 .536 .622 r
.69811 .41358 m .69565 .4162 L .6955 .41405 L F
.067 0 0 r
.20954 .69426 m .20678 .69535 L .20848 .69613 L F
.637 .262 .316 r
.20848 .69613 m .2129 .69513 L .20954 .69426 L F
.675 .792 .937 r
.28836 .55181 m .28454 .5514 L .28676 .55038 L F
.612 .42 .598 r
.28836 .55181 m .28585 .55494 L .28454 .5514 L F
.28836 .55181 m .28831 .55458 L .28585 .55494 L F
.387 .675 .974 r
.28676 .55038 m .28897 .55029 L .28836 .55181 L F
.971 .731 .516 r
.28646 .55338 m .28836 .55181 L .28897 .55029 L F
.28646 .55338 m .28831 .55458 L .28836 .55181 L F
.13 0 0 r
.17574 .54748 m .18012 .54589 L .1778 .54612 L F
.384 .181 .477 r
.77082 .43736 m .76949 .43808 L .77159 .43494 L F
.85 .456 .297 r
.77082 .43736 m .76844 .43697 L .76949 .43808 L F
.796 .652 .703 r
.60533 .4587 m .60868 .46151 L .60784 .45828 L F
.60533 .4587 m .60524 .46124 L .60868 .46151 L F
.792 .681 .742 r
.60524 .46124 m .60641 .4648 L .60868 .46151 L F
.767 .659 .743 r
.60784 .45828 m .60868 .46151 L .60919 .45935 L F
.465 0 0 r
.50575 .55051 m .50154 .54826 L .5029 .54945 L F
.989 .774 .522 r
.50424 .59391 m .50295 .59373 L .50014 .59357 L F
.50424 .59391 m .50398 .59676 L .50295 .59373 L F
.50295 .59373 m .50424 .59391 L .50507 .59226 L F
.50295 .59373 m .50398 .59676 L .50424 .59391 L F
.38 .131 .406 r
.42097 .61505 m .42053 .61724 L .4231 .61431 L F
.737 .337 .292 r
.50746 .53637 m .50894 .5384 L .50996 .5368 L F
.101 0 0 r
.50996 .5368 m .51182 .53683 L .51314 .53686 L F
.50996 .5368 m .50894 .5384 L .51182 .53683 L F
.618 .39 .549 r
.44623 .6054 m .44816 .60226 L .44642 .60285 L F
.477 .358 .638 r
.44816 .60226 m .4532 .60411 L .45109 .59888 L F
.572 .362 .558 r
.44816 .60226 m .44897 .60523 L .45181 .60465 L F
.837 .621 .61 r
.58258 .49445 m .58054 .49435 L .58087 .49189 L F
.707 .52 .634 r
.58036 .49672 m .58054 .49435 L .58258 .49445 L F
.774 .531 .568 r
.58258 .49445 m .58273 .49761 L .58036 .49672 L F
.836 .669 .675 r
.60546 .48874 m .60461 .48585 L .60435 .48721 L F
.9 .775 .714 r
.6021 .49082 m .60546 .48874 L .60435 .48721 L F
.6021 .49082 m .60402 .49214 L .60546 .48874 L F
.403 .284 .602 r
.25498 .58493 m .25688 .58429 L .25676 .5814 L F
.302 .078 .398 r
.25474 .58724 m .25688 .58429 L .25498 .58493 L F
.441 .394 .71 r
.53836 .57291 m .53941 .57491 L .53722 .57516 L F
.817 .708 .744 r
.53941 .57491 m .53742 .57816 L .53722 .57516 L F
.435 .81 .992 r
.73135 .41937 m .73009 .41867 L .72753 .41906 L F
.383 .64 .957 r
.73135 .41937 m .73262 .41802 L .73009 .41867 L F
.73135 .41937 m .73359 .41957 L .73262 .41802 L F
.727 .739 .862 r
.4365 .56528 m .43837 .5668 L .43454 .56638 L F
.792 .738 .803 r
.44094 .56363 m .43837 .5668 L .4365 .56528 L F
.438 .364 .676 r
.28364 .59302 m .28133 .59103 L .28356 .59043 L F
.28364 .59302 m .28179 .59378 L .28133 .59103 L F
.793 .691 .752 r
.61345 .44281 m .61738 .44119 L .61565 .43985 L F
.61345 .44281 m .61512 .44421 L .61738 .44119 L F
.788 .759 .827 r
.61565 .43985 m .61738 .44119 L .61996 .43848 L F
.752 .618 .71 r
.78284 .44609 m .78672 .447 L .78459 .45029 L F
.482 .275 .522 r
.78459 .45029 m .78672 .447 L .78708 .4494 L F
.46 .261 .522 r
.78708 .4494 m .78672 .447 L .78946 .44614 L F
.767 .696 .784 r
.42162 .60819 m .4233 .61193 L .42545 .60863 L F
.538 .392 .63 r
.4233 .61193 m .42561 .61161 L .42545 .60863 L F
.119 0 .379 r
.4233 .61193 m .42502 .61264 L .42561 .61161 L F
.4233 .61193 m .4231 .61431 L .42502 .61264 L F
.112 .663 .71 r
.20716 .5398 m .20934 .53947 L .21066 .53929 L F
0 0 0 r
.15307 .57587 m .15437 .57492 L .15181 .57758 L F
.703 .528 .648 r
.46966 .59249 m .46804 .59477 L .46867 .59286 L F
.52 .834 1 r
.47651 .57217 m .47271 .57187 L .47405 .57271 L F
.276 .206 .595 r
.74186 .41614 m .74177 .41833 L .74024 .417 L F
0 0 0 r
.74187 .41629 m .74186 .41614 L .74024 .417 L F
.74187 .41629 m .74024 .417 L .73834 .41376 L F
.311 .064 .369 r
.27707 .60513 m .27497 .60784 L .27519 .60588 L F
.314 .043 .333 r
.24736 .63579 m .24666 .63846 L .24469 .6387 L F
.364 .087 .353 r
.24864 .63787 m .24736 .63579 L .24945 .63527 L F
.24864 .63787 m .24666 .63846 L .24736 .63579 L F
.579 .45 .669 r
.28559 .58502 m .2861 .58747 L .28368 .58775 L F
.49 .298 .547 r
.28576 .58986 m .28368 .58775 L .2861 .58747 L F
.28576 .58986 m .28356 .59043 L .28368 .58775 L F
.575 .833 .994 r
.19587 .63243 m .1937 .63313 L .19192 .63213 L F
.884 .928 .845 r
.67843 .44191 m .68181 .44018 L .68101 .4393 L F
.795 .971 .911 r
.68101 .4393 m .68181 .44018 L .68481 .43767 L F
.109 .54 .914 r
.50703 .5517 m .50713 .55088 L .50575 .55051 L F
.50703 .5517 m .50845 .55204 L .50713 .55088 L F
0 0 0 r
.43173 .64781 m .4308 .6502 L .43146 .64835 L F
.5 .019 .045 r
.21745 .55343 m .22133 .55309 L .21994 .55405 L F
.127 .559 .922 r
.21745 .55343 m .21994 .55405 L .21896 .55342 L F
.121 0 0 r
.21963 .55148 m .21745 .55343 L .21638 .55344 L F
.584 .165 .213 r
.22193 .5518 m .21745 .55343 L .21963 .55148 L F
.22193 .5518 m .22133 .55309 L .21745 .55343 L F
.127 .559 .922 r
.21745 .55343 m .21896 .55342 L .2175 .55248 L F
.121 0 0 r
.21638 .55344 m .21745 .55343 L .2154 .55403 L F
.11 .663 .735 r
.24151 .53977 m .24376 .5395 L .24528 .53937 L F
.176 0 0 r
.24591 .53953 m .24528 .53937 L .24376 .5395 L F
.24591 .53953 m .2473 .5398 L .24528 .53937 L F
.812 .687 .726 r
.45875 .61774 m .45478 .61919 L .45736 .61637 L F
.45875 .61774 m .45612 .62003 L .45478 .61919 L F
.677 .451 .571 r
.45875 .61774 m .45882 .6206 L .45612 .62003 L F
.274 0 0 r
.45736 .61637 m .46106 .61504 L .45875 .61774 L F
.586 .919 .694 r
.79539 .42718 m .79102 .43068 L .79415 .42787 L F
.753 .725 .826 r
.72481 .40941 m .72615 .41113 L .72259 .4106 L F
.711 .714 .851 r
.72859 .41024 m .72615 .41113 L .72481 .40941 L F
.751 .69 .793 r
.45327 .62042 m .45035 .6212 L .45262 .61981 L F
.623 .673 .877 r
.45612 .62003 m .45327 .62042 L .45262 .61981 L F
.468 .241 .485 r
.4555 .62269 m .45327 .62042 L .45612 .62003 L F
.4555 .62269 m .45291 .6235 L .45327 .62042 L F
.921 .915 .794 r
.76473 .42919 m .76178 .43104 L .76383 .42806 L F
.76473 .42919 m .76281 .43216 L .76178 .43104 L F
.899 .945 .829 r
.76625 .4251 m .76473 .42919 L .76383 .42806 L F
.76625 .4251 m .76708 .42617 L .76473 .42919 L F
.747 .505 .564 r
.6232 .43056 m .62754 .42902 L .62335 .42845 L F
.6232 .43056 m .62697 .43139 L .62754 .42902 L F
.611 .18 .199 r
.51923 .60614 m .51784 .60804 L .51527 .60654 L F
0 0 0 r
.51939 .60677 m .51923 .60614 L .52012 .60438 L F
.51939 .60677 m .51784 .60804 L .51923 .60614 L F
.384 .181 .477 r
.77082 .43736 m .77159 .43494 L .77107 .43372 L F
.877 .952 .854 r
.77351 .43114 m .77107 .43372 L .77159 .43494 L F
.662 .654 .832 r
.48237 .59424 m .47848 .59306 L .4801 .59381 L F
.892 .69 .622 r
.4801 .59381 m .48113 .59505 L .48237 .59424 L F
.188 .131 .558 r
.4351 .63862 m .43739 .63774 L .43674 .63478 L F
.098 0 .365 r
.43506 .64089 m .43739 .63774 L .4351 .63862 L F
.514 .408 .672 r
.16934 .65054 m .17122 .64778 L .16815 .6475 L F
.16934 .65054 m .17147 .65026 L .17122 .64778 L F
.238 .056 .42 r
.61058 .43805 m .61228 .437 L .61244 .43477 L F
.658 .572 .747 r
.60998 .44014 m .61228 .437 L .61058 .43805 L F
.559 .842 .997 r
.7288 .39797 m .72968 .39902 L .7322 .39828 L F
.7288 .39797 m .72968 .39902 L .7322 .39828 L F
0 0 0 r
.55839 .60773 m .5596 .60608 L .56124 .60478 L F
.55644 .60821 m .5596 .60608 L .55839 .60773 L F
.78 .739 .815 r
.62045 .43374 m .62215 .43505 L .62135 .43208 L F
.746 .719 .827 r
.62135 .43208 m .62215 .43505 L .6249 .43281 L F
.586 .919 .694 r
.79539 .42718 m .79415 .42787 L .79416 .4275 L F
.058 0 0 r
.79539 .42718 m .79416 .4275 L .79796 .42706 L F
0 .058 .608 r
.41039 .64591 m .41052 .64761 L .4111 .64614 L F
0 .345 .753 r
.41178 .64852 m .41048 .64759 L .40988 .64743 L F
.41178 .64852 m .41161 .64811 L .41048 .64759 L F
.40988 .64743 m .41048 .64759 L .40895 .6469 L F
.297 .397 .796 r
.40895 .6469 m .41161 .64811 L .41056 .64808 L F
0 .058 .608 r
.41052 .64761 m .41056 .64808 L .41068 .64765 L F
.41052 .64761 m .41068 .64765 L .4111 .64614 L F
.346 0 0 r
.41178 .64852 m .41394 .64967 L .41161 .64811 L F
.41178 .64852 m .41557 .65027 L .41394 .64967 L F
.877 .808 .778 r
.60061 .5042 m .60074 .49968 L .59937 .50305 L F
.60061 .5042 m .60221 .50105 L .60074 .49968 L F
.967 .791 .613 r
.59844 .50536 m .60061 .5042 L .59937 .50305 L F
.59844 .50536 m .59992 .50652 L .60061 .5042 L F
.508 .719 .967 r
.5262 .54166 m .52862 .5412 L .52689 .53947 L F
0 0 0 r
.52639 .54108 m .52689 .53947 L .52741 .53715 L F
.508 .719 .967 r
.5262 .54166 m .52689 .53947 L .52639 .54108 L F
.772 .815 .337 r
.78745 .43756 m .78609 .44167 L .78749 .43948 L F
.8 .977 .689 r
.78749 .43948 m .78609 .44167 L .78519 .44262 L F
.48 .096 .234 r
.1777 .56073 m .17645 .56322 L .17384 .56324 L F
0 0 0 r
.17813 .56185 m .17645 .56322 L .1777 .56073 L F
.74 .859 .936 r
.21173 .68874 m .2149 .68872 L .21369 .68639 L F
.989 .792 .55 r
.64811 .41524 m .64999 .41413 L .64848 .41263 L F
.64811 .41524 m .64956 .41664 L .64999 .41413 L F
.271 0 .135 r
.24569 .64009 m .24469 .6387 L .24666 .63846 L F
.24569 .64009 m .24361 .64076 L .24469 .6387 L F
0 0 0 r
.72815 .3779 m .72572 .38096 L .72749 .37959 L F
.519 .909 .93 r
.72749 .37959 m .72896 .3799 L .72572 .38096 L F
.892 .903 .828 r
.41855 .65036 m .41951 .65032 L .41796 .64811 L F
0 0 .559 r
.51558 .59279 m .51648 .59636 L .51664 .59385 L F
.645 .324 .413 r
.68688 .40685 m .69034 .40466 L .68718 .40521 L F
.195 0 .254 r
.64436 .40825 m .64404 .41 L .64625 .40726 L F
.891 .98 .694 r
.21369 .67722 m .21326 .67658 L .21529 .675 L F
.563 .588 .837 r
.21348 .67134 m .21529 .675 L .21732 .67424 L F
.691 .251 .202 r
.21326 .67658 m .21717 .67696 L .21529 .675 L F
.45 .274 .55 r
.21529 .675 m .21717 .67696 L .21732 .67424 L F
.62 .872 .989 r
.52089 .52552 m .52002 .52752 L .52263 .52668 L F
.373 .208 .524 r
.52079 .53042 m .52263 .52668 L .52002 .52752 L F
.919 .914 .523 r
.53861 .51795 m .53963 .51557 L .53833 .51722 L F
.068 0 0 r
.54197 .51517 m .53833 .51722 L .53963 .51557 L F
.6 .668 .888 r
.17892 .62537 m .17643 .62612 L .17468 .62338 L F
.341 .815 .756 r
.49378 .5369 m .49587 .536 L .4969 .5358 L F
.487 .895 .778 r
.4969 .5358 m .49781 .53484 L .49751 .53245 L F
.4969 .5358 m .49587 .536 L .49781 .53484 L F
.506 .126 .254 r
.52604 .51468 m .52872 .51466 L .5295 .51235 L F
.197 0 .078 r
.52872 .51466 m .53169 .51167 L .5295 .51235 L F
.977 .843 .642 r
.60221 .50105 m .60162 .4977 L .60074 .49968 L F
0 0 0 r
.14884 .56034 m .15042 .5598 L .15226 .5581 L F
.218 0 0 r
.15042 .5598 m .15427 .55731 L .15226 .5581 L F
.163 .578 .934 r
.26169 .54114 m .26147 .54211 L .26003 .54069 L F
.26169 .54114 m .26326 .54241 L .26147 .54211 L F
.549 .69 .932 r
.75255 .37552 m .75415 .3732 L .75182 .37443 L F
.75255 .37552 m .75525 .37513 L .75415 .3732 L F
.407 .172 .442 r
.71071 .39616 m .71264 .39747 L .71253 .39498 L F
.71071 .39616 m .71035 .39836 L .71264 .39747 L F
.448 .484 .804 r
.52844 .52963 m .52771 .53354 L .52986 .53174 L F
.313 0 .183 r
.71035 .39836 m .70789 .39914 L .70739 .40052 L F
0 0 0 r
.66538 .45182 m .66899 .45024 L .66761 .45015 L F
.525 .846 .998 r
.66899 .45024 m .67163 .44955 L .67086 .4486 L F
.015 0 0 r
.41127 .5872 m .41321 .58676 L .41445 .5852 L F
0 0 0 r
.41445 .5852 m .41479 .58565 L .41626 .58393 L F
.41445 .5852 m .41321 .58676 L .41479 .58565 L F
.856 .466 .306 r
.42751 .65148 m .42792 .65172 L .42849 .65079 L F
.927 .546 .16 r
.42686 .64821 m .42703 .64972 L .42849 .65079 L F
.856 .466 .306 r
.42849 .65079 m .42751 .65148 L .42703 .64972 L F
.42849 .65079 m .42792 .65172 L .42751 .65148 L F
.664 .222 .192 r
.42849 .65079 m .43073 .65275 L .42792 .65172 L F
.366 .13 .418 r
.27497 .60784 m .27227 .61103 L .27264 .60864 L F
.35 .031 .276 r
.56095 .48491 m .56305 .48519 L .56363 .48276 L F
.4 .084 .31 r
.56305 .48519 m .56618 .48193 L .56363 .48276 L F
.117 .663 .825 r
.21305 .53872 m .21523 .53866 L .21689 .53886 L F
.184 .71 .859 r
.21689 .53886 m .21523 .53866 L .21908 .5387 L F
.724 .67 .797 r
.41794 .62017 m .42198 .6206 L .42053 .61724 L F
.68 .273 .267 r
.41794 .62017 m .42033 .62258 L .42198 .6206 L F
.557 .576 .829 r
.42198 .6206 m .42286 .61672 L .42053 .61724 L F
.42198 .6206 m .42431 .62021 L .42286 .61672 L F
.577 .15 .194 r
.42198 .6206 m .42415 .62251 L .42431 .62021 L F
.42198 .6206 m .42033 .62258 L .42415 .62251 L F
.429 .649 .951 r
.25771 .55481 m .25918 .55355 L .25428 .55197 L F
.315 .444 .832 r
.25771 .55481 m .26043 .55603 L .25918 .55355 L F
.529 .32 .54 r
.25771 .55481 m .25749 .5573 L .26043 .55603 L F
.658 .538 .706 r
.60289 .44941 m .60632 .4497 L .60522 .44615 L F
.66 .527 .691 r
.60289 .44941 m .60387 .45276 L .60632 .4497 L F
.248 .448 .86 r
.3999 .62957 m .39934 .62637 L .39723 .62611 L F
.3999 .62957 m .40079 .62911 L .39934 .62637 L F
0 0 0 r
.74124 .39775 m .73852 .39871 L .74153 .39755 L F
0 0 .031 r
.74153 .39755 m .74312 .39438 L .74124 .39775 L F
.203 .161 .585 r
.41501 .59951 m .41646 .60191 L .41601 .59783 L F
0 0 .062 r
.41601 .59783 m .41579 .59913 L .41501 .59951 L F
.973 .767 .565 r
.41579 .59913 m .41646 .60191 L .41501 .59951 L F
.255 .168 .561 r
.55711 .58406 m .55536 .58779 L .55415 .58431 L F
.55711 .58406 m .55711 .58691 L .55536 .58779 L F
.328 .331 .711 r
.55711 .58691 m .55736 .58959 L .55536 .58779 L F
.632 .322 .427 r
.55536 .58779 m .55736 .58959 L .55537 .58969 L F
.226 .366 .796 r
.25749 .5573 m .25898 .5608 L .26017 .55842 L F
.01 .09 .6 r
.25898 .5608 m .26051 .563 L .26017 .55842 L F
.759 .696 .791 r
.61121 .44358 m .61512 .44421 L .61345 .44281 L F
.763 .621 .701 r
.61125 .44604 m .61512 .44421 L .61121 .44358 L F
.61125 .44604 m .61473 .44661 L .61512 .44421 L F
.435 .377 .694 r
.20891 .68986 m .21032 .69166 L .20892 .68822 L F
.484 .25 .482 r
.26293 .62109 m .26255 .62339 L .26021 .62373 L F
.415 .223 .509 r
.26211 .62582 m .26021 .62373 L .26255 .62339 L F
.26211 .62582 m .26009 .6266 L .26021 .62373 L F
.469 0 .048 r
.43964 .57263 m .43823 .57423 L .43573 .57411 L F
.682 .289 .295 r
.44167 .57293 m .43823 .57423 L .43964 .57263 L F
.751 .697 .801 r
.67142 .43463 m .67228 .43862 L .66882 .43727 L F
.792 .366 .237 r
.66882 .43727 m .67228 .43862 L .67108 .43988 L F
.784 .717 .79 r
.67487 .43498 m .67228 .43862 L .67142 .43463 L F
.694 .235 .158 r
.67108 .43988 m .67228 .43862 L .67307 .44002 L F
.963 .758 .58 r
.42788 .59047 m .42754 .59304 L .4286 .59136 L F
.398 .193 .481 r
.24772 .59651 m .24949 .59607 L .25005 .59351 L F
.434 .224 .494 r
.24746 .59897 m .24949 .59607 L .24772 .59651 L F
.64 .442 .599 r
.58572 .46992 m .5881 .46738 L .58544 .46805 L F
.756 .94 .602 r
.53582 .56592 m .538 .56379 L .5365 .56338 L F
.702 .511 .627 r
.59793 .4557 m .60161 .45833 L .60148 .45584 L F
.622 .48 .668 r
.60148 .45584 m .60397 .45547 L .60387 .45276 L F
.697 .553 .687 r
.60161 .45833 m .60397 .45547 L .60148 .45584 L F
.804 .83 .871 r
.21753 .67015 m .21348 .67134 L .21507 .67185 L F
.929 .969 .754 r
.21753 .67015 m .21722 .66846 L .21955 .66956 L F
.21753 .67015 m .21507 .67185 L .21722 .66846 L F
.241 0 0 r
.73091 .37713 m .72815 .3779 L .72749 .37959 L F
.144 0 .313 r
.58262 .55741 m .58279 .55969 L .58052 .5608 L F
0 0 .246 r
.58279 .55969 m .58054 .56327 L .58052 .5608 L F
.989 .871 .523 r
.76778 .41594 m .76844 .41702 L .76783 .41929 L F
.621 .452 .632 r
.2039 .69825 m .20678 .69535 L .20408 .69561 L F
.623 .466 .648 r
.48416 .59078 m .48659 .59065 L .48657 .58774 L F
.589 .314 .467 r
.48659 .59065 m .48653 .59275 L .48416 .59078 L F
.623 .466 .648 r
.48416 .59078 m .48659 .59065 L .48657 .58774 L F
.589 .314 .467 r
.48659 .59065 m .48653 .59275 L .48416 .59078 L F
.213 0 .016 r
.55434 .50449 m .55259 .50372 L .55482 .50294 L F
.55434 .50449 m .55163 .50541 L .55259 .50372 L F
.641 .433 .585 r
.70159 .41083 m .7015 .4138 L .69811 .41358 L F
.663 .391 .497 r
.70159 .41083 m .70411 .41335 L .7015 .4138 L F
.70159 .41083 m .70404 .4108 L .70411 .41335 L F
.047 .119 .617 r
.40237 .63252 m .40293 .6364 L .40413 .63492 L F
.192 .337 .782 r
.40293 .6364 m .40523 .63811 L .40413 .63492 L F
.137 .328 .792 r
.40464 .63874 m .40523 .63811 L .40293 .6364 L F
.422 .044 .213 r
.56061 .49845 m .56022 .49987 L .55779 .50023 L F
.338 0 .111 r
.56395 .49732 m .56022 .49987 L .56061 .49845 L F
.625 .449 .623 r
.44252 .61483 m .44271 .61744 L .44012 .61761 L F
.55 .333 .537 r
.44538 .61456 m .44271 .61744 L .44252 .61483 L F
.416 .799 .991 r
.2473 .5398 m .24964 .53944 L .25132 .5401 L F
.162 .693 .855 r
.24964 .53944 m .25353 .53955 L .25132 .5401 L F
.984 .845 .625 r
.76281 .43216 m .761 .43355 L .76178 .43104 L F
.795 .746 .808 r
.46937 .5821 m .47302 .58227 L .47161 .58092 L F
.178 .228 .678 r
.47302 .58227 m .47485 .58139 L .47161 .58092 L F
.47302 .58227 m .47481 .58379 L .47485 .58139 L F
.82 .86 .409 r
.58014 .53072 m .5789 .53414 L .57921 .53226 L F
.802 .827 .353 r
.57921 .53226 m .5789 .53414 L .5781 .53638 L F
.393 .158 .435 r
.26501 .62048 m .26255 .62339 L .26293 .62109 L F
.132 .289 .758 r
.52012 .60438 m .51716 .60239 L .51886 .60223 L F
.804 .687 .735 r
.60524 .46124 m .60286 .46422 L .60641 .4648 L F
.811 .639 .669 r
.60286 .46422 m .60622 .46707 L .60641 .4648 L F
.193 0 .206 r
.55578 .48934 m .5574 .48981 L .55812 .48849 L F
.55578 .48934 m .55527 .491 L .5574 .48981 L F
.881 .924 .535 r
.5814 .52668 m .58014 .53072 L .58004 .53002 L F
.854 .863 .413 r
.58004 .53002 m .58014 .53072 L .57921 .53226 L F
.61 .445 .634 r
.59331 .46176 m .59659 .46161 L .5958 .45877 L F
.67 .52 .672 r
.59308 .46419 m .59659 .46161 L .59331 .46176 L F
.562 .411 .634 r
.50062 .58289 m .49895 .58782 L .49749 .58407 L F
.50062 .58289 m .50155 .58747 L .49895 .58782 L F
.438 .329 .632 r
.50371 .58617 m .50062 .58289 L .50363 .58399 L F
.50371 .58617 m .50155 .58747 L .50062 .58289 L F
.421 .867 .829 r
.20995 .63348 m .21224 .63305 L .20883 .63419 L F
.207 .732 .836 r
.21229 .63266 m .21224 .63305 L .20995 .63348 L F
.21229 .63266 m .21453 .63274 L .21224 .63305 L F
.732 .547 .642 r
.41601 .59783 m .41934 .60119 L .42059 .60009 L F
0 0 0 r
.41934 .60119 m .42276 .59944 L .42059 .60009 L F
.965 .931 .7 r
.41238 .61377 m .41043 .61684 L .41126 .61465 L F
.605 .345 .498 r
.41238 .61377 m .41268 .61668 L .41043 .61684 L F
.735 .587 .69 r
.41572 .61297 m .41268 .61668 L .41238 .61377 L F
.78 .876 .917 r
.69448 .42323 m .69028 .42428 L .69326 .42182 L F
.764 .741 .831 r
.69561 .41878 m .69448 .42323 L .69326 .42182 L F
.69561 .41878 m .69641 .42195 L .69448 .42323 L F
.296 .459 .853 r
.47848 .59306 m .48113 .59505 L .4801 .59381 L F
.507 .809 .999 r
.16438 .62541 m .16407 .62691 L .16357 .6265 L F
.16438 .62541 m .16629 .62645 L .16407 .62691 L F
.289 .257 .649 r
.25623 .57519 m .25641 .57888 L .25817 .57754 L F
.321 .265 .637 r
.25676 .5814 m .25817 .57754 L .25641 .57888 L F
.536 .137 .231 r
.44077 .58369 m .44326 .58354 L .44483 .58139 L F
.638 .254 .299 r
.44483 .58139 m .44326 .58354 L .44697 .58341 L F
.645 .251 .284 r
.44483 .58139 m .44697 .58341 L .44751 .58209 L F
.944 .69 .224 r
.79239 .43196 m .79174 .43171 L .78917 .43108 L F
.79239 .43196 m .79244 .43364 L .79174 .43171 L F
.367 .421 .785 r
.76694 .38797 m .76505 .39 L .76399 .38631 L F
.393 .461 .811 r
.76694 .38797 m .76773 .39135 L .76505 .39 L F
.635 .475 .649 r
.5958 .45877 m .599 .45874 L .59793 .4557 L F
.702 .511 .627 r
.59793 .4557 m .599 .45874 L .60161 .45833 L F
.92 .771 .68 r
.60296 .48416 m .60461 .48585 L .60305 .48173 L F
.897 .732 .669 r
.60296 .48416 m .60435 .48721 L .60461 .48585 L F
.742 .7 .811 r
.60305 .48173 m .60461 .48585 L .60675 .48226 L F
.687 .551 .695 r
.60752 .44335 m .60998 .44014 L .60751 .44079 L F
.686 .771 .916 r
.19857 .63134 m .19973 .63297 L .19587 .63243 L F
.195 .499 .906 r
.20009 .63161 m .19973 .63297 L .19857 .63134 L F
.459 .781 .998 r
.20009 .63161 m .20188 .63265 L .19973 .63297 L F
.411 .03 .202 r
.57018 .49691 m .56641 .49982 L .56643 .49733 L F
.57018 .49691 m .56883 .49942 L .56641 .49982 L F
.701 .419 .494 r
.57257 .49711 m .56883 .49942 L .57018 .49691 L F
.681 .969 .767 r
.50667 .52302 m .50441 .52497 L .50533 .52352 L F
.681 .973 .791 r
.50533 .52352 m .50441 .52497 L .50258 .52576 L F
.362 .794 .967 r
.55196 .6095 m .55307 .60934 L .55187 .60857 L F
.072 0 0 r
.55644 .60821 m .55238 .60963 L .55342 .60932 L F
.55238 .60963 m .55163 .60989 L .55215 .60972 L F
.55238 .60963 m .55215 .60972 L .55342 .60932 L F
.55644 .60821 m .55514 .60927 L .55163 .60989 L F
.362 .794 .967 r
.55307 .60934 m .55406 .6092 L .55367 .60909 L F
.55307 .60934 m .55367 .60909 L .55187 .60857 L F
0 0 0 r
.55644 .60821 m .5566 .60879 L .55514 .60927 L F
.55644 .60821 m .55839 .60773 L .5566 .60879 L F
.051 0 .145 r
.1955 .71071 m .19684 .71032 L .1973 .70846 L F
.257 .442 .853 r
.1955 .71071 m .19663 .71151 L .19684 .71032 L F
.753 .45 .471 r
.58581 .50087 m .58241 .50267 L .58241 .50014 L F
.58581 .50087 m .58618 .50305 L .58241 .50267 L F
.769 .295 .115 r
.51611 .59887 m .51219 .59638 L .51369 .59884 L F
.202 .728 .84 r
.43109 .56314 m .43324 .56288 L .43378 .56301 L F
.78 .76 .835 r
.43109 .56314 m .43378 .56301 L .43324 .56288 L F
.316 .173 .522 r
.57888 .56899 m .5789 .57145 L .57635 .57232 L F
.362 .212 .539 r
.5789 .57145 m .57695 .57427 L .57635 .57232 L F
0 0 .187 r
.58702 .54587 m .58777 .54378 L .58781 .5441 L F
0 0 .04 r
.58789 .54465 m .58781 .5441 L .58751 .54383 L F
.5883 .54553 m .58725 .54656 L .58781 .5441 L F
.5883 .54553 m .58781 .5441 L .58789 .54465 L F
0 0 .187 r
.58777 .54378 m .58835 .54216 L .58781 .5441 L F
0 0 0 r
.58644 .54801 m .58702 .54587 L .58781 .5441 L F
.627 .174 .157 r
.69819 .40364 m .69889 .40236 L .69574 .40195 L F
.582 .126 .135 r
.70159 .40369 m .69889 .40236 L .69819 .40364 L F
.56 .24 .384 r
.70159 .40369 m .70186 .40226 L .69889 .40236 L F
.601 .448 .646 r
.48657 .58774 m .48988 .58985 L .4895 .58779 L F
.067 0 .18 r
.48988 .58985 m .49347 .58532 L .4895 .58779 L F
.527 .528 .8 r
.79446 .40153 m .79317 .40504 L .79252 .40143 L F
.79446 .40153 m .79573 .40292 L .79317 .40504 L F
.611 .425 .606 r
.79649 .40676 m .79317 .40504 L .79573 .40292 L F
.79649 .40676 m .79372 .40752 L .79317 .40504 L F
.536 .39 .63 r
.55646 .57875 m .55889 .57821 L .55861 .57583 L F
.55861 .57583 m .55889 .57821 L .55646 .57875 L F
.63 .098 0 r
.44793 .55725 m .45203 .5582 L .45006 .55758 L F
.649 .128 0 r
.44793 .55725 m .45027 .55905 L .45203 .5582 L F
.303 0 0 r
.45203 .5582 m .45376 .55874 L .45436 .55754 L F
.45203 .5582 m .45027 .55905 L .45376 .55874 L F
.685 .484 .608 r
.20016 .70721 m .2032 .7075 L .20335 .70473 L F
.97 .919 .587 r
.76993 .40462 m .76973 .40816 L .76886 .41023 L F
.857 .996 .771 r
.23852 .6114 m .23567 .61487 L .23606 .61276 L F
.688 .969 .755 r
.2393 .60997 m .23852 .6114 L .23606 .61276 L F
.758 .641 .732 r
.61125 .44604 m .61237 .44959 L .61473 .44661 L F
.431 0 0 r
.66057 .41026 m .66011 .41039 L .66352 .41083 L F
.721 .577 .693 r
.66011 .41039 m .66372 .4133 L .66352 .41083 L F
.544 .759 .977 r
.51401 .52743 m .51536 .5255 L .51261 .52635 L F
.51401 .52743 m .51658 .52694 L .51536 .5255 L F
.18 0 0 r
.51401 .52743 m .51503 .52854 L .51658 .52694 L F
.51401 .52743 m .51272 .52921 L .51503 .52854 L F
.382 .024 .226 r
.17185 .564 m .17108 .56529 L .16823 .5657 L F
.318 .008 .272 r
.17108 .56529 m .16769 .56798 L .16823 .5657 L F
.645 .324 .413 r
.68688 .40685 m .69062 .40657 L .69034 .40466 L F
.701 .456 .549 r
.69062 .40657 m .69307 .40451 L .69034 .40466 L F
.614 .392 .557 r
.45359 .5966 m .45659 .59867 L .4573 .59683 L F
.455 .115 .3 r
.45659 .59867 m .45983 .59645 L .4573 .59683 L F
.326 .811 .863 r
.46872 .55835 m .46788 .55907 L .46618 .55904 L F
.46872 .55835 m .47024 .55849 L .46788 .55907 L F
.754 .892 .94 r
.68936 .43345 m .69352 .43244 L .69259 .43154 L F
.774 .921 .935 r
.6946 .42992 m .69352 .43244 L .69563 .43097 L F
.784 .931 .93 r
.69259 .43154 m .69352 .43244 L .6946 .42992 L F
0 0 0 r
.1833 .54463 m .18434 .54467 L .18623 .54267 L F
.281 0 0 r
.18623 .54267 m .18671 .54416 L .18841 .54214 L F
.18623 .54267 m .18434 .54467 L .18671 .54416 L F
.601 .448 .646 r
.48657 .58774 m .48659 .59065 L .48988 .58985 L F
.48988 .58985 m .48659 .59065 L .48657 .58774 L F
.387 .695 .981 r
.18514 .65211 m .18541 .65061 L .18347 .65088 L F
.18514 .65211 m .18773 .65208 L .18541 .65061 L F
.428 .672 .964 r
.42659 .64998 m .42579 .64938 L .42452 .64776 L F
.119 .291 .764 r
.42579 .64938 m .42703 .64972 L .42452 .64776 L F
.603 .248 .339 r
.42452 .64776 m .42703 .64972 L .42686 .64821 L F
.994 .763 .403 r
.41724 .64436 m .4171 .64775 L .41796 .64811 L F
.949 .608 .207 r
.4171 .64775 m .41855 .65036 L .41796 .64811 L F
.773 .627 .699 r
.78284 .44609 m .78459 .45029 L .7807 .44959 L F
.564 .013 0 r
.78459 .45029 m .78358 .45109 L .7807 .44959 L F
.056 0 0 r
.78708 .4494 m .78358 .45109 L .78459 .45029 L F
.158 0 0 r
.45714 .58532 m .45389 .58684 L .45477 .58541 L F
.363 .312 .666 r
.28585 .55494 m .28792 .55701 L .2862 .55701 L F
.583 .326 .493 r
.28831 .55458 m .28792 .55701 L .28585 .55494 L F
.704 .539 .663 r
.4056 .61741 m .4086 .61751 L .40799 .61468 L F
.463 .213 .449 r
.40799 .61468 m .40689 .61748 L .4056 .61741 L F
.66 .417 .542 r
.41043 .61684 m .40799 .61468 L .41126 .61465 L F
.41043 .61684 m .40689 .61748 L .40799 .61468 L F
.239 0 .232 r
.56095 .48491 m .5624 .48654 L .56305 .48519 L F
.56095 .48491 m .56027 .48752 L .5624 .48654 L F
.705 .502 .61 r
.5958 .45877 m .59913 .46136 L .599 .45874 L F
.5958 .45877 m .59659 .46161 L .59913 .46136 L F
.495 .218 .423 r
.69307 .40451 m .69566 .40394 L .69574 .40195 L F
.627 .174 .157 r
.69819 .40364 m .69574 .40195 L .69566 .40394 L F
.836 .403 0 r
.51767 .56098 m .51745 .56186 L .51683 .5597 L F
.51767 .56098 m .51859 .56289 L .51745 .56186 L F
.632 .495 .678 r
.43296 .58802 m .43605 .58938 L .43506 .58677 L F
.43296 .58802 m .43373 .59046 L .43605 .58938 L F
.736 .821 .917 r
.71267 .42479 m .71694 .42376 L .71573 .42249 L F
.815 .864 .884 r
.71573 .42249 m .71694 .42376 L .71888 .42225 L F
.903 .738 .238 r
.43492 .62412 m .4354 .62634 L .43578 .62508 L F
.412 .312 .631 r
.43578 .62508 m .43732 .62679 L .43584 .62646 L F
.247 0 .251 r
.44038 .6229 m .43578 .62508 L .43708 .62345 L F
.44038 .6229 m .43901 .62493 L .43578 .62508 L F
.473 .231 .466 r
.28179 .59378 m .28136 .59612 L .2791 .59663 L F
.316 .095 .411 r
.28364 .59302 m .28136 .59612 L .28179 .59378 L F
.754 .882 .937 r
.7464 .41719 m .74296 .41925 L .74177 .41833 L F
.538 .324 .536 r
.42162 .60819 m .41919 .61073 L .41929 .60871 L F
.75 .507 .565 r
.6819 .41383 m .68553 .41376 L .68545 .41628 L F
.373 .193 .504 r
.24532 .60241 m .24746 .59897 L .24543 .59976 L F
.419 .281 .586 r
.52771 .53354 m .52997 .53543 L .53087 .53428 L F
.486 .437 .728 r
.53386 .53609 m .53193 .53723 L .53087 .53428 L F
.679 .591 .75 r
.73489 .41021 m .73237 .41314 L .73235 .41107 L F
.73489 .41021 m .73587 .41408 L .73237 .41314 L F
.627 .462 .639 r
.44271 .61744 m .44025 .62031 L .44012 .61761 L F
.409 .298 .616 r
.28781 .56809 m .28603 .57245 L .28558 .57058 L F
.729 .315 .261 r
.20793 .65065 m .20981 .65163 L .20595 .65064 L F
.198 .72 .862 r
.72749 .37959 m .72896 .3799 L .73112 .37962 L F
.906 .698 .611 r
.43944 .56213 m .44094 .56363 L .43793 .56231 L F
.792 .738 .803 r
.44094 .56363 m .4365 .56528 L .43793 .56231 L F
.095 .084 .553 r
.65537 .40172 m .65711 .40266 L .65734 .40125 L F
.65537 .40172 m .65575 .40494 L .65711 .40266 L F
.808 .765 .813 r
.19375 .73463 m .19659 .73195 L .19474 .73036 L F
.849 .886 .865 r
.45035 .6212 m .44635 .62292 L .44917 .62108 L F
.659 .329 .404 r
.45051 .62026 m .4477 .61936 L .4499 .61844 L F
.31 0 0 r
.44932 .62109 m .45262 .61981 L .45035 .6212 L F
.44953 .62095 m .45262 .61981 L .44932 .62109 L F
.44917 .62108 m .44953 .62095 L .44932 .62109 L F
.44937 .621 m .45078 .62105 L .45262 .61981 L F
.44917 .62108 m .45078 .62105 L .44937 .621 L F
.623 .673 .877 r
.45612 .62003 m .45402 .6199 L .45478 .61919 L F
.45402 .6199 m .45262 .61981 L .45478 .61919 L F
.184 0 .275 r
.45719 .62181 m .4555 .62269 L .45612 .62003 L F
.675 .243 .214 r
.45478 .61919 m .45299 .62187 L .45719 .62181 L F
.45478 .61919 m .45719 .62181 L .45395 .62077 L F
0 0 0 r
.45478 .61919 m .45395 .62077 L .45623 .61783 L F
.45478 .61919 m .45623 .61783 L .45736 .61637 L F
.672 .239 .212 r
.45078 .62105 m .45478 .61919 L .45262 .61981 L F
.45078 .62105 m .45299 .62187 L .45478 .61919 L F
.602 .549 .767 r
.45199 .6179 m .45299 .62187 L .45078 .62105 L F
.45199 .6179 m .45263 .6204 L .45118 .62001 L F
.813 .532 0 r
.45249 .62042 m .45299 .62187 L .45199 .6179 L F
.65 .794 .951 r
.4556 .6212 m .45299 .62187 L .45249 .62042 L F
.4554 .62115 m .45249 .62042 L .45424 .62091 L F
.184 0 .275 r
.45719 .62181 m .45612 .62003 L .45882 .6206 L F
0 0 0 r
.45478 .61919 m .45401 .62067 L .45736 .61637 L F
.45401 .62067 m .45395 .62077 L .4541 .62058 L F
.45401 .62067 m .4541 .62058 L .45736 .61637 L F
.094 0 0 r
.46118 .62015 m .45719 .62181 L .45882 .6206 L F
.45831 .62135 m .45956 .6213 L .45719 .62181 L F
.46118 .62015 m .45956 .6213 L .45831 .62135 L F
.584 .9 .635 r
.46095 .6199 m .45956 .6213 L .46118 .62015 L F
.615 .514 .716 r
.46095 .6199 m .46047 .62127 L .45956 .6213 L F
.46047 .62127 m .45956 .6239 L .45956 .6213 L F
.574 .662 .897 r
.45719 .62181 m .45956 .6213 L .45714 .61769 L F
.653 .873 .504 r
.45736 .61637 m .45395 .62077 L .45638 .61716 L F
.45663 .61683 m .45638 .61716 L .45659 .61685 L F
.45736 .61637 m .45638 .61716 L .45663 .61683 L F
.537 .332 .549 r
.45487 .61784 m .45448 .61972 L .45249 .62042 L F
.45448 .61972 m .45424 .62091 L .45371 .62076 L F
.45448 .61972 m .45371 .62076 L .45249 .62042 L F
.574 .662 .897 r
.45674 .61807 m .45714 .61769 L .45659 .61685 L F
.45719 .62181 m .45714 .61769 L .45674 .61807 L F
.45719 .62181 m .45659 .61685 L .45395 .62077 L F
.65 .794 .951 r
.4556 .6212 m .455 .62104 L .4554 .62115 L F
.455 .62104 m .45249 .62042 L .4554 .62115 L F
.602 .549 .767 r
.45118 .62001 m .45281 .62112 L .45078 .62105 L F
.45263 .6204 m .45281 .62112 L .45118 .62001 L F
.45281 .62112 m .45299 .62187 L .45078 .62105 L F
.659 .329 .404 r
.45078 .62105 m .45 .62062 L .45051 .62026 L F
.45 .62062 m .4477 .61936 L .45051 .62026 L F
.583 .456 .673 r
.20892 .68822 m .21032 .69166 L .21173 .68874 L F
.315 .414 .804 r
.16787 .64469 m .16775 .64089 L .16636 .64235 L F
.16787 .64469 m .16911 .64324 L .16775 .64089 L F
.425 .499 .832 r
.16795 .64539 m .16911 .64324 L .16787 .64469 L F
.776 .898 .929 r
.70725 .42583 m .71035 .4257 L .70922 .4244 L F
.708 .855 .952 r
.70922 .4244 m .71035 .4257 L .71267 .42479 L F
.124 0 0 r
.47231 .55881 m .47626 .55729 L .47396 .55826 L F
.522 .309 .531 r
.70404 .4108 m .70669 .41258 L .70411 .41335 L F
.70404 .4108 m .70658 .41021 L .70669 .41258 L F
.745 .826 .915 r
.75115 .42813 m .75457 .42856 L .75311 .42721 L F
.786 .792 .858 r
.75251 .42971 m .75457 .42856 L .75115 .42813 L F
.849 .834 .831 r
.75311 .42721 m .75457 .42856 L .75695 .42553 L F
.808 .765 .813 r
.19375 .73463 m .19474 .73036 L .19244 .73117 L F
.625 .775 .953 r
.16707 .61891 m .16886 .62069 L .16473 .61987 L F
.437 .272 .559 r
.16438 .62541 m .16247 .62389 L .16285 .62323 L F
.16438 .62541 m .16247 .62389 L .16285 .62323 L F
.788 .291 0 r
.16409 .62522 m .16438 .62541 L .16285 .62323 L F
.666 .367 .455 r
.16886 .62069 m .16409 .62522 L .16473 .61987 L F
.16886 .62069 m .16847 .6232 L .16409 .62522 L F
.424 .686 .973 r
.16932 .61899 m .16886 .62069 L .16707 .61891 L F
.601 .307 .442 r
.17115 .62244 m .16886 .62069 L .16932 .61899 L F
.17115 .62244 m .16847 .6232 L .16886 .62069 L F
.766 .742 .831 r
.69908 .41925 m .69641 .42195 L .69561 .41878 L F
.65 .945 .957 r
.73661 .37437 m .73718 .3755 L .73931 .3742 L F
.643 .948 .951 r
.73931 .3742 m .73718 .3755 L .73621 .37496 L F
.56 .807 .991 r
.2572 .54016 m .25353 .53955 L .2557 .539 L F
.265 .61 .955 r
.25761 .53876 m .2572 .54016 L .2557 .539 L F
.25761 .53876 m .26003 .54069 L .2572 .54016 L F
.735 .26 .119 r
.50996 .59443 m .50886 .59564 L .50884 .59292 L F
.50996 .59443 m .51219 .59638 L .50886 .59564 L F
.656 .479 .633 r
.57967 .49496 m .57855 .49696 L .57534 .4949 L F
.634 .288 .367 r
.43427 .64612 m .43551 .64935 L .43173 .64781 L F
.233 0 .205 r
.43843 .64379 m .43427 .64612 L .43643 .6445 L F
.43843 .64379 m .4382 .6454 L .43427 .64612 L F
.603 .492 .699 r
.4382 .6454 m .43551 .64935 L .43427 .64612 L F
.727 .792 .904 r
.71985 .41326 m .71634 .41281 L .71899 .41001 L F
.756 .737 .835 r
.72259 .4106 m .71985 .41326 L .71899 .41001 L F
.878 .901 .485 r
.49895 .58782 m .49736 .59125 L .49808 .59025 L F
.511 .308 .542 r
.44457 .56668 m .44452 .56938 L .44198 .56977 L F
.333 0 0 r
.48652 .58386 m .48626 .58388 L .48427 .58398 L F
.183 0 0 r
.48522 .5822 m .48427 .58398 L .48288 .58405 L F
.699 .421 .499 r
.48172 .58185 m .48453 .58403 L .48457 .58173 L F
.175 0 0 r
.48427 .58398 m .48115 .58579 L .4821 .58466 L F
.183 0 0 r
.48288 .58405 m .48427 .58398 L .4821 .58466 L F
.58 .941 .822 r
.48427 .58398 m .48246 .58417 L .48115 .58579 L F
.699 .421 .499 r
.48172 .58185 m .48154 .58464 L .48382 .58348 L F
.58 .941 .822 r
.48246 .58417 m .48244 .58417 L .48243 .58419 L F
.214 0 .357 r
.48115 .58579 m .47965 .58502 L .4821 .58466 L F
.58 .941 .822 r
.48246 .58417 m .48243 .58419 L .48115 .58579 L F
.699 .421 .499 r
.48172 .58185 m .48143 .58465 L .48154 .58464 L F
.48248 .58416 m .48243 .58419 L .4848 .58424 L F
.48243 .58419 m .48154 .58464 L .48234 .58454 L F
.346 0 .213 r
.4848 .58424 m .48166 .58685 L .4824 .58432 L F
.699 .421 .499 r
.48243 .58419 m .4824 .58432 L .4848 .58424 L F
.346 0 .213 r
.4848 .58424 m .4824 .58432 L .48244 .58417 L F
.699 .421 .499 r
.4824 .58432 m .48234 .58454 L .4848 .58424 L F
.076 0 0 r
.48166 .58685 m .48115 .58579 L .48243 .58419 L F
.4824 .58432 m .48243 .58419 L .48244 .58417 L F
.48166 .58685 m .48243 .58419 L .4824 .58432 L F
.333 0 0 r
.48255 .58416 m .4848 .58424 L .48244 .58417 L F
.48652 .58386 m .4848 .58424 L .48255 .58416 L F
.48349 .58409 m .48255 .58416 L .48276 .58414 L F
.48255 .58416 m .48244 .58417 L .48246 .58417 L F
.48255 .58416 m .48246 .58417 L .48276 .58414 L F
.699 .421 .499 r
.48382 .58348 m .48248 .58416 L .48255 .58416 L F
.48453 .58403 m .48255 .58416 L .4848 .58424 L F
.333 0 0 r
.48349 .58409 m .48276 .58414 L .48427 .58398 L F
.699 .421 .499 r
.48382 .58348 m .48255 .58416 L .48453 .58403 L F
.48453 .58403 m .4848 .58424 L .48478 .58401 L F
.333 0 0 r
.48626 .58388 m .48349 .58409 L .48427 .58398 L F
.699 .421 .499 r
.48453 .58403 m .48478 .58401 L .48457 .58173 L F
.711 .714 .851 r
.72859 .41024 m .72481 .40941 L .72762 .40736 L F
.764 .776 .862 r
.73122 .40744 m .72859 .41024 L .72762 .40736 L F
.66 .593 .769 r
.73122 .40744 m .73235 .41107 L .72859 .41024 L F
.47 .3 .568 r
.41953 .64373 m .41724 .64436 L .41753 .64177 L F
.41953 .64373 m .41724 .64436 L .41753 .64177 L F
0 0 0 r
.4083 .59009 m .41022 .58937 L .41127 .5872 L F
.249 0 .087 r
.41127 .5872 m .41237 .5887 L .41321 .58676 L F
.41127 .5872 m .41022 .58937 L .41237 .5887 L F
.748 .618 .714 r
.47008 .57441 m .47212 .57902 L .46792 .57852 L F
.631 .497 .68 r
.47161 .58092 m .46792 .57852 L .47212 .57902 L F
.567 .324 .506 r
.47455 .57855 m .47161 .58092 L .47212 .57902 L F
.47455 .57855 m .47161 .58092 L .47212 .57902 L F
.707 .464 .554 r
.45109 .59888 m .45373 .59907 L .45359 .5966 L F
.614 .392 .557 r
.45359 .5966 m .45373 .59907 L .45659 .59867 L F
.497 .399 .675 r
.52321 .54569 m .52165 .54865 L .52267 .54621 L F
.527 .879 .985 r
.49705 .59836 m .49769 .59894 L .49533 .59959 L F
.901 .737 .669 r
.49769 .59894 m .49611 .60191 L .49533 .59959 L F
0 0 .448 r
.49533 .59959 m .4966 .60074 L .49705 .59836 L F
.49533 .59959 m .49611 .60191 L .4966 .60074 L F
.289 .257 .649 r
.25623 .57519 m .25817 .57754 L .25776 .57482 L F
.982 .803 .586 r
.58698 .50664 m .58568 .50562 L .58618 .50305 L F
.987 .822 .594 r
.58698 .50664 m .58526 .5077 L .58568 .50562 L F
.58698 .50664 m .58617 .50907 L .58526 .5077 L F
.04 0 .374 r
.57032 .55477 m .57121 .5562 L .57166 .5538 L F
.57032 .55477 m .57016 .5572 L .57121 .5562 L F
.92 .827 .737 r
.6021 .49082 m .60057 .49381 L .60314 .49374 L F
.966 .825 .654 r
.60024 .49662 m .60314 .49374 L .60057 .49381 L F
.60024 .49662 m .60162 .4977 L .60314 .49374 L F
.849 .803 .806 r
.60314 .49374 m .60402 .49214 L .6021 .49082 L F
.94 .574 .201 r
.23567 .61487 m .23516 .61644 L .23606 .61276 L F
.23567 .61487 m .2364 .61717 L .23516 .61644 L F
.392 .851 .83 r
.5156 .51841 m .51532 .5191 L .5134 .51957 L F
.5156 .51841 m .51755 .51823 L .51532 .5191 L F
.336 .105 .408 r
.26758 .61495 m .26703 .61725 L .26549 .6177 L F
.46 .284 .555 r
.26703 .61725 m .26501 .62048 L .26549 .6177 L F
.713 .472 .56 r
.44671 .56901 m .44452 .56938 L .44457 .56668 L F
.945 .87 .733 r
.75784 .42329 m .75831 .41887 L .75665 .42218 L F
.917 .817 .733 r
.7556 .42431 m .75784 .42329 L .75665 .42218 L F
.7556 .42431 m .75695 .42553 L .75784 .42329 L F
.273 .13 .496 r
.57705 .57789 m .57546 .58129 L .57573 .57867 L F
0 0 0 r
.55314 .49185 m .55063 .49484 L .55222 .49331 L F
.183 0 .072 r
.55222 .49331 m .55527 .491 L .55314 .49185 L F
.975 .752 .33 r
.65677 .42467 m .65759 .42767 L .66005 .42537 L F
.65677 .42467 m .65683 .42766 L .65759 .42767 L F
.836 .781 .799 r
.56156 .58776 m .55736 .58959 L .56028 .58677 L F
.56156 .58776 m .55939 .59043 L .55736 .58959 L F
.789 .783 .847 r
.56255 .58364 m .56156 .58776 L .56028 .58677 L F
.56255 .58364 m .56434 .58484 L .56156 .58776 L F
.804 .848 .883 r
.42807 .57377 m .42754 .57439 L .43023 .57265 L F
.536 .526 .792 r
.43023 .57265 m .43339 .57524 L .43217 .572 L F
.992 .874 .608 r
.75997 .41235 m .76155 .41116 L .76107 .40873 L F
.75997 .41235 m .76085 .41355 L .76155 .41116 L F
.704 .975 .919 r
.70198 .42922 m .70415 .42777 L .70333 .42732 L F
.66 .912 .979 r
.70099 .42846 m .70198 .42922 L .70333 .42732 L F
.659 .747 .916 r
.74844 .42893 m .75251 .42971 L .75115 .42813 L F
.357 .543 .9 r
.1882 .62899 m .18646 .62896 L .18453 .62627 L F
.651 .454 .605 r
.51658 .53878 m .51837 .53838 L .51964 .53696 L F
0 0 .234 r
.51964 .53696 m .52017 .53321 L .51772 .53317 L F
.51973 .53633 m .52045 .53528 L .52017 .53321 L F
.012 0 .311 r
.52017 .53321 m .52045 .53528 L .5219 .53177 L F
0 0 0 r
.52045 .53528 m .52168 .53367 L .5219 .53177 L F
.607 .888 .578 r
.52045 .53528 m .51889 .53665 L .52125 .53414 L F
.52045 .53528 m .52125 .53414 L .52168 .53367 L F
0 0 .234 r
.51964 .53696 m .52045 .53528 L .51973 .53633 L F
.878 .991 .803 r
.51964 .53696 m .51756 .53771 L .52045 .53528 L F
.51964 .53696 m .51837 .53838 L .51756 .53771 L F
.922 .965 .658 r
.76376 .39929 m .76544 .39469 L .76675 .39834 L F
.715 .957 .948 r
.7658 .39989 m .76376 .39929 L .76675 .39834 L F
.7658 .39989 m .76479 .40191 L .76376 .39929 L F
.556 .74 .962 r
.78588 .41479 m .7879 .41308 L .78516 .4134 L F
.78588 .41479 m .789 .41461 L .7879 .41308 L F
.788 .759 .827 r
.61565 .43985 m .61996 .43848 L .61831 .4368 L F
.815 .864 .884 r
.71573 .42249 m .71888 .42225 L .71781 .42094 L F
.696 .858 .96 r
.71781 .42094 m .71888 .42225 L .72163 .42084 L F
.387 .066 .294 r
.26009 .6266 m .25707 .62898 L .25794 .62741 L F
.069 .457 .883 r
.49849 .56475 m .49787 .56555 L .49635 .56437 L F
.49849 .56475 m .49955 .56618 L .49787 .56555 L F
.55 .313 .509 r
.43506 .58677 m .43832 .58413 L .43589 .58431 L F
.834 .885 .879 r
.72451 .41956 m .72666 .4203 L .72753 .41906 L F
.64 .883 .985 r
.50554 .58719 m .50155 .58747 L .50371 .58617 L F
.076 .41 .861 r
.50554 .58719 m .506 .58596 L .50363 .58399 L F
.50554 .58719 m .50648 .58719 L .506 .58596 L F
.506 .58596 m .50554 .58719 L .50371 .58617 L F
.506 .58596 m .50648 .58719 L .50554 .58719 L F
.718 .62 .746 r
.60901 .44948 m .61237 .44959 L .61125 .44604 L F
.721 .59 .709 r
.60901 .44948 m .61002 .45268 L .61237 .44959 L F
.425 .499 .832 r
.16795 .64539 m .17031 .64653 L .16911 .64324 L F
.65 .652 .838 r
.16815 .6475 m .17031 .64653 L .16795 .64539 L F
.579 .294 .448 r
.44001 .60795 m .44377 .60514 L .44021 .60592 L F
.706 .317 0 r
.52369 .56943 m .52488 .57201 L .5241 .57069 L F
0 0 .532 r
.5314 .59291 m .53033 .58944 L .53139 .59068 L F
.025 .468 .876 r
.74148 .39313 m .74092 .39371 L .73954 .3926 L F
.74148 .39313 m .74312 .39438 L .74092 .39371 L F
.514 .266 .476 r
.26963 .61664 m .26758 .61495 L .26961 .61416 L F
.26963 .61664 m .26703 .61725 L .26758 .61495 L F
0 0 0 r
.16332 .55236 m .16325 .55277 L .16526 .55163 L F
.16332 .55236 m .16118 .55349 L .16325 .55277 L F
0 0 .27 r
.5838 .55831 m .58262 .55741 L .58425 .5562 L F
.5838 .55831 m .58279 .55969 L .58262 .55741 L F
.767 .696 .784 r
.42162 .60819 m .42545 .60863 L .42387 .61018 L F
.627 .622 .826 r
.42561 .61161 m .4271 .60896 L .42545 .60863 L F
.22 0 0 r
.4263 .60966 m .42545 .60863 L .4271 .60896 L F
.4263 .60966 m .42387 .61018 L .42545 .60863 L F
.837 .703 .716 r
.60378 .47262 m .60549 .47381 L .60416 .47027 L F
.855 .69 .676 r
.60378 .47262 m .60528 .47641 L .60549 .47381 L F
.702 .604 .744 r
.60522 .44615 m .60752 .44335 L .60498 .4437 L F
.967 .645 .29 r
.49243 .57762 m .49383 .57907 L .49289 .5786 L F
.59 .797 .978 r
.49243 .57762 m .49383 .57907 L .49703 .57824 L F
.434 0 0 r
.49289 .5786 m .49618 .5806 L .49383 .57907 L F
.445 .274 .555 r
.61244 .43477 m .61469 .43395 L .6145 .4311 L F
.405 .188 .468 r
.61244 .43477 m .61228 .437 L .61469 .43395 L F
.91 .869 .433 r
.59121 .5319 m .59129 .53407 L .59217 .53038 L F
.926 .909 .517 r
.59039 .53618 m .59129 .53407 L .59121 .5319 L F
.957 .687 .483 r
.55939 .59043 m .55775 .59001 L .55736 .58959 L F
.55939 .59043 m .55955 .59375 L .55775 .59001 L F
.335 .073 .36 r
.44025 .62031 m .43708 .62345 L .43797 .62099 L F
.124 0 .03 r
.23194 .62176 m .23103 .62267 L .23382 .62062 L F
.568 .382 .589 r
.21482 .66041 m .21723 .65662 L .21338 .65627 L F
.21482 .66041 m .21762 .65983 L .21723 .65662 L F
.457 .303 .584 r
.21723 .65662 m .21914 .65924 L .21762 .65983 L F
.694 .576 .719 r
.60632 .4497 m .60387 .45276 L .60645 .45214 L F
.702 .556 .685 r
.60397 .45547 m .60645 .45214 L .60387 .45276 L F
.455 .445 .758 r
.73798 .41175 m .73587 .41408 L .73489 .41021 L F
.532 .562 .831 r
.73798 .41175 m .73834 .41376 L .73587 .41408 L F
.419 .332 .651 r
.28138 .59866 m .2791 .59663 L .28136 .59612 L F
.28138 .59866 m .27953 .59939 L .2791 .59663 L F
.259 .111 .481 r
.39109 .60861 m .39281 .60792 L .3931 .6051 L F
.298 .201 .573 r
.39109 .60861 m .39291 .6106 L .39281 .60792 L F
.245 .193 .598 r
.39146 .61114 m .39291 .6106 L .39109 .60861 L F
.624 .155 .118 r
.56224 .57933 m .5589 .58042 L .55889 .57821 L F
.56224 .57933 m .56139 .58039 L .5589 .58042 L F
.834 .425 .267 r
.56224 .57933 m .56355 .58146 L .56139 .58039 L F
.799 .998 .847 r
.53861 .51795 m .53604 .51922 L .53788 .51954 L F
.486 .23 .452 r
.39573 .60504 m .39843 .60232 L .39593 .60268 L F
0 0 .355 r
.53362 .60513 m .53363 .6012 L .53368 .60265 L F
.712 .757 .887 r
.22447 .64937 m .22726 .64971 L .22655 .64862 L F
.822 .931 .904 r
.22655 .64862 m .22797 .64908 L .23008 .64721 L F
.22655 .64862 m .22843 .64787 L .22978 .64806 L F
.22843 .64787 m .23008 .64721 L .22978 .64806 L F
.651 .351 .45 r
.23178 .64663 m .23089 .64877 L .22978 .64806 L F
0 .355 .826 r
.22978 .64806 m .23089 .64877 L .23035 .64814 L F
.22978 .64806 m .23035 .64814 L .22956 .6472 L F
.365 .796 .967 r
.22476 .64804 m .22655 .64862 L .22978 .64806 L F
.22469 .64804 m .22655 .64862 L .22476 .64804 L F
.822 .931 .904 r
.22655 .64862 m .22726 .64971 L .22797 .64908 L F
.824 .772 .804 r
.19961 .71944 m .19557 .71998 L .19789 .71896 L F
.714 .938 .626 r
.20202 .7165 m .19961 .71944 L .20005 .71828 L F
.509 .873 .983 r
.19961 .71944 m .19789 .71896 L .20005 .71828 L F
.587 .425 .629 r
.20202 .7165 m .20227 .71902 L .19961 .71944 L F
.618 .472 .661 r
.20253 .7213 m .19961 .71944 L .20227 .71902 L F
.20253 .7213 m .19978 .72242 L .19961 .71944 L F
0 0 0 r
.54544 .50058 m .54718 .49963 L .54806 .49776 L F
.54806 .49776 m .54977 .49661 L .55063 .49484 L F
.54806 .49776 m .54913 .49844 L .54977 .49661 L F
.54806 .49776 m .54718 .49963 L .54913 .49844 L F
.954 .889 .495 r
.59456 .51969 m .59584 .51804 L .59545 .51764 L F
.59456 .51969 m .59487 .52197 L .59584 .51804 L F
.873 .963 .63 r
.59545 .51764 m .59584 .51804 L .59779 .51442 L F
.196 0 .095 r
.54232 .50309 m .54484 .50257 L .54544 .50058 L F
0 0 0 r
.54544 .50058 m .5463 .50116 L .54718 .49963 L F
.54544 .50058 m .54484 .50257 L .5463 .50116 L F
.475 .453 .754 r
.5508 .58161 m .55276 .5808 L .5499 .5802 L F
.5499 .5802 m .55276 .5808 L .5508 .58161 L F
.46 .243 .497 r
.44153 .59321 m .44321 .59376 L .44106 .59385 L F
.44341 .59061 m .44323 .59346 L .44153 .59321 L F
.44323 .59346 m .44321 .59376 L .44153 .59321 L F
.465 .247 .498 r
.44516 .59314 m .44321 .59378 L .44341 .59061 L F
.524 .546 .82 r
.44321 .59378 m .44411 .59605 L .44082 .59418 L F
.557 .565 .818 r
.44599 .59547 m .44411 .59605 L .44321 .59378 L F
.44599 .59547 m .44321 .59378 L .44391 .59355 L F
.44531 .59357 m .44391 .59355 L .44516 .59314 L F
.44599 .59547 m .44391 .59355 L .44531 .59357 L F
.586 .158 .195 r
.44227 .59434 m .44547 .59377 L .44309 .59353 L F
.44296 .59353 m .44309 .59353 L .44297 .59352 L F
.46 .243 .497 r
.44106 .59385 m .44321 .59378 L .44082 .59418 L F
.586 .158 .195 r
.44227 .59434 m .44309 .59353 L .44296 .59353 L F
.44547 .59377 m .44559 .59375 L .44489 .59369 L F
.44547 .59377 m .44489 .59369 L .44297 .59352 L F
.465 .247 .498 r
.44516 .59314 m .44341 .59061 L .446 .59008 L F
.477 .519 .822 r
.44297 .59352 m .44489 .59369 L .44323 .58828 L F
.44489 .59369 m .44559 .59375 L .44555 .59366 L F
.298 .051 .362 r
.44703 .59212 m .44516 .59314 L .446 .59008 L F
.609 .581 .797 r
.44877 .59321 m .44599 .59547 L .44516 .59314 L F
.44877 .59321 m .44516 .59314 L .44703 .59212 L F
.477 .519 .822 r
.44489 .59369 m .44555 .59366 L .44323 .58828 L F
.46 .243 .497 r
.44321 .59376 m .44321 .59378 L .44106 .59385 L F
.594 .863 .526 r
.79073 .44206 m .78931 .44373 L .79188 .44078 L F
.315 .178 .53 r
.79087 .4448 m .78931 .44373 L .79073 .44206 L F
.79087 .4448 m .78946 .44614 L .78931 .44373 L F
.395 .244 .555 r
.25005 .59351 m .25219 .59271 L .25204 .58998 L F
.381 .186 .487 r
.24949 .59607 m .25219 .59271 L .25005 .59351 L F
.194 0 0 r
.51248 .5384 m .51635 .53887 L .51658 .53878 L F
.552 .884 .626 r
.51658 .53878 m .51756 .53771 L .51837 .53838 L F
.51658 .53878 m .51635 .53887 L .51756 .53771 L F
.875 .634 .571 r
.751 .39746 m .75395 .39857 L .75342 .40085 L F
.476 .4 .692 r
.79584 .43607 m .79349 .4347 L .79635 .43426 L F
.79584 .43607 m .79402 .4375 L .79349 .4347 L F
.879 .928 .85 r
.77878 .39572 m .77535 .39754 L .77839 .39498 L F
.799 .504 0 r
.77771 .39207 m .77878 .39572 L .77839 .39498 L F
.136 0 0 r
.18012 .54589 m .18231 .54544 L .1833 .54463 L F
0 0 0 r
.1833 .54463 m .18231 .54544 L .18434 .54467 L F
.782 .472 .464 r
.78367 .40432 m .78018 .40167 L .78091 .40375 L F
.626 .802 .967 r
.78018 .40167 m .78288 .4008 L .78173 .39934 L F
.079 .064 .538 r
.78091 .40375 m .78018 .40167 L .78173 .39934 L F
.691 .504 .629 r
.43856 .62873 m .43584 .62646 L .43732 .62679 L F
.43856 .62873 m .43553 .62936 L .43584 .62646 L F
.497 .399 .675 r
.52321 .54569 m .52385 .54816 L .52165 .54865 L F
.66 .482 .633 r
.58801 .46479 m .5881 .46738 L .59056 .46449 L F
.838 .576 .031 r
.53362 .60513 m .53445 .60883 L .53396 .60744 L F
.752 .29 .151 r
.53884 .61121 m .53692 .6112 L .53445 .60883 L F
0 .084 .606 r
.53445 .60883 m .53576 .60972 L .53396 .60744 L F
.53445 .60883 m .53692 .6112 L .53576 .60972 L F
.471 .164 .364 r
.72117 .38859 m .71832 .3891 L .7179 .38964 L F
.338 0 .111 r
.56395 .49732 m .56272 .49931 L .56022 .49987 L F
.787 .551 .579 r
.56643 .49733 m .56272 .49931 L .56395 .49732 L F
.71 .532 .646 r
.44377 .60514 m .44623 .6054 L .44642 .60285 L F
0 0 .312 r
.52757 .57745 m .52816 .5785 L .52777 .57769 L F
.52757 .57745 m .52777 .57769 L .52712 .57635 L F
0 0 .244 r
.52688 .57514 m .52747 .57734 L .52757 .57745 L F
.52747 .57734 m .52784 .57871 L .52757 .57745 L F
0 0 .369 r
.5284 .58106 m .52757 .57745 L .52784 .57871 L F
.702 .604 .744 r
.60522 .44615 m .60871 .44669 L .60752 .44335 L F
.711 .568 .691 r
.60522 .44615 m .60632 .4497 L .60871 .44669 L F
.719 .58 .698 r
.60871 .44669 m .60632 .4497 L .60901 .44948 L F
.715 .587 .711 r
.60645 .45214 m .61002 .45268 L .60901 .44948 L F
.719 .564 .678 r
.60645 .45214 m .60779 .45576 L .61002 .45268 L F
.682 .594 .75 r
.60752 .44335 m .60871 .44669 L .61121 .44358 L F
.66 .562 .733 r
.61121 .44358 m .60871 .44669 L .61125 .44604 L F
.718 .62 .746 r
.60901 .44948 m .61125 .44604 L .60871 .44669 L F
.478 .398 .688 r
.28872 .5593 m .2862 .55701 L .28792 .55701 L F
.28872 .5593 m .28661 .56153 L .2862 .55701 L F
.016 0 0 r
.5309 .53869 m .53193 .53723 L .53386 .53609 L F
.038 0 0 r
.55063 .49484 m .55172 .49557 L .55222 .49331 L F
.55063 .49484 m .54977 .49661 L .55172 .49557 L F
.368 .123 .406 r
.57174 .47656 m .5739 .47586 L .57431 .47387 L F
.489 .381 .658 r
.57174 .47656 m .5737 .47884 L .5739 .47586 L F
.57174 .47656 m .57197 .47958 L .5737 .47884 L F
.18 0 0 r
.21908 .5387 m .22133 .53877 L .22314 .53851 L F
.398 0 0 r
.22314 .53851 m .22133 .53877 L .22524 .53893 L F
.286 .03 .339 r
.40626 .59344 m .40824 .59268 L .4083 .59009 L F
.009 0 .272 r
.4083 .59009 m .4094 .59153 L .41022 .58937 L F
.4083 .59009 m .40824 .59268 L .4094 .59153 L F
0 .088 .631 r
.5284 .58106 m .52942 .58467 L .52998 .58301 L F
.986 .851 .477 r
.53037 .58683 m .52998 .58301 L .52942 .58467 L F
.605 .373 .539 r
.44967 .57854 m .45294 .58031 L .45377 .57788 L F
.606 .323 .461 r
.45294 .58031 m .4559 .57826 L .45377 .57788 L F
.357 .402 .771 r
.74355 .4222 m .74459 .42624 L .74635 .42385 L F
.478 .57 .87 r
.74459 .42624 m .74781 .42755 L .74635 .42385 L F
.396 .142 .408 r
.1608 .56956 m .16014 .57201 L .15811 .57252 L F
.445 .188 .428 r
.16228 .57137 m .1608 .56956 L .16305 .56986 L F
.16228 .57137 m .16014 .57201 L .1608 .56956 L F
.423 .336 .653 r
.28796 .58335 m .2861 .58747 L .28559 .58502 L F
0 0 .104 r
.58835 .54216 m .59004 .53834 L .58948 .5399 L F
0 0 0 r
.58948 .5399 m .58781 .5441 L .58835 .54216 L F
.395 0 .124 r
.57608 .47289 m .57858 .4726 L .57959 .47074 L F
.559 .142 .206 r
.57959 .47074 m .58215 .47228 L .58195 .47031 L F
.57959 .47074 m .57858 .4726 L .58215 .47228 L F
.811 .639 .669 r
.60286 .46422 m .60288 .46677 L .60622 .46707 L F
.81 .654 .689 r
.60288 .46677 m .60416 .47027 L .60622 .46707 L F
.888 .987 .727 r
.58296 .52083 m .58267 .52011 L .58449 .51902 L F
.929 .963 .661 r
.58388 .5166 m .58547 .51529 L .58449 .51902 L F
.976 .917 .666 r
.58449 .51902 m .58267 .52011 L .58388 .5166 L F
.58 .398 .599 r
.52771 .53354 m .52803 .53658 L .52518 .53673 L F
0 0 0 r
.52771 .53354 m .52656 .53532 L .52518 .53673 L F
.448 .484 .804 r
.52844 .52963 m .52968 .53306 L .52771 .53354 L F
0 0 0 r
.52933 .53226 m .52771 .53354 L .52968 .53306 L F
.419 .281 .586 r
.52771 .53354 m .52803 .53658 L .52997 .53543 L F
0 0 0 r
.52933 .53226 m .52656 .53532 L .52771 .53354 L F
.069 0 0 r
.46078 .58465 m .4595 .58509 L .45714 .58532 L F
.54 .203 .345 r
.45805 .58583 m .46043 .58626 L .46078 .58465 L F
0 0 .099 r
.46256 .58111 m .46184 .5838 L .46078 .58465 L F
.459 .878 .762 r
.46184 .5838 m .4595 .58509 L .46078 .58465 L F
.03 0 .195 r
.79369 .43971 m .79188 .44078 L .79402 .4375 L F
.234 .005 .348 r
.79369 .43971 m .79073 .44206 L .79188 .44078 L F
.558 .413 .639 r
.56564 .56379 m .56774 .56365 L .56804 .56038 L F
.476 .395 .686 r
.56564 .56379 m .56781 .56588 L .56774 .56365 L F
.56564 .56379 m .56602 .56653 L .56781 .56588 L F
.485 .206 .415 r
.45053 .6115 m .44759 .61396 L .4479 .61182 L F
.728 .667 .79 r
.17356 .65058 m .1759 .65127 L .17355 .64732 L F
.258 .334 .752 r
.43374 .59287 m .43678 .5955 L .43789 .59321 L F
.652 .297 .357 r
.43678 .5955 m .44084 .59335 L .43789 .59321 L F
.335 .073 .36 r
.44025 .62031 m .44038 .6229 L .43708 .62345 L F
.929 .963 .661 r
.58388 .5166 m .58511 .51461 L .58547 .51529 L F
.45 .166 .389 r
.25502 .62965 m .25435 .6318 L .25217 .63227 L F
.375 .102 .366 r
.25707 .62898 m .25435 .6318 L .25502 .62965 L F
0 0 .336 r
.5319 .59668 m .53216 .59537 L .5314 .59291 L F
0 0 .279 r
.5319 .59668 m .5325 .59798 L .53216 .59537 L F
.5319 .59668 m .5327 .59902 L .5325 .59798 L F
.23 0 .267 r
.47566 .61379 m .473 .61674 L .47367 .61469 L F
.784 .717 .79 r
.67487 .43498 m .67142 .43463 L .67383 .43294 L F
.625 .696 .895 r
.67745 .43417 m .67487 .43498 L .67383 .43294 L F
.636 .901 .586 r
.50725 .60762 m .50663 .60876 L .50907 .60825 L F
.715 .587 .711 r
.60645 .45214 m .60901 .44948 L .60632 .4497 L F
.629 .647 .849 r
.42894 .59921 m .42651 .59959 L .42494 .59644 L F
.603 .415 .601 r
.42645 .60229 m .42894 .59921 L .42651 .59959 L F
.42894 .59921 m .42645 .60229 L .42651 .59959 L F
.849 .834 .831 r
.75311 .42721 m .75695 .42553 L .7556 .42431 L F
.767 .655 .738 r
.60779 .45576 m .60533 .4587 L .60784 .45828 L F
.736 .536 .622 r
.69811 .41358 m .69803 .41565 L .69565 .4162 L F
.68 .534 .68 r
.7015 .4138 m .69803 .41565 L .69811 .41358 L F
.457 .769 .997 r
.52656 .53532 m .52803 .53658 L .52518 .53673 L F
.395 .192 .483 r
.27953 .59939 m .27918 .60193 L .27722 .6023 L F
.227 .065 .442 r
.27918 .60193 m .27707 .60513 L .27722 .6023 L F
.305 .604 .951 r
.53647 .56802 m .53762 .56944 L .53558 .56941 L F
0 0 0 r
.59217 .53038 m .59377 .5265 L .5923 .53001 L F
.668 .827 .397 r
.59121 .5319 m .59217 .53038 L .5923 .53001 L F
.616 .315 .436 r
.4489 .58853 m .44859 .5905 L .446 .59008 L F
.491 .204 .406 r
.45131 .58977 m .4489 .58853 L .4513 .58778 L F
.45131 .58977 m .44859 .5905 L .4489 .58853 L F
.605 .373 .539 r
.44967 .57854 m .44973 .5811 L .45294 .58031 L F
.746 .719 .827 r
.62135 .43208 m .6249 .43281 L .6232 .43056 L F
.695 .668 .819 r
.6232 .43056 m .6249 .43281 L .62697 .43139 L F
0 .075 .632 r
.50784 .53539 m .50894 .5384 L .50746 .53637 L F
.428 .868 .803 r
.50533 .52352 m .50935 .52209 L .50667 .52302 L F
0 0 .311 r
.65583 .41394 m .65535 .41655 L .65743 .41423 L F
.702 .556 .685 r
.60397 .45547 m .60779 .45576 L .60645 .45214 L F
.166 .393 .838 r
.79081 .39842 m .79003 .3985 L .78759 .3949 L F
.888 .953 .842 r
.7807 .44959 m .78257 .4453 L .78284 .44609 L F
.797 .996 .777 r
.78284 .44609 m .78257 .4453 L .78523 .44255 L F
.863 .608 .551 r
.64701 .4074 m .64977 .4076 L .64625 .40726 L F
.64701 .4074 m .64959 .40958 L .64977 .4076 L F
.387 0 0 r
.20262 .54071 m .20497 .54088 L .20716 .5398 L F
0 0 0 r
.20716 .5398 m .20727 .53977 L .20934 .53947 L F
.20716 .5398 m .20497 .54088 L .20727 .53977 L F
.591 .146 .163 r
.15927 .57386 m .15811 .57252 L .16014 .57201 L F
.15927 .57386 m .15632 .57418 L .15811 .57252 L F
.19 0 0 r
.42053 .61724 m .41775 .61693 L .41794 .62017 L F
0 0 0 r
.41807 .6217 m .4161 .62447 L .41675 .62391 L F
.682 .272 .263 r
.41807 .6217 m .42033 .62258 L .41859 .62083 L F
0 0 0 r
.41971 .62234 m .4193 .62173 L .42033 .62258 L F
.41807 .6217 m .4193 .62173 L .41971 .62234 L F
.41807 .6217 m .41675 .62391 L .4193 .62173 L F
.617 .385 .544 r
.41737 .62252 m .41886 .6211 L .4193 .62173 L F
.804 .548 .551 r
.4227 .62179 m .4193 .62173 L .41904 .61852 L F
0 0 .316 r
.41904 .61852 m .4193 .62173 L .41995 .62006 L F
.617 .385 .544 r
.41886 .6211 m .41995 .62006 L .4193 .62173 L F
.682 .272 .263 r
.41807 .6217 m .41859 .62083 L .41794 .62017 L F
.926 .678 .543 r
.53413 .56018 m .53359 .56248 L .5365 .56338 L F
.465 .323 .602 r
.45796 .60739 m .45559 .60564 L .45791 .60512 L F
.45796 .60739 m .45595 .60809 L .45559 .60564 L F
.789 .862 .904 r
.68342 .43161 m .68028 .43179 L .68203 .43034 L F
.86 .875 .848 r
.68596 .42863 m .68342 .43161 L .68203 .43034 L F
.55 .716 .95 r
.24316 .53823 m .24151 .53977 L .24091 .5391 L F
.24316 .53823 m .24376 .5395 L .24151 .53977 L F
.13 .1 .553 r
.57528 .58339 m .57569 .58597 L .57399 .58756 L F
0 0 .401 r
.57569 .58597 m .57411 .59011 L .57399 .58756 L F
.675 .811 .948 r
.64403 .42521 m .6479 .42582 L .64655 .42441 L F
.604 .816 .981 r
.64655 .42441 m .6479 .42582 L .65024 .42493 L F
0 0 0 r
.19758 .65224 m .19805 .65241 L .19565 .65251 L F
.19758 .65224 m .19961 .65171 L .19805 .65241 L F
.578 .374 .567 r
.6145 .4311 m .61703 .43328 L .61744 .43012 L F
.6145 .4311 m .61469 .43395 L .61703 .43328 L F
.505 .51 .795 r
.50014 .59357 m .50295 .59373 L .50344 .59282 L F
.444 .356 .662 r
.28872 .5593 m .2871 .56342 L .28661 .56153 L F
.592 .325 .481 r
.7094 .40788 m .70912 .40982 L .70658 .41021 L F
.674 .491 .63 r
.71292 .40736 m .70912 .40982 L .7094 .40788 L F
.416 .228 .516 r
.71517 .40695 m .71509 .40461 L .71711 .40412 L F
.71517 .40695 m .71509 .40461 L .71711 .40412 L F
.97 .7 .282 r
.65876 .44692 m .65837 .449 L .65825 .44532 L F
.65876 .44692 m .65922 .4498 L .65837 .449 L F
.502 .562 .85 r
.66076 .44504 m .65876 .44692 L .65825 .44532 L F
.608 .575 .792 r
.66076 .44504 m .65922 .4498 L .65876 .44692 L F
.761 .779 .868 r
.42546 .58439 m .42623 .58714 L .42649 .58462 L F
.704 .548 .674 r
.4086 .61751 m .40564 .62014 L .4056 .61741 L F
.4056 .61741 m .40564 .62014 L .4086 .61751 L F
.4086 .61751 m .4056 .61741 L .40689 .61748 L F
.615 .932 .963 r
.17266 .62436 m .16823 .62532 L .17115 .62244 L F
.624 .72 .915 r
.17468 .62338 m .17266 .62436 L .17115 .62244 L F
.855 .69 .676 r
.60378 .47262 m .60189 .47569 L .60528 .47641 L F
.85 .677 .667 r
.6017 .47805 m .60528 .47641 L .60189 .47569 L F
.6017 .47805 m .60333 .47921 L .60528 .47641 L F
.429 .705 .98 r
.26939 .54426 m .27151 .54409 L .27094 .5457 L F
.448 .726 .985 r
.27151 .54409 m .27311 .54551 L .27094 .5457 L F
.708 .855 .952 r
.70922 .4244 m .71267 .42479 L .71133 .42332 L F
.735 .893 .951 r
.71133 .42332 m .71267 .42479 L .71573 .42249 L F
.259 0 .312 r
.22297 .6266 m .22053 .62957 L .2224 .62848 L F
.358 0 .039 r
.22361 .62831 m .22297 .6266 L .2224 .62848 L F
.22361 .62831 m .22528 .62636 L .22297 .6266 L F
.777 .281 .032 r
.51319 .5565 m .51589 .55763 L .51567 .55777 L F
.6 .906 .983 r
.66569 .40097 m .66608 .39969 L .66543 .39869 L F
.66569 .40097 m .66394 .40098 L .66608 .39969 L F
.793 .511 .509 r
.66569 .40097 m .6635 .40331 L .66394 .40098 L F
.66569 .40097 m .6671 .4041 L .6635 .40331 L F
.877 .536 .4 r
.6684 .40422 m .6671 .4041 L .66569 .40097 L F
.74 .694 .807 r
.19327 .72249 m .19478 .72583 L .19132 .7249 L F
.788 .964 .654 r
.19478 .72583 m .19279 .72762 L .19132 .7249 L F
.634 .642 .841 r
.19701 .72522 m .19478 .72583 L .19327 .72249 L F
.491 .512 .807 r
.19742 .72811 m .19478 .72583 L .19701 .72522 L F
.739 .548 .635 r
.51772 .53317 m .52017 .53321 L .52079 .53042 L F
.373 .208 .524 r
.52079 .53042 m .52282 .53003 L .52263 .52668 L F
.034 0 .345 r
.52079 .53042 m .5219 .53177 L .52282 .53003 L F
.52079 .53042 m .52017 .53321 L .5219 .53177 L F
.748 .618 .714 r
.47008 .57441 m .46792 .57852 L .46839 .57483 L F
.55 .333 .537 r
.44538 .61456 m .4452 .61704 L .44271 .61744 L F
.537 .321 .535 r
.4478 .61652 m .44538 .61456 L .44759 .61396 L F
.4478 .61652 m .4452 .61704 L .44538 .61456 L F
.745 .289 .169 r
.49503 .5415 m .49282 .54146 L .49334 .53984 L F
.825 .761 .248 r
.49334 .53984 m .49282 .54146 L .49334 .53854 L F
.754 .683 .783 r
.70411 .41335 m .70551 .41702 L .7018 .41639 L F
.752 .733 .835 r
.70669 .41258 m .70551 .41702 L .70411 .41335 L F
.70669 .41258 m .70755 .41581 L .70551 .41702 L F
0 0 .228 r
.74827 .4103 m .74871 .41088 L .7497 .40941 L F
0 0 0 r
.42209 .57887 m .42343 .57825 L .42496 .57882 L F
.42107 .58056 m .42009 .58247 L .42362 .57946 L F
.42361 .57924 m .42362 .57946 L .42427 .5789 L F
.42107 .58056 m .42362 .57946 L .42361 .57924 L F
.735 .251 0 r
.426 .58088 m .42496 .57882 L .42358 .57831 L F
.42358 .57841 m .42358 .57831 L .42343 .57825 L F
.426 .58088 m .42358 .57831 L .42358 .57841 L F
.558 .883 .99 r
.4086 .61751 m .40689 .61748 L .41043 .61684 L F
.687 .219 .137 r
.4086 .61751 m .40677 .61894 L .40689 .61748 L F
.629 .962 .842 r
.78745 .43756 m .78915 .43579 L .7909 .43541 L F
.015 0 .432 r
.78749 .43948 m .78915 .43579 L .78745 .43756 L F
.429 .175 .425 r
.24067 .60804 m .24283 .60769 L .24324 .6054 L F
.361 .174 .487 r
.24532 .60241 m .24324 .6054 L .24529 .60486 L F
.525 .316 .539 r
.24283 .60769 m .24529 .60486 L .24324 .6054 L F
0 0 .188 r
.20202 .7165 m .20253 .71902 L .20227 .71902 L F
.639 .203 .196 r
.20005 .71828 m .20253 .71902 L .20202 .7165 L F
0 0 0 r
.78519 .44262 m .78683 .44098 L .78749 .43948 L F
.509 .83 .524 r
.78519 .44262 m .78523 .44255 L .78683 .44098 L F
.33 .753 .975 r
.23133 .53881 m .23346 .53869 L .23527 .53943 L F
.164 .663 .912 r
.23346 .53869 m .23734 .53952 L .23527 .53943 L F
.694 .613 .761 r
.73489 .41021 m .73235 .41107 L .73122 .40744 L F
.778 .709 .787 r
.55276 .5808 m .55034 .58426 L .5508 .58161 L F
0 0 0 r
.55141 .58199 m .5508 .58161 L .55034 .58426 L F
.55141 .58199 m .55276 .5808 L .5508 .58161 L F
.483 .741 .985 r
.20595 .65064 m .20981 .65163 L .2081 .65025 L F
.557 .772 .978 r
.2081 .65025 m .20981 .65163 L .21201 .6509 L F
0 0 0 r
.2224 .62848 m .22053 .62957 L .21857 .63115 L F
.364 0 0 r
.21722 .66846 m .22216 .67054 L .21955 .66956 L F
.699 .262 0 r
.53692 .6112 m .53624 .61041 L .53576 .60972 L F
.736 .937 .952 r
.53884 .61121 m .53624 .61041 L .53692 .6112 L F
.442 0 0 r
.54096 .61263 m .53624 .61041 L .53884 .61121 L F
.274 0 0 r
.45736 .61637 m .45966 .61623 L .46106 .61504 L F
.446 0 .076 r
.45966 .61623 m .46309 .61465 L .46106 .61504 L F
.381 .064 .298 r
.79631 .43894 m .79402 .4375 L .79584 .43607 L F
.79631 .43894 m .79369 .43971 L .79402 .4375 L F
0 .088 .647 r
.40237 .63252 m .40277 .63137 L .40079 .62911 L F
0 .015 .588 r
.40237 .63252 m .40413 .63492 L .40277 .63137 L F
.741 .273 .138 r
.43443 .6022 m .43916 .60426 L .43641 .60338 L F
.36 .036 .274 r
.17384 .56324 m .17108 .56529 L .17185 .564 L F
.346 .038 .293 r
.46775 .59022 m .47019 .58978 L .47066 .58758 L F
.494 .166 .339 r
.47066 .58758 m .47268 .58912 L .47314 .58711 L F
.47066 .58758 m .47019 .58978 L .47268 .58912 L F
.705 .708 .85 r
.50043 .59715 m .49907 .59952 L .49769 .59894 L F
.254 .446 .857 r
.50049 .60174 m .49769 .59894 L .49907 .59952 L F
.687 .868 .967 r
.50302 .59703 m .49907 .59952 L .50043 .59715 L F
.513 .204 .38 r
.46547 .59037 m .46683 .59234 L .46775 .59022 L F
.46547 .59037 m .46439 .59284 L .46683 .59234 L F
.795 .971 .911 r
.68101 .4393 m .68481 .43767 L .68395 .43704 L F
.811 .975 .899 r
.68395 .43704 m .68481 .43767 L .68777 .43507 L F
.121 .608 .912 r
.47626 .55729 m .47836 .55759 L .4799 .55837 L F
.556 0 0 r
.47836 .55759 m .48236 .55888 L .4799 .55837 L F
.393 0 0 r
.20646 .70185 m .20853 .70044 L .21024 .70081 L F
.41 .23 .524 r
.56602 .56653 m .56782 .56815 L .56781 .56588 L F
.56602 .56653 m .56599 .569 L .56782 .56815 L F
.725 .336 .313 r
.68545 .41628 m .68943 .41695 L .68844 .41884 L F
.62 .218 .26 r
.68844 .41884 m .68943 .41695 L .69185 .41857 L F
.586 .262 .387 r
.68943 .41695 m .69287 .41639 L .69185 .41857 L F
.661 .945 .96 r
.69563 .43097 m .69715 .42896 L .6946 .42992 L F
.69563 .43097 m .69812 .42962 L .69715 .42896 L F
.945 .897 .749 r
.59779 .51442 m .59774 .51219 L .59697 .51358 L F
.873 .963 .63 r
.59545 .51764 m .59779 .51442 L .59697 .51358 L F
.175 0 0 r
.19438 .54156 m .19669 .54158 L .1983 .54125 L F
.56 .017 0 r
.45436 .55754 m .45642 .55888 L .45756 .55802 L F
.69 .175 .003 r
.45642 .55888 m .46019 .56012 L .45756 .55802 L F
0 0 .192 r
.5736 .54815 m .57229 .55159 L .57382 .55001 L F
0 0 .082 r
.57382 .55001 m .57229 .55159 L .57166 .5538 L F
.501 .288 .521 r
.56337 .56953 m .56106 .57255 L .56348 .57187 L F
.537 .323 .536 r
.56348 .57187 m .56599 .569 L .56337 .56953 L F
0 .07 .631 r
.16247 .62389 m .16371 .6255 L .16357 .6265 L F
.507 .809 .999 r
.16438 .62541 m .16357 .6265 L .16371 .6255 L F
.65 .652 .838 r
.16815 .6475 m .17122 .64778 L .17031 .64653 L F
.058 0 .306 r
.58018 .5655 m .57884 .56651 L .58054 .56327 L F
.059 0 .395 r
.58018 .5655 m .57888 .56899 L .57884 .56651 L F
.249 .613 .956 r
.21352 .55385 m .21371 .55263 L .21204 .55265 L F
.21352 .55385 m .2154 .55403 L .21371 .55263 L F
.652 .281 .327 r
.67132 .40536 m .6671 .4041 L .6684 .40422 L F
.344 .054 .321 r
.79878 .43308 m .79903 .43159 L .80148 .43064 L F
.406 .522 .862 r
.79428 .39942 m .79252 .40143 L .79081 .39842 L F
.395 .504 .851 r
.79446 .40153 m .79252 .40143 L .79428 .39942 L F
.884 .937 .565 r
.65665 .40632 m .65461 .41047 L .65494 .40835 L F
.989 .727 .425 r
.6587 .40675 m .65575 .40494 L .65665 .40632 L F
.6587 .40675 m .65711 .40266 L .65575 .40494 L F
.586 .838 .473 r
.65665 .40632 m .65728 .40541 L .6587 .40675 L F
.65665 .40632 m .65494 .40835 L .65728 .40541 L F
.244 .649 .962 r
.47127 .5733 m .47008 .57441 L .46949 .57335 L F
.47127 .5733 m .47008 .57441 L .46949 .57335 L F
.703 .715 .858 r
.47271 .57187 m .47008 .57441 L .47069 .57306 L F
.331 .655 .971 r
.48949 .56126 m .49329 .56377 L .49035 .56234 L F
.624 .062 0 r
.48949 .56126 m .49635 .56437 L .49329 .56377 L F
.85 .456 .297 r
.77082 .43736 m .76933 .43857 L .76844 .43697 L F
.77082 .43736 m .77219 .43977 L .76933 .43857 L F
0 0 .449 r
.77145 .43565 m .77082 .43736 L .77107 .43372 L F
.262 .255 .663 r
.77426 .43794 m .77082 .43736 L .77145 .43565 L F
.77426 .43794 m .77219 .43977 L .77082 .43736 L F
.379 .166 .459 r
.5739 .47586 m .57608 .47289 L .57431 .47387 L F
.661 .484 .634 r
.59056 .46449 m .5881 .46738 L .59066 .46707 L F
.631 .439 .604 r
.59066 .46707 m .59308 .46419 L .59056 .46449 L F
.96 .921 .574 r
.59396 .52409 m .59487 .52197 L .59456 .51969 L F
.468 .341 .624 r
.55861 .57583 m .56112 .57697 L .5613 .57517 L F
.55861 .57583 m .55889 .57821 L .56112 .57697 L F
.817 .708 .744 r
.53941 .57491 m .5402 .57883 L .53742 .57816 L F
0 .092 .621 r
.54108 .57679 m .5402 .57883 L .53941 .57491 L F
.075 0 .22 r
.54232 .50309 m .54372 .50396 L .54484 .50257 L F
.54232 .50309 m .54212 .50542 L .54372 .50396 L F
.718 .461 .536 r
.2393 .60997 m .24283 .60769 L .24067 .60804 L F
.697 .553 .687 r
.60161 .45833 m .60533 .4587 L .60397 .45547 L F
.702 .555 .685 r
.60397 .45547 m .60533 .4587 L .60779 .45576 L F
.062 0 0 r
.18841 .54214 m .19064 .54215 L .19195 .54204 L F
0 0 0 r
.19064 .54215 m .19438 .54156 L .19195 .54204 L F
.903 .924 .821 r
.74769 .41566 m .74552 .41606 L .74662 .41466 L F
.74769 .41566 m .7464 .41719 L .74552 .41606 L F
.917 .53 .252 r
.53003 .55635 m .5313 .5593 L .53215 .55827 L F
.777 .308 .129 r
.5313 .5593 m .53413 .56018 L .53215 .55827 L F
.654 .97 .843 r
.7909 .43541 m .79256 .43356 L .79244 .43364 L F
.7909 .43541 m .78915 .43579 L .79256 .43356 L F
.986 .813 .42 r
.77482 .40158 m .77373 .40239 L .77292 .40059 L F
.08 .561 .9 r
.76215 .43452 m .76541 .4352 L .76425 .43431 L F
.456 .199 .434 r
.43454 .56638 m .43223 .56891 L .43398 .56802 L F
.72 .944 .955 r
.4365 .56528 m .43454 .56638 L .43488 .56463 L F
0 0 .431 r
.43398 .56802 m .43488 .56463 L .43454 .56638 L F
.676 .228 0 r
.52817 .55031 m .52977 .55288 L .53005 .55298 L F
.958 .793 .35 r
.52977 .55288 m .53003 .55635 L .53005 .55298 L F
.52 .389 .643 r
.45805 .58583 m .46049 .58944 L .46043 .58626 L F
.45805 .58583 m .45824 .59013 L .46049 .58944 L F
.777 .862 .912 r
.5553 .58086 m .55415 .58431 L .55276 .5808 L F
.5553 .58086 m .55629 .58184 L .55415 .58431 L F
.6 .561 .782 r
.55629 .58184 m .55711 .58406 L .55415 .58431 L F
.778 .709 .787 r
.55276 .5808 m .55415 .58431 L .55034 .58426 L F
.891 .735 .682 r
.65881 .42177 m .66005 .42537 L .66049 .42285 L F
.897 .732 .669 r
.60296 .48416 m .60084 .48725 L .60435 .48721 L F
.897 .747 .687 r
.60084 .48725 m .6021 .49082 L .60435 .48721 L F
.048 .606 .808 r
.19196 .65223 m .19182 .652 L .18954 .65258 L F
.19196 .65223 m .19363 .65232 L .19182 .652 L F
.85 .886 .865 r
.66623 .43943 m .6672 .44111 L .66483 .44304 L F
.93 .893 .772 r
.66882 .43727 m .6672 .44111 L .66623 .43943 L F
.584 .945 .846 r
.66891 .43989 m .6672 .44111 L .66882 .43727 L F
.206 .724 .871 r
.24591 .53953 m .24964 .53944 L .2473 .5398 L F
0 0 .208 r
.641 .42158 m .64168 .41788 L .6398 .41883 L F
.703 .703 .848 r
.71046 .41343 m .70755 .41581 L .70669 .41258 L F
.738 .664 .777 r
.42 .58731 m .42438 .58921 L .42244 .58658 L F
.42 .58731 m .42151 .59048 L .42438 .58921 L F
.79 .739 .806 r
.42244 .58658 m .42438 .58921 L .42623 .58714 L F
.973 .728 .304 r
.67072 .40247 m .67143 .40158 L .66987 .40034 L F
.67072 .40247 m .67167 .40434 L .67143 .40158 L F
.664 .477 .622 r
.41764 .59289 m .41528 .59323 L .41785 .59013 L F
.41764 .59289 m .41528 .59323 L .41785 .59013 L F
.69 .642 .798 r
.41785 .59013 m .42151 .59048 L .42 .58731 L F
0 0 0 r
.42 .58731 m .41953 .58894 L .41785 .59013 L F
.687 .475 .594 r
.41764 .59289 m .42151 .59048 L .41785 .59013 L F
0 0 .175 r
.41953 .58894 m .41764 .59289 L .41785 .59013 L F
.382 .816 .657 r
.24392 .55156 m .24168 .55269 L .24022 .55356 L F
0 0 0 r
.2461 .55196 m .24168 .55269 L .24392 .55156 L F
.86 .875 .848 r
.68596 .42863 m .68203 .43034 L .68493 .42752 L F
.856 .917 .872 r
.68852 .42587 m .68596 .42863 L .68493 .42752 L F
.33 0 0 r
.48206 .61168 m .4811 .61331 L .47819 .61366 L F
.777 .335 .2 r
.47975 .61132 m .4811 .61331 L .48206 .61168 L F
.638 .505 .685 r
.43311 .63211 m .4305 .63259 L .43286 .62943 L F
.635 .514 .698 r
.43407 .63512 m .4305 .63259 L .43311 .63211 L F
.43407 .63512 m .43062 .63601 L .4305 .63259 L F
.682 .289 .295 r
.44167 .57293 m .44177 .57455 L .43823 .57423 L F
.519 .164 .304 r
.44167 .57293 m .44432 .57417 L .44177 .57455 L F
.526 .142 .256 r
.445 .57272 m .44432 .57417 L .44167 .57293 L F
.729 .365 0 r
.21369 .67722 m .21472 .67979 L .21326 .67658 L F
.274 .724 .958 r
.52263 .52668 m .52249 .52576 L .52089 .52552 L F
.52263 .52668 m .52493 .52646 L .52249 .52576 L F
.395 .224 .528 r
.52263 .52668 m .52282 .53003 L .52493 .52646 L F
.652 .297 .357 r
.43678 .5955 m .44065 .59582 L .44084 .59335 L F
.474 .544 .848 r
.44084 .59335 m .44297 .59352 L .44096 .5889 L F
.119 0 .257 r
.44084 .59335 m .44227 .59434 L .44297 .59352 L F
.44084 .59335 m .44065 .59582 L .44227 .59434 L F
.659 .689 .867 r
.28676 .55038 m .28454 .5514 L .28296 .54874 L F
.178 0 0 r
.52458 .51605 m .52353 .51521 L .52216 .51646 L F
.52458 .51605 m .52604 .51468 L .52353 .51521 L F
.346 .818 .76 r
.54096 .61263 m .54463 .61144 L .5433 .61308 L F
.703 .267 .21 r
.54463 .61144 m .54708 .61368 L .5433 .61308 L F
.128 .281 .751 r
.42579 .64938 m .42751 .65148 L .42703 .64972 L F
.809 .657 .694 r
.16411 .62045 m .16315 .62064 L .16473 .61987 L F
.16411 .62045 m .16079 .62167 L .16315 .62064 L F
.16411 .62045 m .16217 .62312 L .16079 .62167 L F
.16411 .62045 m .16285 .62323 L .16217 .62312 L F
.384 .189 .489 r
.16473 .61987 m .16285 .62323 L .16411 .62045 L F
.604 .347 .5 r
.44697 .58341 m .44973 .5811 L .44751 .58209 L F
.687 .475 .594 r
.41764 .59289 m .42139 .59304 L .42151 .59048 L F
.73 .857 .941 r
.77781 .42504 m .77965 .42677 L .78186 .42538 L F
.057 0 0 r
.17143 .54849 m .17171 .54969 L .17361 .54828 L F
.17143 .54849 m .16975 .55057 L .17171 .54969 L F
.357 .829 .801 r
.42679 .63386 m .42381 .63469 L .42515 .63475 L F
.42679 .63386 m .42596 .63373 L .42381 .63469 L F
0 0 .538 r
.42679 .63386 m .42767 .63331 L .42596 .63373 L F
.42679 .63386 m .42763 .635 L .42767 .63331 L F
.252 0 0 r
.19351 .55709 m .19029 .55885 L .19196 .55717 L F
.294 .266 .656 r
.22486 .67057 m .22303 .67204 L .22216 .67054 L F
.22486 .67057 m .22489 .67352 L .22303 .67204 L F
.76 .913 .942 r
.49964 .53065 m .49864 .53331 L .50186 .53049 L F
.675 .196 .106 r
.49781 .53484 m .5016 .53545 L .49864 .53331 L F
.638 .622 .818 r
.49864 .53331 m .50218 .53372 L .50186 .53049 L F
.64 .284 .351 r
.49864 .53331 m .5016 .53545 L .50218 .53372 L F
.498 .25 .469 r
.27227 .61103 m .27208 .61393 L .26961 .61416 L F
.366 .13 .418 r
.27497 .60784 m .27451 .61062 L .27227 .61103 L F
.438 .201 .456 r
.27422 .61335 m .27227 .61103 L .27451 .61062 L F
.27422 .61335 m .27208 .61393 L .27227 .61103 L F
.321 .265 .637 r
.25676 .5814 m .25816 .58079 L .25817 .57754 L F
.316 .252 .625 r
.25676 .5814 m .2587 .58337 L .25816 .58079 L F
.371 .259 .595 r
.25676 .5814 m .25688 .58429 L .2587 .58337 L F
.409 .298 .616 r
.28781 .56809 m .28758 .5722 L .28603 .57245 L F
.405 .281 .597 r
.28758 .5722 m .28806 .57449 L .28603 .57245 L F
.146 .237 .702 r
.28603 .57245 m .28806 .57449 L .2868 .57424 L F
.701 .456 .549 r
.69062 .40657 m .69313 .40688 L .69307 .40451 L F
.537 .323 .537 r
.69579 .40616 m .69307 .40451 L .69313 .40688 L F
.69579 .40616 m .69566 .40394 L .69307 .40451 L F
.899 .521 .308 r
.44284 .62371 m .44025 .62031 L .44268 .62014 L F
.44284 .62371 m .44038 .6229 L .44025 .62031 L F
.55 .356 .57 r
.44271 .61744 m .44268 .62014 L .44025 .62031 L F
.451 .367 .67 r
.54262 .58971 m .54287 .59352 L .54058 .59357 L F
0 0 0 r
.57197 .47958 m .5742 .47858 L .5737 .47884 L F
.57197 .47958 m .57093 .48086 L .5742 .47858 L F
.291 .373 .776 r
.50224 .56795 m .50079 .56998 L .49955 .56618 L F
.041 .315 .801 r
.50282 .57016 m .50079 .56998 L .50224 .56795 L F
.50282 .57016 m .50376 .57232 L .50079 .56998 L F
.12 0 .122 r
.49378 .5369 m .49334 .53854 L .49587 .536 L F
.882 .913 .843 r
.77207 .38783 m .77283 .38972 L .77207 .39049 L F
.768 .989 .761 r
.55088 .61152 m .55196 .6095 L .54889 .61259 L F
.747 .955 .652 r
.55163 .60989 m .55196 .6095 L .55088 .61152 L F
.543 .341 .557 r
.4452 .61704 m .44268 .62014 L .44271 .61744 L F
.706 .777 .907 r
.71406 .41404 m .71046 .41343 L .71264 .41208 L F
.698 .718 .865 r
.71264 .41208 m .71634 .41281 L .71406 .41404 L F
.312 0 .15 r
.22755 .62589 m .22976 .62522 L .23103 .62267 L F
0 0 0 r
.23103 .62267 m .23229 .62218 L .23382 .62062 L F
.286 0 .138 r
.23103 .62267 m .23188 .62464 L .23229 .62218 L F
.23103 .62267 m .22976 .62522 L .23188 .62464 L F
.68 .204 .114 r
.67966 .41332 m .67856 .41463 L .67609 .41273 L F
.726 .261 .145 r
.67966 .41332 m .6821 .41543 L .67856 .41463 L F
.692 .321 .34 r
.67966 .41332 m .6819 .41383 L .6821 .41543 L F
.717 .582 .703 r
.599 .45874 m .59913 .46136 L .60161 .45833 L F
.651 .486 .648 r
.60161 .45833 m .59913 .46136 L .60165 .46092 L F
.734 .6 .707 r
.60165 .46092 m .60533 .4587 L .60161 .45833 L F
.687 .551 .695 r
.60752 .44335 m .61121 .44358 L .60998 .44014 L F
.544 .677 .925 r
.1799 .64957 m .1817 .65167 L .18347 .65088 L F
.834 .885 .879 r
.72451 .41956 m .72753 .41906 L .72652 .41845 L F
.567 .895 .984 r
.72902 .41753 m .72753 .41906 L .73009 .41867 L F
.72902 .41753 m .72652 .41845 L .72753 .41906 L F
.715 .907 .963 r
.55833 .59286 m .55646 .5954 L .55488 .59466 L F
.55833 .59286 m .55955 .59375 L .55646 .5954 L F
.449 0 .004 r
.21056 .69682 m .2129 .69513 L .20848 .69613 L F
.493 .407 .687 r
.21526 .69773 m .2129 .69513 L .21475 .69506 L F
.21526 .69773 m .21338 .69902 L .2129 .69513 L F
.21 0 0 r
.21475 .69506 m .2129 .69513 L .21056 .69682 L F
.45 .701 .974 r
.20595 .63409 m .20188 .63265 L .20384 .63272 L F
.441 .724 .986 r
.20793 .63385 m .20595 .63409 L .20384 .63272 L F
.039 .606 .769 r
.20883 .63419 m .20595 .63409 L .20793 .63385 L F
.849 .946 .587 r
.5781 .53638 m .57648 .53945 L .5767 .53774 L F
.628 .472 .652 r
.51392 .61444 m .51606 .61488 L .5182 .61327 L F
.426 .039 .2 r
.5182 .61327 m .51776 .61395 L .51726 .61401 L F
.5182 .61327 m .51726 .61401 L .51392 .61444 L F
0 0 0 r
.5182 .61327 m .51606 .61488 L .51715 .6141 L F
.5182 .61327 m .51715 .6141 L .51813 .6134 L F
.645 .79 .952 r
.51813 .6134 m .51715 .6141 L .51541 .61287 L F
.51715 .6141 m .51606 .61488 L .5159 .61441 L F
.426 .039 .2 r
.51776 .61395 m .5159 .61441 L .51392 .61444 L F
.645 .79 .952 r
.51715 .6141 m .5159 .61441 L .51541 .61287 L F
.426 .039 .2 r
.51776 .61395 m .51748 .61439 L .5159 .61441 L F
.448 .656 .949 r
.5159 .61441 m .51606 .61488 L .51392 .61444 L F
.426 .039 .2 r
.51748 .61439 m .51716 .61489 L .51392 .61444 L F
.448 .656 .949 r
.51541 .61287 m .5159 .61441 L .51392 .61444 L F
.353 .504 .87 r
.51392 .61444 m .51716 .61489 L .51541 .61287 L F
.299 .515 .896 r
.26294 .56607 m .26349 .56414 L .26051 .563 L F
.26294 .56607 m .26422 .56569 L .26349 .56414 L F
.571 .45 .676 r
.2624 .56884 m .26422 .56569 L .26294 .56607 L F
.547 .573 .832 r
.76166 .37906 m .76031 .38258 L .75893 .38206 L F
.76166 .37906 m .76285 .38262 L .76031 .38258 L F
.501 .529 .817 r
.76399 .38631 m .76031 .38258 L .76285 .38262 L F
.557 .318 .509 r
.19978 .72242 m .19977 .72528 L .19701 .72522 L F
.032 0 .38 r
.20093 .72386 m .19978 .72242 L .20253 .7213 L F
.20093 .72386 m .19977 .72528 L .19978 .72242 L F
.8 .643 .687 r
.69803 .41565 m .69908 .41925 L .69561 .41878 L F
.669 .568 .733 r
.7018 .41639 m .69908 .41925 L .69803 .41565 L F
.828 1 .816 r
.21223 .70472 m .21046 .70638 L .21055 .70571 L F
.21223 .70472 m .21046 .70638 L .21055 .70571 L F
.886 .734 .688 r
.78016 .42401 m .78186 .42538 L .78295 .42315 L F
.417 .169 .428 r
.79878 .43308 m .79584 .43607 L .79635 .43426 L F
.727 .572 .68 r
.60998 .44014 m .61345 .44281 L .61378 .44077 L F
.60998 .44014 m .61121 .44358 L .61345 .44281 L F
.77 .697 .783 r
.61378 .44077 m .61345 .44281 L .61565 .43985 L F
.658 .572 .747 r
.60998 .44014 m .61378 .44077 L .61228 .437 L F
.253 .391 .809 r
.40895 .6469 m .41039 .64591 L .40768 .64394 L F
.40895 .6469 m .41056 .64808 L .41039 .64591 L F
.423 .336 .653 r
.28796 .58335 m .28797 .58685 L .2861 .58747 L F
.425 .23 .51 r
.28797 .58685 m .28576 .58986 L .2861 .58747 L F
.421 .867 .829 r
.20995 .63348 m .20883 .63419 L .20793 .63385 L F
.832 .566 .018 r
.72366 .39115 m .72405 .39199 L .72338 .38909 L F
.653 .887 .537 r
.72177 .39467 m .72405 .39199 L .72366 .39115 L F
.832 .566 .018 r
.72366 .39115 m .72405 .39199 L .72338 .38909 L F
.613 .299 .415 r
.43407 .63512 m .43056 .63713 L .43062 .63601 L F
.513 .311 .544 r
.73752 .40717 m .73774 .40962 L .73489 .41021 L F
.455 .445 .758 r
.73798 .41175 m .73489 .41021 L .73774 .40962 L F
.558 .565 .817 r
.19192 .63213 m .18977 .63269 L .1882 .62899 L F
.311 .064 .369 r
.27707 .60513 m .27678 .60752 L .27497 .60784 L F
.227 .065 .442 r
.27918 .60193 m .279 .60429 L .27707 .60513 L F
.493 .333 .592 r
.279 .60429 m .27678 .60752 L .27707 .60513 L F
.476 .309 .575 r
.28138 .59866 m .27918 .60193 L .27953 .59939 L F
.364 .187 .502 r
.5613 .57517 m .56348 .57187 L .56106 .57255 L F
.631 .497 .68 r
.47161 .58092 m .46937 .5821 L .46792 .57852 L F
.844 .665 .66 r
.61744 .43012 m .61703 .43328 L .61921 .42964 L F
.817 .627 .645 r
.61921 .42964 m .62045 .43374 L .62135 .43208 L F
.61921 .42964 m .61703 .43328 L .62045 .43374 L F
.673 .517 .665 r
.61921 .42964 m .6232 .43056 L .62335 .42845 L F
.675 .512 .657 r
.61921 .42964 m .62135 .43208 L .6232 .43056 L F
.097 0 0 r
.53169 .51167 m .53363 .5117 L .53476 .50964 L F
.127 0 0 r
.53579 .5105 m .53476 .50964 L .53363 .5117 L F
.53579 .5105 m .53714 .50892 L .53476 .50964 L F
.728 .667 .79 r
.17356 .65058 m .17355 .64732 L .17147 .65026 L F
.757 .695 .792 r
.47777 .57552 m .48002 .57522 L .47902 .57172 L F
.719 .486 .572 r
.47622 .57778 m .48002 .57522 L .47777 .57552 L F
.47622 .57778 m .48013 .57782 L .48002 .57522 L F
.73 .679 .801 r
.47902 .57172 m .48002 .57522 L .48288 .57313 L F
.73 .678 .8 r
.48288 .57313 m .48002 .57522 L .4827 .574 L F
.423 .172 .427 r
.48013 .57782 m .4827 .574 L .48002 .57522 L F
.554 .196 .315 r
.7804 .40649 m .78367 .40432 L .78091 .40375 L F
.7804 .40649 m .78299 .40665 L .78367 .40432 L F
0 0 .281 r
.78498 .40079 m .78367 .40432 L .78621 .40391 L F
.624 .264 .338 r
.78367 .40432 m .78642 .40579 L .78621 .40391 L F
.78367 .40432 m .78299 .40665 L .78642 .40579 L F
.905 .872 .794 r
.77353 .39361 m .77438 .39618 L .77595 .39211 L F
0 0 .554 r
.77535 .39754 m .77438 .39618 L .77353 .39361 L F
0 0 .537 r
.51034 .58248 m .50955 .58192 L .50903 .58034 L F
.51034 .58248 m .51128 .58387 L .50955 .58192 L F
.952 .947 .643 r
.76394 .40295 m .76479 .40191 L .76334 .40258 L F
.715 .957 .948 r
.76479 .40191 m .7658 .39989 L .76334 .40258 L F
.99 .878 .616 r
.7602 .41554 m .76085 .41355 L .75997 .41235 L F
.947 .823 .689 r
.5989 .50897 m .59992 .50652 L .59844 .50536 L F
.384 .122 .389 r
.25217 .63227 m .25157 .6347 L .24945 .63527 L F
.391 .103 .351 r
.25435 .6318 m .25157 .6347 L .25217 .63227 L F
.793 .637 .688 r
.58054 .49435 m .57878 .49712 L .57967 .49496 L F
.707 .52 .634 r
.58036 .49672 m .57878 .49712 L .58054 .49435 L F
.444 .356 .662 r
.28872 .5593 m .28894 .56319 L .2871 .56342 L F
.438 .322 .624 r
.28894 .56319 m .28935 .56534 L .2871 .56342 L F
.705 .694 .837 r
.54661 .59525 m .54452 .59674 L .54287 .59352 L F
.754 .882 .937 r
.7464 .41719 m .74177 .41833 L .74552 .41606 L F
.579 .294 .448 r
.44001 .60795 m .44246 .60812 L .44377 .60514 L F
.74 .472 .524 r
.44377 .60514 m .44617 .60794 L .44623 .6054 L F
.44377 .60514 m .44246 .60812 L .44617 .60794 L F
.872 .848 .817 r
.76998 .3921 m .77077 .39214 L .76969 .3935 L F
.77062 .38903 m .76969 .3935 L .76773 .39135 L F
0 0 .244 r
.76969 .3935 m .7706 .39335 L .76773 .39135 L F
.624 .085 0 r
.76709 .39251 m .76738 .39198 L .7706 .39335 L F
.76738 .39198 m .76773 .39135 L .76872 .39204 L F
.76738 .39198 m .76872 .39204 L .7706 .39335 L F
.872 .848 .817 r
.77062 .38903 m .77207 .39049 L .77077 .39214 L F
.77062 .38903 m .77077 .39214 L .76998 .3921 L F
.882 .913 .843 r
.77207 .38783 m .77207 .39049 L .77062 .38903 L F
.6 .371 .541 r
.44617 .60794 m .44897 .60523 L .44623 .6054 L F
.364 .049 .291 r
.55779 .50023 m .55669 .50275 L .55482 .50294 L F
.633 .321 .425 r
.56026 .50232 m .55779 .50023 L .56022 .49987 L F
.56026 .50232 m .55669 .50275 L .55779 .50023 L F
.13 0 0 r
.17574 .54748 m .17794 .54714 L .18012 .54589 L F
.046 0 0 r
.17794 .54714 m .18231 .54544 L .18012 .54589 L F
.672 .48 .617 r
.46683 .59234 m .47019 .58978 L .46775 .59022 L F
.62 .929 .968 r
.7369 .39376 m .73448 .39485 L .736 .39302 L F
.203 .306 .747 r
.73448 .39485 m .73736 .39724 L .736 .39302 L F
.955 .797 .646 r
.41619 .65324 m .41456 .65261 L .41557 .65027 L F
.724 .242 .1 r
.41619 .65324 m .41564 .65505 L .41456 .65261 L F
.41619 .65324 m .41891 .65561 L .41564 .65505 L F
.735 .92 .955 r
.24757 .55725 m .2509 .55639 L .24973 .55719 L F
.2509 .55639 m .24742 .55729 L .24973 .55719 L F
.347 0 0 r
.2509 .55639 m .25277 .55722 L .24973 .55719 L F
.2509 .55639 m .2536 .55683 L .25277 .55722 L F
.287 0 0 r
.2509 .55639 m .25208 .55701 L .24973 .55719 L F
.403 .73 .991 r
.25254 .55698 m .25266 .5571 L .24973 .55719 L F
.25266 .5571 m .25277 .55722 L .24973 .55719 L F
.287 0 0 r
.25208 .55701 m .25241 .55718 L .24973 .55719 L F
.2509 .55639 m .2536 .55683 L .25274 .55709 L F
.71 .877 .959 r
.25441 .55633 m .253 .55709 L .25301 .55539 L F
.25561 .55569 m .25081 .55514 L .25129 .55511 L F
.25561 .55569 m .25068 .55503 L .25223 .55479 L F
.25301 .55583 m .253 .55709 L .25265 .55535 L F
.578 .13 0 r
.25305 .55595 m .25329 .55626 L .25241 .55504 L F
.71 .877 .959 r
.25561 .55569 m .25441 .55633 L .25301 .55539 L F
.653 .31 .379 r
.25428 .55197 m .25458 .55501 L .25222 .55179 L F
0 0 .507 r
.25222 .55179 m .25458 .55501 L .25268 .55185 L F
.246 .623 .958 r
.25428 .55197 m .25918 .55355 L .25563 .5514 L F
.25428 .55197 m .25563 .5514 L .25458 .55501 L F
.822 .7 .731 r
.25268 .55185 m .25458 .55501 L .25563 .5514 L F
.494 .808 1 r
.2561 .55503 m .25561 .55569 L .25223 .55479 L F
.575 .086 .055 r
.25427 .55492 m .25365 .55675 L .2561 .55503 L F
.71 .877 .959 r
.25301 .55539 m .25301 .55583 L .25265 .55535 L F
.575 .086 .055 r
.25241 .55504 m .25365 .55675 L .25427 .55492 L F
.461 .847 .982 r
.25561 .55569 m .2536 .55683 L .25277 .55722 L F
.25561 .55569 m .25581 .55627 L .2536 .55683 L F
.167 0 0 r
.2536 .55683 m .25581 .55627 L .25389 .55801 L F
.591 .928 .959 r
.2561 .55503 m .25581 .55627 L .25561 .55569 L F
.761 .695 .789 r
.2561 .55503 m .25389 .55801 L .25581 .55627 L F
.2561 .55503 m .25785 .55821 L .25389 .55801 L F
.226 .366 .796 r
.25749 .5573 m .26017 .55842 L .26043 .55603 L F
.573 .645 .883 r
.25819 .55478 m .25788 .55789 L .2561 .55503 L F
.25788 .55789 m .25785 .55821 L .25768 .5579 L F
.25788 .55789 m .25768 .5579 L .2561 .55503 L F
.311 0 0 r
.25785 .55821 m .25519 .55853 L .25389 .55801 L F
.573 .645 .883 r
.25819 .55478 m .26007 .55765 L .25785 .55821 L F
.037 0 0 r
.26007 .55765 m .25519 .55853 L .25785 .55821 L F
.25959 .55774 m .25804 .55816 L .25519 .55853 L F
.26007 .55765 m .25981 .55772 L .25959 .55774 L F
.25981 .55772 m .25804 .55816 L .25959 .55774 L F
.066 0 0 r
.25365 .55675 m .25819 .55478 L .2561 .55503 L F
.25365 .55675 m .25596 .55621 L .25819 .55478 L F
.578 .13 0 r
.25234 .55495 m .25241 .55504 L .25223 .55479 L F
.25305 .55595 m .25241 .55504 L .25234 .55495 L F
.574 .155 .209 r
.25008 .55128 m .24842 .55403 L .2461 .55196 L F
0 0 0 r
.25009 .55248 m .24842 .55403 L .25008 .55128 L F
.553 0 0 r
.2461 .55196 m .24842 .55403 L .2476 .5535 L F
.24587 .55207 m .2476 .5535 L .24559 .55222 L F
.2461 .55196 m .2476 .5535 L .24587 .55207 L F
.653 .795 .951 r
.24874 .5524 m .24842 .55403 L .25009 .55248 L F
.39 .344 .687 r
.24842 .55335 m .24989 .5554 L .24829 .55408 L F
.653 .795 .951 r
.24559 .55222 m .2476 .5535 L .24855 .55259 L F
.39 .344 .687 r
.24874 .55151 m .24855 .55259 L .24819 .55237 L F
.653 .795 .951 r
.24819 .55237 m .24855 .55259 L .24874 .5524 L F
.24559 .55222 m .24855 .55259 L .24819 .55237 L F
.2476 .5535 m .24842 .55403 L .24874 .5524 L F
.39 .344 .687 r
.24819 .55237 m .2479 .55633 L .24668 .55478 L F
.24855 .55259 m .2479 .55633 L .24819 .55237 L F
.653 .795 .951 r
.24559 .55222 m .24819 .55237 L .24874 .55151 L F
.39 .344 .687 r
.24874 .55151 m .24668 .55478 L .24631 .5543 L F
.653 .795 .951 r
.24819 .55237 m .24874 .5524 L .24874 .55151 L F
.24874 .5524 m .25009 .55248 L .24874 .55151 L F
.39 .344 .687 r
.24874 .55151 m .24926 .55326 L .24875 .55332 L F
.24874 .55151 m .24875 .55332 L .24842 .55335 L F
.24894 .55221 m .25014 .55415 L .24989 .5554 L F
.25014 .55415 m .25068 .55503 L .25038 .55517 L F
.25014 .55415 m .25038 .55517 L .24989 .5554 L F
.752 .487 .531 r
.25128 .55408 m .25068 .55503 L .2501 .55397 L F
.25063 .55354 m .2501 .55397 L .2492 .55234 L F
.129 0 0 r
.24991 .55318 m .25011 .55401 L .25223 .55479 L F
.752 .487 .531 r
.25128 .55408 m .2501 .55397 L .25063 .55354 L F
.129 0 0 r
.25268 .55185 m .25053 .55361 L .25223 .55479 L F
0 0 0 r
.25009 .55248 m .25008 .55128 L .25222 .55179 L F
0 0 .507 r
.25222 .55179 m .25268 .55185 L .25009 .55248 L F
.756 .637 .729 r
.25009 .55248 m .25268 .55185 L .24874 .55151 L F
.752 .487 .531 r
.25268 .55185 m .25128 .55408 L .24874 .55151 L F
.25128 .55408 m .2492 .55234 L .24874 .55151 L F
.129 0 0 r
.25268 .55185 m .24991 .55318 L .25053 .55361 L F
.39 .344 .687 r
.24906 .5521 m .25068 .55503 L .24894 .55221 L F
.129 0 0 r
.24991 .55318 m .24902 .55362 L .25011 .55401 L F
.064 .569 .886 r
.25011 .55401 m .25041 .55366 L .24902 .55362 L F
.25223 .55479 m .25123 .55417 L .25011 .55401 L F
.25123 .55417 m .25041 .55366 L .25011 .55401 L F
.39 .344 .687 r
.24926 .55326 m .24945 .55392 L .24842 .55335 L F
.24945 .55392 m .24989 .5554 L .24876 .55383 L F
.24945 .55392 m .24876 .55383 L .24842 .55335 L F
.129 0 0 r
.24991 .55318 m .25041 .55366 L .24902 .55362 L F
.25268 .55185 m .25118 .55304 L .24991 .55318 L F
.25118 .55304 m .25041 .55366 L .24991 .55318 L F
.39 .344 .687 r
.24874 .55151 m .24906 .5521 L .24894 .55221 L F
.24829 .55408 m .24989 .5554 L .2479 .55633 L F
.578 .13 0 r
.25305 .55595 m .25238 .555 L .25041 .55366 L F
.25238 .555 m .25234 .55495 L .25221 .55486 L F
.25238 .555 m .25221 .55486 L .25041 .55366 L F
.25234 .55495 m .25223 .55479 L .25056 .55375 L F
.25234 .55495 m .25056 .55375 L .25041 .55366 L F
.575 .086 .055 r
.25223 .55479 m .25241 .55504 L .25427 .55492 L F
.566 .441 .668 r
.25251 .5527 m .25305 .55595 L .25041 .55366 L F
.822 .7 .731 r
.25268 .55185 m .25563 .5514 L .2552 .552 L F
0 0 0 r
.25251 .5527 m .25268 .55185 L .2552 .552 L F
.732 .225 0 r
.2552 .552 m .25439 .55254 L .25251 .5527 L F
.413 .584 .911 r
.25251 .5527 m .25439 .55254 L .2535 .55102 L F
.621 .609 .817 r
.2535 .55102 m .25312 .55513 L .25251 .5527 L F
.25312 .55513 m .25305 .55595 L .25288 .55493 L F
.25312 .55513 m .25288 .55493 L .25251 .5527 L F
.71 .877 .959 r
.25265 .55535 m .253 .55709 L .25081 .55514 L F
.518 0 0 r
.25275 .55557 m .25145 .55541 L .25305 .55595 L F
.621 .609 .817 r
.2535 .55102 m .25591 .55594 L .25305 .55595 L F
.518 0 0 r
.25379 .55569 m .25308 .55617 L .25145 .55541 L F
.25591 .55594 m .25275 .55557 L .25305 .55595 L F
.25591 .55594 m .25426 .55608 L .25379 .55569 L F
.578 .13 0 r
.25305 .55595 m .25365 .55675 L .25329 .55626 L F
.576 .75 .96 r
.25305 .55595 m .25398 .55663 L .25596 .55621 L F
.526 .821 .999 r
.25398 .55663 m .25596 .55621 L .25365 .55675 L F
.576 .75 .96 r
.25398 .55663 m .25449 .55701 L .25596 .55621 L F
.526 .821 .999 r
.25591 .55594 m .25596 .55621 L .25398 .55663 L F
.576 .75 .96 r
.25305 .55595 m .25596 .55621 L .25591 .55594 L F
.526 .821 .999 r
.25591 .55594 m .25398 .55663 L .25305 .55595 L F
.25398 .55663 m .25365 .55675 L .25305 .55595 L F
.576 .75 .96 r
.25305 .55595 m .25382 .55738 L .25449 .55701 L F
.518 0 0 r
.25426 .55608 m .25308 .55617 L .25379 .55569 L F
.71 .877 .959 r
.25129 .55511 m .25081 .55514 L .25068 .55503 L F
.25274 .55709 m .25277 .55722 L .25264 .55708 L F
.167 0 0 r
.25274 .55709 m .25389 .55801 L .25241 .55718 L F
.2536 .55683 m .25371 .5573 L .25274 .55709 L F
.71 .877 .959 r
.25293 .55713 m .25277 .55722 L .25274 .55709 L F
.167 0 0 r
.25371 .5573 m .25389 .55801 L .25274 .55709 L F
.71 .877 .959 r
.253 .55709 m .25293 .55713 L .25274 .55709 L F
.253 .55709 m .25264 .55708 L .25068 .55503 L F
.287 0 0 r
.2527 .55708 m .25274 .55709 L .25271 .55709 L F
.2509 .55639 m .25274 .55709 L .2527 .55708 L F
.25208 .55701 m .25271 .55709 L .25241 .55718 L F
.2509 .55639 m .25271 .55709 L .25208 .55701 L F
.403 .73 .991 r
.25068 .55503 m .25254 .55698 L .25208 .55701 L F
.24993 .55675 m .25208 .55701 L .24973 .55719 L F
.25068 .55503 m .25208 .55701 L .24993 .55675 L F
.735 .92 .955 r
.24742 .55729 m .24757 .55725 L .24973 .55719 L F
.766 .576 .64 r
.69565 .4162 m .69185 .41857 L .69287 .41639 L F
.634 .579 .775 r
.41268 .61668 m .41201 .62043 L .41043 .61684 L F
.41268 .61668 m .4145 .62068 L .41201 .62043 L F
.622 .279 .367 r
.41201 .62043 m .41424 .62241 L .4145 .62068 L F
.631 .439 .604 r
.59066 .46707 m .59419 .46686 L .59308 .46419 L F
.67 .52 .672 r
.59308 .46419 m .59663 .46418 L .59659 .46161 L F
.637 .417 .567 r
.59419 .46686 m .59663 .46418 L .59308 .46419 L F
.25 0 0 r
.44284 .62371 m .43901 .62493 L .44038 .6229 L F
.44284 .62371 m .4415 .62485 L .43901 .62493 L F
.2 .082 .485 r
.44511 .61974 m .44284 .62371 L .44268 .62014 L F
.648 .577 .761 r
.44635 .62292 m .45007 .62588 L .44917 .62108 L F
.559 .344 .544 r
.44748 .62126 m .44744 .62318 L .44625 .62288 L F
.2 .082 .485 r
.44511 .61974 m .44602 .62197 L .44284 .62371 L F
.44602 .62197 m .44622 .62246 L .44615 .62249 L F
.44602 .62197 m .44615 .62249 L .44284 .62371 L F
.44622 .62246 m .44623 .62256 L .44284 .62371 L F
.468 .818 .539 r
.44434 .6224 m .44284 .62371 L .44623 .62256 L F
.459 .206 .442 r
.44748 .62126 m .44622 .62246 L .44511 .61974 L F
.559 .344 .544 r
.44617 .62173 m .44622 .62246 L .44434 .6224 L F
.44622 .62246 m .44623 .62256 L .44613 .62256 L F
.44622 .62246 m .44613 .62256 L .44434 .6224 L F
.44748 .62126 m .44625 .62288 L .44617 .62173 L F
.459 .206 .442 r
.44748 .62126 m .44626 .62255 L .44622 .62246 L F
.468 .818 .539 r
.44434 .6224 m .44623 .62256 L .44626 .62255 L F
.559 .344 .544 r
.44623 .62256 m .44625 .62288 L .44434 .6224 L F
.486 .269 .509 r
.44657 .6265 m .44434 .6224 L .44625 .62288 L F
.648 .577 .761 r
.44635 .62292 m .44773 .62662 L .45007 .62588 L F
.486 .269 .509 r
.44687 .62534 m .44625 .62288 L .44744 .62318 L F
.44657 .6265 m .44625 .62288 L .44687 .62534 L F
.2 .082 .485 r
.44622 .62246 m .44626 .62255 L .44623 .62256 L F
.468 .818 .539 r
.44434 .6224 m .4415 .62485 L .44284 .62371 L F
.136 .378 .833 r
.51527 .60654 m .51584 .6048 L .51295 .60575 L F
.51527 .60654 m .51784 .60804 L .51584 .6048 L F
.991 .849 .604 r
.76686 .4181 m .76783 .41929 L .76722 .42134 L F
.989 .871 .523 r
.76778 .41594 m .76783 .41929 L .76686 .4181 L F
.735 .587 .69 r
.41482 .61406 m .41844 .6179 L .41268 .61668 L F
.41572 .61297 m .41698 .61525 L .41482 .61406 L F
.392 .335 .674 r
.41775 .61693 m .41822 .61593 L .42053 .61724 L F
.41822 .61593 m .41917 .61389 L .4205 .61718 L F
.41822 .61593 m .4205 .61718 L .42053 .61724 L F
.19 0 0 r
.42053 .61724 m .41844 .6179 L .41775 .61693 L F
.392 .335 .674 r
.41775 .61693 m .41844 .6179 L .41917 .61389 L F
.735 .587 .69 r
.41698 .61525 m .41844 .6179 L .41482 .61406 L F
.351 .234 .577 r
.56804 .56038 m .57029 .56201 L .56999 .55954 L F
.56804 .56038 m .56774 .56365 L .57029 .56201 L F
.09 .464 .889 r
.76692 .43634 m .7675 .43557 L .76541 .4352 L F
.76692 .43634 m .76844 .43697 L .7675 .43557 L F
.608 .575 .792 r
.66076 .44504 m .66164 .44884 L .65922 .4498 L F
.642 .735 .917 r
.65922 .4498 m .66067 .44681 L .65837 .449 L F
.65922 .4498 m .66164 .44884 L .66067 .44681 L F
.155 .619 .93 r
.65922 .4498 m .66271 .45071 L .66164 .44884 L F
.779 .685 .759 r
.43217 .572 m .43339 .57524 L .43016 .57481 L F
.717 .288 .23 r
.43339 .57524 m .43217 .57708 L .43016 .57481 L F
.195 0 0 r
.43517 .57504 m .43339 .57524 L .43573 .57411 L F
.63 .585 .785 r
.4318 .57272 m .43528 .57497 L .43403 .57051 L F
.43528 .57497 m .43542 .57506 L .43538 .57492 L F
.417 .468 .806 r
.43538 .57491 m .43533 .56985 L .43403 .57051 L F
.43542 .57506 m .43542 .5749 L .43538 .57491 L F
.43542 .5749 m .43533 .56985 L .43538 .57491 L F
.538 .406 .649 r
.43528 .57497 m .43434 .57639 L .43542 .57506 L F
.073 0 0 r
.43525 .575 m .43434 .57639 L .43517 .57504 L F
.195 0 0 r
.43434 .57639 m .43384 .57579 L .43517 .57504 L F
.43384 .57579 m .43339 .57524 L .43517 .57504 L F
.538 .406 .649 r
.4318 .57272 m .43434 .57639 L .43528 .57497 L F
.073 0 0 r
.43575 .57481 m .43434 .57639 L .43525 .575 L F
0 0 0 r
.43542 .57506 m .43434 .57639 L .43718 .57426 L F
.073 0 0 r
.43718 .57426 m .4368 .57454 L .43575 .57481 L F
.4368 .57454 m .43434 .57639 L .43575 .57481 L F
.43652 .57419 m .43536 .57492 L .43573 .57411 L F
.43536 .57492 m .43521 .57497 L .43573 .57411 L F
.63 .585 .785 r
.43528 .57497 m .43538 .57492 L .43538 .57491 L F
.43528 .57497 m .43538 .57491 L .43528 .57497 L F
.073 0 0 r
.43718 .57426 m .43517 .57504 L .43652 .57419 L F
.43718 .57426 m .43573 .57411 L .43823 .57423 L F
.417 .468 .806 r
.43542 .5749 m .43718 .57426 L .43533 .56985 L F
.43542 .57506 m .43718 .57426 L .43542 .5749 L F
.073 0 0 r
.43536 .57492 m .43517 .57504 L .43521 .57497 L F
.63 .585 .785 r
.43528 .57497 m .43538 .57491 L .43403 .57051 L F
.983 .711 .428 r
.4335 .57742 m .43217 .57708 L .43339 .57524 L F
.195 0 0 r
.43434 .57639 m .43217 .57708 L .43339 .57524 L F
.632 .84 .98 r
.18453 .62627 m .18237 .62708 L .18047 .62606 L F
.75 .507 .565 r
.6819 .41383 m .68545 .41628 L .6821 .41543 L F
.287 .441 .841 r
.47571 .57415 m .47271 .57187 L .47651 .57217 L F
.757 .695 .792 r
.47777 .57552 m .47902 .57172 L .47651 .57217 L F
.599 .305 .442 r
.47902 .57172 m .47571 .57415 L .47651 .57217 L F
.406 .164 .431 r
.27653 .61 m .27497 .60784 L .27678 .60752 L F
.27653 .61 m .27451 .61062 L .27497 .60784 L F
.761 .779 .868 r
.42546 .58439 m .42244 .58658 L .42623 .58714 L F
.973 .83 .641 r
.64769 .41763 m .64956 .41664 L .64811 .41524 L F
.64769 .41763 m .64879 .41883 L .64956 .41664 L F
.67 .965 .93 r
.70333 .42732 m .70415 .42777 L .70725 .42583 L F
.066 0 0 r
.4383 .634 m .44178 .63333 L .4429 .63241 L F
.601 .634 .856 r
.17031 .64653 m .17122 .64778 L .17355 .64732 L F
.577 .455 .677 r
.17122 .64778 m .17147 .65026 L .17355 .64732 L F
.716 .556 .672 r
.59659 .46161 m .59663 .46418 L .59913 .46136 L F
.674 .495 .635 r
.59913 .46136 m .59663 .46418 L .59922 .464 L F
.716 .571 .69 r
.59922 .464 m .60165 .46092 L .59913 .46136 L F
.799 .998 .847 r
.53861 .51795 m .53833 .51722 L .53604 .51922 L F
.78 .696 .77 r
.72119 .40701 m .72259 .4106 L .71899 .41001 L F
.738 .675 .79 r
.72481 .40941 m .72259 .4106 L .72119 .40701 L F
.85 .886 .865 r
.66623 .43943 m .66483 .44304 L .66342 .44017 L F
.574 .539 .778 r
.66402 .44346 m .66623 .43943 L .66342 .44017 L F
.66402 .44346 m .66648 .44273 L .66623 .43943 L F
.431 .755 .995 r
.28136 .54764 m .28075 .54903 L .27934 .54713 L F
.28136 .54764 m .28296 .54874 L .28075 .54903 L F
.277 .585 .944 r
.73642 .40546 m .73886 .40592 L .73752 .40717 L F
.086 .008 .462 r
.73939 .4078 m .73752 .40717 L .73886 .40592 L F
.73939 .4078 m .73774 .40962 L .73752 .40717 L F
.734 .6 .707 r
.60165 .46092 m .60524 .46124 L .60533 .4587 L F
.983 .872 .646 r
.76886 .41023 m .76705 .41177 L .76843 .40919 L F
.76886 .41023 m .76799 .41314 L .76705 .41177 L F
.97 .919 .587 r
.76993 .40462 m .76886 .41023 L .76843 .40919 L F
.386 0 .175 r
.25898 .57113 m .2624 .56884 L .26031 .56955 L F
.736 .581 .681 r
.60165 .46092 m .60286 .46422 L .60524 .46124 L F
.833 .569 .539 r
.5214 .54104 m .52639 .54108 L .52387 .53864 L F
0 0 0 r
.52639 .54108 m .52741 .53715 L .52387 .53864 L F
.20934 .53947 m .21186 .53906 L .21305 .53872 L F
.379 0 0 r
.21186 .53906 m .21523 .53866 L .21305 .53872 L F
.262 .233 .637 r
.39146 .61114 m .39344 .61308 L .39291 .6106 L F
.39146 .61114 m .39172 .61466 L .39344 .61308 L F
.52 .064 .108 r
.24197 .6419 m .23731 .6434 L .238 .6436 L F
.24197 .6419 m .23984 .64354 L .23731 .6434 L F
.268 0 0 r
.24259 .64304 m .24197 .6419 L .24361 .64076 L F
.24259 .64304 m .23984 .64354 L .24197 .6419 L F
.802 .697 .749 r
.65677 .42467 m .66005 .42537 L .65881 .42177 L F
.465 .277 .541 r
.41976 .6466 m .41724 .64436 L .41953 .64373 L F
.41976 .6466 m .4171 .64775 L .41724 .64436 L F
.427 .556 .883 r
.4198 .64952 m .41855 .65036 L .4171 .64775 L F
.229 .168 .577 r
.4198 .64952 m .42014 .65185 L .41855 .65036 L F
.927 .546 .16 r
.42686 .64821 m .4308 .6502 L .43037 .64703 L F
.991 .739 .436 r
.77219 .43977 m .77335 .44336 L .77244 .44178 L F
.363 .432 .799 r
.77525 .4413 m .77335 .44336 L .77219 .43977 L F
.502 .65 .925 r
.77244 .44178 m .77335 .44336 L .77525 .4413 L F
0 0 .244 r
.76969 .3935 m .76936 .39548 L .7706 .39335 L F
.461 .244 .497 r
.25204 .58998 m .25429 .58967 L .25474 .58724 L F
.381 .189 .491 r
.25219 .59271 m .25429 .58967 L .25204 .58998 L F
.591 .404 .596 r
.42499 .59355 m .42494 .59644 L .42754 .59304 L F
.125 .16 .627 r
.39235 .61712 m .39279 .62116 L .39409 .6193 L F
.375 .464 .823 r
.39405 .62279 m .39409 .6193 L .39279 .62116 L F
.98 .911 .649 r
.65535 .41655 m .65441 .41867 L .65375 .41724 L F
.63 .95 .756 r
.65743 .41423 m .65535 .41655 L .65375 .41724 L F
.828 .906 .893 r
.77319 .41792 m .77426 .41914 L .77675 .41651 L F
0 .268 .775 r
.77612 .41951 m .77426 .41914 L .77319 .41792 L F
.77612 .41951 m .77728 .42182 L .77426 .41914 L F
.64 .442 .599 r
.58572 .46992 m .58814 .46991 L .5881 .46738 L F
.631 .435 .599 r
.5881 .46738 m .59073 .46952 L .59066 .46707 L F
.5881 .46738 m .58814 .46991 L .59073 .46952 L F
.575 .833 .994 r
.19587 .63243 m .19192 .63213 L .19411 .63147 L F
.678 .851 .965 r
.19622 .63023 m .19587 .63243 L .19411 .63147 L F
.19622 .63023 m .19857 .63134 L .19587 .63243 L F
.19 .171 .606 r
.39235 .61712 m .39344 .61308 L .39172 .61466 L F
.721 .818 .925 r
.67343 .446 m .67589 .44225 L .67324 .44295 L F
.67343 .446 m .67608 .44442 L .67589 .44225 L F
.645 .665 .854 r
.74844 .42893 m .75022 .4271 L .74781 .42755 L F
.74844 .42893 m .75115 .42813 L .75022 .4271 L F
.738 .675 .79 r
.72481 .40941 m .72119 .40701 L .72385 .40638 L F
.687 .733 .886 r
.72762 .40736 m .72481 .40941 L .72385 .40638 L F
.764 .38 .327 r
.2032 .7075 m .20097 .70929 L .20494 .70931 L F
.235 0 0 r
.2032 .7075 m .20331 .70878 L .20494 .70931 L F
.2032 .7075 m .20097 .70929 L .20331 .70878 L F
.234 .005 .348 r
.79369 .43971 m .79365 .44153 L .79073 .44206 L F
.089 0 .287 r
.79365 .44153 m .79087 .4448 L .79073 .44206 L F
.387 0 .177 r
.70498 .40094 m .70186 .40226 L .70485 .40142 L F
.429 .098 .3 r
.70422 .40299 m .70186 .40226 L .70159 .40369 L F
.70422 .40299 m .70485 .40142 L .70186 .40226 L F
.539 .836 .999 r
.22272 .64833 m .22447 .64937 L .22655 .64862 L F
.627 .622 .826 r
.42561 .61161 m .42861 .61166 L .4271 .60896 L F
0 .53 .842 r
.42502 .61264 m .42861 .61166 L .42561 .61161 L F
.441 .275 .56 r
.48013 .57782 m .48037 .5806 L .48242 .57968 L F
.48013 .57782 m .48242 .57968 L .48148 .57893 L F
.423 .172 .427 r
.48013 .57782 m .48148 .57893 L .4827 .574 L F
.331 .197 .543 r
.4827 .574 m .48494 .57137 L .48288 .57313 L F
.4827 .574 m .48586 .57413 L .48511 .57189 L F
.4827 .574 m .48511 .57189 L .48433 .57209 L F
.441 .257 .534 r
.48494 .57137 m .48822 .57296 L .48736 .57115 L F
.48822 .57296 m .48831 .573 L .48828 .57293 L F
.48822 .57296 m .48828 .57293 L .48736 .57115 L F
.793 .296 0 r
.48736 .57115 m .48831 .573 L .48643 .57183 L F
.808 .791 .836 r
.48643 .57183 m .48898 .57253 L .48843 .57013 L F
.48898 .57253 m .48976 .57274 L .4895 .57223 L F
.48898 .57253 m .4895 .57223 L .48843 .57013 L F
.441 .257 .534 r
.48494 .57137 m .48586 .57413 L .48831 .573 L F
.793 .296 0 r
.48624 .5716 m .48643 .57183 L .4836 .57267 L F
.48736 .57115 m .48701 .57141 L .48624 .5716 L F
.48701 .57141 m .48643 .57183 L .48624 .5716 L F
.331 .197 .543 r
.48433 .57209 m .48511 .57189 L .48494 .57137 L F
.406 .157 .421 r
.4827 .574 m .48518 .57666 L .48586 .57413 L F
.4827 .574 m .48148 .57893 L .48518 .57666 L F
.455 .289 .566 r
.28576 .58986 m .28364 .59302 L .28356 .59043 L F
.487 .513 .81 r
.14769 .56233 m .15042 .5598 L .14884 .56034 L F
0 0 .093 r
.58632 .55003 m .58501 .55149 L .58644 .54801 L F
0 0 .171 r
.58455 .55382 m .58501 .55149 L .58632 .55003 L F
.587 .944 .818 r
.49872 .59762 m .49769 .59894 L .49705 .59836 L F
.49872 .59762 m .50043 .59715 L .49769 .59894 L F
.147 0 .046 r
.15722 .55487 m .15617 .5564 L .15902 .55409 L F
.696 .56 .697 r
.28898 .57795 m .2868 .57424 L .28806 .57449 L F
.8 .643 .687 r
.69803 .41565 m .69561 .41878 L .69565 .4162 L F
.68 .534 .68 r
.7015 .4138 m .7018 .41639 L .69803 .41565 L F
.499 0 0 r
.50845 .55204 m .50856 .55222 L .50713 .55088 L F
.50845 .55204 m .51026 .55368 L .50856 .55222 L F
.682 .65 .812 r
.17355 .64732 m .17782 .65 L .17585 .64678 L F
.524 .61 .88 r
.17585 .64678 m .17782 .65 L .1799 .64957 L F
.544 .471 .724 r
.43605 .58938 m .43844 .5863 L .43506 .58677 L F
.43605 .58938 m .43879 .58895 L .43844 .5863 L F
.809 .689 .733 r
.61703 .43328 m .61831 .4368 L .62045 .43374 L F
.792 .621 .668 r
.21338 .69902 m .21413 .70142 L .21024 .70081 L F
.583 .503 .729 r
.21457 .69892 m .21338 .69902 L .21526 .69773 L F
.21457 .69892 m .21413 .70142 L .21338 .69902 L F
.614 .328 .46 r
.44553 .55703 m .44767 .55949 L .44793 .55725 L F
.44553 .55703 m .44438 .5598 L .44767 .55949 L F
.341 .111 .413 r
.40385 .59639 m .40588 .59589 L .40626 .59344 L F
.043 0 .347 r
.40385 .59639 m .4049 .59763 L .40588 .59589 L F
.40385 .59639 m .40371 .59881 L .4049 .59763 L F
.266 .554 .929 r
.26798 .54249 m .26703 .54359 L .26539 .54218 L F
.26798 .54249 m .26939 .54426 L .26703 .54359 L F
.428 .15 .387 r
.39843 .60232 m .40073 .60178 L .40127 .59964 L F
.462 .22 .46 r
.40073 .60178 m .40371 .59881 L .40127 .59964 L F
0 0 0 r
.23603 .55477 m .23493 .55732 L .23631 .55581 L F
.23603 .55477 m .23631 .55581 L .23406 .55335 L F
.573 .154 .208 r
.22193 .5518 m .22375 .55326 L .22133 .55309 L F
.576 0 0 r
.22519 .55364 m .22375 .55326 L .2242 .55308 L F
.516 .889 .97 r
.22599 .55245 m .22375 .55326 L .22519 .55364 L F
0 0 0 r
.22327 .55345 m .22375 .55326 L .22599 .55245 L F
.22197 .55392 m .22375 .55326 L .22327 .55345 L F
.576 0 0 r
.2242 .55308 m .22375 .55326 L .22193 .5518 L F
.983 .711 .426 r
.54247 .58067 m .54385 .58356 L .54433 .58139 L F
.572 .484 .716 r
.79662 .40951 m .79372 .40752 L .79649 .40676 L F
.79662 .40951 m .79423 .41037 L .79372 .40752 L F
.475 .164 .359 r
.43856 .62873 m .43558 .63157 L .43553 .62936 L F
.43856 .62873 m .4382 .63126 L .43558 .63157 L F
.32 .478 .86 r
.43732 .62679 m .44097 .62861 L .43856 .62873 L F
.253 0 .273 r
.44097 .62861 m .4382 .63126 L .43856 .62873 L F
.923 .549 .289 r
.7807 .44959 m .77945 .44942 L .77815 .44731 L F
.888 .953 .842 r
.7807 .44959 m .77945 .44942 L .77968 .44912 L F
.809 .328 0 r
.7807 .44959 m .77968 .44912 L .77815 .44731 L F
.835 .401 0 r
.77785 .44786 m .77945 .44942 L .77815 .44731 L F
.691 .223 0 r
.77866 .44824 m .7783 .44785 L .77767 .44688 L F
.77815 .44731 m .77919 .44881 L .77866 .44824 L F
.809 .328 0 r
.77968 .44912 m .77919 .44881 L .77815 .44731 L F
.869 .891 .847 r
.78257 .4453 m .77816 .4477 L .78163 .44434 L F
.77816 .4477 m .77785 .44786 L .7781 .44763 L F
.78257 .4453 m .77968 .44912 L .77912 .44873 L F
.77816 .4477 m .77912 .44873 L .77785 .44786 L F
.691 .223 0 r
.77861 .44814 m .77866 .44824 L .77854 .44808 L F
.77861 .44814 m .77854 .44808 L .77767 .44688 L F
.869 .891 .847 r
.78257 .4453 m .77912 .44873 L .77816 .4477 L F
.835 .401 0 r
.77785 .44786 m .77815 .44731 L .77767 .44688 L F
.691 .225 0 r
.77767 .44688 m .77828 .44781 L .77816 .4477 L F
.691 .223 0 r
.77815 .44731 m .77861 .44814 L .77767 .44688 L F
.836 .86 .862 r
.78163 .44434 m .7781 .44763 L .77714 .4461 L F
.7781 .44763 m .77785 .44786 L .77748 .44694 L F
.691 .225 0 r
.77793 .44745 m .77816 .4477 L .7781 .44763 L F
.77767 .44688 m .77816 .4477 L .77785 .44736 L F
.805 .492 0 r
.77714 .4461 m .77785 .44786 L .77767 .44688 L F
.691 .225 0 r
.77767 .44688 m .77785 .44735 L .77714 .4461 L F
.836 .86 .862 r
.77785 .44735 m .77748 .44694 L .77714 .4461 L F
.691 .225 0 r
.77785 .44735 m .77813 .44808 L .77714 .4461 L F
.836 .86 .862 r
.7781 .44763 m .77785 .44735 L .77714 .4461 L F
.691 .225 0 r
.77785 .44736 m .77793 .44745 L .77787 .4474 L F
.77793 .44745 m .7781 .44763 L .77787 .4474 L F
.869 .891 .847 r
.77968 .44912 m .77816 .44816 L .77785 .44786 L F
.691 .225 0 r
.77787 .4474 m .7792 .44923 L .77813 .44808 L F
.77828 .44781 m .7792 .44923 L .77787 .4474 L F
.869 .891 .847 r
.77816 .4477 m .77816 .4477 L .7781 .44763 L F
.77816 .4477 m .7781 .44763 L .7781 .44763 L F
.77816 .4477 m .7781 .44763 L .78163 .44434 L F
.77917 .4488 m .77945 .44942 L .77816 .44816 L F
.691 .223 0 r
.77866 .44824 m .7792 .44923 L .7783 .44785 L F
.869 .891 .847 r
.77919 .44881 m .7792 .44883 L .77917 .4488 L F
.7792 .44883 m .77945 .44942 L .77917 .4488 L F
.77968 .44912 m .77959 .44924 L .77919 .44881 L F
.77959 .44924 m .77945 .44942 L .77919 .44881 L F
.691 .223 0 r
.77866 .44824 m .78017 .45022 L .7792 .44923 L F
.77919 .44881 m .78017 .45022 L .77866 .44824 L F
.809 .328 0 r
.77968 .44912 m .77928 .44893 L .77919 .44881 L F
.888 .953 .842 r
.7807 .44959 m .77968 .44912 L .78257 .4453 L F
.809 .328 0 r
.7807 .44959 m .78017 .45022 L .77928 .44893 L F
.524 0 0 r
.7807 .44959 m .78358 .45109 L .78017 .45022 L F
.607 .135 0 r
.4801 .59381 m .48113 .59505 L .48148 .5956 L F
.456 .224 .473 r
.48169 .5959 m .48222 .59668 L .48219 .59604 L F
.759 .745 .84 r
.48222 .59668 m .484 .59829 L .4823 .59822 L F
.48219 .59604 m .48251 .59644 L .48222 .59668 L F
.48251 .59644 m .484 .59829 L .48222 .59668 L F
.48219 .59604 m .4823 .59822 L .48042 .59815 L F
.456 .224 .473 r
.48222 .59668 m .48042 .59815 L .4831 .59794 L F
.759 .745 .84 r
.48169 .5959 m .48042 .59815 L .48098 .59571 L F
.456 .224 .473 r
.48169 .5959 m .48042 .59815 L .48222 .59668 L F
.759 .745 .84 r
.48219 .59604 m .48042 .59815 L .48169 .5959 L F
.456 .224 .473 r
.48148 .5956 m .48042 .59815 L .48169 .5959 L F
.48222 .59668 m .4831 .59794 L .48219 .59604 L F
.759 .745 .84 r
.48219 .59604 m .48098 .59571 L .48113 .59505 L F
.456 .224 .473 r
.48148 .5956 m .48169 .5959 L .48219 .59604 L F
0 0 .118 r
.48148 .5956 m .48113 .59505 L .48042 .59815 L F
.607 .135 0 r
.4801 .59381 m .48113 .59505 L .48148 .5956 L F
.759 .745 .84 r
.48219 .59604 m .48113 .59505 L .48148 .5956 L F
.373 .193 .504 r
.24532 .60241 m .24715 .60192 L .24746 .59897 L F
.455 .278 .55 r
.24532 .60241 m .24736 .60435 L .24715 .60192 L F
.24532 .60241 m .24529 .60486 L .24736 .60435 L F
0 0 0 r
.42209 .57887 m .42107 .58056 L .42343 .57825 L F
.041 .38 .844 r
.43843 .59992 m .43919 .59942 L .43732 .59853 L F
.43843 .59992 m .44104 .60142 L .43919 .59942 L F
.787 .551 .579 r
.56643 .49733 m .56641 .49982 L .56272 .49931 L F
.219 .352 .785 r
.55173 .58741 m .55185 .58724 L .55143 .58641 L F
.55141 .58669 m .55143 .58641 L .55035 .58428 L F
.55141 .58669 m .55035 .58428 L .55035 .58428 L F
.55185 .58724 m .55105 .58467 L .55034 .58426 L F
.927 .781 .68 r
.54906 .58491 m .55105 .58466 L .55026 .58992 L F
.55105 .58466 m .55146 .58599 L .55026 .58992 L F
.568 .032 0 r
.55146 .58599 m .55012 .58652 L .55026 .58992 L F
.927 .781 .68 r
.55105 .58467 m .5519 .58455 L .55146 .58599 L F
.57 .032 0 r
.55034 .58426 m .55105 .58467 L .5519 .58455 L F
.927 .781 .68 r
.55105 .58466 m .5519 .58455 L .55105 .58467 L F
.568 .032 0 r
.5519 .58455 m .55154 .58495 L .55146 .58599 L F
.57 .032 0 r
.55105 .58467 m .55154 .58494 L .5519 .58455 L F
.568 .032 0 r
.5519 .58455 m .55294 .58574 L .55154 .58495 L F
.57 .032 0 r
.55154 .58494 m .55294 .58574 L .5519 .58455 L F
.219 .352 .785 r
.55185 .58724 m .55294 .58574 L .55105 .58467 L F
.568 .032 0 r
.55154 .58495 m .55012 .58652 L .55146 .58599 L F
.55154 .58495 m .55294 .58574 L .55012 .58652 L F
.219 .352 .785 r
.55035 .58428 m .55035 .58428 L .55034 .58426 L F
.55173 .58741 m .55143 .58641 L .55141 .58669 L F
.802 .827 .353 r
.57921 .53226 m .5781 .53638 L .57761 .53553 L F
.96 .92 .571 r
.57761 .53553 m .5781 .53638 L .5767 .53774 L F
.794 .588 .623 r
.21413 .70142 m .20999 .70476 L .21024 .70081 L F
.242 0 .248 r
.21485 .7008 m .21457 .69892 L .21675 .69975 L F
.401 .837 .701 r
.21526 .70049 m .21485 .7008 L .21675 .69975 L F
.458 .822 .56 r
.21485 .7008 m .21414 .70134 L .21457 .69892 L F
.21485 .7008 m .21413 .70142 L .21414 .70134 L F
.803 .927 .917 r
.2103 .70224 m .20999 .70476 L .21485 .7008 L F
.2103 .70224 m .21485 .7008 L .21256 .70182 L F
.401 .837 .701 r
.21256 .70182 m .21485 .7008 L .21526 .70049 L F
.458 .822 .56 r
.21485 .7008 m .20999 .70476 L .21413 .70142 L F
.189 0 0 r
.23229 .62218 m .2362 .61996 L .23382 .62062 L F
.477 .284 .539 r
.23382 .62062 m .2362 .61996 L .2364 .61717 L F
.546 .432 .675 r
.79729 .41289 m .79423 .41037 L .79662 .40951 L F
.79729 .41289 m .79441 .41351 L .79423 .41037 L F
.941 .703 .231 r
.66011 .4151 m .66072 .41634 L .66028 .41357 L F
.809 .748 .228 r
.6603 .41748 m .66072 .41634 L .66011 .4151 L F
.6603 .41748 m .66027 .41807 L .66072 .41634 L F
.724 .624 .745 r
.66028 .41357 m .66072 .41634 L .66372 .4133 L F
.843 .985 .704 r
.50498 .57354 m .50592 .57232 L .50376 .57232 L F
.587 .467 .684 r
.43558 .63157 m .43286 .62943 L .43553 .62936 L F
.43558 .63157 m .43311 .63211 L .43286 .62943 L F
.825 .388 0 r
.5122 .55451 m .51207 .55541 L .51026 .55368 L F
.5122 .55451 m .51319 .5565 L .51207 .55541 L F
.285 0 .131 r
.16483 .57045 m .16228 .57137 L .16305 .56986 L F
.355 .548 .904 r
.79244 .43364 m .79458 .43218 L .79174 .43171 L F
0 0 0 r
.79256 .43356 m .79458 .43218 L .79244 .43364 L F
.172 .081 .503 r
.43223 .56891 m .43403 .57051 L .43398 .56802 L F
.43223 .56891 m .43217 .572 L .43403 .57051 L F
.393 .436 .787 r
.76616 .38416 m .76399 .38631 L .76285 .38262 L F
.382 .419 .775 r
.76616 .38416 m .76694 .38797 L .76399 .38631 L F
.4 .1 .336 r
.25092 .63728 m .24945 .63527 L .25157 .6347 L F
.25092 .63728 m .24864 .63787 L .24945 .63527 L F
.807 .954 .913 r
.4365 .56528 m .43793 .5622 L .43793 .56231 L F
.4365 .56528 m .43488 .56463 L .43793 .5622 L F
.839 .826 .348 r
.76869 .3966 m .76936 .39548 L .76855 .39793 L F
.614 .794 .362 r
.7706 .39335 m .76936 .39548 L .76869 .3966 L F
0 0 .559 r
.51558 .59279 m .517 .59512 L .51648 .59636 L F
0 0 .02 r
.5736 .54815 m .57406 .54744 L .57511 .54409 L F
0 0 .169 r
.5736 .54815 m .57382 .55001 L .57406 .54744 L F
.856 .917 .872 r
.68852 .42587 m .68493 .42752 L .68745 .42464 L F
.783 .776 .847 r
.68978 .42124 m .68852 .42587 L .68745 .42464 L F
.68978 .42124 m .69028 .42428 L .68852 .42587 L F
.867 .987 .713 r
.44392 .65276 m .44574 .6494 L .44525 .65155 L F
.44392 .65276 m .44297 .65345 L .44574 .6494 L F
.544 .061 .06 r
.44527 .6534 m .44392 .65276 L .44525 .65155 L F
.4448 .65399 m .44392 .65276 L .44527 .6534 L F
.44528 .65467 m .44297 .65345 L .44392 .65276 L F
.552 .378 .599 r
.44572 .65283 m .44627 .65213 L .44588 .65014 L F
.44573 .65095 m .44588 .65014 L .44574 .6494 L F
.44572 .65283 m .44588 .65014 L .44573 .65095 L F
.486 .206 .415 r
.44528 .65467 m .44638 .65268 L .44536 .65291 L F
0 0 .19 r
.44535 .65319 m .44528 .65467 L .44527 .6534 L F
.544 .061 .06 r
.44528 .65467 m .4448 .65399 L .44527 .6534 L F
.486 .206 .415 r
.44528 .65467 m .44536 .65291 L .44297 .65345 L F
0 0 .19 r
.44608 .65129 m .44528 .65467 L .44535 .65319 L F
.44564 .65143 m .44527 .6534 L .44525 .65155 L F
.552 .378 .599 r
.44557 .65286 m .44572 .65283 L .44574 .6494 L F
0 0 .19 r
.44608 .65129 m .44527 .6534 L .44564 .65143 L F
0 0 .279 r
.44608 .65129 m .44564 .65143 L .44574 .6494 L F
.44564 .65143 m .44525 .65155 L .44574 .6494 L F
.552 .378 .599 r
.44297 .65345 m .44557 .65286 L .44574 .6494 L F
.44572 .65283 m .44638 .65268 L .44627 .65213 L F
0 0 .045 r
.2039 .69825 m .20151 .70165 L .20222 .70018 L F
.462 .715 .978 r
.20151 .70165 m .20356 .70159 L .20222 .70018 L F
.354 .417 .788 r
.54014 .57097 m .53836 .57291 L .53762 .56944 L F
.028 .059 .557 r
.54014 .57097 m .53941 .57491 L .53836 .57291 L F
.315 .03 .31 r
.5439 .51435 m .54197 .51517 L .54466 .5124 L F
0 0 0 r
.54675 .51149 m .5439 .51435 L .54466 .5124 L F
.197 0 .078 r
.52872 .51466 m .53086 .51377 L .53169 .51167 L F
.107 0 .042 r
.53086 .51377 m .53363 .5117 L .53169 .51167 L F
0 0 0 r
.41939 .58172 m .41836 .58319 L .42107 .58056 L F
.378 .83 .929 r
.20184 .65098 m .20595 .65064 L .2042 .65038 L F
.306 .786 .915 r
.2042 .65038 m .20595 .65064 L .2081 .65025 L F
.194 0 .193 r
.46263 .59369 m .46183 .5955 L .46439 .59284 L F
.495 .557 .848 r
.73499 .37284 m .73279 .375 L .73661 .37437 L F
.124 0 0 r
.47231 .55881 m .47486 .55841 L .47626 .55729 L F
.637 .186 .164 r
.47486 .55841 m .47836 .55759 L .47626 .55729 L F
.516 .889 .97 r
.22599 .55245 m .22519 .55364 L .22809 .55266 L F
.853 .873 .854 r
.19506 .72709 m .19642 .72656 L .19458 .72708 L F
.97 .73 .299 r
.19699 .72733 m .19739 .72787 L .19701 .72522 L F
.19699 .72786 m .19739 .72787 L .19699 .72733 L F
.19699 .72786 m .19701 .72522 L .19977 .72528 L F
.853 .873 .854 r
.19642 .72656 m .19977 .72528 L .19635 .72647 L F
.19642 .72656 m .19635 .72647 L .19458 .72708 L F
.97 .73 .299 r
.19699 .72786 m .19742 .72811 L .19739 .72787 L F
.742 .614 .716 r
.61228 .437 m .61565 .43985 L .61469 .43645 L F
.61228 .437 m .61378 .44077 L .61565 .43985 L F
.724 .631 .754 r
.61469 .43645 m .61565 .43985 L .61831 .4368 L F
.629 .647 .849 r
.42894 .59921 m .42494 .59644 L .42731 .59589 L F
.603 .415 .601 r
.42645 .60229 m .42923 .60226 L .42894 .59921 L F
.42894 .59921 m .42923 .60226 L .42645 .60229 L F
0 .197 .726 r
.42902 .59712 m .42894 .59921 L .42731 .59589 L F
.506 .569 .854 r
.42902 .59712 m .42923 .60226 L .42894 .59921 L F
.603 .415 .601 r
.42645 .60229 m .42923 .60226 L .42894 .59921 L F
.752 .593 .678 r
.58273 .49761 m .58241 .50014 L .58036 .49672 L F
.776 .847 .905 r
.46665 .57368 m .47069 .57306 L .46949 .57335 L F
.164 0 .167 r
.7179 .38964 m .71532 .39238 L .71761 .39146 L F
.461 .132 .321 r
.71761 .39146 m .72117 .38859 L .7179 .38964 L F
.93 .893 .772 r
.66882 .43727 m .66623 .43943 L .66737 .4396 L F
.803 1 .827 r
.67142 .43463 m .66882 .43727 L .66846 .43661 L F
.925 .909 .515 r
.66846 .43661 m .66882 .43727 L .66737 .4396 L F
.792 .366 .237 r
.66882 .43727 m .67108 .43988 L .66891 .43989 L F
.212 0 .077 r
.56434 .60247 m .56343 .60385 L .56124 .60478 L F
.178 0 .071 r
.56642 .60155 m .56343 .60385 L .56434 .60247 L F
.573 .753 .963 r
.73262 .41802 m .73359 .41957 L .73631 .41887 L F
.621 .491 .683 r
.70411 .41335 m .7018 .41639 L .7015 .4138 L F
0 0 .246 r
.58279 .55969 m .58235 .56194 L .58054 .56327 L F
.142 .004 .42 r
.58235 .56194 m .58018 .5655 L .58054 .56327 L F
.384 .189 .489 r
.16473 .61987 m .16409 .62522 L .16285 .62323 L F
.415 .864 .836 r
.16473 .61987 m .16568 .61915 L .16707 .61891 L F
0 0 0 r
.16473 .61987 m .16498 .62009 L .16568 .61915 L F
.16473 .61987 m .16315 .62064 L .16498 .62009 L F
.811 .975 .899 r
.68395 .43704 m .68777 .43507 L .68549 .43526 L F
.855 .972 .867 r
.68777 .43507 m .68848 .43256 L .68549 .43526 L F
.68777 .43507 m .68936 .43345 L .68848 .43256 L F
.846 .91 .505 r
.21028 .70579 m .21046 .70638 L .21055 .70571 L F
.21028 .70579 m .21046 .70638 L .21055 .70571 L F
.993 .788 .523 r
.21472 .67979 m .21431 .68227 L .21359 .68022 L F
.571 .375 .577 r
.21189 .68296 m .2139 .68518 L .21431 .68227 L F
.027 .241 .744 r
.21359 .68022 m .21431 .68227 L .21429 .68061 L F
.999 .809 .518 r
.21431 .68227 m .21328 .68366 L .21429 .68061 L F
.21328 .68366 m .21285 .68424 L .21323 .68329 L F
.21328 .68366 m .21323 .68329 L .21429 .68061 L F
0 .167 .705 r
.21369 .68639 m .2139 .68518 L .2134 .68462 L F
.21361 .68623 m .2134 .68462 L .21189 .68296 L F
.21369 .68639 m .2134 .68462 L .21361 .68623 L F
.656 .479 .633 r
.57967 .49496 m .57878 .49712 L .57855 .49696 L F
.555 .001 0 r
.46872 .55835 m .47231 .55881 L .47024 .55849 L F
.566 .351 .547 r
.53742 .57816 m .53674 .58052 L .53552 .57817 L F
.403 0 .076 r
.70485 .40142 m .70739 .40052 L .70498 .40094 L F
.895 .683 .608 r
.75158 .39524 m .75203 .39558 L .753 .39395 L F
.75158 .39524 m .751 .39746 L .74925 .39521 L F
.75158 .39524 m .74925 .39521 L .75203 .39558 L F
.6 .668 .888 r
.17892 .62537 m .17468 .62338 L .17707 .62235 L F
.404 .211 .502 r
.18082 .62306 m .17892 .62537 L .17707 .62235 L F
.18082 .62306 m .18047 .62606 L .17892 .62537 L F
.605 .793 .971 r
.789 .41461 m .79051 .41254 L .7879 .41308 L F
.789 .41461 m .79165 .4141 L .79051 .41254 L F
.569 .396 .608 r
.44671 .56901 m .445 .57272 L .44452 .56938 L F
.44671 .56901 m .44838 .57219 L .445 .57272 L F
.709 .544 .663 r
.44935 .56925 m .45094 .57001 L .44671 .56901 L F
.681 .44 .55 r
.45045 .57144 m .44671 .56901 L .45094 .57001 L F
.45045 .57144 m .44838 .57219 L .44671 .56901 L F
0 0 0 r
.54867 .50838 m .54675 .51149 L .54753 .5095 L F
.692 .865 .964 r
.16823 .62532 m .16629 .62645 L .16438 .62541 L F
.762 .748 .84 r
.4231 .61431 m .41917 .61389 L .42177 .61149 L F
.785 .699 .77 r
.4231 .61431 m .42053 .61724 L .41917 .61389 L F
.108 .35 .817 r
.42177 .61149 m .42391 .61297 L .4231 .61431 L F
.631 .963 .87 r
.4231 .61431 m .42391 .61297 L .42502 .61264 L F
0 .152 .626 r
.75697 .37261 m .75849 .37396 L .75604 .37206 L F
.232 0 0 r
.75604 .37206 m .75415 .3732 L .75697 .37261 L F
.803 .678 .725 r
.48703 .60757 m .49055 .60842 L .49057 .60531 L F
.298 .051 .362 r
.44703 .59212 m .446 .59008 L .44859 .5905 L F
.313 .591 .943 r
.27812 .54553 m .27669 .54657 L .2753 .54529 L F
.27812 .54553 m .27934 .54713 L .27669 .54657 L F
.917 .88 .784 r
.74924 .40692 m .74733 .40617 L .74907 .40354 L F
.937 .595 .353 r
.74924 .40692 m .74803 .40828 L .74733 .40617 L F
.74924 .40692 m .7497 .40941 L .74803 .40828 L F
.842 .833 .837 r
.75187 .40373 m .74924 .40692 L .74907 .40354 L F
.099 .119 .592 r
.29021 .57412 m .28898 .57795 L .28806 .57449 L F
.452 .214 .461 r
.29161 .57958 m .28898 .57795 L .29008 .57956 L F
.2913 .57939 m .29017 .57945 L .28898 .57795 L F
.29017 .57945 m .29009 .57945 L .29008 .57944 L F
.29017 .57945 m .29008 .57944 L .28898 .57795 L F
.508 .463 .742 r
.29017 .57945 m .29161 .57958 L .29008 .57956 L F
.452 .214 .461 r
.29161 .57958 m .29009 .57945 L .2913 .57939 L F
.508 .463 .742 r
.29307 .57565 m .29161 .57958 L .29017 .57945 L F
.485 .45 .743 r
.29307 .57565 m .29017 .57945 L .29021 .57412 L F
.29017 .57945 m .29008 .57956 L .29009 .57945 L F
.29017 .57945 m .29009 .57945 L .29021 .57412 L F
.452 .214 .461 r
.29161 .57958 m .29047 .57998 L .29009 .57945 L F
.099 .119 .592 r
.29009 .57945 m .29008 .57956 L .28898 .57795 L F
.452 .214 .461 r
.29047 .57998 m .28933 .58038 L .28898 .57795 L F
.099 .119 .592 r
.29021 .57412 m .29009 .57945 L .28898 .57795 L F
.633 .85 .983 r
.21718 .69425 m .21878 .69526 L .21475 .69506 L F
.637 .552 .742 r
.2181 .6966 m .21475 .69506 L .21878 .69526 L F
0 0 0 r
.21914 .69657 m .2181 .6966 L .21878 .69526 L F
.21914 .69657 m .21878 .69526 L .21718 .69425 L F
.954 .931 .735 r
.77373 .40239 m .77462 .40424 L .77423 .40231 L F
.768 .686 .772 r
.42286 .61672 m .42431 .62021 L .42665 .61716 L F
.613 .307 .427 r
.42431 .62021 m .42415 .62251 L .4266 .62234 L F
.518 .337 .575 r
.42431 .62021 m .42664 .61974 L .42665 .61716 L F
.512 .32 .557 r
.42431 .62021 m .4266 .62234 L .42664 .61974 L F
.482 .098 .236 r
.50049 .60174 m .5002 .604 L .4974 .60287 L F
.229 .749 .794 r
.43793 .56231 m .43793 .5622 L .43944 .56213 L F
.584 .163 .209 r
.43793 .5622 m .44208 .56054 L .43944 .56213 L F
.519 .214 .389 r
.4354 .62634 m .43395 .62815 L .43184 .62651 L F
0 0 0 r
.2364 .61717 m .23634 .61829 L .23516 .61644 L F
.2364 .61717 m .2362 .61996 L .23634 .61829 L F
.614 .512 .715 r
.43037 .64703 m .4321 .64383 L .43092 .6449 L F
.563 .588 .837 r
.21348 .67134 m .21732 .67424 L .21551 .67334 L F
.495 .594 .883 r
.21732 .67424 m .21817 .67119 L .21551 .67334 L F
.21732 .67424 m .21911 .6738 L .21817 .67119 L F
.549 .356 .572 r
.21732 .67424 m .2195 .67652 L .21911 .6738 L F
.21732 .67424 m .21717 .67696 L .2195 .67652 L F
.794 .334 0 r
.51567 .55777 m .51559 .55861 L .51319 .5565 L F
.51567 .55777 m .51683 .5597 L .51559 .55861 L F
.764 .776 .862 r
.73122 .40744 m .72762 .40736 L .72997 .40583 L F
.751 .797 .89 r
.73403 .4058 m .73122 .40744 L .72997 .40583 L F
.015 0 .432 r
.78749 .43948 m .78917 .43796 L .78915 .43579 L F
0 0 0 r
.78749 .43948 m .78683 .44098 L .78917 .43796 L F
.218 0 0 r
.15042 .5598 m .15256 .55924 L .15427 .55731 L F
.254 0 .073 r
.15256 .55924 m .15617 .5564 L .15427 .55731 L F
.128 .339 .804 r
.20253 .71902 m .20253 .7213 L .20227 .71902 L F
.19 0 0 r
.42053 .61724 m .41904 .61852 L .41844 .6179 L F
.654 .29 .343 r
.42286 .61672 m .41904 .61852 L .42053 .61724 L F
.715 .534 .643 r
.41528 .59323 m .41881 .59635 L .41764 .59289 L F
0 0 .397 r
.41659 .59419 m .41528 .59323 L .41764 .59289 L F
.715 .534 .643 r
.41528 .59323 m .41524 .59647 L .41881 .59635 L F
0 0 .397 r
.41659 .59419 m .41524 .59647 L .41528 .59323 L F
0 0 .555 r
.52208 .56604 m .52386 .56813 L .52334 .56707 L F
.428 .868 .803 r
.50533 .52352 m .50748 .5225 L .50935 .52209 L F
.41 .859 .797 r
.50935 .52209 m .50882 .52172 L .51152 .52088 L F
.50935 .52209 m .50748 .5225 L .50882 .52172 L F
.933 .642 .172 r
.67086 .4486 m .67163 .44955 L .67044 .44652 L F
0 0 0 r
.58644 .54801 m .58781 .5441 L .58725 .54656 L F
0 0 .391 r
.58725 .54656 m .58632 .55003 L .58644 .54801 L F
.696 .858 .96 r
.71781 .42094 m .72163 .42084 L .7203 .4197 L F
.637 .858 .983 r
.7203 .4197 m .72163 .42084 L .72451 .41956 L F
.068 0 0 r
.54197 .51517 m .54071 .51646 L .53833 .51722 L F
.289 0 .001 r
.5439 .51435 m .54071 .51646 L .54197 .51517 L F
.55 .313 .509 r
.43506 .58677 m .43844 .5863 L .43832 .58413 L F
.567 .362 .562 r
.43844 .5863 m .44077 .58369 L .43832 .58413 L F
.687 .588 .739 r
.50218 .53372 m .50492 .52987 L .50186 .53049 L F
.238 0 .195 r
.50218 .53372 m .5016 .53545 L .50497 .53314 L F
.137 .416 .861 r
.21348 .67134 m .21507 .67185 L .214 .66996 L F
0 .2 .721 r
.21348 .67134 m .21551 .67334 L .214 .66996 L F
.455 .115 .3 r
.45659 .59867 m .45822 .59913 L .45983 .59645 L F
.101 0 .082 r
.45983 .59645 m .46109 .59737 L .46183 .5955 L F
.45983 .59645 m .45822 .59913 L .46109 .59737 L F
.602 .811 .98 r
.73736 .39724 m .73852 .39871 L .74124 .39775 L F
.162 .693 .855 r
.24964 .53944 m .25113 .53921 L .25353 .53955 L F
.498 0 0 r
.25113 .53921 m .2557 .539 L .25353 .53955 L F
.804 .679 .727 r
.16217 .62312 m .16285 .62323 L .16247 .62389 L F
.762 .595 .671 r
.70912 .40982 m .70669 .41258 L .70658 .41021 L F
.186 0 .356 r
.40626 .59344 m .40746 .59475 L .40824 .59268 L F
.40626 .59344 m .40588 .59589 L .40746 .59475 L F
.66 .469 .616 r
.59073 .46952 m .59419 .46686 L .59066 .46707 L F
.716 .571 .69 r
.59922 .464 m .60286 .46422 L .60165 .46092 L F
.4 .084 .31 r
.56305 .48519 m .56578 .48443 L .56618 .48193 L F
.09 0 .217 r
.56618 .48193 m .56751 .48311 L .56859 .48166 L F
.56618 .48193 m .56578 .48443 L .56751 .48311 L F
.721 .577 .693 r
.66011 .41039 m .66028 .41357 L .66372 .4133 L F
.566 .806 .989 r
.65282 .42438 m .65428 .42238 L .65327 .42266 L F
.675 .567 .725 r
.65256 .42173 m .65255 .42543 L .65282 .42438 L F
.97 .65 .318 r
.65256 .42173 m .65282 .42438 L .65147 .42317 L F
.566 .806 .989 r
.65282 .42438 m .65327 .42266 L .65147 .42317 L F
.675 .567 .725 r
.65255 .42543 m .65255 .42632 L .65282 .42438 L F
.495 .605 .892 r
.65255 .42632 m .65429 .42707 L .65282 .42438 L F
.159 .481 .899 r
.19394 .73602 m .19353 .73724 L .19237 .73563 L F
.19237 .73563 m .19353 .73724 L .19394 .73602 L F
.825 .691 .716 r
.60378 .47262 m .60072 .46971 L .60039 .4722 L F
.60378 .47262 m .60416 .47027 L .60072 .46971 L F
.832 .655 .663 r
.60039 .4722 m .60189 .47569 L .60378 .47262 L F
.73 .679 .801 r
.47902 .57172 m .48288 .57313 L .48115 .57341 L F
.281 .781 .771 r
.4836 .57267 m .48288 .57313 L .48494 .57137 L F
.4836 .57267 m .48115 .57341 L .48288 .57313 L F
.83 .663 .675 r
.60072 .46971 m .60416 .47027 L .60288 .46677 L F
.157 0 0 r
.21523 .53866 m .21741 .53879 L .21908 .5387 L F
.069 0 0 r
.21908 .5387 m .22138 .53874 L .22133 .53877 L F
.21908 .5387 m .21741 .53879 L .22138 .53874 L F
.245 .683 .959 r
.20229 .6318 m .20188 .63265 L .20009 .63161 L F
.20229 .6318 m .20384 .63272 L .20188 .63265 L F
.781 .79 .294 r
.58296 .52083 m .58199 .52432 L .58233 .52234 L F
.752 .746 .229 r
.58233 .52234 m .58199 .52432 L .5814 .52668 L F
0 0 .208 r
.641 .42158 m .6417 .4202 L .64168 .41788 L F
.227 .519 .914 r
.641 .42158 m .64301 .42192 L .6417 .4202 L F
.918 .561 .339 r
.55889 .57821 m .56066 .57837 L .56112 .57697 L F
.55889 .57821 m .5589 .58042 L .55767 .57983 L F
.55889 .57821 m .55767 .57983 L .56066 .57837 L F
.522 .126 .23 r
.45376 .55874 m .45642 .55888 L .45436 .55754 L F
.451 .179 .409 r
.42734 .58203 m .42974 .58164 L .43087 .57829 L F
.767 .702 .79 r
.71264 .39747 m .7173 .39824 L .71489 .39368 L F
.633 .119 .006 r
.71531 .39924 m .7173 .39824 L .71264 .39747 L F
.494 .573 .864 r
.71489 .39368 m .7173 .39824 L .7188 .39726 L F
.433 .847 .677 r
.7188 .39726 m .7173 .39824 L .71531 .39924 L F
.79 .504 .504 r
.68545 .41628 m .68206 .41787 L .6821 .41543 L F
.68545 .41628 m .6859 .41858 L .68206 .41787 L F
.725 .336 .313 r
.68545 .41628 m .68844 .41884 L .6859 .41858 L F
.676 .578 .738 r
.46654 .58119 m .46937 .5821 L .46738 .58138 L F
.568 .253 .394 r
.44793 .55725 m .44767 .55949 L .45027 .55905 L F
.644 .515 .692 r
.43674 .63478 m .43311 .63211 L .43558 .63157 L F
.43674 .63478 m .43407 .63512 L .43311 .63211 L F
.65 .964 .916 r
.68936 .43345 m .69131 .43119 L .68848 .43256 L F
.68936 .43345 m .69259 .43154 L .69131 .43119 L F
.701 .419 .494 r
.57257 .49711 m .57317 .49948 L .56883 .49942 L F
.735 .44 .481 r
.57672 .49928 m .57257 .49711 L .57855 .49696 L F
.57672 .49928 m .57317 .49948 L .57257 .49711 L F
.411 .344 .672 r
.52566 .54723 m .52321 .54569 L .52561 .54434 L F
.52566 .54723 m .52385 .54816 L .52321 .54569 L F
.313 0 .183 r
.71035 .39836 m .70739 .40052 L .70975 .39942 L F
.182 0 .021 r
.71264 .39747 m .71035 .39836 L .70975 .39942 L F
.393 .158 .435 r
.26501 .62048 m .26455 .62283 L .26255 .62339 L F
.268 .049 .385 r
.26384 .62491 m .26255 .62339 L .26455 .62283 L F
.26384 .62491 m .26211 .62582 L .26255 .62339 L F
.701 .361 .397 r
.58195 .47031 m .5846 .47238 L .58572 .46992 L F
.58195 .47031 m .58215 .47228 L .5846 .47238 L F
.302 .078 .398 r
.25474 .58724 m .25651 .58658 L .25688 .58429 L F
.494 .332 .589 r
.25429 .58967 m .25651 .58658 L .25474 .58724 L F
.17 0 0 r
.18025 .56118 m .17979 .55995 L .18241 .55939 L F
.18025 .56118 m .17813 .56185 L .17979 .55995 L F
.898 .607 .486 r
.65825 .44532 m .65514 .44646 L .65671 .44408 L F
.65825 .44532 m .65837 .449 L .65514 .44646 L F
.475 .677 .953 r
.65937 .44336 m .65825 .44532 L .65671 .44408 L F
.65937 .44336 m .66076 .44504 L .65825 .44532 L F
.477 .576 .875 r
.75525 .37513 m .75697 .37261 L .75415 .3732 L F
.75525 .37513 m .75763 .37518 L .75697 .37261 L F
.998 .785 .48 r
.6589 .41182 m .66028 .41357 L .66011 .41039 L F
.966 .651 .266 r
.65897 .40903 m .66011 .41039 L .6587 .40675 L F
.04 0 0 r
.66127 .41084 m .66011 .41039 L .65897 .40903 L F
.66127 .41084 m .6589 .41182 L .66011 .41039 L F
.637 .417 .567 r
.59419 .46686 m .59672 .46661 L .59663 .46418 L F
.712 .475 .566 r
.59663 .46418 m .59922 .46657 L .59922 .464 L F
.59663 .46418 m .59672 .46661 L .59922 .46657 L F
.781 .79 .294 r
.58296 .52083 m .58233 .52234 L .58267 .52011 L F
.241 0 0 r
.73091 .37713 m .72749 .37959 L .7299 .37773 L F
0 0 .436 r
.73236 .37761 m .73112 .37962 L .73091 .37713 L F
.73236 .37761 m .73091 .37713 L .7299 .37773 L F
.089 0 0 r
.18671 .54416 m .19064 .54215 L .18841 .54214 L F
.486 .23 .452 r
.39573 .60504 m .3981 .60457 L .39843 .60232 L F
.342 .108 .408 r
.39843 .60232 m .40011 .60378 L .40073 .60178 L F
.39843 .60232 m .3981 .60457 L .40011 .60378 L F
.477 .889 .928 r
.2165 .63194 m .21453 .63274 L .21229 .63266 L F
.621 .452 .632 r
.2039 .69825 m .20636 .69798 L .20678 .69535 L F
.411 0 .044 r
.20435 .70013 m .2039 .69825 L .20222 .70018 L F
.20435 .70013 m .20636 .69798 L .2039 .69825 L F
.983 .711 .426 r
.54247 .58067 m .54244 .58315 L .54385 .58356 L F
.179 .172 .613 r
.54244 .58315 m .54141 .58672 L .54385 .58356 L F
.594 .5 .718 r
.79729 .41289 m .7952 .41595 L .79441 .41351 L F
.056 0 0 r
.78708 .4494 m .78615 .45037 L .78358 .45109 L F
.119 0 .231 r
.78873 .44792 m .78708 .4494 L .78946 .44614 L F
0 0 0 r
.78925 .44797 m .78708 .4494 L .78873 .44792 L F
.78925 .44797 m .78615 .45037 L .78708 .4494 L F
.538 .324 .536 r
.42162 .60819 m .42177 .61149 L .41919 .61073 L F
.511 .303 .534 r
.42387 .61018 m .42177 .61149 L .42162 .60819 L F
.608 .515 .723 r
.43037 .64703 m .4308 .6502 L .43173 .64781 L F
.437 .272 .559 r
.16438 .62541 m .16371 .6255 L .16247 .62389 L F
.16438 .62541 m .16371 .6255 L .16247 .62389 L F
.564 .251 .396 r
.42645 .60229 m .4287 .60411 L .42923 .60226 L F
.42923 .60226 m .4287 .60411 L .42645 .60229 L F
.401 .18 .46 r
.66394 .40098 m .66165 .40356 L .66127 .4017 L F
.66394 .40098 m .6635 .40331 L .66165 .40356 L F
.355 .047 .298 r
.6635 .40331 m .66077 .40584 L .66165 .40356 L F
.46 .284 .555 r
.26703 .61725 m .26707 .61993 L .26501 .62048 L F
.335 .108 .413 r
.26647 .62202 m .26501 .62048 L .26707 .61993 L F
.26647 .62202 m .26455 .62283 L .26501 .62048 L F
.164 .663 .912 r
.23346 .53869 m .23606 .53904 L .23734 .53952 L F
.622 .892 .988 r
.23734 .53952 m .23929 .53733 L .24091 .5391 L F
.23734 .53952 m .23606 .53904 L .23929 .53733 L F
0 0 .496 r
.4594 .57195 m .45677 .56882 L .45816 .56898 L F
.986 .851 .477 r
.53037 .58683 m .52945 .58558 L .52998 .58301 L F
.832 .577 .028 r
.53033 .58944 m .52945 .58558 L .53037 .58683 L F
.211 0 .09 r
.71761 .39146 m .71532 .39238 L .71489 .39368 L F
.666 .335 .403 r
.201 .55453 m .19902 .55681 L .19719 .55619 L F
.487 .336 .601 r
.20322 .55425 m .20283 .55649 L .201 .55453 L F
.819 .604 .612 r
.20283 .55649 m .19902 .55681 L .201 .55453 L F
.158 0 0 r
.45714 .58532 m .45587 .58646 L .45389 .58684 L F
.362 0 0 r
.45985 .58523 m .45714 .58532 L .4595 .58509 L F
.45985 .58523 m .45587 .58646 L .45714 .58532 L F
.375 .464 .823 r
.39405 .62279 m .39562 .6228 L .39409 .6193 L F
.422 .126 .355 r
.4321 .64383 m .43438 .64336 L .43506 .64089 L F
.098 0 .365 r
.43506 .64089 m .43658 .64017 L .43739 .63774 L F
.499 .196 .383 r
.43506 .64089 m .4368 .64287 L .43658 .64017 L F
.43506 .64089 m .43438 .64336 L .4368 .64287 L F
.681 .565 .717 r
.51446 .53601 m .51248 .5384 L .51314 .53686 L F
.287 .547 .921 r
.51182 .53683 m .51411 .53757 L .51248 .5384 L F
.352 .731 .987 r
.5154 .53832 m .51635 .53887 L .51295 .53846 L F
.885 .935 .845 r
.52264 .53714 m .5179 .54258 L .5214 .54104 L F
.52264 .53714 m .5214 .54104 L .52387 .53864 L F
.756 .922 .945 r
.51895 .54201 m .51886 .54165 L .52165 .53888 L F
0 0 0 r
.52029 .54023 m .51886 .54165 L .51984 .54048 L F
.51886 .54165 m .51868 .54172 L .52264 .53714 L F
.51802 .54249 m .5179 .54258 L .52264 .53714 L F
.885 .935 .845 r
.5179 .54258 m .51788 .5427 L .5214 .54104 L F
.566 .934 .804 r
.5214 .54104 m .51788 .5427 L .52229 .53994 L F
.51788 .5427 m .51796 .54263 L .52229 .53994 L F
.756 .922 .945 r
.51895 .54201 m .51796 .54263 L .51886 .54165 L F
.51796 .54263 m .51802 .54249 L .51886 .54165 L F
0 0 0 r
.51886 .54165 m .51802 .54249 L .51868 .54172 L F
.237 .32 .746 r
.51784 .54298 m .51959 .54168 L .51867 .54094 L F
.51785 .54287 m .51867 .54094 L .51823 .54058 L F
.51784 .54298 m .51867 .54094 L .51785 .54287 L F
.51788 .5427 m .51823 .54058 L .51778 .54279 L F
.885 .935 .845 r
.5179 .54258 m .51774 .54277 L .51788 .5427 L F
.756 .922 .945 r
.51796 .54263 m .51774 .54277 L .51802 .54249 L F
.933 .562 .273 r
.51959 .54168 m .51813 .54125 L .51748 .53978 L F
.332 0 .02 r
.51575 .53896 m .51684 .53945 L .51736 .53821 L F
.51399 .53978 m .51756 .53771 L .51635 .53887 L F
.51399 .53978 m .51736 .53821 L .51663 .53825 L F
0 0 0 r
.51756 .53771 m .51684 .53945 L .51889 .53665 L F
.332 0 .02 r
.51663 .53825 m .51736 .53821 L .51756 .53771 L F
.886 .989 .799 r
.51889 .53665 m .51684 .53945 L .5165 .53756 L F
.933 .562 .273 r
.51848 .5402 m .5165 .53756 L .51684 .53945 L F
.51848 .5402 m .51748 .53978 L .5165 .53756 L F
.51867 .54094 m .51848 .5402 L .51684 .53945 L F
.51933 .54147 m .51848 .5402 L .51867 .54094 L F
.51848 .5402 m .51848 .5402 L .51867 .54094 L F
.756 .922 .945 r
.52049 .54106 m .51895 .54201 L .51996 .54084 L F
.933 .562 .273 r
.51959 .54168 m .51941 .54145 L .51933 .54147 L F
.51941 .54145 m .51848 .5402 L .51933 .54147 L F
.51959 .54168 m .51748 .53978 L .51848 .5402 L F
.756 .922 .945 r
.52229 .53994 m .52049 .54106 L .52165 .53888 L F
.52049 .54106 m .51996 .54084 L .52165 .53888 L F
0 0 0 r
.52214 .53802 m .52029 .54023 L .52264 .53714 L F
.52132 .53921 m .52029 .54023 L .52214 .53802 L F
.52029 .54023 m .51984 .54048 L .52264 .53714 L F
.871 .952 .861 r
.52165 .53888 m .51984 .54011 L .52229 .53994 L F
.681 .335 .382 r
.5206 .54006 m .52444 .53931 L .52229 .53994 L F
.52081 .53994 m .52444 .53931 L .52087 .54001 L F
.881 .873 .824 r
.52165 .53888 m .52082 .54 L .51984 .54011 L F
.681 .335 .382 r
.52067 .54002 m .52087 .54001 L .5206 .54006 L F
.52082 .54 m .52087 .54001 L .52067 .54002 L F
.881 .873 .824 r
.52082 .54 m .51959 .54168 L .51984 .54011 L F
.681 .335 .382 r
.52071 .54 m .52082 .54 L .52067 .54002 L F
.889 .99 .781 r
.51967 .53994 m .52082 .54 L .52165 .53888 L F
.681 .335 .382 r
.52081 .53994 m .52087 .54001 L .52071 .54 L F
.889 .99 .781 r
.51969 .53967 m .51967 .53994 L .52165 .53888 L F
.52055 .53999 m .51959 .54168 L .52082 .54 L F
.681 .335 .382 r
.52055 .53999 m .52061 .54023 L .52081 .53994 L F
.51984 .54011 m .52081 .53994 L .5206 .54006 L F
.51984 .54011 m .5203 .54019 L .52055 .53999 L F
.5203 .54019 m .52061 .54023 L .52055 .53999 L F
.686 .157 0 r
.52342 .54151 m .5261 .54264 L .52561 .54434 L F
.566 .934 .804 r
.5214 .54104 m .52229 .53994 L .52342 .54151 L F
.686 .157 0 r
.52483 .54211 m .52549 .54313 L .5261 .54264 L F
.52342 .54151 m .52549 .54313 L .52483 .54211 L F
0 0 .346 r
.52729 .54078 m .52619 .54421 L .52549 .54313 L F
.019 .006 .498 r
.52594 .5467 m .52561 .54434 L .5261 .54264 L F
0 0 .286 r
.52549 .54313 m .52594 .5467 L .5261 .54264 L F
0 0 .346 r
.52619 .54421 m .52598 .54486 L .52549 .54313 L F
.186 .347 .793 r
.52444 .53931 m .52342 .54151 L .52229 .53994 L F
.52444 .53931 m .52549 .54313 L .52342 .54151 L F
.357 .475 .843 r
.52729 .54078 m .52549 .54313 L .52444 .53931 L F
.576 .394 .597 r
.52135 .54394 m .52494 .54089 L .5203 .54019 L F
.52002 .54059 m .5203 .54019 L .51984 .54011 L F
.52135 .54394 m .5203 .54019 L .52002 .54059 L F
.347 .4 .774 r
.51959 .54168 m .52135 .54394 L .52002 .54059 L F
.51959 .54168 m .52002 .54059 L .51984 .54011 L F
.889 .99 .781 r
.52013 .54033 m .51959 .54168 L .52055 .53999 L F
.51963 .54072 m .51959 .54168 L .52013 .54033 L F
.51967 .53994 m .51963 .54072 L .5203 .54019 L F
.52045 .53998 m .5203 .54019 L .52055 .53999 L F
.51967 .53994 m .5203 .54019 L .52045 .53998 L F
.681 .335 .382 r
.52081 .53994 m .52494 .54089 L .52444 .53931 L F
.52061 .54023 m .52494 .54089 L .52081 .53994 L F
0 0 0 r
.52165 .53888 m .52132 .53921 L .52214 .53802 L F
.51802 .54249 m .51774 .54277 L .5179 .54258 L F
.237 .32 .746 r
.51775 .54269 m .51823 .54058 L .51684 .53945 L F
.51778 .54279 m .51781 .54265 L .51775 .54269 L F
.51781 .54265 m .51823 .54058 L .51775 .54269 L F
.51784 .54298 m .51788 .5427 L .51778 .54279 L F
.566 .934 .804 r
.51788 .5427 m .51774 .54277 L .51796 .54263 L F
.237 .32 .746 r
.51771 .54308 m .51784 .54298 L .51684 .53945 L F
.332 0 .02 r
.51399 .53978 m .51684 .53945 L .51575 .53896 L F
.352 .731 .987 r
.51411 .53757 m .5154 .53832 L .51248 .5384 L F
.5154 .53832 m .51295 .53846 L .51248 .5384 L F
.598 .671 .891 r
.74781 .42755 m .74889 .42339 L .74635 .42385 L F
.74781 .42755 m .75022 .4271 L .74889 .42339 L F
.017 0 .472 r
.56774 .56365 m .56929 .56429 L .57029 .56201 L F
.56774 .56365 m .56781 .56588 L .56929 .56429 L F
.348 .425 .799 r
.74177 .41833 m .74355 .4222 L .74533 .42019 L F
.334 .404 .785 r
.74355 .4222 m .74635 .42385 L .74533 .42019 L F
.135 .552 .923 r
.48715 .55935 m .4862 .56002 L .48472 .55919 L F
.48715 .55935 m .48839 .56031 L .4862 .56002 L F
.458 .277 .548 r
.3931 .6051 m .39498 .60707 L .39573 .60504 L F
.3931 .6051 m .39281 .60792 L .39498 .60707 L F
.51 .275 .494 r
.45796 .60739 m .45553 .60983 L .45595 .60809 L F
.42 .187 .453 r
.27208 .61393 m .26963 .61664 L .26961 .61416 L F
.704 .486 .59 r
.5846 .47238 m .58814 .46991 L .58572 .46992 L F
0 0 .532 r
.5314 .59291 m .53166 .59172 L .53033 .58944 L F
0 0 .422 r
.5314 .59291 m .5327 .59417 L .53166 .59172 L F
.5314 .59291 m .53216 .59537 L .5327 .59417 L F
.995 .869 .56 r
.65461 .41047 m .65339 .41142 L .65494 .40835 L F
.65461 .41047 m .65402 .41257 L .65339 .41142 L F
0 0 .214 r
.43924 .64273 m .43843 .64379 L .43874 .64126 L F
.443 0 .047 r
.4368 .64287 m .43924 .64273 L .43874 .64126 L F
.183 .705 .873 r
.22133 .53877 m .22352 .53868 L .22524 .53893 L F
.228 .73 .903 r
.22352 .53868 m .22744 .53886 L .22524 .53893 L F
.948 .605 .203 r
.77771 .39207 m .77839 .39498 L .77705 .39331 L F
.434 .224 .494 r
.24746 .59897 m .24958 .59852 L .24949 .59607 L F
.381 .186 .487 r
.24949 .59607 m .25188 .5953 L .25219 .59271 L F
.444 .262 .538 r
.24958 .59852 m .25188 .5953 L .24949 .59607 L F
.937 .706 .563 r
.44599 .59547 m .44682 .59773 L .44411 .59605 L F
.364 .187 .502 r
.5613 .57517 m .56329 .57446 L .56348 .57187 L F
.532 .36 .594 r
.56112 .57697 m .56329 .57446 L .5613 .57517 L F
.436 .17 .409 r
.42471 .64285 m .42248 .6415 L .42505 .64033 L F
.19 .117 .538 r
.42671 .63728 m .42694 .64031 L .42505 .64033 L F
.169 0 .229 r
.42694 .64031 m .42471 .64285 L .42505 .64033 L F
.917 .937 .804 r
.51466 .52316 m .51471 .52331 L .51625 .52445 L F
.068 .461 .885 r
.51658 .52694 m .51652 .52502 L .51536 .5255 L F
.51652 .52502 m .51647 .52498 L .51536 .5255 L F
0 0 0 r
.51647 .52498 m .51487 .52626 L .51536 .5255 L F
.51652 .52495 m .5164 .52504 L .51647 .52498 L F
.5164 .52504 m .51487 .52626 L .51647 .52498 L F
.917 .937 .804 r
.51471 .52331 m .51549 .52597 L .51618 .5247 L F
.068 .461 .885 r
.51652 .52502 m .51652 .52495 L .51647 .52498 L F
.36 .362 .727 r
.51652 .52495 m .51503 .52854 L .51487 .52626 L F
.917 .937 .804 r
.51549 .52597 m .51568 .52661 L .51598 .52548 L F
.51549 .52597 m .51598 .52548 L .51618 .5247 L F
.51471 .52331 m .51618 .5247 L .51625 .52445 L F
.838 .946 .587 r
.51652 .52495 m .51503 .52854 L .51658 .52694 L F
.19 .171 .606 r
.39235 .61712 m .39341 .61676 L .39344 .61308 L F
.192 .179 .613 r
.39235 .61712 m .39409 .6193 L .39341 .61676 L F
.785 .554 .587 r
.66608 .39969 m .66988 .39793 L .66543 .39869 L F
.926 .909 .517 r
.59039 .53618 m .59121 .5319 L .59064 .53525 L F
0 0 0 r
.59004 .53834 m .59039 .53618 L .59064 .53525 L F
.666 .508 .662 r
.41844 .6179 m .4145 .62068 L .41268 .61668 L F
.41844 .6179 m .41659 .62108 L .4145 .62068 L F
0 0 0 r
.41484 .6206 m .4145 .62068 L .41659 .62108 L F
.41462 .62126 m .41424 .62241 L .4145 .62072 L F
.593 .385 .568 r
.41167 .6252 m .41424 .62241 L .41299 .6219 L F
0 0 0 r
.41484 .6206 m .41462 .62126 L .4145 .62068 L F
.41462 .62126 m .4145 .62072 L .4145 .62068 L F
.715 .955 .949 r
.41484 .6206 m .41299 .6219 L .41424 .62241 L F
.593 .385 .568 r
.41167 .6252 m .41299 .6219 L .41039 .62261 L F
0 0 0 r
.41471 .62163 m .41119 .62304 L .41299 .6219 L F
.41539 .62152 m .41474 .62175 L .41471 .62163 L F
.41474 .62175 m .41119 .62304 L .41471 .62163 L F
.762 .762 .853 r
.68978 .42124 m .69326 .42182 L .69028 .42428 L F
0 0 .369 r
.5284 .58106 m .52858 .58012 L .52757 .57745 L F
0 .015 .588 r
.5284 .58106 m .52998 .58301 L .52858 .58012 L F
.887 .457 .118 r
.67318 .40994 m .67427 .41245 L .67233 .41099 L F
.841 .453 .315 r
.67609 .41273 m .67427 .41245 L .67318 .40994 L F
.693 .467 .575 r
.45109 .59888 m .45427 .60177 L .45373 .59907 L F
.27 0 .291 r
.45427 .60177 m .45659 .59867 L .45373 .59907 L F
.642 .444 .599 r
.41919 .61073 m .41917 .61389 L .41572 .61297 L F
.529 .352 .586 r
.42177 .61149 m .41917 .61389 L .41919 .61073 L F
.838 .872 .868 r
.19327 .72249 m .19132 .7249 L .18914 .72443 L F
0 0 .372 r
.19132 .7249 m .191 .72407 L .18914 .72443 L F
.19132 .7249 m .19279 .72762 L .191 .72407 L F
.273 .13 .496 r
.57705 .57789 m .57703 .5803 L .57546 .58129 L F
.209 .02 .391 r
.57546 .58129 m .57703 .5803 L .57528 .58339 L F
.524 .85 .561 r
.45854 .57581 m .4559 .57826 L .457 .57718 L F
.586 .405 .604 r
.457 .57718 m .45989 .57436 L .45854 .57581 L F
.399 .682 .975 r
.78173 .39934 m .78288 .4008 L .78498 .40079 L F
.787 .601 .649 r
.58036 .49672 m .58241 .50014 L .57872 .49962 L F
.809 .573 .581 r
.58241 .50014 m .57886 .50198 L .57872 .49962 L F
.58241 .50014 m .58241 .50267 L .57886 .50198 L F
.387 .066 .294 r
.26009 .6266 m .25925 .62846 L .25707 .62898 L F
.279 0 .237 r
.26211 .62582 m .25925 .62846 L .26009 .6266 L F
.607 .326 .465 r
.42248 .6415 m .42202 .64353 L .41953 .64373 L F
.436 .17 .409 r
.42471 .64285 m .42202 .64353 L .42248 .6415 L F
.578 .246 .37 r
.55669 .50275 m .55434 .50449 L .55482 .50294 L F
.938 .756 .63 r
.58617 .50907 m .58398 .51101 L .58526 .5077 L F
.58617 .50907 m .58601 .51243 L .58398 .51101 L F
0 0 .019 r
.79087 .4448 m .78873 .44792 L .78946 .44614 L F
0 .116 .604 r
.51859 .56289 m .51829 .56243 L .51745 .56186 L F
.51859 .56289 m .52084 .56473 L .51829 .56243 L F
.593 .658 .883 r
.17031 .64653 m .17065 .64279 L .16911 .64324 L F
.17031 .64653 m .17227 .6466 L .17065 .64279 L F
.601 .634 .856 r
.17031 .64653 m .17355 .64732 L .17227 .6466 L F
.643 .948 .951 r
.73931 .3742 m .73621 .37496 L .73869 .37436 L F
.635 .704 .896 r
.73658 .37441 m .73869 .37436 L .73621 .37496 L F
.73777 .37264 m .73856 .37411 L .73658 .37441 L F
.65 .945 .957 r
.7386 .37411 m .73931 .3742 L .7394 .37399 L F
.126 0 0 r
.74128 .37433 m .73931 .3742 L .73869 .37436 L F
.74128 .37433 m .74165 .37393 L .73931 .3742 L F
.086 0 0 r
.73931 .3742 m .74165 .37393 L .7412 .37427 L F
.569 .664 .902 r
.74097 .37371 m .74125 .37427 L .73888 .37406 L F
.74126 .37429 m .74128 .37433 L .7412 .37427 L F
.516 0 0 r
.74091 .37449 m .7412 .37427 L .74446 .37542 L F
.7412 .37427 m .74165 .37393 L .74417 .37526 L F
.7412 .37427 m .74417 .37526 L .74446 .37542 L F
.569 .664 .902 r
.7412 .37427 m .74128 .37433 L .74098 .37429 L F
.74125 .37427 m .74126 .37429 L .7412 .37427 L F
.74125 .37427 m .74098 .37429 L .73888 .37406 L F
.086 0 0 r
.74028 .37437 m .7412 .37427 L .74091 .37449 L F
.73931 .3742 m .7412 .37427 L .74028 .37437 L F
.7394 .37397 m .74091 .37449 L .73944 .37388 L F
.73931 .3742 m .74028 .37437 L .7394 .37397 L F
.569 .664 .902 r
.73983 .37417 m .74128 .37433 L .74021 .37434 L F
.086 0 0 r
.74028 .37437 m .74091 .37449 L .7394 .37397 L F
.65 .945 .957 r
.73727 .37433 m .73931 .3742 L .73856 .37411 L F
.569 .664 .902 r
.73888 .37406 m .73983 .37417 L .73869 .37436 L F
.73983 .37417 m .74021 .37434 L .73869 .37436 L F
.74014 .37207 m .74097 .37371 L .73888 .37406 L F
.65 .945 .957 r
.73856 .37411 m .73857 .37411 L .7386 .37411 L F
.73857 .37411 m .73931 .3742 L .7386 .37411 L F
.73704 .37434 m .73727 .37433 L .73856 .37411 L F
.569 .664 .902 r
.74014 .37207 m .73888 .37406 L .73777 .37264 L F
.73888 .37406 m .73869 .37436 L .73856 .37411 L F
.73888 .37406 m .73856 .37411 L .73777 .37264 L F
.635 .704 .896 r
.73856 .37411 m .73869 .37436 L .73658 .37441 L F
.65 .945 .957 r
.73661 .37437 m .73704 .37434 L .73944 .37388 L F
.73704 .37434 m .7394 .37399 L .73944 .37388 L F
0 0 0 r
.41626 .58393 m .41714 .58445 L .41836 .58319 L F
.41626 .58393 m .41479 .58565 L .41714 .58445 L F
.752 .592 .677 r
.59922 .46657 m .60286 .46422 L .59922 .464 L F
.59922 .46657 m .60288 .46677 L .60286 .46422 L F
.128 .339 .804 r
.20253 .71902 m .20429 .72213 L .20253 .7213 L F
.181 0 0 r
.20429 .72213 m .20093 .72386 L .20253 .7213 L F
.768 .686 .772 r
.42286 .61672 m .42665 .61716 L .42572 .61815 L F
.319 .069 .37 r
.4288 .61632 m .42665 .61716 L .42912 .61416 L F
.4288 .61632 m .42912 .61416 L .42915 .61417 L F
.4288 .61632 m .42665 .61716 L .42916 .61411 L F
.42915 .61417 m .42912 .61416 L .42916 .61411 L F
0 .53 .842 r
.42502 .61264 m .42916 .61411 L .42861 .61166 L F
.42502 .61264 m .4275 .61336 L .42916 .61411 L F
.319 .069 .37 r
.4288 .61632 m .42916 .61411 L .4275 .61336 L F
.397 .26 .575 r
.42916 .61411 m .4292 .61416 L .43079 .61364 L F
.42916 .61411 m .43079 .61364 L .4308 .61362 L F
.631 .688 .885 r
.43308 .6102 m .433 .61023 L .43366 .61053 L F
.433 .61023 m .43299 .61042 L .43366 .61053 L F
.4326 .61036 m .43285 .61063 L .43366 .61053 L F
.657 .497 .655 r
.4316 .61294 m .43366 .61053 L .43285 .61063 L F
.43167 .61302 m .43366 .61053 L .4316 .61294 L F
.43125 .61249 m .43285 .61063 L .43115 .61085 L F
.43125 .61254 m .43285 .61063 L .43125 .61249 L F
.586 .438 .647 r
.43156 .6129 m .43103 .61412 L .43134 .61265 L F
.657 .497 .655 r
.43131 .61346 m .4316 .61294 L .43125 .61254 L F
.4316 .61294 m .43285 .61063 L .43125 .61254 L F
.631 .688 .885 r
.4326 .61036 m .43115 .61085 L .43285 .61063 L F
.43108 .6107 m .43115 .61085 L .4326 .61036 L F
.43257 .61033 m .4326 .61036 L .43308 .6102 L F
.43108 .6107 m .4326 .61036 L .43257 .61033 L F
.586 .438 .647 r
.43295 .60973 m .43257 .61033 L .43254 .6097 L F
.43257 .61033 m .43145 .61216 L .43236 .6101 L F
.43257 .61033 m .43236 .6101 L .43254 .6097 L F
.43295 .60973 m .43234 .61112 L .43145 .61216 L F
.43295 .60973 m .433 .61022 L .43269 .6103 L F
.631 .688 .885 r
.42993 .60839 m .43108 .6107 L .4314 .61062 L F
.42993 .60839 m .4314 .61062 L .43188 .60982 L F
.42993 .60839 m .43257 .61033 L .43179 .60946 L F
.42993 .60839 m .43179 .60946 L .43188 .60894 L F
.43043 .60816 m .43188 .60894 L .43214 .60737 L F
.42993 .60839 m .43188 .60894 L .43043 .60816 L F
.43214 .60737 m .43308 .6102 L .43224 .60732 L F
.43179 .60946 m .43201 .60959 L .43214 .60737 L F
.73 .822 .922 r
.43201 .60959 m .43295 .60973 L .43197 .60966 L F
.43276 .60942 m .43295 .60973 L .43201 .60959 L F
.631 .688 .885 r
.43201 .60959 m .43308 .6102 L .43282 .6094 L F
.43201 .60959 m .43282 .6094 L .43214 .60737 L F
.73 .822 .922 r
.43243 .60889 m .43276 .60942 L .43201 .60959 L F
.437 .669 .96 r
.43299 .60955 m .43295 .60973 L .43276 .60942 L F
.631 .688 .885 r
.43308 .6102 m .43336 .60986 L .43298 .609 L F
.433 .60993 m .43298 .609 L .43224 .60732 L F
.43308 .6102 m .43298 .609 L .433 .60993 L F
.43308 .6102 m .43366 .61053 L .43336 .60986 L F
.657 .497 .655 r
.43167 .61302 m .43404 .61342 L .43366 .61053 L F
.586 .438 .647 r
.43156 .6129 m .43167 .61302 L .43103 .61412 L F
.43167 .61302 m .43166 .61407 L .43103 .61412 L F
.657 .497 .655 r
.43131 .61346 m .43166 .61346 L .43167 .61302 L F
.43166 .61346 m .43404 .61342 L .43167 .61302 L F
.586 .438 .647 r
.43166 .61346 m .43252 .61399 L .43166 .61407 L F
.43215 .61357 m .43252 .61399 L .43166 .61346 L F
.434 .29 .586 r
.4333 .61343 m .43382 .61394 L .43404 .61342 L F
.43166 .61346 m .43343 .61385 L .4333 .61343 L F
.43343 .61385 m .43382 .61394 L .4333 .61343 L F
.623 .608 .815 r
.43224 .60732 m .43366 .61053 L .43615 .61004 L F
.43224 .60732 m .43615 .61004 L .43456 .60711 L F
.324 .355 .739 r
.43351 .60765 m .43344 .61387 L .43301 .61029 L F
.43344 .61387 m .43344 .61391 L .43343 .61385 L F
.43344 .61387 m .43343 .61385 L .43301 .61029 L F
.586 .438 .647 r
.43269 .6103 m .43344 .61391 L .43252 .61399 L F
.43269 .6103 m .43252 .61399 L .43156 .6129 L F
.527 .017 0 r
.43344 .61391 m .43335 .61393 L .43103 .61412 L F
.434 .29 .586 r
.4325 .61406 m .43334 .61506 L .43359 .61399 L F
.43213 .61411 m .43334 .61506 L .4325 .61406 L F
.43361 .6139 m .43334 .61506 L .43382 .61394 L F
.397 .26 .575 r
.4292 .61416 m .43114 .61615 L .43127 .61412 L F
.434 .29 .586 r
.43213 .61411 m .43114 .61615 L .43334 .61506 L F
.43131 .61346 m .43127 .61404 L .43213 .61411 L F
.43193 .61409 m .43114 .61615 L .43213 .61411 L F
.527 .017 0 r
.43259 .61409 m .4322 .61417 L .43107 .61412 L F
.43127 .61412 m .43107 .61412 L .43103 .61412 L F
.434 .29 .586 r
.43127 .61412 m .43114 .61615 L .43193 .61409 L F
.527 .017 0 r
.43259 .61409 m .43107 .61412 L .43127 .61412 L F
.434 .29 .586 r
.43127 .61404 m .43127 .61412 L .43193 .61409 L F
.395 .112 .362 r
.43385 .61388 m .43598 .6125 L .43404 .61342 L F
.43334 .61506 m .43431 .61412 L .43385 .61388 L F
.765 .414 .389 r
.4345 .61407 m .43433 .61413 L .43414 .61403 L F
.395 .112 .362 r
.43411 .61401 m .43598 .6125 L .43385 .61388 L F
.4345 .61394 m .43598 .6125 L .43423 .61392 L F
.56 .339 .536 r
.43366 .61053 m .43598 .6125 L .43615 .61004 L F
.451 .349 .648 r
.43366 .61053 m .43404 .61342 L .43598 .6125 L F
.495 .365 .633 r
.43598 .6125 m .43789 .60867 L .43615 .61004 L F
.781 .559 .599 r
.43232 .61693 m .43335 .61611 L .43334 .61506 L F
.43232 .61693 m .43596 .61757 L .43575 .61665 L F
.43232 .61693 m .43575 .61665 L .43335 .61611 L F
.445 .346 .649 r
.43539 .61455 m .43588 .61644 L .43737 .61391 L F
.157 .161 .611 r
.43467 .61404 m .43604 .61706 L .4345 .61407 L F
.395 .112 .362 r
.43523 .61446 m .4353 .61451 L .43533 .61443 L F
.4345 .61394 m .43533 .61443 L .43598 .6125 L F
.157 .161 .611 r
.43523 .61394 m .4354 .61458 L .43467 .61404 L F
.4354 .61458 m .43604 .61706 L .43467 .61404 L F
.395 .112 .362 r
.43433 .61475 m .43527 .61459 L .4353 .61451 L F
.43433 .61475 m .4353 .61451 L .43523 .61446 L F
.445 .346 .649 r
.43575 .61665 m .43612 .61717 L .43737 .61391 L F
0 0 0 r
.43527 .61459 m .43821 .6119 L .43598 .6125 L F
.157 .161 .611 r
.43691 .61363 m .43539 .61455 L .43538 .61451 L F
0 0 0 r
.43533 .61453 m .43691 .61363 L .43821 .6119 L F
.157 .161 .611 r
.43691 .61363 m .43538 .61451 L .43523 .61394 L F
0 0 0 r
.43527 .61459 m .43691 .61363 L .43533 .61453 L F
.445 .346 .649 r
.43527 .61459 m .43539 .61455 L .43691 .61363 L F
.43539 .61455 m .43737 .61391 L .43691 .61363 L F
.157 .161 .611 r
.43691 .61363 m .43604 .61706 L .43539 .61455 L F
.43691 .61363 m .43621 .61738 L .43604 .61706 L F
.445 .346 .649 r
.43527 .61459 m .43575 .61665 L .43588 .61644 L F
.43527 .61459 m .43588 .61644 L .43539 .61455 L F
.43575 .61665 m .43596 .61757 L .43612 .61717 L F
.765 .414 .389 r
.43466 .61439 m .43604 .61706 L .43445 .61467 L F
.43604 .61706 m .43621 .61738 L .43553 .61635 L F
.43604 .61706 m .43553 .61635 L .43445 .61467 L F
.665 .587 .758 r
.43612 .61717 m .43848 .61746 L .43737 .61391 L F
.43596 .61757 m .43684 .61753 L .43612 .61717 L F
.43684 .61753 m .43848 .61746 L .43612 .61717 L F
.765 .414 .389 r
.43454 .61638 m .43621 .61738 L .4343 .61633 L F
.43573 .61665 m .43604 .61713 L .43454 .61638 L F
.43604 .61713 m .43621 .61738 L .43454 .61638 L F
.4343 .61633 m .43621 .61738 L .43427 .61664 L F
.43445 .61467 m .43573 .61665 L .4343 .61633 L F
.781 .559 .599 r
.43335 .61611 m .43433 .61482 L .43334 .61506 L F
.395 .112 .362 r
.43334 .61506 m .43433 .61482 L .43433 .61475 L F
.765 .414 .389 r
.4345 .61407 m .43466 .61439 L .43445 .61467 L F
.4345 .61407 m .43427 .61664 L .43435 .61412 L F
.157 .161 .611 r
.43467 .61404 m .4345 .61407 L .43455 .61397 L F
.395 .112 .362 r
.43334 .61506 m .43533 .61443 L .43455 .61397 L F
.43449 .61394 m .43455 .61397 L .4345 .61394 L F
.214 .271 .706 r
.43449 .61394 m .4345 .61407 L .43448 .61394 L F
.43455 .61397 m .4345 .61407 L .43449 .61394 L F
.395 .112 .362 r
.43334 .61506 m .43455 .61397 L .43449 .61394 L F
.214 .271 .706 r
.43457 .61394 m .43455 .61397 L .43449 .61394 L F
.55 .266 .438 r
.4288 .61632 m .43114 .61615 L .42916 .61411 L F
.428 .006 .133 r
.4297 .61601 m .43334 .61506 L .43114 .61615 L F
.621 .354 .492 r
.4288 .61632 m .43123 .6186 L .43114 .61615 L F
.428 .006 .133 r
.4297 .61601 m .43232 .61693 L .43334 .61506 L F
.765 .414 .389 r
.43435 .61412 m .43427 .61664 L .43091 .61534 L F
.781 .559 .599 r
.43335 .61611 m .43575 .61665 L .43527 .61459 L F
.43335 .61611 m .43527 .61459 L .43433 .61482 L F
.395 .112 .362 r
.43433 .61482 m .43527 .61459 L .43433 .61475 L F
.157 .161 .611 r
.43505 .61397 m .43467 .61404 L .43457 .61394 L F
.43467 .61404 m .43455 .61397 L .43457 .61394 L F
.495 .365 .633 r
.43598 .6125 m .43821 .6119 L .43789 .60867 L F
.157 .161 .611 r
.43691 .61363 m .43505 .61397 L .43635 .61047 L F
.43505 .61397 m .43457 .61394 L .43635 .61047 L F
.395 .112 .362 r
.4345 .61394 m .4345 .61394 L .43419 .61395 L F
.4345 .61394 m .43423 .61392 L .43419 .61395 L F
.43448 .61394 m .43419 .61395 L .43411 .61401 L F
.4345 .61394 m .43419 .61395 L .43448 .61394 L F
.214 .271 .706 r
.43635 .61047 m .43457 .61394 L .43351 .60765 L F
.43457 .61394 m .43448 .61394 L .43351 .60765 L F
.324 .355 .739 r
.43351 .60765 m .43448 .61394 L .43344 .61391 L F
.43448 .61394 m .4345 .61407 L .43411 .61401 L F
.43448 .61394 m .43411 .61401 L .43344 .61391 L F
.395 .112 .362 r
.43431 .61412 m .4345 .61394 L .43411 .61401 L F
.765 .414 .389 r
.43414 .61403 m .43393 .61427 L .43339 .61394 L F
.43433 .61413 m .43393 .61427 L .43414 .61403 L F
.43393 .61427 m .43091 .61534 L .43295 .61419 L F
.43393 .61427 m .43295 .61419 L .43339 .61394 L F
.43352 .61392 m .43339 .61394 L .43344 .61391 L F
.527 .017 0 r
.43344 .61391 m .43339 .61394 L .43335 .61393 L F
.434 .29 .586 r
.43335 .61393 m .43359 .61399 L .43361 .6139 L F
.765 .414 .389 r
.4345 .61407 m .43339 .61394 L .43352 .61392 L F
.434 .29 .586 r
.4321 .61409 m .43213 .61411 L .4325 .61406 L F
.4321 .61409 m .43359 .61399 L .43335 .61393 L F
.095 .266 .749 r
.42802 .61454 m .4297 .61601 L .4288 .61632 L F
.4275 .61336 m .42852 .61459 L .42802 .61454 L F
.42852 .61459 m .4297 .61601 L .42802 .61454 L F
.527 .017 0 r
.4305 .61417 m .42928 .61465 L .4302 .61419 L F
.42928 .61465 m .42856 .61494 L .4292 .61465 L F
.42928 .61465 m .4292 .61465 L .4302 .61419 L F
.634 .142 0 r
.42856 .61494 m .4297 .61601 L .4275 .61336 L F
.527 .017 0 r
.43335 .61393 m .43091 .61534 L .42856 .61494 L F
.43339 .61394 m .43091 .61534 L .43335 .61393 L F
.43335 .61393 m .43259 .61409 L .432 .6141 L F
.43335 .61393 m .432 .6141 L .43103 .61412 L F
.434 .29 .586 r
.43131 .61346 m .4321 .61409 L .43361 .6139 L F
.43131 .61346 m .43382 .61394 L .43166 .61346 L F
.586 .438 .647 r
.43167 .61302 m .43215 .61357 L .43166 .61346 L F
.324 .355 .739 r
.43301 .61019 m .43301 .61029 L .433 .61022 L F
.43351 .60765 m .43301 .61029 L .43301 .61019 L F
.735 .643 .757 r
.42867 .60723 m .42882 .60737 L .43224 .60732 L F
.42882 .60737 m .42993 .60839 L .43043 .60816 L F
.42882 .60737 m .43043 .60816 L .43224 .60732 L F
.437 .669 .96 r
.43351 .60765 m .43303 .60943 L .43143 .60727 L F
.43303 .60943 m .43299 .60955 L .43285 .60934 L F
.43303 .60943 m .43285 .60934 L .43143 .60727 L F
.43299 .60955 m .43276 .60942 L .43143 .60727 L F
.631 .624 .825 r
.4271 .60896 m .43115 .61085 L .42993 .60839 L F
.73 .822 .922 r
.43143 .60727 m .43243 .60889 L .42869 .60944 L F
.43243 .60889 m .43197 .60966 L .42869 .60944 L F
.631 .688 .885 r
.43188 .60982 m .4314 .61062 L .43257 .61033 L F
.586 .438 .647 r
.43236 .6101 m .43236 .61009 L .43254 .6097 L F
.43254 .6097 m .43234 .61007 L .43197 .60966 L F
.631 .688 .885 r
.43179 .60946 m .43257 .61033 L .43308 .6102 L F
.586 .438 .647 r
.43145 .61216 m .4313 .61239 L .43236 .61009 L F
.43145 .61216 m .43236 .61009 L .43236 .6101 L F
.397 .26 .575 r
.4292 .61416 m .43103 .61412 L .43116 .61351 L F
.405 .281 .597 r
.42916 .61411 m .4308 .61362 L .43115 .61085 L F
.4308 .61362 m .43116 .61351 L .43125 .61249 L F
.397 .26 .575 r
.4308 .61362 m .43079 .61364 L .43131 .61346 L F
.586 .438 .647 r
.43126 .61246 m .43103 .61412 L .4302 .61419 L F
.43145 .61216 m .43116 .61351 L .43126 .61246 L F
.405 .281 .597 r
.43116 .61351 m .43125 .61254 L .43125 .61249 L F
.586 .438 .647 r
.43116 .61351 m .43103 .61412 L .43126 .61246 L F
.405 .281 .597 r
.43116 .61351 m .43131 .61346 L .43125 .61254 L F
.4308 .61362 m .43125 .61249 L .43115 .61085 L F
.586 .438 .647 r
.43131 .61233 m .4302 .61419 L .43138 .61192 L F
.4313 .61239 m .43126 .61246 L .43131 .61233 L F
.43126 .61246 m .4302 .61419 L .43131 .61233 L F
.4313 .61239 m .43138 .61192 L .43254 .6097 L F
.43234 .61112 m .43156 .6129 L .43146 .61221 L F
.43234 .61112 m .43146 .61221 L .43145 .61216 L F
.43156 .6129 m .43134 .61265 L .43145 .61216 L F
.657 .497 .655 r
.43131 .61346 m .43167 .61302 L .4316 .61294 L F
.405 .281 .597 r
.42916 .61411 m .43115 .61085 L .42861 .61166 L F
.631 .624 .825 r
.4271 .60896 m .42861 .61166 L .43115 .61085 L F
.586 .438 .647 r
.43197 .60966 m .43054 .61332 L .42869 .60944 L F
.43054 .61332 m .4302 .61419 L .43009 .61385 L F
.43054 .61332 m .43009 .61385 L .42869 .60944 L F
.324 .355 .739 r
.43308 .60923 m .433 .61022 L .43295 .60973 L F
.43351 .60765 m .433 .61022 L .43308 .60923 L F
.631 .688 .885 r
.433 .61023 m .4326 .61036 L .43299 .61042 L F
.586 .438 .647 r
.43234 .61007 m .4302 .61419 L .43197 .60966 L F
.433 .61022 m .43344 .61391 L .43269 .6103 L F
.397 .26 .575 r
.43116 .61351 m .43127 .61412 L .43131 .61346 L F
.43103 .61412 m .43127 .61412 L .43116 .61351 L F
.527 .017 0 r
.43103 .61412 m .4322 .61417 L .4305 .61417 L F
.4322 .61417 m .42856 .61494 L .4305 .61417 L F
.219 .033 .402 r
.42664 .61974 m .4288 .61632 L .42665 .61716 L F
.712 .432 .5 r
.4288 .61632 m .42572 .61815 L .42665 .61716 L F
.767 .365 .291 r
.52652 .55236 m .52977 .55288 L .52817 .55031 L F
.913 .649 .524 r
.4974 .60287 m .49628 .60428 L .49611 .60191 L F
.789 .455 .422 r
.4974 .60287 m .49776 .60678 L .49628 .60428 L F
.385 .159 .444 r
.49988 .60602 m .4974 .60287 L .5002 .604 L F
.49899 .60489 m .49772 .60636 L .4974 .60287 L F
.76 .685 .779 r
.49706 .60402 m .49975 .604 L .49894 .60021 L F
.49975 .604 m .5002 .604 L .50008 .60363 L F
.49975 .604 m .50008 .60363 L .49894 .60021 L F
.385 .159 .444 r
.49988 .60602 m .49776 .60678 L .49772 .60636 L F
.49988 .60602 m .49772 .60636 L .49899 .60489 L F
.322 .183 .531 r
.20678 .69535 m .20636 .69798 L .20819 .69719 L F
.675 .244 .217 r
.20819 .69719 m .20848 .69613 L .20678 .69535 L F
.766 .576 .64 r
.69565 .4162 m .69561 .41878 L .69185 .41857 L F
.787 .601 .649 r
.58036 .49672 m .57872 .49962 L .57878 .49712 L F
.74 .662 .773 r
.71519 .40931 m .71634 .41281 L .71264 .41208 L F
.716 .649 .781 r
.71899 .41001 m .71634 .41281 L .71519 .40931 L F
0 0 .329 r
.5325 .59798 m .5327 .59902 L .53363 .6012 L F
0 0 .319 r
.52757 .57745 m .52595 .5739 L .52688 .57514 L F
.527 .793 .994 r
.45109 .59888 m .44729 .59849 L .44939 .59581 L F
.274 0 0 r
.44729 .59849 m .44984 .599 L .45109 .59888 L F
.114 .328 .798 r
.44939 .59581 m .45194 .59776 L .45109 .59888 L F
.589 .947 .876 r
.45194 .59776 m .4508 .59844 L .45163 .59817 L F
.4508 .59844 m .44984 .599 L .45163 .59817 L F
0 0 0 r
.45194 .59776 m .45062 .5988 L .44984 .599 L F
.23 0 0 r
.45062 .5988 m .44729 .59849 L .44984 .599 L F
.44989 .59873 m .44527 .59947 L .44729 .59849 L F
.45062 .5988 m .44909 .59899 L .44989 .59873 L F
.44909 .59899 m .44527 .59947 L .44989 .59873 L F
.589 .947 .876 r
.45163 .59817 m .44984 .599 L .45109 .59888 L F
.693 .467 .575 r
.45109 .59888 m .4532 .60411 L .45427 .60177 L F
.811 .528 .509 r
.22976 .65976 m .22903 .66158 L .22725 .65797 L F
.723 .582 .696 r
.22588 .65623 m .22548 .65665 L .22725 .65797 L F
.827 .419 .272 r
.22676 .6579 m .22741 .65831 L .22725 .65797 L F
.22741 .65831 m .2291 .65935 L .22725 .65797 L F
.2291 .65935 m .22976 .65976 L .22725 .65797 L F
.589 .657 .884 r
.23171 .65895 m .22992 .6597 L .22738 .65826 L F
.723 .582 .696 r
.22469 .65749 m .2264 .65821 L .22725 .65797 L F
.396 0 0 r
.22725 .65797 m .22727 .65804 L .22676 .6579 L F
.589 .657 .884 r
.22727 .65804 m .22738 .65826 L .22676 .6579 L F
.396 0 0 r
.22727 .65804 m .22738 .65838 L .22676 .6579 L F
.589 .657 .884 r
.22725 .65801 m .22727 .65804 L .22676 .6579 L F
.675 .292 0 r
.22725 .65797 m .22749 .65847 L .22741 .65831 L F
.589 .657 .884 r
.23171 .65895 m .22738 .65826 L .22725 .65801 L F
.675 .292 0 r
.22741 .65831 m .22903 .66158 L .22832 .6602 L F
.22749 .65847 m .22903 .66158 L .22741 .65831 L F
.589 .657 .884 r
.22992 .6597 m .2291 .65935 L .22741 .65831 L F
.22738 .65826 m .22741 .65831 L .22676 .6579 L F
.22992 .6597 m .22741 .65831 L .22738 .65826 L F
.675 .292 0 r
.22727 .65804 m .22832 .6602 L .22738 .65838 L F
.22725 .65797 m .22741 .65831 L .22727 .65804 L F
.22741 .65831 m .22832 .6602 L .22727 .65804 L F
.589 .657 .884 r
.22992 .6597 m .22976 .65976 L .2291 .65935 L F
.723 .582 .696 r
.22548 .65665 m .22469 .65749 L .22725 .65797 L F
.22469 .65749 m .22317 .65912 L .2264 .65821 L F
.305 .004 .278 r
.23171 .65895 m .22903 .66158 L .22976 .65976 L F
.931 .681 .538 r
.64701 .4074 m .64848 .41263 L .64959 .40958 L F
.614 .512 .715 r
.43037 .64703 m .43173 .64781 L .4321 .64383 L F
.381 .2 .507 r
.24746 .59897 m .24926 .60092 L .24958 .59852 L F
.24746 .59897 m .24715 .60192 L .24926 .60092 L F
.924 .546 .269 r
.1957 .73831 m .19757 .74051 L .1957 .73979 L F
.1957 .73831 m .19757 .74051 L .1957 .73979 L F
.999 .787 .465 r
.76799 .41314 m .76674 .41487 L .76705 .41177 L F
.76799 .41314 m .76778 .41594 L .76674 .41487 L F
.99 .878 .616 r
.7602 .41554 m .75997 .41235 L .75923 .41435 L F
.937 .91 .767 r
.75732 .41771 m .7602 .41554 L .75923 .41435 L F
.75732 .41771 m .75831 .41887 L .7602 .41554 L F
.031 0 .361 r
.57016 .5572 m .56999 .55954 L .57121 .5562 L F
.043 0 0 r
.16325 .55277 m .16756 .55126 L .16526 .55163 L F
0 0 .175 r
.41953 .58894 m .41908 .59161 L .41764 .59289 L F
.592 .492 .709 r
.41764 .59289 m .42123 .59556 L .42139 .59304 L F
.41764 .59289 m .41881 .59635 L .42123 .59556 L F
0 0 0 r
.41908 .59161 m .41659 .59419 L .41764 .59289 L F
0 0 .355 r
.53362 .60513 m .53409 .60367 L .53363 .6012 L F
0 0 .366 r
.53396 .60744 m .53409 .60367 L .53362 .60513 L F
.366 0 0 r
.79796 .42706 m .79416 .4275 L .7967 .42817 L F
.24 0 0 r
.79888 .42778 m .79796 .42706 L .7967 .42817 L F
.79888 .42778 m .80041 .42737 L .79796 .42706 L F
.403 .549 .887 r
.1584 .60725 m .16071 .60788 L .15895 .60814 L F
.889 .957 .839 r
.16071 .60788 m .15884 .61074 L .15895 .60814 L F
.343 0 0 r
.21013 .55287 m .20783 .55345 L .20538 .5534 L F
.971 .674 .281 r
.6589 .41182 m .66011 .4151 L .66028 .41357 L F
.606 .323 .461 r
.45294 .58031 m .45515 .58018 L .4559 .57826 L F
.375 .198 .509 r
.45515 .58018 m .457 .57718 L .4559 .57826 L F
.312 0 0 r
.24316 .53823 m .24591 .53953 L .24376 .5395 L F
.036 .427 .867 r
.22011 .66982 m .22422 .67232 L .22297 .67118 L F
.364 0 0 r
.21734 .66851 m .22011 .66982 L .22216 .67054 L F
.885 .935 .846 r
.22216 .67054 m .22255 .66684 L .22414 .66791 L F
.22216 .67054 m .22011 .66982 L .22255 .66684 L F
.487 .467 .761 r
.22414 .66791 m .22486 .67057 L .22216 .67054 L F
.72 .942 .631 r
.22255 .66684 m .22011 .66982 L .22037 .66882 L F
.036 .427 .867 r
.22011 .66982 m .22297 .67118 L .22037 .66882 L F
.364 0 0 r
.21722 .66846 m .22011 .66982 L .21734 .66851 L F
.378 .142 .424 r
.25688 .58429 m .2585 .58587 L .2587 .58337 L F
.25688 .58429 m .25651 .58658 L .2585 .58587 L F
.485 .206 .415 r
.45053 .6115 m .45004 .61357 L .44759 .61396 L F
.433 .153 .387 r
.45274 .61099 m .45004 .61357 L .45053 .6115 L F
.824 .809 .836 r
.52689 .53947 m .52862 .5412 L .5309 .53869 L F
.72 .645 .774 r
.61469 .43645 m .61831 .4368 L .61703 .43328 L F
.644 .441 .594 r
.57878 .49712 m .57672 .49928 L .57855 .49696 L F
.142 0 0 r
.47161 .58092 m .46738 .58138 L .46937 .5821 L F
.6 .371 .541 r
.44617 .60794 m .44871 .60777 L .44897 .60523 L F
.193 0 0 r
.26169 .54114 m .26539 .54218 L .26326 .54241 L F
.41 .207 .491 r
.28338 .59548 m .28136 .59612 L .28364 .59302 L F
.301 .115 .454 r
.28338 .59548 m .28138 .59866 L .28136 .59612 L F
.625 .696 .895 r
.67745 .43417 m .67383 .43294 L .67612 .43274 L F
.791 .835 .886 r
.68028 .43179 m .67745 .43417 L .67612 .43274 L F
.602 .535 .751 r
.41917 .61389 m .41844 .6179 L .41572 .61297 L F
.155 0 .042 r
.55812 .48849 m .5574 .48981 L .56027 .48752 L F
.609 .049 0 r
.23929 .53733 m .24316 .53823 L .24091 .5391 L F
.648 .471 .63 r
.52741 .53715 m .52997 .53543 L .52803 .53658 L F
.158 .065 .491 r
.21675 .69975 m .21457 .69892 L .21526 .69773 L F
.353 .826 .879 r
.51885 .51748 m .51755 .51823 L .5156 .51841 L F
.51885 .51748 m .51992 .51759 L .51755 .51823 L F
0 0 .074 r
.41904 .61852 m .41659 .62108 L .41844 .6179 L F
.419 .866 .826 r
.69812 .42962 m .69961 .4286 L .69715 .42896 L F
.69812 .42962 m .70099 .42846 L .69961 .4286 L F
.842 .833 .837 r
.75187 .40373 m .74907 .40354 L .75077 .40248 L F
.918 .882 .783 r
.75342 .40085 m .75187 .40373 L .75077 .40248 L F
.674 .491 .63 r
.71292 .40736 m .71281 .4101 L .70912 .40982 L F
.642 .456 .616 r
.71517 .40695 m .71281 .4101 L .71292 .40736 L F
.453 .794 .999 r
.21419 .64984 m .21829 .65043 L .21645 .64948 L F
.701 .931 .965 r
.21855 .64867 m .21829 .65043 L .22023 .64915 L F
.601 .85 .991 r
.21645 .64948 m .21829 .65043 L .21855 .64867 L F
0 .103 .622 r
.49035 .56234 m .48973 .56133 L .48949 .56126 L F
0 .205 .699 r
.48839 .56031 m .48973 .56133 L .49035 .56234 L F
.73 .857 .941 r
.77781 .42504 m .78186 .42538 L .78016 .42401 L F
.291 0 .145 r
.44653 .57336 m .445 .57272 L .44838 .57219 L F
.44653 .57336 m .44432 .57417 L .445 .57272 L F
0 0 .232 r
.78891 .42696 m .78989 .42412 L .78792 .42505 L F
.705 .694 .837 r
.54661 .59525 m .54287 .59352 L .54544 .59308 L F
.102 0 0 r
.54544 .59308 m .54947 .59242 L .54661 .59525 L F
.554 .571 .826 r
.16636 .64235 m .16775 .64089 L .16572 .64093 L F
.875 .634 .571 r
.751 .39746 m .75342 .40085 L .75162 .40041 L F
.918 .882 .783 r
.75342 .40085 m .75077 .40248 L .75162 .40041 L F
.961 .64 .359 r
.41524 .59647 m .41579 .59913 L .41601 .59783 L F
.718 .646 .776 r
.41524 .59647 m .41601 .59783 L .41881 .59635 L F
.732 .547 .642 r
.41601 .59783 m .41646 .60191 L .41934 .60119 L F
.96 .921 .574 r
.59396 .52409 m .59456 .51969 L .59385 .52113 L F
.947 .823 .689 r
.5989 .50897 m .59844 .50536 L .59786 .50774 L F
.972 .876 .681 r
.59658 .51126 m .5989 .50897 L .59786 .50774 L F
.59658 .51126 m .59774 .51219 L .5989 .50897 L F
.644 .441 .594 r
.57878 .49712 m .57872 .49962 L .57672 .49928 L F
.432 .208 .471 r
.26963 .61664 m .26707 .61993 L .26703 .61725 L F
.82 .536 .508 r
.58568 .50562 m .58241 .50267 L .58618 .50305 L F
.97 .65 .318 r
.65256 .42173 m .65147 .42317 L .65129 .42033 L F
.897 .87 .803 r
.65441 .41867 m .65256 .42173 L .65129 .42033 L F
.146 .687 .82 r
.22744 .53886 m .22971 .53872 L .23133 .53881 L F
.535 .377 .613 r
.65429 .42707 m .65677 .42467 L .65282 .42438 L F
.65429 .42707 m .65683 .42766 L .65677 .42467 L F
.188 .233 .678 r
.78917 .43108 m .7908 .42929 L .78891 .42696 L F
.408 .574 .905 r
.78917 .43108 m .79174 .43171 L .7908 .42929 L F
0 .518 .852 r
.23138 .55392 m .22985 .55311 L .22809 .55266 L F
.513 .827 1 r
.23406 .55335 m .22985 .55311 L .23138 .55392 L F
.659 .689 .867 r
.28676 .55038 m .28296 .54874 L .28501 .54836 L F
.799 .395 .287 r
.28501 .54836 m .28897 .55029 L .28676 .55038 L F
.335 .131 .447 r
.45323 .58883 m .4513 .58778 L .45389 .58684 L F
.45323 .58883 m .45131 .58977 L .4513 .58778 L F
0 0 .431 r
.43398 .56802 m .43528 .56733 L .43488 .56463 L F
.169 .055 .47 r
.43403 .57051 m .43528 .56733 L .43398 .56802 L F
.486 .218 .433 r
.45533 .56897 m .45303 .56892 L .45677 .56882 L F
0 0 .496 r
.45934 .57189 m .45884 .57121 L .45677 .56882 L F
.4594 .57195 m .45884 .57121 L .45934 .57189 L F
.051 .372 .839 r
.45884 .57121 m .45983 .57042 L .45817 .5703 L F
0 .229 .661 r
.45884 .57121 m .45533 .56897 L .45677 .56882 L F
.051 .372 .839 r
.45884 .57121 m .45817 .5703 L .45752 .57026 L F
.749 .618 .714 r
.49398 .58171 m .49749 .58407 L .49618 .5806 L F
.49398 .58171 m .49431 .58449 L .49749 .58407 L F
.5 .067 .148 r
.4937 .58591 m .49749 .58407 L .49431 .58449 L F
.4937 .58591 m .49625 .58585 L .49749 .58407 L F
.323 .409 .795 r
.49618 .5806 m .49749 .58407 L .4987 .58259 L F
.344 0 .057 r
.49749 .58407 m .49899 .58524 L .4987 .58259 L F
.49749 .58407 m .49625 .58585 L .49899 .58524 L F
.568 .14 .188 r
.49431 .58449 m .49625 .58585 L .49749 .58407 L F
.461 .132 .321 r
.71761 .39146 m .7202 .39097 L .72117 .38859 L F
.716 .416 .468 r
.72366 .39115 m .72117 .38859 L .7202 .39097 L F
.72366 .39115 m .72338 .38909 L .72117 .38859 L F
.186 0 .059 r
.56257 .60589 m .5604 .60674 L .56124 .60478 L F
0 0 0 r
.56257 .60589 m .56213 .60603 L .5604 .60674 L F
.55864 .60747 m .56124 .60478 L .5604 .60674 L F
.56213 .60603 m .55945 .60684 L .5604 .60674 L F
.55839 .60773 m .55864 .60747 L .5604 .60674 L F
.186 0 .059 r
.56257 .60589 m .56124 .60478 L .56343 .60385 L F
.431 .123 .341 r
.45291 .6235 m .45242 .62537 L .45007 .62588 L F
.562 .318 .505 r
.4555 .62269 m .45242 .62537 L .45291 .6235 L F
0 0 .401 r
.57569 .58597 m .57564 .58868 L .57411 .59011 L F
.048 0 .41 r
.57564 .58868 m .57385 .59258 L .57411 .59011 L F
0 0 0 r
.64404 .41 m .64536 .40841 L .64625 .40726 L F
.64625 .40726 m .64769 .40743 L .64701 .4074 L F
.982 .74 .492 r
.64536 .40841 m .64669 .4117 L .64701 .4074 L F
.931 .681 .538 r
.64701 .4074 m .64669 .4117 L .64848 .41263 L F
.982 .74 .492 r
.64536 .40841 m .64701 .4074 L .64769 .40743 L F
0 0 0 r
.64625 .40726 m .64536 .40841 L .64769 .40743 L F
.991 .849 .604 r
.76686 .4181 m .76722 .42134 L .76626 .42023 L F
.927 .777 .674 r
.76722 .42134 m .7647 .42358 L .76626 .42023 L F
.76722 .42134 m .76625 .4251 L .7647 .42358 L F
.803 1 .827 r
.67142 .43463 m .66846 .43661 L .67073 .43382 L F
.792 .903 .92 r
.67275 .4316 m .67142 .43463 L .67073 .43382 L F
.67275 .4316 m .67383 .43294 L .67142 .43463 L F
.096 .306 .784 r
.39723 .62611 m .39803 .62472 L .39562 .6228 L F
.295 .571 .935 r
.39723 .62611 m .39934 .62637 L .39803 .62472 L F
.517 .534 .813 r
.79763 .4027 m .79649 .40676 L .79573 .40292 L F
.79763 .4027 m .79887 .40626 L .79649 .40676 L F
.607 .521 .731 r
.79887 .40626 m .79662 .40951 L .79649 .40676 L F
.327 0 0 r
.65734 .40125 m .65959 .40198 L .66127 .4017 L F
.553 .932 .849 r
.66127 .4017 m .66265 .40059 L .66394 .40098 L F
.66127 .4017 m .65959 .40198 L .66265 .40059 L F
.067 0 .18 r
.48988 .58985 m .49134 .58913 L .49347 .58532 L F
.636 .447 .61 r
.48988 .58985 m .48947 .59061 L .49134 .58913 L F
0 .308 .801 r
.78382 .39196 m .78086 .38886 L .78301 .39051 L F
.073 .421 .867 r
.78603 .39196 m .78382 .39196 L .78301 .39051 L F
.78603 .39196 m .78679 .39342 L .78382 .39196 L F
.613 .299 .415 r
.43407 .63512 m .43287 .63756 L .43056 .63713 L F
.302 0 .246 r
.4354 .63653 m .43407 .63512 L .43674 .63478 L F
.4354 .63653 m .43287 .63756 L .43407 .63512 L F
.428 .024 .169 r
.16769 .56798 m .16686 .57024 L .16483 .57045 L F
.318 .008 .272 r
.17108 .56529 m .1701 .56831 L .16769 .56798 L F
.208 0 .086 r
.16888 .56942 m .16769 .56798 L .1701 .56831 L F
.16888 .56942 m .16686 .57024 L .16769 .56798 L F
.96 .625 .268 r
.55775 .59001 m .55955 .59375 L .55833 .59286 L F
.563 .021 0 r
.55034 .58426 m .5519 .58455 L .54906 .58491 L F
.553 0 0 r
.2461 .55196 m .24559 .55222 L .2437 .55239 L F
.421 .581 .906 r
.2437 .55239 m .24559 .55222 L .24554 .55213 L F
0 0 0 r
.24239 .55258 m .2437 .55239 L .24205 .55263 L F
.2461 .55196 m .2437 .55239 L .24239 .55258 L F
.421 .581 .906 r
.2437 .55239 m .24554 .55213 L .2448 .55077 L F
.535 .415 .663 r
.24539 .55216 m .2437 .55239 L .2448 .55077 L F
.24631 .5543 m .2437 .55239 L .24539 .55216 L F
0 0 0 r
.24205 .55263 m .2437 .55239 L .24168 .55269 L F
.446 0 .076 r
.45966 .61623 m .46218 .61622 L .46309 .61465 L F
.567 .324 .506 r
.47455 .57855 m .47485 .58139 L .47161 .58092 L F
.47455 .57855 m .47485 .58139 L .47161 .58092 L F
.373 .187 .495 r
.47576 .58002 m .47455 .57855 L .47622 .57778 L F
.47576 .58002 m .47485 .58139 L .47455 .57855 L F
.47576 .58002 m .47455 .57855 L .47622 .57778 L F
.47576 .58002 m .47485 .58139 L .47455 .57855 L F
.693 .568 .709 r
.61469 .43395 m .61228 .437 L .61469 .43645 L F
.359 .821 .921 r
.238 .6436 m .23731 .6434 L .23511 .6439 L F
.244 0 0 r
.22561 .62775 m .22528 .62636 L .22361 .62831 L F
.22561 .62775 m .22755 .62589 L .22528 .62636 L F
.767 .702 .79 r
.71264 .39747 m .71489 .39368 L .71253 .39498 L F
.426 .018 .159 r
.55678 .59123 m .55537 .58969 L .55736 .58959 L F
.65 .174 .108 r
.49243 .57762 m .49703 .57824 L .49492 .57939 L F
.98 .848 .639 r
.49703 .57824 m .49618 .5806 L .49492 .57939 L F
.455 .77 .997 r
.17921 .62196 m .18082 .62306 L .17707 .62235 L F
0 0 0 r
.18086 .62456 m .18047 .62606 L .18082 .62306 L F
.18086 .62456 m .18082 .62306 L .17921 .62196 L F
.177 0 0 r
.66265 .40059 m .66608 .39969 L .66394 .40098 L F
0 0 0 r
.51813 .6134 m .51716 .61489 L .5182 .61327 L F
.028 .059 .557 r
.54014 .57097 m .54072 .57326 L .53941 .57491 L F
.065 .114 .603 r
.53941 .57491 m .54072 .57326 L .54108 .57679 L F
.751 .545 .618 r
.59922 .46657 m .60072 .46971 L .60288 .46677 L F
.536 .337 .558 r
.42123 .59556 m .42365 .59511 L .42139 .59304 L F
.42139 .59304 m .42365 .59511 L .42123 .59556 L F
.957 .843 .689 r
.59937 .50305 m .60074 .49968 L .59942 .49833 L F
.925 .865 .761 r
.60074 .49968 m .60024 .49662 L .59942 .49833 L F
.60074 .49968 m .60162 .4977 L .60024 .49662 L F
.265 0 .129 r
.39498 .60707 m .3981 .60457 L .39573 .60504 L F
.897 .87 .803 r
.65441 .41867 m .65129 .42033 L .65375 .41724 L F
.378 .016 .219 r
.65734 .40125 m .65711 .40266 L .65959 .40198 L F
.681 .344 .398 r
.64532 .42075 m .64879 .41883 L .64769 .41763 L F
.64532 .42075 m .65058 .42131 L .64879 .41883 L F
.751 .797 .89 r
.73403 .4058 m .72997 .40583 L .73289 .40439 L F
.428 .757 .995 r
.73524 .40439 m .73403 .4058 L .73289 .40439 L F
.73524 .40439 m .73642 .40546 L .73403 .4058 L F
0 0 0 r
.19064 .54215 m .19305 .54184 L .19438 .54156 L F
.427 .846 .959 r
.19305 .54184 m .19669 .54158 L .19438 .54156 L F
.166 .393 .838 r
.79081 .39842 m .78759 .3949 L .79079 .39633 L F
.111 .46 .888 r
.79021 .39493 m .78759 .3949 L .78679 .39342 L F
.79021 .39493 m .79079 .39633 L .78759 .3949 L F
0 0 0 r
.76544 .39469 m .76773 .39135 L .76709 .39251 L F
.671 .653 .824 r
.77062 .38903 m .76773 .39135 L .76694 .38797 L F
.403 .855 .809 r
.70696 .4005 m .70739 .40052 L .70485 .40142 L F
.441 .876 .816 r
.70917 .39943 m .70975 .39942 L .70739 .40052 L F
.439 .875 .81 r
.70917 .39943 m .70739 .40052 L .70696 .4005 L F
.624 .72 .915 r
.17468 .62338 m .17115 .62244 L .17287 .62241 L F
.689 .865 .965 r
.17707 .62235 m .17468 .62338 L .17287 .62241 L F
.824 .809 .836 r
.52689 .53947 m .5309 .53869 L .52949 .53752 L F
.998 .854 .545 r
.53386 .53609 m .53238 .53733 L .5309 .53869 L F
.648 .471 .63 r
.52741 .53715 m .53106 .53761 L .52997 .53543 L F
.516 .312 .542 r
.53238 .53733 m .52997 .53543 L .53106 .53761 L F
.252 .754 .892 r
.52949 .53752 m .53238 .53733 L .53106 .53761 L F
.486 .821 .999 r
.5309 .53869 m .53238 .53733 L .52949 .53752 L F
.498 .284 .519 r
.42494 .59644 m .42731 .59589 L .42754 .59304 L F
.455 .289 .566 r
.28576 .58986 m .28575 .5924 L .28364 .59302 L F
.464 .252 .506 r
.28554 .59491 m .28364 .59302 L .28575 .5924 L F
.28554 .59491 m .28338 .59548 L .28364 .59302 L F
.26 .203 .601 r
.25776 .57482 m .25898 .57113 L .25713 .57249 L F
.747 .745 .85 r
.19279 .72762 m .19474 .73036 L .19699 .72786 L F
.868 .934 .863 r
.77992 .38755 m .78086 .38886 L .7777 .39166 L F
0 .195 .7 r
.78301 .39051 m .78086 .38886 L .77992 .38755 L F
.5 .551 .84 r
.64359 .41112 m .64536 .40841 L .64404 .41 L F
.425 .347 .665 r
.28935 .56534 m .28971 .5676 L .28781 .56809 L F
.48 .377 .661 r
.28971 .5676 m .28758 .5722 L .28781 .56809 L F
.699 .775 .911 r
.73855 .39026 m .7369 .39376 L .736 .39302 L F
.73855 .39026 m .73954 .3926 L .7369 .39376 L F
.51 .9 .945 r
.78715 .41198 m .78516 .4134 L .7879 .41308 L F
.78715 .41198 m .78458 .41302 L .78516 .4134 L F
0 .266 .747 r
.49974 .56559 m .49955 .56618 L .49849 .56475 L F
.49974 .56559 m .50224 .56795 L .49955 .56618 L F
.543 .341 .557 r
.4452 .61704 m .44511 .61974 L .44268 .62014 L F
.549 .348 .562 r
.4478 .61652 m .44511 .61974 L .4452 .61704 L F
.183 0 .072 r
.55222 .49331 m .55445 .49294 L .55527 .491 L F
.321 0 .242 r
.55445 .49294 m .5574 .48981 L .55527 .491 L F
.957 .905 .727 r
.47223 .61114 m .47079 .61438 L .46978 .61247 L F
0 0 0 r
.47438 .60755 m .47223 .61114 L .47304 .60999 L F
.619 .945 .754 r
.47304 .60999 m .47223 .61114 L .46978 .61247 L F
.955 .902 .731 r
.75665 .42218 m .75831 .41887 L .75732 .41771 L F
.302 0 0 r
.41904 .61852 m .41484 .6206 L .41659 .62108 L F
.78 .492 .499 r
.47304 .60999 m .4762 .60702 L .47438 .60755 L F
.414 .466 .805 r
.43901 .62493 m .44097 .62861 L .43732 .62679 L F
.009 .528 .858 r
.20009 .63161 m .19857 .63134 L .19622 .63023 L F
.854 .492 .366 r
.77728 .42182 m .77716 .42341 L .77828 .42163 L F
.816 .44 .341 r
.77828 .42163 m .77716 .42341 L .78016 .42401 L F
.822 .652 .672 r
.56355 .58146 m .56255 .58364 L .56139 .58039 L F
.403 0 0 r
.20727 .53977 m .21186 .53906 L .20934 .53947 L F
.537 .323 .536 r
.56348 .57187 m .56575 .57137 L .56599 .569 L F
.187 .033 .427 r
.56599 .569 m .56805 .5701 L .56782 .56815 L F
.56599 .569 m .56575 .57137 L .56805 .5701 L F
.508 .11 .221 r
.43203 .58217 m .43308 .58249 L .43094 .58116 L F
.539 .049 .04 r
.43308 .58249 m .43266 .5825 L .43207 .58204 L F
.499 .232 .441 r
.43221 .58209 m .43308 .58249 L .43203 .58217 L F
.539 .049 .04 r
.43308 .58249 m .43207 .58204 L .43268 .58224 L F
.499 .232 .441 r
.43585 .58044 m .43308 .58249 L .43221 .58209 L F
.539 .049 .04 r
.43268 .58224 m .43221 .58209 L .43094 .58116 L F
.43221 .58209 m .43207 .58204 L .43201 .582 L F
.43221 .58209 m .43201 .582 L .43094 .58116 L F
.547 .322 .525 r
.43585 .58044 m .43221 .58209 L .4335 .57742 L F
.43221 .58209 m .43203 .58217 L .43207 .58204 L F
.43221 .58209 m .43207 .58204 L .4335 .57742 L F
.345 .128 .433 r
.4335 .57742 m .43207 .58204 L .43094 .58116 L F
.43207 .58204 m .43203 .58217 L .43094 .58116 L F
.539 .049 .04 r
.43266 .5825 m .42948 .58258 L .43094 .58116 L F
.365 .009 .221 r
.46051 .60426 m .45791 .60512 L .4609 .60287 L F
.516 .142 .27 r
.4609 .60287 m .46305 .60401 L .46051 .60426 L F
.503 .166 .329 r
.4636 .60217 m .46305 .60401 L .4609 .60287 L F
0 0 0 r
.42046 .58776 m .42 .58731 L .42244 .58658 L F
.42046 .58776 m .41953 .58894 L .42 .58731 L F
.473 .485 .79 r
.55629 .58184 m .55891 .58324 L .55711 .58406 L F
.694 .633 .784 r
.55891 .58324 m .55711 .58691 L .55711 .58406 L F
0 0 0 r
.19805 .65241 m .19961 .65171 L .20184 .65098 L F
.197 .38 .819 r
.40587 .64059 m .40768 .64394 L .4087 .64256 L F
.193 .374 .815 r
.40768 .64394 m .41039 .64591 L .4087 .64256 L F
.179 .172 .613 r
.54244 .58315 m .5432 .58546 L .54141 .58672 L F
.273 .352 .763 r
.5432 .58546 m .54438 .58869 L .54141 .58672 L F
.363 .346 .706 r
.54438 .58869 m .54262 .58971 L .54141 .58672 L F
.753 .552 .624 r
.20616 .70979 m .20289 .71263 L .20494 .70931 L F
.20616 .70979 m .20622 .71266 L .20289 .71263 L F
.596 .09 .02 r
.20494 .70931 m .20877 .70995 L .20616 .70979 L F
.579 .35 .533 r
.20877 .70995 m .20622 .71266 L .20616 .70979 L F
.642 .456 .616 r
.71517 .40695 m .71519 .40931 L .71281 .4101 L F
.708 .601 .735 r
.71711 .40412 m .71765 .40644 L .71517 .40695 L F
.74 .575 .669 r
.71765 .40644 m .71519 .40931 L .71517 .40695 L F
.421 .474 .809 r
.74006 .41138 m .73834 .41376 L .73798 .41175 L F
.74006 .41138 m .74187 .41629 L .73834 .41376 L F
.72 .645 .774 r
.61469 .43645 m .61703 .43328 L .61469 .43395 L F
.921 .764 .67 r
.58601 .51243 m .58335 .51353 L .58398 .51101 L F
.58601 .51243 m .58511 .51461 L .58335 .51353 L F
.762 .595 .671 r
.70912 .40982 m .71046 .41343 L .70669 .41258 L F
.688 .572 .719 r
.71281 .4101 m .71046 .41343 L .70912 .40982 L F
.828 .906 .893 r
.77319 .41792 m .77675 .41651 L .77531 .41599 L F
.548 .002 0 r
.77675 .41651 m .77676 .41678 L .77531 .41599 L F
.77675 .41651 m .77867 .41807 L .77676 .41678 L F
.413 .342 .668 r
.48947 .59061 m .49533 .59293 L .49347 .58801 L F
.475 .878 .955 r
.43434 .57639 m .43217 .57708 L .4335 .57742 L F
0 .137 .669 r
.43434 .57639 m .43585 .58044 L .4335 .57742 L F
.785 .554 .587 r
.66608 .39969 m .66987 .40034 L .66988 .39793 L F
.488 .234 .456 r
.41881 .59635 m .42075 .59818 L .42123 .59556 L F
.963 .714 .511 r
.42123 .59556 m .42075 .59818 L .41881 .59635 L F
.745 .749 .855 r
.65058 .42131 m .65024 .42493 L .65076 .42195 L F
.375 .102 .366 r
.25707 .62898 m .25647 .63124 L .25435 .6318 L F
.429 .15 .387 r
.25864 .63071 m .25707 .62898 L .25925 .62846 L F
.25864 .63071 m .25647 .63124 L .25707 .62898 L F
.555 .358 .569 r
.47268 .58912 m .47503 .58633 L .47314 .58711 L F
.51 .159 .307 r
.69821 .40528 m .69566 .40394 L .69579 .40616 L F
.69821 .40528 m .69819 .40364 L .69566 .40394 L F
.535 .31 .52 r
.50363 .58399 m .506 .58596 L .50371 .58617 L F
.24 .567 .938 r
.18773 .65208 m .18751 .6509 L .18541 .65061 L F
.18773 .65208 m .18954 .65258 L .18751 .6509 L F
.632 .84 .98 r
.18453 .62627 m .18047 .62606 L .18274 .62582 L F
.392 .792 .985 r
.18487 .62525 m .18453 .62627 L .18274 .62582 L F
.18487 .62525 m .18671 .62596 L .18453 .62627 L F
.357 .543 .9 r
.1882 .62899 m .18453 .62627 L .18671 .62596 L F
.775 .982 .725 r
.54906 .58491 m .55141 .58199 L .55034 .58426 L F
.059 0 .395 r
.58018 .5655 m .58002 .56821 L .57888 .56899 L F
.144 .056 .488 r
.58002 .56821 m .5789 .57145 L .57888 .56899 L F
.74 .575 .669 r
.71765 .40644 m .71899 .41001 L .71519 .40931 L F
.639 .63 .826 r
.7195 .40404 m .71765 .40644 L .71711 .40412 L F
.7195 .40404 m .72119 .40701 L .71765 .40644 L F
.675 .542 .695 r
.72119 .40701 m .71899 .41001 L .71765 .40644 L F
0 .028 .592 r
.50447 .57235 m .50498 .57354 L .50376 .57232 L F
.708 .376 0 r
.50447 .57235 m .50478 .57314 L .50498 .57354 L F
.843 .985 .704 r
.50498 .57354 m .50516 .5747 L .50539 .57437 L F
.114 .402 .854 r
.50857 .57779 m .50516 .5747 L .50726 .57665 L F
.593 .043 0 r
.50579 .57578 m .50516 .5747 L .50498 .57354 L F
.708 .376 0 r
.50478 .57314 m .50579 .57578 L .50498 .57354 L F
.843 .985 .704 r
.50498 .57354 m .50539 .57437 L .50714 .5719 L F
.593 .043 0 r
.50579 .57578 m .50726 .57665 L .50516 .5747 L F
.459 .69 .966 r
.23493 .55732 m .23732 .5571 L .23631 .55581 L F
.329 .5 .875 r
.39934 .62637 m .40079 .62911 L .40203 .62736 L F
.101 .179 .659 r
.40079 .62911 m .40277 .63137 L .40203 .62736 L F
.604 .347 .5 r
.44697 .58341 m .44944 .58342 L .44973 .5811 L F
.608 .361 .518 r
.44944 .58342 m .45294 .58031 L .44973 .5811 L F
.85 .624 .596 r
.46038 .5769 m .46459 .57996 L .46517 .57872 L F
.137 0 .166 r
.46459 .57996 m .46779 .57756 L .46517 .57872 L F
.795 .352 .193 r
.67497 .41402 m .67427 .41245 L .67609 .41273 L F
.68 .201 .107 r
.67609 .41273 m .67856 .41463 L .67497 .41402 L F
.594 .5 .718 r
.79729 .41289 m .79792 .41555 L .7952 .41595 L F
.06 0 0 r
.7952 .41595 m .79792 .41555 L .79718 .41609 L F
.7952 .41595 m .79718 .41609 L .79388 .41526 L F
.36 .036 .274 r
.17384 .56324 m .1732 .56488 L .17108 .56529 L F
.377 .052 .282 r
.17569 .56411 m .17384 .56324 L .17645 .56322 L F
.17569 .56411 m .1732 .56488 L .17384 .56324 L F
.695 .613 .76 r
.56028 .58677 m .55736 .58959 L .55711 .58691 L F
.621 .149 .111 r
.55736 .58959 m .55775 .59001 L .55678 .59123 L F
.301 .072 .39 r
.45004 .61357 m .4478 .61652 L .44759 .61396 L F
.619 .947 .762 r
.47633 .58963 m .47735 .58823 L .47514 .5888 L F
.47633 .58963 m .47957 .5872 L .47735 .58823 L F
0 .563 .773 r
.19363 .65232 m .19565 .65251 L .19182 .652 L F
.356 .285 .638 r
.4321 .64383 m .43173 .64781 L .43423 .64598 L F
0 .42 .803 r
.43173 .64781 m .43397 .64834 L .43423 .64598 L F
.43173 .64781 m .43551 .64935 L .43397 .64834 L F
.452 .741 .99 r
.27358 .54388 m .27311 .54551 L .27151 .54409 L F
.27358 .54388 m .2753 .54529 L .27311 .54551 L F
0 .501 .757 r
.6671 .4041 m .66604 .40374 L .6635 .40331 L F
0 .321 .72 r
.6671 .4041 m .66805 .40214 L .66604 .40374 L F
.6671 .4041 m .6684 .40446 L .66805 .40214 L F
.362 .212 .539 r
.5789 .57145 m .57895 .57411 L .57695 .57427 L F
.007 0 .35 r
.57895 .57411 m .57705 .57789 L .57695 .57427 L F
.964 .913 .56 r
.76131 .40575 m .76107 .40873 L .76156 .40656 L F
.877 .988 .724 r
.76131 .40575 m .76156 .40656 L .76394 .40295 L F
.732 .299 .22 r
.51219 .59638 m .51363 .59846 L .51126 .59817 L F
.769 .295 .115 r
.51611 .59887 m .51363 .59846 L .51219 .59638 L F
.416 .477 .815 r
.78498 .40079 m .78621 .40391 L .78824 .40186 L F
.59 .574 .803 r
.78642 .40579 m .78824 .40186 L .78621 .40391 L F
.937 .706 .563 r
.44599 .59547 m .44729 .59849 L .44682 .59773 L F
.187 0 0 r
.44527 .59947 m .44682 .59773 L .44729 .59849 L F
.704 .627 .768 r
.44939 .59581 m .44729 .59849 L .44599 .59547 L F
.711 .632 .767 r
.49001 .58066 m .49212 .58352 L .49398 .58171 L F
.204 0 .276 r
.49347 .58532 m .49134 .58913 L .49347 .58801 L F
.724 .249 0 r
.49347 .58532 m .4937 .58591 L .49212 .58352 L F
.669 .561 .724 r
.49212 .58352 m .49431 .58449 L .49398 .58171 L F
.739 .371 .355 r
.49212 .58352 m .4937 .58591 L .49431 .58449 L F
.839 .686 .693 r
.6017 .47805 m .60305 .48173 L .60333 .47921 L F
.862 .722 .706 r
.59937 .48366 m .60296 .48416 L .60305 .48173 L F
.867 .681 .649 r
.59937 .48366 m .60084 .48725 L .60296 .48416 L F
.441 .202 .454 r
.48465 .61144 m .48664 .61286 L .48737 .61061 L F
.065 .629 .747 r
.46019 .56012 m .46291 .55999 L .46397 .56001 L F
.372 .839 .858 r
.46397 .56001 m .46516 .55928 L .46618 .55904 L F
.46397 .56001 m .46291 .55999 L .46516 .55928 L F
.619 .627 .837 r
.17227 .6466 m .17355 .64732 L .17585 .64678 L F
.72 .682 .812 r
.75022 .4271 m .75115 .42813 L .75311 .42721 L F
.963 .714 .511 r
.42123 .59556 m .42276 .59944 L .42075 .59818 L F
0 0 0 r
.41934 .60119 m .42121 .6008 L .42276 .59944 L F
.963 .704 .495 r
.42276 .59944 m .42121 .6008 L .42075 .59818 L F
.753 .651 .748 r
.42494 .59644 m .42276 .59944 L .42123 .59556 L F
.079 .064 .538 r
.78091 .40375 m .78173 .39934 L .77901 .40286 L F
.899 .713 .641 r
.77901 .40286 m .7804 .40649 L .78091 .40375 L F
.704 .486 .59 r
.5846 .47238 m .58818 .47242 L .58814 .46991 L F
.654 .462 .612 r
.58818 .47242 m .59073 .46952 L .58814 .46991 L F
0 0 0 r
.2219 .62883 m .21857 .63115 L .22034 .62992 L F
.599 .95 .896 r
.22034 .62992 m .21857 .63115 L .21707 .63131 L F
.117 0 0 r
.21943 .63056 m .22034 .62992 L .21923 .63053 L F
.22049 .63074 m .22034 .62992 L .21943 .63056 L F
0 0 0 r
.2224 .62848 m .2219 .62883 L .22034 .62992 L F
.22262 .62945 m .2224 .62848 L .22034 .62992 L F
.22262 .62945 m .22361 .62831 L .2224 .62848 L F
.207 0 .223 r
.17186 .56741 m .17108 .56529 L .1732 .56488 L F
.17186 .56741 m .1701 .56831 L .17108 .56529 L F
.233 0 0 r
.50132 .59779 m .50043 .59715 L .49872 .59762 L F
.50132 .59779 m .50302 .59703 L .50043 .59715 L F
.635 .297 .382 r
.68954 .40878 m .69062 .40657 L .68688 .40685 L F
.668 .3 .339 r
.69316 .40848 m .69062 .40657 L .68954 .40878 L F
.69316 .40848 m .69313 .40688 L .69062 .40657 L F
.263 0 0 r
.52711 .51552 m .52604 .51468 L .52458 .51605 L F
.52711 .51552 m .52872 .51466 L .52604 .51468 L F
0 0 0 r
.43217 .572 m .43016 .57481 L .4318 .57272 L F
.364 .276 .621 r
.43016 .57481 m .43217 .57708 L .4318 .57272 L F
.346 .545 .905 r
.79251 .39689 m .79081 .39842 L .79079 .39633 L F
.79251 .39689 m .79428 .39942 L .79081 .39842 L F
0 0 0 r
.16228 .57137 m .15927 .57386 L .16014 .57201 L F
.26 .203 .601 r
.25776 .57482 m .25918 .57421 L .25898 .57113 L F
.285 .263 .658 r
.25776 .57482 m .25979 .57682 L .25918 .57421 L F
.348 .271 .627 r
.25817 .57754 m .25979 .57682 L .25776 .57482 L F
.736 .875 .945 r
.50269 .52895 m .50186 .53049 L .50492 .52987 L F
.539 .011 0 r
.50492 .52987 m .50566 .53075 L .50269 .52895 L F
.50492 .52987 m .5068 .5317 L .50566 .53075 L F
.811 .799 .841 r
.50352 .52896 m .50566 .53075 L .50753 .52757 L F
0 0 0 r
.50295 .52916 m .50269 .52895 L .50566 .53075 L F
.811 .799 .841 r
.50295 .52916 m .50566 .53075 L .50352 .52896 L F
.539 .011 0 r
.5068 .5317 m .50712 .53201 L .50566 .53075 L F
0 0 0 r
.5737 .47884 m .57603 .47515 L .5739 .47586 L F
.5737 .47884 m .5742 .47858 L .57603 .47515 L F
.482 .549 .848 r
.19015 .62869 m .1882 .62899 L .18671 .62596 L F
.558 .565 .817 r
.19192 .63213 m .1882 .62899 L .19015 .62869 L F
.998 .854 .545 r
.53386 .53609 m .53286 .53532 L .53238 .53733 L F
.956 .64 .223 r
.53239 .53238 m .53286 .53532 L .53386 .53609 L F
.579 .596 .834 r
.44355 .6343 m .44278 .63754 L .44277 .63497 L F
.863 .922 .867 r
.67608 .44442 m .67731 .4408 L .67589 .44225 L F
.67608 .44442 m .67843 .44191 L .67731 .4408 L F
.294 0 .208 r
.55222 .49331 m .55398 .49478 L .55445 .49294 L F
.55222 .49331 m .55172 .49557 L .55398 .49478 L F
.802 .313 0 r
.49826 .54487 m .49668 .54396 L .49503 .5415 L F
.752 .255 .046 r
.49826 .54487 m .49717 .54585 L .49668 .54396 L F
.49826 .54487 m .50028 .54711 L .49717 .54585 L F
.63 .585 .785 r
.4318 .57272 m .43403 .57051 L .43217 .572 L F
.887 .569 .065 r
.4594 .57195 m .45989 .57436 L .45884 .57121 L F
.739 .362 .338 r
.68354 .4082 m .68688 .40685 L .68343 .40696 L F
.68354 .4082 m .68616 .40872 L .68688 .40685 L F
.656 .272 .306 r
.68616 .40872 m .68954 .40878 L .68688 .40685 L F
.916 .665 .544 r
.53152 .56146 m .53413 .56018 L .5313 .5593 L F
.53152 .56146 m .53359 .56248 L .53413 .56018 L F
.237 .297 .723 r
.43916 .60426 m .44175 .60662 L .44001 .60795 L F
.446 .701 .975 r
.44175 .60662 m .44246 .60812 L .44001 .60795 L F
.534 .295 .5 r
.44781 .64651 m .45075 .64368 L .44787 .64397 L F
.44781 .64651 m .45075 .64368 L .44787 .64397 L F
.688 .572 .719 r
.71281 .4101 m .71264 .41208 L .71046 .41343 L F
.584 .163 .209 r
.43793 .5622 m .44035 .56257 L .44208 .56054 L F
.387 0 .074 r
.44208 .56054 m .44035 .56257 L .44413 .56123 L F
.374 .034 .254 r
.44208 .56054 m .44413 .56123 L .44438 .5598 L F
.146 .477 .897 r
.26063 .53953 m .26003 .54069 L .25761 .53876 L F
.26063 .53953 m .26169 .54114 L .26003 .54069 L F
.915 .859 .771 r
.52775 .52585 m .53099 .52381 L .53015 .52321 L F
.52775 .52585 m .52935 .52717 L .53099 .52381 L F
.558 .934 .887 r
.53279 .52238 m .53015 .52321 L .53099 .52381 L F
.623 .625 .832 r
.64301 .42192 m .64403 .42521 L .64655 .42441 L F
0 0 .178 r
.56782 .56815 m .56929 .56429 L .56781 .56588 L F
0 .337 .815 r
.41161 .64811 m .4111 .64614 L .41056 .64808 L F
.978 .824 .623 r
.52726 .52834 m .52935 .52717 L .52775 .52585 L F
.52726 .52834 m .52844 .52963 L .52935 .52717 L F
.217 0 .117 r
.24782 .63918 m .24666 .63846 L .24864 .63787 L F
.24782 .63918 m .24569 .64009 L .24666 .63846 L F
.592 .658 .883 r
.17065 .64279 m .17227 .6466 L .17402 .64413 L F
.619 .627 .837 r
.17227 .6466 m .17585 .64678 L .17402 .64413 L F
.157 .042 .461 r
.50487 .59754 m .50535 .5962 L .50577 .59537 L F
.801 .525 .519 r
.5072 .59263 m .50577 .59537 L .50507 .59226 L F
0 .006 .516 r
.50507 .59226 m .50561 .59465 L .50611 .59404 L F
.50561 .59465 m .50577 .59537 L .50611 .59404 L F
.801 .525 .519 r
.50884 .59292 m .50577 .59537 L .5072 .59263 L F
.789 .619 .67 r
.50823 .59196 m .5075 .59235 L .50611 .59404 L F
.613 .108 .028 r
.49736 .59125 m .50344 .59282 L .49821 .59217 L F
.529 .3 .511 r
.49836 .59353 m .49821 .59217 L .50344 .59282 L F
.31 .793 .73 r
.50348 .59165 m .49836 .59353 L .50344 .59282 L F
.858 .996 .812 r
.50344 .59282 m .50295 .59373 L .50348 .59165 L F
.717 .887 .959 r
.50348 .59165 m .50295 .59373 L .50507 .59226 L F
.50348 .59165 m .50295 .59373 L .50507 .59226 L F
0 .006 .516 r
.50507 .59226 m .50611 .59404 L .50348 .59165 L F
0 0 .491 r
.49836 .59353 m .49872 .59762 L .49791 .59484 L F
.49851 .59528 m .49977 .59652 L .49872 .59762 L F
.49836 .59353 m .49977 .59652 L .49851 .59528 L F
.471 0 0 r
.49977 .59652 m .50227 .59748 L .50075 .59749 L F
.602 .262 .366 r
.49872 .59762 m .5013 .59966 L .50132 .59779 L F
.1 .289 .768 r
.49872 .59762 m .5013 .59966 L .49977 .59652 L F
.471 0 0 r
.49977 .59652 m .50075 .59749 L .49852 .59749 L F
.31 .793 .73 r
.50348 .59165 m .50239 .59198 L .49836 .59353 L F
.50239 .59198 m .50024 .59272 L .49836 .59353 L F
.50093 .59243 m .50064 .59253 L .49836 .59353 L F
.623 .521 .718 r
.50078 .59247 m .49977 .59652 L .49836 .59353 L F
.643 .264 .312 r
.49845 .59334 m .49836 .59504 L .49943 .59342 L F
.586 .349 .524 r
.49821 .59217 m .49791 .59484 L .49518 .59497 L F
.529 .3 .511 r
.49836 .59353 m .49791 .59484 L .49821 .59217 L F
.643 .264 .312 r
.49603 .59313 m .49692 .59386 L .49845 .59334 L F
.49692 .59386 m .49836 .59504 L .49845 .59334 L F
.31 .793 .73 r
.50239 .59198 m .50093 .59243 L .50024 .59272 L F
.50093 .59243 m .50078 .59247 L .50064 .59253 L F
.689 .568 .714 r
.49603 .59313 m .49845 .59334 L .49847 .59019 L F
.49845 .59334 m .49943 .59342 L .49931 .59302 L F
.49845 .59334 m .49931 .59302 L .49847 .59019 L F
.819 .407 .265 r
.50348 .59165 m .50611 .59404 L .50078 .59247 L F
.23 .324 .754 r
.50324 .59461 m .50078 .59247 L .50276 .59306 L F
.50324 .59461 m .50276 .59306 L .50611 .59404 L F
.809 .96 .91 r
.50886 .59564 m .50687 .59788 L .50487 .59754 L F
.662 .391 .499 r
.50759 .59981 m .50541 .59799 L .50687 .59788 L F
.50541 .59799 m .50487 .59754 L .50531 .59761 L F
.50541 .59799 m .50531 .59761 L .50687 .59788 L F
.809 .96 .91 r
.50886 .59564 m .50487 .59754 L .50577 .59537 L F
.662 .391 .499 r
.50759 .59981 m .50479 .60008 L .50487 .59754 L F
.50759 .59981 m .50479 .60008 L .50487 .59754 L F
0 0 .107 r
.50558 .59868 m .50618 .5988 L .50681 .59649 L F
.50479 .60008 m .50572 .59923 L .50558 .59868 L F
.50572 .59923 m .50618 .5988 L .50558 .59868 L F
.359 0 0 r
.50487 .59754 m .50302 .59703 L .50132 .59779 L F
.25 .065 .424 r
.50487 .59754 m .50479 .60008 L .50293 .60073 L F
.76 .474 .499 r
.5013 .59966 m .50487 .59754 L .50132 .59779 L F
.5013 .59966 m .50479 .60008 L .50487 .59754 L F
.157 .042 .461 r
.50535 .5962 m .50611 .59404 L .50577 .59537 L F
.801 .525 .519 r
.50884 .59292 m .50886 .59564 L .50577 .59537 L F
.157 .042 .461 r
.50487 .59754 m .50681 .59649 L .50611 .59404 L F
0 0 .107 r
.50479 .60008 m .50681 .59649 L .50487 .59754 L F
.623 .521 .718 r
.50078 .59247 m .50278 .59625 L .49977 .59652 L F
.484 .082 .202 r
.50278 .59625 m .50227 .59748 L .49977 .59652 L F
.23 .324 .754 r
.50324 .59461 m .50278 .59625 L .50078 .59247 L F
.781 .665 .736 r
.50324 .59461 m .50227 .59748 L .50278 .59625 L F
.50324 .59461 m .50618 .5988 L .50227 .59748 L F
0 0 .201 r
.50324 .59461 m .50336 .59673 L .5037 .59611 L F
.789 .619 .67 r
.5075 .59235 m .50324 .59461 L .50611 .59404 L F
.587 .097 .057 r
.50736 .59496 m .50952 .5946 L .50803 .59545 L F
.50611 .59404 m .50719 .59422 L .50736 .59496 L F
.50719 .59422 m .50952 .5946 L .50736 .59496 L F
0 0 .171 r
.50681 .59649 m .50618 .5988 L .50761 .59603 L F
.50754 .59572 m .50761 .59603 L .50804 .59518 L F
.50681 .59649 m .50761 .59603 L .50754 .59572 L F
.246 .239 .653 r
.50611 .59404 m .50803 .59545 L .50806 .59492 L F
.425 0 0 r
.50806 .59492 m .50952 .5946 L .50611 .59404 L F
.568 .521 .763 r
.50823 .59196 m .50806 .59492 L .50999 .59252 L F
.50806 .59492 m .50803 .59545 L .50834 .59498 L F
.50806 .59492 m .50834 .59498 L .50999 .59252 L F
.425 0 0 r
.50826 .59501 m .50834 .59498 L .50806 .59492 L F
.50834 .59498 m .50952 .5946 L .50806 .59492 L F
.832 .996 .765 r
.50803 .59545 m .50952 .5946 L .50834 .59498 L F
.425 0 0 r
.50836 .59506 m .50952 .5946 L .50826 .59501 L F
.832 .996 .765 r
.50834 .59498 m .50952 .5946 L .50999 .59252 L F
.246 .239 .653 r
.50611 .59404 m .50806 .59492 L .50823 .59196 L F
.425 0 0 r
.50804 .59518 m .50836 .59506 L .50611 .59404 L F
.50804 .59518 m .50611 .59404 L .50681 .59649 L F
.789 .619 .67 r
.50823 .59196 m .50804 .59518 L .50324 .59461 L F
.782 .666 .735 r
.50804 .59518 m .50618 .5988 L .50324 .59461 L F
0 0 .201 r
.50324 .59461 m .5037 .59611 L .5052 .59344 L F
.379 .166 .459 r
.5739 .47586 m .57603 .47515 L .57608 .47289 L F
.727 .947 .952 r
.41394 .64967 m .41557 .65027 L .4156 .64855 L F
.906 .92 .816 r
.41456 .65261 m .4156 .64855 L .41557 .65027 L F
.78 .492 .499 r
.47304 .60999 m .4798 .61141 L .4762 .60702 L F
.608 .577 .794 r
.4762 .60702 m .47932 .60938 L .47935 .60497 L F
.414 .426 .764 r
.4762 .60702 m .4798 .61141 L .47967 .6107 L F
.46 0 0 r
.50154 .54826 m .50264 .54924 L .50028 .54711 L F
.50154 .54826 m .50419 .54988 L .50264 .54924 L F
.465 0 0 r
.50575 .55051 m .50419 .54988 L .50154 .54826 L F
.267 .364 .777 r
.41659 .59419 m .41775 .59757 L .41524 .59647 L F
.404 .283 .601 r
.41775 .59757 m .41579 .59913 L .41524 .59647 L F
.753 .651 .748 r
.42494 .59644 m .42123 .59556 L .42365 .59511 L F
.755 .417 .411 r
.42365 .59511 m .42731 .59589 L .42494 .59644 L F
0 0 0 r
.54212 .50542 m .54005 .50652 L .53897 .50763 L F
.243 0 0 r
.41646 .60191 m .41804 .6022 L .41934 .60119 L F
0 0 0 r
.41934 .60119 m .41804 .6022 L .42121 .6008 L F
.67 .611 .78 r
.74327 .41497 m .74177 .41833 L .74186 .41614 L F
0 0 0 r
.74327 .41497 m .74186 .41614 L .74187 .41629 L F
.253 .393 .811 r
.79165 .4141 m .79377 .41313 L .79051 .41254 L F
.79165 .4141 m .79388 .41526 L .79377 .41313 L F
.142 0 0 r
.47161 .58092 m .47016 .58143 L .46738 .58138 L F
.263 .755 .676 r
.47208 .58071 m .47161 .58092 L .47485 .58139 L F
.47208 .58071 m .47016 .58143 L .47161 .58092 L F
.131 .561 .923 r
.15709 .6051 m .1584 .60725 L .15659 .60631 L F
.15709 .6051 m .16071 .60788 L .1584 .60725 L F
0 0 0 r
.20819 .69719 m .20636 .69798 L .20435 .70013 L F
.19718 .54149 m .19889 .54126 L .20049 .54084 L F
.419 0 0 r
.19675 .54133 m .20077 .54101 L .19889 .54126 L F
0 0 0 r
.20192 .54081 m .20115 .54098 L .20262 .54071 L F
.19889 .54126 m .20115 .54098 L .20192 .54081 L F
.419 0 0 r
.20077 .54101 m .20115 .54098 L .19889 .54126 L F
0 0 0 r
.19669 .54158 m .19889 .54126 L .19718 .54149 L F
.419 0 0 r
.19675 .54133 m .19903 .54173 L .20115 .54098 L F
.585 .941 .803 r
.20115 .54098 m .19903 .54173 L .1996 .54133 L F
.086 0 0 r
.20049 .54084 m .19889 .54126 L .20262 .54071 L F
.585 .941 .803 r
.20115 .54098 m .1996 .54133 L .20111 .54026 L F
.463 .268 .529 r
.56348 .57187 m .56526 .5738 L .56575 .57137 L F
.56348 .57187 m .56329 .57446 L .56526 .5738 L F
.665 .205 .151 r
.677 .40573 m .6797 .40782 L .68099 .40624 L F
.632 .166 .129 r
.6797 .40782 m .68354 .4082 L .68099 .40624 L F
.632 .166 .128 r
.68099 .40624 m .68354 .4082 L .68343 .40696 L F
.422 .731 .99 r
.67612 .43274 m .67383 .43294 L .67275 .4316 L F
.691 .476 .591 r
.69316 .40848 m .69579 .40616 L .69313 .40688 L F
.772 .703 .786 r
.76525 .37963 m .76285 .38262 L .76166 .37906 L F
.545 .376 .602 r
.76525 .37963 m .76587 .38199 L .76285 .38262 L F
.393 .436 .787 r
.76616 .38416 m .76285 .38262 L .76587 .38199 L F
.574 .294 .453 r
.4905 .59609 m .4877 .59848 L .48786 .59602 L F
.4905 .59609 m .49019 .59823 L .4877 .59848 L F
.378 .126 .401 r
.49237 .59716 m .4905 .59609 L .49286 .59551 L F
.49237 .59716 m .49019 .59823 L .4905 .59609 L F
.735 .44 .481 r
.57672 .49928 m .57483 .50193 L .57317 .49948 L F
.717 .417 .468 r
.57886 .50198 m .57672 .49928 L .57872 .49962 L F
.57886 .50198 m .57483 .50193 L .57672 .49928 L F
.853 .403 .008 r
.51128 .58387 m .51229 .58575 L .51373 .5867 L F
.839 .415 0 r
.51229 .58575 m .51369 .58883 L .51373 .5867 L F
.527 .336 .564 r
.56272 .49931 m .56026 .50232 L .56022 .49987 L F
.962 .71 .51 r
.5202 .6168 m .52003 .61941 L .51866 .61815 L F
.975 .921 .667 r
.51941 .61585 m .51915 .61717 L .5202 .6168 L F
.193 0 0 r
.50713 .55088 m .50419 .54988 L .50575 .55051 L F
.802 .639 .68 r
.48013 .57782 m .47576 .58002 L .47622 .57778 L F
.48013 .57782 m .47813 .58035 L .47576 .58002 L F
.665 .441 .57 r
.47813 .58035 m .48037 .5806 L .48013 .57782 L F
.601 .713 .923 r
.66164 .44884 m .66427 .44817 L .66067 .44681 L F
.181 .665 .927 r
.24742 .55729 m .24581 .55656 L .2436 .55643 L F
.24742 .55729 m .24581 .55656 L .2436 .55643 L F
.329 .755 .974 r
.24742 .55729 m .2479 .55633 L .24581 .55656 L F
.24742 .55729 m .24973 .55719 L .2479 .55633 L F
.24742 .55729 m .2479 .55633 L .24581 .55656 L F
.24742 .55729 m .24973 .55719 L .2479 .55633 L F
.714 .635 .768 r
.50687 .59788 m .51068 .5981 L .50861 .59855 L F
.221 0 0 r
.24422 .53875 m .24216 .53877 L .24458 .53893 L F
.312 0 0 r
.24337 .53833 m .24422 .53875 L .24591 .53953 L F
.203 0 0 r
.24422 .53875 m .24799 .53907 L .24591 .53953 L F
.221 0 0 r
.24422 .53875 m .24458 .53893 L .2461 .53903 L F
.312 0 0 r
.24316 .53823 m .24422 .53875 L .24337 .53833 L F
.206 .724 .871 r
.24591 .53953 m .24799 .53907 L .24964 .53944 L F
.414 .177 .443 r
.49827 .52989 m .5006 .52991 L .5006 .52697 L F
.699 .859 .959 r
.50258 .52576 m .5006 .52697 L .49901 .52576 L F
0 0 .08 r
.5006 .52697 m .5006 .52932 L .50081 .52809 L F
.5006 .52932 m .5006 .52991 L .50064 .52959 L F
.5006 .52932 m .50064 .52959 L .50081 .52809 L F
.763 .912 .94 r
.50269 .52895 m .49964 .53065 L .50186 .53049 L F
.408 .144 .398 r
.49827 .52989 m .49964 .53065 L .5006 .52991 L F
0 0 0 r
.49827 .52989 m .49799 .53082 L .49964 .53065 L F
.332 0 0 r
.49799 .53082 m .49964 .53065 L .5006 .52991 L F
.787 .971 .915 r
.49964 .53065 m .49799 .53082 L .5006 .52991 L F
.332 0 0 r
.49799 .53082 m .5006 .52991 L .50081 .52809 L F
.857 .913 .869 r
.5006 .52991 m .49799 .53082 L .50081 .52809 L F
.5006 .52991 m .49799 .53082 L .50081 .52809 L F
.332 0 0 r
.49799 .53082 m .50269 .52895 L .49964 .53065 L F
.50066 .52976 m .50201 .5304 L .50269 .52895 L F
.49799 .53082 m .50077 .53053 L .50066 .52976 L F
.50077 .53053 m .50201 .5304 L .50066 .52976 L F
0 0 .08 r
.5006 .52697 m .50081 .52809 L .49901 .52576 L F
.417 .169 .428 r
.79878 .43308 m .79894 .43568 L .79584 .43607 L F
.51 .301 .532 r
.79894 .43568 m .79631 .43894 L .79584 .43607 L F
.391 .103 .351 r
.25435 .6318 m .25366 .63453 L .25157 .6347 L F
.389 .101 .35 r
.2557 .6339 m .25435 .6318 L .25647 .63124 L F
.2557 .6339 m .25366 .63453 L .25435 .6318 L F
.913 .745 .661 r
.47079 .61438 m .46802 .61527 L .46978 .61247 L F
.47079 .61438 m .46975 .61669 L .46802 .61527 L F
.778 .566 .613 r
.473 .61674 m .46975 .61669 L .47079 .61438 L F
.82 .678 .706 r
.6017 .47805 m .59959 .48115 L .60305 .48173 L F
.862 .722 .706 r
.59937 .48366 m .60305 .48173 L .59959 .48115 L F
0 0 0 r
.75588 .39225 m .753 .39395 L .75493 .39371 L F
.115 0 .082 r
.7575 .39112 m .75588 .39225 L .75493 .39371 L F
.27 0 .291 r
.45427 .60177 m .45607 .60121 L .45659 .59867 L F
.47 .159 .357 r
.45659 .59867 m .4581 .60029 L .45822 .59913 L F
.45659 .59867 m .45607 .60121 L .4581 .60029 L F
.518 .664 .928 r
.16572 .64093 m .16711 .63949 L .16476 .6394 L F
.16572 .64093 m .16775 .64089 L .16711 .63949 L F
.769 .53 .572 r
.42381 .63469 m .42267 .63736 L .42515 .63475 L F
.697 .424 .506 r
.42515 .63475 m .42267 .63736 L .42671 .63728 L F
0 0 .328 r
.51369 .58883 m .5151 .59171 L .51558 .59279 L F
.662 .224 0 r
.51598 .59376 m .51558 .59279 L .5151 .59171 L F
.51598 .59376 m .517 .59512 L .51558 .59279 L F
.762 .655 .744 r
.69185 .41857 m .69561 .41878 L .69326 .42182 L F
.638 .851 .981 r
.73146 .4166 m .73009 .41867 L .73262 .41802 L F
.73146 .4166 m .72902 .41753 L .73009 .41867 L F
.754 .259 .051 r
.49668 .54396 m .49282 .54146 L .49503 .5415 L F
.559 .026 0 r
.24799 .53907 m .25113 .53921 L .24964 .53944 L F
.007 0 .35 r
.57895 .57411 m .57878 .5765 L .57705 .57789 L F
0 0 .278 r
.57878 .5765 m .57703 .5803 L .57705 .57789 L F
.46 .57 .879 r
.17935 .70372 m .18005 .70374 L .17949 .70396 L F
0 0 0 r
.17949 .70396 m .18005 .70374 L .17931 .70412 L F
.579 .35 .533 r
.20877 .70995 m .20854 .71248 L .20622 .71266 L F
.21 .046 .428 r
.20974 .71247 m .20854 .71248 L .20877 .70995 L F
.596 .09 .02 r
.20494 .70931 m .20893 .71018 L .20877 .70995 L F
.148 .085 .524 r
.21028 .70579 m .21021 .70942 L .20877 .70995 L F
.21 .046 .428 r
.20974 .71247 m .20877 .70995 L .21021 .70942 L F
.148 .085 .524 r
.21028 .70579 m .20877 .70995 L .20893 .71018 L F
.72 .508 .602 r
.48786 .59602 m .484 .59829 L .4846 .59572 L F
.48786 .59602 m .4877 .59848 L .484 .59829 L F
.487 .299 .551 r
.28933 .58038 m .28919 .58293 L .2871 .58108 L F
.251 .288 .706 r
.2871 .58108 m .28919 .58293 L .28796 .58335 L F
.756 .737 .215 r
.5767 .53774 m .5759 .54194 L .5761 .54009 L F
0 0 0 r
.57511 .54409 m .5761 .54009 L .5759 .54194 L F
.736 .784 .891 r
.73887 .4178 m .74177 .41833 L .74166 .41722 L F
.73887 .4178 m .73975 .41883 L .74177 .41833 L F
.67 .611 .78 r
.74327 .41497 m .74552 .41606 L .74177 .41833 L F
.786 .682 .749 r
.74327 .41497 m .74187 .41629 L .74006 .41138 L F
.463 .643 .935 r
.74067 .41536 m .74166 .41722 L .74299 .41525 L F
.678 .936 .967 r
.74299 .41525 m .74166 .41722 L .74255 .41584 L F
.208 .432 .858 r
.74177 .41833 m .74255 .41584 L .74166 .41722 L F
.74177 .41833 m .74533 .42019 L .74255 .41584 L F
.66 .469 .616 r
.59073 .46952 m .59423 .46948 L .59419 .46686 L F
.699 .534 .66 r
.59423 .46948 m .59672 .46661 L .59419 .46686 L F
.389 .318 .655 r
.71948 .402 m .71711 .40412 L .71726 .4003 L F
.536 .561 .827 r
.71948 .402 m .7195 .40404 L .71711 .40412 L F
.35 0 0 r
.44246 .60812 m .44491 .60879 L .44596 .60795 L F
.718 .19 0 r
.44175 .60662 m .44491 .60879 L .44246 .60812 L F
.44175 .60662 m .44419 .60921 L .44491 .60879 L F
.786 .949 .611 r
.44491 .60879 m .44419 .60921 L .44522 .60761 L F
.735 .404 .421 r
.44412 .60943 m .44491 .60879 L .44522 .60761 L F
.44308 .61116 m .44491 .60879 L .44412 .60943 L F
.35 0 0 r
.44596 .60795 m .44491 .60879 L .44617 .60794 L F
.712 .198 0 r
.44491 .60879 m .4484 .61 L .44617 .60794 L F
.585 .316 .475 r
.44617 .60794 m .4484 .61 L .44871 .60777 L F
.726 .28 0 r
.76844 .43697 m .76839 .43744 L .7675 .43557 L F
.76844 .43697 m .76933 .43857 L .76839 .43744 L F
.045 0 .139 r
.22776 .65811 m .22891 .65737 L .23171 .65895 L F
.711 .263 .186 r
.23171 .65895 m .22738 .65838 L .22903 .66158 L F
.23171 .65895 m .22993 .66058 L .22738 .65838 L F
.235 .704 .943 r
.22891 .65737 m .23402 .6584 L .23171 .65895 L F
.22891 .65737 m .23218 .65757 L .23402 .6584 L F
.598 .042 0 r
.22738 .65838 m .22993 .66058 L .22779 .65931 L F
.448 .721 .983 r
.2302 .65626 m .23218 .65757 L .22891 .65737 L F
.831 .824 .841 r
.22779 .65931 m .22975 .65683 L .22891 .65737 L F
.22975 .65683 m .2302 .65626 L .22891 .65737 L F
.045 0 .139 r
.22676 .6579 m .22891 .65737 L .22776 .65811 L F
.22676 .6579 m .22738 .65838 L .22891 .65737 L F
0 0 .398 r
.67307 .44002 m .67324 .44295 L .67429 .44187 L F
.845 .922 .883 r
.67423 .442 m .67731 .4408 L .67438 .44165 L F
0 0 .398 r
.67431 .44181 m .67429 .44187 L .67433 .44183 L F
.67307 .44002 m .67429 .44187 L .67431 .44181 L F
.845 .922 .883 r
.67438 .44165 m .67731 .4408 L .67652 .44018 L F
.657 .645 .826 r
.67426 .44181 m .67192 .44351 L .67013 .44083 L F
.845 .922 .883 r
.67392 .44213 m .67423 .442 L .67434 .44175 L F
.657 .645 .826 r
.67433 .44183 m .67396 .44209 L .67426 .44181 L F
.67396 .44209 m .67192 .44351 L .67426 .44181 L F
.845 .922 .883 r
.67337 .44234 m .67392 .44213 L .67438 .44165 L F
.67392 .44213 m .67434 .44175 L .67438 .44165 L F
0 0 .398 r
.67307 .44002 m .67433 .44183 L .67108 .43988 L F
.914 .725 .634 r
.47148 .56839 m .47098 .57185 L .47271 .57187 L F
.806 .383 .243 r
.47098 .57185 m .47127 .5733 L .47271 .57187 L F
.264 .24 .643 r
.47271 .57187 m .47383 .56781 L .47148 .56839 L F
.47271 .57187 m .47456 .57121 L .47383 .56781 L F
.695 .479 .59 r
.47127 .5733 m .47456 .57121 L .47271 .57187 L F
.989 .727 .425 r
.6587 .40675 m .65728 .40541 L .65711 .40266 L F
0 0 0 r
.66077 .40584 m .65897 .40903 L .6587 .40675 L F
.617 .832 .982 r
.66077 .40584 m .65728 .40541 L .6587 .40675 L F
0 0 .082 r
.57382 .55001 m .57166 .5538 L .57326 .55236 L F
0 0 .091 r
.57166 .5538 m .57168 .55567 L .57326 .55236 L F
.57166 .5538 m .57121 .5562 L .57168 .55567 L F
.548 .128 .196 r
.45076 .59174 m .44703 .59212 L .44859 .5905 L F
.494 .211 .413 r
.45131 .58977 m .45076 .59174 L .44859 .5905 L F
.476 .309 .575 r
.28138 .59866 m .28139 .60141 L .27918 .60193 L F
.289 .045 .36 r
.28139 .60141 m .279 .60429 L .27918 .60193 L F
.228 .446 .864 r
.191 .72407 m .19339 .72587 L .19238 .72399 L F
.838 .872 .868 r
.19327 .72249 m .18973 .72415 L .191 .72407 L F
.883 .99 .745 r
.19327 .72076 m .19327 .72249 L .191 .72407 L F
.674 .874 .494 r
.19327 .72076 m .191 .72407 L .19172 .72274 L F
.228 .446 .864 r
.191 .72407 m .19238 .72399 L .19172 .72274 L F
.838 .872 .868 r
.18973 .72415 m .18914 .72443 L .191 .72407 L F
.853 .995 .828 r
.19557 .71998 m .19327 .72249 L .19327 .72076 L F
.477 .519 .822 r
.44297 .59352 m .44323 .58828 L .44096 .5889 L F
.328 0 .089 r
.42734 .58203 m .42948 .58258 L .42974 .58164 L F
0 0 .438 r
.26043 .55603 m .26018 .55274 L .25918 .55355 L F
.678 .592 .753 r
.26018 .55274 m .26139 .55851 L .264 .55558 L F
.179 0 .273 r
.26139 .55851 m .26157 .55871 L .264 .55558 L F
0 0 .438 r
.26043 .55603 m .26139 .55851 L .26063 .5549 L F
.499 0 0 r
.26017 .55842 m .26139 .55851 L .26043 .55603 L F
.876 .886 .837 r
.264 .55558 m .26157 .55871 L .26007 .55765 L F
.264 .55558 m .26141 .55694 L .26276 .55772 L F
.26141 .55694 m .26007 .55765 L .2617 .55769 L F
.26141 .55694 m .2617 .55769 L .26276 .55772 L F
0 0 .438 r
.26027 .55397 m .26063 .5549 L .26018 .55274 L F
.26043 .55603 m .26063 .5549 L .26027 .55397 L F
.574 .228 .345 r
.56641 .49982 m .56253 .5022 L .56272 .49931 L F
.56641 .49982 m .56593 .50207 L .56253 .5022 L F
.543 .2 .337 r
.56954 .50147 m .56641 .49982 L .56883 .49942 L F
.56954 .50147 m .56593 .50207 L .56641 .49982 L F
.588 .608 .84 r
.19411 .63147 m .19192 .63213 L .19015 .62869 L F
.557 .772 .978 r
.2081 .65025 m .21201 .6509 L .21021 .64947 L F
.685 .934 .967 r
.21201 .6509 m .21229 .64956 L .21021 .64947 L F
.21201 .6509 m .21419 .64984 L .21229 .64956 L F
.807 .674 .717 r
.69185 .41857 m .69326 .42182 L .68978 .42124 L F
.344 .054 .321 r
.79878 .43308 m .80148 .43064 L .80142 .43206 L F
.415 .167 .427 r
.80142 .43206 m .79894 .43568 L .79878 .43308 L F
.525 .386 .633 r
.47227 .61904 m .46975 .61669 L .473 .61674 L F
.653 .913 .603 r
.47421 .61505 m .473 .61674 L .47566 .61379 L F
.195 0 .158 r
.47427 .61809 m .473 .61674 L .47421 .61505 L F
.47427 .61809 m .47227 .61904 L .473 .61674 L F
.525 .316 .539 r
.24283 .60769 m .24516 .60716 L .24529 .60486 L F
.485 .283 .531 r
.24529 .60486 m .24732 .60654 L .24736 .60435 L F
.24529 .60486 m .24516 .60716 L .24732 .60654 L F
.386 .171 .461 r
.57608 .47289 m .57851 .47409 L .57858 .4726 L F
.57608 .47289 m .57603 .47515 L .57851 .47409 L F
.776 .658 .732 r
.65426 .42406 m .65881 .42177 L .65776 .41986 L F
.65426 .42406 m .65677 .42467 L .65881 .42177 L F
.774 .753 .834 r
.65776 .41986 m .65881 .42177 L .66027 .41807 L F
.762 .579 .006 r
.77149 .43199 m .77218 .43179 L .77103 .43137 L F
.726 .964 .697 r
.77218 .43179 m .77107 .43372 L .77318 .43149 L F
0 0 .344 r
.77218 .43179 m .77145 .43565 L .77107 .43372 L F
.762 .579 .006 r
.77215 .43288 m .77218 .43179 L .77149 .43199 L F
.726 .964 .697 r
.77218 .43179 m .77318 .43149 L .77351 .43114 L F
.447 .852 .671 r
.77485 .43007 m .77351 .43114 L .77596 .43008 L F
.77485 .43007 m .77218 .43179 L .77351 .43114 L F
0 0 .296 r
.47932 .60938 m .47967 .6107 L .48016 .60804 L F
.72 .682 .812 r
.75022 .4271 m .75311 .42721 L .75266 .42392 L F
.838 .81 .824 r
.75266 .42392 m .75311 .42721 L .7556 .42431 L F
.704 .204 0 r
.77244 .44178 m .76933 .43857 L .77219 .43977 L F
.368 .431 .796 r
.77426 .43794 m .77525 .4413 L .77219 .43977 L F
.842 .446 .295 r
.51611 .59887 m .5146 .60037 L .51363 .59846 L F
.52 .538 .815 r
.517 .59512 m .51802 .59826 L .51611 .59887 L F
.163 .316 .773 r
.40413 .63492 m .40523 .63811 L .40641 .63656 L F
0 0 .528 r
.40523 .63811 m .40682 .63913 L .40641 .63656 L F
.40523 .63811 m .40587 .64059 L .40682 .63913 L F
.802 .626 .663 r
.23178 .64663 m .23139 .64738 L .23511 .6439 L F
.23178 .64663 m .23511 .6439 L .23327 .64597 L F
.597 .204 .269 r
.23677 .64583 m .23511 .6439 L .23731 .6434 L F
.23677 .64583 m .23327 .64597 L .23511 .6439 L F
.239 .755 .83 r
.20661 .69912 m .20819 .69719 L .20638 .69931 L F
.449 0 .004 r
.21056 .69682 m .20893 .69628 L .20819 .69719 L F
.239 .755 .83 r
.20956 .69674 m .21056 .69682 L .20945 .697 L F
.20956 .69674 m .20945 .697 L .20819 .69719 L F
.051 0 .157 r
.20956 .69674 m .20999 .69815 L .2097 .69645 L F
.978 .681 .327 r
.2092 .69364 m .21056 .69682 L .20956 .69674 L F
.051 0 .157 r
.20956 .69674 m .2097 .69645 L .20943 .69491 L F
.239 .755 .83 r
.20956 .69674 m .20819 .69719 L .20661 .69912 L F
.449 0 .004 r
.20893 .69628 m .20848 .69613 L .20819 .69719 L F
.29 .339 .74 r
.28792 .55701 m .29018 .55873 L .28872 .5593 L F
.538 .502 .764 r
.29018 .55873 m .28894 .56319 L .28872 .5593 L F
.035 0 0 r
.17361 .54828 m .17382 .54904 L .17574 .54748 L F
.17361 .54828 m .17171 .54969 L .17382 .54904 L F
.381 .189 .491 r
.25219 .59271 m .2541 .59209 L .25429 .58967 L F
.468 .292 .558 r
.25188 .5953 m .2541 .59209 L .25219 .59271 L F
.205 0 .206 r
.15437 .57492 m .15169 .57775 L .15181 .57758 L F
.574 .619 .86 r
.45007 .62588 m .45078 .62105 L .44917 .62108 L F
.45007 .62588 m .45242 .62537 L .45078 .62105 L F
.938 .905 .763 r
.59467 .51434 m .59774 .51219 L .59658 .51126 L F
.59467 .51434 m .59697 .51358 L .59774 .51219 L F
.506 .649 .921 r
.42454 .66046 m .42372 .66226 L .42263 .65977 L F
.972 .847 .66 r
.42372 .66226 m .42211 .66147 L .42216 .65924 L F
.837 .588 .564 r
.42064 .65753 m .42228 .65876 L .42445 .65795 L F
.681 .943 .962 r
.42445 .65795 m .42386 .65854 L .42271 .6586 L F
.42386 .65854 m .42263 .65977 L .42223 .65877 L F
.837 .588 .564 r
.4222 .6587 m .42223 .65877 L .42228 .65876 L F
.681 .943 .962 r
.42386 .65854 m .42223 .65877 L .42217 .65863 L F
.506 .649 .921 r
.42454 .66046 m .42263 .65977 L .42445 .65795 L F
.837 .588 .564 r
.42228 .65876 m .42454 .66046 L .42445 .65795 L F
.681 .943 .962 r
.42445 .65795 m .42271 .6586 L .42217 .65863 L F
.837 .588 .564 r
.42228 .65876 m .42291 .66031 L .42454 .66046 L F
.42223 .65877 m .42291 .66031 L .42228 .65876 L F
.972 .847 .66 r
.42233 .659 m .42223 .65877 L .42263 .65977 L F
.837 .588 .564 r
.42064 .65753 m .42207 .65929 L .4222 .6587 L F
.972 .847 .66 r
.42372 .66226 m .42233 .659 L .42263 .65977 L F
.42372 .66226 m .42216 .65924 L .42233 .659 L F
.837 .588 .564 r
.42207 .65929 m .42291 .66031 L .42238 .65912 L F
.42207 .65929 m .42238 .65912 L .4222 .6587 L F
.907 .796 .727 r
.42216 .65924 m .42211 .66147 L .42057 .66009 L F
.837 .588 .564 r
.42064 .65753 m .42057 .66009 L .42151 .66018 L F
.42064 .65753 m .42151 .66018 L .4221 .65932 L F
.907 .796 .727 r
.42217 .65863 m .42216 .65924 L .42057 .66009 L F
.972 .847 .66 r
.42233 .659 m .42217 .65863 L .42223 .65877 L F
.42233 .659 m .42216 .65924 L .42217 .65863 L F
.837 .588 .564 r
.4221 .65932 m .42151 .66018 L .42291 .66031 L F
.506 .649 .921 r
.42454 .66046 m .42553 .66183 L .42372 .66226 L F
.749 .931 .948 r
.42454 .66046 m .42372 .66226 L .42553 .66183 L F
.42454 .66046 m .42211 .66147 L .42372 .66226 L F
.389 .155 .433 r
.42553 .66183 m .425 .66372 L .42372 .66226 L F
.61 .627 .843 r
.80283 .42709 m .80148 .43064 L .80041 .42737 L F
.80283 .42709 m .80418 .43023 L .80148 .43064 L F
.477 .128 .295 r
.80148 .43064 m .80421 .43169 L .80142 .43206 L F
.80148 .43064 m .80418 .43023 L .80421 .43169 L F
.68 .565 .718 r
.71519 .40931 m .71264 .41208 L .71281 .4101 L F
.627 .226 .263 r
.77342 .42765 m .77438 .42779 L .77473 .42647 L F
.91 .77 .282 r
.77473 .42647 m .775 .4283 L .77505 .42527 L F
.609 .548 .761 r
.77507 .42453 m .775 .4283 L .77781 .42504 L F
0 0 .529 r
.77473 .42647 m .77596 .43008 L .775 .4283 L F
.267 .374 .787 r
.77473 .42647 m .77747 .42823 L .77596 .43008 L F
.627 .226 .263 r
.77438 .42779 m .77747 .42823 L .77473 .42647 L F
.91 .77 .282 r
.77473 .42647 m .77505 .42527 L .77507 .42453 L F
.403 .855 .809 r
.70696 .4005 m .70485 .40142 L .70422 .40299 L F
.718 .461 .536 r
.2393 .60997 m .24209 .60994 L .24283 .60769 L F
.465 .171 .381 r
.24458 .6097 m .24283 .60769 L .24209 .60994 L F
.24458 .6097 m .24516 .60716 L .24283 .60769 L F
.205 0 .206 r
.15437 .57492 m .15353 .57688 L .15169 .57775 L F
.339 .023 .274 r
.15564 .57625 m .15437 .57492 L .15632 .57418 L F
.15564 .57625 m .15353 .57688 L .15437 .57492 L F
.846 .922 .882 r
.67731 .4408 m .67843 .44191 L .68101 .4393 L F
.297 .783 .716 r
.47819 .61366 m .47421 .61505 L .47566 .61379 L F
0 0 .398 r
.50726 .57665 m .50903 .58034 L .50857 .57779 L F
.791 .835 .886 r
.68028 .43179 m .67612 .43274 L .67774 .43127 L F
.786 .9 .922 r
.68203 .43034 m .68028 .43179 L .67774 .43127 L F
.877 .988 .724 r
.76131 .40575 m .76394 .40295 L .76334 .40258 L F
.346 .641 .964 r
.20356 .70159 m .20435 .70013 L .20222 .70018 L F
.20356 .70159 m .20646 .70185 L .20435 .70013 L F
.154 0 0 r
.17909 .70378 m .18005 .70374 L .17935 .70372 L F
.735 .893 .951 r
.71133 .42332 m .71573 .42249 L .71475 .42159 L F
.791 .928 .925 r
.71475 .42159 m .71573 .42249 L .71781 .42094 L F
.438 0 0 r
.65743 .41423 m .65339 .41142 L .65402 .41257 L F
.445 .011 .119 r
.75203 .39558 m .75493 .39371 L .753 .39395 L F
.356 .285 .638 r
.4321 .64383 m .43423 .64598 L .43438 .64336 L F
.967 .825 .651 r
.16847 .6232 m .16823 .62532 L .16659 .62482 L F
.692 .865 .964 r
.16823 .62532 m .16438 .62541 L .16659 .62482 L F
.705 .578 .71 r
.17115 .62244 m .16823 .62532 L .16847 .6232 L F
.761 .276 0 r
.77867 .41807 m .77612 .41951 L .77676 .41678 L F
.77867 .41807 m .77859 .41915 L .77612 .41951 L F
.77867 .41807 m .77942 .41956 L .77859 .41915 L F
0 0 0 r
.19549 .72016 m .19557 .71998 L .19327 .72076 L F
.19549 .72016 m .19789 .71896 L .19557 .71998 L F
.67 .965 .93 r
.70333 .42732 m .70725 .42583 L .70568 .42621 L F
.749 .988 .894 r
.70725 .42583 m .70856 .42395 L .70568 .42621 L F
.70725 .42583 m .70922 .4244 L .70856 .42395 L F
.441 .724 .986 r
.20793 .63385 m .20384 .63272 L .20619 .63341 L F
0 .574 .714 r
.20619 .63341 m .20995 .63348 L .20793 .63385 L F
.722 .676 .805 r
.74925 .39521 m .751 .39746 L .74704 .39759 L F
.483 .266 .508 r
.74982 .3991 m .74704 .39759 L .751 .39746 L F
.918 .579 .383 r
.751 .39746 m .75162 .40041 L .74982 .3991 L F
.662 .391 .499 r
.50759 .59981 m .50687 .59788 L .50861 .59855 L F
.967 .825 .651 r
.16847 .6232 m .16438 .62541 L .16409 .62522 L F
.16847 .6232 m .16659 .62482 L .16438 .62541 L F
.45 .016 .12 r
.49418 .53186 m .49827 .52989 L .49751 .53245 L F
.49418 .53186 m .49637 .53203 L .49827 .52989 L F
0 0 0 r
.49827 .52989 m .49637 .53203 L .49799 .53082 L F
.607 .521 .731 r
.79887 .40626 m .79985 .40926 L .79662 .40951 L F
.541 .386 .619 r
.79985 .40926 m .79729 .41289 L .79662 .40951 L F
.267 0 .089 r
.53579 .5105 m .53897 .50763 L .53714 .50892 L F
.422 .493 .828 r
.55767 .57983 m .55629 .58184 L .5553 .58086 L F
.55767 .57983 m .55891 .58324 L .55629 .58184 L F
.78 .695 .771 r
.66623 .43943 m .66648 .44273 L .66891 .43989 L F
.633 .817 .398 r
.20494 .70931 m .20331 .70878 L .20097 .70929 L F
.20494 .70931 m .20394 .71083 L .20331 .70878 L F
.20494 .70931 m .20289 .71263 L .20394 .71083 L F
.187 .649 .939 r
.20577 .70866 m .20494 .70931 L .20331 .70878 L F
.20577 .70866 m .20893 .71018 L .20494 .70931 L F
.48 .377 .661 r
.28971 .5676 m .28905 .57362 L .28758 .5722 L F
.458 .235 .487 r
.28905 .57362 m .28806 .57449 L .28758 .5722 L F
.808 .433 0 r
.76675 .39834 m .76544 .39469 L .76555 .39571 L F
0 0 .016 r
.76555 .39571 m .76544 .39469 L .76709 .39251 L F
.853 .784 .784 r
.75266 .42392 m .7556 .42431 L .75495 .42077 L F
.863 .79 .777 r
.75495 .42077 m .7556 .42431 L .75665 .42218 L F
.56 .5 .745 r
.4383 .634 m .43674 .63478 L .43558 .63157 L F
.914 .593 .423 r
.43674 .63478 m .43739 .63774 L .4354 .63653 L F
.342 .576 .928 r
.17166 .62042 m .17115 .62244 L .16932 .61899 L F
.17166 .62042 m .17287 .62241 L .17115 .62244 L F
.091 0 .362 r
.71726 .4003 m .7188 .39726 L .71863 .3998 L F
.389 .318 .655 r
.71948 .402 m .71726 .4003 L .71863 .3998 L F
.187 0 0 r
.44527 .59947 m .44323 .6002 L .44682 .59773 L F
.379 0 0 r
.21186 .53906 m .2131 .53992 L .21523 .53866 L F
.2 0 0 r
.2131 .53992 m .21741 .53879 L .21523 .53866 L F
.78 .695 .771 r
.66623 .43943 m .66775 .43969 L .66737 .4396 L F
.952 .849 .424 r
.66737 .4396 m .6667 .43978 L .66677 .43945 L F
.904 .758 .69 r
.66846 .43661 m .66737 .4396 L .6666 .4351 L F
0 0 .243 r
.6666 .4351 m .66737 .4396 L .66715 .43758 L F
.6666 .4351 m .66737 .4396 L .66715 .43758 L F
.263 .459 .864 r
.66715 .43758 m .66737 .4396 L .66623 .43943 L F
.66715 .43758 m .66737 .4396 L .66623 .43943 L F
.952 .849 .424 r
.66737 .4396 m .66677 .43945 L .66715 .43758 L F
.78 .695 .771 r
.66775 .43969 m .66891 .43989 L .66737 .4396 L F
.305 0 0 r
.66891 .43989 m .67013 .44083 L .66737 .4396 L F
.66891 .43989 m .67108 .43988 L .67013 .44083 L F
.412 0 0 r
.66737 .4396 m .66891 .43989 L .67013 .44083 L F
.425 .23 .51 r
.28797 .58685 m .28769 .5894 L .28576 .58986 L F
.529 .348 .579 r
.28807 .59187 m .28576 .58986 L .28769 .5894 L F
.28807 .59187 m .28575 .5924 L .28576 .58986 L F
.714 .391 0 r
.52844 .52963 m .52933 .53226 L .52968 .53306 L F
.891 .856 .801 r
.76251 .42673 m .76383 .42806 L .76178 .43104 L F
.865 .859 .833 r
.76625 .4251 m .76383 .42806 L .76251 .42673 L F
.711 .632 .767 r
.49001 .58066 m .49398 .58171 L .49289 .5786 L F
.676 .57 .729 r
.49289 .5786 m .49398 .58171 L .49618 .5806 L F
.942 .848 .721 r
.75763 .37518 m .75849 .37396 L .75697 .37261 L F
0 0 0 r
.48653 .59275 m .4846 .59572 L .48547 .59498 L F
.486 .218 .433 r
.45533 .56897 m .45274 .57081 L .45303 .56892 L F
0 0 .171 r
.58455 .55382 m .58632 .55003 L .58587 .55232 L F
0 0 .23 r
.58425 .5562 m .58455 .55382 L .58587 .55232 L F
.288 .395 .798 r
.28888 .5551 m .28792 .55701 L .28646 .55338 L F
.239 .335 .761 r
.28888 .5551 m .29018 .55873 L .28792 .55701 L F
.599 .305 .442 r
.47902 .57172 m .47691 .57468 L .47571 .57415 L F
.544 .24 .403 r
.47954 .57213 m .47691 .57468 L .47902 .57172 L F
.47862 .57417 m .47691 .57468 L .47954 .57213 L F
.225 .287 .718 r
.47794 .57614 m .47622 .57778 L .47571 .57415 L F
.47794 .57614 m .47571 .57415 L .47691 .57468 L F
.572 .274 .424 r
.48183 .57519 m .47691 .57468 L .48115 .57341 L F
.48183 .57519 m .47794 .57614 L .47691 .57468 L F
.577 .558 .797 r
.47385 .57288 m .47778 .57601 L .47811 .574 L F
.47778 .57601 m .47794 .57614 L .47799 .57556 L F
.47778 .57601 m .47799 .57556 L .47811 .574 L F
.544 .24 .403 r
.48115 .57341 m .47862 .57417 L .47954 .57213 L F
.958 .793 .35 r
.52977 .55288 m .52943 .55582 L .53003 .55635 L F
.806 .413 0 r
.5303 .55798 m .53003 .55635 L .52943 .55582 L F
.5303 .55798 m .5313 .5593 L .53003 .55635 L F
.386 0 .175 r
.25898 .57113 m .26117 .57076 L .2624 .56884 L F
.524 .141 .257 r
.2624 .56884 m .26117 .57076 L .2642 .57036 L F
.571 .45 .676 r
.2624 .56884 m .26476 .56843 L .26422 .56569 L F
.471 .157 .351 r
.2624 .56884 m .2642 .57036 L .26476 .56843 L F
.6 .6 .823 r
.7247 .40109 m .72119 .40701 L .7195 .40404 L F
.7247 .40109 m .72385 .40638 L .72119 .40701 L F
.251 0 0 r
.55383 .58163 m .55276 .5808 L .55141 .58199 L F
0 0 .07 r
.55411 .58218 m .55383 .58163 L .55371 .58361 L F
.55454 .58066 m .55383 .58163 L .55411 .58218 L F
.251 0 0 r
.55383 .58163 m .5553 .58086 L .55343 .58082 L F
.55383 .58163 m .55343 .58082 L .55276 .5808 L F
.568 .773 .975 r
.2154 .55403 m .21687 .55212 L .21371 .55263 L F
.2154 .55403 m .21745 .55343 L .21687 .55212 L F
.977 .901 .672 r
.59448 .51643 m .59697 .51358 L .59467 .51434 L F
.59448 .51643 m .59545 .51764 L .59697 .51358 L F
.046 0 0 r
.17794 .54714 m .18013 .54667 L .18231 .54544 L F
0 0 0 r
.18231 .54544 m .18225 .54581 L .18434 .54467 L F
.18231 .54544 m .18013 .54667 L .18225 .54581 L F
.288 .303 .702 r
.73939 .4078 m .74006 .41138 L .73774 .40962 L F
.398 .297 .623 r
.73774 .40962 m .74006 .41138 L .73798 .41175 L F
.56 .5 .745 r
.4383 .634 m .43558 .63157 L .4382 .63126 L F
.393 0 0 r
.20646 .70185 m .21024 .70081 L .20822 .70208 L F
0 0 .014 r
.21024 .70081 m .21012 .70266 L .2103 .70224 L F
.21012 .70266 m .20999 .70476 L .2103 .70224 L F
.18 .714 .76 r
.2103 .70224 m .21109 .70197 L .21046 .70188 L F
0 0 .014 r
.21024 .70081 m .2103 .70224 L .20822 .70208 L F
.18 .714 .76 r
.2103 .70224 m .21046 .70188 L .20849 .7016 L F
.204 0 .276 r
.49347 .58532 m .49347 .58801 L .4937 .58591 L F
.506 .569 .854 r
.42902 .59712 m .43161 .60182 L .42923 .60226 L F
.381 .082 .327 r
.42923 .60226 m .4287 .60411 L .43161 .60182 L F
.42923 .60226 m .4287 .60411 L .43161 .60182 L F
0 .013 .587 r
.47991 .61078 m .4811 .61331 L .47975 .61132 L F
.198 .72 .862 r
.72749 .37959 m .73112 .37962 L .72978 .37991 L F
.736 .984 .771 r
.73108 .37881 m .73112 .37962 L .73221 .37785 L F
.72978 .37991 m .72995 .37988 L .73108 .37881 L F
.72995 .37988 m .73112 .37962 L .73108 .37881 L F
.522 .303 .523 r
.73108 .37881 m .73236 .37761 L .7299 .37773 L F
.73243 .38004 m .73236 .37761 L .73108 .37881 L F
.73243 .38004 m .73108 .37881 L .72978 .37991 L F
.73108 .37881 m .7299 .37773 L .72978 .37991 L F
.736 .984 .771 r
.72978 .37991 m .73221 .37785 L .73236 .37761 L F
.544 .558 .819 r
.42033 .62258 m .42189 .62591 L .42396 .6251 L F
.858 .435 .216 r
.42012 .62548 m .42077 .62464 L .42132 .62349 L F
.41963 .62629 m .42077 .62464 L .42012 .62548 L F
.923 .569 .13 r
.42077 .62464 m .42189 .62591 L .4211 .62422 L F
.42077 .62464 m .4211 .62422 L .42033 .62258 L F
.93 .716 .592 r
.42553 .66183 m .42722 .66484 L .425 .66372 L F
.904 .517 .278 r
.42722 .66484 m .426 .66602 L .425 .66372 L F
.15 .364 .819 r
.4281 .66347 m .42722 .66484 L .42553 .66183 L F
.637 .884 .543 r
.4281 .66347 m .426 .66602 L .42722 .66484 L F
0 0 0 r
.56938 .48139 m .57039 .48066 L .57093 .48086 L F
.581 .34 .516 r
.56886 .48204 m .57088 .48032 L .57039 .48066 L F
.655 .969 .818 r
.57093 .48086 m .57039 .48066 L .57258 .47885 L F
.581 .34 .516 r
.57088 .48032 m .57258 .47885 L .57039 .48066 L F
0 0 0 r
.56859 .48166 m .57039 .48066 L .56938 .48139 L F
.56859 .48166 m .56751 .48311 L .57039 .48066 L F
.706 .528 .644 r
.59683 .4694 m .59922 .46657 L .59672 .46661 L F
.59683 .4694 m .60072 .46971 L .59922 .46657 L F
.532 .827 .999 r
.2156 .67592 m .21717 .67696 L .21326 .67658 L F
.754 .334 .252 r
.21509 .67848 m .21717 .67696 L .2156 .67592 L F
.21509 .67848 m .21816 .67923 L .21717 .67696 L F
.955 .902 .731 r
.75665 .42218 m .75732 .41771 L .75495 .42077 L F
.653 .873 .504 r
.45736 .61637 m .45659 .61685 L .45966 .61623 L F
0 0 .288 r
.47672 .57729 m .47576 .58002 L .47622 .57778 L F
.47695 .5779 m .47576 .58002 L .47672 .57729 L F
.47794 .57614 m .47763 .5787 L .47576 .58002 L F
.541 .177 .298 r
.47644 .58221 m .47813 .58035 L .47576 .58002 L F
.783 .863 .421 r
.477 .57915 m .47644 .58221 L .47576 .58002 L F
.47763 .5787 m .4774 .57939 L .477 .57915 L F
.4774 .57939 m .47644 .58221 L .477 .57915 L F
.671 .131 0 r
.47644 .58221 m .47485 .58139 L .47576 .58002 L F
.528 .534 .805 r
.47485 .58139 m .47644 .58221 L .47576 .58002 L F
.505 0 0 r
.47583 .57845 m .47354 .58051 L .47673 .58035 L F
.47576 .5783 m .47569 .57837 L .47583 .57845 L F
.47569 .57837 m .47354 .58051 L .47583 .57845 L F
.47576 .5783 m .47673 .58035 L .47741 .57912 L F
.47722 .57861 m .47741 .57912 L .47763 .5787 L F
.47576 .5783 m .47741 .57912 L .47722 .57861 L F
0 0 .288 r
.47794 .57614 m .47695 .5779 L .47672 .57729 L F
.191 0 .208 r
.46456 .60335 m .4636 .60217 L .46528 .60083 L F
.46456 .60335 m .46305 .60401 L .4636 .60217 L F
.768 .573 .634 r
.21911 .6738 m .2232 .67622 L .222 .67508 L F
.21911 .6738 m .2195 .67652 L .2232 .67622 L F
.618 .524 .725 r
.22489 .67352 m .2232 .67622 L .22445 .67515 L F
0 0 0 r
.77227 .40195 m .77049 .40365 L .77292 .40059 L F
.692 .786 .923 r
.76454 .37787 m .76525 .37963 L .76166 .37906 L F
.12 .393 .847 r
.76577 .37819 m .76525 .37963 L .76454 .37787 L F
0 0 .494 r
.76669 .38011 m .76525 .37963 L .76577 .37819 L F
.76669 .38011 m .76587 .38199 L .76525 .37963 L F
.843 .598 .57 r
.50712 .53201 m .51024 .52969 L .50886 .52856 L F
.963 .638 .261 r
.51003 .52828 m .50964 .52946 L .5088 .52921 L F
0 0 0 r
.51246 .52644 m .51003 .52828 L .50886 .52856 L F
.818 .679 .71 r
.50566 .53075 m .50886 .52856 L .50753 .52757 L F
.50566 .53075 m .50712 .53201 L .50886 .52856 L F
.208 .64 .951 r
.50886 .52856 m .51003 .52828 L .50753 .52757 L F
.963 .638 .261 r
.51003 .52828 m .5088 .52921 L .50753 .52757 L F
0 0 0 r
.51261 .52635 m .51003 .52828 L .51246 .52644 L F
.153 0 0 r
.51392 .52693 m .51003 .52828 L .51261 .52635 L F
.963 .638 .261 r
.51003 .52828 m .51127 .53102 L .50945 .53005 L F
.51127 .53102 m .51148 .53149 L .51081 .53101 L F
.51127 .53102 m .51081 .53101 L .50945 .53005 L F
.859 .948 .872 r
.50945 .53005 m .51023 .5306 L .50885 .53178 L F
.51023 .5306 m .51148 .53149 L .50942 .53172 L F
.51023 .5306 m .50942 .53172 L .50885 .53178 L F
.591 .938 .939 r
.51208 .52683 m .51003 .52828 L .51392 .52693 L F
.322 .431 .817 r
.5135 .53193 m .51003 .52828 L .51208 .52683 L F
.422 .287 .591 r
.51042 .53093 m .51275 .52935 L .51232 .52774 L F
.51095 .52963 m .51232 .52774 L .51208 .52683 L F
.51042 .53093 m .51232 .52774 L .51095 .52963 L F
.583 .945 .849 r
.51042 .53093 m .51029 .531 L .51275 .52935 L F
.776 .857 .911 r
.50945 .53005 m .50885 .53178 L .51042 .53093 L F
.583 .945 .849 r
.51029 .531 m .50885 .53178 L .51011 .531 L F
.98 .697 .41 r
.50945 .53005 m .51042 .53093 L .50845 .52578 L F
.583 .945 .849 r
.51029 .531 m .51011 .531 L .51275 .52935 L F
.422 .287 .591 r
.50987 .52951 m .51208 .52683 L .50845 .52578 L F
.51042 .53093 m .51091 .52971 L .50987 .52951 L F
.51091 .52971 m .51208 .52683 L .50987 .52951 L F
.963 .638 .261 r
.50964 .52946 m .50945 .53005 L .50889 .52932 L F
.50964 .52946 m .50889 .52932 L .5088 .52921 L F
.151 0 0 r
.51536 .5255 m .51487 .52626 L .51261 .52635 L F
.153 0 0 r
.51392 .52693 m .51261 .52635 L .51487 .52626 L F
.544 .677 .925 r
.1799 .64957 m .18347 .65088 L .1819 .64957 L F
.503 .624 .903 r
.18347 .65088 m .1841 .64873 L .1819 .64957 L F
.18347 .65088 m .18541 .65061 L .1841 .64873 L F
.697 .785 .919 r
.75415 .3732 m .75182 .37443 L .75087 .37246 L F
0 0 0 r
.75082 .375 m .75182 .37443 L .75075 .37504 L F
.75075 .37504 m .75182 .37443 L .75415 .3732 L F
.75075 .37504 m .75415 .3732 L .75087 .37246 L F
.05 0 .428 r
.75269 .37299 m .75075 .37504 L .75087 .37246 L F
.524 .828 .505 r
.75065 .3751 m .75075 .37504 L .75269 .37299 L F
0 0 0 r
.74849 .37632 m .75082 .375 L .75075 .37504 L F
.587 .944 .909 r
.7473 .37603 m .74849 .37632 L .75075 .37504 L F
.7473 .37603 m .75075 .37504 L .74978 .376 L F
.524 .828 .505 r
.74978 .376 m .75075 .37504 L .75065 .3751 L F
.766 .678 .766 r
.65426 .42406 m .65282 .42438 L .65677 .42467 L F
.865 .859 .833 r
.76625 .4251 m .76251 .42673 L .7647 .42358 L F
.662 .681 .858 r
.17909 .70378 m .18005 .70374 L .17931 .70412 L F
.342 .27 .63 r
.2897 .58532 m .28796 .58335 L .28919 .58293 L F
.2897 .58532 m .28797 .58685 L .28796 .58335 L F
0 0 0 r
.19805 .65241 m .20184 .65098 L .19996 .6514 L F
.196 .72 .712 r
.19996 .6514 m .20184 .65098 L .2042 .65038 L F
.694 .633 .784 r
.55891 .58324 m .56028 .58677 L .55711 .58691 L F
.076 0 0 r
.15902 .55409 m .15617 .5564 L .15809 .55544 L F
.148 0 .014 r
.15902 .55409 m .16021 .55455 L .16118 .55349 L F
.15902 .55409 m .15809 .55544 L .16021 .55455 L F
.388 .493 .845 r
.79626 .39958 m .79446 .40153 L .79428 .39942 L F
.79626 .39958 m .79763 .4027 L .79446 .40153 L F
.401 .488 .834 r
.79763 .4027 m .79573 .40292 L .79446 .40153 L F
.637 .552 .742 r
.2181 .6966 m .21526 .69773 L .21475 .69506 L F
.158 .065 .491 r
.21675 .69975 m .21526 .69773 L .2181 .6966 L F
.958 .904 .725 r
.5814 .52668 m .57911 .52779 L .58052 .52572 L F
.5814 .52668 m .58004 .53002 L .57911 .52779 L F
.752 .746 .229 r
.58233 .52234 m .5814 .52668 L .58052 .52572 L F
.924 .546 .269 r
.1957 .73831 m .1957 .73979 L .19566 .73716 L F
.383 .016 .213 r
.15353 .57688 m .1501 .57952 L .15169 .57775 L F
.762 .668 .759 r
.49289 .5786 m .49001 .58066 L .49243 .57762 L F
.074 0 .047 r
.49106 .58166 m .49001 .58066 L .49289 .5786 L F
.762 .668 .759 r
.49289 .5786 m .49001 .58066 L .49243 .57762 L F
.164 .333 .788 r
.49492 .57939 m .49289 .5786 L .49243 .57762 L F
0 .376 .809 r
.49492 .57939 m .49618 .5806 L .49289 .5786 L F
.49289 .5786 m .49618 .5806 L .49492 .57939 L F
.448 .031 .154 r
.49348 .58111 m .49289 .5786 L .49492 .57939 L F
.49348 .58111 m .49106 .58166 L .49289 .5786 L F
.608 .361 .518 r
.44944 .58342 m .45209 .58345 L .45294 .58031 L F
.538 .294 .493 r
.45294 .58031 m .45478 .58293 L .45515 .58018 L F
.45294 .58031 m .45209 .58345 L .45478 .58293 L F
.964 .913 .56 r
.76131 .40575 m .76048 .40784 L .76107 .40873 L F
.97 .9 .54 r
.75944 .41154 m .76107 .40873 L .76048 .40784 L F
.75944 .41154 m .75997 .41235 L .76107 .40873 L F
.654 .462 .612 r
.58818 .47242 m .59075 .47234 L .59073 .46952 L F
.655 .463 .612 r
.59073 .46952 m .59424 .472 L .59423 .46948 L F
.59073 .46952 m .59075 .47234 L .59424 .472 L F
.704 .204 0 r
.77244 .44178 m .7713 .44106 L .76933 .43857 L F
.367 0 0 r
.77525 .4413 m .7713 .44106 L .77244 .44178 L F
0 0 0 r
.54867 .50838 m .54801 .50994 L .54675 .51149 L F
.039 0 .065 r
.55163 .50541 m .55071 .50773 L .54867 .50838 L F
.12 0 0 r
.55033 .50907 m .54867 .50838 L .55071 .50773 L F
.55033 .50907 m .54801 .50994 L .54867 .50838 L F
.851 .73 .729 r
.60079 .48931 m .6021 .49082 L .60084 .48725 L F
.864 .74 .724 r
.59846 .49268 m .6021 .49082 L .60079 .48931 L F
.59846 .49268 m .60057 .49381 L .6021 .49082 L F
.801 .538 .541 r
.69821 .40528 m .70159 .40369 L .69819 .40364 L F
.69821 .40528 m .70173 .40605 L .70159 .40369 L F
.509 .314 .551 r
.70173 .40605 m .70422 .40299 L .70159 .40369 L F
.104 .657 .793 r
.22138 .53874 m .22352 .53868 L .22133 .53877 L F
.743 .989 .89 r
.69131 .43119 m .69259 .43154 L .6946 .42992 L F
.97 .909 .561 r
.422 .63582 m .42267 .63736 L .42381 .63469 L F
.811 .623 .649 r
.42596 .63373 m .422 .63582 L .42381 .63469 L F
.891 .856 .801 r
.76251 .42673 m .76178 .43104 L .75995 .42973 L F
.904 .749 .68 r
.76178 .43104 m .761 .43355 L .75995 .42973 L F
0 0 .457 r
.49611 .60191 m .49706 .60402 L .4966 .60074 L F
.49611 .60191 m .49628 .60428 L .49706 .60402 L F
.716 .74 .87 r
.74889 .42339 m .75022 .4271 L .75266 .42392 L F
.754 .675 .774 r
.50784 .53539 m .50534 .53832 L .50894 .5384 L F
.17 .699 .858 r
.50534 .53832 m .50783 .538 L .50894 .5384 L F
.659 .624 .804 r
.51182 .53683 m .50894 .5384 L .50784 .53539 L F
0 .141 .676 r
.50894 .5384 m .50954 .53721 L .50784 .53539 L F
.643 .966 .886 r
.50894 .5384 m .50783 .538 L .50954 .53721 L F
.611 .93 .965 r
.71074 .4227 m .70922 .4244 L .71133 .42332 L F
.621 .947 .941 r
.70856 .42395 m .70922 .4244 L .71074 .4227 L F
.689 .865 .965 r
.17707 .62235 m .17287 .62241 L .17509 .6218 L F
.362 .798 .963 r
.17707 .62235 m .17509 .6218 L .17921 .62196 L F
.502 .673 .941 r
.74401 .37157 m .74165 .37393 L .74128 .37433 L F
.74487 .37069 m .74422 .37134 L .74401 .37157 L F
.74422 .37134 m .74165 .37393 L .74401 .37157 L F
.636 .7 .892 r
.74487 .37069 m .74128 .37433 L .74014 .37207 L F
.427 .093 .295 r
.7425 .37313 m .74014 .37207 L .73985 .37322 L F
.74257 .37313 m .74252 .37311 L .7425 .37313 L F
.74252 .37311 m .74014 .37207 L .7425 .37313 L F
.538 0 0 r
.77373 .40239 m .77423 .40231 L .77227 .40195 L F
.706 .312 .3 r
.77227 .40195 m .77292 .40059 L .77373 .40239 L F
.947 .595 .212 r
.76881 .40113 m .76965 .40065 L .7704 .40154 L F
.997 .774 .427 r
.76881 .40113 m .7704 .40154 L .76948 .40467 L F
.449 .744 .991 r
.28361 .54728 m .28296 .54874 L .28136 .54764 L F
.28361 .54728 m .28501 .54836 L .28296 .54874 L F
.786 .635 .695 r
.56139 .58039 m .56255 .58364 L .55891 .58324 L F
.779 .675 .749 r
.55891 .58324 m .56255 .58364 L .56028 .58677 L F
.335 .23 .583 r
.39281 .60792 m .39509 .6093 L .39498 .60707 L F
.39281 .60792 m .39291 .6106 L .39509 .6093 L F
.262 0 .165 r
.24444 .64246 m .24361 .64076 L .24569 .64009 L F
.24444 .64246 m .24259 .64304 L .24361 .64076 L F
.272 .228 .624 r
.54527 .59147 m .54262 .58971 L .54438 .58869 L F
.54527 .59147 m .54287 .59352 L .54262 .58971 L F
0 0 .377 r
.51745 .56186 m .51559 .55861 L .51683 .5597 L F
.837 .391 0 r
.51834 .59979 m .51784 .6012 L .5184 .59936 L F
.588 .851 .994 r
.51784 .6012 m .51886 .60223 L .51749 .6022 L F
.779 .336 0 r
.5193 .60374 m .51886 .60223 L .51784 .6012 L F
.837 .391 0 r
.51799 .60251 m .5193 .60374 L .51803 .60152 L F
.51799 .60251 m .51803 .60152 L .51784 .6012 L F
.054 .016 .491 r
.51867 .60092 m .51796 .60326 L .51799 .60251 L F
.986 .883 .636 r
.51743 .60502 m .5193 .60374 L .51799 .60251 L F
.054 .016 .491 r
.51796 .60326 m .51743 .60502 L .51799 .60251 L F
.837 .391 0 r
.51799 .60251 m .51784 .6012 L .51834 .59979 L F
.588 .851 .994 r
.51784 .6012 m .51749 .6022 L .51629 .60217 L F
.779 .336 0 r
.5193 .60374 m .52012 .60438 L .51886 .60223 L F
.82 .536 .508 r
.58568 .50562 m .58249 .50501 L .58241 .50267 L F
.829 .614 .612 r
.58568 .50562 m .58244 .50755 L .58249 .50501 L F
.58568 .50562 m .58526 .5077 L .58244 .50755 L F
.973 .767 .565 r
.41579 .59913 m .41491 .60125 L .41646 .60191 L F
0 .428 .728 r
.41491 .60125 m .41804 .6022 L .41646 .60191 L F
.538 .502 .764 r
.29018 .55873 m .29122 .56271 L .28894 .56319 L F
.402 .237 .541 r
.29122 .56271 m .28935 .56534 L .28894 .56319 L F
.815 .512 .476 r
.58249 .50501 m .57886 .50198 L .58241 .50267 L F
.889 .957 .839 r
.16071 .60788 m .15848 .61025 L .15884 .61074 L F
.978 .916 .658 r
.15884 .61074 m .15848 .61025 L .15799 .61145 L F
.683 .471 .593 r
.42202 .64353 m .41976 .6466 L .41953 .64373 L F
.992 .878 .605 r
.57911 .52779 m .58004 .53002 L .57921 .53226 L F
.524 .61 .88 r
.17585 .64678 m .1799 .64957 L .17793 .64646 L F
.34 .644 .966 r
.1799 .64957 m .18184 .64885 L .17793 .64646 L F
.1799 .64957 m .1819 .64957 L .18184 .64885 L F
.219 .033 .402 r
.42664 .61974 m .42865 .61892 L .4288 .61632 L F
.52 .326 .558 r
.42664 .61974 m .42902 .62175 L .42865 .61892 L F
.42664 .61974 m .4266 .62234 L .42902 .62175 L F
.441 .584 .899 r
.22029 .68532 m .21818 .68342 L .22026 .68276 L F
0 0 .491 r
.22026 .68276 m .22095 .68537 L .22029 .68532 L F
.213 .413 .842 r
.53824 .5677 m .53762 .56944 L .53647 .56802 L F
.53824 .5677 m .54014 .57097 L .53762 .56944 L F
.454 .885 .849 r
.16707 .61891 m .16743 .61829 L .16932 .61899 L F
.16707 .61891 m .16568 .61915 L .16743 .61829 L F
.528 .534 .805 r
.47485 .58139 m .47481 .58379 L .47644 .58221 L F
.34 .222 .569 r
.47481 .58379 m .47672 .58539 L .47644 .58221 L F
.47481 .58379 m .47503 .58633 L .47672 .58539 L F
.189 0 0 r
.23229 .62218 m .2346 .62166 L .2362 .61996 L F
0 0 0 r
.2362 .61996 m .23592 .62064 L .23634 .61829 L F
.2362 .61996 m .2346 .62166 L .23592 .62064 L F
.531 .423 .676 r
.41976 .6466 m .42011 .64868 L .4171 .64775 L F
.427 .556 .883 r
.4198 .64952 m .4171 .64775 L .42011 .64868 L F
.566 .016 0 r
.51319 .5565 m .51559 .55861 L .5141 .55767 L F
.279 0 0 r
.73889 .39278 m .73954 .3926 L .73855 .39026 L F
.73889 .39278 m .74148 .39313 L .73954 .3926 L F
.699 .534 .66 r
.59423 .46948 m .59683 .4694 L .59672 .46661 L F
0 0 .034 r
.43924 .64273 m .4382 .6454 L .43843 .64379 L F
.637 .857 .48 r
.74704 .39759 m .74476 .40073 L .74617 .39856 L F
.467 .255 .506 r
.74721 .39979 m .74476 .40073 L .74704 .39759 L F
0 0 .072 r
.74704 .39759 m .74905 .39666 L .74925 .39521 L F
.066 0 0 r
.74704 .39759 m .7479 .39796 L .74905 .39666 L F
.483 .266 .508 r
.74982 .3991 m .74721 .39979 L .74704 .39759 L F
.066 0 0 r
.74704 .39759 m .74617 .39856 L .7479 .39796 L F
.154 0 .1 r
.56824 .60071 m .56642 .60155 L .56933 .59898 L F
0 0 0 r
.57075 .59771 m .56933 .59898 L .57182 .59591 L F
.075 0 .131 r
.57075 .59771 m .56824 .60071 L .56933 .59898 L F
.732 .389 .399 r
.43306 .62907 m .43086 .63143 L .42833 .63059 L F
.719 .364 .376 r
.42987 .63262 m .43001 .63281 L .43122 .63133 L F
.43102 .63135 m .43122 .63133 L .43306 .62907 L F
.42987 .63262 m .43122 .63133 L .43102 .63135 L F
.639 .264 .316 r
.43306 .62907 m .43001 .63281 L .43451 .63262 L F
.216 0 0 r
.43336 .63005 m .43102 .63135 L .43306 .62907 L F
.43102 .63135 m .43086 .63143 L .43306 .62907 L F
.789 .805 .866 r
.43082 .63137 m .43086 .63143 L .43102 .63135 L F
.489 .676 .947 r
.42833 .63059 m .43086 .63143 L .43082 .63137 L F
.719 .364 .376 r
.42833 .63059 m .42987 .63262 L .43096 .63141 L F
.42833 .63059 m .43096 .63141 L .43306 .62907 L F
.489 .676 .947 r
.42833 .63059 m .43082 .63137 L .42887 .62853 L F
.789 .805 .866 r
.42887 .62853 m .43082 .63137 L .43336 .63005 L F
.43082 .63137 m .43102 .63135 L .43336 .63005 L F
.639 .264 .316 r
.43306 .62907 m .43451 .63262 L .43445 .62964 L F
.216 0 0 r
.43336 .63005 m .43306 .62907 L .43445 .62964 L F
.687 .733 .886 r
.72762 .40736 m .72385 .40638 L .72639 .4055 L F
.744 .775 .879 r
.72997 .40583 m .72762 .40736 L .72639 .4055 L F
.256 0 0 r
.50882 .52172 m .5134 .51957 L .51152 .52088 L F
.498 0 0 r
.25113 .53921 m .25387 .53989 L .2557 .539 L F
.175 0 0 r
.25387 .53989 m .25761 .53876 L .2557 .539 L F
.667 .772 .296 r
.75893 .38206 m .75755 .38529 L .75898 .38439 L F
0 0 .411 r
.75755 .38529 m .75834 .3868 L .75898 .38439 L F
.75755 .38529 m .75881 .38906 L .75834 .3868 L F
.856 .97 .653 r
.52493 .52646 m .52282 .53003 L .52298 .52806 L F
0 0 0 r
.52282 .53003 m .52358 .53035 L .52298 .52806 L F
.52282 .53003 m .5219 .53177 L .52358 .53035 L F
.494 .332 .589 r
.25429 .58967 m .25646 .58919 L .25651 .58658 L F
.422 .202 .472 r
.2541 .59209 m .25646 .58919 L .25429 .58967 L F
.668 .699 .869 r
.44877 .59321 m .44939 .59581 L .44599 .59547 L F
.482 .449 .744 r
.45076 .59174 m .44939 .59581 L .44877 .59321 L F
.45076 .59174 m .45293 .59608 L .44939 .59581 L F
.494 .35 .614 r
.45293 .59608 m .45194 .59776 L .44939 .59581 L F
0 0 .019 r
.79087 .4448 m .79079 .44637 L .78873 .44792 L F
0 0 0 r
.79079 .44637 m .78925 .44797 L .78873 .44792 L F
.654 .29 .343 r
.42286 .61672 m .42159 .61881 L .41904 .61852 L F
.59 .218 .305 r
.42572 .61815 m .42159 .61881 L .42286 .61672 L F
.462 .006 .082 r
.45985 .58523 m .45527 .58775 L .45587 .58646 L F
.45985 .58523 m .45788 .58766 L .45527 .58775 L F
.371 .164 .464 r
.46184 .5838 m .45985 .58523 L .4595 .58509 L F
.46184 .5838 m .46262 .5841 L .45985 .58523 L F
.287 0 0 r
.46051 .5871 m .45788 .58766 L .45985 .58523 L F
.974 .888 .679 r
.76674 .41487 m .76778 .41594 L .76686 .4181 L F
.24 .198 .608 r
.25817 .57754 m .25816 .58079 L .25989 .57936 L F
.48 .362 .641 r
.25816 .58079 m .26077 .58272 L .25989 .57936 L F
.25816 .58079 m .2587 .58337 L .26077 .58272 L F
.811 .848 .878 r
.77705 .39331 m .77535 .39754 L .77353 .39361 L F
.77705 .39331 m .77839 .39498 L .77535 .39754 L F
.932 .924 .779 r
.75881 .38906 m .75673 .38974 L .75834 .3868 L F
.75881 .38906 m .7575 .39112 L .75673 .38974 L F
.567 .362 .562 r
.43844 .5863 m .44074 .5862 L .44077 .58369 L F
.605 .393 .566 r
.44074 .5862 m .44326 .58595 L .44077 .58369 L F
.63 .388 .533 r
.44077 .58369 m .44326 .58595 L .44326 .58354 L F
.442 .312 .608 r
.2897 .58532 m .28769 .5894 L .28797 .58685 L F
.301 .115 .454 r
.28338 .59548 m .28307 .59801 L .28138 .59866 L F
.348 .222 .563 r
.28307 .59801 m .28317 .60059 L .28138 .59866 L F
.368 .225 .551 r
.28317 .60059 m .28139 .60141 L .28138 .59866 L F
0 0 0 r
.42046 .58776 m .42244 .58658 L .42111 .58571 L F
.796 .93 .922 r
.42348 .58395 m .42244 .58658 L .42546 .58439 L F
.42348 .58395 m .42111 .58571 L .42244 .58658 L F
.539 .836 .999 r
.22272 .64833 m .22655 .64862 L .22469 .64804 L F
.901 .736 .668 r
.40817 .62327 m .40657 .62461 L .40927 .62551 L F
.837 .585 .558 r
.40608 .62732 m .40927 .62551 L .40657 .62461 L F
.40608 .62732 m .40905 .6283 L .40927 .62551 L F
.579 .616 .854 r
.40927 .62551 m .41039 .62261 L .40817 .62327 L F
.40927 .62551 m .41167 .6252 L .41039 .62261 L F
.55 .337 .544 r
.40905 .6283 m .41167 .6252 L .40927 .62551 L F
.873 .841 .811 r
.21028 .70579 m .20893 .71018 L .20577 .70866 L F
.463 .36 .652 r
.46054 .60648 m .45791 .60512 L .46051 .60426 L F
.46054 .60648 m .45796 .60739 L .45791 .60512 L F
.903 .842 .775 r
.73986 .39627 m .74312 .39438 L .74148 .39313 L F
.73986 .39627 m .74124 .39775 L .74312 .39438 L F
.7 .432 0 r
.79328 .42331 m .79368 .42478 L .79273 .42098 L F
.79277 .42115 m .79273 .42098 L .79272 .42093 L F
.79328 .42331 m .79273 .42098 L .79277 .42115 L F
.79328 .42331 m .79272 .42093 L .79505 .41979 L F
.786 .548 .577 r
.79832 .42117 m .79328 .42331 L .79505 .41979 L F
.211 0 .193 r
.79543 .42028 m .79308 .42246 L .79472 .4219 L F
.79308 .42246 m .79255 .42295 L .79312 .42267 L F
.79308 .42246 m .79312 .42267 L .79472 .4219 L F
0 .009 .533 r
.79548 .42563 m .79368 .42478 L .79328 .42331 L F
.718 .591 .714 r
.7919 .42673 m .79376 .42896 L .79571 .42806 L F
.234 .419 .841 r
.79634 .42743 m .79416 .4275 L .79548 .42563 L F
.7967 .42817 m .79466 .42763 L .79634 .42743 L F
.79466 .42763 m .79416 .4275 L .79634 .42743 L F
.549 .395 .624 r
.79924 .42617 m .7967 .42817 L .79548 .42563 L F
.79924 .42617 m .79888 .42778 L .7967 .42817 L F
.488 .299 .55 r
.79589 .43025 m .79809 .42723 L .79669 .42761 L F
.79809 .42723 m .79834 .42689 L .79736 .42732 L F
.79809 .42723 m .79736 .42732 L .79669 .42761 L F
.718 .591 .714 r
.79564 .42742 m .79571 .42806 L .79669 .42761 L F
0 .009 .533 r
.79545 .42562 m .79416 .4275 L .79368 .42478 L F
.79545 .42566 m .79416 .4275 L .79545 .42562 L F
.718 .591 .714 r
.7919 .42673 m .79571 .42806 L .79564 .42742 L F
0 .009 .533 r
.79548 .42563 m .79545 .42566 L .79545 .42562 L F
.485 .371 .648 r
.43879 .58895 m .44074 .5862 L .43844 .5863 L F
.43879 .58895 m .44096 .5889 L .44074 .5862 L F
.228 .73 .903 r
.22352 .53868 m .22572 .53864 L .22744 .53886 L F
.182 .705 .869 r
.22572 .53864 m .22971 .53872 L .22744 .53886 L F
.423 .838 .967 r
.67433 .44183 m .67324 .44295 L .67589 .44225 L F
.947 .616 .365 r
.55775 .59001 m .55833 .59286 L .55678 .59123 L F
.178 0 0 r
.55775 .59001 m .55903 .5908 L .55678 .59123 L F
.55775 .59001 m .55903 .5908 L .55678 .59123 L F
.24 .198 .608 r
.25817 .57754 m .25989 .57936 L .25979 .57682 L F
.289 0 .001 r
.5439 .51435 m .54311 .51599 L .54071 .51646 L F
0 0 0 r
.54675 .51149 m .54592 .51326 L .5439 .51435 L F
.54592 .51326 m .54311 .51599 L .5439 .51435 L F
.637 .186 .164 r
.47486 .55841 m .47715 .55896 L .47836 .55759 L F
.598 .14 .137 r
.47836 .55759 m .47715 .55896 L .4809 .55894 L F
.556 0 0 r
.47836 .55759 m .4809 .55894 L .48236 .55888 L F
.488 .902 .839 r
.69961 .4286 m .70099 .42846 L .70333 .42732 L F
0 0 0 r
.54801 .50994 m .54592 .51326 L .54675 .51149 L F
0 .188 .681 r
.49618 .5806 m .49736 .58102 L .49492 .57939 L F
.49691 .58118 m .4987 .58259 L .498 .58177 L F
.555 .12 .168 r
.5 .5808 m .49736 .58102 L .4987 .58259 L F
.404 .001 .157 r
.49849 .58204 m .49565 .58543 L .49789 .58216 L F
.515 .707 .958 r
.4987 .58259 m .5019 .58227 L .5 .5808 L F
.404 .001 .157 r
.50062 .58162 m .49941 .58255 L .49849 .58204 L F
.509 .31 .546 r
.49899 .58524 m .5019 .58227 L .4987 .58259 L F
.404 .001 .157 r
.49941 .58255 m .49565 .58543 L .49849 .58204 L F
0 .188 .681 r
.49618 .5806 m .49691 .58118 L .49736 .58102 L F
.49691 .58118 m .498 .58177 L .49736 .58102 L F
.074 0 .047 r
.49106 .58166 m .48923 .58272 L .49001 .58066 L F
.447 .684 .966 r
.27 .54246 m .26939 .54426 L .26798 .54249 L F
.27 .54246 m .27151 .54409 L .26939 .54426 L F
.089 0 0 r
.18727 .54388 m .18883 .54358 L .19064 .54215 L F
.286 0 0 r
.18659 .54398 m .19048 .54328 L .18883 .54358 L F
.137 0 0 r
.18883 .54358 m .19108 .54317 L .19305 .54184 L F
.286 0 0 r
.19048 .54328 m .19108 .54317 L .18883 .54358 L F
.089 0 0 r
.18671 .54416 m .18883 .54358 L .18727 .54388 L F
.137 0 0 r
.18883 .54358 m .19305 .54184 L .19064 .54215 L F
.791 .928 .925 r
.71475 .42159 m .71781 .42094 L .71676 .42007 L F
.655 .903 .981 r
.71676 .42007 m .71781 .42094 L .7203 .4197 L F
.606 .144 .131 r
.20289 .71263 m .20622 .71266 L .20459 .71365 L F
0 0 0 r
.20854 .71248 m .20459 .71365 L .20622 .71266 L F
.942 .71 .558 r
.21326 .67658 m .21472 .67979 L .21227 .678 L F
.939 .598 .351 r
.21472 .67979 m .21359 .68022 L .21227 .678 L F
.957 .843 .689 r
.59937 .50305 m .59942 .49833 L .59785 .50188 L F
.939 .825 .705 r
.59844 .50536 m .59937 .50305 L .59785 .50188 L F
.804 .645 .685 r
.60039 .4722 m .59825 .47514 L .60189 .47569 L F
.804 .646 .687 r
.59825 .47514 m .6017 .47805 L .60189 .47569 L F
.853 .873 .854 r
.19506 .72709 m .19699 .72786 L .19977 .72528 L F
.736 .974 .926 r
.19543 .72663 m .20093 .72386 L .19978 .72433 L F
.19458 .72708 m .1952 .72677 L .19543 .72663 L F
.1952 .72677 m .20093 .72386 L .19543 .72663 L F
.573 .727 .947 r
.19279 .72762 m .19439 .72724 L .19339 .72587 L F
.19439 .72724 m .19495 .72711 L .19481 .727 L F
.754 .865 .929 r
.19487 .72609 m .19789 .72306 L .19553 .72384 L F
.19458 .72708 m .19539 .72609 L .19487 .72609 L F
.19539 .72609 m .19789 .72306 L .19487 .72609 L F
.573 .727 .947 r
.19439 .72724 m .19481 .727 L .19365 .72608 L F
.19354 .72608 m .19365 .72608 L .19339 .72587 L F
.19439 .72724 m .19365 .72608 L .19354 .72608 L F
.19495 .72711 m .19506 .72709 L .195 .72704 L F
.19495 .72711 m .195 .72704 L .19339 .72587 L F
.736 .974 .926 r
.1952 .72677 m .19977 .72528 L .20093 .72386 L F
.19458 .72708 m .1951 .7269 L .1952 .72677 L F
.1951 .7269 m .19977 .72528 L .1952 .72677 L F
0 0 0 r
.46183 .5955 m .46297 .59546 L .46439 .59284 L F
.729 .509 .593 r
.46486 .59399 m .46683 .59234 L .46439 .59284 L F
0 0 0 r
.46439 .59284 m .46508 .59346 L .46486 .59399 L F
.46439 .59284 m .46297 .59546 L .46508 .59346 L F
.787 .78 .278 r
.76855 .39793 m .77049 .40155 L .76965 .40065 L F
.672 .762 .918 r
.76965 .40065 m .77049 .40155 L .77191 .39936 L F
.76965 .40065 m .77049 .40155 L .77191 .39936 L F
.254 .206 .608 r
.78074 .41131 m .77924 .41568 L .77797 .4122 L F
.78074 .41131 m .78003 .41523 L .77924 .41568 L F
.116 .267 .743 r
.7801 .41409 m .77924 .41568 L .77797 .4122 L F
.723 .651 .777 r
.78074 .41131 m .78003 .41523 L .78458 .41302 L F
0 .208 .73 r
.78111 .41606 m .77924 .41568 L .7801 .41409 L F
.78111 .41606 m .78121 .41735 L .77924 .41568 L F
0 0 0 r
.41836 .58319 m .42009 .58247 L .42107 .58056 L F
.41836 .58319 m .41714 .58445 L .42009 .58247 L F
.63 .227 0 r
.52488 .57201 m .52595 .5739 L .5241 .57069 L F
.221 .742 .834 r
.21419 .64984 m .21506 .64943 L .21229 .64956 L F
.21419 .64984 m .21645 .64948 L .21506 .64943 L F
.624 .062 0 r
.48949 .56126 m .49472 .56425 L .49635 .56437 L F
.181 0 0 r
.49472 .56425 m .49849 .56475 L .49635 .56437 L F
.142 .004 .42 r
.58235 .56194 m .58216 .56436 L .58018 .5655 L F
0 0 .088 r
.58216 .56436 m .58002 .56821 L .58018 .5655 L F
.511 .152 .294 r
.44326 .58595 m .44697 .58341 L .44326 .58354 L F
.44326 .58595 m .44548 .58588 L .44697 .58341 L F
.639 .295 .371 r
.44697 .58341 m .44927 .58546 L .44944 .58342 L F
.44697 .58341 m .44548 .58588 L .44927 .58546 L F
.846 .922 .882 r
.67731 .4408 m .68101 .4393 L .68017 .43838 L F
.783 .98 .907 r
.68101 .4393 m .68179 .43701 L .68017 .43838 L F
.68101 .4393 m .68395 .43704 L .68179 .43701 L F
.911 .78 .704 r
.58335 .51353 m .58511 .51461 L .58388 .5166 L F
.306 .037 .331 r
.25281 .63647 m .25157 .6347 L .25366 .63453 L F
.25281 .63647 m .25092 .63728 L .25157 .6347 L F
.773 .424 .393 r
.68206 .41787 m .6859 .41858 L .68609 .42046 L F
.779 .587 .641 r
.68844 .41884 m .68609 .42046 L .6859 .41858 L F
.588 .709 .927 r
.46665 .57368 m .46732 .57057 L .4651 .5734 L F
.46665 .57368 m .46949 .57335 L .46732 .57057 L F
.326 .234 .596 r
.46665 .57368 m .46904 .57625 L .46949 .57335 L F
.46665 .57368 m .46779 .57756 L .46904 .57625 L F
.971 .717 .491 r
.77904 .40611 m .7804 .40649 L .77901 .40286 L F
.297 .716 .973 r
.78195 .40569 m .7804 .40649 L .77904 .40611 L F
.78195 .40569 m .78299 .40665 L .7804 .40649 L F
.29 0 0 r
.22809 .55266 m .22985 .55311 L .22599 .55245 L F
0 0 .366 r
.53396 .60744 m .53452 .60619 L .53409 .60367 L F
0 .112 .655 r
.53396 .60744 m .53576 .60972 L .53452 .60619 L F
0 0 0 r
.57305 .59438 m .57182 .59591 L .57385 .59258 L F
.059 0 .194 r
.57305 .59438 m .57075 .59771 L .57182 .59591 L F
0 0 0 r
.44896 .57243 m .44838 .57219 L .45045 .57144 L F
.117 0 0 r
.45274 .57081 m .44896 .57243 L .45045 .57144 L F
.319 0 .129 r
.56305 .48519 m .56481 .48582 L .56578 .48443 L F
.56305 .48519 m .5624 .48654 L .56481 .48582 L F
.526 .89 .974 r
.22023 .64915 m .22075 .64796 L .21855 .64867 L F
.22023 .64915 m .22272 .64833 L .22075 .64796 L F
.178 0 .071 r
.56642 .60155 m .56569 .60357 L .56343 .60385 L F
0 0 .003 r
.56736 .60244 m .56642 .60155 L .56824 .60071 L F
.56736 .60244 m .56569 .60357 L .56642 .60155 L F
.306 .786 .915 r
.2042 .65038 m .2081 .65025 L .20642 .6499 L F
.539 .893 .978 r
.20642 .6499 m .2081 .65025 L .21021 .64947 L F
.21 0 0 r
.21475 .69506 m .21056 .69682 L .21304 .69436 L F
.636 .844 .98 r
.21532 .69325 m .21718 .69425 L .21475 .69506 L F
.707 .912 .966 r
.21532 .69325 m .21475 .69506 L .21304 .69436 L F
.656 .727 .901 r
.73262 .41802 m .73631 .41887 L .73514 .41711 L F
.696 .743 .887 r
.73514 .41711 m .73631 .41887 L .73887 .4178 L F
.93 .942 .782 r
.42671 .63728 m .42767 .63331 L .42763 .635 L F
.024 .102 .608 r
.26017 .55842 m .26051 .563 L .26149 .56116 L F
.952 .701 .521 r
.26349 .56414 m .26149 .56116 L .26051 .563 L F
.178 0 .024 r
.41424 .62494 m .41807 .6217 L .41424 .62241 L F
.468 .38 .673 r
.4161 .62447 m .41963 .62629 L .41845 .62431 L F
.703 .977 .778 r
.4193 .62173 m .4161 .62447 L .41737 .62252 L F
.468 .38 .673 r
.4161 .62447 m .41845 .62431 L .41737 .62252 L F
.178 0 .024 r
.41469 .62456 m .4161 .62447 L .41807 .6217 L F
.41424 .62494 m .4161 .62447 L .41469 .62456 L F
.079 .51 .901 r
.20452 .63203 m .20384 .63272 L .20229 .6318 L F
.20452 .63203 m .20619 .63341 L .20384 .63272 L F
.432 .208 .471 r
.26963 .61664 m .26926 .61935 L .26707 .61993 L F
.42 .187 .453 r
.27208 .61393 m .27167 .61622 L .26963 .61664 L F
.349 .137 .445 r
.27112 .61846 m .26963 .61664 L .27167 .61622 L F
.27112 .61846 m .26926 .61935 L .26963 .61664 L F
.741 .273 .138 r
.43443 .6022 m .43555 .60377 L .43916 .60426 L F
.683 .174 .021 r
.43555 .60377 m .43769 .60488 L .43916 .60426 L F
.649 .095 0 r
.43906 .60508 m .43916 .60426 L .43769 .60488 L F
.43906 .60508 m .44175 .60662 L .43916 .60426 L F
.999 .794 .492 r
.74721 .39979 m .74617 .39856 L .74476 .40073 L F
0 0 0 r
.18463 .55989 m .18025 .56118 L .18241 .55939 L F
.862 .654 .62 r
.64616 .41423 m .64848 .41263 L .64669 .4117 L F
.64616 .41423 m .64811 .41524 L .64848 .41263 L F
.943 .925 .563 r
.54527 .59147 m .54544 .59308 L .54287 .59352 L F
.339 0 0 r
.42869 .60944 m .4271 .60896 L .42993 .60839 L F
.42869 .60944 m .4263 .60966 L .4271 .60896 L F
.213 .019 .386 r
.24171 .55436 m .24022 .55356 L .24168 .55269 L F
.24171 .55436 m .23977 .55623 L .24022 .55356 L F
.462 .22 .46 r
.40073 .60178 m .40313 .60123 L .40371 .59881 L F
.169 0 .336 r
.40371 .59881 m .40471 .60017 L .4049 .59763 L F
.40371 .59881 m .40313 .60123 L .40471 .60017 L F
.559 .572 .824 r
.46853 .59853 m .4658 .59925 L .46562 .59558 L F
.371 .047 .279 r
.46853 .59853 m .46528 .60083 L .4658 .59925 L F
.786 .635 .695 r
.56139 .58039 m .55891 .58324 L .5589 .58042 L F
.254 0 .073 r
.15256 .55924 m .1547 .55865 L .15617 .5564 L F
.115 0 0 r
.15617 .5564 m .1566 .55781 L .15809 .55544 L F
.15617 .5564 m .1547 .55865 L .1566 .55781 L F
.346 .046 .306 r
.40073 .60178 m .40221 .6031 L .40313 .60123 L F
.40073 .60178 m .40011 .60378 L .40221 .6031 L F
.089 0 .287 r
.79365 .44153 m .79334 .44345 L .79087 .4448 L F
0 0 .028 r
.79334 .44345 m .79079 .44637 L .79087 .4448 L F
.91 .892 .476 r
.76993 .40462 m .76889 .40477 L .76948 .40467 L F
.76993 .40462 m .76843 .40919 L .76889 .40477 L F
.455 0 0 r
.44874 .61176 m .45274 .61099 L .4484 .61 L F
.44874 .61176 m .45118 .61222 L .45274 .61099 L F
.433 .153 .387 r
.45274 .61099 m .45229 .61306 L .45004 .61357 L F
.798 .949 .608 r
.45274 .61099 m .45118 .61222 L .45335 .60893 L F
.482 .176 .37 r
.45553 .60983 m .45229 .61306 L .45274 .61099 L F
.403 0 0 r
.20727 .53977 m .20927 .54009 L .21186 .53906 L F
.397 0 0 r
.21186 .53906 m .20927 .54009 L .2131 .53992 L F
.984 .783 .555 r
.54108 .57679 m .541 .57992 L .54247 .58067 L F
.866 .512 .01 r
.541 .57992 m .54244 .58315 L .54247 .58067 L F
.957 .949 .684 r
.59176 .52802 m .5923 .53001 L .59377 .5265 L F
.964 .938 .646 r
.59121 .5319 m .5923 .53001 L .59176 .52802 L F
0 .178 .71 r
.4253 .57949 m .426 .58088 L .42343 .57825 L F
.012 0 .023 r
.42107 .58056 m .42427 .5789 L .42343 .57825 L F
.432 .426 .752 r
.21911 .6738 m .22011 .66982 L .21817 .67119 L F
.21911 .6738 m .22198 .67489 L .22011 .66982 L F
.156 .488 .902 r
.21911 .6738 m .222 .67508 L .22198 .67489 L F
.723 .931 .6 r
.23218 .65757 m .23171 .65895 L .23402 .6584 L F
.23218 .65757 m .22993 .66058 L .23171 .65895 L F
.427 .294 .596 r
.24736 .60435 m .24926 .60092 L .24715 .60192 L F
.026 0 0 r
.71177 .39897 m .71264 .39747 L .70975 .39942 L F
.635 .162 .114 r
.71531 .39924 m .71264 .39747 L .71177 .39897 L F
.477 .889 .928 r
.2165 .63194 m .21229 .63266 L .21418 .63214 L F
.602 .811 .98 r
.73736 .39724 m .74124 .39775 L .73986 .39627 L F
.846 .6 .566 r
.6821 .41543 m .67844 .41531 L .67856 .41463 L F
.6821 .41543 m .68206 .41787 L .67844 .41531 L F
.5 .311 .556 r
.27653 .61 m .27422 .61335 L .27451 .61062 L F
.766 .43 .416 r
.66608 .39969 m .66805 .40214 L .66987 .40034 L F
.809 .493 .456 r
.66987 .40034 m .66805 .40214 L .67072 .40247 L F
.889 .925 .839 r
.75673 .38974 m .7575 .39112 L .75493 .39371 L F
0 0 .014 r
.56999 .55954 m .57106 .55799 L .57121 .5562 L F
.954 .952 .694 r
.57029 .56201 m .57106 .55799 L .56999 .55954 L F
.747 .745 .85 r
.19279 .72762 m .19699 .72786 L .19506 .72709 L F
.793 .296 0 r
.48736 .57115 m .4836 .57267 L .48494 .57137 L F
.42 .187 .453 r
.27377 .61561 m .27208 .61393 L .27422 .61335 L F
.27377 .61561 m .27167 .61622 L .27208 .61393 L F
.043 0 0 r
.16325 .55277 m .16547 .55231 L .16756 .55126 L F
0 0 0 r
.16547 .55231 m .16975 .55057 L .16756 .55126 L F
.85 .855 .398 r
.64359 .41112 m .64224 .41562 L .64248 .41367 L F
.267 0 .096 r
.46183 .5955 m .46309 .5967 L .46297 .59546 L F
.46183 .5955 m .46109 .59737 L .46309 .5967 L F
.304 .036 .331 r
.26842 .62129 m .26707 .61993 L .26926 .61935 L F
.26842 .62129 m .26647 .62202 L .26707 .61993 L F
.637 .858 .983 r
.7203 .4197 m .72451 .41956 L .7232 .41837 L F
.74 .825 .917 r
.72451 .41956 m .72535 .41688 L .7232 .41837 L F
.72451 .41956 m .72652 .41845 L .72535 .41688 L F
.804 .646 .687 r
.59825 .47514 m .59809 .47769 L .6017 .47805 L F
.803 .653 .695 r
.59809 .47769 m .59959 .48115 L .6017 .47805 L F
.85 .624 .596 r
.46038 .5769 m .46028 .57943 L .46459 .57996 L F
.756 .318 .21 r
.46028 .57943 m .46277 .58186 L .46459 .57996 L F
.137 0 .166 r
.46459 .57996 m .46643 .57947 L .46779 .57756 L F
.348 .49 .859 r
.4675 .58182 m .46459 .57996 L .46738 .58138 L F
.313 0 .05 r
.46277 .58186 m .46643 .57947 L .46459 .57996 L F
0 .036 .59 r
.76855 .39793 m .76965 .40065 L .76869 .3966 L F
.786 .9 .922 r
.68203 .43034 m .67774 .43127 L .68145 .42981 L F
.851 .939 .881 r
.68415 .42632 m .68203 .43034 L .68291 .42779 L F
.68415 .42632 m .68493 .42752 L .68203 .43034 L F
.841 .998 .825 r
.68203 .43034 m .68145 .42981 L .68291 .42779 L F
.919 .811 .724 r
.74871 .41088 m .74803 .40828 L .7497 .40941 L F
.314 .521 .897 r
.17402 .64413 m .17585 .64678 L .17648 .6451 L F
.497 .728 .976 r
.17585 .64678 m .17793 .64646 L .17648 .6451 L F
.481 .229 .454 r
.42123 .59556 m .42359 .59752 L .42365 .59511 L F
.42123 .59556 m .42075 .59818 L .42359 .59752 L F
.412 0 0 r
.78642 .40579 m .78299 .40665 L .78565 .40801 L F
.59 .574 .803 r
.78642 .40579 m .78832 .40452 L .78824 .40186 L F
.123 0 .128 r
.78817 .4074 m .78642 .40579 L .78565 .40801 L F
.78817 .4074 m .78832 .40452 L .78642 .40579 L F
.427 .846 .959 r
.19305 .54184 m .19488 .54127 L .19669 .54158 L F
.038 0 0 r
.19488 .54127 m .19889 .54126 L .19669 .54158 L F
.51 .275 .494 r
.45796 .60739 m .45778 .60953 L .45553 .60983 L F
.369 .153 .449 r
.46054 .60648 m .45778 .60953 L .45796 .60739 L F
.534 .295 .5 r
.44781 .64651 m .45029 .64626 L .45075 .64368 L F
.44781 .64651 m .45029 .64626 L .45075 .64368 L F
.516 .343 .584 r
.45258 .64298 m .45029 .64626 L .45075 .64368 L F
.45258 .64298 m .45029 .64626 L .45075 .64368 L F
.084 0 .377 r
.45427 .60177 m .45582 .60266 L .45607 .60121 L F
.72 .473 0 r
.44574 .6494 m .44638 .65268 L .44608 .65129 L F
.421 .091 .298 r
.55434 .50449 m .55071 .50773 L .55163 .50541 L F
.493 .333 .592 r
.279 .60429 m .27893 .60701 L .27678 .60752 L F
.51 .31 .545 r
.27893 .60701 m .27653 .61 L .27678 .60752 L F
.169 0 .038 r
.56569 .60357 m .56257 .60589 L .56343 .60385 L F
.202 0 .233 r
.45527 .58775 m .45389 .58684 L .45587 .58646 L F
.45527 .58775 m .45323 .58883 L .45389 .58684 L F
.271 0 .288 r
.26647 .62202 m .26384 .62491 L .26455 .62283 L F
.222 .735 .879 r
.22971 .53872 m .23212 .53859 L .23346 .53869 L F
.157 .677 .886 r
.23212 .53859 m .23606 .53904 L .23346 .53869 L F
.532 .36 .594 r
.56112 .57697 m .56354 .57663 L .56329 .57446 L F
.562 .171 .258 r
.56066 .57837 m .56354 .57663 L .56112 .57697 L F
0 0 0 r
.52075 .5179 m .51992 .51759 L .51885 .51748 L F
.52075 .5179 m .52216 .51646 L .51992 .51759 L F
.957 .949 .684 r
.59176 .52802 m .59377 .5265 L .59268 .52549 L F
.812 .687 .144 r
.59377 .5265 m .59385 .52113 L .59268 .52549 L F
.927 .781 .68 r
.54906 .58491 m .55026 .58992 L .54793 .5894 L F
.569 .159 .224 r
.55026 .58992 m .5473 .59223 L .54793 .5894 L F
.55026 .58992 m .55062 .59206 L .5473 .59223 L F
.701 .666 .813 r
.55012 .58652 m .55062 .59206 L .55026 .58992 L F
.404 .461 .806 r
.16911 .64324 m .17065 .64279 L .16775 .64089 L F
.211 0 .09 r
.71761 .39146 m .71489 .39368 L .71756 .39353 L F
.628 .42 .581 r
.71756 .39353 m .7202 .39097 L .71761 .39146 L F
.399 .682 .975 r
.78173 .39934 m .78498 .40079 L .78432 .39908 L F
.28 .523 .907 r
.78498 .40079 m .78744 .40007 L .78432 .39908 L F
.78498 .40079 m .78824 .40186 L .78744 .40007 L F
.507 .011 .013 r
.15927 .57386 m .15942 .5744 L .15632 .57418 L F
0 0 0 r
.16228 .57137 m .16053 .57297 L .15927 .57386 L F
0 0 .172 r
.16053 .57297 m .15942 .5744 L .15927 .57386 L F
0 0 0 r
.20005 .71828 m .19789 .71896 L .19549 .72016 L F
.375 .198 .509 r
.45515 .58018 m .45711 .57953 L .457 .57718 L F
.456 .183 .41 r
.45515 .58018 m .45716 .58229 L .45711 .57953 L F
.45515 .58018 m .45478 .58293 L .45716 .58229 L F
0 0 .319 r
.52757 .57745 m .52712 .57635 L .52595 .5739 L F
0 0 .312 r
.52757 .57745 m .52858 .58012 L .52816 .5785 L F
.185 .193 .633 r
.42011 .64868 m .42014 .65185 L .4198 .64952 L F
.736 .499 0 r
.43492 .62412 m .43537 .62662 L .4354 .62634 L F
.048 0 .41 r
.57564 .58868 m .57563 .5913 L .57385 .59258 L F
.043 0 .258 r
.57563 .5913 m .57305 .59438 L .57385 .59258 L F
.653 .31 .38 r
.20709 .55525 m .21204 .55265 L .20926 .55452 L F
.20709 .55525 m .20783 .55345 L .21204 .55265 L F
.151 0 0 r
.21371 .55263 m .20926 .55452 L .21204 .55265 L F
.725 .296 .23 r
.67376 .40533 m .67603 .40757 L .677 .40573 L F
.658 .22 .197 r
.677 .40573 m .67603 .40757 L .6797 .40782 L F
.012 0 .232 r
.57528 .58339 m .57703 .5803 L .57647 .58274 L F
.068 .028 .499 r
.57647 .58274 m .57569 .58597 L .57528 .58339 L F
.549 .348 .562 r
.4478 .61652 m .4477 .61936 L .44511 .61974 L F
.301 .072 .39 r
.45004 .61357 m .44966 .61582 L .4478 .61652 L F
.457 .274 .544 r
.4499 .61844 m .4478 .61652 L .44966 .61582 L F
.4499 .61844 m .4477 .61936 L .4478 .61652 L F
.5 .551 .84 r
.64359 .41112 m .64669 .4117 L .64536 .40841 L F
.78 .634 .7 r
.64248 .41367 m .64669 .4117 L .64359 .41112 L F
.541 .386 .619 r
.79985 .40926 m .80014 .41221 L .79729 .41289 L F
.601 .505 .718 r
.80039 .41485 m .79729 .41289 L .80014 .41221 L F
.80039 .41485 m .79792 .41555 L .79729 .41289 L F
.298 0 .256 r
.26126 .62779 m .25925 .62846 L .26211 .62582 L F
.378 .061 .297 r
.26343 .62723 m .26211 .62582 L .26384 .62491 L F
.26343 .62723 m .26126 .62779 L .26211 .62582 L F
.152 .409 .853 r
.26422 .56569 m .26488 .56447 L .26349 .56414 L F
.103 .344 .813 r
.26422 .56569 m .26717 .56817 L .26488 .56447 L F
.524 .418 .677 r
.26476 .56843 m .26717 .56817 L .26422 .56569 L F
.961 .864 .458 r
.58948 .5399 m .59004 .53834 L .58902 .53999 L F
0 0 0 r
.59004 .53834 m .59064 .53525 L .59052 .53778 L F
.58902 .53999 m .59004 .53834 L .59052 .53778 L F
.743 .576 .668 r
.69185 .41857 m .68978 .42124 L .68844 .41884 L F
.576 .418 .629 r
.20519 .55595 m .20322 .55425 L .20538 .5534 L F
.20519 .55595 m .20283 .55649 L .20322 .55425 L F
.735 .507 .583 r
.44195 .57618 m .43823 .57423 L .44177 .57455 L F
.615 .411 .582 r
.44432 .57417 m .44195 .57618 L .44177 .57455 L F
.651 .108 0 r
.21569 .68655 m .21834 .68841 L .21492 .68765 L F
.671 .248 .233 r
.23406 .55335 m .23185 .55504 L .22985 .55311 L F
.112 .637 .877 r
.23631 .55581 m .23185 .55504 L .23406 .55335 L F
.692 .448 .549 r
.58467 .47467 m .58818 .47242 L .5846 .47238 L F
.58467 .47467 m .58821 .47481 L .58818 .47242 L F
.625 .395 .548 r
.58818 .47242 m .5908 .47442 L .59075 .47234 L F
.58818 .47242 m .58821 .47481 L .5908 .47442 L F
.662 .463 .605 r
.59423 .46948 m .59678 .4717 L .59683 .4694 L F
.59423 .46948 m .59424 .472 L .59678 .4717 L F
.837 .97 .885 r
.53279 .52238 m .53604 .51922 L .53459 .5192 L F
.53452 .52089 m .53459 .5192 L .53455 .52086 L F
.53279 .52238 m .53449 .51937 L .53452 .52089 L F
.53449 .51937 m .53459 .5192 L .53452 .52089 L F
.682 .897 .974 r
.53057 .5222 m .53449 .52093 L .53086 .52148 L F
.53015 .52321 m .53203 .52223 L .53057 .5222 L F
.53203 .52223 m .53449 .52093 L .53057 .5222 L F
.837 .809 .823 r
.52601 .52482 m .52775 .52585 L .53015 .52321 L F
.52601 .52482 m .53015 .52321 L .52861 .52169 L F
.661 .168 .07 r
.52846 .52215 m .53087 .5236 L .52804 .52347 L F
.52861 .52169 m .52917 .52216 L .52846 .52215 L F
.837 .97 .885 r
.53279 .52238 m .53455 .52086 L .53449 .52093 L F
.558 .934 .887 r
.53279 .52238 m .53449 .52093 L .53015 .52321 L F
.661 .168 .07 r
.52917 .52216 m .53087 .5236 L .52846 .52215 L F
.682 .897 .974 r
.53449 .52093 m .53452 .5209 L .53086 .52148 L F
.53449 .52093 m .53458 .52089 L .53452 .5209 L F
.837 .97 .885 r
.53279 .52238 m .53453 .52162 L .53458 .52089 L F
.729 .459 .518 r
.53458 .52089 m .53453 .52162 L .53452 .5209 L F
.558 .934 .887 r
.53279 .52238 m .53458 .52089 L .53449 .52093 L F
.837 .97 .885 r
.53279 .52238 m .53455 .52088 L .53453 .52162 L F
.729 .459 .518 r
.53452 .5209 m .53453 .52162 L .53086 .52148 L F
.837 .97 .885 r
.53449 .52093 m .53455 .52086 L .53455 .52088 L F
.144 .056 .488 r
.58002 .56821 m .58022 .57058 L .5789 .57145 L F
.159 .058 .482 r
.58045 .57283 m .5789 .57145 L .58022 .57058 L F
.58045 .57283 m .57895 .57411 L .5789 .57145 L F
.364 .621 .951 r
.27812 .54553 m .27987 .54549 L .27934 .54713 L F
.271 .516 .905 r
.27987 .54549 m .28136 .54764 L .27934 .54713 L F
.672 .48 .617 r
.46683 .59234 m .46966 .59249 L .47019 .58978 L F
.457 .219 .463 r
.46966 .59249 m .47268 .58912 L .47019 .58978 L F
.265 0 .129 r
.39498 .60707 m .397 .60675 L .3981 .60457 L F
.347 .011 .245 r
.397 .60675 m .40011 .60378 L .3981 .60457 L F
.483 .334 .603 r
.4291 .63946 m .42671 .63728 L .43056 .63713 L F
.203 0 .056 r
.43135 .63861 m .43056 .63713 L .43287 .63756 L F
.43135 .63861 m .4291 .63946 L .43056 .63713 L F
.856 .97 .653 r
.52493 .52646 m .52298 .52806 L .52249 .52576 L F
0 0 .013 r
.40588 .59589 m .4049 .59763 L .40746 .59475 L F
.625 .061 0 r
.79792 .41555 m .80019 .41722 L .79718 .41609 L F
.536 .319 .532 r
.80039 .41485 m .80019 .41722 L .79792 .41555 L F
.102 0 0 r
.54544 .59308 m .54827 .59278 L .54947 .59242 L F
.504 .805 .999 r
.54827 .59278 m .55165 .59325 L .54947 .59242 L F
0 0 .232 r
.78891 .42696 m .79003 .42614 L .78989 .42412 L F
0 .153 .681 r
.78891 .42696 m .7908 .42929 L .79003 .42614 L F
.683 .471 .593 r
.42202 .64353 m .42172 .64666 L .41976 .6466 L F
.729 .513 .598 r
.42562 .64633 m .42202 .64353 L .42471 .64285 L F
.42562 .64633 m .42172 .64666 L .42202 .64353 L F
.711 .932 .61 r
.79272 .42093 m .78989 .42412 L .79255 .42295 L F
.168 0 .075 r
.79505 .41979 m .79272 .42093 L .79543 .42028 L F
.211 0 .193 r
.79543 .42028 m .79272 .42093 L .79255 .42295 L F
.732 .369 .364 r
.57302 .50164 m .56883 .49942 L .57317 .49948 L F
.689 .432 .53 r
.57317 .49948 m .57483 .50193 L .57302 .50164 L F
.878 .809 .778 r
.21722 .66846 m .21507 .67185 L .214 .66996 L F
.21722 .66846 m .214 .66996 L .21685 .66952 L F
.607 .157 .159 r
.21685 .66952 m .22011 .66982 L .21722 .66846 L F
.297 .783 .716 r
.47819 .61366 m .4774 .61385 L .47421 .61505 L F
.421 0 0 r
.47945 .61415 m .4774 .61385 L .47819 .61366 L F
.256 0 0 r
.4811 .61331 m .47945 .61415 L .47819 .61366 L F
.525 .083 .142 r
.22907 .62721 m .22755 .62589 L .22561 .62775 L F
.408 .111 .346 r
.22907 .62721 m .22976 .62522 L .22755 .62589 L F
.308 .149 .496 r
.56526 .5738 m .56805 .5701 L .56575 .57137 L F
0 0 0 r
.44896 .57243 m .44653 .57336 L .44838 .57219 L F
.991 .878 .612 r
.59456 .51969 m .59545 .51764 L .59448 .51643 L F
.701 .462 .559 r
.58215 .47471 m .5846 .47238 L .58215 .47228 L F
.58215 .47471 m .58467 .47467 L .5846 .47238 L F
.482 .176 .37 r
.45553 .60983 m .45489 .61275 L .45229 .61306 L F
.269 0 .298 r
.45687 .6118 m .45553 .60983 L .45778 .60953 L F
.45687 .6118 m .45489 .61275 L .45553 .60983 L F
.541 .177 .298 r
.47644 .58221 m .48037 .5806 L .47813 .58035 L F
.78 .645 .713 r
.59678 .4717 m .60072 .46971 L .59683 .4694 L F
.595 .635 .861 r
.18954 .65258 m .19001 .64878 L .18751 .6509 L F
.18954 .65258 m .19182 .652 L .19001 .64878 L F
.832 .577 .028 r
.53033 .58944 m .52986 .58847 L .52945 .58558 L F
0 0 .38 r
.53033 .58944 m .53166 .59172 L .52986 .58847 L F
.572 .119 .136 r
.46758 .61929 m .46591 .621 L .46335 .61958 L F
.604 .156 .16 r
.46903 .62095 m .46758 .61929 L .46984 .6198 L F
.46903 .62095 m .46591 .621 L .46758 .61929 L F
.62 .46 .644 r
.46975 .61669 m .46984 .6198 L .46758 .61929 L F
.824 .762 .795 r
.46992 .56566 m .46855 .56782 L .47148 .56839 L F
.993 .841 .48 r
.47014 .57019 m .47148 .56839 L .46855 .56782 L F
.47014 .57019 m .47098 .57185 L .47148 .56839 L F
.579 .647 .882 r
.47148 .56839 m .47251 .56495 L .46992 .56566 L F
.47148 .56839 m .47383 .56781 L .47251 .56495 L F
.709 .386 .429 r
.48779 .6002 m .48685 .59972 L .4877 .59848 L F
.48685 .59972 m .484 .59829 L .48743 .59847 L F
.48685 .59972 m .48743 .59847 L .4877 .59848 L F
.48779 .60033 m .48762 .60023 L .48779 .6002 L F
.48762 .60023 m .484 .59829 L .48779 .6002 L F
.454 .141 .345 r
.49019 .59823 m .48779 .60033 L .4877 .59848 L F
.709 .386 .429 r
.48681 .5998 m .48583 .60023 L .484 .59829 L F
.752 .417 .416 r
.484 .59829 m .48607 .60069 L .48599 .60039 L F
.484 .59829 m .48441 .60085 L .48607 .60069 L F
.709 .386 .429 r
.48583 .60023 m .48528 .60047 L .484 .59829 L F
.55 .241 .396 r
.48603 .60053 m .48637 .60036 L .48599 .60039 L F
.48651 .60044 m .4867 .60046 L .48673 .60032 L F
.48607 .60069 m .48651 .60044 L .48603 .60053 L F
.709 .386 .429 r
.4867 .6005 m .48441 .60085 L .48681 .5998 L F
.752 .417 .416 r
.484 .59829 m .48599 .60039 L .485 .59669 L F
.709 .386 .429 r
.48779 .60033 m .4867 .6005 L .48673 .60032 L F
.48762 .60023 m .48673 .60032 L .48681 .5998 L F
.48779 .60033 m .48673 .60032 L .48762 .60023 L F
.55 .241 .396 r
.48651 .60044 m .48673 .60032 L .48603 .60053 L F
.48673 .60032 m .49035 .5983 L .48637 .60036 L F
.48673 .60032 m .48637 .60036 L .48603 .60053 L F
.48599 .60039 m .49035 .5983 L .485 .59669 L F
.48637 .60036 m .49035 .5983 L .48599 .60039 L F
.709 .386 .429 r
.48528 .60047 m .48441 .60085 L .48436 .60056 L F
.48528 .60047 m .48436 .60056 L .484 .59829 L F
.454 .141 .345 r
.49019 .59823 m .48972 .59994 L .48779 .60033 L F
.66 .432 .563 r
.48398 .6033 m .48607 .60069 L .48441 .60085 L F
.653 .403 .527 r
.48614 .60125 m .48398 .6033 L .48603 .60131 L F
.48779 .60033 m .48602 .60171 L .48614 .60125 L F
.48602 .60171 m .48398 .6033 L .48614 .60125 L F
.447 .29 .574 r
.48607 .60069 m .48616 .60118 L .48626 .60081 L F
.66 .432 .563 r
.48398 .6033 m .48616 .60118 L .48607 .60069 L F
.653 .403 .527 r
.48779 .60033 m .48414 .60236 L .48642 .6007 L F
.48672 .60049 m .48642 .6007 L .4867 .6005 L F
.48779 .60033 m .48642 .6007 L .48672 .60049 L F
.48779 .60033 m .48653 .60321 L .48398 .6033 L F
.363 .1 .375 r
.48938 .60097 m .48779 .60033 L .48972 .59994 L F
.4889 .60245 m .48873 .60212 L .48938 .60097 L F
.48838 .60146 m .48929 .60093 L .48938 .60097 L F
.48873 .60212 m .48838 .60146 L .48938 .60097 L F
.48838 .60146 m .48779 .60033 L .48929 .60093 L F
.4889 .60245 m .48653 .60321 L .48693 .60229 L F
.48838 .60146 m .48693 .60229 L .48779 .60033 L F
.4889 .60245 m .48693 .60229 L .48838 .60146 L F
.447 .29 .574 r
.48642 .6007 m .4879 .60174 L .4895 .60081 L F
.4879 .60174 m .4889 .60245 L .4895 .60081 L F
.48626 .60081 m .4889 .60245 L .48642 .6007 L F
.595 .341 .502 r
.49197 .59967 m .4889 .60245 L .48942 .60086 L F
.999 .828 .498 r
.4895 .60081 m .4895 .60081 L .4895 .60081 L F
.4895 .60081 m .4889 .60245 L .48779 .60186 L F
.4895 .60081 m .4895 .60081 L .4895 .60081 L F
.55 .241 .396 r
.48948 .60081 m .4895 .60081 L .48948 .6008 L F
.595 .341 .502 r
.49135 .59974 m .4895 .60081 L .48972 .59994 L F
.48949 .60076 m .48942 .60086 L .48948 .60068 L F
.55 .241 .396 r
.48947 .6008 m .4895 .60081 L .48957 .60061 L F
.595 .341 .502 r
.4895 .60081 m .48948 .60068 L .48972 .59994 L F
.55 .241 .396 r
.48762 .59982 m .48947 .6008 L .49035 .5983 L F
.449 .185 .42 r
.49201 .59754 m .48992 .59992 L .48988 .59978 L F
.49237 .59716 m .49205 .59752 L .49201 .59754 L F
.49205 .59752 m .48992 .59992 L .49201 .59754 L F
.49176 .59785 m .49197 .59967 L .48992 .59992 L F
.49237 .59716 m .49227 .59776 L .49176 .59785 L F
.49227 .59776 m .49197 .59967 L .49176 .59785 L F
.49237 .59716 m .48972 .59994 L .49019 .59823 L F
.722 .761 .259 r
.49035 .5983 m .49014 .5989 L .48992 .59911 L F
.55 .241 .396 r
.48947 .6008 m .48957 .60061 L .48986 .59973 L F
.48985 .59971 m .48986 .59973 L .49035 .5983 L F
.48947 .6008 m .48986 .59973 L .48985 .59971 L F
.722 .761 .259 r
.49011 .59899 m .4895 .60081 L .48992 .59911 L F
.49 .213 .421 r
.49518 .59497 m .49237 .59716 L .49286 .59551 L F
.49518 .59497 m .49554 .59599 L .49237 .59716 L F
.537 .604 .868 r
.48755 .59403 m .49286 .59677 L .49425 .59479 L F
.454 .885 .88 r
.49237 .59716 m .49348 .59675 L .49335 .59662 L F
.49348 .59675 m .49554 .59599 L .49351 .59658 L F
.49348 .59675 m .49351 .59658 L .49335 .59662 L F
.537 .604 .868 r
.49287 .59674 m .49351 .59658 L .49425 .59479 L F
.49286 .59677 m .49288 .59676 L .49287 .59674 L F
.49288 .59676 m .49351 .59658 L .49287 .59674 L F
.711 .794 .318 r
.49425 .59479 m .49351 .59658 L .49359 .5962 L F
.454 .885 .88 r
.49288 .59676 m .49426 .59613 L .49359 .5962 L F
.094 0 .296 r
.49289 .59698 m .49288 .59676 L .49359 .5962 L F
.537 .604 .868 r
.49288 .59678 m .49272 .59723 L .49333 .59701 L F
.094 0 .296 r
.49275 .59714 m .49288 .59678 L .49289 .59698 L F
.454 .885 .88 r
.49237 .59716 m .49426 .59613 L .49288 .59676 L F
.094 0 .296 r
.49288 .59678 m .49288 .59676 L .49289 .59698 L F
.537 .604 .868 r
.49288 .59676 m .49333 .59701 L .49351 .59658 L F
.094 0 .296 r
.49275 .59714 m .49237 .59716 L .49288 .59676 L F
.537 .604 .868 r
.49286 .59677 m .49288 .59678 L .49288 .59676 L F
.49288 .59678 m .49333 .59701 L .49288 .59676 L F
.711 .794 .318 r
.49351 .59658 m .49333 .59701 L .49359 .5962 L F
.757 .552 .619 r
.49299 .59723 m .49359 .5962 L .49333 .59701 L F
.094 0 .296 r
.49305 .59712 m .4929 .59713 L .49359 .5962 L F
.4929 .59713 m .49275 .59714 L .49289 .59698 L F
.4929 .59713 m .49289 .59698 L .49359 .5962 L F
.49369 .59856 m .49197 .59967 L .49227 .59776 L F
.49264 .59745 m .49227 .59776 L .49237 .59716 L F
.49369 .59856 m .49227 .59776 L .49264 .59745 L F
.537 .604 .868 r
.49022 .59811 m .49115 .59795 L .49296 .59717 L F
.49302 .59712 m .49296 .59717 L .49333 .59701 L F
.094 0 .296 r
.49252 .59732 m .49237 .59716 L .49275 .59714 L F
.537 .604 .868 r
.49272 .59723 m .49296 .59717 L .49302 .59712 L F
.49271 .59726 m .49296 .59717 L .49272 .59723 L F
.722 .761 .259 r
.4927 .59729 m .49299 .59723 L .49333 .59701 L F
.094 0 .296 r
.4927 .59729 m .49275 .59714 L .49363 .59709 L F
.49252 .59732 m .49275 .59714 L .4927 .59729 L F
.537 .604 .868 r
.49022 .59811 m .49271 .59726 L .49272 .59723 L F
.49235 .597 m .49022 .59811 L .49272 .59723 L F
.48755 .59403 m .49272 .59723 L .49288 .59678 L F
.094 0 .296 r
.49369 .59856 m .49252 .59732 L .49363 .59709 L F
.722 .761 .259 r
.49115 .59795 m .48992 .59911 L .49299 .59723 L F
.49115 .59795 m .49299 .59723 L .4927 .59729 L F
.757 .552 .619 r
.48992 .59911 m .49359 .5962 L .49299 .59723 L F
.094 0 .296 r
.49363 .59709 m .49305 .59712 L .49359 .5962 L F
.454 .885 .88 r
.49335 .59662 m .49554 .59599 L .49426 .59613 L F
.49554 .59599 m .49554 .59599 L .49335 .59662 L F
.537 .604 .868 r
.48755 .59403 m .49015 .598 L .49235 .597 L F
.49015 .598 m .49022 .59811 L .49235 .597 L F
.722 .761 .259 r
.49035 .5983 m .49032 .59834 L .49115 .59795 L F
.49032 .59834 m .48992 .59911 L .49115 .59795 L F
.537 .604 .868 r
.49022 .59811 m .49035 .5983 L .49115 .59795 L F
.449 .185 .42 r
.48988 .59978 m .48992 .59992 L .48972 .59994 L F
.999 .828 .498 r
.4895 .60081 m .4895 .60081 L .4895 .60081 L F
.595 .341 .502 r
.4895 .60081 m .48945 .60084 L .48949 .60076 L F
.48945 .60084 m .48942 .60086 L .48949 .60076 L F
.999 .828 .498 r
.4895 .60081 m .4902 .60049 L .48992 .59911 L F
.595 .341 .502 r
.49197 .59967 m .48942 .60086 L .49135 .59974 L F
.999 .828 .498 r
.4895 .60081 m .4902 .60049 L .4895 .60081 L F
.4895 .60081 m .48934 .60091 L .48956 .60078 L F
.4895 .60081 m .48934 .60091 L .4895 .60081 L F
.48956 .60078 m .48779 .60186 L .4902 .60049 L F
.48934 .60091 m .48779 .60186 L .48956 .60078 L F
.4895 .60081 m .48779 .60186 L .4895 .60081 L F
.55 .241 .396 r
.48689 .60035 m .48948 .60081 L .48762 .59982 L F
.48948 .60081 m .48948 .6008 L .48762 .59982 L F
.447 .29 .574 r
.48607 .60069 m .48626 .60081 L .48642 .6007 L F
.48626 .60081 m .48653 .60321 L .4889 .60245 L F
.48616 .60118 m .48653 .60321 L .48626 .60081 L F
.66 .432 .563 r
.48398 .6033 m .48653 .60321 L .48616 .60118 L F
.653 .403 .527 r
.48603 .60131 m .48398 .6033 L .48414 .60236 L F
.55 .241 .396 r
.48607 .60069 m .48639 .6007 L .48651 .60044 L F
.653 .403 .527 r
.4867 .6005 m .48414 .60236 L .48441 .60085 L F
.55 .241 .396 r
.48673 .60032 m .48689 .60035 L .48762 .59982 L F
.4867 .60046 m .4895 .60081 L .48673 .60032 L F
.48639 .6007 m .4895 .60081 L .48651 .60044 L F
0 0 0 r
.6635 .40331 m .66355 .40458 L .66077 .40584 L F
.66471 .40344 m .6635 .40331 L .66604 .40374 L F
.66471 .40344 m .66355 .40458 L .6635 .40331 L F
.497 .55 .841 r
.16476 .6394 m .16567 .63644 L .16415 .63746 L F
.16476 .6394 m .16711 .63949 L .16567 .63644 L F
.347 .011 .246 r
.56027 .48752 m .5574 .48981 L .55974 .48909 L F
.383 .103 .36 r
.55974 .48909 m .5624 .48654 L .56027 .48752 L F
.252 0 0 r
.19351 .55709 m .19256 .55832 L .19029 .55885 L F
.333 0 0 r
.19719 .55619 m .19256 .55832 L .19351 .55709 L F
.452 0 0 r
.45642 .55888 m .4587 .56006 L .46019 .56012 L F
.058 0 0 r
.4587 .56006 m .46291 .55999 L .46019 .56012 L F
.869 .852 .823 r
.77362 .42246 m .77728 .42182 L .77612 .41951 L F
.77362 .42246 m .77507 .42453 L .77728 .42182 L F
.243 0 .296 r
.77507 .42453 m .77716 .42341 L .77728 .42182 L F
.958 .858 .7 r
.77564 .42057 m .77728 .42182 L .77612 .41951 L F
.869 .852 .823 r
.77498 .42206 m .77612 .41951 L .77555 .4219 L F
.77362 .42246 m .77612 .41951 L .77498 .42206 L F
.958 .858 .7 r
.77523 .42026 m .77564 .42057 L .77612 .41951 L F
.837 .77 .787 r
.52656 .53532 m .52387 .53864 L .52741 .53715 L F
.424 .245 .532 r
.52741 .53715 m .52949 .53752 L .53106 .53761 L F
.52741 .53715 m .52689 .53947 L .52949 .53752 L F
.899 .68 .597 r
.59831 .49517 m .60057 .49381 L .59846 .49268 L F
.59831 .49517 m .60024 .49662 L .60057 .49381 L F
.452 .713 .979 r
.25563 .5514 m .25918 .55355 L .26018 .55274 L F
.026 0 0 r
.71177 .39897 m .70975 .39942 L .70917 .39943 L F
.99 .734 .372 r
.75995 .42973 m .761 .43355 L .76 .43242 L F
.134 .549 .922 r
.76 .43242 m .761 .43355 L .76425 .43431 L F
.49 .184 .374 r
.4477 .61936 m .44748 .62126 L .44511 .61974 L F
.825 .753 .783 r
.77716 .42341 m .77781 .42504 L .78016 .42401 L F
.248 .762 .788 r
.21549 .53975 m .22138 .53874 L .21741 .53879 L F
.21549 .53975 m .21768 .53921 L .22138 .53874 L F
0 0 0 r
.21768 .53921 m .22135 .53851 L .22138 .53874 L F
.104 .657 .793 r
.22138 .53874 m .22135 .53851 L .22352 .53868 L F
0 0 .45 r
.5083 .57785 m .50864 .57917 L .50726 .57665 L F
.5083 .57785 m .50726 .57665 L .50579 .57578 L F
0 .126 .621 r
.50716 .57665 m .50797 .5775 L .50579 .57578 L F
.50797 .5775 m .5083 .57785 L .50794 .57755 L F
.50797 .5775 m .50794 .57755 L .50579 .57578 L F
0 0 .201 r
.5083 .57785 m .50854 .57875 L .50864 .57917 L F
0 0 .398 r
.5088 .57985 m .50864 .57917 L .50903 .58034 L F
.722 .246 0 r
.5093 .58154 m .50903 .58034 L .50864 .57917 L F
0 0 .201 r
.50854 .57875 m .5093 .58154 L .50864 .57917 L F
0 0 .398 r
.50781 .5778 m .50864 .57917 L .5088 .57985 L F
.50726 .57665 m .50785 .57773 L .50781 .5778 L F
.50785 .57773 m .50864 .57917 L .50781 .5778 L F
.722 .246 0 r
.5093 .58154 m .51034 .58248 L .50903 .58034 L F
.78 .645 .713 r
.59678 .4717 m .60039 .4722 L .60072 .46971 L F
.784 .615 .671 r
.59678 .4717 m .59825 .47514 L .60039 .4722 L F
.261 .391 .806 r
.39409 .6193 m .39562 .6228 L .39682 .62113 L F
.216 .328 .764 r
.39562 .6228 m .39803 .62472 L .39682 .62113 L F
.403 .504 .848 r
.79174 .43171 m .79376 .42896 L .7908 .42929 L F
.79174 .43171 m .79458 .43218 L .79376 .42896 L F
.623 .625 .832 r
.64301 .42192 m .64655 .42441 L .64532 .42075 L F
.69 .627 .781 r
.64532 .42075 m .64655 .42441 L .65058 .42131 L F
.551 .076 .08 r
.45027 .55905 m .45208 .56021 L .45376 .55874 L F
.615 .205 .241 r
.45208 .56021 m .45642 .55888 L .45376 .55874 L F
.562 .318 .505 r
.4555 .62269 m .45496 .62512 L .45242 .62537 L F
.489 .252 .48 r
.45742 .6245 m .4555 .62269 L .45719 .62181 L F
.45742 .6245 m .45496 .62512 L .4555 .62269 L F
.577 .454 .676 r
.47245 .59412 m .46966 .59249 L .47359 .59225 L F
0 0 0 r
.475 .59158 m .47245 .59412 L .47359 .59225 L F
.558 .011 0 r
.67013 .44083 m .67108 .43988 L .67433 .44183 L F
.444 .262 .538 r
.24958 .59852 m .25186 .59785 L .25188 .5953 L F
.456 .229 .48 r
.24958 .59852 m .25158 .60042 L .25186 .59785 L F
.24958 .59852 m .24926 .60092 L .25158 .60042 L F
.185 .378 .821 r
.40587 .64059 m .4087 .64256 L .40682 .63913 L F
.482 .092 .225 r
.44278 .63754 m .44137 .64119 L .43855 .64009 L F
.579 .596 .834 r
.44355 .6343 m .44521 .63721 L .44278 .63754 L F
.353 0 .173 r
.44456 .63776 m .44278 .63754 L .44521 .63721 L F
.44456 .63776 m .44137 .64119 L .44278 .63754 L F
.972 .754 .549 r
.44635 .56146 m .44438 .5598 L .44413 .56123 L F
.44635 .56146 m .44767 .55949 L .44438 .5598 L F
.287 .167 .536 r
.25651 .58658 m .25815 .58828 L .2585 .58587 L F
.25651 .58658 m .25646 .58919 L .25815 .58828 L F
.575 .745 .957 r
.22026 .68276 m .21818 .68342 L .21662 .68192 L F
.471 .261 .512 r
.28554 .59491 m .28307 .59801 L .28338 .59548 L F
.754 .697 .798 r
.42869 .60944 m .4302 .61419 L .4275 .61336 L F
.634 .142 0 r
.42856 .61494 m .4275 .61336 L .4302 .61419 L F
.42 0 .046 r
.52711 .51552 m .53086 .51377 L .52872 .51466 L F
.519 .327 .561 r
.52997 .53543 m .53286 .53532 L .53239 .53238 L F
.516 .312 .542 r
.53238 .53733 m .53286 .53532 L .52997 .53543 L F
.339 .67 .976 r
.2436 .55643 m .24581 .55656 L .2441 .55512 L F
.2441 .55512 m .24581 .55656 L .2436 .55643 L F
.609 .049 0 r
.23929 .53733 m .2401 .53834 L .24316 .53823 L F
.314 0 0 r
.2401 .53834 m .24422 .53875 L .24316 .53823 L F
.808 .778 .825 r
.7188 .39726 m .72177 .39467 L .72027 .39285 L F
.228 .522 .915 r
.72027 .39285 m .72177 .39467 L .72176 .39358 L F
.653 .887 .537 r
.72177 .39467 m .72366 .39115 L .72176 .39358 L F
0 .178 .71 r
.4253 .57949 m .42343 .57825 L .42427 .5789 L F
.22 .464 .879 r
.16711 .63949 m .16775 .64089 L .16865 .63972 L F
.202 .436 .863 r
.16775 .64089 m .17065 .64279 L .16865 .63972 L F
.77 .675 .757 r
.20519 .55595 m .20676 .55949 L .20277 .55925 L F
.201 .713 .891 r
.20676 .55949 m .20538 .55913 L .20277 .55925 L F
.34 .115 .42 r
.20891 .55481 m .20676 .55661 L .20709 .55525 L F
.331 0 .086 r
.20891 .55481 m .20741 .55596 L .20676 .55661 L F
.129 .303 .772 r
.20676 .55661 m .20588 .5575 L .20519 .55595 L F
.331 0 .086 r
.20741 .55596 m .20467 .55806 L .20676 .55661 L F
.129 .303 .772 r
.20676 .55661 m .20676 .55949 L .20588 .5575 L F
.904 .949 .821 r
.20676 .55661 m .20538 .55913 L .20676 .55949 L F
.699 .859 .959 r
.50258 .52576 m .49901 .52576 L .50109 .52489 L F
.787 .907 .924 r
.50258 .52576 m .5039 .52284 L .50533 .52352 L F
.50258 .52576 m .50109 .52489 L .5039 .52284 L F
0 0 .182 r
.5838 .55831 m .58235 .56194 L .58279 .55969 L F
.74 .437 .468 r
.77112 .42607 m .77507 .42453 L .77362 .42246 L F
.77112 .42607 m .77473 .42647 L .77507 .42453 L F
.609 .548 .761 r
.77507 .42453 m .77781 .42504 L .77716 .42341 L F
.487 .513 .81 r
.14769 .56233 m .14935 .56128 L .15042 .5598 L F
.17 0 .009 r
.15042 .5598 m .15133 .56051 L .15256 .55924 L F
.15042 .5598 m .14935 .56128 L .15133 .56051 L F
.735 .972 .717 r
.68525 .43493 m .68395 .43704 L .68549 .43526 L F
.738 .977 .92 r
.68179 .43701 m .68395 .43704 L .68525 .43493 L F
.494 .573 .864 r
.71489 .39368 m .7188 .39726 L .71756 .39353 L F
.433 .847 .677 r
.7188 .39726 m .71531 .39924 L .71863 .3998 L F
.808 .778 .825 r
.7188 .39726 m .72027 .39285 L .71756 .39353 L F
.193 0 0 r
.26169 .54114 m .26394 .54178 L .26539 .54218 L F
.127 .644 .89 r
.26394 .54178 m .26798 .54249 L .26539 .54218 L F
.315 0 0 r
.49261 .53688 m .49476 .53673 L .49449 .5372 L F
.576 .875 .574 r
.4942 .53768 m .49449 .5372 L .49587 .536 L F
.646 .169 .107 r
.49587 .536 m .49449 .5372 L .49778 .53742 L F
.315 0 0 r
.49476 .53673 m .49663 .53661 L .49449 .5372 L F
.576 .875 .574 r
.49334 .53854 m .49449 .5372 L .4942 .53768 L F
.441 .304 .598 r
.49587 .536 m .49778 .53742 L .49781 .53484 L F
.49587 .536 m .49778 .53742 L .49781 .53484 L F
.909 .721 .635 r
.49334 .53854 m .49068 .53954 L .49189 .53829 L F
.49334 .53854 m .49282 .54146 L .49068 .53954 L F
.598 .924 .968 r
.49334 .53854 m .49189 .53829 L .49449 .5372 L F
.392 .671 .971 r
.46802 .61527 m .46975 .61669 L .4655 .61522 L F
.525 .386 .633 r
.47227 .61904 m .46984 .6198 L .46975 .61669 L F
.76 .669 .762 r
.20769 .72162 m .20375 .71964 L .20465 .71902 L F
.20769 .72162 m .20429 .72213 L .20253 .71902 L F
.328 .63 .961 r
.20793 .72005 m .20769 .72162 L .20465 .71902 L F
0 0 .1 r
.20465 .71902 m .20631 .71759 L .20793 .72005 L F
.2035 .72201 m .20346 .7221 L .20353 .722 L F
.726 .353 0 r
.20198 .71913 m .20344 .72205 L .20218 .71898 L F
.20344 .72205 m .20346 .7221 L .20345 .72207 L F
.20344 .72205 m .20345 .72207 L .20218 .71898 L F
.639 .931 .97 r
.20314 .72219 m .20321 .72172 L .20221 .72189 L F
.76 .669 .762 r
.20375 .71964 m .20253 .71902 L .20465 .71902 L F
.618 .33 .458 r
.20218 .71898 m .20465 .71902 L .20253 .71902 L F
.20218 .71898 m .20346 .7221 L .20465 .71902 L F
0 0 .1 r
.20465 .71902 m .2035 .72201 L .20597 .71811 L F
.2035 .72201 m .20353 .722 L .20597 .71811 L F
.20465 .71902 m .20597 .71811 L .20631 .71759 L F
.327 0 0 r
.20218 .71898 m .20253 .71902 L .20005 .71828 L F
.843 .777 .788 r
.20631 .71759 m .20346 .7221 L .20198 .71913 L F
.639 .931 .97 r
.20321 .72172 m .20336 .72068 L .20285 .72122 L F
.20321 .72172 m .20285 .72122 L .20221 .72189 L F
.765 .968 .927 r
.20314 .72219 m .2065 .72157 L .20793 .72005 L F
.20367 .72197 m .20793 .72005 L .20688 .72066 L F
.20314 .72219 m .20357 .72199 L .20367 .72197 L F
.20357 .72199 m .20793 .72005 L .20367 .72197 L F
.138 0 0 r
.2065 .72157 m .20429 .72213 L .20769 .72162 L F
.758 .989 .893 r
.20793 .72005 m .2065 .72157 L .20769 .72162 L F
0 0 0 r
.57406 .54744 m .57488 .54599 L .57511 .54409 L F
.57386 .54796 m .57406 .54744 L .57382 .55001 L F
.57386 .54796 m .57488 .54599 L .57406 .54744 L F
.392 .671 .971 r
.46802 .61527 m .4655 .61522 L .46627 .6155 L F
.498 0 0 r
.51026 .55368 m .50967 .55315 L .50856 .55222 L F
.51026 .55368 m .51207 .55541 L .50967 .55315 L F
.38 0 .069 r
.22489 .67352 m .22362 .67536 L .222 .67508 L F
0 0 .399 r
.22612 .66972 m .22489 .67352 L .22486 .67057 L F
.22612 .66972 m .22611 .67243 L .22489 .67352 L F
0 0 0 r
.22611 .67243 m .22362 .67536 L .22489 .67352 L F
.719 .798 .913 r
.72888 .40415 m .72997 .40583 L .72639 .4055 L F
.678 .781 .928 r
.73289 .40439 m .72997 .40583 L .72888 .40415 L F
.87 .941 .862 r
.68745 .42464 m .68493 .42752 L .68415 .42632 L F
.09 0 0 r
.16257 .57232 m .16228 .57137 L .16483 .57045 L F
.16257 .57232 m .16053 .57297 L .16228 .57137 L F
.578 .246 .37 r
.55669 .50275 m .55657 .50471 L .55434 .50449 L F
.546 .177 .293 r
.56026 .50232 m .55657 .50471 L .55669 .50275 L F
.441 .22 .481 r
.45323 .58883 m .45076 .59174 L .45131 .58977 L F
.691 .476 .591 r
.69316 .40848 m .69566 .40909 L .69579 .40616 L F
.461 .285 .555 r
.69579 .40616 m .69689 .4059 L .69821 .40528 L F
.69579 .40616 m .69566 .40909 L .69689 .4059 L F
.971 .655 .319 r
.49751 .53245 m .49637 .53203 L .49418 .53186 L F
.49751 .53245 m .49781 .53484 L .49637 .53203 L F
.952 .765 .614 r
.59638 .5068 m .59844 .50536 L .59692 .50431 L F
.59638 .5068 m .59786 .50774 L .59844 .50536 L F
.939 .825 .705 r
.59844 .50536 m .59785 .50188 L .59692 .50431 L F
0 0 .081 r
.40824 .59268 m .40746 .59475 L .4094 .59153 L F
.467 .766 .995 r
.18086 .62456 m .18274 .62582 L .18047 .62606 L F
.645 .916 .979 r
.65426 .42406 m .65428 .42238 L .65282 .42438 L F
.866 .915 .514 r
.65581 .41923 m .65426 .42406 L .65776 .41986 L F
.65581 .41923 m .65428 .42238 L .65426 .42406 L F
.453 .201 .441 r
.45229 .61306 m .44966 .61582 L .45004 .61357 L F
.743 .989 .89 r
.69131 .43119 m .6946 .42992 L .69361 .43093 L F
0 0 0 r
.69361 .43093 m .6946 .42992 L .69715 .42896 L F
.368 .464 .827 r
.66201 .44292 m .66076 .44504 L .65937 .44336 L F
.66201 .44292 m .66353 .44582 L .66076 .44504 L F
.487 .308 .564 r
.66353 .44582 m .66293 .4475 L .66076 .44504 L F
.527 .313 .532 r
.66076 .44504 m .66293 .4475 L .66067 .44681 L F
.919 .811 .724 r
.74871 .41088 m .74633 .41139 L .74803 .40828 L F
.911 .864 .78 r
.74871 .41088 m .74662 .41466 L .74633 .41139 L F
.671 .653 .824 r
.77062 .38903 m .76694 .38797 L .76976 .38824 L F
.796 .94 .922 r
.77207 .38783 m .77062 .38903 L .76976 .38824 L F
.402 .129 .381 r
.79613 .44072 m .79369 .43971 L .79631 .43894 L F
.79613 .44072 m .79365 .44153 L .79369 .43971 L F
.632 .736 .923 r
.16096 .61895 m .16079 .62167 L .15932 .61897 L F
.16096 .61895 m .16315 .62064 L .16079 .62167 L F
.706 .733 .872 r
.55678 .59123 m .55488 .59466 L .55416 .59449 L F
.55678 .59123 m .55833 .59286 L .55488 .59466 L F
.546 .177 .293 r
.56026 .50232 m .55893 .50468 L .55657 .50471 L F
.561 .193 .301 r
.56255 .50386 m .56026 .50232 L .56253 .5022 L F
.56255 .50386 m .55893 .50468 L .56026 .50232 L F
.599 .431 .625 r
.56272 .49931 m .56253 .5022 L .56026 .50232 L F
.449 .207 .453 r
.26126 .62779 m .25864 .63071 L .25925 .62846 L F
0 0 .178 r
.56782 .56815 m .56891 .56674 L .56929 .56429 L F
0 0 .211 r
.56782 .56815 m .56805 .5701 L .56891 .56674 L F
.948 .811 .675 r
.76686 .4181 m .76424 .42018 L .76559 .41668 L F
.76686 .4181 m .76626 .42023 L .76424 .42018 L F
.974 .888 .679 r
.76674 .41487 m .76686 .4181 L .76559 .41668 L F
.2 0 0 r
.2131 .53992 m .21549 .53975 L .21741 .53879 L F
.393 .097 .339 r
.17813 .56185 m .17569 .56411 L .17645 .56322 L F
.075 0 .163 r
.41775 .59757 m .41491 .60125 L .41579 .59913 L F
.987 .895 .577 r
.43501 .60128 m .43555 .60377 L .43443 .6022 L F
.4358 .60001 m .43563 .60258 L .43501 .60128 L F
.43563 .60258 m .43555 .60377 L .43501 .60128 L F
.4358 .60001 m .43461 .60314 L .43555 .60377 L F
.874 .455 .212 r
.43461 .60314 m .43769 .60488 L .43555 .60377 L F
.43461 .60314 m .43661 .60461 L .43638 .60413 L F
.984 .897 .571 r
.4358 .60001 m .43461 .60314 L .43428 .60157 L F
0 .04 .609 r
.43461 .60314 m .43534 .60431 L .43428 .60157 L F
.985 .768 .527 r
.43428 .60157 m .43406 .60449 L .43534 .60431 L F
.43406 .60449 m .43405 .60456 L .43534 .60431 L F
.874 .455 .212 r
.43606 .60421 m .43534 .60431 L .43661 .60461 L F
.43461 .60314 m .43534 .60431 L .43606 .60421 L F
.43638 .60413 m .43661 .60461 L .43769 .60488 L F
0 0 0 r
.18463 .55989 m .18245 .56054 L .18025 .56118 L F
.343 .819 .884 r
.18664 .56002 m .18245 .56054 L .18463 .55989 L F
.281 0 0 r
.18787 .5593 m .18664 .56002 L .18463 .55989 L F
0 0 .344 r
.77218 .43179 m .77237 .43473 L .77145 .43565 L F
.039 .301 .791 r
.77237 .43473 m .77426 .43794 L .77145 .43565 L F
.126 .602 .918 r
.76541 .4352 m .76612 .43474 L .76425 .43431 L F
.76541 .4352 m .76673 .43544 L .76612 .43474 L F
.613 .155 0 r
.76564 .43418 m .76612 .43474 L .76713 .43614 L F
.262 .62 .959 r
.76425 .43431 m .76612 .43474 L .7651 .43347 L F
.613 .155 0 r
.7651 .43347 m .76612 .43474 L .76564 .43418 L F
.126 .602 .918 r
.76673 .43544 m .7675 .43557 L .76612 .43474 L F
.608 .039 0 r
.50609 .53683 m .50651 .53664 L .50506 .53559 L F
.633 .89 .56 r
.50651 .53664 m .50534 .53832 L .50696 .53643 L F
.313 .516 .893 r
.50651 .53664 m .50783 .538 L .50534 .53832 L F
.608 .039 0 r
.50679 .53766 m .50651 .53664 L .50609 .53683 L F
.633 .89 .56 r
.50651 .53664 m .50696 .53643 L .50784 .53539 L F
.357 0 0 r
.22133 .55309 m .22197 .55392 L .21994 .55405 L F
.22133 .55309 m .22375 .55326 L .22197 .55392 L F
0 0 0 r
.76166 .37906 m .75893 .38206 L .76067 .38107 L F
.262 .375 .79 r
.76155 .38014 m .76115 .38269 L .76249 .38077 L F
0 0 0 r
.76166 .37906 m .76067 .38107 L .76061 .37767 L F
0 0 .348 r
.76067 .38107 m .75898 .38439 L .76115 .38269 L F
.975 .671 .305 r
.75974 .37892 m .76061 .37767 L .76067 .38107 L F
0 0 .348 r
.76067 .38107 m .75893 .38206 L .75896 .38369 L F
.76067 .38107 m .75896 .38369 L .76021 .38198 L F
.952 .741 .581 r
.76067 .38107 m .76115 .38269 L .75974 .37892 L F
.262 .375 .79 r
.75974 .37892 m .76065 .38137 L .76155 .38014 L F
.76065 .38137 m .76115 .38269 L .76155 .38014 L F
0 0 .348 r
.76021 .38198 m .75896 .38369 L .75898 .38439 L F
.333 0 0 r
.19719 .55619 m .19491 .55802 L .19256 .55832 L F
.634 .22 .239 r
.19897 .55785 m .19719 .55619 L .19902 .55681 L F
.19897 .55785 m .19491 .55802 L .19719 .55619 L F
.212 .129 .54 r
.39344 .61308 m .39509 .6093 L .39291 .6106 L F
.274 0 0 r
.19394 .73602 m .19237 .73563 L .19 .73565 L F
.19 .73565 m .19237 .73563 L .19394 .73602 L F
.569 .764 .97 r
.51784 .6012 m .51629 .60217 L .5146 .60037 L F
.906 .92 .816 r
.41456 .65261 m .41309 .65214 L .4156 .64855 L F
.674 .183 0 r
.41564 .65505 m .41309 .65214 L .41456 .65261 L F
.833 .627 .624 r
.44002 .63061 m .4383 .634 L .4382 .63126 L F
.43946 .63172 m .44178 .63333 L .4383 .634 L F
.772 .435 .416 r
.43981 .63355 m .44302 .63419 L .44178 .63333 L F
.44302 .63419 m .44355 .6343 L .44178 .63333 L F
.833 .627 .624 r
.44002 .63061 m .44178 .63333 L .43946 .63172 L F
.028 0 .121 r
.41321 .58676 m .41237 .5887 L .41479 .58565 L F
.134 .27 .74 r
.55456 .5906 m .55521 .5878 L .55294 .58574 L F
.874 .993 .801 r
.55278 .59086 m .55521 .5878 L .55456 .5906 L F
.157 .677 .886 r
.23212 .53859 m .23405 .53832 L .23606 .53904 L F
.082 .614 .866 r
.23222 .53784 m .23297 .53799 L .23405 .53832 L F
.407 0 0 r
.23405 .53832 m .23929 .53733 L .23618 .53897 L F
.23405 .53832 m .23609 .53862 L .23929 .53733 L F
.082 .614 .866 r
.23297 .53799 m .23609 .53862 L .23405 .53832 L F
.407 0 0 r
.23405 .53832 m .23618 .53897 L .23606 .53904 L F
.274 .735 .951 r
.19182 .652 m .19565 .65251 L .19378 .65182 L F
.426 .745 .993 r
.19565 .65251 m .19607 .65111 L .19378 .65182 L F
.19565 .65251 m .19805 .65241 L .19607 .65111 L F
0 0 0 r
.55839 .60773 m .5604 .60674 L .5566 .60879 L F
.834 .528 .472 r
.52582 .53135 m .52844 .52963 L .52726 .52834 L F
.52582 .53135 m .52933 .53226 L .52844 .52963 L F
.708 .587 .719 r
.74662 .41466 m .74552 .41606 L .74327 .41497 L F
.325 .731 .98 r
.18721 .62499 m .18671 .62596 L .18487 .62525 L F
.18721 .62499 m .18911 .62601 L .18671 .62596 L F
.482 .549 .848 r
.19015 .62869 m .18671 .62596 L .18911 .62601 L F
.763 .922 .941 r
.42586 .58215 m .42348 .58395 L .42546 .58439 L F
0 0 .56 r
.67072 .40247 m .67199 .40497 L .67132 .40536 L F
.193 0 0 r
.50713 .55088 m .50424 .5523 L .50419 .54988 L F
.429 0 0 r
.50967 .55315 m .50936 .55332 L .50623 .55205 L F
.50936 .55332 m .50919 .55342 L .50875 .55321 L F
.50936 .55332 m .50875 .55321 L .50623 .55205 L F
.803 .34 .133 r
.50919 .55342 m .50764 .55224 L .50623 .55205 L F
.193 0 0 r
.50506 .5519 m .50623 .55205 L .50424 .5523 L F
.50713 .55088 m .50623 .55205 L .50506 .5519 L F
.704 .197 .03 r
.50856 .55222 m .50623 .55205 L .50713 .55088 L F
.429 0 0 r
.50967 .55315 m .50623 .55205 L .50856 .55222 L F
.47 .719 .978 r
.50424 .5523 m .50623 .55205 L .50553 .55063 L F
.805 .323 .059 r
.50553 .55063 m .50723 .55294 L .50469 .55153 L F
.50723 .55294 m .5074 .55318 L .50693 .55289 L F
.50723 .55294 m .50693 .55289 L .50469 .55153 L F
.803 .34 .133 r
.50764 .55224 m .50553 .55063 L .50623 .55205 L F
.198 .715 .879 r
.48042 .59815 m .484 .59829 L .4831 .59794 L F
.854 .756 .755 r
.4846 .59572 m .484 .59829 L .48219 .59604 L F
.752 .417 .416 r
.484 .59829 m .485 .59669 L .4831 .59794 L F
.632 .639 .839 r
.80688 .42956 m .80418 .43023 L .80283 .42709 L F
.515 .157 .297 r
.80418 .43023 m .80684 .43145 L .80421 .43169 L F
.495 .202 .397 r
.80688 .42956 m .80684 .43145 L .80418 .43023 L F
0 .028 .592 r
.50447 .57235 m .50376 .57232 L .50282 .57016 L F
.55 .796 .99 r
.5433 .61308 m .54708 .61368 L .54574 .61251 L F
.57 .94 .86 r
.54708 .61368 m .54889 .61259 L .54833 .61239 L F
.431 .739 .991 r
.54574 .61251 m .54708 .61368 L .54833 .61239 L F
.54574 .61251 m .54708 .61368 L .54833 .61239 L F
.858 .543 .453 r
.47984 .56501 m .47994 .5673 L .47892 .56647 L F
.402 .237 .541 r
.29122 .56271 m .29122 .56489 L .28935 .56534 L F
.51 .442 .716 r
.29122 .56489 m .28971 .5676 L .28935 .56534 L F
0 0 .278 r
.57878 .5765 m .5785 .57892 L .57703 .5803 L F
.142 .014 .433 r
.5785 .57892 m .57647 .58274 L .57703 .5803 L F
.337 .043 .31 r
.43732 .59853 m .44065 .59582 L .43678 .5955 L F
.43732 .59853 m .43925 .59843 L .44065 .59582 L F
.377 .513 .867 r
.43732 .59853 m .43919 .59942 L .43925 .59843 L F
.574 .755 .964 r
.7879 .41308 m .78954 .41085 L .78715 .41198 L F
.7879 .41308 m .79051 .41254 L .78954 .41085 L F
.403 .73 .991 r
.25068 .55503 m .24973 .55719 L .2479 .55633 L F
.435 0 0 r
.25241 .55718 m .2479 .55633 L .24973 .55719 L F
.696 .283 0 r
.51034 .58248 m .51229 .58575 L .51128 .58387 L F
.432 .768 .997 r
.80235 .42613 m .80041 .42737 L .79888 .42778 L F
.80235 .42613 m .80283 .42709 L .80041 .42737 L F
.889 .475 .21 r
.41829 .65776 m .41564 .65505 L .41891 .65561 L F
.791 .826 .353 r
.41908 .65421 m .41891 .65561 L .42014 .65185 L F
0 .098 .654 r
.41908 .65421 m .42064 .65753 L .41891 .65561 L F
.501 .254 .471 r
.41891 .65561 m .42064 .65753 L .41829 .65776 L F
.534 .342 .567 r
.42387 .61018 m .42391 .61297 L .42177 .61149 L F
.605 .641 .86 r
.51584 .6048 m .51784 .60804 L .51939 .60677 L F
.786 .682 .749 r
.74327 .41497 m .74006 .41138 L .74265 .41064 L F
.656 .649 .832 r
.74633 .41139 m .74327 .41497 L .74265 .41064 L F
.699 .72 .866 r
.74662 .41466 m .74327 .41497 L .74633 .41139 L F
.196 .719 .704 r
.46618 .55904 m .46757 .55864 L .46872 .55835 L F
.46618 .55904 m .46516 .55928 L .46757 .55864 L F
.075 0 .266 r
.56354 .57663 m .56526 .5738 L .56329 .57446 L F
.732 .369 .364 r
.57302 .50164 m .56954 .50147 L .56883 .49942 L F
.64 .655 .849 r
.43919 .59942 m .44104 .60142 L .44323 .6002 L F
.079 0 0 r
.46218 .61622 m .46469 .61596 L .46627 .6155 L F
0 0 0 r
.46627 .6155 m .46469 .61596 L .46802 .61527 L F
.37 .671 .974 r
.27581 .54365 m .2753 .54529 L .27358 .54388 L F
.27581 .54365 m .27812 .54553 L .2753 .54529 L F
.586 .405 .604 r
.457 .57718 m .46038 .5769 L .45989 .57436 L F
.629 .434 .6 r
.45711 .57953 m .46038 .5769 L .457 .57718 L F
.266 .359 .773 r
.20289 .71263 m .20459 .71365 L .20394 .71083 L F
.633 .783 .953 r
.72535 .41688 m .72652 .41845 L .72902 .41753 L F
.755 .417 .411 r
.42365 .59511 m .42551 .59748 L .42731 .59589 L F
.505 .088 .181 r
.42731 .59589 m .42902 .59712 L .4298 .59505 L F
.42731 .59589 m .42551 .59748 L .42902 .59712 L F
0 .197 .726 r
.42902 .59712 m .42731 .59589 L .4298 .59505 L F
.757 .754 .849 r
.54438 .58869 m .5473 .58592 L .54793 .5894 L F
.75 .413 .411 r
.54793 .5894 m .54527 .59147 L .54438 .58869 L F
.54793 .5894 m .5473 .59223 L .54527 .59147 L F
.927 .781 .68 r
.54906 .58491 m .54793 .5894 L .5473 .58592 L F
.41 .245 .544 r
.20709 .55525 m .20519 .55595 L .20538 .5534 L F
.598 .253 .356 r
.20538 .5534 m .20783 .55345 L .20709 .55525 L F
.41 .245 .544 r
.20709 .55525 m .20519 .55595 L .20538 .5534 L F
.381 .143 .424 r
.28807 .59187 m .28554 .59491 L .28575 .5924 L F
.401 .511 .855 r
.16415 .63746 m .16567 .63644 L .16322 .63566 L F
.712 .432 .5 r
.4288 .61632 m .42865 .61892 L .42572 .61815 L F
.621 .354 .492 r
.43123 .6186 m .4288 .61632 L .4297 .61601 L F
.43123 .6186 m .42865 .61892 L .4288 .61632 L F
.4288 .61632 m .42865 .61892 L .43123 .6186 L F
.428 .018 .156 r
.74925 .39521 m .74905 .39666 L .75203 .39558 L F
.414 .126 .364 r
.24732 .60654 m .24516 .60716 L .24458 .6097 L F
.458 .235 .487 r
.28905 .57362 m .29021 .57412 L .28806 .57449 L F
0 0 .093 r
.21675 .69975 m .2181 .6966 L .21914 .69657 L F
.493 .343 .605 r
.4966 .60074 m .49872 .59762 L .49705 .59836 L F
.793 .625 .674 r
.51541 .61287 m .51716 .61489 L .51813 .6134 L F
0 .449 .786 r
.66067 .44681 m .66427 .44817 L .66293 .4475 L F
.66067 .44681 m .66427 .44817 L .66293 .4475 L F
.865 .932 .866 r
.66293 .4475 m .66427 .44817 L .66646 .44542 L F
.019 .547 .855 r
.66293 .4475 m .66427 .44817 L .66661 .44862 L F
.744 .464 .507 r
.72176 .39358 m .72366 .39115 L .7202 .39097 L F
.819 .604 .612 r
.20283 .55649 m .19897 .55785 L .19902 .55681 L F
.20283 .55649 m .20277 .55925 L .19897 .55785 L F
.77 .675 .757 r
.20519 .55595 m .20277 .55925 L .20283 .55649 L F
.654 .81 .958 r
.73146 .4166 m .73262 .41802 L .73514 .41711 L F
.831 .664 .676 r
.58526 .5077 m .58398 .51101 L .58244 .50755 L F
.678 .875 .491 r
.4227 .62179 m .42033 .62258 L .4193 .62173 L F
.544 .558 .819 r
.42033 .62258 m .42396 .6251 L .42415 .62251 L F
.678 .875 .491 r
.4227 .62179 m .42077 .62464 L .42033 .62258 L F
0 0 .013 r
.57121 .5562 m .57106 .55799 L .57168 .55567 L F
.588 .608 .84 r
.19411 .63147 m .19015 .62869 L .19214 .62832 L F
.654 .666 .85 r
.19622 .63023 m .19411 .63147 L .19214 .62832 L F
.494 .088 .199 r
.49778 .53742 m .5016 .53545 L .49781 .53484 L F
.49778 .53742 m .50097 .53715 L .5016 .53545 L F
.054 0 0 r
.17382 .54904 m .17794 .54714 L .17574 .54748 L F
.043 .162 .665 r
.76811 .3862 m .76694 .38797 L .76616 .38416 L F
.37 .618 .947 r
.76811 .3862 m .76976 .38824 L .76694 .38797 L F
.802 .574 .592 r
.57851 .47409 m .58215 .47228 L .57858 .4726 L F
.57851 .47409 m .58215 .47471 L .58215 .47228 L F
.445 .011 .119 r
.75203 .39558 m .75478 .39539 L .75493 .39371 L F
.889 .925 .839 r
.75673 .38974 m .75493 .39371 L .75664 .39172 L F
0 0 .021 r
.75493 .39371 m .75478 .39539 L .75664 .39172 L F
.295 .128 .477 r
.2587 .58337 m .26029 .58496 L .26077 .58272 L F
.2587 .58337 m .2585 .58587 L .26029 .58496 L F
.211 .356 .792 r
.51915 .61717 m .52003 .61941 L .51866 .61815 L F
.51915 .61717 m .52137 .61805 L .52003 .61941 L F
.414 .684 .973 r
.52003 .61941 m .52137 .61805 L .51866 .61815 L F
.22 .197 .618 r
.39344 .61308 m .39341 .61676 L .39526 .61515 L F
.187 .175 .612 r
.39341 .61676 m .39571 .61763 L .39526 .61515 L F
.39341 .61676 m .39409 .6193 L .39571 .61763 L F
.408 .064 .266 r
.46738 .58138 m .47016 .58143 L .4675 .58182 L F
.696 .743 .887 r
.73514 .41711 m .73887 .4178 L .73785 .41602 L F
.584 .713 .932 r
.73887 .4178 m .74067 .41536 L .73785 .41602 L F
.73887 .4178 m .74166 .41722 L .74067 .41536 L F
.672 .447 .571 r
.5908 .47442 m .59424 .472 L .59075 .47234 L F
.435 .181 .429 r
.42396 .6251 m .4266 .62234 L .42415 .62251 L F
.487 .513 .81 r
.14769 .56233 m .14819 .56213 L .14935 .56128 L F
.054 0 0 r
.14758 .56247 m .14819 .56213 L .14769 .56233 L F
.978 .868 .659 r
.75923 .41435 m .75997 .41235 L .75825 .41314 L F
.91 .982 .766 r
.75825 .41314 m .75997 .41235 L .75944 .41154 L F
.593 .385 .568 r
.41167 .6252 m .41424 .62494 L .41424 .62241 L F
.445 .245 .513 r
.29161 .57958 m .28919 .58293 L .28933 .58038 L F
0 0 .51 r
.43905 .57695 m .43718 .57426 L .43823 .57423 L F
.735 .507 .583 r
.44195 .57618 m .43905 .57695 L .43823 .57423 L F
0 .337 .815 r
.41161 .64811 m .41307 .64817 L .4111 .64614 L F
.912 .949 .809 r
.4156 .64855 m .41337 .64826 L .41311 .6479 L F
.736 .865 .941 r
.41307 .64817 m .4131 .64822 L .4156 .64855 L F
.4131 .64822 m .41394 .64967 L .4156 .64855 L F
.912 .949 .809 r
.4156 .64855 m .41435 .64956 L .41337 .64826 L F
0 .337 .815 r
.41247 .64868 m .41367 .64949 L .41302 .64822 L F
.41302 .64822 m .41367 .64949 L .4131 .64822 L F
.41367 .64949 m .41394 .64967 L .41317 .64834 L F
.41367 .64949 m .41317 .64834 L .4131 .64822 L F
.912 .949 .809 r
.41435 .64956 m .41261 .65096 L .41306 .64818 L F
0 0 .128 r
.41309 .64816 m .41261 .65096 L .41295 .65025 L F
.912 .949 .809 r
.41435 .64956 m .41306 .64818 L .41311 .6479 L F
0 0 .128 r
.41311 .6479 m .41306 .64818 L .41307 .64817 L F
.736 .865 .941 r
.41307 .64817 m .41307 .64817 L .41311 .6479 L F
.41307 .64817 m .4156 .64855 L .41311 .6479 L F
0 0 .128 r
.41311 .6479 m .41307 .64817 L .41309 .64816 L F
0 .337 .815 r
.41305 .64817 m .4131 .64822 L .41307 .64817 L F
0 0 .128 r
.41306 .64818 m .41261 .65096 L .41309 .64816 L F
0 .337 .815 r
.41161 .64811 m .41247 .64868 L .41302 .64822 L F
.41161 .64811 m .4131 .64822 L .41305 .64817 L F
0 .206 .733 r
.4111 .64614 m .41307 .64817 L .4105 .64462 L F
.845 .623 .603 r
.4105 .64462 m .41311 .6479 L .41249 .64684 L F
.4105 .64462 m .41307 .64817 L .41311 .6479 L F
0 0 .128 r
.41259 .64702 m .41295 .65025 L .41249 .64684 L F
.41311 .6479 m .41309 .64816 L .41259 .64702 L F
.41309 .64816 m .41295 .65025 L .41259 .64702 L F
.445 .133 .341 r
.26476 .56843 m .2642 .57036 L .26717 .56817 L F
.541 .177 .298 r
.47644 .58221 m .47958 .58208 L .48037 .5806 L F
.367 .053 .294 r
.47958 .58208 m .48242 .57968 L .48037 .5806 L F
.019 .006 .498 r
.52594 .5467 m .52566 .54723 L .52561 .54434 L F
.643 .957 .768 r
.47735 .58823 m .48115 .58579 L .47925 .5876 L F
.076 0 0 r
.48166 .58685 m .47918 .58766 L .48115 .58579 L F
.559 .443 .677 r
.47884 .58461 m .47905 .58754 L .47983 .58733 L F
.48138 .58663 m .47983 .58733 L .48166 .58685 L F
.47884 .58461 m .47983 .58733 L .48138 .58663 L F
.268 .235 .635 r
.47918 .58765 m .47961 .59085 L .47929 .58773 L F
.366 .22 .547 r
.47928 .58763 m .47961 .59085 L .47918 .58766 L F
.643 .957 .768 r
.47907 .58768 m .47925 .5876 L .47922 .58763 L F
.268 .235 .635 r
.47918 .58765 m .47929 .58773 L .47983 .58733 L F
.643 .957 .768 r
.47918 .58765 m .47922 .58763 L .47921 .58764 L F
.47907 .58768 m .47922 .58763 L .47918 .58765 L F
.268 .235 .635 r
.47983 .58733 m .47929 .58773 L .48166 .58685 L F
.47905 .58754 m .47918 .58765 L .47983 .58733 L F
.366 .22 .547 r
.48166 .58685 m .47961 .59085 L .47929 .58773 L F
.48166 .58685 m .4815 .59049 L .47961 .59085 L F
.78 .565 .609 r
.48488 .58974 m .48172 .59071 L .48166 .58685 L F
.423 .505 .838 r
.4815 .59049 m .48223 .59097 L .48192 .5904 L F
.47961 .59085 m .48194 .59095 L .4815 .59049 L F
.48194 .59095 m .48223 .59097 L .48172 .59071 L F
.62 .241 .303 r
.48172 .59071 m .48223 .59097 L .48149 .59078 L F
.48488 .58974 m .48223 .59097 L .48172 .59071 L F
.423 .505 .838 r
.48172 .59071 m .48223 .59097 L .4815 .59049 L F
.78 .565 .609 r
.48172 .59071 m .48149 .59078 L .4815 .59049 L F
.48172 .59071 m .4815 .59049 L .48166 .58685 L F
.366 .22 .547 r
.4815 .59049 m .48149 .59078 L .47961 .59085 L F
.423 .505 .838 r
.47961 .59085 m .48192 .5904 L .48138 .58941 L F
.268 .235 .635 r
.47929 .58773 m .48138 .58941 L .48166 .58685 L F
.366 .22 .547 r
.48166 .58685 m .47929 .58773 L .47928 .58763 L F
.268 .235 .635 r
.47929 .58773 m .47961 .59085 L .48138 .58941 L F
.47905 .58754 m .47907 .58768 L .47918 .58765 L F
.47907 .58768 m .47961 .59085 L .47918 .58765 L F
.519 .411 .671 r
.47741 .59117 m .47961 .59085 L .47907 .58768 L F
.643 .957 .768 r
.47905 .58769 m .47907 .58768 L .47907 .58768 L F
.519 .411 .671 r
.47897 .58772 m .47907 .58768 L .47905 .58754 L F
.47741 .59117 m .47907 .58768 L .47897 .58772 L F
.643 .957 .768 r
.47893 .58774 m .47905 .58769 L .47918 .58766 L F
.47905 .58769 m .47907 .58768 L .47918 .58766 L F
.47907 .58768 m .47921 .58764 L .47918 .58766 L F
.519 .411 .671 r
.47741 .59117 m .47897 .58772 L .47735 .58823 L F
.643 .957 .768 r
.47735 .58823 m .47925 .5876 L .47898 .58772 L F
.519 .411 .671 r
.47897 .58772 m .47905 .58754 L .47735 .58823 L F
.643 .957 .768 r
.47735 .58823 m .47898 .58772 L .47893 .58774 L F
.289 .045 .36 r
.28139 .60141 m .2808 .60365 L .279 .60429 L F
.522 .356 .598 r
.28143 .6063 m .279 .60429 L .2808 .60365 L F
.28143 .6063 m .27893 .60701 L .279 .60429 L F
.442 0 0 r
.54096 .61263 m .53948 .61205 L .53624 .61041 L F
0 .523 .808 r
.5433 .61308 m .53948 .61205 L .54096 .61263 L F
.513 .189 .356 r
.44927 .58546 m .45209 .58345 L .44944 .58342 L F
.624 .87 .52 r
.16016 .60817 m .15923 .60945 L .16071 .60788 L F
0 0 0 r
.1595 .60916 m .15923 .60945 L .16016 .60817 L F
.519 .818 .486 r
.15923 .60945 m .15848 .61025 L .15872 .61 L F
0 0 0 r
.15799 .61145 m .15848 .61025 L .15923 .60945 L F
.15799 .61145 m .15923 .60945 L .15801 .61139 L F
.15801 .61139 m .15923 .60945 L .1595 .60916 L F
.519 .818 .486 r
.15923 .60945 m .15872 .61 L .16071 .60788 L F
.342 .82 .871 r
.16071 .60788 m .16099 .60731 L .15709 .6051 L F
.16071 .60788 m .16289 .60726 L .16099 .60731 L F
.624 .87 .52 r
.16016 .60817 m .16071 .60788 L .16289 .60726 L F
.729 .509 .593 r
.46486 .59399 m .46804 .59477 L .46683 .59234 L F
.703 .528 .648 r
.46804 .59477 m .46966 .59249 L .46683 .59234 L F
.808 .985 .717 r
.28733 .55132 m .28646 .55338 L .28897 .55029 L F
.261 .392 .807 r
.28733 .55132 m .28888 .5551 L .28646 .55338 L F
.604 .561 .779 r
.80146 .40586 m .79985 .40926 L .79887 .40626 L F
.80146 .40586 m .80244 .40875 L .79985 .40926 L F
.617 .466 .654 r
.80244 .40875 m .80014 .41221 L .79985 .40926 L F
.064 .175 .67 r
.49628 .60428 m .49776 .60678 L .49706 .60402 L F
.54 .598 .861 r
.80078 .40378 m .79887 .40626 L .79763 .4027 L F
.80078 .40378 m .80146 .40586 L .79887 .40626 L F
.84 .376 .005 r
.67233 .41099 m .67427 .41245 L .67497 .41402 L F
.799 .395 .287 r
.28501 .54836 m .28668 .5502 L .28897 .55029 L F
.808 .985 .717 r
.28733 .55132 m .28897 .55029 L .28668 .5502 L F
.346 0 .172 r
.25092 .63728 m .24782 .63918 L .24864 .63787 L F
0 0 0 r
.66077 .40584 m .66003 .40722 L .65897 .40903 L F
.556 .451 .69 r
.66355 .40458 m .66003 .40722 L .66077 .40584 L F
.321 0 .242 r
.55445 .49294 m .55674 .49222 L .5574 .48981 L F
.332 .002 .246 r
.5574 .48981 m .55898 .49146 L .55974 .48909 L F
.5574 .48981 m .55674 .49222 L .55898 .49146 L F
.656 .97 .831 r
.57093 .48086 m .57258 .47885 L .5742 .47858 L F
0 0 0 r
.77319 .41792 m .77531 .41599 L .77491 .41654 L F
.348 .425 .8 r
.77491 .41654 m .77612 .41951 L .77319 .41792 L F
.291 .788 .781 r
.20262 .54071 m .20325 .54033 L .20497 .54088 L F
.20262 .54071 m .20115 .54098 L .20325 .54033 L F
.882 .73 .689 r
.65743 .41423 m .66011 .4151 L .6589 .41182 L F
.849 .638 .617 r
.65743 .41423 m .6603 .41748 L .66011 .4151 L F
.478 .216 .438 r
.23731 .6434 m .23927 .64542 L .23677 .64583 L F
.583 .212 .304 r
.23984 .64354 m .23927 .64542 L .23731 .6434 L F
.779 .587 .641 r
.68844 .41884 m .68978 .42124 L .68609 .42046 L F
.62 .63 .839 r
.7247 .40109 m .7195 .40404 L .71948 .402 L F
0 0 0 r
.20854 .71248 m .20888 .71239 L .20459 .71365 L F
0 .183 .713 r
.20921 .71142 m .20854 .71248 L .20974 .71247 L F
.20921 .71142 m .20888 .71239 L .20854 .71248 L F
0 0 .407 r
.76719 .38242 m .76587 .38199 L .76669 .38011 L F
.76719 .38242 m .76616 .38416 L .76587 .38199 L F
.336 .366 .744 r
.22612 .66972 m .22486 .67057 L .22414 .66791 L F
.987 .885 .634 r
.5193 .60374 m .51939 .60677 L .52012 .60438 L F
.276 0 .268 r
.4094 .59153 m .41237 .5887 L .41022 .58937 L F
.468 .292 .558 r
.25188 .5953 m .25406 .59483 L .2541 .59209 L F
.345 .185 .516 r
.25188 .5953 m .25358 .59713 L .25406 .59483 L F
.25188 .5953 m .25186 .59785 L .25358 .59713 L F
0 0 .385 r
.45242 .62537 m .45299 .62187 L .45078 .62105 L F
.45242 .62537 m .45324 .62416 L .45299 .62187 L F
.558 .306 .49 r
.45496 .62512 m .45473 .6274 L .45242 .62537 L F
.044 .258 .755 r
.45242 .62537 m .45473 .6274 L .45324 .62416 L F
.214 0 .24 r
.54977 .49661 m .54913 .49844 L .55172 .49557 L F
.529 .021 0 r
.50629 .53583 m .50651 .53664 L .50784 .53539 L F
.91 .814 .74 r
.50712 .53201 m .50784 .53539 L .50983 .53513 L F
.50712 .53201 m .50629 .53583 L .50784 .53539 L F
.659 .624 .804 r
.51182 .53683 m .50784 .53539 L .50983 .53513 L F
.57 .247 .382 r
.50784 .53539 m .50954 .53721 L .50983 .53513 L F
0 0 0 r
.57511 .54409 m .5753 .54338 L .5761 .54009 L F
.57511 .54409 m .57488 .54599 L .5753 .54338 L F
.536 .436 .688 r
.29185 .56703 m .28905 .57362 L .28971 .5676 L F
.29185 .56703 m .29281 .57276 L .28905 .57362 L F
.402 .119 .365 r
.29281 .57276 m .29021 .57412 L .28905 .57362 L F
.046 0 .028 r
.54913 .49844 m .54718 .49963 L .5463 .50116 L F
.361 .409 .777 r
.45884 .57121 m .45989 .57436 L .46132 .57278 L F
.05 0 0 r
.54071 .51646 m .53757 .51891 L .53833 .51722 L F
.493 .24 .459 r
.53604 .51922 m .53833 .51722 L .53757 .51891 L F
.555 .001 0 r
.46872 .55835 m .47122 .55906 L .47195 .55876 L F
.972 .677 .402 r
.46939 .55817 m .47122 .55906 L .46872 .55835 L F
.46939 .55817 m .4702 .55949 L .47122 .55906 L F
.4702 .55949 m .471 .56078 L .47122 .55906 L F
.555 .001 0 r
.47195 .55876 m .47122 .55906 L .47231 .55881 L F
.937 .625 .422 r
.47122 .55906 m .471 .56078 L .47231 .55881 L F
.214 0 0 r
.47231 .55881 m .47333 .56007 L .47486 .55841 L F
.47231 .55881 m .471 .56078 L .47333 .56007 L F
.439 0 0 r
.49313 .56353 m .49472 .56425 L .49399 .56383 L F
.49313 .56353 m .49399 .56383 L .48949 .56126 L F
0 .238 .694 r
.49184 .5624 m .49313 .56353 L .48973 .56133 L F
0 .224 .743 r
.49184 .5624 m .49238 .56325 L .49313 .56353 L F
.49238 .56325 m .49338 .56485 L .49313 .56353 L F
.439 0 0 r
.49313 .56353 m .48949 .56126 L .48973 .56133 L F
.87 .941 .862 r
.68745 .42464 m .68415 .42632 L .6862 .42318 L F
.876 .849 .813 r
.68978 .42124 m .68745 .42464 L .6862 .42318 L F
.662 .972 .836 r
.77596 .43008 m .77747 .42823 L .77485 .43007 L F
.943 .925 .563 r
.54527 .59147 m .54428 .59421 L .54544 .59308 L F
.243 0 0 r
.54428 .59421 m .54827 .59278 L .54544 .59308 L F
.555 .358 .569 r
.47268 .58912 m .47514 .5888 L .47503 .58633 L F
.515 .397 .656 r
.47514 .5888 m .47672 .58539 L .47503 .58633 L F
.544 .397 .632 r
.51337 .53511 m .51182 .53683 L .50983 .53513 L F
.51337 .53511 m .51411 .53757 L .51182 .53683 L F
.697 .906 .969 r
.19612 .73559 m .19818 .73627 L .19566 .73716 L F
.19612 .73559 m .19818 .73627 L .19566 .73716 L F
.663 .473 .618 r
.19566 .73716 m .1957 .73979 L .19818 .73627 L F
.165 .59 .936 r
.73524 .40439 m .73886 .40592 L .73642 .40546 L F
.849 .709 .708 r
.59926 .48625 m .60079 .48931 L .60084 .48725 L F
.59926 .48625 m .59707 .4892 L .60079 .48931 L F
.849 .709 .707 r
.59707 .4892 m .59846 .49268 L .60079 .48931 L F
.087 0 0 r
.18885 .55958 m .18787 .5593 L .19029 .55885 L F
.18885 .55958 m .18664 .56002 L .18787 .5593 L F
.652 .65 .835 r
.72504 .40084 m .72385 .40638 L .7247 .40109 L F
.72504 .40084 m .72639 .4055 L .72385 .40638 L F
.72 .767 .89 r
.6417 .4202 m .64301 .42192 L .64532 .42075 L F
.524 .865 .992 r
.50533 .52352 m .50624 .52216 L .50748 .5225 L F
.50533 .52352 m .5039 .52284 L .50624 .52216 L F
0 0 .552 r
.53428 .56288 m .53359 .56248 L .53152 .56146 L F
.53428 .56288 m .53522 .56444 L .53359 .56248 L F
.21 0 .074 r
.17569 .56411 m .17186 .56741 L .1732 .56488 L F
.875 .448 .183 r
.65514 .44646 m .65837 .449 L .65669 .44839 L F
.824 .894 .892 r
.65669 .44839 m .65837 .449 L .66067 .44681 L F
.911 .78 .704 r
.58335 .51353 m .58388 .5166 L .58216 .51633 L F
.999 .835 .513 r
.58267 .52011 m .58216 .51633 L .58388 .5166 L F
.876 .941 .574 r
.57921 .53226 m .57761 .53553 L .57786 .53363 L F
.992 .878 .605 r
.57911 .52779 m .57921 .53226 L .57863 .53131 L F
.979 .895 .547 r
.57863 .53131 m .57921 .53226 L .57786 .53363 L F
.621 .421 .589 r
.44432 .57417 m .44444 .57705 L .44195 .57618 L F
.477 .258 .502 r
.44653 .57336 m .44632 .57597 L .44432 .57417 L F
.413 .262 .564 r
.44632 .57597 m .44444 .57705 L .44432 .57417 L F
.854 .756 .755 r
.4846 .59572 m .485 .59669 L .48547 .59498 L F
.4846 .59572 m .48219 .59604 L .485 .59669 L F
.82 .813 .844 r
.77353 .39361 m .77541 .39155 L .77705 .39331 L F
0 0 0 r
.54484 .50257 m .54372 .50396 L .5463 .50116 L F
0 .574 .714 r
.20619 .63341 m .20829 .63344 L .20995 .63348 L F
.476 .891 .917 r
.20995 .63348 m .21051 .6326 L .21229 .63266 L F
.20995 .63348 m .20829 .63344 L .21051 .6326 L F
.41 .478 .819 r
.40277 .63137 m .40413 .63492 L .4058 .63305 L F
.306 .321 .712 r
.40413 .63492 m .40641 .63656 L .4058 .63305 L F
.537 .814 .997 r
.21823 .69282 m .21718 .69425 L .21532 .69325 L F
.105 .2 .679 r
.21823 .69282 m .21914 .69657 L .21718 .69425 L F
.657 .905 .98 r
.76322 .37703 m .76166 .37906 L .76061 .37767 L F
.76322 .37703 m .76454 .37787 L .76166 .37906 L F
.972 .754 .549 r
.44635 .56146 m .44762 .56245 L .44767 .55949 L F
.494 .349 .613 r
.44767 .55949 m .44957 .56138 L .45027 .55905 L F
.44767 .55949 m .44762 .56245 L .44957 .56138 L F
0 0 .23 r
.58425 .5562 m .58587 .55232 L .58527 .5545 L F
0 0 .009 r
.58475 .55641 m .58425 .5562 L .58527 .5545 L F
.58475 .55641 m .5838 .55831 L .58425 .5562 L F
.941 .847 .722 r
.76424 .42018 m .76626 .42023 L .7647 .42358 L F
.072 .633 .774 r
.22135 .53851 m .22572 .53864 L .22352 .53868 L F
.51 .53 .814 r
.19214 .62832 m .19015 .62869 L .18911 .62601 L F
.814 .916 .523 r
.76843 .40919 m .76705 .41177 L .76738 .4103 L F
.919 .907 .508 r
.76843 .40919 m .76738 .4103 L .76889 .40477 L F
.898 .631 .525 r
.21227 .678 m .21359 .68022 L .21326 .67658 L F
.391 .254 .572 r
.21326 .67658 m .21509 .67848 L .2156 .67592 L F
.21326 .67658 m .21359 .68022 L .21509 .67848 L F
.834 .658 .114 r
.7788 .40417 m .77904 .40611 L .77901 .40286 L F
.879 .992 .793 r
.77869 .40178 m .77901 .40286 L .78173 .39934 L F
.846 .654 .113 r
.7788 .40417 m .77901 .40286 L .77869 .40178 L F
.122 0 .017 r
.14616 .56412 m .14819 .56213 L .14758 .56247 L F
.796 .94 .922 r
.77207 .38783 m .76976 .38824 L .77237 .38733 L F
0 .109 .625 r
.77376 .38904 m .77207 .38783 L .77237 .38733 L F
0 .112 .661 r
.21687 .55212 m .21745 .55343 L .2175 .55248 L F
.51 .442 .716 r
.29122 .56489 m .29185 .56703 L .28971 .5676 L F
.493 .24 .459 r
.53604 .51922 m .53757 .51891 L .53459 .5192 L F
.177 0 0 r
.23977 .55623 m .23591 .55821 L .23732 .5571 L F
.457 .219 .463 r
.46966 .59249 m .47251 .59199 L .47268 .58912 L F
.579 .318 .485 r
.47268 .58912 m .475 .59158 L .47514 .5888 L F
0 0 0 r
.18225 .54581 m .18671 .54416 L .18434 .54467 L F
.738 .788 .893 r
.18888 .74433 m .19068 .74549 L .18906 .74528 L F
.18905 .74376 m .19068 .74549 L .18848 .74407 L F
.18859 .74396 m .18848 .74407 L .18841 .74403 L F
.18905 .74376 m .18848 .74407 L .18859 .74396 L F
.18888 .74433 m .18906 .74528 L .18723 .74504 L F
.772 .407 .365 r
.18723 .74504 m .19068 .74549 L .18904 .74775 L F
0 0 0 r
.19022 .74632 m .19068 .74549 L .19162 .74465 L F
.18904 .74775 m .18989 .74658 L .19022 .74632 L F
.18989 .74658 m .19068 .74549 L .19022 .74632 L F
.18904 .74775 m .19162 .74465 L .19086 .74691 L F
.432 .295 .594 r
.18871 .74347 m .19041 .74618 L .18935 .7437 L F
.19041 .74618 m .19086 .74691 L .19049 .74612 L F
.19041 .74618 m .19049 .74612 L .18935 .7437 L F
.18877 .74378 m .18904 .74775 L .19086 .74691 L F
.18852 .74341 m .18859 .74396 L .18877 .74378 L F
.738 .788 .893 r
.18841 .74403 m .18888 .74433 L .18723 .74504 L F
.432 .295 .594 r
.18859 .74396 m .18904 .74775 L .18877 .74378 L F
.18852 .74341 m .18877 .74378 L .18871 .74347 L F
.738 .788 .893 r
.18891 .74361 m .18905 .74376 L .18841 .74403 L F
.632 .438 .602 r
.18841 .74403 m .18859 .74396 L .18852 .74341 L F
.18841 .74403 m .18852 .74341 L .18723 .74504 L F
.738 .788 .893 r
.18865 .74334 m .18891 .74361 L .18723 .74504 L F
.432 .295 .594 r
.18877 .74378 m .19086 .74691 L .18871 .74347 L F
.772 .407 .365 r
.18723 .74504 m .18904 .74775 L .18779 .74751 L F
.632 .438 .602 r
.18779 .74751 m .18904 .74775 L .18859 .74396 L F
.18779 .74751 m .18859 .74396 L .18841 .74403 L F
.18779 .74751 m .18841 .74403 L .18723 .74504 L F
.238 .561 .936 r
.19162 .74465 m .19068 .74549 L .18865 .74334 L F
.884 .872 .821 r
.65581 .41923 m .65776 .41986 L .65726 .41683 L F
.763 .802 .884 r
.65726 .41683 m .65776 .41986 L .6603 .41748 L F
.774 .753 .834 r
.65776 .41986 m .66027 .41807 L .6603 .41748 L F
.704 .41 .475 r
.2393 .60997 m .24161 .61255 L .24209 .60994 L F
.509 .271 .49 r
.24161 .61255 m .24458 .6097 L .24209 .60994 L F
0 0 0 r
.51756 .53771 m .51889 .53665 L .52045 .53528 L F
.35 .779 .971 r
.19818 .73627 m .20005 .73595 L .19612 .73559 L F
.19818 .73627 m .20005 .73595 L .19612 .73559 L F
.841 .69 .696 r
.64616 .41423 m .64769 .41763 L .64811 .41524 L F
.189 .317 .764 r
.66003 .40722 m .66127 .41084 L .65897 .40903 L F
0 0 0 r
.70621 .40162 m .70696 .4005 L .70422 .40299 L F
.069 0 0 r
.70917 .39943 m .70696 .4005 L .70621 .40162 L F
.36 .746 .987 r
.47575 .60997 m .4798 .61141 L .47414 .61022 L F
.865 .732 .714 r
.47967 .6107 m .4798 .61141 L .47575 .60997 L F
.47967 .6107 m .47682 .61017 L .4782 .60934 L F
.47682 .61017 m .47575 .60997 L .4782 .60934 L F
.531 .222 .388 r
.47649 .61067 m .47912 .60878 L .4782 .60934 L F
.692 .93 .967 r
.48016 .60804 m .47967 .6107 L .4782 .60934 L F
.531 .222 .388 r
.47912 .60878 m .48016 .60804 L .4782 .60934 L F
.141 0 0 r
.47575 .60997 m .47649 .61067 L .47781 .60964 L F
.47575 .60997 m .47781 .60964 L .4782 .60934 L F
.36 .746 .987 r
.47575 .60997 m .47414 .61022 L .47304 .60999 L F
.504 .805 .999 r
.54827 .59278 m .55062 .59206 L .55165 .59325 L F
.305 .395 .791 r
.55278 .59086 m .55416 .59449 L .55165 .59325 L F
.923 .757 .658 r
.5589 .58042 m .55891 .58324 L .55767 .57983 L F
.549 .876 .605 r
.40817 .62327 m .40757 .62351 L .40657 .62461 L F
.137 0 0 r
.40886 .62355 m .40817 .62327 L .41039 .62261 L F
.40886 .62355 m .40757 .62351 L .40817 .62327 L F
.876 .849 .813 r
.68978 .42124 m .6862 .42318 L .68609 .42046 L F
.676 .454 .577 r
.43438 .64336 m .4382 .6454 L .4368 .64287 L F
.43438 .64336 m .43423 .64598 L .4382 .6454 L F
.77 .798 .875 r
.22651 .66701 m .22255 .66684 L .22491 .66373 L F
.22651 .66701 m .22414 .66791 L .22255 .66684 L F
.637 .374 .503 r
.22651 .66701 m .22612 .66972 L .22414 .66791 L F
.365 .498 .86 r
.22645 .6641 m .22651 .66701 L .22491 .66373 L F
.478 .596 .893 r
.22645 .6641 m .22944 .66747 L .22651 .66701 L F
.006 0 0 r
.22944 .66747 m .22612 .66972 L .22651 .66701 L F
.025 0 0 r
.53897 .50763 m .54096 .50733 L .54212 .50542 L F
.021 0 0 r
.54212 .50542 m .54313 .50612 L .54372 .50396 L F
.54212 .50542 m .54096 .50733 L .54313 .50612 L F
.364 .282 .629 r
.25898 .57113 m .26091 .57275 L .26117 .57076 L F
.25898 .57113 m .25918 .57421 L .26091 .57275 L F
.422 .731 .99 r
.67612 .43274 m .67275 .4316 L .67516 .4318 L F
.746 .933 .949 r
.67774 .43127 m .67612 .43274 L .67516 .4318 L F
.715 .632 .763 r
.67044 .44652 m .66646 .44542 L .66909 .44464 L F
0 0 .379 r
.67086 .44589 m .67044 .44652 L .66909 .44464 L F
.67086 .44589 m .67086 .4486 L .67044 .44652 L F
.586 .395 .589 r
.43925 .59843 m .44227 .59434 L .44065 .59582 L F
.009 .528 .858 r
.20009 .63161 m .19622 .63023 L .19931 .62998 L F
.228 .477 .887 r
.20061 .62998 m .20009 .63161 L .19931 .62998 L F
.358 .625 .954 r
.20061 .62998 m .20229 .6318 L .20009 .63161 L F
.525 .341 .574 r
.28317 .60059 m .2808 .60365 L .28139 .60141 L F
0 0 0 r
.43217 .57708 m .42974 .58164 L .43149 .57836 L F
.059 0 .298 r
.42948 .58258 m .43149 .57836 L .42974 .58164 L F
.427 .294 .596 r
.24736 .60435 m .24911 .60382 L .24926 .60092 L F
.406 .245 .548 r
.24736 .60435 m .24899 .60564 L .24911 .60382 L F
.24736 .60435 m .24732 .60654 L .24899 .60564 L F
.538 .406 .649 r
.4318 .57272 m .43217 .57708 L .43434 .57639 L F
.637 .077 0 r
.40203 .62736 m .39803 .62472 L .39934 .62637 L F
.445 .169 .399 r
.25864 .63071 m .2557 .6339 L .25647 .63124 L F
.488 .902 .839 r
.69961 .4286 m .70333 .42732 L .70208 .42782 L F
.327 .791 .674 r
.70208 .42782 m .70333 .42732 L .70568 .42621 L F
.182 .705 .869 r
.22572 .53864 m .22765 .5383 L .22971 .53872 L F
.305 .781 .923 r
.22765 .5383 m .23212 .53859 L .22971 .53872 L F
.693 .743 .89 r
.76806 .39725 m .76965 .40065 L .7658 .39989 L F
.971 .733 .304 r
.76881 .40113 m .76948 .40467 L .76876 .40366 L F
.942 .962 .693 r
.76876 .40366 m .76931 .40178 L .76881 .40113 L F
.482 0 0 r
.76823 .40037 m .76965 .40065 L .76881 .40113 L F
.996 .763 .441 r
.76869 .3966 m .76965 .40065 L .76806 .39725 L F
.942 .962 .693 r
.76931 .40178 m .77003 .3993 L .76881 .40113 L F
.482 0 0 r
.7658 .39989 m .76823 .40037 L .76881 .40113 L F
.478 .289 .545 r
.51272 .52921 m .51502 .53102 L .51503 .52854 L F
.682 .815 .947 r
.67192 .44351 m .67272 .44505 L .66909 .44464 L F
.67192 .44351 m .67272 .44505 L .66909 .44464 L F
.425 .137 .37 r
.42396 .64797 m .42172 .64666 L .42562 .64633 L F
.915 .636 .144 r
.42471 .64285 m .4251 .64581 L .42562 .64633 L F
.957 .93 .593 r
.4251 .64581 m .42396 .64797 L .42562 .64633 L F
.787 .549 .576 r
.51802 .59826 m .51784 .6012 L .5146 .60037 L F
.142 .282 .748 r
.51896 .59676 m .51802 .59826 L .517 .59512 L F
0 0 .129 r
.5184 .59936 m .51802 .59826 L .51896 .59676 L F
.5184 .59936 m .51784 .6012 L .51802 .59826 L F
.425 0 0 r
.78017 .45022 m .78358 .45109 L .78254 .45126 L F
0 0 0 r
.78358 .45109 m .78615 .45037 L .78519 .45077 L F
.78358 .45109 m .78519 .45077 L .78254 .45126 L F
.549 .305 .499 r
.425 .66372 m .4281 .66347 L .42553 .66183 L F
.415 .167 .427 r
.80142 .43206 m .80131 .43485 L .79894 .43568 L F
.489 .225 .44 r
.80402 .43418 m .80142 .43206 L .80421 .43169 L F
.80402 .43418 m .80131 .43485 L .80142 .43206 L F
.759 .355 .285 r
.70121 .40797 m .70173 .40605 L .69821 .40528 L F
0 0 .07 r
.70371 .40432 m .70422 .40299 L .70173 .40605 L F
0 0 .043 r
.70371 .40432 m .70173 .40605 L .70121 .40797 L F
.673 .946 .96 r
.71133 .42332 m .71255 .42143 L .71074 .4227 L F
.71133 .42332 m .71475 .42159 L .71255 .42143 L F
.267 0 .089 r
.53579 .5105 m .53823 .50969 L .53897 .50763 L F
0 0 0 r
.53897 .50763 m .54 .50827 L .54096 .50733 L F
.53897 .50763 m .53823 .50969 L .54 .50827 L F
.9 .568 .409 r
.77561 .41132 m .77797 .4122 L .77631 .412 L F
.696 .155 0 r
.77563 .41134 m .77797 .4122 L .77561 .41132 L F
.77674 .41194 m .77797 .4122 L .77563 .41134 L F
.719 .793 .91 r
.77596 .41161 m .77703 .40698 L .7747 .41018 L F
.77631 .412 m .77635 .41177 L .77596 .41161 L F
.696 .155 0 r
.77583 .41155 m .77674 .41194 L .77563 .41134 L F
.719 .793 .91 r
.77635 .41177 m .77703 .40698 L .77596 .41161 L F
.696 .155 0 r
.77607 .4118 m .77672 .41193 L .77583 .41155 L F
.751 .67 .771 r
.78074 .41131 m .77825 .4117 L .77797 .4122 L F
.77825 .4117 m .77674 .41194 L .77691 .41197 L F
.77825 .4117 m .77691 .41197 L .77797 .4122 L F
.702 .787 .917 r
.77703 .40698 m .77993 .41135 L .78225 .40808 L F
.751 .67 .771 r
.77839 .4117 m .78015 .41169 L .77679 .41196 L F
.78074 .41131 m .78015 .41169 L .77839 .4117 L F
.702 .787 .917 r
.77993 .41135 m .78015 .41169 L .7804 .41126 L F
.77993 .41135 m .7804 .41126 L .78225 .40808 L F
.751 .67 .771 r
.78074 .41131 m .77679 .41196 L .77674 .41194 L F
.719 .793 .91 r
.77635 .41177 m .78015 .41169 L .77703 .40698 L F
.751 .67 .771 r
.77674 .41194 m .77631 .412 L .77797 .4122 L F
.77674 .41194 m .77679 .41196 L .77631 .412 L F
.719 .793 .91 r
.77631 .412 m .77679 .41196 L .77635 .41177 L F
.696 .155 0 r
.77672 .41193 m .77674 .41194 L .77597 .41161 L F
.719 .793 .91 r
.77679 .41196 m .78015 .41169 L .77635 .41177 L F
.696 .155 0 r
.77635 .41177 m .77597 .41161 L .77583 .41155 L F
.77672 .41193 m .77597 .41161 L .77635 .41177 L F
.77691 .41265 m .77797 .4122 L .77607 .4118 L F
.673 .124 0 r
.7801 .41409 m .77797 .4122 L .77691 .41265 L F
.541 .212 .36 r
.44195 .57618 m .43807 .57936 L .43905 .57695 L F
.44195 .57618 m .44011 .57974 L .43807 .57936 L F
.333 0 .058 r
.44444 .57705 m .44011 .57974 L .44195 .57618 L F
.616 .396 .56 r
.46305 .60401 m .46054 .60648 L .46051 .60426 L F
.111 .463 .889 r
.52084 .56473 m .52121 .56363 L .51829 .56243 L F
.536 .598 .863 r
.74635 .42385 m .74757 .42017 L .74533 .42019 L F
.74635 .42385 m .74889 .42339 L .74757 .42017 L F
0 0 .301 r
.52619 .54729 m .52566 .54723 L .52594 .5467 L F
.52619 .54729 m .52583 .55009 L .52566 .54723 L F
.253 0 .273 r
.44097 .62861 m .44002 .63061 L .4382 .63126 L F
0 .266 .712 r
.78553 .40794 m .78299 .40665 L .78195 .40569 L F
.071 .37 .837 r
.78387 .4054 m .78487 .40747 L .78195 .40569 L F
0 .266 .712 r
.78565 .40801 m .78553 .40794 L .78487 .40747 L F
.78553 .40794 m .78195 .40569 L .78469 .40735 L F
.78553 .40794 m .78469 .40735 L .78487 .40747 L F
.615 .74 .935 r
.78225 .40808 m .78327 .40638 L .78093 .40615 L F
.78327 .40638 m .78334 .40628 L .78311 .40626 L F
.78327 .40638 m .78311 .40626 L .78093 .40615 L F
.78334 .40628 m .78387 .4054 L .7826 .40572 L F
.78334 .40628 m .7826 .40572 L .78093 .40615 L F
0 .266 .712 r
.78565 .40801 m .78559 .40798 L .78553 .40794 L F
.78559 .40798 m .78299 .40665 L .78553 .40794 L F
.855 .993 .835 r
.78523 .44255 m .78257 .4453 L .78343 .44271 L F
.672 .975 .882 r
.78523 .44255 m .78682 .44058 L .78683 .44098 L F
.78523 .44255 m .78343 .44271 L .78682 .44058 L F
.4 .158 .428 r
.7299 .37773 m .72749 .37959 L .72978 .37991 L F
.185 .193 .633 r
.42011 .64868 m .42194 .65142 L .42014 .65185 L F
.026 0 .009 r
.42194 .65142 m .41908 .65421 L .42014 .65185 L F
.435 .181 .429 r
.42396 .6251 m .42637 .62455 L .4266 .62234 L F
.676 .491 .628 r
.42637 .62455 m .42902 .62175 L .4266 .62234 L F
.896 .682 .605 r
.59792 .4803 m .59959 .48115 L .59809 .47769 L F
.859 .678 .656 r
.59792 .4803 m .59937 .48366 L .59959 .48115 L F
.429 .133 .359 r
.1577 .57569 m .15632 .57418 L .15942 .5744 L F
.1577 .57569 m .15564 .57625 L .15632 .57418 L F
.196 .72 .712 r
.19996 .6514 m .2042 .65038 L .20182 .65029 L F
.403 .826 .965 r
.2042 .65038 m .20367 .64918 L .20182 .65029 L F
.2042 .65038 m .20642 .6499 L .20367 .64918 L F
.671 .131 0 r
.47644 .58221 m .47208 .58071 L .47485 .58139 L F
.55 .337 .544 r
.40905 .6283 m .4116 .62793 L .41167 .6252 L F
.613 .389 .552 r
.41167 .6252 m .41416 .62752 L .41424 .62494 L F
.41167 .6252 m .4116 .62793 L .41416 .62752 L F
0 .366 .783 r
.18544 .73895 m .18572 .73907 L .18614 .73944 L F
.85 .955 .88 r
.18614 .73944 m .18572 .73907 L .18541 .73939 L F
.805 .779 .829 r
.46732 .57057 m .46949 .57335 L .47098 .57185 L F
.331 .078 .372 r
.46949 .57335 m .46904 .57625 L .47127 .5733 L F
.46949 .57335 m .46904 .57625 L .47127 .5733 L F
.691 .651 .805 r
.214 .66996 m .21551 .67334 L .21817 .67119 L F
.181 0 0 r
.20429 .72213 m .20272 .72349 L .20093 .72386 L F
.138 0 0 r
.2065 .72157 m .20272 .72349 L .20429 .72213 L F
.943 .638 .188 r
.5303 .55798 m .53152 .56146 L .5313 .5593 L F
.212 .129 .54 r
.39344 .61308 m .3948 .61256 L .39509 .6093 L F
.24 .201 .611 r
.39344 .61308 m .39526 .61515 L .3948 .61256 L F
.408 .198 .479 r
.42267 .63736 m .42554 .63675 L .42671 .63728 L F
.93 .942 .782 r
.42671 .63728 m .42554 .63675 L .42767 .63331 L F
.483 .334 .603 r
.4291 .63946 m .42694 .64031 L .42671 .63728 L F
.847 .877 .44 r
.57786 .53363 m .57761 .53553 L .5767 .53774 L F
.56 .442 .676 r
.50463 .60773 m .50725 .60762 L .50662 .60479 L F
.50463 .60773 m .5051 .61009 L .50725 .60762 L F
.992 .778 .512 r
.58233 .52234 m .58118 .52142 L .58267 .52011 L F
.999 .835 .513 r
.58267 .52011 m .58165 .51897 L .58216 .51633 L F
.996 .862 .567 r
.58267 .52011 m .58118 .52142 L .58165 .51897 L F
0 0 .23 r
.77771 .38907 m .777 .39035 L .77705 .39331 L F
.898 .839 .779 r
.74907 .40354 m .74624 .40428 L .74799 .40148 L F
.74907 .40354 m .74733 .40617 L .74624 .40428 L F
.782 .801 .868 r
.75077 .40248 m .74907 .40354 L .74799 .40148 L F
0 0 0 r
.57603 .47515 m .5742 .47858 L .57579 .47623 L F
.56 .342 .541 r
.57579 .47623 m .57851 .47409 L .57603 .47515 L F
.773 .811 .33 r
.58902 .53999 m .58781 .5441 L .58948 .5399 L F
.58902 .53999 m .58751 .54383 L .58781 .5441 L F
.623 .475 .66 r
.44074 .5862 m .44096 .5889 L .44326 .58595 L F
.879 .992 .793 r
.77869 .40178 m .78173 .39934 L .78077 .39872 L F
.521 .68 .937 r
.78173 .39934 m .78342 .3973 L .78077 .39872 L F
.78173 .39934 m .78432 .39908 L .78342 .3973 L F
.703 .528 .648 r
.46804 .59477 m .47042 .59499 L .46966 .59249 L F
.46966 .59249 m .47042 .59499 L .46804 .59477 L F
.577 .454 .676 r
.47245 .59412 m .46966 .59249 L .47251 .59199 L F
.47245 .59412 m .47042 .59499 L .46966 .59249 L F
.47245 .59412 m .47042 .59499 L .46966 .59249 L F
.526 .85 .997 r
.16743 .61829 m .16966 .61768 L .16932 .61899 L F
.045 .337 .817 r
.16966 .61768 m .17166 .62042 L .16932 .61899 L F
.117 0 0 r
.45274 .57081 m .45134 .57197 L .44896 .57243 L F
0 0 0 r
.4546 .56973 m .45274 .57081 L .45533 .56897 L F
.376 0 .07 r
.4546 .56973 m .45134 .57197 L .45274 .57081 L F
.523 .192 .349 r
.16021 .55455 m .16325 .55277 L .16118 .55349 L F
.284 .767 .92 r
.22075 .64796 m .22272 .64833 L .22469 .64804 L F
.559 .618 .868 r
.18541 .65061 m .1865 .64808 L .1841 .64873 L F
.18541 .65061 m .18751 .6509 L .1865 .64808 L F
0 0 0 r
.19305 .54184 m .19318 .5424 L .19488 .54127 L F
.19305 .54184 m .19108 .54317 L .19318 .5424 L F
.797 .431 .364 r
.45659 .61685 m .46218 .61622 L .45966 .61623 L F
.858 .696 .68 r
.64616 .41423 m .6444 .41696 L .64769 .41763 L F
.836 .757 .776 r
.6444 .41696 m .64532 .42075 L .64769 .41763 L F
.771 .765 .847 r
.51503 .52854 m .51847 .52866 L .51794 .52847 L F
.442 .312 .608 r
.2897 .58532 m .28978 .5891 L .28769 .5894 L F
.578 .501 .732 r
.28978 .5891 m .28807 .59187 L .28769 .5894 L F
.508 .167 .324 r
.47227 .61904 m .46903 .62095 L .46984 .6198 L F
.358 0 0 r
.43542 .63777 m .43135 .63861 L .43287 .63756 L F
0 .152 .679 r
.43658 .64017 m .43577 .63769 L .43739 .63774 L F
.43658 .64017 m .43742 .63911 L .43664 .63837 L F
.516 .113 .215 r
.43742 .63911 m .4362 .63795 L .43629 .63784 L F
0 .152 .679 r
.43658 .64017 m .43662 .63897 L .43577 .63769 L F
.43662 .63897 m .43665 .63813 L .43604 .63782 L F
.43662 .63897 m .43604 .63782 L .43577 .63769 L F
.43577 .63769 m .4354 .63653 L .43688 .63743 L F
.358 0 0 r
.43629 .63784 m .43604 .63782 L .4354 .63653 L F
.43604 .63782 m .43287 .63756 L .4354 .63653 L F
.516 .113 .215 r
.43742 .63911 m .43364 .64106 L .4362 .63795 L F
0 .152 .679 r
.43664 .63837 m .43742 .63911 L .43665 .63813 L F
.358 0 0 r
.43629 .63784 m .43613 .63787 L .43604 .63782 L F
0 .152 .679 r
.43577 .63769 m .43688 .63743 L .43739 .63774 L F
0 .015 .583 r
.4354 .63653 m .43742 .63911 L .43629 .63784 L F
0 .152 .679 r
.43577 .63769 m .43665 .63813 L .4354 .63653 L F
.358 0 0 r
.43604 .63782 m .43284 .63838 L .43542 .63777 L F
.43613 .63787 m .43284 .63838 L .43604 .63782 L F
.43284 .63838 m .43135 .63861 L .43542 .63777 L F
.083 0 .118 r
.70621 .40162 m .70422 .40299 L .70371 .40432 L F
.434 .236 .51 r
.4581 .60029 m .46109 .59737 L .45822 .59913 L F
.122 .549 .919 r
.26187 .54015 m .26169 .54114 L .26063 .53953 L F
.26187 .54015 m .26394 .54178 L .26169 .54114 L F
.846 .674 .669 r
.59926 .48625 m .60084 .48725 L .59937 .48366 L F
.843 .756 .766 r
.74982 .3991 m .75077 .40248 L .74799 .40148 L F
.827 .748 .776 r
.75162 .40041 m .75077 .40248 L .74982 .3991 L F
.289 0 .186 r
.24782 .63918 m .24444 .64246 L .24569 .64009 L F
.799 .943 .92 r
.78257 .4453 m .78163 .44434 L .78343 .44271 L F
.068 .028 .499 r
.57647 .58274 m .57669 .58533 L .57569 .58597 L F
.032 0 .427 r
.57669 .58533 m .57675 .58757 L .57569 .58597 L F
.047 0 .423 r
.57675 .58757 m .57564 .58868 L .57569 .58597 L F
.174 0 .214 r
.23278 .64745 m .23178 .64663 L .23327 .64597 L F
.23278 .64745 m .23089 .64877 L .23178 .64663 L F
0 0 0 r
.65728 .40541 m .65959 .40198 L .65711 .40266 L F
.659 .183 .11 r
.42502 .61264 m .42391 .61297 L .4275 .61336 L F
.422 .202 .472 r
.2541 .59209 m .25617 .59155 L .25646 .58919 L F
.402 .24 .544 r
.2541 .59209 m .25596 .59408 L .25617 .59155 L F
.2541 .59209 m .25406 .59483 L .25596 .59408 L F
.539 .893 .978 r
.20642 .6499 m .21021 .64947 L .20863 .64938 L F
.033 .599 .783 r
.21021 .64947 m .21059 .64931 L .20863 .64938 L F
.21021 .64947 m .21229 .64956 L .21059 .64931 L F
0 0 .14 r
.50983 .53513 m .51139 .53501 L .51141 .53314 L F
.50983 .53513 m .50954 .53721 L .51139 .53501 L F
.556 .207 .333 r
.57258 .47885 m .57579 .47623 L .5742 .47858 L F
.122 0 .017 r
.14616 .56412 m .14935 .56128 L .14819 .56213 L F
.317 .772 .953 r
.4809 .55894 m .48324 .55869 L .48472 .55919 L F
.121 0 0 r
.48324 .55869 m .48715 .55935 L .48472 .55919 L F
.999 .809 .518 r
.21431 .68227 m .2139 .68518 L .21285 .68424 L F
.672 .447 .571 r
.5908 .47442 m .59444 .47457 L .59424 .472 L F
.654 .434 .572 r
.59424 .472 m .59444 .47457 L .59678 .4717 L F
.772 .482 .496 r
.57886 .50198 m .57532 .50385 L .57483 .50193 L F
.57886 .50198 m .57931 .5045 L .57532 .50385 L F
.815 .512 .476 r
.58249 .50501 m .57931 .5045 L .57886 .50198 L F
.822 .79 .822 r
.67073 .43382 m .66846 .43661 L .6666 .4351 L F
.655 .903 .981 r
.71676 .42007 m .7203 .4197 L .71914 .41892 L F
.688 .83 .952 r
.7203 .4197 m .72214 .41696 L .71914 .41892 L F
.7203 .4197 m .7232 .41837 L .72214 .41696 L F
.177 0 0 r
.66265 .40059 m .66508 .4007 L .66608 .39969 L F
.826 .363 .115 r
.66508 .4007 m .66805 .40214 L .66608 .39969 L F
.249 0 0 r
.22985 .55311 m .22807 .55293 L .22599 .55245 L F
0 .123 .667 r
.22985 .55311 m .23095 .55334 L .22807 .55293 L F
.22985 .55311 m .23185 .55504 L .23095 .55334 L F
.133 0 .249 r
.39509 .6093 m .397 .60675 L .39498 .60707 L F
.778 .461 .451 r
.42077 .62464 m .42284 .6277 L .42396 .6251 L F
.503 .165 .326 r
.42396 .6251 m .42619 .62659 L .42637 .62455 L F
.42396 .6251 m .42284 .6277 L .42619 .62659 L F
.805 .779 .829 r
.46732 .57057 m .47098 .57185 L .47014 .57019 L F
.57 .007 0 r
.77531 .41599 m .77676 .41678 L .77491 .41654 L F
.77531 .41599 m .77676 .41678 L .77491 .41654 L F
.603 .492 .699 r
.4382 .6454 m .43836 .64937 L .43551 .64935 L F
.397 0 0 r
.43836 .64937 m .43753 .65055 L .43551 .64935 L F
.698 .233 .142 r
.43753 .65055 m .43397 .64834 L .43551 .64935 L F
0 .229 .661 r
.4566 .56978 m .45752 .57026 L .45533 .56897 L F
.45884 .57121 m .45752 .57026 L .4566 .56978 L F
.186 .715 .727 r
.45983 .57042 m .4584 .57072 L .45752 .57026 L F
.4584 .57072 m .45606 .5712 L .45752 .57026 L F
.536 .147 .25 r
.45533 .56897 m .45752 .57026 L .4546 .56973 L F
.544 .35 .568 r
.4263 .60966 m .42391 .61297 L .42387 .61018 L F
.16 0 0 r
.52249 .52576 m .52024 .52553 L .52089 .52552 L F
.893 .6 .483 r
.68206 .41787 m .68032 .41962 L .67844 .41531 L F
.68206 .41787 m .68228 .42031 L .68032 .41962 L F
.773 .424 .393 r
.68206 .41787 m .68609 .42046 L .68228 .42031 L F
0 .008 .579 r
.5241 .57069 m .52595 .5739 L .52581 .57277 L F
0 0 .412 r
.52595 .5739 m .5269 .57507 L .52581 .57277 L F
.52595 .5739 m .52712 .57635 L .5269 .57507 L F
.887 .753 .25 r
.76705 .41177 m .76658 .41095 L .76738 .4103 L F
.76705 .41177 m .76674 .41487 L .76658 .41095 L F
.368 .19 .503 r
.69689 .4059 m .69566 .40909 L .69836 .40942 L F
.759 .355 .285 r
.70121 .40797 m .69821 .40528 L .69689 .4059 L F
.629 .257 .319 r
.70082 .40943 m .69689 .4059 L .69836 .40942 L F
.70082 .40943 m .70121 .40797 L .69689 .4059 L F
.458 .861 .965 r
.51075 .60737 m .50976 .60694 L .50725 .60762 L F
.459 .842 .619 r
.51295 .60575 m .51221 .60621 L .51075 .60737 L F
.489 .877 .967 r
.51221 .60621 m .50976 .60694 L .51075 .60737 L F
.847 .691 .689 r
.2393 .60997 m .23603 .60975 L .237 .60724 L F
.981 .878 .514 r
.23606 .61276 m .23603 .60975 L .2393 .60997 L F
.65 .172 0 r
.237 .60724 m .23827 .60904 L .2393 .60997 L F
.785 .285 0 r
.23901 .61135 m .2393 .60997 L .23827 .60904 L F
.23901 .61135 m .24161 .61255 L .2393 .60997 L F
.631 .632 .834 r
.73736 .39724 m .73889 .39278 L .736 .39302 L F
.73736 .39724 m .73986 .39627 L .73889 .39278 L F
.877 .635 .109 r
.52386 .56813 m .52361 .56918 L .52334 .56707 L F
.52386 .56813 m .5241 .57069 L .52361 .56918 L F
0 0 .377 r
.51745 .56186 m .5171 .56117 L .51559 .55861 L F
0 0 .497 r
.51829 .56243 m .5171 .56117 L .51745 .56186 L F
.586 .158 .195 r
.44227 .59434 m .44503 .59483 L .44559 .59375 L F
.669 .625 .796 r
.44323 .58828 m .44559 .59375 L .44703 .59212 L F
0 0 0 r
.44559 .59375 m .44689 .59324 L .44703 .59212 L F
.44559 .59375 m .44503 .59483 L .44689 .59324 L F
.801 .319 0 r
.49282 .54146 m .49231 .54218 L .49068 .53954 L F
.763 .255 0 r
.49282 .54146 m .49389 .54322 L .49231 .54218 L F
.754 .259 .051 r
.49668 .54396 m .49389 .54322 L .49282 .54146 L F
.26 .067 .419 r
.25646 .58919 m .25783 .59078 L .25815 .58828 L F
.25646 .58919 m .25617 .59155 L .25783 .59078 L F
0 0 .222 r
.65514 .44646 m .65527 .44303 L .65671 .44408 L F
.582 .846 .995 r
.65937 .44336 m .65671 .44408 L .65527 .44303 L F
.698 .972 .756 r
.68525 .43493 m .68549 .43526 L .68848 .43256 L F
.419 .404 .736 r
.29215 .5583 m .29122 .56271 L .29018 .55873 L F
.29215 .5583 m .29235 .56257 L .29122 .56271 L F
.434 .277 .567 r
.29235 .56257 m .29122 .56489 L .29122 .56271 L F
.983 .832 .438 r
.59064 .53525 m .59121 .5319 L .59016 .53346 L F
.964 .938 .646 r
.59121 .5319 m .59176 .52802 L .59137 .52912 L F
.905 .881 .453 r
.59016 .53346 m .59121 .5319 L .59137 .52912 L F
.998 .799 .448 r
.52854 .55507 m .52977 .55288 L .52652 .55236 L F
.52854 .55507 m .52943 .55582 L .52977 .55288 L F
0 .111 .664 r
.76933 .43857 m .77077 .43932 L .76839 .43744 L F
.76933 .43857 m .7713 .44106 L .77077 .43932 L F
.64 .561 .75 r
.80281 .4116 m .80039 .41485 L .80014 .41221 L F
.658 .586 .763 r
.80281 .4116 m .80358 .41455 L .80039 .41485 L F
.66 .45 .589 r
.80358 .41455 m .80019 .41722 L .80039 .41485 L F
.812 .594 .607 r
.58249 .50501 m .57888 .50701 L .57931 .5045 L F
.58249 .50501 m .58244 .50755 L .57888 .50701 L F
.383 .145 .425 r
.23229 .62218 m .2339 .62395 L .2346 .62166 L F
.23229 .62218 m .23188 .62464 L .2339 .62395 L F
.256 0 0 r
.50882 .52172 m .51145 .52157 L .5134 .51957 L F
0 0 0 r
.5134 .51957 m .51509 .51894 L .5156 .51841 L F
.5134 .51957 m .51145 .52157 L .51509 .51894 L F
0 .163 .703 r
.41039 .64591 m .4105 .64462 L .4087 .64256 L F
.41039 .64591 m .4111 .64614 L .4105 .64462 L F
.926 .883 .772 r
.75622 .41645 m .75923 .41435 L .75825 .41314 L F
.75622 .41645 m .75732 .41771 L .75923 .41435 L F
.961 .901 .528 r
.23606 .61276 m .23516 .61644 L .23472 .61477 L F
0 0 .495 r
.23516 .61644 m .23634 .61829 L .23472 .61477 L F
.783 .676 .745 r
.4275 .61336 m .42391 .61297 L .4263 .60966 L F
.754 .697 .798 r
.42869 .60944 m .4275 .61336 L .4263 .60966 L F
.491 .175 .359 r
.56253 .5022 m .56524 .50343 L .56255 .50386 L F
.515 .095 .18 r
.56593 .50207 m .56524 .50343 L .56253 .5022 L F
.573 .727 .947 r
.19279 .72762 m .19339 .72587 L .191 .72407 L F
.352 .817 .732 r
.55518 .58068 m .5553 .58086 L .55383 .58163 L F
.55518 .58068 m .55767 .57983 L .5553 .58086 L F
.961 .901 .528 r
.23606 .61276 m .23472 .61477 L .23553 .6124 L F
.981 .878 .514 r
.23606 .61276 m .23553 .6124 L .23603 .60975 L F
.732 .419 .45 r
.42365 .59511 m .42359 .59752 L .42551 .59748 L F
.969 .684 .271 r
.65129 .42033 m .65147 .42317 L .65035 .41944 L F
.847 .96 .881 r
.65129 .42033 m .6531 .41698 L .65375 .41724 L F
.65129 .42033 m .65035 .41944 L .6531 .41698 L F
.525 .494 .764 r
.64168 .41788 m .6444 .41696 L .64248 .41367 L F
.433 .242 .521 r
.64168 .41788 m .6417 .4202 L .6444 .41696 L F
.465 .887 .908 r
.21506 .64943 m .21645 .64948 L .21855 .64867 L F
.097 .026 .479 r
.51502 .53102 m .51516 .53356 L .51337 .53511 L F
0 0 .291 r
.51366 .53486 m .51337 .53511 L .51516 .53356 L F
.51366 .53486 m .51411 .53757 L .51337 .53511 L F
.951 .612 .335 r
.4211 .63842 m .42267 .63736 L .422 .63582 L F
.4211 .63842 m .4229 .63959 L .42267 .63736 L F
.408 .198 .479 r
.42267 .63736 m .4229 .63959 L .42554 .63675 L F
.285 0 .175 r
.44957 .56138 m .45208 .56021 L .45027 .55905 L F
.689 .768 .911 r
.82233 .44393 m .81937 .44416 L .822 .44229 L F
.476 .18 .383 r
.82233 .44393 m .81967 .44742 L .81937 .44416 L F
.82233 .44393 m .82235 .44682 L .81967 .44742 L F
.457 .439 .75 r
.82469 .44125 m .82233 .44393 L .822 .44229 L F
.82469 .44125 m .82522 .44365 L .82233 .44393 L F
.46 .202 .435 r
.82522 .44365 m .82235 .44682 L .82233 .44393 L F
.954 .952 .694 r
.57029 .56201 m .56923 .56136 L .57106 .55799 L F
.975 .875 .497 r
.56929 .56429 m .56923 .56136 L .57029 .56201 L F
0 0 0 r
.15799 .61145 m .15763 .61154 L .15729 .61258 L F
.15799 .61145 m .15801 .61139 L .15763 .61154 L F
.526 .065 .102 r
.69212 .41006 m .69316 .40848 L .68954 .40878 L F
.564 .029 0 r
.69455 .4099 m .69316 .40848 L .69212 .41006 L F
.69455 .4099 m .69566 .40909 L .69316 .40848 L F
.577 .526 .762 r
.50725 .60762 m .50904 .60482 L .50662 .60479 L F
.728 .622 .739 r
.7987 .41669 m .79832 .42117 L .79505 .41979 L F
.786 .548 .577 r
.79832 .42117 m .79918 .42339 L .79328 .42331 L F
.323 .265 .636 r
.80056 .41888 m .79832 .42117 L .7987 .41669 L F
.611 .586 .801 r
.80056 .41888 m .79918 .42339 L .79832 .42117 L F
.628 .42 .581 r
.71756 .39353 m .72027 .39285 L .7202 .39097 L F
.744 .464 .507 r
.72176 .39358 m .7202 .39097 L .72027 .39285 L F
0 0 .088 r
.58216 .56436 m .58147 .5667 L .58002 .56821 L F
0 0 .429 r
.58147 .5667 m .58022 .57058 L .58002 .56821 L F
.383 .016 .213 r
.15353 .57688 m .15246 .57907 L .1501 .57952 L F
.015 0 .025 r
.15399 .57822 m .15353 .57688 L .15564 .57625 L F
.15399 .57822 m .15246 .57907 L .15353 .57688 L F
.865 .932 .866 r
.66293 .4475 m .66646 .44542 L .66565 .4444 L F
.642 .764 .937 r
.66785 .44308 m .66646 .44542 L .66565 .4444 L F
.66785 .44308 m .66909 .44464 L .66646 .44542 L F
.664 .841 .968 r
.66661 .44862 m .67086 .4486 L .66965 .44765 L F
.881 .915 .845 r
.66965 .44765 m .67086 .4486 L .67086 .44589 L F
.999 .794 .492 r
.74721 .39979 m .74602 .4011 L .74617 .39856 L F
.798 .379 .253 r
.74799 .40148 m .74602 .4011 L .74721 .39979 L F
.471 .237 .477 r
.74982 .3991 m .74799 .40148 L .74721 .39979 L F
.812 .419 .308 r
.40608 .62732 m .40803 .62979 L .40905 .6283 L F
.801 .615 .65 r
.40803 .62979 m .4116 .62793 L .40905 .6283 L F
.356 .796 .961 r
.17509 .6218 m .17732 .62147 L .17921 .62196 L F
.559 .887 .988 r
.17921 .62196 m .17732 .62147 L .17981 .62068 L F
0 .014 .581 r
.17988 .6213 m .17921 .62196 L .17981 .62068 L F
.17988 .6213 m .18086 .62456 L .17921 .62196 L F
0 .378 .833 r
.48715 .55935 m .48973 .56133 L .48839 .56031 L F
.77 .693 .778 r
.485 .59669 m .49035 .5983 L .48755 .59403 L F
.075 0 .131 r
.57075 .59771 m .57045 .5999 L .56824 .60071 L F
.059 0 .194 r
.57305 .59438 m .57289 .59685 L .57075 .59771 L F
.031 0 .121 r
.57289 .59685 m .57045 .5999 L .57075 .59771 L F
0 .195 .7 r
.78301 .39051 m .77992 .38755 L .78233 .38875 L F
.317 .54 .91 r
.78422 .389 m .78301 .39051 L .78233 .38875 L F
.248 .439 .853 r
.78422 .389 m .78603 .39196 L .78301 .39051 L F
0 0 0 r
.20819 .69719 m .20435 .70013 L .20638 .69931 L F
.758 .408 .391 r
.6684 .40446 m .67072 .40247 L .66805 .40214 L F
.6684 .40446 m .67199 .40497 L .67072 .40247 L F
.779 .613 .674 r
.59444 .47457 m .59825 .47514 L .59678 .4717 L F
.79 .634 .688 r
.59437 .47719 m .59825 .47514 L .59444 .47457 L F
.59437 .47719 m .59809 .47769 L .59825 .47514 L F
.371 .748 .99 r
.43855 .64009 m .43742 .63911 L .43658 .64017 L F
.443 0 .047 r
.4368 .64287 m .43855 .64009 L .43658 .64017 L F
.503 .173 .34 r
.49347 .58801 m .49625 .58585 L .4937 .58591 L F
.159 .161 .611 r
.41976 .6466 m .42109 .64898 L .42011 .64868 L F
.66 .359 .452 r
.42172 .64666 m .42109 .64898 L .41976 .6466 L F
.159 .161 .611 r
.41976 .6466 m .42109 .64898 L .42011 .64868 L F
.072 .633 .774 r
.22135 .53851 m .22359 .53846 L .22572 .53864 L F
.283 .776 .894 r
.22359 .53846 m .22765 .5383 L .22572 .53864 L F
.902 .771 .708 r
.59481 .50976 m .59786 .50774 L .59638 .5068 L F
.59481 .50976 m .59658 .51126 L .59786 .50774 L F
.764 .716 .808 r
.6444 .41696 m .6417 .4202 L .64532 .42075 L F
.169 .108 .541 r
.25979 .57682 m .26091 .57275 L .25918 .57421 L F
.833 .733 .754 r
.59942 .49833 m .60024 .49662 L .59831 .49517 L F
.824 .894 .892 r
.65669 .44839 m .66067 .44681 L .65963 .44729 L F
.356 .803 .659 r
.66193 .44607 m .66067 .44681 L .66293 .4475 L F
.66193 .44607 m .65963 .44729 L .66067 .44681 L F
.384 .009 .197 r
.4675 .58182 m .46639 .58456 L .46396 .58503 L F
.113 0 .08 r
.46849 .58332 m .4675 .58182 L .47016 .58143 L F
.46849 .58332 m .46639 .58456 L .4675 .58182 L F
.414 .505 .843 r
.16322 .63566 m .16391 .63284 L .16211 .63374 L F
.16322 .63566 m .16567 .63644 L .16391 .63284 L F
.2 .481 .895 r
.17331 .621 m .17287 .62241 L .17166 .62042 L F
.543 .847 .998 r
.17509 .6218 m .17287 .62241 L .17331 .621 L F
.107 .457 .886 r
.79251 .39689 m .79079 .39633 L .79021 .39493 L F
.481 .871 .684 r
.78915 .43579 m .79129 .43417 L .79256 .43356 L F
0 0 0 r
.78917 .43796 m .79129 .43417 L .78915 .43579 L F
.20005 .71828 m .19549 .72016 L .19773 .7197 L F
.488 0 0 r
.20014 .71961 m .20005 .71828 L .19773 .7197 L F
.20014 .71961 m .20218 .71898 L .20005 .71828 L F
.972 .85 .448 r
.52998 .58301 m .52945 .58558 L .52898 .5845 L F
0 .003 .578 r
.52998 .58301 m .53004 .58235 L .52858 .58012 L F
.782 .873 .443 r
.52998 .58301 m .52898 .5845 L .53004 .58235 L F
.785 .665 .731 r
.44193 .56405 m .44554 .56501 L .44413 .56123 L F
.775 .378 .301 r
.44193 .56405 m .44367 .56608 L .44554 .56501 L F
.74 .643 .752 r
.44413 .56123 m .44554 .56501 L .44762 .56245 L F
.552 .375 .595 r
.44554 .56501 m .44808 .56514 L .44762 .56245 L F
.383 .809 .63 r
.44554 .56501 m .44648 .56439 L .44808 .56514 L F
.44554 .56501 m .44367 .56608 L .44648 .56439 L F
.937 .769 .647 r
.59942 .49833 m .59831 .49517 L .59767 .49773 L F
.905 .836 .767 r
.59942 .49833 m .59587 .50071 L .59785 .50188 L F
.59942 .49833 m .59767 .49773 L .59587 .50071 L F
.111 0 0 r
.1909 .55937 m .19029 .55885 L .19256 .55832 L F
.1909 .55937 m .18885 .55958 L .19029 .55885 L F
.761 .828 .904 r
.81937 .44416 m .81576 .4439 L .81818 .44231 L F
.81937 .44416 m .81691 .4449 L .81576 .4439 L F
.563 .353 .554 r
.81937 .44416 m .81691 .44769 L .81691 .4449 L F
.81937 .44416 m .81967 .44742 L .81691 .44769 L F
.699 .796 .925 r
.822 .44229 m .81937 .44416 L .81818 .44231 L F
.326 .355 .738 r
.78824 .40186 m .78832 .40452 L .79093 .40372 L F
.115 0 .127 r
.79093 .40372 m .78832 .40452 L .78817 .4074 L F
.217 .355 .789 r
.4415 .62768 m .44097 .62861 L .43901 .62493 L F
0 0 0 r
.4415 .62768 m .44002 .63061 L .44097 .62861 L F
.906 .784 .715 r
.73889 .39278 m .73986 .39627 L .74148 .39313 L F
.957 .614 .284 r
.74733 .40617 m .74663 .40687 L .74624 .40428 L F
.74733 .40617 m .74803 .40828 L .74663 .40687 L F
.565 .194 .298 r
.24198 .64507 m .23984 .64354 L .24259 .64304 L F
.24198 .64507 m .23927 .64542 L .23984 .64354 L F
.043 0 .258 r
.57563 .5913 m .57501 .59356 L .57305 .59438 L F
.016 0 .184 r
.57501 .59356 m .57289 .59685 L .57305 .59438 L F
.545 .515 .773 r
.73661 .37437 m .73777 .37264 L .73499 .37284 L F
.73661 .37437 m .73944 .37388 L .73777 .37264 L F
.419 .866 .87 r
.21857 .63115 m .21418 .63214 L .21707 .63131 L F
.051 .372 .839 r
.45884 .57121 m .46132 .57278 L .45983 .57042 L F
0 0 .258 r
.58045 .57283 m .57878 .5765 L .57895 .57411 L F
.627 .629 .833 r
.43353 .6005 m .43161 .60182 L .42902 .59712 L F
0 0 .417 r
.53216 .59537 m .5325 .59798 L .5327 .59417 L F
.055 .39 .85 r
.79154 .39557 m .79021 .39493 L .79058 .39382 L F
0 .264 .772 r
.79058 .39382 m .79021 .39493 L .79094 .39434 L F
.061 .448 .879 r
.79094 .39434 m .78679 .39342 L .78603 .39196 L F
.79094 .39434 m .79021 .39493 L .78679 .39342 L F
.305 .781 .923 r
.22765 .5383 m .22994 .53798 L .23212 .53859 L F
.258 .739 .931 r
.22994 .53798 m .23405 .53832 L .23212 .53859 L F
.723 .651 .777 r
.78074 .41131 m .78458 .41302 L .7833 .41058 L F
.605 .687 .901 r
.7833 .41058 m .78458 .41302 L .78715 .41198 L F
.038 0 0 r
.19488 .54127 m .19675 .54133 L .19889 .54126 L F
.406 .526 .866 r
.79388 .41526 m .79569 .41293 L .79377 .41313 L F
.383 .493 .847 r
.79388 .41526 m .79718 .41609 L .79569 .41293 L F
.442 .554 .874 r
.19001 .64878 m .19182 .652 L .19378 .65182 L F
.636 .135 .041 r
.49472 .56425 m .49703 .56605 L .49849 .56475 L F
.694 .266 .227 r
.49703 .56605 m .49974 .56559 L .49849 .56475 L F
0 0 .329 r
.5325 .59798 m .53363 .6012 L .53361 .60005 L F
0 0 .233 r
.53363 .6012 m .53409 .60367 L .53361 .60005 L F
0 0 0 r
.56578 .48443 m .56481 .48582 L .56751 .48311 L F
.377 .056 .289 r
.42902 .59712 m .43182 .59548 L .4298 .59505 L F
.74 .748 .858 r
.43182 .59548 m .42902 .59712 L .4298 .59505 L F
.822 .79 .822 r
.67073 .43382 m .6666 .4351 L .66895 .43185 L F
.782 .766 .838 r
.67275 .4316 m .67073 .43382 L .66895 .43185 L F
0 0 0 r
.16547 .55231 m .16756 .55175 L .16975 .55057 L F
.139 0 0 r
.16756 .55175 m .17171 .54969 L .16975 .55057 L F
0 0 .043 r
.40313 .60123 m .40221 .6031 L .40471 .60017 L F
.562 .171 .258 r
.56066 .57837 m .56248 .57882 L .56354 .57663 L F
.075 0 .266 r
.56354 .57663 m .56542 .57583 L .56526 .5738 L F
.329 .059 .342 r
.56248 .57882 m .56542 .57583 L .56354 .57663 L F
.798 .501 .486 r
.58215 .47471 m .58572 .47756 L .58467 .47467 L F
.701 .546 .673 r
.58467 .47467 m .58572 .47756 L .58821 .47481 L F
.868 .918 .86 r
.54889 .61259 m .55196 .6095 L .55027 .60875 L F
.362 .794 .967 r
.55196 .6095 m .55187 .60857 L .55027 .60875 L F
.596 .581 .806 r
.55163 .60989 m .55406 .6092 L .55196 .6095 L F
0 .523 .808 r
.5433 .61308 m .54185 .61253 L .53948 .61205 L F
.485 .841 .994 r
.5433 .61308 m .5442 .61188 L .54185 .61253 L F
.5433 .61308 m .54574 .61251 L .5442 .61188 L F
.437 0 0 r
.20277 .55925 m .20095 .55877 L .19897 .55785 L F
.14 .68 .832 r
.20277 .55925 m .20301 .5589 L .20095 .55877 L F
.20277 .55925 m .20538 .55913 L .20301 .5589 L F
.497 .709 .965 r
.2722 .54216 m .27151 .54409 L .27 .54246 L F
.46 .668 .953 r
.2722 .54216 m .27358 .54388 L .27151 .54409 L F
.081 .284 .769 r
.28615 .54782 m .28501 .54836 L .28361 .54728 L F
.28615 .54782 m .28668 .5502 L .28501 .54836 L F
.742 .249 .066 r
.67309 .40655 m .67376 .40533 L .67199 .40497 L F
.513 .189 .356 r
.44927 .58546 m .45169 .5853 L .45209 .58345 L F
.611 .346 .492 r
.45169 .5853 m .45478 .58293 L .45209 .58345 L F
0 0 0 r
.66265 .40059 m .65959 .40198 L .66215 .40091 L F
.121 0 0 r
.66215 .40091 m .66508 .4007 L .66265 .40059 L F
.615 .205 .241 r
.45208 .56021 m .45483 .56089 L .45642 .55888 L F
.54 .118 .19 r
.45642 .55888 m .45483 .56089 L .4587 .56006 L F
.873 .841 .811 r
.21028 .70579 m .20577 .70866 L .20849 .7079 L F
.569 .427 .648 r
.21243 .70751 m .21094 .70632 L .21159 .70651 L F
.21094 .70632 m .21028 .70579 L .21159 .70651 L F
.21243 .70751 m .21021 .70942 L .21028 .70579 L F
0 0 .526 r
.21159 .70651 m .21358 .70873 L .21243 .70751 L F
.264 .349 .764 r
.21341 .70664 m .21358 .70873 L .21159 .70651 L F
.21274 .70686 m .21159 .70651 L .20951 .70793 L F
.21341 .70664 m .21159 .70651 L .21274 .70686 L F
.058 0 0 r
.20849 .7079 m .21159 .70651 L .21028 .70579 L F
.632 .639 .839 r
.80688 .42956 m .80283 .42709 L .80608 .42742 L F
.584 .83 .991 r
.80834 .4275 m .80688 .42956 L .80608 .42742 L F
.80834 .4275 m .80957 .42881 L .80688 .42956 L F
.593 .353 .522 r
.80957 .42881 m .80684 .43145 L .80688 .42956 L F
.937 .632 .175 r
.43488 .56463 m .43528 .56733 L .43406 .56381 L F
.743 .957 .941 r
.43488 .56463 m .43406 .56381 L .43576 .56363 L F
.103 .018 .465 r
.43425 .56435 m .43576 .56363 L .43406 .56381 L F
.743 .957 .941 r
.43488 .56463 m .43576 .56363 L .43667 .5632 L F
.103 .018 .465 r
.43528 .56733 m .43576 .56363 L .43425 .56435 L F
.743 .957 .941 r
.43667 .5632 m .43576 .56363 L .43793 .5622 L F
.586 .705 .925 r
.43925 .59843 m .43919 .59942 L .44209 .59815 L F
.64 .655 .849 r
.43919 .59942 m .44323 .6002 L .44209 .59815 L F
.715 .273 .199 r
.67856 .41463 m .67739 .41616 L .67497 .41402 L F
.88 .503 .322 r
.67844 .41531 m .67739 .41616 L .67856 .41463 L F
.369 .153 .449 r
.46054 .60648 m .46019 .60946 L .45778 .60953 L F
.517 .218 .398 r
.46019 .60946 m .45687 .6118 L .45778 .60953 L F
.374 .079 .33 r
.23188 .62464 m .22976 .62522 L .22907 .62721 L F
.5 .311 .556 r
.27653 .61 m .27655 .61283 L .27422 .61335 L F
.393 .123 .381 r
.27655 .61283 m .27377 .61561 L .27422 .61335 L F
0 0 0 r
.57045 .5999 m .56736 .60244 L .56824 .60071 L F
.293 .487 .878 r
.17793 .64646 m .17866 .64479 L .17648 .6451 L F
.17793 .64646 m .18184 .64885 L .17866 .64479 L F
.349 .609 .946 r
.49974 .56559 m .50309 .56637 L .50224 .56795 L F
.942 .604 .357 r
.50078 .56921 m .50224 .56795 L .50309 .56637 L F
.50078 .56921 m .50282 .57016 L .50224 .56795 L F
.899 .569 .082 r
.59456 .51969 m .59427 .52058 L .59385 .52113 L F
.59456 .51969 m .5939 .51897 L .59427 .52058 L F
.991 .878 .612 r
.59456 .51969 m .59448 .51643 L .5939 .51897 L F
.851 .782 .783 r
.75128 .42245 m .75495 .42077 L .75371 .41937 L F
.75128 .42245 m .75266 .42392 L .75495 .42077 L F
.868 .848 .822 r
.75371 .41937 m .75495 .42077 L .75732 .41771 L F
.659 .329 .404 r
.45078 .62105 m .44748 .62126 L .4477 .61936 L F
.482 .423 .715 r
.48148 .57893 m .4842 .57895 L .48518 .57666 L F
.48148 .57893 m .48242 .57968 L .4842 .57895 L F
.318 .529 .902 r
.79556 .39784 m .79428 .39942 L .79251 .39689 L F
.345 .57 .923 r
.79626 .39958 m .79428 .39942 L .79556 .39784 L F
.795 .651 .703 r
.58244 .50755 m .58398 .51101 L .58025 .5104 L F
.83 .671 .686 r
.58398 .51101 m .58016 .51299 L .58025 .5104 L F
.58398 .51101 m .58335 .51353 L .58016 .51299 L F
0 .452 .707 r
.74446 .37542 m .74849 .37632 L .7473 .37603 L F
.425 .137 .37 r
.42396 .64797 m .42109 .64898 L .42172 .64666 L F
.596 .581 .806 r
.55163 .60989 m .55514 .60927 L .55406 .6092 L F
.685 .91 .572 r
.51085 .61063 m .50884 .6132 L .50985 .6114 L F
.184 0 0 r
.50884 .6132 m .50745 .61463 L .50985 .6114 L F
.50884 .6132 m .51031 .61388 L .50745 .61463 L F
.50884 .6132 m .51159 .61308 L .51031 .61388 L F
.558 .39 .609 r
.51085 .61063 m .51159 .61308 L .50884 .6132 L F
.678 .897 .543 r
.50985 .6114 m .50884 .6132 L .50745 .61463 L F
.209 0 .065 r
.15809 .55544 m .15862 .55708 L .16021 .55455 L F
.15809 .55544 m .1566 .55781 L .15862 .55708 L F
.866 .512 .01 r
.541 .57992 m .54158 .58195 L .54244 .58315 L F
.931 .56 .161 r
.54185 .58435 m .54244 .58315 L .54158 .58195 L F
.54185 .58435 m .5432 .58546 L .54244 .58315 L F
.51 .31 .545 r
.27893 .60701 m .27864 .60969 L .27653 .61 L F
.385 .221 .533 r
.27837 .61205 m .27653 .61 L .27864 .60969 L F
.27837 .61205 m .27655 .61283 L .27653 .61 L F
.698 .972 .756 r
.68525 .43493 m .68848 .43256 L .68729 .43348 L F
0 0 0 r
.68729 .43348 m .68848 .43256 L .69131 .43119 L F
.831 .477 .386 r
.47165 .57679 m .47576 .5783 L .47647 .57752 L F
.47165 .57679 m .47117 .57839 L .47576 .5783 L F
.673 .176 .059 r
.47117 .57839 m .47354 .58051 L .47576 .5783 L F
.196 .004 .379 r
.47576 .5783 m .47794 .57614 L .47647 .57752 L F
.47576 .5783 m .47763 .5787 L .47794 .57614 L F
.499 0 0 r
.26017 .55842 m .26157 .55871 L .26139 .55851 L F
.723 .925 .959 r
.48273 .61041 m .47991 .61078 L .48198 .60967 L F
.48273 .61041 m .4811 .61331 L .47991 .61078 L F
.868 .918 .86 r
.54889 .61259 m .55027 .60875 L .54833 .61239 L F
.882 .82 .782 r
.52099 .61292 m .51915 .61717 L .51941 .61585 L F
.211 .356 .792 r
.51915 .61717 m .51866 .61815 L .51941 .61585 L F
.53 .399 .646 r
.5219 .61521 m .51915 .61717 L .52099 .61292 L F
.407 .198 .48 r
.5219 .61521 m .52137 .61805 L .51915 .61717 L F
.868 .848 .822 r
.75371 .41937 m .75732 .41771 L .75622 .41645 L F
.819 .792 .827 r
.75871 .42806 m .75995 .42973 L .75748 .42855 L F
.99 .734 .38 r
.75995 .42973 m .75896 .43126 L .75748 .42855 L F
.75995 .42973 m .76 .43242 L .75896 .43126 L F
.824 .793 .823 r
.76251 .42673 m .75995 .42973 L .75871 .42806 L F
.808 .579 .591 r
.59437 .47719 m .59792 .4803 L .59809 .47769 L F
.475 .281 .536 r
.44326 .58595 m .44096 .5889 L .44323 .58828 L F
.357 .13 .427 r
.20709 .55525 m .20676 .55661 L .20519 .55595 L F
.579 .37 .561 r
.28112 .60864 m .27893 .60701 L .28143 .6063 L F
.28112 .60864 m .27864 .60969 L .27893 .60701 L F
.024 .102 .608 r
.26017 .55842 m .26149 .56116 L .26157 .55871 L F
.533 .574 .842 r
.44701 .63527 m .44521 .63721 L .44355 .6343 L F
.043 0 .145 r
.44701 .63527 m .44456 .63776 L .44521 .63721 L F
.702 .299 .28 r
.46486 .59399 m .46674 .59521 L .46804 .59477 L F
.559 .572 .824 r
.46853 .59853 m .46562 .59558 L .46804 .59477 L F
.204 .199 .63 r
.46902 .5964 m .46804 .59477 L .47042 .59499 L F
.46902 .5964 m .46853 .59853 L .46804 .59477 L F
.344 0 0 r
.46674 .59521 m .47042 .59499 L .46804 .59477 L F
.388 .132 .399 r
.2732 .61784 m .27167 .61622 L .27377 .61561 L F
.2732 .61784 m .27112 .61846 L .27167 .61622 L F
.671 .131 0 r
.47385 .58132 m .47307 .58145 L .47208 .58071 L F
.564 .357 .558 r
.47208 .58071 m .47307 .58145 L .47016 .58143 L F
0 0 0 r
.47067 .58214 m .47016 .58143 L .47307 .58145 L F
0 .138 .684 r
.47307 .58145 m .47354 .58051 L .47136 .58175 L F
.47307 .58145 m .47136 .58175 L .47067 .58214 L F
.671 .131 0 r
.47644 .58221 m .47307 .58145 L .47385 .58132 L F
.675 .138 0 r
.47644 .58221 m .47466 .58298 L .47307 .58145 L F
.783 .863 .421 r
.47763 .5787 m .47673 .58035 L .47644 .58221 L F
.781 .978 .703 r
.47673 .58035 m .47466 .58298 L .47644 .58221 L F
.147 0 .187 r
.47672 .58539 m .47958 .58208 L .47644 .58221 L F
.829 .712 .735 r
.49637 .53203 m .49964 .53065 L .49799 .53082 L F
.49637 .53203 m .49781 .53484 L .49964 .53065 L F
.328 .394 .778 r
.39409 .6193 m .39682 .62113 L .39571 .61763 L F
.658 .481 .633 r
.58572 .47756 m .58832 .47756 L .58821 .47481 L F
.647 .472 .633 r
.58832 .47756 m .5908 .47442 L .58821 .47481 L F
.431 .56 .884 r
.20646 .70185 m .20638 .69931 L .20435 .70013 L F
.20646 .70185 m .20822 .70208 L .20638 .69931 L F
.626 .937 .706 r
.79256 .43356 m .79417 .43168 L .79458 .43218 L F
.79256 .43356 m .79129 .43417 L .79417 .43168 L F
.78 .487 .49 r
.57871 .47649 m .58215 .47471 L .57851 .47409 L F
.57871 .47649 m .5823 .47708 L .58215 .47471 L F
.798 .501 .486 r
.58215 .47471 m .5823 .47708 L .58572 .47756 L F
0 0 0 r
.16053 .57297 m .1577 .57569 L .15942 .5744 L F
.654 .81 .958 r
.73146 .4166 m .73514 .41711 L .73391 .41396 L F
.668 .696 .867 r
.73391 .41396 m .73514 .41711 L .73785 .41602 L F
.542 .61 .871 r
.43456 .60711 m .43615 .61004 L .43789 .60867 L F
.862 .493 .348 r
.49668 .54396 m .4952 .54557 L .49389 .54322 L F
.859 .487 .345 r
.49717 .54585 m .4952 .54557 L .49668 .54396 L F
.74 .643 .752 r
.44413 .56123 m .44762 .56245 L .44635 .56146 L F
.677 .783 .312 r
.44899 .56268 m .44957 .56138 L .44762 .56245 L F
.299 .203 .576 r
.44762 .56245 m .44808 .56514 L .44899 .56268 L F
.883 .865 .817 r
.52264 .53714 m .52387 .53864 L .52656 .53532 L F
0 0 0 r
.52815 .53359 m .52656 .53532 L .52837 .53333 L F
.52815 .53359 m .52837 .53333 L .52933 .53226 L F
.581 .338 .513 r
.52815 .53359 m .5246 .53459 L .52656 .53532 L F
.52815 .53359 m .52778 .53593 L .5246 .53459 L F
.909 .657 .546 r
.52778 .53593 m .52815 .53359 L .52261 .53322 L F
.52778 .53593 m .52324 .53355 L .5246 .53459 L F
.883 .865 .817 r
.52264 .53714 m .52592 .53562 L .5246 .53459 L F
.52592 .53562 m .52656 .53532 L .5246 .53459 L F
.278 0 0 r
.52778 .53593 m .52403 .53548 L .52407 .53526 L F
.909 .657 .546 r
.52778 .53593 m .52403 .53548 L .52815 .53359 L F
.52815 .53359 m .52403 .53548 L .52778 .53593 L F
.52815 .53359 m .52778 .53593 L .52803 .53374 L F
.791 .376 .261 r
.52849 .53204 m .52815 .53359 L .52933 .53226 L F
.52582 .53135 m .52815 .53359 L .52849 .53204 L F
.775 .556 .603 r
.52358 .53035 m .52815 .53359 L .52582 .53135 L F
.52358 .53035 m .52261 .53322 L .52815 .53359 L F
.893 .963 .831 r
.52711 .53214 m .52822 .53212 L .52815 .53359 L F
.802 .725 .194 r
.52822 .53212 m .52794 .53454 L .52815 .53359 L F
.52794 .53454 m .52778 .53593 L .52815 .53359 L F
.909 .657 .546 r
.52815 .53359 m .52803 .53374 L .52822 .53212 L F
.52324 .53355 m .52261 .53322 L .5246 .53459 L F
.177 0 0 r
.23977 .55623 m .23821 .5577 L .23591 .55821 L F
0 0 0 r
.23994 .55665 m .23977 .55623 L .24171 .55436 L F
.23994 .55665 m .23821 .5577 L .23977 .55623 L F
.872 .818 .793 r
.76325 .42237 m .7647 .42358 L .76251 .42673 L F
.941 .847 .722 r
.76424 .42018 m .7647 .42358 L .76325 .42237 L F
.642 .239 .264 r
.68948 .41001 m .68954 .40878 L .68616 .40872 L F
.512 .131 .255 r
.69212 .41006 m .68954 .40878 L .68948 .41001 L F
.455 .222 .471 r
.48042 .59815 m .48025 .60039 L .4831 .59794 L F
.198 .715 .879 r
.48042 .59815 m .4831 .59794 L .48025 .60039 L F
.604 .698 .91 r
.46297 .59546 m .46486 .59399 L .46508 .59346 L F
.46453 .59425 m .46674 .59521 L .46486 .59399 L F
.46503 .59532 m .46674 .59521 L .46453 .59425 L F
.46297 .59546 m .46544 .59622 L .46674 .59521 L F
0 .082 .602 r
.46586 .5923 m .46544 .5962 L .46508 .59346 L F
.46544 .5962 m .46544 .59622 L .46543 .59618 L F
.46544 .5962 m .46543 .59618 L .46508 .59346 L F
.604 .698 .91 r
.46297 .59546 m .46503 .59532 L .46453 .59425 L F
.344 0 0 r
.46674 .59521 m .46902 .5964 L .47042 .59499 L F
.752 .428 .437 r
.57302 .50164 m .57127 .50383 L .56954 .50147 L F
.678 .332 .381 r
.57532 .50385 m .57302 .50164 L .57483 .50193 L F
.57532 .50385 m .57127 .50383 L .57302 .50164 L F
.975 .873 .671 r
.44608 .65129 m .44638 .65268 L .44528 .65467 L F
.489 .771 .994 r
.18184 .64885 m .1819 .64957 L .18257 .64809 L F
.617 .907 .984 r
.18257 .64809 m .1819 .64957 L .1841 .64873 L F
.18257 .64809 m .1819 .64957 L .1841 .64873 L F
.566 .935 .912 r
.65375 .41724 m .65553 .41332 L .65743 .41423 L F
.438 0 0 r
.65743 .41423 m .6566 .4137 L .6565 .41358 L F
.566 .935 .912 r
.65574 .41342 m .65583 .41321 L .65743 .41423 L F
.438 0 0 r
.65477 .41237 m .65578 .41317 L .65339 .41142 L F
.6565 .41358 m .65581 .41319 L .65477 .41237 L F
.65581 .41319 m .65578 .41317 L .65477 .41237 L F
.777 .924 .934 r
.65761 .41237 m .65593 .41298 L .65743 .41423 L F
.726 .628 .748 r
.65542 .41293 m .65563 .41326 L .65566 .41309 L F
.438 0 0 r
.65578 .41317 m .65564 .41308 L .65554 .41301 L F
.65578 .41317 m .65554 .41301 L .65339 .41142 L F
.726 .628 .748 r
.65564 .41326 m .65587 .41312 L .65639 .40904 L F
.65563 .41326 m .65578 .41317 L .65564 .41326 L F
.65578 .41317 m .65587 .41312 L .65564 .41326 L F
.777 .924 .934 r
.65593 .41298 m .65564 .41308 L .65578 .41317 L F
.65587 .41312 m .65578 .41317 L .65583 .41321 L F
.65593 .41298 m .65578 .41317 L .65587 .41312 L F
.438 0 0 r
.6566 .4137 m .65578 .41317 L .6565 .41358 L F
.777 .924 .934 r
.65593 .41298 m .65583 .41321 L .65743 .41423 L F
0 0 .381 r
.6575 .40941 m .65592 .41328 L .6578 .40951 L F
.65746 .4094 m .65701 .41053 L .6575 .40941 L F
.65701 .41053 m .65592 .41328 L .6575 .40941 L F
.65592 .41328 m .65581 .41355 L .65594 .41329 L F
.65592 .41328 m .65594 .41329 L .6578 .40951 L F
.65639 .40904 m .65587 .41312 L .65746 .4094 L F
.65587 .41312 m .65581 .41355 L .65746 .4094 L F
.566 .935 .912 r
.6557 .4134 m .65578 .41317 L .65583 .41321 L F
.6557 .4134 m .65583 .41321 L .65574 .41342 L F
.65553 .41332 m .65563 .41326 L .6557 .4134 L F
.65563 .41326 m .65578 .41317 L .6557 .4134 L F
.921 .706 .595 r
.65628 .41432 m .65743 .41423 L .65761 .41237 L F
.65531 .41574 m .65652 .41488 L .65628 .41432 L F
.65652 .41488 m .65743 .41423 L .65628 .41432 L F
0 0 .499 r
.65581 .41355 m .65605 .41334 L .6578 .40951 L F
.65605 .41334 m .65644 .413 L .65726 .41091 L F
.65605 .41334 m .65726 .41091 L .6578 .40951 L F
.65581 .41355 m .65656 .41435 L .65644 .413 L F
0 0 .504 r
.65604 .41375 m .65656 .41435 L .65608 .41384 L F
.65604 .41375 m .65608 .41384 L .65581 .41355 L F
0 0 0 r
.65666 .41377 m .65656 .41435 L .65531 .41574 L F
.124 .177 .646 r
.65531 .41574 m .65656 .41435 L .65595 .41353 L F
0 0 .504 r
.65563 .41326 m .65604 .41375 L .65581 .41355 L F
.726 .628 .748 r
.6549 .4121 m .65542 .41293 L .65639 .40904 L F
0 .131 .677 r
.65339 .41142 m .65564 .41308 L .6549 .4121 L F
.598 .543 .764 r
.65564 .41308 m .65563 .41322 L .6549 .4121 L F
0 0 .504 r
.6549 .4121 m .6554 .41278 L .65558 .41315 L F
.6549 .4121 m .65558 .41315 L .65563 .41326 L F
.566 .935 .912 r
.65375 .41724 m .65531 .41574 L .65564 .41308 L F
.598 .543 .764 r
.65563 .41322 m .65531 .41574 L .6549 .4121 L F
.726 .628 .748 r
.65563 .41326 m .65581 .41355 L .65587 .41312 L F
.566 .935 .912 r
.65553 .41332 m .65564 .41308 L .65578 .41317 L F
0 0 .504 r
.6554 .41278 m .65656 .41435 L .65563 .41326 L F
.124 .177 .646 r
.65523 .415 m .65595 .41353 L .6549 .4121 L F
.65531 .41574 m .65595 .41353 L .65523 .415 L F
0 0 0 r
.65761 .41237 m .65679 .41392 L .65666 .41377 L F
.65679 .41392 m .65656 .41435 L .65666 .41377 L F
.726 .628 .748 r
.65542 .41293 m .65566 .41309 L .65639 .40904 L F
.566 .935 .912 r
.65375 .41724 m .6531 .41698 L .65531 .41574 L F
.629 .675 .875 r
.47251 .56495 m .47383 .56781 L .47637 .56736 L F
.561 .439 .671 r
.47383 .56781 m .47648 .56965 L .47637 .56736 L F
.47383 .56781 m .47456 .57121 L .47648 .56965 L F
.219 0 .212 r
.27112 .61846 m .26842 .62129 L .26926 .61935 L F
.26 0 0 r
.69836 .40942 m .69566 .40909 L .69455 .4099 L F
.255 0 0 r
.52326 .51758 m .52216 .51646 L .52075 .5179 L F
.52326 .51758 m .52458 .51605 L .52216 .51646 L F
.908 .929 .816 r
.1957 .73979 m .19453 .74079 L .19426 .73998 L F
.1957 .73979 m .19453 .74079 L .19426 .73998 L F
.226 .007 .358 r
.52168 .53367 m .52358 .53035 L .5219 .53177 L F
.404 .645 .955 r
.49418 .53186 m .49637 .53203 L .49519 .53023 L F
.49519 .53023 m .49637 .53203 L .49418 .53186 L F
.516 .343 .584 r
.45258 .64298 m .45268 .64564 L .45029 .64626 L F
.45258 .64298 m .45268 .64564 L .45029 .64626 L F
.396 .844 .92 r
.20325 .54033 m .20727 .53977 L .20497 .54088 L F
.05 0 0 r
.54071 .51646 m .53982 .51845 L .53757 .51891 L F
.045 0 0 r
.53757 .51891 m .53982 .51845 L .53676 .52097 L F
.239 0 .025 r
.53757 .51891 m .53453 .52162 L .53459 .5192 L F
.53757 .51891 m .53676 .52097 L .53453 .52162 L F
.175 0 0 r
.25387 .53989 m .25613 .53964 L .25761 .53876 L F
.509 0 0 r
.25761 .53876 m .25613 .53964 L .26063 .53953 L F
.617 .466 .654 r
.80244 .40875 m .80281 .4116 L .80014 .41221 L F
.517 .827 1 r
.18305 .62432 m .18274 .62582 L .18086 .62456 L F
.18305 .62432 m .18487 .62525 L .18274 .62582 L F
.467 .802 .999 r
.1893 .62459 m .18911 .62601 L .18721 .62499 L F
.1893 .62459 m .19075 .62564 L .18911 .62601 L F
.51 .53 .814 r
.19214 .62832 m .18911 .62601 L .19075 .62564 L F
.616 .396 .56 r
.46305 .60401 m .46308 .60659 L .46054 .60648 L F
.081 0 .332 r
.46456 .60335 m .46308 .60659 L .46305 .60401 L F
.151 0 0 r
.21371 .55263 m .21164 .55401 L .20926 .55452 L F
.184 0 0 r
.21371 .55263 m .21391 .55365 L .21164 .55401 L F
.21371 .55263 m .21687 .55212 L .21391 .55365 L F
0 0 .008 r
.65339 .41142 m .65462 .41016 L .65494 .40835 L F
0 .131 .677 r
.65339 .41142 m .6549 .4121 L .65462 .41016 L F
0 0 .286 r
.52549 .54313 m .52598 .54486 L .52594 .5467 L F
.979 .877 .508 r
.52598 .54486 m .52619 .54729 L .52594 .5467 L F
.496 .797 .999 r
.19671 .62943 m .19931 .62998 L .19622 .63023 L F
.19715 .6287 m .19764 .62899 L .19671 .62943 L F
.19764 .62899 m .19931 .62998 L .19671 .62943 L F
.468 .643 .933 r
.19305 .62645 m .19656 .6295 L .19214 .62832 L F
.496 .797 .999 r
.19715 .6287 m .19671 .62943 L .19695 .62984 L F
.19671 .62943 m .19622 .63023 L .19695 .62984 L F
.468 .643 .933 r
.19656 .6295 m .19695 .62984 L .19629 .62963 L F
.19656 .6295 m .19629 .62963 L .19214 .62832 L F
.654 .666 .85 r
.19622 .63023 m .19214 .62832 L .19695 .62984 L F
.707 .739 .877 r
.72756 .40014 m .72639 .4055 L .72504 .40084 L F
.72756 .40014 m .72888 .40415 L .72639 .4055 L F
.75 .33 0 r
.51363 .59846 m .51289 .59762 L .51126 .59817 L F
.51363 .59846 m .5146 .60037 L .51289 .59762 L F
.146 .178 .637 r
.42109 .64898 m .42194 .65142 L .42011 .64868 L F
.471 .261 .512 r
.28554 .59491 m .28535 .59744 L .28307 .59801 L F
.495 .334 .592 r
.28535 .60004 m .28307 .59801 L .28535 .59744 L F
.28535 .60004 m .28317 .60059 L .28307 .59801 L F
0 0 0 r
.16457 .57124 m .16483 .57045 L .16686 .57024 L F
.16457 .57124 m .16257 .57232 L .16483 .57045 L F
0 .444 .808 r
.76577 .37819 m .76454 .37787 L .76322 .37703 L F
.712 .628 .762 r
.44703 .59212 m .44877 .59321 L .45076 .59174 L F
.723 .925 .959 r
.48273 .61041 m .47994 .6122 L .4811 .61331 L F
.897 .928 .545 r
.47994 .6122 m .47945 .61415 L .4811 .61331 L F
.64 .081 0 r
.50028 .54711 m .49937 .54751 L .49717 .54585 L F
.687 .142 0 r
.50028 .54711 m .50264 .54924 L .49937 .54751 L F
.099 .126 .601 r
.22177 .68369 m .22026 .68276 L .22228 .68007 L F
0 0 0 r
.22296 .68343 m .22272 .68357 L .22177 .68369 L F
.099 .126 .601 r
.22177 .68369 m .22095 .68537 L .22055 .68384 L F
.843 .964 .636 r
.22005 .68508 m .22095 .68537 L .22177 .68369 L F
0 0 0 r
.22272 .68357 m .22005 .68508 L .22177 .68369 L F
.099 .126 .601 r
.22177 .68369 m .22055 .68384 L .22026 .68276 L F
.932 .887 .477 r
.57326 .55236 m .57386 .54796 L .57382 .55001 L F
.678 .781 .928 r
.73289 .40439 m .72888 .40415 L .73237 .40219 L F
.484 .606 .898 r
.73349 .40173 m .73289 .40439 L .73237 .40219 L F
.73349 .40173 m .73524 .40439 L .73289 .40439 L F
.109 .433 .873 r
.15666 .60484 m .15659 .60631 L .15482 .60493 L F
.15666 .60484 m .15709 .6051 L .15659 .60631 L F
.859 .678 .656 r
.59792 .4803 m .596 .48317 L .59937 .48366 L F
.824 .697 .723 r
.596 .48317 m .59926 .48625 L .59937 .48366 L F
.474 .538 .843 r
.53694 .56477 m .53647 .56802 L .53522 .56444 L F
.53694 .56477 m .53824 .5677 L .53647 .56802 L F
.952 .701 .521 r
.26349 .56414 m .26138 .56367 L .26149 .56116 L F
.167 0 0 r
.26349 .56414 m .26488 .56447 L .26138 .56367 L F
.648 .729 .908 r
.44209 .59815 m .44323 .6002 L .44527 .59947 L F
.237 0 .121 r
.46751 .59992 m .46528 .60083 L .46853 .59853 L F
.133 0 .05 r
.46953 .59901 m .46853 .59853 L .46902 .5964 L F
.46953 .59901 m .46751 .59992 L .46853 .59853 L F
.381 .143 .424 r
.28807 .59187 m .28763 .59433 L .28554 .59491 L F
.492 .278 .517 r
.28756 .59687 m .28554 .59491 L .28763 .59433 L F
.28756 .59687 m .28535 .59744 L .28554 .59491 L F
0 0 .431 r
.53824 .5677 m .5397 .57005 L .54014 .57097 L F
.952 .625 .367 r
.53895 .57242 m .54014 .57097 L .5397 .57005 L F
.53895 .57242 m .54072 .57326 L .54014 .57097 L F
.671 .455 .583 r
.51202 .61131 m .51159 .61308 L .51085 .61063 L F
.662 .12 0 r
.51085 .61063 m .50985 .6114 L .51202 .61131 L F
0 0 .51 r
.43905 .57695 m .43868 .57293 L .43718 .57426 L F
.43905 .57695 m .43967 .57597 L .43868 .57293 L F
.625 .578 .781 r
.43807 .57936 m .43585 .58044 L .43554 .57962 L F
.43692 .57844 m .43554 .57962 L .43434 .57639 L F
.43807 .57936 m .43554 .57962 L .43692 .57844 L F
.43807 .57936 m .43434 .57639 L .43662 .57836 L F
.532 .287 .489 r
.43662 .57836 m .43967 .57597 L .43951 .57623 L F
.43787 .57763 m .43951 .57623 L .43905 .57695 L F
.43662 .57836 m .43951 .57623 L .43787 .57763 L F
.43662 .57836 m .43905 .57695 L .43807 .57936 L F
.835 .403 0 r
.7675 .43557 m .76713 .43614 L .76612 .43474 L F
.7675 .43557 m .76839 .43744 L .76713 .43614 L F
.218 0 .259 r
.46751 .59992 m .46456 .60335 L .46528 .60083 L F
.421 .091 .298 r
.55434 .50449 m .55321 .50713 L .55071 .50773 L F
.494 .162 .333 r
.55702 .50597 m .55434 .50449 L .55657 .50471 L F
.55702 .50597 m .55321 .50713 L .55434 .50449 L F
.47 .719 .978 r
.50424 .5523 m .50264 .54924 L .50419 .54988 L F
.585 .378 .567 r
.45742 .6245 m .45473 .6274 L .45496 .62512 L F
.692 .761 .905 r
.74889 .42339 m .75266 .42392 L .75128 .42245 L F
.578 .501 .732 r
.28978 .5891 m .29047 .59152 L .28807 .59187 L F
.434 .189 .442 r
.28983 .59365 m .28807 .59187 L .29047 .59152 L F
.28983 .59365 m .28763 .59433 L .28807 .59187 L F
.179 0 0 r
.15256 .55924 m .15133 .56051 L .1547 .55865 L F
.913 .973 .788 r
.67164 .40634 m .66995 .40596 L .6684 .40446 L F
.67164 .40634 m .66988 .40776 L .66995 .40596 L F
.451 .197 .437 r
.44323 .58828 m .44548 .58588 L .44326 .58595 L F
.147 0 .092 r
.7987 .41669 m .79505 .41979 L .79543 .42028 L F
.957 .761 .597 r
.81691 .4449 m .81691 .44769 L .81576 .4439 L F
.058 0 0 r
.4587 .56006 m .46108 .5601 L .46291 .55999 L F
.297 0 0 r
.46108 .5601 m .46516 .55928 L .46291 .55999 L F
.64 .825 .971 r
.19607 .65111 m .19805 .65241 L .19996 .6514 L F
.682 .691 .852 r
.1865 .64808 m .18751 .6509 L .19001 .64878 L F
.597 .568 .791 r
.80407 .40539 m .80244 .40875 L .80146 .40586 L F
.80407 .40539 m .80515 .40835 L .80244 .40875 L F
.628 .504 .692 r
.80515 .40835 m .80281 .4116 L .80244 .40875 L F
.324 .413 .799 r
.15919 .61864 m .15957 .61879 L .15932 .61897 L F
.632 .736 .923 r
.16096 .61895 m .15932 .61897 L .15957 .61879 L F
.483 .462 .758 r
.48451 .60647 m .48165 .60376 L .48398 .6033 L F
0 0 .515 r
.48165 .60376 m .48316 .60548 L .48398 .6033 L F
.009 .584 .732 r
.43224 .60732 m .43143 .60727 L .42867 .60723 L F
.503 .909 .876 r
.43368 .60619 m .43143 .60727 L .43224 .60732 L F
.434 .757 .995 r
.43224 .60732 m .43456 .60711 L .43368 .60619 L F
.308 .149 .496 r
.56526 .5738 m .56798 .57288 L .56805 .5701 L F
0 0 .248 r
.56526 .5738 m .5663 .57475 L .56798 .57288 L F
.56526 .5738 m .56542 .57583 L .5663 .57475 L F
.345 .078 .359 r
.26588 .6242 m .26384 .62491 L .26647 .62202 L F
.462 .236 .484 r
.26842 .62129 m .26588 .6242 L .26647 .62202 L F
.824 .793 .823 r
.76251 .42673 m .75871 .42806 L .76129 .42544 L F
.872 .818 .793 r
.76325 .42237 m .76251 .42673 L .76129 .42544 L F
.808 .401 .279 r
.44491 .60879 m .44696 .61176 L .4484 .61 L F
.87 .494 .33 r
.4484 .61 m .44696 .61176 L .44874 .61176 L F
.42 0 .046 r
.52711 .51552 m .52968 .51549 L .53086 .51377 L F
0 0 0 r
.5328 .51237 m .53363 .5117 L .53086 .51377 L F
.251 0 .13 r
.52968 .51549 m .5328 .51237 L .53086 .51377 L F
.633 .783 .953 r
.72535 .41688 m .72902 .41753 L .72775 .4158 L F
.648 .713 .895 r
.72775 .4158 m .72902 .41753 L .73146 .4166 L F
.447 .154 .373 r
.2557 .6339 m .25281 .63647 L .25366 .63453 L F
.542 .712 .951 r
.16498 .62009 m .16315 .62064 L .16096 .61895 L F
.598 .042 0 r
.22738 .65838 m .22779 .65931 L .22891 .65737 L F
.445 .245 .513 r
.29161 .57958 m .29128 .58246 L .28919 .58293 L F
.502 .43 .707 r
.29128 .58246 m .2897 .58532 L .28919 .58293 L F
.889 .475 .21 r
.41829 .65776 m .41675 .65747 L .41564 .65505 L F
.805 .376 .228 r
.42057 .66009 m .41829 .65776 L .42064 .65753 L F
.42057 .66009 m .41675 .65747 L .41829 .65776 L F
.397 .269 .587 r
.24926 .60092 m .25127 .60295 L .25158 .60042 L F
.24926 .60092 m .24911 .60382 L .25127 .60295 L F
0 0 .391 r
.58725 .54656 m .58726 .54851 L .58632 .55003 L F
0 0 .148 r
.58632 .55003 m .58726 .54851 L .58587 .55232 L F
0 0 0 r
.4514 .61468 m .44966 .61582 L .45229 .61306 L F
.38 .011 .207 r
.45457 .61357 m .45229 .61306 L .45489 .61275 L F
.45457 .61357 m .4514 .61468 L .45229 .61306 L F
.484 .576 .872 r
.79051 .41254 m .79208 .40989 L .78954 .41085 L F
.79051 .41254 m .79377 .41313 L .79208 .40989 L F
0 0 .267 r
.42062 .58997 m .41953 .58894 L .42024 .58804 L F
.105 .12 .59 r
.42096 .5853 m .42046 .58776 L .42111 .58571 L F
.42048 .58401 m .42046 .58649 L .42096 .5853 L F
.42046 .58649 m .42046 .58776 L .42096 .5853 L F
.227 0 0 r
.41615 .5898 m .4198 .58811 L .41842 .58533 L F
.7 .637 .783 r
.42091 .58735 m .42083 .5876 L .42046 .58776 L F
.42091 .58735 m .42091 .58736 L .42091 .58735 L F
.42091 .58736 m .42083 .5876 L .42091 .58735 L F
.227 0 0 r
.4198 .58811 m .42092 .58759 L .42031 .58687 L F
.42092 .58759 m .4211 .58751 L .42091 .58736 L F
.504 .415 .688 r
.42091 .58735 m .42102 .58704 L .42048 .58401 L F
.791 .86 .901 r
.42048 .58401 m .42111 .58571 L .42348 .58395 L F
.063 .101 .589 r
.42048 .58401 m .4211 .58751 L .42183 .58652 L F
.105 .12 .59 r
.42048 .58401 m .42183 .58652 L .42091 .58735 L F
.42048 .58401 m .42091 .58735 L .42046 .58776 L F
.504 .415 .688 r
.42091 .58736 m .42091 .58735 L .42048 .58401 L F
.227 0 0 r
.42092 .58759 m .42091 .58736 L .42031 .58687 L F
.4198 .58811 m .42031 .58687 L .41842 .58533 L F
.504 .415 .688 r
.41842 .58533 m .42091 .58736 L .42048 .58401 L F
.42091 .58736 m .4211 .58751 L .42102 .58704 L F
0 0 0 r
.4211 .58751 m .42105 .58757 L .42183 .58652 L F
.7 .637 .783 r
.42183 .58652 m .42113 .58746 L .42083 .5876 L F
.42157 .58727 m .42062 .58997 L .42047 .58791 L F
0 0 0 r
.42105 .58757 m .42093 .58765 L .42103 .58759 L F
.4211 .58751 m .42097 .58762 L .42105 .58757 L F
.42097 .58762 m .42093 .58765 L .42105 .58757 L F
.42105 .58757 m .42035 .58836 L .42183 .58652 L F
.7 .637 .783 r
.42183 .58652 m .42157 .58727 L .42113 .58746 L F
.42183 .58652 m .42083 .5876 L .42091 .58735 L F
0 0 .267 r
.42047 .58791 m .42024 .58804 L .42046 .58776 L F
.227 0 0 r
.41615 .5898 m .41875 .5894 L .42097 .58762 L F
.42092 .58759 m .42097 .58762 L .4211 .58751 L F
.7 .637 .783 r
.42089 .58757 m .42047 .58791 L .42046 .58776 L F
.42097 .58762 m .42047 .58791 L .42089 .58757 L F
.227 0 0 r
.41615 .5898 m .42097 .58762 L .42092 .58759 L F
.7 .637 .783 r
.42157 .58727 m .42097 .58762 L .42089 .58757 L F
0 0 0 r
.42103 .58759 m .41875 .5894 L .42035 .58836 L F
.42093 .58765 m .41875 .5894 L .42103 .58759 L F
0 0 .267 r
.42062 .58997 m .42024 .58804 L .42047 .58791 L F
.42062 .58997 m .41908 .59161 L .41953 .58894 L F
.393 .097 .339 r
.17813 .56185 m .17743 .56383 L .17569 .56411 L F
.435 .156 .39 r
.18025 .56118 m .17743 .56383 L .17813 .56185 L F
.263 .409 .821 r
.16567 .63644 m .16711 .63949 L .16865 .63972 L F
0 0 0 r
.50295 .52916 m .50201 .5304 L .50269 .52895 L F
.837 .593 .57 r
.68609 .42046 m .68286 .42237 L .68228 .42031 L F
.68609 .42046 m .6862 .42318 L .68286 .42237 L F
.637 .522 .707 r
.4368 .64287 m .4382 .6454 L .43924 .64273 L F
0 0 0 r
.43149 .57836 m .43434 .57639 L .43217 .57708 L F
.414 .126 .364 r
.24732 .60654 m .24458 .6097 L .24634 .60892 L F
.281 0 .209 r
.24732 .60654 m .24838 .60823 L .24899 .60564 L F
.24732 .60654 m .24634 .60892 L .24838 .60823 L F
0 0 0 r
.69361 .43093 m .69715 .42896 L .69617 .43079 L F
.245 0 0 r
.69715 .42896 m .69851 .42997 L .69617 .43079 L F
.551 .875 .993 r
.69558 .43091 m .69788 .42909 L .69487 .43105 L F
.69617 .43079 m .69652 .43044 L .69558 .43091 L F
.69652 .43044 m .69788 .42909 L .69558 .43091 L F
.245 0 0 r
.69715 .42896 m .69961 .4286 L .69921 .4291 L F
.69809 .42966 m .69921 .4291 L .69851 .42997 L F
.69715 .42896 m .69921 .4291 L .69809 .42966 L F
.477 .441 .739 r
.29114 .55446 m .29018 .55873 L .28888 .5551 L F
.29114 .55446 m .29215 .5583 L .29018 .55873 L F
.367 0 0 r
.77525 .4413 m .77472 .4419 L .7713 .44106 L F
.117 .253 .729 r
.77426 .43794 m .77643 .43978 L .77525 .4413 L F
.568 .827 .463 r
.77643 .43978 m .77472 .4419 L .77525 .4413 L F
.243 0 0 r
.54428 .59421 m .54693 .59389 L .54827 .59278 L F
0 0 0 r
.54922 .593 m .54827 .59278 L .54693 .59389 L F
.54922 .593 m .55062 .59206 L .54827 .59278 L F
.169 .108 .541 r
.25979 .57682 m .26115 .5765 L .26091 .57275 L F
.197 .223 .661 r
.25979 .57682 m .26165 .57876 L .26115 .5765 L F
.375 .252 .582 r
.25989 .57936 m .26165 .57876 L .25979 .57682 L F
.845 .922 .883 r
.67337 .44234 m .67589 .44225 L .67731 .4408 L F
.423 .838 .967 r
.67433 .44183 m .67589 .44225 L .67337 .44234 L F
0 0 .235 r
.75898 .38439 m .76029 .38452 L .76115 .38269 L F
.75898 .38439 m .75834 .3868 L .76029 .38452 L F
.147 0 .092 r
.7987 .41669 m .79543 .42028 L .79715 .41884 L F
.964 .708 .499 r
.7987 .41669 m .79718 .41609 L .80019 .41722 L F
.7987 .41669 m .79715 .41884 L .79718 .41609 L F
.323 .265 .636 r
.80056 .41888 m .7987 .41669 L .80019 .41722 L F
.51 .301 .532 r
.79894 .43568 m .79895 .43842 L .79631 .43894 L F
.518 .332 .568 r
.80131 .43485 m .79895 .43842 L .79894 .43568 L F
.719 .667 .797 r
.21304 .69436 m .21056 .69682 L .2092 .69364 L F
.78 .634 .7 r
.64248 .41367 m .64616 .41423 L .64669 .4117 L F
.997 .81 .534 r
.50081 .52809 m .50109 .52489 L .49901 .52576 L F
.748 .512 .573 r
.5823 .47708 m .58569 .47963 L .58572 .47756 L F
.662 .356 .444 r
.58569 .47963 m .58828 .47973 L .58572 .47756 L F
.637 .366 .492 r
.58572 .47756 m .58828 .47973 L .58832 .47756 L F
.127 .644 .89 r
.26394 .54178 m .26602 .54182 L .26798 .54249 L F
.277 .698 .969 r
.26824 .54147 m .26798 .54249 L .26602 .54182 L F
.26824 .54147 m .27 .54246 L .26798 .54249 L F
.66 .45 .589 r
.80358 .41455 m .80382 .41702 L .80019 .41722 L F
.59 .509 .732 r
.80546 .41085 m .80358 .41455 L .80281 .4116 L F
.80546 .41085 m .80601 .41405 L .80358 .41455 L F
.571 .394 .603 r
.80601 .41405 m .80382 .41702 L .80358 .41455 L F
.413 .341 .667 r
.41424 .62494 m .41659 .62736 L .4161 .62447 L F
.552 .356 .569 r
.41416 .62752 m .41659 .62736 L .41424 .62494 L F
.767 .954 .934 r
.71255 .42143 m .71475 .42159 L .71676 .42007 L F
0 0 0 r
.20272 .72349 m .19978 .72433 L .20093 .72386 L F
.045 .163 .664 r
.76811 .3862 m .76616 .38416 L .76719 .38242 L F
.87 .882 .449 r
.76131 .40575 m .7604 .40691 L .76048 .40784 L F
.793 .942 .591 r
.76222 .40348 m .76131 .40575 L .76334 .40258 L F
.746 .874 .455 r
.76222 .40348 m .7604 .40691 L .76131 .40575 L F
.629 .434 .6 r
.45711 .57953 m .46028 .57943 L .46038 .5769 L F
.403 .503 .846 r
.79626 .39958 m .79945 .40062 L .79763 .4027 L F
.425 .536 .866 r
.79945 .40062 m .80078 .40378 L .79763 .4027 L F
.394 .512 .859 r
.16034 .61675 m .15919 .61864 L .15754 .61604 L F
.16034 .61675 m .15957 .61879 L .15919 .61864 L F
.455 .227 .478 r
.2585 .58587 m .26028 .58763 L .26029 .58496 L F
.2585 .58587 m .25815 .58828 L .26028 .58763 L F
.848 .998 .815 r
.76472 .3997 m .76334 .40258 L .7658 .39989 L F
.791 .942 .591 r
.76472 .3997 m .76222 .40348 L .76334 .40258 L F
.01 0 0 r
.16568 .61915 m .16498 .62009 L .16743 .61829 L F
.496 .817 1 r
.78017 .38632 m .77992 .38755 L .77911 .38643 L F
.155 .466 .89 r
.78017 .38632 m .78233 .38875 L .77992 .38755 L F
.469 .651 .939 r
.24581 .55656 m .24631 .5543 L .2441 .55512 L F
.24581 .55656 m .2479 .55633 L .24631 .5543 L F
.583 .018 0 r
.2479 .55633 m .2441 .55512 L .24581 .55656 L F
0 0 0 r
.42615 .64177 m .42471 .64285 L .42694 .64031 L F
0 0 .326 r
.42563 .64484 m .42471 .64285 L .42615 .64177 L F
.42563 .64484 m .4251 .64581 L .42471 .64285 L F
.91 .962 .639 r
.65761 .41237 m .65743 .41423 L .6589 .41182 L F
.292 0 0 r
.66127 .41084 m .65761 .41237 L .6589 .41182 L F
.493 .343 .605 r
.4966 .60074 m .49894 .60021 L .49872 .59762 L F
.76 .685 .779 r
.49706 .60402 m .49894 .60021 L .4966 .60074 L F
.373 .141 .428 r
.26547 .62666 m .26384 .62491 L .26588 .6242 L F
.26547 .62666 m .26343 .62723 L .26384 .62491 L F
.217 .355 .789 r
.4415 .62768 m .43901 .62493 L .4415 .62485 L F
.434 0 0 r
.66737 .4396 m .67013 .44083 L .6667 .43978 L F
.952 .849 .424 r
.66737 .4396 m .6667 .43978 L .66715 .43758 L F
0 .342 .74 r
.18441 .73819 m .18544 .73895 L .18382 .73643 L F
.18441 .73819 m .18572 .73907 L .18544 .73895 L F
.938 .571 .191 r
.51034 .58248 m .51105 .58478 L .51229 .58575 L F
0 0 .399 r
.51317 .58687 m .51229 .58575 L .51105 .58478 L F
.839 .415 0 r
.51229 .58575 m .51366 .58894 L .51369 .58883 L F
0 0 .399 r
.51317 .58687 m .51366 .58894 L .51229 .58575 L F
.756 .431 .434 r
.68354 .4082 m .68607 .41091 L .68616 .40872 L F
.642 .239 .264 r
.68948 .41001 m .68616 .40872 L .68607 .41091 L F
.646 .571 .755 r
.76555 .39571 m .7658 .39989 L .76675 .39834 L F
.514 .467 .742 r
.76806 .39725 m .7658 .39989 L .76555 .39571 L F
.295 .468 .861 r
.7658 .39989 m .76712 .39815 L .76472 .3997 L F
.7658 .39989 m .76881 .40113 L .76712 .39815 L F
0 0 .076 r
.5838 .55831 m .58365 .5604 L .58235 .56194 L F
0 0 0 r
.58365 .5604 m .58216 .56436 L .58235 .56194 L F
.592 .658 .883 r
.17065 .64279 m .17402 .64413 L .17269 .64236 L F
.404 .504 .847 r
.17402 .64413 m .17486 .64186 L .17269 .64236 L F
.17402 .64413 m .17648 .6451 L .17486 .64186 L F
.508 .463 .742 r
.29307 .57565 m .29349 .57926 L .29161 .57958 L F
.499 .291 .528 r
.29359 .58178 m .29161 .57958 L .29349 .57926 L F
.29359 .58178 m .29128 .58246 L .29161 .57958 L F
.923 .729 .624 r
.52601 .52482 m .52726 .52834 L .52775 .52585 L F
.397 .046 .249 r
.222 .67508 m .22477 .67377 L .22198 .67489 L F
.222 .67508 m .22362 .67536 L .22477 .67377 L F
.605 .641 .86 r
.51584 .6048 m .51939 .60677 L .51847 .60591 L F
.987 .885 .634 r
.5193 .60374 m .51847 .60591 L .51939 .60677 L F
.071 0 .119 r
.4049 .59763 m .40697 .59674 L .40746 .59475 L F
.18 .017 .409 r
.40471 .60017 m .40697 .59674 L .4049 .59763 L F
.53 .731 .966 r
.53015 .52321 m .53086 .52148 L .52861 .52169 L F
.53015 .52321 m .53086 .52148 L .52861 .52169 L F
.972 .852 .451 r
.5761 .54009 m .57564 .53921 L .5767 .53774 L F
.847 .877 .44 r
.57786 .53363 m .5767 .53774 L .57598 .53699 L F
.988 .822 .437 r
.5767 .53774 m .57564 .53921 L .57598 .53699 L F
.818 .634 .653 r
.58335 .51353 m .57969 .51557 L .58016 .51299 L F
.58335 .51353 m .58216 .51633 L .57969 .51557 L F
.458 .254 .514 r
.65728 .40541 m .65494 .40835 L .65733 .40743 L F
.05 0 .102 r
.65494 .40835 m .65639 .40904 L .65733 .40743 L F
.65494 .40835 m .65462 .41016 L .65639 .40904 L F
.401 0 .046 r
.51126 .59817 m .50759 .59981 L .50861 .59855 L F
.517 .412 .674 r
.42075 .59818 m .42353 .60003 L .42359 .59752 L F
.42075 .59818 m .42121 .6008 L .42353 .60003 L F
.347 .011 .245 r
.397 .60675 m .39907 .60629 L .40011 .60378 L F
.434 .093 .286 r
.40011 .60378 m .40168 .60569 L .40221 .6031 L F
.40011 .60378 m .39907 .60629 L .40168 .60569 L F
.502 .43 .707 r
.29128 .58246 m .29179 .58473 L .2897 .58532 L F
.394 .275 .598 r
.29187 .5872 m .2897 .58532 L .29179 .58473 L F
.29187 .5872 m .28978 .5891 L .2897 .58532 L F
.809 .689 .732 r
.45381 .59801 m .45607 .60121 L .45193 .60023 L F
.45444 .59727 m .45193 .60023 L .45194 .59776 L F
.113 0 .403 r
.45194 .59776 m .45193 .60023 L .45349 .59883 L F
.45114 .59843 m .45349 .59883 L .45103 .59852 L F
.45194 .59776 m .45258 .5982 L .45114 .59843 L F
.45258 .5982 m .45349 .59883 L .45114 .59843 L F
.809 .689 .732 r
.45444 .59727 m .45469 .59788 L .45381 .59801 L F
.45469 .59788 m .45607 .60121 L .45381 .59801 L F
.698 .541 .672 r
.45582 .60266 m .45185 .60313 L .45193 .60023 L F
.852 .86 .847 r
.45582 .60266 m .45215 .60467 L .45185 .60313 L F
.441 .324 .624 r
.45215 .60467 m .45272 .60197 L .45185 .60313 L F
.45272 .60197 m .45298 .60076 L .4526 .60156 L F
.45272 .60197 m .4526 .60156 L .45185 .60313 L F
.698 .541 .672 r
.45582 .60266 m .45227 .60044 L .45607 .60121 L F
.45227 .60044 m .45193 .60023 L .45223 .6003 L F
.45227 .60044 m .45223 .6003 L .45607 .60121 L F
.699 .639 .785 r
.4581 .60029 m .45607 .60121 L .45444 .59727 L F
.672 .37 .454 r
.45582 .60266 m .4581 .60029 L .45607 .60121 L F
.45582 .60266 m .4581 .60029 L .45607 .60121 L F
.05 0 .428 r
.75269 .37299 m .75087 .37246 L .74944 .37231 L F
.529 .518 .788 r
.7215 .40149 m .71948 .402 L .71863 .3998 L F
.62 .63 .839 r
.7247 .40109 m .71948 .402 L .7215 .40149 L F
0 0 0 r
.52099 .61292 m .51941 .61585 L .52034 .61459 L F
0 0 .023 r
.51866 .61815 m .52034 .61459 L .51941 .61585 L F
0 .095 .636 r
.77619 .38745 m .77771 .38907 L .77911 .38643 L F
0 .268 .699 r
.53948 .61205 m .53576 .60972 L .53624 .61041 L F
.054 0 0 r
.17382 .54904 m .17598 .54847 L .17794 .54714 L F
0 0 0 r
.17794 .54714 m .17808 .54779 L .18013 .54667 L F
.17794 .54714 m .17598 .54847 L .17808 .54779 L F
.573 .266 .41 r
.43576 .56363 m .44005 .56395 L .43793 .5622 L F
.611 .248 .33 r
.43793 .5622 m .44005 .56395 L .44035 .56257 L F
.701 .213 .085 r
.55294 .58574 m .55521 .5878 L .55012 .58652 L F
.368 .086 .348 r
.79861 .43975 m .79631 .43894 L .79895 .43842 L F
.79861 .43975 m .79613 .44072 L .79631 .43894 L F
.045 0 .144 r
.44896 .57243 m .44632 .57597 L .44653 .57336 L F
.89 .564 .423 r
.52034 .61459 m .5219 .61521 L .52099 .61292 L F
.742 .433 .46 r
.79918 .42339 m .79548 .42563 L .79328 .42331 L F
.79918 .42339 m .79924 .42617 L .79709 .42586 L F
.277 .154 .526 r
.79728 .42657 m .79834 .42689 L .79842 .42456 L F
.79669 .42761 m .79746 .42727 L .79728 .42657 L F
.79746 .42727 m .79834 .42689 L .79728 .42657 L F
.742 .433 .46 r
.79682 .42482 m .79709 .42586 L .79548 .42563 L F
.79918 .42339 m .79709 .42586 L .79682 .42482 L F
.611 .586 .801 r
.80056 .41888 m .80188 .423 L .79918 .42339 L F
.11 0 .38 r
.80108 .42421 m .79918 .42339 L .80188 .423 L F
.80108 .42421 m .79924 .42617 L .79918 .42339 L F
.441 .22 .481 r
.45323 .58883 m .45296 .59127 L .45076 .59174 L F
.71 .553 .674 r
.45436 .59472 m .45076 .59174 L .45296 .59127 L F
.45436 .59472 m .45293 .59608 L .45076 .59174 L F
.879 .783 .751 r
.59467 .51434 m .59658 .51126 L .59481 .50976 L F
.849 .638 .617 r
.65743 .41423 m .65726 .41683 L .6603 .41748 L F
.739 .841 .927 r
.20459 .71365 m .20888 .71239 L .20532 .71114 L F
.452 .793 .998 r
.20532 .71114 m .20888 .71239 L .20921 .71142 L F
.515 .397 .656 r
.47514 .5888 m .47735 .58823 L .47672 .58539 L F
.534 .338 .562 r
.475 .59158 m .47735 .58823 L .47514 .5888 L F
.475 .59158 m .47735 .58823 L .47514 .5888 L F
.691 .651 .805 r
.214 .66996 m .21817 .67119 L .21685 .66952 L F
.691 .622 .775 r
.21685 .66952 m .21817 .67119 L .22011 .66982 L F
.904 .786 .72 r
.74803 .40828 m .74556 .40808 L .74663 .40687 L F
.74803 .40828 m .74633 .41139 L .74556 .40808 L F
.106 0 .278 r
.40746 .59475 m .40934 .59403 L .4094 .59153 L F
.13 0 .195 r
.40697 .59674 m .40934 .59403 L .40746 .59475 L F
.647 .472 .633 r
.58832 .47756 m .59187 .47734 L .5908 .47442 L F
.717 .508 .605 r
.5908 .47442 m .59437 .47719 L .59444 .47457 L F
.5908 .47442 m .59187 .47734 L .59437 .47719 L F
.571 .334 .518 r
.45711 .57953 m .4601 .58169 L .46028 .57943 L F
.45711 .57953 m .45716 .58229 L .4601 .58169 L F
.824 .697 .723 r
.596 .48317 m .5957 .48565 L .59926 .48625 L F
.829 .676 .693 r
.5957 .48565 m .59707 .4892 L .59926 .48625 L F
.565 .755 .967 r
.42739 .57834 m .426 .58088 L .4253 .57949 L F
0 0 0 r
.42643 .58009 m .426 .58088 L .42739 .57834 L F
.669 .625 .796 r
.44323 .58828 m .44703 .59212 L .44551 .58781 L F
.29 .426 .827 r
.44551 .58781 m .44703 .59212 L .44818 .59012 L F
.663 .571 .741 r
.44689 .59324 m .44818 .59012 L .44703 .59212 L F
.016 0 0 r
.18445 .54529 m .18464 .54612 L .18522 .54548 L F
0 0 0 r
.18397 .54517 m .18445 .54529 L .18671 .54416 L F
.436 .851 .686 r
.18671 .54416 m .18445 .54529 L .18659 .54398 L F
.016 0 0 r
.18445 .54529 m .18522 .54548 L .18659 .54398 L F
0 0 0 r
.18225 .54581 m .18445 .54529 L .18397 .54517 L F
.436 .851 .686 r
.18671 .54416 m .18659 .54398 L .18883 .54358 L F
.751 .655 .756 r
.47385 .57288 m .47811 .574 L .47648 .56965 L F
.294 .385 .786 r
.47648 .56965 m .47811 .574 L .47939 .5714 L F
.54 .253 .428 r
.48183 .57519 m .47763 .5787 L .47794 .57614 L F
.541 .296 .493 r
.47811 .574 m .4805 .57562 L .47939 .5714 L F
.47811 .574 m .47794 .57614 L .4805 .57562 L F
.383 .103 .36 r
.55974 .48909 m .56178 .48851 L .5624 .48654 L F
.197 0 .128 r
.56178 .48851 m .56481 .48582 L .5624 .48654 L F
.569 .388 .597 r
.425 .66372 m .426 .66602 L .4281 .66347 L F
.934 .732 .606 r
.5968 .49174 m .59846 .49268 L .59707 .4892 L F
.93 .709 .582 r
.59644 .49449 m .59846 .49268 L .5968 .49174 L F
.59644 .49449 m .59831 .49517 L .59846 .49268 L F
.509 .72 .968 r
.17065 .64279 m .17158 .64101 L .16865 .63972 L F
.17065 .64279 m .17269 .64236 L .17158 .64101 L F
.432 .871 .813 r
.5604 .60674 m .55594 .6083 L .5566 .60879 L F
.751 .977 .919 r
.55514 .60927 m .5566 .60879 L .55594 .6083 L F
.559 .026 0 r
.24799 .53907 m .25001 .5398 L .25113 .53921 L F
.491 0 0 r
.25113 .53921 m .25001 .5398 L .25387 .53989 L F
.518 .494 .769 r
.49706 .60402 m .49988 .60602 L .5002 .604 L F
.538 .351 .575 r
.50293 .60073 m .50279 .60375 L .5002 .604 L F
.112 .266 .743 r
.49894 .60021 m .5002 .604 L .50144 .60294 L F
.362 .092 .363 r
.50286 .60452 m .5002 .604 L .50279 .60375 L F
.5002 .604 m .50286 .60452 L .50144 .60294 L F
.5002 .604 m .49988 .60602 L .50286 .60452 L F
.50286 .60452 m .49988 .60602 L .5002 .604 L F
.348 .16 .479 r
.25186 .59785 m .2534 .59962 L .25358 .59713 L F
.25186 .59785 m .25158 .60042 L .2534 .59962 L F
.782 .766 .838 r
.67275 .4316 m .66923 .43372 L .67181 .43395 L F
.67275 .4316 m .66895 .43185 L .66923 .43372 L F
.67275 .4316 m .67181 .43395 L .67146 .4312 L F
.064 .61 .84 r
.67146 .4312 m .67516 .4318 L .67275 .4316 L F
.503 .173 .34 r
.49347 .58801 m .49599 .58796 L .49625 .58585 L F
.493 .165 .338 r
.49625 .58585 m .49599 .58796 L .49837 .58741 L F
.487 .168 .351 r
.49625 .58585 m .49837 .58741 L .49899 .58524 L F
.785 .589 .636 r
.64248 .41367 m .6444 .41696 L .64616 .41423 L F
.974 .74 .52 r
.29121 .54973 m .28937 .55123 L .28981 .54825 L F
.606 .766 .956 r
.28981 .54825 m .29121 .54973 L .29345 .54899 L F
.28981 .54825 m .29345 .54899 L .29181 .54781 L F
.82 .972 .666 r
.29181 .54781 m .29121 .54973 L .29345 .54899 L F
.29181 .54781 m .28937 .55123 L .29121 .54973 L F
.67 .369 .454 r
.56954 .50147 m .56524 .50343 L .56593 .50207 L F
.469 .58 .883 r
.80465 .42483 m .80283 .42709 L .80235 .42613 L F
.80465 .42483 m .80608 .42742 L .80283 .42709 L F
.333 0 .058 r
.44444 .57705 m .44343 .57911 L .44011 .57974 L F
.017 0 0 r
.44522 .57802 m .44444 .57705 L .44632 .57597 L F
.206 0 .019 r
.44749 .57719 m .44522 .57802 L .44632 .57597 L F
.151 0 0 r
.44749 .57719 m .44669 .57742 L .44522 .57802 L F
.017 0 0 r
.44522 .57802 m .44365 .57865 L .44444 .57705 L F
.151 0 0 r
.44669 .57742 m .44323 .57843 L .44522 .57802 L F
.017 0 0 r
.44522 .57802 m .44343 .57911 L .44365 .57865 L F
.407 .32 .645 r
.4514 .61468 m .45199 .6179 L .44966 .61582 L F
.456 .321 .608 r
.44966 .61582 m .45199 .6179 L .4499 .61844 L F
.343 .681 .979 r
.2066 .63213 m .20619 .63341 L .20452 .63203 L F
.2066 .63213 m .20829 .63344 L .20619 .63341 L F
0 .153 .67 r
.51896 .59676 m .517 .59512 L .51598 .59376 L F
.449 .207 .453 r
.26126 .62779 m .2608 .63019 L .25864 .63071 L F
.445 .205 .454 r
.26343 .62723 m .2608 .63019 L .26126 .62779 L F
0 0 0 r
.21051 .6326 m .21418 .63214 L .21229 .63266 L F
.992 .747 .449 r
.81691 .44769 m .8158 .44723 L .81576 .4439 L F
0 .376 .703 r
.81691 .44769 m .81613 .44731 L .8158 .44723 L F
.557 0 0 r
.81967 .44742 m .81613 .44731 L .81691 .44769 L F
.529 .708 .953 r
.28189 .54537 m .28136 .54764 L .27987 .54549 L F
.28189 .54537 m .28361 .54728 L .28136 .54764 L F
.004 .39 .847 r
.51207 .55541 m .51221 .55441 L .50967 .55315 L F
0 .1 .655 r
.51207 .55541 m .5141 .55767 L .51221 .55441 L F
.402 .119 .365 r
.29281 .57276 m .29214 .57369 L .29021 .57412 L F
.512 .44 .712 r
.29214 .57369 m .29307 .57565 L .29021 .57412 L F
.599 .438 .635 r
.77112 .42607 m .77342 .42765 L .77473 .42647 L F
.909 .555 .356 r
.54438 .58869 m .54527 .59147 L .54316 .59023 L F
.805 .87 .896 r
.54535 .58561 m .54438 .58869 L .54331 .58575 L F
.54535 .58561 m .5473 .58592 L .54438 .58869 L F
.647 .307 .383 r
.54394 .58663 m .54654 .58553 L .54535 .58561 L F
.25 .762 .778 r
.54535 .58561 m .54906 .58491 L .5473 .58592 L F
.647 .307 .383 r
.54654 .58553 m .54774 .58503 L .54535 .58561 L F
.805 .87 .896 r
.54535 .58561 m .54331 .58575 L .5432 .58546 L F
.909 .555 .356 r
.54438 .58869 m .54527 .59147 L .54316 .59023 L F
.239 0 .246 r
.46779 .57756 m .46865 .57819 L .46904 .57625 L F
.46779 .57756 m .46643 .57947 L .46865 .57819 L F
.483 .169 .357 r
.26091 .57275 m .2642 .57036 L .26117 .57076 L F
.984 .731 .464 r
.49791 .59484 m .49554 .59599 L .49518 .59497 L F
.326 .125 .446 r
.45527 .58775 m .45296 .59127 L .45323 .58883 L F
.255 0 .051 r
.42866 .64077 m .42694 .64031 L .4291 .63946 L F
.42866 .64077 m .42615 .64177 L .42694 .64031 L F
.722 .939 .62 r
.51457 .60331 m .51295 .60575 L .51584 .6048 L F
.787 .815 .875 r
.42057 .66009 m .42211 .66147 L .42454 .66046 L F
.07 0 0 r
.46396 .58503 m .46051 .5871 L .46262 .5841 L F
.554 .301 .487 r
.43423 .64598 m .43689 .64606 L .4382 .6454 L F
.43423 .64598 m .43397 .64834 L .43689 .64606 L F
0 0 0 r
.65728 .40541 m .65893 .4037 L .65959 .40198 L F
0 0 .261 r
.65733 .40743 m .65893 .4037 L .65728 .40541 L F
.806 .667 .71 r
.58244 .50755 m .58025 .5104 L .57888 .50701 L F
0 0 .272 r
.2111 .70964 m .21021 .70942 L .21223 .70768 L F
.2111 .70964 m .21223 .70768 L .21224 .70781 L F
.568 .184 .274 r
.21358 .70873 m .2111 .70964 L .21243 .70751 L F
.589 .027 0 r
.21358 .70873 m .20951 .70793 L .2111 .70964 L F
.21231 .70848 m .21175 .70919 L .20951 .70793 L F
.21358 .70873 m .21237 .70904 L .21231 .70848 L F
.21237 .70904 m .21175 .70919 L .21231 .70848 L F
0 0 .272 r
.21224 .70781 m .21223 .70768 L .21243 .70751 L F
.2111 .70964 m .20974 .71247 L .21021 .70942 L F
.849 .932 .881 r
.18541 .73939 m .18441 .73819 L .18361 .73877 L F
.18541 .73939 m .18572 .73907 L .18441 .73819 L F
0 0 0 r
.54176 .51714 m .54071 .51646 L .54311 .51599 L F
.54176 .51714 m .53982 .51845 L .54071 .51646 L F
.155 0 .237 r
.55445 .49294 m .55603 .49343 L .55674 .49222 L F
.55445 .49294 m .55398 .49478 L .55603 .49343 L F
.188 .244 .69 r
.40203 .62736 m .40277 .63137 L .40403 .62965 L F
.355 .48 .848 r
.40277 .63137 m .4058 .63305 L .40403 .62965 L F
.709 .982 .799 r
.67731 .4408 m .67846 .43899 L .67652 .44018 L F
.67731 .4408 m .68017 .43838 L .67846 .43899 L F
.862 .991 .831 r
.77859 .41915 m .77942 .41956 L .78121 .41735 L F
.98 .718 .456 r
.26157 .55871 m .26149 .56116 L .26007 .55765 L F
.276 0 .268 r
.4094 .59153 m .41195 .59067 L .41237 .5887 L F
.368 .075 .33 r
.4094 .59153 m .4113 .59342 L .41195 .59067 L F
.4094 .59153 m .40934 .59403 L .4113 .59342 L F
.879 .858 .817 r
.41356 .59982 m .41491 .60125 L .41775 .59757 L F
.223 .42 .845 r
.41572 .59934 m .41491 .60125 L .41356 .59982 L F
0 0 .383 r
.41613 .60158 m .41823 .59876 L .41572 .59934 L F
.41616 .60178 m .41627 .60163 L .41613 .60158 L F
.41627 .60163 m .41823 .59876 L .41613 .60158 L F
0 .428 .728 r
.41491 .60125 m .41609 .60157 L .41622 .60162 L F
.41581 .60152 m .41622 .60162 L .41708 .60191 L F
.41491 .60125 m .41622 .60162 L .41581 .60152 L F
0 0 .383 r
.41627 .60163 m .41647 .60165 L .41823 .59876 L F
.41647 .60165 m .41675 .6015 L .41823 .59876 L F
.508 .53 .814 r
.41823 .59876 m .41688 .60178 L .41675 .6015 L F
.41823 .59876 m .4197 .60061 L .41688 .60178 L F
0 0 .383 r
.41675 .6015 m .41821 .60069 L .41823 .59876 L F
.508 .53 .814 r
.41823 .59876 m .41675 .6015 L .41572 .59934 L F
.223 .42 .845 r
.41572 .59934 m .41675 .6015 L .41608 .60157 L F
.41675 .6015 m .41688 .60178 L .41645 .60166 L F
.41675 .6015 m .41645 .60166 L .41608 .60157 L F
.419 .866 .869 r
.41688 .60178 m .42121 .6008 L .41804 .6022 L F
.41688 .60178 m .4197 .60061 L .42121 .6008 L F
0 0 .383 r
.41647 .60165 m .4182 .60188 L .41821 .60069 L F
0 .428 .728 r
.41608 .60156 m .41688 .60178 L .41758 .60203 L F
0 0 .383 r
.41616 .60178 m .41723 .60184 L .41627 .60163 L F
.41723 .60184 m .4182 .60188 L .41627 .60163 L F
.888 .87 .815 r
.41601 .60154 m .41198 .60134 L .41613 .60178 L F
.223 .42 .845 r
.4156 .59964 m .41608 .60157 L .41491 .60125 L F
.888 .87 .815 r
.41504 .59961 m .41327 .60061 L .41601 .60154 L F
0 .428 .728 r
.41491 .60125 m .41608 .60156 L .41609 .60157 L F
.888 .87 .815 r
.41327 .60061 m .41198 .60134 L .41601 .60154 L F
0 .428 .728 r
.41708 .60191 m .4163 .60164 L .41804 .6022 L F
.41608 .60156 m .41758 .60203 L .41804 .6022 L F
.011 0 .007 r
.41616 .60178 m .41575 .60424 L .41807 .60201 L F
.41723 .60184 m .41807 .60201 L .4182 .60188 L F
0 .428 .728 r
.4163 .60164 m .41633 .60165 L .41804 .6022 L F
.011 0 .007 r
.41616 .60178 m .41807 .60201 L .41723 .60184 L F
0 .428 .728 r
.4163 .60164 m .41609 .60157 L .41633 .60165 L F
.223 .42 .845 r
.41572 .59934 m .41608 .60157 L .4156 .59964 L F
.888 .87 .815 r
.41611 .60167 m .41613 .60178 L .41616 .60178 L F
.41504 .59961 m .41613 .60178 L .41611 .60167 L F
.879 .858 .817 r
.41356 .59982 m .41775 .59757 L .41604 .59906 L F
.41356 .59982 m .41604 .59906 L .41541 .59941 L F
.496 .746 .984 r
.41356 .59982 m .41572 .59934 L .41428 .59813 L F
.888 .87 .815 r
.41428 .59813 m .41572 .59934 L .41356 .59982 L F
.41428 .59813 m .41202 .60128 L .41504 .59961 L F
.41202 .60128 m .41198 .60134 L .41504 .59961 L F
.879 .858 .817 r
.41541 .59941 m .41604 .59906 L .41572 .59934 L F
.046 .209 .71 r
.41659 .59419 m .41854 .59618 L .41775 .59757 L F
.206 0 0 r
.41823 .59876 m .41775 .59757 L .41854 .59618 L F
.41823 .59876 m .41572 .59934 L .41775 .59757 L F
.888 .894 .828 r
.46829 .56531 m .46855 .56782 L .46992 .56566 L F
.46829 .56531 m .46665 .56735 L .46855 .56782 L F
.653 .608 .791 r
.46665 .56735 m .47014 .57019 L .46855 .56782 L F
.652 .963 .787 r
.43585 .58044 m .43386 .58129 L .43308 .58249 L F
.823 .999 .798 r
.43662 .57836 m .43585 .58044 L .43807 .57936 L F
.43662 .57836 m .43386 .58129 L .43585 .58044 L F
.432 .871 .813 r
.5604 .60674 m .55945 .60684 L .55594 .6083 L F
.689 .853 .44 r
.7706 .39335 m .76869 .3966 L .76973 .3945 L F
.728 .91 .544 r
.76973 .3945 m .76869 .3966 L .76806 .39725 L F
.346 0 .172 r
.25092 .63728 m .24995 .63872 L .24782 .63918 L F
.153 0 .051 r
.25281 .63647 m .24995 .63872 L .25092 .63728 L F
.25 .762 .778 r
.54535 .58561 m .54774 .58503 L .54906 .58491 L F
.548 .213 .353 r
.54774 .58503 m .55141 .58199 L .54906 .58491 L F
.367 .053 .294 r
.47958 .58208 m .48172 .58185 L .48242 .57968 L F
.584 .354 .534 r
.48172 .58185 m .4842 .57895 L .48242 .57968 L F
.797 .431 .364 r
.45659 .61685 m .46154 .61798 L .46218 .61622 L F
.442 .067 .231 r
.46218 .61622 m .46154 .61798 L .4642 .61722 L F
.452 .046 .177 r
.46218 .61622 m .4642 .61722 L .46469 .61596 L F
.376 0 .07 r
.4546 .56973 m .45372 .57177 L .45134 .57197 L F
.027 0 0 r
.45752 .57026 m .45372 .57177 L .4546 .56973 L F
.492 .188 .379 r
.55898 .49146 m .56178 .48851 L .55974 .48909 L F
0 0 .135 r
.50748 .5225 m .509 .52185 L .50882 .52172 L F
.314 .786 .927 r
.50624 .52216 m .509 .52185 L .50748 .5225 L F
.982 .863 .488 r
.51031 .61388 m .51202 .61131 L .50985 .6114 L F
.51031 .61388 m .51159 .61308 L .51202 .61131 L F
.557 .553 .806 r
.26077 .58272 m .26165 .57876 L .25989 .57936 L F
.26077 .58272 m .26294 .58218 L .26165 .57876 L F
.434 .174 .418 r
.26029 .58496 m .26294 .58218 L .26077 .58272 L F
.698 .446 .54 r
.43982 .64698 m .44041 .64829 L .4382 .6454 L F
.489 .402 .684 r
.44041 .64829 m .43836 .64937 L .43824 .64635 L F
.43926 .64678 m .43824 .64635 L .4382 .6454 L F
.44041 .64829 m .43824 .64635 L .43926 .64678 L F
.415 .007 .154 r
.43689 .64606 m .43877 .64713 L .43974 .64699 L F
.43946 .64687 m .43974 .64699 L .43982 .64698 L F
.43689 .64606 m .43974 .64699 L .43946 .64687 L F
.698 .446 .54 r
.43982 .64698 m .4382 .6454 L .43689 .64606 L F
.269 0 0 r
.4642 .61722 m .46802 .61527 L .46469 .61596 L F
.4642 .61722 m .46648 .61693 L .46802 .61527 L F
.131 .134 .594 r
.46802 .61527 m .46915 .61165 L .46978 .61247 L F
.46802 .61527 m .46957 .61431 L .46915 .61165 L F
0 0 0 r
.46802 .61527 m .46648 .61693 L .46957 .61431 L F
.567 .096 .095 r
.43308 .58249 m .4319 .58396 L .42948 .58258 L F
.613 .841 .46 r
.43386 .58129 m .4319 .58396 L .43308 .58249 L F
.689 .853 .44 r
.7706 .39335 m .76973 .3945 L .76709 .39251 L F
.21 0 .074 r
.17569 .56411 m .17386 .5667 L .17186 .56741 L F
.228 0 .085 r
.1759 .566 m .17569 .56411 L .17743 .56383 L F
.1759 .566 m .17386 .5667 L .17569 .56411 L F
.726 .604 .721 r
.42565 .61919 m .42159 .61881 L .42572 .61815 L F
.42565 .61919 m .4227 .62179 L .42159 .61881 L F
0 0 0 r
.42366 .62148 m .4227 .62179 L .42565 .61919 L F
.362 .294 .644 r
.42572 .61815 m .42775 .61998 L .42565 .61919 L F
.336 0 0 r
.42775 .61998 m .42366 .62148 L .42565 .61919 L F
.941 .922 .763 r
.58233 .52234 m .57951 .52472 L .58118 .52142 L F
.58233 .52234 m .58052 .52572 L .57951 .52472 L F
.587 .499 .722 r
.50479 .60008 m .50279 .60375 L .50293 .60073 L F
.474 .16 .353 r
.78989 .42412 m .79218 .42508 L .79255 .42295 L F
.78989 .42412 m .79003 .42614 L .79218 .42508 L F
.327 .791 .674 r
.70208 .42782 m .70568 .42621 L .70447 .42688 L F
0 0 0 r
.70568 .42621 m .70856 .42395 L .70773 .42498 L F
.381 .808 .63 r
.70447 .42688 m .70568 .42621 L .70773 .42498 L F
.396 .172 .452 r
.41479 .58565 m .41237 .5887 L .41428 .58767 L F
.282 0 .27 r
.41237 .5887 m .41595 .58793 L .41428 .58767 L F
.41237 .5887 m .41195 .59067 L .41595 .58793 L F
.52 .653 .918 r
.78195 .40569 m .77904 .40611 L .7788 .40417 L F
0 0 0 r
.45194 .59776 m .45103 .59852 L .45062 .5988 L F
.841 .803 .814 r
.45436 .59472 m .45194 .59776 L .45293 .59608 L F
.574 .399 .607 r
.45444 .59727 m .45194 .59776 L .45436 .59472 L F
.574 .876 .994 r
.45719 .62181 m .45299 .62187 L .4556 .6212 L F
0 .115 .627 r
.45752 .62168 m .45719 .62181 L .4556 .6212 L F
.45752 .62168 m .45956 .6239 L .45719 .62181 L F
.479 .342 .616 r
.45956 .6239 m .45742 .6245 L .45719 .62181 L F
.173 .199 .647 r
.54072 .57326 m .54258 .5754 L .54108 .57679 L F
.121 .078 .531 r
.54258 .5754 m .541 .57992 L .54108 .57679 L F
.371 .611 .943 r
.27814 .54339 m .27812 .54553 L .27581 .54365 L F
.27814 .54339 m .27987 .54549 L .27812 .54553 L F
0 0 0 r
.2642 .57036 m .26569 .5694 L .26717 .56817 L F
.578 .607 .846 r
.26488 .56447 m .26717 .56817 L .269 .5671 L F
.313 .192 .55 r
.26569 .5694 m .269 .5671 L .26717 .56817 L F
.732 .467 .528 r
.46283 .60945 m .46054 .60648 L .46308 .60659 L F
.46283 .60945 m .46019 .60946 L .46054 .60648 L F
.797 .323 0 r
.51559 .55861 m .5158 .56016 L .5141 .55767 L F
.51559 .55861 m .5171 .56117 L .5158 .56016 L F
.083 .642 .777 r
.47715 .55896 m .47978 .55885 L .4809 .55894 L F
.224 .741 .855 r
.47978 .55885 m .48324 .55869 L .4809 .55894 L F
.733 .218 0 r
.78254 .45126 m .7792 .44923 L .78017 .45022 L F
.768 .633 .712 r
.47165 .57679 m .47647 .57752 L .47385 .57288 L F
.577 .558 .797 r
.47385 .57288 m .47647 .57752 L .47794 .57614 L F
0 0 .034 r
.58475 .55641 m .58365 .5604 L .5838 .55831 L F
.718 .452 .523 r
.16334 .60486 m .16099 .60731 L .15907 .6056 L F
.16334 .60486 m .15907 .6056 L .16159 .60571 L F
.411 .573 .903 r
.15942 .60129 m .16165 .60345 L .15907 .6056 L F
.886 .953 .843 r
.16345 .60533 m .16289 .60726 L .16154 .60729 L F
.16345 .60533 m .16154 .60729 L .16156 .60685 L F
.16404 .60486 m .16333 .60636 L .16345 .60533 L F
.16333 .60636 m .16289 .60726 L .16345 .60533 L F
.16437 .60474 m .16289 .60726 L .16404 .60486 L F
.16454 .60446 m .16099 .60731 L .16334 .60486 L F
.718 .452 .523 r
.16348 .60505 m .16159 .60571 L .16358 .60579 L F
0 0 .27 r
.16348 .60505 m .16382 .60548 L .16354 .60457 L F
0 0 0 r
.16363 .60587 m .16437 .60474 L .16365 .60583 L F
0 .285 .692 r
.16411 .60482 m .16454 .60446 L .16334 .60486 L F
.784 .939 .587 r
.16454 .60446 m .16409 .60522 L .16482 .60422 L F
.16409 .60522 m .16409 .60542 L .16516 .60377 L F
.886 .953 .843 r
.16454 .60446 m .16437 .60474 L .16404 .60486 L F
0 0 0 r
.16425 .60491 m .16437 .60474 L .16454 .60446 L F
.784 .939 .587 r
.16409 .60522 m .16289 .60726 L .16409 .60542 L F
0 0 0 r
.16365 .60583 m .16437 .60474 L .16425 .60491 L F
.1631 .60667 m .16363 .60587 L .16365 .60583 L F
.16263 .6074 m .16308 .60671 L .1631 .60667 L F
.16308 .60671 m .16437 .60474 L .1631 .60667 L F
.16263 .6074 m .16289 .60726 L .1633 .60657 L F
.16363 .60588 m .1633 .60657 L .16437 .60474 L F
.16263 .6074 m .1633 .60657 L .16363 .60588 L F
0 0 .27 r
.16334 .60486 m .16414 .60373 L .16411 .60482 L F
.16354 .60457 m .16388 .60535 L .16421 .60363 L F
.384 0 0 r
.16696 .60574 m .16388 .60692 L .16454 .60446 L F
.16388 .60692 m .16263 .6074 L .16365 .60583 L F
.16388 .60692 m .16365 .60583 L .16454 .60446 L F
0 0 .27 r
.16388 .60535 m .16408 .60581 L .16414 .6048 L F
.16414 .60373 m .16421 .60363 L .16411 .60482 L F
.16388 .60535 m .16414 .6048 L .16421 .60363 L F
0 .285 .692 r
.16541 .60476 m .16454 .60446 L .16411 .60482 L F
.784 .939 .587 r
.16454 .60446 m .16482 .60422 L .16516 .60377 L F
0 0 .27 r
.16411 .60482 m .16421 .60363 L .16541 .60476 L F
.16382 .60548 m .16408 .60581 L .16388 .60535 L F
.16382 .60548 m .16388 .60535 L .16354 .60457 L F
.718 .452 .523 r
.16348 .60505 m .16358 .60579 L .16382 .60548 L F
.16334 .60486 m .16159 .60571 L .16348 .60505 L F
.411 .573 .903 r
.16165 .60345 m .16375 .60549 L .16159 .60571 L F
.718 .452 .523 r
.16382 .60548 m .16358 .60579 L .16408 .60581 L F
.411 .573 .903 r
.16375 .60549 m .16408 .60581 L .16358 .60579 L F
.16375 .60549 m .16358 .60579 L .16159 .60571 L F
.16165 .60345 m .16159 .60571 L .15907 .6056 L F
.886 .953 .843 r
.16156 .60685 m .16154 .60729 L .16099 .60731 L F
0 0 .27 r
.16334 .60486 m .16348 .60505 L .16354 .60457 L F
0 0 0 r
.16263 .6074 m .16016 .60817 L .16289 .60726 L F
.73 .822 .922 r
.43143 .60727 m .42869 .60944 L .42867 .60723 L F
0 0 0 r
.73762 .39141 m .73855 .39026 L .736 .39302 L F
.471 .709 .973 r
.73762 .39141 m .736 .39302 L .73889 .39278 L F
.772 .367 .284 r
.2139 .68518 m .21492 .68765 L .2131 .68692 L F
.993 .741 .4 r
.2139 .68518 m .2131 .68692 L .21285 .68424 L F
.746 .933 .949 r
.67774 .43127 m .67516 .4318 L .67723 .43012 L F
.633 .934 .966 r
.67975 .42918 m .67774 .43127 L .67723 .43012 L F
.67975 .42918 m .68145 .42981 L .67774 .43127 L F
.804 .931 .917 r
.78225 .40808 m .78074 .41131 L .7833 .41058 L F
.78225 .40808 m .78015 .41169 L .78074 .41131 L F
.678 .875 .491 r
.4227 .62179 m .42132 .62349 L .42077 .62464 L F
.858 .435 .216 r
.41963 .62629 m .42284 .6277 L .42077 .62464 L F
.676 .491 .628 r
.42637 .62455 m .42933 .62478 L .42902 .62175 L F
0 0 .004 r
.42902 .62175 m .43123 .6186 L .42865 .61892 L F
.42902 .62175 m .43025 .62106 L .43123 .6186 L F
.519 .517 .793 r
.42933 .62478 m .43025 .62106 L .42902 .62175 L F
.365 .796 .967 r
.22469 .64804 m .22978 .64806 L .22674 .6477 L F
0 .355 .826 r
.22978 .64806 m .22956 .6472 L .22674 .6477 L F
0 0 .33 r
.52249 .52576 m .51984 .52738 L .52024 .52553 L F
.52249 .52576 m .52298 .52806 L .52311 .52683 L F
.52249 .52576 m .52311 .52683 L .51984 .52738 L F
.769 .859 .917 r
.72214 .41696 m .7232 .41837 L .72535 .41688 L F
.77 .533 .576 r
.44041 .64829 m .44026 .65088 L .43753 .65055 L F
.44041 .64829 m .43913 .64929 L .43836 .64937 L F
.077 .274 .761 r
.43943 .64759 m .44026 .65088 L .44041 .64829 L F
.43877 .64713 m .43941 .64873 L .43943 .64759 L F
.43941 .64873 m .44026 .65088 L .43943 .64759 L F
.207 .092 .494 r
.44132 .64929 m .441 .65199 L .43933 .65241 L F
.43934 .65171 m .43933 .65241 L .43863 .65259 L F
.077 .274 .761 r
.43959 .6492 m .44132 .64929 L .44026 .65088 L F
.388 0 0 r
.44026 .65088 m .4361 .65045 L .43753 .65055 L F
.565 .027 0 r
.43863 .65259 m .4361 .65045 L .44026 .65088 L F
.207 .092 .494 r
.44121 .64945 m .43863 .65259 L .44026 .65088 L F
.44132 .64929 m .44097 .64972 L .44121 .64945 L F
.44097 .64972 m .43863 .65259 L .44121 .64945 L F
.44132 .64929 m .43933 .65241 L .43934 .65171 L F
0 0 0 r
.441 .65199 m .43842 .65268 L .43863 .65259 L F
.612 .405 .577 r
.43984 .65097 m .43842 .65268 L .441 .65199 L F
.565 .027 0 r
.43863 .65259 m .43842 .65268 L .4361 .65045 L F
.612 .405 .577 r
.43834 .64965 m .43841 .65255 L .43984 .65097 L F
.43841 .65255 m .43842 .65268 L .43984 .65097 L F
.077 .274 .761 r
.43877 .64713 m .4409 .64894 L .43959 .6492 L F
.4409 .64894 m .44132 .64929 L .43959 .6492 L F
.77 .533 .576 r
.43913 .64929 m .43753 .65055 L .4383 .64946 L F
.43913 .64929 m .4383 .64946 L .43836 .64937 L F
.434 .277 .567 r
.29235 .56257 m .29324 .56439 L .29122 .56489 L F
.466 .378 .673 r
.29324 .56439 m .29367 .56668 L .29122 .56489 L F
.415 .382 .714 r
.29122 .56489 m .29367 .56668 L .29185 .56703 L F
.881 .749 .712 r
.59692 .50431 m .59785 .50188 L .59587 .50071 L F
.394 .512 .859 r
.16034 .61675 m .16096 .61895 L .15957 .61879 L F
.445 .169 .399 r
.25864 .63071 m .25788 .63346 L .2557 .6339 L F
.455 .187 .418 r
.2608 .63019 m .25788 .63346 L .25864 .63071 L F
.169 .055 .47 r
.43403 .57051 m .43533 .56985 L .43528 .56733 L F
.467 .58 .884 r
.74255 .41584 m .74533 .42019 L .74676 .41787 L F
.395 .485 .834 r
.74533 .42019 m .74757 .42017 L .74676 .41787 L F
.673 .236 .204 r
.42865 .61892 m .42775 .61998 L .42572 .61815 L F
.96 .807 .647 r
.49761 .60924 m .49698 .60648 L .49776 .60678 L F
.518 .494 .769 r
.49706 .60402 m .49776 .60678 L .49988 .60602 L F
.408 .208 .495 r
.49988 .60602 m .49761 .60924 L .49776 .60678 L F
.969 .693 .275 r
.49776 .60678 m .49699 .60625 L .49706 .60402 L F
.49699 .60625 m .49692 .6062 L .49696 .60555 L F
.49699 .60625 m .49696 .60555 L .49706 .60402 L F
.96 .807 .647 r
.49761 .60924 m .49604 .60882 L .49692 .6062 L F
.001 0 .145 r
.49988 .60602 m .49927 .60859 L .49761 .60924 L F
.802 .722 .776 r
.49988 .60602 m .49692 .6062 L .4997 .60431 L F
.605 .369 .533 r
.49706 .60756 m .49927 .60859 L .4997 .60431 L F
.4969 .60776 m .49708 .60782 L .49706 .60756 L F
.49708 .60782 m .49927 .60859 L .49706 .60756 L F
.49604 .60882 m .49684 .60877 L .4969 .60776 L F
.49684 .60877 m .49927 .60859 L .4969 .60776 L F
.96 .807 .647 r
.49698 .60648 m .49692 .6062 L .49699 .60625 L F
.49698 .60648 m .49699 .60625 L .49776 .60678 L F
.586 .395 .589 r
.43925 .59843 m .44209 .59815 L .44227 .59434 L F
.487 .313 .57 r
.44227 .59434 m .44209 .59815 L .44394 .59644 L F
.628 .336 .454 r
.44227 .59434 m .44394 .59644 L .44503 .59483 L F
.78 .295 0 r
.50506 .53559 m .50651 .53664 L .50629 .53583 L F
.788 .687 .752 r
.50712 .53201 m .50629 .53583 L .50566 .53075 L F
.483 .261 .501 r
.4836 .57267 m .48183 .57519 L .48115 .57341 L F
.72 .634 .761 r
.47637 .56736 m .47994 .5673 L .47892 .56647 L F
.477 .143 .32 r
.47648 .56965 m .47994 .5673 L .47637 .56736 L F
.47648 .56965 m .47891 .56967 L .47994 .5673 L F
0 .28 .753 r
.47994 .5673 m .47975 .56656 L .47892 .56647 L F
.055 0 .107 r
.47994 .5673 m .48074 .56881 L .47975 .56656 L F
.47994 .5673 m .47891 .56967 L .48074 .56881 L F
.605 .465 .664 r
.2437 .55239 m .24171 .55436 L .24168 .55269 L F
.776 .772 .849 r
.51369 .53726 m .51399 .53978 L .51411 .53757 L F
.935 .862 .432 r
.51366 .53486 m .51369 .53726 L .51411 .53757 L F
.804 .548 .551 r
.4227 .62179 m .41904 .61852 L .42159 .61881 L F
0 0 0 r
.42366 .62148 m .42132 .62349 L .4227 .62179 L F
.699 .639 .785 r
.4581 .60029 m .45444 .59727 L .45668 .59677 L F
.672 .37 .454 r
.45582 .60266 m .45807 .60312 L .4581 .60029 L F
.45582 .60266 m .45807 .60312 L .4581 .60029 L F
.434 .236 .51 r
.46109 .59737 m .4581 .60029 L .45668 .59677 L F
.46109 .59737 m .46064 .59986 L .4581 .60029 L F
.883 .67 .148 r
.45751 .60129 m .45807 .60312 L .4581 .60029 L F
.523 .251 .444 r
.4581 .60029 m .4606 .60263 L .46064 .59986 L F
.4581 .60029 m .45807 .60312 L .4606 .60263 L F
.883 .67 .148 r
.45751 .60129 m .4581 .60029 L .46064 .59986 L F
.434 .236 .51 r
.4581 .60029 m .46064 .59986 L .46109 .59737 L F
.591 .355 .527 r
.41479 .58565 m .41842 .58533 L .41714 .58445 L F
.41479 .58565 m .41428 .58767 L .41842 .58533 L F
0 .398 .803 r
.51584 .6048 m .51743 .60502 L .51457 .60331 L F
.51584 .6048 m .51847 .60591 L .51743 .60502 L F
.302 0 0 r
.41904 .61852 m .41739 .62027 L .41484 .6206 L F
0 0 .316 r
.41904 .61852 m .41995 .62006 L .41739 .62027 L F
0 0 0 r
.78806 .44914 m .78615 .45037 L .78925 .44797 L F
.414 .838 .679 r
.78519 .45077 m .78615 .45037 L .78806 .44914 L F
.856 .5 .379 r
.44035 .56257 m .44193 .56405 L .44413 .56123 L F
.661 .566 .737 r
.74265 .41064 m .74006 .41138 L .73939 .4078 L F
.77 .693 .778 r
.485 .59669 m .48755 .59403 L .48547 .59498 L F
.664 .647 .824 r
.67013 .44083 m .66909 .44464 L .66785 .44308 L F
.67013 .44083 m .67192 .44351 L .66909 .44464 L F
0 0 0 r
.18865 .74334 m .18723 .74504 L .18852 .74341 L F
.945 .92 .755 r
.57951 .52472 m .58052 .52572 L .57911 .52779 L F
0 0 0 r
.78917 .43796 m .78771 .43984 L .7886 .43923 L F
.381 .83 .717 r
.7886 .43923 m .78761 .43953 L .78926 .43878 L F
.397 .202 .495 r
.79086 .43821 m .79352 .43747 L .79293 .43541 L F
.79075 .43837 m .79352 .43747 L .79086 .43821 L F
.426 .218 .493 r
.79293 .43541 m .79352 .43747 L .79594 .43681 L F
0 0 0 r
.79207 .43747 m .79578 .43683 L .79352 .43747 L F
.79578 .43683 m .79594 .43681 L .79352 .43747 L F
.381 .83 .717 r
.79084 .43809 m .79123 .43789 L .79126 .43787 L F
.7886 .43923 m .79072 .43815 L .79084 .43809 L F
.397 .202 .495 r
.79102 .438 m .79293 .43541 L .79072 .43815 L F
.381 .83 .717 r
.79072 .43815 m .79123 .43789 L .79084 .43809 L F
0 0 0 r
.78917 .43796 m .7895 .43754 L .79129 .43417 L F
.889 .962 .631 r
.79129 .43417 m .7895 .43754 L .79035 .4353 L F
.397 .202 .495 r
.79072 .43815 m .79293 .43541 L .79035 .4353 L F
.381 .83 .717 r
.7886 .43923 m .79084 .43809 L .79075 .43837 L F
.397 .202 .495 r
.79075 .43837 m .79102 .438 L .79084 .43809 L F
.381 .83 .717 r
.79084 .43809 m .79126 .43787 L .79075 .43837 L F
.397 .202 .495 r
.79075 .43837 m .79084 .43809 L .79072 .43815 L F
.394 .238 .548 r
.7886 .43923 m .79075 .43837 L .79072 .43815 L F
0 0 0 r
.78917 .43796 m .7886 .43923 L .7895 .43754 L F
.394 .238 .548 r
.7886 .43923 m .79035 .4353 L .7895 .43754 L F
.7886 .43923 m .79072 .43815 L .79035 .4353 L F
.381 .83 .717 r
.7886 .43923 m .78926 .43878 L .79123 .43789 L F
0 0 0 r
.78771 .43984 m .78683 .44098 L .7886 .43923 L F
.032 0 0 r
.70773 .42498 m .70856 .42395 L .71074 .4227 L F
.168 0 .02 r
.65959 .40198 m .66141 .4026 L .66215 .40091 L F
.65959 .40198 m .65893 .4037 L .66141 .4026 L F
.645 .373 .493 r
.58832 .47756 m .59078 .47926 L .59187 .47734 L F
.58832 .47756 m .58828 .47973 L .59078 .47926 L F
.578 .584 .822 r
.45673 .5942 m .45436 .59472 L .45296 .59127 L F
.558 .387 .606 r
.45668 .59677 m .45436 .59472 L .45673 .5942 L F
.45668 .59677 m .45444 .59727 L .45436 .59472 L F
.465 .815 .998 r
.19217 .73522 m .19394 .73602 L .19 .73565 L F
.19217 .73522 m .19394 .73602 L .19 .73565 L F
.739 .841 .927 r
.20459 .71365 m .20532 .71114 L .20394 .71083 L F
.695 .479 .59 r
.47127 .5733 m .47385 .57288 L .47456 .57121 L F
.751 .655 .756 r
.47385 .57288 m .47648 .56965 L .47456 .57121 L F
.881 .923 .848 r
.19426 .73998 m .19453 .74079 L .19177 .74212 L F
.699 .35 .382 r
.19177 .74212 m .19453 .74079 L .19326 .74386 L F
.802 .529 0 r
.19441 .74158 m .19453 .74079 L .19426 .73998 L F
0 0 0 r
.19326 .74386 m .19453 .74079 L .19441 .74158 L F
.411 .148 .401 r
.79613 .44072 m .79334 .44345 L .79365 .44153 L F
0 0 0 r
.17186 .56741 m .16888 .56942 L .1701 .56831 L F
.712 .584 .711 r
.22011 .66982 m .22477 .67377 L .22422 .67232 L F
.22011 .66982 m .22198 .67489 L .22477 .67377 L F
.658 .752 .919 r
.22422 .67232 m .22477 .67377 L .22611 .67243 L F
0 0 0 r
.22477 .67377 m .22362 .67536 L .22611 .67243 L F
.22197 .55392 m .22599 .55245 L .22401 .5541 L F
.237 0 0 r
.22807 .55293 m .22842 .55353 L .22621 .55354 L F
.532 .003 0 r
.22842 .55353 m .2274 .55345 L .22621 .55354 L F
.409 0 0 r
.22599 .55245 m .22621 .55354 L .22454 .55366 L F
.532 .003 0 r
.2274 .55345 m .2241 .55321 L .22621 .55354 L F
.409 0 0 r
.22454 .55366 m .22621 .55354 L .22401 .5541 L F
.22599 .55245 m .22807 .55293 L .22621 .55354 L F
.401 .166 .438 r
.25406 .59483 m .25564 .59653 L .25596 .59408 L F
.25406 .59483 m .25358 .59713 L .25564 .59653 L F
.08 0 0 r
.41299 .6219 m .40886 .62355 L .41039 .62261 L F
.056 0 0 r
.47251 .56495 m .46829 .56531 L .46992 .56566 L F
.672 .904 .977 r
.56066 .57837 m .55767 .57983 L .55871 .57783 L F
.761 .996 .847 r
.55871 .57783 m .55767 .57983 L .55518 .58068 L F
.582 .846 .995 r
.65937 .44336 m .65527 .44303 L .65809 .44217 L F
.526 .786 .992 r
.66062 .44151 m .65937 .44336 L .65809 .44217 L F
.66062 .44151 m .66201 .44292 L .65937 .44336 L F
.451 .608 .914 r
.15371 .59686 m .15581 .59683 L .15432 .59771 L F
.068 0 .277 r
.15581 .59683 m .15382 .6001 L .15432 .59771 L F
.44 .255 .532 r
.48586 .57413 m .48518 .57666 L .48831 .573 L F
.592 .943 .797 r
.78683 .44098 m .78682 .44058 L .7886 .43923 L F
0 0 .023 r
.51866 .61815 m .51987 .61691 L .52034 .61459 L F
.983 .744 .495 r
.52137 .61805 m .51987 .61691 L .51866 .61815 L F
.678 .592 .753 r
.26018 .55274 m .264 .55558 L .26156 .55301 L F
.249 .53 .918 r
.264 .55558 m .26449 .55407 L .26156 .55301 L F
.456 .387 .691 r
.26276 .55772 m .26449 .55407 L .264 .55558 L F
.523 .192 .349 r
.16021 .55455 m .16251 .55448 L .16325 .55277 L F
.308 0 .244 r
.16325 .55277 m .16456 .5537 L .16547 .55231 L F
.16325 .55277 m .16251 .55448 L .16456 .5537 L F
.963 .632 .296 r
.73889 .39278 m .73855 .39026 L .73762 .39141 L F
0 0 0 r
.75834 .3868 m .75673 .38974 L .75845 .38797 L F
.76029 .38452 m .75834 .3868 L .75845 .38797 L F
.808 .579 .591 r
.59437 .47719 m .59436 .47974 L .59792 .4803 L F
.808 .602 .623 r
.59449 .48211 m .59792 .4803 L .59436 .47974 L F
.59449 .48211 m .596 .48317 L .59792 .4803 L F
.034 0 .404 r
.57675 .58757 m .57563 .5913 L .57564 .58868 L F
.581 .658 .89 r
.80326 .40327 m .80146 .40586 L .80078 .40378 L F
.80326 .40327 m .80407 .40539 L .80146 .40586 L F
.558 .836 .997 r
.1841 .64873 m .1844 .64705 L .18257 .64809 L F
.1841 .64873 m .1865 .64808 L .1844 .64705 L F
.572 .76 .967 r
.71794 .39858 m .71863 .3998 L .71531 .39924 L F
.603 .498 .707 r
.72165 .39899 m .71863 .3998 L .71794 .39858 L F
.72165 .39899 m .7215 .40149 L .71863 .3998 L F
0 0 .497 r
.51829 .56243 m .51821 .56233 L .5171 .56117 L F
0 .332 .684 r
.51829 .56243 m .52121 .56363 L .51821 .56233 L F
.278 .744 .946 r
.21229 .64956 m .21274 .64879 L .21059 .64931 L F
.21229 .64956 m .21506 .64943 L .21274 .64879 L F
.258 .385 .801 r
.19305 .62645 m .19214 .62832 L .19075 .62564 L F
.639 .402 .544 r
.48219 .59604 m .4831 .59794 L .485 .59669 L F
.753 .345 .276 r
.4197 .60061 m .42353 .60003 L .42121 .6008 L F
.026 0 .068 r
.54372 .50396 m .54573 .5033 L .5463 .50116 L F
.047 0 .059 r
.54372 .50396 m .545 .50483 L .54573 .5033 L F
.54372 .50396 m .54313 .50612 L .545 .50483 L F
0 0 .452 r
.52581 .57277 m .52361 .56918 L .5241 .57069 L F
.575 .724 .944 r
.51392 .52693 m .51503 .52854 L .51568 .52661 L F
.527 .672 .93 r
.51503 .52854 m .51794 .52847 L .51568 .52661 L F
.265 .278 .687 r
.29422 .56014 m .29235 .56257 L .29215 .5583 L F
.481 .458 .756 r
.29422 .56014 m .29324 .56439 L .29235 .56257 L F
.577 .526 .762 r
.50725 .60762 m .50976 .60694 L .50904 .60482 L F
.972 .677 .402 r
.46939 .55817 m .46872 .55835 L .46757 .55864 L F
.322 0 0 r
.78843 .42457 m .78634 .42564 L .7835 .42572 L F
.78843 .42457 m .78634 .42564 L .7835 .42572 L F
0 .058 .594 r
.78869 .42442 m .78843 .42457 L .78634 .42564 L F
.78869 .42442 m .79003 .42614 L .78843 .42457 L F
.78843 .42457 m .78869 .42442 L .78634 .42564 L F
.78843 .42457 m .79003 .42614 L .78869 .42442 L F
.576 .293 .449 r
.44548 .58588 m .44839 .5873 L .44927 .58546 L F
.436 .048 .203 r
.44927 .58546 m .45152 .58572 L .45169 .5853 L F
.44927 .58546 m .44839 .5873 L .45152 .58572 L F
.807 .756 .24 r
.40611 .62539 m .40657 .62461 L .40757 .62351 L F
.4061 .62574 m .40608 .62732 L .4065 .62501 L F
0 .147 .69 r
.4061 .62574 m .40803 .62979 L .40608 .62732 L F
.40611 .62539 m .40628 .62578 L .4061 .62574 L F
.40628 .62578 m .40803 .62979 L .4061 .62574 L F
.385 .399 .752 r
.40886 .62512 m .40803 .62979 L .40611 .62539 L F
.096 0 0 r
.40637 .6258 m .40732 .62582 L .40886 .62512 L F
.40602 .62589 m .40664 .62586 L .40637 .6258 L F
.40664 .62586 m .40732 .62582 L .40637 .6258 L F
.40517 .62613 m .40595 .62602 L .40602 .62589 L F
.40595 .62602 m .40732 .62582 L .40602 .62589 L F
.807 .756 .24 r
.40611 .62539 m .4061 .62574 L .40657 .62461 L F
.4061 .62574 m .4065 .62501 L .40657 .62461 L F
.069 0 0 r
.70917 .39943 m .70621 .40162 L .70876 .40085 L F
.367 0 .109 r
.71127 .40009 m .70917 .39943 L .70876 .40085 L F
.71127 .40009 m .71177 .39897 L .70917 .39943 L F
.628 .504 .692 r
.80515 .40835 m .80546 .41085 L .80281 .4116 L F
0 .378 .833 r
.48715 .55935 m .48946 .56052 L .48973 .56133 L F
0 .238 .694 r
.49184 .5624 m .48973 .56133 L .48946 .56052 L F
.162 0 .191 r
.55172 .49557 m .54913 .49844 L .5512 .49714 L F
.315 0 .256 r
.55172 .49557 m .55327 .49639 L .55398 .49478 L F
.55172 .49557 m .5512 .49714 L .55327 .49639 L F
.731 .57 .673 r
.29445 .57068 m .29185 .56703 L .29367 .56668 L F
.29445 .57068 m .29281 .57276 L .29185 .56703 L F
.924 .94 .793 r
.76674 .41487 m .7647 .41547 L .76658 .41095 L F
.76674 .41487 m .76559 .41668 L .7647 .41547 L F
.874 .701 .665 r
.77676 .41678 m .77612 .41951 L .77491 .41654 L F
.432 0 .073 r
.23677 .64583 m .23278 .64745 L .23327 .64597 L F
.006 0 0 r
.22883 .66818 m .22801 .66913 L .22859 .66805 L F
.578 .151 .194 r
.23075 .66895 m .22801 .66913 L .22944 .66747 L F
.006 0 0 r
.22859 .66805 m .22801 .66913 L .22612 .66972 L F
.679 .799 .939 r
.22766 .66786 m .22801 .66913 L .23075 .66895 L F
.22719 .6677 m .22745 .66816 L .22766 .66786 L F
.22745 .66816 m .22801 .66913 L .22766 .66786 L F
.582 .635 .869 r
.23095 .66621 m .22944 .66747 L .22645 .6641 L F
0 0 0 r
.22883 .66616 m .2281 .6681 L .22861 .66719 L F
.035 .5 .883 r
.2291 .66489 m .23095 .66621 L .22645 .6641 L F
0 0 0 r
.2291 .66489 m .2286 .6665 L .22883 .66616 L F
.2286 .6665 m .2281 .6681 L .22883 .66616 L F
.31 0 0 r
.22931 .66844 m .22908 .66844 L .22719 .6677 L F
.23075 .66895 m .22957 .66859 L .22931 .66844 L F
.22957 .66859 m .22908 .66844 L .22931 .66844 L F
.006 0 0 r
.22944 .66747 m .22883 .66818 L .22859 .66805 L F
.578 .151 .194 r
.23075 .66895 m .22944 .66747 L .23095 .66621 L F
.306 .141 .486 r
.21359 .68022 m .21429 .68061 L .21509 .67848 L F
0 0 .148 r
.52945 .58558 m .52974 .587 L .52898 .5845 L F
.52945 .58558 m .52986 .58847 L .52974 .587 L F
.142 .014 .433 r
.5785 .57892 m .5784 .58141 L .57647 .58274 L F
.154 .071 .502 r
.5784 .58141 m .57669 .58533 L .57647 .58274 L F
.322 .782 .945 r
.20367 .64918 m .20642 .6499 L .20863 .64938 L F
.755 .426 .428 r
.6797 .40782 m .68377 .40972 L .68354 .4082 L F
.689 .445 .548 r
.68377 .40972 m .68607 .41091 L .68354 .4082 L F
.075 0 0 r
.53487 .51164 m .53363 .5117 L .5328 .51237 L F
.53487 .51164 m .53579 .5105 L .53363 .5117 L F
.986 .897 .634 r
.7647 .41547 m .76559 .41668 L .76424 .42018 L F
0 0 0 r
.79028 .44785 m .78925 .44797 L .79079 .44637 L F
.79028 .44785 m .78806 .44914 L .78925 .44797 L F
.497 .753 .987 r
.17125 .604 m .17355 .60367 L .17152 .60216 L F
.17152 .60216 m .17355 .60367 L .17125 .604 L F
.801 .615 .65 r
.40803 .62979 m .41186 .63085 L .4116 .62793 L F
.643 .497 .67 r
.4116 .62793 m .41186 .63085 L .41416 .62752 L F
.484 .558 .856 r
.16211 .63374 m .16391 .63284 L .16161 .63278 L F
.273 .087 .437 r
.24899 .60564 m .25127 .60295 L .24911 .60382 L F
0 0 0 r
.21509 .67848 m .21508 .67978 L .21704 .67908 L F
.247 .361 .783 r
.21579 .67898 m .21704 .67908 L .21508 .67978 L F
.292 0 0 r
.2158 .67866 m .21704 .67908 L .21778 .67914 L F
.21509 .67848 m .21704 .67908 L .2158 .67866 L F
.21778 .67914 m .21704 .67908 L .21816 .67923 L F
.578 .569 .807 r
.22228 .68007 m .21816 .67923 L .2212 .68111 L F
.247 .361 .783 r
.21788 .67662 m .21915 .6798 L .21704 .67908 L F
.21915 .6798 m .21927 .68012 L .21704 .67908 L F
.21788 .67662 m .21704 .67908 L .21579 .67898 L F
.452 .713 .979 r
.25563 .5514 m .26018 .55274 L .25898 .55155 L F
.328 0 0 r
.26018 .55274 m .26091 .5544 L .25898 .55155 L F
.26018 .55274 m .26156 .55301 L .26091 .5544 L F
.64 .7 .889 r
.73237 .40219 m .72757 .40018 L .72759 .40015 L F
.73237 .40219 m .72759 .40015 L .73039 .40021 L F
.72759 .40015 m .72756 .40014 L .72761 .40014 L F
.72759 .40015 m .72761 .40014 L .73039 .40021 L F
.406 .722 .989 r
.72917 .3995 m .73039 .40021 L .72761 .40014 L F
.22 .128 .533 r
.72917 .3995 m .72771 .4001 L .7277 .40009 L F
.406 .722 .989 r
.72917 .3995 m .72761 .40014 L .72756 .40014 L F
.22 .128 .533 r
.72917 .3995 m .7278 .40032 L .72771 .4001 L F
.72804 .3999 m .7277 .40009 L .72768 .40003 L F
.72917 .3995 m .7277 .40009 L .72804 .3999 L F
.72842 .39902 m .72768 .40003 L .72688 .39802 L F
.72917 .3995 m .72768 .40003 L .72842 .39902 L F
.64 .7 .889 r
.73237 .40219 m .72888 .40415 L .72757 .40018 L F
.72759 .40015 m .72757 .40018 L .72756 .40014 L F
.981 .749 .513 r
.43123 .6186 m .42775 .61998 L .42865 .61892 L F
.629 .675 .875 r
.47251 .56495 m .47637 .56736 L .47462 .56393 L F
.736 .711 .828 r
.47462 .56393 m .47637 .56736 L .47892 .56647 L F
.508 .167 .324 r
.47227 .61904 m .47175 .62077 L .46903 .62095 L F
.556 .212 .341 r
.47227 .61904 m .47424 .62068 L .47175 .62077 L F
.409 .244 .544 r
.47427 .61809 m .47424 .62068 L .47227 .61904 L F
.122 0 .017 r
.14616 .56412 m .14791 .56359 L .14935 .56128 L F
.187 0 .049 r
.14791 .56359 m .15133 .56051 L .14935 .56128 L F
.424 0 0 r
.21567 .68782 m .21834 .68841 L .21633 .68809 L F
.391 .826 .954 r
.21817 .68892 m .21893 .6879 L .21895 .68928 L F
.21633 .68809 m .21834 .68841 L .21893 .6879 L F
.21633 .68809 m .21893 .6879 L .21817 .68892 L F
0 0 0 r
.21893 .6879 m .21852 .6882 L .21995 .68653 L F
.21893 .6879 m .21995 .68653 L .22095 .68537 L F
.843 .964 .636 r
.22005 .68508 m .21893 .6879 L .22095 .68537 L F
0 0 .108 r
.22005 .68508 m .2194 .68756 L .21893 .6879 L F
.2194 .68756 m .21895 .68928 L .21893 .6879 L F
0 0 0 r
.21893 .6879 m .21834 .68841 L .21852 .6882 L F
.377 .444 .803 r
.21633 .68809 m .21895 .68928 L .2189 .68917 L F
.21633 .68809 m .2189 .68917 L .21704 .68541 L F
.424 0 0 r
.21492 .68765 m .21567 .68782 L .21633 .68809 L F
.147 0 .187 r
.47672 .58539 m .47884 .58461 L .47958 .58208 L F
.575 .312 .48 r
.47884 .58461 m .48172 .58185 L .47958 .58208 L F
.019 .547 .855 r
.66293 .4475 m .66661 .44862 L .66556 .4468 L F
.632 .739 .925 r
.66661 .44862 m .66801 .4458 L .66556 .4468 L F
.66661 .44862 m .66965 .44765 L .66801 .4458 L F
.645 .574 .761 r
.47251 .59199 m .47245 .59412 L .475 .59158 L F
.989 .723 .405 r
.53452 .60619 m .53576 .60972 L .53457 .60867 L F
0 .167 .595 r
.53851 .61128 m .53457 .60867 L .53576 .60972 L F
0 .268 .699 r
.53948 .61205 m .53851 .61128 L .53576 .60972 L F
.371 .302 .649 r
.44137 .64119 m .44141 .64229 L .43855 .64009 L F
.54 .11 .173 r
.46915 .61165 m .47304 .60999 L .46978 .61247 L F
.215 0 0 r
.22561 .62775 m .22361 .62831 L .22262 .62945 L F
.525 .341 .574 r
.28317 .60059 m .28311 .60317 L .2808 .60365 L F
.296 .149 .505 r
.28311 .60317 m .28143 .6063 L .2808 .60365 L F
.9 .557 .386 r
.67844 .41531 m .67755 .4183 L .67739 .41616 L F
.67844 .41531 m .68032 .41962 L .67755 .4183 L F
.432 0 .073 r
.23677 .64583 m .23621 .64735 L .23278 .64745 L F
.876 .945 .855 r
.23927 .64542 m .23621 .64735 L .23677 .64583 L F
.472 .083 .221 r
.80382 .41702 m .80056 .41888 L .80019 .41722 L F
.566 .912 .7 r
.68166 .43688 m .68017 .43838 L .68179 .43701 L F
.584 .938 .784 r
.67846 .43899 m .68017 .43838 L .68166 .43688 L F
.833 .627 .624 r
.44002 .63061 m .43981 .63355 L .44178 .63333 L F
.736 .711 .828 r
.47462 .56393 m .47892 .56647 L .47674 .56428 L F
0 .234 .736 r
.47892 .56647 m .47887 .56532 L .47674 .56428 L F
.47892 .56647 m .47975 .56656 L .47887 .56532 L F
.033 0 0 r
.47333 .56007 m .47715 .55896 L .47486 .55841 L F
.021 0 .003 r
.5463 .50116 m .54856 .5004 L .54913 .49844 L F
.02 0 .003 r
.54913 .49844 m .55028 .49922 L .5512 .49714 L F
.54913 .49844 m .54856 .5004 L .55028 .49922 L F
.589 .475 .691 r
.44339 .64101 m .44137 .64119 L .44456 .63776 L F
.286 0 .199 r
.44598 .63991 m .44339 .64101 L .44407 .63913 L F
.44598 .63991 m .44407 .63913 L .44456 .63776 L F
.341 0 0 r
.44829 .6401 m .4467 .6402 L .44598 .63991 L F
.4467 .6402 m .44426 .64036 L .44598 .63991 L F
.286 0 .199 r
.44598 .63991 m .44456 .63776 L .44547 .63979 L F
.043 0 .145 r
.44701 .63527 m .44547 .63979 L .44456 .63776 L F
.428 .818 .987 r
.49449 .5372 m .49663 .53661 L .49778 .53742 L F
.262 0 0 r
.49663 .53661 m .50097 .53715 L .49778 .53742 L F
.668 .696 .867 r
.73391 .41396 m .73785 .41602 L .73643 .41334 L F
.579 .72 .939 r
.73785 .41602 m .73908 .4131 L .73643 .41334 L F
.73785 .41602 m .74067 .41536 L .73908 .4131 L F
.289 0 .186 r
.24782 .63918 m .24661 .64188 L .24444 .64246 L F
.086 0 .087 r
.24835 .64089 m .24782 .63918 L .24995 .63872 L F
.24835 .64089 m .24661 .64188 L .24782 .63918 L F
.088 .581 .899 r
.53948 .61205 m .54044 .6117 L .53851 .61128 L F
.53948 .61205 m .54185 .61253 L .54044 .6117 L F
.169 0 .114 r
.5463 .50116 m .54781 .50223 L .54856 .5004 L F
.5463 .50116 m .54573 .5033 L .54781 .50223 L F
.465 .887 .908 r
.21506 .64943 m .21855 .64867 L .21678 .64861 L F
.43 .863 .927 r
.21678 .64861 m .21855 .64867 L .22075 .64796 L F
.914 .617 .466 r
.19339 .72587 m .19506 .72709 L .19458 .72708 L F
.753 .556 .631 r
.42445 .65795 m .42217 .65863 L .42064 .65753 L F
.461 .78 .998 r
.1755 .62038 m .17509 .6218 L .17331 .621 L F
.1755 .62038 m .17732 .62147 L .17509 .6218 L F
.381 .594 .929 r
.78744 .40007 m .78824 .40186 L .78962 .40021 L F
.22 .353 .786 r
.78962 .40021 m .78824 .40186 L .79093 .40372 L F
.611 .346 .492 r
.45169 .5853 m .45473 .58565 L .45478 .58293 L F
.251 .067 .426 r
.45478 .58293 m .45646 .58426 L .45716 .58229 L F
.45478 .58293 m .45473 .58565 L .45646 .58426 L F
.984 .731 .464 r
.49791 .59484 m .49872 .59762 L .49735 .59665 L F
.401 .758 .994 r
.49872 .59762 m .49977 .59652 L .49735 .59665 L F
.446 .308 .599 r
.49894 .60021 m .5013 .59966 L .49872 .59762 L F
.688 .705 .861 r
.48976 .57274 m .49347 .57357 L .48965 .57177 L F
.76 .465 .486 r
.48976 .57274 m .48954 .57476 L .49347 .57357 L F
0 .465 .835 r
.49041 .57204 m .49347 .57357 L .49278 .5729 L F
.49029 .57207 m .49347 .57357 L .49041 .57204 L F
.701 .965 .939 r
.49347 .57357 m .48954 .57476 L .49278 .5729 L F
.338 .558 .917 r
.48965 .57177 m .49278 .5729 L .49173 .57052 L F
0 0 .099 r
.48954 .57476 m .49173 .57052 L .49278 .5729 L F
0 .302 .658 r
.49036 .57468 m .49164 .57522 L .49113 .57489 L F
0 0 .099 r
.4897 .5745 m .49036 .57468 L .49128 .57188 L F
.48954 .57476 m .49128 .57188 L .491 .57193 L F
.001 .57 .78 r
.48911 .57462 m .48954 .57476 L .48976 .57274 L F
.823 1 .815 r
.49036 .57468 m .49109 .57248 L .49173 .57052 L F
0 .302 .658 r
.49036 .57468 m .48958 .5739 L .48921 .57366 L F
0 0 .099 r
.48954 .57476 m .49036 .57468 L .4897 .5745 L F
.086 .578 .899 r
.48911 .57462 m .49036 .57468 L .48921 .57366 L F
.823 1 .815 r
.49036 .57468 m .48945 .57435 L .48972 .57404 L F
.49036 .57468 m .48972 .57404 L .49109 .57248 L F
0 .302 .658 r
.49036 .57468 m .49113 .57489 L .48958 .5739 L F
0 0 .099 r
.491 .57193 m .49128 .57188 L .49173 .57052 L F
0 .465 .835 r
.48965 .57177 m .49029 .57207 L .49041 .57204 L F
.606 .222 .288 r
.49492 .57939 m .49736 .58102 L .49348 .58111 L F
.441 .189 .434 r
.80644 .43337 m .80421 .43169 L .80684 .43145 L F
.80644 .43337 m .80402 .43418 L .80421 .43169 L F
.406 .575 .907 r
.20272 .62949 m .20229 .6318 L .20061 .62998 L F
.20272 .62949 m .20452 .63203 L .20229 .6318 L F
.578 .372 .565 r
.47684 .61729 m .47421 .61505 L .4774 .61385 L F
.47684 .61729 m .47427 .61809 L .47421 .61505 L F
.767 .954 .934 r
.71255 .42143 m .71676 .42007 L .71603 .41941 L F
.629 .931 .969 r
.71603 .41941 m .71676 .42007 L .71914 .41892 L F
.49 .66 .937 r
.78342 .3973 m .78432 .39908 L .78602 .39716 L F
.395 .513 .86 r
.78432 .39908 m .78744 .40007 L .78602 .39716 L F
0 0 .429 r
.58147 .5667 m .58149 .5695 L .58022 .57058 L F
.176 .142 .579 r
.58149 .5695 m .58045 .57283 L .58022 .57058 L F
.603 .603 .824 r
.29114 .55446 m .28888 .5551 L .28733 .55132 L F
.744 .224 0 r
.50286 .5716 m .50282 .57016 L .50078 .56921 L F
.50286 .5716 m .50447 .57235 L .50282 .57016 L F
.371 .163 .463 r
.44434 .6224 m .4415 .62768 L .4415 .62485 L F
.44434 .6224 m .44316 .62731 L .4415 .62768 L F
.559 .344 .544 r
.44748 .62126 m .44434 .6224 L .44626 .62255 L F
.486 .269 .509 r
.44657 .6265 m .44316 .62731 L .44434 .6224 L F
.343 .819 .884 r
.18664 .56002 m .18463 .55998 L .18245 .56054 L F
.256 .765 .85 r
.18885 .55958 m .18463 .55998 L .18664 .56002 L F
.869 .492 .327 r
.68032 .41962 m .68228 .42031 L .68096 .42169 L F
.843 .45 .302 r
.68096 .42169 m .68228 .42031 L .68286 .42237 L F
.648 .729 .908 r
.44209 .59815 m .44527 .59947 L .44394 .59644 L F
.67 .677 .848 r
.44394 .59644 m .44527 .59947 L .45062 .5988 L F
.879 .783 .751 r
.59467 .51434 m .59481 .50976 L .59449 .51072 L F
.983 .789 .567 r
.59304 .51532 m .59467 .51434 L .59449 .51072 L F
.59304 .51532 m .59448 .51643 L .59467 .51434 L F
.282 0 .293 r
.24444 .64246 m .24198 .64507 L .24259 .64304 L F
.112 .637 .877 r
.23631 .55581 m .23478 .55526 L .23236 .55508 L F
.23228 .55511 m .23236 .55508 L .23185 .55504 L F
.23631 .55581 m .23236 .55508 L .23228 .55511 L F
.312 .683 .977 r
.23185 .55504 m .23487 .55526 L .23216 .55403 L F
.749 .755 .858 r
.23216 .55403 m .23487 .55526 L .23604 .5538 L F
.753 .741 .841 r
.23604 .5538 m .23375 .55609 L .23216 .55403 L F
0 .26 .765 r
.23375 .55609 m .23429 .55529 L .23321 .55465 L F
.2328 .55486 m .23321 .55465 L .23216 .55403 L F
.23375 .55609 m .23321 .55465 L .2328 .55486 L F
.827 .954 .899 r
.23631 .55581 m .23375 .55609 L .23464 .5552 L F
.23631 .55581 m .23464 .5552 L .23604 .5538 L F
.112 .637 .877 r
.23631 .55581 m .23487 .55526 L .23478 .55526 L F
.829 .981 .881 r
.23365 .55753 m .23375 .55609 L .23631 .55581 L F
.672 .484 .623 r
.23631 .55581 m .23591 .55821 L .23365 .55753 L F
.844 .961 .883 r
.23604 .5538 m .23487 .55526 L .23631 .55581 L F
.727 .653 .776 r
.21126 .69062 m .21304 .69436 L .2092 .69364 L F
.701 .69 .836 r
.21229 .69046 m .21304 .69436 L .21126 .69062 L F
.21229 .69046 m .21532 .69325 L .21304 .69436 L F
.483 .169 .357 r
.26091 .57275 m .2632 .57269 L .2642 .57036 L F
.297 .081 .407 r
.2632 .57269 m .26569 .5694 L .2642 .57036 L F
.607 .056 0 r
.74091 .37449 m .74446 .37542 L .74361 .37618 L F
.363 0 0 r
.74361 .37618 m .74446 .37542 L .7473 .37603 L F
.674 .183 0 r
.41564 .65505 m .41474 .65435 L .41309 .65214 L F
.798 .386 0 r
.41564 .65505 m .41573 .65621 L .41474 .65435 L F
.41564 .65505 m .41675 .65747 L .41573 .65621 L F
0 0 .49 r
.28615 .54782 m .28733 .55132 L .28668 .5502 L F
0 .099 .655 r
.52986 .58847 m .53166 .59172 L .5313 .59037 L F
.693 .321 0 r
.53283 .59365 m .5313 .59037 L .53166 .59172 L F
0 0 .477 r
.5327 .59417 m .53283 .59365 L .53166 .59172 L F
0 0 .354 r
.53361 .60005 m .53409 .60367 L .53434 .6024 L F
.758 .513 0 r
.53409 .60367 m .53427 .60534 L .53434 .6024 L F
.53409 .60367 m .53452 .60619 L .53427 .60534 L F
.305 0 0 r
.54394 .58663 m .5432 .58546 L .54185 .58435 L F
.54394 .58663 m .54535 .58561 L .5432 .58546 L F
.861 .459 0 r
.52854 .55507 m .5303 .55798 L .52943 .55582 L F
.694 .253 .2 r
.44043 .63526 m .44355 .6343 L .43981 .63355 L F
.44043 .63526 m .44309 .63574 L .44355 .6343 L F
.364 0 .098 r
.44355 .6343 m .44309 .63574 L .44551 .63503 L F
.002 0 .11 r
.44309 .63574 m .44371 .63665 L .44551 .63503 L F
.702 .938 .632 r
.44551 .63503 m .44371 .63665 L .44503 .63512 L F
.533 .574 .842 r
.44589 .63496 m .44355 .6343 L .44551 .63503 L F
.722 .534 .635 r
.44532 .62995 m .4462 .6338 L .44296 .63173 L F
.687 .927 .969 r
.44845 .63383 m .44551 .63503 L .44657 .63334 L F
.459 .365 .661 r
.44704 .63277 m .44617 .63363 L .44532 .62995 L F
.499 .416 .693 r
.44665 .6333 m .44876 .63047 L .44917 .63285 L F
.459 .365 .661 r
.44713 .63293 m .44668 .63326 L .44704 .63277 L F
.44668 .63326 m .44617 .63363 L .44704 .63277 L F
.44876 .63047 m .44713 .63293 L .44532 .62995 L F
.499 .416 .693 r
.44659 .63331 m .44876 .63047 L .44665 .6333 L F
.687 .927 .969 r
.4466 .63331 m .44657 .63334 L .44659 .63331 L F
.44845 .63383 m .44657 .63334 L .4466 .63331 L F
.459 .365 .661 r
.44713 .63293 m .44629 .6342 L .44617 .63363 L F
.722 .534 .635 r
.4462 .6338 m .44629 .6342 L .44603 .634 L F
.4462 .6338 m .44603 .634 L .44296 .63173 L F
.702 .938 .632 r
.44551 .63503 m .44503 .63512 L .44534 .63476 L F
.711 .454 .535 r
.44659 .63331 m .44296 .63173 L .44603 .634 L F
.702 .938 .632 r
.44644 .63355 m .44603 .634 L .44659 .63331 L F
.711 .454 .535 r
.44659 .63331 m .44603 .634 L .44629 .6342 L F
.702 .938 .632 r
.44603 .634 m .44534 .63476 L .44659 .63331 L F
.44551 .63503 m .44534 .63476 L .44644 .63355 L F
.533 .574 .842 r
.44701 .63527 m .44589 .63496 L .44551 .63503 L F
.512 .269 .482 r
.29445 .57068 m .29214 .57369 L .29281 .57276 L F
.29445 .57068 m .29474 .57484 L .29214 .57369 L F
.116 .232 .708 r
.29568 .56865 m .29445 .57068 L .29367 .56668 L F
.671 .579 .743 r
.29568 .56865 m .29474 .57484 L .29445 .57068 L F
.453 .353 .651 r
.74131 .40457 m .73939 .4078 L .73886 .40592 L F
.74131 .40457 m .74151 .407 L .73939 .4078 L F
.661 .566 .737 r
.74265 .41064 m .73939 .4078 L .74151 .407 L F
.727 .615 .733 r
.23663 .60311 m .237 .60724 L .23373 .60668 L F
.864 .713 .693 r
.237 .60724 m .23385 .60827 L .23373 .60668 L F
.237 .60724 m .23603 .60975 L .23385 .60827 L F
.165 .183 .633 r
.23768 .60439 m .237 .60724 L .23663 .60311 L F
.313 .455 .843 r
.2359 .59965 m .23784 .60294 L .23663 .60311 L F
.165 .183 .633 r
.2385 .60539 m .23663 .60311 L .23784 .60294 L F
.996 .864 .576 r
.23689 .60173 m .23645 .60419 L .2377 .60307 L F
.2377 .60276 m .2377 .60307 L .23784 .60294 L F
.23689 .60173 m .2377 .60307 L .2377 .60276 L F
.165 .183 .633 r
.2385 .60539 m .23766 .60643 L .23768 .60439 L F
.23766 .60643 m .237 .60724 L .23768 .60439 L F
.759 .244 0 r
.23694 .60847 m .23827 .60904 L .237 .60724 L F
.23694 .60847 m .237 .60724 L .2385 .60539 L F
.278 .636 .964 r
.26442 .54047 m .26394 .54178 L .26187 .54015 L F
.26442 .54047 m .26602 .54182 L .26394 .54178 L F
0 0 .28 r
.75845 .38797 m .75673 .38974 L .75664 .39172 L F
.5 .08 .175 r
.55657 .50471 m .55906 .50583 L .55702 .50597 L F
.501 .074 .161 r
.55657 .50471 m .55893 .50468 L .55906 .50583 L F
.994 .75 .417 r
.5958 .50315 m .59692 .50431 L .59587 .50071 L F
.917 .816 .731 r
.5958 .50315 m .59638 .5068 L .59692 .50431 L F
0 0 0 r
.16781 .56998 m .16686 .57024 L .16888 .56942 L F
.16781 .56998 m .16457 .57124 L .16686 .57024 L F
.01 0 0 r
.19318 .5424 m .19675 .54133 L .19488 .54127 L F
.284 .767 .92 r
.22075 .64796 m .22469 .64804 L .22296 .64796 L F
.252 .761 .862 r
.22296 .64796 m .22469 .64804 L .22674 .6477 L F
.862 .991 .831 r
.77859 .41915 m .78121 .41735 L .78111 .41606 L F
.89 .724 .214 r
.59022 .53595 m .59064 .53525 L .59016 .53346 L F
.59022 .53595 m .59052 .53778 L .59064 .53525 L F
.549 .581 .839 r
.43437 .59585 m .4358 .60001 L .43353 .6005 L F
.321 .268 .641 r
.47672 .58539 m .47905 .58754 L .47884 .58461 L F
.47672 .58539 m .47735 .58823 L .47905 .58754 L F
.123 .522 .914 r
.73944 .37388 m .74014 .37207 L .73777 .37264 L F
.54 .11 .173 r
.46915 .61165 m .47188 .61168 L .47304 .60999 L F
.299 0 0 r
.47188 .61168 m .47575 .60997 L .47304 .60999 L F
.426 .236 .518 r
.28535 .60004 m .28311 .60317 L .28317 .60059 L F
.279 .436 .84 r
.40682 .63913 m .4087 .64256 L .40985 .64109 L F
.103 .178 .657 r
.4087 .64256 m .4105 .64462 L .40985 .64109 L F
.58 .625 .861 r
.79003 .42614 m .7908 .42929 L .7919 .42673 L F
.504 .537 .824 r
.7908 .42929 m .79376 .42896 L .7919 .42673 L F
.373 0 0 r
.19491 .55802 m .1909 .55937 L .19256 .55832 L F
0 0 0 r
.22255 .66684 m .22329 .66635 L .22491 .66373 L F
.53 .247 .429 r
.22329 .66635 m .22627 .66438 L .22491 .66373 L F
.365 .498 .86 r
.22645 .6641 m .22491 .66373 L .22627 .66438 L F
0 0 .064 r
.2231 .66847 m .22255 .66684 L .22037 .66882 L F
.2231 .66847 m .22329 .66635 L .22255 .66684 L F
.103 .018 .465 r
.43528 .56733 m .43644 .56711 L .43576 .56363 L F
.621 .375 .524 r
.43644 .56711 m .44005 .56395 L .43576 .56363 L F
.856 .5 .379 r
.44035 .56257 m .44005 .56395 L .44193 .56405 L F
.476 0 0 r
.44005 .56395 m .44367 .56608 L .44193 .56405 L F
0 0 .043 r
.70371 .40432 m .70121 .40797 L .70332 .40691 L F
.083 0 .118 r
.70621 .40162 m .70371 .40432 L .70633 .40408 L F
.552 .244 .4 r
.70371 .40432 m .70647 .40605 L .70633 .40408 L F
.70371 .40432 m .70332 .40691 L .70647 .40605 L F
.138 .601 .925 r
.20061 .62998 m .19931 .62998 L .19715 .6287 L F
.263 .1 .463 r
.25617 .59155 m .25759 .59331 L .25783 .59078 L F
.25617 .59155 m .25596 .59408 L .25759 .59331 L F
.276 .722 .96 r
.21994 .55405 m .2201 .55316 L .2175 .55248 L F
.21994 .55405 m .22197 .55392 L .2201 .55316 L F
.883 .99 .801 r
.49068 .53954 m .49012 .53852 L .49189 .53829 L F
.59 .948 .86 r
.49189 .53829 m .49261 .53688 L .49449 .5372 L F
.49189 .53829 m .49012 .53852 L .49261 .53688 L F
.211 0 0 r
.18935 .7437 m .18865 .74334 L .18852 .74341 L F
.977 .808 .607 r
.66508 .4007 m .66604 .40374 L .66805 .40214 L F
0 0 .222 r
.65514 .44646 m .6555 .44626 L .65527 .44303 L F
0 .101 .649 r
.65514 .44646 m .65669 .44839 L .6555 .44626 L F
.84 .376 .005 r
.67233 .41099 m .67497 .41402 L .67317 .41375 L F
.471 .057 .172 r
.67497 .41402 m .67126 .4161 L .67317 .41375 L F
.67497 .41402 m .67356 .41589 L .67126 .4161 L F
.689 .307 .318 r
.67497 .41402 m .67739 .41616 L .67356 .41589 L F
.67 .369 .454 r
.56954 .50147 m .5671 .50384 L .56524 .50343 L F
.71 .426 .492 r
.56954 .50147 m .57127 .50383 L .5671 .50384 L F
.626 .07 0 r
.49338 .56485 m .49472 .56425 L .49313 .56353 L F
.49338 .56485 m .49703 .56605 L .49472 .56425 L F
.579 .094 .068 r
.46544 .59622 m .46901 .59641 L .46674 .59521 L F
.344 0 0 r
.46674 .59521 m .46901 .59641 L .46902 .5964 L F
.575 .308 .475 r
.44947 .67567 m .4491 .67785 L .44681 .67575 L F
.44947 .67567 m .4491 .67785 L .44681 .67575 L F
.68 .679 .842 r
.74757 .42017 m .74889 .42339 L .75128 .42245 L F
.719 .186 0 r
.54079 .57468 m .54072 .57326 L .53895 .57242 L F
.54079 .57468 m .54258 .5754 L .54072 .57326 L F
0 0 .23 r
.77771 .38907 m .77705 .39331 L .77541 .39155 L F
.615 .875 .99 r
.7707 .3865 m .76976 .38824 L .76811 .3862 L F
.7707 .3865 m .77237 .38733 L .76976 .38824 L F
.766 .878 .457 r
.76607 .39384 m .76555 .39571 L .76709 .39251 L F
.514 .467 .742 r
.76806 .39725 m .7671 .39666 L .76712 .39815 L F
.7671 .39666 m .76555 .39571 L .76653 .39723 L F
.7671 .39666 m .76653 .39723 L .76712 .39815 L F
.755 .938 .598 r
.76557 .39819 m .76428 .39973 L .76472 .3997 L F
0 0 .417 r
.76637 .39678 m .76712 .39815 L .76607 .39652 L F
.76637 .39678 m .76607 .39652 L .76555 .39571 L F
.904 .91 .815 r
.76973 .3945 m .76712 .39815 L .76637 .39678 L F
.728 .91 .544 r
.76973 .3945 m .76806 .39725 L .76712 .39815 L F
0 .445 .862 r
.76637 .39678 m .76924 .39787 L .76815 .39673 L F
.76924 .39787 m .7693 .39789 L .76815 .39673 L F
.76637 .39678 m .76815 .39673 L .76667 .39704 L F
.904 .91 .815 r
.76973 .3945 m .76637 .39678 L .76813 .39386 L F
.12 .474 .895 r
.76712 .39815 m .7693 .39789 L .76637 .39678 L F
.788 .958 .635 r
.76533 .39732 m .76428 .39973 L .76637 .39678 L F
0 .445 .862 r
.76637 .39678 m .76667 .39704 L .76533 .39732 L F
.755 .938 .598 r
.76637 .39678 m .76489 .39888 L .76557 .39819 L F
0 0 .417 r
.76637 .39678 m .76555 .39571 L .76607 .39384 L F
.755 .938 .598 r
.76637 .39678 m .76472 .3997 L .76712 .39815 L F
.724 .524 .62 r
.76813 .39386 m .76637 .39678 L .76607 .39384 L F
.555 .799 .99 r
.76533 .39732 m .76815 .39673 L .76704 .39549 L F
.977 .683 .31 r
.76815 .39673 m .76734 .3982 L .76705 .39558 L F
.76815 .39673 m .76705 .39558 L .76704 .39549 L F
.755 .938 .598 r
.76489 .39888 m .76428 .39973 L .76557 .39819 L F
.249 .39 .809 r
.79376 .42896 m .79458 .43218 L .79589 .43025 L F
.693 .98 .887 r
.79589 .43025 m .79458 .43218 L .79417 .43168 L F
.434 .679 .967 r
.7378 .4044 m .73886 .40592 L .73524 .40439 L F
.678 .805 .943 r
.74131 .40457 m .73886 .40592 L .7378 .4044 L F
.599 .438 .635 r
.77112 .42607 m .7716 .42873 L .77342 .42765 L F
.96 .673 .447 r
.76957 .42796 m .77112 .42607 L .77038 .42485 L F
.76957 .42796 m .7716 .42873 L .77112 .42607 L F
.902 .964 .818 r
.77038 .42485 m .77112 .42607 L .77362 .42246 L F
.569 .84 .493 r
.59385 .52113 m .59122 .52414 L .59268 .52549 L F
.59385 .52113 m .59427 .52058 L .59122 .52414 L F
.192 .012 .393 r
.15246 .57907 m .15042 .58234 L .1501 .57952 L F
.451 .197 .437 r
.44323 .58828 m .44551 .58781 L .44548 .58588 L F
.576 .293 .449 r
.44548 .58588 m .44551 .58781 L .44839 .5873 L F
.944 .779 .647 r
.59176 .52802 m .59268 .52549 L .59122 .52414 L F
.919 .548 .303 r
.54001 .58152 m .54158 .58195 L .541 .57992 L F
.121 .078 .531 r
.54258 .5754 m .54298 .57817 L .541 .57992 L F
0 0 0 r
.54298 .57817 m .54001 .58152 L .541 .57992 L F
.593 .353 .522 r
.80957 .42881 m .80961 .43145 L .80684 .43145 L F
.547 .77 .981 r
.81077 .42676 m .80957 .42881 L .80834 .4275 L F
.81077 .42676 m .81207 .42816 L .80957 .42881 L F
.416 .216 .499 r
.81175 .43022 m .80957 .42881 L .81207 .42816 L F
.81175 .43022 m .80961 .43145 L .80957 .42881 L F
.42 .805 .99 r
.71461 .39855 m .71531 .39924 L .71364 .39911 L F
0 0 0 r
.71538 .39812 m .71461 .39855 L .71391 .39927 L F
.491 .847 .993 r
.71794 .39858 m .71461 .39855 L .71668 .39711 L F
0 0 0 r
.71668 .39711 m .71461 .39855 L .71538 .39812 L F
.42 .805 .99 r
.71461 .39855 m .71364 .39911 L .71177 .39897 L F
.491 .847 .993 r
.71794 .39858 m .71531 .39924 L .71461 .39855 L F
.948 .752 .606 r
.52989 .56045 m .53152 .56146 L .5303 .55798 L F
.95 .635 .4 r
.52989 .56045 m .53015 .56296 L .53152 .56146 L F
.035 0 0 r
.53152 .56146 m .53283 .56185 L .53428 .56288 L F
.53152 .56146 m .53015 .56296 L .53283 .56185 L F
.436 .853 .958 r
.55594 .6083 m .55187 .60857 L .55406 .6092 L F
.751 .977 .919 r
.55514 .60927 m .55594 .6083 L .55406 .6092 L F
.849 .969 .876 r
.68291 .42779 m .68145 .42981 L .67975 .42918 L F
.623 .566 .769 r
.43445 .62964 m .43537 .62662 L .43336 .63005 L F
.43445 .62964 m .43639 .63018 L .43537 .62662 L F
.68 .428 .534 r
.43451 .63262 m .43611 .63334 L .43445 .62964 L F
.775 .468 .466 r
.43445 .62964 m .4386 .63249 L .43639 .63018 L F
.43445 .62964 m .43611 .63334 L .4386 .63249 L F
0 0 .134 r
.58771 .54661 m .58725 .54656 L .5883 .54553 L F
.58771 .54661 m .58726 .54851 L .58725 .54656 L F
.677 .783 .312 r
.44899 .56268 m .44862 .56342 L .44957 .56138 L F
.285 0 .175 r
.44957 .56138 m .45179 .56128 L .45208 .56021 L F
.575 .304 .467 r
.44862 .56342 m .45179 .56128 L .44957 .56138 L F
.019 0 0 r
.5156 .51841 m .51738 .5181 L .51885 .51748 L F
.268 0 0 r
.51885 .51748 m .51738 .5181 L .52075 .5179 L F
0 .019 .588 r
.39803 .62472 m .39832 .62355 L .39682 .62113 L F
.637 .077 0 r
.40139 .62694 m .4003 .62668 L .39803 .62472 L F
.945 .59 .292 r
.4003 .62668 m .39902 .62643 L .39899 .62631 L F
.4003 .62668 m .39832 .62355 L .39803 .62472 L F
.4003 .62668 m .39899 .62631 L .39832 .62355 L F
.591 .933 .95 r
.40094 .62543 m .39908 .62639 L .4003 .62668 L F
.39908 .62639 m .39902 .62643 L .4003 .62668 L F
.637 .077 0 r
.40153 .62703 m .4003 .62668 L .40139 .62694 L F
.40203 .62736 m .4003 .62668 L .40153 .62703 L F
.725 .555 0 r
.52619 .54729 m .52646 .5517 L .52652 .55236 L F
.705 .21 0 r
.52716 .55388 m .52854 .55507 L .52652 .55236 L F
.52716 .55388 m .52652 .55236 L .52646 .5517 L F
.415 .174 .438 r
.28047 .61142 m .27864 .60969 L .28112 .60864 L F
.28047 .61142 m .27837 .61205 L .27864 .60969 L F
.295 .277 .668 r
.15801 .61139 m .15729 .61258 L .15763 .61154 L F
.15801 .61139 m .15704 .61511 L .15729 .61258 L F
.513 .305 .535 r
.70633 .40408 m .70876 .40085 L .70621 .40162 L F
.059 0 .298 r
.42948 .58258 m .43122 .58143 L .43149 .57836 L F
.304 .323 .716 r
.42948 .58258 m .4319 .58396 L .43122 .58143 L F
.397 .638 .953 r
.22612 .66972 m .22801 .66913 L .22719 .6677 L F
.709 .93 .607 r
.22719 .6677 m .22429 .67144 L .22612 .66972 L F
.964 .72 .52 r
.22429 .67144 m .22611 .67243 L .22612 .66972 L F
0 0 .414 r
.5327 .59417 m .5325 .59798 L .53356 .59605 L F
0 0 .568 r
.5325 .59798 m .53381 .59868 L .53356 .59605 L F
.5325 .59798 m .53361 .60005 L .53381 .59868 L F
.224 0 0 r
.52726 .52834 m .52358 .53035 L .52582 .53135 L F
.52726 .52834 m .52757 .53039 L .52358 .53035 L F
.186 .31 .758 r
.52893 .52629 m .52726 .52834 L .52601 .52482 L F
0 0 0 r
.52893 .52629 m .52757 .53039 L .52726 .52834 L F
.556 .207 .333 r
.57258 .47885 m .57465 .47886 L .57579 .47623 L F
.56 .342 .541 r
.57579 .47623 m .57871 .47649 L .57851 .47409 L F
.691 .439 .537 r
.57465 .47886 m .57871 .47649 L .57579 .47623 L F
.629 .357 .488 r
.42619 .62659 m .4287 .62679 L .42637 .62455 L F
.656 .351 .444 r
.42637 .62455 m .4287 .62679 L .42933 .62478 L F
.724 .508 .598 r
.59078 .47926 m .59437 .47719 L .59187 .47734 L F
.59078 .47926 m .59436 .47974 L .59437 .47719 L F
1 .806 .476 r
.56891 .56674 m .56811 .56588 L .56929 .56429 L F
.975 .879 .504 r
.56929 .56429 m .56811 .56588 L .56876 .5635 L F
0 0 .029 r
.56811 .56588 m .56813 .56581 L .56876 .5635 L F
.975 .875 .497 r
.56929 .56429 m .56876 .5635 L .56924 .56177 L F
0 0 .029 r
.56813 .56581 m .56954 .56186 L .56876 .5635 L F
.975 .875 .497 r
.56924 .56177 m .56876 .5635 L .56923 .56136 L F
0 0 .504 r
.52858 .58012 m .52937 .58074 L .52816 .5785 L F
.52858 .58012 m .52955 .5816 L .52937 .58074 L F
0 .161 .701 r
.52937 .58074 m .527 .57734 L .52816 .5785 L F
.52937 .58074 m .52925 .57964 L .527 .57734 L F
.759 .693 .151 r
.52937 .58074 m .52906 .58213 L .52922 .58005 L F
.52937 .58074 m .52922 .58005 L .52925 .57964 L F
0 0 .504 r
.52955 .5816 m .53004 .58235 L .52937 .58074 L F
.057 .623 .736 r
.54574 .61251 m .54673 .6124 L .5442 .61188 L F
.54574 .61251 m .54833 .61239 L .54673 .6124 L F
.943 .893 .494 r
.75962 .40829 m .76048 .40784 L .7604 .40691 L F
.75962 .40829 m .75944 .41154 L .76048 .40784 L F
.626 .76 .942 r
.43639 .63018 m .44002 .63061 L .43917 .62893 L F
.688 .498 .624 r
.4386 .63249 m .44002 .63061 L .43639 .63018 L F
.4386 .63249 m .43981 .63355 L .44002 .63061 L F
0 .419 .748 r
.44237 .6301 m .44002 .63061 L .4415 .62768 L F
.44237 .6301 m .43917 .62893 L .44002 .63061 L F
.669 .376 .467 r
.4601 .58169 m .46277 .58186 L .46028 .57943 L F
.401 0 .046 r
.51126 .59817 m .51017 .59958 L .50759 .59981 L F
0 0 0 r
.51208 .5986 m .51126 .59817 L .51289 .59762 L F
.51208 .5986 m .51017 .59958 L .51126 .59817 L F
.798 .827 .874 r
.72214 .41696 m .72535 .41688 L .72416 .41534 L F
.725 .807 .915 r
.72416 .41534 m .72535 .41688 L .72775 .4158 L F
.094 0 0 r
.15596 .57748 m .15564 .57625 L .1577 .57569 L F
.15596 .57748 m .15399 .57822 L .15564 .57625 L F
.117 .633 .89 r
.20822 .70208 m .20849 .7016 L .20638 .69931 L F
.20822 .70208 m .2103 .70224 L .20849 .7016 L F
.81 .611 .633 r
.57931 .5045 m .57544 .50632 L .57532 .50385 L F
.57931 .5045 m .57888 .50701 L .57544 .50632 L F
.829 .981 .881 r
.23365 .55753 m .23194 .55773 L .23375 .55609 L F
.752 .463 .493 r
.23365 .55753 m .23135 .56014 L .23194 .55773 L F
.23365 .55753 m .23602 .56071 L .23135 .56014 L F
.679 .456 .575 r
.23591 .55821 m .23602 .56071 L .23365 .55753 L F
.917 .962 .645 r
.57326 .55236 m .57168 .55567 L .57156 .55384 L F
0 0 0 r
.57168 .55567 m .57169 .55622 L .57156 .55384 L F
.57168 .55567 m .57106 .55799 L .57169 .55622 L F
.731 .203 0 r
.53428 .56288 m .53694 .56477 L .53522 .56444 L F
.689 .718 .871 r
.46132 .57278 m .4651 .5734 L .46406 .57028 L F
.78 .768 .842 r
.46406 .57028 m .4651 .5734 L .46732 .57057 L F
.798 .919 .919 r
.20921 .71142 m .20974 .71247 L .2111 .70964 L F
.73 .969 .933 r
.20314 .72219 m .20272 .72349 L .2065 .72157 L F
.686 .901 .973 r
.44808 .56514 m .44862 .56342 L .44899 .56268 L F
.44808 .56514 m .44648 .56439 L .44862 .56342 L F
.188 .597 .943 r
.76 .43242 m .76279 .43206 L .75896 .43126 L F
.76 .43242 m .76403 .43328 L .76279 .43206 L F
.134 .549 .922 r
.76 .43242 m .76425 .43431 L .76403 .43328 L F
.658 .639 .82 r
.74556 .40808 m .74265 .41064 L .74151 .407 L F
.66 .644 .823 r
.74556 .40808 m .74633 .41139 L .74265 .41064 L F
.726 .353 0 r
.20198 .71913 m .20218 .71898 L .20014 .71961 L F
.291 .65 .969 r
.43906 .60508 m .4413 .60498 L .44175 .60662 L F
.628 .095 0 r
.44175 .60662 m .43974 .60725 L .4413 .60498 L F
.44175 .60662 m .44191 .60731 L .43974 .60725 L F
.44201 .6069 m .44419 .60921 L .44191 .60731 L F
.623 .58 .785 r
.44076 .61149 m .44308 .61116 L .44191 .60731 L F
.745 .683 .791 r
.44522 .60761 m .44419 .60921 L .44191 .60731 L F
.752 .656 .754 r
.44191 .60731 m .44308 .61116 L .44522 .60761 L F
.514 .813 .999 r
.44498 .60634 m .44522 .60761 L .44191 .60731 L F
.501 .237 .447 r
.44498 .60634 m .44187 .60746 L .44191 .60731 L F
.623 .58 .785 r
.44076 .61149 m .44191 .60731 L .43974 .60725 L F
.501 .237 .447 r
.44187 .60746 m .44119 .60771 L .44191 .60731 L F
.628 .095 0 r
.44175 .60662 m .44201 .6069 L .44191 .60731 L F
.923 .751 .651 r
.59767 .49773 m .59831 .49517 L .59644 .49449 L F
.313 0 .05 r
.46277 .58186 m .46529 .58134 L .46643 .57947 L F
.111 0 0 r
.46643 .57947 m .46737 .5805 L .46865 .57819 L F
.46643 .57947 m .46529 .58134 L .46737 .5805 L F
.121 0 0 r
.48324 .55869 m .48613 .55919 L .48715 .55935 L F
.631 .071 0 r
.48613 .55919 m .48946 .56052 L .48715 .55935 L F
0 0 .258 r
.58045 .57283 m .58044 .57522 L .57878 .5765 L F
0 0 0 r
.58044 .57522 m .5785 .57892 L .57878 .5765 L F
.588 .135 .144 r
.43024 .62086 m .42592 .62192 L .42775 .61998 L F
.43024 .62086 m .42775 .61998 L .42966 .62067 L F
.981 .749 .513 r
.43123 .6186 m .42966 .62067 L .42775 .61998 L F
.43123 .6186 m .43025 .62106 L .42966 .62067 L F
.417 .198 .47 r
.20394 .71083 m .20577 .70866 L .20331 .70878 L F
.668 .618 .79 r
.66565 .4444 m .66353 .44582 L .66201 .44292 L F
.525 .347 .583 r
.66565 .4444 m .66293 .4475 L .66353 .44582 L F
.139 0 0 r
.16756 .55175 m .16978 .55124 L .17171 .54969 L F
0 0 0 r
.17171 .54969 m .17184 .5505 L .17382 .54904 L F
.17171 .54969 m .16978 .55124 L .17184 .5505 L F
.585 .941 .803 r
.20115 .54098 m .20111 .54026 L .20325 .54033 L F
.798 .604 .64 r
.55278 .59086 m .55499 .59232 L .55678 .59123 L F
0 .132 .678 r
.40203 .62736 m .4026 .62643 L .4003 .62668 L F
.40203 .62736 m .40403 .62965 L .4026 .62643 L F
.648 .713 .895 r
.72775 .4158 m .73146 .4166 L .73036 .41331 L F
.71 .663 .801 r
.73036 .41331 m .73146 .4166 L .73391 .41396 L F
0 0 0 r
.43149 .57836 m .43282 .5779 L .43434 .57639 L F
.664 .359 .446 r
.43149 .57836 m .43386 .58129 L .43282 .5779 L F
.43149 .57836 m .43122 .58143 L .43386 .58129 L F
.323 0 0 r
.25563 .5514 m .25898 .55155 L .2552 .552 L F
.393 .123 .381 r
.27655 .61283 m .2759 .615 L .27377 .61561 L F
.271 .013 .327 r
.27776 .6142 m .27655 .61283 L .27837 .61205 L F
.27776 .6142 m .2759 .615 L .27655 .61283 L F
.789 .805 .866 r
.42887 .62853 m .43336 .63005 L .43105 .6263 L F
.833 .815 .832 r
.43105 .6263 m .43336 .63005 L .43537 .62662 L F
0 .212 .713 r
.77561 .41132 m .77631 .412 L .7747 .41018 L F
.056 .436 .874 r
.19161 .6248 m .19075 .62564 L .1893 .62459 L F
.19161 .6248 m .19305 .62645 L .19075 .62564 L F
.805 .667 .711 r
.57888 .50701 m .58025 .5104 L .57824 .50979 L F
.859 .649 .617 r
.58025 .5104 m .57727 .51225 L .57824 .50979 L F
.58025 .5104 m .58016 .51299 L .57727 .51225 L F
.185 .656 .935 r
.40803 .62979 m .4097 .6298 L .41186 .63085 L F
0 0 .545 r
.41282 .63153 m .41186 .63085 L .4097 .6298 L F
.447 .222 .478 r
.41186 .63085 m .41368 .6329 L .41416 .63008 L F
.476 .287 .544 r
.41416 .62752 m .41186 .63085 L .41416 .63008 L F
.871 .839 .373 r
.41341 .62776 m .41282 .63153 L .41143 .62776 L F
0 .068 .604 r
.41255 .63069 m .41255 .63079 L .41282 .63153 L F
0 0 .545 r
.41282 .63153 m .41306 .6322 L .41186 .63085 L F
.4 .435 .781 r
.41143 .62776 m .41282 .63153 L .4097 .6298 L F
0 .068 .604 r
.41255 .63079 m .41259 .63416 L .41282 .63153 L F
0 0 .545 r
.41282 .63153 m .41368 .6329 L .41306 .6322 L F
.997 .81 .534 r
.50081 .52809 m .49944 .52709 L .50109 .52489 L F
.745 .985 .762 r
.50109 .52489 m .50227 .52275 L .5039 .52284 L F
.50109 .52489 m .50076 .52452 L .50227 .52275 L F
.872 .929 .544 r
.50109 .52489 m .49944 .52709 L .50076 .52452 L F
.033 0 0 r
.47333 .56007 m .47575 .55967 L .47715 .55896 L F
0 0 0 r
.47715 .55896 m .47808 .55872 L .47978 .55885 L F
.47715 .55896 m .47575 .55967 L .47808 .55872 L F
.418 .654 .957 r
.16161 .63278 m .16283 .63168 L .15991 .63075 L F
.16161 .63278 m .16391 .63284 L .16283 .63168 L F
.509 .271 .49 r
.24161 .61255 m .24409 .61216 L .24458 .6097 L F
.388 .164 .448 r
.24458 .6097 m .24601 .61144 L .24634 .60892 L F
.24458 .6097 m .24409 .61216 L .24601 .61144 L F
.296 .149 .505 r
.28311 .60317 m .28306 .60563 L .28143 .6063 L F
.412 .311 .63 r
.28306 .60563 m .28112 .60864 L .28143 .6063 L F
.46 .426 .734 r
.29227 .59069 m .29047 .59152 L .28978 .5891 L F
.429 .133 .358 r
.29211 .59306 m .29047 .59152 L .29227 .59069 L F
.29211 .59306 m .28983 .59365 L .29047 .59152 L F
.038 .18 .684 r
.42887 .62853 m .43001 .63281 L .42833 .63059 L F
.771 .593 .657 r
.42359 .59752 m .42353 .60003 L .42551 .59748 L F
.683 .468 .588 r
.42353 .60003 m .42573 .60037 L .42551 .59748 L F
.592 .399 .589 r
.42551 .59748 m .42908 .59942 L .42902 .59712 L F
.42551 .59748 m .42573 .60037 L .42908 .59942 L F
.602 .549 .767 r
.45199 .6179 m .45078 .62105 L .4499 .61844 L F
.982 .773 .547 r
.51987 .61691 m .5219 .61521 L .52034 .61459 L F
.51987 .61691 m .52137 .61805 L .5219 .61521 L F
.265 0 0 r
.23609 .53862 m .2401 .53834 L .23929 .53733 L F
.171 .374 .821 r
.43091 .61534 m .4297 .61601 L .42856 .61494 L F
.43091 .61534 m .43232 .61693 L .4297 .61601 L F
.297 0 0 r
.46108 .5601 m .46418 .55999 L .46516 .55928 L F
0 0 0 r
.46516 .55928 m .46553 .55907 L .46757 .55864 L F
.46516 .55928 m .46418 .55999 L .46553 .55907 L F
.46 .426 .734 r
.29227 .59069 m .28978 .5891 L .29187 .5872 L F
.472 .083 .221 r
.80382 .41702 m .80334 .41874 L .80056 .41888 L F
.571 .394 .603 r
.80601 .41405 m .80643 .41653 L .80382 .41702 L F
.684 .411 .503 r
.80643 .41653 m .80334 .41874 L .80382 .41702 L F
.883 .907 .841 r
.23663 .60311 m .23373 .60668 L .2331 .60497 L F
.368 .47 .833 r
.23385 .60827 m .2331 .60497 L .23373 .60668 L F
.514 .417 .682 r
.80811 .41022 m .80601 .41405 L .80546 .41085 L F
.80811 .41022 m .80857 .41266 L .80601 .41405 L F
.539 .407 .65 r
.80857 .41266 m .80643 .41653 L .80601 .41405 L F
.64 .623 .817 r
.80639 .40482 m .80515 .40835 L .80407 .40539 L F
.80639 .40482 m .80738 .40778 L .80515 .40835 L F
.576 .446 .666 r
.80738 .40778 m .80546 .41085 L .80515 .40835 L F
.664 .281 .311 r
.19897 .55785 m .19685 .56005 L .19491 .55802 L F
.024 0 0 r
.20095 .55877 m .19685 .56005 L .19897 .55785 L F
.823 .607 .61 r
.58216 .51633 m .58165 .51897 L .57969 .51557 L F
.932 .887 .477 r
.57326 .55236 m .5729 .55168 L .57386 .54796 L F
.909 .964 .646 r
.57156 .55384 m .5729 .55168 L .57326 .55236 L F
.159 0 0 r
.52326 .51758 m .52711 .51552 L .52458 .51605 L F
.885 .843 .798 r
.6862 .42318 m .68271 .42492 L .68286 .42237 L F
.6862 .42318 m .68415 .42632 L .68271 .42492 L F
.811 .623 .649 r
.42596 .63373 m .42554 .63675 L .422 .63582 L F
.578 .407 .614 r
.42767 .63331 m .42554 .63675 L .42596 .63373 L F
.963 .91 .552 r
.5761 .54009 m .5753 .54338 L .57483 .54164 L F
.99 .818 .438 r
.5753 .54338 m .57405 .54495 L .57483 .54164 L F
.5753 .54338 m .57488 .54599 L .57405 .54495 L F
.671 .755 .914 r
.22956 .6472 m .23089 .64877 L .23278 .64745 L F
.711 .794 .318 r
.49425 .59479 m .49359 .5962 L .49413 .59432 L F
.133 0 .249 r
.39509 .6093 m .39656 .60864 L .397 .60675 L F
.272 .18 .565 r
.39509 .6093 m .39677 .61112 L .39656 .60864 L F
.39509 .6093 m .3948 .61256 L .39677 .61112 L F
.414 .658 .96 r
.15432 .59519 m .15371 .59686 L .15194 .5954 L F
.15432 .59519 m .15581 .59683 L .15371 .59686 L F
0 0 0 r
.22992 .62656 m .23188 .62464 L .22907 .62721 L F
.064 0 0 r
.2339 .62395 m .23188 .62464 L .22992 .62656 L F
.921 .706 .595 r
.65531 .41574 m .65726 .41683 L .65743 .41423 L F
.008 0 .213 r
.23592 .62064 m .2346 .62166 L .2339 .62395 L F
.945 .92 .755 r
.57951 .52472 m .57911 .52779 L .57801 .52684 L F
.998 .845 .552 r
.57911 .52779 m .57761 .53024 L .57801 .52684 L F
.57911 .52779 m .57863 .53131 L .57761 .53024 L F
.768 .633 .712 r
.47165 .57679 m .47385 .57288 L .47127 .5733 L F
.995 .771 .479 r
.42992 .67371 m .43061 .67586 L .42927 .67463 L F
.42992 .67371 m .43061 .67586 L .42927 .67463 L F
.133 0 .05 r
.46953 .59901 m .46902 .5964 L .46901 .59641 L F
.549 .345 .556 r
.41416 .62752 m .41416 .63008 L .41659 .62736 L F
.681 .226 .166 r
.43282 .5779 m .43662 .57836 L .43434 .57639 L F
.509 .31 .546 r
.49899 .58524 m .50159 .58482 L .5019 .58227 L F
.416 .093 .307 r
.49837 .58741 m .50159 .58482 L .49899 .58524 L F
.306 .47 .858 r
.77237 .43473 m .7755 .4361 L .77426 .43794 L F
.154 .259 .72 r
.7755 .4361 m .77643 .43978 L .77426 .43794 L F
.081 0 .332 r
.46456 .60335 m .46465 .60589 L .46308 .60659 L F
0 0 .202 r
.46368 .60709 m .46308 .60659 L .46465 .60589 L F
.46368 .60709 m .46283 .60945 L .46308 .60659 L F
.559 .554 .805 r
.80436 .42225 m .80188 .423 L .80056 .41888 L F
.785 .546 .575 r
.80436 .42225 m .80108 .42421 L .80188 .423 L F
.445 .768 .997 r
.18523 .62378 m .18487 .62525 L .18305 .62432 L F
.18523 .62378 m .18721 .62499 L .18487 .62525 L F
.699 .796 .925 r
.822 .44229 m .81818 .44231 L .82094 .44071 L F
.654 .781 .942 r
.8236 .43966 m .822 .44229 L .82094 .44071 L F
.8236 .43966 m .82469 .44125 L .822 .44229 L F
.791 .86 .901 r
.42048 .58401 m .42348 .58395 L .42193 .58212 L F
.748 .828 .913 r
.42193 .58212 m .42348 .58395 L .42586 .58215 L F
.473 .231 .466 r
.2759 .615 m .2732 .61784 L .27377 .61561 L F
.629 .849 .983 r
.65669 .44839 m .65836 .44609 L .6555 .44626 L F
.65669 .44839 m .65963 .44729 L .65836 .44609 L F
.912 .949 .809 r
.4156 .64855 m .41309 .65214 L .41261 .65096 L F
.77 .316 .171 r
.41309 .65214 m .41163 .65325 L .41261 .65096 L F
.41309 .65214 m .41474 .65435 L .41163 .65325 L F
.585 .378 .567 r
.45742 .6245 m .45733 .62736 L .45473 .6274 L F
.501 .309 .552 r
.45969 .62663 m .45742 .6245 L .45956 .6239 L F
.45969 .62663 m .45733 .62736 L .45742 .6245 L F
.117 .317 .788 r
.16391 .63284 m .16567 .63644 L .16605 .63472 L F
.155 .36 .814 r
.16605 .63472 m .16567 .63644 L .16683 .63612 L F
.263 .409 .821 r
.16567 .63644 m .16865 .63972 L .16683 .63612 L F
.843 .982 .692 r
.68259 .42739 m .68415 .42632 L .68291 .42779 L F
.98 .74 .5 r
.68271 .42492 m .68415 .42632 L .68259 .42739 L F
.873 .607 .533 r
.67233 .41099 m .6699 .41022 L .66988 .40776 L F
.953 .617 .337 r
.67233 .41099 m .67114 .41241 L .6699 .41022 L F
.67233 .41099 m .67317 .41375 L .67114 .41241 L F
.9 .641 .537 r
.2391 .61397 m .24161 .61255 L .23901 .61135 L F
.2391 .61397 m .24139 .61502 L .24161 .61255 L F
.432 .224 .496 r
.24161 .61255 m .24347 .61441 L .24409 .61216 L F
.24161 .61255 m .24139 .61502 L .24347 .61441 L F
.658 .219 .195 r
.67603 .40757 m .67859 .40941 L .6797 .40782 L F
.8 .397 .287 r
.67859 .40941 m .68239 .41083 L .6797 .40782 L F
.755 .426 .428 r
.6797 .40782 m .68239 .41083 L .68377 .40972 L F
.77 .636 .713 r
.4836 .57267 m .48518 .57666 L .48183 .57519 L F
.814 .521 .494 r
.48518 .57666 m .48386 .57789 L .48183 .57519 L F
.682 .593 .75 r
.48831 .573 m .48518 .57666 L .4836 .57267 L F
.336 0 0 r
.2201 .55316 m .21882 .55288 L .2175 .55248 L F
.21882 .55288 m .21673 .55242 L .2175 .55248 L F
.295 0 0 r
.21391 .55365 m .21666 .55222 L .2175 .55248 L F
.21666 .55222 m .21687 .55212 L .2175 .55248 L F
.776 .772 .849 r
.51369 .53726 m .51016 .53961 L .51399 .53978 L F
.78 .304 0 r
.51016 .53961 m .51292 .54281 L .51399 .53978 L F
.713 .547 .663 r
.51292 .54281 m .51514 .54272 L .51399 .53978 L F
.679 .626 .789 r
.51514 .54272 m .51684 .53945 L .51399 .53978 L F
.984 .731 .464 r
.49791 .59484 m .49735 .59665 L .49554 .59599 L F
.894 .477 .091 r
.43877 .64713 m .44041 .64829 L .43982 .64698 L F
.217 0 0 r
.15862 .55708 m .16251 .55448 L .16021 .55455 L F
.899 .933 .828 r
.83973 .42456 m .84012 .42599 L .8377 .42897 L F
.603 .419 .605 r
.84012 .42599 m .84062 .4285 L .8377 .42897 L F
.411 .639 .95 r
.83973 .42456 m .84092 .42436 L .84012 .42599 L F
0 .053 .565 r
.84092 .42436 m .84062 .4285 L .84012 .42599 L F
.703 .351 .378 r
.43629 .63784 m .43364 .64106 L .43135 .63861 L F
.888 .913 .837 r
.20301 .5589 m .20538 .55913 L .20676 .55661 L F
.479 .271 .519 r
.77859 .41915 m .77612 .41951 L .77555 .4219 L F
.915 .711 .613 r
.77523 .42026 m .77612 .41951 L .77491 .41654 L F
.918 .719 .617 r
.77555 .4219 m .77612 .41951 L .77523 .42026 L F
.528 .534 .805 r
.77491 .41654 m .77612 .41951 L .77859 .41915 L F
.479 .271 .519 r
.77859 .41915 m .77612 .41951 L .77555 .4219 L F
.763 .825 .901 r
.49519 .53023 m .49637 .53203 L .49799 .53082 L F
.49799 .53082 m .49637 .53203 L .49519 .53023 L F
.901 .62 .503 r
.42051 .64027 m .4229 .63959 L .4211 .63842 L F
.42051 .64027 m .42277 .64196 L .4229 .63959 L F
.831 .866 .871 r
.42554 .63675 m .4229 .63959 L .4211 .63842 L F
0 0 .236 r
.4229 .63959 m .42277 .64196 L .42385 .64045 L F
.4229 .63959 m .42385 .64045 L .4211 .63842 L F
.605 .687 .901 r
.7833 .41058 m .78715 .41198 L .78603 .40977 L F
.636 .653 .849 r
.78603 .40977 m .78715 .41198 L .78954 .41085 L F
0 0 0 r
.47067 .58214 m .46849 .58332 L .47016 .58143 L F
.358 0 .123 r
.19172 .72274 m .19549 .72016 L .19327 .72076 L F
.902 .698 .19 r
.76128 .37601 m .76165 .37665 L .76117 .37454 L F
0 .351 .797 r
.76128 .37601 m .76145 .37613 L .76165 .37665 L F
.442 .849 .969 r
.76322 .37703 m .76191 .37735 L .76165 .37665 L F
.518 0 0 r
.76387 .37782 m .76322 .37703 L .76165 .37665 L F
0 .351 .797 r
.76145 .37613 m .76387 .37782 L .76165 .37665 L F
.442 .849 .969 r
.76191 .37735 m .76061 .37767 L .76165 .37665 L F
0 0 0 r
.76165 .37665 m .76061 .37767 L .75974 .37892 L F
.447 .154 .373 r
.2557 .6339 m .2551 .63599 L .25281 .63647 L F
.388 .101 .35 r
.25723 .63542 m .2557 .6339 L .25788 .63346 L F
.25723 .63542 m .2551 .63599 L .2557 .6339 L F
.835 .714 .73 r
.23663 .60311 m .23351 .60294 L .23481 .59965 L F
.883 .907 .841 r
.23663 .60311 m .2331 .60497 L .23351 .60294 L F
.313 .455 .843 r
.2359 .59965 m .23663 .60311 L .23481 .59965 L F
.47 .719 .978 r
.50424 .5523 m .50553 .55063 L .50264 .54924 L F
.456 .689 .966 r
.27423 .54207 m .27358 .54388 L .2722 .54216 L F
.27423 .54207 m .27581 .54365 L .27358 .54388 L F
0 0 .345 r
.48327 .60786 m .48273 .61041 L .48198 .60967 L F
.247 0 .204 r
.74905 .39666 m .75179 .39556 L .75203 .39558 L F
.59 .671 .896 r
.75353 .39271 m .75478 .39539 L .75203 .39558 L F
.75353 .39271 m .75203 .39558 L .75277 .3945 L F
.648 .921 .633 r
.75203 .39558 m .75179 .39556 L .75277 .3945 L F
.363 .178 .491 r
.48653 .60321 m .48451 .60647 L .48398 .6033 L F
.48653 .60321 m .48674 .60475 L .48451 .60647 L F
.351 0 0 r
.48507 .60448 m .48653 .60321 L .48398 .6033 L F
.496 .268 .498 r
.48911 .60522 m .48653 .60321 L .4889 .60245 L F
.48911 .60522 m .48688 .60579 L .48653 .60321 L F
0 0 0 r
.4889 .60245 m .48653 .60321 L .48507 .60448 L F
.4888 .60239 m .48507 .60448 L .48779 .60186 L F
.4889 .60245 m .48862 .6026 L .4888 .60239 L F
.48862 .6026 m .48507 .60448 L .4888 .60239 L F
.363 .178 .491 r
.48674 .60475 m .48688 .60579 L .48547 .60619 L F
.48674 .60475 m .48547 .60619 L .48451 .60647 L F
.611 .284 .392 r
.48688 .60579 m .48327 .60786 L .48451 .60647 L F
0 0 .293 r
.43528 .56733 m .43625 .56821 L .43644 .56711 L F
.43528 .56733 m .43533 .56985 L .43625 .56821 L F
.262 .558 .932 r
.7713 .44106 m .77359 .44052 L .77077 .43932 L F
.7713 .44106 m .77472 .4419 L .77359 .44052 L F
.218 0 .259 r
.46751 .59992 m .46691 .60251 L .46456 .60335 L F
.39 .084 .32 r
.46917 .60189 m .46751 .59992 L .46953 .59901 L F
.46917 .60189 m .46691 .60251 L .46751 .59992 L F
.967 .792 .613 r
.59244 .51774 m .59448 .51643 L .59304 .51532 L F
.59244 .51774 m .5939 .51897 L .59448 .51643 L F
.509 .148 .29 r
.48923 .58272 m .48857 .58433 L .48652 .58386 L F
.69 .517 .649 r
.49106 .58166 m .48857 .58433 L .48923 .58272 L F
.578 .58 .818 r
.65147 .42317 m .653 .41885 L .65035 .41944 L F
.65147 .42317 m .65428 .42238 L .653 .41885 L F
0 .336 .808 r
.43807 .57936 m .43862 .57886 L .43662 .57836 L F
.543 .336 .549 r
.44011 .57974 m .44051 .58083 L .43807 .57936 L F
0 .336 .808 r
.43807 .57936 m .44051 .58083 L .43862 .57886 L F
.262 .62 .959 r
.76425 .43431 m .7651 .43347 L .76403 .43328 L F
.164 .239 .695 r
.41777 .59381 m .41854 .59618 L .41659 .59419 L F
0 0 0 r
.41908 .59161 m .41777 .59381 L .41659 .59419 L F
.884 .891 .831 r
.66895 .43185 m .6666 .4351 L .66537 .43372 L F
.876 .903 .846 r
.66715 .43758 m .66537 .43372 L .6666 .4351 L F
.769 .482 .499 r
.45324 .62416 m .45078 .62105 L .45299 .62187 L F
.45324 .62416 m .45261 .6241 L .45078 .62105 L F
.669 .456 .587 r
.44917 .62108 m .45103 .62146 L .45078 .62105 L F
.769 .482 .499 r
.45261 .6241 m .44968 .62387 L .45078 .62105 L F
.669 .456 .587 r
.45103 .62146 m .45299 .62187 L .45078 .62105 L F
.64 .825 .971 r
.19607 .65111 m .19996 .6514 L .19804 .651 L F
.573 .94 .891 r
.20048 .65033 m .19996 .6514 L .20182 .65029 L F
.472 .867 .968 r
.19804 .651 m .19996 .6514 L .20048 .65033 L F
.554 .783 .984 r
.66293 .4475 m .66556 .4468 L .66193 .44607 L F
.329 .447 .829 r
.43815 .60207 m .43769 .60488 L .43534 .60431 L F
.43815 .60207 m .43906 .60508 L .43769 .60488 L F
.351 0 0 r
.48507 .60448 m .48398 .6033 L .48316 .60548 L F
.34 .115 .42 r
.20891 .55481 m .20709 .55525 L .20926 .55452 L F
.914 .617 .466 r
.19339 .72587 m .19458 .72708 L .19553 .72384 L F
.754 .865 .929 r
.19458 .72708 m .19978 .72433 L .19789 .72306 L F
.538 .813 .997 r
.21793 .6916 m .21532 .69325 L .21229 .69046 L F
.21793 .6916 m .21823 .69282 L .21532 .69325 L F
.519 .517 .793 r
.42933 .62478 m .4312 .62423 L .43025 .62106 L F
.346 .056 .321 r
.42933 .62478 m .4287 .62679 L .4312 .62423 L F
.719 .569 .685 r
.46904 .57625 m .47165 .57679 L .47127 .5733 L F
.576 .446 .666 r
.80738 .40778 m .80811 .41022 L .80546 .41085 L F
0 0 0 r
.58365 .5604 m .58309 .56268 L .58216 .56436 L F
0 0 .083 r
.58295 .5651 m .58216 .56436 L .58309 .56268 L F
.58295 .5651 m .58147 .5667 L .58216 .56436 L F
.363 .161 .467 r
.28756 .59687 m .28535 .60004 L .28535 .59744 L F
.53 .285 .489 r
.45687 .6118 m .45457 .61357 L .45489 .61275 L F
.273 .087 .437 r
.24899 .60564 m .25099 .60552 L .25127 .60295 L F
.291 .006 .296 r
.24838 .60823 m .25099 .60552 L .24899 .60564 L F
.877 .902 .844 r
.21126 .69062 m .2092 .69364 L .20751 .69298 L F
0 0 .11 r
.2092 .69364 m .20943 .69491 L .20751 .69298 L F
.2092 .69364 m .20956 .69674 L .20943 .69491 L F
0 .212 .713 r
.77561 .41132 m .7747 .41018 L .77457 .41058 L F
.627 .872 .988 r
.77362 .41304 m .77561 .41132 L .77457 .41058 L F
.77362 .41304 m .77691 .41265 L .77561 .41132 L F
.877 .694 .65 r
.59517 .4882 m .59707 .4892 L .5957 .48565 L F
.851 .673 .661 r
.59517 .4882 m .5968 .49174 L .59707 .4892 L F
.665 .293 0 r
.51444 .59042 m .5151 .59171 L .51369 .58883 L F
.696 .331 0 r
.51444 .59042 m .51598 .59376 L .5151 .59171 L F
.192 .012 .393 r
.15246 .57907 m .15211 .58141 L .15042 .58234 L F
.558 .523 .772 r
.15211 .58141 m .15081 .58521 L .15042 .58234 L F
.567 .531 .774 r
.43537 .62662 m .43639 .63018 L .43917 .62893 L F
.435 .156 .39 r
.18025 .56118 m .17977 .5633 L .17743 .56383 L F
.423 .144 .384 r
.18245 .56054 m .17977 .5633 L .18025 .56118 L F
.294 .385 .786 r
.47648 .56965 m .47939 .5714 L .47891 .56967 L F
.197 0 .128 r
.56178 .48851 m .56416 .4878 L .56481 .48582 L F
0 0 0 r
.56751 .48311 m .56481 .48582 L .56587 .48477 L F
.3 0 .167 r
.56481 .48582 m .56631 .48708 L .56587 .48477 L F
.56481 .48582 m .56416 .4878 L .56631 .48708 L F
0 .234 .744 r
.76839 .43744 m .7691 .4372 L .76713 .43614 L F
.76839 .43744 m .77077 .43932 L .7691 .4372 L F
0 0 0 r
.44503 .59483 m .44394 .59644 L .44689 .59324 L F
.493 .251 .475 r
.27112 .61846 m .27072 .62083 L .26842 .62129 L F
.463 .224 .465 r
.27294 .6203 m .27112 .61846 L .2732 .61784 L F
.27294 .6203 m .27072 .62083 L .27112 .61846 L F
.123 .522 .914 r
.73944 .37388 m .73985 .37322 L .74014 .37207 L F
.73944 .37388 m .74091 .37449 L .73985 .37322 L F
.682 .593 .75 r
.48831 .573 m .4836 .57267 L .48643 .57183 L F
.814 .39 .237 r
.48643 .57183 m .48911 .57462 L .48976 .57274 L F
.81 .792 .835 r
.48843 .57013 m .48976 .57274 L .48965 .57177 L F
.267 .452 .858 r
.5146 .60037 m .51581 .59892 L .51289 .59762 L F
.919 .714 .221 r
.5146 .60037 m .51416 .60173 L .51581 .59892 L F
.907 .796 .727 r
.42217 .65863 m .42057 .66009 L .42064 .65753 L F
.111 .31 .784 r
.42151 .65615 m .42064 .65753 L .41908 .65421 L F
.121 .123 .586 r
.42151 .65615 m .42057 .66009 L .42064 .65753 L F
.826 .364 .12 r
.49068 .53954 m .49026 .54136 L .49012 .53852 L F
.49068 .53954 m .49231 .54218 L .49026 .54136 L F
.767 .629 .707 r
.74799 .40148 m .7439 .40395 L .74602 .4011 L F
.74799 .40148 m .74624 .40428 L .7439 .40395 L F
.736 .984 .771 r
.72978 .37991 m .73236 .37761 L .73243 .38004 L F
.525 .318 .542 r
.73236 .37761 m .73505 .37956 L .73243 .38004 L F
.73236 .37761 m .73471 .37708 L .73505 .37956 L F
0 0 0 r
.73352 .37749 m .73236 .37761 L .73243 .38004 L F
.73352 .37749 m .73471 .37708 L .73236 .37761 L F
.876 .945 .855 r
.23927 .64542 m .23694 .64848 L .23621 .64735 L F
.413 .733 .991 r
.23585 .6468 m .23621 .64735 L .23742 .6471 L F
.23331 .64632 m .23621 .64735 L .23585 .6468 L F
.876 .945 .855 r
.23694 .64848 m .23692 .6485 L .23621 .64735 L F
.589 .014 0 r
.23692 .6485 m .23574 .64879 L .23621 .64735 L F
.23692 .6485 m .23867 .64992 L .23574 .64879 L F
.606 .487 .691 r
.23927 .64542 m .23921 .6484 L .23692 .6485 L F
.53 .18 .319 r
.23921 .6484 m .23867 .64992 L .23692 .6485 L F
.902 .964 .818 r
.77038 .42485 m .77362 .42246 L .77301 .42217 L F
.918 .719 .617 r
.77555 .4219 m .77301 .42217 L .77362 .42246 L F
.392 .028 .223 r
.55321 .50713 m .55033 .50907 L .55071 .50773 L F
.94 .793 .67 r
.67086 .44589 m .67192 .44351 L .66956 .44437 L F
.666 .972 .895 r
.67337 .44234 m .67192 .44351 L .67433 .44183 L F
0 0 0 r
.6733 .44262 m .67192 .44351 L .67337 .44234 L F
.4 .847 .751 r
.66956 .44437 m .67192 .44351 L .6733 .44262 L F
.14 0 .097 r
.39656 .60864 m .39907 .60629 L .397 .60675 L F
.599 .95 .896 r
.21914 .63043 m .21707 .63131 L .21923 .63053 L F
.484 .897 .807 r
.21707 .63131 m .21703 .63076 L .21923 .63053 L F
.131 0 0 r
.21943 .63074 m .21923 .63053 L .21703 .63076 L F
.22049 .63074 m .21923 .63053 L .21943 .63074 L F
.599 .95 .896 r
.22034 .62992 m .21914 .63043 L .21923 .63053 L F
.117 0 0 r
.22049 .63074 m .22262 .62945 L .22034 .62992 L F
.524 .755 .98 r
.1865 .64808 m .19001 .64878 L .18838 .64754 L F
.624 .779 .955 r
.19001 .64878 m .1914 .64683 L .18838 .64754 L F
.19001 .64878 m .19237 .64814 L .1914 .64683 L F
.442 .554 .874 r
.19001 .64878 m .19378 .65182 L .19237 .64814 L F
.282 .049 .372 r
.46654 .60484 m .46456 .60335 L .46691 .60251 L F
.46654 .60484 m .46465 .60589 L .46456 .60335 L F
.542 .712 .951 r
.16498 .62009 m .16096 .61895 L .16433 .61963 L F
.802 .915 .916 r
.16743 .61829 m .16498 .62009 L .16433 .61963 L F
.542 .61 .871 r
.43456 .60711 m .43789 .60867 L .4376 .60758 L F
.479 0 0 r
.43456 .60711 m .4376 .60758 L .43351 .60765 L F
0 0 .509 r
.5093 .58154 m .51105 .58478 L .51034 .58248 L F
.436 .355 .667 r
.49347 .58801 m .4963 .59097 L .49599 .58796 L F
.49347 .58801 m .49533 .59293 L .4963 .59097 L F
.789 .752 .819 r
.83676 .42726 m .8377 .42897 L .8345 .4286 L F
.676 .497 .636 r
.8377 .42897 m .83543 .43238 L .8345 .4286 L F
.8377 .42897 m .83792 .43143 L .83543 .43238 L F
.899 .933 .828 r
.83973 .42456 m .8377 .42897 L .83676 .42726 L F
.49 .281 .523 r
.84062 .4285 m .83792 .43143 L .8377 .42897 L F
.977 .808 .607 r
.66508 .4007 m .66471 .40344 L .66604 .40374 L F
.599 .217 .289 r
.22907 .62721 m .22493 .62916 L .2271 .62866 L F
.22907 .62721 m .22561 .62775 L .22493 .62916 L F
.428 .812 .572 r
.22992 .62656 m .22907 .62721 L .2271 .62866 L F
.774 .737 .212 r
.23603 .60975 m .23564 .61086 L .23385 .60827 L F
.23603 .60975 m .23553 .6124 L .23564 .61086 L F
.577 .188 .268 r
.56255 .50386 m .55906 .50583 L .55893 .50468 L F
.56255 .50386 m .56144 .50601 L .55906 .50583 L F
.566 .227 .352 r
.56524 .50343 m .56144 .50601 L .56255 .50386 L F
.557 0 0 r
.81967 .44742 m .81877 .44818 L .81613 .44731 L F
0 0 0 r
.82097 .44694 m .81967 .44742 L .82235 .44682 L F
.82097 .44694 m .81877 .44818 L .81967 .44742 L F
.048 0 0 r
.15133 .56051 m .15288 .56055 L .1547 .55865 L F
0 0 0 r
.1547 .55865 m .15449 .55929 L .1566 .55781 L F
.1547 .55865 m .15288 .56055 L .15449 .55929 L F
.605 .465 .664 r
.2437 .55239 m .2441 .55512 L .24171 .55436 L F
.501 .044 .099 r
.2441 .55512 m .23994 .55665 L .24171 .55436 L F
.322 .503 .88 r
.17866 .64479 m .18184 .64885 L .18257 .64809 L F
.751 .657 .757 r
.45925 .5936 m .46109 .59737 L .45668 .59677 L F
.589 .582 .813 r
.46309 .5967 m .46109 .59737 L .45925 .5936 L F
.56 .378 .591 r
.46064 .59986 m .46309 .5967 L .46109 .59737 L F
.46064 .59986 m .46309 .5967 L .46109 .59737 L F
.613 .049 0 r
.49937 .54751 m .4952 .54557 L .49717 .54585 L F
.802 .531 .529 r
.57871 .47649 m .58227 .4794 L .5823 .47708 L F
.748 .512 .573 r
.5823 .47708 m .58227 .4794 L .58569 .47963 L F
.725 .807 .915 r
.72416 .41534 m .72775 .4158 L .72682 .41279 L F
.756 .76 .856 r
.72682 .41279 m .72775 .4158 L .73036 .41331 L F
.609 .819 .981 r
.72875 .3898 m .73031 .38763 L .72771 .38825 L F
.72875 .3898 m .73146 .38907 L .73031 .38763 L F
.72875 .3898 m .73031 .38763 L .72771 .38825 L F
.72875 .3898 m .73146 .38907 L .73031 .38763 L F
.091 0 0 r
.53487 .51164 m .53823 .50969 L .53579 .5105 L F
.109 0 0 r
.69851 .42997 m .69961 .4286 L .70208 .42782 L F
.247 0 .204 r
.74905 .39666 m .7479 .39796 L .75179 .39556 L F
.819 .845 .868 r
.75824 .42533 m .75871 .42806 L .75748 .42855 L F
.807 .838 .874 r
.76129 .42544 m .75871 .42806 L .75824 .42533 L F
.409 .336 .664 r
.44393 .62935 m .4415 .62768 L .44316 .62731 L F
.44393 .62935 m .44237 .6301 L .4415 .62768 L F
.25 .208 .614 r
.3948 .61256 m .39704 .61374 L .39677 .61112 L F
.3948 .61256 m .39526 .61515 L .39704 .61374 L F
.708 .636 .774 r
.83187 .42928 m .83155 .43178 L .8291 .43178 L F
.77 .545 .593 r
.83155 .43178 m .82954 .43417 L .8291 .43178 L F
.83155 .43178 m .83135 .43474 L .82954 .43417 L F
.825 .594 .59 r
.83343 .43468 m .83135 .43474 L .83155 .43178 L F
.651 .588 .771 r
.8345 .4286 m .83155 .43178 L .83187 .42928 L F
.8345 .4286 m .83543 .43238 L .83155 .43178 L F
.661 .557 .726 r
.83155 .43178 m .83543 .43238 L .83343 .43468 L F
.495 .597 .885 r
.73684 .4023 m .73524 .40439 L .73349 .40173 L F
.73684 .4023 m .7378 .4044 L .73524 .40439 L F
.019 0 0 r
.5156 .51841 m .51509 .51894 L .51738 .5181 L F
.612 .579 .793 r
.19378 .65182 m .19487 .64767 L .19237 .64814 L F
.19378 .65182 m .19607 .65111 L .19487 .64767 L F
.75 .658 .758 r
.72401 .39599 m .72378 .39834 L .72165 .39899 L F
.64 .477 .647 r
.72378 .39834 m .7215 .40149 L .72165 .39899 L F
.72378 .39834 m .72504 .40084 L .7215 .40149 L F
.648 .553 .734 r
.72679 .39514 m .72378 .39834 L .72401 .39599 L F
.72679 .39514 m .72688 .39802 L .72378 .39834 L F
.445 .241 .508 r
.72688 .39802 m .72504 .40084 L .72378 .39834 L F
.963 .91 .552 r
.5761 .54009 m .57483 .54164 L .57564 .53921 L F
0 0 0 r
.56751 .48311 m .56886 .48204 L .57039 .48066 L F
.418 .219 .5 r
.56587 .48477 m .56886 .48204 L .56751 .48311 L F
.196 0 .318 r
.23821 .5577 m .23602 .56071 L .23591 .55821 L F
.983 .753 .512 r
.77103 .43137 m .77218 .43179 L .7716 .42873 L F
.762 .579 .006 r
.77215 .43288 m .77237 .43473 L .77218 .43179 L F
.631 .544 .737 r
.7716 .42873 m .77218 .43179 L .77485 .43007 L F
.396 .844 .92 r
.20325 .54033 m .20541 .53974 L .20727 .53977 L F
.366 .785 .977 r
.20541 .53974 m .20927 .54009 L .20727 .53977 L F
.587 .815 .986 r
.29569 .54827 m .29345 .54899 L .29181 .54781 L F
.738 .223 0 r
.29345 .54899 m .29341 .55004 L .29181 .54781 L F
.29345 .54899 m .29524 .55128 L .29341 .55004 L F
.492 .301 .549 r
.29569 .54827 m .29524 .55128 L .29345 .54899 L F
.292 0 0 r
.66127 .41084 m .66023 .41208 L .65761 .41237 L F
.236 .35 .777 r
.66279 .40856 m .66127 .41084 L .66003 .40722 L F
.619 .847 .469 r
.66279 .40856 m .66023 .41208 L .66127 .41084 L F
.412 .311 .63 r
.28306 .60563 m .28338 .60883 L .28112 .60864 L F
.417 .121 .352 r
.28271 .61084 m .28112 .60864 L .28338 .60883 L F
.28271 .61084 m .28047 .61142 L .28112 .60864 L F
.331 0 0 r
.43611 .63334 m .43981 .63355 L .4386 .63249 L F
.022 .068 .571 r
.45335 .60893 m .45215 .60467 L .45343 .60635 L F
.677 .379 .461 r
.45078 .62105 m .44968 .62387 L .44748 .62126 L F
.375 .373 .729 r
.29457 .57536 m .29349 .57926 L .29307 .57565 L F
.29457 .57536 m .29491 .57906 L .29349 .57926 L F
.472 .337 .615 r
.29491 .57906 m .29359 .58178 L .29349 .57926 L F
.145 0 0 r
.68377 .40972 m .68239 .41083 L .6824 .41154 L F
.634 .082 0 r
.68491 .41154 m .68377 .40972 L .6824 .41154 L F
.68491 .41154 m .68607 .41091 L .68377 .40972 L F
.409 0 0 r
.51115 .6027 m .512 .60302 L .5095 .60302 L F
.438 .092 .281 r
.55371 .58361 m .55141 .58199 L .55047 .58448 L F
.55371 .58361 m .55383 .58163 L .55141 .58199 L F
.548 .213 .353 r
.54774 .58503 m .55047 .58448 L .55141 .58199 L F
.136 .467 .892 r
.49554 .59599 m .49655 .5952 L .49359 .5962 L F
.49554 .59599 m .49735 .59665 L .49655 .5952 L F
.208 0 .249 r
.40221 .6031 m .40462 .60227 L .40471 .60017 L F
.18 .017 .409 r
.40471 .60017 m .40678 .59955 L .40697 .59674 L F
0 0 .155 r
.40471 .60017 m .40545 .60135 L .40678 .59955 L F
.40471 .60017 m .40462 .60227 L .40545 .60135 L F
.655 .259 .281 r
.46903 .62095 m .46806 .62312 L .46591 .621 L F
.576 .218 .325 r
.47175 .62077 m .46806 .62312 L .46903 .62095 L F
.809 .739 .786 r
.82835 .42932 m .8291 .43178 L .82618 .43123 L F
.778 .492 .501 r
.8291 .43178 m .82618 .43379 L .82618 .43123 L F
.8291 .43178 m .82954 .43417 L .82618 .43379 L F
.708 .636 .774 r
.83187 .42928 m .8291 .43178 L .82835 .42932 L F
0 0 0 r
.20272 .72349 m .20246 .72371 L .19978 .72433 L F
.756 .866 .435 r
.20314 .72219 m .20246 .72371 L .20272 .72349 L F
.583 .565 .799 r
.43533 .56985 m .43718 .57426 L .43868 .57293 L F
.327 .152 .484 r
.26115 .5765 m .2632 .57269 L .26091 .57275 L F
.915 .922 .804 r
.75962 .40829 m .75825 .41314 L .75944 .41154 L F
.399 .846 .755 r
.76948 .40467 m .76824 .40501 L .76876 .40366 L F
.76948 .40467 m .76889 .40477 L .76824 .40501 L F
.098 .296 .774 r
.53694 .56477 m .53834 .56635 L .53824 .5677 L F
0 0 .405 r
.53862 .5682 m .53824 .5677 L .53834 .56635 L F
.53862 .5682 m .5397 .57005 L .53824 .5677 L F
0 0 .062 r
.58726 .54851 m .58702 .55081 L .58587 .55232 L F
0 0 0 r
.58587 .55232 m .58607 .55262 L .58527 .5545 L F
.58587 .55232 m .58702 .55081 L .58607 .55262 L F
.348 .594 .938 r
.19715 .6287 m .19695 .62984 L .19305 .62645 L F
.007 0 0 r
.25613 .53964 m .25841 .53961 L .26063 .53953 L F
0 .284 .727 r
.26056 .53907 m .26063 .53953 L .25841 .53961 L F
.26056 .53907 m .26187 .54015 L .26063 .53953 L F
0 .197 .72 r
.45324 .62416 m .45473 .6274 L .45512 .62611 L F
.937 .666 .501 r
.45733 .62736 m .45512 .62611 L .45473 .6274 L F
.987 .741 .469 r
.81576 .4439 m .8158 .44723 L .81365 .44519 L F
.765 .947 .938 r
.81818 .44231 m .81576 .4439 L .81531 .44279 L F
.552 .446 .688 r
.81365 .44519 m .81199 .4417 L .81531 .44279 L F
.96 .941 .639 r
.81576 .4439 m .81365 .44519 L .81505 .44317 L F
.552 .446 .688 r
.81365 .44519 m .81519 .44592 L .81199 .4417 L F
.829 .471 .378 r
.81199 .4417 m .81394 .44428 L .81043 .44344 L F
.81394 .44428 m .81519 .44592 L .81329 .44493 L F
.81394 .44428 m .81329 .44493 L .81043 .44344 L F
.96 .941 .639 r
.81534 .44287 m .81505 .44317 L .81531 .44279 L F
.81576 .4439 m .81505 .44317 L .81534 .44287 L F
.212 .046 .427 r
.25815 .58828 m .25962 .58938 L .26028 .58763 L F
.25815 .58828 m .25783 .59078 L .25962 .58938 L F
.107 .457 .886 r
.79251 .39689 m .79021 .39493 L .79154 .39557 L F
.235 .539 .925 r
.79479 .39632 m .79251 .39689 L .79154 .39557 L F
.79479 .39632 m .79556 .39784 L .79251 .39689 L F
.518 .332 .568 r
.80131 .43485 m .80149 .43765 L .79895 .43842 L F
.552 .358 .571 r
.80412 .43684 m .80131 .43485 L .80402 .43418 L F
.80412 .43684 m .80149 .43765 L .80131 .43485 L F
0 0 .414 r
.5327 .59417 m .53356 .59605 L .53283 .59365 L F
.68 .679 .842 r
.74757 .42017 m .75128 .42245 L .75056 .41919 L F
.832 .8 .821 r
.75056 .41919 m .75128 .42245 L .75371 .41937 L F
.401 .837 .701 r
.21256 .70182 m .21675 .69975 L .21374 .70128 L F
0 0 0 r
.21799 .69837 m .21675 .69975 L .21914 .69657 L F
.698 .973 .762 r
.21591 .6998 m .21675 .69975 L .21799 .69837 L F
.21374 .70128 m .21617 .70005 L .21591 .6998 L F
.21617 .70005 m .21675 .69975 L .21591 .6998 L F
.21374 .70128 m .21799 .69837 L .21653 .69981 L F
.316 0 .058 r
.21653 .69981 m .21799 .69837 L .21885 .69947 L F
.21653 .69981 m .21885 .69947 L .21903 .6997 L F
.157 .685 .866 r
.21553 .69944 m .21653 .69981 L .21903 .6997 L F
.21486 .69939 m .2157 .6996 L .21553 .69944 L F
.2157 .6996 m .21653 .69981 L .21553 .69944 L F
.507 .309 .547 r
.29359 .58178 m .29356 .58428 L .29128 .58246 L F
.342 .321 .69 r
.29128 .58246 m .29356 .58428 L .29179 .58473 L F
.654 .329 .409 r
.41595 .58793 m .41842 .58533 L .41428 .58767 L F
.74 .345 .303 r
.83343 .43468 m .83207 .4364 L .83135 .43474 L F
.379 .094 .348 r
.83405 .43522 m .83207 .4364 L .83343 .43468 L F
.66 .555 .725 r
.83543 .43238 m .83567 .43502 L .83343 .43468 L F
.307 0 0 r
.83343 .43468 m .83567 .43502 L .83405 .43522 L F
.795 .64 .69 r
.50954 .53721 m .50783 .538 L .50651 .53664 L F
.648 .134 .008 r
.50651 .53664 m .50896 .53844 L .50954 .53721 L F
0 0 0 r
.50954 .53721 m .50896 .53844 L .51139 .53501 L F
.435 0 0 r
.25241 .55718 m .25002 .55714 L .2479 .55633 L F
.627 .094 0 r
.25241 .55718 m .25389 .55801 L .25002 .55714 L F
.299 .533 .909 r
.79888 .39888 m .79626 .39958 L .79556 .39784 L F
.79888 .39888 m .79945 .40062 L .79626 .39958 L F
0 0 0 r
.56569 .60357 m .56452 .60523 L .56257 .60589 L F
.56607 .60397 m .56569 .60357 L .56736 .60244 L F
.56607 .60397 m .56452 .60523 L .56569 .60357 L F
.435 .242 .519 r
.25158 .60042 m .25341 .60233 L .2534 .59962 L F
.25158 .60042 m .25127 .60295 L .25341 .60233 L F
0 0 0 r
.68729 .43348 m .69131 .43119 L .68967 .43257 L F
.128 0 0 r
.69131 .43119 m .69218 .43175 L .68967 .43257 L F
.69131 .43119 m .69361 .43093 L .69218 .43175 L F
.617 .05 0 r
.76709 .39251 m .76813 .39386 L .76607 .39384 L F
.76709 .39251 m .76973 .3945 L .76813 .39386 L F
.317 .781 .94 r
.25001 .5398 m .25218 .5395 L .25387 .53989 L F
.26 .756 .903 r
.25442 .53936 m .25387 .53989 L .25218 .5395 L F
.25442 .53936 m .25613 .53964 L .25387 .53989 L F
.917 .816 .731 r
.5958 .50315 m .59401 .50629 L .59638 .5068 L F
.921 .807 .717 r
.59638 .5068 m .59342 .50855 L .59481 .50976 L F
.59638 .5068 m .59401 .50629 L .59342 .50855 L F
.154 .071 .502 r
.5784 .58141 m .57857 .58395 L .57669 .58533 L F
0 0 .27 r
.57857 .58395 m .57675 .58757 L .57669 .58533 L F
0 0 .261 r
.65733 .40743 m .65868 .40588 L .65893 .4037 L F
0 0 0 r
.65733 .40743 m .65639 .40904 L .65868 .40588 L F
.203 0 0 r
.24422 .53875 m .2461 .53903 L .24799 .53907 L F
.481 0 0 r
.2461 .53903 m .25001 .5398 L .24799 .53907 L F
.045 0 .144 r
.44896 .57243 m .44832 .57523 L .44632 .57597 L F
.07 0 .153 r
.44991 .57414 m .44896 .57243 L .45134 .57197 L F
.44991 .57414 m .44832 .57523 L .44896 .57243 L F
.252 .281 .698 r
.4058 .63305 m .40641 .63656 L .40796 .63496 L F
.413 .398 .733 r
.40682 .63913 m .40796 .63496 L .40641 .63656 L F
.884 .891 .831 r
.66895 .43185 m .66537 .43372 L .66923 .43372 L F
.421 0 0 r
.47945 .61415 m .47893 .61446 L .4774 .61385 L F
.897 .928 .545 r
.47994 .6122 m .47893 .61446 L .47945 .61415 L F
0 .29 .662 r
.21704 .67908 m .21927 .68012 L .2212 .68111 L F
.776 .946 .933 r
.2212 .68111 m .22213 .67814 L .2232 .67837 L F
.2212 .68111 m .21927 .68012 L .22213 .67814 L F
.581 .635 .87 r
.2232 .67837 m .22228 .68007 L .2212 .68111 L F
.711 .765 .894 r
.45983 .57042 m .46132 .57278 L .46406 .57028 L F
.665 .701 .874 r
.72504 .40084 m .7247 .40109 L .7215 .40149 L F
.262 0 0 r
.49663 .53661 m .49925 .53726 L .50097 .53715 L F
.542 0 0 r
.49925 .53726 m .50275 .53873 L .50097 .53715 L F
.992 .802 .549 r
.50275 .53873 m .50368 .53671 L .50097 .53715 L F
.08 0 0 r
.41299 .6219 m .41119 .62304 L .40886 .62355 L F
0 0 0 r
.41539 .62152 m .41299 .6219 L .41484 .6206 L F
.967 .644 .312 r
.77377 .41504 m .77469 .41379 L .77362 .41304 L F
.627 .872 .988 r
.77362 .41304 m .77469 .41379 L .77691 .41265 L F
0 0 0 r
.77691 .41265 m .77469 .41379 L .77377 .41504 L F
.534 .338 .562 r
.475 .59158 m .47741 .59117 L .47735 .58823 L F
.475 .59158 m .47741 .59117 L .47735 .58823 L F
.522 .427 .688 r
.47918 .58766 m .47741 .59117 L .47735 .58823 L F
.67 .677 .848 r
.44394 .59644 m .45062 .5988 L .44686 .59661 L F
.128 .39 .843 r
.45062 .5988 m .44891 .59563 L .44686 .59661 L F
.45062 .5988 m .45103 .59852 L .44891 .59563 L F
0 .129 .586 r
.5019 .58227 m .5014 .58183 L .5 .5808 L F
.352 .176 .497 r
.5019 .58227 m .50159 .58482 L .50336 .58401 L F
.5019 .58227 m .50336 .58401 L .5014 .58183 L F
.445 0 0 r
.50967 .55315 m .51221 .55441 L .50919 .55342 L F
.654 .329 .409 r
.41595 .58793 m .41615 .5898 L .41842 .58533 L F
.504 .415 .688 r
.41842 .58533 m .42048 .58401 L .41714 .58445 L F
.587 .499 .722 r
.50479 .60008 m .50537 .60327 L .50279 .60375 L F
.601 .262 .367 r
.50537 .60327 m .50286 .60452 L .50279 .60375 L F
0 .067 .621 r
.42563 .64484 m .42648 .64751 L .4251 .64581 L F
.512 .221 .409 r
.42648 .64751 m .42396 .64797 L .4251 .64581 L F
.708 .341 .351 r
.46904 .57625 m .47117 .57839 L .47165 .57679 L F
.468 .145 .335 r
.80149 .43765 m .79861 .43975 L .79895 .43842 L F
.375 .091 .349 r
.40221 .6031 m .40424 .60492 L .40462 .60227 L F
.40221 .6031 m .40168 .60569 L .40424 .60492 L F
.735 .404 .421 r
.44308 .61116 m .44696 .61176 L .44491 .60879 L F
0 0 0 r
.42062 .58997 m .41777 .59381 L .41908 .59161 L F
.877 .902 .844 r
.21126 .69062 m .20751 .69298 L .21226 .69284 L F
.689 .258 .22 r
.20751 .69298 m .20943 .69491 L .21226 .69284 L F
0 0 .426 r
.21212 .69173 m .21226 .69284 L .21126 .69062 L F
.264 0 0 r
.21226 .69284 m .20943 .69491 L .21243 .69437 L F
.21226 .69284 m .21243 .69437 L .21212 .69173 L F
0 0 .426 r
.21126 .69062 m .21226 .69284 L .21212 .69173 L F
.871 .818 .794 r
.65531 .41574 m .65581 .41923 L .65726 .41683 L F
.65531 .41574 m .653 .41885 L .65581 .41923 L F
.897 .739 .677 r
.653 .41885 m .65428 .42238 L .65581 .41923 L F
.133 0 .021 r
.43397 .64834 m .43602 .64774 L .43689 .64606 L F
.415 .007 .154 r
.43689 .64606 m .43602 .64774 L .43877 .64713 L F
.298 .172 .535 r
.29474 .57484 m .29307 .57565 L .29214 .57369 L F
.303 .55 .92 r
.78422 .389 m .78233 .38875 L .78017 .38632 L F
.896 .628 .523 r
.66988 .40776 m .66681 .40794 L .66995 .40596 L F
.66988 .40776 m .6699 .41022 L .66681 .40794 L F
0 0 .101 r
.23553 .6124 m .23601 .61339 L .23564 .61086 L F
.23553 .6124 m .23472 .61477 L .23601 .61339 L F
.99 .792 .543 r
.16415 .60393 m .16541 .60476 L .16421 .60363 L F
0 .285 .692 r
.16541 .60476 m .16668 .60559 L .16454 .60446 L F
.598 .632 .856 r
.16421 .60363 m .16408 .60581 L .15942 .60129 L F
.99 .792 .543 r
.16358 .60692 m .16541 .60476 L .16415 .60393 L F
0 .285 .692 r
.16541 .60476 m .16696 .60574 L .16668 .60559 L F
.471 .018 .094 r
.80684 .43145 m .80896 .4327 L .80644 .43337 L F
.80684 .43145 m .80961 .43145 L .80896 .4327 L F
.888 .87 .815 r
.41428 .59813 m .41616 .60178 L .41572 .59934 L F
.641 .542 .727 r
.41198 .60134 m .41575 .60424 L .41616 .60178 L F
.552 .306 .496 r
.4805 .57562 m .47763 .5787 L .47794 .57614 L F
.801 .447 .387 r
.77663 .41487 m .7801 .41409 L .77691 .41265 L F
.77663 .41487 m .78111 .41606 L .7801 .41409 L F
.238 .561 .936 r
.19162 .74465 m .18865 .74334 L .19177 .74212 L F
.211 0 0 r
.18935 .7437 m .19177 .74212 L .18865 .74334 L F
.534 .536 .803 r
.17648 .6451 m .17738 .64143 L .17486 .64186 L F
.17648 .6451 m .17866 .64479 L .17738 .64143 L F
.275 0 0 r
.17808 .54779 m .18225 .54581 L .18013 .54667 L F
.271 .344 .755 r
.16801 .66467 m .16967 .6657 L .1686 .66646 L F
.453 .861 .697 r
.1686 .66646 m .16967 .6657 L .1678 .66685 L F
.445 .205 .454 r
.26343 .62723 m .26297 .62968 L .2608 .63019 L F
.446 .233 .495 r
.26547 .62666 m .26297 .62968 L .26343 .62723 L F
.377 .056 .289 r
.42902 .59712 m .43168 .59668 L .43182 .59548 L F
.536 .353 .581 r
.42908 .59942 m .43168 .59668 L .42902 .59712 L F
.409 .257 .562 r
.28954 .59611 m .28763 .59433 L .28983 .59365 L F
.28954 .59611 m .28756 .59687 L .28763 .59433 L F
.351 .615 .95 r
.28405 .54559 m .28361 .54728 L .28189 .54537 L F
.28405 .54559 m .28615 .54782 L .28361 .54728 L F
.673 .202 .126 r
.6684 .40446 m .67096 .40636 L .67199 .40497 L F
.769 .322 .189 r
.67199 .40497 m .67096 .40636 L .67309 .40655 L F
.697 .589 .731 r
.79218 .42508 m .79472 .4219 L .79255 .42295 L F
0 0 0 r
.54592 .51326 m .54457 .51462 L .54311 .51599 L F
.496 .835 .551 r
.54457 .51462 m .54176 .51714 L .54311 .51599 L F
0 0 .132 r
.5472 .51194 m .54592 .51326 L .54801 .50994 L F
0 0 0 r
.54645 .51345 m .54592 .51326 L .5472 .51194 L F
.54645 .51345 m .54457 .51462 L .54592 .51326 L F
.156 .691 .695 r
.48806 .58352 m .48681 .58393 L .48857 .58433 L F
.295 .593 .946 r
.48857 .58433 m .48924 .58308 L .48806 .58352 L F
.69 .517 .649 r
.49106 .58166 m .49119 .58428 L .48857 .58433 L F
.596 .202 .266 r
.49119 .58428 m .49086 .58595 L .48857 .58433 L F
.747 .404 .403 r
.49086 .58595 m .48924 .58308 L .48857 .58433 L F
.49086 .58595 m .48806 .58352 L .48924 .58308 L F
.49086 .58595 m .48649 .586 L .48806 .58352 L F
.463 .185 .406 r
.48649 .586 m .48917 .58315 L .48806 .58352 L F
.48917 .58315 m .48924 .58308 L .48806 .58352 L F
.156 .691 .695 r
.48806 .58352 m .48652 .58386 L .48681 .58393 L F
.48806 .58352 m .4848 .58424 L .48652 .58386 L F
.905 .837 .769 r
.76325 .42237 m .76065 .42394 L .76181 .4216 L F
.76325 .42237 m .76129 .42544 L .76065 .42394 L F
.933 .897 .769 r
.76424 .42018 m .76325 .42237 L .76181 .4216 L F
0 0 0 r
.21509 .67848 m .21429 .68061 L .21508 .67978 L F
.251 0 .13 r
.52968 .51549 m .53196 .51459 L .5328 .51237 L F
0 0 0 r
.53196 .51459 m .53487 .51164 L .5328 .51237 L F
.112 .266 .743 r
.49894 .60021 m .50144 .60294 L .5013 .59966 L F
.134 .68 .793 r
.20927 .54009 m .21146 .53988 L .2131 .53992 L F
.427 .844 .963 r
.21146 .53988 m .21549 .53975 L .2131 .53992 L F
.462 .236 .484 r
.26842 .62129 m .26809 .62369 L .26588 .6242 L F
.489 .26 .492 r
.27033 .62321 m .26842 .62129 L .27072 .62083 L F
.27033 .62321 m .26809 .62369 L .26842 .62129 L F
.663 .21 .167 r
.45152 .58572 m .45397 .58718 L .45169 .5853 L F
.597 .268 .382 r
.45169 .5853 m .45397 .58718 L .45473 .58565 L F
0 0 .348 r
.26149 .56116 m .26276 .55772 L .26007 .55765 L F
.394 .193 .485 r
.26276 .55772 m .2626 .56069 L .26487 .55949 L F
0 0 .348 r
.26263 .55808 m .26274 .55804 L .26276 .55772 L F
.574 .1 .093 r
.26007 .55765 m .26313 .55801 L .26276 .55772 L F
.264 .713 .958 r
.26103 .557 m .26299 .55794 L .26007 .55765 L F
.26299 .55794 m .26313 .55801 L .26289 .55798 L F
.26299 .55794 m .26289 .55798 L .26007 .55765 L F
0 0 .348 r
.26149 .56116 m .2626 .56069 L .26274 .55804 L F
.26149 .56116 m .26274 .55804 L .26263 .55808 L F
.435 .382 .701 r
.26138 .56367 m .2626 .56069 L .26149 .56116 L F
.545 .3 .496 r
.41714 .58445 m .42048 .58401 L .42009 .58247 L F
.455 .009 .099 r
.68948 .41001 m .68607 .41091 L .68894 .41197 L F
.568 .325 .508 r
.69257 .41237 m .68948 .41001 L .68894 .41197 L F
.69257 .41237 m .69212 .41006 L .68948 .41001 L F
.013 .23 .738 r
.23634 .61829 m .23698 .61691 L .23472 .61477 L F
.308 .09 .411 r
.23634 .61829 m .23808 .61967 L .23698 .61691 L F
.23634 .61829 m .23592 .62064 L .23808 .61967 L F
.181 .353 .8 r
.16164 .61694 m .16096 .61895 L .16034 .61675 L F
.457 .666 .952 r
.16164 .61694 m .16433 .61963 L .16096 .61895 L F
.428 .313 .62 r
.29356 .58428 m .29187 .5872 L .29179 .58473 L F
.578 .365 .555 r
.46865 .57819 m .47117 .57839 L .46904 .57625 L F
.385 .784 .986 r
.44696 .61176 m .45118 .61222 L .44874 .61176 L F
.597 .374 .549 r
.44748 .62126 m .44968 .62387 L .44744 .62318 L F
.666 .757 .918 r
.7833 .41058 m .78487 .40747 L .78225 .40808 L F
.7833 .41058 m .78603 .40977 L .78487 .40747 L F
.657 .328 .404 r
.51292 .54281 m .51389 .5451 L .51514 .54272 L F
.679 .626 .789 r
.51514 .54272 m .51771 .54308 L .51684 .53945 L F
.09 0 .089 r
.51514 .54272 m .51638 .5437 L .51771 .54308 L F
.51514 .54272 m .51389 .5451 L .51638 .5437 L F
.464 .217 .454 r
.26769 .62608 m .26588 .6242 L .26809 .62369 L F
.26769 .62608 m .26547 .62666 L .26588 .6242 L F
.521 .474 .744 r
.43028 .63736 m .4291 .63946 L .42763 .63822 L F
.43028 .63736 m .42968 .63843 L .4291 .63946 L F
.59 .817 .986 r
.42763 .63822 m .42968 .63843 L .43028 .63736 L F
.42968 .63843 m .43135 .63861 L .43028 .63736 L F
.521 .474 .744 r
.43028 .63736 m .43022 .63749 L .42968 .63843 L F
.59 .817 .986 r
.42968 .63843 m .4291 .63946 L .43135 .63861 L F
.521 .474 .744 r
.43022 .63749 m .42866 .64077 L .4291 .63946 L F
.59 .817 .986 r
.42763 .63822 m .4291 .63946 L .42968 .63843 L F
.363 .306 .659 r
.29427 .55307 m .29215 .5583 L .29114 .55446 L F
.29427 .55307 m .29387 .55756 L .29215 .5583 L F
.354 .285 .64 r
.29387 .55756 m .29422 .56014 L .29215 .5583 L F
0 0 .476 r
.21978 .6959 m .21914 .69657 L .21823 .69282 L F
0 0 0 r
.21799 .69837 m .21914 .69657 L .21978 .6959 L F
.784 .756 .828 r
.17136 .67256 m .17122 .67546 L .17015 .67527 L F
.217 .697 .934 r
.17122 .67546 m .16889 .67526 L .17015 .67527 L F
.784 .756 .828 r
.17136 .67256 m .17015 .67527 L .16932 .67218 L F
.217 .697 .934 r
.17122 .67546 m .17101 .67477 L .16889 .67526 L F
.522 .531 .806 r
.17136 .67256 m .17294 .67549 L .17122 .67546 L F
.217 .697 .934 r
.17122 .67546 m .17294 .67549 L .17101 .67477 L F
.746 .655 .76 r
.72015 .39741 m .72165 .39899 L .71794 .39858 L F
.749 .655 .757 r
.72401 .39599 m .72165 .39899 L .72015 .39741 L F
.16 .699 .743 r
.50227 .52275 m .50624 .52216 L .5039 .52284 L F
.558 .523 .772 r
.15211 .58141 m .15302 .58492 L .15081 .58521 L F
.511 .744 .979 r
.15081 .58521 m .15263 .58389 L .14899 .5865 L F
.15081 .58521 m .15302 .58492 L .15263 .58389 L F
.434 .174 .418 r
.26029 .58496 m .26237 .58446 L .26294 .58218 L F
.445 .485 .807 r
.26165 .57876 m .26294 .58218 L .2646 .58132 L F
.433 .244 .523 r
.26237 .58446 m .2646 .58132 L .26294 .58218 L F
.583 .018 0 r
.2479 .55633 m .24616 .55655 L .2441 .55512 L F
.425 0 0 r
.2479 .55633 m .25002 .55714 L .24616 .55655 L F
.206 0 .019 r
.44749 .57719 m .44632 .57597 L .44832 .57523 L F
.453 .556 .87 r
.15853 .61394 m .15754 .61604 L .15704 .61511 L F
.15853 .61394 m .16034 .61675 L .15754 .61604 L F
.631 .544 .737 r
.7716 .42873 m .77485 .43007 L .77342 .42765 L F
.966 .725 .523 r
.77103 .43137 m .7716 .42873 L .76957 .42796 L F
.409 .425 .765 r
.79377 .41313 m .79477 .40915 L .79208 .40989 L F
.79377 .41313 m .79569 .41293 L .79477 .40915 L F
.593 .671 .894 r
.45659 .61685 m .45956 .6213 L .46095 .6199 L F
.955 .707 .521 r
.45956 .6213 m .46054 .62054 L .46095 .6199 L F
.45956 .6213 m .45752 .62168 L .46054 .62054 L F
.45956 .6213 m .45956 .6239 L .45752 .62168 L F
.802 .915 .916 r
.16743 .61829 m .16433 .61963 L .16793 .61887 L F
0 0 0 r
.16793 .61887 m .16966 .61768 L .16743 .61829 L F
.56 .745 .964 r
.17158 .64101 m .17269 .64236 L .17486 .64186 L F
.342 0 .125 r
.17977 .5633 m .1759 .566 L .17743 .56383 L F
.554 .417 .648 r
.42396 .64797 m .42194 .65142 L .42109 .64898 L F
.417 .198 .47 r
.20394 .71083 m .20532 .71114 L .20577 .70866 L F
.058 0 0 r
.20849 .7079 m .20951 .70793 L .21159 .70651 L F
.992 .87 .604 r
.57761 .53024 m .57863 .53131 L .57786 .53363 L F
.797 .458 .414 r
.18276 .73794 m .18441 .73819 L .18382 .73643 L F
.438 .264 .546 r
.18382 .73643 m .18598 .73484 L .18448 .73561 L F
.18382 .73643 m .18441 .73819 L .18598 .73484 L F
.29 .592 .947 r
.56139 .57727 m .56066 .57837 L .55871 .57783 L F
.56139 .57727 m .56248 .57882 L .56066 .57837 L F
.784 .282 0 r
.16966 .61768 m .17331 .621 L .17166 .62042 L F
0 0 .048 r
.79543 .42028 m .79472 .4219 L .79715 .41884 L F
.817 1 .827 r
.19178 .74084 m .19426 .73998 L .19177 .74212 L F
.717 .239 .114 r
.19441 .74158 m .19426 .73998 L .19178 .74084 L F
.474 .742 .987 r
.27053 .54077 m .27 .54246 L .26824 .54147 L F
.27053 .54077 m .2722 .54216 L .27 .54246 L F
.174 .163 .604 r
.49799 .53082 m .49944 .52709 L .50081 .52809 L F
.49799 .53082 m .50025 .52908 L .49944 .52709 L F
.52 .257 .456 r
.50201 .5304 m .50119 .53251 L .49799 .53082 L F
.292 .374 .776 r
.49799 .53082 m .50119 .53251 L .50025 .52908 L F
.993 .788 .523 r
.5874 .54143 m .58751 .54383 L .58902 .53999 L F
.842 .978 .681 r
.58871 .53951 m .58902 .53999 L .59052 .53778 L F
.864 .963 .631 r
.58871 .53951 m .5874 .54143 L .58902 .53999 L F
.799 .386 0 r
.76573 .37893 m .76577 .37819 L .76322 .37703 L F
.76573 .37893 m .76669 .38011 L .76577 .37819 L F
.972 .902 .69 r
.56891 .56674 m .56805 .5701 L .5669 .56819 L F
.989 .752 .37 r
.56805 .5701 m .56686 .57178 L .5669 .56819 L F
.56805 .5701 m .56798 .57288 L .56686 .57178 L F
.78 .304 0 r
.51016 .53961 m .5114 .54187 L .51292 .54281 L F
.941 .586 .307 r
.5114 .54187 m .51389 .5451 L .51292 .54281 L F
.497 .813 1 r
.1844 .64705 m .1865 .64808 L .18838 .64754 L F
.795 .6 .639 r
.74624 .40428 m .74375 .40615 L .7439 .40395 L F
.74624 .40428 m .74663 .40687 L .74375 .40615 L F
.539 .652 .908 r
.4376 .60758 m .43789 .60867 L .43974 .60725 L F
.595 .528 .749 r
.43821 .6119 m .43974 .60725 L .43789 .60867 L F
.748 .92 .558 r
.45385 .58925 m .45296 .59127 L .45527 .58775 L F
.752 .928 .575 r
.45296 .59127 m .45151 .59272 L .45385 .58925 L F
.578 .584 .822 r
.45673 .5942 m .45296 .59127 L .45554 .59107 L F
.162 0 0 r
.45296 .59127 m .45404 .59191 L .45554 .59107 L F
.45296 .59127 m .45151 .59272 L .45404 .59191 L F
.923 .751 .651 r
.59767 .49773 m .59644 .49449 L .59669 .49748 L F
.935 .903 .768 r
.59587 .50071 m .59767 .49773 L .59669 .49748 L F
.492 .188 .379 r
.55898 .49146 m .56156 .49098 L .56178 .48851 L F
.556 .361 .573 r
.56156 .49098 m .56416 .4878 L .56178 .48851 L F
.116 0 .189 r
.14549 .5664 m .14791 .56359 L .14616 .56412 L F
.407 .232 .528 r
.47893 .61446 m .47684 .61729 L .4774 .61385 L F
.648 .65 .838 r
.45925 .5936 m .45673 .5942 L .45554 .59107 L F
.751 .657 .757 r
.45925 .5936 m .45668 .59677 L .45673 .5942 L F
.668 .618 .79 r
.66565 .4444 m .66201 .44292 L .66477 .44213 L F
.704 .686 .83 r
.66785 .44308 m .66565 .4444 L .66477 .44213 L F
.266 0 .252 r
.42009 .58247 m .42193 .58212 L .42427 .5789 L F
.343 .18 .51 r
.42009 .58247 m .42048 .58401 L .42193 .58212 L F
.909 .634 .51 r
.57824 .50979 m .57544 .50632 L .57888 .50701 L F
.457 .857 .67 r
.51771 .54308 m .51638 .5437 L .51959 .54168 L F
.902 .741 .672 r
.58016 .51299 m .57718 .51487 L .57727 .51225 L F
.58016 .51299 m .57969 .51557 L .57718 .51487 L F
.369 .156 .453 r
.21285 .68424 m .21448 .68499 L .21429 .68061 L F
0 0 .346 r
.21429 .68061 m .21586 .68213 L .21508 .67978 L F
.21429 .68061 m .21448 .68499 L .21586 .68213 L F
.678 .228 .174 r
.51141 .53314 m .51516 .53356 L .51502 .53102 L F
.911 .867 .782 r
.75502 .41513 m .75825 .41314 L .75728 .41195 L F
.75502 .41513 m .75622 .41645 L .75825 .41314 L F
.915 .922 .804 r
.75962 .40829 m .75728 .41195 L .75825 .41314 L F
.986 .883 .636 r
.51743 .60502 m .51847 .60591 L .5193 .60374 L F
.381 .808 .63 r
.70447 .42688 m .70773 .42498 L .70769 .42501 L F
.032 0 0 r
.70773 .42498 m .70881 .42349 L .70769 .42501 L F
.70773 .42498 m .71074 .4227 L .70881 .42349 L F
.821 .818 .846 r
.75259 .4177 m .75056 .41919 L .75371 .41937 L F
.835 .821 .835 r
.75259 .4177 m .75371 .41937 L .75622 .41645 L F
.296 0 0 r
.50885 .53178 m .51148 .53149 L .5135 .53193 L F
.535 .651 .91 r
.80136 .40081 m .80078 .40378 L .79945 .40062 L F
.80136 .40081 m .80326 .40327 L .80078 .40378 L F
.25 0 0 r
.71391 .39927 m .71177 .39897 L .71127 .40009 L F
.71391 .39927 m .71461 .39855 L .71177 .39897 L F
.056 0 0 r
.47251 .56495 m .47156 .56529 L .46829 .56531 L F
.688 .158 0 r
.46939 .55817 m .47333 .56007 L .471 .56078 L F
.956 .759 .597 r
.47186 .56004 m .47239 .56491 L .47333 .56007 L F
.632 .168 .133 r
.47451 .56399 m .47236 .56493 L .47251 .56495 L F
.47236 .56493 m .47156 .56529 L .472 .56513 L F
.47236 .56493 m .472 .56513 L .47251 .56495 L F
0 0 .234 r
.47333 .56007 m .47317 .56092 L .47403 .56084 L F
.47317 .56092 m .47281 .56289 L .47389 .56107 L F
.47317 .56092 m .47389 .56107 L .47403 .56084 L F
.956 .759 .597 r
.47239 .56491 m .47243 .56489 L .47333 .56007 L F
.432 .484 .813 r
.47419 .56056 m .47389 .56107 L .47186 .56004 L F
.47403 .56084 m .4744 .56132 L .47389 .56107 L F
0 0 .234 r
.47333 .56007 m .47403 .56084 L .47575 .55967 L F
.432 .484 .813 r
.47419 .56056 m .47427 .56083 L .47403 .56084 L F
.47427 .56083 m .4744 .56132 L .47403 .56084 L F
0 0 .234 r
.47403 .56084 m .47448 .56082 L .47575 .55967 L F
.572 .938 .822 r
.47469 .56076 m .4744 .56132 L .47457 .56079 L F
.994 .769 .485 r
.47469 .56076 m .47486 .56104 L .47575 .55967 L F
.47486 .56104 m .47562 .56232 L .47569 .56088 L F
.47486 .56104 m .47569 .56088 L .47575 .55967 L F
.572 .938 .822 r
.47482 .56105 m .4744 .56132 L .47469 .56076 L F
.47482 .56105 m .47431 .56115 L .4744 .56132 L F
.47566 .56051 m .47482 .56105 L .47469 .56076 L F
.994 .769 .485 r
.47529 .56203 m .47562 .56232 L .47469 .56076 L F
.497 .341 .599 r
.47575 .55967 m .47818 .56163 L .47808 .55872 L F
.518 .338 .577 r
.47575 .55967 m .47562 .56232 L .47818 .56163 L F
.572 .938 .822 r
.47713 .55956 m .47566 .56051 L .47591 .55673 L F
0 0 .234 r
.47448 .56082 m .47469 .56076 L .47575 .55967 L F
.572 .938 .822 r
.47566 .56051 m .47457 .56079 L .47591 .55673 L F
.47713 .55956 m .47431 .56115 L .47482 .56105 L F
.994 .769 .485 r
.47431 .56115 m .47529 .56203 L .47469 .56076 L F
0 0 .234 r
.47448 .56082 m .47464 .56081 L .47469 .56076 L F
.511 .538 .82 r
.47591 .55673 m .47457 .56079 L .47326 .5571 L F
.47457 .56079 m .4744 .56132 L .47427 .56083 L F
.47457 .56079 m .47427 .56083 L .47326 .5571 L F
0 0 .234 r
.47427 .56083 m .47431 .56115 L .47464 .56081 L F
.47403 .56084 m .47404 .56085 L .47427 .56083 L F
.47404 .56085 m .47431 .56115 L .47427 .56083 L F
.342 .314 .682 r
.47431 .56115 m .47389 .56107 L .4744 .56132 L F
0 0 .234 r
.47403 .56084 m .47243 .56489 L .47431 .56115 L F
.47281 .56289 m .47243 .56489 L .47403 .56084 L F
.342 .314 .682 r
.47431 .56115 m .47186 .56004 L .47389 .56107 L F
.688 .158 0 r
.46939 .55817 m .47186 .56004 L .47333 .56007 L F
.432 .484 .813 r
.47326 .5571 m .47419 .56056 L .47186 .56004 L F
.632 .168 .133 r
.47462 .56393 m .47367 .56435 L .47451 .56399 L F
.47367 .56435 m .47228 .56497 L .47451 .56399 L F
.47228 .56497 m .47156 .56529 L .47226 .56498 L F
.47228 .56497 m .47226 .56498 L .47451 .56399 L F
0 0 .234 r
.47243 .56489 m .4725 .56486 L .47431 .56115 L F
.342 .314 .682 r
.47431 .56115 m .4725 .56486 L .47186 .56004 L F
.632 .168 .133 r
.47462 .56393 m .47337 .56545 L .47289 .56541 L F
.47228 .56497 m .47289 .56541 L .47156 .56529 L F
.47462 .56393 m .47289 .56541 L .47228 .56497 L F
0 0 .234 r
.47243 .56489 m .47241 .56505 L .4725 .56486 L F
.956 .759 .597 r
.47239 .56491 m .47241 .56505 L .47243 .56489 L F
.342 .314 .682 r
.4725 .56486 m .47241 .56505 L .47239 .56491 L F
.4725 .56486 m .47239 .56491 L .47186 .56004 L F
.986 .897 .634 r
.7647 .41547 m .76424 .42018 L .76334 .41915 L F
.933 .897 .769 r
.76424 .42018 m .76181 .4216 L .76334 .41915 L F
.455 .187 .418 r
.2608 .63019 m .26029 .63301 L .25788 .63346 L F
.388 .129 .396 r
.26237 .63235 m .2608 .63019 L .26297 .62968 L F
.26237 .63235 m .26029 .63301 L .2608 .63019 L F
.536 .359 .588 r
.67146 .4312 m .67445 .43091 L .67516 .4318 L F
.727 .945 .953 r
.67723 .43012 m .67516 .4318 L .67445 .43091 L F
.708 .93 .963 r
.71182 .42064 m .71074 .4227 L .71255 .42143 L F
.774 .996 .809 r
.70881 .42349 m .71074 .4227 L .71182 .42064 L F
.224 .741 .855 r
.47978 .55885 m .48219 .55843 L .48324 .55869 L F
.399 0 0 r
.48219 .55843 m .48613 .55919 L .48324 .55869 L F
.455 .848 .979 r
.22401 .5541 m .22621 .55354 L .2241 .55321 L F
.532 .003 0 r
.22842 .55353 m .22648 .55445 L .2241 .55321 L F
.719 .981 .774 r
.22904 .55204 m .22707 .55389 L .22842 .55353 L F
.22707 .55389 m .22648 .55445 L .22842 .55353 L F
.237 0 0 r
.22807 .55293 m .22977 .55317 L .22842 .55353 L F
.22977 .55317 m .23095 .55334 L .22842 .55353 L F
.584 .354 .534 r
.48172 .58185 m .48457 .58173 L .4842 .57895 L F
.516 .644 .913 r
.48386 .57789 m .4842 .57895 L .48643 .57762 L F
.54 .324 .535 r
.4842 .57895 m .48709 .58114 L .48643 .57762 L F
.4842 .57895 m .48457 .58173 L .48709 .58114 L F
.738 .747 .859 r
.19415 .73252 m .19612 .73559 L .19217 .73522 L F
.038 .601 .791 r
.19217 .73522 m .19612 .73559 L .19413 .73526 L F
.068 .371 .838 r
.19653 .73436 m .19612 .73559 L .19415 .73252 L F
.603 .933 .957 r
.19413 .73526 m .19612 .73559 L .19653 .73436 L F
.215 0 0 r
.22561 .62775 m .22262 .62945 L .22493 .62916 L F
.319 0 .233 r
.25281 .63647 m .25219 .63829 L .24995 .63872 L F
.439 .094 .282 r
.25415 .63792 m .25281 .63647 L .2551 .63599 L F
.25415 .63792 m .25219 .63829 L .25281 .63647 L F
.604 .822 .983 r
.66477 .44213 m .66201 .44292 L .66062 .44151 L F
.152 0 .136 r
.55033 .50907 m .5472 .51194 L .54801 .50994 L F
.313 .192 .55 r
.26569 .5694 m .26694 .56639 L .269 .5671 L F
.26569 .5694 m .26746 .56872 L .26694 .56639 L F
.86 .544 .022 r
.26694 .56639 m .26746 .56872 L .26685 .56684 L F
.578 .607 .846 r
.26488 .56447 m .26705 .56586 L .26694 .56639 L F
0 .156 .69 r
.26488 .56447 m .26694 .56639 L .26629 .56513 L F
.86 .544 .022 r
.26694 .56639 m .26685 .56684 L .26629 .56513 L F
.578 .607 .846 r
.26705 .56586 m .269 .5671 L .26694 .56639 L F
0 0 0 r
.16456 .5537 m .16756 .55175 L .16547 .55231 L F
.627 .804 .968 r
.21051 .6326 m .20829 .63344 L .2066 .63213 L F
.694 .266 .227 r
.49703 .56605 m .50074 .5668 L .49974 .56559 L F
.586 .267 .395 r
.49974 .56559 m .50074 .5668 L .50309 .56637 L F
.629 .931 .969 r
.71603 .41941 m .71914 .41892 L .71795 .41783 L F
.736 .774 .884 r
.71914 .41892 m .72067 .4152 L .71795 .41783 L F
.71914 .41892 m .72214 .41696 L .72067 .4152 L F
.751 .438 .454 r
.5473 .59223 m .54693 .59389 L .54527 .59147 L F
.388 0 0 r
.5473 .59223 m .54922 .593 L .54693 .59389 L F
.5473 .59223 m .55062 .59206 L .54922 .593 L F
.531 .628 .892 r
.80579 .4029 m .80407 .40539 L .80326 .40327 L F
.59 .71 .926 r
.80579 .4029 m .80639 .40482 L .80407 .40539 L F
.41 .164 .427 r
.44947 .67567 m .4491 .67785 L .45166 .67512 L F
.44947 .67567 m .4491 .67785 L .45166 .67512 L F
.819 .845 .868 r
.75824 .42533 m .75748 .42855 L .75625 .42752 L F
.67 .264 0 r
.75748 .42855 m .75803 .42976 L .75625 .42752 L F
.75748 .42855 m .75896 .43126 L .75803 .42976 L F
.331 0 0 r
.43611 .63334 m .43901 .63406 L .43981 .63355 L F
0 .347 .79 r
.43901 .63406 m .44043 .63526 L .43981 .63355 L F
.837 .993 .854 r
.46368 .60709 m .4621 .60877 L .46283 .60945 L F
.167 0 .204 r
.46368 .60709 m .46222 .60868 L .4621 .60877 L F
.177 0 .254 r
.4621 .60877 m .46125 .60946 L .46283 .60945 L F
.167 0 .204 r
.46222 .60868 m .46116 .60984 L .4621 .60877 L F
.177 0 .254 r
.4621 .60877 m .46019 .60946 L .46125 .60946 L F
.506 .108 .219 r
.49927 .60859 m .49604 .60882 L .49761 .60924 L F
.841 .705 .712 r
.54184 .5906 m .54527 .59147 L .54316 .59023 L F
.54184 .5906 m .54428 .59421 L .54527 .59147 L F
.845 .384 .076 r
.54527 .59147 m .54498 .59281 L .54316 .59023 L F
.54527 .59147 m .54693 .59389 L .54498 .59281 L F
.603 .603 .824 r
.29114 .55446 m .28733 .55132 L .28937 .55123 L F
.646 .677 .865 r
.29386 .55278 m .29114 .55446 L .28937 .55123 L F
.262 0 .273 r
.29386 .55278 m .29427 .55307 L .29114 .55446 L F
.467 .515 .824 r
.80967 .40572 m .80738 .40778 L .80639 .40482 L F
.597 .58 .805 r
.80967 .40572 m .80811 .41022 L .80738 .40778 L F
.842 .978 .681 r
.58871 .53951 m .59052 .53778 L .59022 .53595 L F
.535 .415 .663 r
.24631 .5543 m .2441 .55512 L .2437 .55239 L F
.205 0 .007 r
.55674 .49222 m .55603 .49343 L .55898 .49146 L F
.831 .866 .871 r
.42554 .63675 m .4211 .63842 L .422 .63582 L F
0 0 .318 r
.53361 .60005 m .53434 .60119 L .53381 .59868 L F
.53361 .60005 m .53434 .6024 L .53434 .60119 L F
.718 .61 .736 r
.20532 .71114 m .20849 .7079 L .20577 .70866 L F
.497 .323 .576 r
.83792 .43143 m .83567 .43502 L .83543 .43238 L F
.83792 .43143 m .83839 .43419 L .83567 .43502 L F
.304 .798 .798 r
.83567 .43502 m .83839 .43419 L .83405 .43522 L F
.59 .534 .76 r
.50904 .60482 m .50976 .60694 L .51221 .60621 L F
.837 .988 .717 r
.50999 .59252 m .50952 .5946 L .50804 .59518 L F
0 0 .53 r
.52361 .56918 m .52156 .5661 L .52334 .56707 L F
.426 .236 .518 r
.28535 .60004 m .28518 .60256 L .28311 .60317 L F
.444 .281 .565 r
.28518 .60256 m .28515 .60514 L .28311 .60317 L F
.464 .281 .547 r
.28311 .60317 m .28515 .60514 L .28306 .60563 L F
0 .019 .561 r
.53457 .60867 m .53427 .60534 L .53452 .60619 L F
0 0 0 r
.56257 .60589 m .56186 .60618 L .55945 .60684 L F
.56452 .60523 m .56186 .60618 L .56257 .60589 L F
.312 .683 .977 r
.23185 .55504 m .23216 .55403 L .23095 .55334 L F
.384 .748 .992 r
.26138 .56367 m .26488 .56447 L .26327 .56336 L F
0 .156 .69 r
.26488 .56447 m .26629 .56513 L .26327 .56336 L F
.453 .625 .926 r
.72216 .39366 m .72401 .39599 L .72237 .39444 L F
.749 .655 .757 r
.72401 .39599 m .72015 .39741 L .72237 .39444 L F
.681 .652 .815 r
.72508 .39168 m .72401 .39599 L .72216 .39366 L F
.72508 .39168 m .72679 .39514 L .72401 .39599 L F
.829 .511 .45 r
.52228 .52185 m .52601 .52482 L .52603 .52232 L F
.52228 .52185 m .5229 .52454 L .52601 .52482 L F
.514 .553 .833 r
.52311 .52683 m .52601 .52482 L .5229 .52454 L F
.52311 .52683 m .52517 .52618 L .52601 .52482 L F
.714 .601 .729 r
.52603 .52232 m .52601 .52482 L .52861 .52169 L F
.502 .011 .022 r
.52517 .52618 m .52893 .52629 L .52601 .52482 L F
0 0 0 r
.16053 .57297 m .15912 .57531 L .1577 .57569 L F
.234 0 .096 r
.16132 .57441 m .16053 .57297 L .16257 .57232 L F
.16132 .57441 m .15912 .57531 L .16053 .57297 L F
.694 .179 0 r
.77105 .38653 m .77237 .38733 L .7707 .3865 L F
.77105 .38653 m .77376 .38904 L .77237 .38733 L F
.806 .706 .755 r
.46665 .56735 m .46406 .57028 L .46732 .57057 L F
.653 .608 .791 r
.46665 .56735 m .46732 .57057 L .47014 .57019 L F
0 0 0 r
.58771 .54661 m .58702 .55081 L .58726 .54851 L F
.909 .634 .51 r
.57824 .50979 m .57557 .50886 L .57544 .50632 L F
.915 .693 .587 r
.57824 .50979 m .57536 .51138 L .57557 .50886 L F
.57824 .50979 m .57727 .51225 L .57536 .51138 L F
.734 .437 .477 r
.58227 .4794 m .58448 .48161 L .58569 .47963 L F
.757 .529 .588 r
.58448 .48161 m .58828 .47973 L .58569 .47963 L F
.04 0 .103 r
.79334 .44345 m .79312 .44532 L .79079 .44637 L F
0 0 0 r
.79312 .44532 m .79028 .44785 L .79079 .44637 L F
.698 .233 .142 r
.43753 .65055 m .4361 .65045 L .43397 .64834 L F
.362 .275 .622 r
.43397 .64834 m .4361 .65045 L .43602 .64774 L F
.763 .955 .936 r
.74617 .39856 m .74707 .39652 L .7479 .39796 L F
.719 .903 .961 r
.75179 .39556 m .7479 .39796 L .74707 .39652 L F
.468 .38 .673 r
.4161 .62447 m .41659 .62736 L .41963 .62629 L F
.658 .752 .919 r
.22422 .67232 m .22611 .67243 L .22429 .67144 L F
.876 .56 .447 r
.22603 .67472 m .22415 .67432 L .22611 .67243 L F
.705 .533 .653 r
.22836 .67182 m .22603 .67472 L .22611 .67243 L F
0 0 0 r
.22611 .67243 m .2262 .67341 L .22836 .67182 L F
.22611 .67243 m .22415 .67432 L .2262 .67341 L F
.373 0 0 r
.19491 .55802 m .19293 .55949 L .1909 .55937 L F
.63 .095 0 r
.19491 .55802 m .19514 .55885 L .19293 .55949 L F
.19554 .55868 m .19685 .56005 L .19514 .55885 L F
.516 .786 .994 r
.19514 .55885 m .19685 .56005 L .19731 .55838 L F
0 0 0 r
.19588 .55869 m .19486 .55897 L .19514 .55885 L F
.19486 .55897 m .19382 .55926 L .19514 .55885 L F
.63 .095 0 r
.19491 .55802 m .19554 .55868 L .19514 .55885 L F
.581 .635 .87 r
.2232 .67837 m .22497 .68143 L .22228 .68007 L F
.012 0 0 r
.22497 .68143 m .22177 .68369 L .22228 .68007 L F
.22497 .68143 m .22296 .68343 L .22177 .68369 L F
.516 .602 .878 r
.22624 .68053 m .22497 .68143 L .2232 .67837 L F
.455 .027 .136 r
.22581 .68294 m .22497 .68143 L .22624 .68053 L F
.22581 .68294 m .22296 .68343 L .22497 .68143 L F
.599 .074 0 r
.16618 .66527 m .16967 .6657 L .16801 .66467 L F
0 0 .471 r
.5313 .59037 m .52974 .587 L .52986 .58847 L F
.884 .988 .728 r
.77921 .39935 m .78077 .39872 L .78011 .3982 L F
.77921 .39935 m .77869 .40178 L .78077 .39872 L F
.661 .955 .945 r
.78229 .39686 m .78077 .39872 L .78342 .3973 L F
.664 .96 .938 r
.78011 .3982 m .78077 .39872 L .78229 .39686 L F
0 0 0 r
.21051 .6326 m .21267 .63236 L .21418 .63214 L F
.21267 .63236 m .21707 .63131 L .21418 .63214 L F
.572 .416 .631 r
.45457 .61357 m .45199 .6179 L .4514 .61468 L F
.724 .53 .628 r
.59078 .47926 m .59214 .48252 L .59436 .47974 L F
.734 .545 .637 r
.59436 .47974 m .59214 .48252 L .59449 .48211 L F
.94 .604 .175 r
.73985 .37322 m .74091 .37449 L .74109 .37623 L F
.58 .274 .415 r
.74091 .37449 m .74361 .37618 L .74109 .37623 L F
.988 .778 .533 r
.74617 .39856 m .74481 .39942 L .74557 .39759 L F
.74617 .39856 m .74602 .4011 L .74481 .39942 L F
.763 .955 .936 r
.74617 .39856 m .74557 .39759 L .74707 .39652 L F
.633 .699 .893 r
.51568 .52661 m .51794 .52847 L .51984 .52738 L F
.765 .947 .938 r
.81818 .44231 m .81531 .44279 L .81744 .44014 L F
.687 .791 .929 r
.82094 .44071 m .81818 .44231 L .81744 .44014 L F
.4 .213 .508 r
.25358 .59713 m .25535 .59899 L .25564 .59653 L F
.25358 .59713 m .2534 .59962 L .25535 .59899 L F
.624 .333 .456 r
.45646 .58426 m .4601 .58169 L .45716 .58229 L F
.836 .86 .862 r
.78163 .44434 m .77714 .4461 L .78056 .44355 L F
.672 .912 .976 r
.78163 .44434 m .783 .44238 L .78343 .44271 L F
.78163 .44434 m .78056 .44355 L .783 .44238 L F
.129 .276 .746 r
.78079 .40341 m .77869 .40178 L .77921 .39935 L F
.846 .654 .113 r
.7788 .40417 m .77869 .40178 L .78079 .40341 L F
.663 .7 .874 r
.19172 .72274 m .19339 .72587 L .19553 .72384 L F
0 0 .327 r
.57675 .58757 m .57722 .58975 L .57563 .5913 L F
0 0 .315 r
.57722 .58975 m .57501 .59356 L .57563 .5913 L F
.691 .69 .844 r
.73036 .41331 m .73391 .41396 L .7329 .41097 L F
.623 .65 .856 r
.7329 .41097 m .73391 .41396 L .73643 .41334 L F
.944 .779 .647 r
.59176 .52802 m .59122 .52414 L .59072 .52699 L F
.999 .799 .498 r
.59058 .52888 m .59176 .52802 L .59072 .52699 L F
.59058 .52888 m .59137 .52912 L .59176 .52802 L F
.728 .224 .032 r
.67309 .40655 m .67505 .40862 L .67603 .40757 L F
.659 .137 0 r
.67505 .40862 m .67859 .40941 L .67603 .40757 L F
.701 .666 .813 r
.55012 .58652 m .55278 .59086 L .55062 .59206 L F
0 0 .426 r
.21212 .69173 m .21126 .69062 L .21229 .69046 L F
.176 .142 .579 r
.58149 .5695 m .58206 .57178 L .58045 .57283 L F
.014 0 .28 r
.58206 .57178 m .58044 .57522 L .58045 .57283 L F
.187 0 .049 r
.14791 .56359 m .14987 .56286 L .15133 .56051 L F
.409 .138 .387 r
.14987 .56286 m .15288 .56055 L .15133 .56051 L F
.821 .465 .382 r
.4312 .62423 m .43537 .62662 L .43492 .62412 L F
.4312 .62423 m .43105 .6263 L .43537 .62662 L F
.532 .429 .683 r
.43537 .62662 m .43752 .62361 L .43492 .62412 L F
.43537 .62662 m .43795 .62625 L .43752 .62361 L F
.567 .531 .774 r
.43537 .62662 m .43917 .62893 L .43795 .62625 L F
0 .154 .674 r
.39682 .62113 m .39761 .6197 L .39571 .61763 L F
0 .087 .621 r
.39682 .62113 m .39832 .62355 L .39761 .6197 L F
.223 .021 .381 r
.26028 .58763 m .26237 .58446 L .26029 .58496 L F
.991 .759 .383 r
.77523 .42026 m .77491 .41654 L .77377 .41504 L F
.628 .849 .984 r
.77377 .41504 m .77491 .41654 L .77663 .41487 L F
.528 .534 .805 r
.77491 .41654 m .77859 .41915 L .77663 .41487 L F
.113 0 0 r
.17186 .56741 m .17074 .56879 L .16888 .56942 L F
.227 0 .055 r
.17386 .5667 m .17074 .56879 L .17186 .56741 L F
.542 .356 .579 r
.18766 .75642 m .19006 .75625 L .18771 .75508 L F
.563 .335 .527 r
.18754 .75637 m .19006 .75625 L .18771 .75508 L F
.811 .783 .827 r
.66801 .4458 m .66965 .44765 L .67086 .44589 L F
.622 .23 .28 r
.45208 .56021 m .45179 .56128 L .45483 .56089 L F
.415 .034 .204 r
.25219 .63829 m .24835 .64089 L .24995 .63872 L F
.798 .553 .567 r
.57532 .50385 m .57175 .50566 L .57127 .50383 L F
.57532 .50385 m .57544 .50632 L .57175 .50566 L F
.581 .64 .874 r
.19978 .72433 m .20048 .72087 L .19789 .72306 L F
.19978 .72433 m .20246 .72371 L .20048 .72087 L F
.756 .66 .755 r
.43025 .62106 m .43492 .62412 L .43338 .62095 L F
.43025 .62106 m .4312 .62423 L .43492 .62412 L F
.595 .635 .861 r
.43338 .62095 m .43492 .62412 L .43752 .62361 L F
.81 .792 .835 r
.48843 .57013 m .48965 .57177 L .49074 .56905 L F
.338 .558 .917 r
.48965 .57177 m .49173 .57052 L .49074 .56905 L F
.17 .365 .814 r
.40403 .62965 m .4058 .63305 L .40675 .63152 L F
.09 .254 .739 r
.4058 .63305 m .40796 .63496 L .40675 .63152 L F
.631 .801 .964 r
.17152 .60216 m .17355 .60367 L .17552 .60269 L F
.17552 .60269 m .17355 .60367 L .17152 .60216 L F
.298 .172 .535 r
.29474 .57484 m .29457 .57536 L .29307 .57565 L F
.202 0 .19 r
.79613 .44072 m .7957 .44289 L .79334 .44345 L F
.423 .11 .327 r
.79861 .43975 m .7957 .44289 L .79613 .44072 L F
.796 .621 .664 r
.59214 .48252 m .5957 .48565 L .59449 .48211 L F
.59214 .48252 m .59199 .48518 L .5957 .48565 L F
.846 .583 .542 r
.59199 .48518 m .59517 .4882 L .5957 .48565 L F
.756 .634 .725 r
.59449 .48211 m .5957 .48565 L .596 .48317 L F
.46 .202 .435 r
.82522 .44365 m .82508 .44607 L .82235 .44682 L F
.435 .298 .596 r
.82707 .4398 m .82522 .44365 L .82469 .44125 L F
.82707 .4398 m .82755 .44291 L .82522 .44365 L F
.263 .009 .328 r
.82755 .44291 m .82508 .44607 L .82522 .44365 L F
.685 .435 .539 r
.46591 .621 m .46202 .62373 L .46095 .6199 L F
.46591 .621 m .46743 .62411 L .46202 .62373 L F
.316 .268 .645 r
.46806 .62312 m .46743 .62411 L .46591 .621 L F
.849 .969 .876 r
.68291 .42779 m .67975 .42918 L .68259 .42739 L F
.456 .552 .864 r
.16683 .63612 m .16865 .63972 L .17058 .63909 L F
.448 .511 .831 r
.16865 .63972 m .17158 .64101 L .17058 .63909 L F
.748 .92 .558 r
.45385 .58925 m .45527 .58775 L .45397 .58718 L F
.363 .782 .977 r
.45788 .58766 m .45397 .58718 L .45527 .58775 L F
.753 .345 .276 r
.4197 .60061 m .42197 .60173 L .42353 .60003 L F
.788 .393 .305 r
.42353 .60003 m .42197 .60173 L .42483 .60208 L F
.675 .375 .457 r
.42353 .60003 m .42483 .60208 L .42573 .60037 L F
.677 .933 .968 r
.44701 .63527 m .44845 .63383 L .44857 .635 L F
.44701 .63527 m .44551 .63503 L .44845 .63383 L F
.684 .359 .419 r
.44886 .63844 m .44701 .63527 L .44857 .635 L F
.44886 .63844 m .44547 .63979 L .44701 .63527 L F
.49 .281 .523 r
.84062 .4285 m .84064 .43087 L .83792 .43143 L F
.506 .33 .576 r
.83792 .43143 m .84064 .43087 L .83839 .43419 L F
.197 .13 .55 r
.45193 .60023 m .45298 .60076 L .45349 .59883 L F
.45193 .60023 m .45185 .60313 L .45298 .60076 L F
.185 .401 .84 r
.78707 .39062 m .78603 .39196 L .78422 .389 L F
.217 .447 .868 r
.78707 .39062 m .79094 .39434 L .78603 .39196 L F
.166 .505 .911 r
.22037 .66882 m .22422 .67232 L .22429 .67144 L F
.851 .673 .661 r
.59517 .4882 m .59364 .49099 L .5968 .49174 L F
.843 .628 .612 r
.59337 .49359 m .5968 .49174 L .59364 .49099 L F
.59337 .49359 m .59644 .49449 L .5968 .49174 L F
.068 0 .277 r
.15581 .59683 m .15467 .59957 L .15382 .6001 L F
.726 .703 .168 r
.15467 .59957 m .15403 .60288 L .15382 .6001 L F
.366 .393 .756 r
.50124 .60489 m .49988 .60602 L .4997 .60431 L F
.299 0 .254 r
.50119 .60792 m .49988 .60602 L .50124 .60489 L F
.50119 .60792 m .49927 .60859 L .49988 .60602 L F
.027 0 0 r
.45752 .57026 m .45606 .5712 L .45372 .57177 L F
.872 .491 .319 r
.49389 .54322 m .49279 .5446 L .49231 .54218 L F
.49389 .54322 m .4952 .54557 L .49279 .5446 L F
.214 0 0 r
.15828 .57693 m .1577 .57569 L .15912 .57531 L F
.15828 .57693 m .15596 .57748 L .1577 .57569 L F
.835 .821 .835 r
.75259 .4177 m .75622 .41645 L .75502 .41513 L F
.437 .609 .92 r
.28074 .54341 m .27987 .54549 L .27814 .54339 L F
.28074 .54341 m .28189 .54537 L .27987 .54549 L F
.995 .756 .424 r
.65527 .44303 m .65443 .44386 L .65434 .43995 L F
.856 .63 .092 r
.65527 .44303 m .65511 .44418 L .65443 .44386 L F
.65527 .44303 m .6555 .44626 L .65511 .44418 L F
.626 .622 .827 r
.65809 .44217 m .65527 .44303 L .65434 .43995 L F
.168 0 .128 r
.79534 .44415 m .79334 .44345 L .7957 .44289 L F
.79534 .44415 m .79312 .44532 L .79334 .44345 L F
.757 .529 .588 r
.58448 .48161 m .58829 .48224 L .58828 .47973 L F
.723 .53 .629 r
.58829 .48224 m .59078 .47926 L .58828 .47973 L F
.888 .913 .837 r
.20301 .5589 m .20676 .55661 L .20467 .55806 L F
.723 .53 .629 r
.58829 .48224 m .59214 .48252 L .59078 .47926 L F
.452 .779 .998 r
.52861 .52169 m .52482 .52123 L .52603 .52232 L F
.52861 .52169 m .5281 .5206 L .52482 .52123 L F
.661 .168 .07 r
.52861 .52169 m .52804 .52347 L .5281 .5206 L F
.527 .259 .453 r
.53086 .52148 m .53087 .5236 L .52861 .52169 L F
.481 .458 .756 r
.29422 .56014 m .29465 .56425 L .29324 .56439 L F
.414 .319 .639 r
.29465 .56425 m .29367 .56668 L .29324 .56439 L F
.687 .641 .798 r
.52228 .52185 m .52603 .52232 L .52482 .52123 L F
0 0 .3 r
.52284 .52203 m .52228 .52185 L .52482 .52123 L F
.52284 .52203 m .5229 .52454 L .52228 .52185 L F
.758 .268 0 r
.41963 .62629 m .42247 .62941 L .42284 .6277 L F
.317 .007 .27 r
.42284 .6277 m .42472 .62867 L .42619 .62659 L F
.42284 .6277 m .42247 .62941 L .42472 .62867 L F
.53 .337 .564 r
.24198 .64507 m .23921 .6484 L .23927 .64542 L F
.566 .933 .796 r
.68179 .43701 m .68525 .43493 L .68373 .43531 L F
.569 .934 .796 r
.68373 .43531 m .68525 .43493 L .68729 .43348 L F
.183 .131 .561 r
.39571 .61763 m .39704 .61374 L .39526 .61515 L F
.82 .646 .666 r
.66141 .4026 m .66508 .4007 L .66215 .40091 L F
.54 .253 .428 r
.48183 .57519 m .48016 .57873 L .47763 .5787 L F
.253 .27 .686 r
.48069 .57423 m .4831 .57592 L .48118 .57077 L F
.136 0 .199 r
.48234 .5773 m .48016 .57873 L .48183 .57519 L F
.253 .27 .686 r
.4805 .57562 m .48167 .57575 L .48069 .57423 L F
.136 0 .199 r
.48277 .57747 m .48183 .57519 L .48386 .57789 L F
.253 .27 .686 r
.48167 .57575 m .4831 .57592 L .48069 .57423 L F
.136 0 .199 r
.48234 .5773 m .48214 .57649 L .48277 .57747 L F
.48214 .57649 m .48183 .57519 L .48277 .57747 L F
.708 .636 .774 r
.83187 .42928 m .82835 .42932 L .83056 .42796 L F
.656 .733 .906 r
.83056 .42796 m .8345 .4286 L .83187 .42928 L F
0 .568 .727 r
.5442 .61188 m .54044 .6117 L .54185 .61253 L F
.946 .828 .696 r
.59287 .50855 m .59481 .50976 L .59342 .50855 L F
.59287 .50855 m .59449 .51072 L .59481 .50976 L F
.634 .893 .986 r
.21274 .64879 m .21506 .64943 L .21678 .64861 L F
.238 0 .283 r
.55327 .49639 m .55603 .49343 L .55398 .49478 L F
.566 .933 .796 r
.68179 .43701 m .68373 .43531 L .68166 .43688 L F
0 0 0 r
.21267 .63236 m .21488 .63192 L .21707 .63131 L F
.484 .897 .807 r
.21707 .63131 m .21488 .63192 L .21703 .63076 L F
.245 .43 .846 r
.23157 .66439 m .23095 .66621 L .2291 .66489 L F
.23157 .66439 m .23229 .66574 L .23095 .66621 L F
.562 .616 .864 r
.23431 .66488 m .23229 .66574 L .23157 .66439 L F
0 0 0 r
.23392 .66463 m .23229 .66574 L .23431 .66488 L F
.23392 .66463 m .23377 .66479 L .23229 .66574 L F
.565 .508 .75 r
.23229 .66574 m .23075 .66895 L .23092 .66661 L F
.23229 .66574 m .23311 .66854 L .23075 .66895 L F
.499 .467 .752 r
.23504 .66783 m .23311 .66854 L .23229 .66574 L F
.709 .409 .466 r
.23109 .66757 m .23504 .66783 L .23229 .66574 L F
0 0 0 r
.23377 .66479 m .23109 .66757 L .23229 .66574 L F
.565 .508 .75 r
.23229 .66574 m .23092 .66661 L .23095 .66621 L F
.618 .839 .984 r
.17981 .62068 m .17732 .62147 L .1755 .62038 L F
.47 .131 .309 r
.43182 .59548 m .43437 .59585 L .43419 .59459 L F
.43182 .59548 m .43168 .59668 L .43437 .59585 L F
.374 .541 .892 r
.43437 .59585 m .43182 .59548 L .43419 .59459 L F
.07 0 0 r
.46396 .58503 m .4625 .58656 L .46051 .5871 L F
.165 0 0 r
.46483 .58599 m .46396 .58503 L .46639 .58456 L F
.46483 .58599 m .4625 .58656 L .46396 .58503 L F
.035 .5 .883 r
.2291 .66489 m .22645 .6641 L .22627 .66438 L F
.664 .537 .7 r
.77485 .43007 m .77747 .42823 L .77342 .42765 L F
.441 .226 .49 r
.25596 .59408 m .25776 .59594 L .25759 .59331 L F
.25596 .59408 m .25564 .59653 L .25776 .59594 L F
.414 .156 .41 r
.7278 .40032 m .72756 .40014 L .72504 .40084 L F
.445 .241 .508 r
.72688 .39802 m .7278 .40032 L .72504 .40084 L F
.055 .074 .562 r
.72805 .39812 m .72688 .39802 L .72679 .39514 L F
.22 .128 .533 r
.72917 .3995 m .72688 .39802 L .72805 .39812 L F
.395 .666 .968 r
.15533 .60347 m .15482 .60493 L .15403 .60288 L F
.15533 .60347 m .15666 .60484 L .15482 .60493 L F
.294 .461 .855 r
.52854 .55507 m .53156 .55645 L .5303 .55798 L F
0 0 .384 r
.53156 .55645 m .52989 .56045 L .5303 .55798 L F
0 .485 .759 r
.75269 .37299 m .74944 .37231 L .74916 .37207 L F
.295 .277 .668 r
.15801 .61139 m .15853 .61394 L .15704 .61511 L F
.954 .605 .275 r
.59427 .52058 m .5939 .51897 L .59244 .51774 L F
.404 0 0 r
.68894 .41197 m .68607 .41091 L .68491 .41154 L F
.43 .863 .927 r
.21678 .64861 m .22075 .64796 L .2192 .64811 L F
.029 .6 .744 r
.22075 .64796 m .22118 .64789 L .2192 .64811 L F
.22075 .64796 m .22296 .64796 L .22118 .64789 L F
.299 0 0 r
.47188 .61168 m .47466 .61124 L .47575 .60997 L F
.141 0 0 r
.47575 .60997 m .47466 .61124 L .47649 .61067 L F
.016 0 0 r
.22296 .64796 m .22674 .6477 L .2253 .64786 L F
.34 .813 .902 r
.22674 .6477 m .22956 .6472 L .22747 .64704 L F
.393 .851 .838 r
.2253 .64786 m .22674 .6477 L .22747 .64704 L F
.684 .411 .503 r
.80643 .41653 m .80667 .41911 L .80334 .41874 L F
.539 .407 .65 r
.80857 .41266 m .80908 .41591 L .80643 .41653 L F
.57 .37 .57 r
.80908 .41591 m .80667 .41911 L .80643 .41653 L F
0 0 .5 r
.52712 .57635 m .52816 .5785 L .5269 .57507 L F
.024 0 0 r
.20095 .55877 m .19899 .55971 L .19685 .56005 L F
0 0 0 r
.20125 .559 m .20095 .55877 L .20301 .5589 L F
.20125 .559 m .19899 .55971 L .20095 .55877 L F
.907 .717 .635 r
.57718 .51487 m .57969 .51557 L .57862 .51821 L F
.821 .606 .611 r
.57969 .51557 m .58165 .51897 L .57862 .51821 L F
.14 0 0 r
.17074 .56879 m .16781 .56998 L .16888 .56942 L F
.972 .902 .69 r
.56891 .56674 m .5669 .56819 L .56811 .56588 L F
.961 .829 .402 r
.67126 .4161 m .67114 .41241 L .67317 .41375 L F
.748 .828 .913 r
.42193 .58212 m .42586 .58215 L .4243 .58134 L F
.69 .897 .972 r
.42643 .58009 m .4243 .58134 L .42586 .58215 L F
.88 .747 .711 r
.48103 .61239 m .47994 .6122 L .48273 .61041 L F
.48103 .61239 m .47893 .61446 L .47994 .6122 L F
.009 0 .304 r
.48103 .61239 m .48021 .6169 L .47893 .61446 L F
.48103 .61239 m .48177 .61592 L .48021 .6169 L F
.474 .472 .775 r
.48273 .61041 m .48253 .61198 L .48103 .61239 L F
.484 .519 .818 r
.48402 .61057 m .48103 .61239 L .48273 .61041 L F
.48402 .61057 m .48253 .61198 L .48103 .61239 L F
.024 0 .2 r
.48253 .61198 m .48177 .61592 L .48103 .61239 L F
.807 .838 .874 r
.76129 .42544 m .75824 .42533 L .76065 .42394 L F
.53 .337 .564 r
.24198 .64507 m .242 .64809 L .23921 .6484 L F
.655 .97 .886 r
.242 .64809 m .23867 .64992 L .23921 .6484 L F
.789 .627 .68 r
.74663 .40687 m .74556 .40808 L .74375 .40615 L F
.893 .569 .072 r
.59451 .49959 m .5958 .50315 L .59587 .50071 L F
.935 .903 .768 r
.59587 .50071 m .59669 .49748 L .59451 .49959 L F
.427 .093 .295 r
.74257 .37313 m .74487 .37069 L .74014 .37207 L F
.696 .793 .925 r
.74131 .40457 m .7378 .4044 L .74022 .40319 L F
.705 .796 .921 r
.7439 .40395 m .74131 .40457 L .74022 .40319 L F
.629 .485 .668 r
.74375 .40615 m .74131 .40457 L .7439 .40395 L F
.74375 .40615 m .74151 .407 L .74131 .40457 L F
.946 .586 .253 r
.54288 .59448 m .54428 .59421 L .54184 .5906 L F
.503 .784 .996 r
.54498 .59281 m .54428 .59421 L .54288 .59448 L F
.54498 .59281 m .54693 .59389 L .54428 .59421 L F
.768 .699 .158 r
.52898 .5845 m .52937 .58074 L .53004 .58235 L F
.875 .708 .672 r
.58165 .51897 m .57843 .52107 L .57862 .51821 L F
.58165 .51897 m .58118 .52142 L .57843 .52107 L F
.413 .398 .733 r
.40682 .63913 m .40879 .63901 L .40796 .63496 L F
.279 .436 .84 r
.40682 .63913 m .40985 .64109 L .40879 .63901 L F
.363 .161 .467 r
.28756 .59687 m .28724 .59946 L .28535 .60004 L F
.528 .378 .622 r
.28724 .59946 m .28518 .60256 L .28535 .60004 L F
.264 0 .202 r
.70332 .40691 m .70121 .40797 L .70082 .40943 L F
.482 .601 .894 r
.74067 .41536 m .74159 .41232 L .73908 .4131 L F
.74067 .41536 m .74299 .41525 L .74159 .41232 L F
.395 .116 .367 r
.65035 .41944 m .653 .41885 L .6531 .41698 L F
.29 .036 .345 r
.6531 .41698 m .653 .41885 L .65531 .41574 L F
.755 .649 .745 r
.28981 .54825 m .28733 .55132 L .28615 .54782 L F
.444 .225 .485 r
.28981 .54825 m .28937 .55123 L .28733 .55132 L F
.28981 .54825 m .28937 .55123 L .28733 .55132 L F
.918 .719 .617 r
.77555 .4219 m .77523 .42026 L .77301 .42217 L F
.616 .426 .602 r
.47684 .61729 m .47424 .62068 L .47427 .61809 L F
.282 0 .293 r
.24437 .64254 m .24383 .64449 L .24198 .64507 L F
.24442 .64252 m .24383 .64449 L .24437 .64254 L F
.347 .056 .321 r
.24661 .64188 m .24383 .64449 L .24444 .64246 L F
.861 .921 .867 r
.24227 .64373 m .24383 .64449 L .24661 .64188 L F
.24227 .64373 m .24628 .64202 L .24462 .64305 L F
.24628 .64202 m .24661 .64188 L .24645 .64197 L F
.24628 .64202 m .24645 .64197 L .24462 .64305 L F
.282 0 .293 r
.24444 .64246 m .24442 .64252 L .24437 .64254 L F
.542 .805 .994 r
.2882 .54701 m .28981 .54825 L .28615 .54782 L F
.062 .597 .859 r
.2882 .54701 m .29181 .54781 L .28981 .54825 L F
.437 .669 .96 r
.43351 .60765 m .43143 .60727 L .43368 .60619 L F
.217 0 0 r
.15862 .55708 m .16077 .5565 L .16251 .55448 L F
.072 0 0 r
.16251 .55448 m .16277 .55569 L .16456 .5537 L F
.16251 .55448 m .16077 .5565 L .16277 .55569 L F
0 0 0 r
.56998 .56003 m .57037 .5598 L .57071 .55888 L F
.57106 .55799 m .56979 .56033 L .56998 .56003 L F
.56998 .56003 m .57169 .55622 L .57106 .55799 L F
.56998 .56003 m .57071 .55888 L .57169 .55622 L F
.56979 .56033 m .56923 .56136 L .56998 .56003 L F
.19 0 .377 r
.15399 .57822 m .15211 .58141 L .15246 .57907 L F
.494 .53 .823 r
.80729 .42415 m .80608 .42742 L .80465 .42483 L F
.80729 .42415 m .80834 .4275 L .80608 .42742 L F
.867 .796 .779 r
.75664 .39172 m .75478 .39539 L .75353 .39271 L F
.772 .933 .937 r
.71869 .39593 m .72015 .39741 L .71794 .39858 L F
.883 .945 .848 r
.72237 .39444 m .72015 .39741 L .71869 .39593 L F
.49 .215 .424 r
.42427 .5789 m .4243 .58134 L .4253 .57949 L F
.379 .286 .623 r
.42674 .57548 m .4253 .57949 L .42739 .57834 L F
.135 0 .061 r
.4253 .57949 m .42643 .58009 L .42739 .57834 L F
.4253 .57949 m .4243 .58134 L .42643 .58009 L F
.565 .755 .967 r
.42739 .57834 m .4253 .57949 L .42674 .57548 L F
.909 .736 .656 r
.59119 .51416 m .59449 .51072 L .59287 .50855 L F
.59119 .51416 m .59304 .51532 L .59449 .51072 L F
.745 .634 .737 r
.50759 .59981 m .50858 .60303 L .50537 .60327 L F
0 0 0 r
.50858 .60303 m .50476 .60497 L .50537 .60327 L F
.50858 .60303 m .50693 .60414 L .50476 .60497 L F
0 .053 .565 r
.84092 .42436 m .84175 .42648 L .84062 .4285 L F
.945 .951 .643 r
.84175 .42648 m .84064 .43087 L .84062 .4285 L F
.578 .184 .26 r
.45483 .56089 m .45723 .56247 L .4587 .56006 L F
.51 .125 .245 r
.45723 .56247 m .46108 .5601 L .4587 .56006 L F
.584 .443 .655 r
.21027 .68714 m .2131 .68692 L .21285 .68424 L F
.535 .248 .426 r
.21027 .68714 m .21233 .68929 L .2131 .68692 L F
.584 .443 .655 r
.21027 .68714 m .2131 .68692 L .21285 .68424 L F
.848 .824 .346 r
.2131 .68692 m .21233 .68929 L .21027 .68714 L F
.665 .293 0 r
.51444 .59042 m .51369 .58883 L .51366 .58894 L F
.351 .473 .844 r
.79718 .41609 m .79878 .41444 L .79569 .41293 L F
.457 .413 .721 r
.79715 .41884 m .79878 .41444 L .79718 .41609 L F
.979 .877 .508 r
.52598 .54486 m .52541 .54715 L .52619 .54729 L F
.991 .75 .38 r
.52519 .55028 m .52619 .54729 L .52541 .54715 L F
.52519 .55028 m .52646 .5517 L .52619 .54729 L F
.119 0 .029 r
.5512 .49714 m .55253 .49806 L .55327 .49639 L F
.5512 .49714 m .55028 .49922 L .55253 .49806 L F
.509 .566 .849 r
.43624 .59661 m .4358 .60001 L .43437 .59585 L F
.43624 .59661 m .43737 .59976 L .4358 .60001 L F
.708 .265 .196 r
.43815 .60207 m .43428 .60157 L .4358 .60001 L F
.48 .348 .624 r
.43737 .59976 m .43815 .60207 L .4358 .60001 L F
.43737 .59976 m .43815 .60207 L .4358 .60001 L F
0 .419 .748 r
.44237 .6301 m .44083 .62944 L .44039 .62937 L F
.723 .394 .422 r
.44393 .62935 m .44083 .62944 L .44237 .6301 L F
.44393 .62935 m .44296 .63173 L .44083 .62944 L F
0 .009 .537 r
.44083 .62944 m .44196 .63047 L .44184 .62958 L F
.44083 .62944 m .44184 .62958 L .44158 .62778 L F
0 .419 .748 r
.44039 .62937 m .44083 .62944 L .43917 .62893 L F
.584 .76 .962 r
.1914 .64683 m .19237 .64814 L .19487 .64767 L F
.767 .664 .749 r
.22009 .68943 m .21983 .69271 L .22213 .6897 L F
.21895 .68928 m .21922 .69032 L .22009 .68943 L F
.21922 .69032 m .21983 .69271 L .22009 .68943 L F
.865 .984 .845 r
.21947 .68991 m .21936 .69017 L .21922 .69031 L F
.335 .36 .739 r
.21983 .69271 m .21823 .69282 L .21947 .68991 L F
.865 .984 .845 r
.21947 .68991 m .21983 .69271 L .21922 .69032 L F
.21947 .68991 m .21922 .69032 L .21895 .68928 L F
.2189 .69054 m .2192 .69033 L .21793 .6916 L F
.21936 .69017 m .21823 .69282 L .21793 .69163 L F
.21936 .69017 m .21793 .69163 L .21793 .6916 L F
.861 .716 .701 r
.21798 .69118 m .21922 .69032 L .21895 .68928 L F
.865 .984 .845 r
.21947 .68991 m .2189 .69054 L .21789 .69137 L F
.2189 .69054 m .21793 .6916 L .21789 .69137 L F
.861 .716 .701 r
.21789 .69137 m .21922 .69032 L .2189 .69054 L F
.21789 .69137 m .2189 .69054 L .21798 .69118 L F
.21789 .69137 m .21983 .69271 L .21922 .69032 L F
.865 .984 .845 r
.21947 .68991 m .21922 .69031 L .2192 .69033 L F
.21947 .68991 m .2192 .69033 L .2189 .69054 L F
0 0 .476 r
.21978 .6959 m .21823 .69282 L .21983 .69271 L F
0 0 .122 r
.24224 .6463 m .24198 .64507 L .24383 .64449 L F
.24214 .64583 m .242 .64727 L .24198 .64507 L F
.701 .368 .41 r
.23964 .64661 m .24219 .64532 L .24227 .64373 L F
.24219 .64532 m .24383 .64449 L .24234 .64377 L F
.24219 .64532 m .24234 .64377 L .24227 .64373 L F
0 0 .122 r
.24224 .6463 m .242 .64809 L .242 .64727 L F
.24224 .6463 m .242 .64727 L .24214 .64583 L F
.517 .218 .398 r
.46019 .60946 m .45958 .61146 L .45687 .6118 L F
.177 0 .254 r
.4621 .60877 m .45958 .61146 L .46019 .60946 L F
.938 .652 .186 r
.54108 .58288 m .54158 .58195 L .54001 .58152 L F
.54108 .58288 m .54185 .58435 L .54158 .58195 L F
.705 .796 .921 r
.7439 .40395 m .74022 .40319 L .74277 .40194 L F
.863 .861 .837 r
.74602 .4011 m .7439 .40395 L .74277 .40194 L F
.358 0 .123 r
.19172 .72274 m .19384 .72252 L .19549 .72016 L F
.374 0 .176 r
.19384 .72252 m .19773 .7197 L .19549 .72016 L F
.476 .151 .336 r
.42483 .60208 m .42908 .59942 L .42573 .60037 L F
.991 .759 .383 r
.77523 .42026 m .77377 .41504 L .77294 .4177 L F
.93 .874 .76 r
.77301 .42217 m .77523 .42026 L .77294 .4177 L F
.52 .653 .918 r
.78195 .40569 m .7788 .40417 L .78079 .40341 L F
.071 .37 .837 r
.78387 .4054 m .78195 .40569 L .78079 .40341 L F
.48 .709 .97 r
.18136 .6227 m .18086 .62456 L .17988 .6213 L F
.18136 .6227 m .18305 .62432 L .18086 .62456 L F
.831 .824 .841 r
.22779 .65931 m .22993 .66058 L .23218 .65757 L F
.159 0 0 r
.52326 .51758 m .52584 .51705 L .52711 .51552 L F
.349 0 0 r
.52825 .51672 m .52711 .51552 L .52584 .51705 L F
.52825 .51672 m .52968 .51549 L .52711 .51552 L F
0 0 0 r
.58044 .57522 m .57973 .57738 L .5785 .57892 L F
.054 .014 .489 r
.57973 .57738 m .5784 .58141 L .5785 .57892 L F
.753 .754 .853 r
.82606 .43672 m .82469 .44125 L .8236 .43966 L F
.82606 .43672 m .82707 .4398 L .82469 .44125 L F
.684 .354 0 r
.50516 .5742 m .50579 .57578 L .50447 .57235 L F
0 .126 .621 r
.50716 .57665 m .50579 .57578 L .50516 .5742 L F
.749 .768 .869 r
.72682 .41279 m .73036 .41331 L .72938 .41224 L F
.727 .764 .882 r
.72938 .41224 m .73036 .41331 L .7329 .41097 L F
.01 0 0 r
.17382 .54904 m .17393 .54983 L .17598 .54847 L F
.17382 .54904 m .17184 .5505 L .17393 .54983 L F
0 0 0 r
.41416 .63008 m .41523 .62939 L .41659 .62736 L F
.649 .508 .677 r
.41523 .62939 m .41963 .62629 L .41659 .62736 L F
.772 .933 .937 r
.71869 .39593 m .71794 .39858 L .71668 .39711 L F
.476 0 0 r
.44005 .56395 m .44256 .56563 L .44367 .56608 L F
.566 .143 .199 r
.44256 .56563 m .44648 .56439 L .44367 .56608 L F
.811 .459 .391 r
.68032 .41962 m .6776 .42085 L .67755 .4183 L F
.68032 .41962 m .68096 .42169 L .6776 .42085 L F
.704 .686 .83 r
.66785 .44308 m .66477 .44213 L .6667 .43978 L F
.745 .654 .76 r
.67013 .44083 m .66785 .44308 L .6667 .43978 L F
.501 .044 .099 r
.2441 .55512 m .24231 .55685 L .23994 .55665 L F
.581 .137 .161 r
.24616 .55655 m .24231 .55685 L .2441 .55512 L F
.867 .796 .779 r
.75664 .39172 m .75353 .39271 L .75632 .39148 L F
0 0 .28 r
.75845 .38797 m .75664 .39172 L .75819 .39015 L F
.609 .952 .817 r
.75664 .39172 m .75632 .39148 L .75819 .39015 L F
.385 .399 .752 r
.40886 .62512 m .4097 .6298 L .40803 .62979 L F
.566 .814 .437 r
.52407 .53526 m .52264 .53714 L .5246 .53459 L F
.49 .215 .424 r
.42427 .5789 m .42193 .58212 L .4243 .58134 L F
0 0 0 r
.52407 .53526 m .52165 .53888 L .52264 .53714 L F
.65 .797 .953 r
.15742 .60225 m .15907 .6056 L .15666 .60484 L F
.789 .329 .149 r
.15907 .6056 m .15709 .6051 L .15666 .60484 L F
.15907 .6056 m .16099 .60731 L .15709 .6051 L F
.411 .573 .903 r
.15942 .60129 m .15907 .6056 L .15742 .60225 L F
.94 .793 .67 r
.67086 .44589 m .66956 .44437 L .66801 .4458 L F
.211 .736 .798 r
.20111 .54026 m .20541 .53974 L .20325 .54033 L F
.256 .765 .85 r
.18885 .55958 m .18681 .55957 L .18463 .55998 L F
.13 .678 .787 r
.1909 .55937 m .18681 .55957 L .18885 .55958 L F
.496 0 0 r
.50264 .54924 m .50278 .5498 L .49937 .54751 L F
.673 .129 0 r
.50553 .55063 m .50278 .5498 L .50264 .54924 L F
.982 .91 .62 r
.57405 .54495 m .57488 .54599 L .57386 .54796 L F
.671 .755 .914 r
.22956 .6472 m .23278 .64745 L .23136 .64673 L F
.468 .747 .99 r
.23278 .64745 m .23331 .64632 L .23136 .64673 L F
.23278 .64745 m .23621 .64735 L .23331 .64632 L F
.19 0 .369 r
.55027 .60875 m .5502 .6103 L .54833 .61239 L F
.195 0 0 r
.5502 .6103 m .54673 .6124 L .54833 .61239 L F
.677 .28 .287 r
.57175 .50566 m .5671 .50384 L .57127 .50383 L F
.209 .721 .889 r
.20888 .71961 m .20793 .72005 L .20631 .71759 L F
.20888 .71961 m .21031 .71993 L .20793 .72005 L F
.20793 .72005 m .20888 .71961 L .20688 .72066 L F
.20793 .72005 m .21031 .71993 L .20888 .71961 L F
.897 .511 .288 r
.45215 .60467 m .4504 .60449 L .45185 .60313 L F
.917 .937 .804 r
.51466 .52316 m .51392 .52693 L .51568 .52661 L F
.51466 .52316 m .51208 .52683 L .51392 .52693 L F
.607 .668 .883 r
.78603 .40977 m .78954 .41085 L .78817 .4074 L F
.647 .691 .877 r
.78817 .4074 m .78954 .41085 L .79208 .40989 L F
.617 .563 .771 r
.7872 .4043 m .78565 .40801 L .78487 .40747 L F
.7872 .4043 m .78817 .4074 L .78565 .40801 L F
.656 .752 .92 r
.78487 .40747 m .78603 .40977 L .78817 .4074 L F
.322 .024 .294 r
.20638 .69931 m .20839 .6998 L .20956 .69674 L F
.238 .261 .683 r
.20638 .69931 m .20849 .7016 L .20839 .6998 L F
.404 .613 .935 r
.20439 .6296 m .20452 .63203 L .20272 .62949 L F
.20439 .6296 m .2066 .63213 L .20452 .63203 L F
0 0 0 r
.25251 .5527 m .25041 .55366 L .25268 .55185 L F
.547 .728 .959 r
.16919 .67206 m .17148 .67161 L .16932 .67218 L F
.784 .756 .828 r
.17136 .67256 m .16932 .67218 L .17148 .67161 L F
.425 .567 .892 r
.19607 .65111 m .19595 .64698 L .19487 .64767 L F
.19607 .65111 m .19804 .651 L .19595 .64698 L F
0 .214 .733 r
.72711 .39358 m .72679 .39514 L .72508 .39168 L F
0 0 .477 r
.72805 .39812 m .72679 .39514 L .72711 .39358 L F
.687 .295 .297 r
.42619 .62659 m .42887 .62853 L .4287 .62679 L F
.42619 .62659 m .42472 .62867 L .42887 .62853 L F
.801 .546 .553 r
.41282 .63153 m .41416 .63008 L .41368 .6329 L F
.41282 .63153 m .41523 .62939 L .41416 .63008 L F
.4 .317 .647 r
.19326 .74386 m .19162 .74465 L .19177 .74212 L F
.22 0 .3 r
.19086 .74691 m .19162 .74465 L .19326 .74386 L F
.527 .92 .836 r
.46757 .55864 m .46832 .55763 L .46939 .55817 L F
.46757 .55864 m .46553 .55907 L .46832 .55763 L F
.433 .791 .996 r
.52482 .52123 m .5281 .5206 L .5258 .51979 L F
.622 .946 .751 r
.52482 .52123 m .5258 .51979 L .52284 .52203 L F
.314 0 0 r
.2401 .53834 m .24216 .53877 L .24422 .53875 L F
0 .473 .856 r
.26156 .55301 m .26449 .55407 L .26316 .55305 L F
.26156 .55301 m .26316 .55305 L .26091 .5544 L F
.534 .781 .989 r
.73031 .38763 m .73146 .38907 L .73387 .38845 L F
.73387 .38845 m .73146 .38907 L .73031 .38763 L F
.559 .554 .805 r
.80436 .42225 m .80056 .41888 L .80334 .41874 L F
.414 .319 .639 r
.29465 .56425 m .29555 .56622 L .29367 .56668 L F
.401 .277 .594 r
.29555 .56622 m .29568 .56865 L .29367 .56668 L F
.597 .58 .805 r
.80967 .40572 m .81074 .4096 L .80811 .41022 L F
.562 .444 .676 r
.81074 .4096 m .80857 .41266 L .80811 .41022 L F
.182 .709 .701 r
.55945 .60684 m .55537 .60782 L .55594 .6083 L F
.436 .853 .958 r
.55594 .6083 m .55537 .60782 L .55187 .60857 L F
.595 .341 .502 r
.49197 .59967 m .49183 .60241 L .4889 .60245 L F
.492 .257 .485 r
.4937 .6015 m .49197 .59967 L .49369 .59856 L F
.4937 .6015 m .49183 .60241 L .49197 .59967 L F
.433 .113 .322 r
.47641 .59139 m .47399 .59515 L .47376 .59295 L F
.47641 .59139 m .47637 .59471 L .47399 .59515 L F
.47399 .59515 m .47641 .59139 L .47376 .59295 L F
.47399 .59515 m .47637 .59471 L .47641 .59139 L F
.537 .397 .638 r
.47637 .59471 m .47855 .59188 L .47641 .59139 L F
.47855 .59188 m .47637 .59471 L .47641 .59139 L F
0 .153 .67 r
.51896 .59676 m .51598 .59376 L .5181 .59585 L F
.998 .846 .525 r
.5181 .59585 m .5184 .59936 L .51896 .59676 L F
.769 .689 .775 r
.55012 .58652 m .55521 .5878 L .55278 .59086 L F
.759 .514 .563 r
.49789 .58216 m .49348 .58111 L .49736 .58102 L F
.49789 .58216 m .49376 .58379 L .49348 .58111 L F
.374 .087 .343 r
.49565 .58543 m .49376 .58379 L .49789 .58216 L F
.526 .037 .037 r
.49736 .58102 m .50062 .58162 L .49789 .58216 L F
.326 .061 .349 r
.55187 .60857 m .5502 .6103 L .55027 .60875 L F
.691 .439 .537 r
.57465 .47886 m .57871 .47893 L .57871 .47649 L F
.802 .531 .529 r
.57871 .47649 m .57871 .47893 L .58227 .4794 L F
.294 .468 .861 r
.76881 .40113 m .77003 .3993 L .76712 .39815 L F
.56 .378 .591 r
.46064 .59986 m .46315 .59964 L .46309 .5967 L F
.46064 .59986 m .46315 .59964 L .46309 .5967 L F
.353 .806 .678 r
.46059 .59975 m .46064 .59986 L .46315 .59964 L F
.46059 .59975 m .45751 .60129 L .46064 .59986 L F
.497 .273 .504 r
.4606 .60263 m .46315 .59964 L .46064 .59986 L F
.911 .959 .807 r
.45751 .60129 m .45807 .60312 L .46064 .59986 L F
.763 .793 .877 r
.80108 .42421 m .79888 .42778 L .79924 .42617 L F
.439 .01 .125 r
.46737 .5805 m .47117 .57839 L .46865 .57819 L F
.801 .375 .235 r
.41675 .65747 m .41528 .65879 L .41573 .65621 L F
.41675 .65747 m .41772 .65949 L .41528 .65879 L F
.805 .376 .228 r
.42057 .66009 m .41772 .65949 L .41675 .65747 L F
.716 .955 .675 r
.7373 .37412 m .73471 .37708 L .73616 .37472 L F
.723 .966 .706 r
.73616 .37472 m .73471 .37708 L .73352 .37749 L F
.69 .608 .76 r
.7373 .37412 m .73835 .37672 L .73471 .37708 L F
.501 .191 .373 r
.73835 .37672 m .73505 .37956 L .73471 .37708 L F
.817 1 .827 r
.19178 .74084 m .19177 .74212 L .18954 .74088 L F
.65 .353 .455 r
.18935 .7437 m .19326 .74386 L .19177 .74212 L F
0 .119 .67 r
.19177 .74212 m .19178 .74084 L .18954 .74088 L F
.19177 .74212 m .19326 .74386 L .19178 .74084 L F
.53 .247 .429 r
.22329 .66635 m .22667 .66612 L .22627 .66438 L F
.53 .246 .429 r
.22627 .66438 m .22667 .66612 L .2291 .66489 L F
.439 .176 .416 r
.24409 .61216 m .24567 .61385 L .24601 .61144 L F
.24409 .61216 m .24347 .61441 L .24567 .61385 L F
.755 .53 .592 r
.57871 .47893 m .58143 .4814 L .58227 .4794 L F
.737 .436 .471 r
.58143 .4814 m .58448 .48161 L .58227 .4794 L F
.648 .65 .838 r
.45925 .5936 m .45554 .59107 L .45859 .59169 L F
.735 .639 .752 r
.46163 .59043 m .45925 .5936 L .45859 .59169 L F
.631 .49 .672 r
.46163 .59043 m .46297 .59546 L .45925 .5936 L F
.589 .582 .813 r
.46309 .5967 m .45925 .5936 L .46297 .59546 L F
.604 .698 .91 r
.46544 .59622 m .46309 .5967 L .46297 .59546 L F
0 0 0 r
.46544 .59622 m .46315 .59964 L .46309 .5967 L F
.604 .698 .91 r
.46297 .59546 m .46309 .5967 L .46544 .59622 L F
.565 .385 .596 r
.46315 .59964 m .46544 .59622 L .46309 .5967 L F
.497 .347 .607 r
.44839 .5873 m .44975 .58817 L .45152 .58572 L F
.652 .387 .505 r
.44975 .58817 m .45397 .58718 L .45152 .58572 L F
.646 .813 .963 r
.81428 .42658 m .81207 .42816 L .81077 .42676 L F
.234 .029 .384 r
.81428 .42658 m .81175 .43022 L .81207 .42816 L F
.513 .305 .535 r
.70633 .40408 m .70888 .4035 L .70876 .40085 L F
.533 .334 .556 r
.70888 .4035 m .71127 .40009 L .70876 .40085 L F
0 .493 .75 r
.25389 .55801 m .25222 .55756 L .25002 .55714 L F
0 .309 .761 r
.25389 .55801 m .25382 .55738 L .25222 .55756 L F
.25389 .55801 m .25519 .55853 L .25382 .55738 L F
.937 .666 .501 r
.45733 .62736 m .45532 .62872 L .45512 .62611 L F
.57 .091 .079 r
.45933 .6288 m .45532 .62872 L .45733 .62736 L F
.445 .184 .423 r
.45969 .62663 m .45933 .6288 L .45733 .62736 L F
.983 .744 .495 r
.52137 .61805 m .51974 .61954 L .51987 .61691 L F
.51987 .61691 m .51974 .61954 L .52137 .61805 L F
.529 .298 .509 r
.18766 .75642 m .18877 .75876 L .18785 .75923 L F
0 0 0 r
.18785 .75923 m .18877 .75876 L .18731 .75966 L F
.71 .752 .885 r
.18731 .75966 m .18877 .75876 L .18901 .75773 L F
.18733 .75973 m .18901 .75773 L .18754 .76048 L F
.18731 .75966 m .18763 .7593 L .18733 .75973 L F
.18763 .7593 m .18901 .75773 L .18733 .75973 L F
.529 .298 .509 r
.18847 .75812 m .19006 .75625 L .18877 .75876 L F
.18766 .75642 m .18978 .75627 L .18847 .75812 L F
.18978 .75627 m .19006 .75625 L .18847 .75812 L F
.456 .271 .54 r
.28954 .59611 m .28724 .59946 L .28756 .59687 L F
.566 .227 .352 r
.56524 .50343 m .56385 .50608 L .56144 .50601 L F
.622 .287 .382 r
.56766 .50543 m .56385 .50608 L .56524 .50343 L F
.652 .266 .301 r
.5671 .50384 m .56766 .50543 L .56524 .50343 L F
.039 0 0 r
.69361 .43093 m .69487 .43105 L .69218 .43175 L F
.69361 .43093 m .69617 .43079 L .69487 .43105 L F
.18 .714 .76 r
.2103 .70224 m .21256 .70182 L .21109 .70197 L F
.726 .657 .781 r
.47893 .61446 m .48049 .61751 L .47684 .61729 L F
.328 0 .19 r
.48049 .61751 m .47702 .62062 L .47684 .61729 L F
.48049 .61751 m .47956 .61992 L .47702 .62062 L F
0 0 .352 r
.47893 .61446 m .48021 .6169 L .48049 .61751 L F
.432 .804 .994 r
.48307 .61736 m .48021 .6169 L .48049 .61751 L F
0 0 0 r
.48038 .61892 m .48049 .61751 L .48021 .6169 L F
.48038 .61892 m .47956 .61992 L .48049 .61751 L F
.575 .312 .48 r
.47884 .58461 m .48143 .58465 L .48172 .58185 L F
.512 .335 .578 r
.44394 .59644 m .44686 .59661 L .44689 .59324 L F
.667 .863 .974 r
.65836 .44609 m .65963 .44729 L .66193 .44607 L F
.327 .152 .484 r
.26115 .5765 m .26327 .57566 L .2632 .57269 L F
.925 .752 .649 r
.26363 .57829 m .26115 .5765 L .26165 .57876 L F
.26363 .57829 m .26327 .57566 L .26115 .5765 L F
.887 .458 .132 r
.42049 .66266 m .41772 .65949 L .42057 .66009 L F
.121 .123 .586 r
.42151 .65615 m .42213 .65915 L .42057 .66009 L F
0 0 .257 r
.42141 .66134 m .42057 .66009 L .42213 .65915 L F
.42141 .66134 m .42049 .66266 L .42057 .66009 L F
.99 .746 .463 r
.43683 .56968 m .43625 .56821 L .43533 .56985 L F
.583 .565 .799 r
.43533 .56985 m .43866 .57291 L .43683 .56968 L F
.99 .746 .463 r
.43683 .56968 m .43655 .57139 L .43631 .56875 L F
.43683 .56968 m .43631 .56875 L .43625 .56821 L F
.583 .565 .799 r
.43866 .57291 m .43868 .57293 L .43683 .56968 L F
.358 .048 .295 r
.25936 .63478 m .25788 .63346 L .26029 .63301 L F
.25936 .63478 m .25723 .63542 L .25788 .63346 L F
.417 .151 .4 r
.42194 .65142 m .42064 .6545 L .41908 .65421 L F
.615 .355 .501 r
.4237 .65367 m .42064 .6545 L .42194 .65142 L F
.564 .428 .655 r
.42431 .65058 m .42194 .65142 L .42396 .64797 L F
.528 .34 .57 r
.42431 .65058 m .4237 .65367 L .42194 .65142 L F
.456 .387 .691 r
.26276 .55772 m .26524 .55693 L .26449 .55407 L F
.394 .193 .485 r
.26276 .55772 m .26487 .55949 L .26524 .55693 L F
.992 .802 .549 r
.50275 .53873 m .504 .5397 L .50368 .53671 L F
.50368 .53671 m .504 .5397 L .50275 .53873 L F
.658 .639 .82 r
.74556 .40808 m .74151 .407 L .74375 .40615 L F
.166 .703 .732 r
.1691 .67207 m .17148 .67161 L .16919 .67206 L F
.825 .677 .699 r
.23342 .59375 m .23394 .59725 L .2319 .59612 L F
.916 .546 .308 r
.23481 .59965 m .2319 .59612 L .23394 .59725 L F
.385 .365 .713 r
.23503 .59502 m .23394 .59725 L .23342 .59375 L F
.529 .487 .754 r
.23513 .58972 m .23547 .59323 L .23342 .59375 L F
.385 .365 .713 r
.23616 .59591 m .23342 .59375 L .23547 .59323 L F
.935 .62 .418 r
.23383 .5949 m .23521 .5935 L .23466 .59104 L F
.23521 .5935 m .23547 .59323 L .23529 .59275 L F
.23521 .5935 m .23529 .59275 L .23466 .59104 L F
.385 .365 .713 r
.23616 .59591 m .23484 .5967 L .23503 .59502 L F
.23484 .5967 m .23394 .59725 L .23503 .59502 L F
.352 .336 .702 r
.23616 .59591 m .23481 .59965 L .23394 .59725 L F
.947 .956 .725 r
.76674 .40932 m .76738 .4103 L .76658 .41095 L F
.969 .933 .654 r
.76889 .40477 m .76738 .4103 L .76674 .40932 L F
.552 .306 .496 r
.4805 .57562 m .48016 .57873 L .47763 .5787 L F
.253 .27 .686 r
.4805 .57562 m .48118 .57077 L .47939 .5714 L F
.282 .082 .421 r
.4805 .57562 m .48234 .5773 L .4831 .57592 L F
.4805 .57562 m .48016 .57873 L .48234 .5773 L F
.749 .382 0 r
.51535 .59269 m .51598 .59376 L .51444 .59042 L F
.652 .105 0 r
.51654 .59502 m .51598 .59376 L .51535 .59269 L F
.51654 .59502 m .5181 .59585 L .51598 .59376 L F
0 0 .509 r
.5093 .58154 m .51078 .58365 L .51105 .58478 L F
0 .016 .518 r
.51203 .5857 m .51105 .58478 L .51078 .58365 L F
.51203 .5857 m .51317 .58687 L .51105 .58478 L F
.69 .387 .457 r
.41739 .62027 m .41539 .62152 L .41484 .6206 L F
.02 0 0 r
.80896 .4327 m .80961 .43145 L .81175 .43022 L F
.595 .528 .749 r
.43821 .6119 m .44076 .61149 L .43974 .60725 L F
.209 0 0 r
.43691 .61363 m .44076 .61149 L .43821 .6119 L F
.624 .944 .95 r
.82508 .44607 m .82097 .44694 L .82235 .44682 L F
.608 .039 0 r
.50679 .53766 m .50896 .53844 L .50651 .53664 L F
.444 .181 .419 r
.44343 .57911 m .44051 .58083 L .44011 .57974 L F
.493 .786 .997 r
.18757 .6233 m .18721 .62499 L .18523 .62378 L F
.18757 .6233 m .1893 .62459 L .18721 .62499 L F
.366 .785 .977 r
.20541 .53974 m .20748 .53943 L .20927 .54009 L F
.333 .757 .975 r
.20971 .53911 m .20927 .54009 L .20748 .53943 L F
.20971 .53911 m .21146 .53988 L .20927 .54009 L F
.29 .426 .827 r
.44551 .58781 m .44818 .59012 L .44839 .5873 L F
.423 .144 .384 r
.18245 .56054 m .18195 .56277 L .17977 .5633 L F
.305 0 .273 r
.18463 .55998 m .18195 .56277 L .18245 .56054 L F
.477 .246 .484 r
.4113 .59342 m .41595 .58793 L .41195 .59067 L F
.768 .592 .66 r
.2391 .61397 m .24066 .61712 L .24139 .61502 L F
.519 .266 .472 r
.24066 .61712 m .24347 .61441 L .24139 .61502 L F
.046 0 0 r
.22265 .62988 m .22262 .62945 L .22049 .63074 L F
.22265 .62988 m .22493 .62916 L .22262 .62945 L F
.736 .494 .562 r
.53086 .52148 m .53453 .52162 L .53448 .52406 L F
.582 .819 .436 r
.53676 .52097 m .53448 .52406 L .53453 .52162 L F
.392 .028 .223 r
.55321 .50713 m .5528 .50854 L .55033 .50907 L F
.394 .006 .18 r
.55702 .50597 m .5528 .50854 L .55321 .50713 L F
.566 .056 .001 r
.51289 .59762 m .51581 .59892 L .51208 .5986 L F
.49 0 0 r
.23602 .56071 m .2334 .56124 L .23135 .56014 L F
.196 0 .318 r
.23821 .5577 m .23762 .55996 L .23602 .56071 L F
.287 .784 .77 r
.23555 .56057 m .23602 .56071 L .23762 .55996 L F
.23555 .56057 m .2334 .56124 L .23602 .56071 L F
.292 .653 .97 r
.22197 .55392 m .22242 .55278 L .2201 .55316 L F
.22197 .55392 m .22401 .5541 L .22242 .55278 L F
.576 .218 .325 r
.47175 .62077 m .47068 .62303 L .46806 .62312 L F
.516 .145 .275 r
.47424 .62068 m .47068 .62303 L .47175 .62077 L F
.328 .741 .978 r
.2461 .53903 m .24825 .53894 L .25001 .5398 L F
.264 .729 .948 r
.24825 .53894 m .25218 .5395 L .25001 .5398 L F
.621 .375 .524 r
.43644 .56711 m .44128 .56678 L .44005 .56395 L F
.471 .304 .573 r
.44005 .56395 m .44128 .56678 L .44256 .56563 L F
0 .138 .684 r
.47307 .58145 m .47466 .58298 L .47354 .58051 L F
.617 .729 .926 r
.16793 .61887 m .16433 .61963 L .16164 .61694 L F
.876 .903 .846 r
.66715 .43758 m .66923 .43372 L .66537 .43372 L F
.66715 .43758 m .66804 .43405 L .66923 .43372 L F
.66715 .43758 m .66577 .43632 L .66804 .43405 L F
.987 .825 .595 r
.66715 .43758 m .6667 .43978 L .66577 .43632 L F
.418 .219 .5 r
.56587 .48477 m .56858 .48424 L .56886 .48204 L F
.616 .409 .579 r
.56631 .48708 m .56858 .48424 L .56587 .48477 L F
.124 .483 .899 r
.16283 .63168 m .16391 .63284 L .16509 .63282 L F
.15 .326 .786 r
.16391 .63284 m .16605 .63472 L .16509 .63282 L F
.897 .803 .748 r
.58118 .52142 m .57774 .5235 L .57843 .52107 L F
.58118 .52142 m .57951 .52472 L .57774 .5235 L F
0 0 .528 r
.53862 .5682 m .53895 .57242 L .5397 .57005 L F
.769 .69 .776 r
.83676 .42726 m .83301 .42692 L .83549 .42418 L F
.83676 .42726 m .8345 .4286 L .83301 .42692 L F
.742 .707 .818 r
.83549 .42418 m .83973 .42456 L .83676 .42726 L F
.943 .941 .756 r
.57786 .53363 m .57513 .53604 L .57684 .53263 L F
.57786 .53363 m .57598 .53699 L .57513 .53604 L F
.992 .87 .604 r
.57761 .53024 m .57786 .53363 L .57684 .53263 L F
.726 .703 .168 r
.15467 .59957 m .15414 .60217 L .15403 .60288 L F
.395 .666 .968 r
.15533 .60347 m .15403 .60288 L .15414 .60217 L F
.383 .107 .366 r
.28047 .61142 m .27776 .6142 L .27837 .61205 L F
.445 .485 .807 r
.26165 .57876 m .2646 .58132 L .26363 .57829 L F
0 0 .402 r
.43712 .57017 m .43828 .57205 L .43702 .56999 L F
.43868 .57293 m .43831 .57211 L .43712 .57017 L F
.43831 .57211 m .43828 .57205 L .43712 .57017 L F
.405 .763 .994 r
.4388 .57291 m .43618 .57328 L .43655 .57139 L F
.162 .183 .635 r
.43868 .57293 m .43967 .57597 L .44025 .57413 L F
.405 .763 .994 r
.44039 .574 m .43935 .57382 L .4388 .57291 L F
.43935 .57382 m .43618 .57328 L .4388 .57291 L F
0 0 .402 r
.43868 .57293 m .43702 .56999 L .43691 .56982 L F
0 .136 .645 r
.44025 .57413 m .43828 .57205 L .43868 .57293 L F
.44025 .57413 m .44039 .574 L .43828 .57205 L F
.405 .763 .994 r
.44039 .574 m .43655 .57139 L .43828 .57205 L F
.639 .583 .776 r
.43618 .57328 m .4382 .57181 L .43655 .57139 L F
.4382 .57181 m .44003 .57048 L .43773 .57108 L F
0 0 .402 r
.43691 .56982 m .43702 .56999 L .43683 .56968 L F
.7 .42 .495 r
.43683 .56968 m .43828 .57205 L .43655 .57139 L F
.639 .583 .776 r
.4382 .57181 m .43773 .57108 L .43655 .57139 L F
.665 .31 .362 r
.83135 .43474 m .82902 .43579 L .82954 .43417 L F
.83135 .43474 m .83207 .4364 L .82902 .43579 L F
.517 .916 .885 r
.20048 .65033 m .20182 .65029 L .20367 .64918 L F
.616 .545 .752 r
.82902 .43579 m .82707 .4398 L .82606 .43672 L F
.82902 .43579 m .82983 .43918 L .82707 .4398 L F
.376 .163 .457 r
.82983 .43918 m .82755 .44291 L .82707 .4398 L F
.863 .861 .837 r
.74602 .4011 m .74277 .40194 L .74481 .39942 L F
.064 0 0 r
.2339 .62395 m .22992 .62656 L .2321 .62596 L F
0 0 0 r
.23592 .62064 m .2339 .62395 L .23514 .62282 L F
.475 .216 .441 r
.2321 .62596 m .23514 .62282 L .2339 .62395 L F
.556 .451 .69 r
.66355 .40458 m .66254 .40656 L .66003 .40722 L F
.236 .35 .777 r
.66279 .40856 m .66003 .40722 L .66254 .40656 L F
.128 .467 .892 r
.77463 .43456 m .77237 .43473 L .77215 .43288 L F
.77463 .43456 m .7755 .4361 L .77237 .43473 L F
.473 .231 .466 r
.2759 .615 m .27545 .61734 L .2732 .61784 L F
.483 .24 .469 r
.27774 .61685 m .2759 .615 L .27776 .6142 L F
.27774 .61685 m .27545 .61734 L .2759 .615 L F
.385 .179 .473 r
.25127 .60295 m .25293 .60476 L .25341 .60233 L F
.25127 .60295 m .25099 .60552 L .25293 .60476 L F
.427 .844 .963 r
.21146 .53988 m .21363 .53933 L .21549 .53975 L F
.359 .814 .936 r
.21363 .53933 m .21768 .53921 L .21549 .53975 L F
.518 0 0 r
.76387 .37782 m .76573 .37893 L .76322 .37703 L F
.605 .369 .533 r
.49604 .60882 m .4997 .60431 L .49692 .6062 L F
.408 .202 .485 r
.4997 .60431 m .50119 .60792 L .50124 .60489 L F
.4997 .60431 m .49927 .60859 L .50119 .60792 L F
.416 .093 .307 r
.49837 .58741 m .50078 .58688 L .50159 .58482 L F
.554 .331 .531 r
.50078 .58688 m .50336 .58401 L .50159 .58482 L F
.575 .386 .588 r
.49599 .58796 m .49847 .59019 L .49837 .58741 L F
.49599 .58796 m .4963 .59097 L .49847 .59019 L F
.466 .206 .435 r
.4498 .62495 m .44744 .62318 L .44968 .62387 L F
.4498 .62495 m .44657 .6265 L .44744 .62318 L F
0 0 0 r
.67337 .44234 m .67531 .44128 L .6733 .44262 L F
.67337 .44234 m .67652 .44018 L .67531 .44128 L F
.183 0 0 r
.18927 .75678 m .18754 .75637 L .18563 .75786 L F
.18927 .75678 m .18934 .75674 L .18754 .75637 L F
.18934 .75674 m .19002 .75625 L .1898 .75626 L F
.18934 .75674 m .1898 .75626 L .18754 .75637 L F
.843 .929 .546 r
.18934 .75674 m .18901 .75773 L .18927 .75678 L F
.79 .866 .426 r
.18754 .76048 m .18901 .75773 L .18934 .75674 L F
.843 .929 .546 r
.18958 .75599 m .18934 .75674 L .18927 .75678 L F
.71 .752 .885 r
.18731 .75966 m .18737 .75987 L .18551 .7592 L F
.592 .37 .548 r
.18568 .75931 m .18927 .75678 L .18563 .75786 L F
.493 .295 .539 r
.18551 .7592 m .18568 .75931 L .18569 .75953 L F
.592 .37 .548 r
.18569 .75953 m .18586 .75941 L .18568 .75931 L F
.831 .874 .875 r
.18584 .7594 m .18586 .75941 L .18569 .75953 L F
.592 .37 .548 r
.18586 .75941 m .18927 .75678 L .18568 .75931 L F
.71 .752 .885 r
.18737 .75987 m .18586 .75941 L .18551 .7592 L F
.831 .874 .875 r
.18958 .75599 m .18927 .75678 L .18586 .75941 L F
.18958 .75599 m .18586 .75941 L .18584 .7594 L F
.71 .752 .885 r
.18737 .75987 m .18754 .76048 L .18584 .7594 L F
.504 .284 .514 r
.18754 .76048 m .18958 .75599 L .18584 .7594 L F
.18754 .76048 m .18584 .7594 L .18569 .75953 L F
.71 .752 .885 r
.18584 .7594 m .18754 .76048 L .18583 .7594 L F
.493 .295 .539 r
.18568 .75931 m .18754 .76048 L .18569 .75953 L F
.71 .752 .885 r
.18586 .75941 m .18583 .7594 L .18568 .75931 L F
.592 .37 .548 r
.18558 .75928 m .18563 .75786 L .18503 .75802 L F
.18569 .75953 m .18568 .75931 L .18558 .75928 L F
.71 .752 .885 r
.1857 .75931 m .18568 .75931 L .18551 .7592 L F
.592 .37 .548 r
.18568 .75931 m .18563 .75786 L .18558 .75928 L F
.71 .752 .885 r
.18586 .75941 m .18568 .75931 L .1857 .75931 L F
.79 .866 .426 r
.18916 .75691 m .18934 .75674 L .18958 .75599 L F
.18754 .76048 m .18934 .75674 L .18916 .75691 L F
.183 0 0 r
.18927 .75678 m .19006 .75625 L .19002 .75625 L F
.516 .34 .582 r
.24601 .61144 m .24838 .60823 L .24634 .60892 L F
0 0 .27 r
.57857 .58395 m .57825 .5863 L .57675 .58757 L F
0 0 .222 r
.57825 .5863 m .57722 .58975 L .57675 .58757 L F
.654 .971 .858 r
.78343 .44271 m .78503 .44083 L .78682 .44058 L F
.78343 .44271 m .783 .44238 L .78503 .44083 L F
.544 0 0 r
.66471 .40344 m .6684 .40446 L .66995 .40596 L F
.66471 .40344 m .66995 .40596 L .66604 .40576 L F
.66471 .40344 m .66766 .40512 L .6684 .40446 L F
.638 .079 0 r
.66766 .40512 m .67096 .40636 L .6684 .40446 L F
.587 .815 .986 r
.29569 .54827 m .29181 .54781 L .29407 .54732 L F
0 .01 .546 r
.29623 .54862 m .29569 .54827 L .29407 .54732 L F
.29623 .54862 m .29779 .55054 L .29569 .54827 L F
.481 .292 .546 r
.29779 .55054 m .29524 .55128 L .29569 .54827 L F
.635 .636 .834 r
.74676 .41787 m .74757 .42017 L .75056 .41919 L F
.923 .596 .405 r
.81613 .44731 m .81365 .44519 L .8158 .44723 L F
.763 .793 .877 r
.80108 .42421 m .80235 .42613 L .79888 .42778 L F
.327 0 0 r
.43001 .63281 m .43126 .63361 L .43085 .63277 L F
.645 .205 0 r
.43024 .63211 m .43126 .63361 L .43001 .63281 L F
.43024 .63211 m .43138 .63386 L .43126 .63361 L F
.43138 .63386 m .43154 .63411 L .43126 .63361 L F
.327 0 0 r
.43085 .63277 m .43126 .63361 L .43451 .63262 L F
.499 0 0 r
.43126 .63361 m .43611 .63334 L .43451 .63262 L F
.79 .801 .861 r
.72214 .41696 m .72348 .41249 L .72067 .4152 L F
.72214 .41696 m .72416 .41534 L .72348 .41249 L F
0 0 .092 r
.15509 .59905 m .15467 .59957 L .15581 .59683 L F
.547 .773 .982 r
.15632 .59495 m .15581 .59683 L .15432 .59519 L F
.15632 .59495 m .15796 .5963 L .15581 .59683 L F
.557 .87 .58 r
.15796 .5963 m .15509 .59905 L .15581 .59683 L F
.472 .337 .615 r
.29491 .57906 m .29564 .5813 L .29359 .58178 L F
.54 .336 .552 r
.29584 .58382 m .29359 .58178 L .29564 .5813 L F
.29584 .58382 m .29356 .58428 L .29359 .58178 L F
.378 .343 .693 r
.42064 .6545 m .42151 .65615 L .41908 .65421 L F
.338 .749 .98 r
.78342 .3973 m .78475 .39635 L .78229 .39686 L F
.78342 .3973 m .78602 .39716 L .78475 .39635 L F
.601 .262 .367 r
.50537 .60327 m .50476 .60497 L .50286 .60452 L F
.745 .634 .737 r
.50759 .59981 m .50537 .60327 L .50479 .60008 L F
0 0 0 r
.45473 .58565 m .45556 .58566 L .45646 .58426 L F
.45473 .58565 m .45397 .58718 L .45556 .58566 L F
.583 .56 .795 r
.17136 .67256 m .1757 .67493 L .17294 .67549 L F
.232 0 0 r
.17294 .67549 m .1757 .67493 L .17448 .67573 L F
0 .502 .799 r
.17101 .67477 m .17294 .67549 L .17448 .67573 L F
.731 .203 0 r
.53428 .56288 m .5364 .5653 L .53694 .56477 L F
.78 .276 0 r
.5364 .5653 m .53834 .56635 L .53694 .56477 L F
.846 .583 .542 r
.59199 .48518 m .59203 .48763 L .59517 .4882 L F
.846 .666 .658 r
.59203 .48763 m .59364 .49099 L .59517 .4882 L F
.615 .514 .716 r
.46095 .6199 m .46202 .62373 L .45956 .6239 L F
.514 .345 .589 r
.46189 .62608 m .45956 .6239 L .46202 .62373 L F
.46189 .62608 m .45969 .62663 L .45956 .6239 L F
.183 0 0 r
.47572 .56486 m .47462 .56393 L .47674 .56428 L F
.47572 .56486 m .47337 .56545 L .47462 .56393 L F
.519 .303 .527 r
.17101 .67477 m .1691 .67207 L .16878 .67461 L F
.17101 .67477 m .17148 .67161 L .1691 .67207 L F
.817 .757 .797 r
.82835 .42932 m .82447 .4305 L .82705 .42748 L F
.82835 .42932 m .82618 .43123 L .82447 .4305 L F
.732 .769 .882 r
.83056 .42796 m .82835 .42932 L .82705 .42748 L F
.244 0 0 r
.45424 .62091 m .45752 .62168 L .4556 .6212 L F
.36 .073 .334 r
.4287 .62679 m .43105 .6263 L .4312 .62423 L F
.616 .688 .895 r
.46419 .58965 m .46407 .59105 L .46163 .59043 L F
.712 .539 .653 r
.46508 .59346 m .46163 .59043 L .46407 .59105 L F
.462 .548 .858 r
.46419 .58965 m .46671 .59003 L .46407 .59105 L F
0 0 0 r
.46671 .59003 m .46508 .59346 L .46407 .59105 L F
.572 .416 .631 r
.45457 .61357 m .45487 .61784 L .45199 .6179 L F
.537 .332 .549 r
.45487 .61784 m .45249 .62042 L .45199 .6179 L F
.514 .553 .833 r
.52311 .52683 m .52298 .52806 L .52517 .52618 L F
.333 .271 .637 r
.52358 .53035 m .52517 .52618 L .52298 .52806 L F
.354 .165 .48 r
.25783 .59078 m .2594 .59277 L .25962 .58938 L F
.25783 .59078 m .25759 .59331 L .2594 .59277 L F
.534 .344 .569 r
.70647 .40605 m .70888 .4035 L .70633 .40408 L F
.353 .122 .418 r
.42757 .64384 m .42615 .64177 L .42866 .64077 L F
.42757 .64384 m .42563 .64484 L .42615 .64177 L F
.091 0 0 r
.53487 .51164 m .53705 .51125 L .53823 .50969 L F
.293 0 .184 r
.53705 .51125 m .54 .50827 L .53823 .50969 L F
.466 .453 .76 r
.55512 .5777 m .55518 .58068 L .55383 .58163 L F
0 0 .07 r
.55454 .58066 m .55371 .58361 L .55521 .58271 L F
.811 .462 0 r
.55454 .58066 m .55521 .58271 L .55462 .58132 L F
.466 .453 .76 r
.55443 .57978 m .55383 .58163 L .55454 .58066 L F
.811 .462 0 r
.55454 .58066 m .55462 .58132 L .55373 .57924 L F
.466 .453 .76 r
.55512 .5777 m .55443 .57978 L .55454 .58066 L F
.607 .459 .655 r
.80644 .43337 m .80412 .43684 L .80402 .43418 L F
.785 .546 .575 r
.80436 .42225 m .80465 .42483 L .80108 .42421 L F
.528 .416 .67 r
.80667 .41911 m .80436 .42225 L .80334 .41874 L F
.80667 .41911 m .807 .42153 L .80436 .42225 L F
.514 .374 .629 r
.80436 .42225 m .80729 .42415 L .80465 .42483 L F
.80436 .42225 m .807 .42153 L .80729 .42415 L F
.535 .832 .999 r
.45174 .62325 m .44968 .62387 L .45324 .62416 L F
0 .012 .535 r
.45324 .62416 m .45423 .62502 L .45174 .62325 L F
.45324 .62416 m .45512 .62611 L .45423 .62502 L F
.221 0 .094 r
.50144 .60294 m .50479 .60008 L .5013 .59966 L F
.522 .546 .821 r
.50286 .60452 m .50476 .60497 L .504 .60203 L F
.50286 .60452 m .504 .60203 L .50144 .60294 L F
.663 .639 .815 r
.504 .60203 m .50476 .60497 L .50124 .60489 L F
.519 .581 .857 r
.50393 .60413 m .50418 .6026 L .504 .60203 L F
0 0 0 r
.50479 .60008 m .504 .60203 L .50618 .5988 L F
.825 .97 .657 r
.50618 .5988 m .504 .60203 L .50458 .60005 L F
.519 .581 .857 r
.50418 .6026 m .50458 .60005 L .504 .60203 L F
.221 0 .094 r
.50369 .60102 m .504 .60203 L .50479 .60008 L F
.50144 .60294 m .504 .60203 L .50369 .60102 L F
.275 0 0 r
.17808 .54779 m .18035 .54748 L .18225 .54581 L F
.1 0 0 r
.18035 .54748 m .18445 .54529 L .18225 .54581 L F
.803 .488 .457 r
.41939 .64418 m .42277 .64196 L .42051 .64027 L F
.814 .626 .648 r
.41939 .64418 m .42504 .64517 L .4252 .64518 L F
.42258 .64474 m .42213 .64496 L .42504 .64517 L F
.707 .402 .457 r
.42258 .64474 m .42257 .64496 L .4226 .64474 L F
.814 .626 .648 r
.41939 .64418 m .42213 .64496 L .42258 .64474 L F
.803 .488 .457 r
.41939 .64418 m .42257 .64496 L .42258 .64474 L F
.814 .626 .648 r
.41939 .64418 m .4226 .64474 L .42257 .64496 L F
.4226 .64474 m .4252 .64518 L .42257 .64496 L F
.707 .402 .457 r
.4226 .64474 m .42257 .64496 L .42459 .64379 L F
.42459 .64379 m .42257 .64496 L .42563 .64484 L F
.42277 .64196 m .42258 .64474 L .42459 .64379 L F
.814 .626 .648 r
.41939 .64418 m .41948 .64476 L .42213 .64496 L F
.803 .488 .457 r
.41939 .64418 m .42258 .64474 L .42277 .64196 L F
.707 .402 .457 r
.42277 .64196 m .42563 .64484 L .42385 .64045 L F
.69 .766 .91 r
.80465 .42483 m .80235 .42613 L .80108 .42421 L F
.938 .607 .168 r
.76573 .37893 m .76719 .38242 L .76669 .38011 L F
.597 .916 .975 r
.2231 .66847 m .22667 .66612 L .22329 .66635 L F
.501 .191 .373 r
.73835 .37672 m .73769 .37915 L .73505 .37956 L F
.94 .604 .175 r
.73985 .37322 m .73835 .37672 L .7373 .37412 L F
.73985 .37322 m .74109 .37623 L .73835 .37672 L F
.612 .342 .483 r
.74109 .37623 m .73769 .37915 L .73835 .37672 L F
.109 0 0 r
.69851 .42997 m .70208 .42782 L .69954 .42876 L F
.505 .903 .929 r
.70208 .42782 m .70447 .42688 L .70376 .42654 L F
.488 .896 .782 r
.69954 .42876 m .70208 .42782 L .70376 .42654 L F
.543 .025 0 r
.7792 .44923 m .78048 .45066 L .77813 .44808 L F
.7792 .44923 m .78174 .45175 L .78048 .45066 L F
.733 .218 0 r
.78254 .45126 m .78174 .45175 L .7792 .44923 L F
.223 .021 .381 r
.26028 .58763 m .26191 .58684 L .26237 .58446 L F
.416 .171 .432 r
.25962 .58938 m .26191 .58684 L .26028 .58763 L F
.593 .671 .894 r
.45659 .61685 m .46095 .6199 L .46154 .61798 L F
.287 0 .224 r
.46095 .6199 m .4642 .61722 L .46154 .61798 L F
.214 .271 .706 r
.43635 .61047 m .43351 .60765 L .4376 .60758 L F
.355 .003 .222 r
.43876 .60966 m .4376 .60758 L .43974 .60725 L F
.43876 .60966 m .43635 .61047 L .4376 .60758 L F
.204 .722 .691 r
.78519 .45077 m .78174 .45175 L .78254 .45126 L F
.811 .799 .841 r
.50295 .52916 m .50753 .52757 L .50622 .52623 L F
.559 .779 .981 r
.50622 .52623 m .50753 .52757 L .50845 .52578 L F
.98 .697 .41 r
.50945 .53005 m .50845 .52578 L .50753 .52757 L F
.736 .326 0 r
.51326 .55622 m .5141 .55767 L .51318 .55633 L F
0 0 .528 r
.5141 .55767 m .51521 .55855 L .51318 .55633 L F
.864 .444 .223 r
.51521 .55855 m .51305 .55648 L .51318 .55633 L F
.51305 .55648 m .51183 .55532 L .51318 .55633 L F
.736 .326 0 r
.51221 .55441 m .51326 .55622 L .51318 .55633 L F
0 0 .528 r
.5141 .55767 m .5158 .56016 L .51521 .55855 L F
.798 .895 .912 r
.50896 .53844 m .51016 .53961 L .51369 .53726 L F
0 0 .496 r
.51133 .5404 m .51016 .53961 L .50896 .53844 L F
.51133 .5404 m .5114 .54187 L .51016 .53961 L F
.951 .941 .619 r
.23481 .59965 m .23337 .60135 L .2338 .60062 L F
.674 .623 .791 r
.23337 .60135 m .23381 .60071 L .2338 .60062 L F
.916 .546 .308 r
.23481 .59965 m .2338 .60062 L .2335 .59806 L F
.674 .623 .791 r
.23381 .60071 m .23543 .59834 L .2338 .60062 L F
.916 .546 .308 r
.2335 .59806 m .2338 .60062 L .2319 .59612 L F
.951 .941 .619 r
.23481 .59965 m .23351 .60294 L .23337 .60135 L F
.352 .336 .702 r
.23616 .59591 m .2359 .59965 L .23481 .59965 L F
.68 .783 .928 r
.73278 .40001 m .73237 .40219 L .73039 .40021 L F
.73278 .40001 m .73349 .40173 L .73237 .40219 L F
.883 .811 .773 r
.45788 .58766 m .45385 .58925 L .45397 .58718 L F
.45788 .58766 m .45554 .59107 L .45385 .58925 L F
.746 .596 .69 r
.45788 .58766 m .45859 .59169 L .45554 .59107 L F
.714 .575 .697 r
.46163 .59043 m .45788 .58766 L .46051 .5871 L F
.46163 .59043 m .45859 .59169 L .45788 .58766 L F
.602 .591 .812 r
.46419 .58965 m .46163 .59043 L .46051 .5871 L F
.712 .539 .653 r
.46508 .59346 m .46297 .59546 L .46163 .59043 L F
.38 .388 .743 r
.4406 .60145 m .43906 .60508 L .43815 .60207 L F
.4406 .60145 m .4413 .60498 L .43906 .60508 L F
.484 .431 .723 r
.29378 .58685 m .29227 .59069 L .29187 .5872 L F
.29378 .58685 m .2943 .59026 L .29227 .59069 L F
.575 .411 .621 r
.2943 .59026 m .29211 .59306 L .29227 .59069 L F
.329 .059 .342 r
.56248 .57882 m .56462 .57798 L .56542 .57583 L F
.576 .761 .966 r
.56139 .57727 m .56462 .57798 L .56248 .57882 L F
.749 .791 .887 r
.18361 .73877 m .18441 .73819 L .18276 .73794 L F
.657 .908 .98 r
.45118 .61222 m .45194 .61003 L .45335 .60893 L F
.022 .068 .571 r
.45335 .60893 m .454 .60516 L .45215 .60467 L F
.562 .444 .676 r
.81074 .4096 m .81074 .41213 L .80857 .41266 L F
.567 .432 .657 r
.81074 .41213 m .80908 .41591 L .80857 .41266 L F
.962 .756 .58 r
.68286 .42237 m .68119 .42374 L .68096 .42169 L F
.68286 .42237 m .68271 .42492 L .68119 .42374 L F
.334 .81 .9 r
.22747 .64704 m .22956 .6472 L .23136 .64673 L F
.967 .841 .666 r
.58997 .52497 m .59122 .52414 L .59042 .5211 L F
.938 .718 .578 r
.59072 .52699 m .59122 .52414 L .58997 .52497 L F
.822 .786 .819 r
.59122 .52414 m .59427 .52058 L .59042 .5211 L F
.138 .601 .925 r
.20061 .62998 m .19715 .6287 L .19886 .62907 L F
.498 .815 1 r
.20272 .62949 m .20061 .62998 L .19886 .62907 L F
.506 .576 .86 r
.74255 .41584 m .74546 .41482 L .74299 .41525 L F
.74255 .41584 m .74676 .41787 L .74546 .41482 L F
.589 .439 .646 r
.49376 .58379 m .49106 .58166 L .49348 .58111 L F
.49376 .58379 m .49119 .58428 L .49106 .58166 L F
.609 .074 0 r
.5171 .56117 m .51694 .56144 L .5158 .56016 L F
.5171 .56117 m .51821 .56233 L .51694 .56144 L F
.687 .428 .525 r
.69257 .41237 m .69455 .4099 L .69212 .41006 L F
.264 .713 .958 r
.26103 .557 m .26007 .55765 L .25819 .55478 L F
.26007 .55765 m .26103 .557 L .25804 .55816 L F
.26007 .55765 m .26313 .55801 L .26103 .557 L F
.435 .382 .701 r
.26138 .56367 m .26327 .56336 L .2626 .56069 L F
0 0 .523 r
.51317 .58687 m .51444 .59042 L .51366 .58894 L F
.624 .333 .456 r
.45646 .58426 m .45882 .58456 L .4601 .58169 L F
.629 .339 .459 r
.4601 .58169 m .46226 .5837 L .46277 .58186 L F
.4601 .58169 m .45882 .58456 L .46226 .5837 L F
.209 .704 .919 r
.25704 .53907 m .25613 .53964 L .25442 .53936 L F
.25704 .53907 m .25841 .53961 L .25613 .53964 L F
.89 .973 .828 r
.48452 .5744 m .48386 .57789 L .48643 .57762 L F
.48452 .5744 m .48234 .5773 L .48386 .57789 L F
.051 0 .157 r
.20956 .69674 m .20839 .6998 L .20999 .69815 L F
.746 .748 .233 r
.58527 .5545 m .58472 .5562 L .58475 .55641 L F
0 0 0 r
.58607 .55262 m .58472 .5562 L .58527 .5545 L F
.783 .743 .816 r
.55625 .59024 m .55903 .5908 L .55754 .5877 L F
.8 .476 .441 r
.55628 .59186 m .55903 .5908 L .55625 .59024 L F
.55628 .59186 m .55742 .59283 L .55903 .5908 L F
.453 .572 .884 r
.55754 .5877 m .55903 .5908 L .56078 .58934 L F
.246 0 .049 r
.55903 .5908 m .56049 .59038 L .56078 .58934 L F
.55903 .5908 m .55742 .59283 L .56049 .59038 L F
.453 .572 .884 r
.55754 .5877 m .55903 .5908 L .56078 .58934 L F
0 0 0 r
.46775 .56599 m .46665 .56735 L .46829 .56531 L F
.377 .83 .929 r
.47156 .56529 m .46775 .56599 L .46829 .56531 L F
.708 .681 .822 r
.83301 .42692 m .8345 .4286 L .83056 .42796 L F
0 0 0 r
.73352 .37749 m .73243 .38004 L .73403 .37785 L F
.58 .742 .953 r
.73243 .38004 m .73352 .37749 L .73403 .37785 L F
.73243 .38004 m .73505 .37956 L .73352 .37749 L F
.427 .533 .862 r
.78602 .39716 m .78744 .40007 L .78962 .40021 L F
.336 0 0 r
.42775 .61998 m .42592 .62192 L .42366 .62148 L F
.385 .784 .986 r
.44696 .61176 m .44721 .61172 L .45118 .61222 L F
.738 .504 .576 r
.44748 .61175 m .44314 .61372 L .44831 .61185 L F
.44308 .61116 m .44831 .61185 L .44696 .61176 L F
.44308 .61116 m .44308 .6114 L .44748 .61175 L F
.44308 .6114 m .44314 .61372 L .44748 .61175 L F
.385 .784 .986 r
.44822 .6118 m .44975 .61137 L .45083 .61201 L F
.44721 .61172 m .45083 .61201 L .45118 .61222 L F
.419 .218 .498 r
.44913 .61243 m .45067 .61112 L .44975 .61137 L F
.657 .908 .98 r
.45118 .61222 m .44975 .61137 L .45194 .61003 L F
.419 .218 .498 r
.45067 .61112 m .45194 .61003 L .44975 .61137 L F
.385 .784 .986 r
.44721 .61172 m .44975 .61137 L .44822 .6118 L F
.962 .748 .567 r
.57598 .53699 m .57404 .5381 L .57513 .53604 L F
.57598 .53699 m .57564 .53921 L .57404 .5381 L F
.476 .257 .502 r
.27545 .61734 m .27294 .6203 L .2732 .61784 L F
.25 .287 .705 r
.23472 .61477 m .23698 .61691 L .23601 .61339 L F
.443 .213 .468 r
.27249 .62266 m .27072 .62083 L .27294 .6203 L F
.27249 .62266 m .27033 .62321 L .27072 .62083 L F
.866 .63 .098 r
.72216 .39366 m .72237 .39444 L .72191 .3938 L F
.883 .945 .848 r
.72237 .39444 m .71869 .39593 L .72191 .3938 L F
.297 .081 .407 r
.2632 .57269 m .26528 .57204 L .26569 .5694 L F
0 0 .342 r
.2632 .57269 m .26418 .57406 L .26528 .57204 L F
.2632 .57269 m .26327 .57566 L .26418 .57406 L F
.468 .145 .335 r
.80149 .43765 m .80127 .4393 L .79861 .43975 L F
.637 .395 .535 r
.80412 .43684 m .80127 .4393 L .80149 .43765 L F
.749 .757 .859 r
.79218 .42508 m .79003 .42614 L .78869 .42442 L F
.79218 .42508 m .79003 .42614 L .78869 .42442 L F
.58 .625 .861 r
.79003 .42614 m .7919 .42673 L .79218 .42508 L F
.652 .293 .35 r
.25898 .55155 m .25716 .55471 L .2552 .552 L F
.717 .217 0 r
.25898 .55155 m .2591 .55256 L .25716 .55471 L F
.25898 .55155 m .26091 .5544 L .2591 .55256 L F
.43 .594 .912 r
.44845 .63383 m .45118 .63454 L .44857 .635 L F
.353 .187 .512 r
.45138 .63723 m .44857 .635 L .45118 .63454 L F
.45138 .63723 m .44886 .63844 L .44857 .635 L F
.819 .338 .024 r
.51743 .60502 m .51416 .60173 L .51457 .60331 L F
.696 .372 .424 r
.66681 .40794 m .66254 .40656 L .66604 .40576 L F
.66681 .40794 m .66279 .40856 L .66254 .40656 L F
.759 .611 .694 r
.66995 .40596 m .66681 .40794 L .66604 .40576 L F
.623 .223 .264 r
.66681 .40794 m .66531 .40927 L .66279 .40856 L F
.453 .306 .591 r
.66564 .40846 m .66791 .40754 L .66607 .40741 L F
.66531 .40927 m .66612 .40873 L .66564 .40846 L F
.874 .448 .19 r
.6699 .41022 m .66975 .41079 L .66681 .40794 L F
.66975 .41079 m .6678 .40968 L .66681 .40794 L F
.865 .418 .061 r
.66681 .40794 m .66746 .41069 L .66531 .40927 L F
.66709 .40914 m .66935 .4124 L .66746 .41069 L F
.66681 .40794 m .6678 .40968 L .66709 .40914 L F
.6678 .40968 m .66935 .4124 L .66709 .40914 L F
.453 .306 .591 r
.66612 .40873 m .66635 .40858 L .66564 .40846 L F
.66635 .40858 m .66791 .40754 L .66601 .40831 L F
.66635 .40858 m .66601 .40831 L .66564 .40846 L F
.874 .448 .19 r
.66975 .41079 m .66935 .4124 L .6678 .40968 L F
0 0 .532 r
.6699 .41022 m .67114 .41241 L .67121 .41153 L F
.67109 .41116 m .67121 .41153 L .67124 .41126 L F
.6699 .41022 m .67121 .41153 L .67109 .41114 L F
.894 .701 .635 r
.67114 .41241 m .66875 .41357 L .67124 .41126 L F
.637 .934 .682 r
.6705 .41139 m .67124 .41126 L .66875 .41357 L F
.389 0 0 r
.6705 .41139 m .67216 .41191 L .67124 .41126 L F
.67216 .41191 m .67397 .41246 L .67124 .41126 L F
0 0 .532 r
.67109 .41114 m .67109 .41116 L .67124 .41126 L F
.6699 .41022 m .67124 .41126 L .66935 .4124 L F
.664 .516 .674 r
.66935 .4124 m .67066 .40981 L .66791 .40754 L F
.67066 .40981 m .67151 .40811 L .67003 .40788 L F
.67066 .40981 m .67003 .40788 L .66791 .40754 L F
.536 .359 .588 r
.67146 .4312 m .67181 .43395 L .67445 .43091 L F
.428 .313 .62 r
.29356 .58428 m .29378 .58685 L .29187 .5872 L F
.14 0 .097 r
.39656 .60864 m .39859 .60789 L .39907 .60629 L F
.541 .139 .228 r
.39907 .60629 m .40117 .60772 L .40168 .60569 L F
.39907 .60629 m .39859 .60789 L .40117 .60772 L F
.51 .459 .735 r
.47939 .5714 m .48074 .56881 L .47891 .56967 L F
0 0 .53 r
.52361 .56918 m .52328 .56824 L .52156 .5661 L F
0 0 .452 r
.52581 .57277 m .52523 .57162 L .52361 .56918 L F
.703 .226 0 r
.52361 .56918 m .52523 .57162 L .52408 .57052 L F
.52361 .56918 m .52408 .57052 L .52328 .56824 L F
.16 .699 .743 r
.50227 .52275 m .5047 .52232 L .50624 .52216 L F
.147 .691 .756 r
.5047 .52232 m .509 .52185 L .50624 .52216 L F
.779 .699 .775 r
.77663 .41487 m .77859 .41915 L .78111 .41606 L F
.834 .723 .741 r
.23192 .5903 m .23342 .59375 L .23042 .59276 L F
.672 .319 0 r
.2319 .59612 m .23042 .59276 L .23342 .59375 L F
.529 .487 .754 r
.23513 .58972 m .23342 .59375 L .23192 .5903 L F
0 0 0 r
.1566 .55781 m .1565 .55837 L .15862 .55708 L F
.1566 .55781 m .15449 .55929 L .1565 .55837 L F
.183 .131 .561 r
.39571 .61763 m .39692 .61728 L .39704 .61374 L F
.206 .207 .639 r
.39571 .61763 m .39761 .6197 L .39692 .61728 L F
.286 0 0 r
.18659 .54398 m .18875 .5441 L .19108 .54317 L F
.075 0 0 r
.18875 .5441 m .19318 .5424 L .19108 .54317 L F
.511 .737 .976 r
.26668 .53998 m .26602 .54182 L .26442 .54047 L F
.26668 .53998 m .26824 .54147 L .26602 .54182 L F
.677 .28 .287 r
.57175 .50566 m .56766 .50543 L .5671 .50384 L F
.762 .591 .666 r
.58836 .48476 m .59214 .48252 L .58829 .48224 L F
.58836 .48476 m .59199 .48518 L .59214 .48252 L F
.228 0 .197 r
.15389 .58388 m .15365 .58408 L .15302 .58327 L F
0 0 .406 r
.15302 .58327 m .15302 .58492 L .15238 .58244 L F
.276 .57 .937 r
.15263 .58389 m .15302 .58492 L .15302 .58327 L F
.228 0 .197 r
.15365 .58408 m .15215 .58532 L .15302 .58327 L F
0 0 .406 r
.15302 .58327 m .15238 .58244 L .15211 .58141 L F
.425 .043 .208 r
.45807 .60312 m .46091 .60437 L .4606 .60263 L F
.704 .52 .637 r
.45751 .60129 m .46091 .60437 L .45807 .60312 L F
.773 .625 .697 r
.66193 .44607 m .66556 .4468 L .66477 .44213 L F
.599 .507 .721 r
.66477 .44213 m .66556 .4468 L .66801 .4458 L F
.421 .001 .133 r
.51128 .52096 m .51509 .51894 L .51145 .52157 L F
.51128 .52096 m .51377 .5207 L .51509 .51894 L F
.636 .364 .489 r
.51377 .5207 m .51738 .5181 L .51509 .51894 L F
.678 .228 .174 r
.51141 .53314 m .51343 .53453 L .51516 .53356 L F
.532 .248 .43 r
.51139 .53501 m .51293 .53483 L .51141 .53314 L F
.51293 .53483 m .51404 .5347 L .51347 .53436 L F
.729 .982 .766 r
.51516 .53356 m .51343 .53453 L .51481 .53322 L F
.51516 .53356 m .51481 .53322 L .51606 .53215 L F
.768 .61 .683 r
.51626 .53184 m .51372 .53478 L .51516 .53356 L F
.51372 .53478 m .51371 .53481 L .51516 .53356 L F
.729 .982 .766 r
.51606 .53215 m .51481 .53322 L .51626 .53184 L F
.768 .61 .683 r
.51372 .53478 m .51366 .53486 L .51371 .53481 L F
.5137 .5348 m .51404 .5347 L .51366 .53486 L F
.51626 .53184 m .51404 .5347 L .5137 .5348 L F
.23 .686 .95 r
.51366 .53486 m .51785 .53557 L .51404 .5347 L F
.768 .61 .683 r
.51626 .53184 m .51785 .53557 L .51404 .5347 L F
0 .014 .55 r
.5165 .53756 m .51404 .5347 L .51785 .53557 L F
.862 .721 .705 r
.51603 .53684 m .51509 .53438 L .51404 .5347 L F
.693 .905 .554 r
.51404 .5347 m .51626 .53184 L .5135 .53447 L F
.51404 .5347 m .5135 .53447 L .51343 .53453 L F
.51404 .5347 m .5147 .53336 L .51626 .53184 L F
.862 .721 .705 r
.51509 .53438 m .5147 .53336 L .51404 .5347 L F
0 .337 .819 r
.51141 .53314 m .5138 .53456 L .51343 .53453 L F
.5138 .53456 m .51404 .5347 L .51378 .53463 L F
.5138 .53456 m .51378 .53463 L .51343 .53453 L F
.532 .248 .43 r
.51293 .53483 m .51347 .53436 L .51141 .53314 L F
0 0 0 r
.46531 .56907 m .46406 .57028 L .46665 .56735 L F
.46708 .56783 m .46665 .56735 L .46775 .56599 L F
.46708 .56783 m .46531 .56907 L .46665 .56735 L F
.53 .285 .489 r
.45687 .6118 m .45666 .61412 L .45457 .61357 L F
.404 .289 .608 r
.4568 .6164 m .45457 .61357 L .45666 .61412 L F
.4568 .6164 m .45487 .61784 L .45457 .61357 L F
.51 .268 .484 r
.45687 .6118 m .45873 .61373 L .45666 .61412 L F
.536 .269 .457 r
.45958 .61146 m .45873 .61373 L .45687 .6118 L F
.203 .273 .714 r
.21285 .68424 m .21461 .68608 L .21448 .68499 L F
.414 .317 .635 r
.21285 .68424 m .2131 .68692 L .21461 .68608 L F
.346 .212 .552 r
.19415 .73252 m .19217 .73522 L .19413 .73526 L F
0 0 0 r
.16793 .61887 m .16755 .61937 L .16966 .61768 L F
0 .055 .617 r
.16966 .61768 m .17031 .61672 L .16755 .61937 L F
.784 .282 0 r
.16966 .61768 m .17157 .62033 L .17331 .621 L F
0 .055 .617 r
.16966 .61768 m .17157 .62033 L .17031 .61672 L F
.715 .599 .725 r
.7919 .42673 m .79669 .42761 L .79548 .42563 L F
.575 .294 .453 r
.79376 .42896 m .79589 .43025 L .79669 .42761 L F
.79376 .42896 m .79589 .43025 L .79669 .42761 L F
.277 .154 .526 r
.79669 .42761 m .79842 .42456 L .79548 .42563 L F
.748 .933 .948 r
.5663 .57475 m .56542 .57583 L .56564 .57379 L F
.997 .858 .557 r
.56542 .57583 m .56377 .57712 L .56564 .57379 L F
.56542 .57583 m .56462 .57798 L .56377 .57712 L F
0 0 .326 r
.58244 .56783 m .58147 .5667 L .58295 .5651 L F
.58244 .56783 m .58149 .5695 L .58147 .5667 L F
.516 .502 .78 r
.45103 .59852 m .45256 .59629 L .44891 .59563 L F
.45103 .59852 m .45349 .59883 L .45256 .59629 L F
.501 .741 .981 r
.27647 .54196 m .27581 .54365 L .27423 .54207 L F
.27647 .54196 m .27814 .54339 L .27581 .54365 L F
.001 .57 .78 r
.48911 .57462 m .49036 .57468 L .48954 .57476 L F
.48911 .57462 m .49036 .57468 L .48954 .57476 L F
.616 .426 .602 r
.47684 .61729 m .47702 .62062 L .47424 .62068 L F
.712 .443 .517 r
.82954 .43417 m .82606 .43672 L .82618 .43379 L F
.82954 .43417 m .82902 .43579 L .82606 .43672 L F
.989 .725 .41 r
.48346 .56827 m .48494 .57004 L .48462 .56663 L F
.267 0 0 r
.48704 .56748 m .48462 .56663 L .48753 .56842 L F
.538 .389 .627 r
.48462 .56663 m .48494 .57004 L .48753 .56842 L F
.267 0 0 r
.48704 .56748 m .48346 .56827 L .48462 .56663 L F
.747 .944 .947 r
.71182 .42064 m .71255 .42143 L .71603 .41941 L F
.56 .745 .964 r
.17158 .64101 m .17486 .64186 L .17259 .64045 L F
.593 .756 .956 r
.17259 .64045 m .17486 .64186 L .17738 .64143 L F
.517 .41 .672 r
.47157 .5958 m .46953 .59901 L .46901 .59641 L F
.47157 .5958 m .47219 .5985 L .46953 .59901 L F
.466 .198 .423 r
.47143 .60135 m .46953 .59901 L .47219 .5985 L F
.47143 .60135 m .46917 .60189 L .46953 .59901 L F
.714 .784 .907 r
.1678 .66685 m .16967 .6657 L .16618 .66527 L F
.187 0 .314 r
.23994 .55665 m .23762 .55996 L .23821 .5577 L F
.962 .662 .245 r
.52917 .56167 m .53015 .56296 L .52989 .56045 L F
0 0 .384 r
.53156 .55645 m .53153 .55895 L .52989 .56045 L F
.492 .29 .533 r
.53283 .56185 m .52989 .56045 L .53153 .55895 L F
.53283 .56185 m .53015 .56296 L .52989 .56045 L F
.848 .824 .346 r
.2131 .68692 m .21229 .69046 L .21233 .68929 L F
.744 .652 .095 r
.21212 .69173 m .21229 .69046 L .21233 .68929 L F
.848 .824 .346 r
.21233 .68929 m .21229 .69046 L .2131 .68692 L F
.744 .652 .095 r
.21233 .68929 m .21229 .69046 L .21212 .69173 L F
0 .493 .754 r
.21469 .69083 m .21793 .6916 L .21229 .69046 L F
.813 .531 .512 r
.21418 .69453 m .2177 .69506 L .21788 .69156 L F
.68 .954 .951 r
.21789 .69137 m .21793 .6916 L .21595 .69103 L F
0 .493 .754 r
.21538 .69093 m .21703 .69137 L .21469 .69083 L F
.21703 .69137 m .21793 .6916 L .21469 .69083 L F
.2172 .69139 m .21793 .6916 L .21538 .69093 L F
.21568 .69105 m .21229 .69046 L .21212 .69173 L F
.21579 .69103 m .21574 .69102 L .21568 .69105 L F
.21574 .69102 m .21229 .69046 L .21568 .69105 L F
.21583 .691 m .21229 .69046 L .21579 .69103 L F
.444 .259 .535 r
.21212 .69173 m .21568 .69105 L .21233 .68929 L F
0 .493 .754 r
.21587 .69101 m .2172 .69139 L .21538 .69093 L F
.851 .726 .724 r
.2157 .69109 m .21623 .69093 L .21594 .69092 L F
.782 .564 0 r
.21212 .69173 m .21243 .69437 L .21207 .69314 L F
.851 .726 .724 r
.21255 .6929 m .21418 .69453 L .21615 .69108 L F
.21207 .69314 m .21231 .6933 L .21255 .6929 L F
.21231 .6933 m .21418 .69453 L .21255 .6929 L F
.21207 .69314 m .21615 .69108 L .21602 .69104 L F
0 .493 .754 r
.21588 .69101 m .21592 .69102 L .21587 .69101 L F
.21589 .69101 m .21592 .69102 L .21588 .69101 L F
.444 .259 .535 r
.21568 .69105 m .21579 .69103 L .21576 .69095 L F
.21579 .69103 m .21578 .69096 L .21576 .69095 L F
.851 .726 .724 r
.21579 .69103 m .21578 .69092 L .21297 .69084 L F
.653 .215 .197 r
.21591 .69104 m .21541 .69091 L .21297 .69084 L F
.68 .954 .951 r
.21596 .69102 m .21595 .69103 L .21589 .69101 L F
.21596 .69102 m .21589 .69101 L .21589 .69101 L F
.21789 .69137 m .21589 .69101 L .21623 .69093 L F
.851 .726 .724 r
.21602 .69104 m .21615 .69108 L .21623 .69093 L F
.21579 .69103 m .21594 .69092 L .21578 .69092 L F
.653 .215 .197 r
.21609 .69106 m .21623 .69093 L .21541 .69091 L F
.68 .954 .951 r
.21589 .69101 m .21589 .69101 L .21589 .69101 L F
.851 .726 .724 r
.21207 .69314 m .21618 .69096 L .2125 .69204 L F
.653 .215 .197 r
.21609 .69106 m .21589 .69101 L .21591 .69104 L F
.21589 .69101 m .21588 .69101 L .21588 .69101 L F
.21589 .69101 m .21588 .69101 L .21591 .69104 L F
0 .493 .754 r
.21588 .69101 m .21583 .691 L .21579 .69103 L F
.21589 .69101 m .21588 .69101 L .21588 .69101 L F
.21588 .69101 m .21583 .691 L .21588 .69101 L F
.444 .259 .535 r
.21579 .69103 m .21588 .69101 L .21578 .69096 L F
.21588 .69101 m .21589 .69101 L .21587 .691 L F
.21588 .69101 m .21587 .691 L .21578 .69096 L F
.21568 .69105 m .21576 .69095 L .21233 .68929 L F
.653 .215 .197 r
.21588 .69101 m .21541 .69091 L .21587 .69103 L F
.21588 .69101 m .21587 .69103 L .21591 .69104 L F
.21588 .69101 m .21587 .69103 L .21588 .69101 L F
.396 .798 .984 r
.21297 .69084 m .21589 .69101 L .21588 .69101 L F
.21297 .69084 m .21588 .69101 L .21212 .69173 L F
.851 .726 .724 r
.2157 .69109 m .21579 .69103 L .21297 .69084 L F
.2125 .69204 m .2157 .69109 L .21297 .69084 L F
.21618 .69096 m .21623 .69093 L .2125 .69204 L F
.653 .215 .197 r
.21428 .69267 m .21609 .69106 L .21297 .69084 L F
.76 .698 .793 r
.21472 .68746 m .21607 .69055 L .21297 .69084 L F
.21607 .69055 m .21587 .69081 L .21297 .69084 L F
.21618 .69081 m .21594 .69092 L .21297 .69084 L F
.643 .196 .174 r
.21623 .69093 m .21589 .69101 L .21297 .69084 L F
.388 .157 .437 r
.21513 .69044 m .21384 .69068 L .21428 .69267 L F
.21384 .69068 m .21297 .69084 L .2134 .69143 L F
.21384 .69068 m .2134 .69143 L .21428 .69267 L F
0 .493 .754 r
.21589 .69101 m .21589 .69101 L .21588 .69101 L F
.21592 .69102 m .2172 .69139 L .21587 .69101 L F
.76 .698 .793 r
.21607 .69055 m .21618 .69081 L .21587 .69081 L F
.21618 .69081 m .21623 .69093 L .21594 .69092 L F
.68 .954 .951 r
.21789 .69137 m .21595 .69103 L .21596 .69102 L F
.813 .531 .512 r
.21771 .69152 m .21788 .69156 L .21789 .69137 L F
.21418 .69453 m .21788 .69156 L .21771 .69152 L F
.926 .656 .507 r
.2177 .69506 m .21983 .69271 L .21833 .69168 L F
.21788 .69156 m .21833 .69168 L .21789 .69137 L F
.2177 .69506 m .21833 .69168 L .21788 .69156 L F
.623 .65 .856 r
.7329 .41097 m .73643 .41334 L .73537 .41023 L F
.536 .587 .853 r
.73537 .41023 m .73643 .41334 L .7383 .41127 L F
.521 .564 .839 r
.73643 .41334 m .73908 .4131 L .7383 .41127 L F
.425 .194 .458 r
.29211 .59306 m .28954 .59611 L .28983 .59365 L F
.104 .659 .754 r
.47808 .55872 m .48219 .55843 L .47978 .55885 L F
.359 .617 .949 r
.15991 .63075 m .15954 .62873 L .1592 .62958 L F
.15991 .63075 m .15999 .62884 L .15954 .62873 L F
.15991 .63075 m .16283 .63168 L .15999 .62884 L F
.617 .344 .482 r
.45179 .56128 m .45471 .56232 L .45483 .56089 L F
.574 .19 .276 r
.45471 .56232 m .45723 .56247 L .45483 .56089 L F
.386 .783 .987 r
.20874 .63184 m .21051 .6326 L .2066 .63213 L F
.368 .773 .983 r
.20874 .63184 m .21267 .63236 L .21051 .6326 L F
.831 .824 .841 r
.22779 .65931 m .23218 .65757 L .2302 .65626 L F
.919 .589 .401 r
.23645 .60419 m .2385 .60539 L .23784 .60294 L F
.764 .351 0 r
.23689 .60173 m .23784 .60294 L .2359 .59965 L F
.919 .589 .401 r
.23645 .60419 m .2385 .60539 L .23784 .60294 L F
.961 .829 .402 r
.67126 .4161 m .67077 .41493 L .67114 .41241 L F
.805 .498 .47 r
.67428 .4177 m .67126 .4161 L .67356 .41589 L F
.67428 .4177 m .67077 .41493 L .67126 .4161 L F
0 0 0 r
.67531 .44128 m .67652 .44018 L .67846 .43899 L F
.368 .47 .833 r
.23385 .60827 m .23416 .605 L .2331 .60497 L F
.23385 .60827 m .23589 .60825 L .23416 .605 L F
.38 .279 .613 r
.23385 .60827 m .23564 .61086 L .23589 .60825 L F
.283 .776 .894 r
.22359 .53846 m .22594 .53812 L .22765 .5383 L F
.134 .681 .797 r
.22594 .53812 m .22994 .53798 L .22765 .5383 L F
.783 .797 .864 r
.72348 .41249 m .72416 .41534 L .72682 .41279 L F
.522 .427 .688 r
.47918 .58766 m .47961 .59085 L .47741 .59117 L F
.78 .522 .546 r
.52121 .56363 m .51781 .56564 L .51821 .56233 L F
.52121 .56363 m .52156 .5661 L .51781 .56564 L F
.542 .707 .947 r
.2882 .54701 m .28615 .54782 L .28405 .54559 L F
.604 .822 .983 r
.66477 .44213 m .66062 .44151 L .663 .43909 L F
.925 .905 .785 r
.66082 .445 m .66477 .44213 L .66332 .44257 L F
.66082 .445 m .66193 .44607 L .66477 .44213 L F
.786 .729 .799 r
.6667 .43978 m .66477 .44213 L .663 .43909 L F
.397 .842 .738 r
.66589 .44132 m .66477 .44213 L .66678 .44227 L F
.66589 .44132 m .66332 .44257 L .66477 .44213 L F
.599 .507 .721 r
.66477 .44213 m .66801 .4458 L .66678 .44227 L F
.624 .484 .671 r
.23135 .56014 m .22925 .56059 L .23194 .55773 L F
.23135 .56014 m .22925 .56059 L .23194 .55773 L F
.377 .183 .486 r
.44657 .6265 m .44393 .62935 L .44316 .62731 L F
0 0 .471 r
.5313 .59037 m .53125 .58947 L .52974 .587 L F
.693 .321 0 r
.53283 .59365 m .53238 .59285 L .5313 .59037 L F
0 0 .354 r
.5313 .59037 m .53238 .59285 L .53125 .58947 L F
.13 0 .195 r
.40697 .59674 m .40857 .59602 L .40934 .59403 L F
0 0 .309 r
.40697 .59674 m .40771 .59814 L .40857 .59602 L F
.40697 .59674 m .40678 .59955 L .40771 .59814 L F
.798 .895 .912 r
.50896 .53844 m .51369 .53726 L .51139 .53501 L F
.672 .769 .924 r
.51139 .53501 m .51369 .53726 L .51366 .53486 L F
0 0 0 r
.54096 .50733 m .54 .50827 L .54313 .50612 L F
.138 .684 .776 r
.7797 .38622 m .77911 .38643 L .77771 .38907 L F
.654 .891 .547 r
.7797 .38622 m .77771 .38907 L .77727 .38928 L F
.027 .076 .578 r
.2331 .60497 m .23337 .60135 L .23351 .60294 L F
.453 .341 .636 r
.28542 .60792 m .28306 .60563 L .28515 .60514 L F
.28542 .60792 m .28338 .60883 L .28306 .60563 L F
.687 .428 .525 r
.69257 .41237 m .69487 .41235 L .69455 .4099 L F
.624 .303 .406 r
.69749 .41198 m .69455 .4099 L .69487 .41235 L F
.69749 .41198 m .69836 .40942 L .69455 .4099 L F
.182 .709 .701 r
.55945 .60684 m .55773 .60723 L .55537 .60782 L F
.294 .786 .75 r
.55992 .60648 m .55945 .60684 L .56186 .60618 L F
.55992 .60648 m .55773 .60723 L .55945 .60684 L F
.881 .639 .568 r
.82618 .43123 m .82618 .43379 L .82447 .4305 L F
.646 .094 0 r
.6824 .41154 m .68239 .41083 L .67859 .40941 L F
.464 .494 .805 r
.17738 .64143 m .17866 .64479 L .18043 .64418 L F
.779 .278 0 r
.17866 .64479 m .18044 .64739 L .17879 .6465 L F
.322 .503 .88 r
.17866 .64479 m .18257 .64809 L .18044 .64739 L F
.779 .278 0 r
.17866 .64479 m .17879 .6465 L .18043 .64418 L F
.384 0 0 r
.16696 .60574 m .16496 .60737 L .16263 .6074 L F
.977 .771 .56 r
.16541 .60476 m .16496 .60737 L .16696 .60574 L F
.434 .802 .995 r
.19544 .74344 m .19721 .74422 L .19774 .74307 L F
.19774 .74307 m .19721 .74422 L .19544 .74344 L F
.697 .589 .731 r
.79218 .42508 m .79548 .42563 L .79472 .4219 L F
.715 .599 .725 r
.7919 .42673 m .79548 .42563 L .79218 .42508 L F
0 0 0 r
.21799 .69837 m .21978 .6959 L .21885 .69947 L F
.467 .163 .365 r
.46226 .5837 m .46529 .58134 L .46277 .58186 L F
.718 .61 .736 r
.20532 .71114 m .20921 .71142 L .20849 .7079 L F
.625 .549 .748 r
.20849 .7079 m .20921 .71142 L .2111 .70964 L F
.412 .548 .882 r
.80818 .40294 m .80639 .40482 L .80579 .4029 L F
.80818 .40294 m .80967 .40572 L .80639 .40482 L F
.927 .894 .487 r
.58986 .53268 m .59137 .52912 L .59058 .52888 L F
.58986 .53268 m .59016 .53346 L .59137 .52912 L F
.295 0 0 r
.21391 .55365 m .2175 .55248 L .21673 .55242 L F
.677 .699 .862 r
.74022 .40319 m .7378 .4044 L .73684 .4023 L F
0 0 .027 r
.56923 .56136 m .56954 .56186 L .56998 .56003 L F
.56923 .56136 m .56876 .5635 L .56954 .56186 L F
.768 .699 .158 r
.52898 .5845 m .52901 .58314 L .52937 .58074 L F
0 0 .515 r
.52898 .5845 m .53051 .58553 L .52901 .58314 L F
.52898 .5845 m .52974 .587 L .53051 .58553 L F
.152 0 .136 r
.55033 .50907 m .54941 .51168 L .5472 .51194 L F
.467 .152 .347 r
.54941 .51168 m .54645 .51345 L .5472 .51194 L F
.894 .69 .62 r
.59529 .49703 m .59644 .49449 L .59337 .49359 L F
.59529 .49703 m .59669 .49748 L .59644 .49449 L F
.634 .893 .986 r
.21274 .64879 m .21678 .64861 L .21576 .6483 L F
.356 .817 .926 r
.21678 .64861 m .21607 .64791 L .21576 .6483 L F
.21678 .64861 m .2192 .64811 L .21607 .64791 L F
.985 .705 .353 r
.5269 .57507 m .52816 .5785 L .527 .57734 L F
.384 .378 .729 r
.43917 .62893 m .44022 .62585 L .43795 .62625 L F
.43917 .62893 m .44083 .62944 L .44022 .62585 L F
.377 .294 .635 r
.42396 .64797 m .42617 .65014 L .42431 .65058 L F
.544 .303 .5 r
.42648 .64751 m .42617 .65014 L .42396 .64797 L F
.643 .306 .386 r
.45372 .57177 m .44991 .57414 L .45134 .57197 L F
.547 .239 .398 r
.70078 .41125 m .69836 .40942 L .69749 .41198 L F
.70078 .41125 m .70082 .40943 L .69836 .40942 L F
.462 .223 .465 r
.26988 .62555 m .26809 .62369 L .27033 .62321 L F
.26988 .62555 m .26769 .62608 L .26809 .62369 L F
.883 .809 .771 r
.57801 .52684 m .57774 .5235 L .57951 .52472 L F
.954 .605 .275 r
.59427 .52058 m .59244 .51774 L .59042 .5211 L F
.608 .628 .845 r
.21551 .70587 m .21358 .70873 L .21341 .70664 L F
.764 .993 .794 r
.21455 .70658 m .21358 .70873 L .21397 .7085 L F
.21455 .70658 m .21175 .70919 L .21358 .70873 L F
.572 .578 .821 r
.21676 .70794 m .21358 .70873 L .21551 .70587 L F
.518 .553 .831 r
.21826 .70653 m .21676 .70794 L .21551 .70587 L F
.699 .972 .924 r
.21826 .70653 m .21456 .70823 L .21676 .70794 L F
.21456 .70823 m .21397 .7085 L .21451 .70839 L F
.21456 .70823 m .21451 .70839 L .21676 .70794 L F
.758 .598 .679 r
.21455 .70658 m .21397 .7085 L .21826 .70653 L F
.211 .733 .739 r
.21676 .70794 m .21451 .70839 L .21407 .70861 L F
0 0 .355 r
.21555 .70785 m .21469 .7091 L .21455 .70658 L F
.587 .602 .835 r
.21559 .70795 m .21585 .71001 L .21793 .70813 L F
0 0 .355 r
.21557 .70801 m .21553 .70806 L .2156 .70791 L F
.21553 .70806 m .21469 .7091 L .21555 .70785 L F
.587 .602 .835 r
.21501 .70791 m .21536 .70877 L .21559 .70795 L F
.09 .21 .696 r
.21585 .71001 m .21469 .7091 L .21557 .70801 L F
.587 .602 .835 r
.21557 .70801 m .21585 .71001 L .21559 .70795 L F
.09 .21 .696 r
.21585 .71001 m .21557 .70801 L .21562 .70795 L F
.587 .602 .835 r
.21536 .70877 m .21585 .71001 L .21557 .70801 L F
.534 .03 .005 r
.21551 .70587 m .21455 .70658 L .21826 .70653 L F
.701 .355 .388 r
.21826 .70653 m .21455 .70658 L .21531 .70541 L F
.433 .32 .625 r
.21722 .70521 m .21829 .7054 L .22072 .70504 L F
.611 .858 .99 r
.2226 .706 m .22011 .70565 L .22072 .70504 L F
.22011 .70565 m .21831 .7054 L .22072 .70504 L F
.2226 .706 m .22058 .70685 L .21827 .7054 L F
.21831 .7054 m .21827 .7054 L .21825 .70539 L F
.2226 .706 m .21827 .7054 L .21831 .7054 L F
.204 .65 .948 r
.21825 .7054 m .22058 .70685 L .21826 .70653 L F
.057 .592 .858 r
.21722 .70521 m .21823 .70539 L .21531 .70541 L F
.433 .32 .625 r
.21722 .70521 m .21736 .70556 L .21829 .7054 L F
.204 .65 .948 r
.21825 .70539 m .21827 .7054 L .21825 .7054 L F
.21827 .7054 m .22058 .70685 L .21825 .7054 L F
.433 .32 .625 r
.21829 .7054 m .21829 .70541 L .22005 .70571 L F
.419 0 0 r
.22058 .70685 m .21652 .70775 L .21826 .70653 L F
.21652 .70775 m .2162 .70766 L .21826 .70653 L F
.21574 .70792 m .21568 .70792 L .21826 .70653 L F
.204 .65 .948 r
.21823 .70539 m .21826 .70653 L .21531 .70541 L F
.21825 .70539 m .21825 .7054 L .21823 .70539 L F
.21825 .7054 m .21826 .70653 L .21823 .70539 L F
0 0 .355 r
.21578 .70786 m .21455 .70658 L .21826 .70653 L F
.21563 .70785 m .21455 .70658 L .21578 .70786 L F
.21559 .7079 m .21455 .70658 L .21568 .70792 L F
.608 .628 .845 r
.21551 .70587 m .21432 .7063 L .21455 .70658 L F
.21432 .7063 m .21341 .70664 L .21455 .70658 L F
0 0 .2 r
.21455 .70658 m .21501 .70791 L .21491 .70699 L F
.813 .909 .507 r
.21531 .70541 m .21455 .70658 L .21472 .70523 L F
0 0 .2 r
.21455 .70658 m .21491 .70699 L .21472 .70523 L F
.617 .436 .615 r
.215 .70782 m .2156 .70719 L .21472 .70523 L F
.21501 .70791 m .21508 .70782 L .215 .70782 L F
.21508 .70782 m .2156 .70719 L .215 .70782 L F
0 0 .355 r
.21568 .70792 m .21563 .70785 L .21578 .70786 L F
.617 .436 .615 r
.21559 .70795 m .21621 .708 L .21567 .70791 L F
.21559 .70791 m .21567 .70791 L .21559 .7079 L F
.21559 .70795 m .21567 .70791 L .21559 .70791 L F
.21621 .708 m .21793 .70813 L .21559 .7079 L F
.419 0 0 r
.21574 .70792 m .21793 .70813 L .21562 .70795 L F
.22058 .70685 m .21793 .70813 L .21574 .70792 L F
0 0 .355 r
.21562 .70795 m .21559 .7079 L .21568 .70792 L F
.419 0 0 r
.21652 .70775 m .21574 .70792 L .2162 .70766 L F
.617 .436 .615 r
.21559 .7079 m .21793 .70813 L .2156 .70719 L F
.433 .32 .625 r
.21736 .70556 m .2182 .70758 L .21829 .70541 L F
.21827 .7054 m .21829 .70541 L .21829 .7054 L F
.21736 .70556 m .21829 .70541 L .21827 .7054 L F
.21722 .70521 m .21792 .70811 L .2182 .70758 L F
.21792 .70811 m .21793 .70813 L .21794 .70811 L F
.21792 .70811 m .21794 .70811 L .2182 .70758 L F
.419 0 0 r
.21574 .70792 m .21562 .70795 L .21568 .70792 L F
.617 .436 .615 r
.2156 .70719 m .21787 .7081 L .21722 .70521 L F
.21787 .7081 m .21793 .70813 L .21792 .70811 L F
.21787 .7081 m .21792 .70811 L .21722 .70521 L F
.433 .32 .625 r
.21829 .70541 m .2182 .70758 L .22001 .70575 L F
.21829 .70541 m .22001 .70575 L .22005 .70571 L F
.925 .974 .748 r
.2182 .70758 m .2226 .706 L .22072 .70504 L F
.278 0 .212 r
.22223 .70539 m .22072 .70504 L .22273 .70201 L F
.22223 .70539 m .2182 .70758 L .22072 .70504 L F
0 0 0 r
.22117 .70627 m .2182 .70758 L .22223 .70539 L F
.007 0 0 r
.22072 .70504 m .22117 .70627 L .22215 .70358 L F
.22072 .70504 m .22215 .70358 L .22273 .70201 L F
.433 .32 .625 r
.21829 .7054 m .22005 .70571 L .22072 .70504 L F
.611 .858 .99 r
.21831 .7054 m .21825 .70539 L .22072 .70504 L F
.057 .592 .858 r
.21722 .70521 m .21825 .70539 L .21823 .70539 L F
0 0 .355 r
.21559 .7079 m .21553 .70806 L .21555 .70785 L F
.617 .436 .615 r
.21501 .70791 m .21559 .70795 L .2156 .70719 L F
0 0 .355 r
.2156 .70791 m .21559 .70794 L .21559 .7079 L F
.21559 .70794 m .21553 .70806 L .21559 .7079 L F
.21562 .70795 m .21557 .70801 L .2156 .70791 L F
.057 .592 .858 r
.21722 .70521 m .21531 .70541 L .21472 .70523 L F
.617 .436 .615 r
.2156 .70719 m .21722 .70521 L .21575 .70523 L F
.2156 .70719 m .21575 .70523 L .21472 .70523 L F
0 0 .2 r
.21482 .70735 m .21465 .70833 L .21501 .70791 L F
.21455 .70658 m .21463 .70798 L .21482 .70735 L F
.21463 .70798 m .21465 .70833 L .21482 .70735 L F
.21465 .70833 m .21469 .7091 L .21494 .70819 L F
.21465 .70833 m .21494 .70819 L .21501 .70791 L F
.211 .733 .739 r
.21407 .70861 m .21397 .7085 L .21358 .70873 L F
.21451 .70839 m .21397 .7085 L .21407 .70861 L F
.28 0 .226 r
.25619 .6372 m .2551 .63599 L .25723 .63542 L F
.25619 .6372 m .25415 .63792 L .2551 .63599 L F
.986 .718 .424 r
.59022 .53595 m .59016 .53346 L .58893 .53486 L F
.926 .918 .534 r
.58893 .53486 m .59016 .53346 L .58986 .53268 L F
.526 .037 .037 r
.49736 .58102 m .4996 .58155 L .50062 .58162 L F
.555 .12 .168 r
.5 .5808 m .4996 .58155 L .49736 .58102 L F
.583 .148 .181 r
.5 .5808 m .5014 .58183 L .4996 .58155 L F
.411 .203 .484 r
.4287 .62679 m .42887 .62853 L .43105 .6263 L F
0 0 .382 r
.42887 .62853 m .43024 .63211 L .43001 .63281 L F
0 0 0 r
.57045 .5999 m .56938 .6017 L .56736 .60244 L F
.56938 .6017 m .56607 .60397 L .56736 .60244 L F
.471 .27 .526 r
.51128 .52096 m .51145 .52157 L .50882 .52172 L F
.51128 .52096 m .50882 .52172 L .509 .52185 L F
0 0 0 r
.5718 .59868 m .57045 .5999 L .57289 .59685 L F
.57091 .60044 m .57045 .5999 L .5718 .59868 L F
.57091 .60044 m .56938 .6017 L .57045 .5999 L F
.61 .531 .741 r
.79472 .4219 m .79548 .42563 L .79842 .42456 L F
.138 .684 .776 r
.7797 .38622 m .78017 .38632 L .77911 .38643 L F
.749 .33 .254 r
.67755 .4183 m .67356 .41589 L .67739 .41616 L F
0 .019 .561 r
.53457 .60867 m .53548 .60729 L .53427 .60534 L F
.13 .346 .809 r
.53457 .60867 m .53719 .61039 L .53548 .60729 L F
0 .167 .595 r
.53851 .61128 m .53719 .61039 L .53457 .60867 L F
.285 .126 .481 r
.65462 .41016 m .6549 .4121 L .65639 .40904 L F
.992 .802 .549 r
.50368 .53671 m .50275 .53873 L .50506 .53559 L F
.121 0 0 r
.53405 .51328 m .53705 .51125 L .53487 .51164 L F
0 0 0 r
.53196 .51459 m .53405 .51328 L .53487 .51164 L F
.342 0 .125 r
.17977 .5633 m .17811 .56558 L .1759 .566 L F
.396 .02 .202 r
.18195 .56277 m .17811 .56558 L .17977 .5633 L F
.761 .746 .839 r
.17765 .61799 m .17981 .62068 L .1755 .62038 L F
.349 .489 .858 r
.1793 .61719 m .17981 .62068 L .17765 .61799 L F
.1793 .61719 m .18091 .62017 L .17981 .62068 L F
.223 .167 .581 r
.18091 .62017 m .18136 .6227 L .17981 .62068 L F
.157 .149 .598 r
.18136 .6227 m .17988 .6213 L .17981 .62068 L F
.79 .486 .474 r
.57544 .50632 m .57321 .50824 L .57175 .50566 L F
.848 .584 .539 r
.57544 .50632 m .57557 .50886 L .57321 .50824 L F
.331 0 .086 r
.20891 .55481 m .20713 .55749 L .20467 .55806 L F
.221 0 0 r
.21164 .55401 m .20891 .55481 L .20926 .55452 L F
.21164 .55401 m .20979 .55574 L .20891 .55481 L F
.139 0 0 r
.20979 .55574 m .20713 .55749 L .20891 .55481 L F
.728 .549 .649 r
.58448 .48161 m .58836 .48476 L .58829 .48224 L F
.506 .344 .595 r
.46544 .59622 m .46839 .59853 L .46901 .59641 L F
.596 .486 .699 r
.47194 .59473 m .46901 .59641 L .47157 .5958 L F
.034 0 0 r
.46839 .59853 m .47157 .5958 L .46901 .59641 L F
.596 .486 .699 r
.47194 .59473 m .46901 .59641 L .47157 .5958 L F
.269 0 .179 r
.49533 .59293 m .49603 .59313 L .4963 .59097 L F
.49533 .59293 m .49413 .59432 L .49603 .59313 L F
.353 .356 .723 r
.29695 .57722 m .29491 .57906 L .29457 .57536 L F
.477 .437 .734 r
.29695 .57722 m .29564 .5813 L .29491 .57906 L F
.037 .597 .809 r
.66889 .43328 m .66923 .43372 L .66804 .43405 L F
.66889 .43328 m .67181 .43395 L .66923 .43372 L F
.5 .908 .85 r
.78682 .44058 m .78761 .43953 L .7886 .43923 L F
.78682 .44058 m .78503 .44083 L .78761 .43953 L F
.294 .571 .935 r
.53851 .61128 m .53943 .61009 L .53719 .61039 L F
.53851 .61128 m .54044 .6117 L .53943 .61009 L F
.188 0 .179 r
.23514 .62282 m .23808 .61967 L .23592 .62064 L F
.736 .494 .562 r
.53086 .52148 m .53448 .52406 L .53087 .5236 L F
.931 .947 .779 r
.56686 .57178 m .56798 .57288 L .5663 .57475 L F
.134 .229 .698 r
.76922 .38475 m .76811 .3862 L .76719 .38242 L F
.219 .665 .951 r
.77069 .38572 m .76811 .3862 L .76922 .38475 L F
.77069 .38572 m .7707 .3865 L .76811 .3862 L F
.336 .199 .542 r
.39656 .60864 m .3984 .6106 L .39859 .60789 L F
.295 .193 .565 r
.39677 .61112 m .3984 .6106 L .39656 .60864 L F
.563 .686 .922 r
.21492 .68765 m .21633 .68809 L .21461 .68608 L F
.377 .444 .803 r
.21633 .68809 m .21704 .68541 L .21461 .68608 L F
.731 .34 .309 r
.43135 .63861 m .43124 .64022 L .43028 .63736 L F
.43135 .63861 m .43364 .64106 L .43124 .64022 L F
0 0 0 r
.77691 .41265 m .77377 .41504 L .77663 .41487 L F
.558 .861 .997 r
.26299 .55637 m .26313 .55801 L .26103 .557 L F
.26299 .55637 m .26313 .55801 L .26103 .557 L F
.631 .071 0 r
.48613 .55919 m .48754 .56005 L .48946 .56052 L F
0 .1 .565 r
.49051 .56131 m .48946 .56052 L .48754 .56005 L F
.49051 .56131 m .49184 .5624 L .48946 .56052 L F
.425 .675 .966 r
.49655 .5952 m .49735 .59665 L .49836 .59504 L F
.49836 .59504 m .49735 .59665 L .49655 .5952 L F
.026 0 0 r
.49977 .59652 m .49616 .59822 L .49735 .59665 L F
.425 .675 .966 r
.49655 .5952 m .49735 .59665 L .49836 .59504 L F
.458 .649 .941 r
.73523 .39997 m .73349 .40173 L .73278 .40001 L F
.73523 .39997 m .73684 .4023 L .73349 .40173 L F
0 .002 .551 r
.53574 .56418 m .53428 .56288 L .53283 .56185 L F
.53574 .56418 m .5364 .5653 L .53428 .56288 L F
0 0 .051 r
.57501 .59356 m .57459 .59588 L .57289 .59685 L F
0 0 0 r
.57459 .59588 m .5718 .59868 L .57289 .59685 L F
.497 .347 .607 r
.44839 .5873 m .44818 .59012 L .44975 .58817 L F
.813 .963 .641 r
.76428 .39973 m .76222 .40348 L .76472 .3997 L F
.403 .252 .559 r
.2534 .59962 m .2553 .60157 L .25535 .59899 L F
.2534 .59962 m .25341 .60233 L .2553 .60157 L F
.322 .782 .945 r
.20367 .64918 m .20863 .64938 L .20697 .64879 L F
.406 .798 .988 r
.20863 .64938 m .20905 .64859 L .20697 .64879 L F
.20863 .64938 m .21059 .64931 L .20905 .64859 L F
.211 0 .063 r
.16332 .57376 m .16257 .57232 L .16457 .57124 L F
.16332 .57376 m .16132 .57441 L .16257 .57232 L F
.419 .716 .986 r
.27053 .54077 m .27272 .54063 L .2722 .54216 L F
.387 .681 .976 r
.27272 .54063 m .27423 .54207 L .2722 .54216 L F
.608 .888 .99 r
.17331 .621 m .17372 .61941 L .1755 .62038 L F
.17331 .621 m .17157 .62033 L .17372 .61941 L F
.811 .676 .715 r
.23694 .60847 m .23901 .61135 L .23827 .60904 L F
.581 .34 .516 r
.56886 .48204 m .57294 .48174 L .57258 .47885 L F
.673 .406 .508 r
.57258 .47885 m .57468 .48135 L .57465 .47886 L F
.57258 .47885 m .57294 .48174 L .57468 .48135 L F
0 0 0 r
.16456 .5537 m .16582 .55352 L .16756 .55175 L F
.16756 .55175 m .16766 .55266 L .16978 .55124 L F
.16756 .55175 m .16582 .55352 L .16766 .55266 L F
.499 0 0 r
.43126 .63361 m .43454 .63425 L .43611 .63334 L F
.229 0 0 r
.43611 .63334 m .43756 .63398 L .43901 .63406 L F
.43611 .63334 m .43454 .63425 L .43756 .63398 L F
.446 .233 .495 r
.26547 .62666 m .26511 .62914 L .26297 .62968 L F
.481 .222 .443 r
.26511 .62914 m .26237 .63235 L .26297 .62968 L F
.663 .571 .741 r
.44689 .59324 m .44944 .59326 L .44818 .59012 L F
.693 .481 .596 r
.44689 .59324 m .44891 .59563 L .44944 .59326 L F
.44689 .59324 m .44686 .59661 L .44891 .59563 L F
.695 .626 .775 r
.51568 .52661 m .51984 .52738 L .51851 .52363 L F
.682 .619 .779 r
.51851 .52363 m .51984 .52738 L .52311 .52683 L F
.82 .646 .666 r
.66141 .4026 m .66471 .40344 L .66508 .4007 L F
.479 .835 .995 r
.20179 .73122 m .20079 .73216 L .19662 .73162 L F
.405 .4 .741 r
.29684 .56201 m .29465 .56425 L .29422 .56014 L F
.529 .488 .755 r
.29684 .56201 m .29555 .56622 L .29465 .56425 L F
.194 .328 .772 r
.16027 .61345 m .16034 .61675 L .15853 .61394 L F
.16027 .61345 m .16164 .61694 L .16034 .61675 L F
0 0 0 r
.79417 .43168 m .79129 .43417 L .79376 .43255 L F
.462 .23 .475 r
.79035 .4353 m .79376 .43255 L .79129 .43417 L F
.258 .739 .931 r
.22994 .53798 m .23222 .53784 L .23405 .53832 L F
0 0 0 r
.21768 .53921 m .21986 .5388 L .22135 .53851 L F
.115 0 0 r
.22135 .53851 m .21986 .5388 L .22359 .53846 L F
.757 .754 .85 r
.2448 .55077 m .24559 .55222 L .24874 .55151 L F
.797 .69 .747 r
.24874 .55151 m .24631 .5543 L .2448 .55077 L F
.497 .813 1 r
.1844 .64705 m .18838 .64754 L .18698 .64602 L F
.574 .858 .996 r
.18838 .64754 m .18873 .64589 L .18698 .64602 L F
.18838 .64754 m .1914 .64683 L .18873 .64589 L F
.595 .635 .861 r
.43338 .62095 m .43752 .62361 L .43589 .62018 L F
0 0 .07 r
.43752 .62361 m .43839 .61988 L .43589 .62018 L F
.43752 .62361 m .43816 .6222 L .43839 .61988 L F
.083 .331 .807 r
.43752 .62361 m .44022 .62585 L .43816 .6222 L F
.496 .404 .681 r
.43795 .62625 m .44022 .62585 L .43752 .62361 L F
.364 0 0 r
.17348 .67377 m .17136 .67256 L .17148 .67161 L F
.17348 .67377 m .1757 .67493 L .17136 .67256 L F
.375 .134 .415 r
.46957 .61431 m .47188 .61168 L .46915 .61165 L F
.626 .622 .827 r
.65809 .44217 m .65434 .43995 L .65748 .44085 L F
.571 .797 .985 r
.65942 .44026 m .65809 .44217 L .65748 .44085 L F
.65942 .44026 m .66062 .44151 L .65809 .44217 L F
.476 .151 .336 r
.42483 .60208 m .42782 .60332 L .42908 .59942 L F
.536 .353 .581 r
.42908 .59942 m .43124 .59921 L .43168 .59668 L F
.633 .304 .396 r
.42908 .59942 m .43171 .60193 L .43124 .59921 L F
.42908 .59942 m .42782 .60332 L .43171 .60193 L F
.328 0 .143 r
.55603 .49343 m .55876 .4927 L .55898 .49146 L F
.569 .143 .193 r
.55876 .4927 m .56126 .49295 L .55898 .49146 L F
.503 .212 .406 r
.55898 .49146 m .56126 .49295 L .56156 .49098 L F
.562 .818 .447 r
.41219 .61167 m .41073 .61348 L .40996 .61447 L F
.586 .372 .558 r
.40996 .61447 m .41245 .61415 L .41219 .61167 L F
.426 .258 .549 r
.41219 .61167 m .41245 .61415 L .41468 .61337 L F
.658 .681 .861 r
.41294 .6077 m .41087 .61212 L .41584 .60832 L F
.40957 .60698 m .41584 .60832 L .41313 .60698 L F
.978 .79 .583 r
.41584 .60832 m .41564 .60685 L .41313 .60698 L F
.467 .103 .263 r
.41502 .60861 m .41855 .60712 L .41789 .60706 L F
.41546 .60737 m .41789 .60706 L .41564 .60685 L F
.978 .79 .583 r
.41584 .60832 m .41502 .60861 L .41564 .60685 L F
.467 .103 .263 r
.41502 .60861 m .41789 .60706 L .41546 .60737 L F
.658 .681 .861 r
.40957 .60698 m .40985 .60811 L .41294 .6077 L F
.40985 .60811 m .41087 .61212 L .41294 .6077 L F
.41087 .61212 m .41103 .61277 L .41165 .6122 L F
.41087 .61212 m .41165 .6122 L .41584 .60832 L F
.592 .13 .124 r
.41468 .61337 m .41073 .61348 L .41175 .61221 L F
.41318 .61234 m .41175 .61221 L .41219 .61167 L F
.41468 .61337 m .41175 .61221 L .41318 .61234 L F
.775 .746 .827 r
.6667 .43978 m .663 .43909 L .66577 .43632 L F
.806 .671 .714 r
.41918 .63514 m .422 .63582 L .41999 .63262 L F
.793 .648 .701 r
.41918 .63514 m .4211 .63842 L .422 .63582 L F
.806 .671 .714 r
.41918 .63514 m .422 .63582 L .41999 .63262 L F
.141 .332 .795 r
.4211 .63842 m .41918 .63514 L .422 .63582 L F
0 0 0 r
.73906 .37359 m .7373 .37412 L .73616 .37472 L F
.73906 .37359 m .73985 .37322 L .7373 .37412 L F
.705 .533 .653 r
.22836 .67182 m .22869 .67531 L .22603 .67472 L F
.467 .357 .645 r
.23067 .67421 m .22869 .67531 L .22836 .67182 L F
.312 0 0 r
.22836 .67182 m .22872 .67301 L .23067 .67421 L F
.22836 .67182 m .2262 .67341 L .22872 .67301 L F
.653 .283 0 r
.52581 .57277 m .5269 .57507 L .52523 .57162 L F
.695 .626 .775 r
.51568 .52661 m .51851 .52363 L .51625 .52445 L F
.838 .401 .192 r
.4952 .54557 m .494 .54678 L .49279 .5446 L F
.644 .141 .036 r
.4952 .54557 m .49775 .54738 L .494 .54678 L F
.613 .049 0 r
.49937 .54751 m .49775 .54738 L .4952 .54557 L F
.886 .989 .799 r
.51889 .53665 m .5165 .53756 L .51785 .53557 L F
.863 .929 .868 r
.52168 .53367 m .51889 .53665 L .51785 .53557 L F
.644 .372 .493 r
.43419 .59459 m .43624 .59661 L .43437 .59585 L F
.43419 .59459 m .43624 .59661 L .43437 .59585 L F
.334 .034 .298 r
.40934 .59403 m .41064 .59528 L .4113 .59342 L F
.40934 .59403 m .40857 .59602 L .41064 .59528 L F
.604 .698 .91 r
.46544 .59622 m .46297 .59546 L .46508 .59346 L F
0 0 0 r
.46671 .59003 m .46586 .5923 L .46508 .59346 L F
.876 .482 .02 r
.52519 .55028 m .52716 .55388 L .52646 .5517 L F
.683 .942 .963 r
.23109 .66757 m .23075 .66895 L .23311 .66854 L F
.23109 .66757 m .22908 .66844 L .23075 .66895 L F
.226 .007 .358 r
.52204 .53303 m .52261 .53322 L .52358 .53035 L F
.033 .226 .729 r
.52256 .53144 m .52336 .53346 L .52261 .53322 L F
.52336 .53346 m .52407 .53526 L .52261 .53322 L F
.226 .007 .358 r
.52168 .53367 m .52261 .53322 L .52204 .53303 L F
.333 .271 .637 r
.52358 .53035 m .52757 .53039 L .52517 .52618 L F
.325 0 .208 r
.55167 .51089 m .55033 .50907 L .5528 .50854 L F
.55167 .51089 m .54941 .51168 L .55033 .50907 L F
.628 .182 .172 r
.74361 .37618 m .7473 .37603 L .74631 .37788 L F
.376 0 0 r
.7473 .37603 m .7489 .37744 L .74631 .37788 L F
.7473 .37603 m .74978 .376 L .7489 .37744 L F
.669 .89 .978 r
.18044 .64739 m .18257 .64809 L .1844 .64705 L F
.394 .006 .18 r
.55702 .50597 m .5553 .50811 L .5528 .50854 L F
.6 .255 .356 r
.55906 .50583 m .5553 .50811 L .55702 .50597 L F
.723 .482 .561 r
.5886 .48733 m .59199 .48518 L .58836 .48476 L F
.5886 .48733 m .59203 .48763 L .59199 .48518 L F
.433 .244 .523 r
.26237 .58446 m .26443 .58384 L .2646 .58132 L F
.292 .079 .409 r
.26237 .58446 m .26403 .58583 L .26443 .58384 L F
.26237 .58446 m .26191 .58684 L .26403 .58583 L F
.115 0 .127 r
.79093 .40372 m .78817 .4074 L .78974 .40711 L F
.302 .408 .805 r
.78962 .40021 m .79093 .40372 L .79249 .40185 L F
0 0 0 r
.79056 .40554 m .7905 .40494 L .78974 .40711 L F
.845 .844 .843 r
.7872 .4043 m .78487 .40747 L .78387 .4054 L F
.638 .68 .873 r
.78974 .40711 m .79406 .4071 L .79345 .40598 L F
0 0 0 r
.79249 .40185 m .79209 .40544 L .79255 .40435 L F
.638 .68 .873 r
.79209 .40544 m .79345 .40598 L .79285 .40489 L F
.78974 .40711 m .79345 .40598 L .79172 .4057 L F
0 0 0 r
.79249 .40185 m .78974 .40711 L .79209 .40544 L F
.638 .68 .873 r
.78974 .40711 m .79285 .40489 L .79255 .40435 L F
0 0 0 r
.79209 .40544 m .79198 .4064 L .79255 .40435 L F
.638 .68 .873 r
.79172 .4057 m .79196 .40574 L .79209 .40544 L F
.79196 .40574 m .79345 .40598 L .79209 .40544 L F
0 0 0 r
.79209 .40544 m .78974 .40711 L .79198 .4064 L F
.638 .68 .873 r
.78974 .40711 m .79125 .40562 L .79118 .40574 L F
.536 .767 .983 r
.79198 .4064 m .79 .40692 L .79098 .40596 L F
.636 .711 .901 r
.78974 .40711 m .79208 .40989 L .79477 .40915 L F
.78974 .40711 m .79477 .40915 L .79406 .4071 L F
.536 .767 .983 r
.79 .40692 m .78974 .40711 L .78817 .4074 L F
.79198 .4064 m .78974 .40711 L .79 .40692 L F
.638 .68 .873 r
.78977 .40714 m .79 .40692 L .79012 .40748 L F
.79 .40692 m .79114 .4058 L .79085 .40628 L F
.79 .40692 m .79085 .40628 L .79012 .40748 L F
.536 .767 .983 r
.79098 .40596 m .78817 .4074 L .7872 .4043 L F
.594 .045 0 r
.7906 .40591 m .79099 .40605 L .79059 .40579 L F
.79099 .40605 m .79198 .4064 L .79098 .40596 L F
.79099 .40605 m .79098 .40596 L .79059 .40579 L F
.638 .68 .873 r
.79114 .4058 m .79227 .40471 L .79102 .40632 L F
.707 .46 .549 r
.79055 .40677 m .79198 .4064 L .79099 .40605 L F
.638 .68 .873 r
.79099 .40605 m .79102 .40632 L .79012 .40748 L F
.79114 .4058 m .79102 .40632 L .79099 .40605 L F
.707 .46 .549 r
.79012 .40748 m .79198 .4064 L .79055 .40677 L F
.79012 .40748 m .79055 .40677 L .78977 .40698 L F
.638 .68 .873 r
.78974 .40711 m .79227 .40471 L .78977 .40714 L F
.536 .767 .983 r
.79 .40692 m .78817 .4074 L .79098 .40596 L F
.707 .46 .549 r
.78977 .40698 m .79055 .40677 L .78849 .40517 L F
.79055 .40677 m .79099 .40605 L .78849 .40517 L F
.638 .68 .873 r
.79118 .40574 m .79255 .40435 L .79227 .40471 L F
.79125 .40562 m .79255 .40435 L .79118 .40574 L F
.845 .844 .843 r
.7872 .4043 m .78387 .4054 L .78589 .40426 L F
.707 .46 .549 r
.78671 .40488 m .78849 .40517 L .78589 .40426 L F
.79012 .40748 m .78849 .40517 L .78671 .40488 L F
.594 .045 0 r
.78589 .40426 m .7906 .40591 L .7872 .4043 L F
.7906 .40591 m .79059 .40579 L .7872 .4043 L F
0 0 0 r
.79249 .40185 m .79093 .40372 L .7905 .40494 L F
.79249 .40185 m .7905 .40494 L .79056 .40554 L F
.287 0 .224 r
.46095 .6199 m .46299 .62029 L .4642 .61722 L F
.512 .171 .326 r
.4642 .61722 m .46612 .61897 L .46648 .61693 L F
.4642 .61722 m .46299 .62029 L .46612 .61897 L F
.584 .76 .962 r
.1914 .64683 m .19487 .64767 L .19302 .64635 L F
.228 .638 .957 r
.19302 .64635 m .19487 .64767 L .19595 .64698 L F
0 0 0 r
.15035 .59559 m .15432 .59519 L .15194 .5954 L F
.727 .945 .953 r
.67723 .43012 m .67445 .43091 L .67679 .42891 L F
.622 .842 .984 r
.679 .42818 m .67723 .43012 L .67679 .42891 L F
.679 .42818 m .67975 .42918 L .67723 .43012 L F
.763 .732 .824 r
.82961 .42474 m .83056 .42796 L .82705 .42748 L F
.709 .687 .827 r
.83186 .42369 m .83056 .42796 L .82961 .42474 L F
.83186 .42369 m .83301 .42692 L .83056 .42796 L F
0 0 .315 r
.57722 .58975 m .57675 .59242 L .57501 .59356 L F
0 0 .06 r
.57596 .5944 m .57501 .59356 L .57675 .59242 L F
.57596 .5944 m .57459 .59588 L .57501 .59356 L F
.711 .765 .894 r
.45983 .57042 m .46406 .57028 L .46257 .57014 L F
.281 0 .041 r
.46531 .56907 m .46257 .57014 L .46406 .57028 L F
.447 .218 .473 r
.26769 .62608 m .26511 .62914 L .26547 .62666 L F
.811 .816 .334 r
.77457 .41058 m .7747 .41018 L .77551 .40645 L F
.665 .709 .88 r
.77551 .40645 m .7747 .41018 L .77703 .40698 L F
.746 .331 .261 r
.67096 .40636 m .67505 .40862 L .67309 .40655 L F
.591 .933 .95 r
.40094 .62543 m .4003 .62668 L .4026 .62643 L F
.264 0 .202 r
.70332 .40691 m .70082 .40943 L .70364 .40929 L F
.466 .263 .52 r
.70332 .40691 m .70597 .4084 L .70647 .40605 L F
.70332 .40691 m .70364 .40929 L .70597 .4084 L F
.508 .744 .98 r
.44051 .58083 m .44151 .57925 L .43862 .57886 L F
.444 .181 .419 r
.44343 .57911 m .44249 .58047 L .44051 .58083 L F
.508 .744 .98 r
.44051 .58083 m .44249 .58047 L .44151 .57925 L F
.516 .145 .275 r
.47424 .62068 m .47269 .62306 L .47068 .62303 L F
.605 .245 .331 r
.47647 .62263 m .47269 .62306 L .47424 .62068 L F
.574 .256 .393 r
.47702 .62062 m .47647 .62263 L .47424 .62068 L F
0 .568 .727 r
.5442 .61188 m .54324 .6118 L .54044 .6117 L F
0 .501 .798 r
.5442 .61188 m .54539 .61186 L .54324 .6118 L F
.5442 .61188 m .54673 .6124 L .54539 .61186 L F
.687 .791 .929 r
.82094 .44071 m .81744 .44014 L .81993 .43909 L F
.663 .784 .938 r
.81993 .43909 m .8236 .43966 L .82094 .44071 L F
0 0 .252 r
.26569 .5694 m .26649 .57071 L .26746 .56872 L F
.26569 .5694 m .26528 .57204 L .26649 .57071 L F
.588 .825 .443 r
.50985 .6114 m .50745 .61463 L .5085 .61316 L F
.472 .312 .583 r
.51031 .61388 m .5099 .61667 L .50745 .61463 L F
.13 .289 .759 r
.50745 .61463 m .5099 .61667 L .5085 .61316 L F
.785 .692 .762 r
.50078 .58688 m .49847 .59019 L .50219 .59054 L F
.649 .545 .723 r
.49847 .59019 m .50078 .59247 L .50219 .59054 L F
.874 .608 .533 r
.50563 .58849 m .50333 .58882 L .50299 .5892 L F
0 .173 .698 r
.50207 .59022 m .50299 .5892 L .50078 .58688 L F
.554 .331 .531 r
.50078 .58688 m .50334 .58657 L .50336 .58401 L F
.471 .265 .518 r
.50336 .58401 m .50334 .58657 L .50398 .5864 L F
.50459 .58506 m .50398 .5864 L .50565 .58596 L F
.50336 .58401 m .50398 .5864 L .50459 .58506 L F
.50336 .58401 m .50565 .58596 L .50579 .58302 L F
.783 .496 .502 r
.5055 .58308 m .50202 .58554 L .50374 .58347 L F
.50579 .58302 m .50542 .58327 L .5055 .58308 L F
.50542 .58327 m .50202 .58554 L .5055 .58308 L F
.538 .281 .474 r
.50078 .58688 m .50299 .5892 L .50334 .58657 L F
.445 .201 .45 r
.50334 .58657 m .50299 .5892 L .50565 .58596 L F
.785 .67 .736 r
.50565 .58596 m .50299 .5892 L .50202 .58554 L F
.985 .752 .501 r
.50299 .5892 m .50195 .58903 L .50202 .58554 L F
.874 .608 .533 r
.50333 .58882 m .50195 .58903 L .50299 .5892 L F
0 .173 .698 r
.50219 .59054 m .50299 .5892 L .50207 .59022 L F
.513 .496 .775 r
.50078 .59247 m .50299 .5892 L .50219 .59054 L F
.74 .711 .824 r
.83786 .42153 m .83973 .42456 L .83549 .42418 L F
.215 .478 .89 r
.83786 .42153 m .84092 .42436 L .83973 .42456 L F
.498 .112 .239 r
.48016 .57873 m .47673 .58035 L .47763 .5787 L F
.48016 .57873 m .47673 .58035 L .47763 .5787 L F
0 0 .177 r
.1551 .59979 m .15467 .59957 L .15509 .59905 L F
.1551 .59979 m .15414 .60217 L .15467 .59957 L F
.583 .811 .986 r
.54693 .59389 m .54922 .593 L .54498 .59281 L F
.54693 .59389 m .54922 .593 L .54498 .59281 L F
.513 .327 .566 r
.49837 .58741 m .49847 .59019 L .50078 .58688 L F
.842 .412 .208 r
.49703 .56605 m .50078 .56921 L .50074 .5668 L F
.68 .539 .687 r
.50074 .5668 m .50078 .56921 L .50309 .56637 L F
.516 .113 .215 r
.43742 .63911 m .43628 .64096 L .43364 .64106 L F
.645 .254 .289 r
.43968 .64103 m .43628 .64096 L .43742 .63911 L F
.113 .564 .917 r
.78247 .38617 m .78017 .38632 L .7797 .38622 L F
.439 .76 .996 r
.78138 .38508 m .78247 .38617 L .7797 .38622 L F
.617 .141 .101 r
.78139 .38519 m .78247 .38617 L .78138 .38508 L F
.113 .564 .917 r
.78247 .38617 m .78362 .3872 L .78017 .38632 L F
.303 .55 .92 r
.78422 .389 m .78017 .38632 L .78375 .38723 L F
.617 .141 .101 r
.78156 .38767 m .78247 .38617 L .78139 .38519 L F
.113 .564 .917 r
.78247 .38617 m .78375 .38723 L .78362 .3872 L F
.599 .282 .403 r
.49376 .58379 m .49086 .58595 L .49119 .58428 L F
.174 .699 .869 r
.22296 .64796 m .22353 .64757 L .22118 .64789 L F
.22296 .64796 m .2253 .64786 L .22353 .64757 L F
.453 .078 .236 r
.46054 .62054 m .46299 .62029 L .46095 .6199 L F
.277 .462 .862 r
.52983 .55331 m .52854 .55507 L .52716 .55388 L F
.52983 .55331 m .53156 .55645 L .52854 .55507 L F
.469 .214 .444 r
.49183 .60241 m .48911 .60522 L .4889 .60245 L F
.719 .45 .519 r
.46849 .58332 m .46483 .58599 L .46639 .58456 L F
.893 .569 .072 r
.59451 .49959 m .59502 .5023 L .5958 .50315 L F
.83 .987 .871 r
.5958 .50315 m .59229 .50511 L .59401 .50629 L F
.5958 .50315 m .59502 .5023 L .59229 .50511 L F
.603 .914 .978 r
.5958 .50315 m .59721 .50147 L .59502 .5023 L F
.5958 .50315 m .59721 .50147 L .59502 .5023 L F
.094 .39 .848 r
.78644 .38897 m .78422 .389 L .78375 .38723 L F
.78644 .38897 m .78707 .39062 L .78422 .389 L F
.625 .469 .65 r
.79715 .41884 m .79472 .4219 L .79756 .42119 L F
.61 .531 .741 r
.79472 .4219 m .79842 .42456 L .79756 .42119 L F
.414 .258 .559 r
.41163 .65325 m .41295 .65025 L .41261 .65096 L F
.867 .766 .749 r
.59451 .49959 m .59669 .49748 L .59529 .49703 L F
.934 .81 .699 r
.7647 .41547 m .76185 .41771 L .76379 .41441 L F
.7647 .41547 m .76334 .41915 L .76185 .41771 L F
.952 .919 .741 r
.76658 .41095 m .7647 .41547 L .76379 .41441 L F
.747 .944 .947 r
.71182 .42064 m .71603 .41941 L .71471 .41791 L F
.771 .849 .91 r
.71471 .41791 m .71603 .41941 L .71795 .41783 L F
.646 .677 .865 r
.29386 .55278 m .28937 .55123 L .29166 .55171 L F
.816 .845 .871 r
.29524 .55128 m .29386 .55278 L .29166 .55171 L F
.55 .326 .528 r
.29524 .55128 m .29427 .55307 L .29386 .55278 L F
.322 .572 .93 r
.75896 .43126 m .76007 .4297 L .75803 .42976 L F
.75896 .43126 m .76279 .43206 L .76007 .4297 L F
.968 .725 .518 r
.68271 .42492 m .68259 .42739 L .68119 .42374 L F
.227 0 .055 r
.17386 .5667 m .17262 .56826 L .17074 .56879 L F
.068 0 0 r
.1759 .566 m .17262 .56826 L .17386 .5667 L F
0 0 0 r
.56998 .56003 m .56954 .56186 L .57037 .5598 L F
.748 .771 .871 r
.72682 .41279 m .72938 .41224 L .72826 .40864 L F
.729 .76 .877 r
.72826 .40864 m .72938 .41224 L .73176 .40917 L F
.727 .764 .882 r
.72938 .41224 m .7329 .41097 L .73176 .40917 L F
0 0 0 r
.23135 .56014 m .23375 .55609 L .23194 .55773 L F
.028 0 0 r
.19096 .54366 m .19323 .54314 L .19536 .54195 L F
.69 .966 .741 r
.19536 .54195 m .19323 .54314 L .19343 .54293 L F
.01 0 0 r
.19318 .5424 m .19536 .54195 L .19638 .54144 L F
.028 0 0 r
.19096 .54366 m .19536 .54195 L .19318 .5424 L F
.69 .966 .741 r
.19536 .54195 m .19343 .54293 L .19497 .54139 L F
.01 0 0 r
.19638 .54144 m .19536 .54195 L .19675 .54133 L F
.461 0 0 r
.19675 .54133 m .19536 .54195 L .19903 .54173 L F
.501 .561 .849 r
.43984 .59786 m .43737 .59976 L .43624 .59661 L F
.425 .419 .749 r
.43984 .59786 m .4406 .60145 L .43737 .59976 L F
.524 .373 .619 r
.4406 .60145 m .43815 .60207 L .43737 .59976 L F
.205 0 .278 r
.2131 .68692 m .21233 .68929 L .21461 .68608 L F
.848 .824 .346 r
.21233 .68929 m .2131 .68692 L .21461 .68608 L F
.625 .549 .748 r
.20849 .7079 m .2111 .70964 L .20951 .70793 L F
.595 .031 0 r
.49937 .54751 m .50018 .54914 L .49775 .54738 L F
.49937 .54751 m .50278 .5498 L .50018 .54914 L F
.516 .602 .878 r
.22624 .68053 m .2232 .67837 L .22528 .67786 L F
.315 .344 .732 r
.22785 .67751 m .22624 .68053 L .22528 .67786 L F
.22785 .67751 m .22822 .67978 L .22624 .68053 L F
.286 .044 .361 r
.22787 .68186 m .22624 .68053 L .22822 .67978 L F
.22787 .68186 m .22581 .68294 L .22624 .68053 L F
.811 .816 .334 r
.77457 .41058 m .77551 .40645 L .77416 .40818 L F
.904 .805 .739 r
.77258 .4121 m .77457 .41058 L .77416 .40818 L F
.77258 .4121 m .77362 .41304 L .77457 .41058 L F
.994 .753 .448 r
.65434 .43995 m .65443 .44386 L .653 .44098 L F
.625 .905 .606 r
.65434 .43995 m .65516 .43861 L .65748 .44085 L F
.65434 .43995 m .653 .44098 L .65516 .43861 L F
0 .185 .714 r
.40403 .62965 m .40462 .62852 L .4026 .62643 L F
.041 .339 .818 r
.40403 .62965 m .40675 .63152 L .40462 .62852 L F
.801 .999 .836 r
.43534 .60431 m .43368 .60619 L .43405 .60456 L F
.528 .378 .622 r
.28724 .59946 m .28746 .60204 L .28518 .60256 L F
.47 .281 .542 r
.28746 .60204 m .28515 .60514 L .28518 .60256 L F
.35 .075 .349 r
.83705 .43272 m .83405 .43522 L .83839 .43419 L F
.81 .983 .891 r
.84064 .43087 m .83705 .43272 L .83839 .43419 L F
.708 .688 .829 r
.20048 .72087 m .20246 .72371 L .20314 .72219 L F
.296 .552 .923 r
.7691 .4372 m .77077 .43932 L .77192 .43798 L F
.257 .492 .891 r
.77077 .43932 m .77359 .44052 L .77192 .43798 L F
.561 .886 .989 r
.51488 .6282 m .51255 .62904 L .51382 .62965 L F
.51488 .6282 m .51255 .62904 L .51382 .62965 L F
.531 .343 .571 r
.25535 .59899 m .25776 .59594 L .25564 .59653 L F
.647 .691 .877 r
.78817 .4074 m .79208 .40989 L .78974 .40711 L F
.692 .3 .301 r
.74498 .37241 m .74608 .37053 L .74487 .37069 L F
.515 .695 .95 r
.80509 .40118 m .80326 .40327 L .80136 .40081 L F
.80509 .40118 m .80579 .4029 L .80326 .40327 L F
.566 .143 .199 r
.44256 .56563 m .44529 .56569 L .44648 .56439 L F
.395 .002 .171 r
.44529 .56569 m .44862 .56342 L .44648 .56439 L F
.998 .846 .525 r
.5181 .59585 m .51749 .59868 L .5184 .59936 L F
0 0 .123 r
.51867 .60092 m .51799 .60251 L .5184 .59936 L F
.51867 .60092 m .5184 .59936 L .51749 .59868 L F
.907 .717 .635 r
.57718 .51487 m .57862 .51821 L .57686 .51735 L F
.945 .708 .547 r
.57862 .51821 m .57673 .51993 L .57686 .51735 L F
.57862 .51821 m .57843 .52107 L .57673 .51993 L F
.116 0 .189 r
.14549 .5664 m .14625 .56601 L .14791 .56359 L F
0 0 0 r
.14521 .5668 m .14625 .56601 L .14549 .5664 L F
.457 .413 .721 r
.79715 .41884 m .79957 .41872 L .79878 .41444 L F
.457 .395 .699 r
.79715 .41884 m .8 .42049 L .79957 .41872 L F
.496 .38 .651 r
.79756 .42119 m .8 .42049 L .79715 .41884 L F
.883 .809 .771 r
.57801 .52684 m .57616 .5266 L .57774 .5235 L F
.921 .722 .617 r
.57801 .52684 m .57553 .52897 L .57616 .5266 L F
.57801 .52684 m .57761 .53024 L .57553 .52897 L F
.565 .385 .596 r
.46315 .59964 m .46582 .59918 L .46544 .59622 L F
0 0 0 r
.46544 .59622 m .46431 .59818 L .46315 .59964 L F
0 .082 .602 r
.46586 .5923 m .46681 .59498 L .46544 .59622 L F
.506 .344 .595 r
.46544 .59622 m .46582 .59918 L .46839 .59853 L F
0 0 0 r
.46536 .59688 m .46544 .59622 L .46681 .59498 L F
.46536 .59688 m .46431 .59818 L .46544 .59622 L F
0 0 .528 r
.53862 .5682 m .53983 .57084 L .53895 .57242 L F
.917 .649 .156 r
.53983 .57084 m .54079 .57468 L .53895 .57242 L F
.423 .11 .327 r
.79861 .43975 m .79811 .4423 L .7957 .44289 L F
.546 .217 .362 r
.80167 .44126 m .79861 .43975 L .80127 .4393 L F
.80167 .44126 m .79811 .4423 L .79861 .43975 L F
.024 0 .2 r
.48253 .61198 m .48284 .61553 L .48177 .61592 L F
.585 .069 0 r
.48402 .61057 m .48557 .61242 L .48253 .61198 L F
0 0 .171 r
.48384 .61377 m .48253 .61198 L .48557 .61242 L F
.48384 .61377 m .48284 .61553 L .48253 .61198 L F
.732 .225 0 r
.2552 .552 m .25716 .55471 L .25439 .55254 L F
.966 .725 .523 r
.77103 .43137 m .76957 .42796 L .77038 .4296 L F
0 .012 .583 r
.77038 .4296 m .77215 .43288 L .77103 .43137 L F
.635 .328 .433 r
.46743 .62411 m .46189 .62608 L .46202 .62373 L F
.559 .443 .677 r
.47884 .58461 m .48166 .58685 L .48143 .58465 L F
.758 .467 .492 r
.44043 .63526 m .44207 .63812 L .44309 .63574 L F
.002 0 .11 r
.44309 .63574 m .44207 .63812 L .44371 .63665 L F
.639 .437 .593 r
.79376 .43255 m .79589 .43025 L .79417 .43168 L F
.121 .549 .919 r
.76279 .43206 m .76403 .43328 L .7651 .43347 L F
.478 .527 .83 r
.17058 .63909 m .17158 .64101 L .17259 .64045 L F
0 0 0 r
.16456 .5537 m .16459 .55466 L .16582 .55352 L F
.16456 .5537 m .16277 .55569 L .16459 .55466 L F
.492 .819 1 r
.43025 .62106 m .43264 .62009 L .42966 .62067 L F
.43025 .62106 m .43338 .62095 L .43264 .62009 L F
.19 0 .377 r
.15399 .57822 m .15354 .58067 L .15211 .58141 L F
0 0 .406 r
.15302 .58327 m .15211 .58141 L .15354 .58067 L F
.14 0 0 r
.53076 .51637 m .52968 .51549 L .52825 .51672 L F
.53076 .51637 m .53196 .51459 L .52968 .51549 L F
.611 .284 .392 r
.48688 .60579 m .48606 .60796 L .48327 .60786 L F
.566 .238 .373 r
.48892 .60757 m .48688 .60579 L .48911 .60522 L F
.48892 .60757 m .48606 .60796 L .48688 .60579 L F
.575 .304 .467 r
.44862 .56342 m .45118 .56344 L .45179 .56128 L F
.617 .344 .482 r
.45179 .56128 m .45118 .56344 L .45471 .56232 L F
.712 .23 0 r
.50286 .5716 m .50516 .5742 L .50447 .57235 L F
0 0 0 r
.23135 .56014 m .23228 .55872 L .23375 .55609 L F
.079 .289 .773 r
.23135 .56014 m .2334 .56124 L .23228 .55872 L F
.103 .178 .657 r
.40985 .64109 m .4105 .64462 L .41171 .64323 L F
.131 .22 .69 r
.4105 .64462 m .41249 .64684 L .41171 .64323 L F
.906 .605 .112 r
.53801 .5681 m .53834 .56635 L .5364 .5653 L F
.53801 .5681 m .53862 .5682 L .53834 .56635 L F
.842 .412 .208 r
.49703 .56605 m .49885 .56895 L .50078 .56921 L F
.761 .25 0 r
.5008 .57089 m .50078 .56921 L .49885 .56895 L F
.5008 .57089 m .50286 .5716 L .50078 .56921 L F
.469 .84 .99 r
.21059 .64931 m .21119 .64808 L .20905 .64859 L F
.21059 .64931 m .21274 .64879 L .21119 .64808 L F
.027 .076 .578 r
.2331 .60497 m .23416 .605 L .23337 .60135 L F
.863 .929 .868 r
.52168 .53367 m .51785 .53557 L .52013 .53317 L F
.761 .934 .942 r
.52168 .53367 m .52256 .53144 L .52261 .53322 L F
.52168 .53367 m .52013 .53317 L .52256 .53144 L F
.821 .372 0 r
.41474 .65435 m .41327 .65303 L .41241 .65353 L F
.41474 .65435 m .41573 .65621 L .41327 .65303 L F
.751 .29 0 r
.41327 .65303 m .41573 .65621 L .41466 .6552 L F
0 0 .156 r
.41466 .6552 m .41471 .65217 L .41327 .65303 L F
.41471 .65217 m .41473 .65135 L .41327 .65303 L F
.821 .372 0 r
.41241 .65353 m .41327 .65303 L .41163 .65325 L F
.662 .502 .657 r
.48457 .58173 m .48806 .58352 L .48709 .58114 L F
.48457 .58173 m .4848 .58424 L .48806 .58352 L F
.8 .535 .536 r
.43232 .61693 m .43589 .62018 L .43596 .61757 L F
.577 .333 .51 r
.43589 .62018 m .43848 .61746 L .43596 .61757 L F
.569 .934 .796 r
.68373 .43531 m .68729 .43348 L .68619 .43419 L F
0 0 0 r
.68729 .43348 m .68967 .43257 L .68951 .43293 L F
.68619 .43419 m .68729 .43348 L .68951 .43293 L F
.51 .125 .245 r
.45723 .56247 m .45964 .56271 L .46108 .5601 L F
.488 .102 .234 r
.46108 .5601 m .46287 .56148 L .46418 .55999 L F
.46108 .5601 m .45964 .56271 L .46287 .56148 L F
.385 .638 .955 r
.26277 .53878 m .26187 .54015 L .26056 .53907 L F
.26277 .53878 m .26442 .54047 L .26187 .54015 L F
.719 .903 .961 r
.75179 .39556 m .74707 .39652 L .7507 .39423 L F
.826 .914 .897 r
.75277 .3945 m .75179 .39556 L .7507 .39423 L F
.521 .474 .744 r
.43028 .63736 m .43124 .64022 L .42866 .64077 L F
.555 .308 .497 r
.43124 .64022 m .42757 .64384 L .42866 .64077 L F
.482 .417 .707 r
.44944 .59326 m .44975 .58817 L .44818 .59012 L F
.44944 .59326 m .45151 .59272 L .44975 .58817 L F
.651 .573 .754 r
.44891 .59563 m .45151 .59272 L .44944 .59326 L F
.949 .715 .55 r
.57727 .51225 m .57546 .51384 L .57536 .51138 L F
.57727 .51225 m .57718 .51487 L .57546 .51384 L F
.959 .631 .343 r
.77377 .41504 m .77362 .41304 L .77258 .4121 L F
.732 .625 .739 r
.43737 .61391 m .4421 .61755 L .44064 .61344 L F
.43737 .61391 m .43848 .61746 L .4421 .61755 L F
.537 .17 .293 r
.43839 .61988 m .4421 .61755 L .43848 .61746 L F
.43839 .61988 m .44118 .61984 L .4421 .61755 L F
.39 .49 .841 r
.44064 .61344 m .4421 .61755 L .44379 .61648 L F
.414 .053 .24 r
.4421 .61755 m .44351 .61923 L .44379 .61648 L F
.4421 .61755 m .44118 .61984 L .44351 .61923 L F
.794 .8 .857 r
.75945 .4209 m .76065 .42394 L .75667 .42372 L F
.814 .763 .806 r
.76065 .42394 m .75824 .42533 L .75667 .42372 L F
.844 .821 .827 r
.76181 .4216 m .76065 .42394 L .75945 .4209 L F
.57 .37 .57 r
.80908 .41591 m .80961 .41845 L .80667 .41911 L F
.567 .432 .657 r
.81074 .41213 m .81174 .41528 L .80908 .41591 L F
.661 .428 .556 r
.8121 .41794 m .80908 .41591 L .81174 .41528 L F
.8121 .41794 m .80961 .41845 L .80908 .41591 L F
.672 .319 0 r
.2319 .59612 m .2315 .59529 L .23042 .59276 L F
.677 .325 0 r
.2319 .59612 m .2338 .60062 L .2315 .59529 L F
.682 .619 .779 r
.51851 .52363 m .52311 .52683 L .52098 .52358 L F
.924 .757 .656 r
.52098 .52358 m .52311 .52683 L .5229 .52454 L F
.917 .969 .67 r
.76095 .40389 m .76222 .40348 L .76207 .40295 L F
.76095 .40389 m .7604 .40691 L .76222 .40348 L F
.813 .963 .641 r
.76428 .39973 m .76207 .40295 L .76222 .40348 L F
.111 0 0 r
.23375 .55609 m .23417 .55791 L .23429 .55529 L F
.23375 .55609 m .23228 .55872 L .23417 .55791 L F
.384 .123 .39 r
.43124 .59921 m .43437 .59585 L .43168 .59668 L F
.211 .736 .798 r
.20111 .54026 m .20321 .53986 L .20541 .53974 L F
.491 .902 .898 r
.20541 .53974 m .2054 .53888 L .20748 .53943 L F
.20541 .53974 m .20321 .53986 L .2054 .53888 L F
.572 .381 .584 r
.42702 .65283 m .42431 .65058 L .42617 .65014 L F
.42702 .65283 m .4237 .65367 L .42431 .65058 L F
.874 .439 .155 r
.54079 .57468 m .54192 .57688 L .54258 .5754 L F
.961 .665 .242 r
.54258 .5754 m .54192 .57688 L .54298 .57817 L F
.611 .483 .682 r
.40758 .61749 m .40751 .62142 L .40803 .61955 L F
.909 .714 .626 r
.40803 .61955 m .40886 .62355 L .40751 .62142 L F
.40803 .61955 m .4079 .6198 L .40886 .62355 L F
.446 .347 .649 r
.40779 .61961 m .40751 .62142 L .40794 .62105 L F
.40758 .61749 m .40755 .61958 L .40779 .61961 L F
.40758 .61749 m .40794 .62105 L .40788 .61927 L F
.948 .706 .538 r
.40788 .61924 m .40793 .61963 L .40803 .61955 L F
.446 .347 .649 r
.40788 .61924 m .40788 .61927 L .40788 .61926 L F
.40758 .61749 m .40788 .61927 L .40788 .61924 L F
.948 .706 .538 r
.4062 .61586 m .40605 .62114 L .40793 .61963 L F
.4062 .61586 m .40793 .61963 L .40788 .61924 L F
.915 .93 .556 r
.40644 .62137 m .40602 .62338 L .4079 .6198 L F
.40795 .61964 m .4079 .6198 L .40803 .61955 L F
.446 .347 .649 r
.40755 .61958 m .40752 .62091 L .40779 .61961 L F
.915 .93 .556 r
.40644 .62137 m .4079 .6198 L .40795 .61964 L F
.446 .347 .649 r
.40752 .62091 m .40751 .62142 L .40765 .62053 L F
.40752 .62091 m .40765 .62053 L .40779 .61961 L F
.915 .93 .556 r
.40644 .62137 m .40795 .61964 L .40608 .62112 L F
.40795 .61964 m .40793 .61963 L .40605 .62114 L F
.565 .545 .791 r
.40886 .62355 m .40794 .62105 L .40751 .62142 L F
.909 .714 .626 r
.40794 .62105 m .40602 .62338 L .40801 .6235 L F
.4079 .6198 m .40765 .62027 L .40794 .62105 L F
.40765 .62027 m .40602 .62338 L .40794 .62105 L F
.4079 .6198 m .40801 .6235 L .40886 .62355 L F
.565 .545 .791 r
.40886 .62355 m .40989 .61932 L .40794 .62105 L F
0 .115 .661 r
.40656 .62049 m .40779 .62231 L .40644 .62137 L F
.40779 .62231 m .40855 .62344 L .40644 .62137 L F
.915 .93 .556 r
.40644 .62137 m .40608 .62112 L .40605 .62114 L F
.40795 .61964 m .40803 .61955 L .40793 .61963 L F
.446 .347 .649 r
.40788 .61926 m .40794 .62105 L .40815 .62086 L F
.948 .706 .538 r
.40788 .61924 m .40803 .61955 L .40758 .61749 L F
.446 .347 .649 r
.40758 .61749 m .40815 .62086 L .40989 .61932 L F
.948 .706 .538 r
.4062 .61586 m .40788 .61924 L .40758 .61749 L F
.402 .184 .464 r
.40758 .61749 m .40935 .61302 L .4062 .61586 L F
.40758 .61749 m .40996 .61447 L .40935 .61302 L F
.40758 .61749 m .41031 .61741 L .40996 .61447 L F
.423 .349 .669 r
.40758 .61749 m .40989 .61932 L .41031 .61741 L F
.054 .014 .489 r
.57973 .57738 m .57999 .57999 L .5784 .58141 L F
0 0 .157 r
.57999 .57999 m .57857 .58395 L .5784 .58141 L F
.44 .465 .789 r
.2646 .58132 m .26528 .57805 L .26363 .57829 L F
.2646 .58132 m .26668 .58037 L .26528 .57805 L F
.34 .186 .521 r
.26443 .58384 m .26668 .58037 L .2646 .58132 L F
.674 .537 .69 r
.19086 .74691 m .19326 .74386 L .18935 .7437 L F
.439 .01 .125 r
.46737 .5805 m .46962 .58033 L .47117 .57839 L F
.63 .223 .254 r
.46962 .58033 m .47354 .58051 L .47117 .57839 L F
.663 .7 .874 r
.19172 .72274 m .19553 .72384 L .19384 .72252 L F
.598 .858 .993 r
.19553 .72384 m .19617 .72219 L .19384 .72252 L F
.19553 .72384 m .19789 .72306 L .19617 .72219 L F
.497 .273 .504 r
.4606 .60263 m .4629 .60219 L .46315 .59964 L F
.106 0 0 r
.46431 .59818 m .46059 .59975 L .46315 .59964 L F
.774 .516 .545 r
.46315 .59964 m .46691 .60251 L .46582 .59918 L F
.46315 .59964 m .4629 .60219 L .46691 .60251 L F
.091 .334 .808 r
.1592 .62958 m .15954 .62873 L .15828 .62793 L F
.806 .993 .871 r
.48559 .57161 m .48643 .57183 L .48843 .57013 L F
.805 .315 0 r
.48559 .57161 m .48911 .57462 L .48643 .57183 L F
.265 0 0 r
.23609 .53862 m .23823 .53879 L .2401 .53834 L F
.423 0 0 r
.2401 .53834 m .23823 .53879 L .24216 .53877 L F
.81 .983 .891 r
.84064 .43087 m .8402 .42991 L .83705 .43272 L F
.945 .951 .643 r
.84175 .42648 m .8402 .42991 L .84064 .43087 L F
.209 0 0 r
.43691 .61363 m .43927 .61311 L .44076 .61149 L F
.744 .317 .237 r
.44076 .61149 m .43927 .61311 L .44314 .61372 L F
.587 .385 .575 r
.44076 .61149 m .44314 .61372 L .44308 .61116 L F
.945 .944 .75 r
.5415 .58938 m .54184 .5906 L .54316 .59023 L F
0 0 .413 r
.54316 .59023 m .54168 .58665 L .5415 .58938 L F
.54316 .59023 m .54394 .58663 L .54168 .58665 L F
.54316 .59023 m .54407 .58979 L .54394 .58663 L F
.79 .303 0 r
.54316 .59023 m .54498 .59281 L .54344 .59185 L F
.54316 .59023 m .54344 .59185 L .54407 .58979 L F
.613 .155 0 r
.7651 .43347 m .76713 .43614 L .76809 .43526 L F
.112 .402 .854 r
.76713 .43614 m .7691 .4372 L .76809 .43526 L F
.376 .163 .457 r
.82983 .43918 m .82982 .44189 L .82755 .44291 L F
.653 .569 .748 r
.83207 .4364 m .82983 .43918 L .82902 .43579 L F
.593 .484 .698 r
.83207 .4364 m .83261 .43889 L .82983 .43918 L F
0 0 0 r
.83261 .43889 m .82982 .44189 L .82983 .43918 L F
.25 .541 .924 r
.79803 .39728 m .79556 .39784 L .79479 .39632 L F
.79803 .39728 m .79888 .39888 L .79556 .39784 L F
.298 0 .184 r
.46648 .61693 m .46875 .61641 L .46957 .61431 L F
.425 .059 .238 r
.46957 .61431 m .47129 .61589 L .47166 .61387 L F
.46957 .61431 m .46875 .61641 L .47129 .61589 L F
.375 .134 .415 r
.46957 .61431 m .47166 .61387 L .47188 .61168 L F
.532 .287 .489 r
.43662 .57836 m .43862 .57886 L .43967 .57597 L F
.727 .782 .292 r
.43967 .57597 m .43862 .57886 L .44025 .57413 L F
.238 0 .283 r
.55327 .49639 m .55511 .49668 L .55603 .49343 L F
.432 .066 .242 r
.55253 .49806 m .55511 .49668 L .55327 .49639 L F
.691 .424 .514 r
.40886 .62512 m .40757 .62351 L .40886 .62355 L F
.40886 .62512 m .40611 .62539 L .40757 .62351 L F
.751 .693 .797 r
.40602 .62338 m .40886 .62512 L .40886 .62355 L F
.565 .545 .791 r
.40886 .62355 m .41119 .62304 L .40989 .61932 L F
.608 .29 .406 r
.40886 .62355 m .41111 .62558 L .40886 .62512 L F
.40886 .62355 m .41111 .62558 L .40886 .62512 L F
.973 .66 .322 r
.54105 .58625 m .54185 .58435 L .54108 .58288 L F
.54105 .58625 m .54168 .58665 L .54185 .58435 L F
.305 0 0 r
.54394 .58663 m .54185 .58435 L .54168 .58665 L F
.64 .223 .237 r
.22213 .67814 m .22528 .67786 L .2232 .67837 L F
.749 .33 .254 r
.67755 .4183 m .67428 .4177 L .67356 .41589 L F
.749 .961 .667 r
.50295 .52916 m .50269 .52876 L .50201 .5304 L F
.471 .759 .993 r
.50201 .5304 m .50269 .52876 L .50025 .52908 L F
.958 .773 .612 r
.50025 .52908 m .50119 .53251 L .50201 .5304 L F
.471 .759 .993 r
.50201 .5304 m .50269 .52876 L .50025 .52908 L F
.364 .582 .926 r
.80136 .40081 m .79945 .40062 L .79888 .39888 L F
.806 .993 .871 r
.48559 .57161 m .48843 .57013 L .48753 .56842 L F
.696 .729 .876 r
.48753 .56842 m .48843 .57013 L .49074 .56905 L F
0 0 0 r
.17598 .54847 m .17605 .54916 L .17808 .54779 L F
.17598 .54847 m .17393 .54983 L .17605 .54916 L F
.655 .97 .886 r
.242 .64809 m .24032 .64845 L .23867 .64992 L F
.877 .974 .844 r
.24224 .6463 m .24032 .64845 L .242 .64809 L F
.785 .712 .784 r
.74886 .41751 m .75259 .4177 L .75185 .4149 L F
.74886 .41751 m .75056 .41919 L .75259 .4177 L F
.797 .797 .852 r
.75185 .4149 m .75259 .4177 L .75502 .41513 L F
.622 .651 .858 r
.81205 .40553 m .81074 .4096 L .80967 .40572 L F
.81205 .40553 m .81334 .40883 L .81074 .4096 L F
.639 .544 .73 r
.81334 .40883 m .81074 .41213 L .81074 .4096 L F
.264 0 0 r
.66141 .4026 m .66344 .40321 L .66471 .40344 L F
.647 .56 .742 r
.66604 .40576 m .66355 .40458 L .66471 .40344 L F
.723 .469 .543 r
.66471 .40344 m .66604 .40576 L .66355 .40458 L F
.514 0 0 r
.66563 .40448 m .66471 .40344 L .66344 .40321 L F
.66563 .40448 m .66766 .40512 L .66471 .40344 L F
.947 .956 .725 r
.76674 .40932 m .76658 .41095 L .76587 .41068 L F
.952 .919 .741 r
.76658 .41095 m .76379 .41441 L .76587 .41068 L F
.65 .797 .953 r
.15742 .60225 m .15666 .60484 L .15533 .60347 L F
.647 .307 .383 r
.54394 .58663 m .5483 .58669 L .54774 .58503 L F
.656 .493 .652 r
.55012 .58652 m .54774 .58503 L .5483 .58669 L F
.55012 .58652 m .55047 .58448 L .54774 .58503 L F
0 0 0 r
.43625 .56821 m .44128 .56678 L .43644 .56711 L F
.975 .914 .676 r
.7604 .40691 m .75877 .40759 L .75962 .40829 L F
.915 .98 .748 r
.76095 .40389 m .75877 .40759 L .7604 .40691 L F
.551 .875 .993 r
.69617 .43079 m .69851 .42997 L .69788 .42909 L F
.461 .461 .771 r
.79477 .40915 m .79569 .41293 L .7981 .41091 L F
.455 .45 .764 r
.79569 .41293 m .79878 .41444 L .7981 .41091 L F
.77 .681 .765 r
.43282 .5779 m .43386 .58129 L .43662 .57836 L F
0 .463 .763 r
.43662 .57836 m .43675 .57818 L .43862 .57886 L F
.874 .436 .131 r
.43862 .57886 m .43675 .57818 L .43662 .57836 L F
.713 .586 .712 r
.43122 .58143 m .4319 .58396 L .43386 .58129 L F
.612 .342 .483 r
.74109 .37623 m .74133 .37821 L .73769 .37915 L F
.598 .34 .496 r
.74109 .37623 m .74364 .37826 L .74133 .37821 L F
.74109 .37623 m .74361 .37618 L .74364 .37826 L F
.182 .521 .918 r
.19161 .6248 m .19331 .62513 L .19305 .62645 L F
.348 .594 .938 r
.19715 .6287 m .19305 .62645 L .19517 .62762 L F
.047 .369 .837 r
.19331 .62513 m .19517 .62762 L .19305 .62645 L F
0 .078 .571 r
.77387 .38899 m .77376 .38904 L .77105 .38653 L F
0 .551 .731 r
.77727 .38928 m .77376 .38904 L .77387 .38899 L F
.701 .775 .909 r
.51466 .52316 m .51625 .52445 L .51851 .52363 L F
.758 .713 .81 r
.83549 .42418 m .83301 .42692 L .83186 .42369 L F
.708 .587 .718 r
.77643 .43978 m .77699 .4447 L .77472 .4419 L F
.446 .393 .706 r
.77931 .44145 m .77699 .4447 L .77643 .43978 L F
0 .095 .639 r
.77699 .4447 m .77718 .44446 L .77472 .4419 L F
.639 .497 .673 r
.78056 .44355 m .77714 .4461 L .77699 .4447 L F
0 0 .223 r
.77699 .4447 m .77714 .4461 L .77718 .44446 L F
.639 .497 .673 r
.78056 .44355 m .77699 .4447 L .77931 .44145 L F
.473 .404 .698 r
.29602 .5563 m .29387 .55756 L .29427 .55307 L F
.322 .262 .633 r
.29619 .55888 m .29387 .55756 L .29602 .5563 L F
.29619 .55888 m .29422 .56014 L .29387 .55756 L F
.757 .593 .673 r
.58143 .4814 m .58223 .48465 L .58448 .48161 L F
.726 .548 .65 r
.58223 .48465 m .5859 .4849 L .58448 .48161 L F
.728 .549 .649 r
.58448 .48161 m .5859 .4849 L .58836 .48476 L F
.293 .574 .937 r
.79422 .39483 m .79154 .39557 L .79058 .39382 L F
.79422 .39483 m .79479 .39632 L .79154 .39557 L F
.39 .103 .352 r
.28489 .61023 m .28338 .60883 L .28542 .60792 L F
.28489 .61023 m .28271 .61084 L .28338 .60883 L F
.644 .722 .905 r
.73176 .40917 m .7329 .41097 L .73537 .41023 L F
.123 .663 .843 r
.24216 .53877 m .24436 .53875 L .2461 .53903 L F
.279 .758 .93 r
.24436 .53875 m .24825 .53894 L .2461 .53903 L F
.981 .888 .657 r
.57386 .54796 m .5719 .54941 L .57318 .54724 L F
.57386 .54796 m .5729 .55168 L .5719 .54941 L F
.982 .91 .62 r
.57405 .54495 m .57386 .54796 L .57318 .54724 L F
0 0 0 r
.41909 .5921 m .41777 .59381 L .42062 .58997 L F
.51 .8 .998 r
.41861 .59497 m .41777 .59381 L .41909 .5921 L F
.41861 .59497 m .41854 .59618 L .41777 .59381 L F
.054 .543 .888 r
.19886 .62907 m .19715 .6287 L .19517 .62762 L F
.792 .507 0 r
.50876 .57997 m .5093 .58154 L .5083 .57785 L F
.736 .325 0 r
.50876 .57997 m .51078 .58365 L .5093 .58154 L F
0 0 0 r
.76249 .38077 m .76115 .38269 L .76029 .38452 L F
.22583 .62905 m .22493 .62916 L .22265 .62988 L F
.22583 .62905 m .2271 .62866 L .22493 .62916 L F
.792 .783 .844 r
.72348 .41249 m .72682 .41279 L .72525 .4115 L F
.748 .771 .871 r
.72682 .41279 m .72826 .40864 L .72525 .4115 L F
0 0 .065 r
.65868 .40588 m .66141 .4026 L .65893 .4037 L F
0 0 .301 r
.53283 .59365 m .53338 .59497 L .53238 .59285 L F
.53283 .59365 m .53356 .59605 L .53338 .59497 L F
.606 .553 .769 r
.80959 .42347 m .80834 .4275 L .80729 .42415 L F
.80959 .42347 m .81077 .42676 L .80834 .4275 L F
.275 .508 .898 r
.28253 .54369 m .28189 .54537 L .28074 .54341 L F
.368 .616 .947 r
.28253 .54369 m .28405 .54559 L .28189 .54537 L F
.533 .334 .556 r
.70888 .4035 m .71162 .40292 L .71127 .40009 L F
.543 .341 .556 r
.71127 .40009 m .7139 .40212 L .71391 .39927 L F
.71127 .40009 m .71162 .40292 L .7139 .40212 L F
0 0 0 r
.72432 .39231 m .72508 .39168 L .72328 .3929 L F
.72432 .39231 m .72328 .3929 L .72216 .39366 L F
.27 .725 .956 r
.72321 .39165 m .72495 .39195 L .72432 .39231 L F
0 .185 .719 r
.72687 .39227 m .72711 .39358 L .72508 .39168 L F
.72687 .39227 m .72508 .39168 L .72432 .39231 L F
.27 .725 .956 r
.72495 .39195 m .72687 .39227 L .72432 .39231 L F
0 0 0 r
.72432 .39231 m .72216 .39366 L .72191 .3938 L F
.534 .344 .569 r
.70647 .40605 m .70907 .40559 L .70888 .4035 L F
.55 .261 .429 r
.70597 .4084 m .70907 .40559 L .70647 .40605 L F
.514 .806 .998 r
.18364 .62271 m .18305 .62432 L .18136 .6227 L F
.18364 .62271 m .18523 .62378 L .18305 .62432 L F
.811 .773 .818 r
.40779 .60915 m .41103 .61277 L .40957 .60698 L F
.40707 .61002 m .40857 .61106 L .40779 .60915 L F
.40857 .61106 m .41103 .61277 L .40779 .60915 L F
.692 .353 0 r
.40935 .61302 m .40996 .61447 L .40977 .614 L F
.40896 .61201 m .40977 .614 L .40856 .61098 L F
.40935 .61302 m .40945 .61322 L .40896 .61201 L F
0 .201 .716 r
.40996 .61447 m .41073 .61348 L .40995 .61258 L F
.40941 .61309 m .40995 .61258 L .40856 .61098 L F
.40996 .61447 m .40995 .61258 L .40941 .61309 L F
.406 .33 .657 r
.40856 .61098 m .41073 .61348 L .40935 .61302 L F
.637 .094 0 r
.40707 .61002 m .40919 .61214 L .41103 .61277 L F
.44 .87 .921 r
.41103 .61277 m .41009 .61245 L .41169 .6113 L F
.41009 .61245 m .40919 .61214 L .41109 .6115 L F
.41009 .61245 m .41109 .6115 L .41169 .6113 L F
.792 .972 .678 r
.40919 .61214 m .40901 .61237 L .40935 .61302 L F
.40901 .61237 m .4069 .6151 L .40935 .61302 L F
.692 .353 0 r
.40935 .61302 m .40977 .614 L .40945 .61322 L F
.64 .349 .462 r
.40996 .61447 m .41031 .61741 L .41219 .61664 L F
.581 .356 .539 r
.40996 .61447 m .41219 .61664 L .41245 .61415 L F
.887 .458 .132 r
.42049 .66266 m .41926 .66239 L .41827 .66052 L F
.41879 .66071 m .41827 .66052 L .41772 .65949 L F
0 .09 .628 r
.41772 .65949 m .41926 .66239 L .41922 .66138 L F
.565 0 0 r
.41572 .65958 m .41922 .66138 L .41587 .65985 L F
.41528 .65879 m .41744 .66021 L .41572 .65958 L F
.41744 .66021 m .41922 .66138 L .41572 .65958 L F
.887 .458 .132 r
.42049 .66266 m .41827 .66052 L .41879 .66071 L F
.588 .932 .951 r
.42141 .66134 m .41926 .66239 L .42049 .66266 L F
.525 .261 .457 r
.47166 .61387 m .47466 .61124 L .47188 .61168 L F
.24 .064 .43 r
.55742 .59283 m .5595 .59366 L .56049 .59038 L F
.077 0 .374 r
.56049 .59038 m .56272 .58885 L .56078 .58934 L F
.56049 .59038 m .56255 .59123 L .56272 .58885 L F
.184 0 .079 r
.56049 .59038 m .5595 .59366 L .56255 .59123 L F
.51 .8 .998 r
.41861 .59497 m .42078 .59564 L .41854 .59618 L F
.542 .34 .556 r
.42078 .59564 m .41823 .59876 L .41854 .59618 L F
.918 .947 .601 r
.18877 .75876 m .19006 .75625 L .18901 .75773 L F
0 0 .027 r
.19087 .75436 m .19006 .75625 L .19066 .75566 L F
.706 .195 .014 r
.49338 .56485 m .49604 .56701 L .49703 .56605 L F
.577 .022 0 r
.49604 .56701 m .49885 .56895 L .49703 .56605 L F
.6 .255 .356 r
.55906 .50583 m .55795 .50832 L .5553 .50811 L F
.539 .192 .327 r
.56124 .50727 m .55906 .50583 L .56144 .50601 L F
.56124 .50727 m .55795 .50832 L .55906 .50583 L F
.793 .648 .701 r
.41918 .63514 m .41756 .63807 L .4211 .63842 L F
.849 .57 .514 r
.41756 .63807 m .42051 .64027 L .4211 .63842 L F
.141 .332 .795 r
.4211 .63842 m .42223 .6371 L .41918 .63514 L F
.149 .345 .803 r
.4211 .63842 m .42385 .64045 L .42223 .6371 L F
.718 .379 0 r
.42197 .60173 m .42336 .60523 L .42483 .60208 L F
.501 .309 .553 r
.42336 .60523 m .42574 .60537 L .42483 .60208 L F
.539 .332 .548 r
.42483 .60208 m .42794 .60476 L .42782 .60332 L F
.42483 .60208 m .42574 .60537 L .42794 .60476 L F
.537 .3 .503 r
.46189 .62608 m .45933 .6288 L .45969 .62663 L F
.18 0 0 r
.25002 .55714 m .24822 .55693 L .24616 .55655 L F
.411 .775 .995 r
.25222 .55756 m .24822 .55693 L .25002 .55714 L F
.195 0 0 r
.5502 .6103 m .54986 .61117 L .54673 .6124 L F
.326 .061 .349 r
.55187 .60857 m .55433 .60909 L .5502 .6103 L F
.11 0 0 r
.5502 .6103 m .55433 .60909 L .54986 .61117 L F
.589 .872 .994 r
.43264 .62009 m .43338 .62095 L .43589 .62018 L F
.315 0 0 r
.49261 .53688 m .49506 .53716 L .49663 .53661 L F
.278 .761 .923 r
.49506 .53716 m .49925 .53726 L .49663 .53661 L F
.628 .441 .609 r
.56858 .48424 m .57294 .48174 L .56886 .48204 L F
.848 .886 .866 r
.75824 .42533 m .75625 .42752 L .75498 .42644 L F
0 0 .532 r
.75625 .42752 m .75708 .42819 L .75498 .42644 L F
.75625 .42752 m .75803 .42976 L .75708 .42819 L F
0 0 .216 r
.58472 .5562 m .58365 .5604 L .58475 .55641 L F
.58472 .5562 m .58458 .55869 L .58365 .5604 L F
0 0 0 r
.58458 .55869 m .58309 .56268 L .58365 .5604 L F
.062 .597 .859 r
.2882 .54701 m .29016 .54721 L .29181 .54781 L F
.52 .326 .557 r
.29181 .54781 m .29228 .55131 L .28937 .55123 L F
.816 .845 .871 r
.29524 .55128 m .29192 .55168 L .29205 .55155 L F
.29428 .55062 m .29205 .55155 L .29349 .55009 L F
.29524 .55128 m .29205 .55155 L .29428 .55062 L F
.473 .056 .166 r
.29205 .55155 m .29166 .55171 L .28937 .55123 L F
.29232 .55158 m .29166 .55171 L .29205 .55155 L F
.482 .299 .556 r
.29341 .55004 m .29232 .55158 L .29228 .55131 L F
.29341 .55004 m .29228 .55131 L .29181 .54781 L F
.816 .845 .871 r
.29349 .55009 m .29291 .55061 L .29341 .55004 L F
.29291 .55061 m .29166 .55171 L .29341 .55004 L F
.29192 .55168 m .29166 .55171 L .29349 .55009 L F
.52 .326 .557 r
.29228 .55131 m .29232 .55158 L .29205 .55155 L F
.29228 .55131 m .29205 .55155 L .28937 .55123 L F
.438 .83 .983 r
.29181 .54781 m .29016 .54721 L .29407 .54732 L F
.706 .815 .933 r
.29987 .58389 m .29584 .58382 L .2986 .58235 L F
.29987 .58389 m .29584 .58382 L .2986 .58235 L F
0 .408 .758 r
.30197 .58374 m .2986 .58235 L .29987 .58389 L F
.30197 .58374 m .2986 .58235 L .29987 .58389 L F
.671 .356 0 r
.51317 .58687 m .51374 .58849 L .51444 .59042 L F
.786 .407 0 r
.51428 .59114 m .51444 .59042 L .51374 .58849 L F
.51428 .59114 m .51535 .59269 L .51444 .59042 L F
.727 .99 .832 r
.53982 .51845 m .5366 .52036 L .53676 .52097 L F
.53982 .51845 m .53753 .51904 L .5366 .52036 L F
.634 .962 .829 r
.54084 .51706 m .53982 .51845 L .54176 .51714 L F
.54084 .51706 m .53753 .51904 L .53982 .51845 L F
0 0 0 r
.14791 .56359 m .14625 .56601 L .14693 .56533 L F
.14693 .56533 m .14987 .56286 L .14791 .56359 L F
.969 .933 .654 r
.76889 .40477 m .76674 .40932 L .76824 .40501 L F
.996 .794 .514 r
.57483 .54164 m .57404 .5381 L .57564 .53921 L F
.559 .616 .865 r
.74676 .41787 m .74803 .41431 L .74546 .41482 L F
.74676 .41787 m .74886 .41751 L .74803 .41431 L F
.635 .636 .834 r
.74676 .41787 m .75056 .41919 L .74886 .41751 L F
.634 .24 .28 r
.51738 .5181 m .51992 .52064 L .52075 .5179 L F
0 0 0 r
.51992 .52064 m .52326 .51758 L .52075 .5179 L F
.341 .449 .826 r
.65511 .44418 m .6555 .44626 L .65702 .44433 L F
.522 .713 .959 r
.6555 .44626 m .65836 .44609 L .65702 .44433 L F
.907 .738 .661 r
.59119 .51416 m .59244 .51774 L .59304 .51532 L F
.781 .284 0 r
.22603 .67472 m .22418 .67613 L .22415 .67432 L F
.22603 .67472 m .2265 .67651 L .22418 .67613 L F
.22603 .67472 m .22785 .67751 L .2265 .67651 L F
.694 .318 .331 r
.22869 .67531 m .22785 .67751 L .22603 .67472 L F
.667 .863 .974 r
.65836 .44609 m .66193 .44607 L .66082 .445 L F
.585 .302 .452 r
.45174 .62325 m .4498 .62495 L .44968 .62387 L F
.779 .503 .519 r
.53087 .5236 m .53448 .52406 L .53388 .52594 L F
.582 .819 .436 r
.53676 .52097 m .53562 .52247 L .53448 .52406 L F
.779 .503 .519 r
.53087 .5236 m .53359 .52572 L .53021 .52726 L F
.53359 .52572 m .53388 .52594 L .53337 .52613 L F
.53359 .52572 m .53337 .52613 L .53021 .52726 L F
0 0 0 r
.53438 .52427 m .53562 .52247 L .53362 .52595 L F
.53448 .52406 m .53456 .52394 L .53438 .52427 L F
.53456 .52394 m .53562 .52247 L .53438 .52427 L F
.53448 .52406 m .53362 .52595 L .53388 .52594 L F
.264 .655 .966 r
.21308 .70083 m .21256 .70182 L .21374 .70128 L F
.568 .938 .884 r
.21109 .70197 m .21256 .70182 L .21308 .70083 L F
.959 .9 .722 r
.5719 .54941 m .5729 .55168 L .57156 .55384 L F
.55 .326 .528 r
.29524 .55128 m .29538 .55359 L .29427 .55307 L F
.527 .308 .526 r
.29784 .5531 m .29524 .55128 L .29779 .55054 L F
.29784 .5531 m .29538 .55359 L .29524 .55128 L F
.637 .395 .535 r
.80412 .43684 m .80382 .43918 L .80127 .4393 L F
.607 .459 .655 r
.80644 .43337 m .80739 .43647 L .80412 .43684 L F
.684 .516 .654 r
.80739 .43647 m .80382 .43918 L .80412 .43684 L F
.702 .787 .917 r
.77703 .40698 m .78225 .40808 L .78093 .40615 L F
.615 .74 .935 r
.78225 .40808 m .78487 .40747 L .78387 .4054 L F
0 .329 .808 r
.77472 .4419 m .77547 .44153 L .77359 .44052 L F
0 .169 .707 r
.77472 .4419 m .77718 .44446 L .77547 .44153 L F
.176 0 .232 r
.44831 .61185 m .44975 .61137 L .44696 .61176 L F
.54 .609 .871 r
.74299 .41525 m .7441 .41154 L .74159 .41232 L F
.74299 .41525 m .74546 .41482 L .7441 .41154 L F
.906 .952 .817 r
.42147 .62036 m .42132 .62349 L .42366 .62148 L F
.03 .507 .88 r
.42366 .62148 m .42431 .62083 L .42147 .62036 L F
.42366 .62148 m .42592 .62192 L .42431 .62083 L F
.399 .027 .211 r
.4606 .60263 m .46284 .60349 L .4629 .60219 L F
.4606 .60263 m .46091 .60437 L .46284 .60349 L F
.613 .618 .832 r
.16683 .63612 m .16894 .63588 L .16605 .63472 L F
.456 .552 .864 r
.16683 .63612 m .17058 .63909 L .16894 .63588 L F
.452 .792 .999 r
.43621 .61738 m .43232 .61693 L .43091 .61534 L F
.43621 .61738 m .43301 .61567 L .43232 .61693 L F
.644 .862 .982 r
.4352 .61466 m .43621 .61738 L .43691 .61363 L F
.4352 .61466 m .43301 .61567 L .43621 .61738 L F
.02 0 0 r
.80896 .4327 m .81175 .43022 L .81155 .43233 L F
.524 .378 .625 r
.81428 .42658 m .81554 .42942 L .81175 .43022 L F
.623 .422 .59 r
.81554 .42942 m .81155 .43233 L .81175 .43022 L F
.853 .404 .004 r
.49279 .5446 m .49026 .54136 L .49231 .54218 L F
.377 .183 .486 r
.44657 .6265 m .44532 .62995 L .44393 .62935 L F
.722 .534 .635 r
.44532 .62995 m .44296 .63173 L .44393 .62935 L F
.639 .544 .73 r
.81334 .40883 m .81421 .41218 L .81074 .41213 L F
.54 .342 .56 r
.81421 .41218 m .81174 .41528 L .81074 .41213 L F
.924 .757 .656 r
.52098 .52358 m .5229 .52454 L .52284 .52203 L F
.147 .691 .756 r
.50496 .52229 m .50719 .52197 L .509 .52185 L F
0 .378 .82 r
.50982 .52144 m .509 .52185 L .50719 .52197 L F
.286 0 0 r
.50585 .52378 m .50951 .52163 L .50719 .52197 L F
.50951 .52163 m .50982 .52144 L .50719 .52197 L F
.147 .691 .756 r
.5047 .52232 m .50719 .52197 L .50496 .52229 L F
.369 .01 .217 r
.509 .52185 m .51082 .52251 L .51128 .52096 L F
0 .378 .82 r
.50982 .52144 m .51082 .52251 L .509 .52185 L F
.635 .328 .433 r
.46743 .62411 m .4678 .62623 L .46189 .62608 L F
0 0 .376 r
.46793 .62582 m .46743 .62411 L .46806 .62312 L F
.46793 .62582 m .4678 .62623 L .46743 .62411 L F
.394 .571 .908 r
.18963 .62216 m .1893 .62459 L .18757 .6233 L F
.18963 .62216 m .19161 .6248 L .1893 .62459 L F
.234 0 .102 r
.23742 .6471 m .23621 .64735 L .23574 .64879 L F
.989 .883 .55 r
.76909 .42581 m .76957 .42796 L .77038 .42485 L F
.85 .983 .86 r
.77038 .42485 m .77301 .42217 L .7717 .42111 L F
.848 .963 .631 r
.76909 .42581 m .77038 .42485 L .7717 .42111 L F
0 0 .435 r
.58255 .57022 m .58149 .5695 L .58244 .56783 L F
.58255 .57022 m .58206 .57178 L .58149 .5695 L F
.589 .475 .691 r
.44339 .64101 m .44141 .64229 L .44137 .64119 L F
.679 .879 .502 r
.55537 .60782 m .55433 .60909 L .55187 .60857 L F
0 0 0 r
.5004 .52473 m .50076 .52452 L .49944 .52709 L F
.5004 .52473 m .50227 .52275 L .50076 .52452 L F
.811 .676 .715 r
.23694 .60847 m .23564 .61086 L .23901 .61135 L F
.798 .606 .642 r
.23601 .61339 m .23901 .61135 L .23564 .61086 L F
.23601 .61339 m .2391 .61397 L .23901 .61135 L F
.704 .486 .591 r
.57468 .48135 m .57871 .47893 L .57465 .47886 L F
.593 .756 .956 r
.17259 .64045 m .17738 .64143 L .1738 .63865 L F
.515 .756 .983 r
.17738 .64143 m .17763 .63953 L .1738 .63865 L F
.17738 .64143 m .1793 .64086 L .17763 .63953 L F
.464 .494 .805 r
.17738 .64143 m .18043 .64418 L .1793 .64086 L F
.14 0 0 r
.17074 .56879 m .16896 .57034 L .16781 .56998 L F
.202 0 0 r
.17262 .56826 m .16896 .57034 L .17074 .56879 L F
.558 .429 .661 r
.44314 .61372 m .4457 .61576 L .44831 .61185 L F
.176 0 .232 r
.44831 .61185 m .44913 .61243 L .44975 .61137 L F
.595 .352 .519 r
.4457 .61576 m .44913 .61243 L .44831 .61185 L F
0 .502 .799 r
.17101 .67477 m .17448 .67573 L .17222 .67419 L F
.474 .264 .513 r
.17336 .67364 m .17148 .67161 L .17104 .67459 L F
.17222 .67419 m .17104 .67459 L .17101 .67477 L F
.17336 .67364 m .17104 .67459 L .17222 .67419 L F
.925 .784 .686 r
.17222 .67419 m .17348 .67377 L .1717 .67383 L F
.17448 .67573 m .17348 .67377 L .17222 .67419 L F
0 .502 .799 r
.17101 .67477 m .17222 .67419 L .1717 .67383 L F
.474 .264 .513 r
.17348 .67377 m .17336 .67364 L .17101 .67477 L F
.945 .944 .75 r
.5415 .58938 m .54007 .59196 L .54184 .5906 L F
.924 .577 .358 r
.54169 .59469 m .54184 .5906 L .54007 .59196 L F
.54169 .59469 m .54288 .59448 L .54184 .5906 L F
.305 0 .273 r
.18463 .55998 m .18341 .56227 L .18195 .56277 L F
.082 0 0 r
.18681 .55957 m .18341 .56227 L .18463 .55998 L F
.422 .681 .97 r
.16283 .63168 m .16237 .62941 L .15999 .62884 L F
.16283 .63168 m .16486 .63149 L .16237 .62941 L F
.124 .483 .899 r
.16283 .63168 m .16509 .63282 L .16486 .63149 L F
.729 .663 .785 r
.66678 .44227 m .66801 .4458 L .66956 .44437 L F
.704 .486 .591 r
.57468 .48135 m .57857 .4817 L .57871 .47893 L F
.755 .53 .592 r
.57871 .47893 m .57857 .4817 L .58143 .4814 L F
0 .007 .573 r
.77714 .4461 m .77813 .44808 L .77718 .44446 L F
.186 .715 .727 r
.45983 .57042 m .45847 .57065 L .45606 .5712 L F
0 0 0 r
.46257 .57014 m .45847 .57065 L .45983 .57042 L F
.462 .015 .102 r
.24835 .64089 m .24462 .64305 L .24661 .64188 L F
.406 .722 .989 r
.72917 .3995 m .72756 .40014 L .7278 .40032 L F
.516 .34 .582 r
.24601 .61144 m .24829 .61095 L .24838 .60823 L F
.475 .24 .477 r
.24567 .61385 m .24829 .61095 L .24601 .61144 L F
.707 .326 .326 r
.44339 .64101 m .43968 .64103 L .44141 .64229 L F
0 0 0 r
.21183 .55481 m .21164 .55401 L .21391 .55365 L F
.21183 .55481 m .20979 .55574 L .21164 .55401 L F
.124 .236 .709 r
.7755 .4361 m .77771 .43811 L .77643 .43978 L F
.245 .414 .832 r
.77771 .43811 m .77931 .44145 L .77643 .43978 L F
.296 0 0 r
.50885 .53178 m .5135 .53193 L .51275 .52935 L F
.717 .434 0 r
.51275 .52935 m .5135 .53193 L .51208 .52683 L F
.441 .324 .624 r
.45215 .60467 m .454 .60516 L .45298 .60076 L F
.257 0 0 r
.45215 .60467 m .454 .60516 L .4504 .60449 L F
.805 .334 .105 r
.23867 .64992 m .23761 .65033 L .23574 .64879 L F
.272 0 .105 r
.23964 .64661 m .23742 .6471 L .23725 .64736 L F
.23908 .64698 m .23725 .64736 L .23626 .64888 L F
0 0 0 r
.23869 .64711 m .23964 .64661 L .2393 .64703 L F
.272 0 .105 r
.23964 .64661 m .23725 .64736 L .23885 .64703 L F
0 0 0 r
.23696 .64735 m .23964 .64661 L .23869 .64711 L F
.272 0 .105 r
.23964 .64661 m .23885 .64703 L .23908 .64698 L F
.23947 .64701 m .23626 .64888 L .23925 .64755 L F
.23964 .64661 m .23908 .64698 L .23947 .64701 L F
.495 .544 .836 r
.23867 .64992 m .24032 .64845 L .23964 .64661 L F
.781 .705 .779 r
.23964 .64661 m .24032 .64845 L .24224 .6463 L F
.316 .044 .332 r
.23964 .64661 m .24295 .64608 L .2393 .64703 L F
.458 .763 .995 r
.23932 .647 m .2393 .64703 L .2394 .64701 L F
.272 0 .105 r
.23908 .64698 m .23626 .64888 L .23947 .64701 L F
.458 .763 .995 r
.23938 .64692 m .23932 .647 L .23947 .64699 L F
.23932 .647 m .2394 .64701 L .23947 .64699 L F
0 0 0 r
.23812 .64703 m .23742 .6471 L .23964 .64661 L F
.23696 .64735 m .23717 .64724 L .23812 .64703 L F
.23717 .64724 m .23742 .6471 L .23812 .64703 L F
.458 .763 .995 r
.23919 .6468 m .2392 .64696 L .23938 .64692 L F
.23556 .64436 m .23902 .64683 L .23919 .6468 L F
.23902 .64683 m .2392 .64696 L .23919 .6468 L F
.2392 .64696 m .2393 .64703 L .23938 .64692 L F
.701 .368 .41 r
.23964 .64661 m .24224 .6463 L .24383 .64449 L F
.316 .044 .332 r
.23964 .64661 m .24227 .64373 L .24295 .64608 L F
.458 .763 .995 r
.2397 .64532 m .23947 .64699 L .24295 .64608 L F
.23556 .64436 m .23947 .64699 L .2397 .64532 L F
.495 .544 .836 r
.23867 .64992 m .23943 .64732 L .23925 .64755 L F
.23943 .64732 m .23964 .64661 L .23947 .64701 L F
.23943 .64732 m .23947 .64701 L .23925 .64755 L F
.884 .987 .721 r
.23925 .64755 m .23761 .65033 L .23867 .64992 L F
.775 .87 .918 r
.70447 .42688 m .70628 .42344 L .70376 .42654 L F
.70447 .42688 m .70769 .42501 L .70628 .42344 L F
.677 .699 .862 r
.74022 .40319 m .73684 .4023 L .73925 .40167 L F
.694 .825 .945 r
.74277 .40194 m .74022 .40319 L .73925 .40167 L F
.604 .225 .296 r
.23066 .67699 m .22869 .67531 L .23067 .67421 L F
.23066 .67699 m .22785 .67751 L .22869 .67531 L F
.807 .379 0 r
.48346 .56827 m .48559 .57161 L .48494 .57004 L F
.806 .993 .871 r
.48559 .57161 m .48753 .56842 L .48494 .57004 L F
.565 .415 .636 r
.29584 .58382 m .29378 .58685 L .29356 .58428 L F
0 0 .316 r
.76655 .38079 m .76719 .38242 L .76573 .37893 L F
0 0 .535 r
.76823 .38331 m .76719 .38242 L .76655 .38079 L F
.76823 .38331 m .76922 .38475 L .76719 .38242 L F
.415 .034 .204 r
.25219 .63829 m .25071 .64055 L .24835 .64089 L F
.248 0 .102 r
.25279 .63989 m .25219 .63829 L .25415 .63792 L F
.25279 .63989 m .25071 .64055 L .25219 .63829 L F
.91 .591 .428 r
.5085 .61316 m .51031 .61388 L .50985 .6114 L F
.899 .907 .501 r
.53676 .52097 m .5366 .52036 L .53562 .52247 L F
.456 .271 .54 r
.28954 .59611 m .28942 .59899 L .28724 .59946 L F
.58 .468 .691 r
.28942 .59899 m .28746 .60204 L .28724 .59946 L F
.44 .87 .921 r
.41103 .61277 m .41123 .61231 L .41584 .60832 L F
.41123 .61231 m .41165 .61137 L .41456 .60925 L F
.41123 .61231 m .41456 .60925 L .41584 .60832 L F
.41165 .61137 m .41265 .61061 L .41584 .60832 L F
.664 .352 .434 r
.41169 .6113 m .41502 .60861 L .41584 .60832 L F
.881 .871 .429 r
.42002 .60857 m .41965 .61035 L .42215 .60983 L F
.41965 .61035 m .41924 .61228 L .4217 .61021 L F
.41965 .61035 m .4217 .61021 L .42215 .60983 L F
.691 .378 .44 r
.41527 .6086 m .41924 .61129 L .41899 .60853 L F
.881 .871 .429 r
.41965 .61035 m .41924 .6113 L .41924 .61228 L F
.41924 .6113 m .41916 .61149 L .41917 .61159 L F
.41924 .6113 m .41917 .61159 L .41924 .61228 L F
.691 .378 .44 r
.41517 .6087 m .41924 .6113 L .41527 .6086 L F
.41924 .6113 m .41964 .61156 L .41924 .61129 L F
.41924 .6113 m .41924 .61129 L .41527 .6086 L F
.41924 .61129 m .41964 .61156 L .41943 .61056 L F
.41924 .61129 m .41943 .61056 L .41899 .60853 L F
.881 .871 .429 r
.41938 .61074 m .41911 .61099 L .41916 .61149 L F
.42002 .60857 m .41974 .60933 L .41938 .61074 L F
.981 .706 .322 r
.41899 .60853 m .41943 .61056 L .41911 .61099 L F
.881 .871 .429 r
.41943 .61056 m .41911 .61099 L .41938 .61074 L F
.981 .706 .322 r
.41943 .61056 m .41964 .61156 L .41911 .61099 L F
.881 .871 .429 r
.41974 .60933 m .41911 .61099 L .41943 .61056 L F
.42002 .60857 m .41916 .61149 L .41965 .61035 L F
.691 .378 .44 r
.41793 .61046 m .41433 .612 L .41911 .6116 L F
.8 .938 .92 r
.42215 .60983 m .42098 .61383 L .42322 .61166 L F
.42215 .60983 m .41924 .61228 L .42098 .61383 L F
.556 .533 .785 r
.4218 .61499 m .42322 .61166 L .42098 .61383 L F
.023 .384 .846 r
.41916 .61149 m .42199 .61399 L .41924 .61228 L F
.691 .378 .44 r
.41924 .6113 m .41916 .61149 L .41964 .61156 L F
.41916 .61149 m .4193 .61159 L .41964 .61156 L F
.023 .384 .846 r
.42035 .61229 m .42199 .61399 L .41947 .61177 L F
.41943 .61167 m .41947 .61177 L .41916 .61149 L F
.42035 .61229 m .41947 .61177 L .41943 .61167 L F
.594 .514 .734 r
.4193 .61159 m .41941 .61164 L .41964 .61156 L F
.7 .493 .604 r
.41941 .61164 m .41911 .61099 L .41964 .61156 L F
.594 .514 .734 r
.41433 .612 m .41709 .61248 L .41815 .6121 L F
.41742 .61178 m .41815 .6121 L .41941 .61164 L F
.41433 .612 m .41815 .6121 L .41742 .61178 L F
.41433 .612 m .41941 .61164 L .4193 .61159 L F
.023 .384 .846 r
.41911 .61099 m .42002 .61194 L .41916 .61149 L F
.42002 .61194 m .42035 .61229 L .4193 .61159 L F
.42002 .61194 m .4193 .61159 L .41916 .61149 L F
.691 .378 .44 r
.41916 .61149 m .41911 .6116 L .4193 .61159 L F
.479 .603 .897 r
.42151 .61058 m .42199 .61399 L .41911 .61099 L F
.572 .427 .647 r
.419 .61248 m .42151 .61058 L .41911 .61099 L F
0 0 .009 r
.41924 .61228 m .4182 .61322 L .42098 .61383 L F
.761 .422 .411 r
.4182 .61322 m .4218 .61499 L .42098 .61383 L F
.659 .529 .694 r
.416 .61687 m .41963 .61747 L .4182 .61322 L F
.784 .696 .767 r
.41468 .61337 m .416 .61687 L .4182 .61322 L F
.651 .224 .22 r
.4182 .61322 m .41799 .61471 L .41468 .61337 L F
.696 .549 .683 r
.4182 .61322 m .42195 .61655 L .4218 .61499 L F
.4182 .61322 m .41963 .61747 L .42195 .61655 L F
.628 .417 .577 r
.41799 .61471 m .41712 .61618 L .41468 .61337 L F
0 0 .009 r
.41924 .61228 m .41799 .61471 L .4182 .61322 L F
.638 .536 .722 r
.41924 .61228 m .41712 .61618 L .41799 .61471 L F
.41924 .61228 m .42015 .61608 L .41712 .61618 L F
.572 .427 .647 r
.41893 .61353 m .41962 .61275 L .419 .61248 L F
.483 .434 .727 r
.42199 .61399 m .42015 .61608 L .41924 .61228 L F
.572 .427 .647 r
.41962 .61275 m .42151 .61058 L .419 .61248 L F
.691 .378 .44 r
.41793 .61046 m .41911 .6116 L .41924 .6113 L F
.7 .493 .604 r
.41709 .61248 m .41911 .61099 L .41941 .61164 L F
.691 .378 .44 r
.41502 .60861 m .4146 .61069 L .41793 .61046 L F
.4146 .61069 m .41433 .612 L .41793 .61046 L F
.41502 .60861 m .41517 .6087 L .41527 .6086 L F
.467 .103 .263 r
.41556 .60838 m .41899 .60853 L .41855 .60712 L F
.41502 .60861 m .41527 .6086 L .41556 .60838 L F
.41527 .6086 m .41899 .60853 L .41556 .60838 L F
.44 .87 .921 r
.41165 .61137 m .41169 .6113 L .41265 .61061 L F
.401 0 0 r
.46284 .60349 m .46691 .60251 L .4629 .60219 L F
.172 0 .096 r
.46506 .60372 m .46622 .60504 L .46623 .605 L F
.46506 .60372 m .46623 .605 L .46657 .60253 L F
.401 0 0 r
.46449 .60309 m .46506 .60372 L .46691 .60251 L F
.46284 .60349 m .46506 .60372 L .46449 .60309 L F
.559 .541 .791 r
.46582 .59918 m .46691 .60251 L .46917 .60189 L F
.463 .843 .617 r
.46691 .60251 m .46813 .60149 L .46917 .60189 L F
.46691 .60251 m .46506 .60372 L .46813 .60149 L F
.486 .249 .48 r
.46917 .60189 m .46654 .60484 L .46691 .60251 L F
.602 .591 .812 r
.46419 .58965 m .46051 .5871 L .4625 .58656 L F
.263 .009 .328 r
.82755 .44291 m .8272 .44473 L .82508 .44607 L F
.317 .053 .347 r
.82982 .44189 m .8272 .44473 L .82755 .44291 L F
.51 .459 .735 r
.47939 .5714 m .48118 .57077 L .48074 .56881 L F
.817 .657 .685 r
.59203 .48763 m .59001 .49044 L .59364 .49099 L F
.798 .602 .637 r
.5897 .49305 m .59364 .49099 L .59001 .49044 L F
.5897 .49305 m .59337 .49359 L .59364 .49099 L F
.616 .49 .685 r
.80961 .41845 m .807 .42153 L .80667 .41911 L F
.577 .333 .51 r
.43589 .62018 m .43839 .61988 L .43848 .61746 L F
.647 .56 .742 r
.66604 .40576 m .66254 .40656 L .66355 .40458 L F
.374 0 .176 r
.19384 .72252 m .19617 .72219 L .19773 .7197 L F
.79 .564 .594 r
.19617 .72219 m .20014 .71961 L .19773 .7197 L F
.617 .729 .926 r
.16793 .61887 m .16164 .61694 L .16394 .61624 L F
.929 .636 .163 r
.16644 .61544 m .16793 .61887 L .16394 .61624 L F
.16644 .61544 m .16755 .61937 L .16793 .61887 L F
0 0 0 r
.29642 .57482 m .29457 .57536 L .29474 .57484 L F
.29642 .57482 m .29664 .57486 L .29457 .57536 L F
.476 .352 .632 r
.29664 .57486 m .29695 .57722 L .29457 .57536 L F
.69 .387 .457 r
.41739 .62027 m .41737 .62252 L .41539 .62152 L F
.569 .51 .75 r
.41739 .62027 m .41963 .61747 L .416 .61687 L F
.41739 .62027 m .41995 .62006 L .41963 .61747 L F
0 .17 .697 r
.416 .61687 m .41837 .61939 L .41739 .62027 L F
.617 .385 .544 r
.41995 .62006 m .41739 .62027 L .41837 .61939 L F
.41995 .62006 m .41737 .62252 L .41739 .62027 L F
0 0 .215 r
.41837 .61939 m .41737 .62252 L .41739 .62027 L F
.98 .909 .594 r
.76824 .40501 m .76743 .40449 L .76876 .40366 L F
.942 .962 .693 r
.76876 .40366 m .76831 .40265 L .77003 .3993 L F
.957 .939 .622 r
.76876 .40366 m .76743 .40449 L .76831 .40265 L F
.57 .406 .619 r
.49413 .59432 m .49655 .5952 L .49603 .59313 L F
.49413 .59432 m .49359 .5962 L .49655 .5952 L F
.359 .814 .936 r
.21363 .53933 m .21596 .53888 L .21768 .53921 L F
.449 .85 .973 r
.21596 .53888 m .21986 .5388 L .21768 .53921 L F
.921 .901 .788 r
.75353 .39271 m .75277 .3945 L .75212 .39251 L F
.826 .914 .897 r
.75277 .3945 m .7507 .39423 L .75212 .39251 L F
.627 .07 0 r
.51221 .55441 m .51183 .55532 L .50919 .55342 L F
.857 .421 0 r
.51221 .55441 m .51318 .55633 L .51183 .55532 L F
.588 .582 .814 r
.45298 .60076 m .45563 .59835 L .45349 .59883 L F
.45298 .60076 m .45774 .60205 L .45563 .59835 L F
.526 .378 .623 r
.45298 .60076 m .45649 .60443 L .45774 .60205 L F
.45298 .60076 m .454 .60516 L .45649 .60443 L F
.497 .218 .421 r
.55511 .49668 m .55876 .4927 L .55603 .49343 L F
.264 .729 .948 r
.24825 .53894 m .25049 .53886 L .25218 .5395 L F
.325 .756 .971 r
.25268 .53862 m .25218 .5395 L .25049 .53886 L F
.25268 .53862 m .25442 .53936 L .25218 .5395 L F
.468 .892 .877 r
.56452 .60523 m .55992 .60648 L .56186 .60618 L F
.204 .722 .691 r
.78519 .45077 m .78438 .45099 L .78174 .45175 L F
.522 .906 .753 r
.78671 .44945 m .78519 .45077 L .78806 .44914 L F
.78671 .44945 m .78438 .45099 L .78519 .45077 L F
.291 0 0 r
.73505 .37956 m .73769 .37915 L .73779 .38021 L F
.043 .407 .859 r
.73352 .37749 m .73505 .37956 L .73779 .38021 L F
.596 .435 .634 r
.4963 .59097 m .49603 .59313 L .49847 .59019 L F
.509 .663 .931 r
.20874 .63184 m .2066 .63213 L .20439 .6296 L F
.399 .115 .362 r
.40168 .60569 m .40343 .6071 L .40424 .60492 L F
.40168 .60569 m .40117 .60772 L .40343 .6071 L F
.462 .063 .198 r
.66023 .41208 m .65656 .41435 L .65761 .41237 L F
.817 .627 .645 r
.82447 .4305 m .82618 .43379 L .82433 .43351 L F
.802 .489 .459 r
.82433 .43351 m .82618 .43379 L .8246 .43465 L F
.884 .662 .597 r
.82618 .43379 m .82606 .43672 L .8246 .43465 L F
.285 0 .192 r
.26144 .63407 m .26029 .63301 L .26237 .63235 L F
.26144 .63407 m .25936 .63478 L .26029 .63301 L F
.407 .709 .985 r
.1583 .59479 m .15796 .5963 L .15632 .59495 L F
.292 .763 .938 r
.15219 .59471 m .15632 .59495 L .15432 .59519 L F
.15386 .5948 m .15445 .59448 L .15632 .59495 L F
.15219 .59471 m .15445 .59448 L .15386 .5948 L F
.238 .73 .918 r
.15632 .59495 m .15445 .59448 L .1583 .59479 L F
0 0 .558 r
.15445 .59448 m .15612 .59788 L .1583 .59479 L F
.694 .272 .239 r
.1583 .59479 m .15608 .59666 L .15445 .59448 L F
0 .1 .62 r
.15445 .59448 m .15608 .59666 L .15572 .59459 L F
.686 .801 .936 r
.1583 .59479 m .15445 .59448 L .15644 .59301 L F
0 .1 .62 r
.15445 .59448 m .15572 .59459 L .1556 .59387 L F
.536 .906 .726 r
.15445 .59448 m .15552 .5934 L .15644 .59301 L F
0 .1 .62 r
.15445 .59448 m .1556 .59387 L .15552 .5934 L F
0 .157 .695 r
.15608 .59666 m .1565 .59731 L .15612 .59788 L F
.557 .87 .58 r
.15796 .5963 m .15612 .59788 L .15575 .59841 L F
.806 .968 .659 r
.1583 .59479 m .15612 .59788 L .15796 .5963 L F
0 .157 .695 r
.1565 .59731 m .15797 .59953 L .15612 .59788 L F
.557 .87 .58 r
.15575 .59841 m .15612 .59788 L .15509 .59905 L F
0 .347 .79 r
.43901 .63406 m .4398 .63429 L .44043 .63526 L F
.8 .353 0 r
.44074 .63682 m .44043 .63526 L .4398 .63429 L F
.44074 .63682 m .44207 .63812 L .44043 .63526 L F
0 0 0 r
.46116 .60984 m .45958 .61146 L .4621 .60877 L F
.019 0 .168 r
.46116 .60984 m .45873 .61373 L .45958 .61146 L F
.843 .777 .788 r
.20631 .71759 m .20198 .71913 L .20481 .71737 L F
.592 .026 0 r
.20692 .71872 m .20631 .71759 L .20481 .71737 L F
.20692 .71872 m .20888 .71961 L .20631 .71759 L F
.475 .531 .836 r
.46483 .58599 m .46419 .58965 L .4625 .58656 L F
.46483 .58599 m .46671 .59003 L .46419 .58965 L F
.624 .944 .95 r
.82508 .44607 m .82335 .44572 L .82097 .44694 L F
.595 .934 .952 r
.82687 .44429 m .82508 .44607 L .8272 .44473 L F
.82687 .44429 m .82335 .44572 L .82508 .44607 L F
.521 .432 .696 r
.16889 .67526 m .17101 .67477 L .16878 .67461 L F
.671 .579 .743 r
.29568 .56865 m .29642 .57482 L .29474 .57484 L F
.257 0 0 r
.42358 .64853 m .42417 .64853 L .42517 .64823 L F
.853 .43 .22 r
.4265 .64783 m .42657 .64921 L .42517 .64823 L F
.42648 .64751 m .4265 .64783 L .42517 .64823 L F
.183 .146 .58 r
.4252 .64518 m .42657 .64921 L .42563 .64484 L F
.495 .094 .21 r
.4252 .64518 m .42517 .64823 L .42657 .64921 L F
0 0 .409 r
.42563 .64484 m .42632 .64807 L .42673 .64669 L F
.42632 .64807 m .42657 .64921 L .42663 .64828 L F
.42632 .64807 m .42663 .64828 L .42673 .64669 L F
.42572 .645 m .42657 .64921 L .42563 .64484 L F
.42673 .64669 m .42563 .64484 L .42757 .64384 L F
.374 .058 .295 r
.42936 .64515 m .42673 .64669 L .42757 .64384 L F
.76 .522 .573 r
.42936 .64515 m .42685 .64541 L .42673 .64669 L F
0 0 .409 r
.42673 .64669 m .42659 .64829 L .42572 .645 L F
.42662 .64841 m .42657 .64921 L .42572 .645 L F
.42563 .64484 m .42673 .64669 L .42561 .64554 L F
.76 .522 .573 r
.42685 .64541 m .42561 .64554 L .42673 .64669 L F
0 0 .409 r
.42673 .64669 m .42662 .64841 L .42659 .64829 L F
.369 .539 .892 r
.42635 .64837 m .42617 .65014 L .42517 .64823 L F
.42736 .6485 m .42699 .64901 L .42635 .64837 L F
.42699 .64901 m .42617 .65014 L .42635 .64837 L F
.468 .428 .731 r
.42885 .6519 m .42617 .65014 L .42722 .64976 L F
.42885 .6519 m .42702 .65283 L .42617 .65014 L F
.258 .455 .863 r
.42928 .64857 m .43096 .65172 L .42851 .65043 L F
.4276 .64954 m .42851 .65043 L .42722 .64976 L F
.686 .456 .568 r
.42702 .65283 m .42385 .65536 L .4237 .65367 L F
.457 .431 .741 r
.42722 .64976 m .43096 .65172 L .42885 .6519 L F
.37 0 .139 r
.4236 .65352 m .42613 .65324 L .42782 .64958 L F
.42776 .64957 m .42782 .64958 L .42787 .64946 L F
.4236 .65352 m .42782 .64958 L .42776 .64957 L F
.258 .455 .863 r
.42769 .64949 m .42776 .64957 L .4276 .64954 L F
.42776 .64957 m .42851 .65043 L .4276 .64954 L F
.37 0 .139 r
.42776 .64957 m .42787 .64946 L .42771 .64951 L F
.258 .455 .863 r
.42928 .64857 m .42851 .65043 L .42769 .64949 L F
.37 0 .139 r
.42766 .64966 m .42776 .64957 L .42755 .64956 L F
.42776 .64957 m .42771 .64951 L .42755 .64956 L F
.4236 .65352 m .42766 .64966 L .42335 .65088 L F
.517 .746 .979 r
.42736 .6485 m .42722 .64976 L .42617 .65014 L F
.37 0 .139 r
.42766 .64966 m .42755 .64956 L .42335 .65088 L F
.796 .488 .468 r
.42358 .64853 m .42335 .65088 L .42697 .64974 L F
.42684 .64924 m .42697 .64974 L .42787 .64946 L F
.42358 .64853 m .42697 .64974 L .42684 .64924 L F
.257 0 0 r
.42417 .64853 m .42695 .6485 L .42517 .64823 L F
.42695 .6485 m .42736 .6485 L .42685 .64843 L F
.42695 .6485 m .42685 .64843 L .42517 .64823 L F
.536 .344 .568 r
.70907 .40559 m .71162 .40292 L .70888 .4035 L F
.832 .705 .723 r
.2345 .58718 m .23078 .58657 L .23338 .5836 L F
.892 .886 .82 r
.2345 .58718 m .23052 .58928 L .23078 .58657 L F
.849 .992 .739 r
.23338 .5836 m .23078 .58657 L .23085 .58529 L F
.363 .223 .553 r
.23078 .58657 m .23147 .58745 L .23085 .58529 L F
.892 .886 .82 r
.2345 .58718 m .23211 .59006 L .23176 .58862 L F
.363 .223 .553 r
.23147 .58745 m .23226 .58847 L .23104 .58572 L F
.23147 .58745 m .23104 .58572 L .23085 .58529 L F
.892 .886 .82 r
.23176 .58862 m .23192 .5903 L .23052 .58928 L F
.23211 .59006 m .23192 .5903 L .23176 .58862 L F
.635 .451 .616 r
.23513 .58972 m .23192 .5903 L .2345 .58718 L F
0 0 .53 r
.23468 .58562 m .2345 .58718 L .23338 .5836 L F
.855 .742 .738 r
.23468 .58562 m .23448 .58906 L .2345 .58718 L F
.913 .588 .112 r
.2345 .58718 m .23448 .58906 L .23513 .58972 L F
.295 .064 .384 r
.15596 .57748 m .15354 .58067 L .15399 .57822 L F
.025 0 0 r
.46654 .60484 m .46368 .60709 L .46465 .60589 L F
.357 .27 .619 r
.39704 .61374 m .3984 .6106 L .39677 .61112 L F
.906 .952 .817 r
.42147 .62036 m .42011 .62285 L .42132 .62349 L F
.47 0 0 r
.4219 .62227 m .42011 .62285 L .42158 .62032 L F
.82 .67 .697 r
.41737 .62252 m .41963 .62629 L .42132 .62349 L F
.408 .21 .496 r
.42276 .62265 m .42203 .62391 L .4223 .62469 L F
.47 0 0 r
.4223 .62469 m .42011 .62285 L .42116 .62251 L F
.42203 .62391 m .42116 .62251 L .4215 .6224 L F
.4223 .62469 m .42116 .62251 L .42203 .62391 L F
.408 .21 .496 r
.42203 .62391 m .42163 .6246 L .4223 .62469 L F
.758 .268 0 r
.41963 .62629 m .42148 .62889 L .42247 .62941 L F
.649 .508 .677 r
.41523 .62939 m .4198 .63141 L .41963 .62629 L F
0 0 0 r
.41941 .62629 m .41953 .62754 L .41874 .62667 L F
.771 .609 .043 r
.41963 .62629 m .41964 .62659 L .41953 .62754 L F
.41964 .62659 m .41975 .62997 L .41953 .62754 L F
.41975 .62997 m .4198 .63141 L .41968 .62967 L F
.41962 .62849 m .41968 .62967 L .41953 .62754 L F
.41975 .62997 m .41968 .62967 L .41962 .62849 L F
.843 .929 .886 r
.4198 .63141 m .42148 .62889 L .41953 .62754 L F
.593 .392 .578 r
.41523 .62939 m .41865 .63158 L .4198 .63141 L F
.843 .929 .886 r
.4198 .63141 m .41865 .63158 L .42148 .62889 L F
.765 .713 .804 r
.42148 .62889 m .41972 .63056 L .42245 .63201 L F
.41972 .63056 m .41865 .63158 L .41978 .63171 L F
.41972 .63056 m .41978 .63171 L .42245 .63201 L F
.337 0 0 r
.42032 .62865 m .41939 .62871 L .41953 .62754 L F
.41939 .62871 m .41777 .62882 L .41953 .62754 L F
.771 .609 .043 r
.42133 .62868 m .41953 .62754 L .42148 .62889 L F
.41963 .62629 m .41953 .62754 L .42133 .62868 L F
0 0 0 r
.4223 .62469 m .41953 .62754 L .41941 .62629 L F
.4223 .62469 m .41874 .62667 L .42135 .62507 L F
.4223 .62469 m .42038 .62673 L .41953 .62754 L F
.408 .21 .496 r
.42135 .62507 m .42038 .62673 L .4223 .62469 L F
.42135 .62507 m .42291 .62621 L .42038 .62673 L F
.42163 .6246 m .42135 .62507 L .4223 .62469 L F
.47 0 0 r
.42163 .6246 m .41727 .62506 L .41844 .62415 L F
.4223 .62469 m .42192 .62472 L .42163 .6246 L F
.42192 .62472 m .41727 .62506 L .42163 .6246 L F
.408 .21 .496 r
.42203 .62391 m .42226 .62451 L .42192 .62472 L F
.42163 .6246 m .42192 .62472 L .42135 .62507 L F
.82 .67 .697 r
.41951 .62304 m .42132 .62349 L .42011 .62285 L F
.47 0 0 r
.4223 .62469 m .41844 .62415 L .42011 .62285 L F
.408 .21 .496 r
.42203 .62391 m .42192 .62472 L .42163 .6246 L F
.42226 .62451 m .42291 .62621 L .42135 .62507 L F
0 0 0 r
.42135 .62507 m .41874 .62667 L .41836 .62626 L F
.4223 .62469 m .41836 .62626 L .41727 .62506 L F
.891 .729 .674 r
.42276 .62265 m .4223 .62469 L .42222 .62423 L F
.408 .21 .496 r
.42276 .62265 m .42222 .62423 L .42203 .62391 L F
.891 .729 .674 r
.42276 .62265 m .42222 .62423 L .42158 .62032 L F
.408 .21 .496 r
.42276 .62265 m .42287 .62529 L .42222 .62423 L F
.42287 .62529 m .42291 .62621 L .42203 .62391 L F
.47 0 0 r
.4223 .62469 m .4215 .6224 L .4219 .62227 L F
.82 .67 .697 r
.41737 .62252 m .41951 .62304 L .42011 .62285 L F
.203 0 0 r
.16781 .56998 m .16642 .57118 L .16457 .57124 L F
.143 0 0 r
.16896 .57034 m .16642 .57118 L .16781 .56998 L F
.883 .559 .431 r
.68096 .42169 m .67921 .42266 L .6776 .42085 L F
.68096 .42169 m .68119 .42374 L .67921 .42266 L F
.12 .474 .895 r
.76712 .39815 m .77003 .3993 L .7693 .39789 L F
.725 .531 .629 r
.5859 .4849 m .58591 .4875 L .58836 .48476 L F
.721 .526 .626 r
.58836 .48476 m .58591 .4875 L .5886 .48733 L F
.692 .3 .301 r
.74498 .37241 m .74487 .37069 L .74257 .37313 L F
.799 .513 .503 r
.41948 .64476 m .421 .6489 L .4252 .64518 L F
.183 .146 .58 r
.4252 .64518 m .42563 .64484 L .42257 .64496 L F
.495 .094 .21 r
.4252 .64518 m .42358 .64853 L .42517 .64823 L F
.4252 .64518 m .421 .6489 L .42358 .64853 L F
.669 .876 .5 r
.41368 .6329 m .41259 .63416 L .41221 .63492 L F
.739 .548 .635 r
.41368 .6329 m .41221 .63492 L .41637 .635 L F
.999 .802 .465 r
.41282 .63153 m .41368 .6329 L .41844 .63405 L F
.41282 .63153 m .41259 .63416 L .41368 .6329 L F
.6 .57 .793 r
.41368 .6329 m .41637 .635 L .41844 .63405 L F
.366 .017 .233 r
.48166 .58685 m .4848 .58424 L .48143 .58465 L F
.48166 .58685 m .484 .58624 L .4848 .58424 L F
.451 .07 .223 r
.484 .58624 m .48806 .58352 L .4848 .58424 L F
.78 .565 .609 r
.48488 .58974 m .48166 .58685 L .48389 .58627 L F
.451 .07 .223 r
.48422 .58624 m .48806 .58352 L .484 .58624 L F
.78 .565 .609 r
.48431 .58623 m .48389 .58627 L .4843 .58616 L F
.48488 .58974 m .48389 .58627 L .48431 .58623 L F
.451 .07 .223 r
.48422 .58624 m .48649 .586 L .48806 .58352 L F
.212 .16 .579 r
.48649 .586 m .48488 .58974 L .48431 .58623 L F
.48649 .586 m .48431 .58623 L .48429 .58611 L F
.451 .07 .223 r
.48392 .58645 m .48611 .58607 L .48431 .58623 L F
.48421 .58624 m .48431 .58623 L .48422 .58624 L F
.48392 .58645 m .48431 .58623 L .48421 .58624 L F
.48611 .58607 m .48649 .586 L .48422 .58624 L F
.48392 .58645 m .48422 .58624 L .484 .58624 L F
.78 .565 .609 r
.4843 .58616 m .484 .58624 L .48429 .58611 L F
.484 .58624 m .48166 .58685 L .48384 .58623 L F
.484 .58624 m .48384 .58623 L .48429 .58611 L F
.366 .017 .233 r
.48166 .58685 m .48392 .58645 L .484 .58624 L F
.346 0 .213 r
.4848 .58424 m .48429 .58611 L .48166 .58685 L F
.488 .109 .245 r
.48806 .58352 m .48429 .58611 L .4848 .58424 L F
0 0 .404 r
.15612 .59788 m .1551 .59979 L .15509 .59905 L F
.608 .152 .144 r
.1909 .55937 m .18856 .56096 L .18681 .55957 L F
.226 .732 .672 r
.19293 .55949 m .18856 .56096 L .1909 .55937 L F
.03 0 .329 r
.45576 .61944 m .45487 .61784 L .4568 .6164 L F
.45576 .61944 m .45424 .62091 L .45487 .61784 L F
.323 0 .217 r
.14391 .56817 m .14625 .56601 L .14521 .5668 L F
.661 .535 .699 r
.80896 .4327 m .80739 .43647 L .80644 .43337 L F
.184 .37 .814 r
.47091 .55747 m .46939 .55817 L .46832 .55763 L F
.47091 .55747 m .47186 .56004 L .46939 .55817 L F
.519 .266 .472 r
.24066 .61712 m .24303 .61675 L .24347 .61441 L F
.46 .216 .457 r
.24303 .61675 m .24567 .61385 L .24347 .61441 L F
.656 .601 .781 r
.79842 .42456 m .8 .42049 L .79756 .42119 L F
.344 .082 .366 r
.55012 .58652 m .55371 .58361 L .55047 .58448 L F
.472 .865 .971 r
.42247 .62941 m .42148 .62889 L .42472 .62867 L F
.075 0 0 r
.18875 .5441 m .19096 .54366 L .19318 .5424 L F
.972 .867 .478 r
.23543 .59834 m .2359 .59965 L .23616 .59591 L F
0 0 .357 r
.23543 .59834 m .23689 .60173 L .2359 .59965 L F
.405 .135 .387 r
.27996 .61359 m .27776 .6142 L .28047 .61142 L F
.543 .259 .434 r
.28047 .61142 m .28242 .61332 L .27996 .61359 L F
.479 .262 .506 r
.28271 .61084 m .28242 .61332 L .28047 .61142 L F
.534 .462 .721 r
.4413 .60498 m .44191 .60731 L .43974 .60725 L F
.307 0 .171 r
.44119 .60771 m .43974 .60725 L .44191 .60731 L F
.44119 .60771 m .43876 .60966 L .43974 .60725 L F
.444 .309 .603 r
.25759 .59331 m .25973 .59531 L .2594 .59277 L F
.25759 .59331 m .25776 .59594 L .25973 .59531 L F
.588 .664 .891 r
.17058 .63909 m .17187 .63704 L .16894 .63588 L F
.17058 .63909 m .17235 .63839 L .17187 .63704 L F
.478 .527 .83 r
.17058 .63909 m .17259 .64045 L .17235 .63839 L F
.925 .784 .686 r
.17448 .67573 m .1757 .67493 L .17348 .67377 L F
.395 .002 .171 r
.44529 .56569 m .44767 .56538 L .44862 .56342 L F
.382 0 .164 r
.44862 .56342 m .45072 .56392 L .45118 .56344 L F
.44862 .56342 m .44767 .56538 L .45072 .56392 L F
0 0 0 r
.67531 .44128 m .67846 .43899 L .67877 .43878 L F
.616 .954 .813 r
.67846 .43899 m .68166 .43688 L .67996 .43733 L F
0 0 0 r
.67996 .43733 m .67877 .43878 L .67846 .43899 L F
.669 .919 .608 r
.67445 .43091 m .67181 .43395 L .67313 .432 L F
.689 .956 .95 r
.67313 .432 m .67181 .43395 L .66889 .43328 L F
.21 0 .181 r
.54781 .50223 m .54573 .5033 L .545 .50483 L F
.455 .848 .979 r
.22401 .5541 m .2241 .55321 L .22242 .55278 L F
.941 .586 .307 r
.51252 .54333 m .51266 .54499 L .51389 .5451 L F
.975 .694 .43 r
.51266 .54499 m .51251 .54651 L .51389 .5451 L F
0 0 0 r
.51389 .5451 m .51251 .54651 L .51519 .54417 L F
.449 .192 .431 r
.51519 .54417 m .51277 .54629 L .51266 .54499 L F
.51277 .54629 m .51251 .54651 L .51266 .54499 L F
.941 .586 .307 r
.5114 .54187 m .51266 .54499 L .51252 .54333 L F
0 0 0 r
.51389 .5451 m .51519 .54417 L .51638 .5437 L F
.93 .874 .76 r
.77301 .42217 m .77294 .4177 L .77363 .41981 L F
.839 .983 .871 r
.7717 .42111 m .77301 .42217 L .77363 .41981 L F
.034 0 0 r
.46839 .59853 m .47006 .59787 L .47157 .5958 L F
.561 .449 .683 r
.47399 .59515 m .47157 .5958 L .47194 .59473 L F
.604 .492 .699 r
.47399 .59515 m .47219 .5985 L .47157 .5958 L F
.346 0 .079 r
.47006 .59787 m .47399 .59515 L .47157 .5958 L F
.561 .449 .683 r
.47399 .59515 m .47157 .5958 L .47194 .59473 L F
.042 .61 .766 r
.55512 .5777 m .55736 .57771 L .55871 .57783 L F
.772 .701 .784 r
.55871 .57783 m .55518 .58068 L .55512 .5777 L F
.3 0 0 r
.55991 .57915 m .55871 .57783 L .55736 .57771 L F
.55991 .57915 m .56139 .57727 L .55871 .57783 L F
.854 .84 .831 r
.55418 .58905 m .55625 .59024 L .55754 .5877 L F
.054 .381 .845 r
.5575 .59163 m .55628 .59186 L .55625 .59024 L F
.5575 .59163 m .55625 .59024 L .55418 .58905 L F
.21 0 .054 r
.54 .50827 m .5424 .50791 L .54313 .50612 L F
0 0 0 r
.54313 .50612 m .54423 .5068 L .545 .50483 L F
.54313 .50612 m .5424 .50791 L .54423 .5068 L F
.741 .702 .815 r
.19178 .74084 m .19326 .74386 L .19441 .74158 L F
.406 .794 .989 r
.18873 .64589 m .1914 .64683 L .19302 .64635 L F
.1 0 0 r
.18035 .54748 m .18254 .54687 L .18445 .54529 L F
.016 0 0 r
.18445 .54529 m .18254 .54687 L .18464 .54612 L F
.477 .246 .484 r
.4113 .59342 m .41383 .59302 L .41595 .58793 L F
.128 0 .282 r
.41595 .58793 m .41544 .59175 L .41615 .5898 L F
.41595 .58793 m .41383 .59302 L .41544 .59175 L F
.549 .241 .398 r
.70339 .41107 m .70082 .40943 L .70078 .41125 L F
.559 .231 .37 r
.70339 .41107 m .70364 .40929 L .70082 .40943 L F
.467 .88 .939 r
.43028 .63736 m .42931 .63717 L .42763 .63822 L F
.42763 .63822 m .42931 .63717 L .43028 .63736 L F
.476 .257 .502 r
.27545 .61734 m .27516 .61977 L .27294 .6203 L F
.461 .244 .497 r
.27732 .61923 m .27545 .61734 L .27774 .61685 L F
.27732 .61923 m .27516 .61977 L .27545 .61734 L F
.291 .006 .296 r
.24838 .60823 m .25026 .60763 L .25099 .60552 L F
.33 .051 .329 r
.25026 .60763 m .25293 .60476 L .25099 .60552 L F
.816 .636 .659 r
.81355 .43887 m .81531 .44279 L .81199 .4417 L F
.684 .581 .734 r
.81744 .44014 m .81531 .44279 L .81355 .43887 L F
.938 .718 .578 r
.59072 .52699 m .58997 .52497 L .58938 .52564 L F
.943 .705 .549 r
.5885 .52884 m .59072 .52699 L .58938 .52564 L F
.5885 .52884 m .59058 .52888 L .59072 .52699 L F
.498 .815 1 r
.20272 .62949 m .19886 .62907 L .2011 .62837 L F
.166 .601 .937 r
.20439 .6296 m .20272 .62949 L .2011 .62837 L F
0 .058 .602 r
.39832 .62355 m .39922 .62209 L .39761 .6197 L F
.458 .289 .563 r
.39832 .62355 m .40094 .62543 L .39922 .62209 L F
.39832 .62355 m .39902 .62643 L .40094 .62543 L F
.504 .39 .658 r
.50124 .60489 m .50393 .60413 L .504 .60203 L F
.521 .186 .34 r
.50476 .60497 m .50119 .60792 L .50124 .60489 L F
.606 .411 .592 r
.50119 .60792 m .50393 .60413 L .50124 .60489 L F
.771 .849 .91 r
.71471 .41791 m .71795 .41783 L .71731 .41506 L F
.802 .794 .845 r
.71731 .41506 m .71795 .41783 L .72067 .4152 L F
.848 .886 .866 r
.75824 .42533 m .75498 .42644 L .75667 .42372 L F
.172 .306 .76 r
.40985 .64109 m .41097 .6409 L .40879 .63901 L F
.103 .178 .657 r
.40985 .64109 m .41171 .64323 L .41097 .6409 L F
.931 .947 .779 r
.56686 .57178 m .5663 .57475 L .56564 .57379 L F
.26 0 .279 r
.44522 .57802 m .44249 .58047 L .44343 .57911 L F
.885 .83 .787 r
.76334 .41915 m .76181 .4216 L .76185 .41771 L F
0 0 .379 r
.52974 .587 m .53043 .58806 L .53051 .58553 L F
.52974 .587 m .53125 .58947 L .53043 .58806 L F
.428 .187 .444 r
.27466 .62206 m .27294 .6203 L .27516 .61977 L F
.27466 .62206 m .27249 .62266 L .27294 .6203 L F
.701 .775 .909 r
.51466 .52316 m .51851 .52363 L .51701 .52204 L F
.471 .572 .875 r
.51851 .52363 m .51984 .52159 L .51701 .52204 L F
.51851 .52363 m .52098 .52358 L .51984 .52159 L F
.849 .44 0 r
.47975 .56656 m .47945 .56707 L .47887 .56532 L F
.47975 .56656 m .48074 .56881 L .47945 .56707 L F
.504 .828 1 r
.21169 .53849 m .21146 .53988 L .20971 .53911 L F
.21169 .53849 m .21363 .53933 L .21146 .53988 L F
.271 0 .2 r
.46287 .56148 m .46553 .55907 L .46418 .55999 L F
.775 .607 .672 r
.23589 .60825 m .2385 .60539 L .23645 .60419 L F
.23589 .60825 m .23694 .60847 L .2385 .60539 L F
.466 .883 .77 r
.79028 .44785 m .78671 .44945 L .78806 .44914 L F
.512 0 0 r
.47887 .56532 m .47572 .56486 L .47674 .56428 L F
.367 .386 .748 r
.41143 .62776 m .4097 .6298 L .40889 .62531 L F
.41143 .62776 m .40889 .62531 L .4091 .62537 L F
.41143 .62776 m .40886 .62512 L .41111 .62558 L F
.404 0 0 r
.40732 .62582 m .4108 .62643 L .411 .62588 L F
.41012 .62564 m .411 .62588 L .41111 .62558 L F
.40732 .62582 m .411 .62588 L .41012 .62564 L F
.367 .386 .748 r
.4091 .62537 m .40889 .62531 L .40886 .62512 L F
.651 .573 .754 r
.44891 .59563 m .45256 .59629 L .45151 .59272 L F
.603 .069 0 r
.23095 .55334 m .23216 .55403 L .22842 .55353 L F
.849 .57 .514 r
.41756 .63807 m .41763 .6405 L .42051 .64027 L F
.937 .718 .581 r
.4178 .64346 m .42051 .64027 L .41763 .6405 L F
.4178 .64346 m .41939 .64418 L .42051 .64027 L F
.409 .105 .335 r
.47872 .62207 m .47702 .62062 L .47956 .61992 L F
.47872 .62207 m .47647 .62263 L .47702 .62062 L F
.393 .4 .748 r
.29619 .55888 m .29684 .56201 L .29422 .56014 L F
.76 .677 .771 r
.82338 .42686 m .82447 .4305 L .82085 .43029 L F
.894 .695 .626 r
.82447 .4305 m .82152 .43233 L .82085 .43029 L F
.82447 .4305 m .82433 .43351 L .82152 .43233 L F
.75 .671 .774 r
.82705 .42748 m .82447 .4305 L .82338 .42686 L F
.495 .341 .601 r
.15997 .61087 m .15801 .61139 L .16016 .60817 L F
.5 .355 .615 r
.15997 .61087 m .16027 .61345 L .15801 .61139 L F
.4 .35 .686 r
.16027 .61345 m .15853 .61394 L .15801 .61139 L F
.376 0 0 r
.5201 .56546 m .52114 .56617 L .5201 .56471 L F
.5201 .56546 m .5201 .56471 L .51949 .56386 L F
.333 .765 .971 r
.52011 .56592 m .5201 .56546 L .51781 .56564 L F
.52156 .5661 m .5201 .56546 L .52011 .56592 L F
0 .046 .614 r
.52156 .5661 m .52303 .56693 L .5201 .56546 L F
.52156 .5661 m .52328 .56824 L .52303 .56693 L F
.425 .194 .458 r
.29211 .59306 m .29167 .59552 L .28954 .59611 L F
.575 .411 .621 r
.2943 .59026 m .29457 .59267 L .29211 .59306 L F
.463 .228 .471 r
.29392 .59496 m .29211 .59306 L .29457 .59267 L F
.29392 .59496 m .29167 .59552 L .29211 .59306 L F
.506 .108 .219 r
.49604 .60882 m .49828 .60996 L .49927 .60859 L F
.49927 .60859 m .49828 .60996 L .49604 .60882 L F
.242 .275 .697 r
.40796 .63496 m .40879 .63901 L .41011 .63708 L F
.278 .324 .731 r
.40879 .63901 m .41097 .6409 L .41011 .63708 L F
.445 .712 .98 r
.2787 .54179 m .27814 .54339 L .27647 .54196 L F
.2787 .54179 m .28074 .54341 L .27814 .54339 L F
.473 .306 .573 r
.24838 .60823 m .25051 .61033 L .25026 .60763 L F
.24838 .60823 m .24829 .61095 L .25051 .61033 L F
.729 .663 .785 r
.66678 .44227 m .66956 .44437 L .66936 .44145 L F
.691 .715 .867 r
.66936 .44145 m .66956 .44437 L .6733 .44262 L F
.722 .965 .704 r
.505 .52636 m .50295 .52916 L .50622 .52623 L F
.505 .52636 m .50269 .52876 L .50295 .52916 L F
.556 .361 .573 r
.56156 .49098 m .56416 .49056 L .56416 .4878 L F
.616 .409 .579 r
.56416 .4878 m .56723 .48965 L .56631 .48708 L F
.56416 .4878 m .56416 .49056 L .56723 .48965 L F
.46 .275 .543 r
.29167 .59552 m .28942 .59899 L .28954 .59611 L F
.423 0 0 r
.20048 .72087 m .20314 .72219 L .20221 .72189 L F
.20048 .72087 m .20314 .72219 L .20221 .72189 L F
.639 .931 .97 r
.20314 .72219 m .20688 .72066 L .20336 .72068 L F
.652 .387 .505 r
.44975 .58817 m .45385 .58925 L .45397 .58718 L F
.729 .887 .953 r
.45556 .58566 m .45397 .58718 L .45314 .5866 L F
.45556 .58566 m .45314 .5866 L .45382 .58597 L F
.45556 .58566 m .45254 .58619 L .45469 .58509 L F
.501 .449 .731 r
.45385 .58925 m .45611 .58982 L .4547 .58515 L F
.45467 .58518 m .4547 .58515 L .45469 .58509 L F
.45385 .58925 m .4547 .58515 L .45467 .58518 L F
.729 .887 .953 r
.45382 .58597 m .45314 .5866 L .45254 .58619 L F
.501 .449 .731 r
.45385 .58925 m .45254 .58619 L .45397 .58718 L F
.384 .123 .39 r
.43124 .59921 m .43373 .59878 L .43437 .59585 L F
.445 .177 .411 r
.43437 .59585 m .43587 .59816 L .43624 .59661 L F
.43437 .59585 m .43373 .59878 L .43587 .59816 L F
.609 .671 .884 r
.19595 .64698 m .19804 .651 L .20048 .65033 L F
.723 .455 .521 r
.41221 .63492 m .41376 .63755 L .41637 .635 L F
.781 .669 .74 r
.41376 .63755 m .41844 .63405 L .41637 .635 L F
.477 .437 .734 r
.29695 .57722 m .29807 .58148 L .29564 .5813 L F
.559 .402 .626 r
.2986 .58235 m .29564 .5813 L .29807 .58148 L F
.2986 .58235 m .29584 .58382 L .29564 .5813 L F
.801 .546 .553 r
.41282 .63153 m .41555 .63274 L .41523 .62939 L F
.593 .392 .578 r
.41523 .62939 m .41555 .63274 L .41865 .63158 L F
.814 .877 .892 r
.70628 .42344 m .70769 .42501 L .70881 .42349 L F
.5 .315 .562 r
.25293 .60476 m .2553 .60157 L .25341 .60233 L F
.508 .459 .737 r
.29872 .57048 m .29642 .57482 L .29568 .56865 L F
.482 .374 .654 r
.29872 .57048 m .29664 .57486 L .29642 .57482 L F
.455 .348 .644 r
.43602 .64774 m .43834 .64965 L .43877 .64713 L F
.43602 .64774 m .4361 .65045 L .43834 .64965 L F
0 0 .328 r
.53434 .6024 m .53495 .60369 L .53434 .60119 L F
.53434 .6024 m .53427 .60534 L .53495 .60369 L F
.671 .861 .972 r
.19415 .73252 m .19733 .73189 L .19494 .73091 L F
.068 .371 .838 r
.19653 .73436 m .19415 .73252 L .19733 .73189 L F
.928 .727 .612 r
.19494 .73091 m .19733 .73189 L .19653 .73436 L F
.19494 .73091 m .19653 .73436 L .19472 .73357 L F
.958 .772 .609 r
.19653 .73436 m .19733 .73189 L .19472 .73357 L F
.19653 .73436 m .19733 .73189 L .19472 .73357 L F
.561 .449 .683 r
.47399 .59515 m .47194 .59473 L .47376 .59295 L F
.47399 .59515 m .47194 .59473 L .47376 .59295 L F
.892 .771 .722 r
.41844 .63405 m .41999 .63262 L .41865 .63158 L F
.41844 .63405 m .41918 .63514 L .41999 .63262 L F
.581 .824 .99 r
.41865 .63158 m .41999 .63262 L .42245 .63201 L F
.57 .417 .634 r
.41999 .63262 m .41918 .63514 L .42245 .63201 L F
.656 .601 .781 r
.79842 .42456 m .80108 .42421 L .8 .42049 L F
.523 .352 .591 r
.79842 .42456 m .80075 .42617 L .80108 .42421 L F
.79842 .42456 m .79834 .42689 L .80075 .42617 L F
.757 .552 .619 r
.48992 .59911 m .49369 .59856 L .49359 .5962 L F
.517 .335 .573 r
.49369 .59856 m .49655 .5952 L .49359 .5962 L F
.49369 .59856 m .49655 .5952 L .49359 .5962 L F
.959 .909 .724 r
.58814 .53697 m .59022 .53595 L .58893 .53486 L F
.58814 .53697 m .58871 .53951 L .59022 .53595 L F
.465 .288 .556 r
.43428 .65546 m .4314 .65905 L .43139 .65651 L F
0 0 0 r
.43139 .65651 m .43229 .65647 L .43428 .65546 L F
.4314 .65905 m .43229 .65647 L .43139 .65651 L F
.274 .611 .956 r
.44917 .63285 m .44845 .63383 L .44659 .63331 L F
.44917 .63285 m .45118 .63454 L .44845 .63383 L F
.558 .853 .997 r
.26883 .5399 m .26824 .54147 L .26668 .53998 L F
.26883 .5399 m .27053 .54077 L .26824 .54147 L F
.93 .725 .241 r
.23466 .59104 m .23547 .59323 L .23513 .58972 L F
.935 .62 .418 r
.23383 .5949 m .23616 .59591 L .23547 .59323 L F
.857 .809 .802 r
.76185 .41771 m .76181 .4216 L .75945 .4209 L F
.399 0 0 r
.48219 .55843 m .48427 .5591 L .48613 .55919 L F
.663 .125 0 r
.48427 .5591 m .48754 .56005 L .48613 .55919 L F
.529 .488 .755 r
.29684 .56201 m .29771 .56572 L .29555 .56622 L F
.511 .37 .625 r
.29771 .56572 m .29568 .56865 L .29555 .56622 L F
.718 .379 0 r
.42197 .60173 m .42291 .60433 L .42336 .60523 L F
.599 .136 .125 r
.42184 .60625 m .42336 .60523 L .42291 .60433 L F
.42184 .60625 m .42574 .60537 L .42336 .60523 L F
.597 .916 .975 r
.2231 .66847 m .22719 .6677 L .22667 .66612 L F
.551 .168 .268 r
.22568 .6675 m .22667 .66612 L .22719 .6677 L F
.22568 .6675 m .2291 .66489 L .22667 .66612 L F
.724 .53 .629 r
.58218 .48724 m .5859 .4849 L .58223 .48465 L F
.58218 .48724 m .58591 .4875 L .5859 .4849 L F
.636 .364 .489 r
.51377 .5207 m .51705 .52125 L .51738 .5181 L F
.511 .257 .465 r
.51705 .52125 m .51992 .52064 L .51738 .5181 L F
.472 .236 .475 r
.27249 .62266 m .26988 .62555 L .27033 .62321 L F
.495 .202 .397 r
.56126 .49295 m .56416 .49056 L .56156 .49098 L F
.868 .746 .726 r
.59342 .50855 m .59401 .50629 L .59229 .50511 L F
.306 0 0 r
.1565 .55837 m .16077 .5565 L .15862 .55708 L F
.062 .373 .84 r
.5014 .58183 m .50336 .58401 L .50267 .58226 L F
.832 .496 .418 r
.50579 .58302 m .50267 .58226 L .50336 .58401 L F
.921 .808 .718 r
.51959 .54168 m .51824 .54426 L .52004 .54497 L F
.347 .4 .774 r
.51959 .54168 m .52004 .54497 L .52135 .54394 L F
.6 .232 .315 r
.51824 .54426 m .52135 .54394 L .52004 .54497 L F
.134 .681 .797 r
.22594 .53812 m .22819 .53793 L .22994 .53798 L F
.101 .656 .779 r
.22994 .53798 m .22819 .53793 L .23222 .53784 L F
.691 .631 .784 r
.48016 .60804 m .48273 .61041 L .48327 .60786 L F
.793 .999 .838 r
.48316 .60548 m .48161 .6068 L .48327 .60786 L F
.48161 .6068 m .48016 .60804 L .48242 .60791 L F
.48161 .6068 m .48242 .60791 L .48327 .60786 L F
.428 .434 .764 r
.48265 .60821 m .48402 .61057 L .48273 .61041 L F
.4826 .60694 m .4836 .6095 L .48265 .60821 L F
.4836 .6095 m .48402 .61057 L .48265 .60821 L F
.4826 .60694 m .48273 .61041 L .48016 .60804 L F
.787 .687 .754 r
.21953 .68939 m .22213 .6897 L .21947 .68991 L F
.22005 .68508 m .21953 .68939 L .21895 .68928 L F
.21953 .68939 m .21947 .68991 L .21895 .68928 L F
.767 .664 .749 r
.21909 .68934 m .21953 .68939 L .21962 .68959 L F
.21953 .68939 m .22213 .6897 L .22076 .68964 L F
.21953 .68939 m .22076 .68964 L .21962 .68959 L F
.21895 .68928 m .22213 .6897 L .21909 .68934 L F
.787 .687 .754 r
.22005 .68508 m .22213 .6897 L .21953 .68939 L F
.787 .696 .764 r
.22213 .6897 m .21983 .69271 L .21947 .68991 L F
.576 .586 .826 r
.22339 .68831 m .22213 .6897 L .22005 .68508 L F
.752 .905 .945 r
.21962 .68959 m .22213 .6897 L .22339 .68831 L F
.779 .817 .883 r
.75386 .41339 m .75185 .4149 L .75502 .41513 L F
.871 .838 .81 r
.75386 .41339 m .75502 .41513 L .75728 .41195 L F
.738 .581 .68 r
.57851 .48438 m .58143 .4814 L .57857 .4817 L F
.57851 .48438 m .58223 .48465 L .58143 .4814 L F
.375 .838 .792 r
.21341 .70664 m .20951 .70793 L .2118 .70697 L F
0 0 0 r
.21341 .70664 m .2118 .70697 L .21455 .70658 L F
.596 .25 .353 r
.45556 .58566 m .45882 .58456 L .45646 .58426 L F
.42 .364 .689 r
.26449 .55407 m .26524 .55693 L .26704 .55602 L F
.661 .284 .32 r
.26704 .55602 m .26299 .55637 L .26449 .55407 L F
.469 .214 .444 r
.49183 .60241 m .49146 .60479 L .48911 .60522 L F
.511 .264 .476 r
.4937 .6015 m .49146 .60479 L .49183 .60241 L F
.64 .219 .227 r
.43024 .62086 m .42859 .62279 L .42592 .62192 L F
.357 .093 .37 r
.43264 .62009 m .43024 .62086 L .42966 .62067 L F
.43264 .62009 m .43261 .62141 L .43024 .62086 L F
.562 .228 .36 r
.43261 .62141 m .42859 .62279 L .43024 .62086 L F
.491 .815 1 r
.25872 .53818 m .25841 .53961 L .25704 .53907 L F
.25872 .53818 m .26056 .53907 L .25841 .53961 L F
.775 .671 .749 r
.83477 .42068 m .83549 .42418 L .83186 .42369 L F
.678 .609 .771 r
.83477 .42068 m .83786 .42153 L .83549 .42418 L F
.911 .762 .684 r
.59342 .50855 m .59229 .50511 L .59133 .50745 L F
.923 .702 .585 r
.59133 .50745 m .59287 .50855 L .59342 .50855 L F
.871 .838 .81 r
.75386 .41339 m .75728 .41195 L .7564 .41091 L F
.907 .933 .818 r
.75877 .40759 m .75728 .41195 L .75962 .40829 L F
.75877 .40759 m .7564 .41091 L .75728 .41195 L F
.865 .984 .845 r
.21947 .68991 m .21789 .69137 L .21983 .69271 L F
.926 .656 .507 r
.2177 .69506 m .21978 .6959 L .21983 .69271 L F
.7 .637 .783 r
.42183 .58652 m .42319 .59016 L .42062 .58997 L F
0 0 0 r
.42207 .5896 m .42062 .58997 L .42319 .59016 L F
.941 .946 .759 r
.4241 .58608 m .42319 .59016 L .42183 .58652 L F
.4241 .58608 m .42207 .5896 L .42319 .59016 L F
.616 .49 .685 r
.80961 .41845 m .80973 .42103 L .807 .42153 L F
.604 .44 .633 r
.807 .42153 m .80973 .42103 L .80729 .42415 L F
.104 .594 .906 r
.78475 .39635 m .78602 .39716 L .78781 .39728 L F
.427 .533 .862 r
.78602 .39716 m .78962 .40021 L .78781 .39728 L F
.762 .647 .734 r
.8121 .41794 m .81342 .42149 L .80973 .42103 L F
.729 .534 .627 r
.81342 .42149 m .80959 .42347 L .80973 .42103 L F
.81342 .42149 m .81342 .42402 L .80959 .42347 L F
.749 .64 .74 r
.81577 .41856 m .81342 .42149 L .8121 .41794 L F
.7 .567 .701 r
.81577 .41856 m .81744 .42198 L .81342 .42149 L F
.707 .52 .634 r
.81744 .42198 m .81342 .42402 L .81342 .42149 L F
0 0 0 r
.5669 .56819 m .56783 .56753 L .56811 .56588 L F
0 0 .029 r
.56811 .56588 m .56902 .56429 L .56954 .56186 L F
0 0 0 r
.56811 .56588 m .56783 .56753 L .56902 .56429 L F
.768 .392 0 r
.52523 .57162 m .5269 .57507 L .52615 .57388 L F
0 0 .309 r
.527 .57734 m .52615 .57388 L .5269 .57507 L F
.671 .861 .972 r
.19415 .73252 m .19472 .73357 L .19413 .73526 L F
.19415 .73252 m .19494 .73091 L .19472 .73357 L F
.345 .323 .691 r
.2626 .56069 m .26476 .56128 L .26487 .55949 L F
.2626 .56069 m .26327 .56336 L .26476 .56128 L F
.599 .282 .403 r
.49376 .58379 m .49334 .58622 L .49086 .58595 L F
.374 .087 .343 r
.49565 .58543 m .49334 .58622 L .49376 .58379 L F
.732 .678 .798 r
.81454 .41455 m .81577 .41856 L .8121 .41794 L F
.72 .701 .831 r
.81717 .41426 m .81577 .41856 L .81454 .41455 L F
.81717 .41426 m .8183 .41765 L .81577 .41856 L F
.677 .553 .707 r
.8183 .41765 m .81744 .42198 L .81577 .41856 L F
.467 .163 .365 r
.46226 .5837 m .46469 .58329 L .46529 .58134 L F
.391 .093 .335 r
.46529 .58134 m .46709 .58264 L .46737 .5805 L F
.46529 .58134 m .46469 .58329 L .46709 .58264 L F
.925 .752 .649 r
.26363 .57829 m .26184 .57765 L .26327 .57566 L F
.396 .71 .986 r
.26363 .57829 m .26413 .57687 L .26184 .57765 L F
.26363 .57829 m .26528 .57805 L .26413 .57687 L F
.848 .618 .59 r
.57557 .50886 m .57536 .51138 L .57321 .50824 L F
.3 0 0 r
.74131 .37419 m .73985 .37322 L .73906 .37359 L F
.74131 .37419 m .74257 .37313 L .73985 .37322 L F
.505 .332 .58 r
.27999 .61632 m .27776 .6142 L .27996 .61359 L F
.27999 .61632 m .27774 .61685 L .27776 .6142 L F
.696 .729 .876 r
.48753 .56842 m .49074 .56905 L .48931 .56833 L F
.148 .455 .884 r
.49173 .57052 m .48931 .56833 L .49074 .56905 L F
0 0 .279 r
.40462 .60227 m .40533 .60375 L .40545 .60135 L F
.40462 .60227 m .40424 .60492 L .40533 .60375 L F
.643 .306 .386 r
.45372 .57177 m .45228 .57426 L .44991 .57414 L F
.434 .08 .264 r
.45496 .57283 m .45372 .57177 L .45606 .5712 L F
.45496 .57283 m .45228 .57426 L .45372 .57177 L F
0 0 0 r
.42207 .5896 m .41909 .5921 L .42062 .58997 L F
.603 .948 .802 r
.68315 .43531 m .68166 .43688 L .68373 .43531 L F
.604 .95 .812 r
.67996 .43733 m .68166 .43688 L .68315 .43531 L F
.921 .901 .788 r
.75353 .39271 m .75212 .39251 L .75293 .39148 L F
.716 .865 .952 r
.75632 .39148 m .75353 .39271 L .75293 .39148 L F
.697 .33 .35 r
.57175 .50566 m .56998 .50768 L .56766 .50543 L F
.812 .49 .445 r
.57321 .50824 m .56998 .50768 L .57175 .50566 L F
.712 .23 0 r
.50286 .5716 m .50453 .57404 L .50516 .5742 L F
.698 .176 0 r
.50563 .57567 m .50516 .5742 L .50453 .57404 L F
.50563 .57567 m .50716 .57665 L .50516 .5742 L F
.685 .425 .523 r
.43124 .59921 m .43428 .60157 L .43373 .59878 L F
.43124 .59921 m .43171 .60193 L .43428 .60157 L F
.468 .408 .707 r
.45349 .59883 m .45491 .5957 L .45256 .59629 L F
.45349 .59883 m .45563 .59835 L .45491 .5957 L F
.733 .4 .416 r
.67506 .41096 m .67859 .40941 L .67505 .40862 L F
.67506 .41096 m .67896 .41129 L .67859 .40941 L F
.646 .094 0 r
.6824 .41154 m .67859 .40941 L .67896 .41129 L F
.446 .715 .981 r
.19685 .56005 m .19899 .55971 L .19731 .55838 L F
.273 .653 .968 r
.48149 .59078 m .48223 .59097 L .47961 .59085 L F
.323 .756 .97 r
.2109 .63166 m .21267 .63236 L .20874 .63184 L F
.387 .82 .959 r
.2132 .63151 m .21267 .63236 L .2109 .63166 L F
.2132 .63151 m .21488 .63192 L .21267 .63236 L F
.921 .975 .705 r
.23042 .59276 m .22992 .59184 L .23192 .5903 L F
.978 .799 .596 r
.23192 .5903 m .22992 .59184 L .23052 .58928 L F
.628 .495 .682 r
.44975 .58817 m .45151 .59272 L .45385 .58925 L F
.555 .93 .911 r
.20346 .55801 m .20301 .5589 L .20467 .55806 L F
.20346 .55801 m .20125 .559 L .20301 .5589 L F
.334 .81 .9 r
.22747 .64704 m .23136 .64673 L .22946 .64616 L F
.525 .852 .997 r
.23136 .64673 m .2311 .64509 L .22946 .64616 L F
.23136 .64673 m .23331 .64632 L .2311 .64509 L F
.601 .787 .97 r
.41428 .59813 m .41572 .59934 L .41823 .59876 L F
.66 .467 .613 r
.4237 .65367 m .42151 .65615 L .42064 .6545 L F
.773 .628 .7 r
.81355 .43887 m .80985 .43623 L .81253 .43557 L F
.81355 .43887 m .81194 .44015 L .80985 .43623 L F
.816 .636 .659 r
.81355 .43887 m .81199 .4417 L .81194 .44015 L F
.72 .711 .841 r
.81614 .43621 m .81355 .43887 L .81253 .43557 L F
.661 .608 .785 r
.81614 .43621 m .81744 .44014 L .81355 .43887 L F
0 0 0 r
.21986 .5388 m .22222 .5386 L .22359 .53846 L F
.385 .847 .848 r
.22359 .53846 m .22424 .53787 L .22594 .53812 L F
.22359 .53846 m .22222 .5386 L .22424 .53787 L F
.524 .547 .821 r
.16509 .63282 m .16605 .63472 L .16807 .63395 L F
.546 .638 .892 r
.16605 .63472 m .16894 .63588 L .16807 .63395 L F
.385 0 0 r
.42472 .62867 m .42707 .62896 L .42887 .62853 L F
.877 .484 .287 r
.42775 .63056 m .42887 .62853 L .42707 .62896 L F
.42775 .63056 m .43024 .63211 L .42887 .62853 L F
.473 .404 .698 r
.29602 .5563 m .29427 .55307 L .29538 .55359 L F
.795 .632 .68 r
.23601 .61339 m .23698 .61691 L .2391 .61397 L F
.768 .592 .66 r
.2391 .61397 m .23698 .61691 L .24066 .61712 L F
.343 .731 .985 r
.56377 .57712 m .56462 .57798 L .56139 .57727 L F
.745 .718 .827 r
.82259 .43637 m .8236 .43966 L .81993 .43909 L F
.779 .737 .814 r
.82606 .43672 m .8236 .43966 L .82259 .43637 L F
.809 .8 .843 r
.22329 .66969 m .22429 .67144 L .22719 .6677 L F
.597 .916 .975 r
.2231 .66847 m .22568 .6675 L .22719 .6677 L F
.809 .8 .843 r
.22329 .66969 m .22719 .6677 L .22568 .6675 L F
0 .365 .711 r
.22719 .6677 m .22831 .66804 L .22568 .6675 L F
.551 .168 .268 r
.22568 .6675 m .2281 .6681 L .22813 .668 L F
0 .365 .711 r
.22831 .66804 m .2284 .66807 L .22568 .6675 L F
.551 .168 .268 r
.22568 .6675 m .22813 .668 L .2291 .66489 L F
.452 .515 .832 r
.22654 .66618 m .22801 .66798 L .22568 .6675 L F
.22801 .66798 m .2281 .6681 L .22568 .6675 L F
0 .365 .711 r
.2284 .66807 m .22873 .66816 L .22568 .6675 L F
0 0 0 r
.2291 .66489 m .23109 .66757 L .23157 .66439 L F
.2291 .66489 m .22861 .66719 L .23109 .66757 L F
.28 .757 .931 r
.2192 .64811 m .2193 .6475 L .21607 .64791 L F
.2192 .64811 m .22118 .64789 L .2193 .6475 L F
.41 .352 .682 r
.1551 .59979 m .15533 .60347 L .15414 .60217 L F
.344 .082 .366 r
.55012 .58652 m .55324 .58585 L .55371 .58361 L F
.639 .583 .776 r
.55128 .58888 m .55324 .58585 L .55012 .58652 L F
.732 .436 .479 r
.54866 .5886 m .55012 .58652 L .5483 .58669 L F
.54866 .5886 m .55128 .58888 L .55012 .58652 L F
.323 0 .217 r
.14391 .56817 m .14693 .56533 L .14625 .56601 L F
.45 .407 .719 r
.29614 .58877 m .2943 .59026 L .29378 .58685 L F
.569 .483 .719 r
.29614 .58877 m .29457 .59267 L .2943 .59026 L F
.457 .322 .609 r
.49655 .5952 m .49836 .59504 L .49603 .59313 L F
.49655 .5952 m .49836 .59504 L .49603 .59313 L F
.584 .046 0 r
.51821 .56233 m .51789 .56236 L .51694 .56144 L F
.492 .702 .963 r
.51781 .56564 m .51789 .56236 L .51821 .56233 L F
.669 .89 .978 r
.18044 .64739 m .1844 .64705 L .18257 .64689 L F
.518 .911 .92 r
.1844 .64705 m .18698 .64602 L .18468 .64614 L F
.484 .889 .939 r
.18468 .64614 m .18257 .64689 L .1844 .64705 L F
.98 .743 .505 r
.59104 .51655 m .59244 .51774 L .59119 .51416 L F
.914 .851 .767 r
.58901 .52004 m .59244 .51774 L .59104 .51655 L F
.58901 .52004 m .59042 .5211 L .59244 .51774 L F
.491 .095 .216 r
.56144 .50601 m .56413 .50721 L .56124 .50727 L F
.498 .054 .125 r
.56385 .50608 m .56413 .50721 L .56144 .50601 L F
.578 .572 .809 r
.47052 .62531 m .46934 .62928 L .46794 .62847 L F
.47052 .62531 m .47186 .62899 L .46934 .62928 L F
.457 .791 .999 r
.46934 .62928 m .47045 .62792 L .46794 .62847 L F
.46934 .62928 m .47186 .62899 L .47045 .62792 L F
.23 0 .296 r
.54856 .5004 m .54781 .50223 L .55028 .49922 L F
.778 .665 .739 r
.59451 .49959 m .59304 .49625 L .59109 .4989 L F
.59451 .49959 m .59529 .49703 L .59304 .49625 L F
.863 .519 .399 r
.59305 .5012 m .59451 .49959 L .59109 .4989 L F
.59305 .5012 m .59502 .5023 L .59451 .49959 L F
.931 .968 .694 r
.58704 .5405 m .58871 .53951 L .58814 .53697 L F
.58704 .5405 m .5874 .54143 L .58871 .53951 L F
.488 .109 .245 r
.48806 .58352 m .48649 .586 L .48429 .58611 L F
.66 .569 .741 r
.48709 .58114 m .48806 .58352 L .48957 .58101 L F
.048 0 .271 r
.48806 .58352 m .48924 .58308 L .48957 .58101 L F
.595 .464 .672 r
.49852 .59749 m .49915 .60084 L .49628 .60104 L F
.791 .61 .656 r
.49756 .59971 m .49852 .59792 L .49852 .59749 L F
.026 0 0 r
.49977 .59652 m .49852 .59749 L .49853 .5971 L F
.987 .735 .46 r
.49977 .59652 m .49852 .59749 L .49836 .59504 L F
.533 .422 .673 r
.50148 .59997 m .49852 .59749 L .50227 .59748 L F
.50148 .59997 m .49915 .60084 L .49852 .59749 L F
.791 .61 .656 r
.49852 .59792 m .49991 .59532 L .49852 .59749 L F
.026 0 0 r
.49853 .5971 m .49852 .59749 L .49616 .59822 L F
.958 .81 .656 r
.57761 .53024 m .57536 .53153 L .57553 .52897 L F
.57761 .53024 m .57684 .53263 L .57536 .53153 L F
.879 .772 .739 r
.41844 .63405 m .41756 .63807 L .41918 .63514 L F
.507 .324 .567 r
.41918 .63514 m .4213 .63626 L .42245 .63201 L F
.594 .186 .239 r
.41918 .63514 m .42223 .6371 L .4213 .63626 L F
.564 .364 .569 r
.45873 .61373 m .4568 .6164 L .45666 .61412 L F
.771 .54 .585 r
.50267 .58226 m .49812 .58509 L .50056 .58169 L F
.062 .373 .84 r
.5014 .58183 m .50267 .58226 L .50146 .58193 L F
.5014 .58183 m .50149 .58198 L .50059 .5817 L F
.771 .54 .585 r
.50267 .58226 m .50056 .58169 L .50062 .58162 L F
.062 .373 .84 r
.50146 .58193 m .50267 .58226 L .50149 .58198 L F
.50059 .5817 m .50149 .58198 L .4996 .58155 L F
.647 .171 .109 r
.49812 .58509 m .50202 .58554 L .50106 .58701 L F
.212 .372 .807 r
.49812 .58509 m .50106 .58701 L .50046 .58579 L F
.404 .001 .157 r
.50054 .58169 m .49812 .58509 L .49666 .58465 L F
.50056 .58169 m .49812 .58509 L .50054 .58169 L F
.771 .54 .585 r
.50267 .58226 m .50202 .58554 L .49812 .58509 L F
.212 .372 .807 r
.49812 .58509 m .50046 .58579 L .49916 .58312 L F
.404 .001 .157 r
.49666 .58465 m .49812 .58509 L .49565 .58543 L F
.50062 .58162 m .50056 .58169 L .50054 .58169 L F
.408 0 0 r
.4996 .58155 m .50267 .58226 L .50062 .58162 L F
.122 .57 .92 r
.77105 .38653 m .7707 .3865 L .77069 .38572 L F
.396 .02 .202 r
.18195 .56277 m .18056 .56517 L .17811 .56558 L F
0 0 0 r
.18341 .56227 m .18056 .56517 L .18195 .56277 L F
.47 .281 .542 r
.28746 .60204 m .28732 .60459 L .28515 .60514 L F
.353 .247 .592 r
.28708 .6071 m .28515 .60514 L .28732 .60459 L F
.28708 .6071 m .28542 .60792 L .28515 .60514 L F
.293 0 .184 r
.53705 .51125 m .53932 .51048 L .54 .50827 L F
.339 0 .201 r
.54 .50827 m .54174 .50981 L .5424 .50791 L F
.54 .50827 m .53932 .51048 L .54174 .50981 L F
.684 .731 .886 r
.783 .44238 m .78056 .44355 L .77931 .44145 L F
.774 .72 .802 r
.43815 .60207 m .43534 .60431 L .43428 .60157 L F
.275 .419 .826 r
.43534 .60431 m .43715 .60353 L .43428 .60157 L F
.675 .449 .571 r
.43423 .60586 m .43534 .60431 L .43405 .60456 L F
.43423 .60586 m .43715 .60353 L .43534 .60431 L F
.536 .691 .939 r
.73925 .40167 m .73684 .4023 L .73523 .39997 L F
.788 .756 .824 r
.48452 .5744 m .48643 .57762 L .48911 .57462 L F
.53 .357 .592 r
.48643 .57762 m .48836 .5774 L .48911 .57462 L F
.66 .58 .755 r
.48709 .58114 m .48836 .5774 L .48643 .57762 L F
.707 .52 .634 r
.81744 .42198 m .81757 .42462 L .81342 .42402 L F
.677 .553 .707 r
.8183 .41765 m .81969 .42144 L .81744 .42198 L F
.694 .53 .661 r
.81969 .42144 m .81757 .42462 L .81744 .42198 L F
.549 .301 .493 r
.74361 .37618 m .74631 .37788 L .74364 .37826 L F
.508 .249 .457 r
.48535 .61682 m .48754 .619 L .48782 .6161 L F
.48535 .61682 m .48754 .619 L .48782 .6161 L F
0 .038 .564 r
.53427 .60534 m .53548 .60729 L .53495 .60369 L F
.166 .505 .911 r
.22037 .66882 m .22429 .67144 L .22329 .66969 L F
.774 .9 .93 r
.67679 .42891 m .67445 .43091 L .67384 .42941 L F
.989 .887 .565 r
.67445 .43091 m .67313 .432 L .67384 .42941 L F
.798 .649 .697 r
.23156 .57733 m .23282 .58114 L .23135 .58082 L F
.863 .418 .033 r
.23338 .5836 m .23135 .58082 L .23282 .58114 L F
.607 .615 .833 r
.23449 .5771 m .23282 .58114 L .23156 .57733 L F
.23449 .5771 m .2352 .58062 L .23282 .58114 L F
.861 .568 .039 r
.23248 .58166 m .23338 .5836 L .23282 .58114 L F
.23248 .58166 m .23282 .58114 L .2352 .58062 L F
.057 .33 .81 r
.15828 .62793 m .15801 .62586 L .15655 .62611 L F
.15828 .62793 m .15999 .62884 L .15801 .62586 L F
.15828 .62793 m .15954 .62873 L .15999 .62884 L F
.867 .709 .684 r
.68119 .42374 m .68259 .42739 L .68074 .42613 L F
.804 .911 .913 r
.68259 .42739 m .679 .42818 L .68074 .42613 L F
.68259 .42739 m .67975 .42918 L .679 .42818 L F
.536 .742 .971 r
.79477 .40915 m .79643 .40709 L .79406 .4071 L F
.79477 .40915 m .79716 .40857 L .79643 .40709 L F
.461 .461 .771 r
.79477 .40915 m .7981 .41091 L .79716 .40857 L F
.354 .011 .237 r
.25936 .63478 m .25619 .6372 L .25723 .63542 L F
0 0 0 r
.23994 .55665 m .23865 .55862 L .23762 .55996 L F
.636 .964 .843 r
.23865 .55862 m .23555 .56057 L .23762 .55996 L F
0 0 .346 r
.52729 .54078 m .52728 .54327 L .52598 .54486 L F
.798 .779 .274 r
.52569 .5447 m .52598 .54486 L .52728 .54327 L F
.52569 .5447 m .52541 .54715 L .52598 .54486 L F
.964 .859 .688 r
.76824 .40501 m .76554 .40803 L .76743 .40449 L F
.76824 .40501 m .76674 .40932 L .76554 .40803 L F
.458 .836 .988 r
.44064 .61344 m .43691 .61363 L .43737 .61391 L F
.972 .701 .46 r
.49026 .54136 m .48871 .54042 L .49012 .53852 L F
.612 .955 .89 r
.49012 .53852 m .49132 .53705 L .49261 .53688 L F
0 0 0 r
.49012 .53852 m .48871 .54042 L .49132 .53705 L F
.971 .726 .508 r
.57686 .51735 m .57546 .51384 L .57718 .51487 L F
.37 .434 .797 r
.78266 .40137 m .78079 .40341 L .77921 .39935 L F
.334 .379 .76 r
.78266 .40137 m .78387 .4054 L .78079 .40341 L F
.686 .497 .624 r
.23808 .61967 m .24066 .61712 L .23698 .61691 L F
.23808 .61967 m .24075 .61992 L .24066 .61712 L F
.333 .222 .575 r
.24066 .61712 m .2424 .61863 L .24303 .61675 L F
.24066 .61712 m .24075 .61992 L .2424 .61863 L F
.979 .682 .334 r
.43138 .61851 m .43232 .61693 L .43301 .61567 L F
.43138 .61851 m .43264 .62009 L .43232 .61693 L F
.8 .535 .536 r
.43232 .61693 m .43264 .62009 L .43589 .62018 L F
.823 .876 .883 r
.17765 .61799 m .1755 .62038 L .17372 .61941 L F
.752 .557 .632 r
.57835 .48694 m .58223 .48465 L .57851 .48438 L F
.57835 .48694 m .58218 .48724 L .58223 .48465 L F
.548 .8 .992 r
.23109 .66757 m .23311 .66854 L .23504 .66783 L F
.562 .347 .546 r
.46612 .61897 m .46875 .61641 L .46648 .61693 L F
.379 .094 .348 r
.83405 .43522 m .83422 .43629 L .83207 .4364 L F
.83422 .43629 m .83436 .43715 L .83405 .43705 L F
.83422 .43629 m .83405 .43705 L .83207 .4364 L F
.898 .602 .475 r
.83383 .43679 m .83405 .43705 L .83207 .4364 L F
.83405 .43705 m .83498 .43817 L .83207 .4364 L F
.379 .094 .348 r
.83436 .43715 m .83442 .43759 L .83207 .4364 L F
.241 .201 .611 r
.83383 .43679 m .83442 .43759 L .83428 .43689 L F
.83207 .4364 m .83398 .43736 L .83383 .43679 L F
.898 .602 .475 r
.83383 .43679 m .83398 .43736 L .83405 .43705 L F
.435 .378 .695 r
.83207 .4364 m .83498 .43817 L .83261 .43889 L F
.898 .602 .475 r
.83405 .43705 m .83384 .43798 L .83498 .43817 L F
.241 .201 .611 r
.83398 .43736 m .83442 .43759 L .83383 .43679 L F
.83207 .4364 m .83428 .43689 L .83332 .43226 L F
.898 .602 .475 r
.83267 .43539 m .83383 .43679 L .83207 .4364 L F
.241 .201 .611 r
.83207 .4364 m .83286 .43378 L .83267 .43539 L F
.83286 .43378 m .83332 .43226 L .83267 .43539 L F
.851 .567 .507 r
.83259 .43605 m .83267 .43539 L .83026 .43412 L F
.759 .689 .785 r
.82772 .4371 m .83334 .43692 L .83281 .43646 L F
.764 .558 .619 r
.82775 .43955 m .83337 .43702 L .82772 .4371 L F
.83337 .43702 m .83334 .43692 L .82772 .4371 L F
.82775 .43955 m .83151 .44007 L .83344 .43718 L F
.898 .602 .475 r
.83338 .43695 m .83396 .43745 L .83398 .43736 L F
.764 .558 .619 r
.83337 .43702 m .83344 .43718 L .83363 .43691 L F
.82775 .43955 m .83344 .43718 L .83337 .43702 L F
.898 .602 .475 r
.83281 .43646 m .833 .43783 L .83336 .43699 L F
.83335 .43697 m .83336 .43699 L .83336 .43698 L F
.83281 .43646 m .83336 .43699 L .83335 .43697 L F
.83334 .43692 m .83336 .43698 L .83338 .43695 L F
.83281 .43646 m .83336 .43698 L .83334 .43692 L F
.83267 .43539 m .83338 .43695 L .83398 .43736 L F
.764 .558 .619 r
.83337 .43702 m .83363 .43691 L .83334 .43692 L F
.851 .567 .507 r
.83363 .43691 m .833 .43783 L .83281 .43646 L F
.898 .602 .475 r
.83267 .43539 m .83281 .43646 L .83338 .43695 L F
.851 .567 .507 r
.83363 .43691 m .83281 .43646 L .83267 .43539 L F
.759 .689 .785 r
.82972 .43476 m .83281 .43646 L .8302 .4342 L F
.82772 .4371 m .83281 .43646 L .82972 .43476 L F
.898 .602 .475 r
.83338 .43695 m .833 .43783 L .83384 .43798 L F
.851 .567 .507 r
.83363 .43691 m .83267 .43539 L .83259 .43605 L F
.759 .689 .785 r
.8302 .4342 m .83363 .43691 L .83026 .43412 L F
.83334 .43692 m .83363 .43691 L .8302 .4342 L F
.898 .602 .475 r
.83338 .43695 m .83384 .43798 L .83396 .43745 L F
.83267 .43539 m .83398 .43736 L .83383 .43679 L F
.931 .969 .698 r
.48177 .61592 m .48038 .61892 L .48021 .6169 L F
.781 .604 .66 r
.58843 .48959 m .59203 .48763 L .5886 .48733 L F
.58843 .48959 m .59001 .49044 L .59203 .48763 L F
.442 .562 .88 r
.54044 .6117 m .54201 .60957 L .53943 .61009 L F
.54044 .6117 m .54324 .6118 L .54201 .60957 L F
.03 0 0 r
.16978 .55124 m .16984 .55204 L .17184 .5505 L F
.16978 .55124 m .16766 .55266 L .16984 .55204 L F
.521 .186 .34 r
.50476 .60497 m .50421 .60744 L .50119 .60792 L F
.288 0 .238 r
.50693 .60414 m .50421 .60744 L .50476 .60497 L F
.507 .153 .3 r
.5553 .50811 m .55167 .51089 L .5528 .50854 L F
.803 .793 .843 r
.71731 .41506 m .72067 .4152 L .7195 .41348 L F
.774 .785 .862 r
.7195 .41348 m .72067 .4152 L .72348 .41249 L F
.76 .645 .735 r
.82574 .42381 m .82705 .42748 L .82338 .42686 L F
.692 .61 .76 r
.82961 .42474 m .82705 .42748 L .82574 .42381 L F
.609 .356 .509 r
.69225 .41487 m .69487 .41235 L .69257 .41237 L F
.69225 .41487 m .69492 .41457 L .69487 .41235 L F
.52 .267 .471 r
.69492 .41457 m .69749 .41198 L .69487 .41235 L F
.757 .543 .607 r
.68873 .41453 m .69257 .41237 L .68894 .41197 L F
.68873 .41453 m .69225 .41487 L .69257 .41237 L F
.842 .879 .868 r
.663 .43909 m .66062 .44151 L .65942 .44026 L F
.567 .878 .993 r
.19903 .54173 m .19536 .54195 L .19732 .54109 L F
.685 .969 .928 r
.19903 .54173 m .19949 .54029 L .20111 .54026 L F
.572 .88 .993 r
.19903 .54173 m .19732 .54109 L .19949 .54029 L F
.692 .685 .838 r
.81717 .41426 m .82085 .41494 L .8183 .41765 L F
.646 .607 .796 r
.82085 .41494 m .82183 .41859 L .8183 .41765 L F
.68 .555 .706 r
.82183 .41859 m .81969 .42144 L .8183 .41765 L F
.803 .613 .646 r
.59304 .49625 m .59529 .49703 L .59337 .49359 L F
.797 .653 .702 r
.51082 .52251 m .51377 .5207 L .51128 .52096 L F
.136 0 .065 r
.77921 .39935 m .78011 .3982 L .78229 .39686 L F
.447 .218 .473 r
.26769 .62608 m .26731 .62863 L .26511 .62914 L F
.441 .214 .471 r
.26946 .62807 m .26769 .62608 L .26988 .62555 L F
.26946 .62807 m .26731 .62863 L .26769 .62608 L F
.692 .938 .64 r
.54298 .57817 m .54137 .57941 L .54054 .58092 L F
.566 .045 0 r
.54192 .57688 m .54137 .57941 L .54298 .57817 L F
.54192 .57688 m .54512 .57987 L .54137 .57941 L F
.501 .806 .999 r
.54137 .57941 m .54386 .57885 L .54185 .57854 L F
.54137 .57941 m .54185 .57854 L .54061 .57835 L F
.692 .938 .64 r
.54054 .58092 m .54137 .57941 L .54001 .58152 L F
.89 .826 .356 r
.54137 .57941 m .54108 .58288 L .54001 .58152 L F
.76 .516 .564 r
.41245 .61415 m .416 .61687 L .41468 .61337 L F
.41245 .61415 m .41219 .61664 L .416 .61687 L F
.311 .002 .269 r
.4113 .59342 m .41307 .59411 L .41383 .59302 L F
.4113 .59342 m .41064 .59528 L .41307 .59411 L F
0 .117 .659 r
.40796 .63496 m .40858 .63372 L .40675 .63152 L F
0 .205 .725 r
.40796 .63496 m .41011 .63708 L .40858 .63372 L F
.694 .582 .725 r
.48606 .60796 m .48402 .61057 L .48345 .60912 L F
.642 .577 .766 r
.48327 .60786 m .48606 .60796 L .48507 .60448 L F
.694 .582 .725 r
.48391 .60733 m .48345 .60912 L .4826 .60694 L F
.48606 .60796 m .48345 .60912 L .48391 .60733 L F
.642 .577 .766 r
.48327 .60786 m .48423 .60606 L .48316 .60548 L F
.48423 .60606 m .48507 .60448 L .48456 .60474 L F
.48423 .60606 m .48456 .60474 L .48316 .60548 L F
.646 .599 .788 r
.81993 .43909 m .81744 .44014 L .81614 .43621 L F
.646 .813 .963 r
.81428 .42658 m .81077 .42676 L .81342 .42402 L F
.635 .488 .666 r
.81757 .42462 m .81428 .42658 L .81342 .42402 L F
.81757 .42462 m .81724 .42695 L .81428 .42658 L F
.696 .507 .628 r
.81724 .42695 m .81554 .42942 L .81428 .42658 L F
.498 .112 .239 r
.48016 .57873 m .47953 .58009 L .47673 .58035 L F
.48016 .57873 m .47953 .58009 L .47673 .58035 L F
.013 0 .012 r
.48234 .5773 m .47953 .58009 L .48016 .57873 L F
.48016 .57873 m .47953 .58009 L .48234 .5773 L F
.756 .3 .169 r
.42604 .65701 m .42489 .6563 L .42385 .65536 L F
.326 .039 .315 r
.42385 .65536 m .42151 .65615 L .42293 .65454 L F
.42385 .65536 m .42151 .65615 L .4237 .65367 L F
0 0 .279 r
.42214 .65805 m .42213 .65915 L .42151 .65615 L F
.797 .385 0 r
.42159 .65737 m .42214 .65805 L .42151 .65615 L F
.42271 .65638 m .42151 .65615 L .42385 .65536 L F
.42159 .65737 m .42153 .65641 L .42271 .65638 L F
.42153 .65641 m .42151 .65615 L .42271 .65638 L F
.42159 .65737 m .42385 .65536 L .42238 .65476 L F
.756 .3 .169 r
.42489 .6563 m .42238 .65476 L .42385 .65536 L F
.326 .039 .315 r
.42385 .65536 m .42293 .65454 L .4237 .65367 L F
.756 .3 .169 r
.42604 .65701 m .42457 .65717 L .42238 .65476 L F
.169 .26 .715 r
.42238 .65476 m .42382 .65634 L .4236 .65352 L F
.42382 .65634 m .42457 .65717 L .42435 .65633 L F
.686 .456 .568 r
.42702 .65283 m .42639 .65581 L .42385 .65536 L F
.622 .175 .17 r
.42639 .65581 m .42604 .65701 L .42385 .65536 L F
.169 .26 .715 r
.42382 .65634 m .42435 .65633 L .4236 .65352 L F
.948 .822 .686 r
.58997 .52497 m .58901 .52004 L .58686 .52266 L F
.58997 .52497 m .59042 .5211 L .58901 .52004 L F
.828 .402 .227 r
.58666 .5248 m .58997 .52497 L .58686 .52266 L F
.58666 .5248 m .58938 .52564 L .58997 .52497 L F
.48 .597 .893 r
.16807 .63395 m .16894 .63588 L .17028 .63377 L F
.413 .508 .847 r
.16894 .63588 m .17187 .63704 L .17028 .63377 L F
.308 .41 .803 r
.2591 .55256 m .25819 .55478 L .25596 .55621 L F
.26055 .55591 m .26103 .557 L .25838 .55493 L F
.693 .873 .966 r
.25804 .55816 m .26103 .557 L .25684 .55631 L F
.749 .684 .789 r
.2591 .55256 m .26091 .5544 L .26316 .55305 L F
.757 .658 .752 r
.26316 .55305 m .26103 .557 L .2591 .55256 L F
.539 .008 0 r
.26266 .55649 m .26103 .557 L .26279 .55643 L F
.26266 .55649 m .26279 .55643 L .26299 .55637 L F
.656 .179 .106 r
.26266 .55649 m .26137 .55761 L .2607 .55743 L F
.558 .861 .997 r
.26299 .55637 m .26103 .557 L .26316 .55305 L F
.539 .008 0 r
.26266 .55649 m .26004 .55684 L .26103 .557 L F
.26266 .55649 m .25684 .55631 L .26004 .55684 L F
.656 .179 .106 r
.26266 .55649 m .2607 .55743 L .25895 .55698 L F
.539 .008 0 r
.26179 .55647 m .25895 .55698 L .25684 .55631 L F
.26266 .55649 m .26204 .55658 L .26179 .55647 L F
.26204 .55658 m .25895 .55698 L .26179 .55647 L F
.308 .41 .803 r
.2591 .55256 m .26055 .55591 L .25819 .55478 L F
.26055 .55591 m .25838 .55493 L .25819 .55478 L F
.463 .481 .792 r
.26327 .56336 m .26629 .56513 L .26476 .56128 L F
.66 .58 .755 r
.48709 .58114 m .48957 .58101 L .48836 .5774 L F
.226 .455 .871 r
.78781 .39728 m .78962 .40021 L .79051 .3987 L F
.19 .407 .843 r
.78962 .40021 m .79249 .40185 L .79051 .3987 L F
.355 .16 .471 r
.29584 .58382 m .29556 .58643 L .29378 .58685 L F
.29584 .58382 m .29556 .58643 L .29378 .58685 L F
.45 .407 .719 r
.29614 .58877 m .29378 .58685 L .29556 .58643 L F
.416 .254 .551 r
.4361 .65045 m .43842 .65268 L .43834 .64965 L F
.996 .794 .514 r
.57483 .54164 m .5737 .54064 L .57404 .5381 L F
.993 .86 .598 r
.57483 .54164 m .5732 .54262 L .5737 .54064 L F
.57483 .54164 m .57405 .54495 L .5732 .54262 L F
.737 .978 .918 r
.74707 .39652 m .74557 .39759 L .74692 .39546 L F
0 0 0 r
.74557 .39759 m .74601 .39756 L .74692 .39546 L F
.74557 .39759 m .74481 .39942 L .74601 .39756 L F
.215 .478 .89 r
.83786 .42153 m .84097 .42293 L .84092 .42436 L F
.999 .789 .481 r
.84097 .42293 m .84175 .42648 L .84092 .42436 L F
0 0 0 r
.15035 .59559 m .15219 .59471 L .15432 .59519 L F
.723 .616 .738 r
.82183 .41859 m .82204 .42092 L .81969 .42144 L F
.697 .527 .654 r
.82204 .42092 m .81956 .42396 L .81969 .42144 L F
.82204 .42092 m .82372 .42456 L .81956 .42396 L F
.663 .62 .796 r
.82455 .41792 m .82204 .42092 L .82183 .41859 L F
.82455 .41792 m .82596 .42133 L .82204 .42092 L F
.682 .536 .68 r
.82204 .42092 m .82574 .42381 L .82372 .42456 L F
.82204 .42092 m .82596 .42133 L .82574 .42381 L F
.649 .545 .723 r
.49847 .59019 m .49943 .59342 L .50078 .59247 L F
.357 0 .212 r
.49836 .59504 m .50078 .59247 L .49943 .59342 L F
.082 .614 .866 r
.23222 .53784 m .23427 .53804 L .23609 .53862 L F
.139 .643 .905 r
.23658 .53811 m .23609 .53862 L .23427 .53804 L F
.23658 .53811 m .23823 .53879 L .23609 .53862 L F
.809 .865 .89 r
.44151 .57925 m .44249 .58047 L .44522 .57802 L F
.481 .222 .443 r
.26511 .62914 m .26451 .63197 L .26237 .63235 L F
.489 .249 .477 r
.26731 .62863 m .26451 .63197 L .26511 .62914 L F
.207 .439 .864 r
.65443 .44386 m .65511 .44418 L .653 .44098 L F
.54 .925 .833 r
.4253 .58028 m .4243 .58134 L .42643 .58009 L F
0 0 0 r
.58169 .57356 m .58044 .57522 L .58206 .57178 L F
0 0 .115 r
.58169 .57356 m .57973 .57738 L .58044 .57522 L F
0 0 0 r
.51992 .52064 m .52203 .51918 L .52326 .51758 L F
.484 .352 .625 r
.5258 .51979 m .52326 .51758 L .52203 .51918 L F
.5258 .51979 m .52584 .51705 L .52326 .51758 L F
.644 .722 .905 r
.73176 .40917 m .73537 .41023 L .73437 .40823 L F
.519 .594 .869 r
.73537 .41023 m .7369 .40767 L .73437 .40823 L F
.73537 .41023 m .7383 .41127 L .7369 .40767 L F
0 .09 .628 r
.41772 .65949 m .41922 .66138 L .41528 .65879 L F
.341 .364 .74 r
.17235 .63839 m .17259 .64045 L .1738 .63865 L F
.462 .23 .475 r
.79035 .4353 m .79293 .43541 L .79376 .43255 L F
0 0 0 r
.71668 .39711 m .71391 .39927 L .71605 .39883 L F
.179 0 .198 r
.71869 .39593 m .71668 .39711 L .71605 .39883 L F
.79 .602 .646 r
.58974 .49573 m .59337 .49359 L .5897 .49305 L F
.58974 .49573 m .59304 .49625 L .59337 .49359 L F
0 0 0 r
.15263 .58389 m .14873 .58673 L .14899 .5865 L F
.15263 .58389 m .15041 .58597 L .14873 .58673 L F
.035 0 0 r
.15215 .58532 m .15263 .58389 L .15302 .58327 L F
.15215 .58532 m .15041 .58597 L .15263 .58389 L F
.604 .492 .699 r
.47399 .59515 m .47452 .59812 L .47219 .5985 L F
.544 .285 .472 r
.47452 .59812 m .47143 .60135 L .47219 .5985 L F
.183 .01 .397 r
.49074 .60615 m .48911 .60522 L .49146 .60479 L F
.49074 .60615 m .48892 .60757 L .48911 .60522 L F
.604 .225 .296 r
.23066 .67699 m .2311 .6755 L .23174 .67739 L F
.444 .439 .759 r
.22994 .6791 m .23066 .67699 L .23174 .67739 L F
0 0 .106 r
.2326 .67353 m .23174 .67739 L .23067 .67421 L F
.2326 .67353 m .23235 .67615 L .23174 .67739 L F
.54 .878 .989 r
.23235 .67615 m .23066 .67699 L .23174 .67739 L F
.179 0 .25 r
.23235 .67615 m .23008 .67892 L .23066 .67699 L F
.23008 .67892 m .22994 .6791 L .23066 .67699 L F
.604 .225 .296 r
.23066 .67699 m .23067 .67421 L .2311 .6755 L F
.694 .923 .598 r
.23235 .67615 m .22994 .6791 L .23174 .67739 L F
.79 .564 .594 r
.19617 .72219 m .20048 .72087 L .20014 .71961 L F
.448 .305 .593 r
.20014 .71961 m .20221 .72189 L .20198 .71913 L F
.331 .284 .654 r
.20014 .71961 m .20048 .72087 L .20221 .72189 L F
.512 .512 .792 r
.22037 .66882 m .22329 .66969 L .2231 .66847 L F
.594 .605 .833 r
.73908 .4131 m .74159 .41232 L .7383 .41127 L F
.121 .549 .919 r
.76279 .43206 m .7651 .43347 L .76402 .43271 L F
0 .223 .649 r
.76402 .43271 m .7651 .43347 L .76809 .43526 L F
0 0 0 r
.43625 .56821 m .43866 .56769 L .44128 .56678 L F
.605 .124 .087 r
.44128 .56678 m .44236 .56782 L .44256 .56563 L F
.44128 .56678 m .43866 .56769 L .44236 .56782 L F
.758 .556 0 r
.53356 .59605 m .53381 .59868 L .53338 .59497 L F
.923 .596 .405 r
.81613 .44731 m .81516 .44758 L .81365 .44519 L F
.595 .059 0 r
.81613 .44731 m .81877 .44818 L .81516 .44758 L F
.82 .89 .893 r
.19789 .72306 m .20048 .72087 L .19617 .72219 L F
0 0 .502 r
.44083 .62944 m .44158 .62778 L .44022 .62585 L F
0 .009 .537 r
.44083 .62944 m .44296 .63173 L .44196 .63047 L F
.812 .589 .6 r
.67755 .4183 m .67408 .41996 L .67428 .4177 L F
.67755 .4183 m .6776 .42085 L .67408 .41996 L F
.54 .342 .56 r
.81421 .41218 m .81454 .41455 L .81174 .41528 L F
.569 .423 .643 r
.81681 .40893 m .81421 .41218 L .81334 .40883 L F
.81681 .40893 m .81694 .41171 L .81421 .41218 L F
.65 .487 .65 r
.81694 .41171 m .81454 .41455 L .81421 .41218 L F
.416 .171 .432 r
.25962 .58938 m .26144 .58915 L .26191 .58684 L F
.493 .317 .571 r
.26144 .58915 m .26403 .58583 L .26191 .58684 L F
0 0 .448 r
.77038 .4296 m .76957 .42796 L .76909 .42581 L F
.685 .876 .49 r
.26327 .57566 m .26184 .57765 L .26418 .57406 L F
.511 .028 .047 r
.7489 .37744 m .74978 .376 L .75251 .37719 L F
.524 .828 .505 r
.74978 .376 m .75269 .37299 L .75274 .37554 L F
.498 .146 .3 r
.74978 .376 m .75274 .37554 L .75251 .37719 L F
.694 .53 .661 r
.81969 .42144 m .81956 .42396 L .81757 .42462 L F
.921 .776 .684 r
.57843 .52107 m .57601 .52242 L .57673 .51993 L F
.57843 .52107 m .57774 .5235 L .57601 .52242 L F
.707 .326 .326 r
.44339 .64101 m .4419 .64322 L .43968 .64103 L F
.413 .862 .819 r
.44598 .63991 m .44426 .64036 L .44339 .64101 L F
.485 .172 .36 r
.44677 .64175 m .44288 .64275 L .44426 .64036 L F
0 0 0 r
.44358 .64154 m .4419 .64322 L .44339 .64101 L F
.485 .172 .36 r
.44288 .64275 m .44253 .64284 L .44358 .64154 L F
0 0 0 r
.44363 .64168 m .44302 .64223 L .44358 .64154 L F
.44302 .64223 m .4419 .64322 L .44358 .64154 L F
.485 .172 .36 r
.44358 .64154 m .4421 .64294 L .44426 .64036 L F
.347 0 .065 r
.4421 .64294 m .4419 .64322 L .44302 .64223 L F
.485 .172 .36 r
.44302 .64223 m .4421 .64294 L .44358 .64154 L F
.347 0 .065 r
.4421 .64294 m .44302 .64223 L .44363 .64168 L F
.485 .172 .36 r
.44253 .64284 m .4421 .64294 L .44302 .64223 L F
0 0 0 r
.44363 .64168 m .44358 .64154 L .44426 .64036 L F
.44358 .64154 m .44339 .64101 L .44426 .64036 L F
.58 .468 .691 r
.28942 .59899 m .28988 .60163 L .28746 .60204 L F
.464 .276 .54 r
.28948 .60398 m .28746 .60204 L .28988 .60163 L F
.28948 .60398 m .28732 .60459 L .28746 .60204 L F
.696 .333 0 r
.23042 .59276 m .2315 .59529 L .22992 .59184 L F
.669 .364 .447 r
.80127 .4393 m .80391 .44164 L .80167 .44126 L F
.632 .376 .513 r
.80382 .43918 m .80391 .44164 L .80127 .4393 L F
.732 .251 .102 r
.75136 .37407 m .75269 .37299 L .74916 .37207 L F
.091 .024 .48 r
.75386 .37551 m .75274 .37554 L .75269 .37299 L F
.786 .327 .152 r
.75386 .37551 m .75269 .37299 L .75136 .37407 L F
.902 .942 .825 r
.74481 .39942 m .7417 .40099 L .7441 .39977 L F
.74481 .39942 m .74277 .40194 L .7417 .40099 L F
.653 .911 .598 r
.74601 .39756 m .74481 .39942 L .7441 .39977 L F
.956 .659 .226 r
.57169 .55622 m .57055 .55283 L .57156 .55384 L F
.959 .9 .722 r
.5719 .54941 m .57156 .55384 L .57055 .55283 L F
.414 .22 .507 r
.26524 .55693 m .26703 .55863 L .26704 .55602 L F
.26524 .55693 m .26487 .55949 L .26703 .55863 L F
.559 .541 .791 r
.46582 .59918 m .46917 .60189 L .46839 .59853 L F
0 0 .157 r
.57999 .57999 m .57967 .58238 L .57857 .58395 L F
0 0 .297 r
.57967 .58238 m .57825 .5863 L .57857 .58395 L F
.716 .926 .591 r
.16263 .6074 m .15997 .61087 L .16016 .60817 L F
.355 .212 .545 r
.25962 .58938 m .26128 .59159 L .26144 .58915 L F
.25962 .58938 m .2594 .59277 L .26128 .59159 L F
.601 .375 .547 r
.47052 .62531 m .46806 .62312 L .47068 .62303 L F
.47052 .62531 m .46793 .62582 L .46806 .62312 L F
.815 .897 .482 r
.23951 .55622 m .23994 .55665 L .24231 .55685 L F
.23951 .55622 m .23865 .55862 L .23994 .55665 L F
.414 .258 .559 r
.41163 .65325 m .41327 .65303 L .41295 .65025 L F
0 .079 .631 r
.41259 .63416 m .41376 .63755 L .41221 .63492 L F
.583 .531 .763 r
.45151 .59272 m .45256 .59629 L .45491 .5957 L F
.639 .853 .469 r
.40678 .59955 m .40545 .60135 L .40771 .59814 L F
.53 .895 .971 r
.22353 .64757 m .2253 .64786 L .22747 .64704 L F
0 0 0 r
.83261 .43889 m .83179 .44032 L .82982 .44189 L F
.115 0 0 r
.83498 .43817 m .83179 .44032 L .83261 .43889 L F
.564 .553 .801 r
.18043 .64418 m .18143 .64036 L .1793 .64086 L F
.18043 .64418 m .18308 .64363 L .18143 .64036 L F
.126 0 0 r
.18043 .64418 m .18089 .64549 L .18308 .64363 L F
.18043 .64418 m .17879 .6465 L .18089 .64549 L F
.13 0 .015 r
.16642 .57118 m .16332 .57376 L .16457 .57124 L F
.728 .46 .521 r
.58591 .4875 m .58843 .48959 L .5886 .48733 L F
0 .235 .753 r
.53801 .5681 m .53983 .57084 L .53862 .5682 L F
.739 .658 .77 r
.82811 .42106 m .82455 .41792 L .82718 .41711 L F
.82811 .42106 m .82596 .42133 L .82455 .41792 L F
.715 .554 .67 r
.82811 .42106 m .82574 .42381 L .82596 .42133 L F
.82811 .42106 m .82961 .42474 L .82574 .42381 L F
.735 .755 .868 r
.82974 .41637 m .82811 .42106 L .82718 .41711 L F
.82974 .41637 m .83078 .41816 L .82811 .42106 L F
.671 .644 .814 r
.83078 .41816 m .832 .4212 L .82811 .42106 L F
.669 .519 .671 r
.832 .4212 m .82961 .42474 L .82811 .42106 L F
.717 .615 .742 r
.81342 .42402 m .81077 .42676 L .80959 .42347 L F
.542 .707 .947 r
.2882 .54701 m .28405 .54559 L .28691 .54553 L F
.355 .586 .931 r
.28916 .54542 m .2882 .54701 L .28691 .54553 L F
.28916 .54542 m .29016 .54721 L .2882 .54701 L F
.531 .343 .571 r
.25535 .59899 m .25769 .59854 L .25776 .59594 L F
.431 .217 .487 r
.2553 .60157 m .25769 .59854 L .25535 .59899 L F
.584 .471 .691 r
.81454 .41455 m .8121 .41794 L .81174 .41528 L F
.518 .497 .772 r
.80108 .42421 m .80257 .41992 L .8 .42049 L F
.80108 .42421 m .80319 .42271 L .80257 .41992 L F
.322 .116 .436 r
.80075 .42617 m .80319 .42271 L .80108 .42421 L F
.809 .493 .456 r
.82433 .43351 m .82138 .43419 L .82152 .43233 L F
.82433 .43351 m .8246 .43465 L .82138 .43419 L F
0 0 .559 r
.42385 .64045 m .42563 .64484 L .42541 .64247 L F
0 0 .409 r
.42563 .64484 m .42561 .64554 L .42541 .64247 L F
.384 .819 .958 r
.23823 .53879 m .2404 .53834 L .24216 .53877 L F
.488 .821 .999 r
.2404 .53834 m .24436 .53875 L .24216 .53877 L F
.636 .702 .894 r
.81462 .40514 m .81334 .40883 L .81205 .40553 L F
.81462 .40514 m .81603 .40808 L .81334 .40883 L F
.635 .682 .877 r
.81603 .40808 m .81681 .40893 L .81334 .40883 L F
.431 .705 .98 r
.27485 .54045 m .27423 .54207 L .27272 .54063 L F
.27485 .54045 m .27647 .54196 L .27423 .54207 L F
.34 .186 .521 r
.26443 .58384 m .2666 .58293 L .26668 .58037 L F
.422 .204 .475 r
.26403 .58583 m .2666 .58293 L .26443 .58384 L F
.742 .617 .721 r
.80985 .43623 m .81194 .44015 L .80774 .43907 L F
.771 .535 .578 r
.81194 .44015 m .80796 .44121 L .80774 .43907 L F
.81194 .44015 m .81199 .4417 L .80796 .44121 L F
.471 .735 .985 r
.65942 .44026 m .65748 .44085 L .65516 .43861 L F
.068 0 0 r
.1759 .566 m .17428 .56795 L .17262 .56826 L F
.294 0 .03 r
.17811 .56558 m .17428 .56795 L .1759 .566 L F
.354 .813 .933 r
.21274 .64879 m .21298 .64803 L .21119 .64808 L F
.21274 .64879 m .21576 .6483 L .21298 .64803 L F
.998 .79 .492 r
.75727 .38882 m .75845 .38797 L .75819 .39015 L F
.816 .924 .54 r
.76029 .38452 m .75845 .38797 L .75847 .38721 L F
.803 .966 .652 r
.75847 .38721 m .75845 .38797 L .75727 .38882 L F
.314 0 .125 r
.25619 .6372 m .25279 .63989 L .25415 .63792 L F
.835 .745 .765 r
.45532 .62872 m .45423 .62502 L .45512 .62611 L F
.517 .916 .885 r
.20048 .65033 m .20367 .64918 L .20271 .64878 L F
.573 .858 .996 r
.20367 .64918 m .20482 .64818 L .20271 .64878 L F
.20367 .64918 m .20697 .64879 L .20482 .64818 L F
.842 .879 .868 r
.663 .43909 m .65942 .44026 L .66185 .43795 L F
.839 .909 .885 r
.66577 .43632 m .663 .43909 L .66185 .43795 L F
.633 .644 .844 r
.21461 .68608 m .21586 .68213 L .21448 .68499 L F
.21461 .68608 m .21704 .68541 L .21586 .68213 L F
.137 .47 .893 r
.24902 .55362 m .25041 .55366 L .24905 .55215 L F
.24902 .55362 m .25041 .55366 L .24905 .55215 L F
.219 .187 .607 r
.49944 .52709 m .50025 .52908 L .5004 .52473 L F
.816 .924 .54 r
.76029 .38452 m .75847 .38721 L .76056 .38415 L F
0 0 0 r
.76249 .38077 m .76029 .38452 L .76056 .38415 L F
.756 .383 0 r
.50716 .57665 m .50876 .57997 L .5083 .57785 L F
.075 .306 .788 r
.773 .43152 m .77215 .43288 L .77038 .4296 L F
.091 .329 .804 r
.77463 .43456 m .77215 .43288 L .773 .43152 L F
.616 .409 .579 r
.56631 .48708 m .5699 .48674 L .56858 .48424 L F
.628 .441 .609 r
.56858 .48424 m .57234 .48414 L .57294 .48174 L F
.684 .5 .631 r
.5699 .48674 m .57234 .48414 L .56858 .48424 L F
0 0 0 r
.22818 .6284 m .22992 .62656 L .2271 .62866 L F
.177 0 0 r
.2321 .62596 m .22992 .62656 L .22818 .6284 L F
.639 .437 .593 r
.79376 .43255 m .79639 .4327 L .79589 .43025 L F
.488 .299 .55 r
.79589 .43025 m .79841 .42991 L .79834 .42689 L F
.5 .346 .604 r
.79589 .43025 m .79639 .4327 L .79841 .42991 L F
0 .051 .587 r
.41249 .64684 m .41295 .65025 L .41344 .64923 L F
0 0 .457 r
.41295 .65025 m .41473 .65135 L .41344 .64923 L F
.41295 .65025 m .41327 .65303 L .41473 .65135 L F
.49 .721 .974 r
.20697 .64879 m .20709 .64703 L .20482 .64818 L F
.20697 .64879 m .20905 .64859 L .20709 .64703 L F
.854 .84 .831 r
.55418 .58905 m .55754 .5877 L .55653 .58588 L F
.635 .647 .845 r
.55653 .58588 m .55754 .5877 L .55988 .58686 L F
.453 .572 .884 r
.55754 .5877 m .56078 .58934 L .55988 .58686 L F
.546 .7 .941 r
.78387 .4054 m .78487 .40747 L .78789 .40692 L F
.656 .752 .92 r
.78487 .40747 m .78817 .4074 L .78789 .40692 L F
.418 0 0 r
.51416 .60173 m .51222 .60328 L .50998 .60247 L F
.74 .628 .735 r
.51581 .59892 m .51416 .60173 L .51208 .5986 L F
.775 .352 .246 r
.51416 .60173 m .51566 .60421 L .51222 .60328 L F
.819 .338 .024 r
.51743 .60502 m .51566 .60421 L .51416 .60173 L F
.783 .57 .611 r
.45871 .58611 m .46226 .5837 L .45882 .58456 L F
.45871 .58611 m .4625 .58656 L .46226 .5837 L F
.52 .373 .621 r
.46226 .5837 m .46483 .58599 L .46469 .58329 L F
.46226 .5837 m .4625 .58656 L .46483 .58599 L F
.244 0 0 r
.45424 .62091 m .45711 .62173 L .45752 .62168 L F
.659 .239 .236 r
.45711 .62173 m .46054 .62054 L .45752 .62168 L F
.694 .825 .945 r
.74277 .40194 m .73925 .40167 L .7417 .40099 L F
.979 .725 .477 r
.23156 .57733 m .23005 .57882 L .22996 .57414 L F
.997 .842 .564 r
.23139 .58017 m .23012 .57889 L .23156 .57733 L F
.23012 .57889 m .23005 .57882 L .23013 .57874 L F
.23012 .57889 m .23013 .57874 L .23156 .57733 L F
.23135 .58082 m .23079 .57995 L .23139 .58017 L F
.23079 .57995 m .23005 .57882 L .23139 .58017 L F
.23135 .58082 m .23003 .5797 L .23005 .57882 L F
.802 .493 .467 r
.23006 .5797 m .23248 .58166 L .23362 .57968 L F
.23003 .5797 m .23006 .57972 L .23006 .5797 L F
.23006 .57972 m .23248 .58166 L .23006 .5797 L F
.252 .746 .912 r
.23362 .57968 m .23162 .57962 L .23005 .5797 L F
.23006 .5797 m .23005 .5797 L .23003 .5797 L F
.23362 .57968 m .23005 .5797 L .23006 .5797 L F
.466 .568 .874 r
.23154 .57385 m .23156 .57733 L .22996 .57414 L F
.23154 .57385 m .23449 .5771 L .23156 .57733 L F
0 .093 .65 r
.18103 .61887 m .18091 .62017 L .1793 .61719 L F
0 0 .341 r
.18178 .62121 m .18091 .62017 L .18103 .61887 L F
.18178 .62121 m .18136 .6227 L .18091 .62017 L F
.716 .865 .952 r
.75632 .39148 m .75293 .39148 L .75531 .39007 L F
.736 .873 .944 r
.75819 .39015 m .75632 .39148 L .75531 .39007 L F
.719 .45 .519 r
.46849 .58332 m .46819 .58702 L .46483 .58599 L F
.615 .603 .815 r
.46737 .5805 m .46849 .58332 L .47067 .58214 L F
.276 .394 .802 r
.46737 .5805 m .47017 .5823 L .46849 .58332 L F
0 0 .28 r
.46955 .58487 m .46849 .58332 L .47017 .5823 L F
.46955 .58487 m .46819 .58702 L .46849 .58332 L F
.417 .241 .533 r
.25776 .59594 m .2596 .59782 L .25973 .59531 L F
.403 .24 .544 r
.25776 .59594 m .25769 .59854 L .2596 .59782 L F
0 0 .477 r
.72805 .39812 m .72711 .39358 L .72798 .39575 L F
0 .148 .673 r
.72917 .3995 m .72805 .39812 L .72798 .39575 L F
.872 .722 .694 r
.52893 .52629 m .52804 .52347 L .53087 .5236 L F
.577 .344 .526 r
.53087 .5236 m .53021 .52726 L .52893 .52629 L F
.357 .27 .619 r
.39704 .61374 m .39871 .6132 L .3984 .6106 L F
.147 .102 .545 r
.39704 .61374 m .39859 .61569 L .39871 .6132 L F
.39704 .61374 m .39692 .61728 L .39859 .61569 L F
.162 .342 .797 r
.52804 .52347 m .5258 .51979 L .5281 .5206 L F
.599 .347 .506 r
.16132 .57441 m .15828 .57693 L .15912 .57531 L F
.605 .564 .782 r
.82341 .41416 m .82183 .41859 L .82085 .41494 L F
.82341 .41416 m .82455 .41792 L .82183 .41859 L F
.421 .083 .284 r
.53076 .51637 m .53405 .51328 L .53196 .51459 L F
.458 .506 .82 r
.16486 .63149 m .16509 .63282 L .16656 .63097 L F
.524 .547 .821 r
.16509 .63282 m .16807 .63395 L .16656 .63097 L F
.413 .219 .505 r
.44846 .62809 m .44657 .6265 L .4498 .62495 L F
.44846 .62809 m .44532 .62995 L .44657 .6265 L F
.684 .516 .654 r
.80739 .43647 m .80774 .43907 L .80382 .43918 L F
.661 .535 .699 r
.80896 .4327 m .80985 .43623 L .80739 .43647 L F
.656 .497 .656 r
.80985 .43623 m .80774 .43907 L .80739 .43647 L F
.849 .938 .882 r
.50945 .53005 m .50768 .53264 L .50885 .53178 L F
.531 .222 .388 r
.47649 .61067 m .47957 .61144 L .48016 .60804 L F
.877 .703 .663 r
.47957 .61144 m .4826 .60694 L .48016 .60804 L F
0 0 .051 r
.65639 .40904 m .65837 .40774 L .65868 .40588 L F
0 0 .065 r
.65868 .40588 m .66068 .40483 L .66141 .4026 L F
.102 0 .093 r
.65868 .40588 m .66029 .40665 L .66068 .40483 L F
.65868 .40588 m .65837 .40774 L .66029 .40665 L F
.997 .766 .437 r
.77101 .4122 m .77258 .4121 L .77153 .41001 L F
.77101 .4122 m .77219 .41424 L .77258 .4121 L F
.959 .631 .343 r
.77377 .41504 m .77258 .4121 L .77219 .41424 L F
.938 .934 .769 r
.77153 .41001 m .77258 .4121 L .77416 .40818 L F
.618 .927 .97 r
.20336 .72068 m .20688 .72066 L .20888 .71961 L F
.122 .57 .92 r
.77105 .38653 m .77069 .38572 L .77115 .38686 L F
.664 .111 0 r
.77094 .38775 m .77387 .38899 L .77105 .38653 L F
.77094 .38775 m .77105 .38653 L .77115 .38686 L F
.544 .304 .501 r
.43834 .64965 m .44132 .64929 L .43877 .64713 L F
.838 .978 .877 r
.21374 .70128 m .21653 .69981 L .21486 .69939 L F
.761 .631 .717 r
.5746 .48378 m .57851 .48438 L .57857 .4817 L F
.779 .548 .586 r
.5746 .48378 m .57835 .48694 L .57851 .48438 L F
.511 .264 .476 r
.4937 .6015 m .4938 .60439 L .49146 .60479 L F
.463 .34 .626 r
.49616 .59822 m .4937 .6015 L .49369 .59856 L F
.49616 .59822 m .49628 .60104 L .4937 .6015 L F
.554 .362 .575 r
.49628 .60104 m .4938 .60439 L .4937 .6015 L F
.932 .764 .652 r
.58784 .53138 m .59058 .52888 L .5885 .52884 L F
.58784 .53138 m .58986 .53268 L .59058 .52888 L F
0 0 0 r
.58255 .57022 m .58169 .57356 L .58206 .57178 L F
.617 .212 .252 r
.49245 .60036 m .49369 .59856 L .48992 .59911 L F
.517 .335 .573 r
.49369 .59856 m .49616 .59822 L .49655 .5952 L F
.767 .576 .64 r
.49245 .60036 m .49616 .59822 L .49369 .59856 L F
.517 .335 .573 r
.49369 .59856 m .49616 .59822 L .49655 .5952 L F
.137 0 0 r
.78817 .4074 m .78974 .40711 L .79012 .40748 L F
.78817 .4074 m .79012 .40748 L .78789 .40692 L F
.717 .239 .114 r
.19441 .74158 m .19178 .74084 L .1939 .74003 L F
.741 .702 .815 r
.19178 .74084 m .19441 .74158 L .1939 .74003 L F
.771 .623 .696 r
.23589 .60825 m .23564 .61086 L .23694 .60847 L F
.445 .218 .474 r
.2986 .58235 m .29556 .58643 L .29584 .58382 L F
.368 .072 .325 r
.70597 .4084 m .70364 .40929 L .70339 .41107 L F
.984 .713 .336 r
.22296 .68343 m .22282 .68581 L .22211 .68392 L F
.039 0 .331 r
.2233 .68302 m .22211 .68392 L .2232 .68373 L F
.74 .992 .846 r
.22199 .68327 m .22296 .68343 L .22347 .68176 L F
.846 .851 .847 r
.21916 .6835 m .22005 .68508 L .22296 .68343 L F
.773 .952 .626 r
.22296 .68343 m .22211 .68392 L .22347 .68176 L F
.039 0 .331 r
.22347 .68176 m .22257 .6832 L .2233 .68302 L F
.22257 .6832 m .22211 .68392 L .2233 .68302 L F
.846 .851 .847 r
.21916 .6835 m .22152 .68346 L .22199 .68327 L F
.22152 .68346 m .22296 .68343 L .22216 .6833 L F
.22152 .68346 m .22216 .6833 L .22199 .68327 L F
.662 .366 .46 r
.22514 .68557 m .22296 .68343 L .22581 .68294 L F
.22514 .68557 m .22282 .68581 L .22296 .68343 L F
.098 .207 .69 r
.41528 .65879 m .41466 .6552 L .41573 .65621 L F
.298 0 0 r
.21673 .55242 m .21183 .55481 L .21391 .55365 L F
.779 .737 .814 r
.82606 .43672 m .82259 .43637 L .8246 .43465 L F
.782 .754 .828 r
.47354 .58051 m .47466 .58298 L .47673 .58035 L F
.713 .629 .762 r
.40989 .61932 m .41119 .62304 L .41539 .62152 L F
.339 0 0 r
.48427 .5591 m .48699 .56016 L .48754 .56005 L F
.429 0 0 r
.48699 .56016 m .49051 .56131 L .48754 .56005 L F
0 0 0 r
.22818 .6284 m .2271 .62866 L .22583 .62905 L F
.357 0 .212 r
.49836 .59504 m .50096 .59439 L .50078 .59247 L F
.513 .496 .775 r
.50078 .59247 m .50414 .59175 L .50299 .5892 L F
.707 .256 .179 r
.50078 .59247 m .50324 .59461 L .50414 .59175 L F
.50078 .59247 m .50096 .59439 L .50324 .59461 L F
0 0 .381 r
.65639 .40904 m .6578 .40951 L .65837 .40774 L F
.717 .529 .635 r
.57294 .48174 m .57234 .48414 L .57468 .48135 L F
.69 .49 .612 r
.57468 .48135 m .57234 .48414 L .5746 .48378 L F
.761 .631 .717 r
.5746 .48378 m .57857 .4817 L .57468 .48135 L F
.858 .997 .797 r
.75974 .37892 m .76128 .37601 L .75974 .37673 L F
.75974 .37892 m .76165 .37665 L .76128 .37601 L F
.389 .372 .719 r
.75974 .37892 m .76128 .37601 L .75974 .37673 L F
.75974 .37892 m .76249 .38077 L .76128 .37601 L F
.517 .133 .251 r
.44886 .63844 m .44598 .63991 L .44547 .63979 L F
.44886 .63844 m .44829 .6401 L .44598 .63991 L F
.574 .368 .564 r
.45138 .63723 m .44829 .6401 L .44886 .63844 L F
.483 .581 .877 r
.8115 .40343 m .80967 .40572 L .80818 .40294 L F
.8115 .40343 m .81205 .40553 L .80967 .40572 L F
.93 .725 .241 r
.23466 .59104 m .23513 .58972 L .23448 .58906 L F
.695 .158 0 r
.51316 .58826 m .51317 .58687 L .51203 .5857 L F
.51316 .58826 m .51374 .58849 L .51317 .58687 L F
0 0 .368 r
.20839 .6998 m .20849 .7016 L .209 .7001 L F
.351 .641 .963 r
.20849 .7016 m .21109 .70197 L .209 .7001 L F
.525 .261 .457 r
.47166 .61387 m .47421 .61349 L .47466 .61124 L F
.473 .215 .441 r
.47466 .61124 m .47662 .6129 L .47649 .61067 L F
.47466 .61124 m .47421 .61349 L .47662 .6129 L F
.698 .554 .687 r
.8121 .41794 m .80973 .42103 L .80961 .41845 L F
.805 .315 0 r
.48559 .57161 m .4869 .57361 L .48911 .57462 L F
.788 .756 .824 r
.48452 .5744 m .48911 .57462 L .4869 .57361 L F
.086 .578 .899 r
.48911 .57462 m .48921 .57366 L .4869 .57361 L F
0 .404 .702 r
.4869 .57361 m .49036 .57468 L .48911 .57462 L F
.617 .563 .771 r
.48836 .5774 m .49036 .57468 L .48911 .57462 L F
.413 .134 .376 r
.40857 .59602 m .41042 .59743 L .41064 .59528 L F
.40857 .59602 m .40771 .59814 L .41042 .59743 L F
0 0 0 r
.4125 .61916 m .416 .61687 L .41219 .61664 L F
.4125 .61916 m .4148 .61826 L .416 .61687 L F
.557 .05 0 r
.41694 .61805 m .416 .61687 L .4148 .61826 L F
.41694 .61805 m .41837 .61939 L .416 .61687 L F
.317 0 .154 r
.79794 .44336 m .7957 .44289 L .79811 .4423 L F
.79794 .44336 m .79534 .44415 L .7957 .44289 L F
.447 .694 .971 r
.77666 .43433 m .7755 .4361 L .77463 .43456 L F
.027 .217 .723 r
.77768 .43658 m .7755 .4361 L .77666 .43433 L F
.77768 .43658 m .77771 .43811 L .7755 .4361 L F
.737 .73 .845 r
.74803 .41431 m .74886 .41751 L .75185 .4149 L F
.315 .805 .806 r
.50749 .52558 m .50622 .52623 L .50845 .52578 L F
.50749 .52558 m .505 .52636 L .50622 .52623 L F
.781 .669 .74 r
.41376 .63755 m .41756 .63807 L .41844 .63405 L F
.747 .226 0 r
.41376 .63755 m .41763 .6405 L .41756 .63807 L F
.691 .43 .523 r
.58225 .48975 m .58591 .4875 L .58218 .48724 L F
.58225 .48975 m .58593 .48983 L .58591 .4875 L F
.728 .46 .521 r
.58591 .4875 m .58593 .48983 L .58843 .48959 L F
.537 .3 .503 r
.46189 .62608 m .4618 .62857 L .45933 .6288 L F
.327 0 .01 r
.4678 .62623 m .4618 .62857 L .46189 .62608 L F
.596 .25 .353 r
.45556 .58566 m .45871 .58611 L .45882 .58456 L F
.336 0 0 r
.2201 .55316 m .21841 .55299 L .21859 .55283 L F
.519 .903 .948 r
.22055 .55213 m .21841 .55299 L .2201 .55316 L F
.349 0 0 r
.22055 .55213 m .21814 .55323 L .21841 .55299 L F
.519 .387 .641 r
.21944 .55394 m .21838 .55601 L .21774 .5542 L F
.349 0 0 r
.21521 .55458 m .2169 .55443 L .21455 .55488 L F
.2169 .55443 m .21604 .55468 L .21455 .55488 L F
.22055 .55213 m .21936 .55396 L .21521 .55458 L F
.21814 .55323 m .21521 .55458 L .21841 .55299 L F
.21521 .55458 m .21492 .5547 L .21841 .55299 L F
.05 0 0 r
.21841 .55299 m .21397 .55448 L .21673 .55242 L F
.21841 .55299 m .21455 .55488 L .21397 .55448 L F
.782 .633 .696 r
.21774 .5542 m .21838 .55601 L .21491 .55499 L F
.349 0 0 r
.21936 .55396 m .21917 .55424 L .21521 .55458 L F
.21521 .55458 m .21455 .55488 L .21492 .5547 L F
.646 .44 .59 r
.21455 .55488 m .21604 .55468 L .21732 .55301 L F
.782 .633 .696 r
.21732 .55301 m .21774 .5542 L .21609 .55461 L F
.349 0 0 r
.2169 .55443 m .21917 .55424 L .21604 .55468 L F
.519 .387 .641 r
.22002 .55283 m .21944 .55394 L .21753 .5536 L F
.21944 .55394 m .21774 .5542 L .21753 .5536 L F
.21926 .55288 m .21753 .5536 L .21732 .55301 L F
.22002 .55283 m .21753 .5536 L .21926 .55288 L F
.646 .44 .59 r
.21604 .55468 m .21917 .55424 L .21732 .55301 L F
.782 .633 .696 r
.21732 .55301 m .21609 .55461 L .21476 .55495 L F
.21774 .5542 m .21491 .55499 L .21476 .55495 L F
.336 0 0 r
.21859 .55283 m .21841 .55299 L .21673 .55242 L F
.41 .809 .984 r
.22242 .55278 m .22055 .55213 L .2201 .55316 L F
.781 .294 .064 r
.23135 .58082 m .22935 .58169 L .23003 .5797 L F
.836 .696 .708 r
.22935 .58169 m .23085 .58529 L .23194 .58286 L F
.781 .294 .064 r
.23135 .58082 m .23148 .58265 L .22935 .58169 L F
.863 .418 .033 r
.23338 .5836 m .23157 .58271 L .23135 .58082 L F
.849 .992 .739 r
.23338 .5836 m .23085 .58529 L .23148 .58267 L F
.792 .64 .693 r
.23248 .58166 m .23468 .58562 L .23338 .5836 L F
.23248 .58166 m .23185 .58306 L .23468 .58562 L F
.23185 .58306 m .23085 .58529 L .23387 .58555 L F
.23185 .58306 m .23387 .58555 L .23468 .58562 L F
.863 .418 .033 r
.23157 .58271 m .2315 .58268 L .2315 .58263 L F
.23157 .58271 m .2315 .58263 L .23135 .58082 L F
.2315 .58268 m .23148 .58267 L .23148 .58265 L F
.2315 .58268 m .23148 .58265 L .23135 .58082 L F
.836 .696 .708 r
.2306 .58168 m .23194 .58286 L .23248 .58166 L F
.22935 .58169 m .23148 .58265 L .2306 .58168 L F
.23148 .58265 m .23194 .58286 L .2306 .58168 L F
.781 .294 .064 r
.23148 .58265 m .23148 .58267 L .22935 .58169 L F
.536 .884 .645 r
.17808 .54779 m .17782 .54763 L .18035 .54748 L F
.17808 .54779 m .17605 .54916 L .17782 .54763 L F
.593 .118 .095 r
.56773 .50737 m .56385 .50608 L .56766 .50543 L F
.683 .337 .382 r
.56766 .50543 m .56998 .50768 L .56773 .50737 L F
.511 .37 .625 r
.29771 .56572 m .2979 .56814 L .29568 .56865 L F
.508 .459 .737 r
.29872 .57048 m .29568 .56865 L .2979 .56814 L F
.289 .734 .962 r
.56293 .57645 m .56377 .57712 L .56258 .5772 L F
.56293 .57645 m .56258 .5772 L .56139 .57727 L F
0 0 0 r
.56178 .57799 m .56293 .57645 L .55991 .57915 L F
.651 .848 .45 r
.56178 .57799 m .56325 .57575 L .56293 .57645 L F
.56325 .57575 m .56391 .57475 L .56293 .57645 L F
.289 .734 .962 r
.56293 .57645 m .56139 .57727 L .55991 .57915 L F
.179 0 0 r
.24616 .55655 m .2446 .55706 L .24231 .55685 L F
0 0 0 r
.24624 .55659 m .24616 .55655 L .24822 .55693 L F
.24624 .55659 m .2446 .55706 L .24616 .55655 L F
.703 .963 .942 r
.7507 .39423 m .74707 .39652 L .74692 .39546 L F
.313 0 0 r
.45118 .56344 m .45342 .56391 L .45471 .56232 L F
.55 .1 .137 r
.45342 .56391 m .45723 .56247 L .45471 .56232 L F
.729 .98 .913 r
.52856 .53133 m .52879 .53139 L .52822 .53212 L F
.52711 .53214 m .52856 .53133 L .52822 .53212 L F
.811 .889 .9 r
.52695 .53051 m .52905 .53106 L .52711 .53214 L F
.692 .809 .937 r
.52711 .53214 m .5285 .53207 L .52695 .53051 L F
.119 .665 .821 r
.52822 .53212 m .52855 .532 L .52942 .53203 L F
.692 .809 .937 r
.52855 .532 m .52942 .53203 L .5288 .53165 L F
.119 .665 .821 r
.52855 .532 m .52882 .53191 L .52942 .53203 L F
.692 .809 .937 r
.5285 .53207 m .52942 .53203 L .52855 .532 L F
0 0 0 r
.52879 .53139 m .5288 .53165 L .52822 .53212 L F
.5288 .53165 m .52855 .532 L .52822 .53212 L F
.692 .809 .937 r
.5285 .53207 m .5288 .53165 L .52695 .53051 L F
0 0 0 r
.5288 .53165 m .52882 .53191 L .52855 .532 L F
.52905 .53106 m .52882 .53191 L .52879 .53139 L F
.726 .2 0 r
.5288 .53169 m .52882 .53191 L .52778 .53113 L F
.52942 .53203 m .52882 .53191 L .5288 .53169 L F
.52809 .53121 m .52778 .53113 L .52695 .53051 L F
.52942 .53203 m .52778 .53113 L .52809 .53121 L F
.729 .98 .913 r
.52856 .53133 m .52905 .53106 L .52879 .53139 L F
.07 .633 .738 r
.52822 .53212 m .52942 .53203 L .52711 .53214 L F
.393 .226 .533 r
.79834 .42689 m .80115 .42763 L .80075 .42617 L F
.79834 .42689 m .79841 .42991 L .80115 .42763 L F
.469 .364 .652 r
.48957 .58101 m .49173 .57774 L .48836 .5774 L F
.48957 .58101 m .49207 .58068 L .49173 .57774 L F
.123 0 .3 r
.48957 .58101 m .49132 .58184 L .49207 .58068 L F
.48957 .58101 m .48924 .58308 L .49132 .58184 L F
.814 .877 .892 r
.70628 .42344 m .70881 .42349 L .7081 .42218 L F
.843 .899 .877 r
.7081 .42218 m .70881 .42349 L .71182 .42064 L F
.781 .64 .705 r
.8198 .4263 m .82085 .43029 L .8171 .42967 L F
.729 .369 .369 r
.82085 .43029 m .81764 .43183 L .8171 .42967 L F
.82085 .43029 m .82152 .43233 L .81764 .43183 L F
.703 .593 .731 r
.82338 .42686 m .82085 .43029 L .8198 .4263 L F
.673 .129 0 r
.50553 .55063 m .50351 .55016 L .50278 .5498 L F
.805 .323 .059 r
.50553 .55063 m .50469 .55153 L .50351 .55016 L F
.803 .34 .133 r
.50919 .55342 m .5074 .55318 L .50553 .55063 L F
.337 0 .155 r
.43624 .59661 m .43788 .59457 L .43961 .59543 L F
.501 .561 .849 r
.43984 .59786 m .43624 .59661 L .43961 .59543 L F
.337 0 .155 r
.43624 .59661 m .43834 .59739 L .43788 .59457 L F
.43624 .59661 m .43587 .59816 L .43834 .59739 L F
.768 .971 .922 r
.69788 .42909 m .69851 .42997 L .69954 .42876 L F
.019 0 .168 r
.46116 .60984 m .46064 .61264 L .45873 .61373 L F
.167 0 .204 r
.46368 .60709 m .46311 .60986 L .46116 .60984 L F
.248 0 .243 r
.46261 .61195 m .46116 .60984 L .46311 .60986 L F
.46261 .61195 m .46064 .61264 L .46116 .60984 L F
.211 .61 .95 r
.23331 .64632 m .23367 .64439 L .2311 .64509 L F
.413 .733 .991 r
.23331 .64632 m .23742 .6471 L .23696 .64735 L F
.211 .61 .95 r
.23331 .64632 m .23696 .64735 L .23367 .64439 L F
.761 .271 .068 r
.48931 .56833 m .48704 .56748 L .48753 .56842 L F
.462 .063 .198 r
.66023 .41208 m .65933 .41405 L .65656 .41435 L F
.14 0 .293 r
.66198 .41087 m .66023 .41208 L .66279 .40856 L F
.432 .035 .184 r
.66267 .41316 m .66023 .41208 L .66198 .41087 L F
.66267 .41316 m .65933 .41405 L .66023 .41208 L F
.138 .163 .624 r
.39692 .61728 m .39896 .61828 L .39859 .61569 L F
.39692 .61728 m .39761 .6197 L .39896 .61828 L F
.517 .845 .998 r
.42678 .68029 m .42766 .67892 L .42918 .67983 L F
.42678 .68029 m .42517 .67957 L .42766 .67892 L F
.666 .22 .183 r
.42918 .67983 m .42517 .67957 L .42678 .68029 L F
.55 .261 .429 r
.70597 .4084 m .70884 .40807 L .70907 .40559 L F
.536 .344 .568 r
.70907 .40559 m .71137 .40512 L .71162 .40292 L F
.448 .162 .386 r
.70884 .40807 m .71137 .40512 L .70907 .40559 L F
.997 .849 .518 r
.51669 .59768 m .5181 .59585 L .51654 .59502 L F
.51669 .59768 m .51749 .59868 L .5181 .59585 L F
.29 0 0 r
.45072 .56392 m .45342 .56391 L .45118 .56344 L F
.38 0 0 r
.55674 .60913 m .55537 .60782 L .55773 .60723 L F
.679 .879 .502 r
.55537 .60782 m .55423 .60909 L .55433 .60909 L F
.38 0 0 r
.55674 .60913 m .55423 .60909 L .55537 .60782 L F
.511 .139 .271 r
.73769 .37915 m .74024 .38037 L .73779 .38021 L F
.73769 .37915 m .74133 .37821 L .74024 .38037 L F
.64 .223 .237 r
.22213 .67814 m .22379 .67938 L .22528 .67786 L F
.777 .674 .75 r
.22379 .67938 m .22785 .67751 L .22528 .67786 L F
.173 0 .01 r
.50119 .60792 m .49828 .60996 L .49927 .60859 L F
.49927 .60859 m .49828 .60996 L .50119 .60792 L F
.923 .702 .585 r
.59133 .50745 m .59117 .51053 L .59287 .50855 L F
.967 .811 .636 r
.59287 .50855 m .59029 .51343 L .59119 .51416 L F
.59287 .50855 m .59117 .51053 L .59029 .51343 L F
0 0 0 r
.58458 .55869 m .58389 .56098 L .58309 .56268 L F
0 0 .158 r
.58371 .56335 m .58309 .56268 L .58389 .56098 L F
.58371 .56335 m .58295 .5651 L .58309 .56268 L F
.735 .324 .269 r
.66791 .40754 m .67096 .40636 L .66766 .40512 L F
.66791 .40754 m .67151 .40811 L .67096 .40636 L F
.746 .331 .261 r
.67096 .40636 m .67151 .40811 L .67505 .40862 L F
.62 .241 .303 r
.48488 .58974 m .48463 .59142 L .48223 .59097 L F
.212 .16 .579 r
.48649 .586 m .48687 .58881 L .48488 .58974 L F
.028 0 .159 r
.48687 .58881 m .48463 .59142 L .48488 .58974 L F
.609 .078 0 r
.40517 .62613 m .40094 .62543 L .4026 .62643 L F
.595 .319 .467 r
.4026 .62643 m .40462 .62852 L .40517 .62613 L F
.894 .701 .635 r
.67114 .41241 m .67077 .41493 L .66875 .41357 L F
.854 .511 .402 r
.42415 .6682 m .422 .67143 L .42213 .6682 L F
.553 .907 .968 r
.42515 .66691 m .42415 .6682 L .42213 .6682 L F
0 0 0 r
.42415 .6682 m .422 .67143 L .42515 .66691 L F
.467 0 0 r
.26277 .53878 m .26668 .53998 L .26442 .54047 L F
0 0 0 r
.26528 .57204 m .26418 .57406 L .26649 .57071 L F
.001 0 0 r
.50289 .53906 m .50151 .54052 L .50275 .53873 L F
.847 .434 .254 r
.50281 .53902 m .50151 .54052 L .50289 .53906 L F
0 0 0 r
.50277 .53907 m .50151 .54052 L .50278 .53959 L F
.50275 .53873 m .50151 .54052 L .50277 .53907 L F
.278 .761 .923 r
.49506 .53716 m .49757 .53694 L .49925 .53726 L F
.847 .434 .254 r
.49757 .53694 m .50151 .54052 L .50281 .53902 L F
.595 .023 0 r
.49757 .53694 m .50281 .53902 L .49925 .53726 L F
.50281 .53902 m .50289 .53906 L .50281 .53902 L F
.50281 .53902 m .50281 .53902 L .49925 .53726 L F
0 0 0 r
.50281 .53902 m .50278 .53959 L .50289 .53951 L F
.50275 .53873 m .50278 .53959 L .50281 .53902 L F
.542 0 0 r
.50281 .53902 m .50289 .53906 L .50275 .53873 L F
0 0 0 r
.50275 .53873 m .50289 .53951 L .50397 .53873 L F
.542 0 0 r
.49925 .53726 m .50281 .53902 L .50275 .53873 L F
0 0 .087 r
.50275 .53873 m .50444 .53802 L .50506 .53559 L F
0 0 0 r
.50275 .53873 m .50397 .53873 L .50444 .53802 L F
.68 .545 .694 r
.80973 .42103 m .80959 .42347 L .80729 .42415 L F
0 .083 .641 r
.5158 .56016 m .51694 .56144 L .51521 .55855 L F
.772 .395 .341 r
.50506 .53559 m .50444 .53802 L .50679 .53766 L F
.234 0 .102 r
.23742 .6471 m .23574 .64879 L .23626 .64888 L F
.361 .589 .931 r
.80509 .40118 m .80728 .40144 L .80579 .4029 L F
.408 .667 .966 r
.80728 .40144 m .80818 .40294 L .80579 .4029 L F
.594 .493 .708 r
.81253 .43557 m .80896 .4327 L .81155 .43233 L F
.81253 .43557 m .80985 .43623 L .80896 .4327 L F
.936 .907 .768 r
.76587 .41068 m .76554 .40803 L .76674 .40932 L F
.76587 .41068 m .76367 .41121 L .76554 .40803 L F
.923 .84 .745 r
.76587 .41068 m .76262 .41296 L .76367 .41121 L F
.76587 .41068 m .76379 .41441 L .76262 .41296 L F
.347 .149 .463 r
.7139 .40212 m .71605 .39883 L .71391 .39927 L F
.871 .957 .859 r
.66577 .43632 m .66614 .43425 L .66804 .43405 L F
.457 .266 .533 r
.66614 .43425 m .66889 .43328 L .66804 .43405 L F
.669 .519 .671 r
.832 .4212 m .83186 .42369 L .82961 .42474 L F
.715 .721 .854 r
.83334 .41738 m .832 .4212 L .83078 .41816 L F
.83334 .41738 m .83477 .42068 L .832 .4212 L F
.775 .671 .749 r
.83477 .42068 m .83186 .42369 L .832 .4212 L F
.279 .758 .93 r
.24436 .53875 m .2467 .53852 L .24825 .53894 L F
.294 .734 .965 r
.24886 .53809 m .24825 .53894 L .2467 .53852 L F
.24886 .53809 m .25049 .53886 L .24825 .53894 L F
.917 .707 .604 r
.51428 .59114 m .51654 .59502 L .51535 .59269 L F
.304 .774 .936 r
.2054 .53888 m .20971 .53911 L .20748 .53943 L F
.188 0 .179 r
.23514 .62282 m .23677 .62222 L .23808 .61967 L F
.329 0 .039 r
.23677 .62222 m .24075 .61992 L .23808 .61967 L F
.832 .496 .418 r
.50579 .58302 m .50374 .58347 L .50267 .58226 L F
.783 .496 .502 r
.50579 .58302 m .50565 .58596 L .50202 .58554 L F
.923 .586 .383 r
.76458 .38062 m .76573 .37893 L .76387 .37782 L F
.858 .481 .334 r
.76458 .38062 m .76655 .38079 L .76573 .37893 L F
.467 .206 .435 r
.48166 .58685 m .48338 .58869 L .48392 .58645 L F
.48166 .58685 m .48138 .58941 L .48338 .58869 L F
.7 .548 .678 r
.81956 .42396 m .81724 .42695 L .81757 .42462 L F
.7 .549 .678 r
.8198 .4263 m .81724 .42695 L .81956 .42396 L F
.707 .577 .707 r
.82372 .42456 m .8198 .4263 L .81956 .42396 L F
.686 .978 .816 r
.46609 .60493 m .46368 .60709 L .46654 .60484 L F
.346 .019 .26 r
.46517 .60922 m .46368 .60709 L .46609 .60493 L F
.46517 .60922 m .46311 .60986 L .46368 .60709 L F
.921 .691 .573 r
.77294 .4177 m .77377 .41504 L .77219 .41424 L F
0 0 0 r
.5004 .52473 m .50122 .52489 L .50227 .52275 L F
.364 0 .028 r
.50227 .52275 m .50344 .52436 L .5047 .52232 L F
.50227 .52275 m .50122 .52489 L .50344 .52436 L F
.661 .778 .935 r
.65702 .44433 m .65836 .44609 L .66082 .445 L F
.625 .718 .914 r
.83605 .41695 m .83477 .42068 L .83334 .41738 L F
.83605 .41695 m .83738 .41959 L .83477 .42068 L F
.615 .664 .874 r
.83738 .41959 m .83786 .42153 L .83477 .42068 L F
.469 .272 .53 r
.44991 .57414 m .44749 .57719 L .44832 .57523 L F
0 .037 .594 r
.77813 .44808 m .77886 .44697 L .77718 .44446 L F
0 .189 .713 r
.77813 .44808 m .78007 .44861 L .77886 .44697 L F
.77813 .44808 m .78048 .45066 L .78007 .44861 L F
.874 .436 .131 r
.43862 .57886 m .43764 .57949 L .43675 .57818 L F
.888 .908 .835 r
.43862 .57886 m .44039 .574 L .44025 .57413 L F
.43862 .57886 m .43675 .57818 L .44039 .574 L F
.269 .772 .867 r
.44151 .57925 m .43764 .57949 L .43862 .57886 L F
.694 .606 .753 r
.21704 .68541 m .21895 .68928 L .22005 .68508 L F
.937 .912 .529 r
.22005 .68508 m .21895 .68928 L .21848 .68794 L F
0 .288 .778 r
.21895 .68928 m .21962 .68959 L .21848 .68794 L F
.586 .864 .995 r
.66589 .44132 m .66678 .44227 L .66936 .44145 L F
0 0 0 r
.46257 .57014 m .46088 .57036 L .45847 .57065 L F
.05 0 0 r
.46434 .57015 m .46088 .57036 L .46257 .57014 L F
.281 0 .041 r
.46531 .56907 m .46434 .57015 L .46257 .57014 L F
.853 .404 .004 r
.49279 .5446 m .49142 .54366 L .49026 .54136 L F
.907 .558 .367 r
.494 .54678 m .49142 .54366 L .49279 .5446 L F
.036 .605 .754 r
.29016 .54721 m .29245 .54722 L .29407 .54732 L F
0 .332 .791 r
.29428 .54674 m .29407 .54732 L .29245 .54722 L F
.29428 .54674 m .29623 .54862 L .29407 .54732 L F
.549 .669 .916 r
.18601 .6214 m .18523 .62378 L .18364 .62271 L F
.18601 .6214 m .18757 .6233 L .18523 .62378 L F
.997 .846 .514 r
.55512 .5777 m .55454 .58066 L .55373 .57924 L F
.513 .067 .129 r
.55373 .57924 m .55736 .57771 L .55512 .5777 L F
.688 .42 .512 r
.80796 .44121 m .80382 .43918 L .80774 .43907 L F
.80796 .44121 m .80391 .44164 L .80382 .43918 L F
.373 .015 .221 r
.66141 .4026 m .66265 .40415 L .66344 .40321 L F
.66141 .4026 m .66068 .40483 L .66265 .40415 L F
0 0 0 r
.57459 .59588 m .5734 .59739 L .5718 .59868 L F
.5734 .59739 m .57091 .60044 L .5718 .59868 L F
.585 .302 .452 r
.45174 .62325 m .45273 .62552 L .4498 .62495 L F
.564 .292 .462 r
.45423 .62502 m .45273 .62552 L .45174 .62325 L F
.89 .825 .354 r
.40667 .61384 m .40636 .61549 L .4069 .6151 L F
.909 .851 .401 r
.4069 .6151 m .40605 .62114 L .4062 .61586 L F
.89 .825 .354 r
.40636 .61549 m .40605 .61712 L .4069 .6151 L F
.511 .846 .565 r
.40757 .61462 m .4069 .6151 L .4062 .61586 L F
.40935 .61302 m .4069 .6151 L .40757 .61462 L F
.877 .703 .663 r
.47957 .61144 m .48344 .61003 L .4826 .60694 L F
.517 .039 .059 r
.48165 .61223 m .48344 .61003 L .47957 .61144 L F
.109 .277 .755 r
.48344 .61003 m .48458 .60834 L .4826 .60694 L F
.585 .069 0 r
.48402 .61057 m .48619 .61123 L .48557 .61242 L F
.635 .498 .678 r
.48606 .60796 m .48733 .61072 L .48402 .61057 L F
.635 .476 .65 r
.48733 .61072 m .48619 .61123 L .48402 .61057 L F
.109 .277 .755 r
.48344 .61003 m .48556 .61167 L .48458 .60834 L F
.644 .129 .004 r
.48557 .61242 m .48344 .61003 L .48165 .61223 L F
.48557 .61242 m .48556 .61167 L .48344 .61003 L F
.94 .911 .763 r
.57774 .5235 m .57486 .52581 L .57601 .52242 L F
.57774 .5235 m .57616 .5266 L .57486 .52581 L F
.286 .463 .86 r
.43816 .6222 m .44022 .62585 L .44112 .62409 L F
0 0 .492 r
.44022 .62585 m .44158 .62778 L .44112 .62409 L F
.968 .714 .495 r
.44022 .62585 m .43774 .62469 L .43816 .6222 L F
.874 .906 .496 r
.58607 .55262 m .58702 .55081 L .58591 .55213 L F
.889 .83 .362 r
.58708 .54824 m .58702 .55081 L .58771 .54661 L F
.928 .894 .487 r
.58591 .55213 m .58702 .55081 L .58708 .54824 L F
.789 .671 .121 r
.52541 .54715 m .52513 .54867 L .52519 .55028 L F
.728 .675 .128 r
.52569 .5447 m .52513 .54867 L .52541 .54715 L F
.713 .629 .762 r
.40989 .61932 m .41539 .62152 L .4125 .61916 L F
.968 .882 .499 r
.41539 .62152 m .4148 .61826 L .4125 .61916 L F
.41539 .62152 m .41414 .62128 L .4148 .61826 L F
.259 .299 .714 r
.41345 .62507 m .41414 .62128 L .41539 .62152 L F
0 0 0 r
.41737 .62252 m .41345 .62507 L .41539 .62152 L F
.918 .85 .761 r
.57536 .53153 m .57684 .53263 L .57513 .53604 L F
.475 .24 .477 r
.24567 .61385 m .24791 .61335 L .24829 .61095 L F
.454 .222 .471 r
.24829 .61095 m .25014 .61279 L .25051 .61033 L F
.24829 .61095 m .24791 .61335 L .25014 .61279 L F
.567 .851 .997 r
.73205 .39906 m .73278 .40001 L .73039 .40021 L F
.46 .637 .932 r
.73436 .39807 m .73278 .40001 L .73205 .39906 L F
.73436 .39807 m .73523 .39997 L .73278 .40001 L F
.569 .483 .719 r
.29614 .58877 m .29685 .59223 L .29457 .59267 L F
.355 .082 .355 r
.29598 .59417 m .29457 .59267 L .29685 .59223 L F
.29598 .59417 m .29392 .59496 L .29457 .59267 L F
.35 .075 .349 r
.83705 .43272 m .83442 .43759 L .83405 .43522 L F
.437 .788 .997 r
.81516 .44758 m .81877 .44818 L .81839 .44723 L F
.658 .928 .973 r
.81839 .44723 m .81877 .44818 L .82097 .44694 L F
.378 .843 .861 r
.68967 .43257 m .69169 .43166 L .68951 .43293 L F
.68967 .43257 m .69218 .43175 L .69169 .43166 L F
0 0 0 r
.14693 .56533 m .14855 .56465 L .14987 .56286 L F
.139 0 0 r
.14855 .56465 m .152 .56224 L .14987 .56286 L F
.409 .138 .387 r
.14987 .56286 m .152 .56224 L .15288 .56055 L F
0 .224 .743 r
.49184 .5624 m .49413 .56446 L .49338 .56485 L F
0 .288 .787 r
.49413 .56446 m .49604 .56701 L .49338 .56485 L F
0 .107 .661 r
.45637 .59964 m .45774 .60205 L .45751 .60129 L F
.988 .896 .611 r
.45774 .60205 m .45649 .60443 L .45751 .60129 L F
.704 .52 .637 r
.45751 .60129 m .45649 .60443 L .45964 .60439 L F
.45751 .60129 m .45964 .60439 L .46091 .60437 L F
0 .107 .661 r
.45563 .59835 m .45637 .59964 L .45751 .60129 L F
.775 .607 .672 r
.23589 .60825 m .23645 .60419 L .23416 .605 L F
0 0 .305 r
.5669 .56819 m .56766 .5702 L .56783 .56753 L F
.974 .76 .335 r
.56783 .56753 m .56768 .56784 L .56864 .56604 L F
.56783 .56753 m .56766 .5702 L .56692 .56937 L F
.56768 .56784 m .56692 .56937 L .56856 .56618 L F
.56768 .56784 m .56856 .56618 L .56864 .56604 L F
0 0 .305 r
.56715 .56885 m .56686 .57178 L .56766 .5702 L F
.5669 .56819 m .56688 .56934 L .56715 .56885 L F
.56688 .56934 m .56686 .57178 L .56715 .56885 L F
.308 .508 .889 r
.65511 .44418 m .6559 .44234 L .653 .44098 L F
.65511 .44418 m .65702 .44433 L .6559 .44234 L F
.557 .624 .875 r
.83738 .41959 m .83992 .41951 L .83786 .42153 L F
.446 .442 .761 r
.83992 .41951 m .84097 .42293 L .83786 .42153 L F
.836 .582 .554 r
.50679 .53766 m .50856 .54006 L .50896 .53844 L F
.606 .303 .431 r
.50856 .54006 m .51133 .5404 L .50896 .53844 L F
0 0 0 r
.54457 .51462 m .54322 .51629 L .54176 .51714 L F
.409 .859 .885 r
.54322 .51629 m .54084 .51706 L .54176 .51714 L F
.756 .509 .559 r
.57852 .48941 m .58218 .48724 L .57835 .48694 L F
.57852 .48941 m .58225 .48975 L .58218 .48724 L F
.054 .543 .888 r
.19886 .62907 m .19517 .62762 L .1973 .62741 L F
.602 .77 .96 r
.19981 .62711 m .19886 .62907 L .1973 .62741 L F
.19981 .62711 m .2011 .62837 L .19886 .62907 L F
.993 .812 .559 r
.57486 .52581 m .57616 .5266 L .57553 .52897 L F
.617 .385 .544 r
.41995 .62006 m .42011 .62285 L .41737 .62252 L F
.41737 .62252 m .42011 .62285 L .41995 .62006 L F
.403 .386 .726 r
.41963 .61747 m .41995 .62006 L .42185 .6178 L F
.747 .938 .948 r
.41995 .62006 m .41837 .61939 L .42185 .6178 L F
.726 .595 .709 r
.82372 .42456 m .82574 .42381 L .82338 .42686 L F
.356 .78 .974 r
.22842 .55353 m .23216 .55403 L .23017 .55326 L F
.029 .261 .761 r
.23216 .55403 m .23361 .55258 L .23017 .55326 L F
.23216 .55403 m .23429 .55529 L .23361 .55258 L F
.542 .34 .556 r
.41823 .59876 m .42078 .59564 L .41861 .59497 L F
.41823 .59876 m .4208 .59829 L .42078 .59564 L F
.42078 .59564 m .4208 .59829 L .41823 .59876 L F
.497 .304 .55 r
.42314 .59516 m .4208 .59829 L .42078 .59564 L F
.42314 .59516 m .4208 .59829 L .42078 .59564 L F
.583 .531 .763 r
.45151 .59272 m .45491 .5957 L .45404 .59191 L F
.054 .016 .491 r
.51867 .60092 m .51891 .60373 L .51743 .60502 L F
.559 .298 .477 r
.51891 .60373 m .51566 .60421 L .51743 .60502 L F
.364 .582 .926 r
.80136 .40081 m .79888 .39888 L .80064 .39931 L F
.41 .657 .96 r
.80432 .39961 m .80136 .40081 L .80064 .39931 L F
.80432 .39961 m .80509 .40118 L .80136 .40081 L F
.593 .901 .628 r
.53388 .52594 m .53083 .52862 L .53021 .52726 L F
.53388 .52594 m .53362 .52595 L .53083 .52862 L F
.751 .693 .797 r
.40602 .62338 m .40517 .62613 L .40886 .62512 L F
.404 0 0 r
.40732 .62582 m .41111 .62558 L .40886 .62512 L F
.575 .276 .424 r
.44236 .56782 m .44529 .56569 L .44256 .56563 L F
.209 0 0 r
.54563 .51567 m .54457 .51462 L .54645 .51345 L F
.54563 .51567 m .54322 .51629 L .54457 .51462 L F
.797 .653 .702 r
.51082 .52251 m .51466 .52316 L .51377 .5207 L F
.789 .684 .749 r
.51082 .52251 m .51208 .52683 L .51466 .52316 L F
.663 .584 .756 r
.51377 .5207 m .51466 .52316 L .51701 .52204 L F
.809 .865 .89 r
.44151 .57925 m .44522 .57802 L .44323 .57843 L F
.082 0 0 r
.18681 .55957 m .18506 .56201 L .18341 .56227 L F
.566 .187 .281 r
.18856 .56096 m .18506 .56201 L .18681 .55957 L F
.593 .118 .095 r
.56773 .50737 m .56413 .50721 L .56385 .50608 L F
.411 .775 .995 r
.25222 .55756 m .25081 .55665 L .24822 .55693 L F
.398 .64 .954 r
.25222 .55756 m .25305 .55595 L .25081 .55665 L F
.25222 .55756 m .25382 .55738 L .25305 .55595 L F
.139 .349 .81 r
.17187 .63704 m .17235 .63839 L .17314 .63719 L F
.341 .364 .74 r
.17235 .63839 m .1738 .63865 L .17314 .63719 L F
.638 .31 .401 r
.52729 .54078 m .52494 .54089 L .52444 .53931 L F
.394 0 0 r
.51183 .55532 m .5074 .55318 L .50919 .55342 L F
.323 0 .217 r
.14391 .56817 m .14589 .56783 L .14693 .56533 L F
.24 0 .178 r
.14693 .56533 m .14792 .56705 L .14855 .56465 L F
.14693 .56533 m .14589 .56783 L .14792 .56705 L F
.318 .17 .516 r
.29784 .5531 m .29602 .5563 L .29538 .55359 L F
0 .408 .758 r
.30197 .58374 m .30018 .58287 L .2986 .58235 L F
.30197 .58374 m .30018 .58287 L .2986 .58235 L F
.534 .574 .841 r
.42148 .62889 m .42245 .63201 L .42401 .63049 L F
.19 .026 .415 r
.42245 .63201 m .42408 .63317 L .42401 .63049 L F
.42245 .63201 m .4213 .63626 L .42408 .63317 L F
.572 .221 .335 r
.74133 .37821 m .74322 .38056 L .74024 .38037 L F
.74133 .37821 m .74364 .37826 L .74322 .38056 L F
.606 .791 .97 r
.25519 .55853 m .25596 .55621 L .25382 .55738 L F
.25519 .55853 m .25804 .55816 L .25596 .55621 L F
.356 .381 .749 r
.45576 .61944 m .45711 .62173 L .45424 .62091 L F
.567 .851 .997 r
.73205 .39906 m .73039 .40021 L .72917 .3995 L F
.484 .252 .486 r
.47255 .62443 m .47068 .62303 L .47269 .62306 L F
.47255 .62443 m .47052 .62531 L .47068 .62303 L F
.622 .594 .8 r
.16394 .61624 m .16164 .61694 L .16027 .61345 L F
.449 .85 .973 r
.21596 .53888 m .218 .53837 L .21986 .5388 L F
.3 .771 .936 r
.21986 .5388 m .22005 .53808 L .22222 .5386 L F
.21986 .5388 m .218 .53837 L .22005 .53808 L F
.696 .896 .969 r
.19413 .73526 m .19653 .73436 L .19472 .73357 L F
.541 .525 .786 r
.44274 .60107 m .4413 .60498 L .4406 .60145 L F
.44274 .60107 m .44444 .60433 L .4413 .60498 L F
.487 .432 .721 r
.44498 .60634 m .4413 .60498 L .44444 .60433 L F
.44498 .60634 m .44191 .60731 L .4413 .60498 L F
.798 .812 .863 r
.72348 .41249 m .72525 .4115 L .72483 .40827 L F
.761 .788 .875 r
.72483 .40827 m .72525 .4115 L .72826 .40864 L F
.647 .61 .798 r
.48118 .57077 m .48346 .56827 L .48074 .56881 L F
.48118 .57077 m .48559 .57161 L .48346 .56827 L F
.596 .468 .676 r
.48118 .57077 m .48452 .5744 L .48559 .57161 L F
.48118 .57077 m .4831 .57592 L .48452 .5744 L F
.919 .812 .725 r
.71042 .41952 m .71182 .42064 L .71104 .4172 L F
.843 .899 .877 r
.7081 .42218 m .71182 .42064 L .71042 .41952 L F
.767 .731 .819 r
.71182 .42064 m .71471 .41791 L .71104 .4172 L F
.492 .702 .963 r
.51781 .56564 m .51949 .56386 L .51789 .56236 L F
.51781 .56564 m .5201 .56546 L .51949 .56386 L F
.659 .398 .513 r
.52517 .52618 m .52757 .53039 L .52893 .52629 L F
.151 0 0 r
.52517 .52618 m .52728 .52635 L .52893 .52629 L F
.52517 .52618 m .52728 .52635 L .52893 .52629 L F
.323 .77 .959 r
.25515 .53843 m .25442 .53936 L .25268 .53862 L F
.25515 .53843 m .25704 .53907 L .25442 .53936 L F
.346 0 .079 r
.47006 .59787 m .47254 .59754 L .47399 .59515 L F
.522 .423 .683 r
.47637 .59471 m .47452 .59812 L .47399 .59515 L F
.315 0 .063 r
.47399 .59515 m .47511 .59696 L .47637 .59471 L F
.47399 .59515 m .47254 .59754 L .47511 .59696 L F
.636 .733 .918 r
.81888 .40721 m .81681 .40893 L .81603 .40808 L F
.81888 .40721 m .81932 .40866 L .81681 .40893 L F
.585 .402 .6 r
.81932 .40866 m .81694 .41171 L .81681 .40893 L F
.622 .594 .801 r
.4208 .59829 m .4197 .60061 L .41823 .59876 L F
.4208 .5983 m .42197 .60173 L .4197 .60061 L F
.536 .321 .535 r
.41845 .59897 m .4182 .60188 L .42081 .60121 L F
.41823 .59876 m .41823 .59903 L .41845 .59897 L F
.41823 .59903 m .4182 .60188 L .41845 .59897 L F
.622 .594 .801 r
.4208 .59829 m .4208 .5983 L .4208 .5983 L F
.4208 .5983 m .42197 .60173 L .4208 .5983 L F
.651 .415 .548 r
.79376 .43255 m .7965 .43504 L .79639 .4327 L F
.79376 .43255 m .79293 .43541 L .7965 .43504 L F
.066 0 .23 r
.15041 .58597 m .14811 .58906 L .14873 .58673 L F
.823 .876 .883 r
.17765 .61799 m .17372 .61941 L .17609 .61636 L F
.635 .747 .93 r
.1793 .61719 m .17765 .61799 L .17609 .61636 L F
.788 .624 .678 r
.59109 .4989 m .59304 .49625 L .58974 .49573 L F
.14 0 0 r
.18659 .54398 m .18675 .54541 L .18875 .5441 L F
.18659 .54398 m .18464 .54612 L .18675 .54541 L F
.38 .211 .522 r
.71162 .40292 m .71395 .40422 L .7139 .40212 L F
.71162 .40292 m .71137 .40512 L .71395 .40422 L F
.941 .73 .589 r
.23383 .5949 m .23543 .59834 L .23616 .59591 L F
.999 .802 .465 r
.41282 .63153 m .41844 .63405 L .41555 .63274 L F
.686 .658 .817 r
.41555 .63274 m .41844 .63405 L .41865 .63158 L F
.691 .715 .867 r
.66936 .44145 m .6733 .44262 L .6714 .44146 L F
.352 .813 .927 r
.67531 .44128 m .6714 .44146 L .6733 .44262 L F
.677 .465 .591 r
.54407 .58979 m .5483 .58669 L .54394 .58663 L F
.486 .249 .48 r
.46917 .60189 m .4689 .60433 L .46654 .60484 L F
0 .021 .579 r
.46839 .59853 m .46917 .60189 L .46972 .59991 L F
.758 .984 .905 r
.46917 .60189 m .46813 .60149 L .46972 .59991 L F
.545 .324 .531 r
.47143 .60135 m .4689 .60433 L .46917 .60189 L F
.465 .722 .981 r
.28458 .54375 m .28405 .54559 L .28253 .54369 L F
.28458 .54375 m .28691 .54553 L .28405 .54559 L F
.202 0 0 r
.17262 .56826 m .17119 .56982 L .16896 .57034 L F
.352 0 .145 r
.17428 .56795 m .17119 .56982 L .17262 .56826 L F
.054 .381 .845 r
.5575 .59163 m .55742 .59283 L .55628 .59186 L F
.813 .452 .374 r
.55628 .59186 m .55775 .59496 L .55742 .59283 L F
.55628 .59186 m .55775 .59496 L .55742 .59283 L F
.684 .731 .886 r
.783 .44238 m .77931 .44145 L .78184 .44094 L F
.692 .977 .907 r
.78503 .44083 m .783 .44238 L .7845 .44039 L F
.558 .778 .981 r
.7845 .44039 m .783 .44238 L .78184 .44094 L F
.06 .625 .721 r
.18468 .64614 m .18698 .64602 L .18873 .64589 L F
.697 .576 .715 r
.22787 .68186 m .22514 .68557 L .22581 .68294 L F
.555 .308 .497 r
.43124 .64022 m .43016 .64373 L .42757 .64384 L F
.613 .366 .519 r
.43354 .64234 m .43124 .64022 L .43364 .64106 L F
.43354 .64234 m .43016 .64373 L .43124 .64022 L F
.759 .693 .151 r
.52937 .58074 m .52901 .58314 L .52906 .58213 L F
.91 .724 .639 r
.5085 .61316 m .5099 .61667 L .51031 .61388 L F
.329 0 .039 r
.23677 .62222 m .23902 .62191 L .24075 .61992 L F
.421 .096 .307 r
.23902 .62191 m .2424 .61863 L .24075 .61992 L F
.447 .267 .543 r
.28708 .6071 m .28489 .61023 L .28542 .60792 L F
.583 .439 .651 r
.22418 .67613 m .2262 .67341 L .22415 .67432 L F
.736 .753 .866 r
.72826 .40864 m .73176 .40917 L .7307 .40756 L F
.671 .732 .896 r
.73176 .40917 m .73381 .40671 L .7307 .40756 L F
.73176 .40917 m .73437 .40823 L .73381 .40671 L F
.544 .394 .628 r
.49836 .59504 m .49616 .59822 L .49655 .5952 L F
.351 .128 .429 r
.2793 .61858 m .27774 .61685 L .27999 .61632 L F
.2793 .61858 m .27732 .61923 L .27774 .61685 L F
.562 .334 .527 r
.28499 .61284 m .28271 .61084 L .28489 .61023 L F
.28499 .61284 m .28242 .61332 L .28271 .61084 L F
.134 .567 .925 r
.50999 .59252 m .50963 .59159 L .50823 .59196 L F
.609 .464 .659 r
.50999 .59252 m .50804 .59518 L .50823 .59196 L F
.134 .567 .925 r
.50823 .59196 m .50963 .59159 L .50999 .59252 L F
.35 .347 .715 r
.29951 .54918 m .29779 .55054 L .29623 .54862 L F
.29951 .54918 m .29966 .54976 L .29779 .55054 L F
.294 .208 .585 r
.29966 .54976 m .29968 .55247 L .29779 .55054 L F
.356 .215 .548 r
.29779 .55054 m .29968 .55247 L .29784 .5531 L F
.483 .321 .586 r
.39859 .60789 m .40063 .60992 L .40117 .60772 L F
.39859 .60789 m .3984 .6106 L .40063 .60992 L F
.46 .216 .457 r
.24303 .61675 m .24523 .61623 L .24567 .61385 L F
.469 .224 .46 r
.24567 .61385 m .24523 .61623 L .24791 .61335 L F
.891 .61 .505 r
.57321 .50824 m .57536 .51138 L .57324 .51063 L F
.839 .577 .542 r
.57536 .51138 m .57316 .51338 L .57324 .51063 L F
.57536 .51138 m .57546 .51384 L .57316 .51338 L F
.982 .88 .652 r
.57405 .54495 m .57213 .54629 L .5732 .54262 L F
.57405 .54495 m .57318 .54724 L .57213 .54629 L F
.995 .844 .496 r
.58704 .5405 m .58727 .54412 L .5874 .54143 L F
.942 .578 .269 r
.58727 .54412 m .58751 .54383 L .5874 .54143 L F
.609 .671 .884 r
.19595 .64698 m .20048 .65033 L .19943 .64684 L F
.745 .751 .857 r
.20048 .65033 m .20044 .64646 L .19943 .64684 L F
.20048 .65033 m .20271 .64878 L .20044 .64646 L F
.707 .577 .707 r
.82372 .42456 m .82338 .42686 L .8198 .4263 L F
.781 .64 .705 r
.8198 .4263 m .8171 .42967 L .81724 .42695 L F
.672 .263 .263 r
.43364 .64106 m .436 .64319 L .43354 .64234 L F
.589 .299 .445 r
.43628 .64096 m .436 .64319 L .43364 .64106 L F
.601 .787 .97 r
.41428 .59813 m .41823 .59876 L .41745 .59593 L F
.542 .34 .556 r
.41823 .59876 m .41861 .59497 L .41745 .59593 L F
.536 .321 .535 r
.41823 .59876 m .42081 .60121 L .4208 .59829 L F
.465 .288 .556 r
.43349 .65644 m .43402 .65873 L .4314 .65905 L F
.43411 .65753 m .43402 .65873 L .43349 .65644 L F
.79 .39 .296 r
.43411 .65753 m .43424 .65776 L .43537 .65826 L F
.815 .811 .846 r
.43435 .65844 m .43387 .65952 L .43537 .65826 L F
0 0 0 r
.43537 .65826 m .43387 .65952 L .43422 .65924 L F
.79 .554 .58 r
.43537 .65826 m .43422 .65924 L .43423 .65846 L F
.43537 .65826 m .43423 .65846 L .43424 .65776 L F
.815 .811 .846 r
.43448 .65817 m .43435 .65844 L .43537 .65826 L F
.79 .39 .296 r
.43424 .65776 m .43448 .65817 L .43537 .65826 L F
.43411 .65753 m .43537 .65826 L .43428 .65546 L F
.79 .554 .58 r
.43537 .65826 m .43424 .65776 L .43428 .65546 L F
.465 .288 .556 r
.43428 .65546 m .43422 .65924 L .43398 .65922 L F
.79 .39 .296 r
.43229 .65647 m .43195 .65791 L .43448 .65817 L F
.43229 .65647 m .43448 .65817 L .43411 .65753 L F
.465 .288 .556 r
.43428 .65546 m .43411 .65753 L .43349 .65644 L F
.815 .811 .846 r
.43357 .65927 m .43387 .65952 L .43448 .65817 L F
.465 .288 .556 r
.43402 .65873 m .43398 .65922 L .43362 .6592 L F
.43402 .65873 m .43362 .6592 L .4314 .65905 L F
.815 .811 .846 r
.43195 .65791 m .43357 .65927 L .43448 .65817 L F
.79 .39 .296 r
.43229 .65647 m .43411 .65753 L .43428 .65546 L F
.747 .637 .738 r
.43386 .65618 m .43208 .65797 L .43195 .65791 L F
0 0 0 r
.4314 .65905 m .43195 .65791 L .43181 .65786 L F
.747 .637 .738 r
.43208 .65797 m .4305 .65956 L .43195 .65791 L F
0 0 0 r
.43181 .65786 m .43195 .65791 L .43229 .65647 L F
.351 .608 .945 r
.43422 .65924 m .43387 .65952 L .4314 .65905 L F
.269 .619 .959 r
.4314 .65905 m .43387 .65952 L .43195 .65791 L F
.581 .931 .946 r
.43048 .63643 m .42931 .63717 L .43028 .63736 L F
.519 .696 .95 r
.47945 .56707 m .48074 .56881 L .48169 .56681 L F
.571 .758 .967 r
.48074 .56881 m .48346 .56827 L .48169 .56681 L F
0 0 0 r
.79312 .44532 m .79217 .4467 L .79028 .44785 L F
.083 0 0 r
.79473 .44578 m .79312 .44532 L .79534 .44415 L F
.79473 .44578 m .79217 .4467 L .79312 .44532 L F
.696 .507 .628 r
.81724 .42695 m .8171 .42967 L .81554 .42942 L F
.382 .525 .876 r
.7691 .4372 m .77049 .43506 L .76809 .43526 L F
.7691 .4372 m .77192 .43798 L .77049 .43506 L F
.066 .34 .817 r
.77359 .44052 m .77486 .4397 L .77192 .43798 L F
.77359 .44052 m .77547 .44153 L .77486 .4397 L F
.692 .88 .495 r
.52407 .53526 m .52251 .53719 L .52165 .53888 L F
.306 .299 .687 r
.52361 .52767 m .52456 .5319 L .52256 .53144 L F
.966 .838 .666 r
.52383 .53075 m .52456 .5319 L .52393 .53053 L F
.033 .226 .729 r
.52256 .53144 m .5245 .53331 L .52407 .53526 L F
.313 .285 .667 r
.52456 .5319 m .52482 .53361 L .52256 .53144 L F
.966 .838 .666 r
.52302 .53263 m .52418 .53208 L .52383 .53075 L F
.52418 .53208 m .52456 .5319 L .52383 .53075 L F
.033 .226 .729 r
.5245 .53331 m .52482 .53361 L .52467 .53394 L F
.5245 .53331 m .52467 .53394 L .52407 .53526 L F
.706 .885 .499 r
.52482 .53361 m .52251 .53719 L .52407 .53526 L F
.839 .909 .885 r
.66577 .43632 m .66185 .43795 L .66396 .4365 L F
.871 .957 .859 r
.66577 .43632 m .66508 .43522 L .66614 .43425 L F
.943 .948 .752 r
.66577 .43632 m .66396 .4365 L .66508 .43522 L F
.295 .064 .384 r
.15596 .57748 m .15533 .58 L .15354 .58067 L F
.029 0 .197 r
.15533 .58 m .15302 .58327 L .15354 .58067 L F
.495 .202 .397 r
.56126 .49295 m .56379 .49249 L .56416 .49056 L F
.551 .251 .413 r
.56416 .49056 m .56661 .49193 L .56723 .48965 L F
.56416 .49056 m .56379 .49249 L .56661 .49193 L F
0 .365 .711 r
.22719 .6677 m .22908 .66844 L .22873 .66816 L F
.497 .218 .421 r
.55511 .49668 m .55798 .49671 L .55876 .4927 L F
.536 .253 .432 r
.55876 .4927 m .56119 .49462 L .56126 .49295 L F
.55876 .4927 m .55798 .49671 L .56119 .49462 L F
0 0 0 r
.23072 .67328 m .2326 .67353 L .23036 .67265 L F
.534 .799 .994 r
.23072 .67328 m .23067 .67421 L .22873 .67302 L F
.2326 .67353 m .23259 .67354 L .23072 .67328 L F
.23259 .67354 m .23067 .67421 L .23072 .67328 L F
.2326 .67353 m .22873 .67302 L .22872 .67301 L F
.484 .537 .836 r
.22872 .67301 m .23235 .67615 L .23072 .67328 L F
.22872 .67301 m .23072 .67328 L .23036 .67265 L F
0 0 0 r
.23235 .67615 m .2326 .67353 L .23072 .67328 L F
.556 .533 .785 r
.4218 .61499 m .4241 .61475 L .42322 .61166 L F
.528 .412 .665 r
.4218 .61499 m .42433 .6158 L .4241 .61475 L F
.4218 .61499 m .42195 .61655 L .42433 .6158 L F
.846 .951 .6 r
.42255 .58761 m .42183 .58652 L .42035 .58836 L F
.42255 .58761 m .4241 .58608 L .42183 .58652 L F
.104 .659 .754 r
.47808 .55872 m .48052 .55849 L .48219 .55843 L F
.43 0 0 r
.48052 .55849 m .48427 .5591 L .48219 .55843 L F
.543 .622 .881 r
.74546 .41482 m .7468 .41249 L .7441 .41154 L F
.74546 .41482 m .74803 .41431 L .7468 .41249 L F
.424 .804 .992 r
.19544 .74344 m .19774 .74307 L .19606 .7423 L F
.19606 .7423 m .19774 .74307 L .19544 .74344 L F
.19544 .74344 m .19774 .74307 L .19606 .7423 L F
.803 .787 .838 r
.17408 .61649 m .17031 .61672 L .17202 .61515 L F
.6 .598 .821 r
.17372 .61941 m .17031 .61672 L .17408 .61649 L F
.433 .632 .938 r
.17436 .61462 m .17408 .61649 L .17202 .61515 L F
.17436 .61462 m .17609 .61636 L .17408 .61649 L F
.441 .234 .501 r
.17609 .61636 m .17372 .61941 L .17408 .61649 L F
.716 .926 .591 r
.16263 .6074 m .16057 .60953 L .15997 .61087 L F
.283 .199 .581 r
.16174 .61281 m .15997 .61087 L .16057 .60953 L F
.16174 .61281 m .16027 .61345 L .15997 .61087 L F
.692 .586 .732 r
.56723 .48965 m .5699 .48674 L .56631 .48708 L F
.646 .599 .788 r
.81993 .43909 m .81614 .43621 L .81882 .43522 L F
.673 .594 .759 r
.82259 .43637 m .81993 .43909 L .81882 .43522 L F
.377 .83 .929 r
.47156 .56529 m .46943 .56554 L .46775 .56599 L F
.335 .021 .276 r
.46943 .56554 m .46708 .56783 L .46775 .56599 L F
.918 .85 .761 r
.57536 .53153 m .57513 .53604 L .57469 .53402 L F
.94 .956 .65 r
.57513 .53604 m .57351 .53725 L .57469 .53402 L F
.57513 .53604 m .57404 .5381 L .57351 .53725 L F
.774 .785 .862 r
.7195 .41348 m .72348 .41249 L .72197 .41091 L F
.798 .812 .863 r
.72348 .41249 m .72483 .40827 L .72197 .41091 L F
.73 .651 .771 r
.50845 .52578 m .51208 .52683 L .51082 .52251 L F
.501 .876 .976 r
.78174 .45175 m .78321 .45054 L .78048 .45066 L F
.78174 .45175 m .78438 .45099 L .78321 .45054 L F
.588 .636 .866 r
.7369 .40767 m .7383 .41127 L .74085 .41051 L F
.585 .611 .845 r
.7383 .41127 m .74159 .41232 L .74085 .41051 L F
.614 .622 .836 r
.17348 .67377 m .17101 .67477 L .1717 .67383 L F
.509 .663 .931 r
.20874 .63184 m .20439 .6296 L .20728 .63013 L F
.457 .671 .956 r
.20935 .62996 m .20874 .63184 L .20728 .63013 L F
.473 .689 .961 r
.20935 .62996 m .2109 .63166 L .20874 .63184 L F
.226 .732 .672 r
.19293 .55949 m .19066 .56026 L .18856 .56096 L F
0 0 0 r
.19382 .55926 m .19293 .55949 L .19514 .55885 L F
.19382 .55926 m .19066 .56026 L .19293 .55949 L F
.654 .446 .589 r
.4585 .63081 m .45532 .62872 L .45933 .6288 L F
0 0 0 r
.4618 .62857 m .4585 .63081 L .45933 .6288 L F
.564 .364 .569 r
.45873 .61373 m .45882 .61618 L .4568 .6164 L F
.269 .174 .559 r
.46064 .61264 m .45882 .61618 L .45873 .61373 L F
.935 .642 .46 r
.43875 .59315 m .43961 .59543 L .43788 .59457 L F
.453 .413 .723 r
.43875 .59315 m .44148 .59492 L .43961 .59543 L F
.667 .274 .293 r
.43788 .59457 m .44148 .59492 L .43875 .59315 L F
.43 .462 .792 r
.23157 .66439 m .22979 .66139 L .23386 .66175 L F
.661 .814 .957 r
.23222 .66036 m .23386 .66175 L .22979 .66139 L F
.43 .462 .792 r
.23157 .66439 m .23222 .66036 L .22979 .66139 L F
.562 .616 .864 r
.23431 .66488 m .23157 .66439 L .23386 .66175 L F
.43 .462 .792 r
.23157 .66439 m .23392 .66463 L .23222 .66036 L F
.463 .291 .562 r
.23157 .66439 m .23109 .66757 L .23392 .66463 L F
.812 .726 .77 r
.55521 .58271 m .55324 .58585 L .55371 .58361 L F
.942 .578 .269 r
.58727 .54412 m .5883 .54553 L .58751 .54383 L F
.703 .632 .775 r
.22213 .67814 m .21927 .68012 L .21788 .67662 L F
0 0 .368 r
.20839 .6998 m .209 .7001 L .20999 .69815 L F
.381 .02 .221 r
.26451 .63197 m .26144 .63407 L .26237 .63235 L F
.331 .744 .979 r
.26883 .5399 m .27272 .54063 L .27053 .54077 L F
.026 .174 .682 r
.26629 .56513 m .26746 .56872 L .26804 .56719 L F
.472 .379 .669 r
.26649 .57071 m .26804 .56719 L .26746 .56872 L F
.423 .186 .448 r
.4741 .62826 m .47186 .62899 L .47438 .62598 L F
.957 .69 .488 r
.47255 .62443 m .4741 .62826 L .47438 .62598 L F
.757 .545 .61 r
.47255 .62443 m .47647 .62263 L .47438 .62598 L F
.491 .346 .611 r
.47647 .62263 m .4767 .62553 L .47438 .62598 L F
.445 .204 .454 r
.4767 .62553 m .4741 .62826 L .47438 .62598 L F
.514 .78 .992 r
.1793 .64086 m .18018 .63914 L .17763 .63953 L F
.1793 .64086 m .18143 .64036 L .18018 .63914 L F
.483 .3 .557 r
.54169 .59469 m .54498 .59281 L .54288 .59448 L F
.54169 .59469 m .54344 .59185 L .54498 .59281 L F
.425 .164 .413 r
.27732 .61923 m .27466 .62206 L .27516 .61977 L F
.468 .892 .877 r
.56452 .60523 m .56257 .6054 L .55992 .60648 L F
.464 .007 .081 r
.56607 .60397 m .56257 .6054 L .56452 .60523 L F
.674 .623 .791 r
.23337 .60135 m .23689 .60173 L .23543 .59834 L F
.707 .534 .653 r
.23337 .60135 m .23645 .60419 L .23689 .60173 L F
.23337 .60135 m .23416 .605 L .23645 .60419 L F
.523 .215 .387 r
.47129 .61589 m .47379 .61562 L .47166 .61387 L F
.509 .22 .41 r
.47166 .61387 m .47379 .61562 L .47421 .61349 L F
.971 .726 .508 r
.57686 .51735 m .57534 .51637 L .57546 .51384 L F
.921 .676 .55 r
.57686 .51735 m .57481 .51886 L .57534 .51637 L F
.57686 .51735 m .57673 .51993 L .57481 .51886 L F
.988 .719 .394 r
.4208 .59829 m .42081 .60121 L .42197 .60173 L F
.915 .519 .141 r
.42081 .60121 m .42291 .60433 L .42197 .60173 L F
.708 .329 .328 r
.68873 .41453 m .69131 .41655 L .69225 .41487 L F
.669 .354 .431 r
.69131 .41655 m .69492 .41457 L .69225 .41487 L F
.482 .408 .697 r
.15742 .60225 m .15533 .60347 L .1551 .59979 L F
.829 .434 0 r
.52523 .57162 m .52515 .57289 L .52408 .57052 L F
.52523 .57162 m .52615 .57388 L .52515 .57289 L F
.713 .309 .282 r
.80796 .44121 m .81199 .4417 L .81043 .44344 L F
.659 .239 .236 r
.45711 .62173 m .45937 .62188 L .46054 .62054 L F
.467 .019 .101 r
.46054 .62054 m .45937 .62188 L .46274 .62152 L F
.453 .078 .236 r
.46054 .62054 m .46274 .62152 L .46299 .62029 L F
.136 0 .065 r
.77921 .39935 m .78229 .39686 L .78134 .39774 L F
.346 .435 .81 r
.78134 .39774 m .78266 .40137 L .77921 .39935 L F
.861 .568 .039 r
.23248 .58166 m .2352 .58062 L .23362 .57968 L F
.978 .826 .623 r
.23449 .5771 m .23362 .57968 L .2352 .58062 L F
.895 .703 .635 r
.68074 .42613 m .67921 .42266 L .68119 .42374 L F
.244 .529 .917 r
.28137 .54196 m .28074 .54341 L .2787 .54179 L F
.28137 .54196 m .28253 .54369 L .28074 .54341 L F
.822 .791 .823 r
.4531 .63145 m .45118 .63454 L .44917 .63285 L F
.427 .275 .571 r
.4531 .63145 m .4534 .63455 L .45118 .63454 L F
.421 .223 .504 r
.4534 .63455 m .45138 .63723 L .45118 .63454 L F
.375 .819 .948 r
.21392 .53845 m .21363 .53933 L .21169 .53849 L F
.21392 .53845 m .21596 .53888 L .21363 .53933 L F
.99 .792 .543 r
.16358 .60692 m .16496 .60737 L .16541 .60476 L F
.677 .465 .591 r
.54407 .58979 m .54866 .5886 L .5483 .58669 L F
.544 .285 .472 r
.47452 .59812 m .47434 .60111 L .47143 .60135 L F
.522 .423 .683 r
.47637 .59471 m .47662 .59772 L .47452 .59812 L F
.419 .183 .447 r
.47659 .60043 m .47452 .59812 L .47662 .59772 L F
.47659 .60043 m .47434 .60111 L .47452 .59812 L F
.83 .668 .682 r
.44248 .61229 m .43876 .60966 L .44119 .60771 L F
.44248 .61229 m .43927 .61311 L .43876 .60966 L F
.154 .671 .891 r
.44206 .6136 m .43927 .61311 L .44064 .61344 L F
.44314 .61372 m .4421 .61355 L .44206 .6136 L F
.4421 .61355 m .43927 .61311 L .44206 .6136 L F
.414 .391 .725 r
.44309 .61147 m .44251 .61308 L .44248 .61229 L F
.44251 .61308 m .44214 .6141 L .44228 .61335 L F
.44251 .61308 m .44228 .61335 L .44248 .61229 L F
.39 .49 .841 r
.44064 .61344 m .44379 .61648 L .44314 .61372 L F
.551 .136 .206 r
.44214 .6141 m .43927 .61311 L .44248 .61229 L F
0 0 0 r
.44427 .60868 m .44248 .61229 L .44119 .60771 L F
.44427 .60868 m .44309 .61147 L .44248 .61229 L F
.538 .287 .483 r
.43839 .61988 m .4406 .62176 L .44118 .61984 L F
.43839 .61988 m .43816 .6222 L .4406 .62176 L F
.482 .374 .654 r
.29872 .57048 m .29869 .57433 L .29664 .57486 L F
.42 .286 .591 r
.29869 .57433 m .29695 .57722 L .29664 .57486 L F
.466 .883 .77 r
.79028 .44785 m .78916 .44808 L .78671 .44945 L F
.422 .86 .764 r
.79217 .4467 m .78916 .44808 L .79028 .44785 L F
.617 .563 .771 r
.48836 .5774 m .49173 .57774 L .49036 .57468 L F
.46 .275 .543 r
.29167 .59552 m .29155 .59847 L .28942 .59899 L F
.495 .41 .688 r
.29196 .601 m .28942 .59899 L .29155 .59847 L F
.29196 .601 m .28988 .60163 L .28942 .59899 L F
0 .154 .696 r
.5575 .59163 m .55835 .59164 L .55742 .59283 L F
.847 .914 .879 r
.56255 .59123 m .55907 .59267 L .55971 .58984 L F
.24 .064 .43 r
.55944 .59356 m .55742 .59283 L .55835 .59164 L F
.5595 .59366 m .55948 .59365 L .55944 .59356 L F
.5595 .59366 m .55835 .59164 L .55869 .59283 L F
.847 .914 .879 r
.55907 .59267 m .55869 .59283 L .55889 .59224 L F
.55907 .59267 m .55889 .59224 L .55971 .58984 L F
.24 .064 .43 r
.55948 .59365 m .55742 .59283 L .55944 .59356 L F
.5595 .59366 m .55775 .59496 L .55742 .59283 L F
.55742 .59283 m .55775 .59496 L .5595 .59366 L F
.318 .17 .516 r
.29784 .5531 m .2977 .5556 L .29602 .5563 L F
.377 .245 .572 r
.2977 .5556 m .29619 .55888 L .29602 .5563 L F
.702 .334 .347 r
.67896 .41129 m .68134 .41351 L .6824 .41154 L F
.792 .564 .592 r
.68134 .41351 m .68491 .41154 L .6824 .41154 L F
.462 .015 .102 r
.24835 .64089 m .2468 .64279 L .24462 .64305 L F
.019 0 0 r
.24878 .64203 m .24835 .64089 L .25071 .64055 L F
.24878 .64203 m .2468 .64279 L .24835 .64089 L F
0 0 0 r
.545 .50483 m .54685 .504 L .54781 .50223 L F
.009 0 .091 r
.55028 .49922 m .54781 .50223 L .5498 .50069 L F
0 0 0 r
.54781 .50223 m .54888 .50287 L .5498 .50069 L F
.54781 .50223 m .54685 .504 L .54888 .50287 L F
.52 .267 .471 r
.69492 .41457 m .69752 .41408 L .69749 .41198 L F
.555 .267 .433 r
.69752 .41408 m .70078 .41125 L .69749 .41198 L F
0 0 0 r
.16358 .60692 m .16263 .6074 L .16496 .60737 L F
.16358 .60692 m .16057 .60953 L .16263 .6074 L F
.25 .745 .911 r
.2265 .53757 m .22594 .53812 L .22424 .53787 L F
.2265 .53757 m .22819 .53793 L .22594 .53812 L F
.451 0 0 r
.74524 .37401 m .74257 .37313 L .74131 .37419 L F
.472 .167 .366 r
.74524 .37401 m .74498 .37241 L .74257 .37313 L F
.825 .999 .795 r
.82982 .44189 m .82844 .44212 L .8272 .44473 L F
.818 .99 .733 r
.8272 .44473 m .82844 .44212 L .82687 .44429 L F
.691 .189 .043 r
.6776 .42085 m .67685 .4224 L .67408 .41996 L F
.807 .336 .102 r
.67921 .42266 m .67685 .4224 L .6776 .42085 L F
0 0 .404 r
.15612 .59788 m .15602 .59953 L .1551 .59979 L F
.482 .408 .697 r
.15742 .60225 m .1551 .59979 L .15602 .59953 L F
.616 .571 .781 r
.79957 .41872 m .80113 .41398 L .79878 .41444 L F
.79957 .41872 m .80068 .41834 L .80113 .41398 L F
.539 .448 .701 r
.79957 .41872 m .80257 .41992 L .80068 .41834 L F
.79957 .41872 m .8 .42049 L .80257 .41992 L F
.726 .881 .953 r
.44371 .63665 m .44207 .63812 L .44074 .63682 L F
.558 .429 .661 r
.44314 .61372 m .44379 .61648 L .4457 .61576 L F
0 0 0 r
.18341 .56227 m .18191 .5645 L .18056 .56517 L F
.034 0 0 r
.18414 .56324 m .18341 .56227 L .18506 .56201 L F
.18414 .56324 m .18191 .5645 L .18341 .56227 L F
.576 .586 .826 r
.22339 .68831 m .22005 .68508 L .22282 .68581 L F
.752 .905 .945 r
.21962 .68959 m .22339 .68831 L .22205 .69037 L F
.271 .132 .501 r
.22514 .68557 m .22339 .68831 L .22282 .68581 L F
.22514 .68557 m .22506 .68838 L .22339 .68831 L F
.845 .571 .525 r
.22506 .68838 m .22205 .69037 L .22339 .68831 L F
.785 .666 .115 r
.59105 .5137 m .59119 .51416 L .59029 .51343 L F
.59105 .5137 m .59104 .51655 L .59119 .51416 L F
.69 .966 .741 r
.19536 .54195 m .19497 .54139 L .19732 .54109 L F
.775 .611 .676 r
.58843 .48959 m .5897 .49305 L .59001 .49044 L F
.774 .9 .93 r
.67679 .42891 m .67384 .42941 L .67599 .42679 L F
.625 .68 .881 r
.67787 .42579 m .67679 .42891 L .67599 .42679 L F
.67787 .42579 m .679 .42818 L .67679 .42891 L F
.479 .706 .969 r
.16237 .62941 m .16486 .63149 L .16656 .63097 L F
0 0 .511 r
.52705 .57651 m .52871 .57862 L .5272 .57657 L F
0 0 .309 r
.52676 .57638 m .52705 .57651 L .52615 .57388 L F
.879 .461 .04 r
.52615 .57388 m .52705 .57651 L .52633 .57589 L F
.52587 .57494 m .52633 .57589 L .52576 .57539 L F
.52615 .57388 m .52633 .57589 L .52587 .57494 L F
0 0 .309 r
.527 .57734 m .52705 .57651 L .52676 .57638 L F
.879 .461 .04 r
.52615 .57388 m .52576 .57539 L .52515 .57289 L F
0 0 .511 r
.52705 .57651 m .52566 .57449 L .52576 .57539 L F
.52705 .57651 m .5272 .57657 L .52566 .57449 L F
0 .115 .66 r
.527 .57734 m .52925 .57964 L .52705 .57651 L F
0 .089 .637 r
.52705 .57651 m .52925 .57964 L .52871 .57862 L F
0 0 .312 r
.52906 .58152 m .52566 .57449 L .52871 .57862 L F
.52713 .57753 m .5282 .57973 L .52566 .57449 L F
.52906 .58152 m .52857 .5805 L .52713 .57753 L F
.52857 .5805 m .5282 .57973 L .52713 .57753 L F
0 0 0 r
.545 .50483 m .54423 .5068 L .54685 .504 L F
0 .249 .719 r
.7853 .3878 m .78375 .38723 L .78247 .38617 L F
.7853 .3878 m .78644 .38897 L .78375 .38723 L F
.817 .694 .729 r
.82138 .43419 m .8246 .43465 L .82259 .43637 L F
.663 .584 .756 r
.51377 .5207 m .51701 .52204 L .51705 .52125 L F
.264 .772 .836 r
.78229 .39686 m .78372 .39619 L .78134 .39774 L F
.78229 .39686 m .78475 .39635 L .78372 .39619 L F
0 0 .539 r
.51133 .5404 m .51266 .54499 L .5114 .54187 L F
.999 .789 .481 r
.40517 .62613 m .40462 .62852 L .40367 .62703 L F
.609 .078 0 r
.40517 .62613 m .40367 .62703 L .40094 .62543 L F
.495 .473 .762 r
.40644 .62137 m .40517 .62613 L .40602 .62338 L F
.40644 .62137 m .40732 .62582 L .40517 .62613 L F
.359 .077 .343 r
.24303 .61675 m .24462 .61784 L .24523 .61623 L F
.24303 .61675 m .2424 .61863 L .24462 .61784 L F
.306 0 0 r
.1565 .55837 m .15882 .55813 L .16077 .5565 L F
.092 0 0 r
.16077 .5565 m .16095 .55752 L .16277 .55569 L F
.16077 .5565 m .15882 .55813 L .16095 .55752 L F
.075 0 .193 r
.75251 .37719 m .75274 .37554 L .75386 .37551 L F
.524 .835 .999 r
.19936 .73007 m .20179 .73122 L .19662 .73162 L F
.912 .609 .122 r
.20179 .73122 m .20204 .73371 L .19662 .73162 L F
0 .36 .702 r
.19662 .73162 m .19961 .73268 L .19936 .73007 L F
.647 .65 .84 r
.20354 .73093 m .20266 .73429 L .20179 .73122 L F
.20354 .73093 m .20514 .73344 L .20266 .73429 L F
.912 .609 .122 r
.20179 .73122 m .20266 .73429 L .20204 .73371 L F
.544 .903 .969 r
.20266 .73429 m .20514 .73344 L .20204 .73371 L F
.842 .709 .716 r
.20204 .73371 m .20514 .73344 L .20354 .73093 L F
.558 .209 .334 r
.20246 .73271 m .20317 .73364 L .2027 .73387 L F
.954 .945 .639 r
.20204 .73371 m .20266 .73429 L .2007 .73624 L F
.544 .903 .969 r
.20266 .73429 m .20204 .73371 L .2007 .73624 L F
.558 .209 .334 r
.20192 .73358 m .2027 .73387 L .20132 .73455 L F
.20246 .73271 m .2027 .73387 L .20192 .73358 L F
0 .36 .702 r
.19662 .73162 m .20204 .73371 L .19979 .73276 L F
.19938 .7326 m .19979 .73276 L .19961 .73268 L F
.19662 .73162 m .19979 .73276 L .19938 .7326 L F
.56 .561 .811 r
.4741 .62826 m .47186 .62899 L .47052 .62531 L F
.553 .837 .998 r
.47045 .62792 m .47186 .62899 L .4741 .62826 L F
.524 .148 .27 r
.4689 .60433 m .46609 .60493 L .46654 .60484 L F
.58 .59 .827 r
.46777 .5878 m .46671 .59003 L .46483 .58599 L F
0 0 0 r
.46777 .5878 m .46586 .5923 L .46671 .59003 L F
.475 .216 .441 r
.2321 .62596 m .23453 .62543 L .23514 .62282 L F
.171 0 .318 r
.23514 .62282 m .23616 .62423 L .23677 .62222 L F
.23514 .62282 m .23453 .62543 L .23616 .62423 L F
.431 .157 .396 r
.5498 .50069 m .55253 .49806 L .55028 .49922 L F
.682 .601 .759 r
.4826 .60694 m .48606 .60796 L .48507 .60448 L F
.315 .073 .379 r
.4826 .60694 m .48458 .60834 L .48507 .60448 L F
.093 0 0 r
.45847 .57065 m .45496 .57283 L .45606 .5712 L F
.501 .449 .731 r
.45385 .58925 m .45469 .58509 L .45254 .58619 L F
.623 .573 .778 r
.45404 .59191 m .45611 .58982 L .45385 .58925 L F
.357 .083 .355 r
.15288 .56055 m .15399 .5615 L .15449 .55929 L F
.15288 .56055 m .152 .56224 L .15399 .5615 L F
.575 .276 .424 r
.44236 .56782 m .44493 .56792 L .44529 .56569 L F
.426 .147 .384 r
.44529 .56569 m .44727 .56728 L .44767 .56538 L F
.44529 .56569 m .44493 .56792 L .44727 .56728 L F
.718 .713 .844 r
.81512 .43423 m .81614 .43621 L .81253 .43557 L F
.699 .682 .831 r
.81764 .43183 m .81614 .43621 L .81512 .43423 L F
.81764 .43183 m .81882 .43522 L .81614 .43621 L F
.311 .02 .3 r
.15828 .57693 m .15533 .58 L .15596 .57748 L F
.672 .769 .924 r
.51139 .53501 m .51366 .53486 L .51404 .5347 L F
.64 .965 .886 r
.82982 .44189 m .83179 .44032 L .83151 .44007 L F
.634 .962 .828 r
.83151 .44007 m .82844 .44212 L .82982 .44189 L F
.403 .386 .726 r
.41963 .61747 m .42185 .6178 L .42195 .61655 L F
0 .178 .711 r
.49352 .56304 m .49184 .5624 L .49051 .56131 L F
.49352 .56304 m .49413 .56446 L .49184 .5624 L F
.872 .594 .513 r
.57321 .50824 m .57021 .5096 L .56998 .50768 L F
.57321 .50824 m .57324 .51063 L .57021 .5096 L F
.33 .051 .329 r
.25026 .60763 m .2523 .60696 L .25293 .60476 L F
.5 .315 .562 r
.25293 .60476 m .25516 .60422 L .2553 .60157 L F
.48 .186 .389 r
.25293 .60476 m .25467 .60649 L .25516 .60422 L F
.25293 .60476 m .2523 .60696 L .25467 .60649 L F
.629 .573 .772 r
.2315 .59529 m .2338 .60062 L .23543 .59834 L F
.429 .096 .298 r
.42185 .6178 m .42433 .6158 L .42195 .61655 L F
.703 .164 0 r
.53943 .61009 m .53548 .60729 L .53719 .61039 L F
.435 .439 .764 r
.55988 .58686 m .56078 .58934 L .56272 .58885 L F
.77 .592 .657 r
.68498 .41405 m .68894 .41197 L .68491 .41154 L F
.68498 .41405 m .68873 .41453 L .68894 .41197 L F
.117 .668 .792 r
.22819 .53793 m .23044 .53778 L .23222 .53784 L F
.11 .626 .889 r
.2326 .53738 m .23222 .53784 L .23044 .53778 L F
.2326 .53738 m .23427 .53804 L .23222 .53784 L F
0 .043 .609 r
.52983 .55331 m .53153 .55536 L .53156 .55645 L F
.183 .287 .737 r
.53153 .55536 m .53153 .55895 L .53156 .55645 L F
.484 .295 .548 r
.29381 .59785 m .29167 .59552 L .29392 .59496 L F
.29381 .59785 m .29155 .59847 L .29167 .59552 L F
.635 .565 .758 r
.45439 .60801 m .45649 .60443 L .454 .60516 L F
.62 .058 0 r
.75667 .42372 m .75419 .42314 L .75517 .4233 L F
.922 .882 .778 r
.75667 .42372 m .75402 .42491 L .75419 .42314 L F
.75667 .42372 m .75498 .42644 L .75402 .42491 L F
.806 .795 .842 r
.75667 .42372 m .75802 .4193 L .75945 .4209 L F
.75667 .42372 m .75517 .4233 L .75802 .4193 L F
0 0 0 r
.46708 .56783 m .46434 .57015 L .46531 .56907 L F
.518 .638 .908 r
.45769 .58384 m .45556 .58566 L .45469 .58509 L F
.45769 .58384 m .45871 .58611 L .45556 .58566 L F
.472 .236 .475 r
.27249 .62266 m .27212 .62509 L .26988 .62555 L F
.415 .187 .457 r
.27428 .62452 m .27249 .62266 L .27466 .62206 L F
.27428 .62452 m .27212 .62509 L .27249 .62266 L F
.534 .574 .841 r
.42148 .62889 m .42401 .63049 L .42472 .62867 L F
.552 .231 .377 r
.42401 .63049 m .42707 .62896 L .42472 .62867 L F
.606 .34 .488 r
.48892 .60757 m .48826 .60948 L .48606 .60796 L F
.429 .395 .719 r
.48826 .60948 m .48733 .61072 L .48606 .60796 L F
.318 .183 .534 r
.44148 .59492 m .43984 .59786 L .43961 .59543 L F
.327 .416 .8 r
.19192 .62157 m .19161 .6248 L .18963 .62216 L F
.19192 .62157 m .19331 .62513 L .19161 .6248 L F
.496 .388 .661 r
.20951 .70793 m .21175 .70919 L .2118 .70697 L F
.647 .927 .973 r
.21703 .63076 m .21488 .63192 L .2132 .63151 L F
.715 .524 .63 r
.51638 .5437 m .51824 .54426 L .51959 .54168 L F
.438 0 0 r
.51519 .54417 m .51824 .54426 L .51638 .5437 L F
.921 .92 .796 r
.51959 .54168 m .51613 .54404 L .51813 .54125 L F
.873 .989 .823 r
.51969 .53967 m .51613 .54404 L .51959 .54168 L F
.55 .1 .137 r
.45342 .56391 m .4558 .56428 L .45723 .56247 L F
.317 0 0 r
.4558 .56428 m .45964 .56271 L .45723 .56247 L F
.927 .771 .668 r
.58893 .53486 m .58986 .53268 L .58784 .53138 L F
.192 .564 .936 r
.24231 .55685 m .24256 .55527 L .23951 .55622 L F
.24231 .55685 m .2446 .55706 L .24256 .55527 L F
0 0 .222 r
.57825 .5863 m .57799 .58878 L .57722 .58975 L F
.068 0 .351 r
.57809 .59095 m .57722 .58975 L .57799 .58878 L F
.57809 .59095 m .57675 .59242 L .57722 .58975 L F
.491 .496 .79 r
.29854 .56171 m .29771 .56572 L .29684 .56201 L F
.29854 .56171 m .29911 .5653 L .29771 .56572 L F
.447 .326 .622 r
.29911 .5653 m .2979 .56814 L .29771 .56572 L F
0 0 0 r
.48038 .61892 m .47872 .62207 L .47956 .61992 L F
.123 .139 .604 r
.39761 .6197 m .39922 .62209 L .39896 .61828 L F
.499 .507 .796 r
.79878 .41444 m .80006 .41029 L .7981 .41091 L F
.79878 .41444 m .80113 .41398 L .80006 .41029 L F
.686 .361 .42 r
.45868 .58863 m .4625 .58656 L .45871 .58611 L F
.45868 .58863 m .46204 .58871 L .4625 .58656 L F
.561 .305 .485 r
.46204 .58871 m .46483 .58599 L .4625 .58656 L F
.729 .727 .848 r
.83705 .43272 m .83647 .42972 L .83332 .43226 L F
.771 .55 .6 r
.83332 .43226 m .83442 .43759 L .83705 .43272 L F
.776 .77 .847 r
.83705 .43272 m .83839 .42838 L .83647 .42972 L F
.83705 .43272 m .8402 .42991 L .83839 .42838 L F
.6 .598 .821 r
.17372 .61941 m .17157 .62033 L .17031 .61672 L F
.813 .531 .512 r
.21418 .69453 m .21789 .69137 L .21623 .69093 L F
.869 .425 .095 r
.49026 .54136 m .48951 .54244 L .48871 .54042 L F
.49026 .54136 m .49142 .54366 L .48951 .54244 L F
.62 .936 .96 r
.54673 .6124 m .54763 .611 L .54539 .61186 L F
.54673 .6124 m .54986 .61117 L .54763 .611 L F
.891 .949 .595 r
.58731 .54705 m .5883 .54553 L .58727 .54412 L F
.58731 .54705 m .58771 .54661 L .5883 .54553 L F
.356 .045 .293 r
.45882 .61618 m .45576 .61944 L .4568 .6164 L F
0 0 .03 r
.40424 .60492 m .40343 .6071 L .40533 .60375 L F
.872 .722 .694 r
.52893 .52629 m .52728 .52635 L .52804 .52347 L F
0 .208 .726 r
.52893 .52629 m .52948 .52543 L .52728 .52635 L F
.414 .373 .704 r
.53021 .52726 m .53083 .52862 L .52893 .52629 L F
0 .208 .726 r
.52893 .52629 m .53083 .52862 L .52948 .52543 L F
.8 .511 .5 r
.67077 .41493 m .66725 .41649 L .66875 .41357 L F
.67077 .41493 m .66871 .4171 L .66725 .41649 L F
.775 .473 .477 r
.67077 .41493 m .67091 .41727 L .66871 .4171 L F
.805 .498 .47 r
.67428 .4177 m .67091 .41727 L .67077 .41493 L F
.458 .836 .988 r
.44064 .61344 m .43927 .61311 L .43691 .61363 L F
.122 0 .285 r
.42885 .6519 m .42639 .65581 L .42702 .65283 L F
.459 .365 .661 r
.44876 .63047 m .44532 .62995 L .44846 .62809 L F
.402 .121 .369 r
.40117 .60772 m .40063 .60992 L .40343 .6071 L F
.994 .846 .584 r
.59098 .50386 m .59133 .50745 L .59229 .50511 L F
.747 .71 .817 r
.59229 .50511 m .59305 .5012 L .59098 .50386 L F
.59229 .50511 m .59502 .5023 L .59305 .5012 L F
.573 .609 .85 r
.21586 .68213 m .21704 .68541 L .21916 .6835 L F
.66 .778 .936 r
.21916 .6835 m .21704 .68541 L .22005 .68508 L F
.586 .256 .377 r
.45194 .61003 m .45402 .60988 L .45439 .60801 L F
.635 .565 .758 r
.45938 .60801 m .46017 .60801 L .45982 .60767 L F
.551 .191 .31 r
.45402 .60988 m .46017 .60801 L .45439 .60801 L F
.812 .542 .531 r
.45649 .60443 m .46017 .60801 L .46024 .60726 L F
.551 .191 .31 r
.45402 .60988 m .45692 .60996 L .46017 .60801 L F
0 0 0 r
.46017 .60801 m .4588 .60888 L .46024 .60726 L F
.4605 .60713 m .4588 .60888 L .46143 .60667 L F
.46024 .60726 m .46002 .60751 L .4605 .60713 L F
.46002 .60751 m .4588 .60888 L .4605 .60713 L F
.635 .565 .758 r
.45439 .60801 m .45938 .60801 L .45649 .60443 L F
.45938 .60801 m .45982 .60767 L .45649 .60443 L F
0 .009 .581 r
.53125 .58947 m .53238 .59285 L .5322 .59121 L F
0 .031 .596 r
.53338 .59497 m .5322 .59121 L .53238 .59285 L F
.507 .712 .964 r
.75708 .42819 m .75803 .42976 L .75962 .42787 L F
.428 .593 .912 r
.75803 .42976 m .76007 .4297 L .75962 .42787 L F
0 0 0 r
.15035 .59559 m .15169 .59499 L .15219 .59471 L F
.414 .863 .862 r
.15 .59563 m .15169 .59499 L .15035 .59559 L F
.812 .726 .77 r
.55521 .58271 m .55653 .58588 L .55324 .58585 L F
.55521 .58271 m .55653 .58588 L .55324 .58585 L F
.817 .684 .718 r
.55324 .58585 m .55418 .58905 L .55653 .58588 L F
.675 .222 .169 r
.55653 .58588 m .55506 .5878 L .55324 .58585 L F
.612 .663 .875 r
.55751 .58216 m .55653 .58588 L .55521 .58271 L F
.55751 .58216 m .55939 .58513 L .55653 .58588 L F
.55751 .58216 m .55653 .58588 L .55521 .58271 L F
.55751 .58216 m .55939 .58513 L .55653 .58588 L F
.612 .661 .874 r
.55653 .58588 m .55988 .58686 L .55939 .58513 L F
.328 0 .016 r
.55939 .58513 m .55506 .5878 L .55653 .58588 L F
.507 .153 .3 r
.5553 .50811 m .55402 .51065 L .55167 .51089 L F
.568 .216 .332 r
.55768 .50973 m .55402 .51065 L .5553 .50811 L F
.583 .201 .284 r
.55795 .50832 m .55768 .50973 L .5553 .50811 L F
.553 .931 .835 r
.42733 .57898 m .42643 .58009 L .4253 .58028 L F
.4253 .58028 m .42643 .58009 L .42733 .57898 L F
0 .189 .714 r
.53153 .55895 m .53355 .56086 L .53283 .56185 L F
.02 .293 .788 r
.53355 .56086 m .53574 .56418 L .53283 .56185 L F
.748 .752 .855 r
.71104 .4172 m .71471 .41791 L .71345 .41618 L F
.789 .762 .829 r
.71345 .41618 m .71471 .41791 L .71731 .41506 L F
.288 0 .238 r
.50693 .60414 m .50632 .6067 L .50421 .60744 L F
.425 .244 .53 r
.50421 .60744 m .50632 .6067 L .50705 .60415 L F
.50664 .60436 m .50705 .60415 L .50719 .60367 L F
.50421 .60744 m .50705 .60415 L .50664 .60436 L F
0 0 0 r
.50998 .60247 m .5079 .6037 L .50693 .60414 L F
.5079 .6037 m .50742 .60398 L .50728 .60403 L F
.5079 .6037 m .50728 .60403 L .50693 .60414 L F
.516 .415 .679 r
.50742 .60398 m .50632 .6067 L .50693 .60414 L F
.525 .668 .927 r
.19513 .62497 m .19517 .62762 L .19331 .62513 L F
.19513 .62497 m .1973 .62741 L .19517 .62762 L F
.71 .53 .644 r
.5723 .48671 m .5746 .48378 L .57234 .48414 L F
.5723 .48671 m .57649 .48692 L .5746 .48378 L F
.779 .548 .586 r
.5746 .48378 m .57649 .48692 L .57835 .48694 L F
.501 .294 .53 r
.29196 .601 m .28948 .60398 L .28988 .60163 L F
.585 .402 .6 r
.81932 .40866 m .81965 .41117 L .81694 .41171 L F
.529 .654 .914 r
.81888 .40721 m .8217 .40843 L .81932 .40866 L F
.519 .355 .599 r
.8217 .40843 m .81965 .41117 L .81932 .40866 L F
.738 .99 .804 r
.52251 .53719 m .51969 .53967 L .52165 .53888 L F
.349 .819 .756 r
.68619 .43419 m .68315 .43531 L .68373 .43531 L F
.307 .783 .923 r
.261 .53838 m .26056 .53907 L .25872 .53818 L F
.261 .53838 m .26277 .53878 L .26056 .53907 L F
.998 .79 .492 r
.75727 .38882 m .75819 .39015 L .75531 .39007 L F
.589 .413 .612 r
.28242 .61332 m .27999 .61632 L .27996 .61359 L F
0 0 0 r
.51073 .60266 m .50998 .60247 L .51092 .60281 L F
.663 .895 .549 r
.51073 .60266 m .50927 .60414 L .51054 .60252 L F
0 0 .301 r
.51067 .60003 m .51073 .60266 L .51169 .60106 L F
.663 .895 .549 r
.51073 .60266 m .51054 .60252 L .51169 .60106 L F
0 0 0 r
.51073 .60266 m .51092 .60281 L .51222 .60328 L F
.51073 .60266 m .50742 .60398 L .50998 .60247 L F
.783 .704 .776 r
.41031 .61741 m .40989 .61932 L .41219 .61664 L F
.621 .456 .637 r
.40989 .61932 m .4125 .61916 L .41219 .61664 L F
.895 .703 .635 r
.68074 .42613 m .67787 .42579 L .67921 .42266 L F
.881 .787 .752 r
.68074 .42613 m .679 .42818 L .67787 .42579 L F
.438 .874 .9 r
.20111 .54026 m .20167 .5395 L .20321 .53986 L F
.20111 .54026 m .19949 .54029 L .20167 .5395 L F
.684 .5 .631 r
.5699 .48674 m .5723 .48671 L .57234 .48414 L F
0 .288 .788 r
.40675 .63152 m .40703 .63031 L .40462 .62852 L F
0 .079 .639 r
.40675 .63152 m .40858 .63372 L .40703 .63031 L F
.227 0 0 r
.43756 .63398 m .4398 .63429 L .43901 .63406 L F
.515 .29 .512 r
.48559 .57161 m .48452 .5744 L .4869 .57361 L F
.89 .826 .356 r
.54137 .57941 m .54051 .58302 L .54108 .58288 L F
.79 .637 .078 r
.54087 .58445 m .54108 .58288 L .54051 .58302 L F
.54087 .58445 m .54105 .58625 L .54108 .58288 L F
.876 .482 .02 r
.52519 .55028 m .52618 .55298 L .52716 .55388 L F
.498 .801 .999 r
.52863 .55237 m .52716 .55388 L .52618 .55298 L F
.52863 .55237 m .52983 .55331 L .52716 .55388 L F
.687 .567 .713 r
.29341 .55004 m .29166 .55171 L .29232 .55158 L F
.394 .297 .626 r
.2594 .59277 m .26163 .59447 L .26128 .59159 L F
.2594 .59277 m .25973 .59531 L .26163 .59447 L F
.47 .811 .999 r
.17879 .6465 m .18044 .64739 L .18257 .64689 L F
.394 .789 .987 r
.22118 .64789 m .22199 .64684 L .2193 .6475 L F
.22118 .64789 m .22353 .64757 L .22199 .64684 L F
.32 .796 .913 r
.19595 .64698 m .19943 .64684 L .19739 .6466 L F
.294 .781 .904 r
.19739 .6466 m .19943 .64684 L .20044 .64646 L F
.598 .653 .875 r
.51701 .52204 m .51992 .52064 L .51705 .52125 L F
.51701 .52204 m .51984 .52159 L .51992 .52064 L F
.356 .671 .975 r
.18178 .62121 m .18364 .62271 L .18136 .6227 L F
0 0 .2 r
.53991 .58869 m .54007 .59196 L .5415 .58938 L F
.937 .831 .714 r
.54105 .58625 m .5415 .58938 L .54168 .58665 L F
.54105 .58625 m .53991 .58869 L .5415 .58938 L F
.609 .728 .929 r
.81729 .40487 m .81603 .40808 L .81462 .40514 L F
.81729 .40487 m .81888 .40721 L .81603 .40808 L F
.097 0 .269 r
.66422 .40933 m .66279 .40856 L .66531 .40927 L F
.66422 .40933 m .66198 .41087 L .66279 .40856 L F
.834 .874 .435 r
.57169 .55622 m .57037 .5598 L .57069 .55779 L F
.938 .902 .509 r
.57037 .5598 m .56933 .56067 L .57069 .55779 L F
.57037 .5598 m .56954 .56186 L .56933 .56067 L F
.693 .873 .966 r
.25804 .55816 m .25684 .55631 L .25596 .55621 L F
.702 .58 .715 r
.52013 .53317 m .51785 .53557 L .51626 .53184 L F
.737 .502 .574 r
.67124 .41126 m .67505 .40862 L .67151 .40811 L F
.67124 .41126 m .67506 .41096 L .67505 .40862 L F
.431 .217 .487 r
.2553 .60157 m .25738 .60099 L .25769 .59854 L F
.465 .287 .554 r
.2553 .60157 m .25732 .6036 L .25738 .60099 L F
.2553 .60157 m .25516 .60422 L .25732 .6036 L F
.567 .413 .631 r
.48933 .58823 m .48649 .586 L .49086 .58595 L F
0 0 0 r
.49334 .58622 m .48933 .58823 L .49086 .58595 L F
.356 .483 .85 r
.55939 .58513 m .55988 .58686 L .56123 .58519 L F
.463 .643 .935 r
.55988 .58686 m .56174 .58597 L .56167 .58587 L F
.55988 .58686 m .56167 .58587 L .56082 .5857 L F
.435 .439 .764 r
.55988 .58686 m .56272 .58885 L .56174 .58597 L F
.376 .118 .39 r
.55919 .58537 m .56113 .58734 L .55749 .58741 L F
.55939 .58513 m .55965 .58546 L .55919 .58537 L F
.55965 .58546 m .56113 .58734 L .55919 .58537 L F
.463 .643 .935 r
.56082 .5857 m .56167 .58587 L .56123 .58519 L F
.126 .478 .897 r
.78978 .39059 m .78707 .39062 L .78644 .38897 L F
.78978 .39059 m .79036 .39202 L .78707 .39062 L F
.356 .503 .867 r
.79058 .39382 m .78707 .39062 L .79036 .39202 L F
.79058 .39382 m .79094 .39434 L .78707 .39062 L F
.426 .171 .423 r
.27212 .62509 m .26946 .62807 L .26988 .62555 L F
.327 0 .01 r
.4678 .62623 m .46417 .62828 L .4618 .62857 L F
.774 .532 .569 r
.46794 .62847 m .4678 .62623 L .46793 .62582 L F
.46794 .62847 m .46417 .62828 L .4678 .62623 L F
.743 .509 .576 r
.57649 .48692 m .57852 .48941 L .57835 .48694 L F
.395 .178 .462 r
.28948 .60398 m .28708 .6071 L .28732 .60459 L F
.623 .573 .778 r
.45404 .59191 m .45657 .59165 L .45611 .58982 L F
.446 .329 .626 r
.45491 .5957 m .45657 .59165 L .45404 .59191 L F
.338 .123 .433 r
.26476 .56128 m .26703 .55863 L .26487 .55949 L F
.577 .814 .989 r
.20271 .64878 m .20329 .64709 L .20044 .64646 L F
.20271 .64878 m .20482 .64818 L .20329 .64709 L F
.41 0 .115 r
.43968 .64103 m .436 .64319 L .43628 .64096 L F
.43968 .64103 m .43839 .64297 L .436 .64319 L F
.716 .32 .297 r
.4419 .64322 m .43839 .64297 L .43968 .64103 L F
.354 .011 .237 r
.25936 .63478 m .25845 .63668 L .25619 .6372 L F
.448 .151 .367 r
.26144 .63407 m .25845 .63668 L .25936 .63478 L F
.488 .495 .791 r
.44148 .59742 m .4406 .60145 L .43993 .59828 L F
.44148 .59742 m .44274 .60107 L .4406 .60145 L F
.597 .561 .785 r
.44515 .60043 m .44274 .60107 L .44148 .59742 L F
.44515 .60043 m .44148 .59742 L .44336 .59633 L F
.596 .37 .544 r
.44033 .59892 m .44325 .59643 L .44148 .59742 L F
.44325 .59643 m .44336 .59633 L .44148 .59742 L F
.488 .495 .791 r
.44148 .59742 m .43993 .59828 L .43984 .59786 L F
.577 .022 0 r
.49604 .56701 m .49737 .56811 L .49815 .56846 L F
0 .235 .745 r
.49618 .5664 m .49737 .56811 L .49604 .56701 L F
.977 .682 .309 r
.49618 .5664 m .49633 .56765 L .49737 .56811 L F
.49633 .56765 m .4965 .56914 L .49737 .56811 L F
.577 .022 0 r
.49815 .56846 m .49737 .56811 L .49885 .56895 L F
0 .016 .526 r
.49986 .56985 m .49885 .56895 L .49737 .56811 L F
.49986 .56985 m .5008 .57089 L .49885 .56895 L F
0 0 0 r
.41737 .62252 m .41499 .62466 L .41345 .62507 L F
.28 0 0 r
.42011 .62285 m .41499 .62466 L .41737 .62252 L F
.596 .313 .457 r
.46737 .5805 m .46709 .58264 L .47017 .5823 L F
.615 .603 .815 r
.46737 .5805 m .47067 .58214 L .46962 .58033 L F
0 0 .489 r
.53338 .59497 m .53381 .59868 L .53406 .59835 L F
.782 .585 .018 r
.53434 .60119 m .53406 .59835 L .53381 .59868 L F
.861 .764 .754 r
.76379 .41441 m .7604 .41607 L .76262 .41296 L F
.76379 .41441 m .76185 .41771 L .7604 .41607 L F
.553 .474 .721 r
.43876 .60966 m .43691 .61363 L .43635 .61047 L F
.43876 .60966 m .43927 .61311 L .43691 .61363 L F
.576 .162 .221 r
.43927 .61311 m .4352 .61466 L .43691 .61363 L F
.681 .479 .605 r
.43171 .60349 m .43428 .60157 L .43171 .60193 L F
.43171 .60349 m .43405 .60456 L .43428 .60157 L F
.051 .15 .649 r
.43373 .59878 m .43428 .60157 L .4353 .60015 L F
.233 .412 .835 r
.43428 .60157 m .43715 .60353 L .4353 .60015 L F
.233 .528 .919 r
.79991 .39771 m .79888 .39888 L .79803 .39728 L F
.229 .522 .916 r
.80064 .39931 m .79888 .39888 L .79991 .39771 L F
.424 .256 .548 r
.25026 .60763 m .25218 .60955 L .2523 .60696 L F
.349 .25 .599 r
.25026 .60763 m .25051 .61033 L .25218 .60955 L F
.835 .745 .765 r
.45532 .62872 m .4521 .62805 L .45423 .62502 L F
.889 .875 .816 r
.45532 .62872 m .45158 .63049 L .4521 .62805 L F
.45532 .62872 m .4531 .63145 L .45158 .63049 L F
.597 .401 .587 r
.45532 .62872 m .45546 .63158 L .4531 .63145 L F
.654 .446 .589 r
.4585 .63081 m .45546 .63158 L .45532 .62872 L F
.65 .487 .65 r
.81694 .41171 m .81717 .41426 L .81454 .41455 L F
.599 .449 .65 r
.81694 .41171 m .81965 .41117 L .81717 .41426 L F
.427 0 0 r
.49775 .54738 m .49735 .54817 L .494 .54678 L F
.892 .695 .628 r
.50018 .54914 m .49735 .54817 L .49775 .54738 L F
.531 .309 .523 r
.53236 .54729 m .53513 .54657 L .53478 .54922 L F
.53236 .54729 m .53513 .54657 L .53478 .54922 L F
.771 .335 .214 r
.50618 .5988 m .50458 .60005 L .50227 .59748 L F
.446 .329 .626 r
.45491 .5957 m .45699 .59518 L .45657 .59165 L F
.398 .33 .664 r
.45563 .59835 m .45699 .59518 L .45491 .5957 L F
.854 .832 .359 r
.42214 .65805 m .42141 .66134 L .42213 .65915 L F
.692 .586 .732 r
.56723 .48965 m .56996 .4898 L .5699 .48674 L F
.553 .262 .426 r
.56723 .48965 m .56853 .49109 L .56996 .4898 L F
.56723 .48965 m .56661 .49193 L .56853 .49109 L F
.852 .406 .15 r
.5008 .57089 m .502 .57272 L .50286 .5716 L F
.806 .337 .113 r
.502 .57272 m .50453 .57404 L .50286 .5716 L F
0 0 0 r
.17184 .5505 m .17188 .55125 L .17393 .54983 L F
.17184 .5505 m .16984 .55204 L .17188 .55125 L F
.8 .622 .661 r
.58602 .49245 m .58843 .48959 L .58593 .48983 L F
.58602 .49245 m .5897 .49305 L .58843 .48959 L F
.617 .212 .252 r
.49245 .60036 m .48992 .59911 L .4902 .60049 L F
.064 .33 .809 r
.26528 .57805 m .26722 .5784 L .26413 .57687 L F
.26528 .57805 m .26757 .5795 L .26722 .5784 L F
.196 .339 .782 r
.26668 .58037 m .26757 .5795 L .26528 .57805 L F
.606 .411 .592 r
.50119 .60792 m .50421 .60744 L .50393 .60413 L F
.519 .581 .857 r
.50393 .60413 m .50719 .60367 L .50458 .60005 L F
.425 .244 .53 r
.50421 .60744 m .50719 .60367 L .50393 .60413 L F
.522 .887 .975 r
.51879 .53115 m .51919 .53027 L .51626 .53184 L F
.302 0 0 r
.51809 .53153 m .51879 .53115 L .51626 .53184 L F
.505 .678 .943 r
.51952 .53129 m .52013 .53317 L .51691 .53206 L F
.51871 .53143 m .51691 .53206 L .51626 .53184 L F
.51952 .53129 m .51691 .53206 L .51871 .53143 L F
.131 0 0 r
.5185 .5315 m .52219 .52957 L .51879 .53115 L F
.754 .833 .913 r
.52256 .53144 m .52013 .53317 L .51948 .53115 L F
.627 .961 .882 r
.52101 .52926 m .51879 .53115 L .52219 .52957 L F
.52101 .52926 m .51919 .53027 L .51879 .53115 L F
.754 .833 .913 r
.52037 .53068 m .51948 .53115 L .51919 .53027 L F
.52256 .53144 m .51948 .53115 L .52037 .53068 L F
.131 0 0 r
.51724 .53301 m .52036 .53084 L .51948 .53115 L F
.51824 .53181 m .51948 .53115 L .5185 .5315 L F
.51724 .53301 m .51948 .53115 L .51824 .53181 L F
.754 .833 .913 r
.52156 .53003 m .51919 .53027 L .52101 .52926 L F
.52256 .53144 m .52037 .53068 L .52141 .53011 L F
.52256 .53144 m .52141 .53011 L .52156 .53004 L F
.331 .191 .535 r
.52219 .52957 m .52361 .52767 L .52101 .52926 L F
.52219 .52957 m .52236 .52966 L .52361 .52767 L F
.306 .299 .687 r
.52361 .52767 m .52322 .52908 L .5227 .52912 L F
.52196 .5298 m .52256 .53144 L .52156 .53004 L F
.39 .152 .427 r
.52225 .52977 m .52219 .52957 L .52196 .5298 L F
.306 .299 .687 r
.52322 .52908 m .52305 .52969 L .52196 .5298 L F
.52305 .52969 m .52256 .53144 L .52203 .52999 L F
.52305 .52969 m .52203 .52999 L .52225 .52977 L F
.39 .152 .427 r
.52302 .53263 m .52393 .53053 L .52236 .52966 L F
.52225 .52977 m .52236 .52966 L .52219 .52957 L F
.52302 .53263 m .52236 .52966 L .52225 .52977 L F
.306 .299 .687 r
.52225 .52977 m .52203 .52999 L .52196 .5298 L F
.39 .152 .427 r
.52302 .53263 m .52225 .52977 L .51957 .53227 L F
.52225 .52977 m .52196 .5298 L .51957 .53227 L F
.131 0 0 r
.52141 .53011 m .52156 .53004 L .52219 .52957 L F
.52156 .53004 m .52196 .5298 L .52219 .52957 L F
.306 .299 .687 r
.52322 .52908 m .52156 .53004 L .52101 .52926 L F
.331 .191 .535 r
.52236 .52966 m .52393 .53053 L .52361 .52767 L F
.306 .299 .687 r
.52361 .52767 m .5227 .52912 L .52101 .52926 L F
.131 0 0 r
.52156 .53004 m .52191 .52986 L .52196 .5298 L F
.51724 .53301 m .51957 .53227 L .52191 .52986 L F
.51724 .53301 m .52191 .52986 L .52141 .53011 L F
.754 .833 .913 r
.52156 .53004 m .52141 .53011 L .52156 .53003 L F
.131 0 0 r
.52141 .53011 m .52219 .52957 L .51955 .53113 L F
.754 .833 .913 r
.52037 .53068 m .51919 .53027 L .52156 .53003 L F
.131 0 0 r
.51955 .53113 m .52219 .52957 L .5185 .5315 L F
.52036 .53084 m .52141 .53011 L .51955 .53113 L F
.302 0 0 r
.5147 .53336 m .51724 .53301 L .5185 .5315 L F
.51809 .53153 m .5185 .5315 L .51879 .53115 L F
.5147 .53336 m .5185 .5315 L .51809 .53153 L F
.505 .678 .943 r
.51919 .53027 m .51952 .53129 L .51809 .53153 L F
.51662 .53164 m .51809 .53153 L .51626 .53184 L F
.51919 .53027 m .51809 .53153 L .51662 .53164 L F
.302 0 0 r
.5147 .53336 m .51809 .53153 L .51626 .53184 L F
.816 .633 .654 r
.58597 .49504 m .5897 .49305 L .58602 .49245 L F
.58597 .49504 m .58974 .49573 L .5897 .49305 L F
.659 .557 .728 r
.79639 .4327 m .79956 .43285 L .79841 .42991 L F
.488 .176 .362 r
.7965 .43504 m .79956 .43285 L .79639 .4327 L F
.061 0 .053 r
.22005 .68508 m .22211 .68392 L .22282 .68581 L F
.22005 .68508 m .21848 .68794 L .22211 .68392 L F
.436 .04 .188 r
.74364 .37826 m .74614 .37972 L .74322 .38056 L F
.74364 .37826 m .74631 .37788 L .74614 .37972 L F
.551 .921 .767 r
.20302 .71806 m .20481 .71737 L .20198 .71913 L F
.558 .014 0 r
.20692 .71872 m .20481 .71737 L .20302 .71806 L F
.995 .824 .56 r
.77362 .40477 m .77416 .40818 L .77551 .40645 L F
.77362 .40477 m .77307 .40716 L .77416 .40818 L F
.938 .934 .769 r
.77153 .41001 m .77416 .40818 L .77307 .40716 L F
.766 .542 .593 r
.67428 .4177 m .67029 .41971 L .67091 .41727 L F
.67428 .4177 m .67408 .41996 L .67029 .41971 L F
.432 .484 .813 r
.47326 .5571 m .47186 .56004 L .47091 .55747 L F
.276 .22 .612 r
.2666 .58293 m .26757 .5795 L .26668 .58037 L F
.391 .832 .944 r
.21298 .64803 m .21576 .6483 L .21607 .64791 L F
.476 .179 .382 r
.47662 .6129 m .47957 .61144 L .47649 .61067 L F
.956 .659 .226 r
.57169 .55622 m .57085 .55527 L .57055 .55283 L F
.834 .874 .435 r
.57169 .55622 m .57069 .55779 L .57085 .55527 L F
.599 .136 .125 r
.42184 .60625 m .42447 .60652 L .42574 .60537 L F
.182 0 0 r
.42574 .60537 m .42666 .60579 L .42794 .60476 L F
.42574 .60537 m .42447 .60652 L .42666 .60579 L F
.762 .343 0 r
.53574 .56418 m .53801 .5681 L .5364 .5653 L F
.639 .583 .776 r
.55128 .58888 m .55418 .58905 L .55324 .58585 L F
0 0 0 r
.54895 .5901 m .55418 .58905 L .55128 .58888 L F
.598 .104 .051 r
.54895 .5901 m .55128 .58888 L .54866 .5886 L F
.118 .224 .699 r
.19089 .78199 m .1912 .78232 L .19104 .78246 L F
0 0 0 r
.19104 .78246 m .1912 .78232 L .19083 .78269 L F
.368 .164 .467 r
.25769 .59854 m .25738 .60099 L .2596 .59782 L F
.326 .665 .974 r
.23222 .66036 m .23386 .66175 L .23422 .66042 L F
.971 .695 .45 r
.23222 .66036 m .23386 .66175 L .23422 .66042 L F
.23222 .66036 m .23392 .66463 L .23386 .66175 L F
.983 .725 .334 r
.23386 .66175 m .23392 .66463 L .23431 .66488 L F
.555 .267 .433 r
.69752 .41408 m .7002 .41388 L .70078 .41125 L F
.565 .288 .455 r
.70351 .41312 m .70078 .41125 L .7002 .41388 L F
.70351 .41312 m .70339 .41107 L .70078 .41125 L F
.685 .511 .645 r
.45273 .62552 m .44846 .62809 L .4498 .62495 L F
.665 .668 .843 r
.51984 .52159 m .52098 .52358 L .52284 .52203 L F
.131 0 0 r
.22049 .63074 m .21703 .63076 L .21924 .63049 L F
.517 .897 .959 r
.22265 .62988 m .22049 .63074 L .21924 .63049 L F
.665 .709 .88 r
.77551 .40645 m .77703 .40698 L .77669 .40634 L F
.67 .823 .957 r
.77669 .40634 m .77703 .40698 L .78093 .40615 L F
.445 .218 .474 r
.2986 .58235 m .29773 .58615 L .29556 .58643 L F
.339 .362 .739 r
.29928 .57868 m .2986 .58235 L .29807 .58148 L F
.29928 .57868 m .30018 .58287 L .2986 .58235 L F
.471 .25 .497 r
.30018 .58287 m .29773 .58615 L .2986 .58235 L F
.973 .758 .554 r
.5737 .54064 m .57219 .53972 L .57404 .5381 L F
.934 .964 .672 r
.57404 .5381 m .57219 .53972 L .57351 .53725 L F
.233 .551 .931 r
.79596 .39531 m .79479 .39632 L .79422 .39483 L F
.79596 .39531 m .79803 .39728 L .79479 .39632 L F
.406 .794 .989 r
.18873 .64589 m .19302 .64635 L .19113 .6455 L F
.093 .598 .894 r
.19302 .64635 m .19473 .64657 L .19113 .6455 L F
.228 .638 .957 r
.19302 .64635 m .19595 .64698 L .19473 .64657 L F
.756 .383 0 r
.50716 .57665 m .50807 .57907 L .50876 .57997 L F
.837 .385 0 r
.5087 .58153 m .50876 .57997 L .50807 .57907 L F
.5087 .58153 m .51001 .58258 L .50876 .57997 L F
.736 .325 0 r
.50876 .57997 m .51001 .58258 L .51078 .58365 L F
1 .802 .491 r
.44584 .64836 m .44714 .64974 L .44729 .64674 L F
.44584 .64836 m .44714 .64974 L .44729 .64674 L F
.703 .632 .775 r
.22213 .67814 m .21788 .67662 L .22065 .67609 L F
.649 .112 0 r
.22057 .67876 m .22213 .67814 L .22065 .67609 L F
.22057 .67876 m .22379 .67938 L .22213 .67814 L F
.917 .649 .156 r
.53983 .57084 m .54013 .57336 L .54079 .57468 L F
0 0 .33 r
.54013 .57336 m .54192 .57688 L .54079 .57468 L F
.583 .599 .834 r
.74159 .41232 m .7436 .40983 L .74085 .41051 L F
.74159 .41232 m .7441 .41154 L .7436 .40983 L F
.56 .306 .487 r
.41544 .59175 m .41875 .5894 L .41615 .5898 L F
.737 .73 .845 r
.74803 .41431 m .75185 .4149 L .75044 .41332 L F
.768 .781 .864 r
.75044 .41332 m .75185 .4149 L .75386 .41339 L F
.636 .801 .364 r
.53753 .51904 m .53562 .52247 L .5366 .52036 L F
.834 .991 .735 r
.40988 .60265 m .40948 .60459 L .41198 .60134 L F
.686 .566 .714 r
.40948 .60459 m .41318 .60457 L .41198 .60134 L F
.719 .434 .494 r
.40948 .60459 m .41313 .60698 L .41318 .60457 L F
.40948 .60459 m .40957 .60698 L .41313 .60698 L F
.974 .911 .682 r
.40988 .60265 m .40957 .60698 L .40948 .60459 L F
0 0 .2 r
.53991 .58869 m .54025 .59105 L .54007 .59196 L F
0 0 .538 r
.54025 .59105 m .54169 .59469 L .54007 .59196 L F
.53 .895 .971 r
.22353 .64757 m .22747 .64704 L .22611 .64674 L F
.555 .916 .955 r
.22611 .64674 m .22747 .64704 L .22946 .64616 L F
.535 .494 .757 r
.80444 .41928 m .80113 .41398 L .80068 .41834 L F
.358 .003 .22 r
.80257 .41992 m .80444 .41928 L .80068 .41834 L F
.772 .858 .914 r
.2218 .69423 m .21978 .6959 L .2177 .69506 L F
.754 .654 .751 r
.2218 .69423 m .21885 .69947 L .21978 .6959 L F
.062 .301 .787 r
.75498 .42644 m .7563 .42575 L .75402 .42491 L F
.75498 .42644 m .75708 .42819 L .7563 .42575 L F
.692 .286 .272 r
.19061 .78228 m .1912 .78232 L .19089 .78199 L F
.488 .555 .851 r
.16656 .63097 m .16807 .63395 L .17028 .63377 L F
.623 .422 .59 r
.81554 .42942 m .81541 .43305 L .81155 .43233 L F
.69 .394 .467 r
.81554 .42942 m .81764 .43183 L .81541 .43305 L F
.81554 .42942 m .8171 .42967 L .81764 .43183 L F
.999 .789 .481 r
.84097 .42293 m .84077 .42522 L .84175 .42648 L F
.866 .755 .738 r
.83839 .42838 m .84175 .42648 L .84077 .42522 L F
.83839 .42838 m .8402 .42991 L .84175 .42648 L F
0 0 .115 r
.58169 .57356 m .5811 .57585 L .57973 .57738 L F
0 0 .474 r
.5811 .57585 m .57999 .57999 L .57973 .57738 L F
.614 .299 .413 r
.4938 .60439 m .49074 .60615 L .49146 .60479 L F
.347 .752 .982 r
.20354 .73093 m .20179 .73122 L .19936 .73007 L F
.669 .354 .431 r
.69131 .41655 m .69499 .4166 L .69492 .41457 L F
.707 .515 .626 r
.69499 .4166 m .69752 .41408 L .69492 .41457 L F
.251 0 .091 r
.53405 .51328 m .53642 .51271 L .53705 .51125 L F
.347 0 .131 r
.53705 .51125 m .53854 .51216 L .53932 .51048 L F
.53705 .51125 m .53642 .51271 L .53854 .51216 L F
.688 .583 .732 r
.5699 .48674 m .56996 .4898 L .5723 .48671 L F
.641 .265 .316 r
.56853 .49109 m .57226 .49169 L .56996 .4898 L F
.596 .455 .66 r
.56996 .4898 m .57246 .48963 L .5723 .48671 L F
.563 .301 .478 r
.56996 .4898 m .57226 .49169 L .57246 .48963 L F
.611 .232 .3 r
.56119 .49462 m .56372 .49474 L .56126 .49295 L F
.528 .285 .49 r
.56126 .49295 m .56372 .49474 L .56379 .49249 L F
.822 .592 .037 r
.50999 .59252 m .50963 .59159 L .50939 .58894 L F
.50999 .59252 m .50963 .59159 L .50939 .58894 L F
.437 .818 .99 r
.23875 .53763 m .23823 .53879 L .23658 .53811 L F
.23875 .53763 m .2404 .53834 L .23823 .53879 L F
.889 .83 .362 r
.58708 .54824 m .58771 .54661 L .58731 .54705 L F
.355 .356 .722 r
.29928 .57868 m .29807 .58148 L .29695 .57722 L F
0 0 0 r
.51082 .52251 m .5097 .52436 L .50845 .52578 L F
.571 .939 .897 r
.5097 .52436 m .50749 .52558 L .50845 .52578 L F
.725 .63 .752 r
.81965 .41117 m .82085 .41494 L .81717 .41426 L F
.622 .528 .726 r
.82263 .41032 m .82085 .41494 L .81965 .41117 L F
.82263 .41032 m .82341 .41416 L .82085 .41494 L F
.098 .207 .69 r
.41528 .65879 m .41655 .65754 L .41466 .6552 L F
.565 0 0 r
.41528 .65879 m .41587 .65985 L .41655 .65754 L F
.649 .608 .795 r
.82605 .41341 m .82455 .41792 L .82341 .41416 L F
.82605 .41341 m .82718 .41711 L .82455 .41792 L F
.792 .564 .592 r
.68134 .41351 m .68498 .41405 L .68491 .41154 L F
.15 .234 .697 r
.41171 .64323 m .41249 .64684 L .41373 .64517 L F
.12 .175 .646 r
.41344 .64923 m .41373 .64517 L .41249 .64684 L F
.312 .564 .927 r
.79201 .39246 m .79058 .39382 L .79036 .39202 L F
.79201 .39246 m .79422 .39483 L .79058 .39382 L F
.519 .732 .971 r
.20709 .64703 m .20905 .64859 L .21119 .64808 L F
.363 .223 .553 r
.23078 .58657 m .23052 .58928 L .23226 .58847 L F
.965 .903 .708 r
.57213 .54629 m .57318 .54724 L .5719 .54941 L F
.587 .471 .688 r
.82152 .43233 m .81882 .43522 L .81764 .43183 L F
.82152 .43233 m .82138 .43419 L .81882 .43522 L F
.673 .594 .759 r
.82259 .43637 m .81882 .43522 L .82138 .43419 L F
.489 .249 .477 r
.26731 .62863 m .26696 .63145 L .26451 .63197 L F
.419 .19 .458 r
.26902 .63082 m .26731 .62863 L .26946 .62807 L F
.26902 .63082 m .26696 .63145 L .26731 .62863 L F
.223 .398 .826 r
.79716 .40857 m .79864 .40718 L .79643 .40709 L F
.79716 .40857 m .80006 .41029 L .79864 .40718 L F
.413 .384 .717 r
.7981 .41091 m .80006 .41029 L .79716 .40857 L F
.698 .65 .798 r
.46962 .58033 m .47067 .58214 L .47354 .58051 L F
.396 .217 .517 r
.46483 .58599 m .46709 .58264 L .46469 .58329 L F
.688 .277 .261 r
.67506 .41096 m .67765 .41306 L .67896 .41129 L F
.721 .318 .283 r
.67896 .41129 m .67765 .41306 L .68134 .41351 L F
.755 .665 .762 r
.42782 .60332 m .43171 .60349 L .43171 .60193 L F
.649 .523 .697 r
.81512 .43423 m .81155 .43233 L .81541 .43305 L F
.81512 .43423 m .81253 .43557 L .81155 .43233 L F
.98 .732 .486 r
.43396 .57585 m .43395 .57721 L .43517 .57736 L F
.43517 .57736 m .43395 .57721 L .43396 .57585 L F
0 0 .226 r
.43396 .57585 m .43367 .57682 L .43083 .5783 L F
.976 .727 .494 r
.43209 .57482 m .43396 .57585 L .43004 .57635 L F
0 0 .226 r
.43396 .57585 m .43083 .5783 L .43004 .57635 L F
.976 .727 .494 r
.43209 .57482 m .43367 .57684 L .43396 .57585 L F
.43367 .57684 m .43395 .57721 L .43396 .57585 L F
.86 .796 .786 r
.43618 .57328 m .43472 .57586 L .43209 .57482 L F
.43472 .57586 m .43395 .57721 L .43367 .57684 L F
0 0 .226 r
.43396 .57585 m .43404 .57649 L .43367 .57682 L F
.43404 .57649 m .43371 .5768 L .43367 .57682 L F
.86 .796 .786 r
.43472 .57586 m .43367 .57684 L .43209 .57482 L F
0 0 .226 r
.43404 .57649 m .43406 .57662 L .43371 .5768 L F
.306 .297 .685 r
.43472 .57586 m .43517 .57736 L .43395 .57721 L F
.86 .408 .057 r
.43675 .57818 m .43395 .57721 L .43517 .57736 L F
.43675 .57818 m .43587 .5784 L .43395 .57721 L F
0 0 .226 r
.43396 .57585 m .43395 .57721 L .43428 .57833 L F
.43406 .57662 m .43428 .57833 L .43258 .57831 L F
.43406 .57662 m .43258 .57831 L .43083 .5783 L F
.306 .297 .685 r
.43618 .57328 m .43587 .57454 L .43472 .57586 L F
.43587 .57454 m .43517 .57736 L .43472 .57586 L F
.43618 .57328 m .43675 .57818 L .43517 .57736 L F
.728 .831 .929 r
.48826 .60948 m .48619 .61123 L .48733 .61072 L F
0 0 0 r
.48557 .61242 m .48619 .61123 L .48826 .60948 L F
.166 .601 .937 r
.20439 .6296 m .2011 .62837 L .20311 .62822 L F
.332 .655 .971 r
.20521 .62843 m .20439 .6296 L .20311 .62822 L F
.20521 .62843 m .20728 .63013 L .20439 .6296 L F
.757 .545 .61 r
.47255 .62443 m .4767 .62553 L .47647 .62263 L F
.481 .175 .37 r
.47489 .62371 m .47269 .62306 L .47647 .62263 L F
.483 .856 .628 r
.47778 .6215 m .47647 .62263 L .47872 .62207 L F
.47778 .6215 m .47489 .62371 L .47647 .62263 L F
.487 .343 .61 r
.4789 .62469 m .4767 .62553 L .47647 .62263 L F
.4789 .62469 m .4767 .62553 L .47647 .62263 L F
0 0 .382 r
.50025 .52908 m .50126 .52739 L .5004 .52473 L F
.987 .776 .531 r
.50269 .52876 m .50126 .52739 L .50025 .52908 L F
.294 0 .03 r
.17811 .56558 m .17662 .56752 L .17428 .56795 L F
.17 0 0 r
.17862 .56685 m .17811 .56558 L .18056 .56517 L F
.17862 .56685 m .17662 .56752 L .17811 .56558 L F
.599 .347 .506 r
.16132 .57441 m .16077 .57708 L .15828 .57693 L F
.391 .159 .437 r
.16284 .57635 m .16132 .57441 L .16332 .57376 L F
.16284 .57635 m .16077 .57708 L .16132 .57441 L F
.335 .222 .573 r
.20198 .71913 m .20336 .72068 L .20302 .71806 L F
.20198 .71913 m .20221 .72189 L .20336 .72068 L F
.177 0 0 r
.2321 .62596 m .22818 .6284 L .23025 .62769 L F
.2 0 0 r
.23258 .6272 m .2321 .62596 L .23025 .62769 L F
.23258 .6272 m .23453 .62543 L .2321 .62596 L F
.984 .702 .371 r
.47431 .56115 m .47572 .56486 L .47562 .56232 L F
.503 .301 .538 r
.47562 .56232 m .47572 .56486 L .47818 .56163 L F
.339 .381 .758 r
.26629 .56513 m .26676 .56091 L .26476 .56128 L F
.26629 .56513 m .26765 .56454 L .26676 .56091 L F
.026 .174 .682 r
.26629 .56513 m .26804 .56719 L .26765 .56454 L F
0 0 .297 r
.57967 .58238 m .57953 .58488 L .57825 .5863 L F
0 0 .322 r
.57953 .58488 m .57799 .58878 L .57825 .5863 L F
.578 .938 .921 r
.54986 .61117 m .55088 .60994 L .54763 .611 L F
.54986 .61117 m .55433 .60909 L .55088 .60994 L F
.89 .988 .736 r
.7628 .40018 m .76207 .40295 L .76428 .39973 L F
.808 .996 .77 r
.76533 .39732 m .7628 .40018 L .76428 .39973 L F
.374 .058 .295 r
.42936 .64515 m .42757 .64384 L .43016 .64373 L F
.448 .162 .386 r
.70884 .40807 m .71133 .40726 L .71137 .40512 L F
.571 .393 .601 r
.71133 .40726 m .71395 .40422 L .71137 .40512 L F
.753 .445 .463 r
.68525 .4161 m .68873 .41453 L .68498 .41405 L F
.68525 .4161 m .68881 .41649 L .68873 .41453 L F
.662 .372 .47 r
.68881 .41649 m .69131 .41655 L .68873 .41453 L F
.347 .149 .463 r
.7139 .40212 m .71636 .40139 L .71605 .39883 L F
.435 .21 .472 r
.71395 .40422 m .71636 .40139 L .7139 .40212 L F
0 0 0 r
.41383 .59302 m .41307 .59411 L .41544 .59175 L F
0 0 .409 r
.51818 .59951 m .51749 .59868 L .51669 .59768 L F
.51818 .59951 m .51867 .60092 L .51749 .59868 L F
.481 .175 .37 r
.47489 .62371 m .47255 .62443 L .47269 .62306 L F
0 0 .429 r
.43138 .61851 m .43261 .62141 L .43264 .62009 L F
.271 0 .2 r
.46287 .56148 m .46481 .5618 L .46553 .55907 L F
.288 0 .205 r
.46553 .55907 m .46698 .56089 L .46832 .55763 L F
.46553 .55907 m .46481 .5618 L .46698 .56089 L F
.456 .851 .976 r
.20467 .55806 m .20591 .55713 L .20346 .55801 L F
.20467 .55806 m .20713 .55749 L .20591 .55713 L F
.628 .783 .956 r
.19731 .55838 m .19899 .55971 L .20125 .559 L F
.406 .815 .978 r
.25081 .55665 m .24624 .55659 L .24822 .55693 L F
.398 .33 .664 r
.45563 .59835 m .45744 .59783 L .45699 .59518 L F
0 .107 .661 r
.45563 .59835 m .45751 .60129 L .45744 .59783 L F
.266 .1 .461 r
.39871 .6132 m .40063 .60992 L .3984 .6106 L F
.42 .286 .591 r
.29869 .57433 m .29882 .57678 L .29695 .57722 L F
.436 .338 .646 r
.29882 .57678 m .29928 .57868 L .29695 .57722 L F
.657 .616 .796 r
.2231 .66847 m .22329 .66969 L .22568 .6675 L F
.558 .014 0 r
.20692 .71872 m .20302 .71806 L .20532 .71748 L F
.964 .77 .593 r
.20532 .71748 m .20525 .71786 L .20692 .71872 L F
.618 .927 .97 r
.20336 .72068 m .2087 .71964 L .20692 .71872 L F
.69 .254 .209 r
.20692 .71872 m .20302 .71806 L .20336 .72068 L F
.20692 .71872 m .20484 .72008 L .20302 .71806 L F
.964 .77 .593 r
.20525 .71786 m .20484 .72008 L .20692 .71872 L F
.618 .927 .97 r
.2087 .71964 m .20888 .71961 L .20692 .71872 L F
.435 .303 .602 r
.41111 .62558 m .41341 .62776 L .41143 .62776 L F
.612 .064 0 r
.41177 .62676 m .41111 .62558 L .4108 .62643 L F
.41177 .62676 m .41341 .62776 L .41111 .62558 L F
.626 .454 .63 r
.47052 .62531 m .46794 .62847 L .46793 .62582 L F
.835 .642 .643 r
.58995 .49885 m .59109 .4989 L .58974 .49573 L F
.767 .501 .533 r
.58736 .50096 m .59109 .4989 L .58995 .49885 L F
.58736 .50096 m .59126 .50165 L .59109 .4989 L F
.699 .449 .541 r
.59109 .4989 m .59126 .50165 L .59305 .5012 L F
.568 .67 .907 r
.73381 .40671 m .73437 .40823 L .7369 .40767 L F
.378 .366 .72 r
.29778 .55825 m .29684 .56201 L .29619 .55888 L F
.29778 .55825 m .29854 .56171 L .29684 .56201 L F
.134 .432 .871 r
.76279 .43206 m .76331 .43094 L .76007 .4297 L F
.76279 .43206 m .76402 .43271 L .76331 .43094 L F
.822 .791 .823 r
.4531 .63145 m .44917 .63285 L .45158 .63049 L F
.424 .273 .57 r
.45533 .63332 m .4531 .63145 L .45546 .63158 L F
.45533 .63332 m .4534 .63455 L .4531 .63145 L F
.595 .352 .519 r
.4457 .61576 m .44855 .61554 L .44913 .61243 L F
.419 .218 .498 r
.44913 .61243 m .45071 .61282 L .45194 .61003 L F
.446 .225 .485 r
.44855 .61554 m .45071 .61282 L .44913 .61243 L F
.739 .662 .775 r
.47337 .56545 m .46943 .56554 L .47156 .56529 L F
.241 0 0 r
.47337 .56545 m .47162 .56596 L .46943 .56554 L F
.502 .903 .787 r
.47485 .56418 m .47337 .56545 L .47572 .56486 L F
.47485 .56418 m .47162 .56596 L .47337 .56545 L F
.622 .594 .8 r
.16394 .61624 m .16027 .61345 L .16174 .61281 L F
.619 .665 .872 r
.16644 .61544 m .16394 .61624 L .16174 .61281 L F
.488 .821 .999 r
.2404 .53834 m .24262 .53788 L .24436 .53875 L F
.323 .769 .96 r
.24502 .53776 m .24436 .53875 L .24262 .53788 L F
.24502 .53776 m .2467 .53852 L .24436 .53875 L F
.169 .297 .753 r
.77149 .42778 m .77038 .4296 L .76909 .42581 L F
.187 .322 .769 r
.773 .43152 m .77038 .4296 L .77149 .42778 L F
.905 .591 .101 r
.41259 .63416 m .41313 .637 L .41368 .63732 L F
.963 .83 .406 r
.41326 .63372 m .41313 .637 L .41259 .63416 L F
.41326 .63372 m .41237 .63655 L .41313 .637 L F
.41237 .63655 m .41221 .63705 L .41313 .637 L F
.905 .591 .101 r
.41368 .63732 m .41313 .637 L .41376 .63755 L F
.728 .31 .253 r
.41227 .63917 m .41376 .63755 L .41313 .637 L F
.41227 .63917 m .41587 .6399 L .41376 .63755 L F
.747 .226 0 r
.41376 .63755 m .41587 .6399 L .41763 .6405 L F
.38 .23 .549 r
.43655 .57139 m .43866 .56769 L .43625 .56821 L F
.064 0 .224 r
.49074 .60615 m .48826 .60948 L .48892 .60757 L F
.536 .691 .939 r
.73925 .40167 m .73523 .39997 L .73807 .39927 L F
.583 .692 .917 r
.7417 .40099 m .73925 .40167 L .73807 .39927 L F
.179 0 .198 r
.71869 .39593 m .71605 .39883 L .71871 .39811 L F
0 0 0 r
.72077 .3946 m .72191 .3938 L .71869 .39593 L F
.329 .034 .303 r
.71869 .39593 m .72109 .39711 L .72077 .3946 L F
.71869 .39593 m .71871 .39811 L .72109 .39711 L F
.396 .503 .85 r
.42223 .6371 m .42385 .64045 L .42486 .63814 L F
.028 .064 .563 r
.42385 .64045 m .42541 .64247 L .42486 .63814 L F
0 0 0 r
.72432 .39231 m .72191 .3938 L .72077 .3946 L F
.558 .646 .893 r
.77929 .43731 m .77931 .44145 L .77771 .43811 L F
.77929 .43731 m .78184 .44094 L .77931 .44145 L F
0 0 .379 r
.72687 .39227 m .72798 .39575 L .72711 .39358 L F
.582 .405 .608 r
.44351 .61923 m .4457 .61576 L .44379 .61648 L F
.493 .317 .571 r
.26144 .58915 m .26371 .58865 L .26403 .58583 L F
.521 .325 .555 r
.26128 .59159 m .26371 .58865 L .26144 .58915 L F
.148 .455 .884 r
.49173 .57052 m .49214 .5696 L .48931 .56833 L F
0 0 0 r
.49173 .57052 m .49109 .57248 L .49214 .5696 L F
.638 .634 .83 r
.45744 .59783 m .45751 .60129 L .46059 .59975 L F
.306 0 .002 r
.80167 .44126 m .79794 .44336 L .79811 .4423 L F
.553 .426 .661 r
.20999 .69815 m .21243 .69437 L .20943 .69491 L F
.458 .763 .995 r
.23556 .64436 m .24295 .64608 L .23821 .64405 L F
.08 0 0 r
.23556 .64436 m .23821 .64405 L .23811 .64407 L F
.568 .81 .99 r
.23696 .64735 m .23556 .64436 L .23384 .64455 L F
.23696 .64735 m .2393 .64703 L .23556 .64436 L F
.08 0 0 r
.23556 .64436 m .23811 .64407 L .23451 .64469 L F
.568 .81 .99 r
.23384 .64455 m .23556 .64436 L .23367 .64439 L F
.167 .483 .899 r
.18308 .64363 m .1833 .64243 L .18143 .64036 L F
0 0 0 r
.18585 .64443 m .18494 .64495 L .18682 .64253 L F
.18493 .64495 m .18564 .64453 L .18682 .64253 L F
.18494 .64495 m .18495 .64494 L .18682 .64253 L F
.771 .597 .663 r
.1833 .64243 m .18566 .64428 L .18682 .64253 L F
.845 .96 .625 r
.18682 .64253 m .18564 .64453 L .18594 .64386 L F
.771 .597 .663 r
.18566 .64428 m .18585 .64443 L .18682 .64253 L F
.845 .96 .625 r
.18682 .64253 m .18607 .64366 L .18636 .64294 L F
.771 .597 .663 r
.1833 .64243 m .18682 .64253 L .18749 .64312 L F
.569 .692 .924 r
.1833 .64243 m .18633 .64293 L .18384 .64026 L F
.062 .09 .577 r
.18799 .64151 m .18749 .64312 L .18682 .64253 L F
.559 .623 .873 r
.18636 .64294 m .18799 .64151 L .18682 .64253 L F
.18636 .64294 m .18726 .6431 L .18799 .64151 L F
.569 .692 .924 r
.18729 .64309 m .18749 .64312 L .1874 .64305 L F
.559 .623 .873 r
.18726 .6431 m .1896 .64351 L .18881 .64253 L F
.18726 .6431 m .1874 .64305 L .18799 .64151 L F
.708 .242 .144 r
.18799 .64151 m .18384 .64026 L .1874 .64305 L F
.18799 .64151 m .1874 .64305 L .18749 .64312 L F
.559 .623 .873 r
.1874 .64305 m .18881 .64253 L .18799 .64151 L F
.569 .692 .924 r
.18633 .64293 m .18729 .64309 L .18653 .64236 L F
.18729 .64309 m .1874 .64305 L .18653 .64236 L F
.18633 .64293 m .18653 .64236 L .18384 .64026 L F
.845 .96 .625 r
.18607 .64366 m .18594 .64386 L .18622 .64324 L F
.18607 .64366 m .18622 .64324 L .18636 .64294 L F
.163 .484 .9 r
.18564 .64453 m .18494 .64495 L .18564 .64455 L F
0 0 0 r
.18493 .64495 m .18468 .64614 L .18564 .64453 L F
.845 .96 .625 r
.18564 .64453 m .18468 .64614 L .18566 .64427 L F
.18564 .64453 m .18566 .64427 L .18636 .64294 L F
.163 .484 .9 r
.18582 .64442 m .18564 .64453 L .18585 .64443 L F
.18564 .64453 m .18564 .64455 L .18585 .64443 L F
.18308 .64363 m .18494 .64495 L .18582 .64442 L F
0 0 0 r
.18494 .64495 m .18493 .64495 L .18495 .64494 L F
.493 .403 .682 r
.18468 .64614 m .18705 .64577 L .18679 .64474 L F
.18566 .64427 m .18679 .64474 L .18636 .64294 L F
.167 .483 .899 r
.18582 .64442 m .18585 .64443 L .18583 .64441 L F
.493 .403 .682 r
.18468 .64614 m .18679 .64474 L .18566 .64427 L F
.167 .483 .899 r
.18308 .64363 m .18582 .64442 L .18559 .64423 L F
.18315 .64322 m .18559 .64423 L .1833 .64243 L F
.18308 .64363 m .18559 .64423 L .18315 .64322 L F
.18582 .64442 m .18583 .64441 L .1833 .64243 L F
.747 .382 .362 r
.18089 .64549 m .18468 .64614 L .18308 .64363 L F
.811 .383 .227 r
.18308 .64363 m .18468 .64614 L .18494 .64495 L F
0 .021 .579 r
.46839 .59853 m .46972 .59991 L .47006 .59787 L F
0 .358 .829 r
.23574 .64879 m .23761 .65033 L .23626 .64888 L F
.915 .966 .793 r
.76207 .40295 m .76014 .40333 L .76095 .40389 L F
.876 .986 .826 r
.7628 .40018 m .76014 .40333 L .76207 .40295 L F
.664 .235 0 r
.51001 .58258 m .51203 .5857 L .51078 .58365 L F
0 0 0 r
.58537 .55451 m .58472 .5562 L .58607 .55262 L F
0 0 .042 r
.58496 .55678 m .58472 .5562 L .58537 .55451 L F
.58496 .55678 m .58458 .55869 L .58472 .5562 L F
.778 .723 .801 r
.71731 .41506 m .7195 .41348 L .71838 .4104 L F
.755 .711 .811 r
.71838 .4104 m .7195 .41348 L .72197 .41091 L F
.322 .116 .436 r
.80075 .42617 m .80336 .42541 L .80319 .42271 L F
.307 .08 .397 r
.80301 .42709 m .80075 .42617 L .80115 .42763 L F
.80301 .42709 m .80336 .42541 L .80075 .42617 L F
.661 .778 .935 r
.65702 .44433 m .66082 .445 L .65946 .44314 L F
.794 .774 .835 r
.65946 .44314 m .66082 .445 L .66332 .44257 L F
.206 .725 .701 r
.18017 .54748 m .18035 .54748 L .17782 .54763 L F
.18017 .54748 m .18254 .54687 L .18035 .54748 L F
.855 .987 .714 r
.41248 .59919 m .41428 .59813 L .41264 .59727 L F
.41248 .59919 m .41198 .60134 L .41428 .59813 L F
.849 .889 .867 r
.41532 .59436 m .41428 .59813 L .41745 .59593 L F
.41532 .59436 m .41264 .59727 L .41428 .59813 L F
.22 0 .336 r
.40545 .60135 m .40777 .60061 L .40771 .59814 L F
.158 0 .324 r
.40533 .60375 m .40777 .60061 L .40545 .60135 L F
.754 .654 .751 r
.2218 .69423 m .22175 .69734 L .21885 .69947 L F
.595 .933 .737 r
.21885 .69947 m .22175 .69734 L .21895 .6989 L F
.066 .076 .559 r
.22294 .69537 m .22175 .69734 L .2218 .69423 L F
.764 .992 .786 r
.21895 .6989 m .22175 .69734 L .22294 .69537 L F
.889 .514 .321 r
.22861 .66719 m .22891 .66812 L .22873 .66816 L F
.22891 .66812 m .22936 .66951 L .22873 .66816 L F
.447 .879 .81 r
.22873 .66816 m .22908 .66844 L .23097 .66763 L F
.22873 .66816 m .23097 .66763 L .23109 .66757 L F
0 .13 .678 r
.77718 .44446 m .77816 .44412 L .77547 .44153 L F
0 .031 .591 r
.77718 .44446 m .77872 .4451 L .77816 .44412 L F
.77718 .44446 m .77886 .44697 L .77872 .4451 L F
.368 .072 .325 r
.70597 .4084 m .70339 .41107 L .7061 .41073 L F
.565 .304 .48 r
.70866 .4101 m .70597 .4084 L .7061 .41073 L F
.70866 .4101 m .70884 .40807 L .70597 .4084 L F
.298 0 0 r
.21673 .55242 m .21397 .55448 L .21183 .55481 L F
.799 .723 .78 r
.66698 .43857 m .66589 .44132 L .66936 .44145 L F
.442 .54 .861 r
.66936 .44145 m .67125 .43927 L .66698 .43857 L F
.66936 .44145 m .6714 .44146 L .67125 .43927 L F
.768 .971 .922 r
.69788 .42909 m .69954 .42876 L .70029 .42624 L F
.763 .805 .887 r
.69954 .42876 m .70249 .42519 L .70029 .42624 L F
.69954 .42876 m .70376 .42654 L .70249 .42519 L F
.707 .33 .334 r
.42141 .66134 m .41922 .66138 L .41926 .66239 L F
.569 .544 .787 r
.29773 .58615 m .29614 .58877 L .29556 .58643 L F
.29773 .58615 m .29831 .5889 L .29614 .58877 L F
.429 .387 .711 r
.29857 .59136 m .29614 .58877 L .29831 .5889 L F
.29857 .59136 m .29685 .59223 L .29614 .58877 L F
.259 0 0 r
.49261 .53688 m .49132 .53705 L .49506 .53716 L F
.833 .766 .788 r
.76185 .41771 m .75802 .4193 L .7604 .41607 L F
.76185 .41771 m .75945 .4209 L .75802 .4193 L F
.854 .991 .734 r
.41248 .59919 m .40988 .60265 L .41198 .60134 L F
.641 .542 .727 r
.41198 .60134 m .41318 .60457 L .41575 .60424 L F
.641 .456 .617 r
.41313 .60698 m .41575 .60424 L .41318 .60457 L F
0 .28 .782 r
.21962 .68959 m .22169 .68967 L .21848 .68794 L F
.21962 .68959 m .22205 .69037 L .22169 .68967 L F
.45 0 0 r
.41468 .61337 m .41342 .61438 L .41073 .61348 L F
.81 .355 .155 r
.41468 .61337 m .41712 .61618 L .41342 .61438 L F
.689 .724 .877 r
.17871 .61524 m .1793 .61719 L .17609 .61636 L F
.276 .441 .845 r
.18004 .61529 m .1793 .61719 L .17871 .61524 L F
0 .135 .658 r
.18084 .61751 m .1793 .61719 L .18004 .61529 L F
.18084 .61751 m .18103 .61887 L .1793 .61719 L F
.424 .256 .547 r
.26418 .57406 m .26184 .57765 L .26413 .57687 L F
.143 .338 .799 r
.17028 .63377 m .17187 .63704 L .17314 .63719 L F
.618 .798 .968 r
.14903 .59488 m .15169 .59499 L .15 .59563 L F
.117 0 0 r
.54344 .59185 m .54866 .5886 L .54407 .58979 L F
.807 .808 .851 r
.55048 .58602 m .54911 .58979 L .54796 .587 L F
.73 .211 0 r
.54866 .5886 m .54888 .59042 L .54895 .5901 L F
.807 .808 .851 r
.54911 .58979 m .54888 .59042 L .54874 .58991 L F
.117 0 0 r
.54417 .5914 m .54836 .59004 L .54866 .5886 L F
.73 .211 0 r
.54866 .5886 m .54826 .59055 L .54888 .59042 L F
.807 .808 .851 r
.54911 .58979 m .54874 .58991 L .54796 .587 L F
.117 0 0 r
.54344 .59185 m .54826 .59055 L .54836 .59004 L F
.54344 .59185 m .54836 .59004 L .54417 .5914 L F
.782 .564 0 r
.21212 .69173 m .21207 .69314 L .21297 .69084 L F
.782 .707 .781 r
.71371 .41442 m .71731 .41506 L .71594 .4131 L F
.789 .762 .829 r
.71345 .41618 m .71731 .41506 L .71371 .41442 L F
.778 .723 .801 r
.71731 .41506 m .71838 .4104 L .71594 .4131 L F
.46 .711 .977 r
.27697 .5401 m .27647 .54196 L .27485 .54045 L F
.27697 .5401 m .2787 .54179 L .27647 .54196 L F
.752 .383 .356 r
.8131 .44483 m .81057 .44609 L .81043 .44344 L F
.86 .433 0 r
.81365 .44519 m .81516 .44758 L .81421 .44672 L F
.8139 .44619 m .81421 .44672 L .81398 .44651 L F
.81365 .44519 m .81421 .44672 L .8139 .44619 L F
.81365 .44519 m .81398 .44651 L .81519 .44592 L F
.752 .383 .356 r
.81519 .44592 m .81377 .44597 L .8131 .44483 L F
.81377 .44597 m .81057 .44609 L .8131 .44483 L F
.964 .635 .276 r
.81516 .44758 m .81438 .44891 L .81398 .44651 L F
.278 0 0 r
.81516 .44758 m .81716 .44852 L .81438 .44891 L F
.81516 .44758 m .81839 .44723 L .81716 .44852 L F
.603 .434 .625 r
.48507 .60448 m .49018 .60423 L .48779 .60186 L F
.744 .575 .665 r
.48458 .60834 m .49018 .60423 L .48507 .60448 L F
.468 .221 .456 r
.29857 .59136 m .29598 .59417 L .29685 .59223 L F
.509 .416 .685 r
.42223 .6371 m .42408 .63317 L .4213 .63626 L F
.67 .823 .957 r
.77669 .40634 m .78093 .40615 L .78014 .40456 L F
.648 .736 .913 r
.78093 .40615 m .78387 .4054 L .78014 .40456 L F
.52 .689 .944 r
.77551 .40645 m .77612 .40466 L .77362 .40477 L F
.77551 .40645 m .77669 .40634 L .77612 .40466 L F
.553 .426 .661 r
.20999 .69815 m .21303 .70019 L .21243 .69437 L F
.698 .746 .888 r
.209 .7001 m .21303 .70019 L .20999 .69815 L F
.833 .641 .643 r
.58778 .49847 m .58974 .49573 L .58597 .49504 L F
.58778 .49847 m .58995 .49885 L .58974 .49573 L F
0 0 .076 r
.58295 .5651 m .58297 .56693 L .58244 .56783 L F
0 0 .064 r
.58371 .56335 m .58297 .56693 L .58295 .5651 L F
.424 .266 .561 r
.79126 .43787 m .79352 .43747 L .79075 .43837 L F
.631 .71 .903 r
.82974 .41637 m .83334 .41738 L .83078 .41816 L F
.666 .22 .183 r
.42918 .67983 m .42759 .6815 L .42517 .67957 L F
.977 .724 .484 r
.42766 .67892 m .42759 .6815 L .42918 .67983 L F
.703 .963 .942 r
.7507 .39423 m .74692 .39546 L .74934 .39293 L F
.869 .88 .842 r
.75212 .39251 m .7507 .39423 L .74934 .39293 L F
.676 .199 .111 r
.66344 .40321 m .66265 .40415 L .66563 .40448 L F
.751 .697 .8 r
.19083 .78269 m .1912 .78232 L .19061 .78228 L F
.354 .421 .792 r
.73075 .39728 m .72917 .3995 L .72798 .39575 L F
.572 .725 .946 r
.73075 .39728 m .73205 .39906 L .72917 .3995 L F
0 .28 .772 r
.77069 .38572 m .76922 .38475 L .76823 .38331 L F
.562 .347 .546 r
.46612 .61897 m .46851 .61876 L .46875 .61641 L F
.433 .184 .435 r
.46851 .61876 m .47129 .61589 L .46875 .61641 L F
.216 .279 .714 r
.41011 .63708 m .41097 .6409 L .41227 .63917 L F
.153 .191 .648 r
.41171 .64323 m .41227 .63917 L .41097 .6409 L F
.882 .681 .626 r
.5885 .52884 m .58938 .52564 L .58666 .5248 L F
.641 .325 .42 r
.7476 .37439 m .74498 .37241 L .74524 .37401 L F
.7476 .37439 m .74916 .37207 L .74498 .37241 L F
.767 .576 .64 r
.49245 .60036 m .49628 .60104 L .49616 .59822 L F
.544 .394 .628 r
.49836 .59504 m .49852 .59749 L .49616 .59822 L F
.595 .464 .672 r
.49852 .59749 m .49628 .60104 L .49616 .59822 L F
0 0 .447 r
.49616 .59822 m .49756 .59971 L .49852 .59749 L F
.49616 .59822 m .49628 .60104 L .49756 .59971 L F
.854 .988 .848 r
.44296 .63173 m .44118 .63212 L .44196 .63047 L F
.44296 .63173 m .4398 .63429 L .44118 .63212 L F
.669 .423 .54 r
.4432 .6341 m .4398 .63429 L .44296 .63173 L F
.711 .454 .535 r
.44659 .63331 m .4432 .6341 L .44296 .63173 L F
.697 .385 0 r
.47887 .56532 m .47901 .56587 L .47572 .56486 L F
.47887 .56532 m .47945 .56707 L .47901 .56587 L F
.564 .874 .994 r
.22283 .55134 m .22055 .55213 L .22242 .55278 L F
.264 .569 .938 r
.22242 .55278 m .2241 .55321 L .22283 .55134 L F
.564 .874 .994 r
.22283 .55134 m .22055 .55213 L .22242 .55278 L F
.995 .844 .496 r
.58704 .5405 m .58652 .54293 L .58727 .54412 L F
.992 .811 .433 r
.58727 .54412 m .58622 .54523 L .58731 .54705 L F
.58727 .54412 m .58652 .54293 L .58622 .54523 L F
.467 0 0 r
.26277 .53878 m .26484 .53984 L .26668 .53998 L F
.475 .885 .935 r
.26668 .53998 m .26711 .53905 L .26883 .5399 L F
.26668 .53998 m .26484 .53984 L .26711 .53905 L F
.817 .337 .04 r
.7655 .38146 m .76655 .38079 L .76458 .38062 L F
.7655 .38146 m .76823 .38331 L .76655 .38079 L F
.951 .93 .742 r
.77003 .3993 m .76749 .39887 L .7693 .39789 L F
.77003 .3993 m .76831 .40265 L .76749 .39887 L F
.447 .326 .622 r
.29911 .5653 m .30002 .5677 L .2979 .56814 L F
.476 .424 .719 r
.30002 .5677 m .29872 .57048 L .2979 .56814 L F
.871 .839 .373 r
.41341 .62776 m .41255 .63069 L .41282 .63153 L F
.777 .674 .75 r
.22379 .67938 m .22822 .67978 L .22785 .67751 L F
.812 .54 .527 r
.22379 .67938 m .22787 .68186 L .22822 .67978 L F
.444 .439 .759 r
.22994 .6791 m .22822 .67978 L .22785 .67751 L F
.75 .957 .656 r
.22787 .68186 m .22994 .6791 L .22822 .67978 L F
.444 .439 .759 r
.22994 .6791 m .22822 .67978 L .22785 .67751 L F
.493 .372 .643 r
.22994 .6791 m .22787 .68186 L .22822 .67978 L F
.767 .934 .583 r
.56564 .57379 m .56766 .5702 L .56686 .57178 L F
.314 0 .125 r
.25619 .6372 m .25501 .63937 L .25279 .63989 L F
.53 .201 .355 r
.25845 .63668 m .25501 .63937 L .25619 .6372 L F
.768 .781 .864 r
.75044 .41332 m .75386 .41339 L .75335 .41062 L F
.817 .824 .855 r
.75335 .41062 m .75386 .41339 L .7564 .41091 L F
.437 .21 .469 r
.71605 .39883 m .71877 .4005 L .71871 .39811 L F
.71605 .39883 m .71636 .40139 L .71877 .4005 L F
0 0 0 r
.2162 .67872 m .21788 .67662 L .21508 .67978 L F
.369 0 .089 r
.22065 .67609 m .21788 .67662 L .2162 .67872 L F
.186 .47 .889 r
.28916 .54542 m .29064 .54571 L .29016 .54721 L F
.407 .716 .987 r
.29064 .54571 m .29245 .54722 L .29016 .54721 L F
.447 .879 .81 r
.22873 .66816 m .23109 .66757 L .22861 .66719 L F
.533 .345 .572 r
.30021 .55502 m .29784 .5531 L .29968 .55247 L F
.30021 .55502 m .2977 .5556 L .29784 .5531 L F
.625 .436 .606 r
.41042 .59743 m .41307 .59411 L .41064 .59528 L F
.653 .338 .428 r
.7476 .37439 m .75136 .37407 L .74916 .37207 L F
.755 .665 .762 r
.42782 .60332 m .42794 .60476 L .43171 .60349 L F
.567 .22 .341 r
.42794 .60476 m .43033 .60623 L .43171 .60349 L F
.676 .34 .397 r
.43171 .60349 m .43423 .60586 L .43405 .60456 L F
.43171 .60349 m .43033 .60623 L .43423 .60586 L F
0 0 .197 r
.41817 .64175 m .4178 .64346 L .41763 .6405 L F
.41817 .64175 m .41763 .6405 L .41587 .6399 L F
.426 .691 .974 r
.20311 .62822 m .2011 .62837 L .19981 .62711 L F
.796 .475 .446 r
.43367 .62083 m .43557 .62243 L .43261 .62141 L F
0 0 0 r
.43261 .62141 m .43283 .62143 L .43367 .62083 L F
.671 .535 .691 r
.43816 .6222 m .43367 .62083 L .43682 .62103 L F
.43816 .6222 m .43557 .62243 L .43367 .62083 L F
.212 0 0 r
.43367 .62083 m .43283 .62143 L .43682 .62103 L F
.612 .405 .577 r
.43834 .64965 m .441 .65199 L .44132 .64929 L F
.658 .928 .973 r
.81839 .44723 m .82097 .44694 L .82022 .44388 L F
.645 .623 .813 r
.82097 .44694 m .82296 .44333 L .82022 .44388 L F
.82097 .44694 m .82335 .44572 L .82296 .44333 L F
.747 .803 .897 r
.2265 .67651 m .22785 .67751 L .23066 .67699 L F
.812 .692 .732 r
.22872 .67301 m .2265 .67651 L .23066 .67699 L F
.444 .439 .759 r
.22994 .6791 m .22785 .67751 L .23066 .67699 L F
.22994 .6791 m .22785 .67751 L .23066 .67699 L F
.484 .537 .836 r
.22872 .67301 m .23066 .67699 L .23235 .67615 L F
.185 0 .173 r
.40777 .60061 m .41042 .59743 L .40771 .59814 L F
.318 .183 .534 r
.44148 .59492 m .44148 .59742 L .43984 .59786 L F
.481 .1 .24 r
.56124 .50727 m .55768 .50973 L .55795 .50832 L F
.56124 .50727 m .56017 .50955 L .55768 .50973 L F
.623 .246 .307 r
.56435 .50931 m .56124 .50727 L .56413 .50721 L F
.56435 .50931 m .56017 .50955 L .56124 .50727 L F
.637 .781 .95 r
.66662 .41906 m .66795 .42076 L .67029 .41971 L F
.66662 .41906 m .66795 .42076 L .67029 .41971 L F
.659 .794 .339 r
.55727 .60798 m .55773 .60723 L .55992 .60648 L F
.55727 .60798 m .55674 .60913 L .55773 .60723 L F
.194 0 .139 r
.53339 .51596 m .53642 .51271 L .53405 .51328 L F
.421 .083 .284 r
.53076 .51637 m .53339 .51596 L .53405 .51328 L F
.595 .933 .737 r
.21885 .69947 m .21895 .6989 L .21903 .6997 L F
.495 .562 .853 r
.1432 .57043 m .14589 .56783 L .14391 .56817 L F
.878 .992 .796 r
.75165 .39153 m .75293 .39148 L .75212 .39251 L F
.869 .88 .842 r
.75212 .39251 m .74934 .39293 L .75165 .39153 L F
.306 0 .002 r
.80167 .44126 m .80064 .44285 L .79794 .44336 L F
.444 0 0 r
.80391 .44164 m .80064 .44285 L .80167 .44126 L F
.614 .374 .531 r
.4406 .62176 m .44351 .61923 L .44118 .61984 L F
.6 .232 .315 r
.51824 .54426 m .52113 .54595 L .52135 .54394 L F
.576 .394 .597 r
.52135 .54394 m .52468 .54347 L .52494 .54089 L F
.332 .014 .266 r
.52135 .54394 m .5235 .54508 L .52468 .54347 L F
.52135 .54394 m .52113 .54595 L .5235 .54508 L F
.504 .037 .077 r
.80796 .44121 m .80692 .44278 L .80391 .44164 L F
.727 .287 .204 r
.80796 .44121 m .81043 .44344 L .80692 .44278 L F
.644 .423 .568 r
.57246 .48963 m .57649 .48692 L .5723 .48671 L F
.57246 .48963 m .57631 .4895 L .57649 .48692 L F
.743 .509 .576 r
.57649 .48692 m .57631 .4895 L .57852 .48941 L F
0 0 .464 r
.49427 .57641 m .49404 .57722 L .4941 .5751 L F
.55 .753 .972 r
.49394 .57658 m .49404 .57722 L .49427 .57641 L F
.49173 .57774 m .49404 .57722 L .49394 .57658 L F
.981 .691 .364 r
.49404 .57722 m .4939 .57746 L .49396 .5767 L F
.55 .753 .972 r
.49173 .57774 m .49394 .57658 L .49036 .57468 L F
.49394 .57658 m .49396 .57627 L .49036 .57468 L F
.577 .835 .476 r
.49164 .57522 m .49047 .57656 L .4916 .57517 L F
.931 .736 .617 r
.49214 .5696 m .49109 .57248 L .49015 .56922 L F
.812 .828 .863 r
.49109 .57248 m .48945 .57435 L .48825 .5728 L F
.222 .576 .942 r
.48777 .57297 m .4869 .57361 L .48921 .57366 L F
.48675 .57334 m .4869 .57361 L .48777 .57297 L F
0 0 0 r
.48777 .57297 m .48825 .5728 L .48723 .57316 L F
.4883 .57277 m .48826 .5728 L .48777 .57297 L F
.222 .576 .942 r
.48777 .57297 m .48921 .57366 L .48826 .5728 L F
0 0 0 r
.48826 .5728 m .48825 .5728 L .48777 .57297 L F
.48961 .57183 m .4883 .57277 L .48723 .57316 L F
.49041 .57138 m .4873 .57312 L .48829 .57275 L F
.4873 .57312 m .48723 .57316 L .48775 .57296 L F
.4873 .57312 m .48775 .57296 L .48829 .57275 L F
.222 .576 .942 r
.48611 .57218 m .48775 .57296 L .48823 .57278 L F
.48775 .57296 m .48777 .57297 L .48823 .57278 L F
.48777 .57297 m .48826 .5728 L .48823 .57278 L F
.18 .512 .914 r
.48812 .57285 m .4869 .57361 L .48676 .57335 L F
.48721 .57318 m .48676 .57335 L .48675 .57334 L F
.48812 .57285 m .48676 .57335 L .48721 .57318 L F
0 0 0 r
.48829 .57275 m .48804 .57286 L .48823 .57278 L F
.48825 .5728 m .48765 .57323 L .48721 .57318 L F
.48804 .57286 m .48684 .57338 L .48823 .57278 L F
.222 .576 .942 r
.48775 .57296 m .48723 .57316 L .48777 .57297 L F
0 0 0 r
.48723 .57316 m .48825 .5728 L .48721 .57318 L F
.48723 .57316 m .48684 .57338 L .48829 .57275 L F
.222 .576 .942 r
.48611 .57218 m .48675 .57334 L .48723 .57316 L F
.48611 .57218 m .48723 .57316 L .48775 .57296 L F
0 0 0 r
.48721 .57318 m .48765 .57323 L .48684 .57338 L F
.18 .512 .914 r
.48823 .57278 m .48812 .57285 L .48611 .57218 L F
.48812 .57285 m .48675 .57334 L .48611 .57218 L F
.812 .828 .863 r
.48829 .57277 m .48825 .5728 L .48823 .57278 L F
.49109 .57248 m .48825 .5728 L .48829 .57277 L F
.49109 .57248 m .48829 .57277 L .49041 .57138 L F
0 0 0 r
.49041 .57138 m .48829 .57277 L .48961 .57183 L F
.812 .828 .863 r
.48829 .57277 m .48823 .57278 L .49041 .57138 L F
0 0 0 r
.49041 .57138 m .48825 .5728 L .48829 .57277 L F
.537 .565 .831 r
.48826 .5728 m .49041 .57138 L .48823 .57278 L F
.48921 .57366 m .49041 .57138 L .48826 .5728 L F
0 0 0 r
.49041 .57138 m .48765 .57323 L .48825 .5728 L F
.49041 .57138 m .48888 .57301 L .48765 .57323 L F
.917 .621 .137 r
.49015 .56922 m .49109 .57248 L .49041 .57138 L F
.124 .28 .752 r
.49164 .57522 m .49289 .57359 L .49041 .57138 L F
.577 .835 .476 r
.49164 .57522 m .4916 .57517 L .49289 .57359 L F
0 .302 .658 r
.49036 .57468 m .49168 .57526 L .49164 .57522 L F
.49168 .57526 m .49396 .57627 L .49164 .57522 L F
.981 .691 .364 r
.49407 .57633 m .494 .57629 L .4941 .5751 L F
0 .302 .658 r
.49396 .57627 m .49427 .57641 L .49387 .57623 L F
.49396 .57627 m .49387 .57623 L .49164 .57522 L F
.981 .691 .364 r
.49404 .57722 m .49396 .5767 L .494 .57629 L F
.49404 .57722 m .494 .57629 L .49407 .57633 L F
.545 .419 .659 r
.49173 .57774 m .49457 .57974 L .49404 .57722 L F
.883 .707 .659 r
.49164 .57522 m .49387 .57623 L .4941 .5751 L F
.981 .691 .364 r
.4939 .57746 m .494 .57552 L .4941 .5751 L F
.883 .707 .659 r
.49387 .57623 m .49427 .57641 L .4941 .5751 L F
.981 .691 .364 r
.49399 .57562 m .49329 .57847 L .494 .57552 L F
.4939 .57746 m .49347 .57817 L .49399 .57562 L F
.49347 .57817 m .49329 .57847 L .49399 .57562 L F
.55 .753 .972 r
.49394 .57658 m .49427 .57641 L .49396 .57627 L F
.545 .419 .659 r
.49173 .57774 m .49207 .58068 L .49457 .57974 L F
.051 .15 .649 r
.43373 .59878 m .4353 .60015 L .43587 .59816 L F
.375 .672 .974 r
.15655 .62611 m .15554 .62445 L .15577 .62513 L F
.15655 .62611 m .15682 .62447 L .15554 .62445 L F
.15655 .62611 m .15801 .62586 L .15682 .62447 L F
.592 .949 .872 r
.75531 .39007 m .75293 .39148 L .75165 .39153 L F
.442 .576 .892 r
.79255 .40435 m .79406 .4071 L .79643 .40709 L F
.744 .493 .551 r
.57851 .49166 m .58225 .48975 L .57852 .48941 L F
.57851 .49166 m .58226 .49216 L .58225 .48975 L F
.744 .542 .622 r
.58226 .49216 m .58593 .48983 L .58225 .48975 L F
.488 .176 .362 r
.7965 .43504 m .79919 .43467 L .79956 .43285 L F
.58 .514 .746 r
.79956 .43285 m .80196 .43214 L .79841 .42991 L F
.396 .096 .334 r
.79956 .43285 m .80174 .43381 L .80196 .43214 L F
.79956 .43285 m .79919 .43467 L .80174 .43381 L F
.744 .542 .622 r
.58226 .49216 m .58602 .49245 L .58593 .48983 L F
.664 .766 .926 r
.209 .7001 m .21109 .70197 L .21308 .70083 L F
.438 0 0 r
.51519 .54417 m .51778 .5451 L .51824 .54426 L F
.577 .01 0 r
.51778 .5451 m .52113 .54595 L .51824 .54426 L F
.567 .295 .463 r
.50119 .60792 m .50388 .60986 L .50421 .60744 L F
.50119 .60792 m .50388 .60986 L .50421 .60744 L F
.198 .066 .465 r
.25973 .59531 m .26119 .59678 L .26163 .59447 L F
.25973 .59531 m .2596 .59782 L .26119 .59678 L F
.564 .799 .987 r
.44932 .60319 m .4504 .60449 L .4466 .60394 L F
.267 0 .025 r
.4504 .60449 m .44686 .60684 L .4466 .60394 L F
.4504 .60449 m .44941 .60623 L .44686 .60684 L F
.252 .167 .561 r
.44932 .60319 m .44941 .60623 L .4504 .60449 L F
.763 .706 .799 r
.23626 .64888 m .23761 .65033 L .23925 .64755 L F
.029 0 .197 r
.15533 .58 m .15389 .58388 L .15302 .58327 L F
.654 .356 .455 r
.46274 .62152 m .46612 .61897 L .46299 .62029 L F
.46274 .62152 m .46548 .62219 L .46612 .61897 L F
.473 .171 .373 r
.46548 .62219 m .46851 .61876 L .46612 .61897 L F
.232 0 0 r
.50344 .52436 m .50719 .52197 L .5047 .52232 L F
.067 0 .148 r
.5258 .51979 m .52825 .51672 L .52584 .51705 L F
.888 .77 .726 r
.4178 .64346 m .41948 .64476 L .41939 .64418 L F
.485 .31 .568 r
.4831 .57592 m .48234 .5773 L .48452 .5744 L F
.359 .406 .774 r
.51431 .54286 m .51266 .54499 L .51133 .5404 L F
.449 .192 .431 r
.51519 .54417 m .51266 .54499 L .51431 .54286 L F
.994 .846 .584 r
.59098 .50386 m .59007 .50747 L .59133 .50745 L F
.768 .651 .094 r
.59113 .50898 m .59133 .50745 L .59007 .50747 L F
.59113 .50898 m .59117 .51053 L .59133 .50745 L F
.882 .652 .587 r
.57553 .52897 m .5734 .53044 L .57365 .52812 L F
.57553 .52897 m .57536 .53153 L .5734 .53044 L F
.993 .812 .559 r
.57486 .52581 m .57553 .52897 L .57365 .52812 L F
.542 .376 .605 r
.47808 .55872 m .47818 .56163 L .48052 .55849 L F
.545 .324 .531 r
.47143 .60135 m .47145 .604 L .4689 .60433 L F
.471 .216 .446 r
.47434 .60111 m .47145 .604 L .47143 .60135 L F
.529 .589 .859 r
.2315 .59529 m .23199 .59138 L .22992 .59184 L F
.2315 .59529 m .23383 .5949 L .23199 .59138 L F
.629 .573 .772 r
.2315 .59529 m .23543 .59834 L .23383 .5949 L F
.585 .611 .844 r
.23228 .55872 m .2334 .56124 L .23555 .56057 L F
.761 .788 .875 r
.72483 .40827 m .72826 .40864 L .72695 .40708 L F
.742 .81 .906 r
.72826 .40864 m .72979 .40497 L .72695 .40708 L F
.72826 .40864 m .7307 .40756 L .72979 .40497 L F
.349 .776 .973 r
.25098 .53779 m .25049 .53886 L .24886 .53809 L F
.25098 .53779 m .25268 .53862 L .25049 .53886 L F
.352 .813 .927 r
.67531 .44128 m .67475 .44089 L .6714 .44146 L F
.694 .982 .836 r
.67877 .43878 m .67666 .43937 L .67531 .44128 L F
.692 .981 .88 r
.67666 .43937 m .67475 .44089 L .67531 .44128 L F
.151 0 0 r
.44749 .57719 m .44599 .57804 L .44323 .57843 L F
.21 .736 .799 r
.44997 .57754 m .44599 .57804 L .44749 .57719 L F
.469 .272 .53 r
.44991 .57414 m .44997 .57754 L .44749 .57719 L F
.938 .695 .545 r
.51694 .56144 m .51507 .56112 L .51521 .55855 L F
.708 .179 0 r
.51694 .56144 m .51789 .56236 L .51507 .56112 L F
.938 .695 .545 r
.51694 .56144 m .51507 .56112 L .51521 .55855 L F
.671 .975 .835 r
.67991 .43718 m .67877 .43878 L .67996 .43733 L F
.67991 .43718 m .67666 .43937 L .67877 .43878 L F
.573 .516 .753 r
.79841 .42991 m .80196 .43214 L .80115 .42763 L F
.139 0 0 r
.14855 .56465 m .15044 .56411 L .152 .56224 L F
.127 0 0 r
.152 .56224 m .1524 .56345 L .15399 .5615 L F
.152 .56224 m .15044 .56411 L .1524 .56345 L F
.513 .067 .129 r
.55373 .57924 m .55662 .57913 L .55736 .57771 L F
.593 .149 .166 r
.55662 .57913 m .55991 .57915 L .55736 .57771 L F
.162 .342 .797 r
.52804 .52347 m .52833 .52151 L .5258 .51979 L F
.522 .51 .784 r
.52728 .52635 m .52833 .52151 L .52804 .52347 L F
.316 .668 .975 r
.29767 .5472 m .29623 .54862 L .29428 .54674 L F
.29767 .5472 m .29951 .54918 L .29623 .54862 L F
.888 .77 .726 r
.4178 .64346 m .41711 .64612 L .41948 .64476 L F
.846 .534 .46 r
.41718 .64755 m .41948 .64476 L .41711 .64612 L F
.41718 .64755 m .421 .6489 L .41948 .64476 L F
0 0 .386 r
.5004 .52473 m .50126 .52739 L .50122 .52489 L F
.944 .955 .738 r
.56564 .57379 m .56293 .57645 L .56543 .57351 L F
.56564 .57379 m .56377 .57712 L .56293 .57645 L F
.767 .934 .583 r
.56564 .57379 m .56543 .57351 L .56766 .5702 L F
.966 .713 .279 r
.50587 .53883 m .50679 .53766 L .50444 .53802 L F
.50587 .53883 m .50693 .54066 L .50679 .53766 L F
.836 .582 .554 r
.50679 .53766 m .50693 .54066 L .50856 .54006 L F
.104 .594 .906 r
.78475 .39635 m .78781 .39728 L .78807 .39687 L F
0 .383 .827 r
.78781 .39728 m .78967 .39768 L .78807 .39687 L F
.78781 .39728 m .79051 .3987 L .78967 .39768 L F
.419 .141 .382 r
.47421 .61349 m .47612 .61498 L .47662 .6129 L F
.47421 .61349 m .47379 .61562 L .47612 .61498 L F
0 0 0 r
.26704 .55602 m .26542 .55617 L .26299 .55637 L F
.684 .138 0 r
.26704 .55602 m .26689 .55715 L .26542 .55617 L F
.395 .254 .569 r
.26704 .55602 m .26703 .55863 L .2689 .55791 L F
.684 .138 0 r
.26704 .55602 m .2689 .55791 L .26689 .55715 L F
.137 .33 .794 r
.48779 .60186 m .49042 .60347 L .4902 .60049 L F
.48779 .60186 m .49018 .60423 L .49042 .60347 L F
.269 .772 .867 r
.44151 .57925 m .44007 .579 L .43764 .57949 L F
.253 .761 .862 r
.44255 .57878 m .44151 .57925 L .44323 .57843 L F
.44255 .57878 m .44007 .579 L .44151 .57925 L F
.777 .719 .798 r
.70376 .42654 m .70498 .42233 L .70249 .42519 L F
.70376 .42654 m .70628 .42344 L .70498 .42233 L F
.373 .142 .429 r
.15449 .55929 m .15399 .5615 L .1565 .55837 L F
.874 .473 .267 r
.52695 .53051 m .52882 .53191 L .52905 .53106 L F
.868 .624 .567 r
.57546 .51384 m .57318 .51529 L .57316 .51338 L F
.57546 .51384 m .57534 .51637 L .57318 .51529 L F
.501 .237 .447 r
.44498 .60634 m .44427 .60868 L .44119 .60771 L F
0 0 0 r
.73535 .37599 m .73616 .37472 L .73352 .37749 L F
.043 .407 .859 r
.73352 .37749 m .73699 .3797 L .73688 .37989 L F
.73699 .3797 m .73779 .38021 L .73688 .37989 L F
.765 .641 .725 r
.73688 .37989 m .73793 .38208 L .73496 .38362 L F
0 0 0 r
.73688 .37989 m .73496 .38362 L .73625 .38132 L F
.75 .791 .301 r
.73649 .38057 m .73688 .37989 L .73625 .38132 L F
.295 .395 .795 r
.73352 .37749 m .73688 .37989 L .73535 .37599 L F
.015 .204 .714 r
.73535 .37599 m .73688 .37989 L .73737 .37781 L F
.75 .791 .301 r
.73737 .37781 m .73688 .37989 L .73649 .38057 L F
.564 .925 .945 r
.78503 .44083 m .78693 .43927 L .78761 .43953 L F
.78503 .44083 m .7845 .44039 L .78693 .43927 L F
.619 .882 .989 r
.69218 .43175 m .69346 .43034 L .69169 .43166 L F
.69218 .43175 m .69487 .43105 L .69346 .43034 L F
.356 .045 .293 r
.45882 .61618 m .45835 .6189 L .45576 .61944 L F
.269 .174 .559 r
.46064 .61264 m .45947 .61623 L .45882 .61618 L F
.283 0 .272 r
.46044 .61801 m .45882 .61618 L .45947 .61623 L F
.46044 .61801 m .45835 .6189 L .45882 .61618 L F
0 0 0 r
.54895 .5901 m .55308 .58932 L .55418 .58905 L F
.167 .381 .829 r
.55506 .5878 m .55418 .58905 L .55308 .58932 L F
.55506 .5878 m .5575 .59163 L .55418 .58905 L F
.59 .429 .632 r
.77491 .39316 m .77727 .38928 L .77387 .38899 L F
.77491 .39316 m .77803 .39316 L .77727 .38928 L F
.059 0 0 r
.77755 .39329 m .77803 .39316 L .77491 .39316 L F
.302 .235 .614 r
.77727 .38928 m .77803 .39316 L .77924 .39157 L F
.751 .645 .744 r
.77745 .39315 m .77864 .39094 L .77755 .39329 L F
.59 .429 .632 r
.77491 .39316 m .77387 .38899 L .77678 .39106 L F
.77491 .39316 m .77678 .39106 L .77691 .39147 L F
.059 0 0 r
.77755 .39329 m .77491 .39316 L .77691 .39147 L F
.751 .645 .744 r
.77656 .39037 m .77864 .39094 L .77809 .39197 L F
.77678 .39106 m .77809 .39197 L .77745 .39315 L F
.77656 .39037 m .77809 .39197 L .77678 .39106 L F
.77531 .39003 m .77652 .39037 L .77745 .39315 L F
.77652 .39037 m .77691 .39147 L .77745 .39315 L F
.059 0 0 r
.77755 .39329 m .77691 .39147 L .77712 .3913 L F
.767 .608 .682 r
.7765 .39123 m .77694 .39117 L .77531 .39003 L F
.421 0 0 r
.7765 .39086 m .77688 .39113 L .77678 .39106 L F
.77531 .39003 m .77654 .39089 L .7765 .39086 L F
.77654 .39089 m .77688 .39113 L .7765 .39086 L F
.767 .608 .682 r
.77694 .39117 m .77864 .39094 L .77704 .39051 L F
.751 .645 .744 r
.77652 .39037 m .77656 .39037 L .77691 .39147 L F
.767 .608 .682 r
.77654 .39089 m .77704 .39051 L .77531 .39003 L F
.77694 .39117 m .77704 .39051 L .77654 .39089 L F
.302 .235 .614 r
.77727 .38928 m .77924 .39157 L .77864 .39094 L F
.77727 .38928 m .77864 .39094 L .77941 .38925 L F
0 0 0 r
.77941 .38925 m .77864 .39094 L .78156 .38767 L F
.774 .712 .794 r
.78156 .38767 m .77864 .39094 L .77694 .39117 L F
.77676 .39105 m .77694 .39117 L .7765 .39123 L F
.409 .209 .495 r
.7797 .38622 m .77727 .38928 L .77941 .38925 L F
.01 0 .349 r
.78138 .38508 m .7797 .38622 L .77941 .38925 L F
.78138 .38508 m .77941 .38925 L .78156 .38767 L F
.774 .712 .794 r
.78156 .38767 m .77694 .39117 L .77676 .39105 L F
.421 0 0 r
.77531 .39003 m .7764 .3908 L .77688 .39113 L F
.59 .429 .632 r
.77691 .39147 m .77678 .39106 L .77712 .3913 L F
.421 0 0 r
.7764 .3908 m .77712 .3913 L .77689 .39114 L F
.7764 .3908 m .77689 .39114 L .77688 .39113 L F
.77531 .39003 m .77678 .39106 L .77387 .38899 L F
.774 .712 .794 r
.78156 .38767 m .7765 .39123 L .77645 .39101 L F
.78156 .38767 m .77658 .39092 L .77915 .39063 L F
.588 .593 .824 r
.77531 .39003 m .77669 .39204 L .7765 .39123 L F
.767 .608 .682 r
.77599 .3913 m .7765 .39123 L .77531 .39003 L F
.774 .712 .794 r
.77645 .39101 m .7765 .39123 L .77599 .3913 L F
.588 .593 .824 r
.77632 .39105 m .77727 .39201 L .77661 .39095 L F
.774 .712 .794 r
.77661 .39095 m .77599 .3913 L .77688 .39115 L F
.77658 .39092 m .77645 .39101 L .77661 .39095 L F
.77645 .39101 m .77599 .3913 L .77661 .39095 L F
.588 .593 .824 r
.77661 .39095 m .77727 .39201 L .77712 .3913 L F
.77531 .39003 m .77632 .39105 L .77661 .39095 L F
.774 .712 .794 r
.77658 .39092 m .77688 .39115 L .78009 .39058 L F
.78036 .39049 m .78009 .39058 L .781 .39042 L F
.77658 .39092 m .78009 .39058 L .78036 .39049 L F
.43 .498 .828 r
.77963 .38749 m .77599 .3913 L .77706 .38806 L F
.774 .712 .794 r
.78124 .38924 m .77915 .39063 L .781 .39042 L F
.78156 .38767 m .77915 .39063 L .78124 .38924 L F
.43 .498 .828 r
.77963 .38749 m .781 .39042 L .77599 .3913 L F
.393 .437 .787 r
.77837 .39115 m .77963 .38749 L .77706 .38806 L F
.671 .918 .603 r
.77924 .39157 m .77755 .39329 L .77864 .39094 L F
.77924 .39157 m .77803 .39316 L .77755 .39329 L F
.687 .569 .716 r
.77755 .39329 m .77955 .39339 L .77864 .39094 L F
.262 .32 .735 r
.77955 .39339 m .78129 .39299 L .77864 .39094 L F
.664 .176 .081 r
.7789 .3924 m .78129 .39299 L .77888 .39113 L F
.7789 .3924 m .77888 .39113 L .77864 .39094 L F
.039 0 0 r
.77755 .39329 m .77945 .39339 L .77955 .39339 L F
.261 .474 .877 r
.7789 .3924 m .77945 .39339 L .77755 .39329 L F
.081 0 .076 r
.7789 .3924 m .7785 .39395 L .77891 .39353 L F
.658 .7 .877 r
.77945 .39339 m .78129 .39299 L .7789 .3924 L F
.081 0 .076 r
.7789 .3924 m .77891 .39353 L .78081 .39161 L F
.393 .437 .787 r
.7789 .3924 m .77912 .3909 L .77837 .39115 L F
.77912 .3909 m .77963 .38749 L .77837 .39115 L F
.244 .358 .782 r
.77706 .38806 m .77599 .3913 L .77531 .39003 L F
.779 .711 .788 r
.77451 .39147 m .77707 .39201 L .77706 .38806 L F
0 0 .174 r
.77864 .39094 m .7789 .3924 L .77755 .39329 L F
.779 .711 .788 r
.77707 .39201 m .7789 .3924 L .77837 .39115 L F
.77707 .39201 m .77837 .39115 L .77706 .38806 L F
.588 .593 .824 r
.7765 .39123 m .77755 .39329 L .77727 .39201 L F
.77669 .39204 m .77755 .39329 L .7765 .39123 L F
.703 .951 .955 r
.78321 .45054 m .78438 .45099 L .78671 .44945 L F
.551 .64 .892 r
.83897 .41616 m .83738 .41959 L .83605 .41695 L F
.83897 .41616 m .83992 .41951 L .83738 .41959 L F
.942 .689 .527 r
.22996 .57414 m .22826 .57533 L .22843 .57315 L F
.22996 .57414 m .23005 .57882 L .22826 .57533 L F
.399 0 .074 r
.22826 .57533 m .22996 .57414 L .22843 .57315 L F
.22826 .57533 m .23154 .57385 L .22996 .57414 L F
.984 .883 .532 r
.41909 .5921 m .41769 .59379 L .41861 .59497 L F
.857 .773 .768 r
.41532 .59436 m .41861 .59497 L .41769 .59379 L F
.41532 .59436 m .41745 .59593 L .41861 .59497 L F
.703 .164 0 r
.53943 .61009 m .53831 .60997 L .53548 .60729 L F
.43 .832 .978 r
.54201 .60957 m .54057 .60899 L .53943 .61009 L F
.49 .901 .901 r
.53943 .61009 m .54057 .60899 L .53831 .60997 L F
.912 .766 .687 r
.58749 .53356 m .58893 .53486 L .58784 .53138 L F
.916 .763 .676 r
.58814 .53697 m .58893 .53486 L .58749 .53356 L F
0 0 0 r
.4618 .62857 m .46052 .63031 L .4585 .63081 L F
.247 0 0 r
.46282 .62977 m .4618 .62857 L .46417 .62828 L F
.46282 .62977 m .46045 .6304 L .4618 .62857 L F
.714 .597 .724 r
.45889 .62923 m .46162 .6296 L .46323 .6267 L F
.46162 .6296 m .46282 .62977 L .46296 .62873 L F
.46162 .6296 m .46296 .62873 L .46323 .6267 L F
0 0 0 r
.46052 .63031 m .46045 .6304 L .46034 .63043 L F
.46052 .63031 m .46034 .63043 L .4585 .63081 L F
.685 .719 .875 r
.18963 .62216 m .18757 .6233 L .18601 .6214 L F
.835 .784 .804 r
.83273 .42875 m .83058 .43156 L .83332 .43226 L F
.891 .696 .632 r
.83026 .43412 m .83332 .43226 L .83058 .43156 L F
.83026 .43412 m .83267 .43539 L .83332 .43226 L F
.722 .712 .84 r
.83332 .43226 m .83647 .42972 L .83273 .42875 L F
.794 .774 .835 r
.65946 .44314 m .66332 .44257 L .66148 .4419 L F
.673 .89 .977 r
.66148 .4419 m .66332 .44257 L .66589 .44132 L F
.467 .152 .347 r
.54941 .51168 m .54904 .51308 L .54645 .51345 L F
.352 .05 .306 r
.55145 .51216 m .54941 .51168 L .55167 .51089 L F
.55145 .51216 m .54904 .51308 L .54941 .51168 L F
.537 .397 .638 r
.47637 .59471 m .47883 .59435 L .47855 .59188 L F
.427 .293 .594 r
.47883 .59435 m .47662 .59772 L .47637 .59471 L F
.039 0 0 r
.47637 .59471 m .47706 .59596 L .47883 .59435 L F
.47637 .59471 m .47511 .59696 L .47706 .59596 L F
.537 .397 .638 r
.47855 .59188 m .47883 .59435 L .47637 .59471 L F
.897 .742 .681 r
.57673 .51993 m .57601 .52242 L .57481 .51886 L F
.552 .231 .377 r
.42401 .63049 m .42775 .63056 L .42707 .62896 L F
.381 .02 .221 r
.26451 .63197 m .26374 .63361 L .26144 .63407 L F
.462 .127 .312 r
.26696 .63145 m .26374 .63361 L .26451 .63197 L F
.705 .617 .756 r
.17031 .61672 m .16755 .61937 L .16644 .61544 L F
.75 .399 .389 r
.50693 .54066 m .5074 .54274 L .50856 .54006 L F
.252 0 .162 r
.50856 .54006 m .5098 .54171 L .51133 .5404 L F
.50856 .54006 m .5074 .54274 L .5098 .54171 L F
.965 .92 .709 r
.76743 .40449 m .76749 .39887 L .76831 .40265 L F
.394 0 0 r
.48052 .55849 m .48332 .55939 L .48427 .5591 L F
0 .541 .799 r
.48332 .55939 m .48699 .56016 L .48427 .5591 L F
.88 .791 .758 r
.58744 .51841 m .59104 .51655 L .59105 .5137 L F
.58744 .51841 m .58901 .52004 L .59104 .51655 L F
.523 .914 .918 r
.78761 .43953 m .78947 .43814 L .79126 .43787 L F
.267 .774 .801 r
.78947 .43814 m .79352 .43747 L .79126 .43787 L F
.376 0 0 r
.5201 .56546 m .52303 .56693 L .52114 .56617 L F
.442 .564 .882 r
.15801 .62586 m .15999 .62884 L .161 .62703 L F
.435 .554 .877 r
.15999 .62884 m .16237 .62941 L .161 .62703 L F
.696 .306 .306 r
.43866 .56769 m .44091 .56986 L .44236 .56782 L F
.505 .086 .178 r
.44091 .56986 m .44493 .56792 L .44236 .56782 L F
.285 0 0 r
.45964 .56271 m .46216 .56244 L .46287 .56148 L F
.066 0 0 r
.46216 .56244 m .46481 .5618 L .46287 .56148 L F
.493 .295 .539 r
.18551 .7592 m .18569 .75953 L .18503 .75802 L F
.858 .541 .017 r
.44683 .65117 m .44584 .64836 L .44714 .64974 L F
.44683 .65117 m .44584 .64836 L .44714 .64974 L F
.073 0 .084 r
.24791 .61335 m .24523 .61623 L .24692 .61539 L F
.305 0 .208 r
.24791 .61335 m .24914 .61471 L .25014 .61279 L F
.24791 .61335 m .24692 .61539 L .24914 .61471 L F
.597 .574 .799 r
.48223 .59097 m .48338 .58869 L .48138 .58941 L F
.48223 .59097 m .48463 .59142 L .48338 .58869 L F
.546 .7 .941 r
.78387 .4054 m .78789 .40692 L .78589 .40426 L F
.707 .46 .549 r
.79012 .40748 m .78589 .40426 L .78789 .40692 L F
.892 .639 .549 r
.76935 .41563 m .77219 .41424 L .77101 .4122 L F
.76935 .41563 m .77203 .41651 L .77219 .41424 L F
.921 .691 .573 r
.77294 .4177 m .77219 .41424 L .77203 .41651 L F
.717 .384 0 r
.52328 .56824 m .52354 .56928 L .52303 .56693 L F
.52328 .56824 m .52408 .57052 L .52354 .56928 L F
.258 .455 .863 r
.42757 .64956 m .42722 .64976 L .42736 .6485 L F
.796 .488 .468 r
.42358 .64853 m .42753 .64939 L .42736 .6485 L F
.42753 .64939 m .42787 .64946 L .42736 .6485 L F
.258 .455 .863 r
.42738 .6485 m .42757 .64956 L .42736 .6485 L F
.701 .332 0 r
.42787 .64946 m .42663 .64702 L .42736 .6485 L F
.4274 .64852 m .42774 .64969 L .42663 .64702 L F
.42787 .64946 m .42787 .64947 L .4274 .64852 L F
.258 .455 .863 r
.42783 .64941 m .42757 .64956 L .42738 .6485 L F
.701 .332 0 r
.42787 .64947 m .42774 .64969 L .4274 .64852 L F
.258 .455 .863 r
.42928 .64857 m .42783 .64941 L .42738 .6485 L F
.994 .752 .43 r
.50982 .52144 m .5097 .52436 L .51082 .52251 L F
0 0 .402 r
.52513 .54867 m .52618 .55298 L .52519 .55028 L F
.602 .769 .96 r
.48169 .56681 m .48346 .56827 L .48704 .56748 L F
.539 .519 .781 r
.4241 .61475 m .42543 .61167 L .42322 .61166 L F
.4241 .61475 m .42591 .61448 L .42543 .61167 L F
.6 .514 .729 r
.42433 .6158 m .42591 .61448 L .4241 .61475 L F
.387 .156 .437 r
.28202 .61567 m .27999 .61632 L .28242 .61332 L F
.428 .165 .411 r
.28202 .61567 m .2793 .61858 L .27999 .61632 L F
0 0 0 r
.2162 .67872 m .21508 .67978 L .21378 .67932 L F
0 0 .263 r
.21508 .67978 m .2162 .67872 L .21378 .67932 L F
.21508 .67978 m .21558 .68097 L .2162 .67872 L F
.21508 .67978 m .21586 .68213 L .21558 .68097 L F
.519 .507 .782 r
.80536 .42168 m .80257 .41992 L .80319 .42271 L F
.455 .21 .452 r
.80319 .42271 m .80514 .42445 L .80536 .42168 L F
.80319 .42271 m .80336 .42541 L .80514 .42445 L F
0 .031 .596 r
.53338 .59497 m .53385 .59366 L .5322 .59121 L F
0 0 .276 r
.53338 .59497 m .53403 .59619 L .53385 .59366 L F
.53338 .59497 m .53406 .59835 L .53403 .59619 L F
.676 .49 .626 r
.48338 .58869 m .48649 .586 L .48392 .58645 L F
.23 .044 .409 r
.25051 .61033 m .25175 .61198 L .25218 .60955 L F
.25051 .61033 m .25014 .61279 L .25175 .61198 L F
.528 .439 .698 r
.45657 .59165 m .45868 .58863 L .45611 .58982 L F
.45657 .59165 m .45873 .59129 L .45868 .58863 L F
.558 .427 .658 r
.45699 .59518 m .45873 .59129 L .45657 .59165 L F
.396 .649 .959 r
.80996 .40163 m .80818 .40294 L .80728 .40144 L F
.80996 .40163 m .8115 .40343 L .80818 .40294 L F
.169 0 0 r
.22005 .53808 m .22424 .53787 L .22222 .5386 L F
.462 .596 .9 r
.54324 .6118 m .54405 .60938 L .54201 .60957 L F
.54324 .6118 m .54539 .61186 L .54405 .60938 L F
.311 0 .097 r
.54904 .51308 m .54563 .51567 L .54645 .51345 L F
.476 .424 .719 r
.30002 .5677 m .30066 .56998 L .29872 .57048 L F
.619 .537 .741 r
.30066 .56998 m .29869 .57433 L .29872 .57048 L F
0 .014 .55 r
.5165 .53756 m .51603 .53684 L .51404 .5347 L F
0 0 0 r
.19588 .55869 m .19514 .55885 L .19731 .55838 L F
.402 .804 .586 r
.56938 .6017 m .56774 .60282 L .56607 .60397 L F
0 0 0 r
.56964 .60182 m .56938 .6017 L .57091 .60044 L F
.56964 .60182 m .56774 .60282 L .56938 .6017 L F
.397 0 .037 r
.25279 .63989 m .24878 .64203 L .25071 .64055 L F
.464 .222 .462 r
.28242 .61332 m .28432 .61513 L .28202 .61567 L F
.517 .218 .399 r
.28499 .61284 m .28432 .61513 L .28242 .61332 L F
.933 .759 .643 r
.67921 .42266 m .67656 .42414 L .67685 .4224 L F
.67921 .42266 m .67787 .42579 L .67656 .42414 L F
0 0 0 r
.18875 .5441 m .18869 .54447 L .19096 .54366 L F
.18875 .5441 m .18675 .54541 L .18869 .54447 L F
.759 .459 .477 r
.66607 .40741 m .66766 .40512 L .66563 .40448 L F
.66607 .40741 m .66791 .40754 L .66766 .40512 L F
0 0 0 r
.46943 .56554 m .46882 .56676 L .46708 .56783 L F
.884 .942 .846 r
.47286 .56254 m .47019 .56562 L .47162 .56596 L F
.071 0 .127 r
.47286 .56254 m .47168 .56514 L .47019 .56562 L F
0 0 0 r
.47182 .56501 m .47019 .56562 L .47168 .56514 L F
.47182 .56501 m .47074 .56569 L .47019 .56562 L F
.47019 .56562 m .46948 .56555 L .47162 .56596 L F
.47074 .56569 m .46884 .56689 L .47019 .56562 L F
.47019 .56562 m .46943 .56554 L .46948 .56555 L F
.47019 .56562 m .46882 .56676 L .46943 .56554 L F
.394 0 0 r
.49539 .58703 m .49112 .58752 L .49334 .58622 L F
.453 .838 .615 r
.49539 .58703 m .49114 .59005 L .49112 .58752 L F
.29 0 .24 r
.49112 .58752 m .49297 .58873 L .49292 .58692 L F
.49112 .58752 m .49292 .58692 L .49289 .58612 L F
0 0 0 r
.48999 .5879 m .49112 .58752 L .48933 .58823 L F
.49334 .58622 m .49112 .58752 L .48999 .5879 L F
.394 0 0 r
.49539 .58703 m .49334 .58622 L .49565 .58543 L F
.524 .148 .27 r
.4689 .60433 m .46874 .6059 L .46609 .60493 L F
.543 .272 .454 r
.46762 .60781 m .46609 .60493 L .46874 .6059 L F
.46762 .60781 m .46517 .60922 L .46609 .60493 L F
.786 .822 .881 r
.25439 .55254 m .25716 .55471 L .2591 .55256 L F
.411 .686 .975 r
.28744 .54403 m .28691 .54553 L .28458 .54375 L F
.28744 .54403 m .28916 .54542 L .28691 .54553 L F
.101 0 .147 r
.19066 .75566 m .19155 .75437 L .19087 .75436 L F
.883 .849 .805 r
.19308 .75214 m .19345 .75223 L .19066 .75566 L F
.101 0 .147 r
.19066 .75566 m .19345 .75223 L .19236 .75437 L F
.255 .02 .352 r
.19066 .75566 m .19087 .75436 L .19236 .75437 L F
.883 .849 .805 r
.1906 .75158 m .19308 .75214 L .19066 .75566 L F
.101 0 .147 r
.19066 .75566 m .19236 .75437 L .19155 .75437 L F
.969 .756 .561 r
.42207 .5896 m .41875 .5894 L .41909 .5921 L F
.612 .946 .937 r
.42012 .59068 m .41873 .59159 L .41909 .5921 L F
.587 .834 .465 r
.42012 .59068 m .41769 .59379 L .41909 .5921 L F
.641 .949 .736 r
.42207 .5896 m .42012 .59068 L .41909 .5921 L F
.333 .053 .33 r
.24295 .64608 m .24227 .64373 L .24462 .64305 L F
.812 .542 .531 r
.45649 .60443 m .46024 .60726 L .46091 .60437 L F
0 0 0 r
.46024 .60726 m .46284 .60349 L .46091 .60437 L F
.46024 .60726 m .46143 .60667 L .46104 .6061 L F
.83 .987 .871 r
.46143 .60667 m .4588 .60888 L .45901 .60646 L F
.449 0 0 r
.45901 .60646 m .46187 .60731 L .46143 .60667 L F
.46187 .60731 m .46355 .60782 L .46143 .60667 L F
0 0 0 r
.46104 .6061 m .46143 .60667 L .46284 .60349 L F
.463 .185 .406 r
.48649 .586 m .48873 .58563 L .48924 .58308 L F
.28 .029 .343 r
.48924 .58308 m .49127 .58444 L .49132 .58184 L F
.48924 .58308 m .48873 .58563 L .49127 .58444 L F
.923 .787 .693 r
.75517 .4233 m .75272 .4218 L .75485 .41925 L F
.75517 .4233 m .75419 .42314 L .75272 .4218 L F
.829 .835 .852 r
.75802 .4193 m .75517 .4233 L .75485 .41925 L F
0 0 0 r
.16582 .55352 m .16459 .55466 L .16766 .55266 L F
.422 .204 .475 r
.26403 .58583 m .26609 .58534 L .2666 .58293 L F
.46 .292 .566 r
.26371 .58865 m .26609 .58534 L .26403 .58583 L F
.38 .23 .549 r
.43655 .57139 m .44003 .57048 L .43866 .56769 L F
0 0 0 r
.56774 .60282 m .56465 .60663 L .56607 .60397 L F
.56465 .60663 m .56451 .6068 L .56461 .60661 L F
.56465 .60663 m .56461 .60661 L .56607 .60397 L F
0 0 .394 r
.56486 .60697 m .56488 .60706 L .56471 .60666 L F
.464 .007 .081 r
.56607 .60397 m .56461 .60661 L .56364 .60497 L F
.773 .562 .613 r
.56425 .60564 m .56451 .6068 L .56465 .60663 L F
.56425 .60564 m .56465 .60663 L .56774 .60282 L F
0 0 .394 r
.56469 .60674 m .56524 .60844 L .56457 .60654 L F
.56488 .60706 m .565 .60754 L .56469 .60674 L F
.565 .60754 m .56524 .60844 L .56469 .60674 L F
.56472 .60667 m .56471 .60666 L .56425 .60564 L F
.56486 .60697 m .56471 .60666 L .56472 .60667 L F
.56488 .60706 m .56457 .60654 L .56425 .60564 L F
.464 .007 .081 r
.56364 .60497 m .56451 .6068 L .56257 .6054 L F
.56461 .60661 m .56451 .6068 L .56364 .60497 L F
.426 .218 .493 r
.79293 .43541 m .79594 .43681 L .7965 .43504 L F
.377 .245 .572 r
.2977 .5556 m .29778 .55825 L .29619 .55888 L F
0 0 0 r
.73906 .37359 m .73616 .37472 L .73778 .37435 L F
.73778 .37435 m .73616 .37472 L .73535 .37599 L F
.817 .824 .855 r
.75508 .40965 m .75335 .41062 L .7564 .41091 L F
.861 .822 .809 r
.75508 .40965 m .7564 .41091 L .75877 .40759 L F
.667 .748 .911 r
.7307 .40756 m .732 .40386 L .72979 .40497 L F
.7307 .40756 m .73381 .40671 L .732 .40386 L F
0 0 0 r
.58537 .55451 m .58607 .55262 L .58591 .55213 L F
.341 .039 .299 r
.44767 .56538 m .44948 .56647 L .45072 .56392 L F
.357 0 .102 r
.44948 .56647 m .45342 .56391 L .45072 .56392 L F
.473 .574 .876 r
.81383 .40323 m .81205 .40553 L .8115 .40343 L F
.543 .676 .925 r
.81462 .40514 m .81205 .40553 L .81383 .40323 L F
.56 .561 .811 r
.4741 .62826 m .47052 .62531 L .47045 .62792 L F
.436 .004 .119 r
.47255 .62443 m .47045 .62792 L .47052 .62531 L F
.539 .326 .539 r
.45236 .5765 m .44991 .57414 L .45228 .57426 L F
.45236 .5765 m .44997 .57754 L .44991 .57414 L F
.499 .416 .693 r
.44659 .63331 m .44629 .6342 L .44876 .63047 L F
.385 .209 .515 r
.22992 .59184 m .23226 .58847 L .23052 .58928 L F
.809 .588 .604 r
.43537 .62515 m .43261 .62141 L .43557 .62243 L F
.473 .219 .447 r
.43816 .6222 m .43537 .62515 L .43557 .62243 L F
.447 .267 .543 r
.28708 .6071 m .28699 .60966 L .28489 .61023 L F
.5 .362 .625 r
.28699 .60966 m .28499 .61284 L .28489 .61023 L F
.703 .337 .351 r
.46832 .55763 m .47052 .56068 L .47091 .55747 L F
.46832 .55763 m .46698 .56089 L .47052 .56068 L F
.627 .637 .841 r
.19066 .75566 m .18927 .75678 L .18958 .75599 L F
.304 .774 .936 r
.2054 .53888 m .2078 .53859 L .20971 .53911 L F
.508 0 0 r
.2078 .53859 m .21169 .53849 L .20971 .53911 L F
.782 .585 .018 r
.53434 .60119 m .5342 .6004 L .53406 .59835 L F
0 .029 .583 r
.53495 .60369 m .5342 .6004 L .53434 .60119 L F
.833 .644 .647 r
.58778 .49847 m .58736 .50096 L .58995 .49885 L F
.444 0 0 r
.80391 .44164 m .80324 .443 L .80064 .44285 L F
.495 0 0 r
.80692 .44278 m .80324 .443 L .80391 .44164 L F
.471 .735 .985 r
.65942 .44026 m .65516 .43861 L .65825 .43774 L F
.803 .823 .868 r
.66185 .43795 m .65942 .44026 L .65825 .43774 L F
.385 .836 .924 r
.21613 .53811 m .21596 .53888 L .21392 .53845 L F
.21613 .53811 m .218 .53837 L .21596 .53888 L F
.861 .822 .809 r
.75508 .40965 m .75877 .40759 L .7577 .40638 L F
.907 .902 .809 r
.7577 .40638 m .75877 .40759 L .76095 .40389 L F
.279 .748 .942 r
.22867 .53723 m .22819 .53793 L .2265 .53757 L F
.22867 .53723 m .23044 .53778 L .22819 .53793 L F
.453 .306 .591 r
.66531 .40927 m .66607 .40741 L .66422 .40933 L F
.66531 .40927 m .66746 .41069 L .66791 .40754 L F
.855 .996 .77 r
.66422 .40933 m .66531 .40927 L .66607 .40741 L F
.729 .769 .884 r
.21303 .70019 m .21371 .70032 L .21395 .69985 L F
.708 .639 .778 r
.21342 .70023 m .21395 .69995 L .21418 .69453 L F
.729 .769 .884 r
.21303 .70019 m .21458 .69961 L .21486 .69939 L F
.21395 .69985 m .21371 .70032 L .21458 .69961 L F
.425 .395 .723 r
.21395 .69985 m .21393 .70028 L .21399 .69977 L F
.708 .639 .778 r
.21303 .70019 m .21342 .70023 L .21345 .70004 L F
.21342 .70023 m .21393 .70028 L .21395 .69995 L F
.729 .769 .884 r
.21303 .70019 m .21399 .69977 L .21393 .70028 L F
.838 .978 .877 r
.2148 .6995 m .21458 .69961 L .21308 .70083 L F
.729 .769 .884 r
.21399 .69977 m .21486 .69939 L .21393 .70028 L F
.425 .395 .723 r
.21399 .69977 m .21393 .70028 L .21591 .69598 L F
.21591 .69598 m .21393 .70028 L .21618 .69621 L F
.21418 .69453 m .21395 .69985 L .21591 .69598 L F
.729 .769 .884 r
.21303 .70019 m .21308 .70083 L .21371 .70032 L F
.708 .639 .778 r
.21303 .70019 m .21345 .70004 L .21418 .69453 L F
.838 .978 .877 r
.21374 .70128 m .2148 .6995 L .21308 .70083 L F
.2148 .6995 m .21486 .69939 L .21458 .69961 L F
.607 .065 0 r
.2217 .69397 m .22013 .69445 L .22165 .69392 L F
.22294 .69537 m .2218 .69423 L .22013 .69445 L F
.22294 .69537 m .22013 .69445 L .2217 .69397 L F
.772 .858 .914 r
.2218 .69423 m .2189 .69482 L .22013 .69445 L F
.2189 .69482 m .2177 .69506 L .22013 .69445 L F
.699 .599 .741 r
.8217 .40843 m .82263 .41032 L .81965 .41117 L F
.266 .1 .461 r
.39871 .6132 m .40021 .61254 L .40063 .60992 L F
.012 0 .374 r
.39871 .6132 m .4 .61433 L .40021 .61254 L F
.39871 .6132 m .39859 .61569 L .4 .61433 L F
.28 0 0 r
.42011 .62285 m .41727 .62506 L .41499 .62466 L F
0 0 0 r
.42158 .62032 m .42011 .62285 L .42147 .62036 L F
.425 .164 .413 r
.27732 .61923 m .27684 .62154 L .27466 .62206 L F
.471 .257 .506 r
.2793 .61858 m .27684 .62154 L .27732 .61923 L F
.004 0 .474 r
.42592 .62192 m .42692 .61845 L .42431 .62083 L F
.42592 .62192 m .42707 .62091 L .42692 .61845 L F
.364 .607 .942 r
.42592 .62192 m .42859 .62279 L .42707 .62091 L F
.427 .293 .594 r
.47883 .59435 m .47893 .59778 L .47662 .59772 L F
.328 .096 .402 r
.47851 .5996 m .47662 .59772 L .47893 .59778 L F
.47851 .5996 m .47659 .60043 L .47662 .59772 L F
.291 .051 .367 r
.45444 .5749 m .45228 .57426 L .45496 .57283 L F
.093 0 0 r
.45847 .57065 m .45712 .57258 L .45496 .57283 L F
.128 0 .064 r
.45712 .57258 m .45444 .5749 L .45496 .57283 L F
.761 .271 .068 r
.48931 .56833 m .48738 .568 L .48704 .56748 L F
0 .529 .748 r
.48931 .56833 m .48815 .56806 L .48738 .568 L F
.443 0 0 r
.48931 .56833 m .49015 .56922 L .48815 .56806 L F
.847 .585 .044 r
.49015 .56922 m .49041 .57138 L .48999 .56944 L F
.443 0 0 r
.48931 .56833 m .49043 .56883 L .49015 .56922 L F
.241 .516 .91 r
.48815 .56806 m .49015 .56922 L .48956 .56749 L F
.847 .585 .044 r
.49015 .56922 m .48999 .56944 L .48956 .56749 L F
.443 0 0 r
.49043 .56883 m .49214 .5696 L .49015 .56922 L F
.437 .588 .904 r
.4586 .58323 m .45871 .58611 L .45769 .58384 L F
.976 .742 .324 r
.45799 .58586 m .45871 .58611 L .4586 .58323 L F
.45799 .58586 m .45868 .58863 L .45871 .58611 L F
.753 .522 .582 r
.50267 .58226 m .50374 .58347 L .50202 .58554 L F
.745 .727 .834 r
.71838 .4104 m .72197 .41091 L .7209 .40747 L F
.722 .713 .842 r
.7209 .40747 m .72197 .41091 L .72483 .40827 L F
.338 .123 .433 r
.26476 .56128 m .26676 .56091 L .26703 .55863 L F
.264 .183 .574 r
.49836 .59504 m .49991 .59532 L .50096 .59439 L F
.49836 .59504 m .49852 .59749 L .49991 .59532 L F
.697 .576 .715 r
.22787 .68186 m .22893 .68561 L .22514 .68557 L F
.682 .428 .532 r
.22514 .68557 m .22847 .68795 L .22506 .68838 L F
.22514 .68557 m .22893 .68561 L .22847 .68795 L F
.719 .981 .774 r
.22904 .55204 m .22842 .55353 L .23017 .55326 L F
.432 .066 .242 r
.55253 .49806 m .55503 .49774 L .55511 .49668 L F
.503 .163 .323 r
.55503 .49774 m .55798 .49671 L .55511 .49668 L F
.598 .159 .179 r
.42666 .60579 m .43033 .60623 L .42794 .60476 L F
.619 .588 .797 r
.82848 .41265 m .82718 .41711 L .82605 .41341 L F
.82848 .41265 m .82974 .41637 L .82718 .41711 L F
0 0 .505 r
.5322 .59121 m .53043 .58806 L .53125 .58947 L F
.448 .722 .984 r
.21136 .63001 m .2109 .63166 L .20935 .62996 L F
.21136 .63001 m .2132 .63151 L .2109 .63166 L F
.576 .709 .933 r
.73807 .39927 m .73523 .39997 L .73436 .39807 L F
.183 .287 .737 r
.53153 .55536 m .53276 .55712 L .53153 .55895 L F
.143 .232 .697 r
.53276 .55712 m .53355 .56086 L .53153 .55895 L F
.311 .02 .3 r
.15828 .57693 m .15686 .57968 L .15533 .58 L F
.013 0 0 r
.16077 .57708 m .15686 .57968 L .15828 .57693 L F
0 .299 .728 r
.26319 .53862 m .26277 .53878 L .261 .53838 L F
.26319 .53862 m .26484 .53984 L .26277 .53878 L F
.588 .636 .866 r
.7369 .40767 m .74085 .41051 L .73937 .40738 L F
.597 .675 .895 r
.74085 .41051 m .74198 .40666 L .73937 .40738 L F
.74085 .41051 m .7436 .40983 L .74198 .40666 L F
.155 .687 .858 r
.46794 .62847 m .46698 .6282 L .46417 .62828 L F
.73 .985 .897 r
.46882 .62674 m .46794 .62847 L .47045 .62792 L F
.46882 .62674 m .46698 .6282 L .46794 .62847 L F
.13 0 .015 r
.16642 .57118 m .16518 .57305 L .16332 .57376 L F
.025 0 0 r
.16708 .57203 m .16642 .57118 L .16896 .57034 L F
.16708 .57203 m .16518 .57305 L .16642 .57118 L F
.8 .558 .572 r
.7705 .41927 m .77294 .4177 L .77203 .41651 L F
.7705 .41927 m .77363 .41981 L .77294 .4177 L F
.699 .479 .586 r
.70351 .41312 m .7061 .41073 L .70339 .41107 L F
0 0 0 r
.68619 .43419 m .68951 .43293 L .68803 .43357 L F
.451 .87 .74 r
.68951 .43293 m .69169 .43166 L .68803 .43357 L F
0 .482 .699 r
.78372 .39619 m .78475 .39635 L .78807 .39687 L F
.761 .249 0 r
.67261 .42002 m .6717 .42048 L .67147 .42023 L F
.238 0 0 r
.67328 .4199 m .67261 .42002 L .67029 .41971 L F
.981 .896 .555 r
.67091 .41727 m .67029 .41971 L .66978 .41837 L F
.761 .249 0 r
.67261 .42002 m .66978 .41837 L .67029 .41971 L F
.67261 .42002 m .67147 .42023 L .66978 .41837 L F
.238 0 0 r
.67408 .41996 m .67261 .42002 L .67328 .4199 L F
0 .112 .629 r
.67408 .41996 m .67685 .4224 L .67549 .42085 L F
.67408 .41996 m .67549 .42085 L .67261 .42002 L F
0 .404 .702 r
.4869 .57361 m .48945 .57435 L .49036 .57468 L F
.539 .738 .967 r
.75758 .37399 m .75793 .37606 L .757 .37451 L F
.961 .881 .488 r
.7574 .37477 m .75793 .37606 L .75758 .37399 L F
.673 .917 .975 r
.75793 .37606 m .75831 .37699 L .75523 .37753 L F
.75523 .37753 m .75974 .37673 L .75793 .37606 L F
.425 .67 .964 r
.757 .37451 m .75793 .37606 L .75386 .37551 L F
.673 .917 .975 r
.75793 .37606 m .75523 .37753 L .75386 .37551 L F
0 0 0 r
.75466 .37848 m .75523 .37753 L .75793 .37606 L F
.75466 .37848 m .75641 .37718 L .75677 .37752 L F
.75641 .37718 m .75793 .37606 L .75677 .37752 L F
.992 .876 .606 r
.75595 .37616 m .75677 .37752 L .75758 .37399 L F
.438 0 0 r
.75729 .37801 m .75677 .37752 L .75595 .37616 L F
.223 .373 .804 r
.75951 .37923 m .75857 .38154 L .75677 .37752 L F
.438 0 0 r
.75734 .37807 m .75951 .37923 L .75677 .37752 L F
.75734 .37807 m .75677 .37752 L .75729 .37801 L F
.961 .881 .488 r
.75677 .37752 m .75793 .37606 L .7574 .37477 L F
.673 .917 .975 r
.75793 .37606 m .75974 .37673 L .75831 .37699 L F
.667 .916 .976 r
.75974 .37673 m .76128 .37601 L .75793 .37606 L F
.75974 .37673 m .76128 .37601 L .75793 .37606 L F
.788 .728 .797 r
.43096 .65172 m .43229 .65647 L .42642 .65708 L F
.493 0 0 r
.43195 .65791 m .42642 .65708 L .43229 .65647 L F
.557 .587 .839 r
.43472 .6546 m .43229 .65647 L .43096 .65172 L F
0 0 .023 r
.43386 .65618 m .43229 .65647 L .43472 .6546 L F
.43386 .65618 m .43195 .65791 L .43229 .65647 L F
.769 .614 .687 r
.76128 .37601 m .76249 .38077 L .76387 .37782 L F
.923 .586 .383 r
.76458 .38062 m .76387 .37782 L .76249 .38077 L F
.477 .121 .283 r
.47145 .604 m .46874 .6059 L .4689 .60433 L F
.647 .927 .973 r
.21703 .63076 m .2132 .63151 L .21541 .63085 L F
.413 .848 .94 r
.21541 .63085 m .21924 .63049 L .21703 .63076 L F
.846 .951 .6 r
.42255 .58761 m .42207 .5896 L .4241 .58608 L F
0 .343 .792 r
.18143 .64036 m .18123 .63954 L .18018 .63914 L F
0 .023 .574 r
.18143 .64036 m .1833 .64243 L .18123 .63954 L F
0 .087 .645 r
.52901 .58314 m .53051 .58553 L .52906 .58213 L F
.611 .56 .772 r
.82509 .40966 m .82341 .41416 L .82263 .41032 L F
.82509 .40966 m .82605 .41341 L .82341 .41416 L F
.715 .688 .823 r
.81764 .43183 m .81512 .43423 L .81541 .43305 L F
.489 .284 .527 r
.24462 .61784 m .24692 .61539 L .24523 .61623 L F
.482 .683 .954 r
.1738 .63865 m .17442 .63701 L .17314 .63719 L F
.1738 .63865 m .17763 .63953 L .17442 .63701 L F
0 0 .051 r
.57809 .59095 m .57596 .5944 L .57675 .59242 L F
.344 .386 .761 r
.30098 .56343 m .29911 .5653 L .29854 .56171 L F
.582 .398 .597 r
.30255 .56711 m .29911 .5653 L .30098 .56343 L F
.30255 .56711 m .30002 .5677 L .29911 .5653 L F
.153 .191 .648 r
.41171 .64323 m .41303 .6432 L .41227 .63917 L F
.153 .235 .696 r
.41171 .64323 m .41373 .64517 L .41303 .6432 L F
.19 0 0 r
.45937 .57192 m .45847 .57065 L .46088 .57036 L F
.45937 .57192 m .45712 .57258 L .45847 .57065 L F
.416 .23 .518 r
.26649 .57071 m .26418 .57406 L .26645 .57324 L F
.367 .187 .5 r
.26413 .57687 m .26645 .57324 L .26418 .57406 L F
.539 .065 .076 r
.67124 .41126 m .67397 .41246 L .67506 .41096 L F
.701 .248 .173 r
.67397 .41246 m .67765 .41306 L .67506 .41096 L F
.341 .039 .299 r
.44767 .56538 m .44727 .56728 L .44948 .56647 L F
.641 .456 .617 r
.41313 .60698 m .41564 .60685 L .41575 .60424 L F
.705 .59 .724 r
.4182 .60188 m .41575 .60424 L .41876 .60411 L F
.607 .364 .524 r
.41564 .60685 m .41876 .60411 L .41575 .60424 L F
.637 .416 .566 r
.52468 .54347 m .52729 .54078 L .52494 .54089 L F
.524 .302 .519 r
.25467 .60649 m .25732 .6036 L .25516 .60422 L F
.726 .881 .953 r
.44371 .63665 m .4398 .63429 L .4432 .6341 L F
.44371 .63665 m .44074 .63682 L .4398 .63429 L F
.775 .69 .77 r
.44659 .63331 m .44371 .63665 L .4432 .6341 L F
.952 .693 .239 r
.42213 .6682 m .422 .67143 L .4212 .66643 L F
.621 .809 .973 r
.42515 .66691 m .42213 .6682 L .4212 .66643 L F
.522 .51 .784 r
.52728 .52635 m .52948 .52543 L .52833 .52151 L F
.607 .364 .524 r
.41564 .60685 m .41855 .60712 L .41876 .60411 L F
.685 .641 .799 r
.41876 .60411 m .42081 .60121 L .4182 .60188 L F
.41876 .60411 m .42291 .60433 L .42081 .60121 L F
.295 .11 .451 r
.41876 .60411 m .42034 .60583 L .42291 .60433 L F
.41876 .60411 m .41855 .60712 L .42034 .60583 L F
.677 .846 .964 r
.20329 .64709 m .20482 .64818 L .20709 .64703 L F
.169 0 0 r
.74631 .37788 m .74798 .37843 L .74614 .37972 L F
.74631 .37788 m .7489 .37744 L .74798 .37843 L F
.219 .239 .668 r
.53495 .60369 m .53548 .60729 L .5372 .60574 L F
.283 .345 .75 r
.53548 .60729 m .53831 .60997 L .5372 .60574 L F
.963 .652 .385 r
.58613 .54758 m .58731 .54705 L .58622 .54523 L F
.58613 .54758 m .58708 .54824 L .58731 .54705 L F
.191 .681 .924 r
.26883 .5399 m .271 .53996 L .27272 .54063 L F
.451 .798 .998 r
.271 .53996 m .27485 .54045 L .27272 .54063 L F
.623 .585 .791 r
.2302 .6817 m .22893 .68561 L .22787 .68186 L F
.2302 .6817 m .23166 .68448 L .22893 .68561 L F
.438 .204 .46 r
.22847 .68795 m .22893 .68561 L .23054 .68734 L F
.459 .205 .442 r
.22893 .68561 m .23166 .68448 L .23054 .68734 L F
.752 .913 .946 r
.69346 .43034 m .69487 .43105 L .69788 .42909 L F
.06 0 0 r
.79707 .44454 m .79534 .44415 L .79794 .44336 L F
.79707 .44454 m .79473 .44578 L .79534 .44415 L F
.067 0 .148 r
.5258 .51979 m .52743 .51899 L .52825 .51672 L F
.426 .041 .204 r
.52877 .51826 m .52825 .51672 L .52743 .51899 L F
.52877 .51826 m .53076 .51637 L .52825 .51672 L F
.724 .816 .922 r
.77612 .40466 m .77669 .40634 L .78014 .40456 L F
.066 0 .23 r
.15041 .58597 m .14957 .58862 L .14811 .58906 L F
.647 .897 .568 r
.14957 .58862 m .14735 .59131 L .14811 .58906 L F
.171 .274 .729 r
.49245 .60036 m .49498 .6027 L .49628 .60104 L F
.554 .362 .575 r
.49628 .60104 m .49646 .60408 L .4938 .60439 L F
.582 .383 .576 r
.49881 .60326 m .49628 .60104 L .49915 .60084 L F
.49881 .60326 m .49646 .60408 L .49628 .60104 L F
0 0 0 r
.49756 .59971 m .49628 .60104 L .49498 .6027 L F
.692 .245 .186 r
.49498 .6027 m .49628 .60104 L .49245 .60036 L F
.733 .56 .658 r
.57226 .49169 m .57631 .4895 L .57246 .48963 L F
.474 .294 .556 r
.29598 .59417 m .29381 .59785 L .29392 .59496 L F
.291 .051 .367 r
.45444 .5749 m .45236 .5765 L .45228 .57426 L F
.935 .635 .171 r
.65687 .41651 m .65596 .41532 L .65656 .41435 L F
.866 .79 .295 r
.65656 .41435 m .65596 .41532 L .65644 .413 L F
.49 .306 .558 r
.65936 .41575 m .65656 .41435 L .65933 .41405 L F
.65936 .41575 m .65687 .41651 L .65656 .41435 L F
.353 .502 .868 r
.79051 .3987 m .79249 .40185 L .79404 .4 L F
0 0 .381 r
.79404 .4 m .79249 .40185 L .79255 .40435 L F
.498 .347 .606 r
.45469 .58509 m .45799 .58586 L .45769 .58384 L F
.609 .516 .723 r
.45469 .58509 m .45868 .58863 L .45799 .58586 L F
.45469 .58509 m .45611 .58982 L .45868 .58863 L F
.659 .598 .775 r
.66422 .40933 m .66267 .41316 L .66198 .41087 L F
.839 .706 .716 r
.70498 .42233 m .70628 .42344 L .705 .41969 L F
.732 .653 .771 r
.705 .41969 m .70628 .42344 L .7081 .42218 L F
.637 .416 .566 r
.52468 .54347 m .52728 .54327 L .52729 .54078 L F
.483 .395 .681 r
.29402 .60033 m .29155 .59847 L .29381 .59785 L F
.29402 .60033 m .29196 .601 L .29155 .59847 L F
.797 .482 .456 r
.68161 .41536 m .68498 .41405 L .68134 .41351 L F
.68161 .41536 m .68525 .4161 L .68498 .41405 L F
.53 .519 .787 r
.8217 .40843 m .82509 .40966 L .82263 .41032 L F
.611 .818 .413 r
.83363 .43691 m .83151 .44007 L .833 .43783 L F
.715 .987 .849 r
.83151 .44007 m .83498 .43817 L .833 .43783 L F
.83151 .44007 m .83179 .44032 L .83498 .43817 L F
.046 0 0 r
.49132 .58184 m .49457 .57974 L .49207 .58068 L F
.554 .729 .957 r
.19782 .62497 m .1973 .62741 L .19513 .62497 L F
.19782 .62497 m .19981 .62711 L .1973 .62741 L F
.534 .799 .994 r
.2326 .67353 m .22872 .67301 L .23036 .67265 L F
0 0 0 r
.23235 .67615 m .23456 .67564 L .2326 .67353 L F
.484 .285 .534 r
.2326 .67353 m .23456 .67564 L .23235 .67615 L F
.897 .678 .598 r
.57324 .51063 m .57027 .51224 L .57021 .5096 L F
.57324 .51063 m .57316 .51338 L .57027 .51224 L F
.778 .722 .801 r
.52284 .52203 m .5258 .51979 L .52203 .51918 L F
.344 .346 .717 r
.5258 .51979 m .52833 .52151 L .52743 .51899 L F
.737 .775 .883 r
.51984 .52159 m .52203 .51918 L .51992 .52064 L F
.665 .668 .843 r
.51984 .52159 m .52284 .52203 L .52203 .51918 L F
.16 0 0 r
.16277 .55569 m .16309 .55692 L .16459 .55466 L F
.16277 .55569 m .16095 .55752 L .16309 .55692 L F
.169 .657 .922 r
.25313 .53781 m .25342 .53788 L .25515 .53843 L F
.25342 .53788 m .25701 .5387 L .25515 .53843 L F
.285 0 0 r
.25515 .53843 m .25872 .53818 L .25708 .53905 L F
.25515 .53843 m .25708 .53905 L .25704 .53907 L F
.619 .537 .741 r
.30066 .56998 m .30146 .57516 L .29869 .57433 L F
.317 0 .164 r
.30146 .57516 m .29882 .57678 L .29869 .57433 L F
.965 .903 .708 r
.57213 .54629 m .5719 .54941 L .5709 .54871 L F
.981 .911 .637 r
.57055 .55283 m .5709 .54871 L .5719 .54941 L F
0 0 .331 r
.653 .44098 m .65448 .43691 L .65516 .43861 L F
.653 .44098 m .65447 .43941 L .65448 .43691 L F
.305 .491 .877 r
.653 .44098 m .6559 .44234 L .65447 .43941 L F
.734 .621 .733 r
.47255 .62443 m .4741 .62826 L .4767 .62553 L F
.157 .685 .866 r
.21486 .69939 m .21903 .6997 L .21562 .69899 L F
.41 .815 .981 r
.21562 .69899 m .21903 .6997 L .21895 .6989 L F
.429 .096 .298 r
.42185 .6178 m .42415 .61892 L .42433 .6158 L F
.6 .514 .729 r
.42433 .6158 m .42687 .61581 L .42591 .61448 L F
.76 .375 .325 r
.42433 .6158 m .42692 .61845 L .42687 .61581 L F
.42433 .6158 m .42415 .61892 L .42692 .61845 L F
.546 .017 0 r
.43126 .63361 m .43154 .63411 L .43454 .63425 L F
.812 .54 .527 r
.22379 .67938 m .22347 .68176 L .22787 .68186 L F
.706 .267 .206 r
.22347 .68176 m .22547 .68388 L .22787 .68186 L F
.75 .957 .656 r
.22787 .68186 m .22789 .68082 L .22994 .6791 L F
.753 .955 .646 r
.22787 .68186 m .22547 .68388 L .22789 .68082 L F
.493 .372 .643 r
.22994 .6791 m .2302 .6817 L .22787 .68186 L F
.994 .825 .566 r
.5737 .54064 m .5721 .54167 L .57219 .53972 L F
.5737 .54064 m .5732 .54262 L .5721 .54167 L F
.276 .22 .612 r
.2666 .58293 m .26796 .58218 L .26757 .5795 L F
.403 .255 .564 r
.26609 .58534 m .26796 .58218 L .2666 .58293 L F
.32 .796 .913 r
.19595 .64698 m .19739 .6466 L .19473 .64657 L F
0 0 .063 r
.56902 .56429 m .56933 .56067 L .56954 .56186 L F
.282 .694 .971 r
.23453 .53697 m .23427 .53804 L .2326 .53738 L F
.23453 .53697 m .23658 .53811 L .23427 .53804 L F
.328 0 .016 r
.55939 .58513 m .55749 .58741 L .55506 .5878 L F
.376 .118 .39 r
.55939 .58513 m .56123 .58519 L .56113 .58734 L F
.561 .305 .485 r
.46204 .58871 m .46458 .58848 L .46483 .58599 L F
.396 .217 .517 r
.46483 .58599 m .46702 .5853 L .46709 .58264 L F
.58 .59 .827 r
.46777 .5878 m .46483 .58599 L .46819 .58702 L F
.513 .264 .475 r
.46483 .58599 m .46706 .58797 L .46702 .5853 L F
.46483 .58599 m .46458 .58848 L .46706 .58797 L F
.931 .969 .698 r
.48177 .61592 m .4799 .61808 L .48038 .61892 L F
.931 .951 .776 r
.4799 .61808 m .47872 .62207 L .48038 .61892 L F
.317 0 0 r
.4558 .56428 m .45837 .56407 L .45964 .56271 L F
.191 0 0 r
.45837 .56407 m .46216 .56244 L .45964 .56271 L F
0 0 .41 r
.39922 .62209 m .40094 .62543 L .40046 .62429 L F
.838 .394 .168 r
.40367 .62703 m .40046 .62429 L .40094 .62543 L F
.907 .558 .367 r
.494 .54678 m .49217 .54642 L .49142 .54366 L F
.338 0 0 r
.49735 .54817 m .49217 .54642 L .494 .54678 L F
0 0 .091 r
.53406 .59835 m .53424 .59864 L .53403 .59619 L F
.53406 .59835 m .5342 .6004 L .53424 .59864 L F
.245 0 .066 r
.7965 .43504 m .79842 .43598 L .79919 .43467 L F
.7965 .43504 m .79594 .43681 L .79842 .43598 L F
.687 .682 .839 r
.7468 .41249 m .74803 .41431 L .75044 .41332 L F
.688 .719 .873 r
.17871 .61524 m .17609 .61636 L .17436 .61462 L F
0 .047 .615 r
.41011 .63708 m .41047 .63602 L .40858 .63372 L F
0 .169 .707 r
.41011 .63708 m .41227 .63917 L .41047 .63602 L F
.813 .845 .873 r
.67599 .42679 m .67384 .42941 L .67242 .42789 L F
0 0 .04 r
.67384 .42941 m .6743 .42994 L .67242 .42789 L F
.67384 .42941 m .67313 .432 L .6743 .42994 L F
.393 .614 .939 r
.76402 .43271 m .76569 .43092 L .76331 .43094 L F
.76402 .43271 m .76748 .43325 L .76569 .43092 L F
0 .223 .649 r
.76402 .43271 m .76809 .43526 L .76748 .43325 L F
0 0 0 r
.57596 .5944 m .5734 .59739 L .57459 .59588 L F
.787 .985 .898 r
.19732 .54109 m .19769 .53924 L .19949 .54029 L F
.19732 .54109 m .19497 .54139 L .19769 .53924 L F
.329 .054 .336 r
.4579 .63242 m .45546 .63158 L .4585 .63081 L F
.4579 .63242 m .45533 .63332 L .45546 .63158 L F
.78 .346 .22 r
.50278 .5498 m .50351 .55016 L .50018 .54914 L F
.499 0 0 r
.50351 .55016 m .50311 .55069 L .50018 .54914 L F
.703 .173 0 r
.50469 .55153 m .50311 .55069 L .50351 .55016 L F
.86 .818 .807 r
.58516 .52176 m .58901 .52004 L .58744 .51841 L F
.58516 .52176 m .58686 .52266 L .58901 .52004 L F
.421 .096 .307 r
.23902 .62191 m .2414 .62143 L .2424 .61863 L F
.334 .016 .269 r
.2424 .61863 m .24352 .62079 L .24462 .61784 L F
.2424 .61863 m .2414 .62143 L .24352 .62079 L F
.473 .219 .447 r
.43816 .6222 m .43774 .62469 L .43537 .62515 L F
.218 .281 .715 r
.43682 .62103 m .43774 .62469 L .43816 .6222 L F
.286 .463 .86 r
.43816 .6222 m .44112 .62409 L .4406 .62176 L F
.966 .656 .379 r
.57055 .55283 m .57085 .55527 L .56935 .55423 L F
.981 .911 .637 r
.57055 .55283 m .56981 .55177 L .5709 .54871 L F
.994 .84 .481 r
.57055 .55283 m .56935 .55423 L .56981 .55177 L F
.966 .656 .379 r
.57055 .55283 m .57085 .55527 L .56935 .55423 L F
.909 .574 .396 r
.5165 .53756 m .51531 .53948 L .51603 .53684 L F
.5165 .53756 m .51813 .54125 L .51531 .53948 L F
.936 .75 .625 r
.42291 .60433 m .42034 .60583 L .42184 .60625 L F
.969 .756 .561 r
.42207 .5896 m .42035 .58836 L .41875 .5894 L F
.42207 .5896 m .42012 .59068 L .42035 .58836 L F
.852 .996 .762 r
.42255 .58761 m .42012 .59068 L .42207 .5896 L F
.628 .783 .956 r
.19731 .55838 m .20125 .559 L .19947 .5577 L F
.704 .82 .937 r
.19947 .5577 m .20125 .559 L .20346 .55801 L F
.493 .266 .498 r
.27684 .62154 m .27428 .62452 L .27466 .62206 L F
.418 .096 .31 r
.42408 .63317 m .42775 .63056 L .42401 .63049 L F
.434 .112 .319 r
.46284 .60349 m .46417 .60586 L .46506 .60372 L F
.46284 .60349 m .46143 .60667 L .46417 .60586 L F
.706 .371 .408 r
.56773 .50737 m .56627 .50954 L .56413 .50721 L F
.698 .361 .402 r
.57021 .5096 m .56773 .50737 L .56998 .50768 L F
.57021 .5096 m .56627 .50954 L .56773 .50737 L F
.219 .74 .845 r
.18873 .64589 m .18705 .64577 L .18468 .64614 L F
.55 .71 .946 r
.18873 .64589 m .19113 .6455 L .1896 .64351 L F
.813 .983 .889 r
.1896 .64351 m .18705 .64577 L .18873 .64589 L F
.67 .455 .585 r
.56372 .49474 m .56661 .49193 L .56379 .49249 L F
.705 .617 .756 r
.17031 .61672 m .16644 .61544 L .1681 .61548 L F
.831 .983 .877 r
.17202 .61515 m .17031 .61672 L .17034 .61494 L F
.546 .786 .987 r
.17034 .61494 m .17031 .61672 L .1681 .61548 L F
.582 .405 .608 r
.44351 .61923 m .44614 .61883 L .4457 .61576 L F
.502 .349 .606 r
.4457 .61576 m .4487 .61746 L .44855 .61554 L F
.4457 .61576 m .44614 .61883 L .4487 .61746 L F
.732 .653 .771 r
.705 .41969 m .7081 .42218 L .70874 .42033 L F
.81 .749 .796 r
.70874 .42033 m .7081 .42218 L .71042 .41952 L F
0 0 .474 r
.5811 .57585 m .58142 .57846 L .57999 .57999 L F
0 0 .337 r
.58142 .57846 m .57967 .58238 L .57999 .57999 L F
.12 .175 .646 r
.41344 .64923 m .41469 .64891 L .41373 .64517 L F
.097 .085 .553 r
.41344 .64923 m .41473 .65135 L .41469 .64891 L F
.641 .819 .968 r
.23989 .65684 m .23847 .65882 L .24115 .65838 L F
.803 .324 .077 r
.24097 .6614 m .2407 .66244 L .2384 .65988 L F
0 .173 .71 r
.2384 .65988 m .2407 .66244 L .23999 .66137 L F
.429 .849 .694 r
.23847 .65882 m .23652 .65974 L .23823 .65871 L F
.837 .635 .629 r
.24124 .65867 m .2384 .65988 L .23847 .65882 L F
0 0 0 r
.23746 .6592 m .23652 .65974 L .23422 .66042 L F
.23847 .65882 m .23768 .6592 L .23746 .6592 L F
.23768 .6592 m .23652 .65974 L .23746 .6592 L F
.837 .635 .629 r
.24124 .65867 m .24097 .6614 L .2384 .65988 L F
0 .173 .71 r
.2384 .65988 m .23999 .66137 L .23854 .65918 L F
.697 .214 .097 r
.2384 .65988 m .23768 .6592 L .23847 .65882 L F
0 .173 .71 r
.2383 .65918 m .23854 .65918 L .23823 .65871 L F
.2384 .65988 m .23854 .65918 L .2383 .65918 L F
.697 .214 .097 r
.2384 .65988 m .23652 .65974 L .23768 .6592 L F
.604 .765 .956 r
.23989 .65684 m .24091 .65822 L .23847 .65882 L F
.304 .633 .963 r
.23989 .65684 m .24115 .65838 L .24107 .65785 L F
.627 .775 .952 r
.24333 .65793 m .2418 .65847 L .23989 .65684 L F
.24192 .65693 m .23989 .65684 L .24089 .65621 L F
.24333 .65793 m .24131 .65728 L .24192 .65693 L F
.24131 .65728 m .23989 .65684 L .24192 .65693 L F
.304 .633 .963 r
.23989 .65684 m .24084 .65624 L .24089 .65621 L F
.23989 .65684 m .24029 .65718 L .24084 .65624 L F
.24029 .65718 m .24107 .65785 L .24084 .65624 L F
.627 .775 .952 r
.2418 .65847 m .24124 .65867 L .24091 .65822 L F
.24107 .65785 m .24091 .65822 L .23989 .65684 L F
.82 .988 .876 r
.24107 .65785 m .24115 .65838 L .24091 .65822 L F
.627 .775 .952 r
.2418 .65847 m .24091 .65822 L .24107 .65785 L F
.82 .988 .876 r
.24091 .65822 m .24115 .65838 L .24084 .65841 L F
.24107 .65781 m .24107 .65785 L .24091 .65822 L F
.647 .883 .532 r
.24155 .65503 m .24084 .65624 L .23916 .65806 L F
.24158 .65499 m .24084 .65624 L .24155 .65503 L F
.82 .988 .876 r
.24084 .65624 m .24101 .65745 L .23823 .65871 L F
.24101 .65745 m .24107 .65781 L .23957 .65829 L F
.24101 .65745 m .23957 .65829 L .23823 .65871 L F
.604 .765 .956 r
.24091 .65822 m .24084 .65841 L .23847 .65882 L F
.82 .988 .876 r
.24107 .65781 m .24084 .65841 L .23823 .65871 L F
.604 .765 .956 r
.24091 .65822 m .24103 .65838 L .24084 .65841 L F
.429 .849 .694 r
.23847 .65882 m .24084 .65841 L .24115 .65838 L F
.604 .765 .956 r
.24103 .65838 m .24124 .65867 L .23847 .65882 L F
.429 .849 .694 r
.23847 .65882 m .23823 .65871 L .24084 .65841 L F
.171 .707 .753 r
.24115 .65838 m .23847 .65882 L .23823 .65871 L F
.26 .77 .816 r
.20167 .5395 m .2054 .53888 L .20321 .53986 L F
.431 .157 .396 r
.5498 .50069 m .55195 .50035 L .55253 .49806 L F
.342 .015 .257 r
.55195 .50035 m .55503 .49774 L .55253 .49806 L F
.731 .269 0 r
.43049 .6331 m .43024 .63211 L .42775 .63056 L F
.43049 .6331 m .43154 .63411 L .43024 .63211 L F
.911 .747 .665 r
.57481 .51886 m .57601 .52242 L .5738 .52187 L F
.907 .763 .69 r
.5738 .52187 m .57601 .52242 L .57486 .52581 L F
.786 .663 .728 r
.70874 .42033 m .71042 .41952 L .71104 .4172 L F
.395 .178 .462 r
.28948 .60398 m .28915 .6066 L .28708 .6071 L F
.585 .379 .568 r
.2895 .60924 m .28708 .6071 L .28915 .6066 L F
.2895 .60924 m .28699 .60966 L .28708 .6071 L F
.555 .916 .955 r
.22611 .64674 m .22946 .64616 L .22786 .64526 L F
.593 .859 .994 r
.22786 .64526 m .22946 .64616 L .2311 .64509 L F
.707 .515 .626 r
.69499 .4166 m .69761 .41662 L .69752 .41408 L F
.673 .542 .696 r
.69761 .41662 m .7002 .41388 L .69752 .41408 L F
.628 .606 .809 r
.15942 .60129 m .15742 .60225 L .15602 .59953 L F
.122 0 .285 r
.42885 .6519 m .42642 .65708 L .42639 .65581 L F
.271 0 0 r
.42642 .65708 m .42604 .65701 L .42639 .65581 L F
.871 .691 .656 r
.49042 .60347 m .4938 .60439 L .49245 .60036 L F
.614 .299 .413 r
.49074 .60615 m .4938 .60439 L .49042 .60347 L F
.49074 .60615 m .49349 .60634 L .4938 .60439 L F
.4938 .60439 m .49349 .60634 L .49074 .60615 L F
.171 .274 .729 r
.49245 .60036 m .4938 .60439 L .49498 .6027 L F
.504 .202 .388 r
.49612 .60581 m .4938 .60439 L .49646 .60408 L F
.4938 .60439 m .49612 .60581 L .49498 .6027 L F
.4938 .60439 m .49349 .60634 L .49612 .60581 L F
.49612 .60581 m .49349 .60634 L .4938 .60439 L F
.438 .173 .414 r
.15642 .58203 m .15533 .58 L .15686 .57968 L F
.15642 .58203 m .15389 .58388 L .15533 .58 L F
.907 .902 .809 r
.7577 .40638 m .76095 .40389 L .76014 .40333 L F
.114 .537 .915 r
.21243 .69437 m .21418 .69453 L .21207 .69314 L F
.708 .639 .778 r
.21303 .70019 m .21418 .69453 L .21243 .69437 L F
.504 .797 .998 r
.51981 .61192 m .51797 .61299 L .51685 .61176 L F
.51981 .61192 m .52084 .61299 L .51797 .61299 L F
.51797 .61299 m .51981 .61192 L .51685 .61176 L F
.51797 .61299 m .52084 .61299 L .51981 .61192 L F
.535 .034 .013 r
.46434 .57015 m .46164 .57174 L .46088 .57036 L F
.222 0 .172 r
.46708 .56783 m .46634 .56939 L .46434 .57015 L F
.078 0 0 r
.46624 .57015 m .46434 .57015 L .46634 .56939 L F
.46624 .57015 m .46164 .57174 L .46434 .57015 L F
.258 .433 .844 r
.41073 .61348 m .41169 .6113 L .40919 .61214 L F
.41073 .61348 m .41342 .61438 L .41169 .6113 L F
.254 0 .237 r
.4588 .60888 m .45694 .61066 L .45788 .61021 L F
.45694 .61066 m .456 .61157 L .45788 .61021 L F
.6 .684 .901 r
.45788 .61021 m .4617 .6109 L .46052 .60895 L F
.45788 .61021 m .45816 .6093 L .4588 .60888 L F
0 0 0 r
.46 .60811 m .45692 .60996 L .4588 .60888 L F
.6 .684 .901 r
.45816 .6093 m .45901 .60646 L .4588 .60888 L F
0 0 0 r
.46017 .60801 m .46 .60811 L .4588 .60888 L F
.092 0 .073 r
.45692 .60996 m .456 .61157 L .4588 .60888 L F
.6 .684 .901 r
.45788 .61021 m .46052 .60895 L .45901 .60646 L F
.765 .694 .783 r
.70749 .41671 m .71104 .4172 L .70999 .41366 L F
.786 .663 .728 r
.70874 .42033 m .71104 .4172 L .70749 .41671 L F
.724 .647 .771 r
.71104 .4172 m .71371 .41442 L .70999 .41366 L F
.71104 .4172 m .71345 .41618 L .71371 .41442 L F
.426 .171 .423 r
.27212 .62509 m .27169 .62769 L .26946 .62807 L F
.486 .256 .49 r
.27428 .62452 m .27169 .62769 L .27212 .62509 L F
.451 .184 .417 r
.40343 .6071 m .40063 .60992 L .40302 .60917 L F
.252 .091 .46 r
.40343 .6071 m .40524 .60637 L .40533 .60375 L F
.452 .185 .417 r
.40343 .6071 m .40548 .60857 L .40524 .60637 L F
.40343 .6071 m .40302 .60917 L .40548 .60857 L F
.962 .663 .417 r
.46436 .59138 m .46459 .59346 L .46586 .5923 L F
.914 .843 .761 r
.46436 .59138 m .46586 .5923 L .46777 .5878 L F
.937 .605 .38 r
.46459 .59346 m .46681 .59498 L .46586 .5923 L F
.576 .162 .221 r
.43927 .61311 m .43782 .61522 L .4352 .61466 L F
.551 .136 .206 r
.44214 .6141 m .43782 .61522 L .43927 .61311 L F
0 0 0 r
.72432 .39231 m .72077 .3946 L .72321 .39165 L F
.849 .518 0 r
.41922 .66138 m .41862 .6619 L .41587 .65985 L F
.41922 .66138 m .41944 .66319 L .41862 .6619 L F
.707 .33 .334 r
.42141 .66134 m .41944 .66319 L .41922 .66138 L F
.149 0 .216 r
.5424 .50791 m .54174 .50981 L .54423 .5068 L F
.799 .83 .876 r
.53083 .52862 m .53203 .52465 L .52948 .52543 L F
.53083 .52862 m .53362 .52595 L .53203 .52465 L F
.917 .707 .604 r
.51428 .59114 m .51409 .59444 L .51654 .59502 L F
.896 .609 .492 r
.51382 .59573 m .51654 .59502 L .51409 .59444 L F
.51382 .59573 m .51669 .59768 L .51654 .59502 L F
.755 .58 .659 r
.57631 .4895 m .57604 .49214 L .57852 .48941 L F
.662 .441 .575 r
.57852 .48941 m .57604 .49214 L .57851 .49166 L F
.68 .753 .906 r
.15219 .59471 m .15169 .59499 L .14903 .59488 L F
.15219 .59471 m .15169 .59499 L .14903 .59488 L F
.746 .637 .74 r
.78014 .40456 m .78387 .4054 L .78266 .40137 L F
.529 .654 .914 r
.81888 .40721 m .82123 .40664 L .8217 .40843 L F
.539 .661 .915 r
.82123 .40664 m .82378 .40622 L .8217 .40843 L F
.47 .549 .855 r
.82378 .40622 m .82509 .40966 L .8217 .40843 L F
.909 .851 .401 r
.40624 .61979 m .40562 .61987 L .40605 .62114 L F
0 .325 .799 r
.40547 .61945 m .40656 .62049 L .40644 .62137 L F
.561 .009 0 r
.40696 .62123 m .40656 .62049 L .40519 .61992 L F
.40509 .61994 m .40519 .61992 L .40489 .6198 L F
.40696 .62123 m .40519 .61992 L .40509 .61994 L F
.909 .851 .401 r
.4069 .6151 m .40547 .61945 L .40562 .61987 L F
.4069 .6151 m .40562 .61987 L .40624 .61979 L F
0 .325 .799 r
.40547 .61945 m .40644 .62137 L .40605 .62114 L F
.634 .441 .604 r
.70866 .4101 m .71133 .40726 L .70884 .40807 L F
.181 .245 .694 r
.40855 .62344 m .40732 .62582 L .40644 .62137 L F
.432 .557 .881 r
.40855 .62344 m .4108 .62643 L .40732 .62582 L F
.49 .489 .783 r
.30061 .58777 m .29831 .5889 L .29773 .58615 L F
.395 .274 .596 r
.30061 .58777 m .29857 .59136 L .29831 .5889 L F
.05 .237 .735 r
.50227 .59748 m .50252 .59775 L .50336 .59673 L F
.50252 .59775 m .50458 .60005 L .50336 .59673 L F
.697 .657 .807 r
.50336 .59673 m .50148 .59997 L .50227 .59748 L F
0 .105 .631 r
.49991 .59532 m .50212 .59816 L .50336 .59673 L F
.553 .826 .473 r
.50406 .59587 m .50336 .59673 L .50212 .59816 L F
0 0 0 r
.5052 .59344 m .50336 .59673 L .50461 .59522 L F
.553 .826 .473 r
.50461 .59522 m .50336 .59673 L .50406 .59587 L F
0 0 .134 r
.46882 .56676 m .46634 .56939 L .46708 .56783 L F
.776 .576 .629 r
.58224 .49459 m .58602 .49245 L .58226 .49216 L F
.58224 .49459 m .58597 .49504 L .58602 .49245 L F
.906 .525 .29 r
.23256 .57649 m .23449 .5771 L .23154 .57385 L F
.747 .688 .794 r
.23256 .57649 m .23362 .57968 L .23449 .5771 L F
.304 .617 .957 r
.80636 .40002 m .80509 .40118 L .80432 .39961 L F
.80636 .40002 m .80728 .40144 L .80509 .40118 L F
.358 .003 .22 r
.80257 .41992 m .80515 .41945 L .80444 .41928 L F
.519 .507 .782 r
.80536 .42168 m .80515 .41945 L .80257 .41992 L F
0 .029 .583 r
.53495 .60369 m .53575 .60222 L .5342 .6004 L F
0 .198 .716 r
.53495 .60369 m .5372 .60574 L .53575 .60222 L F
0 .068 .604 r
.41255 .63069 m .41326 .63372 L .41259 .63416 L F
.916 .763 .676 r
.58814 .53697 m .58749 .53356 L .58587 .53672 L F
.958 .838 .682 r
.58555 .53943 m .58814 .53697 L .58587 .53672 L F
.58555 .53943 m .58704 .5405 L .58814 .53697 L F
.914 .843 .761 r
.46436 .59138 m .46777 .5878 L .46706 .58797 L F
.105 .017 .462 r
.46955 .58487 m .46777 .5878 L .46819 .58702 L F
.46955 .58487 m .46956 .58745 L .46777 .5878 L F
0 0 0 r
.46956 .58745 m .46706 .58797 L .46777 .5878 L F
.583 .439 .651 r
.22418 .67613 m .2265 .67651 L .2262 .67341 L F
.587 .885 .991 r
.19477 .75132 m .19345 .75223 L .1906 .75158 L F
0 0 .059 r
.19236 .75437 m .19345 .75223 L .19477 .75132 L F
.613 .6 .814 r
.46045 .6304 m .4579 .63242 L .4585 .63081 L F
.555 .199 .319 r
.43354 .64234 m .42936 .64515 L .43016 .64373 L F
.905 .964 .814 r
.17202 .61515 m .17248 .61184 L .17436 .61462 L F
.17202 .61515 m .17034 .61494 L .17248 .61184 L F
.692 .551 .69 r
.2118 .70697 m .21175 .70919 L .21455 .70658 L F
.975 .793 .594 r
.2118 .70697 m .21175 .70919 L .21034 .7084 L F
.221 .738 .726 r
.22369 .62952 m .22583 .62905 L .22265 .62988 L F
.267 0 0 r
.22369 .62952 m .22818 .6284 L .22583 .62905 L F
.7 .597 .737 r
.4466 .60394 m .44444 .60433 L .44274 .60107 L F
.681 .504 .64 r
.4466 .60394 m .44498 .60634 L .44444 .60433 L F
.526 .698 .948 r
.8205 .40496 m .81888 .40721 L .81729 .40487 L F
.8205 .40496 m .82123 .40664 L .81888 .40721 L F
0 0 0 r
.55458 .58407 m .55521 .58271 L .55324 .58585 L F
.232 .206 .623 r
.55324 .58585 m .55506 .5878 L .55458 .58407 L F
.404 .232 .532 r
.55324 .58585 m .55308 .58932 L .55506 .5878 L F
.937 .685 .53 r
.58516 .52176 m .58666 .5248 L .58686 .52266 L F
.479 .706 .969 r
.16237 .62941 m .16656 .63097 L .16433 .6277 L F
.516 .617 .891 r
.16656 .63097 m .16641 .62726 L .16433 .6277 L F
.16656 .63097 m .16856 .63048 L .16641 .62726 L F
.488 .555 .851 r
.16656 .63097 m .17028 .63377 L .16856 .63048 L F
.315 0 0 r
.20979 .55574 m .20591 .55713 L .20713 .55749 L F
.20979 .55574 m .20783 .55722 L .20591 .55713 L F
0 0 0 r
.20998 .55643 m .20979 .55574 L .21183 .55481 L F
.20998 .55643 m .20783 .55722 L .20979 .55574 L F
.662 .729 .9 r
.24905 .55215 m .25041 .55366 L .25251 .5527 L F
.566 .441 .668 r
.25251 .5527 m .25041 .55366 L .24905 .55215 L F
.752 .383 .356 r
.81519 .44592 m .81398 .44651 L .81057 .44609 L F
0 0 0 r
.17393 .54983 m .17384 .55012 L .17605 .54916 L F
.17393 .54983 m .17188 .55125 L .17384 .55012 L F
.385 .209 .515 r
.22992 .59184 m .23117 .59156 L .23226 .58847 L F
0 .238 .688 r
.23218 .5892 m .23466 .59104 L .23448 .58906 L F
.385 .209 .515 r
.23201 .58919 m .2322 .58916 L .23226 .58847 L F
.23117 .59156 m .23215 .58927 L .23201 .58919 L F
.23215 .58927 m .2322 .58916 L .23201 .58919 L F
0 .238 .688 r
.23219 .58929 m .23466 .59104 L .23218 .5892 L F
.23219 .58929 m .2344 .59071 L .23466 .59104 L F
.855 .742 .738 r
.23468 .58562 m .23306 .58784 L .23448 .58906 L F
.23306 .58784 m .23234 .58883 L .23241 .58883 L F
.23306 .58784 m .23241 .58883 L .23448 .58906 L F
.23239 .58883 m .23218 .5892 L .23448 .58906 L F
.592 .384 .568 r
.23226 .58847 m .2322 .58916 L .23249 .58871 L F
.23226 .58847 m .23249 .58871 L .23206 .58921 L F
.855 .742 .738 r
.23234 .58883 m .23229 .58894 L .23239 .58883 L F
.23229 .58894 m .23218 .5892 L .23239 .58883 L F
.592 .384 .568 r
.23249 .58871 m .23219 .58929 L .2344 .59071 L F
.2322 .58916 m .23219 .58929 L .23249 .58871 L F
0 .238 .688 r
.23206 .58921 m .23219 .58929 L .23218 .5892 L F
.385 .209 .515 r
.23218 .5892 m .23219 .58931 L .2322 .58916 L F
.855 .742 .738 r
.23234 .58883 m .23206 .58921 L .23218 .5892 L F
.592 .384 .568 r
.23249 .58871 m .2344 .59071 L .23206 .58921 L F
.23219 .58929 m .23199 .59138 L .2344 .59071 L F
0 .238 .688 r
.23206 .58921 m .23232 .58937 L .23219 .58929 L F
.23218 .58929 m .23219 .58929 L .23219 .58929 L F
.23206 .58921 m .23219 .58929 L .23218 .58929 L F
.23232 .58937 m .2344 .59071 L .23219 .58929 L F
.385 .209 .515 r
.23117 .59156 m .23199 .59138 L .23219 .58931 L F
.23117 .59156 m .23219 .58931 L .23218 .5892 L F
.55 .861 .996 r
.22199 .64684 m .22353 .64757 L .22611 .64674 L F
.448 .151 .367 r
.26144 .63407 m .26057 .63674 L .25845 .63668 L F
.416 .121 .353 r
.26292 .63608 m .26144 .63407 L .26374 .63361 L F
.26292 .63608 m .26057 .63674 L .26144 .63407 L F
.501 .294 .53 r
.29196 .601 m .29177 .60349 L .28948 .60398 L F
.503 .27 .493 r
.29149 .60609 m .28948 .60398 L .29177 .60349 L F
.29149 .60609 m .28915 .6066 L .28948 .60398 L F
.574 .368 .564 r
.45138 .63723 m .45119 .64012 L .44829 .6401 L F
0 0 0 r
.45239 .63649 m .45138 .63723 L .4534 .63455 L F
.045 0 .398 r
.45224 .6392 m .45138 .63723 L .45239 .63649 L F
.45224 .6392 m .45119 .64012 L .45138 .63723 L F
.535 .577 .843 r
.55373 .57924 m .55521 .58271 L .55751 .58216 L F
.27 0 .072 r
.55751 .58216 m .55521 .58271 L .55458 .58407 L F
.398 .201 .494 r
.29402 .60033 m .29177 .60349 L .29196 .601 L F
.301 .071 .389 r
.50421 .60744 m .50584 .60876 L .50632 .6067 L F
.50421 .60744 m .50388 .60986 L .50584 .60876 L F
.50584 .60876 m .50421 .60744 L .50632 .6067 L F
.50584 .60876 m .50388 .60986 L .50421 .60744 L F
.472 .379 .669 r
.26649 .57071 m .26889 .57031 L .26804 .56719 L F
.548 .334 .542 r
.26649 .57071 m .26875 .57224 L .26889 .57031 L F
.26649 .57071 m .26645 .57324 L .26875 .57224 L F
.481 .26 .501 r
.18754 .76048 m .18958 .75599 L .18972 .76006 L F
.18754 .76048 m .18958 .75599 L .18972 .76006 L F
.722 .287 .216 r
.50096 .59439 m .50336 .59673 L .50324 .59461 L F
.358 .245 .586 r
.50414 .59175 m .50563 .58849 L .50299 .5892 L F
.50414 .59175 m .506 .59118 L .50563 .58849 L F
.753 .498 .546 r
.50545 .59108 m .50228 .59277 L .50362 .59074 L F
.506 .59118 m .50529 .59149 L .50545 .59108 L F
.084 0 .397 r
.50414 .59175 m .50324 .59461 L .50434 .59395 L F
.50414 .59175 m .50434 .59395 L .50479 .59279 L F
.50414 .59175 m .5052 .59344 L .506 .59118 L F
.753 .498 .546 r
.50529 .59149 m .50228 .59277 L .50545 .59108 L F
.084 0 .397 r
.50479 .59279 m .50434 .59395 L .5052 .59344 L F
.555 .199 .319 r
.43354 .64234 m .43201 .64508 L .42936 .64515 L F
.434 .861 .734 r
.436 .64319 m .43201 .64508 L .43354 .64234 L F
.657 .819 .387 r
.77002 .42397 m .76909 .42581 L .7717 .42111 L F
.965 .658 .258 r
.77002 .42397 m .77149 .42778 L .76909 .42581 L F
.566 .045 0 r
.54192 .57688 m .54386 .57885 L .54512 .57987 L F
.494 .812 1 r
.54137 .57941 m .54386 .57885 L .54512 .57987 L F
.54512 .57987 m .54386 .57885 L .54137 .57941 L F
.951 .931 .743 r
.76554 .40803 m .76658 .40341 L .76743 .40449 L F
.965 .92 .709 r
.76743 .40449 m .76658 .40341 L .76749 .39887 L F
.246 .613 .956 r
.15577 .62513 m .15554 .62445 L .15481 .62435 L F
.111 0 .248 r
.25738 .60099 m .25883 .60038 L .2596 .59782 L F
.279 .249 .645 r
.25738 .60099 m .25934 .60296 L .25883 .60038 L F
.432 .265 .554 r
.25738 .60099 m .25732 .6036 L .25934 .60296 L F
0 .235 .753 r
.53801 .5681 m .53935 .56936 L .53983 .57084 L F
.93 .681 .198 r
.53935 .56936 m .54013 .57336 L .53983 .57084 L F
.46 .165 .377 r
.23616 .62423 m .23902 .62191 L .23677 .62222 L F
.537 .064 .079 r
.44829 .6401 m .44677 .64175 L .44426 .64036 L F
.526 .052 .072 r
.4504 .64134 m .44829 .6401 L .45119 .64012 L F
.4504 .64134 m .44677 .64175 L .44829 .6401 L F
.704 .724 .866 r
.6559 .44234 m .65702 .44433 L .65946 .44314 L F
.48 .751 .989 r
.47945 .56707 m .48052 .56545 L .47901 .56587 L F
.47945 .56707 m .48169 .56681 L .48052 .56545 L F
.255 0 0 r
.17119 .56982 m .16708 .57203 L .16896 .57034 L F
.664 .516 .674 r
.66935 .4124 m .67124 .41126 L .67151 .40811 L F
.614 .374 .531 r
.4406 .62176 m .44301 .62182 L .44351 .61923 L F
.629 .388 .535 r
.44351 .61923 m .44654 .62133 L .44614 .61883 L F
.44351 .61923 m .44301 .62182 L .44654 .62133 L F
.803 .823 .868 r
.66185 .43795 m .65825 .43774 L .66108 .43749 L F
.604 .953 .863 r
.66185 .43795 m .66359 .43624 L .66396 .4365 L F
.601 .934 .955 r
.66185 .43795 m .66108 .43749 L .66359 .43624 L F
.987 .855 .484 r
.77243 .40591 m .77362 .40477 L .77259 .40349 L F
.77243 .40591 m .77307 .40716 L .77362 .40477 L F
.396 .716 .987 r
.77362 .40477 m .77612 .40466 L .77259 .40349 L F
.803 .743 .797 r
.66875 .41357 m .66533 .4131 L .66746 .41069 L F
.905 .755 .685 r
.66875 .41357 m .66558 .41542 L .66533 .4131 L F
.66875 .41357 m .66725 .41649 L .66558 .41542 L F
.664 .516 .674 r
.66935 .4124 m .66791 .40754 L .66746 .41069 L F
.637 .934 .682 r
.6705 .41139 m .66875 .41357 L .66746 .41069 L F
.158 .378 .828 r
.77049 .43506 m .77192 .43798 L .77282 .43674 L F
.168 .391 .836 r
.77192 .43798 m .77486 .4397 L .77282 .43674 L F
.67 .611 .78 r
.48338 .58869 m .48463 .59142 L .48687 .58881 L F
.523 .387 .637 r
.48117 .59375 m .47855 .59188 L .48113 .59149 L F
.48117 .59375 m .47883 .59435 L .47855 .59188 L F
.48117 .59375 m .47855 .59188 L .48113 .59149 L F
.48117 .59375 m .47883 .59435 L .47855 .59188 L F
.47 .811 .999 r
.17879 .6465 m .18257 .64689 L .18089 .64549 L F
.619 .782 .959 r
.18089 .64549 m .18257 .64689 L .18468 .64614 L F
.517 .897 .959 r
.22265 .62988 m .21924 .63049 L .22141 .62992 L F
.221 .738 .726 r
.22369 .62952 m .22265 .62988 L .22141 .62992 L F
.628 .07 0 r
.5074 .55318 m .50703 .55373 L .50469 .55153 L F
.48 0 0 r
.5074 .55318 m .51004 .55458 L .50703 .55373 L F
.394 0 0 r
.51183 .55532 m .51004 .55458 L .5074 .55318 L F
.347 .144 .455 r
.45194 .61003 m .45261 .61192 L .45402 .60988 L F
.45194 .61003 m .45071 .61282 L .45261 .61192 L F
.389 .431 .784 r
.22654 .66618 m .22568 .6675 L .22873 .66816 L F
.431 .705 .98 r
.20935 .62996 m .20728 .63013 L .20521 .62843 L F
0 .277 .78 r
.40462 .62852 m .40526 .62785 L .40367 .62703 L F
.40462 .62852 m .40703 .63031 L .40526 .62785 L F
.852 .43 0 r
.50713 .57826 m .50716 .57665 L .50563 .57567 L F
.50713 .57826 m .50807 .57907 L .50716 .57665 L F
.68 .267 .255 r
.49132 .53705 m .49369 .53912 L .49506 .53716 L F
0 0 0 r
.49506 .53716 m .49617 .53712 L .49757 .53694 L F
.49506 .53716 m .49369 .53912 L .49617 .53712 L F
.619 .665 .872 r
.16644 .61544 m .16174 .61281 L .16344 .61233 L F
.318 .519 .894 r
.16707 .6137 m .16644 .61544 L .16344 .61233 L F
.16707 .6137 m .1681 .61548 L .16644 .61544 L F
.538 .567 .832 r
.42322 .61166 m .42416 .6089 L .42215 .60983 L F
.42322 .61166 m .42543 .61167 L .42416 .6089 L F
.7 .597 .737 r
.4466 .60394 m .44274 .60107 L .44515 .60043 L F
.673 .493 .634 r
.4466 .60394 m .44686 .60684 L .44498 .60634 L F
.577 .589 .828 r
.44932 .60319 m .4466 .60394 L .44515 .60043 L F
0 .429 .723 r
.19113 .6455 m .19473 .64657 L .19313 .64604 L F
.365 .731 .989 r
.19473 .64657 m .19518 .64525 L .19313 .64604 L F
.19473 .64657 m .19739 .6466 L .19518 .64525 L F
.861 .877 .849 r
.40548 .60857 m .40707 .61002 L .40957 .60698 L F
.695 .152 0 r
.40726 .61122 m .40707 .61002 L .40548 .60857 L F
.40726 .61122 m .40919 .61214 L .40707 .61002 L F
.486 .574 .869 r
.77666 .43433 m .77463 .43456 L .773 .43152 L F
.781 .705 .779 r
.71371 .41442 m .71594 .4131 L .7146 .40974 L F
.75 .69 .794 r
.7146 .40974 m .71594 .4131 L .71838 .4104 L F
.537 .366 .597 r
.30021 .55502 m .29778 .55825 L .2977 .5556 L F
0 0 0 r
.84285 .419 m .84097 .42293 L .83992 .41951 L F
.84285 .419 m .84217 .42084 L .84097 .42293 L F
.895 .948 .595 r
.84217 .42084 m .84077 .42522 L .84097 .42293 L F
.256 .536 .92 r
.28137 .54196 m .28308 .54219 L .28253 .54369 L F
.339 .632 .96 r
.28308 .54219 m .28458 .54375 L .28253 .54369 L F
.8 .373 0 r
.51101 .5846 m .51203 .5857 L .51001 .58258 L F
.8 .379 0 r
.51101 .5846 m .51316 .58826 L .51203 .5857 L F
.866 .706 .682 r
.75793 .37606 m .76128 .37601 L .76117 .37454 L F
.553 .338 .543 r
.21175 .70919 m .21469 .7091 L .21455 .70658 L F
0 0 0 r
.23616 .62423 m .23453 .62543 L .23258 .6272 L F
.914 .628 .488 r
.42682 .63699 m .42931 .63717 L .43048 .63643 L F
.42682 .63699 m .42864 .63896 L .42931 .63717 L F
.797 .655 .706 r
.42864 .63896 m .43048 .63643 L .42931 .63717 L F
.69 .849 .43 r
.76249 .38077 m .76056 .38415 L .76162 .38198 L F
.25 0 0 r
.76409 .38159 m .76249 .38077 L .76162 .38198 L F
.76409 .38159 m .76458 .38062 L .76249 .38077 L F
.722 .504 .594 r
.43788 .59457 m .44148 .59742 L .44148 .59492 L F
.685 .511 .645 r
.45273 .62552 m .4521 .62805 L .44846 .62809 L F
.642 .468 .633 r
.45423 .62502 m .4521 .62805 L .45273 .62552 L F
.537 .923 .906 r
.55433 .60909 m .5529 .6089 L .55088 .60994 L F
.136 0 0 r
.55433 .60909 m .55423 .60909 L .5529 .6089 L F
.636 .801 .364 r
.53751 .51908 m .53677 .52034 L .53562 .52247 L F
.181 0 0 r
.53801 .52096 m .53581 .52196 L .53677 .52034 L F
.757 .992 .878 r
.53562 .52247 m .53677 .52034 L .53491 .52205 L F
.181 0 0 r
.53581 .52196 m .53538 .52216 L .53677 .52034 L F
.636 .801 .364 r
.53753 .51904 m .53677 .52034 L .53751 .51908 L F
.802 .998 .849 r
.53562 .52247 m .53203 .52465 L .53362 .52595 L F
.53562 .52247 m .53491 .52205 L .53203 .52465 L F
.746 .588 .68 r
.59305 .5012 m .59126 .50165 L .59098 .50386 L F
0 0 0 r
.58297 .56693 m .58255 .57022 L .58244 .56783 L F
.666 .692 .865 r
.83229 .41544 m .83334 .41738 L .82974 .41637 L F
.54 .546 .81 r
.83461 .41288 m .83334 .41738 L .83229 .41544 L F
.83461 .41288 m .83605 .41695 L .83334 .41738 L F
.305 0 0 r
.18172 .56565 m .18056 .56517 L .18191 .5645 L F
.18172 .56565 m .17862 .56685 L .18056 .56517 L F
.788 .728 .797 r
.43096 .65172 m .42642 .65708 L .42885 .6519 L F
.578 .596 .835 r
.7436 .40983 m .7441 .41154 L .74619 .40912 L F
.569 .582 .827 r
.7441 .41154 m .7468 .41249 L .74619 .40912 L F
.433 .184 .435 r
.46851 .61876 m .4709 .61819 L .47129 .61589 L F
.425 .119 .341 r
.4709 .61819 m .47379 .61562 L .47129 .61589 L F
.707 .33 .334 r
.42141 .66134 m .42166 .66412 L .41944 .66319 L F
.41944 .66319 m .42166 .66412 L .42141 .66134 L F
.41944 .66319 m .42141 .66134 L .42098 .66259 L F
.793 .779 .275 r
.42098 .66259 m .42141 .66134 L .42214 .65805 L F
.931 .951 .776 r
.4799 .61808 m .47778 .6215 L .47872 .62207 L F
.988 .721 .364 r
.47778 .6215 m .4789 .62469 L .47872 .62207 L F
.995 .813 .45 r
.51818 .59951 m .51891 .60373 L .51867 .60092 L F
.688 .653 .81 r
.82296 .44333 m .82335 .44572 L .82687 .44429 L F
.685 .719 .875 r
.18963 .62216 m .18601 .6214 L .18784 .62119 L F
.547 .829 .998 r
.19192 .62157 m .18963 .62216 L .18784 .62119 L F
0 0 0 r
.48557 .61242 m .48826 .60948 L .4871 .61119 L F
0 0 .061 r
.48988 .60867 m .48826 .60948 L .49074 .60615 L F
0 0 0 r
.4871 .61119 m .48826 .60948 L .48988 .60867 L F
.397 .027 .215 r
.54888 .50287 m .55195 .50035 L .5498 .50069 L F
.618 .065 0 r
.51566 .60421 m .51477 .60513 L .51222 .60328 L F
0 .185 .63 r
.51566 .60421 m .51698 .60496 L .51477 .60513 L F
.559 .298 .477 r
.51891 .60373 m .51831 .60597 L .51566 .60421 L F
.768 .461 0 r
.51691 .60477 m .51698 .60496 L .51671 .6033 L F
.564 .409 .63 r
.51767 .6075 m .51477 .60513 L .51698 .60496 L F
.768 .461 0 r
.51711 .60622 m .51698 .60496 L .51691 .60477 L F
0 .185 .63 r
.51566 .60421 m .51704 .60513 L .51698 .60496 L F
.51704 .60513 m .51831 .60597 L .51698 .60496 L F
.419 .556 .886 r
.76748 .43325 m .76809 .43526 L .76966 .43326 L F
.477 .641 .928 r
.76966 .43326 m .76809 .43526 L .77049 .43506 L F
.333 .118 .431 r
.26703 .55863 m .26676 .56091 L .2689 .55791 L F
.369 0 .089 r
.22065 .67609 m .2162 .67872 L .21755 .67829 L F
.649 .112 0 r
.22057 .67876 m .22065 .67609 L .22215 .67572 L F
.04 0 0 r
.22215 .67572 m .22065 .67609 L .21755 .67829 L F
.505 .311 .551 r
.42517 .67957 m .42759 .6815 L .42766 .67892 L F
0 .235 .745 r
.49618 .5664 m .49604 .56701 L .49413 .56446 L F
.592 .949 .872 r
.75531 .39007 m .75165 .39153 L .75425 .39114 L F
.767 .926 .939 r
.75727 .38882 m .75531 .39007 L .75643 .3875 L F
.772 .914 .532 r
.75643 .3875 m .75531 .39007 L .75425 .39114 L F
0 0 .337 r
.54087 .58445 m .53991 .58869 L .54105 .58625 L F
.766 .725 .815 r
.47818 .56163 m .47431 .56115 L .47713 .55956 L F
.782 .685 .756 r
.47818 .56163 m .47572 .56486 L .47431 .56115 L F
.542 .655 .908 r
.47941 .55925 m .47818 .56163 L .47713 .55956 L F
.51 .335 .58 r
.47818 .56163 m .48086 .56121 L .48052 .55849 L F
.542 .655 .908 r
.47941 .55925 m .48086 .56121 L .47818 .56163 L F
.711 .423 .485 r
.47675 .56307 m .48086 .56121 L .47818 .56163 L F
.47675 .56307 m .48037 .5644 L .48086 .56121 L F
.656 .836 .969 r
.48107 .56519 m .48409 .56547 L .48344 .56406 L F
.269 .775 .835 r
.47901 .56587 m .4812 .56535 L .47675 .56307 L F
.656 .836 .969 r
.4813 .56546 m .48409 .56547 L .48107 .56519 L F
.269 .775 .835 r
.48062 .56505 m .48037 .5644 L .47675 .56307 L F
.4812 .56535 m .48095 .56506 L .48062 .56505 L F
.48095 .56506 m .48037 .5644 L .48062 .56505 L F
.656 .836 .969 r
.48052 .56545 m .48133 .56507 L .48095 .56506 L F
.48251 .5645 m .48344 .56406 L .48265 .56415 L F
.711 .423 .485 r
.48184 .56423 m .48229 .5651 L .48196 .56422 L F
.561 .364 .571 r
.48229 .5651 m .48095 .56506 L .48184 .56423 L F
.711 .423 .485 r
.48037 .5644 m .48229 .5651 L .48184 .56423 L F
.656 .836 .969 r
.48184 .56423 m .48344 .56406 L .48302 .56315 L F
.561 .364 .571 r
.48229 .5651 m .48184 .56423 L .48302 .56315 L F
.269 .775 .835 r
.48095 .56506 m .48229 .5651 L .48037 .5644 L F
.4812 .56535 m .48229 .5651 L .48095 .56506 L F
.656 .836 .969 r
.48052 .56545 m .4812 .56535 L .48107 .56519 L F
.561 .364 .571 r
.48229 .5651 m .48052 .56545 L .48095 .56506 L F
.269 .775 .835 r
.4812 .56535 m .48052 .56545 L .48229 .5651 L F
.47901 .56587 m .48052 .56545 L .4812 .56535 L F
.656 .836 .969 r
.48052 .56545 m .4813 .56546 L .4812 .56535 L F
.711 .423 .485 r
.48037 .5644 m .48196 .56422 L .48086 .56121 L F
.225 0 0 r
.47818 .56163 m .48001 .56227 L .48086 .56121 L F
.47818 .56163 m .47675 .56307 L .48001 .56227 L F
.911 .775 .698 r
.57536 .53153 m .57219 .53336 L .5734 .53044 L F
.57536 .53153 m .57469 .53402 L .57219 .53336 L F
.883 .855 .401 r
.59029 .51343 m .59117 .51053 L .59113 .50898 L F
0 0 0 r
.58416 .56035 m .58458 .55869 L .58496 .55678 L F
.58416 .56035 m .58389 .56098 L .58458 .55869 L F
.573 .609 .85 r
.21586 .68213 m .21916 .6835 L .21725 .68319 L F
0 .168 .695 r
.21586 .68213 m .21725 .68319 L .21558 .68097 L F
.981 .896 .555 r
.67091 .41727 m .66978 .41837 L .66871 .4171 L F
.68 .753 .906 r
.15219 .59471 m .14903 .59488 L .14981 .59403 L F
.376 .78 .984 r
.14981 .59403 m .15032 .59396 L .15219 .59471 L F
.68 .753 .906 r
.15219 .59471 m .14903 .59488 L .14981 .59403 L F
.133 0 0 r
.15032 .59396 m .15445 .59448 L .15219 .59471 L F
.314 .509 .888 r
.76007 .4297 m .76273 .4291 L .75962 .42787 L F
.76007 .4297 m .76331 .43094 L .76273 .4291 L F
.259 .299 .714 r
.41345 .62507 m .41499 .62466 L .41414 .62128 L F
.494 .406 .685 r
.41499 .62466 m .41341 .62776 L .41345 .62507 L F
.41341 .62776 m .41499 .62466 L .41345 .62507 L F
.447 .831 .987 r
.24098 .53726 m .2404 .53834 L .23875 .53763 L F
.24098 .53726 m .24262 .53788 L .2404 .53834 L F
0 0 .156 r
.41466 .6552 m .41488 .65392 L .41473 .65135 L F
0 .11 .662 r
.41466 .6552 m .41655 .65754 L .41488 .65392 L F
.744 .551 .634 r
.43048 .63643 m .43454 .63425 L .43154 .63411 L F
.43048 .63643 m .43454 .63686 L .43454 .63425 L F
.674 .494 .634 r
.43454 .63425 m .43454 .63686 L .43756 .63398 L F
0 .091 .649 r
.53112 .5537 m .52983 .55331 L .52863 .55237 L F
.53112 .5537 m .53153 .55536 L .52983 .55331 L F
.919 .946 .8 r
.76056 .38415 m .75847 .38721 L .75847 .38414 L F
.767 .983 .906 r
.76162 .38198 m .76056 .38415 L .75847 .38414 L F
.255 0 0 r
.26299 .55637 m .26587 .55628 L .26266 .55649 L F
.26299 .55637 m .26542 .55617 L .26587 .55628 L F
.473 .171 .373 r
.46548 .62219 m .46712 .62227 L .46851 .61876 L F
.418 .118 .347 r
.46851 .61876 m .47112 .62021 L .4709 .61819 L F
.46851 .61876 m .46712 .62227 L .47112 .62021 L F
.562 .228 .36 r
.43261 .62141 m .43077 .62439 L .42859 .62279 L F
0 0 .429 r
.43138 .61851 m .43283 .62143 L .43261 .62141 L F
.864 .605 .546 r
.43261 .62141 m .43471 .62602 L .43077 .62439 L F
.809 .588 .604 r
.43537 .62515 m .43471 .62602 L .43261 .62141 L F
0 0 0 r
.53854 .51216 m .54174 .50981 L .53932 .51048 L F
.406 .645 .954 r
.14823 .59402 m .14981 .59403 L .14903 .59488 L F
0 0 0 r
.54084 .51706 m .5395 .51828 L .53753 .51904 L F
.2 0 0 r
.54231 .51735 m .54084 .51706 L .54322 .51629 L F
.54231 .51735 m .5395 .51828 L .54084 .51706 L F
.327 .178 .52 r
.2523 .60696 m .25393 .60872 L .25467 .60649 L F
.2523 .60696 m .25218 .60955 L .25393 .60872 L F
.798 .624 .665 r
.7705 .41927 m .7717 .42111 L .77363 .41981 L F
.434 .194 .449 r
.27119 .63022 m .26946 .62807 L .27169 .62769 L F
.27119 .63022 m .26902 .63082 L .26946 .62807 L F
.078 .351 .823 r
.2241 .55321 m .22483 .55158 L .22283 .55134 L F
.2241 .55321 m .22648 .55445 L .22483 .55158 L F
.107 .364 .828 r
.73213 .39196 m .7322 .39351 L .73214 .39348 L F
.149 .37 .824 r
.72934 .39168 m .7322 .39351 L .73137 .39263 L F
.438 .485 .811 r
.73137 .39263 m .73128 .39263 L .72934 .39168 L F
.107 .364 .828 r
.73011 .39176 m .73093 .39246 L .72934 .39168 L F
.73093 .39246 m .73214 .39348 L .72934 .39168 L F
.438 .485 .811 r
.73128 .39263 m .72687 .39227 L .72934 .39168 L F
.107 .364 .828 r
.73133 .39267 m .73214 .39348 L .73011 .39176 L F
.395 .414 .762 r
.73133 .39267 m .73075 .39728 L .72798 .39575 L F
.73137 .39263 m .73136 .3927 L .73133 .39267 L F
.73136 .3927 m .73075 .39728 L .73133 .39267 L F
.107 .364 .828 r
.73044 .39179 m .73133 .39267 L .73011 .39176 L F
.438 .485 .811 r
.73137 .39263 m .73133 .39267 L .73128 .39263 L F
.107 .364 .828 r
.73213 .39196 m .73214 .39348 L .73044 .39179 L F
.438 .485 .811 r
.73128 .39263 m .72798 .39575 L .72687 .39227 L F
.73133 .39267 m .72798 .39575 L .73128 .39263 L F
.797 .377 .25 r
.43558 .62676 m .43471 .62602 L .43537 .62515 L F
.606 .465 .663 r
.43774 .62469 m .43558 .62676 L .43537 .62515 L F
.382 .674 .974 r
.80334 .39817 m .80064 .39931 L .79991 .39771 L F
.80334 .39817 m .80432 .39961 L .80064 .39931 L F
.559 .674 .916 r
.73381 .40671 m .73454 .40313 L .732 .40386 L F
.73381 .40671 m .73667 .40628 L .73454 .40313 L F
.568 .67 .907 r
.73381 .40671 m .7369 .40767 L .73667 .40628 L F
.848 .812 .815 r
.79255 .40435 m .79198 .4064 L .79012 .40748 L F
.676 .49 .626 r
.48338 .58869 m .48687 .58881 L .48649 .586 L F
.567 .413 .631 r
.48649 .586 m .48933 .58823 L .48873 .58563 L F
.48649 .586 m .48687 .58881 L .48933 .58823 L F
.48933 .58823 m .48687 .58881 L .48649 .586 L F
.94 .621 .175 r
.47572 .56486 m .47485 .56418 L .47431 .56115 L F
.38 .564 .908 r
.47572 .56486 m .47675 .56307 L .47485 .56418 L F
.47572 .56486 m .47901 .56587 L .47675 .56307 L F
0 0 .558 r
.15445 .59448 m .15608 .59666 L .15612 .59788 L F
.402 .261 .572 r
.15612 .59788 m .15797 .59953 L .15602 .59953 L F
.475 .749 .989 r
.17763 .63953 m .17783 .63774 L .17442 .63701 L F
.17763 .63953 m .18018 .63914 L .17783 .63774 L F
.621 .333 .459 r
.43866 .56769 m .44003 .57048 L .44091 .56986 L F
.56 .306 .487 r
.41544 .59175 m .41873 .59159 L .41875 .5894 L F
.188 .022 .411 r
.41875 .5894 m .41873 .59159 L .42035 .58836 L F
.545 .543 .803 r
.80113 .41398 m .80251 .4098 L .80006 .41029 L F
.80113 .41398 m .80363 .41334 L .80251 .4098 L F
.535 .494 .757 r
.80444 .41928 m .80363 .41334 L .80113 .41398 L F
.861 .876 .848 r
.50126 .52739 m .505 .52636 L .50344 .52436 L F
.50126 .52739 m .50269 .52876 L .505 .52636 L F
.585 .743 .951 r
.50344 .52436 m .505 .52636 L .50749 .52558 L F
.268 .173 .558 r
.4625 .61438 m .45947 .61623 L .46064 .61264 L F
.268 0 .284 r
.4625 .61603 m .45947 .61623 L .4625 .61438 L F
.46165 .61678 m .45947 .61623 L .4625 .61603 L F
.268 .173 .558 r
.4625 .61438 m .46064 .61264 L .46261 .61195 L F
.47 .213 .441 r
.46517 .60922 m .46261 .61195 L .46311 .60986 L F
.46517 .60922 m .465 .61143 L .46261 .61195 L F
.5 .289 .525 r
.465 .61143 m .4625 .61438 L .46261 .61195 L F
.241 0 .289 r
.46428 .61367 m .46419 .6137 L .465 .61143 L F
.46419 .6137 m .4625 .61438 L .4635 .6132 L F
.46419 .6137 m .4635 .6132 L .465 .61143 L F
.155 0 .248 r
.46652 .61244 m .465 .61143 L .46738 .61094 L F
.46652 .61244 m .46428 .61367 L .465 .61143 L F
.013 0 0 r
.46823 .61132 m .46652 .61244 L .46738 .61094 L F
.65 .678 .863 r
.4647 .61412 m .46473 .61416 L .46652 .61244 L F
.658 .543 .712 r
.46652 .61244 m .4643 .61593 L .46429 .61451 L F
.213 .091 .487 r
.46429 .61448 m .4625 .61438 L .46428 .61367 L F
.459 .34 .63 r
.46411 .6146 m .46334 .61523 L .46414 .61464 L F
.213 .091 .487 r
.46338 .61514 m .46329 .61531 L .4625 .61438 L F
.46329 .61531 m .4625 .617 L .4625 .61603 L F
.46329 .61531 m .4625 .61603 L .4625 .61438 L F
.46338 .61514 m .4625 .61438 L .46429 .61448 L F
.459 .34 .63 r
.4617 .6109 m .46171 .61635 L .46411 .6146 L F
.46171 .61635 m .46171 .61657 L .46411 .6146 L F
.658 .543 .712 r
.46467 .61408 m .46428 .61378 L .46428 .61367 L F
.46466 .61408 m .46428 .61378 L .46467 .61408 L F
.459 .34 .63 r
.46466 .61408 m .46414 .61464 L .46473 .61416 L F
.46466 .61408 m .46473 .61416 L .4647 .61412 L F
.658 .543 .712 r
.4647 .61412 m .46429 .61451 L .46428 .61378 L F
.459 .34 .63 r
.4617 .6109 m .46414 .61464 L .46466 .61408 L F
.457 .859 .967 r
.46171 .61657 m .46243 .61486 L .46449 .61423 L F
.46419 .6145 m .46449 .61423 L .46453 .61422 L F
.459 .34 .63 r
.46334 .61523 m .46333 .61528 L .46414 .61464 L F
.213 .091 .487 r
.46343 .61519 m .46338 .61514 L .46429 .61451 L F
.457 .859 .967 r
.46171 .61657 m .46449 .61423 L .46419 .6145 L F
.459 .34 .63 r
.46334 .61523 m .46171 .61657 L .46333 .61528 L F
.213 .091 .487 r
.4643 .61593 m .46279 .61682 L .46338 .61514 L F
.46279 .61682 m .4625 .617 L .46338 .61514 L F
.457 .859 .967 r
.46343 .6152 m .46354 .6151 L .46473 .61416 L F
.213 .091 .487 r
.46429 .61451 m .46338 .61514 L .46429 .61448 L F
.457 .859 .967 r
.46354 .6151 m .46453 .61422 L .46473 .61416 L F
.46354 .6151 m .46473 .61416 L .46473 .61416 L F
.213 .091 .487 r
.4643 .61593 m .46343 .61519 L .46429 .61451 L F
.658 .543 .712 r
.4647 .61412 m .46466 .61408 L .46467 .61408 L F
.459 .34 .63 r
.46457 .61399 m .46466 .61408 L .46467 .61406 L F
.658 .543 .712 r
.46652 .61244 m .4647 .61412 L .46428 .61367 L F
.459 .34 .63 r
.46466 .61408 m .4647 .61412 L .46467 .61406 L F
.65 .678 .863 r
.46451 .61382 m .4647 .61412 L .46652 .61244 L F
.46297 .61146 m .46451 .61382 L .46652 .61244 L F
.437 .149 .375 r
.46762 .60781 m .465 .61143 L .46517 .60922 L F
.46762 .60781 m .46738 .61094 L .465 .61143 L F
.323 .059 .35 r
.4695 .60995 m .46738 .61094 L .46762 .60781 L F
.65 .678 .863 r
.46297 .61146 m .46652 .61244 L .46848 .61047 L F
.208 0 0 r
.46477 .61307 m .46792 .61147 L .46652 .61244 L F
.013 0 0 r
.46823 .61132 m .46738 .61094 L .4695 .60995 L F
.13 0 .047 r
.46848 .61047 m .46652 .61244 L .46823 .61132 L F
.208 0 0 r
.46792 .61147 m .46823 .61132 L .46652 .61244 L F
.46408 .61331 m .4648 .61297 L .46477 .61307 L F
.4648 .61297 m .46823 .61132 L .46477 .61307 L F
.459 .34 .63 r
.4617 .6109 m .46448 .61389 L .46297 .61146 L F
.46448 .61389 m .46457 .61399 L .46449 .61386 L F
.46448 .61389 m .46449 .61386 L .46297 .61146 L F
.46457 .61399 m .46467 .61406 L .46297 .61146 L F
.457 .859 .967 r
.46171 .61657 m .46453 .61422 L .46343 .6152 L F
.268 0 .284 r
.4625 .617 m .46165 .61678 L .4625 .61603 L F
.4625 .617 m .46044 .61801 L .45947 .61623 L F
.235 .355 .782 r
.1941 .62298 m .19331 .62513 L .19192 .62157 L F
.462 .615 .915 r
.1941 .62298 m .19513 .62497 L .19331 .62513 L F
.047 0 0 r
.42791 .65179 m .42613 .65324 L .42791 .6524 L F
.42787 .64946 m .42639 .65267 L .42791 .65179 L F
.42639 .65267 m .42613 .65324 L .42791 .65179 L F
.42787 .64946 m .42791 .6524 L .42774 .64969 L F
.647 .678 .866 r
.43373 .65109 m .43096 .65172 L .42928 .64857 L F
.698 .482 .592 r
.42774 .64969 m .42924 .65102 L .43007 .64937 L F
.42924 .65102 m .43033 .65197 L .43018 .65047 L F
.42924 .65102 m .43018 .65047 L .43007 .64937 L F
.921 .95 .795 r
.75847 .38721 m .75643 .3875 L .75847 .38414 L F
.75847 .38721 m .75727 .38882 L .75643 .3875 L F
.521 .325 .555 r
.26128 .59159 m .26358 .59133 L .26371 .58865 L F
.517 .38 .633 r
.26128 .59159 m .26385 .59386 L .26358 .59133 L F
.26128 .59159 m .26163 .59447 L .26385 .59386 L F
.436 .004 .119 r
.47255 .62443 m .46882 .62674 L .47045 .62792 L F
.47255 .62443 m .47167 .62776 L .46882 .62674 L F
0 0 0 r
.47352 .62516 m .47255 .62443 L .47489 .62371 L F
.209 .328 .766 r
.47425 .62646 m .47294 .62811 L .4727 .62664 L F
.47325 .62616 m .4727 .62664 L .47259 .62596 L F
.47425 .62646 m .4727 .62664 L .47325 .62616 L F
0 0 0 r
.47352 .62516 m .47208 .62719 L .47255 .62443 L F
.47208 .62719 m .47167 .62776 L .47175 .62748 L F
.47208 .62719 m .47175 .62748 L .47255 .62443 L F
.315 0 .223 r
.45502 .63569 m .4534 .63455 L .45533 .63332 L F
.45502 .63569 m .45239 .63649 L .4534 .63455 L F
.94 .574 .264 r
.49142 .54366 m .49037 .54497 L .48951 .54244 L F
.49142 .54366 m .49217 .54642 L .49037 .54497 L F
.194 .67 .934 r
.5098 .54171 m .51431 .54286 L .51133 .5404 L F
.078 0 .232 r
.2596 .59782 m .26056 .59897 L .26119 .59678 L F
.2596 .59782 m .25883 .60038 L .26056 .59897 L F
.174 0 0 r
.26587 .55628 m .26137 .55761 L .26266 .55649 L F
.507 .341 .59 r
.243 .66067 m .24124 .65867 L .24333 .65793 L F
.243 .66067 m .24097 .6614 L .24124 .65867 L F
.722 .504 .594 r
.43788 .59457 m .43834 .59739 L .44148 .59742 L F
.5 .362 .625 r
.28699 .60966 m .28711 .61231 L .28499 .61284 L F
.564 .324 .511 r
.28711 .61231 m .28432 .61513 L .28499 .61284 L F
0 0 0 r
.48284 .61553 m .4799 .61808 L .48177 .61592 L F
.558 .765 .974 r
.43922 .63379 m .4398 .63429 L .43852 .63412 L F
.949 .599 .3 r
.43922 .63379 m .44074 .63682 L .4398 .63429 L F
.43922 .63379 m .44074 .63682 L .4398 .63429 L F
.767 .821 .895 r
.44118 .63212 m .4398 .63429 L .43922 .63379 L F
.683 .525 .666 r
.43856 .63519 m .4401 .63338 L .43922 .63379 L F
.4401 .63338 m .44118 .63212 L .43922 .63379 L F
.558 .765 .974 r
.43922 .63379 m .43852 .63412 L .43756 .63398 L F
.343 0 0 r
.18017 .54748 m .18464 .54612 L .18254 .54687 L F
.526 .231 .409 r
.43587 .59816 m .43803 .59958 L .43834 .59739 L F
.43587 .59816 m .4353 .60015 L .43803 .59958 L F
.987 .776 .531 r
.50269 .52876 m .50099 .52992 L .50126 .52739 L F
.50126 .52739 m .50099 .52992 L .50269 .52876 L F
.742 .809 .905 r
.18178 .62121 m .18601 .6214 L .18364 .62271 L F
.735 .63 .742 r
.705 .41969 m .70874 .42033 L .70749 .41671 L F
.569 .355 .551 r
.46709 .58264 m .46955 .58487 L .47017 .5823 L F
.46709 .58264 m .46702 .5853 L .46955 .58487 L F
.104 0 .178 r
.40021 .61254 m .40302 .60917 L .40063 .60992 L F
.981 .693 .337 r
.56174 .58597 m .56272 .58885 L .56113 .58734 L F
.994 .75 .437 r
.56255 .59123 m .56113 .58734 L .56272 .58885 L F
.819 .552 .534 r
.66277 .4065 m .66563 .40448 L .66265 .40415 L F
.66277 .4065 m .66607 .40741 L .66563 .40448 L F
.708 .672 .813 r
.45158 .63049 m .44917 .63285 L .44876 .63047 L F
.326 .104 .415 r
.16518 .57305 m .16284 .57635 L .16332 .57376 L F
.505 .086 .178 r
.44091 .56986 m .44355 .57001 L .44493 .56792 L F
.349 0 .089 r
.44493 .56792 m .44643 .56877 L .44727 .56728 L F
.44493 .56792 m .44355 .57001 L .44643 .56877 L F
.699 .479 .586 r
.70351 .41312 m .70618 .41321 L .7061 .41073 L F
.713 .587 .713 r
.70618 .41321 m .70866 .4101 L .7061 .41073 L F
.583 .692 .917 r
.7417 .40099 m .73807 .39927 L .74064 .3985 L F
.663 .714 .886 r
.7441 .39977 m .7417 .40099 L .74064 .3985 L F
.786 .822 .881 r
.25439 .55254 m .2591 .55256 L .25743 .5515 L F
.887 .991 .765 r
.2591 .55256 m .25591 .55594 L .25743 .5515 L F
.2591 .55256 m .25596 .55621 L .25591 .55594 L F
.478 .611 .904 r
.73667 .40628 m .7369 .40767 L .73937 .40738 L F
.235 0 0 r
.24502 .53776 m .24886 .53809 L .2467 .53852 L F
.797 .949 .92 r
.47052 .56068 m .47326 .5571 L .47091 .55747 L F
.349 .819 .756 r
.68619 .43419 m .68556 .43432 L .68315 .43531 L F
.394 .846 .767 r
.68783 .43327 m .68619 .43419 L .68803 .43357 L F
.68783 .43327 m .68556 .43432 L .68619 .43419 L F
.232 0 0 r
.50344 .52436 m .50585 .52378 L .50719 .52197 L F
.253 0 0 r
.18657 .56244 m .18506 .56201 L .18856 .56096 L F
.268 .768 .726 r
.19066 .56026 m .1897 .56048 L .18856 .56096 L F
0 0 0 r
.1897 .56048 m .18657 .56244 L .18856 .56096 L F
.519 .732 .971 r
.20709 .64703 m .21119 .64808 L .20911 .64666 L F
.284 .706 .97 r
.21119 .64808 m .21145 .64713 L .20911 .64666 L F
.21119 .64808 m .21298 .64803 L .21145 .64713 L F
0 .242 .668 r
.51949 .56386 m .51507 .56112 L .51789 .56236 L F
.662 .378 .479 r
.56413 .50721 m .56627 .50954 L .56435 .50931 L F
.007 .583 .72 r
.42292 .62034 m .42147 .62036 L .42431 .62083 L F
.42292 .62034 m .42158 .62032 L .42147 .62036 L F
.635 .754 .934 r
.73436 .39807 m .73205 .39906 L .73075 .39728 L F
.698 .746 .888 r
.209 .7001 m .21308 .70083 L .21303 .70019 L F
.962 .658 .404 r
.54035 .5758 m .54192 .57688 L .54013 .57336 L F
.707 .262 .191 r
.54061 .57835 m .54192 .57688 L .54035 .5758 L F
.54061 .57835 m .54386 .57885 L .54192 .57688 L F
.558 .427 .658 r
.45699 .59518 m .45976 .59485 L .45873 .59129 L F
.688 .531 .668 r
.45699 .59518 m .46058 .59735 L .45976 .59485 L F
.45699 .59518 m .45744 .59783 L .46058 .59735 L F
.46 .292 .566 r
.26371 .58865 m .26609 .58809 L .26609 .58534 L F
.463 .278 .543 r
.26371 .58865 m .26601 .59069 L .26609 .58809 L F
.26371 .58865 m .26358 .59133 L .26601 .59069 L F
.932 .896 .77 r
.76554 .40803 m .76249 .41 L .76471 .40687 L F
.76554 .40803 m .76367 .41121 L .76249 .41 L F
.951 .931 .743 r
.76554 .40803 m .76471 .40687 L .76658 .40341 L F
.48 .785 .998 r
.29293 .54566 m .29245 .54722 L .29064 .54571 L F
.29293 .54566 m .29428 .54674 L .29245 .54722 L F
.733 .56 .658 r
.57226 .49169 m .57604 .49214 L .57631 .4895 L F
.679 .51 .65 r
.2262 .67341 m .2265 .67651 L .22872 .67301 L F
0 .133 .68 r
.77547 .44153 m .77705 .4421 L .77486 .4397 L F
.77547 .44153 m .77816 .44412 L .77705 .4421 L F
.6 .575 .797 r
.80196 .43214 m .80301 .42709 L .80115 .42763 L F
.80196 .43214 m .80426 .43152 L .80301 .42709 L F
.484 .178 .372 r
.80174 .43381 m .80426 .43152 L .80196 .43214 L F
.585 .611 .844 r
.23228 .55872 m .23555 .56057 L .23417 .55791 L F
.711 .488 .586 r
.45158 .63049 m .44846 .62809 L .4521 .62805 L F
.45158 .63049 m .44876 .63047 L .44846 .62809 L F
.753 .677 .777 r
.83273 .42875 m .83647 .42972 L .83469 .42652 L F
.741 .723 .835 r
.83647 .42972 m .83757 .42786 L .83469 .42652 L F
.83647 .42972 m .83839 .42838 L .83757 .42786 L F
.11 .317 .79 r
.16856 .63048 m .17028 .63377 L .17075 .63221 L F
.111 .319 .791 r
.17075 .63221 m .17028 .63377 L .1716 .63401 L F
.143 .338 .799 r
.17028 .63377 m .17314 .63719 L .1716 .63401 L F
.882 .681 .626 r
.5885 .52884 m .58666 .5248 L .5874 .52545 L F
.893 .744 .69 r
.58625 .53025 m .5885 .52884 L .5874 .52545 L F
.58625 .53025 m .58784 .53138 L .5885 .52884 L F
.11 .125 .594 r
.56257 .6054 m .56451 .6068 L .56425 .60564 L F
.56257 .6054 m .56425 .60564 L .56168 .60602 L F
.136 .539 .921 r
.56168 .60602 m .56323 .60572 L .56313 .60573 L F
0 0 0 r
.56041 .60628 m .56257 .6054 L .56168 .60602 L F
.136 .539 .921 r
.56168 .60602 m .56313 .60573 L .56024 .60595 L F
0 0 0 r
.55992 .60648 m .56041 .60628 L .56168 .60602 L F
.56168 .60602 m .55727 .60798 L .55992 .60648 L F
.687 .682 .839 r
.7468 .41249 m .75044 .41332 L .74975 .41018 L F
.743 .751 .858 r
.74975 .41018 m .75044 .41332 L .75335 .41062 L F
.638 .634 .83 r
.45744 .59783 m .46059 .59975 L .46058 .59735 L F
.106 0 0 r
.46059 .59975 m .46431 .59818 L .46058 .59735 L F
.46059 .59975 m .46329 .59899 L .46431 .59818 L F
.46431 .59818 m .46329 .59899 L .46059 .59975 L F
.753 .667 .766 r
.70999 .41366 m .71371 .41442 L .712 .4125 L F
.781 .705 .779 r
.71371 .41442 m .7146 .40974 L .712 .4125 L F
.426 .508 .84 r
.48458 .60834 m .48556 .61167 L .48637 .60823 L F
0 0 .01 r
.48637 .60823 m .48556 .61167 L .48557 .61242 L F
.864 .444 .223 r
.51521 .55855 m .51333 .55803 L .51183 .55532 L F
.847 .408 .178 r
.51521 .55855 m .51436 .55975 L .51333 .55803 L F
.983 .775 .37 r
.51521 .55855 m .51507 .56112 L .51436 .55975 L F
.51521 .55855 m .51507 .56112 L .51436 .55975 L F
.471 .25 .497 r
.30018 .58287 m .29993 .58581 L .29773 .58615 L F
.398 .411 .757 r
.30099 .5788 m .30018 .58287 L .29928 .57868 L F
.30099 .5788 m .30185 .58256 L .30018 .58287 L F
.456 .238 .493 r
.30222 .58484 m .30018 .58287 L .30185 .58256 L F
.30222 .58484 m .29993 .58581 L .30018 .58287 L F
.625 .436 .606 r
.41042 .59743 m .41264 .59727 L .41307 .59411 L F
.533 .324 .542 r
.41307 .59411 m .41532 .59436 L .41544 .59175 L F
.533 .353 .583 r
.41307 .59411 m .41264 .59727 L .41532 .59436 L F
.852 .666 .65 r
.57534 .51637 m .57185 .51826 L .57318 .51529 L F
.57534 .51637 m .57481 .51886 L .57185 .51826 L F
.406 .815 .978 r
.25081 .55665 m .24871 .556 L .24624 .55659 L F
.394 .829 .954 r
.25305 .55595 m .24871 .556 L .25081 .55665 L F
.738 .918 .954 r
.45732 .6199 m .45576 .61944 L .45835 .6189 L F
.45732 .6199 m .45711 .62173 L .45576 .61944 L F
.673 .89 .977 r
.66148 .4419 m .66589 .44132 L .6649 .44041 L F
.801 .87 .431 r
.66708 .43774 m .66698 .43857 L .66542 .43761 L F
.66708 .43774 m .66704 .43786 L .66698 .43857 L F
.299 .673 .974 r
.66698 .43857 m .66974 .43791 L .66705 .43772 L F
.66698 .43857 m .66704 .43786 L .66542 .43761 L F
.875 .945 .857 r
.66704 .43786 m .6649 .44041 L .66589 .44132 L F
.66708 .43774 m .667 .43783 L .66704 .43786 L F
.667 .43783 m .6649 .44041 L .66704 .43786 L F
.83 .825 .843 r
.66338 .43875 m .6649 .44041 L .667 .43783 L F
.66692 .43778 m .667 .43783 L .66708 .43774 L F
.66338 .43875 m .667 .43783 L .66692 .43778 L F
.521 .531 .807 r
.66542 .43761 m .66707 .43586 L .66467 .43708 L F
.77 .511 .543 r
.66467 .43708 m .66647 .43757 L .66542 .43761 L F
.66647 .43757 m .66708 .43774 L .66542 .43761 L F
.521 .531 .807 r
.66542 .43761 m .66974 .43791 L .66918 .43748 L F
.77 .511 .543 r
.66467 .43708 m .66464 .43713 L .66649 .43759 L F
.66647 .43757 m .66649 .43759 L .66708 .43774 L F
.521 .531 .807 r
.66542 .43761 m .66647 .43757 L .66591 .43709 L F
.77 .511 .543 r
.66467 .43708 m .66649 .43759 L .66647 .43757 L F
.521 .531 .807 r
.66591 .43709 m .66918 .43748 L .66707 .43586 L F
.66647 .43757 m .66918 .43748 L .66591 .43709 L F
.299 .673 .974 r
.66704 .43786 m .66689 .43771 L .66542 .43761 L F
.77 .511 .543 r
.66464 .43713 m .66338 .43875 L .66692 .43778 L F
.66464 .43713 m .66692 .43778 L .66708 .43774 L F
.299 .673 .974 r
.66698 .4378 m .66705 .43772 L .66689 .43771 L F
.667 .43783 m .66701 .43781 L .66698 .4378 L F
.66701 .43781 m .66705 .43772 L .66698 .4378 L F
.66704 .43786 m .66704 .43785 L .667 .43783 L F
.66704 .43785 m .66705 .43772 L .667 .43783 L F
.801 .87 .431 r
.66704 .43786 m .66589 .44132 L .66698 .43857 L F
.405 .763 .994 r
.43826 .57364 m .43849 .57337 L .43618 .57328 L F
.75 .628 .724 r
.44039 .574 m .43618 .57328 L .43849 .57337 L F
.44039 .574 m .43675 .57818 L .43618 .57328 L F
.335 0 0 r
.43695 .57433 m .43849 .57337 L .43618 .57328 L F
.571 .896 .639 r
.43913 .5726 m .43849 .57337 L .43695 .57433 L F
0 0 .079 r
.44003 .57048 m .43849 .57337 L .43943 .57237 L F
.571 .896 .639 r
.43943 .57237 m .43849 .57337 L .43913 .5726 L F
.405 .763 .994 r
.44039 .574 m .43849 .57337 L .43826 .57364 L F
.509 .416 .685 r
.42223 .6371 m .42473 .63699 L .42408 .63317 L F
.396 .503 .85 r
.42223 .6371 m .42486 .63814 L .42473 .63699 L F
.935 .865 .746 r
.22089 .68092 m .22379 .67938 L .22057 .67876 L F
.22089 .68092 m .22199 .68327 L .22379 .67938 L F
.194 .001 .376 r
.22379 .67938 m .22199 .68327 L .22347 .68176 L F
.744 .411 .419 r
.68525 .4161 m .68759 .41863 L .68881 .41649 L F
.781 .536 .566 r
.68759 .41863 m .69131 .41655 L .68881 .41649 L F
.428 .758 .995 r
.78048 .45066 m .78241 .4492 L .78007 .44861 L F
.78048 .45066 m .78321 .45054 L .78241 .4492 L F
.471 .216 .446 r
.47434 .60111 m .47391 .60346 L .47145 .604 L F
.382 .139 .416 r
.47605 .60269 m .47434 .60111 L .47659 .60043 L F
.47605 .60269 m .47391 .60346 L .47434 .60111 L F
.553 .225 .367 r
.45261 .61192 m .456 .61157 L .45402 .60988 L F
.562 .222 .35 r
.45402 .60988 m .456 .61157 L .45692 .60996 L F
.409 .685 .975 r
.15872 .59316 m .1583 .59479 L .15644 .59301 L F
.809 .975 .678 r
.15872 .59316 m .15608 .59666 L .1583 .59479 L F
.756 .716 .814 r
.23417 .55791 m .23555 .56057 L .23865 .55862 L F
.578 .145 .183 r
.7489 .37744 m .75251 .37719 L .7516 .3789 L F
.474 0 0 r
.75251 .37719 m .75466 .37848 L .7516 .3789 L F
.75251 .37719 m .75523 .37753 L .75466 .37848 L F
.632 .514 .701 r
.75386 .37551 m .75523 .37753 L .75251 .37719 L F
.875 .699 .661 r
.81858 .44314 m .81793 .44344 L .82022 .44388 L F
.929 .887 .77 r
.81744 .44557 m .82022 .44388 L .81793 .44344 L F
.81744 .44557 m .81839 .44723 L .82022 .44388 L F
.632 .782 .954 r
.82022 .44388 m .82092 .44047 L .81858 .44314 L F
.82022 .44388 m .82296 .44333 L .82092 .44047 L F
.361 .678 .977 r
.27964 .5404 m .2787 .54179 L .27697 .5401 L F
.27964 .5404 m .28137 .54196 L .2787 .54179 L F
.764 .604 .681 r
.59098 .50386 m .59126 .50165 L .58736 .50096 L F
.635 .843 .98 r
.19947 .5577 m .20346 .55801 L .20174 .5568 L F
.582 .825 .99 r
.20174 .5568 m .20346 .55801 L .20591 .55713 L F
.861 .877 .849 r
.40548 .60857 m .40957 .60698 L .40649 .6081 L F
.974 .911 .682 r
.40988 .60265 m .40844 .60713 L .40957 .60698 L F
.637 .965 .865 r
.40844 .60713 m .40649 .6081 L .40957 .60698 L F
.587 .685 .909 r
.78193 .43687 m .78184 .44094 L .77929 .43731 L F
.78193 .43687 m .7845 .44039 L .78184 .44094 L F
.559 .325 .516 r
.43454 .63686 m .43717 .63654 L .43756 .63398 L F
.472 .248 .492 r
.43756 .63398 m .43856 .63519 L .43922 .63379 L F
.43756 .63398 m .43717 .63654 L .43856 .63519 L F
.013 0 0 r
.16077 .57708 m .1593 .57874 L .15686 .57968 L F
0 0 0 r
.16085 .57795 m .16077 .57708 L .16284 .57635 L F
.16085 .57795 m .1593 .57874 L .16077 .57708 L F
.5235 .54508 m .52728 .54327 L .52468 .54347 L F
.883 .849 .805 r
.1906 .75158 m .19066 .75566 L .19236 .75437 L F
.723 .519 .614 r
.57851 .49166 m .58224 .49459 L .58226 .49216 L F
.487 .263 .499 r
.66889 .43328 m .67222 .43124 L .67313 .432 L F
.698 .945 .959 r
.6743 .42994 m .67313 .432 L .67222 .43124 L F
.918 .752 .661 r
.57219 .53336 m .57469 .53402 L .57351 .53725 L F
.317 0 .164 r
.30146 .57516 m .30064 .57647 L .29882 .57678 L F
.353 .345 .711 r
.30212 .57181 m .30146 .57516 L .30066 .56998 L F
.464 .334 .619 r
.30212 .57181 m .30064 .57647 L .30146 .57516 L F
.536 .552 .818 r
.84128 .41495 m .83992 .41951 L .83897 .41616 L F
.84128 .41495 m .84285 .419 L .83992 .41951 L F
.994 .767 .479 r
.43077 .62439 m .42707 .62091 L .42859 .62279 L F
0 0 .322 r
.57953 .58488 m .57937 .58728 L .57799 .58878 L F
0 0 .227 r
.57937 .58728 m .57809 .59095 L .57799 .58878 L F
.67 .455 .585 r
.56372 .49474 m .5665 .49481 L .56661 .49193 L F
.687 .486 .609 r
.5665 .49481 m .56853 .49109 L .56661 .49193 L F
.871 .691 .656 r
.49042 .60347 m .49245 .60036 L .4902 .60049 L F
.703 .951 .955 r
.78321 .45054 m .78671 .44945 L .78638 .44949 L F
.502 .906 .812 r
.78671 .44945 m .78916 .44808 L .78853 .44808 L F
.47 .87 .697 r
.78853 .44808 m .78638 .44949 L .78671 .44945 L F
.607 .567 .784 r
.42543 .61167 m .42591 .61448 L .42834 .61125 L F
.564 .502 .745 r
.42591 .61448 m .42925 .61524 L .42834 .61125 L F
.42591 .61448 m .42687 .61581 L .42925 .61524 L F
.336 .783 .958 r
.47941 .55925 m .48332 .55939 L .48052 .55849 L F
.904 .776 .71 r
.66369 .43368 m .66614 .43425 L .66508 .43522 L F
.924 .745 .259 r
.66396 .4365 m .66369 .43368 L .66508 .43522 L F
.904 .776 .71 r
.66369 .43368 m .66457 .43637 L .66614 .43425 L F
.457 .266 .533 r
.66614 .43425 m .66934 .43366 L .66889 .43328 L F
.487 .263 .499 r
.66889 .43328 m .66934 .43366 L .67222 .43124 L F
.81 .954 .616 r
.66614 .43425 m .66814 .43016 L .66934 .43366 L F
.66614 .43425 m .66457 .43637 L .66814 .43016 L F
.504 .301 .537 r
.41544 .59175 m .41769 .59379 L .41873 .59159 L F
.41544 .59175 m .41532 .59436 L .41769 .59379 L F
.962 .925 .714 r
.7698 .4179 m .77203 .41651 L .76935 .41563 L F
.7698 .4179 m .7705 .41927 L .77203 .41651 L F
.756 .4 .38 r
.42185 .6178 m .41712 .61618 L .42015 .61608 L F
.42185 .6178 m .41694 .61805 L .41712 .61618 L F
.782 .847 .9 r
.42185 .6178 m .41837 .61939 L .41694 .61805 L F
.953 .88 .479 r
.42199 .61399 m .42185 .6178 L .42015 .61608 L F
.42199 .61399 m .42099 .61718 L .42185 .6178 L F
.802 .317 .049 r
.41946 .61828 m .42185 .6178 L .42099 .61718 L F
.41946 .61828 m .42292 .62034 L .42185 .6178 L F
.415 .115 .345 r
.42185 .6178 m .42292 .62034 L .42415 .61892 L F
.347 .752 .982 r
.20354 .73093 m .19936 .73007 L .20146 .72912 L F
.716 .852 .425 r
.20246 .73271 m .20204 .73371 L .20354 .73093 L F
.304 .636 .965 r
.2039 .72944 m .20354 .73093 L .20146 .72912 L F
.559 .152 .226 r
.20636 .73148 m .20657 .73116 L .20354 .73093 L F
.442 0 0 r
.20354 .73093 m .20657 .73116 L .20639 .73135 L F
.812 .806 .845 r
.20669 .72812 m .20638 .73135 L .2039 .72944 L F
.20638 .73135 m .20636 .73148 L .20623 .73137 L F
.20638 .73135 m .20623 .73137 L .2039 .72944 L F
.442 0 0 r
.20623 .73137 m .20639 .73135 L .20634 .73139 L F
.20354 .73093 m .20639 .73135 L .20623 .73137 L F
.304 .636 .965 r
.20623 .73137 m .20636 .73148 L .20354 .73093 L F
.442 0 0 r
.20354 .73093 m .20634 .73139 L .20616 .73157 L F
.304 .636 .965 r
.2039 .72944 m .20623 .73137 L .20354 .73093 L F
.498 .107 .23 r
.20354 .73093 m .20616 .73157 L .20246 .73271 L F
.924 .955 .787 r
.51813 .54125 m .51503 .54256 L .51531 .53948 L F
.51503 .54256 m .51431 .54286 L .51468 .54161 L F
.51503 .54256 m .51468 .54161 L .51531 .53948 L F
.51546 .54238 m .51599 .54183 L .51431 .54286 L F
.51813 .54125 m .51599 .54183 L .51546 .54238 L F
.88 .938 .852 r
.51599 .54183 m .51791 .54071 L .51743 .54018 L F
.51791 .54071 m .51969 .53967 L .51835 .53997 L F
.51791 .54071 m .51835 .53997 L .51743 .54018 L F
.966 .75 .56 r
.51844 .53627 m .51969 .53967 L .52251 .53719 L F
.905 .93 .821 r
.51431 .54286 m .51481 .53829 L .51531 .53948 L F
.428 0 0 r
.51476 .53963 m .51743 .54018 L .51835 .54009 L F
.961 .727 .538 r
.51835 .54009 m .51743 .54018 L .51824 .54 L F
.51835 .54009 m .51824 .54 L .51969 .53967 L F
.966 .75 .56 r
.51844 .53627 m .51835 .54009 L .51969 .53967 L F
.663 .754 .918 r
.51844 .53627 m .52251 .53719 L .52077 .53539 L F
.813 .828 .862 r
.51996 .53518 m .51844 .53627 L .52077 .53539 L F
.51996 .53518 m .51844 .53983 L .51844 .53627 L F
.51844 .53983 m .51835 .54009 L .51835 .53997 L F
.51844 .53983 m .51835 .53997 L .51844 .53627 L F
.51996 .53518 m .51639 .53823 L .51835 .54009 L F
.51639 .53823 m .51625 .53835 L .51835 .54009 L F
.428 0 0 r
.51529 .53974 m .51711 .54047 L .51743 .54018 L F
.895 .837 .781 r
.51469 .54257 m .51711 .54047 L .51526 .53972 L F
.51469 .54257 m .51527 .53965 L .5146 .54002 L F
.428 0 0 r
.51476 .53963 m .51711 .54047 L .51529 .53974 L F
.895 .837 .781 r
.51526 .53972 m .51711 .54047 L .51527 .53965 L F
.5146 .54002 m .51527 .53965 L .51457 .53935 L F
.509 0 0 r
.51457 .53935 m .51527 .53965 L .51476 .53963 L F
.813 .828 .862 r
.51625 .53835 m .51476 .53963 L .51527 .53965 L F
.51682 .53881 m .51527 .53965 L .51798 .53978 L F
.51625 .53835 m .51527 .53965 L .51682 .53881 L F
.509 0 0 r
.51527 .53965 m .51711 .54047 L .51476 .53963 L F
.813 .828 .862 r
.51798 .53978 m .51476 .53963 L .51835 .54009 L F
.563 .843 .504 r
.51743 .54018 m .51711 .54047 L .51599 .54183 L F
.86 .75 .237 r
.51685 .54096 m .51599 .54183 L .51711 .54047 L F
.924 .955 .787 r
.51813 .54125 m .51613 .54404 L .51599 .54183 L F
.88 .938 .852 r
.51599 .54183 m .51613 .54404 L .51969 .53967 L F
.269 .42 .829 r
.51599 .54183 m .51778 .5451 L .51568 .54434 L F
.5154 .54358 m .51568 .54434 L .51519 .54417 L F
.51599 .54183 m .51568 .54434 L .5154 .54358 L F
.51599 .54183 m .51519 .54417 L .51431 .54286 L F
.787 .676 .742 r
.51354 .54444 m .51778 .5451 L .51599 .54183 L F
.647 .143 .034 r
.51578 .54479 m .51709 .54562 L .51778 .5451 L F
.51354 .54444 m .51565 .54514 L .51578 .54479 L F
.51565 .54514 m .51709 .54562 L .51578 .54479 L F
.699 .533 .659 r
.51599 .54183 m .51565 .54514 L .51354 .54444 L F
.51565 .54514 m .51564 .54525 L .51354 .54444 L F
.86 .75 .237 r
.51564 .54519 m .51564 .54525 L .51565 .54514 L F
.649 .128 0 r
.51354 .54444 m .51598 .54646 L .51564 .54525 L F
.731 .207 0 r
.51548 .54533 m .51598 .54646 L .51564 .54525 L F
.647 .143 .034 r
.51535 .54504 m .51598 .54646 L .51709 .54562 L F
.51354 .54444 m .51508 .54572 L .51535 .54504 L F
.51508 .54572 m .51548 .54533 L .51535 .54504 L F
.934 .916 .536 r
.51548 .54357 m .51449 .54589 L .51548 .54533 L F
.51564 .54519 m .51548 .54533 L .51564 .54525 L F
.51548 .54357 m .51548 .54533 L .51564 .54519 L F
.647 .143 .034 r
.51508 .54572 m .51598 .54646 L .51548 .54533 L F
.731 .207 0 r
.51449 .54589 m .51598 .54646 L .51548 .54533 L F
.86 .75 .237 r
.51548 .54357 m .51564 .54519 L .51599 .54183 L F
.51564 .54519 m .51565 .54514 L .51599 .54183 L F
.51548 .54357 m .51599 .54183 L .51685 .54096 L F
.837 .838 .846 r
.7604 .41607 m .75735 .4159 L .76006 .41286 L F
.856 .806 .8 r
.7604 .41607 m .75802 .4193 L .75735 .4159 L F
.88 .864 .819 r
.76262 .41296 m .7604 .41607 L .76006 .41286 L F
.671 .405 .511 r
.44498 .60634 m .44642 .60918 L .44427 .60868 L F
.685 .411 .502 r
.44686 .60684 m .44642 .60918 L .44498 .60634 L F
.476 .179 .382 r
.47662 .6129 m .47905 .61263 L .47957 .61144 L F
.439 .122 .33 r
.47612 .61498 m .47905 .61263 L .47662 .6129 L F
.86 .648 .614 r
.57318 .51529 m .57027 .51224 L .57316 .51338 L F
.687 .486 .609 r
.5665 .49481 m .56991 .49459 L .56853 .49109 L F
.668 .477 .617 r
.56853 .49109 m .56991 .49459 L .57226 .49169 L F
.379 0 .144 r
.55402 .51065 m .55145 .51216 L .55167 .51089 L F
.675 .449 .571 r
.43423 .60586 m .43677 .60677 L .43715 .60353 L F
.432 .428 .755 r
.43715 .60353 m .43803 .59958 L .4353 .60015 L F
.43715 .60353 m .43894 .60303 L .43803 .59958 L F
.6 .463 .666 r
.43677 .60677 m .43894 .60303 L .43715 .60353 L F
.981 .691 .364 r
.49404 .57722 m .49457 .57974 L .49329 .57847 L F
1 .816 .496 r
.75419 .42314 m .75332 .42367 L .75272 .4218 L F
.75419 .42314 m .75402 .42491 L .75332 .42367 L F
.748 .399 .39 r
.29767 .5472 m .30071 .54721 L .29951 .54918 L F
.616 .52 .723 r
.30194 .54922 m .29951 .54918 L .30071 .54721 L F
.30194 .54922 m .29966 .54976 L .29951 .54918 L F
.389 .264 .587 r
.30064 .57647 m .29928 .57868 L .29882 .57678 L F
.688 .719 .873 r
.17871 .61524 m .17436 .61462 L .177 .61384 L F
.274 .445 .849 r
.17935 .61329 m .17871 .61524 L .177 .61384 L F
.17935 .61329 m .18004 .61529 L .17871 .61524 L F
0 0 0 r
.2998 .55099 m .29968 .55247 L .29967 .5511 L F
.576 .458 .682 r
.30431 .54915 m .30447 .55144 L .30082 .55097 L F
.30026 .55061 m .30082 .55097 L .29968 .55082 L F
0 0 0 r
.30194 .54922 m .30076 .55093 L .30026 .55061 L F
.558 .394 .615 r
.3005 .5513 m .30074 .55096 L .30447 .55144 L F
.30435 .55358 m .30207 .55442 L .30024 .55166 L F
0 0 0 r
.30072 .55097 m .30026 .55165 L .30023 .55168 L F
.30026 .55061 m .30026 .5508 L .2998 .55099 L F
.30026 .5508 m .30023 .55168 L .29992 .55117 L F
.558 .394 .615 r
.30004 .55103 m .29992 .55117 L .29968 .55082 L F
.30072 .55097 m .29968 .55082 L .30074 .55096 L F
0 0 0 r
.30076 .55093 m .30023 .55168 L .30026 .55061 L F
.558 .394 .615 r
.3005 .5513 m .30004 .55103 L .30072 .55097 L F
.30004 .55103 m .29968 .55082 L .30072 .55097 L F
0 0 0 r
.30026 .5508 m .30004 .55103 L .2998 .55099 L F
.30004 .55103 m .29992 .55117 L .29984 .55105 L F
.30004 .55103 m .29984 .55105 L .2998 .55099 L F
.558 .394 .615 r
.3005 .5513 m .30024 .55166 L .29992 .55117 L F
.3005 .5513 m .29992 .55117 L .30004 .55103 L F
.30435 .55358 m .30024 .55166 L .3005 .5513 L F
0 0 0 r
.30052 .55127 m .30067 .55105 L .30026 .55165 L F
.30076 .55093 m .30075 .55093 L .30052 .55127 L F
.30075 .55093 m .30067 .55105 L .30052 .55127 L F
.30076 .55093 m .30026 .55165 L .30072 .55097 L F
.558 .394 .615 r
.30435 .55358 m .3005 .5513 L .30447 .55144 L F
0 .054 .62 r
.2997 .55082 m .30025 .55165 L .30067 .55105 L F
.30025 .55165 m .30207 .55442 L .30067 .55105 L F
.29968 .55082 m .29992 .55117 L .2997 .55082 L F
0 0 0 r
.29968 .55082 m .30194 .54922 L .30026 .55061 L F
.30194 .54922 m .29967 .5511 L .29966 .54976 L F
0 .054 .62 r
.29992 .55117 m .30207 .55442 L .2997 .55082 L F
0 0 0 r
.30023 .55168 m .30067 .55105 L .29968 .55247 L F
.30122 .55027 m .30194 .54922 L .30431 .54915 L F
.30194 .54922 m .30122 .55027 L .30076 .55093 L F
.30026 .55061 m .30194 .54922 L .30122 .55027 L F
.30194 .54922 m .30184 .54937 L .30122 .55027 L F
.576 .458 .682 r
.30431 .54915 m .30076 .55093 L .30122 .55027 L F
0 0 0 r
.30184 .54937 m .30067 .55105 L .30076 .55093 L F
.576 .458 .682 r
.30431 .54915 m .30082 .55097 L .30076 .55093 L F
.30122 .55027 m .30076 .55093 L .30026 .55061 L F
0 0 0 r
.30023 .55168 m .29968 .55247 L .2998 .55099 L F
.391 .832 .944 r
.21298 .64803 m .21607 .64791 L .21507 .64729 L F
.534 .855 .997 r
.21607 .64791 m .21705 .64653 L .21507 .64729 L F
.21607 .64791 m .2193 .6475 L .21705 .64653 L F
.623 .419 .585 r
.45873 .59129 m .46204 .58871 L .45868 .58863 L F
.45873 .59129 m .46226 .59144 L .46204 .58871 L F
.667 .502 .652 r
.46226 .59144 m .46458 .58848 L .46204 .58871 L F
.783 .66 .728 r
.70267 .42272 m .70498 .42233 L .705 .41969 L F
.783 .665 .733 r
.70249 .42519 m .70498 .42233 L .70267 .42272 L F
.98 .786 .573 r
.58555 .53943 m .58652 .54293 L .58704 .5405 L F
.18 .512 .914 r
.48823 .57278 m .48945 .57435 L .4869 .57361 L F
0 .28 .772 r
.77069 .38572 m .76823 .38331 L .76968 .38481 L F
.819 .388 0 r
.76968 .38481 m .77115 .38686 L .77069 .38572 L F
.758 .676 .771 r
.7146 .40974 m .71838 .4104 L .71712 .40673 L F
.693 .641 .793 r
.71712 .40673 m .71838 .4104 L .7209 .40747 L F
.925 .974 .748 r
.2182 .70758 m .22058 .70685 L .2226 .706 L F
.2182 .70758 m .21793 .70813 L .22058 .70685 L F
.216 0 .306 r
.15134 .58754 m .15041 .58597 L .15215 .58532 L F
.15134 .58754 m .14957 .58862 L .15041 .58597 L F
.542 .306 .507 r
.23226 .58847 m .23468 .58562 L .23085 .58529 L F
.23226 .58847 m .23206 .58921 L .23468 .58562 L F
.847 .801 .806 r
.75802 .4193 m .75485 .41925 L .75735 .4159 L F
.782 .652 .719 r
.23417 .55791 m .23865 .55862 L .23706 .55514 L F
.475 .5 .805 r
.23706 .55514 m .23865 .55862 L .23951 .55622 L F
.455 .653 .945 r
.77904 .43632 m .77771 .43811 L .77768 .43658 L F
.77904 .43632 m .77929 .43731 L .77771 .43811 L F
.009 0 0 r
.44426 .64036 m .4421 .64294 L .44363 .64168 L F
.652 .605 .788 r
.82848 .41265 m .83229 .41544 L .82974 .41637 L F
.796 .445 0 r
.52906 .58213 m .53051 .58553 L .52984 .58443 L F
.075 .18 .671 r
.53043 .58806 m .52984 .58443 L .53051 .58553 L F
.88 .864 .819 r
.76262 .41296 m .76006 .41286 L .76169 .41146 L F
.897 .877 .808 r
.76367 .41121 m .76262 .41296 L .76169 .41146 L F
.752 .913 .946 r
.69346 .43034 m .69788 .42909 L .69631 .4277 L F
.802 .789 .841 r
.69631 .4277 m .69788 .42909 L .70029 .42624 L F
.473 .206 .428 r
.47006 .59787 m .46972 .59991 L .47254 .59754 L F
0 0 .505 r
.5322 .59121 m .53218 .59053 L .53043 .58806 L F
0 0 .488 r
.5322 .59121 m .53385 .59366 L .53218 .59053 L F
.709 .459 .545 r
.69509 .41898 m .69761 .41662 L .69499 .4166 L F
.69509 .41898 m .69763 .41877 L .69761 .41662 L F
.673 .542 .696 r
.69761 .41662 m .70103 .41652 L .7002 .41388 L F
.725 .542 .643 r
.69763 .41877 m .70103 .41652 L .69761 .41662 L F
0 0 0 r
.1565 .55837 m .15399 .5615 L .15575 .55955 L F
.33 .013 .268 r
.1524 .56345 m .15575 .55955 L .15399 .5615 L F
.754 .598 .684 r
.58622 .49807 m .58778 .49847 L .58597 .49504 L F
.817 .628 .647 r
.58654 .50054 m .58778 .49847 L .58622 .49807 L F
.58654 .50054 m .58736 .50096 L .58778 .49847 L F
.627 .893 .987 r
.22012 .68214 m .21916 .6835 L .22199 .68327 L F
.22012 .68214 m .21725 .68319 L .21916 .6835 L F
.53 .201 .355 r
.25845 .63668 m .25741 .63925 L .25501 .63937 L F
.537 .246 .421 r
.26057 .63674 m .25741 .63925 L .25845 .63668 L F
.352 0 .145 r
.17428 .56795 m .17332 .56946 L .17119 .56982 L F
.278 0 .101 r
.17546 .56885 m .17428 .56795 L .17662 .56752 L F
.17546 .56885 m .17332 .56946 L .17428 .56795 L F
.692 .661 .815 r
.46058 .59735 m .46431 .59818 L .46224 .59415 L F
.506 .568 .853 r
.46224 .59415 m .46431 .59818 L .46536 .59688 L F
.673 .941 .667 r
.46536 .59688 m .46329 .59899 L .46431 .59818 L F
.46536 .59688 m .46329 .59899 L .46431 .59818 L F
.907 .763 .69 r
.5738 .52187 m .57486 .52581 L .57327 .52452 L F
.923 .866 .764 r
.57486 .52581 m .57219 .52681 L .57327 .52452 L F
.57486 .52581 m .57365 .52812 L .57219 .52681 L F
.724 .816 .922 r
.77612 .40466 m .78014 .40456 L .7793 .40347 L F
.897 .945 .832 r
.7793 .40347 m .78014 .40456 L .78266 .40137 L F
0 0 0 r
.56783 .56753 m .56864 .56604 L .56902 .56429 L F
.199 .694 .919 r
.25098 .53779 m .25515 .53843 L .25268 .53862 L F
.926 .734 .624 r
.50587 .53883 m .5074 .54274 L .50693 .54066 L F
.548 .317 .518 r
.48113 .59149 m .48359 .59327 L .48323 .59172 L F
.48113 .59149 m .48117 .59375 L .48359 .59327 L F
.48113 .59149 m .48359 .59327 L .48323 .59172 L F
.48113 .59149 m .48117 .59375 L .48359 .59327 L F
.13 .677 .806 r
.21613 .53811 m .22005 .53808 L .218 .53837 L F
.781 .536 .566 r
.68759 .41863 m .69165 .41925 L .69131 .41655 L F
.653 .405 .531 r
.69165 .41925 m .69499 .4166 L .69131 .41655 L F
.787 .652 .713 r
.57226 .49169 m .56991 .49459 L .57356 .49496 L F
.489 .088 .206 r
.56991 .49714 m .57356 .49496 L .56991 .49459 L F
.56991 .49714 m .5725 .49686 L .57356 .49496 L F
.724 .622 .744 r
.57226 .49169 m .57356 .49496 L .57604 .49214 L F
.544 .144 .235 r
.57356 .49496 m .57622 .49657 L .57622 .49506 L F
.57356 .49496 m .5725 .49686 L .57622 .49657 L F
.635 .488 .665 r
.57356 .49496 m .57622 .49506 L .57604 .49214 L F
.426 .691 .974 r
.20311 .62822 m .19981 .62711 L .20185 .62671 L F
.297 .588 .944 r
.20359 .62673 m .20311 .62822 L .20185 .62671 L F
.308 .6 .949 r
.20521 .62843 m .20311 .62822 L .20359 .62673 L F
.462 .127 .312 r
.26696 .63145 m .26609 .63332 L .26374 .63361 L F
.298 0 .227 r
.26818 .63259 m .26696 .63145 L .26902 .63082 L F
.26818 .63259 m .26609 .63332 L .26696 .63145 L F
.667 .394 .498 r
.45664 .6242 m .45937 .62188 L .45711 .62173 L F
.45664 .6242 m .45915 .62436 L .45937 .62188 L F
.627 .36 .493 r
.45937 .62188 m .46277 .62411 L .46274 .62152 L F
.45937 .62188 m .45915 .62436 L .46277 .62411 L F
.446 .225 .485 r
.44855 .61554 m .44968 .61632 L .45071 .61282 L F
.324 .111 .428 r
.45071 .61282 m .4525 .61473 L .45261 .61192 L F
.45071 .61282 m .44968 .61632 L .4525 .61473 L F
.523 .914 .918 r
.78761 .43953 m .78693 .43927 L .78947 .43814 L F
.542 .554 .816 r
.75708 .42819 m .7584 .4243 L .7563 .42575 L F
.75708 .42819 m .75962 .42787 L .7584 .4243 L F
.653 .405 .531 r
.69165 .41925 m .69509 .41898 L .69499 .4166 L F
.726 .779 .895 r
.7233 .40664 m .72695 .40708 L .72594 .40423 L F
.769 .724 .81 r
.72483 .40827 m .72695 .40708 L .7233 .40664 L F
.688 .758 .905 r
.72594 .40423 m .72695 .40708 L .72979 .40497 L F
.864 .731 .713 r
.19732 .75462 m .20004 .75771 L .19687 .75662 L F
.781 .299 .084 r
.19687 .75662 m .20004 .75771 L .19726 .75782 L F
.121 .445 .88 r
.20047 .75652 m .20004 .75771 L .19732 .75462 L F
.629 .956 .921 r
.19726 .75782 m .20004 .75771 L .20033 .75691 L F
.19726 .75782 m .20033 .75691 L .19879 .7572 L F
0 0 .3 r
.19726 .75782 m .19686 .75628 L .19687 .75662 L F
.717 .944 .639 r
.19451 .75804 m .19686 .75628 L .19413 .75915 L F
.538 .22 .376 r
.19413 .75915 m .19686 .75628 L .19675 .75915 L F
.595 .268 .385 r
.19726 .75782 m .20047 .75652 L .19686 .75628 L F
.604 .273 .382 r
.19675 .75915 m .19686 .75628 L .19726 .75782 L F
.629 .956 .921 r
.19879 .7572 m .20033 .75691 L .20047 .75652 L F
.59 .258 .376 r
.19726 .75782 m .20047 .75652 L .19675 .75915 L F
.263 .01 .329 r
.19848 .75839 m .19686 .75628 L .19675 .75915 L F
.592 .079 .001 r
.19848 .75839 m .19772 .75741 L .19451 .75804 L F
.19772 .75741 m .19686 .75628 L .19454 .75801 L F
.19772 .75741 m .19454 .75801 L .19451 .75804 L F
.897 .945 .832 r
.7793 .40347 m .78266 .40137 L .78199 .4007 L F
.899 .58 .087 r
.78134 .39774 m .78199 .4007 L .78266 .40137 L F
.229 0 .319 r
.14855 .56465 m .14964 .56611 L .15044 .56411 L F
.14855 .56465 m .14792 .56705 L .14964 .56611 L F
.985 .874 .64 r
.5732 .54262 m .57099 .54526 L .5721 .54167 L F
.5732 .54262 m .57213 .54629 L .57099 .54526 L F
.793 .657 .713 r
.22211 .68392 m .21848 .68794 L .21725 .68319 L F
.22211 .68392 m .21725 .68319 L .21901 .68672 L F
0 0 0 r
.2232 .68373 m .22211 .68392 L .21901 .68672 L F
0 .313 .679 r
.67475 .44089 m .67125 .43927 L .6714 .44146 L F
.856 .447 .258 r
.51183 .55532 m .51042 .55666 L .51004 .55458 L F
.51183 .55532 m .51333 .55803 L .51042 .55666 L F
.743 .341 0 r
.52408 .57052 m .52443 .57188 L .52354 .56928 L F
.52408 .57052 m .52515 .57289 L .52443 .57188 L F
0 0 0 r
.68315 .43531 m .68204 .43607 L .67996 .43733 L F
.422 .86 .762 r
.68204 .43607 m .67991 .43718 L .67996 .43733 L F
.805 .636 .673 r
.58224 .49742 m .58597 .49504 L .58224 .49459 L F
.58224 .49742 m .58622 .49807 L .58597 .49504 L F
.826 .697 .159 r
.52925 .57964 m .52906 .58152 L .52871 .57862 L F
0 0 .424 r
.52906 .58152 m .53016 .58305 L .5287 .58057 L F
.52906 .58152 m .5287 .58057 L .5282 .57973 L F
.826 .697 .159 r
.52925 .57964 m .5291 .58162 L .52906 .58152 L F
.5291 .58162 m .52906 .58213 L .52906 .58152 L F
1 .805 .483 r
.81716 .44852 m .81839 .44723 L .81744 .44557 L F
.14 0 0 r
.46698 .6282 m .46282 .62977 L .46417 .62828 L F
.642 .438 .592 r
.4487 .61746 m .44968 .61632 L .44855 .61554 L F
0 0 0 r
.29968 .55082 m .30067 .55105 L .30194 .54922 L F
.245 .724 .935 r
.54201 .60957 m .54405 .60938 L .54057 .60899 L F
.622 .817 .975 r
.73779 .38021 m .74024 .38037 L .73688 .37989 L F
.697 .471 .576 r
.74024 .38037 m .73793 .38208 L .73688 .37989 L F
.74024 .38037 m .74046 .38293 L .73793 .38208 L F
.573 .174 .248 r
.74024 .38037 m .74286 .38199 L .74046 .38293 L F
.74024 .38037 m .74322 .38056 L .74286 .38199 L F
.704 .724 .866 r
.6559 .44234 m .65946 .44314 L .65802 .44161 L F
.702 .793 .921 r
.65802 .44161 m .65946 .44314 L .66148 .4419 L F
.331 0 .078 r
.15575 .55955 m .15882 .55813 L .1565 .55837 L F
.169 0 0 r
.22005 .53808 m .22222 .53825 L .22424 .53787 L F
.333 .816 .858 r
.22222 .53825 m .2265 .53757 L .22424 .53787 L F
.508 0 0 r
.2078 .53859 m .21007 .53923 L .21169 .53849 L F
.145 .684 .697 r
.21007 .53923 m .21392 .53845 L .21169 .53849 L F
.434 .861 .734 r
.436 .64319 m .43387 .64391 L .43201 .64508 L F
.668 .964 .762 r
.43704 .64169 m .436 .64319 L .43839 .64297 L F
.795 .571 .597 r
.43348 .6429 m .43704 .64169 L .43296 .64102 L F
.43348 .6429 m .43387 .64391 L .43704 .64169 L F
.43348 .6429 m .43296 .64102 L .43526 .64317 L F
.334 .318 .692 r
.43296 .64102 m .43526 .64317 L .43348 .6429 L F
.594 .049 0 r
.4338 .64225 m .4346 .64275 L .43296 .64102 L F
.4346 .64275 m .43526 .64317 L .43487 .6428 L F
.4346 .64275 m .43487 .6428 L .43296 .64102 L F
.668 .964 .762 r
.4361 .64305 m .43387 .64391 L .436 .64319 L F
.43704 .64169 m .43532 .64289 L .4361 .64305 L F
.43532 .64289 m .43387 .64391 L .4361 .64305 L F
.57 .404 .617 r
.48155 .5969 m .47883 .59435 L .48117 .59375 L F
.48155 .5969 m .47893 .59778 L .47883 .59435 L F
.421 0 .071 r
.47706 .59596 m .48117 .59375 L .47883 .59435 L F
.337 .095 .391 r
.66163 .41469 m .65933 .41405 L .66267 .41316 L F
.66163 .41469 m .65936 .41575 L .65933 .41405 L F
.829 .83 .848 r
.20204 .73371 m .20041 .73546 L .20014 .73443 L F
.954 .945 .639 r
.20204 .73371 m .2007 .73624 L .1988 .73719 L F
.829 .83 .848 r
.20014 .73443 m .1988 .73719 L .19673 .73575 L F
.20041 .73546 m .1988 .73719 L .20014 .73443 L F
.20204 .73371 m .19673 .73575 L .2007 .73624 L F
.20204 .73371 m .2007 .73624 L .19961 .73268 L F
.592 .815 .985 r
.19961 .73268 m .20204 .73371 L .20246 .73271 L F
.888 .728 .678 r
.2007 .73624 m .20204 .73371 L .19961 .73268 L F
.643 .247 .28 r
.19961 .73268 m .20246 .73271 L .20132 .73455 L F
0 .119 .666 r
.20004 .73146 m .19966 .73254 L .20132 .73455 L F
.19966 .73254 m .19961 .73268 L .19973 .73281 L F
.19966 .73254 m .19973 .73281 L .20132 .73455 L F
.607 .803 .975 r
.19673 .73575 m .1988 .73719 L .2007 .73624 L F
.618 .575 .783 r
.82755 .40901 m .82605 .41341 L .82509 .40966 L F
.82755 .40901 m .82848 .41265 L .82605 .41341 L F
.628 .606 .809 r
.15942 .60129 m .15602 .59953 L .15797 .59953 L F
.525 .481 .75 r
.29993 .58581 m .30061 .58777 L .29773 .58615 L F
.764 .604 .681 r
.59098 .50386 m .58736 .50096 L .58732 .50361 L F
.805 .604 .631 r
.58723 .50615 m .59098 .50386 L .58732 .50361 L F
.58723 .50615 m .59007 .50747 L .59098 .50386 L F
.294 .781 .904 r
.19739 .6466 m .20044 .64646 L .19899 .64597 L F
.156 .611 .932 r
.20044 .64646 m .20146 .64598 L .19899 .64597 L F
.20044 .64646 m .20329 .64709 L .20146 .64598 L F
.797 .655 .706 r
.42864 .63896 m .43215 .63996 L .43048 .63643 L F
.668 .143 0 r
.42864 .63896 m .43055 .64011 L .43067 .63954 L F
.53 .406 .655 r
.42682 .63699 m .43055 .64011 L .42864 .63896 L F
.42682 .63699 m .43037 .64097 L .43055 .64011 L F
.43037 .64097 m .43043 .64104 L .43055 .64011 L F
.668 .143 0 r
.43067 .63954 m .43055 .64011 L .43215 .63996 L F
.734 .522 .604 r
.42687 .61581 m .43138 .61851 L .42925 .61524 L F
.42687 .61581 m .42692 .61845 L .43138 .61851 L F
.538 .536 .8 r
.43048 .63643 m .43215 .63996 L .43446 .63886 L F
.471 .056 .17 r
.43055 .64011 m .43446 .63886 L .43215 .63996 L F
.615 .119 .052 r
.4419 .64322 m .44051 .64457 L .43839 .64297 L F
.347 0 .065 r
.4421 .64294 m .44051 .64457 L .4419 .64322 L F
.329 .8 .709 r
.19096 .54366 m .19081 .54354 L .19323 .54314 L F
.19096 .54366 m .18869 .54447 L .19081 .54354 L F
.863 .471 .298 r
.77265 .38928 m .77387 .38899 L .77094 .38775 L F
.421 0 0 r
.77531 .39003 m .77387 .38899 L .77265 .38928 L F
.598 .632 .856 r
.16421 .60363 m .15942 .60129 L .16148 .60087 L F
.222 .504 .905 r
.16465 .60276 m .16421 .60363 L .16148 .60087 L F
.008 0 .32 r
.16554 .60412 m .16421 .60363 L .16465 .60276 L F
.16554 .60412 m .16358 .60692 L .16421 .60363 L F
.59 .895 .614 r
.68381 .43432 m .68315 .43531 L .68556 .43432 L F
.68381 .43432 m .68204 .43607 L .68315 .43531 L F
.311 0 .097 r
.54904 .51308 m .54819 .51499 L .54563 .51567 L F
.164 0 .036 r
.55035 .51411 m .54904 .51308 L .55145 .51216 L F
.55035 .51411 m .54819 .51499 L .54904 .51308 L F
.722 .713 .842 r
.7209 .40747 m .72483 .40827 L .7233 .40664 L F
.619 .463 .649 r
.45873 .59129 m .46224 .59415 L .46226 .59144 L F
.45873 .59129 m .45976 .59485 L .46224 .59415 L F
.897 .877 .808 r
.76367 .41121 m .76169 .41146 L .76249 .41 L F
.477 .121 .283 r
.47145 .604 m .47087 .60559 L .46874 .6059 L F
.364 .006 .217 r
.47391 .60346 m .47087 .60559 L .47145 .604 L F
.158 0 .324 r
.40533 .60375 m .40745 .6028 L .40777 .60061 L F
0 0 .349 r
.40533 .60375 m .40651 .60503 L .40745 .6028 L F
.40533 .60375 m .40524 .60637 L .40651 .60503 L F
.644 .66 .851 r
.161 .62703 m .16237 .62941 L .16433 .6277 L F
.499 .251 .469 r
.24914 .61471 m .25175 .61198 L .25014 .61279 L F
.813 .845 .873 r
.67599 .42679 m .67242 .42789 L .67416 .42523 L F
.736 .739 .854 r
.67787 .42579 m .67599 .42679 L .67416 .42523 L F
.86 .408 .057 r
.43675 .57818 m .43764 .57949 L .43587 .5784 L F
0 0 0 r
.19947 .5577 m .19588 .55869 L .19731 .55838 L F
.403 .177 .454 r
.44112 .62409 m .44301 .62182 L .4406 .62176 L F
.556 .846 .998 r
.26883 .5399 m .26711 .53905 L .26937 .53836 L F
.386 .668 .971 r
.26937 .53836 m .271 .53996 L .26883 .5399 L F
.677 .846 .964 r
.20329 .64709 m .20709 .64703 L .2053 .64627 L F
.368 .786 .977 r
.20911 .64666 m .2053 .64627 L .20709 .64703 L F
.78 .998 .847 r
.84077 .42522 m .83757 .42786 L .83839 .42838 L F
.845 .571 .525 r
.22506 .68838 m .22474 .69115 L .22205 .69037 L F
.367 .016 .231 r
.22847 .68795 m .22474 .69115 L .22506 .68838 L F
.429 0 0 r
.48699 .56016 m .48884 .56098 L .49051 .56131 L F
.444 0 0 r
.48884 .56098 m .49352 .56304 L .49051 .56131 L F
.916 .75 .66 r
.46459 .59346 m .46536 .59688 L .46681 .59498 L F
.835 .722 .739 r
.23199 .59138 m .23383 .5949 L .23466 .59104 L F
.872 .857 .823 r
.22012 .68214 m .22199 .68327 L .22089 .68092 L F
.604 .56 .778 r
.80444 .41928 m .80619 .41278 L .80363 .41334 L F
.80444 .41928 m .80688 .41526 L .80619 .41278 L F
.606 .52 .731 r
.80515 .41945 m .80688 .41526 L .80444 .41928 L F
.744 .575 .665 r
.48458 .60834 m .49057 .60555 L .49018 .60423 L F
.426 .508 .84 r
.48458 .60834 m .48637 .60823 L .49057 .60555 L F
.945 .673 .489 r
.49018 .60423 m .48937 .60633 L .49042 .60347 L F
.49018 .60423 m .49057 .60555 L .48937 .60633 L F
.891 .745 .694 r
.58749 .53356 m .58784 .53138 L .58625 .53025 L F
.253 .576 .942 r
.75377 .37497 m .75386 .37551 L .75136 .37407 L F
.425 .67 .964 r
.757 .37451 m .75386 .37551 L .75377 .37497 L F
.941 .789 .665 r
.5734 .53044 m .57219 .52681 L .57365 .52812 L F
0 0 .337 r
.54087 .58445 m .541 .58765 L .53991 .58869 L F
.576 .611 .851 r
.541 .58765 m .54025 .59105 L .53991 .58869 L F
.629 .625 .827 r
.74619 .40912 m .7468 .41249 L .74975 .41018 L F
.602 .769 .96 r
.48169 .56681 m .48704 .56748 L .48409 .56547 L F
0 0 .537 r
.48704 .56748 m .48703 .56587 L .48409 .56547 L F
.48704 .56748 m .48738 .568 L .48703 .56587 L F
.481 .772 .995 r
.16 .59978 m .15942 .60129 L .15797 .59953 L F
.16 .59978 m .16148 .60087 L .15942 .60129 L F
.773 .77 .85 r
.18377 .61906 m .18601 .6214 L .18178 .62121 L F
.409 .642 .952 r
.18784 .62119 m .18601 .6214 L .18377 .61906 L F
.468 .221 .456 r
.29857 .59136 m .29847 .59396 L .29598 .59417 L F
.395 .274 .596 r
.30061 .58777 m .30078 .59084 L .29857 .59136 L F
.463 .217 .455 r
.30083 .59336 m .29857 .59136 L .30078 .59084 L F
.30083 .59336 m .29847 .59396 L .29857 .59136 L F
.458 .274 .542 r
.50136 .6027 m .49915 .60084 L .50148 .59997 L F
.50029 .6018 m .49881 .60326 L .49915 .60084 L F
.791 .61 .656 r
.49756 .59971 m .50148 .59997 L .49991 .59532 L F
0 .105 .631 r
.49991 .59532 m .50148 .59997 L .50212 .59816 L F
.686 .248 .203 r
.49956 .60192 m .50148 .59997 L .49756 .59971 L F
.793 .944 .596 r
.50212 .59816 m .50151 .5999 L .49956 .60192 L F
.50151 .5999 m .50148 .59997 L .50142 .60003 L F
.50151 .5999 m .50142 .60003 L .49956 .60192 L F
.458 .274 .542 r
.50136 .6027 m .49945 .60312 L .50029 .6018 L F
.49945 .60312 m .49881 .60326 L .50029 .6018 L F
.84 .959 .887 r
.74934 .39293 m .74692 .39546 L .74613 .39441 L F
.989 .893 .59 r
.74613 .39441 m .74692 .39546 L .74601 .39756 L F
.63 .382 .525 r
.66029 .40665 m .66265 .40415 L .66068 .40483 L F
.607 .849 .483 r
.48871 .54042 m .49 .53858 L .49132 .53705 L F
0 0 .258 r
.48951 .54244 m .49 .53858 L .48871 .54042 L F
.758 .64 .73 r
.70127 .41918 m .705 .41969 L .70368 .41617 L F
.783 .66 .728 r
.70267 .42272 m .705 .41969 L .70127 .41918 L F
.733 .627 .74 r
.70368 .41617 m .705 .41969 L .70749 .41671 L F
.261 .325 .74 r
.26676 .56091 m .26765 .56454 L .26892 .56263 L F
.788 .5 .5 r
.27168 .56742 m .26765 .56454 L .26804 .56719 L F
.27168 .56742 m .27065 .5682 L .2702 .56766 L F
0 .04 .568 r
.26804 .56719 m .26869 .5679 L .2702 .56766 L F
.26942 .56728 m .2702 .56766 L .27168 .56742 L F
.26804 .56719 m .2702 .56766 L .26942 .56728 L F
.788 .5 .5 r
.27168 .56742 m .2702 .56766 L .26765 .56454 L F
.313 .396 .787 r
.26765 .56454 m .2702 .56766 L .26892 .56263 L F
.2702 .56766 m .27065 .5682 L .27053 .56782 L F
0 .04 .568 r
.26944 .56778 m .27077 .56782 L .27168 .56742 L F
.728 .66 .783 r
.26892 .56263 m .27053 .56782 L .27226 .56345 L F
.27053 .56782 m .27065 .5682 L .27077 .56782 L F
.27053 .56782 m .27077 .56782 L .27226 .56345 L F
0 .04 .568 r
.26869 .5679 m .26925 .56851 L .27077 .56782 L F
.26869 .5679 m .27077 .56782 L .26944 .56778 L F
.937 .911 .767 r
.27077 .56782 m .27065 .5682 L .27168 .56742 L F
0 .04 .568 r
.26925 .56851 m .2695 .56879 L .27168 .56742 L F
.937 .911 .767 r
.27226 .56345 m .27077 .56782 L .27168 .56742 L F
.313 .396 .787 r
.2702 .56766 m .27053 .56782 L .26892 .56263 L F
.567 .029 0 r
.74798 .37843 m .7489 .37744 L .7516 .3789 L F
.987 .713 .371 r
.43471 .62602 m .43272 .62346 L .43077 .62439 L F
.43471 .62602 m .43408 .62728 L .43272 .62346 L F
.797 .377 .25 r
.43558 .62676 m .43408 .62728 L .43471 .62602 L F
.667 .542 .703 r
.70103 .41652 m .70351 .41312 L .7002 .41388 L F
.485 .834 .996 r
.21705 .64653 m .2193 .6475 L .22199 .64684 L F
0 .374 .812 r
.78978 .39059 m .78644 .38897 L .7853 .3878 L F
.367 .187 .5 r
.26413 .57687 m .26575 .57638 L .26645 .57324 L F
.468 .497 .805 r
.26413 .57687 m .26722 .5784 L .26575 .57638 L F
.937 .911 .767 r
.27226 .56345 m .27168 .56742 L .27406 .56443 L F
.684 .531 .673 r
.27168 .56742 m .27457 .56751 L .27406 .56443 L F
.225 .718 .919 r
.27646 .56389 m .27226 .56345 L .27406 .56443 L F
.488 .395 .677 r
.27406 .56443 m .2766 .56674 L .27646 .56389 L F
.27406 .56443 m .27457 .56751 L .2766 .56674 L F
.498 .657 .932 r
.19965 .62428 m .19981 .62711 L .19782 .62497 L F
.19965 .62428 m .20185 .62671 L .19981 .62711 L F
.185 0 .173 r
.40777 .60061 m .40924 .60015 L .41042 .59743 L F
.647 .317 .399 r
.41042 .59743 m .41248 .59919 L .41264 .59727 L F
.41042 .59743 m .40924 .60015 L .41248 .59919 L F
.617 .141 .101 r
.78156 .38767 m .7853 .3878 L .78247 .38617 L F
.235 .256 .679 r
.39859 .61569 m .40067 .61774 L .4 .61433 L F
.358 .274 .623 r
.39896 .61828 m .40067 .61774 L .39859 .61569 L F
.434 .565 .887 r
.15801 .62586 m .15912 .62372 L .15682 .62447 L F
.15801 .62586 m .161 .62703 L .15912 .62372 L F
.426 .338 .654 r
.30014 .55776 m .29854 .56171 L .29778 .55825 L F
.30014 .55776 m .30042 .56106 L .29854 .56171 L F
.441 .381 .695 r
.30042 .56106 m .30098 .56343 L .29854 .56171 L F
.531 .693 .943 r
.54763 .611 m .54405 .60938 L .54539 .61186 L F
.397 0 .037 r
.25279 .63989 m .25097 .64171 L .24878 .64203 L F
.561 .119 .157 r
.25384 .64156 m .25279 .63989 L .25501 .63937 L F
.25384 .64156 m .25097 .64171 L .25279 .63989 L F
.382 .807 .97 r
.2326 .53738 m .23044 .53778 L .22867 .53723 L F
.148 .322 .783 r
.23279 .6838 m .23166 .68448 L .2302 .6817 L F
0 0 .079 r
.23054 .68734 m .23166 .68448 L .23279 .6838 L F
.04 0 0 r
.52877 .51826 m .53339 .51596 L .53076 .51637 L F
.495 .562 .853 r
.1432 .57043 m .14494 .56961 L .14589 .56783 L F
.1 0 .084 r
.14589 .56783 m .14673 .56858 L .14792 .56705 L F
.14589 .56783 m .14494 .56961 L .14673 .56858 L F
.399 0 .074 r
.22826 .57533 m .23005 .57516 L .23154 .57385 L F
.81 .491 .449 r
.23005 .57516 m .23256 .57649 L .23154 .57385 L F
.815 .901 .902 r
.21618 .69621 m .21393 .70028 L .21486 .69939 L F
.506 .845 .566 r
.22994 .6791 m .2306 .67839 L .2304 .67856 L F
.22994 .6791 m .22789 .68082 L .2306 .67839 L F
.502 .632 .91 r
.2304 .67856 m .2302 .6817 L .22994 .6791 L F
.832 .554 .517 r
.58224 .49742 m .58654 .50054 L .58622 .49807 L F
.63 .454 .625 r
.57622 .49506 m .57851 .49166 L .57604 .49214 L F
.489 .248 .476 r
.44941 .60623 m .44642 .60918 L .44686 .60684 L F
.205 .535 .924 r
.79991 .39771 m .79803 .39728 L .79596 .39531 L F
.364 .002 .211 r
.49812 .58509 m .49539 .58703 L .49565 .58543 L F
.538 .536 .8 r
.43048 .63643 m .43446 .63886 L .43454 .63686 L F
.59 .31 .459 r
.43446 .63886 m .43686 .63896 L .43454 .63686 L F
.557 .316 .506 r
.43454 .63686 m .43686 .63896 L .43717 .63654 L F
.627 .618 .823 r
.50662 .60038 m .51067 .60003 L .50912 .59833 L F
.568 .343 .534 r
.50912 .59833 m .50781 .59978 L .50662 .60038 L F
0 0 .37 r
.50719 .60367 m .50662 .60038 L .50529 .60104 L F
.50719 .60367 m .50742 .60398 L .50662 .60038 L F
.627 .618 .823 r
.50662 .60038 m .50742 .60398 L .51073 .60266 L F
.50662 .60038 m .51073 .60266 L .51067 .60003 L F
.568 .343 .534 r
.50781 .59978 m .50604 .60176 L .50662 .60038 L F
0 0 .37 r
.50529 .60104 m .50662 .60038 L .50458 .60005 L F
.516 .415 .679 r
.50632 .6067 m .50742 .60398 L .50719 .60367 L F
.463 .843 .617 r
.46506 .60372 m .46657 .60253 L .46813 .60149 L F
.172 0 .096 r
.46506 .60372 m .46417 .60586 L .46622 .60504 L F
.555 .324 .52 r
.30255 .56711 m .30219 .56954 L .30002 .5677 L F
.332 .33 .707 r
.30002 .5677 m .30219 .56954 L .30066 .56998 L F
.555 .324 .52 r
.30255 .56711 m .30219 .56954 L .30002 .5677 L F
.587 .127 .128 r
.73778 .37435 m .74131 .37419 L .73906 .37359 L F
.757 .335 .247 r
.67765 .41306 m .68161 .41536 L .68134 .41351 L F
.522 .729 .968 r
.82296 .44333 m .82687 .44429 L .82594 .44364 L F
.722 .681 .811 r
.82687 .44429 m .82775 .43955 L .82594 .44364 L F
.82687 .44429 m .82844 .44212 L .82775 .43955 L F
.47 .755 .992 r
.21562 .69899 m .2159 .69783 L .21618 .69621 L F
.543 .454 .704 r
.2159 .69783 m .21602 .69714 L .21618 .69621 L F
.425 .395 .723 r
.21418 .69453 m .21618 .69621 L .21642 .69487 L F
.543 .454 .704 r
.21602 .69714 m .21639 .69478 L .21618 .69621 L F
.425 .395 .723 r
.21642 .69487 m .21618 .69621 L .2177 .69506 L F
.787 .97 .674 r
.2177 .69506 m .21808 .69363 L .22013 .69445 L F
.2177 .69506 m .21618 .69621 L .21808 .69363 L F
0 0 .574 r
.5342 .6004 m .53575 .60222 L .53424 .59864 L F
.16 0 0 r
.46657 .60253 m .46972 .59991 L .46813 .60149 L F
.971 .699 .284 r
.41712 .61618 m .41606 .6168 L .41342 .61438 L F
.41712 .61618 m .41694 .61805 L .41606 .6168 L F
.11 .463 .89 r
.79201 .39246 m .79036 .39202 L .78978 .39059 L F
.299 .673 .974 r
.66698 .43857 m .67125 .43927 L .66974 .43791 L F
.891 .745 .694 r
.58749 .53356 m .58625 .53025 L .5843 .53343 L F
.886 .703 .649 r
.58587 .53672 m .58749 .53356 L .5843 .53343 L F
.434 .756 .995 r
.22904 .55204 m .23017 .55326 L .23361 .55258 L F
.949 .792 .653 r
.65683 .41897 m .65596 .41532 L .65687 .41651 L F
.515 .315 .547 r
.65936 .41575 m .65683 .41897 L .65687 .41651 L F
.661 .622 .8 r
.45976 .59485 m .46058 .59735 L .46224 .59415 L F
.631 .803 .371 r
.43301 .61567 m .43198 .61739 L .43138 .61851 L F
.739 .846 .403 r
.43227 .61654 m .43301 .61567 L .4352 .61466 L F
.43227 .61654 m .43198 .61739 L .43301 .61567 L F
0 0 0 r
.16459 .55466 m .16594 .55463 L .16766 .55266 L F
.067 0 0 r
.16766 .55266 m .16759 .55402 L .16984 .55204 L F
.16766 .55266 m .16594 .55463 L .16759 .55402 L F
.408 .19 .468 r
.43021 .57355 m .43004 .57635 L .43232 .57283 L F
.43021 .57355 m .43004 .57635 L .43232 .57283 L F
.413 .848 .94 r
.21541 .63085 m .21747 .63029 L .21924 .63049 L F
.177 0 0 r
.21747 .63029 m .22141 .62992 L .21924 .63049 L F
.285 0 0 r
.25515 .53843 m .25701 .5387 L .25872 .53818 L F
.244 .757 .85 r
.25701 .5387 m .261 .53838 L .25872 .53818 L F
0 .021 .569 r
.49352 .56304 m .49618 .5664 L .49413 .56446 L F
0 0 0 r
.48937 .60633 m .49057 .60555 L .48637 .60823 L F
.483 .3 .557 r
.54169 .59469 m .54401 .59402 L .54344 .59185 L F
.538 .793 .992 r
.54025 .59105 m .54401 .59402 L .54169 .59469 L F
.428 .165 .411 r
.28202 .61567 m .28148 .61809 L .2793 .61858 L F
.497 .227 .435 r
.28388 .61754 m .28202 .61567 L .28432 .61513 L F
.28388 .61754 m .28148 .61809 L .28202 .61567 L F
0 0 0 r
.5235 .54508 m .52569 .5447 L .52728 .54327 L F
.151 0 .212 r
.53753 .51904 m .53906 .52001 L .53677 .52034 L F
.53753 .51904 m .5395 .51828 L .53906 .52001 L F
.41 .106 .336 r
.23456 .67564 m .23374 .67812 L .23235 .67615 L F
0 0 0 r
.23235 .67615 m .23257 .6762 L .23456 .67564 L F
0 0 .459 r
.23235 .67615 m .23374 .67812 L .23257 .6762 L F
.585 .66 .89 r
.7436 .40983 m .74434 .40607 L .74198 .40666 L F
.7436 .40983 m .74619 .40912 L .74434 .40607 L F
.689 .163 0 r
.66871 .4171 m .66978 .41837 L .66725 .41649 L F
.182 0 .222 r
.65837 .40774 m .6578 .40951 L .66029 .40665 L F
.538 .793 .992 r
.54025 .59105 m .54344 .59185 L .54401 .59402 L F
.54025 .59105 m .5427 .59051 L .54344 .59185 L F
.481 .504 .805 r
.54532 .58784 m .54344 .59185 L .5427 .59051 L F
.54532 .58784 m .54826 .59055 L .54344 .59185 L F
.736 .619 .729 r
.70368 .41617 m .70749 .41671 L .70618 .41321 L F
.709 .606 .739 r
.70618 .41321 m .70749 .41671 L .70999 .41366 L F
.517 .039 .059 r
.48165 .61223 m .47957 .61144 L .47905 .61263 L F
.966 .917 .574 r
.53203 .56698 m .53122 .56892 L .53266 .5675 L F
.675 .967 .926 r
.53266 .5675 m .53365 .56585 L .53203 .56698 L F
.67 .901 .559 r
.53365 .56585 m .53122 .56892 L .53266 .5675 L F
.525 .536 .809 r
.51843 .60831 m .51685 .61176 L .51522 .61148 L F
.51843 .60831 m .51981 .61192 L .51685 .61176 L F
.666 .235 .215 r
.51981 .61192 m .51522 .61148 L .51685 .61176 L F
.252 .678 .963 r
.23251 .65944 m .23222 .66036 L .23422 .66042 L F
.23251 .65944 m .23222 .66036 L .23422 .66042 L F
.526 .686 .94 r
.81635 .40302 m .81462 .40514 L .81383 .40323 L F
.81635 .40302 m .81729 .40487 L .81462 .40514 L F
.738 .918 .954 r
.45732 .6199 m .45534 .62131 L .45711 .62173 L F
.941 .724 .58 r
.45534 .62131 m .45664 .6242 L .45711 .62173 L F
.495 .562 .853 r
.1432 .57043 m .14469 .56982 L .14494 .56961 L F
.074 0 0 r
.14285 .57092 m .14469 .56982 L .1432 .57043 L F
.065 0 0 r
.46164 .57174 m .45937 .57192 L .46088 .57036 L F
.63 .454 .625 r
.57622 .49506 m .57895 .49477 L .57851 .49166 L F
.723 .519 .614 r
.57851 .49166 m .57895 .49477 L .58224 .49459 L F
.739 .698 .813 r
.20302 .71806 m .20336 .72068 L .20262 .7196 L F
.961 .653 .396 r
.20336 .72068 m .20254 .72331 L .20262 .7196 L F
.071 .181 .673 r
.20302 .71806 m .20484 .72008 L .20336 .72068 L F
.493 .312 .564 r
.20484 .72008 m .20254 .72331 L .20336 .72068 L F
.337 .14 .459 r
.42755 .57644 m .4253 .58028 L .42733 .57898 L F
.553 .931 .835 r
.42733 .57898 m .4253 .58028 L .42755 .57644 L F
.78 .998 .847 r
.84077 .42522 m .8405 .42444 L .83757 .42786 L F
0 0 0 r
.8405 .42444 m .84108 .42409 L .83991 .42393 L F
.8405 .42444 m .83991 .42393 L .83901 .4238 L F
.895 .948 .595 r
.84091 .42479 m .8405 .42444 L .84077 .42522 L F
.84217 .42084 m .8405 .42444 L .84091 .42479 L F
0 0 .054 r
.41811 .64433 m .4178 .64346 L .41817 .64175 L F
.41811 .64433 m .41711 .64612 L .4178 .64346 L F
.114 .093 .553 r
.41811 .64433 m .41718 .64755 L .41711 .64612 L F
.403 .255 .564 r
.26609 .58534 m .26801 .58476 L .26796 .58218 L F
.406 .25 .554 r
.26609 .58534 m .26802 .58739 L .26801 .58476 L F
.26609 .58534 m .26609 .58809 L .26802 .58739 L F
.772 .51 .539 r
.43083 .5783 m .4282 .57681 L .43004 .57635 L F
.43083 .5783 m .42733 .57898 L .42755 .57644 L F
.375 .111 .38 r
.42934 .57831 m .4311 .57608 L .43004 .57635 L F
.4311 .57608 m .43209 .57482 L .43004 .57635 L F
.772 .51 .539 r
.4282 .57681 m .42755 .57644 L .43004 .57635 L F
.655 .258 .279 r
.43083 .5783 m .4296 .58092 L .42733 .57898 L F
.126 0 0 r
.43428 .57833 m .4296 .58092 L .43083 .5783 L F
.78 .663 .733 r
.69882 .4246 m .70249 .42519 L .70267 .42272 L F
.769 .694 .78 r
.69882 .4246 m .70029 .42624 L .70249 .42519 L F
.793 .779 .275 r
.42098 .66259 m .42214 .65805 L .42159 .65737 L F
.595 .752 .953 r
.21386 .62912 m .2132 .63151 L .21136 .63001 L F
.21386 .62912 m .21541 .63085 L .2132 .63151 L F
.774 .662 .74 r
.23005 .57882 m .23003 .5797 L .22826 .57533 L F
.619 .594 .803 r
.23003 .5797 m .23005 .57516 L .22826 .57533 L F
.23003 .5797 m .23162 .57962 L .23005 .57516 L F
.802 .493 .467 r
.23003 .5797 m .22935 .58169 L .23248 .58166 L F
.353 .345 .711 r
.30212 .57181 m .30066 .56998 L .30219 .56954 L F
.477 .447 .746 r
.49287 .58353 m .49344 .58173 L .49339 .58116 L F
.046 0 0 r
.49333 .58054 m .49339 .58116 L .49457 .57974 L F
.99 .746 .462 r
.49457 .57974 m .49339 .58116 L .49329 .57847 L F
.477 .447 .746 r
.49344 .58173 m .49424 .57924 L .49339 .58116 L F
.046 0 0 r
.49132 .58184 m .49339 .58116 L .49333 .58054 L F
.981 .693 .337 r
.56174 .58597 m .56113 .58734 L .56123 .58519 L F
0 0 .063 r
.56902 .56429 m .56921 .56353 L .56933 .56067 L F
0 0 0 r
.56902 .56429 m .56864 .56604 L .56921 .56353 L F
.47778 .6215 m .47639 .62314 L .47489 .62371 L F
.802 .523 .516 r
.47639 .62314 m .47352 .62516 L .47489 .62371 L F
.319 .391 .78 r
.163 .61114 m .16174 .61281 L .16057 .60953 L F
.436 .558 .88 r
.163 .61114 m .16344 .61233 L .16174 .61281 L F
.762 .343 0 r
.53574 .56418 m .537 .56684 L .53801 .5681 L F
0 .089 .606 r
.537 .56684 m .53935 .56936 L .53801 .5681 L F
.537 .366 .597 r
.30021 .55502 m .30014 .55776 L .29778 .55825 L F
.855 .994 .751 r
.27168 .56742 m .2695 .56879 L .27203 .56546 L F
.004 0 0 r
.27145 .57 m .27457 .56751 L .27168 .56742 L F
.421 .442 .776 r
.27203 .56546 m .27145 .57 L .27168 .56742 L F
.277 .754 .933 r
.19769 .53924 m .20167 .5395 L .19949 .54029 L F
.568 .414 .633 r
.28966 .61184 m .28699 .60966 L .2895 .60924 L F
.28966 .61184 m .28711 .61231 L .28699 .60966 L F
.137 .48 .899 r
.75402 .42491 m .75492 .42399 L .75332 .42367 L F
.75402 .42491 m .7563 .42575 L .75492 .42399 L F
.638 .093 0 r
.502 .57272 m .50563 .57567 L .50453 .57404 L F
.21 0 0 r
.79842 .43598 m .80174 .43381 L .79919 .43467 L F
.317 .043 .329 r
.42733 .57898 m .43004 .57635 L .42755 .57644 L F
.723 .753 .877 r
.67656 .42414 m .67787 .42579 L .67416 .42523 L F
.725 .542 .643 r
.69763 .41877 m .70127 .41918 L .70103 .41652 L F
.667 .542 .703 r
.70103 .41652 m .70368 .41617 L .70351 .41312 L F
.657 .491 .648 r
.70127 .41918 m .70368 .41617 L .70103 .41652 L F
.574 .516 .752 r
.80536 .42168 m .80776 .41868 L .80515 .41945 L F
.80536 .42168 m .80862 .42205 L .80776 .41868 L F
.662 .502 .656 r
.80514 .42445 m .80862 .42205 L .80536 .42168 L F
0 0 .381 r
.79404 .4 m .79255 .40435 L .79516 .40368 L F
.442 .576 .892 r
.79255 .40435 m .79643 .40709 L .79516 .40368 L F
.179 .351 .799 r
.30067 .55105 m .30207 .55442 L .29968 .55247 L F
.456 .387 .691 r
.29968 .55247 m .30207 .55442 L .30021 .55502 L F
0 0 .061 r
.48988 .60867 m .49074 .60615 L .48937 .60633 L F
.614 .299 .413 r
.49074 .60615 m .49042 .60347 L .48937 .60633 L F
.647 .454 .608 r
.44614 .61883 m .44911 .62109 L .4487 .61746 L F
.44614 .61883 m .44654 .62133 L .44911 .62109 L F
.835 .722 .739 r
.23199 .59138 m .23466 .59104 L .2344 .59071 L F
.478 0 0 r
.74423 .37518 m .74524 .37401 L .74131 .37419 L F
.538 .021 0 r
.74423 .37518 m .74822 .37492 L .74524 .37401 L F
.516 0 0 r
.74822 .37492 m .7476 .37439 L .74524 .37401 L F
.683 .966 .933 r
.50228 .59277 m .50096 .59439 L .50072 .59377 L F
.65 .326 .411 r
.49991 .59532 m .50336 .59673 L .50096 .59439 L F
.634 .441 .604 r
.70866 .4101 m .71112 .40952 L .71133 .40726 L F
.571 .393 .601 r
.71133 .40726 m .71354 .40642 L .71395 .40422 L F
.724 .6 .718 r
.71112 .40952 m .71354 .40642 L .71133 .40726 L F
.1 0 0 r
.80064 .44285 m .79707 .44454 L .79794 .44336 L F
.443 .664 .956 r
.81298 .40158 m .8115 .40343 L .80996 .40163 L F
.81298 .40158 m .81383 .40323 L .8115 .40343 L F
.916 .793 .711 r
.43952 .63072 m .43922 .63379 L .43779 .63019 L F
.43952 .63072 m .43922 .63379 L .43779 .63019 L F
.232 .363 .791 r
.79516 .40368 m .79643 .40709 L .79791 .4055 L F
.384 .602 .934 r
.79791 .4055 m .79643 .40709 L .79864 .40718 L F
0 0 0 r
.5734 .59739 m .57277 .59935 L .57091 .60044 L F
.57277 .59935 m .56964 .60182 L .57091 .60044 L F
.685 .23 0 r
.49986 .56985 m .502 .57272 L .5008 .57089 L F
.589 .315 .469 r
.55757 .49752 m .56119 .49462 L .55798 .49671 L F
.55757 .49752 m .55955 .49744 L .56119 .49462 L F
.662 .4 .514 r
.56119 .49462 m .5637 .49698 L .56372 .49474 L F
.56119 .49462 m .55955 .49744 L .5637 .49698 L F
.542 .067 .078 r
.43395 .57721 m .43587 .5784 L .43428 .57833 L F
.357 0 .102 r
.44948 .56647 m .45191 .56606 L .45342 .56391 L F
.347 0 0 r
.45191 .56606 m .4558 .56428 L .45342 .56391 L F
.962 .847 .683 r
.58452 .55092 m .58708 .54824 L .58613 .54758 L F
.58452 .55092 m .58591 .55213 L .58708 .54824 L F
.005 0 .062 r
.57596 .5944 m .57547 .59645 L .5734 .59739 L F
0 0 .124 r
.57809 .59095 m .57773 .59329 L .57596 .5944 L F
0 0 .021 r
.57773 .59329 m .57547 .59645 L .57596 .5944 L F
.793 .555 .577 r
.243 .66067 m .2407 .66244 L .24097 .6614 L F
.769 .891 .482 r
.77237 .4078 m .77307 .40716 L .77243 .40591 L F
.77237 .4078 m .77153 .41001 L .77307 .40716 L F
0 0 0 r
.50906 .53082 m .50786 .53268 L .50612 .53363 L F
.177 .036 .439 r
.50612 .53363 m .50608 .53645 L .50786 .53268 L F
0 0 0 r
.50612 .53363 m .50786 .53268 L .50906 .53082 L F
.177 .036 .439 r
.50612 .53363 m .50608 .53645 L .50786 .53268 L F
.253 0 0 r
.18657 .56244 m .18414 .56324 L .18506 .56201 L F
0 0 0 r
.58297 .56693 m .58274 .56921 L .58255 .57022 L F
0 0 .383 r
.58274 .56921 m .58169 .57356 L .58255 .57022 L F
.701 .233 .136 r
.49132 .53705 m .49 .53858 L .49369 .53912 L F
.474 .294 .556 r
.29598 .59417 m .29607 .5973 L .29381 .59785 L F
.514 .394 .654 r
.29607 .5973 m .29402 .60033 L .29381 .59785 L F
.3 0 .203 r
.49881 .60326 m .49612 .60581 L .49646 .60408 L F
.194 0 .139 r
.53339 .51596 m .53553 .51491 L .53642 .51271 L F
.145 0 .117 r
.53642 .51271 m .53751 .51369 L .53854 .51216 L F
.53642 .51271 m .53553 .51491 L .53751 .51369 L F
.367 .016 .231 r
.22847 .68795 m .22753 .6906 L .22474 .69115 L F
0 0 0 r
.22868 .68884 m .22847 .68795 L .23054 .68734 L F
.22868 .68884 m .22753 .6906 L .22847 .68795 L F
.524 .302 .519 r
.25467 .60649 m .25702 .60608 L .25732 .6036 L F
.475 .26 .506 r
.25732 .6036 m .25925 .60554 L .25934 .60296 L F
.25732 .6036 m .25702 .60608 L .25925 .60554 L F
.254 .533 .919 r
.79513 .39352 m .79422 .39483 L .79201 .39246 L F
.23 .5 .902 r
.79596 .39531 m .79422 .39483 L .79513 .39352 L F
.363 .567 .916 r
.26722 .5784 m .26757 .5795 L .26868 .57811 L F
0 0 .482 r
.26757 .5795 m .26896 .5806 L .26868 .57811 L F
.26757 .5795 m .26796 .58218 L .26896 .5806 L F
.455 .074 .226 r
.42707 .62091 m .43138 .61851 L .42692 .61845 L F
.42707 .62091 m .42983 .62104 L .43138 .61851 L F
.074 .319 .799 r
.43138 .61851 m .43198 .61739 L .42925 .61524 L F
.756 .348 0 r
.43183 .62015 m .43283 .62143 L .43138 .61851 L F
.135 0 .042 r
.43138 .61851 m .43183 .62015 L .43198 .61739 L F
.43138 .61851 m .42983 .62104 L .43183 .62015 L F
.756 .348 0 r
.43183 .62015 m .43138 .61851 L .43198 .61739 L F
.429 .184 .439 r
.26119 .59678 m .26385 .59386 L .26163 .59447 L F
.992 .773 .396 r
.50202 .58554 m .50195 .58903 L .50106 .58701 L F
.874 .608 .533 r
.50563 .58849 m .50362 .59074 L .50195 .58903 L F
.50563 .58849 m .506 .59118 L .50362 .59074 L F
.747 .688 .794 r
.23256 .57649 m .23162 .57962 L .23362 .57968 L F
.584 .031 0 r
.7655 .38146 m .76458 .38062 L .76409 .38159 L F
.902 .734 .665 r
.57481 .51886 m .5717 .52078 L .57185 .51826 L F
.57481 .51886 m .5738 .52187 L .5717 .52078 L F
.606 .465 .663 r
.43774 .62469 m .43809 .62733 L .43558 .62676 L F
.931 .695 .56 r
.43809 .62733 m .43408 .62728 L .43558 .62676 L F
.632 .111 0 r
.4965 .56914 m .49986 .56985 L .49737 .56811 L F
.458 .282 .553 r
.29819 .59591 m .29598 .59417 L .29847 .59396 L F
.29819 .59591 m .29607 .5973 L .29598 .59417 L F
.505 .259 .476 r
.43834 .59739 m .44033 .59892 L .44148 .59742 L F
.156 0 .308 r
.44336 .59633 m .44148 .59742 L .4437 .59447 L F
.44336 .59633 m .44148 .59742 L .4437 .59447 L F
.304 0 0 r
.75039 .37493 m .75136 .37407 L .7476 .37439 L F
0 .397 .743 r
.75299 .37445 m .75377 .37497 L .75136 .37407 L F
.75299 .37445 m .75136 .37407 L .75039 .37493 L F
.966 .713 .279 r
.50587 .53883 m .50444 .53802 L .50397 .53873 L F
.808 .626 .655 r
.7705 .41927 m .76972 .42241 L .7717 .42111 L F
.657 .819 .387 r
.77002 .42397 m .7717 .42111 L .76972 .42241 L F
.425 .119 .341 r
.4709 .61819 m .47327 .61768 L .47379 .61562 L F
.431 .138 .365 r
.47327 .61768 m .47612 .61498 L .47379 .61562 L F
.618 .357 .5 r
.46274 .62152 m .46277 .62411 L .46509 .62378 L F
.654 .35 .445 r
.46274 .62152 m .46509 .62378 L .46548 .62219 L F
.975 .734 .511 r
.57085 .55527 m .57069 .55779 L .56935 .55423 L F
.006 .475 .869 r
.79051 .3987 m .79288 .39895 L .78967 .39768 L F
.79051 .3987 m .79404 .4 L .79288 .39895 L F
.216 .448 .868 r
.28962 .54387 m .28916 .54542 L .28744 .54403 L F
.28962 .54387 m .29064 .54571 L .28916 .54542 L F
0 0 .02 r
.43195 .63489 m .43154 .63411 L .43049 .6331 L F
.43195 .63489 m .43048 .63643 L .43154 .63411 L F
.784 .92 .929 r
.68803 .43357 m .69169 .43166 L .69069 .4305 L F
.749 .91 .947 r
.69069 .4305 m .69169 .43166 L .69346 .43034 L F
.431 .649 .95 r
.1896 .64351 m .19113 .6455 L .19125 .64355 L F
.312 .535 .908 r
.19113 .6455 m .19313 .64604 L .19125 .64355 L F
.923 .844 .396 r
.54049 .58092 m .54051 .58302 L .54137 .57941 L F
.501 .806 .999 r
.54137 .57941 m .54061 .57835 L .54049 .58092 L F
.957 .675 .461 r
.58533 .52581 m .58666 .5248 L .58516 .52176 L F
.973 .723 .495 r
.58514 .52721 m .58666 .5248 L .58533 .52581 L F
.95 .838 .698 r
.58514 .52721 m .58625 .53025 L .58648 .5293 L F
.58514 .52721 m .58648 .5293 L .5874 .52545 L F
.961 .68 .455 r
.58373 .52569 m .58533 .52581 L .58516 .52176 L F
.984 .739 .483 r
.58391 .52565 m .58533 .52581 L .58373 .52569 L F
.58391 .52565 m .58514 .52721 L .58533 .52581 L F
.568 .762 .969 r
.58391 .52565 m .58419 .52571 L .58514 .52721 L F
.95 .838 .698 r
.58644 .5262 m .5874 .52545 L .58776 .52648 L F
.629 .065 0 r
.58776 .52648 m .58666 .5248 L .58514 .52721 L F
.568 .762 .969 r
.58419 .52571 m .58776 .52648 L .58514 .52721 L F
.629 .065 0 r
.58776 .52648 m .5874 .52545 L .58666 .5248 L F
.389 .264 .587 r
.30064 .57647 m .30099 .5788 L .29928 .57868 L F
.507 .665 .933 r
.14937 .59216 m .14823 .59402 L .14735 .59131 L F
.14937 .59216 m .14981 .59403 L .14823 .59402 L F
.93 .681 .198 r
.53935 .56936 m .53959 .57293 L .54013 .57336 L F
.871 .99 .733 r
.54013 .57336 m .53801 .57532 L .54035 .5758 L F
.54013 .57336 m .5399 .57318 L .53801 .57532 L F
.5399 .57318 m .53858 .57445 L .53801 .57532 L F
.5399 .57318 m .53959 .57293 L .53858 .57445 L F
0 0 .236 r
.53959 .57293 m .53991 .57343 L .53823 .5751 L F
.53858 .57445 m .53823 .5751 L .53801 .57532 L F
.53959 .57293 m .53823 .5751 L .53858 .57445 L F
.95 .918 .553 r
.53801 .57532 m .53687 .57728 L .53721 .57486 L F
.53801 .57532 m .53765 .57555 L .53687 .57728 L F
.842 .576 .536 r
.53687 .57728 m .53781 .57519 L .53706 .57591 L F
.95 .918 .553 r
.53765 .57555 m .53647 .5763 L .53687 .57728 L F
.842 .576 .536 r
.53687 .57728 m .53793 .57507 L .53781 .57519 L F
.53687 .57728 m .53709 .57718 L .53793 .57507 L F
.535 .877 .625 r
.53801 .57532 m .53991 .57343 L .53928 .57396 L F
.389 .772 .991 r
.53721 .57486 m .53817 .57515 L .53801 .57532 L F
.842 .576 .536 r
.53709 .57718 m .5382 .57515 L .53817 .57515 L F
.53779 .57544 m .53817 .57515 L .53793 .57507 L F
.535 .877 .625 r
.53801 .57532 m .53817 .57515 L .53765 .57555 L F
.842 .576 .536 r
.53709 .57718 m .53817 .57515 L .53779 .57544 L F
.535 .877 .625 r
.53765 .57555 m .53928 .57396 L .53647 .5763 L F
.53817 .57515 m .53928 .57396 L .53765 .57555 L F
.389 .772 .991 r
.53817 .57515 m .54035 .5758 L .53801 .57532 L F
.842 .576 .536 r
.53709 .57718 m .54035 .5758 L .5382 .57515 L F
.53706 .57591 m .53793 .57507 L .53721 .57486 L F
0 .173 .704 r
.40858 .63372 m .40917 .63257 L .40703 .63031 L F
0 .086 .638 r
.40858 .63372 m .41047 .63602 L .40917 .63257 L F
.627 .644 .848 r
.82296 .44333 m .82426 .43898 L .82092 .44047 L F
.82296 .44333 m .82594 .44364 L .82426 .43898 L F
.665 .729 .898 r
.177 .61384 m .17436 .61462 L .17248 .61184 L F
.342 .015 .257 r
.55195 .50035 m .55415 .50018 L .55503 .49774 L F
.489 .151 .32 r
.55503 .49774 m .55763 .49925 L .55757 .49752 L F
.55503 .49774 m .55415 .50018 L .55763 .49925 L F
.503 .163 .323 r
.55503 .49774 m .55757 .49752 L .55798 .49671 L F
.807 .535 0 r
.52554 .55067 m .52618 .55298 L .52513 .54867 L F
.709 .178 0 r
.52554 .55067 m .52863 .55237 L .52618 .55298 L F
.642 .668 .86 r
.65825 .43774 m .65516 .43861 L .65448 .43691 L F
0 .04 .568 r
.26804 .56719 m .26889 .57031 L .2695 .56879 L F
.815 .901 .902 r
.21618 .69621 m .21486 .69939 L .21562 .69899 L F
.267 0 0 r
.22369 .62952 m .22591 .62954 L .22818 .6284 L F
0 0 0 r
.22818 .6284 m .2281 .62882 L .23025 .62769 L F
.22818 .6284 m .22591 .62954 L .2281 .62882 L F
.662 .747 .913 r
.23361 .55258 m .23706 .55514 L .2342 .55335 L F
.23361 .55258 m .23364 .55268 L .23442 .55324 L F
.23611 .55444 m .23442 .55324 L .23706 .55514 L F
.23361 .55258 m .23442 .55324 L .23611 .55444 L F
.738 .302 0 r
.23361 .55258 m .23249 .55115 L .23113 .55081 L F
.23361 .55258 m .2342 .55335 L .23249 .55115 L F
.454 0 0 r
.23634 .55228 m .23249 .55115 L .23375 .55277 L F
.23442 .55324 m .23375 .55277 L .2342 .55335 L F
.23634 .55228 m .23375 .55277 L .23442 .55324 L F
.525 .774 .988 r
.23706 .55514 m .23634 .55228 L .23442 .55324 L F
.23706 .55514 m .23442 .55324 L .2342 .55335 L F
.662 .747 .913 r
.23364 .55268 m .23429 .55529 L .23706 .55514 L F
.782 .652 .719 r
.23417 .55791 m .23706 .55514 L .23429 .55529 L F
0 0 0 r
.57398 .59828 m .5734 .59739 L .57547 .59645 L F
.57398 .59828 m .57277 .59935 L .5734 .59739 L F
.576 .709 .933 r
.73807 .39927 m .73436 .39807 L .73694 .39737 L F
.617 .661 .87 r
.7395 .39647 m .73807 .39927 L .73694 .39737 L F
.7395 .39647 m .74064 .3985 L .73807 .39927 L F
.815 .385 0 r
.53355 .56086 m .5349 .56362 L .53574 .56418 L F
0 0 .53 r
.5349 .56362 m .537 .56684 L .53574 .56418 L F
0 0 .383 r
.58274 .56921 m .58284 .57209 L .58169 .57356 L F
0 0 .015 r
.58214 .57428 m .58169 .57356 L .58284 .57209 L F
.58214 .57428 m .5811 .57585 L .58169 .57356 L F
.86 .796 .786 r
.43618 .57328 m .43209 .57482 L .43479 .57414 L F
.639 .583 .776 r
.43618 .57328 m .43849 .57337 L .44003 .57048 L F
.335 0 0 r
.43695 .57433 m .43618 .57328 L .43479 .57414 L F
.743 .642 .747 r
.70999 .41366 m .712 .4125 L .71112 .40952 L F
.72 .628 .755 r
.71112 .40952 m .712 .4125 L .7146 .40974 L F
.571 .185 .272 r
.55768 .50973 m .55403 .51172 L .55402 .51065 L F
.55768 .50973 m .55632 .51194 L .55403 .51172 L F
.625 .246 .304 r
.56025 .51156 m .55768 .50973 L .56017 .50955 L F
.56025 .51156 m .55632 .51194 L .55768 .50973 L F
.713 .795 .916 r
.24256 .55527 m .2446 .55706 L .24624 .55659 L F
.247 0 .055 r
.16459 .55466 m .16523 .55629 L .16594 .55463 L F
.16459 .55466 m .16309 .55692 L .16523 .55629 L F
.159 .168 .619 r
.39896 .61828 m .39922 .62209 L .40075 .62028 L F
.036 .161 .666 r
.39922 .62209 m .4012 .62283 L .40075 .62028 L F
.39922 .62209 m .40046 .62429 L .4012 .62283 L F
.435 .21 .472 r
.71395 .40422 m .71623 .40316 L .71636 .40139 L F
.698 .608 .752 r
.71354 .40642 m .71623 .40316 L .71395 .40422 L F
.392 .479 .83 r
.15554 .62445 m .1532 .62132 L .15481 .62435 L F
.588 .653 .881 r
.83757 .42786 m .834 .42407 L .83469 .42652 L F
.83757 .42786 m .83679 .42354 L .834 .42407 L F
.785 .924 .929 r
.83757 .42786 m .83901 .4238 L .83679 .42354 L F
.83757 .42786 m .8405 .42444 L .83901 .4238 L F
.883 .855 .401 r
.59029 .51343 m .59113 .50898 L .58891 .51224 L F
.021 .477 .876 r
.59105 .5137 m .59029 .51343 L .58891 .51224 L F
.995 .813 .45 r
.51818 .59951 m .51793 .60279 L .51891 .60373 L F
.988 .785 .542 r
.51698 .60496 m .51891 .60373 L .51793 .60279 L F
.51698 .60496 m .51831 .60597 L .51891 .60373 L F
0 0 .337 r
.58142 .57846 m .58126 .58092 L .57967 .58238 L F
0 0 .187 r
.58126 .58092 m .57953 .58488 L .57967 .58238 L F
.304 0 0 r
.75039 .37493 m .7476 .37439 L .74822 .37492 L F
.26 .77 .816 r
.20167 .5395 m .20382 .539 L .2054 .53888 L F
.462 .888 .889 r
.2054 .53888 m .20675 .53785 L .2078 .53859 L F
.2054 .53888 m .20382 .539 L .20675 .53785 L F
.792 .715 .779 r
.75176 .40925 m .75508 .40965 L .75496 .40662 L F
.75176 .40925 m .75335 .41062 L .75508 .40965 L F
.851 .877 .859 r
.75496 .40662 m .75508 .40965 L .7577 .40638 L F
0 0 0 r
.50786 .53268 m .51094 .53031 L .50906 .53082 L F
.761 .614 .696 r
.51094 .53031 m .50786 .53268 L .50906 .53082 L F
.752 .623 .716 r
.69889 .42216 m .70267 .42272 L .70127 .41918 L F
.78 .663 .733 r
.69882 .4246 m .70267 .42272 L .69889 .42216 L F
.489 .563 .857 r
.1716 .63401 m .17314 .63719 L .17437 .63495 L F
.436 .497 .823 r
.17437 .63495 m .17314 .63719 L .17442 .63701 L F
.914 .58 .397 r
.43735 .58086 m .43587 .5784 L .43764 .57949 L F
.277 0 .091 r
.44007 .579 m .43735 .58086 L .43764 .57949 L F
.102 0 0 r
.54563 .51567 m .54231 .51735 L .54322 .51629 L F
.794 .604 .644 r
.42034 .60583 m .42416 .6089 L .42184 .60625 L F
.707 .487 .588 r
.42184 .60625 m .42416 .6089 L .42447 .60652 L F
.835 .537 .486 r
.81398 .44651 m .81104 .44783 L .81057 .44609 L F
.81398 .44651 m .81438 .44891 L .81104 .44783 L F
.701 .197 .037 r
.66725 .41649 m .66593 .41725 L .66558 .41542 L F
.66725 .41649 m .66978 .41837 L .66593 .41725 L F
.833 .79 .811 r
.73496 .38362 m .73383 .38637 L .73249 .38636 L F
.687 .222 .141 r
.73249 .38636 m .73383 .38637 L .73471 .3881 L F
.075 0 .396 r
.73719 .38279 m .73383 .38637 L .73496 .38362 L F
.099 0 .426 r
.73471 .3881 m .73383 .38637 L .73719 .38279 L F
.668 .537 .696 r
.71623 .40316 m .71877 .4005 L .71636 .40139 L F
.26 .057 .403 r
.25218 .60955 m .25345 .61114 L .25393 .60872 L F
.25218 .60955 m .25175 .61198 L .25345 .61114 L F
.802 .789 .841 r
.69631 .4277 m .70029 .42624 L .69882 .4246 L F
.892 .695 .628 r
.50018 .54914 m .49819 .54895 L .49735 .54817 L F
.787 .348 .208 r
.50018 .54914 m .49877 .55046 L .49819 .54895 L F
.344 0 0 r
.50311 .55069 m .49877 .55046 L .50018 .54914 L F
.595 .166 0 r
.49821 .53794 m .49757 .53694 L .49617 .53712 L F
.49821 .53794 m .50004 .54067 L .49757 .53694 L F
.847 .434 .254 r
.49757 .53694 m .50004 .54067 L .50151 .54052 L F
.847 .649 .635 r
.58384 .50281 m .58736 .50096 L .58654 .50054 L F
.58384 .50281 m .58732 .50361 L .58736 .50096 L F
.786 .432 .387 r
.68161 .41536 m .68403 .41816 L .68525 .4161 L F
.763 .403 .373 r
.68525 .4161 m .68403 .41816 L .68759 .41863 L F
.004 0 0 r
.27145 .57 m .27323 .56927 L .27457 .56751 L F
.579 .169 .23 r
.27457 .56751 m .27622 .56913 L .2766 .56674 L F
.27457 .56751 m .27323 .56927 L .27622 .56913 L F
.493 .266 .498 r
.27684 .62154 m .27655 .62397 L .27428 .62452 L F
.471 .257 .506 r
.2793 .61858 m .27911 .62101 L .27684 .62154 L F
.507 .297 .528 r
.27911 .62101 m .27655 .62397 L .27684 .62154 L F
.451 .798 .998 r
.271 .53996 m .27319 .53956 L .27485 .54045 L F
.239 .714 .939 r
.27319 .53956 m .27697 .5401 L .27485 .54045 L F
.688 .5 .628 r
.42416 .6089 m .42666 .60579 L .42447 .60652 L F
.649 .626 .813 r
.42416 .6089 m .42543 .61167 L .42762 .60947 L F
.607 .567 .784 r
.42543 .61167 m .42834 .61125 L .42762 .60947 L F
.766 .348 0 r
.51027 .58381 m .51001 .58258 L .5087 .58153 L F
.51027 .58381 m .51101 .5846 L .51001 .58258 L F
.659 .598 .775 r
.66422 .40933 m .66533 .4131 L .66267 .41316 L F
.239 0 0 r
.66533 .4131 m .66163 .41469 L .66267 .41316 L F
.398 .201 .494 r
.29402 .60033 m .29387 .60289 L .29177 .60349 L F
.505 .28 .507 r
.29384 .60551 m .29177 .60349 L .29387 .60289 L F
.29384 .60551 m .29149 .60609 L .29177 .60349 L F
.534 .592 .859 r
.80251 .4098 m .79864 .40718 L .80006 .41029 L F
.495 .277 .512 r
.28141 .62037 m .2793 .61858 L .28148 .61809 L F
.28141 .62037 m .27911 .62101 L .2793 .61858 L F
.838 .484 .385 r
.41718 .64755 m .41923 .65068 L .421 .6489 L F
.672 .252 .24 r
.421 .6489 m .41923 .65068 L .42335 .65088 L F
.591 .304 .449 r
.421 .6489 m .42335 .65088 L .42358 .64853 L F
.713 .587 .713 r
.70618 .41321 m .70999 .41366 L .70866 .4101 L F
.743 .642 .747 r
.70999 .41366 m .71112 .40952 L .70866 .4101 L F
.489 .284 .527 r
.24462 .61784 m .24671 .61739 L .24692 .61539 L F
.291 0 .258 r
.24462 .61784 m .24549 .62002 L .24671 .61739 L F
.24462 .61784 m .24352 .62079 L .24549 .62002 L F
.525 .774 .988 r
.23706 .55514 m .23995 .55464 L .23634 .55228 L F
.475 .5 .805 r
.23706 .55514 m .23951 .55622 L .23995 .55464 L F
.713 .795 .916 r
.24256 .55527 m .24624 .55659 L .24401 .55451 L F
.483 .748 .987 r
.24624 .55659 m .2459 .5542 L .24401 .55451 L F
.24624 .55659 m .24871 .556 L .2459 .5542 L F
.493 .36 .628 r
.30207 .55442 m .30014 .55776 L .30021 .55502 L F
.108 0 .007 r
.25393 .60872 m .25702 .60608 L .25467 .60649 L F
0 0 0 r
.45224 .6392 m .4504 .64134 L .45119 .64012 L F
.547 .829 .998 r
.19192 .62157 m .18784 .62119 L .1899 .62072 L F
0 .198 .639 r
.19207 .62151 m .19192 .62157 L .1899 .62072 L F
.19207 .62151 m .1941 .62298 L .19192 .62157 L F
.267 .774 .801 r
.78947 .43814 m .79207 .43747 L .79352 .43747 L F
.413 .107 .334 r
.26532 .63523 m .26374 .63361 L .26609 .63332 L F
.26532 .63523 m .26292 .63608 L .26374 .63361 L F
.255 0 0 r
.17119 .56982 m .16941 .57167 L .16708 .57203 L F
.684 .356 .414 r
.17332 .56946 m .16941 .57167 L .17119 .56982 L F
.665 .232 .211 r
.57622 .49657 m .57858 .4968 L .57622 .49506 L F
.59 .311 .461 r
.57622 .49506 m .57858 .4968 L .57895 .49477 L F
.104 0 .178 r
.40021 .61254 m .40224 .61174 L .40302 .60917 L F
.343 .129 .438 r
.4 .61433 m .40224 .61174 L .40021 .61254 L F
.935 .696 .553 r
.23962 .66691 m .2375 .66766 L .23641 .66691 L F
.13 .677 .804 r
.23641 .66691 m .23855 .66678 L .2387 .66691 L F
.568 .368 .57 r
.23641 .66691 m .2375 .66766 L .23855 .66678 L F
.596 .92 .685 r
.23855 .66678 m .2375 .66766 L .23852 .66676 L F
.23855 .66678 m .23852 .66676 L .23997 .6655 L F
.13 .677 .804 r
.2387 .66691 m .23855 .66678 L .23962 .66691 L F
.935 .696 .553 r
.23962 .66691 m .23927 .66945 L .2375 .66766 L F
.73 .99 .868 r
.23962 .66691 m .23855 .66678 L .23997 .6655 L F
.935 .696 .553 r
.2375 .66766 m .23962 .66691 L .23997 .6655 L F
.2375 .66766 m .23927 .66945 L .23962 .66691 L F
0 0 .222 r
.77177 .41973 m .7705 .41927 L .7698 .4179 L F
.77177 .41973 m .76972 .42241 L .7705 .41927 L F
.49 .649 .929 r
.24535 .65689 m .24333 .65793 L .24089 .65621 L F
.283 .139 .502 r
.24528 .65951 m .24333 .65793 L .24535 .65689 L F
.24528 .65951 m .243 .66067 L .24333 .65793 L F
.531 .563 .832 r
.30379 .54687 m .30194 .54922 L .30071 .54721 L F
.30379 .54687 m .30431 .54915 L .30194 .54922 L F
.379 0 .144 r
.55402 .51065 m .55403 .51172 L .55145 .51216 L F
.83 .646 .653 r
.82845 .43091 m .83058 .43156 L .82873 .42805 L F
.8 .587 .614 r
.82685 .43372 m .83058 .43156 L .82845 .43091 L F
.82685 .43372 m .83026 .43412 L .83058 .43156 L F
.728 .613 .729 r
.82873 .42805 m .83058 .43156 L .83273 .42875 L F
.396 .823 .963 r
.23693 .53704 m .23658 .53811 L .23453 .53697 L F
.23693 .53704 m .23875 .53763 L .23658 .53811 L F
.975 .712 .466 r
.81043 .44344 m .80964 .44633 L .80692 .44278 L F
.81043 .44344 m .81057 .44609 L .80964 .44633 L F
.403 .177 .454 r
.44112 .62409 m .44301 .62369 L .44301 .62182 L F
.577 .458 .681 r
.44112 .62409 m .44411 .62723 L .44301 .62369 L F
.44112 .62409 m .44158 .62778 L .44411 .62723 L F
.476 .836 .579 r
.23686 .6236 m .23902 .62191 L .23616 .62423 L F
.318 0 0 r
.24002 .62279 m .23902 .62191 L .23686 .6236 L F
.275 0 0 r
.24002 .62279 m .2414 .62143 L .23902 .62191 L F
.704 .571 .702 r
.70351 .41312 m .70368 .41617 L .70618 .41321 L F
.418 .096 .31 r
.42408 .63317 m .42613 .63275 L .42775 .63056 L F
.641 .359 .475 r
.42613 .63275 m .43049 .6331 L .42775 .63056 L F
.618 .953 .92 r
.45086 .5763 m .44812 .57765 L .44997 .57754 L F
0 0 0 r
.44951 .57708 m .44899 .57732 L .44812 .57765 L F
.21 .736 .799 r
.44997 .57754 m .44812 .57765 L .44764 .57783 L F
0 0 0 r
.44899 .57732 m .44735 .57806 L .44812 .57765 L F
.21 .736 .799 r
.44764 .57783 m .44812 .57765 L .44599 .57804 L F
.618 .953 .92 r
.45086 .5763 m .44997 .57754 L .45236 .5765 L F
.656 .836 .969 r
.48052 .56545 m .48169 .56681 L .48409 .56547 L F
.653 .97 .837 r
.17605 .54916 m .17681 .54811 L .17782 .54763 L F
.551 .213 .348 r
.17384 .55012 m .17681 .54811 L .17605 .54916 L F
.329 .318 .695 r
.41227 .63917 m .41483 .64145 L .41587 .6399 L F
.66 .196 .14 r
.41587 .6399 m .41483 .64145 L .41817 .64175 L F
.195 .033 .421 r
.26645 .57324 m .26768 .57496 L .26875 .57224 L F
.26645 .57324 m .26575 .57638 L .26768 .57496 L F
.95 .903 .742 r
.5709 .54871 m .57099 .54526 L .57213 .54629 L F
.156 0 .362 r
.15846 .5808 m .15686 .57968 L .1593 .57874 L F
.15846 .5808 m .15642 .58203 L .15686 .57968 L F
.333 .053 .33 r
.24295 .64608 m .24462 .64305 L .2422 .64436 L F
.577 .243 .367 r
.24462 .64305 m .24603 .64694 L .2422 .64436 L F
.24462 .64305 m .2468 .64279 L .24603 .64694 L F
.505 .259 .476 r
.43834 .59739 m .43803 .59958 L .44033 .59892 L F
.49 .827 .999 r
.33301 .75919 m .33229 .76049 L .33476 .76003 L F
.33301 .75919 m .33229 .76049 L .33476 .76003 L F
.914 .628 .488 r
.4295 .63663 m .43048 .63643 L .43034 .63652 L F
.42936 .63664 m .43048 .63643 L .4295 .63663 L F
.781 .56 .6 r
.43024 .63659 m .43195 .63489 L .42953 .63663 L F
.43024 .63659 m .42953 .63663 L .4294 .63673 L F
.914 .628 .488 r
.42918 .63668 m .42936 .63664 L .4295 .63663 L F
.42682 .63699 m .4285 .63673 L .42918 .63668 L F
.4285 .63673 m .43048 .63643 L .42918 .63668 L F
.612 .466 .658 r
.42921 .63667 m .4294 .63673 L .42942 .63664 L F
.084 .567 .901 r
.43024 .63659 m .4294 .63673 L .42921 .63667 L F
.612 .466 .658 r
.42694 .63606 m .42921 .63667 L .43049 .6331 L F
.42921 .63667 m .42942 .63664 L .43049 .6331 L F
.519 .371 .619 r
.43049 .6331 m .42942 .63664 L .43195 .63489 L F
.42942 .63664 m .4294 .63673 L .42953 .63663 L F
.42942 .63664 m .42953 .63663 L .43195 .63489 L F
.914 .628 .488 r
.42709 .63696 m .42942 .63664 L .43024 .63659 L F
.42942 .63664 m .43034 .63652 L .43033 .63653 L F
.42942 .63664 m .43033 .63653 L .43024 .63659 L F
.084 .567 .901 r
.43024 .63659 m .42921 .63667 L .42694 .63606 L F
.914 .628 .488 r
.42682 .63699 m .43034 .63652 L .42709 .63696 L F
.781 .56 .6 r
.43195 .63489 m .43024 .63659 L .43048 .63643 L F
.643 .374 .497 r
.5637 .49698 m .5665 .49481 L .56372 .49474 L F
.056 .189 .687 r
.52948 .52543 m .53048 .52403 L .52833 .52151 L F
.544 .864 .995 r
.52948 .52543 m .53203 .52465 L .53048 .52403 L F
.721 .633 .758 r
.82873 .42805 m .83273 .42875 L .83132 .42494 L F
.729 .636 .755 r
.83132 .42494 m .83273 .42875 L .83469 .42652 L F
.525 0 0 r
.50004 .54067 m .49979 .54118 L .50151 .54052 L F
.248 0 0 r
.50151 .54052 m .50255 .5411 L .50397 .53873 L F
.50151 .54052 m .49979 .54118 L .50255 .5411 L F
.647 .274 .324 r
.43033 .60623 m .4326 .60812 L .43423 .60586 L F
.638 .263 .317 r
.43423 .60586 m .43622 .60803 L .43677 .60677 L F
.43423 .60586 m .4326 .60812 L .43622 .60803 L F
.388 .049 .264 r
.74322 .38056 m .74544 .38141 L .74286 .38199 L F
.74322 .38056 m .74614 .37972 L .74544 .38141 L F
.206 .698 .921 r
.24317 .5372 m .24262 .53788 L .24098 .53726 L F
.24317 .5372 m .24502 .53776 L .24262 .53788 L F
.573 .027 0 r
.50469 .55153 m .5057 .55285 L .50311 .55069 L F
.50469 .55153 m .50703 .55373 L .5057 .55285 L F
.776 .27 0 r
.51523 .59718 m .51669 .59768 L .51382 .59573 L F
.669 .156 0 r
.51691 .59852 m .51669 .59768 L .51523 .59718 L F
.51691 .59852 m .51818 .59951 L .51669 .59768 L F
.558 .817 .994 r
.19518 .64525 m .19739 .6466 L .19899 .64597 L F
.652 .605 .788 r
.82848 .41265 m .832 .41359 L .83229 .41544 L F
.612 .576 .79 r
.832 .41359 m .83461 .41288 L .83229 .41544 L F
.754 .237 0 r
.47591 .55673 m .47941 .55925 L .47713 .55956 L F
.933 .697 .559 r
.43809 .62733 m .43779 .63019 L .43952 .63072 L F
.43809 .62733 m .43779 .63019 L .43952 .63072 L F
.163 0 0 r
.20863 .73009 m .20657 .73116 L .20636 .73148 L F
.20863 .73009 m .20636 .73148 L .20638 .73135 L F
0 0 0 r
.20638 .73135 m .20657 .73116 L .20863 .73009 L F
.163 0 0 r
.20863 .73009 m .20638 .73135 L .20669 .72812 L F
0 0 0 r
.20616 .73157 m .20638 .73135 L .20863 .73009 L F
.502 .632 .91 r
.2304 .67856 m .23218 .68129 L .2302 .6817 L F
.148 .322 .783 r
.23279 .6838 m .2302 .6817 L .23218 .68129 L F
0 .224 .744 r
.5575 .59029 m .5575 .59163 L .55506 .5878 L F
.5575 .59029 m .55835 .59164 L .5575 .59163 L F
.784 .92 .929 r
.68803 .43357 m .69069 .4305 L .68783 .43327 L F
.858 .541 .017 r
.44683 .65117 m .44666 .65119 L .44584 .64836 L F
.44683 .65117 m .44666 .65119 L .44584 .64836 L F
.675 .133 0 r
.76968 .38481 m .76823 .38331 L .7655 .38146 L F
0 0 .248 r
.44605 .59617 m .44515 .60043 L .44336 .59633 L F
.44605 .59617 m .44604 .59878 L .44515 .60043 L F
.39 .679 .975 r
.44604 .59878 m .44731 .60036 L .44515 .60043 L F
.577 .589 .828 r
.44932 .60319 m .44515 .60043 L .44731 .60036 L F
.484 .178 .372 r
.80174 .43381 m .80436 .43344 L .80426 .43152 L F
.646 .604 .792 r
.80301 .42709 m .80426 .43152 L .80674 .42783 L F
.64 .595 .788 r
.80674 .42783 m .80426 .43152 L .80746 .43057 L F
.524 .233 .414 r
.80436 .43344 m .80746 .43057 L .80426 .43152 L F
.61 .663 .877 r
.82639 .40585 m .82509 .40966 L .82378 .40622 L F
.82639 .40585 m .82755 .40901 L .82509 .40966 L F
.495 .795 .999 r
.72585 .39118 m .72687 .39227 L .72321 .39165 L F
.533 .815 .998 r
.72934 .39168 m .72687 .39227 L .72585 .39118 L F
.663 .714 .886 r
.7441 .39977 m .74064 .3985 L .74355 .39765 L F
.816 .838 .866 r
.74601 .39756 m .7441 .39977 L .74355 .39765 L F
0 0 .227 r
.57937 .58728 m .57914 .58952 L .57809 .59095 L F
0 0 .028 r
.57914 .58952 m .57773 .59329 L .57809 .59095 L F
.55 .861 .996 r
.22199 .64684 m .22611 .64674 L .22394 .64615 L F
.765 .907 .938 r
.22394 .64615 m .22611 .64674 L .22786 .64526 L F
.075 0 .396 r
.73721 .38277 m .73496 .38362 L .73793 .38208 L F
.694 .292 .281 r
.73793 .38208 m .7379 .38593 L .73745 .38392 L F
.73721 .38277 m .73745 .38392 L .73719 .38279 L F
.73793 .38208 m .73745 .38392 L .73721 .38277 L F
.73793 .38208 m .74046 .38293 L .7379 .38593 L F
.371 .3 .646 r
.73814 .38014 m .73683 .38096 L .73811 .38239 L F
.73683 .38096 m .73625 .38132 L .73699 .38175 L F
.73683 .38096 m .73699 .38175 L .73811 .38239 L F
.73842 .38225 m .73811 .38239 L .73847 .38259 L F
.73814 .38014 m .73811 .38239 L .73842 .38225 L F
.075 0 .396 r
.73719 .38279 m .73704 .38284 L .73721 .38277 L F
.73704 .38284 m .73496 .38362 L .73721 .38277 L F
.669 .434 .555 r
.44301 .62369 m .44654 .62133 L .44301 .62182 L F
.941 .789 .665 r
.5734 .53044 m .57114 .53007 L .57219 .52681 L F
.919 .726 .626 r
.5734 .53044 m .57037 .53247 L .57114 .53007 L F
.5734 .53044 m .57219 .53336 L .57037 .53247 L F
.215 .149 .563 r
.45769 .58384 m .45799 .58586 L .4586 .58323 L F
.634 .201 .202 r
.41855 .60712 m .41899 .60853 L .42002 .60857 L F
.366 .223 .552 r
.41855 .60712 m .42002 .60857 L .42034 .60583 L F
.271 0 0 r
.42642 .65708 m .42861 .65774 L .42604 .65701 L F
.493 0 0 r
.43195 .65791 m .42861 .65774 L .42642 .65708 L F
.191 0 0 r
.45837 .56407 m .46091 .56355 L .46216 .56244 L F
.094 0 0 r
.46091 .56355 m .46373 .56236 L .46216 .56244 L F
.066 0 0 r
.46216 .56244 m .46373 .56236 L .46481 .5618 L F
.704 .642 .784 r
.23005 .57516 m .23162 .57962 L .23256 .57649 L F
.38 .053 .279 r
.40224 .61174 m .40548 .60857 L .40302 .60917 L F
.486 .256 .49 r
.27428 .62452 m .2738 .62741 L .27169 .62769 L F
.473 .237 .476 r
.27655 .62397 m .2738 .62741 L .27428 .62452 L F
.752 .743 .844 r
.42121 .65432 m .42159 .65737 L .42238 .65476 L F
.169 .26 .715 r
.42238 .65476 m .4236 .65352 L .42121 .65432 L F
.988 .885 .557 r
.77047 .41036 m .77153 .41001 L .77135 .40969 L F
.77047 .41036 m .77101 .4122 L .77153 .41001 L F
.791 .922 .542 r
.77237 .4078 m .77135 .40969 L .77153 .41001 L F
.667 .502 .652 r
.46226 .59144 m .46436 .59138 L .46458 .58848 L F
.563 .412 .634 r
.46458 .58848 m .46436 .59138 L .46706 .58797 L F
0 .218 .733 r
.48738 .568 m .48815 .56806 L .48703 .56587 L F
.621 .809 .973 r
.42515 .66691 m .4212 .66643 L .42363 .66337 L F
.78 .615 .676 r
.4212 .66643 m .42515 .66691 L .42374 .66644 L F
.4212 .66643 m .422 .67143 L .42515 .66691 L F
0 0 .414 r
.42421 .66407 m .42515 .66691 L .42363 .66337 L F
.902 .943 .825 r
.42374 .66644 m .42515 .66691 L .42421 .66407 L F
.83 .871 .875 r
.54888 .59042 m .55308 .58932 L .54895 .5901 L F
.54888 .59042 m .55081 .58856 L .55308 .58932 L F
.377 0 0 r
.55081 .58856 m .55506 .5878 L .55308 .58932 L F
.981 .707 .43 r
.51316 .58826 m .51428 .59114 L .51374 .58849 L F
.51316 .58826 m .51321 .59049 L .51428 .59114 L F
.999 .801 .465 r
.51312 .59343 m .51428 .59114 L .51321 .59049 L F
.51312 .59343 m .51409 .59444 L .51428 .59114 L F
.286 0 0 r
.50585 .52378 m .50829 .5234 L .50982 .52144 L F
.165 0 0 r
.50982 .52144 m .51067 .52261 L .5097 .52436 L F
.50982 .52144 m .50829 .5234 L .51067 .52261 L F
.343 .414 .79 r
.25145 .55541 m .25308 .55617 L .25261 .55495 L F
.25145 .55541 m .25261 .55495 L .25176 .55271 L F
.394 .829 .954 r
.25001 .55598 m .25145 .55541 L .24871 .556 L F
.25305 .55595 m .25145 .55541 L .25001 .55598 L F
0 .216 .622 r
.51507 .56112 m .51638 .56185 L .51436 .55975 L F
.51507 .56112 m .51829 .56299 L .51638 .56185 L F
0 .242 .668 r
.51949 .56386 m .51829 .56299 L .51507 .56112 L F
.159 .168 .619 r
.39896 .61828 m .40075 .62028 L .40067 .61774 L F
.84 .959 .887 r
.74934 .39293 m .74613 .39441 L .74725 .39283 L F
.739 .916 .953 r
.75069 .39054 m .74934 .39293 L .74725 .39283 L F
.75069 .39054 m .75165 .39153 L .74934 .39293 L F
.133 0 0 r
.15032 .59396 m .15282 .59433 L .15445 .59448 L F
0 0 .554 r
.15484 .59407 m .15445 .59448 L .15282 .59433 L F
.15484 .59407 m .15608 .59666 L .15445 .59448 L F
.769 .292 .104 r
.41044 .62825 m .41153 .62889 L .4123 .629 L F
.979 .878 .508 r
.4123 .629 m .41255 .63069 L .41302 .6291 L F
.065 .432 .873 r
.41485 .63086 m .41255 .63069 L .4123 .629 L F
.769 .292 .104 r
.41153 .62889 m .41485 .63086 L .4123 .629 L F
.979 .878 .508 r
.4123 .629 m .41302 .6291 L .41341 .62776 L F
.951 .621 .36 r
.41177 .62676 m .4123 .629 L .41341 .62776 L F
.494 .406 .685 r
.41499 .62466 m .41535 .62731 L .41341 .62776 L F
.41341 .62776 m .41535 .62731 L .41499 .62466 L F
.417 .324 .642 r
.48933 .58823 m .49127 .58444 L .48873 .58563 L F
.616 .711 .913 r
.6559 .44234 m .65705 .43894 L .65447 .43941 L F
.6559 .44234 m .65802 .44161 L .65705 .43894 L F
.63 .382 .525 r
.66029 .40665 m .66277 .4065 L .66265 .40415 L F
.688 .5 .628 r
.42416 .6089 m .42762 .60947 L .42666 .60579 L F
.457 .207 .446 r
.42762 .60947 m .43033 .60623 L .42666 .60579 L F
.743 .751 .858 r
.74975 .41018 m .75335 .41062 L .75176 .40925 L F
0 .203 .72 r
.21501 .70791 m .21469 .7091 L .21585 .71001 L F
.585 .939 .79 r
.19135 .55922 m .19066 .56026 L .19382 .55926 L F
.19135 .55922 m .1897 .56048 L .19066 .56026 L F
.819 .623 .638 r
.44657 .62676 m .45182 .62991 L .44943 .62655 L F
.44657 .62676 m .44676 .6292 L .45182 .62991 L F
.379 0 0 r
.44623 .63056 m .45182 .62991 L .44637 .63017 L F
.434 .312 .614 r
.44639 .63063 m .44523 .63579 L .44716 .63499 L F
.44638 .63062 m .44523 .63579 L .44639 .63063 L F
.346 .256 .61 r
.44631 .63058 m .44639 .63063 L .45169 .63119 L F
.44639 .63063 m .44993 .63318 L .45076 .63225 L F
.44639 .63063 m .45076 .63225 L .45169 .63119 L F
.434 .312 .614 r
.44638 .63059 m .44638 .63062 L .44639 .63063 L F
.379 0 0 r
.44621 .63057 m .44648 .6306 L .44623 .63056 L F
.434 .312 .614 r
.44633 .63028 m .44627 .63057 L .44638 .63059 L F
.379 0 0 r
.44623 .63056 m .44626 .63057 L .44624 .63056 L F
.534 .406 .653 r
.44633 .63028 m .44627 .63057 L .44633 .63028 L F
.44627 .63057 m .44627 .63057 L .44633 .63028 L F
.44285 .63602 m .44439 .63587 L .44633 .63028 L F
.379 0 0 r
.44621 .63057 m .44623 .63056 L .44637 .63017 L F
.434 .312 .614 r
.44633 .63028 m .44639 .63063 L .44621 .63057 L F
.44624 .63072 m .44523 .63579 L .4463 .63098 L F
.44624 .63072 m .4463 .63098 L .44638 .63059 L F
.44627 .63057 m .44624 .63072 L .44638 .63059 L F
.534 .406 .653 r
.44627 .63057 m .44523 .63579 L .44627 .63057 L F
.379 0 0 r
.44624 .63056 m .45169 .63119 L .45182 .62991 L F
.44626 .63057 m .45169 .63119 L .44624 .63056 L F
.44648 .6306 m .45169 .63119 L .44623 .63056 L F
.534 .406 .653 r
.44439 .63587 m .44523 .63579 L .44633 .63028 L F
.434 .312 .614 r
.44639 .63063 m .44716 .63499 L .44621 .63057 L F
.346 .256 .61 r
.44621 .63057 m .44935 .63384 L .44993 .63318 L F
.44621 .63057 m .44993 .63318 L .44631 .63058 L F
.379 0 0 r
.44637 .63017 m .45182 .62991 L .44676 .6292 L F
0 0 .118 r
.45182 .62991 m .45375 .62645 L .44943 .62655 L F
.45182 .62991 m .45308 .62932 L .45375 .62645 L F
.634 .481 .657 r
.45169 .63119 m .45308 .62932 L .45182 .62991 L F
.396 .184 .47 r
.24671 .61739 m .24914 .61471 L .24692 .61539 L F
.535 .577 .843 r
.55373 .57924 m .55751 .58216 L .55662 .57913 L F
.724 .6 .718 r
.71112 .40952 m .7146 .40974 L .71354 .40642 L F
.701 .587 .725 r
.71354 .40642 m .7146 .40974 L .71712 .40673 L F
.832 .554 .517 r
.58224 .49742 m .58226 .4996 L .58654 .50054 L F
.835 .617 .607 r
.58226 .4996 m .58384 .50281 L .58654 .50054 L F
.908 .906 .502 r
.20262 .7196 m .20149 .72122 L .20302 .71806 L F
.961 .652 .396 r
.20262 .7196 m .20079 .72259 L .20149 .72122 L F
.20262 .7196 m .20254 .72331 L .20144 .72286 L F
.20262 .7196 m .20144 .72286 L .20158 .7213 L F
.571 .267 .415 r
.20161 .72097 m .20484 .72008 L .20302 .71806 L F
.20149 .72122 m .20159 .72119 L .20161 .72097 L F
.20159 .72119 m .20484 .72008 L .20161 .72097 L F
.961 .652 .396 r
.20158 .7213 m .20144 .72286 L .20079 .72259 L F
.647 .897 .568 r
.14957 .58862 m .1478 .59062 L .14735 .59131 L F
.507 .665 .933 r
.14937 .59216 m .14735 .59131 L .1478 .59062 L F
.431 .705 .98 r
.20935 .62996 m .20521 .62843 L .20757 .62844 L F
.342 .645 .966 r
.21136 .63001 m .20935 .62996 L .20757 .62844 L F
.321 .143 .477 r
.26385 .59386 m .26601 .59069 L .26358 .59133 L F
.218 .281 .715 r
.43682 .62103 m .4393 .62354 L .43774 .62469 L F
.89 .947 .59 r
.4393 .62354 m .43809 .62733 L .43774 .62469 L F
.664 .352 .434 r
.41169 .6113 m .41433 .612 L .41502 .60861 L F
.577 .551 .789 r
.51477 .60513 m .51073 .60266 L .51222 .60328 L F
.924 .745 .259 r
.66396 .4365 m .66359 .43624 L .66369 .43368 L F
.319 .512 .889 r
.16641 .62726 m .16856 .63048 L .16979 .6301 L F
.28 .347 .754 r
.16856 .63048 m .17075 .63221 L .16979 .6301 L F
.563 .455 .689 r
.29149 .60609 m .2895 .60924 L .28915 .6066 L F
.116 0 0 r
.19588 .55869 m .19135 .55922 L .19382 .55926 L F
.514 .394 .654 r
.29607 .5973 m .29627 .59987 L .29402 .60033 L F
.587 .356 .533 r
.29641 .60251 m .29402 .60033 L .29627 .59987 L F
.29641 .60251 m .29387 .60289 L .29402 .60033 L F
.847 .898 .873 r
.42415 .61892 m .42431 .62083 L .42692 .61845 L F
.516 .415 .679 r
.50632 .6067 m .50878 .60664 L .50742 .60398 L F
.50742 .60398 m .50878 .60664 L .50632 .6067 L F
.092 0 .242 r
.50632 .6067 m .50745 .60667 L .50878 .60664 L F
.50632 .6067 m .50584 .60876 L .50745 .60667 L F
.50632 .6067 m .50745 .60667 L .50878 .60664 L F
.50632 .6067 m .50584 .60876 L .50745 .60667 L F
.084 .638 .811 r
.5529 .6089 m .55423 .60909 L .55674 .60913 L F
.854 .588 .051 r
.58452 .55092 m .58537 .55451 L .58591 .55213 L F
.656 .58 .757 r
.22861 .66719 m .2281 .6681 L .22654 .66618 L F
0 0 .134 r
.46882 .56676 m .468 .56878 L .46634 .56939 L F
0 0 0 r
.468 .56878 m .46624 .57015 L .46634 .56939 L F
.788 .614 .665 r
.41953 .62754 m .41499 .62466 L .41727 .62506 L F
.41953 .62754 m .41535 .62731 L .41499 .62466 L F
0 0 0 r
.41953 .62754 m .41605 .62982 L .41535 .62731 L F
.241 .259 .679 r
.41777 .62882 m .41918 .62801 L .41917 .62801 L F
0 0 0 r
.41953 .62754 m .41777 .62882 L .41616 .62975 L F
.241 .259 .679 r
.41777 .62882 m .41917 .62801 L .41685 .62554 L F
0 0 0 r
.41616 .62975 m .41777 .62882 L .41605 .62982 L F
.337 0 0 r
.42032 .62865 m .41953 .62754 L .42038 .62673 L F
0 0 0 r
.53854 .51216 m .54062 .51151 L .54174 .50981 L F
.54423 .5068 m .54174 .50981 L .5432 .50838 L F
.54174 .50981 m .54242 .51012 L .5432 .50838 L F
.54174 .50981 m .54062 .51151 L .54242 .51012 L F
.722 .578 .692 r
.69763 .41877 m .69889 .42216 L .70127 .41918 L F
0 0 0 r
.54685 .504 m .54423 .5068 L .54589 .50544 L F
.314 0 .239 r
.54589 .50544 m .54888 .50287 L .54685 .504 L F
.585 .609 .842 r
.66448 .42993 m .66457 .43637 L .66369 .43368 L F
.771 .759 .842 r
.66814 .43016 m .66457 .43637 L .66448 .42993 L F
.322 .509 .885 r
.44731 .60036 m .45045 .60204 L .44932 .60319 L F
.068 .1 .586 r
.45045 .60204 m .45085 .60561 L .44932 .60319 L F
.252 .167 .561 r
.44932 .60319 m .45085 .60561 L .44941 .60623 L F
.79 .586 .625 r
.57858 .4968 m .58224 .49459 L .57895 .49477 L F
.57858 .4968 m .58224 .49742 L .58224 .49459 L F
.702 .793 .921 r
.65802 .44161 m .66148 .4419 L .66117 .44017 L F
.673 .824 .956 r
.66117 .44017 m .66148 .4419 L .6649 .44041 L F
.625 .757 .942 r
.73329 .3964 m .73436 .39807 L .73075 .39728 L F
.598 .715 .926 r
.73549 .39572 m .73436 .39807 L .73329 .3964 L F
.73549 .39572 m .73694 .39737 L .73436 .39807 L F
.361 0 0 r
.67261 .42002 m .67549 .42085 L .6717 .42048 L F
.27 0 .072 r
.55751 .58216 m .55458 .58407 L .55732 .5832 L F
.078 .189 .679 r
.55662 .57913 m .55751 .58216 L .55871 .58076 L F
0 0 0 r
.55751 .58216 m .55732 .5832 L .55871 .58076 L F
.774 .724 .806 r
.82426 .43898 m .82594 .44364 L .82775 .43955 L F
.298 .378 .776 r
.41221 .63705 m .41047 .63602 L .41227 .63917 L F
.482 0 0 r
.41047 .63602 m .41217 .63732 L .41149 .63696 L F
.298 .378 .776 r
.41222 .63734 m .41227 .63917 L .41287 .63765 L F
.482 0 0 r
.41217 .63732 m .41296 .63792 L .41166 .63707 L F
.41217 .63732 m .41166 .63707 L .41149 .63696 L F
.298 .378 .776 r
.41221 .63705 m .41222 .63734 L .41313 .637 L F
.41222 .63734 m .41287 .63765 L .41313 .637 L F
.881 .992 .785 r
.7693 .39789 m .76744 .39842 L .76815 .39673 L F
.7693 .39789 m .76749 .39887 L .76744 .39842 L F
.397 .027 .215 r
.54888 .50287 m .55137 .50237 L .55195 .50035 L F
.404 .066 .276 r
.55137 .50237 m .55415 .50018 L .55195 .50035 L F
.842 .977 .875 r
.81816 .44149 m .81793 .44344 L .81858 .44314 L F
.017 0 0 r
.82092 .44047 m .81816 .44149 L .81858 .44314 L F
.343 0 0 r
.18017 .54748 m .18256 .54745 L .18464 .54612 L F
.407 .814 .608 r
.18464 .54612 m .18445 .54619 L .18675 .54541 L F
.18464 .54612 m .18256 .54745 L .18445 .54619 L F
.729 .636 .755 r
.83132 .42494 m .83469 .42652 L .834 .42407 L F
.501 0 0 r
.25684 .55631 m .25591 .55594 L .25596 .55621 L F
.587 .885 .991 r
.19477 .75132 m .1906 .75158 L .19295 .75139 L F
.893 .932 .836 r
.19236 .75437 m .19295 .75139 L .1906 .75158 L F
.19236 .75437 m .19477 .75132 L .19295 .75139 L F
.302 0 .097 r
.14141 .5721 m .14469 .56982 L .14285 .57092 L F
.86 .648 .614 r
.57318 .51529 m .57007 .51484 L .57027 .51224 L F
.86 .676 .653 r
.57318 .51529 m .57185 .51826 L .57007 .51484 L F
.133 0 .259 r
.2689 .55791 m .26676 .56091 L .26786 .56084 L F
.171 .313 .767 r
.26676 .56091 m .26892 .56263 L .26786 .56084 L F
.486 .574 .869 r
.77666 .43433 m .773 .43152 L .77677 .43274 L F
.243 .389 .811 r
.77805 .43276 m .77666 .43433 L .77677 .43274 L F
.355 .322 .684 r
.77904 .43632 m .77666 .43433 L .77805 .43276 L F
.77904 .43632 m .77768 .43658 L .77666 .43433 L F
.647 .82 .395 r
.22002 .55283 m .22055 .55213 L .22283 .55134 L F
.22002 .55283 m .21917 .55424 L .22055 .55213 L F
.918 .752 .661 r
.57219 .53336 m .57351 .53725 L .57243 .53639 L F
.93 .861 .75 r
.57351 .53725 m .57071 .5388 L .57243 .53639 L F
.57351 .53725 m .57219 .53972 L .57071 .5388 L F
.563 .385 .598 r
.46702 .5853 m .46956 .58745 L .46955 .58487 L F
.46702 .5853 m .46706 .58797 L .46956 .58745 L F
.112 0 .191 r
.5432 .50838 m .54589 .50544 L .54423 .5068 L F
.789 .305 .071 r
.51949 .56386 m .51826 .5648 L .51829 .56299 L F
.51949 .56386 m .52114 .56617 L .51826 .5648 L F
.318 0 .2 r
.44643 .56877 m .44948 .56647 L .44727 .56728 L F
.187 .322 .769 r
.773 .43152 m .77149 .42778 L .77214 .43014 L F
.251 .574 .941 r
.77582 .43106 m .773 .43152 L .77214 .43014 L F
.77582 .43106 m .77677 .43274 L .773 .43152 L F
.449 .203 .448 r
.4579 .63242 m .45502 .63569 L .45533 .63332 L F
.65 .595 .78 r
.82755 .40901 m .83115 .41026 L .82848 .41265 L F
.654 .603 .785 r
.82848 .41265 m .83115 .41026 L .832 .41359 L F
.373 .675 .975 r
.80897 .40024 m .80728 .40144 L .80636 .40002 L F
.80897 .40024 m .80996 .40163 L .80728 .40144 L F
.942 .781 .653 r
.58503 .54212 m .58652 .54293 L .58555 .53943 L F
.955 .732 .562 r
.58622 .54523 m .58652 .54293 L .58503 .54212 L F
.736 .69 .807 r
.82775 .43955 m .82844 .44212 L .83151 .44007 L F
.691 .645 .8 r
.71712 .40673 m .7209 .40747 L .71976 .40397 L F
.709 .657 .797 r
.7209 .40747 m .72212 .40296 L .71976 .40397 L F
.7209 .40747 m .7233 .40664 L .72212 .40296 L F
.564 .324 .511 r
.28711 .61231 m .28682 .61491 L .28432 .61513 L F
.417 .2 .474 r
.28892 .61423 m .28711 .61231 L .28966 .61184 L F
.28892 .61423 m .28682 .61491 L .28711 .61231 L F
.682 .507 .643 r
.80301 .42709 m .80514 .42445 L .80336 .42541 L F
.978 .759 .537 r
.5861 .51684 m .58744 .51841 L .58627 .51513 L F
.875 .826 .796 r
.58516 .52176 m .58744 .51841 L .5861 .51684 L F
.788 .705 .773 r
.58627 .51513 m .58744 .51841 L .59105 .5137 L F
.981 .69 .342 r
.21472 .68746 m .21623 .69093 L .21513 .69044 L F
.989 .88 .623 r
.21513 .69044 m .21623 .69093 L .21428 .69267 L F
.586 .469 .687 r
.42408 .63317 m .42694 .63606 L .42613 .63275 L F
.42408 .63317 m .42473 .63699 L .42694 .63606 L F
.587 .499 .722 r
.44158 .62778 m .44196 .63047 L .44411 .62723 L F
.579 .489 .716 r
.44411 .62723 m .44196 .63047 L .44437 .6297 L F
.564 .4 .617 r
.44196 .63047 m .44633 .63028 L .44437 .6297 L F
.44196 .63047 m .44118 .63212 L .44633 .63028 L F
.3 0 .203 r
.49881 .60326 m .49826 .60528 L .49612 .60581 L F
.538 .165 .281 r
.50149 .60441 m .49881 .60326 L .50136 .6027 L F
.50149 .60441 m .49826 .60528 L .49881 .60326 L F
.23 0 .266 r
.24603 .64694 m .2468 .64279 L .24878 .64203 L F
.643 .374 .497 r
.5637 .49698 m .56633 .49706 L .5665 .49481 L F
.726 .447 .503 r
.5665 .49481 m .56991 .49714 L .56991 .49459 L F
.5665 .49481 m .56633 .49706 L .56991 .49714 L F
.808 .648 .684 r
.66277 .4065 m .66422 .40933 L .66607 .40741 L F
.756 .403 .385 r
.22873 .66816 m .22861 .66719 L .22654 .66618 L F
.51 .699 .955 r
.8205 .40496 m .82378 .40622 L .82123 .40664 L F
.438 .673 .962 r
.19593 .62322 m .19513 .62497 L .1941 .62298 L F
.19593 .62322 m .19782 .62497 L .19513 .62497 L F
0 0 .235 r
.30304 .56299 m .30255 .56711 L .30098 .56343 L F
.30304 .56299 m .30268 .56845 L .30255 .56711 L F
.49 .296 .544 r
.30268 .56845 m .30219 .56954 L .30255 .56711 L F
.239 0 0 r
.66533 .4131 m .66422 .41431 L .66163 .41469 L F
.75 .65 .751 r
.66746 .41069 m .66533 .4131 L .66422 .40933 L F
.975 .674 .369 r
.66558 .41542 m .66422 .41431 L .66533 .4131 L F
0 0 0 r
.21232 .55537 m .21183 .55481 L .21397 .55448 L F
.21397 .55448 m .21455 .55488 L .21528 .55396 L F
.319 0 .069 r
.21528 .55396 m .21476 .55495 L .21232 .55537 L F
.442 .818 .992 r
.21476 .55495 m .21377 .55489 L .21232 .55537 L F
.319 0 .069 r
.21528 .55396 m .21232 .55537 L .21397 .55448 L F
.442 .818 .992 r
.21377 .55489 m .21049 .55471 L .21232 .55537 L F
0 0 0 r
.21232 .55537 m .20998 .55643 L .21051 .55596 L F
.21232 .55537 m .21051 .55596 L .21183 .55481 L F
.807 .665 .706 r
.21725 .68319 m .21848 .68794 L .21472 .68746 L F
.808 .556 .558 r
.21472 .68746 m .21848 .68794 L .2158 .68923 L F
.08 .395 .853 r
.21848 .68794 m .21901 .68672 L .2158 .68923 L F
.21848 .68794 m .22169 .68967 L .21901 .68672 L F
.774 .453 .443 r
.57027 .51224 m .56627 .50954 L .57021 .5096 L F
.488 .193 .391 r
.48155 .5969 m .47851 .5996 L .47893 .59778 L F
.74 .642 .082 r
.58389 .56098 m .5837 .56279 L .58371 .56335 L F
0 0 0 r
.58416 .56035 m .5837 .56279 L .58389 .56098 L F
.563 .891 .987 r
.78321 .45054 m .78466 .44881 L .78241 .4492 L F
.78321 .45054 m .78638 .44949 L .78466 .44881 L F
.463 .225 .467 r
.16358 .60692 m .16279 .61033 L .16057 .60953 L F
.315 .391 .782 r
.16279 .61033 m .163 .61114 L .16057 .60953 L F
.832 .695 .712 r
.23148 .58267 m .23085 .58529 L .22935 .58169 L F
0 .099 .614 r
.26796 .58218 m .26959 .58403 L .26896 .5806 L F
.265 .149 .529 r
.26801 .58476 m .26959 .58403 L .26796 .58218 L F
.758 .514 .563 r
.49349 .60634 m .48988 .60867 L .48937 .60633 L F
.49349 .60634 m .49343 .60887 L .48988 .60867 L F
.49349 .60634 m .48937 .60633 L .4916 .60818 L F
.776 .664 .74 r
.49612 .60581 m .49343 .60887 L .49349 .60634 L F
.371 0 .098 r
.49612 .60581 m .49349 .60634 L .4916 .60818 L F
0 0 0 r
.23353 .62641 m .23258 .6272 L .23439 .62599 L F
.431 .848 .686 r
.23258 .6272 m .23246 .62702 L .23439 .62599 L F
0 0 0 r
.23537 .62552 m .23439 .62599 L .23246 .62702 L F
.23663 .62487 m .23439 .62599 L .23537 .62552 L F
.23616 .62423 m .23353 .62641 L .23439 .62599 L F
.23439 .62599 m .23686 .6236 L .23616 .62423 L F
.575 .678 .91 r
.19568 .74846 m .19477 .75132 L .19295 .75139 L F
.19568 .74846 m .19727 .75093 L .19477 .75132 L F
.694 .454 .556 r
.19727 .75093 m .19295 .75139 L .19477 .75132 L F
.642 .708 .895 r
.78693 .43927 m .7845 .44039 L .78193 .43687 L F
.561 .421 .648 r
.71877 .4005 m .72109 .39711 L .71871 .39811 L F
.525 .658 .919 r
.73454 .40313 m .73667 .40628 L .73856 .40558 L F
.478 .611 .904 r
.73667 .40628 m .73937 .40738 L .73856 .40558 L F
.847 .914 .879 r
.56255 .59123 m .5595 .59366 L .55869 .59283 L F
.953 .61 .314 r
.56255 .59123 m .55971 .58984 L .56171 .59159 L F
.994 .75 .437 r
.56255 .59123 m .56171 .59159 L .56113 .58734 L F
.078 .189 .679 r
.55662 .57913 m .55871 .58076 L .55991 .57915 L F
0 0 0 r
.56041 .57951 m .55991 .57915 L .55871 .58076 L F
.56041 .57951 m .56178 .57799 L .55991 .57915 L F
.603 .443 .638 r
.46226 .59144 m .46459 .59346 L .46436 .59138 L F
.46226 .59144 m .46224 .59415 L .46459 .59346 L F
.698 .608 .752 r
.71354 .40642 m .71712 .40673 L .71623 .40316 L F
.476 .894 .812 r
.78853 .44808 m .78916 .44808 L .79217 .4467 L F
.606 .52 .731 r
.80515 .41945 m .80776 .41868 L .80688 .41526 L F
.376 .711 .986 r
.77259 .40349 m .77612 .40466 L .77544 .40353 L F
.584 .866 .995 r
.7793 .40347 m .77544 .40353 L .77612 .40466 L F
.111 .204 .681 r
.26542 .55617 m .26689 .55715 L .26587 .55628 L F
.585 .743 .951 r
.50344 .52436 m .50749 .52558 L .50585 .52378 L F
.671 .781 .932 r
.50585 .52378 m .50749 .52558 L .5097 .52436 L F
.502 .191 .371 r
.4709 .61819 m .47124 .62005 L .47327 .61768 L F
.4709 .61819 m .47112 .62021 L .47124 .62005 L F
.683 .525 .666 r
.43856 .63519 m .44285 .63602 L .44118 .63212 L F
.534 .406 .653 r
.44285 .63602 m .44633 .63028 L .44118 .63212 L F
.75 .65 .751 r
.66746 .41069 m .66422 .40933 L .66598 .40959 L F
0 .441 .706 r
.66713 .41057 m .66746 .41069 L .66598 .40959 L F
.66713 .41057 m .6705 .41139 L .66746 .41069 L F
.021 .477 .876 r
.59105 .5137 m .58891 .51224 L .58627 .51513 L F
.735 .649 .764 r
.82504 .42781 m .82873 .42805 L .82756 .42417 L F
.807 .539 .533 r
.82504 .42781 m .82845 .43091 L .82873 .42805 L F
.73 .646 .765 r
.82756 .42417 m .82873 .42805 L .83132 .42494 L F
.392 .479 .83 r
.15554 .62445 m .15495 .62064 L .1532 .62132 L F
.15554 .62445 m .15682 .62447 L .15495 .62064 L F
.617 .083 0 r
.43839 .64297 m .43923 .64108 L .43704 .64169 L F
.43839 .64297 m .43661 .64385 L .43923 .64108 L F
.43839 .64297 m .44051 .64457 L .43661 .64385 L F
.768 .467 .477 r
.68778 .42081 m .69165 .41925 L .68759 .41863 L F
.68778 .42081 m .69153 .42129 L .69165 .41925 L F
.748 .546 .622 r
.69153 .42129 m .69509 .41898 L .69165 .41925 L F
.81 .447 .37 r
.51778 .5451 m .52134 .54769 L .52113 .54595 L F
.427 .192 .454 r
.5235 .54508 m .52113 .54595 L .52134 .54769 L F
.5235 .54508 m .52113 .54595 L .52134 .54769 L F
.776 .604 .666 r
.69523 .42165 m .69763 .41877 L .69509 .41898 L F
.69523 .42165 m .69889 .42216 L .69763 .41877 L F
0 .541 .799 r
.48332 .55939 m .48533 .55967 L .48699 .56016 L F
.374 0 0 r
.48533 .55967 m .48884 .56098 L .48699 .56016 L F
.845 .611 .584 r
.58377 .50537 m .58732 .50361 L .58384 .50281 L F
.58377 .50537 m .58723 .50615 L .58732 .50361 L F
.397 0 0 r
.74058 .37509 m .74131 .37419 L .73778 .37435 L F
.455 0 0 r
.74423 .37518 m .74131 .37419 L .74058 .37509 L F
.649 .577 .76 r
.71623 .40316 m .71712 .40673 L .71976 .40397 L F
.797 .949 .92 r
.47052 .56068 m .47089 .55834 L .47326 .5571 L F
0 0 0 r
.47326 .5571 m .47394 .55738 L .47591 .55673 L F
.47326 .5571 m .47089 .55834 L .47394 .55738 L F
.685 .261 .235 r
.43195 .65791 m .4305 .65956 L .42861 .65774 L F
.581 .478 .702 r
.29149 .60609 m .29192 .60897 L .2895 .60924 L F
.404 .184 .464 r
.29192 .60897 m .28966 .61184 L .2895 .60924 L F
.609 .863 .991 r
.21145 .64713 m .21298 .64803 L .21507 .64729 L F
.761 .614 .696 r
.51094 .53031 m .51404 .53608 L .50786 .53268 L F
.103 .524 .91 r
.50786 .53268 m .51404 .53608 L .51224 .53462 L F
.51116 .53388 m .51224 .53462 L .51144 .53397 L F
.50786 .53268 m .51224 .53462 L .51116 .53388 L F
.862 .721 .705 r
.51603 .53684 m .51541 .53682 L .5147 .53336 L F
.51541 .53682 m .51369 .53677 L .51397 .53582 L F
.51541 .53682 m .51397 .53582 L .5147 .53336 L F
0 0 .172 r
.51481 .53829 m .51476 .53963 L .5149 .53893 L F
.982 .864 .49 r
.51603 .53684 m .51481 .53829 L .51462 .5368 L F
.51603 .53684 m .51531 .53948 L .51481 .53829 L F
0 0 .172 r
.51481 .53829 m .5149 .53893 L .51581 .53437 L F
.982 .864 .49 r
.51462 .5368 m .51481 .53829 L .51369 .53677 L F
.961 .68 .455 r
.58373 .52569 m .58516 .52176 L .58397 .52072 L F
.875 .826 .796 r
.58516 .52176 m .5861 .51684 L .58397 .52072 L F
.331 0 .078 r
.15575 .55955 m .15717 .56015 L .15882 .55813 L F
.223 0 .007 r
.15717 .56015 m .16095 .55752 L .15882 .55813 L F
.606 .619 .839 r
.83799 .41395 m .83605 .41695 L .83461 .41288 L F
.83799 .41395 m .83897 .41616 L .83605 .41695 L F
.95 .903 .742 r
.5709 .54871 m .56985 .54792 L .57099 .54526 L F
.99 .876 .541 r
.56981 .55177 m .56985 .54792 L .5709 .54871 L F
.593 .859 .994 r
.22786 .64526 m .2311 .64509 L .23005 .64486 L F
.333 .8 .928 r
.23005 .64486 m .2311 .64509 L .23367 .64439 L F
.475 .357 .639 r
.74286 .38199 m .7431 .38453 L .74046 .38293 L F
.628 .211 .232 r
.74046 .38293 m .7431 .38453 L .7379 .38593 L F
.337 .183 .52 r
.42035 .58836 m .41873 .59159 L .42012 .59068 L F
.152 0 .237 r
.41873 .59159 m .41769 .59379 L .42012 .59068 L F
.951 .87 .722 r
.76825 .4143 m .77101 .4122 L .77047 .41036 L F
.76825 .4143 m .76935 .41563 L .77101 .4122 L F
.955 .701 .514 r
.22784 .57171 m .22669 .57143 L .22693 .56948 L F
.887 .865 .812 r
.22907 .56894 m .22843 .57315 L .22693 .56948 L F
.965 .737 .543 r
.22693 .56948 m .22444 .56854 L .22483 .56565 L F
.954 .701 .514 r
.22693 .56948 m .2248 .57097 L .22444 .56854 L F
.22693 .56948 m .22657 .57237 L .2248 .57097 L F
.521 .566 .842 r
.22744 .56542 m .22693 .56948 L .22483 .56565 L F
.22744 .56542 m .22907 .56894 L .22693 .56948 L F
.859 .808 .799 r
.2248 .57096 m .22907 .56894 L .22718 .56807 L F
.2248 .57097 m .2248 .57096 L .2248 .57096 L F
.2248 .57096 m .22907 .56894 L .2248 .57096 L F
.955 .701 .514 r
.22843 .57315 m .22657 .57237 L .22669 .57143 L F
.22843 .57315 m .22669 .57143 L .22784 .57171 L F
.887 .865 .812 r
.22907 .56894 m .22657 .57237 L .22843 .57315 L F
.284 0 0 r
.48684 .57338 m .48405 .57656 L .48504 .5745 L F
.48684 .57338 m .48644 .57608 L .48405 .57656 L F
0 0 0 r
.48888 .57301 m .48644 .57608 L .48671 .57424 L F
.4876 .57324 m .48671 .57424 L .48684 .57338 L F
.48888 .57301 m .48671 .57424 L .4876 .57324 L F
.48805 .57273 m .48504 .5745 L .48419 .57172 L F
.48823 .57278 m .48781 .57301 L .48805 .57273 L F
.48823 .57278 m .48684 .57338 L .48504 .5745 L F
.48781 .57301 m .48504 .5745 L .48805 .57273 L F
.592 .833 .99 r
.20146 .64598 m .20329 .64709 L .2053 .64627 L F
.949 .66 .212 r
.52393 .53053 m .52456 .5319 L .52361 .52767 L F
.441 .268 .549 r
.52361 .52767 m .52393 .53053 L .52573 .52706 L F
.949 .66 .212 r
.52393 .53053 m .52361 .52767 L .52573 .52706 L F
.397 .161 .436 r
.27325 .6295 m .27169 .62769 L .2738 .62741 L F
.27325 .6295 m .27119 .63022 L .27169 .62769 L F
.954 .615 .228 r
.52303 .56693 m .52228 .56826 L .52114 .56617 L F
.52303 .56693 m .52354 .56928 L .52228 .56826 L F
.368 .632 .956 r
.76748 .43325 m .76896 .43173 L .76569 .43092 L F
.76748 .43325 m .76966 .43326 L .76896 .43173 L F
.439 .122 .33 r
.47612 .61498 m .4786 .61446 L .47905 .61263 L F
.621 .359 .499 r
.4786 .61446 m .48165 .61223 L .47905 .61263 L F
.938 .727 .591 r
.2689 .55791 m .26786 .56084 L .26689 .55715 L F
.476 .894 .812 r
.78853 .44808 m .79217 .4467 L .79094 .4469 L F
.381 .84 .78 r
.79364 .44577 m .79217 .4467 L .79473 .44578 L F
.79364 .44577 m .79094 .4469 L .79217 .4467 L F
.469 .185 .399 r
.47087 .60559 m .46762 .60781 L .46874 .6059 L F
.074 .251 .741 r
.77886 .44697 m .78007 .44861 L .77872 .4451 L F
.824 .746 .778 r
.82507 .43608 m .82772 .4371 L .82685 .43372 L F
.805 .572 .586 r
.82426 .43898 m .82772 .4371 L .82507 .43608 L F
.82426 .43898 m .82775 .43955 L .82772 .4371 L F
.777 .72 .799 r
.82685 .43372 m .82772 .4371 L .83026 .43412 L F
.434 .412 .735 r
.18799 .76985 m .18671 .77242 L .18633 .77089 L F
.18799 .76985 m .18868 .77242 L .18671 .77242 L F
.313 0 0 r
.18671 .77242 m .18868 .77242 L .18615 .77299 L F
.235 0 0 r
.24502 .53776 m .24697 .53811 L .24886 .53809 L F
.155 0 0 r
.24697 .53811 m .25098 .53779 L .24886 .53809 L F
.463 .235 .482 r
.43717 .63654 m .43686 .63896 L .43856 .63519 L F
.726 .372 .379 r
.21808 .69363 m .22165 .69392 L .22013 .69445 L F
.438 .706 .979 r
.2853 .54216 m .28458 .54375 L .28308 .54219 L F
.2853 .54216 m .28744 .54403 L .28458 .54375 L F
.053 .35 .825 r
.77049 .43506 m .77237 .43505 L .76966 .43326 L F
.77049 .43506 m .77282 .43674 L .77237 .43505 L F
.776 .664 .74 r
.49612 .60581 m .49721 .60931 L .49343 .60887 L F
.572 .039 0 r
.49721 .60931 m .49481 .60986 L .49343 .60887 L F
.939 .959 .663 r
.49826 .60528 m .49721 .60931 L .49612 .60581 L F
.49826 .60528 m .4967 .60876 L .49721 .60931 L F
.777 .991 .885 r
.4967 .60876 m .49481 .60986 L .49721 .60931 L F
0 .313 .679 r
.67475 .44089 m .67298 .44002 L .67125 .43927 L F
.372 .838 .877 r
.67666 .43937 m .67298 .44002 L .67475 .44089 L F
.56 .566 .816 r
.80363 .41334 m .80503 .40934 L .80251 .4098 L F
.80363 .41334 m .80619 .41278 L .80503 .40934 L F
.288 .612 .956 r
.29502 .54548 m .29428 .54674 L .29293 .54566 L F
.29502 .54548 m .29767 .5472 L .29428 .54674 L F
.665 .729 .898 r
.177 .61384 m .17248 .61184 L .17481 .6114 L F
.497 .7 .96 r
.17935 .61329 m .177 .61384 L .17481 .6114 L F
.645 .621 .811 r
.72212 .40296 m .7233 .40664 L .72594 .40423 L F
.521 .249 .442 r
.46509 .62378 m .46712 .62227 L .46548 .62219 L F
0 0 .414 r
.52984 .58443 m .52906 .58152 L .52906 .58213 L F
.075 .18 .671 r
.53043 .58806 m .53161 .58661 L .52984 .58443 L F
0 0 .555 r
.53043 .58806 m .5317 .58899 L .53161 .58661 L F
.53043 .58806 m .53218 .59053 L .5317 .58899 L F
.776 .615 .68 r
.69518 .42431 m .69889 .42216 L .69523 .42165 L F
.69518 .42431 m .69882 .4246 L .69889 .42216 L F
.557 .587 .839 r
.43472 .6546 m .43096 .65172 L .43373 .65109 L F
.965 .781 .343 r
.43407 .6507 m .43472 .6546 L .43373 .65109 L F
.43407 .6507 m .43364 .65334 L .43472 .6546 L F
.399 .476 .824 r
.43364 .65334 m .43386 .65618 L .43472 .6546 L F
.531 .693 .943 r
.54763 .611 m .54636 .60898 L .54405 .60938 L F
.255 .712 .953 r
.55088 .60994 m .54636 .60898 L .54763 .611 L F
.851 .877 .859 r
.75496 .40662 m .7577 .40638 L .75656 .4052 L F
.868 .884 .845 r
.75656 .4052 m .7577 .40638 L .76014 .40333 L F
.555 .291 .471 r
.4462 .59385 m .44336 .59633 L .4437 .59447 L F
.44336 .59633 m .4462 .59385 L .4437 .59447 L F
.693 .231 .151 r
.67397 .41246 m .67645 .41438 L .67765 .41306 L F
.761 .32 .203 r
.67645 .41438 m .6803 .41544 L .67765 .41306 L F
.757 .335 .247 r
.67765 .41306 m .6803 .41544 L .68161 .41536 L F
0 0 .271 r
.26875 .57224 m .2695 .56879 L .26889 .57031 L F
.76 .464 .482 r
.40777 .60061 m .40988 .60265 L .40924 .60015 L F
.40777 .60061 m .40745 .6028 L .40988 .60265 L F
0 0 0 r
.19947 .5577 m .19739 .55831 L .19588 .55869 L F
.276 .77 .716 r
.20022 .55735 m .19947 .5577 L .20174 .5568 L F
.20022 .55735 m .19739 .55831 L .19947 .5577 L F
.583 .777 .971 r
.18668 .76882 m .18633 .77089 L .18454 .77028 L F
.18668 .76882 m .18799 .76985 L .18633 .77089 L F
.025 0 .068 r
.18414 .56324 m .18172 .56565 L .18191 .5645 L F
0 .048 .612 r
.76968 .38481 m .77094 .38775 L .77115 .38686 L F
.397 .137 .398 r
.47829 .60193 m .47659 .60043 L .47851 .5996 L F
.47829 .60193 m .47605 .60269 L .47659 .60043 L F
.814 .733 .776 r
.51574 .6138 m .51031 .61195 L .51364 .61177 L F
.51574 .6138 m .50952 .61423 L .51031 .61195 L F
.613 .141 .11 r
.51574 .6138 m .51182 .61572 L .50952 .61423 L F
.379 .841 .89 r
.51364 .61177 m .51519 .61108 L .51522 .61148 L F
0 0 .35 r
.51519 .61108 m .51574 .6138 L .51364 .61177 L F
.666 .235 .215 r
.51928 .61187 m .51735 .61332 L .51522 .61148 L F
.51981 .61192 m .51735 .61332 L .51928 .61187 L F
.723 .913 .554 r
.51834 .6084 m .51767 .6075 L .51843 .60831 L F
.51522 .61148 m .51642 .60953 L .51834 .6084 L F
.51642 .60953 m .51767 .6075 L .51834 .6084 L F
.51642 .60953 m .51519 .61108 L .51767 .6075 L F
0 0 .35 r
.51519 .61108 m .51625 .61399 L .51612 .61394 L F
.51561 .61316 m .51607 .61392 L .51574 .6138 L F
.662 .112 0 r
.51471 .61168 m .51617 .61408 L .51519 .61108 L F
.51617 .61408 m .51625 .61399 L .51519 .61108 L F
0 .013 .523 r
.51735 .61332 m .51519 .61108 L .51522 .61148 L F
.51735 .61332 m .51677 .61266 L .51519 .61108 L F
.792 .459 .425 r
.51677 .61266 m .51468 .61143 L .51519 .61108 L F
.313 .392 .784 r
.5119 .60871 m .51519 .61108 L .51364 .61177 L F
.662 .112 0 r
.5142 .61084 m .51471 .61168 L .51519 .61108 L F
.792 .459 .425 r
.51468 .61143 m .5136 .61079 L .51519 .61108 L F
.723 .913 .554 r
.51566 .61075 m .51519 .61108 L .51642 .60953 L F
.51522 .61148 m .51519 .61108 L .51566 .61075 L F
.787 .874 .442 r
.5119 .60871 m .51031 .61195 L .511 .61005 L F
.798 .601 .635 r
.5119 .60871 m .51364 .61177 L .51031 .61195 L F
.662 .112 0 r
.511 .61005 m .51295 .61158 L .5142 .61084 L F
0 0 .35 r
.51625 .61399 m .51628 .61417 L .51574 .6138 L F
.662 .112 0 r
.51295 .61158 m .51617 .61408 L .5142 .61084 L F
.964 .919 .711 r
.51603 .61431 m .51533 .61499 L .51579 .61449 L F
.51735 .61332 m .5164 .61411 L .51603 .61431 L F
.5164 .61411 m .51533 .61499 L .51603 .61431 L F
0 0 0 r
.51574 .6138 m .51628 .61417 L .51182 .61572 L F
.51628 .61417 m .51633 .61421 L .51604 .61431 L F
.51628 .61417 m .51604 .61431 L .51182 .61572 L F
0 0 .35 r
.51625 .61399 m .51633 .61421 L .51628 .61417 L F
.964 .919 .711 r
.51735 .61332 m .51627 .61413 L .51677 .61266 L F
.662 .112 0 r
.511 .61005 m .51243 .61156 L .51403 .61244 L F
.511 .61005 m .5161 .61407 L .51617 .61408 L F
.756 .312 .196 r
.50745 .60667 m .511 .61005 L .5119 .60871 L F
.692 .233 .157 r
.511 .61005 m .51519 .61108 L .5119 .60871 L F
.967 .789 .61 r
.51556 .60832 m .511 .61005 L .5119 .60871 L F
.771 .33 .205 r
.5119 .60871 m .511 .61005 L .51043 .60899 L F
.967 .789 .61 r
.51556 .60832 m .5136 .61079 L .511 .61005 L F
.119 .538 .917 r
.511 .61005 m .5136 .61079 L .5111 .60894 L F
.899 .918 .524 r
.51031 .61195 m .50952 .61423 L .5095 .6131 L F
.51031 .61195 m .5095 .6131 L .511 .61005 L F
.897 .95 .6 r
.5095 .6131 m .50922 .61187 L .511 .61005 L F
.659 .208 .169 r
.50922 .61187 m .51332 .61249 L .511 .61005 L F
.726 .394 .417 r
.5136 .61079 m .51184 .61123 L .5111 .60894 L F
.51184 .61123 m .50922 .61187 L .51021 .61032 L F
.751 .324 .237 r
.50745 .60667 m .511 .61005 L .51043 .60899 L F
.742 .65 .757 r
.51073 .60266 m .51174 .60599 L .50878 .60664 L F
.755 .549 .618 r
.51174 .60599 m .5119 .60871 L .5084 .6071 L F
.50878 .60646 m .5084 .6071 L .50745 .60667 L F
.51174 .60599 m .50867 .60665 L .50878 .60664 L F
.866 .948 .589 r
.50925 .60568 m .50878 .60664 L .50883 .60638 L F
.409 .451 .793 r
.50745 .60667 m .50927 .60414 L .50878 .60664 L F
.755 .549 .618 r
.51174 .60599 m .50745 .60667 L .50867 .60665 L F
.51174 .60599 m .5084 .6071 L .50878 .60646 L F
.866 .948 .589 r
.51073 .60266 m .50925 .60568 L .50927 .60414 L F
.50925 .60568 m .50883 .60638 L .50927 .60414 L F
.119 .538 .917 r
.511 .61005 m .51021 .60653 L .51043 .60899 L F
.511 .61005 m .5111 .60894 L .51021 .60653 L F
.726 .394 .417 r
.51184 .61123 m .51021 .61032 L .5111 .60894 L F
.662 .112 0 r
.51403 .61244 m .51332 .61249 L .5161 .61407 L F
.51243 .61156 m .51332 .61249 L .51403 .61244 L F
.563 .629 .875 r
.51332 .61249 m .51182 .61572 L .51604 .61431 L F
.964 .919 .711 r
.51609 .61409 m .51551 .6147 L .51591 .61405 L F
.51627 .61413 m .51604 .61431 L .51609 .61409 L F
.51604 .61431 m .51551 .6147 L .51609 .61409 L F
.563 .629 .875 r
.5161 .61407 m .51604 .61431 L .51633 .61421 L F
.51332 .61249 m .51604 .61431 L .5161 .61407 L F
.964 .919 .711 r
.51627 .61413 m .51591 .61405 L .51627 .61409 L F
.662 .112 0 r
.51617 .61408 m .5161 .61407 L .51633 .61421 L F
.964 .919 .711 r
.51627 .61409 m .51591 .61405 L .51619 .6136 L F
.51627 .61413 m .51619 .6136 L .51677 .61266 L F
.662 .112 0 r
.51617 .61408 m .51633 .61421 L .51625 .61399 L F
.964 .919 .711 r
.51735 .61332 m .51504 .61546 L .51533 .61499 L F
.51579 .61449 m .51533 .61499 L .51551 .6147 L F
.098 0 .221 r
.16435 .57505 m .16284 .57635 L .16518 .57305 L F
0 0 0 r
.16278 .57707 m .16284 .57635 L .16435 .57505 L F
.16278 .57707 m .16085 .57795 L .16284 .57635 L F
.945 .667 .48 r
.49329 .57847 m .49164 .57522 L .4941 .5751 L F
.347 0 0 r
.45191 .56606 m .45438 .56584 L .4558 .56428 L F
.371 0 0 r
.45438 .56584 m .45837 .56407 L .4558 .56428 L F
.014 .299 .793 r
.18018 .63914 m .18036 .63775 L .17783 .63774 L F
.18018 .63914 m .18123 .63954 L .18036 .63775 L F
.669 .434 .555 r
.44301 .62369 m .44676 .62412 L .44654 .62133 L F
.635 .408 .557 r
.44654 .62133 m .44676 .62412 L .44911 .62109 L F
.421 .442 .776 r
.27203 .56546 m .27323 .56927 L .27145 .57 L F
.594 .396 .583 r
.27057 .57132 m .27323 .56927 L .27145 .57 L F
.27057 .57132 m .27323 .56927 L .27145 .57 L F
.703 .366 .404 r
.58746 .50875 m .59007 .50747 L .58723 .50615 L F
.58746 .50875 m .59113 .50898 L .59007 .50747 L F
.749 .91 .947 r
.69069 .4305 m .69346 .43034 L .69323 .42743 L F
.816 .825 .856 r
.69346 .43034 m .69631 .4277 L .69323 .42743 L F
.572 .665 .901 r
.17034 .61494 m .1681 .61548 L .16707 .6137 L F
0 0 .284 r
.52833 .52151 m .52877 .51826 L .52743 .51899 L F
.254 .752 .902 r
.757 .37451 m .75377 .37497 L .75299 .37445 L F
.698 .899 .969 r
.7826 .39544 m .78134 .39774 L .78372 .39619 L F
0 .004 .511 r
.78318 .39834 m .78134 .39774 L .7826 .39544 L F
.78318 .39834 m .78199 .4007 L .78134 .39774 L F
.582 .825 .99 r
.20174 .5568 m .20591 .55713 L .20416 .55598 L F
.266 .655 .967 r
.20591 .55713 m .2061 .55598 L .20416 .55598 L F
.20591 .55713 m .20783 .55722 L .2061 .55598 L F
.667 .389 .491 r
.22294 .69537 m .21961 .69891 L .21895 .6989 L F
.22294 .69537 m .22188 .69896 L .21961 .69891 L F
.364 .452 .818 r
.22404 .69346 m .22294 .69537 L .22165 .69392 L F
.22404 .69346 m .22519 .69632 L .22294 .69537 L F
.68 .466 .59 r
.22519 .69632 m .22188 .69896 L .22294 .69537 L F
.611 .573 .787 r
.83375 .40935 m .832 .41359 L .83115 .41026 L F
.83375 .40935 m .83461 .41288 L .832 .41359 L F
.608 .82 .981 r
.26711 .53905 m .26484 .53984 L .26319 .53862 L F
.219 .18 .599 r
.42925 .61524 m .43037 .61117 L .42834 .61125 L F
.42925 .61524 m .43063 .61464 L .43037 .61117 L F
.69 .254 .21 r
.42925 .61524 m .43067 .61488 L .43063 .61464 L F
.42925 .61524 m .43198 .61739 L .42816 .61697 L F
.42925 .61524 m .42816 .61697 L .43067 .61488 L F
.651 .312 .385 r
.56435 .50931 m .56254 .51158 L .56017 .50955 L F
.707 .406 .465 r
.56627 .50954 m .56254 .51158 L .56435 .50931 L F
.368 .786 .977 r
.20911 .64666 m .20698 .6452 L .2053 .64627 L F
0 .499 .788 r
.20911 .64666 m .20966 .64651 L .20698 .6452 L F
.20911 .64666 m .21145 .64713 L .20966 .64651 L F
.923 .533 .2 r
.49217 .54642 m .49121 .54731 L .49037 .54497 L F
.421 0 0 r
.49217 .54642 m .49375 .54747 L .49121 .54731 L F
.49217 .54642 m .49604 .54792 L .49375 .54747 L F
.338 0 0 r
.49735 .54817 m .49604 .54792 L .49217 .54642 L F
.44 .255 .532 r
.30392 .57773 m .30297 .57895 L .30099 .5788 L F
.482 .309 .569 r
.30389 .57776 m .30517 .57885 L .30297 .57895 L F
.30384 .57737 m .30519 .57844 L .30371 .57761 L F
.3054 .57454 m .30522 .57789 L .30384 .57737 L F
.30522 .57789 m .30519 .57844 L .30384 .57737 L F
.3054 .57454 m .30371 .57761 L .30519 .57726 L F
.464 .334 .619 r
.30212 .57181 m .30519 .57726 L .30214 .57673 L F
.30072 .57619 m .30214 .57673 L .30064 .57647 L F
.30212 .57181 m .30214 .57673 L .30072 .57619 L F
.482 .309 .569 r
.30519 .57844 m .30517 .57885 L .30371 .57761 L F
.44 .255 .532 r
.30519 .57726 m .30297 .57895 L .30392 .57773 L F
.482 .309 .569 r
.30371 .57761 m .30389 .57776 L .30297 .57895 L F
.44 .255 .532 r
.30371 .57761 m .30099 .5788 L .30091 .57826 L F
.30519 .57726 m .30392 .57773 L .30371 .57761 L F
.30392 .57773 m .30099 .5788 L .30371 .57761 L F
.482 .309 .569 r
.30371 .57761 m .30297 .57895 L .30519 .57726 L F
.44 .255 .532 r
.30519 .57726 m .30091 .57826 L .30064 .57647 L F
.04 0 0 r
.22215 .67572 m .21755 .67829 L .22057 .67876 L F
.526 .294 .506 r
.2232 .68373 m .22547 .68388 L .22347 .68176 L F
0 0 0 r
.53854 .51216 m .53751 .51369 L .54062 .51151 L F
0 0 .271 r
.26875 .57224 m .26951 .57152 L .2695 .56879 L F
.431 .105 .31 r
.26875 .57224 m .27012 .57417 L .26951 .57152 L F
.26875 .57224 m .26768 .57496 L .27012 .57417 L F
.863 .994 .819 r
.73321 .38395 m .73496 .38362 L .73249 .38636 L F
.789 .998 .846 r
.73625 .38132 m .73496 .38362 L .73321 .38395 L F
.951 .829 .688 r
.43856 .63519 m .43686 .63896 L .43464 .63629 L F
.734 .28 .172 r
.43464 .63629 m .44122 .63761 L .43856 .63519 L F
.679 .34 .393 r
.43856 .63519 m .44122 .63761 L .44285 .63602 L F
.645 .675 .864 r
.15912 .62372 m .161 .62703 L .16381 .62634 L F
.645 .659 .849 r
.161 .62703 m .16433 .6277 L .16381 .62634 L F
.098 0 .165 r
.16708 .57203 m .16435 .57505 L .16518 .57305 L F
.503 .078 .167 r
.43622 .60803 m .43886 .60795 L .43677 .60677 L F
.6 .463 .666 r
.43677 .60677 m .43956 .60647 L .43894 .60303 L F
.484 .111 .256 r
.43677 .60677 m .43886 .60795 L .43956 .60647 L F
.228 0 .197 r
.15389 .58388 m .15384 .58484 L .15215 .58532 L F
.255 0 .265 r
.15384 .58484 m .15134 .58754 L .15215 .58532 L F
.364 .002 .211 r
.49812 .58509 m .49745 .58656 L .49539 .58703 L F
.212 .372 .807 r
.49812 .58509 m .49918 .58605 L .49745 .58656 L F
.49812 .58509 m .49916 .58312 L .49918 .58605 L F
.579 .477 .702 r
.42486 .63814 m .42694 .63606 L .42473 .63699 L F
.42486 .63814 m .42682 .63699 L .42694 .63606 L F
.465 .361 .652 r
.42541 .64247 m .42682 .63699 L .42486 .63814 L F
.566 .3 .472 r
.44626 .61049 m .44427 .60868 L .44642 .60918 L F
.44626 .61049 m .44309 .61147 L .44427 .60868 L F
.421 0 .071 r
.47706 .59596 m .47963 .59573 L .48117 .59375 L F
.582 .443 .656 r
.48425 .59636 m .48117 .59375 L .48359 .59327 L F
.48425 .59636 m .48134 .59512 L .48192 .59464 L F
.48425 .59636 m .48122 .59413 L .4815 .59403 L F
.6 .562 .784 r
.48562 .59113 m .48674 .59342 L .48359 .59327 L F
.598 .44 .638 r
.48674 .59342 m .48425 .59636 L .48359 .59327 L F
.268 0 .192 r
.48204 .59506 m .48475 .59272 L .48361 .59326 L F
.48357 .59329 m .48361 .59326 L .48359 .59327 L F
.48204 .59506 m .48361 .59326 L .48357 .59329 L F
.582 .443 .656 r
.48425 .59636 m .48155 .5969 L .48134 .59512 L F
.48192 .59464 m .48134 .59512 L .48122 .59413 L F
.4815 .59403 m .48122 .59413 L .48117 .59375 L F
.113 0 0 r
.47963 .59573 m .48204 .59506 L .48357 .59329 L F
.48354 .59331 m .48357 .59329 L .48359 .59327 L F
.47963 .59573 m .48357 .59329 L .48354 .59331 L F
.47963 .59573 m .48359 .59327 L .48117 .59375 L F
0 0 .512 r
.18084 .61751 m .18178 .62121 L .18103 .61887 L F
.175 0 0 r
.17862 .56685 m .17546 .56885 L .17662 .56752 L F
.946 .723 .569 r
.52302 .53263 m .52482 .53361 L .52456 .5319 L F
.52302 .53263 m .52482 .53361 L .52456 .5319 L F
0 0 .255 r
.19936 .73007 m .20004 .73146 L .20146 .72912 L F
.19936 .73007 m .19961 .73268 L .20004 .73146 L F
.363 .02 .242 r
.27041 .63201 m .26902 .63082 L .27119 .63022 L F
.27041 .63201 m .26818 .63259 L .26902 .63082 L F
.909 .547 .335 r
.43779 .63019 m .43637 .63149 L .43589 .62937 L F
.43779 .63019 m .43637 .63149 L .43589 .62937 L F
0 0 .463 r
.43589 .62937 m .43637 .63149 L .43644 .63089 L F
.931 .695 .56 r
.43809 .62733 m .43589 .62937 L .43512 .62729 L F
.43809 .62733 m .43779 .63019 L .43589 .62937 L F
0 0 .463 r
.43589 .62937 m .43644 .63089 L .43686 .62746 L F
.931 .695 .56 r
.43512 .62729 m .43589 .62937 L .43408 .62728 L F
.89 .947 .59 r
.4393 .62354 m .43765 .62654 L .43809 .62733 L F
0 0 .181 r
.4388 .62848 m .43809 .62733 L .43765 .62654 L F
.4388 .62848 m .43779 .63019 L .43809 .62733 L F
.518 .914 .91 r
.68381 .43432 m .68556 .43432 L .68783 .43327 L F
.948 .846 .709 r
.73249 .38636 m .73072 .38627 L .73321 .38395 L F
.73249 .38636 m .73202 .38765 L .73072 .38627 L F
.687 .222 .141 r
.73249 .38636 m .73471 .3881 L .73202 .38765 L F
.976 .719 .478 r
.57219 .53972 m .57054 .5401 L .57071 .5388 L F
.57219 .53972 m .5721 .54167 L .57054 .5401 L F
.333 .816 .858 r
.22222 .53825 m .22448 .53761 L .2265 .53757 L F
.099 0 0 r
.22448 .53761 m .22867 .53723 L .2265 .53757 L F
.955 .759 .6 r
.5738 .52187 m .57167 .52339 L .5717 .52078 L F
.5738 .52187 m .57327 .52452 L .57167 .52339 L F
.279 .519 .905 r
.28173 .54018 m .28137 .54196 L .27964 .5404 L F
.28173 .54018 m .28308 .54219 L .28137 .54196 L F
0 0 0 r
.20616 .73157 m .20863 .73009 L .20748 .73219 L F
.324 .599 .946 r
.21021 .72952 m .20863 .73009 L .20669 .72812 L F
0 0 0 r
.20748 .73219 m .20863 .73009 L .21021 .72952 L F
.628 .761 .942 r
.53831 .60997 m .53908 .60745 L .5372 .60574 L F
.53831 .60997 m .54057 .60899 L .53908 .60745 L F
.33 .013 .268 r
.1524 .56345 m .15449 .56278 L .15575 .55955 L F
.276 0 .242 r
.15575 .55955 m .15644 .56203 L .15717 .56015 L F
.15575 .55955 m .15449 .56278 L .15644 .56203 L F
.364 .006 .217 r
.47391 .60346 m .47301 .60503 L .47087 .60559 L F
.194 0 .119 r
.47565 .60383 m .47391 .60346 L .47605 .60269 L F
.47565 .60383 m .47301 .60503 L .47391 .60346 L F
.612 .244 .321 r
.27068 .56275 m .27092 .56295 L .27292 .56261 L F
.225 .718 .919 r
.27487 .56369 m .27352 .56323 L .27254 .5634 L F
.27646 .56389 m .27254 .5634 L .27239 .56347 L F
.27239 .56347 m .27254 .5634 L .27226 .56345 L F
.2744 .56308 m .27406 .56307 L .27226 .56345 L F
.252 .522 .912 r
.27226 .56345 m .27426 .56302 L .27292 .56261 L F
.073 .256 .746 r
.27292 .56261 m .27444 .56537 L .27226 .56345 L F
.545 .288 .476 r
.27226 .56345 m .27444 .56537 L .27203 .56546 L F
.938 .57 .264 r
.2732 .56312 m .27288 .56459 L .27444 .56537 L F
.27292 .56261 m .27291 .56302 L .2732 .56312 L F
.27291 .56302 m .27288 .56459 L .2732 .56312 L F
.693 .952 .954 r
.2769 .56219 m .27426 .56302 L .27646 .56389 L F
.676 .149 0 r
.27596 .56299 m .27628 .56279 L .27502 .56379 L F
.2769 .56219 m .27648 .56259 L .27596 .56299 L F
.27648 .56259 m .27628 .56279 L .27596 .56299 L F
.225 .718 .919 r
.27516 .5636 m .2744 .56308 L .27352 .56323 L F
.27646 .56389 m .27535 .56345 L .27516 .5636 L F
.27535 .56345 m .2744 .56308 L .27516 .5636 L F
.27646 .56389 m .27352 .56323 L .27487 .56369 L F
.585 .875 .994 r
.27502 .56379 m .27444 .56537 L .2732 .56312 L F
.27355 .56297 m .2732 .56312 L .27292 .56261 L F
.27502 .56379 m .2732 .56312 L .27355 .56297 L F
.099 .61 .891 r
.27226 .56345 m .27068 .56275 L .26892 .56263 L F
.971 .704 .467 r
.27226 .56345 m .27203 .56546 L .27068 .56275 L F
.612 .244 .321 r
.27092 .56295 m .27288 .56459 L .27291 .56302 L F
.27092 .56295 m .27291 .56302 L .27292 .56261 L F
.225 .718 .919 r
.2744 .56308 m .27426 .56302 L .27406 .56307 L F
.033 .268 .766 r
.27646 .56389 m .27878 .56598 L .2769 .56219 L F
.478 .348 .625 r
.27646 .56389 m .2766 .56674 L .27878 .56598 L F
.457 .207 .446 r
.42762 .60947 m .43014 .6089 L .43033 .60623 L F
.579 .307 .469 r
.43033 .60623 m .43014 .6089 L .4326 .60812 L F
.891 .863 .805 r
.67242 .42789 m .67298 .42389 L .67416 .42523 L F
.67242 .42789 m .6708 .42697 L .67298 .42389 L F
.711 .31 .286 r
.67242 .42789 m .67052 .42897 L .6708 .42697 L F
.67242 .42789 m .6743 .42994 L .67052 .42897 L F
.553 .917 .952 r
.45329 .57534 m .45236 .5765 L .45444 .5749 L F
.45329 .57534 m .45086 .5763 L .45236 .5765 L F
.579 .513 .745 r
.30222 .58484 m .30061 .58777 L .29993 .58581 L F
.547 .475 .725 r
.30222 .58484 m .30316 .58741 L .30061 .58777 L F
.436 .262 .545 r
.30316 .58741 m .30078 .59084 L .30061 .58777 L F
0 0 0 r
.46972 .59991 m .47109 .59878 L .47254 .59754 L F
.497 .841 .996 r
.47109 .59878 m .47503 .59858 L .47254 .59754 L F
.432 .105 .31 r
.47254 .59754 m .47503 .59858 L .47511 .59696 L F
.845 .781 .79 r
.52077 .53539 m .52251 .53719 L .52482 .53361 L F
.906 .842 .77 r
.74613 .39441 m .74601 .39756 L .7451 .39639 L F
.816 .838 .866 r
.74601 .39756 m .74355 .39765 L .7451 .39639 L F
.748 .546 .622 r
.69153 .42129 m .69523 .42165 L .69509 .41898 L F
0 0 0 r
.43764 .6143 m .4352 .61466 L .43782 .61522 L F
.43764 .6143 m .43227 .61654 L .4352 .61466 L F
.518 .382 .635 r
.16554 .60412 m .16279 .61033 L .16358 .60692 L F
.383 .221 .534 r
.26609 .58809 m .26795 .59 L .26802 .58739 L F
.26609 .58809 m .26601 .59069 L .26795 .59 L F
.829 .679 .697 r
.5235 .54508 m .52513 .54867 L .52569 .5447 L F
0 0 0 r
.5235 .54508 m .52593 .54472 L .52569 .5447 L F
.829 .679 .697 r
.5235 .54508 m .52569 .5447 L .52593 .54472 L F
.471 .129 .303 r
.19081 .54354 m .19497 .54139 L .19323 .54314 L F
.77 .679 .762 r
.45347 .62349 m .45664 .6242 L .45534 .62131 L F
.793 .504 .498 r
.45347 .62349 m .45544 .62691 L .45664 .6242 L F
.69 .383 .452 r
.45664 .6242 m .45544 .62691 L .45896 .6266 L F
.665 .388 .49 r
.45664 .6242 m .45896 .6266 L .45915 .62436 L F
.059 0 0 r
.43272 .62346 m .43682 .62103 L .43283 .62143 L F
.352 .786 .967 r
.4344 .62311 m .4393 .62354 L .43682 .62103 L F
.4344 .62311 m .43828 .62291 L .4393 .62354 L F
.059 0 0 r
.43293 .62334 m .4344 .62311 L .43682 .62103 L F
.564 .756 .968 r
.43609 .6214 m .43828 .62291 L .4344 .62311 L F
.535 .556 .823 r
.43538 .62537 m .43582 .62288 L .4344 .62311 L F
.43582 .62288 m .43609 .6214 L .4344 .62311 L F
.059 0 0 r
.43272 .62346 m .4344 .62311 L .43293 .62334 L F
.728 .836 .932 r
.67656 .42414 m .67416 .42523 L .67298 .42389 L F
.417 .324 .642 r
.48933 .58823 m .49112 .58752 L .49127 .58444 L F
.925 .742 .256 r
.49114 .59005 m .49112 .58752 L .48933 .58823 L F
.414 .316 .635 r
.49112 .58752 m .49114 .59005 L .48933 .58823 L F
.935 .589 .346 r
.44243 .61646 m .44085 .61682 L .44063 .6167 L F
.225 0 0 r
.43782 .61522 m .44057 .61614 L .43862 .61549 L F
.327 0 0 r
.44087 .61443 m .44057 .61614 L .43782 .61522 L F
.44071 .61596 m .44057 .61614 L .44087 .61443 L F
.714 .227 .087 r
.44243 .61646 m .44057 .61614 L .44214 .6141 L F
.763 .323 .206 r
.43862 .61549 m .44057 .61614 L .44243 .61646 L F
.935 .589 .346 r
.4407 .61602 m .44063 .6167 L .43862 .61549 L F
.44243 .61646 m .44063 .6167 L .4407 .61602 L F
.327 0 0 r
.44214 .6141 m .44071 .61596 L .44087 .61443 L F
.414 .391 .725 r
.44309 .61147 m .44392 .61461 L .44214 .6141 L F
.714 .227 .087 r
.44243 .61646 m .44214 .6141 L .44392 .61461 L F
.904 .985 .755 r
.56766 .5702 m .56543 .57351 L .5656 .57132 L F
.937 .965 .737 r
.56692 .56937 m .56766 .5702 L .5656 .57132 L F
.697 .657 .807 r
.50336 .59673 m .50458 .60005 L .50148 .59997 L F
.463 .126 .308 r
.50458 .60005 m .50136 .6027 L .50148 .59997 L F
.50458 .60005 m .50347 .60239 L .50136 .6027 L F
.309 0 .118 r
.50662 .60038 m .50347 .60239 L .50458 .60005 L F
.77 .665 .747 r
.69518 .42431 m .69631 .4277 L .69882 .4246 L F
.329 0 .062 r
.55403 .51172 m .55035 .51411 L .55145 .51216 L F
.845 .781 .79 r
.52077 .53539 m .52482 .53361 L .52302 .53263 L F
.541 .598 .86 r
.16381 .62634 m .16433 .6277 L .16641 .62726 L F
0 0 0 r
.81818 .44402 m .81793 .44344 L .81816 .44149 L F
.81818 .44402 m .81744 .44557 L .81793 .44344 L F
.646 .152 0 r
.537 .56684 m .53909 .56947 L .53935 .56936 L F
0 0 .138 r
.53909 .56947 m .53959 .57293 L .53935 .56936 L F
0 0 .352 r
.77132 .42224 m .76972 .42241 L .77177 .41973 L F
.77132 .42224 m .77002 .42397 L .76972 .42241 L F
.13 .677 .806 r
.21613 .53811 m .2184 .53795 L .22005 .53808 L F
0 .534 .708 r
.22005 .53808 m .2184 .53795 L .22222 .53825 L F
.464 .663 .948 r
.24344 .65434 m .24089 .65621 L .24084 .65624 L F
.24344 .65434 m .24535 .65689 L .24089 .65621 L F
.642 .438 .592 r
.4487 .61746 m .45114 .61827 L .44968 .61632 L F
.274 .324 .733 r
.44968 .61632 m .4526 .61605 L .4525 .61473 L F
.44968 .61632 m .45114 .61827 L .4526 .61605 L F
.569 .692 .924 r
.1833 .64243 m .18384 .64026 L .18123 .63954 L F
.243 .357 .781 r
.7584 .4243 m .75962 .42787 L .76108 .42611 L F
.339 .5 .872 r
.75962 .42787 m .76273 .4291 L .76108 .42611 L F
.753 .498 .546 r
.506 .59118 m .5052 .59344 L .50228 .59277 L F
.793 .555 .577 r
.243 .66067 m .2418 .66321 L .2407 .66244 L F
0 0 0 r
.24528 .65951 m .2418 .66321 L .243 .66067 L F
.329 .318 .695 r
.41227 .63917 m .41303 .6432 L .41483 .64145 L F
0 0 0 r
.41373 .64517 m .41483 .64145 L .41303 .6432 L F
.448 .258 .53 r
.20302 .71806 m .20484 .72008 L .20532 .71748 L F
.539 0 0 r
.42604 .65701 m .42861 .65774 L .42457 .65717 L F
0 .173 .71 r
.2384 .65988 m .23823 .65871 L .23652 .65974 L F
.838 .394 .168 r
.40367 .62703 m .4022 .62712 L .40046 .62429 L F
0 .34 .817 r
.40367 .62703 m .40407 .62605 L .4022 .62712 L F
.40367 .62703 m .40526 .62785 L .40407 .62605 L F
.674 .283 .297 r
.55763 .49925 m .5599 .49958 L .55757 .49752 L F
.59 .319 .474 r
.55757 .49752 m .5599 .49958 L .55955 .49744 L F
.493 .36 .628 r
.30207 .55442 m .30224 .55714 L .30014 .55776 L F
.486 .377 .654 r
.30224 .55714 m .30042 .56106 L .30014 .55776 L F
.455 .854 .972 r
.21551 .62996 m .21541 .63085 L .21386 .62912 L F
.21551 .62996 m .21747 .63029 L .21541 .63085 L F
0 .118 .641 r
.40855 .62344 m .41177 .62676 L .4108 .62643 L F
.457 .787 .999 r
.75425 .39114 m .75165 .39153 L .75069 .39054 L F
.706 .937 .627 r
.56293 .57645 m .56391 .57475 L .56543 .57351 L F
.914 .961 .638 r
.56543 .57351 m .56391 .57475 L .5656 .57132 L F
.16 0 0 r
.46657 .60253 m .4686 .60192 L .46972 .59991 L F
.287 0 .057 r
.46972 .59991 m .47085 .60134 L .47109 .59878 L F
.46972 .59991 m .4686 .60192 L .47085 .60134 L F
.598 .333 .486 r
.56017 .50955 m .56254 .51158 L .56025 .51156 L F
.985 .709 .399 r
.65448 .43691 m .65447 .43941 L .6531 .43563 L F
.682 .854 .965 r
.6575 .43582 m .65448 .43691 L .6531 .43563 L F
.677 .63 .795 r
.6575 .43582 m .65825 .43774 L .65448 .43691 L F
.192 .069 .474 r
.45411 .63823 m .45239 .63649 L .45502 .63569 L F
.45411 .63823 m .45224 .6392 L .45239 .63649 L F
0 0 .137 r
.40548 .60857 m .40651 .60503 L .40524 .60637 L F
.922 .796 .705 r
.43923 .64108 m .4421 .64294 L .44122 .63761 L F
.347 0 .065 r
.4421 .64294 m .44291 .64419 L .44051 .64457 L F
.785 .55 .581 r
.43923 .64108 m .44291 .64419 L .4421 .64294 L F
.607 .593 .81 r
.44122 .63761 m .4421 .64294 L .446 .64194 L F
.594 .253 .36 r
.44601 .64194 m .44291 .64419 L .4421 .64294 L F
.44677 .64175 m .44595 .64226 L .44601 .64194 L F
.44595 .64226 m .44291 .64419 L .44601 .64194 L F
.44616 .64213 m .44564 .64424 L .44291 .64419 L F
.44677 .64175 m .44564 .64424 L .44616 .64213 L F
.612 .311 .435 r
.44291 .64419 m .44515 .64633 L .44564 .64424 L F
.44291 .64419 m .44515 .64633 L .44564 .64424 L F
.749 .721 .191 r
.44515 .64633 m .4452 .64604 L .44564 .64424 L F
.598 .264 .375 r
.44291 .64419 m .4455 .64424 L .44588 .64202 L F
.4459 .64201 m .44564 .64424 L .446 .64194 L F
.44291 .64419 m .446 .64194 L .4421 .64294 L F
.607 .593 .81 r
.44122 .63761 m .446 .64194 L .44554 .63849 L F
.749 .721 .191 r
.4452 .64604 m .44593 .64175 L .44564 .64424 L F
.723 .672 .123 r
.446 .64194 m .44593 .64236 L .44593 .64175 L F
.44593 .64236 m .44564 .64424 L .4457 .64377 L F
.44593 .64236 m .4457 .64377 L .44593 .64175 L F
.45 .381 .688 r
.30447 .56908 m .30212 .57181 L .30219 .56954 L F
.573 .377 .577 r
.3054 .57454 m .30212 .57181 L .30486 .57423 L F
.574 .477 .706 r
.30738 .5726 m .30493 .57419 L .30447 .56908 L F
.30493 .57419 m .30486 .57423 L .30486 .57419 L F
.573 .377 .577 r
.30499 .57419 m .30486 .57419 L .30212 .57181 L F
.574 .477 .706 r
.30493 .57419 m .30486 .57419 L .30447 .56908 L F
.573 .377 .577 r
.3054 .57454 m .30539 .57465 L .30486 .57419 L F
.516 .396 .655 r
.30494 .57422 m .3054 .57454 L .30486 .57423 L F
.573 .377 .577 r
.3054 .57454 m .3049 .57419 L .30499 .57419 L F
.516 .396 .655 r
.3076 .57371 m .3054 .57454 L .30494 .57422 L F
.573 .377 .577 r
.3054 .57454 m .30486 .57419 L .3049 .57419 L F
.45 .381 .688 r
.30486 .57419 m .30486 .57423 L .30212 .57181 L F
.573 .377 .577 r
.30539 .57465 m .30519 .57726 L .30212 .57181 L F
.45 .381 .688 r
.30447 .56908 m .30486 .57419 L .30212 .57181 L F
.496 .432 .715 r
.25934 .60296 m .26056 .59897 L .25883 .60038 L F
0 0 0 r
.25741 .63925 m .25384 .64156 L .25501 .63937 L F
.588 .315 .471 r
.45261 .61192 m .45581 .61391 L .456 .61157 L F
.45261 .61192 m .4525 .61473 L .45581 .61391 L F
.501 0 0 r
.25684 .55631 m .25705 .55683 L .25591 .55594 L F
.428 0 0 r
.25895 .55698 m .25705 .55683 L .25684 .55631 L F
0 0 .414 r
.52984 .58443 m .53016 .58305 L .52906 .58152 L F
.868 .884 .845 r
.75656 .4052 m .76014 .40333 L .75945 .40239 L F
.868 .969 .857 r
.76213 .39949 m .76014 .40333 L .7628 .40018 L F
.76213 .39949 m .75945 .40239 L .76014 .40333 L F
.483 .52 .819 r
.65955 .43542 m .65825 .43774 L .6575 .43582 L F
.654 .738 .911 r
.65955 .43542 m .66108 .43749 L .65825 .43774 L F
.24 .085 .459 r
.49132 .58184 m .49287 .58353 L .49339 .58116 L F
.49132 .58184 m .49127 .58444 L .49287 .58353 L F
0 0 .284 r
.52833 .52151 m .52933 .51988 L .52877 .51826 L F
0 0 .076 r
.52856 .52323 m .52833 .52151 L .53048 .52403 L F
.52856 .52323 m .52933 .51988 L .52833 .52151 L F
.981 .689 .361 r
.73072 .38627 m .73202 .38765 L .73091 .38949 L F
.447 0 0 r
.73202 .38765 m .73421 .38975 L .73091 .38949 L F
.73202 .38765 m .73471 .3881 L .73427 .38957 L F
.73202 .38765 m .73427 .38957 L .73399 .38954 L F
.524 .272 .474 r
.73089 .38924 m .73414 .38781 L .73072 .38627 L F
.73091 .38949 m .73132 .38928 L .73089 .38924 L F
.73132 .38928 m .73414 .38781 L .73089 .38924 L F
.447 0 0 r
.73399 .38954 m .73427 .38957 L .73421 .38975 L F
.326 .769 .963 r
.44666 .65119 m .44818 .65042 L .44783 .65136 L F
.768 .467 .476 r
.44783 .65136 m .44561 .65354 L .44666 .65119 L F
.44783 .65136 m .44942 .65396 L .44561 .65354 L F
.413 .844 .949 r
.44783 .65136 m .44818 .65042 L .45022 .65026 L F
0 0 .141 r
.45022 .65026 m .44942 .65396 L .44783 .65136 L F
.681 .709 .869 r
.82756 .42417 m .83132 .42494 L .83055 .42294 L F
.65 .704 .887 r
.83132 .42494 m .83321 .42114 L .83055 .42294 L F
.83132 .42494 m .834 .42407 L .83321 .42114 L F
.948 .922 .749 r
.57069 .55779 m .56933 .56067 L .56823 .55907 L F
.999 .805 .508 r
.56921 .56353 m .56823 .55907 L .56933 .56067 L F
.305 0 .044 r
.16759 .55402 m .17188 .55125 L .16984 .55204 L F
.857 .815 .807 r
.5831 .52998 m .58625 .53025 L .58514 .52721 L F
.881 .737 .698 r
.5843 .53343 m .58625 .53025 L .5831 .52998 L F
.506 .568 .853 r
.46224 .59415 m .46536 .59688 L .46459 .59346 L F
.523 .706 .954 r
.27175 .53781 m .271 .53996 L .26937 .53836 L F
.27175 .53781 m .27319 .53956 L .271 .53996 L F
0 0 .514 r
.50128 .57162 m .502 .57272 L .49986 .56985 L F
.862 .415 .119 r
.50128 .57162 m .50409 .5748 L .502 .57272 L F
.638 .093 0 r
.502 .57272 m .50409 .5748 L .50563 .57567 L F
0 0 .262 r
.53276 .55712 m .53351 .56 L .53355 .56086 L F
.765 .349 0 r
.53364 .56195 m .5349 .56362 L .53355 .56086 L F
.53364 .56195 m .53355 .56086 L .53351 .56 L F
.325 .36 .744 r
.30338 .58051 m .30185 .58256 L .30099 .5788 L F
.481 .319 .583 r
.30433 .58404 m .30185 .58256 L .30338 .58051 L F
.30433 .58404 m .30222 .58484 L .30185 .58256 L F
.374 .536 .888 r
.16213 .59879 m .16148 .60087 L .16 .59978 L F
.16213 .59879 m .16465 .60276 L .16148 .60087 L F
.861 .708 .691 r
.69323 .42743 m .69631 .4277 L .69518 .42431 L F
.91 .732 .649 r
.56935 .55423 m .57069 .55779 L .56891 .55678 L F
.948 .922 .749 r
.57069 .55779 m .56823 .55907 L .56891 .55678 L F
.277 .754 .933 r
.19769 .53924 m .19969 .53907 L .20167 .5395 L F
.496 0 0 r
.19969 .53907 m .20382 .539 L .20167 .5395 L F
.865 .791 .777 r
.82222 .42687 m .82504 .42781 L .82575 .42556 L F
.89 .75 .702 r
.82321 .43049 m .82504 .42781 L .82222 .42687 L F
.745 .533 .607 r
.82321 .43049 m .82722 .43096 L .82504 .42781 L F
.735 .649 .764 r
.82504 .42781 m .82756 .42417 L .82575 .42556 L F
.807 .539 .533 r
.82504 .42781 m .82722 .43096 L .82845 .43091 L F
.371 .059 .3 r
.28682 .61491 m .28388 .61754 L .28432 .61513 L F
0 0 0 r
.41373 .64517 m .4143 .64393 L .41483 .64145 L F
0 .142 .682 r
.41373 .64517 m .41576 .64739 L .4143 .64393 L F
.192 .224 .666 r
.41373 .64517 m .41469 .64891 L .41576 .64739 L F
.14 0 0 r
.46698 .6282 m .46439 .62964 L .46282 .62977 L F
.396 0 0 r
.46863 .62909 m .46698 .6282 L .46882 .62674 L F
.46863 .62909 m .46439 .62964 L .46698 .6282 L F
.623 .682 .886 r
.73937 .40738 m .7412 .40473 L .73856 .40558 L F
.73937 .40738 m .74198 .40666 L .7412 .40473 L F
.578 .266 .404 r
.23646 .67768 m .23456 .67564 L .23666 .67509 L F
0 0 0 r
.23456 .67564 m .23257 .6762 L .23666 .67509 L F
.578 .266 .404 r
.23646 .67768 m .23374 .67812 L .23456 .67564 L F
.794 .604 .644 r
.42034 .60583 m .42002 .60857 L .42416 .6089 L F
.778 .717 .795 r
.42002 .60857 m .42215 .60983 L .42416 .6089 L F
.576 .611 .851 r
.541 .58765 m .5427 .59051 L .54025 .59105 L F
.8 .379 0 r
.51101 .5846 m .51215 .58718 L .51316 .58826 L F
.866 .664 .133 r
.51284 .5894 m .51316 .58826 L .51215 .58718 L F
.51284 .5894 m .51321 .59049 L .51316 .58826 L F
.537 .246 .421 r
.26057 .63674 m .25978 .63923 L .25741 .63925 L F
.273 .002 .308 r
.26189 .63816 m .26057 .63674 L .26292 .63608 L F
.26189 .63816 m .25978 .63923 L .26057 .63674 L F
0 .482 .699 r
.78372 .39619 m .78807 .39687 L .78689 .39561 L F
.089 .438 .877 r
.78807 .39687 m .78885 .39613 L .78689 .39561 L F
.78807 .39687 m .78967 .39768 L .78885 .39613 L F
.121 0 .183 r
.15044 .56411 m .15136 .56506 L .1524 .56345 L F
.15044 .56411 m .14964 .56611 L .15136 .56506 L F
.222 .564 .937 r
.80636 .40002 m .80432 .39961 L .80334 .39817 L F
.862 .6 .541 r
.42235 .6726 m .41965 .67292 L .41867 .67185 L F
.777 .354 .246 r
.41867 .67185 m .42016 .67258 L .42235 .6726 L F
.862 .6 .541 r
.42235 .6726 m .42234 .67527 L .41965 .67292 L F
.41965 .67292 m .42235 .6726 L .42016 .67258 L F
.41965 .67292 m .42234 .67527 L .42235 .6726 L F
.707 .406 .465 r
.56627 .50954 m .56668 .51178 L .56254 .51158 L F
.774 .453 .443 r
.57027 .51224 m .56668 .51178 L .56627 .50954 L F
.465 .361 .652 r
.42541 .64247 m .42768 .64206 L .42682 .63699 L F
.505 .323 .568 r
.42541 .64247 m .42752 .64427 L .42768 .64206 L F
.42541 .64247 m .42561 .64554 L .42752 .64427 L F
.7 .164 0 r
.50195 .58903 m .50085 .5892 L .50106 .58701 L F
.50195 .58903 m .50362 .59074 L .50085 .5892 L F
.303 0 .209 r
.1561 .58414 m .15389 .58388 L .15642 .58203 L F
.1561 .58414 m .15384 .58484 L .15389 .58388 L F
.338 0 0 r
.44599 .57804 m .44255 .57878 L .44323 .57843 L F
.733 .746 .863 r
.2535 .55102 m .25439 .55254 L .25743 .5515 L F
.77 .675 .759 r
.25743 .5515 m .25591 .55594 L .2535 .55102 L F
.496 0 0 r
.25591 .55594 m .25705 .55683 L .25308 .55617 L F
.177 0 0 r
.21747 .63029 m .22003 .6303 L .22141 .62992 L F
.231 .749 .763 r
.22003 .6303 m .22369 .62952 L .22141 .62992 L F
.194 .67 .934 r
.5098 .54171 m .51287 .54206 L .51431 .54286 L F
.691 .383 .45 r
.51351 .54017 m .5139 .54097 L .51457 .53935 L F
.905 .93 .821 r
.51431 .54286 m .51457 .53935 L .51474 .53893 L F
.51431 .54286 m .51287 .54206 L .51457 .53935 L F
.691 .383 .45 r
.5139 .54097 m .51469 .54257 L .51457 .53935 L F
.905 .93 .821 r
.51474 .53893 m .51457 .53935 L .51481 .53829 L F
.507 .665 .933 r
.14937 .59216 m .15032 .59396 L .14981 .59403 L F
.682 .507 .643 r
.80301 .42709 m .80674 .42783 L .80514 .42445 L F
.662 .502 .656 r
.80514 .42445 m .80907 .42461 L .80862 .42205 L F
.689 .51 .64 r
.80514 .42445 m .80955 .42706 L .80907 .42461 L F
.80514 .42445 m .80674 .42783 L .80955 .42706 L F
.541 .357 .58 r
.42035 .58836 m .42012 .59068 L .42255 .58761 L F
.9 .759 .695 r
.41756 .65942 m .42098 .66259 L .42159 .65737 L F
.803 .946 .917 r
.41862 .6619 m .42098 .66259 L .41756 .65942 L F
.41862 .6619 m .41944 .66319 L .42098 .66259 L F
.1 0 0 r
.80064 .44285 m .79975 .44388 L .79707 .44454 L F
.088 0 0 r
.80324 .443 m .79975 .44388 L .80064 .44285 L F
.581 .515 .745 r
.55506 .5878 m .55732 .5832 L .55458 .58407 L F
.413 .583 .91 r
.76273 .4291 m .76331 .43094 L .76488 .42909 L F
.435 .615 .926 r
.76488 .42909 m .76331 .43094 L .76569 .43092 L F
.074 .293 .778 r
.18067 .61374 m .18004 .61529 L .17935 .61329 L F
.02 .225 .732 r
.18067 .61374 m .18226 .61736 L .18004 .61529 L F
.282 .278 .678 r
.18004 .61529 m .18226 .61736 L .18084 .61751 L F
.623 .664 .869 r
.7395 .39647 m .74355 .39765 L .74064 .3985 L F
.131 .263 .734 r
.79404 .4 m .79516 .40368 L .79632 .40202 L F
.199 .361 .801 r
.79516 .40368 m .79791 .4055 L .79632 .40202 L F
.634 .369 .499 r
.48165 .61223 m .48384 .61377 L .48557 .61242 L F
0 0 .01 r
.48637 .60823 m .48557 .61242 L .4871 .61119 L F
.927 .97 .759 r
.48557 .61242 m .48335 .61339 L .48384 .61377 L F
.451 .821 .567 r
.4871 .61119 m .48384 .61377 L .48557 .61242 L F
.4871 .61119 m .48384 .61377 L .48557 .61242 L F
.752 .743 .844 r
.42121 .65432 m .41659 .65753 L .42159 .65737 L F
.41659 .65753 m .41659 .65754 L .42159 .65737 L F
.9 .759 .695 r
.41756 .65942 m .42159 .65737 L .41659 .65754 L F
.349 .328 .695 r
.41627 .6585 m .41678 .65697 L .41655 .65754 L F
.9 .759 .695 r
.41659 .65755 m .41659 .65754 L .41658 .65754 L F
.41756 .65942 m .41659 .65754 L .41659 .65755 L F
.349 .328 .695 r
.41666 .65736 m .41717 .65595 L .41678 .65697 L F
.767 .967 .927 r
.41717 .65595 m .41658 .65754 L .41659 .65753 L F
.41717 .65595 m .41659 .65753 L .42121 .65432 L F
0 0 .519 r
.41717 .65595 m .41756 .65942 L .41659 .65755 L F
.349 .328 .695 r
.41665 .65739 m .41717 .65595 L .41666 .65736 L F
.752 .743 .844 r
.41659 .65753 m .41658 .65754 L .41659 .65754 L F
0 0 .519 r
.41717 .65595 m .41659 .65755 L .41658 .65754 L F
.349 .328 .695 r
.41654 .65774 m .41717 .65595 L .41665 .65739 L F
.41587 .65985 m .41637 .65836 L .41654 .65774 L F
.41637 .65836 m .41717 .65595 L .41654 .65774 L F
.41587 .65985 m .41678 .65697 L .41627 .6585 L F
.876 .466 .237 r
.80964 .44633 m .81057 .44609 L .81104 .44783 L F
.382 .807 .97 r
.2326 .53738 m .22867 .53723 L .23045 .53698 L F
.329 .797 .926 r
.23453 .53697 m .2326 .53738 L .23045 .53698 L F
.515 .315 .547 r
.65936 .41575 m .65939 .41845 L .65683 .41897 L F
.539 .334 .55 r
.66198 .4177 m .65936 .41575 L .66163 .41469 L F
.66198 .4177 m .65939 .41845 L .65936 .41575 L F
.21 0 0 r
.79842 .43598 m .80099 .43527 L .80174 .43381 L F
.318 0 0 r
.80099 .43527 m .80436 .43344 L .80174 .43381 L F
.763 .654 .741 r
.52134 .54769 m .52513 .54867 L .5235 .54508 L F
.729 .283 .19 r
.52134 .54769 m .52363 .55003 L .52513 .54867 L F
.962 .674 .442 r
.52363 .55003 m .52554 .55067 L .52513 .54867 L F
.828 .653 .665 r
.82722 .43096 m .82685 .43372 L .82845 .43091 L F
.011 .128 .64 r
.40046 .62429 m .4022 .62712 L .4012 .62283 L F
0 0 0 r
.53215 .51729 m .53553 .51491 L .53339 .51596 L F
.04 0 0 r
.52877 .51826 m .53215 .51729 L .53339 .51596 L F
.608 .545 .758 r
.43894 .60303 m .44033 .59892 L .43803 .59958 L F
.43894 .60303 m .44167 .60257 L .44033 .59892 L F
.523 .41 .667 r
.43894 .60303 m .44148 .6052 L .44167 .60257 L F
.43894 .60303 m .43956 .60647 L .44148 .6052 L F
.753 .895 .497 r
.21516 .68612 m .21725 .68319 L .21472 .68746 L F
.668 .721 .889 r
.21558 .68097 m .21725 .68319 L .22012 .68214 L F
.736 .372 .361 r
.21901 .68672 m .21725 .68319 L .21516 .68612 L F
0 0 0 r
.723 .39252 m .72321 .39165 L .72077 .3946 L F
.452 .367 .669 r
.72077 .3946 m .7235 .39632 L .723 .39252 L F
.499 .352 .612 r
.72077 .3946 m .72109 .39711 L .7235 .39632 L F
.348 .386 .759 r
.26722 .5784 m .26768 .57496 L .26575 .57638 L F
.312 .236 .609 r
.84403 .41491 m .84285 .419 L .84128 .41495 L F
.84403 .41491 m .8443 .41751 L .84285 .419 L F
0 0 .07 r
.84285 .419 m .8443 .41751 L .84217 .42084 L F
.949 .792 .653 r
.65683 .41897 m .65515 .41823 L .65596 .41532 L F
.871 .432 .132 r
.65683 .41897 m .6558 .41994 L .65515 .41823 L F
.36 0 0 r
.65841 .41984 m .65683 .41897 L .65939 .41845 L F
.65841 .41984 m .6558 .41994 L .65683 .41897 L F
.489 .248 .476 r
.44941 .60623 m .44878 .60868 L .44642 .60918 L F
.636 .389 .527 r
.45066 .60808 m .44941 .60623 L .45085 .60561 L F
.45066 .60808 m .44878 .60868 L .44941 .60623 L F
.76 .522 .573 r
.42936 .64515 m .42663 .64702 L .42561 .64554 L F
.42936 .64515 m .42928 .64857 L .42663 .64702 L F
.505 .262 .479 r
.43201 .64508 m .42928 .64857 L .42936 .64515 L F
.765 .907 .938 r
.22394 .64615 m .22786 .64526 L .22616 .64574 L F
0 0 0 r
.22786 .64526 m .2283 .64525 L .22616 .64574 L F
.22786 .64526 m .23005 .64486 L .2283 .64525 L F
.631 .491 .674 r
.18636 .64294 m .18705 .64577 L .1896 .64351 L F
.773 .554 .603 r
.21558 .68097 m .21755 .67829 L .2162 .67872 L F
.941 .822 .699 r
.51639 .62453 m .51516 .62618 L .51484 .62404 L F
.51639 .62453 m .51516 .62618 L .51484 .62404 L F
.603 .318 .457 r
.45896 .6266 m .46277 .62411 L .45915 .62436 L F
.436 .433 .757 r
.41553 .63218 m .41326 .63372 L .41255 .63069 L F
.448 .124 .323 r
.41604 .63535 m .41326 .63372 L .41553 .63218 L F
.41604 .63535 m .41221 .63705 L .41326 .63372 L F
0 0 .328 r
.58203 .57679 m .5811 .57585 L .58214 .57428 L F
.58203 .57679 m .58142 .57846 L .5811 .57585 L F
.49 .438 .726 r
.42834 .61125 m .43014 .6089 L .42762 .60947 L F
.42834 .61125 m .43037 .61117 L .43014 .6089 L F
0 0 .079 r
.23054 .68734 m .23279 .6838 L .2323 .6871 L F
.589 .266 .39 r
.2323 .6871 m .22868 .68884 L .23054 .68734 L F
.348 .386 .759 r
.26722 .5784 m .26868 .57811 L .26768 .57496 L F
.86 .896 .859 r
.75485 .41925 m .75272 .4218 L .75243 .41951 L F
.184 .406 .844 r
.75332 .42367 m .75243 .41951 L .75272 .4218 L F
.688 .758 .905 r
.72594 .40423 m .72979 .40497 L .72854 .40319 L F
.695 .729 .877 r
.72979 .40497 m .73105 .40207 L .72854 .40319 L F
.72979 .40497 m .732 .40386 L .73105 .40207 L F
.02 0 0 r
.2281 .62882 m .23258 .6272 L .23025 .62769 L F
.255 .712 .953 r
.55088 .60994 m .54903 .60883 L .54636 .60898 L F
.294 0 0 r
.5529 .6089 m .54903 .60883 L .55088 .60994 L F
.778 .524 .553 r
.57858 .4968 m .58226 .4996 L .58224 .49742 L F
.994 .767 .479 r
.43077 .62439 m .42983 .62104 L .42792 .62171 L F
.43077 .62439 m .42931 .62328 L .42983 .62104 L F
.303 .045 .346 r
.42983 .62104 m .42931 .62328 L .43162 .62041 L F
.42983 .62104 m .43162 .62041 L .43183 .62015 L F
.994 .767 .479 r
.42792 .62171 m .42983 .62104 L .42707 .62091 L F
.485 .28 .526 r
.51293 .59574 m .51181 .59846 L .51175 .59599 L F
.51404 .59551 m .5127 .59728 L .51293 .59574 L F
.5127 .59728 m .51181 .59846 L .51293 .59574 L F
0 0 .413 r
.51325 .59356 m .51382 .59573 L .51409 .59444 L F
.51312 .59343 m .51322 .59375 L .51325 .59356 L F
.51322 .59375 m .51382 .59573 L .51325 .59356 L F
.778 .607 .668 r
.44911 .62109 m .44676 .62412 L .4492 .62395 L F
.606 .504 .712 r
.4487 .61746 m .44911 .62109 L .45114 .61827 L F
.649 .563 .744 r
.45114 .61827 m .44911 .62109 L .45196 .62043 L F
.68 .53 .675 r
.44911 .62109 m .45347 .62349 L .45196 .62043 L F
.44911 .62109 m .4492 .62395 L .45347 .62349 L F
.616 .648 .858 r
.7322 .39351 m .73075 .39728 L .73121 .39385 L F
.7322 .39351 m .73329 .3964 L .73075 .39728 L F
.635 .659 .857 r
.73468 .39247 m .73329 .3964 L .7322 .39351 L F
0 0 0 r
.73397 .39291 m .7322 .39351 L .73142 .39451 L F
.73468 .39247 m .7322 .39351 L .73397 .39291 L F
.616 .648 .858 r
.7322 .39351 m .73121 .39385 L .73137 .39263 L F
.811 .986 .885 r
.76494 .3971 m .7628 .40018 L .76533 .39732 L F
.76494 .3971 m .76213 .39949 L .7628 .40018 L F
0 .102 .657 r
.53112 .5537 m .53276 .55712 L .53153 .55536 L F
.429 .184 .439 r
.26119 .59678 m .26338 .59638 L .26385 .59386 L F
.321 .143 .477 r
.26385 .59386 m .26583 .59342 L .26601 .59069 L F
.222 .008 .362 r
.26385 .59386 m .26524 .59529 L .26583 .59342 L F
.26385 .59386 m .26338 .59638 L .26524 .59529 L F
.74 .99 .802 r
.48055 .61643 m .4799 .61808 L .48284 .61553 L F
.655 .146 .023 r
.48284 .61553 m .48477 .6172 L .48055 .61643 L F
.247 .247 .662 r
.48384 .61377 m .48477 .6172 L .48284 .61553 L F
.655 .497 .658 r
.50122 .52489 m .50126 .52739 L .50344 .52436 L F
.709 .178 0 r
.52554 .55067 m .52769 .55306 L .52863 .55237 L F
.555 0 0 r
.52769 .55306 m .53112 .5537 L .52863 .55237 L F
.519 .659 .924 r
.74619 .40912 m .7473 .40674 L .74434 .40607 L F
.74619 .40912 m .74824 .40851 L .7473 .40674 L F
.629 .625 .827 r
.74619 .40912 m .74975 .41018 L .74824 .40851 L F
.993 .777 .505 r
.50912 .59833 m .51067 .60003 L .50969 .59755 L F
.204 .391 .826 r
.50969 .59755 m .51067 .60003 L .51181 .59846 L F
0 0 .301 r
.51067 .60003 m .51169 .60106 L .51181 .59846 L F
.668 .537 .696 r
.71623 .40316 m .71976 .40397 L .71877 .4005 L F
.538 .263 .446 r
.14957 .58862 m .14843 .59128 L .1478 .59062 L F
.631 .461 .634 r
.15134 .58754 m .14843 .59128 L .14957 .58862 L F
.99 .876 .541 r
.56981 .55177 m .56898 .55065 L .56985 .54792 L F
.997 .86 .55 r
.56935 .55423 m .56898 .55065 L .56981 .55177 L F
.302 0 .097 r
.14141 .5721 m .14494 .56961 L .14469 .56982 L F
.108 0 .007 r
.25393 .60872 m .25567 .60804 L .25702 .60608 L F
.427 .072 .258 r
.25567 .60804 m .25925 .60554 L .25702 .60608 L F
.793 .801 .311 r
.58371 .56335 m .58297 .5651 L .58297 .56693 L F
.842 .751 .234 r
.58297 .5651 m .58274 .56921 L .58297 .56693 L F
0 0 0 r
.14792 .56705 m .14673 .56858 L .14964 .56611 L F
.512 .682 .943 r
.81895 .40279 m .81729 .40487 L .81635 .40302 L F
.81895 .40279 m .8205 .40496 L .81729 .40487 L F
.599 .532 .751 r
.80862 .42205 m .8104 .41796 L .80776 .41868 L F
.80862 .42205 m .8115 .4215 L .8104 .41796 L F
.633 .482 .659 r
.80862 .42205 m .81182 .42399 L .8115 .4215 L F
.80862 .42205 m .80907 .42461 L .81182 .42399 L F
.444 .232 .495 r
.43232 .57283 m .43004 .57635 L .43209 .57482 L F
.092 .39 .848 r
.40703 .63031 m .40784 .62915 L .40526 .62785 L F
0 .181 .707 r
.40703 .63031 m .40917 .63257 L .40784 .62915 L F
.009 0 0 r
.46044 .61801 m .45732 .6199 L .45835 .6189 L F
.586 .416 .618 r
.48036 .61902 m .47778 .6215 L .4799 .61808 L F
0 0 .303 r
.48055 .61643 m .48036 .61902 L .4799 .61808 L F
.32 .555 .919 r
.2023 .62486 m .20185 .62671 L .19965 .62428 L F
.2023 .62486 m .20359 .62673 L .20185 .62671 L F
.876 .877 .833 r
.21099 .72001 m .21284 .72086 L .20928 .72238 L F
.813 .577 .582 r
.21284 .72086 m .21285 .72367 L .20928 .72238 L F
.457 .811 .997 r
.21498 .72042 m .21284 .72086 L .21099 .72001 L F
0 0 .372 r
.21345 .72243 m .21284 .72086 L .21498 .72042 L F
.21345 .72243 m .21285 .72367 L .21284 .72086 L F
.492 .711 .968 r
.20568 .62651 m .20521 .62843 L .20359 .62673 L F
.20568 .62651 m .20757 .62844 L .20521 .62843 L F
.938 .793 .674 r
.58346 .54747 m .58613 .54758 L .58622 .54523 L F
.944 .793 .663 r
.58288 .55001 m .58613 .54758 L .58346 .54747 L F
.58288 .55001 m .58452 .55092 L .58613 .54758 L F
.658 .575 .749 r
.18377 .61906 m .18178 .62121 L .18084 .61751 L F
.485 .834 .996 r
.21705 .64653 m .22199 .64684 L .22069 .64601 L F
.483 .865 .977 r
.22069 .64601 m .22199 .64684 L .22394 .64615 L F
.524 .233 .414 r
.80436 .43344 m .80711 .43354 L .80746 .43057 L F
.613 .502 .704 r
.80746 .43057 m .80955 .42706 L .80674 .42783 L F
.80746 .43057 m .80983 .43033 L .80955 .42706 L F
.589 .289 .427 r
.80746 .43057 m .8101 .43154 L .80983 .43033 L F
.80746 .43057 m .80711 .43354 L .8101 .43154 L F
0 0 0 r
.46481 .5618 m .46373 .56236 L .46698 .56089 L F
.058 .259 .753 r
.41488 .65392 m .41655 .65754 L .41717 .65595 L F
.664 .577 .747 r
.5147 .53336 m .51404 .53608 L .51094 .53031 L F
.937 .898 .5 r
.5147 .53336 m .51144 .53397 L .51404 .53608 L F
.435 .307 .606 r
.21513 .69044 m .21297 .69084 L .21472 .68746 L F
.444 .171 .403 r
.21428 .69267 m .21297 .69084 L .21207 .69314 L F
.839 .392 .157 r
.50441 .57651 m .50563 .57567 L .50409 .5748 L F
.50441 .57651 m .50713 .57826 L .50563 .57567 L F
.497 .566 .855 r
.17442 .63701 m .17638 .63485 L .17437 .63495 L F
.17442 .63701 m .17783 .63774 L .17638 .63485 L F
0 0 .187 r
.58126 .58092 m .58083 .58337 L .57953 .58488 L F
0 0 .189 r
.58083 .58337 m .57937 .58728 L .57953 .58488 L F
.471 .056 .17 r
.43055 .64011 m .43296 .64102 L .43446 .63886 L F
.809 .586 .6 r
.43296 .64102 m .43686 .63896 L .43446 .63886 L F
.255 0 0 r
.72495 .39207 m .72321 .39165 L .723 .39252 L F
.72495 .39207 m .72585 .39118 L .72321 .39165 L F
.686 .482 .604 r
.44122 .63761 m .44523 .63579 L .44285 .63602 L F
.83 .818 .335 r
.40605 .61712 m .40547 .61945 L .4069 .6151 L F
.882 .803 .318 r
.40726 .61122 m .4069 .6151 L .40919 .61214 L F
.40726 .61122 m .40667 .61384 L .4069 .6151 L F
.399 .055 .262 r
.26688 .63476 m .26609 .63332 L .26818 .63259 L F
.26688 .63476 m .26532 .63523 L .26609 .63332 L F
.505 .199 .38 r
.44878 .60868 m .44626 .61049 L .44642 .60918 L F
.504 .27 .493 r
.26056 .59897 m .26338 .59638 L .26119 .59678 L F
.431 .138 .365 r
.47327 .61768 m .47575 .61722 L .47612 .61498 L F
.472 .173 .377 r
.47612 .61498 m .47825 .61673 L .4786 .61446 L F
.47612 .61498 m .47575 .61722 L .47825 .61673 L F
.884 .942 .846 r
.47286 .56254 m .47162 .56596 L .47485 .56418 L F
.336 .783 .958 r
.47941 .55925 m .48201 .55877 L .48332 .55939 L F
.025 .564 .846 r
.48201 .55877 m .48533 .55967 L .48332 .55939 L F
.556 .876 .993 r
.23422 .66042 m .23652 .65974 L .23471 .65904 L F
.472 .794 .999 r
.23251 .65944 m .23422 .66042 L .23471 .65904 L F
.556 .876 .993 r
.23422 .66042 m .23652 .65974 L .23471 .65904 L F
.472 .794 .999 r
.23251 .65944 m .23422 .66042 L .23471 .65904 L F
.069 .388 .849 r
.67125 .43927 m .67206 .43824 L .66974 .43791 L F
.67125 .43927 m .67298 .44002 L .67206 .43824 L F
.396 .184 .47 r
.24671 .61739 m .24882 .61696 L .24914 .61471 L F
.58 .309 .47 r
.24549 .62002 m .24882 .61696 L .24671 .61739 L F
0 0 .079 r
.44003 .57048 m .43943 .57237 L .44091 .56986 L F
.405 0 0 r
.44217 .57105 m .44091 .56986 L .43943 .57237 L F
.44217 .57105 m .44355 .57001 L .44091 .56986 L F
.317 .043 .329 r
.42733 .57898 m .42934 .57831 L .43004 .57635 L F
.437 .316 .616 r
.42733 .57898 m .4296 .58092 L .42934 .57831 L F
.842 .576 .536 r
.53687 .57728 m .54061 .57835 L .54035 .5758 L F
.846 .382 .047 r
.51333 .55803 m .51201 .55762 L .51042 .55666 L F
.51333 .55803 m .51436 .55975 L .51201 .55762 L F
.078 .153 .641 r
.44656 .65084 m .44818 .65042 L .44584 .64836 L F
.473 .271 .524 r
.44772 .64802 m .44601 .65035 L .44515 .64633 L F
.078 .153 .641 r
.44666 .65119 m .44818 .65042 L .44656 .65084 L F
.344 .818 .89 r
.44666 .65119 m .44478 .65052 L .44818 .65042 L F
.189 .72 .814 r
.44818 .65042 m .44481 .65052 L .4485 .65034 L F
.44481 .65052 m .44478 .65052 L .44481 .65052 L F
.44481 .65052 m .44481 .65052 L .4485 .65034 L F
.44818 .65042 m .4485 .65034 L .45022 .65026 L F
.484 .736 .982 r
.44561 .65354 m .44478 .65052 L .44666 .65119 L F
.286 .004 .298 r
.44768 .6531 m .45022 .65026 L .44478 .65052 L F
.473 .271 .524 r
.44601 .65035 m .44572 .65074 L .44568 .65039 L F
.44601 .65035 m .44568 .65039 L .44515 .64633 L F
.728 .836 .932 r
.67656 .42414 m .67298 .42389 L .67549 .42085 L F
.901 .793 .733 r
.67685 .4224 m .67656 .42414 L .67549 .42085 L F
.886 .703 .649 r
.58587 .53672 m .5843 .53343 L .58423 .53584 L F
.94 .757 .627 r
.58423 .53584 m .58555 .53943 L .58587 .53672 L F
.989 .842 .606 r
.54049 .58092 m .54087 .58445 L .54051 .58302 L F
.772 .749 .832 r
.74824 .40851 m .75176 .40925 L .75099 .40765 L F
.74824 .40851 m .74975 .41018 L .75176 .40925 L F
.731 .787 .898 r
.75099 .40765 m .75176 .40925 L .75496 .40662 L F
.469 .185 .399 r
.47087 .60559 m .47039 .60857 L .46762 .60781 L F
.323 .059 .35 r
.4695 .60995 m .46762 .60781 L .47039 .60857 L F
.503 0 0 r
.80692 .44278 m .80607 .4441 L .80324 .443 L F
.851 .419 .194 r
.80692 .44278 m .80964 .44633 L .80607 .4441 L F
.842 .541 .479 r
.22474 .69115 m .22404 .69346 L .22205 .69037 L F
.295 0 .211 r
.22753 .6906 m .22404 .69346 L .22474 .69115 L F
0 0 .482 r
.41469 .64891 m .41592 .64984 L .41576 .64739 L F
.41469 .64891 m .41473 .65135 L .41592 .64984 L F
.409 .642 .952 r
.18784 .62119 m .18377 .61906 L .18583 .61853 L F
.526 .727 .966 r
.18917 .61898 m .18784 .62119 L .18583 .61853 L F
.18917 .61898 m .1899 .62072 L .18784 .62119 L F
.624 .529 .727 r
.23995 .55464 m .23951 .55622 L .24256 .55527 L F
.275 .272 .674 r
.41488 .65392 m .41592 .64984 L .41473 .65135 L F
.92 .853 .76 r
.76658 .40341 m .76347 .4055 L .76599 .40269 L F
.76658 .40341 m .76471 .40687 L .76347 .4055 L F
.962 .933 .615 r
.76658 .40341 m .76744 .39842 L .76749 .39887 L F
.76658 .40341 m .76599 .40269 L .76744 .39842 L F
.655 .738 .911 r
.66359 .43624 m .66108 .43749 L .65955 .43542 L F
.361 0 .02 r
.18172 .56565 m .18107 .56659 L .17862 .56685 L F
.025 0 .068 r
.18414 .56324 m .18298 .56572 L .18172 .56565 L F
.033 0 0 r
.18298 .56572 m .18107 .56659 L .18172 .56565 L F
.573 .715 .939 r
.82639 .40585 m .82994 .40695 L .82755 .40901 L F
.618 .619 .829 r
.82994 .40695 m .83115 .41026 L .82755 .40901 L F
.43 .193 .451 r
.66029 .40665 m .6578 .40951 L .66089 .40822 L F
.694 .325 .345 r
.66089 .40822 m .66255 .40902 L .66029 .40665 L F
.744 .227 0 r
.66029 .40665 m .66422 .40933 L .66277 .4065 L F
.66029 .40665 m .66255 .40902 L .66422 .40933 L F
0 0 .258 r
.48951 .54244 m .49003 .54128 L .49 .53858 L F
.758 .415 0 r
.48951 .54244 m .48969 .5436 L .49003 .54128 L F
.988 .738 .459 r
.48969 .5436 m .48966 .54659 L .48815 .54514 L F
0 0 0 r
.48969 .5436 m .48815 .54514 L .48953 .54381 L F
.48969 .5436 m .48953 .54381 L .49097 .54241 L F
.758 .415 0 r
.48951 .54244 m .48984 .54341 L .48969 .5436 L F
.48984 .54341 m .49037 .54497 L .48969 .5436 L F
.629 .119 .015 r
.66329 .40999 m .66422 .40933 L .66255 .40902 L F
.66329 .40999 m .66598 .40959 L .66422 .40933 L F
.504 .19 .368 r
.48036 .61902 m .47639 .62314 L .47778 .6215 L F
.534 .409 .656 r
.2985 .59917 m .29607 .5973 L .29819 .59591 L F
.2985 .59917 m .29627 .59987 L .29607 .5973 L F
.575 .882 .992 r
.47052 .56068 m .46698 .56089 L .4694 .55993 L F
.797 .949 .92 r
.47052 .56068 m .4694 .55993 L .47089 .55834 L F
.199 .694 .919 r
.25098 .53779 m .25313 .53781 L .25515 .53843 L F
.884 .561 .057 r
.50791 .5803 m .50807 .57907 L .50713 .57826 L F
.50791 .5803 m .5087 .58153 L .50807 .57907 L F
.643 .523 .702 r
.21755 .67829 m .22089 .68092 L .22057 .67876 L F
0 0 0 r
.73778 .37435 m .73535 .37599 L .73803 .37482 L F
.397 0 0 r
.74058 .37509 m .73778 .37435 L .73803 .37482 L F
.961 .695 .257 r
.43183 .62015 m .43272 .62346 L .43283 .62143 L F
0 .273 .777 r
.77282 .43674 m .77486 .4397 L .77457 .43825 L F
0 .125 .675 r
.77457 .43825 m .77486 .4397 L .77705 .4421 L F
.87 .828 .803 r
.42104 .66458 m .4212 .66643 L .41921 .66595 L F
.836 .793 .811 r
.42363 .66337 m .4212 .66643 L .42166 .66412 L F
.87 .828 .803 r
.42166 .66412 m .41921 .66595 L .41944 .66319 L F
.565 .022 0 r
.42021 .66426 m .42204 .66566 L .42046 .66417 L F
.41979 .66368 m .42046 .66417 L .41944 .66319 L F
.42021 .66426 m .42046 .66417 L .41979 .66368 L F
.87 .828 .803 r
.42166 .66412 m .4215 .66491 L .42104 .66458 L F
.4215 .66491 m .4212 .66643 L .42104 .66458 L F
.89 .546 .388 r
.4212 .66643 m .41961 .66815 L .41921 .66595 L F
0 0 0 r
.42204 .66566 m .4212 .66643 L .42374 .66644 L F
.42204 .66566 m .41961 .66815 L .4212 .66643 L F
.486 .377 .654 r
.30224 .55714 m .30273 .5604 L .30042 .56106 L F
.479 .395 .683 r
.30273 .5604 m .30098 .56343 L .30042 .56106 L F
.825 .482 .406 r
.6803 .41544 m .68037 .4174 L .68161 .41536 L F
.787 .431 .383 r
.68037 .4174 m .68403 .41816 L .68161 .41536 L F
.205 .535 .924 r
.79991 .39771 m .79596 .39531 L .79914 .39616 L F
.311 .643 .967 r
.80095 .39652 m .79991 .39771 L .79914 .39616 L F
.80095 .39652 m .80334 .39817 L .79991 .39771 L F
.934 .62 .421 r
.51027 .58381 m .51215 .58718 L .51101 .5846 L F
0 .148 .682 r
.78007 .44861 m .78079 .44746 L .77872 .4451 L F
.181 .502 .908 r
.78007 .44861 m .78241 .4492 L .78079 .44746 L F
.144 .087 .529 r
.77155 .41627 m .76935 .41563 L .76825 .4143 L F
.77155 .41627 m .7698 .4179 L .76935 .41563 L F
.097 .647 .82 r
.5529 .6089 m .55674 .60913 L .55532 .60889 L F
.311 .551 .918 r
.5579 .60769 m .55674 .60913 L .55727 .60798 L F
.589 .934 .947 r
.55532 .60889 m .55674 .60913 L .5579 .60769 L F
.289 0 0 r
.23927 .66945 m .23536 .6692 L .23608 .66914 L F
.753 .747 .847 r
.2375 .66766 m .23536 .6692 L .23927 .66945 L F
.684 .356 .414 r
.17332 .56946 m .17216 .57196 L .16941 .57167 L F
.455 .115 .3 r
.17463 .57078 m .17332 .56946 L .17546 .56885 L F
.17463 .57078 m .17216 .57196 L .17332 .56946 L F
.542 .653 .907 r
.19125 .64355 m .19313 .64604 L .19518 .64525 L F
.102 0 0 r
.54563 .51567 m .54446 .51712 L .54231 .51735 L F
.457 0 0 r
.54753 .51671 m .54446 .51712 L .54563 .51567 L F
.395 .056 .268 r
.54819 .51499 m .54753 .51671 L .54563 .51567 L F
.492 .537 .831 r
.1532 .62132 m .15495 .62064 L .15308 .62106 L F
0 0 .267 r
.5193 .61055 m .51981 .61192 L .51843 .60831 L F
.938 .944 .765 r
.5193 .61055 m .51735 .61332 L .51981 .61192 L F
.926 .734 .624 r
.50587 .53883 m .5054 .54197 L .5074 .54274 L F
.627 .425 .589 r
.50453 .5457 m .505 .54512 L .50576 .54367 L F
0 0 0 r
.5074 .54274 m .50576 .54367 L .50834 .54262 L F
.885 .484 .257 r
.50644 .54237 m .50576 .54367 L .5074 .54274 L F
.622 .901 .986 r
.50834 .54262 m .50576 .54367 L .50737 .54221 L F
.627 .425 .589 r
.505 .54512 m .50737 .54221 L .50576 .54367 L F
.885 .484 .257 r
.5054 .54197 m .50576 .54367 L .50644 .54237 L F
0 0 0 r
.5074 .54274 m .50834 .54262 L .5098 .54171 L F
.619 .145 .107 r
.26689 .55715 m .26527 .55866 L .26321 .55788 L F
0 .382 .728 r
.26321 .55788 m .26527 .55866 L .26378 .55804 L F
.174 0 0 r
.26587 .55628 m .26321 .55788 L .2618 .55748 L F
0 .382 .728 r
.26321 .55788 m .26378 .55804 L .26169 .55718 L F
.174 0 0 r
.2618 .55748 m .26321 .55788 L .26137 .55761 L F
.619 .145 .107 r
.26689 .55715 m .26321 .55788 L .26587 .55628 L F
.965 .658 .258 r
.77002 .42397 m .77063 .42711 L .77149 .42778 L F
.931 .577 .152 r
.77063 .42711 m .77214 .43014 L .77149 .42778 L F
.653 .733 .908 r
.65705 .43894 m .65802 .44161 L .66117 .44017 L F
.145 .684 .697 r
.21007 .53923 m .2123 .53877 L .21392 .53845 L F
.318 .805 .784 r
.21392 .53845 m .21442 .53805 L .21613 .53811 L F
.21392 .53845 m .2123 .53877 L .21442 .53805 L F
0 0 0 r
.6578 .40951 m .65644 .413 L .65754 .41123 L F
0 0 .272 r
.65596 .41532 m .65754 .41123 L .65644 .413 L F
0 .319 .802 r
.7715 .38751 m .77265 .38928 L .77094 .38775 L F
0 .33 .769 r
.7715 .38751 m .77531 .39003 L .77265 .38928 L F
.031 .533 .875 r
.20675 .53785 m .21007 .53923 L .2078 .53859 L F
.145 0 0 r
.24352 .62079 m .2414 .62143 L .24002 .62279 L F
.383 .112 .374 r
.47245 .60787 m .47087 .60559 L .47301 .60503 L F
.47245 .60787 m .47039 .60857 L .47087 .60559 L F
.955 .732 .562 r
.58622 .54523 m .58503 .54212 L .58491 .54362 L F
.938 .793 .674 r
.58346 .54747 m .58622 .54523 L .58491 .54362 L F
.865 .791 .777 r
.82222 .42687 m .82575 .42556 L .82416 .42384 L F
.787 .778 .844 r
.82575 .42556 m .82756 .42417 L .82416 .42384 L F
.507 .297 .528 r
.27911 .62101 m .27876 .6235 L .27655 .62397 L F
.464 .259 .515 r
.28094 .62305 m .27911 .62101 L .28141 .62037 L F
.28094 .62305 m .27876 .6235 L .27911 .62101 L F
.97 .771 .339 r
.7718 .40464 m .77259 .40349 L .77172 .40223 L F
.7718 .40464 m .77243 .40591 L .77259 .40349 L F
.443 .677 .963 r
.77259 .40349 m .77429 .40174 L .77172 .40223 L F
.77259 .40349 m .77544 .40353 L .77429 .40174 L F
.88 .536 .04 r
.51698 .60496 m .51843 .60831 L .51831 .60597 L F
.51698 .60496 m .51843 .60831 L .51831 .60597 L F
.119 .613 .908 r
.81104 .44783 m .81438 .44891 L .81338 .44824 L F
.268 .767 .888 r
.81438 .44891 m .81578 .4482 L .81338 .44824 L F
.81438 .44891 m .81716 .44852 L .81578 .4482 L F
.224 0 .12 r
.65754 .41123 m .66089 .40822 L .6578 .40951 L F
.127 .411 .859 r
.14937 .59216 m .15066 .59245 L .15032 .59396 L F
.329 .633 .962 r
.15066 .59245 m .15282 .59433 L .15032 .59396 L F
.925 .742 .256 r
.49112 .58775 m .49073 .5897 L .49112 .58752 L F
.49114 .59005 m .49073 .5897 L .49112 .58775 L F
.852 .694 .686 r
.49114 .59005 m .48963 .59231 L .4887 .5915 L F
.102 0 .147 r
.49073 .5897 m .49011 .5911 L .4905 .59087 L F
.453 .838 .615 r
.49539 .58703 m .49239 .58905 L .49114 .59005 L F
.6 .355 .517 r
.49114 .59005 m .49156 .59462 L .48963 .59231 L F
.453 .838 .615 r
.49239 .58905 m .49228 .58913 L .49114 .59005 L F
.679 .413 .512 r
.49483 .59213 m .49114 .59005 L .49232 .58909 L F
.49483 .59213 m .49156 .59462 L .49114 .59005 L F
.079 0 .049 r
.49761 .58972 m .49483 .59213 L .49232 .58909 L F
.102 0 .147 r
.49073 .5897 m .4905 .59087 L .4929 .58946 L F
.29 0 .24 r
.49112 .58752 m .49073 .5897 L .49261 .58889 L F
.453 .838 .615 r
.49239 .58905 m .49232 .58909 L .49228 .58913 L F
.711 .274 .21 r
.49761 .58972 m .49232 .58909 L .49539 .58703 L F
.29 0 .24 r
.4929 .58868 m .49261 .58889 L .49297 .58873 L F
.49112 .58752 m .49261 .58889 L .4929 .58868 L F
.711 .274 .21 r
.49761 .58972 m .49539 .58703 L .49745 .58656 L F
.107 .094 .559 r
.41342 .61438 m .41433 .612 L .41169 .6113 L F
.41342 .61438 m .4142 .61438 L .41433 .612 L F
.101 .277 .757 r
.41342 .61438 m .41606 .6168 L .4142 .61438 L F
.496 .432 .715 r
.25934 .60296 m .26136 .60235 L .26056 .59897 L F
.4 .235 .539 r
.25934 .60296 m .26118 .6048 L .26136 .60235 L F
.25934 .60296 m .25925 .60554 L .26118 .6048 L F
.561 .421 .648 r
.71877 .4005 m .72135 .39971 L .72109 .39711 L F
.689 .603 .755 r
.71976 .40397 m .72135 .39971 L .71877 .4005 L F
.473 .237 .476 r
.27655 .62397 m .27601 .62694 L .2738 .62741 L F
.494 .257 .483 r
.27848 .62604 m .27655 .62397 L .27876 .6235 L F
.27848 .62604 m .27601 .62694 L .27655 .62397 L F
.63 .959 .812 r
.76704 .39549 m .76494 .3971 L .76533 .39732 L F
.642 .789 .952 r
.54057 .60899 m .54405 .60938 L .54288 .60807 L F
.54057 .60899 m .54405 .60938 L .54288 .60807 L F
.515 .733 .973 r
.54405 .60938 m .54636 .60898 L .54288 .60807 L F
.054 0 .18 r
.15846 .5808 m .1561 .58414 L .15642 .58203 L F
.558 .209 .334 r
.20246 .73271 m .20616 .73157 L .20317 .73364 L F
.408 .01 .169 r
.20317 .73364 m .20616 .73157 L .20748 .73219 L F
.239 .458 .87 r
.15843 .5979 m .15797 .59953 L .15608 .59666 L F
.339 .569 .924 r
.15843 .5979 m .16 .59978 L .15797 .59953 L F
.159 0 0 r
.53112 .51848 m .52877 .51826 L .52933 .51988 L F
.53112 .51848 m .53215 .51729 L .52877 .51826 L F
.579 .081 .037 r
.74676 .37687 m .74822 .37492 L .74423 .37518 L F
.278 0 0 r
.75039 .37493 m .74822 .37492 L .74676 .37687 L F
.773 .554 .603 r
.21558 .68097 m .22012 .68214 L .21755 .67829 L F
.643 .523 .702 r
.21755 .67829 m .22012 .68214 L .22089 .68092 L F
.371 0 .098 r
.49612 .60581 m .4916 .60818 L .49498 .60764 L F
0 .086 .636 r
.49498 .6027 m .49612 .60581 L .49682 .60457 L F
.621 .803 .377 r
.49682 .60457 m .49612 .60581 L .49498 .60764 L F
0 .086 .636 r
.49498 .6027 m .49612 .60581 L .49682 .60457 L F
.499 .251 .469 r
.24914 .61471 m .25143 .61426 L .25175 .61198 L F
.491 .321 .578 r
.25143 .61426 m .25345 .61114 L .25175 .61198 L F
.488 .193 .391 r
.48155 .5969 m .48098 .59925 L .47851 .5996 L F
.518 .23 .417 r
.48425 .59636 m .48098 .59925 L .48155 .5969 L F
.558 .817 .994 r
.19518 .64525 m .19899 .64597 L .19749 .6447 L F
.398 .685 .976 r
.19899 .64597 m .19951 .64422 L .19749 .6447 L F
.19899 .64597 m .20146 .64598 L .19951 .64422 L F
.532 .563 .833 r
.30595 .54807 m .30431 .54915 L .30379 .54687 L F
.407 .317 .642 r
.30595 .54807 m .30644 .55052 L .30431 .54915 L F
.395 .32 .654 r
.30644 .55052 m .30447 .55144 L .30431 .54915 L F
.445 .827 .988 r
.42759 .6815 m .42994 .68103 L .42842 .68035 L F
.836 .793 .811 r
.42363 .66337 m .42166 .66412 L .41944 .66319 L F
.42363 .66337 m .41944 .66319 L .42204 .66566 L F
.073 0 0 r
.42421 .66407 m .42363 .66337 L .42204 .66566 L F
.208 .264 .701 r
.41414 .62128 m .41499 .62466 L .41622 .62341 L F
.122 .134 .598 r
.41499 .62466 m .41685 .62554 L .41622 .62341 L F
.41499 .62466 m .41535 .62731 L .41685 .62554 L F
.235 .56 .935 r
.79829 .39471 m .79596 .39531 L .79513 .39352 L F
.79829 .39471 m .79914 .39616 L .79596 .39531 L F
0 0 0 r
.53203 .52465 m .53491 .52205 L .53372 .52353 L F
.488 .899 .908 r
.53203 .52465 m .53095 .52421 L .53048 .52403 L F
.53203 .52465 m .53372 .52353 L .53095 .52421 L F
.116 0 0 r
.19588 .55869 m .19361 .55918 L .19135 .55922 L F
.314 0 0 r
.19739 .55831 m .19361 .55918 L .19588 .55869 L F
.497 .613 .897 r
.15308 .62106 m .15282 .6175 L .15157 .61832 L F
.15308 .62106 m .15495 .62064 L .15282 .6175 L F
.753 .265 .077 r
.51004 .55458 m .50898 .55555 L .50703 .55373 L F
.935 .566 .269 r
.51004 .55458 m .51042 .55666 L .50898 .55555 L F
.35 .21 .546 r
.26801 .58476 m .26977 .58665 L .26959 .58403 L F
.26801 .58476 m .26802 .58739 L .26977 .58665 L F
.782 .589 .639 r
.50255 .5411 m .50587 .53883 L .50397 .53873 L F
.465 .237 .483 r
.28388 .61754 m .28141 .62037 L .28148 .61809 L F
0 0 .082 r
.40971 .60487 m .40844 .60713 L .40988 .60265 L F
.499 .247 .463 r
.40971 .60487 m .40649 .6081 L .40844 .60713 L F
.62 .402 .564 r
.44657 .62676 m .4492 .62395 L .44676 .62412 L F
.44657 .62676 m .44943 .62655 L .4492 .62395 L F
.617 .365 .514 r
.44943 .62655 m .45347 .62349 L .4492 .62395 L F
.382 .246 .569 r
.4148 .61826 m .4164 .62022 L .41694 .61805 L F
.4148 .61826 m .41414 .62128 L .4164 .62022 L F
.302 0 .097 r
.14141 .5721 m .14351 .57173 L .14494 .56961 L F
.264 0 .162 r
.14351 .57173 m .14673 .56858 L .14494 .56961 L F
.708 .402 .457 r
.56633 .49706 m .56979 .49919 L .56991 .49714 L F
.658 .348 .437 r
.56979 .49919 m .57249 .49926 L .56991 .49714 L F
.603 .371 .537 r
.56991 .49714 m .57249 .49926 L .5725 .49686 L F
.244 .757 .85 r
.25701 .5387 m .25925 .53832 L .261 .53838 L F
.123 0 0 r
.261 .53838 m .25925 .53832 L .26319 .53862 L F
.555 .291 .471 r
.4462 .59385 m .44605 .59617 L .44336 .59633 L F
.44336 .59633 m .44605 .59617 L .4462 .59385 L F
.564 .298 .472 r
.4462 .59385 m .4485 .59585 L .44605 .59617 L F
.44605 .59617 m .4485 .59585 L .4462 .59385 L F
.555 .291 .471 r
.4462 .59385 m .44605 .59617 L .44336 .59633 L F
.541 .376 .608 r
.29384 .60551 m .2939 .60814 L .29149 .60609 L F
.442 .379 .691 r
.2939 .60814 m .29192 .60897 L .29149 .60609 L F
.543 .787 .989 r
.19027 .75834 m .18972 .76006 L .192 .7596 L F
.192 .7596 m .18972 .76006 L .19027 .75834 L F
.842 .825 .831 r
.76169 .41146 m .7585 .4116 L .76101 .40859 L F
.851 .802 .802 r
.76169 .41146 m .76006 .41286 L .7585 .4116 L F
.818 .812 .845 r
.76249 .41 m .76169 .41146 L .76101 .40859 L F
.788 .698 .765 r
.40924 .60015 m .40988 .60265 L .41248 .59919 L F
.377 0 0 r
.55081 .58856 m .55448 .58901 L .55506 .5878 L F
.581 .515 .745 r
.55506 .5878 m .55749 .58741 L .55732 .5832 L F
.722 .21 .003 r
.55448 .58901 m .5575 .59029 L .55506 .5878 L F
.526 .294 .505 r
.55506 .5878 m .5575 .59029 L .55749 .58741 L F
.51 .321 .56 r
.27622 .56913 m .27878 .56598 L .2766 .56674 L F
.801 .705 .759 r
.40988 .60265 m .40745 .6028 L .40924 .60015 L F
.191 .296 .742 r
.40924 .60015 m .41142 .60151 L .40988 .60265 L F
.092 0 .2 r
.41119 .60398 m .40988 .60265 L .41142 .60151 L F
.41119 .60398 m .40971 .60487 L .40988 .60265 L F
.191 .296 .742 r
.40924 .60015 m .41142 .60151 L .40988 .60265 L F
.079 0 0 r
.19116 .78428 m .1948 .78371 L .19382 .78407 L F
.19382 .78407 m .1948 .78371 L .19116 .78428 L F
.708 .974 .753 r
.19382 .78407 m .1948 .78371 L .19689 .78101 L F
.19382 .78407 m .1948 .78371 L .19689 .78101 L F
.49 .562 .856 r
.1716 .63401 m .17289 .63196 L .17075 .63221 L F
.1716 .63401 m .17437 .63495 L .17289 .63196 L F
.609 .863 .991 r
.21145 .64713 m .21507 .64729 L .21352 .64694 L F
.503 .888 .963 r
.21352 .64694 m .21507 .64729 L .21705 .64653 L F
.639 .352 .468 r
.55955 .49744 m .56364 .49915 L .5637 .49698 L F
.55955 .49744 m .5599 .49958 L .56364 .49915 L F
.793 .801 .311 r
.58371 .56335 m .5837 .56279 L .58297 .5651 L F
.449 .141 .35 r
.46143 .60667 m .46355 .60782 L .46417 .60586 L F
.598 .53 .749 r
.80776 .41868 m .81029 .41674 L .80688 .41526 L F
.80776 .41868 m .8104 .41796 L .81029 .41674 L F
.647 .678 .866 r
.43373 .65109 m .42928 .64857 L .43168 .64776 L F
.99 .812 .57 r
.43554 .64706 m .43298 .64997 L .434 .64677 L F
.817 .667 .696 r
.43293 .64995 m .43298 .64997 L .43323 .64972 L F
.43033 .65197 m .43298 .64997 L .43293 .64995 L F
.261 .692 .964 r
.43298 .64997 m .43373 .65109 L .43305 .64999 L F
.43298 .64997 m .43305 .64999 L .43168 .64776 L F
.43298 .64997 m .43407 .6507 L .43373 .65109 L F
.341 0 0 r
.42861 .65774 m .42705 .65801 L .42457 .65717 L F
.7 .162 0 r
.42861 .65774 m .4305 .65956 L .42705 .65801 L F
.081 .637 .799 r
.23693 .53704 m .24098 .53726 L .23875 .53763 L F
.404 .184 .464 r
.29192 .60897 m .29169 .61136 L .28966 .61184 L F
.405 .12 .364 r
.29112 .61365 m .28966 .61184 L .29169 .61136 L F
.29112 .61365 m .28892 .61423 L .28966 .61184 L F
.72 .835 .936 r
.82416 .42384 m .82756 .42417 L .8265 .42256 L F
.687 .748 .898 r
.82756 .42417 m .82937 .42021 L .8265 .42256 L F
.82756 .42417 m .83055 .42294 L .82937 .42021 L F
.528 .337 .566 r
.30083 .59336 m .29819 .59591 L .29847 .59396 L F
.533 .815 .998 r
.72934 .39168 m .72585 .39118 L .72834 .39017 L F
.107 .364 .828 r
.73213 .39196 m .72934 .39168 L .72834 .39017 L F
.86 .896 .859 r
.75485 .41925 m .75243 .41951 L .75335 .41771 L F
.83 .771 .796 r
.75735 .4159 m .75485 .41925 L .75335 .41771 L F
.503 .716 .967 r
.78202 .43615 m .77929 .43731 L .77904 .43632 L F
.78202 .43615 m .78193 .43687 L .77929 .43731 L F
.737 .677 .792 r
.67222 .43124 m .66934 .43366 L .66814 .43016 L F
1 .799 .475 r
.58537 .55451 m .58411 .55593 L .58496 .55678 L F
.854 .588 .051 r
.58452 .55092 m .58493 .55369 L .58537 .55451 L F
.957 .905 .533 r
.58493 .55369 m .58411 .55593 L .58537 .55451 L F
0 .048 .612 r
.76968 .38481 m .7715 .38751 L .77094 .38775 L F
.593 .499 .717 r
.44411 .62723 m .44437 .6297 L .44676 .6292 L F
.804 .701 .751 r
.44633 .63028 m .44676 .6292 L .44437 .6297 L F
.829 .593 .581 r
.58367 .50798 m .58723 .50615 L .58377 .50537 L F
.58367 .50798 m .58746 .50875 L .58723 .50615 L F
0 0 0 r
.53677 .52034 m .53372 .52353 L .53491 .52205 L F
.83 .771 .796 r
.75735 .4159 m .75335 .41771 L .75573 .41446 L F
.796 .754 .814 r
.76006 .41286 m .75735 .4159 L .75573 .41446 L F
.344 .576 .927 r
.23995 .55464 m .23929 .55179 L .23634 .55228 L F
.23995 .55464 m .24075 .55387 L .23929 .55179 L F
.624 .529 .727 r
.23995 .55464 m .24256 .55527 L .24075 .55387 L F
.612 .466 .658 r
.42694 .63606 m .43049 .6331 L .42613 .63275 L F
.636 .338 .448 r
.56364 .49915 m .5662 .49912 L .5637 .49698 L F
.635 .339 .451 r
.5637 .49698 m .5662 .49912 L .56633 .49706 L F
.05 0 .1 r
.74544 .38141 m .74614 .37972 L .74798 .37843 L F
.239 .714 .939 r
.27319 .53956 m .27536 .53951 L .27697 .5401 L F
.166 .64 .929 r
.27766 .53944 m .27697 .5401 L .27536 .53951 L F
.27766 .53944 m .27964 .5404 L .27697 .5401 L F
.49 .296 .544 r
.30268 .56845 m .30447 .56908 L .30219 .56954 L F
.497 .459 .745 r
.30589 .56481 m .30268 .56845 L .30304 .56299 L F
.511 .247 .451 r
.30687 .56827 m .30268 .56845 L .30589 .56481 L F
.30687 .56827 m .30447 .56908 L .30268 .56845 L F
.682 .854 .965 r
.6575 .43582 m .6531 .43563 L .65566 .43319 L F
.471 .7 .968 r
.6586 .43376 m .6575 .43582 L .65566 .43319 L F
.6586 .43376 m .65955 .43542 L .6575 .43582 L F
.657 .291 .338 r
.22483 .55158 m .22002 .55283 L .22283 .55134 L F
.38 .053 .279 r
.40224 .61174 m .40472 .6112 L .40548 .60857 L F
.536 .918 .928 r
.40649 .6081 m .4061 .60772 L .40548 .60857 L F
0 0 .137 r
.40548 .60857 m .4061 .60772 L .40651 .60503 L F
.969 .77 .581 r
.4061 .60772 m .40726 .61122 L .40548 .60857 L F
.432 .098 .298 r
.40548 .60857 m .40614 .61057 L .4061 .60772 L F
.40548 .60857 m .40472 .6112 L .40614 .61057 L F
.184 .406 .844 r
.75332 .42367 m .75353 .42215 L .75243 .41951 L F
.75332 .42367 m .75492 .42399 L .75353 .42215 L F
.82 .651 .673 r
.69156 .42359 m .69523 .42165 L .69153 .42129 L F
.69156 .42359 m .69518 .42431 L .69523 .42165 L F
.748 .989 .89 r
.67784 .43735 m .67666 .43937 L .67991 .43718 L F
.744 .954 .943 r
.68204 .43607 m .67784 .43735 L .67991 .43718 L F
.555 .525 .777 r
.80688 .41526 m .80892 .41227 L .80619 .41278 L F
.80688 .41526 m .81029 .41674 L .80892 .41227 L F
.479 .395 .683 r
.30273 .5604 m .30304 .56299 L .30098 .56343 L F
.433 .657 .955 r
.81298 .40158 m .81544 .40157 L .81383 .40323 L F
.466 .711 .975 r
.81544 .40157 m .81635 .40302 L .81383 .40323 L F
.065 .432 .873 r
.41485 .63086 m .41553 .63218 L .41255 .63069 L F
.534 .592 .859 r
.80251 .4098 m .80209 .40803 L .79864 .40718 L F
.456 .63 .928 r
.79864 .40718 m .80017 .40528 L .79791 .4055 L F
.79864 .40718 m .80209 .40803 L .80017 .40528 L F
.647 .111 0 r
.52597 .55195 m .52554 .55067 L .52363 .55003 L F
.52597 .55195 m .52769 .55306 L .52554 .55067 L F
.467 .674 .954 r
.28754 .54156 m .28744 .54403 L .2853 .54216 L F
.28754 .54156 m .28962 .54387 L .28744 .54403 L F
.654 .547 .721 r
.44301 .62369 m .44657 .62676 L .44676 .62412 L F
.44301 .62369 m .44411 .62723 L .44657 .62676 L F
.593 .499 .717 r
.44411 .62723 m .44676 .6292 L .44657 .62676 L F
.788 .589 .631 r
.57007 .51484 m .56668 .51178 L .57027 .51224 L F
.63 .64 .842 r
.83262 .40606 m .83115 .41026 L .82994 .40695 L F
.83262 .40606 m .83375 .40935 L .83115 .41026 L F
.5 .26 .482 r
.44255 .57878 m .44013 .58129 L .44007 .579 L F
.44255 .57878 m .44266 .58105 L .44013 .58129 L F
.105 0 0 r
.44599 .57804 m .44266 .58105 L .44255 .57878 L F
.471 .24 .481 r
.294 .61074 m .29192 .60897 L .2939 .60814 L F
.294 .61074 m .29169 .61136 L .29192 .60897 L F
.46 .639 .934 r
.16467 .61094 m .16344 .61233 L .163 .61114 L F
.16467 .61094 m .16707 .6137 L .16344 .61233 L F
.268 0 0 r
.18615 .77299 m .18659 .77422 L .1844 .7742 L F
.18615 .77299 m .18868 .77242 L .18659 .77422 L F
.41 .815 .981 r
.21562 .69899 m .21895 .6989 L .21961 .69891 L F
.321 .163 .505 r
.30644 .55052 m .30435 .55358 L .30447 .55144 L F
.621 .359 .499 r
.4786 .61446 m .48178 .61496 L .48165 .61223 L F
.634 .369 .499 r
.48165 .61223 m .48178 .61496 L .48384 .61377 L F
.577 .551 .789 r
.51477 .60513 m .51174 .60599 L .51073 .60266 L F
.542 .395 .631 r
.51477 .60513 m .5119 .60871 L .51174 .60599 L F
.504 .19 .368 r
.48036 .61902 m .47889 .6228 L .47639 .62314 L F
.59 .277 .407 r
.48264 .62169 m .47889 .6228 L .48036 .61902 L F
.48264 .62169 m .48036 .61902 L .48088 .62035 L F
0 0 .303 r
.48055 .61643 m .48088 .62035 L .48036 .61902 L F
.879 .68 .629 r
.57007 .51484 m .57185 .51826 L .56981 .51733 L F
.849 .61 .576 r
.57185 .51826 m .56853 .5198 L .56981 .51733 L F
.57185 .51826 m .5717 .52078 L .56853 .5198 L F
.645 .675 .864 r
.15912 .62372 m .16381 .62634 L .16152 .6226 L F
.473 .602 .9 r
.16152 .6226 m .16381 .62634 L .16544 .62564 L F
.541 .598 .86 r
.16381 .62634 m .16641 .62726 L .16544 .62564 L F
.84 .531 .465 r
.68431 .4198 m .68759 .41863 L .68403 .41816 L F
.68431 .4198 m .68778 .42081 L .68759 .41863 L F
.47 .755 .992 r
.21562 .69899 m .21961 .69891 L .2159 .69783 L F
.11 .463 .89 r
.79201 .39246 m .78978 .39059 L .79241 .39189 L F
0 .482 .861 r
.79402 .39263 m .79201 .39246 L .79241 .39189 L F
.79402 .39263 m .79513 .39352 L .79201 .39246 L F
.593 .448 .654 r
.30435 .55358 m .30224 .55714 L .30207 .55442 L F
.974 .894 .534 r
.19686 .75628 m .19732 .75462 L .19687 .75662 L F
.987 .893 .569 r
.19686 .75628 m .19732 .75462 L .19704 .75364 L F
.624 .445 .62 r
.19686 .75628 m .20047 .75652 L .19732 .75462 L F
.987 .893 .569 r
.19686 .75628 m .19732 .75462 L .19704 .75364 L F
.658 .575 .749 r
.18377 .61906 m .18084 .61751 L .18226 .61736 L F
.816 .661 .691 r
.66593 .41725 m .66422 .41431 L .66558 .41542 L F
0 0 0 r
.50786 .53268 m .50953 .53168 L .51094 .53031 L F
.664 .577 .747 r
.5147 .53336 m .51094 .53031 L .51284 .52986 L F
.51361 .53044 m .51284 .52986 L .51335 .52973 L F
.5147 .53336 m .51284 .52986 L .51361 .53044 L F
.756 .427 0 r
.51405 .5319 m .5147 .53336 L .51335 .52973 L F
.684 .428 .529 r
.51405 .5319 m .51724 .53301 L .5147 .53336 L F
.51405 .5319 m .51581 .53437 L .51715 .5331 L F
.51687 .53288 m .51715 .5331 L .51724 .53301 L F
.51405 .5319 m .51715 .5331 L .51687 .53288 L F
.064 0 0 r
.51094 .53031 m .51215 .53082 L .51335 .52973 L F
.51094 .53031 m .50953 .53168 L .51215 .53082 L F
0 0 0 r
.56964 .60182 m .56946 .60206 L .56774 .60282 L F
.57277 .59935 m .56946 .60206 L .56964 .60182 L F
.141 .678 .844 r
.48703 .56587 m .4828 .56568 L .48409 .56547 L F
.996 .774 .418 r
.49847 .6205 m .49765 .61618 L .49865 .61796 L F
.344 .614 .95 r
.49953 .61642 m .49865 .61796 L .49765 .61618 L F
.093 .282 .764 r
.49953 .61642 m .50104 .62014 L .49865 .61796 L F
.559 .341 .54 r
.49865 .61796 m .50104 .62014 L .49847 .6205 L F
.694 .454 .556 r
.19727 .75093 m .19571 .75379 L .19295 .75139 L F
.19727 .75093 m .19704 .75364 L .19571 .75379 L F
0 .157 .694 r
.19735 .7499 m .19727 .75093 L .19568 .74846 L F
.694 .454 .556 r
.19571 .75379 m .19727 .75093 L .19735 .7499 L F
.19571 .75379 m .19704 .75364 L .19727 .75093 L F
.603 .318 .457 r
.45896 .6266 m .46323 .6267 L .46277 .62411 L F
.398 .185 .469 r
.46277 .62411 m .46466 .6259 L .46509 .62378 L F
.46277 .62411 m .46323 .6267 L .46466 .6259 L F
.681 .702 .863 r
.7384 .39327 m .73694 .39737 L .73549 .39572 L F
.7384 .39327 m .7395 .39647 L .73694 .39737 L F
.689 .603 .755 r
.71976 .40397 m .72212 .40296 L .72135 .39971 L F
.706 .971 .742 r
.15644 .59301 m .15731 .59155 L .15872 .59316 L F
.15644 .59301 m .15552 .5934 L .15731 .59155 L F
.279 .284 .686 r
.41605 .62982 m .41685 .62554 L .41535 .62731 L F
.526 .587 .858 r
.80461 .40752 m .80209 .40803 L .80251 .4098 L F
.534 .6 .866 r
.80251 .4098 m .80503 .40934 L .80461 .40752 L F
.105 0 0 r
.44599 .57804 m .44459 .58031 L .44266 .58105 L F
.007 0 0 r
.44735 .57806 m .44599 .57804 L .44812 .57765 L F
.44735 .57806 m .44459 .58031 L .44599 .57804 L F
.914 .628 .488 r
.42682 .63699 m .43024 .63659 L .42694 .63606 L F
.53 .406 .655 r
.42682 .63699 m .42768 .64206 L .43043 .64104 L F
.764 .81 .89 r
.75492 .42399 m .7563 .42575 L .7584 .4243 L F
.478 0 0 r
.4504 .64134 m .44987 .64209 L .44677 .64175 L F
0 0 0 r
.45224 .6392 m .45051 .64183 L .4504 .64134 L F
.45051 .64183 m .44987 .64209 L .4504 .64134 L F
.585 .609 .842 r
.66448 .42993 m .66369 .43368 L .66187 .43259 L F
.939 .705 .558 r
.66369 .43368 m .66361 .43577 L .66187 .43259 L F
.66361 .43577 m .6633 .43563 L .66187 .43259 L F
.738 .652 .765 r
.66187 .43259 m .66359 .43624 L .65955 .43542 L F
.421 .696 .978 r
.6609 .43451 m .66355 .4332 L .66089 .43381 L F
.6609 .43528 m .66152 .4348 L .6609 .43451 L F
.66152 .4348 m .66355 .4332 L .6609 .43451 L F
.939 .705 .558 r
.66361 .43577 m .66359 .43624 L .6633 .43563 L F
.454 .269 .539 r
.80955 .42706 m .81182 .42399 L .80907 .42461 L F
.927 .556 .286 r
.81906 .43286 m .81958 .435 L .82039 .43358 L F
.683 .58 .733 r
.82039 .43358 m .82152 .42933 L .81906 .43286 L F
.82039 .43358 m .82321 .43049 L .82152 .42933 L F
.82039 .43358 m .82308 .43306 L .82321 .43049 L F
.729 .27 .16 r
.81958 .435 m .82291 .43561 L .82039 .43358 L F
.628 .384 .529 r
.82291 .43561 m .82308 .43306 L .82039 .43358 L F
0 0 0 r
.48359 .59327 m .48562 .59113 L .48323 .59172 L F
.48359 .59327 m .48475 .59272 L .48562 .59113 L F
.6 .562 .784 r
.48562 .59113 m .48359 .59327 L .48323 .59172 L F
.671 .781 .932 r
.50585 .52378 m .5097 .52436 L .50829 .5234 L F
.588 .853 .994 r
.51067 .52261 m .50829 .5234 L .5097 .52436 L F
.979 .817 .613 r
.4962 .5476 m .49735 .54817 L .49819 .54895 L F
.4962 .5476 m .49604 .54792 L .49735 .54817 L F
.907 .542 .334 r
.49877 .55046 m .4962 .5476 L .49819 .54895 L F
.673 .824 .956 r
.66117 .44017 m .6649 .44041 L .66338 .43875 L F
.112 0 .191 r
.5432 .50838 m .54538 .50775 L .54589 .50544 L F
.019 0 0 r
.5432 .50838 m .54242 .51012 L .54538 .50775 L F
.476 .609 .904 r
.29179 .54358 m .29064 .54571 L .28962 .54387 L F
.501 .641 .918 r
.29179 .54358 m .29293 .54566 L .29064 .54571 L F
.463 0 0 r
.43043 .64104 m .43296 .64102 L .43055 .64011 L F
.436 .353 .665 r
.30297 .57895 m .30338 .58051 L .30099 .5788 L F
.436 .262 .545 r
.30316 .58741 m .30304 .59024 L .30078 .59084 L F
.446 .275 .555 r
.30263 .59172 m .30078 .59084 L .30304 .59024 L F
.30263 .59172 m .30083 .59336 L .30078 .59084 L F
.325 .033 .306 r
.41694 .61805 m .41774 .61751 L .41606 .6168 L F
.41694 .61805 m .41946 .61828 L .41774 .61751 L F
.41694 .61805 m .4164 .62022 L .41946 .61828 L F
.382 .835 .743 r
.18869 .54447 m .18675 .54541 L .18445 .54619 L F
.653 .21 .187 r
.48988 .60867 m .49343 .60887 L .49265 .61055 L F
.456 0 0 r
.49343 .60887 m .49388 .60934 L .49265 .61055 L F
.49343 .60887 m .49481 .60986 L .49388 .60934 L F
.697 .53 .657 r
.82308 .43306 m .82722 .43096 L .82321 .43049 L F
.82308 .43306 m .82685 .43372 L .82722 .43096 L F
.87 .808 .786 r
.76471 .40687 m .76101 .40859 L .76347 .4055 L F
.76471 .40687 m .76249 .41 L .76101 .40859 L F
.44 .241 .512 r
.73535 .37599 m .73737 .37781 L .73803 .37482 L F
.517 .456 .727 r
.23374 .67812 m .23218 .68129 L .2304 .67856 L F
.23374 .67812 m .23436 .68094 L .23218 .68129 L F
.225 .197 .616 r
.23404 .68329 m .23218 .68129 L .23436 .68094 L F
.23404 .68329 m .23279 .6838 L .23218 .68129 L F
.699 .934 .965 r
.78466 .44881 m .78638 .44949 L .78853 .44808 L F
.799 .716 .773 r
.23821 .64405 m .24295 .64608 L .2422 .64436 L F
.914 .579 .109 r
.58483 .51392 m .5861 .51684 L .58627 .51513 L F
.834 .849 .857 r
.58483 .51392 m .58627 .51513 L .58891 .51224 L F
.937 .898 .5 r
.5147 .53336 m .51341 .5348 L .51144 .53397 L F
.5147 .53336 m .51369 .53677 L .51341 .5348 L F
.642 .708 .895 r
.78693 .43927 m .78193 .43687 L .78635 .43761 L F
.641 .754 .93 r
.78947 .43814 m .78693 .43927 L .78635 .43761 L F
.005 0 0 r
.20416 .55598 m .20022 .55735 L .20174 .5568 L F
.275 .085 .432 r
.2985 .59917 m .29641 .60251 L .29627 .59987 L F
.408 .3 .619 r
.41414 .62128 m .41622 .62341 L .4164 .62022 L F
.576 .398 .603 r
.29631 .60512 m .29387 .60289 L .29641 .60251 L F
.29631 .60512 m .29384 .60551 L .29387 .60289 L F
.791 .294 0 r
.766 .38327 m .7655 .38146 L .76409 .38159 L F
.766 .38327 m .76773 .38418 L .7655 .38146 L F
.675 .133 0 r
.76968 .38481 m .7655 .38146 L .76773 .38418 L F
.773 .562 .613 r
.56425 .60564 m .56774 .60282 L .56606 .60419 L F
0 0 0 r
.56774 .60282 m .56946 .60206 L .56606 .60419 L F
.638 .418 .567 r
.43886 .60795 m .44148 .6052 L .43956 .60647 L F
.76 .737 .832 r
.22483 .55158 m .22648 .55445 L .22904 .55204 L F
.638 .592 .786 r
.46959 .62517 m .47167 .62776 L .47352 .62516 L F
.054 .259 .753 r
.46747 .62354 m .46982 .62563 L .46882 .62674 L F
.46982 .62563 m .46984 .62566 L .46882 .62674 L F
.51 .532 .814 r
.47294 .62811 m .47253 .62825 L .46984 .62565 L F
.064 .408 .86 r
.46882 .62674 m .47167 .62776 L .4703 .62659 L F
.51 .532 .814 r
.47253 .62825 m .47102 .62876 L .47016 .62649 L F
.638 .592 .786 r
.46998 .62602 m .47033 .62662 L .46984 .62566 L F
.51 .532 .814 r
.4703 .62659 m .47016 .62649 L .46998 .62602 L F
.638 .592 .786 r
.47018 .62649 m .4703 .62659 L .46998 .62602 L F
.4703 .62659 m .47033 .62662 L .46998 .62602 L F
.47033 .62662 m .47167 .62776 L .46959 .62517 L F
.51 .532 .814 r
.47253 .62825 m .4703 .62659 L .46984 .62565 L F
.4703 .62659 m .46998 .62602 L .46984 .62565 L F
.064 .408 .86 r
.47016 .62649 m .4703 .62659 L .47018 .62649 L F
.46882 .62674 m .4703 .62659 L .47016 .62649 L F
.57 .238 .366 r
.47016 .62649 m .46882 .62674 L .46984 .62566 L F
.064 .408 .86 r
.46882 .62674 m .46862 .62518 L .46747 .62354 L F
.693 .229 .147 r
.46844 .62492 m .46984 .62565 L .46747 .62354 L F
.064 .408 .86 r
.46862 .62518 m .46862 .62517 L .46747 .62354 L F
.693 .229 .147 r
.46691 .62412 m .46844 .62492 L .46747 .62354 L F
.064 .408 .86 r
.46882 .62674 m .47018 .62649 L .46863 .62518 L F
.46882 .62674 m .46863 .62518 L .46862 .62518 L F
.693 .229 .147 r
.46606 .62501 m .46922 .62555 L .46691 .62412 L F
.054 .259 .753 r
.46982 .62563 m .46984 .62565 L .46984 .62566 L F
.693 .229 .147 r
.46922 .62555 m .46984 .62565 L .46691 .62412 L F
.064 .408 .86 r
.46862 .62518 m .46863 .62518 L .46862 .62517 L F
.57 .238 .366 r
.47102 .62876 m .46882 .62674 L .47016 .62649 L F
.46998 .62602 m .46984 .62566 L .46984 .62565 L F
.47102 .62876 m .46984 .62566 L .46998 .62602 L F
.638 .592 .786 r
.46862 .62517 m .47018 .62649 L .46959 .62517 L F
.47018 .62649 m .46984 .62566 L .46959 .62517 L F
.57 .238 .366 r
.47102 .62876 m .46863 .62909 L .46882 .62674 L F
.992 .751 .459 r
.41944 .66319 m .41747 .66277 L .41862 .6619 L F
.41944 .66319 m .41921 .66595 L .41747 .66277 L F
.565 .022 0 r
.42021 .66426 m .41944 .66319 L .41862 .6619 L F
0 0 .398 r
.53575 .60222 m .5372 .60574 L .53706 .6048 L F
0 .124 .654 r
.5372 .60574 m .53795 .60609 L .53706 .6048 L F
.5372 .60574 m .53908 .60745 L .53795 .60609 L F
0 0 0 r
.48937 .60633 m .48637 .60823 L .48988 .60867 L F
.619 .453 .634 r
.48937 .60633 m .48988 .60867 L .4916 .60818 L F
.766 .32 .191 r
.6705 .41139 m .67276 .41375 L .67397 .41246 L F
.694 .225 .134 r
.67276 .41375 m .67645 .41438 L .67397 .41246 L F
.584 .858 .995 r
.43272 .62346 m .42931 .62328 L .43077 .62439 L F
.54 .495 .754 r
.83651 .40848 m .83461 .41288 L .83375 .40935 L F
.83651 .40848 m .83754 .41207 L .83461 .41288 L F
.555 .562 .816 r
.83754 .41207 m .83799 .41395 L .83461 .41288 L F
.618 .602 .813 r
.15495 .62064 m .15682 .62447 L .15912 .62372 L F
.372 .838 .877 r
.67666 .43937 m .67629 .43912 L .67298 .44002 L F
.747 .981 .742 r
.67784 .43735 m .67629 .43912 L .67666 .43937 L F
.911 .819 .744 r
.57327 .52452 m .57219 .52681 L .57167 .52339 L F
.81 .477 .426 r
.66978 .41837 m .66769 .42004 L .66593 .41725 L F
.726 .348 .335 r
.6717 .42048 m .66769 .42004 L .66978 .41837 L F
.316 0 0 r
.17782 .54763 m .17681 .54811 L .18017 .54748 L F
0 0 .241 r
.52515 .57289 m .52557 .57403 L .52443 .57188 L F
.52515 .57289 m .52576 .57539 L .52557 .57403 L F
.575 .692 .921 r
.45196 .62043 m .45462 .61961 L .45114 .61827 L F
.45196 .62043 m .45534 .62131 L .45462 .61961 L F
.705 .575 .707 r
.45196 .62043 m .45347 .62349 L .45534 .62131 L F
.318 0 .2 r
.44643 .56877 m .44855 .56896 L .44948 .56647 L F
.281 0 .112 r
.44855 .56896 m .45191 .56606 L .44948 .56647 L F
.936 .67 .507 r
.57219 .53336 m .57044 .53496 L .57037 .53247 L F
.57219 .53336 m .57243 .53639 L .57044 .53496 L F
.526 .303 .519 r
.24882 .61696 m .25143 .61426 L .24914 .61471 L F
0 0 0 r
.79207 .43747 m .79475 .43706 L .79594 .43681 L F
.159 0 0 r
.79475 .43706 m .79842 .43598 L .79594 .43681 L F
.424 .232 .514 r
.25345 .61114 m .25567 .60804 L .25393 .60872 L F
.47 .219 .451 r
.456 .61157 m .45822 .61315 L .45788 .61021 L F
.456 .61157 m .45581 .61391 L .45822 .61315 L F
0 0 .35 r
.81829 .44636 m .81744 .44557 L .81818 .44402 L F
.81829 .44636 m .81716 .44852 L .81744 .44557 L F
.905 .749 .678 r
.58394 .53816 m .58555 .53943 L .58423 .53584 L F
.874 .586 .065 r
.58394 .53816 m .58503 .54212 L .58555 .53943 L F
.521 .249 .442 r
.46509 .62378 m .46747 .62354 L .46712 .62227 L F
.449 .179 .412 r
.46747 .62354 m .47112 .62021 L .46712 .62227 L F
0 0 0 r
.19418 .54166 m .19303 .54345 L .19461 .54127 L F
.673 .958 .73 r
.19497 .54139 m .19418 .54166 L .19534 .54026 L F
0 0 0 r
.19418 .54166 m .19461 .54127 L .19534 .54026 L F
.471 .129 .303 r
.19383 .54198 m .19418 .54166 L .19497 .54139 L F
.19081 .54354 m .19418 .54166 L .19383 .54198 L F
.673 .958 .73 r
.19497 .54139 m .19706 .53813 L .19769 .53924 L F
.19497 .54139 m .19534 .54026 L .19706 .53813 L F
.93 .773 .666 r
.5721 .54167 m .56933 .54412 L .57054 .5401 L F
.5721 .54167 m .57099 .54526 L .56933 .54412 L F
.602 .66 .879 r
.732 .40386 m .7338 .40134 L .73105 .40207 L F
.732 .40386 m .73454 .40313 L .7338 .40134 L F
.617 .365 .514 r
.44943 .62655 m .45375 .62645 L .45347 .62349 L F
.804 .506 .484 r
.45375 .62645 m .45544 .62691 L .45347 .62349 L F
.817 .602 .611 r
.44604 .59878 m .45045 .60204 L .44731 .60036 L F
.9 .483 .133 r
.52354 .56928 m .52297 .57093 L .52228 .56826 L F
.52354 .56928 m .52443 .57188 L .52297 .57093 L F
.727 .227 .044 r
.48533 .55967 m .48762 .56191 L .48884 .56098 L F
.564 .024 0 r
.48762 .56191 m .49141 .56237 L .48884 .56098 L F
.444 0 0 r
.48884 .56098 m .49141 .56237 L .49352 .56304 L F
.448 .174 .403 r
.45683 .57438 m .45444 .5749 L .45712 .57258 L F
.544 .329 .538 r
.45937 .57192 m .45683 .57438 L .45712 .57258 L F
.666 .974 .884 r
.45732 .6199 m .45607 .62005 L .45534 .62131 L F
.215 .449 .87 r
.45534 .62131 m .45607 .62005 L .45462 .61961 L F
.828 .659 .673 r
.69152 .42607 m .69518 .42431 L .69156 .42359 L F
.69152 .42607 m .69323 .42743 L .69518 .42431 L F
.534 .302 .509 r
.47124 .62005 m .47575 .61722 L .47327 .61768 L F
.505 .262 .479 r
.43201 .64508 m .43168 .64776 L .42928 .64857 L F
.275 .289 .694 r
.43201 .64508 m .43387 .64391 L .43348 .6429 L F
.422 .191 .456 r
.434 .64677 m .43201 .64508 L .43348 .6429 L F
.434 .64677 m .43168 .64776 L .43201 .64508 L F
0 0 0 r
.2232 .68373 m .21901 .68672 L .22124 .68618 L F
.415 0 .006 r
.22349 .68564 m .2232 .68373 L .22124 .68618 L F
.22349 .68564 m .22547 .68388 L .2232 .68373 L F
.724 .77 .89 r
.47286 .56254 m .47485 .56418 L .47675 .56307 L F
.506 .754 .985 r
.18902 .75021 m .19295 .75139 L .1906 .75158 L F
.18902 .75021 m .19295 .75139 L .1906 .75158 L F
.774 .632 .703 r
.44007 .579 m .44013 .58129 L .43735 .58086 L F
.743 .367 .34 r
.44013 .58129 m .43991 .58308 L .43735 .58086 L F
.643 .392 .524 r
.44266 .58105 m .43991 .58308 L .44013 .58129 L F
.425 .141 .375 r
.27544 .62896 m .2738 .62741 L .27601 .62694 L F
.27544 .62896 m .27325 .6295 L .2738 .62741 L F
.77 .378 .312 r
.76802 .38649 m .76968 .38481 L .76773 .38418 L F
.76802 .38649 m .7715 .38751 L .76968 .38481 L F
.68 .686 .848 r
.16556 .59969 m .16465 .60276 L .16213 .59879 L F
.469 .463 .768 r
.16556 .59969 m .16675 .60201 L .16465 .60276 L F
.468 .334 .614 r
.16675 .60201 m .16554 .60412 L .16465 .60276 L F
.631 .24 0 r
.51838 .54627 m .51778 .5451 L .51598 .54646 L F
.51838 .54627 m .5193 .54793 L .51778 .5451 L F
.81 .447 .37 r
.51778 .5451 m .5193 .54793 L .52134 .54769 L F
0 0 0 r
.25741 .63925 m .2558 .64095 L .25384 .64156 L F
.25773 .64016 m .25741 .63925 L .25811 .64018 L F
.25773 .64016 m .2558 .64095 L .25741 .63925 L F
.309 0 0 r
.25978 .63923 m .25811 .64018 L .25741 .63925 L F
.579 .782 .975 r
.1842 .61694 m .18377 .61906 L .18226 .61736 L F
.1842 .61694 m .18583 .61853 L .18377 .61906 L F
.223 0 .007 r
.15717 .56015 m .15938 .55953 L .16095 .55752 L F
.174 0 0 r
.15938 .55953 m .16309 .55692 L .16095 .55752 L F
.584 .866 .995 r
.7793 .40347 m .77846 .40252 L .77544 .40353 L F
.903 .954 .821 r
.78066 .39938 m .7793 .40347 L .78199 .4007 L F
.78066 .39938 m .77846 .40252 L .7793 .40347 L F
.608 .82 .981 r
.26711 .53905 m .26319 .53862 L .26544 .53782 L F
.581 .809 .986 r
.26937 .53836 m .26711 .53905 L .26544 .53782 L F
.796 .754 .814 r
.76006 .41286 m .75573 .41446 L .7585 .4116 L F
.7 .668 .815 r
.84128 .41495 m .83897 .41616 L .83799 .41395 L F
.371 0 0 r
.45438 .56584 m .45701 .56557 L .45837 .56407 L F
.291 0 0 r
.45837 .56407 m .45701 .56557 L .46015 .56453 L F
.292 0 0 r
.45837 .56407 m .46015 .56453 L .46091 .56355 L F
.454 .269 .539 r
.80955 .42706 m .81201 .42643 L .81182 .42399 L F
.481 .393 .679 r
.80983 .43033 m .81201 .42643 L .80955 .42706 L F
0 0 .413 r
.51312 .59343 m .51404 .59551 L .51382 .59573 L F
0 .117 .646 r
.51404 .59551 m .51523 .59718 L .51382 .59573 L F
.292 .12 .468 r
.26601 .59069 m .26752 .59247 L .26795 .59 L F
.26601 .59069 m .26583 .59342 L .26752 .59247 L F
.27 0 .136 r
.18657 .56244 m .18298 .56572 L .18414 .56324 L F
.754 .237 0 r
.47591 .55673 m .47768 .55901 L .47941 .55925 L F
.322 .797 .917 r
.47768 .55901 m .48201 .55877 L .47941 .55925 L F
.592 .833 .99 r
.20146 .64598 m .2053 .64627 L .20409 .6455 L F
.281 .609 .955 r
.2053 .64627 m .20543 .64478 L .20409 .6455 L F
.2053 .64627 m .20698 .6452 L .20543 .64478 L F
.738 .366 0 r
.53112 .5537 m .53221 .55642 L .53276 .55712 L F
.811 .496 0 r
.5327 .55837 m .53276 .55712 L .53221 .55642 L F
.5327 .55837 m .53351 .56 L .53276 .55712 L F
.586 .571 .804 r
.834 .42407 m .83564 .41994 L .83321 .42114 L F
.834 .42407 m .83679 .42354 L .83564 .41994 L F
.569 .234 .361 r
.53906 .52001 m .54231 .51735 L .54133 .51911 L F
.53906 .52001 m .5395 .51828 L .54231 .51735 L F
.141 0 0 r
.54231 .51735 m .54446 .51712 L .54133 .51911 L F
.345 .823 .826 r
.7963 .44492 m .79473 .44578 L .79707 .44454 L F
.7963 .44492 m .79364 .44577 L .79473 .44578 L F
.098 0 .165 r
.16708 .57203 m .16602 .5749 L .16435 .57505 L F
0 0 0 r
.1645 .57626 m .16435 .57505 L .16602 .5749 L F
.1645 .57626 m .16278 .57707 L .16435 .57505 L F
.371 .059 .3 r
.28682 .61491 m .28611 .61702 L .28388 .61754 L F
.456 .137 .335 r
.28849 .61652 m .28682 .61491 L .28892 .61423 L F
.28849 .61652 m .28611 .61702 L .28682 .61491 L F
0 .102 .654 r
.52984 .58443 m .53161 .58661 L .53016 .58305 L F
.114 .093 .553 r
.41811 .64433 m .4185 .64696 L .41718 .64755 L F
.187 .277 .725 r
.4185 .64696 m .41923 .65068 L .41718 .64755 L F
0 .021 .569 r
.49352 .56304 m .49562 .56536 L .49618 .5664 L F
.754 .244 0 r
.49141 .56237 m .49562 .56536 L .49352 .56304 L F
.844 .723 .73 r
.45462 .61961 m .4526 .61605 L .45114 .61827 L F
.429 .7 .978 r
.81213 .40016 m .80996 .40163 L .80897 .40024 L F
.81213 .40016 m .81298 .40158 L .80996 .40163 L F
.737 .677 .792 r
.67222 .43124 m .66814 .43016 L .67052 .42897 L F
.661 .664 .842 r
.6743 .42994 m .67222 .43124 L .67052 .42897 L F
.694 .548 .684 r
.82507 .43608 m .82308 .43306 L .82291 .43561 L F
.82507 .43608 m .82685 .43372 L .82308 .43306 L F
.554 .439 .676 r
.72135 .39971 m .7235 .39632 L .72109 .39711 L F
0 .126 .675 r
.53385 .59366 m .53384 .59272 L .53218 .59053 L F
.849 .63 .088 r
.53385 .59366 m .53367 .59507 L .53384 .59272 L F
.53385 .59366 m .53403 .59619 L .53367 .59507 L F
.701 .871 .962 r
.21243 .62575 m .21391 .62689 L .20977 .62686 L F
.813 .746 .789 r
.20977 .62686 m .21391 .62689 L .21136 .63001 L F
.517 .315 .545 r
.21391 .62689 m .21386 .62912 L .21136 .63001 L F
.766 .628 .064 r
.21373 .62858 m .21391 .62689 L .21243 .62575 L F
.21373 .62858 m .21386 .62912 L .21391 .62689 L F
.481 .393 .679 r
.80983 .43033 m .81303 .42898 L .81201 .42643 L F
.509 .383 .644 r
.8101 .43154 m .81303 .42898 L .80983 .43033 L F
0 0 0 r
.45411 .63823 m .45051 .64183 L .45224 .6392 L F
.195 0 0 r
.45683 .57438 m .45329 .57534 L .45444 .5749 L F
.622 .088 0 r
.14843 .59128 m .14937 .59216 L .1478 .59062 L F
.342 .645 .966 r
.21136 .63001 m .20757 .62844 L .20977 .62686 L F
.615 .571 .781 r
.72212 .40296 m .72382 .39894 L .72135 .39971 L F
.72212 .40296 m .72481 .40211 L .72382 .39894 L F
.645 .621 .811 r
.72212 .40296 m .72594 .40423 L .72481 .40211 L F
.727 .881 .952 r
.50228 .59277 m .50072 .59377 L .50049 .59199 L F
.50049 .59199 m .50072 .59377 L .50228 .59277 L F
.50228 .59277 m .50072 .59377 L .50049 .59199 L F
.002 0 .132 r
.46509 .62378 m .46606 .62501 L .46747 .62354 L F
.46509 .62378 m .46466 .6259 L .46606 .62501 L F
.51 .699 .955 r
.8205 .40496 m .82296 .40457 L .82378 .40622 L F
.498 .692 .955 r
.82296 .40457 m .82546 .4043 L .82378 .40622 L F
.52 .726 .967 r
.82546 .4043 m .82639 .40585 L .82378 .40622 L F
.314 0 .239 r
.54589 .50544 m .54815 .50515 L .54888 .50287 L F
.402 .055 .258 r
.54815 .50515 m .55137 .50237 L .54888 .50287 L F
.572 .665 .901 r
.17034 .61494 m .16707 .6137 L .16859 .61355 L F
.769 .692 .777 r
.17248 .61184 m .17034 .61494 L .16859 .61355 L F
.088 0 0 r
.80324 .443 m .80244 .44357 L .79975 .44388 L F
.432 0 0 r
.80324 .443 m .80607 .4441 L .80244 .44357 L F
.225 0 0 r
.43782 .61522 m .43862 .61549 L .43764 .6143 L F
.748 .399 .39 r
.29767 .5472 m .29934 .54828 L .30071 .54721 L F
.465 .024 .114 r
.30071 .54721 m .29934 .54828 L .30379 .54687 L F
.726 .682 .808 r
.19571 .75379 m .19686 .75628 L .19704 .75364 L F
.726 .39 .409 r
.21075 .68709 m .21472 .68746 L .21232 .68847 L F
.161 0 0 r
.21366 .68745 m .21472 .68746 L .21075 .68709 L F
.721 .985 .894 r
.21355 .68745 m .21472 .68746 L .21516 .68612 L F
.21232 .68847 m .21472 .68746 L .21355 .68745 L F
.161 0 0 r
.21381 .68747 m .21472 .68746 L .21366 .68745 L F
.818 .576 .573 r
.21472 .68746 m .21513 .69044 L .21232 .68847 L F
.74 .992 .856 r
.21516 .68612 m .21472 .68746 L .21381 .68747 L F
0 .188 .71 r
.21472 .68746 m .2158 .68923 L .21516 .68612 L F
.708 .402 .457 r
.56633 .49706 m .5662 .49912 L .56979 .49919 L F
.498 .316 .564 r
.59489 .51462 m .59475 .51178 L .59245 .51513 L F
.524 .775 .989 r
.59245 .51513 m .59367 .51335 L .59162 .51452 L F
.498 .316 .564 r
.59245 .51513 m .59475 .51178 L .59489 .51462 L F
.524 .775 .989 r
.59245 .51513 m .59489 .51462 L .59367 .51335 L F
.498 .316 .564 r
.59489 .51462 m .59245 .51513 L .59162 .51452 L F
.598 .621 .846 r
.21793 .70813 m .21585 .71001 L .21562 .70795 L F
.499 .532 .822 r
.1896 .64351 m .19064 .64167 L .18799 .64151 L F
.1896 .64351 m .19125 .64355 L .19064 .64167 L F
.736 .606 .713 r
.58891 .51224 m .59113 .50898 L .58746 .50875 L F
.957 .672 .236 r
.49554 .56721 m .4965 .56914 L .49618 .5664 L F
.952 .753 .295 r
.49562 .56536 m .49554 .56721 L .49618 .5664 L F
.819 .706 .74 r
.47503 .59858 m .47706 .59596 L .47511 .59696 L F
.255 .371 .789 r
.43272 .62346 m .43408 .62728 L .43538 .62537 L F
.214 .26 .695 r
.43408 .62728 m .43686 .62746 L .43538 .62537 L F
.43408 .62728 m .43589 .62937 L .43686 .62746 L F
.989 .842 .606 r
.54049 .58092 m .53972 .58344 L .54087 .58445 L F
.961 .686 .467 r
.53933 .58653 m .54087 .58445 L .53972 .58344 L F
.53933 .58653 m .541 .58765 L .54087 .58445 L F
.809 .586 .6 r
.43296 .64102 m .43704 .64169 L .43686 .63896 L F
0 .112 .629 r
.43686 .63896 m .43923 .64108 L .43464 .63629 L F
.472 .331 .607 r
.43704 .64169 m .43923 .64108 L .43686 .63896 L F
.105 0 0 r
.17862 .56685 m .17735 .56832 L .17546 .56885 L F
0 0 0 r
.18107 .56659 m .17735 .56832 L .17862 .56685 L F
.54 .673 .924 r
.16703 .61046 m .16707 .6137 L .16467 .61094 L F
.16703 .61046 m .16859 .61355 L .16707 .6137 L F
.706 .25 .167 r
.5193 .54793 m .51966 .54913 L .52134 .54769 L F
.73 .282 .188 r
.51966 .54913 m .52363 .55003 L .52134 .54769 L F
.384 .801 .975 r
.52198 .52408 m .52103 .52346 L .51824 .52388 L F
.51824 .52388 m .52103 .52346 L .52198 .52408 L F
.486 .328 .593 r
.30433 .58404 m .30435 .58672 L .30222 .58484 L F
.283 .316 .72 r
.30222 .58484 m .30435 .58672 L .30316 .58741 L F
.106 .635 .87 r
.26137 .55761 m .25705 .55683 L .25895 .55698 L F
0 0 0 r
.49756 .59971 m .49498 .6027 L .49762 .60259 L F
0 .086 .636 r
.49498 .6027 m .49682 .60457 L .49762 .60259 L F
.564 .707 .938 r
.24871 .556 m .2493 .55328 L .2459 .5542 L F
.24871 .556 m .25145 .55541 L .2493 .55328 L F
.945 .667 .48 r
.49329 .57847 m .49149 .5777 L .49164 .57522 L F
0 0 .328 r
.49329 .57847 m .49339 .58116 L .49424 .57924 L F
.49329 .57847 m .49424 .57924 L .49149 .5777 L F
.217 0 0 r
.43871 .63062 m .43779 .63019 L .4388 .62848 L F
.43871 .63062 m .43637 .63149 L .43779 .63019 L F
0 0 .136 r
.47019 .56562 m .468 .56878 L .46882 .56676 L F
.906 .817 .748 r
.57219 .52681 m .57016 .52626 L .57167 .52339 L F
.968 .83 .654 r
.57219 .52681 m .56982 .52905 L .57016 .52626 L F
.57219 .52681 m .57114 .53007 L .56982 .52905 L F
.561 .371 .581 r
.23641 .66691 m .23536 .6692 L .2375 .66766 L F
.318 .779 .944 r
.78399 .38738 m .7853 .3878 L .78156 .38767 L F
0 .388 .821 r
.78837 .38862 m .7853 .3878 L .78399 .38738 L F
.78837 .38862 m .78919 .38958 L .7853 .3878 L F
0 .374 .812 r
.78978 .39059 m .7853 .3878 L .78919 .38958 L F
.106 .635 .87 r
.26137 .55761 m .25925 .55699 L .25705 .55683 L F
.083 .593 .888 r
.26321 .55788 m .25925 .55699 L .26137 .55761 L F
.601 .716 .926 r
.74198 .40666 m .74382 .40416 L .7412 .40473 L F
.74198 .40666 m .74434 .40607 L .74382 .40416 L F
.518 .914 .91 r
.68381 .43432 m .68783 .43327 L .68665 .43207 L F
.795 .777 .837 r
.68783 .43327 m .68899 .42904 L .68665 .43207 L F
.68783 .43327 m .69069 .4305 L .68899 .42904 L F
.998 .852 .538 r
.56891 .55678 m .56791 .55574 L .56935 .55423 L F
.997 .86 .55 r
.56935 .55423 m .56842 .55319 L .56898 .55065 L F
.997 .855 .539 r
.56935 .55423 m .56791 .55574 L .56842 .55319 L F
.572 .573 .816 r
.80503 .40934 m .80619 .41278 L .80831 .41038 L F
.564 .561 .809 r
.80619 .41278 m .80892 .41227 L .80831 .41038 L F
0 .169 .613 r
.79288 .39895 m .78885 .39613 L .78967 .39768 L F
.637 .825 .973 r
.54057 .60899 m .54118 .60713 L .53908 .60745 L F
.54057 .60899 m .54288 .60807 L .54118 .60713 L F
.784 .496 .5 r
.68778 .42081 m .69156 .42359 L .69153 .42129 L F
.406 .327 .655 r
.44167 .60257 m .44338 .59937 L .44033 .59892 L F
.44167 .60257 m .44354 .602 L .44338 .59937 L F
.529 .425 .68 r
.44148 .6052 m .44354 .602 L .44167 .60257 L F
.602 .847 .991 r
.19792 .62336 m .19782 .62497 L .19593 .62322 L F
.19792 .62336 m .19965 .62428 L .19782 .62497 L F
.764 .81 .89 r
.75492 .42399 m .7584 .4243 L .75755 .42265 L F
.494 .679 .948 r
.75755 .42265 m .7584 .4243 L .76018 .42237 L F
.291 .358 .76 r
.7584 .4243 m .76108 .42611 L .76018 .42237 L F
0 0 .058 r
.51336 .59174 m .51321 .59049 L .51284 .5894 L F
.51336 .59174 m .51312 .59343 L .51321 .59072 L F
.715 .186 0 r
.51354 .593 m .51336 .59174 L .51215 .59039 L F
0 .004 .559 r
.51336 .59174 m .51404 .59551 L .51312 .59343 L F
.715 .186 0 r
.51356 .59304 m .51336 .59174 L .51354 .593 L F
0 0 .058 r
.51336 .59174 m .51321 .59072 L .51321 .59049 L F
.596 .37 .544 r
.44033 .59892 m .44338 .59937 L .44336 .59633 L F
.6 .374 .545 r
.44336 .59633 m .44604 .59878 L .44605 .59617 L F
.44336 .59633 m .44338 .59937 L .44604 .59878 L F
.329 0 .062 r
.55403 .51172 m .55279 .51361 L .55035 .51411 L F
.559 .134 .191 r
.55637 .51323 m .55403 .51172 L .55632 .51194 L F
.55637 .51323 m .55279 .51361 L .55403 .51172 L F
.624 .388 .539 r
.5725 .49686 m .57497 .49881 L .57622 .49657 L F
.5725 .49686 m .57249 .49926 L .57497 .49881 L F
.835 .918 .89 r
.78573 .3929 m .78372 .39619 L .78689 .39561 L F
.78573 .3929 m .7826 .39544 L .78372 .39619 L F
0 0 .497 r
.42447 .61379 m .42151 .61058 L .42539 .61194 L F
.42447 .61379 m .4243 .6136 L .42151 .61058 L F
.479 .603 .897 r
.42151 .61058 m .4243 .6136 L .42199 .61399 L F
.404 .178 .454 r
.42396 .61396 m .42099 .61718 L .42253 .6139 L F
.42253 .6139 m .42099 .61718 L .42199 .61399 L F
.808 .841 .875 r
.41858 .61517 m .42245 .61468 L .41893 .61353 L F
.787 .999 .837 r
.42271 .61452 m .42099 .61718 L .42424 .61366 L F
.42251 .61456 m .42225 .61501 L .42227 .61499 L F
.42251 .61456 m .42227 .61499 L .42279 .61441 L F
.808 .841 .875 r
.42245 .61468 m .42289 .61462 L .42266 .61455 L F
.787 .999 .837 r
.42225 .61501 m .42099 .61718 L .42279 .61441 L F
.808 .841 .875 r
.42245 .61468 m .42251 .61456 L .42289 .61462 L F
.42245 .61468 m .42266 .61455 L .41893 .61353 L F
.41858 .61517 m .42251 .61456 L .42245 .61468 L F
.787 .999 .837 r
.42279 .61441 m .42271 .61452 L .4243 .6136 L F
.404 .178 .454 r
.4243 .6136 m .42396 .61396 L .42253 .6139 L F
.787 .999 .837 r
.42271 .61452 m .42424 .61366 L .4243 .6136 L F
.572 .427 .647 r
.41893 .61353 m .42266 .61455 L .42151 .61058 L F
.42266 .61455 m .42289 .61462 L .42284 .61446 L F
.42266 .61455 m .42284 .61446 L .42274 .61447 L F
.582 .433 .645 r
.42151 .61058 m .42284 .61446 L .42539 .61194 L F
.42284 .61446 m .42289 .61462 L .42304 .61446 L F
.42284 .61446 m .42304 .61446 L .42539 .61194 L F
.18 0 0 r
.42275 .61447 m .42495 .61466 L .42251 .61456 L F
.42275 .61447 m .42275 .61447 L .42275 .61447 L F
.42275 .61447 m .42495 .61466 L .42275 .61447 L F
.42403 .61396 m .42461 .6144 L .42275 .61447 L F
.42461 .6144 m .42495 .61466 L .42275 .61447 L F
.42447 .61379 m .42275 .61447 L .4243 .6136 L F
.572 .427 .647 r
.42274 .61447 m .42275 .61447 L .42279 .61441 L F
.42266 .61455 m .42281 .61439 L .42151 .61058 L F
.18 0 0 r
.42275 .61447 m .42251 .61456 L .42279 .61441 L F
.42275 .61447 m .42279 .61441 L .4243 .6136 L F
.572 .427 .647 r
.42279 .61441 m .42284 .61446 L .42281 .61439 L F
.42275 .61447 m .42284 .61446 L .42279 .61441 L F
.18 0 0 r
.42447 .61379 m .42457 .61399 L .42403 .61396 L F
.42457 .61399 m .42495 .61466 L .42403 .61396 L F
.65 .906 .981 r
.23471 .65904 m .23652 .65974 L .23823 .65871 L F
.23471 .65904 m .23652 .65974 L .23823 .65871 L F
.999 .805 .508 r
.56921 .56353 m .56791 .56239 L .56823 .55907 L F
.981 .785 .567 r
.56921 .56353 m .56716 .56489 L .56791 .56239 L F
.56921 .56353 m .56864 .56604 L .56716 .56489 L F
0 0 .568 r
.51369 .53677 m .51481 .53829 L .51341 .5348 L F
.679 .858 .967 r
.78066 .39938 m .78199 .4007 L .78318 .39834 L F
.525 .658 .919 r
.73454 .40313 m .73856 .40558 L .73715 .40245 L F
.604 .665 .882 r
.73856 .40558 m .73966 .40163 L .73715 .40245 L F
.73856 .40558 m .7412 .40473 L .73966 .40163 L F
.379 .048 .273 r
.27264 .63146 m .27119 .63022 L .27325 .6295 L F
.27264 .63146 m .27041 .63201 L .27119 .63022 L F
.686 .248 .203 r
.49956 .60192 m .49756 .59971 L .49762 .60259 L F
.031 0 0 r
.21775 .63037 m .21747 .63029 L .21551 .62996 L F
.21775 .63037 m .22003 .6303 L .21747 .63029 L F
.651 .644 .829 r
.72594 .40423 m .72854 .40319 L .72481 .40211 L F
.657 .777 .937 r
.20977 .62686 m .20757 .62844 L .20568 .62651 L F
0 .183 .715 r
.40656 .62049 m .40858 .62226 L .40855 .62344 L F
0 .118 .641 r
.40855 .62344 m .41153 .62616 L .41177 .62676 L F
.675 .126 0 r
.40918 .62493 m .41153 .62616 L .40855 .62344 L F
.40918 .62493 m .40855 .62344 L .40858 .62226 L F
.784 .325 .156 r
.19706 .53813 m .19969 .53907 L .19769 .53924 L F
.271 .758 .668 r
.46624 .57015 m .46215 .57176 L .46164 .57174 L F
.781 .947 .61 r
.46491 .56909 m .46345 .57121 L .46422 .57093 L F
.271 .758 .668 r
.46489 .57068 m .46422 .57093 L .46215 .57176 L F
0 0 0 r
.46422 .57093 m .46116 .57348 L .46215 .57176 L F
.781 .947 .61 r
.46345 .57121 m .46267 .57234 L .46422 .57093 L F
.271 .758 .668 r
.46624 .57015 m .46422 .57093 L .46489 .57068 L F
.681 .974 .795 r
.4672 .56855 m .46624 .57015 L .468 .56878 L F
.4672 .56855 m .46422 .57093 L .46624 .57015 L F
.358 .548 .903 r
.48632 .57052 m .48611 .57218 L .48419 .57172 L F
.48632 .57052 m .48823 .57278 L .48611 .57218 L F
0 0 0 r
.48823 .57278 m .48419 .57172 L .48611 .57218 L F
.265 .551 .928 r
.19438 .62144 m .1941 .62298 L .19207 .62151 L F
.19438 .62144 m .19593 .62322 L .1941 .62298 L F
.499 .247 .463 r
.40971 .60487 m .4061 .60772 L .40649 .6081 L F
.225 .249 .677 r
.4 .61433 m .40067 .61774 L .40227 .61644 L F
.301 .177 .539 r
.40067 .61774 m .40287 .61929 L .40227 .61644 L F
.40067 .61774 m .40075 .62028 L .40287 .61929 L F
.817 .641 .664 r
.58524 .51166 m .58891 .51224 L .58746 .50875 L F
.834 .849 .857 r
.58483 .51392 m .58891 .51224 L .58524 .51166 L F
.811 .69 .731 r
.75466 .37848 m .75541 .38193 L .75198 .38089 L F
.957 .671 .235 r
.75541 .38193 m .7548 .38221 L .75198 .38089 L F
.75541 .38193 m .75573 .38442 L .7548 .38221 L F
.608 .605 .822 r
.75677 .37752 m .75541 .38193 L .75466 .37848 L F
.75677 .37752 m .75857 .38154 L .75541 .38193 L F
.559 .317 .505 r
.75541 .38193 m .75796 .38361 L .75573 .38442 L F
.75541 .38193 m .75857 .38154 L .75796 .38361 L F
.798 .312 0 r
.50828 .58235 m .5087 .58153 L .50791 .5803 L F
.50828 .58235 m .51027 .58381 L .5087 .58153 L F
.967 .832 .658 r
.51516 .62618 m .51434 .62572 L .51484 .62404 L F
.956 .616 .31 r
.51516 .62618 m .51452 .62835 L .51434 .62572 L F
.8 .582 .019 r
.51484 .62404 m .51493 .62581 L .51516 .62618 L F
.842 .766 .256 r
.51493 .62581 m .51452 .62835 L .51516 .62618 L F
.736 .491 .558 r
.57497 .49881 m .57858 .4968 L .57622 .49657 L F
.57497 .49881 m .57866 .49926 L .57858 .4968 L F
.778 .524 .553 r
.57858 .4968 m .57866 .49926 L .58226 .4996 L F
0 0 0 r
.49369 .53912 m .49529 .53813 L .49617 .53712 L F
.443 0 0 r
.49617 .53712 m .49529 .53813 L .49821 .53794 L F
.869 .779 .76 r
.20254 .74096 m .20153 .74409 L .20158 .74158 L F
.20153 .74409 m .20113 .74531 L .20123 .74449 L F
.20153 .74409 m .20123 .74449 L .20158 .74158 L F
.504 .446 .725 r
.20123 .74449 m .19874 .746 L .20113 .74531 L F
.803 .676 .724 r
.20123 .74449 m .20117 .74457 L .19934 .74565 L F
.20117 .74457 m .20115 .7446 L .20054 .74496 L F
.20117 .74457 m .20054 .74496 L .19934 .74565 L F
.19926 .74568 m .19934 .74565 L .19874 .746 L F
.20123 .74449 m .19934 .74565 L .19926 .74568 L F
.514 .485 .762 r
.20054 .74496 m .19874 .746 L .19767 .74326 L F
.103 .229 .711 r
.19767 .74326 m .19874 .746 L .1988 .74601 L F
.514 .485 .762 r
.1995 .74559 m .19767 .74326 L .19869 .74572 L F
.20113 .74531 m .19874 .746 L .20054 .74496 L F
.20113 .74531 m .20054 .74496 L .1995 .74559 L F
.20054 .74496 m .19767 .74326 L .1995 .74559 L F
.103 .229 .711 r
.19767 .74326 m .19869 .74572 L .19916 .74483 L F
.499 .733 .977 r
.20081 .74506 m .20113 .74531 L .1995 .74559 L F
.803 .676 .724 r
.20115 .7446 m .19995 .74623 L .19874 .746 L F
.499 .733 .977 r
.19954 .7441 m .20081 .74506 L .19869 .74572 L F
.19954 .7441 m .19869 .74572 L .19867 .74573 L F
.20081 .74506 m .1995 .74559 L .19867 .74573 L F
.869 .779 .76 r
.20158 .74158 m .20123 .74449 L .19868 .74344 L F
.20123 .74449 m .20113 .74531 L .20081 .74506 L F
.20123 .74449 m .20081 .74506 L .19868 .74344 L F
.504 .446 .725 r
.20267 .74362 m .20113 .74531 L .20254 .74096 L F
.803 .676 .724 r
.20267 .74362 m .2006 .74636 L .19995 .74623 L F
.504 .446 .725 r
.20267 .74362 m .20123 .74449 L .20113 .74531 L F
.803 .676 .724 r
.20267 .74362 m .19995 .74623 L .20123 .74449 L F
.103 .229 .711 r
.19916 .74483 m .1988 .74601 L .2006 .74636 L F
.19869 .74572 m .1988 .74601 L .19916 .74483 L F
.514 .485 .762 r
.19869 .74572 m .19767 .74326 L .19867 .74573 L F
.794 .621 .666 r
.19614 .74433 m .19867 .74573 L .19767 .74326 L F
.103 .229 .711 r
.19767 .74326 m .19916 .74483 L .19764 .74501 L F
.718 .478 .561 r
.19767 .74326 m .19764 .74504 L .19614 .74433 L F
0 .467 .863 r
.19796 .74519 m .19867 .74573 L .19706 .74483 L F
.19764 .74504 m .19706 .74483 L .19614 .74433 L F
.19796 .74519 m .19706 .74483 L .19764 .74504 L F
.103 .229 .711 r
.19764 .74501 m .19786 .74511 L .19786 .74511 L F
.19764 .74504 m .19786 .74511 L .19764 .74518 L F
.19764 .74501 m .19786 .74511 L .19764 .74504 L F
.718 .478 .561 r
.19764 .74504 m .1976 .74705 L .19614 .74433 L F
0 .467 .863 r
.1958 .74355 m .19796 .74519 L .19614 .74433 L F
.499 .733 .977 r
.19868 .74344 m .19867 .74489 L .1958 .74355 L F
.19867 .74489 m .19867 .74573 L .19786 .74511 L F
.19867 .74489 m .19786 .74511 L .1958 .74355 L F
.103 .229 .711 r
.19764 .74518 m .2006 .74636 L .1976 .74705 L F
.499 .733 .977 r
.19867 .74489 m .19915 .74483 L .19867 .74573 L F
.103 .229 .711 r
.19786 .74511 m .2006 .74636 L .19764 .74518 L F
.19916 .74483 m .2006 .74636 L .19764 .74501 L F
.499 .733 .977 r
.19868 .74344 m .19954 .7441 L .19915 .74483 L F
.19868 .74344 m .19915 .74483 L .19867 .74489 L F
.641 .151 .071 r
.74798 .37843 m .7516 .3789 L .74992 .37999 L F
.898 .539 .354 r
.74992 .37999 m .7516 .3789 L .75198 .38089 L F
.811 .69 .731 r
.75466 .37848 m .75198 .38089 L .7516 .3789 L F
.244 0 0 r
.44643 .56877 m .44355 .57001 L .4454 .57028 L F
.257 0 0 r
.4476 .5698 m .44643 .56877 L .4454 .57028 L F
.4476 .5698 m .44855 .56896 L .44643 .56877 L F
.723 .192 0 r
.49825 .54051 m .50004 .54067 L .49821 .53794 L F
.49825 .54051 m .49979 .54118 L .50004 .54067 L F
.15 0 0 r
.49003 .54128 m .49369 .53912 L .49 .53858 L F
.49003 .54128 m .49232 .54069 L .49369 .53912 L F
.138 0 0 r
.49369 .53912 m .49468 .54 L .49529 .53813 L F
.49369 .53912 m .49232 .54069 L .49468 .54 L F
.586 .416 .618 r
.50347 .60239 m .50149 .60441 L .50136 .6027 L F
.099 0 0 r
.22448 .53761 m .22673 .53759 L .22867 .53723 L F
0 0 0 r
.22673 .53759 m .23045 .53698 L .22867 .53723 L F
.193 .53 .922 r
.77805 .43276 m .77677 .43274 L .77582 .43106 L F
.375 .111 .38 r
.42934 .57831 m .43147 .57777 L .43209 .57482 L F
.122 0 .282 r
.43209 .57482 m .43353 .57631 L .43479 .57414 L F
.43209 .57482 m .43147 .57777 L .43353 .57631 L F
.487 .622 .909 r
.16544 .62564 m .16641 .62726 L .16757 .62535 L F
.464 .591 .895 r
.16757 .62535 m .16641 .62726 L .16813 .62692 L F
.319 .512 .889 r
.16641 .62726 m .16979 .6301 L .16813 .62692 L F
.543 .361 .585 r
.75425 .39114 m .75643 .3875 L .75317 .38713 L F
.75425 .39114 m .75683 .39031 L .75643 .3875 L F
.772 .914 .532 r
.75643 .3875 m .75425 .39114 L .75683 .39031 L F
.91 .982 .738 r
.7559 .38662 m .75643 .3875 L .75847 .38414 L F
.89 .75 .702 r
.82321 .43049 m .82222 .42687 L .82152 .42933 L F
.241 .516 .91 r
.48815 .56806 m .48956 .56749 L .48703 .56587 L F
0 0 .058 r
.58172 .57914 m .58142 .57846 L .58203 .57679 L F
.58172 .57914 m .58126 .58092 L .58142 .57846 L F
.182 .059 .467 r
.30438 .58924 m .30316 .58741 L .30435 .58672 L F
.30438 .58924 m .30304 .59024 L .30316 .58741 L F
.809 .706 .752 r
.58238 .53176 m .5843 .53343 L .5831 .52998 L F
.875 .634 .571 r
.58249 .53478 m .5843 .53343 L .58238 .53176 L F
.58249 .53478 m .58423 .53584 L .5843 .53343 L F
.535 .007 0 r
.79632 .40202 m .79288 .39895 L .79404 .4 L F
.536 .714 .954 r
.24075 .55387 m .24256 .55527 L .24401 .55451 L F
.981 .782 .563 r
.51645 .60119 m .51818 .59951 L .51691 .59852 L F
.51645 .60119 m .51793 .60279 L .51818 .59951 L F
.34 .482 .856 r
.16813 .62692 m .16979 .6301 L .171 .62851 L F
.485 .463 .758 r
.16979 .6301 m .17289 .63196 L .171 .62851 L F
.16979 .6301 m .17075 .63221 L .17289 .63196 L F
.819 .706 .74 r
.47503 .59858 m .47851 .5996 L .47706 .59596 L F
.535 0 0 r
.47503 .59858 m .47758 .59975 L .47851 .5996 L F
.995 .756 .409 r
.47834 .59963 m .47829 .60193 L .47851 .5996 L F
.47778 .60037 m .47829 .60193 L .47834 .59963 L F
.38 .165 .457 r
.48039 .60104 m .47851 .5996 L .48098 .59925 L F
.47983 .60058 m .47851 .5996 L .47859 .59953 L F
.706 .31 .296 r
.47979 .6002 m .48005 .60025 L .47963 .59851 L F
.38 .126 .399 r
.4799 .60032 m .47998 .60036 L .48005 .60025 L F
.38 .165 .457 r
.48023 .60052 m .47859 .59953 L .47963 .59851 L F
0 0 .272 r
.47851 .5996 m .47963 .59573 L .47706 .59596 L F
.47851 .5996 m .47963 .59851 L .47963 .59573 L F
.38 .165 .457 r
.48039 .60104 m .47829 .60193 L .47851 .5996 L F
.48039 .60104 m .47829 .60193 L .47851 .5996 L F
.706 .31 .296 r
.47758 .59975 m .47979 .6002 L .47963 .59851 L F
.38 .165 .457 r
.48039 .60104 m .47984 .60062 L .47983 .60058 L F
.47984 .60062 m .47851 .5996 L .47983 .60058 L F
.47992 .60035 m .47859 .59953 L .4799 .60032 L F
.48039 .60104 m .47938 .6002 L .47992 .60035 L F
.47938 .6002 m .47859 .59953 L .47992 .60035 L F
.559 .604 .855 r
.48039 .60104 m .47829 .60193 L .47795 .60089 L F
.995 .756 .409 r
.47758 .59975 m .47778 .60037 L .47834 .59963 L F
.559 .604 .855 r
.47943 .6006 m .47795 .60089 L .47758 .59975 L F
.48039 .60104 m .47795 .60089 L .47943 .6006 L F
.491 .242 .464 r
.48039 .60104 m .4779 .60318 L .47829 .60193 L F
.22 0 0 r
.48005 .60025 m .47998 .60036 L .48008 .60039 L F
.706 .31 .296 r
.47979 .6002 m .4799 .60032 L .48005 .60025 L F
.47758 .59975 m .4799 .60032 L .47979 .6002 L F
.559 .604 .855 r
.4802 .60043 m .47758 .59975 L .47963 .59851 L F
.38 .165 .457 r
.48031 .60078 m .47994 .60036 L .48023 .60052 L F
.47994 .60036 m .4799 .60032 L .47999 .60037 L F
.47994 .60036 m .47999 .60037 L .48023 .60052 L F
.485 .152 .328 r
.48369 .59893 m .48039 .60104 L .48098 .59925 L F
.48369 .59893 m .483 .60076 L .48039 .60104 L F
.22 0 0 r
.48005 .60025 m .48008 .60039 L .48347 .59933 L F
.38 .165 .457 r
.48039 .60104 m .4799 .60032 L .48031 .60078 L F
.475 .229 .461 r
.4826 .60236 m .48039 .60104 L .483 .60076 L F
.4826 .60236 m .48027 .60299 L .48039 .60104 L F
.22 0 0 r
.48008 .60039 m .48037 .6021 L .48184 .60079 L F
.48008 .60039 m .48184 .60079 L .48347 .59933 L F
.559 .604 .855 r
.48039 .60104 m .47943 .6006 L .4802 .60043 L F
.22 0 0 r
.48008 .60039 m .48002 .60047 L .48009 .60045 L F
.559 .604 .855 r
.47943 .6006 m .47758 .59975 L .47968 .60055 L F
.706 .31 .296 r
.47758 .59975 m .47671 .60168 L .47951 .60048 L F
.47758 .59975 m .47951 .60048 L .4799 .60032 L F
.559 .604 .855 r
.47968 .60055 m .47758 .59975 L .4802 .60043 L F
.22 0 0 r
.48009 .60045 m .48 .60049 L .48009 .60047 L F
.48002 .60047 m .48 .60049 L .48009 .60045 L F
.491 .242 .464 r
.48039 .60104 m .48027 .60299 L .4779 .60318 L F
.22 0 0 r
.48009 .60047 m .47851 .60253 L .48037 .6021 L F
.48 .60049 m .47851 .60253 L .48009 .60047 L F
.47998 .60036 m .47851 .60253 L .48008 .60039 L F
.313 0 .091 r
.4779 .60318 m .47605 .60269 L .47829 .60193 L F
.38 .126 .399 r
.47683 .60163 m .47851 .60253 L .47998 .60036 L F
.47683 .60163 m .47998 .60036 L .4799 .60032 L F
.47671 .60168 m .47677 .6017 L .47683 .60163 L F
.47677 .6017 m .47851 .60253 L .47683 .60163 L F
.67 .522 .675 r
.74613 .39441 m .74206 .39412 L .74454 .39322 L F
.74613 .39441 m .74355 .39765 L .74206 .39412 L F
.74613 .39441 m .7451 .39639 L .74355 .39765 L F
0 0 .121 r
.74725 .39283 m .74613 .39441 L .7474 .3928 L F
.54 .789 .99 r
.7474 .3928 m .74613 .39441 L .74454 .39322 L F
.65 .541 .717 r
.8115 .4215 m .81182 .42399 L .81419 .4209 L F
.544 .396 .631 r
.81182 .42399 m .81438 .4237 L .81419 .4209 L F
.407 .168 .437 r
.81201 .42643 m .81438 .4237 L .81182 .42399 L F
.693 .73 .879 r
.84434 .41377 m .84403 .41491 L .84128 .41495 L F
.468 .498 .806 r
.84434 .41377 m .84677 .41368 L .84403 .41491 L F
.297 .771 .659 r
.84403 .41491 m .8446 .41463 L .8443 .41751 L F
.84403 .41491 m .84677 .41368 L .8446 .41463 L F
.537 .565 .831 r
.48921 .57366 m .49164 .57522 L .49041 .57138 L F
.036 0 0 r
.58503 .54212 m .58183 .54394 L .58491 .54362 L F
.58503 .54212 m .58489 .54247 L .58183 .54394 L F
.874 .586 .065 r
.58394 .53816 m .58489 .54247 L .58503 .54212 L F
.343 .129 .438 r
.4 .61433 m .40182 .61395 L .40224 .61174 L F
.225 .249 .677 r
.4 .61433 m .40227 .61644 L .40182 .61395 L F
.593 .448 .654 r
.30435 .55358 m .30526 .55761 L .30224 .55714 L F
.53 .408 .657 r
.30497 .55938 m .30224 .55714 L .30526 .55761 L F
.30497 .55938 m .30273 .5604 L .30224 .55714 L F
.546 0 0 r
.20928 .72238 m .21285 .72367 L .21049 .72329 L F
.788 .947 .926 r
.21049 .72329 m .21285 .72367 L .21345 .72243 L F
.574 .431 .648 r
.74544 .38141 m .7431 .38453 L .74286 .38199 L F
.419 .085 .291 r
.26532 .63523 m .26189 .63816 L .26292 .63608 L F
.126 0 0 r
.43428 .57833 m .43167 .58047 L .4296 .58092 L F
.755 .404 .39 r
.43626 .58065 m .43428 .57833 L .43587 .5784 L F
.43626 .58065 m .43167 .58047 L .43428 .57833 L F
.43626 .58065 m .43167 .58047 L .43428 .57833 L F
.006 .283 .782 r
.77282 .43674 m .77501 .43693 L .77237 .43505 L F
.77282 .43674 m .77457 .43825 L .77501 .43693 L F
.68 .701 .863 r
.74206 .39412 m .7395 .39647 L .7384 .39327 L F
.65 .646 .832 r
.74206 .39412 m .74355 .39765 L .7395 .39647 L F
0 0 0 r
.5052 .59344 m .50433 .59267 L .50228 .59277 L F
.5052 .59344 m .50461 .59522 L .50433 .59267 L F
.231 .749 .763 r
.22003 .6303 m .22195 .62982 L .22369 .62952 L F
.007 .582 .724 r
.22303 .62946 m .22369 .62952 L .22195 .62982 L F
.22303 .62946 m .22591 .62954 L .22369 .62952 L F
.835 .674 .683 r
.82291 .43561 m .82426 .43898 L .82507 .43608 L F
.275 .272 .674 r
.41488 .65392 m .41625 .6537 L .41592 .64984 L F
.28 .302 .705 r
.41488 .65392 m .41717 .65595 L .41625 .6537 L F
.496 0 0 r
.19969 .53907 m .20185 .53996 L .20382 .539 L F
.393 .826 .675 r
.20382 .539 m .20386 .53881 L .20675 .53785 L F
.20382 .539 m .20185 .53996 L .20386 .53881 L F
.318 0 0 r
.80099 .43527 m .80372 .43483 L .80436 .43344 L F
.103 0 0 r
.80372 .43483 m .80711 .43354 L .80436 .43344 L F
.62 .456 .638 r
.40745 .6028 m .41041 .60265 L .40924 .60015 L F
.277 .285 .688 r
.40924 .60015 m .41041 .60265 L .41142 .60151 L F
.313 0 .091 r
.4779 .60318 m .47565 .60383 L .47605 .60269 L F
.784 .799 .865 r
.54391 .58663 m .5427 .59051 L .541 .58765 L F
.54391 .58663 m .54532 .58784 L .5427 .59051 L F
.613 .817 .979 r
.2061 .55598 m .20783 .55722 L .20998 .55643 L F
.769 .692 .777 r
.17248 .61184 m .16859 .61355 L .17093 .61082 L F
.528 .797 .995 r
.17093 .61082 m .17481 .6114 L .17248 .61184 L F
.661 .597 .773 r
.8115 .4215 m .81304 .41723 L .8104 .41796 L F
.8115 .4215 m .81419 .4209 L .81304 .41723 L F
.683 .75 .902 r
.21516 .68612 m .2158 .68923 L .21901 .68672 L F
.908 .623 .493 r
.42052 .67711 m .42234 .67527 L .41965 .67292 L F
.42052 .67711 m .42237 .67765 L .42234 .67527 L F
.42234 .67527 m .42052 .67711 L .41965 .67292 L F
.42234 .67527 m .42237 .67765 L .42052 .67711 L F
.122 0 .183 r
.16085 .57795 m .15846 .5808 L .1593 .57874 L F
.635 .659 .857 r
.73468 .39247 m .73549 .39572 L .73329 .3964 L F
.423 .8 .992 r
.44942 .65396 m .44768 .6531 L .44561 .65354 L F
0 0 .141 r
.45022 .65026 m .45031 .65224 L .44942 .65396 L F
0 0 .245 r
.45031 .65224 m .44768 .6531 L .44942 .65396 L F
.76 .737 .832 r
.22483 .55158 m .22904 .55204 L .22713 .5504 L F
.711 .778 .905 r
.22713 .5504 m .22904 .55204 L .23113 .55081 L F
.434 .756 .995 r
.22904 .55204 m .23361 .55258 L .23113 .55081 L F
.305 0 .044 r
.16759 .55402 m .17 .55367 L .17188 .55125 L F
.167 0 0 r
.17188 .55125 m .17242 .5527 L .17384 .55012 L F
.17188 .55125 m .17 .55367 L .17242 .5527 L F
.38 .545 .893 r
.50786 .53268 m .51144 .53397 L .50953 .53168 L F
.555 .925 .776 r
.53302 .56596 m .53365 .56585 L .53203 .56698 L F
.294 .051 .365 r
.53365 .56585 m .53122 .56892 L .53203 .56698 L F
.555 .925 .776 r
.53203 .56698 m .53365 .56585 L .53302 .56596 L F
.88 .536 .04 r
.51698 .60496 m .51767 .6075 L .51843 .60831 L F
.51698 .60496 m .51767 .6075 L .51843 .60831 L F
.957 .726 .548 r
.51767 .6075 m .5193 .61055 L .51843 .60831 L F
.226 0 0 r
.4454 .57028 m .44355 .57001 L .44217 .57105 L F
.21 0 0 r
.18868 .77242 m .18892 .77382 L .18659 .77422 L F
.18868 .77242 m .19079 .772 L .18892 .77382 L F
.534 .477 .738 r
.18799 .76985 m .19079 .772 L .18868 .77242 L F
.786 .448 .416 r
.67665 .41663 m .6803 .41544 L .67645 .41438 L F
.67665 .41663 m .68037 .4174 L .6803 .41544 L F
.478 .204 .42 r
.54538 .50775 m .54815 .50515 L .54589 .50544 L F
.449 .203 .448 r
.4579 .63242 m .45759 .63511 L .45502 .63569 L F
0 0 .295 r
.45876 .63422 m .4579 .63242 L .46057 .63266 L F
.45876 .63422 m .45759 .63511 L .4579 .63242 L F
.613 .6 .814 r
.46045 .6304 m .46057 .63266 L .45932 .63255 L F
.46045 .6304 m .45932 .63255 L .45919 .6314 L F
.761 .715 .809 r
.46282 .62977 m .46057 .63266 L .46045 .6304 L F
.873 .942 .859 r
.45957 .63168 m .46282 .62977 L .45889 .62923 L F
0 0 .351 r
.45976 .63021 m .45957 .63168 L .45896 .62946 L F
.45893 .62928 m .45896 .62946 L .45889 .62923 L F
.45976 .63021 m .45896 .62946 L .45893 .62928 L F
.613 .6 .814 r
.45919 .6314 m .45932 .63255 L .4579 .63242 L F
0 0 .53 r
.5349 .56362 m .53616 .56526 L .537 .56684 L F
.701 .193 0 r
.53688 .5674 m .537 .56684 L .53616 .56526 L F
.53688 .5674 m .53909 .56947 L .537 .56684 L F
.469 .807 .999 r
.47675 .56307 m .47525 .56208 L .47286 .56254 L F
.47675 .56307 m .47525 .56208 L .47286 .56254 L F
.886 .907 .837 r
.47768 .55901 m .47675 .56307 L .48001 .56227 L F
.47768 .55901 m .47525 .56208 L .47675 .56307 L F
.614 .641 .853 r
.83055 .42294 m .83171 .41953 L .82937 .42021 L F
.83055 .42294 m .83321 .42114 L .83171 .41953 L F
.558 .309 .495 r
.47333 .59045 m .47579 .59248 L .47592 .5901 L F
.47333 .59045 m .47579 .59248 L .47592 .5901 L F
.41 .69 .977 r
.27352 .53784 m .27319 .53956 L .27175 .53781 L F
.27352 .53784 m .27536 .53951 L .27319 .53956 L F
.602 .346 .501 r
.40651 .60503 m .41041 .60265 L .40745 .6028 L F
.788 .589 .631 r
.57007 .51484 m .56636 .51439 L .56668 .51178 L F
.898 .698 .624 r
.57007 .51484 m .56716 .51681 L .56636 .51439 L F
.57007 .51484 m .56981 .51733 L .56716 .51681 L F
.981 .706 .322 r
.41899 .60853 m .41911 .61099 L .42002 .60857 L F
.914 .579 .109 r
.58483 .51392 m .58582 .51677 L .5861 .51684 L F
.943 .896 .751 r
.58285 .51959 m .5861 .51684 L .58582 .51677 L F
.58285 .51959 m .58397 .52072 L .5861 .51684 L F
.809 .603 .623 r
.57862 .50169 m .58226 .4996 L .57866 .49926 L F
.57862 .50169 m .58238 .50251 L .58226 .4996 L F
.822 .613 .62 r
.58238 .50251 m .58384 .50281 L .58226 .4996 L F
.528 .337 .566 r
.30083 .59336 m .30064 .59615 L .29819 .59591 L F
.499 .386 .656 r
.30063 .59842 m .29819 .59591 L .30064 .59615 L F
.30063 .59842 m .2985 .59917 L .29819 .59591 L F
.573 .109 0 r
.47635 .55738 m .47591 .55673 L .47394 .55738 L F
.47635 .55738 m .47768 .55901 L .47591 .55673 L F
.7 .668 .815 r
.84128 .41495 m .83799 .41395 L .8407 .41311 L F
.597 .925 .966 r
.84312 .41326 m .84128 .41495 L .8407 .41311 L F
.84312 .41326 m .84434 .41377 L .84128 .41495 L F
.842 .751 .234 r
.58297 .5651 m .58255 .56777 L .58274 .56921 L F
.89 .68 .163 r
.58176 .5668 m .58274 .56921 L .58255 .56777 L F
.58176 .5668 m .58284 .57209 L .58274 .56921 L F
.535 .077 .112 r
.56025 .51156 m .55896 .51326 L .55632 .51194 L F
.763 .45 .456 r
.56254 .51158 m .55896 .51326 L .56025 .51156 L F
0 .501 .769 r
.24317 .5372 m .24697 .53811 L .24502 .53776 L F
.559 .606 .856 r
.65447 .43941 m .65593 .43678 L .6531 .43563 L F
.65447 .43941 m .65705 .43894 L .65593 .43678 L F
.083 0 0 r
.16941 .57167 m .16602 .5749 L .16708 .57203 L F
0 0 0 r
.46373 .56236 m .46507 .56137 L .46698 .56089 L F
.554 .93 .819 r
.46698 .56089 m .468 .55972 L .4694 .55993 L F
.46698 .56089 m .46507 .56137 L .468 .55972 L F
.914 .58 .397 r
.43735 .58086 m .43626 .58065 L .43587 .5784 L F
.884 .798 .759 r
.41943 .65295 m .42335 .65088 L .41923 .65068 L F
.41943 .65295 m .42121 .65432 L .42335 .65088 L F
.636 .45 .615 r
.42335 .65088 m .42121 .65432 L .4236 .65352 L F
.542 .395 .631 r
.51477 .60513 m .51556 .60832 L .5119 .60871 L F
.179 .124 .554 r
.49127 .58444 m .49289 .58612 L .49287 .58353 L F
.49127 .58444 m .49112 .58752 L .49289 .58612 L F
.477 .458 .758 r
.26689 .55715 m .26786 .56084 L .27036 .56027 L F
.377 .34 .691 r
.26892 .56263 m .27036 .56027 L .26786 .56084 L F
.349 .328 .695 r
.41587 .65985 m .41756 .65942 L .41717 .65595 L F
.359 .369 .734 r
.41587 .65985 m .41862 .6619 L .41756 .65942 L F
.338 .765 .973 r
.19116 .78428 m .19342 .78411 L .19034 .78324 L F
.19342 .78411 m .19382 .78407 L .19331 .78395 L F
.19342 .78411 m .19331 .78395 L .19034 .78324 L F
.783 .834 .892 r
.19034 .78324 m .19382 .78407 L .19689 .78101 L F
.81 .98 .894 r
.19689 .78101 m .19272 .78313 L .19369 .78244 L F
.19272 .78313 m .19117 .78392 L .19266 .78304 L F
.19272 .78313 m .19266 .78304 L .19369 .78244 L F
.19689 .78101 m .19382 .78407 L .19117 .78392 L F
.783 .834 .892 r
.19034 .78324 m .19434 .78188 L .19369 .78244 L F
.19434 .78188 m .19689 .78101 L .19369 .78244 L F
.137 .682 .805 r
.19117 .78392 m .19284 .78402 L .19116 .78428 L F
.465 .868 .699 r
.1916 .78364 m .19369 .78244 L .19117 .78392 L F
.309 0 0 r
.1911 .78392 m .19369 .78244 L .19174 .7845 L F
.19034 .78324 m .19369 .78244 L .1916 .78364 L F
.19034 .78324 m .1916 .78364 L .19093 .78377 L F
.338 .765 .973 r
.19116 .78428 m .19034 .78324 L .19117 .78392 L F
.443 0 .051 r
.19117 .78392 m .19034 .78324 L .18943 .78481 L F
.309 0 0 r
.18992 .78397 m .19174 .7845 L .18943 .78481 L F
.683 .377 .451 r
.18829 .7833 m .19069 .78382 L .18748 .78243 L F
.19069 .78382 m .19117 .78392 L .19079 .78377 L F
.309 0 0 r
.19034 .78324 m .19086 .78371 L .18992 .78397 L F
.19086 .78371 m .19088 .78372 L .19083 .78373 L F
.19086 .78371 m .19083 .78373 L .18992 .78397 L F
.683 .377 .451 r
.19069 .78382 m .19079 .78377 L .18748 .78243 L F
.309 0 0 r
.19088 .78372 m .19069 .78382 L .18992 .78397 L F
.465 .868 .699 r
.1916 .78364 m .19093 .78377 L .18972 .78356 L F
.18899 .78337 m .18972 .78356 L .18829 .7833 L F
.443 0 .051 r
.19079 .78377 m .19073 .78381 L .18966 .78336 L F
.18915 .7831 m .18909 .78311 L .18748 .78243 L F
.19073 .78381 m .18823 .78318 L .18748 .78243 L F
0 .212 .732 r
.1883 .78325 m .18829 .7833 L .18748 .78243 L F
.443 0 .051 r
.18823 .78318 m .18806 .78314 L .18748 .78243 L F
0 .212 .732 r
.18856 .78202 m .1883 .78325 L .18748 .78243 L F
.648 .925 .974 r
.19021 .78078 m .18833 .78324 L .18856 .78202 L F
.18833 .78324 m .18829 .7833 L .1883 .78325 L F
.18833 .78324 m .1883 .78325 L .18856 .78202 L F
.443 0 .051 r
.1898 .78337 m .18966 .78336 L .18909 .78311 L F
.1898 .78337 m .18909 .78311 L .18915 .7831 L F
.19079 .78377 m .18966 .78336 L .1898 .78337 L F
.751 .934 .591 r
.1924 .78356 m .193 .78304 L .19337 .7824 L F
.19329 .78256 m .19402 .78135 L .19406 .78122 L F
.714 .821 .932 r
.19406 .78122 m .19336 .78249 L .19334 .78248 L F
.19406 .78122 m .19334 .78248 L .19021 .78078 L F
.751 .934 .591 r
.193 .78304 m .19329 .78256 L .19406 .78122 L F
.19363 .78182 m .19337 .7824 L .19406 .78122 L F
.557 .792 .987 r
.19021 .78078 m .19334 .78248 L .18855 .78326 L F
.19334 .78248 m .19333 .78249 L .18855 .78326 L F
.465 .868 .699 r
.19333 .78249 m .19325 .78255 L .19329 .7825 L F
.19325 .78255 m .1916 .78364 L .19329 .7825 L F
.19329 .7825 m .1916 .78364 L .18829 .7833 L F
.751 .934 .591 r
.1924 .78356 m .19337 .7824 L .19363 .78182 L F
.193 .78304 m .19369 .78244 L .19402 .78135 L F
.557 .792 .987 r
.19334 .78248 m .19336 .78249 L .19333 .78249 L F
.18833 .78324 m .18855 .78326 L .18829 .7833 L F
.19021 .78078 m .18855 .78326 L .18833 .78324 L F
.465 .868 .699 r
.1916 .78364 m .18972 .78356 L .18899 .78337 L F
.309 0 0 r
.19088 .78372 m .19093 .78377 L .19069 .78382 L F
.465 .868 .699 r
.19093 .78377 m .19069 .78382 L .18829 .7833 L F
.443 0 .051 r
.19073 .78381 m .18943 .78481 L .18806 .78314 L F
.465 .868 .699 r
.19073 .78381 m .19069 .78382 L .19069 .78382 L F
.443 0 .051 r
.19117 .78392 m .19073 .78381 L .19079 .78377 L F
.465 .868 .699 r
.19093 .78377 m .19073 .78381 L .19073 .78381 L F
.19073 .78381 m .19069 .78382 L .19073 .78381 L F
.443 0 .051 r
.19117 .78392 m .18943 .78481 L .19073 .78381 L F
.309 0 0 r
.19093 .78377 m .19174 .7845 L .18992 .78397 L F
.465 .868 .699 r
.19336 .78249 m .19331 .78252 L .19333 .78249 L F
.19331 .78252 m .1916 .78364 L .19333 .78249 L F
.1916 .78364 m .19117 .78392 L .19069 .78382 L F
.309 0 0 r
.19093 .78377 m .1916 .78364 L .1911 .78392 L F
.465 .868 .699 r
.19336 .78249 m .19369 .78244 L .1916 .78364 L F
.751 .934 .591 r
.19229 .78371 m .19369 .78244 L .1924 .78356 L F
.19174 .7845 m .19242 .78378 L .19229 .78371 L F
.19242 .78378 m .19369 .78244 L .19229 .78371 L F
.137 .682 .805 r
.19284 .78402 m .19382 .78407 L .19305 .78413 L F
.19284 .78402 m .19305 .78413 L .19116 .78428 L F
.541 .105 .161 r
.6618 .4197 m .65841 .41984 L .65939 .41845 L F
.487 .215 .427 r
.66198 .4177 m .6618 .4197 L .65939 .41845 L F
.23 0 .266 r
.24603 .64694 m .24878 .64203 L .2481 .64559 L F
.331 0 0 r
.24878 .64203 m .24929 .64341 L .2481 .64559 L F
.24878 .64203 m .25097 .64171 L .24929 .64341 L F
.379 0 .119 r
.23005 .64486 m .2322 .64645 L .2283 .64525 L F
.23005 .64486 m .23232 .64459 L .2322 .64645 L F
.333 .8 .928 r
.23005 .64486 m .23367 .64439 L .23232 .64459 L F
.422 0 .05 r
.23296 .67631 m .23666 .67509 L .23257 .6762 L F
.23296 .67631 m .23559 .67695 L .23666 .67509 L F
0 0 0 r
.23666 .67509 m .23659 .67513 L .23872 .6745 L F
.993 .781 .407 r
.23559 .67695 m .23646 .67768 L .23666 .67509 L F
.647 .804 .363 r
.23666 .67509 m .23559 .67695 L .23659 .67513 L F
.68 .466 .59 r
.22519 .69632 m .22548 .69882 L .22188 .69896 L F
.425 .556 .883 r
.2254 .69366 m .22519 .69632 L .22404 .69346 L F
.2254 .69366 m .22731 .69613 L .22519 .69632 L F
.581 .486 .712 r
.22731 .69613 m .22548 .69882 L .22519 .69632 L F
.877 .573 .469 r
.53687 .57728 m .54049 .58092 L .54061 .57835 L F
.825 .654 .67 r
.58367 .50798 m .58524 .51166 L .58746 .50875 L F
0 .342 .799 r
.79241 .39189 m .78978 .39059 L .78919 .38958 L F
.91 .982 .738 r
.7559 .38662 m .75847 .38414 L .75796 .38361 L F
.026 0 0 r
.76119 .38314 m .76162 .38198 L .75847 .38414 L F
.76119 .38314 m .75847 .38414 L .75796 .38361 L F
.726 .372 .379 r
.21808 .69363 m .22059 .69589 L .22165 .69392 L F
.187 0 0 r
.22059 .69589 m .22404 .69346 L .22165 .69392 L F
.77 .655 .735 r
.75317 .38713 m .75425 .39114 L .75069 .39054 L F
0 .323 .81 r
.76896 .43173 m .76966 .43326 L .77237 .43505 L F
.503 .159 .316 r
.44915 .6435 m .44677 .64175 L .44987 .64209 L F
.44915 .6435 m .44564 .64424 L .44677 .64175 L F
.816 .631 .651 r
.45822 .61315 m .4617 .6109 L .45788 .61021 L F
.005 0 .375 r
.42663 .64702 m .42752 .64427 L .42561 .64554 L F
.093 0 0 r
.76325 .3823 m .76162 .38198 L .76119 .38314 L F
.76325 .3823 m .76409 .38159 L .76162 .38198 L F
.36 .19 .511 r
.44626 .61049 m .44392 .61461 L .44309 .61147 L F
.124 .012 .443 r
.26802 .58739 m .26917 .58905 L .26977 .58665 L F
.26802 .58739 m .26795 .59 L .26917 .58905 L F
.816 .374 .189 r
.2418 .66321 m .24299 .66678 L .2407 .66244 L F
0 0 0 r
.24528 .65951 m .24313 .66225 L .2418 .66321 L F
0 0 .412 r
.24313 .66225 m .24299 .66678 L .2418 .66321 L F
.36 .19 .511 r
.44626 .61049 m .4465 .6148 L .44392 .61461 L F
.587 .156 .191 r
.44594 .61627 m .44392 .61461 L .4465 .6148 L F
.44594 .61627 m .44243 .61646 L .44392 .61461 L F
.505 .199 .38 r
.44878 .60868 m .44872 .61042 L .44626 .61049 L F
.55 .234 .386 r
.44878 .60868 m .45104 .61042 L .44872 .61042 L F
.557 .231 .371 r
.45066 .60808 m .45104 .61042 L .44878 .60868 L F
.427 .072 .258 r
.25567 .60804 m .25834 .60764 L .25925 .60554 L F
.349 0 .221 r
.25925 .60554 m .26043 .60706 L .26118 .6048 L F
.25925 .60554 m .25834 .60764 L .26043 .60706 L F
.492 0 0 r
.1888 .77064 m .18799 .76985 L .18668 .76882 L F
.167 0 0 r
.18892 .77382 m .19079 .772 L .19288 .77153 L F
.18949 .77277 m .19246 .77168 L .18986 .77209 L F
.028 0 .46 r
.18948 .77215 m .18986 .77209 L .18983 .77292 L F
.1888 .77064 m .18892 .77382 L .18986 .77209 L F
.1888 .77064 m .18986 .77209 L .18948 .77215 L F
.472 .311 .581 r
.19288 .77153 m .19079 .772 L .19339 .76907 L F
.167 0 0 r
.19246 .77168 m .19288 .77153 L .18986 .77209 L F
.18892 .77382 m .18951 .77348 L .18949 .77277 L F
.18951 .77348 m .19288 .77153 L .18949 .77277 L F
.028 0 .46 r
.1888 .77064 m .18948 .77215 L .18943 .77135 L F
.18948 .77215 m .18983 .77292 L .18947 .77149 L F
.18948 .77215 m .18947 .77149 L .18943 .77135 L F
.492 0 0 r
.1888 .77064 m .19079 .772 L .18832 .77011 L F
.813 .851 .877 r
.19339 .76907 m .19079 .772 L .1888 .77064 L F
.19339 .76907 m .1888 .77064 L .19136 .77169 L F
.332 .794 .938 r
.19288 .77153 m .19311 .77111 L .19136 .77169 L F
.19133 .77182 m .19136 .77169 L .19055 .77196 L F
.19288 .77153 m .19136 .77169 L .19133 .77182 L F
0 .437 .843 r
.19119 .77152 m .19137 .77164 L .1911 .77154 L F
.19137 .77164 m .19136 .77169 L .1888 .77064 L F
.813 .851 .877 r
.19339 .76907 m .19136 .77169 L .19168 .77158 L F
.97 .79 .604 r
.19571 .76738 m .19288 .77153 L .19339 .76907 L F
.024 0 0 r
.19334 .77069 m .19339 .76907 L .19168 .77158 L F
.332 .794 .938 r
.19311 .77111 m .19334 .77069 L .19168 .77158 L F
.024 0 0 r
.19334 .77069 m .19168 .77158 L .19155 .77177 L F
.332 .794 .938 r
.19168 .77158 m .19334 .77069 L .19104 .7718 L F
.813 .851 .877 r
.19168 .77158 m .19136 .77169 L .19155 .77177 L F
.621 .784 .96 r
.19334 .77069 m .19155 .77177 L .19137 .77164 L F
.19334 .77069 m .19137 .77164 L .1891 .77004 L F
.332 .794 .938 r
.19104 .7718 m .19334 .77069 L .19055 .77196 L F
.19055 .77196 m .19334 .77069 L .18986 .77209 L F
0 0 0 r
.18986 .77209 m .1914 .77147 L .19092 .7718 L F
.1914 .77147 m .19334 .77069 L .19188 .77136 L F
.1914 .77147 m .19188 .77136 L .19092 .7718 L F
0 .437 .843 r
.1891 .77004 m .19119 .77152 L .1888 .77064 L F
.19119 .77152 m .1911 .77154 L .1888 .77064 L F
.19137 .77164 m .19155 .77177 L .19136 .77169 L F
.028 0 .46 r
.1888 .77064 m .18943 .77135 L .1891 .77004 L F
.492 0 0 r
.1888 .77064 m .18832 .77011 L .18799 .76985 L F
.275 .085 .432 r
.2985 .59917 m .29814 .60194 L .29641 .60251 L F
.356 .294 .65 r
.29814 .60194 m .29854 .60455 L .29641 .60251 L F
.486 .303 .557 r
.29854 .60455 m .29631 .60512 L .29641 .60251 L F
.472 .434 .734 r
.45085 .60561 m .45363 .60776 L .45066 .60808 L F
.193 0 .374 r
.45338 .60841 m .4508 .6081 L .45363 .60776 L F
.4508 .6081 m .45066 .60808 L .45077 .60807 L F
.4508 .6081 m .45077 .60807 L .45363 .60776 L F
.45268 .60891 m .45066 .60808 L .45338 .60841 L F
.45268 .60891 m .45104 .61042 L .45066 .60808 L F
.735 .456 .506 r
.45265 .60913 m .45271 .60915 L .45267 .60903 L F
.193 0 .374 r
.45312 .6091 m .45262 .60941 L .45268 .60891 L F
.383 .259 .586 r
.45096 .60324 m .45252 .60138 L .45045 .60204 L F
.45096 .60324 m .45255 .60406 L .45252 .60138 L F
.32 .292 .671 r
.45255 .60406 m .45165 .60488 L .45096 .60324 L F
.45165 .60488 m .45085 .60561 L .45045 .60204 L F
.383 .259 .586 r
.45067 .60358 m .45255 .60406 L .45096 .60324 L F
.32 .292 .671 r
.45255 .60406 m .45096 .60324 L .45045 .60204 L F
.383 .259 .586 r
.45067 .60358 m .45096 .60324 L .45045 .60204 L F
.405 .431 .774 r
.45158 .60494 m .45363 .60776 L .45085 .60561 L F
.193 0 .374 r
.45267 .60903 m .45104 .61042 L .45268 .60891 L F
.45265 .60913 m .45141 .61018 L .45267 .60903 L F
.45262 .60941 m .45258 .60944 L .45265 .60913 L F
.45265 .60915 m .45141 .61018 L .45265 .60913 L F
.45262 .60925 m .45141 .61018 L .45265 .60915 L F
.45256 .60945 m .45244 .60953 L .45262 .60925 L F
.45244 .60953 m .45141 .61018 L .45262 .60925 L F
0 0 .091 r
.45149 .61098 m .45104 .61042 L .45162 .60953 L F
.193 0 .374 r
.45141 .61018 m .45104 .61042 L .45267 .60903 L F
.473 .261 .51 r
.44942 .61317 m .44872 .61042 L .45104 .61042 L F
.734 .526 .611 r
.45265 .60915 m .45271 .60915 L .45265 .60913 L F
.45265 .60915 m .45265 .60913 L .44594 .60691 L F
.735 .456 .506 r
.45246 .60907 m .45265 .60913 L .45264 .60894 L F
.734 .526 .611 r
.45265 .60915 m .45262 .60925 L .45271 .60915 L F
.44585 .6095 m .45262 .60925 L .45265 .60915 L F
.44585 .6095 m .45148 .60921 L .44594 .60691 L F
.45148 .60921 m .45265 .60915 L .45151 .60877 L F
.45148 .60921 m .45151 .60877 L .44594 .60691 L F
.591 .866 .994 r
.45162 .60953 m .45104 .61042 L .45244 .60953 L F
.45242 .60946 m .45244 .60953 L .45256 .60945 L F
.45162 .60953 m .45235 .60953 L .45234 .60947 L F
.734 .526 .611 r
.45164 .60928 m .45162 .60953 L .45262 .60925 L F
.45162 .60953 m .45155 .61039 L .45242 .60946 L F
.45162 .60953 m .45242 .60946 L .45262 .60925 L F
.591 .866 .994 r
.45162 .60953 m .45234 .60946 L .45211 .60939 L F
.735 .456 .506 r
.45168 .60881 m .45246 .60907 L .4517 .60673 L F
.405 .431 .774 r
.45255 .60406 m .45333 .60672 L .45158 .60494 L F
.45333 .60672 m .45363 .60776 L .45158 .60494 L F
.844 .634 .618 r
.45267 .60903 m .45255 .60406 L .45067 .60358 L F
.45271 .60915 m .45271 .60899 L .45267 .60903 L F
.45271 .60899 m .45255 .60406 L .45267 .60903 L F
.735 .456 .506 r
.45265 .60913 m .45267 .60903 L .45264 .60894 L F
.45246 .60907 m .45264 .60894 L .45067 .60358 L F
.844 .634 .618 r
.45271 .60915 m .45233 .60941 L .45255 .60406 L F
.891 .989 .785 r
.45271 .60915 m .4522 .60865 L .45233 .60941 L F
.4527 .60913 m .45241 .60944 L .4522 .60865 L F
.591 .866 .994 r
.45234 .60946 m .45259 .60943 L .45233 .60941 L F
.45234 .60946 m .45233 .60941 L .45211 .60939 L F
.844 .634 .618 r
.45233 .60941 m .45209 .60958 L .4521 .60938 L F
.45233 .60941 m .4521 .60938 L .45255 .60406 L F
.591 .866 .994 r
.4522 .60865 m .45162 .60953 L .45238 .60931 L F
.715 .406 .453 r
.45462 .60767 m .45312 .6091 L .45363 .60776 L F
.45618 .60753 m .45434 .60847 L .45462 .60767 L F
.45434 .60847 m .45312 .6091 L .45462 .60767 L F
.747 .297 .182 r
.45593 .60962 m .45472 .61071 L .4542 .61016 L F
.45593 .60962 m .45451 .61006 L .4541 .60914 L F
.45451 .61006 m .45398 .61023 L .45391 .60971 L F
.45398 .61023 m .45383 .60991 L .45391 .60971 L F
.45472 .61071 m .45435 .61104 L .4542 .61016 L F
.527 .049 .063 r
.45764 .61079 m .45435 .61104 L .45593 .60962 L F
.431 .009 .136 r
.45859 .60936 m .45764 .61079 L .45593 .60962 L F
.62 .449 .629 r
.45435 .61104 m .45748 .61038 L .4537 .60962 L F
.45435 .61104 m .4537 .60962 L .45358 .6096 L F
.891 .989 .785 r
.45271 .60915 m .45262 .60925 L .4527 .60913 L F
.591 .866 .994 r
.45258 .60883 m .45238 .60931 L .45312 .6091 L F
0 0 .362 r
.45243 .60889 m .45215 .60933 L .45243 .6089 L F
.45255 .60406 m .45213 .60901 L .45243 .60889 L F
.756 .283 .121 r
.45279 .60905 m .45435 .61104 L .45358 .6096 L F
0 0 .362 r
.4521 .60941 m .45264 .60864 L .45262 .60859 L F
.756 .283 .121 r
.4522 .60865 m .45293 .60947 L .45279 .60905 L F
.45293 .60947 m .45435 .61104 L .45279 .60905 L F
0 0 .362 r
.4521 .60941 m .45226 .60928 L .45238 .60901 L F
.45215 .60933 m .4521 .60941 L .45215 .60933 L F
.45215 .60933 m .45215 .60933 L .45243 .6089 L F
.45213 .60901 m .4521 .60941 L .45243 .60889 L F
.891 .989 .785 r
.45262 .60925 m .45242 .60946 L .4527 .60913 L F
.45242 .60946 m .45241 .60944 L .4527 .60913 L F
.193 0 .374 r
.45258 .60944 m .45256 .60945 L .45265 .60915 L F
.591 .866 .994 r
.45211 .60939 m .45259 .60943 L .45312 .6091 L F
0 0 .362 r
.4521 .60941 m .45215 .60946 L .45226 .60928 L F
.591 .866 .994 r
.45162 .60953 m .45256 .60945 L .45259 .60943 L F
0 0 .362 r
.4521 .60941 m .45209 .60958 L .45215 .60946 L F
.891 .989 .785 r
.45229 .60917 m .4522 .60865 L .45209 .60958 L F
.734 .526 .611 r
.44585 .6095 m .45155 .61039 L .45164 .60928 L F
.891 .989 .785 r
.45233 .60913 m .45162 .61019 L .4522 .60865 L F
.45199 .60991 m .45135 .6106 L .45233 .60913 L F
0 0 .091 r
.45165 .61117 m .45166 .61008 L .4522 .60865 L F
.45166 .61008 m .45167 .60945 L .4522 .60865 L F
.891 .989 .785 r
.45162 .61019 m .45135 .6106 L .4522 .60865 L F
.45233 .60941 m .45229 .60917 L .45209 .60958 L F
.45241 .60944 m .45199 .60991 L .45233 .60913 L F
0 0 .362 r
.45238 .60901 m .45226 .60928 L .45264 .60864 L F
.45262 .60859 m .45264 .60864 L .45322 .60766 L F
.45317 .60741 m .45243 .6089 L .45322 .60766 L F
.45255 .60406 m .45245 .60794 L .45317 .60741 L F
.45245 .60794 m .45243 .6089 L .45263 .6085 L F
.45245 .60794 m .45263 .6085 L .45317 .60741 L F
.513 .335 .576 r
.45358 .6096 m .45364 .60956 L .45357 .60952 L F
.45358 .6096 m .4537 .60962 L .45364 .60956 L F
.747 .297 .182 r
.4541 .60914 m .45369 .61031 L .45293 .60947 L F
.578 .523 .756 r
.4522 .60865 m .45322 .60766 L .4524 .60904 L F
.591 .866 .994 r
.4522 .60865 m .4524 .60904 L .45258 .60883 L F
.218 .68 .946 r
.45258 .60883 m .45272 .60878 L .4522 .60865 L F
.747 .297 .182 r
.45272 .60878 m .45293 .60947 L .4522 .60865 L F
.715 .406 .453 r
.45618 .60753 m .45593 .60962 L .45312 .6091 L F
.218 .68 .946 r
.45312 .6091 m .45593 .60962 L .45272 .60878 L F
.193 0 .374 r
.45312 .6091 m .45268 .60891 L .45338 .60841 L F
.218 .68 .946 r
.45312 .6091 m .45272 .60878 L .45258 .60883 L F
.578 .523 .756 r
.4522 .60865 m .45358 .6096 L .45357 .60952 L F
.747 .297 .182 r
.4541 .60914 m .45332 .60936 L .45272 .60878 L F
.45332 .60936 m .45279 .60903 L .45272 .60878 L F
.578 .523 .756 r
.4522 .60865 m .45357 .60952 L .45322 .60766 L F
.747 .297 .182 r
.45332 .60936 m .45293 .60947 L .45279 .60903 L F
.591 .866 .994 r
.4522 .60865 m .45233 .60913 L .4524 .60904 L F
.578 .523 .756 r
.4522 .60865 m .4524 .60904 L .45209 .60958 L F
.591 .866 .994 r
.45233 .60913 m .45238 .60931 L .45258 .60883 L F
.747 .297 .182 r
.45398 .61023 m .45369 .61031 L .45383 .60991 L F
.45451 .61006 m .45391 .60971 L .4541 .60914 L F
.632 .577 .774 r
.45578 .60485 m .45363 .60776 L .45255 .60406 L F
.611 .548 .759 r
.45578 .60485 m .45618 .60753 L .45363 .60776 L F
.676 .594 .756 r
.45901 .60646 m .45618 .60753 L .45578 .60485 L F
.54 .259 .438 r
.45901 .60646 m .45593 .60962 L .45618 .60753 L F
.513 .335 .576 r
.45357 .60952 m .45867 .60677 L .45322 .60766 L F
.45364 .60956 m .45867 .60677 L .45357 .60952 L F
.54 .259 .438 r
.45901 .60646 m .45859 .60936 L .45593 .60962 L F
.513 .335 .576 r
.45364 .60956 m .45748 .61038 L .45867 .60677 L F
.4537 .60962 m .45748 .61038 L .45364 .60956 L F
.747 .297 .182 r
.4542 .61016 m .45435 .61104 L .45369 .61031 L F
.591 .866 .994 r
.45234 .60947 m .45244 .60953 L .45242 .60946 L F
.45235 .60953 m .45244 .60953 L .45234 .60947 L F
.891 .989 .785 r
.45242 .60946 m .45135 .6106 L .45241 .60944 L F
0 0 .091 r
.45165 .61117 m .45149 .61098 L .45167 .60945 L F
.45197 .61157 m .45165 .61117 L .4522 .60865 L F
.106 0 .242 r
.4514 .61049 m .45197 .61157 L .4522 .60865 L F
.45135 .6106 m .45139 .61066 L .4514 .61049 L F
.45139 .61066 m .45197 .61157 L .4514 .61049 L F
0 0 .091 r
.45175 .6113 m .44942 .61317 L .45104 .61042 L F
.45197 .61157 m .45086 .61227 L .45175 .6113 L F
.45086 .61227 m .44942 .61317 L .45175 .6113 L F
.519 .309 .534 r
.44852 .61346 m .44626 .61049 L .44872 .61042 L F
.44852 .61346 m .4465 .6148 L .44626 .61049 L F
.473 .261 .51 r
.44942 .61317 m .44852 .61346 L .44872 .61042 L F
.516 .342 .584 r
.44852 .61346 m .44594 .61627 L .4465 .6148 L F
.44852 .61346 m .44895 .61728 L .44594 .61627 L F
.846 .582 .539 r
.45057 .61709 m .44852 .61346 L .44942 .61317 L F
.45057 .61709 m .44895 .61728 L .44876 .6156 L F
.45021 .61645 m .44876 .6156 L .44852 .61346 L F
.45057 .61709 m .44876 .6156 L .45021 .61645 L F
.138 .214 .68 r
.45025 .61355 m .45033 .61627 L .44942 .61317 L F
.45227 .61447 m .45033 .61627 L .45026 .61379 L F
.45227 .61447 m .45084 .61318 L .45197 .61157 L F
.45084 .61318 m .45025 .61265 L .45097 .6122 L F
.45084 .61318 m .45097 .6122 L .45197 .61157 L F
.494 .374 .645 r
.45076 .61378 m .45088 .614 L .45084 .61318 L F
.196 .145 .57 r
.45084 .61318 m .45088 .614 L .45227 .61447 L F
.138 .214 .68 r
.45084 .61318 m .44942 .61317 L .45025 .61265 L F
.45227 .61447 m .45076 .61378 L .45084 .61318 L F
.45076 .61378 m .44942 .61317 L .45084 .61318 L F
.494 .374 .645 r
.448 .61551 m .45072 .61408 L .45023 .61287 L F
.138 .214 .68 r
.45227 .61447 m .45026 .61379 L .45025 .61355 L F
.494 .374 .645 r
.45072 .61408 m .45088 .614 L .45076 .61378 L F
.45072 .61408 m .45076 .61378 L .45023 .61287 L F
.45023 .61287 m .45076 .61378 L .45078 .61222 L F
.45076 .61378 m .45084 .61318 L .45078 .61222 L F
.196 .145 .57 r
.45078 .61222 m .45084 .61318 L .45227 .61447 L F
.45088 .614 m .45099 .61589 L .45227 .61447 L F
.494 .374 .645 r
.448 .61551 m .45099 .61589 L .45088 .614 L F
.138 .214 .68 r
.45154 .61514 m .45057 .61709 L .45033 .61627 L F
.45227 .61447 m .45168 .61538 L .45154 .61514 L F
.45168 .61538 m .45057 .61709 L .45154 .61514 L F
.494 .374 .645 r
.44768 .61497 m .45023 .61271 L .44589 .61191 L F
.45023 .61271 m .45078 .61222 L .45022 .61218 L F
.45023 .61271 m .45022 .61218 L .44589 .61191 L F
.44795 .61541 m .44812 .61522 L .44768 .61497 L F
.44812 .61522 m .45078 .61222 L .44768 .61497 L F
.448 .61551 m .44954 .61369 L .44795 .61541 L F
.44954 .61369 m .45078 .61222 L .44795 .61541 L F
.734 .526 .611 r
.4479 .60982 m .45135 .6106 L .45155 .61039 L F
.44585 .6095 m .44758 .60984 L .4479 .60982 L F
.44758 .60984 m .45135 .6106 L .4479 .60982 L F
0 0 .091 r
.45149 .61098 m .45162 .60953 L .45167 .60945 L F
.735 .456 .506 r
.44594 .60691 m .45168 .60881 L .45089 .60425 L F
.45168 .60881 m .4517 .60673 L .45089 .60425 L F
.45041 .60376 m .45089 .60425 L .45067 .60358 L F
.44594 .60691 m .45089 .60425 L .45041 .60376 L F
.465 .237 .483 r
.28388 .61754 m .28363 .61997 L .28141 .62037 L F
.527 .328 .554 r
.28611 .61702 m .28363 .61997 L .28388 .61754 L F
.236 0 .071 r
.16489 .61075 m .163 .61114 L .16279 .61033 L F
.16489 .61075 m .16467 .61094 L .163 .61114 L F
.804 .701 .751 r
.44633 .63028 m .44621 .63057 L .44676 .6292 L F
.346 .256 .61 r
.44621 .63057 m .44716 .63499 L .44935 .63384 L F
0 .553 .81 r
.4965 .56914 m .49876 .56948 L .49986 .56985 L F
0 .315 .782 r
.49876 .56948 m .50128 .57162 L .49986 .56985 L F
.617 .22 .268 r
.56113 .58734 m .55995 .58935 L .55749 .58741 L F
.986 .749 .493 r
.56113 .58734 m .56171 .59159 L .55995 .58935 L F
0 0 .189 r
.58083 .58337 m .58052 .58568 L .57937 .58728 L F
0 0 0 r
.58052 .58568 m .57914 .58952 L .57937 .58728 L F
.464 .323 .604 r
.55 .58383 m .54796 .587 L .54756 .58437 L F
0 0 0 r
.54391 .58663 m .54756 .58437 L .54796 .587 L F
.515 .031 .045 r
.54624 .58523 m .55 .58383 L .54756 .58437 L F
0 0 0 r
.54391 .58663 m .54624 .58523 L .54756 .58437 L F
.807 .808 .851 r
.55048 .58602 m .55081 .58856 L .54888 .59042 L F
.806 .326 .068 r
.54888 .59042 m .54532 .58784 L .54796 .587 L F
.54888 .59042 m .54826 .59055 L .54532 .58784 L F
.963 .815 .649 r
.41153 .62616 m .4123 .629 L .41177 .62676 L F
.546 .247 .411 r
.4786 .61446 m .48055 .61643 L .48178 .61496 L F
.4786 .61446 m .47825 .61673 L .48055 .61643 L F
.957 .621 .236 r
.5525 .60937 m .5529 .6089 L .55532 .60889 L F
.5525 .60937 m .55174 .6093 L .5529 .6089 L F
.294 0 0 r
.5529 .6089 m .55174 .6093 L .54903 .60883 L F
.404 .066 .276 r
.55137 .50237 m .55383 .5018 L .55415 .50018 L F
.616 .333 .465 r
.55383 .5018 m .55763 .49925 L .55415 .50018 L F
.518 .23 .417 r
.48425 .59636 m .48369 .59893 L .48098 .59925 L F
.598 .44 .638 r
.48674 .59342 m .48665 .59601 L .48425 .59636 L F
.374 .103 .369 r
.48601 .59816 m .48425 .59636 L .48665 .59601 L F
.48601 .59816 m .48369 .59893 L .48425 .59636 L F
.517 .676 .937 r
.82156 .40248 m .8205 .40496 L .81895 .40279 L F
.82156 .40248 m .82296 .40457 L .8205 .40496 L F
.822 .595 .596 r
.58238 .50251 m .58377 .50537 L .58384 .50281 L F
.244 .026 .371 r
.46657 .60253 m .46818 .60387 L .4686 .60192 L F
.46657 .60253 m .46622 .60504 L .46818 .60387 L F
.529 .281 .484 r
.4871 .61119 m .48988 .60867 L .48637 .60823 L F
.4871 .61119 m .48962 .61097 L .48988 .60867 L F
0 0 0 r
.4871 .61119 m .48988 .60867 L .48962 .61097 L F
.569 .316 .493 r
.48988 .60867 m .49265 .61055 L .4916 .60818 L F
.48988 .60867 m .48962 .61097 L .49265 .61055 L F
.653 .21 .187 r
.48988 .60867 m .49265 .61055 L .48962 .61097 L F
.454 .606 .911 r
.18036 .63775 m .18123 .63954 L .18222 .63746 L F
.18123 .63954 m .18384 .64026 L .18222 .63746 L F
.449 .144 .355 r
.47494 .60729 m .47301 .60503 L .47565 .60383 L F
.47494 .60729 m .47245 .60787 L .47301 .60503 L F
.971 .762 .332 r
.7718 .40464 m .77237 .4078 L .77243 .40591 L F
.748 .683 .788 r
.69069 .4305 m .69152 .42607 L .68899 .42904 L F
.69069 .4305 m .69323 .42743 L .69152 .42607 L F
.981 .712 .443 r
.48074 .58125 m .47919 .58023 L .47941 .57793 L F
.312 .355 .746 r
.48144 .57701 m .48074 .58125 L .47941 .57793 L F
.48144 .57701 m .48242 .58079 L .48074 .58125 L F
.357 .643 .963 r
.48151 .57962 m .48074 .58125 L .47919 .58023 L F
.48151 .57962 m .48242 .58079 L .48074 .58125 L F
.295 .29 .684 r
.48242 .58079 m .48304 .58339 L .48074 .58125 L F
.46 0 0 r
.20675 .53785 m .20822 .53868 L .21007 .53923 L F
.514 .851 .996 r
.20822 .53868 m .2123 .53877 L .21007 .53923 L F
.351 .404 .777 r
.24571 .65283 m .24535 .65689 L .24344 .65434 L F
.24571 .65283 m .24672 .65625 L .24535 .65689 L F
.424 .319 .631 r
.24672 .65625 m .24528 .65951 L .24535 .65689 L F
.253 0 .111 r
.1524 .56345 m .15136 .56506 L .15449 .56278 L F
.052 0 .071 r
.15277 .58678 m .15134 .58754 L .15384 .58484 L F
.007 0 .044 r
.15468 .58557 m .15384 .58484 L .1561 .58414 L F
.15468 .58557 m .15277 .58678 L .15384 .58484 L F
.799 .716 .773 r
.23821 .64405 m .2422 .64436 L .24062 .64352 L F
.076 .386 .847 r
.2422 .64436 m .24285 .64319 L .24062 .64352 L F
.2422 .64436 m .24603 .64694 L .24285 .64319 L F
0 0 .545 r
.77816 .44412 m .77872 .4451 L .77705 .4421 L F
.311 .475 .861 r
.77705 .4421 m .77872 .4451 L .78015 .44338 L F
.12 .208 .682 r
.77872 .4451 m .78116 .44547 L .78015 .44338 L F
.77872 .4451 m .78079 .44746 L .78116 .44547 L F
.22 0 0 r
.29853 .54764 m .30379 .54687 L .29934 .54828 L F
.29853 .54764 m .30138 .54767 L .30379 .54687 L F
.636 .865 .498 r
.30379 .54687 m .30368 .54672 L .30536 .54473 L F
.33 .804 .73 r
.30379 .54687 m .30138 .54767 L .30368 .54672 L F
.532 .563 .833 r
.30595 .54807 m .30379 .54687 L .30536 .54473 L F
.522 0 0 r
.51538 .59761 m .51523 .59718 L .51404 .59551 L F
.51538 .59761 m .51691 .59852 L .51523 .59718 L F
.275 .421 .828 r
.7736 .42845 m .77214 .43014 L .77063 .42711 L F
.356 .544 .901 r
.7736 .42845 m .77582 .43106 L .77214 .43014 L F
0 0 0 r
.53677 .52034 m .53538 .52216 L .53372 .52353 L F
.181 0 0 r
.53801 .52096 m .53677 .52034 L .53906 .52001 L F
.554 .439 .676 r
.72135 .39971 m .72382 .39894 L .7235 .39632 L F
.501 .286 .519 r
.28363 .61997 m .28094 .62305 L .28141 .62037 L F
.309 0 .118 r
.50662 .60038 m .50604 .60176 L .50347 .60239 L F
.338 .183 .519 r
.30644 .55052 m .30639 .55356 L .30435 .55358 L F
.716 .526 .633 r
.308 .55683 m .30435 .55358 L .30639 .55356 L F
.308 .55683 m .30526 .55761 L .30435 .55358 L F
.457 .811 .997 r
.21498 .72042 m .21099 .72001 L .21268 .71962 L F
.755 .929 .575 r
.21345 .72243 m .21498 .72042 L .21323 .72229 L F
.542 .508 .767 r
.21607 .71592 m .21498 .72042 L .21268 .71962 L F
.21607 .71592 m .21724 .72006 L .21498 .72042 L F
.184 .717 .789 r
.21498 .72042 m .21528 .72015 L .21323 .72229 L F
.21498 .72042 m .21724 .72006 L .21528 .72015 L F
.388 .555 .898 r
.66359 .43624 m .66467 .43708 L .66629 .43563 L F
.582 .941 .913 r
.66629 .43563 m .66467 .43708 L .66707 .43586 L F
.497 .7 .96 r
.17935 .61329 m .17481 .6114 L .17698 .61091 L F
.03 .322 .807 r
.17862 .61066 m .17935 .61329 L .17698 .61091 L F
.17862 .61066 m .18067 .61374 L .17935 .61329 L F
.279 .098 .448 r
.2339 .68621 m .23279 .6838 L .23404 .68329 L F
.2339 .68621 m .2323 .6871 L .23279 .6838 L F
.583 .382 .574 r
.20532 .71748 m .2071 .71995 L .20484 .72008 L F
.458 .227 .475 r
.28069 .62549 m .27876 .6235 L .28094 .62305 L F
.28069 .62549 m .27848 .62604 L .27876 .6235 L F
0 0 .272 r
.65596 .41532 m .65728 .41389 L .65754 .41123 L F
0 0 .043 r
.65596 .41532 m .65662 .41553 L .65728 .41389 L F
.65596 .41532 m .65515 .41823 L .65662 .41553 L F
.026 .287 .782 r
.23823 .65871 m .2407 .66244 L .24101 .66116 L F
0 0 .52 r
.2407 .66244 m .24299 .66678 L .24101 .66116 L F
.984 .902 .641 r
.58338 .55838 m .58416 .56035 L .58496 .55678 L F
.983 .77 .54 r
.58216 .56156 m .58416 .56035 L .58338 .55838 L F
.58216 .56156 m .5837 .56279 L .58416 .56035 L F
.576 .335 .513 r
.50085 .5892 m .49745 .58656 L .49918 .58605 L F
.50085 .5892 m .49761 .58972 L .49745 .58656 L F
0 0 0 r
.53215 .51729 m .53418 .51624 L .53553 .51491 L F
.53553 .51491 m .53643 .51527 L .53751 .51369 L F
.53553 .51491 m .53418 .51624 L .53643 .51527 L F
.3 .772 .658 r
.5579 .60769 m .56168 .60602 L .56024 .60595 L F
.5579 .60769 m .55727 .60798 L .56168 .60602 L F
.546 .316 .518 r
.56168 .60602 m .56425 .60564 L .56486 .60697 L F
.39 .243 .559 r
.56486 .60697 m .56425 .60564 L .56606 .60419 L F
.533 .153 .266 r
.56606 .60419 m .56323 .60572 L .56486 .60697 L F
0 0 0 r
.5677 .60321 m .56426 .60572 L .56606 .60419 L F
.136 .539 .921 r
.56297 .60641 m .56486 .60697 L .56365 .60604 L F
0 0 0 r
.56426 .60572 m .56291 .60671 L .56391 .60591 L F
.56426 .60572 m .56391 .60591 L .56606 .60419 L F
.136 .539 .921 r
.56168 .60602 m .56297 .60641 L .56323 .60572 L F
.56297 .60641 m .56365 .60604 L .56323 .60572 L F
.594 .396 .583 r
.27057 .57132 m .27297 .57244 L .27323 .56927 L F
.27057 .57132 m .27297 .57244 L .27323 .56927 L F
.377 .34 .691 r
.26892 .56263 m .27068 .56275 L .27036 .56027 L F
.033 .161 .666 r
.4236 .65352 m .42457 .65717 L .42571 .65541 L F
.937 .728 .595 r
.42705 .65801 m .42571 .65541 L .42457 .65717 L F
.263 0 .272 r
.46417 .60586 m .46355 .60782 L .46622 .60504 L F
0 .152 .643 r
.51436 .55975 m .51388 .55904 L .51201 .55762 L F
.905 .51 .25 r
.51638 .56185 m .51388 .55904 L .51436 .55975 L F
.734 .541 .632 r
.43991 .58308 m .43626 .58065 L .43735 .58086 L F
0 0 .095 r
.84217 .42084 m .8416 .42234 L .8405 .42444 L F
0 0 0 r
.8405 .42444 m .8416 .42234 L .84108 .42409 L F
.388 .555 .898 r
.66359 .43624 m .66629 .43563 L .6609 .43528 L F
.686 .482 .604 r
.44122 .63761 m .44554 .63849 L .44523 .63579 L F
.323 .22 .58 r
.44523 .63579 m .44703 .63753 L .44716 .63499 L F
.44523 .63579 m .44554 .63849 L .44703 .63753 L F
.464 .566 .873 r
.17437 .63495 m .17452 .63165 L .17289 .63196 L F
.17437 .63495 m .17638 .63485 L .17452 .63165 L F
.246 .248 .664 r
.77155 .41627 m .77177 .41973 L .7698 .4179 L F
0 0 .517 r
.77192 .42475 m .77002 .42397 L .77132 .42224 L F
.77192 .42475 m .77063 .42711 L .77002 .42397 L F
0 0 .382 r
.55732 .5832 m .55749 .58741 L .55812 .58569 L F
.514 0 0 r
.55749 .58741 m .5592 .58876 L .55795 .58801 L F
.5592 .58876 m .55995 .58935 L .55795 .58801 L F
.883 .855 .81 r
.55795 .58801 m .55503 .58791 L .5559 .58678 L F
.514 0 0 r
.55749 .58741 m .55795 .58801 L .55812 .58569 L F
0 .163 .658 r
.55812 .58569 m .55483 .58279 L .55732 .5832 L F
.55812 .58569 m .55742 .5848 L .55483 .58279 L F
.883 .855 .81 r
.55795 .58801 m .5559 .58678 L .55742 .5848 L F
.618 .534 .738 r
.43014 .6089 m .43037 .61117 L .43279 .61053 L F
.451 .298 .581 r
.43063 .61464 m .43279 .61053 L .43037 .61117 L F
0 0 .138 r
.53909 .56947 m .53931 .57062 L .53959 .57293 L F
0 0 .236 r
.53959 .57293 m .53931 .57062 L .53991 .57343 L F
.155 0 0 r
.24697 .53811 m .24913 .53815 L .25098 .53779 L F
.25098 .53779 m .24913 .53815 L .25313 .53781 L F
.578 .406 .612 r
.29631 .60512 m .2939 .60814 L .29384 .60551 L F
.478 .634 .922 r
.284 .54006 m .28308 .54219 L .28173 .54018 L F
.454 .606 .911 r
.284 .54006 m .2853 .54216 L .28308 .54219 L F
.118 .669 .792 r
.21613 .53811 m .21442 .53805 L .2184 .53795 L F
.782 .589 .639 r
.50255 .5411 m .5054 .54197 L .50587 .53883 L F
.514 .776 .991 r
.19413 .75915 m .192 .7596 L .19027 .75834 L F
.19027 .75834 m .192 .7596 L .19413 .75915 L F
.258 0 .206 r
.55035 .51411 m .54753 .51671 L .54819 .51499 L F
.931 .798 .691 r
.5575 .59029 m .55869 .59283 L .55835 .59164 L F
.63 .685 .883 r
.55971 .58984 m .55869 .59283 L .5575 .59029 L F
.02 0 0 r
.2281 .62882 m .23033 .62832 L .23258 .6272 L F
.431 .848 .686 r
.23258 .6272 m .23033 .62832 L .23246 .62702 L F
.344 0 0 r
.50311 .55069 m .50103 .55082 L .49877 .55046 L F
.637 .075 0 r
.50311 .55069 m .50358 .55199 L .50103 .55082 L F
.50311 .55069 m .5057 .55285 L .50358 .55199 L F
.594 .556 .781 r
.44554 .63849 m .446 .64194 L .45131 .64043 L F
.815 .761 .803 r
.45131 .64043 m .45055 .64186 L .45026 .6407 L F
.594 .556 .781 r
.44554 .63849 m .45131 .64043 L .44703 .63753 L F
.815 .761 .803 r
.45131 .64043 m .44933 .63687 L .44703 .63753 L F
.45131 .64043 m .45026 .6407 L .44933 .63687 L F
.723 .672 .123 r
.44596 .64182 m .44593 .64175 L .45131 .64043 L F
.315 .803 .78 r
.45131 .64043 m .45054 .64056 L .45055 .64186 L F
.723 .672 .123 r
.45001 .6408 m .45026 .6407 L .45131 .64043 L F
0 .072 .624 r
.45026 .6407 m .45055 .64186 L .45072 .64053 L F
.723 .672 .123 r
.446 .64194 m .44596 .64182 L .45026 .6407 L F
.446 .64194 m .45026 .6407 L .45001 .6408 L F
0 .072 .624 r
.44933 .63687 m .45026 .6407 L .45054 .63985 L F
.315 .803 .78 r
.45131 .64043 m .44629 .64166 L .44854 .64092 L F
.44629 .64166 m .44593 .64175 L .44854 .64092 L F
.45054 .64056 m .44854 .64092 L .45055 .64186 L F
0 .072 .624 r
.45026 .6407 m .45072 .64053 L .45098 .63847 L F
.07 0 .075 r
.45285 .64077 m .45051 .64183 L .45411 .63823 L F
0 .072 .624 r
.45053 .63803 m .45054 .63985 L .45098 .63847 L F
.44933 .63687 m .45054 .63985 L .45053 .63803 L F
.828 .991 .864 r
.45055 .64186 m .44854 .64092 L .45098 .63847 L F
.554 .384 .606 r
.44854 .64092 m .45177 .64137 L .45139 .63997 L F
.44854 .64092 m .45139 .63997 L .45098 .63847 L F
.005 0 .375 r
.42663 .64702 m .42743 .64712 L .42752 .64427 L F
0 0 .483 r
.42663 .64702 m .42774 .64969 L .42743 .64712 L F
.607 .543 .757 r
.8104 .41796 m .81245 .41386 L .81029 .41674 L F
.8104 .41796 m .81304 .41723 L .81245 .41386 L F
.571 .896 .639 r
.43943 .57237 m .43695 .57433 L .43886 .57346 L F
.287 .081 .416 r
.43943 .57237 m .44201 .5737 L .44217 .57105 L F
.43943 .57237 m .43886 .57346 L .44201 .5737 L F
.633 .82 .972 r
.41817 .64175 m .41483 .64145 L .41746 .64046 L F
0 .334 .814 r
.41746 .64046 m .41815 .6404 L .41817 .64175 L F
0 0 .316 r
.41929 .64289 m .41817 .64175 L .41815 .6404 L F
.41929 .64289 m .41811 .64433 L .41817 .64175 L F
.68 .652 .815 r
.50049 .59199 m .50362 .59074 L .50228 .59277 L F
.239 .692 .953 r
.50228 .59277 m .50433 .59267 L .50049 .59199 L F
.66 .49 .643 r
.27041 .63201 m .26688 .63476 L .26818 .63259 L F
.279 .284 .686 r
.41605 .62982 m .41777 .62882 L .41685 .62554 L F
.732 .549 .645 r
.41485 .63086 m .41605 .62982 L .41553 .63218 L F
.413 .307 .624 r
.41777 .62882 m .41553 .63218 L .41605 .62982 L F
.732 .549 .645 r
.41485 .63086 m .41777 .62882 L .41605 .62982 L F
.991 .744 .38 r
.49164 .57522 m .49149 .5777 L .49047 .57656 L F
.551 .213 .348 r
.17384 .55012 m .17625 .5502 L .17681 .54811 L F
.349 .032 .279 r
.17681 .54811 m .17838 .54954 L .18017 .54748 L F
.17681 .54811 m .17625 .5502 L .17838 .54954 L F
.158 0 .161 r
.17735 .56832 m .17463 .57078 L .17546 .56885 L F
.329 .797 .926 r
.23453 .53697 m .23045 .53698 L .23298 .53651 L F
.215 0 0 r
.23298 .53651 m .23693 .53704 L .23453 .53697 L F
.68 .652 .815 r
.50049 .59199 m .50085 .5892 L .50362 .59074 L F
.88 .987 .818 r
.21808 .69363 m .21618 .69621 L .21639 .69478 L F
.497 .291 .53 r
.72925 .39308 m .72585 .39118 L .72495 .39207 L F
.72925 .39308 m .72834 .39017 L .72585 .39118 L F
.947 .83 .695 r
.56823 .55907 m .56791 .55574 L .56891 .55678 L F
.434 .592 .909 r
.22169 .68967 m .22205 .69037 L .22285 .68954 L F
.285 .356 .761 r
.22205 .69037 m .22404 .69346 L .22285 .68954 L F
.81 .824 .861 r
.56171 .59159 m .55971 .58984 L .55995 .58935 L F
.631 .461 .634 r
.15134 .58754 m .15347 .59214 L .14843 .59128 L F
0 0 .546 r
.15265 .58948 m .15134 .58754 L .15277 .58678 L F
.15265 .58948 m .15347 .59214 L .15134 .58754 L F
.081 .637 .799 r
.23693 .53704 m .23906 .53703 L .24098 .53726 L F
.173 0 0 r
.23906 .53703 m .24317 .5372 L .24098 .53726 L F
0 .275 .779 r
.19009 .61957 m .1899 .62072 L .18917 .61898 L F
.123 .489 .902 r
.19009 .61957 m .19207 .62151 L .1899 .62072 L F
.241 .756 .781 r
.45884 .61947 m .45732 .6199 L .46044 .61801 L F
0 0 0 r
.46079 .61785 m .46044 .61801 L .4625 .617 L F
.46079 .61785 m .45884 .61947 L .46044 .61801 L F
.783 .831 .364 r
.76744 .39842 m .76734 .3982 L .76815 .39673 L F
.182 0 .254 r
.48176 .57214 m .48087 .57463 L .47929 .5752 L F
.363 .247 .585 r
.48144 .57701 m .47929 .5752 L .48087 .57463 L F
.48144 .57701 m .47941 .57793 L .47929 .5752 L F
.182 0 .254 r
.47929 .5752 m .48087 .57463 L .48176 .57214 L F
.363 .247 .585 r
.47929 .5752 m .48144 .57701 L .48087 .57463 L F
.47929 .5752 m .47941 .57793 L .48144 .57701 L F
0 0 .288 r
.27444 .56537 m .27323 .56927 L .27203 .56546 L F
.27444 .56537 m .27405 .56847 L .27323 .56927 L F
.644 .439 .591 r
.27323 .56927 m .27599 .57168 L .27622 .56913 L F
.27323 .56927 m .27297 .57244 L .27599 .57168 L F
0 0 .203 r
.27387 .5705 m .27323 .56927 L .27405 .56847 L F
.27387 .5705 m .27297 .57244 L .27323 .56927 L F
.571 .434 .655 r
.21075 .68709 m .21232 .68847 L .21381 .68747 L F
.05 0 .216 r
.8443 .41751 m .8446 .4193 L .84217 .42084 L F
.06 0 .234 r
.84217 .42084 m .84396 .42131 L .8416 .42234 L F
.84217 .42084 m .8446 .4193 L .84396 .42131 L F
.781 .718 .793 r
.51957 .53227 m .52077 .53539 L .52302 .53263 L F
.04 .247 .746 r
.52109 .53323 m .52077 .53539 L .51957 .53227 L F
.873 .991 .737 r
.52109 .53323 m .51996 .53518 L .52077 .53539 L F
.888 .635 .55 r
.5717 .52078 m .56962 .52197 L .56853 .5198 L F
.5717 .52078 m .57167 .52339 L .56962 .52197 L F
.618 .637 .847 r
.8353 .40527 m .83375 .40935 L .83262 .40606 L F
.8353 .40527 m .83651 .40848 L .83375 .40935 L F
.718 .474 .555 r
.51581 .53437 m .51957 .53227 L .51724 .53301 L F
.409 .451 .793 r
.50745 .60667 m .51043 .60899 L .50927 .60414 L F
.437 .232 .503 r
.48302 .56315 m .4828 .56568 L .48523 .56246 L F
.972 .723 .501 r
.48302 .56315 m .4828 .56568 L .48131 .56224 L F
.437 .232 .503 r
.48302 .56315 m .4828 .56568 L .48523 .56246 L F
.59 .362 .539 r
.45759 .63511 m .45411 .63823 L .45502 .63569 L F
.629 .119 .015 r
.66329 .40999 m .66713 .41057 L .66598 .40959 L F
.711 .47 .559 r
.47112 .62021 m .4733 .62344 L .47124 .62005 L F
.534 .302 .509 r
.47124 .62005 m .47503 .62093 L .47575 .61722 L F
.433 .371 .688 r
.47124 .62005 m .47497 .62247 L .47503 .62093 L F
.47124 .62005 m .4733 .62344 L .47497 .62247 L F
.561 .725 .951 r
.66163 .41469 m .66422 .41431 L .66275 .41277 L F
.487 .802 1 r
.66163 .41469 m .66422 .41431 L .66053 .41375 L F
.66163 .41469 m .66422 .41431 L .66053 .41375 L F
.589 .451 .662 r
.66422 .41431 m .66198 .4177 L .66163 .41469 L F
.98 .724 .47 r
.42842 .68035 m .42994 .68103 L .42855 .67757 L F
.067 .252 .744 r
.42855 .67757 m .42994 .68103 L .43083 .67969 L F
.529 .866 .993 r
.42842 .68035 m .42994 .68103 L .43083 .67969 L F
.222 .564 .937 r
.80636 .40002 m .80334 .39817 L .80547 .39857 L F
.356 .66 .971 r
.80792 .3988 m .80636 .40002 L .80547 .39857 L F
.80792 .3988 m .80897 .40024 L .80636 .40002 L F
.774 .413 .373 r
.45544 .62691 m .45889 .62923 L .45896 .6266 L F
.714 .597 .724 r
.45889 .62923 m .46323 .6267 L .45896 .6266 L F
.483 .865 .977 r
.22069 .64601 m .22394 .64615 L .22168 .646 L F
.391 .836 .937 r
.22394 .64615 m .22302 .64556 L .22168 .646 L F
.22394 .64615 m .22616 .64574 L .22302 .64556 L F
.204 .391 .826 r
.50969 .59755 m .51181 .59846 L .51175 .59599 L F
.603 .371 .538 r
.51175 .59599 m .50912 .59833 L .50969 .59755 L F
.163 .697 .706 r
.77945 .39339 m .78129 .39299 L .77955 .39339 L F
.788 .514 .521 r
.48504 .5745 m .4822 .57246 L .48419 .57172 L F
.4822 .57246 m .48176 .57214 L .48419 .57172 L F
.48504 .5745 m .48087 .57463 L .48176 .57214 L F
.593 .291 .427 r
.48304 .5733 m .48545 .57126 L .48419 .57172 L F
.48545 .57126 m .48632 .57052 L .48419 .57172 L F
.208 0 .267 r
.48176 .57214 m .48304 .5733 L .48419 .57172 L F
.48176 .57214 m .48087 .57463 L .48304 .5733 L F
.816 .631 .651 r
.45822 .61315 m .46171 .61657 L .4617 .6109 L F
0 0 .21 r
.4617 .6109 m .46355 .60782 L .45901 .60646 L F
.4617 .6109 m .46297 .61146 L .46355 .60782 L F
.094 0 0 r
.46091 .56355 m .46349 .56285 L .46373 .56236 L F
0 0 0 r
.46373 .56236 m .46349 .56285 L .46507 .56137 L F
.26 0 0 r
.43822 .57489 m .43886 .57346 L .43695 .57433 L F
.206 0 0 r
.44201 .5737 m .43886 .57346 L .43822 .57489 L F
.745 .228 0 r
.55048 .58602 m .55448 .58901 L .55081 .58856 L F
.812 .806 .845 r
.20669 .72812 m .2039 .72944 L .20619 .72843 L F
.507 0 0 r
.20619 .72843 m .21021 .72952 L .20669 .72812 L F
.518 .382 .635 r
.16554 .60412 m .16489 .61075 L .16279 .61033 L F
.642 .382 .51 r
.22072 .70504 m .21825 .70539 L .21722 .70521 L F
.504 .27 .493 r
.26056 .59897 m .26289 .59864 L .26338 .59638 L F
.444 .398 .712 r
.26056 .59897 m .26319 .60164 L .26289 .59864 L F
.26056 .59897 m .26136 .60235 L .26319 .60164 L F
.635 .579 .775 r
.48963 .59231 m .48674 .59342 L .48562 .59113 L F
.27 .034 .36 r
.48963 .59231 m .48665 .59601 L .48674 .59342 L F
.024 0 0 r
.14964 .56611 m .14673 .56858 L .1486 .56747 L F
.277 0 .253 r
.1486 .56747 m .15136 .56506 L .14964 .56611 L F
.523 .664 .926 r
.80017 .40528 m .80209 .40803 L .80461 .40752 L F
.27 0 .136 r
.18657 .56244 m .18508 .5651 L .18298 .56572 L F
.277 0 .13 r
.1897 .56048 m .18849 .56208 L .18657 .56244 L F
.357 .001 .215 r
.18849 .56208 m .18508 .5651 L .18657 .56244 L F
.847 .992 .845 r
.81578 .4482 m .81716 .44852 L .81829 .44636 L F
.618 .602 .813 r
.15495 .62064 m .15912 .62372 L .15736 .6224 L F
.641 .806 .962 r
.15736 .6224 m .15912 .62372 L .16152 .6226 L F
.51 .321 .56 r
.27622 .56913 m .27875 .56861 L .27878 .56598 L F
.489 .268 .506 r
.27622 .56913 m .27841 .57105 L .27875 .56861 L F
.27622 .56913 m .27599 .57168 L .27841 .57105 L F
.803 .602 .631 r
.56668 .51178 m .56274 .51372 L .56254 .51158 L F
.56668 .51178 m .56636 .51439 L .56274 .51372 L F
.411 .594 .919 r
.15157 .61832 m .152 .61614 L .15102 .61731 L F
.15157 .61832 m .15282 .6175 L .152 .61614 L F
.241 .756 .781 r
.45884 .61947 m .45607 .62005 L .45732 .6199 L F
.141 .678 .844 r
.48703 .56587 m .48477 .56568 L .4828 .56568 L F
.559 0 0 r
.48703 .56587 m .48515 .5675 L .48477 .56568 L F
.48703 .56587 m .48752 .56707 L .48515 .5675 L F
.48703 .56587 m .48956 .56749 L .48752 .56707 L F
.523 .379 .627 r
.26289 .59864 m .26524 .59529 L .26338 .59638 L F
.184 0 .168 r
.19135 .55922 m .18849 .56208 L .1897 .56048 L F
.4 .474 .821 r
.51351 .54017 m .51287 .54206 L .51099 .53775 L F
.691 .383 .45 r
.51351 .54017 m .51285 .54119 L .51469 .54257 L F
0 0 .506 r
.51176 .53934 m .51287 .54206 L .51232 .54029 L F
.51109 .53798 m .51287 .54206 L .51155 .53883 L F
.469 .681 .958 r
.51269 .54143 m .51287 .54206 L .51233 .542 L F
.51269 .54143 m .51233 .542 L .5098 .54171 L F
0 0 .506 r
.51232 .54029 m .51287 .54206 L .51243 .54049 L F
.469 .681 .958 r
.51243 .54049 m .51269 .54143 L .5098 .54171 L F
.691 .383 .45 r
.51285 .54119 m .51191 .54265 L .51368 .5426 L F
.51285 .54119 m .51368 .5426 L .51469 .54257 L F
0 0 .506 r
.51155 .53883 m .51176 .53934 L .51232 .54029 L F
.51099 .53775 m .51109 .53798 L .51155 .53883 L F
0 0 0 r
.5098 .54171 m .50834 .54262 L .51243 .54049 L F
.342 .157 .479 r
.50737 .54221 m .51243 .54049 L .50834 .54262 L F
.50737 .54221 m .50993 .53928 L .51243 .54049 L F
.762 .474 .497 r
.50828 .54184 m .51191 .54265 L .51285 .54119 L F
.51247 .5405 m .51285 .54119 L .51351 .54017 L F
.50828 .54184 m .51285 .54119 L .51247 .5405 L F
.571 .139 .181 r
.25242 .64353 m .25097 .64171 L .25384 .64156 L F
.1 0 .063 r
.25384 .64156 m .25479 .64258 L .25242 .64353 L F
.25384 .64156 m .2558 .64095 L .25479 .64258 L F
.318 .617 .956 r
.41966 .67086 m .42016 .67258 L .41867 .67185 L F
.953 .687 .494 r
.41961 .66815 m .41966 .67086 L .41784 .66999 L F
.522 .827 1 r
.41936 .67006 m .41966 .67086 L .41784 .66999 L F
.881 .681 .159 r
.41966 .67086 m .4201 .67206 L .41961 .66815 L F
.602 .127 .099 r
.41784 .66999 m .41936 .67006 L .41966 .67086 L F
.881 .681 .159 r
.41966 .67086 m .41987 .67021 L .41961 .66815 L F
.602 .127 .099 r
.41936 .67006 m .42133 .67014 L .41966 .67086 L F
.881 .681 .159 r
.41966 .67086 m .42016 .67258 L .4201 .67206 L F
.41966 .67086 m .4201 .67206 L .41987 .67021 L F
.916 .878 .452 r
.41965 .67292 m .41966 .67086 L .41867 .67185 L F
.939 .788 .667 r
.41966 .67086 m .41881 .67365 L .41784 .66999 L F
.893 .866 .423 r
.41922 .67135 m .41881 .67365 L .41898 .67162 L F
.41966 .67086 m .4193 .67205 L .41922 .67135 L F
.4193 .67205 m .41881 .67365 L .41922 .67135 L F
.522 .827 1 r
.42133 .67014 m .41966 .67086 L .41936 .67006 L F
.035 .211 .715 r
.41961 .66815 m .41782 .66366 L .41921 .66595 L F
.41782 .66366 m .41747 .66277 L .41776 .66329 L F
.41782 .66366 m .41776 .66329 L .41921 .66595 L F
.182 .189 .63 r
.42054 .66452 m .41961 .66815 L .42204 .66566 L F
.42021 .66426 m .42014 .66466 L .42054 .66452 L F
.42014 .66466 m .41961 .66815 L .42054 .66452 L F
.42021 .66426 m .42147 .66936 L .41961 .66815 L F
.035 .211 .715 r
.41961 .66815 m .42147 .66936 L .41847 .66442 L F
.41782 .66366 m .41795 .6638 L .41747 .66277 L F
.883 .655 .587 r
.41747 .66277 m .41795 .6638 L .41862 .6619 L F
.035 .211 .715 r
.41795 .6638 m .41847 .66442 L .41747 .66277 L F
.883 .655 .587 r
.41747 .66277 m .41755 .6649 L .41795 .6638 L F
.035 .211 .715 r
.41961 .66815 m .41847 .66442 L .41782 .66366 L F
.626 .364 .501 r
.41788 .66398 m .41812 .66401 L .41795 .6638 L F
.704 .512 .626 r
.41847 .66442 m .41889 .66511 L .41755 .6649 L F
.626 .364 .501 r
.41755 .6649 m .41803 .66479 L .41801 .66466 L F
.41755 .6649 m .41801 .66466 L .41788 .66398 L F
.704 .512 .626 r
.41747 .66277 m .41847 .66442 L .41755 .6649 L F
.41889 .66511 m .42147 .66936 L .41802 .66543 L F
.41889 .66511 m .41802 .66543 L .41755 .6649 L F
.626 .364 .501 r
.41795 .6638 m .42021 .66426 L .41862 .6619 L F
.41812 .66401 m .42021 .66426 L .41795 .6638 L F
.41803 .66479 m .42021 .66426 L .41788 .66398 L F
.68 .511 .65 r
.41755 .6649 m .42147 .66936 L .42021 .66426 L F
.522 .827 1 r
.42133 .67014 m .41784 .66999 L .42057 .66783 L F
.916 .878 .452 r
.41965 .67292 m .41881 .67365 L .41966 .67086 L F
.602 .127 .099 r
.41784 .66999 m .42035 .67142 L .42133 .67014 L F
.015 .361 .833 r
.41901 .6695 m .42035 .67142 L .41901 .66949 L F
.41784 .66999 m .41915 .67074 L .41901 .6695 L F
.41915 .67074 m .42035 .67142 L .41901 .6695 L F
.675 .144 0 r
.41898 .67162 m .41935 .6718 L .41966 .67086 L F
.881 .681 .159 r
.41966 .67086 m .42016 .67258 L .4201 .67206 L F
.399 .808 .6 r
.42048 .67233 m .42016 .67258 L .41966 .67086 L F
.675 .144 0 r
.41935 .6718 m .42048 .67233 L .41966 .67086 L F
.399 .808 .6 r
.42048 .67233 m .41965 .67292 L .42016 .67258 L F
.847 .901 .875 r
.75506 .40415 m .75389 .40539 L .75656 .4052 L F
.849 .898 .871 r
.75389 .40539 m .75496 .40662 L .75656 .4052 L F
.792 .9 .918 r
.75869 .40144 m .75656 .4052 L .75945 .40239 L F
.75869 .40144 m .75506 .40415 L .75656 .4052 L F
.925 .858 .757 r
.57099 .54526 m .56985 .54792 L .56839 .54701 L F
.942 .749 .613 r
.56985 .54792 m .56727 .5497 L .56839 .54701 L F
.56985 .54792 m .56898 .55065 L .56727 .5497 L F
.925 .858 .757 r
.57099 .54526 m .56839 .54701 L .56933 .54412 L F
.852 .694 .686 r
.49114 .59005 m .4887 .5915 L .49073 .5897 L F
.362 .167 .477 r
.42752 .64427 m .43043 .64104 L .42768 .64206 L F
.727 .766 .884 r
.7473 .40674 m .74824 .40851 L .75099 .40765 L F
.653 .611 .795 r
.81029 .41674 m .81149 .41178 L .80892 .41227 L F
.81029 .41674 m .81245 .41386 L .81149 .41178 L F
.599 .722 .93 r
.54636 .60898 m .54646 .60772 L .54288 .60807 L F
.187 .332 .779 r
.54636 .60898 m .54766 .60775 L .54646 .60772 L F
.379 .655 .965 r
.54636 .60898 m .54903 .60883 L .54766 .60775 L F
.322 .37 .757 r
.40526 .62785 m .4066 .62532 L .40407 .62605 L F
.40526 .62785 m .40784 .62915 L .4066 .62532 L F
.449 0 0 r
.73421 .38975 m .73471 .3881 L .7368 .38872 L F
.099 0 .426 r
.73471 .3881 m .73719 .38279 L .73702 .38684 L F
.442 .246 .517 r
.7368 .38872 m .73471 .3881 L .73702 .38684 L F
.97 .79 .604 r
.19571 .76738 m .1971 .76874 L .19616 .77018 L F
.251 .606 .954 r
.19738 .76752 m .1971 .76874 L .19571 .76738 L F
.766 .894 .491 r
.19616 .77018 m .1971 .76874 L .19738 .76752 L F
.348 0 .058 r
.48504 .5745 m .48144 .57701 L .48087 .57463 L F
.48504 .5745 m .48405 .57656 L .48144 .57701 L F
.794 .696 .756 r
.15552 .5934 m .15608 .59666 L .15872 .59316 L F
.15552 .5934 m .15872 .59316 L .15656 .59491 L F
.934 .563 .177 r
.15731 .59155 m .15683 .59198 L .15872 .59316 L F
.986 .867 .634 r
.15683 .59198 m .15656 .59491 L .15872 .59316 L F
.449 .179 .412 r
.46747 .62354 m .46862 .62517 L .47112 .62021 L F
.711 .47 .559 r
.47112 .62021 m .46862 .62517 L .4733 .62344 L F
.509 .34 .587 r
.30263 .59172 m .30064 .59615 L .30083 .59336 L F
.034 0 0 r
.24171 .62247 m .24352 .62079 L .24002 .62279 L F
.01 0 0 r
.24549 .62002 m .24352 .62079 L .24171 .62247 L F
.618 .534 .738 r
.43014 .6089 m .43279 .61053 L .4326 .60812 L F
.503 .888 .963 r
.21352 .64694 m .21705 .64653 L .21474 .64627 L F
.504 .74 .979 r
.21705 .64653 m .21772 .64501 L .21474 .64627 L F
.21705 .64653 m .22069 .64601 L .21772 .64501 L F
.226 .713 .928 r
.17783 .63774 m .17829 .6345 L .17638 .63485 L F
.17783 .63774 m .17816 .63709 L .17829 .6345 L F
.17783 .63774 m .18036 .63775 L .17816 .63709 L F
.751 .287 .147 r
.68037 .4174 m .68431 .4198 L .68403 .41816 L F
.638 .418 .567 r
.43886 .60795 m .44214 .60803 L .44148 .6052 L F
.529 .425 .68 r
.44148 .6052 m .44387 .60515 L .44354 .602 L F
.254 .175 .57 r
.44148 .6052 m .44351 .60707 L .44387 .60515 L F
.44148 .6052 m .44214 .60803 L .44351 .60707 L F
.941 .641 .442 r
.58297 .55245 m .58452 .55092 L .58288 .55001 L F
.58297 .55245 m .58493 .55369 L .58452 .55092 L F
.925 .7 .579 r
.82262 .43827 m .82426 .43898 L .82291 .43561 L F
.614 .857 .496 r
.82262 .43827 m .82092 .44047 L .82426 .43898 L F
.361 0 .16 r
.80711 .43354 m .80967 .43299 L .8101 .43154 L F
.509 .383 .644 r
.8101 .43154 m .81311 .4313 L .81303 .42898 L F
.463 .104 .269 r
.80967 .43299 m .81311 .4313 L .8101 .43154 L F
.274 0 0 r
.15347 .59214 m .14937 .59216 L .14843 .59128 L F
.747 .78 .88 r
.17093 .61082 m .16859 .61355 L .16703 .61046 L F
.394 .451 .801 r
.78127 .43424 m .77904 .43632 L .77805 .43276 L F
.514 .658 .925 r
.78127 .43424 m .78202 .43615 L .77904 .43632 L F
.847 .796 .801 r
.7431 .38453 m .74064 .38756 L .7379 .38593 L F
.675 .519 .667 r
.7431 .38453 m .74422 .38484 L .74064 .38756 L F
.66 .547 .716 r
.74544 .38141 m .74623 .38374 L .7431 .38453 L F
.64 .505 .682 r
.74623 .38374 m .74422 .38484 L .7431 .38453 L F
.703 .849 .425 r
.75499 .40308 m .75389 .40539 L .75501 .40305 L F
.731 .787 .898 r
.75099 .40765 m .75308 .40711 L .75389 .40539 L F
.693 .828 .948 r
.7499 .4053 m .75099 .40765 L .75137 .40736 L F
.7499 .4053 m .75137 .40736 L .75389 .40539 L F
.7499 .4053 m .75389 .40539 L .7529 .40666 L F
0 .344 .816 r
.74889 .40389 m .7499 .4053 L .7529 .40666 L F
.74868 .40375 m .7499 .4053 L .74889 .40389 L F
.703 .849 .425 r
.7529 .40666 m .75389 .40539 L .75499 .40308 L F
.731 .787 .898 r
.75308 .40711 m .75496 .40662 L .75389 .40539 L F
.13 0 0 r
.2184 .53795 m .22061 .5382 L .22222 .53825 L F
.16 .7 .746 r
.22061 .5382 m .22448 .53761 L .22222 .53825 L F
.169 .657 .922 r
.25313 .53781 m .2553 .53796 L .25701 .5387 L F
.267 .743 .936 r
.2553 .53796 m .25925 .53832 L .25701 .5387 L F
.413 .555 .888 r
.76569 .43092 m .76749 .42901 L .76488 .42909 L F
.76569 .43092 m .76896 .43173 L .76749 .42901 L F
.695 .154 0 r
.52114 .56617 m .52044 .5668 L .51826 .5648 L F
.844 .383 .008 r
.52114 .56617 m .52228 .56826 L .52044 .5668 L F
.882 .954 .848 r
.77036 .40857 m .77047 .41036 L .77135 .40969 L F
.909 .946 .816 r
.77036 .40857 m .77135 .40969 L .77237 .4078 L F
.984 .902 .641 r
.58338 .55838 m .58496 .55678 L .58411 .55593 L F
.096 0 .173 r
.19568 .74846 m .19295 .75139 L .19482 .75047 L F
.433 .527 .854 r
.19295 .75139 m .19571 .75379 L .19482 .75047 L F
.653 .733 .908 r
.65705 .43894 m .66117 .44017 L .65964 .43813 L F
.701 .763 .9 r
.65964 .43813 m .66117 .44017 L .66338 .43875 L F
0 0 .162 r
.8446 .41463 m .8446 .4193 L .8443 .41751 L F
.324 .026 .295 r
.14074 .5744 m .14351 .57173 L .14141 .5721 L F
.859 .808 .799 r
.2248 .57097 m .22657 .57237 L .22907 .56894 L F
.976 .717 .474 r
.22744 .56542 m .22718 .56807 L .22907 .56894 L F
0 0 0 r
.45086 .5763 m .44951 .57708 L .44812 .57765 L F
.528 .12 .211 r
.55632 .51194 m .55896 .51326 L .55637 .51323 L F
.876 .466 .237 r
.80964 .44633 m .81104 .44783 L .80978 .44733 L F
0 .527 .783 r
.81104 .44783 m .8126 .44789 L .80978 .44733 L F
.81104 .44783 m .81338 .44824 L .8126 .44789 L F
.414 .247 .544 r
.4916 .60818 m .49388 .60934 L .49498 .60764 L F
.4916 .60818 m .49265 .61055 L .49388 .60934 L F
.571 .573 .816 r
.8407 .41311 m .83799 .41395 L .83754 .41207 L F
.859 .905 .865 r
.42204 .66566 m .42374 .66644 L .42421 .66407 L F
.642 .173 .124 r
.2701 .55866 m .26689 .55715 L .268 .5575 L F
.477 .458 .758 r
.26689 .55715 m .27036 .56027 L .26838 .55794 L F
.26689 .55715 m .26838 .55794 L .268 .5575 L F
.372 .513 .87 r
.268 .5575 m .27163 .5581 L .2701 .55866 L F
.421 .449 .784 r
.268 .5575 m .26838 .55794 L .27163 .5581 L F
.26888 .55852 m .26921 .55892 L .26975 .55866 L F
.26921 .55892 m .27036 .56027 L .26978 .55873 L F
.26921 .55892 m .26978 .55873 L .26975 .55866 L F
.259 0 0 r
.2701 .55866 m .2699 .55869 L .26975 .55866 L F
.2699 .55869 m .26779 .55894 L .26975 .55866 L F
.288 0 0 r
.27163 .5581 m .2699 .55869 L .2701 .55866 L F
.642 .173 .124 r
.2701 .55866 m .26975 .55866 L .26689 .55715 L F
.421 .449 .784 r
.26838 .55794 m .27093 .55929 L .27163 .5581 L F
.642 .173 .124 r
.26975 .55866 m .26838 .55794 L .26689 .55715 L F
.421 .449 .784 r
.26838 .55794 m .26888 .55852 L .26975 .55866 L F
.642 .173 .124 r
.26975 .55866 m .26527 .55866 L .26689 .55715 L F
.288 0 0 r
.27163 .5581 m .26779 .55894 L .2699 .55869 L F
.259 0 0 r
.26975 .55866 m .26779 .55894 L .26527 .55866 L F
.421 .449 .784 r
.26975 .55866 m .27036 .56027 L .27093 .55929 L F
.642 .173 .124 r
.26975 .55866 m .26975 .55866 L .26838 .55794 L F
.771 .759 .842 r
.66814 .43016 m .66448 .42993 L .66697 .42891 L F
.871 .888 .844 r
.6708 .42697 m .66814 .43016 L .66697 .42891 L F
.686 .56 .707 r
.67052 .42897 m .66814 .43016 L .6708 .42697 L F
.324 .153 .489 r
.26136 .60235 m .26293 .60407 L .26319 .60164 L F
.26136 .60235 m .26118 .6048 L .26293 .60407 L F
.503 .29 .524 r
.53365 .56585 m .5349 .56362 L .53364 .56195 L F
.53365 .56585 m .53616 .56526 L .5349 .56362 L F
.73 .637 .755 r
.81304 .41723 m .81419 .4209 L .81664 .41804 L F
.682 .562 .714 r
.81419 .4209 m .8156 .42119 L .81664 .41804 L F
.514 .374 .628 r
.81419 .4209 m .8164 .42391 L .8156 .42119 L F
.81419 .4209 m .81438 .4237 L .8164 .42391 L F
.399 0 0 r
.20177 .72997 m .20146 .72912 L .20004 .73146 L F
.20177 .72997 m .2039 .72944 L .20146 .72912 L F
.569 .305 .476 r
.43279 .61053 m .43622 .60803 L .4326 .60812 L F
.43279 .61053 m .43541 .61052 L .43622 .60803 L F
.559 .295 .472 r
.43622 .60803 m .43866 .61007 L .43886 .60795 L F
.43622 .60803 m .43541 .61052 L .43866 .61007 L F
.402 .582 .913 r
.18639 .6163 m .18917 .61898 L .18583 .61853 L F
0 .266 .77 r
.18899 .6179 m .18917 .61898 L .18639 .6163 L F
.466 0 0 r
.18263 .61577 m .18639 .6163 L .1842 .61694 L F
.402 .582 .913 r
.18639 .6163 m .18618 .61714 L .18534 .61661 L F
.466 0 0 r
.18263 .61577 m .18732 .61674 L .18639 .6163 L F
.275 .414 .821 r
.1876 .6148 m .18899 .6179 L .18639 .6163 L F
.195 .296 .741 r
.18639 .6163 m .18732 .61674 L .1876 .6148 L F
.246 .639 .961 r
.18322 .61442 m .18732 .61674 L .18468 .61619 L F
.18293 .61509 m .18468 .61619 L .18263 .61577 L F
.18322 .61442 m .18468 .61619 L .18293 .61509 L F
.402 .582 .913 r
.18534 .61661 m .18583 .61853 L .1842 .61694 L F
.18618 .61714 m .18583 .61853 L .18534 .61661 L F
.596 .429 .626 r
.40182 .61395 m .40472 .6112 L .40224 .61174 L F
0 .146 .676 r
.40917 .63257 m .41047 .63602 L .41091 .63471 L F
.482 0 0 r
.41047 .63602 m .41149 .63696 L .41091 .63471 L F
.298 .378 .776 r
.41221 .63705 m .41296 .63792 L .41047 .63602 L F
.372 .013 .22 r
.15552 .5934 m .15282 .59433 L .15066 .59245 L F
.15552 .5934 m .15484 .59407 L .15282 .59433 L F
.264 0 .162 r
.14351 .57173 m .14549 .57113 L .14673 .56858 L F
.279 0 .17 r
.14673 .56858 m .14757 .57047 L .1486 .56747 L F
.14673 .56858 m .14549 .57113 L .14757 .57047 L F
.911 .966 .802 r
.75573 .41446 m .75294 .41632 L .75447 .41312 L F
.75573 .41446 m .75335 .41771 L .75294 .41632 L F
.828 .882 .882 r
.7585 .4116 m .75573 .41446 L .75447 .41312 L F
.526 .303 .519 r
.24882 .61696 m .25126 .61652 L .25143 .61426 L F
.491 .321 .578 r
.25143 .61426 m .25362 .61379 L .25345 .61114 L F
.517 .296 .518 r
.25143 .61426 m .25359 .61599 L .25362 .61379 L F
.25143 .61426 m .25126 .61652 L .25359 .61599 L F
.858 .457 0 r
.80964 .44633 m .80872 .44616 L .80607 .4441 L F
.80964 .44633 m .80978 .44733 L .80872 .44616 L F
.399 .26 .574 r
.4296 .58092 m .43147 .57777 L .42934 .57831 L F
.862 .696 .674 r
.6717 .42048 m .67298 .42389 L .67087 .42265 L F
.996 .863 .539 r
.6708 .42697 m .67087 .42265 L .67298 .42389 L F
.735 .639 .752 r
.67549 .42085 m .67298 .42389 L .6717 .42048 L F
.617 .144 .108 r
.24929 .64341 m .25097 .64171 L .25242 .64353 L F
.708 .242 .144 r
.18799 .64151 m .1891 .6435 L .18384 .64026 L F
0 0 .449 r
.18806 .64 m .18799 .64151 L .19064 .64167 L F
.18806 .64 m .1891 .6435 L .18799 .64151 L F
.996 .774 .418 r
.49847 .6205 m .49712 .61937 L .49765 .61618 L F
.996 .779 .427 r
.49847 .6205 m .49724 .62201 L .49712 .61937 L F
.678 .199 .108 r
.50086 .62248 m .49724 .62201 L .49847 .6205 L F
.545 .296 .489 r
.50104 .62014 m .50086 .62248 L .49847 .6205 L F
.699 .934 .965 r
.78466 .44881 m .78853 .44808 L .7879 .44785 L F
.477 .896 .833 r
.79037 .4468 m .78853 .44808 L .79094 .4469 L F
.487 .901 .891 r
.7879 .44785 m .78853 .44808 L .79037 .4468 L F
.93 .561 .289 r
.51215 .53082 m .51405 .5319 L .51335 .52973 L F
.727 .766 .884 r
.7473 .40674 m .75099 .40765 L .7499 .4053 L F
.403 .6 .926 r
.76273 .4291 m .76399 .42728 L .76108 .42611 L F
.76273 .4291 m .76488 .42909 L .76399 .42728 L F
.426 .211 .483 r
.30063 .59842 m .29814 .60194 L .2985 .59917 L F
0 0 0 r
.18017 .54748 m .18032 .5484 L .18256 .54745 L F
.18017 .54748 m .17838 .54954 L .18032 .5484 L F
.851 .781 .782 r
.57243 .53639 m .57071 .5388 L .57044 .53496 L F
.605 .29 .411 r
.50149 .60441 m .50064 .60729 L .49826 .60528 L F
.586 .416 .618 r
.50347 .60239 m .50394 .6046 L .50149 .60441 L F
.215 0 .257 r
.50288 .60604 m .50149 .60441 L .50394 .6046 L F
.50288 .60604 m .50064 .60729 L .50149 .60441 L F
.464 .323 .604 r
.55 .58383 m .55048 .58602 L .54796 .587 L F
.758 .797 .885 r
.54391 .58663 m .54796 .587 L .54532 .58784 L F
.548 .436 .678 r
.723 .39252 m .72604 .39564 L .72495 .39207 L F
.723 .39252 m .7235 .39632 L .72604 .39564 L F
.908 .633 .508 r
.42723 .62128 m .42931 .62328 L .42983 .62104 L F
.42723 .62128 m .42931 .62328 L .42983 .62104 L F
.545 0 0 r
.42553 .62036 m .42723 .62128 L .42983 .62104 L F
0 0 0 r
.26189 .63816 m .25811 .64018 L .25978 .63923 L F
.408 .282 .596 r
.30497 .55938 m .30304 .56299 L .30273 .5604 L F
.93 .882 .765 r
.49498 .60764 m .4967 .60876 L .49826 .60528 L F
.854 .935 .877 r
.49388 .60934 m .4967 .60876 L .49498 .60764 L F
.49388 .60934 m .49481 .60986 L .4967 .60876 L F
.346 .532 .895 r
.15282 .6175 m .15495 .62064 L .1559 .61907 L F
.228 .376 .805 r
.15495 .62064 m .15736 .6224 L .1559 .61907 L F
.326 .767 .964 r
.21145 .64713 m .21186 .64632 L .20966 .64651 L F
.21145 .64713 m .21352 .64694 L .21186 .64632 L F
0 0 .528 r
.30536 .54473 m .30675 .54748 L .30595 .54807 L F
.47 .672 .952 r
.30761 .54889 m .30595 .54807 L .30675 .54748 L F
.30761 .54889 m .30644 .55052 L .30595 .54807 L F
.576 .506 .739 r
.26868 .57811 m .27012 .57417 L .26768 .57496 L F
.26868 .57811 m .27105 .57778 L .27012 .57417 L F
.549 .367 .587 r
.26868 .57811 m .26896 .5806 L .27105 .57778 L F
.26868 .57811 m .26896 .5806 L .27105 .57778 L F
.7 .909 .557 r
.42742 .58395 m .42821 .58234 L .4296 .58092 L F
.6 .481 .689 r
.4296 .58092 m .43043 .58438 L .42742 .58395 L F
.246 0 0 r
.43043 .58438 m .42912 .58446 L .42742 .58395 L F
.041 .239 .739 r
.42742 .58395 m .42912 .58446 L .42821 .58234 L F
.676 .141 0 r
.28036 .5652 m .2769 .56219 L .27878 .56598 L F
.161 .05 .469 r
.27878 .56598 m .27997 .5677 L .28036 .5652 L F
.27878 .56598 m .27875 .56861 L .27997 .5677 L F
.767 .967 .927 r
.41717 .65595 m .42121 .65432 L .41943 .65295 L F
.451 .298 .581 r
.43063 .61464 m .43317 .61419 L .43279 .61053 L F
.392 .03 .226 r
.43067 .61488 m .43317 .61419 L .43063 .61464 L F
.458 .679 .96 r
.29348 .54358 m .29293 .54566 L .29179 .54358 L F
.29348 .54358 m .29502 .54548 L .29293 .54566 L F
.589 .793 .977 r
.7379 .38593 m .74064 .38756 L .73702 .38684 L F
.789 .549 .573 r
.74064 .38756 m .7368 .38872 L .73702 .38684 L F
.74064 .38756 m .74119 .39011 L .7368 .38872 L F
.543 .304 .503 r
.74064 .38756 m .74334 .38928 L .74119 .39011 L F
.74064 .38756 m .74422 .38484 L .74334 .38928 L F
.227 .457 .872 r
.15656 .59491 m .15608 .59666 L .15484 .59407 L F
.15656 .59491 m .15843 .5979 L .15608 .59666 L F
.984 .741 .487 r
.58373 .52569 m .58397 .52072 L .58235 .52212 L F
.997 .809 .532 r
.58235 .52212 m .58397 .52072 L .58285 .51959 L F
.331 0 0 r
.20132 .73455 m .20317 .73364 L .20337 .73488 L F
.408 .01 .169 r
.20317 .73364 m .20748 .73219 L .2053 .73274 L F
0 0 .001 r
.20337 .73488 m .20317 .73364 L .2053 .73274 L F
.64 .505 .682 r
.74623 .38374 m .74709 .38697 L .74422 .38484 L F
.775 .326 .183 r
.74422 .38484 m .7459 .38797 L .74334 .38928 L F
.74422 .38484 m .74709 .38697 L .7459 .38797 L F
.072 .264 .753 r
.53575 .60222 m .53659 .60073 L .53424 .59864 L F
.77 .569 0 r
.53706 .6048 m .53659 .60073 L .53575 .60222 L F
.929 .927 .558 r
.51671 .6033 m .51793 .60279 L .51645 .60119 L F
.51671 .6033 m .51698 .60496 L .51793 .60279 L F
.942 .8 .675 r
.57114 .53007 m .5688 .53132 L .56982 .52905 L F
.57114 .53007 m .57037 .53247 L .5688 .53132 L F
.875 .697 .658 r
.5815 .54649 m .58491 .54362 L .58183 .54394 L F
.5815 .54649 m .58346 .54747 L .58491 .54362 L F
.675 .588 .75 r
.8156 .42119 m .81924 .41715 L .81664 .41804 L F
.8156 .42119 m .82029 .42065 L .81924 .41715 L F
.732 .536 .627 r
.8164 .42391 m .82029 .42065 L .8156 .42119 L F
.594 .514 .734 r
.41433 .612 m .4142 .61438 L .41709 .61248 L F
.767 .76 .249 r
.41606 .6168 m .41709 .61248 L .4142 .61438 L F
.281 0 .112 r
.44855 .56896 m .45087 .56822 L .45191 .56606 L F
.35 0 .144 r
.45191 .56606 m .45315 .56764 L .45438 .56584 L F
.45191 .56606 m .45087 .56822 L .45315 .56764 L F
.816 .634 .656 r
.43464 .63629 m .43923 .64108 L .44122 .63761 L F
.573 .715 .939 r
.82639 .40585 m .82907 .40528 L .82994 .40695 L F
.615 .748 .94 r
.83172 .40454 m .82994 .40695 L .82907 .40528 L F
.83172 .40454 m .83262 .40606 L .82994 .40695 L F
.511 .831 1 r
.25925 .53832 m .26149 .53775 L .26319 .53862 L F
.228 .737 .887 r
.26149 .53775 m .26544 .53782 L .26319 .53862 L F
.645 .789 .337 r
.75335 .41771 m .75243 .41951 L .7529 .41855 L F
.514 .615 .89 r
.7529 .41855 m .75294 .41632 L .75335 .41771 L F
.802 .458 .405 r
.48201 .55877 m .48493 .56262 L .48533 .55967 L F
.062 0 .236 r
.48533 .55967 m .48688 .56076 L .48762 .56191 L F
.48533 .55967 m .48493 .56262 L .48688 .56076 L F
.747 .637 .738 r
.43386 .65618 m .43458 .65975 L .4305 .65956 L F
.72 .453 .522 r
.43403 .66171 m .4305 .65956 L .43458 .65975 L F
0 .057 .591 r
.43548 .65836 m .43458 .65975 L .43386 .65618 L F
.253 .203 .606 r
.43548 .65836 m .43403 .66171 L .43458 .65975 L F
.552 .652 .901 r
.19125 .64355 m .19518 .64525 L .19396 .64281 L F
.328 .514 .887 r
.19396 .64281 m .19518 .64525 L .19577 .64341 L F
.59 .8 .98 r
.19518 .64525 m .19749 .6447 L .19577 .64341 L F
.595 .854 .993 r
.77544 .40353 m .77713 .40125 L .77429 .40174 L F
.77544 .40353 m .77846 .40252 L .77713 .40125 L F
.58 .309 .47 r
.24549 .62002 m .24809 .62006 L .24882 .61696 L F
.443 .164 .393 r
.24809 .62006 m .25126 .61652 L .24882 .61696 L F
0 0 0 r
.57277 .59935 m .57122 .60068 L .56946 .60206 L F
.617 .951 .926 r
.57398 .59828 m .57399 .5978 L .57277 .59935 L F
.6 .886 .581 r
.57399 .5978 m .57122 .60068 L .57277 .59935 L F
.899 .495 .227 r
.19614 .74433 m .19569 .74637 L .1958 .74355 L F
.19614 .74433 m .1976 .74705 L .19569 .74637 L F
.536 .77 .984 r
.20146 .64598 m .20173 .64385 L .19951 .64422 L F
.20146 .64598 m .20409 .6455 L .20173 .64385 L F
.224 0 .12 r
.65754 .41123 m .6592 .4108 L .66089 .40822 L F
.597 .252 .356 r
.66089 .40822 m .66329 .40999 L .66255 .40902 L F
.66089 .40822 m .6592 .4108 L .66329 .40999 L F
.975 .723 .488 r
.49121 .54731 m .48969 .5436 L .49037 .54497 L F
.897 .714 .647 r
.56716 .51681 m .56981 .51733 L .56853 .5198 L F
.327 0 .09 r
.46015 .56453 m .46349 .56285 L .46091 .56355 L F
.005 0 0 r
.20416 .55598 m .20256 .55677 L .20022 .55735 L F
.205 .728 .734 r
.2061 .55598 m .20256 .55677 L .20416 .55598 L F
0 .332 .761 r
.21373 .62858 m .21551 .62996 L .21386 .62912 L F
.295 0 .211 r
.22753 .6906 m .2254 .69366 L .22404 .69346 L F
.621 .83 .432 r
.22868 .68884 m .2254 .69366 L .22753 .6906 L F
.873 .942 .859 r
.45957 .63168 m .46057 .63266 L .46282 .62977 L F
.725 .651 .775 r
.46053 .63221 m .46057 .63266 L .45957 .63168 L F
.46053 .63221 m .45876 .63422 L .46057 .63266 L F
.065 0 0 r
.46164 .57174 m .46215 .57176 L .45937 .57192 L F
.551 .559 .816 r
.51824 .52388 m .5184 .52215 L .51705 .52287 L F
.51824 .52388 m .52103 .52346 L .5184 .52215 L F
.5184 .52215 m .51824 .52388 L .51705 .52287 L F
.5184 .52215 m .52103 .52346 L .51824 .52388 L F
.51824 .52388 m .52103 .52346 L .5184 .52215 L F
.653 .594 .775 r
.72382 .39894 m .72481 .40211 L .72712 .39938 L F
.673 .624 .792 r
.72481 .40211 m .72854 .40319 L .72712 .39938 L F
.468 .643 .933 r
.28975 .54111 m .28962 .54387 L .28754 .54156 L F
.28975 .54111 m .29179 .54358 L .28962 .54387 L F
.386 .594 .927 r
.20423 .62487 m .20359 .62673 L .2023 .62486 L F
.465 .682 .96 r
.20423 .62487 m .20568 .62651 L .20359 .62673 L F
.969 .77 .581 r
.4061 .60772 m .40614 .61057 L .40726 .61122 L F
.985 .836 .448 r
.40611 .61271 m .40726 .61122 L .40614 .61057 L F
.40611 .61271 m .40667 .61384 L .40726 .61122 L F
.837 .579 .549 r
.43198 .61739 m .42964 .61922 L .42816 .61697 L F
.43198 .61739 m .43183 .62015 L .42964 .61922 L F
.725 .822 .363 r
.43227 .61654 m .4324 .61598 L .43198 .61739 L F
.837 .579 .549 r
.42964 .61922 m .43198 .61739 L .4324 .61598 L F
.42964 .61922 m .43183 .62015 L .43198 .61739 L F
.641 .754 .93 r
.78947 .43814 m .78635 .43761 L .78886 .43725 L F
.332 0 0 r
.78886 .43725 m .79207 .43747 L .78947 .43814 L F
.871 .888 .844 r
.6708 .42697 m .66697 .42891 L .67 .42617 L F
.996 .863 .539 r
.6708 .42697 m .67 .42617 L .67087 .42265 L F
.374 .789 .978 r
.78342 .38669 m .78399 .38738 L .78156 .38767 L F
.78342 .38669 m .78156 .38767 L .781 .39042 L F
.772 .979 .912 r
.48384 .61377 m .48178 .61496 L .48335 .61339 L F
.937 .616 .169 r
.48335 .61339 m .48477 .6172 L .48384 .61377 L F
.544 .57 .831 r
.19125 .64355 m .19265 .64064 L .19064 .64167 L F
.19125 .64355 m .19396 .64281 L .19265 .64064 L F
.524 .16 .292 r
.4526 .61605 m .45581 .61391 L .4525 .61473 L F
.739 .714 .828 r
.72854 .40319 m .72974 .39872 L .72712 .39938 L F
.72854 .40319 m .73105 .40207 L .72974 .39872 L F
.586 .651 .881 r
.7338 .40134 m .73454 .40313 L .73715 .40245 L F
.581 .809 .986 r
.26937 .53836 m .26544 .53782 L .26764 .53721 L F
.572 .736 .953 r
.27053 .53619 m .26937 .53836 L .26764 .53721 L F
.27053 .53619 m .27175 .53781 L .26937 .53836 L F
.879 .544 .413 r
.41946 .61828 m .42108 .62034 L .42292 .62034 L F
.891 .729 .674 r
.42276 .62265 m .42158 .62032 L .42292 .62034 L F
.233 0 .241 r
.42553 .62036 m .42276 .62265 L .42292 .62034 L F
.561 .064 .034 r
.42108 .62034 m .42553 .62036 L .42292 .62034 L F
.93 .882 .765 r
.49498 .60764 m .49826 .60528 L .49682 .60457 L F
.078 .277 .763 r
.49826 .60528 m .49939 .60402 L .49682 .60457 L F
.49826 .60528 m .50064 .60729 L .49939 .60402 L F
.672 .152 0 r
.21961 .69891 m .21817 .69921 L .2159 .69783 L F
.521 0 0 r
.22025 .70104 m .21817 .69921 L .21961 .69891 L F
.9 .697 .62 r
.22188 .69896 m .22025 .70104 L .21961 .69891 L F
.526 .285 .493 r
.294 .61074 m .29112 .61365 L .29169 .61136 L F
.728 .524 .615 r
.18342 .77103 m .18668 .76882 L .18454 .77028 L F
.635 .579 .775 r
.48963 .59231 m .48562 .59113 L .4887 .5915 L F
.546 .128 .2 r
.48562 .59113 m .48475 .59272 L .4887 .5915 L F
.647 .708 .892 r
.16213 .59879 m .16 .59978 L .15843 .5979 L F
.773 .689 .77 r
.82057 .42312 m .82416 .42384 L .823 .42015 L F
.273 .38 .791 r
.82057 .42312 m .82222 .42687 L .82416 .42384 L F
.673 .641 .81 r
.82416 .42384 m .82567 .41971 L .823 .42015 L F
.82416 .42384 m .8265 .42256 L .82567 .41971 L F
.59 .817 .426 r
.57773 .59329 m .57658 .59484 L .57547 .59645 L F
.774 .981 .721 r
.57658 .59484 m .57398 .59828 L .57547 .59645 L F
.81 .576 .584 r
.57862 .50169 m .58018 .5047 L .58238 .50251 L F
.822 .595 .596 r
.58238 .50251 m .58018 .5047 L .58377 .50537 L F
.763 .45 .456 r
.56254 .51158 m .56274 .51372 L .55896 .51326 L F
.711 .778 .905 r
.22713 .5504 m .23113 .55081 L .22934 .55069 L F
0 .47 .847 r
.23113 .55081 m .23162 .55041 L .22934 .55069 L F
.23113 .55081 m .23249 .55115 L .23162 .55041 L F
.516 .396 .655 r
.3076 .57371 m .30486 .57423 L .30738 .5726 L F
.048 .556 .879 r
.20028 .62384 m .19965 .62428 L .19792 .62336 L F
.20028 .62384 m .2023 .62486 L .19965 .62428 L F
.656 .679 .86 r
.19482 .75047 m .19571 .75379 L .19735 .7499 L F
.855 .554 .477 r
.68478 .42221 m .68778 .42081 L .68431 .4198 L F
.68478 .42221 m .68792 .42305 L .68778 .42081 L F
.784 .496 .5 r
.68778 .42081 m .68792 .42305 L .69156 .42359 L F
.574 .477 .706 r
.30738 .5726 m .30447 .56908 L .30687 .56827 L F
.972 .855 .665 r
.57044 .53496 m .57071 .5388 L .56966 .53719 L F
.953 .798 .652 r
.57054 .5401 m .56966 .53719 L .57071 .5388 L F
.471 .188 .402 r
.27848 .62604 m .27544 .62896 L .27601 .62694 L F
.744 .954 .943 r
.68204 .43607 m .68145 .4351 L .67784 .43735 L F
.87 .982 .841 r
.68287 .43334 m .68204 .43607 L .68381 .43432 L F
.68287 .43334 m .68145 .4351 L .68204 .43607 L F
0 0 .208 r
.53403 .59619 m .53461 .5976 L .53367 .59507 L F
.53403 .59619 m .53424 .59864 L .53461 .5976 L F
.466 .516 .826 r
.84401 .4106 m .84433 .41373 L .84377 .41132 L F
.84401 .4106 m .84677 .41368 L .84434 .41377 L F
.521 .36 .603 r
.84808 .40697 m .84401 .4106 L .84526 .40855 L F
.466 .516 .826 r
.84377 .41132 m .84434 .41377 L .84312 .41326 L F
.84433 .41373 m .84434 .41377 L .84377 .41132 L F
.84401 .4106 m .84312 .41326 L .84568 .41249 L F
.521 .36 .603 r
.84808 .40697 m .84861 .4094 L .84401 .4106 L F
.477 .245 .483 r
.84401 .4106 m .84568 .41249 L .84677 .41368 L F
.84401 .4106 m .84861 .4094 L .84568 .41249 L F
.124 .319 .788 r
.84353 .41031 m .84568 .41249 L .84501 .41042 L F
.466 .516 .826 r
.84401 .4106 m .84568 .41249 L .84307 .41028 L F
.124 .319 .788 r
.84307 .41028 m .84363 .41076 L .84353 .41031 L F
.84363 .41076 m .84568 .41249 L .84353 .41031 L F
.792 .364 0 r
.51826 .5648 m .51638 .56185 L .51829 .56299 L F
.58 .234 .347 r
.66675 .41365 m .6705 .41139 L .66713 .41057 L F
.66675 .41365 m .66943 .41379 L .6705 .41139 L F
.703 .367 .405 r
.6705 .41139 m .66943 .41379 L .67276 .41375 L F
.408 .282 .596 r
.30497 .55938 m .30494 .56253 L .30304 .56299 L F
.455 .463 .778 r
.30494 .56253 m .30589 .56481 L .30304 .56299 L F
0 0 0 r
.84108 .42409 m .8416 .42234 L .84396 .42131 L F
.974 .747 .533 r
.19797 .77975 m .19926 .78059 L .19768 .78298 L F
.19768 .78298 m .19926 .78059 L .19797 .77975 L F
.362 .167 .477 r
.42752 .64427 m .43024 .64343 L .43043 .64104 L F
.354 .173 .491 r
.42752 .64427 m .42986 .64583 L .43024 .64343 L F
.42752 .64427 m .42743 .64712 L .42986 .64583 L F
.339 .583 .933 r
.42539 .61194 m .42717 .6119 L .42447 .61379 L F
0 0 0 r
.42717 .6119 m .42495 .61466 L .42447 .61379 L F
.18107 .56659 m .17939 .56767 L .17735 .56832 L F
.119 0 0 r
.18298 .56572 m .17939 .56767 L .18107 .56659 L F
.649 .741 .916 r
.75249 .3852 m .75317 .38713 L .74954 .3865 L F
.743 .614 .715 r
.74954 .3865 m .75317 .38713 L .75069 .39054 L F
.51 .652 .922 r
.7559 .38662 m .75317 .38713 L .75249 .3852 L F
.8 .637 .679 r
.17093 .61082 m .17018 .60749 L .17117 .60827 L F
.462 .735 .986 r
.1721 .60675 m .17117 .60827 L .17018 .60749 L F
.524 .316 .54 r
.17329 .60979 m .17117 .60827 L .1721 .60675 L F
.17329 .60979 m .17093 .61082 L .17117 .60827 L F
.497 .442 .726 r
.23635 .68037 m .23436 .68094 L .23374 .67812 L F
.404 .181 .458 r
.23635 .68037 m .23404 .68329 L .23436 .68094 L F
.424 .232 .514 r
.25345 .61114 m .25577 .6105 L .25567 .60804 L F
.394 .249 .563 r
.25345 .61114 m .25562 .61288 L .25577 .6105 L F
.25345 .61114 m .25362 .61379 L .25562 .61288 L F
.184 .476 .894 r
.29819 .5461 m .29767 .5472 L .29502 .54548 L F
.362 .681 .978 r
.29935 .54593 m .30138 .54767 L .29853 .54764 L F
.29935 .54593 m .29853 .54764 L .29934 .54828 L F
.184 .476 .894 r
.29819 .5461 m .29934 .54828 L .29767 .5472 L F
.479 .346 .622 r
.50615 .60378 m .50347 .60239 L .50604 .60176 L F
.50615 .60378 m .50394 .6046 L .50347 .60239 L F
.592 .389 .574 r
.4485 .59585 m .44604 .59878 L .44605 .59617 L F
.4485 .59585 m .44604 .59878 L .44605 .59617 L F
0 .298 .736 r
.51042 .55666 m .51061 .55643 L .50898 .55555 L F
.51042 .55666 m .51201 .55762 L .51061 .55643 L F
.559 .83 .478 r
.74544 .38141 m .74798 .37843 L .74705 .37945 L F
.645 .119 0 r
.74705 .37945 m .74798 .37843 L .74992 .37999 L F
0 0 .267 r
.51434 .62572 m .51493 .62581 L .51484 .62404 L F
.882 .954 .848 r
.77036 .40857 m .76798 .41135 L .77047 .41036 L F
.921 .865 .768 r
.76704 .41249 m .77047 .41036 L .76798 .41135 L F
.76704 .41249 m .76825 .4143 L .77047 .41036 L F
.478 .72 .976 r
.81801 .40136 m .81635 .40302 L .81544 .40157 L F
.81801 .40136 m .81895 .40279 L .81635 .40302 L F
.282 .137 .5 r
.40075 .62028 m .4024 .62229 L .40287 .61929 L F
.132 .107 .56 r
.4012 .62283 m .4024 .62229 L .40075 .62028 L F
.558 .542 .792 r
.29853 .54764 m .30067 .55105 L .29934 .54828 L F
.007 0 0 r
.22072 .70504 m .2182 .70758 L .22117 .70627 L F
.402 .055 .258 r
.54815 .50515 m .55063 .50469 L .55137 .50237 L F
.372 .02 .233 r
.55063 .50469 m .55383 .5018 L .55137 .50237 L F
.641 .725 .909 r
.81304 .41723 m .81664 .41804 L .8155 .41646 L F
.658 .736 .907 r
.81664 .41804 m .81815 .4156 L .8155 .41646 L F
.81664 .41804 m .81924 .41715 L .81815 .4156 L F
.419 .621 .935 r
.74434 .40607 m .74608 .40431 L .74382 .40416 L F
.74434 .40607 m .7473 .40674 L .74608 .40431 L F
.243 .418 .836 r
.48001 .56227 m .48229 .5651 L .48131 .56224 L F
.707 .706 .846 r
.7384 .39327 m .73549 .39572 L .73468 .39247 L F
.957 .62 .245 r
.41965 .67292 m .4191 .676 L .41881 .67365 L F
.41965 .67292 m .42052 .67711 L .4191 .676 L F
0 0 .463 r
.42176 .67542 m .41965 .67292 L .42048 .67233 L F
.42176 .67542 m .42052 .67711 L .41965 .67292 L F
.174 0 0 r
.15938 .55953 m .16139 .55896 L .16309 .55692 L F
.184 0 0 r
.16309 .55692 m .16353 .55831 L .16523 .55629 L F
.16309 .55692 m .16139 .55896 L .16353 .55831 L F
.382 .835 .743 r
.18869 .54447 m .18445 .54619 L .18659 .54546 L F
.458 .887 .875 r
.18869 .54447 m .18927 .54379 L .19081 .54354 L F
.518 .9 .73 r
.18659 .54546 m .18927 .54379 L .18869 .54447 L F
.274 0 0 r
.15347 .59214 m .15066 .59245 L .14937 .59216 L F
.556 .778 .981 r
.54288 .60807 m .54345 .606 L .54118 .60713 L F
.54288 .60807 m .54646 .60772 L .54345 .606 L F
.707 .169 0 r
.22568 .68534 m .22547 .68388 L .22349 .68564 L F
.22568 .68534 m .22748 .686 L .22547 .68388 L F
.576 .402 .609 r
.22547 .68388 m .22799 .68364 L .22789 .68082 L F
.548 .295 .484 r
.22547 .68388 m .22748 .686 L .22799 .68364 L F
.159 0 0 r
.79475 .43706 m .79739 .43678 L .79842 .43598 L F
0 0 0 r
.79842 .43598 m .79971 .43564 L .80099 .43527 L F
.79842 .43598 m .79739 .43678 L .79971 .43564 L F
.608 .683 .896 r
.7548 .38221 m .75573 .38442 L .75796 .38361 L F
.431 .185 .439 r
.75796 .38361 m .75573 .38442 L .7559 .38662 L F
.958 .632 .233 r
.7559 .38662 m .75573 .38442 L .75483 .38507 L F
.431 .185 .439 r
.75796 .38361 m .75573 .38442 L .7559 .38662 L F
.881 .699 .652 r
.58249 .53478 m .58394 .53816 L .58423 .53584 L F
.817 .602 .611 r
.44604 .59878 m .44598 .60147 L .45045 .60204 L F
.802 .646 .688 r
.44598 .60147 m .45067 .60358 L .45045 .60204 L F
.32 .292 .671 r
.45255 .60406 m .45045 .60204 L .45252 .60138 L F
.714 .381 .413 r
.21639 .69478 m .22059 .69589 L .21808 .69363 L F
.389 .211 .514 r
.30683 .55835 m .30526 .55761 L .308 .55683 L F
.747 .348 .295 r
.304 .54634 m .30675 .54748 L .30536 .54473 L F
.337 .519 .888 r
.30816 .54683 m .30768 .54863 L .3058 .54618 L F
.30768 .54863 m .30761 .54889 L .30726 .54837 L F
.684 .252 0 r
.3058 .54618 m .30761 .54889 L .30675 .54748 L F
.337 .519 .888 r
.30768 .54863 m .30726 .54837 L .3058 .54618 L F
.747 .348 .295 r
.30368 .54672 m .30523 .5471 L .304 .54634 L F
.30523 .5471 m .30675 .54748 L .304 .54634 L F
.474 .567 .87 r
.30939 .55513 m .308 .55683 L .30639 .55356 L F
.538 .354 .579 r
.30939 .55513 m .30683 .55835 L .308 .55683 L F
.816 .661 .691 r
.66593 .41725 m .66382 .41738 L .66422 .41431 L F
.811 .477 .423 r
.66593 .41725 m .66433 .41921 L .66382 .41738 L F
.66593 .41725 m .66769 .42004 L .66433 .41921 L F
.683 .858 .966 r
.23374 .67812 m .2306 .67839 L .23296 .67631 L F
.23374 .67812 m .2304 .67856 L .2306 .67839 L F
.497 .442 .726 r
.23635 .68037 m .23374 .67812 L .23646 .67768 L F
.637 .779 .949 r
.67298 .44002 m .67462 .43735 L .67206 .43824 L F
.67298 .44002 m .67629 .43912 L .67462 .43735 L F
.626 .673 .874 r
.73105 .40207 m .73234 .39805 L .72974 .39872 L F
.73105 .40207 m .7338 .40134 L .73234 .39805 L F
.72 .704 .834 r
.84493 .40587 m .84526 .40855 L .84259 .40871 L F
.81 .545 .538 r
.84526 .40855 m .84307 .41028 L .84259 .40871 L F
.84526 .40855 m .84401 .4106 L .84307 .41028 L F
.467 .514 .823 r
.84808 .40697 m .84526 .40855 L .84493 .40587 L F
.107 0 .211 r
.27203 .56546 m .2695 .56879 L .27146 .56764 L F
.46 .351 .644 r
.26951 .57152 m .27146 .56764 L .2695 .56879 L F
.625 .382 .53 r
.45375 .62645 m .45498 .62868 L .45544 .62691 L F
.774 .413 .373 r
.45544 .62691 m .45498 .62868 L .45889 .62923 L F
.564 .409 .63 r
.51767 .6075 m .51556 .60832 L .51477 .60513 L F
.602 .346 .501 r
.40651 .60503 m .40971 .60487 L .41041 .60265 L F
.143 0 .29 r
.41041 .60265 m .41119 .60398 L .41142 .60151 L F
.41041 .60265 m .40971 .60487 L .41119 .60398 L F
.437 .576 .895 r
.21901 .68672 m .22169 .68967 L .22285 .68954 L F
.266 0 0 r
.27766 .53944 m .28173 .54018 L .27964 .5404 L F
.64 .359 .476 r
.55763 .49925 m .56015 .5014 L .5599 .49958 L F
.71 .436 .508 r
.56015 .5014 m .56364 .49915 L .5599 .49958 L F
.506 .3 .535 r
.73091 .38949 m .73072 .38627 L .72834 .39017 L F
.537 .378 .612 r
.73072 .38627 m .73414 .38781 L .73321 .38395 L F
0 .113 .651 r
.83564 .41994 m .83679 .42354 L .83702 .42197 L F
.369 .589 .929 r
.83702 .42197 m .83679 .42354 L .83901 .4238 L F
.493 .312 .564 r
.20484 .72008 m .20481 .72312 L .20254 .72331 L F
.32 .758 .967 r
.20254 .72331 m .20481 .72312 L .20079 .72259 L F
.917 .88 .784 r
.43661 .64385 m .43727 .64017 L .43923 .64108 L F
.901 .522 .3 r
.43464 .63629 m .43923 .64108 L .43727 .64017 L F
.482 .79 .999 r
.44006 .63959 m .43923 .64108 L .43727 .64017 L F
.917 .88 .784 r
.43661 .64385 m .43526 .64317 L .43727 .64017 L F
.297 .62 .959 r
.43526 .64317 m .43721 .64393 L .43609 .64193 L F
.924 .683 .557 r
.43731 .64375 m .43897 .6442 L .43923 .64108 L F
.297 .62 .959 r
.43721 .64393 m .43755 .64407 L .43738 .64381 L F
.43721 .64393 m .43738 .64381 L .43731 .64375 L F
.924 .683 .557 r
.4371 .64403 m .43738 .64381 L .43731 .64375 L F
0 .532 .768 r
.43729 .64397 m .43728 .64395 L .43661 .64385 L F
.44051 .64457 m .43728 .64395 L .43729 .64397 L F
.164 0 0 r
.43661 .64385 m .43897 .6442 L .43755 .64407 L F
.113 0 0 r
.43755 .64407 m .43897 .6442 L .4371 .64403 L F
.924 .683 .557 r
.43773 .64409 m .43897 .6442 L .43731 .64375 L F
.297 .62 .959 r
.43731 .64375 m .43738 .64381 L .43732 .64372 L F
.43721 .64393 m .43732 .64372 L .43609 .64193 L F
.924 .683 .557 r
.4371 .64403 m .43725 .64383 L .43725 .64383 L F
.973 .88 .68 r
.43609 .64193 m .43732 .64372 L .4371 .64403 L F
.924 .683 .557 r
.4371 .64403 m .43725 .64383 L .43724 .64382 L F
.973 .88 .68 r
.43732 .64372 m .43738 .64381 L .4371 .64403 L F
.43738 .64381 m .43755 .64407 L .4371 .64403 L F
.924 .683 .557 r
.4371 .64403 m .43773 .64409 L .43738 .64381 L F
.43737 .64363 m .43923 .64108 L .44006 .63959 L F
.43724 .64382 m .43734 .64369 L .43737 .64363 L F
.43734 .64369 m .43923 .64108 L .43737 .64363 L F
.43725 .64383 m .43923 .64108 L .43724 .64382 L F
0 .532 .768 r
.44051 .64457 m .43897 .6442 L .43728 .64395 L F
.345 .802 .941 r
.44291 .64419 m .43897 .6442 L .44051 .64457 L F
.9 .697 .62 r
.22188 .69896 m .22198 .70203 L .22025 .70104 L F
.133 .095 .545 r
.22375 .7004 m .22188 .69896 L .22548 .69882 L F
.239 .754 .764 r
.22597 .70034 m .22445 .70067 L .22375 .7004 L F
.133 .095 .545 r
.22375 .7004 m .22198 .70203 L .2219 .69969 L F
0 0 0 r
.22375 .7004 m .2223 .70218 L .22198 .70203 L F
.718 .798 .914 r
.21963 .70059 m .2223 .70218 L .22375 .7004 L F
.239 .754 .764 r
.22445 .70067 m .2216 .70129 L .22375 .7004 L F
.133 .095 .545 r
.22375 .7004 m .2219 .69969 L .22188 .69896 L F
.616 .333 .465 r
.55383 .5018 m .55652 .50194 L .55763 .49925 L F
.64 .359 .476 r
.55763 .49925 m .55652 .50194 L .56015 .5014 L F
.305 .501 .885 r
.15102 .61731 m .152 .61614 L .14992 .61559 L F
.862 .882 .85 r
.66187 .43259 m .65955 .43542 L .6586 .43376 L F
.233 0 .241 r
.42553 .62036 m .42565 .62256 L .42276 .62265 L F
.468 .254 .505 r
.42519 .6252 m .42276 .62265 L .42565 .62256 L F
.42519 .6252 m .42291 .62621 L .42276 .62265 L F
.873 .892 .844 r
.55871 .58076 m .55732 .5832 L .55483 .58279 L F
.551 .04 0 r
.7433 .37644 m .74423 .37518 L .74058 .37509 L F
.58 .072 .01 r
.74676 .37687 m .74423 .37518 L .7433 .37644 L F
.27 .034 .36 r
.48963 .59231 m .48865 .59587 L .48665 .59601 L F
.444 .076 .244 r
.48723 .59774 m .48665 .59601 L .48865 .59587 L F
.48723 .59774 m .48601 .59816 L .48665 .59601 L F
.129 .621 .911 r
.48001 .56227 m .47775 .56116 L .47768 .55901 L F
.48001 .56227 m .48131 .56224 L .47775 .56116 L F
.432 .733 .99 r
.78541 .43621 m .78193 .43687 L .78202 .43615 L F
.78541 .43621 m .78635 .43761 L .78193 .43687 L F
.643 .392 .524 r
.44266 .58105 m .44227 .58369 L .43991 .58308 L F
.427 .202 .467 r
.44452 .58289 m .44266 .58105 L .44459 .58031 L F
.44452 .58289 m .44227 .58369 L .44266 .58105 L F
.69 .479 .596 r
.5662 .49912 m .56999 .50143 L .56979 .49919 L F
.696 .444 .539 r
.56999 .50143 m .57249 .49926 L .56979 .49919 L F
.523 .601 .873 r
.80503 .40934 m .80695 .40706 L .80461 .40752 L F
.80503 .40934 m .80831 .41038 L .80695 .40706 L F
.033 .161 .666 r
.4236 .65352 m .42571 .65541 L .42613 .65324 L F
.544 .329 .538 r
.45937 .57192 m .45925 .57426 L .45683 .57438 L F
.438 .242 .516 r
.46116 .57348 m .45937 .57192 L .46215 .57176 L F
.46116 .57348 m .45925 .57426 L .45937 .57192 L F
.468 .334 .614 r
.16675 .60201 m .16665 .60419 L .16554 .60412 L F
.286 .181 .556 r
.16658 .60587 m .16554 .60412 L .16665 .60419 L F
.16658 .60587 m .16489 .61075 L .16554 .60412 L F
.358 .818 .926 r
.22302 .64556 m .22616 .64574 L .2283 .64525 L F
.431 .207 .471 r
.47592 .5901 m .47579 .59248 L .47817 .58967 L F
.47817 .58967 m .47579 .59248 L .47592 .5901 L F
.691 .972 .769 r
.2306 .67839 m .22789 .68082 L .22838 .67959 L F
0 .158 .696 r
.22789 .68082 m .2299 .68294 L .22838 .67959 L F
.425 .286 .587 r
.22789 .68082 m .22799 .68364 L .2299 .68294 L F
.565 .584 .831 r
.1976 .54221 m .19783 .54101 L .19765 .5399 L F
.784 .325 .156 r
.19738 .53824 m .19765 .5399 L .19969 .53907 L F
.018 .592 .732 r
.19765 .5399 m .20185 .53996 L .19969 .53907 L F
.19765 .5399 m .20094 .53991 L .20185 .53996 L F
.414 .7 .98 r
.19835 .53845 m .20094 .53991 L .19765 .5399 L F
.565 .584 .831 r
.19783 .54101 m .19835 .53845 L .19765 .5399 L F
.784 .325 .156 r
.19706 .53813 m .19765 .5399 L .19738 .53824 L F
0 0 0 r
.57914 .58952 m .57855 .59152 L .57773 .59329 L F
.697 .862 .453 r
.57855 .59152 m .57658 .59484 L .57773 .59329 L F
.205 .636 .95 r
.49702 .56831 m .4965 .56914 L .49554 .56721 L F
.49702 .56831 m .49876 .56948 L .4965 .56914 L F
.195 0 0 r
.45683 .57438 m .45553 .57508 L .45329 .57534 L F
.291 0 0 r
.45925 .57426 m .45553 .57508 L .45683 .57438 L F
.8 .473 .436 r
.52747 .55531 m .53112 .5537 L .52769 .55306 L F
.52747 .55531 m .52955 .55584 L .53112 .5537 L F
.731 .381 .387 r
.52955 .55584 m .53221 .55642 L .53112 .5537 L F
.119 0 .199 r
.16594 .55463 m .16699 .55516 L .16759 .55402 L F
.16594 .55463 m .16523 .55629 L .16699 .55516 L F
.419 .085 .291 r
.26532 .63523 m .26408 .63776 L .26189 .63816 L F
.544 .239 .402 r
.26688 .63476 m .26408 .63776 L .26532 .63523 L F
.673 .809 .948 r
.52576 .57539 m .52566 .57449 L .52504 .57433 L F
.661 .285 0 r
.52566 .57449 m .52566 .5745 L .52504 .57433 L F
.673 .809 .948 r
.52576 .57539 m .52504 .57433 L .52563 .57449 L F
.661 .285 0 r
.52566 .5745 m .52755 .57848 L .52504 .57433 L F
.673 .809 .948 r
.52563 .57449 m .52504 .57433 L .52557 .57403 L F
0 0 0 r
.45175 .57642 m .45086 .5763 L .45329 .57534 L F
.45175 .57642 m .44951 .57708 L .45086 .5763 L F
.366 .547 .899 r
.78689 .39561 m .78877 .39436 L .78573 .3929 L F
.78689 .39561 m .78885 .39613 L .78877 .39436 L F
.952 .925 .742 r
.6558 .41994 m .65662 .41553 L .65515 .41823 L F
.52 .493 .766 r
.30647 .58327 m .30433 .58404 L .30338 .58051 L F
.428 .275 .57 r
.30647 .58327 m .30435 .58672 L .30433 .58404 L F
.522 .05 .075 r
.73947 .37606 m .73803 .37482 L .73737 .37781 L F
.73947 .37606 m .74058 .37509 L .73803 .37482 L F
.192 0 .288 r
.26524 .59529 m .26752 .59247 L .26583 .59342 L F
.566 .929 .776 r
.53302 .56596 m .53163 .56659 L .53365 .56585 L F
.503 .29 .524 r
.53365 .56585 m .53364 .56195 L .53302 .56596 L F
0 0 0 r
.53316 .56599 m .53365 .56585 L .53163 .56659 L F
.53316 .56599 m .53616 .56526 L .53365 .56585 L F
.791 .491 .481 r
.43196 .65286 m .43407 .6507 L .43298 .64997 L F
.43196 .65286 m .43364 .65334 L .43407 .6507 L F
.656 .565 .741 r
.41592 .64984 m .41943 .65295 L .41923 .65068 L F
.41592 .64984 m .41625 .6537 L .41861 .65314 L F
.4187 .65231 m .41861 .65314 L .41943 .65295 L F
.41592 .64984 m .41861 .65314 L .4187 .65231 L F
.74 .272 .138 r
.41923 .65068 m .4183 .65222 L .41592 .64984 L F
.937 .836 .393 r
.41877 .64997 m .4183 .65222 L .41881 .65138 L F
.41893 .65023 m .41881 .65138 L .41923 .65068 L F
.41877 .64997 m .41881 .65138 L .41893 .65023 L F
.939 .855 .424 r
.41941 .64592 m .41923 .65068 L .4185 .64696 L F
.41941 .64592 m .41877 .64997 L .41923 .65068 L F
.967 .643 .308 r
.41923 .65068 m .4183 .65222 L .41943 .65295 L F
.372 .489 .849 r
.74705 .37945 m .7485 .38304 L .74544 .38141 L F
.516 .464 .736 r
.74544 .38141 m .7485 .38304 L .74623 .38374 L F
.016 .132 .642 r
.4012 .62283 m .4022 .62712 L .40284 .6246 L F
.533 .691 .94 r
.40284 .6246 m .4022 .62712 L .40407 .62605 L F
.536 .304 .51 r
.47575 .61722 m .47803 .61946 L .47825 .61673 L F
.47575 .61722 m .47503 .62093 L .47803 .61946 L F
.96 .706 .506 r
.49916 .58312 m .50106 .58701 L .49918 .58605 L F
.949 .626 .383 r
.50106 .58701 m .50085 .5892 L .49918 .58605 L F
.801 .708 .762 r
.43183 .62015 m .42931 .62328 L .43272 .62346 L F
.381 .375 .728 r
.43272 .62346 m .43538 .62537 L .4344 .62311 L F
.91 .835 .759 r
.56864 .56604 m .56507 .56816 L .56716 .56489 L F
.56864 .56604 m .56692 .56937 L .56507 .56816 L F
0 0 0 r
.75796 .38361 m .75857 .38154 L .75951 .37923 L F
.92 .735 .635 r
.6586 .43376 m .6609 .43528 L .66089 .43381 L F
.6586 .43376 m .65964 .43813 L .6609 .43528 L F
.786 .557 .589 r
.65964 .43813 m .66338 .43875 L .6609 .43528 L F
.421 .696 .978 r
.6609 .43528 m .66629 .43563 L .66355 .4332 L F
0 .315 .782 r
.49876 .56948 m .50028 .57018 L .50128 .57162 L F
.961 .683 .462 r
.50028 .57018 m .50236 .574 L .50128 .57162 L F
.862 .415 .119 r
.50128 .57162 m .50236 .574 L .50409 .5748 L F
.881 .699 .652 r
.58249 .53478 m .58078 .53778 L .58394 .53816 L F
.848 .63 .607 r
.58035 .54035 m .58394 .53816 L .58078 .53778 L F
.58035 .54035 m .58489 .54247 L .58394 .53816 L F
0 .084 .583 r
.8159 .43155 m .81958 .435 L .81906 .43286 L F
.772 .277 .035 r
.8159 .43155 m .81906 .43286 L .81884 .43388 L F
.915 .951 .609 r
.82152 .42933 m .81884 .43388 L .81906 .43286 L F
.403 .857 .825 r
.20619 .72843 m .2039 .72944 L .20417 .72899 L F
.429 .869 .802 r
.20417 .72899 m .2039 .72944 L .20177 .72997 L F
.254 .752 .902 r
.757 .37451 m .75299 .37445 L .7554 .37423 L F
.62 .922 .975 r
.75758 .37399 m .757 .37451 L .7554 .37423 L F
.866 .68 .648 r
.74954 .3865 m .75069 .39054 L .74803 .38965 L F
.842 .735 .746 r
.74803 .38965 m .75069 .39054 L .74725 .39283 L F
.278 0 0 r
.75039 .37493 m .74676 .37687 L .74958 .37628 L F
.375 0 .165 r
.75192 .37645 m .75039 .37493 L .74958 .37628 L F
.75192 .37645 m .75299 .37445 L .75039 .37493 L F
0 0 .524 r
.53218 .59053 m .53322 .59141 L .5317 .58899 L F
.53218 .59053 m .53384 .59272 L .53322 .59141 L F
.003 .243 .751 r
.27203 .56546 m .27288 .56459 L .27068 .56275 L F
.752 .567 .645 r
.27146 .56764 m .27288 .56459 L .27203 .56546 L F
0 0 0 r
.27203 .56546 m .27146 .56764 L .27288 .56459 L F
.615 .072 0 r
.50703 .55373 m .50753 .55467 L .5057 .55285 L F
.50703 .55373 m .50898 .55555 L .50753 .55467 L F
.737 .676 .791 r
.7485 .38304 m .74709 .38697 L .74623 .38374 L F
.866 .778 .762 r
.58148 .5294 m .58238 .53176 L .5831 .52998 L F
.881 .658 .595 r
.57921 .53424 m .58238 .53176 L .58148 .5294 L F
.57921 .53424 m .58249 .53478 L .58238 .53176 L F
.533 .309 .521 r
.29112 .61365 m .28849 .61652 L .28892 .61423 L F
.84 .551 .5 r
.51182 .61572 m .5095 .6131 L .50952 .61423 L F
.71 .436 .508 r
.56015 .5014 m .56234 .50198 L .56364 .49915 L F
.721 .448 .513 r
.56364 .49915 m .56622 .5017 L .5662 .49912 L F
.56364 .49915 m .56234 .50198 L .56622 .5017 L F
.65 .906 .981 r
.23471 .65904 m .23823 .65871 L .23694 .65834 L F
.23471 .65904 m .23823 .65871 L .23694 .65834 L F
0 0 0 r
.23916 .65806 m .24084 .65624 L .23823 .65871 L F
.23916 .65806 m .23823 .65871 L .23694 .65834 L F
0 .265 .772 r
.23823 .65871 m .23916 .65806 L .23694 .65834 L F
.23823 .65871 m .24101 .66116 L .23916 .65806 L F
.788 .553 .581 r
.20079 .72259 m .20484 .72008 L .20149 .72122 L F
.307 .799 .852 r
.22002 .62981 m .22003 .6303 L .21775 .63037 L F
.22002 .62981 m .22195 .62982 L .22003 .6303 L F
.187 0 0 r
.22059 .69589 m .22308 .69497 L .22404 .69346 L F
.275 .196 .583 r
.22404 .69346 m .22557 .68906 L .22285 .68954 L F
.22404 .69346 m .2254 .69366 L .22557 .68906 L F
.033 0 0 r
.22404 .69346 m .22467 .69438 L .2254 .69366 L F
.22404 .69346 m .22308 .69497 L .22467 .69438 L F
.428 .213 .483 r
.29602 .60757 m .2939 .60814 L .29631 .60512 L F
.29602 .60757 m .2939 .60814 L .29631 .60512 L F
.349 .171 .493 r
.29602 .60757 m .294 .61074 L .2939 .60814 L F
0 0 0 r
.79975 .44388 m .7963 .44492 L .79707 .44454 L F
.828 .615 .614 r
.58015 .5073 m .58377 .50537 L .58018 .5047 L F
.58015 .5073 m .58367 .50798 L .58377 .50537 L F
.702 .654 .798 r
.84151 .40464 m .84259 .40871 L .84069 .40845 L F
.627 .367 .504 r
.84307 .41028 m .84069 .40845 L .84259 .40871 L F
.679 .64 .803 r
.84493 .40587 m .84259 .40871 L .84151 .40464 L F
.535 .358 .588 r
.43279 .61053 m .43531 .61371 L .43541 .61052 L F
.43279 .61053 m .43317 .61419 L .43531 .61371 L F
.21 .591 .946 r
.80547 .39857 m .80334 .39817 L .80095 .39652 L F
.783 .998 .846 r
.65566 .43319 m .6531 .43563 L .65494 .43246 L F
.42 .521 .855 r
.6531 .43563 m .65593 .43678 L .65494 .43246 L F
.615 .604 .816 r
.30438 .58924 m .30263 .59172 L .30304 .59024 L F
.658 .58 .756 r
.72382 .39894 m .72604 .39564 L .7235 .39632 L F
.971 .762 .332 r
.7718 .40464 m .77169 .40688 L .77237 .4078 L F
.909 .946 .816 r
.77036 .40857 m .77237 .4078 L .77169 .40688 L F
.484 .736 .982 r
.44561 .65354 m .44768 .6531 L .44478 .65052 L F
.764 .486 .512 r
.57497 .49881 m .57862 .50169 L .57866 .49926 L F
.872 .748 .237 r
.82236 .43662 m .82291 .43561 L .81958 .435 L F
.82236 .43662 m .82262 .43827 L .82291 .43561 L F
.498 .316 .564 r
.59489 .51462 m .59162 .51452 L .59367 .51335 L F
0 .33 .769 r
.7715 .38751 m .77556 .38972 L .77531 .39003 L F
.244 .358 .782 r
.77706 .38806 m .77531 .39003 L .77556 .38972 L F
.876 .877 .833 r
.21099 .72001 m .20928 .72238 L .2085 .72335 L F
.546 0 0 r
.20928 .72238 m .21049 .72329 L .2085 .72335 L F
.845 .574 .53 r
.68792 .42305 m .69152 .42607 L .69156 .42359 L F
.582 .941 .913 r
.66629 .43563 m .66707 .43586 L .66722 .43413 L F
.398 .556 .894 r
.66707 .43586 m .66964 .43311 L .66722 .43413 L F
.66707 .43586 m .67102 .4361 L .66964 .43311 L F
.454 .565 .878 r
.66974 .43791 m .67102 .4361 L .66707 .43586 L F
.589 .451 .662 r
.66422 .41431 m .66382 .41738 L .66198 .4177 L F
.524 .245 .434 r
.66433 .41921 m .66198 .4177 L .66382 .41738 L F
.66433 .41921 m .6618 .4197 L .66198 .4177 L F
.473 .602 .9 r
.16152 .6226 m .16544 .62564 L .1633 .62404 L F
.459 .705 .974 r
.16544 .62564 m .16572 .62393 L .1633 .62404 L F
.16544 .62564 m .16757 .62535 L .16572 .62393 L F
.581 .486 .712 r
.22731 .69613 m .22774 .69848 L .22548 .69882 L F
.423 0 .047 r
.22774 .69848 m .22375 .7004 L .22548 .69882 L F
.808 .428 0 r
.50691 .57878 m .50713 .57826 L .50441 .57651 L F
.50691 .57878 m .50791 .5803 L .50713 .57826 L F
.861 .821 .808 r
.5831 .52998 m .58514 .52721 L .58391 .52565 L F
.568 .762 .969 r
.58391 .52565 m .58776 .52648 L .58514 .52721 L F
.719 .464 .54 r
.50255 .5411 m .50576 .54367 L .5054 .54197 L F
.802 .646 .688 r
.44598 .60147 m .44639 .60474 L .45067 .60358 L F
.735 .456 .506 r
.44594 .60691 m .45067 .60358 L .44639 .60474 L F
.349 .023 .263 r
.15717 .56015 m .15857 .56142 L .15938 .55953 L F
.15717 .56015 m .15644 .56203 L .15857 .56142 L F
.613 .817 .979 r
.2061 .55598 m .20998 .55643 L .20827 .55547 L F
.638 .865 .984 r
.20827 .55547 m .20998 .55643 L .21232 .55537 L F
.844 .723 .73 r
.45462 .61961 m .4508 .61967 L .4526 .61605 L F
.708 .514 .625 r
.45315 .62175 m .4508 .61967 L .45462 .61961 L F
.454 .059 .2 r
.45607 .62005 m .45315 .62175 L .45462 .61961 L F
.375 .121 .395 r
.42291 .62621 m .42032 .62865 L .42038 .62673 L F
.963 .815 .649 r
.41153 .62616 m .41044 .62825 L .4123 .629 L F
.696 .444 .539 r
.56999 .50143 m .57245 .50172 L .57249 .49926 L F
.667 .42 .538 r
.57249 .49926 m .57642 .50154 L .57497 .49881 L F
.57249 .49926 m .57245 .50172 L .57642 .50154 L F
.866 .778 .762 r
.58148 .5294 m .5831 .52998 L .5814 .5287 L F
.861 .821 .808 r
.5831 .52998 m .58391 .52565 L .5814 .5287 L F
.273 .38 .791 r
.82057 .42312 m .82339 .42503 L .82222 .42687 L F
.589 .381 .566 r
.82339 .42503 m .82152 .42933 L .82222 .42687 L F
.679 .764 .915 r
.17329 .60979 m .17481 .6114 L .17093 .61082 L F
.55 .752 .971 r
.17535 .60937 m .17481 .6114 L .17329 .60979 L F
.17535 .60937 m .17698 .61091 L .17481 .6114 L F
.565 .744 .961 r
.8281 .40368 m .82639 .40585 L .82546 .4043 L F
.8281 .40368 m .82907 .40528 L .82639 .40585 L F
.788 .553 .581 r
.20079 .72259 m .20481 .72312 L .20484 .72008 L F
.438 .784 .998 r
.20528 .71882 m .2071 .71995 L .20484 .72008 L F
.57 .328 .51 r
.2071 .71995 m .20726 .7211 L .20484 .72008 L F
.17 .488 .902 r
.20484 .72008 m .20726 .7211 L .20528 .71882 L F
.552 .359 .573 r
.20484 .72008 m .20481 .72312 L .20726 .7211 L F
.20484 .72008 m .20481 .72312 L .20726 .7211 L F
.786 .727 .797 r
.20748 .73219 m .21021 .72952 L .20619 .72843 L F
.20748 .73219 m .20619 .72843 L .20782 .73078 L F
.728 .99 .859 r
.2053 .73274 m .20748 .73219 L .20782 .73078 L F
.583 .177 .239 r
.23367 .64439 m .23556 .64436 L .23232 .64459 L F
.219 .464 .879 r
.18384 .64026 m .18415 .638 L .18222 .63746 L F
.18384 .64026 m .1891 .6435 L .18415 .638 L F
.537 .295 .495 r
.22444 .56854 m .22744 .56542 L .22483 .56565 L F
.479 .369 .651 r
.30517 .57885 m .30338 .58051 L .30297 .57895 L F
.691 .972 .769 r
.2306 .67839 m .22838 .67959 L .22857 .67688 L F
.531 .136 .237 r
.22838 .67959 m .2306 .67839 L .22857 .67688 L F
.22838 .67959 m .23296 .67631 L .2306 .67839 L F
.22838 .67959 m .23056 .67957 L .23296 .67631 L F
.668 .295 .329 r
.23296 .67631 m .23453 .67958 L .23559 .67695 L F
.23296 .67631 m .23056 .67957 L .23453 .67958 L F
.448 .211 .462 r
.25577 .6105 m .25834 .60764 L .25567 .60804 L F
0 0 0 r
.58052 .58568 m .57942 .58935 L .57914 .58952 L F
.57942 .58935 m .57855 .59152 L .57914 .58952 L F
.485 .319 .579 r
.47919 .58023 m .48144 .57701 L .47941 .57793 L F
.83 .663 .676 r
.43538 .62537 m .43765 .62654 L .4393 .62354 L F
.43538 .62537 m .4393 .62354 L .43748 .6249 L F
.986 .898 .629 r
.43828 .62291 m .43748 .6249 L .4393 .62354 L F
.877 .573 .469 r
.53687 .57728 m .53829 .5806 L .54049 .58092 L F
.982 .828 .615 r
.53839 .58294 m .54049 .58092 L .53829 .5806 L F
.53839 .58294 m .53972 .58344 L .54049 .58092 L F
.822 .961 .9 r
.76171 .39889 m .75945 .40239 L .76213 .39949 L F
.76171 .39889 m .75869 .40144 L .75945 .40239 L F
.079 .159 .647 r
.26896 .5806 m .26959 .58403 L .27064 .58259 L F
0 0 .279 r
.26959 .58403 m .27028 .5851 L .27064 .58259 L F
.26959 .58403 m .26977 .58665 L .27028 .5851 L F
.929 .627 .449 r
.58021 .56613 m .58172 .56671 L .5803 .56631 L F
.998 .824 .48 r
.58117 .57294 m .58198 .57348 L .58176 .5668 L F
.859 .731 .721 r
.57825 .57127 m .58134 .5696 L .58021 .56613 L F
.878 .844 .383 r
.58198 .57348 m .58284 .57209 L .58176 .5668 L F
.58176 .5668 m .58176 .5668 L .58176 .5668 L F
.58198 .57348 m .58176 .5668 L .58176 .5668 L F
.998 .824 .48 r
.58117 .57294 m .58176 .5668 L .58203 .56922 L F
.859 .731 .721 r
.58134 .5696 m .58179 .56935 L .5803 .56631 L F
.58134 .5696 m .5803 .56631 L .58021 .56613 L F
.936 .68 .526 r
.58038 .56368 m .58015 .56582 L .58172 .56671 L F
.929 .627 .449 r
.58021 .56613 m .5803 .56631 L .5801 .56625 L F
.936 .68 .526 r
.58015 .56582 m .5801 .56625 L .5803 .56631 L F
.58015 .56582 m .5803 .56631 L .58172 .56671 L F
.859 .731 .721 r
.58179 .56935 m .58203 .56922 L .58021 .56613 L F
.929 .627 .449 r
.58021 .56613 m .58145 .56824 L .58172 .56671 L F
.58145 .56824 m .58203 .56922 L .58174 .5669 L F
.58145 .56824 m .58174 .5669 L .58172 .56671 L F
.878 .844 .383 r
.58198 .57348 m .58214 .57428 L .58284 .57209 L F
.689 .677 .834 r
.49041 .57138 m .48823 .57278 L .48632 .57052 L F
.544 .379 .608 r
.3076 .57371 m .30517 .57885 L .3054 .57454 L F
.83 .55 .003 r
.5327 .55837 m .53364 .56195 L .53351 .56 L F
.731 .207 0 r
.51449 .54589 m .51598 .54646 L .51564 .54525 L F
.614 .834 .984 r
.50433 .59267 m .50799 .59301 L .50692 .5918 L F
.715 .297 .253 r
.50604 .59486 m .50799 .59301 L .50433 .59267 L F
.992 .836 .586 r
.50692 .5918 m .50799 .59301 L .50604 .59486 L F
.609 .261 .355 r
.23663 .62487 m .24002 .62279 L .23686 .6236 L F
.23663 .62487 m .23907 .6254 L .24002 .62279 L F
.294 0 .222 r
.24002 .62279 m .24116 .62463 L .24171 .62247 L F
.24002 .62279 m .23907 .6254 L .24116 .62463 L F
.546 .633 .889 r
.73966 .40163 m .7412 .40473 L .74382 .40416 L F
.772 .399 .35 r
.56636 .51439 m .56466 .51606 L .56274 .51372 L F
.819 .47 .395 r
.56636 .51439 m .56716 .51681 L .56466 .51606 L F
.725 .507 .596 r
.83878 .40835 m .84069 .40845 L .83651 .40848 L F
.455 .225 .474 r
.84069 .40845 m .83754 .41207 L .83651 .40848 L F
.84069 .40845 m .84055 .41071 L .83754 .41207 L F
.702 .654 .798 r
.84151 .40464 m .84069 .40845 L .83878 .40835 L F
.627 .367 .504 r
.84307 .41028 m .84055 .41071 L .84069 .40845 L F
.842 .76 .248 r
.58072 .58248 m .58126 .58092 L .58172 .57914 L F
.58072 .58248 m .58083 .58337 L .58126 .58092 L F
.524 .16 .292 r
.4526 .61605 m .45484 .61618 L .45581 .61391 L F
.557 .256 .413 r
.45484 .61618 m .45822 .61315 L .45581 .61391 L F
.717 .407 .453 r
.24101 .66116 m .24528 .65951 L .24297 .66012 L F
.24101 .66116 m .24313 .66225 L .24528 .65951 L F
.362 .831 .884 r
.24528 .65951 m .24437 .65895 L .24297 .66012 L F
.424 .319 .631 r
.24672 .65625 m .24714 .65891 L .24528 .65951 L F
.362 .831 .884 r
.24528 .65951 m .24714 .65891 L .24437 .65895 L F
.355 .07 .336 r
.48055 .61643 m .48335 .61339 L .48178 .61496 L F
.525 .323 .548 r
.29854 .60455 m .29602 .60757 L .29631 .60512 L F
.918 .523 .211 r
.53933 .58653 m .54007 .58858 L .541 .58765 L F
.072 0 0 r
.54254 .58801 m .541 .58765 L .54007 .58858 L F
.54254 .58801 m .54391 .58663 L .541 .58765 L F
.206 0 .163 r
.23663 .62487 m .23686 .6236 L .23439 .62599 L F
.389 .211 .514 r
.30683 .55835 m .30497 .55938 L .30526 .55761 L F
.307 .755 .96 r
.5427 .59557 m .54546 .59541 L .54645 .59602 L F
.54645 .59602 m .54546 .59541 L .5427 .59557 L F
.478 .303 .565 r
.434 .64677 m .43298 .64997 L .43168 .64776 L F
.938 .605 .377 r
.50236 .574 m .50269 .57614 L .50409 .5748 L F
.926 .582 .362 r
.50409 .5748 m .50269 .57614 L .50441 .57651 L F
.782 .747 .821 r
.43196 .65286 m .4294 .65611 L .43386 .65618 L F
.597 .099 .042 r
.4294 .65611 m .43181 .65771 L .43386 .65618 L F
.399 .476 .824 r
.43386 .65618 m .43364 .65334 L .43196 .65286 L F
.43386 .65618 m .43555 .65578 L .43364 .65334 L F
0 .057 .591 r
.43548 .65836 m .43386 .65618 L .43555 .65578 L F
.803 .558 .567 r
.43181 .65771 m .43555 .65578 L .43386 .65618 L F
.399 .476 .824 r
.43364 .65334 m .43555 .65578 L .43386 .65618 L F
.442 .155 .38 r
.27544 .62896 m .27264 .63146 L .27325 .6295 L F
0 0 .342 r
.51493 .62581 m .51452 .62835 L .51434 .62572 L F
.974 .664 .315 r
.23118 .65837 m .23251 .65944 L .23097 .65605 L F
.23097 .65605 m .23251 .65944 L .23118 .65837 L F
.199 0 0 r
.43353 .57631 m .43695 .57433 L .43479 .57414 L F
.752 .931 .583 r
.46884 .56689 m .468 .56878 L .47019 .56562 L F
.768 .996 .85 r
.46884 .56689 m .4672 .56855 L .468 .56878 L F
.907 .542 .334 r
.49877 .55046 m .49712 .55021 L .4962 .5476 L F
.45 0 0 r
.50103 .55082 m .49712 .55021 L .49877 .55046 L F
.283 .766 .92 r
.7877 .43692 m .78635 .43761 L .78541 .43621 L F
.7877 .43692 m .78886 .43725 L .78635 .43761 L F
.343 .414 .79 r
.25145 .55541 m .25176 .55271 L .2493 .55328 L F
.925 .824 .366 r
.41483 .64145 m .41477 .63775 L .41746 .64046 L F
.41483 .64145 m .4143 .64025 L .41477 .63775 L F
0 0 .043 r
.41483 .64145 m .41521 .64248 L .4143 .64025 L F
.41483 .64145 m .4143 .64393 L .41521 .64248 L F
.857 .637 .604 r
.41774 .61751 m .42099 .61718 L .4205 .61651 L F
.41774 .61751 m .41946 .61828 L .42099 .61718 L F
.787 .999 .837 r
.42251 .61456 m .4205 .61651 L .42099 .61718 L F
.891 .696 .633 r
.57044 .53496 m .5688 .53132 L .57037 .53247 L F
.222 0 0 r
.23232 .64459 m .23556 .64436 L .23442 .64463 L F
.08 0 0 r
.23556 .64436 m .23451 .64469 L .23442 .64463 L F
.71 .394 .44 r
.43866 .61007 m .4414 .61053 L .43886 .60795 L F
.636 .406 .552 r
.43886 .60795 m .4414 .61053 L .44214 .60803 L F
.59 .577 .807 r
.80892 .41227 m .81149 .41178 L .80831 .41038 L F
.635 .222 .243 r
.44987 .64209 m .45123 .64353 L .44915 .6435 L F
.225 .202 .622 r
.45051 .64183 m .45123 .64353 L .44987 .64209 L F
.45051 .64183 m .45123 .64353 L .44987 .64209 L F
.753 .835 .914 r
.76711 .41371 m .76825 .4143 L .76704 .41249 L F
.791 .294 0 r
.76711 .41371 m .76787 .41541 L .76825 .4143 L F
.222 .695 .939 r
.76787 .41541 m .77155 .41627 L .76825 .4143 L F
.355 .461 .83 r
.79632 .40202 m .79791 .4055 L .7996 .40349 L F
.487 .659 .937 r
.7996 .40349 m .79791 .4055 L .80017 .40528 L F
.862 .882 .85 r
.66187 .43259 m .6586 .43376 L .66035 .43165 L F
.852 .863 .849 r
.66187 .43259 m .66325 .42821 L .66448 .42993 L F
.66187 .43259 m .66035 .43165 L .66325 .42821 L F
.212 .543 .928 r
.80095 .39652 m .79914 .39616 L .79829 .39471 L F
.603 .371 .538 r
.51175 .59599 m .51181 .59846 L .50912 .59833 L F
0 0 .276 r
.51831 .61619 m .51703 .62019 L .51554 .61671 L F
0 0 .519 r
.51554 .61671 m .51644 .61882 L .51649 .61868 L F
0 .077 .638 r
.51649 .61868 m .51504 .61546 L .51554 .61671 L F
.964 .919 .711 r
.51735 .61332 m .51554 .61671 L .51504 .61546 L F
.604 .395 .57 r
.51831 .61619 m .51554 .61671 L .51735 .61332 L F
0 .077 .638 r
.51649 .61868 m .51695 .61774 L .51504 .61546 L F
.555 .928 .796 r
.51649 .61868 m .51494 .61912 L .51673 .61789 L F
.51649 .61868 m .51673 .61789 L .51695 .61774 L F
0 0 .519 r
.51644 .61882 m .51703 .62019 L .51649 .61868 L F
.92 .791 .701 r
.51624 .62239 m .51649 .61868 L .51703 .62019 L F
0 0 .276 r
.51831 .61619 m .51818 .61875 L .51703 .62019 L F
0 0 0 r
.51704 .62076 m .51703 .62019 L .51818 .61875 L F
.51704 .62076 m .51624 .62239 L .51703 .62019 L F
.407 .168 .437 r
.81201 .42643 m .81442 .42576 L .81438 .4237 L F
.335 .019 .272 r
.81442 .42576 m .8164 .42391 L .81438 .4237 L F
.548 .359 .577 r
.23646 .67768 m .2388 .68002 L .23635 .68037 L F
.697 .159 0 r
.23681 .67908 m .23646 .67768 L .23559 .67695 L F
.499 .264 .489 r
.23453 .67958 m .23681 .67908 L .23559 .67695 L F
.38 .84 .896 r
.23605 .67895 m .23681 .67908 L .23467 .67918 L F
.697 .159 0 r
.23681 .67908 m .23809 .67931 L .23646 .67768 L F
.23681 .67908 m .2388 .68002 L .23809 .67931 L F
.881 .874 .825 r
.24097 .67676 m .2388 .68002 L .23741 .67937 L F
.23779 .67854 m .23741 .67937 L .23681 .67908 L F
.24097 .67676 m .23741 .67937 L .23779 .67854 L F
.899 .987 .746 r
.23872 .6745 m .24138 .67157 L .24074 .67407 L F
0 0 0 r
.24022 .67457 m .23872 .6745 L .24074 .67407 L F
.899 .987 .746 r
.23872 .6745 m .24066 .67037 L .24138 .67157 L F
.58 .122 .129 r
.23872 .6745 m .23815 .677 L .23659 .67513 L F
.37 0 0 r
.23659 .67513 m .23752 .6752 L .23872 .6745 L F
.899 .987 .746 r
.23872 .6745 m .23752 .6752 L .24066 .67037 L F
.664 .648 .825 r
.23884 .67522 m .24028 .67524 L .23996 .67483 L F
0 0 0 r
.2386 .67612 m .24019 .67528 L .24097 .67676 L F
.23996 .67483 m .24074 .67407 L .24091 .67604 L F
.23996 .67483 m .24091 .67604 L .24097 .67676 L F
.459 .424 .732 r
.24197 .67281 m .24097 .67676 L .24074 .67407 L F
.357 .044 .291 r
.24028 .67524 m .2386 .67612 L .24106 .67525 L F
0 0 0 r
.2386 .67612 m .23866 .67528 L .23884 .67522 L F
.357 .044 .291 r
.23884 .67522 m .2386 .67612 L .24028 .67524 L F
0 0 0 r
.2386 .67612 m .23884 .67522 L .23996 .67483 L F
.2386 .67612 m .23815 .677 L .23872 .6745 L F
.357 .044 .291 r
.23752 .6752 m .2386 .67612 L .23884 .67522 L F
0 0 0 r
.2386 .67612 m .23996 .67483 L .24019 .67528 L F
.664 .648 .825 r
.23996 .67483 m .24106 .67525 L .24067 .67457 L F
.24028 .67524 m .24106 .67525 L .23996 .67483 L F
.23752 .6752 m .23786 .66978 L .24066 .67037 L F
.287 .453 .851 r
.23786 .66978 m .24067 .67457 L .24053 .67123 L F
.24067 .67457 m .24106 .67525 L .24098 .67458 L F
0 0 .156 r
.24197 .67281 m .24105 .67376 L .24138 .67157 L F
.24105 .67376 m .24074 .67407 L .24116 .67244 L F
.24105 .67376 m .24116 .67244 L .24138 .67157 L F
.287 .453 .851 r
.24067 .67457 m .24098 .67458 L .24053 .67123 L F
.761 .984 .905 r
.24098 .6746 m .24061 .67386 L .24053 .67123 L F
.24106 .67525 m .24095 .67491 L .24098 .6746 L F
.24095 .67491 m .24061 .67386 L .24098 .6746 L F
0 0 0 r
.23996 .67483 m .2389 .67455 L .24022 .67457 L F
.2389 .67455 m .23872 .6745 L .24022 .67457 L F
.23866 .67528 m .23872 .6745 L .23996 .67483 L F
.664 .648 .825 r
.23752 .6752 m .23884 .67522 L .23786 .66978 L F
.23884 .67522 m .24067 .67457 L .23786 .66978 L F
.881 .874 .825 r
.24097 .67676 m .23681 .67908 L .23899 .67845 L F
.24097 .67676 m .23899 .67845 L .2386 .67612 L F
.761 .984 .905 r
.24106 .67525 m .2386 .67612 L .24061 .67386 L F
.531 .423 .676 r
.23899 .67845 m .24061 .67386 L .23917 .67549 L F
.23868 .67657 m .23917 .67549 L .2386 .67612 L F
.23899 .67845 m .23917 .67549 L .23868 .67657 L F
.38 .84 .896 r
.23899 .67845 m .23681 .67908 L .23605 .67895 L F
.571 .573 .816 r
.8407 .41311 m .83754 .41207 L .84055 .41071 L F
.828 .882 .882 r
.7585 .4116 m .75447 .41312 L .75707 .41007 L F
.828 .796 .821 r
.76101 .40859 m .7585 .4116 L .75707 .41007 L F
.45 .351 .651 r
.81303 .42898 m .81442 .42576 L .81201 .42643 L F
.744 .858 .933 r
.21381 .68747 m .21232 .68847 L .21516 .68612 L F
.732 .536 .627 r
.8164 .42391 m .82057 .42312 L .82029 .42065 L F
.638 .585 .779 r
.82029 .42065 m .82185 .4164 L .81924 .41715 L F
.82029 .42065 m .823 .42015 L .82185 .4164 L F
.611 .449 .637 r
.82057 .42312 m .823 .42015 L .82029 .42065 L F
.537 .672 .925 r
.24075 .55387 m .24172 .55153 L .23929 .55179 L F
.24075 .55387 m .24319 .55342 L .24172 .55153 L F
.536 .714 .954 r
.24075 .55387 m .24401 .55451 L .24319 .55342 L F
.47 .672 .952 r
.30761 .54889 m .30813 .55018 L .30644 .55052 L F
.558 .357 .565 r
.30879 .55278 m .30644 .55052 L .30813 .55018 L F
.30879 .55278 m .30639 .55356 L .30644 .55052 L F
.362 .681 .978 r
.29935 .54593 m .29934 .54828 L .29819 .5461 L F
.304 0 .253 r
.49956 .60192 m .49762 .60259 L .49682 .60457 L F
.285 .419 .822 r
.77192 .42475 m .7736 .42845 L .77063 .42711 L F
0 .447 .842 r
.79712 .39373 m .79513 .39352 L .79402 .39263 L F
.79712 .39373 m .79829 .39471 L .79513 .39352 L F
0 0 0 r
.47322 .56353 m .47286 .56254 L .47525 .56208 L F
.47322 .56353 m .47168 .56514 L .47286 .56254 L F
.772 .916 .936 r
.19569 .74637 m .19568 .74846 L .19482 .75047 L F
.19569 .74637 m .1976 .74705 L .19568 .74846 L F
0 .157 .694 r
.19735 .7499 m .19568 .74846 L .1976 .74705 L F
.047 .161 .662 r
.75243 .41951 m .75353 .42215 L .7529 .41855 L F
.801 .621 .658 r
.6717 .42048 m .66959 .42269 L .66769 .42004 L F
.6717 .42048 m .67087 .42265 L .66959 .42269 L F
.509 .34 .587 r
.30263 .59172 m .30253 .5957 L .30064 .59615 L F
.615 .604 .816 r
.30438 .58924 m .30588 .59276 L .30263 .59172 L F
.387 .241 .558 r
.30461 .59441 m .30263 .59172 L .30588 .59276 L F
.30461 .59441 m .30253 .5957 L .30263 .59172 L F
.042 0 .311 r
.26795 .59 m .26752 .59247 L .26917 .58905 L F
0 .575 .721 r
.23232 .64459 m .23324 .64457 L .2322 .64645 L F
.23232 .64459 m .23442 .64463 L .23324 .64457 L F
.399 .26 .574 r
.4296 .58092 m .43167 .58047 L .43147 .57777 L F
.653 .514 .682 r
.43353 .58223 m .4296 .58092 L .43167 .58047 L F
.43353 .58223 m .43043 .58438 L .4296 .58092 L F
.628 .307 .408 r
.42821 .58234 m .43167 .58047 L .4296 .58092 L F
.418 .838 .963 r
.45735 .61621 m .46171 .61657 L .45822 .61315 L F
.45735 .61621 m .45889 .61579 L .46171 .61657 L F
.45889 .61579 m .45966 .61562 L .46171 .61657 L F
.457 .859 .967 r
.46171 .61657 m .46134 .6164 L .46243 .61486 L F
.46134 .6164 m .4596 .61559 L .46243 .61486 L F
.579 .588 .826 r
.46243 .61486 m .46079 .61785 L .4596 .61559 L F
.46243 .61486 m .46079 .61785 L .4596 .61559 L F
.701 .249 .176 r
.45812 .61404 m .46243 .61486 L .4596 .61559 L F
.45812 .61404 m .46041 .61615 L .46243 .61486 L F
.624 .318 .432 r
.46041 .61615 m .46284 .61427 L .46243 .61486 L F
.46284 .61427 m .46408 .61331 L .46243 .61486 L F
.511 .131 .256 r
.4643 .61593 m .46079 .61785 L .4625 .617 L F
.4643 .61593 m .46337 .61783 L .46079 .61785 L F
.579 .588 .826 r
.46233 .61503 m .46337 .61783 L .46079 .61785 L F
.46243 .61486 m .46247 .615 L .46233 .61503 L F
.46247 .615 m .46337 .61783 L .46233 .61503 L F
.418 .838 .963 r
.45889 .61579 m .4596 .61559 L .45966 .61562 L F
.703 .171 0 r
.76325 .3823 m .766 .38327 L .76409 .38159 L F
.734 .7 .819 r
.83878 .40835 m .8353 .40527 L .83801 .40445 L F
.83878 .40835 m .83651 .40848 L .8353 .40527 L F
.786 .777 .845 r
.84151 .40464 m .83878 .40835 L .83801 .40445 L F
.479 .615 .908 r
.18263 .61577 m .18226 .61736 L .18067 .61374 L F
.18263 .61577 m .1842 .61694 L .18226 .61736 L F
.613 .547 .757 r
.81245 .41386 m .81304 .41723 L .8155 .41646 L F
.913 .833 .753 r
.56692 .56937 m .5656 .57132 L .56507 .56816 L F
.944 .641 .436 r
.4305 .65956 m .42876 .66118 L .42705 .65801 L F
.4305 .65956 m .43062 .66209 L .42876 .66118 L F
.72 .453 .522 r
.43403 .66171 m .43062 .66209 L .4305 .65956 L F
.737 .676 .791 r
.7485 .38304 m .74954 .3865 L .74709 .38697 L F
.866 .68 .648 r
.74954 .3865 m .74803 .38965 L .74709 .38697 L F
.617 .605 .815 r
.75249 .3852 m .74954 .3865 L .7485 .38304 L F
.75 .632 .73 r
.2071 .71995 m .21099 .72001 L .2085 .72335 L F
.445 0 0 r
.21079 .72065 m .21099 .72001 L .2071 .71995 L F
.555 .803 .991 r
.21136 .71835 m .21099 .72001 L .21079 .72065 L F
.21136 .71835 m .21268 .71962 L .21099 .72001 L F
.413 .307 .624 r
.41777 .62882 m .41797 .63173 L .41553 .63218 L F
.464 .31 .586 r
.41779 .63427 m .41553 .63218 L .41797 .63173 L F
.41779 .63427 m .41604 .63535 L .41553 .63218 L F
.845 .7 .702 r
.58175 .51357 m .58582 .51677 L .58483 .51392 L F
.58175 .51357 m .58124 .51607 L .58582 .51677 L F
.846 .69 .688 r
.58124 .51607 m .58285 .51959 L .58582 .51677 L F
.915 .951 .609 r
.82152 .42933 m .82108 .42829 L .81884 .43388 L F
.589 .381 .566 r
.82339 .42503 m .82108 .42829 L .82152 .42933 L F
0 .501 .769 r
.24317 .5372 m .24519 .53759 L .24697 .53811 L F
.243 .718 .939 r
.24519 .53759 m .24913 .53815 L .24697 .53811 L F
.537 .779 .987 r
.78241 .4492 m .78368 .44756 L .78079 .44746 L F
.78241 .4492 m .78466 .44881 L .78368 .44756 L F
.878 .467 .237 r
.53048 .52403 m .52927 .52502 L .52856 .52323 L F
.066 0 0 r
.53048 .52403 m .53095 .52421 L .52927 .52502 L F
.339 .337 .71 r
.48314 .61842 m .48055 .61643 L .48477 .6172 L F
.621 .588 .795 r
.48692 .61433 m .48477 .6172 L .48335 .61339 L F
.629 .121 .024 r
.48477 .6172 m .48632 .61908 L .48314 .61842 L F
.608 .57 .786 r
.48692 .61433 m .48741 .61714 L .48477 .6172 L F
.508 .11 .22 r
.48741 .61714 m .48632 .61908 L .48477 .6172 L F
.957 .726 .548 r
.51767 .6075 m .51708 .60989 L .5193 .61055 L F
.961 .816 .384 r
.51708 .60989 m .51735 .61332 L .5193 .61055 L F
.81 .986 .885 r
.76365 .39655 m .76213 .39949 L .76494 .3971 L F
.819 1 .806 r
.76365 .39655 m .76171 .39889 L .76213 .39949 L F
0 .237 .636 r
.22198 .70203 m .2223 .70218 L .22025 .70104 L F
.499 .247 .463 r
.4061 .60772 m .40971 .60487 L .40651 .60503 L F
.948 .641 .423 r
.42062 .67993 m .42229 .6803 L .42052 .67711 L F
.96 .709 .512 r
.42062 .67993 m .42237 .67765 L .42052 .67711 L F
.42062 .67993 m .42229 .6803 L .42237 .67765 L F
0 0 .529 r
.4143 .64393 m .41576 .64739 L .4155 .64615 L F
0 0 .087 r
.41576 .64739 m .41587 .64822 L .4155 .64615 L F
.41576 .64739 m .41592 .64984 L .41587 .64822 L F
.96 .709 .512 r
.42237 .67765 m .42062 .67993 L .42052 .67711 L F
.42237 .67765 m .42229 .6803 L .42062 .67993 L F
.934 .62 .421 r
.51027 .58381 m .51089 .587 L .51215 .58718 L F
.935 .571 .289 r
.51126 .58864 m .51215 .58718 L .51089 .587 L F
.51126 .58864 m .51284 .5894 L .51215 .58718 L F
.18 .348 .796 r
.40784 .62915 m .40917 .63257 L .41016 .63092 L F
.061 .186 .682 r
.40917 .63257 m .41091 .63471 L .41016 .63092 L F
.586 .04 0 r
.51388 .55904 m .51061 .55643 L .51201 .55762 L F
.412 0 0 r
.25705 .55683 m .25477 .55693 L .25308 .55617 L F
.398 .854 .877 r
.25771 .55594 m .25705 .55683 L .25925 .55699 L F
.25771 .55594 m .25477 .55693 L .25705 .55683 L F
.445 .872 .925 r
.2281 .62882 m .22591 .62954 L .22303 .62946 L F
0 0 0 r
.20675 .53785 m .20634 .53814 L .20822 .53868 L F
.20675 .53785 m .20386 .53881 L .20634 .53814 L F
.68 .686 .848 r
.16556 .59969 m .16213 .59879 L .1647 .59781 L F
.059 .276 .767 r
.16617 .59842 m .16556 .59969 L .1647 .59781 L F
.16617 .59842 m .16757 .6014 L .16556 .59969 L F
.176 .301 .754 r
.16556 .59969 m .16757 .6014 L .16675 .60201 L F
.951 .795 .653 r
.40605 .61712 m .40656 .62049 L .40547 .61945 L F
.40605 .61712 m .40489 .6198 L .40656 .62049 L F
.561 .009 0 r
.40696 .62123 m .40858 .62226 L .40656 .62049 L F
.657 .291 .338 r
.22483 .55158 m .22432 .55196 L .22002 .55283 L F
.22432 .55196 m .22105 .55403 L .22002 .55283 L F
.519 .387 .641 r
.22002 .55283 m .22059 .55545 L .21838 .55601 L F
.657 .291 .338 r
.22432 .55196 m .22123 .55425 L .22105 .55403 L F
.177 .212 .66 r
.22002 .55283 m .22123 .55425 L .22142 .55165 L F
.919 .913 .797 r
.22142 .55165 m .22059 .55545 L .22002 .55283 L F
.22142 .55165 m .21924 .55474 L .21962 .55494 L F
.22088 .55414 m .21962 .55494 L .22059 .55545 L F
.22142 .55165 m .21962 .55494 L .22088 .55414 L F
.5 .86 .617 r
.22548 .55084 m .22483 .55158 L .22713 .5504 L F
.22548 .55084 m .22123 .55425 L .22483 .55158 L F
.69 .479 .596 r
.5662 .49912 m .56622 .5017 L .56999 .50143 L F
.263 .188 .58 r
.46323 .6267 m .46282 .62977 L .4645 .62808 L F
.422 .368 .693 r
.46439 .62964 m .4658 .63261 L .46282 .62977 L F
.576 .443 .663 r
.46739 .63107 m .46439 .62964 L .46863 .62909 L F
.46739 .63107 m .4658 .63261 L .46439 .62964 L F
.379 .362 .714 r
.46282 .62977 m .4658 .63261 L .4645 .62808 L F
.697 .653 .802 r
.22493 .55559 m .22666 .55913 L .224 .55895 L F
.22493 .55559 m .224 .55895 L .22208 .5591 L F
.967 .731 .528 r
.22235 .55637 m .22208 .5591 L .22059 .55545 L F
.697 .653 .802 r
.22493 .55559 m .22234 .55877 L .22235 .55637 L F
.22234 .55877 m .22208 .5591 L .22211 .55876 L F
.22234 .55877 m .22211 .55876 L .22235 .55637 L F
.039 .603 .787 r
.224 .55895 m .22666 .55913 L .22281 .55879 L F
.22252 .55878 m .22281 .55879 L .22195 .55871 L F
.224 .55895 m .22281 .55879 L .22252 .55878 L F
.34 .726 .984 r
.22655 .55787 m .22666 .55913 L .22493 .55559 L F
.22655 .55787 m .22829 .5589 L .22666 .55913 L F
.663 .626 .803 r
.22059 .55545 m .222 .5589 L .22343 .55609 L F
.222 .5589 m .22208 .5591 L .22218 .55888 L F
.222 .5589 m .22218 .55888 L .22343 .55609 L F
.911 .952 .811 r
.22343 .55609 m .22208 .5591 L .22195 .55871 L F
.34 .726 .984 r
.22294 .5588 m .22655 .55787 L .22195 .55871 L F
.22666 .55913 m .2266 .55842 L .22294 .5588 L F
.2266 .55842 m .22655 .55787 L .22294 .5588 L F
.22666 .55913 m .22829 .5589 L .22655 .55787 L F
.005 .281 .781 r
.77457 .43825 m .77687 .44011 L .77501 .43693 L F
0 .125 .675 r
.77457 .43825 m .77705 .4421 L .77687 .44011 L F
0 0 0 r
.53751 .51369 m .53926 .51279 L .54062 .51151 L F
.58 .316 .481 r
.53643 .51527 m .53926 .51279 L .53751 .51369 L F
.515 .031 .045 r
.54624 .58523 m .54869 .58536 L .55 .58383 L F
.95 .629 .384 r
.55 .58383 m .54869 .58536 L .55048 .58602 L F
.604 .344 .497 r
.49175 .59508 m .48865 .59587 L .48963 .59231 L F
.724 .354 .349 r
.49156 .59462 m .49175 .59508 L .48963 .59231 L F
.539 .37 .6 r
.44354 .602 m .44604 .59878 L .44338 .59937 L F
.658 .58 .756 r
.72382 .39894 m .72712 .39938 L .72604 .39564 L F
.884 .701 .651 r
.58395 .51091 m .58483 .51392 L .58524 .51166 L F
.58395 .51091 m .58175 .51357 L .58483 .51392 L F
.394 .688 .978 r
.81449 .40022 m .81298 .40158 L .81213 .40016 L F
.81449 .40022 m .81544 .40157 L .81298 .40158 L F
.791 .64 .694 r
.58395 .51091 m .58524 .51166 L .58367 .50798 L F
.409 .385 .721 r
.16757 .6014 m .16665 .60419 L .16675 .60201 L F
.554 .323 .519 r
.72925 .39308 m .73213 .39196 L .72834 .39017 L F
.755 .719 .819 r
.20481 .72312 m .2085 .72335 L .20726 .7211 L F
.187 .408 .845 r
.20726 .7211 m .2085 .72335 L .20914 .72176 L F
.377 .635 .956 r
.20914 .72176 m .2085 .72335 L .21049 .72329 L F
0 .392 .793 r
.75198 .38089 m .75136 .38253 L .74992 .37999 L F
.75198 .38089 m .7548 .38221 L .75325 .38103 L F
.75198 .38089 m .75325 .38103 L .75136 .38253 L F
.949 .636 .406 r
.76643 .38555 m .76773 .38418 L .766 .38327 L F
.76643 .38555 m .76802 .38649 L .76773 .38418 L F
.275 .478 .876 r
.16813 .62692 m .16897 .6254 L .16757 .62535 L F
.16813 .62692 m .171 .62851 L .16897 .6254 L F
.781 .56 .6 r
.43024 .63659 m .43209 .63833 L .43195 .63489 L F
.43195 .63489 m .43209 .63833 L .43024 .63659 L F
.493 .336 .596 r
.43195 .63489 m .43479 .63711 L .43412 .63432 L F
.43195 .63489 m .43209 .63833 L .43479 .63711 L F
.43195 .63489 m .43479 .63711 L .43412 .63432 L F
.43195 .63489 m .43209 .63833 L .43479 .63711 L F
0 0 .516 r
.24066 .67037 m .24089 .67046 L .24138 .67157 L F
0 0 .156 r
.24197 .67281 m .24138 .67157 L .24089 .67046 L F
.71 .632 .768 r
.75353 .42215 m .75492 .42399 L .75755 .42265 L F
.625 .382 .53 r
.45375 .62645 m .45308 .62932 L .45498 .62868 L F
.768 .461 0 r
.51711 .60622 m .51767 .6075 L .51698 .60496 L F
.788 .947 .926 r
.21049 .72329 m .21345 .72243 L .21323 .72229 L F
.039 .603 .787 r
.224 .55895 m .22195 .55871 L .22208 .5591 L F
.586 .453 .666 r
.81958 .44131 m .8214 .44344 L .81818 .44402 L F
.017 0 0 r
.82092 .44047 m .82035 .44106 L .81816 .44149 L F
.82035 .44106 m .82033 .44108 L .82009 .44112 L F
.82035 .44106 m .82009 .44112 L .81816 .44149 L F
.614 .857 .496 r
.82262 .43827 m .82059 .44075 L .82092 .44047 L F
.017 0 0 r
.82033 .44108 m .81976 .44125 L .81816 .44149 L F
.253 .102 .474 r
.81816 .44149 m .81976 .44125 L .82027 .43996 L F
.586 .453 .666 r
.82027 .43996 m .82054 .4408 L .81978 .4412 L F
.82054 .4408 m .82033 .44108 L .81958 .44131 L F
.82061 .44099 m .8214 .44344 L .81958 .44131 L F
.017 0 0 r
.82033 .44108 m .82023 .44118 L .81976 .44125 L F
.253 .102 .474 r
.81976 .44125 m .82023 .44118 L .82027 .43996 L F
.586 .453 .666 r
.82027 .43996 m .81978 .4412 L .81958 .44131 L F
.614 .857 .496 r
.82054 .4408 m .82033 .44108 L .82035 .44106 L F
.586 .453 .666 r
.82054 .4408 m .82061 .44099 L .82033 .44108 L F
.614 .857 .496 r
.82059 .44075 m .82023 .44118 L .82033 .44108 L F
.82059 .44075 m .82033 .44108 L .82054 .4408 L F
.82059 .44075 m .82035 .44106 L .82092 .44047 L F
.763 .684 .775 r
.82258 .43946 m .82225 .44058 L .82101 .44019 L F
.82068 .44098 m .82061 .44099 L .82027 .43996 L F
.801 .55 .558 r
.82027 .43996 m .82023 .44118 L .82059 .44075 L F
.82027 .43996 m .82059 .44075 L .82262 .43827 L F
.763 .684 .775 r
.82225 .44058 m .82068 .44098 L .82027 .43996 L F
.82137 .43973 m .82101 .44019 L .82027 .43996 L F
.82258 .43946 m .82101 .44019 L .82137 .43973 L F
.82225 .44058 m .8214 .44344 L .82061 .44099 L F
.764 .293 .126 r
.51632 .54789 m .5193 .54793 L .51838 .54627 L F
.51632 .54789 m .51966 .54913 L .5193 .54793 L F
.621 .5 .694 r
.41622 .62341 m .41946 .61828 L .4164 .62022 L F
.976 .799 .598 r
.58297 .5651 m .5837 .56279 L .58216 .56156 L F
.845 .574 .53 r
.68792 .42305 m .68802 .42545 L .69152 .42607 L F
.825 .746 .777 r
.68802 .42545 m .68899 .42904 L .69152 .42607 L F
.576 .594 .834 r
.24401 .55451 m .24571 .55244 L .24319 .55342 L F
.24401 .55451 m .2459 .5542 L .24571 .55244 L F
.764 .486 .512 r
.57497 .49881 m .57642 .50154 L .57862 .50169 L F
.596 .823 .986 r
.18806 .64 m .19064 .64167 L .19265 .64064 L F
.103 0 0 r
.80372 .43483 m .80661 .43424 L .80711 .43354 L F
0 0 0 r
.80711 .43354 m .80874 .43286 L .80967 .43299 L F
.80711 .43354 m .80661 .43424 L .80874 .43286 L F
.828 .796 .821 r
.76101 .40859 m .75707 .41007 L .75987 .40738 L F
.882 .887 .832 r
.76347 .4055 m .76101 .40859 L .75987 .40738 L F
.083 0 0 r
.16941 .57167 m .1673 .57441 L .16602 .5749 L F
.71 .396 .444 r
.17152 .57422 m .1673 .57441 L .16941 .57167 L F
.694 .396 .467 r
.17216 .57196 m .17152 .57422 L .16941 .57167 L F
.105 .649 .839 r
.8126 .44789 m .81338 .44824 L .81578 .4482 L F
.563 .859 .545 r
.4694 .55993 m .47052 .55863 L .47089 .55834 L F
.208 0 0 r
.468 .55972 m .47052 .55863 L .4694 .55993 L F
.972 .721 .298 r
.77097 .40339 m .77172 .40223 L .77107 .40095 L F
.77097 .40339 m .7718 .40464 L .77172 .40223 L F
.503 .772 .992 r
.77172 .40223 m .77429 .40174 L .77107 .40095 L F
.7 .493 .604 r
.41709 .61248 m .41893 .61353 L .41911 .61099 L F
.004 .059 .567 r
.41929 .64289 m .41941 .64592 L .41811 .64433 L F
.091 .077 .546 r
.41941 .64592 m .4185 .64696 L .41811 .64433 L F
.882 .887 .832 r
.76347 .4055 m .75987 .40738 L .76259 .40429 L F
.876 .925 .853 r
.76599 .40269 m .76347 .4055 L .76259 .40429 L F
0 .001 .547 r
.74709 .38697 m .74803 .38965 L .74855 .38789 L F
.74709 .38697 m .74855 .38789 L .7459 .38797 L F
.475 .445 .745 r
.3081 .56432 m .30687 .56827 L .30589 .56481 L F
.3081 .56432 m .30902 .56791 L .30687 .56827 L F
.529 .424 .679 r
.30979 .57082 m .30687 .56827 L .30902 .56791 L F
.30979 .57082 m .30738 .5726 L .30687 .56827 L F
.514 .851 .996 r
.20822 .53868 m .21033 .53805 L .2123 .53877 L F
.021 .594 .725 r
.21033 .53805 m .21442 .53805 L .2123 .53877 L F
.577 .004 0 r
.27352 .53784 m .27766 .53944 L .27536 .53951 L F
.878 .772 .741 r
.57167 .52339 m .56805 .52524 L .56962 .52197 L F
.57167 .52339 m .57016 .52626 L .56805 .52524 L F
.726 .534 .631 r
.43626 .58065 m .43353 .58223 L .43167 .58047 L F
.43626 .58065 m .43591 .58343 L .43353 .58223 L F
.734 .541 .632 r
.43991 .58308 m .43591 .58343 L .43626 .58065 L F
.178 .713 .801 r
.24913 .53815 m .25138 .53784 L .25313 .53781 L F
.189 .711 .87 r
.25138 .53784 m .2553 .53796 L .25313 .53781 L F
.691 .652 .806 r
.8265 .42256 m .82937 .42021 L .82567 .41971 L F
.806 .928 .915 r
.68287 .43334 m .68381 .43432 L .68665 .43207 L F
.629 .641 .843 r
.65593 .43678 m .65705 .43894 L .65964 .43813 L F
.343 .065 .339 r
.17358 .57342 m .17216 .57196 L .17463 .57078 L F
.17358 .57342 m .17152 .57422 L .17216 .57196 L F
.479 .369 .651 r
.30517 .57885 m .30549 .58013 L .30338 .58051 L F
.52 .493 .766 r
.30647 .58327 m .30338 .58051 L .30549 .58013 L F
.353 0 0 r
.45562 .62877 m .45708 .62923 L .45889 .62923 L F
0 0 .351 r
.45976 .63021 m .45889 .62923 L .45708 .62923 L F
0 0 .129 r
.45964 .62529 m .45835 .627 L .45757 .62695 L F
.856 .507 .391 r
.45696 .62812 m .45959 .63003 L .45708 .62923 L F
.45687 .62732 m .45736 .6278 L .45696 .62812 L F
.45736 .6278 m .45959 .63003 L .45696 .62812 L F
.45959 .63003 m .45976 .63021 L .45708 .62923 L F
.45687 .62732 m .45828 .63081 L .45976 .63021 L F
0 0 .129 r
.45835 .627 m .45752 .62812 L .45754 .62765 L F
.45835 .627 m .45754 .62765 L .45757 .62695 L F
.353 0 0 r
.45498 .62868 m .45708 .62923 L .45562 .62877 L F
0 0 .433 r
.2177 .71928 m .21724 .72006 L .21607 .71592 L F
.403 .857 .876 r
.21528 .72015 m .21724 .72006 L .2177 .71928 L F
.868 .888 .847 r
.21531 .71632 m .21268 .71962 L .21136 .71835 L F
.21607 .71592 m .21508 .71701 L .21531 .71632 L F
.21508 .71701 m .21268 .71962 L .21531 .71632 L F
.21607 .71592 m .21531 .71632 L .21559 .71635 L F
.21531 .71632 m .21136 .71835 L .21559 .71635 L F
.946 .679 .218 r
.21583 .71389 m .21607 .71592 L .21559 .71635 L F
.708 .176 0 r
.21607 .71523 m .21593 .71446 L .21559 .71635 L F
.21593 .71446 m .21583 .71389 L .2157 .71514 L F
.21593 .71446 m .2157 .71514 L .21559 .71635 L F
.39 .283 .611 r
.21583 .71389 m .21769 .71599 L .21607 .71592 L F
.708 .176 0 r
.21607 .71523 m .21769 .71599 L .21583 .71389 L F
.553 .762 .975 r
.27162 .57101 m .27297 .57244 L .27387 .5705 L F
.457 .157 .368 r
.27297 .57244 m .27563 .57275 L .27599 .57168 L F
.27297 .57244 m .27271 .5738 L .27563 .57275 L F
.782 .487 .487 r
.67302 .41605 m .67645 .41438 L .67276 .41375 L F
.67302 .41605 m .67665 .41663 L .67645 .41438 L F
.777 .698 .776 r
.15265 .58948 m .15066 .59245 L .15347 .59214 L F
.757 .668 .763 r
.15265 .58948 m .15552 .5934 L .15066 .59245 L F
0 .174 .707 r
.15496 .59168 m .15552 .5934 L .15265 .58948 L F
.81 .956 .91 r
.15731 .59155 m .15552 .5934 L .15496 .59168 L F
.64 .966 .843 r
.24344 .65434 m .24084 .65624 L .24158 .65499 L F
.7 .773 .908 r
.66275 .41277 m .66422 .41431 L .66053 .41375 L F
.66275 .41277 m .66422 .41431 L .66053 .41375 L F
.621 .748 .937 r
.66275 .41277 m .66422 .41431 L .66675 .41365 L F
.447 0 0 r
.66275 .41277 m .66675 .41365 L .66422 .41431 L F
.157 0 .007 r
.15449 .56278 m .15136 .56506 L .1533 .56428 L F
.16 0 .014 r
.1533 .56428 m .15644 .56203 L .15449 .56278 L F
.957 .634 .231 r
.50946 .58543 m .51027 .58381 L .50828 .58235 L F
.50946 .58543 m .51089 .587 L .51027 .58381 L F
.523 .311 .534 r
.42842 .68035 m .43083 .67969 L .42855 .67757 L F
.58 .852 .995 r
.22235 .55637 m .22059 .55545 L .22493 .55559 L F
.657 .777 .937 r
.20977 .62686 m .20568 .62651 L .20837 .62704 L F
.481 .899 .862 r
.20998 .62628 m .20977 .62686 L .20837 .62704 L F
.20998 .62628 m .21243 .62575 L .20977 .62686 L F
.604 .394 .569 r
.74119 .39011 m .7384 .39327 L .7368 .38872 L F
.74119 .39011 m .74137 .39213 L .7384 .39327 L F
.576 .789 .98 r
.74015 .3885 m .74119 .39011 L .74334 .38928 L F
0 0 .259 r
.74198 .39108 m .74119 .39011 L .74015 .3885 L F
.74198 .39108 m .74137 .39213 L .74119 .39011 L F
.886 .622 .534 r
.45327 .6437 m .45134 .64618 L .45123 .64353 L F
.238 .557 .934 r
.45236 .64215 m .45327 .6437 L .45123 .64353 L F
.45236 .64215 m .45577 .64435 L .45327 .6437 L F
.733 .399 .414 r
.45327 .6437 m .45524 .64663 L .45134 .64618 L F
.515 .347 .592 r
.45577 .64435 m .45524 .64663 L .45327 .6437 L F
.236 0 .056 r
.53926 .51279 m .54242 .51012 L .54062 .51151 L F
.263 .188 .58 r
.46323 .6267 m .4645 .62808 L .46466 .6259 L F
.514 .776 .991 r
.19413 .75915 m .19027 .75834 L .19245 .75803 L F
.19027 .75834 m .19413 .75915 L .19209 .7611 L F
.717 .944 .639 r
.19451 .75804 m .19413 .75915 L .19245 .75803 L F
.508 .051 .104 r
.19209 .7611 m .19413 .75915 L .19529 .76053 L F
.471 .046 .151 r
.19413 .75915 m .19675 .75915 L .19529 .76053 L F
.876 .925 .853 r
.76599 .40269 m .76259 .40429 L .76503 .4014 L F
.966 .899 .706 r
.76744 .39842 m .76599 .40269 L .76503 .4014 L F
.66 .49 .643 r
.27041 .63201 m .26885 .63504 L .26688 .63476 L F
.318 .108 .429 r
.27195 .63308 m .27041 .63201 L .27264 .63146 L F
.27195 .63308 m .26885 .63504 L .27041 .63201 L F
.956 .659 .433 r
.76704 .39549 m .76365 .39655 L .76494 .3971 L F
.506 .363 .621 r
.30253 .5957 m .30063 .59842 L .30064 .59615 L F
.68 .701 .863 r
.74206 .39412 m .7384 .39327 L .74137 .39213 L F
.676 .877 .974 r
.74335 .3922 m .74206 .39412 L .74137 .39213 L F
.74335 .3922 m .74454 .39322 L .74206 .39412 L F
.944 .752 .614 r
.49932 .61878 m .50104 .62014 L .49953 .61642 L F
.607 .787 .968 r
.50396 .61975 m .50104 .62014 L .49932 .61878 L F
.71 .438 .512 r
.50433 .62223 m .50104 .62014 L .50396 .61975 L F
.50433 .62223 m .50086 .62248 L .50104 .62014 L F
.509 .777 .993 r
.53908 .60745 m .54043 .60584 L .53795 .60609 L F
.53908 .60745 m .54118 .60713 L .54043 .60584 L F
.501 .286 .519 r
.28363 .61997 m .28342 .62256 L .28094 .62305 L F
.527 .328 .554 r
.28611 .61702 m .28589 .61958 L .28363 .61997 L F
.542 .331 .544 r
.28589 .61958 m .28342 .62256 L .28363 .61997 L F
.41 .515 .855 r
.171 .62851 m .17289 .63196 L .17452 .63165 L F
.953 .798 .652 r
.57054 .5401 m .56864 .54069 L .56966 .53719 L F
.926 .783 .683 r
.57054 .5401 m .56784 .54274 L .56864 .54069 L F
.57054 .5401 m .56933 .54412 L .56784 .54274 L F
.76 .996 .828 r
.42816 .61697 m .42857 .61541 L .43067 .61488 L F
.482 0 0 r
.42857 .61541 m .4324 .61598 L .43067 .61488 L F
.392 .03 .226 r
.43067 .61488 m .4324 .61598 L .43317 .61419 L F
.241 0 .069 r
.47193 .60916 m .47039 .60857 L .47245 .60787 L F
.47193 .60916 m .4695 .60995 L .47039 .60857 L F
.789 .998 .846 r
.73625 .38132 m .73321 .38395 L .73582 .3828 L F
.325 .215 .572 r
.73737 .37781 m .73625 .38132 L .73814 .38014 L F
.527 .193 .345 r
.73847 .38259 m .73625 .38132 L .73582 .3828 L F
.73847 .38259 m .73625 .38132 L .73582 .3828 L F
.966 .899 .706 r
.76744 .39842 m .76503 .4014 L .76734 .3982 L F
.025 0 0 r
.17384 .55012 m .17417 .55154 L .17625 .5502 L F
.17384 .55012 m .17242 .5527 L .17417 .55154 L F
.494 .762 .99 r
.19577 .64341 m .19749 .6447 L .19951 .64422 L F
.728 .524 .615 r
.18342 .77103 m .18871 .77292 L .18668 .76882 L F
.267 .305 .716 r
.18668 .76882 m .18871 .77292 L .1888 .77064 L F
.802 .523 .516 r
.47639 .62314 m .47621 .62563 L .47352 .62516 L F
.532 .289 .492 r
.47869 .62518 m .47639 .62314 L .47889 .6228 L F
.47869 .62518 m .47621 .62563 L .47639 .62314 L F
.539 .37 .6 r
.44354 .602 m .44598 .60147 L .44604 .59878 L F
.604 .481 .685 r
.44354 .602 m .44639 .60474 L .44598 .60147 L F
.44354 .602 m .44387 .60515 L .44639 .60474 L F
.158 0 .161 r
.17735 .56832 m .17636 .57072 L .17463 .57078 L F
.154 0 .133 r
.17636 .57072 m .17358 .57342 L .17463 .57078 L F
.448 .221 .476 r
.28849 .61652 m .28589 .61958 L .28611 .61702 L F
.544 .239 .402 r
.26688 .63476 m .26674 .6376 L .26408 .63776 L F
.322 0 .164 r
.26885 .63504 m .26674 .6376 L .26688 .63476 L F
.502 .269 .493 r
.28307 .62486 m .28094 .62305 L .28342 .62256 L F
.28307 .62486 m .28069 .62549 L .28094 .62305 L F
.586 .453 .666 r
.82027 .43996 m .81818 .44402 L .81816 .44149 L F
0 0 0 r
.54061 .51955 m .53906 .52001 L .54133 .51911 L F
.54061 .51955 m .53801 .52096 L .53906 .52001 L F
.546 .696 .938 r
.19681 .62115 m .19593 .62322 L .19438 .62144 L F
.443 .576 .892 r
.19681 .62115 m .19792 .62336 L .19593 .62322 L F
0 0 0 r
.18256 .54745 m .18246 .54781 L .18445 .54619 L F
.18256 .54745 m .18032 .5484 L .18246 .54781 L F
.39 .284 .613 r
.73321 .38395 m .73542 .38531 L .73582 .3828 L F
.73321 .38395 m .73414 .38781 L .73542 .38531 L F
.589 .248 .358 r
.50615 .60378 m .50536 .60433 L .50394 .6046 L F
.50536 .60433 m .50365 .60551 L .50388 .60478 L F
.50536 .60433 m .50388 .60478 L .50394 .6046 L F
.568 .343 .534 r
.50912 .59833 m .50915 .60155 L .50604 .60176 L F
.672 .551 .71 r
.50915 .60155 m .50615 .60378 L .50604 .60176 L F
.585 .233 .338 r
.50288 .60604 m .50547 .60624 L .50629 .60474 L F
.358 0 .213 r
.50629 .60474 m .50547 .60624 L .50778 .60731 L F
.342 .023 .272 r
.50778 .60731 m .50547 .60624 L .50586 .60481 L F
.752 .625 .719 r
.50616 .60469 m .50626 .60466 L .5062 .6045 L F
.342 .023 .272 r
.50639 .60429 m .50617 .6045 L .50615 .60378 L F
.50617 .6045 m .50603 .60465 L .50605 .60452 L F
.50617 .6045 m .50605 .60452 L .50615 .60378 L F
.48 .483 .783 r
.5062 .6045 m .50637 .60402 L .50605 .60411 L F
.50629 .60474 m .50632 .60448 L .5062 .6045 L F
.50632 .60448 m .50637 .60402 L .5062 .6045 L F
.752 .625 .719 r
.50613 .60456 m .5062 .6045 L .50605 .60411 L F
.50616 .60469 m .5062 .6045 L .50613 .60456 L F
.342 .023 .272 r
.50603 .60465 m .50586 .60481 L .50587 .60478 L F
.50603 .60465 m .50587 .60478 L .50615 .60378 L F
.585 .233 .338 r
.50586 .60481 m .50629 .60474 L .50616 .60469 L F
.50572 .60495 m .50629 .60474 L .50586 .60481 L F
.752 .625 .719 r
.50616 .60469 m .50629 .60474 L .50626 .60466 L F
.358 0 .213 r
.50629 .60474 m .50778 .60731 L .50752 .60483 L F
.48 .483 .783 r
.50629 .60474 m .50752 .60483 L .5068 .60457 L F
.342 .023 .272 r
.50646 .60446 m .50615 .60378 L .50874 .60526 L F
.48 .483 .783 r
.50629 .60474 m .50819 .60413 L .50632 .60448 L F
.342 .023 .272 r
.50778 .60731 m .50646 .60446 L .50874 .60526 L F
.358 0 .213 r
.50752 .60483 m .50778 .60731 L .50841 .6049 L F
.342 .023 .272 r
.50874 .60526 m .50749 .60454 L .50927 .60414 L F
.50749 .60454 m .50615 .60378 L .50742 .60393 L F
.50749 .60454 m .50742 .60393 L .50927 .60414 L F
.48 .483 .783 r
.5068 .60457 m .50841 .6049 L .50819 .60413 L F
.50752 .60483 m .50841 .6049 L .5068 .60457 L F
.342 .023 .272 r
.50646 .60446 m .50617 .60451 L .50639 .60429 L F
.672 .551 .71 r
.50915 .60155 m .50927 .60414 L .50615 .60378 L F
.48 .483 .783 r
.50632 .60448 m .50819 .60413 L .50687 .59959 L F
.342 .023 .272 r
.50778 .60731 m .50586 .60481 L .50617 .60451 L F
.50778 .60731 m .50617 .60451 L .50646 .60446 L F
.585 .233 .338 r
.50288 .60604 m .50572 .60495 L .50586 .60481 L F
.589 .248 .358 r
.50365 .60551 m .50392 .60562 L .50288 .60604 L F
.50615 .60378 m .50587 .60478 L .50365 .60551 L F
.50587 .60478 m .50547 .60624 L .50365 .60551 L F
.50365 .60551 m .50288 .60604 L .50299 .6059 L F
.50365 .60551 m .50299 .6059 L .50394 .6046 L F
.585 .233 .338 r
.50288 .60604 m .50616 .60469 L .50171 .60317 L F
.589 .248 .358 r
.50392 .60562 m .50547 .60624 L .50288 .60604 L F
.752 .625 .719 r
.50547 .60445 m .50616 .60469 L .50605 .60411 L F
.48 .483 .783 r
.50605 .60411 m .50687 .59959 L .50469 .60057 L F
.50637 .60402 m .50687 .59959 L .50605 .60411 L F
.752 .625 .719 r
.50171 .60317 m .50547 .60445 L .50469 .60057 L F
.50547 .60445 m .50605 .60411 L .50469 .60057 L F
.523 .379 .627 r
.26289 .59864 m .26541 .59818 L .26524 .59529 L F
.391 .234 .545 r
.26319 .60164 m .26541 .59818 L .26289 .59864 L F
.3 .782 .914 r
.21442 .53805 m .21659 .5377 L .2184 .53795 L F
.061 .6 .853 r
.21879 .53761 m .2184 .53795 L .21659 .5377 L F
.21879 .53761 m .22061 .5382 L .2184 .53795 L F
.909 .866 .428 r
.73142 .39451 m .7322 .39351 L .73213 .39196 L F
.767 .76 .249 r
.41606 .6168 m .41619 .61558 L .41709 .61248 L F
.057 .403 .857 r
.41606 .6168 m .41774 .61751 L .41619 .61558 L F
.454 .565 .878 r
.66974 .43791 m .67206 .43824 L .67102 .4361 L F
.319 .767 .959 r
.17816 .63709 m .18036 .63775 L .18222 .63746 L F
.835 .66 .666 r
.58183 .54394 m .58489 .54247 L .58035 .54035 L F
.304 .476 .865 r
.77705 .4421 m .77836 .44037 L .77687 .44011 L F
.77705 .4421 m .78015 .44338 L .77836 .44037 L F
.71 .632 .768 r
.75353 .42215 m .75755 .42265 L .75624 .41971 L F
.522 .527 .801 r
.75755 .42265 m .759 .41863 L .75624 .41971 L F
.75755 .42265 m .76018 .42237 L .759 .41863 L F
0 .173 .703 r
.4828 .56568 m .48352 .5646 L .48131 .56224 L F
.59 .259 .376 r
.48477 .56568 m .48515 .5675 L .4828 .56568 L F
.008 .274 .774 r
.4828 .56568 m .48515 .5675 L .48352 .5646 L F
.392 .09 .328 r
.26118 .6048 m .26266 .60647 L .26293 .60407 L F
.26118 .6048 m .26043 .60706 L .26266 .60647 L F
.497 .841 .996 r
.47109 .59878 m .4732 .59805 L .47503 .59858 L F
.624 .455 .633 r
.4732 .59805 m .47758 .59975 L .47503 .59858 L F
.602 .836 .457 r
.27105 .57778 m .26896 .5806 L .26983 .57937 L F
.199 .19 .623 r
.26896 .5806 m .27064 .58259 L .26983 .57937 L F
.114 0 .232 r
.15779 .58291 m .1561 .58414 L .15846 .5808 L F
.541 .274 .46 r
.15779 .58291 m .15468 .58557 L .1561 .58414 L F
.743 .419 .434 r
.21813 .70778 m .21256 .70954 L .2155 .70611 L F
.21813 .70778 m .21713 .70977 L .21256 .70954 L F
.941 .69 .53 r
.21483 .70947 m .21813 .70778 L .2155 .70611 L F
.21483 .70947 m .21713 .70977 L .21813 .70778 L F
.578 .809 .987 r
.55732 .57954 m .55871 .58076 L .55683 .58049 L F
.873 .892 .844 r
.55871 .58076 m .55483 .58279 L .55488 .58022 L F
.695 .851 .958 r
.56041 .57951 m .55871 .58076 L .55732 .57954 L F
.56041 .57951 m .55732 .57954 L .55972 .57897 L F
.562 .769 .975 r
.55972 .57897 m .55732 .57954 L .55836 .57752 L F
0 0 0 r
.55732 .57954 m .55664 .58144 L .55831 .57764 L F
.55732 .57954 m .55831 .57764 L .55836 .57752 L F
.578 .809 .987 r
.55732 .57954 m .55683 .58049 L .55488 .58022 L F
.561 .064 .034 r
.42108 .62034 m .42219 .62079 L .42553 .62036 L F
.42219 .62079 m .42397 .62152 L .42428 .62129 L F
.42219 .62079 m .42428 .62129 L .42553 .62036 L F
0 .307 .737 r
.42261 .62119 m .42372 .6217 L .42176 .62069 L F
.61 .495 .698 r
.42219 .62079 m .42261 .62119 L .42108 .62034 L F
0 .307 .737 r
.42261 .62119 m .42176 .62069 L .42108 .62034 L F
.61 .495 .698 r
.42219 .62079 m .42217 .62093 L .42261 .62119 L F
.42217 .62093 m .42189 .62341 L .42261 .62119 L F
.41946 .61828 m .42219 .62079 L .42108 .62034 L F
.41946 .61828 m .42046 .62039 L .42219 .62079 L F
.42046 .62039 m .42189 .62341 L .42219 .62079 L F
.561 .064 .034 r
.42108 .62034 m .42372 .6217 L .42397 .62152 L F
.549 .157 .25 r
.42723 .62128 m .42565 .62256 L .42553 .62036 L F
.563 .066 .035 r
.42553 .62036 m .42372 .6217 L .42723 .62128 L F
.56 .83 .475 r
.16002 .57892 m .15846 .5808 L .16085 .57795 L F
.422 .294 .601 r
.16002 .57892 m .1604 .58238 L .15846 .5808 L F
.559 .268 .43 r
.1604 .58238 m .15779 .58291 L .15846 .5808 L F
.374 .224 .546 r
.55629 .60649 m .55532 .60889 L .5579 .60769 L F
.55574 .60785 m .5525 .60937 L .55532 .60889 L F
.55507 .60741 m .5525 .60937 L .55574 .60785 L F
.55629 .60649 m .55507 .60741 L .55574 .60785 L F
.55629 .60649 m .55504 .60947 L .5525 .60937 L F
.959 .715 .525 r
.55306 .6061 m .55285 .60853 L .55504 .60947 L F
.55298 .60595 m .55297 .60604 L .55306 .6061 L F
.55297 .60604 m .55285 .60853 L .55306 .6061 L F
.307 .328 .719 r
.27012 .57417 m .27105 .57778 L .27209 .57627 L F
.129 0 .255 r
.26983 .57937 m .27209 .57627 L .27105 .57778 L F
.783 .998 .846 r
.65566 .43319 m .65494 .43246 L .65454 .43147 L F
.487 .883 .957 r
.66035 .43165 m .65818 .43205 L .65958 .428 L F
.53 .492 .758 r
.65795 .43194 m .65566 .43319 L .65789 .43192 L F
.6582 .43206 m .65813 .43209 L .65795 .43194 L F
.65813 .43209 m .65566 .43319 L .65795 .43194 L F
.794 .704 .766 r
.65958 .428 m .65795 .43194 L .65595 .42755 L F
.65795 .43194 m .65788 .4321 L .65792 .43192 L F
.487 .883 .957 r
.65818 .43205 m .65788 .4321 L .65795 .43194 L F
.65818 .43205 m .65795 .43194 L .65958 .428 L F
.53 .492 .758 r
.65837 .43198 m .6582 .43206 L .65789 .43192 L F
.666 .576 .745 r
.65788 .4321 m .65837 .43198 L .65792 .43192 L F
.53 .492 .758 r
.65789 .43192 m .65566 .43319 L .65454 .43147 L F
.666 .576 .745 r
.65788 .4321 m .65792 .43192 L .65454 .43147 L F
.794 .704 .766 r
.65792 .43192 m .65788 .4321 L .65774 .43177 L F
.65795 .43194 m .65774 .43177 L .65595 .42755 L F
.53 .492 .758 r
.65837 .43198 m .6586 .43376 L .65566 .43319 L F
.589 .266 .39 r
.2323 .6871 m .23122 .689 L .22868 .68884 L F
.064 0 .075 r
.2339 .68621 m .23122 .689 L .2323 .6871 L F
.923 .752 .652 r
.58297 .55245 m .58411 .55593 L .58493 .55369 L F
.589 .793 .977 r
.7379 .38593 m .73702 .38684 L .73719 .38279 L F
.531 .098 .163 r
.45438 .56584 m .45315 .56764 L .45645 .56719 L F
.497 .135 .283 r
.45438 .56584 m .45645 .56719 L .45701 .56557 L F
.016 .132 .642 r
.4012 .62283 m .40284 .6246 L .4024 .62229 L F
.656 .302 .361 r
.43991 .58308 m .43815 .58565 L .43591 .58343 L F
.359 0 0 r
.44227 .58369 m .43815 .58565 L .43991 .58308 L F
.488 .875 .684 r
.16278 .57707 m .16002 .57892 L .16085 .57795 L F
.512 .66 .927 r
.82459 .40253 m .82296 .40457 L .82156 .40248 L F
.82459 .40253 m .82546 .4043 L .82296 .40457 L F
.646 .405 .539 r
.51169 .60106 m .50912 .59833 L .51181 .59846 L F
.51169 .60106 m .50915 .60155 L .50912 .59833 L F
.622 .703 .903 r
.81924 .41715 m .82092 .41358 L .81815 .4156 L F
.81924 .41715 m .82185 .4164 L .82092 .41358 L F
0 .111 .658 r
.42816 .61697 m .42964 .61922 L .42857 .61541 L F
.572 .58 .823 r
.30791 .59193 m .30588 .59276 L .30438 .58924 L F
.323 0 .054 r
.30734 .59382 m .30588 .59276 L .30791 .59193 L F
.30734 .59382 m .30461 .59441 L .30588 .59276 L F
.474 .067 .188 r
.43353 .58223 m .42912 .58446 L .43043 .58438 L F
.555 .089 .102 r
.7433 .37644 m .74058 .37509 L .73947 .37606 L F
.596 .429 .626 r
.40182 .61395 m .40528 .61416 L .40472 .6112 L F
0 0 0 r
.40227 .61644 m .40528 .61416 L .40182 .61395 L F
.193 .53 .922 r
.77805 .43276 m .77582 .43106 L .77734 .43138 L F
.279 .47 .868 r
.78085 .43237 m .77805 .43276 L .77734 .43138 L F
.78085 .43237 m .78127 .43424 L .77805 .43276 L F
.46 .888 .834 r
.79278 .44567 m .79094 .4469 L .79364 .44577 L F
.79278 .44567 m .79037 .4468 L .79094 .4469 L F
.856 .762 .757 r
.68597 .42856 m .68899 .42904 L .68802 .42545 L F
.847 .781 .787 r
.68665 .43207 m .68899 .42904 L .68597 .42856 L F
.471 .188 .402 r
.27848 .62604 m .2778 .62859 L .27544 .62896 L F
.426 .148 .387 r
.28069 .62549 m .2778 .62859 L .27848 .62604 L F
.621 .5 .694 r
.41622 .62341 m .42189 .62341 L .41946 .61828 L F
.658 .531 .698 r
.41685 .62554 m .42189 .62341 L .41622 .62341 L F
.478 .598 .894 r
.17638 .63485 m .17639 .63162 L .17452 .63165 L F
.17638 .63485 m .17829 .6345 L .17639 .63162 L F
.641 .806 .962 r
.15736 .6224 m .16152 .6226 L .15942 .62206 L F
.488 .843 .994 r
.16152 .6226 m .16194 .62154 L .15942 .62206 L F
.019 .304 .796 r
.16152 .6226 m .1633 .62404 L .16194 .62154 L F
.841 .974 .667 r
.56222 .57605 m .56391 .57475 L .56178 .57799 L F
.842 .981 .692 r
.56222 .57605 m .56178 .57799 L .56041 .57951 L F
.663 .418 .538 r
.49971 .54339 m .50255 .5411 L .49979 .54118 L F
.49971 .54339 m .50247 .54413 L .50255 .5411 L F
.719 .464 .54 r
.50255 .5411 m .50247 .54413 L .50576 .54367 L F
.957 .727 .549 r
.51215 .53082 m .51341 .5348 L .51405 .5319 L F
.684 .428 .529 r
.51405 .5319 m .51341 .5348 L .51581 .53437 L F
.351 .046 .3 r
.55035 .51411 m .55 .51597 L .54753 .51671 L F
.517 .219 .4 r
.55279 .51361 m .55 .51597 L .55035 .51411 L F
.932 .969 .699 r
.27841 .57105 m .27997 .5677 L .27875 .56861 L F
.645 .708 .893 r
.16046 .59685 m .16213 .59879 L .15843 .5979 L F
.655 .711 .89 r
.1647 .59781 m .16213 .59879 L .16046 .59685 L F
.369 .168 .471 r
.65728 .41389 m .6592 .4108 L .65754 .41123 L F
.517 .409 .671 r
.16658 .60587 m .16467 .61094 L .16489 .61075 L F
.912 .51 .196 r
.52557 .57403 m .52297 .57093 L .52443 .57188 L F
.919 .74 .644 r
.56898 .55065 m .56664 .55225 L .56727 .5497 L F
.56898 .55065 m .56842 .55319 L .56664 .55225 L F
.236 .754 .788 r
.23451 .64469 m .23821 .64405 L .24062 .64352 L F
.443 .164 .393 r
.24809 .62006 m .25049 .61947 L .25126 .61652 L F
.328 .061 .348 r
.25126 .61652 m .25251 .6186 L .25359 .61599 L F
.25126 .61652 m .25049 .61947 L .25251 .6186 L F
.36 .225 .558 r
.44703 .63753 m .44935 .63384 L .44716 .63499 L F
0 0 .172 r
.51481 .53829 m .51581 .53437 L .51341 .5348 L F
.509 0 0 r
.51457 .53935 m .51476 .53963 L .51481 .53829 L F
.702 .414 .484 r
.49765 .61618 m .49932 .61878 L .49953 .61642 L F
.49765 .61618 m .49712 .61937 L .49932 .61878 L F
.228 .737 .887 r
.26149 .53775 m .26376 .53754 L .26544 .53782 L F
.266 .771 .86 r
.26376 .53754 m .26764 .53721 L .26544 .53782 L F
.569 .412 .629 r
.30753 .5619 m .30497 .55938 L .30683 .55835 L F
.30753 .5619 m .30494 .56253 L .30497 .55938 L F
.184 0 .168 r
.19135 .55922 m .19023 .56142 L .18849 .56208 L F
.497 .878 .682 r
.19361 .55918 m .19023 .56142 L .19135 .55922 L F
.309 0 0 r
.76802 .38649 m .7711 .38762 L .7715 .38751 L F
.43 0 0 r
.7711 .38762 m .77556 .38972 L .7715 .38751 L F
.828 .553 .522 r
.77962 .39746 m .7826 .39544 L .78201 .39469 L F
.77962 .39746 m .78318 .39834 L .7826 .39544 L F
.875 .987 .824 r
.78413 .39321 m .7826 .39544 L .78573 .3929 L F
.78413 .39321 m .78201 .39469 L .7826 .39544 L F
.823 .663 .685 r
.58395 .51091 m .58015 .5073 L .58001 .50997 L F
.58395 .51091 m .58367 .50798 L .58015 .5073 L F
.857 .655 .628 r
.58001 .50997 m .58175 .51357 L .58395 .51091 L F
.738 .306 .224 r
.67665 .41663 m .67927 .4189 L .68037 .4174 L F
.746 .315 .228 r
.67927 .4189 m .68286 .41965 L .68037 .4174 L F
.751 .287 .147 r
.68037 .4174 m .68286 .41965 L .68431 .4198 L F
.947 .83 .695 r
.56823 .55907 m .56663 .55844 L .56791 .55574 L F
.971 .766 .57 r
.56823 .55907 m .56642 .56177 L .56663 .55844 L F
.56823 .55907 m .56791 .56239 L .56642 .56177 L F
.569 .744 .959 r
.28594 .53991 m .2853 .54216 L .284 .54006 L F
.28594 .53991 m .28754 .54156 L .2853 .54216 L F
.552 .402 .631 r
.47085 .60134 m .4732 .59805 L .47109 .59878 L F
.267 .743 .936 r
.2553 .53796 m .25747 .53782 L .25925 .53832 L F
0 0 0 r
.25747 .53782 m .26149 .53775 L .25925 .53832 L F
.638 .904 .983 r
.21186 .64632 m .21352 .64694 L .21474 .64627 L F
.572 .7 .929 r
.80831 .41038 m .80904 .40719 L .80695 .40706 L F
.80831 .41038 m .81093 .40964 L .80904 .40719 L F
.564 .587 .835 r
.80831 .41038 m .81149 .41178 L .81093 .40964 L F
.869 .681 .646 r
.57906 .53689 m .58249 .53478 L .57921 .53424 L F
.57906 .53689 m .58078 .53778 L .58249 .53478 L F
.652 .214 .196 r
.27563 .57275 m .27801 .57354 L .27599 .57168 L F
.485 .26 .497 r
.27599 .57168 m .27801 .57354 L .27841 .57105 L F
.175 .424 .86 r
.78573 .3929 m .78687 .39137 L .78413 .39321 L F
.78573 .3929 m .78877 .39436 L .78687 .39137 L F
.409 .385 .721 r
.16757 .6014 m .16881 .60464 L .16665 .60419 L F
.783 .606 .66 r
.17018 .60749 m .16703 .61046 L .16658 .60587 L F
.458 .106 .28 r
.16665 .60419 m .16754 .60647 L .16658 .60587 L F
.16665 .60419 m .16881 .60464 L .16754 .60647 L F
.545 .555 .816 r
.81245 .41386 m .81475 .41283 L .81149 .41178 L F
.613 .547 .757 r
.81245 .41386 m .8155 .41646 L .81475 .41283 L F
.428 .275 .57 r
.30647 .58327 m .3056 .58679 L .30435 .58672 L F
.454 .29 .569 r
.3056 .58679 m .30438 .58924 L .30435 .58672 L F
.277 0 .253 r
.1486 .56747 m .15033 .56776 L .15136 .56506 L F
.258 0 .231 r
.1486 .56747 m .14952 .56966 L .15033 .56776 L F
.1486 .56747 m .14757 .57047 L .14952 .56966 L F
0 0 0 r
.26917 .58905 m .27028 .5851 L .26977 .58665 L F
.385 .417 .771 r
.51144 .53397 m .51215 .53082 L .50953 .53168 L F
.51144 .53397 m .51341 .5348 L .51215 .53082 L F
.314 0 0 r
.19739 .55831 m .19613 .5591 L .19361 .55918 L F
0 0 0 r
.20022 .55735 m .19613 .5591 L .19739 .55831 L F
0 .283 .718 r
.49149 .5777 m .49229 .57783 L .49047 .57656 L F
.49149 .5777 m .49424 .57924 L .49229 .57783 L F
.718 .474 .555 r
.51581 .53437 m .51996 .53518 L .51957 .53227 L F
.317 .193 .549 r
.51957 .53227 m .51996 .53518 L .52109 .53323 L F
.618 .549 .755 r
.72712 .39938 m .72882 .39489 L .72604 .39564 L F
.72712 .39938 m .72974 .39872 L .72882 .39489 L F
.738 .988 .789 r
.51021 .60653 m .51066 .60516 L .51058 .60522 L F
0 0 .507 r
.50927 .60414 m .51001 .60723 L .51021 .60653 L F
.738 .988 .789 r
.51021 .60653 m .50778 .60731 L .50927 .60414 L F
.51021 .60653 m .51058 .60522 L .50778 .60731 L F
0 0 .507 r
.51001 .60723 m .51043 .60899 L .51021 .60653 L F
.322 .797 .917 r
.47768 .55901 m .48005 .5586 L .48201 .55877 L F
0 0 .46 r
.48208 .55872 m .48201 .55877 L .48005 .5586 L F
.48208 .55872 m .48493 .56262 L .48201 .55877 L F
.348 .115 .413 r
.22799 .68364 m .22748 .686 L .2299 .68294 L F
.01 0 0 r
.24549 .62002 m .24171 .62247 L .24401 .62215 L F
.428 .017 .154 r
.24708 .62118 m .24549 .62002 L .24401 .62215 L F
.462 0 .065 r
.24708 .62118 m .24809 .62006 L .24549 .62002 L F
.513 .064 .122 r
.45553 .57508 m .45175 .57642 L .45329 .57534 L F
.668 .759 .918 r
.66697 .42891 m .66448 .42993 L .66325 .42821 L F
.471 .129 .303 r
.19081 .54354 m .19303 .54345 L .19418 .54166 L F
.872 .812 .787 r
.56507 .56816 m .5656 .57132 L .56402 .57072 L F
.941 .906 .759 r
.5656 .57132 m .56273 .57352 L .56402 .57072 L F
.5656 .57132 m .56391 .57475 L .56273 .57352 L F
.597 .576 .801 r
.7529 .41855 m .75353 .42215 L .75624 .41971 L F
.793 .944 .596 r
.50212 .59816 m .49956 .60192 L .50222 .60151 L F
.553 .826 .473 r
.50461 .59522 m .50212 .59816 L .50452 .59781 L F
.546 .378 .605 r
.50222 .60151 m .50452 .59781 L .50212 .59816 L F
.16 .7 .746 r
.22061 .5382 m .22283 .53781 L .22448 .53761 L F
.058 .623 .721 r
.22283 .53781 m .22673 .53759 L .22448 .53761 L F
.733 .664 .783 r
.83321 .42114 m .83564 .41994 L .83171 .41953 L F
.613 .592 .805 r
.27012 .57417 m .27162 .57101 L .26951 .57152 L F
.27012 .57417 m .27271 .5738 L .27162 .57101 L F
.307 .328 .719 r
.27012 .57417 m .27209 .57627 L .27271 .5738 L F
.266 0 0 r
.27766 .53944 m .27982 .54 L .28173 .54018 L F
.619 .943 .949 r
.28173 .54018 m .28214 .5388 L .284 .54006 L F
.28173 .54018 m .27982 .54 L .28214 .5388 L F
.46 .845 .983 r
.1976 .74705 m .2006 .74636 L .19795 .74594 L F
0 0 .014 r
.19735 .7499 m .1976 .74705 L .19795 .74594 L F
.623 .306 .412 r
.4946 .59486 m .49156 .59462 L .49483 .59213 L F
.079 0 .049 r
.49712 .59014 m .49657 .5916 L .49483 .59213 L F
.189 0 .354 r
.49657 .5916 m .4946 .59486 L .49483 .59213 L F
0 0 .126 r
.49606 .59349 m .4946 .59486 L .49464 .5948 L F
.49606 .59349 m .49464 .5948 L .49657 .5916 L F
.292 .256 .646 r
.49617 .59003 m .49608 .59288 L .49657 .5916 L F
.49608 .59288 m .49606 .59349 L .49657 .5916 L F
.079 0 .049 r
.49761 .58972 m .49657 .5916 L .49712 .59014 L F
.133 0 .079 r
.49931 .58935 m .49657 .5916 L .49761 .58972 L F
.822 .907 .898 r
.49617 .59003 m .49657 .5916 L .49931 .58935 L F
.292 .256 .646 r
.49617 .59003 m .49735 .59231 L .49606 .59349 L F
.49735 .59231 m .49798 .59353 L .49606 .59349 L F
.621 .35 .486 r
.44351 .60707 m .44639 .60474 L .44387 .60515 L F
.01 0 0 r
.22748 .55062 m .22713 .5504 L .22934 .55069 L F
.22748 .55062 m .22548 .55084 L .22713 .5504 L F
0 .56 .723 r
.55504 .60947 m .55174 .6093 L .5525 .60937 L F
.543 .454 .704 r
.2159 .69783 m .21817 .69921 L .21639 .69478 L F
.689 .677 .834 r
.49041 .57138 m .48632 .57052 L .48956 .56749 L F
.546 .003 0 r
.49041 .57138 m .49128 .57246 L .48888 .57301 L F
.49041 .57138 m .49289 .57359 L .49128 .57246 L F
.528 .69 .941 r
.54766 .60775 m .54345 .606 L .54646 .60772 L F
.755 .481 .518 r
.49375 .54747 m .49604 .54792 L .4962 .5476 L F
.797 .494 .476 r
.4962 .5476 m .49348 .54931 L .49375 .54747 L F
.4962 .5476 m .49712 .55021 L .49348 .54931 L F
.547 .231 .385 r
.46818 .60387 m .47072 .6037 L .4686 .60192 L F
.481 .248 .483 r
.4686 .60192 m .47072 .6037 L .47085 .60134 L F
.97 .79 .604 r
.19571 .76738 m .19616 .77018 L .19288 .77153 L F
.192 0 0 r
.19288 .77153 m .19616 .77018 L .19505 .77116 L F
.766 .894 .491 r
.19616 .77018 m .19738 .76752 L .19762 .76981 L F
.135 0 .042 r
.19616 .77018 m .19747 .77069 L .19505 .77116 L F
.19616 .77018 m .19762 .76981 L .19747 .77069 L F
.488 .058 .148 r
.8164 .42391 m .81969 .42446 L .82057 .42312 L F
.662 .204 .155 r
.81969 .42446 m .82339 .42503 L .82057 .42312 L F
.537 .295 .495 r
.22444 .56854 m .22718 .56807 L .22744 .56542 L F
.432 .26 .547 r
.25362 .61379 m .25533 .61516 L .25562 .61288 L F
.25362 .61379 m .25359 .61599 L .25533 .61516 L F
.59 .362 .539 r
.45759 .63511 m .45664 .63793 L .45411 .63823 L F
.752 .587 .671 r
.45964 .63599 m .45759 .63511 L .45876 .63422 L F
.45964 .63599 m .45664 .63793 L .45759 .63511 L F
.915 .724 .63 r
.67087 .42265 m .66807 .42451 L .66959 .42269 L F
.67087 .42265 m .67 .42617 L .66807 .42451 L F
.437 .576 .895 r
.21901 .68672 m .22285 .68954 L .22124 .68618 L F
.65 .668 .854 r
.22285 .68954 m .22349 .68564 L .22124 .68618 L F
.22285 .68954 m .22557 .68906 L .22349 .68564 L F
.517 .409 .671 r
.16658 .60587 m .16703 .61046 L .16467 .61094 L F
.443 .216 .474 r
.49003 .54128 m .48969 .5436 L .49232 .54069 L F
0 .209 .735 r
.53424 .59864 m .53659 .60073 L .53461 .5976 L F
.491 .263 .495 r
.44214 .60803 m .44387 .60963 L .44351 .60707 L F
.44214 .60803 m .4414 .61053 L .44387 .60963 L F
.887 .496 .045 r
.53692 .579 m .53687 .57728 L .53647 .5763 L F
.53692 .579 m .53829 .5806 L .53687 .57728 L F
.529 .42 .674 r
.15468 .58557 m .15265 .58948 L .15277 .58678 L F
.678 .337 0 r
.53161 .58661 m .53131 .58596 L .53016 .58305 L F
.979 .717 .316 r
.53161 .58661 m .53072 .5875 L .53131 .58596 L F
.53161 .58661 m .5317 .58899 L .53072 .5875 L F
.945 .734 .586 r
.57016 .52626 m .56794 .52779 L .56805 .52524 L F
.57016 .52626 m .56982 .52905 L .56794 .52779 L F
.996 .833 .564 r
.56273 .57352 m .56391 .57475 L .56222 .57605 L F
.638 .592 .786 r
.46862 .62517 m .47352 .62516 L .4733 .62344 L F
.371 .14 .429 r
.47352 .62516 m .47497 .62247 L .4733 .62344 L F
.582 .648 .881 r
.73234 .39805 m .7338 .40134 L .7362 .40067 L F
.586 .651 .881 r
.7338 .40134 m .73715 .40245 L .7362 .40067 L F
.568 .862 .547 r
.46622 .60504 m .46355 .60782 L .46498 .60625 L F
.516 .269 .478 r
.46498 .60625 m .46818 .60387 L .46622 .60504 L F
.097 .596 .899 r
.20804 .71929 m .2071 .71995 L .20528 .71882 L F
.2079 .71939 m .21079 .72065 L .2071 .71995 L F
.20837 .71946 m .21079 .72065 L .2079 .71939 L F
.9 .868 .798 r
.21136 .71835 m .21079 .72065 L .20804 .71929 L F
.341 0 0 r
.20914 .72176 m .2096 .72251 L .20776 .7207 L F
0 .416 .819 r
.20726 .7211 m .20914 .72176 L .20776 .7207 L F
.484 .281 .528 r
.20776 .7207 m .20911 .72203 L .20911 .72203 L F
.566 .038 0 r
.20997 .72313 m .20911 .72203 L .20776 .7207 L F
.341 0 0 r
.2096 .72251 m .20997 .72313 L .20776 .7207 L F
.484 .281 .528 r
.20776 .7207 m .20911 .72203 L .20959 .71962 L F
.9 .868 .798 r
.21136 .71835 m .20804 .71929 L .20985 .71829 L F
.484 .281 .528 r
.20879 .71951 m .20959 .71962 L .20985 .71829 L F
.20776 .7207 m .20959 .71962 L .20879 .71951 L F
.097 .596 .899 r
.20804 .71929 m .20837 .71946 L .2079 .71939 L F
.294 .506 .891 r
.14992 .61559 m .1484 .61313 L .14828 .6132 L F
.14992 .61559 m .1499 .61317 L .1484 .61313 L F
.14992 .61559 m .152 .61614 L .1499 .61317 L F
.512 .29 .515 r
.43043 .64104 m .43276 .6414 L .43296 .64102 L F
.43043 .64104 m .43024 .64343 L .43276 .6414 L F
.354 .177 .497 r
.30979 .57082 m .3076 .57371 L .30738 .5726 L F
.639 .498 .674 r
.41625 .6537 m .41717 .65595 L .41943 .65295 L F
0 0 0 r
.20022 .55735 m .19826 .55849 L .19613 .5591 L F
.20048 .55787 m .20022 .55735 L .20256 .55677 L F
.20048 .55787 m .19826 .55849 L .20022 .55735 L F
.779 .819 .884 r
.67462 .43735 m .67629 .43912 L .67784 .43735 L F
.58 .215 .314 r
.48475 .59272 m .48707 .59388 L .4887 .5915 L F
.095 0 .143 r
.4887 .5915 m .49011 .5911 L .49073 .5897 L F
.792 .637 .689 r
.48707 .59388 m .49011 .5911 L .4887 .5915 L F
.732 .667 .786 r
.83171 .41953 m .83564 .41994 L .83435 .41629 L F
.541 .557 .82 r
.83435 .41629 m .83564 .41994 L .83811 .41931 L F
0 .113 .651 r
.83564 .41994 m .83702 .42197 L .83811 .41931 L F
.472 .219 .449 r
.4779 .60318 m .47494 .60729 L .47565 .60383 L F
.639 .276 .339 r
.47076 .63042 m .46863 .62909 L .47102 .62876 L F
.47076 .63042 m .46739 .63107 L .46863 .62909 L F
.869 .779 .76 r
.20254 .74096 m .19868 .74344 L .20037 .74274 L F
.387 .255 .576 r
.20441 .74314 m .20254 .74096 L .20463 .7405 L F
.20441 .74314 m .20267 .74362 L .20254 .74096 L F
.14 0 0 r
.20463 .7405 m .20254 .74096 L .20037 .74274 L F
.46 .351 .644 r
.26951 .57152 m .27162 .57101 L .27146 .56764 L F
.322 0 .164 r
.26885 .63504 m .26895 .63702 L .26674 .6376 L F
.332 0 .165 r
.27114 .63641 m .26885 .63504 L .27195 .63308 L F
.27114 .63641 m .26895 .63702 L .26885 .63504 L F
.412 .726 .989 r
.81115 .39888 m .80897 .40024 L .80792 .3988 L F
.81115 .39888 m .81213 .40016 L .80897 .40024 L F
.426 .211 .483 r
.30063 .59842 m .30024 .60142 L .29814 .60194 L F
.506 .363 .621 r
.30253 .5957 m .30286 .59808 L .30063 .59842 L F
.542 .311 .515 r
.30288 .60077 m .30063 .59842 L .30286 .59808 L F
.30288 .60077 m .30024 .60142 L .30063 .59842 L F
.332 .571 .927 r
.27244 .53609 m .27175 .53781 L .27053 .53619 L F
.27244 .53609 m .27352 .53784 L .27175 .53781 L F
.967 .789 .61 r
.51556 .60832 m .51519 .61108 L .5136 .61079 L F
.559 .397 .618 r
.51767 .6075 m .51519 .61108 L .51556 .60832 L F
.8 .637 .679 r
.17093 .61082 m .16703 .61046 L .17018 .60749 L F
.689 .388 .46 r
.46355 .60782 m .46848 .61047 L .46498 .60625 L F
.46355 .60782 m .46297 .61146 L .46848 .61047 L F
.062 0 .289 r
.46319 .60592 m .4616 .60631 L .46338 .6054 L F
.311 .714 .978 r
.4616 .60631 m .46355 .60782 L .45992 .60673 L F
.062 0 .289 r
.4626 .60761 m .4616 .60631 L .46319 .60592 L F
.311 .714 .978 r
.4616 .60631 m .45992 .60673 L .45901 .60646 L F
.615 .748 .94 r
.8353 .40527 m .83262 .40606 L .83172 .40454 L F
.992 .876 .606 r
.75595 .37616 m .75758 .37399 L .7554 .37423 L F
.324 .026 .295 r
.14074 .5744 m .14274 .57377 L .14351 .57173 L F
.326 .028 .296 r
.14351 .57173 m .14274 .57377 L .14549 .57113 L F
.071 .262 .751 r
.20004 .73146 m .20132 .73455 L .20217 .73371 L F
.212 .494 .901 r
.20217 .73371 m .20132 .73455 L .20337 .73488 L F
.477 .447 .746 r
.49287 .58353 m .49429 .58339 L .49424 .57924 L F
.502 .315 .56 r
.49287 .58353 m .4951 .58544 L .49429 .58339 L F
.49287 .58353 m .49289 .58612 L .4951 .58544 L F
.526 .285 .493 r
.294 .61074 m .29353 .61328 L .29112 .61365 L F
.349 .171 .493 r
.29602 .60757 m .29583 .6101 L .294 .61074 L F
.319 .103 .421 r
.29583 .6101 m .29353 .61328 L .294 .61074 L F
0 0 .476 r
.53367 .59507 m .53322 .59141 L .53384 .59272 L F
.907 .813 .743 r
.68519 .43079 m .68665 .43207 L .68597 .42856 L F
.806 .928 .915 r
.68287 .43334 m .68665 .43207 L .68519 .43079 L F
.897 .714 .647 r
.56716 .51681 m .56853 .5198 L .56657 .51925 L F
.813 .539 .524 r
.56853 .5198 m .56628 .52194 L .56657 .51925 L F
.56853 .5198 m .56962 .52197 L .56628 .52194 L F
.425 .725 .988 r
.19227 .62004 m .19207 .62151 L .19009 .61957 L F
.19227 .62004 m .19438 .62144 L .19207 .62151 L F
.267 0 0 r
.41619 .61558 m .41893 .61353 L .41709 .61248 L F
.449 .82 .993 r
.1721 .60675 m .17018 .60749 L .16754 .60647 L F
.395 .187 .476 r
.47963 .59573 m .48181 .59722 L .48204 .59506 L F
.47963 .59573 m .47963 .59851 L .48181 .59722 L F
.45 .351 .651 r
.81303 .42898 m .81489 .42818 L .81442 .42576 L F
.625 .554 .755 r
.81311 .4313 m .81489 .42818 L .81303 .42898 L F
.461 .572 .88 r
.22865 .69463 m .22731 .69613 L .2254 .69366 L F
.183 .205 .648 r
.22894 .69801 m .22731 .69613 L .22865 .69463 L F
.22894 .69801 m .22774 .69848 L .22731 .69613 L F
.419 0 0 r
.48762 .56191 m .48987 .56252 L .49141 .56237 L F
.566 0 0 r
.48987 .56252 m .49375 .56487 L .49141 .56237 L F
.754 .244 0 r
.49141 .56237 m .49375 .56487 L .49562 .56536 L F
.654 .581 .761 r
.823 .42015 m .82552 .41722 L .82185 .4164 L F
.823 .42015 m .82567 .41971 L .82552 .41722 L F
.621 .748 .937 r
.66275 .41277 m .66713 .41057 L .66329 .40999 L F
.66275 .41277 m .66675 .41365 L .66713 .41057 L F
.873 .699 .663 r
.5815 .54649 m .58288 .55001 L .58346 .54747 L F
.344 .042 .302 r
.15033 .56776 m .1533 .56428 L .15136 .56506 L F
.572 .783 .978 r
.20173 .64385 m .20409 .6455 L .20543 .64478 L F
.622 .53 .729 r
.72604 .39564 m .72925 .39308 L .72495 .39207 L F
.357 .001 .215 r
.18849 .56208 m .18746 .56452 L .18508 .5651 L F
0 0 .032 r
.18903 .56339 m .18849 .56208 L .19023 .56142 L F
.18903 .56339 m .18746 .56452 L .18849 .56208 L F
.626 .842 .455 r
.77985 .40037 m .77846 .40252 L .78066 .39938 L F
.639 .873 .985 r
.77713 .40125 m .77846 .40252 L .77985 .40037 L F
.785 .55 .581 r
.43923 .64108 m .43897 .6442 L .44291 .64419 L F
.412 .821 .977 r
.74643 .39217 m .74454 .39322 L .74335 .3922 L F
.74643 .39217 m .7474 .3928 L .74454 .39322 L F
.008 .501 .868 r
.78837 .38862 m .78399 .38738 L .78342 .38669 L F
.96 .758 .586 r
.51477 .60014 m .51691 .59852 L .51538 .59761 L F
.51477 .60014 m .51645 .60119 L .51691 .59852 L F
.975 .723 .488 r
.49121 .54731 m .48966 .54659 L .48969 .5436 L F
.644 .089 0 r
.49348 .54931 m .48966 .54659 L .49121 .54731 L F
.625 .28 .365 r
.49375 .54747 m .49348 .54931 L .49121 .54731 L F
.339 .337 .71 r
.48314 .61842 m .48088 .62035 L .48055 .61643 L F
.443 .516 .838 r
.48314 .61842 m .48264 .62169 L .48088 .62035 L F
.608 .683 .896 r
.7548 .38221 m .75796 .38361 L .75754 .38049 L F
.91 .982 .738 r
.7559 .38662 m .75796 .38361 L .75838 .38625 L F
0 0 0 r
.75796 .38361 m .75951 .37923 L .75754 .38049 L F
.578 .351 .535 r
.75838 .38625 m .76119 .38314 L .75796 .38361 L F
.233 .634 .958 r
.55693 .58942 m .5575 .59029 L .55448 .58901 L F
.619 .889 .989 r
.55995 .58935 m .5575 .59029 L .55693 .58942 L F
.63 .685 .883 r
.55971 .58984 m .5575 .59029 L .55995 .58935 L F
.492 .294 .539 r
.43541 .61052 m .43707 .61287 L .43866 .61007 L F
.43541 .61052 m .43531 .61371 L .43707 .61287 L F
.621 .742 .933 r
.74608 .40431 m .7473 .40674 L .7499 .4053 L F
.756 .626 .716 r
.7368 .38872 m .7384 .39327 L .73468 .39247 L F
.423 0 .047 r
.22774 .69848 m .22597 .70034 L .22375 .7004 L F
.47 .011 .08 r
.22857 .70016 m .22774 .69848 L .22894 .69801 L F
.22857 .70016 m .22597 .70034 L .22774 .69848 L F
0 .004 .58 r
.43276 .6414 m .43231 .64024 L .43296 .64102 L F
.594 .049 0 r
.43502 .64073 m .43462 .64078 L .43522 .64049 L F
.43462 .64078 m .43296 .64102 L .43472 .6406 L F
.43462 .64078 m .43472 .6406 L .43522 .64049 L F
.723 .3 .243 r
.43445 .64108 m .4338 .64225 L .43555 .64152 L F
.594 .049 0 r
.4338 .64225 m .43344 .64171 L .43502 .64073 L F
.43344 .64171 m .43296 .64102 L .43502 .64073 L F
.723 .3 .243 r
.43231 .64024 m .4338 .64225 L .43445 .64108 L F
.732 .583 .688 r
.43479 .63711 m .43522 .64049 L .43231 .64024 L F
.705 .543 .666 r
.43231 .64024 m .43445 .64108 L .43479 .63711 L F
.916 .879 .784 r
.43727 .64017 m .43649 .64063 L .43522 .64049 L F
.705 .543 .666 r
.43445 .64108 m .43555 .64152 L .43541 .6407 L F
.43445 .64108 m .43541 .6407 L .43502 .64073 L F
.033 0 .45 r
.43526 .64317 m .434 .64677 L .43348 .6429 L F
.698 .461 .562 r
.43151 .64581 m .43526 .64317 L .43276 .6414 L F
0 0 .532 r
.43479 .63711 m .43727 .64017 L .43522 .64049 L F
.43479 .63711 m .43707 .63967 L .43727 .64017 L F
.268 .239 .64 r
.43479 .63711 m .43541 .6407 L .43707 .63967 L F
.916 .879 .784 r
.43581 .64104 m .43526 .64317 L .4338 .64225 L F
.43727 .64017 m .43542 .64294 L .43581 .64104 L F
.43542 .64294 m .43526 .64317 L .43581 .64104 L F
.268 .239 .64 r
.43541 .6407 m .43555 .64152 L .43577 .64125 L F
.43581 .64104 m .43577 .64125 L .43589 .6411 L F
.43541 .6407 m .43577 .64125 L .43581 .64104 L F
.916 .879 .784 r
.43649 .64063 m .43581 .64104 L .43541 .6407 L F
.43649 .64063 m .43502 .64073 L .43522 .64049 L F
.268 .239 .64 r
.43541 .6407 m .43589 .6411 L .43707 .63967 L F
.916 .879 .784 r
.43541 .6407 m .4338 .64225 L .43502 .64073 L F
.43581 .64104 m .4338 .64225 L .43541 .6407 L F
.705 .543 .666 r
.43502 .64073 m .43541 .6407 L .43538 .64051 L F
.43445 .64108 m .43538 .64051 L .43479 .63711 L F
.704 .579 .712 r
.27036 .56027 m .27068 .56275 L .27292 .56261 L F
.961 .816 .384 r
.51708 .60989 m .51677 .61266 L .51735 .61332 L F
.828 .473 0 r
.51677 .61266 m .51831 .61619 L .51735 .61332 L F
.805 .406 .297 r
.21373 .62858 m .21243 .62575 L .20998 .62628 L F
.792 .364 0 r
.51826 .5648 m .51759 .56453 L .51638 .56185 L F
.867 .431 .161 r
.52044 .5668 m .51759 .56453 L .51826 .5648 L F
0 .015 .581 r
.24736 .65524 m .24672 .65625 L .24571 .65283 L F
0 .058 .589 r
.24736 .65524 m .24714 .65891 L .24672 .65625 L F
.458 .597 .903 r
.84215 .41112 m .8407 .41311 L .84055 .41071 L F
.84215 .41112 m .84312 .41326 L .8407 .41311 L F
.499 .247 .463 r
.4061 .60772 m .40915 .60717 L .40971 .60487 L F
.695 .947 .667 r
.40614 .61057 m .40915 .60717 L .4061 .60772 L F
.499 .247 .463 r
.40971 .60487 m .40915 .60717 L .4061 .60772 L F
.357 .165 .478 r
.40915 .60717 m .40614 .61057 L .4061 .60772 L F
.101 .543 .912 r
.21628 .62923 m .21551 .62996 L .21373 .62858 L F
.21628 .62923 m .21775 .63037 L .21551 .62996 L F
.646 .44 .59 r
.21455 .55488 m .21732 .55301 L .21528 .55396 L F
.782 .633 .696 r
.21732 .55301 m .21476 .55495 L .21528 .55396 L F
.163 0 .164 r
.17818 .56978 m .17735 .56832 L .17939 .56767 L F
.17818 .56978 m .17636 .57072 L .17735 .56832 L F
.372 .02 .233 r
.55063 .50469 m .55286 .50417 L .55383 .5018 L F
.56 .202 .317 r
.55383 .5018 m .55286 .50417 L .55631 .50334 L F
.572 .185 .271 r
.55383 .5018 m .55631 .50334 L .55652 .50194 L F
.447 0 0 r
.54646 .51796 m .54446 .51712 L .54753 .51671 L F
.305 0 .014 r
.55 .51597 m .54646 .51796 L .54753 .51671 L F
.801 .55 .558 r
.82027 .43996 m .82262 .43827 L .82236 .43662 L F
.752 .567 .645 r
.27146 .56764 m .27444 .56537 L .27288 .56459 L F
.27146 .56764 m .27405 .56847 L .27444 .56537 L F
.585 .875 .994 r
.27502 .56379 m .27288 .56459 L .27444 .56537 L F
.386 .595 .928 r
.29574 .54348 m .29502 .54548 L .29348 .54358 L F
.29574 .54348 m .29819 .5461 L .29502 .54548 L F
.194 .159 .587 r
.40472 .6112 m .40611 .61271 L .40614 .61057 L F
.40472 .6112 m .40528 .61416 L .40611 .61271 L F
.492 .391 .669 r
.30065 .60394 m .29814 .60194 L .30024 .60142 L F
.30065 .60394 m .29854 .60455 L .29814 .60194 L F
.803 .676 .724 r
.20267 .74362 m .20385 .74717 L .2006 .74636 L F
.406 0 0 r
.2006 .74636 m .20385 .74717 L .20246 .74709 L F
0 .002 .574 r
.20419 .74577 m .20385 .74717 L .20267 .74362 L F
.704 .977 .912 r
.20246 .74709 m .20385 .74717 L .20419 .74577 L F
.905 .682 .59 r
.49825 .54051 m .49971 .54339 L .49979 .54118 L F
.45 0 0 r
.50103 .55082 m .4998 .55133 L .49712 .55021 L F
.462 0 0 r
.50103 .55082 m .50358 .55199 L .4998 .55133 L F
.704 .579 .712 r
.27036 .56027 m .27292 .56261 L .27163 .5581 L F
.779 .495 0 r
.27163 .5581 m .27292 .56261 L .27213 .56027 L F
.361 .051 .297 r
.27292 .56261 m .27309 .56119 L .27213 .56027 L F
.533 .111 .186 r
.27292 .56261 m .27426 .56302 L .2769 .56219 L F
.585 .875 .994 r
.27502 .56379 m .27292 .56261 L .2769 .56219 L F
.361 .051 .297 r
.27292 .56261 m .27502 .56379 L .27309 .56119 L F
.27292 .56261 m .27288 .56459 L .27502 .56379 L F
.551 .342 .55 r
.73737 .37781 m .74079 .37941 L .73947 .37606 L F
.73737 .37781 m .73814 .38014 L .74079 .37941 L F
.987 .779 .539 r
.53839 .58294 m .53933 .58653 L .53972 .58344 L F
.621 .672 .877 r
.7362 .40067 m .73715 .40245 L .73966 .40163 L F
.558 0 0 r
.51966 .54913 m .52174 .54994 L .52363 .55003 L F
.648 .134 .008 r
.52276 .55121 m .52363 .55003 L .52174 .54994 L F
.52276 .55121 m .52597 .55195 L .52363 .55003 L F
.453 .674 .959 r
.78379 .43419 m .78202 .43615 L .78127 .43424 L F
.78379 .43419 m .78541 .43621 L .78202 .43615 L F
.32 .02 .289 r
.41604 .63535 m .41296 .63792 L .41221 .63705 L F
0 0 .433 r
.2177 .71928 m .21607 .71592 L .21726 .71597 L F
.2177 .71928 m .21726 .71597 L .21769 .71652 L F
.52 .245 .439 r
.21769 .71599 m .21886 .71798 L .2177 .71928 L F
.805 .58 .597 r
.21607 .71523 m .21604 .71841 L .21886 .71798 L F
.21607 .71523 m .21868 .71781 L .21817 .71775 L F
.21868 .71781 m .21886 .71798 L .2188 .71796 L F
.21868 .71781 m .2188 .71796 L .21817 .71775 L F
0 0 .433 r
.21769 .71652 m .21726 .71597 L .21769 .71599 L F
.523 .664 .926 r
.80017 .40528 m .80461 .40752 L .80367 .40579 L F
.493 .723 .974 r
.80367 .40579 m .80461 .40752 L .80695 .40706 L F
.192 0 0 r
.2272 .53723 m .2297 .5372 L .22893 .53728 L F
.173 0 0 r
.22893 .53728 m .23121 .53719 L .23298 .53651 L F
.192 0 0 r
.2297 .5372 m .23121 .53719 L .22893 .53728 L F
0 0 0 r
.22821 .53734 m .22893 .53728 L .23045 .53698 L F
.22673 .53759 m .22893 .53728 L .22821 .53734 L F
.23045 .53698 m .22893 .53728 L .23298 .53651 L F
.669 .921 .612 r
.6558 .41994 m .65319 .42296 L .65444 .42104 L F
.621 .495 .688 r
.6558 .41994 m .65594 .42298 L .65319 .42296 L F
.432 .135 .359 r
.65328 .42542 m .65594 .42298 L .65319 .42296 L F
.584 .581 .815 r
.65328 .42542 m .65444 .42104 L .65319 .42296 L F
.291 0 0 r
.45925 .57426 m .45751 .5756 L .45553 .57508 L F
0 0 0 r
.4596 .57481 m .45925 .57426 L .46116 .57348 L F
.4596 .57481 m .45751 .5756 L .45925 .57426 L F
.563 .337 .531 r
.47825 .61673 m .48061 .61887 L .48055 .61643 L F
.47825 .61673 m .47803 .61946 L .48061 .61887 L F
.005 0 0 r
.53112 .51848 m .53418 .51624 L .53215 .51729 L F
.661 .285 0 r
.52566 .57449 m .5282 .57973 L .52755 .57848 L F
.8 .561 .575 r
.57642 .50154 m .5788 .5044 L .57862 .50169 L F
.783 .568 .609 r
.5788 .5044 m .58018 .5047 L .57862 .50169 L F
.474 .067 .188 r
.43353 .58223 m .43195 .5846 L .42912 .58446 L F
.706 .297 .269 r
.43591 .58343 m .43195 .5846 L .43353 .58223 L F
.119 0 0 r
.18298 .56572 m .1809 .56749 L .17939 .56767 L F
.181 0 0 r
.18396 .56636 m .18298 .56572 L .18508 .5651 L F
.18396 .56636 m .1809 .56749 L .18298 .56572 L F
.489 .9 .907 r
.79971 .43564 m .80372 .43483 L .80099 .43527 L F
.833 .436 .298 r
.43686 .62746 m .43765 .62654 L .43538 .62537 L F
.43686 .62746 m .4388 .62848 L .43765 .62654 L F
.227 0 .102 r
.16353 .55831 m .16699 .55516 L .16523 .55629 L F
.164 0 .325 r
.41119 .60398 m .40915 .60717 L .40971 .60487 L F
.41119 .60398 m .40915 .60717 L .40971 .60487 L F
.488 .394 .675 r
.43167 .58047 m .43353 .57631 L .43147 .57777 L F
.606 .225 .295 r
.26189 .63816 m .25773 .64016 L .25811 .64018 L F
.26189 .63816 m .26012 .64056 L .25773 .64016 L F
.413 .012 .166 r
.26405 .63933 m .26189 .63816 L .26408 .63776 L F
.26405 .63933 m .26012 .64056 L .26189 .63816 L F
.327 0 .09 r
.46015 .56453 m .46233 .56402 L .46349 .56285 L F
0 0 0 r
.46349 .56285 m .46233 .56402 L .46507 .56137 L F
.211 .736 .815 r
.22303 .62946 m .22195 .62982 L .22002 .62981 L F
0 0 .112 r
.40611 .61271 m .40605 .61712 L .40667 .61384 L F
.638 .681 .874 r
.16046 .59685 m .15843 .5979 L .15656 .59491 L F
.367 .653 .967 r
.2062 .62499 m .20568 .62651 L .20423 .62487 L F
.2062 .62499 m .20837 .62704 L .20568 .62651 L F
.478 .204 .42 r
.54538 .50775 m .54797 .50723 L .54815 .50515 L F
.275 0 .229 r
.54797 .50723 m .55063 .50469 L .54815 .50515 L F
.479 .137 .308 r
.1844 .7742 m .18659 .77422 L .18415 .77472 L F
.743 .45 0 r
.52228 .56826 m .52246 .56948 L .52044 .5668 L F
.52228 .56826 m .52297 .57093 L .52246 .56948 L F
.585 .322 .485 r
.50086 .62248 m .50396 .61975 L .49932 .61878 L F
.697 .398 .465 r
.50433 .62223 m .50128 .62498 L .50086 .62248 L F
.585 .322 .485 r
.50086 .62248 m .50362 .6228 L .50396 .61975 L F
.50362 .6228 m .50411 .62235 L .50396 .61975 L F
.167 .155 .599 r
.50569 .62077 m .50433 .62223 L .50396 .61975 L F
.284 .103 .451 r
.50396 .61975 m .50411 .62235 L .50569 .62077 L F
.563 .876 .589 r
.50496 .62155 m .50411 .62235 L .50433 .62223 L F
.284 .103 .451 r
.50411 .62235 m .50413 .62286 L .50569 .62077 L F
.563 .876 .589 r
.5041 .62235 m .50129 .62497 L .50322 .62322 L F
.50362 .6228 m .50129 .62497 L .5041 .62235 L F
.585 .322 .484 r
.50362 .6228 m .50128 .62498 L .50413 .62286 L F
.50086 .62248 m .50128 .62498 L .50362 .6228 L F
.563 .876 .589 r
.50411 .62235 m .50362 .6228 L .5041 .62235 L F
.50411 .62235 m .50322 .62322 L .50433 .62223 L F
.50569 .62077 m .50128 .62498 L .50129 .62497 L F
.50569 .62077 m .50129 .62497 L .50496 .62155 L F
.585 .322 .485 r
.50362 .6228 m .50413 .62286 L .50411 .62235 L F
.466 .498 .807 r
.50459 .61628 m .50396 .61975 L .50194 .61599 L F
0 .257 .766 r
.50396 .61975 m .50433 .61794 L .50194 .61599 L F
.342 .394 .771 r
.50574 .61985 m .50667 .61971 L .50746 .61815 L F
.466 .498 .807 r
.50639 .61924 m .50667 .61971 L .50597 .61972 L F
.293 .702 .974 r
.50396 .61975 m .50597 .61972 L .50574 .61985 L F
.50597 .61972 m .50667 .61971 L .50574 .61985 L F
0 0 .005 r
.506 .6197 m .50569 .62077 L .50573 .61998 L F
.401 .466 .812 r
.50746 .61815 m .50667 .61971 L .50639 .61924 L F
.50746 .61815 m .50639 .61924 L .50459 .61628 L F
0 0 .005 r
.50664 .61896 m .50639 .61924 L .50574 .61985 L F
.50639 .61924 m .50573 .61998 L .50574 .61991 L F
.50639 .61924 m .50574 .61991 L .50574 .61985 L F
.50746 .61815 m .50668 .61931 L .506 .6197 L F
.50668 .61931 m .50569 .62077 L .506 .6197 L F
.50746 .61815 m .50573 .61998 L .50664 .61896 L F
.466 .498 .807 r
.50459 .61628 m .50639 .61924 L .50396 .61975 L F
.50639 .61924 m .50597 .61972 L .50396 .61975 L F
.167 .155 .599 r
.50569 .62077 m .50396 .61975 L .50574 .61985 L F
.284 .103 .451 r
.50396 .61975 m .50569 .62077 L .50433 .61794 L F
.537 .072 .097 r
.43324 .66372 m .43062 .66209 L .43403 .66171 L F
.253 .203 .606 r
.43548 .65836 m .43578 .66053 L .43403 .66171 L F
.849 .686 .681 r
.43578 .66053 m .43324 .66372 L .43403 .66171 L F
.306 0 .082 r
.16699 .55516 m .17 .55367 L .16759 .55402 L F
.538 .435 .685 r
.48935 .61365 m .48741 .61714 L .48692 .61433 L F
.48935 .61365 m .49026 .61664 L .48741 .61714 L F
.17 0 .043 r
.48862 .61794 m .48741 .61714 L .49026 .61664 L F
.48862 .61794 m .48632 .61908 L .48741 .61714 L F
.819 .553 .537 r
.68451 .42478 m .68792 .42305 L .68478 .42221 L F
.68451 .42478 m .68802 .42545 L .68792 .42305 L F
.339 .056 .329 r
.14045 .5753 m .14274 .57377 L .14074 .5744 L F
.205 .728 .734 r
.2061 .55598 m .2047 .55624 L .20256 .55677 L F
.297 .791 .776 r
.20671 .55558 m .2061 .55598 L .20827 .55547 L F
.20671 .55558 m .2047 .55624 L .2061 .55598 L F
.699 .938 .963 r
.53372 .52353 m .53538 .52216 L .53095 .52421 L F
.568 .762 .969 r
.58391 .52565 m .58638 .52507 L .58776 .52648 L F
.58391 .52565 m .58638 .52507 L .58776 .52648 L F
.663 .798 .947 r
.59011 .52556 m .58638 .52507 L .58776 .52648 L F
.59011 .52556 m .58638 .52507 L .58776 .52648 L F
.271 0 .231 r
.48515 .5999 m .48369 .59893 L .48601 .59816 L F
.4846 .59953 m .483 .60076 L .48369 .59893 L F
.48453 .60015 m .483 .60076 L .4846 .59953 L F
.397 .14 .403 r
.48515 .5999 m .48387 .60114 L .483 .60076 L F
.48387 .60114 m .4826 .60236 L .48297 .6009 L F
.48387 .60114 m .48297 .6009 L .483 .60076 L F
.271 0 .231 r
.48515 .5999 m .48453 .60015 L .4846 .59953 L F
.923 .655 .513 r
.48601 .59816 m .48515 .5999 L .48457 .59884 L F
.48451 .5979 m .48457 .59884 L .484 .59781 L F
.48601 .59816 m .48457 .59884 L .48451 .5979 L F
.397 .14 .403 r
.48515 .5999 m .48511 .60214 L .4826 .60236 L F
.692 .303 .304 r
.48347 .59933 m .48465 .60136 L .48471 .60116 L F
.48459 .59914 m .48471 .60116 L .48537 .59902 L F
.48347 .59933 m .48471 .60116 L .48459 .59914 L F
.48465 .60136 m .48511 .60214 L .48516 .6015 L F
.48465 .60136 m .48516 .6015 L .48537 .59902 L F
.48347 .59933 m .48037 .6021 L .4843 .60213 L F
.48444 .60099 m .4843 .60213 L .48511 .60214 L F
.48347 .59933 m .4843 .60213 L .48444 .60099 L F
.174 .371 .818 r
.78885 .39613 m .79135 .39601 L .78877 .39436 L F
.78885 .39613 m .79168 .39806 L .79135 .39601 L F
0 .169 .613 r
.79288 .39895 m .79168 .39806 L .78885 .39613 L F
.391 .234 .545 r
.26319 .60164 m .26544 .60105 L .26541 .59818 L F
.295 .085 .414 r
.26293 .60407 m .26544 .60105 L .26319 .60164 L F
.511 0 0 r
.79288 .39895 m .79379 .3999 L .79168 .39806 L F
.79288 .39895 m .79522 .40115 L .79379 .3999 L F
.535 .007 0 r
.79632 .40202 m .79522 .40115 L .79288 .39895 L F
.895 .94 .834 r
.23304 .68217 m .23404 .68329 L .23635 .68037 L F
0 0 .374 r
.23304 .68217 m .23372 .68393 L .23404 .68329 L F
.882 .723 .209 r
.23372 .68393 m .2339 .68621 L .23404 .68329 L F
.58 .478 .703 r
.48144 .57701 m .48304 .5733 L .48087 .57463 L F
.487 .148 .318 r
.19534 .54026 m .19765 .5399 L .19706 .53813 L F
.803 .682 .73 r
.66769 .42004 m .66562 .42278 L .66433 .41921 L F
.726 .566 .673 r
.66959 .42269 m .66562 .42278 L .66769 .42004 L F
.133 0 .079 r
.49931 .58935 m .49761 .58972 L .50085 .5892 L F
.204 .295 .736 r
.76108 .42611 m .76259 .42436 L .76018 .42237 L F
.332 .49 .866 r
.76108 .42611 m .76399 .42728 L .76259 .42436 L F
.984 .766 .364 r
.49479 .56603 m .49562 .56536 L .49375 .56487 L F
.49479 .56603 m .49554 .56721 L .49562 .56536 L F
.676 .149 0 r
.2769 .56219 m .27802 .5641 L .27628 .56279 L F
.676 .141 0 r
.28036 .5652 m .27802 .5641 L .2769 .56219 L F
.65 .674 .859 r
.8155 .41646 m .81719 .41227 L .81475 .41283 L F
.8155 .41646 m .81815 .4156 L .81719 .41227 L F
.706 .297 .269 r
.43591 .58343 m .43499 .58524 L .43195 .5846 L F
.695 .285 .264 r
.43591 .58343 m .43815 .58565 L .43499 .58524 L F
0 .311 .747 r
.49865 .56896 m .49876 .56948 L .49702 .56831 L F
.49865 .56896 m .50028 .57018 L .49876 .56948 L F
.456 .735 .988 r
.54382 .59405 m .54546 .59541 L .5427 .59557 L F
.54382 .59405 m .54546 .59541 L .5427 .59557 L F
.904 .504 .233 r
.53512 .56664 m .53616 .56526 L .53316 .56599 L F
.53512 .56664 m .53688 .5674 L .53616 .56526 L F
.332 0 0 r
.78886 .43725 m .79142 .43772 L .79207 .43747 L F
0 0 0 r
.79207 .43747 m .79142 .43772 L .79475 .43706 L F
.178 .446 .875 r
.53706 .6048 m .53795 .60609 L .53682 .60331 L F
.77 .569 0 r
.53706 .6048 m .53682 .60331 L .53659 .60073 L F
.208 .728 .865 r
.54043 .60584 m .53682 .60331 L .53795 .60609 L F
.024 0 0 r
.19334 .77069 m .19571 .76738 L .19339 .76907 L F
.451 .272 .546 r
.47691 .58334 m .47917 .58278 L .47919 .58023 L F
.073 0 0 r
.19081 .54354 m .18927 .54379 L .19303 .54345 L F
.593 .291 .427 r
.48304 .5733 m .48653 .57372 L .48632 .57052 L F
.274 0 .298 r
.48632 .57052 m .48819 .57085 L .48956 .56749 L F
.569 .273 .427 r
.48632 .57052 m .48888 .57301 L .48819 .57085 L F
.48632 .57052 m .48653 .57372 L .48888 .57301 L F
.895 .94 .834 r
.23304 .68217 m .23635 .68037 L .23453 .67958 L F
0 .111 .66 r
.23635 .68037 m .23681 .67908 L .23453 .67958 L F
.496 .206 .402 r
.2388 .68002 m .23814 .68223 L .23635 .68037 L F
0 .111 .66 r
.23635 .68037 m .23814 .68223 L .23681 .67908 L F
.92 .791 .701 r
.51624 .62239 m .51479 .62247 L .51649 .61868 L F
.824 .427 .296 r
.51624 .62239 m .51496 .62419 L .51479 .62247 L F
.68 .854 .445 r
.51704 .62076 m .51496 .62419 L .51624 .62239 L F
.445 .316 .611 r
.45236 .64215 m .45051 .64183 L .45285 .64077 L F
.45236 .64215 m .45123 .64353 L .45051 .64183 L F
.557 .256 .413 r
.45484 .61618 m .45735 .61621 L .45822 .61315 L F
.82 .987 .879 r
.83763 .43087 m .83811 .43208 L .83893 .42973 L F
0 0 .33 r
.83775 .43117 m .83811 .43208 L .83702 .42959 L F
.98 .805 .596 r
.83702 .42959 m .83811 .43208 L .83624 .4321 L F
.82 .987 .879 r
.83624 .4321 m .83811 .43208 L .83763 .43087 L F
0 0 .33 r
.83796 .43163 m .83811 .43208 L .83775 .43117 L F
.813 .933 .562 r
.83796 .43163 m .83811 .43208 L .83893 .42973 L F
.358 .818 .926 r
.22302 .64556 m .2283 .64525 L .22603 .64426 L F
.095 .528 .908 r
.2283 .64525 m .22765 .64409 L .22603 .64426 L F
.2283 .64525 m .2322 .64645 L .22765 .64409 L F
.679 .64 .803 r
.84493 .40587 m .84151 .40464 L .84427 .40387 L F
.05 .4 .855 r
.84427 .40387 m .84808 .40697 L .84493 .40587 L F
.523 .331 .563 r
.47294 .62811 m .47076 .63042 L .47102 .62876 L F
.433 0 0 r
.50269 .57614 m .50691 .57878 L .50441 .57651 L F
.511 .437 .709 r
.21639 .69478 m .22011 .6977 L .22059 .69589 L F
.21639 .69478 m .21817 .69921 L .22011 .6977 L F
.604 .546 .763 r
.30753 .5619 m .30589 .56481 L .30494 .56253 L F
.562 .493 .736 r
.30753 .5619 m .3081 .56432 L .30589 .56481 L F
.638 .865 .984 r
.20827 .55547 m .21232 .55537 L .21049 .55471 L F
.355 .07 .336 r
.48055 .61643 m .48263 .61607 L .48335 .61339 L F
.621 .588 .795 r
.48692 .61433 m .48335 .61339 L .48562 .61344 L F
.443 .153 .376 r
.48263 .61607 m .48562 .61344 L .48335 .61339 L F
.192 0 .288 r
.26524 .59529 m .26675 .59492 L .26752 .59247 L F
.453 .384 .689 r
.26541 .59818 m .26675 .59492 L .26524 .59529 L F
.164 0 0 r
.43661 .64385 m .43755 .64407 L .43526 .64317 L F
.435 .699 .976 r
.17746 .60925 m .17698 .61091 L .17535 .60937 L F
.4 .663 .965 r
.17862 .61066 m .17698 .61091 L .17746 .60925 L F
0 0 0 r
.54501 .58599 m .54624 .58523 L .54409 .58652 L F
.102 .448 .882 r
.54595 .58512 m .54614 .58533 L .54501 .58599 L F
.575 .154 .205 r
.54501 .58599 m .54869 .58536 L .54624 .58523 L F
.425 0 0 r
.54501 .58599 m .54737 .58672 L .54869 .58536 L F
.102 .448 .882 r
.54614 .58533 m .54737 .58672 L .54501 .58599 L F
0 0 0 r
.54501 .58599 m .54409 .58652 L .54391 .58663 L F
.54254 .58801 m .54501 .58599 L .54391 .58663 L F
0 .154 .688 r
.55114 .58482 m .55031 .58596 L .54869 .58536 L F
.127 0 0 r
.54737 .58672 m .55114 .58482 L .54869 .58536 L F
.54737 .58672 m .54968 .58614 L .55114 .58482 L F
.596 .88 .567 r
.55114 .58482 m .54968 .58614 L .55198 .58368 L F
.55114 .58482 m .55198 .58368 L .55231 .58332 L F
0 .154 .688 r
.55114 .58482 m .55048 .58602 L .55031 .58596 L F
.745 .228 0 r
.55048 .58602 m .55301 .58886 L .55448 .58901 L F
0 .154 .688 r
.55114 .58482 m .55301 .58886 L .55048 .58602 L F
.61 .223 .286 r
.75192 .37645 m .75595 .37616 L .75299 .37445 L F
.562 .298 .473 r
.75595 .37616 m .7554 .37423 L .75299 .37445 L F
.5 .741 .981 r
.82062 .40112 m .81895 .40279 L .81801 .40136 L F
.82062 .40112 m .82156 .40248 L .81895 .40279 L F
.695 .947 .667 r
.40614 .61057 m .40718 .60863 L .40915 .60717 L F
.357 .165 .478 r
.40915 .60717 m .40896 .60965 L .40614 .61057 L F
.163 0 .328 r
.40774 .61177 m .40614 .61057 L .40896 .60965 L F
.40614 .61057 m .40774 .61177 L .40718 .60863 L F
.40614 .61057 m .40611 .61271 L .40774 .61177 L F
.40774 .61177 m .40611 .61271 L .40614 .61057 L F
.507 .391 .657 r
.42774 .64969 m .42986 .64583 L .42743 .64712 L F
.728 .392 .411 r
.56234 .50198 m .5662 .50393 L .56622 .5017 L F
.654 .372 .48 r
.5662 .50393 m .56999 .50143 L .56622 .5017 L F
0 0 .112 r
.40611 .61271 m .40622 .61614 L .40605 .61712 L F
.926 .755 .651 r
.40376 .61578 m .40605 .61712 L .40622 .61614 L F
.40376 .61578 m .40489 .6198 L .40605 .61712 L F
.945 .877 .737 r
.42723 .62128 m .42519 .6252 L .42565 .62256 L F
.718 .846 .411 r
.42586 .62346 m .42545 .62451 L .42723 .62128 L F
.42545 .62451 m .42519 .6252 L .42723 .62128 L F
.88 .667 .61 r
.42723 .62128 m .42565 .62256 L .42644 .62272 L F
.42723 .62128 m .42644 .62272 L .42931 .62328 L F
.752 .587 .671 r
.45964 .63599 m .46027 .63805 L .45664 .63793 L F
.642 .731 .914 r
.46221 .63494 m .45964 .63599 L .45876 .63422 L F
.622 .545 .746 r
.46221 .63494 m .46027 .63805 L .45964 .63599 L F
.968 .87 .478 r
.52817 .52182 m .52933 .51988 L .52856 .52323 L F
.203 0 .111 r
.52817 .52182 m .53112 .51848 L .52933 .51988 L F
.558 .696 .932 r
.76399 .42728 m .76488 .42909 L .7666 .42681 L F
.482 .585 .881 r
.7666 .42681 m .76488 .42909 L .76749 .42901 L F
.57 .613 .856 r
.48005 .60025 m .48181 .59722 L .47963 .59851 L F
.48005 .60025 m .48347 .59933 L .48181 .59722 L F
0 0 .184 r
.76704 .41249 m .76715 .41234 L .76711 .41371 L F
.969 .772 .582 r
.76715 .41234 m .76787 .41541 L .76711 .41371 L F
.68 .652 .815 r
.50049 .59199 m .50433 .59267 L .50226 .5901 L F
.134 .404 .853 r
.50433 .59267 m .5048 .59162 L .50226 .5901 L F
.556 .887 .987 r
.50595 .59213 m .5048 .59162 L .50433 .59267 L F
.754 .611 .7 r
.50535 .59354 m .5037 .59112 L .5048 .59162 L F
0 .289 .742 r
.50226 .5901 m .5048 .59162 L .503 .5901 L F
.754 .611 .7 r
.5037 .59112 m .503 .5901 L .5048 .59162 L F
.556 .887 .987 r
.50692 .5918 m .5048 .59162 L .50595 .59213 L F
.265 .221 .62 r
.50461 .59522 m .50604 .59486 L .50433 .59267 L F
.321 .657 .972 r
.20244 .62344 m .2023 .62486 L .20028 .62384 L F
.20244 .62344 m .20423 .62487 L .2023 .62486 L F
0 0 0 r
.79975 .44388 m .79885 .44438 L .7963 .44492 L F
.80244 .44357 m .79885 .44438 L .79975 .44388 L F
.666 .662 .836 r
.24571 .55244 m .2459 .5542 L .2493 .55328 L F
.596 .25 .352 r
.45627 .6397 m .45285 .64077 L .45411 .63823 L F
.562 .278 .443 r
.45664 .63793 m .45627 .6397 L .45411 .63823 L F
.978 .713 .312 r
.77962 .39746 m .78066 .39938 L .78318 .39834 L F
.77962 .39746 m .77985 .40037 L .78066 .39938 L F
.654 .372 .48 r
.5662 .50393 m .56902 .50422 L .56999 .50143 L F
.609 .326 .463 r
.56999 .50143 m .57251 .50354 L .57245 .50172 L F
.56999 .50143 m .56902 .50422 L .57251 .50354 L F
.943 .834 .706 r
.56933 .54412 m .56664 .54498 L .56784 .54274 L F
.56933 .54412 m .56839 .54701 L .56664 .54498 L F
.568 .444 .671 r
.43317 .61419 m .43227 .61654 L .43764 .6143 L F
.267 0 0 r
.41619 .61558 m .41858 .61517 L .41893 .61353 L F
.173 0 0 r
.23906 .53703 m .24131 .53726 L .24317 .5372 L F
.273 0 0 r
.24317 .5372 m .24131 .53726 L .24519 .53759 L F
.163 .01 .413 r
.4645 .62808 m .46606 .62501 L .46466 .6259 L F
.622 .53 .729 r
.72604 .39564 m .72882 .39489 L .72925 .39308 L F
.533 .309 .521 r
.29112 .61365 m .29089 .61611 L .28849 .61652 L F
.466 .253 .505 r
.2931 .61559 m .29112 .61365 L .29353 .61328 L F
.2931 .61559 m .29089 .61611 L .29112 .61365 L F
.628 .875 .988 r
.78466 .44881 m .78664 .44681 L .78368 .44756 L F
.78466 .44881 m .7879 .44785 L .78664 .44681 L F
0 .515 .729 r
.80607 .4441 m .80494 .4439 L .80244 .44357 L F
.545 0 0 r
.80607 .4441 m .80776 .44578 L .80494 .4439 L F
.80607 .4441 m .80872 .44616 L .80776 .44578 L F
.359 .523 .883 r
.76749 .42901 m .76896 .43173 L .7704 .43004 L F
.298 .431 .828 r
.76896 .43173 m .77187 .43325 L .7704 .43004 L F
0 .323 .81 r
.76896 .43173 m .77237 .43505 L .77187 .43325 L F
.051 .336 .815 r
.18089 .61227 m .18067 .61374 L .17862 .61066 L F
.988 .718 .379 r
.18089 .61227 m .18263 .61577 L .18067 .61374 L F
.527 .562 .834 r
.81149 .41178 m .81346 .40919 L .81093 .40964 L F
.529 .565 .836 r
.81149 .41178 m .81475 .41283 L .81346 .40919 L F
.363 .244 .581 r
.43871 .63295 m .43637 .63149 L .43871 .63062 L F
.476 .51 .813 r
.4415 .62882 m .43871 .63062 L .4388 .62848 L F
.4415 .62882 m .44182 .63091 L .43871 .63062 L F
.683 .386 .465 r
.44182 .63091 m .43871 .63295 L .43871 .63062 L F
.215 0 0 r
.23298 .53651 m .23513 .53691 L .23693 .53704 L F
.325 .783 .947 r
.23513 .53691 m .23906 .53703 L .23693 .53704 L F
.752 .682 .135 r
.58053 .58504 m .58083 .58337 L .58072 .58248 L F
.58053 .58504 m .58052 .58568 L .58083 .58337 L F
.201 .289 .731 r
.41592 .64984 m .41866 .64978 L .41587 .64822 L F
.41592 .64984 m .4183 .65222 L .41866 .64978 L F
.637 .252 .298 r
.66959 .42269 m .66807 .42451 L .66562 .42278 L F
.463 .104 .269 r
.80967 .43299 m .81246 .43329 L .81311 .4313 L F
.625 .554 .755 r
.81311 .4313 m .8159 .43155 L .81489 .42818 L F
.322 0 0 r
.81246 .43329 m .8159 .43155 L .81311 .4313 L F
.317 .527 .901 r
.29263 .54173 m .29179 .54358 L .28975 .54111 L F
.29263 .54173 m .29348 .54358 L .29179 .54358 L F
.286 .004 .298 r
.44768 .6531 m .45031 .65224 L .45022 .65026 L F
.647 .266 .309 r
.45022 .65026 m .45257 .65235 L .45031 .65224 L F
.45022 .65026 m .45257 .65235 L .45031 .65224 L F
0 .094 .635 r
.41818 .63923 m .41746 .64046 L .41477 .63775 L F
.41818 .63923 m .41815 .6404 L .41746 .64046 L F
.743 .381 .366 r
.56274 .51372 m .56091 .51544 L .55896 .51326 L F
.759 .403 .38 r
.56274 .51372 m .56466 .51606 L .56091 .51544 L F
.547 .81 .994 r
.76121 .41591 m .76234 .41705 L .76391 .41534 L F
.76121 .41591 m .76234 .41705 L .76391 .41534 L F
.68 .652 .815 r
.50049 .59199 m .50226 .5901 L .50085 .5892 L F
.925 .612 .431 r
.23118 .65837 m .23097 .65605 L .22916 .65766 L F
.22916 .65766 m .23097 .65605 L .23118 .65837 L F
.23118 .65837 m .23097 .65605 L .22916 .65766 L F
0 0 .168 r
.28036 .5652 m .27997 .5677 L .2811 .56608 L F
.28036 .5652 m .2811 .56608 L .27802 .5641 L F
0 0 0 r
.81578 .4482 m .81829 .44636 L .81787 .44751 L F
.609 .603 .82 r
.8214 .44344 m .81829 .44636 L .81818 .44402 L F
.208 0 0 r
.81787 .44751 m .81829 .44636 L .82142 .44629 L F
.441 .332 .635 r
.82142 .44629 m .81829 .44636 L .8214 .44344 L F
.802 .465 0 r
.50691 .57878 m .50828 .58235 L .50791 .5803 L F
.267 0 0 r
.23324 .64457 m .23442 .64463 L .23451 .64469 L F
.544 .379 .608 r
.3076 .57371 m .30757 .57893 L .30517 .57885 L F
.354 .177 .497 r
.30979 .57082 m .30955 .57304 L .3076 .57371 L F
.48 .349 .624 r
.30955 .57304 m .30757 .57893 L .3076 .57371 L F
.839 .63 .621 r
.41777 .62882 m .41957 .63074 L .42032 .62865 L F
.41777 .62882 m .41797 .63173 L .41957 .63074 L F
.868 .704 .675 r
.41957 .63074 m .41779 .63427 L .41797 .63173 L F
.839 .63 .621 r
.41957 .63074 m .41777 .62882 L .42032 .62865 L F
.41957 .63074 m .41797 .63173 L .41777 .62882 L F
.868 .704 .675 r
.41957 .63074 m .41779 .63427 L .41797 .63173 L F
.838 .384 0 r
.53848 .56988 m .53909 .56947 L .53688 .5674 L F
.53848 .56988 m .53931 .57062 L .53909 .56947 L F
.119 .485 .9 r
.23249 .55115 m .23413 .55075 L .23162 .55041 L F
.454 0 0 r
.23634 .55228 m .23541 .55231 L .23249 .55115 L F
.119 .485 .9 r
.23249 .55115 m .23541 .55231 L .23413 .55075 L F
.657 .177 0 r
.52504 .57433 m .5237 .57298 L .52557 .57403 L F
.52504 .57433 m .52551 .57547 L .5237 .57298 L F
.664 .227 0 r
.52504 .57433 m .52755 .57848 L .52551 .57547 L F
.917 .769 .683 r
.57812 .53108 m .58148 .5294 L .5814 .5287 L F
.916 .767 .681 r
.57812 .53108 m .57921 .53424 L .58148 .5294 L F
.484 .281 .529 r
.19245 .75803 m .19027 .75834 L .19209 .7611 L F
.487 .052 .139 r
.45884 .61947 m .45843 .62111 L .45607 .62005 L F
0 0 0 r
.46079 .61785 m .45843 .62111 L .45884 .61947 L F
.442 .155 .38 r
.27544 .62896 m .27489 .63099 L .27264 .63146 L F
.369 .048 .284 r
.2778 .62859 m .27489 .63099 L .27544 .62896 L F
.359 0 0 r
.44227 .58369 m .44061 .58551 L .43815 .58565 L F
.423 .021 .17 r
.44452 .58289 m .44061 .58551 L .44227 .58369 L F
.513 0 0 r
.15496 .59168 m .15683 .59198 L .15731 .59155 L F
.591 .482 .699 r
.22444 .56854 m .2248 .57097 L .22718 .56807 L F
.891 .696 .633 r
.57044 .53496 m .56855 .5344 L .5688 .53132 L F
.973 .857 .665 r
.57044 .53496 m .56845 .53612 L .56855 .5344 L F
.57044 .53496 m .56966 .53719 L .56845 .53612 L F
.971 .799 .614 r
.56842 .55319 m .56647 .55477 L .56664 .55225 L F
.56842 .55319 m .56791 .55574 L .56647 .55477 L F
.582 .481 .705 r
.45255 .60406 m .45457 .60085 L .45252 .60138 L F
.45457 .60085 m .45255 .60406 L .45252 .60138 L F
.448 .211 .462 r
.25577 .6105 m .25788 .6103 L .25834 .60764 L F
.43 .196 .456 r
.25834 .60764 m .25975 .60971 L .26043 .60706 L F
.25834 .60764 m .25788 .6103 L .25975 .60971 L F
.602 .756 .952 r
.83074 .40291 m .82907 .40528 L .8281 .40368 L F
.83074 .40291 m .83172 .40454 L .82907 .40528 L F
.141 .551 .924 r
.80872 .44616 m .80978 .44733 L .8126 .44789 L F
.661 .659 .837 r
.24727 .64521 m .24603 .64694 L .2481 .64559 L F
.775 .634 .705 r
.24988 .64457 m .25111 .64713 L .24653 .64652 L F
.661 .659 .837 r
.24285 .64319 m .24727 .64521 L .24548 .64325 L F
.24727 .64521 m .2481 .64559 L .24751 .64507 L F
.24727 .64521 m .24751 .64507 L .24548 .64325 L F
.71 .704 .843 r
.24548 .64325 m .2481 .64559 L .24929 .64341 L F
.775 .634 .705 r
.24988 .64457 m .24653 .64652 L .24929 .64341 L F
.166 0 .241 r
.2491 .64412 m .24653 .64652 L .24882 .64519 L F
.24882 .64519 m .24653 .64652 L .24866 .64578 L F
.24926 .64352 m .24825 .64463 L .2491 .64412 L F
.24825 .64463 m .24653 .64652 L .2491 .64412 L F
.24929 .64341 m .24898 .64375 L .24926 .64352 L F
.24898 .64375 m .24653 .64652 L .24926 .64352 L F
.661 .659 .837 r
.24285 .64319 m .24569 .64655 L .24727 .64521 L F
.24569 .64655 m .24603 .64694 L .24727 .64521 L F
0 .108 .567 r
.79632 .40202 m .79648 .40212 L .79522 .40115 L F
0 .302 .664 r
.79632 .40202 m .7996 .40349 L .79825 .40285 L F
.79632 .40202 m .79825 .40285 L .79648 .40212 L F
.814 .671 .124 r
.58203 .57679 m .58214 .57428 L .58198 .57348 L F
.746 .488 .54 r
.57251 .50354 m .57642 .50154 L .57245 .50172 L F
.484 .826 .542 r
.48264 .62169 m .47869 .62518 L .47889 .6228 L F
.48264 .62169 m .47981 .62416 L .47869 .62518 L F
.443 .516 .838 r
.48314 .61842 m .48468 .62221 L .48264 .62169 L F
.647 .221 .221 r
.48482 .62405 m .48264 .62169 L .48468 .62221 L F
.48482 .62405 m .47981 .62416 L .48264 .62169 L F
.788 .474 .456 r
.49529 .53813 m .49825 .54051 L .49821 .53794 L F
.578 .324 .496 r
.22011 .6977 m .22308 .69497 L .22059 .69589 L F
0 0 0 r
.47089 .55834 m .47246 .55736 L .47394 .55738 L F
.47089 .55834 m .47052 .55863 L .47246 .55736 L F
.513 .619 .894 r
.15736 .6224 m .15727 .61904 L .1559 .61907 L F
.15736 .6224 m .15942 .62206 L .15727 .61904 L F
.532 .311 .525 r
.65841 .41984 m .65594 .42298 L .6558 .41994 L F
.65841 .41984 m .65873 .42252 L .65594 .42298 L F
.61 .366 .524 r
.66228 .42165 m .65841 .41984 L .6618 .4197 L F
.66228 .42165 m .65873 .42252 L .65841 .41984 L F
.203 0 .297 r
.42613 .65324 m .42571 .65541 L .42791 .6524 L F
.733 .445 .491 r
.46027 .63805 m .45627 .6397 L .45664 .63793 L F
.46027 .63805 m .46008 .64028 L .45627 .6397 L F
.622 .545 .746 r
.46221 .63494 m .46273 .63764 L .46027 .63805 L F
.395 .159 .435 r
.46193 .63937 m .46027 .63805 L .46273 .63764 L F
.46193 .63937 m .46008 .64028 L .46027 .63805 L F
.076 0 .125 r
.15938 .55953 m .16032 .56024 L .16139 .55896 L F
.15938 .55953 m .15857 .56142 L .16032 .56024 L F
.32 .02 .289 r
.41604 .63535 m .41477 .63775 L .41296 .63792 L F
.654 .154 .047 r
.41477 .63775 m .41149 .63696 L .41296 .63792 L F
.525 .323 .548 r
.29854 .60455 m .29839 .60713 L .29602 .60757 L F
.435 .249 .528 r
.30048 .60646 m .29854 .60455 L .30065 .60394 L F
.30048 .60646 m .29839 .60713 L .29854 .60455 L F
.842 .735 .746 r
.74803 .38965 m .74725 .39283 L .7474 .3928 L F
.688 .658 .815 r
.82567 .41971 m .82937 .42021 L .82825 .41672 L F
.706 .681 .823 r
.83171 .41953 m .82825 .41672 L .82937 .42021 L F
.033 0 .45 r
.43526 .64317 m .43554 .64706 L .434 .64677 L F
.856 .533 .439 r
.68286 .41965 m .68291 .42139 L .68431 .4198 L F
.854 .529 .437 r
.68291 .42139 m .68478 .42221 L .68431 .4198 L F
.369 .589 .929 r
.83702 .42197 m .83901 .4238 L .83911 .42376 L F
0 .498 .723 r
.83911 .42376 m .83901 .4238 L .84108 .42409 L F
.073 0 0 r
.42421 .66407 m .42204 .66566 L .42467 .66491 L F
.859 .905 .865 r
.42204 .66566 m .42421 .66407 L .42467 .66491 L F
.785 .769 .839 r
.65494 .43246 m .65593 .43678 L .6586 .43376 L F
.629 .641 .843 r
.65593 .43678 m .65964 .43813 L .6586 .43376 L F
.239 .647 .96 r
.74335 .3922 m .74137 .39213 L .74198 .39108 L F
.706 .681 .823 r
.83171 .41953 m .83068 .41571 L .82825 .41672 L F
.761 .713 .808 r
.83171 .41953 m .83435 .41629 L .83068 .41571 L F
0 .13 .652 r
.4155 .64615 m .41521 .64248 L .4143 .64393 L F
.447 0 0 r
.66275 .41277 m .66681 .41451 L .66675 .41365 L F
.886 .687 .628 r
.66681 .41451 m .66935 .41541 L .66675 .41365 L F
.577 .224 .334 r
.66675 .41365 m .66935 .41541 L .66943 .41379 L F
.786 .777 .845 r
.84151 .40464 m .83801 .40445 L .84057 .40337 L F
.418 .794 .993 r
.84057 .40337 m .84427 .40387 L .84151 .40464 L F
.428 .235 .516 r
.29793 .60943 m .29602 .60757 L .29839 .60713 L F
.29793 .60943 m .29583 .6101 L .29602 .60757 L F
.409 .483 .825 r
.19396 .64281 m .19429 .63993 L .19265 .64064 L F
.19396 .64281 m .19577 .64341 L .19429 .63993 L F
.95 .616 .209 r
.51215 .59039 m .51284 .5894 L .51126 .58864 L F
.51215 .59039 m .51336 .59174 L .51284 .5894 L F
.277 0 .195 r
.45701 .56557 m .45882 .56628 L .46015 .56453 L F
.597 .222 .303 r
.45882 .56628 m .46233 .56402 L .46015 .56453 L F
.351 .532 .893 r
.15282 .6175 m .15376 .61606 L .152 .61614 L F
.15282 .6175 m .1559 .61907 L .15376 .61606 L F
0 0 0 r
.17625 .5502 m .17597 .55042 L .17838 .54954 L F
.17625 .5502 m .17417 .55154 L .17597 .55042 L F
.218 0 0 r
.45013 .5695 m .44855 .56896 L .4476 .5698 L F
.45013 .5695 m .45087 .56822 L .44855 .56896 L F
.445 0 0 r
.51061 .55643 m .50753 .55467 L .50898 .55555 L F
.622 .565 .769 r
.30879 .58204 m .30647 .58327 L .30549 .58013 L F
.559 .407 .632 r
.30879 .58204 m .3056 .58679 L .30647 .58327 L F
.33 .367 .749 r
.48401 .57916 m .48242 .58079 L .48144 .57701 L F
.57 .761 .968 r
.48151 .57962 m .48242 .58079 L .48401 .57916 L F
.577 .479 .706 r
.48555 .58272 m .48304 .58339 L .48242 .58079 L F
.48242 .58079 m .48304 .58339 L .48555 .58272 L F
.445 .872 .925 r
.2281 .62882 m .22303 .62946 L .22645 .62879 L F
.34 .813 .906 r
.22876 .62815 m .2281 .62882 L .22645 .62879 L F
.22876 .62815 m .23033 .62832 L .2281 .62882 L F
.624 .455 .633 r
.4732 .59805 m .47671 .60168 L .47758 .59975 L F
.854 .478 .335 r
.43024 .63659 m .43231 .64024 L .43209 .63833 L F
.43024 .63659 m .43231 .64024 L .43209 .63833 L F
.449 0 0 r
.73421 .38975 m .7368 .38872 L .73606 .38813 L F
.943 .943 .757 r
.7368 .38872 m .73415 .39012 L .73606 .38813 L F
.7368 .38872 m .73468 .39247 L .73415 .39012 L F
.3 .065 .38 r
.25562 .61288 m .25788 .6103 L .25577 .6105 L F
.15 .332 .792 r
.77237 .43505 m .77351 .43337 L .77187 .43325 L F
.77237 .43505 m .77501 .43693 L .77351 .43337 L F
0 .084 .583 r
.8159 .43155 m .81845 .43379 L .81958 .435 L F
.558 .527 .776 r
.8159 .43155 m .81884 .43388 L .81734 .42756 L F
.712 .627 .76 r
.81884 .43388 m .82108 .42829 L .81734 .42756 L F
.128 .357 .818 r
.82034 .43307 m .81958 .435 L .81845 .43379 L F
.82034 .43307 m .82236 .43662 L .81958 .435 L F
.379 0 .127 r
.19738 .76752 m .19571 .76738 L .19334 .77069 L F
.533 .153 .266 r
.56606 .60419 m .56291 .60671 L .56323 .60572 L F
0 0 0 r
.56606 .60419 m .56946 .60206 L .5677 .60321 L F
.199 0 0 r
.43353 .57631 m .43542 .57622 L .43695 .57433 L F
.128 0 0 r
.43695 .57433 m .43788 .57531 L .43822 .57489 L F
.43695 .57433 m .43542 .57622 L .43788 .57531 L F
.255 .687 .962 r
.22069 .64601 m .22031 .64528 L .21772 .64501 L F
.22069 .64601 m .22168 .646 L .22031 .64528 L F
.705 .543 .666 r
.43231 .64024 m .43479 .63711 L .43209 .63833 L F
.732 .583 .688 r
.43479 .63711 m .43231 .64024 L .43209 .63833 L F
.335 .019 .272 r
.81442 .42576 m .81716 .42498 L .8164 .42391 L F
.488 .058 .148 r
.8164 .42391 m .81716 .42498 L .81969 .42446 L F
.969 .68 .427 r
.52629 .55453 m .52769 .55306 L .52597 .55195 L F
.52629 .55453 m .52747 .55531 L .52769 .55306 L F
.694 .9 .97 r
.75325 .38103 m .7548 .38221 L .75754 .38049 L F
.75325 .38103 m .75754 .38049 L .75593 .38002 L F
.63 .879 .987 r
.75325 .38103 m .7548 .38221 L .75593 .38002 L F
.764 .711 .802 r
.22349 .68564 m .22557 .68906 L .22748 .686 L F
.707 .631 .77 r
.22557 .68906 m .22868 .68884 L .22748 .686 L F
.703 .553 .681 r
.22557 .68906 m .2254 .69366 L .22868 .68884 L F
.568 .444 .671 r
.43317 .61419 m .43764 .6143 L .43531 .61371 L F
.917 .75 .659 r
.58284 .55465 m .58411 .55593 L .58297 .55245 L F
.897 .748 .688 r
.58284 .55465 m .58338 .55838 L .58411 .55593 L F
.623 .557 .76 r
.82552 .41722 m .82567 .41971 L .82825 .41672 L F
.312 0 0 r
.26169 .55718 m .25771 .55594 L .25925 .55699 L F
.083 .593 .888 r
.26321 .55788 m .26169 .55718 L .25925 .55699 L F
.792 .73 .794 r
.74992 .37999 m .7485 .38304 L .74705 .37945 L F
.537 .425 .674 r
.74992 .37999 m .75136 .38253 L .7485 .38304 L F
.617 .605 .815 r
.75249 .3852 m .7485 .38304 L .75136 .38253 L F
.043 .212 .714 r
.25176 .55271 m .25308 .55617 L .25379 .55456 L F
.128 .32 .787 r
.25308 .55617 m .25477 .55693 L .25379 .55456 L F
.086 .183 .67 r
.51522 .59394 m .51404 .59551 L .51336 .59174 L F
.63 .199 0 r
.51457 .59649 m .51404 .59551 L .51522 .59394 L F
.51457 .59649 m .51538 .59761 L .51404 .59551 L F
.917 .769 .683 r
.57812 .53108 m .5814 .5287 L .5799 .52778 L F
.851 .848 .84 r
.5799 .52778 m .5814 .5287 L .58391 .52565 L F
.884 .639 .119 r
.77097 .40339 m .77169 .40688 L .7718 .40464 L F
.474 .567 .87 r
.30939 .55513 m .30639 .55356 L .30879 .55278 L F
.398 .735 .992 r
.22868 .68884 m .22935 .68786 L .22748 .686 L F
.22868 .68884 m .23122 .689 L .22935 .68786 L F
.826 .604 .602 r
.57866 .50689 m .58018 .5047 L .5788 .5044 L F
.57866 .50689 m .58015 .5073 L .58018 .5047 L F
.913 .71 .616 r
.58139 .54946 m .58288 .55001 L .5815 .54649 L F
.91 .638 .512 r
.58197 .55193 m .58288 .55001 L .58139 .54946 L F
.58197 .55193 m .58297 .55245 L .58288 .55001 L F
0 0 .245 r
.44925 .6542 m .45031 .65224 L .44768 .6531 L F
.44925 .6542 m .44962 .65547 L .45031 .65224 L F
.45031 .65224 m .44925 .6542 L .44768 .6531 L F
.45031 .65224 m .44962 .65547 L .44925 .6542 L F
.957 .623 .24 r
.6592 .4108 m .66053 .41375 L .66275 .41277 L F
.495 .199 .393 r
.65946 .41296 m .65927 .41552 L .65956 .41544 L F
.957 .623 .24 r
.65938 .41121 m .65946 .41296 L .66053 .41375 L F
.413 .849 .937 r
.65946 .41296 m .66275 .41277 L .66053 .41375 L F
.495 .199 .393 r
.65946 .41296 m .65956 .41544 L .66271 .41463 L F
.957 .623 .24 r
.6592 .4108 m .65946 .41296 L .65938 .41121 L F
.508 .401 .668 r
.30461 .59441 m .30286 .59808 L .30253 .5957 L F
.733 .508 .586 r
.18659 .77422 m .18342 .77103 L .18384 .77396 L F
.18659 .77422 m .18871 .77292 L .18342 .77103 L F
0 0 0 r
.54446 .51712 m .54297 .51869 L .54133 .51911 L F
.447 0 0 r
.54646 .51796 m .54297 .51869 L .54446 .51712 L F
1 .805 .475 r
.58172 .56671 m .58297 .5651 L .582 .56413 L F
.58172 .56671 m .58255 .56777 L .58297 .5651 L F
.976 .799 .598 r
.58297 .5651 m .58216 .56156 L .582 .56413 L F
.579 .829 .992 r
.54345 .606 m .54043 .60584 L .54118 .60713 L F
.638 .904 .983 r
.21186 .64632 m .21474 .64627 L .21368 .64545 L F
.685 .882 .971 r
.21474 .64627 m .21622 .64397 L .21368 .64545 L F
.21474 .64627 m .21772 .64501 L .21622 .64397 L F
.898 .758 .7 r
.78081 .39161 m .78413 .39321 L .78374 .39075 L F
.78081 .39161 m .78201 .39469 L .78413 .39321 L F
.548 .789 .988 r
.78374 .39075 m .78413 .39321 L .78687 .39137 L F
.277 0 .195 r
.45701 .56557 m .45645 .56719 L .45882 .56628 L F
.454 .059 .2 r
.45607 .62005 m .45573 .62155 L .45315 .62175 L F
.48 .082 .207 r
.45843 .62111 m .45573 .62155 L .45607 .62005 L F
.658 .531 .698 r
.41685 .62554 m .41923 .62745 L .42189 .62341 L F
.708 .171 0 r
.41685 .62554 m .41918 .62801 L .41923 .62745 L F
.956 .659 .433 r
.76704 .39549 m .76565 .39642 L .76365 .39655 L F
.76704 .39549 m .76734 .3982 L .76565 .39642 L F
.458 .597 .903 r
.84215 .41112 m .84055 .41071 L .84307 .41028 L F
.304 0 .253 r
.49956 .60192 m .49682 .60457 L .49939 .60402 L F
.519 .218 .396 r
.50171 .60317 m .49956 .60192 L .49939 .60402 L F
.50171 .60317 m .50222 .60151 L .49956 .60192 L F
.379 .633 .954 r
.18533 .78238 m .18711 .78249 L .18604 .78313 L F
0 0 0 r
.18604 .78313 m .18711 .78249 L .18519 .78404 L F
.881 .676 .621 r
.40918 .62493 m .41044 .62825 L .41153 .62616 L F
.677 .366 .439 r
.55637 .51323 m .5528 .51561 L .55279 .51361 L F
.55637 .51323 m .55524 .51603 L .5528 .51561 L F
.622 .324 .444 r
.55896 .51326 m .55524 .51603 L .55637 .51323 L F
.448 .221 .476 r
.28849 .61652 m .28811 .61911 L .28589 .61958 L F
.503 .269 .493 r
.29046 .61862 m .28849 .61652 L .29089 .61611 L F
.29046 .61862 m .28811 .61911 L .28849 .61652 L F
.21 .591 .946 r
.80547 .39857 m .80095 .39652 L .80449 .39732 L F
.301 .647 .968 r
.80792 .3988 m .80547 .39857 L .80449 .39732 L F
.961 .821 .66 r
.56839 .54701 m .56588 .54863 L .56664 .54498 L F
.56839 .54701 m .56727 .5497 L .56588 .54863 L F
.371 .453 .815 r
.77754 .42999 m .77582 .43106 L .7736 .42845 L F
.77754 .42999 m .77734 .43138 L .77582 .43106 L F
0 0 0 r
.19529 .76053 m .19675 .75915 L .19848 .75839 L F
.123 0 .374 r
.26917 .58905 m .26752 .59247 L .26899 .59136 L F
.245 .041 .393 r
.26675 .59492 m .26899 .59136 L .26752 .59247 L F
.876 .909 .849 r
.8446 .41463 m .84677 .41368 L .84568 .41249 L F
.579 .432 .646 r
.30787 .57937 m .30517 .57885 L .30757 .57893 L F
.30787 .57937 m .30549 .58013 L .30517 .57885 L F
.672 .448 .572 r
.44915 .6435 m .44515 .64633 L .44564 .64424 L F
.774 .981 .721 r
.57658 .59484 m .57399 .5978 L .57398 .59828 L F
.165 .555 .93 r
.16572 .62393 m .16757 .62535 L .16897 .6254 L F
.542 .331 .544 r
.28589 .61958 m .28579 .62208 L .28342 .62256 L F
.542 .368 .595 r
.28811 .61911 m .28579 .62208 L .28589 .61958 L F
.286 0 .201 r
.54538 .50775 m .54242 .51012 L .54496 .50908 L F
.403 .045 .24 r
.54496 .50908 m .54797 .50723 L .54538 .50775 L F
.942 .603 .354 r
.76687 .38773 m .76802 .38649 L .76643 .38555 L F
.489 0 0 r
.76687 .38773 m .7711 .38762 L .76802 .38649 L F
.524 .272 .474 r
.73091 .38949 m .73421 .38975 L .73414 .38781 L F
.853 .81 .807 r
.1888 .77064 m .18871 .77292 L .18659 .77422 L F
.438 .225 .492 r
.47775 .56116 m .47525 .56208 L .47768 .55901 L F
.532 .878 .632 r
.47613 .56108 m .47525 .56208 L .47775 .56116 L F
.47613 .56108 m .47322 .56353 L .47525 .56208 L F
0 0 0 r
.44645 .57909 m .44459 .58031 L .44735 .57806 L F
.333 .174 .511 r
.44654 .5816 m .44459 .58031 L .44645 .57909 L F
.44654 .5816 m .44452 .58289 L .44459 .58031 L F
.663 .626 .803 r
.22059 .55545 m .22343 .55609 L .22493 .55559 L F
.709 .29 .248 r
.22343 .55609 m .22655 .55787 L .22493 .55559 L F
.905 .76 .69 r
.56962 .52197 m .56621 .52425 L .56628 .52194 L F
.56962 .52197 m .56805 .52524 L .56621 .52425 L F
.727 .552 .654 r
.22483 .70518 m .22223 .70539 L .22273 .70201 L F
.22483 .70518 m .22539 .70751 L .22223 .70539 L F
.432 .574 .895 r
.22223 .70539 m .22539 .70751 L .2252 .7071 L F
.22427 .70582 m .2252 .7071 L .22466 .70592 L F
.2234 .70561 m .22364 .70581 L .22427 .70582 L F
.22364 .70581 m .2252 .7071 L .22427 .70582 L F
.349 .309 .672 r
.22731 .70561 m .22539 .70751 L .22483 .70518 L F
.349 0 0 r
.22483 .70518 m .22427 .70582 L .22731 .70561 L F
.432 .574 .895 r
.22223 .70539 m .2252 .7071 L .22325 .70548 L F
.563 .653 .896 r
.22451 .7056 m .22462 .70583 L .22731 .70561 L F
.22462 .70583 m .22539 .70751 L .22731 .70561 L F
.349 0 0 r
.22462 .70583 m .22381 .70635 L .22606 .70587 L F
.547 .078 .092 r
.2234 .70561 m .22427 .70582 L .22483 .70518 L F
.432 .574 .895 r
.2234 .70561 m .22466 .70592 L .22451 .7056 L F
.349 0 0 r
.22427 .70582 m .22423 .70587 L .22462 .70583 L F
.22423 .70587 m .22381 .70635 L .22462 .70583 L F
.22427 .70582 m .22606 .70587 L .22731 .70561 L F
.547 .078 .092 r
.22117 .70627 m .22381 .70635 L .22427 .70582 L F
.22117 .70627 m .22427 .70582 L .2234 .70561 L F
.432 .574 .895 r
.22325 .70548 m .2234 .70561 L .22451 .7056 L F
.547 .078 .092 r
.22325 .70548 m .22483 .70518 L .22467 .70495 L F
.22117 .70627 m .2234 .70561 L .22325 .70548 L F
.2234 .70561 m .22483 .70518 L .22325 .70548 L F
.659 .341 .423 r
.22325 .70548 m .22117 .70627 L .22223 .70539 L F
.22451 .7056 m .22117 .70627 L .22325 .70548 L F
.547 .078 .092 r
.22117 .70627 m .22467 .70495 L .22273 .70201 L F
.488 .875 .684 r
.16278 .57707 m .16066 .57823 L .16002 .57892 L F
0 0 .386 r
.16075 .58059 m .16002 .57892 L .16066 .57823 L F
.16075 .58059 m .1604 .58238 L .16002 .57892 L F
.765 .848 .913 r
.55629 .60649 m .5579 .60769 L .56024 .60595 L F
.98 .722 .465 r
.66562 .42278 m .66442 .42248 L .66433 .41921 L F
.782 .387 .306 r
.66807 .42451 m .66442 .42248 L .66562 .42278 L F
.789 .502 .501 r
.66935 .41541 m .67276 .41375 L .66943 .41379 L F
.66935 .41541 m .67302 .41605 L .67276 .41375 L F
.506 .423 .696 r
.50452 .59781 m .50604 .59486 L .50461 .59522 L F
.506 .315 .556 r
.19768 .78298 m .19994 .78261 L .19797 .77975 L F
.974 .747 .533 r
.19768 .78298 m .19797 .77975 L .19994 .78261 L F
.243 .718 .939 r
.24519 .53759 m .24736 .53754 L .24913 .53815 L F
.306 .765 .95 r
.24736 .53754 m .25138 .53784 L .24913 .53815 L F
.46 .554 .864 r
.75483 .38507 m .75249 .3852 L .75136 .38253 L F
.51 .652 .922 r
.7559 .38662 m .75249 .3852 L .75483 .38507 L F
.521 0 0 r
.22025 .70104 m .21963 .70059 L .21817 .69921 L F
0 .261 .666 r
.22025 .70104 m .2223 .70218 L .21963 .70059 L F
.631 .595 .795 r
.18415 .77472 m .18659 .77422 L .18384 .77396 L F
.632 .473 .649 r
.30813 .55018 m .30955 .5497 L .30761 .54889 L F
.30813 .55018 m .31123 .54965 L .30955 .5497 L F
.30813 .55018 m .30879 .55278 L .31123 .54965 L F
.746 .488 .54 r
.57251 .50354 m .57494 .50383 L .57642 .50154 L F
.8 .561 .575 r
.57642 .50154 m .57494 .50383 L .5788 .5044 L F
.485 .319 .579 r
.47919 .58023 m .48151 .57962 L .48144 .57701 L F
.247 0 0 r
.21838 .55601 m .21753 .55581 L .21476 .55495 L F
.579 .935 .933 r
.21924 .55474 m .21838 .55601 L .22059 .55545 L F
.21924 .55474 m .21753 .55581 L .21838 .55601 L F
.714 .497 .594 r
.66433 .41921 m .66228 .42165 L .6618 .4197 L F
.332 .794 .938 r
.19288 .77153 m .19505 .77116 L .19334 .77069 L F
.952 .925 .742 r
.6558 .41994 m .65501 .41876 L .65662 .41553 L F
.997 .856 .543 r
.6558 .41994 m .65444 .42104 L .65501 .41876 L F
.229 0 .233 r
.41779 .63427 m .41477 .63775 L .41604 .63535 L F
0 .416 .819 r
.20726 .7211 m .20776 .7207 L .20528 .71882 L F
.76 .658 .102 r
.51479 .62247 m .51494 .61912 L .51649 .61868 L F
.045 .186 .688 r
.74803 .38965 m .74955 .39154 L .74855 .38789 L F
.842 .735 .746 r
.74803 .38965 m .7474 .3928 L .74955 .39154 L F
.232 .635 .958 r
.81146 .43225 m .80967 .43299 L .80874 .43286 L F
.81146 .43225 m .81246 .43329 L .80967 .43299 L F
0 0 0 r
.1673 .57441 m .1645 .57626 L .16602 .5749 L F
.211 .64 .952 r
.80017 .40528 m .8026 .4048 L .7996 .40349 L F
.80017 .40528 m .80367 .40579 L .8026 .4048 L F
.621 .35 .486 r
.44351 .60707 m .44594 .60691 L .44639 .60474 L F
.912 .51 .196 r
.52557 .57403 m .5237 .57298 L .52297 .57093 L F
.021 .594 .725 r
.21066 .53805 m .2121 .53802 L .21442 .53805 L F
.433 0 0 r
.21063 .53846 m .21311 .538 L .2121 .53802 L F
.136 .683 .772 r
.2121 .53802 m .21445 .53775 L .21659 .5377 L F
.433 0 0 r
.21311 .538 m .21445 .53775 L .2121 .53802 L F
.021 .594 .725 r
.21033 .53805 m .2121 .53802 L .21066 .53805 L F
.136 .683 .772 r
.2121 .53802 m .21659 .5377 L .21442 .53805 L F
.822 .999 .828 r
.75501 .40305 m .75389 .40539 L .75506 .40415 L F
0 0 0 r
.55483 .58279 m .55732 .57954 L .55488 .58022 L F
.655 .711 .89 r
.1647 .59781 m .16046 .59685 L .16249 .59527 L F
.715 .672 .125 r
.16542 .59274 m .16483 .5967 L .16365 .59339 L F
.482 .511 .811 r
.16501 .5953 m .16495 .59571 L .16483 .5967 L F
0 .335 .815 r
.16249 .59527 m .16483 .5967 L .16469 .59781 L F
.482 .511 .811 r
.16495 .59571 m .16441 .59929 L .16483 .5967 L F
0 .335 .815 r
.16469 .59781 m .16483 .5967 L .1647 .59781 L F
0 .382 .843 r
.16483 .5967 m .16617 .59842 L .1647 .59781 L F
.514 .811 .999 r
.75719 .3852 m .7559 .38662 L .75483 .38507 L F
.75719 .3852 m .75838 .38625 L .7559 .38662 L F
.298 .291 .682 r
.77402 .41801 m .77177 .41973 L .77155 .41627 L F
.147 0 .375 r
.77399 .42036 m .77177 .41973 L .77402 .41801 L F
.77399 .42036 m .77132 .42224 L .77177 .41973 L F
.701 .737 .879 r
.24172 .55153 m .24319 .55342 L .24571 .55244 L F
.937 .679 .519 r
.49825 .54051 m .49825 .54331 L .49971 .54339 L F
.87 .474 .284 r
.49825 .54331 m .49847 .54496 L .49971 .54339 L F
.627 .158 .122 r
.49847 .54496 m .50247 .54413 L .49971 .54339 L F
.772 .828 .896 r
.67668 .43597 m .67462 .43735 L .67784 .43735 L F
.764 .853 .917 r
.67784 .43735 m .67992 .43363 L .67668 .43597 L F
.67784 .43735 m .68145 .4351 L .67992 .43363 L F
.575 .538 .776 r
.72974 .39872 m .73142 .39451 L .72882 .39489 L F
.72974 .39872 m .73234 .39805 L .73142 .39451 L F
.961 .817 .655 r
.56791 .56239 m .56716 .56489 L .56642 .56177 L F
0 .266 .77 r
.18899 .6179 m .19009 .61957 L .18917 .61898 L F
.8 .715 .771 r
.42571 .65541 m .4294 .65611 L .42791 .6524 L F
0 0 0 r
.42705 .65801 m .42784 .65779 L .4294 .65611 L F
.937 .728 .595 r
.42571 .65541 m .42705 .65801 L .4294 .65611 L F
.747 .69 .797 r
.42791 .6524 m .4294 .65611 L .43196 .65286 L F
.591 .128 .123 r
.4294 .65611 m .42784 .65779 L .43181 .65771 L F
.636 .243 .282 r
.55652 .50194 m .56008 .50307 L .56015 .5014 L F
.55652 .50194 m .55631 .50334 L .56008 .50307 L F
.697 .836 .95 r
.73415 .39012 m .73468 .39247 L .73213 .39196 L F
0 0 0 r
.73468 .39247 m .73142 .39451 L .73213 .39196 L F
.105 0 .109 r
.27209 .57627 m .27563 .57275 L .27271 .5738 L F
.229 .571 .94 r
.47635 .55738 m .47836 .5583 L .47768 .55901 L F
.837 .427 .264 r
.47836 .5583 m .48005 .5586 L .47768 .55901 L F
.134 .679 .808 r
.20634 .53814 m .21033 .53805 L .20822 .53868 L F
.936 .698 .552 r
.51543 .60915 m .51767 .6075 L .51711 .60622 L F
.51543 .60915 m .51708 .60989 L .51767 .6075 L F
.219 .74 .75 r
.7963 .44492 m .79278 .44567 L .79364 .44577 L F
.663 .762 .923 r
.66565 .42734 m .66697 .42891 L .66325 .42821 L F
.8 .798 .85 r
.67 .42617 m .66697 .42891 L .66565 .42734 L F
.31 0 .099 r
.24942 .62099 m .24809 .62006 L .24708 .62118 L F
.24942 .62099 m .25049 .61947 L .24809 .62006 L F
.853 .735 .732 r
.4526 .61605 m .4508 .61967 L .44857 .61862 L F
.797 .474 .442 r
.45112 .61738 m .45484 .61618 L .45133 .61692 L F
.853 .735 .732 r
.45133 .61692 m .44857 .61862 L .44955 .61814 L F
.4526 .61605 m .44955 .61814 L .45112 .61738 L F
.797 .474 .442 r
.45112 .61738 m .45133 .61692 L .45057 .61709 L F
.853 .735 .732 r
.4526 .61605 m .45137 .61684 L .45133 .61692 L F
.45137 .61684 m .44857 .61862 L .45133 .61692 L F
.485 .055 .148 r
.4526 .61605 m .45057 .61709 L .45133 .61692 L F
.4526 .61605 m .45133 .61692 L .45484 .61618 L F
.853 .735 .732 r
.4526 .61605 m .45112 .61738 L .45057 .61709 L F
0 0 0 r
.24279 .65559 m .24344 .65434 L .24158 .65499 L F
.628 .267 .339 r
.24736 .65524 m .24571 .65283 L .24279 .65559 L F
.467 .228 .468 r
.24571 .65283 m .24794 .65233 L .24736 .65524 L F
.688 .743 .893 r
.24854 .65276 m .24736 .65524 L .24612 .65362 L F
.2477 .65271 m .24612 .65362 L .24532 .65257 L F
.24854 .65276 m .24612 .65362 L .2477 .65271 L F
0 0 0 r
.24282 .65553 m .24571 .65283 L .24344 .65434 L F
.24279 .65559 m .2429 .65548 L .24282 .65553 L F
.2429 .65548 m .24571 .65283 L .24282 .65553 L F
.523 .826 1 r
.58266 .52469 m .58368 .52556 L .58235 .52212 L F
.926 .559 .142 r
.58103 .52166 m .58266 .52469 L .58235 .52212 L F
.58103 .52166 m .58156 .5238 L .58266 .52469 L F
.544 .852 .998 r
.58266 .52469 m .58511 .52399 L .58161 .52381 L F
.58266 .52469 m .58161 .52381 L .58156 .5238 L F
.523 .826 1 r
.58266 .52469 m .58373 .52569 L .58368 .52556 L F
.58266 .52469 m .58391 .52565 L .58373 .52569 L F
0 .058 .589 r
.24736 .65524 m .24818 .65879 L .24714 .65891 L F
.066 .623 .808 r
.24714 .65891 m .24702 .65862 L .24437 .65895 L F
.24714 .65891 m .24818 .65879 L .24702 .65862 L F
.547 .311 .51 r
.48055 .61643 m .48314 .61842 L .48263 .61607 L F
.48055 .61643 m .48061 .61887 L .48314 .61842 L F
.455 .596 .903 r
.54903 .60883 m .55036 .60733 L .54766 .60775 L F
.54903 .60883 m .55174 .6093 L .55036 .60733 L F
.546 .633 .889 r
.73966 .40163 m .74382 .40416 L .74212 .4011 L F
.399 .536 .878 r
.74212 .4011 m .74382 .40416 L .74608 .40431 L F
.839 .63 .621 r
.41777 .62882 m .42032 .62865 L .41918 .62801 L F
.191 0 .336 r
.42089 .62622 m .41923 .62745 L .42077 .62654 L F
.539 .899 .971 r
.42519 .6252 m .42394 .62475 L .42284 .62505 L F
.191 0 .336 r
.42189 .62341 m .41966 .6268 L .42093 .6261 L F
.42189 .62341 m .42077 .62654 L .421 .62621 L F
.42189 .62341 m .42093 .62645 L .42178 .62543 L F
.42189 .62341 m .42177 .62564 L .42261 .62119 L F
.539 .899 .971 r
.42194 .62554 m .42177 .62565 L .42291 .62621 L F
.42177 .62565 m .42138 .6259 L .42153 .62593 L F
.42177 .62565 m .42153 .62593 L .42291 .62621 L F
.191 0 .336 r
.42177 .62564 m .42177 .62565 L .42182 .62559 L F
.42177 .62565 m .42175 .62596 L .42182 .6256 L F
.42177 .62565 m .42182 .6256 L .42182 .62559 L F
.42177 .62564 m .42182 .62559 L .42261 .62119 L F
.478 .294 .551 r
.42195 .62552 m .42394 .62475 L .42372 .6217 L F
.539 .899 .971 r
.42194 .62554 m .42203 .62549 L .42195 .62552 L F
.42519 .6252 m .42284 .62505 L .42194 .62554 L F
.478 .294 .551 r
.42175 .62596 m .42394 .62475 L .42195 .62552 L F
.539 .899 .971 r
.42195 .62552 m .42284 .62505 L .42219 .62523 L F
.42203 .62549 m .42284 .62505 L .42195 .62552 L F
.478 .294 .551 r
.42182 .6256 m .42372 .6217 L .42261 .62119 L F
.42175 .62596 m .42196 .62552 L .42182 .6256 L F
.42196 .62552 m .42372 .6217 L .42182 .6256 L F
.897 .956 .829 r
.42138 .6259 m .42108 .62667 L .42291 .62621 L F
.42108 .62667 m .42032 .62865 L .42161 .62743 L F
.42108 .62667 m .42161 .62743 L .42291 .62621 L F
.191 0 .336 r
.42178 .62543 m .42139 .62589 L .42175 .62596 L F
.421 .62621 m .42077 .62654 L .42093 .62645 L F
.42093 .6261 m .41942 .62717 L .42089 .62622 L F
.41966 .6268 m .41942 .62717 L .42093 .6261 L F
.41942 .62717 m .41923 .62745 L .42089 .62622 L F
0 0 0 r
.41923 .62745 m .42041 .62571 L .42093 .62645 L F
.897 .956 .829 r
.42041 .62571 m .42037 .62712 L .42138 .6259 L F
0 0 0 r
.42093 .62645 m .42041 .62571 L .42175 .62596 L F
.539 .899 .971 r
.42194 .62554 m .4219 .62555 L .42138 .6259 L F
.4219 .62555 m .42041 .62571 L .42131 .62589 L F
.4219 .62555 m .42131 .62589 L .42138 .6259 L F
.42185 .62555 m .42219 .62523 L .42041 .62571 L F
.42194 .62554 m .42219 .62523 L .42185 .62555 L F
.42519 .6252 m .42194 .62554 L .42291 .62621 L F
.897 .956 .829 r
.42041 .62571 m .41918 .62801 L .41958 .62824 L F
.42037 .62712 m .41958 .62824 L .42032 .62865 L F
.42041 .62571 m .41958 .62824 L .42037 .62712 L F
.42037 .62712 m .42032 .62865 L .42138 .6259 L F
.5 .563 .851 r
.17535 .60937 m .17329 .60979 L .1721 .60675 L F
.473 .605 .902 r
.78079 .44746 m .78281 .44526 L .78116 .44547 L F
.78079 .44746 m .78368 .44756 L .78281 .44526 L F
.126 0 0 r
.4487 .57805 m .44735 .57806 L .44951 .57708 L F
.4487 .57805 m .44645 .57909 L .44735 .57806 L F
.431 .136 .362 r
.27162 .57101 m .27405 .56847 L .27146 .56764 L F
.27162 .57101 m .27387 .5705 L .27405 .56847 L F
0 0 0 r
.40227 .61644 m .40376 .61578 L .40528 .61416 L F
.629 .595 .797 r
.40287 .61929 m .40376 .61578 L .40227 .61644 L F
.648 .719 .9 r
.82092 .41358 m .82185 .4164 L .82447 .41562 L F
.641 .638 .831 r
.82185 .4164 m .82552 .41722 L .82447 .41562 L F
.772 .916 .936 r
.19569 .74637 m .19482 .75047 L .19735 .7499 L F
.912 .527 .271 r
.51243 .54049 m .50993 .53928 L .51099 .53775 L F
.827 .393 .204 r
.51099 .53775 m .50993 .53928 L .51351 .54017 L F
.941 .626 .412 r
.42876 .66118 m .43062 .66209 L .42918 .66363 L F
.539 .065 .076 r
.42918 .66363 m .43062 .66209 L .43324 .66372 L F
.33 .001 .248 r
.25359 .61599 m .25459 .61796 L .25533 .61516 L F
.25359 .61599 m .25251 .6186 L .25459 .61796 L F
.236 .754 .788 r
.23451 .64469 m .24062 .64352 L .23893 .64336 L F
.138 .684 .747 r
.24062 .64352 m .24115 .64335 L .23893 .64336 L F
.24062 .64352 m .24285 .64319 L .24115 .64335 L F
.585 .167 .215 r
.50247 .54413 m .50453 .5457 L .50576 .54367 L F
.36 .225 .558 r
.44703 .63753 m .44933 .63687 L .44935 .63384 L F
.508 .229 .427 r
.27489 .63099 m .27195 .63308 L .27264 .63146 L F
.697 .889 .968 r
.56946 .60206 m .56933 .60043 L .5677 .60321 L F
.56946 .60206 m .56992 .59974 L .56933 .60043 L F
.56946 .60206 m .57122 .60068 L .56992 .59974 L F
.124 .319 .788 r
.84307 .41028 m .84501 .41042 L .84215 .41112 L F
.496 .294 .535 r
.45563 .59423 m .45334 .59223 L .45607 .59151 L F
.45563 .59423 m .45325 .59479 L .45334 .59223 L F
.45334 .59223 m .45563 .59423 L .45607 .59151 L F
.45334 .59223 m .45325 .59479 L .45563 .59423 L F
.525 0 0 r
.48131 .56224 m .4799 .56215 L .47775 .56116 L F
0 .185 .706 r
.48131 .56224 m .48352 .5646 L .483 .56242 L F
.48131 .56224 m .483 .56242 L .4799 .56215 L F
.672 .386 .479 r
.56008 .50307 m .56247 .50369 L .56015 .5014 L F
.707 .375 .414 r
.56015 .5014 m .56247 .50369 L .56234 .50198 L F
.472 .219 .449 r
.4779 .60318 m .4775 .60681 L .47494 .60729 L F
.388 .15 .427 r
.47968 .60599 m .4779 .60318 L .48027 .60299 L F
.47968 .60599 m .4775 .60681 L .4779 .60318 L F
.701 .588 .726 r
.51581 .53437 m .51476 .53963 L .51996 .53518 L F
0 .002 .574 r
.20419 .74577 m .20267 .74362 L .20441 .74314 L F
.102 0 .147 r
.49073 .5897 m .4929 .58946 L .49297 .58873 L F
.908 .793 .721 r
.56982 .52905 m .5688 .53132 L .56794 .52779 L F
.549 .383 .609 r
.43412 .63432 m .43659 .63473 L .43637 .63149 L F
.549 .382 .607 r
.43412 .63432 m .43479 .63711 L .43659 .63473 L F
.549 .383 .609 r
.43412 .63432 m .43659 .63473 L .43637 .63149 L F
.549 .382 .607 r
.43412 .63432 m .43479 .63711 L .43659 .63473 L F
.517 .219 .4 r
.55279 .51361 m .5528 .51561 L .55 .51597 L F
.578 .269 .41 r
.47494 .60729 m .47193 .60916 L .47245 .60787 L F
.236 0 .056 r
.53926 .51279 m .54156 .51212 L .54242 .51012 L F
.145 0 .02 r
.54242 .51012 m .54377 .51117 L .54496 .50908 L F
.54242 .51012 m .54156 .51212 L .54377 .51117 L F
.72 .239 .104 r
.5057 .55285 m .50424 .55397 L .50358 .55199 L F
.5057 .55285 m .50753 .55467 L .50424 .55397 L F
.773 .496 .516 r
.24653 .64652 m .25111 .64713 L .24984 .64789 L F
.296 .778 .695 r
.25242 .64353 m .25369 .64297 L .25262 .64395 L F
.35 .422 .795 r
.25064 .64515 m .25026 .64538 L .24988 .64457 L F
.25167 .64592 m .25026 .64538 L .25064 .64515 L F
.621 .057 0 r
.25066 .64575 m .25167 .64592 L .24988 .64457 L F
.296 .778 .695 r
.2516 .64457 m .25262 .64395 L .25066 .64575 L F
.25242 .64353 m .25262 .64395 L .2516 .64457 L F
.35 .422 .795 r
.25167 .64592 m .25111 .64713 L .25026 .64538 L F
.829 .995 .853 r
.24984 .64789 m .25111 .64713 L .25167 .64592 L F
.788 .474 .456 r
.49529 .53813 m .49468 .54 L .49825 .54051 L F
.634 .481 .657 r
.45169 .63119 m .45257 .63114 L .45308 .62932 L F
.102 0 0 r
.44935 .63384 m .45257 .63114 L .45169 .63119 L F
.851 .848 .84 r
.5799 .52778 m .58391 .52565 L .58266 .52469 L F
.842 .981 .692 r
.56222 .57605 m .56041 .57951 L .55972 .57897 L F
.558 .21 .334 r
.44438 .57304 m .44217 .57105 L .44201 .5737 L F
.44438 .57304 m .4454 .57028 L .44217 .57105 L F
.511 .274 .492 r
.28579 .62208 m .28307 .62486 L .28342 .62256 L F
.501 .275 .504 r
.47497 .62247 m .47803 .61946 L .47503 .62093 L F
.454 .29 .569 r
.3056 .58679 m .3064 .58914 L .30438 .58924 L F
.467 .441 .745 r
.3064 .58914 m .30671 .59079 L .30438 .58924 L F
.572 .58 .823 r
.30791 .59193 m .30438 .58924 L .30671 .59079 L F
0 0 0 r
.13951 .57639 m .14274 .57377 L .14045 .5753 L F
.189 .711 .87 r
.25138 .53784 m .25355 .53769 L .2553 .53796 L F
.153 .688 .846 r
.25355 .53769 m .25747 .53782 L .2553 .53796 L F
.212 .543 .928 r
.80095 .39652 m .79829 .39471 L .80011 .39533 L F
.143 .586 .929 r
.80343 .39635 m .80095 .39652 L .80011 .39533 L F
.80343 .39635 m .80449 .39732 L .80095 .39652 L F
.758 .426 0 r
.53692 .579 m .53839 .58294 L .53829 .5806 L F
.983 .879 .647 r
.75447 .41312 m .7532 .41291 L .75405 .40986 L F
0 0 0 r
.75447 .41312 m .75294 .41632 L .75436 .41438 L F
.75447 .41312 m .75436 .41438 L .7532 .41291 L F
.846 .817 .82 r
.75707 .41007 m .75447 .41312 L .75405 .40986 L F
.432 .135 .359 r
.65328 .42542 m .6558 .42476 L .65594 .42298 L F
.392 .056 .271 r
.65873 .42252 m .6558 .42476 L .65594 .42298 L F
.489 .389 .668 r
.81734 .42756 m .81716 .42498 L .81442 .42576 L F
.5 .385 .654 r
.81489 .42818 m .81734 .42756 L .81442 .42576 L F
.834 .835 .847 r
.75707 .41007 m .75405 .40986 L .75572 .4085 L F
.801 .83 .874 r
.75987 .40738 m .75707 .41007 L .75572 .4085 L F
.825 .631 .641 r
.56716 .51681 m .56657 .51925 L .56466 .51606 L F
.513 .064 .122 r
.45553 .57508 m .45556 .57662 L .45175 .57642 L F
.293 0 .119 r
.45751 .5756 m .45556 .57662 L .45553 .57508 L F
.686 .535 .675 r
.45308 .62932 m .45257 .63114 L .45498 .62868 L F
.809 .551 .547 r
.57494 .50383 m .57866 .50689 L .5788 .5044 L F
.905 .51 .25 r
.51638 .56185 m .51467 .56118 L .51388 .55904 L F
0 0 .392 r
.51638 .56185 m .51759 .56453 L .51722 .56296 L F
.51638 .56185 m .51722 .56296 L .51467 .56118 L F
.767 .488 .512 r
.44594 .61627 m .44352 .61798 L .44243 .61646 L F
.44594 .61627 m .44608 .61952 L .44521 .61935 L F
.44352 .61798 m .44521 .61935 L .44236 .6188 L F
.44594 .61627 m .44521 .61935 L .44352 .61798 L F
.636 .385 .522 r
.44857 .61862 m .44608 .61952 L .44594 .61627 L F
.74 .671 .783 r
.44857 .61862 m .44632 .62164 L .44626 .6211 L F
.44709 .61915 m .44626 .6211 L .44608 .61952 L F
.44857 .61862 m .44626 .6211 L .44709 .61915 L F
.636 .385 .522 r
.44857 .61862 m .44594 .61627 L .44895 .61728 L F
.875 .702 .664 r
.4508 .61967 m .44998 .62226 L .44857 .61862 L F
.713 .631 .764 r
.44857 .61862 m .44998 .62226 L .44632 .62164 L F
.474 .389 .68 r
.45112 .61738 m .44857 .61862 L .44895 .61728 L F
.145 .016 .433 r
.44845 .616 m .44835 .61974 L .44974 .61741 L F
.448 .61551 m .44811 .61679 L .44845 .616 L F
.44811 .61679 m .44835 .61974 L .44845 .616 L F
.408 .511 .851 r
.44509 .61876 m .44542 .61952 L .44741 .61992 L F
.44542 .61952 m .44573 .62023 L .44594 .62019 L F
.44542 .61952 m .44594 .62019 L .44585 .61987 L F
.767 .488 .512 r
.44352 .61798 m .44236 .6188 L .4424 .61741 L F
.44352 .61798 m .4424 .61741 L .44243 .61646 L F
.713 .683 .82 r
.44236 .6188 m .44573 .62023 L .44541 .61948 L F
.747 .388 .373 r
.44608 .61952 m .44598 .61961 L .44236 .6188 L F
.713 .683 .82 r
.44236 .6188 m .44541 .61948 L .44334 .61474 L F
.77 .314 .167 r
.44236 .6188 m .44466 .62077 L .44573 .62023 L F
.747 .388 .373 r
.44598 .61961 m .44466 .62077 L .44236 .6188 L F
.966 .818 .646 r
.44632 .62164 m .44466 .62077 L .44593 .62018 L F
.44615 .62015 m .44581 .61976 L .44608 .61952 L F
.44628 .62128 m .44594 .62019 L .44615 .62015 L F
.44594 .62019 m .44581 .61976 L .44615 .62015 L F
.408 .511 .851 r
.44542 .61952 m .44618 .62014 L .44741 .61992 L F
0 0 0 r
.44594 .62019 m .44729 .61993 L .44835 .61974 L F
.44573 .62023 m .4459 .6202 L .44594 .62019 L F
.4459 .6202 m .44729 .61993 L .44594 .62019 L F
.966 .818 .646 r
.44632 .62164 m .44581 .61976 L .44628 .62128 L F
0 0 0 r
.4459 .6202 m .44466 .62077 L .44729 .61993 L F
.44573 .62023 m .44466 .62077 L .4459 .6202 L F
.966 .818 .646 r
.44593 .62018 m .44466 .62077 L .44581 .61976 L F
.408 .511 .851 r
.44585 .61987 m .44594 .62019 L .44618 .62014 L F
.44334 .61474 m .44509 .61876 L .44835 .61974 L F
.44509 .61876 m .44741 .61992 L .44835 .61974 L F
.619 .558 .763 r
.4066 .62532 m .40784 .62915 L .41044 .62825 L F
.544 .351 .57 r
.40784 .62915 m .41016 .63092 L .41044 .62825 L F
.497 .878 .682 r
.19361 .55918 m .19151 .56035 L .19023 .56142 L F
0 0 0 r
.1935 .55965 m .19361 .55918 L .19613 .5591 L F
.1935 .55965 m .19151 .56035 L .19361 .55918 L F
.435 .569 .889 r
.16897 .6254 m .171 .62851 L .17276 .62817 L F
.41 .515 .855 r
.171 .62851 m .17452 .63165 L .17276 .62817 L F
.367 .795 .97 r
.48562 .61344 m .48935 .61365 L .48692 .61433 L F
.66 .431 .561 r
.21732 .55301 m .21917 .55424 L .22002 .55283 L F
.918 .523 .203 r
.8235 .44293 m .82472 .44385 L .82423 .44553 L F
.273 .778 .813 r
.82702 .4431 m .82472 .44385 L .8235 .44293 L F
.82702 .4431 m .82736 .44321 L .82472 .44385 L F
0 0 0 r
.82472 .44385 m .82571 .4439 L .82423 .44553 L F
.82472 .44385 m .82736 .44321 L .82571 .4439 L F
.529 .42 .674 r
.15468 .58557 m .15594 .59017 L .15265 .58948 L F
.547 .353 .57 r
.15594 .59017 m .15496 .59168 L .15265 .58948 L F
.344 .514 .882 r
.20028 .62384 m .19792 .62336 L .19681 .62115 L F
.3 .652 .97 r
.20698 .6452 m .20966 .64651 L .20866 .64532 L F
.441 .74 .991 r
.20966 .64651 m .21186 .64632 L .20866 .64532 L F
0 0 0 r
.54297 .51869 m .54061 .51955 L .54133 .51911 L F
.76 .983 .908 r
.75501 .40305 m .75506 .40415 L .75869 .40144 L F
.33 0 .237 r
.4476 .5698 m .4454 .57028 L .44438 .57304 L F
.732 .549 .645 r
.41485 .63086 m .41797 .63173 L .41777 .62882 L F
.16 0 .014 r
.1533 .56428 m .15511 .564 L .15644 .56203 L F
.212 0 .026 r
.15511 .564 m .15857 .56142 L .15644 .56203 L F
.552 .92 .944 r
.55448 .58901 m .55301 .58886 L .55503 .58791 L F
.272 .636 .964 r
.55503 .58791 m .55693 .58942 L .55448 .58901 L F
0 0 .474 r
.20664 .72878 m .20782 .73078 L .20619 .72843 L F
.20664 .72878 m .20619 .72843 L .20417 .72899 L F
.492 .113 .249 r
.23659 .67513 m .23815 .677 L .23752 .6752 L F
.369 .098 .366 r
.23559 .67695 m .23815 .677 L .23659 .67513 L F
.559 .407 .632 r
.30879 .58204 m .30758 .58775 L .3056 .58679 L F
.485 .225 .445 r
.30758 .58775 m .3064 .58914 L .3056 .58679 L F
.266 .771 .86 r
.26376 .53754 m .26605 .53712 L .26764 .53721 L F
.334 .813 .779 r
.26764 .53721 m .26841 .5367 L .27053 .53619 L F
.278 .778 .865 r
.26605 .53712 m .26841 .5367 L .26764 .53721 L F
0 .549 .707 r
.21879 .53761 m .22283 .53781 L .22061 .5382 L F
.666 .503 .654 r
.45257 .63114 m .45599 .63172 L .45498 .62868 L F
.307 .59 .944 r
.45441 .6274 m .45708 .62923 L .45498 .62868 L F
.228 .243 .668 r
.45498 .62868 m .45599 .63172 L .45626 .62989 L F
.552 .729 .957 r
.30916 .59034 m .30791 .59193 L .30671 .59079 L F
.465 .298 .569 r
.30916 .59034 m .30734 .59382 L .30791 .59193 L F
.539 .004 0 r
.22467 .69438 m .22865 .69463 L .2254 .69366 L F
.448 .742 .991 r
.81708 .40013 m .81544 .40157 L .81449 .40022 L F
.81708 .40013 m .81801 .40136 L .81544 .40157 L F
.188 0 .118 r
.25479 .64258 m .2558 .64095 L .25773 .64016 L F
.719 .727 .856 r
.42857 .61541 m .42964 .61922 L .4324 .61598 L F
.71 .269 .2 r
.67302 .41605 m .67552 .4182 L .67665 .41663 L F
.739 .304 .219 r
.67552 .4182 m .67927 .4189 L .67665 .41663 L F
.971 .825 .642 r
.56966 .53719 m .56733 .53959 L .56845 .53612 L F
.56966 .53719 m .56864 .54069 L .56733 .53959 L F
.619 .889 .989 r
.55995 .58935 m .55693 .58942 L .55795 .58801 L F
.896 .516 .065 r
.51126 .58864 m .51089 .587 L .50946 .58543 L F
.93 .679 .196 r
.42052 .67711 m .41994 .67775 L .4191 .676 L F
.42052 .67711 m .42062 .67993 L .41994 .67775 L F
.41994 .67775 m .42052 .67711 L .42176 .67542 L F
.41994 .67775 m .42062 .67993 L .42052 .67711 L F
0 .157 .64 r
.49571 .56705 m .49554 .56721 L .49479 .56603 L F
.49571 .56705 m .49702 .56831 L .49554 .56721 L F
.728 .392 .411 r
.56234 .50198 m .56247 .50369 L .5662 .50393 L F
.622 .565 .769 r
.30879 .58204 m .30549 .58013 L .30787 .57937 L F
.774 .659 .736 r
.77107 .40095 m .77429 .40174 L .77329 .39778 L F
.502 .487 .772 r
.77329 .39778 m .77429 .40174 L .77655 .39974 L F
.505 .492 .776 r
.77429 .40174 m .77713 .40125 L .77655 .39974 L F
.936 .571 .29 r
.51477 .60014 m .51671 .6033 L .51645 .60119 L F
.817 .667 .696 r
.43033 .65197 m .43196 .65286 L .43298 .64997 L F
.99 .812 .57 r
.43496 .64772 m .43659 .64928 L .43298 .64997 L F
.4357 .64739 m .43659 .64928 L .43496 .64772 L F
.43554 .64706 m .43519 .64887 L .43659 .64928 L F
.978 .872 .663 r
.43659 .64928 m .43755 .64407 L .43898 .64713 L F
.43659 .64928 m .43519 .64887 L .43755 .64407 L F
.365 .101 .375 r
.43745 .64659 m .43519 .64887 L .4374 .64787 L F
.43755 .64407 m .43598 .64726 L .43745 .64659 L F
.43598 .64726 m .43519 .64887 L .43745 .64659 L F
.99 .812 .57 r
.43554 .64706 m .4357 .64739 L .43496 .64772 L F
.987 .74 .469 r
.43659 .64928 m .43323 .64972 L .43298 .64997 L F
.96 .699 .496 r
.58119 .51854 m .58285 .51959 L .58124 .51607 L F
.956 .744 .576 r
.58235 .52212 m .58285 .51959 L .58119 .51854 L F
.868 .536 .42 r
.76643 .38555 m .766 .38327 L .76325 .3823 L F
.453 .384 .689 r
.26541 .59818 m .26744 .59755 L .26675 .59492 L F
.357 .208 .538 r
.26541 .59818 m .26721 .60019 L .26744 .59755 L F
.26541 .59818 m .26544 .60105 L .26721 .60019 L F
.66 .965 .921 r
.23729 .55111 m .23634 .55228 L .23929 .55179 L F
.23729 .55111 m .23541 .55231 L .23634 .55228 L F
.616 .636 .847 r
.67206 .43824 m .67357 .43383 L .67102 .4361 L F
.67206 .43824 m .67462 .43735 L .67357 .43383 L F
0 .342 .799 r
.79241 .39189 m .78919 .38958 L .79103 .39111 L F
0 .344 .725 r
.79103 .39111 m .79402 .39263 L .79241 .39189 L F
.351 .176 .499 r
.21817 .69921 m .21963 .70059 L .22011 .6977 L F
.32 .646 .968 r
.79056 .43622 m .78886 .43725 L .7877 .43692 L F
.79056 .43622 m .79142 .43772 L .78886 .43725 L F
.426 .148 .387 r
.28069 .62549 m .28002 .62805 L .2778 .62859 L F
.484 .208 .42 r
.28307 .62486 m .28002 .62805 L .28069 .62549 L F
.777 .958 .642 r
.40528 .61416 m .40376 .61578 L .40611 .61271 L F
.692 .752 .898 r
.40284 .6246 m .40407 .62605 L .4066 .62532 L F
.958 .82 .665 r
.53081 .56053 m .53163 .56659 L .53302 .56596 L F
.832 .77 .793 r
.53317 .56084 m .53081 .56053 L .53302 .56596 L F
.902 .791 .728 r
.53081 .56053 m .53284 .56525 L .53163 .56659 L F
.53284 .56525 m .53316 .56599 L .5327 .56617 L F
.53284 .56525 m .5327 .56617 L .53163 .56659 L F
.832 .77 .793 r
.53341 .56142 m .53302 .56596 L .53364 .56195 L F
.53317 .56084 m .53309 .56361 L .53341 .56142 L F
.53309 .56361 m .53302 .56596 L .53341 .56142 L F
0 0 .217 r
.27841 .57105 m .27801 .57354 L .27896 .57274 L F
.569 .277 .433 r
.28236 .57177 m .27896 .57274 L .28286 .56982 L F
.28286 .56982 m .27896 .57274 L .28236 .57177 L F
.28087 .57006 m .28286 .56982 L .27963 .56864 L F
0 0 0 r
.27938 .56907 m .27826 .57123 L .27913 .56965 L F
.27997 .5677 m .27891 .56988 L .27938 .56907 L F
.932 .969 .699 r
.27841 .57105 m .27782 .57015 L .27997 .5677 L F
0 0 0 r
.27891 .56988 m .27826 .57123 L .27938 .56907 L F
.696 .647 .797 r
.2811 .56608 m .28286 .56982 L .27963 .56864 L F
.569 .277 .433 r
.28236 .57177 m .27963 .56864 L .27957 .56876 L F
0 0 0 r
.27997 .5677 m .27913 .56965 L .28038 .56711 L F
.773 .48 .49 r
.28286 .56982 m .28236 .57177 L .27957 .56876 L F
.27963 .56864 m .27957 .56876 L .27937 .56854 L F
.28286 .56982 m .27957 .56876 L .27963 .56864 L F
0 0 0 r
.27826 .57123 m .27826 .57124 L .2791 .56971 L F
.27913 .56965 m .2791 .56971 L .2811 .56608 L F
.27826 .57123 m .2791 .56971 L .27913 .56965 L F
.28038 .56711 m .27913 .56965 L .2811 .56608 L F
.696 .647 .797 r
.2811 .56608 m .27963 .56864 L .27937 .56854 L F
.569 .277 .433 r
.27957 .56876 m .27963 .56864 L .27937 .56854 L F
.663 .334 .405 r
.2775 .56933 m .27782 .57015 L .27997 .5677 L F
0 0 .217 r
.27826 .57086 m .27826 .57116 L .27796 .57048 L F
.27841 .57105 m .27826 .57116 L .27826 .57086 L F
.27841 .57105 m .27796 .57048 L .27782 .57015 L F
.663 .334 .405 r
.27723 .57083 m .27822 .57131 L .27827 .57122 L F
.27782 .57015 m .27827 .57122 L .27997 .5677 L F
.27723 .57083 m .27827 .57122 L .27782 .57015 L F
.27606 .57027 m .27723 .57083 L .27782 .57015 L F
.27606 .57027 m .27782 .57015 L .2775 .56933 L F
.27606 .57027 m .27997 .5677 L .27778 .57008 L F
.692 .329 0 r
.27778 .57008 m .27818 .57103 L .27606 .57027 L F
.528 .489 .756 r
.27809 .571 m .27822 .57131 L .27606 .57027 L F
0 0 0 r
.27826 .57123 m .27822 .57131 L .27826 .57124 L F
.692 .329 0 r
.27818 .57103 m .27856 .57192 L .27606 .57027 L F
.528 .489 .756 r
.27669 .56773 m .27809 .571 L .27606 .57027 L F
.692 .329 0 r
.27778 .57008 m .27796 .57048 L .27825 .57118 L F
.27778 .57008 m .27825 .57118 L .27818 .57103 L F
0 0 .217 r
.27782 .57015 m .27796 .57048 L .27778 .57008 L F
.932 .969 .699 r
.27782 .57015 m .27778 .57008 L .27997 .5677 L F
.528 .489 .756 r
.27717 .56579 m .27816 .57099 L .27669 .56773 L F
.27816 .57099 m .27822 .57131 L .27669 .56773 L F
.692 .329 0 r
.27818 .57103 m .27825 .57118 L .27856 .57192 L F
.27796 .57048 m .27896 .57274 L .27863 .57208 L F
.27796 .57048 m .27863 .57208 L .27856 .57192 L F
.762 .647 .734 r
.2811 .56608 m .2791 .56971 L .27717 .56579 L F
.2791 .56971 m .27822 .57131 L .27787 .56947 L F
.2791 .56971 m .27787 .56947 L .27717 .56579 L F
.569 .277 .433 r
.28236 .57177 m .2827 .57042 L .28087 .57006 L F
.2827 .57042 m .28286 .56982 L .28087 .57006 L F
0 0 .217 r
.27841 .57105 m .27896 .57274 L .27826 .57116 L F
0 0 0 r
.23663 .62487 m .23246 .62702 L .23477 .62686 L F
.418 0 0 r
.23477 .62686 m .23907 .6254 L .23663 .62487 L F
.495 .125 .265 r
.43707 .61287 m .4414 .61053 L .43866 .61007 L F
.43707 .61287 m .44092 .6124 L .4414 .61053 L F
.639 .258 .307 r
.44092 .6124 m .44333 .61254 L .4414 .61053 L F
.494 .267 .5 r
.4414 .61053 m .44333 .61254 L .44387 .60963 L F
.552 .402 .631 r
.47085 .60134 m .47374 .60343 L .4732 .59805 L F
.626 .358 .492 r
.47072 .6037 m .47374 .60343 L .47085 .60134 L F
0 0 0 r
.76043 .38432 m .76119 .38314 L .75838 .38625 L F
.069 0 0 r
.76325 .3823 m .76119 .38314 L .76043 .38432 L F
.245 .407 .826 r
.43364 .65334 m .43555 .65578 L .43642 .65401 L F
0 0 0 r
.41923 .62745 m .41918 .62801 L .42041 .62571 L F
.222 .234 .661 r
.49424 .57924 m .49429 .58339 L .49632 .58153 L F
.114 .098 .56 r
.4951 .58544 m .49632 .58153 L .49429 .58339 L F
.576 .789 .98 r
.74015 .3885 m .74334 .38928 L .74169 .3862 L F
.641 .674 .866 r
.74169 .3862 m .74334 .38928 L .7459 .38797 L F
.514 .615 .89 r
.7529 .41855 m .75527 .41786 L .75294 .41632 L F
.7529 .41855 m .75624 .41971 L .75527 .41786 L F
.554 .601 .855 r
.82447 .41562 m .82552 .41722 L .82724 .41508 L F
.623 .557 .76 r
.82552 .41722 m .82825 .41672 L .82724 .41508 L F
.803 .649 .691 r
.49932 .61878 m .49724 .62201 L .50086 .62248 L F
.593 .027 0 r
.48688 .56076 m .48987 .56252 L .48762 .56191 L F
.639 .211 0 r
.53322 .59141 m .53072 .5875 L .5317 .58899 L F
0 0 0 r
.25747 .53782 m .25981 .53779 L .26149 .53775 L F
.019 0 0 r
.25981 .53779 m .26376 .53754 L .26149 .53775 L F
.474 .368 .654 r
.20004 .73146 m .20217 .73371 L .20177 .72997 L F
.494 .762 .99 r
.19577 .64341 m .19951 .64422 L .19786 .64331 L F
.426 .792 .995 r
.19951 .64422 m .20031 .64302 L .19786 .64331 L F
.19951 .64422 m .20173 .64385 L .20031 .64302 L F
.633 .877 .987 r
.78664 .44681 m .7879 .44785 L .79037 .4468 L F
0 0 0 r
.18445 .54619 m .18553 .54601 L .18659 .54546 L F
.18445 .54619 m .18246 .54781 L .18553 .54601 L F
.513 .769 .989 r
.288 .53979 m .28754 .54156 L .28594 .53991 L F
.288 .53979 m .28975 .54111 L .28754 .54156 L F
.102 0 0 r
.44935 .63384 m .45113 .6333 L .45257 .63114 L F
.747 .376 .351 r
.45113 .6333 m .45495 .63379 L .45257 .63114 L F
.668 .391 .493 r
.45257 .63114 m .45495 .63379 L .45599 .63172 L F
.803 .558 .567 r
.43181 .65771 m .43548 .65836 L .43555 .65578 L F
.519 .744 .977 r
.43555 .65578 m .43817 .65558 L .43642 .65401 L F
.43555 .65578 m .43817 .65558 L .43642 .65401 L F
0 0 .442 r
.5282 .57973 m .53016 .58305 L .52953 .58182 L F
.871 .477 .01 r
.53016 .58305 m .52994 .5845 L .52953 .58182 L F
.53016 .58305 m .53131 .58596 L .52994 .5845 L F
.582 .359 .543 r
.73851 .38504 m .73582 .3828 L .73542 .38531 L F
.73851 .38504 m .73847 .38259 L .73582 .3828 L F
.596 .823 .986 r
.18806 .64 m .19265 .64064 L .19321 .63962 L F
.501 .816 1 r
.19321 .63962 m .19265 .64064 L .19429 .63993 L F
.636 .628 .825 r
.65595 .42755 m .65788 .4321 L .65454 .43147 L F
.65595 .42755 m .65454 .43147 L .65598 .42986 L F
.549 .568 .826 r
.65494 .43246 m .65598 .42986 L .65454 .43147 L F
.076 .615 .855 r
.29935 .54593 m .30368 .54672 L .30138 .54767 L F
.058 .623 .721 r
.22283 .53781 m .22531 .53765 L .22673 .53759 L F
.313 .799 .883 r
.22531 .53765 m .22893 .53728 L .22673 .53759 L F
.322 0 0 r
.81246 .43329 m .81504 .433 L .8159 .43155 L F
.558 .527 .776 r
.8159 .43155 m .81734 .42756 L .81489 .42818 L F
0 .227 .748 r
.81767 .43207 m .81845 .43379 L .8159 .43155 L F
.81767 .43207 m .8159 .43155 L .81504 .433 L F
.437 .876 .863 r
.21049 .72329 m .21179 .72239 L .20914 .72176 L F
.21049 .72329 m .21323 .72229 L .21179 .72239 L F
.897 .748 .688 r
.58284 .55465 m .58084 .55816 L .58338 .55838 L F
.897 .748 .689 r
.58084 .55816 m .58216 .56156 L .58338 .55838 L F
.02 0 0 r
.23162 .55041 m .22748 .55062 L .22934 .55069 L F
0 0 0 r
.49297 .58873 m .4951 .58544 L .49289 .58612 L F
.20252 .55721 m .20256 .55677 L .2047 .55624 L F
.20252 .55721 m .20048 .55787 L .20256 .55677 L F
.273 0 0 r
.1645 .57626 m .16066 .57823 L .16278 .57707 L F
.653 .752 .923 r
.81815 .4156 m .81996 .41184 L .81719 .41227 L F
.81815 .4156 m .82092 .41358 L .81996 .41184 L F
.881 .945 .85 r
.76864 .4082 m .76798 .41135 L .77036 .40857 L F
0 0 0 r
.76864 .4082 m .76704 .41249 L .76798 .41135 L F
.538 .354 .579 r
.30939 .55513 m .30915 .55788 L .30683 .55835 L F
.572 .461 .688 r
.30992 .5613 m .30683 .55835 L .30915 .55788 L F
.30992 .5613 m .30753 .5619 L .30683 .55835 L F
.957 .623 .24 r
.6592 .4108 m .66275 .41277 L .66329 .40999 L F
.07 .454 .882 r
.50085 .5892 m .5014 .58851 L .49931 .58935 L F
.50085 .5892 m .50226 .5901 L .5014 .58851 L F
.645 .935 .967 r
.74955 .39154 m .7474 .3928 L .74643 .39217 L F
.8 .798 .85 r
.67 .42617 m .66565 .42734 L .66807 .42451 L F
.91 .768 .691 r
.56791 .55574 m .56486 .55748 L .56647 .55477 L F
.56791 .55574 m .56663 .55844 L .56486 .55748 L F
.58 .478 .703 r
.48144 .57701 m .48405 .57656 L .48304 .5733 L F
.552 .37 .588 r
.48144 .57701 m .48401 .57916 L .48405 .57656 L F
.48144 .57701 m .48151 .57962 L .48401 .57916 L F
.33 .367 .749 r
.48401 .57916 m .48144 .57701 L .48405 .57656 L F
.923 .597 .134 r
.78838 .3886 m .78919 .38958 L .78837 .38862 L F
0 .104 .593 r
.78992 .39004 m .78919 .38958 L .78838 .3886 L F
.78992 .39004 m .79103 .39111 L .78919 .38958 L F
.529 .675 .931 r
.1633 .62404 m .16363 .62127 L .16194 .62154 L F
.1633 .62404 m .16572 .62393 L .16363 .62127 L F
.436 .874 .825 r
.20185 .53996 m .20276 .53922 L .20386 .53881 L F
.20185 .53996 m .20094 .53991 L .20276 .53922 L F
.267 0 0 r
.23324 .64457 m .23451 .64469 L .23472 .64444 L F
.235 .745 .713 r
.23451 .64469 m .23576 .64416 L .23472 .64444 L F
.23451 .64469 m .23893 .64336 L .23576 .64416 L F
.666 .662 .836 r
.24571 .55244 m .2493 .55328 L .24765 .55195 L F
.697 .784 .918 r
.24765 .55195 m .2493 .55328 L .25176 .55271 L F
.582 .481 .705 r
.45255 .60406 m .45499 .60342 L .45457 .60085 L F
.632 .577 .774 r
.45578 .60485 m .45255 .60406 L .45499 .60342 L F
0 0 .362 r
.45255 .60406 m .45322 .60766 L .45499 .60342 L F
.582 .481 .705 r
.45457 .60085 m .45499 .60342 L .45255 .60406 L F
.397 .781 .991 r
.47621 .62563 m .47487 .62489 L .47352 .62516 L F
.666 .146 0 r
.47621 .62563 m .47847 .62749 L .47425 .62646 L F
.525 .272 .474 r
.47869 .62518 m .47847 .62749 L .47621 .62563 L F
.564 .604 .852 r
.49939 .60402 m .50064 .60729 L .50288 .60604 L F
.615 .748 .94 r
.8353 .40527 m .83172 .40454 L .83434 .40375 L F
.655 .764 .93 r
.83801 .40445 m .8353 .40527 L .83434 .40375 L F
.495 .834 .998 r
.24038 .55046 m .23929 .55179 L .24172 .55153 L F
.24038 .55046 m .23729 .55111 L .23929 .55179 L F
.444 .379 .69 r
.31045 .5639 m .30902 .56791 L .3081 .56432 L F
.31045 .5639 m .31096 .56761 L .30902 .56791 L F
.483 .429 .72 r
.31181 .57005 m .30902 .56791 L .31096 .56761 L F
.31181 .57005 m .30979 .57082 L .30902 .56791 L F
0 0 .476 r
.53367 .59507 m .53398 .59369 L .53322 .59141 L F
.858 .623 .086 r
.53461 .5976 m .53398 .59369 L .53367 .59507 L F
.405 .183 .461 r
.73414 .38781 m .73606 .38813 L .73542 .38531 L F
.73414 .38781 m .73421 .38975 L .73606 .38813 L F
.367 .795 .97 r
.48562 .61344 m .48817 .61316 L .48935 .61365 L F
0 .204 .726 r
.49013 .61303 m .48935 .61365 L .48817 .61316 L F
.49013 .61303 m .49105 .61507 L .48935 .61365 L F
.219 .236 .665 r
.49105 .61507 m .49026 .61664 L .48935 .61365 L F
.972 .917 .587 r
.52713 .52445 m .52856 .52323 L .52927 .52502 L F
.52713 .52445 m .52817 .52182 L .52856 .52323 L F
.628 .307 .408 r
.42821 .58234 m .43044 .58234 L .43167 .58047 L F
.488 .394 .675 r
.43167 .58047 m .43379 .58032 L .43353 .57631 L F
.604 .368 .532 r
.43044 .58234 m .43379 .58032 L .43167 .58047 L F
.789 .736 .804 r
.74705 .37945 m .74992 .37999 L .74958 .37628 L F
.614 .073 0 r
.74978 .38116 m .74992 .37999 L .74705 .37945 L F
.394 .433 .783 r
.74958 .37628 m .74992 .37999 L .75226 .37826 L F
.698 .864 .961 r
.74978 .38116 m .75226 .37826 L .74992 .37999 L F
.649 .89 .547 r
.43637 .63149 m .4388 .62848 L .43686 .62746 L F
.43637 .63149 m .43708 .63024 L .4388 .62848 L F
.363 .244 .581 r
.43637 .63149 m .43871 .63295 L .43708 .63024 L F
.43637 .63149 m .43659 .63473 L .43871 .63295 L F
.43871 .63295 m .43659 .63473 L .43637 .63149 L F
.535 .556 .823 r
.43538 .62537 m .43748 .6249 L .43609 .6214 L F
.489 .9 .907 r
.79971 .43564 m .80248 .43462 L .80372 .43483 L F
.431 .869 .901 r
.80372 .43483 m .80773 .4332 L .80661 .43424 L F
.80372 .43483 m .80248 .43462 L .80773 .4332 L F
.696 .779 .915 r
.83068 .41571 m .83435 .41629 L .83335 .41491 L F
.644 .725 .908 r
.83435 .41629 m .83636 .41265 L .83335 .41491 L F
.83435 .41629 m .83707 .41554 L .83636 .41265 L F
.541 .557 .82 r
.83435 .41629 m .83811 .41931 L .83707 .41554 L F
.413 .849 .937 r
.65946 .41296 m .66146 .41239 L .66275 .41277 L F
.36 0 0 r
.66435 .41371 m .66275 .41277 L .66146 .41239 L F
.66435 .41371 m .66681 .41451 L .66275 .41277 L F
0 0 0 r
.26917 .58905 m .26964 .58792 L .27028 .5851 L F
.238 .051 .413 r
.26917 .58905 m .2707 .59034 L .26964 .58792 L F
.26917 .58905 m .26899 .59136 L .2707 .59034 L F
.621 .057 0 r
.25066 .64575 m .24988 .64457 L .24929 .64341 L F
.672 .189 .096 r
.46606 .62501 m .46838 .62702 L .46984 .62565 L F
.51 .532 .814 r
.47294 .62811 m .46984 .62565 L .47259 .62596 L F
.351 0 0 r
.46838 .62702 m .47259 .62596 L .46984 .62565 L F
.542 .737 .966 r
.2084 .62461 m .20837 .62704 L .2062 .62499 L F
.2084 .62461 m .20998 .62628 L .20837 .62704 L F
.05 .322 .806 r
.45976 .63021 m .46053 .63221 L .45957 .63168 L F
.324 .402 .788 r
.75294 .41632 m .75527 .41786 L .75436 .41438 L F
.586 .694 .916 r
.82705 .40209 m .82546 .4043 L .82459 .40253 L F
.82705 .40209 m .8281 .40368 L .82546 .4043 L F
.621 .672 .877 r
.7362 .40067 m .73966 .40163 L .73903 .40013 L F
.578 .61 .848 r
.73966 .40163 m .74102 .3977 L .73903 .40013 L F
.73966 .40163 m .74212 .4011 L .74102 .3977 L F
.428 .198 .46 r
.42986 .64583 m .43276 .6414 L .43024 .64343 L F
.785 .769 .839 r
.65494 .43246 m .6586 .43376 L .65762 .43344 L F
.487 .883 .957 r
.66035 .43165 m .65837 .43198 L .65788 .4321 L F
.758 .656 .749 r
.66035 .43165 m .6586 .43376 L .65837 .43198 L F
.699 .98 .897 r
.65954 .43215 m .6586 .43376 L .66089 .43381 L F
.65954 .43215 m .65762 .43344 L .6586 .43376 L F
.638 .681 .874 r
.16046 .59685 m .15656 .59491 L .15901 .59395 L F
.64 .66 .854 r
.16249 .59527 m .16046 .59685 L .15901 .59395 L F
.487 .883 .957 r
.66035 .43165 m .65958 .428 L .66077 .42891 L F
.674 .554 .711 r
.66325 .42821 m .66035 .43165 L .66077 .42891 L F
.653 .561 .738 r
.72925 .39308 m .72882 .39489 L .73213 .39196 L F
.909 .866 .428 r
.73142 .39451 m .73213 .39196 L .72882 .39489 L F
0 0 0 r
.48969 .5436 m .49097 .54241 L .49232 .54069 L F
.582 .648 .881 r
.73234 .39805 m .7362 .40067 L .73499 .39724 L F
.629 .638 .84 r
.73499 .39724 m .7362 .40067 L .73903 .40013 L F
.881 .989 .808 r
.53538 .52216 m .5322 .5247 L .53095 .52421 L F
.264 0 0 r
.53095 .52421 m .5322 .5247 L .52927 .52502 L F
.268 0 .192 r
.48204 .59506 m .48419 .59434 L .48475 .59272 L F
.58 .215 .314 r
.48475 .59272 m .48419 .59434 L .48707 .59388 L F
.53 .481 .746 r
.46498 .63669 m .46273 .63764 L .46221 .63494 L F
.753 .628 .722 r
.46498 .63669 m .46193 .63937 L .46273 .63764 L F
.736 .491 .559 r
.45134 .64618 m .44915 .6435 L .45123 .64353 L F
.937 .728 .595 r
.42705 .65801 m .42546 .65803 L .42571 .65541 L F
.42571 .65541 m .42546 .65803 L .42705 .65801 L F
.744 .585 .679 r
.42876 .66118 m .42784 .65779 L .42705 .65801 L F
0 .083 .627 r
.53963 .58518 m .53933 .58653 L .53839 .58294 L F
.056 .153 .649 r
.53963 .58518 m .54007 .58858 L .53933 .58653 L F
.629 .595 .797 r
.40287 .61929 m .40489 .6198 L .40376 .61578 L F
.07 0 .402 r
.40287 .61929 m .40395 .62107 L .40489 .6198 L F
.40287 .61929 m .4024 .62229 L .40395 .62107 L F
.512 .751 .982 r
.19507 .61946 m .19438 .62144 L .19227 .62004 L F
.19507 .61946 m .19681 .62115 L .19438 .62144 L F
.56 .633 .88 r
.23916 .65806 m .24101 .66116 L .24297 .66012 L F
.659 .499 .657 r
.24101 .66116 m .24299 .66678 L .24313 .66225 L F
.701 .737 .879 r
.24172 .55153 m .24571 .55244 L .2439 .55106 L F
.485 .775 .996 r
.24571 .55244 m .24765 .55195 L .2439 .55106 L F
.651 .569 .749 r
.31157 .55152 m .30939 .55513 L .30879 .55278 L F
.31157 .55152 m .31251 .55572 L .30939 .55513 L F
.585 .32 .481 r
.31251 .55572 m .30915 .55788 L .30939 .55513 L F
.22 .719 .912 r
.17816 .63709 m .18222 .63746 L .18012 .63695 L F
.04 .481 .884 r
.18222 .63746 m .1823 .63641 L .18012 .63695 L F
.18222 .63746 m .18415 .638 L .1823 .63641 L F
.369 .168 .471 r
.65728 .41389 m .65946 .41296 L .6592 .4108 L F
.229 0 .203 r
.65728 .41389 m .65662 .41553 L .65946 .41296 L F
.764 .711 .802 r
.22349 .68564 m .22748 .686 L .22568 .68534 L F
.88 .889 .835 r
.2299 .68294 m .22748 .686 L .22568 .68534 L F
0 .133 .679 r
.22748 .686 m .22778 .68519 L .22568 .68534 L F
.22748 .686 m .22935 .68786 L .22778 .68519 L F
.961 .683 .462 r
.50028 .57018 m .50075 .5733 L .50236 .574 L F
.916 .61 .128 r
.50195 .57514 m .50236 .574 L .50075 .5733 L F
.50195 .57514 m .50269 .57614 L .50236 .574 L F
.708 .514 .625 r
.45315 .62175 m .44998 .62226 L .4508 .61967 L F
.935 .589 .346 r
.44243 .61646 m .44236 .6188 L .44085 .61682 L F
.222 .695 .939 r
.76787 .41541 m .77034 .41544 L .77155 .41627 L F
.662 .941 .964 r
.77155 .41627 m .77266 .41428 L .77237 .41527 L F
.77155 .41627 m .77034 .41544 L .77266 .41428 L F
.298 .291 .682 r
.77402 .41801 m .77155 .41627 L .77237 .41527 L F
.988 .718 .379 r
.18089 .61227 m .18099 .61499 L .18263 .61577 L F
.246 .639 .961 r
.18322 .61442 m .18263 .61577 L .18099 .61499 L F
.85 .955 .88 r
.77118 .40579 m .77036 .40857 L .77169 .40688 L F
.77118 .40579 m .76864 .4082 L .77036 .40857 L F
.928 .801 .7 r
.56794 .52779 m .5688 .53132 L .56715 .53026 L F
.935 .74 .614 r
.5688 .53132 m .56627 .53299 L .56715 .53026 L F
.5688 .53132 m .56855 .5344 L .56627 .53299 L F
.493 .335 .596 r
.31181 .57005 m .30955 .57304 L .30979 .57082 L F
.296 .44 .836 r
.17276 .62817 m .17452 .63165 L .1756 .62997 L F
.392 .569 .907 r
.17452 .63165 m .17639 .63162 L .1756 .62997 L F
.344 .042 .302 r
.15033 .56776 m .15243 .56721 L .1533 .56428 L F
.293 0 .281 r
.1533 .56428 m .1544 .56639 L .15511 .564 L F
.1533 .56428 m .15243 .56721 L .1544 .56639 L F
.41 .844 .946 r
.23121 .53719 m .23513 .53691 L .23298 .53651 L F
0 0 0 r
.46422 .57093 m .46267 .57234 L .46116 .57348 L F
.46267 .57234 m .4596 .57481 L .46116 .57348 L F
.507 .391 .657 r
.42774 .64969 m .43007 .64937 L .42986 .64583 L F
.698 .482 .592 r
.42774 .64969 m .42791 .6524 L .43033 .65197 L F
.696 .639 .788 r
.45772 .64338 m .45577 .64435 L .45236 .64215 L F
.543 .35 .568 r
.45772 .64338 m .45524 .64663 L .45577 .64435 L F
.428 .793 .995 r
.50686 .61221 m .50922 .61187 L .5095 .6131 L F
.909 .628 .498 r
.5095 .6131 m .50894 .61623 L .50686 .61221 L F
.84 .551 .5 r
.51182 .61572 m .50894 .61623 L .5095 .6131 L F
.846 .83 .832 r
.22935 .68786 m .2339 .68621 L .23197 .68554 L F
.22935 .68786 m .23122 .689 L .2339 .68621 L F
.627 .906 .984 r
.23414 .68459 m .2339 .68621 L .23372 .68393 L F
.23414 .68459 m .23197 .68554 L .2339 .68621 L F
.358 0 0 r
.17152 .57422 m .16906 .57509 L .1673 .57441 L F
.298 .78 .698 r
.17125 .57419 m .17152 .57422 L .17358 .57342 L F
.17125 .57419 m .16906 .57509 L .17152 .57422 L F
.541 .274 .46 r
.15779 .58291 m .15925 .58617 L .15468 .58557 L F
0 0 .347 r
.15866 .58479 m .15779 .58291 L .1604 .58238 L F
.15866 .58479 m .15925 .58617 L .15779 .58291 L F
.747 .712 .819 r
.43898 .64713 m .44045 .64962 L .43659 .64928 L F
.452 .065 .213 r
.44045 .64962 m .43666 .65211 L .43659 .64928 L F
.44045 .64962 m .43915 .65195 L .43666 .65211 L F
.306 .489 .875 r
.44161 .64851 m .44045 .64962 L .43898 .64713 L F
.492 .286 .528 r
.44161 .64851 m .43915 .65195 L .44045 .64962 L F
.572 .783 .978 r
.20173 .64385 m .20543 .64478 L .20368 .64331 L F
.32 .626 .959 r
.20543 .64478 m .20745 .64422 L .20368 .64331 L F
.20543 .64478 m .20866 .64532 L .20745 .64422 L F
.3 .652 .97 r
.20698 .6452 m .20866 .64532 L .20543 .64478 L F
.961 .716 .523 r
.17829 .6345 m .17816 .63709 L .17636 .63616 L F
.417 .565 .895 r
.17639 .63162 m .17829 .6345 L .17985 .63389 L F
0 0 0 r
.17985 .63389 m .17829 .6345 L .17636 .63616 L F
.129 0 .255 r
.26983 .57937 m .27193 .57896 L .27209 .57627 L F
0 0 .384 r
.26983 .57937 m .27072 .58057 L .27193 .57896 L F
0 0 .388 r
.27072 .58057 m .2723 .58008 L .27106 .58007 L F
0 0 .384 r
.26983 .57937 m .27029 .5812 L .27072 .58057 L F
.113 0 .251 r
.27209 .57627 m .27193 .57896 L .27322 .57781 L F
0 0 0 r
.27193 .57896 m .27072 .58057 L .27322 .57781 L F
.566 .185 .278 r
.26946 .58006 m .27322 .57781 L .27072 .58057 L F
0 0 .388 r
.27072 .58057 m .27106 .58007 L .26946 .58006 L F
0 0 .384 r
.27029 .5812 m .27064 .58259 L .27072 .58057 L F
.002 .167 .683 r
.76018 .42237 m .76106 .42077 L .759 .41863 L F
.08 .274 .76 r
.76018 .42237 m .76259 .42436 L .76106 .42077 L F
.811 .413 .299 r
.51632 .54789 m .51827 .54961 L .51966 .54913 L F
.114 0 0 r
.51827 .54961 m .52174 .54994 L .51966 .54913 L F
.577 .004 0 r
.27352 .53784 m .27592 .53931 L .27766 .53944 L F
.204 .556 .934 r
.27813 .53832 m .27766 .53944 L .27592 .53931 L F
.27813 .53832 m .27982 .54 L .27766 .53944 L F
0 .289 .742 r
.50226 .5901 m .503 .5901 L .5014 .58851 L F
.14 0 0 r
.20463 .7405 m .20037 .74274 L .20441 .74314 L F
.7 .7 .847 r
.66325 .42821 m .66077 .42891 L .65958 .428 L F
.515 .126 .241 r
.26408 .63776 m .26589 .63922 L .26405 .63933 L F
.502 .131 .269 r
.26674 .6376 m .26589 .63922 L .26408 .63776 L F
.673 .973 .811 r
.46473 .61416 m .46408 .61331 L .46652 .61244 L F
.46473 .61416 m .46243 .61486 L .46408 .61331 L F
.194 .668 .935 r
.49712 .55021 m .49553 .54942 L .49348 .54931 L F
.455 0 0 r
.4998 .55133 m .49553 .54942 L .49712 .55021 L F
.97 .65 .308 r
.77728 .39282 m .7789 .3924 L .77451 .39147 L F
.793 .324 0 r
.77394 .39171 m .77518 .39278 L .77451 .39147 L F
.97 .65 .308 r
.77737 .39287 m .77451 .39147 L .77518 .39278 L F
.383 .702 .984 r
.77432 .39203 m .77636 .39162 L .77394 .39171 L F
.77518 .39278 m .77559 .39237 L .77432 .39203 L F
.77559 .39237 m .77636 .39162 L .77432 .39203 L F
.97 .65 .308 r
.77737 .39287 m .77741 .39286 L .77728 .39282 L F
.77741 .39286 m .7789 .3924 L .77728 .39282 L F
.77737 .39287 m .7785 .39395 L .7789 .3924 L F
.393 .437 .787 r
.7789 .3924 m .78081 .39161 L .77963 .38749 L F
.508 .401 .668 r
.30461 .59441 m .30508 .59774 L .30286 .59808 L F
.574 .374 .571 r
.30534 .60029 m .30286 .59808 L .30508 .59774 L F
.30534 .60029 m .30288 .60077 L .30286 .59808 L F
.748 .747 .851 r
.24765 .55195 m .25176 .55271 L .24963 .55128 L F
.554 .664 .91 r
.25176 .55271 m .25375 .55051 L .24963 .55128 L F
.25176 .55271 m .25401 .55201 L .25375 .55051 L F
.043 .212 .714 r
.25176 .55271 m .25379 .55456 L .25401 .55201 L F
.829 .359 .075 r
.49468 .54 m .49825 .54331 L .49825 .54051 L F
.784 .651 .716 r
.5815 .54649 m .57832 .54314 L .57817 .54588 L F
.5815 .54649 m .58183 .54394 L .57832 .54314 L F
.841 .646 .64 r
.57786 .54845 m .5815 .54649 L .57817 .54588 L F
.57786 .54845 m .58139 .54946 L .5815 .54649 L F
.433 .252 .535 r
.2408 .67937 m .2388 .68002 L .24097 .67676 L F
.59 .384 .569 r
.2408 .67937 m .23814 .68223 L .2388 .68002 L F
.551 .365 .582 r
.31157 .55152 m .30879 .55278 L .31123 .54965 L F
.048 .268 .763 r
.16825 .59996 m .16757 .6014 L .16617 .59842 L F
.358 .355 .72 r
.17008 .60331 m .16757 .6014 L .16825 .59996 L F
.17008 .60331 m .16881 .60464 L .16757 .6014 L F
.329 .709 .982 r
.28431 .53881 m .284 .54006 L .28214 .5388 L F
.28431 .53881 m .28594 .53991 L .284 .54006 L F
.47 0 .051 r
.49232 .54069 m .49482 .54193 L .49468 .54 L F
.49232 .54069 m .49097 .54241 L .49482 .54193 L F
.511 .707 .959 r
.81093 .40964 m .81256 .40751 L .80904 .40719 L F
.81093 .40964 m .81346 .40919 L .81256 .40751 L F
.88 .889 .835 r
.2299 .68294 m .22568 .68534 L .22778 .68519 L F
.887 .916 .517 r
.22843 .6831 m .22897 .6827 L .22778 .68519 L F
.965 .649 .261 r
.22838 .67959 m .22958 .68224 L .22897 .6827 L F
.617 .424 .598 r
.22838 .67959 m .22897 .6827 L .23056 .67957 L F
.22838 .67959 m .22897 .6827 L .23056 .67957 L F
.887 .916 .517 r
.22922 .68055 m .22897 .6827 L .22843 .6831 L F
.965 .649 .261 r
.22958 .68224 m .2299 .68294 L .22897 .6827 L F
.977 .919 .624 r
.22897 .6827 m .2299 .68294 L .22778 .68519 L F
.888 .758 .712 r
.56402 .57072 m .56285 .56672 L .56507 .56816 L F
.56402 .57072 m .56126 .56992 L .56285 .56672 L F
.929 .775 .668 r
.56402 .57072 m .56095 .57251 L .56126 .56992 L F
.56402 .57072 m .56273 .57352 L .56095 .57251 L F
.287 .643 .967 r
.21772 .64501 m .21894 .64399 L .21622 .64397 L F
.21772 .64501 m .22031 .64528 L .21894 .64399 L F
.787 .641 .7 r
.57832 .54314 m .58183 .54394 L .58035 .54035 L F
.623 .306 .412 r
.4946 .59486 m .49175 .59508 L .49156 .59462 L F
.899 .644 .544 r
.19795 .74594 m .2006 .74636 L .19868 .74344 L F
.229 .488 .894 r
.2006 .74636 m .20246 .74709 L .19965 .74416 L F
.84 .857 .857 r
.19795 .74594 m .2006 .74636 L .19965 .74416 L F
.433 .287 .581 r
.31123 .54965 m .31331 .55182 L .31157 .55152 L F
0 .251 .654 r
.30955 .5497 m .31331 .55182 L .31123 .54965 L F
.862 .692 .669 r
.57906 .53689 m .58035 .54035 L .58078 .53778 L F
.864 .775 .761 r
.68432 .42728 m .68802 .42545 L .68451 .42478 L F
.68432 .42728 m .68597 .42856 L .68802 .42545 L F
.295 .085 .414 r
.26293 .60407 m .26502 .60334 L .26544 .60105 L F
.356 .158 .468 r
.26266 .60647 m .26502 .60334 L .26293 .60407 L F
0 0 0 r
.58004 .5876 m .57942 .58935 L .58052 .58568 L F
.763 .845 .394 r
.58004 .5876 m .57855 .59152 L .57942 .58935 L F
.576 .072 .018 r
.51182 .61572 m .51029 .61746 L .50894 .61623 L F
.563 .629 .875 r
.51332 .61249 m .51504 .61546 L .51182 .61572 L F
.756 .437 .446 r
.51504 .61546 m .51029 .61746 L .51182 .61572 L F
0 .13 .652 r
.4155 .64615 m .41658 .64514 L .41521 .64248 L F
0 0 0 r
.41587 .64822 m .41658 .64514 L .4155 .64615 L F
.622 .324 .444 r
.55896 .51326 m .55893 .51548 L .55524 .51603 L F
.702 .391 .446 r
.55896 .51326 m .56091 .51544 L .55893 .51548 L F
.363 0 0 r
.18493 .78268 m .18711 .78249 L .18533 .78238 L F
.809 .748 .796 r
.56716 .56489 m .5639 .56468 L .56642 .56177 L F
.813 .702 .742 r
.56716 .56489 m .56285 .56672 L .5639 .56468 L F
.56716 .56489 m .56507 .56816 L .56285 .56672 L F
.765 .848 .913 r
.55629 .60649 m .56024 .60595 L .55874 .60494 L F
.533 .822 .999 r
.56024 .60595 m .56127 .60485 L .55874 .60494 L F
.56024 .60595 m .56323 .60572 L .56127 .60485 L F
.576 .84 .995 r
.22031 .64528 m .22168 .646 L .22302 .64556 L F
.871 .547 .434 r
.53008 .55714 m .53221 .55642 L .52955 .55584 L F
.53008 .55714 m .5327 .55837 L .53221 .55642 L F
.173 0 0 r
.80186 .44379 m .80424 .4443 L .80191 .44383 L F
0 0 0 r
.80178 .44372 m .80186 .44379 L .79885 .44438 L F
.319 .807 .807 r
.80065 .44358 m .79885 .44438 L .80186 .44379 L F
.173 0 0 r
.80186 .44379 m .80191 .44383 L .80065 .44358 L F
0 0 0 r
.80244 .44357 m .80186 .44379 L .80178 .44372 L F
.324 0 0 r
.80494 .4439 m .80186 .44379 L .80244 .44357 L F
.863 .653 .617 r
.57852 .50848 m .58015 .5073 L .57866 .50689 L F
.57852 .50848 m .58001 .50997 L .58015 .5073 L F
.541 .137 .225 r
.4695 .60995 m .47122 .61158 L .46823 .61132 L F
.591 .325 .482 r
.47193 .60916 m .46823 .61132 L .4695 .60995 L F
.385 .182 .478 r
.29555 .6126 m .29353 .61328 L .29583 .6101 L F
.524 .325 .553 r
.29555 .6126 m .2931 .61559 L .29353 .61328 L F
.622 .78 .957 r
.66355 .4332 m .66629 .43563 L .66722 .43413 L F
.843 .861 .857 r
.67992 .43363 m .68145 .4351 L .68287 .43334 L F
.744 .657 .764 r
.46493 .63358 m .46053 .63221 L .46395 .63167 L F
.46493 .63358 m .46221 .63494 L .46053 .63221 L F
.53 .481 .746 r
.46498 .63669 m .46221 .63494 L .46493 .63358 L F
.623 .515 .711 r
.4645 .62808 m .4658 .63261 L .46739 .63107 L F
.806 .861 .89 r
.46739 .63107 m .46493 .63358 L .46395 .63167 L F
.673 .603 .77 r
.46739 .63107 m .46741 .6332 L .46493 .63358 L F
.521 .282 .493 r
.46741 .6332 m .46498 .63669 L .46493 .63358 L F
.627 .158 .122 r
.49847 .54496 m .50107 .5457 L .50247 .54413 L F
.608 .136 .109 r
.50247 .54413 m .50107 .5457 L .50453 .5457 L F
.549 .463 .711 r
.30992 .5613 m .3081 .56432 L .30753 .5619 L F
.30992 .5613 m .31045 .5639 L .3081 .56432 L F
.676 .736 .896 r
.41619 .61558 m .41774 .61751 L .4205 .61651 L F
.768 .994 .875 r
.46491 .56909 m .46422 .57093 L .4672 .56855 L F
0 0 .014 r
.19735 .7499 m .19795 .74594 L .19569 .74637 L F
.058 0 0 r
.43708 .63024 m .4415 .62882 L .4388 .62848 L F
.585 .482 .703 r
.22195 .55871 m .22655 .55787 L .22343 .55609 L F
.347 .748 .983 r
.4066 .62532 m .40506 .62442 L .40284 .6246 L F
.4066 .62532 m .40506 .62442 L .40284 .6246 L F
.922 .882 .778 r
.40696 .62123 m .4066 .62532 L .40858 .62226 L F
.40696 .62123 m .40506 .62442 L .4066 .62532 L F
.675 .126 0 r
.40918 .62493 m .40858 .62226 L .4066 .62532 L F
.619 .558 .763 r
.4066 .62532 m .41044 .62825 L .40918 .62493 L F
.672 .448 .572 r
.44915 .6435 m .44967 .64671 L .44515 .64633 L F
.736 .491 .559 r
.45134 .64618 m .44967 .64671 L .44915 .6435 L F
.83 .55 .003 r
.5327 .55837 m .53317 .56084 L .53364 .56195 L F
.468 .494 .802 r
.41016 .63092 m .41091 .63471 L .41319 .63249 L F
.3 .191 .559 r
.41091 .63471 m .4132 .63511 L .41319 .63249 L F
.41091 .63471 m .41149 .63696 L .4132 .63511 L F
.584 .581 .815 r
.65328 .42542 m .6558 .42476 L .65444 .42104 L F
0 0 0 r
.14274 .57377 m .14387 .57278 L .14549 .57113 L F
.14549 .57113 m .14558 .572 L .14757 .57047 L F
.14549 .57113 m .14387 .57278 L .14558 .572 L F
.278 .781 .812 r
.79142 .43772 m .79409 .43704 L .79475 .43706 L F
.603 .891 .989 r
.79409 .43704 m .79739 .43678 L .79475 .43706 L F
.545 .52 .779 r
.30951 .58069 m .30879 .58204 L .30787 .57937 L F
.499 .372 .638 r
.30951 .58069 m .30758 .58775 L .30879 .58204 L F
.853 .81 .807 r
.1888 .77064 m .18659 .77422 L .18892 .77382 L F
.827 .44 .319 r
.50692 .5918 m .50535 .59354 L .5048 .59162 L F
.996 .863 .553 r
.50692 .5918 m .50604 .59486 L .50535 .59354 L F
.718 .846 .411 r
.42586 .62346 m .42723 .62128 L .42372 .6217 L F
.692 .568 .71 r
.51169 .60106 m .50927 .60414 L .50915 .60155 L F
.762 .474 .497 r
.50828 .54184 m .51351 .54017 L .50993 .53928 L F
.36 0 0 r
.19303 .54345 m .18927 .54379 L .19102 .54446 L F
.52 .358 .602 r
.19534 .54026 m .19303 .54345 L .1953 .54247 L F
.271 0 0 r
.19102 .54446 m .1953 .54247 L .19303 .54345 L F
.735 .714 .832 r
.42791 .6524 m .43196 .65286 L .43033 .65197 L F
.371 .14 .429 r
.47352 .62516 m .47487 .62489 L .47497 .62247 L F
.501 .275 .504 r
.47497 .62247 m .47713 .62211 L .47803 .61946 L F
.511 .262 .473 r
.47487 .62489 m .47713 .62211 L .47497 .62247 L F
.243 .438 .853 r
.77501 .43693 m .77687 .44011 L .77805 .43849 L F
.236 .429 .848 r
.77805 .43849 m .77687 .44011 L .77836 .44037 L F
.532 .634 .897 r
.81475 .41283 m .81578 .4096 L .81346 .40919 L F
.81475 .41283 m .81719 .41227 L .81578 .4096 L F
.249 .76 .764 r
.21049 .55471 m .20671 .55558 L .20827 .55547 L F
0 0 0 r
.53112 .51848 m .53277 .51751 L .53418 .51624 L F
.53045 .52083 m .53277 .51751 L .53112 .51848 L F
.203 0 .111 r
.52817 .52182 m .53045 .52083 L .53112 .51848 L F
.357 .044 .291 r
.23752 .6752 m .23815 .677 L .2386 .67612 L F
.597 .222 .303 r
.45882 .56628 m .46158 .56652 L .46233 .56402 L F
.283 0 .277 r
.46233 .56402 m .4645 .56404 L .46507 .56137 L F
.325 0 .209 r
.46233 .56402 m .46383 .56589 L .4645 .56404 L F
.46233 .56402 m .46158 .56652 L .46383 .56589 L F
.777 .85 .4 r
.83811 .41931 m .83702 .42197 L .83735 .42047 L F
0 .191 .717 r
.83735 .42047 m .83702 .42197 L .83911 .42376 L F
.242 .735 .915 r
.49177 .5978 m .48865 .59587 L .49175 .59508 L F
.49177 .5978 m .48723 .59774 L .48865 .59587 L F
.696 .646 .796 r
.18415 .638 m .1891 .6435 L .18806 .64 L F
.18415 .638 m .1891 .6435 L .18806 .64 L F
0 .336 .717 r
.79389 .39237 m .79402 .39263 L .79103 .39111 L F
.427 0 0 r
.79562 .39377 m .79712 .39373 L .79402 .39263 L F
.79562 .39377 m .79402 .39263 L .79389 .39237 L F
.624 .455 .633 r
.4732 .59805 m .47374 .60343 L .47671 .60168 L F
0 0 0 r
.47322 .56353 m .47182 .56501 L .47168 .56514 L F
.456 .627 .926 r
.14828 .6132 m .1484 .61313 L .14824 .61314 L F
.772 .605 .672 r
.49712 .61937 m .49724 .62201 L .49932 .61878 L F
.725 .651 .775 r
.46053 .63221 m .46221 .63494 L .45876 .63422 L F
.257 0 .179 r
.47076 .63042 m .46741 .6332 L .46739 .63107 L F
.593 .592 .82 r
.47425 .62646 m .4757 .62995 L .47323 .63046 L F
.496 .001 .01 r
.4757 .62995 m .47342 .63025 L .47323 .63046 L F
.523 .331 .563 r
.47294 .62811 m .47323 .63046 L .47076 .63042 L F
.257 0 .179 r
.46989 .63114 m .46973 .63313 L .46741 .6332 L F
.47076 .63042 m .47055 .63098 L .46989 .63114 L F
.47055 .63098 m .46973 .63313 L .46989 .63114 L F
.997 .771 .458 r
.46892 .63086 m .46973 .63313 L .47076 .63042 L F
.46892 .63086 m .47076 .63042 L .47323 .63046 L F
.593 .592 .82 r
.47425 .62646 m .47342 .62971 L .47294 .62811 L F
.47342 .62971 m .47323 .63046 L .47309 .62931 L F
.47342 .62971 m .47309 .62931 L .47294 .62811 L F
.496 .001 .01 r
.47342 .63025 m .46892 .63086 L .47223 .63055 L F
.47342 .63025 m .47223 .63055 L .47323 .63046 L F
.47382 .6302 m .47358 .63213 L .46892 .63086 L F
.4757 .62995 m .47457 .63111 L .47382 .6302 L F
.47457 .63111 m .47358 .63213 L .47382 .6302 L F
.966 .711 .499 r
.40915 .60717 m .40718 .60863 L .40896 .60965 L F
.275 0 .229 r
.54797 .50723 m .55015 .50636 L .55063 .50469 L F
.345 .016 .256 r
.55063 .50469 m .55252 .5056 L .55286 .50417 L F
.55063 .50469 m .55015 .50636 L .55252 .5056 L F
.552 .326 .527 r
.47803 .61946 m .48029 .62146 L .48061 .61887 L F
.47803 .61946 m .47713 .62211 L .48029 .62146 L F
.586 .536 .766 r
.83707 .41554 m .83811 .41931 L .84087 .41698 L F
0 0 0 r
.83811 .41931 m .83995 .41918 L .84087 .41698 L F
.83811 .41931 m .83735 .42047 L .83995 .41918 L F
.428 .198 .46 r
.42986 .64583 m .43151 .64581 L .43276 .6414 L F
0 .004 .58 r
.43276 .6414 m .4338 .64225 L .43231 .64024 L F
0 .45 .844 r
.80011 .39533 m .79829 .39471 L .79712 .39373 L F
.769 .725 .195 r
.58053 .58504 m .58004 .5876 L .58052 .58568 L F
.546 .378 .605 r
.50222 .60151 m .50469 .60057 L .50452 .59781 L F
.752 .625 .719 r
.50171 .60317 m .50469 .60057 L .50222 .60151 L F
.276 0 .006 r
.18746 .56452 m .18396 .56636 L .18508 .5651 L F
.856 .553 .475 r
.41485 .63086 m .41779 .63427 L .41797 .63173 L F
.163 .01 .413 r
.4645 .62808 m .46589 .62756 L .46606 .62501 L F
.623 .515 .711 r
.4645 .62808 m .46739 .63107 L .4661 .63059 L F
.4645 .62808 m .4661 .63059 L .46589 .62756 L F
0 0 0 r
.468 .55972 m .46507 .56137 L .46838 .55964 L F
.389 .078 .312 r
.46507 .56137 m .46676 .56338 L .46838 .55964 L F
.46507 .56137 m .4645 .56404 L .46676 .56338 L F
.632 .148 .085 r
.40489 .6198 m .40395 .62107 L .40696 .62123 L F
.697 .439 .53 r
.83963 .41511 m .84312 .41326 L .84215 .41112 L F
.83963 .41511 m .84322 .41557 L .84312 .41326 L F
.473 .268 .52 r
.84312 .41326 m .84322 .41557 L .84568 .41249 L F
0 0 0 r
.41587 .64822 m .41619 .64691 L .41658 .64514 L F
.004 .32 .808 r
.41587 .64822 m .41866 .64978 L .41619 .64691 L F
.325 .783 .947 r
.23513 .53691 m .23732 .53661 L .23906 .53703 L F
.285 .733 .96 r
.23732 .53661 m .24131 .53726 L .23906 .53703 L F
.709 .53 .645 r
.43764 .6143 m .43707 .61287 L .43531 .61371 L F
.496 .339 .598 r
.30288 .60077 m .30065 .60394 L .30024 .60142 L F
.431 .665 .96 r
.14824 .61314 m .14862 .61138 L .14656 .61055 L F
.14824 .61314 m .1484 .61313 L .14862 .61138 L F
.807 .449 .378 r
.67927 .4189 m .68291 .42139 L .68286 .41965 L F
.3 .065 .38 r
.25562 .61288 m .25748 .61235 L .25788 .6103 L F
.322 .177 .524 r
.25533 .61516 m .25748 .61235 L .25562 .61288 L F
.714 .497 .594 r
.66433 .41921 m .66442 .42248 L .66228 .42165 L F
.715 .186 0 r
.51356 .59304 m .51522 .59394 L .51336 .59174 L F
.832 .77 .793 r
.53317 .56084 m .53316 .56599 L .53081 .56053 L F
.043 .103 .601 r
.53317 .56084 m .53415 .56331 L .53316 .56599 L F
0 0 .048 r
.53316 .56599 m .53379 .56563 L .53512 .56664 L F
.53316 .56599 m .53415 .56331 L .53379 .56563 L F
.344 .071 .347 r
.24171 .62247 m .24321 .62385 L .24401 .62215 L F
.24171 .62247 m .24116 .62463 L .24321 .62385 L F
.38 .148 .432 r
.48204 .59506 m .48181 .59722 L .48419 .59434 L F
.105 0 .109 r
.27209 .57627 m .27402 .57582 L .27563 .57275 L F
.113 0 .251 r
.27209 .57627 m .27322 .57781 L .27402 .57582 L F
.501 .394 .664 r
.73814 .38014 m .74097 .38184 L .74079 .37941 L F
.73814 .38014 m .73847 .38259 L .74097 .38184 L F
.801 .83 .874 r
.75987 .40738 m .75572 .4085 L .75866 .40596 L F
.853 .862 .847 r
.76259 .40429 m .75987 .40738 L .75866 .40596 L F
.884 .639 .119 r
.77097 .40339 m .77118 .40579 L .77162 .40658 L F
0 0 .158 r
.77128 .40378 m .77118 .40579 L .77097 .40339 L F
.917 .978 .724 r
.77128 .40378 m .77066 .40486 L .77118 .40579 L F
.77066 .40486 m .76982 .40631 L .77118 .40579 L F
.884 .639 .119 r
.77162 .40658 m .77118 .40579 L .77169 .40688 L F
.516 .269 .478 r
.46498 .60625 m .46846 .60736 L .46818 .60387 L F
0 .282 .783 r
.46498 .60625 m .46823 .60929 L .46846 .60736 L F
.13 0 .047 r
.46848 .61047 m .46823 .61132 L .46823 .60929 L F
0 0 .259 r
.46823 .61132 m .46924 .6095 L .46823 .60929 L F
.46924 .6095 m .4696 .60886 L .46823 .60929 L F
0 .282 .783 r
.46498 .60625 m .46734 .6091 L .46823 .60929 L F
.46734 .6091 m .46848 .61047 L .46823 .60929 L F
.506 .423 .696 r
.50452 .59781 m .50748 .59736 L .50604 .59486 L F
.367 .244 .578 r
.50452 .59781 m .50687 .59959 L .50748 .59736 L F
.50452 .59781 m .50469 .60057 L .50687 .59959 L F
.852 .396 .089 r
.41966 .67086 m .41898 .67162 L .41784 .66999 L F
.499 .248 .465 r
.26043 .60706 m .2622 .60902 L .26266 .60647 L F
.26043 .60706 m .25975 .60971 L .2622 .60902 L F
.696 .639 .788 r
.45772 .64338 m .45236 .64215 L .45627 .6397 L F
.543 .35 .568 r
.45772 .64338 m .45761 .64648 L .45524 .64663 L F
.723 .634 .758 r
.46008 .64028 m .45772 .64338 L .45627 .6397 L F
.583 .437 .649 r
.46016 .64288 m .45772 .64338 L .46008 .64028 L F
.645 .434 .582 r
.46081 .64561 m .45772 .64338 L .46016 .64288 L F
.46081 .64561 m .45761 .64648 L .45772 .64338 L F
.586 .04 0 r
.51388 .55904 m .51266 .55833 L .51061 .55643 L F
.809 .432 0 r
.51388 .55904 m .51377 .55981 L .51266 .55833 L F
.51388 .55904 m .51467 .56118 L .51377 .55981 L F
.814 .671 .124 r
.58203 .57679 m .58198 .57348 L .58136 .57563 L F
0 0 .372 r
.58136 .57563 m .58172 .57914 L .58203 .57679 L F
.7 .7 .847 r
.66325 .42821 m .65958 .428 L .66175 .42683 L F
.66 .711 .886 r
.66565 .42734 m .66325 .42821 L .66175 .42683 L F
.701 .21 .075 r
.52747 .55531 m .53008 .55714 L .52955 .55584 L F
.828 .473 0 r
.51677 .61266 m .51766 .61539 L .51831 .61619 L F
.993 .75 .448 r
.51695 .61774 m .51831 .61619 L .51766 .61539 L F
.51695 .61774 m .51818 .61875 L .51831 .61619 L F
.447 .216 .469 r
.30048 .60646 m .29793 .60943 L .29839 .60713 L F
0 0 0 r
.76864 .4082 m .76715 .41234 L .76704 .41249 L F
.281 .493 .885 r
.15376 .61606 m .1559 .61907 L .15641 .61739 L F
.249 .456 .866 r
.1559 .61907 m .15727 .61904 L .15641 .61739 L F
.72 .829 .379 r
.75903 .3983 m .7582 .4004 L .75955 .39725 L F
.76 .983 .908 r
.75501 .40305 m .75759 .40192 L .7582 .4004 L F
0 0 0 r
.75501 .40305 m .7582 .4004 L .7573 .40177 L F
.76 .983 .908 r
.75759 .40192 m .75869 .40144 L .7582 .4004 L F
.817 .974 .897 r
.7582 .4004 m .75869 .40144 L .76171 .39889 L F
.853 .963 .875 r
.75977 .40152 m .75702 .40248 L .75869 .40042 L F
.31 .498 .881 r
.75556 .39997 m .75504 .40201 L .75705 .4018 L F
.75702 .40149 m .75705 .4018 L .7573 .40177 L F
.75556 .39997 m .75705 .4018 L .75702 .40149 L F
.853 .963 .875 r
.75702 .40248 m .75569 .40295 L .75705 .40178 L F
.75569 .40295 m .75574 .40287 L .75705 .40178 L F
0 .107 .625 r
.75558 .40299 m .75684 .40474 L .75501 .40305 L F
0 0 0 r
.75501 .40305 m .75722 .40182 L .75504 .40201 L F
.853 .963 .875 r
.75702 .40248 m .75749 .40141 L .75869 .40042 L F
.75977 .40152 m .75684 .40474 L .75622 .40386 L F
.75977 .40152 m .75622 .40386 L .75735 .4024 L F
.75977 .40152 m .75563 .40303 L .75569 .40295 L F
.817 .974 .897 r
.7582 .4004 m .76171 .39889 L .76074 .40077 L F
.501 .492 .779 r
.7582 .4004 m .76074 .40077 L .75955 .39725 L F
.832 .676 .689 r
.75955 .39725 m .76074 .40077 L .7628 .39513 L F
0 0 0 r
.76074 .40077 m .76171 .39889 L .76365 .39655 L F
.76074 .40077 m .76365 .39655 L .7628 .39513 L F
.8 .941 .919 r
.76223 .39776 m .75977 .40152 L .75869 .40042 L F
.157 0 .337 r
.76123 .39874 m .75909 .40015 L .75866 .40242 L F
.75909 .40015 m .75869 .40042 L .75868 .40068 L F
.75909 .40015 m .75868 .40068 L .75866 .40242 L F
.853 .963 .875 r
.75735 .4024 m .75622 .40386 L .75563 .40303 L F
0 0 0 r
.75722 .40182 m .75709 .40179 L .75504 .40201 L F
.54 .24 .406 r
.75593 .40292 m .75555 .40245 L .7555 .40179 L F
.498 .39 .662 r
.75554 .40212 m .75555 .40245 L .75599 .40244 L F
.75555 .40245 m .75558 .40308 L .75579 .40275 L F
.75555 .40245 m .75579 .40275 L .75599 .40244 L F
.54 .24 .406 r
.75866 .40242 m .75866 .40207 L .75587 .40291 L F
.498 .39 .662 r
.75564 .40304 m .7561 .40347 L .756 .40254 L F
.54 .24 .406 r
.75593 .40292 m .75587 .40291 L .7556 .40299 L F
.75866 .40242 m .75587 .40291 L .75593 .40292 L F
.823 .761 .794 r
.75684 .40474 m .75866 .40596 L .75536 .40555 L F
.821 .762 .797 r
.76107 .40289 m .75866 .40596 L .75684 .40474 L F
.76107 .40289 m .75684 .40474 L .75977 .40152 L F
.498 .39 .662 r
.75712 .40326 m .75634 .40572 L .75901 .40461 L F
.853 .963 .875 r
.7571 .40231 m .75705 .40178 L .75749 .40141 L F
.75702 .40248 m .75705 .40178 L .7571 .40231 L F
.54 .24 .406 r
.75866 .40207 m .75704 .40179 L .75574 .40287 L F
.498 .39 .662 r
.75564 .40304 m .75576 .40287 L .75569 .40295 L F
.75576 .40287 m .75575 .40287 L .75569 .40295 L F
.75547 .40324 m .75569 .40295 L .75599 .40244 L F
.853 .963 .875 r
.75569 .40295 m .7556 .40299 L .75574 .40287 L F
.54 .24 .406 r
.75587 .40291 m .75574 .40287 L .7556 .40299 L F
.75866 .40207 m .75574 .40287 L .75587 .40291 L F
.498 .39 .662 r
.75576 .40287 m .756 .40254 L .75575 .40287 L F
.75599 .40244 m .75605 .40296 L .75712 .40326 L F
.75605 .40296 m .75634 .40572 L .75712 .40326 L F
.54 .24 .406 r
.75866 .40242 m .75593 .40292 L .7555 .40179 L F
.75593 .40292 m .7556 .40299 L .75555 .40245 L F
0 0 .291 r
.7556 .40299 m .75557 .40294 L .75557 .40264 L F
.75557 .40294 m .75504 .40201 L .75536 .40076 L F
.75554 .40212 m .75536 .40076 L .75547 .40029 L F
.75557 .40294 m .75536 .40076 L .75554 .40212 L F
.498 .39 .662 r
.7555 .40179 m .75901 .40461 L .75866 .40242 L F
.54 .24 .406 r
.7555 .40179 m .75555 .40245 L .75493 .40168 L F
.498 .39 .662 r
.75493 .40168 m .75558 .40308 L .75555 .40245 L F
.54 .24 .406 r
.75555 .40245 m .7556 .40299 L .75493 .40168 L F
.498 .39 .662 r
.75493 .40168 m .75555 .40245 L .75554 .40212 L F
.75493 .40168 m .75554 .40212 L .7555 .40179 L F
.75554 .40212 m .75901 .40461 L .7555 .40179 L F
0 0 .291 r
.7556 .40299 m .75557 .40264 L .75556 .39997 L F
.75557 .40294 m .75547 .40029 L .75556 .39997 L F
0 .107 .625 r
.75559 .40297 m .75501 .40305 L .75504 .40201 L F
.7556 .40299 m .75559 .40299 L .75559 .40297 L F
.75559 .40299 m .75501 .40305 L .75559 .40297 L F
.945 .945 .621 r
.7529 .40666 m .75501 .40305 L .75386 .40394 L F
.925 .577 .355 r
.75386 .40394 m .75501 .40305 L .75536 .40555 L F
.813 .841 .87 r
.75536 .40555 m .75285 .40652 L .75386 .40394 L F
0 .344 .816 r
.74868 .40375 m .7529 .40666 L .75283 .4065 L F
.74868 .40375 m .75238 .4062 L .75151 .40522 L F
.75238 .4062 m .75283 .4065 L .75228 .40597 L F
.75238 .4062 m .75228 .40597 L .75151 .40522 L F
.198 .355 .797 r
.74803 .40157 m .75211 .40538 L .75043 .40117 L F
.962 .943 .673 r
.75223 .40516 m .75299 .40297 L .75043 .40117 L F
.906 .978 .793 r
.75299 .40297 m .75228 .40597 L .7521 .40553 L F
.962 .943 .673 r
.75232 .40536 m .75299 .40297 L .75223 .40516 L F
.906 .978 .793 r
.75299 .40297 m .7521 .40553 L .7521 .40553 L F
.198 .355 .797 r
.74803 .40157 m .7521 .40553 L .75211 .40538 L F
.906 .978 .793 r
.75214 .40519 m .7521 .40553 L .75205 .40541 L F
.75299 .40297 m .7521 .40553 L .75214 .40519 L F
.198 .355 .797 r
.74803 .40157 m .74868 .40375 L .7521 .40553 L F
.75211 .40538 m .7521 .40553 L .75224 .4056 L F
.906 .978 .793 r
.75268 .40425 m .75386 .40394 L .75228 .40597 L F
.75299 .40297 m .75321 .40321 L .75268 .40425 L F
.75321 .40321 m .75386 .40394 L .75268 .40425 L F
.813 .841 .87 r
.75285 .40652 m .75142 .40707 L .75228 .40597 L F
.945 .945 .621 r
.7529 .40666 m .75386 .40394 L .75283 .4065 L F
.813 .841 .87 r
.75285 .40652 m .75283 .4065 L .75386 .40394 L F
.75283 .4065 m .75228 .40597 L .75386 .40394 L F
.826 .808 .834 r
.75572 .4085 m .75263 .40853 L .75536 .40555 L F
.75572 .4085 m .75405 .40986 L .75263 .40853 L F
.813 .841 .87 r
.75536 .40555 m .75263 .40853 L .75142 .40707 L F
.585 .523 .752 r
.75142 .40707 m .75517 .41039 L .75491 .40777 L F
.75289 .40624 m .75491 .40777 L .75465 .40524 L F
.75142 .40707 m .75491 .40777 L .75289 .40624 L F
0 .344 .816 r
.75151 .40522 m .75283 .4065 L .75262 .40604 L F
.75177 .4054 m .75262 .40604 L .75257 .40593 L F
.75151 .40522 m .75262 .40604 L .75177 .4054 L F
.906 .978 .793 r
.75299 .40297 m .75225 .40561 L .75257 .40593 L F
0 .344 .816 r
.75224 .4056 m .75257 .40593 L .75248 .40573 L F
.75151 .40522 m .75257 .40593 L .75224 .4056 L F
.906 .978 .793 r
.75257 .40593 m .75191 .40679 L .7525 .40646 L F
.75225 .40561 m .75191 .40679 L .75257 .40593 L F
.945 .945 .621 r
.75283 .4065 m .75386 .40394 L .75263 .40553 L F
.75283 .4065 m .75263 .40553 L .75257 .40593 L F
.962 .943 .673 r
.75248 .40573 m .75263 .40553 L .75299 .40297 L F
.75263 .40553 m .75386 .40394 L .75299 .40297 L F
.906 .978 .793 r
.75301 .40299 m .75263 .40553 L .75465 .40524 L F
.75263 .40553 m .7525 .40646 L .75251 .40645 L F
.75263 .40553 m .75251 .40645 L .75465 .40524 L F
.75299 .40297 m .7525 .40646 L .75301 .40299 L F
.945 .945 .621 r
.75257 .40593 m .75263 .40553 L .75248 .40573 L F
.198 .355 .797 r
.75221 .40547 m .75224 .4056 L .75248 .40573 L F
.75211 .40538 m .75224 .4056 L .75221 .40547 L F
.906 .978 .793 r
.75205 .40541 m .75228 .40597 L .75142 .40707 L F
.75225 .40561 m .75142 .40707 L .75191 .40679 L F
.198 .355 .797 r
.75211 .40538 m .75221 .40547 L .75223 .40516 L F
.906 .978 .793 r
.75232 .40536 m .75221 .40547 L .75225 .40561 L F
.198 .355 .797 r
.75221 .40547 m .75248 .40573 L .75232 .40536 L F
.75221 .40547 m .75232 .40536 L .75223 .40516 L F
.906 .978 .793 r
.75299 .40297 m .75214 .40519 L .75221 .40547 L F
.75299 .40297 m .75221 .40547 L .75232 .40536 L F
.75214 .40519 m .75142 .40707 L .75225 .40561 L F
.962 .943 .673 r
.75248 .40573 m .75299 .40297 L .75232 .40536 L F
.198 .355 .797 r
.75211 .40538 m .75223 .40516 L .75043 .40117 L F
.345 .301 .665 r
.75465 .40524 m .7563 .40571 L .75493 .40168 L F
.7563 .40571 m .75634 .40572 L .75621 .40536 L F
.7563 .40571 m .75621 .40536 L .75493 .40168 L F
.498 .39 .662 r
.75493 .40168 m .75547 .40324 L .75558 .40308 L F
.75547 .40324 m .75549 .40329 L .75569 .40295 L F
.853 .963 .875 r
.75569 .40295 m .75563 .40303 L .7556 .40299 L F
.498 .39 .662 r
.75569 .40295 m .756 .40254 L .75599 .40244 L F
.54 .24 .406 r
.75866 .40207 m .75869 .40042 L .75749 .40141 L F
.75728 .40183 m .75749 .40141 L .75704 .40179 L F
.72 .829 .379 r
.75734 .40171 m .7574 .40162 L .75749 .40141 L F
.54 .24 .406 r
.75866 .40207 m .75749 .40141 L .75728 .40183 L F
.72 .829 .379 r
.7573 .40177 m .75734 .40171 L .75757 .40122 L F
.75734 .40171 m .75749 .40141 L .75757 .40122 L F
0 0 0 r
.75722 .40182 m .7573 .40177 L .75709 .40179 L F
0 .107 .625 r
.7556 .40299 m .75563 .40303 L .75558 .40299 L F
.75563 .40303 m .75684 .40474 L .75558 .40299 L F
.498 .39 .662 r
.75549 .40329 m .75634 .40572 L .7561 .40347 L F
.75549 .40329 m .7561 .40347 L .75564 .40304 L F
.786 .719 .789 r
.75556 .39997 m .75801 .40032 L .75827 .3969 L F
.72 .829 .379 r
.75783 .4007 m .7582 .4004 L .75903 .3983 L F
.786 .719 .789 r
.75801 .40032 m .75869 .40042 L .75854 .39915 L F
.75801 .40032 m .75854 .39915 L .75827 .3969 L F
.72 .829 .379 r
.75757 .40122 m .75763 .40115 L .75783 .4007 L F
.75763 .40115 m .7582 .4004 L .75783 .4007 L F
.7574 .40162 m .7582 .4004 L .75757 .40122 L F
.381 .589 .925 r
.152 .61614 m .15247 .61436 L .1499 .61317 L F
.152 .61614 m .15376 .61606 L .15247 .61436 L F
.205 .236 .673 r
.19935 .76976 m .19762 .76981 L .19738 .76752 L F
.148 0 .045 r
.19747 .77069 m .19762 .76981 L .19935 .76976 L F
.962 .922 .58 r
.45599 .63172 m .45495 .63379 L .45626 .62989 L F
.761 .905 .94 r
.76043 .38432 m .75838 .38625 L .75719 .3852 L F
.508 .284 .509 r
.2931 .61559 m .29046 .61862 L .29089 .61611 L F
.899 .634 .528 r
.56466 .51606 m .56657 .51925 L .56448 .51811 L F
.789 .656 .717 r
.56628 .52194 m .56448 .51811 L .56657 .51925 L F
.286 0 .011 r
.53277 .51751 m .53643 .51527 L .53418 .51624 L F
0 0 0 r
.13951 .57639 m .14145 .5753 L .14274 .57377 L F
.18 0 .23 r
.14145 .5753 m .14387 .57278 L .14274 .57377 L F
.656 .533 .702 r
.45457 .60085 m .45758 .60076 L .45736 .60014 L F
.45457 .60085 m .45499 .60342 L .45758 .60076 L F
.734 .671 .788 r
.45759 .60086 m .45759 .60087 L .45499 .60342 L F
.45759 .60087 m .45849 .60375 L .45554 .60347 L F
.45759 .60087 m .45554 .60347 L .45499 .60342 L F
.738 .659 .772 r
.45849 .60375 m .45578 .60485 L .45499 .60342 L F
.676 .594 .756 r
.45901 .60646 m .45578 .60485 L .45849 .60375 L F
.29 .282 .678 r
.45758 .60076 m .45897 .60005 L .45736 .60014 L F
.45758 .60076 m .45783 .60086 L .45897 .60005 L F
.953 .953 .686 r
.45897 .60005 m .45886 .60095 L .4582 .6006 L F
.45886 .60095 m .45849 .60375 L .4576 .60088 L F
.45768 .60087 m .4576 .60088 L .45759 .60087 L F
.45886 .60095 m .4576 .60088 L .45768 .60087 L F
.45886 .60095 m .45899 .6023 L .45849 .60375 L F
.561 .477 .717 r
.45899 .6023 m .46131 .60343 L .45849 .60375 L F
.449 .322 .615 r
.46131 .60343 m .45901 .60646 L .45849 .60375 L F
.46131 .60343 m .4616 .60631 L .45901 .60646 L F
.405 .22 .513 r
.45849 .60172 m .45867 .60677 L .4612 .60454 L F
.45768 .60087 m .458 .60276 L .45849 .60172 L F
.458 .60276 m .45867 .60677 L .45849 .60172 L F
.953 .953 .686 r
.45888 .60076 m .45889 .60088 L .45886 .60095 L F
.45889 .60088 m .45899 .6023 L .45886 .60095 L F
.45897 .60005 m .45898 .60052 L .45888 .60076 L F
.45898 .60052 m .45899 .6023 L .45888 .60076 L F
.843 .406 .19 r
.45897 .60005 m .46135 .60294 L .45899 .6023 L F
0 .415 .832 r
.45899 .6023 m .46135 .60294 L .46131 .60343 L F
.405 .22 .513 r
.45871 .60119 m .46096 .60351 L .46006 .60169 L F
.29 .282 .678 r
.45783 .60086 m .46006 .60169 L .45897 .60005 L F
.843 .406 .19 r
.45967 .60089 m .46006 .60169 L .46135 .60294 L F
.29 .282 .678 r
.46006 .60169 m .46057 .60189 L .45897 .60005 L F
.843 .406 .19 r
.46006 .60169 m .46059 .60276 L .4608 .60281 L F
.46006 .60169 m .4608 .60281 L .46135 .60294 L F
.45897 .60005 m .46045 .60273 L .46059 .60276 L F
.45897 .60005 m .46059 .60276 L .45967 .60089 L F
.893 .498 .267 r
.4612 .60454 m .46142 .60469 L .46083 .6035 L F
.405 .22 .513 r
.45871 .60119 m .4612 .60454 L .46077 .60332 L F
.893 .498 .267 r
.4612 .60454 m .46083 .6035 L .46045 .60273 L F
.405 .22 .513 r
.46077 .60332 m .4612 .60454 L .46096 .60351 L F
.46006 .60169 m .46096 .60351 L .46057 .60189 L F
.45783 .60086 m .45853 .60163 L .45871 .60119 L F
.45853 .60163 m .4612 .60454 L .45871 .60119 L F
.45758 .60076 m .45768 .60087 L .45783 .60086 L F
.45768 .60087 m .4612 .60454 L .45783 .60086 L F
.953 .953 .686 r
.45897 .60005 m .4582 .6006 L .45736 .60014 L F
.405 .22 .513 r
.45763 .60082 m .45764 .60087 L .45768 .60087 L F
.45758 .60076 m .4576 .60086 L .45763 .60082 L F
.953 .953 .686 r
.45886 .60095 m .45759 .60087 L .45736 .60014 L F
.405 .22 .513 r
.45764 .60087 m .45867 .60677 L .45768 .60087 L F
.4576 .60086 m .45867 .60677 L .45763 .60082 L F
.536 .253 .432 r
.45499 .60342 m .45867 .60677 L .4576 .60086 L F
.45499 .60342 m .4576 .60086 L .45758 .60076 L F
.734 .671 .788 r
.45736 .60014 m .45759 .60086 L .45499 .60342 L F
.769 .292 .104 r
.41044 .62825 m .41327 .63138 L .41485 .63086 L F
.872 .564 .464 r
.41319 .63141 m .41485 .63086 L .41319 .62944 L F
.41319 .63249 m .41485 .63086 L .41319 .63141 L F
.769 .292 .104 r
.41327 .63138 m .41335 .63148 L .41485 .63086 L F
.993 .871 .601 r
.41485 .63086 m .41335 .63148 L .41319 .62944 L F
.872 .564 .464 r
.41319 .63249 m .4154 .63396 L .41485 .63086 L F
.856 .553 .475 r
.41485 .63086 m .4154 .63396 L .41779 .63427 L F
.138 0 .073 r
.18005 .56893 m .17939 .56767 L .1809 .56749 L F
.18005 .56893 m .17818 .56978 L .17939 .56767 L F
.578 .324 .496 r
.22011 .6977 m .22263 .69759 L .22308 .69497 L F
.257 .047 .391 r
.22308 .69497 m .22263 .69759 L .22467 .69438 L F
.369 .048 .284 r
.2778 .62859 m .27707 .63045 L .27489 .63099 L F
.381 .057 .286 r
.28002 .62805 m .27707 .63045 L .2778 .62859 L F
.648 .719 .9 r
.82092 .41358 m .82447 .41562 L .8234 .41242 L F
.552 .564 .821 r
.82447 .41562 m .82602 .4115 L .8234 .41242 L F
.82447 .41562 m .82724 .41508 L .82602 .4115 L F
.602 .644 .864 r
.48688 .56076 m .48493 .56262 L .48208 .55872 L F
.292 .527 .907 r
.1484 .61313 m .1499 .61317 L .14862 .61138 L F
.459 .424 .732 r
.24197 .67281 m .24287 .67618 L .24097 .67676 L F
.532 .39 .634 r
.24287 .67618 m .2408 .67937 L .24097 .67676 L F
.403 .192 .476 r
.29793 .60943 m .29555 .6126 L .29583 .6101 L F
.616 .763 .949 r
.83434 .40375 m .83172 .40454 L .83074 .40291 L F
.134 0 0 r
.27402 .57582 m .27801 .57354 L .27563 .57275 L F
.998 .827 .48 r
.84378 .41764 m .8446 .4193 L .8446 .41463 L F
.998 .848 .53 r
.84396 .42131 m .8446 .4193 L .84378 .41764 L F
.774 .691 .771 r
.48181 .59722 m .48601 .59816 L .48419 .59434 L F
.289 0 0 r
.48601 .59816 m .484 .59781 L .48181 .59722 L F
.699 .658 .806 r
.48419 .59434 m .48601 .59816 L .48723 .59774 L F
.923 .655 .513 r
.484 .59781 m .48515 .5999 L .48601 .59816 L F
.319 .693 .979 r
.81353 .39918 m .81213 .40016 L .81115 .39888 L F
.81353 .39918 m .81449 .40022 L .81213 .40016 L F
.105 .649 .839 r
.8126 .44789 m .81578 .4482 L .81522 .44796 L F
0 0 0 r
.81578 .4482 m .81787 .44751 L .81522 .44796 L F
.881 .989 .808 r
.53538 .52216 m .53459 .52167 L .5322 .5247 L F
.732 .913 .956 r
.53649 .5197 m .53538 .52216 L .53801 .52096 L F
.805 .992 .876 r
.53649 .5197 m .53459 .52167 L .53538 .52216 L F
.504 .701 .958 r
.82354 .40055 m .82156 .40248 L .82062 .40112 L F
.82354 .40055 m .82459 .40253 L .82156 .40248 L F
.418 .794 .993 r
.84057 .40337 m .84318 .40306 L .84427 .40387 L F
0 .335 .778 r
.84642 .40451 m .84427 .40387 L .84318 .40306 L F
.84642 .40451 m .84772 .4057 L .84427 .40387 L F
.05 .4 .855 r
.84427 .40387 m .84772 .4057 L .84808 .40697 L F
.128 .669 .839 r
.21256 .70954 m .21713 .70977 L .21483 .70947 L F
.442 .818 .992 r
.21476 .55495 m .21276 .55427 L .21049 .55471 L F
.214 0 0 r
.21476 .55495 m .21489 .555 L .21276 .55427 L F
.21476 .55495 m .21753 .55581 L .21489 .555 L F
.305 0 .014 r
.55 .51597 m .54906 .51752 L .54646 .51796 L F
.52 .228 .411 r
.55 .51597 m .55232 .51712 L .54906 .51752 L F
.55 .51597 m .5528 .51561 L .55232 .51712 L F
.529 .278 .478 r
.46818 .60387 m .47053 .60558 L .47072 .6037 L F
.46818 .60387 m .46846 .60736 L .47053 .60558 L F
.684 .252 0 r
.3058 .54618 m .30675 .54748 L .30368 .54672 L F
.864 .713 .693 r
.58197 .55193 m .58284 .55465 L .58297 .55245 L F
.569 .592 .836 r
.487 .62164 m .48468 .62221 L .48314 .61842 L F
.479 .203 .417 r
.487 .62164 m .48482 .62405 L .48468 .62221 L F
.604 .422 .608 r
.45433 .64845 m .45134 .64618 L .45524 .64663 L F
.312 0 .056 r
.45761 .64648 m .45433 .64845 L .45524 .64663 L F
.005 .35 .827 r
.27463 .53739 m .27352 .53784 L .27244 .53609 L F
.27463 .53739 m .27592 .53931 L .27352 .53784 L F
.976 .718 .477 r
.19429 .63993 m .19577 .64341 L .1942 .64189 L F
.333 .736 .981 r
.19577 .64341 m .19615 .64238 L .1942 .64189 L F
.19577 .64341 m .19786 .64331 L .19615 .64238 L F
.969 .828 .649 r
.56727 .5497 m .56525 .551 L .56588 .54863 L F
.56727 .5497 m .56664 .55225 L .56525 .551 L F
0 0 0 r
.41693 .63589 m .41477 .63775 L .41779 .63427 L F
.41693 .63589 m .41779 .63427 L .4154 .63396 L F
.19151 .56035 m .18903 .56339 L .19023 .56142 L F
.438 .775 .997 r
.23694 .65834 m .23736 .65697 L .2351 .65752 L F
.23694 .65834 m .23916 .65806 L .23736 .65697 L F
.23694 .65834 m .23736 .65697 L .2351 .65752 L F
.23694 .65834 m .23916 .65806 L .23736 .65697 L F
.848 .989 .854 r
.46759 .56632 m .4672 .56855 L .46884 .56689 L F
.46759 .56632 m .46491 .56909 L .4672 .56855 L F
.306 0 .082 r
.16699 .55516 m .16923 .55462 L .17 .55367 L F
.322 0 .161 r
.16923 .55462 m .17242 .5527 L .17 .55367 L F
0 0 .457 r
.7721 .39639 m .77107 .40095 L .77329 .39778 L F
.786 .868 .909 r
.7721 .39639 m .77329 .39778 L .77649 .39495 L F
.69 .647 .802 r
.77329 .39778 m .77676 .39745 L .77649 .39495 L F
.502 .487 .772 r
.77329 .39778 m .77655 .39974 L .77676 .39745 L F
.189 0 0 r
.23786 .66978 m .24089 .67046 L .24066 .67037 L F
.361 .786 .973 r
.24131 .53726 m .24347 .53696 L .24519 .53759 L F
.436 .791 .997 r
.24347 .53696 m .24736 .53754 L .24519 .53759 L F
.591 .26 .378 r
.45013 .5695 m .45315 .56764 L .45087 .56822 L F
.808 .641 .675 r
.57994 .51255 m .58175 .51357 L .58001 .50997 L F
.874 .73 .7 r
.57831 .51516 m .58175 .51357 L .57994 .51255 L F
.57831 .51516 m .58124 .51607 L .58175 .51357 L F
.362 0 0 r
.21946 .71712 m .21769 .71599 L .21607 .71523 L F
.52 .245 .439 r
.21769 .71599 m .22067 .71676 L .21886 .71798 L F
.809 .941 .913 r
.22039 .71677 m .22067 .71676 L .22234 .71523 L F
.21886 .71798 m .22067 .71676 L .22039 .71677 L F
0 0 0 r
.21886 .71798 m .22039 .71677 L .22075 .71753 L F
.362 0 0 r
.22039 .71677 m .22067 .71676 L .22031 .71667 L F
0 0 0 r
.22039 .71677 m .22234 .71523 L .22086 .71736 L F
.22039 .71677 m .22086 .71736 L .22075 .71753 L F
.362 0 0 r
.219 .71682 m .22039 .71677 L .21769 .71599 L F
.22039 .71677 m .22031 .71667 L .21769 .71599 L F
.21946 .71712 m .22067 .71676 L .219 .71682 L F
.816 .987 .72 r
.49105 .61507 m .48862 .61794 L .49026 .61664 L F
.635 .464 .634 r
.74079 .37941 m .7433 .37644 L .73947 .37606 L F
.585 .32 .481 r
.31251 .55572 m .31214 .55823 L .30915 .55788 L F
.674 .584 .746 r
.31502 .55514 m .31251 .55572 L .31157 .55152 L F
.575 .312 .479 r
.31468 .55758 m .31214 .55823 L .31251 .55572 L F
.585 .309 .465 r
.31502 .55514 m .31468 .55758 L .31251 .55572 L F
.76 .658 .102 r
.51479 .62247 m .5147 .6217 L .51494 .61912 L F
.9 .579 .088 r
.51479 .62247 m .51429 .62341 L .5147 .6217 L F
.51479 .62247 m .51496 .62419 L .51429 .62341 L F
0 0 0 r
.55483 .58279 m .55664 .58144 L .55732 .57954 L F
.16 .31 .768 r
.55483 .58279 m .55742 .5848 L .55664 .58144 L F
.747 .767 .869 r
.18594 .76228 m .18754 .76461 L .18342 .76442 L F
.119 .664 .829 r
.18342 .76442 m .18754 .76461 L .18592 .76434 L F
.714 .755 .885 r
.18715 .76162 m .18754 .76461 L .18594 .76228 L F
.965 .897 .707 r
.18592 .76434 m .18754 .76461 L .18715 .76162 L F
0 0 0 r
.16754 .60647 m .16881 .60464 L .17008 .60331 L F
.697 .708 .856 r
.75527 .41786 m .75624 .41971 L .759 .41863 L F
.773 .496 .516 r
.24653 .64652 m .24984 .64789 L .24868 .64819 L F
.772 .992 .777 r
.24868 .64819 m .24984 .64789 L .25167 .64592 L F
.508 .318 .558 r
.44387 .60963 m .44594 .60691 L .44351 .60707 L F
.447 .18 .414 r
.46111 .60866 m .45901 .60646 L .4616 .60631 L F
.46111 .60866 m .45859 .60936 L .45901 .60646 L F
.646 .951 .948 r
.23246 .62702 m .23033 .62832 L .22876 .62815 L F
.883 .855 .81 r
.55795 .58801 m .55742 .5848 L .55812 .58569 L F
.521 .282 .493 r
.46741 .6332 m .46709 .63633 L .46498 .63669 L F
0 0 .215 r
.46898 .63242 m .46741 .6332 L .46973 .63313 L F
.46898 .63242 m .46709 .63633 L .46741 .6332 L F
.227 0 .102 r
.16353 .55831 m .16558 .55756 L .16699 .55516 L F
.245 0 .112 r
.16699 .55516 m .16768 .55685 L .16923 .55462 L F
.16699 .55516 m .16558 .55756 L .16768 .55685 L F
.479 .277 .528 r
.19451 .75804 m .19245 .75803 L .19209 .7611 L F
.843 .861 .857 r
.67992 .43363 m .68287 .43334 L .68236 .4306 L F
.846 .835 .835 r
.68519 .43079 m .68236 .4306 L .68287 .43334 L F
.931 .676 .531 r
.56805 .52524 m .56794 .52779 L .56621 .52425 L F
.657 .377 .484 r
.19795 .74594 m .1958 .74355 L .19569 .74637 L F
.19795 .74594 m .19868 .74344 L .1958 .74355 L F
.455 .27 .54 r
.4878 .57962 m .48777 .58215 L .48555 .58272 L F
.4878 .57962 m .48777 .58215 L .48555 .58272 L F
.72 .364 .374 r
.24929 .64341 m .25242 .64353 L .25066 .64575 L F
.296 .778 .695 r
.25242 .64353 m .25479 .64258 L .25369 .64297 L F
.778 .997 .816 r
.21346 .72085 m .21323 .72229 L .21528 .72015 L F
.743 .99 .881 r
.21179 .72239 m .21323 .72229 L .21346 .72085 L F
.493 .723 .974 r
.80367 .40579 m .80695 .40706 L .80606 .4057 L F
.297 .622 .96 r
.80606 .4057 m .80695 .40706 L .80904 .40719 L F
0 0 0 r
.56323 .60572 m .5638 .60496 L .56127 .60485 L F
.56323 .60572 m .56291 .60671 L .5638 .60496 L F
.834 .681 .692 r
.57906 .53689 m .57677 .53994 L .58035 .54035 L F
.83 .708 .729 r
.57677 .53994 m .57832 .54314 L .58035 .54035 L F
.633 .455 .624 r
.45315 .62175 m .45026 .62549 L .44998 .62226 L F
.721 .406 .446 r
.45441 .6274 m .44979 .62746 L .45026 .62549 L F
.45441 .6274 m .45026 .62549 L .45316 .62732 L F
.633 .455 .624 r
.45315 .62175 m .45316 .62732 L .45026 .62549 L F
.572 .405 .617 r
.45543 .62565 m .45315 .62175 L .45573 .62155 L F
.45543 .62565 m .45316 .62732 L .45315 .62175 L F
.903 .805 .741 r
.55795 .58801 m .55693 .58942 L .55503 .58791 L F
.395 .171 .452 r
.45805 .59118 m .45563 .59423 L .45607 .59151 L F
.45607 .59151 m .45563 .59423 L .45805 .59118 L F
0 0 0 r
.17838 .54954 m .17825 .54981 L .18032 .5484 L F
.17838 .54954 m .17597 .55042 L .17825 .54981 L F
.797 .474 .442 r
.45112 .61738 m .45344 .61779 L .45484 .61618 L F
0 0 0 r
.45344 .61779 m .45735 .61621 L .45484 .61618 L F
.423 .021 .17 r
.44452 .58289 m .44344 .58513 L .44061 .58551 L F
.225 0 .079 r
.44582 .58409 m .44452 .58289 L .44654 .5816 L F
.44582 .58409 m .44344 .58513 L .44452 .58289 L F
.853 .862 .847 r
.76259 .40429 m .75866 .40596 L .76107 .40289 L F
.843 .826 .831 r
.76503 .4014 m .76259 .40429 L .76107 .40289 L F
.899 .731 .665 r
.43609 .6214 m .43748 .6249 L .43828 .62291 L F
.715 .404 .45 r
.56247 .50369 m .56608 .50571 L .5662 .50393 L F
.599 .269 .382 r
.56608 .50571 m .5687 .50575 L .5662 .50393 L F
.622 .248 .312 r
.5662 .50393 m .5687 .50575 L .56902 .50422 L F
.864 .713 .693 r
.58197 .55193 m .57934 .55453 L .58284 .55465 L F
.9 .753 .69 r
.57914 .557 m .58284 .55465 L .57934 .55453 L F
.57914 .557 m .58084 .55816 L .58284 .55465 L F
.874 .771 .744 r
.68432 .42728 m .68519 .43079 L .68597 .42856 L F
.68432 .42728 m .68236 .4306 L .68519 .43079 L F
.083 0 .293 r
.16075 .58059 m .15866 .58479 L .1604 .58238 L F
.496 .265 .494 r
.4946 .59486 m .49177 .5978 L .49175 .59508 L F
.511 .274 .492 r
.28579 .62208 m .28549 .62442 L .28307 .62486 L F
.542 .368 .595 r
.28811 .61911 m .28812 .62166 L .28579 .62208 L F
.522 .284 .495 r
.28783 .62397 m .28579 .62208 L .28812 .62166 L F
.28783 .62397 m .28549 .62442 L .28579 .62208 L F
.393 .335 .674 r
.78015 .44338 m .78116 .44547 L .78281 .44526 L F
.306 .477 .865 r
.77836 .44037 m .78015 .44338 L .78153 .44169 L F
.213 .338 .775 r
.78153 .44169 m .78015 .44338 L .78281 .44526 L F
.801 .55 .558 r
.82027 .43996 m .82236 .43662 L .82258 .43946 L F
.061 0 0 r
.27053 .53619 m .26841 .5367 L .27244 .53609 L F
.699 .658 .806 r
.48419 .59434 m .48723 .59774 L .48707 .59388 L F
.351 0 .21 r
.48723 .59774 m .4908 .59569 L .48707 .59388 L F
.48723 .59774 m .49034 .59742 L .4908 .59569 L F
.242 .735 .915 r
.49177 .5978 m .49034 .59742 L .48723 .59774 L F
.108 0 0 r
.47246 .55736 m .47635 .55738 L .47394 .55738 L F
.528 .69 .941 r
.54766 .60775 m .54637 .60509 L .54345 .606 L F
.745 .683 .791 r
.55036 .60733 m .54637 .60509 L .54766 .60775 L F
.166 .704 .812 r
.54061 .51955 m .53649 .5197 L .53801 .52096 L F
.355 .464 .833 r
.77529 .42647 m .7736 .42845 L .77192 .42475 L F
.43 .577 .899 r
.77529 .42647 m .77754 .42999 L .7736 .42845 L F
.888 .864 .809 r
.76734 .3982 m .76379 .39997 L .76565 .39642 L F
.76734 .3982 m .76503 .4014 L .76379 .39997 L F
.913 .615 .465 r
.58172 .56671 m .58176 .5668 L .58255 .56777 L F
.596 .737 .943 r
.15942 .62206 m .16037 .62057 L .15727 .61904 L F
.15942 .62206 m .16194 .62154 L .16037 .62057 L F
.249 .444 .857 r
.2978 .54314 m .29819 .5461 L .29574 .54348 L F
.2978 .54314 m .29935 .54593 L .29819 .5461 L F
.451 .356 .656 r
.30984 .57817 m .30787 .57937 L .30757 .57893 L F
.30984 .57817 m .30999 .57908 L .30787 .57937 L F
.545 .52 .779 r
.30951 .58069 m .30787 .57937 L .30999 .57908 L F
.634 .117 0 r
.41107 .62941 m .41044 .62825 L .41016 .63092 L F
.41107 .62941 m .41335 .63148 L .41044 .62825 L F
.809 .392 .257 r
.53502 .56902 m .53688 .5674 L .53512 .56664 L F
.53502 .56902 m .53848 .56988 L .53688 .5674 L F
.403 .045 .24 r
.54496 .50908 m .54718 .5087 L .54797 .50723 L F
0 0 0 r
.54718 .5087 m .55015 .50636 L .54797 .50723 L F
0 0 .238 r
.52297 .57093 m .5237 .57298 L .52246 .56948 L F
0 0 .04 r
.41933 .6482 m .41877 .64997 L .41941 .64592 L F
.775 .74 .216 r
.41866 .64978 m .41877 .64997 L .41933 .6482 L F
.41866 .64978 m .4183 .65222 L .41877 .64997 L F
.574 .457 .682 r
.48405 .57656 m .48653 .57372 L .48304 .5733 L F
.541 .465 .719 r
.42912 .58446 m .43044 .58234 L .42821 .58234 L F
.42912 .58446 m .43195 .5846 L .43044 .58234 L F
.531 .334 .558 r
.56151 .61305 m .56401 .61251 L .56152 .6156 L F
.56151 .61305 m .56401 .61251 L .56152 .6156 L F
.772 .836 .901 r
.45627 .6397 m .45236 .64215 L .45285 .64077 L F
0 0 .015 r
.45236 .64215 m .45274 .64201 L .45285 .64077 L F
.808 .608 .632 r
.65958 .428 m .6558 .42476 L .65832 .42411 L F
.65958 .428 m .65595 .42755 L .6558 .42476 L F
.679 .677 .841 r
.66175 .42683 m .65958 .428 L .65832 .42411 L F
.802 .465 0 r
.50691 .57878 m .50773 .58148 L .50828 .58235 L F
.967 .649 .349 r
.50773 .58148 m .50946 .58543 L .50828 .58235 L F
.157 .181 .635 r
.15628 .58685 m .15468 .58557 L .15925 .58617 L F
.15628 .58685 m .15594 .59017 L .15468 .58557 L F
.523 .327 .556 r
.1953 .54247 m .19765 .5399 L .19534 .54026 L F
.621 .742 .933 r
.74608 .40431 m .7499 .4053 L .74868 .40375 L F
.862 .737 .723 r
.58084 .55816 m .58051 .56124 L .58216 .56156 L F
.911 .674 .567 r
.58038 .56368 m .58216 .56156 L .58051 .56124 L F
.58038 .56368 m .582 .56413 L .58216 .56156 L F
.974 .731 .31 r
.84772 .4057 m .84861 .4094 L .84808 .40697 L F
.262 .373 .788 r
.17964 .60866 m .17862 .61066 L .17746 .60925 L F
.17964 .60866 m .18089 .61227 L .17862 .61066 L F
.337 .805 .923 r
.43727 .64017 m .43707 .63967 L .44006 .63959 L F
.279 .585 .944 r
.19064 .61806 m .19009 .61957 L .18899 .6179 L F
.19064 .61806 m .19227 .62004 L .19009 .61957 L F
.888 .63 .541 r
.58119 .51854 m .58124 .51607 L .57831 .51516 L F
.496 .339 .598 r
.30288 .60077 m .30284 .6034 L .30065 .60394 L F
.526 .343 .576 r
.30284 .6034 m .30048 .60646 L .30065 .60394 L F
.208 0 0 r
.468 .55972 m .47065 .55944 L .47052 .55863 L F
.194 .707 .892 r
.46838 .55964 m .47065 .55944 L .468 .55972 L F
0 0 .457 r
.7721 .39639 m .7725 .39911 L .77107 .40095 L F
.966 .758 .32 r
.77032 .40204 m .77107 .40095 L .7725 .39911 L F
.77032 .40204 m .77097 .40339 L .77107 .40095 L F
.945 .633 .413 r
.56855 .5344 m .56686 .53429 L .56627 .53299 L F
.56855 .5344 m .56845 .53612 L .56686 .53429 L F
.718 .749 .876 r
.82825 .41672 m .83068 .41571 L .82724 .41508 L F
.48 .349 .624 r
.30955 .57304 m .30984 .57817 L .30757 .57893 L F
.831 .599 .587 r
.57804 .55105 m .58139 .54946 L .57786 .54845 L F
.57804 .55105 m .58197 .55193 L .58139 .54946 L F
.785 .504 .511 r
.76882 .42409 m .77132 .42224 L .76894 .42141 L F
.76882 .42409 m .77192 .42475 L .77132 .42224 L F
.772 .339 .224 r
.77132 .42224 m .77135 .42444 L .76894 .42141 L F
.036 0 .194 r
.77399 .42036 m .77135 .42444 L .77132 .42224 L F
.195 0 0 r
.16139 .55896 m .16032 .56024 L .16353 .55831 L F
.175 .549 .929 r
.78741 .4357 m .78541 .43621 L .78379 .43419 L F
.7874 .4357 m .7877 .43692 L .78541 .43621 L F
.78742 .43571 m .7877 .43692 L .7874 .4357 L F
.78741 .4357 m .78742 .43571 L .7874 .4357 L F
.733 .963 .94 r
.78649 .4358 m .7877 .43692 L .78741 .4357 L F
.462 .838 .989 r
.79056 .43622 m .7877 .43692 L .78677 .43605 L F
.78767 .43592 m .78677 .43605 L .78649 .4358 L F
.79056 .43622 m .78677 .43605 L .78767 .43592 L F
.585 .347 .521 r
.78771 .43591 m .78879 .43467 L .78741 .4357 L F
.462 .838 .989 r
.78992 .43683 m .78649 .4358 L .78951 .43723 L F
.79056 .43622 m .78795 .43595 L .78992 .43683 L F
.78795 .43595 m .78649 .4358 L .78992 .43683 L F
.585 .347 .521 r
.78951 .43723 m .78908 .43571 L .78771 .43591 L F
.78908 .43571 m .78879 .43467 L .78771 .43591 L F
.841 .54 .479 r
.42818 .66757 m .42485 .66872 L .42696 .66597 L F
.42818 .66757 m .42769 .66971 L .42485 .66872 L F
.506 .673 .939 r
.42966 .66595 m .42818 .66757 L .42696 .66597 L F
.539 .434 .682 r
.42966 .66595 m .42769 .66971 L .42818 .66757 L F
.212 0 .302 r
.20037 .74274 m .19868 .74344 L .19795 .74594 L F
.342 .52 .887 r
.78312 .43249 m .78127 .43424 L .78085 .43237 L F
.382 .587 .924 r
.78379 .43419 m .78127 .43424 L .78312 .43249 L F
.837 .427 .264 r
.47836 .5583 m .4783 .56037 L .48005 .5586 L F
.012 0 0 r
.48005 .5586 m .48093 .55925 L .48208 .55872 L F
.48005 .5586 m .4783 .56037 L .48093 .55925 L F
.187 .232 .677 r
.52187 .54659 m .52231 .55013 L .52126 .54998 L F
.52231 .55013 m .52236 .55056 L .52126 .54998 L F
.114 0 0 r
.51945 .54972 m .52126 .54998 L .52174 .54994 L F
.51827 .54961 m .52126 .54998 L .51945 .54972 L F
0 .269 .719 r
.52126 .54998 m .52276 .55121 L .52174 .54994 L F
.418 0 0 r
.23477 .62686 m .23701 .62707 L .23907 .6254 L F
.103 0 0 r
.23907 .6254 m .23922 .62647 L .24116 .62463 L F
.23907 .6254 m .23701 .62707 L .23922 .62647 L F
.474 .389 .68 r
.45112 .61738 m .44895 .61728 L .45057 .61709 L F
.893 .953 .835 r
.45227 .61447 m .45112 .61738 L .45057 .61709 L F
.306 .765 .95 r
.24736 .53754 m .24975 .53731 L .25138 .53784 L F
.374 .788 .979 r
.24975 .53731 m .25355 .53769 L .25138 .53784 L F
0 0 0 r
.18659 .54546 m .18746 .54525 L .18927 .54379 L F
.361 0 0 r
.18927 .54379 m .18746 .54525 L .19102 .54446 L F
.783 .522 .542 r
.56091 .51544 m .56466 .51606 L .56448 .51811 L F
.322 .177 .524 r
.25533 .61516 m .25745 .6152 L .25748 .61235 L F
.358 .05 .3 r
.25533 .61516 m .25672 .61738 L .25745 .6152 L F
.25533 .61516 m .25459 .61796 L .25672 .61738 L F
.629 .602 .803 r
.77676 .39745 m .7785 .39395 L .77649 .39495 L F
.77676 .39745 m .77962 .39746 L .7785 .39395 L F
.674 .471 .602 r
.77655 .39974 m .77962 .39746 L .77676 .39745 L F
.489 .567 .861 r
.77981 .43078 m .77734 .43138 L .77754 .42999 L F
.482 .516 .816 r
.77981 .43078 m .78085 .43237 L .77734 .43138 L F
.584 .821 .989 r
.51449 .54589 m .51838 .54627 L .51598 .54646 L F
.819 .864 .881 r
.50464 .6125 m .50111 .61179 L .50314 .61104 L F
.909 .934 .815 r
.50464 .6125 m .50126 .6146 L .50111 .61179 L F
.667 .964 .931 r
.50314 .61104 m .50111 .61179 L .50163 .6109 L F
.75 .646 .746 r
.50111 .61179 m .50247 .61283 L .50163 .6109 L F
.909 .934 .815 r
.50464 .6125 m .50295 .61469 L .5027 .61371 L F
.683 .524 .665 r
.50464 .6125 m .50459 .61628 L .50194 .61599 L F
.75 .646 .746 r
.50247 .61283 m .50396 .61397 L .50216 .6116 L F
.50247 .61283 m .50216 .6116 L .50163 .6109 L F
.909 .934 .815 r
.5027 .61371 m .50194 .61599 L .50126 .6146 L F
.50295 .61469 m .50194 .61599 L .5027 .61371 L F
.491 .531 .825 r
.50539 .60881 m .50464 .6125 L .50314 .61104 L F
.50539 .60881 m .50686 .61221 L .50464 .6125 L F
.634 .547 .739 r
.50686 .61221 m .50459 .61628 L .50464 .6125 L F
.451 .258 .527 r
.74097 .38184 m .73847 .38259 L .73851 .38504 L F
.74097 .38184 m .73847 .38259 L .73851 .38504 L F
.396 .523 .868 r
.20396 .62152 m .20423 .62487 L .20244 .62344 L F
.20396 .62152 m .2062 .62499 L .20423 .62487 L F
.951 .876 .726 r
.56864 .54069 m .56645 .54168 L .56733 .53959 L F
.56864 .54069 m .56784 .54274 L .56645 .54168 L F
.843 .826 .831 r
.76503 .4014 m .76107 .40289 L .76379 .39997 L F
.655 .764 .93 r
.83801 .40445 m .83434 .40375 L .83699 .40299 L F
.68 .815 .948 r
.84057 .40337 m .83801 .40445 L .83699 .40299 L F
.222 .739 .729 r
.19826 .55849 m .1935 .55965 L .19613 .5591 L F
.723 .602 .721 r
.44998 .62226 m .44753 .625 L .44632 .62164 L F
.697 .56 .696 r
.44998 .62226 m .45026 .62549 L .44753 .625 L F
.134 .679 .808 r
.20634 .53814 m .2086 .53791 L .21033 .53805 L F
.461 0 0 r
.2086 .53791 m .2121 .53802 L .21033 .53805 L F
.501 .504 .792 r
.40284 .6246 m .40395 .62107 L .4024 .62229 L F
.578 .269 .41 r
.47494 .60729 m .4745 .60931 L .47193 .60916 L F
.357 .073 .339 r
.47672 .60849 m .47494 .60729 L .4775 .60681 L F
.47672 .60849 m .4745 .60931 L .47494 .60729 L F
.723 .606 .726 r
.44753 .625 m .44411 .62267 L .44632 .62164 L F
.961 .844 .683 r
.44411 .62267 m .44366 .62529 L .44221 .62371 L F
.723 .606 .726 r
.44495 .62325 m .44376 .62471 L .44411 .62267 L F
.592 .413 .608 r
.44222 .62371 m .44632 .62164 L .44411 .62267 L F
.44221 .62371 m .44223 .6237 L .44222 .62371 L F
.44223 .6237 m .44632 .62164 L .44222 .62371 L F
.765 .91 .939 r
.44632 .62164 m .44411 .62267 L .44466 .62077 L F
.873 .713 .681 r
.44236 .6188 m .44411 .62267 L .44173 .62092 L F
.912 .652 .531 r
.44411 .62267 m .44221 .62371 L .44173 .62092 L F
.295 .417 .816 r
.44466 .62077 m .44411 .62267 L .44236 .6188 L F
.868 .995 .798 r
.44411 .62267 m .44221 .62371 L .44466 .62077 L F
.592 .413 .608 r
.44221 .62371 m .44466 .62077 L .44627 .62162 L F
.44221 .62371 m .44627 .62162 L .44621 .62169 L F
.575 .393 .597 r
.44464 .62263 m .44729 .61993 L .44466 .62077 L F
.44462 .62362 m .44567 .62217 L .44464 .62263 L F
.44567 .62217 m .44729 .61993 L .44464 .62263 L F
.592 .413 .608 r
.44621 .62169 m .44627 .62162 L .44632 .62164 L F
.723 .606 .726 r
.44753 .625 m .44366 .62529 L .44376 .62471 L F
.44753 .625 m .44376 .62471 L .44495 .62325 L F
.676 .341 .4 r
.44736 .62711 m .44366 .62529 L .44753 .625 L F
.691 .384 .451 r
.44753 .625 m .44979 .62746 L .44736 .62711 L F
.698 .383 .44 r
.45026 .62549 m .44979 .62746 L .44753 .625 L F
.161 .7 .811 r
.21445 .53775 m .21879 .53761 L .21659 .5377 L F
.125 0 0 r
.25251 .6186 m .25049 .61947 L .24942 .62099 L F
.496 .265 .494 r
.4946 .59486 m .49428 .59735 L .49177 .5978 L F
0 0 0 r
.49606 .59349 m .49428 .59735 L .4946 .59486 L F
.845 .632 .614 r
.68291 .42139 m .68451 .42478 L .68478 .42221 L F
.219 .74 .75 r
.7963 .44492 m .7954 .44503 L .79278 .44567 L F
.253 .765 .792 r
.79885 .44438 m .7954 .44503 L .7963 .44492 L F
.809 .551 .547 r
.57494 .50383 m .57481 .50626 L .57866 .50689 L F
.805 .574 .589 r
.57481 .50626 m .57852 .50848 L .57866 .50689 L F
.261 0 .281 r
.25748 .61235 m .25975 .60971 L .25788 .6103 L F
.994 .786 .516 r
.56663 .55844 m .56521 .56064 L .56486 .55748 L F
.56663 .55844 m .56642 .56177 L .56521 .56064 L F
.792 .637 .689 r
.48707 .59388 m .4908 .59569 L .49011 .5911 L F
.015 .073 .58 r
.49011 .5911 m .4908 .59569 L .49205 .59296 L F
.359 0 .213 r
.4908 .59569 m .49425 .59599 L .49205 .59296 L F
.4908 .59569 m .49034 .59742 L .49425 .59599 L F
.325 .279 .652 r
.24866 .64578 m .24653 .64652 L .24868 .64819 L F
.849 .686 .681 r
.43578 .66053 m .43713 .66455 L .43324 .66372 L F
.63 .109 0 r
.43677 .66704 m .43324 .66372 L .43713 .66455 L F
0 .138 .663 r
.43803 .6633 m .43713 .66455 L .43578 .66053 L F
.916 .965 .793 r
.43803 .6633 m .43677 .66704 L .43713 .66455 L F
.628 .514 .704 r
.18519 .78404 m .18711 .78249 L .18493 .78268 L F
.635 .549 .741 r
.15901 .59395 m .15656 .59491 L .15683 .59198 L F
.579 .213 .311 r
.44951 .57708 m .45159 .57863 L .4487 .57805 L F
.512 .25 .455 r
.45175 .57642 m .45159 .57863 L .44951 .57708 L F
.649 .643 .83 r
.73234 .39805 m .73362 .39359 L .73142 .39451 L F
.73234 .39805 m .73499 .39724 L .73362 .39359 L F
.508 .229 .427 r
.27489 .63099 m .27658 .63269 L .27195 .63308 L F
.179 .202 .647 r
.27675 .63243 m .27489 .63099 L .27707 .63045 L F
.27675 .63243 m .27658 .63269 L .27489 .63099 L F
.654 .549 .724 r
.46193 .63937 m .46016 .64288 L .46008 .64028 L F
.721 .338 .325 r
.66982 .41737 m .67302 .41605 L .66935 .41541 L F
.66982 .41737 m .67297 .41758 L .67302 .41605 L F
.683 .305 .325 r
.67297 .41758 m .67552 .4182 L .67302 .41605 L F
.72 .943 .955 r
.75593 .38002 m .75754 .38049 L .75951 .37923 L F
.974 .854 .459 r
.51416 .59906 m .51538 .59761 L .51457 .59649 L F
.51416 .59906 m .51477 .60014 L .51538 .59761 L F
.015 .073 .58 r
.49011 .5911 m .49205 .59296 L .4929 .58946 L F
.525 .781 .991 r
.19505 .77116 m .19528 .76951 L .19334 .77069 L F
.19505 .77116 m .19747 .77069 L .19528 .76951 L F
.423 .501 .835 r
.76749 .42901 m .76905 .42661 L .7666 .42681 L F
.76749 .42901 m .7704 .43004 L .76905 .42661 L F
.508 .318 .558 r
.44387 .60963 m .44585 .6095 L .44594 .60691 L F
.542 .311 .515 r
.44387 .60963 m .44589 .61191 L .44585 .6095 L F
.44387 .60963 m .44333 .61254 L .44589 .61191 L F
.876 .909 .849 r
.8446 .41463 m .84568 .41249 L .84322 .41557 L F
.998 .827 .48 r
.84378 .41764 m .8446 .41463 L .84322 .41557 L F
.658 .29 .336 r
.55631 .50334 m .55878 .50546 L .56008 .50307 L F
.737 .421 .447 r
.55878 .50546 m .56247 .50369 L .56008 .50307 L F
.445 0 0 r
.51061 .55643 m .5101 .55633 L .50753 .55467 L F
.572 .03 0 r
.51061 .55643 m .51266 .55833 L .5101 .55633 L F
.552 .371 .589 r
.73606 .38813 m .73851 .38504 L .73542 .38531 L F
.489 .65 .93 r
.45687 .62732 m .45708 .62923 L .45441 .6274 L F
.828 .375 0 r
.45626 .62989 m .45441 .6274 L .45708 .62923 L F
.734 .671 .788 r
.45736 .60014 m .45499 .60342 L .45457 .60085 L F
.728 .779 .894 r
.83636 .41265 m .83707 .41554 L .8402 .41318 L F
.644 .589 .778 r
.83707 .41554 m .83963 .41511 L .8402 .41318 L F
.586 .536 .766 r
.83707 .41554 m .84087 .41698 L .83963 .41511 L F
.501 .318 .565 r
.29046 .61862 m .28812 .62166 L .28811 .61911 L F
.379 0 .127 r
.19738 .76752 m .19505 .76935 L .19528 .76951 L F
.691 .297 .295 r
.19528 .76951 m .19935 .76976 L .19738 .76752 L F
.638 .81 .965 r
.19528 .76951 m .19747 .77069 L .19935 .76976 L F
.578 .553 .791 r
.19619 .76817 m .19569 .76979 L .19528 .76951 L F
.19569 .76979 m .19505 .77184 L .19528 .76951 L F
.379 0 .127 r
.19505 .76935 m .19334 .77069 L .19528 .76951 L F
.484 .208 .42 r
.28307 .62486 m .28221 .62771 L .28002 .62805 L F
.537 .277 .469 r
.28549 .62442 m .28221 .62771 L .28307 .62486 L F
0 0 0 r
.1673 .57441 m .16591 .57573 L .1645 .57626 L F
.362 0 0 r
.16906 .57509 m .16591 .57573 L .1673 .57441 L F
.753 .582 .664 r
.74328 .37904 m .74676 .37687 L .7433 .37644 L F
.74328 .37904 m .74705 .37945 L .74676 .37687 L F
.625 .489 .676 r
.74676 .37687 m .74705 .37945 L .74958 .37628 L F
.586 .279 .415 r
.24285 .64319 m .24405 .64576 L .24115 .64335 L F
.24285 .64319 m .24548 .64325 L .24405 .64576 L F
.19 .318 .765 r
.49424 .57924 m .4945 .57569 L .49229 .57783 L F
.49424 .57924 m .49586 .57964 L .4945 .57569 L F
.245 .239 .654 r
.49424 .57924 m .49632 .58153 L .49586 .57964 L F
.899 .8 .742 r
.56664 .54498 m .56645 .54168 L .56784 .54274 L F
.674 .584 .746 r
.31502 .55514 m .31157 .55152 L .31331 .55182 L F
.54 .6 .862 r
.31557 .55135 m .31502 .55514 L .31331 .55182 L F
.31557 .55135 m .31728 .55453 L .31502 .55514 L F
.551 .342 .55 r
.31728 .55453 m .31468 .55758 L .31502 .55514 L F
.571 .777 .976 r
.49041 .57909 m .4878 .57962 L .48881 .57761 L F
.976 .712 .464 r
.49041 .57909 m .48881 .57761 L .4878 .57962 L F
.919 .842 .392 r
.48515 .5675 m .4843 .56946 L .48473 .56719 L F
.76 .359 0 r
.48515 .5675 m .48473 .56719 L .48352 .5646 L F
.196 0 .073 r
.48628 .5687 m .48515 .5675 L .48752 .56707 L F
.48628 .5687 m .4843 .56946 L .48515 .5675 L F
.58 .007 0 r
.49283 .59916 m .49177 .5978 L .49428 .59735 L F
.49283 .59916 m .49034 .59742 L .49177 .5978 L F
.443 .153 .376 r
.48263 .61607 m .48538 .61551 L .48562 .61344 L F
.484 .187 .386 r
.48562 .61344 m .48781 .61492 L .48817 .61316 L F
.48562 .61344 m .48538 .61551 L .48781 .61492 L F
.576 .84 .995 r
.22031 .64528 m .22302 .64556 L .22246 .64461 L F
.532 .92 .911 r
.22302 .64556 m .22511 .6439 L .22246 .64461 L F
.22302 .64556 m .22603 .64426 L .22511 .6439 L F
.895 .837 .781 r
.51469 .54257 m .51548 .54357 L .51711 .54047 L F
.96 .814 .655 r
.51469 .54257 m .51449 .54589 L .51548 .54357 L F
.469 .693 .965 r
.51469 .54257 m .51548 .54357 L .51573 .54167 L F
.39 0 0 r
.26169 .55718 m .26527 .55866 L .26313 .55791 L F
.308 0 0 r
.26779 .55894 m .26313 .55791 L .26527 .55866 L F
.485 .225 .445 r
.30758 .58775 m .30866 .58906 L .3064 .58914 L F
.499 .372 .638 r
.30951 .58069 m .31075 .58731 L .30758 .58775 L F
.472 .223 .455 r
.31127 .58761 m .30758 .58775 L .31075 .58731 L F
.31127 .58761 m .30866 .58906 L .30758 .58775 L F
.817 .656 .682 r
.57852 .50848 m .57994 .51255 L .58001 .50997 L F
.698 .864 .961 r
.74978 .38116 m .75136 .38253 L .75325 .38103 L F
.75325 .38103 m .75136 .38253 L .74978 .38116 L F
.46 .554 .864 r
.75483 .38507 m .75136 .38253 L .75325 .38103 L F
.392 .056 .271 r
.65873 .42252 m .65832 .42411 L .6558 .42476 L F
.275 0 .033 r
.66228 .42165 m .65832 .42411 L .65873 .42252 L F
.845 .739 .746 r
.49703 .62487 m .49824 .62791 L .49576 .62696 L F
.698 .161 0 r
.49824 .62791 m .49722 .62807 L .49576 .62696 L F
0 0 .253 r
.49945 .62409 m .49824 .62791 L .49703 .62487 L F
.49945 .62409 m .49951 .62673 L .49824 .62791 L F
.395 .3 .629 r
.49951 .62673 m .49722 .62807 L .49824 .62791 L F
.158 .424 .863 r
.55174 .6093 m .55285 .60853 L .55036 .60733 L F
.336 .755 .977 r
.55504 .60947 m .55285 .60853 L .55174 .6093 L F
.629 .638 .84 r
.73499 .39724 m .73903 .40013 L .73752 .39652 L F
.618 .648 .858 r
.73752 .39652 m .73903 .40013 L .74102 .3977 L F
0 .549 .707 r
.21879 .53761 m .22075 .53771 L .22283 .53781 L F
.048 0 0 r
.22075 .53771 m .22531 .53765 L .22283 .53781 L F
.956 .744 .576 r
.58235 .52212 m .58119 .51854 L .58103 .52166 L F
.561 .68 .919 r
.76399 .42728 m .76545 .42432 L .76259 .42436 L F
.76399 .42728 m .7666 .42681 L .76545 .42432 L F
.562 .303 .481 r
.48093 .62711 m .47869 .62518 L .47981 .62416 L F
.48093 .62711 m .47847 .62749 L .47869 .62518 L F
.748 .257 0 r
.51449 .54589 m .51632 .54789 L .51838 .54627 L F
.047 .471 .884 r
.47775 .56116 m .4783 .56037 L .47613 .56108 L F
.47775 .56116 m .4799 .56215 L .4783 .56037 L F
0 0 0 r
.83624 .4321 m .83757 .43092 L .83757 .431 L F
.83757 .43092 m .83893 .42973 L .83757 .431 L F
.747 .36 0 r
.83757 .431 m .83796 .43163 L .83756 .43075 L F
.83757 .431 m .83756 .43075 L .83702 .42959 L F
.361 .129 .42 r
.83757 .431 m .83702 .42959 L .83624 .4321 L F
0 .298 .776 r
.16919 .7125 m .16948 .71267 L .16962 .71294 L F
.285 .12 .473 r
.16948 .71267 m .16899 .71538 L .16962 .71294 L F
.883 .954 .847 r
.73967 .38714 m .74015 .3885 L .74169 .3862 L F
0 0 .532 r
.74198 .39108 m .74015 .3885 L .73967 .38714 L F
.476 .367 .651 r
.44933 .63687 m .45113 .6333 L .44935 .63384 L F
.518 .305 .529 r
.44901 .58109 m .44645 .57909 L .4487 .57805 L F
.44901 .58109 m .44654 .5816 L .44645 .57909 L F
.867 .431 .161 r
.52044 .5668 m .51872 .56629 L .51759 .56453 L F
.812 .335 .067 r
.52246 .56948 m .51872 .56629 L .52044 .5668 L F
.647 .585 .771 r
.43007 .64937 m .43033 .65197 L .43323 .64972 L F
.967 .705 .484 r
.43666 .65211 m .43817 .65558 L .43642 .65401 L F
.339 .655 .97 r
.43642 .65401 m .43939 .65533 L .43817 .65558 L F
.43817 .65558 m .43939 .65533 L .43642 .65401 L F
.309 .279 .662 r
.43939 .65533 m .44025 .65742 L .43817 .65558 L F
.153 .688 .846 r
.25355 .53769 m .2559 .53753 L .25747 .53782 L F
.207 .72 .884 r
.2559 .53753 m .25981 .53779 L .25747 .53782 L F
0 0 .407 r
.41929 .64289 m .41983 .64558 L .41941 .64592 L F
0 0 .096 r
.41983 .64558 m .41933 .6482 L .41941 .64592 L F
.593 .027 0 r
.48688 .56076 m .48869 .56237 L .48987 .56252 L F
.56 0 0 r
.48869 .56237 m .49217 .5643 L .48987 .56252 L F
.566 0 0 r
.48987 .56252 m .49217 .5643 L .49375 .56487 L F
.617 .492 .688 r
.31254 .56079 m .30915 .55788 L .31214 .55823 L F
.31254 .56079 m .30992 .5613 L .30915 .55788 L F
0 .033 .541 r
.27028 .5851 m .27072 .58057 L .27064 .58259 L F
.772 .673 .754 r
.19529 .76053 m .19848 .75839 L .19451 .75804 L F
.987 .74 .469 r
.43659 .64928 m .43519 .64887 L .43323 .64972 L F
.43659 .64928 m .43666 .65211 L .43519 .64887 L F
.536 .253 .432 r
.45499 .60342 m .45322 .60766 L .45867 .60677 L F
.589 .381 .566 r
.82108 .42829 m .82339 .42503 L .81969 .42446 L F
.82108 .42829 m .82357 .42746 L .82339 .42503 L F
.82339 .42503 m .82357 .42746 L .82108 .42829 L F
.528 .915 .787 r
.82919 .44171 m .82736 .44321 L .82702 .4431 L F
.514 .899 .738 r
.82571 .4439 m .82736 .44321 L .82919 .44171 L F
.388 .215 .521 r
.73213 .39196 m .73362 .39359 L .73415 .39012 L F
.73213 .39196 m .73142 .39451 L .73362 .39359 L F
.734 .707 .825 r
.67357 .43383 m .67462 .43735 L .67668 .43597 L F
.957 .71 .522 r
.56664 .55225 m .56505 .55338 L .56525 .551 L F
.56664 .55225 m .56647 .55477 L .56505 .55338 L F
0 0 0 r
.49297 .58873 m .49401 .58719 L .4951 .58544 L F
.49297 .58873 m .4929 .58946 L .49401 .58719 L F
.316 .102 .422 r
.26544 .60105 m .26688 .60261 L .26721 .60019 L F
.26544 .60105 m .26502 .60334 L .26688 .60261 L F
.633 .877 .987 r
.78664 .44681 m .79037 .4468 L .78926 .44614 L F
.62 .914 .98 r
.78926 .44614 m .79037 .4468 L .79278 .44567 L F
.493 .335 .596 r
.31181 .57005 m .3118 .57249 L .30955 .57304 L F
.589 .456 .668 r
.3118 .57249 m .30984 .57817 L .30955 .57304 L F
.703 .957 .949 r
.42586 .62346 m .42394 .62475 L .42519 .6252 L F
.676 .736 .896 r
.41619 .61558 m .4205 .61651 L .41858 .61517 L F
.808 .841 .875 r
.41858 .61517 m .4205 .61651 L .42251 .61456 L F
.588 .698 .918 r
.79272 .43504 m .79142 .43772 L .79056 .43622 L F
.79272 .43504 m .79409 .43704 L .79142 .43772 L F
.965 .64 .27 r
.44366 .62529 m .44368 .62752 L .44221 .62371 L F
.676 .341 .4 r
.44736 .62711 m .44368 .62752 L .44366 .62529 L F
.523 .25 .442 r
.4826 .60236 m .47968 .60599 L .48027 .60299 L F
.633 .4 .547 r
.20177 .72997 m .20349 .73264 L .20417 .72899 L F
0 0 .052 r
.20417 .72899 m .20462 .7295 L .20664 .72878 L F
.341 .27 .63 r
.20177 .72997 m .20217 .73371 L .20337 .73328 L F
.20365 .73231 m .20337 .73328 L .20419 .73298 L F
0 0 .052 r
.20417 .72899 m .20349 .73264 L .2038 .7318 L F
.155 .16 .612 r
.20462 .7295 m .20349 .73264 L .20419 .73298 L F
.341 .27 .63 r
.20177 .72997 m .20419 .73298 L .20349 .73264 L F
.20177 .72997 m .20337 .73328 L .20365 .73231 L F
0 0 .052 r
.2045 .72936 m .2038 .7318 L .20462 .7295 L F
.20417 .72899 m .2038 .7318 L .2045 .72936 L F
.482 .191 .395 r
.27658 .63269 m .27114 .63641 L .27195 .63308 L F
.658 .543 .712 r
.46652 .61244 m .46701 .61581 L .4643 .61593 L F
.805 .604 .63 r
.46701 .61581 m .46337 .61783 L .4643 .61593 L F
.85 .743 .745 r
.57789 .53327 m .57921 .53424 L .57812 .53108 L F
.869 .701 .671 r
.57864 .53401 m .57921 .53424 L .57789 .53327 L F
.57864 .53401 m .57906 .53689 L .57921 .53424 L F
.114 .098 .56 r
.4951 .58544 m .49691 .58462 L .49632 .58153 L F
0 0 0 r
.4951 .58544 m .49401 .58719 L .49691 .58462 L F
.984 .715 .43 r
.43412 .65938 m .43548 .65836 L .43181 .65771 L F
.43412 .65938 m .43578 .66053 L .43548 .65836 L F
.333 .368 .748 r
.17098 .604 m .17161 .60605 L .16961 .60635 L F
.633 .097 0 r
.172 .60734 m .1721 .60675 L .16961 .60635 L F
.333 .368 .748 r
.17161 .60605 m .172 .60734 L .16961 .60635 L F
.218 .723 .901 r
.16961 .60635 m .1721 .60675 L .16848 .60652 L F
.16961 .60635 m .16848 .60652 L .16754 .60647 L F
.633 .097 0 r
.172 .60734 m .17365 .60846 L .1721 .60675 L F
.5 .563 .851 r
.17535 .60937 m .1721 .60675 L .17365 .60846 L F
.747 .495 .55 r
.57251 .50354 m .57481 .50626 L .57494 .50383 L F
.993 .83 .462 r
.5161 .61134 m .51708 .60989 L .51543 .60915 L F
.5161 .61134 m .51677 .61266 L .51708 .60989 L F
.574 .457 .682 r
.48405 .57656 m .48644 .57608 L .48653 .57372 L F
.524 .389 .639 r
.30734 .59382 m .30508 .59774 L .30461 .59441 L F
.794 .719 .781 r
.7785 .39395 m .78201 .39469 L .78081 .39161 L F
.804 .699 .749 r
.7785 .39395 m .77962 .39746 L .78201 .39469 L F
.511 0 0 r
.21186 .64632 m .21054 .64631 L .20866 .64532 L F
.61 .923 .972 r
.21244 .64489 m .21186 .64632 L .21368 .64545 L F
.684 .976 .9 r
.21244 .64489 m .21054 .64631 L .21186 .64632 L F
.568 .565 .81 r
.30866 .58906 m .30671 .59079 L .3064 .58914 L F
.30866 .58906 m .30916 .59034 L .30671 .59079 L F
.212 0 .026 r
.15511 .564 m .15721 .56339 L .15857 .56142 L F
.103 0 0 r
.15857 .56142 m .15908 .56265 L .16032 .56024 L F
.15857 .56142 m .15721 .56339 L .15908 .56265 L F
.579 .488 .715 r
.23146 .69667 m .22894 .69801 L .22865 .69463 L F
.448 .202 .447 r
.23146 .69667 m .22857 .70016 L .22894 .69801 L F
.101 0 0 r
.54496 .50908 m .54592 .51019 L .54718 .5087 L F
.54496 .50908 m .54377 .51117 L .54592 .51019 L F
.862 .908 .863 r
.56992 .59974 m .57122 .60068 L .57399 .5978 L F
.662 .695 .87 r
.67102 .4361 m .67209 .4322 L .66964 .43311 L F
.67102 .4361 m .67357 .43383 L .67209 .4322 L F
.849 .541 .466 r
.50433 .61794 m .50126 .6146 L .50194 .61599 L F
.021 .018 .511 r
.42986 .64583 m .43129 .6479 L .43151 .64581 L F
.42986 .64583 m .43007 .64937 L .43129 .6479 L F
.504 .491 .776 r
.31227 .57851 m .30951 .58069 L .30999 .57908 L F
.31227 .57851 m .31491 .58212 L .30951 .58069 L F
.423 .32 .633 r
.31268 .58339 m .30951 .58069 L .31491 .58212 L F
.31268 .58339 m .31075 .58731 L .30951 .58069 L F
.382 .029 .237 r
.26895 .63702 m .26589 .63922 L .26674 .6376 L F
.806 .861 .89 r
.46739 .63107 m .46395 .63167 L .4661 .63059 L F
.498 .278 .511 r
.46606 .62501 m .46589 .62756 L .46838 .62702 L F
.557 .899 .979 r
.46739 .63107 m .4661 .63059 L .46844 .62971 L F
.46739 .63107 m .4661 .63059 L .46844 .62971 L F
.473 .656 .94 r
.16572 .62393 m .16579 .62105 L .16363 .62127 L F
.16572 .62393 m .16825 .62376 L .16579 .62105 L F
.165 .555 .93 r
.16572 .62393 m .16897 .6254 L .16825 .62376 L F
.421 .719 .987 r
.29423 .54212 m .29348 .54358 L .29263 .54173 L F
.29423 .54212 m .29574 .54348 L .29348 .54358 L F
.772 .992 .777 r
.24868 .64819 m .25167 .64592 L .25066 .64575 L F
.004 .567 .801 r
.2439 .55106 m .24038 .55046 L .24172 .55153 L F
.314 .373 .763 r
.48347 .59933 m .484 .59781 L .48181 .59722 L F
.48492 .59909 m .48537 .59902 L .484 .59781 L F
0 .114 .618 r
.48537 .59902 m .48592 .59939 L .484 .59781 L F
0 .193 .719 r
.484 .59781 m .48592 .59939 L .48539 .59974 L F
.484 .59781 m .48539 .59974 L .48515 .5999 L F
.314 .373 .763 r
.48347 .59933 m .48492 .59909 L .484 .59781 L F
.522 .796 .995 r
.83068 .41571 m .8298 .41452 L .82724 .41508 L F
.698 .743 .886 r
.83068 .41571 m .83236 .41142 L .8298 .41452 L F
.83068 .41571 m .83335 .41491 L .83236 .41142 L F
.727 .944 .632 r
.49289 .57359 m .49047 .57656 L .4913 .57476 L F
.975 .734 .508 r
.49047 .57656 m .48881 .57761 L .4913 .57476 L F
.49047 .57656 m .49041 .57909 L .48881 .57761 L F
.682 .397 .483 r
.5687 .50575 m .57251 .50354 L .56902 .50422 L F
.4 .134 .391 r
.42251 .61456 m .42539 .61194 L .42289 .61462 L F
.301 .647 .968 r
.80792 .3988 m .80449 .39732 L .80692 .39745 L F
.359 .7 .984 r
.81009 .39769 m .80792 .3988 L .80692 .39745 L F
.81009 .39769 m .81115 .39888 L .80792 .3988 L F
.709 .172 0 r
.49217 .5643 m .49291 .56522 L .49375 .56487 L F
.735 .211 0 r
.49291 .56522 m .49479 .56603 L .49375 .56487 L F
0 0 .219 r
.41881 .67365 m .4191 .676 L .41898 .67162 L F
.835 .427 0 r
.52953 .58182 m .52755 .57848 L .5282 .57973 L F
.94 .831 .387 r
.41477 .63775 m .4143 .64025 L .41411 .63874 L F
.654 .154 .047 r
.41477 .63775 m .41411 .63874 L .41149 .63696 L F
.455 .509 .825 r
.41693 .63589 m .41818 .63923 L .41477 .63775 L F
.288 0 0 r
.27163 .5581 m .2706 .55912 L .26779 .55894 L F
.148 .59 .93 r
.27213 .56027 m .2706 .55912 L .27163 .5581 L F
.641 .674 .866 r
.74169 .3862 m .7459 .38797 L .74534 .38649 L F
0 0 0 r
.7459 .38797 m .74855 .38789 L .74918 .3879 L F
.046 .186 .688 r
.74855 .38789 m .75003 .38966 L .7511 .38723 L F
0 0 0 r
.74918 .3879 m .74855 .38789 L .7511 .38723 L F
.7459 .38797 m .74918 .3879 L .74534 .38649 L F
.489 .265 .501 r
.48061 .61887 m .4827 .62075 L .48314 .61842 L F
.48061 .61887 m .48029 .62146 L .4827 .62075 L F
0 0 0 r
.18659 .54546 m .18553 .54601 L .18746 .54525 L F
.432 .73 .989 r
.74536 .39062 m .74335 .3922 L .74198 .39108 L F
.74536 .39062 m .74643 .39217 L .74335 .3922 L F
.697 .708 .856 r
.75527 .41786 m .759 .41863 L .7583 .41686 L F
0 0 0 r
.759 .41863 m .7605 .41684 L .76121 .41591 L F
.858 .876 .851 r
.7583 .41686 m .759 .41863 L .76121 .41591 L F
.136 .198 .664 r
.759 .41863 m .76106 .42077 L .7605 .41684 L F
.611 .042 0 r
.52839 .55659 m .52747 .55531 L .52629 .55453 L F
.52839 .55659 m .53008 .55714 L .52747 .55531 L F
.271 .446 .851 r
.30816 .54683 m .30955 .5497 L .30761 .54889 L F
.245 .041 .393 r
.26675 .59492 m .26854 .59415 L .26899 .59136 L F
.344 .252 .605 r
.26675 .59492 m .26871 .59675 L .26854 .59415 L F
.236 .242 .662 r
.26744 .59755 m .26871 .59675 L .26675 .59492 L F
.709 .53 .645 r
.43764 .6143 m .43862 .61549 L .43707 .61287 L F
.402 .219 .515 r
.43862 .61549 m .44092 .6124 L .43707 .61287 L F
.134 0 0 r
.27402 .57582 m .27627 .57526 L .27801 .57354 L F
.689 .246 .195 r
.27627 .57526 m .27967 .57565 L .27801 .57354 L F
.045 .121 .62 r
.27801 .57354 m .27967 .57565 L .27896 .57274 L F
.757 .674 .77 r
.20217 .73371 m .20337 .73488 L .2053 .73274 L F
.698 .461 .562 r
.43151 .64581 m .43554 .64706 L .43526 .64317 L F
.297 .62 .959 r
.43526 .64317 m .43609 .64193 L .4338 .64225 L F
.789 .656 .717 r
.56628 .52194 m .56253 .52151 L .56448 .51811 L F
.822 .452 .355 r
.56621 .52425 m .56253 .52151 L .56628 .52194 L F
0 .032 .593 r
.53461 .5976 m .53659 .60073 L .53639 .59991 L F
.681 .851 .964 r
.53782 .60233 m .53996 .60164 L .53851 .60065 L F
0 0 .384 r
.53659 .60073 m .53682 .60331 L .53792 .60301 L F
.681 .851 .964 r
.53788 .60309 m .53805 .60297 L .538 .60281 L F
0 0 .384 r
.538 .60281 m .53792 .60301 L .53809 .60296 L F
.53659 .60073 m .53792 .60301 L .538 .60281 L F
.53659 .60073 m .538 .60281 L .53639 .59991 L F
.538 .60281 m .53797 .60273 L .53639 .59991 L F
.214 .346 .782 r
.53809 .60296 m .53736 .60153 L .53639 .59991 L F
.53736 .60153 m .53582 .5985 L .53597 .59888 L F
.53736 .60153 m .53597 .59888 L .53639 .59991 L F
.681 .851 .964 r
.53759 .60195 m .53851 .60065 L .53768 .60136 L F
.214 .346 .782 r
.53809 .60296 m .53768 .60136 L .53582 .5985 L F
.38 .469 .826 r
.53794 .60239 m .53735 .60346 L .53768 .60136 L F
.681 .851 .964 r
.53735 .60346 m .5378 .60237 L .53759 .60195 L F
.5378 .60237 m .53851 .60065 L .53759 .60195 L F
.53735 .60346 m .53788 .60309 L .53784 .60258 L F
.53788 .60309 m .538 .60281 L .53782 .60233 L F
.53805 .60297 m .53996 .60164 L .53782 .60233 L F
0 0 .384 r
.538 .60281 m .53809 .60296 L .53797 .60273 L F
.38 .469 .826 r
.53809 .60296 m .53735 .60346 L .53794 .60239 L F
.681 .851 .964 r
.53735 .60346 m .53784 .60258 L .53782 .60233 L F
.337 .741 .982 r
.17365 .60846 m .17746 .60925 L .17535 .60937 L F
.678 .167 .018 r
.45976 .63021 m .46395 .63167 L .46053 .63221 L F
.076 .615 .855 r
.29935 .54593 m .30201 .54621 L .30368 .54672 L F
.338 .797 .939 r
.30201 .54621 m .3058 .54618 L .30368 .54672 L F
0 0 0 r
.22722 .69514 m .22704 .69479 L .22582 .69592 L F
.283 0 0 r
.22704 .69479 m .22865 .69463 L .22689 .69452 L F
.579 .488 .715 r
.23146 .69667 m .22865 .69463 L .2308 .69447 L F
0 0 0 r
.2308 .69447 m .22865 .69463 L .22704 .69479 L F
.2308 .69447 m .22704 .69479 L .22944 .69391 L F
.22944 .69391 m .22704 .69479 L .22722 .69514 L F
.283 0 0 r
.22704 .69479 m .22689 .69452 L .22467 .69438 L F
0 0 0 r
.44515 .64633 m .44502 .6481 L .44532 .6448 L F
.594 .166 .199 r
.44515 .64633 m .44753 .64653 L .44647 .6472 L F
.746 .463 .502 r
.44515 .64633 m .44572 .65074 L .44489 .64996 L F
0 0 0 r
.44502 .6481 m .44489 .64996 L .44532 .6448 L F
.945 .848 .715 r
.44532 .6448 m .44504 .6481 L .44237 .64762 L F
.44504 .6481 m .44489 .64996 L .44376 .64891 L F
.44504 .6481 m .44376 .64891 L .44237 .64762 L F
.594 .166 .199 r
.44647 .6472 m .44967 .64671 L .44772 .64802 L F
.44753 .64653 m .44967 .64671 L .44647 .6472 L F
.311 0 0 r
.44532 .6448 m .44465 .64655 L .44486 .64649 L F
.749 .721 .191 r
.44515 .64633 m .44532 .6448 L .44557 .64385 L F
.311 0 0 r
.44532 .6448 m .44486 .64649 L .44707 .64591 L F
.749 .721 .191 r
.44557 .64385 m .44532 .6448 L .44593 .64175 L F
.504 .836 .999 r
.21846 .62901 m .21775 .63037 L .21628 .62923 L F
.21846 .62901 m .22002 .62981 L .21775 .63037 L F
.313 .799 .883 r
.22531 .53765 m .2272 .53723 L .22893 .53728 L F
.817 .656 .682 r
.57852 .50848 m .57622 .51211 L .57994 .51255 L F
.862 .651 .616 r
.57623 .51448 m .57994 .51255 L .57622 .51211 L F
.57623 .51448 m .57831 .51516 L .57994 .51255 L F
.763 .684 .775 r
.82258 .43946 m .8235 .44293 L .8214 .44344 L F
.918 .523 .203 r
.8235 .44293 m .82142 .44629 L .8214 .44344 L F
.8235 .44293 m .82423 .44553 L .82142 .44629 L F
.524 .427 .687 r
.82677 .44021 m .8235 .44293 L .82258 .43946 L F
.82677 .44021 m .82702 .4431 L .8235 .44293 L F
0 .56 .803 r
.2602 .53733 m .26254 .53777 L .26183 .53776 L F
.397 0 0 r
.26183 .53776 m .26605 .53712 L .26376 .53754 L F
.26183 .53776 m .26411 .53807 L .26605 .53712 L F
0 .56 .803 r
.26254 .53777 m .26411 .53807 L .26183 .53776 L F
.019 0 0 r
.26061 .53774 m .26183 .53776 L .26376 .53754 L F
.25981 .53779 m .26183 .53776 L .26061 .53774 L F
.727 .944 .632 r
.49289 .57359 m .4913 .57476 L .49128 .57246 L F
.319 .728 .978 r
.17636 .63616 m .17816 .63709 L .18012 .63695 L F
.324 0 0 r
.80494 .4439 m .80424 .4443 L .80186 .44379 L F
.561 0 0 r
.80494 .4439 m .80776 .44578 L .80424 .4443 L F
.501 .504 .792 r
.40284 .6246 m .40506 .62442 L .40395 .62107 L F
.834 .428 0 r
.78687 .39137 m .78877 .39436 L .78773 .39317 L F
0 .297 .779 r
.78877 .39436 m .79004 .39443 L .78773 .39317 L F
.78877 .39436 m .79135 .39601 L .79004 .39443 L F
.907 .77 .699 r
.57648 .52966 m .5799 .52778 L .57824 .52725 L F
.57648 .52966 m .57812 .53108 L .5799 .52778 L F
.823 .91 .899 r
.58156 .5238 m .5799 .52778 L .58266 .52469 L F
.58156 .5238 m .57824 .52725 L .5799 .52778 L F
.635 .464 .634 r
.74079 .37941 m .74328 .37904 L .7433 .37644 L F
0 0 .389 r
.51021 .60653 m .5111 .60894 L .51066 .60516 L F
.982 .786 .378 r
.49724 .62201 m .49703 .62487 L .49659 .62349 L F
.905 .839 .77 r
.49703 .62487 m .49458 .62511 L .49587 .62386 L F
.49703 .62487 m .49587 .62386 L .49606 .62376 L F
.49665 .62367 m .49606 .62376 L .49659 .62349 L F
.49703 .62487 m .49606 .62376 L .49665 .62367 L F
.49703 .62487 m .49576 .62696 L .49458 .62511 L F
.814 .519 .49 r
.49458 .62511 m .4929 .62388 L .49534 .62344 L F
.762 .643 .729 r
.49549 .6228 m .4929 .62388 L .49154 .62115 L F
.854 .54 .456 r
.49538 .62325 m .49541 .62321 L .4954 .6232 L F
.814 .519 .49 r
.49458 .62511 m .49559 .6234 L .49595 .62378 L F
.854 .54 .456 r
.49484 .62395 m .49606 .62376 L .49606 .62373 L F
.49538 .62325 m .49603 .62293 L .49572 .62281 L F
.49541 .62321 m .49555 .6228 L .49449 .62276 L F
.762 .643 .729 r
.49549 .6228 m .49367 .62204 L .49449 .62276 L F
.854 .54 .456 r
.49555 .6228 m .49564 .62252 L .49449 .62276 L F
.762 .643 .729 r
.49559 .6234 m .49538 .62325 L .49549 .6228 L F
.727 .413 .448 r
.49603 .62293 m .49672 .62279 L .49601 .62245 L F
0 0 .514 r
.49601 .62245 m .49703 .62487 L .49659 .62349 L F
.727 .413 .448 r
.49664 .62321 m .49672 .62279 L .49603 .62293 L F
0 0 .514 r
.49601 .62245 m .49659 .62349 L .49651 .62323 L F
.727 .413 .448 r
.49616 .62594 m .49659 .62349 L .49603 .62293 L F
.49659 .62349 m .49664 .62321 L .49636 .62308 L F
.49659 .62349 m .49636 .62308 L .49603 .62293 L F
.762 .643 .729 r
.49651 .62323 m .49549 .6228 L .49449 .62276 L F
.49367 .62204 m .49154 .62115 L .49208 .62144 L F
.49367 .62204 m .49208 .62144 L .49449 .62276 L F
.854 .54 .456 r
.49538 .62325 m .49606 .62373 L .49603 .62293 L F
.49572 .62281 m .49603 .62293 L .49601 .62245 L F
.762 .643 .729 r
.49559 .6234 m .49534 .62344 L .49538 .62325 L F
.814 .519 .49 r
.49506 .62429 m .49534 .62344 L .49559 .6234 L F
.854 .54 .456 r
.49484 .62395 m .49606 .62373 L .49538 .62325 L F
.762 .643 .729 r
.49651 .62323 m .49559 .6234 L .49549 .6228 L F
.49534 .62344 m .4929 .62388 L .49549 .6228 L F
.814 .519 .49 r
.49458 .62511 m .49206 .6262 L .4929 .62388 L F
.854 .54 .456 r
.49401 .62503 m .49538 .62325 L .49449 .62276 L F
.49538 .62325 m .4954 .6232 L .49449 .62276 L F
.49541 .62321 m .49601 .62245 L .49564 .62252 L F
.814 .519 .49 r
.49458 .62511 m .49534 .62344 L .49506 .62429 L F
.49595 .62378 m .49559 .6234 L .49651 .62323 L F
0 .243 .734 r
.49576 .62696 m .49619 .62669 L .49458 .62511 L F
.625 .96 .841 r
.49401 .62503 m .49206 .6262 L .49458 .62511 L F
.657 .113 0 r
.49458 .62511 m .49619 .62669 L .49401 .62503 L F
.854 .54 .456 r
.49401 .62503 m .49619 .62669 L .49607 .6239 L F
.49598 .62381 m .49607 .6239 L .49606 .62376 L F
.49401 .62503 m .49607 .6239 L .49598 .62381 L F
.49401 .62503 m .49606 .62376 L .49484 .62395 L F
.905 .839 .77 r
.49659 .62349 m .49587 .62386 L .49651 .62323 L F
.727 .413 .448 r
.49619 .62669 m .49945 .62409 L .49738 .6231 L F
.49662 .62348 m .49738 .6231 L .49672 .62279 L F
.49619 .62669 m .49738 .6231 L .49662 .62348 L F
.49619 .62669 m .49672 .62279 L .49616 .62594 L F
.982 .786 .378 r
.4967 .62292 m .49659 .62349 L .49651 .62323 L F
.49724 .62201 m .49659 .62349 L .4967 .62292 L F
.3 .609 .954 r
.2906 .53977 m .28975 .54111 L .288 .53979 L F
.2906 .53977 m .29263 .54173 L .28975 .54111 L F
.9 .906 .819 r
.45134 .64618 m .44772 .64802 L .44967 .64671 L F
.45117 .64639 m .44897 .64907 L .44772 .64802 L F
.632 .444 .611 r
.45134 .64618 m .4513 .6491 L .44897 .64907 L F
.599 .289 .415 r
.4513 .6491 m .45137 .65113 L .44897 .64907 L F
0 .171 .696 r
.44897 .64907 m .45057 .64978 L .44772 .64802 L F
.44897 .64907 m .45057 .65044 L .45057 .64978 L F
.45057 .65044 m .45137 .65113 L .45057 .64978 L F
0 .144 .688 r
.45057 .64978 m .45082 .64884 L .45056 .64899 L F
.084 .514 .903 r
.44237 .64762 m .44489 .64996 L .44161 .64851 L F
.675 .483 .618 r
.44489 .64996 m .44572 .65074 L .44161 .64851 L F
.752 .479 .518 r
.44527 .65151 m .44161 .64851 L .44572 .65074 L F
.44527 .65151 m .44187 .65154 L .44161 .64851 L F
.873 .861 .826 r
.44363 .65032 m .44572 .65074 L .44772 .64802 L F
.44363 .65032 m .44537 .64934 L .44556 .64902 L F
.44537 .64934 m .44772 .64802 L .44556 .64902 L F
.404 0 0 r
.45057 .64978 m .44853 .64947 L .44801 .6482 L F
.44853 .64947 m .4456 .64903 L .44801 .6482 L F
.44801 .6482 m .4456 .64903 L .44772 .64802 L F
.4456 .64903 m .44556 .64902 L .44772 .64802 L F
.9 .906 .819 r
.45134 .64618 m .45117 .64639 L .44772 .64802 L F
.404 0 0 r
.45057 .64978 m .44877 .65005 L .44556 .64902 L F
.34 .412 .79 r
.44556 .64902 m .44877 .65005 L .44719 .6462 L F
.44556 .64902 m .44719 .6462 L .44707 .64591 L F
0 .144 .688 r
.45057 .64978 m .45056 .64899 L .44877 .65005 L F
.604 .422 .608 r
.45433 .64845 m .4513 .6491 L .45134 .64618 L F
.371 .194 .507 r
.22011 .6977 m .22219 .69837 L .22263 .69759 L F
.22011 .6977 m .21963 .70059 L .22219 .69837 L F
.862 .908 .863 r
.56992 .59974 m .57399 .5978 L .57185 .59866 L F
.887 .991 .781 r
.57379 .59612 m .57399 .5978 L .57658 .59484 L F
.57379 .59612 m .57324 .59726 L .57399 .5978 L F
.843 .997 .829 r
.57324 .59726 m .57185 .59866 L .57399 .5978 L F
.702 .315 .312 r
.7472 .381 m .74705 .37945 L .74328 .37904 L F
.605 .241 .325 r
.7472 .381 m .74978 .38116 L .74705 .37945 L F
.546 .439 .683 r
.43353 .57631 m .43547 .57957 L .43542 .57622 L F
.43353 .57631 m .43379 .58032 L .43547 .57957 L F
.607 .418 .6 r
.40611 .61271 m .40622 .61614 L .40376 .61578 L F
0 0 .344 r
.4066 .6137 m .40611 .61271 L .40774 .61177 L F
.4066 .6137 m .40622 .61614 L .40611 .61271 L F
.4066 .6137 m .40611 .61271 L .40774 .61177 L F
.4066 .6137 m .40622 .61614 L .40611 .61271 L F
.607 .418 .6 r
.40376 .61578 m .40622 .61614 L .40611 .61271 L F
.683 .386 .465 r
.44182 .63091 m .44142 .63358 L .43871 .63295 L F
.49 .445 .734 r
.44368 .62752 m .44182 .63091 L .4415 .62882 L F
.44368 .62752 m .44434 .63048 L .44182 .63091 L F
.476 .202 .419 r
.44414 .63297 m .44182 .63091 L .44434 .63048 L F
.44414 .63297 m .44142 .63358 L .44182 .63091 L F
.861 .431 .193 r
.79648 .40212 m .79379 .3999 L .79522 .40115 L F
.66 .711 .886 r
.66565 .42734 m .66175 .42683 L .66481 .42425 L F
.817 .8 .836 r
.66807 .42451 m .66565 .42734 L .66481 .42425 L F
.852 .912 .874 r
.50413 .62286 m .50128 .62498 L .50569 .62077 L F
.452 .701 .974 r
.19736 .61919 m .19681 .62115 L .19507 .61946 L F
.19736 .61919 m .19896 .62096 L .19681 .62115 L F
.344 .514 .882 r
.20028 .62384 m .19681 .62115 L .19896 .62096 L F
0 0 .08 r
.15033 .56776 m .15122 .56829 L .15243 .56721 L F
.15033 .56776 m .14952 .56966 L .15122 .56829 L F
.824 .706 .734 r
.57649 .54242 m .57832 .54314 L .57677 .53994 L F
.83 .605 .598 r
.57694 .54542 m .57832 .54314 L .57649 .54242 L F
.57694 .54542 m .57817 .54588 L .57832 .54314 L F
.66 .107 0 r
.48966 .54659 m .4898 .54734 L .48815 .54514 L F
.48966 .54659 m .49187 .54862 L .4898 .54734 L F
.644 .089 0 r
.49348 .54931 m .49187 .54862 L .48966 .54659 L F
.585 .034 0 r
.49553 .54942 m .49187 .54862 L .49348 .54931 L F
.48 .74 .985 r
.81968 .39971 m .81801 .40136 L .81708 .40013 L F
.81968 .39971 m .82062 .40112 L .81801 .40136 L F
0 0 0 r
.53767 .58133 m .53872 .58076 L .53754 .58162 L F
.53767 .58133 m .53702 .582 L .53829 .58371 L F
.53767 .58133 m .53754 .58162 L .53702 .582 L F
.758 .426 0 r
.53773 .58118 m .53767 .58133 L .53839 .58294 L F
.53692 .579 m .53767 .58133 L .53773 .58118 L F
.915 .548 .108 r
.53767 .58133 m .53963 .58518 L .53839 .58294 L F
.579 .829 .992 r
.54345 .606 m .54326 .60408 L .54043 .60584 L F
.333 .816 .851 r
.54345 .606 m .54515 .60521 L .54326 .60408 L F
.54345 .606 m .54637 .60509 L .54515 .60521 L F
.816 .652 .679 r
.5755 .53901 m .57906 .53689 L .57864 .53401 L F
.5755 .53901 m .57677 .53994 L .57906 .53689 L F
.52 .573 .849 r
.74102 .3977 m .74212 .4011 L .74404 .39872 L F
.509 .556 .839 r
.74212 .4011 m .74529 .40211 L .74404 .39872 L F
.399 .536 .878 r
.74212 .4011 m .74608 .40431 L .74529 .40211 L F
.645 .935 .967 r
.74931 .39159 m .74801 .39185 L .74833 .39199 L F
.74801 .39185 m .74643 .39217 L .74833 .39199 L F
0 .086 .611 r
.74905 .39231 m .74833 .39199 L .75075 .39412 L F
.645 .935 .967 r
.74955 .39154 m .74931 .39159 L .74833 .39199 L F
.046 .186 .688 r
.74961 .38916 m .74955 .39154 L .75003 .38966 L F
.74855 .38789 m .74939 .39096 L .74961 .38916 L F
.74939 .39096 m .74955 .39154 L .74961 .38916 L F
0 0 0 r
.74918 .3879 m .7511 .38723 L .75039 .3864 L F
.915 .803 .721 r
.7511 .38723 m .74974 .38815 L .75039 .3864 L F
.74974 .38815 m .74808 .38927 L .74987 .38704 L F
.74974 .38815 m .74987 .38704 L .75039 .3864 L F
.861 .996 .769 r
.75003 .38966 m .74955 .39154 L .74833 .39199 L F
.454 .744 .991 r
.74833 .39199 m .74536 .39062 L .74808 .38927 L F
.862 .876 .847 r
.75003 .38966 m .74833 .39199 L .74808 .38927 L F
0 .086 .611 r
.74751 .39065 m .74833 .39199 L .74905 .39231 L F
.454 .744 .991 r
.74833 .39199 m .74643 .39217 L .74536 .39062 L F
.949 .954 .665 r
.74709 .3925 m .74833 .39199 L .74751 .39065 L F
.74633 .39582 m .74833 .39199 L .74709 .3925 L F
.661 .965 .923 r
.23729 .55111 m .2358 .55106 L .23541 .55231 L F
.238 .566 .938 r
.23541 .55231 m .2358 .55106 L .23413 .55075 L F
.273 0 0 r
.1645 .57626 m .16282 .57794 L .16066 .57823 L F
0 0 0 r
.16479 .57673 m .1645 .57626 L .16591 .57573 L F
.16479 .57673 m .16282 .57794 L .1645 .57626 L F
0 .213 .738 r
.79168 .39806 m .793 .39803 L .79135 .39601 L F
.79168 .39806 m .79379 .3999 L .793 .39803 L F
.751 .518 .578 r
.19965 .74416 m .20441 .74314 L .20037 .74274 L F
.19965 .74416 m .20419 .74577 L .20441 .74314 L F
.966 .736 .54 r
.20545 .75417 m .20706 .75526 L .20508 .75713 L F
.347 .711 .985 r
.20747 .75409 m .20706 .75526 L .20545 .75417 L F
.724 .937 .614 r
.20508 .75713 m .20706 .75526 L .20747 .75409 L F
.277 .774 .736 r
.20334 .73335 m .2053 .73274 L .20419 .73298 L F
.42 .159 .41 r
.2053 .73274 m .20736 .73325 L .20419 .73298 L F
.675 .258 .245 r
.20419 .73298 m .20736 .73325 L .20575 .73449 L F
.025 .221 .726 r
.20419 .73298 m .20575 .73449 L .20496 .73266 L F
.20419 .73298 m .20496 .73266 L .20459 .73181 L F
.277 .774 .736 r
.20217 .73371 m .20334 .73335 L .20419 .73298 L F
.42 .159 .41 r
.2053 .73274 m .20782 .73078 L .20736 .73325 L F
.869 .573 .486 r
.53019 .56003 m .5327 .55837 L .53008 .55714 L F
.53019 .56003 m .53317 .56084 L .5327 .55837 L F
0 0 0 r
.25479 .64258 m .25773 .64016 L .25605 .6424 L F
.52 .107 .198 r
.25605 .6424 m .25773 .64016 L .25958 .64154 L F
.552 .078 .082 r
.25773 .64016 m .26012 .64056 L .25958 .64154 L F
.339 .1 .398 r
.30534 .60029 m .30284 .6034 L .30288 .60077 L F
.839 .51 .43 r
.44333 .61254 m .448 .61551 L .44589 .61191 L F
.44333 .61254 m .44334 .61474 L .448 .61551 L F
.408 .511 .851 r
.44334 .61474 m .44835 .61974 L .448 .61551 L F
.145 .016 .433 r
.448 .61551 m .44974 .61741 L .45099 .61589 L F
.342 .426 .803 r
.75653 .38322 m .75483 .38507 L .75325 .38103 L F
.445 .588 .9 r
.75653 .38322 m .75719 .3852 L .75483 .38507 L F
.603 .217 .284 r
.17535 .57193 m .17376 .57438 L .17333 .57435 L F
0 0 0 r
.17535 .57193 m .17358 .57342 L .17633 .57076 L F
.603 .217 .284 r
.17535 .57193 m .17125 .57419 L .17358 .57342 L F
.17535 .57193 m .17333 .57435 L .17125 .57419 L F
0 0 0 r
.17535 .57193 m .17633 .57076 L .17636 .57072 L F
.17818 .56978 m .17535 .57193 L .17636 .57072 L F
.569 .935 .916 r
.21136 .71835 m .21192 .7172 L .21559 .71635 L F
.21136 .71835 m .20985 .71829 L .21192 .7172 L F
.828 .644 .654 r
.57804 .55105 m .57934 .55453 L .58197 .55193 L F
.616 .701 .905 r
.83066 .40287 m .8281 .40368 L .82705 .40209 L F
.83066 .40287 m .83074 .40291 L .8281 .40368 L F
.543 .846 .999 r
.20031 .64302 m .20173 .64385 L .20368 .64331 L F
.429 0 0 r
.15496 .59168 m .15696 .59248 L .15683 .59198 L F
.182 .532 .923 r
.15929 .59198 m .16095 .59364 L .15683 .59198 L F
.47 .526 .833 r
.15683 .59198 m .16095 .59364 L .15901 .59395 L F
.182 .532 .923 r
.15929 .59198 m .15683 .59198 L .15696 .59248 L F
.621 .411 .576 r
.74097 .38184 m .74328 .37904 L .74079 .37941 L F
.603 .891 .989 r
.79409 .43704 m .79659 .43599 L .79739 .43678 L F
.737 .944 .95 r
.79739 .43678 m .79869 .43461 L .79971 .43564 L F
.79739 .43678 m .79659 .43599 L .79869 .43461 L F
.377 .071 .314 r
.45315 .56764 m .45507 .56884 L .45645 .56719 L F
.551 .88 .99 r
.45645 .56719 m .45753 .5658 L .45882 .56628 L F
.659 .506 .666 r
.45507 .56884 m .45753 .5658 L .45645 .56719 L F
.608 .773 .959 r
.78368 .44756 m .78526 .44501 L .78281 .44526 L F
.78368 .44756 m .78664 .44681 L .78526 .44501 L F
.824 .427 0 r
.53526 .57594 m .53692 .579 L .53647 .5763 L F
.216 0 0 r
.53991 .57343 m .53526 .57594 L .53647 .5763 L F
.364 .787 .974 r
.24548 .64325 m .24929 .64341 L .2473 .64302 L F
.671 .351 .423 r
.24866 .64578 m .25066 .64575 L .24929 .64341 L F
0 0 .502 r
.24929 .64341 m .24988 .64365 L .2473 .64302 L F
.24929 .64341 m .25066 .64575 L .24988 .64365 L F
.634 .547 .739 r
.50686 .61221 m .50894 .61623 L .50459 .61628 L F
.401 .466 .812 r
.50746 .61815 m .50459 .61628 L .50894 .61623 L F
1 .826 .499 r
.54163 .58839 m .54254 .58801 L .54007 .58858 L F
.056 .153 .649 r
.53963 .58518 m .54163 .58839 L .54007 .58858 L F
.86 .604 .069 r
.53072 .5875 m .52994 .5845 L .53131 .58596 L F
0 0 0 r
.25369 .64297 m .25479 .64258 L .25605 .6424 L F
.829 .359 .075 r
.49468 .54 m .49641 .5426 L .49825 .54331 L F
.9 .51 .273 r
.49641 .5426 m .49847 .54496 L .49825 .54331 L F
.622 .112 .013 r
.16441 .59929 m .16617 .59842 L .16483 .5967 L F
.16441 .59929 m .16825 .59996 L .16617 .59842 L F
.822 .907 .898 r
.49617 .59003 m .49931 .58935 L .49757 .58931 L F
.861 .987 .843 r
.49972 .58724 m .49931 .58935 L .5014 .58851 L F
.49972 .58724 m .49757 .58931 L .49931 .58935 L F
.654 .549 .724 r
.46193 .63937 m .4637 .64285 L .46016 .64288 L F
.612 .432 .615 r
.4637 .64285 m .46081 .64561 L .46016 .64288 L F
.271 0 0 r
.19102 .54446 m .19332 .54414 L .1953 .54247 L F
.523 .327 .556 r
.1953 .54247 m .1976 .54221 L .19765 .5399 L F
0 0 0 r
.1953 .54247 m .1955 .54328 L .1976 .54221 L F
.1953 .54247 m .19332 .54414 L .1955 .54328 L F
.905 .978 .794 r
.57792 .59118 m .57658 .59484 L .57855 .59152 L F
.57792 .59118 m .57574 .59409 L .57658 .59484 L F
.889 .981 .816 r
.57574 .59409 m .57379 .59612 L .57658 .59484 L F
.709 .978 .912 r
.80773 .4332 m .80874 .43286 L .80661 .43424 L F
0 .119 .653 r
.41818 .63923 m .41929 .64289 L .41815 .6404 L F
.538 .247 .42 r
.47053 .60558 m .47294 .60533 L .47072 .6037 L F
.626 .358 .492 r
.47072 .6037 m .47341 .60388 L .47374 .60343 L F
.588 .215 .302 r
.47072 .6037 m .47294 .60533 L .47341 .60388 L F
.64 .66 .854 r
.16249 .59527 m .15901 .59395 L .16095 .59364 L F
.303 .374 .77 r
.16365 .59339 m .16249 .59527 L .16095 .59364 L F
.16365 .59339 m .16483 .5967 L .16249 .59527 L F
.41 .844 .946 r
.23121 .53719 m .23352 .53663 L .23513 .53691 L F
.08 0 0 r
.23352 .53663 m .23732 .53661 L .23513 .53691 L F
.536 .398 .64 r
.48263 .61607 m .48547 .6178 L .48538 .61551 L F
.48263 .61607 m .48314 .61842 L .48547 .6178 L F
.868 .536 .42 r
.76643 .38555 m .76325 .3823 L .76404 .38418 L F
.899 .574 .423 r
.76422 .38698 m .76643 .38555 L .76404 .38418 L F
.76422 .38698 m .76687 .38773 L .76643 .38555 L F
.734 .707 .825 r
.67357 .43383 m .67668 .43597 L .67578 .43285 L F
.685 .672 .831 r
.67578 .43285 m .67668 .43597 L .67992 .43363 L F
.373 .489 .848 r
.44005 .64475 m .43898 .64713 L .43755 .64407 L F
.48 .254 .493 r
.4374 .64787 m .44005 .64475 L .43755 .64407 L F
.81 .601 .619 r
.43554 .64706 m .43519 .64887 L .43755 .64407 L F
.28 .42 .825 r
.7704 .43004 m .77187 .43325 L .77351 .43337 L F
.332 .114 .425 r
.13901 .5788 m .14145 .5753 L .13951 .57639 L F
.963 .659 .404 r
.49865 .56896 m .50075 .5733 L .50028 .57018 L F
.939 .751 .621 r
.56273 .57352 m .56222 .57605 L .56095 .57251 L F
.878 .442 .122 r
.7711 .38762 m .77451 .39147 L .77556 .38972 L F
.067 0 .193 r
.77556 .38972 m .77451 .39147 L .77706 .38806 L F
.33 0 .237 r
.4476 .5698 m .44438 .57304 L .44686 .57251 L F
.587 .325 .486 r
.44686 .57251 m .45013 .5695 L .4476 .5698 L F
.433 0 0 r
.50269 .57614 m .50544 .57796 L .50691 .57878 L F
.829 .428 .287 r
.50195 .57514 m .50544 .57796 L .50269 .57614 L F
0 0 0 r
.19209 .7611 m .19529 .76053 L .19399 .76077 L F
.772 .673 .754 r
.19529 .76053 m .19529 .75826 L .19631 .76025 L F
.19529 .76053 m .19451 .75804 L .19529 .75826 L F
.185 .714 .726 r
.19399 .76077 m .19529 .76053 L .19631 .76025 L F
.179 0 0 r
.20671 .55558 m .20252 .55721 L .2047 .55624 L F
.53 .451 .711 r
.31263 .56328 m .30992 .5613 L .31254 .56079 L F
.31263 .56328 m .31045 .5639 L .30992 .5613 L F
.737 .421 .447 r
.55878 .50546 m .56263 .50575 L .56247 .50369 L F
.715 .404 .45 r
.56247 .50369 m .56263 .50575 L .56608 .50571 L F
.824 .427 0 r
.53526 .57594 m .5358 .57774 L .53692 .579 L F
.299 .515 .897 r
.53533 .57678 m .53829 .57756 L .5358 .57774 L F
.216 0 0 r
.53991 .57343 m .53841 .57596 L .53526 .57594 L F
.53841 .57596 m .53751 .5762 L .53526 .57594 L F
.996 .84 .492 r
.53481 .57181 m .53433 .57475 L .53526 .57594 L F
.809 .424 0 r
.53433 .57475 m .5358 .57774 L .53526 .57594 L F
.233 .039 .4 r
.53526 .57594 m .53833 .57259 L .53481 .57181 L F
.216 0 0 r
.53841 .57596 m .53822 .57628 L .53751 .5762 L F
.233 .039 .4 r
.53526 .57594 m .53822 .57628 L .53833 .57259 L F
.299 .515 .897 r
.53433 .57475 m .53668 .57642 L .53533 .57678 L F
.53668 .57642 m .53829 .57756 L .53533 .57678 L F
.725 .252 .123 r
.53848 .56988 m .53991 .57343 L .53931 .57062 L F
.53848 .56988 m .5418 .57162 L .53991 .57343 L F
.051 0 0 r
.5418 .57162 m .53822 .57628 L .53991 .57343 L F
.763 .845 .394 r
.58004 .5876 m .57916 .58945 L .57855 .59152 L F
.826 .999 .793 r
.57916 .58945 m .57792 .59118 L .57855 .59152 L F
.024 0 .016 r
.47052 .55863 m .47065 .55944 L .47246 .55736 L F
.805 .406 .297 r
.21373 .62858 m .20998 .62628 L .21271 .62663 L F
.263 .554 .929 r
.21415 .62698 m .21373 .62858 L .21271 .62663 L F
.21415 .62698 m .21628 .62923 L .21373 .62858 L F
.682 .397 .483 r
.5687 .50575 m .57129 .50605 L .57251 .50354 L F
.764 .494 .524 r
.57129 .50605 m .57481 .50626 L .57251 .50354 L F
.511 .262 .473 r
.47487 .62489 m .47716 .62457 L .47713 .62211 L F
.588 .321 .48 r
.47713 .62211 m .47981 .62416 L .48029 .62146 L F
.47713 .62211 m .47716 .62457 L .47981 .62416 L F
.959 .715 .525 r
.55298 .60595 m .55504 .60947 L .55629 .60649 L F
.846 .427 .237 r
.52927 .52502 m .5279 .52624 L .52713 .52445 L F
.068 0 0 r
.52927 .52502 m .53004 .52539 L .5279 .52624 L F
.52927 .52502 m .5322 .5247 L .53004 .52539 L F
.799 .999 .815 r
.21604 .71841 m .21528 .72015 L .2177 .71928 L F
.21604 .71841 m .21346 .72085 L .21528 .72015 L F
.718 .798 .914 r
.21963 .70059 m .22375 .7004 L .2216 .70129 L F
.438 .587 .903 r
.16825 .62376 m .16897 .6254 L .16998 .6234 L F
.421 .566 .893 r
.16897 .6254 m .17238 .62699 L .16998 .6234 L F
.435 .569 .889 r
.16897 .6254 m .17276 .62817 L .17238 .62699 L F
.871 .457 .232 r
.66442 .42248 m .66481 .42425 L .66335 .42299 L F
.519 .104 .193 r
.66335 .42299 m .66228 .42165 L .66442 .42248 L F
.782 .387 .306 r
.66807 .42451 m .66481 .42425 L .66442 .42248 L F
.049 0 .3 r
.66335 .42299 m .66622 .41889 L .66497 .42314 L F
.511 .634 .907 r
.66335 .42299 m .66497 .42314 L .66376 .42239 L F
.275 0 .033 r
.66228 .42165 m .66135 .42282 L .66002 .42305 L F
.519 .104 .193 r
.66335 .42299 m .66085 .42345 L .66228 .42165 L F
.511 .634 .907 r
.66284 .42256 m .66376 .42239 L .65963 .41985 L F
.66335 .42299 m .66376 .42239 L .66284 .42256 L F
.275 0 .033 r
.66002 .42305 m .66085 .42345 L .65832 .42411 L F
.66135 .42282 m .66085 .42345 L .66002 .42305 L F
.828 .375 0 r
.45626 .62989 m .45575 .63021 L .45441 .6274 L F
.497 .331 .587 r
.45626 .62989 m .45495 .63379 L .45622 .63342 L F
.45626 .62989 m .45622 .63342 L .45575 .63021 L F
.77 .389 .335 r
.49482 .54193 m .49641 .5426 L .49468 .54 L F
.982 .708 .423 r
.76752 .41806 m .76737 .42083 L .76894 .42141 L F
.986 .726 .447 r
.76737 .42083 m .76882 .42409 L .76894 .42141 L F
.405 .342 .673 r
.76894 .42141 m .77037 .41774 L .76752 .41806 L F
.76894 .42141 m .77138 .42101 L .77037 .41774 L F
.397 .305 .633 r
.76894 .42141 m .77135 .42444 L .77138 .42101 L F
.519 .06 .103 r
.43815 .58565 m .43328 .58668 L .43499 .58524 L F
.43815 .58565 m .43728 .58753 L .43328 .58668 L F
0 0 0 r
.43886 .58596 m .43815 .58565 L .44061 .58551 L F
.43886 .58596 m .43728 .58753 L .43815 .58565 L F
.679 .677 .841 r
.66175 .42683 m .65859 .42432 L .66097 .42393 L F
.664 .713 .885 r
.66481 .42425 m .66175 .42683 L .66139 .42549 L F
.66282 .42385 m .66139 .42549 L .66085 .42345 L F
.66481 .42425 m .66139 .42549 L .66282 .42385 L F
.66481 .42425 m .66085 .42345 L .66335 .42299 L F
.049 0 .3 r
.66434 .42157 m .66436 .42158 L .66622 .41889 L F
.582 .537 .77 r
.66205 .41672 m .6643 .42166 L .66622 .41889 L F
.6643 .42166 m .66497 .42314 L .66622 .41889 L F
.049 0 .3 r
.66436 .42158 m .66523 .42199 L .66622 .41889 L F
.66335 .42299 m .66382 .42274 L .66434 .42157 L F
.733 .609 .72 r
.66393 .42249 m .66394 .4225 L .66393 .42248 L F
.66394 .4225 m .66497 .42314 L .66434 .42176 L F
.049 0 .3 r
.66382 .42274 m .66523 .42199 L .66434 .42157 L F
.733 .609 .72 r
.65963 .41985 m .66393 .42249 L .66205 .41672 L F
.66393 .42249 m .66393 .42248 L .66205 .41672 L F
.66394 .4225 m .66434 .42176 L .66205 .41672 L F
.582 .426 .636 r
.66326 .42562 m .66523 .42199 L .66382 .42274 L F
.66375 .42285 m .66382 .42274 L .66377 .42276 L F
.66326 .42562 m .66382 .42274 L .66375 .42285 L F
.66334 .42326 m .66377 .42276 L .66335 .42299 L F
.66326 .42562 m .66377 .42276 L .66334 .42326 L F
.466 .13 .311 r
.66025 .42591 m .66326 .42562 L .66333 .42355 L F
.66264 .42366 m .66333 .42355 L .66335 .42299 L F
.66025 .42591 m .66333 .42355 L .66264 .42366 L F
.679 .677 .841 r
.66097 .42393 m .65832 .42411 L .66085 .42345 L F
.65859 .42432 m .65832 .42411 L .66097 .42393 L F
.947 .953 .653 r
.57834 .53284 m .57864 .53401 L .57789 .53327 L F
.57834 .53284 m .5771 .53355 L .57864 .53401 L F
.937 .868 .745 r
.57448 .53576 m .57864 .53401 L .5771 .53355 L F
.57448 .53576 m .5755 .53901 L .57864 .53401 L F
.748 .257 0 r
.51449 .54589 m .51626 .54854 L .51632 .54789 L F
.692 .155 0 r
.51626 .54854 m .51827 .54961 L .51632 .54789 L F
.424 .567 .892 r
.17238 .62699 m .17276 .62817 L .17405 .62664 L F
.341 .442 .819 r
.17276 .62817 m .1756 .62997 L .17405 .62664 L F
.753 .628 .722 r
.46498 .63669 m .46428 .64028 L .46193 .63937 L F
.674 .558 .715 r
.46608 .64263 m .46193 .63937 L .46428 .64028 L F
.533 .402 .649 r
.46709 .63633 m .46428 .64028 L .46498 .63669 L F
.543 .365 .59 r
.47084 .63893 m .47105 .64156 L .46825 .64192 L F
.47084 .63893 m .46825 .64192 L .46968 .6411 L F
.533 .402 .649 r
.46709 .63633 m .46968 .6411 L .46428 .64028 L F
.479 .438 .734 r
.46825 .64192 m .46428 .64028 L .46968 .6411 L F
.46825 .64192 m .46608 .64263 L .46428 .64028 L F
.864 .957 .866 r
.469 .56408 m .46884 .56689 L .47182 .56501 L F
.469 .56408 m .46759 .56632 L .46884 .56689 L F
.583 .031 0 r
.16878 .71256 m .16948 .71267 L .16919 .7125 L F
.221 .021 .383 r
.26899 .59136 m .27076 .59238 L .2707 .59034 L F
.26899 .59136 m .26854 .59415 L .27076 .59238 L F
.652 .456 .606 r
.46676 .56338 m .47065 .55944 L .46838 .55964 L F
.02 0 0 r
.23162 .55041 m .22965 .55057 L .22748 .55062 L F
.147 .683 .846 r
.23413 .55075 m .22965 .55057 L .23162 .55041 L F
.463 .211 .445 r
.4338 .64225 m .43707 .63967 L .43555 .64152 L F
.674 .471 .602 r
.77655 .39974 m .77985 .40037 L .77962 .39746 L F
.58 .316 .481 r
.53643 .51527 m .53905 .51502 L .53926 .51279 L F
.415 .178 .444 r
.53926 .51279 m .53905 .51502 L .54156 .51212 L F
.845 .699 .701 r
.78342 .38669 m .77963 .38749 L .78218 .38687 L F
.78342 .38669 m .781 .39042 L .77963 .38749 L F
.318 .505 .883 r
.78372 .38423 m .78342 .38669 L .78218 .38687 L F
.78372 .38423 m .78696 .38736 L .78342 .38669 L F
.78696 .38736 m .78703 .38753 L .78342 .38669 L F
.008 .501 .868 r
.78837 .38862 m .78342 .38669 L .78703 .38753 L F
.78777 .3881 m .78703 .38753 L .78717 .38757 L F
.78837 .38862 m .78703 .38753 L .78777 .3881 L F
.91 .84 .763 r
.78646 .3871 m .7862 .3894 L .78706 .38761 L F
.78556 .38633 m .78558 .38644 L .78646 .3871 L F
.78558 .38644 m .7862 .3894 L .78646 .3871 L F
.78696 .38736 m .78706 .38761 L .78721 .38729 L F
.849 .561 .5 r
.78721 .38729 m .78717 .38757 L .78696 .38736 L F
.78721 .38729 m .78696 .38736 L .78372 .38423 L F
.91 .84 .763 r
.78685 .38708 m .78696 .38736 L .78721 .38729 L F
.78556 .38633 m .78706 .38761 L .78685 .38708 L F
.318 .505 .883 r
.78696 .38736 m .78717 .38757 L .78703 .38753 L F
.567 .6 .845 r
.74529 .40211 m .74608 .40431 L .74803 .40157 L F
.588 .628 .859 r
.74608 .40431 m .74868 .40375 L .74803 .40157 L F
.604 .368 .532 r
.43044 .58234 m .4337 .58219 L .43379 .58032 L F
.529 .335 .562 r
.4337 .58219 m .43547 .57957 L .43379 .58032 L F
.47 .377 .669 r
.31263 .56328 m .31096 .56761 L .31045 .5639 L F
.696 .646 .796 r
.18415 .638 m .18806 .64 L .18564 .63724 L F
.611 .753 .946 r
.18806 .64 m .18841 .6379 L .18564 .63724 L F
.18806 .64 m .19321 .63962 L .18841 .6379 L F
.407 .324 .65 r
.20528 .71882 m .20776 .7207 L .20804 .71929 L F
.633 .661 .86 r
.83335 .41491 m .83472 .41056 L .83236 .41142 L F
.83335 .41491 m .83636 .41265 L .83472 .41056 L F
.506 .113 .229 r
.55252 .5056 m .55631 .50334 L .55286 .50417 L F
.55252 .5056 m .55508 .50553 L .55631 .50334 L F
.665 .285 .315 r
.55631 .50334 m .55508 .50553 L .55878 .50546 L F
.4 .134 .391 r
.42251 .61456 m .42495 .61466 L .42539 .61194 L F
.576 .485 .714 r
.46939 .61533 m .46652 .61244 L .46823 .61132 L F
.46939 .61533 m .46701 .61581 L .46652 .61244 L F
.805 .604 .63 r
.46701 .61581 m .46736 .61869 L .46337 .61783 L F
.482 .371 .651 r
.46962 .61792 m .46701 .61581 L .46939 .61533 L F
.46962 .61792 m .46736 .61869 L .46701 .61581 L F
.359 .738 .988 r
.8026 .4048 m .80367 .40579 L .80606 .4057 L F
.858 .876 .851 r
.7583 .41686 m .76121 .41591 L .76019 .41449 L F
.544 .812 .996 r
.76121 .41591 m .76296 .41412 L .76019 .41449 L F
.76121 .41591 m .76391 .41534 L .76296 .41412 L F
0 0 0 r
.76121 .41591 m .76296 .41412 L .76391 .41534 L F
.76121 .41591 m .7605 .41684 L .76296 .41412 L F
.249 .76 .764 r
.21049 .55471 m .2088 .55501 L .20671 .55558 L F
.101 0 0 r
.21276 .55427 m .2088 .55501 L .21049 .55471 L F
.373 .489 .848 r
.44005 .64475 m .44161 .64851 L .43898 .64713 L F
.587 .599 .832 r
.6558 .42476 m .65707 .4207 L .65444 .42104 L F
.6558 .42476 m .65832 .42411 L .65707 .4207 L F
.487 .335 .6 r
.65595 .42755 m .65832 .42411 L .6558 .42476 L F
.653 .652 .837 r
.19965 .74416 m .20246 .74709 L .20419 .74577 L F
.712 .559 .679 r
.81969 .42446 m .81716 .42498 L .81734 .42756 L F
.728 .581 .691 r
.81734 .42756 m .82108 .42829 L .81969 .42446 L F
0 0 0 r
.20276 .53922 m .20634 .53814 L .20386 .53881 L F
.681 .921 .972 r
.24797 .55011 m .24765 .55195 L .24963 .55128 L F
.496 .84 .997 r
.25375 .55051 m .24797 .55011 L .24963 .55128 L F
.591 .26 .378 r
.45013 .5695 m .45274 .56947 L .45315 .56764 L F
.377 .071 .314 r
.45315 .56764 m .45274 .56947 L .45507 .56884 L F
.285 .72 .966 r
.43632 .65955 m .43578 .66053 L .43412 .65938 L F
.43632 .65955 m .43795 .66044 L .43578 .66053 L F
0 .138 .663 r
.43803 .6633 m .43578 .66053 L .43795 .66044 L F
.697 .439 .53 r
.83963 .41511 m .84215 .41112 L .8402 .41318 L F
.633 .39 .533 r
.84087 .41698 m .84322 .41557 L .83963 .41511 L F
.613 .88 .99 r
.21489 .555 m .21753 .55581 L .21924 .55474 L F
.276 0 0 r
.43822 .57489 m .44083 .57503 L .44201 .5737 L F
.337 0 0 r
.44201 .5737 m .44083 .57503 L .44381 .57452 L F
.306 0 .11 r
.44201 .5737 m .44381 .57452 L .44438 .57304 L F
.354 .182 .505 r
.26744 .59755 m .26906 .59943 L .26871 .59675 L F
.26744 .59755 m .26721 .60019 L .26906 .59943 L F
.799 .978 .902 r
.21607 .71523 m .21559 .71635 L .21192 .7172 L F
.896 .516 .065 r
.51126 .58864 m .50946 .58543 L .51047 .58732 L F
.963 .63 .289 r
.51047 .58732 m .51215 .59039 L .51126 .58864 L F
0 .312 .673 r
.79825 .40285 m .7996 .40349 L .8026 .4048 L F
.887 .46 .095 r
.50604 .59486 m .50532 .59569 L .50535 .59354 L F
.50604 .59486 m .50748 .59736 L .50532 .59569 L F
.643 .087 0 r
.49571 .56705 m .49865 .56896 L .49702 .56831 L F
.524 .389 .639 r
.30734 .59382 m .30739 .59726 L .30508 .59774 L F
.563 .442 .673 r
.30739 .59726 m .30534 .60029 L .30508 .59774 L F
.654 .838 .971 r
.55298 .60595 m .55629 .60649 L .55507 .60528 L F
.741 .866 .938 r
.55507 .60528 m .55629 .60649 L .55874 .60494 L F
0 .521 .787 r
.24765 .55195 m .24623 .55148 L .2439 .55106 L F
.732 .958 .944 r
.24797 .55011 m .24623 .55148 L .24765 .55195 L F
.377 .624 .949 r
.21048 .62457 m .20998 .62628 L .2084 .62461 L F
.21048 .62457 m .21271 .62663 L .20998 .62628 L F
0 .331 .783 r
.80872 .44616 m .81064 .44667 L .80776 .44578 L F
.141 .551 .924 r
.80872 .44616 m .8126 .44789 L .81165 .44776 L F
0 .331 .783 r
.80872 .44616 m .81165 .44776 L .81064 .44667 L F
.647 .585 .771 r
.43007 .64937 m .43323 .64972 L .43129 .6479 L F
.59 .384 .569 r
.2408 .67937 m .24068 .68203 L .23814 .68223 L F
.532 .39 .634 r
.24287 .67618 m .24314 .67894 L .2408 .67937 L F
.384 .215 .526 r
.24251 .68137 m .2408 .67937 L .24314 .67894 L F
.24251 .68137 m .24068 .68203 L .2408 .67937 L F
.285 .733 .96 r
.23732 .53661 m .23954 .53651 L .24131 .53726 L F
.462 .81 .998 r
.23954 .53651 m .24347 .53696 L .24131 .53726 L F
.694 .676 .828 r
.22142 .55165 m .22123 .55425 L .22548 .55084 L F
.667 .36 .444 r
.75603 .37863 m .75595 .37616 L .75192 .37645 L F
.69 .378 .443 r
.75603 .37863 m .75734 .37807 L .75595 .37616 L F
.473 .759 .993 r
.81408 .43178 m .81246 .43329 L .81146 .43225 L F
.81408 .43178 m .81504 .433 L .81246 .43329 L F
.564 .604 .852 r
.49939 .60402 m .50288 .60604 L .50171 .60317 L F
.805 .574 .589 r
.57481 .50626 m .57646 .50947 L .57852 .50848 L F
.858 .716 .705 r
.57646 .50947 m .57622 .51211 L .57852 .50848 L F
0 0 0 r
.20276 .53922 m .20489 .53884 L .20634 .53814 L F
.20634 .53814 m .20681 .53818 L .2086 .53791 L F
.20634 .53814 m .20489 .53884 L .20681 .53818 L F
.42 .362 .687 r
.41149 .63696 m .41411 .63874 L .4132 .63511 L F
.341 0 0 r
.20914 .72176 m .21179 .72239 L .20997 .72313 L F
.648 .407 .54 r
.45556 .57662 m .45159 .57863 L .45175 .57642 L F
.468 .243 .489 r
.2155 .70611 m .21256 .70954 L .21483 .70947 L F
.069 0 0 r
.76325 .3823 m .76043 .38432 L .76189 .38412 L F
.724 .336 .314 r
.76404 .38418 m .76325 .3823 L .76189 .38412 L F
.59 .296 .438 r
.5528 .51561 m .55524 .51741 L .55232 .51712 L F
.647 .246 .27 r
.5528 .51561 m .55524 .51603 L .55524 .51741 L F
.31 .485 .87 r
.41994 .67775 m .42062 .67993 L .42178 .67813 L F
.525 .646 .911 r
.66089 .43381 m .6621 .43162 L .65954 .43215 L F
.66089 .43381 m .66355 .4332 L .6621 .43162 L F
.249 .037 .383 r
.45589 .61724 m .45786 .61695 L .45785 .61686 L F
0 0 0 r
.45374 .61767 m .45589 .61724 L .45735 .61621 L F
.797 .961 .641 r
.45735 .61621 m .45812 .61404 L .4596 .61559 L F
.45735 .61621 m .45589 .61724 L .45812 .61404 L F
.249 .037 .383 r
.45589 .61724 m .45785 .61686 L .45775 .61478 L F
0 0 0 r
.45344 .61779 m .45589 .61724 L .45374 .61767 L F
.72 .943 .955 r
.75593 .38002 m .75951 .37923 L .75734 .37807 L F
.394 .433 .783 r
.74958 .37628 m .75226 .37826 L .75192 .37645 L F
.792 .459 .425 r
.51677 .61266 m .51332 .61249 L .5136 .61079 L F
.82 .732 .767 r
.51677 .61266 m .51504 .61546 L .51332 .61249 L F
.906 .529 .086 r
.51656 .61433 m .51677 .61266 L .5161 .61134 L F
.51656 .61433 m .51766 .61539 L .51677 .61266 L F
.283 .383 .788 r
.76498 .39077 m .76593 .39434 L .7675 .39241 L F
0 0 .54 r
.76571 .39277 m .76593 .39434 L .76498 .39077 L F
.602 .422 .611 r
.76365 .39655 m .76571 .39277 L .7628 .39513 L F
.76365 .39655 m .76593 .39434 L .76571 .39277 L F
.76365 .39655 m .76565 .39642 L .76593 .39434 L F
.428 .247 .532 r
.23453 .67958 m .23498 .68201 L .23304 .68217 L F
.425 .237 .519 r
.23498 .68201 m .23414 .68459 L .23304 .68217 L F
0 0 .374 r
.23304 .68217 m .23414 .68459 L .23372 .68393 L F
.659 .341 .423 r
.22451 .7056 m .22381 .70635 L .22117 .70627 L F
.54 .189 .322 r
.22731 .70561 m .22381 .70635 L .22451 .7056 L F
0 0 0 r
.43195 .5846 m .4337 .58219 L .43044 .58234 L F
.811 .825 .349 r
.58172 .57914 m .5809 .58085 L .58072 .58248 L F
0 0 0 r
.58072 .58248 m .5807 .58337 L .58053 .58504 L F
.58072 .58248 m .5809 .58085 L .5807 .58337 L F
.856 .93 .547 r
.51818 .61875 m .51679 .62036 L .51704 .62076 L F
.994 .764 .473 r
.51695 .61774 m .51679 .62036 L .51818 .61875 L F
.278 .339 .746 r
.53163 .56659 m .53379 .56563 L .53081 .56053 L F
0 .064 .598 r
.53233 .56668 m .53241 .56699 L .53163 .56659 L F
.201 0 .166 r
.53163 .56659 m .53241 .56699 L .53102 .569 L F
.923 .771 .674 r
.53102 .569 m .53241 .56699 L .53219 .56696 L F
.005 0 .098 r
.53102 .569 m .53146 .56846 L .53148 .56819 L F
.53102 .569 m .53148 .56819 L .53163 .56659 L F
.53146 .56846 m .53233 .56668 L .53163 .56659 L F
.201 0 .166 r
.53163 .56659 m .53102 .569 L .53063 .56811 L F
.005 0 .098 r
.53102 .569 m .53163 .56659 L .53063 .56811 L F
.923 .771 .674 r
.53102 .569 m .53219 .56696 L .52868 .56643 L F
.005 0 .098 r
.53287 .56675 m .53379 .56563 L .53163 .56659 L F
0 .064 .598 r
.53081 .56053 m .53233 .56668 L .53163 .56659 L F
.927 .713 .594 r
.5296 .56386 m .52962 .56387 L .53081 .56053 L F
.52962 .56387 m .53162 .56429 L .53083 .56062 L F
.52962 .56387 m .53083 .56062 L .53081 .56053 L F
.52868 .56643 m .53162 .56429 L .5296 .56386 L F
.914 .695 .592 r
.52962 .56387 m .52868 .56643 L .5302 .56358 L F
.52732 .56503 m .52868 .56643 L .52962 .56387 L F
.52962 .56387 m .5302 .56358 L .5296 .56386 L F
.927 .713 .594 r
.52868 .56643 m .5296 .56386 L .5302 .56358 L F
.5296 .56386 m .53081 .56053 L .5302 .56358 L F
.914 .695 .592 r
.5296 .56386 m .5302 .56358 L .52778 .56348 L F
.52778 .56348 m .5302 .56358 L .5283 .56175 L F
.52732 .56503 m .52962 .56387 L .52778 .56348 L F
.927 .713 .594 r
.52868 .56643 m .53219 .56696 L .53162 .56429 L F
.53219 .56696 m .53241 .56699 L .53233 .56668 L F
.53219 .56696 m .53233 .56668 L .53081 .56053 L F
.005 0 .098 r
.53146 .56846 m .53287 .56675 L .53233 .56668 L F
.593 .62 .848 r
.25379 .55456 m .25477 .55693 L .25771 .55594 L F
.955 .787 .634 r
.40718 .60863 m .40774 .61177 L .40896 .60965 L F
.47 .377 .669 r
.31263 .56328 m .31302 .56738 L .31096 .56761 L F
.478 .447 .745 r
.31302 .56738 m .31376 .56935 L .31096 .56761 L F
.481 .446 .742 r
.31096 .56761 m .31376 .56935 L .31181 .57005 L F
.016 0 0 r
.14757 .57047 m .14762 .57133 L .14952 .56966 L F
.14757 .57047 m .14558 .572 L .14762 .57133 L F
.357 .098 .378 r
.42539 .61194 m .42495 .61466 L .42717 .6119 L F
.934 .556 .209 r
.50634 .58065 m .50691 .57878 L .50544 .57796 L F
.50634 .58065 m .50773 .58148 L .50691 .57878 L F
0 .341 .725 r
.79269 .39165 m .79103 .39111 L .78992 .39004 L F
.79269 .39165 m .79389 .39237 L .79103 .39111 L F
0 .212 .732 r
.18856 .78202 m .18748 .78243 L .18943 .78481 L F
.885 .915 .841 r
.83893 .42973 m .83796 .43163 L .83757 .431 L F
.606 .765 .956 r
.83337 .40218 m .83434 .40375 L .83074 .40291 L F
.607 .756 .95 r
.83601 .4014 m .83434 .40375 L .83337 .40218 L F
.83601 .4014 m .83699 .40299 L .83434 .40375 L F
.782 .343 .208 r
.67552 .4182 m .67943 .42075 L .67927 .4189 L F
.807 .449 .378 r
.67927 .4189 m .67943 .42075 L .68291 .42139 L F
.268 .5 .894 r
.41016 .63092 m .41319 .63249 L .41107 .62941 L F
.685 .651 .81 r
.22765 .64409 m .2322 .64645 L .23324 .64457 L F
.322 0 .161 r
.16923 .55462 m .1713 .5541 L .17242 .5527 L F
0 0 0 r
.17242 .5527 m .1713 .5541 L .17417 .55154 L F
.682 .788 .93 r
.28214 .5388 m .27982 .54 L .27813 .53832 L F
.726 .394 .417 r
.5136 .61079 m .51332 .61249 L .50922 .61187 L F
.518 .163 .305 r
.24708 .62118 m .24401 .62215 L .24321 .62385 L F
.569 .592 .836 r
.487 .62164 m .48314 .61842 L .48632 .61908 L F
.648 .908 .981 r
.48813 .61717 m .48632 .61908 L .48862 .61794 L F
.376 .354 .707 r
.48928 .62018 m .48632 .61908 L .48813 .61717 L F
.48928 .62018 m .487 .62164 L .48632 .61908 L F
.756 .437 .446 r
.51504 .61546 m .51312 .61783 L .51029 .61746 L F
.658 .31 .371 r
.51695 .61774 m .51312 .61783 L .51504 .61546 L F
.879 .64 .573 r
.68281 .4239 m .68451 .42478 L .68291 .42139 L F
.862 .668 .639 r
.68117 .42683 m .68451 .42478 L .68281 .4239 L F
.68117 .42683 m .68432 .42728 L .68451 .42478 L F
.68 .815 .948 r
.84057 .40337 m .83699 .40299 L .83965 .40218 L F
.461 .782 .998 r
.84207 .40193 m .84057 .40337 L .83965 .40218 L F
.84207 .40193 m .84318 .40306 L .84057 .40337 L F
.51 .387 .649 r
.31376 .56935 m .3118 .57249 L .31181 .57005 L F
.602 .068 0 r
.50358 .55199 m .50271 .553 L .4998 .55133 L F
.908 .501 .182 r
.50358 .55199 m .50424 .55397 L .50271 .553 L F
.591 .325 .482 r
.47193 .60916 m .47122 .61158 L .46823 .61132 L F
.516 .253 .454 r
.47397 .61104 m .47193 .60916 L .4745 .60931 L F
.47397 .61104 m .47122 .61158 L .47193 .60916 L F
.56 .633 .88 r
.23916 .65806 m .24297 .66012 L .24097 .65712 L F
.544 .64 .896 r
.24097 .65712 m .24297 .66012 L .24437 .65895 L F
.402 .219 .515 r
.43862 .61549 m .44076 .61542 L .44092 .6124 L F
.413 .441 .78 r
.43862 .61549 m .44085 .61682 L .44076 .61542 L F
.567 .6 .846 r
.20092 .6204 m .20028 .62384 L .19896 .62096 L F
.20092 .6204 m .20244 .62344 L .20028 .62384 L F
.339 .148 .468 r
.65662 .41553 m .65501 .41876 L .6567 .41794 L F
.389 .114 .372 r
.65662 .41553 m .65927 .41552 L .65946 .41296 L F
.55 .406 .638 r
.6567 .41794 m .65927 .41552 L .65662 .41553 L F
.501 .816 1 r
.19321 .63962 m .19429 .63993 L .19271 .63883 L F
.413 .726 .989 r
.18841 .6379 m .19321 .63962 L .19271 .63883 L F
.251 .523 .913 r
.1942 .64189 m .19271 .63883 L .19429 .63993 L F
.786 .699 .768 r
.17448 .60051 m .16825 .59996 L .17042 .59957 L F
.17448 .60051 m .17008 .60331 L .16825 .59996 L F
0 0 .259 r
.17348 .60151 m .17318 .60134 L .17448 .60051 L F
.922 .536 .146 r
.17235 .5994 m .17448 .60051 L .17132 .59978 L F
.17235 .5994 m .17132 .59978 L .17042 .59957 L F
.101 .138 .614 r
.17342 .59678 m .17363 .59892 L .17235 .5994 L F
0 0 0 r
.17433 .60221 m .17098 .604 L .17448 .60051 L F
.922 .536 .146 r
.17235 .5994 m .17433 .60221 L .17448 .60051 L F
.101 .138 .614 r
.17363 .59892 m .17381 .60073 L .17235 .5994 L F
0 .08 .627 r
.17235 .5994 m .17381 .60073 L .17423 .60193 L F
.17407 .60184 m .17423 .60193 L .17433 .60221 L F
.17235 .5994 m .17423 .60193 L .17407 .60184 L F
0 0 .259 r
.17098 .604 m .17008 .60331 L .17318 .60134 L F
.17098 .604 m .17318 .60134 L .17348 .60151 L F
.276 0 .006 r
.18746 .56452 m .18619 .56586 L .18396 .56636 L F
0 0 0 r
.18903 .56339 m .18619 .56586 L .18746 .56452 L F
.312 0 .056 r
.45761 .64648 m .45577 .6482 L .45433 .64845 L F
.547 .156 .252 r
.45761 .64648 m .4599 .64795 L .45577 .6482 L F
.527 .179 .321 r
.46081 .64561 m .4599 .64795 L .45761 .64648 L F
.594 .611 .839 r
.73362 .39359 m .73499 .39724 L .73752 .39652 L F
.537 .745 .972 r
.25401 .55201 m .2548 .54993 L .25375 .55051 L F
.25401 .55201 m .256 .55135 L .2548 .54993 L F
.557 .351 .557 r
.25401 .55201 m .2565 .5539 L .256 .55135 L F
.25401 .55201 m .25379 .55456 L .2565 .5539 L F
.816 .775 .814 r
.20975 .72771 m .20782 .73078 L .20664 .72878 L F
.573 .295 .456 r
.20782 .73078 m .2097 .73252 L .20736 .73325 L F
.474 .324 .596 r
.20975 .72771 m .20898 .73157 L .20782 .73078 L F
.533 .3 .507 r
.20898 .73157 m .2097 .73252 L .20782 .73078 L F
0 .061 .615 r
.41818 .63923 m .41993 .64143 L .41929 .64289 L F
0 0 .243 r
.41985 .64406 m .41929 .64289 L .41993 .64143 L F
.41985 .64406 m .41983 .64558 L .41929 .64289 L F
0 0 0 r
.1565 .58941 m .15594 .59017 L .15628 .58685 L F
.1565 .58941 m .15496 .59168 L .15594 .59017 L F
.786 .868 .909 r
.7721 .39639 m .77649 .39495 L .77518 .39278 L F
.681 .843 .961 r
.77649 .39495 m .77737 .39287 L .77518 .39278 L F
.77649 .39495 m .7785 .39395 L .77737 .39287 L F
.238 0 0 r
.23056 .67957 m .2334 .67987 L .23453 .67958 L F
.301 .795 .863 r
.23467 .67918 m .23453 .67958 L .2334 .67987 L F
.23467 .67918 m .23681 .67908 L .23453 .67958 L F
.514 .304 .532 r
.23681 .67908 m .23498 .68201 L .23453 .67958 L F
.633 .39 .533 r
.84087 .41698 m .84378 .41764 L .84322 .41557 L F
.619 .75 .94 r
.82354 .40055 m .82705 .40209 L .82459 .40253 L F
.083 0 0 r
.24548 .64325 m .24762 .64349 L .24405 .64576 L F
.24548 .64325 m .2473 .64302 L .24762 .64349 L F
.73 .585 .694 r
.45843 .62111 m .45543 .62565 L .45573 .62155 L F
.883 .954 .847 r
.73967 .38714 m .74169 .3862 L .74178 .38451 L F
.555 .631 .881 r
.74169 .3862 m .74368 .38367 L .74178 .38451 L F
.74169 .3862 m .74534 .38649 L .74368 .38367 L F
.767 .337 .229 r
.50753 .55467 m .50578 .55488 L .50424 .55397 L F
.523 0 0 r
.5101 .55633 m .50578 .55488 L .50753 .55467 L F
.511 .891 .964 r
.22416 .62843 m .22645 .62879 L .22303 .62946 L F
.423 .85 .949 r
.22876 .62815 m .22645 .62879 L .22416 .62843 L F
.419 .597 .919 r
.16194 .62154 m .16323 .6203 L .16037 .62057 L F
.16194 .62154 m .16363 .62127 L .16323 .6203 L F
.518 .163 .305 r
.24708 .62118 m .24321 .62385 L .24544 .62305 L F
.564 .176 .265 r
.24544 .62305 m .24942 .62099 L .24708 .62118 L F
.876 .838 .805 r
.56285 .56672 m .56012 .56649 L .56237 .56368 L F
.885 .753 .711 r
.56285 .56672 m .55931 .56906 L .56012 .56649 L F
.56285 .56672 m .56126 .56992 L .55931 .56906 L F
.908 .854 .778 r
.5639 .56468 m .56285 .56672 L .56237 .56368 L F
.879 .535 .393 r
.67943 .42075 m .68281 .4239 L .68291 .42139 L F
.924 .802 .333 r
.76593 .39434 m .76565 .39642 L .76521 .39565 L F
.76593 .39434 m .76521 .39565 L .7675 .39241 L F
.723 .271 .178 r
.45201 .65313 m .4547 .65461 L .45257 .65235 L F
.434 .301 .599 r
.45297 .65414 m .4528 .65421 L .45201 .65313 L F
.4528 .65421 m .45121 .65432 L .45201 .65313 L F
.45073 .65503 m .45072 .6544 L .45201 .65313 L F
.723 .271 .178 r
.45151 .65382 m .45303 .6542 L .45201 .65313 L F
0 0 0 r
.45353 .65392 m .45294 .65461 L .45318 .65433 L F
.723 .271 .178 r
.45297 .65414 m .45327 .65422 L .45201 .65313 L F
.45327 .65422 m .4535 .65395 L .45201 .65313 L F
0 0 0 r
.45318 .65433 m .45069 .65721 L .45297 .65414 L F
.723 .271 .178 r
.45303 .6542 m .45303 .6542 L .45297 .65414 L F
.45303 .6542 m .4547 .65461 L .45297 .65414 L F
0 0 0 r
.45297 .65414 m .45069 .65721 L .44962 .65547 L F
.45353 .65392 m .45318 .65433 L .45297 .65414 L F
.434 .301 .599 r
.45353 .65392 m .45297 .65414 L .45201 .65313 L F
.45353 .65392 m .45201 .65313 L .45257 .65235 L F
.704 .166 0 r
.45257 .65235 m .4547 .65461 L .45353 .65392 L F
.46 .292 .566 r
.45398 .65365 m .45127 .65376 L .45303 .6542 L F
.723 .271 .178 r
.45327 .65422 m .4547 .65461 L .4535 .65395 L F
.7 .448 .539 r
.45402 .65422 m .45353 .65392 L .4547 .65461 L F
.46 .292 .566 r
.45433 .65411 m .45387 .65414 L .4547 .65461 L F
.825 .982 .882 r
.4547 .65461 m .4514 .65636 L .45164 .6561 L F
.7 .448 .539 r
.45414 .6545 m .4517 .65607 L .45336 .65412 L F
.45402 .65422 m .45336 .65412 L .45353 .65392 L F
.825 .982 .882 r
.4547 .65461 m .45164 .6561 L .45447 .65429 L F
.46 .292 .566 r
.45402 .65422 m .45303 .6542 L .4547 .65461 L F
.45361 .65416 m .45303 .6542 L .45402 .65422 L F
.7 .448 .539 r
.45565 .65524 m .45336 .65412 L .45402 .65422 L F
.46 .292 .566 r
.45387 .65414 m .45361 .65416 L .45402 .65422 L F
.45398 .65365 m .45303 .6542 L .45433 .65411 L F
.825 .982 .882 r
.45447 .65429 m .45164 .6561 L .45398 .65365 L F
.7 .448 .539 r
.45565 .65524 m .45142 .65646 L .45172 .65607 L F
.45565 .65524 m .4517 .65607 L .45414 .6545 L F
.843 .659 .653 r
.45056 .65981 m .44898 .65663 L .45069 .65721 L F
.688 .704 .859 r
.45132 .65651 m .45056 .65981 L .45069 .65721 L F
.546 .303 .498 r
.45116 .65679 m .45159 .65623 L .45151 .65629 L F
0 0 0 r
.45156 .65623 m .45132 .65651 L .45129 .65655 L F
.45318 .65433 m .45159 .6562 L .45069 .65721 L F
.546 .303 .498 r
.45132 .65652 m .45151 .65629 L .4514 .65636 L F
.688 .704 .859 r
.45134 .65653 m .45056 .65981 L .45132 .65651 L F
.546 .303 .498 r
.45116 .65679 m .45151 .65629 L .45132 .65652 L F
0 0 0 r
.45159 .6562 m .45135 .65648 L .45132 .65651 L F
.45159 .6562 m .45132 .65651 L .45156 .65623 L F
.688 .704 .859 r
.45135 .65648 m .45134 .65653 L .45132 .65651 L F
.607 .66 .877 r
.45558 .65981 m .45304 .6603 L .45136 .65651 L F
.45138 .6565 m .45136 .65651 L .45135 .65648 L F
.45558 .65981 m .45136 .65651 L .45138 .6565 L F
.546 .303 .498 r
.45147 .65644 m .45349 .65495 L .45159 .65623 L F
.45137 .6566 m .45268 .65558 L .45147 .65644 L F
.45268 .65558 m .45349 .65495 L .45147 .65644 L F
.688 .704 .859 r
.45134 .65653 m .45304 .6603 L .45056 .65981 L F
.45135 .65648 m .45136 .65651 L .45134 .65653 L F
.45136 .65651 m .45304 .6603 L .45134 .65653 L F
.607 .66 .877 r
.45558 .65981 m .45135 .65648 L .45565 .65524 L F
.546 .303 .498 r
.45012 .6587 m .45148 .65641 L .45116 .65679 L F
.45148 .65641 m .45159 .65623 L .4514 .65648 L F
.45148 .65641 m .4514 .65648 L .45116 .65679 L F
.45012 .6587 m .4516 .65705 L .45137 .6566 L F
.4516 .65705 m .45349 .65495 L .45137 .6566 L F
.165 0 .26 r
.45398 .65365 m .45164 .6561 L .45349 .65495 L F
.45164 .6561 m .4514 .65636 L .45159 .65623 L F
.7 .448 .539 r
.45172 .65607 m .45161 .65619 L .4517 .65607 L F
.45161 .65619 m .45162 .65616 L .4517 .65607 L F
.165 0 .26 r
.45164 .6561 m .45159 .65623 L .45349 .65495 L F
.7 .448 .539 r
.45161 .65619 m .45135 .65648 L .45162 .65616 L F
.45142 .65646 m .45135 .65648 L .45172 .65607 L F
.45565 .65524 m .45402 .65422 L .4547 .65461 L F
.434 .301 .599 r
.4528 .65421 m .45073 .65503 L .45121 .65432 L F
.46 .292 .566 r
.45378 .65366 m .4514 .65636 L .45127 .65376 L F
.45398 .65365 m .45189 .65585 L .45378 .65366 L F
0 0 0 r
.45294 .65461 m .45165 .65613 L .45318 .65433 L F
.45165 .65613 m .45135 .65648 L .45159 .6562 L F
.45165 .65613 m .45159 .6562 L .45318 .65433 L F
.46 .292 .566 r
.45127 .65376 m .4514 .65636 L .45189 .65585 L F
.45378 .65366 m .45189 .65585 L .45398 .65365 L F
.45127 .65376 m .45189 .65585 L .45378 .65366 L F
.45189 .65585 m .4514 .65636 L .45378 .65366 L F
0 0 .313 r
.45075 .65684 m .4514 .65636 L .45127 .65376 L F
.45069 .65721 m .45076 .65713 L .45075 .65684 L F
.45076 .65713 m .4514 .65636 L .45075 .65684 L F
.434 .301 .599 r
.45073 .65503 m .44962 .65547 L .45072 .6544 L F
0 0 .313 r
.45069 .65721 m .45127 .65376 L .44962 .65547 L F
.034 0 .378 r
.44898 .65663 m .44986 .65823 L .4514 .65636 L F
.44986 .65823 m .45012 .6587 L .45132 .65652 L F
0 0 0 r
.45154 .65625 m .45129 .65655 L .45069 .65721 L F
.034 0 .378 r
.44986 .65823 m .45132 .65652 L .4514 .65636 L F
0 0 0 r
.45159 .6562 m .45144 .65637 L .45154 .65625 L F
.45144 .65637 m .45129 .65655 L .45154 .65625 L F
.434 .301 .599 r
.45201 .65313 m .44962 .65547 L .45031 .65224 L F
.45201 .65313 m .45031 .65224 L .45257 .65235 L F
.723 .271 .178 r
.45127 .65376 m .45151 .65382 L .45257 .65235 L F
.005 0 .378 r
.45031 .65224 m .45127 .65376 L .45257 .65235 L F
.936 .68 .526 r
.58038 .56368 m .58172 .56671 L .582 .56413 L F
.867 .871 .839 r
.56642 .56177 m .5639 .56468 L .56237 .56368 L F
.704 .398 .455 r
.45492 .62926 m .44979 .62746 L .45441 .6274 L F
.531 .479 .744 r
.45543 .62565 m .45441 .6274 L .45316 .62732 L F
.45543 .62565 m .45687 .62732 L .45441 .6274 L F
.632 .315 .416 r
.45441 .6274 m .45575 .63021 L .45492 .62926 L F
.655 .431 .568 r
.16882 .7153 m .16948 .71267 L .16878 .71256 L F
.285 .12 .473 r
.16948 .71267 m .16923 .71529 L .16899 .71538 L F
.655 .431 .568 r
.16882 .7153 m .16923 .71529 L .16948 .71267 L F
.005 0 .378 r
.45031 .65224 m .44962 .65547 L .45127 .65376 L F
.782 .816 .88 r
.75866 .40596 m .75572 .4085 L .75536 .40555 L F
0 0 .372 r
.58136 .57563 m .58191 .57818 L .58172 .57914 L F
.775 .817 .34 r
.58191 .57818 m .5809 .58085 L .58172 .57914 L F
.501 .318 .565 r
.29046 .61862 m .29038 .62115 L .28812 .62166 L F
.488 .266 .503 r
.29038 .62115 m .28783 .62397 L .28812 .62166 L F
.204 0 .142 r
.84108 .42409 m .84396 .42131 L .8441 .42305 L F
.998 .848 .53 r
.84396 .42131 m .84378 .41764 L .84456 .42065 L F
0 0 .114 r
.8441 .42305 m .84396 .42131 L .84456 .42065 L F
.356 .158 .468 r
.26266 .60647 m .26475 .60571 L .26502 .60334 L F
.405 .195 .478 r
.26266 .60647 m .26467 .60825 L .26475 .60571 L F
.26266 .60647 m .2622 .60902 L .26467 .60825 L F
0 .448 .754 r
.80343 .39635 m .80692 .39745 L .80449 .39732 L F
.867 .871 .839 r
.56642 .56177 m .56237 .56368 L .56391 .56218 L F
.888 .9 .831 r
.56521 .56064 m .56642 .56177 L .56391 .56218 L F
.82 .659 .683 r
.56621 .52425 m .56794 .52779 L .56464 .5272 L F
.87 .661 .618 r
.56715 .53026 m .56464 .5272 L .56794 .52779 L F
.596 .59 .816 r
.75436 .41438 m .75527 .41786 L .7583 .41686 L F
.495 .199 .393 r
.65946 .41296 m .66271 .41463 L .66146 .41239 L F
.878 .442 .122 r
.7711 .38762 m .7732 .39107 L .77451 .39147 L F
.793 .324 0 r
.77394 .39171 m .77451 .39147 L .7732 .39107 L F
.744 .585 .679 r
.42876 .66118 m .42546 .65803 L .42784 .65779 L F
.42876 .66118 m .42601 .66138 L .42546 .65803 L F
.724 .477 .552 r
.42876 .66118 m .4251 .66335 L .42601 .66138 L F
.42876 .66118 m .42918 .66363 L .4251 .66335 L F
.773 .92 .935 r
.84861 .4094 m .84501 .41042 L .84568 .41249 L F
.84861 .4094 m .84771 .40808 L .84501 .41042 L F
.974 .731 .31 r
.84772 .4057 m .84771 .40808 L .84861 .4094 L F
.724 .461 .528 r
.44589 .61191 m .45135 .6106 L .44585 .6095 L F
.44589 .61191 m .45078 .61222 L .45135 .6106 L F
.106 0 .242 r
.45135 .6106 m .45078 .61222 L .45197 .61157 L F
.505 .24 .446 r
.47341 .60388 m .47671 .60168 L .47374 .60343 L F
.641 .953 .752 r
.18594 .76228 m .18342 .76442 L .18395 .76336 L F
.328 .719 .982 r
.18395 .76336 m .18342 .76442 L .18592 .76434 L F
0 0 0 r
.16923 .55462 m .16951 .55586 L .1713 .5541 L F
.16923 .55462 m .16768 .55685 L .16951 .55586 L F
.427 .682 .97 r
.17639 .63162 m .17704 .62998 L .1756 .62997 L F
.17639 .63162 m .17834 .63154 L .17704 .62998 L F
.417 .565 .895 r
.17639 .63162 m .17985 .63389 L .17834 .63154 L F
.771 .441 .427 r
.52276 .55121 m .52433 .55407 L .52597 .55195 L F
.891 .621 .521 r
.52597 .55195 m .52433 .55407 L .52629 .55453 L F
.381 .057 .286 r
.28002 .62805 m .27928 .62993 L .27707 .63045 L F
.4 .057 .264 r
.28221 .62771 m .27928 .62993 L .28002 .62805 L F
.585 .791 .977 r
.21551 .72659 m .21651 .72781 L .21174 .72649 L F
.008 0 .212 r
.21397 .73286 m .21328 .73284 L .21487 .7295 L F
.21397 .73286 m .21328 .73284 L .21487 .7295 L F
.722 .73 .21 r
.21433 .73138 m .21487 .7295 L .21397 .73286 L F
.793 .394 .298 r
.21174 .72649 m .21544 .72751 L .21487 .7295 L F
.21174 .72649 m .21487 .7295 L .21321 .73139 L F
.255 .741 .925 r
.21298 .72611 m .21551 .72659 L .21174 .72649 L F
.744 .341 0 r
.21426 .72874 m .21487 .7295 L .21298 .72611 L F
.557 .437 .672 r
.21174 .72649 m .21321 .73139 L .20898 .73157 L F
.53 .284 .486 r
.20898 .73157 m .21328 .73284 L .2097 .73252 L F
.20898 .73157 m .21321 .73139 L .21328 .73284 L F
.227 0 0 r
.2097 .73252 m .21328 .73284 L .2099 .73302 L F
.829 .684 .702 r
.2099 .73302 m .21487 .7295 L .21426 .72874 L F
.394 .184 .471 r
.21328 .73284 m .21321 .73139 L .21487 .7295 L F
.829 .684 .702 r
.2099 .73302 m .21328 .73284 L .21487 .7295 L F
0 .245 .754 r
.21298 .72611 m .21487 .7295 L .21522 .72778 L F
.722 .73 .21 r
.21522 .72778 m .21487 .7295 L .21433 .73138 L F
.793 .394 .298 r
.21544 .72751 m .21651 .72781 L .21487 .7295 L F
.425 .782 .996 r
.21631 .72601 m .21651 .72781 L .21551 .72659 L F
.551 .241 .397 r
.21651 .72781 m .21927 .72768 L .21822 .72977 L F
.763 .891 .935 r
.21926 .72647 m .21927 .72768 L .21631 .72601 L F
.425 .782 .996 r
.21893 .72749 m .21927 .72768 L .21886 .7277 L F
.936 .915 .535 r
.21822 .72977 m .21927 .72768 L .21926 .72647 L F
0 0 0 r
.21866 .72844 m .21822 .72977 L .21907 .72709 L F
.21914 .72688 m .21907 .72709 L .21926 .72647 L F
.21866 .72844 m .21907 .72709 L .21914 .72688 L F
.425 .782 .996 r
.21631 .72601 m .21893 .72749 L .21651 .72781 L F
.21893 .72749 m .21886 .7277 L .21651 .72781 L F
.675 .236 .2 r
.21487 .7295 m .21651 .72781 L .21822 .72977 L F
.731 .493 .568 r
.56091 .51544 m .55914 .51802 L .55893 .51548 L F
.757 .528 .586 r
.5613 .51819 m .55914 .51802 L .56091 .51544 L F
.783 .522 .542 r
.56091 .51544 m .56448 .51811 L .5613 .51819 L F
.508 .284 .509 r
.2931 .61559 m .2928 .61813 L .29046 .61862 L F
.524 .325 .553 r
.29555 .6126 m .29544 .61513 L .2931 .61559 L F
.472 .253 .5 r
.29513 .61752 m .2931 .61559 L .29544 .61513 L F
.29513 .61752 m .2928 .61813 L .2931 .61559 L F
.936 .571 .29 r
.51477 .60014 m .5157 .60308 L .51671 .6033 L F
.91 .56 .097 r
.5157 .60308 m .51711 .60622 L .51671 .6033 L F
.667 .36 .444 r
.75603 .37863 m .75192 .37645 L .75226 .37826 L F
.997 .857 .535 r
.58136 .57563 m .58198 .57348 L .58117 .57294 L F
0 0 .158 r
.77128 .40378 m .77097 .40339 L .77032 .40204 L F
.403 .192 .476 r
.29793 .60943 m .29759 .61205 L .29555 .6126 L F
.526 .371 .614 r
.29759 .61205 m .29544 .61513 L .29555 .6126 L F
.479 .203 .417 r
.487 .62164 m .48696 .62394 L .48482 .62405 L F
.586 .287 .429 r
.48943 .62367 m .487 .62164 L .48928 .62018 L F
.48943 .62367 m .48696 .62394 L .487 .62164 L F
.464 .678 .958 r
.81256 .40751 m .81346 .40919 L .81503 .40739 L F
.351 .505 .871 r
.81346 .40919 m .81578 .4096 L .81503 .40739 L F
.649 .572 .755 r
.77713 .40125 m .77985 .40037 L .77655 .39974 L F
.66 .464 .608 r
.74097 .38184 m .74351 .38157 L .74328 .37904 L F
.702 .315 .312 r
.7472 .381 m .74328 .37904 L .74351 .38157 L F
.466 .788 .999 r
.23966 .65667 m .23916 .65806 L .23736 .65697 L F
.23966 .65667 m .23916 .65806 L .23736 .65697 L F
.647 .883 .532 r
.24158 .65499 m .23916 .65806 L .24097 .65712 L F
.559 .879 .992 r
.23966 .65667 m .23916 .65806 L .24097 .65712 L F
.331 .356 .737 r
.1565 .58941 m .15696 .59248 L .15496 .59168 L F
.646 .951 .948 r
.23246 .62702 m .22876 .62815 L .23092 .62747 L F
0 0 0 r
.23092 .62747 m .23477 .62686 L .23246 .62702 L F
.248 .399 .818 r
.77351 .43337 m .77501 .43693 L .77635 .43522 L F
.274 .437 .843 r
.77501 .43693 m .77805 .43849 L .77635 .43522 L F
.351 0 0 r
.46838 .62702 m .47047 .62692 L .47259 .62596 L F
.366 0 0 r
.47259 .62596 m .47425 .62646 L .47487 .62489 L F
.47259 .62596 m .47047 .62692 L .47425 .62646 L F
.209 .328 .766 r
.47425 .62646 m .47259 .62596 L .47487 .62489 L F
.166 .704 .812 r
.54061 .51955 m .53909 .51942 L .53649 .5197 L F
.464 0 0 r
.54297 .51869 m .53909 .51942 L .54061 .51955 L F
.729 .412 .444 r
.45752 .63462 m .45622 .63342 L .45495 .63379 L F
.699 .538 .666 r
.45658 .63442 m .45752 .63462 L .45606 .63415 L F
.45113 .6333 m .45132 .63648 L .45657 .6349 L F
.45658 .63442 m .45657 .6349 L .45752 .63462 L F
.45113 .6333 m .45657 .6349 L .45658 .63442 L F
.729 .412 .444 r
.45662 .63379 m .45666 .63446 L .45622 .63342 L F
.45752 .63462 m .45666 .63446 L .45662 .63379 L F
.315 0 .071 r
.45098 .63847 m .45671 .6351 L .45132 .63648 L F
.45671 .6351 m .45752 .63462 L .45657 .6349 L F
.45671 .6351 m .45657 .6349 L .45132 .63648 L F
.45098 .63847 m .45341 .638 L .45689 .63513 L F
.45671 .6351 m .45689 .63513 L .45752 .63462 L F
.45098 .63847 m .45689 .63513 L .45671 .6351 L F
.729 .412 .444 r
.45752 .63462 m .45745 .63488 L .45666 .63446 L F
.727 .436 .486 r
.45341 .638 m .45721 .63579 L .45752 .63462 L F
.729 .412 .444 r
.45742 .63498 m .45721 .63579 L .45694 .63514 L F
.525 .468 .735 r
.45694 .63514 m .45756 .63494 L .45666 .63446 L F
.4572 .63577 m .45742 .63525 L .45694 .63514 L F
.45742 .63525 m .45756 .63494 L .45694 .63514 L F
.45721 .63579 m .45721 .63578 L .4572 .63577 L F
.45721 .63578 m .45756 .63494 L .4572 .63577 L F
.45666 .63446 m .45897 .63154 L .45659 .63316 L F
.45658 .63427 m .45659 .63316 L .45622 .63342 L F
.45666 .63446 m .45659 .63316 L .45658 .63427 L F
.45756 .63494 m .45897 .63154 L .45666 .63446 L F
.699 .538 .666 r
.45113 .6333 m .45658 .63442 L .45495 .63379 L F
.45658 .63442 m .45606 .63415 L .45495 .63379 L F
0 0 0 r
.76189 .38412 m .76043 .38432 L .76012 .38477 L F
.76189 .38412 m .76012 .38477 L .76283 .38572 L F
.024 .444 .871 r
.76163 .38497 m .76012 .38477 L .75853 .38306 L F
.76283 .38572 m .76012 .38477 L .76163 .38497 L F
.761 .905 .94 r
.76043 .38432 m .75922 .38465 L .76012 .38477 L F
.75922 .38465 m .75719 .3852 L .76012 .38477 L F
.458 .513 .827 r
.46135 .60294 m .4616 .60631 L .46131 .60343 L F
.926 .796 .698 r
.57833 .55933 m .58051 .56124 L .58084 .55816 L F
.898 .629 .522 r
.57717 .56259 m .58051 .56124 L .57833 .55933 L F
.57717 .56259 m .58038 .56368 L .58051 .56124 L F
.037 .605 .772 r
.8126 .44789 m .81522 .44796 L .81165 .44776 L F
.969 .772 .582 r
.76715 .41234 m .76642 .41439 L .76787 .41541 L F
.779 .279 .006 r
.76391 .41534 m .76752 .41806 L .76787 .41541 L F
.421 .656 .957 r
.76908 .41383 m .76787 .41541 L .76642 .41439 L F
.76908 .41383 m .77034 .41544 L .76787 .41541 L F
.76787 .41541 m .76908 .41383 L .76642 .41439 L F
.76787 .41541 m .77034 .41544 L .76908 .41383 L F
.651 .464 .618 r
.76787 .41541 m .77037 .41774 L .77034 .41544 L F
.76787 .41541 m .76752 .41806 L .77037 .41774 L F
.58 .003 0 r
.51467 .56118 m .51528 .56234 L .51377 .55981 L F
.51467 .56118 m .51722 .56296 L .51528 .56234 L F
.528 .379 .622 r
.65444 .42104 m .6567 .41794 L .65501 .41876 L F
.75 .925 .568 r
.19406 .78122 m .19369 .78244 L .19336 .78249 L F
.296 .702 .975 r
.28431 .53881 m .288 .53979 L .28594 .53991 L F
.815 .69 .727 r
.23814 .68223 m .23498 .68201 L .23681 .67908 L F
.663 .183 .101 r
.23678 .68397 m .23498 .68201 L .23814 .68223 L F
.71 .239 .131 r
.23814 .68223 m .23997 .68428 L .23678 .68397 L F
.555 .262 .425 r
.24068 .68203 m .23997 .68428 L .23814 .68223 L F
.888 .63 .541 r
.58119 .51854 m .57831 .51516 L .57985 .51831 L F
.797 .573 .597 r
.57757 .52068 m .58119 .51854 L .57985 .51831 L F
.57757 .52068 m .58103 .52166 L .58119 .51854 L F
.208 .728 .865 r
.54043 .60584 m .53649 .60582 L .53682 .60331 L F
.54043 .60584 m .53897 .60554 L .53649 .60582 L F
.575 .913 .971 r
.54043 .60584 m .54073 .60476 L .53897 .60554 L F
.54043 .60584 m .54326 .60408 L .54073 .60476 L F
.758 .514 .564 r
.55893 .51548 m .55524 .51741 L .55524 .51603 L F
.077 .637 .705 r
.22603 .64426 m .22687 .64417 L .22511 .6439 L F
.22603 .64426 m .22765 .64409 L .22687 .64417 L F
.447 .216 .469 r
.30048 .60646 m .30014 .60886 L .29793 .60943 L F
.526 .343 .576 r
.30284 .6034 m .30283 .606 L .30048 .60646 L F
.44 .209 .467 r
.30244 .6082 m .30048 .60646 L .30283 .606 L F
.30244 .6082 m .30014 .60886 L .30048 .60646 L F
.711 .983 .894 r
.5638 .60496 m .56291 .60671 L .5677 .60321 L F
.808 .656 .695 r
.75405 .40986 m .75017 .41162 L .75263 .40853 L F
.75405 .40986 m .7532 .41291 L .75017 .41162 L F
.436 .791 .997 r
.24347 .53696 m .24563 .53658 L .24736 .53754 L F
.43 .76 .996 r
.24768 .53603 m .24736 .53754 L .24563 .53658 L F
.24768 .53603 m .24975 .53731 L .24736 .53754 L F
.208 0 0 r
.81787 .44751 m .82142 .44629 L .82053 .44702 L F
.528 .848 .998 r
.82142 .44629 m .82345 .4446 L .82053 .44702 L F
.82142 .44629 m .82423 .44553 L .82345 .4446 L F
.52 0 0 r
.483 .56242 m .4783 .56037 L .4799 .56215 L F
.674 .558 .715 r
.46608 .64263 m .4637 .64285 L .46193 .63937 L F
.56 .598 .848 r
.43666 .65211 m .4374 .64787 L .43519 .64887 L F
.43666 .65211 m .43915 .65195 L .4374 .64787 L F
.529 .278 .479 r
.43642 .65401 m .43915 .65195 L .43666 .65211 L F
.43915 .65195 m .43642 .65401 L .43666 .65211 L F
.612 .432 .615 r
.4637 .64285 m .46342 .64524 L .46081 .64561 L F
.597 .249 .351 r
.46235 .64771 m .46081 .64561 L .46342 .64524 L F
.46235 .64771 m .4599 .64795 L .46081 .64561 L F
.818 .663 .691 r
.42546 .65803 m .42326 .6608 L .422 .65966 L F
.42546 .65803 m .422 .65966 L .4241 .65938 L F
.786 .614 .667 r
.42546 .65803 m .42601 .66138 L .42326 .6608 L F
.683 .32 .352 r
.4241 .65938 m .42784 .65779 L .42546 .65803 L F
.382 .762 .99 r
.19615 .64238 m .19786 .64331 L .20031 .64302 L F
0 0 .469 r
.4143 .64025 m .41521 .64248 L .41411 .63874 L F
.78 .644 .712 r
.56448 .51811 m .56253 .52151 L .5613 .51819 L F
.59 .37 .55 r
.45159 .57863 m .44901 .58109 L .4487 .57805 L F
.19 .441 .869 r
.2433 .65461 m .24279 .65559 L .24158 .65499 L F
.045 0 .209 r
.2433 .65461 m .24158 .65499 L .24097 .65712 L F
.488 .438 .728 r
.48752 .56707 m .48819 .57085 L .49058 .56886 L F
.563 .513 .758 r
.48888 .57301 m .49058 .56886 L .48819 .57085 L F
.702 .787 .917 r
.1876 .6148 m .18732 .61674 L .18322 .61442 L F
.17 .606 .938 r
.51955 .54854 m .51827 .54961 L .51626 .54854 L F
.51955 .54854 m .52126 .54998 L .51827 .54961 L F
.423 .57 .896 r
.81719 .41227 m .81876 .41026 L .81578 .4096 L F
.5 .684 .949 r
.81719 .41227 m .81996 .41184 L .81876 .41026 L F
.552 .784 .985 r
.21894 .64399 m .22031 .64528 L .22246 .64461 L F
0 0 .486 r
.43328 .58668 m .43195 .5846 L .43499 .58524 L F
.799 .672 .724 r
.51077 .5451 m .51449 .54589 L .51469 .54257 L F
.701 .216 .093 r
.51077 .5451 m .51332 .54719 L .51449 .54589 L F
.79 .334 .16 r
.51332 .54719 m .51626 .54854 L .51449 .54589 L F
.479 .277 .528 r
.19451 .75804 m .19209 .7611 L .19399 .76077 L F
.108 0 0 r
.47246 .55736 m .47451 .55742 L .47635 .55738 L F
.706 .236 .13 r
.47451 .55742 m .47836 .5583 L .47635 .55738 L F
.002 .579 .709 r
.23893 .64336 m .23882 .64335 L .23576 .64416 L F
.23893 .64336 m .24115 .64335 L .23882 .64335 L F
.345 .447 .822 r
.14656 .61055 m .14717 .60788 L .14611 .60938 L F
.14656 .61055 m .14862 .61138 L .14717 .60788 L F
.476 .367 .651 r
.44933 .63687 m .45132 .63648 L .45113 .6333 L F
0 .072 .624 r
.44933 .63687 m .45098 .63847 L .45132 .63648 L F
.674 .244 .217 r
.50746 .61815 m .50433 .61794 L .50569 .62077 L F
.405 .174 .448 r
.30014 .60886 m .29759 .61205 L .29793 .60943 L F
.706 .954 .952 r
.21244 .64489 m .21368 .64545 L .21622 .64397 L F
.128 .402 .852 r
.20866 .64532 m .21003 .64524 L .20745 .64422 L F
.20866 .64532 m .21054 .64631 L .21003 .64524 L F
.84 .821 .831 r
.56048 .57503 m .55972 .57897 L .55836 .57752 L F
.56048 .57503 m .56222 .57605 L .55972 .57897 L F
.211 .736 .815 r
.22303 .62946 m .22002 .62981 L .22206 .62935 L F
.511 .891 .964 r
.22416 .62843 m .22303 .62946 L .22206 .62935 L F
.261 0 .281 r
.25748 .61235 m .25929 .61172 L .25975 .60971 L F
.499 .206 .399 r
.25929 .61172 m .2622 .60902 L .25975 .60971 L F
0 0 0 r
.73513 .38931 m .73606 .38813 L .73415 .39012 L F
.552 .371 .589 r
.73606 .38813 m .73967 .38714 L .73851 .38504 L F
.238 0 0 r
.7375 .38882 m .73606 .38813 L .73513 .38931 L F
.7375 .38882 m .73967 .38714 L .73606 .38813 L F
.404 .122 .368 r
.46608 .64263 m .46342 .64524 L .4637 .64285 L F
.681 .546 .695 r
.48653 .57372 m .48644 .57608 L .48888 .57301 L F
.471 .561 .865 r
.77798 .42594 m .77754 .42999 L .77529 .42647 L F
.369 .462 .825 r
.78312 .43249 m .77981 .43078 L .78204 .42932 L F
.431 .436 .764 r
.78204 .42932 m .77981 .43078 L .78051 .43066 L F
.471 .561 .865 r
.77798 .42594 m .78051 .43066 L .77754 .42999 L F
.489 .567 .861 r
.77981 .43078 m .77754 .42999 L .78051 .43066 L F
.308 0 0 r
.26779 .55894 m .26583 .55873 L .26313 .55791 L F
.116 .626 .896 r
.26779 .55894 m .26806 .55827 L .26583 .55873 L F
.26779 .55894 m .2706 .55912 L .26806 .55827 L F
.505 .24 .446 r
.47341 .60388 m .47626 .60356 L .47671 .60168 L F
.341 0 .212 r
.47341 .60388 m .47545 .60462 L .47626 .60356 L F
.47341 .60388 m .47294 .60533 L .47545 .60462 L F
.886 .687 .628 r
.66681 .41451 m .66755 .41503 L .66935 .41541 L F
.839 .51 .431 r
.66755 .41503 m .66982 .41737 L .66935 .41541 L F
.501 .305 .546 r
.2928 .61813 m .29038 .62115 L .29046 .61862 L F
.333 0 0 r
.17825 .54981 m .18246 .54781 L .18032 .5484 L F
.287 0 0 r
.25958 .64154 m .26012 .64056 L .26405 .63933 L F
.704 .776 .908 r
.82092 .41358 m .8234 .41242 L .81996 .41184 L F
.504 0 0 r
.84279 .41855 m .84087 .41698 L .83995 .41918 L F
.84279 .41855 m .84378 .41764 L .84087 .41698 L F
0 .45 .844 r
.80011 .39533 m .79712 .39373 L .79995 .39527 L F
0 .385 .682 r
.79995 .39527 m .80343 .39635 L .80011 .39533 L F
.286 0 0 r
.54646 .51796 m .54538 .51863 L .54297 .51869 L F
.337 0 0 r
.54906 .51752 m .54538 .51863 L .54646 .51796 L F
.476 .17 .367 r
.48781 .61492 m .49013 .61303 L .48817 .61316 L F
.537 .277 .469 r
.28549 .62442 m .28481 .62736 L .28221 .62771 L F
.476 .221 .448 r
.28718 .62681 m .28549 .62442 L .28783 .62397 L F
.28718 .62681 m .28481 .62736 L .28549 .62442 L F
.927 .57 .329 r
.51362 .60189 m .51477 .60014 L .51416 .59906 L F
.51362 .60189 m .5157 .60308 L .51477 .60014 L F
.976 .712 .464 r
.49041 .57909 m .48878 .5806 L .48881 .57761 L F
.625 .961 .864 r
.49229 .57783 m .49164 .57755 L .49041 .57909 L F
.586 .872 .556 r
.49164 .57755 m .48878 .5806 L .49041 .57909 L F
.544 .852 .998 r
.58266 .52469 m .58511 .52399 L .58156 .5238 L F
.757 .841 .915 r
.8384 .41123 m .84215 .41112 L .84123 .40911 L F
.808 .735 .783 r
.8384 .41123 m .8402 .41318 L .84215 .41112 L F
.614 .724 .924 r
.84215 .41112 m .84382 .40791 L .84123 .40911 L F
.84215 .41112 m .84501 .41042 L .84382 .40791 L F
.142 .347 .806 r
.42057 .66783 m .42271 .66857 L .42133 .67014 L F
0 0 0 r
.42271 .66857 m .42035 .67142 L .42133 .67014 L F
.59 .019 0 r
.4669 .61993 m .46337 .61783 L .46736 .61869 L F
.297 0 .235 r
.46962 .61792 m .4669 .61993 L .46736 .61869 L F
.544 .263 .44 r
.19631 .76025 m .19451 .75804 L .19399 .76077 L F
.19631 .76025 m .19529 .75826 L .19451 .75804 L F
.148 .59 .93 r
.27213 .56027 m .27184 .55921 L .2706 .55912 L F
0 .044 .597 r
.27213 .56027 m .27309 .56119 L .27184 .55921 L F
.339 .1 .398 r
.30534 .60029 m .30488 .60276 L .30284 .6034 L F
.43 .267 .558 r
.30487 .60539 m .30284 .6034 L .30488 .60276 L F
.30487 .60539 m .30283 .606 L .30284 .6034 L F
.462 .281 .549 r
.42372 .6217 m .42394 .62475 L .42586 .62346 L F
.379 .732 .99 r
.81708 .40013 m .81449 .40022 L .81353 .39918 L F
.89 .78 .733 r
.57789 .53327 m .57812 .53108 L .57648 .52966 L F
.57789 .53327 m .57648 .52966 L .57834 .53284 L F
.208 0 0 r
.46408 .61331 m .46604 .61309 L .46823 .61132 L F
0 0 .259 r
.46823 .61132 m .46957 .61112 L .4696 .60886 L F
.488 .416 .702 r
.47092 .61365 m .46823 .61132 L .47122 .61158 L F
.47092 .61365 m .46939 .61533 L .46823 .61132 L F
0 0 0 r
.46823 .61132 m .46604 .61309 L .46957 .61112 L F
.373 .092 .352 r
.4827 .62075 m .48547 .6178 L .48314 .61842 L F
.047 .59 .846 r
.76882 .42409 m .77135 .42444 L .77192 .42475 L F
.246 .465 .874 r
.77373 .42369 m .77192 .42475 L .77135 .42444 L F
.77373 .42369 m .77529 .42647 L .77192 .42475 L F
.758 .514 .564 r
.55893 .51548 m .55914 .51802 L .55524 .51741 L F
0 0 0 r
.22467 .69438 m .22263 .69759 L .22346 .69679 L F
.22346 .69679 m .22263 .69759 L .22219 .69837 L F
.17985 .63389 m .17636 .63616 L .18012 .63695 L F
.516 .591 .868 r
.17834 .63154 m .17985 .63389 L .18142 .63211 L F
.439 .326 .628 r
.17985 .63389 m .1823 .63641 L .18142 .63211 L F
.17985 .63389 m .18012 .63695 L .1823 .63641 L F
.222 .739 .729 r
.19826 .55849 m .19564 .55906 L .1935 .55965 L F
.214 .734 .725 r
.19794 .55845 m .19826 .55849 L .20048 .55787 L F
.19794 .55845 m .19564 .55906 L .19826 .55849 L F
.652 .522 .693 r
.73851 .38504 m .74178 .38451 L .74097 .38184 L F
.883 .954 .847 r
.73967 .38714 m .74178 .38451 L .73851 .38504 L F
.487 .335 .6 r
.65595 .42755 m .65908 .42775 L .65832 .42411 L F
.472 .206 .429 r
.65595 .42755 m .65855 .42881 L .65908 .42775 L F
.65595 .42755 m .65598 .42986 L .65855 .42881 L F
.207 .72 .884 r
.2559 .53753 m .25797 .53736 L .25981 .53779 L F
.184 .694 .898 r
.25797 .53736 m .26183 .53776 L .25981 .53779 L F
.556 .529 .78 r
.82724 .41508 m .8287 .41064 L .82602 .4115 L F
.82724 .41508 m .8298 .41452 L .8287 .41064 L F
.247 0 0 r
.23922 .62647 m .24321 .62385 L .24116 .62463 L F
.456 .555 .868 r
.82431 .43453 m .82236 .43662 L .82034 .43307 L F
.448 .542 .86 r
.82431 .43453 m .82493 .43633 L .82236 .43662 L F
.618 .603 .813 r
.82493 .43633 m .82258 .43946 L .82236 .43662 L F
.589 .692 .913 r
.15247 .61436 m .15376 .61606 L .1548 .61359 L F
.414 .488 .827 r
.15376 .61606 m .15641 .61739 L .1548 .61359 L F
.926 .796 .698 r
.57833 .55933 m .58084 .55816 L .57914 .557 L F
.41 .035 .212 r
.47425 .62646 m .47716 .62457 L .47487 .62489 L F
.281 .48 .876 r
.77836 .44037 m .78131 .43996 L .77805 .43849 L F
.77836 .44037 m .78153 .44169 L .78131 .43996 L F
.572 .761 .968 r
.43323 .64972 m .43519 .64887 L .43129 .6479 L F
.87 .661 .618 r
.56715 .53026 m .56432 .52978 L .56464 .5272 L F
.919 .737 .64 r
.56715 .53026 m .56431 .5322 L .56432 .52978 L F
.56715 .53026 m .56627 .53299 L .56431 .5322 L F
.603 .794 .973 r
.1823 .63641 m .18415 .638 L .18564 .63724 L F
.563 .442 .673 r
.30739 .59726 m .30773 .59988 L .30534 .60029 L F
.469 .212 .442 r
.30725 .60217 m .30534 .60029 L .30773 .59988 L F
.30725 .60217 m .30488 .60276 L .30534 .60029 L F
0 0 0 r
.16353 .55831 m .16032 .56024 L .16238 .55932 L F
.139 0 0 r
.16238 .55932 m .16558 .55756 L .16353 .55831 L F
.641 .39 .523 r
.45433 .64845 m .45137 .65113 L .4513 .6491 L F
.876 .554 .437 r
.49291 .56522 m .49571 .56705 L .49479 .56603 L F
.488 .438 .728 r
.48752 .56707 m .49058 .56886 L .49001 .56764 L F
.262 0 0 r
.49001 .56764 m .48628 .5687 L .48752 .56707 L F
.43 .328 .638 r
.24458 .67256 m .24287 .67618 L .24197 .67281 L F
.24458 .67256 m .2447 .67554 L .24287 .67618 L F
0 0 .437 r
.24414 .67761 m .24287 .67618 L .2447 .67554 L F
.24414 .67761 m .24314 .67894 L .24287 .67618 L F
.973 .681 .287 r
.52246 .56948 m .5237 .57298 L .52267 .57169 L F
.643 .169 0 r
.5237 .57298 m .52442 .5743 L .52267 .57169 L F
.5237 .57298 m .52551 .57547 L .52442 .5743 L F
.925 .775 .676 r
.56845 .53612 m .56549 .53842 L .56686 .53429 L F
.56845 .53612 m .56733 .53959 L .56549 .53842 L F
.293 .789 .86 r
.24038 .55046 m .2358 .55106 L .23729 .55111 L F
.38 .126 .399 r
.47671 .60168 m .47626 .60356 L .47851 .60253 L F
.792 .555 .579 r
.42601 .66138 m .4251 .66335 L .42326 .6608 L F
.931 .825 .719 r
.56486 .55748 m .56505 .55338 L .56647 .55477 L F
.925 .748 .644 r
.56095 .57251 m .56222 .57605 L .56048 .57503 L F
.89 .886 .822 r
.43609 .64193 m .4371 .64403 L .44006 .63959 L F
.406 .233 .531 r
.31468 .55758 m .31254 .56079 L .31214 .55823 L F
.31468 .55758 m .31453 .56018 L .31254 .56079 L F
.523 .375 .621 r
.31493 .56272 m .31254 .56079 L .31453 .56018 L F
.31493 .56272 m .31263 .56328 L .31254 .56079 L F
.544 .722 .956 r
.19276 .61751 m .19227 .62004 L .19064 .61806 L F
.19276 .61751 m .19507 .61946 L .19227 .62004 L F
.549 .568 .826 r
.65494 .43246 m .65762 .43344 L .65598 .42986 L F
.799 .672 .724 r
.51077 .5451 m .51469 .54257 L .51191 .54265 L F
.508 .317 .556 r
.55036 .60733 m .55285 .60853 L .55298 .60595 L F
.509 .474 .753 r
.55266 .60706 m .55036 .60733 L .55298 .60595 L F
.55266 .60706 m .55044 .60642 L .55036 .60733 L F
.745 .683 .791 r
.55036 .60733 m .55044 .60642 L .54637 .60509 L F
.575 .554 .794 r
.55503 .58791 m .55301 .58886 L .55114 .58482 L F
.593 .424 .622 r
.45805 .59118 m .45842 .5943 L .45563 .59423 L F
.45805 .59118 m .45842 .5943 L .45563 .59423 L F
.901 .948 .595 r
.23056 .67957 m .22897 .6827 L .22922 .68055 L F
.078 0 0 r
.23025 .67955 m .23056 .67957 L .22922 .68055 L F
.23025 .67955 m .2334 .67987 L .23056 .67957 L F
.312 0 0 r
.26169 .55718 m .2596 .55663 L .25961 .55653 L F
.426 .82 .985 r
.26169 .55718 m .26208 .55627 L .2596 .55663 L F
.366 .835 .871 r
.26208 .55627 m .2596 .55673 L .2596 .55663 L F
.2596 .55673 m .25824 .55698 L .2596 .55663 L F
.312 0 0 r
.25961 .55653 m .2596 .55663 L .25771 .55594 L F
.035 .374 .841 r
.26169 .55718 m .26313 .55791 L .26208 .55627 L F
.733 .219 0 r
.41581 .63512 m .4154 .63396 L .41319 .63249 L F
.41581 .63512 m .41693 .63589 L .4154 .63396 L F
0 .033 .541 r
.27028 .5851 m .27162 .58371 L .27072 .58057 L F
0 0 .11 r
.27028 .5851 m .27095 .58604 L .27162 .58371 L F
.27028 .5851 m .26964 .58792 L .27095 .58604 L F
.566 .683 .918 r
.24373 .67026 m .24197 .67281 L .24089 .67046 L F
.24373 .67026 m .24413 .67134 L .24197 .67281 L F
.672 .746 .907 r
.24619 .67162 m .24458 .67256 L .24373 .67026 L F
.24619 .67162 m .24373 .67026 L .24654 .66929 L F
.768 .497 .525 r
.24654 .66929 m .24373 .67026 L .2418 .67168 L F
.24654 .66929 m .24423 .67046 L .24488 .66867 L F
.33 0 0 r
.24089 .67046 m .2418 .67168 L .24373 .67026 L F
.768 .497 .525 r
.24423 .67046 m .2418 .67168 L .24439 .66915 L F
.24423 .67046 m .24439 .66915 L .24488 .66867 L F
.566 .683 .918 r
.24413 .67134 m .24458 .67256 L .24397 .67262 L F
.24413 .67134 m .24397 .67262 L .24197 .67281 L F
.523 .25 .442 r
.4826 .60236 m .48204 .60559 L .47968 .60599 L F
.52 .247 .441 r
.4856 .60433 m .48363 .60304 L .48511 .60214 L F
.4856 .60433 m .48204 .60559 L .4826 .60236 L F
.58 .381 .576 r
.48761 .60214 m .48511 .60214 L .48688 .60106 L F
.48761 .60214 m .4856 .60433 L .48511 .60214 L F
.784 .547 .577 r
.4827 .60391 m .48687 .60106 L .48511 .60214 L F
.48687 .60106 m .48688 .60106 L .48511 .60214 L F
.52 .247 .441 r
.48363 .60304 m .4826 .60236 L .48511 .60214 L F
.374 .788 .979 r
.24975 .53731 m .25192 .53686 L .25355 .53769 L F
.401 .776 .993 r
.25192 .53686 m .2559 .53753 L .25355 .53769 L F
.058 0 0 r
.43708 .63024 m .43933 .62994 L .4415 .62882 L F
.43933 .62994 m .43977 .62984 L .4415 .62882 L F
0 0 0 r
.4415 .62882 m .43967 .6299 L .44208 .62908 L F
.663 .581 .753 r
.43862 .6293 m .4389 .63004 L .44208 .62908 L F
.4389 .63004 m .43963 .63195 L .44186 .62933 L F
.4389 .63004 m .44186 .62933 L .44208 .62908 L F
.058 0 0 r
.43933 .62994 m .43967 .6299 L .43977 .62984 L F
0 0 0 r
.4415 .62882 m .44208 .62908 L .44368 .62752 L F
.728 .779 .894 r
.83636 .41265 m .8402 .41318 L .8384 .41123 L F
.253 .765 .792 r
.79885 .44438 m .79803 .44439 L .7954 .44503 L F
.319 .807 .807 r
.80065 .44358 m .79803 .44439 L .79885 .44438 L F
.563 .513 .758 r
.48888 .57301 m .49128 .57246 L .49058 .56886 L F
.63 .109 0 r
.43677 .66704 m .43578 .66639 L .43324 .66372 L F
.916 .965 .793 r
.43803 .6633 m .43578 .66639 L .43677 .66704 L F
.627 .425 .589 r
.50453 .5457 m .50675 .54558 L .50737 .54221 L F
.342 .157 .479 r
.50737 .54221 m .50828 .54184 L .50993 .53928 L F
.688 .483 .604 r
.50737 .54221 m .51077 .5451 L .50828 .54184 L F
.50737 .54221 m .50675 .54558 L .51077 .5451 L F
.829 .702 .724 r
.68059 .42919 m .68432 .42728 L .68117 .42683 L F
.68059 .42919 m .68236 .4306 L .68432 .42728 L F
0 0 0 r
.54718 .5087 m .54902 .50822 L .55015 .50636 L F
.31 0 .034 r
.55015 .50636 m .55126 .50769 L .55252 .5056 L F
.55015 .50636 m .54902 .50822 L .55126 .50769 L F
.467 .501 .81 r
.1499 .61317 m .15167 .61244 L .14862 .61138 L F
.1499 .61317 m .15247 .61436 L .15167 .61244 L F
.73 .585 .694 r
.45843 .62111 m .45757 .62695 L .45543 .62565 L F
.598 .443 .643 r
.46079 .61785 m .45892 .62122 L .45843 .62111 L F
.614 .477 .672 r
.46081 .62276 m .45843 .62111 L .45892 .62122 L F
.46081 .62276 m .45757 .62695 L .45843 .62111 L F
.125 0 0 r
.25251 .6186 m .24942 .62099 L .25182 .62074 L F
.377 .092 .348 r
.25459 .61796 m .25251 .6186 L .25182 .62074 L F
.851 .669 .655 r
.57694 .54542 m .57786 .54845 L .57817 .54588 L F
.899 .515 .072 r
.78721 .38729 m .78838 .3886 L .78837 .38862 L F
0 .029 .519 r
.78876 .38895 m .78838 .3886 L .78721 .38729 L F
.78876 .38895 m .78992 .39004 L .78838 .3886 L F
.901 .726 .654 r
.5755 .53901 m .57649 .54242 L .57677 .53994 L F
.5755 .53901 m .57349 .54182 L .57649 .54242 L F
.862 .645 .607 r
.57295 .5444 m .57649 .54242 L .57349 .54182 L F
.57295 .5444 m .57694 .54542 L .57649 .54242 L F
.748 .734 .839 r
.22778 .68519 m .22935 .68786 L .23197 .68554 L F
.172 0 .14 r
.47877 .60749 m .4775 .60681 L .47968 .60599 L F
.47877 .60749 m .47672 .60849 L .4775 .60681 L F
.316 .461 .847 r
.483 .56242 m .48352 .5646 L .48496 .56248 L F
.802 .775 .829 r
.48473 .56719 m .48496 .56248 L .48352 .5646 L F
.491 .376 .65 r
.21963 .70059 m .2216 .70129 L .22219 .69837 L F
.62 .914 .98 r
.78926 .44614 m .79278 .44567 L .79204 .44543 L F
.436 .863 .938 r
.7954 .44503 m .79204 .44543 L .79278 .44567 L F
0 0 0 r
.43195 .5846 m .432 .58471 L .4337 .58219 L F
.544 .406 .643 r
.43728 .58753 m .43428 .58822 L .43328 .58668 L F
0 .084 .643 r
.43195 .5846 m .43428 .58822 L .43367 .58605 L F
.43195 .5846 m .43367 .58605 L .432 .58471 L F
0 0 .486 r
.43328 .58668 m .43428 .58822 L .43195 .5846 L F
.448 .202 .447 r
.23146 .69667 m .23108 .69993 L .22857 .70016 L F
.407 .228 .524 r
.23383 .69377 m .23146 .69667 L .2308 .69447 L F
.23383 .69377 m .23363 .6971 L .23146 .69667 L F
.754 .671 .119 r
.23117 .698 m .23108 .69993 L .23112 .6996 L F
.23117 .698 m .23112 .6996 L .23146 .69667 L F
.23117 .698 m .23146 .69667 L .23363 .6971 L F
.466 .751 .991 r
.23117 .698 m .23299 .69749 L .23118 .69773 L F
.23117 .698 m .23118 .69773 L .23091 .69776 L F
.465 .298 .569 r
.30916 .59034 m .30957 .59324 L .30734 .59382 L F
.46 .328 .615 r
.30957 .59324 m .30739 .59726 L .30734 .59382 L F
.446 0 0 r
.22582 .69592 m .22467 .69438 L .22346 .69679 L F
.317 .047 .336 r
.22582 .69592 m .22306 .69811 L .22488 .69814 L F
.942 .911 .531 r
.22507 .69668 m .22582 .69592 L .22488 .69814 L F
.446 0 0 r
.22582 .69592 m .22696 .69478 L .22467 .69438 L F
.317 .047 .336 r
.22582 .69592 m .22346 .69679 L .22306 .69811 L F
.942 .911 .531 r
.2254 .69424 m .22582 .69592 L .22507 .69668 L F
.446 0 0 r
.22582 .69592 m .22704 .69479 L .22696 .69478 L F
.495 .256 .481 r
.27928 .62993 m .27675 .63243 L .27707 .63045 L F
.352 .201 .532 r
.25748 .61235 m .2592 .61435 L .25929 .61172 L F
.25748 .61235 m .25745 .6152 L .2592 .61435 L F
.816 .775 .814 r
.20975 .72771 m .20664 .72878 L .20773 .72876 L F
.568 .939 .882 r
.21174 .72649 m .20975 .72771 L .2108 .72662 L F
.567 .927 .76 r
.20975 .72771 m .20773 .72876 L .2108 .72662 L F
.557 .437 .672 r
.21174 .72649 m .20898 .73157 L .20975 .72771 L F
.442 .606 .916 r
.14611 .60938 m .14717 .60788 L .14491 .60771 L F
.87 .5 .012 r
.5358 .57774 m .53767 .58133 L .53692 .579 L F
0 0 0 r
.49606 .59349 m .49516 .59639 L .49428 .59735 L F
.448 .035 .163 r
.49569 .59873 m .49428 .59735 L .49516 .59639 L F
.49569 .59873 m .49283 .59916 L .49428 .59735 L F
.945 .594 .201 r
.47722 .5589 m .47836 .5583 L .47451 .55742 L F
.47722 .5589 m .4783 .56037 L .47836 .5583 L F
.888 .688 .626 r
.4251 .66335 m .42696 .66597 L .42329 .66566 L F
0 .156 .697 r
.42485 .66872 m .42329 .66566 L .42696 .66597 L F
.715 .666 .8 r
.42918 .66363 m .42696 .66597 L .4251 .66335 L F
.506 .673 .939 r
.42966 .66595 m .42696 .66597 L .42918 .66363 L F
.589 .456 .668 r
.3118 .57249 m .31304 .5781 L .30984 .57817 L F
.532 .412 .662 r
.31227 .57851 m .30984 .57817 L .31304 .5781 L F
.31227 .57851 m .30999 .57908 L .30984 .57817 L F
.622 .78 .957 r
.66355 .4332 m .66722 .43413 L .66588 .43232 L F
.648 .724 .904 r
.66588 .43232 m .66722 .43413 L .66964 .43311 L F
.286 0 .011 r
.53277 .51751 m .53523 .51699 L .53643 .51527 L F
.12 0 0 r
.53523 .51699 m .53905 .51502 L .53643 .51527 L F
.96 .929 .718 r
.76565 .39642 m .76299 .3989 L .76521 .39565 L F
.76565 .39642 m .76379 .39997 L .76299 .3989 L F
.518 .325 .559 r
.17008 .60331 m .16961 .60635 L .16754 .60647 L F
.578 .382 .579 r
.44659 .65721 m .44398 .66038 L .44415 .65781 L F
.44398 .66038 m .44659 .65721 L .44415 .65781 L F
0 0 0 r
.54718 .5087 m .54592 .51019 L .54902 .50822 L F
.083 0 .293 r
.16075 .58059 m .16057 .58391 L .15866 .58479 L F
.347 .283 .642 r
.16282 .57794 m .16075 .58059 L .16066 .57823 L F
.16282 .57794 m .16342 .5813 L .16075 .58059 L F
.207 0 .327 r
.16227 .58286 m .16075 .58059 L .16342 .5813 L F
.16227 .58286 m .16057 .58391 L .16075 .58059 L F
.404 .122 .368 r
.46608 .64263 m .46572 .64466 L .46342 .64524 L F
.512 .296 .522 r
.46825 .64192 m .46572 .64466 L .46608 .64263 L F
.899 .8 .742 r
.56664 .54498 m .56446 .54496 L .56645 .54168 L F
.902 .752 .685 r
.56664 .54498 m .56394 .54771 L .56446 .54496 L F
.56664 .54498 m .56588 .54863 L .56394 .54771 L F
.6 .382 .556 r
.44092 .6124 m .44334 .61474 L .44333 .61254 L F
.44092 .6124 m .44076 .61542 L .44334 .61474 L F
0 .098 .654 r
.7532 .41291 m .75274 .41128 L .75017 .41162 L F
.7532 .41291 m .75436 .41438 L .75274 .41128 L F
.522 .115 .211 r
.49105 .61507 m .48813 .61717 L .48862 .61794 L F
.49105 .61507 m .49053 .61715 L .48813 .61717 L F
.316 .453 .84 r
.49013 .61303 m .49297 .61407 L .49105 .61507 L F
0 0 .037 r
.49297 .61407 m .49053 .61715 L .49105 .61507 L F
.795 .558 .579 r
.27885 .58454 m .27542 .58385 L .27664 .5851 L F
.473 .275 .53 r
.27664 .5851 m .27647 .58765 L .27885 .58454 L F
0 0 .059 r
.27691 .58623 m .27647 .58765 L .27664 .5851 L F
.27691 .58623 m .27664 .5851 L .27542 .58385 L F
.835 .427 0 r
.52953 .58182 m .52865 .58138 L .52755 .57848 L F
.838 .556 .013 r
.52953 .58182 m .52939 .58324 L .52865 .58138 L F
.52953 .58182 m .52994 .5845 L .52939 .58324 L F
.86 .604 .069 r
.53072 .5875 m .53027 .5873 L .52994 .5845 L F
0 .065 .614 r
.53241 .59025 m .53027 .5873 L .53072 .5875 L F
.639 .211 0 r
.53322 .59141 m .53241 .59025 L .53072 .5875 L F
.963 .659 .404 r
.49865 .56896 m .49911 .57248 L .50075 .5733 L F
.735 .224 0 r
.49911 .57248 m .50195 .57514 L .50075 .5733 L F
.543 .846 .999 r
.20031 .64302 m .20368 .64331 L .20239 .64166 L F
.524 .714 .958 r
.20239 .64166 m .20368 .64331 L .2046 .64126 L F
.471 .651 .938 r
.20368 .64331 m .20745 .64422 L .2046 .64126 L F
.239 .754 .764 r
.22597 .70034 m .22431 .70062 L .2216 .70129 L F
.94 .819 .697 r
.22857 .70016 m .22666 .70221 L .22597 .70034 L F
0 0 .341 r
.22597 .70034 m .22666 .70221 L .22662 .70144 L F
.22597 .70034 m .22662 .70144 L .22431 .70062 L F
.492 .555 .848 r
.53649 .60582 m .53897 .60554 L .53758 .60375 L F
.53649 .60582 m .53758 .60375 L .53682 .60331 L F
.634 .701 .894 r
.54073 .60476 m .53996 .60164 L .53785 .60311 L F
.492 .555 .848 r
.53763 .60357 m .5379 .60301 L .53777 .60305 L F
.53758 .60375 m .53777 .60305 L .53682 .60331 L F
.634 .701 .894 r
.53763 .60357 m .53785 .60311 L .53735 .60346 L F
.54073 .60476 m .53785 .60311 L .53763 .60357 L F
.492 .555 .848 r
.53758 .60375 m .53798 .60299 L .5379 .60301 L F
.53758 .60375 m .5379 .60301 L .53763 .60357 L F
.634 .701 .894 r
.54073 .60476 m .53763 .60357 L .53897 .60554 L F
.53763 .60357 m .53735 .60346 L .53758 .60375 L F
.53763 .60357 m .53758 .60375 L .53897 .60554 L F
.492 .555 .848 r
.53649 .60582 m .53758 .60375 L .53735 .60346 L F
.53649 .60582 m .53809 .60296 L .53798 .60299 L F
.28 .077 .416 r
.26475 .60571 m .26688 .60261 L .26502 .60334 L F
.161 .7 .811 r
.21445 .53775 m .21688 .53751 L .21879 .53761 L F
.365 0 0 r
.21688 .53751 m .22075 .53771 L .21879 .53761 L F
.307 0 0 r
.26841 .5367 m .27032 .53714 L .27244 .53609 L F
.348 .791 .959 r
.27032 .53714 m .27463 .53739 L .27244 .53609 L F
.44 .299 .592 r
.48537 .59902 m .48688 .60106 L .48592 .59939 L F
.48537 .59902 m .48534 .59936 L .48688 .60106 L F
.306 .072 .385 r
.48688 .60106 m .48515 .5999 L .48557 .59962 L F
.48688 .60106 m .48511 .60214 L .48515 .5999 L F
.44 .299 .592 r
.48534 .59936 m .48511 .60214 L .48688 .60106 L F
.306 .072 .385 r
.48688 .60106 m .48557 .59962 L .48592 .59939 L F
.618 .603 .813 r
.82493 .43633 m .82677 .44021 L .82258 .43946 L F
.579 .107 .098 r
.42784 .65779 m .43007 .65918 L .43181 .65771 L F
.414 .816 .981 r
.43007 .65918 m .43412 .65938 L .43181 .65771 L F
.675 .624 .791 r
.31127 .58761 m .30916 .59034 L .30866 .58906 L F
.514 .399 .66 r
.31127 .58761 m .31153 .59017 L .30916 .59034 L F
.599 .443 .641 r
.31153 .59017 m .30957 .59324 L .30916 .59034 L F
.602 .644 .864 r
.48688 .56076 m .48208 .55872 L .48546 .55982 L F
.784 .554 .588 r
.48546 .55982 m .48869 .56237 L .48688 .56076 L F
.782 .552 .588 r
.57107 .50811 m .57481 .50626 L .57129 .50605 L F
.57107 .50811 m .57275 .50874 L .57481 .50626 L F
.795 .572 .599 r
.57275 .50874 m .57646 .50947 L .57481 .50626 L F
.048 0 0 r
.22075 .53771 m .22303 .53774 L .22531 .53765 L F
.055 0 0 r
.22303 .53774 m .2272 .53723 L .22531 .53765 L F
.202 0 .048 r
.18225 .56819 m .1809 .56749 L .18396 .56636 L F
.18225 .56819 m .18005 .56893 L .1809 .56749 L F
.899 .515 .072 r
.78721 .38729 m .78837 .38862 L .78717 .38757 L F
.815 .807 .843 r
.76545 .42432 m .7666 .42681 L .76882 .42409 L F
.48 .308 .569 r
.7666 .42681 m .76905 .42661 L .76882 .42409 L F
0 .045 .6 r
.50687 .59959 m .50841 .6049 L .50842 .60171 L F
.891 .842 .789 r
.50778 .60731 m .50842 .60171 L .50841 .6049 L F
.844 .673 .67 r
.5613 .51819 m .56253 .52151 L .55915 .52022 L F
.845 .475 .351 r
.56253 .52151 m .56089 .52296 L .55915 .52022 L F
.836 .461 .341 r
.56253 .52151 m .56314 .5236 L .56089 .52296 L F
.822 .452 .355 r
.56621 .52425 m .56314 .5236 L .56253 .52151 L F
.529 .335 .562 r
.4337 .58219 m .43598 .5818 L .43547 .57957 L F
.563 .53 .777 r
.43542 .57622 m .43547 .57957 L .43827 .57769 L F
.382 .242 .564 r
.43547 .57957 m .43838 .58019 L .43827 .57769 L F
.43547 .57957 m .43598 .5818 L .43838 .58019 L F
.602 .723 .93 r
.82052 .43136 m .81845 .43379 L .81767 .43207 L F
.562 .66 .902 r
.82052 .43136 m .82034 .43307 L .81845 .43379 L F
.741 .866 .938 r
.55507 .60528 m .55874 .60494 L .5564 .60315 L F
.538 0 0 r
.56127 .60485 m .5564 .60315 L .55874 .60494 L F
.867 .437 .186 r
.51759 .56453 m .51696 .56575 L .51722 .56296 L F
.51759 .56453 m .51872 .56629 L .51696 .56575 L F
.382 .029 .237 r
.26895 .63702 m .26813 .63879 L .26589 .63922 L F
.565 .284 .449 r
.27114 .63641 m .26813 .63879 L .26895 .63702 L F
.932 .828 .721 r
.56621 .52425 m .56319 .5263 L .56314 .5236 L F
.56621 .52425 m .56464 .5272 L .56319 .5263 L F
.36 .085 .354 r
.15511 .564 m .15647 .56569 L .15721 .56339 L F
.15511 .564 m .1544 .56639 L .15647 .56569 L F
0 0 .259 r
.17098 .604 m .16961 .60635 L .17008 .60331 L F
.297 .622 .96 r
.80606 .4057 m .80904 .40719 L .80824 .40603 L F
.383 .692 .981 r
.80904 .40719 m .81152 .40614 L .80824 .40603 L F
.80904 .40719 m .81256 .40751 L .81152 .40614 L F
.63 .716 .909 r
.79272 .43504 m .79659 .43599 L .79409 .43704 L F
.086 .28 .764 r
.50687 .59959 m .50532 .59569 L .50748 .59736 L F
.685 .651 .81 r
.22765 .64409 m .23324 .64457 L .23043 .64388 L F
0 0 0 r
.22687 .64417 m .22765 .64409 L .23043 .64388 L F
.275 0 0 r
.4834 .55929 m .48208 .55872 L .48093 .55925 L F
.4834 .55929 m .48546 .55982 L .48208 .55872 L F
.243 0 .238 r
.44781 .5833 m .44654 .5816 L .44901 .58109 L F
.44781 .5833 m .44582 .58409 L .44654 .5816 L F
.51 .387 .649 r
.31376 .56935 m .31414 .57182 L .3118 .57249 L F
.482 .377 .658 r
.31414 .57182 m .31304 .5781 L .3118 .57249 L F
.301 0 .171 r
.15866 .58479 m .15628 .58685 L .15925 .58617 L F
.15866 .58479 m .15817 .58688 L .15628 .58685 L F
.016 0 .085 r
.15943 .58612 m .15866 .58479 L .16057 .58391 L F
.15943 .58612 m .15817 .58688 L .15866 .58479 L F
.464 .818 .997 r
.22206 .62935 m .22002 .62981 L .21846 .62901 L F
.267 0 .25 r
.46592 .66986 m .46523 .67216 L .46778 .66951 L F
.46592 .66986 m .46523 .67216 L .46778 .66951 L F
.509 .615 .893 r
.15727 .61904 m .15862 .61704 L .15641 .61739 L F
.15727 .61904 m .16037 .62057 L .15862 .61704 L F
.876 .889 .463 r
.52713 .52445 m .52745 .52234 L .52817 .52182 L F
0 0 0 r
.52799 .5222 m .52817 .52182 L .52745 .52234 L F
.52799 .5222 m .53045 .52083 L .52817 .52182 L F
.232 0 .2 r
.46337 .61783 m .45892 .62122 L .46079 .61785 L F
.46337 .61783 m .46217 .62049 L .45892 .62122 L F
0 0 .042 r
.46217 .62049 m .46081 .62276 L .45892 .62122 L F
.61 .305 .427 r
.74368 .38367 m .74351 .38157 L .74097 .38184 L F
.416 .379 .709 r
.74097 .38184 m .74178 .38451 L .74368 .38367 L F
.223 0 0 r
.26411 .53807 m .26841 .5367 L .26605 .53712 L F
.378 .115 .384 r
.50894 .61623 m .51029 .61746 L .50746 .61815 L F
.579 .588 .826 r
.46243 .61486 m .46337 .61783 L .46079 .61785 L F
.542 .644 .9 r
.50619 .61021 m .50686 .61221 L .50539 .60881 L F
.50619 .61021 m .50922 .61187 L .50686 .61221 L F
.424 .612 .927 r
.17238 .62699 m .1714 .62358 L .16998 .6234 L F
.17238 .62699 m .17405 .62664 L .1714 .62358 L F
.102 .448 .882 r
.54595 .58512 m .54501 .58599 L .5439 .58669 L F
.521 .869 .617 r
.54254 .58801 m .5439 .58669 L .54501 .58599 L F
.762 .561 .625 r
.50828 .54184 m .51077 .5451 L .51191 .54265 L F
.713 .683 .82 r
.44236 .6188 m .44334 .61474 L .44085 .61682 L F
.626 .446 .619 r
.44173 .62092 m .44466 .62077 L .44236 .6188 L F
0 0 .266 r
.41928 .66056 m .4204 .65663 L .422 .65966 L F
.41928 .66056 m .42044 .65925 L .4204 .65663 L F
.64 .665 .859 r
.422 .65966 m .42326 .6608 L .41928 .66056 L F
.649 .34 .436 r
.42326 .6608 m .42253 .66293 L .41928 .66056 L F
.84 .552 .501 r
.42326 .6608 m .4251 .66335 L .42253 .66293 L F
.919 .746 .652 r
.42295 .66273 m .4251 .66335 L .42329 .66566 L F
.95 .743 .59 r
.42253 .66293 m .42159 .66126 L .41928 .66056 L F
.42159 .66126 m .42044 .65925 L .42017 .65956 L F
.42159 .66126 m .42017 .65956 L .41928 .66056 L F
.42253 .66293 m .42007 .66186 L .42044 .65925 L F
0 0 .19 r
.41908 .66577 m .42007 .66186 L .42253 .66293 L F
.693 .534 .666 r
.42253 .66293 m .42329 .66566 L .41908 .66577 L F
.919 .746 .652 r
.42295 .66273 m .42329 .66566 L .42342 .66509 L F
0 0 .42 r
.42342 .66509 m .42253 .66293 L .42295 .66273 L F
.42342 .66509 m .42329 .66566 L .42253 .66293 L F
.848 .61 .578 r
.42007 .66186 m .42342 .66509 L .42299 .66295 L F
.42276 .66267 m .42299 .66295 L .42295 .66273 L F
.42007 .66186 m .42299 .66295 L .42276 .66267 L F
.698 .864 .961 r
.74978 .38116 m .75325 .38103 L .75226 .37826 L F
.75325 .38103 m .74978 .38116 L .75247 .38277 L F
.619 .546 .75 r
.75325 .38103 m .75603 .37863 L .75226 .37826 L F
.75325 .38103 m .75593 .38002 L .75603 .37863 L F
.405 0 0 r
.75521 .38237 m .75325 .38103 L .75247 .38277 L F
0 0 0 r
.75552 .38261 m .75521 .38237 L .75425 .38331 L F
.405 0 0 r
.75521 .38237 m .75653 .38322 L .75482 .38207 L F
.269 .709 .963 r
.75853 .38306 m .75653 .38322 L .75521 .38237 L F
.604 .768 .958 r
.75774 .38138 m .75853 .38306 L .75521 .38237 L F
.75774 .38138 m .75853 .38306 L .75521 .38237 L F
0 0 0 r
.75774 .38138 m .75521 .38237 L .75552 .38261 L F
.405 0 0 r
.75521 .38237 m .75482 .38207 L .75325 .38103 L F
.793 .672 .731 r
.40395 .62107 m .40506 .62442 L .40696 .62123 L F
.748 .332 .262 r
.83911 .42376 m .84108 .42409 L .84162 .42618 L F
.311 .068 .375 r
.84162 .42618 m .84108 .42409 L .8441 .42305 L F
.685 .87 .969 r
.47124 .56349 m .47182 .56501 L .47322 .56353 L F
.652 .456 .606 r
.46676 .56338 m .47017 .56383 L .47065 .55944 L F
.685 .87 .969 r
.47124 .56351 m .47101 .56358 L .47182 .56501 L F
.47065 .56372 m .46915 .56413 L .46942 .56422 L F
.47017 .56383 m .46915 .56413 L .47065 .56372 L F
.573 .524 .762 r
.47017 .56383 m .469 .56408 L .47105 .56394 L F
.46676 .56338 m .469 .56408 L .47017 .56383 L F
.685 .87 .969 r
.47101 .56358 m .47017 .56383 L .47065 .56372 L F
.47101 .56358 m .46942 .56422 L .47182 .56501 L F
.59 .41 .606 r
.47065 .55944 m .47101 .56358 L .47124 .56349 L F
.47101 .56358 m .47105 .56394 L .47124 .56349 L F
.652 .456 .606 r
.47017 .56383 m .47105 .56394 L .47101 .56358 L F
.47017 .56383 m .47101 .56358 L .47065 .55944 L F
.685 .87 .969 r
.47124 .56349 m .469 .56408 L .46915 .56413 L F
.47124 .56349 m .46915 .56413 L .47124 .56351 L F
0 0 .173 r
.46823 .60929 m .47053 .60558 L .46846 .60736 L F
.46823 .60929 m .4696 .60886 L .47053 .60558 L F
.336 .805 .921 r
.20419 .74577 m .20639 .74535 L .20417 .74507 L F
.20419 .74577 m .20639 .74535 L .20417 .74507 L F
.465 .694 .966 r
.29644 .54153 m .29574 .54348 L .29423 .54212 L F
.29644 .54153 m .2978 .54314 L .29574 .54348 L F
.551 .342 .55 r
.31728 .55453 m .31706 .55724 L .31468 .55758 L F
.5 .584 .871 r
.3178 .55128 m .31728 .55453 L .31557 .55135 L F
.3178 .55128 m .31932 .55403 L .31728 .55453 L F
.471 .274 .531 r
.31933 .55657 m .31728 .55453 L .31932 .55403 L F
.31933 .55657 m .31706 .55724 L .31728 .55453 L F
.587 .564 .796 r
.77963 .38749 m .78081 .39161 L .78374 .39075 L F
.328 .568 .926 r
.5472 .60227 m .55044 .60642 L .55266 .60706 L F
.669 .73 .896 r
.54637 .60509 m .55044 .60642 L .5472 .60227 L F
.684 .782 .925 r
.80218 .43185 m .79971 .43564 L .79869 .43461 L F
.80218 .43185 m .80248 .43462 L .79971 .43564 L F
.3 .549 .92 r
.27502 .56379 m .27568 .56211 L .27309 .56119 L F
.27502 .56379 m .27628 .56279 L .27568 .56211 L F
.267 .716 .958 r
.23324 .64457 m .23303 .64362 L .23043 .64388 L F
.23324 .64457 m .23472 .64444 L .23303 .64362 L F
.78 .571 .616 r
.43129 .6479 m .43554 .64706 L .43151 .64581 L F
.619 .437 .614 r
.47084 .63893 m .46709 .63633 L .46898 .63242 L F
.47084 .63893 m .46968 .6411 L .46709 .63633 L F
.711 .393 .437 r
.56263 .50575 m .56479 .50823 L .56608 .50571 L F
.64 .311 .399 r
.56608 .50571 m .56907 .50792 L .5687 .50575 L F
.56608 .50571 m .56479 .50823 L .56907 .50792 L F
.287 0 0 r
.25958 .64154 m .26405 .63933 L .26176 .6414 L F
.452 0 .084 r
.26405 .63933 m .26418 .64112 L .26176 .6414 L F
.26405 .63933 m .26589 .63922 L .26418 .64112 L F
.353 .011 .238 r
.76732 .39074 m .7711 .38762 L .76687 .38773 L F
.76732 .39074 m .76956 .39005 L .7711 .38762 L F
.77 .485 .504 r
.76956 .39005 m .7732 .39107 L .7711 .38762 L F
.561 .646 .891 r
.20735 .6224 m .2062 .62499 L .20396 .62152 L F
.20735 .6224 m .2084 .62461 L .2062 .62499 L F
.522 .362 .605 r
.46589 .62756 m .46844 .62971 L .46838 .62702 L F
.46589 .62756 m .4661 .63059 L .46844 .62971 L F
.915 .548 .108 r
.53767 .58133 m .53829 .58371 L .53963 .58518 L F
.669 .227 0 r
.53994 .58607 m .53963 .58518 L .53829 .58371 L F
.908 .501 .188 r
.53702 .582 m .53877 .58594 L .53994 .58607 L F
.516 .301 .526 r
.53877 .58594 m .53945 .58557 L .53994 .58607 L F
.669 .227 0 r
.53994 .58607 m .54063 .58679 L .53963 .58518 L F
.908 .501 .188 r
.53702 .582 m .53994 .58607 L .53829 .58371 L F
.516 .301 .526 r
.53945 .58557 m .54159 .58443 L .53994 .58607 L F
.669 .227 0 r
.53994 .58607 m .54163 .58839 L .54063 .58679 L F
.116 .254 .73 r
.53081 .56053 m .53379 .56563 L .53201 .56222 L F
.53081 .56053 m .53201 .56222 L .5302 .56358 L F
.858 .52 .41 r
.53019 .56003 m .53201 .56222 L .53317 .56084 L F
.861 .524 .413 r
.53201 .56222 m .53415 .56331 L .53317 .56084 L F
.525 .314 .537 r
.83066 .40287 m .83337 .40218 L .83074 .40291 L F
.91 .56 .097 r
.5157 .60308 m .51617 .60524 L .51711 .60622 L F
0 0 0 r
.5169 .60756 m .51543 .60915 L .51711 .60622 L F
.5169 .60756 m .51711 .60622 L .51617 .60524 L F
.59 .422 .623 r
.19795 .74594 m .19965 .74416 L .20037 .74274 L F
.507 .11 .222 r
.18619 .56586 m .18225 .56819 L .18396 .56636 L F
.593 .812 .983 r
.78664 .44681 m .78777 .44475 L .78526 .44501 L F
.78664 .44681 m .78926 .44614 L .78777 .44475 L F
0 .269 .719 r
.52126 .54998 m .52236 .55056 L .52276 .55121 L F
.721 .296 0 r
.52326 .55265 m .52276 .55121 L .52236 .55056 L F
.52326 .55265 m .52433 .55407 L .52276 .55121 L F
.528 .272 .47 r
.47847 .62749 m .4757 .62995 L .47425 .62646 L F
.47847 .62749 m .47836 .62968 L .4757 .62995 L F
.649 .422 .561 r
.48093 .62711 m .47836 .62968 L .47847 .62749 L F
.89 .886 .822 r
.43609 .64193 m .44006 .63959 L .43707 .63967 L F
.637 .382 .516 r
.4337 .58219 m .43658 .58416 L .43598 .5818 L F
.4337 .58219 m .432 .58471 L .43658 .58416 L F
.276 0 0 r
.43822 .57489 m .43788 .57531 L .44083 .57503 L F
.565 .567 .814 r
.74529 .40211 m .74681 .39787 L .74404 .39872 L F
.74529 .40211 m .74803 .40157 L .74681 .39787 L F
.606 .712 .92 r
.82873 .39861 m .83066 .40287 L .82705 .40209 L F
.48 .581 .878 r
.83134 .39767 m .83066 .40287 L .82873 .39861 L F
.525 .314 .537 r
.83066 .40287 m .83364 .40305 L .83337 .40218 L F
.48 .581 .878 r
.83134 .39767 m .83364 .40305 L .83066 .40287 L F
.851 .669 .655 r
.57694 .54542 m .57448 .5479 L .57786 .54845 L F
.826 .651 .665 r
.57448 .5479 m .57804 .55105 L .57786 .54845 L F
.605 .295 .418 r
.54743 .56898 m .54729 .57188 L .5447 .56979 L F
.56 .21 .332 r
.5478 .56989 m .54863 .56991 L .54743 .56898 L F
.406 .136 .388 r
.54845 .5715 m .54729 .57188 L .54738 .57003 L F
.5478 .5699 m .54738 .57003 L .54743 .56898 L F
.54845 .5715 m .54738 .57003 L .5478 .5699 L F
.56 .21 .332 r
.5447 .56979 m .5478 .56989 L .54743 .56898 L F
.309 .267 .647 r
.54743 .56898 m .54863 .56991 L .54962 .56859 L F
.582 .645 .878 r
.54962 .56859 m .5489 .56955 L .54857 .56948 L F
.5489 .56955 m .54863 .56991 L .54821 .56977 L F
.406 .136 .388 r
.54823 .56976 m .54743 .56898 L .54962 .56859 L F
.54823 .56976 m .5478 .56989 L .54743 .56898 L F
.582 .645 .878 r
.5489 .56955 m .54821 .56977 L .5456 .56886 L F
.406 .136 .388 r
.54962 .57112 m .54823 .56976 L .54962 .56859 L F
.582 .645 .878 r
.54962 .56859 m .54857 .56948 L .5456 .56886 L F
.567 .65 .891 r
.5456 .56886 m .54821 .56977 L .5447 .56979 L F
.54821 .56977 m .54863 .56991 L .5478 .56989 L F
.54821 .56977 m .5478 .56989 L .5447 .56979 L F
.406 .136 .388 r
.54962 .57112 m .54845 .5715 L .5478 .56989 L F
.54962 .57112 m .5478 .56989 L .54823 .56976 L F
.403 .163 .433 r
.47981 .62416 m .4827 .62075 L .48029 .62146 L F
.48 .582 .879 r
.30049 .54361 m .29935 .54593 L .2978 .54314 L F
.514 .624 .898 r
.30049 .54361 m .30201 .54621 L .29935 .54593 L F
.908 .695 .603 r
.56126 .56992 m .56095 .57251 L .55931 .56906 L F
.685 .805 .94 r
.42041 .62571 m .42394 .62475 L .42175 .62596 L F
.646 .584 .77 r
.48499 .62666 m .47981 .62416 L .48482 .62405 L F
.529 .318 .538 r
.48696 .62394 m .48499 .62666 L .48482 .62405 L F
.664 .657 .833 r
.18575 .78234 m .18429 .78517 L .18333 .78399 L F
.18575 .78234 m .18716 .78498 L .18429 .78517 L F
.633 .373 .506 r
.18429 .78517 m .18644 .78688 L .18438 .78797 L F
.18429 .78517 m .18716 .78498 L .18644 .78688 L F
.565 .584 .831 r
.1976 .54221 m .19994 .542 L .19835 .53845 L F
.162 0 0 r
.1955 .54328 m .19994 .542 L .1976 .54221 L F
.62 .09 0 r
.17365 .60846 m .17594 .60963 L .17746 .60925 L F
.477 .016 .077 r
.17594 .60963 m .17964 .60866 L .17746 .60925 L F
.628 .217 .246 r
.45757 .62695 m .45687 .62732 L .45543 .62565 L F
.45757 .62695 m .45752 .62812 L .45687 .62732 L F
0 0 .129 r
.45964 .62529 m .45757 .62695 L .46081 .62276 L F
0 0 .17 r
.47092 .61365 m .46962 .61792 L .46939 .61533 L F
.816 .418 .296 r
.42769 .66971 m .42694 .67159 L .42485 .66872 L F
.539 .434 .682 r
.42966 .66595 m .43022 .66951 L .42769 .66971 L F
.8 .603 .635 r
.43022 .66951 m .42694 .67159 L .42769 .66971 L F
.93 .549 .232 r
.43861 .65645 m .44025 .65742 L .43939 .65533 L F
.837 .856 .859 r
.76379 .39997 m .76107 .40289 L .75977 .40152 L F
.192 0 .108 r
.16032 .56024 m .161 .56191 L .16238 .55932 L F
.16032 .56024 m .15908 .56265 L .161 .56191 L F
.442 .513 .836 r
.45575 .63021 m .45622 .63342 L .45897 .63154 L F
.384 .112 .372 r
.44736 .62711 m .44434 .63048 L .44368 .62752 L F
.44736 .62711 m .44629 .63003 L .44434 .63048 L F
.665 .392 .497 r
.44976 .62961 m .44736 .62711 L .44979 .62746 L F
.44976 .62961 m .44629 .63003 L .44736 .62711 L F
.467 .183 .398 r
.28286 .56982 m .28406 .57235 L .28236 .57177 L F
.274 0 0 r
.27463 .53739 m .27813 .53832 L .27592 .53931 L F
.552 .266 .436 r
.19631 .76025 m .19902 .76015 L .19529 .75826 L F
.19631 .76025 m .19902 .76015 L .19529 .75826 L F
.927 .968 .764 r
.51429 .62341 m .51496 .62419 L .51704 .62076 L F
.887 .79 .748 r
.76498 .39077 m .76687 .38773 L .76422 .38698 L F
.68 .496 .631 r
.76498 .39077 m .76732 .39074 L .76687 .38773 L F
.411 .386 .72 r
.24841 .65709 m .24818 .65879 L .24736 .65524 L F
.915 .852 .766 r
.24702 .65862 m .24818 .65879 L .24841 .65709 L F
.961 .684 .466 r
.17912 .61397 m .18099 .61499 L .18089 .61227 L F
.944 .954 .741 r
.18183 .6082 m .18089 .61227 L .17964 .60866 L F
.18183 .6082 m .17973 .61146 L .18089 .61227 L F
.992 .883 .584 r
.17973 .61146 m .17912 .61397 L .18089 .61227 L F
.779 .279 .006 r
.76391 .41534 m .76604 .41778 L .76752 .41806 L F
.883 .708 .191 r
.76712 .41897 m .76752 .41806 L .76604 .41778 L F
.76712 .41897 m .76737 .42083 L .76752 .41806 L F
1 .826 .499 r
.54163 .58839 m .54117 .58953 L .54254 .58801 L F
0 0 0 r
.54117 .58953 m .5439 .58669 L .54254 .58801 L F
.435 .158 .391 r
.47672 .60849 m .47397 .61104 L .4745 .60931 L F
0 .243 .734 r
.49576 .62696 m .49722 .62807 L .49619 .62669 L F
.232 0 .163 r
.46572 .64466 m .46235 .64771 L .46342 .64524 L F
0 .039 .608 r
.18915 .61665 m .18899 .6179 L .1876 .6148 L F
.18 .548 .929 r
.18915 .61665 m .19064 .61806 L .18899 .6179 L F
.858 .623 .086 r
.53461 .5976 m .53419 .59608 L .53398 .59369 L F
0 0 .466 r
.53639 .59991 m .53419 .59608 L .53461 .5976 L F
.887 .929 .842 r
.47535 .55935 m .47322 .56353 L .47613 .56108 L F
.47535 .55935 m .47124 .56349 L .47322 .56353 L F
0 0 0 r
.16899 .71538 m .16923 .71529 L .16892 .71542 L F
.695 .659 .81 r
.67578 .43285 m .67992 .43363 L .67853 .43001 L F
.778 .701 .778 r
.67853 .43001 m .67992 .43363 L .68236 .4306 L F
.338 .797 .939 r
.30201 .54621 m .3047 .54579 L .3058 .54618 L F
.241 .542 .926 r
.3065 .54486 m .3058 .54618 L .3047 .54579 L F
.3065 .54486 m .30816 .54683 L .3058 .54618 L F
.585 .034 0 r
.49553 .54942 m .49453 .55017 L .49187 .54862 L F
.574 .021 0 r
.49553 .54942 m .49804 .55078 L .49453 .55017 L F
.455 0 0 r
.4998 .55133 m .49804 .55078 L .49553 .54942 L F
.352 .456 .827 r
.76905 .42661 m .7704 .43004 L .77212 .42811 L F
.365 .476 .84 r
.7704 .43004 m .77357 .4315 L .77212 .42811 L F
.28 .42 .825 r
.7704 .43004 m .77351 .43337 L .77357 .4315 L F
.927 .968 .764 r
.51429 .62341 m .51704 .62076 L .51679 .62036 L F
0 0 .303 r
.41784 .66999 m .41908 .66577 L .42057 .66783 L F
.41784 .66999 m .41901 .66949 L .41908 .66577 L F
.541 .758 .977 r
.82255 .39906 m .82062 .40112 L .81968 .39971 L F
.82255 .39906 m .82354 .40055 L .82062 .40112 L F
.931 .825 .719 r
.56486 .55748 m .56323 .55671 L .56505 .55338 L F
.939 .647 .458 r
.56486 .55748 m .56324 .55923 L .56323 .55671 L F
.56486 .55748 m .56521 .56064 L .56324 .55923 L F
.628 .267 .339 r
.24736 .65524 m .24279 .65559 L .24532 .65257 L F
.869 .539 .424 r
.24576 .65642 m .24841 .65709 L .24736 .65524 L F
.861 .989 .723 r
.24739 .65427 m .24736 .65524 L .24854 .65276 L F
.24576 .65642 m .24697 .65553 L .24739 .65427 L F
.24697 .65553 m .24736 .65524 L .24739 .65427 L F
.24576 .65642 m .24854 .65276 L .24872 .65435 L F
.688 .743 .893 r
.24854 .65276 m .24532 .65257 L .24737 .65364 L F
.24861 .65338 m .24737 .65364 L .24872 .65435 L F
.24854 .65276 m .24737 .65364 L .24861 .65338 L F
.446 .57 .886 r
.24532 .65257 m .24757 .65375 L .24645 .65209 L F
.696 .951 .678 r
.24532 .65257 m .24279 .65559 L .2433 .65461 L F
.24532 .65257 m .2433 .65461 L .24432 .65309 L F
.698 .631 .778 r
.2448 .65419 m .24645 .65209 L .24432 .65309 L F
.24576 .65642 m .24616 .6539 L .2448 .65419 L F
.24616 .6539 m .24645 .65209 L .2448 .65419 L F
.446 .57 .886 r
.24757 .65375 m .24872 .65435 L .24771 .65334 L F
.24757 .65375 m .24771 .65334 L .24645 .65209 L F
.641 .953 .752 r
.18594 .76228 m .18395 .76336 L .18416 .76101 L F
.338 .783 .622 r
.18395 .76336 m .18594 .76228 L .18416 .76101 L F
.18395 .76336 m .18715 .76162 L .18594 .76228 L F
.518 .643 .911 r
.16037 .62057 m .16037 .61667 L .15862 .61704 L F
.16037 .62057 m .16323 .6203 L .16037 .61667 L F
.861 .431 .193 r
.79648 .40212 m .79489 .40192 L .79379 .3999 L F
.427 0 0 r
.79648 .40212 m .79825 .40285 L .79489 .40192 L F
.024 0 .322 r
.26721 .60019 m .26816 .60155 L .26906 .59943 L F
.26721 .60019 m .26688 .60261 L .26816 .60155 L F
.722 .403 .439 r
.53481 .57181 m .53848 .56988 L .53502 .56902 L F
.53481 .57181 m .53833 .57259 L .53848 .56988 L F
.051 0 0 r
.5418 .57162 m .54157 .57256 L .53822 .57628 L F
.651 .342 .435 r
.53833 .57259 m .54157 .57256 L .53848 .56988 L F
.725 .252 .123 r
.53848 .56988 m .54157 .57256 L .5418 .57162 L F
0 0 0 r
.76776 .40779 m .76715 .41234 L .76864 .4082 L F
.76776 .40779 m .76731 .4117 L .76715 .41234 L F
.803 .599 .626 r
.76731 .4117 m .76908 .41383 L .76715 .41234 L F
.421 .656 .957 r
.76908 .41383 m .76642 .41439 L .76715 .41234 L F
.682 .788 .93 r
.28214 .5388 m .27813 .53832 L .28034 .53772 L F
.383 .673 .973 r
.28248 .5371 m .28214 .5388 L .28034 .53772 L F
.28248 .5371 m .28431 .53881 L .28214 .5388 L F
.251 .523 .913 r
.1942 .64189 m .19461 .64059 L .19271 .63883 L F
.1942 .64189 m .19615 .64238 L .19461 .64059 L F
.027 0 0 r
.23143 .53725 m .23372 .53706 L .23516 .53673 L F
0 0 0 r
.23372 .53706 m .23467 .53682 L .23516 .53673 L F
.23467 .53682 m .23748 .53612 L .23516 .53673 L F
.08 0 0 r
.23577 .53662 m .23516 .53673 L .23732 .53661 L F
.23352 .53663 m .23516 .53673 L .23577 .53662 L F
.393 .836 .94 r
.23516 .53673 m .23954 .53651 L .23732 .53661 L F
.369 .462 .825 r
.78312 .43249 m .78085 .43237 L .77981 .43078 L F
.538 0 0 r
.56127 .60485 m .56006 .60494 L .5564 .60315 L F
.225 .587 .946 r
.56127 .60485 m .56239 .60356 L .56006 .60494 L F
.56127 .60485 m .5638 .60496 L .56239 .60356 L F
.706 .954 .952 r
.21244 .64489 m .21622 .64397 L .21456 .64342 L F
.304 .725 .973 r
.21622 .64397 m .21714 .64307 L .21456 .64342 L F
.21622 .64397 m .21894 .64399 L .21714 .64307 L F
.619 .75 .94 r
.82354 .40055 m .82626 .39966 L .82705 .40209 L F
.606 .712 .92 r
.82873 .39861 m .82705 .40209 L .82626 .39966 L F
.192 0 0 r
.2272 .53723 m .22914 .53751 L .23121 .53719 L F
.036 0 0 r
.22914 .53751 m .23352 .53663 L .23121 .53719 L F
0 .251 .654 r
.30955 .5497 m .31166 .55083 L .31331 .55182 L F
.468 .802 .999 r
.31166 .55083 m .31557 .55135 L .31331 .55182 L F
.737 .302 .217 r
.45112 .61738 m .45316 .61954 L .45344 .61779 L F
.194 0 .116 r
.45344 .61779 m .45316 .61954 L .45589 .61724 L F
.704 .398 .455 r
.45492 .62926 m .44976 .62961 L .44979 .62746 L F
.365 .332 .689 r
.5447 .56979 m .54729 .57188 L .5456 .56886 L F
.535 .742 .971 r
.20092 .6204 m .19896 .62096 L .19736 .61919 L F
.458 .513 .827 r
.46135 .60294 m .46338 .6054 L .4616 .60631 L F
.062 0 .289 r
.4626 .60761 m .46111 .60866 L .4616 .60631 L F
.555 .203 .327 r
.74603 .38311 m .74351 .38157 L .74368 .38367 L F
.74603 .38311 m .7472 .381 L .74351 .38157 L F
.297 .42 .818 r
.76259 .42436 m .76428 .42264 L .76106 .42077 L F
.441 .654 .95 r
.76259 .42436 m .76545 .42432 L .76428 .42264 L F
.91 .736 .654 r
.56588 .54863 m .56525 .551 L .56394 .54771 L F
.555 .355 .565 r
.31706 .55724 m .31453 .56018 L .31468 .55758 L F
.879 .535 .393 r
.67943 .42075 m .67979 .42312 L .68281 .4239 L F
.864 .675 .645 r
.67933 .42556 m .68281 .4239 L .67979 .42312 L F
.67933 .42556 m .68117 .42683 L .68281 .4239 L F
0 .405 .834 r
.24197 .55061 m .24299 .55035 L .24245 .55043 L F
.004 .567 .801 r
.24175 .55069 m .24197 .55061 L .24038 .55046 L F
.288 0 0 r
.24197 .55061 m .23878 .55065 L .24038 .55046 L F
.203 .731 .794 r
.23641 .55098 m .23718 .55068 L .2358 .55106 L F
.24038 .55046 m .23808 .55062 L .23641 .55098 L F
.23808 .55062 m .23718 .55068 L .23641 .55098 L F
.375 .765 .988 r
.23932 .55034 m .24098 .54942 L .23839 .54964 L F
.23981 .55071 m .24034 .55012 L .23932 .55034 L F
.24034 .55012 m .24098 .54942 L .23932 .55034 L F
.288 0 0 r
.23878 .55065 m .23718 .55068 L .23808 .55062 L F
.23878 .55065 m .23808 .55062 L .24038 .55046 L F
.24197 .55061 m .23988 .55077 L .23718 .55068 L F
.375 .765 .988 r
.23988 .55077 m .23992 .55072 L .23981 .55071 L F
.23992 .55072 m .24098 .54942 L .23981 .55071 L F
0 .405 .834 r
.24197 .55061 m .24245 .55043 L .23988 .55077 L F
.004 .567 .801 r
.2439 .55106 m .24197 .55061 L .24175 .55069 L F
.166 0 0 r
.2439 .55106 m .24373 .55119 L .24197 .55061 L F
.2439 .55106 m .24623 .55148 L .24373 .55119 L F
.717 .767 .892 r
.81996 .41184 m .8234 .41242 L .82235 .41075 L F
.683 .776 .921 r
.8234 .41242 m .82506 .40971 L .82235 .41075 L F
.8234 .41242 m .82602 .4115 L .82506 .40971 L F
.613 .848 .988 r
.76296 .41412 m .76391 .41534 L .76642 .41439 L F
.552 .068 0 r
.76481 .41644 m .76391 .41534 L .76296 .41412 L F
.76481 .41644 m .76604 .41778 L .76391 .41534 L F
.94 .819 .697 r
.22857 .70016 m .2275 .70332 L .22666 .70221 L F
.295 .12 .466 r
.23021 .70203 m .22857 .70016 L .23108 .69993 L F
.23021 .70203 m .2275 .70332 L .22857 .70016 L F
.287 .012 .31 r
.24251 .68137 m .23997 .68428 L .24068 .68203 L F
.858 .681 .662 r
.57295 .5444 m .57448 .5479 L .57694 .54542 L F
.931 .624 .437 r
.51494 .61912 m .51276 .62016 L .51312 .61783 L F
.51494 .61912 m .5147 .6217 L .51276 .62016 L F
.67 .778 .931 r
.51695 .61774 m .51494 .61912 L .51312 .61783 L F
.559 .464 .703 r
.4191 .676 m .42048 .67233 L .41898 .67162 L F
.4191 .676 m .42176 .67542 L .42048 .67233 L F
.544 .406 .644 r
.4191 .676 m .41994 .67775 L .42176 .67542 L F
.818 .379 .197 r
.79562 .39377 m .79623 .39511 L .79712 .39373 L F
.593 .105 .066 r
.79623 .39511 m .79995 .39527 L .79712 .39373 L F
.678 .167 .018 r
.45976 .63021 m .46213 .63217 L .46395 .63167 L F
0 0 0 r
.46395 .63167 m .4665 .63131 L .4661 .63059 L F
.46395 .63167 m .46213 .63217 L .4665 .63131 L F
.639 .346 .457 r
.44381 .57452 m .44686 .57251 L .44438 .57304 L F
.528 .379 .622 r
.65444 .42104 m .65707 .4207 L .6567 .41794 L F
0 0 0 r
.43886 .58596 m .44061 .58551 L .43924 .58378 L F
.104 .284 .762 r
.44061 .58551 m .44128 .58325 L .43924 .58378 L F
.194 0 0 r
.44116 .58544 m .44339 .58598 L .44061 .58551 L F
.44344 .58513 m .4434 .58576 L .44116 .58544 L F
.4434 .58576 m .44339 .58598 L .44116 .58544 L F
.104 .284 .762 r
.44061 .58551 m .44339 .58598 L .44307 .58556 L F
.44068 .58525 m .44307 .58556 L .44128 .58325 L F
.44061 .58551 m .44307 .58556 L .44068 .58525 L F
.551 0 0 r
.44541 .58645 m .44339 .58598 L .44344 .58513 L F
.44541 .58645 m .44344 .58513 L .44582 .58409 L F
.84 .47 .352 r
.44128 .58325 m .44339 .58598 L .44541 .58645 L F
.44128 .58325 m .44541 .58645 L .44174 .58505 L F
0 .501 .826 r
.44371 .5858 m .44461 .58581 L .44423 .58571 L F
.44307 .58556 m .44423 .58571 L .44174 .58505 L F
.44371 .5858 m .44423 .58571 L .44307 .58556 L F
.44541 .58645 m .4448 .58596 L .44371 .5858 L F
.4448 .58596 m .44461 .58581 L .44371 .5858 L F
.438 .591 .906 r
.16825 .62376 m .16764 .62037 L .16579 .62105 L F
.16825 .62376 m .16998 .6234 L .16764 .62037 L F
.247 .342 .764 r
.31031 .5468 m .30955 .5497 L .30816 .54683 L F
.31031 .5468 m .31166 .55083 L .30955 .5497 L F
.641 .723 .907 r
.16892 .71542 m .16923 .71529 L .16882 .7153 L F
.648 .407 .54 r
.45556 .57662 m .45411 .57969 L .45159 .57863 L F
.408 .15 .408 r
.45721 .57813 m .45556 .57662 L .45751 .5756 L F
.45721 .57813 m .45411 .57969 L .45556 .57662 L F
.633 .247 .294 r
.55232 .51712 m .5513 .51815 L .54906 .51752 L F
.712 .378 .412 r
.55524 .51741 m .5513 .51815 L .55232 .51712 L F
0 0 0 r
.58049 .58578 m .58053 .58504 L .5807 .58337 L F
.58049 .58578 m .58004 .5876 L .58053 .58504 L F
.619 .131 .071 r
.66982 .41737 m .67199 .41876 L .67297 .41758 L F
.729 .31 .251 r
.67199 .41876 m .67552 .4182 L .67297 .41758 L F
.886 .532 .046 r
.53322 .59141 m .53398 .59369 L .53241 .59025 L F
0 .442 .72 r
.2473 .64302 m .24763 .64298 L .24762 .64349 L F
.2473 .64302 m .24988 .64365 L .24763 .64298 L F
.977 .684 .389 r
.52886 .55919 m .53008 .55714 L .52839 .55659 L F
.52886 .55919 m .53019 .56003 L .53008 .55714 L F
.585 .584 .818 r
.65832 .42411 m .65963 .41985 L .65707 .4207 L F
.65832 .42411 m .66085 .42345 L .65963 .41985 L F
.283 .201 .584 r
.65832 .42411 m .66025 .42591 L .66085 .42345 L F
.65832 .42411 m .65908 .42775 L .66025 .42591 L F
.287 .453 .851 r
.23786 .66978 m .24053 .67123 L .24089 .67046 L F
.33 0 0 r
.24089 .67046 m .24053 .67123 L .2418 .67168 L F
.638 .147 .069 r
.23786 .66978 m .24053 .67123 L .24089 .67046 L F
.593 .62 .848 r
.25379 .55456 m .25771 .55594 L .2565 .5539 L F
.693 .973 .772 r
.22234 .71523 m .22067 .71676 L .2197 .71705 L F
.22234 .71523 m .2197 .71705 L .21998 .71678 L F
.22234 .71523 m .21946 .71712 L .22147 .71415 L F
.996 .863 .577 r
.22075 .71753 m .22234 .71523 L .22147 .71415 L F
.22075 .71753 m .22115 .71566 L .22266 .71677 L F
.22115 .71566 m .22147 .71415 L .22185 .71499 L F
.22115 .71566 m .22185 .71499 L .22266 .71677 L F
.693 .973 .772 r
.21998 .71678 m .2197 .71705 L .21946 .71712 L F
.179 0 0 r
.20671 .55558 m .2048 .55685 L .20252 .55721 L F
.115 0 0 r
.20807 .55577 m .20671 .55558 L .2088 .55501 L F
.20807 .55577 m .2048 .55685 L .20671 .55558 L F
.87 .447 .208 r
.4998 .55133 m .49844 .55253 L .49804 .55078 L F
.9 .484 .131 r
.49804 .55078 m .49844 .55253 L .49723 .5517 L F
.693 .236 .161 r
.50271 .553 m .50048 .55313 L .49844 .55253 L F
.49969 .55267 m .49844 .55253 L .49889 .55214 L F
.516 0 0 r
.50048 .55313 m .49723 .5517 L .49844 .55253 L F
.50019 .553 m .49961 .55326 L .49723 .5517 L F
.50048 .55313 m .5004 .55314 L .50019 .553 L F
.5004 .55314 m .49961 .55326 L .50019 .553 L F
.693 .236 .161 r
.50271 .553 m .49969 .55267 L .4998 .55133 L F
.49969 .55267 m .49889 .55214 L .4998 .55133 L F
.196 .145 .57 r
.45078 .61222 m .45227 .61447 L .45197 .61157 L F
.815 .678 .712 r
.57258 .51122 m .57622 .51211 L .57646 .50947 L F
.899 .614 .496 r
.57471 .51369 m .57622 .51211 L .57258 .51122 L F
.57471 .51369 m .57623 .51448 L .57622 .51211 L F
.587 .325 .486 r
.44686 .57251 m .45041 .57212 L .45013 .5695 L F
.61 .322 .455 r
.45252 .5716 m .45013 .5695 L .45041 .57212 L F
.45252 .5716 m .45274 .56947 L .45013 .5695 L F
.918 .918 .532 r
.5169 .60756 m .5161 .61134 L .51543 .60915 L F
.771 .716 .801 r
.67853 .43001 m .68236 .4306 L .68059 .42919 L F
0 0 0 r
.15243 .56721 m .15122 .56829 L .1544 .56639 L F
.844 .673 .67 r
.5613 .51819 m .55915 .52022 L .55914 .51802 L F
.829 .569 .019 r
.77167 .39542 m .7725 .39911 L .7721 .39639 L F
.918 .978 .725 r
.77394 .39171 m .7721 .39639 L .77518 .39278 L F
.77394 .39171 m .77167 .39542 L .7721 .39639 L F
.742 .252 .072 r
.52636 .55621 m .52629 .55453 L .52433 .55407 L F
.52636 .55621 m .52839 .55659 L .52629 .55453 L F
.988 .718 .398 r
.41693 .63589 m .4169 .63904 L .41818 .63923 L F
.655 .582 .761 r
.4169 .63904 m .41993 .64143 L .41818 .63923 L F
.913 .615 .465 r
.58172 .56671 m .58203 .56922 L .58176 .5668 L F
.494 .38 .653 r
.31493 .56272 m .31302 .56738 L .31263 .56328 L F
0 0 0 r
.17818 .56978 m .17676 .57144 L .17535 .57193 L F
.17815 .57048 m .17818 .56978 L .18005 .56893 L F
.17815 .57048 m .17676 .57144 L .17818 .56978 L F
.383 .654 .964 r
.2906 .53977 m .2934 .54024 L .29263 .54173 L F
.209 .436 .861 r
.2934 .54024 m .29423 .54212 L .29263 .54173 L F
.683 .524 .664 r
.45753 .5658 m .46158 .56652 L .45882 .56628 L F
.849 .541 .466 r
.50433 .61794 m .50156 .61766 L .50126 .6146 L F
.406 0 .083 r
.50433 .61794 m .50051 .62006 L .50156 .61766 L F
.298 0 0 r
.50051 .62006 m .50465 .61909 L .5041 .61884 L F
.50051 .62006 m .50313 .61997 L .50465 .61909 L F
.673 .245 .222 r
.50458 .61912 m .50313 .61997 L .50382 .61881 L F
.787 .552 .581 r
.5041 .61884 m .50465 .61909 L .50462 .61883 L F
.673 .245 .222 r
.50451 .61809 m .50382 .61881 L .50433 .61794 L F
.50555 .61897 m .50465 .61889 L .50451 .61809 L F
.50465 .61889 m .50382 .61881 L .50451 .61809 L F
.674 .244 .217 r
.50746 .61815 m .50719 .61882 L .50433 .61794 L F
.50719 .61882 m .50537 .61882 L .50433 .61794 L F
.457 .854 .661 r
.50467 .61898 m .50503 .61871 L .50528 .61539 L F
.50465 .61909 m .50468 .61905 L .50467 .61898 L F
.673 .245 .222 r
.50389 .61884 m .5041 .61884 L .50555 .61897 L F
.457 .854 .661 r
.50468 .61905 m .50503 .61871 L .50467 .61898 L F
0 0 .37 r
.50396 .61397 m .50462 .61883 L .50528 .61539 L F
.50462 .61883 m .50465 .61909 L .50467 .61898 L F
.50462 .61883 m .50467 .61898 L .50528 .61539 L F
.673 .245 .222 r
.50673 .61998 m .50475 .61918 L .50555 .61897 L F
.50475 .61918 m .50389 .61884 L .50464 .6189 L F
.50475 .61918 m .50464 .6189 L .50555 .61897 L F
.298 0 0 r
.50051 .62006 m .5041 .61884 L .50382 .61881 L F
.673 .245 .222 r
.50389 .61884 m .50382 .61881 L .5041 .61884 L F
.787 .552 .581 r
.50407 .61882 m .5041 .61884 L .50461 .61882 L F
.5041 .61884 m .50462 .61883 L .50461 .61882 L F
.457 .854 .661 r
.50468 .61905 m .50313 .61997 L .50503 .61871 L F
.50465 .61909 m .50313 .61997 L .50468 .61905 L F
.673 .245 .222 r
.50673 .61998 m .50313 .61997 L .50458 .61912 L F
.298 0 0 r
.50382 .61881 m .5041 .61884 L .50394 .61876 L F
.406 0 .083 r
.50433 .61794 m .50382 .61881 L .50051 .62006 L F
.298 0 0 r
.50051 .62006 m .50394 .61876 L .50156 .61766 L F
.406 0 .083 r
.50382 .61881 m .5038 .61884 L .50051 .62006 L F
.5038 .61884 m .50313 .61997 L .50164 .62002 L F
.5038 .61884 m .50164 .62002 L .50051 .62006 L F
.787 .552 .581 r
.50156 .61766 m .50394 .61876 L .50396 .61397 L F
.50394 .61876 m .50407 .61882 L .50407 .61869 L F
.50394 .61876 m .50407 .61869 L .50396 .61397 L F
.50407 .61882 m .50461 .61882 L .50396 .61397 L F
.674 .244 .217 r
.50719 .61882 m .50673 .61998 L .50537 .61882 L F
.567 .133 .175 r
.51031 .61955 m .50746 .61815 L .51029 .61746 L F
.51031 .61955 m .50673 .61998 L .50746 .61815 L F
.667 .65 .824 r
.20396 .62152 m .20244 .62344 L .20092 .6204 L F
.815 .678 .712 r
.57258 .51122 m .57646 .50947 L .57275 .50874 L F
.564 .176 .265 r
.24544 .62305 m .24791 .62326 L .24942 .62099 L F
.455 .065 .209 r
.24791 .62326 m .25182 .62074 L .24942 .62099 L F
.687 .289 .289 r
.50107 .5457 m .50304 .54756 L .50453 .5457 L F
.595 .18 .224 r
.50453 .5457 m .50304 .54756 L .50701 .54727 L F
.566 .224 .347 r
.50453 .5457 m .50701 .54727 L .50675 .54558 L F
.332 .114 .425 r
.13901 .5788 m .14096 .57796 L .14145 .5753 L F
.248 0 .294 r
.13833 .5811 m .14096 .57796 L .13901 .5788 L F
.566 .552 .797 r
.73362 .39359 m .73513 .38931 L .73415 .39012 L F
0 0 .162 r
.24414 .67761 m .24251 .68137 L .24314 .67894 L F
.101 0 0 r
.21276 .55427 m .2108 .55498 L .2088 .55501 L F
.39 0 0 r
.21276 .55427 m .21296 .55501 L .2108 .55498 L F
.21276 .55427 m .21489 .555 L .21296 .55501 L F
.737 .979 .917 r
.76982 .40631 m .76864 .4082 L .77118 .40579 L F
.76982 .40631 m .76776 .40779 L .76864 .4082 L F
.033 0 0 r
.17417 .55154 m .1713 .5541 L .17301 .55319 L F
.294 0 .269 r
.17301 .55319 m .17597 .55042 L .17417 .55154 L F
.709 .978 .912 r
.80773 .4332 m .8081 .4324 L .80874 .43286 L F
.558 .821 .995 r
.81043 .43113 m .81146 .43225 L .80874 .43286 L F
.624 .948 .941 r
.80874 .43286 m .8081 .4324 L .81043 .43113 L F
.744 .713 .822 r
.67209 .4322 m .67357 .43383 L .67578 .43285 L F
.437 .178 .422 r
.17676 .57144 m .17376 .57438 L .17535 .57193 L F
.287 0 .054 r
.45975 .61024 m .45859 .60936 L .46111 .60866 L F
.45975 .61024 m .45764 .61079 L .45859 .60936 L F
.827 .762 .791 r
.21604 .71841 m .2177 .71928 L .21886 .71798 L F
0 0 0 r
.21886 .71798 m .22075 .71753 L .21817 .71775 L F
.967 .649 .349 r
.50773 .58148 m .50811 .58483 L .50946 .58543 L F
.855 .41 .003 r
.50906 .58629 m .50946 .58543 L .50811 .58483 L F
.50906 .58629 m .51047 .58732 L .50946 .58543 L F
.844 .977 .675 r
.22142 .55165 m .21934 .5533 L .21924 .55474 L F
.322 0 0 r
.22392 .55148 m .21934 .5533 L .22142 .55165 L F
.694 .676 .828 r
.22142 .55165 m .22548 .55084 L .22392 .55148 L F
.963 .63 .289 r
.51047 .58732 m .51079 .58952 L .51215 .59039 L F
.849 .39 .019 r
.51201 .59208 m .51215 .59039 L .51079 .58952 L F
.51201 .59208 m .51356 .59304 L .51215 .59039 L F
.808 .984 .712 r
.53459 .52167 m .53306 .52335 L .5322 .5247 L F
.419 .818 .603 r
.53306 .52335 m .53004 .52539 L .5322 .5247 L F
.495 .323 .577 r
.48547 .6178 m .48781 .61492 L .48538 .61551 L F
.327 0 .224 r
.49766 .5952 m .49606 .59349 L .49798 .59353 L F
.49766 .5952 m .49516 .59639 L .49606 .59349 L F
.997 .857 .535 r
.58136 .57563 m .58117 .57294 L .57932 .57464 L F
.97 .651 .316 r
.57996 .57753 m .58136 .57563 L .57932 .57464 L F
.57996 .57753 m .58191 .57818 L .58136 .57563 L F
.46 .328 .615 r
.30957 .59324 m .30951 .59664 L .30739 .59726 L F
.468 .373 .665 r
.30975 .59922 m .30739 .59726 L .30951 .59664 L F
.30975 .59922 m .30773 .59988 L .30739 .59726 L F
.622 .764 .947 r
.83965 .40218 m .83699 .40299 L .83601 .4014 L F
.37 .368 .727 r
.41521 .64248 m .4169 .63904 L .41411 .63874 L F
.41521 .64248 m .41722 .64169 L .4169 .63904 L F
.309 .211 .577 r
.41521 .64248 m .4175 .64461 L .41722 .64169 L F
.089 .189 .674 r
.41658 .64514 m .4175 .64461 L .41521 .64248 L F
.4 .057 .264 r
.28221 .62771 m .28171 .62944 L .27928 .62993 L F
.572 .263 .406 r
.28481 .62736 m .28171 .62944 L .28221 .62771 L F
.568 .779 .978 r
.75853 .38306 m .75719 .3852 L .75653 .38322 L F
.75853 .38306 m .76012 .38477 L .75719 .3852 L F
.815 .807 .843 r
.76545 .42432 m .76882 .42409 L .76797 .42372 L F
.664 .522 .681 r
.77399 .42036 m .77135 .42444 L .77138 .42101 L F
0 0 .135 r
.77154 .42236 m .77135 .42444 L .77136 .42364 L F
.77154 .42236 m .77136 .42364 L .77138 .42101 L F
.617 .384 .542 r
.77138 .42101 m .77402 .41801 L .77037 .41774 L F
.77138 .42101 m .77399 .42036 L .77402 .41801 L F
.291 .476 .869 r
.77188 .42003 m .77154 .42236 L .76945 .41948 L F
.77243 .42015 m .77154 .42236 L .77188 .42003 L F
.497 .588 .875 r
.77154 .42236 m .76882 .42409 L .76737 .42083 L F
.77154 .42236 m .77135 .42444 L .76882 .42409 L F
.629 .464 .64 r
.44173 .62092 m .44221 .62371 L .44466 .62077 L F
.992 .836 .587 r
.51339 .59567 m .51522 .59394 L .51356 .59304 L F
.51339 .59567 m .51457 .59649 L .51522 .59394 L F
.492 .286 .528 r
.44161 .64851 m .44187 .65154 L .43915 .65195 L F
.084 .514 .903 r
.44237 .64762 m .44161 .64851 L .44005 .64475 L F
.741 .717 .829 r
.67209 .4322 m .67578 .43285 L .67472 .42941 L F
.722 .706 .835 r
.67472 .42941 m .67578 .43285 L .67853 .43001 L F
0 .565 .729 r
.81165 .44776 m .81522 .44796 L .81436 .44789 L F
.315 .794 .91 r
.81522 .44796 m .81707 .44721 L .81436 .44789 L F
.81522 .44796 m .81787 .44751 L .81707 .44721 L F
.225 0 0 r
.47665 .63137 m .4757 .62995 L .47836 .62968 L F
.47662 .63134 m .47358 .63213 L .4757 .62995 L F
.47632 .63146 m .47358 .63213 L .47662 .63134 L F
.766 .605 .68 r
.47798 .63494 m .47358 .63213 L .47632 .63146 L F
.47668 .63148 m .47632 .63146 L .47665 .63137 L F
.47798 .63494 m .47632 .63146 L .47668 .63148 L F
.656 .354 .447 r
.4731 .63114 m .47324 .63128 L .47555 .63139 L F
.47324 .63128 m .47421 .63228 L .47552 .63141 L F
.47324 .63128 m .47552 .63141 L .47555 .63139 L F
.766 .605 .68 r
.47798 .63494 m .47436 .636 L .47358 .63213 L F
.656 .354 .447 r
.47421 .63228 m .47548 .63359 L .47554 .63176 L F
.47421 .63228 m .47554 .63176 L .47555 .63139 L F
.225 0 0 r
.47665 .63137 m .47632 .63146 L .47662 .63134 L F
.957 .65 .409 r
.53381 .56841 m .53512 .56664 L .53379 .56563 L F
.53381 .56841 m .53502 .56902 L .53512 .56664 L F
0 .545 .823 r
.8026 .4048 m .80606 .4057 L .80476 .4052 L F
.018 .564 .836 r
.80476 .4052 m .80606 .4057 L .80824 .40603 L F
.528 .489 .756 r
.27717 .56579 m .27606 .57027 L .27543 .56805 L F
.151 .378 .83 r
.27606 .57027 m .27673 .56889 L .27543 .56805 L F
.27606 .57027 m .27856 .57192 L .27673 .56889 L F
.874 .621 .554 r
.57627 .51692 m .57831 .51516 L .57623 .51448 L F
.57627 .51692 m .57985 .51831 L .57831 .51516 L F
.714 .588 .714 r
.77037 .41774 m .77402 .41801 L .77237 .41527 L F
.674 .185 0 r
.51266 .55833 m .51255 .55869 L .5101 .55633 L F
.51266 .55833 m .51377 .55981 L .51255 .55869 L F
.641 .39 .523 r
.45433 .64845 m .45415 .65132 L .45137 .65113 L F
.461 .241 .492 r
.45618 .65065 m .45433 .64845 L .45577 .6482 L F
.45618 .65065 m .45415 .65132 L .45433 .64845 L F
.947 .692 .23 r
.4913 .57476 m .49229 .57783 L .4945 .57569 L F
.4913 .57476 m .49164 .57755 L .49229 .57783 L F
.526 .371 .614 r
.29759 .61205 m .29775 .61465 L .29544 .61513 L F
.565 .349 .546 r
.29775 .61465 m .29513 .61752 L .29544 .61513 L F
.18 0 .23 r
.14145 .5753 m .14308 .5748 L .14387 .57278 L F
.397 .218 .519 r
.14096 .57796 m .14308 .5748 L .14145 .5753 L F
.596 .88 .567 r
.55114 .58482 m .55231 .58332 L .55357 .5841 L F
.575 .554 .794 r
.55503 .58791 m .55114 .58482 L .55357 .5841 L F
.199 .396 .831 r
.43871 .63295 m .43963 .63195 L .43708 .63024 L F
.664 .276 .3 r
.44142 .63358 m .44109 .63511 L .43871 .63295 L F
.122 .272 .745 r
.43871 .63295 m .44109 .63511 L .43963 .63195 L F
.702 .646 .791 r
.65598 .42986 m .65762 .43344 L .65954 .43215 L F
.748 .734 .839 r
.22778 .68519 m .23197 .68554 L .23029 .685 L F
.63 .903 .985 r
.23029 .685 m .23197 .68554 L .23414 .68459 L F
.594 .611 .839 r
.73362 .39359 m .73752 .39652 L .73614 .39304 L F
.652 .695 .877 r
.73752 .39652 m .7392 .39208 L .73614 .39304 L F
.73752 .39652 m .74011 .3956 L .7392 .39208 L F
.618 .648 .858 r
.73752 .39652 m .74102 .3977 L .74011 .3956 L F
.864 .846 .824 r
.57448 .53576 m .57254 .53838 L .5755 .53901 L F
.921 .763 .668 r
.57184 .5409 m .5755 .53901 L .57254 .53838 L F
.57184 .5409 m .57349 .54182 L .5755 .53901 L F
.548 .826 .478 r
.47065 .55944 m .471 .55899 L .47246 .55736 L F
.726 .289 .213 r
.47246 .55736 m .471 .55899 L .47535 .55935 L F
.642 .423 .571 r
.47246 .55736 m .47535 .55935 L .47451 .55742 L F
0 .212 .732 r
.18856 .78202 m .18716 .78498 L .18575 .78234 L F
.18856 .78202 m .18943 .78481 L .18716 .78498 L F
.496 .888 .722 r
.18707 .78533 m .18809 .78494 L .18986 .78375 L F
.18544 .78625 m .187 .78548 L .18707 .78533 L F
0 0 0 r
.18716 .78498 m .18809 .78494 L .18657 .78658 L F
.496 .888 .722 r
.187 .78548 m .18809 .78494 L .18707 .78533 L F
0 0 0 r
.18676 .78604 m .18657 .78658 L .18644 .78688 L F
.18716 .78498 m .18685 .78582 L .18676 .78604 L F
.18685 .78582 m .18657 .78658 L .18676 .78604 L F
.18716 .78498 m .18943 .78481 L .18809 .78494 L F
.654 .64 .823 r
.8252 .42343 m .82625 .42695 L .82505 .42729 L F
.8252 .42343 m .82561 .4244 L .82572 .42384 L F
.584 .596 .83 r
.82557 .42465 m .82662 .42685 L .82625 .42695 L F
.8252 .42343 m .82561 .42441 L .82557 .42465 L F
.82561 .42441 m .82662 .42685 L .82557 .42465 L F
.654 .64 .823 r
.82505 .42712 m .82508 .42712 L .82551 .42488 L F
.82508 .42712 m .82508 .42712 L .82551 .42488 L F
.82551 .42488 m .82508 .42712 L .82572 .42384 L F
.936 .915 .533 r
.82572 .42384 m .82561 .42441 L .8257 .42388 L F
.584 .596 .83 r
.82559 .42437 m .82892 .42623 L .82662 .42685 L F
.358 .551 .905 r
.82685 .42363 m .8252 .42343 L .82572 .42384 L F
0 0 0 r
.82572 .42384 m .82655 .42203 L .82685 .42363 L F
.82572 .42384 m .82573 .42385 L .82574 .4238 L F
.584 .596 .83 r
.8252 .42343 m .82573 .42383 L .82559 .42437 L F
.82573 .42385 m .82892 .42623 L .82559 .42437 L F
.654 .64 .823 r
.8252 .42343 m .82505 .42712 L .82561 .4244 L F
.82505 .42712 m .82505 .42729 L .82508 .42712 L F
.936 .915 .533 r
.8257 .42388 m .82505 .42729 L .82474 .42583 L F
.82561 .42441 m .82505 .42729 L .8257 .42388 L F
0 0 0 r
.82573 .42385 m .82474 .42583 L .82622 .42426 L F
.82572 .42384 m .8257 .42388 L .82573 .42385 L F
.8257 .42388 m .82474 .42583 L .82573 .42385 L F
.584 .596 .83 r
.82573 .42383 m .82574 .42383 L .82573 .42385 L F
.82574 .42383 m .82892 .42623 L .82573 .42385 L F
.358 .551 .905 r
.82685 .42363 m .82892 .42623 L .82573 .42383 L F
0 0 0 r
.82574 .4238 m .82574 .42381 L .82576 .42375 L F
.358 .551 .905 r
.82586 .42351 m .82573 .42383 L .8252 .42343 L F
.82685 .42363 m .82573 .42383 L .82586 .42351 L F
0 0 0 r
.82576 .42375 m .82622 .42426 L .82655 .42203 L F
.82574 .42381 m .82622 .42426 L .82576 .42375 L F
.82573 .42385 m .82622 .42426 L .82574 .4238 L F
.29 .757 .943 r
.82892 .42623 m .82474 .42583 L .82621 .42692 L F
.82662 .42685 m .82621 .42692 L .82625 .42695 L F
.82892 .42623 m .82621 .42692 L .82662 .42685 L F
.606 .868 .992 r
.82505 .42729 m .82625 .42695 L .82474 .42583 L F
0 0 .1 r
.45808 .5764 m .45751 .5756 L .4596 .57481 L F
.45808 .5764 m .45721 .57813 L .45751 .5756 L F
.105 0 0 r
.43324 .66372 m .42966 .66595 L .42918 .66363 L F
.932 .714 .585 r
.41758 .64703 m .41983 .64558 L .41985 .64406 L F
.41758 .64703 m .41933 .6482 L .41983 .64558 L F
.499 .206 .399 r
.25929 .61172 m .26168 .61137 L .2622 .60902 L F
.417 .133 .372 r
.2622 .60902 m .26402 .61079 L .26467 .60825 L F
.2622 .60902 m .26168 .61137 L .26402 .61079 L F
.84 .649 .644 r
.57592 .55402 m .57934 .55453 L .57804 .55105 L F
.807 .645 .681 r
.57592 .55402 m .57914 .557 L .57934 .55453 L F
.289 .021 .322 r
.47053 .60558 m .47188 .60764 L .47294 .60533 L F
.47053 .60558 m .4696 .60886 L .47188 .60764 L F
.837 .856 .859 r
.76379 .39997 m .75977 .40152 L .76299 .3989 L F
0 .401 .83 r
.84505 .40329 m .84318 .40306 L .84207 .40193 L F
0 .413 .839 r
.84378 .40211 m .84505 .40329 L .84466 .40311 L F
.84378 .40211 m .84466 .40311 L .84207 .40193 L F
0 0 .434 r
.84153 .40015 m .84316 .40075 L .84378 .40211 L F
.862 .884 .852 r
.84284 .40104 m .84378 .40211 L .84316 .40075 L F
0 .413 .839 r
.84378 .40211 m .84207 .40193 L .84153 .40015 L F
.862 .884 .852 r
.84076 .40295 m .84378 .40211 L .84284 .40104 L F
.859 .869 .845 r
.84378 .40211 m .84505 .40329 L .84378 .40211 L F
0 .401 .83 r
.84505 .40329 m .84633 .40447 L .84318 .40306 L F
.859 .869 .845 r
.84176 .40452 m .84505 .40329 L .84378 .40211 L F
0 .401 .83 r
.84505 .40329 m .84642 .40451 L .84633 .40447 L F
.622 .838 .983 r
.81767 .43207 m .81504 .433 L .81408 .43178 L F
.444 .476 .799 r
.74534 .38649 m .74603 .38311 L .74368 .38367 L F
.74534 .38649 m .74918 .3879 L .74603 .38311 L F
.462 .81 .998 r
.23954 .53651 m .24165 .53607 L .24347 .53696 L F
.32 .757 .968 r
.24165 .53607 m .24563 .53658 L .24347 .53696 L F
.903 .786 .721 r
.18395 .76336 m .18592 .76434 L .18715 .76162 L F
0 0 .325 r
.8444 .41823 m .84456 .42065 L .8444 .42002 L F
.8444 .41823 m .8444 .42002 L .84378 .41764 L F
.8444 .41823 m .84378 .41764 L .84279 .41855 L F
.634 .889 .987 r
.84185 .4182 m .8444 .41722 L .8444 .41823 L F
.8444 .41722 m .84488 .41704 L .8444 .41823 L F
0 0 0 r
.53905 .51502 m .54081 .51403 L .54156 .51212 L F
.218 0 .048 r
.54156 .51212 m .54292 .51327 L .54377 .51117 L F
.54156 .51212 m .54081 .51403 L .54292 .51327 L F
.293 0 .081 r
.16951 .55586 m .17301 .55319 L .1713 .5541 L F
.638 .308 .397 r
.26813 .63879 m .26418 .64112 L .26589 .63922 L F
.513 .419 .686 r
.31268 .58339 m .31127 .58761 L .31075 .58731 L F
.596 .898 .987 r
.23383 .69377 m .2308 .69447 L .22944 .69391 L F
.558 .551 .802 r
.74102 .3977 m .74258 .39483 L .74011 .3956 L F
.74102 .3977 m .74404 .39872 L .74258 .39483 L F
.914 .788 .708 r
.56733 .53959 m .56645 .54168 L .56549 .53842 L F
.714 .588 .714 r
.77037 .41774 m .77266 .41428 L .77034 .41544 L F
.77037 .41774 m .77237 .41527 L .77266 .41428 L F
.12 0 0 r
.53523 .51699 m .53766 .51637 L .53905 .51502 L F
0 0 0 r
.53905 .51502 m .53976 .51521 L .54081 .51403 L F
.53905 .51502 m .53766 .51637 L .53976 .51521 L F
.488 .266 .503 r
.29038 .62115 m .29012 .62348 L .28783 .62397 L F
.501 .305 .546 r
.2928 .61813 m .29261 .62065 L .29038 .62115 L F
.489 .269 .506 r
.29261 .62065 m .29012 .62348 L .29038 .62115 L F
.316 .646 .968 r
.81253 .39785 m .81115 .39888 L .81009 .39769 L F
.81253 .39785 m .81353 .39918 L .81115 .39888 L F
.601 .302 .434 r
.66146 .41239 m .66271 .41463 L .66435 .41371 L F
.729 .31 .251 r
.67199 .41876 m .67609 .41992 L .67552 .4182 L F
.782 .343 .208 r
.67552 .4182 m .67609 .41992 L .67943 .42075 L F
.78 .571 .616 r
.43129 .6479 m .43519 .64887 L .43554 .64706 L F
.771 .456 .454 r
.57765 .52303 m .58103 .52166 L .57757 .52068 L F
.57765 .52303 m .58156 .5238 L .58103 .52166 L F
.596 .898 .987 r
.23383 .69377 m .22944 .69391 L .23054 .69252 L F
.436 .628 .934 r
.23358 .69115 m .23383 .69377 L .23054 .69252 L F
.23358 .69115 m .23537 .69337 L .23383 .69377 L F
.383 .208 .517 r
.2354 .69622 m .23383 .69377 L .23537 .69337 L F
.2354 .69622 m .23363 .6971 L .23383 .69377 L F
.452 .184 .416 r
.28947 .62627 m .28783 .62397 L .29012 .62348 L F
.28947 .62627 m .28718 .62681 L .28783 .62397 L F
.843 .719 .727 r
.57627 .51692 m .57757 .52068 L .57985 .51831 L F
.08 .038 .504 r
.53469 .51956 m .53459 .52167 L .53649 .5197 L F
.53469 .51956 m .53306 .52335 L .53459 .52167 L F
.643 .087 0 r
.49571 .56705 m .4978 .56887 L .49865 .56896 L F
.934 .649 .179 r
.4982 .57079 m .49865 .56896 L .4978 .56887 L F
.4982 .57079 m .49911 .57248 L .49865 .56896 L F
.788 .545 .568 r
.56907 .50792 m .57129 .50605 L .5687 .50575 L F
.474 .459 .761 r
.78534 .43159 m .78379 .43419 L .78312 .43249 L F
.78534 .43159 m .78741 .4357 L .78379 .43419 L F
.961 .719 .526 r
.21411 .71703 m .21604 .71841 L .21607 .71523 L F
.799 .978 .902 r
.21607 .71523 m .21192 .7172 L .21411 .71703 L F
.565 .294 .464 r
.21607 .71523 m .21817 .71775 L .21946 .71712 L F
.408 .466 .809 r
.75436 .41438 m .75517 .41039 L .75274 .41128 L F
.75436 .41438 m .75642 .41419 L .75517 .41039 L F
.596 .59 .816 r
.75436 .41438 m .7583 .41686 L .75642 .41419 L F
.548 .789 .988 r
.78374 .39075 m .78687 .39137 L .7862 .3894 L F
.181 .243 .692 r
.78687 .39137 m .78876 .38895 L .7862 .3894 L F
.78687 .39137 m .78915 .39065 L .78876 .38895 L F
.78687 .39137 m .78773 .39317 L .78925 .39081 L F
.845 .49 .381 r
.78917 .39071 m .79086 .39254 L .78876 .38895 L F
.658 .548 .718 r
.7895 .39112 m .79086 .39254 L .78941 .39057 L F
.79004 .39443 m .79086 .39254 L .7895 .39112 L F
.845 .49 .381 r
.78937 .39158 m .79042 .39226 L .7895 .39112 L F
.291 .392 .793 r
.78773 .39317 m .7895 .39112 L .78925 .39081 L F
.845 .49 .381 r
.78919 .3908 m .7895 .39112 L .78917 .39071 L F
.78937 .39158 m .7895 .39112 L .78919 .3908 L F
.79042 .39226 m .79086 .39254 L .78917 .39071 L F
.291 .392 .793 r
.78773 .39317 m .79004 .39443 L .7895 .39112 L F
.78925 .39081 m .7895 .39112 L .78941 .39057 L F
.181 .243 .692 r
.78915 .39065 m .78925 .39081 L .78941 .39057 L F
.78687 .39137 m .78925 .39081 L .78915 .39065 L F
.845 .49 .381 r
.78756 .39042 m .78937 .39158 L .78915 .39065 L F
.78842 .38937 m .78915 .39065 L .78876 .38895 L F
.78756 .39042 m .78915 .39065 L .78842 .38937 L F
.181 .243 .692 r
.78915 .39065 m .78941 .39057 L .78876 .38895 L F
.598 .412 .601 r
.30487 .60539 m .30244 .6082 L .30283 .606 L F
.619 .292 .395 r
.55877 .50807 m .56263 .50575 L .55878 .50546 L F
.55877 .50807 m .56158 .50829 L .56263 .50575 L F
.712 .393 .436 r
.56263 .50575 m .56158 .50829 L .56479 .50823 L F
.423 .85 .949 r
.22876 .62815 m .22416 .62843 L .22648 .62801 L F
.331 .814 .812 r
.22874 .62776 m .22876 .62815 L .22648 .62801 L F
.22874 .62776 m .23092 .62747 L .22876 .62815 L F
.104 0 0 r
.14952 .56966 m .14975 .57072 L .15122 .56829 L F
.14952 .56966 m .14762 .57133 L .14975 .57072 L F
.675 .65 .817 r
.44076 .61542 m .44085 .61682 L .44334 .61474 L F
.461 0 0 r
.2086 .53791 m .21063 .53846 L .2121 .53802 L F
.683 .32 .352 r
.4241 .65938 m .42743 .65964 L .42784 .65779 L F
.539 .185 .315 r
.42784 .65779 m .42743 .65964 L .43007 .65918 L F
.529 .278 .479 r
.43642 .65401 m .43866 .65444 L .43915 .65195 L F
.43915 .65195 m .43866 .65444 L .43642 .65401 L F
.543 .596 .857 r
.43915 .65195 m .43967 .64764 L .4374 .64787 L F
.43915 .65195 m .44187 .65154 L .43967 .64764 L F
.417 .178 .442 r
.43915 .65195 m .44119 .6534 L .44187 .65154 L F
.43915 .65195 m .43866 .65444 L .44119 .6534 L F
.44119 .6534 m .43915 .65195 L .44187 .65154 L F
.44119 .6534 m .43866 .65444 L .43915 .65195 L F
.214 .036 .41 r
.44577 .63185 m .44434 .63048 L .44629 .63003 L F
.44577 .63185 m .44414 .63297 L .44434 .63048 L F
.496 .84 .997 r
.25375 .55051 m .25033 .5495 L .24797 .55011 L F
.303 .652 .97 r
.2548 .54993 m .25489 .54843 L .2526 .54903 L F
0 0 0 r
.25489 .54843 m .25472 .54848 L .2526 .54903 L F
.402 .787 .99 r
.25375 .55051 m .2526 .54903 L .25053 .54956 L F
.25375 .55051 m .2548 .54993 L .2526 .54903 L F
0 0 0 r
.25472 .54848 m .25052 .54985 L .2526 .54903 L F
.402 .787 .99 r
.25053 .54956 m .2526 .54903 L .25033 .5495 L F
.975 .796 .376 r
.51656 .61433 m .51695 .61774 L .51766 .61539 L F
0 0 0 r
.23092 .62747 m .23309 .62719 L .23477 .62686 L F
.08 0 0 r
.23548 .62696 m .23477 .62686 L .23309 .62719 L F
.23548 .62696 m .23701 .62707 L .23477 .62686 L F
.757 .734 .831 r
.41319 .62944 m .41335 .63148 L .41107 .62941 L F
.757 .733 .831 r
.41107 .62941 m .41319 .63249 L .41319 .62944 L F
.733 .219 0 r
.41581 .63512 m .41319 .63249 L .4132 .63511 L F
.769 .641 .72 r
.46383 .56589 m .46676 .56338 L .4645 .56404 L F
.105 0 0 r
.43312 .6638 m .43175 .66533 L .42966 .66595 L F
.649 .511 .68 r
.43284 .66919 m .42966 .66595 L .43175 .66533 L F
.43284 .66919 m .43022 .66951 L .42966 .66595 L F
.553 .415 .646 r
.42962 .66485 m .4301 .66716 L .43175 .66533 L F
.4301 .66716 m .43018 .66752 L .43175 .66533 L F
.105 0 0 r
.43324 .66372 m .43175 .66533 L .43312 .6638 L F
.753 .394 .375 r
.43324 .66372 m .43578 .66639 L .43175 .66533 L F
.43324 .66372 m .43578 .66639 L .43175 .66533 L F
.462 .628 .925 r
.17834 .63154 m .17908 .62928 L .17704 .62998 L F
.17834 .63154 m .18142 .63211 L .17908 .62928 L F
.464 0 0 r
.54297 .51869 m .54147 .5198 L .53909 .51942 L F
.257 0 0 r
.54538 .51863 m .54147 .5198 L .54297 .51869 L F
.391 .288 .616 r
.26854 .59415 m .27049 .59587 L .27076 .59238 L F
.26854 .59415 m .26871 .59675 L .27049 .59587 L F
.836 .735 .753 r
.75593 .38002 m .75734 .37807 L .75603 .37863 L F
.826 .651 .665 r
.57448 .5479 m .57423 .55053 L .57804 .55105 L F
.827 .629 .635 r
.57423 .55053 m .57592 .55402 L .57804 .55105 L F
0 0 .042 r
.46217 .62049 m .46156 .62263 L .46081 .62276 L F
.403 .157 .423 r
.46156 .62263 m .45964 .62529 L .46081 .62276 L F
.75 .646 .746 r
.50111 .61179 m .50126 .6146 L .50396 .61397 L F
.787 .552 .581 r
.50156 .61766 m .50396 .61397 L .50126 .6146 L F
.422 .862 .914 r
.50314 .61104 m .50619 .61021 L .50539 .60881 L F
.50314 .61104 m .50163 .6109 L .50619 .61021 L F
0 0 0 r
.50396 .61397 m .50619 .61021 L .50163 .6109 L F
.50396 .61397 m .50481 .61375 L .50619 .61021 L F
0 0 .37 r
.50396 .61397 m .50528 .61539 L .50481 .61375 L F
.732 .656 .774 r
.8288 .43902 m .82677 .44021 L .82493 .43633 L F
.686 .549 .693 r
.8288 .43902 m .82702 .4431 L .82677 .44021 L F
.674 .132 0 r
.24115 .64335 m .23919 .64315 L .23882 .64335 L F
.24115 .64335 m .24405 .64576 L .23919 .64315 L F
.44 .234 .502 r
.29513 .61752 m .29261 .62065 L .2928 .61813 L F
.64 .372 .496 r
.7498 .38347 m .7472 .381 L .74603 .38311 L F
.7498 .38347 m .74978 .38116 L .7472 .381 L F
.781 .688 .761 r
.43632 .65955 m .44025 .65742 L .43795 .66044 L F
.537 .366 .596 r
.44025 .65742 m .44039 .66033 L .43795 .66044 L F
.53 .326 .548 r
.44039 .66033 m .43803 .6633 L .43795 .66044 L F
.636 .492 .669 r
.48473 .56719 m .4843 .56946 L .48132 .56955 L F
.487 .209 .417 r
.48128 .57208 m .4843 .56946 L .48132 .56955 L F
.636 .492 .669 r
.48132 .56955 m .4843 .56946 L .48473 .56719 L F
.487 .209 .417 r
.4843 .56946 m .48128 .57208 L .48132 .56955 L F
.658 .774 .935 r
.55624 .58336 m .55742 .5848 L .55357 .5841 L F
.77 .654 .734 r
.55742 .5848 m .55503 .58791 L .55357 .5841 L F
.911 .819 .743 r
.55664 .58144 m .55742 .5848 L .55624 .58336 L F
.089 .121 .6 r
.45752 .62812 m .45828 .63081 L .45687 .62732 L F
0 0 0 r
.18553 .54601 m .18246 .54781 L .18454 .54679 L F
.18553 .54601 m .18671 .54592 L .18746 .54525 L F
.18553 .54601 m .18454 .54679 L .18671 .54592 L F
0 0 .274 r
.49034 .59742 m .49144 .59814 L .49425 .59599 L F
.58 .007 0 r
.49283 .59916 m .4912 .59865 L .49053 .5977 L F
.49043 .59749 m .49053 .5977 L .49034 .59742 L F
.49283 .59916 m .49053 .5977 L .49043 .59749 L F
.696 .678 .828 r
.4912 .59865 m .4903 .60161 L .48838 .60079 L F
0 0 0 r
.48838 .60079 m .49078 .59985 L .49113 .59893 L F
0 0 .274 r
.49034 .59742 m .4912 .59865 L .49144 .59814 L F
.696 .678 .828 r
.4912 .59865 m .48838 .60079 L .49144 .59814 L F
0 0 0 r
.49095 .59856 m .49113 .59893 L .49144 .59814 L F
.48838 .60079 m .49113 .59893 L .49095 .59856 L F
.9 .51 .273 r
.49641 .5426 m .49699 .54453 L .49847 .54496 L F
.711 .223 .084 r
.49699 .54453 m .50107 .5457 L .49847 .54496 L F
0 0 0 r
.5418 .57162 m .54249 .57188 L .54157 .57256 L F
.5418 .57162 m .54249 .57188 L .54157 .57256 L F
.921 .637 .488 r
.56686 .53429 m .56431 .5322 L .56627 .53299 L F
.219 .286 .72 r
.40718 .60863 m .40944 .61066 L .40774 .61177 L F
0 0 .14 r
.40774 .61177 m .40774 .61169 L .40718 .60863 L F
0 0 0 r
.40774 .61177 m .407 .61374 L .4066 .6137 L F
.689 .756 .26 r
.40774 .61169 m .407 .61374 L .40774 .61177 L F
0 0 0 r
.40944 .61066 m .407 .61374 L .40774 .61177 L F
.779 .379 0 r
.83911 .42376 m .83849 .42306 L .83735 .42047 L F
.745 .337 .277 r
.83911 .42376 m .83776 .42539 L .83849 .42306 L F
.83911 .42376 m .84162 .42618 L .83776 .42539 L F
.269 .346 .758 r
.1756 .62997 m .17574 .62607 L .17405 .62664 L F
.1756 .62997 m .17704 .62998 L .17574 .62607 L F
.602 .689 .904 r
.16125 .59045 m .16095 .59364 L .15929 .59198 L F
.16125 .59045 m .16365 .59339 L .16095 .59364 L F
.987 .814 .584 r
.55226 .60584 m .55298 .60595 L .55507 .60528 L F
.55226 .60584 m .55266 .60706 L .55298 .60595 L F
.833 .574 .548 r
.5769 .56511 m .58038 .56368 L .57717 .56259 L F
.853 .67 .653 r
.57667 .56788 m .57825 .57127 L .58021 .56613 L F
.467 .017 .096 r
.57667 .56788 m .58021 .56613 L .5801 .56625 L F
.833 .574 .548 r
.5769 .56511 m .5801 .56625 L .58038 .56368 L F
.41 .158 .419 r
.47397 .61104 m .47092 .61365 L .47122 .61158 L F
.705 .798 .922 r
.80773 .4332 m .80248 .43462 L .80218 .43185 L F
.719 .753 .879 r
.84501 .41042 m .84592 .40686 L .84382 .40791 L F
.84501 .41042 m .84771 .40808 L .84592 .40686 L F
.613 .88 .99 r
.21489 .555 m .21924 .55474 L .21748 .55437 L F
.663 .937 .967 r
.21934 .5533 m .21748 .55437 L .21924 .55474 L F
.41 .035 .212 r
.47425 .62646 m .47682 .6261 L .47716 .62457 L F
.486 .1 .232 r
.47682 .6261 m .47938 .62591 L .47716 .62457 L F
.488 .098 .227 r
.47716 .62457 m .47938 .62591 L .47981 .62416 L F
.868 .74 .719 r
.24702 .65862 m .24841 .65709 L .24576 .65642 L F
0 .374 .708 r
.25771 .55594 m .25805 .55333 L .2565 .5539 L F
.25771 .55594 m .2565 .55539 L .25805 .55333 L F
.25771 .55594 m .2596 .55663 L .2565 .55539 L F
.799 .457 .408 r
.55915 .52022 m .55524 .51741 L .55914 .51802 L F
.797 .306 .025 r
.49651 .62323 m .49449 .62276 L .49601 .62245 L F
.672 .206 .139 r
.45897 .63154 m .45976 .63021 L .45828 .63081 L F
.45897 .63154 m .46213 .63217 L .45976 .63021 L F
.77 .745 .83 r
.20276 .53922 m .20094 .53991 L .19835 .53845 L F
.797 .696 .753 r
.19835 .53845 m .19994 .542 L .20276 .53922 L F
.422 .139 .377 r
.19994 .542 m .20214 .54152 L .20276 .53922 L F
.244 0 .304 r
.20276 .53922 m .204 .54058 L .20489 .53884 L F
.20276 .53922 m .20214 .54152 L .204 .54058 L F
.92 .712 .605 r
.56464 .5272 m .56246 .52877 L .56319 .5263 L F
.56464 .5272 m .56432 .52978 L .56246 .52877 L F
.494 .38 .653 r
.31493 .56272 m .31512 .56749 L .31302 .56738 L F
.477 .439 .736 r
.31512 .56749 m .31376 .56935 L .31302 .56738 L F
.858 .644 .612 r
.7619 .39258 m .76498 .39077 L .76359 .38929 L F
.7619 .39258 m .76571 .39277 L .76498 .39077 L F
.887 .79 .748 r
.76498 .39077 m .76422 .38698 L .76359 .38929 L F
.619 .269 .354 r
.7675 .39241 m .76732 .39074 L .76498 .39077 L F
.732 .656 .774 r
.8288 .43902 m .82493 .43633 L .82769 .43586 L F
.528 .915 .787 r
.82919 .44171 m .82702 .4431 L .8288 .43902 L F
.74 .734 .846 r
.83149 .4362 m .8288 .43902 L .82769 .43586 L F
.741 .736 .847 r
.83149 .4362 m .83132 .43792 L .8288 .43902 L F
.414 .17 .432 r
.83132 .43792 m .82919 .44171 L .8288 .43902 L F
.33 .63 .961 r
.2548 .54993 m .256 .55135 L .25653 .5499 L F
0 .208 .725 r
.256 .55135 m .25805 .55333 L .25653 .5499 L F
.338 .283 .648 r
.2565 .5539 m .25805 .55333 L .256 .55135 L F
.476 .17 .367 r
.48781 .61492 m .49057 .61481 L .49013 .61303 L F
.531 .203 .357 r
.49013 .61303 m .49057 .61481 L .49297 .61407 L F
.508 .228 .424 r
.30968 .60172 m .30773 .59988 L .30975 .59922 L F
.30968 .60172 m .30725 .60217 L .30773 .59988 L F
.847 .44 0 r
.2275 .70332 m .22731 .70362 L .22666 .70221 L F
0 0 0 r
.23021 .70203 m .22731 .70362 L .2275 .70332 L F
.266 .568 .937 r
.21305 .62516 m .21271 .62663 L .21048 .62457 L F
.131 .417 .862 r
.21415 .62698 m .21271 .62663 L .21305 .62516 L F
.465 .657 .944 r
.21846 .62901 m .21628 .62923 L .21415 .62698 L F
.847 .515 .424 r
.503 .5901 m .49972 .58724 L .5014 .58851 L F
.421 .477 .812 r
.78153 .44169 m .78281 .44526 L .78467 .44303 L F
.496 .589 .877 r
.78467 .44303 m .78281 .44526 L .78526 .44501 L F
.299 .364 .762 r
.44221 .62371 m .44368 .62752 L .44488 .62625 L F
.306 0 0 r
.44368 .62752 m .44533 .62834 L .44488 .62625 L F
.44368 .62752 m .44208 .62908 L .44533 .62834 L F
0 0 0 r
.21179 .72239 m .21146 .72273 L .20997 .72313 L F
.21179 .72239 m .21346 .72085 L .21146 .72273 L F
.311 .526 .901 r
.20745 .64422 m .20681 .64122 L .2046 .64126 L F
.20745 .64422 m .21003 .64524 L .20681 .64122 L F
.785 .284 0 r
.50578 .55488 m .50271 .553 L .50424 .55397 L F
.788 .545 .568 r
.56907 .50792 m .57107 .50811 L .57129 .50605 L F
0 0 0 r
.22588 .55088 m .22548 .55084 L .22748 .55062 L F
.22588 .55088 m .22392 .55148 L .22548 .55084 L F
.616 .408 .577 r
.45159 .57863 m .45171 .58142 L .44901 .58109 L F
.433 .268 .557 r
.4539 .5801 m .45159 .57863 L .45411 .57969 L F
.535 .243 .418 r
.45721 .57813 m .45636 .58019 L .4539 .5801 L F
.188 .685 .916 r
.4539 .5801 m .45636 .58019 L .45556 .58006 L F
.433 .268 .557 r
.4539 .5801 m .45165 .58014 L .45159 .57863 L F
.535 .243 .418 r
.45721 .57813 m .4539 .5801 L .45411 .57969 L F
.188 .685 .916 r
.4539 .5801 m .45556 .58006 L .45248 .57957 L F
.433 .268 .557 r
.4539 .5801 m .45171 .58142 L .45165 .58014 L F
.966 .839 .666 r
.23258 .68398 m .23414 .68459 L .23498 .68201 L F
.23258 .68398 m .23498 .68201 L .23678 .68397 L F
.373 .092 .352 r
.4827 .62075 m .48516 .62061 L .48547 .6178 L F
.495 .323 .577 r
.48547 .6178 m .48813 .61717 L .48781 .61492 L F
.411 .122 .361 r
.48547 .6178 m .48648 .62007 L .48813 .61717 L F
.48547 .6178 m .48516 .62061 L .48648 .62007 L F
.413 0 0 r
.76019 .41449 m .75642 .41419 L .7583 .41686 L F
.827 .818 .84 r
.7628 .39513 m .76571 .39277 L .7619 .39258 L F
.477 .439 .736 r
.31512 .56749 m .31576 .56878 L .31376 .56935 L F
.426 .318 .628 r
.31576 .56878 m .31414 .57182 L .31376 .56935 L F
.516 .766 .987 r
.2707 .59034 m .27256 .58926 L .26964 .58792 L F
.2707 .59034 m .27409 .59069 L .27256 .58926 L F
.264 0 0 r
.27076 .59238 m .27409 .59069 L .2707 .59034 L F
.001 0 .222 r
.15817 .58688 m .1565 .58941 L .15628 .58685 L F
.649 .422 .561 r
.48093 .62711 m .48099 .6299 L .47836 .62968 L F
.646 .584 .77 r
.48499 .62666 m .48093 .62711 L .47981 .62416 L F
.644 .442 .595 r
.48499 .62666 m .48099 .6299 L .48093 .62711 L F
.157 0 0 r
.20773 .72876 m .20664 .72878 L .20462 .7295 L F
.428 .479 .81 r
.4945 .57569 m .49586 .57964 L .49743 .57743 L F
.235 .232 .652 r
.49586 .57964 m .49809 .57996 L .49743 .57743 L F
.49586 .57964 m .49632 .58153 L .49809 .57996 L F
.128 .639 .896 r
.24768 .53603 m .25192 .53686 L .24975 .53731 L F
.783 .287 0 r
.51872 .56629 m .51915 .56816 L .51696 .56575 L F
.51872 .56629 m .52058 .56891 L .51915 .56816 L F
.812 .335 .067 r
.52246 .56948 m .52058 .56891 L .51872 .56629 L F
.107 .076 .537 r
.24618 .67451 m .24458 .67256 L .24619 .67162 L F
.24618 .67451 m .2447 .67554 L .24458 .67256 L F
.333 0 0 r
.17825 .54981 m .18062 .54953 L .18246 .54781 L F
.349 0 .113 r
.18062 .54953 m .18454 .54679 L .18246 .54781 L F
.603 .794 .973 r
.1823 .63641 m .18564 .63724 L .18471 .63557 L F
.425 .647 .95 r
.18564 .63724 m .18663 .63551 L .18471 .63557 L F
.18564 .63724 m .18841 .6379 L .18663 .63551 L F
.976 .675 .37 r
.52246 .56948 m .52128 .56975 L .52058 .56891 L F
.52246 .56948 m .52267 .57169 L .52128 .56975 L F
.921 .637 .488 r
.56686 .53429 m .56444 .53493 L .56431 .5322 L F
.955 .782 .629 r
.56686 .53429 m .56549 .53842 L .56444 .53493 L F
.95 .632 .393 r
.50587 .58175 m .50773 .58148 L .50634 .58065 L F
.50587 .58175 m .50811 .58483 L .50773 .58148 L F
.987 .72 .413 r
.84642 .40451 m .84771 .40808 L .84772 .4057 L F
.482 .191 .395 r
.27658 .63269 m .27349 .63604 L .27114 .63641 L F
.507 .246 .454 r
.27675 .63243 m .27349 .63604 L .27658 .63269 L F
.586 .944 .901 r
.18438 .78797 m .18293 .79007 L .18285 .79012 L F
.18438 .78797 m .18368 .78697 L .18293 .79007 L F
.18438 .78797 m .18644 .78688 L .18368 .78697 L F
.566 .552 .797 r
.73362 .39359 m .73614 .39304 L .73513 .38931 L F
.329 .783 .64 r
.49757 .58931 m .4967 .58974 L .49617 .59003 L F
0 0 .516 r
.4967 .58974 m .49798 .59353 L .49617 .59003 L F
.55 .406 .638 r
.6567 .41794 m .65957 .41728 L .65927 .41552 L F
.545 .391 .622 r
.6567 .41794 m .65963 .41985 L .65957 .41728 L F
.6567 .41794 m .65707 .4207 L .65963 .41985 L F
.808 .964 .908 r
.82345 .4446 m .82423 .44553 L .82571 .4439 L F
.39 .112 .367 r
.27402 .57582 m .27322 .57781 L .27627 .57526 L F
.405 .174 .448 r
.30014 .60886 m .29964 .61168 L .29759 .61205 L F
.453 .216 .464 r
.30201 .61108 m .30014 .60886 L .30244 .6082 L F
.30201 .61108 m .29964 .61168 L .30014 .60886 L F
.802 .775 .829 r
.48473 .56719 m .48545 .56727 L .48496 .56248 L F
.468 .334 .615 r
.48473 .56719 m .48628 .5687 L .48545 .56727 L F
.311 .397 .789 r
.48496 .56248 m .48545 .56727 L .48706 .56282 L F
.523 .533 .808 r
.48628 .5687 m .48706 .56282 L .48545 .56727 L F
0 0 0 r
.18903 .56339 m .18776 .56552 L .18619 .56586 L F
.213 0 .278 r
.19084 .56254 m .18903 .56339 L .19151 .56035 L F
0 0 0 r
.18927 .5641 m .18903 .56339 L .19084 .56254 L F
.18927 .5641 m .18776 .56552 L .18903 .56339 L F
.383 .702 .984 r
.77518 .39278 m .77737 .39287 L .77636 .39162 L F
.77518 .39278 m .77636 .39162 L .77394 .39171 L F
.77518 .39278 m .77737 .39287 L .77636 .39162 L F
.59 .019 0 r
.4669 .61993 m .466 .61984 L .46337 .61783 L F
.049 .615 .759 r
.4687 .61991 m .4669 .61993 L .46962 .61792 L F
.4687 .61991 m .466 .61984 L .4669 .61993 L F
.856 .789 .784 r
.57553 .52592 m .57824 .52725 L .57765 .52303 L F
.986 .748 .357 r
.57553 .52592 m .57648 .52966 L .57824 .52725 L F
.732 .707 .827 r
.57765 .52303 m .57824 .52725 L .58156 .5238 L F
.264 0 0 r
.27076 .59238 m .2724 .59227 L .27409 .59069 L F
.539 .481 .739 r
.2724 .59227 m .27256 .58926 L .27409 .59069 L F
.69 .693 .848 r
.66588 .43232 m .66964 .43311 L .66844 .43103 L F
.688 .692 .849 r
.66844 .43103 m .66964 .43311 L .67209 .4322 L F
.621 .262 .339 r
.50675 .54558 m .51071 .54669 L .51077 .5451 L F
.50675 .54558 m .50701 .54727 L .51071 .54669 L F
.567 .274 .43 r
.44414 .63297 m .44109 .63511 L .44142 .63358 L F
.147 .683 .846 r
.23413 .55075 m .23192 .55048 L .22965 .55057 L F
.168 0 0 r
.23413 .55075 m .2358 .55106 L .23192 .55048 L F
.702 .646 .791 r
.65598 .42986 m .65954 .43215 L .65855 .42881 L F
.599 .658 .879 r
.65954 .43215 m .66102 .42846 L .65855 .42881 L F
.65954 .43215 m .6621 .43162 L .66102 .42846 L F
0 0 .505 r
.5279 .52624 m .52745 .52234 L .52713 .52445 L F
.219 0 .253 r
.14308 .5748 m .14558 .572 L .14387 .57278 L F
.498 0 0 r
.51187 .54616 m .51077 .5451 L .51071 .54669 L F
0 0 0 r
.51071 .54669 m .50992 .54752 L .51187 .54616 L F
.50992 .54752 m .51039 .54736 L .51187 .54616 L F
.661 .911 .594 r
.51187 .54616 m .51039 .54736 L .51153 .54608 L F
.51187 .54616 m .51153 .54608 L .51286 .54459 L F
.498 0 0 r
.51187 .54616 m .51332 .54719 L .51215 .54623 L F
.51187 .54616 m .51215 .54623 L .51077 .5451 L F
.727 .413 .448 r
.49619 .62669 m .49951 .62673 L .49945 .62409 L F
.686 .38 .451 r
.49951 .62673 m .50065 .62735 L .49945 .62409 L F
.49945 .62409 m .50065 .62735 L .49951 .62673 L F
.194 .212 .651 r
.4132 .63511 m .41535 .63677 L .41581 .63512 L F
.4132 .63511 m .41411 .63874 L .41535 .63677 L F
.552 .784 .985 r
.21894 .64399 m .22246 .64461 L .22114 .6436 L F
.505 .806 .999 r
.22114 .6436 m .22246 .64461 L .22511 .6439 L F
.544 .64 .896 r
.24097 .65712 m .24437 .65895 L .24344 .65705 L F
.646 .666 .855 r
.24437 .65895 m .24576 .65642 L .24344 .65705 L F
.24437 .65895 m .24702 .65862 L .24576 .65642 L F
.646 .761 .933 r
.8287 .41064 m .82506 .40971 L .82602 .4115 L F
.582 .297 .45 r
.45252 .5716 m .45508 .57149 L .45274 .56947 L F
.482 .314 .576 r
.45274 .56947 m .45508 .57149 L .45507 .56884 L F
.45274 .56947 m .45508 .57149 L .45507 .56884 L F
.966 .738 .543 r
.56394 .54771 m .56525 .551 L .56364 .5496 L F
.848 .744 .749 r
.56505 .55338 m .56364 .5496 L .56525 .551 L F
.945 .594 .201 r
.47722 .5589 m .47451 .55742 L .47535 .55935 L F
.364 .096 .368 r
.1935 .55965 m .19084 .56254 L .19151 .56035 L F
.578 .473 .699 r
.29964 .61168 m .29775 .61465 L .29759 .61205 L F
.414 .17 .432 r
.83132 .43792 m .8316 .4406 L .82919 .44171 L F
.678 .634 .798 r
.83393 .43514 m .83132 .43792 L .83149 .4362 L F
.83393 .43514 m .83416 .4376 L .83132 .43792 L F
.138 0 .055 r
.83416 .4376 m .8316 .4406 L .83132 .43792 L F
.985 .88 .64 r
.56933 .60043 m .56992 .59974 L .56889 .59883 L F
.71 .9 .964 r
.56992 .59974 m .57082 .59725 L .56889 .59883 L F
.56992 .59974 m .57185 .59866 L .57082 .59725 L F
.459 .624 .923 r
.16323 .6203 m .16363 .62127 L .16579 .62105 L F
.395 .3 .629 r
.49722 .62807 m .49951 .62673 L .49619 .62669 L F
.49722 .62807 m .4994 .62922 L .49951 .62673 L F
.49951 .62673 m .4994 .62922 L .49722 .62807 L F
.926 .695 .569 r
.55931 .56906 m .56095 .57251 L .55919 .57161 L F
.911 .733 .648 r
.56095 .57251 m .55771 .5748 L .55919 .57161 L F
.56095 .57251 m .56048 .57503 L .55771 .5748 L F
0 0 .506 r
.52551 .57547 m .52755 .57848 L .52677 .57713 L F
.878 .45 .047 r
.52755 .57848 m .52692 .57928 L .52677 .57713 L F
.52755 .57848 m .52865 .58138 L .52692 .57928 L F
.722 .751 .874 r
.66435 .41371 m .66755 .41503 L .66681 .41451 L F
.758 .452 .466 r
.66465 .41637 m .66755 .41503 L .66435 .41371 L F
.66465 .41637 m .6679 .41725 L .66755 .41503 L F
.839 .51 .431 r
.66755 .41503 m .6679 .41725 L .66982 .41737 L F
.296 .702 .975 r
.28431 .53881 m .28572 .53838 L .288 .53979 L F
.066 .587 .875 r
.28572 .53838 m .2906 .53977 L .288 .53979 L F
.711 .983 .894 r
.5638 .60496 m .5677 .60321 L .56647 .60239 L F
.895 .946 .833 r
.56647 .60239 m .5677 .60321 L .56933 .60043 L F
.718 .598 .722 r
.24868 .64819 m .25066 .64575 L .24866 .64578 L F
.675 .536 .687 r
.24868 .64819 m .25132 .64788 L .25066 .64575 L F
0 0 0 r
.24972 .64712 m .25066 .64575 L .24868 .64819 L F
.661 .296 .343 r
.25058 .65277 m .24854 .65276 L .24872 .65435 L F
.25202 .65155 m .25125 .65181 L .25058 .65277 L F
.25125 .65181 m .24854 .65276 L .25058 .65277 L F
.339 .16 .486 r
.24872 .65435 m .24854 .65276 L .24942 .65291 L F
.782 .669 .738 r
.24942 .65291 m .25114 .65201 L .24872 .65435 L F
.25114 .65201 m .25058 .65277 L .24872 .65435 L F
.339 .16 .486 r
.24872 .65435 m .24942 .65291 L .2505 .6531 L F
.782 .669 .738 r
.24833 .65348 m .24942 .65291 L .24872 .65435 L F
.25114 .65201 m .25202 .65155 L .25058 .65277 L F
.661 .296 .343 r
.25202 .65155 m .2505 .6531 L .24942 .65291 L F
.25202 .65155 m .24942 .65291 L .24854 .65276 L F
.782 .669 .738 r
.24776 .65223 m .25202 .65155 L .24833 .65348 L F
.24675 .65001 m .25202 .65155 L .24776 .65223 L F
.661 .296 .343 r
.25202 .65155 m .25198 .65117 L .25164 .65161 L F
.25202 .65155 m .25164 .65161 L .2505 .6531 L F
.787 .401 .324 r
.24868 .64819 m .25169 .65121 L .24675 .65001 L F
.25169 .65121 m .25202 .65155 L .25157 .65142 L F
.236 .745 .88 r
.25167 .65122 m .25182 .65108 L .25141 .65165 L F
.787 .401 .324 r
.25169 .65121 m .25157 .65142 L .24675 .65001 L F
.236 .745 .88 r
.25141 .65165 m .2515 .65154 L .2505 .6531 L F
.661 .296 .343 r
.25195 .65096 m .25193 .6508 L .25167 .65122 L F
.236 .745 .88 r
.25193 .6508 m .252 .65076 L .25167 .65122 L F
.829 .551 .003 r
.25132 .64788 m .2519 .65092 L .24868 .64819 L F
.2519 .65092 m .25202 .65155 L .25169 .65121 L F
.236 .745 .88 r
.25204 .65073 m .25172 .65117 L .25167 .65122 L F
.829 .551 .003 r
.2519 .65092 m .25169 .65121 L .24868 .64819 L F
.2519 .65092 m .25193 .6508 L .25202 .65155 L F
.25132 .64788 m .25193 .6508 L .2519 .65092 L F
.236 .745 .88 r
.252 .65076 m .25204 .65073 L .25191 .65091 L F
.25191 .65088 m .25191 .65091 L .25167 .65122 L F
.252 .65076 m .25191 .65091 L .25191 .65088 L F
.536 .402 .645 r
.25386 .64804 m .25426 .65054 L .25193 .6508 L F
.236 .745 .88 r
.25193 .6508 m .25426 .65054 L .25259 .65036 L F
.25204 .65073 m .25259 .65036 L .25172 .65117 L F
.2515 .65154 m .25259 .65036 L .25088 .6526 L F
.2515 .65154 m .25088 .6526 L .2505 .6531 L F
.25182 .65108 m .25259 .65036 L .25141 .65165 L F
.787 .401 .324 r
.24868 .64819 m .24897 .64964 L .24972 .64712 L F
.24868 .64819 m .24675 .65001 L .24897 .64964 L F
.718 .598 .722 r
.24868 .64819 m .25066 .64575 L .24866 .64578 L F
.337 0 0 r
.54906 .51752 m .54797 .51906 L .54538 .51863 L F
.61 .123 .073 r
.55176 .51933 m .54906 .51752 L .5513 .51815 L F
.55176 .51933 m .54797 .51906 L .54906 .51752 L F
.513 .419 .686 r
.31268 .58339 m .31347 .5871 L .31127 .58761 L F
.536 .431 .681 r
.31347 .5871 m .31153 .59017 L .31127 .58761 L F
.222 0 .288 r
.25745 .6152 m .25672 .61738 L .2592 .61435 L F
.563 .53 .777 r
.43542 .57622 m .43827 .57769 L .43788 .57531 L F
.781 .688 .761 r
.43632 .65955 m .43861 .65645 L .44025 .65742 L F
.973 .712 .475 r
.43861 .65645 m .44039 .66033 L .44025 .65742 L F
.38 .06 .292 r
.77019 .39141 m .76732 .39074 L .7675 .39241 L F
.77019 .39141 m .76956 .39005 L .76732 .39074 L F
.724 .383 .4 r
.74025 .38946 m .73967 .38714 L .7375 .38882 L F
0 0 .532 r
.74198 .39108 m .73967 .38714 L .74025 .38946 L F
0 0 0 r
.45099 .61589 m .44974 .61741 L .45227 .61447 L F
.551 .264 .432 r
.47545 .60462 m .47851 .60253 L .47626 .60356 L F
.333 .396 .777 r
.77357 .4315 m .77351 .43337 L .7753 .43155 L F
.337 .403 .782 r
.77351 .43337 m .77635 .43522 L .7753 .43155 L F
.859 .432 .207 r
.79379 .3999 m .79214 .40041 L .793 .39803 L F
.79379 .3999 m .79489 .40192 L .79214 .40041 L F
.785 .284 0 r
.50578 .55488 m .50454 .55543 L .50271 .553 L F
.518 0 0 r
.50578 .55488 m .50826 .55629 L .50454 .55543 L F
.523 0 0 r
.5101 .55633 m .50826 .55629 L .50578 .55488 L F
.223 0 0 r
.26411 .53807 m .26646 .5379 L .26841 .5367 L F
.316 0 0 r
.26841 .5367 m .26646 .5379 L .27032 .53714 L F
.377 .653 .965 r
.14491 .60771 m .14426 .60518 L .14318 .6056 L F
.14491 .60771 m .14717 .60788 L .14426 .60518 L F
.577 .768 .969 r
.79004 .39443 m .79135 .39601 L .79173 .39437 L F
.975 .676 .381 r
.793 .39803 m .79173 .39437 L .79135 .39601 L F
.759 .446 .455 r
.67596 .42248 m .67943 .42075 L .67609 .41992 L F
.67596 .42248 m .67979 .42312 L .67943 .42075 L F
.609 .282 .391 r
.466 .61984 m .46217 .62049 L .46337 .61783 L F
.58 .861 .995 r
.20364 .75334 m .20545 .75417 L .20133 .75413 L F
.962 .732 .543 r
.20545 .75417 m .20364 .75334 L .20133 .75413 L F
.20545 .75417 m .20508 .75713 L .20364 .75334 L F
.281 .72 .965 r
.20747 .75409 m .20545 .75417 L .20364 .75334 L F
.715 .672 .125 r
.16542 .59274 m .16501 .5953 L .16483 .5967 L F
.228 0 0 r
.20252 .55721 m .19794 .55845 L .20048 .55787 L F
0 .448 .754 r
.80343 .39635 m .80646 .39714 L .80692 .39745 L F
.228 0 0 r
.80646 .39714 m .81009 .39769 L .80692 .39745 L F
0 0 .344 r
.53241 .59025 m .53398 .59369 L .53351 .59253 L F
0 0 .09 r
.53398 .59369 m .53422 .59541 L .53351 .59253 L F
0 .02 .556 r
.53422 .59541 m .53557 .59697 L .53424 .59533 L F
.931 .592 .151 r
.53422 .59541 m .53327 .59414 L .53261 .59254 L F
0 .02 .556 r
.53422 .59541 m .53424 .59533 L .53327 .59414 L F
0 0 .09 r
.53398 .59369 m .53416 .59575 L .53422 .59541 L F
.53416 .59575 m .53419 .59608 L .53422 .59541 L F
0 0 0 r
.25066 .64575 m .25369 .64297 L .25189 .6447 L F
.555 .465 .708 r
.25066 .64575 m .25386 .64804 L .25132 .64788 L F
.598 .03 0 r
.25069 .64672 m .25386 .64804 L .25066 .64575 L F
.774 .64 .713 r
.25189 .6447 m .25386 .64335 L .25053 .64595 L F
0 0 0 r
.25369 .64297 m .25386 .64335 L .25189 .6447 L F
.774 .64 .713 r
.25338 .64332 m .25386 .64335 L .25189 .6447 L F
0 0 0 r
.25189 .6447 m .25386 .64335 L .25169 .64489 L F
.2516 .64496 m .25189 .6447 L .25169 .64489 L F
.25066 .64575 m .25189 .6447 L .2516 .64496 L F
.774 .64 .713 r
.25053 .64595 m .25386 .64335 L .25069 .64672 L F
0 0 0 r
.25066 .64575 m .2516 .64496 L .24988 .64365 L F
.774 .64 .713 r
.25073 .64313 m .25338 .64332 L .2516 .64496 L F
0 0 0 r
.2516 .64496 m .25169 .64489 L .2515 .64476 L F
.2516 .64496 m .2515 .64476 L .24988 .64365 L F
.425 0 0 r
.24763 .64298 m .24988 .64365 L .2515 .64476 L F
.24976 .64398 m .2515 .64476 L .25049 .64432 L F
.24763 .64298 m .24924 .64372 L .24976 .64398 L F
.24924 .64372 m .2515 .64476 L .24976 .64398 L F
.774 .64 .713 r
.25073 .64313 m .25119 .64411 L .25069 .64369 L F
.25119 .64411 m .2516 .64496 L .25069 .64369 L F
.425 0 0 r
.24763 .64298 m .25049 .64432 L .24994 .64307 L F
.774 .64 .713 r
.25069 .64369 m .25101 .6455 L .25062 .64462 L F
.25069 .64369 m .2516 .64496 L .25101 .6455 L F
.425 0 0 r
.25049 .64432 m .2515 .64476 L .25169 .64489 L F
.25049 .64432 m .25169 .64489 L .24994 .64307 L F
.774 .64 .713 r
.25062 .64462 m .25101 .6455 L .25053 .64595 L F
.24994 .64307 m .25073 .64313 L .25064 .64439 L F
.24994 .64307 m .25064 .64439 L .25017 .64418 L F
.604 .654 .872 r
.25386 .64335 m .25386 .64804 L .25069 .64672 L F
.774 .568 .619 r
.25169 .64489 m .25386 .64335 L .24994 .64307 L F
.503 .46 .742 r
.24994 .64307 m .25017 .64418 L .25271 .64536 L F
.774 .64 .713 r
.25017 .64418 m .25064 .64439 L .25053 .64595 L F
.503 .46 .742 r
.25017 .64418 m .25069 .64672 L .25263 .64542 L F
.25017 .64418 m .25263 .64542 L .25271 .64536 L F
.598 .03 0 r
.25069 .64672 m .25066 .64575 L .24972 .64712 L F
.466 .259 .515 r
.75263 .40853 m .75017 .41162 L .75274 .41128 L F
.086 .28 .764 r
.50687 .59959 m .50792 .59825 L .50532 .59569 L F
.984 .822 .602 r
.50842 .60171 m .50792 .59825 L .50687 .59959 L F
.273 .306 .714 r
.49058 .56886 m .49128 .57246 L .49308 .57103 L F
.611 .328 .463 r
.49128 .57246 m .49431 .57433 L .49308 .57103 L F
.49128 .57246 m .4913 .57476 L .49431 .57433 L F
.575 .335 .515 r
.46057 .60189 m .46045 .60273 L .45897 .60005 L F
.783 .497 .502 r
.4204 .65663 m .4241 .65938 L .422 .65966 L F
.683 .524 .664 r
.45753 .5658 m .4607 .56814 L .46158 .56652 L F
.588 .929 .731 r
.4607 .56814 m .46383 .56589 L .46158 .56652 L F
.91 .787 .712 r
.56549 .53842 m .56645 .54168 L .56517 .54069 L F
.884 .775 .736 r
.56645 .54168 m .56283 .54401 L .56517 .54069 L F
.56645 .54168 m .56446 .54496 L .56283 .54401 L F
0 0 .542 r
.76384 .39631 m .7628 .39513 L .7619 .39258 L F
.832 .676 .689 r
.75955 .39725 m .7628 .39513 L .76384 .39631 L F
.567 .559 .805 r
.15167 .61244 m .15247 .61436 L .1548 .61359 L F
.439 .269 .553 r
.41994 .67775 m .42178 .67813 L .42176 .67542 L F
.139 0 0 r
.16238 .55932 m .16394 .55939 L .16558 .55756 L F
.029 0 0 r
.16558 .55756 m .16581 .55861 L .16768 .55685 L F
.16558 .55756 m .16394 .55939 L .16581 .55861 L F
.578 .382 .579 r
.44659 .65721 m .44657 .66029 L .44398 .66038 L F
.44398 .66038 m .44657 .66029 L .44659 .65721 L F
.54 .369 .597 r
.44898 .65663 m .44657 .66029 L .44659 .65721 L F
.44657 .66029 m .44898 .65663 L .44659 .65721 L F
0 0 0 r
.18986 .77209 m .19092 .7718 L .18983 .77292 L F
.709 .789 .914 r
.76908 .41383 m .77034 .41544 L .77266 .41428 L F
.76908 .41383 m .77034 .41544 L .77266 .41428 L F
0 0 0 r
.27866 .58488 m .27792 .58501 L .27961 .5847 L F
.27792 .58501 m .27688 .58519 L .2782 .58495 L F
.755 .95 .632 r
.27859 .58487 m .27647 .58765 L .27842 .58491 L F
.27885 .58454 m .27859 .58487 L .27842 .58491 L F
.078 0 0 r
.28108 .58398 m .27961 .5847 L .2785 .5849 L F
0 0 0 r
.27885 .58454 m .27842 .58491 L .2785 .5849 L F
.27885 .58454 m .2785 .5849 L .27881 .5846 L F
.078 0 0 r
.27877 .58464 m .2785 .5849 L .27688 .58519 L F
.28108 .58398 m .2785 .5849 L .27877 .58464 L F
0 0 0 r
.27881 .5846 m .2785 .5849 L .27866 .58488 L F
.755 .95 .632 r
.27842 .58491 m .27647 .58765 L .27691 .58623 L F
0 0 0 r
.27842 .58491 m .27691 .58623 L .27866 .58488 L F
.27792 .58501 m .2782 .58495 L .2785 .5849 L F
.27856 .58489 m .2785 .5849 L .27961 .5847 L F
.27792 .58501 m .2785 .5849 L .27856 .58489 L F
.463 .211 .445 r
.4338 .64225 m .43609 .64193 L .43707 .63967 L F
.71 .703 .842 r
.6621 .43162 m .66355 .4332 L .66588 .43232 L F
.436 .863 .938 r
.7954 .44503 m .79466 .44466 L .79204 .44543 L F
.458 .875 .939 r
.79729 .44382 m .7954 .44503 L .79803 .44439 L F
.79729 .44382 m .79466 .44466 L .7954 .44503 L F
.492 .555 .848 r
.53649 .60582 m .53735 .60346 L .53809 .60296 L F
.565 .284 .449 r
.27114 .63641 m .27063 .6387 L .26813 .63879 L F
.499 .226 .432 r
.27349 .63604 m .27063 .6387 L .27114 .63641 L F
0 0 0 r
.25369 .64297 m .25605 .6424 L .25386 .64335 L F
.528 .267 .463 r
.4665 .63131 m .46844 .62971 L .4661 .63059 L F
.055 0 0 r
.22303 .53774 m .22528 .53763 L .2272 .53723 L F
.198 0 0 r
.22528 .53763 m .22914 .53751 L .2272 .53723 L F
.247 0 0 r
.23922 .62647 m .24146 .62595 L .24321 .62385 L F
.228 0 0 r
.24321 .62385 m .24368 .62537 L .24544 .62305 L F
.24321 .62385 m .24146 .62595 L .24368 .62537 L F
.517 .586 .863 r
.78204 .42932 m .78051 .43066 L .77798 .42594 L F
.536 .8 .994 r
.50646 .60707 m .50802 .60825 L .50539 .60881 L F
.549 .427 .666 r
.50539 .60881 m .50802 .60825 L .50646 .60707 L F
.50539 .60881 m .50619 .61021 L .50802 .60825 L F
.542 .644 .9 r
.50619 .61021 m .50539 .60881 L .50802 .60825 L F
.482 .377 .658 r
.31414 .57182 m .31516 .57752 L .31304 .5781 L F
.255 0 0 r
.3146 .57793 m .31304 .5781 L .31516 .57752 L F
.3146 .57793 m .31227 .57851 L .31304 .5781 L F
0 0 0 r
.20736 .73325 m .2086 .73289 L .20575 .73449 L F
.20736 .73325 m .2097 .73252 L .2086 .73289 L F
.307 .719 .976 r
.49316 .54351 m .49641 .5426 L .49482 .54193 L F
.49316 .54351 m .49699 .54453 L .49641 .5426 L F
.686 .609 .764 r
.8298 .41452 m .83236 .41142 L .8287 .41064 L F
.664 .35 .432 r
.46892 .63086 m .46898 .63242 L .46973 .63313 L F
.873 .439 .045 r
.74148 .39175 m .74198 .39108 L .74025 .38946 L F
.072 0 0 r
.74402 .39119 m .74198 .39108 L .74148 .39175 L F
.74402 .39119 m .74536 .39062 L .74198 .39108 L F
.754 .695 .795 r
.83472 .41056 m .83636 .41265 L .8384 .41123 L F
.663 .199 0 r
.51362 .60189 m .51617 .60524 L .5157 .60308 L F
.103 0 0 r
.22965 .55057 m .22588 .55088 L .22748 .55062 L F
.626 .217 .248 r
.45492 .62926 m .45196 .63099 L .44976 .62961 L F
.148 .686 .697 r
.45575 .63021 m .45196 .63099 L .45492 .62926 L F
.513 .547 .828 r
.1548 .61359 m .15641 .61739 L .15862 .61704 L F
.544 .853 .998 r
.78926 .44614 m .79078 .44452 L .78777 .44475 L F
.78926 .44614 m .79204 .44543 L .79078 .44452 L F
.377 .092 .348 r
.25459 .61796 m .25182 .62074 L .25428 .62049 L F
.434 .219 .487 r
.25459 .61796 m .25428 .62049 L .25672 .61738 L F
0 0 0 r
.18406 .78395 m .18333 .78399 L .18247 .78442 L F
.18406 .78395 m .18575 .78234 L .18333 .78399 L F
.466 .259 .515 r
.75263 .40853 m .75274 .41128 L .75142 .40707 L F
.28 .077 .416 r
.26475 .60571 m .26647 .60506 L .26688 .60261 L F
.115 0 .336 r
.26467 .60825 m .26647 .60506 L .26475 .60571 L F
.495 .256 .481 r
.27928 .62993 m .27905 .63203 L .27675 .63243 L F
.494 .262 .491 r
.28171 .62944 m .27905 .63203 L .27928 .62993 L F
.694 .666 .819 r
.49435 .59169 m .49798 .59353 L .4967 .58974 L F
.49387 .59209 m .49412 .59218 L .49435 .59169 L F
.49412 .59218 m .49798 .59353 L .49435 .59169 L F
.258 .163 .552 r
.4929 .58946 m .49434 .59172 L .49401 .58719 L F
.49434 .59172 m .49438 .59178 L .49435 .59169 L F
.43 .22 .491 r
.4929 .58946 m .49387 .59209 L .49438 .59178 L F
.469 .286 .549 r
.49438 .59178 m .49387 .59209 L .49435 .59169 L F
.49438 .59178 m .49435 .59169 L .4967 .58974 L F
.258 .163 .552 r
.49435 .59169 m .49438 .59178 L .49437 .59166 L F
.49434 .59172 m .49437 .59166 L .49401 .58719 L F
.42 .215 .493 r
.4929 .58946 m .49205 .59296 L .49387 .59209 L F
.669 .73 .896 r
.54637 .60509 m .5472 .60227 L .54515 .60521 L F
0 0 0 r
.44946 .58115 m .44901 .58109 L .45171 .58142 L F
.44946 .58115 m .44781 .5833 L .44901 .58109 L F
.565 .172 .256 r
.55252 .5056 m .55126 .50769 L .55512 .50713 L F
.544 .207 .347 r
.55252 .5056 m .55512 .50713 L .55508 .50553 L F
.608 .932 .715 r
.46267 .57234 m .46089 .57325 L .4596 .57481 L F
.564 .844 .507 r
.46089 .57325 m .45808 .5764 L .4596 .57481 L F
.676 .149 0 r
.49046 .56316 m .49217 .5643 L .48869 .56237 L F
.49046 .56316 m .49291 .56522 L .49217 .5643 L F
.893 .953 .835 r
.45227 .61447 m .44974 .61741 L .45112 .61738 L F
.636 .337 .446 r
.44998 .61952 m .45112 .61738 L .44974 .61741 L F
.44998 .61952 m .45316 .61954 L .45112 .61738 L F
.583 .591 .826 r
.14717 .60788 m .14862 .61138 L .15098 .61074 L F
.587 .62 .852 r
.14862 .61138 m .15167 .61244 L .15098 .61074 L F
.705 .798 .922 r
.80773 .4332 m .80218 .43185 L .80447 .43139 L F
.316 .549 .916 r
.80678 .43045 m .80773 .4332 L .80447 .43139 L F
.80678 .43045 m .8081 .4324 L .80773 .4332 L F
.045 0 .209 r
.2433 .65461 m .24097 .65712 L .24188 .65614 L F
.388 .745 .992 r
.24097 .65712 m .24344 .65705 L .24188 .65614 L F
.379 .732 .99 r
.81708 .40013 m .81353 .39918 L .81614 .39869 L F
.515 .753 .982 r
.81968 .39971 m .81708 .40013 L .81614 .39869 L F
.221 .21 .634 r
.49632 .58153 m .49809 .583 L .49809 .57996 L F
.28 .21 .597 r
.49632 .58153 m .49691 .58462 L .49809 .583 L F
.587 .564 .796 r
.77963 .38749 m .78374 .39075 L .78218 .38687 L F
.547 0 0 r
.49187 .54862 m .49009 .5478 L .4898 .54734 L F
0 .253 .642 r
.49453 .55017 m .49009 .5478 L .49187 .54862 L F
0 .394 .828 r
.17416 .60798 m .17365 .60846 L .172 .60734 L F
.17416 .60798 m .17594 .60963 L .17365 .60846 L F
.697 .771 .909 r
.21003 .64524 m .21054 .64631 L .21244 .64489 L F
.795 .558 .579 r
.27885 .58454 m .27688 .58519 L .27542 .58385 L F
.078 0 0 r
.28108 .58398 m .27688 .58519 L .27885 .58454 L F
.845 .996 .831 r
.28115 .58217 m .27975 .58446 L .28108 .58398 L F
.27975 .58446 m .27961 .5847 L .28108 .58398 L F
0 0 0 r
.28086 .58403 m .27975 .58446 L .28108 .58398 L F
.27887 .58453 m .27975 .58446 L .28086 .58403 L F
0 0 .16 r
.27975 .58446 m .27961 .5847 L .27971 .58446 L F
.837 .999 .788 r
.27975 .58446 m .27866 .58488 L .27961 .5847 L F
0 0 .16 r
.28115 .58217 m .27975 .58446 L .2818 .57984 L F
.27975 .58446 m .27971 .58446 L .2818 .57984 L F
0 0 0 r
.27885 .58454 m .27868 .58485 L .27975 .58446 L F
.27885 .58454 m .27975 .58446 L .27887 .58453 L F
0 0 .16 r
.2818 .57984 m .27971 .58446 L .28115 .58217 L F
.27971 .58446 m .27961 .5847 L .27975 .58446 L F
.27971 .58446 m .27975 .58446 L .28115 .58217 L F
0 0 0 r
.27868 .58485 m .27866 .58488 L .2798 .58446 L F
.27975 .58446 m .2798 .58446 L .28108 .58398 L F
.27868 .58485 m .2798 .58446 L .27975 .58446 L F
0 0 .16 r
.28115 .58217 m .27961 .5847 L .2818 .57984 L F
.837 .999 .788 r
.28115 .58217 m .27866 .58488 L .27975 .58446 L F
.592 .413 .608 r
.44221 .62371 m .44462 .62362 L .44466 .62077 L F
.44221 .62371 m .44462 .62362 L .44466 .62077 L F
.746 .708 .816 r
.83472 .41056 m .8384 .41123 L .83745 .40796 L F
.698 .68 .829 r
.83745 .40796 m .8384 .41123 L .84123 .40911 L F
.299 .364 .762 r
.44221 .62371 m .44488 .62625 L .44462 .62362 L F
0 0 .17 r
.47092 .61365 m .47074 .61666 L .46962 .61792 L F
0 0 .302 r
.47074 .61666 m .4687 .61991 L .46962 .61792 L F
.769 .339 .23 r
.6679 .41725 m .66844 .41876 L .66982 .41737 L F
.397 0 0 r
.66844 .41876 m .67199 .41876 L .66982 .41737 L F
.603 .453 .65 r
.43598 .5818 m .43924 .58378 L .43838 .58019 L F
.43598 .5818 m .43658 .58416 L .43924 .58378 L F
.508 .061 .123 r
.49097 .54241 m .49316 .54351 L .49482 .54193 L F
.331 .46 .84 r
.26964 .58792 m .27256 .58926 L .27095 .58604 L F
.373 .516 .872 r
.26313 .55791 m .26359 .55474 L .26208 .55627 L F
.26313 .55791 m .26583 .55873 L .26359 .55474 L F
.56 .645 .891 r
.30263 .54299 m .30201 .54621 L .30049 .54361 L F
.30263 .54299 m .3047 .54579 L .30201 .54621 L F
.382 .762 .99 r
.19615 .64238 m .20031 .64302 L .19841 .64188 L F
.751 .843 .92 r
.19841 .64188 m .20031 .64302 L .20239 .64166 L F
.63 .853 .984 r
.23919 .64315 m .24405 .64576 L .24762 .64349 L F
.967 .679 .435 r
.76283 .38572 m .76404 .38418 L .76189 .38412 L F
.76283 .38572 m .76422 .38698 L .76404 .38418 L F
.915 .803 .721 r
.7511 .38723 m .75003 .38966 L .74808 .38927 L F
.527 .283 .489 r
.75247 .38277 m .74978 .38116 L .7498 .38347 L F
.797 .636 .682 r
.74633 .39582 m .74905 .39551 L .74833 .39199 L F
.631 .2 .206 r
.74896 .39772 m .74905 .39551 L .74633 .39582 L F
.11 .165 .639 r
.74833 .39199 m .74905 .39551 L .75075 .39412 L F
0 0 .102 r
.75075 .39412 m .74905 .39551 L .74896 .39772 L F
0 0 .493 r
.53829 .57756 m .53767 .58133 L .5358 .57774 L F
.53829 .57756 m .53872 .58076 L .53767 .58133 L F
.507 .11 .222 r
.18619 .56586 m .18472 .56808 L .18225 .56819 L F
0 0 0 r
.18601 .56642 m .18619 .56586 L .18776 .56552 L F
.18601 .56642 m .18472 .56808 L .18619 .56586 L F
.254 .453 .862 r
.20894 .62263 m .2084 .62461 L .20735 .6224 L F
.452 .668 .955 r
.20894 .62263 m .21048 .62457 L .2084 .62461 L F
0 0 0 r
.18746 .54525 m .18982 .54481 L .19102 .54446 L F
.32 .799 .733 r
.19102 .54446 m .19175 .54403 L .19332 .54414 L F
.19102 .54446 m .18982 .54481 L .19175 .54403 L F
.536 .402 .645 r
.25386 .64804 m .25193 .6508 L .25132 .64788 L F
.59 .41 .606 r
.47065 .55944 m .47124 .56349 L .471 .55899 L F
.694 .672 .824 r
.79545 .43233 m .79659 .43599 L .79272 .43504 L F
.69 .669 .825 r
.79869 .43461 m .79659 .43599 L .79545 .43233 L F
.104 .09 .555 r
.26871 .59675 m .27009 .59853 L .27049 .59587 L F
.26871 .59675 m .26906 .59943 L .27009 .59853 L F
.658 .387 .497 r
.48204 .60559 m .47877 .60749 L .47968 .60599 L F
.162 0 0 r
.1955 .54328 m .19781 .54305 L .19994 .542 L F
.324 0 0 r
.19781 .54305 m .20214 .54152 L .19994 .542 L F
.327 .419 .803 r
.31488 .58049 m .31227 .57851 L .3146 .57793 L F
.31488 .58049 m .31491 .58212 L .31227 .57851 L F
.584 .7 .922 r
.43367 .58605 m .43428 .58822 L .43728 .58753 L F
.507 .246 .454 r
.27675 .63243 m .27601 .63562 L .27349 .63604 L F
.496 .241 .457 r
.27905 .63203 m .27601 .63562 L .27675 .63243 L F
.445 .212 .466 r
.31677 .55961 m .31453 .56018 L .31706 .55724 L F
.627 .37 .508 r
.31964 .55902 m .31706 .55724 L .31933 .55657 L F
.31964 .55902 m .31677 .55961 L .31706 .55724 L F
.26 .163 .551 r
.83337 .40218 m .83563 .40118 L .83601 .4014 L F
.83337 .40218 m .83364 .40305 L .83563 .40118 L F
.468 .334 .615 r
.48473 .56719 m .4843 .56946 L .48628 .5687 L F
.63 .656 .857 r
.2216 .70129 m .22306 .69811 L .22219 .69837 L F
.2216 .70129 m .22431 .70062 L .22306 .69811 L F
.403 .163 .433 r
.47981 .62416 m .48238 .62379 L .4827 .62075 L F
.345 .116 .417 r
.4827 .62075 m .48457 .62243 L .48516 .62061 L F
.4827 .62075 m .48238 .62379 L .48457 .62243 L F
0 0 .466 r
.53639 .59991 m .53582 .5985 L .53419 .59608 L F
.848 .744 .749 r
.56505 .55338 m .56183 .55322 L .56364 .5496 L F
.854 .701 .692 r
.56505 .55338 m .56323 .55671 L .56183 .55322 L F
.979 .754 .527 r
.45073 .64368 m .45247 .64511 L .45274 .64201 L F
.383 .808 .969 r
.45475 .64153 m .45177 .64137 L .45274 .64201 L F
.981 .912 .629 r
.45177 .64137 m .45073 .64368 L .45274 .64201 L F
.383 .808 .969 r
.45475 .64153 m .45177 .64137 L .45274 .64201 L F
.588 .457 .67 r
.45247 .64511 m .45475 .64153 L .45274 .64201 L F
.807 .645 .681 r
.57592 .55402 m .57558 .55655 L .57914 .557 L F
.805 .609 .638 r
.57558 .55655 m .57833 .55933 L .57914 .557 L F
.418 .485 .822 r
.49058 .56886 m .49233 .56836 L .49007 .56766 L F
.49003 .56768 m .49007 .56766 L .49001 .56764 L F
.49058 .56886 m .49007 .56766 L .49003 .56768 L F
.525 .029 .022 r
.49233 .56836 m .48863 .56856 L .49001 .56764 L F
.876 .554 .437 r
.49291 .56522 m .49146 .56828 L .49232 .56803 L F
.49509 .56665 m .4927 .56784 L .49571 .56705 L F
.4927 .56784 m .49274 .56791 L .49571 .56705 L F
.49291 .56522 m .49232 .56803 L .49509 .56665 L F
.714 .256 .163 r
.49274 .56791 m .4978 .56887 L .49571 .56705 L F
.005 .124 .639 r
.49233 .56836 m .49309 .56925 L .4927 .56784 L F
.49309 .56925 m .4936 .56985 L .49329 .56915 L F
.49309 .56925 m .49329 .56915 L .4927 .56784 L F
.231 .642 .958 r
.49316 .56844 m .4982 .57079 L .4978 .56887 L F
.005 .124 .639 r
.49275 .56792 m .49382 .56959 L .49316 .56844 L F
.273 .306 .714 r
.49058 .56886 m .49308 .57103 L .49233 .56836 L F
.127 .156 .621 r
.49233 .56836 m .49308 .57103 L .49391 .57021 L F
.231 .642 .958 r
.49146 .56828 m .4935 .56904 L .49316 .56844 L F
.4935 .56904 m .4982 .57079 L .49316 .56844 L F
.005 .124 .639 r
.49275 .56792 m .49391 .57021 L .49382 .56959 L F
.49316 .56844 m .49382 .56959 L .49376 .56918 L F
.714 .256 .163 r
.49232 .56803 m .49316 .56844 L .49274 .56791 L F
.49146 .56828 m .49174 .5683 L .49232 .56803 L F
.005 .124 .639 r
.49233 .56836 m .49269 .56786 L .49154 .56847 L F
.49269 .56786 m .49255 .56792 L .49154 .56847 L F
.4927 .56784 m .49168 .56835 L .49154 .56847 L F
.714 .256 .163 r
.49174 .5683 m .49316 .56844 L .49232 .56803 L F
.005 .124 .639 r
.49269 .56786 m .4927 .56784 L .49255 .56792 L F
.714 .256 .163 r
.49316 .56844 m .4978 .56887 L .49274 .56791 L F
.005 .124 .639 r
.4927 .56784 m .49275 .56792 L .49341 .56685 L F
.231 .642 .958 r
.4935 .56904 m .49562 .56947 L .4982 .57079 L F
.49378 .56889 m .49713 .56978 L .4935 .56904 L F
.005 .124 .639 r
.49275 .56792 m .49376 .56918 L .49341 .56685 L F
.4936 .56985 m .49391 .57021 L .4927 .56784 L F
.876 .554 .437 r
.4927 .56784 m .49232 .56803 L .49274 .56791 L F
.005 .124 .639 r
.4927 .56784 m .49341 .56685 L .49168 .56835 L F
.606 .616 .835 r
.49372 .56892 m .49146 .56828 L .49341 .56685 L F
.231 .642 .958 r
.49146 .56828 m .49378 .56889 L .4935 .56904 L F
.013 0 0 r
.49233 .56836 m .49154 .56847 L .48863 .56856 L F
.606 .616 .835 r
.49148 .56829 m .49146 .56828 L .49149 .56828 L F
.065 0 .046 r
.49341 .56685 m .49146 .56828 L .49218 .56675 L F
.262 0 0 r
.48645 .56866 m .48863 .56856 L .48628 .5687 L F
.49001 .56764 m .48863 .56856 L .48645 .56866 L F
.356 .726 .987 r
.48863 .56856 m .49154 .56847 L .4915 .56844 L F
.84 .838 .368 r
.48863 .56856 m .48972 .56361 L .48706 .56282 L F
.48863 .56856 m .48856 .56686 L .48972 .56361 L F
.356 .726 .987 r
.48863 .56856 m .48896 .56707 L .48856 .56686 L F
.48863 .56856 m .4915 .56844 L .48896 .56707 L F
.731 .845 .934 r
.48856 .56686 m .49137 .56837 L .49341 .56685 L F
.49148 .56829 m .49154 .56847 L .49341 .56685 L F
.606 .616 .835 r
.49391 .57021 m .49148 .56829 L .49372 .56892 L F
.49148 .56829 m .49149 .56828 L .49372 .56892 L F
.231 .642 .958 r
.49562 .56947 m .49713 .56978 L .49732 .56996 L F
.49562 .56947 m .49732 .56996 L .4982 .57079 L F
.606 .616 .835 r
.49391 .57021 m .49713 .56978 L .49149 .56828 L F
.49148 .56829 m .49149 .56828 L .49146 .56828 L F
.49391 .57021 m .49149 .56828 L .49148 .56829 L F
.731 .845 .934 r
.49137 .56837 m .49139 .56838 L .49148 .56829 L F
.49139 .56838 m .49154 .56847 L .49148 .56829 L F
.065 0 .046 r
.49324 .5663 m .49218 .56675 L .49291 .56522 L F
.49341 .56685 m .49218 .56675 L .49324 .5663 L F
0 0 0 r
.24503 .67624 m .2447 .67554 L .24618 .67451 L F
.24503 .67624 m .24441 .67663 L .2447 .67554 L F
.24503 .67624 m .24414 .67761 L .24441 .67663 L F
.13 .271 .741 r
.24448 .67578 m .24414 .67761 L .24503 .67624 L F
.24288 .67444 m .24393 .67708 L .24448 .67578 L F
.24393 .67708 m .24414 .67761 L .24448 .67578 L F
.184 0 .363 r
.24816 .671 m .24618 .67451 L .24619 .67162 L F
.666 .76 .921 r
.24288 .67444 m .24618 .67451 L .24363 .67192 L F
.24301 .67189 m .24363 .67192 L .24304 .67132 L F
.24288 .67444 m .24363 .67192 L .24301 .67189 L F
.13 .271 .741 r
.24288 .67444 m .24503 .67624 L .24618 .67451 L F
.138 0 .234 r
.24879 .66902 m .24619 .67162 L .24654 .66929 L F
.24879 .66902 m .24816 .671 L .24619 .67162 L F
.848 .786 .791 r
.24304 .67132 m .24618 .67451 L .24816 .671 L F
.315 .246 .618 r
.24813 .67165 m .24618 .67451 L .24455 .6756 L F
.24473 .67518 m .24455 .6756 L .24389 .67605 L F
.677 .279 .286 r
.24618 .67451 m .24799 .67658 L .24503 .67624 L F
.113 .646 .864 r
.24509 .67621 m .24799 .67658 L .24503 .67624 L F
.315 .246 .618 r
.24813 .67165 m .24799 .67658 L .24618 .67451 L F
.731 .568 .671 r
.24813 .67214 m .24829 .67648 L .24815 .67212 L F
.517 .251 .45 r
.24799 .67658 m .24742 .67903 L .24507 .67984 L F
.972 .828 .414 r
.24697 .67819 m .24742 .67903 L .24776 .67758 L F
.24783 .67683 m .24776 .67758 L .24799 .67658 L F
.24697 .67819 m .24776 .67758 L .24783 .67683 L F
.113 .646 .864 r
.24389 .67605 m .24509 .67621 L .24503 .67624 L F
0 0 .093 r
.24503 .67624 m .24364 .68013 L .24414 .67761 L F
.15 .085 .522 r
.24507 .67984 m .24364 .68013 L .24501 .67629 L F
.24503 .67631 m .24501 .67629 L .24503 .67624 L F
.24507 .67984 m .24501 .67629 L .24503 .67631 L F
.24507 .67984 m .24503 .67624 L .24389 .67605 L F
.517 .251 .45 r
.24799 .67658 m .24507 .67984 L .24404 .67656 L F
.24685 .67643 m .24404 .67656 L .24389 .67605 L F
.24799 .67658 m .24404 .67656 L .24685 .67643 L F
.585 .121 .119 r
.24565 .677 m .24697 .67819 L .24829 .67667 L F
0 0 .162 r
.24414 .67761 m .24364 .68013 L .24251 .68137 L F
.618 .572 .78 r
.24122 .67797 m .24414 .67761 L .24288 .67444 L F
.787 .55 .577 r
.2393 .67969 m .24414 .67761 L .24122 .67797 L F
.2393 .67969 m .24364 .68013 L .24414 .67761 L F
.757 .72 .189 r
.24414 .67761 m .24408 .6774 L .24389 .67605 L F
.24414 .67761 m .24364 .68013 L .24408 .6774 L F
.75 .534 .602 r
.23913 .68217 m .24364 .68013 L .2393 .67969 L F
.43 .186 .441 r
.24188 .68356 m .23997 .68428 L .24251 .68137 L F
.056 0 .403 r
.24364 .68013 m .24188 .68356 L .24251 .68137 L F
.24272 .68191 m .24339 .68294 L .24188 .68356 L F
.24364 .68013 m .24339 .68294 L .24272 .68191 L F
.257 0 .204 r
.24455 .68473 m .24558 .68244 L .24754 .68175 L F
.216 .02 .386 r
.24441 .6846 m .24303 .68538 L .24476 .68518 L F
.24339 .68294 m .24306 .68521 L .24441 .6846 L F
.24306 .68521 m .24303 .68538 L .24441 .6846 L F
.75 .534 .602 r
.24245 .68067 m .24339 .68294 L .24364 .68013 L F
.23913 .68217 m .24339 .68294 L .24245 .68067 L F
.874 .741 .229 r
.24364 .68013 m .24339 .68294 L .24307 .68078 L F
.468 .288 .554 r
.24558 .68244 m .24339 .68294 L .24364 .68013 L F
.101 0 .34 r
.24448 .68464 m .24339 .68294 L .24558 .68244 L F
.216 .02 .386 r
.24339 .68294 m .24452 .68471 L .24452 .68469 L F
.24339 .68294 m .2441 .68411 L .24444 .68459 L F
.2441 .68411 m .24476 .68518 L .24444 .68459 L F
.101 0 .34 r
.24433 .68495 m .24339 .68294 L .24448 .68464 L F
.216 .02 .386 r
.24339 .68294 m .24452 .68469 L .24307 .68078 L F
.183 .306 .756 r
.24671 .68696 m .24489 .68542 L .24624 .6839 L F
.216 .02 .386 r
.24452 .68471 m .24467 .68494 L .24463 .68482 L F
.24444 .68459 m .24476 .68518 L .24467 .68494 L F
.183 .306 .756 r
.24489 .68542 m .24461 .68479 L .24624 .6839 L F
.216 .02 .386 r
.24461 .68479 m .24463 .68482 L .24462 .68479 L F
.24452 .68471 m .24463 .68482 L .24461 .68479 L F
.257 0 .204 r
.24448 .68464 m .24558 .68244 L .24455 .68473 L F
.216 .02 .386 r
.24452 .68471 m .24462 .68479 L .24307 .68078 L F
.507 .265 .482 r
.24339 .68294 m .24063 .68578 L .24188 .68356 L F
.184 0 .054 r
.24063 .68578 m .23997 .68428 L .24188 .68356 L F
.507 .265 .482 r
.24063 .68578 m .24339 .68294 L .23913 .68217 L F
.24063 .68578 m .24303 .68538 L .24339 .68294 L F
.24339 .68294 m .24303 .68538 L .24063 .68578 L F
.101 0 .34 r
.24433 .68495 m .24303 .68538 L .24339 .68294 L F
.88 .635 .565 r
.24307 .68078 m .24463 .68482 L .24174 .68386 L F
.24463 .68482 m .24476 .68518 L .24469 .68515 L F
.183 .306 .756 r
.24463 .68482 m .24433 .68495 L .24461 .68479 L F
.24472 .68528 m .24433 .68495 L .24463 .68482 L F
.02 0 0 r
.24433 .68495 m .24455 .68473 L .24461 .68479 L F
.257 0 .204 r
.24433 .68495 m .24448 .68464 L .24455 .68473 L F
.88 .635 .565 r
.24463 .68482 m .24469 .68515 L .24174 .68386 L F
.96 .716 .523 r
.24303 .68538 m .24258 .68804 L .24094 .68705 L F
.243 .343 .767 r
.24446 .68524 m .2454 .68721 L .24303 .68538 L F
.571 .322 .499 r
.2454 .68721 m .24258 .68804 L .24303 .68538 L F
.059 0 0 r
.24476 .68518 m .24303 .68538 L .24469 .68522 L F
.816 .751 .792 r
.24469 .68515 m .24467 .68522 L .24467 .68523 L F
.183 .306 .756 r
.24671 .68696 m .24446 .68524 L .24466 .68523 L F
.059 0 0 r
.24467 .68523 m .24303 .68538 L .24094 .68705 L F
.24469 .68522 m .24446 .68524 L .24467 .68523 L F
.816 .751 .792 r
.24465 .68517 m .24467 .68523 L .24094 .68705 L F
.24469 .68515 m .24467 .68523 L .24465 .68517 L F
.183 .306 .756 r
.24671 .68696 m .2454 .68721 L .24484 .68604 L F
.24471 .68543 m .24484 .68604 L .24446 .68524 L F
.24671 .68696 m .24484 .68604 L .24471 .68543 L F
.24466 .68523 m .24446 .68524 L .24433 .68495 L F
.059 0 0 r
.24446 .68524 m .24303 .68538 L .24467 .68523 L F
.243 .343 .767 r
.24433 .68495 m .24446 .68524 L .24303 .68538 L F
.816 .751 .792 r
.24174 .68386 m .24469 .68515 L .24094 .68705 L F
.24469 .68515 m .24476 .68518 L .24467 .68522 L F
.183 .306 .756 r
.24489 .68542 m .24472 .68528 L .24469 .68515 L F
.24472 .68504 m .24469 .68515 L .24463 .68482 L F
.24489 .68542 m .24469 .68515 L .24472 .68504 L F
.02 0 0 r
.24461 .68479 m .24491 .68437 L .24624 .6839 L F
.24455 .68473 m .24491 .68437 L .24461 .68479 L F
.24491 .68437 m .24754 .68175 L .24635 .68372 L F
.24491 .68437 m .24635 .68372 L .24624 .6839 L F
.874 .741 .229 r
.24364 .68013 m .24307 .68078 L .24408 .6774 L F
.972 .875 .679 r
.24389 .67605 m .24408 .6774 L .24242 .6774 L F
.971 .708 .475 r
.24242 .6774 m .24408 .6774 L .24307 .68078 L F
.585 .121 .119 r
.24242 .6774 m .24667 .67814 L .24565 .677 L F
.24667 .67814 m .24697 .67819 L .24565 .677 L F
.731 .568 .671 r
.24389 .67605 m .24786 .67661 L .24813 .67214 L F
.303 .796 .86 r
.24807 .67651 m .24799 .67658 L .24813 .67165 L F
.731 .568 .671 r
.24786 .67661 m .24807 .67664 L .2481 .67427 L F
.24786 .67661 m .2481 .67427 L .24813 .67214 L F
.972 .828 .414 r
.24697 .67819 m .24783 .67683 L .24827 .67669 L F
.24783 .67683 m .24799 .67658 L .2487 .67641 L F
.731 .568 .671 r
.24829 .67648 m .24829 .67661 L .24829 .67648 L F
.24829 .67661 m .24829 .67667 L .24829 .67661 L F
.24829 .67661 m .24829 .67661 L .24829 .67648 L F
.303 .796 .86 r
.24807 .67651 m .2487 .67641 L .24799 .67658 L F
.24856 .67606 m .2487 .67641 L .24829 .67648 L F
.577 .446 .666 r
.25238 .66764 m .2529 .67044 L .25046 .6704 L F
0 0 .16 r
.24829 .67648 m .24847 .67619 L .24822 .67254 L F
.24847 .67619 m .24849 .67533 L .24822 .67254 L F
.24847 .67619 m .24856 .67606 L .24849 .67533 L F
.24815 .67218 m .2482 .67244 L .24813 .67165 L F
.792 .575 .009 r
.2482 .67244 m .24813 .67165 L .24816 .671 L F
0 0 .16 r
.2482 .67244 m .24822 .67254 L .24813 .67165 L F
.792 .575 .009 r
.2482 .67247 m .24813 .67165 L .2482 .67244 L F
.303 .796 .86 r
.24856 .67606 m .2485 .67611 L .2482 .67247 L F
.24856 .67606 m .2482 .67247 L .24822 .67254 L F
.792 .575 .009 r
.24824 .67435 m .2482 .67247 L .24848 .67392 L F
0 0 .16 r
.24829 .67648 m .24822 .67254 L .24815 .67218 L F
.792 .575 .009 r
.2482 .67247 m .2482 .67244 L .24822 .67254 L F
.2482 .67247 m .24822 .67254 L .24848 .67392 L F
.303 .796 .86 r
.24822 .67254 m .2482 .67247 L .24813 .67165 L F
.731 .568 .671 r
.24829 .67648 m .24829 .67648 L .24815 .67212 L F
.24807 .67664 m .24829 .67667 L .24813 .67214 L F
.315 .246 .618 r
.24813 .67165 m .24455 .6756 L .24473 .67518 L F
.731 .568 .671 r
.24389 .67605 m .24815 .67212 L .2477 .6721 L F
.303 .796 .86 r
.2485 .67611 m .24807 .67651 L .24813 .67165 L F
.792 .575 .009 r
.24824 .67435 m .24813 .67165 L .2482 .67247 L F
.932 .867 .752 r
.2529 .67044 m .24824 .67435 L .25046 .6704 L F
.577 .446 .666 r
.25238 .66764 m .2529 .67044 L .25046 .6704 L F
.932 .867 .752 r
.2529 .67044 m .25096 .67021 L .24851 .67393 L F
.24851 .67412 m .24851 .67393 L .24824 .67435 L F
.2529 .67044 m .24851 .67393 L .24851 .67412 L F
.792 .575 .009 r
.24848 .67392 m .24816 .671 L .25046 .6704 L F
.2482 .67244 m .24816 .671 L .24848 .67392 L F
.303 .796 .86 r
.24856 .67606 m .24829 .67648 L .24807 .67651 L F
0 0 .16 r
.24829 .67667 m .24856 .67606 L .24829 .67648 L F
.585 .121 .119 r
.24242 .6774 m .24829 .67667 L .24389 .67605 L F
.646 .871 .504 r
.2483 .67665 m .24697 .67819 L .24856 .67606 L F
.24829 .67667 m .24697 .67819 L .2483 .67665 L F
.972 .828 .414 r
.24697 .67819 m .24827 .67669 L .25017 .67606 L F
.24783 .67683 m .2487 .67641 L .25017 .67606 L F
.303 .796 .86 r
.24856 .67606 m .25017 .67606 L .2487 .67641 L F
.731 .568 .671 r
.2477 .6721 m .24815 .67212 L .24813 .67165 L F
.138 0 .055 r
.83416 .4376 m .83468 .43824 L .8316 .4406 L F
.401 .833 .684 r
.83757 .43575 m .83416 .4376 L .83393 .43514 L F
.83757 .43575 m .83614 .43639 L .83416 .4376 L F
0 0 .17 r
.83416 .4376 m .83614 .43639 L .83468 .43824 L F
.419 .818 .603 r
.53306 .52335 m .53204 .52401 L .53004 .52539 L F
.08 .038 .504 r
.53469 .51956 m .53509 .52163 L .53306 .52335 L F
.484 .851 .611 r
.53509 .52163 m .53204 .52401 L .53306 .52335 L F
.328 .568 .926 r
.5472 .60227 m .55266 .60706 L .54993 .60213 L F
.665 .691 .864 r
.54993 .60213 m .55266 .60706 L .55226 .60584 L F
.084 0 .067 r
.48815 .54514 m .49024 .54439 L .49097 .54241 L F
.495 .105 .23 r
.49097 .54241 m .49024 .54439 L .49316 .54351 L F
0 0 0 r
.46491 .56909 m .46397 .57106 L .46267 .57234 L F
.546 .905 .702 r
.46397 .57106 m .46089 .57325 L .46267 .57234 L F
.447 .558 .875 r
.82243 .43092 m .82034 .43307 L .82052 .43136 L F
.82243 .43092 m .82431 .43453 L .82034 .43307 L F
.79 .467 0 r
.41866 .64978 m .41758 .64703 L .41619 .64691 L F
.41866 .64978 m .41882 .65063 L .41758 .64703 L F
.775 .74 .216 r
.41866 .64978 m .41933 .6482 L .41882 .65063 L F
.464 .818 .997 r
.22206 .62935 m .21846 .62901 L .22042 .62929 L F
.559 .909 .969 r
.22416 .62843 m .22206 .62935 L .22265 .62811 L F
.609 .948 .928 r
.22265 .62811 m .22206 .62935 L .22042 .62929 L F
.231 .741 .882 r
.20737 .74451 m .20639 .74535 L .20451 .74512 L F
.871 .982 .84 r
.2091 .74402 m .20637 .74704 L .20739 .74453 L F
.716 .288 .231 r
.20783 .7444 m .2091 .74402 L .20732 .74429 L F
.871 .982 .84 r
.2091 .74402 m .20739 .74453 L .2074 .7445 L F
.716 .288 .231 r
.20843 .74453 m .2091 .74402 L .20783 .7444 L F
.231 .741 .882 r
.2072 .74371 m .20496 .74493 L .20678 .74157 L F
.20722 .74381 m .20711 .74387 L .2072 .74371 L F
.20711 .74387 m .20496 .74493 L .2072 .74371 L F
.782 .596 .648 r
.2086 .74204 m .2091 .74402 L .20941 .74109 L F
.913 .72 .629 r
.20941 .74109 m .2073 .74355 L .20706 .7412 L F
.782 .596 .648 r
.2072 .74371 m .2091 .74402 L .20848 .74157 L F
.231 .741 .882 r
.20736 .74451 m .20678 .74461 L .20722 .74381 L F
.20496 .74493 m .20446 .74468 L .20678 .74157 L F
.923 .944 .794 r
.20569 .74065 m .20706 .7412 L .20417 .74507 L F
.716 .288 .231 r
.20606 .74448 m .2091 .74402 L .20505 .74336 L F
.913 .72 .629 r
.20941 .74109 m .2074 .7445 L .2073 .74355 L F
.782 .596 .648 r
.20848 .74157 m .2086 .74204 L .20941 .74109 L F
.231 .741 .882 r
.2074 .7445 m .20736 .74451 L .20706 .7412 L F
.20736 .74451 m .20678 .74157 L .20706 .7412 L F
.782 .596 .648 r
.20505 .74336 m .2072 .74371 L .20848 .74157 L F
.20505 .74336 m .20848 .74157 L .20569 .74065 L F
.20848 .74157 m .20941 .74109 L .20879 .74101 L F
.203 .702 .914 r
.20941 .74109 m .20706 .7412 L .20569 .74065 L F
.782 .596 .648 r
.20848 .74157 m .20879 .74101 L .20569 .74065 L F
.231 .741 .882 r
.20678 .74461 m .20496 .74493 L .20722 .74381 L F
.20496 .74493 m .20417 .74507 L .20446 .74468 L F
.2074 .7445 m .20451 .74512 L .20496 .74493 L F
.20417 .74507 m .20639 .74535 L .2074 .7445 L F
.716 .288 .231 r
.20843 .74453 m .20732 .74429 L .20736 .74451 L F
.231 .741 .882 r
.2074 .7445 m .20739 .74451 L .20737 .74451 L F
.20739 .74451 m .20639 .74535 L .20737 .74451 L F
.20496 .74493 m .20451 .74512 L .20417 .74507 L F
.20417 .74507 m .20736 .74451 L .20637 .74704 L F
.716 .288 .231 r
.20787 .74497 m .20843 .74453 L .20736 .74451 L F
.231 .741 .882 r
.20736 .74451 m .2074 .7445 L .20739 .74453 L F
.20736 .74451 m .20739 .74453 L .20637 .74704 L F
.716 .288 .231 r
.20705 .74559 m .20787 .74497 L .20606 .74448 L F
.20787 .74497 m .20736 .74451 L .20606 .74448 L F
0 .178 .696 r
.20606 .74448 m .20619 .74556 L .20705 .74559 L F
.20619 .74556 m .20637 .74704 L .2069 .74592 L F
.20619 .74556 m .2069 .74592 L .20705 .74559 L F
.716 .288 .231 r
.20736 .74451 m .20732 .74429 L .20606 .74448 L F
0 .178 .696 r
.20505 .74336 m .20553 .7447 L .20606 .74448 L F
.20553 .7447 m .20637 .74704 L .20606 .74448 L F
.533 .328 .548 r
.19604 .76257 m .19631 .76025 L .19399 .76077 L F
.185 .714 .726 r
.19399 .76077 m .19631 .76025 L .19604 .76257 L F
.291 .762 .939 r
.21631 .72601 m .21551 .72659 L .21298 .72611 L F
.753 .674 .775 r
.83643 .43212 m .83757 .43575 L .83393 .43514 L F
0 0 .3 r
.83643 .43212 m .83745 .43503 L .83757 .43575 L F
.82 .99 .734 r
.83745 .43503 m .83614 .43639 L .83757 .43575 L F
.599 .443 .641 r
.31153 .59017 m .31174 .59316 L .30957 .59324 L F
.481 .346 .62 r
.3118 .59509 m .30957 .59324 L .31174 .59316 L F
.3118 .59509 m .30951 .59664 L .30957 .59324 L F
.758 .683 .779 r
.46383 .56589 m .46491 .56909 L .46759 .56632 L F
.093 .253 .737 r
.46383 .56589 m .46598 .56764 L .46491 .56909 L F
0 0 0 r
.46571 .56965 m .46491 .56909 L .46598 .56764 L F
.34 0 0 r
.46813 .56923 m .46608 .56977 L .46571 .56965 L F
0 0 0 r
.46571 .56965 m .46397 .57106 L .46479 .56934 L F
.678 .888 .522 r
.46418 .57028 m .46397 .57106 L .46571 .56965 L F
.34 0 0 r
.46608 .56977 m .46418 .57028 L .46571 .56965 L F
0 0 0 r
.46571 .56965 m .46479 .56934 L .46491 .56909 L F
.685 .55 .695 r
.27896 .57274 m .28264 .57547 L .28236 .57177 L F
.27896 .57274 m .27967 .57565 L .28264 .57547 L F
.274 0 0 r
.27463 .53739 m .27647 .53799 L .27813 .53832 L F
.208 .733 .831 r
.27647 .53799 m .28034 .53772 L .27813 .53832 L F
.127 .066 .512 r
.76019 .41449 m .7605 .41684 L .7631 .41429 L F
.413 0 0 r
.76019 .41449 m .76056 .41522 L .75642 .41419 L F
.515 .734 .973 r
.76019 .41449 m .76296 .41412 L .76175 .41261 L F
.76019 .41449 m .76296 .41412 L .76175 .41261 L F
.127 .066 .512 r
.76019 .41449 m .7631 .41429 L .76056 .41522 L F
.742 .876 .942 r
.55649 .60243 m .55507 .60528 L .5564 .60315 L F
.55649 .60243 m .55226 .60584 L .55507 .60528 L F
.255 .741 .925 r
.21298 .72611 m .21174 .72649 L .2108 .72662 L F
.227 0 0 r
.2097 .73252 m .2099 .73302 L .2086 .73289 L F
.859 .595 .539 r
.53379 .56563 m .53415 .56331 L .53201 .56222 L F
.791 .485 .471 r
.78876 .38895 m .79269 .39165 L .78992 .39004 L F
.486 .329 .594 r
.46838 .62702 m .46844 .62971 L .47084 .62904 L F
.593 .306 .45 r
.46838 .62702 m .47084 .62904 L .47047 .62692 L F
.486 .329 .594 r
.46838 .62702 m .46844 .62971 L .47084 .62904 L F
.651 .119 0 r
.79825 .40285 m .79758 .40373 L .79489 .40192 L F
.663 .133 0 r
.79825 .40285 m .80096 .40473 L .79758 .40373 L F
0 .312 .673 r
.79825 .40285 m .8026 .4048 L .80096 .40473 L F
.625 .5 .69 r
.48813 .61717 m .49057 .61481 L .48781 .61492 L F
.803 .435 .36 r
.50619 .61021 m .50775 .61373 L .50922 .61187 L F
0 0 .133 r
.5111 .60894 m .50922 .61187 L .51069 .61046 L F
.176 0 0 r
.50922 .61187 m .51052 .61283 L .51069 .61046 L F
.50922 .61187 m .50775 .61373 L .51052 .61283 L F
.711 .223 .084 r
.49699 .54453 m .49938 .54659 L .50107 .5457 L F
.722 .238 .095 r
.49938 .54659 m .50304 .54756 L .50107 .5457 L F
.511 .213 .398 r
.47938 .62591 m .48238 .62379 L .47981 .62416 L F
.686 .384 .458 r
.45987 .65057 m .45577 .6482 L .4599 .64795 L F
.45987 .65057 m .45618 .65065 L .45577 .6482 L F
.571 .457 .685 r
.31719 .56221 m .31453 .56018 L .31677 .55961 L F
.31719 .56221 m .31493 .56272 L .31453 .56018 L F
.754 .611 .7 r
.50535 .59354 m .50106 .59354 L .503 .5901 L F
.738 .411 .429 r
.50532 .59569 m .50106 .59354 L .50535 .59354 L F
.979 .897 .554 r
.58029 .57993 m .58191 .57818 L .57996 .57753 L F
.58029 .57993 m .5809 .58085 L .58191 .57818 L F
0 0 0 r
.22346 .69679 m .22219 .69837 L .22306 .69811 L F
.329 0 .061 r
.43367 .58605 m .43658 .58416 L .432 .58471 L F
.41 .158 .419 r
.47397 .61104 m .47358 .61409 L .47092 .61365 L F
.424 .137 .372 r
.47358 .61409 m .47074 .61666 L .47092 .61365 L F
.35 .132 .436 r
.42329 .66566 m .42057 .66783 L .41908 .66577 L F
.42329 .66566 m .42271 .66857 L .42057 .66783 L F
.463 .279 .546 r
.30725 .60217 m .30487 .60539 L .30488 .60276 L F
.501 .728 .974 r
.19478 .61732 m .19507 .61946 L .19276 .61751 L F
.19478 .61732 m .19736 .61919 L .19507 .61946 L F
.912 .895 .481 r
.4898 .54734 m .49024 .54439 L .48815 .54514 L F
.164 0 .247 r
.44187 .65154 m .44363 .65032 L .44527 .65151 L F
.873 .861 .826 r
.44363 .65032 m .44527 .65151 L .44572 .65074 L F
.718 .778 .899 r
.81876 .41026 m .81996 .41184 L .82235 .41075 L F
.536 .431 .681 r
.31347 .5871 m .31359 .58998 L .31153 .59017 L F
.391 .227 .536 r
.31359 .58998 m .31174 .59316 L .31153 .59017 L F
.366 .756 .988 r
.16441 .59929 m .16646 .59905 L .16825 .59996 L F
.472 .805 .999 r
.1687 .59862 m .16825 .59996 L .16646 .59905 L F
.1687 .59862 m .17042 .59957 L .16825 .59996 L F
.71 .703 .842 r
.6621 .43162 m .66588 .43232 L .66496 .42939 L F
.701 .739 .88 r
.66496 .42939 m .66588 .43232 L .66844 .43103 L F
.489 .518 .813 r
.81578 .4096 m .8177 .40671 L .81503 .40739 L F
.81578 .4096 m .81876 .41026 L .8177 .40671 L F
0 0 0 r
.16755 .57471 m .16591 .57573 L .16906 .57509 L F
.529 .861 .995 r
.17125 .57419 m .16965 .57377 L .16906 .57509 L F
.583 .911 .976 r
.16965 .57377 m .16755 .57471 L .16906 .57509 L F
0 0 0 r
.83995 .41918 m .83735 .42047 L .83961 .41949 L F
0 0 .501 r
.83735 .42047 m .83854 .42111 L .83961 .41949 L F
.83735 .42047 m .83849 .42306 L .83854 .42111 L F
.477 .016 .077 r
.17594 .60963 m .17753 .61054 L .17964 .60866 L F
.847 .719 .722 r
.17753 .61054 m .18183 .6082 L .17964 .60866 L F
.915 .633 .494 r
.5744 .53128 m .57834 .53284 L .57648 .52966 L F
.768 .638 .717 r
.5744 .53128 m .5771 .53355 L .57834 .53284 L F
.875 .775 .275 r
.51396 .59804 m .51457 .59649 L .51339 .59567 L F
.51396 .59804 m .51416 .59906 L .51457 .59649 L F
.52 .4 .657 r
.5456 .56886 m .54962 .57112 L .54962 .56859 L F
.5456 .56886 m .54729 .57188 L .54962 .57112 L F
.426 .318 .628 r
.31576 .56878 m .31607 .57122 L .31414 .57182 L F
.581 .445 .66 r
.31724 .57629 m .31414 .57182 L .31607 .57122 L F
.31724 .57629 m .31516 .57752 L .31414 .57182 L F
.768 .7 .788 r
.67689 .42868 m .68059 .42919 L .67933 .42556 L F
.67689 .42868 m .67853 .43001 L .68059 .42919 L F
.805 .716 .767 r
.67933 .42556 m .68059 .42919 L .68117 .42683 L F
.749 .772 .872 r
.79207 .43191 m .79056 .43622 L .78879 .43467 L F
.79207 .43191 m .79272 .43504 L .79056 .43622 L F
.919 .541 .282 r
.78879 .43467 m .79056 .43622 L .78951 .43723 L F
.036 0 0 r
.22941 .53746 m .23143 .53725 L .23352 .53663 L F
.311 .77 .948 r
.22975 .53679 m .23345 .53704 L .23143 .53725 L F
.23345 .53704 m .23372 .53706 L .23143 .53725 L F
.036 0 0 r
.22914 .53751 m .23143 .53725 L .22941 .53746 L F
.027 0 0 r
.23143 .53725 m .23516 .53673 L .23352 .53663 L F
.308 0 .138 r
.47294 .60533 m .47406 .60705 L .47545 .60462 L F
.47294 .60533 m .47188 .60764 L .47406 .60705 L F
.702 .787 .917 r
.1876 .6148 m .18322 .61442 L .18553 .61453 L F
0 0 .524 r
.18721 .6138 m .1876 .6148 L .18553 .61453 L F
.18721 .6138 m .18915 .61665 L .1876 .6148 L F
.639 .346 .457 r
.44381 .57452 m .4464 .57465 L .44686 .57251 L F
.666 .438 .565 r
.4464 .57465 m .45041 .57212 L .44686 .57251 L F
.647 .773 .307 r
.57981 .58805 m .58004 .5876 L .58049 .58578 L F
.57981 .58805 m .57916 .58945 L .58004 .5876 L F
.821 .584 .581 r
.55512 .50713 m .55878 .50546 L .55508 .50553 L F
.55512 .50713 m .55877 .50807 L .55878 .50546 L F
.735 .224 0 r
.49911 .57248 m .50038 .57415 L .50195 .57514 L F
.852 .426 .213 r
.5007 .57651 m .50195 .57514 L .50038 .57415 L F
.5007 .57651 m .50339 .57773 L .50195 .57514 L F
.829 .428 .287 r
.50195 .57514 m .50339 .57773 L .50544 .57796 L F
.712 .378 .412 r
.55524 .51741 m .55176 .51933 L .5513 .51815 L F
.55524 .51741 m .55363 .51983 L .55176 .51933 L F
.775 .46 .453 r
.55524 .51741 m .55749 .52042 L .55363 .51983 L F
.799 .457 .408 r
.55915 .52022 m .55749 .52042 L .55524 .51741 L F
.529 .318 .538 r
.48696 .62394 m .4866 .62641 L .48499 .62666 L F
.444 .158 .383 r
.48943 .62367 m .4866 .62641 L .48696 .62394 L F
.757 .674 .77 r
.2811 .56608 m .27628 .56279 L .27802 .5641 L F
.2811 .56608 m .27717 .56579 L .27628 .56279 L F
.551 .811 .994 r
.18145 .61325 m .18099 .61499 L .17912 .61397 L F
.18145 .61325 m .18322 .61442 L .18099 .61499 L F
.63 .903 .985 r
.23029 .685 m .23414 .68459 L .23258 .68398 L F
.616 .642 .853 r
.74011 .3956 m .74148 .39175 L .7392 .39208 L F
.74011 .3956 m .74258 .39483 L .74148 .39175 L F
.487 .209 .417 r
.48128 .57208 m .48375 .57171 L .4843 .56946 L F
.4843 .56946 m .48375 .57171 L .48128 .57208 L F
.439 .165 .4 r
.4843 .56946 m .48618 .57105 L .48628 .5687 L F
.4843 .56946 m .48375 .57171 L .48618 .57105 L F
.48618 .57105 m .4843 .56946 L .48628 .5687 L F
.48618 .57105 m .48375 .57171 L .4843 .56946 L F
.272 .003 .309 r
.15721 .56339 m .15835 .56481 L .15908 .56265 L F
.15721 .56339 m .15647 .56569 L .15835 .56481 L F
0 .156 .697 r
.42485 .66872 m .42534 .66803 L .42329 .66566 L F
.832 .703 .721 r
.42195 .67012 m .42251 .67148 L .42123 .67057 L F
.86 .752 .742 r
.42259 .67033 m .42534 .66803 L .42485 .66872 L F
.832 .703 .721 r
.42534 .66803 m .42259 .67033 L .42195 .67012 L F
.86 .752 .742 r
.4225 .67039 m .42534 .66803 L .42259 .67033 L F
.42259 .67033 m .42485 .66872 L .42453 .67079 L F
.42328 .67054 m .42453 .67079 L .42451 .67094 L F
.42259 .67033 m .42453 .67079 L .42328 .67054 L F
.832 .703 .721 r
.42328 .67054 m .42251 .67148 L .42195 .67012 L F
.86 .752 .742 r
.4225 .67039 m .42251 .67148 L .42328 .67054 L F
.832 .703 .721 r
.42534 .66803 m .42328 .67054 L .42259 .67033 L F
.86 .752 .742 r
.4225 .67039 m .42328 .67054 L .42534 .66803 L F
.42451 .67094 m .42485 .66872 L .42694 .67159 L F
.4225 .67039 m .42259 .67033 L .42451 .67094 L F
.746 .633 .735 r
.21684 .72018 m .21346 .72085 L .21604 .71841 L F
.493 .046 .116 r
.21333 .72266 m .21346 .72085 L .21684 .72018 L F
.515 .525 .804 r
.21817 .71775 m .21684 .72018 L .21604 .71841 L F
.21817 .71775 m .2189 .7203 L .21684 .72018 L F
.28 0 0 r
.2189 .7203 m .21333 .72266 L .21684 .72018 L F
.445 .541 .86 r
.41411 .63874 m .4169 .63904 L .41535 .63677 L F
.608 .675 .888 r
.2035 .61957 m .20396 .62152 L .20092 .6204 L F
.367 .621 .95 r
.20502 .6201 m .20396 .62152 L .2035 .61957 L F
.20502 .6201 m .20735 .6224 L .20396 .62152 L F
.455 .065 .209 r
.24791 .62326 m .25027 .62313 L .25182 .62074 L F
.396 0 .079 r
.25272 .62245 m .25182 .62074 L .25027 .62313 L F
.25272 .62245 m .25428 .62049 L .25182 .62074 L F
.588 .723 .937 r
.47613 .56108 m .47722 .5589 L .47535 .55935 L F
.47613 .56108 m .4783 .56037 L .47722 .5589 L F
.688 .692 .849 r
.66844 .43103 m .67209 .4322 L .67095 .4288 L F
.732 .702 .821 r
.67095 .4288 m .67209 .4322 L .67472 .42941 L F
.496 .85 .993 r
.45415 .67851 m .45281 .67784 L .45052 .67853 L F
.45415 .67851 m .45281 .67784 L .45052 .67853 L F
.586 .663 .892 r
.15748 .58922 m .15696 .59248 L .1565 .58941 L F
.15748 .58922 m .15929 .59198 L .15696 .59248 L F
.52 0 0 r
.483 .56242 m .48099 .5619 L .47943 .56086 L F
.06 .608 .836 r
.483 .56242 m .48496 .56248 L .48099 .5619 L F
.671 .224 .181 r
.48496 .56248 m .48336 .56387 L .48099 .5619 L F
.111 .285 .761 r
.48099 .5619 m .48336 .56387 L .48277 .56308 L F
.48099 .5619 m .48277 .56308 L .48116 .56094 L F
.52 0 0 r
.47943 .56086 m .48099 .5619 L .4783 .56037 L F
.572 .263 .406 r
.28481 .62736 m .28417 .62936 L .28171 .62944 L F
.518 .245 .439 r
.28718 .62681 m .28417 .62936 L .28481 .62736 L F
.199 0 .106 r
.16238 .55932 m .16296 .56116 L .16394 .55939 L F
.16238 .55932 m .161 .56191 L .16296 .56116 L F
.73 .939 .615 r
.56237 .56368 m .56012 .56649 L .56091 .56497 L F
.827 .878 .882 r
.56391 .56218 m .56237 .56368 L .56118 .56225 L F
.994 .801 .536 r
.56237 .56368 m .56091 .56497 L .56118 .56225 L F
.426 .538 .867 r
.43862 .6293 m .43708 .63024 L .43588 .62908 L F
.43862 .6293 m .43967 .6299 L .43708 .63024 L F
.368 .409 .772 r
.43708 .63024 m .43862 .6293 L .43588 .62908 L F
.43708 .63024 m .43963 .63195 L .43862 .6293 L F
.389 .222 .53 r
.25929 .61172 m .26113 .61358 L .26168 .61137 L F
.25929 .61172 m .2592 .61435 L .26113 .61358 L F
0 0 0 r
.53045 .52083 m .53148 .51945 L .5321 .51847 L F
.63 .944 .731 r
.52799 .5222 m .53148 .51945 L .53045 .52083 L F
0 0 0 r
.53022 .52054 m .53094 .52029 L .53148 .51945 L F
.674 .246 .223 r
.53277 .51751 m .53148 .51945 L .53469 .51956 L F
.275 .759 .922 r
.53358 .51952 m .53418 .51918 L .53469 .51956 L F
.53148 .51945 m .53418 .51918 L .53358 .51952 L F
.674 .246 .223 r
.53277 .51751 m .53469 .51956 L .53523 .51699 L F
0 0 0 r
.53022 .52054 m .53259 .51999 L .53418 .51918 L F
.177 0 0 r
.53259 .51999 m .53477 .51884 L .53418 .51918 L F
0 0 0 r
.53469 .51956 m .53766 .51637 L .53523 .51699 L F
.53469 .51956 m .53643 .51797 L .53766 .51637 L F
.177 0 0 r
.53477 .51884 m .53643 .51797 L .53418 .51918 L F
0 0 0 r
.53094 .52029 m .53418 .51918 L .53148 .51945 L F
.5321 .51847 m .53148 .51945 L .53277 .51751 L F
.679 .621 .784 r
.78218 .38687 m .78374 .39075 L .7862 .3894 L F
.198 .723 .847 r
.53909 .51942 m .53469 .51956 L .53649 .5197 L F
.772 .669 .75 r
.27856 .57192 m .27967 .57565 L .27627 .57526 L F
.083 .217 .705 r
.28052 .57381 m .27924 .57422 L .27856 .57192 L F
.28052 .57381 m .27856 .57192 L .28236 .57177 L F
.629 .517 .707 r
.28236 .57177 m .28503 .57422 L .28406 .57235 L F
.28236 .57177 m .28264 .57547 L .28503 .57422 L F
.125 0 0 r
.28406 .57235 m .28052 .57381 L .28236 .57177 L F
.97 .652 .308 r
.28052 .57381 m .27856 .57192 L .27775 .57369 L F
.28052 .57381 m .2788 .5709 L .27856 .57192 L F
.27987 .5727 m .27933 .57331 L .2788 .5709 L F
.28052 .57381 m .27933 .57331 L .27987 .5727 L F
0 0 0 r
.27775 .57369 m .27933 .57331 L .28052 .57381 L F
.073 0 .185 r
.27813 .57439 m .27894 .57376 L .27933 .57331 L F
.27894 .57376 m .2805 .57252 L .27933 .57331 L F
.221 .715 .919 r
.27933 .57331 m .28149 .5735 L .28052 .57381 L F
.125 0 0 r
.28406 .57235 m .28262 .57359 L .28052 .57381 L F
.221 .715 .919 r
.28149 .5735 m .28262 .57359 L .28052 .57381 L F
.083 .217 .705 r
.28052 .57381 m .27967 .57565 L .27924 .57422 L F
.558 .15 .223 r
.27967 .57565 m .28167 .5773 L .28264 .57547 L F
.072 .203 .695 r
.28052 .57381 m .28167 .5773 L .27967 .57565 L F
.777 .853 .908 r
.19435 .76876 m .19528 .76951 L .19334 .77069 L F
.518 .263 .469 r
.19334 .77069 m .19505 .77184 L .19092 .7718 L F
.19334 .77069 m .19528 .76951 L .19505 .77184 L F
.435 .736 .99 r
.19619 .76817 m .19528 .76951 L .19435 .76876 L F
.134 .677 .822 r
.19092 .7718 m .19155 .7718 L .19187 .77172 L F
.19268 .77166 m .19505 .77184 L .1929 .77164 L F
.19155 .7718 m .19283 .77181 L .19268 .77166 L F
.19283 .77181 m .19505 .77184 L .19268 .77166 L F
.131 0 .079 r
.19619 .76817 m .19473 .76864 L .19262 .77167 L F
.19619 .76817 m .19262 .77167 L .19268 .77166 L F
.19619 .76817 m .19268 .77166 L .19375 .77013 L F
.19268 .77166 m .19262 .77167 L .19249 .77186 L F
.19268 .77166 m .19249 .77186 L .19265 .77163 L F
.19268 .77166 m .19265 .77163 L .19375 .77013 L F
.652 .317 .393 r
.19249 .77186 m .19239 .77167 L .19092 .7718 L F
.621 .784 .96 r
.19244 .77004 m .1891 .77004 L .19107 .76905 L F
.19177 .77045 m .1891 .77004 L .19244 .77004 L F
.652 .317 .393 r
.19239 .77167 m .19107 .76905 L .19092 .7718 L F
.134 .677 .822 r
.19092 .7718 m .19187 .77172 L .19237 .77159 L F
.19155 .7718 m .1929 .77164 L .19237 .77159 L F
.131 0 .079 r
.19473 .76864 m .19435 .76876 L .19425 .76893 L F
.621 .784 .96 r
.19334 .77069 m .19177 .77045 L .19244 .77004 L F
.777 .853 .908 r
.19435 .76876 m .19334 .77069 L .19107 .76905 L F
.701 .979 .905 r
.19345 .77266 m .19378 .77247 L .19343 .77292 L F
.172 0 0 r
.19505 .77184 m .1933 .77216 L .1929 .77164 L F
.1929 .77164 m .1933 .77216 L .19237 .77159 L F
.131 0 .079 r
.19277 .77146 m .19275 .77143 L .19249 .77186 L F
.19473 .76864 m .19275 .77143 L .19277 .77146 L F
.652 .317 .393 r
.19249 .77186 m .19435 .76876 L .19107 .76905 L F
.701 .979 .905 r
.19375 .77013 m .19249 .77186 L .19237 .77159 L F
.19375 .77013 m .19237 .77159 L .19378 .77247 L F
.19375 .77013 m .19378 .77247 L .19345 .77266 L F
.172 0 0 r
.19468 .77191 m .19378 .77247 L .1933 .77216 L F
.19505 .77184 m .19378 .77247 L .19468 .77191 L F
.131 0 .079 r
.19473 .76864 m .19425 .76893 L .19275 .77143 L F
.048 .568 .871 r
.23303 .64362 m .23472 .64444 L .23576 .64416 L F
.769 .59 .656 r
.57107 .50811 m .57258 .51122 L .57275 .50874 L F
.518 .579 .856 r
.15098 .61074 m .15167 .61244 L .15311 .61035 L F
.567 .559 .805 r
.15167 .61244 m .1548 .61359 L .15311 .61035 L F
.502 .839 .998 r
.76642 .41439 m .76577 .4135 L .76296 .41412 L F
.484 .827 .998 r
.76908 .41383 m .76577 .4135 L .76642 .41439 L F
.8 .603 .635 r
.43022 .66951 m .43016 .67235 L .42694 .67159 L F
.346 .088 .373 r
.43284 .66919 m .43016 .67235 L .43022 .66951 L F
.422 .716 .985 r
.81152 .40614 m .81256 .40751 L .81503 .40739 L F
.338 .317 .689 r
.41619 .64691 m .4175 .64461 L .41658 .64514 L F
.739 .645 .755 r
.20804 .71929 m .20776 .7207 L .20985 .71829 L F
.873 .858 .823 r
.55771 .5748 m .56048 .57503 L .55836 .57752 L F
.769 .641 .72 r
.46383 .56589 m .46759 .56632 L .46676 .56338 L F
.573 .524 .762 r
.46676 .56338 m .46759 .56632 L .469 .56408 L F
.711 .636 .772 r
.74258 .39483 m .74404 .39872 L .74633 .39582 L F
.556 .417 .646 r
.74404 .39872 m .74681 .39787 L .74633 .39582 L F
.545 .745 .969 r
.81312 .43026 m .81146 .43225 L .81043 .43113 L F
.81312 .43026 m .81408 .43178 L .81146 .43225 L F
.511 .634 .907 r
.66335 .42299 m .65963 .41985 L .66085 .42345 L F
.466 .13 .311 r
.66025 .42591 m .66335 .42299 L .66085 .42345 L F
.468 .802 .999 r
.31166 .55083 m .31392 .55041 L .31557 .55135 L F
.347 .72 .986 r
.31622 .55019 m .31557 .55135 L .31392 .55041 L F
.31622 .55019 m .3178 .55128 L .31557 .55135 L F
.918 .918 .532 r
.5169 .60756 m .51565 .61038 L .5161 .61134 L F
.715 .493 0 r
.51627 .61271 m .5161 .61134 L .51565 .61038 L F
.51627 .61271 m .51656 .61433 L .5161 .61134 L F
.502 .527 .815 r
.74681 .39787 m .74803 .40157 L .75043 .40117 L F
.839 .944 .89 r
.24654 .66929 m .24659 .6671 L .24879 .66902 L F
.24654 .66929 m .24488 .66867 L .24659 .6671 L F
.759 .889 .483 r
.57379 .59612 m .57392 .59543 L .57324 .59726 L F
.874 .943 .858 r
.57082 .59725 m .57324 .59726 L .57392 .59543 L F
.57082 .59725 m .57185 .59866 L .57324 .59726 L F
.743 .659 .767 r
.43016 .67235 m .42964 .67544 L .42796 .67534 L F
.584 .092 .052 r
.42964 .67544 m .4305 .67693 L .42796 .67534 L F
.483 .412 .701 r
.43307 .67443 m .42964 .67544 L .43016 .67235 L F
.657 .454 .597 r
.43307 .67443 m .4305 .67693 L .42964 .67544 L F
.905 .53 .309 r
.50422 .57981 m .50544 .57796 L .50339 .57773 L F
.50422 .57981 m .50634 .58065 L .50544 .57796 L F
.435 .158 .391 r
.47672 .60849 m .47635 .6107 L .47397 .61104 L F
.455 .174 .397 r
.47876 .61015 m .47672 .60849 L .47877 .60749 L F
.47876 .61015 m .47635 .6107 L .47672 .60849 L F
.883 .791 .301 r
.8441 .42305 m .84456 .42065 L .8444 .41823 L F
.116 .576 .918 r
.80424 .4443 m .80776 .44578 L .80773 .44495 L F
.035 .493 .883 r
.80773 .44495 m .80776 .44578 L .81064 .44667 L F
.34 .714 .984 r
.81165 .44776 m .81306 .44671 L .81064 .44667 L F
.81165 .44776 m .81436 .44789 L .81306 .44671 L F
.384 .722 .989 r
.41581 .63512 m .41711 .63447 L .41693 .63589 L F
.933 .652 .483 r
.41535 .63677 m .41693 .63589 L .41581 .63512 L F
.41535 .63677 m .4169 .63904 L .41693 .63589 L F
.882 .735 .694 r
.57701 .52026 m .57757 .52068 L .57627 .51692 L F
.819 .529 .498 r
.57407 .52243 m .57757 .52068 L .57701 .52026 L F
.57407 .52243 m .57765 .52303 L .57757 .52068 L F
.754 .492 .535 r
.45304 .6603 m .45186 .6625 L .45056 .65981 L F
.179 0 .196 r
.45553 .66185 m .45304 .6603 L .45558 .65981 L F
.45553 .66185 m .45186 .6625 L .45304 .6603 L F
.238 .483 .889 r
.27309 .56119 m .27359 .55934 L .27184 .55921 L F
.27309 .56119 m .27568 .56211 L .27359 .55934 L F
.822 .979 .689 r
.5763 .59235 m .57574 .59409 L .57792 .59118 L F
.53 .873 .62 r
.57766 .59113 m .57792 .59118 L .57916 .58945 L F
.57766 .59113 m .5763 .59235 L .57792 .59118 L F
.622 .764 .947 r
.83965 .40218 m .83601 .4014 L .83897 .40059 L F
.523 .707 .955 r
.83897 .40059 m .84153 .40015 L .83965 .40218 L F
.495 .662 .936 r
.84153 .40015 m .84207 .40193 L .83965 .40218 L F
.203 0 0 r
.2088 .55501 m .2108 .55498 L .20807 .55577 L F
.01 0 .3 r
.26688 .60261 m .26647 .60506 L .26816 .60155 L F
0 0 .54 r
.7605 .41684 m .76106 .42077 L .76129 .41914 L F
.241 .419 .838 r
.76106 .42077 m .76342 .42058 L .76129 .41914 L F
.76106 .42077 m .76428 .42264 L .76342 .42058 L F
.597 .071 0 r
.77019 .39141 m .7732 .39107 L .76956 .39005 L F
.77019 .39141 m .77394 .39171 L .7732 .39107 L F
.958 .617 .27 r
.50906 .58629 m .51079 .58952 L .51047 .58732 L F
.512 .296 .522 r
.46825 .64192 m .46826 .64446 L .46572 .64466 L F
.581 .382 .576 r
.47105 .64156 m .46826 .64446 L .46825 .64192 L F
.273 .43 .837 r
.76797 .42372 m .76905 .42661 L .77062 .42511 L F
.292 .462 .857 r
.76905 .42661 m .77212 .42811 L .77062 .42511 L F
.927 .625 .451 r
.56432 .52978 m .56267 .53128 L .56246 .52877 L F
.959 .697 .496 r
.56432 .52978 m .56431 .5322 L .56267 .53128 L F
.557 .006 0 r
.79269 .39165 m .79562 .39377 L .79389 .39237 L F
.155 .16 .612 r
.20462 .7295 m .20419 .73298 L .20459 .73181 L F
.472 .892 .819 r
.23332 .6793 m .2334 .67987 L .23025 .67955 L F
.23332 .6793 m .23467 .67918 L .2334 .67987 L F
.484 .612 .902 r
.16359 .58997 m .16365 .59339 L .16125 .59045 L F
.16359 .58997 m .16542 .59274 L .16365 .59339 L F
0 .103 .644 r
.45137 .65113 m .45161 .6507 L .45057 .64978 L F
.614 .272 .367 r
.45415 .65132 m .45398 .65365 L .45137 .65113 L F
0 .103 .644 r
.45137 .65113 m .45398 .65365 L .45161 .6507 L F
.887 .916 .517 r
.22922 .68055 m .22778 .68519 L .23029 .685 L F
.232 0 .163 r
.46572 .64466 m .46566 .64649 L .46235 .64771 L F
.5 .086 .186 r
.46716 .64648 m .46572 .64466 L .46826 .64446 L F
.46716 .64648 m .46564 .64734 L .46572 .64466 L F
.831 .527 .476 r
.4633 .64348 m .4666 .64605 L .46578 .64299 L F
.4666 .64605 m .46716 .64648 L .46693 .64589 L F
.4666 .64605 m .46693 .64589 L .46578 .64299 L F
.232 0 .163 r
.46566 .64649 m .46564 .64734 L .46335 .64759 L F
.46566 .64649 m .46335 .64759 L .46235 .64771 L F
.423 .306 .615 r
.40718 .60863 m .40774 .61169 L .40944 .61066 L F
.413 .726 .989 r
.18841 .6379 m .19271 .63883 L .19242 .63798 L F
0 .135 .674 r
.19271 .63883 m .19264 .63775 L .19242 .63798 L F
0 .171 .7 r
.19271 .63883 m .19461 .64059 L .19264 .63775 L F
.729 .405 .431 r
.50619 .61021 m .50481 .61375 L .50775 .61373 L F
.584 .45 .665 r
.31813 .56602 m .31493 .56272 L .31719 .56221 L F
.31813 .56602 m .31512 .56749 L .31493 .56272 L F
.401 .776 .993 r
.25192 .53686 m .2543 .53662 L .2559 .53753 L F
.162 0 0 r
.2543 .53662 m .25797 .53736 L .2559 .53753 L F
.392 .631 .949 r
.29867 .54173 m .2978 .54314 L .29644 .54153 L F
.29867 .54173 m .30049 .54361 L .2978 .54314 L F
.257 .768 .82 r
.18368 .78697 m .18644 .78688 L .18657 .78658 L F
.762 .284 .104 r
.80158 .40603 m .80096 .40473 L .8026 .4048 L F
.428 0 0 r
.8026 .4048 m .80411 .40612 L .80158 .40603 L F
.8026 .4048 m .80476 .4052 L .80411 .40612 L F
.38 .84 .896 r
.23899 .67845 m .23467 .67918 L .23754 .67901 L F
.531 .423 .676 r
.23899 .67845 m .24122 .67797 L .24061 .67386 L F
.189 0 0 r
.2393 .67969 m .23899 .67845 L .23754 .67901 L F
.2393 .67969 m .24122 .67797 L .23899 .67845 L F
.975 .796 .376 r
.51656 .61433 m .51635 .61676 L .51695 .61774 L F
.997 .833 .557 r
.51635 .61676 m .51679 .62036 L .51695 .61774 L F
.859 .731 .721 r
.57825 .57127 m .58117 .57294 L .58203 .56922 L F
.567 .458 .69 r
.31488 .58049 m .31268 .58339 L .31491 .58212 L F
.724 .703 .83 r
.67472 .42941 m .67853 .43001 L .67689 .42868 L F
.649 .154 .06 r
.48058 .63148 m .47665 .63137 L .47836 .62968 L F
.601 .217 .287 r
.48099 .6299 m .48058 .63148 L .47836 .62968 L F
0 0 .474 r
.51066 .60516 m .5111 .60894 L .51135 .60753 L F
0 0 .333 r
.51069 .61046 m .51135 .60753 L .5111 .60894 L F
.681 .387 .469 r
.47084 .62904 m .47425 .62646 L .47047 .62692 L F
.47084 .62904 m .47333 .62943 L .47425 .62646 L F
.526 .233 .412 r
.47425 .62646 m .47649 .62872 L .47682 .6261 L F
.47425 .62646 m .47333 .62943 L .47649 .62872 L F
.535 .742 .971 r
.20092 .6204 m .19736 .61919 L .19894 .61871 L F
.605 .781 .965 r
.20169 .61798 m .20092 .6204 L .19894 .61871 L F
.20169 .61798 m .2035 .61957 L .20092 .6204 L F
.538 .61 .873 r
.32043 .55158 m .31932 .55403 L .3178 .55128 L F
.32043 .55158 m .32149 .55357 L .31932 .55403 L F
.477 .309 .574 r
.32149 .55357 m .31933 .55657 L .31932 .55403 L F
.432 .782 .997 r
.21894 .64399 m .21887 .64275 L .21714 .64307 L F
.21894 .64399 m .22114 .6436 L .21887 .64275 L F
.842 .789 .8 r
.56521 .56064 m .56391 .56218 L .56324 .55923 L F
.212 .734 .847 r
.23095 .62702 m .23092 .62747 L .22874 .62776 L F
.23095 .62702 m .23309 .62719 L .23092 .62747 L F
.309 0 .03 r
.46136 .67448 m .46523 .67216 L .46287 .67551 L F
.52 .37 .618 r
.46523 .67216 m .46529 .67501 L .46287 .67551 L F
.468 .802 .999 r
.46529 .67501 m .46136 .67448 L .46287 .67551 L F
.746 .771 .873 r
.79545 .43233 m .79272 .43504 L .79207 .43191 L F
.568 .91 .688 r
.49852 .58821 m .49757 .58931 L .49972 .58724 L F
0 .285 .786 r
.50023 .59113 m .49852 .58821 L .49989 .59099 L F
.847 .515 .424 r
.503 .5901 m .50035 .59085 L .49972 .58724 L F
.50035 .59085 m .49986 .59031 L .49972 .58724 L F
.967 .642 .314 r
.49972 .58724 m .49986 .59031 L .49852 .58821 L F
0 .285 .786 r
.49956 .58998 m .49967 .59002 L .49852 .58821 L F
.967 .642 .314 r
.49986 .59031 m .49989 .59099 L .49852 .58821 L F
0 .285 .786 r
.49967 .59002 m .50147 .59056 L .49852 .58821 L F
.792 .998 .799 r
.49989 .59099 m .49798 .59353 L .50023 .59113 L F
.731 .807 .912 r
.50106 .59354 m .49921 .59353 L .49986 .59248 L F
.50106 .59354 m .49955 .59221 L .50036 .59202 L F
0 .285 .786 r
.50023 .59113 m .50043 .59104 L .49956 .58998 L F
.925 .87 .764 r
.50035 .59085 m .50046 .59126 L .49989 .59099 L F
.50046 .59126 m .50106 .59354 L .50027 .59182 L F
.042 0 .387 r
.50023 .59113 m .50011 .59208 L .50027 .59182 L F
.50023 .59113 m .50027 .59182 L .50042 .59137 L F
.699 .5 .616 r
.49955 .59221 m .50011 .59208 L .50023 .59113 L F
.925 .87 .764 r
.50046 .59126 m .50027 .59182 L .49989 .59099 L F
.042 0 .387 r
.50042 .59137 m .50027 .59182 L .50049 .59146 L F
.925 .87 .764 r
.503 .5901 m .50133 .59305 L .50043 .59104 L F
.50044 .59083 m .50043 .59104 L .50035 .59085 L F
.503 .5901 m .50043 .59104 L .50044 .59083 L F
.042 0 .387 r
.50043 .59104 m .50202 .59339 L .50147 .59056 L F
.50023 .59113 m .50042 .59137 L .50043 .59104 L F
.50042 .59137 m .50202 .59339 L .50043 .59104 L F
.925 .87 .764 r
.50133 .59305 m .50106 .59354 L .50035 .59085 L F
.744 .401 .4 r
.50147 .59549 m .49798 .59353 L .50106 .59354 L F
.738 .411 .429 r
.50532 .59569 m .50147 .59549 L .50106 .59354 L F
.744 .401 .4 r
.50147 .59549 m .49766 .5952 L .49798 .59353 L F
.68 .176 .037 r
.49766 .5952 m .49989 .59707 L .49958 .59605 L F
.668 .218 .174 r
.49944 .59533 m .49989 .59707 L .49766 .5952 L F
.699 .5 .616 r
.49766 .5952 m .49958 .59605 L .49962 .59576 L F
.668 .218 .174 r
.50147 .59549 m .50084 .59612 L .49944 .59533 L F
.50084 .59612 m .49962 .59576 L .49944 .59533 L F
.731 .807 .912 r
.49921 .59353 m .49798 .59353 L .49986 .59248 L F
.699 .5 .616 r
.49766 .5952 m .49962 .59576 L .50011 .59208 L F
.668 .218 .174 r
.50084 .59612 m .50008 .59688 L .49984 .59629 L F
.50084 .59612 m .49984 .59629 L .49981 .59582 L F
0 0 0 r
.50216 .59566 m .49989 .59707 L .50147 .59549 L F
.243 0 .187 r
.49982 .59602 m .49989 .59707 L .50216 .59566 L F
.49958 .59605 m .49989 .59707 L .49982 .59602 L F
.341 0 0 r
.50532 .59569 m .50454 .59605 L .50147 .59549 L F
.243 0 .187 r
.49969 .59593 m .50216 .59566 L .50202 .59339 L F
.49958 .59605 m .49982 .59602 L .49969 .59593 L F
.49982 .59602 m .50216 .59566 L .49969 .59593 L F
.668 .218 .174 r
.49981 .59582 m .49982 .59602 L .49962 .59576 L F
.49982 .59602 m .49984 .59629 L .49969 .59593 L F
.49982 .59602 m .49969 .59593 L .49962 .59576 L F
.042 0 .387 r
.49963 .59579 m .49958 .59605 L .49969 .59593 L F
.668 .218 .174 r
.50008 .59688 m .49989 .59707 L .49944 .59533 L F
.042 0 .387 r
.50049 .59146 m .49963 .59579 L .50202 .59339 L F
.49963 .59579 m .49969 .59593 L .50202 .59339 L F
.50011 .59208 m .49958 .59605 L .50049 .59146 L F
.731 .807 .912 r
.49986 .59248 m .49798 .59353 L .49955 .59221 L F
.50036 .59202 m .49955 .59221 L .5002 .59167 L F
.699 .5 .616 r
.49766 .5952 m .50011 .59208 L .49955 .59221 L F
.49766 .5952 m .49955 .59221 L .49798 .59353 L F
.49955 .59221 m .50023 .59113 L .49798 .59353 L F
.731 .807 .912 r
.5002 .59167 m .49798 .59353 L .49989 .59099 L F
0 .285 .786 r
.50043 .59104 m .50049 .59101 L .50035 .59085 L F
.50043 .59104 m .50035 .59085 L .49956 .58998 L F
.50049 .59101 m .50147 .59056 L .49956 .58998 L F
.847 .515 .424 r
.50035 .59085 m .49989 .59099 L .49986 .59031 L F
.214 .399 .83 r
.77635 .43522 m .77805 .43849 L .77945 .43716 L F
.255 .468 .874 r
.77805 .43849 m .78131 .43996 L .77945 .43716 L F
.406 .798 .988 r
.18943 .78481 m .18986 .78375 L .18809 .78494 L F
.18943 .78481 m .19174 .7845 L .18986 .78375 L F
.901 .56 .39 r
.57932 .57464 m .58117 .57294 L .57825 .57127 L F
.266 .369 .783 r
.77271 .42201 m .77135 .42444 L .77154 .42236 L F
.509 .68 .942 r
.77271 .42201 m .77373 .42369 L .77135 .42444 L F
.393 .836 .94 r
.23516 .53673 m .23748 .53612 L .23954 .53651 L F
.273 .77 .891 r
.23748 .53612 m .24165 .53607 L .23954 .53651 L F
.828 .877 .88 r
.55836 .57752 m .55502 .57812 L .55706 .57618 L F
.903 .766 .701 r
.55836 .57752 m .5549 .58032 L .55502 .57812 L F
.55836 .57752 m .55664 .58144 L .5549 .58032 L F
.873 .858 .823 r
.55771 .5748 m .55836 .57752 L .55706 .57618 L F
.639 .093 0 r
.79995 .39527 m .8027 .39719 L .80343 .39635 L F
.386 0 0 r
.80343 .39635 m .8027 .39719 L .80646 .39714 L F
.915 .633 .494 r
.5744 .53128 m .57648 .52966 L .57547 .52842 L F
.986 .748 .357 r
.57553 .52592 m .57547 .52842 L .57648 .52966 L F
.622 .838 .983 r
.81767 .43207 m .81408 .43178 L .8167 .43105 L F
.575 .807 .987 r
.81933 .43014 m .81767 .43207 L .8167 .43105 L F
.81933 .43014 m .82052 .43136 L .81767 .43207 L F
.862 .615 .563 r
.56314 .5236 m .56319 .5263 L .56089 .52296 L F
.48 .134 .302 r
.28167 .5773 m .28503 .57422 L .28264 .57547 L F
.473 .67 .95 r
.18841 .6379 m .18872 .63513 L .18663 .63551 L F
.18841 .6379 m .19242 .63798 L .18872 .63513 L F
.838 .582 .552 r
.57269 .51622 m .57623 .51448 L .57471 .51369 L F
.57269 .51622 m .57627 .51692 L .57623 .51448 L F
0 0 .294 r
.20985 .71829 m .21054 .7203 L .21192 .7172 L F
.20985 .71829 m .20911 .72203 L .21054 .7203 L F
.933 .712 .58 r
.41758 .64703 m .41882 .65063 L .41933 .6482 L F
.532 .127 .219 r
.25605 .6424 m .25958 .64154 L .25773 .64455 L F
.968 .726 .516 r
.26411 .64115 m .2623 .64277 L .25997 .6434 L F
.26418 .64112 m .2623 .64277 L .26411 .64115 L F
0 .083 .597 r
.26181 .64571 m .26059 .64706 L .25997 .6434 L F
.563 .5 .743 r
.25997 .6434 m .25856 .64727 L .25773 .64455 L F
.25997 .6434 m .26059 .64706 L .25856 .64727 L F
.581 .198 .281 r
.26181 .64571 m .25997 .6434 L .25826 .64567 L F
.731 .306 .239 r
.26028 .64457 m .2623 .64277 L .26076 .64515 L F
.574 .822 .992 r
.25997 .6434 m .2623 .64277 L .26204 .64273 L F
.35 0 .039 r
.25958 .64154 m .25997 .6434 L .25806 .64402 L F
.25958 .64154 m .26176 .6414 L .25997 .6434 L F
.968 .726 .516 r
.26418 .64112 m .25997 .6434 L .26176 .6414 L F
.574 .822 .992 r
.25997 .6434 m .26204 .64273 L .25835 .64219 L F
.35 0 .039 r
.25806 .64402 m .25997 .6434 L .25773 .64455 L F
.745 .873 .939 r
.25773 .64455 m .25997 .6434 L .25835 .64219 L F
.241 0 .057 r
.25826 .64567 m .25997 .6434 L .25773 .64455 L F
.731 .306 .239 r
.25835 .64219 m .2623 .64277 L .26028 .64457 L F
0 0 0 r
.4626 .60761 m .45975 .61024 L .46111 .60866 L F
.477 0 0 r
.51255 .55869 m .50826 .55629 L .5101 .55633 L F
.474 .715 .975 r
.17405 .62664 m .17464 .62492 L .1714 .62358 L F
.17405 .62664 m .17574 .62607 L .17464 .62492 L F
.565 .349 .546 r
.29775 .61465 m .29756 .61714 L .29513 .61752 L F
.578 .473 .699 r
.29964 .61168 m .30016 .61424 L .29775 .61465 L F
.487 .259 .493 r
.30016 .61424 m .29756 .61714 L .29775 .61465 L F
.742 .336 .281 r
.55915 .52022 m .55778 .5221 L .55749 .52042 L F
.844 .475 .354 r
.56089 .52296 m .55778 .5221 L .55915 .52022 L F
.445 0 0 r
.20681 .53818 m .21063 .53846 L .2086 .53791 L F
.752 .949 .63 r
.5763 .59235 m .57379 .59612 L .57574 .59409 L F
.873 .932 .858 r
.55357 .5841 m .5549 .58032 L .55624 .58336 L F
.55357 .5841 m .55231 .58332 L .5549 .58032 L F
.173 0 0 r
.18585 .78317 m .18575 .78234 L .18406 .78395 L F
.18585 .78317 m .18856 .78202 L .18575 .78234 L F
.621 .454 .635 r
.65927 .41552 m .66205 .41672 L .66271 .41463 L F
.65927 .41552 m .65957 .41728 L .66205 .41672 L F
.699 .264 .215 r
.21411 .71703 m .21817 .71775 L .21604 .71841 L F
.322 0 0 r
.22392 .55148 m .22191 .55317 L .22119 .55257 L F
.558 .872 .584 r
.2237 .55141 m .22191 .55317 L .22392 .55148 L F
.094 0 .215 r
.2237 .55141 m .22225 .55345 L .22191 .55317 L F
.22225 .55345 m .22132 .55476 L .22191 .55317 L F
.322 0 0 r
.22119 .55257 m .22191 .55317 L .21934 .5533 L F
.558 .872 .584 r
.2237 .55141 m .22392 .55148 L .22588 .55088 L F
.418 .691 .976 r
.28493 .53719 m .28431 .53881 L .28248 .5371 L F
.275 .527 .911 r
.28493 .53719 m .28572 .53838 L .28431 .53881 L F
.04 0 0 r
.1544 .56639 m .15122 .56829 L .15322 .56749 L F
.15 0 0 r
.15322 .56749 m .15647 .56569 L .1544 .56639 L F
.275 .375 .785 r
.45596 .65305 m .4547 .65461 L .45398 .65365 L F
.45596 .65305 m .45754 .65633 L .4547 .65461 L F
.457 0 0 r
.4547 .65461 m .45754 .65633 L .45565 .65524 L F
.902 .972 .81 r
.55931 .56906 m .56091 .56497 L .56012 .56649 L F
.912 .895 .481 r
.4898 .54734 m .4894 .54599 L .49024 .54439 L F
0 0 .343 r
.4898 .54734 m .49009 .5478 L .4894 .54599 L F
.827 .878 .882 r
.56391 .56218 m .56118 .56225 L .56324 .55923 L F
.644 .442 .595 r
.48499 .62666 m .48685 .6298 L .48099 .6299 L F
.644 .227 0 r
.48588 .6282 m .48499 .62666 L .4866 .62641 L F
.48588 .6282 m .48685 .6298 L .48574 .62792 L F
.229 0 .065 r
.48818 .62825 m .48646 .62928 L .48588 .6282 L F
.665 .377 .473 r
.48685 .6298 m .48058 .63148 L .48099 .6299 L F
.73 .99 .871 r
.48498 .63017 m .48685 .6298 L .48588 .6282 L F
.229 0 .065 r
.48646 .62928 m .48498 .63017 L .48588 .6282 L F
.644 .227 0 r
.48588 .6282 m .48574 .62792 L .48499 .62666 L F
.463 .826 .995 r
.81787 .44751 m .81987 .44621 L .81707 .44721 L F
.81787 .44751 m .82053 .44702 L .81987 .44621 L F
.257 0 0 r
.54538 .51863 m .54409 .5196 L .54147 .5198 L F
.304 0 0 r
.54797 .51906 m .54409 .5196 L .54538 .51863 L F
.816 .765 .806 r
.55919 .57161 m .55848 .56817 L .55931 .56906 L F
.902 .972 .81 r
.55931 .56906 m .55848 .56817 L .56091 .56497 L F
.612 .8 .972 r
.82521 .39824 m .82354 .40055 L .82255 .39906 L F
.82521 .39824 m .82626 .39966 L .82354 .40055 L F
.559 .652 .897 r
.77798 .42594 m .77529 .42647 L .77373 .42369 L F
.489 .269 .506 r
.29261 .62065 m .29243 .623 L .29012 .62348 L F
.44 .234 .502 r
.29513 .61752 m .29479 .62015 L .29261 .62065 L F
.501 .279 .508 r
.29475 .62247 m .29261 .62065 L .29479 .62015 L F
.29475 .62247 m .29243 .623 L .29261 .62065 L F
.751 .843 .92 r
.19841 .64188 m .20239 .64166 L .20062 .64083 L F
.419 .807 .988 r
.20239 .64166 m .20276 .64058 L .20062 .64083 L F
.20239 .64166 m .2046 .64126 L .20276 .64058 L F
.338 .317 .689 r
.41619 .64691 m .41758 .64703 L .4175 .64461 L F
.838 .612 .596 r
.5692 .51044 m .57107 .50811 L .56907 .50792 L F
.5692 .51044 m .57258 .51122 L .57107 .50811 L F
.575 .393 .597 r
.44593 .64175 m .45091 .64386 L .44854 .64092 L F
.44593 .64175 m .44532 .6448 L .45091 .64386 L F
.734 .953 .947 r
.24373 .55119 m .24623 .55148 L .24797 .55011 L F
0 0 0 r
.43016 .67235 m .42796 .67534 L .42937 .67402 L F
.217 .314 .75 r
.42796 .67534 m .4305 .67693 L .42937 .67402 L F
.329 0 .061 r
.43367 .58605 m .43547 .58632 L .43658 .58416 L F
.183 0 0 r
.43658 .58416 m .43886 .58596 L .43924 .58378 L F
.43658 .58416 m .43754 .58537 L .43886 .58596 L F
.43658 .58416 m .43547 .58632 L .43754 .58537 L F
0 0 0 r
.48881 .57761 m .48983 .57651 L .4913 .57476 L F
.531 .327 .549 r
.48881 .57761 m .49164 .57755 L .48983 .57651 L F
.48881 .57761 m .48878 .5806 L .49164 .57755 L F
.866 .87 .839 r
.77144 .39781 m .77032 .40204 L .7725 .39911 L F
.77144 .39781 m .76883 .40099 L .77032 .40204 L F
.574 .09 0 r
.76883 .40099 m .77128 .40378 L .77032 .40204 L F
.56 .366 .574 r
.43827 .57769 m .44083 .57503 L .43788 .57531 L F
.43827 .57769 m .44103 .57756 L .44083 .57503 L F
.447 .26 .532 r
.43827 .57769 m .44025 .57927 L .44103 .57756 L F
.43827 .57769 m .43838 .58019 L .44025 .57927 L F
.903 .755 .688 r
.56446 .54496 m .56394 .54771 L .56283 .54401 L F
.998 .777 .458 r
.77167 .39542 m .77144 .39781 L .7725 .39911 L F
.461 .19 .415 r
.29179 .62543 m .29012 .62348 L .29243 .623 L F
.29179 .62543 m .28947 .62627 L .29012 .62348 L F
.646 .761 .933 r
.8287 .41064 m .8278 .40866 L .82506 .40971 L F
.649 .792 .951 r
.8287 .41064 m .8303 .40773 L .8278 .40866 L F
.8287 .41064 m .83144 .40967 L .8303 .40773 L F
.643 .665 .856 r
.8287 .41064 m .83236 .41142 L .83144 .40967 L F
.808 .964 .908 r
.82345 .4446 m .82571 .4439 L .82522 .44302 L F
.721 .979 .915 r
.82571 .4439 m .82768 .44153 L .82522 .44302 L F
.82571 .4439 m .82919 .44171 L .82768 .44153 L F
.511 .061 .118 r
.21146 .72273 m .21346 .72085 L .21333 .72266 L F
.853 .4 .106 r
.51377 .55981 m .51289 .56096 L .51255 .55869 L F
.51377 .55981 m .51528 .56234 L .51289 .56096 L F
.49 .225 .44 r
.47607 .61268 m .47397 .61104 L .47635 .6107 L F
.47607 .61268 m .47358 .61409 L .47397 .61104 L F
.985 .88 .64 r
.56933 .60043 m .56889 .59883 L .56844 .59994 L F
.895 .946 .833 r
.56647 .60239 m .56933 .60043 L .56844 .59994 L F
.539 .667 .92 r
.19461 .64059 m .19615 .64238 L .19841 .64188 L F
.618 .304 .416 r
.51312 .61783 m .51031 .61955 L .51029 .61746 L F
.51312 .61783 m .51276 .62016 L .51031 .61955 L F
.638 .308 .397 r
.26813 .63879 m .26666 .64128 L .26418 .64112 L F
.288 0 .055 r
.27063 .6387 m .26666 .64128 L .26813 .63879 L F
.546 .62 .878 r
.83563 .40118 m .83364 .40305 L .83134 .39767 L F
.718 .778 .899 r
.81876 .41026 m .82235 .41075 L .8213 .40921 L F
.658 .81 .956 r
.8213 .40921 m .82235 .41075 L .82506 .40971 L F
.567 .458 .69 r
.31488 .58049 m .31586 .58473 L .31268 .58339 L F
.527 .394 .642 r
.31586 .58473 m .31347 .5871 L .31268 .58339 L F
.258 .23 .635 r
.45937 .62929 m .45752 .62812 L .45964 .62529 L F
.45937 .62929 m .45828 .63081 L .45752 .62812 L F
.488 .278 .521 r
.48037 .6021 m .4827 .60391 L .48511 .60214 L F
.727 .468 .534 r
.20459 .73181 m .20773 .72876 L .20462 .7295 L F
.20459 .73181 m .2086 .73289 L .20773 .72876 L F
.515 .321 .555 r
.20773 .72876 m .21146 .73002 L .2108 .72662 L F
.466 .299 .57 r
.20773 .72876 m .2099 .73302 L .21146 .73002 L F
.20773 .72876 m .2086 .73289 L .2099 .73302 L F
.179 0 .339 r
.26816 .60155 m .27009 .59853 L .26906 .59943 L F
.597 .747 .948 r
.82666 .43428 m .82493 .43633 L .82431 .43453 L F
.82666 .43428 m .82769 .43586 L .82493 .43633 L F
.482 .604 .897 r
.16323 .6203 m .16256 .6162 L .16037 .61667 L F
.16323 .6203 m .16474 .61934 L .16256 .6162 L F
.459 .624 .923 r
.16323 .6203 m .16579 .62105 L .16474 .61934 L F
0 0 .388 r
.27072 .58057 m .27179 .58207 L .2723 .58008 L F
.27072 .58057 m .27162 .58371 L .27179 .58207 L F
.635 .701 .894 r
.47187 .63454 m .47084 .63893 L .46898 .63242 L F
.47187 .63454 m .47341 .63871 L .47084 .63893 L F
.632 .431 .593 r
.47341 .63871 m .47105 .64156 L .47084 .63893 L F
.444 .158 .383 r
.48943 .62367 m .48942 .62553 L .4866 .62641 L F
.601 .509 .722 r
.49154 .62115 m .48943 .62367 L .48928 .62018 L F
.666 .331 .398 r
.48943 .62367 m .49206 .6262 L .48942 .62553 L F
.663 .601 .775 r
.49154 .62115 m .4929 .62388 L .48943 .62367 L F
.648 .337 .43 r
.4929 .62388 m .49206 .6262 L .48943 .62367 L F
.843 .659 .653 r
.45056 .65981 m .44835 .66022 L .44898 .65663 L F
.89 .525 .346 r
.45056 .65981 m .44919 .66151 L .44835 .66022 L F
.45056 .65981 m .45186 .6625 L .44919 .66151 L F
.575 .393 .597 r
.44462 .62362 m .44505 .62542 L .44729 .61993 L F
.713 .715 .85 r
.44835 .61974 m .44729 .61993 L .44974 .61741 L F
.619 .555 .761 r
.44729 .61993 m .44998 .61952 L .44974 .61741 L F
.565 .375 .583 r
.44505 .62542 m .44998 .61952 L .44729 .61993 L F
.405 .6 .925 r
.17908 .62928 m .18142 .63211 L .18326 .63197 L F
.684 .63 .789 r
.1823 .63641 m .18326 .63197 L .18142 .63211 L F
.323 0 .017 r
.18671 .54592 m .18982 .54481 L .18746 .54525 L F
.06 0 0 r
.1803 .56984 m .18005 .56893 L .18225 .56819 L F
.1803 .56984 m .17815 .57048 L .18005 .56893 L F
.716 .698 .832 r
.83144 .40967 m .83236 .41142 L .83472 .41056 L F
.432 .602 .917 r
.3086 .54425 m .30816 .54683 L .3065 .54486 L F
.3086 .54425 m .31031 .5468 L .30816 .54683 L F
.74 .734 .846 r
.83149 .4362 m .82769 .43586 L .83042 .43486 L F
.733 .882 .949 r
.83297 .43381 m .83149 .4362 L .83042 .43486 L F
.83297 .43381 m .83393 .43514 L .83149 .4362 L F
.494 .37 .64 r
.65855 .42881 m .66025 .42591 L .65908 .42775 L F
.727 .436 .486 r
.45341 .638 m .45748 .6388 L .45721 .63579 L F
.525 .468 .735 r
.45721 .63579 m .45949 .63531 L .45897 .63154 L F
.594 .337 .498 r
.45721 .63579 m .45946 .63786 L .45949 .63531 L F
.45721 .63579 m .45748 .6388 L .45946 .63786 L F
.981 .761 .532 r
.51722 .56296 m .51549 .56476 L .51528 .56234 L F
.51722 .56296 m .51696 .56575 L .51549 .56476 L F
.349 .068 .338 r
.44103 .57756 m .44381 .57452 L .44083 .57503 L F
.283 .5 .89 r
.78153 .44169 m .78326 .4405 L .78131 .43996 L F
.78153 .44169 m .78467 .44303 L .78326 .4405 L F
.384 .183 .48 r
.27543 .56805 m .27673 .56889 L .27717 .56579 L F
.69 .669 .825 r
.79869 .43461 m .79545 .43233 L .79795 .43144 L F
.652 .637 .822 r
.80218 .43185 m .79869 .43461 L .79795 .43144 L F
0 0 0 r
.22687 .64417 m .23043 .64388 L .22942 .64354 L F
.094 .651 .738 r
.23043 .64388 m .23122 .64372 L .22942 .64354 L F
.23043 .64388 m .23303 .64362 L .23122 .64372 L F
.821 .428 0 r
.52326 .55265 m .52466 .55535 L .52433 .55407 L F
.742 .252 .072 r
.52636 .55621 m .52433 .55407 L .52466 .55535 L F
.827 .505 .444 r
.5692 .51044 m .57131 .51306 L .57258 .51122 L F
.81 .48 .432 r
.57131 .51306 m .57471 .51369 L .57258 .51122 L F
.714 .324 .31 r
.21487 .7295 m .21822 .72977 L .21662 .73202 L F
.758 .892 .49 r
.21662 .73202 m .21822 .72977 L .21866 .72844 L F
.826 .388 .197 r
.2596 .55663 m .25824 .55698 L .2565 .55539 L F
.817 .725 .764 r
.471 .55899 m .47124 .56349 L .47535 .55935 L F
.32 .757 .968 r
.24165 .53607 m .24382 .53589 L .24563 .53658 L F
.331 .784 .951 r
.24382 .53589 m .24768 .53603 L .24563 .53658 L F
.414 .816 .981 r
.43007 .65918 m .43254 .65877 L .43412 .65938 L F
.22 .664 .952 r
.43485 .65865 m .43412 .65938 L .43254 .65877 L F
.43485 .65865 m .43632 .65955 L .43412 .65938 L F
.383 .578 .917 r
.76945 .41948 m .76737 .42083 L .76712 .41897 L F
.76945 .41948 m .77154 .42236 L .76737 .42083 L F
.763 .891 .935 r
.21926 .72647 m .21631 .72601 L .21933 .72622 L F
.683 .724 .209 r
.21933 .72622 m .21866 .72844 L .21926 .72647 L F
.534 .425 .677 r
.3118 .59509 m .30975 .59922 L .30951 .59664 L F
.849 .561 .5 r
.78721 .38729 m .78372 .38423 L .78556 .38633 L F
.433 0 0 r
.21063 .53846 m .21232 .53901 L .21445 .53775 L F
.247 0 0 r
.21445 .53775 m .21232 .53901 L .21688 .53751 L F
0 0 .396 r
.52267 .57169 m .5235 .57292 L .52128 .56975 L F
.52267 .57169 m .52442 .5743 L .5235 .57292 L F
.703 .504 .616 r
.46235 .64771 m .45987 .65057 L .4599 .64795 L F
.018 .564 .836 r
.80476 .4052 m .80824 .40603 L .80788 .40583 L F
.087 0 0 r
.80824 .40603 m .81051 .40625 L .80788 .40583 L F
.80824 .40603 m .81152 .40614 L .81051 .40625 L F
.236 .482 .889 r
.16764 .62037 m .16998 .6234 L .17055 .62181 L F
.207 .448 .87 r
.17055 .62181 m .16998 .6234 L .1714 .62358 L F
.272 0 0 r
.2172 .5542 m .21779 .55477 L .21518 .55504 L F
.215 0 0 r
.21748 .55437 m .21394 .55487 L .21489 .555 L F
.21394 .55487 m .21296 .55501 L .21328 .55501 L F
.21394 .55487 m .21328 .55501 L .21489 .555 L F
.21748 .55437 m .21518 .55504 L .21296 .55501 L F
.272 0 0 r
.21934 .5533 m .21518 .55504 L .21748 .55437 L F
.21934 .5533 m .21873 .55388 L .2172 .5542 L F
.21873 .55388 m .21779 .55477 L .2172 .5542 L F
.717 .332 .318 r
.45196 .63099 m .45056 .63356 L .44847 .63105 L F
0 .162 .689 r
.44847 .63105 m .45056 .63356 L .44961 .63178 L F
.4 .078 .299 r
.44847 .63105 m .4468 .62997 L .44976 .62961 L F
.635 .171 .133 r
.45196 .63099 m .44847 .63105 L .44976 .62961 L F
0 .162 .689 r
.44847 .63105 m .44961 .63178 L .44866 .63002 L F
.4 .078 .299 r
.44847 .63105 m .44629 .63003 L .4468 .62997 L F
.248 0 .294 r
.13833 .5811 m .14017 .58036 L .14096 .57796 L F
.397 .218 .519 r
.14096 .57796 m .14286 .57738 L .14308 .5748 L F
.171 0 .257 r
.14096 .57796 m .14184 .57941 L .14286 .57738 L F
.14096 .57796 m .14017 .58036 L .14184 .57941 L F
.434 .037 .185 r
.23997 .68428 m .23616 .68672 L .23678 .68397 L F
.23997 .68428 m .23867 .68658 L .23616 .68672 L F
.184 0 .054 r
.24063 .68578 m .23867 .68658 L .23997 .68428 L F
.781 .688 .761 r
.43632 .65955 m .44039 .66033 L .43861 .65645 L F
.783 .683 .753 r
.43632 .65955 m .43803 .6633 L .44039 .66033 L F
.781 .688 .761 r
.43632 .65955 m .44039 .66033 L .43861 .65645 L F
.72 .282 .209 r
.4687 .61991 m .46792 .62201 L .466 .61984 L F
0 0 .302 r
.47074 .61666 m .47048 .61905 L .4687 .61991 L F
0 0 0 r
.47048 .61905 m .46792 .62201 L .4687 .61991 L F
.346 .088 .373 r
.43284 .66919 m .43236 .67191 L .43016 .67235 L F
.727 .647 .769 r
.43578 .66639 m .43284 .66919 L .43175 .66533 L F
0 0 0 r
.43445 .66789 m .43384 .66823 L .43578 .66639 L F
.859 .965 .638 r
.43446 .66748 m .43445 .66789 L .43578 .66639 L F
.608 .616 .834 r
.43485 .66766 m .43445 .66789 L .43446 .66748 L F
.43605 .66821 m .43445 .66789 L .43485 .66766 L F
0 0 0 r
.43445 .66789 m .43284 .66919 L .43384 .66823 L F
.396 .13 .389 r
.43466 .67086 m .43284 .66919 L .43445 .66789 L F
.43466 .67086 m .43236 .67191 L .43284 .66919 L F
.369 .832 .901 r
.23922 .62647 m .23701 .62707 L .23548 .62696 L F
.446 .187 .427 r
.29756 .61714 m .29479 .62015 L .29513 .61752 L F
.896 .667 .584 r
.57269 .51622 m .57701 .52026 L .57627 .51692 L F
.57269 .51622 m .57267 .51892 L .57701 .52026 L F
.891 .705 .644 r
.57267 .51892 m .57407 .52243 L .57701 .52026 L F
.518 .77 .988 r
.81614 .39869 m .81353 .39918 L .81253 .39785 L F
.294 0 .269 r
.17301 .55319 m .17509 .55288 L .17597 .55042 L F
.355 .047 .297 r
.17597 .55042 m .1773 .55223 L .17825 .54981 L F
.17597 .55042 m .17509 .55288 L .1773 .55223 L F
.729 .977 .921 r
.45248 .57957 m .45171 .58142 L .4539 .5801 L F
.45248 .57957 m .44946 .58115 L .45171 .58142 L F
.672 .702 .869 r
.66102 .42846 m .6621 .43162 L .66496 .42939 L F
.842 .531 .463 r
.5283 .56175 m .53019 .56003 L .52886 .55919 L F
.5283 .56175 m .53201 .56222 L .53019 .56003 L F
.171 .582 .937 r
.2706 .55912 m .27034 .55794 L .26806 .55827 L F
.2706 .55912 m .27184 .55921 L .27034 .55794 L F
0 0 .165 r
.52994 .5845 m .53024 .58554 L .52939 .58324 L F
.52994 .5845 m .53027 .5873 L .53024 .58554 L F
.472 .285 .545 r
.44488 .62625 m .44505 .62542 L .44462 .62362 L F
.302 0 0 r
.2354 .69622 m .23117 .698 L .23363 .6971 L F
.812 .665 .701 r
.57255 .54699 m .57448 .5479 L .57295 .5444 L F
.816 .646 .672 r
.57255 .54699 m .57423 .55053 L .57448 .5479 L F
.876 .876 .438 r
.23117 .698 m .23021 .70203 L .23108 .69993 L F
.391 .227 .536 r
.31359 .58998 m .31405 .59247 L .31174 .59316 L F
.308 .096 .42 r
.31405 .59247 m .3118 .59509 L .31174 .59316 L F
.916 .76 .673 r
.56283 .54401 m .56394 .54771 L .56233 .54674 L F
.874 .696 .657 r
.56364 .5496 m .56233 .54674 L .56394 .54771 L F
.665 .691 .864 r
.54993 .60213 m .55226 .60584 L .55241 .60144 L F
.692 .734 .883 r
.55241 .60144 m .55226 .60584 L .55649 .60243 L F
.365 0 0 r
.21688 .53751 m .21912 .53796 L .22075 .53771 L F
.129 0 0 r
.22075 .53771 m .21912 .53796 L .22303 .53774 L F
.281 0 .13 r
.54377 .51117 m .54523 .51255 L .54592 .51019 L F
.54377 .51117 m .54292 .51327 L .54523 .51255 L F
.348 .791 .959 r
.27032 .53714 m .27254 .53686 L .27463 .53739 L F
.161 .462 .887 r
.27512 .53606 m .27463 .53739 L .27254 .53686 L F
.27512 .53606 m .27647 .53799 L .27463 .53739 L F
.679 .621 .784 r
.78218 .38687 m .7862 .3894 L .78556 .38633 L F
.4 .078 .299 r
.44847 .63105 m .44577 .63185 L .44629 .63003 L F
.187 .232 .677 r
.52187 .54659 m .52126 .54998 L .51955 .54854 L F
0 0 .521 r
.22666 .70221 m .22731 .70362 L .22662 .70144 L F
.947 .692 .23 r
.4913 .57476 m .4945 .57569 L .49431 .57433 L F
.842 .393 .147 r
.49743 .57743 m .49431 .57433 L .4945 .57569 L F
.148 .686 .697 r
.45575 .63021 m .45457 .63045 L .45196 .63099 L F
.049 .585 .855 r
.45897 .63154 m .45457 .63045 L .45575 .63021 L F
.31 .154 .502 r
.13825 .58374 m .14017 .58036 L .13833 .5811 L F
.856 .717 .708 r
.84592 .40686 m .84771 .40808 L .84642 .40451 L F
0 0 0 r
.16755 .57471 m .16479 .57673 L .16591 .57573 L F
.447 .245 .511 r
.77431 .40742 m .7741 .40997 L .77118 .41051 L F
.507 .488 .771 r
.7741 .40997 m .77118 .41051 L .77431 .40742 L F
.7741 .40997 m .77248 .41148 L .77118 .41051 L F
.77118 .41051 m .77248 .41148 L .7741 .40997 L F
.293 0 .081 r
.16951 .55586 m .17167 .55534 L .17301 .55319 L F
.011 0 0 r
.17301 .55319 m .17361 .55427 L .17509 .55288 L F
.17301 .55319 m .17167 .55534 L .17361 .55427 L F
.701 .739 .88 r
.66496 .42939 m .66844 .43103 L .66723 .42817 L F
.721 .725 .853 r
.66723 .42817 m .66844 .43103 L .67095 .4288 L F
.648 .143 .032 r
.25386 .64335 m .25605 .6424 L .25773 .64455 L F
.601 .509 .722 r
.49154 .62115 m .48928 .62018 L .48983 .62084 L F
0 0 .425 r
.48928 .62018 m .48983 .62084 L .48813 .61717 L F
.873 .917 .854 r
.83643 .43212 m .83393 .43514 L .83297 .43381 L F
.658 .387 .497 r
.48204 .60559 m .4817 .6079 L .47877 .60749 L F
.536 .278 .471 r
.4856 .60433 m .4817 .6079 L .48204 .60559 L F
.069 .156 .648 r
.49425 .59599 m .49387 .59209 L .49205 .59296 L F
.49425 .59599 m .49516 .59639 L .49387 .59209 L F
.128 0 0 r
.49425 .59599 m .49377 .59744 L .49516 .59639 L F
.49425 .59599 m .49144 .59814 L .49377 .59744 L F
.684 .63 .789 r
.1823 .63641 m .18471 .63557 L .18326 .63197 L F
.589 .735 .945 r
.76545 .42432 m .76668 .42207 L .76428 .42264 L F
.76545 .42432 m .76797 .42372 L .76668 .42207 L F
.805 .609 .638 r
.57558 .55655 m .5751 .55915 L .57833 .55933 L F
.805 .607 .635 r
.5751 .55915 m .57717 .56259 L .57833 .55933 L F
.716 .698 .832 r
.83144 .40967 m .83472 .41056 L .83379 .40872 L F
.794 .809 .864 r
.83379 .40872 m .83472 .41056 L .83745 .40796 L F
.482 .511 .811 r
.16501 .5953 m .16646 .59905 L .16441 .59929 L F
.786 .684 .751 r
.43399 .66273 m .43803 .6633 L .43632 .65955 L F
.789 .677 .741 r
.43399 .66273 m .43578 .66639 L .43803 .6633 L F
.533 .919 .915 r
.82919 .44171 m .83123 .44016 L .82768 .44153 L F
.82919 .44171 m .8316 .4406 L .83123 .44016 L F
.665 .183 0 r
.52551 .57547 m .52557 .57595 L .52442 .5743 L F
.52551 .57547 m .52677 .57713 L .52557 .57595 L F
.703 .504 .616 r
.46235 .64771 m .46335 .65116 L .45987 .65057 L F
.086 0 .43 r
.46564 .64734 m .46335 .65116 L .46235 .64771 L F
.467 .017 .096 r
.57667 .56788 m .5801 .56625 L .5769 .56511 L F
.179 0 .058 r
.15122 .56829 m .1517 .56999 L .15322 .56749 L F
.15122 .56829 m .14975 .57072 L .1517 .56999 L F
.698 .68 .829 r
.83745 .40796 m .84123 .40911 L .84002 .40691 L F
.67 .754 .914 r
.84123 .40911 m .84265 .40616 L .84002 .40691 L F
.84123 .40911 m .84382 .40791 L .84265 .40616 L F
.559 .29 .466 r
.48687 .584 m .4839 .58676 L .48438 .58385 L F
.633 .484 .663 r
.48438 .58385 m .48471 .58581 L .48687 .584 L F
.559 .29 .466 r
.48687 .584 m .48674 .58659 L .4839 .58676 L F
.056 0 .319 r
.48687 .584 m .48857 .58322 L .48878 .5806 L F
.209 .017 .388 r
.48841 .58523 m .48687 .584 L .48857 .58322 L F
.48841 .58523 m .48674 .58659 L .48687 .584 L F
.481 .335 .605 r
.48471 .58581 m .48857 .58322 L .48687 .584 L F
.056 0 .319 r
.48687 .584 m .48857 .58322 L .48878 .5806 L F
.499 .226 .432 r
.27349 .63604 m .2731 .63835 L .27063 .6387 L F
.411 .151 .406 r
.27521 .63777 m .27349 .63604 L .27601 .63562 L F
.27521 .63777 m .2731 .63835 L .27349 .63604 L F
.566 .185 .278 r
.26946 .58006 m .2723 .58008 L .27322 .57781 L F
0 0 0 r
.27322 .57781 m .27494 .57691 L .27627 .57526 L F
.11 0 .082 r
.27322 .57781 m .27428 .57912 L .27494 .57691 L F
.27322 .57781 m .2723 .58008 L .27428 .57912 L F
.981 .762 .532 r
.78679 .42501 m .78826 .4264 L .78763 .42888 L F
.78763 .42888 m .78826 .4264 L .78679 .42501 L F
.829 .48 .395 r
.51332 .54719 m .51545 .54925 L .51626 .54854 L F
.311 0 0 r
.51545 .54925 m .51955 .54854 L .51626 .54854 L F
0 0 .565 r
.53419 .59608 m .53557 .59697 L .53422 .59541 L F
.53419 .59608 m .53582 .5985 L .53557 .59697 L F
.567 .274 .43 r
.44414 .63297 m .44342 .63508 L .44109 .63511 L F
.082 0 .205 r
.44577 .63185 m .44342 .63508 L .44414 .63297 L F
.563 .229 .361 r
.45596 .65305 m .45415 .65132 L .45618 .65065 L F
.45596 .65305 m .45398 .65365 L .45415 .65132 L F
.641 .698 .887 r
.74258 .39483 m .74633 .39582 L .74507 .39374 L F
.949 .954 .665 r
.74633 .39582 m .74751 .39065 L .74507 .39374 L F
.404 .318 .645 r
.74633 .39582 m .74681 .39787 L .74896 .39772 L F
.509 .837 .999 r
.19134 .61678 m .19064 .61806 L .18915 .61665 L F
.19134 .61678 m .19276 .61751 L .19064 .61806 L F
.686 .323 .353 r
.79173 .39437 m .79562 .39377 L .79269 .39165 L F
.79173 .39437 m .79623 .39511 L .79562 .39377 L F
.761 .352 .276 r
.43016 .67235 m .42937 .67402 L .42694 .67159 L F
.443 .416 .734 r
.43236 .67191 m .43307 .67443 L .43016 .67235 L F
.788 .288 0 r
.27688 .58519 m .27691 .58623 L .27542 .58385 L F
0 0 0 r
.27866 .58488 m .27691 .58623 L .27688 .58519 L F
.196 0 .16 r
.49401 .58719 m .49539 .58691 L .49691 .58462 L F
.512 .35 .598 r
.49401 .58719 m .4967 .58974 L .49539 .58691 L F
.49401 .58719 m .49438 .59178 L .4967 .58974 L F
.598 .412 .601 r
.30487 .60539 m .30493 .60802 L .30244 .6082 L F
.463 .279 .546 r
.30725 .60217 m .30708 .60489 L .30487 .60539 L F
.547 .372 .596 r
.30736 .60751 m .30487 .60539 L .30708 .60489 L F
.30736 .60751 m .30493 .60802 L .30487 .60539 L F
.001 0 .222 r
.15817 .58688 m .15748 .58922 L .1565 .58941 L F
.528 .267 .463 r
.4665 .63131 m .46845 .63116 L .46844 .62971 L F
.521 .321 .55 r
.46845 .63116 m .47084 .62904 L .46844 .62971 L F
.32 .447 .833 r
.77212 .42811 m .77357 .4315 L .7753 .43155 L F
.087 0 0 r
.23594 .67149 m .24053 .67123 L .23844 .67149 L F
.23594 .67149 m .24053 .67123 L .23844 .67149 L F
.499 .908 .875 r
.23844 .67149 m .24053 .67123 L .24101 .67039 L F
0 .322 .808 r
.24101 .67039 m .24053 .67123 L .2418 .67168 L F
.499 .908 .875 r
.23844 .67149 m .24053 .67123 L .24101 .67039 L F
0 .322 .808 r
.24101 .67039 m .24053 .67123 L .2418 .67168 L F
.388 .4 .751 r
.24061 .67386 m .2418 .67168 L .24053 .67123 L F
.542 .456 .708 r
.73614 .39304 m .7375 .38882 L .73513 .38931 L F
.73614 .39304 m .7392 .39208 L .7375 .38882 L F
.896 .513 .298 r
.46142 .60469 m .46338 .6054 L .46135 .60294 L F
.916 .578 .388 r
.46142 .60469 m .46169 .60686 L .46338 .6054 L F
.996 .812 .541 r
.46338 .6054 m .46169 .60686 L .4626 .60761 L F
.46338 .6054 m .46169 .60686 L .4626 .60761 L F
.534 .703 .948 r
.23575 .69049 m .23537 .69337 L .23358 .69115 L F
.23575 .69049 m .2383 .69338 L .23537 .69337 L F
.442 .272 .554 r
.23747 .69558 m .23537 .69337 L .2383 .69338 L F
.23747 .69558 m .2354 .69622 L .23537 .69337 L F
.747 .993 .817 r
.26264 .55218 m .26204 .55366 L .2647 .55144 L F
.682 .517 .657 r
.2647 .55144 m .26204 .55366 L .26508 .55315 L F
.361 .307 .662 r
.26508 .55315 m .26671 .55271 L .2647 .55144 L F
.59 .058 0 r
.26671 .55271 m .26264 .55218 L .2647 .55144 L F
.29 .757 .943 r
.82892 .42623 m .8285 .42563 L .82474 .42583 L F
.37 .557 .906 r
.82685 .42363 m .82843 .42345 L .82892 .42623 L F
.895 .718 .209 r
.82892 .42623 m .82843 .42345 L .8285 .42563 L F
.384 .542 .889 r
.22431 .70062 m .22488 .69814 L .22306 .69811 L F
.22431 .70062 m .22662 .70144 L .22488 .69814 L F
.619 .449 .63 r
.65957 .41728 m .65963 .41985 L .66205 .41672 L F
.184 .694 .898 r
.25797 .53736 m .2602 .53733 L .26183 .53776 L F
.8 .941 .919 r
.76223 .39776 m .76299 .3989 L .75977 .40152 L F
.568 .91 .688 r
.49852 .58821 m .4967 .58974 L .49757 .58931 L F
.487 .352 .623 r
.16479 .57673 m .1651 .5799 L .16282 .57794 L F
.448 .353 .655 r
.1651 .5799 m .16342 .5813 L .16282 .57794 L F
.06 0 .066 r
.49691 .58462 m .49811 .58531 L .49809 .583 L F
.49691 .58462 m .49539 .58691 L .49811 .58531 L F
.579 .614 .852 r
.43967 .64764 m .44187 .65154 L .44363 .65032 L F
.164 0 .247 r
.44187 .65154 m .44119 .6534 L .44363 .65032 L F
.44187 .65154 m .44119 .6534 L .44363 .65032 L F
.912 .662 .547 r
.4982 .57079 m .50038 .57415 L .49911 .57248 L F
.349 0 .113 r
.18062 .54953 m .18286 .54917 L .18454 .54679 L F
.325 0 .14 r
.18286 .54917 m .18671 .54592 L .18454 .54679 L F
.581 .489 .715 r
.31809 .56826 m .31512 .56749 L .31813 .56602 L F
.31809 .56826 m .31576 .56878 L .31512 .56749 L F
.683 .687 .848 r
.20681 .64122 m .21003 .64524 L .20964 .64373 L F
.697 .771 .909 r
.21003 .64524 m .21244 .64489 L .20964 .64373 L F
.228 0 0 r
.20252 .55721 m .20041 .55825 L .19794 .55845 L F
.316 0 0 r
.2048 .55685 m .20041 .55825 L .20252 .55721 L F
.448 .841 .632 r
.21244 .64489 m .21175 .6452 L .20964 .64373 L F
.21244 .64489 m .21456 .64342 L .21175 .6452 L F
.541 .784 .988 r
.29481 .5403 m .29423 .54212 L .2934 .54024 L F
.29481 .5403 m .29644 .54153 L .29423 .54212 L F
.008 0 0 r
.22965 .55057 m .22761 .5508 L .22588 .55088 L F
.013 0 0 r
.22965 .55057 m .22994 .55068 L .22761 .5508 L F
.22965 .55057 m .23192 .55048 L .22994 .55068 L F
0 .065 .614 r
.53241 .59025 m .5316 .58881 L .53159 .58912 L F
.848 .463 0 r
.53351 .59253 m .5316 .58881 L .53241 .59025 L F
.53351 .59253 m .53265 .59254 L .5316 .58881 L F
.53265 .59254 m .53261 .59254 L .53256 .59235 L F
.53265 .59254 m .53256 .59235 L .5316 .58881 L F
.931 .592 .151 r
.53422 .59541 m .53261 .59254 L .53351 .59253 L F
.307 .365 .759 r
.53308 .59346 m .53471 .5921 L .53215 .59019 L F
.53327 .59414 m .53335 .59403 L .53308 .59346 L F
.53335 .59403 m .53471 .5921 L .53308 .59346 L F
0 .043 .585 r
.53261 .59254 m .53162 .5879 L .5316 .58881 L F
.53162 .5879 m .53158 .58773 L .5316 .58881 L F
0 .065 .614 r
.53159 .58912 m .5316 .58881 L .53027 .5873 L F
0 .091 .635 r
.27628 .56279 m .27717 .56579 L .27774 .56412 L F
.912 .673 .563 r
.27717 .56579 m .27773 .56908 L .27774 .56412 L F
.27717 .56579 m .27673 .56889 L .27773 .56908 L F
.531 .862 .995 r
.79204 .44543 m .79307 .44387 L .79078 .44452 L F
.79204 .44543 m .79466 .44466 L .79307 .44387 L F
.551 .264 .432 r
.47545 .60462 m .47785 .6047 L .47851 .60253 L F
.604 .362 .523 r
.47785 .6047 m .48037 .6021 L .47851 .60253 L F
.896 .513 .298 r
.46142 .60469 m .46135 .60294 L .46045 .60273 L F
.54 .369 .597 r
.44898 .65663 m .44835 .66022 L .44657 .66029 L F
.44657 .66029 m .44835 .66022 L .44898 .65663 L F
.309 0 .03 r
.46136 .67448 m .46376 .67407 L .46523 .67216 L F
.98 .745 .512 r
.46523 .67216 m .46376 .67407 L .46529 .67501 L F
0 .031 .585 r
.76596 .41712 m .76604 .41778 L .76481 .41644 L F
.76596 .41712 m .76712 .41897 L .76604 .41778 L F
.643 .375 .498 r
.49283 .59916 m .4903 .60161 L .4912 .59865 L F
.49283 .59916 m .49318 .60209 L .4903 .60161 L F
.39 .198 .496 r
.49523 .60092 m .49283 .59916 L .49569 .59873 L F
.49523 .60092 m .49318 .60209 L .49283 .59916 L F
.576 .365 .558 r
.19604 .76257 m .19902 .76015 L .19631 .76025 L F
.19604 .76257 m .19902 .76015 L .19631 .76025 L F
.504 .268 .49 r
.30442 .61049 m .30244 .6082 L .30493 .60802 L F
.30442 .61049 m .30201 .61108 L .30244 .6082 L F
.415 .79 .993 r
.23192 .55048 m .2358 .55106 L .23408 .55013 L F
.197 .604 .946 r
.2358 .55106 m .23625 .55003 L .23408 .55013 L F
.2358 .55106 m .23718 .55068 L .23625 .55003 L F
.666 .438 .565 r
.4464 .57465 m .44931 .57499 L .45041 .57212 L F
.61 .378 .539 r
.44931 .57499 m .45252 .5716 L .45041 .57212 L F
.752 .949 .63 r
.5763 .59235 m .57392 .59543 L .57379 .59612 L F
.929 .721 .6 r
.56183 .55322 m .56323 .55671 L .56148 .55533 L F
.771 .522 .558 r
.56323 .55671 m .5594 .55877 L .56148 .55533 L F
.56323 .55671 m .56324 .55923 L .5594 .55877 L F
.838 .772 .789 r
.5302 .56358 m .53201 .56222 L .5283 .56175 L F
.501 .878 .974 r
.79729 .44382 m .79803 .44439 L .80065 .44358 L F
.958 .781 .621 r
.53481 .57181 m .53502 .56902 L .53381 .56841 L F
.48 .254 .493 r
.4374 .64787 m .43967 .64764 L .44005 .64475 L F
.604 .117 0 r
.44078 .6459 m .44005 .64475 L .43967 .64764 L F
.44078 .6459 m .44237 .64762 L .44005 .64475 L F
.9 .484 .131 r
.49804 .55078 m .49723 .5517 L .49453 .55017 L F
.388 .4 .751 r
.24061 .67386 m .24288 .67444 L .2418 .67168 L F
.618 .572 .78 r
.24122 .67797 m .24288 .67444 L .24061 .67386 L F
.534 .425 .677 r
.3118 .59509 m .31203 .59871 L .30975 .59922 L F
.551 .37 .59 r
.31203 .59871 m .30968 .60172 L .30975 .59922 L F
.832 .63 .63 r
.57391 .55314 m .57592 .55402 L .57423 .55053 L F
.889 .724 .672 r
.57362 .55582 m .57592 .55402 L .57391 .55314 L F
.57362 .55582 m .57558 .55655 L .57592 .55402 L F
.115 0 .336 r
.26467 .60825 m .266 .6075 L .26647 .60506 L F
.088 0 .283 r
.26467 .60825 m .26402 .61079 L .266 .6075 L F
.659 .506 .666 r
.45507 .56884 m .4579 .56884 L .45753 .5658 L F
.683 .524 .664 r
.45753 .5658 m .4579 .56884 L .4607 .56814 L F
.862 .52 .402 r
.52636 .55621 m .52701 .55848 L .52839 .55659 L F
.858 .513 .399 r
.52701 .55848 m .52886 .55919 L .52839 .55659 L F
.76 .666 .759 r
.20364 .75334 m .20508 .75713 L .20747 .75409 L F
.48 .134 .302 r
.28167 .5773 m .28405 .57712 L .28503 .57422 L F
.359 .508 .87 r
.28503 .57422 m .28712 .57383 L .28406 .57235 L F
.277 0 .22 r
.28503 .57422 m .28629 .57616 L .28712 .57383 L F
.28503 .57422 m .28405 .57712 L .28629 .57616 L F
.378 .842 .814 r
.19332 .54414 m .19407 .54355 L .1955 .54328 L F
.323 .804 .895 r
.19175 .54403 m .19407 .54355 L .19332 .54414 L F
.583 .591 .826 r
.14717 .60788 m .15098 .61074 L .14922 .60755 L F
.514 .655 .923 r
.15098 .61074 m .15084 .60761 L .14922 .60755 L F
.15098 .61074 m .15311 .61035 L .15084 .60761 L F
.527 .394 .642 r
.31586 .58473 m .31576 .58658 L .31347 .5871 L F
.639 .511 .691 r
.31645 .58935 m .31347 .5871 L .31576 .58658 L F
.31645 .58935 m .31359 .58998 L .31347 .5871 L F
.576 .392 .595 r
.18395 .76336 m .18632 .75998 L .18416 .76101 L F
.498 .229 .437 r
.45508 .57149 m .4579 .56884 L .45507 .56884 L F
.034 0 .378 r
.44898 .65663 m .44835 .66022 L .45012 .6587 L F
.465 .657 .944 r
.21846 .62901 m .21415 .62698 L .2173 .62766 L F
.258 .582 .944 r
.22042 .62929 m .21846 .62901 L .2173 .62766 L F
.726 .711 .837 r
.67095 .4288 m .67472 .42941 L .67324 .42808 L F
.725 .711 .837 r
.67324 .42808 m .67472 .42941 L .67689 .42868 L F
.508 .045 .089 r
.83563 .40118 m .83897 .40059 L .83601 .4014 L F
.891 .842 .789 r
.50778 .60731 m .51066 .60516 L .50967 .60468 L F
.50817 .60606 m .50967 .60468 L .50874 .60423 L F
.50778 .60731 m .50967 .60468 L .50817 .60606 L F
.50778 .60731 m .50874 .60423 L .50842 .60171 L F
.583 .82 .989 r
.50936 .60691 m .50802 .60825 L .50646 .60707 L F
.718 .424 .479 r
.50896 .6098 m .50802 .60825 L .50936 .60691 L F
.50711 .60703 m .50896 .6098 L .50936 .60691 L F
.50646 .60707 m .50674 .60737 L .50711 .60703 L F
.50896 .6098 m .50646 .60707 L .50802 .60825 L F
.50674 .60737 m .50896 .6098 L .50711 .60703 L F
.476 .041 .132 r
.26204 .55366 m .26359 .55474 L .26508 .55315 L F
0 .181 .697 r
.26264 .55218 m .26359 .55474 L .26204 .55366 L F
.224 .146 .553 r
.26204 .55366 m .26208 .55627 L .26359 .55474 L F
.26204 .55366 m .26208 .55627 L .26359 .55474 L F
.625 .5 .69 r
.48813 .61717 m .49053 .61715 L .49057 .61481 L F
.67 .408 .516 r
.48648 .62007 m .48983 .62084 L .48813 .61717 L F
.984 .892 .648 r
.45091 .64386 m .45177 .64137 L .44854 .64092 L F
.46 .582 .889 r
.1548 .61359 m .15471 .61023 L .15311 .61035 L F
.1548 .61359 m .15694 .6134 L .15471 .61023 L F
.513 .547 .828 r
.1548 .61359 m .15862 .61704 L .15694 .6134 L F
.636 .219 .236 r
.52786 .56976 m .52907 .56924 L .52963 .56815 L F
.923 .771 .674 r
.53102 .569 m .52985 .56771 L .52963 .56815 L F
0 .229 .739 r
.53168 .56814 m .53102 .569 L .52963 .56815 L F
.636 .219 .236 r
.52907 .56924 m .53168 .56814 L .52963 .56815 L F
.923 .771 .674 r
.52985 .56771 m .52868 .56643 L .52963 .56815 L F
.566 .829 .471 r
.53168 .56814 m .53379 .56563 L .53102 .569 L F
.433 .829 .982 r
.53168 .56814 m .53381 .56841 L .53102 .569 L F
.504 .328 .575 r
.53303 .57096 m .53381 .56841 L .53102 .569 L F
0 .229 .739 r
.53168 .56814 m .53303 .57096 L .53102 .569 L F
.54 .81 .996 r
.45052 .67853 m .45281 .67784 L .45127 .67676 L F
.45127 .67676 m .45281 .67784 L .45052 .67853 L F
.861 .548 .457 r
.51066 .60516 m .50936 .60691 L .50874 .60423 L F
.51066 .60516 m .51135 .60753 L .50936 .60691 L F
.369 .293 .639 r
.1891 .77004 m .19092 .7718 L .19107 .76905 L F
.1891 .77004 m .18983 .77292 L .19092 .7718 L F
0 0 .034 r
.27856 .57192 m .27627 .57526 L .27775 .57369 L F
0 .116 .667 r
.27856 .57192 m .2788 .5709 L .27673 .56889 L F
.88 .735 .697 r
.5147 .6217 m .51429 .62341 L .51276 .62016 L F
0 0 0 r
.27627 .57526 m .27646 .57593 L .27775 .57369 L F
.27627 .57526 m .27494 .57691 L .27646 .57593 L F
.485 .69 .958 r
.14717 .60788 m .14774 .60583 L .14426 .60518 L F
.14717 .60788 m .14922 .60755 L .14774 .60583 L F
.727 .566 .672 r
.47341 .63871 m .47402 .64162 L .47105 .64156 L F
.589 .234 .335 r
.47632 .63622 m .47471 .63671 L .47426 .63643 L F
.137 .359 .817 r
.47426 .63643 m .47341 .63871 L .47206 .63506 L F
.793 .717 .779 r
.47426 .63643 m .47584 .63819 L .47341 .63871 L F
.218 .222 .649 r
.47568 .64022 m .47341 .63871 L .47584 .63819 L F
.793 .717 .779 r
.47426 .63643 m .47568 .64022 L .47584 .63819 L F
.218 .222 .649 r
.47568 .64022 m .47402 .64162 L .47341 .63871 L F
.793 .717 .779 r
.47426 .63643 m .47235 .64035 L .47568 .64022 L F
.74 .648 .758 r
.47106 .63961 m .47235 .64035 L .47426 .63643 L F
.589 .234 .335 r
.47471 .63671 m .47338 .63711 L .47426 .63643 L F
.137 .359 .817 r
.47426 .63643 m .47206 .63506 L .47187 .63454 L F
.126 0 0 r
.16768 .55685 m .16803 .55796 L .16951 .55586 L F
.16768 .55685 m .16581 .55861 L .16803 .55796 L F
0 0 0 r
.5141 .60064 m .51416 .59906 L .51396 .59804 L F
.5141 .60064 m .51362 .60189 L .51416 .59906 L F
.918 .769 .68 r
.57184 .5409 m .57295 .5444 L .57349 .54182 L F
.645 .298 .37 r
.46213 .63217 m .46444 .63433 L .4665 .63131 L F
.736 .482 .545 r
.46444 .63433 m .46845 .63116 L .4665 .63131 L F
.699 .294 .276 r
.55508 .50921 m .55877 .50807 L .55512 .50713 L F
.55508 .50921 m .55765 .50994 L .55877 .50807 L F
.625 .209 .235 r
.55877 .50807 m .55765 .50994 L .56122 .50989 L F
.602 .235 .318 r
.55877 .50807 m .56122 .50989 L .56158 .50829 L F
.664 .35 .432 r
.46892 .63086 m .47187 .63454 L .46898 .63242 L F
.688 .555 .698 r
.47358 .63213 m .47187 .63454 L .46892 .63086 L F
.724 .651 .776 r
.43175 .66533 m .43578 .66639 L .43399 .66273 L F
.695 .228 .137 r
.43175 .66533 m .43446 .66748 L .43578 .66639 L F
.268 0 .188 r
.20489 .53884 m .204 .54058 L .20681 .53818 L F
.88 .786 .753 r
.55664 .58144 m .55624 .58336 L .5549 .58032 L F
.666 .581 .75 r
.3171 .57725 m .3146 .57793 L .31516 .57752 L F
.561 .434 .664 r
.31724 .57981 m .3146 .57793 L .3171 .57725 L F
.31724 .57981 m .31488 .58049 L .3146 .57793 L F
0 0 .002 r
.76129 .41914 m .7631 .41429 L .7605 .41684 L F
.496 .241 .457 r
.27905 .63203 m .27827 .63569 L .27601 .63562 L F
.494 .262 .491 r
.28171 .62944 m .28151 .63163 L .27905 .63203 L F
.513 .256 .462 r
.28238 .63412 m .27905 .63203 L .28151 .63163 L F
.28238 .63412 m .27827 .63569 L .27905 .63203 L F
.588 .929 .731 r
.4607 .56814 m .4619 .56687 L .46383 .56589 L F
.027 .242 .745 r
.46493 .56489 m .46383 .56589 L .4619 .56687 L F
.46563 .56672 m .46598 .56764 L .46391 .56596 L F
.653 .542 .717 r
.46652 .567 m .46673 .56701 L .46652 .56676 L F
.46647 .56694 m .46652 .56676 L .46493 .56489 L F
.46652 .567 m .46652 .56676 L .46647 .56694 L F
.561 .545 .794 r
.46704 .56611 m .46571 .56965 L .46574 .56943 L F
.46644 .56698 m .46574 .56943 L .46598 .56764 L F
.46645 .567 m .46574 .56943 L .46644 .56698 L F
.183 .357 .803 r
.46493 .56489 m .46647 .56694 L .46598 .56764 L F
.122 .165 .635 r
.4619 .56687 m .46424 .56794 L .46649 .5671 L F
.46649 .5671 m .46649 .5671 L .4665 .5671 L F
.4619 .56687 m .46649 .5671 L .46649 .5671 L F
.561 .545 .794 r
.46647 .56694 m .46645 .567 L .46644 .56698 L F
.122 .165 .635 r
.46645 .567 m .4665 .5671 L .46673 .56701 L F
.46627 .567 m .46649 .56709 L .46645 .567 L F
.46649 .56709 m .4665 .5671 L .46645 .567 L F
.138 .357 .815 r
.46653 .56677 m .46704 .56611 L .46493 .56489 L F
.46673 .56701 m .46704 .56611 L .46653 .56677 L F
.183 .357 .803 r
.46493 .56489 m .46704 .56611 L .46647 .56694 L F
.027 .242 .745 r
.46493 .56489 m .46563 .56672 L .46383 .56589 L F
.46563 .56672 m .46391 .56596 L .46383 .56589 L F
.653 .542 .717 r
.4619 .56687 m .46652 .567 L .46493 .56489 L F
.122 .165 .635 r
.4619 .56687 m .4665 .5671 L .46627 .567 L F
.781 .944 .601 r
.46527 .56784 m .46673 .56701 L .46424 .56794 L F
.59 .868 .542 r
.46797 .56488 m .46704 .56611 L .46527 .56784 L F
.46845 .56436 m .46704 .56611 L .46797 .56488 L F
.781 .944 .601 r
.46655 .56711 m .46704 .56611 L .46673 .56701 L F
.561 .545 .794 r
.46704 .56611 m .46653 .56716 L .46647 .56694 L F
.46657 .56731 m .46645 .567 L .46647 .56694 L F
.781 .944 .601 r
.46527 .56784 m .46704 .56611 L .46655 .56711 L F
.561 .545 .794 r
.46704 .56611 m .46657 .56731 L .46653 .56716 L F
.46657 .56731 m .46574 .56943 L .46645 .567 L F
.712 .932 .608 r
.24432 .65309 m .2433 .65461 L .24188 .65614 L F
.698 .681 .829 r
.24344 .65705 m .24432 .65309 L .24188 .65614 L F
.24344 .65705 m .24576 .65642 L .24432 .65309 L F
.55 .401 .632 r
.31809 .56826 m .31607 .57122 L .31576 .56878 L F
.716 .437 .502 r
.5652 .50984 m .56907 .50792 L .56479 .50823 L F
.5652 .50984 m .56684 .51055 L .56907 .50792 L F
.781 .53 .556 r
.56907 .50792 m .56684 .51055 L .5692 .51044 L F
.849 .408 .171 r
.79489 .40192 m .79405 .40309 L .79214 .40041 L F
.664 .163 .047 r
.79489 .40192 m .79758 .40373 L .79405 .40309 L F
.687 .316 .34 r
.56158 .50829 m .5652 .50984 L .56479 .50823 L F
.816 .646 .672 r
.57255 .54699 m .57061 .54992 L .57423 .55053 L F
.838 .608 .59 r
.57061 .54992 m .57391 .55314 L .57423 .55053 L F
0 0 0 r
.17433 .60221 m .17226 .60379 L .17098 .604 L F
.909 .977 .698 r
.17381 .60073 m .17226 .60379 L .17433 .60221 L F
0 0 .014 r
.25672 .61738 m .25428 .62049 L .25584 .61929 L F
0 0 0 r
.25584 .61929 m .25428 .62049 L .25272 .62245 L F
.789 .674 .737 r
.66271 .41463 m .66205 .41672 L .66435 .41371 L F
.685 .521 .658 r
.66435 .41371 m .66205 .41672 L .66465 .41637 L F
.364 .096 .368 r
.1935 .55965 m .19287 .56214 L .19084 .56254 L F
.422 .148 .39 r
.19491 .56142 m .1935 .55965 L .19564 .55906 L F
.19491 .56142 m .19287 .56214 L .1935 .55965 L F
.784 .554 .588 r
.48546 .55982 m .48496 .56248 L .48869 .56237 L F
.232 0 0 r
.48496 .56248 m .48706 .56282 L .48869 .56237 L F
.436 0 0 r
.48706 .56282 m .49046 .56316 L .48869 .56237 L F
.522 .242 .431 r
.28417 .62936 m .28151 .63163 L .28171 .62944 L F
.873 .917 .854 r
.83643 .43212 m .83297 .43381 L .83617 .43218 L F
0 0 .506 r
.83745 .43149 m .83643 .43212 L .83617 .43218 L F
.83745 .43149 m .83745 .43503 L .83643 .43212 L F
.917 .755 .666 r
.56517 .54069 m .56394 .53769 L .56549 .53842 L F
.56517 .54069 m .5623 .54065 L .56394 .53769 L F
.912 .843 .763 r
.56517 .54069 m .56136 .54286 L .5623 .54065 L F
.56517 .54069 m .56283 .54401 L .56136 .54286 L F
.311 0 0 r
.44532 .6448 m .44707 .64591 L .45091 .64386 L F
.762 .525 .575 r
.44707 .64591 m .45073 .64368 L .45091 .64386 L F
.98 .718 .46 r
.45073 .64368 m .45076 .64629 L .45247 .64511 L F
.633 .132 .04 r
.45076 .64629 m .45472 .64688 L .45247 .64511 L F
.588 .457 .67 r
.45247 .64511 m .4553 .64455 L .45475 .64153 L F
.512 .233 .428 r
.45247 .64511 m .45472 .64688 L .4553 .64455 L F
.564 .742 .96 r
.2767 .55304 m .27445 .55361 L .27233 .55213 L F
.2767 .55304 m .27445 .55361 L .27233 .55213 L F
.856 .997 .807 r
.28108 .58398 m .27866 .58488 L .28115 .58217 L F
0 .264 .772 r
.17555 .60741 m .17594 .60963 L .17416 .60798 L F
.17555 .60741 m .17753 .61054 L .17594 .60963 L F
.281 .72 .965 r
.20747 .75409 m .20364 .75334 L .20574 .75329 L F
.76 .666 .759 r
.20364 .75334 m .20747 .75409 L .20574 .75329 L F
.219 0 .253 r
.14308 .5748 m .14482 .57413 L .14558 .572 L F
.279 0 .282 r
.14558 .572 m .14669 .57344 L .14762 .57133 L F
.14558 .572 m .14482 .57413 L .14669 .57344 L F
.566 .669 .908 r
.78526 .44501 m .78725 .44264 L .78467 .44303 L F
.78526 .44501 m .78777 .44475 L .78725 .44264 L F
.08 0 .073 r
.18145 .78665 m .18247 .78442 L .18129 .78671 L F
.18145 .78665 m .18406 .78395 L .18247 .78442 L F
0 0 .121 r
.78408 .38458 m .78372 .38423 L .78218 .38687 L F
0 0 .503 r
.78408 .38458 m .78556 .38633 L .78372 .38423 L F
.572 .566 .809 r
.78218 .38687 m .78556 .38633 L .78408 .38458 L F
.725 .711 .837 r
.67324 .42808 m .67689 .42868 L .67589 .425 L F
.793 .737 .801 r
.67589 .425 m .67689 .42868 L .67933 .42556 L F
.369 .462 .825 r
.78312 .43249 m .78204 .42932 L .77925 .43185 L F
.361 .748 .987 r
.78139 .43166 m .78312 .43249 L .77925 .43185 L F
.73 .7 .822 r
.78379 .43007 m .78534 .43159 L .78312 .43249 L F
.78433 .4281 m .78499 .43038 L .78379 .43007 L F
.78499 .43038 m .78534 .43159 L .78379 .43007 L F
.78433 .4281 m .78312 .43249 L .7839 .43061 L F
.609 .915 .656 r
.78085 .42999 m .77925 .43185 L .78204 .42932 L F
.583 .025 0 r
.78168 .42953 m .7839 .43061 L .78085 .42999 L F
.78204 .42932 m .78272 .42979 L .78168 .42953 L F
.78272 .42979 m .7839 .43061 L .78168 .42953 L F
.674 .862 .971 r
.7839 .43061 m .78312 .43249 L .78139 .43166 L F
.454 .307 .592 r
.14286 .57738 m .14482 .57413 L .14308 .5748 L F
.604 .654 .872 r
.25386 .64335 m .25644 .64791 L .25386 .64804 L F
.466 .029 .125 r
.25386 .64804 m .25644 .64791 L .25703 .64811 L F
.658 .569 .743 r
.25703 .64811 m .25426 .65054 L .25386 .64804 L F
.554 .194 .311 r
.42271 .66857 m .41901 .66949 L .42035 .67142 L F
.248 0 .199 r
.48942 .62553 m .48588 .6282 L .4866 .62641 L F
.181 .673 .92 r
.80065 .44358 m .80424 .4443 L .80328 .44374 L F
.014 .545 .851 r
.80328 .44374 m .80424 .4443 L .80773 .44495 L F
.486 .021 .075 r
.50701 .54727 m .50992 .54752 L .51071 .54669 L F
.496 .244 .463 r
.26113 .61358 m .26402 .61079 L .26168 .61137 L F
.006 .528 .855 r
.21099 .62415 m .21048 .62457 L .20894 .62263 L F
.21099 .62415 m .21305 .62516 L .21048 .62457 L F
.637 .679 .873 r
.74258 .39483 m .74402 .39119 L .74148 .39175 L F
.74258 .39483 m .74507 .39374 L .74402 .39119 L F
.327 .1 .409 r
.44781 .5833 m .44541 .58645 L .44582 .58409 L F
.747 .235 0 r
.49155 .56453 m .49291 .56522 L .49046 .56316 L F
.065 0 .046 r
.49341 .56685 m .49291 .56522 L .49155 .56453 L F
.756 .265 0 r
.53004 .52539 m .52745 .52234 L .5279 .52624 L F
.607 .624 .842 r
.54326 .60408 m .54515 .60521 L .54383 .6021 L F
.839 .869 .865 r
.54515 .60521 m .54622 .60145 L .54383 .6021 L F
.54515 .60521 m .5472 .60227 L .54622 .60145 L F
.241 .13 .52 r
.31549 .59164 m .31359 .58998 L .31645 .58935 L F
.31549 .59164 m .31405 .59247 L .31359 .58998 L F
.494 .37 .64 r
.65855 .42881 m .66102 .42846 L .66025 .42591 L F
.15 0 .222 r
.2592 .61435 m .25672 .61738 L .25841 .61654 L F
.091 0 .112 r
.25841 .61654 m .25672 .61738 L .25584 .61929 L F
.985 .755 .508 r
.53994 .58607 m .54117 .58953 L .54163 .58839 L F
.71 .901 .532 r
.57981 .58805 m .57766 .59113 L .57916 .58945 L F
.154 .292 .754 r
.4834 .55929 m .48496 .56248 L .48546 .55982 L F
.562 .223 .352 r
.66622 .41889 m .6679 .41725 L .66465 .41637 L F
.66622 .41889 m .66844 .41876 L .6679 .41725 L F
.472 .249 .494 r
.30968 .60172 m .30708 .60489 L .30725 .60217 L F
.278 0 0 r
.24368 .62537 m .24791 .62326 L .24544 .62305 L F
.062 0 0 r
.26508 .55315 m .26359 .55474 L .26671 .55271 L F
.511 .428 .698 r
.30233 .61364 m .29964 .61168 L .30201 .61108 L F
.30233 .61364 m .30016 .61424 L .29964 .61168 L F
.227 .355 .785 r
.18326 .63197 m .18471 .63557 L .18547 .63365 L F
.405 .563 .898 r
.18547 .63365 m .18471 .63557 L .18663 .63551 L F
0 0 .19 r
.41908 .66577 m .41991 .66448 L .42007 .66186 L F
.671 .636 .806 r
.41901 .66949 m .41991 .66448 L .41908 .66577 L F
.446 .57 .886 r
.24532 .65257 m .24645 .65209 L .24432 .65309 L F
.32 .79 .928 r
.22648 .62801 m .22416 .62843 L .22265 .62811 L F
.417 .691 .976 r
.17093 .59793 m .17042 .59957 L .1687 .59862 L F
.17093 .59793 m .17235 .5994 L .17042 .59957 L F
.518 0 0 r
.18145 .61325 m .18553 .61453 L .18322 .61442 L F
.666 .581 .75 r
.3171 .57725 m .31516 .57752 L .31724 .57629 L F
.982 .736 .485 r
.51197 .59476 m .51356 .59304 L .51201 .59208 L F
.51197 .59476 m .51339 .59567 L .51356 .59304 L F
.381 .29 .626 r
.45754 .65633 m .45558 .65981 L .45565 .65524 L F
.45754 .65633 m .45777 .65995 L .45558 .65981 L F
.951 .74 .581 r
.45777 .65995 m .45553 .66185 L .45558 .65981 L F
.324 0 0 r
.19781 .54305 m .20013 .54297 L .20214 .54152 L F
.249 0 0 r
.20013 .54297 m .204 .54058 L .20214 .54152 L F
.136 0 .154 r
.25841 .61654 m .26113 .61358 L .2592 .61435 L F
.307 .719 .976 r
.49316 .54351 m .49544 .54366 L .49699 .54453 L F
.693 .155 0 r
.49608 .54537 m .49699 .54453 L .49544 .54366 L F
.49608 .54537 m .49938 .54659 L .49699 .54453 L F
.548 .554 .812 r
.31251 .54657 m .31166 .55083 L .31031 .5468 L F
.31251 .54657 m .31392 .55041 L .31166 .55083 L F
.91 .8 .726 r
.76283 .38572 m .76359 .38929 L .76422 .38698 L F
.963 .819 .654 r
.76228 .38786 m .76359 .38929 L .76283 .38572 L F
.931 .842 .734 r
.7619 .39258 m .76359 .38929 L .76228 .38786 L F
.66 .374 .475 r
.53822 .57628 m .54157 .57256 L .53833 .57259 L F
.665 .698 .87 r
.16125 .59045 m .15929 .59198 L .15748 .58922 L F
.477 .309 .574 r
.32149 .55357 m .32153 .55597 L .31933 .55657 L F
.527 .425 .682 r
.32153 .55597 m .31964 .55902 L .31933 .55657 L F
0 0 .378 r
.78408 .38458 m .78372 .38423 L .7838 .38224 L F
.945 .848 .715 r
.44532 .6448 m .44237 .64762 L .44465 .64655 L F
.78 .702 .777 r
.51276 .62016 m .51429 .62341 L .51679 .62036 L F
.515 .753 .982 r
.81968 .39971 m .81614 .39869 L .81876 .39809 L F
.568 .761 .969 r
.82148 .3975 m .81968 .39971 L .81876 .39809 L F
.82148 .3975 m .82255 .39906 L .81968 .39971 L F
0 0 0 r
.23754 .67901 m .23467 .67918 L .23332 .6793 L F
.61 .378 .539 r
.44931 .57499 m .45419 .57617 L .45252 .5716 L F
.77 .409 0 r
.45252 .5716 m .45419 .57617 L .45373 .57505 L F
.45252 .5716 m .45373 .57505 L .45508 .57149 L F
.527 .049 .063 r
.45764 .61079 m .45687 .61139 L .45435 .61104 L F
.884 .551 .414 r
.45764 .61079 m .45668 .61308 L .45687 .61139 L F
.177 0 .108 r
.45975 .61061 m .45764 .61079 L .45975 .61024 L F
.45975 .61061 m .45668 .61308 L .45764 .61079 L F
.28 0 0 r
.2189 .7203 m .21859 .7209 L .21333 .72266 L F
.131 .257 .728 r
.21956 .7188 m .2189 .7203 L .21817 .71775 L F
.664 .783 .318 r
.21956 .7188 m .21859 .7209 L .2189 .7203 L F
0 .405 .834 r
.24197 .55061 m .24373 .55119 L .24299 .55035 L F
.588 .657 .885 r
.3065 .54486 m .3047 .54579 L .30263 .54299 L F
.602 .453 .651 r
.31964 .55902 m .31719 .56221 L .31677 .55961 L F
.31964 .55902 m .32035 .56323 L .31719 .56221 L F
.603 .471 .673 r
.32039 .56518 m .31719 .56221 L .32035 .56323 L F
.32039 .56518 m .31813 .56602 L .31719 .56221 L F
.436 .518 .844 r
.15694 .6134 m .15862 .61704 L .16037 .61667 L F
.459 .601 .905 r
.16474 .61934 m .16579 .62105 L .16648 .61888 L F
.589 .74 .948 r
.16579 .62105 m .16764 .62037 L .16648 .61888 L F
.857 .748 .742 r
.56444 .53493 m .56549 .53842 L .56394 .53769 L F
.527 .737 .971 r
.19894 .61871 m .19736 .61919 L .19478 .61732 L F
.208 .733 .831 r
.27647 .53799 m .27877 .53766 L .28034 .53772 L F
.171 .708 .754 r
.27877 .53766 m .28248 .5371 L .28034 .53772 L F
.71 .688 .827 r
.78763 .42888 m .78534 .43159 L .78433 .4281 L F
.631 .566 .763 r
.78763 .42888 m .78872 .43256 L .78534 .43159 L F
.777 .692 .77 r
.78872 .43256 m .78741 .4357 L .78534 .43159 L F
.066 .587 .875 r
.28572 .53838 m .28912 .53904 L .2906 .53977 L F
.369 0 0 r
.28912 .53904 m .2934 .54024 L .2906 .53977 L F
.289 .151 .513 r
.27049 .59587 m .2724 .59227 L .27076 .59238 L F
.912 .768 .689 r
.53303 .57096 m .53481 .57181 L .53381 .56841 L F
.976 .79 .587 r
.53289 .57373 m .53481 .57181 L .53303 .57096 L F
.53289 .57373 m .53433 .57475 L .53481 .57181 L F
.867 .696 .669 r
.57362 .55582 m .5751 .55915 L .57558 .55655 L F
.816 .765 .806 r
.55919 .57161 m .55595 .57097 L .55848 .56817 L F
.876 .686 .643 r
.55919 .57161 m .5558 .57355 L .55595 .57097 L F
.55919 .57161 m .55771 .5748 L .5558 .57355 L F
.316 0 .036 r
.19287 .56214 m .18927 .5641 L .19084 .56254 L F
.969 .678 .422 r
.22731 .70362 m .22787 .70801 L .22597 .70629 L F
.67 .635 .806 r
.22662 .70144 m .22731 .70362 L .23021 .70203 L F
.462 .314 .594 r
.22996 .70725 m .22787 .70801 L .22731 .70362 L F
.797 .302 0 r
.22803 .70633 m .22731 .70362 L .22597 .70629 L F
.22803 .70633 m .22996 .70725 L .22731 .70362 L F
0 0 0 r
.83995 .41918 m .84185 .4182 L .84279 .41855 L F
.83995 .41918 m .83961 .41949 L .84185 .4182 L F
.607 .624 .842 r
.54326 .60408 m .54383 .6021 L .54073 .60476 L F
.349 .068 .338 r
.44103 .57756 m .44306 .57706 L .44381 .57452 L F
.337 0 .12 r
.44306 .57706 m .4464 .57465 L .44381 .57452 L F
.775 .879 .922 r
.54073 .60476 m .54242 .601 L .53996 .60164 L F
.54073 .60476 m .54383 .6021 L .54242 .601 L F
.518 .245 .439 r
.28718 .62681 m .28663 .62902 L .28417 .62936 L F
.48 .221 .443 r
.28947 .62627 m .28663 .62902 L .28718 .62681 L F
.59 .644 .873 r
.54901 .58325 m .54737 .58672 L .54595 .58512 L F
.54901 .58325 m .54968 .58614 L .54737 .58672 L F
.847 .719 .722 r
.17753 .61054 m .17973 .61146 L .18183 .6082 L F
.606 .069 0 r
.83776 .42539 m .84162 .42618 L .83973 .42693 L F
.729 .941 .621 r
.84162 .42618 m .8441 .42305 L .84287 .42394 L F
.761 .989 .771 r
.84162 .42618 m .84287 .42394 L .83973 .42693 L F
.259 .365 .782 r
.75517 .41039 m .75642 .41419 L .75799 .41216 L F
.416 .593 .916 r
.75642 .41419 m .76056 .41522 L .75799 .41216 L F
.997 .773 .434 r
.5807 .58337 m .5809 .58085 L .57972 .58239 L F
.981 .857 .475 r
.57972 .58239 m .5809 .58085 L .58029 .57993 L F
.467 .419 .721 r
.43924 .58378 m .44025 .57927 L .43838 .58019 L F
.43924 .58378 m .44128 .58325 L .44025 .57927 L F
.956 .67 .452 r
.56431 .5322 m .56444 .53493 L .56267 .53128 L F
.225 0 .303 r
.40774 .61169 m .407 .61374 L .40944 .61066 L F
.777 .692 .77 r
.78872 .43256 m .78879 .43467 L .78741 .4357 L F
.64 .585 .776 r
.79207 .43191 m .78879 .43467 L .78872 .43256 L F
1 .827 .501 r
.75869 .40042 m .75955 .39725 L .75827 .3969 L F
.651 .722 .9 r
.75955 .39725 m .75958 .39332 L .75827 .3969 L F
.75955 .39725 m .76384 .39631 L .75958 .39332 L F
.698 .631 .778 r
.24576 .65642 m .24872 .65435 L .24645 .65209 L F
.685 .515 .651 r
.47105 .56394 m .469 .56408 L .47124 .56349 L F
.778 .68 .755 r
.46335 .65116 m .46342 .65369 L .45984 .65303 L F
.748 .596 .688 r
.46355 .65639 m .45984 .65303 L .46342 .65369 L F
.595 .534 .756 r
.46636 .65299 m .46342 .65369 L .46335 .65116 L F
.59 .44 .646 r
.46636 .65299 m .46355 .65639 L .46342 .65369 L F
.883 .791 .301 r
.8441 .42305 m .8444 .41823 L .84455 .42074 L F
.874 .953 .602 r
.84287 .42394 m .8441 .42305 L .84455 .42074 L F
.629 .815 .971 r
.48823 .6406 m .49013 .64208 L .49204 .64103 L F
.48823 .6406 m .49013 .64208 L .49204 .64103 L F
.863 .605 .548 r
.53168 .56814 m .53381 .56841 L .53379 .56563 L F
.691 .471 .584 r
.47371 .6441 m .47105 .64156 L .47402 .64162 L F
.583 .526 .756 r
.47568 .64022 m .47371 .6441 L .47402 .64162 L F
.677 .761 .915 r
.48093 .55925 m .4783 .56037 L .47722 .5589 L F
.567 .407 .623 r
.4783 .56037 m .48093 .55925 L .47722 .5589 L F
.4783 .56037 m .48099 .5619 L .48093 .55925 L F
.78 .702 .777 r
.51276 .62016 m .51679 .62036 L .51566 .61965 L F
.997 .833 .557 r
.51635 .61676 m .51566 .61965 L .51679 .62036 L F
.868 .75 .73 r
.57111 .54324 m .57295 .5444 L .57184 .5409 L F
.856 .726 .719 r
.57111 .54324 m .57255 .54699 L .57295 .5444 L F
.772 .458 .456 r
.45937 .62929 m .45897 .63154 L .45828 .63081 L F
.38 0 0 r
.80411 .40612 m .80476 .4052 L .80788 .40583 L F
.584 .7 .922 r
.43367 .58605 m .43728 .58753 L .43547 .58632 L F
.721 .887 .957 r
.43886 .58596 m .43728 .58753 L .43547 .58632 L F
0 .156 .697 r
.42329 .66566 m .42534 .66803 L .42342 .66509 L F
0 0 0 r
.42297 .66791 m .42329 .66566 L .42342 .66509 L F
.554 .194 .311 r
.42271 .66857 m .42232 .66909 L .41901 .66949 L F
.671 .636 .806 r
.42232 .66909 m .42259 .6692 L .42252 .66907 L F
.41901 .66949 m .42075 .66935 L .42232 .66909 L F
.42075 .66935 m .42259 .6692 L .42232 .66909 L F
.832 .703 .721 r
.42534 .66803 m .42408 .6688 L .42271 .66857 L F
.42408 .6688 m .42326 .66894 L .42271 .66857 L F
.42326 .66894 m .42232 .66909 L .42259 .66872 L F
.42326 .66894 m .42259 .66872 L .42271 .66857 L F
0 0 0 r
.42301 .66761 m .42271 .66857 L .42329 .66566 L F
.42297 .66791 m .42286 .66818 L .42301 .66761 L F
.42286 .66818 m .42271 .66857 L .42301 .66761 L F
.302 .479 .868 r
.41991 .66448 m .42326 .66894 L .42297 .66791 L F
.42326 .66894 m .42341 .66913 L .42335 .66897 L F
.42326 .66894 m .42335 .66897 L .42297 .66791 L F
.671 .636 .806 r
.42259 .6692 m .42282 .66835 L .41991 .66448 L F
.558 .179 .278 r
.41901 .66949 m .42123 .67057 L .42341 .66913 L F
.832 .703 .721 r
.42342 .66891 m .42123 .67057 L .42232 .66909 L F
.554 .194 .311 r
.42232 .66909 m .42123 .67057 L .41901 .66949 L F
.671 .636 .806 r
.41901 .66949 m .42252 .66907 L .41991 .66448 L F
.42259 .6692 m .42341 .66913 L .42282 .66835 L F
.489 .266 .501 r
.42123 .67057 m .42297 .66791 L .42335 .66897 L F
.42123 .67057 m .42335 .66897 L .42341 .66913 L F
.832 .703 .721 r
.42408 .6688 m .42123 .67057 L .42342 .66891 L F
.9 .589 .094 r
.41944 .65392 m .4204 .65663 L .41962 .65527 L F
0 0 .154 r
.4204 .65663 m .4209 .65789 L .41962 .65527 L F
.783 .497 .502 r
.42071 .65686 m .42044 .65925 L .4241 .65938 L F
.4204 .65663 m .42044 .65925 L .42071 .65686 L F
.869 .765 .745 r
.42007 .66186 m .4241 .65938 L .42044 .65925 L F
0 0 .009 r
.4209 .65789 m .42022 .66115 L .42044 .65925 L F
.42022 .66115 m .42007 .66186 L .42044 .65925 L F
0 0 .154 r
.4204 .65663 m .42044 .65925 L .4209 .65789 L F
.4209 .65789 m .4204 .65663 L .42178 .65512 L F
.4209 .65789 m .42044 .65925 L .4204 .65663 L F
.663 .199 0 r
.51362 .60189 m .51516 .60413 L .51617 .60524 L F
1 .811 .505 r
.51516 .60413 m .51489 .60677 L .51617 .60524 L F
.908 .562 .375 r
.51617 .60524 m .51489 .60677 L .5169 .60756 L F
1 .811 .505 r
.51516 .60413 m .51489 .60677 L .51617 .60524 L F
.288 0 .055 r
.27063 .6387 m .26904 .64087 L .26666 .64128 L F
.414 0 .132 r
.27198 .63984 m .27063 .6387 L .2731 .63835 L F
.27198 .63984 m .26904 .64087 L .27063 .6387 L F
.427 .612 .926 r
.21497 .62504 m .21415 .62698 L .21305 .62516 L F
.21497 .62504 m .2173 .62766 L .21415 .62698 L F
.505 .806 .999 r
.22114 .6436 m .22511 .6439 L .2229 .64375 L F
.526 .823 .999 r
.22687 .64417 m .22942 .64354 L .22924 .64346 L F
.22734 .64354 m .22924 .64346 L .22786 .64285 L F
.22687 .64417 m .22924 .64346 L .22734 .64354 L F
.369 .605 .94 r
.22464 .64387 m .22708 .64356 L .2229 .64375 L F
.57 .767 .971 r
.2229 .64375 m .22355 .64371 L .2238 .64164 L F
.526 .823 .999 r
.22734 .64354 m .22786 .64285 L .22708 .64356 L F
.22708 .64356 m .22786 .64285 L .22773 .64279 L F
.22731 .64288 m .22773 .64279 L .22739 .64263 L F
.22708 .64356 m .22773 .64279 L .22731 .64288 L F
.22708 .64356 m .22739 .64263 L .22804 .64343 L F
.57 .767 .971 r
.22355 .64371 m .22804 .64343 L .22693 .64296 L F
.22355 .64371 m .22693 .64296 L .2238 .64164 L F
.369 .605 .94 r
.22511 .6439 m .22687 .64417 L .22734 .64354 L F
.526 .823 .999 r
.22687 .64417 m .22734 .64354 L .22708 .64356 L F
.369 .605 .94 r
.22511 .6439 m .22734 .64354 L .22464 .64387 L F
.22734 .64354 m .22804 .64343 L .22708 .64356 L F
.22734 .64354 m .22708 .64356 L .22464 .64387 L F
.22703 .64356 m .22591 .64356 L .22355 .64371 L F
.22708 .64356 m .22355 .64371 L .2229 .64375 L F
.57 .767 .971 r
.2229 .64375 m .2238 .64164 L .22417 .64378 L F
.725 .816 .921 r
.21924 .64156 m .22371 .64357 L .2238 .64164 L F
.22371 .64357 m .22417 .64378 L .22413 .64357 L F
.22371 .64357 m .22413 .64357 L .2238 .64164 L F
.369 .605 .94 r
.22708 .64356 m .22804 .64343 L .22591 .64356 L F
.22708 .64356 m .22591 .64356 L .22703 .64356 L F
.22734 .64354 m .22687 .64417 L .22804 .64343 L F
.526 .823 .999 r
.22687 .64417 m .22708 .64356 L .22804 .64343 L F
.585 .523 .752 r
.75142 .40707 m .75274 .41128 L .75517 .41039 L F
.578 .362 .551 r
.2108 .72662 m .21146 .73002 L .21426 .72874 L F
.744 .341 0 r
.21426 .72874 m .21298 .72611 L .2108 .72662 L F
.487 .259 .493 r
.30016 .61424 m .29986 .61667 L .29756 .61714 L F
.464 .252 .505 r
.30233 .61364 m .29986 .61667 L .30016 .61424 L F
.303 .652 .97 r
.2548 .54993 m .25653 .5499 L .25489 .54843 L F
.558 .531 .781 r
.17574 .62607 m .17704 .62998 L .17908 .62928 L F
.633 .484 .663 r
.48438 .58385 m .4839 .58676 L .48471 .58581 L F
.893 .498 .267 r
.4612 .60454 m .46045 .60273 L .46057 .60189 L F
.128 .639 .896 r
.24768 .53603 m .24999 .53617 L .25192 .53686 L F
.404 .794 .989 r
.24999 .53617 m .2543 .53662 L .25192 .53686 L F
.502 .527 .815 r
.74681 .39787 m .75043 .40117 L .74896 .39772 L F
.886 .61 .514 r
.56089 .52296 m .56319 .5263 L .56097 .52536 L F
.923 .771 .674 r
.56319 .5263 m .5607 .52788 L .56097 .52536 L F
.56319 .5263 m .56246 .52877 L .5607 .52788 L F
.21 .497 .903 r
.20767 .62077 m .20735 .6224 L .20502 .6201 L F
.20767 .62077 m .20894 .62263 L .20735 .6224 L F
.312 .205 .568 r
.54157 .57256 m .54347 .57372 L .54249 .57188 L F
.54157 .57256 m .54347 .57372 L .54249 .57188 L F
.087 .281 .764 r
.50532 .59569 m .50792 .59825 L .50624 .59418 L F
.671 .945 .683 r
.50624 .59418 m .50454 .59605 L .50532 .59569 L F
.826 .602 .599 r
.57131 .51306 m .57269 .51622 L .57471 .51369 L F
.589 .538 .766 r
.22922 .68055 m .23029 .685 L .23258 .68398 L F
.822 .608 .612 r
.67596 .42248 m .67933 .42556 L .67979 .42312 L F
.523 .533 .808 r
.48628 .5687 m .48863 .56856 L .48706 .56282 L F
.492 .25 .475 r
.48863 .56856 m .48618 .57105 L .48628 .5687 L F
.48628 .5687 m .48618 .57105 L .48863 .56856 L F
.469 .231 .471 r
.48618 .57105 m .48375 .57171 L .48628 .5687 L F
.794 .809 .864 r
.83379 .40872 m .83745 .40796 L .8366 .4068 L F
.644 .863 .982 r
.8366 .4068 m .83745 .40796 L .84002 .40691 L F
.444 .793 .998 r
.21456 .64342 m .21642 .64189 L .21175 .6452 L F
.21456 .64342 m .21714 .64307 L .21642 .64189 L F
.523 .238 .424 r
.44505 .62542 m .44724 .62661 L .44967 .62433 L F
.45077 .62419 m .45076 .62419 L .45116 .6241 L F
.45076 .62419 m .45054 .6242 L .45116 .6241 L F
.396 .21 .508 r
.45097 .62234 m .45076 .62419 L .45447 .62392 L F
.45076 .62419 m .4506 .62556 L .45422 .62402 L F
.45076 .62419 m .45422 .62402 L .45447 .62392 L F
.523 .238 .424 r
.45076 .62419 m .44967 .62433 L .45054 .6242 L F
.477 .279 .532 r
.44967 .62433 m .45031 .62518 L .45076 .62419 L F
.45031 .62518 m .4506 .62556 L .45075 .62421 L F
.45031 .62518 m .45075 .62421 L .45076 .62419 L F
.408 .086 .305 r
.44724 .62661 m .44924 .62745 L .44962 .62468 L F
.449 .62496 m .44962 .62468 L .44967 .62433 L F
.44724 .62661 m .44962 .62468 L .449 .62496 L F
.803 .488 .456 r
.44924 .62745 m .4506 .62556 L .45031 .62518 L F
.44962 .62468 m .45031 .62518 L .44967 .62433 L F
.44924 .62745 m .45031 .62518 L .44962 .62468 L F
.477 .279 .532 r
.44967 .62433 m .45097 .62234 L .45116 .6241 L F
.44967 .62433 m .45076 .62419 L .45097 .62234 L F
.565 .375 .583 r
.44715 .6229 m .45067 .62421 L .44998 .61952 L F
.523 .238 .424 r
.44505 .62542 m .44967 .62433 L .45067 .6242 L F
.44505 .62542 m .45067 .6242 L .45077 .62419 L F
.565 .375 .583 r
.44505 .62542 m .44936 .62449 L .44715 .6229 L F
.44936 .62449 m .45067 .62421 L .44715 .6229 L F
.45067 .62421 m .45077 .62419 L .45076 .62417 L F
.45067 .62421 m .45076 .62417 L .44998 .61952 L F
.45077 .62419 m .45116 .6241 L .45103 .62361 L F
.45077 .62419 m .45103 .62361 L .44998 .61952 L F
.742 .482 .538 r
.44998 .61952 m .45097 .62234 L .45316 .61954 L F
.44998 .61952 m .45116 .6241 L .45097 .62234 L F
.667 .124 0 r
.50454 .55543 m .50048 .55313 L .50271 .553 L F
.714 .324 .31 r
.21487 .7295 m .21662 .73202 L .21397 .73286 L F
.582 .537 .77 r
.66205 .41672 m .66622 .41889 L .66465 .41637 L F
.474 .356 .639 r
.74918 .3879 m .7498 .38347 L .74603 .38311 L F
.74918 .3879 m .75039 .3864 L .7498 .38347 L F
.105 .107 .575 r
.7498 .38347 m .75188 .38433 L .75247 .38277 L F
.7498 .38347 m .75039 .3864 L .75188 .38433 L F
.519 .858 .994 r
.14426 .60518 m .14124 .60548 L .14318 .6056 L F
0 0 0 r
.22944 .69391 m .22582 .69592 L .22752 .69286 L F
.83 .872 .875 r
.23054 .69252 m .22944 .69391 L .22752 .69286 L F
.695 .407 .482 r
.47406 .60705 m .47785 .6047 L .47545 .60462 L F
.635 .359 .484 r
.7639 .41342 m .76731 .4117 L .76659 .40804 L F
.7639 .41342 m .76577 .4135 L .76731 .4117 L F
.746 .774 .876 r
.76175 .41261 m .7639 .41342 L .76347 .40828 L F
.85 .845 .839 r
.76347 .40828 m .7639 .41342 L .76659 .40804 L F
.465 .762 .994 r
.76175 .41261 m .76577 .4135 L .7639 .41342 L F
.577 .765 .968 r
.76296 .41412 m .76577 .4135 L .76175 .41261 L F
.559 .095 0 r
.7638 .41521 m .76296 .41412 L .76175 .41261 L F
.7638 .41521 m .76481 .41644 L .76296 .41412 L F
.85 .634 .61 r
.67398 .42131 m .67609 .41992 L .67199 .41876 L F
.67398 .42131 m .67596 .42248 L .67609 .41992 L F
.677 .138 0 r
.27673 .56889 m .2788 .5709 L .27773 .56908 L F
.123 .216 .689 r
.27774 .56412 m .27773 .56908 L .27971 .56617 L F
.214 0 .287 r
.27773 .56908 m .28126 .56909 L .27971 .56617 L F
.27773 .56908 m .2788 .5709 L .28126 .56909 L F
.787 .333 0 r
.50587 .58175 m .50906 .58629 L .50811 .58483 L F
.649 .404 .535 r
.21054 .7203 m .21411 .71703 L .21192 .7172 L F
.907 .864 .787 r
.77026 .39414 m .77394 .39171 L .77019 .39141 L F
.77026 .39414 m .77167 .39542 L .77394 .39171 L F
.997 .851 .559 r
.76659 .40804 m .76731 .4117 L .76776 .40779 L F
.742 .977 .921 r
.76904 .40562 m .76776 .40779 L .76982 .40631 L F
.758 .993 .803 r
.76659 .40804 m .76776 .40779 L .76904 .40562 L F
.681 .321 .358 r
.79658 .39706 m .79995 .39527 L .79623 .39511 L F
.79658 .39706 m .79914 .39749 L .79995 .39527 L F
.625 .263 .336 r
.79914 .39749 m .8027 .39719 L .79995 .39527 L F
.572 .461 .689 r
.31817 .5838 m .31488 .58049 L .31724 .57981 L F
.31817 .5838 m .31586 .58473 L .31488 .58049 L F
.498 .229 .437 r
.45508 .57149 m .45768 .57115 L .4579 .56884 L F
.231 .016 .367 r
.4579 .56884 m .45923 .56984 L .4607 .56814 L F
.4579 .56884 m .45768 .57115 L .45923 .56984 L F
.962 .713 .514 r
.48983 .57651 m .49164 .57755 L .4913 .57476 L F
.642 .509 .685 r
.4241 .65938 m .42762 .66226 L .42743 .65964 L F
.742 .569 .659 r
.42762 .66226 m .43007 .65918 L .42743 .65964 L F
.673 .734 .896 r
.81043 .43113 m .8081 .4324 L .80678 .43045 L F
.734 .953 .947 r
.24373 .55119 m .24797 .55011 L .24588 .55087 L F
0 0 0 r
.2483 .55025 m .24797 .55011 L .25033 .5495 L F
.2483 .55025 m .24588 .55087 L .24797 .55011 L F
.822 .608 .612 r
.67596 .42248 m .67589 .425 L .67933 .42556 L F
.814 .745 .787 r
.25111 .6658 m .24879 .66902 L .24659 .6671 L F
.485 .293 .544 r
.25111 .6658 m .25108 .6685 L .24879 .66902 L F
.408 .117 .355 r
.25046 .6704 m .24879 .66902 L .25108 .6685 L F
.25046 .6704 m .24816 .671 L .24879 .66902 L F
.655 .582 .761 r
.4169 .63904 m .41722 .64169 L .41993 .64143 L F
.639 .452 .614 r
.41722 .64169 m .41985 .64406 L .41993 .64143 L F
.41722 .64169 m .4175 .64461 L .41985 .64406 L F
.658 .173 .089 r
.49045 .62217 m .49154 .62115 L .48983 .62084 L F
.49045 .62217 m .49449 .62276 L .49154 .62115 L F
.519 .363 .61 r
.45098 .63847 m .45177 .64137 L .45341 .638 L F
.512 .842 .998 r
.81436 .44789 m .81608 .44625 L .81306 .44671 L F
.81436 .44789 m .81707 .44721 L .81608 .44625 L F
.472 .285 .545 r
.44488 .62625 m .44724 .62661 L .44505 .62542 L F
.683 .786 .929 r
.83042 .43486 m .82769 .43586 L .82666 .43428 L F
.856 .726 .719 r
.57111 .54324 m .56925 .54645 L .57255 .54699 L F
.859 .712 .698 r
.56925 .54645 m .57061 .54992 L .57255 .54699 L F
.308 .061 .368 r
.48722 .6037 m .4856 .60433 L .48761 .60214 L F
.48713 .60391 m .4856 .60433 L .48722 .6037 L F
.48621 .60601 m .48593 .60524 L .48638 .60475 L F
.48646 .60545 m .48638 .60475 L .48666 .60499 L F
.48621 .60601 m .48627 .60555 L .48646 .60545 L F
.48627 .60555 m .48638 .60475 L .48646 .60545 L F
.48593 .60524 m .4856 .60433 L .48713 .60391 L F
.48647 .60674 m .48621 .60601 L .48722 .6037 L F
.608 .318 .451 r
.48948 .6064 m .48647 .60674 L .48684 .60523 L F
.311 .222 .59 r
.48666 .60499 m .48686 .60516 L .48724 .60514 L F
.608 .318 .451 r
.48693 .60519 m .48684 .60523 L .48686 .60516 L F
.311 .222 .59 r
.48686 .60516 m .48691 .6052 L .48693 .60519 L F
.48686 .60516 m .48693 .60519 L .48724 .60514 L F
.608 .318 .451 r
.48957 .60397 m .48761 .60214 L .4896 .60321 L F
.605 .413 .596 r
.48776 .60396 m .48724 .60514 L .4893 .60427 L F
.48962 .60393 m .4893 .60427 L .49012 .60392 L F
.608 .318 .451 r
.48847 .6041 m .48761 .60214 L .48957 .60397 L F
.605 .413 .596 r
.48776 .60396 m .48925 .60426 L .48962 .60393 L F
.48925 .60426 m .4893 .60427 L .48962 .60393 L F
.473 .222 .453 r
.48972 .60408 m .48957 .60414 L .48957 .60397 L F
.522 .918 .843 r
.48919 .60431 m .49004 .60393 L .49012 .60392 L F
.605 .413 .596 r
.4901 .60391 m .48997 .60392 L .49012 .60392 L F
.473 .222 .453 r
.49198 .60577 m .48957 .60397 L .48993 .60365 L F
.49016 .60382 m .48993 .60365 L .48997 .60361 L F
.735 .703 .166 r
.49012 .60392 m .49014 .6038 L .48999 .60369 L F
.473 .222 .453 r
.49198 .60577 m .48993 .60365 L .49016 .60382 L F
.565 .309 .486 r
.4903 .60161 m .48761 .60214 L .48688 .60106 L F
.4903 .60161 m .4896 .60321 L .48761 .60214 L F
.526 .703 .951 r
.48838 .60079 m .4903 .60161 L .48688 .60106 L F
.287 0 0 r
.49318 .60209 m .4896 .60321 L .4903 .60161 L F
.49318 .60209 m .49228 .60295 L .49026 .60315 L F
.4903 .60299 m .49026 .60315 L .4896 .60321 L F
.49318 .60209 m .49026 .60315 L .4903 .60299 L F
.735 .703 .166 r
.49014 .6038 m .49014 .6038 L .48999 .60369 L F
.473 .222 .453 r
.49222 .60349 m .4896 .60321 L .49228 .60295 L F
.49204 .60517 m .49018 .60367 L .49222 .60349 L F
.49018 .60367 m .4896 .60321 L .49222 .60349 L F
.605 .413 .596 r
.48688 .60106 m .48987 .6037 L .48838 .60079 L F
.48987 .6037 m .49012 .60392 L .48999 .60369 L F
.48987 .6037 m .48999 .60369 L .48838 .60079 L F
.473 .222 .453 r
.49016 .60382 m .49014 .60379 L .49204 .60517 L F
.49014 .60379 m .4896 .60321 L .49016 .60366 L F
.49014 .60379 m .49016 .60366 L .49204 .60517 L F
.735 .703 .166 r
.49014 .6038 m .49078 .59985 L .48999 .60369 L F
.49014 .6038 m .49014 .60366 L .4902 .60341 L F
.49012 .60392 m .49012 .60388 L .49014 .6038 L F
.49012 .60388 m .49014 .60366 L .49014 .6038 L F
.49014 .6038 m .48999 .60369 L .48999 .60369 L F
.473 .222 .453 r
.49198 .60577 m .49016 .60382 L .49204 .60517 L F
.735 .703 .166 r
.48999 .60369 m .49078 .59985 L .48838 .60079 L F
.605 .413 .596 r
.48844 .60244 m .48776 .60396 L .48997 .60392 L F
.473 .222 .453 r
.48997 .60361 m .48957 .60397 L .4896 .60321 L F
.605 .413 .596 r
.48844 .60244 m .48997 .60392 L .4901 .60391 L F
.608 .318 .451 r
.48847 .6041 m .48723 .60386 L .48761 .60214 L F
.605 .413 .596 r
.48713 .60391 m .48724 .60514 L .48844 .60244 L F
.608 .318 .451 r
.48862 .60444 m .48723 .60506 L .48723 .60386 L F
.48723 .60506 m .48693 .60519 L .48694 .60517 L F
.784 .547 .577 r
.48666 .60499 m .48724 .60514 L .48713 .60391 L F
.608 .318 .451 r
.48723 .60506 m .48694 .60517 L .48723 .60386 L F
.48957 .60414 m .48847 .6041 L .48957 .60397 L F
.522 .918 .843 r
.48895 .6044 m .48893 .6044 L .48921 .60429 L F
.48724 .60514 m .49004 .60393 L .48919 .60431 L F
.608 .318 .451 r
.48948 .6064 m .48865 .60452 L .48957 .60414 L F
.48865 .60452 m .48847 .6041 L .48957 .60414 L F
.522 .918 .843 r
.48921 .60429 m .48721 .60432 L .49004 .60393 L F
.608 .318 .451 r
.48862 .60444 m .48723 .60386 L .48847 .6041 L F
.522 .918 .843 r
.48893 .6044 m .48721 .60432 L .48921 .60429 L F
.48724 .60514 m .48723 .60506 L .48895 .6044 L F
.48723 .60506 m .48721 .60432 L .48895 .6044 L F
.618 .958 .883 r
.49012 .60392 m .48721 .60432 L .49023 .60268 L F
.015 0 0 r
.49023 .60268 m .48721 .60432 L .49018 .60287 L F
.49023 .60268 m .49018 .60287 L .49061 .60266 L F
.735 .703 .166 r
.49047 .60178 m .49023 .60268 L .49078 .59985 L F
.4902 .60341 m .49023 .60268 L .49047 .60178 L F
.49014 .60366 m .49023 .60268 L .4902 .60341 L F
.473 .222 .453 r
.49198 .60577 m .48948 .6064 L .48957 .60414 L F
.49198 .60577 m .48957 .60414 L .48972 .60408 L F
.608 .318 .451 r
.48693 .60519 m .48686 .60516 L .48761 .60214 L F
.522 .918 .843 r
.48724 .60514 m .48693 .60519 L .48723 .60506 L F
.608 .318 .451 r
.48948 .6064 m .48684 .60523 L .48862 .60444 L F
.522 .918 .843 r
.48723 .60506 m .48691 .6052 L .48723 .60502 L F
.48693 .60519 m .48691 .6052 L .48723 .60506 L F
.536 .278 .471 r
.4856 .60433 m .48457 .60751 L .4817 .6079 L F
.308 .061 .368 r
.48647 .60674 m .48457 .60751 L .48496 .60629 L F
.48608 .60565 m .48496 .60629 L .4856 .60433 L F
.48647 .60674 m .48496 .60629 L .48608 .60565 L F
.311 .222 .59 r
.4827 .60391 m .485 .60552 L .48607 .60494 L F
.48667 .60513 m .485 .60552 L .48691 .6052 L F
.4827 .60391 m .48691 .6052 L .48666 .60499 L F
.784 .547 .577 r
.4827 .60391 m .48666 .60499 L .48688 .60106 L F
.308 .061 .368 r
.48666 .60499 m .48638 .60475 L .48713 .60391 L F
.784 .547 .577 r
.48666 .60499 m .48713 .60391 L .48688 .60106 L F
.522 .918 .843 r
.48723 .60499 m .485 .60552 L .48721 .60432 L F
.48723 .60502 m .48715 .60504 L .48723 .60499 L F
.48715 .60504 m .485 .60552 L .48723 .60499 L F
.48691 .6052 m .485 .60552 L .48723 .60502 L F
.605 .413 .596 r
.48688 .60106 m .48713 .60391 L .48844 .60244 L F
.592 .788 .974 r
.81574 .42964 m .81408 .43178 L .81312 .43026 L F
.81574 .42964 m .8167 .43105 L .81408 .43178 L F
.658 .81 .956 r
.8213 .40921 m .82506 .40971 L .82418 .40732 L F
.643 .715 .9 r
.82506 .40971 m .82659 .40617 L .82418 .40732 L F
.82506 .40971 m .8278 .40866 L .82659 .40617 L F
.644 .789 .952 r
.8303 .40773 m .83144 .40967 L .83379 .40872 L F
.56 .533 .782 r
.31962 .57652 m .3171 .57725 L .31724 .57629 L F
.588 .445 .654 r
.31962 .57652 m .31724 .57981 L .3171 .57725 L F
.554 .926 .785 r
.19021 .78078 m .18856 .78202 L .18585 .78317 L F
.861 .988 .718 r
.7675 .39241 m .76521 .39565 L .76605 .3931 L F
.923 .684 .558 r
.76853 .3935 m .7675 .39241 L .76605 .3931 L F
.76853 .3935 m .77019 .39141 L .7675 .39241 L F
.803 .599 .626 r
.76731 .4117 m .76577 .4135 L .76908 .41383 L F
.446 .187 .427 r
.29756 .61714 m .29706 .61964 L .29479 .62015 L F
.461 .198 .428 r
.29986 .61667 m .29706 .61964 L .29756 .61714 L F
.732 .328 .284 r
.55749 .52042 m .55406 .52157 L .55363 .51983 L F
.55749 .52042 m .55778 .5221 L .55406 .52157 L F
.895 .591 .464 r
.75958 .39332 m .76354 .3961 L .7619 .39258 L F
.76354 .3961 m .76384 .39631 L .76366 .39596 L F
.76354 .3961 m .76366 .39596 L .7619 .39258 L F
.92 .952 .796 r
.76521 .39565 m .76223 .39776 L .76459 .39486 L F
0 0 0 r
.76378 .39592 m .76459 .39486 L .76271 .39717 L F
.76249 .39747 m .76271 .39717 L .76223 .39776 L F
.76378 .39592 m .76271 .39717 L .76249 .39747 L F
.92 .952 .796 r
.76521 .39565 m .76299 .3989 L .76223 .39776 L F
.846 .988 .857 r
.76605 .3931 m .76521 .39565 L .76459 .39486 L F
.185 .713 .852 r
.23326 .62672 m .23309 .62719 L .23095 .62702 L F
.23326 .62672 m .23548 .62696 L .23309 .62719 L F
.289 .151 .513 r
.27049 .59587 m .27237 .59509 L .2724 .59227 L F
.165 0 .368 r
.27009 .59853 m .27237 .59509 L .27049 .59587 L F
.887 .877 .82 r
.18986 .78375 m .19174 .7845 L .19406 .78122 L F
0 0 .099 r
.26647 .60506 m .2677 .60388 L .26816 .60155 L F
0 0 .168 r
.26647 .60506 m .26719 .60624 L .2677 .60388 L F
.26647 .60506 m .266 .6075 L .26719 .60624 L F
.622 .141 .09 r
.20681 .53818 m .20872 .53977 L .21063 .53846 L F
.436 0 0 r
.21063 .53846 m .20872 .53977 L .21253 .53932 L F
.435 0 0 r
.21063 .53846 m .21253 .53932 L .21232 .53901 L F
.527 .425 .682 r
.32153 .55597 m .3219 .55848 L .31964 .55902 L F
.582 .462 .681 r
.3219 .55848 m .32035 .56323 L .31964 .55902 L F
.581 .382 .576 r
.47105 .64156 m .47105 .64434 L .46826 .64446 L F
.691 .471 .584 r
.47371 .6441 m .47105 .64434 L .47105 .64156 L F
.578 .154 .201 r
.50325 .54887 m .50701 .54727 L .50304 .54756 L F
.50325 .54887 m .50574 .54934 L .50701 .54727 L F
.214 0 0 r
.50574 .54934 m .50992 .54752 L .50701 .54727 L F
.479 .557 .857 r
.82443 .42973 m .82431 .43453 L .82243 .43092 L F
.82443 .42973 m .82666 .43428 L .82431 .43453 L F
.259 .613 .956 r
.2036 .61824 m .2035 .61957 L .20169 .61798 L F
.056 .4 .856 r
.20502 .6201 m .2035 .61957 L .2036 .61824 L F
.129 .67 .837 r
.22588 .55088 m .22592 .55047 L .2237 .55141 L F
.22588 .55088 m .22761 .5508 L .22592 .55047 L F
.517 .586 .863 r
.78204 .42932 m .77798 .42594 L .78067 .42495 L F
.566 .531 .775 r
.78433 .4281 m .78204 .42932 L .78067 .42495 L F
.73 .7 .822 r
.78433 .4281 m .7839 .43061 L .78204 .42932 L F
.501 .255 .473 r
.1651 .5799 m .16227 .58286 L .16342 .5813 L F
.814 .745 .787 r
.25111 .6658 m .24659 .6671 L .24967 .66533 L F
.884 .961 .843 r
.25111 .6658 m .2516 .66196 L .25359 .66573 L F
.25111 .6658 m .24967 .66533 L .2516 .66196 L F
.126 .015 .446 r
.25238 .66764 m .25111 .6658 L .25359 .66573 L F
.25238 .66764 m .25108 .6685 L .25111 .6658 L F
.746 .771 .873 r
.79545 .43233 m .79207 .43191 L .79427 .43085 L F
.712 .771 .899 r
.79427 .43085 m .79795 .43144 L .79545 .43233 L F
.366 .835 .871 r
.26208 .55627 m .25964 .55627 L .25824 .55698 L F
.309 .801 .853 r
.26303 .55561 m .26208 .55627 L .26359 .55474 L F
.26303 .55561 m .25964 .55627 L .26208 .55627 L F
.538 .816 .997 r
.3011 .54189 m .30049 .54361 L .29867 .54173 L F
.3011 .54189 m .30263 .54299 L .30049 .54361 L F
.531 .49 .755 r
.48688 .60106 m .48838 .60079 L .48592 .59939 L F
.526 .703 .951 r
.48838 .60079 m .48688 .60106 L .48592 .59939 L F
0 0 0 r
.4607 .56814 m .45923 .56984 L .4619 .56687 L F
.228 0 0 r
.80646 .39714 m .8089 .39762 L .81009 .39769 L F
.045 0 0 r
.8089 .39762 m .81253 .39785 L .81009 .39769 L F
.68 .546 .695 r
.49297 .61407 m .49053 .61715 L .49057 .61481 L F
.661 .694 .869 r
.81933 .43014 m .82243 .43092 L .82052 .43136 L F
.958 .617 .27 r
.50906 .58629 m .50947 .58875 L .51079 .58952 L F
.87 .451 .219 r
.51019 .59142 m .51079 .58952 L .50947 .58875 L F
.51019 .59142 m .51201 .59208 L .51079 .58952 L F
.644 .118 0 r
.51696 .56575 m .51775 .56718 L .51549 .56476 L F
.51696 .56575 m .51915 .56816 L .51775 .56718 L F
.604 .518 .731 r
.44109 .63511 m .44249 .63197 L .43963 .63195 L F
.44109 .63511 m .44342 .63508 L .44249 .63197 L F
.518 .234 .424 r
.47649 .62872 m .47938 .62591 L .47682 .6261 L F
.54 .664 .917 r
.26583 .55873 m .26619 .55531 L .26359 .55474 L F
.26583 .55873 m .26806 .55827 L .26619 .55531 L F
.465 .663 .948 r
.78139 .43166 m .77925 .43185 L .78085 .42999 L F
.874 .696 .657 r
.56364 .5496 m .56069 .54984 L .56233 .54674 L F
.991 .79 .407 r
.56148 .55533 m .56128 .5508 L .56183 .55322 L F
.761 .47 .491 r
.56086 .55041 m .55675 .55412 L .55929 .54891 L F
.56128 .5508 m .56008 .55168 L .56086 .55041 L F
.56008 .55168 m .55675 .55412 L .56086 .55041 L F
.56008 .55168 m .56011 .55459 L .55675 .55412 L F
.56128 .5508 m .56115 .55121 L .56008 .55168 L F
.56115 .55121 m .56011 .55459 L .56008 .55168 L F
.874 .782 .756 r
.56364 .5496 m .56332 .55025 L .56088 .55039 L F
.995 .787 .512 r
.56115 .55121 m .56127 .55156 L .56128 .5508 L F
.56127 .55156 m .56183 .55322 L .56128 .5508 L F
.991 .79 .407 r
.56148 .55533 m .56125 .55516 L .56127 .55156 L F
.56132 .55185 m .56127 .55156 L .56128 .5508 L F
.56148 .55533 m .56127 .55156 L .56132 .55185 L F
.874 .782 .756 r
.56332 .55025 m .56183 .55322 L .56127 .55156 L F
.5612 .55118 m .56127 .55156 L .56115 .55121 L F
.991 .79 .407 r
.56125 .55516 m .56056 .55465 L .5612 .55118 L F
.56127 .55156 m .5612 .55118 L .56128 .5508 L F
.56125 .55516 m .5612 .55118 L .56127 .55156 L F
.995 .787 .512 r
.56069 .54984 m .56115 .55121 L .56128 .5508 L F
.874 .782 .756 r
.56106 .55038 m .56115 .55121 L .56088 .55039 L F
.56332 .55025 m .5612 .55118 L .56106 .55038 L F
.5612 .55118 m .56115 .55121 L .56106 .55038 L F
.56332 .55025 m .56127 .55156 L .5612 .55118 L F
.761 .47 .491 r
.56128 .5508 m .56056 .55465 L .56011 .55459 L F
.874 .782 .756 r
.56124 .5498 m .56088 .55039 L .56069 .54984 L F
.56364 .5496 m .56088 .55039 L .56124 .5498 L F
.526 .273 .474 r
.45316 .61954 m .45554 .6194 L .45589 .61724 L F
0 0 0 r
.45812 .61404 m .45589 .61724 L .45775 .61478 L F
.249 .037 .383 r
.45589 .61724 m .45554 .6194 L .45786 .61695 L F
.298 .021 .313 r
.15908 .56265 m .15835 .56481 L .161 .56191 L F
.61 .505 .709 r
.49387 .59209 m .49766 .5952 L .49798 .59353 L F
.603 .613 .834 r
.4967 .58974 m .49798 .59353 L .49989 .59099 L F
.92 .653 .518 r
.42962 .66485 m .43175 .66533 L .42987 .66248 L F
.716 .639 .77 r
.43175 .66533 m .43399 .66273 L .42987 .66248 L F
.664 .289 .326 r
.43175 .66533 m .43018 .66752 L .43446 .66748 L F
.798 .697 .753 r
.45341 .638 m .45177 .64137 L .45475 .64153 L F
.601 .594 .816 r
.45341 .638 m .45475 .64153 L .45723 .64104 L F
.454 .366 .666 r
.45475 .64153 m .45725 .6437 L .45723 .64104 L F
.45475 .64153 m .4553 .64455 L .45725 .6437 L F
.083 .641 .702 r
.51031 .61955 m .509 .61971 L .50673 .61998 L F
0 .544 .744 r
.51276 .62016 m .509 .61971 L .51031 .61955 L F
.468 .802 .999 r
.46529 .67501 m .46376 .67407 L .46136 .67448 L F
.641 .211 .209 r
.53909 .51942 m .53779 .52117 L .53469 .51956 L F
.53779 .52117 m .53715 .52105 L .53469 .51956 L F
.53779 .52117 m .53766 .52135 L .53715 .52105 L F
.303 .406 .802 r
.53469 .51956 m .53766 .52135 L .53643 .51797 L F
.583 .583 .819 r
.53643 .51797 m .53542 .52073 L .53418 .51918 L F
.53542 .52073 m .53509 .52163 L .5347 .5206 L F
.53542 .52073 m .5347 .5206 L .53418 .51918 L F
.354 0 0 r
.54147 .5198 m .53766 .52135 L .53909 .51942 L F
.273 .77 .891 r
.23748 .53612 m .23991 .53578 L .24165 .53607 L F
.336 0 0 r
.23991 .53578 m .24382 .53589 L .24165 .53607 L F
.887 .877 .82 r
.18986 .78375 m .19406 .78122 L .19021 .78078 L F
.411 .679 .971 r
.31862 .54961 m .3178 .55128 L .31622 .55019 L F
.31862 .54961 m .32043 .55158 L .3178 .55128 L F
.459 .279 .548 r
.15943 .58612 m .15748 .58922 L .15817 .58688 L F
.208 0 0 r
.47105 .64434 m .46716 .64648 L .46826 .64446 L F
.626 .605 .81 r
.8177 .40671 m .81876 .41026 L .8213 .40921 L F
.814 .941 .91 r
.82053 .44702 m .8226 .44353 L .81987 .44621 L F
.82053 .44702 m .82345 .4446 L .8226 .44353 L F
.869 .765 .745 r
.42007 .66186 m .42295 .66273 L .4241 .65938 L F
.642 .509 .685 r
.4241 .65938 m .42295 .66273 L .42762 .66226 L F
.61 .375 .536 r
.42342 .66509 m .42762 .66226 L .42295 .66273 L F
.31 .154 .502 r
.13825 .58374 m .14003 .58296 L .14017 .58036 L F
0 0 .236 r
.13951 .58542 m .13825 .58374 L .13797 .58627 L F
.13951 .58542 m .14003 .58296 L .13825 .58374 L F
.833 .617 .61 r
.56097 .52536 m .55778 .5221 L .56089 .52296 L F
.363 .422 .788 r
.49516 .59639 m .49771 .59794 L .49569 .59873 L F
.113 0 .179 r
.49771 .59794 m .49523 .60092 L .49569 .59873 L F
.986 .753 .5 r
.77026 .39414 m .77144 .39781 L .77167 .39542 L F
.862 .8 .788 r
.57372 .5251 m .57765 .52303 L .57407 .52243 L F
.57372 .5251 m .57553 .52592 L .57765 .52303 L F
.653 .84 .972 r
.82782 .39736 m .82626 .39966 L .82521 .39824 L F
.82782 .39736 m .82873 .39861 L .82626 .39966 L F
.574 .815 .99 r
.81503 .40739 m .81668 .40544 L .81407 .40593 L F
.106 0 0 r
.81638 .40556 m .81407 .40593 L .81668 .40544 L F
.422 .716 .985 r
.81191 .40628 m .81503 .40739 L .81407 .40593 L F
.106 0 0 r
.81291 .40691 m .81407 .40593 L .81638 .40556 L F
.422 .716 .985 r
.81152 .40614 m .81191 .40628 L .81407 .40593 L F
.574 .815 .99 r
.81503 .40739 m .8177 .40671 L .81668 .40544 L F
.687 .316 .34 r
.56158 .50829 m .56122 .50989 L .5652 .50984 L F
.55 .401 .632 r
.31809 .56826 m .31825 .57085 L .31607 .57122 L F
.512 .441 .713 r
.31888 .57527 m .31607 .57122 L .31825 .57085 L F
.31888 .57527 m .31724 .57629 L .31607 .57122 L F
.746 .486 .537 r
.45984 .65303 m .45618 .65065 L .45987 .65057 L F
.778 .68 .755 r
.46335 .65116 m .45984 .65303 L .45987 .65057 L F
.511 .155 .301 r
.48674 .58659 m .48548 .5882 L .4839 .58676 L F
.397 .171 .45 r
.4839 .58676 m .48548 .5882 L .48471 .58581 L F
.307 .175 .531 r
.48548 .5882 m .48397 .58931 L .4839 .58676 L F
.48548 .5882 m .48397 .58931 L .4839 .58676 L F
.505 .52 .806 r
.32283 .55002 m .32149 .55357 L .32043 .55158 L F
.32283 .55002 m .3235 .5529 L .32149 .55357 L F
.482 .34 .612 r
.3235 .5529 m .32153 .55597 L .32149 .55357 L F
.152 0 0 r
.54592 .51019 m .5481 .50975 L .54902 .50822 L F
.453 .005 .095 r
.54902 .50822 m .5481 .50975 L .55126 .50923 L F
.428 .081 .273 r
.54902 .50822 m .55126 .50923 L .55126 .50769 L F
0 0 .081 r
.83849 .42306 m .83983 .42363 L .83854 .42111 L F
.83849 .42306 m .83783 .42517 L .83955 .42384 L F
.83961 .42353 m .83955 .42384 L .83983 .42363 L F
.83849 .42306 m .83955 .42384 L .83961 .42353 L F
.83783 .42517 m .83825 .42498 L .83979 .42366 L F
.83979 .42366 m .83979 .42366 L .83983 .42363 L F
.83783 .42517 m .83979 .42366 L .83979 .42366 L F
.03 .215 .72 r
.83978 .42544 m .83776 .42539 L .83973 .42693 L F
.83983 .42363 m .83893 .4244 L .83978 .42544 L F
.83893 .4244 m .83776 .42539 L .83978 .42544 L F
0 0 0 r
.83973 .42693 m .84287 .42394 L .84251 .42488 L F
.84131 .42595 m .84251 .42488 L .84235 .4253 L F
.83973 .42693 m .84251 .42488 L .84131 .42595 L F
.438 .721 .985 r
.83986 .42725 m .83701 .4285 L .83968 .42596 L F
.84014 .42931 m .83813 .42879 L .83986 .42725 L F
.83813 .42879 m .83701 .4285 L .83986 .42725 L F
.03 .215 .72 r
.83983 .42363 m .83973 .42693 L .83968 .42596 L F
0 0 0 r
.83973 .42693 m .84235 .4253 L .83968 .42596 L F
.019 .102 .609 r
.84065 .42822 m .83968 .42596 L .84011 .42585 L F
.84123 .42723 m .84011 .42585 L .84235 .4253 L F
.84065 .42822 m .84011 .42585 L .84123 .42723 L F
0 0 .403 r
.83854 .42111 m .83868 .42458 L .83767 .42055 L F
.83854 .42111 m .83983 .42363 L .83868 .42458 L F
.86 .637 .599 r
.83767 .42055 m .83868 .42458 L .83484 .42241 L F
.745 .417 .428 r
.83898 .42447 m .83484 .42241 L .83839 .42442 L F
.83898 .42447 m .83839 .42442 L .83868 .42458 L F
.928 .886 .472 r
.83983 .42363 m .83968 .42453 L .83868 .42458 L F
.745 .417 .428 r
.83916 .42456 m .83898 .42447 L .83868 .42458 L F
.83945 .42443 m .83484 .42241 L .83916 .42456 L F
0 0 .081 r
.83783 .42517 m .83776 .42539 L .83825 .42498 L F
.756 .695 .794 r
.83943 .42451 m .83631 .42729 L .83507 .42413 L F
.83968 .42453 m .83928 .42486 L .83943 .42451 L F
.83928 .42486 m .83631 .42729 L .83943 .42451 L F
.745 .417 .428 r
.83945 .42443 m .83507 .42413 L .83484 .42241 L F
.83968 .42453 m .83945 .42443 L .83916 .42456 L F
.83968 .42453 m .83943 .42451 L .83945 .42443 L F
.83943 .42451 m .83507 .42413 L .83945 .42443 L F
.579 .4 .603 r
.44025 .57927 m .44306 .57706 L .44103 .57756 L F
.102 0 .158 r
.16227 .58286 m .15943 .58612 L .16057 .58391 L F
.409 .178 .45 r
.4696 .60886 m .4716 .6101 L .47188 .60764 L F
.4696 .60886 m .46957 .61112 L .4716 .6101 L F
.337 0 .12 r
.44306 .57706 m .44536 .57672 L .4464 .57465 L F
.669 .27 .28 r
.4464 .57465 m .44536 .57672 L .44863 .57671 L F
.639 .286 .356 r
.4464 .57465 m .44863 .57671 L .44931 .57499 L F
.725 .215 0 r
.52058 .56891 m .51956 .5684 L .51915 .56816 L F
.52058 .56891 m .52128 .56975 L .51956 .5684 L F
.993 .776 .405 r
.18472 .79607 m .18533 .79943 L .18434 .79626 L F
.18472 .79607 m .18454 .79874 L .18533 .79943 L F
.945 .948 .747 r
.18533 .79943 m .18454 .79874 L .18379 .80004 L F
0 0 .295 r
.45006 .66548 m .44919 .66151 L .45186 .6625 L F
.474 .285 .544 r
.45223 .66716 m .45 .66807 L .45006 .66548 L F
.45223 .66716 m .45006 .66548 L .45214 .66716 L F
.421 .867 .845 r
.45223 .66716 m .45072 .66741 L .45 .66807 L F
.474 .285 .544 r
.45223 .66716 m .45214 .66716 L .45219 .66719 L F
.451 .218 .469 r
.45186 .6625 m .45219 .66715 L .45006 .66548 L F
.547 .143 .227 r
.45186 .66714 m .45072 .66741 L .45223 .66716 L F
.451 .218 .469 r
.45219 .66715 m .45219 .66719 L .45214 .66716 L F
.45219 .66715 m .45214 .66716 L .45006 .66548 L F
0 0 0 r
.45223 .66716 m .45507 .66579 L .45453 .66651 L F
.547 .143 .227 r
.45453 .66651 m .45414 .6666 L .45223 .66716 L F
0 0 0 r
.45223 .66716 m .45219 .66719 L .45507 .66579 L F
.593 .322 .476 r
.45507 .66579 m .4524 .66709 L .45186 .6625 L F
.547 .143 .227 r
.45414 .6666 m .45214 .66716 L .45223 .66716 L F
.593 .322 .476 r
.4524 .66709 m .45219 .66719 L .45219 .66715 L F
.4524 .66709 m .45219 .66715 L .45186 .6625 L F
.547 .143 .227 r
.45414 .6666 m .45186 .66714 L .45214 .66716 L F
.45219 .66715 m .45214 .66716 L .45214 .66716 L F
.45414 .6666 m .45214 .66716 L .45219 .66715 L F
.593 .322 .476 r
.45507 .66579 m .45186 .6625 L .45553 .66185 L F
.604 .362 .523 r
.47785 .6047 m .48063 .60468 L .48037 .6021 L F
.488 .278 .521 r
.48037 .6021 m .48063 .60468 L .4827 .60391 L F
.419 .134 .373 r
.29475 .62247 m .29179 .62543 L .29243 .623 L F
.354 .01 .236 r
.74751 .39065 m .74536 .39062 L .74402 .39119 L F
.74751 .39065 m .74808 .38927 L .74536 .39062 L F
0 0 .333 r
.51069 .61046 m .5112 .61058 L .51135 .60753 L F
0 0 .184 r
.51069 .61046 m .51052 .61283 L .5112 .61058 L F
.489 .209 .415 r
.3068 .60991 m .30493 .60802 L .30736 .60751 L F
.3068 .60991 m .30442 .61049 L .30493 .60802 L F
.162 0 0 r
.2543 .53662 m .25621 .53703 L .25797 .53736 L F
.138 .672 .856 r
.25797 .53736 m .25621 .53703 L .2602 .53733 L F
.651 .446 .592 r
.7392 .39208 m .74025 .38946 L .7375 .38882 L F
.7392 .39208 m .74148 .39175 L .74025 .38946 L F
.601 .474 .679 r
.49951 .62673 m .4994 .62922 L .50065 .62735 L F
.50065 .62735 m .4994 .62922 L .49951 .62673 L F
.683 .687 .848 r
.20681 .64122 m .20964 .64373 L .20889 .64051 L F
0 .158 .69 r
.20889 .64051 m .20964 .64373 L .21175 .6452 L F
.227 0 .252 r
.44533 .62834 m .44724 .62661 L .44488 .62625 L F
.62 .449 .629 r
.45435 .61104 m .45687 .61139 L .45748 .61038 L F
.658 .569 .743 r
.25703 .64811 m .25692 .6505 L .25426 .65054 L F
.012 0 0 r
.25426 .65054 m .25524 .65056 L .25259 .65036 L F
.25471 .65053 m .25692 .6505 L .25524 .65056 L F
.037 .036 .525 r
.25775 .64959 m .25692 .6505 L .25703 .64811 L F
.617 .951 .925 r
.25524 .65056 m .25692 .6505 L .25775 .64959 L F
.25524 .65056 m .25775 .64959 L .25682 .65147 L F
0 .219 .712 r
.25577 .65059 m .25524 .65056 L .25682 .65147 L F
.25336 .64856 m .25524 .65056 L .25577 .65059 L F
.012 0 0 r
.25426 .65054 m .25471 .65053 L .25524 .65056 L F
.481 .335 .605 r
.48471 .58581 m .48841 .58523 L .48857 .58322 L F
0 0 0 r
.48841 .58523 m .48548 .5882 L .48674 .58659 L F
.438 .193 .444 r
.48471 .58581 m .48548 .5882 L .48841 .58523 L F
.812 .845 .874 r
.56239 .60356 m .5638 .60496 L .56647 .60239 L F
.15 0 0 r
.15322 .56749 m .15478 .56752 L .15647 .56569 L F
.199 0 .013 r
.15478 .56752 m .15835 .56481 L .15647 .56569 L F
.338 .404 .782 r
.7753 .43155 m .77635 .43522 L .77823 .43317 L F
.339 .404 .783 r
.77635 .43522 m .77945 .43716 L .77823 .43317 L F
.246 .718 .942 r
.2046 .64126 m .20534 .64057 L .20276 .64058 L F
.2046 .64126 m .20681 .64122 L .20534 .64057 L F
0 0 0 r
.45808 .5764 m .45636 .58019 L .45721 .57813 L F
.465 .132 .316 r
.4817 .6079 m .47876 .61015 L .47877 .60749 L F
.464 .412 .715 r
.31803 .58602 m .31645 .58935 L .31576 .58658 L F
.31803 .58602 m .3189 .58888 L .31645 .58935 L F
.64 .271 .328 r
.31946 .59149 m .31645 .58935 L .3189 .58888 L F
.31946 .59149 m .31549 .59164 L .31645 .58935 L F
.716 .73 .861 r
.66723 .42817 m .67095 .4288 L .66943 .42727 L F
.727 .732 .854 r
.66943 .42727 m .67095 .4288 L .67324 .42808 L F
.74 .925 .574 r
.2565 .55539 m .25674 .55467 L .25805 .55333 L F
.347 .453 .827 r
.25653 .5499 m .25805 .55333 L .25938 .55137 L F
.078 0 .177 r
.25674 .55467 m .25938 .55137 L .25805 .55333 L F
0 0 .18 r
.21054 .7203 m .20911 .72203 L .2098 .72292 L F
.21054 .7203 m .2098 .72292 L .21013 .72232 L F
.21054 .7203 m .20997 .72313 L .21146 .72273 L F
.21054 .7203 m .21146 .72273 L .20976 .72199 L F
.874 .896 .845 r
.21054 .72155 m .21146 .72273 L .21373 .71973 L F
.20976 .72199 m .2102 .72218 L .21054 .72155 L F
.2102 .72218 m .21146 .72273 L .21054 .72155 L F
0 0 .18 r
.21013 .72232 m .2098 .72292 L .20997 .72313 L F
.248 0 .199 r
.48942 .62553 m .48818 .62825 L .48588 .6282 L F
.522 .242 .431 r
.28417 .62936 m .28374 .63152 L .28151 .63163 L F
.501 .224 .425 r
.28417 .62936 m .2861 .63118 L .28374 .63152 L F
.51 .223 .414 r
.28663 .62902 m .2861 .63118 L .28417 .62936 L F
0 0 .31 r
.51389 .54816 m .51332 .54719 L .51187 .54616 L F
.829 .48 .395 r
.51332 .54719 m .51418 .54954 L .51545 .54925 L F
0 0 .31 r
.51389 .54816 m .51418 .54954 L .51332 .54719 L F
0 .091 .635 r
.27628 .56279 m .27774 .56412 L .27568 .56211 L F
.578 .663 .895 r
.19461 .64059 m .19506 .63705 L .19264 .63775 L F
.19461 .64059 m .19802 .64097 L .19506 .63705 L F
.539 .667 .92 r
.19461 .64059 m .19841 .64188 L .19802 .64097 L F
.859 .685 .154 r
.49431 .57433 m .49419 .57306 L .4938 .57295 L F
.49419 .57306 m .49391 .57021 L .4938 .57295 L F
.49431 .57433 m .49392 .5735 L .49391 .57021 L F
.336 0 0 r
.49392 .5735 m .49729 .5743 L .49769 .57411 L F
.49614 .57365 m .49769 .57411 L .49835 .5738 L F
.49392 .5735 m .49769 .57411 L .49614 .57365 L F
.859 .685 .154 r
.4938 .57295 m .49391 .57021 L .49308 .57103 L F
0 0 .445 r
.49431 .57433 m .49512 .57496 L .49392 .5735 L F
.842 .393 .147 r
.49523 .57525 m .49554 .57675 L .49431 .57433 L F
.49743 .57743 m .49554 .57675 L .49523 .57525 L F
.709 .453 0 r
.49554 .57675 m .49602 .57896 L .49579 .57797 L F
0 0 .445 r
.49431 .57433 m .49554 .57675 L .49512 .57496 L F
.709 .453 0 r
.49554 .57675 m .49579 .57797 L .49512 .57496 L F
.838 .608 .59 r
.57061 .54992 m .57053 .55252 L .57391 .55314 L F
.843 .618 .598 r
.57051 .55511 m .57391 .55314 L .57053 .55252 L F
.57051 .55511 m .57362 .55582 L .57391 .55314 L F
.826 .76 .79 r
.44237 .64762 m .44556 .64902 L .44465 .64655 L F
.44237 .64762 m .44363 .65032 L .44556 .64902 L F
.34 .412 .79 r
.44556 .64902 m .44707 .64591 L .44465 .64655 L F
.742 .569 .659 r
.42762 .66226 m .42987 .66248 L .43007 .65918 L F
.543 .397 .634 r
.43007 .65918 m .42987 .66248 L .43254 .65877 L F
.527 .349 .583 r
.45867 .60677 m .46148 .60758 L .46176 .6073 L F
.087 0 .412 r
.46198 .6071 m .45975 .61024 L .4626 .60761 L F
.46196 .60709 m .46192 .60716 L .46198 .6071 L F
.46192 .60716 m .45975 .61024 L .46198 .6071 L F
.46186 .60719 m .45975 .61024 L .46196 .60709 L F
.4607 .60857 m .45975 .61024 L .46184 .60722 L F
.46184 .6072 m .46184 .60722 L .46195 .60707 L F
.4607 .60857 m .46184 .60722 L .46184 .6072 L F
.527 .349 .583 r
.46176 .6073 m .46184 .6072 L .4612 .60454 L F
.826 .528 0 r
.4612 .60454 m .46184 .6072 L .46169 .60686 L F
.527 .349 .583 r
.45867 .60677 m .46176 .6073 L .4612 .60454 L F
.087 0 .412 r
.46169 .60686 m .46099 .60807 L .46195 .60707 L F
.46099 .60807 m .4607 .60857 L .46173 .60733 L F
.46099 .60807 m .46173 .60733 L .46195 .60707 L F
.453 .234 .491 r
.45687 .61139 m .46124 .60782 L .45748 .61038 L F
.46124 .60782 m .46186 .60731 L .46148 .60758 L F
.46124 .60782 m .46148 .60758 L .45748 .61038 L F
.826 .528 0 r
.46184 .6072 m .46186 .60731 L .46169 .60686 L F
.268 .027 .351 r
.46186 .60731 m .46102 .60863 L .46151 .60947 L F
.087 0 .412 r
.46122 .60897 m .46151 .60947 L .46107 .60966 L F
.46103 .6089 m .46107 .60966 L .46074 .6098 L F
.46097 .6081 m .46074 .6098 L .45975 .61024 L F
0 0 0 r
.46151 .60947 m .45975 .61061 L .45975 .61024 L F
.268 .027 .351 r
.46102 .60863 m .45975 .61061 L .46151 .60947 L F
.087 0 .412 r
.46169 .60686 m .46151 .60947 L .46122 .60897 L F
.46169 .60686 m .46107 .60966 L .46103 .6089 L F
.453 .234 .491 r
.46124 .60782 m .461 .60827 L .46186 .60731 L F
.461 .60827 m .45975 .61061 L .46102 .60863 L F
.461 .60827 m .46102 .60863 L .46186 .60731 L F
.45687 .61139 m .4579 .61111 L .46124 .60782 L F
.4579 .61111 m .45975 .61061 L .46124 .60782 L F
.087 0 .412 r
.46169 .60686 m .46074 .6098 L .46097 .6081 L F
.527 .349 .583 r
.45867 .60677 m .45748 .61038 L .461 .60792 L F
.46106 .60746 m .461 .60792 L .46148 .60758 L F
.45867 .60677 m .461 .60792 L .46106 .60746 L F
.46176 .6073 m .46148 .60758 L .46186 .60731 L F
.087 0 .412 r
.46195 .60707 m .46186 .60719 L .46196 .60709 L F
.527 .349 .583 r
.46176 .6073 m .46186 .60731 L .46184 .6072 L F
.948 .819 .684 r
.84592 .40686 m .84642 .40451 L .84505 .40329 L F
.09 .012 .465 r
.45012 .6587 m .44835 .66022 L .44919 .66151 L F
.273 0 .145 r
.45097 .62234 m .45554 .6194 L .45316 .61954 L F
.182 .686 .908 r
.17125 .57419 m .17376 .57438 L .16965 .57377 L F
.916 .692 .584 r
.51402 .61586 m .51656 .61433 L .51627 .61271 L F
.51402 .61586 m .51635 .61676 L .51656 .61433 L F
.712 .214 .057 r
.45775 .61478 m .46041 .61615 L .45812 .61404 L F
.154 .316 .776 r
.42694 .67159 m .42937 .67402 L .42764 .67036 L F
.086 0 .43 r
.46564 .64734 m .46504 .64981 L .46335 .65116 L F
.595 .534 .756 r
.46636 .65299 m .46335 .65116 L .46348 .65105 L F
.46636 .65299 m .46348 .65105 L .46591 .65189 L F
.668 .496 .642 r
.46822 .65711 m .46354 .65875 L .46355 .65639 L F
.715 .543 .655 r
.46904 .65671 m .46976 .65867 L .46919 .65869 L F
.46876 .65737 m .46919 .65869 L .46819 .65871 L F
.46904 .65671 m .46919 .65869 L .46876 .65737 L F
.46927 .65616 m .46819 .65871 L .46822 .65704 L F
.46927 .65616 m .46935 .65656 L .46904 .65671 L F
.46927 .65616 m .46822 .65704 L .46923 .65727 L F
.991 .733 .402 r
.46843 .65259 m .46923 .65727 L .46824 .65579 L F
.46727 .65281 m .46824 .65579 L .46636 .65299 L F
.46843 .65259 m .46824 .65579 L .46727 .65281 L F
.715 .543 .655 r
.46822 .65704 m .46819 .65871 L .4662 .65875 L F
.668 .496 .642 r
.46923 .65727 m .46802 .65721 L .46822 .65711 L F
.59 .44 .646 r
.46822 .65704 m .46923 .65727 L .46822 .65711 L F
.715 .543 .655 r
.46822 .65704 m .46802 .65721 L .46923 .65727 L F
.46802 .65721 m .4662 .65875 L .46923 .65727 L F
.668 .496 .642 r
.46923 .65727 m .46638 .65801 L .46802 .65721 L F
.46638 .65801 m .46354 .65875 L .46822 .65711 L F
.715 .543 .655 r
.46935 .65656 m .46976 .65867 L .46904 .65671 L F
.59 .44 .646 r
.46383 .65605 m .46822 .65704 L .46355 .65639 L F
.46822 .65704 m .46822 .65711 L .46355 .65639 L F
.46636 .65299 m .46923 .65727 L .46383 .65605 L F
.595 .534 .756 r
.46591 .65189 m .46348 .65105 L .46504 .64981 L F
.939 .807 .688 r
.46504 .64981 m .46425 .65268 L .46636 .65299 L F
.593 .13 .124 r
.46425 .65268 m .46843 .65259 L .46636 .65299 L F
.46425 .65268 m .46695 .65427 L .46831 .65272 L F
.46795 .6526 m .46831 .65272 L .46843 .65259 L F
.46425 .65268 m .46831 .65272 L .46795 .6526 L F
.762 .789 .875 r
.84265 .40616 m .84382 .40791 L .84592 .40686 L F
.611 .811 .977 r
.51277 .52177 m .51656 .52226 L .51429 .52318 L F
.51277 .52177 m .51656 .52226 L .51429 .52318 L F
.658 .548 .718 r
.79004 .39443 m .79269 .39165 L .79086 .39254 L F
.79004 .39443 m .79173 .39437 L .79269 .39165 L F
.251 .676 .963 r
.2229 .64375 m .21887 .64275 L .22114 .6436 L F
.544 .707 .947 r
.24011 .69261 m .2383 .69338 L .23575 .69049 L F
.141 0 .222 r
.23909 .69474 m .2383 .69338 L .24011 .69261 L F
.23909 .69474 m .23747 .69558 L .2383 .69338 L F
.49 .478 .771 r
.79071 .43033 m .78872 .43256 L .78763 .42888 L F
.64 .585 .776 r
.79207 .43191 m .78872 .43256 L .79071 .43033 L F
.586 .308 .461 r
.49119 .58267 m .48857 .58322 L .48878 .5806 L F
.48878 .5806 m .48857 .58322 L .49119 .58267 L F
.49119 .58267 m .48857 .58322 L .48878 .5806 L F
.388 .151 .429 r
.49542 .61099 m .49766 .61052 L .49804 .60843 L F
.49542 .61099 m .49766 .61052 L .49804 .60843 L F
.727 .732 .854 r
.66943 .42727 m .67324 .42808 L .67223 .42446 L F
.753 .739 .84 r
.67324 .42808 m .67589 .425 L .67223 .42446 L F
.919 .669 .543 r
.50394 .58162 m .50634 .58065 L .50422 .57981 L F
.50394 .58162 m .50587 .58175 L .50634 .58065 L F
.873 .741 .228 r
.27188 .58832 m .27175 .58854 L .27176 .58829 L F
.785 .405 0 r
.27211 .58837 m .27188 .58832 L .27095 .58604 L F
.873 .741 .228 r
.27188 .58832 m .27183 .58481 L .27095 .58604 L F
.27188 .58832 m .27176 .58829 L .27183 .58481 L F
.785 .405 0 r
.27256 .58926 m .27188 .58832 L .27211 .58837 L F
.744 .795 .31 r
.27188 .58832 m .27179 .58842 L .27175 .58854 L F
.27179 .58842 m .2717 .58853 L .27175 .58854 L F
.568 .523 .765 r
.27272 .58558 m .27175 .58854 L .27512 .58767 L F
.27183 .58481 m .27175 .58854 L .27272 .58558 L F
0 .176 .621 r
.27256 .58926 m .2717 .58853 L .27188 .58832 L F
.27256 .58926 m .27392 .59016 L .2717 .58853 L F
.539 .481 .739 r
.2724 .59227 m .27392 .59016 L .27256 .58926 L F
.611 .439 .625 r
.66025 .42591 m .66342 .42743 L .66326 .42562 L F
.66025 .42591 m .66102 .42846 L .66342 .42743 L F
.895 .591 .464 r
.75958 .39332 m .7619 .39258 L .7606 .39125 L F
.931 .842 .734 r
.7619 .39258 m .76228 .38786 L .7606 .39125 L F
.509 .067 .134 r
.21253 .53932 m .21688 .53751 L .21232 .53901 L F
.21253 .53932 m .21484 .53951 L .21688 .53751 L F
0 0 0 r
.21688 .53751 m .21675 .53782 L .21912 .53796 L F
.21688 .53751 m .21484 .53951 L .21675 .53782 L F
.559 .652 .897 r
.77798 .42594 m .77373 .42369 L .77718 .42236 L F
.709 .715 .854 r
.78067 .42495 m .77798 .42594 L .77718 .42236 L F
.673 .963 .935 r
.21946 .71712 m .21908 .71621 L .22147 .71415 L F
.123 0 0 r
.21956 .7188 m .22075 .71753 L .22266 .71677 L F
.548 .193 .318 r
.21817 .71775 m .22075 .71753 L .21956 .7188 L F
.21817 .71775 m .22075 .71753 L .21956 .7188 L F
.248 0 0 r
.22266 .71677 m .21908 .71621 L .21956 .7188 L F
.673 .963 .935 r
.21946 .71712 m .21817 .71775 L .21908 .71621 L F
.113 .256 .733 r
.21937 .71782 m .21817 .71775 L .21956 .7188 L F
.21908 .71621 m .21827 .71757 L .21937 .71782 L F
.21827 .71757 m .21817 .71775 L .21937 .71782 L F
.27 .776 .835 r
.21599 .71925 m .21956 .7188 L .21817 .71775 L F
.996 .843 .569 r
.21908 .71621 m .21833 .71876 L .21956 .7188 L F
.248 0 0 r
.22004 .71797 m .22066 .71844 L .21833 .71876 L F
.22266 .71677 m .22097 .71819 L .22004 .71797 L F
.22097 .71819 m .22066 .71844 L .22004 .71797 L F
.22266 .71677 m .21833 .71876 L .21908 .71621 L F
.854 .416 0 r
.22218 .71697 m .22266 .71677 L .22147 .71415 L F
.66 .922 .623 r
.22225 .71694 m .22192 .71725 L .22266 .71677 L F
.22192 .71725 m .22066 .71844 L .22178 .7175 L F
.22192 .71725 m .22178 .7175 L .22266 .71677 L F
.854 .416 0 r
.22197 .71716 m .22147 .71415 L .21908 .71621 L F
.239 .566 .938 r
.21986 .71542 m .22202 .71707 L .21908 .71621 L F
.854 .416 0 r
.22225 .71725 m .22218 .71697 L .22197 .71716 L F
.239 .566 .938 r
.22202 .71707 m .22225 .71725 L .22197 .71716 L F
.22202 .71707 m .22197 .71716 L .21908 .71621 L F
.854 .416 0 r
.22225 .71725 m .22266 .71677 L .22218 .71697 L F
.66 .922 .623 r
.22279 .71643 m .22225 .71694 L .22266 .71677 L F
.854 .416 0 r
.22218 .71697 m .22147 .71415 L .22197 .71716 L F
.521 .303 .524 r
.22533 .71356 m .22266 .71677 L .22147 .71415 L F
.66 .922 .623 r
.22306 .71576 m .22191 .71722 L .22279 .71643 L F
.599 .7 .914 r
.22306 .71576 m .22225 .71725 L .22202 .71707 L F
.22306 .71576 m .22202 .71707 L .21986 .71542 L F
.66 .922 .623 r
.22306 .71576 m .22117 .71787 L .22191 .71722 L F
.22117 .71787 m .22066 .71844 L .22279 .71643 L F
.665 .377 .473 r
.48685 .6298 m .48316 .63195 L .48058 .63148 L F
.73 .99 .871 r
.48498 .63017 m .48316 .63195 L .48685 .6298 L F
.529 .324 .546 r
.45949 .63531 m .46213 .63217 L .45897 .63154 L F
.45949 .63531 m .462 .63495 L .46213 .63217 L F
.524 .319 .545 r
.46213 .63217 m .462 .63495 L .46444 .63433 L F
.612 .658 .871 r
.25773 .64455 m .25644 .64791 L .25386 .64335 L F
.337 .349 .725 r
.25703 .64811 m .25644 .64791 L .25773 .64455 L F
.56 .533 .782 r
.31962 .57652 m .31724 .57629 L .31888 .57527 L F
.369 .832 .901 r
.23922 .62647 m .23548 .62696 L .23755 .62623 L F
.352 .82 .91 r
.23981 .6258 m .23922 .62647 L .23755 .62623 L F
.23981 .6258 m .24146 .62595 L .23922 .62647 L F
.279 .775 .888 r
.21912 .53796 m .22137 .53757 L .22303 .53774 L F
.459 .839 .987 r
.22137 .53757 m .22528 .53763 L .22303 .53774 L F
.83 .872 .875 r
.23054 .69252 m .22752 .69286 L .22923 .69163 L F
.685 .904 .974 r
.23358 .69115 m .23054 .69252 L .22923 .69163 L F
.439 .525 .849 r
.74896 .39772 m .75043 .40117 L .75401 .40138 L F
.475 .299 .562 r
.75401 .40138 m .75043 .40117 L .75299 .40297 L F
.681 .639 .801 r
.80037 .42885 m .80045 .43087 L .79795 .43144 L F
.652 .637 .822 r
.80218 .43185 m .79795 .43144 L .80045 .43087 L F
.724 .763 .884 r
.79717 .42872 m .79795 .43144 L .79427 .43085 L F
.763 .786 .871 r
.80037 .42885 m .79795 .43144 L .79717 .42872 L F
.653 .566 .744 r
.43963 .63195 m .44249 .63197 L .44208 .62908 L F
.887 .624 .536 r
.57379 .52775 m .57553 .52592 L .57372 .5251 L F
.57379 .52775 m .57547 .52842 L .57553 .52592 L F
.578 .553 .791 r
.19619 .76817 m .19753 .77189 L .19505 .77184 L F
.172 0 0 r
.19505 .77184 m .19753 .77189 L .19378 .77247 L F
.088 0 0 r
.1773 .55223 m .18062 .54953 L .17825 .54981 L F
.746 .486 .537 r
.45984 .65303 m .45596 .65305 L .45618 .65065 L F
.969 .655 .283 r
.52677 .57713 m .52584 .57863 L .52557 .57595 L F
.52677 .57713 m .52692 .57928 L .52584 .57863 L F
.523 .351 .59 r
.29706 .61964 m .29475 .62247 L .29479 .62015 L F
.325 0 .14 r
.18286 .54917 m .18506 .54866 L .18671 .54592 L F
.323 0 .017 r
.18671 .54592 m .18752 .54732 L .18982 .54481 L F
.403 .107 .344 r
.18506 .54866 m .18752 .54732 L .18671 .54592 L F
.695 .253 .197 r
.49951 .54843 m .50304 .54756 L .49938 .54659 L F
.49951 .54843 m .50325 .54887 L .50304 .54756 L F
.607 .48 .682 r
.32039 .56518 m .31809 .56826 L .31813 .56602 L F
.397 0 0 r
.66844 .41876 m .67077 .41895 L .67199 .41876 L F
.805 .458 .4 r
.67083 .42065 m .67199 .41876 L .67077 .41895 L F
.67083 .42065 m .67398 .42131 L .67199 .41876 L F
.736 .482 .545 r
.46444 .63433 m .4684 .63587 L .46845 .63116 L F
.521 .321 .55 r
.46845 .63116 m .47065 .63154 L .47084 .62904 L F
.464 .263 .521 r
.46845 .63116 m .47045 .63452 L .47065 .63154 L F
.46845 .63116 m .4684 .63587 L .47045 .63452 L F
.664 .698 .872 r
.19802 .64097 m .19841 .64188 L .20062 .64083 L F
.477 .158 .347 r
.27827 .63569 m .27521 .63777 L .27601 .63562 L F
.948 .819 .684 r
.84592 .40686 m .84505 .40329 L .84265 .40616 L F
.818 .61 .622 r
.57493 .56192 m .57717 .56259 L .5751 .55915 L F
.862 .661 .63 r
.57493 .56192 m .5769 .56511 L .57717 .56259 L F
.782 .669 .738 r
.24675 .65001 m .24872 .65435 L .24645 .65209 L F
.59 .613 .843 r
.24645 .65209 m .24872 .65435 L .2505 .6531 L F
.308 .096 .42 r
.31405 .59247 m .31337 .59478 L .3118 .59509 L F
.449 .384 .692 r
.31337 .59478 m .31203 .59871 L .3118 .59509 L F
0 .113 .651 r
.5141 .60064 m .51516 .60413 L .51362 .60189 L F
.521 .592 .867 r
.5564 .60315 m .55882 .60146 L .55649 .60243 L F
.5564 .60315 m .56006 .60494 L .55882 .60146 L F
.916 .615 .46 r
.56246 .52877 m .56082 .53039 L .5607 .52788 L F
.56246 .52877 m .56267 .53128 L .56082 .53039 L F
.034 0 0 r
.18982 .54481 m .18956 .54632 L .19175 .54403 L F
.18982 .54481 m .18752 .54732 L .18956 .54632 L F
.826 .367 .131 r
.5007 .57651 m .50224 .57887 L .50339 .57773 L F
.852 .409 .157 r
.50224 .57887 m .50422 .57981 L .50339 .57773 L F
0 .383 .836 r
.76797 .42372 m .76953 .42376 L .76668 .42207 L F
.76797 .42372 m .77062 .42511 L .76953 .42376 L F
.191 .129 .552 r
.19995 .76042 m .19902 .76015 L .20062 .7622 L F
.19995 .76042 m .19902 .76015 L .20062 .7622 L F
.847 .812 .815 r
.57055 .5373 m .57254 .53838 L .57448 .53576 L F
.918 .741 .646 r
.57055 .5373 m .57184 .5409 L .57254 .53838 L F
.658 .452 .595 r
.45373 .57505 m .45768 .57115 L .45508 .57149 L F
.278 0 0 r
.24368 .62537 m .24589 .62515 L .24791 .62326 L F
.227 0 0 r
.24589 .62515 m .25027 .62313 L .24791 .62326 L F
.254 .38 .798 r
.16522 .58906 m .16542 .59274 L .16359 .58997 L F
.16522 .58906 m .16711 .59285 L .16542 .59274 L F
.266 .339 .753 r
.16711 .59285 m .16795 .59522 L .16542 .59274 L F
.623 .381 .53 r
.16542 .59274 m .16795 .59522 L .16501 .5953 L F
.16542 .59274 m .16795 .59522 L .16501 .5953 L F
.912 .789 .712 r
.56233 .54674 m .56136 .54286 L .56283 .54401 L F
.546 .386 .616 r
.45949 .63531 m .45946 .63786 L .462 .63495 L F
.867 .696 .669 r
.57362 .55582 m .57206 .55873 L .5751 .55915 L F
.785 .581 .624 r
.57193 .56153 m .5751 .55915 L .57206 .55873 L F
.57193 .56153 m .57493 .56192 L .5751 .55915 L F
.754 .993 .875 r
.8316 .4406 m .83468 .43824 L .83292 .43842 L F
.754 .992 .799 r
.8316 .4406 m .83292 .43842 L .83123 .44016 L F
.52 .388 .64 r
.31803 .58602 m .31586 .58473 L .31817 .5838 L F
.31803 .58602 m .31576 .58658 L .31586 .58473 L F
.772 .662 .742 r
.43254 .65877 m .43632 .65955 L .43485 .65865 L F
.43254 .65877 m .43399 .66273 L .43632 .65955 L F
.699 .264 .215 r
.21411 .71703 m .21599 .71925 L .21817 .71775 L F
.428 .704 .98 r
.19329 .61595 m .19276 .61751 L .19134 .61678 L F
.19329 .61595 m .19478 .61732 L .19276 .61751 L F
.975 .676 .381 r
.793 .39803 m .79217 .39828 L .79173 .39437 L F
.876 .823 .792 r
.79214 .40041 m .79217 .39828 L .793 .39803 L F
.678 .618 .781 r
.20575 .73449 m .2086 .73289 L .20459 .73181 L F
.04 0 0 r
.28505 .5727 m .28406 .57235 L .28712 .57383 L F
.28505 .5727 m .28262 .57359 L .28406 .57235 L F
.504 .27 .492 r
.47853 .61218 m .47635 .6107 L .47876 .61015 L F
.47853 .61218 m .47607 .61268 L .47635 .6107 L F
.273 0 .206 r
.16755 .57471 m .16677 .57635 L .16479 .57673 L F
.463 .361 .654 r
.16677 .57635 m .1651 .5799 L .16479 .57673 L F
.383 .448 .804 r
.17226 .60379 m .172 .60734 L .17098 .604 L F
.17226 .60379 m .17416 .60798 L .172 .60734 L F
.331 .784 .951 r
.24382 .53589 m .24632 .53541 L .24768 .53603 L F
.356 0 0 r
.24632 .53541 m .24999 .53617 L .24768 .53603 L F
.958 .947 .665 r
.77044 .40289 m .76982 .40631 L .77128 .40378 L F
.77044 .40289 m .76904 .40562 L .76982 .40631 L F
.511 .213 .398 r
.47938 .62591 m .48192 .62555 L .48238 .62379 L F
.616 .436 .615 r
.48192 .62555 m .48457 .62243 L .48238 .62379 L F
.756 .265 0 r
.53004 .52539 m .52926 .5251 L .52745 .52234 L F
0 .036 .595 r
.52745 .52234 m .52926 .5251 L .52799 .5222 L F
.739 .272 .14 r
.79758 .40373 m .80096 .40473 L .80158 .40603 L F
.994 .859 .588 r
.56844 .59994 m .56889 .59883 L .56718 .60036 L F
.725 .968 .935 r
.56829 .5981 m .56889 .59883 L .57082 .59725 L F
.959 .941 .635 r
.56718 .60036 m .56889 .59883 L .56829 .5981 L F
.302 0 0 r
.2354 .69622 m .23308 .69783 L .23117 .698 L F
.024 0 0 r
.23747 .69558 m .23308 .69783 L .2354 .69622 L F
.669 .774 .928 r
.22662 .70144 m .22693 .69785 L .22488 .69814 L F
.22662 .70144 m .23037 .70031 L .22693 .69785 L F
.664 .645 .821 r
.22662 .70144 m .23021 .70203 L .23037 .70031 L F
.156 .661 .906 r
.2602 .53733 m .26237 .53741 L .26411 .53807 L F
.518 .821 1 r
.26237 .53741 m .26646 .5379 L .26411 .53807 L F
.675 .587 .75 r
.4175 .64461 m .41758 .64703 L .41985 .64406 L F
.433 .306 .608 r
.22535 .69325 m .22582 .69592 L .22752 .69286 L F
.639 .524 .707 r
.32072 .56791 m .31809 .56826 L .32039 .56518 L F
.562 .371 .58 r
.32072 .56791 m .31825 .57085 L .31809 .56826 L F
.421 .688 .974 r
.17464 .62492 m .17574 .62607 L .17632 .62444 L F
.202 .437 .864 r
.17632 .62444 m .17574 .62607 L .17718 .62606 L F
.558 .531 .781 r
.17574 .62607 m .17908 .62928 L .17718 .62606 L F
.18 0 0 r
.18472 .56808 m .1803 .56984 L .18225 .56819 L F
.862 .661 .63 r
.57493 .56192 m .57343 .56447 L .5769 .56511 L F
.869 .643 .594 r
.57343 .56447 m .57667 .56788 L .5769 .56511 L F
.253 .432 .845 r
.76384 .41341 m .76399 .41533 L .7638 .41521 L F
.805 .709 .759 r
.76367 .41344 m .76399 .41533 L .76384 .41341 L F
0 0 .002 r
.76129 .41913 m .76273 .4157 L .7631 .41429 L F
.463 .853 .978 r
.76056 .41522 m .7631 .41429 L .7608 .41394 L F
0 .138 .668 r
.76384 .41341 m .7638 .41521 L .76175 .41261 L F
0 0 .002 r
.76129 .41914 m .7621 .41809 L .76273 .4157 L F
.76129 .41914 m .76273 .4157 L .76129 .41913 L F
.915 .757 .672 r
.7631 .41429 m .7621 .41809 L .7608 .41394 L F
.805 .709 .759 r
.7608 .41394 m .76305 .41492 L .76367 .41344 L F
.76305 .41492 m .76399 .41533 L .76367 .41344 L F
.025 .337 .818 r
.76129 .41914 m .76342 .42058 L .7621 .41809 L F
0 .123 .666 r
.17993 .61096 m .17973 .61146 L .17753 .61054 L F
.17993 .61096 m .18145 .61325 L .17973 .61146 L F
.536 .373 .607 r
.18145 .61325 m .17912 .61397 L .17973 .61146 L F
0 0 0 r
.27162 .58371 m .27183 .58481 L .27179 .58207 L F
.27162 .58371 m .27095 .58604 L .27183 .58481 L F
.156 0 0 r
.20807 .55577 m .20604 .55722 L .2048 .55685 L F
0 0 0 r
.2108 .55498 m .20604 .55722 L .20807 .55577 L F
.463 .154 .357 r
.1517 .56999 m .15478 .56752 L .15322 .56749 L F
.518 .77 .988 r
.81614 .39869 m .8127 .39789 L .81507 .39774 L F
.515 .818 1 r
.81876 .39809 m .81614 .39869 L .81507 .39774 L F
.81876 .39809 m .81507 .39774 L .81775 .39751 L F
.202 .722 .698 r
.81445 .39839 m .81745 .39759 L .81507 .39774 L F
.81745 .39759 m .81775 .39751 L .81507 .39774 L F
.518 .77 .988 r
.8127 .39789 m .81253 .39785 L .81507 .39774 L F
.847 .812 .815 r
.57055 .5373 m .57448 .53576 L .57278 .53421 L F
.764 .779 .865 r
.57278 .53421 m .57448 .53576 L .5771 .53355 L F
.748 .596 .688 r
.46355 .65639 m .46116 .65661 L .45984 .65303 L F
.737 .421 .447 r
.46355 .65639 m .4595 .65929 L .46116 .65661 L F
.46355 .65639 m .46354 .65875 L .46158 .65902 L F
.46355 .65639 m .46158 .65902 L .46089 .6583 L F
.46089 .6583 m .46158 .65902 L .4595 .65929 L F
.978 .722 .475 r
.46354 .65875 m .46169 .65817 L .4595 .65929 L F
.46354 .65875 m .46349 .66134 L .46169 .65817 L F
.819 .702 .736 r
.4662 .65875 m .46349 .66134 L .46354 .65875 L F
0 .221 .743 r
.46169 .65817 m .46305 .66057 L .46393 .66016 L F
.46305 .66057 m .46349 .66134 L .46357 .66112 L F
.46305 .66057 m .46357 .66112 L .46393 .66016 L F
.316 0 0 r
.2048 .55685 m .203 .5581 L .20041 .55825 L F
0 0 0 r
.20552 .55728 m .2048 .55685 L .20604 .55722 L F
.20552 .55728 m .203 .5581 L .2048 .55685 L F
.627 .378 .52 r
.46552 .62199 m .46217 .62049 L .466 .61984 L F
.46552 .62199 m .46156 .62263 L .46217 .62049 L F
.247 .26 .676 r
.18418 .7955 m .18472 .79607 L .18434 .79626 L F
.671 .282 .302 r
.18377 .79603 m .18472 .79607 L .18418 .7955 L F
.186 .195 .635 r
.23025 .67955 m .22922 .68055 L .23054 .68046 L F
.589 .538 .766 r
.22922 .68055 m .23258 .68398 L .23043 .68323 L F
.191 .265 .711 r
.22922 .68055 m .23043 .68323 L .23054 .68046 L F
.585 .301 .451 r
.466 .61984 m .46792 .62201 L .46552 .62199 L F
.72 .211 0 r
.53289 .57373 m .53374 .57497 L .53433 .57475 L F
.554 .112 .154 r
.53596 .57711 m .53433 .57475 L .53374 .57497 L F
.299 .515 .897 r
.53433 .57475 m .53749 .57581 L .53829 .57756 L F
.554 .112 .154 r
.53596 .57711 m .53749 .57581 L .53433 .57475 L F
.717 .635 .764 r
.42987 .66248 m .43399 .66273 L .43254 .65877 L F
.472 .249 .494 r
.30968 .60172 m .30935 .60429 L .30708 .60489 L F
.551 .37 .59 r
.31203 .59871 m .31208 .60131 L .30968 .60172 L F
.403 .138 .394 r
.31208 .60131 m .30935 .60429 L .30968 .60172 L F
.799 .965 .913 r
.82345 .4446 m .82459 .44206 L .8226 .44353 L F
.82345 .4446 m .82522 .44302 L .82459 .44206 L F
.662 .44 .572 r
.79173 .39437 m .79658 .39706 L .79623 .39511 L F
.79173 .39437 m .79217 .39828 L .79658 .39706 L F
.574 .09 0 r
.76883 .40099 m .77044 .40289 L .77128 .40378 L F
.642 .147 .06 r
.54993 .60213 m .54622 .60145 L .5472 .60227 L F
.765 .477 .496 r
.51369 .55204 m .51545 .54925 L .51418 .54954 L F
.51369 .55204 m .51678 .5525 L .51545 .54925 L F
.311 0 0 r
.51545 .54925 m .51912 .54884 L .51955 .54854 L F
.41 .302 .62 r
.51545 .54925 m .51857 .55149 L .51912 .54884 L F
.51545 .54925 m .51678 .5525 L .51857 .55149 L F
.454 .18 .408 r
.4553 .64455 m .45711 .64627 L .45725 .6437 L F
.4553 .64455 m .45472 .64688 L .45711 .64627 L F
.42 .152 .398 r
.48516 .62061 m .48628 .62169 L .48648 .62007 L F
.48516 .62061 m .48457 .62243 L .48628 .62169 L F
.437 .178 .422 r
.17676 .57144 m .17599 .57389 L .17376 .57438 L F
.084 0 .251 r
.17815 .57048 m .17599 .57389 L .17676 .57144 L F
.19 .603 .945 r
.27184 .55921 m .272 .55812 L .27034 .55794 L F
.27184 .55921 m .27359 .55934 L .272 .55812 L F
.226 .741 .867 r
.22754 .53735 m .22914 .53751 L .22528 .53763 L F
.44 .844 .973 r
.22754 .53735 m .23143 .53725 L .22914 .53751 L F
.768 .643 .724 r
.56324 .55923 m .56118 .56225 L .5594 .55877 L F
.498 .232 .442 r
.54523 .51255 m .5481 .50975 L .54592 .51019 L F
.67 .422 .537 r
.44863 .57671 m .45419 .57617 L .44931 .57499 L F
.486 .647 .929 r
.3113 .54475 m .31031 .5468 L .3086 .54425 L F
.3113 .54475 m .31251 .54657 L .31031 .5468 L F
.148 .691 .745 r
.22994 .55068 m .23192 .55048 L .23408 .55013 L F
.701 .244 .163 r
.49809 .57996 m .49599 .5815 L .49602 .57896 L F
.35 .356 .725 r
.49599 .5815 m .49617 .58076 L .49602 .57896 L F
.957 .651 .409 r
.49809 .57996 m .49602 .57896 L .49743 .57743 L F
.35 .356 .725 r
.49617 .58076 m .49698 .57741 L .49602 .57896 L F
.905 .546 .348 r
.49584 .57686 m .49602 .57896 L .49554 .57675 L F
.49743 .57743 m .49602 .57896 L .49584 .57686 L F
.745 .803 .899 r
.50503 .61871 m .50313 .61997 L .50673 .61998 L F
.50503 .61871 m .50313 .61997 L .50673 .61998 L F
.476 .485 .787 r
.50673 .61998 m .50785 .61605 L .50503 .61871 L F
.50673 .61998 m .509 .61971 L .50785 .61605 L F
.682 .661 .823 r
.23037 .70031 m .23021 .70203 L .23117 .698 L F
.09 .274 .758 r
.53027 .5873 m .5316 .58881 L .53024 .58554 L F
.549 .87 .994 r
.79307 .44387 m .79466 .44466 L .79729 .44382 L F
.291 .79 .817 r
.26646 .5379 m .26867 .5373 L .27032 .53714 L F
.375 .841 .85 r
.27032 .53714 m .27087 .53655 L .27254 .53686 L F
.27032 .53714 m .26867 .5373 L .27087 .53655 L F
.508 .045 .089 r
.83563 .40118 m .84011 .40131 L .83897 .40059 L F
.161 .221 .678 r
.83897 .40059 m .84014 .39739 L .84153 .40015 L F
.83897 .40059 m .84011 .40131 L .84014 .39739 L F
.878 .636 .568 r
.51135 .60753 m .50896 .6098 L .50936 .60691 L F
.51135 .60753 m .5112 .61058 L .50896 .6098 L F
.291 .476 .869 r
.77243 .42015 m .77271 .42201 L .77154 .42236 L F
.454 .307 .592 r
.14286 .57738 m .14488 .57676 L .14482 .57413 L F
.298 0 .227 r
.14286 .57738 m .14184 .57941 L .14488 .57676 L F
.683 .786 .929 r
.83042 .43486 m .82666 .43428 L .8294 .43374 L F
.477 .853 .985 r
.8294 .43374 m .83297 .43381 L .83042 .43486 L F
.796 .585 .616 r
.67223 .42446 m .67596 .42248 L .67398 .42131 L F
.67223 .42446 m .67589 .425 L .67596 .42248 L F
.763 .395 0 r
.52865 .58138 m .52865 .58197 L .52692 .57928 L F
.5289 .58202 m .52939 .58324 L .52865 .58197 L F
.784 .423 0 r
.52939 .58324 m .53024 .58554 L .52865 .58197 L F
0 .197 .718 r
.52865 .58197 m .53024 .58554 L .53181 .58526 L F
.816 .765 .805 r
.53179 .58544 m .53185 .58536 L .53181 .58531 L F
0 0 .452 r
.53181 .58526 m .53024 .58554 L .5315 .58761 L F
.447 .252 .522 r
.53117 .58626 m .53195 .58614 L .53179 .58544 L F
0 0 .452 r
.53195 .58613 m .53179 .58546 L .53158 .58773 L F
.447 .252 .522 r
.53195 .58614 m .53362 .58588 L .53179 .58544 L F
0 0 .452 r
.53217 .58519 m .53179 .58546 L .53195 .58613 L F
.53217 .58519 m .53195 .58613 L .53117 .58626 L F
.53181 .58526 m .5315 .58761 L .53158 .58773 L F
.53195 .58613 m .53158 .58773 L .53117 .58626 L F
.447 .252 .522 r
.53179 .58544 m .53355 .58586 L .53305 .58376 L F
.53355 .58586 m .53362 .58588 L .53361 .58585 L F
.53355 .58586 m .53361 .58585 L .53305 .58376 L F
0 0 .452 r
.53217 .58519 m .53181 .58526 L .53179 .58546 L F
.816 .765 .805 r
.53117 .58626 m .53179 .58544 L .52983 .58315 L F
.53179 .58544 m .53181 .58531 L .52983 .58315 L F
0 .197 .718 r
.52865 .58197 m .53182 .58526 L .53158 .58465 L F
0 .061 .539 r
.53161 .58468 m .52841 .58192 L .52865 .58197 L F
.816 .765 .805 r
.53185 .58536 m .53208 .58505 L .53161 .58468 L F
0 .197 .718 r
.53158 .58465 m .53182 .58526 L .53217 .58519 L F
0 .061 .539 r
.53217 .58519 m .53124 .58439 L .53161 .58468 L F
.53124 .58439 m .52841 .58192 L .53161 .58468 L F
.816 .765 .805 r
.53161 .58468 m .53305 .58376 L .53116 .5834 L F
.53208 .58505 m .53305 .58376 L .53161 .58468 L F
0 .197 .718 r
.52865 .58197 m .53181 .58526 L .53181 .58525 L F
0 .061 .539 r
.53124 .58439 m .52983 .58315 L .52725 .58092 L F
.816 .765 .805 r
.53163 .58472 m .53116 .5834 L .52983 .58315 L F
0 .061 .539 r
.53217 .58519 m .52983 .58315 L .53124 .58439 L F
.816 .765 .805 r
.53185 .58536 m .53163 .58472 L .52983 .58315 L F
0 .197 .718 r
.53181 .58525 m .53181 .58526 L .53182 .58526 L F
.847 .681 .676 r
.53054 .58202 m .53363 .58098 L .53192 .57984 L F
.52983 .58315 m .53078 .58261 L .53054 .58202 L F
.53078 .58261 m .53363 .58098 L .53054 .58202 L F
0 .061 .539 r
.52841 .58192 m .52725 .58092 L .52865 .58197 L F
.763 .395 0 r
.52865 .58138 m .5289 .58202 L .52865 .58197 L F
.503 .753 .985 r
.78777 .44475 m .78967 .44301 L .78725 .44264 L F
.78777 .44475 m .79078 .44452 L .78967 .44301 L F
.61 .505 .709 r
.49387 .59209 m .49516 .59639 L .49766 .5952 L F
.405 .6 .925 r
.17908 .62928 m .18326 .63197 L .18182 .6303 L F
.355 .625 .954 r
.18182 .6303 m .18326 .63197 L .18372 .63032 L F
.094 .329 .803 r
.18326 .63197 m .18547 .63365 L .18372 .63032 L F
.501 .878 .974 r
.79729 .44382 m .80065 .44358 L .79968 .44264 L F
.461 .648 .939 r
.80065 .44358 m .80328 .44374 L .80233 .44176 L F
.593 .864 .994 r
.80065 .44358 m .80233 .44176 L .79968 .44264 L F
.654 .483 .64 r
.44208 .62908 m .43967 .6299 L .43862 .6293 L F
.818 1 .806 r
.83468 .43824 m .83581 .43571 L .83292 .43842 L F
.83468 .43824 m .83614 .43639 L .83581 .43571 L F
.802 .513 .499 r
.56717 .51238 m .5692 .51044 L .56684 .51055 L F
.56717 .51238 m .57131 .51306 L .5692 .51044 L F
.449 .384 .692 r
.31337 .59478 m .31415 .59828 L .31203 .59871 L F
.598 .495 .708 r
.31415 .59828 m .31208 .60131 L .31203 .59871 L F
0 .253 .642 r
.49453 .55017 m .49297 .54932 L .49009 .5478 L F
.693 .159 0 r
.49723 .5517 m .49297 .54932 L .49453 .55017 L F
.597 .268 .384 r
.47584 .63819 m .47766 .64035 L .47568 .64022 L F
.47568 .64022 m .47766 .64035 L .47584 .63819 L F
.382 .685 .978 r
.29714 .54014 m .29644 .54153 L .29481 .5403 L F
.29714 .54014 m .29867 .54173 L .29644 .54153 L F
.737 .339 .297 r
.78876 .38895 m .78756 .39042 L .78941 .39057 L F
.791 .485 .471 r
.78876 .38895 m .79086 .39254 L .79269 .39165 L F
0 0 .187 r
.48093 .55925 m .48116 .56094 L .4834 .55929 L F
.48093 .55925 m .48099 .5619 L .48116 .56094 L F
.191 .286 .732 r
.27568 .56211 m .27613 .55889 L .27359 .55934 L F
.27568 .56211 m .2778 .56341 L .27613 .55889 L F
.276 .271 .673 r
.27568 .56211 m .27774 .56412 L .2778 .56341 L F
.982 .751 .511 r
.17376 .57438 m .17195 .57513 L .16965 .57377 L F
.17376 .57438 m .17339 .57681 L .17195 .57513 L F
.459 .233 .483 r
.17599 .57389 m .17339 .57681 L .17376 .57438 L F
.698 .922 .592 r
.74912 .38742 m .75039 .3864 L .74808 .38927 L F
.652 .907 .588 r
.75188 .38433 m .75039 .3864 L .74912 .38742 L F
.446 .302 .591 r
.30935 .60429 m .30736 .60751 L .30708 .60489 L F
.709 .715 .854 r
.78067 .42495 m .77718 .42236 L .77989 .42121 L F
.593 .578 .805 r
.78302 .42399 m .78067 .42495 L .77989 .42121 L F
.61 .639 .855 r
.78302 .42399 m .78462 .42586 L .78067 .42495 L F
.566 .531 .775 r
.78433 .4281 m .78067 .42495 L .78462 .42586 L F
.643 .607 .798 r
.80297 .42805 m .80045 .43087 L .80037 .42885 L F
.80297 .42805 m .80447 .43139 L .80045 .43087 L F
.652 .586 .768 r
.80447 .43139 m .80218 .43185 L .80045 .43087 L F
.624 .318 .432 r
.46041 .61615 m .46318 .61621 L .46408 .61331 L F
.5 .199 .386 r
.46408 .61331 m .46591 .61505 L .46604 .61309 L F
.46408 .61331 m .46318 .61621 L .46591 .61505 L F
.672 .702 .869 r
.66102 .42846 m .66496 .42939 L .66342 .42743 L F
.718 .685 .817 r
.66342 .42743 m .66496 .42939 L .66723 .42817 L F
.714 .224 0 r
.52128 .56975 m .52224 .57187 L .51956 .5684 L F
.52128 .56975 m .5235 .57292 L .52224 .57187 L F
.425 .638 .945 r
.76835 .41719 m .76712 .41897 L .76596 .41712 L F
.326 .502 .878 r
.76835 .41719 m .76945 .41948 L .76712 .41897 L F
.812 .845 .874 r
.56239 .60356 m .56647 .60239 L .56542 .60181 L F
.876 .972 .845 r
.56542 .60181 m .56647 .60239 L .56844 .59994 L F
.579 .614 .852 r
.43967 .64764 m .44363 .65032 L .44237 .64762 L F
.465 .132 .316 r
.4817 .6079 m .48143 .60972 L .47876 .61015 L F
.535 .191 .332 r
.4817 .6079 m .48393 .60957 L .48143 .60972 L F
.508 .205 .387 r
.48457 .60751 m .48393 .60957 L .4817 .6079 L F
.868 .643 .595 r
.55502 .57812 m .55293 .57837 L .55311 .57641 L F
.55502 .57812 m .5549 .58032 L .55293 .57837 L F
.76 .714 .809 r
.55706 .57618 m .55502 .57812 L .55311 .57641 L F
.957 .657 .229 r
.51528 .56234 m .51449 .56342 L .51289 .56096 L F
.51528 .56234 m .51549 .56476 L .51449 .56342 L F
.458 .564 .875 r
.77062 .42511 m .77212 .42811 L .77412 .42569 L F
.38 .449 .807 r
.77212 .42811 m .77522 .42955 L .77412 .42569 L F
.32 .447 .833 r
.77212 .42811 m .7753 .43155 L .77522 .42955 L F
.179 0 .339 r
.26816 .60155 m .26991 .60093 L .27009 .59853 L F
.157 0 .252 r
.26816 .60155 m .26932 .60307 L .26991 .60093 L F
.26816 .60155 m .2677 .60388 L .26932 .60307 L F
.771 .697 .781 r
.53994 .58607 m .5439 .58669 L .54117 .58953 L F
.163 .357 .809 r
.17351 .74745 m .17362 .74752 L .17357 .74757 L F
.548 .898 .677 r
.17357 .74757 m .17362 .74752 L .1735 .74762 L F
.723 .725 .851 r
.74402 .39119 m .74507 .39374 L .74751 .39065 L F
.526 .325 .551 r
.47065 .63154 m .4731 .63114 L .47084 .62904 L F
.661 .296 .342 r
.47084 .62904 m .4731 .63114 L .47333 .62943 L F
0 0 0 r
.50216 .59566 m .50147 .59549 L .50454 .59605 L F
.912 .789 .712 r
.56233 .54674 m .5597 .54627 L .56136 .54286 L F
.918 .763 .674 r
.56233 .54674 m .56069 .54984 L .5597 .54627 L F
.189 .535 .924 r
.82655 .42203 m .82843 .42345 L .82685 .42363 L F
.916 .966 .659 r
.23594 .67149 m .23401 .67541 L .23381 .67332 L F
.406 .245 .549 r
.23598 .67422 m .23401 .67541 L .23594 .67149 L F
.655 .89 .982 r
.23381 .67332 m .23401 .67541 L .23598 .67422 L F
0 0 .554 r
.5226 .54968 m .52326 .55265 L .52236 .55056 L F
0 0 .396 r
.52187 .54659 m .5226 .54968 L .52236 .55056 L F
0 0 .554 r
.5226 .54968 m .52326 .55265 L .52236 .55056 L F
0 0 0 r
.18285 .79012 m .18293 .79007 L .18279 .7902 L F
.049 .585 .855 r
.45897 .63154 m .45687 .63078 L .45457 .63045 L F
.772 .458 .456 r
.45937 .62929 m .45687 .63078 L .45897 .63154 L F
.436 0 0 r
.48706 .56282 m .48972 .56361 L .49046 .56316 L F
.774 .267 0 r
.48972 .56361 m .49155 .56453 L .49046 .56316 L F
.025 .209 .716 r
.16695 .59724 m .16646 .59905 L .16501 .5953 L F
.526 .762 .983 r
.16695 .59724 m .1687 .59862 L .16646 .59905 L F
.154 .292 .754 r
.4834 .55929 m .48636 .56244 L .48496 .56248 L F
.337 0 0 r
.48706 .56282 m .48336 .56387 L .48496 .56248 L F
.116 .541 .917 r
.48636 .56244 m .48706 .56282 L .48496 .56248 L F
.438 .149 .375 r
.16965 .57377 m .16677 .57635 L .16755 .57471 L F
.588 .125 .122 r
.77271 .42201 m .77718 .42236 L .77373 .42369 L F
0 0 0 r
.1955 .54328 m .19407 .54355 L .19781 .54305 L F
.984 .822 .602 r
.50842 .60171 m .50713 .6013 L .50792 .59825 L F
.974 .684 .408 r
.50842 .60171 m .50874 .60423 L .50713 .6013 L F
.199 .192 .625 r
.49809 .583 m .49998 .58216 L .49809 .57996 L F
0 0 0 r
.49811 .58531 m .49998 .58216 L .49809 .583 L F
.564 .742 .96 r
.2767 .55304 m .27233 .55213 L .2754 .55149 L F
.2767 .55304 m .27233 .55213 L .2754 .55149 L F
0 0 0 r
.74912 .38742 m .74808 .38927 L .74751 .39065 L F
.6 .111 .063 r
.17342 .7475 m .17362 .74752 L .17351 .74745 L F
.169 0 0 r
.75425 .38331 m .75247 .38277 L .75188 .38433 L F
.75425 .38331 m .75521 .38237 L .75247 .38277 L F
0 0 0 r
.27775 .57369 m .27646 .57593 L .27933 .57331 L F
0 .061 .622 r
.19242 .63798 m .19135 .63503 L .18872 .63513 L F
.19242 .63798 m .19264 .63775 L .19135 .63503 L F
0 0 .035 r
.48973 .62691 m .48942 .62553 L .49206 .6262 L F
.48973 .62691 m .48818 .62825 L .48942 .62553 L F
.645 .966 .896 r
.53204 .52401 m .53133 .52375 L .53004 .52539 L F
.643 .964 .906 r
.53004 .52539 m .53133 .52375 L .52926 .5251 L F
.542 .287 .479 r
.49804 .60843 m .50028 .60994 L .50053 .60703 L F
.49804 .60843 m .49766 .61052 L .50028 .60994 L F
.50028 .60994 m .49804 .60843 L .50053 .60703 L F
.50028 .60994 m .49766 .61052 L .49804 .60843 L F
.536 .289 .488 r
.28349 .63371 m .28151 .63163 L .28374 .63152 L F
.28349 .63371 m .28238 .63412 L .28151 .63163 L F
.681 .424 .527 r
.4261 .66431 m .42987 .66248 L .42762 .66226 L F
.4261 .66431 m .42962 .66485 L .42987 .66248 L F
.665 .698 .87 r
.16125 .59045 m .15748 .58922 L .15958 .58872 L F
.544 .712 .95 r
.16183 .58817 m .16125 .59045 L .15958 .58872 L F
.16183 .58817 m .16359 .58997 L .16125 .59045 L F
.928 .734 .621 r
.56394 .53769 m .56231 .53391 L .56444 .53493 L F
.56394 .53769 m .56119 .53694 L .56231 .53391 L F
.917 .755 .666 r
.56394 .53769 m .56046 .53943 L .56119 .53694 L F
.56394 .53769 m .5623 .54065 L .56046 .53943 L F
.84 .382 .118 r
.8285 .42563 m .82697 .42471 L .82474 .42583 L F
.82697 .42471 m .82562 .42489 L .82474 .42583 L F
.8285 .42563 m .82717 .42603 L .82622 .42426 L F
.415 .05 .233 r
.82843 .42345 m .82717 .42603 L .8285 .42563 L F
.82787 .42459 m .82968 .42546 L .82717 .42603 L F
.82843 .42345 m .82904 .42443 L .82787 .42459 L F
.82904 .42443 m .82968 .42546 L .82787 .42459 L F
.84 .382 .118 r
.82697 .42471 m .82622 .42426 L .82562 .42489 L F
.696 .573 .712 r
.44249 .63197 m .44342 .63508 L .44577 .63185 L F
0 0 .295 r
.45006 .66548 m .45007 .66444 L .44919 .66151 L F
0 0 .459 r
.45 .66807 m .45007 .66444 L .45006 .66548 L F
.28 .485 .88 r
.16764 .62037 m .16841 .61873 L .16648 .61888 L F
.16764 .62037 m .17055 .62181 L .16841 .61873 L F
.908 .681 .582 r
.57631 .57048 m .57825 .57127 L .57667 .56788 L F
.807 .467 .412 r
.57497 .57262 m .57825 .57127 L .57631 .57048 L F
.57497 .57262 m .57883 .57371 L .57825 .57127 L F
.901 .56 .39 r
.57932 .57464 m .57825 .57127 L .57883 .57371 L F
.518 0 0 r
.18145 .61325 m .18384 .61439 L .18553 .61453 L F
.825 .964 .897 r
.18553 .61453 m .18584 .61208 L .18721 .6138 L F
.18553 .61453 m .18384 .61439 L .18584 .61208 L F
0 0 0 r
.20681 .53818 m .204 .54058 L .20637 .53888 L F
.622 .141 .09 r
.20637 .53888 m .20872 .53977 L .20681 .53818 L F
.958 .621 .317 r
.20681 .53818 m .20637 .53888 L .205 .53675 L F
.359 .071 .333 r
.19794 .55845 m .19491 .56142 L .19564 .55906 L F
.704 .618 .758 r
.5594 .55877 m .56118 .56225 L .55675 .56209 L F
.724 .533 .633 r
.56118 .56225 m .55685 .56469 L .55675 .56209 L F
.56118 .56225 m .56091 .56497 L .55685 .56469 L F
0 0 .259 r
.14003 .58296 m .14184 .57941 L .14017 .58036 L F
.291 .762 .939 r
.21631 .72601 m .21298 .72611 L .21574 .72653 L F
0 .245 .754 r
.21298 .72611 m .21522 .72778 L .21574 .72653 L F
.935 .567 .277 r
.41944 .65392 m .41962 .65527 L .41725 .6523 L F
.575 .79 .981 r
.42053 .65291 m .41944 .65392 L .41725 .6523 L F
.066 0 .392 r
.42053 .65291 m .41962 .65527 L .41944 .65392 L F
.45 .518 .837 r
.16474 .61934 m .16495 .61559 L .16256 .6162 L F
.16474 .61934 m .16648 .61888 L .16495 .61559 L F
.981 .762 .532 r
.78679 .42501 m .78763 .42888 L .78433 .4281 L F
.78763 .42888 m .78679 .42501 L .79026 .42682 L F
.492 .477 .768 r
.79026 .42682 m .79071 .43033 L .78763 .42888 L F
.697 .597 .741 r
.44208 .62908 m .44249 .63197 L .44577 .63185 L F
0 .144 .688 r
.45057 .64978 m .45161 .6507 L .45082 .64884 L F
.966 .839 .666 r
.23258 .68398 m .23678 .68397 L .23468 .68184 L F
.491 .577 .869 r
.23468 .68184 m .23678 .68397 L .2376 .68259 L F
.552 .499 .75 r
.23616 .68672 m .2376 .68259 L .23678 .68397 L F
.929 .747 .635 r
.55685 .56469 m .55513 .56084 L .55675 .56209 L F
.855 .883 .858 r
.5594 .55877 m .55675 .56209 L .55513 .56084 L F
.85 .995 .756 r
.83581 .43571 m .83745 .43503 L .83745 .43149 L F
.83581 .43571 m .83614 .43639 L .83745 .43503 L F
.808 .783 .83 r
.55231 .58332 m .54968 .58614 L .54901 .58325 L F
.733 .723 .842 r
.1735 .74762 m .17362 .74752 L .17342 .7475 L F
.76 .73 .824 r
.54491 .58257 m .5439 .58669 L .54281 .58538 L F
.54491 .58257 m .54595 .58512 L .5439 .58669 L F
.748 .736 .841 r
.54281 .58538 m .5439 .58669 L .53994 .58607 L F
.779 .778 .852 r
.18279 .7902 m .18293 .79007 L .18263 .79003 L F
.336 .55 .912 r
.15311 .61035 m .15365 .60856 L .15084 .60761 L F
.15311 .61035 m .15471 .61023 L .15365 .60856 L F
.95 .6 .228 r
.51265 .59695 m .51339 .59567 L .51197 .59476 L F
.51265 .59695 m .51396 .59804 L .51339 .59567 L F
.369 0 0 r
.28912 .53904 m .29096 .53976 L .2934 .54024 L F
.024 .586 .804 r
.29096 .53976 m .29481 .5403 L .2934 .54024 L F
.764 .627 .708 r
.45984 .65303 m .45754 .65633 L .45596 .65305 L F
.74 .592 .692 r
.45984 .65303 m .46116 .65661 L .45754 .65633 L F
.527 .737 .971 r
.19894 .61871 m .19478 .61732 L .19697 .61786 L F
.552 .836 .998 r
.19968 .61711 m .19894 .61871 L .19697 .61786 L F
.19968 .61711 m .20169 .61798 L .19894 .61871 L F
.709 .844 .947 r
.83905 .40549 m .8366 .4068 L .84002 .40691 L F
.614 .767 .953 r
.84002 .40691 m .84176 .40452 L .83905 .40549 L F
.84002 .40691 m .84265 .40616 L .84176 .40452 L F
.522 .646 .912 r
.78326 .4405 m .78467 .44303 L .78725 .44264 L F
.668 .269 .28 r
.55126 .50769 m .55508 .50921 L .55512 .50713 L F
.998 .788 .491 r
.57972 .58239 m .58049 .58578 L .5807 .58337 L F
.532 .431 .684 r
.49539 .58691 m .49852 .58821 L .49811 .58531 L F
.49539 .58691 m .4967 .58974 L .49852 .58821 L F
.326 .248 .613 r
.4595 .65929 m .45754 .65633 L .46116 .65661 L F
.518 .234 .424 r
.47649 .62872 m .47915 .62834 L .47938 .62591 L F
.585 .29 .435 r
.47938 .62591 m .47915 .62834 L .48175 .62796 L F
.542 .3 .499 r
.47938 .62591 m .48175 .62796 L .48192 .62555 L F
.741 .81 .907 r
.18263 .79003 m .18293 .79007 L .18368 .78697 L F
.552 .499 .75 r
.23616 .68672 m .23867 .68658 L .2376 .68259 L F
.344 .023 .269 r
.14762 .57133 m .14669 .57344 L .14975 .57072 L F
.306 .785 .917 r
.84185 .4182 m .8444 .41823 L .84279 .41855 L F
.176 0 0 r
.54292 .51327 m .54081 .51403 L .53976 .51521 L F
.48 .221 .443 r
.28947 .62627 m .28896 .62857 L .28663 .62902 L F
.446 .19 .431 r
.29128 .62788 m .28947 .62627 L .29179 .62543 L F
.29128 .62788 m .28896 .62857 L .28947 .62627 L F
.402 .647 .957 r
.14774 .60583 m .14922 .60755 L .14969 .60583 L F
.267 .501 .895 r
.14922 .60755 m .15084 .60761 L .14969 .60583 L F
.496 .244 .463 r
.26113 .61358 m .26347 .61315 L .26402 .61079 L F
0 0 .077 r
.266 .6075 m .26402 .61079 L .26521 .60965 L F
0 0 .217 r
.26347 .61315 m .26521 .60965 L .26402 .61079 L F
.678 .173 .035 r
.50826 .55629 m .50694 .55738 L .50454 .55543 L F
.605 .083 0 r
.50826 .55629 m .51073 .55789 L .50694 .55738 L F
.477 0 0 r
.51255 .55869 m .51073 .55789 L .50826 .55629 L F
.706 .38 .422 r
.48116 .56094 m .48636 .56244 L .4834 .55929 L F
.673 .734 .896 r
.81043 .43113 m .80678 .43045 L .80943 .42949 L F
.632 .778 .951 r
.81226 .42866 m .81043 .43113 L .80943 .42949 L F
.81226 .42866 m .81312 .43026 L .81043 .43113 L F
.782 .669 .738 r
.24675 .65001 m .24645 .65209 L .2505 .6531 L F
.695 .407 .482 r
.47406 .60705 m .47562 .60792 L .47785 .6047 L F
.55 .232 .382 r
.47785 .6047 m .47562 .60792 L .48051 .60621 L F
.561 .215 .339 r
.47785 .6047 m .48051 .60621 L .48063 .60468 L F
.655 .173 .096 r
.49377 .59744 m .49771 .59794 L .49516 .59639 L F
.369 .593 .932 r
.27709 .5361 m .27647 .53799 L .27512 .53606 L F
.505 .741 .98 r
.27709 .5361 m .27877 .53766 L .27647 .53799 L F
.557 .331 .528 r
.66523 .42199 m .66844 .41876 L .66622 .41889 L F
.013 0 0 r
.20913 .55626 m .21048 .55617 L .20837 .55651 L F
.21296 .55501 m .21048 .55617 L .20913 .55626 L F
.559 .063 .035 r
.21518 .55504 m .21317 .55636 L .21048 .55617 L F
.083 .634 .823 r
.21317 .55636 m .21074 .55616 L .21048 .55617 L F
.21074 .55616 m .2092 .55603 L .21048 .55617 L F
.364 .8 .963 r
.21048 .55617 m .20984 .55619 L .20837 .55651 L F
0 0 0 r
.2108 .55498 m .20837 .55651 L .20686 .55684 L F
.013 0 0 r
.21296 .55501 m .20837 .55651 L .2108 .55498 L F
.364 .8 .963 r
.20984 .55619 m .20677 .55626 L .20837 .55651 L F
0 0 0 r
.20686 .55684 m .20837 .55651 L .20604 .55722 L F
.582 .462 .681 r
.3219 .55848 m .32226 .56264 L .32035 .56323 L F
.629 .501 .688 r
.32298 .56447 m .32035 .56323 L .32226 .56264 L F
.32298 .56447 m .32039 .56518 L .32035 .56323 L F
.968 .726 .516 r
.26418 .64112 m .26416 .64396 L .2623 .64277 L F
.538 .362 .591 r
.26652 .64347 m .26418 .64112 L .26666 .64128 L F
.26652 .64347 m .26416 .64396 L .26418 .64112 L F
.301 .568 .932 r
.1714 .62358 m .17212 .62208 L .17055 .62181 L F
.1714 .62358 m .17464 .62492 L .17212 .62208 L F
.588 .445 .654 r
.31962 .57652 m .31987 .57952 L .31724 .57981 L F
.514 .425 .692 r
.3194 .58343 m .31724 .57981 L .31987 .57952 L F
.3194 .58343 m .31817 .5838 L .31724 .57981 L F
.636 .663 .859 r
.55882 .60146 m .56006 .60494 L .56239 .60356 L F
.912 .662 .547 r
.4982 .57079 m .49835 .5738 L .50038 .57415 L F
0 .008 .539 r
.49835 .5738 m .5007 .57651 L .50038 .57415 L F
.518 .523 .801 r
.31477 .54602 m .31392 .55041 L .31251 .54657 L F
.31477 .54602 m .31622 .55019 L .31392 .55041 L F
.946 .796 .663 r
.51424 .60972 m .5169 .60756 L .51489 .60677 L F
.51424 .60972 m .51565 .61038 L .5169 .60756 L F
0 0 0 r
.45317 .62936 m .45196 .63099 L .45457 .63045 L F
.45317 .62936 m .45161 .63151 L .45196 .63099 L F
.687 .816 .368 r
.45196 .63099 m .45056 .63356 L .45161 .63151 L F
.209 0 .014 r
.27521 .63777 m .27198 .63984 L .2731 .63835 L F
.337 .349 .725 r
.25703 .64811 m .25773 .64455 L .25856 .64727 L F
.037 .036 .525 r
.25775 .64959 m .25703 .64811 L .25856 .64727 L F
.449 .41 .723 r
.75465 .40524 m .75517 .41039 L .75763 .40932 L F
.422 .345 .664 r
.75763 .40932 m .75517 .41039 L .75799 .41216 L F
.588 .657 .885 r
.3065 .54486 m .30263 .54299 L .30496 .54204 L F
.529 .621 .888 r
.3086 .54425 m .3065 .54486 L .30496 .54204 L F
.695 .166 0 r
.52319 .55519 m .52636 .55621 L .52466 .55535 L F
.783 .475 .467 r
.52287 .55772 m .52636 .55621 L .52319 .55519 L F
.52287 .55772 m .52701 .55848 L .52636 .55621 L F
.397 .11 .355 r
.45687 .61139 m .45668 .61308 L .45975 .61061 L F
.727 .383 .395 r
.55176 .51933 m .54999 .52149 L .54797 .51906 L F
.681 .323 .36 r
.55406 .52157 m .54999 .52149 L .55176 .51933 L F
.699 .314 .314 r
.55363 .51983 m .55406 .52157 L .55176 .51933 L F
.7 .602 .744 r
.23043 .68323 m .23258 .68398 L .23468 .68184 L F
.035 .493 .883 r
.80773 .44495 m .81064 .44667 L .80977 .44518 L F
.395 .661 .966 r
.80977 .44518 m .81064 .44667 L .81306 .44671 L F
.533 .167 .292 r
.4894 .54599 m .49316 .54351 L .49024 .54439 L F
.4894 .54599 m .49209 .54596 L .49316 .54351 L F
.249 0 0 r
.49209 .54596 m .49544 .54366 L .49316 .54351 L F
.697 .597 .741 r
.44208 .62908 m .44577 .63185 L .44533 .62834 L F
.583 .528 .759 r
.44533 .62834 m .44577 .63185 L .44847 .63105 L F
.589 .666 .892 r
.19802 .64097 m .19755 .63653 L .19506 .63705 L F
.495 .706 .964 r
.20062 .64083 m .20276 .64058 L .20226 .64028 L F
.589 .666 .892 r
.19991 .63983 m .20075 .63999 L .2002 .6394 L F
.19933 .63903 m .2002 .6394 L .19755 .63653 L F
.19991 .63983 m .2002 .6394 L .19933 .63903 L F
.867 .424 .044 r
.19755 .63653 m .20075 .63999 L .19863 .63805 L F
.495 .706 .964 r
.19991 .63983 m .20075 .63999 L .19863 .63805 L F
.20062 .64083 m .20139 .64057 L .19991 .63983 L F
.20139 .64057 m .20226 .64028 L .20075 .63999 L F
.20139 .64057 m .20075 .63999 L .19991 .63983 L F
.867 .424 .044 r
.19755 .63653 m .20075 .63999 L .19863 .63805 L F
.20075 .63999 m .20131 .6406 L .19863 .63805 L F
.20075 .63999 m .20131 .6406 L .19863 .63805 L F
.495 .706 .964 r
.20075 .63999 m .20226 .64028 L .19863 .63805 L F
.297 .633 .964 r
.20226 .64028 m .20313 .63919 L .19863 .63805 L F
.20276 .64058 m .20278 .6405 L .20226 .64028 L F
.20278 .6405 m .20313 .63919 L .20226 .64028 L F
.589 .666 .892 r
.19778 .63868 m .19991 .63983 L .19755 .63653 L F
.19991 .63983 m .20131 .6406 L .20075 .63999 L F
.495 .706 .964 r
.20062 .64083 m .19991 .63983 L .20131 .6406 L F
.19991 .63983 m .19863 .63805 L .20131 .6406 L F
.589 .666 .892 r
.19802 .64097 m .20131 .6406 L .19778 .63868 L F
.664 .698 .872 r
.19802 .64097 m .20062 .64083 L .20131 .6406 L F
.528 .404 .655 r
.30442 .61049 m .30233 .61364 L .30201 .61108 L F
0 0 0 r
.81152 .40614 m .81407 .40593 L .81051 .40625 L F
.539 .481 .739 r
.2724 .59227 m .27483 .59178 L .27392 .59016 L F
.428 .229 .506 r
.27237 .59509 m .27483 .59178 L .2724 .59227 L F
.472 .681 .957 r
.43967 .64764 m .44237 .64762 L .44078 .6459 L F
.306 .756 .958 r
.54622 .60145 m .54242 .601 L .54383 .6021 L F
.667 .415 .53 r
.4731 .63114 m .47649 .62872 L .47333 .62943 L F
.06 .365 .834 r
.2565 .55539 m .25824 .55698 L .25674 .55467 L F
.668 .269 .28 r
.55126 .50769 m .55126 .50923 L .55508 .50921 L F
.787 .333 0 r
.50587 .58175 m .50796 .58533 L .50906 .58629 L F
.946 .603 .335 r
.50781 .58766 m .50906 .58629 L .50796 .58533 L F
.50781 .58766 m .50947 .58875 L .50906 .58629 L F
.389 .713 .987 r
.23644 .67012 m .23844 .67149 L .23594 .67149 L F
.23644 .67012 m .23844 .67149 L .23594 .67149 L F
.529 .341 .57 r
.23594 .67149 m .23844 .67149 L .23598 .67422 L F
0 0 .108 r
.23624 .67272 m .23598 .67422 L .23594 .67149 L F
.23624 .67272 m .23594 .67149 L .23381 .67332 L F
.743 .95 .638 r
.23644 .67012 m .23594 .67149 L .23381 .67332 L F
.847 .708 .709 r
.56874 .54908 m .57061 .54992 L .56925 .54645 L F
.844 .635 .619 r
.56874 .54908 m .57053 .55252 L .57061 .54992 L F
.722 .669 .797 r
.55325 .57065 m .54962 .57112 L .55216 .56867 L F
.635 .101 0 r
.55204 .5735 m .54962 .57112 L .55325 .57065 L F
.629 .599 .8 r
.55453 .56748 m .55325 .57065 L .55216 .56867 L F
.55453 .56748 m .55595 .57097 L .55325 .57065 L F
.719 .456 .528 r
.5558 .57355 m .55325 .57065 L .55595 .57097 L F
.5558 .57355 m .55204 .5735 L .55325 .57065 L F
.48 .586 .882 r
.17718 .62606 m .17908 .62928 L .18057 .62781 L F
.432 .506 .835 r
.17908 .62928 m .18182 .6303 L .18057 .62781 L F
.435 .559 .881 r
.19008 .61453 m .18915 .61665 L .18721 .6138 L F
.19008 .61453 m .19134 .61678 L .18915 .61665 L F
.644 .789 .952 r
.8303 .40773 m .83379 .40872 L .83364 .4061 L F
.726 .829 .929 r
.83379 .40872 m .83549 .40525 L .83364 .4061 L F
.83379 .40872 m .8366 .4068 L .83549 .40525 L F
.865 .711 .689 r
.53303 .57096 m .53381 .56841 L .53168 .56814 L F
.482 .34 .612 r
.3235 .5529 m .32371 .55542 L .32153 .55597 L F
.511 .418 .686 r
.32371 .55542 m .3219 .55848 L .32153 .55597 L F
.085 0 0 r
.16951 .55586 m .16992 .55716 L .17167 .55534 L F
.16951 .55586 m .16803 .55796 L .16992 .55716 L F
.695 .712 .861 r
.23054 .68046 m .23043 .68323 L .23332 .6793 L F
.7 .602 .744 r
.23043 .68323 m .23468 .68184 L .23332 .6793 L F
.571 .505 .743 r
.76428 .42264 m .76596 .41712 L .76342 .42058 L F
.76428 .42264 m .76668 .42207 L .76596 .41712 L F
.766 .585 .014 r
.51101 .61992 m .51094 .62075 L .5109 .61983 L F
.408 .713 .986 r
.509 .61971 m .51101 .61992 L .51085 .61881 L F
.766 .585 .014 r
.51101 .61992 m .5109 .61983 L .51085 .61881 L F
0 .544 .744 r
.51106 .61996 m .51101 .61992 L .509 .61971 L F
.51276 .62016 m .51101 .61992 L .51106 .61996 L F
.421 .828 .976 r
.51276 .62016 m .5146 .61906 L .51101 .61992 L F
.51276 .62016 m .51566 .61965 L .5146 .61906 L F
.878 .904 .844 r
.76774 .39976 m .76883 .40099 L .77144 .39781 L F
.762 .25 0 r
.76867 .4021 m .76883 .40099 L .76774 .39976 L F
.76867 .4021 m .77044 .40289 L .76883 .40099 L F
.539 .55 .814 r
.25443 .66125 m .25359 .66573 L .2516 .66196 L F
.25443 .66125 m .25592 .66521 L .25359 .66573 L F
0 0 0 r
.25306 .66671 m .25359 .66573 L .25592 .66521 L F
.25306 .66671 m .25238 .66764 L .25359 .66573 L F
.695 .166 0 r
.52319 .55519 m .52466 .55535 L .52326 .55265 L F
.741 .81 .907 r
.18263 .79003 m .18145 .78665 L .18129 .78671 L F
.18263 .79003 m .18321 .78665 L .18145 .78665 L F
.18263 .79003 m .18368 .78697 L .18321 .78665 L F
.419 .561 .89 r
.77945 .43716 m .78131 .43996 L .78275 .43809 L F
.329 .43 .814 r
.78275 .43809 m .78131 .43996 L .78326 .4405 L F
.76 .714 .809 r
.55706 .57618 m .55311 .57641 L .5558 .57355 L F
.813 .734 .777 r
.55771 .5748 m .55706 .57618 L .5558 .57355 L F
.86 .763 .754 r
.56148 .55533 m .55789 .55742 L .56056 .55465 L F
.56148 .55533 m .5594 .55877 L .55789 .55742 L F
.962 .765 .59 r
.49297 .54932 m .4894 .54599 L .49009 .5478 L F
.165 0 .368 r
.27009 .59853 m .2721 .59754 L .27237 .59509 L F
.146 0 .329 r
.27009 .59853 m .26991 .60093 L .2721 .59754 L F
.662 .541 .706 r
.32627 .56746 m .32039 .56518 L .32298 .56447 L F
.32627 .56746 m .32072 .56791 L .32039 .56518 L F
.608 .79 .968 r
.82417 .39676 m .82255 .39906 L .82148 .3975 L F
.82417 .39676 m .82521 .39824 L .82255 .39906 L F
.875 .994 .782 r
.44781 .5833 m .44463 .58559 L .44541 .58645 L F
.967 .881 .495 r
.44463 .58559 m .44461 .58581 L .44541 .58645 L F
.708 .578 .707 r
.45748 .6388 m .45723 .64104 L .45946 .63786 L F
.64 .486 .658 r
.45946 .63786 m .45723 .64104 L .45983 .64073 L F
.683 .585 .739 r
.45946 .63786 m .46431 .63889 L .462 .63495 L F
.718 .575 .693 r
.45983 .64073 m .46431 .63889 L .45946 .63786 L F
.714 .691 .826 r
.66342 .42743 m .66723 .42817 L .66612 .42473 L F
.708 .688 .828 r
.66612 .42473 m .66723 .42817 L .66943 .42727 L F
.61 .375 .536 r
.42342 .66509 m .4261 .66431 L .42762 .66226 L F
.171 .708 .754 r
.27877 .53766 m .2811 .53724 L .28248 .5371 L F
.354 .807 .944 r
.2811 .53724 m .28493 .53719 L .28248 .5371 L F
.601 .594 .816 r
.45341 .638 m .45723 .64104 L .45748 .6388 L F
.525 .287 .496 r
.45725 .6437 m .45983 .64073 L .45723 .64104 L F
.593 .632 .86 r
.8278 .40866 m .8293 .40524 L .82659 .40617 L F
.8278 .40866 m .8303 .40773 L .8293 .40524 L F
.657 .533 .701 r
.47413 .64632 m .47105 .64434 L .47371 .6441 L F
.583 .526 .756 r
.47568 .64022 m .47723 .64411 L .47371 .6441 L F
.042 0 0 r
.47723 .64411 m .47413 .64632 L .47371 .6441 L F
.258 .582 .944 r
.22042 .62929 m .2173 .62766 L .21893 .6277 L F
.697 .861 .96 r
.22112 .62719 m .22042 .62929 L .21893 .6277 L F
.22112 .62719 m .22265 .62811 L .22042 .62929 L F
.838 .667 .671 r
.56267 .53128 m .56444 .53493 L .56231 .53391 L F
.992 .8 .545 r
.56069 .54984 m .56128 .5508 L .55929 .54891 L F
0 .054 .577 r
.53829 .57756 m .53925 .57706 L .53928 .57636 L F
.693 .706 .857 r
.53935 .57651 m .54229 .57981 L .5411 .58013 L F
.53928 .57636 m .5411 .58013 L .53925 .57706 L F
.1 .369 .833 r
.53749 .57581 m .53893 .57654 L .53829 .57756 L F
0 .054 .577 r
.53925 .57706 m .5396 .57687 L .53928 .57636 L F
.1 .369 .833 r
.53893 .57654 m .5396 .57687 L .53925 .57706 L F
.693 .706 .857 r
.5392 .57645 m .5392 .57698 L .53829 .57756 L F
.53928 .57636 m .53926 .57652 L .5392 .57645 L F
.53926 .57652 m .5392 .57698 L .5392 .57645 L F
.1 .369 .833 r
.53893 .57654 m .5392 .57698 L .53829 .57756 L F
.693 .706 .857 r
.53928 .57636 m .5391 .58066 L .53872 .58076 L F
.539 .094 .141 r
.53596 .57711 m .53952 .57688 L .53893 .57654 L F
.53952 .57688 m .5396 .57687 L .53947 .5768 L F
.53952 .57688 m .53947 .5768 L .53893 .57654 L F
.1 .369 .833 r
.5392 .57698 m .53925 .57706 L .53829 .57756 L F
.693 .706 .857 r
.5392 .57698 m .53872 .58076 L .53829 .57756 L F
.539 .094 .141 r
.53647 .57668 m .53893 .57654 L .53749 .57581 L F
.53596 .57711 m .53893 .57654 L .53647 .57668 L F
.693 .706 .857 r
.53928 .57636 m .53941 .57651 L .53935 .57651 L F
.53941 .57651 m .54229 .57981 L .53935 .57651 L F
.53925 .57706 m .5411 .58013 L .5391 .58066 L F
.101 .138 .614 r
.17342 .59678 m .17235 .5994 L .17093 .59793 L F
.562 .371 .58 r
.32072 .56791 m .32077 .57046 L .31825 .57085 L F
.601 .357 .519 r
.32627 .56746 m .32077 .57046 L .32072 .56791 L F
.641 .668 .86 r
.54901 .58325 m .54595 .58512 L .54491 .58257 L F
.181 .427 .86 r
.15471 .61023 m .15694 .6134 L .1573 .61185 L F
.13 .369 .827 r
.15694 .6134 m .15822 .61362 L .1573 .61185 L F
.436 .518 .844 r
.15694 .6134 m .16037 .61667 L .15822 .61362 L F
.354 0 0 r
.54147 .5198 m .54023 .52119 L .53766 .52135 L F
.457 0 0 r
.5448 .52078 m .54147 .5198 L .54409 .5196 L F
.5448 .52078 m .54023 .52119 L .54147 .5198 L F
.52 .297 .516 r
.31564 .59428 m .31405 .59247 L .31549 .59164 L F
.31564 .59428 m .31337 .59478 L .31405 .59247 L F
.984 .805 .582 r
.51424 .61641 m .51635 .61676 L .51402 .61586 L F
.51424 .61641 m .51566 .61965 L .51635 .61676 L F
.208 0 0 r
.47105 .64434 m .46855 .64606 L .46716 .64648 L F
.737 .988 .796 r
.47187 .64286 m .46855 .64606 L .47105 .64434 L F
.657 .533 .701 r
.47413 .64632 m .47107 .64712 L .47105 .64434 L F
.338 .362 .74 r
.47107 .64712 m .47187 .64286 L .47105 .64434 L F
.529 .412 .664 r
.32077 .57046 m .31888 .57527 L .31825 .57085 L F
.047 0 .049 r
.23118 .69243 m .22855 .69315 L .23107 .69344 L F
.685 .904 .974 r
.23114 .69239 m .22923 .69163 L .23109 .69242 L F
.23358 .69115 m .2299 .69155 L .23114 .69239 L F
.2299 .69155 m .22923 .69163 L .23114 .69239 L F
.23358 .69115 m .23109 .69242 L .23115 .69242 L F
.569 .459 .689 r
.23419 .69101 m .23121 .69239 L .23136 .69085 L F
.506 .521 .806 r
.23118 .69243 m .23121 .69237 L .23136 .69085 L F
.247 .167 .565 r
.23109 .69242 m .22923 .69163 L .23136 .69085 L F
.047 0 .049 r
.23136 .69085 m .22964 .69226 L .23109 .69242 L F
.23136 .69085 m .23109 .69242 L .23118 .69243 L F
.22964 .69226 m .22855 .69315 L .23118 .69243 L F
.685 .904 .974 r
.23115 .69242 m .23109 .69242 L .23113 .69243 L F
.247 .167 .565 r
.23113 .69243 m .23109 .69242 L .23136 .69085 L F
.569 .459 .689 r
.23121 .69239 m .23113 .69243 L .23136 .69085 L F
.23419 .69101 m .23136 .69085 L .23233 .69031 L F
.506 .521 .806 r
.23121 .69237 m .23233 .69031 L .23136 .69085 L F
.23107 .69344 m .23142 .69258 L .23118 .69243 L F
0 0 0 r
.23575 .69049 m .23358 .69115 L .23117 .69241 L F
.23118 .69241 m .23117 .69241 L .23113 .69243 L F
.23575 .69049 m .23117 .69241 L .23118 .69241 L F
.506 .521 .806 r
.23142 .69258 m .23151 .69234 L .23118 .69243 L F
0 0 0 r
.23575 .69049 m .23118 .69241 L .23419 .69101 L F
.23118 .69241 m .23113 .69243 L .23121 .69239 L F
.23118 .69241 m .23121 .69239 L .23419 .69101 L F
.506 .521 .806 r
.23151 .69234 m .23157 .6922 L .23119 .69241 L F
.23157 .6922 m .23233 .69031 L .2312 .6924 L F
.23157 .6922 m .2312 .6924 L .23119 .69241 L F
.23151 .69234 m .23119 .69241 L .23118 .69243 L F
.951 .74 .581 r
.45777 .65995 m .45871 .66232 L .45553 .66185 L F
.818 .773 .811 r
.45876 .66504 m .45553 .66185 L .45871 .66232 L F
0 0 .443 r
.45849 .66113 m .45871 .66232 L .45777 .65995 L F
.817 .418 .295 r
.45849 .66113 m .46122 .66277 L .45871 .66232 L F
.579 .399 .601 r
.46025 .66351 m .45871 .66232 L .46122 .66277 L F
.46151 .66449 m .45876 .66504 L .45871 .66232 L F
.817 .418 .295 r
.46003 .66205 m .45961 .66353 L .46122 .66277 L F
.45849 .66113 m .45961 .66353 L .46003 .66205 L F
.764 .505 .542 r
.45961 .66353 m .462 .66218 L .46122 .66277 L F
.462 .66218 m .46349 .66134 L .46122 .66277 L F
.579 .399 .601 r
.46151 .66449 m .46025 .66351 L .46122 .66277 L F
.32 .149 .485 r
.46349 .66134 m .46151 .66449 L .46122 .66277 L F
.46349 .66134 m .46345 .66404 L .46151 .66449 L F
.764 .505 .542 r
.45961 .66353 m .46345 .66404 L .46349 .66134 L F
.777 .658 .732 r
.46151 .66449 m .45854 .66752 L .45876 .66504 L F
.46151 .66449 m .46243 .66792 L .45854 .66752 L F
0 0 .464 r
.46258 .66665 m .46243 .66792 L .46151 .66449 L F
.46258 .66665 m .46151 .66449 L .46345 .66404 L F
.861 .725 .711 r
.45902 .66532 m .46345 .66404 L .45961 .66353 L F
.388 .323 .662 r
.46057 .66214 m .45921 .66494 L .45961 .66353 L F
.45921 .66494 m .45902 .66532 L .45961 .66353 L F
.543 0 0 r
.75794 .38395 m .75853 .38306 L .75774 .38138 L F
.024 .444 .871 r
.76283 .38572 m .75853 .38306 L .76172 .38455 L F
.543 0 0 r
.75794 .38395 m .76172 .38455 L .75853 .38306 L F
.404 .794 .989 r
.24999 .53617 m .25243 .53585 L .2543 .53662 L F
.138 .618 .919 r
.25243 .53585 m .25621 .53703 L .2543 .53662 L F
0 0 0 r
.53766 .51637 m .53843 .51676 L .53976 .51521 L F
.53766 .51637 m .53643 .51797 L .53843 .51676 L F
.695 .421 .505 r
.48628 .62169 m .48983 .62084 L .48648 .62007 L F
.626 .605 .81 r
.8177 .40671 m .8213 .40921 L .82034 .40605 L F
.645 .641 .831 r
.82034 .40605 m .8213 .40921 L .82418 .40732 L F
.669 .951 .707 r
.55216 .56867 m .55019 .57057 L .55066 .56955 L F
.608 .927 .694 r
.55216 .56867 m .55066 .56955 L .5538 .56687 L F
.704 .819 .366 r
.55066 .56955 m .55239 .56563 L .5538 .56687 L F
0 0 .121 r
.55066 .56955 m .55097 .57013 L .55113 .56855 L F
.704 .819 .366 r
.55066 .56955 m .55117 .56819 L .55239 .56563 L F
0 0 .121 r
.55066 .56955 m .55113 .56855 L .55117 .56819 L F
.669 .951 .707 r
.55019 .57057 m .54962 .57112 L .55066 .56955 L F
0 0 .113 r
.54962 .57112 m .55068 .57204 L .55066 .56955 L F
.635 .101 0 r
.55204 .5735 m .55039 .57246 L .55038 .57246 L F
.55162 .57309 m .55038 .57246 L .54962 .57112 L F
.55204 .5735 m .55038 .57246 L .55162 .57309 L F
.877 .982 .832 r
.55022 .57237 m .54831 .57499 L .54728 .57443 L F
0 0 .113 r
.54962 .57112 m .55039 .57246 L .55068 .57204 L F
.877 .982 .832 r
.55068 .57204 m .55036 .57244 L .55022 .57237 L F
.55036 .57244 m .54831 .57499 L .55022 .57237 L F
.94 .843 .404 r
.5668 .59946 m .56663 .60019 L .56718 .60036 L F
.876 .972 .845 r
.56542 .60181 m .56757 .60048 L .56718 .60036 L F
0 0 0 r
.56622 .60203 m .56542 .60181 L .56718 .60036 L F
.94 .843 .404 r
.56663 .60019 m .56622 .60203 L .56718 .60036 L F
.876 .972 .845 r
.56757 .60048 m .56844 .59994 L .56718 .60036 L F
.629 .827 .976 r
.81827 .42887 m .8167 .43105 L .81574 .42964 L F
.81827 .42887 m .81933 .43014 L .8167 .43105 L F
.424 .137 .372 r
.47358 .61409 m .47307 .6161 L .47074 .61666 L F
.466 .181 .396 r
.47607 .61268 m .47307 .6161 L .47358 .61409 L F
.698 .841 .952 r
.27117 .55022 m .26887 .55199 L .27233 .55213 L F
.536 .153 .262 r
.26876 .55468 m .27233 .55213 L .26887 .55199 L F
.26876 .55468 m .27128 .55467 L .27233 .55213 L F
.485 .803 1 r
.27233 .55213 m .27117 .5501 L .27117 .55022 L F
.414 .059 .251 r
.27128 .55467 m .2754 .55149 L .27233 .55213 L F
.27128 .55467 m .27407 .55426 L .2754 .55149 L F
.581 .828 .992 r
.27117 .5501 m .2754 .55149 L .27421 .55027 L F
.485 .803 1 r
.2749 .55159 m .2754 .55149 L .27475 .55127 L F
0 0 0 r
.2754 .55149 m .27407 .55426 L .27584 .55265 L F
.2754 .55149 m .27584 .55265 L .27421 .55027 L F
0 0 .455 r
.27411 .55 m .27584 .55265 L .27385 .54939 L F
.27421 .55027 m .27431 .5504 L .27411 .55 L F
.27431 .5504 m .27584 .55265 L .27411 .55 L F
.485 .803 1 r
.27233 .55213 m .2749 .55159 L .27117 .5501 L F
.2749 .55159 m .27475 .55127 L .27117 .5501 L F
.634 .825 .974 r
.83043 .39638 m .82873 .39861 L .82782 .39736 L F
.83043 .39638 m .83134 .39767 L .82873 .39861 L F
.984 .892 .648 r
.45091 .64386 m .45073 .64368 L .45177 .64137 L F
.996 .855 .523 r
.49392 .65279 m .49328 .65486 L .4947 .65319 L F
.699 .97 .929 r
.4947 .65319 m .49392 .65279 L .49525 .65159 L F
.755 .908 .525 r
.49525 .65159 m .49328 .65486 L .4947 .65319 L F
.649 .404 .535 r
.21054 .7203 m .21373 .71973 L .21411 .71703 L F
.487 .261 .496 r
.21373 .71973 m .21599 .71925 L .21411 .71703 L F
.461 .198 .428 r
.29986 .61667 m .29935 .61914 L .29706 .61964 L F
.464 .252 .505 r
.30233 .61364 m .30211 .61612 L .29986 .61667 L F
.473 .209 .432 r
.30169 .61859 m .29986 .61667 L .30211 .61612 L F
.30169 .61859 m .29935 .61914 L .29986 .61667 L F
.705 .932 .964 r
.82459 .44206 m .82522 .44302 L .82768 .44153 L F
.338 .362 .74 r
.47107 .64712 m .47316 .64645 L .47187 .64286 L F
.465 .183 .401 r
.47305 .64874 m .47107 .64712 L .47413 .64632 L F
.47107 .64712 m .47305 .64874 L .47316 .64645 L F
.47107 .64712 m .47082 .64968 L .47305 .64874 L F
.47305 .64874 m .47082 .64968 L .47107 .64712 L F
.674 .798 .941 r
.32283 .55002 m .32043 .55158 L .31862 .54961 L F
.718 .791 .909 r
.78628 .42319 m .78462 .42586 L .78302 .42399 L F
.78628 .42319 m .78679 .42501 L .78462 .42586 L F
.648 .5 .668 r
.78679 .42501 m .78433 .4281 L .78462 .42586 L F
.819 .753 .79 r
.55231 .58332 m .54901 .58325 L .55114 .58013 L F
.792 .74 .805 r
.5549 .58032 m .55231 .58332 L .55114 .58013 L F
.8 .677 .13 r
.1844 .79791 m .18472 .79607 L .18377 .79603 L F
.1844 .79791 m .18454 .79874 L .18472 .79607 L F
.657 .454 .597 r
.43307 .67443 m .43306 .6773 L .4305 .67693 L F
0 0 .134 r
.43466 .67086 m .43307 .67443 L .43236 .67191 L F
.43466 .67086 m .43398 .67365 L .43307 .67443 L F
.01 .085 .595 r
.43398 .67365 m .43466 .67637 L .43307 .67443 L F
.262 .141 .519 r
.43466 .67637 m .43306 .6773 L .43307 .67443 L F
.214 0 0 r
.50574 .54934 m .50857 .54886 L .50992 .54752 L F
0 0 0 r
.50992 .54752 m .50857 .54886 L .51039 .54736 L F
.45 .812 .996 r
.21714 .64307 m .21749 .64163 L .21642 .64189 L F
.21714 .64307 m .21887 .64275 L .21749 .64163 L F
.206 .733 .799 r
.23122 .64372 m .23303 .64362 L .23545 .64316 L F
.048 .568 .871 r
.23303 .64362 m .23576 .64416 L .23545 .64316 L F
.731 .741 .86 r
.79071 .43033 m .79427 .43085 L .79207 .43191 L F
.835 .711 .726 r
.56974 .5402 m .57184 .5409 L .57055 .5373 L F
.899 .729 .662 r
.56974 .5402 m .57111 .54324 L .57184 .5409 L F
.249 0 0 r
.20013 .54297 m .20237 .54248 L .204 .54058 L F
.201 0 0 r
.204 .54058 m .20456 .54188 L .20637 .53888 L F
.204 .54058 m .20244 .54239 L .20456 .54188 L F
.16 0 0 r
.20456 .54188 m .20872 .53977 L .20637 .53888 L F
.20456 .54188 m .20681 .54137 L .20872 .53977 L F
.251 0 0 r
.20278 .5418 m .20654 .5414 L .20456 .54188 L F
.20654 .5414 m .20681 .54137 L .20456 .54188 L F
.201 0 0 r
.20244 .54239 m .20237 .54248 L .20456 .54188 L F
.991 .737 .423 r
.77026 .39651 m .77144 .39781 L .77026 .39414 L F
.878 .904 .844 r
.76774 .39976 m .77144 .39781 L .77026 .39651 L F
.273 0 .145 r
.45097 .62234 m .4547 .62152 L .45554 .6194 L F
.396 .21 .508 r
.45097 .62234 m .45447 .62392 L .4547 .62152 L F
.352 .575 .925 r
.21893 .6277 m .2173 .62766 L .21497 .62504 L F
.784 .553 .586 r
.57193 .56153 m .57343 .56447 L .57493 .56192 L F
.662 .968 .794 r
.18927 .5641 m .18601 .56642 L .18776 .56552 L F
.136 0 .154 r
.25841 .61654 m .26032 .61587 L .26113 .61358 L F
.244 0 .101 r
.26032 .61587 m .26347 .61315 L .26113 .61358 L F
.446 .302 .591 r
.30935 .60429 m .30941 .60694 L .30736 .60751 L F
.481 .205 .417 r
.30918 .60942 m .30736 .60751 L .30941 .60694 L F
.30918 .60942 m .3068 .60991 L .30736 .60751 L F
.528 .404 .655 r
.30442 .61049 m .30461 .61312 L .30233 .61364 L F
.569 .38 .586 r
.30461 .61312 m .30211 .61612 L .30233 .61364 L F
.671 .28 .296 r
.56122 .50989 m .56377 .51187 L .5652 .50984 L F
.775 .41 .366 r
.56377 .51187 m .56717 .51238 L .5652 .50984 L F
.72 .415 .461 r
.5652 .50984 m .56717 .51238 L .56684 .51055 L F
.768 .638 .717 r
.5744 .53128 m .57278 .53421 L .5771 .53355 L F
.18 0 0 r
.18472 .56808 m .18236 .5696 L .1803 .56984 L F
.706 .964 .715 r
.18581 .56614 m .18472 .56808 L .18601 .56642 L F
.706 .965 .719 r
.18581 .56614 m .18236 .5696 L .18472 .56808 L F
.005 0 0 r
.2526 .54903 m .2483 .55025 L .25033 .5495 L F
.32 .79 .928 r
.22648 .62801 m .22265 .62811 L .22488 .62756 L F
.305 .776 .933 r
.22711 .6274 m .22648 .62801 L .22488 .62756 L F
.22711 .6274 m .22874 .62776 L .22648 .62801 L F
.912 .978 .778 r
.18657 .78658 m .18809 .78494 L .18544 .78625 L F
0 0 .135 r
.25238 .66764 m .25046 .6704 L .25108 .6685 L F
.848 .392 .01 r
.50643 .58435 m .50587 .58175 L .50394 .58162 L F
.50643 .58435 m .50796 .58533 L .50587 .58175 L F
.087 .467 .89 r
.48863 .56856 m .48856 .56686 L .48683 .56622 L F
.701 .244 .163 r
.49809 .57996 m .49998 .58216 L .49599 .5815 L F
.875 .889 .84 r
.44869 .57908 m .44781 .5833 L .44946 .58115 L F
.44869 .57908 m .44597 .58213 L .44781 .5833 L F
.948 .843 .705 r
.44597 .58213 m .44463 .58559 L .44781 .5833 L F
.473 .193 .408 r
.28896 .62857 m .2861 .63118 L .28663 .62902 L F
.839 .658 .656 r
.57051 .55511 m .57206 .55873 L .57362 .55582 L F
.278 .398 .805 r
.77522 .42955 m .7753 .43155 L .77699 .42972 L F
.286 .409 .812 r
.7753 .43155 m .77823 .43317 L .77699 .42972 L F
.396 .231 .537 r
.14482 .57413 m .14648 .57608 L .14669 .57344 L F
.343 .221 .567 r
.14488 .57676 m .14648 .57608 L .14482 .57413 L F
.439 .341 .648 r
.13792 .58892 m .13951 .58542 L .13797 .58627 L F
.579 .877 .993 r
.81608 .44625 m .81707 .44721 L .81987 .44621 L F
.444 .654 .949 r
.2871 .5372 m .28572 .53838 L .28493 .53719 L F
.2871 .5372 m .28912 .53904 L .28572 .53838 L F
.899 .729 .662 r
.56974 .5402 m .56823 .54322 L .57111 .54324 L F
.895 .787 .735 r
.56823 .54322 m .56925 .54645 L .57111 .54324 L F
.579 .4 .603 r
.44025 .57927 m .44266 .57899 L .44306 .57706 L F
.518 .452 .722 r
.44025 .57927 m .44354 .58252 L .44266 .57899 L F
.44025 .57927 m .44128 .58325 L .44354 .58252 L F
.281 0 .012 r
.17361 .55427 m .1773 .55223 L .17509 .55288 L F
.204 0 .141 r
.16394 .55939 m .16494 .56029 L .16581 .55861 L F
.16394 .55939 m .16296 .56116 L .16494 .56029 L F
.419 .134 .373 r
.29475 .62247 m .29397 .62526 L .29179 .62543 L F
.523 .351 .59 r
.29706 .61964 m .29707 .62207 L .29475 .62247 L F
.465 .177 .391 r
.29661 .62442 m .29475 .62247 L .29707 .62207 L F
.29661 .62442 m .29397 .62526 L .29475 .62247 L F
0 0 .218 r
.26756 .64236 m .26666 .64128 L .26904 .64087 L F
.26756 .64236 m .26652 .64347 L .26666 .64128 L F
.826 .528 0 r
.4612 .60454 m .46169 .60686 L .46142 .60469 L F
.57 .789 .982 r
.8177 .40671 m .81932 .40465 L .81668 .40544 L F
.8177 .40671 m .82034 .40605 L .81932 .40465 L F
.088 0 0 r
.1773 .55223 m .17917 .55152 L .18062 .54953 L F
.023 0 0 r
.18062 .54953 m .1809 .55077 L .18286 .54917 L F
.18062 .54953 m .17917 .55152 L .1809 .55077 L F
.833 .617 .61 r
.56097 .52536 m .55765 .52472 L .55778 .5221 L F
.876 .574 .474 r
.5607 .52788 m .55765 .52472 L .56097 .52536 L F
.511 .418 .686 r
.32371 .55542 m .32414 .55809 L .3219 .55848 L F
.512 .41 .675 r
.32414 .55809 m .32226 .56264 L .3219 .55848 L F
.8 .677 .13 r
.1844 .79791 m .18377 .79603 L .18214 .79759 L F
.923 .944 .794 r
.20569 .74065 m .20417 .74507 L .20505 .74336 L F
.18 .314 .764 r
.20417 .74507 m .20637 .74704 L .20505 .74336 L F
.489 .609 .898 r
.18547 .63365 m .18663 .63551 L .18872 .63513 L F
.72 .598 .719 r
.462 .63495 m .4659 .63788 L .46444 .63433 L F
.462 .63495 m .46431 .63889 L .4659 .63788 L F
.697 .55 .683 r
.46431 .63889 m .46336 .6409 L .4659 .63788 L F
.582 .388 .584 r
.46336 .6409 m .46598 .64058 L .4659 .63788 L F
.572 .517 .755 r
.4659 .63788 m .4684 .63587 L .46444 .63433 L F
.4659 .63788 m .46843 .63745 L .4684 .63587 L F
.511 .333 .576 r
.4659 .63788 m .46829 .64003 L .46843 .63745 L F
.4659 .63788 m .46598 .64058 L .46829 .64003 L F
.533 .544 .813 r
.23468 .68184 m .23618 .6794 L .23332 .6793 L F
.23468 .68184 m .2376 .68259 L .23618 .6794 L F
.705 .637 .778 r
.80678 .43045 m .80447 .43139 L .80297 .42805 L F
.866 .701 .675 r
.75925 .38755 m .76283 .38572 L .76172 .38455 L F
.75925 .38755 m .76228 .38786 L .76283 .38572 L F
.501 .255 .473 r
.1651 .5799 m .16456 .58256 L .16227 .58286 L F
.463 .361 .654 r
.16677 .57635 m .16709 .57938 L .1651 .5799 L F
.387 .153 .433 r
.16709 .57938 m .16456 .58256 L .1651 .5799 L F
.546 .62 .878 r
.83563 .40118 m .83134 .39767 L .83397 .39677 L F
.623 .628 .835 r
.83665 .39599 m .83563 .40118 L .83397 .39677 L F
.83665 .39599 m .84011 .40131 L .83563 .40118 L F
.876 .823 .792 r
.79214 .40041 m .78987 .40049 L .79217 .39828 L F
.817 .338 0 r
.79214 .40041 m .79215 .40185 L .78987 .40049 L F
.79214 .40041 m .79405 .40309 L .79215 .40185 L F
.706 .667 .809 r
.48019 .63413 m .47665 .63137 L .48058 .63148 L F
0 0 0 r
.48316 .63195 m .48019 .63413 L .48058 .63148 L F
.326 .248 .613 r
.4595 .65929 m .45777 .65995 L .45754 .65633 L F
.052 .616 .775 r
.3011 .54189 m .30496 .54204 L .30263 .54299 L F
.693 .24 .171 r
.25964 .55627 m .25674 .55467 L .25824 .55698 L F
0 0 .28 r
.26521 .60965 m .26719 .60624 L .266 .6075 L F
.455 .479 .795 r
.19856 .76973 m .19753 .77189 L .19619 .76817 L F
.849 .967 .876 r
.19378 .77247 m .19753 .77189 L .19856 .76973 L F
.718 .575 .693 r
.45983 .64073 m .46336 .6409 L .46431 .63889 L F
.731 .624 .738 r
.49449 .62276 m .49206 .6262 L .49401 .62503 L F
.613 .052 0 r
.50048 .55313 m .50276 .55519 L .49961 .55326 L F
.667 .124 0 r
.50454 .55543 m .50276 .55519 L .50048 .55313 L F
.508 .227 .422 r
.22191 .55317 m .22132 .55476 L .21934 .5533 L F
0 0 0 r
.2196 .5532 m .21934 .5533 L .22132 .55476 L F
.2196 .5532 m .21779 .55477 L .21934 .5533 L F
.817 .588 .591 r
.56717 .51238 m .57131 .51593 L .57131 .51306 L F
.817 .598 .607 r
.57131 .51593 m .57269 .51622 L .57131 .51306 L F
.847 .688 .686 r
.52701 .55848 m .5283 .56175 L .52886 .55919 L F
.789 .811 .87 r
.21333 .72266 m .21859 .7209 L .21599 .71925 L F
.816 .806 .842 r
.21599 .71925 m .21859 .7209 L .21956 .7188 L F
.931 .561 .284 r
.51289 .56096 m .51073 .55789 L .51255 .55869 L F
.316 0 .036 r
.19287 .56214 m .19147 .56377 L .18927 .5641 L F
.176 0 0 r
.19364 .56307 m .19287 .56214 L .19491 .56142 L F
.19364 .56307 m .19147 .56377 L .19287 .56214 L F
.361 .688 .981 r
.21323 .62367 m .21305 .62516 L .21099 .62415 L F
.21323 .62367 m .21497 .62504 L .21305 .62516 L F
.721 .887 .957 r
.43886 .58596 m .43547 .58632 L .43754 .58537 L F
.444 .336 .637 r
.32221 .57512 m .31962 .57652 L .31888 .57527 L F
.32221 .57512 m .32155 .57616 L .31962 .57652 L F
.482 .38 .662 r
.32155 .57616 m .31987 .57952 L .31962 .57652 L F
.272 0 .119 r
.49523 .60092 m .49228 .60295 L .49318 .60209 L F
.543 .728 .96 r
.16037 .61667 m .1609 .61485 L .15822 .61362 L F
.16037 .61667 m .16256 .6162 L .1609 .61485 L F
.945 .687 .514 r
.50053 .60703 m .50028 .60994 L .50001 .60921 L F
.50001 .60921 m .50028 .60994 L .50053 .60703 L F
.491 .292 .536 r
.44174 .58505 m .44354 .58252 L .44128 .58325 L F
.608 .616 .834 r
.43605 .66821 m .43466 .67086 L .43445 .66789 L F
.886 .882 .823 r
.49054 .62477 m .49206 .6262 L .49449 .62276 L F
.97 .834 .652 r
.49054 .62477 m .48973 .62691 L .49206 .6262 L F
.761 .453 .464 r
.50528 .61539 m .50775 .61373 L .50481 .61375 L F
.50528 .61539 m .50785 .61605 L .50775 .61373 L F
.703 .406 .471 r
.50775 .61373 m .51122 .616 L .51052 .61283 L F
.50775 .61373 m .50785 .61605 L .51122 .616 L F
.869 .643 .594 r
.57343 .56447 m .57336 .56705 L .57667 .56788 L F
.888 .629 .54 r
.57336 .56705 m .57631 .57048 L .57667 .56788 L F
.355 0 0 r
.8089 .39762 m .81173 .39839 L .81253 .39785 L F
.243 0 0 r
.81173 .39839 m .81507 .39774 L .81253 .39785 L F
.697 .959 .706 r
.24285 .67003 m .24488 .66867 L .2418 .67168 L F
.675 .958 .726 r
.24659 .6671 m .24488 .66867 L .24535 .66766 L F
.678 .952 .701 r
.24535 .66766 m .24488 .66867 L .24285 .67003 L F
0 .089 .646 r
.22787 .70801 m .22803 .70633 L .22597 .70629 L F
.416 .21 .49 r
.22996 .70725 m .2296 .70989 L .22787 .70801 L F
0 .089 .646 r
.22787 .70801 m .2296 .70989 L .22803 .70633 L F
.091 0 .112 r
.25841 .61654 m .25584 .61929 L .25788 .61839 L F
.198 0 .298 r
.25788 .61839 m .26032 .61587 L .25841 .61654 L F
.708 .688 .828 r
.66612 .42473 m .66943 .42727 L .66851 .42391 L F
.697 .662 .812 r
.66943 .42727 m .67223 .42446 L .66851 .42391 L F
.771 .781 .861 r
.22693 .69785 m .23037 .70031 L .23091 .69776 L F
.682 .661 .823 r
.23037 .70031 m .23117 .698 L .23091 .69776 L F
.186 0 .218 r
.4547 .62152 m .45786 .61695 L .45554 .6194 L F
.535 .555 .823 r
.26806 .55827 m .26876 .55468 L .26619 .55531 L F
.26806 .55827 m .27034 .55794 L .26876 .55468 L F
.255 .763 .863 r
.21943 .53743 m .21912 .53796 L .21675 .53782 L F
.21943 .53743 m .22137 .53757 L .21912 .53796 L F
.642 .147 .06 r
.54993 .60213 m .54873 .60318 L .54622 .60145 L F
.588 .877 .568 r
.5512 .60057 m .54993 .60213 L .55241 .60144 L F
.5512 .60057 m .54873 .60318 L .54993 .60213 L F
.482 .332 .601 r
.3194 .58343 m .31803 .58602 L .31817 .5838 L F
.784 .671 .739 r
.26671 .55271 m .26359 .55474 L .26264 .55218 L F
.699 .249 .18 r
.26511 .5536 m .26749 .55408 L .26671 .55271 L F
.26749 .55408 m .2683 .55424 L .26819 .55413 L F
.26749 .55407 m .26759 .55408 L .26671 .55271 L F
.26759 .55408 m .26819 .55413 L .26782 .55377 L F
.26759 .55408 m .26782 .55377 L .26671 .55271 L F
.619 .958 .886 r
.26715 .55154 m .26671 .55271 L .26887 .55199 L F
.503 .301 .539 r
.26671 .55271 m .26876 .55468 L .26887 .55199 L F
.441 .854 .961 r
.26887 .55199 m .26947 .55094 L .26715 .55154 L F
.652 .841 .436 r
.26947 .55094 m .26758 .5541 L .26721 .5519 L F
.26947 .55094 m .26721 .5519 L .26715 .55154 L F
.309 .78 .669 r
.27167 .54995 m .26947 .55094 L .27117 .55022 L F
.328 0 .16 r
.27167 .54995 m .27152 .55007 L .26947 .55094 L F
.652 .841 .436 r
.26947 .55094 m .26819 .55278 L .26757 .5541 L F
.26947 .55094 m .26757 .5541 L .26758 .5541 L F
.592 .941 .786 r
.27117 .55022 m .26947 .55094 L .26887 .55199 L F
.328 0 .16 r
.27152 .55007 m .26819 .55278 L .26947 .55094 L F
.652 .841 .436 r
.26758 .5541 m .26757 .55411 L .26757 .55409 L F
.26758 .5541 m .26757 .5541 L .26757 .55411 L F
.26758 .5541 m .26757 .55409 L .26715 .55154 L F
.699 .249 .18 r
.26749 .55408 m .26753 .55408 L .26749 .55407 L F
.26753 .55408 m .26819 .55413 L .26749 .55407 L F
.815 .638 .664 r
.26757 .55411 m .26463 .55386 L .26749 .55408 L F
.26757 .55411 m .26749 .55408 L .26757 .55409 L F
.699 .249 .18 r
.26463 .55386 m .26747 .55416 L .26511 .5536 L F
.26463 .55386 m .26876 .55468 L .2683 .55424 L F
0 0 0 r
.26463 .55386 m .26359 .55474 L .26592 .55525 L F
.26601 .55514 m .26592 .55525 L .26619 .55531 L F
.26463 .55386 m .26592 .55525 L .26601 .55514 L F
.431 .085 .276 r
.26819 .55278 m .26791 .55297 L .26754 .55412 L F
.734 .687 .806 r
.26709 .55435 m .26619 .55531 L .26876 .55468 L F
.26463 .55386 m .26601 .55514 L .26709 .55435 L F
.26601 .55514 m .26619 .55531 L .26709 .55435 L F
0 0 0 r
.26666 .55441 m .26696 .55406 L .26757 .55411 L F
.699 .249 .18 r
.26747 .55416 m .26759 .5541 L .26511 .5536 L F
.815 .638 .664 r
.26749 .55408 m .26463 .55386 L .26487 .55296 L F
.619 .958 .886 r
.26715 .55154 m .26487 .55296 L .26671 .55271 L F
.815 .638 .664 r
.26757 .55409 m .26487 .55296 L .26715 .55154 L F
.26749 .55408 m .26487 .55296 L .26757 .55409 L F
.431 .085 .276 r
.26791 .55297 m .26666 .55441 L .26729 .5542 L F
.26759 .55398 m .26729 .5542 L .26754 .55412 L F
.26791 .55297 m .26729 .5542 L .26759 .55398 L F
0 0 0 r
.26504 .55493 m .26463 .55386 L .26639 .55401 L F
.431 .085 .276 r
.26791 .55297 m .26504 .55493 L .26666 .55441 L F
.26757 .5541 m .26754 .55412 L .26757 .55411 L F
.699 .249 .18 r
.26747 .55416 m .2683 .55424 L .26759 .5541 L F
.431 .085 .276 r
.26819 .55278 m .26754 .55412 L .26757 .5541 L F
.321 .662 .973 r
.25653 .5499 m .25711 .54875 L .25489 .54843 L F
.147 .446 .879 r
.25653 .5499 m .25938 .55137 L .25711 .54875 L F
.336 0 0 r
.23991 .53578 m .2421 .53621 L .24382 .53589 L F
.229 .748 .776 r
.2421 .53621 m .24632 .53541 L .24382 .53589 L F
.763 .786 .871 r
.80037 .42885 m .79717 .42872 L .79953 .42753 L F
.656 .776 .937 r
.80211 .42636 m .80037 .42885 L .79953 .42753 L F
.80211 .42636 m .80297 .42805 L .80037 .42885 L F
0 0 0 r
.25584 .61929 m .25272 .62245 L .25484 .62172 L F
0 0 .065 r
.25584 .61929 m .25643 .62073 L .25788 .61839 L F
.25584 .61929 m .25484 .62172 L .25643 .62073 L F
.459 .279 .548 r
.15943 .58612 m .15958 .58872 L .15748 .58922 L F
.013 .078 .585 r
.24285 .67003 m .2418 .67168 L .24304 .67132 L F
.666 .76 .921 r
.24288 .67444 m .24304 .67132 L .2418 .67168 L F
.848 .61 .578 r
.42007 .66186 m .41991 .66448 L .42342 .66509 L F
.302 .479 .868 r
.41991 .66448 m .42297 .66791 L .42342 .66509 L F
.679 .561 .714 r
.42534 .66803 m .4261 .66431 L .42342 .66509 L F
.563 .595 .844 r
.28262 .57359 m .28167 .5773 L .28052 .57381 L F
.28262 .57359 m .28405 .57712 L .28167 .5773 L F
.558 .405 .629 r
.28167 .5773 m .2818 .57984 L .28405 .57712 L F
.28167 .5773 m .2818 .57984 L .28405 .57712 L F
.122 .665 .834 r
.22592 .55047 m .22761 .5508 L .22994 .55068 L F
.529 .412 .664 r
.32077 .57046 m .32221 .57512 L .31888 .57527 L F
.449 .216 .468 r
.47278 .61842 m .47074 .61666 L .47307 .6161 L F
.47278 .61842 m .47048 .61905 L .47074 .61666 L F
.792 .74 .805 r
.5549 .58032 m .55114 .58013 L .55293 .57837 L F
.63 .853 .984 r
.23919 .64315 m .24762 .64349 L .24385 .64251 L F
.407 .8 .987 r
.24385 .64251 m .24762 .64349 L .24763 .64298 L F
.557 .331 .528 r
.66523 .42199 m .66862 .42165 L .66844 .41876 L F
.652 .403 .529 r
.66844 .41876 m .66862 .42165 L .67083 .42065 L F
.683 .386 .465 r
.66844 .41876 m .67083 .42065 L .67077 .41895 L F
.738 .464 .513 r
.45983 .64073 m .4633 .64348 L .46336 .6409 L F
.527 .3 .515 r
.4633 .64348 m .46598 .64058 L .46336 .6409 L F
.907 .984 .756 r
.22752 .69286 m .22582 .69592 L .2254 .69424 L F
.692 .734 .883 r
.55241 .60144 m .55649 .60243 L .55513 .60089 L F
.601 .792 .972 r
.55649 .60243 m .55882 .60146 L .55513 .60089 L F
.978 .76 .342 r
.53202 .57216 m .53289 .57373 L .53303 .57096 L F
.803 .43 0 r
.53168 .56814 m .53208 .56961 L .53303 .57096 L F
.978 .758 .341 r
.53208 .56961 m .53202 .57216 L .53303 .57096 L F
.227 0 0 r
.24589 .62515 m .24817 .62483 L .25027 .62313 L F
.432 0 0 r
.25027 .62313 m .24817 .62483 L .25184 .6241 L F
.357 0 .211 r
.25272 .62245 m .25027 .62313 L .25184 .6241 L F
.176 .63 .939 r
.19237 .77159 m .19092 .7718 L .19249 .77186 L F
.772 .458 .456 r
.45937 .62929 m .46067 .63133 L .45687 .63078 L F
.364 .316 .671 r
.462 .62755 m .45937 .62929 L .45964 .62529 L F
0 0 .272 r
.462 .62755 m .46067 .63133 L .45937 .62929 L F
.848 .786 .791 r
.24304 .67132 m .24816 .671 L .24813 .67165 L F
.855 .883 .858 r
.5594 .55877 m .55513 .56084 L .55789 .55742 L F
.645 .796 .955 r
.79316 .42931 m .79427 .43085 L .79071 .43033 L F
.746 .836 .92 r
.79717 .42872 m .79427 .43085 L .79316 .42931 L F
.401 .574 .908 r
.78837 .42318 m .78679 .42501 L .78628 .42319 L F
.345 .49 .86 r
.78837 .42318 m .79026 .42682 L .78679 .42501 L F
.782 .669 .738 r
.24675 .65001 m .2505 .6531 L .24897 .64964 L F
.893 .483 .073 r
.52557 .57595 m .5235 .57292 L .52442 .5743 L F
.969 .668 .272 r
.48439 .64276 m .48576 .64633 L .48568 .64412 L F
.48439 .64276 m .48576 .64633 L .48568 .64412 L F
.387 .798 .98 r
.25621 .53703 m .25845 .53668 L .2602 .53733 L F
.281 .679 .972 r
.26066 .53628 m .2602 .53733 L .25845 .53668 L F
.26066 .53628 m .26237 .53741 L .2602 .53733 L F
.683 .807 .942 r
.78085 .42999 m .7839 .43061 L .78139 .43166 L F
.923 .684 .558 r
.76853 .3935 m .77026 .39414 L .77019 .39141 L F
0 0 .423 r
.53024 .58554 m .5316 .58881 L .53158 .58773 L F
.819 .652 .675 r
.67083 .42065 m .67223 .42446 L .67398 .42131 L F
.121 0 .146 r
.161 .56191 m .15835 .56481 L .16006 .56381 L F
.099 0 .132 r
.161 .56191 m .16176 .5627 L .16296 .56116 L F
.161 .56191 m .16006 .56381 L .16176 .5627 L F
.861 .725 .711 r
.5744 .53128 m .57547 .52842 L .57379 .52775 L F
.76 .665 .757 r
.55848 .56817 m .55595 .57097 L .55453 .56748 L F
.705 .637 .778 r
.80678 .43045 m .80297 .42805 L .80559 .42769 L F
.63 .743 .929 r
.80848 .42729 m .80678 .43045 L .80559 .42769 L F
.80848 .42729 m .80943 .42949 L .80678 .43045 L F
.722 .598 .717 r
.56091 .56497 m .55848 .56817 L .55685 .56469 L F
.525 .87 .99 r
.20534 .64057 m .20681 .64122 L .20889 .64051 L F
.886 .882 .823 r
.49054 .62477 m .49449 .62276 L .49045 .62217 L F
.773 .618 .688 r
.55685 .56469 m .55848 .56817 L .55453 .56748 L F
.466 .181 .396 r
.47607 .61268 m .47548 .61574 L .47307 .6161 L F
.444 .153 .375 r
.47853 .61218 m .47548 .61574 L .47607 .61268 L F
.345 .301 .665 r
.75465 .40524 m .75493 .40168 L .75299 .40297 L F
.449 .41 .723 r
.75465 .40524 m .75763 .40932 L .75634 .40572 L F
.65 .373 .487 r
.21574 .72653 m .21933 .72622 L .21631 .72601 L F
.476 .882 .947 r
.23755 .62623 m .23548 .62696 L .23326 .62672 L F
.412 .838 .684 r
.24967 .66533 m .24659 .6671 L .24535 .66766 L F
.383 .837 .919 r
.24368 .62537 m .24146 .62595 L .23981 .6258 L F
.678 .3 .323 r
.8027 .39719 m .80554 .39932 L .80646 .39714 L F
.414 0 .051 r
.80554 .39932 m .8089 .39762 L .80646 .39714 L F
.814 .516 .485 r
.79758 .40373 m .7944 .40522 L .79405 .40309 L F
.79758 .40373 m .79785 .406 L .7944 .40522 L F
.739 .272 .14 r
.79758 .40373 m .80158 .40603 L .79785 .406 L F
0 0 0 r
.16137 .58457 m .15943 .58612 L .16227 .58286 L F
.508 .316 .554 r
.16183 .58817 m .15943 .58612 L .16137 .58457 L F
.16183 .58817 m .15958 .58872 L .15943 .58612 L F
0 0 0 r
.51912 .54884 m .52187 .54659 L .51955 .54854 L F
.51912 .54884 m .5205 .54806 L .52187 .54659 L F
.949 .626 .384 r
.5205 .54806 m .5226 .54968 L .52187 .54659 L F
.55 .385 .611 r
.5245 .54616 m .5226 .54968 L .52187 .54659 L F
.5245 .54616 m .5226 .54968 L .52187 .54659 L F
.699 .467 .569 r
.4225 .67039 m .42786 .66813 L .42534 .66803 L F
.42582 .66899 m .42764 .67036 L .42786 .66813 L F
.4225 .67039 m .42703 .67036 L .42582 .66899 L F
.42703 .67036 m .42764 .67036 L .42582 .66899 L F
0 0 0 r
.42534 .66803 m .42515 .66824 L .42509 .66823 L F
.42346 .66959 m .4236 .67009 L .4225 .67039 L F
.798 .445 .39 r
.42297 .66791 m .4236 .67009 L .42515 .66824 L F
.42495 .66801 m .42515 .66824 L .42534 .66803 L F
.42297 .66791 m .42515 .66824 L .42495 .66801 L F
.679 .561 .714 r
.42534 .66803 m .42786 .66813 L .4261 .66431 L F
.809 .735 .782 r
.52171 .55099 m .52326 .55265 L .5226 .54968 L F
.774 .531 .568 r
.51937 .55462 m .52326 .55265 L .52171 .55099 L F
.51937 .55462 m .52319 .55519 L .52326 .55265 L F
.403 .138 .394 r
.31208 .60131 m .31163 .60368 L .30935 .60429 L F
.598 .495 .708 r
.31415 .59828 m .31465 .60104 L .31208 .60131 L F
.53 .249 .433 r
.31408 .60325 m .31208 .60131 L .31465 .60104 L F
.31408 .60325 m .31163 .60368 L .31208 .60131 L F
.525 .287 .496 r
.45725 .6437 m .45974 .64329 L .45983 .64073 L F
.738 .464 .513 r
.45983 .64073 m .45974 .64329 L .4633 .64348 L F
.21 .407 .838 r
.24972 .64712 m .25261 .64924 L .25069 .64672 L F
.649 .396 .524 r
.24897 .64964 m .25261 .64924 L .24972 .64712 L F
.24897 .64964 m .25261 .64924 L .24972 .64712 L F
.196 .285 .73 r
.44533 .62834 m .4471 .62943 L .44691 .62848 L F
.227 0 .252 r
.44533 .62834 m .44691 .62848 L .44724 .62661 L F
.583 .528 .759 r
.44533 .62834 m .44847 .63105 L .4471 .62943 L F
.477 .853 .985 r
.8294 .43374 m .83221 .43306 L .83297 .43381 L F
.791 .984 .899 r
.83297 .43381 m .83468 .43099 L .83617 .43218 L F
.83297 .43381 m .83221 .43306 L .83468 .43099 L F
.459 .839 .987 r
.22137 .53757 m .22354 .53702 L .22528 .53763 L F
.344 .781 .966 r
.22354 .53702 m .22754 .53735 L .22528 .53763 L F
.851 .981 .863 r
.53702 .582 m .53872 .58076 L .53497 .58183 L F
.194 .414 .848 r
.53872 .58076 m .5397 .57884 L .53497 .58183 L F
.493 .133 .284 r
.54229 .57981 m .5423 .58216 L .53872 .58076 L F
.194 .414 .848 r
.53872 .58076 m .5423 .58216 L .5397 .57884 L F
.628 .465 .642 r
.4716 .6101 m .47406 .60705 L .47188 .60764 L F
.199 0 .013 r
.15478 .56752 m .15679 .56693 L .15835 .56481 L F
.322 0 .206 r
.15679 .56693 m .16006 .56381 L .15835 .56481 L F
.463 .853 .978 r
.76056 .41522 m .7608 .41394 L .75799 .41216 L F
.523 .29 .503 r
.48143 .60972 m .47853 .61218 L .47876 .61015 L F
.328 0 .037 r
.18956 .54632 m .19407 .54355 L .19175 .54403 L F
.524 .356 .596 r
.29935 .61914 m .29707 .62207 L .29706 .61964 L F
.568 .387 .596 r
.45768 .57115 m .4598 .57321 L .45923 .56984 L F
.865 .905 .858 r
.45927 .57421 m .45808 .5764 L .46089 .57325 L F
.45921 .57424 m .45829 .576 L .45927 .57421 L F
.45829 .576 m .45808 .5764 L .45927 .57421 L F
.457 .372 .672 r
.46309 .57195 m .46258 .57257 L .4633 .57206 L F
0 0 0 r
.46242 .57217 m .46311 .57192 L .46089 .57325 L F
.46361 .57132 m .46314 .57189 L .46242 .57217 L F
.46314 .57189 m .46311 .57192 L .46242 .57217 L F
.122 .165 .635 r
.4619 .56687 m .46324 .57185 L .46424 .56794 L F
.46324 .57185 m .4633 .57206 L .46336 .5718 L F
.46324 .57185 m .46336 .5718 L .46424 .56794 L F
0 0 0 r
.46326 .57184 m .46258 .57257 L .46159 .57297 L F
.46326 .57184 m .46159 .57297 L .46089 .57325 L F
.457 .372 .672 r
.45923 .56984 m .46258 .57257 L .46309 .57195 L F
0 0 0 r
.46397 .57106 m .46326 .57184 L .46311 .57192 L F
.46397 .57106 m .46311 .57192 L .46361 .57132 L F
.662 .512 .671 r
.45923 .56984 m .46309 .57195 L .4619 .56687 L F
.46309 .57195 m .4633 .57206 L .46324 .57185 L F
.46309 .57195 m .46324 .57185 L .4619 .56687 L F
.658 .452 .595 r
.45373 .57505 m .45749 .57534 L .45768 .57115 L F
.45749 .57534 m .45777 .57537 L .45776 .57516 L F
.45749 .57534 m .45776 .57516 L .45768 .57115 L F
.45777 .57537 m .45807 .57511 L .45768 .57115 L F
.865 .905 .858 r
.45927 .57421 m .46089 .57325 L .46012 .57349 L F
.45879 .57449 m .45827 .57588 L .45921 .57424 L F
.45827 .57588 m .45808 .5764 L .45921 .57424 L F
.45753 .57557 m .45808 .5764 L .45879 .57449 L F
.568 .387 .596 r
.4601 .5735 m .45809 .57539 L .46062 .574 L F
.45768 .57115 m .45805 .57497 L .4601 .5735 L F
.865 .905 .858 r
.45845 .57469 m .45879 .57449 L .45884 .57441 L F
.45879 .57449 m .45927 .57421 L .45926 .57418 L F
.568 .387 .596 r
.45805 .57497 m .45809 .57539 L .4601 .5735 L F
.865 .905 .858 r
.45737 .57533 m .45845 .57469 L .45921 .57378 L F
.45845 .57469 m .45884 .57441 L .45921 .57378 L F
.45879 .57449 m .45926 .57418 L .45921 .57378 L F
.45927 .57421 m .46012 .57349 L .45921 .57378 L F
.276 .769 .705 r
.46258 .57257 m .46012 .57349 L .46089 .57325 L F
.457 .372 .672 r
.46072 .57298 m .46062 .574 L .46189 .57201 L F
.46015 .57259 m .46062 .574 L .46091 .57121 L F
.568 .387 .596 r
.4598 .57321 m .4601 .5735 L .46015 .57259 L F
.276 .769 .705 r
.46041 .57338 m .46011 .5735 L .46012 .57349 L F
.568 .387 .596 r
.4601 .5735 m .46062 .574 L .46041 .57338 L F
.4601 .5735 m .46041 .57338 L .46015 .57259 L F
.276 .769 .705 r
.46258 .57257 m .45921 .57378 L .46011 .5735 L F
.46258 .57257 m .46011 .5735 L .46041 .57338 L F
.457 .372 .672 r
.46189 .57201 m .4612 .57309 L .46258 .57257 L F
.4612 .57309 m .46062 .574 L .46258 .57257 L F
.46091 .57121 m .46072 .57298 L .46189 .57201 L F
.45923 .56984 m .46015 .57259 L .46091 .57121 L F
.568 .387 .596 r
.4598 .57321 m .46015 .57259 L .45923 .56984 L F
.865 .905 .858 r
.45737 .57533 m .45753 .57557 L .45879 .57449 L F
.658 .452 .595 r
.45777 .57537 m .45809 .57539 L .45807 .57511 L F
.455 .79 .999 r
.45248 .57957 m .45636 .58019 L .4549 .57919 L F
.923 .878 .773 r
.4549 .57919 m .45636 .58019 L .45808 .5764 L F
.554 .926 .785 r
.19021 .78078 m .18585 .78317 L .18986 .78375 L F
.858 .634 .598 r
.57161 .51805 m .57269 .51622 L .57131 .51593 L F
.57161 .51805 m .57267 .51892 L .57269 .51622 L F
.042 0 0 r
.47723 .64411 m .47572 .64592 L .47413 .64632 L F
.092 0 .119 r
.47572 .64592 m .47305 .64874 L .47413 .64632 L F
.061 .394 .852 r
.20767 .62077 m .20921 .62134 L .20894 .62263 L F
0 .263 .772 r
.20921 .62134 m .21099 .62415 L .20894 .62263 L F
.608 .611 .828 r
.32423 .54985 m .3235 .5529 L .32283 .55002 L F
.32423 .54985 m .32603 .55248 L .3235 .5529 L F
.578 .412 .62 r
.32603 .55248 m .32371 .55542 L .3235 .5529 L F
.614 .522 .727 r
.66342 .42743 m .66612 .42473 L .66326 .42562 L F
.403 .157 .423 r
.46156 .62263 m .46178 .62477 L .45964 .62529 L F
.574 .262 .402 r
.46552 .62199 m .46178 .62477 L .46156 .62263 L F
.512 .41 .675 r
.32414 .55809 m .3245 .5626 L .32226 .56264 L F
.539 .487 .746 r
.32522 .56385 m .32226 .56264 L .3245 .5626 L F
.32522 .56385 m .32298 .56447 L .32226 .56264 L F
.975 .702 .449 r
.5268 .5607 m .5283 .56175 L .52701 .55848 L F
.996 .858 .577 r
.52624 .56411 m .5283 .56175 L .5268 .5607 L F
.52624 .56411 m .52732 .56503 L .5283 .56175 L F
0 0 .567 r
.42937 .67402 m .4305 .67693 L .4311 .67652 L F
.644 .318 .405 r
.43306 .6773 m .43256 .67864 L .4305 .67693 L F
0 .234 .75 r
.4305 .67693 m .43256 .67864 L .4311 .67652 L F
.857 .694 .68 r
.57245 .52144 m .57407 .52243 L .57267 .51892 L F
.932 .72 .593 r
.57245 .52144 m .57372 .5251 L .57407 .52243 L F
.649 .58 .764 r
.44266 .57899 m .44536 .57672 L .44306 .57706 L F
.466 .492 .802 r
.32522 .56385 m .32627 .56746 L .32298 .56447 L F
.738 .675 .789 r
.24897 .64964 m .2505 .6531 L .25259 .65036 L F
0 0 0 r
.16456 .58256 m .16137 .58457 L .16227 .58286 L F
.368 .581 .924 r
.29947 .53957 m .29867 .54173 L .29714 .54014 L F
.29947 .53957 m .3011 .54189 L .29867 .54173 L F
.774 .959 .647 r
.46341 .57158 m .46418 .57028 L .46424 .56794 L F
.678 .888 .522 r
.46418 .57028 m .46326 .57184 L .46397 .57106 L F
.774 .959 .647 r
.4633 .57206 m .46418 .57028 L .46341 .57158 L F
.678 .888 .522 r
.46418 .57028 m .46258 .57257 L .46326 .57184 L F
.697 .564 .701 r
.50646 .60707 m .50936 .60691 L .50874 .60423 L F
.718 .424 .479 r
.50646 .60707 m .5073 .61044 L .50896 .6098 L F
.583 .82 .989 r
.50936 .60691 m .50646 .60707 L .50874 .60423 L F
.718 .424 .479 r
.50896 .6098 m .5073 .61044 L .50646 .60707 L F
.648 .417 .556 r
.48051 .60621 m .4827 .60391 L .48063 .60468 L F
.61 .429 .611 r
.21146 .73002 m .2099 .73302 L .21426 .72874 L F
.14 .36 .818 r
.50874 .60423 m .50992 .60263 L .50713 .6013 L F
.819 .539 0 r
.50874 .60423 m .50936 .60691 L .5085 .60587 L F
.50874 .60423 m .5085 .60587 L .50992 .60263 L F
.194 .725 .793 r
.27087 .53655 m .27512 .53606 L .27254 .53686 L F
0 .1 .641 r
.45161 .6507 m .45398 .65365 L .45306 .6522 L F
0 .106 .627 r
.45349 .65495 m .45306 .6522 L .45398 .65365 L F
.862 .732 .718 r
.7606 .39125 m .76228 .38786 L .75925 .38755 L F
.573 .844 .996 r
.23718 .55068 m .23988 .55077 L .23839 .54964 L F
.375 .765 .988 r
.23988 .55077 m .24299 .55035 L .24098 .54942 L F
.866 .994 .76 r
.5763 .59235 m .57339 .59433 L .57392 .59543 L F
.692 .962 .943 r
.5772 .59054 m .5763 .59235 L .57766 .59113 L F
.742 .979 .738 r
.5772 .59054 m .57339 .59433 L .5763 .59235 L F
.664 .266 .281 r
.54857 .52118 m .54409 .5196 L .54797 .51906 L F
.684 .385 .462 r
.54797 .51906 m .54999 .52149 L .54857 .52118 L F
.725 .968 .935 r
.56829 .5981 m .57082 .59725 L .56949 .59677 L F
.762 .957 .935 r
.56949 .59677 m .57082 .59725 L .57392 .59543 L F
.577 .639 .876 r
.82855 .43121 m .82666 .43428 L .82443 .42973 L F
.82855 .43121 m .8294 .43374 L .82666 .43428 L F
.94 .77 .644 r
.56267 .53128 m .56065 .53282 L .56082 .53039 L F
.56267 .53128 m .56231 .53391 L .56065 .53282 L F
.128 0 0 r
.46604 .61309 m .46835 .61263 L .46957 .61112 L F
.347 0 .032 r
.46957 .61112 m .47152 .61184 L .4716 .6101 L F
.46957 .61112 m .46835 .61263 L .47152 .61184 L F
.518 .821 1 r
.26237 .53741 m .26464 .53687 L .26646 .5379 L F
.465 .813 .998 r
.26464 .53687 m .26867 .5373 L .26646 .5379 L F
.616 .436 .615 r
.48192 .62555 m .48446 .62544 L .48457 .62243 L F
.644 .496 .667 r
.48446 .62544 m .48628 .62169 L .48457 .62243 L F
.929 .747 .635 r
.55685 .56469 m .55437 .56384 L .55513 .56084 L F
.986 .858 .488 r
.55453 .56748 m .55437 .56384 L .55685 .56469 L F
.671 .557 .717 r
.4261 .66431 m .42786 .66813 L .42962 .66485 L F
.064 0 .029 r
.84185 .4182 m .83961 .41949 L .83854 .42111 L F
.025 .209 .716 r
.16695 .59724 m .16501 .5953 L .16795 .59522 L F
0 0 0 r
.48316 .63195 m .48168 .63329 L .48019 .63413 L F
.727 .99 .865 r
.48409 .63002 m .48316 .63195 L .48498 .63017 L F
.731 .945 .632 r
.48409 .63002 m .48168 .63329 L .48316 .63195 L F
.608 .927 .694 r
.55216 .56867 m .5538 .56687 L .55453 .56748 L F
.459 .302 .581 r
.49766 .5952 m .49771 .59794 L .49989 .59707 L F
.49766 .5952 m .49771 .59794 L .49989 .59707 L F
.762 .957 .935 r
.56949 .59677 m .57392 .59543 L .57327 .59751 L F
.89 .712 .199 r
.57392 .59543 m .57339 .59433 L .57327 .59751 L F
.343 .125 .432 r
.46591 .61505 m .46835 .61263 L .46604 .61309 L F
.859 .499 .368 r
.49608 .54537 m .49951 .54843 L .49938 .54659 L F
.809 .61 .632 r
.7573 .40177 m .75869 .40042 L .75556 .39997 L F
0 0 0 r
.76123 .39874 m .76223 .39776 L .75869 .40042 L F
.986 .832 .447 r
.51301 .55051 m .51418 .54954 L .51389 .54816 L F
.51301 .55051 m .51369 .55204 L .51418 .54954 L F
.695 .421 .505 r
.48628 .62169 m .49045 .62217 L .48983 .62084 L F
.477 .158 .347 r
.27827 .63569 m .27759 .63746 L .27521 .63777 L F
.526 .246 .433 r
.28238 .63412 m .27759 .63746 L .27827 .63569 L F
.582 .426 .636 r
.66326 .42562 m .66612 .42473 L .66523 .42199 L F
.44 .844 .973 r
.22754 .53735 m .22975 .53679 L .23143 .53725 L F
.249 0 0 r
.49209 .54596 m .49421 .54554 L .49544 .54366 L F
.75 .335 .262 r
.49544 .54366 m .49421 .54554 L .49608 .54537 L F
0 0 .232 r
.50936 .60691 m .50896 .6098 L .5105 .60793 L F
.025 0 .044 r
.50946 .60685 m .50965 .60858 L .50943 .60686 L F
.816 .609 .622 r
.5105 .60793 m .51268 .60468 L .5085 .60587 L F
.025 0 .044 r
.51133 .60631 m .51035 .60764 L .50946 .60685 L F
0 0 .232 r
.50936 .60691 m .5105 .60793 L .50936 .60676 L F
.025 0 .044 r
.51035 .60764 m .50965 .60858 L .50946 .60685 L F
0 0 .232 r
.50886 .60631 m .50936 .60676 L .5085 .60587 L F
.50936 .60691 m .50936 .60676 L .50886 .60631 L F
.453 .193 .429 r
.29397 .62526 m .29128 .62788 L .29179 .62543 L F
.688 .555 .698 r
.47358 .63213 m .47436 .636 L .47187 .63454 L F
.516 .277 .492 r
.47065 .63154 m .47323 .63348 L .4731 .63114 L F
.47065 .63154 m .47045 .63452 L .47323 .63348 L F
.401 .129 .382 r
.18321 .78665 m .18406 .78395 L .18145 .78665 L F
.262 .002 .318 r
.18585 .78317 m .18406 .78395 L .18321 .78665 L F
.945 .583 .243 r
.52796 .56657 m .52963 .56815 L .52868 .56643 L F
.974 .723 .494 r
.52796 .56657 m .52786 .56976 L .52963 .56815 L F
.58 .425 .636 r
.66523 .42199 m .66612 .42473 L .66862 .42165 L F
.86 .907 .864 r
.54296 .58109 m .54281 .58538 L .54159 .58443 L F
.54296 .58109 m .54491 .58257 L .54281 .58538 L F
.611 .913 .98 r
.53994 .58607 m .54159 .58443 L .54281 .58538 L F
.553 .415 .646 r
.42962 .66485 m .42786 .66813 L .43018 .66752 L F
.585 .403 .601 r
.42764 .67036 m .43018 .66752 L .42786 .66813 L F
.76 .681 .775 r
.49713 .56978 m .49835 .5738 L .4982 .57079 L F
.267 0 .286 r
.48647 .60674 m .48393 .60957 L .48457 .60751 L F
.502 .252 .468 r
.2861 .63118 m .28349 .63371 L .28374 .63152 L F
.544 .707 .947 r
.24011 .69261 m .23637 .69079 L .23812 .68995 L F
.544 .701 .943 r
.24174 .69165 m .24011 .69261 L .23812 .68995 L F
.24174 .69165 m .23812 .68995 L .24009 .68895 L F
0 0 0 r
.23947 .68931 m .23812 .68995 L .2367 .69093 L F
.24009 .68895 m .23812 .68995 L .23947 .68931 L F
.544 .707 .947 r
.23637 .69079 m .23575 .69049 L .23812 .68995 L F
.055 0 .11 r
.24174 .69165 m .23909 .69474 L .24011 .69261 L F
.877 .655 .598 r
.5112 .61058 m .51052 .61283 L .50896 .6098 L F
.934 .844 .731 r
.21647 .72869 m .21574 .72653 L .21522 .72778 L F
.21647 .72869 m .21933 .72622 L .21574 .72653 L F
.667 .415 .53 r
.4731 .63114 m .47555 .63139 L .47649 .62872 L F
.639 .386 .519 r
.47649 .62872 m .47911 .63085 L .47915 .62834 L F
.47649 .62872 m .47555 .63139 L .47911 .63085 L F
.862 .811 .798 r
.55311 .57641 m .55039 .57246 L .55204 .5735 L F
.55311 .57641 m .54991 .57589 L .55039 .57246 L F
.823 .738 .771 r
.55293 .57837 m .54991 .57589 L .55311 .57641 L F
.73 .66 .781 r
.5558 .57355 m .55311 .57641 L .55204 .5735 L F
.788 .31 0 r
.52692 .57928 m .52725 .58092 L .52584 .57863 L F
.52692 .57928 m .52865 .58197 L .52725 .58092 L F
.225 0 0 r
.23748 .55758 m .24178 .55532 L .24147 .55825 L F
.23748 .55758 m .23969 .55721 L .24178 .55532 L F
.478 .279 .531 r
.24178 .55532 m .24373 .55772 L .24147 .55825 L F
.729 .206 0 r
.242 .55682 m .24178 .55532 L .23969 .55721 L F
.242 .55682 m .24373 .55772 L .24178 .55532 L F
.201 .419 .85 r
.17808 .60874 m .17753 .61054 L .17555 .60741 L F
.336 .573 .927 r
.17808 .60874 m .17993 .61096 L .17753 .61054 L F
.213 .587 .945 r
.19448 .61619 m .19478 .61732 L .19329 .61595 L F
.19448 .61619 m .19697 .61786 L .19478 .61732 L F
.812 .894 .902 r
.45737 .57533 m .45539 .57678 L .45808 .5764 L F
.923 .878 .773 r
.4549 .57919 m .45808 .5764 L .45539 .57678 L F
.449 .3 .586 r
.75075 .39412 m .74896 .39772 L .75156 .39716 L F
.439 .525 .849 r
.74896 .39772 m .75401 .40138 L .75156 .39716 L F
.55 .779 .984 r
.78967 .44301 m .79078 .44452 L .79307 .44387 L F
.576 .317 .487 r
.48175 .62796 m .48446 .62544 L .48192 .62555 L F
.661 .694 .869 r
.81933 .43014 m .82225 .42932 L .82243 .43092 L F
.55 .609 .865 r
.82225 .42932 m .82489 .42897 L .82243 .43092 L F
.49 .495 .79 r
.82489 .42897 m .82443 .42973 L .82243 .43092 L F
.528 0 0 r
.2623 .64277 m .26416 .64396 L .26607 .6457 L F
.407 .049 .242 r
.26607 .6457 m .26416 .64396 L .26652 .64347 L F
.387 .831 .941 r
.82051 .39693 m .81876 .39809 L .81775 .39751 L F
.82051 .39693 m .82148 .3975 L .81876 .39809 L F
.37 .559 .907 r
.20566 .61811 m .20502 .6201 L .2036 .61824 L F
.20566 .61811 m .20767 .62077 L .20502 .6201 L F
.812 .56 .558 r
.50868 .59406 m .51201 .59208 L .51019 .59142 L F
.50868 .59406 m .51197 .59476 L .51201 .59208 L F
.549 .87 .994 r
.79307 .44387 m .79729 .44382 L .79633 .44258 L F
.668 .868 .975 r
.79633 .44258 m .79729 .44382 L .79968 .44264 L F
0 0 .443 r
.45849 .66113 m .45784 .65992 L .4595 .65929 L F
.877 .968 .648 r
.45836 .65997 m .45849 .66113 L .4595 .65929 L F
0 0 .407 r
.45836 .65997 m .4593 .66264 L .45849 .66113 L F
.4593 .66264 m .45961 .66353 L .45849 .66113 L F
0 0 .443 r
.45849 .66113 m .45777 .65995 L .45784 .65992 L F
.482 .38 .662 r
.32155 .57616 m .32194 .57901 L .31987 .57952 L F
.475 .353 .633 r
.32194 .57901 m .3194 .58343 L .31987 .57952 L F
.808 .96 .91 r
.23299 .69749 m .23747 .69558 L .23593 .69596 L F
.23299 .69749 m .23308 .69783 L .23747 .69558 L F
.123 0 0 r
.23909 .69474 m .23593 .69596 L .23747 .69558 L F
.537 .699 .944 r
.78934 .39866 m .78987 .40049 L .78767 .40082 L F
.78934 .39866 m .78987 .40049 L .78767 .40082 L F
.593 .578 .805 r
.78302 .42399 m .77989 .42121 L .78163 .42121 L F
.608 .679 .892 r
.78628 .42319 m .78302 .42399 L .78163 .42121 L F
.22 .743 .806 r
.19407 .54355 m .19616 .54315 L .19781 .54305 L F
.271 .769 .889 r
.19616 .54315 m .20013 .54297 L .19781 .54305 L F
0 0 .236 r
.13951 .58542 m .13953 .58541 L .14003 .58296 L F
0 0 .259 r
.14003 .58296 m .14122 .58212 L .14184 .57941 L F
.311 .167 .517 r
.13953 .58541 m .14122 .58212 L .14003 .58296 L F
.844 .635 .619 r
.56874 .54908 m .5672 .55192 L .57053 .55252 L F
.816 .626 .645 r
.5672 .55192 m .57051 .55511 L .57053 .55252 L F
.221 .715 .919 r
.27933 .57331 m .28262 .57359 L .28052 .57381 L F
.438 .149 .375 r
.16965 .57377 m .16905 .57591 L .16677 .57635 L F
.549 .253 .417 r
.17195 .57513 m .16905 .57591 L .16965 .57377 L F
.792 .53 .542 r
.48972 .56361 m .49341 .56685 L .49155 .56453 L F
.482 .332 .601 r
.3194 .58343 m .32021 .58556 L .31803 .58602 L F
.524 .449 .714 r
.32052 .58765 m .31803 .58602 L .32021 .58556 L F
.32052 .58765 m .3189 .58888 L .31803 .58602 L F
.861 .725 .711 r
.5744 .53128 m .57379 .52775 L .57322 .52986 L F
.879 .797 .764 r
.57134 .53288 m .5744 .53128 L .57322 .52986 L F
.57134 .53288 m .57278 .53421 L .5744 .53128 L F
.446 .286 .57 r
.31163 .60368 m .30941 .60694 L .30935 .60429 L F
.746 .774 .876 r
.76175 .41261 m .76347 .40828 L .76117 .41089 L F
0 .138 .668 r
.76384 .41341 m .76175 .41261 L .76117 .41089 L F
.251 .676 .963 r
.2229 .64375 m .22417 .64378 L .21887 .64275 L F
.601 .357 .519 r
.32627 .56746 m .32449 .57151 L .32077 .57046 L F
.466 .492 .802 r
.32522 .56385 m .32773 .56693 L .32627 .56746 L F
.38 .127 .4 r
.32628 .57015 m .32627 .56746 L .32773 .56693 L F
.32628 .57015 m .32449 .57151 L .32627 .56746 L F
.522 .808 .998 r
.22488 .62756 m .22265 .62811 L .22112 .62719 L F
.934 .844 .731 r
.21647 .72869 m .21866 .72844 L .21933 .72622 L F
0 0 0 r
.21748 .73127 m .21662 .73202 L .21866 .72844 L F
.21748 .73127 m .21866 .72844 L .21647 .72869 L F
.541 .233 .394 r
.28712 .57383 m .28629 .57616 L .28884 .5757 L F
.099 .235 .717 r
.28711 .57466 m .28712 .57383 L .28884 .5757 L F
.28711 .57466 m .28505 .5727 L .28712 .57383 L F
0 .313 .804 r
.17993 .61096 m .18173 .61197 L .18145 .61325 L F
.126 .475 .896 r
.18173 .61197 m .18384 .61439 L .18145 .61325 L F
.592 .948 .894 r
.77989 .42121 m .77718 .42236 L .77675 .42201 L F
.109 0 0 r
.77989 .42121 m .77675 .42201 L .78163 .42121 L F
.811 .606 .626 r
.50792 .59825 m .50373 .60023 L .50689 .59773 L F
.50792 .59825 m .50713 .6013 L .50373 .60023 L F
.958 .944 .71 r
.50792 .59825 m .50868 .59406 L .50624 .59418 L F
.50792 .59825 m .50689 .59773 L .50868 .59406 L F
0 0 0 r
.23754 .67901 m .23332 .6793 L .23618 .6794 L F
.525 .009 0 r
.23618 .6794 m .2393 .67969 L .23754 .67901 L F
.932 .72 .593 r
.57245 .52144 m .57304 .52573 L .57372 .5251 L F
.897 .681 .602 r
.57304 .52573 m .57379 .52775 L .57372 .5251 L F
0 0 .459 r
.45 .66807 m .45072 .66741 L .45007 .66444 L F
0 0 .54 r
.53851 .60065 m .53557 .59697 L .53582 .5985 L F
.229 .354 .784 r
.53768 .60136 m .53851 .60065 L .53582 .5985 L F
.469 .626 .92 r
.80328 .44374 m .80474 .44145 L .80233 .44176 L F
.80328 .44374 m .80777 .44412 L .80474 .44145 L F
.014 .545 .851 r
.80328 .44374 m .80773 .44495 L .80777 .44412 L F
.593 .787 .973 r
.17093 .59793 m .1687 .59862 L .16695 .59724 L F
.466 .886 .914 r
.53393 .52275 m .53204 .52401 L .53509 .52163 L F
.53393 .52275 m .53133 .52375 L .53204 .52401 L F
.675 .561 .718 r
.26059 .64706 m .25775 .64959 L .25856 .64727 L F
.148 .691 .745 r
.22994 .55068 m .23408 .55013 L .23213 .55011 L F
.093 .65 .782 r
.23408 .55013 m .23444 .54992 L .23213 .55011 L F
.23408 .55013 m .23625 .55003 L .23444 .54992 L F
.55 .749 .97 r
.81226 .42866 m .81574 .42964 L .81312 .43026 L F
.859 .869 .845 r
.84176 .40452 m .84265 .40616 L .84505 .40329 L F
.998 .788 .491 r
.57972 .58239 m .57945 .58494 L .58049 .58578 L F
.995 .87 .572 r
.57896 .58735 m .58049 .58578 L .57945 .58494 L F
.57896 .58735 m .57981 .58805 L .58049 .58578 L F
.29 .254 .644 r
.42937 .67402 m .43053 .67011 L .42764 .67036 L F
.42937 .67402 m .43042 .67327 L .43053 .67011 L F
0 0 .567 r
.42937 .67402 m .4311 .67652 L .43042 .67327 L F
.407 0 0 r
.17599 .57389 m .17195 .57513 L .17339 .57681 L F
.804 .747 .799 r
.5676 .54519 m .56925 .54645 L .56823 .54322 L F
.895 .738 .68 r
.5676 .54519 m .56874 .54908 L .56925 .54645 L F
.715 .39 .426 r
.55765 .50994 m .56102 .51188 L .56122 .50989 L F
.609 .328 .466 r
.56102 .51188 m .56377 .51187 L .56122 .50989 L F
.818 .773 .811 r
.45876 .66504 m .45507 .66579 L .45553 .66185 L F
.984 .731 .466 r
.45876 .66504 m .45453 .66651 L .45507 .66579 L F
.45876 .66504 m .45682 .66611 L .45453 .66651 L F
.45876 .66504 m .45854 .66752 L .45682 .66611 L F
.784 .677 .746 r
.57014 .56099 m .57193 .56153 L .57206 .55873 L F
.79 .554 .58 r
.57205 .56419 m .57193 .56153 L .57014 .56099 L F
.57205 .56419 m .57343 .56447 L .57193 .56153 L F
0 .346 .803 r
.76399 .41533 m .76481 .41644 L .7638 .41521 L F
.76399 .41533 m .76596 .41712 L .76481 .41644 L F
.415 .569 .898 r
.17464 .62492 m .17416 .62132 L .17212 .62208 L F
.17464 .62492 m .17632 .62444 L .17416 .62132 L F
.149 .338 .797 r
.54622 .60145 m .54726 .59981 L .54514 .60084 L F
.54622 .60145 m .54873 .60318 L .54726 .59981 L F
.306 .756 .958 r
.54622 .60145 m .54514 .60084 L .54242 .601 L F
.708 .183 0 r
.54409 .5196 m .54607 .52151 L .5448 .52078 L F
.664 .266 .281 r
.54857 .52118 m .54607 .52151 L .54409 .5196 L F
.822 .607 .611 r
.55778 .5221 m .55413 .52391 L .55406 .52157 L F
.55778 .5221 m .55765 .52472 L .55413 .52391 L F
.407 0 0 r
.17599 .57389 m .17377 .57542 L .17195 .57513 L F
0 0 .175 r
.1779 .57155 m .17599 .57389 L .17815 .57048 L F
.274 0 0 r
.17653 .57502 m .17599 .57389 L .1779 .57155 L F
.17653 .57502 m .17377 .57542 L .17599 .57389 L F
.408 .086 .305 r
.44724 .62661 m .44691 .62848 L .44924 .62745 L F
.462 .297 .571 r
.3068 .60991 m .30461 .61312 L .30442 .61049 L F
.756 .685 .783 r
.41725 .6523 m .41962 .65527 L .42053 .65291 L F
.616 .527 .73 r
.42053 .65291 m .42178 .65512 L .41962 .65527 L F
0 0 .111 r
.41962 .65527 m .42042 .65451 L .42053 .65291 L F
0 0 .53 r
.41962 .65527 m .4209 .65789 L .42042 .65451 L F
.1 0 .024 r
.14184 .57941 m .14363 .57871 L .14488 .57676 L F
.158 0 .058 r
.14488 .57676 m .14596 .57765 L .14648 .57608 L F
.14488 .57676 m .14363 .57871 L .14596 .57765 L F
.457 0 .042 r
.47798 .63494 m .47426 .63643 L .47436 .636 L F
.47798 .63494 m .47632 .63622 L .47426 .63643 L F
.706 .667 .809 r
.48019 .63413 m .47798 .63494 L .47665 .63137 L F
0 0 0 r
.47885 .63511 m .47798 .63494 L .48019 .63413 L F
.47885 .63511 m .47632 .63622 L .47798 .63494 L F
.945 .583 .243 r
.52796 .56657 m .52868 .56643 L .52825 .56599 L F
.995 .758 .413 r
.52686 .56842 m .52786 .56976 L .52796 .56657 L F
.945 .583 .243 r
.52796 .56657 m .52825 .56599 L .52732 .56503 L F
.875 .464 .025 r
.52694 .56578 m .52732 .56503 L .52624 .56411 L F
.52694 .56578 m .52796 .56657 L .52732 .56503 L F
.775 .521 .552 r
.52525 .56173 m .52624 .56411 L .5268 .5607 L F
.52321 .56308 m .52624 .56411 L .52525 .56173 L F
.846 .459 0 r
.52541 .56319 m .52624 .56411 L .52321 .56308 L F
.52541 .56319 m .52692 .56575 L .52624 .56411 L F
.52692 .56575 m .52694 .56578 L .52624 .56411 L F
.476 .719 .977 r
.52559 .56366 m .526 .56431 L .52541 .56319 L F
.526 .56431 m .52694 .56578 L .52552 .56338 L F
.526 .56431 m .52552 .56338 L .52541 .56319 L F
.52559 .56366 m .52936 .56548 L .52694 .56578 L F
0 .302 .794 r
.53026 .56591 m .52966 .56448 L .52909 .56544 L F
.299 .682 .975 r
.52923 .56542 m .52966 .56448 L .53026 .56591 L F
0 0 0 r
.52909 .56544 m .52966 .56448 L .52908 .56576 L F
.299 .682 .975 r
.52559 .56366 m .52966 .56448 L .52923 .56542 L F
.359 0 0 r
.52694 .56578 m .52909 .56544 L .52796 .56657 L F
0 0 0 r
.52909 .56544 m .52845 .56629 L .52796 .56657 L F
.52909 .56544 m .52881 .56651 L .52686 .56842 L F
.359 0 0 r
.52694 .56578 m .52898 .56586 L .52909 .56544 L F
.52898 .56586 m .53026 .56591 L .52909 .56544 L F
0 0 0 r
.52909 .56544 m .52906 .56627 L .52881 .56651 L F
.476 .719 .977 r
.5292 .5655 m .52893 .56586 L .52694 .56578 L F
.52936 .56548 m .52911 .5657 L .5292 .5655 L F
0 0 0 r
.52908 .56576 m .52923 .56542 L .52908 .56578 L F
.476 .719 .977 r
.52911 .5657 m .52893 .56586 L .5292 .5655 L F
0 0 0 r
.52908 .56578 m .52966 .56448 L .52906 .56627 L F
.52923 .56542 m .52966 .56448 L .52908 .56578 L F
.462 .33 .615 r
.52847 .5656 m .52881 .56467 L .52675 .56578 L F
.52687 .56599 m .52675 .56578 L .52592 .56623 L F
.52847 .5656 m .52675 .56578 L .52687 .56599 L F
.476 .719 .977 r
.52936 .56548 m .53026 .56591 L .52893 .56586 L F
0 0 0 r
.52845 .56629 m .52742 .56767 L .52782 .56686 L F
.52845 .56629 m .52782 .56686 L .52796 .56657 L F
.52742 .56767 m .52686 .56842 L .52796 .56657 L F
.26463 .55386 m .26303 .55561 L .26359 .55474 L F
.584 .473 .693 r
.31638 .59767 m .31337 .59478 L .31564 .59428 L F
.31638 .59767 m .31415 .59828 L .31337 .59478 L F
.552 .724 .954 r
.31344 .54438 m .31251 .54657 L .3113 .54475 L F
.31344 .54438 m .31477 .54602 L .31251 .54657 L F
0 0 0 r
.52799 .5222 m .53022 .52054 L .53148 .51945 L F
.472 .885 .933 r
.18368 .78697 m .18657 .78658 L .18544 .78625 L F
.468 .288 .554 r
.24558 .68244 m .24364 .68013 L .24507 .67984 L F
.176 0 0 r
.54292 .51327 m .53976 .51521 L .5422 .51458 L F
.257 0 .085 r
.54292 .51327 m .5422 .51458 L .54523 .51255 L F
.359 .071 .333 r
.19794 .55845 m .19715 .56094 L .19491 .56142 L F
.452 .117 .306 r
.20041 .55825 m .19715 .56094 L .19794 .55845 L F
.373 .579 .921 r
.53928 .57636 m .54353 .57889 L .54229 .57981 L F
0 0 .202 r
.54353 .57889 m .5423 .58216 L .54229 .57981 L F
0 0 0 r
.23372 .53706 m .23598 .53655 L .23748 .53612 L F
.23598 .53655 m .23991 .53578 L .23748 .53612 L F
.582 .443 .657 r
.32385 .57336 m .32077 .57046 L .32449 .57151 L F
.32385 .57336 m .32221 .57512 L .32077 .57046 L F
.455 .479 .795 r
.19856 .76973 m .19619 .76817 L .19821 .76776 L F
.121 0 0 r
.19821 .76776 m .19619 .76817 L .19375 .77013 L F
.428 .229 .506 r
.27237 .59509 m .27461 .59459 L .27483 .59178 L F
.407 .175 .446 r
.27237 .59509 m .2721 .59754 L .27461 .59459 L F
.895 .738 .68 r
.5676 .54519 m .5658 .54853 L .56874 .54908 L F
.83 .615 .612 r
.56523 .55091 m .56874 .54908 L .5658 .54853 L F
.56523 .55091 m .5672 .55192 L .56874 .54908 L F
.574 .262 .402 r
.46552 .62199 m .46424 .62464 L .46178 .62477 L F
.544 .231 .386 r
.46672 .62408 m .46552 .62199 L .46792 .62201 L F
.46672 .62408 m .46424 .62464 L .46552 .62199 L F
.525 .308 .528 r
.45725 .6437 m .45958 .64576 L .45974 .64329 L F
.45725 .6437 m .45711 .64627 L .45958 .64576 L F
.762 .525 .575 r
.44707 .64591 m .45076 .64629 L .45073 .64368 L F
.965 .707 .272 r
.51328 .59974 m .51396 .59804 L .51265 .59695 L F
.51328 .59974 m .5141 .60064 L .51396 .59804 L F
.562 .862 .996 r
.23381 .67332 m .23598 .67422 L .23624 .67272 L F
.364 .316 .671 r
.462 .62755 m .45964 .62529 L .46178 .62477 L F
.95 .768 .621 r
.56231 .53391 m .55957 .53591 L .56065 .53282 L F
.56231 .53391 m .56119 .53694 L .55957 .53591 L F
.433 0 0 r
.24588 .55087 m .24299 .55035 L .24373 .55119 L F
.221 0 .285 r
.2723 .58008 m .27179 .58207 L .27428 .57912 L F
.439 .341 .648 r
.13792 .58892 m .13953 .58541 L .13951 .58542 L F
.13792 .58892 m .13997 .58815 L .13953 .58541 L F
.257 .143 .526 r
.13824 .59178 m .13997 .58815 L .13792 .58892 L F
.649 .58 .764 r
.44266 .57899 m .44625 .57949 L .44536 .57672 L F
.513 .294 .519 r
.44354 .58252 m .44625 .57949 L .44266 .57899 L F
.964 .761 .582 r
.51314 .60576 m .51516 .60413 L .51386 .60315 L F
.51314 .60576 m .51489 .60677 L .51516 .60413 L F
.991 .756 .481 r
.51386 .60315 m .51516 .60413 L .5141 .60064 L F
.352 .534 .895 r
.84014 .39739 m .84291 .39838 L .84153 .40015 L F
0 0 .434 r
.84153 .40015 m .84291 .39838 L .84316 .40075 L F
.939 .593 .339 r
.51466 .61184 m .51565 .61038 L .51424 .60972 L F
.51466 .61184 m .51627 .61271 L .51565 .61038 L F
.27 .776 .835 r
.21599 .71925 m .21833 .71876 L .21956 .7188 L F
.816 .806 .842 r
.21599 .71925 m .21956 .7188 L .21833 .71876 L F
.839 .727 .741 r
.5597 .54627 m .56069 .54984 L .55897 .54862 L F
.992 .8 .545 r
.56069 .54984 m .55929 .54891 L .55897 .54862 L F
.665 .122 0 r
.50454 .55543 m .50395 .55647 L .50276 .55519 L F
.50454 .55543 m .50694 .55738 L .50395 .55647 L F
.611 .737 .935 r
.16522 .58906 m .16359 .58997 L .16183 .58817 L F
.887 .858 .807 r
.56908 .53621 m .57278 .53421 L .57134 .53288 L F
.56908 .53621 m .57055 .5373 L .57278 .53421 L F
.261 .679 .966 r
.21887 .64275 m .21924 .64156 L .21749 .64163 L F
.21887 .64275 m .22417 .64378 L .21924 .64156 L F
.66 .922 .623 r
.22306 .71576 m .22266 .71677 L .22276 .71695 L F
.547 .816 .455 r
.22533 .71356 m .22287 .7165 L .22306 .71576 L F
.22287 .7165 m .22266 .71677 L .22225 .71725 L F
.22533 .71356 m .22266 .71677 L .22287 .7165 L F
.549 .339 .549 r
.22533 .71356 m .22494 .71656 L .22266 .71677 L F
.245 0 0 r
.22494 .71656 m .22378 .71758 L .22266 .71677 L F
.22378 .71758 m .22336 .71794 L .2232 .71768 L F
.22378 .71758 m .2232 .71768 L .22266 .71677 L F
.597 .382 .56 r
.22722 .71538 m .22494 .71656 L .22533 .71356 L F
.373 0 0 r
.2262 .71748 m .22494 .71656 L .22722 .71538 L F
.2262 .71748 m .22336 .71794 L .22494 .71656 L F
.757 .514 .565 r
.22306 .71576 m .22577 .71725 L .22536 .71485 L F
.22577 .71725 m .2262 .71748 L .22611 .71719 L F
.22577 .71725 m .22611 .71719 L .22536 .71485 L F
.66 .922 .623 r
.22312 .7162 m .22276 .71695 L .22336 .71794 L F
.22306 .71576 m .22287 .7165 L .22312 .7162 L F
.22287 .7165 m .22276 .71695 L .22312 .7162 L F
.547 .816 .455 r
.22287 .7165 m .22225 .71725 L .22306 .71576 L F
.436 .847 .966 r
.22489 .71303 m .22744 .71298 L .22533 .71356 L F
.442 .1 .289 r
.22306 .71576 m .22489 .71303 L .22533 .71356 L F
.597 .382 .56 r
.22722 .71538 m .22533 .71356 L .22744 .71298 L F
.504 .515 .801 r
.17426 .60329 m .17416 .60798 L .17226 .60379 L F
.17426 .60329 m .17555 .60741 L .17416 .60798 L F
0 .128 .676 r
.76668 .42015 m .76727 .41906 L .76705 .41881 L F
0 0 .348 r
.76596 .41712 m .7665 .42082 L .76668 .42015 L F
.844 .827 .831 r
.7621 .41809 m .76342 .42058 L .7651 .41829 L F
.76481 .41741 m .7651 .41829 L .76596 .41712 L F
.7621 .41809 m .7651 .41829 L .76481 .41741 L F
.7621 .41809 m .76596 .41712 L .76399 .41533 L F
0 .128 .676 r
.76668 .42015 m .76399 .41533 L .76596 .41712 L F
.76668 .42015 m .76705 .41881 L .76421 .41558 L F
.76433 .41593 m .76421 .41558 L .76399 .41533 L F
.76668 .42015 m .76421 .41558 L .76433 .41593 L F
0 0 .348 r
.7665 .42082 m .76668 .42207 L .76668 .42015 L F
.206 .389 .824 r
.76668 .42207 m .76922 .42192 L .76668 .42015 L F
.76668 .42207 m .76953 .42376 L .76922 .42192 L F
.613 .511 .715 r
.32052 .58765 m .31946 .59149 L .3189 .58888 L F
.54 .491 .75 r
.2376 .68259 m .23867 .68658 L .24063 .68578 L F
.705 .932 .964 r
.82459 .44206 m .82768 .44153 L .82678 .44057 L F
.687 .844 .958 r
.82768 .44153 m .83003 .43871 L .82678 .44057 L F
.82768 .44153 m .83123 .44016 L .83003 .43871 L F
.206 .728 .722 r
.27175 .58854 m .2717 .58853 L .27512 .58767 L F
.317 .403 .793 r
.27392 .59016 m .27512 .58767 L .2717 .58853 L F
.27392 .59016 m .27579 .59076 L .27512 .58767 L F
.341 .386 .763 r
.27392 .59016 m .27483 .59178 L .27579 .59076 L F
.759 .682 .776 r
.23545 .64316 m .23882 .64335 L .23751 .64309 L F
.23545 .64316 m .23576 .64416 L .23882 .64335 L F
.133 .664 .867 r
.23751 .64309 m .23882 .64335 L .23919 .64315 L F
.317 .597 .945 r
.2023 .61658 m .20169 .61798 L .19968 .61711 L F
.2023 .61658 m .2036 .61824 L .20169 .61798 L F
.866 .87 .839 r
.75299 .40297 m .75493 .40168 L .75556 .39997 L F
.357 .302 .658 r
.75493 .40168 m .7556 .40299 L .75556 .39997 L F
.537 .721 .958 r
.80473 .426 m .80297 .42805 L .80211 .42636 L F
.80473 .426 m .80559 .42769 L .80297 .42805 L F
.817 .588 .591 r
.56717 .51238 m .56729 .51534 L .57131 .51593 L F
.835 .528 .469 r
.56729 .51534 m .57161 .51805 L .57131 .51593 L F
.475 .353 .633 r
.32194 .57901 m .32241 .58439 L .3194 .58343 L F
.525 .413 .669 r
.32241 .58439 m .32021 .58556 L .3194 .58343 L F
.052 0 .138 r
.43466 .67637 m .43256 .67864 L .43306 .6773 L F
.487 .867 .978 r
.53996 .60164 m .5408 .60063 L .53851 .60065 L F
.53996 .60164 m .54242 .601 L .5408 .60063 L F
.659 .765 .928 r
.82149 .42697 m .81933 .43014 L .81827 .42887 L F
.82149 .42697 m .82225 .42932 L .81933 .43014 L F
.511 .061 .118 r
.21146 .72273 m .21333 .72266 L .21373 .71973 L F
.118 .614 .906 r
.27709 .5361 m .2811 .53724 L .27877 .53766 L F
.559 .063 .035 r
.21518 .55504 m .21048 .55617 L .21296 .55501 L F
.509 .881 .975 r
.23095 .62702 m .22874 .62776 L .22711 .6274 L F
.708 .822 .936 r
.83549 .40525 m .8366 .4068 L .83905 .40549 L F
.641 .799 .958 r
.83298 .39527 m .83134 .39767 L .83043 .39638 L F
.83298 .39527 m .83397 .39677 L .83134 .39767 L F
.636 .663 .859 r
.55882 .60146 m .56239 .60356 L .56188 .6009 L F
.361 0 0 r
.5612 .60301 m .56239 .60356 L .56188 .6009 L F
.5612 .60301 m .56542 .60181 L .56239 .60356 L F
0 0 .229 r
.8444 .41823 m .84489 .41982 L .84455 .42074 L F
0 0 .228 r
.84488 .41704 m .84489 .41982 L .8444 .41823 L F
.722 .73 .21 r
.21522 .72778 m .21397 .73286 L .21516 .73228 L F
.32 .805 .78 r
.21397 .73286 m .21347 .73272 L .21516 .73228 L F
.566 .319 .501 r
.21236 .73328 m .21287 .73476 L .21015 .73453 L F
.21374 .7325 m .21359 .73288 L .21236 .73328 L F
.21359 .73288 m .21287 .73476 L .21236 .73328 L F
.32 .805 .78 r
.21397 .73286 m .21662 .73202 L .21542 .73229 L F
.2138 .73281 m .21542 .73229 L .21347 .73272 L F
.21397 .73286 m .21542 .73229 L .2138 .73281 L F
.356 0 0 r
.24632 .53541 m .24831 .53604 L .24999 .53617 L F
.234 .748 .864 r
.24831 .53604 m .25243 .53585 L .24999 .53617 L F
.369 .611 .944 r
.4471 .62943 m .44847 .63105 L .44866 .63002 L F
.898 .71 .64 r
.57804 .57894 m .58029 .57993 L .57844 .57627 L F
.936 .737 .608 r
.57792 .58161 m .58029 .57993 L .57804 .57894 L F
.57792 .58161 m .57972 .58239 L .58029 .57993 L F
.822 .693 .722 r
.57844 .57627 m .58029 .57993 L .57996 .57753 L F
.831 .527 .476 r
.4633 .64348 m .46364 .64605 L .46716 .64648 L F
.887 .777 .735 r
.46322 .64867 m .46716 .64648 L .46364 .64605 L F
.873 .753 .728 r
.46716 .64648 m .46504 .64981 L .46564 .64734 L F
.887 .777 .735 r
.46322 .64867 m .46504 .64981 L .46716 .64648 L F
.613 .61 .824 r
.46716 .64648 m .46825 .64257 L .46578 .64299 L F
.46716 .64648 m .46855 .64606 L .46825 .64257 L F
.123 0 0 r
.17167 .55534 m .17203 .5565 L .17361 .55427 L F
.17167 .55534 m .16992 .55716 L .17203 .5565 L F
.991 .733 .402 r
.46843 .65259 m .46927 .65616 L .46923 .65727 L F
.339 .359 .735 r
.47105 .65457 m .46927 .65616 L .46843 .65259 L F
0 0 .441 r
.47105 .65457 m .46976 .65867 L .46927 .65616 L F
0 .086 .611 r
.74751 .39065 m .75075 .39412 L .75007 .39079 L F
.511 .474 .751 r
.75075 .39412 m .75339 .39 L .75007 .39079 L F
.75075 .39412 m .75493 .3931 L .75339 .39 L F
.568 .45 .678 r
.75156 .39716 m .75493 .3931 L .75075 .39412 L F
.381 .762 .99 r
.22739 .64263 m .22942 .64354 L .22956 .64242 L F
.24 .626 .958 r
.22942 .64354 m .23122 .64372 L .22956 .64242 L F
.268 .027 .351 r
.46186 .60731 m .46151 .60947 L .46169 .60686 L F
0 0 0 r
.74912 .38742 m .74751 .39065 L .75007 .39079 L F
.876 .574 .474 r
.5607 .52788 m .55784 .52708 L .55765 .52472 L F
.888 .609 .508 r
.56082 .53039 m .55784 .52708 L .5607 .52788 L F
.342 .685 .98 r
.80773 .44495 m .80871 .44399 L .80777 .44412 L F
.80773 .44495 m .80977 .44518 L .80871 .44399 L F
.581 .274 .413 r
.45786 .61695 m .46041 .61615 L .45775 .61478 L F
.104 0 .027 r
.14975 .57072 m .14669 .57344 L .14847 .57259 L F
.155 0 .044 r
.14847 .57259 m .1517 .56999 L .14975 .57072 L F
.483 .242 .472 r
.1803 .56984 m .1779 .57155 L .17815 .57048 L F
.414 0 .051 r
.80554 .39932 m .80828 .39915 L .8089 .39762 L F
.458 0 .066 r
.8089 .39762 m .80828 .39915 L .81173 .39839 L F
.572 .171 .243 r
.45082 .64884 m .45472 .64688 L .45076 .64629 L F
.45082 .64884 m .4533 .64892 L .45472 .64688 L F
.455 .045 .171 r
.45472 .64688 m .4578 .64784 L .45711 .64627 L F
.45472 .64688 m .4533 .64892 L .4578 .64784 L F
.647 .478 .64 r
.49119 .58267 m .48841 .58523 L .48857 .58322 L F
.49119 .58267 m .48841 .58523 L .48857 .58322 L F
.628 .82 .974 r
.82674 .39601 m .82521 .39824 L .82417 .39676 L F
.82674 .39601 m .82782 .39736 L .82521 .39824 L F
.672 .741 .902 r
.24897 .64964 m .25259 .65036 L .25261 .64924 L F
.087 .217 .704 r
.25261 .64924 m .25259 .65036 L .25336 .64856 L F
.499 .711 .966 r
.25259 .65036 m .25524 .65056 L .25336 .64856 L F
.209 0 .014 r
.27521 .63777 m .27344 .63997 L .27198 .63984 L F
.433 .024 .163 r
.27694 .63888 m .27521 .63777 L .27759 .63746 L F
.27694 .63888 m .27344 .63997 L .27521 .63777 L F
.994 .753 .414 r
.5146 .61906 m .51566 .61965 L .51424 .61641 L F
.871 .982 .84 r
.2091 .74402 m .20832 .74548 L .20637 .74704 L F
.629 .336 .453 r
.20832 .74548 m .21008 .74821 L .20637 .74704 L F
.128 .044 .483 r
.21089 .74547 m .2091 .74402 L .2112 .743 L F
.656 .209 0 r
.21075 .74716 m .20832 .74548 L .21086 .74569 L F
.2106 .7492 m .21008 .74821 L .20967 .74758 L F
.20993 .74804 m .20967 .74758 L .20976 .74783 L F
.21066 .7483 m .20962 .7476 L .21075 .74716 L F
0 .235 .711 r
.20976 .74783 m .21008 .74821 L .21011 .74801 L F
.656 .209 0 r
.2106 .7492 m .20993 .74804 L .20976 .74783 L F
.2106 .7492 m .21011 .74801 L .21066 .7483 L F
0 0 .322 r
.21014 .74782 m .21011 .74801 L .2106 .7492 L F
.21011 .74801 m .21008 .74821 L .2106 .7492 L F
.656 .209 0 r
.2106 .7492 m .20976 .74783 L .21011 .74801 L F
.20976 .74783 m .20962 .7476 L .21066 .7483 L F
0 .235 .711 r
.20915 .7471 m .20976 .74783 L .21014 .74782 L F
.20976 .74783 m .21011 .74801 L .21014 .74782 L F
.20705 .74559 m .21008 .74821 L .20915 .7471 L F
.656 .209 0 r
.20976 .74783 m .20967 .74758 L .20832 .74548 L F
.20962 .7476 m .20832 .74548 L .21075 .74716 L F
.313 .592 .943 r
.20637 .74704 m .20897 .74786 L .20705 .74559 L F
.20897 .74786 m .21008 .74821 L .20945 .74767 L F
.20897 .74786 m .20945 .74767 L .20705 .74559 L F
.721 .474 .552 r
.21086 .74569 m .21323 .74828 L .2106 .7492 L F
.56 .109 .136 r
.21128 .74735 m .21168 .74698 L .20968 .74558 L F
.21086 .74569 m .21326 .74549 L .21078 .74555 L F
.742 .566 .656 r
.21389 .74291 m .21144 .74517 L .2112 .743 L F
.128 .044 .483 r
.21074 .74558 m .2091 .74402 L .21089 .74547 L F
.21007 .74494 m .20832 .74548 L .2091 .74402 L F
.20969 .7456 m .20832 .74548 L .21007 .74494 L F
0 0 0 r
.2112 .743 m .20705 .74559 L .20968 .74558 L F
.714 .656 .791 r
.20968 .74558 m .21171 .74204 L .21165 .74216 L F
.21035 .74444 m .21165 .74216 L .2112 .743 L F
.20968 .74558 m .21165 .74216 L .21035 .74444 L F
.128 .044 .483 r
.21086 .74569 m .20969 .7456 L .21007 .74494 L F
.298 .711 .974 r
.21389 .74291 m .2112 .743 L .21171 .74204 L F
.714 .656 .791 r
.20968 .74558 m .21074 .74556 L .21171 .74204 L F
.21074 .74556 m .21078 .74555 L .21078 .74553 L F
.742 .566 .656 r
.21144 .74517 m .21089 .74547 L .2112 .743 L F
.21086 .74569 m .21086 .74569 L .2112 .743 L F
.714 .656 .791 r
.21074 .74556 m .21078 .74553 L .21171 .74204 L F
.742 .566 .656 r
.21389 .74291 m .21326 .74549 L .21144 .74517 L F
.714 .656 .791 r
.21133 .74515 m .21326 .74549 L .21267 .74416 L F
.21078 .74555 m .21326 .74549 L .21133 .74515 L F
.742 .566 .656 r
.21144 .74517 m .21326 .74549 L .21086 .74569 L F
.21144 .74517 m .21086 .74569 L .21089 .74547 L F
.21086 .74569 m .21086 .74569 L .21086 .74569 L F
.56 .109 .136 r
.21168 .74698 m .21188 .74679 L .21086 .74569 L F
.721 .474 .552 r
.21086 .74569 m .21326 .74549 L .21323 .74828 L F
.56 .109 .136 r
.21188 .74679 m .21326 .74549 L .21086 .74569 L F
.128 .044 .483 r
.21086 .74569 m .21074 .74558 L .21078 .74555 L F
.21086 .74569 m .21078 .74555 L .21086 .74569 L F
.56 .109 .136 r
.21168 .74698 m .21078 .74555 L .20968 .74558 L F
.128 .044 .483 r
.21086 .74569 m .21078 .74555 L .21089 .74547 L F
.714 .656 .791 r
.21078 .74555 m .21267 .74416 L .21171 .74204 L F
.823 .738 .771 r
.55293 .57837 m .54963 .57836 L .54991 .57589 L F
.827 .704 .729 r
.55293 .57837 m .55114 .58013 L .54963 .57836 L F
.142 0 .094 r
.22855 .69315 m .22752 .69286 L .2254 .69424 L F
.22855 .69315 m .22923 .69163 L .22752 .69286 L F
.713 .665 .802 r
.50528 .61539 m .50503 .61871 L .50785 .61605 L F
.666 .324 .384 r
.79914 .39749 m .80293 .399 L .8027 .39719 L F
.638 .339 .447 r
.80293 .399 m .80554 .39932 L .8027 .39719 L F
.077 0 0 r
.50624 .59418 m .50216 .59566 L .50454 .59605 L F
.699 .341 .366 r
.55126 .50923 m .55373 .51154 L .55508 .50921 L F
.738 .388 .388 r
.55373 .51154 m .55747 .51188 L .55508 .50921 L F
.718 .393 .427 r
.55508 .50921 m .55747 .51188 L .55765 .50994 L F
.837 .498 .414 r
.53476 .58402 m .53702 .582 L .53497 .58183 L F
.53476 .58402 m .53877 .58594 L .53702 .582 L F
.639 .635 .83 r
.84014 .39739 m .84011 .40131 L .83665 .39599 L F
.927 .825 .725 r
.56908 .53621 m .56974 .5402 L .57055 .5373 L F
.765 .474 .492 r
.51369 .55204 m .51547 .55493 L .51678 .5525 L F
.709 .406 .462 r
.51678 .5525 m .51937 .55462 L .51857 .55149 L F
.51678 .5525 m .51547 .55493 L .51937 .55462 L F
.742 .793 .894 r
.47247 .5637 m .47473 .56451 L .47364 .56291 L F
.47364 .56291 m .47473 .56451 L .47247 .5637 L F
.41 .632 .945 r
.47364 .56291 m .47473 .56451 L .47582 .56287 L F
.47364 .56291 m .47473 .56451 L .47582 .56287 L F
.603 .142 .13 r
.80158 .40603 m .80074 .40764 L .79785 .406 L F
.523 .115 .208 r
.80158 .40603 m .80462 .40748 L .80074 .40764 L F
.80158 .40603 m .80411 .40612 L .80462 .40748 L F
.608 .616 .834 r
.43605 .66821 m .43572 .67057 L .43466 .67086 L F
.547 .317 .518 r
.43572 .67057 m .43398 .67365 L .43466 .67086 L F
.421 .602 .921 r
.45457 .63045 m .45568 .62904 L .45317 .62936 L F
.45457 .63045 m .45687 .63078 L .45568 .62904 L F
0 0 0 r
.48168 .63329 m .47885 .63511 L .48019 .63413 L F
.395 0 0 r
.81051 .40625 m .81407 .40593 L .81291 .40691 L F
.312 0 0 r
.79217 .39828 m .79569 .39843 L .79658 .39706 L F
.729 .266 .149 r
.79569 .39843 m .7992 .39928 L .79658 .39706 L F
.685 .339 .382 r
.79658 .39706 m .7992 .39928 L .79914 .39749 L F
.354 .807 .944 r
.2811 .53724 m .28341 .5368 L .28493 .53719 L F
.48 .872 .967 r
.28493 .53719 m .2854 .53611 L .2871 .5372 L F
.28493 .53719 m .28341 .5368 L .2854 .53611 L F
.244 0 .101 r
.26032 .61587 m .26221 .61547 L .26347 .61315 L F
0 0 .217 r
.26347 .61315 m .26497 .61214 L .26521 .60965 L F
.138 0 .045 r
.26347 .61315 m .26425 .61452 L .26497 .61214 L F
.26347 .61315 m .26221 .61547 L .26425 .61452 L F
0 .008 .539 r
.49835 .5738 m .50024 .57578 L .5007 .57651 L F
0 0 .394 r
.50024 .57578 m .50224 .57887 L .5007 .57651 L F
.896 .902 .822 r
.79217 .39828 m .78934 .39866 L .79239 .39777 L F
.79217 .39828 m .78987 .40049 L .78934 .39866 L F
.09 .624 .863 r
.79217 .39828 m .79239 .39777 L .79569 .39843 L F
.805 .604 .631 r
.78941 .39057 m .79086 .39254 L .78756 .39042 L F
.678 .141 0 r
.51549 .56476 m .5153 .56538 L .51449 .56342 L F
.51549 .56476 m .51775 .56718 L .5153 .56538 L F
.353 .205 .537 r
.16905 .57591 m .16709 .57938 L .16677 .57635 L F
.887 .786 .744 r
.5623 .54065 m .56136 .54286 L .56046 .53943 L F
.923 .663 .526 r
.77026 .39651 m .77026 .39414 L .76853 .3935 L F
.056 0 .254 r
.509 .61971 m .51122 .616 L .50785 .61605 L F
.509 .61971 m .51085 .61881 L .51122 .616 L F
.844 .948 .591 r
.18379 .80004 m .18454 .79874 L .1844 .79791 L F
.555 .082 .088 r
.80411 .40612 m .80788 .40583 L .80701 .40746 L F
.52 .055 .09 r
.80788 .40583 m .81055 .40726 L .80701 .40746 L F
.80788 .40583 m .81051 .40625 L .81055 .40726 L F
.207 0 0 r
.19585 .56242 m .19491 .56142 L .19715 .56094 L F
.19585 .56242 m .19364 .56307 L .19491 .56142 L F
.927 .825 .725 r
.56908 .53621 m .56737 .53946 L .56974 .5402 L F
.903 .734 .663 r
.56656 .54167 m .56974 .5402 L .56737 .53946 L F
.56656 .54167 m .56823 .54322 L .56974 .5402 L F
.498 .797 .999 r
.27359 .55934 m .27456 .55772 L .272 .55812 L F
.27359 .55934 m .27613 .55889 L .27456 .55772 L F
.285 0 .059 r
.43053 .67011 m .43446 .66748 L .43018 .66752 L F
.43053 .67011 m .43285 .66932 L .43446 .66748 L F
.114 0 0 r
.43285 .66932 m .43605 .66821 L .43446 .66748 L F
.527 .3 .515 r
.4633 .64348 m .46578 .64299 L .46598 .64058 L F
.569 .336 .523 r
.46598 .64058 m .46825 .64257 L .46829 .64003 L F
.46598 .64058 m .46578 .64299 L .46825 .64257 L F
.381 .681 .977 r
.77062 .42511 m .77204 .42389 L .76953 .42376 L F
.77062 .42511 m .7732 .4253 L .77204 .42389 L F
.458 .564 .875 r
.77062 .42511 m .77412 .42569 L .7732 .4253 L F
.583 .583 .819 r
.53643 .51797 m .53766 .52135 L .53509 .52163 L F
.362 0 0 r
.53766 .52135 m .53393 .52275 L .53509 .52163 L F
.025 .464 .876 r
.28942 .53833 m .28912 .53904 L .2871 .5372 L F
.28942 .53833 m .29096 .53976 L .28912 .53904 L F
.686 .244 .196 r
.46243 .66792 m .46094 .66963 L .45854 .66752 L F
.834 .932 .555 r
.46258 .66665 m .46094 .66963 L .46243 .66792 L F
0 .213 .738 r
.45306 .6522 m .45082 .64884 L .45161 .6507 L F
.739 .539 .623 r
.52287 .55772 m .5268 .5607 L .52701 .55848 L F
.552 .524 .778 r
.31714 .54524 m .31622 .55019 L .31477 .54602 L F
.31714 .54524 m .31862 .54961 L .31622 .55019 L F
0 0 .298 r
.27483 .59178 m .27545 .5931 L .27579 .59076 L F
.27483 .59178 m .27461 .59459 L .27545 .5931 L F
.108 0 .249 r
.27494 .57691 m .27428 .57912 L .27646 .57593 L F
.701 .822 .94 r
.23644 .67012 m .24101 .67039 L .23844 .67149 L F
.23644 .67012 m .24101 .67039 L .23844 .67149 L F
.458 .462 .774 r
.16948 .59422 m .16795 .59522 L .16711 .59285 L F
.144 0 .162 r
.16926 .59469 m .16795 .59522 L .16948 .59422 L F
.16926 .59469 m .16695 .59724 L .16795 .59522 L F
.323 .325 .707 r
.13905 .5949 m .1404 .5941 L .13861 .59301 L F
.393 .365 .709 r
.13947 .59781 m .1404 .5941 L .13905 .5949 L F
.183 .685 .909 r
.18837 .78325 m .18986 .78375 L .18697 .78333 L F
.496 .888 .722 r
.18544 .78625 m .18986 .78375 L .18779 .78565 L F
.346 .103 .396 r
.18967 .78318 m .18837 .78325 L .18779 .78565 L F
.19025 .78241 m .18837 .78325 L .18967 .78318 L F
.183 .685 .909 r
.18837 .78325 m .18697 .78333 L .18585 .78317 L F
.863 .693 .67 r
.75958 .39332 m .7606 .39125 L .75875 .39003 L F
.862 .732 .718 r
.7606 .39125 m .75925 .38755 L .75875 .39003 L F
.662 .759 .922 r
.44465 .64655 m .44237 .64762 L .44078 .6459 L F
.44465 .64655 m .44237 .64762 L .44078 .6459 L F
.573 .844 .996 r
.23718 .55068 m .23839 .54964 L .23625 .55003 L F
.486 0 0 r
.49951 .54843 m .50169 .54906 L .50325 .54887 L F
.537 0 0 r
.50169 .54906 m .50574 .54934 L .50325 .54887 L F
.068 0 0 r
.53976 .51521 m .54078 .5159 L .5422 .51458 L F
.53976 .51521 m .53843 .51676 L .54078 .5159 L F
.758 .81 .332 r
.21347 .73272 m .21287 .73476 L .21309 .73417 L F
.21347 .73272 m .21309 .73417 L .21374 .7325 L F
.881 .666 .607 r
.21522 .72778 m .21516 .73228 L .21197 .73072 L F
.777 .901 .929 r
.21117 .73153 m .21374 .7325 L .21019 .73451 L F
.21018 .73444 m .21019 .73451 L .21015 .73453 L F
.21117 .73153 m .21019 .73451 L .21018 .73444 L F
.719 .912 .961 r
.21117 .73153 m .20977 .7327 L .20968 .73191 L F
0 0 .571 r
.20968 .73191 m .20977 .7327 L .20989 .73286 L F
.777 .901 .929 r
.21117 .73153 m .21015 .73453 L .20977 .7327 L F
0 0 .571 r
.20974 .73202 m .20989 .73286 L .2108 .73407 L F
.20968 .73191 m .20989 .73286 L .20974 .73202 L F
.493 0 0 r
.21347 .73272 m .21374 .7325 L .21117 .73153 L F
.889 .621 .527 r
.21347 .73272 m .21516 .73228 L .21197 .73072 L F
.739 .927 .953 r
.21347 .73272 m .21748 .73127 L .2137 .73184 L F
.21347 .73272 m .2137 .73184 L .21342 .73188 L F
.442 .878 .831 r
.21347 .73272 m .21662 .73202 L .21748 .73127 L F
.473 .193 .408 r
.28896 .62857 m .28844 .63074 L .2861 .63118 L F
.581 .357 .54 r
.29128 .62788 m .28844 .63074 L .28896 .62857 L F
.636 .219 .236 r
.52786 .56976 m .53208 .56961 L .53168 .56814 L F
.005 0 0 r
.2526 .54903 m .25052 .54985 L .2483 .55025 L F
.715 .39 .426 r
.55765 .50994 m .55747 .51188 L .56102 .51188 L F
.092 .147 .628 r
.1404 .5941 m .13824 .59178 L .13861 .59301 L F
.789 .811 .87 r
.21333 .72266 m .21599 .71925 L .21373 .71973 L F
.5 .427 .706 r
.31678 .60031 m .31415 .59828 L .31638 .59767 L F
.31678 .60031 m .31465 .60104 L .31415 .59828 L F
.665 .532 .692 r
.32682 .55495 m .32371 .55542 L .32603 .55248 L F
.589 .472 .688 r
.32659 .55753 m .32371 .55542 L .32682 .55495 L F
.32659 .55753 m .32414 .55809 L .32371 .55542 L F
.09 .012 .465 r
.45012 .6587 m .44919 .66151 L .44938 .66103 L F
0 0 .482 r
.44919 .66151 m .45007 .66444 L .44938 .66103 L F
.878 .67 .617 r
.57063 .55696 m .57206 .55873 L .57051 .55511 L F
.806 .704 .752 r
.56828 .55832 m .57206 .55873 L .57063 .55696 L F
.56828 .55832 m .57014 .56099 L .57206 .55873 L F
.974 .708 .294 r
.51286 .54459 m .51389 .54816 L .51187 .54616 L F
.626 .648 .852 r
.7922 .42618 m .79071 .43033 L .79026 .42682 L F
.7922 .42618 m .79316 .42931 L .79071 .43033 L F
.318 .093 .407 r
.14184 .57941 m .14306 .58133 L .14363 .57871 L F
.14184 .57941 m .14122 .58212 L .14306 .58133 L F
.888 .629 .54 r
.57336 .56705 m .57331 .56974 L .57631 .57048 L F
.848 .612 .582 r
.57305 .57242 m .57631 .57048 L .57331 .56974 L F
.57305 .57242 m .57497 .57262 L .57631 .57048 L F
.874 .896 .845 r
.20976 .72199 m .21373 .71973 L .21054 .7203 L F
.28 .111 .465 r
.83039 .42352 m .83221 .4221 L .82843 .42345 L F
.83221 .4221 m .8325 .42188 L .83225 .42197 L F
.83221 .4221 m .83225 .42197 L .82843 .42345 L F
.548 .469 .718 r
.83027 .42331 m .83039 .42352 L .83014 .42342 L F
.225 0 .339 r
.82843 .42345 m .83139 .4223 L .83018 .42339 L F
.83012 .42342 m .83018 .42339 L .83014 .42342 L F
.82843 .42345 m .83018 .42339 L .83012 .42342 L F
.502 .479 .763 r
.83044 .42322 m .8325 .42188 L .83039 .42352 L F
.225 0 .339 r
.83139 .4223 m .83225 .42197 L .83014 .42342 L F
.502 .479 .763 r
.83127 .41886 m .8325 .42188 L .83044 .42322 L F
.83127 .41886 m .83044 .42322 L .82897 .42087 L F
.83044 .42322 m .83039 .42352 L .83027 .42331 L F
.83044 .42322 m .83027 .42331 L .82897 .42087 L F
.225 0 .339 r
.83014 .42342 m .83043 .42322 L .83119 .42341 L F
.83043 .42322 m .83225 .42197 L .83188 .42247 L F
.83043 .42322 m .83188 .42247 L .83119 .42341 L F
.548 .469 .718 r
.82897 .42087 m .83027 .42331 L .82655 .42203 L F
.83027 .42331 m .83014 .42342 L .82655 .42203 L F
.189 .535 .924 r
.82655 .42203 m .83014 .42342 L .82843 .42345 L F
.83014 .42342 m .83039 .42352 L .82843 .42345 L F
.225 0 .339 r
.82843 .42345 m .83119 .42341 L .82968 .42546 L F
.83225 .42197 m .8325 .42188 L .83184 .42271 L F
.83225 .42197 m .83184 .42271 L .82968 .42546 L F
.687 .511 .643 r
.83115 .42398 m .83177 .42363 L .83023 .4277 L F
.635 .514 .698 r
.82968 .42546 m .8325 .42188 L .83153 .42242 L F
.687 .511 .643 r
.83153 .42242 m .83165 .42305 L .83115 .42398 L F
.83165 .42305 m .83177 .42363 L .83115 .42398 L F
.83177 .42363 m .83241 .42691 L .83063 .42756 L F
.83177 .42363 m .83063 .42756 L .83023 .4277 L F
.666 .324 .384 r
.79914 .39749 m .7992 .39928 L .80293 .399 L F
.536 .791 .991 r
.55241 .60144 m .55367 .59969 L .5512 .60057 L F
.55241 .60144 m .55513 .60089 L .55367 .59969 L F
.518 .63 .9 r
.18547 .63365 m .18563 .63033 L .18372 .63032 L F
.18547 .63365 m .18771 .63339 L .18563 .63033 L F
.489 .609 .898 r
.18547 .63365 m .18872 .63513 L .18771 .63339 L F
.569 .38 .586 r
.30461 .61312 m .30456 .61581 L .30211 .61612 L F
.462 .297 .571 r
.3068 .60991 m .30676 .61262 L .30461 .61312 L F
.589 .455 .666 r
.30676 .61262 m .30456 .61581 L .30461 .61312 L F
.668 .496 .642 r
.46923 .65727 m .4662 .65875 L .46354 .65875 L F
.881 .693 .644 r
.57161 .51805 m .57245 .52144 L .57267 .51892 L F
.819 .702 .736 r
.4662 .65875 m .46594 .66179 L .46349 .66134 L F
0 0 0 r
.46976 .65867 m .46594 .66179 L .4662 .65875 L F
.46976 .65867 m .4685 .66056 L .46594 .66179 L F
.589 .36 .537 r
.46637 .66177 m .46349 .66134 L .46594 .66179 L F
0 0 0 r
.46594 .66179 m .4685 .66056 L .46637 .66177 L F
.504 .278 .504 r
.44625 .57949 m .44863 .57671 L .44536 .57672 L F
.44625 .57949 m .44869 .57908 L .44863 .57671 L F
.67 .422 .537 r
.44863 .57671 m .45344 .57732 L .45419 .57617 L F
.778 .714 .791 r
.44869 .57908 m .45344 .57732 L .44863 .57671 L F
.628 .664 .866 r
.8303 .40773 m .83175 .40462 L .8293 .40524 L F
.8303 .40773 m .83364 .4061 L .83175 .40462 L F
.876 .781 .752 r
.56136 .54286 m .55854 .54229 L .56046 .53943 L F
.935 .827 .714 r
.56136 .54286 m .55824 .54513 L .55854 .54229 L F
.56136 .54286 m .5597 .54627 L .55824 .54513 L F
.519 .858 .994 r
.14426 .60518 m .14316 .60473 L .14124 .60548 L F
.284 .695 .972 r
.14426 .60518 m .14582 .6047 L .14316 .60473 L F
.14426 .60518 m .14774 .60583 L .14582 .6047 L F
.466 .751 .991 r
.23117 .698 m .23308 .69783 L .23299 .69749 L F
.524 .356 .596 r
.29935 .61914 m .29939 .62166 L .29707 .62207 L F
.514 .222 .409 r
.2991 .62392 m .29707 .62207 L .29939 .62166 L F
.2991 .62392 m .29661 .62442 L .29707 .62207 L F
.204 .44 .865 r
.16841 .61873 m .17055 .62181 L .17212 .62208 L F
.986 .858 .488 r
.55453 .56748 m .5538 .56687 L .55437 .56384 L F
.246 .325 .748 r
.47816 .64283 m .47723 .64411 L .47568 .64022 L F
.604 .852 .491 r
.47816 .64283 m .47572 .64592 L .47723 .64411 L F
.517 .537 .815 r
.25783 .6644 m .25592 .66521 L .25443 .66125 L F
0 0 .302 r
.25379 .66638 m .2529 .67044 L .25238 .66764 L F
0 0 0 r
.25783 .6644 m .25379 .66636 L .25592 .66521 L F
.25379 .66636 m .25359 .66645 L .25375 .66637 L F
.25379 .66636 m .25375 .66637 L .25592 .66521 L F
0 0 .302 r
.25396 .66631 m .25388 .6698 L .2529 .67044 L F
.25399 .6662 m .25399 .66631 L .25396 .66631 L F
.25399 .66631 m .25388 .6698 L .25396 .66631 L F
0 0 0 r
.25359 .66645 m .25306 .66671 L .25344 .66651 L F
.25359 .66645 m .25344 .66651 L .25592 .66521 L F
.438 .865 .743 r
.25399 .6662 m .25306 .66671 L .25374 .66638 L F
.25399 .6662 m .25374 .66638 L .25783 .6644 L F
.25399 .6662 m .25783 .6644 L .25566 .66346 L F
.026 .12 .627 r
.25509 .66503 m .25515 .66536 L .25399 .6662 L F
.25515 .66536 m .25572 .6686 L .25399 .6662 L F
0 0 .302 r
.25399 .6662 m .25396 .66631 L .25379 .66638 L F
.25396 .66631 m .2529 .67044 L .25379 .66638 L F
.844 .948 .591 r
.18379 .80004 m .1844 .79791 L .18206 .79845 L F
.585 .04 0 r
.51956 .5684 m .51775 .56718 L .51915 .56816 L F
.685 .624 .782 r
.23618 .6794 m .2376 .68259 L .2393 .67969 L F
.468 .353 .64 r
.2393 .67969 m .2376 .68259 L .23913 .68217 L F
.54 .491 .75 r
.2376 .68259 m .24063 .68578 L .23913 .68217 L F
.945 .849 .716 r
.76781 .40439 m .77044 .40289 L .76867 .4021 L F
.76781 .40439 m .76904 .40562 L .77044 .40289 L F
.519 .474 .746 r
.4684 .63587 m .46843 .63745 L .47066 .63682 L F
.618 .406 .572 r
.46843 .63745 m .47106 .63961 L .47066 .63682 L F
.46843 .63745 m .46829 .64003 L .47106 .63961 L F
.522 .646 .912 r
.78326 .4405 m .78725 .44264 L .786 .4401 L F
.354 .522 .884 r
.786 .4401 m .78725 .44264 L .78877 .44088 L F
.368 .542 .895 r
.78877 .44088 m .78725 .44264 L .78967 .44301 L F
.869 .666 .625 r
.57844 .57627 m .57932 .57464 L .57883 .57371 L F
.57844 .57627 m .57996 .57753 L .57932 .57464 L F
.356 .47 .839 r
.77494 .42045 m .77271 .42201 L .77243 .42015 L F
.588 .125 .122 r
.77271 .42201 m .77589 .42335 L .77718 .42236 L F
.356 .47 .839 r
.77494 .42045 m .77589 .42335 L .77271 .42201 L F
.437 .152 .381 r
.30456 .61581 m .30169 .61859 L .30211 .61612 L F
.644 .496 .667 r
.48446 .62544 m .48771 .62516 L .48628 .62169 L F
.623 .485 .673 r
.48628 .62169 m .49054 .62477 L .49045 .62217 L F
.48628 .62169 m .48771 .62516 L .49054 .62477 L F
.62 .598 .806 r
.52926 .5251 m .53022 .52054 L .52799 .5222 L F
.455 .545 .859 r
.16648 .61888 m .16659 .61544 L .16495 .61559 L F
.16648 .61888 m .16841 .61873 L .16659 .61544 L F
.61 .45 .639 r
.23054 .68046 m .23332 .6793 L .23025 .67955 L F
0 0 0 r
.76605 .3931 m .76459 .39486 L .76378 .39592 L F
.529 .621 .888 r
.3086 .54425 m .30496 .54204 L .30711 .54248 L F
.329 .652 .97 r
.3097 .54338 m .3086 .54425 L .30711 .54248 L F
.3097 .54338 m .3113 .54475 L .3086 .54425 L F
.369 .708 .986 r
.20276 .64058 m .20534 .64057 L .20313 .63919 L F
.193 0 0 r
.1809 .55077 m .18506 .54866 L .18286 .54917 L F
.311 .385 .777 r
.77823 .43317 m .77945 .43716 L .78119 .43501 L F
.429 .557 .883 r
.77945 .43716 m .78275 .43809 L .78119 .43501 L F
.554 .282 .457 r
.45419 .57617 m .45539 .57678 L .45373 .57505 L F
.615 .431 .609 r
.45373 .57505 m .45737 .57533 L .45809 .57539 L F
.45373 .57505 m .45539 .57678 L .45737 .57533 L F
.432 .477 .806 r
.18182 .6303 m .18265 .62721 L .18057 .62781 L F
.18182 .6303 m .18372 .63032 L .18265 .62721 L F
.72 .604 .726 r
.66851 .42391 m .67223 .42446 L .67083 .42065 L F
.467 .185 .401 r
.31643 .60275 m .31465 .60104 L .31678 .60031 L F
.31643 .60275 m .31408 .60325 L .31465 .60104 L F
.546 .303 .498 r
.45012 .6587 m .45397 .6581 L .45349 .65495 L F
0 .106 .627 r
.45349 .65495 m .45454 .65434 L .45306 .6522 L F
.741 .666 .777 r
.45397 .6581 m .45454 .65434 L .45349 .65495 L F
.803 .488 .456 r
.44924 .62745 m .45292 .62919 L .4506 .62556 L F
.562 .482 .723 r
.45292 .62919 m .45447 .62392 L .4506 .62556 L F
.977 .772 .56 r
.50251 .58108 m .50422 .57981 L .50224 .57887 L F
.50251 .58108 m .50394 .58162 L .50422 .57981 L F
.527 .867 .605 r
.77718 .42236 m .77764 .42187 L .77679 .42204 L F
.818 .755 .793 r
.77764 .42187 m .77589 .42335 L .77554 .42229 L F
.77764 .42187 m .77554 .42229 L .77494 .42045 L F
.527 .867 .605 r
.77679 .42204 m .77764 .42187 L .77675 .42201 L F
.77718 .42236 m .77589 .42335 L .77764 .42187 L F
.587 .609 .841 r
.28629 .57616 m .28405 .57712 L .28262 .57359 L F
.517 .556 .835 r
.14124 .60548 m .13991 .60313 L .13948 .60359 L F
.14124 .60548 m .14286 .60344 L .13991 .60313 L F
.14124 .60548 m .14316 .60473 L .14286 .60344 L F
.645 .641 .831 r
.82034 .40605 m .82418 .40732 L .82299 .4053 L F
.58 .83 .992 r
.82034 .40605 m .82201 .40408 L .81932 .40465 L F
.82034 .40605 m .82299 .4053 L .82201 .40408 L F
.698 .698 .846 r
.82418 .40732 m .82659 .40617 L .82299 .4053 L F
.829 .877 .879 r
.76347 .40828 m .76659 .40804 L .76623 .40568 L F
.81 .866 .889 r
.76623 .40568 m .76659 .40804 L .76904 .40562 L F
.589 .869 .546 r
.76378 .39592 m .76223 .39776 L .76123 .39874 L F
.675 .561 .718 r
.26059 .64706 m .2616 .64972 L .25775 .64959 L F
.472 0 0 r
.25775 .64959 m .25919 .65133 L .25682 .65147 L F
.25775 .64959 m .2616 .64972 L .25919 .65133 L F
.585 .04 0 r
.51956 .5684 m .51978 .5691 L .51775 .56718 L F
.58 .116 0 r
.51956 .5684 m .52101 .57037 L .51978 .5691 L F
.51956 .5684 m .52224 .57187 L .52101 .57037 L F
.554 .282 .457 r
.45419 .57617 m .45344 .57732 L .45539 .57678 L F
.372 .413 .774 r
.42053 .65291 m .42345 .65478 L .42178 .65512 L F
.657 .273 .307 r
.42042 .65451 m .42345 .65478 L .42053 .65291 L F
.257 .143 .526 r
.13824 .59178 m .1399 .59074 L .13997 .58815 L F
.092 .147 .628 r
.1404 .5941 m .1399 .59074 L .13824 .59178 L F
0 .552 .77 r
.46067 .63133 m .45934 .63105 L .45687 .63078 L F
.504 0 0 r
.46315 .63139 m .46254 .63137 L .46186 .63015 L F
.46254 .63137 m .46017 .6313 L .46186 .63015 L F
0 0 .272 r
.46138 .6293 m .46186 .63015 L .46067 .63133 L F
.462 .62755 m .46186 .63015 L .46138 .6293 L F
.52 .9 .955 r
.46186 .63015 m .45934 .63105 L .46067 .63133 L F
.38 .61 .94 r
.1879 .61197 m .18721 .6138 L .18584 .61208 L F
.1879 .61197 m .19008 .61453 L .18721 .6138 L F
.604 .727 .932 r
.1923 .61417 m .19134 .61678 L .19008 .61453 L F
.1923 .61417 m .19329 .61595 L .19134 .61678 L F
.536 .003 0 r
.54298 .58095 m .54491 .58257 L .54296 .58109 L F
.654 .675 .857 r
.54708 .58153 m .54491 .58257 L .54298 .58095 L F
.641 .668 .86 r
.54901 .58325 m .54491 .58257 L .54708 .58153 L F
.954 .605 .272 r
.50879 .59063 m .50947 .58875 L .50781 .58766 L F
.50879 .59063 m .51019 .59142 L .50947 .58875 L F
.138 .618 .919 r
.25243 .53585 m .25446 .53611 L .25621 .53703 L F
.204 .698 .92 r
.25446 .53611 m .25845 .53668 L .25621 .53703 L F
.584 .172 .227 r
.18927 .5641 m .18581 .56614 L .18601 .56642 L F
.18927 .5641 m .18756 .56624 L .18581 .56614 L F
.101 0 0 r
.18962 .56547 m .18927 .5641 L .19147 .56377 L F
.18962 .56547 m .18756 .56624 L .18927 .5641 L F
.746 .836 .92 r
.79717 .42872 m .79316 .42931 L .79624 .42743 L F
.717 .847 .944 r
.7985 .4261 m .79717 .42872 L .79624 .42743 L F
.7985 .4261 m .79953 .42753 L .79717 .42872 L F
.395 .661 .966 r
.80977 .44518 m .81306 .44671 L .81216 .4451 L F
.523 .77 .987 r
.81306 .44671 m .81512 .44493 L .81216 .4451 L F
.81306 .44671 m .81608 .44625 L .81512 .44493 L F
.579 .877 .993 r
.81608 .44625 m .81987 .44621 L .81894 .44506 L F
.841 .914 .884 r
.81987 .44621 m .82057 .44337 L .81894 .44506 L F
.81987 .44621 m .8226 .44353 L .82057 .44337 L F
.186 0 .218 r
.4547 .62152 m .45651 .62077 L .45786 .61695 L F
.581 .274 .413 r
.45786 .61695 m .46049 .61806 L .46041 .61615 L F
.506 .187 .36 r
.45786 .61695 m .45898 .61996 L .46049 .61806 L F
.45786 .61695 m .45651 .62077 L .45898 .61996 L F
.638 .317 .412 r
.46049 .61806 m .46302 .61834 L .46041 .61615 L F
.625 .323 .438 r
.46041 .61615 m .46302 .61834 L .46318 .61621 L F
.576 .317 .487 r
.48175 .62796 m .48444 .6277 L .48446 .62544 L F
.409 .066 .269 r
.48444 .6277 m .48771 .62516 L .48446 .62544 L F
.258 0 .161 r
.16581 .55861 m .16694 .55954 L .16803 .55796 L F
.16581 .55861 m .16494 .56029 L .16694 .55954 L F
.72 .446 .511 r
.45958 .64576 m .4633 .64348 L .45974 .64329 L F
.45958 .64576 m .46364 .64605 L .4633 .64348 L F
.409 .521 .86 r
.32715 .55032 m .32603 .55248 L .32423 .54985 L F
.293 .377 .778 r
.32715 .55032 m .32857 .55426 L .32603 .55248 L F
.404 .376 .714 r
.32603 .55248 m .32857 .55426 L .32682 .55495 L F
.913 .72 .629 r
.20941 .74109 m .2091 .74402 L .2074 .7445 L F
.51 .352 .603 r
.2112 .743 m .2091 .74402 L .20941 .74109 L F
.2112 .743 m .2091 .74402 L .20941 .74109 L F
.942 .911 .531 r
.2254 .69424 m .22488 .69814 L .22693 .69785 L F
.806 .704 .752 r
.56828 .55832 m .56793 .56113 L .57014 .56099 L F
.835 .577 .549 r
.56806 .56333 m .57014 .56099 L .56793 .56113 L F
.56806 .56333 m .57205 .56419 L .57014 .56099 L F
.021 0 0 r
.49144 .59814 m .49238 .59896 L .49377 .59744 L F
.49144 .59814 m .49078 .59985 L .49238 .59896 L F
.007 .565 .811 r
.16495 .61559 m .1609 .61485 L .16256 .6162 L F
.674 .798 .941 r
.32283 .55002 m .31862 .54961 L .32101 .54903 L F
.456 .773 .997 r
.32297 .54865 m .32283 .55002 L .32101 .54903 L F
.32297 .54865 m .32423 .54985 L .32283 .55002 L F
.858 .684 .665 r
.42251 .67148 m .42241 .67433 L .42123 .67057 L F
.612 .475 .671 r
.42514 .67366 m .42251 .67148 L .4225 .67039 L F
.42514 .67366 m .42241 .67433 L .42251 .67148 L F
.808 .471 .419 r
.57685 .57548 m .57883 .57371 L .57497 .57262 L F
.954 .759 .601 r
.57685 .57548 m .57844 .57627 L .57883 .57371 L F
.835 .589 .567 r
.57205 .56419 m .57336 .56705 L .57343 .56447 L F
.881 .693 .644 r
.57161 .51805 m .56913 .52068 L .57245 .52144 L F
.909 .705 .615 r
.56912 .52335 m .57245 .52144 L .56913 .52068 L F
.56912 .52335 m .57304 .52573 L .57245 .52144 L F
.676 .229 .183 r
.46843 .65259 m .46695 .65427 L .47105 .65457 L F
.778 .714 .791 r
.44869 .57908 m .45248 .57957 L .45344 .57732 L F
.784 .7 .771 r
.44869 .57908 m .44946 .58115 L .45248 .57957 L F
.512 .344 .59 r
.45248 .57957 m .45539 .57678 L .45344 .57732 L F
.45248 .57957 m .4549 .57919 L .45539 .57678 L F
0 0 .441 r
.47105 .65457 m .47123 .65748 L .46976 .65867 L F
0 0 0 r
.46976 .65867 m .47014 .65976 L .4685 .66056 L F
.46976 .65867 m .47123 .65748 L .47014 .65976 L F
.281 0 .012 r
.17361 .55427 m .17578 .55383 L .1773 .55223 L F
.047 0 0 r
.1773 .55223 m .17578 .55383 L .17917 .55152 L F
.461 .682 .961 r
.84014 .42931 m .83866 .43018 L .83764 .42966 L F
.438 .721 .985 r
.84014 .42931 m .83764 .42966 L .83701 .4285 L F
.325 .643 .966 r
.83764 .42966 m .83866 .43018 L .83701 .4285 L F
.846 .841 .84 r
.83701 .4285 m .83866 .43018 L .83617 .43218 L F
0 0 0 r
.84014 .42931 m .83745 .43149 L .83866 .43018 L F
.266 0 .161 r
.25484 .62172 m .25272 .62245 L .25184 .6241 L F
.198 0 .298 r
.25788 .61839 m .25962 .61832 L .26032 .61587 L F
.136 0 0 r
.25823 .61985 m .25788 .61839 L .25643 .62073 L F
.25823 .61985 m .25962 .61832 L .25788 .61839 L F
.897 .681 .602 r
.57304 .52573 m .57069 .52722 L .57379 .52775 L F
.862 .669 .64 r
.57011 .52948 m .57379 .52775 L .57069 .52722 L F
.57011 .52948 m .57322 .52986 L .57379 .52775 L F
.47 .504 .811 r
.16863 .59112 m .16711 .59285 L .16522 .58906 L F
.458 .462 .774 r
.16948 .59422 m .16711 .59285 L .16863 .59112 L F
.648 .417 .556 r
.48051 .60621 m .48345 .60641 L .4827 .60391 L F
.311 .222 .59 r
.4827 .60391 m .48345 .60641 L .485 .60552 L F
.352 .575 .925 r
.21893 .6277 m .21497 .62504 L .21691 .62479 L F
.562 .709 .939 r
.21913 .62496 m .21893 .6277 L .21691 .62479 L F
.21913 .62496 m .22112 .62719 L .21893 .6277 L F
.079 .185 .675 r
.49852 .58821 m .4988 .58472 L .49811 .58531 L F
.49852 .58821 m .4999 .58696 L .4988 .58472 L F
.166 .336 .79 r
.49852 .58821 m .50147 .59056 L .4999 .58696 L F
.468 .627 .922 r
.15365 .60856 m .15471 .61023 L .15563 .60833 L F
.319 .445 .832 r
.15471 .61023 m .1573 .61185 L .15563 .60833 L F
.393 .365 .709 r
.13947 .59781 m .14049 .59404 L .1404 .5941 L F
.13947 .59781 m .14135 .5972 L .14049 .59404 L F
.667 .608 .78 r
.1408 .60042 m .13947 .59781 L .13919 .60035 L F
.1408 .60042 m .14135 .5972 L .13947 .59781 L F
.052 .616 .775 r
.3011 .54189 m .30321 .54188 L .30496 .54204 L F
.206 0 0 r
.30321 .54188 m .30711 .54248 L .30496 .54204 L F
.272 0 .119 r
.49523 .60092 m .49428 .60263 L .49228 .60295 L F
.673 .911 .584 r
.49617 .59933 m .49523 .60092 L .49771 .59794 L F
.472 .386 .678 r
.49617 .59933 m .49428 .60263 L .49523 .60092 L F
.462 .513 .825 r
.77096 .41663 m .76945 .41948 L .76835 .41719 L F
.77096 .41663 m .77243 .42015 L .76945 .41948 L F
.505 .376 .639 r
.32659 .55753 m .3245 .5626 L .32414 .55809 L F
.431 .631 .938 r
.76771 .41536 m .76596 .41712 L .76399 .41533 L F
.76771 .41536 m .76835 .41719 L .76596 .41712 L F
.702 .477 .58 r
.47187 .64286 m .47568 .64022 L .47235 .64035 L F
.47187 .64286 m .4755 .64333 L .47568 .64022 L F
.6 .39 .568 r
.47568 .64022 m .47816 .64283 L .47766 .64035 L F
.47568 .64022 m .4755 .64333 L .47816 .64283 L F
.246 .325 .748 r
.47816 .64283 m .47568 .64022 L .47766 .64035 L F
.662 .186 .112 r
.49377 .59744 m .49617 .59933 L .49771 .59794 L F
.513 .294 .519 r
.44354 .58252 m .44597 .58213 L .44625 .57949 L F
.508 .29 .518 r
.44625 .57949 m .44597 .58213 L .44869 .57908 L F
.363 .769 .983 r
.29317 .53952 m .29481 .5403 L .29096 .53976 L F
.405 .737 .992 r
.29541 .53891 m .29481 .5403 L .29317 .53952 L F
.29541 .53891 m .29714 .54014 L .29481 .5403 L F
.515 .305 .533 r
.42345 .65478 m .4209 .65789 L .42178 .65512 L F
.194 .725 .793 r
.27087 .53655 m .27317 .53616 L .27512 .53606 L F
.293 .777 .912 r
.27317 .53616 m .27709 .5361 L .27512 .53606 L F
.444 .153 .375 r
.47853 .61218 m .47788 .61527 L .47548 .61574 L F
.523 .29 .503 r
.48143 .60972 m .48126 .61169 L .47853 .61218 L F
.473 .175 .378 r
.48126 .61169 m .47788 .61527 L .47853 .61218 L F
.082 0 0 r
.20872 .53977 m .21099 .53965 L .21253 .53932 L F
.367 .817 .941 r
.21099 .53965 m .21484 .53951 L .21253 .53932 L F
.137 .359 .817 r
.47426 .63643 m .47187 .63454 L .47436 .636 L F
.739 .225 0 r
.43352 .65256 m .43323 .65398 L .43574 .65465 L F
.364 .577 .923 r
.17718 .62606 m .17792 .62439 L .17632 .62444 L F
.17718 .62606 m .18057 .62781 L .17792 .62439 L F
.726 .636 .757 r
.66862 .42165 m .66612 .42473 L .66851 .42391 L F
.72 .604 .726 r
.66851 .42391 m .67083 .42065 L .66862 .42165 L F
.837 .441 .297 r
.51402 .61586 m .51052 .61283 L .51122 .616 L F
.189 0 .299 r
.51122 .616 m .51269 .61747 L .51402 .61586 L F
.51122 .616 m .51085 .61881 L .51269 .61747 L F
.446 .286 .57 r
.31163 .60368 m .31155 .60632 L .30941 .60694 L F
.504 .282 .51 r
.31153 .60892 m .30941 .60694 L .31155 .60632 L F
.31153 .60892 m .30918 .60942 L .30941 .60694 L F
.644 .442 .594 r
.31946 .59149 m .31564 .59428 L .31549 .59164 L F
.31946 .59149 m .31909 .59422 L .31564 .59428 L F
.613 .511 .715 r
.32052 .58765 m .32143 .59143 L .31946 .59149 L F
.582 .385 .58 r
.32138 .59387 m .31946 .59149 L .32143 .59143 L F
.32138 .59387 m .31909 .59422 L .31946 .59149 L F
.777 .564 .611 r
.51937 .55462 m .52287 .55772 L .52319 .55519 L F
.612 .731 .93 r
.81113 .42638 m .80943 .42949 L .80848 .42729 L F
.81113 .42638 m .81226 .42866 L .80943 .42949 L F
.19 .716 .708 r
.22161 .53746 m .22137 .53757 L .21943 .53743 L F
.22161 .53746 m .22354 .53702 L .22137 .53757 L F
.547 .317 .518 r
.43572 .67057 m .43645 .67322 L .43398 .67365 L F
.344 .366 .74 r
.43605 .66821 m .43842 .66945 L .43572 .67057 L F
0 0 .49 r
.43705 .67284 m .43572 .67057 L .43842 .66945 L F
.43705 .67284 m .43645 .67322 L .43572 .67057 L F
0 .215 .733 r
.48116 .56094 m .48356 .56323 L .48636 .56244 L F
.48116 .56094 m .48336 .56387 L .48356 .56323 L F
.462 .515 .827 r
.26876 .55468 m .27034 .55794 L .27169 .55571 L F
.356 .379 .747 r
.27034 .55794 m .272 .55812 L .27169 .55571 L F
.26 0 0 r
.26756 .64236 m .27198 .63984 L .2704 .64185 L F
.26756 .64236 m .26904 .64087 L .27198 .63984 L F
.218 0 .145 r
.27198 .63984 m .27289 .64159 L .2704 .64185 L F
.27198 .63984 m .27344 .63997 L .27289 .64159 L F
.759 .662 .754 r
.55114 .58013 m .54901 .58325 L .54708 .58153 L F
.489 .242 .466 r
.47548 .61574 m .47278 .61842 L .47307 .6161 L F
.476 .882 .947 r
.23755 .62623 m .23326 .62672 L .23552 .62657 L F
.18 0 0 r
.23552 .62657 m .23981 .6258 L .23755 .62623 L F
.507 .228 .425 r
.48393 .60957 m .48126 .61169 L .48143 .60972 L F
.525 .87 .99 r
.20534 .64057 m .20889 .64051 L .20749 .63922 L F
.28 .637 .965 r
.20889 .64051 m .20923 .63927 L .20749 .63922 L F
.266 .622 .96 r
.20889 .64051 m .21077 .64067 L .20923 .63927 L F
0 .158 .69 r
.20889 .64051 m .21175 .6452 L .21077 .64067 L F
.625 .864 .988 r
.23065 .7055 m .22996 .70725 L .22803 .70633 L F
.957 .721 .54 r
.22803 .70633 m .22996 .70725 L .23065 .7055 L F
.22803 .70633 m .2296 .70989 L .22996 .70725 L F
0 0 .21 r
.14648 .57608 m .14847 .57259 L .14669 .57344 L F
.94 .577 .276 r
.7944 .40522 m .79215 .40185 L .79405 .40309 L F
.383 .837 .919 r
.24368 .62537 m .23981 .6258 L .24151 .62598 L F
0 0 0 r
.24393 .62539 m .24368 .62537 L .24151 .62598 L F
.24393 .62539 m .24589 .62515 L .24368 .62537 L F
.243 0 0 r
.81173 .39839 m .81445 .39839 L .81507 .39774 L F
.893 .483 .073 r
.52557 .57595 m .52425 .57496 L .5235 .57292 L F
.686 .334 0 r
.52584 .57863 m .52425 .57496 L .52557 .57595 L F
.776 .556 .601 r
.51912 .54884 m .52171 .55099 L .5226 .54968 L F
.51912 .54884 m .51857 .55149 L .52171 .55099 L F
.796 .646 .697 r
.51857 .55149 m .51937 .55462 L .52171 .55099 L F
.267 .699 .965 r
.14774 .60583 m .14772 .60484 L .14582 .6047 L F
.14774 .60583 m .14969 .60583 L .14772 .60484 L F
.656 .768 .932 r
.19135 .63503 m .19264 .63775 L .19506 .63705 L F
.776 .556 .601 r
.51912 .54884 m .5226 .54968 L .5205 .54806 L F
.412 .838 .684 r
.24967 .66533 m .24535 .66766 L .24759 .667 L F
0 0 0 r
.2516 .66196 m .24967 .66533 L .24976 .66556 L F
.24976 .66556 m .24967 .66533 L .24759 .667 L F
0 0 .28 r
.26521 .60965 m .26675 .60869 L .26719 .60624 L F
.114 0 .274 r
.26521 .60965 m .26647 .61121 L .26675 .60869 L F
.26521 .60965 m .26497 .61214 L .26647 .61121 L F
.128 0 .202 r
.16632 .58156 m .16456 .58256 L .16709 .57938 L F
.353 .205 .537 r
.16905 .57591 m .16884 .57874 L .16709 .57938 L F
.365 .064 .315 r
.16815 .58065 m .16709 .57938 L .16884 .57874 L F
.16815 .58065 m .16632 .58156 L .16709 .57938 L F
0 0 .442 r
.53202 .57216 m .53374 .57497 L .53289 .57373 L F
.816 .626 .645 r
.5672 .55192 m .56683 .55453 L .57051 .55511 L F
.813 .626 .649 r
.56683 .55453 m .57063 .55696 L .57051 .55511 L F
.047 0 .049 r
.23136 .69085 m .22923 .69163 L .22855 .69315 L F
.519 .474 .746 r
.4684 .63587 m .47066 .63682 L .47045 .63452 L F
.728 .697 .821 r
.46825 .64257 m .46855 .64606 L .47187 .64286 L F
.672 .297 .327 r
.47152 .61184 m .47431 .61238 L .4716 .6101 L F
.628 .465 .642 r
.4716 .6101 m .47436 .60988 L .47406 .60705 L F
.596 .335 .491 r
.4716 .6101 m .47431 .61238 L .47436 .60988 L F
.525 .333 .562 r
.47436 .60988 m .47562 .60792 L .47406 .60705 L F
.328 0 .037 r
.18956 .54632 m .19171 .54637 L .19407 .54355 L F
.143 0 0 r
.19407 .54355 m .19545 .54367 L .19616 .54315 L F
.19407 .54355 m .19171 .54637 L .19545 .54367 L F
.491 .292 .536 r
.44174 .58505 m .44365 .58533 L .44354 .58252 L F
.623 .446 .621 r
.44365 .58533 m .44597 .58213 L .44354 .58252 L F
.918 .798 .712 r
.55789 .55742 m .55528 .5572 L .55675 .55412 L F
.894 .797 .312 r
.55513 .56084 m .55528 .5572 L .55789 .55742 L F
.729 .715 .838 r
.56056 .55465 m .55789 .55742 L .55675 .55412 L F
.585 .403 .601 r
.42764 .67036 m .43053 .67011 L .43018 .66752 L F
.844 .549 .489 r
.55765 .52472 m .55476 .52608 L .55413 .52391 L F
.55765 .52472 m .55784 .52708 L .55476 .52608 L F
.898 .684 .605 r
.56877 .52594 m .57304 .52573 L .56912 .52335 L F
.56877 .52594 m .57069 .52722 L .57304 .52573 L F
.558 .462 .701 r
.32857 .55426 m .32659 .55753 L .32682 .55495 L F
.76 .681 .775 r
.49713 .56978 m .49392 .5735 L .49835 .5738 L F
.694 .154 0 r
.49729 .5743 m .50024 .57578 L .49835 .5738 L F
.452 .117 .306 r
.20041 .55825 m .19948 .56066 L .19715 .56094 L F
.37 .04 .269 r
.20217 .5597 m .19948 .56066 L .20041 .55825 L F
.449 .02 .132 r
.203 .5581 m .20217 .5597 L .20041 .55825 L F
.557 .677 .919 r
.78326 .4405 m .78495 .43797 L .78275 .43809 L F
.78326 .4405 m .786 .4401 L .78495 .43797 L F
.498 .232 .442 r
.54523 .51255 m .54767 .51205 L .5481 .50975 L F
.529 .21 .371 r
.54767 .51205 m .55126 .50923 L .5481 .50975 L F
0 0 0 r
.16456 .58256 m .16241 .58408 L .16137 .58457 L F
.168 0 0 r
.16508 .58342 m .16456 .58256 L .16632 .58156 L F
.16508 .58342 m .16241 .58408 L .16456 .58256 L F
.968 .781 .597 r
.5127 .60876 m .51489 .60677 L .51314 .60576 L F
.5127 .60876 m .51424 .60972 L .51489 .60677 L F
.795 .57 .596 r
.56356 .51474 m .56717 .51238 L .56377 .51187 L F
.56356 .51474 m .56729 .51534 L .56717 .51238 L F
.449 .258 .528 r
.30169 .61859 m .29939 .62166 L .29935 .61914 L F
.905 .984 .748 r
.5772 .59054 m .57981 .58805 L .57896 .58735 L F
.5772 .59054 m .57766 .59113 L .57981 .58805 L F
.273 .411 .819 r
.77522 .42955 m .77531 .42633 L .77412 .42569 L F
.77522 .42955 m .77669 .42795 L .77531 .42633 L F
.77522 .42955 m .77699 .42972 L .77669 .42795 L F
.203 0 .252 r
.46997 .62098 m .46792 .62201 L .47048 .61905 L F
.386 .047 .263 r
.47022 .62321 m .46792 .62201 L .46997 .62098 L F
.47022 .62321 m .46672 .62408 L .46792 .62201 L F
.451 .565 .878 r
.15084 .60761 m .15181 .60542 L .14969 .60583 L F
.15084 .60761 m .15365 .60856 L .15181 .60542 L F
.931 .561 .284 r
.51289 .56096 m .51106 .56006 L .51073 .55789 L F
.837 .373 .087 r
.51289 .56096 m .51331 .56348 L .51106 .56006 L F
.51289 .56096 m .51449 .56342 L .51331 .56348 L F
.372 .56 .908 r
.44174 .58505 m .44461 .58581 L .44365 .58533 L F
.759 .664 .757 r
.75299 .40297 m .75556 .39997 L .75401 .40138 L F
.489 .266 .501 r
.42123 .67057 m .4236 .67009 L .42297 .66791 L F
.502 .252 .468 r
.2861 .63118 m .28589 .63344 L .28349 .63371 L F
.56 .3 .479 r
.2861 .63118 m .28822 .63329 L .28589 .63344 L F
.514 .302 .529 r
.28844 .63074 m .28822 .63329 L .2861 .63118 L F
.962 .765 .59 r
.49297 .54932 m .49209 .54596 L .4894 .54599 L F
.835 .528 .469 r
.56729 .51534 m .5673 .51734 L .57161 .51805 L F
.848 .632 .611 r
.5673 .51734 m .56913 .52068 L .57161 .51805 L F
.274 .387 .797 r
.4236 .67009 m .42514 .67366 L .4225 .67039 L F
.344 .506 .875 r
.18771 .63339 m .18872 .63513 L .19135 .63503 L F
.759 .662 .754 r
.55114 .58013 m .54708 .58153 L .54963 .57836 L F
.221 .298 .731 r
.18895 .82621 m .19118 .82829 L .18981 .82899 L F
.329 .096 .401 r
.19118 .82829 m .18869 .83136 L .18981 .82899 L F
.526 .246 .433 r
.28238 .63412 m .27996 .63726 L .27759 .63746 L F
.28396 .63598 m .28238 .63412 L .28349 .63371 L F
.28396 .63598 m .27996 .63726 L .28238 .63412 L F
.549 .333 .539 r
.47911 .63085 m .48175 .62796 L .47915 .62834 L F
.962 .765 .59 r
.49297 .54932 m .49133 .54873 L .49209 .54596 L F
.798 .332 0 r
.49238 .54981 m .49427 .55293 L .49286 .55184 L F
.49238 .54981 m .49286 .55184 L .49281 .55123 L F
.651 .094 0 r
.49297 .54932 m .49238 .54981 L .49215 .54902 L F
.49297 .54932 m .49553 .55147 L .49238 .54981 L F
.843 .422 .235 r
.49553 .55147 m .49427 .55293 L .49238 .54981 L F
.798 .332 0 r
.49238 .54981 m .49281 .55123 L .49258 .54857 L F
.651 .094 0 r
.49215 .54902 m .49238 .54981 L .49133 .54873 L F
.693 .159 0 r
.49723 .5517 m .49553 .55147 L .49297 .54932 L F
.813 .833 .866 r
.32385 .57336 m .32155 .57616 L .32221 .57512 L F
.608 .505 .711 r
.32409 .57568 m .32155 .57616 L .32385 .57336 L F
.54 .421 .667 r
.32426 .57832 m .32155 .57616 L .32409 .57568 L F
.32426 .57832 m .32194 .57901 L .32155 .57616 L F
.703 .853 .954 r
.22693 .69785 m .23091 .69776 L .23017 .69643 L F
.204 .729 .837 r
.23091 .69776 m .23169 .69736 L .23017 .69643 L F
.23091 .69776 m .23299 .69749 L .23169 .69736 L F
.424 .132 .362 r
.47278 .61842 m .46997 .62098 L .47048 .61905 L F
.633 .563 .757 r
.42123 .67057 m .42241 .67433 L .42514 .67366 L F
.206 .733 .799 r
.23122 .64372 m .23545 .64316 L .2337 .64307 L F
.108 .66 .797 r
.23545 .64316 m .23751 .64309 L .2337 .64307 L F
.344 .781 .966 r
.22354 .53702 m .22554 .53674 L .22754 .53735 L F
.105 .632 .875 r
.22754 .53735 m .22751 .53673 L .22975 .53679 L F
.22754 .53735 m .22605 .5369 L .22751 .53673 L F
0 0 0 r
.22751 .53673 m .22605 .53712 L .22825 .53665 L F
.212 .731 .861 r
.23001 .53627 m .22975 .53679 L .22751 .53673 L F
0 0 0 r
.22751 .53673 m .22825 .53665 L .23001 .53627 L F
.105 .632 .875 r
.22605 .5369 m .22554 .53674 L .22751 .53673 L F
0 .458 .838 r
.25432 .64318 m .25386 .64335 L .25575 .64378 L F
.25432 .64318 m .25386 .64335 L .25575 .64378 L F
.648 .143 .032 r
.25386 .64335 m .25773 .64455 L .25575 .64378 L F
.612 .658 .871 r
.25773 .64455 m .25386 .64335 L .25575 .64378 L F
.717 .734 .864 r
.55513 .60089 m .55882 .60146 L .5573 .59982 L F
.694 .769 .909 r
.55882 .60146 m .56022 .5989 L .5573 .59982 L F
.55882 .60146 m .56188 .6009 L .56022 .5989 L F
.568 .756 .966 r
.51101 .61992 m .51269 .61747 L .51085 .61881 L F
.51101 .61992 m .5146 .61906 L .51269 .61747 L F
.175 0 .334 r
.2677 .60388 m .26875 .6054 L .26932 .60307 L F
.2677 .60388 m .26719 .60624 L .26875 .6054 L F
.779 .702 .779 r
.75401 .40138 m .75556 .39997 L .75344 .39816 L F
.868 .897 .852 r
.75556 .39997 m .757 .3956 L .75344 .39816 L F
.75556 .39997 m .75827 .3969 L .757 .3956 L F
.45 .653 .946 r
.21574 .62308 m .21497 .62504 L .21323 .62367 L F
.21574 .62308 m .21691 .62479 L .21497 .62504 L F
.678 .168 .021 r
.79785 .406 m .79707 .40717 L .7944 .40522 L F
.596 .075 0 r
.79785 .406 m .80074 .40764 L .79707 .40717 L F
.613 .818 .979 r
.17334 .5946 m .16948 .59422 L .1712 .59349 L F
.746 .495 .55 r
.17334 .5946 m .16926 .59469 L .16948 .59422 L F
.17334 .5946 m .17342 .59678 L .16926 .59469 L F
.548 .567 .826 r
.17399 .59053 m .17334 .5946 L .1712 .59349 L F
.17399 .59053 m .17576 .59415 L .17334 .5946 L F
.491 .296 .543 r
.17576 .59415 m .17342 .59678 L .17334 .5946 L F
.507 .333 .58 r
.30905 .61207 m .3068 .60991 L .30918 .60942 L F
.30905 .61207 m .30676 .61262 L .3068 .60991 L F
.542 .488 .745 r
.26375 .64908 m .2616 .64972 L .26059 .64706 L F
0 0 0 r
.25919 .65133 m .2616 .64972 L .26375 .64908 L F
.542 .488 .745 r
.26375 .64908 m .26059 .64706 L .26181 .64571 L F
.616 .358 .504 r
.47323 .63348 m .47548 .63359 L .4731 .63114 L F
.105 0 0 r
.16176 .5627 m .16494 .56029 L .16296 .56116 L F
.552 .578 .834 r
.82333 .42546 m .82225 .42932 L .82149 .42697 L F
.82333 .42546 m .82489 .42897 L .82225 .42932 L F
.384 .65 .962 r
.26679 .64202 m .26652 .64347 L .26756 .64236 L F
.7 .683 .143 r
.26607 .6457 m .26652 .64347 L .26679 .64202 L F
.852 .68 .146 r
.49391 .57021 m .49392 .5735 L .49363 .5718 L F
.877 .948 .854 r
.49363 .5718 m .49713 .56978 L .49391 .57021 L F
.74 .469 .519 r
.51333 .5546 m .51369 .55204 L .51301 .55051 L F
.51333 .5546 m .51547 .55493 L .51369 .55204 L F
.639 .449 .61 r
.28848 .58503 m .28858 .58571 L .28549 .58559 L F
.569 .705 .934 r
.28832 .58553 m .28858 .58571 L .28836 .58553 L F
.28549 .58559 m .28748 .58567 L .28832 .58553 L F
.28748 .58567 m .28858 .58571 L .28832 .58553 L F
.545 .383 .613 r
.29104 .58471 m .28858 .58571 L .28848 .58503 L F
.55 .286 .469 r
.28832 .58553 m .29104 .58471 L .28848 .58503 L F
.28764 .58768 m .29049 .58519 L .28832 .58553 L F
.28836 .58553 m .29104 .58471 L .28832 .58553 L F
.583 .294 .444 r
.28549 .58559 m .28832 .58553 L .28848 .58503 L F
.653 .726 .902 r
.28677 .58421 m .28836 .58553 L .29104 .58471 L F
.28836 .58553 m .28858 .58571 L .29104 .58471 L F
.55 .286 .469 r
.29049 .58519 m .29104 .58471 L .28836 .58553 L F
.583 .294 .444 r
.28549 .58559 m .28764 .58768 L .28832 .58553 L F
.569 .705 .934 r
.28549 .58559 m .28836 .58553 L .28677 .58421 L F
.296 .281 .673 r
.28677 .58421 m .28764 .58768 L .28549 .58559 L F
.668 .868 .975 r
.79633 .44258 m .79968 .44264 L .79854 .44121 L F
.625 .654 .858 r
.79968 .44264 m .8011 .43855 L .79854 .44121 L F
.79968 .44264 m .80233 .44176 L .8011 .43855 L F
.523 .319 .544 r
.50681 .6134 m .50896 .6098 L .5073 .61044 L F
.50681 .6134 m .50837 .61124 L .50896 .6098 L F
.774 .655 .731 r
.50837 .61124 m .50681 .6134 L .5073 .61044 L F
.51052 .61283 m .50811 .6132 L .50867 .61146 L F
.51052 .61283 m .50837 .61124 L .50896 .6098 L F
.50811 .6132 m .50681 .6134 L .50867 .61146 L F
.264 .772 .827 r
.51052 .61283 m .50911 .61293 L .50811 .6132 L F
.523 .319 .544 r
.50752 .6133 m .50936 .61303 L .50934 .61286 L F
.774 .655 .731 r
.50867 .61146 m .50681 .6134 L .50837 .61124 L F
.523 .319 .544 r
.50754 .61325 m .50901 .61293 L .50896 .6098 L F
.50901 .61293 m .50933 .61279 L .50896 .6098 L F
.293 .158 .52 r
.50915 .60994 m .50934 .61278 L .51139 .6115 L F
0 .152 .682 r
.51106 .61201 m .51139 .6115 L .50933 .61279 L F
.293 .158 .52 r
.50934 .61278 m .50935 .61286 L .51139 .6115 L F
.50903 .61033 m .50933 .61279 L .50915 .60994 L F
0 .152 .682 r
.51052 .61283 m .50933 .61279 L .50911 .61293 L F
.293 .158 .52 r
.50933 .61279 m .50936 .61303 L .50934 .61278 L F
.50933 .61279 m .50934 .61278 L .50915 .60994 L F
0 .152 .682 r
.51052 .61283 m .51106 .61201 L .50933 .61279 L F
.50911 .61293 m .50933 .61279 L .50901 .61293 L F
.50933 .61279 m .51139 .6115 L .50901 .61293 L F
.50901 .61293 m .51139 .6115 L .50799 .613 L F
.523 .319 .544 r
.50901 .61293 m .50934 .61286 L .50933 .61279 L F
.264 .772 .827 r
.50811 .6132 m .50807 .61313 L .50681 .6134 L F
.50911 .61293 m .50799 .613 L .50811 .6132 L F
.523 .319 .544 r
.50752 .6133 m .50934 .61286 L .50754 .61325 L F
.264 .772 .827 r
.50807 .61313 m .50799 .613 L .50681 .6134 L F
.293 .158 .52 r
.50935 .61286 m .50936 .61303 L .50973 .61275 L F
.50935 .61286 m .50973 .61275 L .51139 .6115 L F
.50896 .6098 m .50903 .61033 L .50915 .60994 L F
.523 .319 .544 r
.50681 .6134 m .50752 .6133 L .50837 .61124 L F
.774 .655 .731 r
.50837 .61124 m .5073 .61044 L .50896 .6098 L F
.837 .441 .297 r
.51402 .61586 m .51275 .6161 L .51052 .61283 L F
0 .152 .682 r
.51052 .61283 m .51275 .6161 L .51139 .6115 L F
.471 .346 .628 r
.17381 .60073 m .17426 .60329 L .17226 .60379 L F
.779 .702 .779 r
.75401 .40138 m .75344 .39816 L .75156 .39716 L F
.985 .706 .379 r
.51046 .62811 m .50915 .62745 L .50911 .62459 L F
.51046 .62811 m .50915 .62745 L .50911 .62459 L F
0 .187 .717 r
.25432 .64318 m .25497 .64337 L .25394 .64335 L F
.241 0 .057 r
.25826 .64567 m .25773 .64455 L .25575 .64378 L F
.663 .485 .634 r
.25575 .64378 m .25835 .64219 L .25432 .64318 L F
.745 .873 .939 r
.25773 .64455 m .25805 .64332 L .25575 .64378 L F
.25805 .64332 m .25835 .64219 L .25646 .64335 L F
.25805 .64332 m .25646 .64335 L .25575 .64378 L F
.757 .501 .546 r
.25521 .64421 m .25826 .64567 L .25575 .64378 L F
.2559 .64513 m .25826 .64567 L .25521 .64421 L F
.736 .623 .733 r
.25595 .64767 m .2569 .64685 L .25448 .6448 L F
.731 .21 0 r
.25818 .64282 m .25847 .64376 L .25737 .64579 L F
.25835 .64219 m .25836 .64238 L .25818 .64282 L F
.25836 .64238 m .25847 .64376 L .25818 .64282 L F
.736 .623 .733 r
.2569 .64685 m .25826 .64567 L .25709 .6454 L F
.25666 .64643 m .25709 .6454 L .2559 .64513 L F
.2569 .64685 m .25709 .6454 L .25666 .64643 L F
.2569 .64685 m .2559 .64513 L .25448 .6448 L F
.543 .202 .341 r
.25432 .64318 m .25835 .64219 L .25737 .64579 L F
0 .187 .717 r
.25485 .64334 m .25737 .64579 L .25716 .644 L F
.25448 .64323 m .25512 .6438 L .25485 .64334 L F
.25512 .6438 m .25737 .64579 L .25485 .64334 L F
.25432 .64318 m .25466 .64347 L .25448 .64323 L F
.25466 .64347 m .25737 .64579 L .25448 .64323 L F
.757 .501 .546 r
.25448 .6448 m .2559 .64513 L .25521 .64421 L F
0 .187 .717 r
.25497 .64337 m .25716 .644 L .25412 .64339 L F
.25497 .64337 m .25412 .64339 L .25394 .64335 L F
.743 .993 .83 r
.5689 .59659 m .56829 .5981 L .56949 .59677 L F
.685 .807 .352 r
.56718 .60036 m .56829 .5981 L .5689 .59659 L F
.803 .879 .902 r
.83123 .44016 m .83292 .43842 L .83003 .43871 L F
.491 .439 .726 r
.32738 .56191 m .32522 .56385 L .3245 .5626 L F
.32738 .56191 m .32733 .56344 L .32522 .56385 L F
.33 .439 .821 r
.32805 .56654 m .32522 .56385 L .32733 .56344 L F
.32805 .56654 m .32773 .56693 L .32522 .56385 L F
.717 .202 0 r
.25674 .55467 m .25831 .55688 L .25662 .55571 L F
.693 .24 .171 r
.25964 .55627 m .25831 .55688 L .25674 .55467 L F
.717 .202 0 r
.25674 .55467 m .25662 .55571 L .25828 .55392 L F
.078 0 .177 r
.25674 .55467 m .25828 .55392 L .25938 .55137 L F
.769 .921 .938 r
.8226 .44353 m .82375 .44094 L .82057 .44337 L F
.8226 .44353 m .82459 .44206 L .82375 .44094 L F
.48 .799 1 r
.26066 .53628 m .26464 .53687 L .26237 .53741 L F
.836 .59 .567 r
.56804 .56585 m .57205 .56419 L .56806 .56333 L F
.56804 .56585 m .5718 .56684 L .57205 .56419 L F
.835 .589 .567 r
.57205 .56419 m .5718 .56684 L .57336 .56705 L F
.622 .067 0 r
.50713 .6013 m .50683 .60208 L .50373 .60023 L F
.49 0 0 r
.50713 .6013 m .50992 .60263 L .50683 .60208 L F
.307 .079 .396 r
.31909 .59422 m .31638 .59767 L .31564 .59428 L F
.708 .822 .936 r
.83549 .40525 m .83905 .40549 L .83815 .40386 L F
.652 .788 .947 r
.83815 .40386 m .83905 .40549 L .84176 .40452 L F
.311 .77 .948 r
.22975 .53679 m .23195 .53655 L .23372 .53706 L F
.202 .723 .864 r
.23195 .53655 m .23598 .53655 L .23372 .53706 L F
.488 .401 .683 r
.27774 .56412 m .27877 .56079 L .2778 .56341 L F
.27774 .56412 m .27984 .56514 L .27877 .56079 L F
.598 .272 .388 r
.27774 .56412 m .27971 .56617 L .27984 .56514 L F
.465 .813 .998 r
.26464 .53687 m .2669 .53642 L .26867 .5373 L F
.402 .818 .973 r
.2669 .53642 m .27087 .53655 L .26867 .5373 L F
.463 .154 .357 r
.1517 .56999 m .15405 .56962 L .15478 .56752 L F
.162 0 .219 r
.15478 .56752 m .1558 .56861 L .15679 .56693 L F
.15478 .56752 m .15405 .56962 L .1558 .56861 L F
.452 .233 .489 r
.49428 .60263 m .49198 .60577 L .49228 .60295 L F
.846 .841 .84 r
.83701 .4285 m .83617 .43218 L .83468 .43099 L F
.529 .21 .371 r
.54767 .51205 m .55026 .51177 L .55126 .50923 L F
.67 .355 .432 r
.55026 .51177 m .55373 .51154 L .55126 .50923 L F
.672 .496 .639 r
.48494 .56494 m .48336 .56387 L .48434 .56359 L F
.48683 .56622 m .48565 .56653 L .48336 .56387 L F
0 .181 .715 r
.48336 .56387 m .48565 .56653 L .48458 .56416 L F
.652 .296 0 r
.48558 .56637 m .48562 .56648 L .48458 .56416 L F
.48565 .56653 m .48565 .56652 L .48558 .56637 L F
.48565 .56652 m .48562 .56648 L .48558 .56637 L F
.672 .496 .639 r
.48683 .56622 m .48494 .56494 L .48706 .56282 L F
.48494 .56494 m .48434 .56359 L .48706 .56282 L F
.63 .126 .035 r
.48636 .56244 m .48972 .56361 L .48706 .56282 L F
.512 .235 .431 r
.48683 .56622 m .48972 .56361 L .48706 .56282 L F
.84 .979 .682 r
.2721 .59754 m .26991 .60093 L .27066 .59881 L F
0 0 .337 r
.26932 .60307 m .27066 .59881 L .26991 .60093 L F
.271 .769 .889 r
.19616 .54315 m .19842 .54278 L .20013 .54297 L F
.352 .817 .917 r
.19842 .54278 m .20237 .54248 L .20013 .54297 L F
.505 .376 .639 r
.32659 .55753 m .32738 .56191 L .3245 .5626 L F
.322 .077 .379 r
.46318 .61621 m .46513 .61743 L .46591 .61505 L F
.46318 .61621 m .46302 .61834 L .46513 .61743 L F
.322 0 .206 r
.15679 .56693 m .15895 .56638 L .16006 .56381 L F
.229 0 .162 r
.16006 .56381 m .16099 .56555 L .16176 .5627 L F
.16006 .56381 m .15895 .56638 L .16099 .56555 L F
.745 .282 .15 r
.55413 .52391 m .54999 .52149 L .55406 .52157 L F
.597 .664 .886 r
.83066 .43091 m .8294 .43374 L .82855 .43121 L F
.83066 .43091 m .83221 .43306 L .8294 .43374 L F
.947 .878 .735 r
.757 .3956 m .75827 .3969 L .75958 .39332 L F
.549 .711 .947 r
.56022 .5989 m .56188 .6009 L .56365 .59992 L F
.361 0 0 r
.5612 .60301 m .56188 .6009 L .56365 .59992 L F
.088 .355 .824 r
.79215 .40185 m .78934 .39866 L .78987 .40049 L F
0 0 0 r
.76605 .3931 m .76569 .39473 L .76789 .39358 L F
.76605 .3931 m .76378 .39592 L .76569 .39473 L F
.291 0 0 r
.76789 .39358 m .76853 .3935 L .76605 .3931 L F
.5 .754 .986 r
.2238 .64164 m .22804 .64343 L .22739 .64263 L F
.813 .626 .649 r
.56683 .55453 m .56677 .55684 L .57063 .55696 L F
.812 .695 .736 r
.56677 .55684 m .56828 .55832 L .57063 .55696 L F
.637 .091 0 r
.49961 .55326 m .49553 .55147 L .49723 .5517 L F
.593 .787 .973 r
.17093 .59793 m .16695 .59724 L .16926 .59469 L F
.636 .596 .792 r
.17342 .59678 m .17093 .59793 L .16926 .59469 L F
.47 .543 .849 r
.15822 .61362 m .15954 .61156 L .1573 .61185 L F
.15822 .61362 m .1609 .61485 L .15954 .61156 L F
.626 .738 .928 r
.82299 .4053 m .82659 .40617 L .82563 .40443 L F
.675 .806 .945 r
.82659 .40617 m .8282 .40355 L .82563 .40443 L F
.82659 .40617 m .8293 .40524 L .8282 .40355 L F
.586 .808 .984 r
.19786 .61564 m .19697 .61786 L .19448 .61619 L F
.19786 .61564 m .19968 .61711 L .19697 .61786 L F
.581 .821 .99 r
.80871 .44399 m .80977 .44518 L .8115 .44326 L F
.469 .64 .931 r
.8115 .44326 m .80977 .44518 L .81216 .4451 L F
.841 .692 .697 r
.46115 .65122 m .46504 .64981 L .46322 .64867 L F
.46115 .65122 m .46425 .65268 L .46504 .64981 L F
.811 .384 .231 r
.50868 .59406 m .51265 .59695 L .51197 .59476 L F
.455 .788 .999 r
.24147 .55825 m .23969 .55721 L .23748 .55758 L F
.49 .821 .999 r
.24147 .55825 m .242 .55682 L .23969 .55721 L F
.24147 .55825 m .24373 .55772 L .242 .55682 L F
.728 .918 .564 r
.84455 .42074 m .8427 .42293 L .84287 .42394 L F
.84455 .42074 m .84489 .41982 L .8427 .42293 L F
.863 .693 .67 r
.75958 .39332 m .75875 .39003 L .75683 .39099 L F
.75958 .39332 m .75683 .39099 L .75827 .39207 L F
.947 .878 .735 r
.757 .3956 m .75958 .39332 L .75827 .39207 L F
.556 .132 .193 r
.80462 .40748 m .80411 .40612 L .80701 .40746 L F
.5 .477 .763 r
.75634 .40572 m .75763 .40932 L .75957 .40758 L F
.583 .518 .747 r
.75799 .41216 m .75957 .40758 L .75763 .40932 L F
.681 .665 .828 r
.44949 .66067 m .45275 .6588 L .45012 .6587 L F
.45275 .6588 m .45397 .6581 L .45171 .65845 L F
.45275 .6588 m .45171 .65845 L .45012 .6587 L F
.631 .399 .547 r
.45275 .6588 m .45283 .65882 L .45588 .65793 L F
.45283 .65882 m .45745 .66034 L .45611 .65828 L F
.45283 .65882 m .45611 .65828 L .45588 .65793 L F
.4524 .65889 m .45275 .6588 L .45397 .6581 L F
.681 .665 .828 r
.45283 .65882 m .4524 .65889 L .45397 .6581 L F
.631 .399 .547 r
.45275 .6588 m .45588 .65793 L .45397 .6581 L F
.681 .665 .828 r
.45283 .65882 m .45397 .6581 L .45266 .65885 L F
.44938 .66103 m .45161 .65945 L .44949 .66067 L F
.44938 .66103 m .4524 .65889 L .45283 .65882 L F
.631 .399 .547 r
.4524 .65889 m .45818 .66148 L .45745 .66034 L F
.4524 .65889 m .45745 .66034 L .45275 .6588 L F
.354 .263 .612 r
.44938 .66103 m .45222 .66283 L .4524 .65889 L F
.44938 .66103 m .45007 .66444 L .45222 .66283 L F
.524 .252 .443 r
.28578 .63537 m .28349 .63371 L .28589 .63344 L F
.28578 .63537 m .28396 .63598 L .28349 .63371 L F
.127 0 0 r
.2367 .69093 m .23575 .69049 L .23419 .69101 L F
.123 0 0 r
.23909 .69474 m .23819 .69536 L .23593 .69596 L F
.699 .782 .916 r
.23593 .69596 m .23819 .69536 L .23534 .69353 L F
.23515 .69374 m .23534 .69353 L .23501 .69332 L F
.23593 .69596 m .23534 .69353 L .23515 .69374 L F
0 0 .024 r
.23696 .69118 m .2367 .69093 L .23555 .69329 L F
.23582 .69298 m .23555 .69329 L .23543 .69354 L F
.23582 .69298 m .23543 .69354 L .23554 .69343 L F
.23696 .69118 m .23555 .69329 L .23582 .69298 L F
.745 .752 .857 r
.23233 .69031 m .2367 .69093 L .23419 .69101 L F
.795 .556 .576 r
.23399 .69227 m .2367 .69093 L .23233 .69031 L F
.51 .564 .846 r
.23501 .69332 m .23522 .69335 L .2351 .69324 L F
.795 .556 .576 r
.2353 .69381 m .23543 .69354 L .23399 .69227 L F
.127 0 0 r
.2367 .69093 m .23812 .68995 L .23615 .69039 L F
0 0 0 r
.24009 .68895 m .2367 .69093 L .23793 .68964 L F
0 0 .024 r
.23793 .68964 m .23555 .69341 L .23707 .69152 L F
.569 .898 .983 r
.23834 .69465 m .23522 .69335 L .23501 .69332 L F
0 0 .024 r
.23555 .69341 m .2353 .69381 L .23572 .69327 L F
.51 .564 .846 r
.23556 .69341 m .23722 .69176 L .23707 .69152 L F
0 0 .024 r
.23555 .69341 m .23572 .69327 L .23707 .69152 L F
.569 .898 .983 r
.23819 .69536 m .23834 .69465 L .23545 .6935 L F
.23538 .69356 m .23545 .6935 L .23501 .69332 L F
.23819 .69536 m .23545 .6935 L .23538 .69356 L F
.23834 .69465 m .23851 .69386 L .23522 .69335 L F
.795 .556 .576 r
.23522 .69335 m .2367 .69093 L .23399 .69227 L F
.23543 .69354 m .23547 .69346 L .23522 .69335 L F
.23547 .69346 m .2367 .69093 L .23522 .69335 L F
.51 .564 .846 r
.2351 .69324 m .23556 .69341 L .23707 .69152 L F
.23522 .69335 m .23556 .69341 L .2351 .69324 L F
.23556 .69341 m .23851 .69386 L .23722 .69176 L F
0 0 .024 r
.23554 .69343 m .23543 .69354 L .2353 .69381 L F
.23793 .68964 m .2367 .69093 L .23696 .69118 L F
.127 0 0 r
.2367 .69093 m .23615 .69039 L .23575 .69049 L F
.322 .759 .967 r
.54242 .601 m .54147 .59983 L .5408 .60063 L F
.54242 .601 m .54514 .60084 L .54147 .59983 L F
.849 .967 .876 r
.19378 .77247 m .19856 .76973 L .1985 .77117 L F
.317 .362 .75 r
.1986 .76903 m .19856 .76973 L .19821 .76776 L F
0 0 0 r
.1985 .77117 m .19856 .76973 L .1986 .76903 L F
.933 .906 .773 r
.51466 .61184 m .51402 .61586 L .51627 .61271 L F
.51466 .61184 m .51275 .6161 L .51402 .61586 L F
.392 0 0 r
.51402 .61586 m .51269 .61747 L .51424 .61641 L F
.852 .779 .78 r
.56656 .54167 m .5676 .54519 L .56823 .54322 L F
.56656 .54167 m .56424 .54485 L .5676 .54519 L F
.908 .759 .685 r
.56405 .54738 m .5676 .54519 L .56424 .54485 L F
.56405 .54738 m .5658 .54853 L .5676 .54519 L F
.559 .542 .792 r
.44707 .64591 m .44877 .65005 L .45082 .64884 L F
.981 .76 .531 r
.57803 .58396 m .57972 .58239 L .57792 .58161 L F
.57803 .58396 m .57945 .58494 L .57972 .58239 L F
.407 .8 .987 r
.24385 .64251 m .24763 .64298 L .24597 .64242 L F
.262 .723 .951 r
.24763 .64298 m .24994 .64307 L .24597 .64242 L F
.682 .833 .956 r
.7985 .4261 m .80211 .42636 L .79953 .42753 L F
.619 .788 .963 r
.83665 .39599 m .83397 .39677 L .83298 .39527 L F
.559 .542 .792 r
.44707 .64591 m .45082 .64884 L .45076 .64629 L F
.371 .836 .887 r
.82298 .3965 m .82148 .3975 L .82051 .39693 L F
.82298 .3965 m .82417 .39676 L .82148 .3975 L F
.957 .814 .66 r
.83854 .42111 m .83767 .42055 L .83815 .41743 L F
.747 .675 .78 r
.83815 .41743 m .84185 .4182 L .83854 .42111 L F
.827 .431 .299 r
.50251 .58108 m .50643 .58435 L .50394 .58162 L F
.522 .808 .998 r
.22488 .62756 m .22112 .62719 L .22354 .6264 L F
.346 .76 .979 r
.22537 .6266 m .22488 .62756 L .22354 .6264 L F
.22537 .6266 m .22711 .6274 L .22488 .62756 L F
.311 .167 .517 r
.13953 .58541 m .1411 .58483 L .14122 .58212 L F
.351 .262 .614 r
.13953 .58541 m .14145 .58741 L .1411 .58483 L F
.319 .258 .63 r
.13997 .58815 m .14145 .58741 L .13953 .58541 L F
.409 .066 .269 r
.48444 .6277 m .48675 .62722 L .48771 .62516 L F
.68 .346 .403 r
.48771 .62516 m .48973 .62691 L .49054 .62477 L F
.48771 .62516 m .48675 .62722 L .48973 .62691 L F
.192 .398 .835 r
.25069 .64672 m .25261 .64924 L .25336 .64856 L F
.606 .572 .79 r
.32257 .58523 m .32052 .58765 L .32021 .58556 L F
.32257 .58523 m .32387 .58789 L .32052 .58765 L F
.321 .143 .477 r
.32387 .58789 m .32143 .59143 L .32052 .58765 L F
.866 .762 .254 r
.84287 .42394 m .8427 .42293 L .84235 .4253 L F
.483 .242 .472 r
.1803 .56984 m .18067 .57155 L .1779 .57155 L F
.114 0 0 r
.18067 .57155 m .17653 .57502 L .1779 .57155 L F
.996 .773 .417 r
.48444 .6277 m .48409 .63002 L .48498 .63017 L F
.744 .683 .792 r
.48444 .6277 m .48498 .63017 L .48818 .62825 L F
.752 .782 .878 r
.18584 .61208 m .18384 .61439 L .18173 .61197 L F
.13 .646 .89 r
.21015 .73453 m .2108 .73407 L .20977 .7327 L F
.21015 .73453 m .21287 .73476 L .2108 .73407 L F
0 0 0 r
.23598 .53655 m .23822 .53611 L .23989 .53578 L F
.212 0 0 r
.2343 .53634 m .23822 .53611 L .23598 .53655 L F
.2343 .53634 m .23577 .5366 L .23822 .53611 L F
.23577 .5366 m .23603 .53664 L .23822 .53611 L F
0 0 0 r
.23989 .53578 m .23822 .53611 L .23991 .53578 L F
.374 0 0 r
.23991 .53578 m .23822 .53611 L .2421 .53621 L F
.644 .31 .391 r
.18796 .82829 m .19118 .82829 L .18895 .82621 L F
0 0 0 r
.2112 .743 m .2091 .74402 L .20705 .74559 L F
.361 0 0 r
.5612 .60301 m .56388 .60301 L .56542 .60181 L F
0 0 0 r
.56622 .60203 m .56388 .60301 L .56542 .60181 L F
.994 .762 .472 r
.51262 .6021 m .5141 .60064 L .51328 .59974 L F
.51262 .6021 m .51386 .60315 L .5141 .60064 L F
.733 .852 .937 r
.46062 .574 m .45809 .57539 L .45737 .57533 L F
.62 .598 .806 r
.52926 .5251 m .53133 .52375 L .53022 .52054 L F
.81 .866 .889 r
.76623 .40568 m .76904 .40562 L .76781 .40439 L F
.55 .749 .97 r
.81226 .42866 m .81479 .42811 L .81574 .42964 L F
.612 .78 .962 r
.81715 .42737 m .81574 .42964 L .81479 .42811 L F
.81715 .42737 m .81827 .42887 L .81574 .42964 L F
.603 .141 .129 r
.48356 .56323 m .48785 .56388 L .48636 .56244 L F
.63 .126 .035 r
.48636 .56244 m .48785 .56388 L .48972 .56361 L F
.698 .667 .815 r
.8258 .42027 m .82655 .42203 L .8238 .42008 L F
.917 .734 .639 r
.82655 .42203 m .82478 .42229 L .8238 .42008 L F
.82655 .42203 m .82622 .42426 L .82478 .42229 L F
.609 .61 .827 r
.8258 .42027 m .82897 .42087 L .82655 .42203 L F
.505 .649 .922 r
.17792 .62439 m .18057 .62781 L .18265 .62721 L F
.46 .202 .435 r
.49392 .65279 m .49328 .65486 L .49091 .65533 L F
.49392 .65279 m .49328 .65486 L .49091 .65533 L F
.282 .367 .773 r
.17645 .6051 m .17555 .60741 L .17426 .60329 L F
.322 .413 .8 r
.17645 .6051 m .17808 .60874 L .17555 .60741 L F
.537 0 0 r
.50169 .54906 m .50422 .55031 L .50574 .54934 L F
.635 .242 .282 r
.50422 .55031 m .50857 .54886 L .50574 .54934 L F
.304 .443 .836 r
.25938 .55137 m .25941 .54825 L .25711 .54875 L F
.25938 .55137 m .26075 .55124 L .25941 .54825 L F
.239 0 .268 r
.25938 .55137 m .25828 .55392 L .26075 .55124 L F
.617 .944 .946 r
.25399 .6662 m .25238 .66764 L .25306 .66671 L F
.508 .325 .568 r
.32805 .56654 m .32628 .57015 L .32773 .56693 L F
.986 .853 .479 r
.76675 .40078 m .76774 .39976 L .76713 .39843 L F
.899 .952 .828 r
.76713 .39843 m .76774 .39976 L .77026 .39651 L F
.887 .482 .246 r
.76867 .4021 m .76774 .39976 L .76675 .40078 L F
.986 .853 .479 r
.76675 .40078 m .76774 .39976 L .76713 .39843 L F
.66 .57 .743 r
.27613 .55889 m .2778 .56341 L .27877 .56079 L F
.455 .555 .868 r
.7922 .42618 m .79026 .42682 L .78837 .42318 L F
.55 .779 .984 r
.78967 .44301 m .79307 .44387 L .79278 .44211 L F
.675 .766 .919 r
.79307 .44387 m .79501 .44075 L .79278 .44211 L F
.79307 .44387 m .79633 .44258 L .79501 .44075 L F
.91 .827 .752 r
.55897 .54862 m .55824 .54513 L .5597 .54627 L F
.55897 .54862 m .55715 .5479 L .55824 .54513 L F
.347 0 0 r
.55929 .54891 m .55715 .5479 L .55897 .54862 L F
.634 .349 .468 r
.47548 .63359 m .47911 .63085 L .47555 .63139 L F
0 0 0 r
.75774 .38138 m .75425 .38331 L .75794 .38395 L F
.609 .885 .99 r
.82947 .39552 m .82782 .39736 L .82674 .39601 L F
.82947 .39552 m .83043 .39638 L .82782 .39736 L F
.608 .679 .892 r
.78628 .42319 m .78163 .42121 L .78423 .42119 L F
.38 .608 .939 r
.78779 .42156 m .78628 .42319 L .78423 .42119 L F
.78779 .42156 m .78837 .42318 L .78628 .42319 L F
.307 .079 .396 r
.31909 .59422 m .31822 .59704 L .31638 .59767 L F
.328 .252 .616 r
.31835 .59952 m .31638 .59767 L .31822 .59704 L F
.31835 .59952 m .31678 .60031 L .31638 .59767 L F
.293 .158 .52 r
.50896 .6098 m .51139 .6115 L .5105 .60793 L F
.888 .609 .508 r
.56082 .53039 m .55795 .52963 L .55784 .52708 L F
.883 .677 .62 r
.56065 .53282 m .55795 .52963 L .56082 .53039 L F
.384 .342 .688 r
.75007 .39079 m .75173 .38638 L .74912 .38742 L F
.75007 .39079 m .75075 .38934 L .75173 .38638 L F
.587 .58 .812 r
.75007 .39079 m .75339 .39 L .75075 .38934 L F
0 0 0 r
.49811 .58531 m .4988 .58472 L .49998 .58216 L F
.262 .002 .318 r
.18585 .78317 m .18321 .78665 L .18544 .78625 L F
.549 .287 .472 r
.18779 .78565 m .18585 .78317 L .18544 .78625 L F
.18779 .78565 m .18837 .78325 L .18585 .78317 L F
.436 .049 .205 r
.27759 .63746 m .27933 .63866 L .27694 .63888 L F
.444 .044 .186 r
.27996 .63726 m .27933 .63866 L .27759 .63746 L F
.525 .413 .669 r
.32241 .58439 m .32257 .58523 L .32021 .58556 L F
.321 .143 .477 r
.32387 .58789 m .32344 .59077 L .32143 .59143 L F
.516 .398 .658 r
.32344 .59077 m .32138 .59387 L .32143 .59143 L F
.549 .333 .539 r
.47911 .63085 m .48163 .63052 L .48175 .62796 L F
.523 .311 .534 r
.48175 .62796 m .48163 .63052 L .48409 .63002 L F
.571 .303 .471 r
.48175 .62796 m .48409 .63002 L .48444 .6277 L F
.525 .333 .562 r
.47436 .60988 m .47682 .60961 L .47562 .60792 L F
.475 .319 .589 r
.47562 .60792 m .47917 .60887 L .48051 .60621 L F
.47562 .60792 m .47682 .60961 L .47917 .60887 L F
.672 .649 .819 r
.54586 .57803 m .54298 .58095 L .54353 .57889 L F
.536 .003 0 r
.54298 .58095 m .54296 .58109 L .54353 .57889 L F
.672 .649 .819 r
.54586 .57803 m .54708 .58153 L .54298 .58095 L F
.923 .663 .526 r
.77026 .39651 m .76853 .3935 L .76907 .39526 L F
.899 .952 .828 r
.76713 .39843 m .77026 .39651 L .76907 .39526 L F
.851 .75 .751 r
.57011 .52948 m .57134 .53288 L .57322 .52986 L F
.615 .176 .184 r
.54857 .52118 m .54664 .52276 L .54607 .52151 L F
.693 .279 .256 r
.55055 .52302 m .54857 .52118 L .54999 .52149 L F
.55055 .52302 m .54664 .52276 L .54857 .52118 L F
.56 .424 .653 r
.32426 .57832 m .32241 .58439 L .32194 .57901 L F
.995 .849 .584 r
.55513 .56084 m .55362 .56205 L .55483 .56011 L F
.55513 .56084 m .55437 .56384 L .55362 .56205 L F
.894 .797 .312 r
.55513 .56084 m .55483 .56011 L .55528 .5572 L F
.531 .356 .588 r
.31388 .6058 m .31163 .60368 L .31408 .60325 L F
.31388 .6058 m .31155 .60632 L .31163 .60368 L F
.633 .563 .757 r
.42123 .67057 m .42514 .67366 L .4236 .67009 L F
.744 .683 .792 r
.48444 .6277 m .48818 .62825 L .48675 .62722 L F
.69 .849 .959 r
.48675 .62722 m .48818 .62825 L .48973 .62691 L F
.068 0 .246 r
.49392 .65279 m .49328 .65486 L .49525 .65159 L F
.465 .228 .47 r
.48647 .60674 m .48636 .60907 L .48393 .60957 L F
.59 .311 .461 r
.48948 .6064 m .48636 .60907 L .48647 .60674 L F
.611 .737 .935 r
.16522 .58906 m .16183 .58817 L .16423 .58726 L F
.395 .505 .852 r
.16639 .58701 m .16522 .58906 L .16423 .58726 L F
.16639 .58701 m .16863 .59112 L .16522 .58906 L F
.174 .71 .755 r
.23625 .55003 m .23664 .54981 L .23444 .54992 L F
.23625 .55003 m .23839 .54964 L .23664 .54981 L F
0 0 0 r
.20681 .54137 m .21099 .53965 L .20872 .53977 L F
.509 .881 .975 r
.23095 .62702 m .22711 .6274 L .22966 .62606 L F
.21 .733 .845 r
.23157 .62663 m .23095 .62702 L .22966 .62606 L F
.23157 .62663 m .23326 .62672 L .23095 .62702 L F
.38 .634 .954 r
.31542 .54436 m .31477 .54602 L .31344 .54438 L F
.59 .861 .994 r
.31714 .54524 m .31477 .54602 L .31542 .54436 L F
.31714 .54524 m .31477 .54602 L .31542 .54436 L F
.118 .614 .906 r
.27709 .5361 m .27909 .53633 L .2811 .53724 L F
.459 .806 .998 r
.27909 .53633 m .28341 .5368 L .2811 .53724 L F
.232 0 .057 r
.5422 .51458 m .54482 .51381 L .54523 .51255 L F
.468 .034 .131 r
.54482 .51381 m .54738 .5137 L .54523 .51255 L F
.434 .09 .281 r
.54523 .51255 m .54738 .5137 L .54767 .51205 L F
.306 .589 .943 r
.32575 .54863 m .32423 .54985 L .32297 .54865 L F
.32575 .54863 m .32715 .55032 L .32423 .54985 L F
.453 .193 .429 r
.29397 .62526 m .29357 .62745 L .29128 .62788 L F
.401 .113 .355 r
.29661 .62442 m .29357 .62745 L .29397 .62526 L F
.952 .769 .618 r
.57804 .57894 m .57844 .57627 L .57685 .57548 L F
.548 .806 .993 r
.45682 .66611 m .45854 .66752 L .45902 .66532 L F
.037 .26 .759 r
.45854 .66752 m .46094 .66963 L .45902 .66532 L F
.53 .469 .733 r
.75634 .40572 m .75957 .40758 L .75901 .40461 L F
.717 .288 .229 r
.4578 .64784 m .45928 .64841 L .45711 .64627 L F
.534 .334 .556 r
.45711 .64627 m .45928 .64841 L .45958 .64576 L F
.343 .125 .432 r
.46591 .61505 m .46796 .61496 L .46835 .61263 L F
.586 .321 .482 r
.46513 .61743 m .46796 .61496 L .46591 .61505 L F
.961 .739 .558 r
.50643 .58435 m .50781 .58766 L .50796 .58533 L F
.437 .152 .381 r
.30456 .61581 m .30403 .61808 L .30169 .61859 L F
.494 .203 .4 r
.30456 .61581 m .30648 .61761 L .30403 .61808 L F
.589 .455 .666 r
.30676 .61262 m .30715 .61559 L .30456 .61581 L F
.52 .2 .365 r
.30715 .61559 m .30648 .61761 L .30456 .61581 L F
.345 0 .215 r
.48051 .60621 m .48151 .60807 L .48345 .60641 L F
.48051 .60621 m .47917 .60887 L .48151 .60807 L F
.674 .606 .771 r
.43042 .67327 m .43285 .66932 L .43053 .67011 L F
.43042 .67327 m .43398 .67365 L .43285 .66932 L F
.574 .291 .449 r
.4311 .67652 m .43398 .67365 L .43042 .67327 L F
.791 .686 .748 r
.75794 .38395 m .75925 .38755 L .76172 .38455 L F
.763 .748 .839 r
.4325 .67646 m .43256 .67864 L .43466 .67637 L F
.224 .231 .657 r
.43651 .67514 m .43466 .67637 L .43398 .67365 L F
.763 .748 .839 r
.4316 .67725 m .43256 .67864 L .4325 .67646 L F
.4311 .67652 m .43466 .67637 L .43389 .67673 L F
.397 .153 .422 r
.43502 .67427 m .43389 .67673 L .43651 .67514 L F
.43398 .67365 m .43393 .67521 L .43502 .67427 L F
.43393 .67521 m .43389 .67673 L .43502 .67427 L F
.763 .748 .839 r
.4311 .67652 m .4316 .67725 L .4325 .67646 L F
.545 .113 .171 r
.21779 .55477 m .21317 .55636 L .21518 .55504 L F
.656 .768 .932 r
.19135 .63503 m .19506 .63705 L .19497 .63576 L F
.543 .808 .995 r
.19506 .63705 m .19604 .63519 L .19497 .63576 L F
.19506 .63705 m .19755 .63653 L .19604 .63519 L F
.362 0 0 r
.53766 .52135 m .53633 .52275 L .53393 .52275 L F
.541 .093 .136 r
.54023 .52119 m .53633 .52275 L .53766 .52135 L F
.767 .7 .788 r
.54963 .57836 m .54708 .58153 L .54586 .57803 L F
.894 .745 .689 r
.56677 .55684 m .56793 .56113 L .56828 .55832 L F
.56677 .55684 m .56511 .56019 L .56793 .56113 L F
.83 .639 .644 r
.56511 .56019 m .56806 .56333 L .56793 .56113 L F
.809 .559 .56 r
.56957 .56887 m .57336 .56705 L .5718 .56684 L F
.56957 .56887 m .57331 .56974 L .57336 .56705 L F
.442 0 .092 r
.81055 .40726 m .81051 .40625 L .81291 .40691 L F
.154 .369 .822 r
.20771 .61842 m .20767 .62077 L .20566 .61811 L F
.20771 .61842 m .20921 .62134 L .20767 .62077 L F
.859 .499 .368 r
.49608 .54537 m .4977 .5487 L .49951 .54843 L F
.466 0 0 r
.4977 .5487 m .50169 .54906 L .49951 .54843 L F
.73 .65 .77 r
.44866 .63002 m .45161 .63151 L .45317 .62936 L F
.799 .576 .599 r
.44866 .63002 m .45056 .63356 L .45161 .63151 L F
.702 .353 .382 r
.55747 .51188 m .55991 .51416 L .56102 .51188 L F
.789 .579 .617 r
.55991 .51416 m .56377 .51187 L .56102 .51188 L F
.388 .17 .458 r
.47436 .60988 m .47645 .61146 L .47682 .60961 L F
.47436 .60988 m .47431 .61238 L .47645 .61146 L F
.771 .382 .317 r
.51106 .56006 m .50694 .55738 L .51073 .55789 L F
.583 .518 .747 r
.75799 .41216 m .76117 .41089 L .75957 .40758 L F
.494 .302 .548 r
.75799 .41216 m .7608 .41394 L .76117 .41089 L F
.527 .714 .958 r
.80848 .42729 m .80559 .42769 L .80473 .426 L F
0 .213 .738 r
.45306 .6522 m .4531 .65075 L .45082 .64884 L F
.85 .733 .734 r
.45454 .65434 m .4531 .65075 L .45306 .6522 L F
.765 .336 .233 r
.4608 .6533 m .46425 .65268 L .46115 .65122 L F
.4608 .6533 m .46441 .65404 L .46425 .65268 L F
.577 .189 .271 r
.46441 .65404 m .46695 .65427 L .46425 .65268 L F
.638 .763 .938 r
.84082 .41664 m .84185 .4182 L .83815 .41743 L F
.66 .84 .969 r
.84406 .41571 m .84185 .4182 L .84082 .41664 L F
.84406 .41571 m .84488 .41704 L .84185 .4182 L F
.578 .825 .992 r
.24304 .67132 m .24813 .67165 L .24476 .66988 L F
.885 .462 .18 r
.24476 .66988 m .24813 .67165 L .24824 .67435 L F
.703 .535 .659 r
.22489 .71303 m .2296 .70989 L .22744 .71298 L F
.597 .469 .677 r
.2296 .70989 m .2303 .71277 L .22744 .71298 L F
.382 .144 .424 r
.2303 .71277 m .22722 .71538 L .22744 .71298 L F
.573 .41 .623 r
.30138 .57299 m .29901 .57608 L .30146 .5756 L F
.523 .265 .466 r
.30146 .5756 m .30107 .57807 L .29901 .57608 L F
.573 .41 .623 r
.30146 .5756 m .29901 .57608 L .30138 .57299 L F
.523 .265 .466 r
.29901 .57608 m .30107 .57807 L .30146 .5756 L F
.839 .729 .743 r
.75683 .39099 m .75875 .39003 L .75925 .38755 L F
.234 .748 .864 r
.24831 .53604 m .25054 .53573 L .25243 .53585 L F
.134 0 0 r
.25243 .53585 m .25054 .53573 L .25446 .53611 L F
.507 .228 .425 r
.48393 .60957 m .48395 .6117 L .48126 .61169 L F
.654 .46 .609 r
.48636 .60907 m .48395 .6117 L .48393 .60957 L F
.697 .311 .313 r
.54999 .52149 m .55196 .52365 L .55055 .52302 L F
.745 .282 .15 r
.55413 .52391 m .55196 .52365 L .54999 .52149 L F
.777 .564 .611 r
.51937 .55462 m .51909 .55751 L .52287 .55772 L F
.832 .603 .593 r
.51937 .55977 m .52287 .55772 L .51909 .55751 L F
.51937 .55977 m .52332 .56078 L .52287 .55772 L F
.739 .539 .623 r
.52287 .55772 m .52332 .56078 L .5268 .5607 L F
.748 .621 .718 r
.46825 .64257 m .47106 .63961 L .46829 .64003 L F
.229 .748 .776 r
.2421 .53621 m .24435 .53569 L .24632 .53541 L F
.488 0 0 r
.24632 .53541 m .24435 .53569 L .24831 .53604 L F
.674 .678 .845 r
.79624 .42743 m .79316 .42931 L .7922 .42618 L F
.358 .812 .939 r
.17985 .60868 m .17808 .60874 L .18118 .60533 L F
.451 .206 .45 r
.18118 .60533 m .18018 .60829 L .17985 .60868 L F
.358 .812 .939 r
.17985 .60868 m .18018 .60829 L .17808 .60874 L F
.157 .31 .769 r
.18018 .60829 m .17993 .61096 L .17808 .60874 L F
.18018 .60829 m .18173 .61197 L .17993 .61096 L F
.429 .662 .958 r
.20566 .61811 m .2036 .61824 L .2023 .61658 L F
.955 .723 .547 r
.19596 .76971 m .1986 .76903 L .19821 .76776 L F
.922 .615 .443 r
.1985 .77117 m .1986 .76903 L .19596 .76971 L F
.37 .466 .828 r
.77699 .42972 m .77823 .43317 L .77999 .43122 L F
.317 .385 .774 r
.77823 .43317 m .78119 .43501 L .77999 .43122 L F
.634 .349 .468 r
.47548 .63359 m .47777 .63368 L .47911 .63085 L F
.761 .494 .531 r
.47911 .63085 m .48168 .63329 L .48163 .63052 L F
.47911 .63085 m .47777 .63368 L .48168 .63329 L F
.008 0 .065 r
.24174 .69165 m .24059 .69443 L .23909 .69474 L F
.511 .539 .822 r
.24258 .68804 m .24174 .69165 L .24009 .68895 L F
.24258 .68804 m .24364 .69124 L .24174 .69165 L F
.133 0 .125 r
.24242 .69348 m .24174 .69165 L .24364 .69124 L F
.24242 .69348 m .24059 .69443 L .24174 .69165 L F
.67 .868 .974 r
.2337 .64307 m .23751 .64309 L .23585 .64199 L F
.513 .811 .999 r
.23585 .64199 m .23751 .64309 L .23976 .64256 L F
.23585 .64199 m .23751 .64309 L .23976 .64256 L F
.133 .664 .867 r
.23751 .64309 m .23919 .64315 L .23976 .64256 L F
.367 .817 .941 r
.21099 .53965 m .21336 .53916 L .21439 .53952 L F
0 0 0 r
.21099 .53965 m .21113 .53982 L .21336 .53916 L F
.915 .967 .793 r
.21336 .53916 m .21113 .53982 L .21199 .53867 L F
.21336 .53916 m .21199 .53867 L .21374 .53633 L F
.367 .817 .941 r
.21439 .53952 m .21336 .53916 L .21484 .53951 L F
.73 .988 .884 r
.21484 .53951 m .21536 .53794 L .21675 .53782 L F
.665 .946 .959 r
.21484 .53951 m .21336 .53916 L .21536 .53794 L F
.561 .545 .794 r
.46704 .56611 m .46813 .56923 L .46571 .56965 L F
.472 .885 .933 r
.18368 .78697 m .18544 .78625 L .18321 .78665 L F
.192 .398 .835 r
.25069 .64672 m .25336 .64856 L .25271 .64536 L F
.271 0 0 r
.50479 .59489 m .50749 .59581 L .50557 .59527 L F
.50479 .59489 m .50557 .59527 L .50371 .59474 L F
.077 0 0 r
.50458 .59478 m .50479 .59489 L .50216 .59566 L F
.50624 .59418 m .50479 .59489 L .50458 .59478 L F
.764 .869 .439 r
.50868 .59406 m .50479 .59489 L .50624 .59418 L F
.581 .357 .54 r
.29128 .62788 m .29113 .63054 L .28844 .63074 L F
.402 .21 .503 r
.29314 .62978 m .29128 .62788 L .29357 .62745 L F
.29314 .62978 m .29113 .63054 L .29128 .62788 L F
.332 .551 .913 r
.45568 .62904 m .45687 .63078 L .45798 .62922 L F
.399 .644 .956 r
.45687 .63078 m .45934 .63105 L .45798 .62922 L F
.967 .751 .559 r
.51728 .55637 m .51937 .55462 L .51547 .55493 L F
.51728 .55637 m .51909 .55751 L .51937 .55462 L F
.589 .36 .537 r
.46349 .66134 m .46637 .66177 L .46415 .6603 L F
.46349 .66134 m .46345 .66404 L .46637 .66177 L F
.46637 .66177 m .46345 .66404 L .46349 .66134 L F
.768 .441 .433 r
.4685 .66056 m .46393 .66016 L .46637 .66177 L F
.46695 .66121 m .46773 .66264 L .46517 .66195 L F
.4685 .66056 m .46812 .66159 L .46695 .66121 L F
.46812 .66159 m .46773 .66264 L .46695 .66121 L F
.589 .36 .537 r
.46391 .66022 m .46415 .6603 L .46393 .66016 L F
.46349 .66134 m .46415 .6603 L .46391 .66022 L F
.39 .236 .549 r
.17054 .57777 m .16905 .57591 L .17195 .57513 L F
.17054 .57777 m .16884 .57874 L .16905 .57591 L F
.558 .462 .701 r
.32857 .55426 m .3291 .55731 L .32659 .55753 L F
.587 .432 .638 r
.32995 .56083 m .32659 .55753 L .3291 .55731 L F
.32995 .56083 m .32738 .56191 L .32659 .55753 L F
.433 0 0 r
.24588 .55087 m .24454 .55098 L .24299 .55035 L F
.585 .172 .225 r
.2483 .55025 m .24454 .55098 L .24588 .55087 L F
0 0 .341 r
.17394 .59908 m .17381 .60073 L .17342 .59678 L F
.371 .415 .777 r
.17568 .60125 m .17381 .60073 L .17394 .59908 L F
.17568 .60125 m .17426 .60329 L .17381 .60073 L F
.917 .521 .155 r
.21547 .72863 m .21508 .7279 L .21197 .73072 L F
.576 .939 .814 r
.2135 .72917 m .21547 .72863 L .21197 .73072 L F
.383 0 0 r
.21581 .72927 m .21547 .72863 L .2135 .72917 L F
.917 .521 .155 r
.21547 .72863 m .21748 .73127 L .21647 .72869 L F
.593 .648 .874 r
.21924 .73013 m .21748 .73127 L .21547 .72863 L F
.383 0 0 r
.2177 .72936 m .21547 .72863 L .21581 .72927 L F
.917 .521 .155 r
.21547 .72863 m .21522 .72778 L .21508 .7279 L F
.21547 .72863 m .21647 .72869 L .21522 .72778 L F
.598 .463 .668 r
.47066 .63682 m .47323 .63348 L .47045 .63452 L F
.553 .513 .765 r
.21833 .71876 m .21986 .71542 L .21908 .71621 L F
.457 .728 .985 r
.31306 .54328 m .3113 .54475 L .3097 .54338 L F
.31306 .54328 m .31344 .54438 L .3113 .54475 L F
.627 .451 .625 r
.18236 .5696 m .18067 .57155 L .1803 .56984 L F
.498 .282 .517 r
.46424 .62464 m .462 .62755 L .46178 .62477 L F
.382 .144 .424 r
.2303 .71277 m .22961 .71544 L .22722 .71538 L F
.58 .275 .415 r
.22961 .71544 m .2262 .71748 L .22722 .71538 L F
.058 .221 .717 r
.16578 .61414 m .16495 .61559 L .16659 .61544 L F
.16566 .61395 m .16561 .61405 L .16578 .61414 L F
.16561 .61405 m .16495 .61559 L .16578 .61414 L F
.16566 .61395 m .16591 .6156 L .16495 .61559 L F
.554 .608 .861 r
.1609 .61485 m .16591 .6156 L .16312 .61267 L F
.16144 .61174 m .16312 .61267 L .16156 .61103 L F
.1609 .61485 m .16312 .61267 L .16144 .61174 L F
.007 .565 .811 r
.16495 .61559 m .16591 .6156 L .1609 .61485 L F
.16495 .61559 m .16591 .6156 L .1609 .61485 L F
0 0 0 r
.23909 .69474 m .24059 .69443 L .23819 .69536 L F
.157 0 .337 r
.76123 .39874 m .75866 .40242 L .76156 .40177 L F
.27 0 .068 r
.76098 .40312 m .75866 .40242 L .75901 .40461 L F
.76098 .40312 m .76156 .40177 L .75866 .40242 L F
.909 .757 .68 r
.56119 .53694 m .55876 .53813 L .55957 .53591 L F
.56119 .53694 m .56046 .53943 L .55876 .53813 L F
.733 .852 .937 r
.46062 .574 m .45737 .57533 L .45921 .57378 L F
.614 .93 .966 r
.25268 .66066 m .25443 .66125 L .2516 .66196 L F
.237 0 0 r
.25297 .66076 m .25443 .66125 L .25268 .66066 L F
.749 .351 .299 r
.25231 .66322 m .25443 .66125 L .25297 .66076 L F
.25231 .66322 m .25566 .66346 L .25443 .66125 L F
.517 .537 .815 r
.25783 .6644 m .25443 .66125 L .25566 .66346 L F
.508 .727 .972 r
.27613 .55889 m .27673 .55688 L .27456 .55772 L F
.27613 .55889 m .2785 .55864 L .27673 .55688 L F
.66 .57 .743 r
.27613 .55889 m .27877 .56079 L .2785 .55864 L F
.774 .959 .647 r
.4633 .57206 m .46258 .57257 L .46418 .57028 L F
.428 .817 .586 r
.4633 .57206 m .46062 .574 L .46258 .57257 L F
.106 0 0 r
.81291 .40691 m .81668 .40544 L .8161 .40548 L F
.423 .862 .917 r
.81668 .40544 m .81857 .40435 L .8161 .40548 L F
.81668 .40544 m .81932 .40465 L .81857 .40435 L F
.777 .898 .928 r
.82459 .44206 m .82569 .4393 L .82375 .44094 L F
.82459 .44206 m .82678 .44057 L .82569 .4393 L F
.409 .121 .361 r
.32138 .59387 m .31822 .59704 L .31909 .59422 L F
0 0 .158 r
.26032 .61587 m .26106 .61681 L .26221 .61547 L F
.26032 .61587 m .25962 .61832 L .26106 .61681 L F
.462 .515 .827 r
.26876 .55468 m .27169 .55571 L .27128 .55467 L F
.447 .572 .887 r
.30133 .53883 m .3011 .54189 L .29947 .53957 L F
.30133 .53883 m .30321 .54188 L .3011 .54189 L F
.822 .631 .645 r
.56523 .55091 m .56683 .55453 L .5672 .55192 L F
.551 .791 .988 r
.23122 .64372 m .23172 .64191 L .22956 .64242 L F
.23122 .64372 m .2337 .64307 L .23172 .64191 L F
0 0 .192 r
.27933 .57331 m .28126 .56909 L .2788 .5709 L F
.449 .258 .528 r
.30169 .61859 m .30155 .62112 L .29939 .62166 L F
.54 .333 .548 r
.30155 .62112 m .2991 .62392 L .29939 .62166 L F
.849 .797 .8 r
.2196 .5532 m .22132 .55476 L .2237 .55141 L F
.436 .745 .993 r
.29145 .5382 m .29096 .53976 L .28942 .53833 L F
.29145 .5382 m .29317 .53952 L .29096 .53976 L F
.155 0 .044 r
.14847 .57259 m .15042 .57209 L .1517 .56999 L F
.171 0 0 r
.15042 .57209 m .15405 .56962 L .1517 .56999 L F
0 0 .21 r
.14648 .57608 m .14787 .57529 L .14847 .57259 L F
.321 .108 .426 r
.14596 .57765 m .14787 .57529 L .14648 .57608 L F
.667 .608 .78 r
.1408 .60042 m .14239 .60032 L .14135 .5972 L F
.631 .431 .593 r
.13941 .60317 m .1408 .60042 L .13919 .60035 L F
.13941 .60317 m .13991 .60313 L .1408 .60042 L F
.692 .51 .636 r
.13991 .60313 m .14239 .60032 L .1408 .60042 L F
.134 .361 .82 r
.7732 .4253 m .77502 .42458 L .77204 .42389 L F
.436 0 0 r
.77412 .42569 m .77531 .42633 L .7732 .4253 L F
.134 .361 .82 r
.7732 .4253 m .77531 .42633 L .77502 .42458 L F
.807 .875 .897 r
.83003 .43871 m .83292 .43842 L .83195 .43716 L F
.838 .963 .887 r
.83292 .43842 m .83504 .43479 L .83195 .43716 L F
.83292 .43842 m .83581 .43571 L .83504 .43479 L F
0 0 0 r
.2721 .59754 m .27373 .59641 L .27461 .59459 L F
.265 .04 .375 r
.27066 .59881 m .27373 .59641 L .2721 .59754 L F
.42 .864 .894 r
.82299 .4053 m .82483 .4042 L .82201 .40408 L F
.82299 .4053 m .82563 .40443 L .82483 .4042 L F
.849 .797 .8 r
.2196 .5532 m .2237 .55141 L .22222 .55185 L F
.311 .788 .698 r
.22592 .55047 m .22455 .55096 L .2237 .55141 L F
.303 .788 .723 r
.22455 .55096 m .22222 .55185 L .2237 .55141 L F
.574 .291 .449 r
.4311 .67652 m .43389 .67673 L .43398 .67365 L F
.469 .423 .724 r
.43398 .67365 m .43478 .66883 L .43285 .66932 L F
.43398 .67365 m .43705 .67284 L .43478 .66883 L F
.224 .231 .657 r
.43651 .67514 m .43398 .67365 L .43645 .67322 L F
0 0 .195 r
.43705 .67284 m .43651 .67514 L .43645 .67322 L F
.397 .153 .422 r
.43398 .67365 m .43651 .67514 L .43705 .67284 L F
.122 .665 .834 r
.22592 .55047 m .22994 .55068 L .22823 .54993 L F
.302 .771 .938 r
.23213 .55011 m .22823 .54993 L .22994 .55068 L F
.797 .915 .524 r
.50914 .59239 m .51019 .59142 L .50879 .59063 L F
.50914 .59239 m .50868 .59406 L .51019 .59142 L F
.789 .685 .75 r
.75578 .38717 m .75925 .38755 L .75794 .38395 L F
.794 .659 .714 r
.75683 .39099 m .75925 .38755 L .75578 .38717 L F
.588 .612 .843 r
.31887 .54539 m .31862 .54961 L .31714 .54524 L F
.31887 .54539 m .32101 .54903 L .31862 .54961 L F
.121 0 0 r
.19821 .76776 m .19375 .77013 L .19596 .76971 L F
.685 .807 .352 r
.56718 .60036 m .5689 .59659 L .5668 .59946 L F
.193 0 0 r
.1809 .55077 m .18316 .5503 L .18506 .54866 L F
.087 0 0 r
.18506 .54866 m .18532 .54966 L .18726 .54809 L F
.18506 .54866 m .18316 .5503 L .18532 .54966 L F
.403 .107 .344 r
.18506 .54866 m .18726 .54809 L .18752 .54732 L F
0 .181 .715 r
.48336 .56387 m .48458 .56416 L .48356 .56323 L F
.5 .605 .889 r
.82724 .42851 m .82443 .42973 L .82489 .42897 L F
.82724 .42851 m .82855 .43121 L .82443 .42973 L F
.666 .625 .799 r
.44691 .62848 m .4471 .62943 L .44924 .62745 L F
.369 .611 .944 r
.4471 .62943 m .44866 .63002 L .44924 .62745 L F
.114 0 0 r
.17361 .55427 m .17402 .55566 L .17578 .55383 L F
.17361 .55427 m .17203 .5565 L .17402 .55566 L F
.709 .354 .374 r
.82622 .42426 m .82333 .42546 L .82478 .42229 L F
.82622 .42426 m .82717 .42603 L .82333 .42546 L F
.916 .772 .687 r
.57011 .52948 m .56868 .53274 L .57134 .53288 L F
.929 .906 .779 r
.56792 .53516 m .57134 .53288 L .56868 .53274 L F
.56792 .53516 m .56908 .53621 L .57134 .53288 L F
0 0 0 r
.25489 .54843 m .25282 .54922 L .25052 .54985 L F
0 .544 .785 r
.25489 .54843 m .25569 .54837 L .25282 .54922 L F
.25489 .54843 m .25711 .54875 L .25569 .54837 L F
.601 .5 .711 r
.32657 .57521 m .32409 .57568 L .32385 .57336 L F
.541 .381 .613 r
.32664 .57766 m .32409 .57568 L .32657 .57521 L F
.32664 .57766 m .32426 .57832 L .32409 .57568 L F
0 0 0 r
.27461 .59459 m .27484 .59539 L .27545 .5931 L F
.27461 .59459 m .27373 .59641 L .27484 .59539 L F
.481 .283 .535 r
.30146 .5756 m .30401 .57254 L .30138 .57299 L F
.30401 .57254 m .30146 .5756 L .30138 .57299 L F
.609 .48 .679 r
.32622 .57264 m .32385 .57336 L .32449 .57151 L F
.601 .5 .711 r
.32657 .57521 m .32385 .57336 L .32622 .57264 L F
.559 .935 .844 r
.20677 .55626 m .20604 .55722 L .20837 .55651 L F
.20677 .55626 m .20552 .55728 L .20604 .55722 L F
.729 .856 .941 r
.55367 .59969 m .55513 .60089 L .5573 .59982 L F
.181 .57 .936 r
.19405 .61504 m .19329 .61595 L .1923 .61417 L F
.19405 .61504 m .19448 .61619 L .19329 .61595 L F
.655 .204 .167 r
.49238 .59896 m .49617 .59933 L .49377 .59744 L F
0 0 0 r
.27179 .58207 m .27289 .58122 L .27428 .57912 L F
.341 .213 .557 r
.27183 .58481 m .27359 .58412 L .27179 .58207 L F
.695 .155 0 r
.27179 .58207 m .27359 .58412 L .27215 .58358 L F
.27179 .58207 m .27215 .58358 L .27289 .58122 L F
.47 .613 .91 r
.18994 .61101 m .19008 .61453 L .1879 .61197 L F
.19074 .61208 m .1923 .61417 L .19002 .61311 L F
.956 .69 .49 r
.19038 .61205 m .1923 .61417 L .18994 .61101 L F
.19038 .61205 m .18994 .61101 L .19235 .61068 L F
0 .169 .707 r
.19039 .61065 m .19038 .61205 L .19111 .61155 L F
.19171 .61067 m .19111 .61155 L .19235 .61068 L F
.19039 .61065 m .19235 .61068 L .18994 .61101 L F
.19039 .61065 m .19111 .61155 L .19171 .61067 L F
.47 .613 .91 r
.19002 .61311 m .1923 .61417 L .19008 .61453 L F
.18994 .61101 m .19074 .61208 L .19002 .61311 L F
.899 .494 .227 r
.49582 .54769 m .49608 .54537 L .49421 .54554 L F
.49582 .54769 m .4977 .5487 L .49608 .54537 L F
.25 .502 .9 r
.53557 .59697 m .53625 .59571 L .53327 .59414 L F
0 .159 .678 r
.53557 .59697 m .53744 .59909 L .53625 .59571 L F
0 0 .54 r
.53851 .60065 m .53744 .59909 L .53557 .59697 L F
.59 .311 .461 r
.48948 .6064 m .48904 .60885 L .48636 .60907 L F
.51 .259 .47 r
.49198 .60577 m .48904 .60885 L .48948 .6064 L F
.998 .841 .548 r
.49209 .54596 m .49133 .54873 L .49028 .54711 L F
0 0 0 r
.49209 .54596 m .49304 .54611 L .49421 .54554 L F
.49209 .54596 m .49028 .54711 L .49304 .54611 L F
.6 .77 .961 r
.8282 .40355 m .8293 .40524 L .83175 .40462 L F
.646 .277 .329 r
.7992 .39928 m .80205 .40121 L .80293 .399 L F
.553 .182 .29 r
.80293 .399 m .80555 .40058 L .80554 .39932 L F
.80293 .399 m .80205 .40121 L .80555 .40058 L F
.449 .494 .814 r
.2785 .55864 m .27877 .56079 L .28096 .55937 L F
.409 .349 .679 r
.27877 .56079 m .28141 .56255 L .28096 .55937 L F
.27877 .56079 m .27984 .56514 L .28141 .56255 L F
.528 .639 .903 r
.18771 .63339 m .18755 .62996 L .18563 .63033 L F
.18771 .63339 m .19014 .63318 L .18755 .62996 L F
.344 .506 .875 r
.18771 .63339 m .19135 .63503 L .19014 .63318 L F
.568 .45 .678 r
.75156 .39716 m .75411 .39619 L .75493 .3931 L F
.609 .568 .783 r
.75156 .39716 m .75344 .39816 L .75411 .39619 L F
.663 .385 .49 r
.20552 .55728 m .20217 .5597 L .203 .5581 L F
.897 .486 .091 r
.5235 .57292 m .52292 .57397 L .52224 .57187 L F
.5235 .57292 m .52425 .57496 L .52292 .57397 L F
.766 .632 .712 r
.47106 .63961 m .47187 .64286 L .47235 .64035 L F
.318 .794 .916 r
.2529 .67044 m .25388 .6698 L .25096 .67021 L F
.4 .296 .62 r
.1399 .59074 m .14145 .58741 L .13997 .58815 L F
.609 .48 .679 r
.32622 .57264 m .32449 .57151 L .32628 .57015 L F
0 0 0 r
.19179 .56418 m .19147 .56377 L .19364 .56307 L F
.19179 .56418 m .18962 .56547 L .19147 .56377 L F
.73 .65 .77 r
.44866 .63002 m .45317 .62936 L .45292 .62919 L F
.539 .739 .967 r
.45317 .62936 m .45536 .62876 L .45292 .62919 L F
.45317 .62936 m .45568 .62904 L .45536 .62876 L F
.817 .512 .473 r
.56378 .51671 m .56729 .51534 L .56356 .51474 L F
.56378 .51671 m .5673 .51734 L .56729 .51534 L F
.46 .274 .541 r
.49599 .5815 m .49373 .5823 L .49602 .57896 L F
.49599 .5815 m .49373 .5823 L .49602 .57896 L F
.77 .69 .775 r
.54991 .57589 m .54963 .57836 L .54586 .57803 L F
0 0 .202 r
.47275 .56149 m .47293 .56174 L .47269 .56029 L F
0 0 .39 r
.47275 .56149 m .47364 .56291 L .47293 .56174 L F
0 0 .202 r
.47269 .56029 m .47293 .56174 L .47275 .56149 L F
.877 .948 .854 r
.49363 .5718 m .49392 .5735 L .49713 .56978 L F
.448 .387 .697 r
.49512 .57496 m .49729 .5743 L .49392 .5735 L F
0 .176 .71 r
.49392 .5735 m .49512 .57496 L .49363 .5718 L F
.49363 .5718 m .49512 .57496 L .49392 .5735 L F
.277 .772 .893 r
.50936 .61303 m .50799 .613 L .50681 .6134 L F
.748 .621 .718 r
.46825 .64257 m .47187 .64286 L .47106 .63961 L F
.681 .563 .716 r
.47187 .64286 m .47572 .64592 L .4755 .64333 L F
.47187 .64286 m .47316 .64645 L .47572 .64592 L F
.674 .533 .685 r
.47316 .64645 m .47305 .64874 L .47572 .64592 L F
.544 .772 .982 r
.2115 .62227 m .21099 .62415 L .20921 .62134 L F
.2115 .62227 m .21323 .62367 L .21099 .62415 L F
0 .37 .817 r
.28749 .53668 m .2871 .5372 L .2854 .53611 L F
.28749 .53668 m .28942 .53833 L .2871 .5372 L F
.775 .521 .552 r
.52321 .56308 m .5268 .5607 L .52332 .56078 L F
.587 .609 .841 r
.28629 .57616 m .28262 .57359 L .28505 .5727 L F
.099 .235 .717 r
.28711 .57466 m .28629 .57616 L .28505 .5727 L F
.572 .836 .995 r
.28884 .5757 m .28629 .57616 L .28711 .57466 L F
.094 0 0 r
.54078 .5159 m .54482 .51381 L .5422 .51458 L F
.473 .175 .378 r
.48126 .61169 m .48044 .61482 L .47788 .61527 L F
.378 .042 .265 r
.48395 .6117 m .48044 .61482 L .48126 .61169 L F
.204 .698 .92 r
.25446 .53611 m .25667 .5361 L .25845 .53668 L F
.301 .769 .94 r
.25667 .5361 m .26066 .53628 L .25845 .53668 L F
.61 .775 .96 r
.22166 .62477 m .22112 .62719 L .21913 .62496 L F
.22166 .62477 m .22354 .6264 L .22112 .62719 L F
.684 .898 .974 r
.46062 .574 m .45921 .57378 L .46258 .57257 L F
0 .545 .773 r
.24597 .64242 m .24994 .64307 L .24808 .64268 L F
.043 .571 .863 r
.24994 .64307 m .25119 .6427 L .24808 .64268 L F
.24994 .64307 m .25205 .64342 L .25119 .6427 L F
.503 .46 .742 r
.24994 .64307 m .25271 .64536 L .25205 .64342 L F
.818 .755 .793 r
.77764 .42187 m .77494 .42045 L .77711 .41979 L F
.535 .736 .967 r
.77992 .4208 m .77764 .42187 L .77711 .41979 L F
.47 .888 .916 r
.77675 .42201 m .77764 .42187 L .77992 .4208 L F
.77675 .42201 m .77992 .4208 L .78163 .42121 L F
.421 .693 .976 r
.78353 .41975 m .78163 .42121 L .77992 .4208 L F
.78353 .41975 m .78423 .42119 L .78163 .42121 L F
.652 .907 .588 r
.75188 .38433 m .74912 .38742 L .75173 .38638 L F
.354 .103 .389 r
.75425 .38331 m .75188 .38433 L .75173 .38638 L F
.303 .507 .889 r
.17416 .62132 m .17632 .62444 L .17792 .62439 L F
.552 .428 .665 r
.3095 .61498 m .30676 .61262 L .30905 .61207 L F
.3095 .61498 m .30715 .61559 L .30676 .61262 L F
0 0 0 r
.27428 .57912 m .2754 .57806 L .27646 .57593 L F
.27428 .57912 m .27442 .57997 L .2754 .57806 L F
.27428 .57912 m .27289 .58122 L .27442 .57997 L F
.45836 .65997 m .4595 .65929 L .46169 .65817 L F
.692 .51 .636 r
.13991 .60313 m .14286 .60344 L .14239 .60032 L F
.484 .498 .796 r
.14135 .5972 m .14239 .60032 L .14429 .59963 L F
.323 .251 .619 r
.14239 .60032 m .14369 .60236 L .14429 .59963 L F
.14239 .60032 m .14286 .60344 L .14369 .60236 L F
.852 .676 .663 r
.5127 .60876 m .51466 .61184 L .51424 .60972 L F
.336 .186 .525 r
.14122 .58212 m .14407 .5824 L .14306 .58133 L F
.14122 .58212 m .1411 .58483 L .14407 .5824 L F
.135 0 .038 r
.16803 .55796 m .16694 .55954 L .16992 .55716 L F
.74 .648 .758 r
.47106 .63961 m .47426 .63643 L .47066 .63682 L F
.569 .207 .314 r
.47426 .63643 m .47338 .63711 L .47066 .63682 L F
.598 .463 .668 r
.47066 .63682 m .47338 .63711 L .47323 .63348 L F
.566 .545 .79 r
.16863 .59112 m .16948 .59422 L .1712 .59349 L F
.602 .507 .719 r
.16423 .58726 m .16183 .58817 L .16137 .58457 L F
.504 .308 .548 r
.30403 .61808 m .30155 .62112 L .30169 .61859 L F
.89 .48 .221 r
.76907 .39526 m .76853 .3935 L .76789 .39358 L F
.358 .679 .978 r
.47364 .56291 m .47582 .56287 L .47413 .56143 L F
.47364 .56291 m .47582 .56287 L .47413 .56143 L F
.4 .184 .467 r
.3185 .6021 m .31678 .60031 L .31835 .59952 L F
.3185 .6021 m .31643 .60275 L .31678 .60031 L F
.508 .325 .568 r
.32805 .56654 m .32841 .56977 L .32628 .57015 L F
.516 .405 .666 r
.32991 .56297 m .32805 .56654 L .32733 .56344 L F
.32991 .56297 m .33146 .56672 L .32805 .56654 L F
.556 .359 .57 r
.33093 .56906 m .32805 .56654 L .33146 .56672 L F
.33093 .56906 m .32841 .56977 L .32805 .56654 L F
.634 .512 .697 r
.4755 .64333 m .47572 .64592 L .47816 .64283 L F
.647 .142 .034 r
.49998 .58216 m .49911 .58334 L .49599 .5815 L F
.834 .877 .44 r
.49944 .58333 m .4988 .58472 L .49911 .58334 L F
.075 .183 .674 r
.4988 .58472 m .4999 .58696 L .49911 .58334 L F
.78 .297 0 r
.49911 .58334 m .49947 .58534 L .4986 .58336 L F
.356 .431 .801 r
.49599 .5815 m .49911 .58334 L .49799 .58124 L F
.78 .297 0 r
.49911 .58334 m .4986 .58336 L .4981 .58223 L F
.834 .877 .44 r
.49998 .58216 m .49944 .58333 L .49911 .58334 L F
0 0 .019 r
.27579 .59076 m .27743 .58691 L .27512 .58767 L F
.27579 .59076 m .27636 .59098 L .27743 .58691 L F
.083 .134 .618 r
.27545 .5931 m .27636 .59098 L .27579 .59076 L F
.662 .84 .968 r
.81608 .44625 m .81791 .44376 L .81512 .44493 L F
.81608 .44625 m .81894 .44506 L .81791 .44376 L F
.18 0 0 r
.23552 .62657 m .2378 .62651 L .23981 .6258 L F
.184 0 0 r
.23981 .6258 m .2378 .62651 L .24151 .62598 L F
0 .383 .795 r
.24299 .55035 m .24287 .54975 L .24098 .54942 L F
.24299 .55035 m .24454 .55098 L .24287 .54975 L F
.455 .092 .26 r
.48151 .60807 m .485 .60552 L .48345 .60641 L F
.708 .986 .864 r
.21175 .6452 m .21441 .64235 L .21077 .64067 L F
.21175 .6452 m .21642 .64189 L .21441 .64235 L F
.512 .235 .431 r
.48683 .56622 m .48856 .56686 L .48972 .56361 L F
.692 .221 .129 r
.48785 .56388 m .48848 .56536 L .48972 .56361 L F
.936 .874 .455 r
.48848 .56536 m .48856 .56686 L .48972 .56361 L F
.792 .53 .542 r
.48972 .56361 m .48856 .56686 L .49341 .56685 L F
.737 .883 .947 r
.8238 .42008 m .8245 .41833 L .8258 .42027 L F
.579 .725 .943 r
.82851 .41733 m .8258 .42027 L .8245 .41833 L F
.82851 .41733 m .82974 .41986 L .8258 .42027 L F
.609 .61 .827 r
.8258 .42027 m .82974 .41986 L .82897 .42087 L F
.567 .646 .888 r
.81372 .4253 m .81226 .42866 L .81113 .42638 L F
.81372 .4253 m .81479 .42811 L .81226 .42866 L F
.47 .62 .916 r
.15365 .60856 m .1536 .60558 L .15181 .60542 L F
.15365 .60856 m .15563 .60833 L .1536 .60558 L F
.772 .47 .476 r
.57319 .57493 m .57497 .57262 L .57305 .57242 L F
.57319 .57493 m .57685 .57548 L .57497 .57262 L F
.452 .181 .411 r
.29113 .63054 m .28822 .63329 L .28844 .63074 L F
.623 .446 .621 r
.44365 .58533 m .44463 .58559 L .44597 .58213 L F
.321 .468 .852 r
.16659 .61544 m .16841 .61873 L .16949 .61691 L F
.354 .511 .875 r
.16949 .61691 m .16841 .61873 L .16982 .61845 L F
.204 .44 .865 r
.16841 .61873 m .17212 .62208 L .16982 .61845 L F
.309 .78 .669 r
.27167 .54995 m .27117 .55022 L .27117 .5501 L F
.202 .722 .698 r
.81445 .39839 m .81708 .39766 L .81775 .39751 L F
.132 0 0 r
.81708 .39766 m .82051 .39693 L .81775 .39751 L F
.496 .098 .216 r
.18184 .79803 m .1844 .79791 L .18214 .79759 L F
.731 .974 .728 r
.47366 .61661 m .47278 .61842 L .47548 .61574 L F
.305 0 0 r
.47788 .61527 m .47366 .61661 L .47548 .61574 L F
.952 .769 .618 r
.57804 .57894 m .57685 .57548 L .57634 .57785 L F
.922 .675 .548 r
.57543 .58082 m .57804 .57894 L .57634 .57785 L F
.57543 .58082 m .57792 .58161 L .57804 .57894 L F
0 .102 .624 r
.49602 .57896 m .49698 .57741 L .49512 .57496 L F
.652 .788 .947 r
.83815 .40386 m .84176 .40452 L .84076 .40295 L F
.862 .884 .852 r
.84076 .40295 m .84176 .40452 L .84378 .40211 L F
0 0 0 r
.17576 .59415 m .17431 .59613 L .17342 .59678 L F
0 0 .442 r
.17449 .59673 m .17342 .59678 L .17431 .59613 L F
.17449 .59673 m .17394 .59908 L .17342 .59678 L F
.703 .535 .659 r
.22489 .71303 m .2303 .71277 L .2296 .70989 L F
.318 .288 .667 r
.2296 .70989 m .2303 .71277 L .23169 .71212 L F
.2296 .70989 m .2303 .71277 L .23169 .71212 L F
.487 .283 .528 r
.31153 .60892 m .30905 .61207 L .30918 .60942 L F
.602 .507 .719 r
.16423 .58726 m .16137 .58457 L .16241 .58408 L F
.254 0 0 r
.19834 .5617 m .19715 .56094 L .19948 .56066 L F
.19834 .5617 m .19585 .56242 L .19715 .56094 L F
.883 .677 .62 r
.56065 .53282 m .55764 .53225 L .55795 .52963 L F
.896 .684 .609 r
.56065 .53282 m .55751 .53472 L .55764 .53225 L F
.56065 .53282 m .55957 .53591 L .55751 .53472 L F
0 0 0 r
.83745 .43149 m .83504 .43479 L .83581 .43571 L F
.238 0 0 r
.22161 .53746 m .22554 .53674 L .22354 .53702 L F
.31 0 .209 r
.25405 .62318 m .25484 .62172 L .25184 .6241 L F
0 0 .043 r
.25405 .62318 m .25643 .62073 L .25484 .62172 L F
.554 .608 .861 r
.1609 .61485 m .16156 .61103 L .15954 .61156 L F
.727 .819 .923 r
.20313 .63919 m .20534 .64057 L .20749 .63922 L F
.556 .578 .832 r
.14316 .60473 m .14369 .60236 L .14286 .60344 L F
.14316 .60473 m .14582 .6047 L .14369 .60236 L F
.707 .859 .954 r
.82678 .44057 m .82903 .43744 L .82569 .4393 L F
.82678 .44057 m .83003 .43871 L .82903 .43744 L F
0 0 0 r
.17377 .57542 m .17054 .57777 L .17195 .57513 L F
.657 .621 .802 r
.75411 .39619 m .75344 .39816 L .757 .3956 L F
0 0 0 r
.19545 .54367 m .19842 .54278 L .19616 .54315 L F
.524 .593 .866 r
.8011 .43855 m .80233 .44176 L .80474 .44145 L F
.494 .83 .542 r
.27933 .57331 m .27646 .57593 L .27813 .57439 L F
.196 0 .066 r
.27646 .57593 m .27734 .57738 L .27813 .57439 L F
.27646 .57593 m .2754 .57806 L .27734 .57738 L F
.114 0 0 r
.43285 .66932 m .43478 .66883 L .43605 .66821 L F
.575 .133 .162 r
.43478 .66883 m .43842 .66945 L .43605 .66821 L F
.418 .499 .835 r
.18372 .63032 m .18389 .62661 L .18265 .62721 L F
.18372 .63032 m .18563 .63033 L .18389 .62661 L F
.73 .65 .77 r
.44866 .63002 m .45292 .62919 L .44924 .62745 L F
.562 .482 .723 r
.45292 .62919 m .45536 .62876 L .45447 .62392 L F
.831 .502 .431 r
.8238 .42008 m .82211 .42166 L .82169 .41994 L F
.737 .883 .947 r
.8238 .42008 m .82169 .41994 L .8245 .41833 L F
.849 .531 .449 r
.8238 .42008 m .82478 .42229 L .82211 .42166 L F
0 0 0 r
.83745 .43149 m .83778 .43199 L .83504 .43479 L F
.84014 .42931 m .8391 .43061 L .83745 .43149 L F
.791 .961 .919 r
.83766 .43182 m .83866 .4297 L .83714 .43108 L F
0 0 0 r
.83745 .43149 m .83905 .43068 L .83778 .43199 L F
.791 .961 .919 r
.83778 .43199 m .83794 .43158 L .83766 .43182 L F
.83794 .43158 m .83866 .4297 L .83766 .43182 L F
0 0 0 r
.8391 .43061 m .83905 .43068 L .83898 .43072 L F
.8391 .43061 m .83898 .43072 L .83745 .43149 L F
.789 .579 .617 r
.55991 .51416 m .56356 .51474 L .56377 .51187 L F
.541 0 0 r
.43526 .67699 m .43466 .67637 L .43651 .67514 L F
.43526 .67699 m .43389 .67673 L .43466 .67637 L F
.444 .694 .972 r
.5408 .60063 m .53744 .59909 L .53851 .60065 L F
0 .474 .73 r
.5689 .59659 m .56949 .59677 L .57327 .59751 L F
.689 .771 .914 r
.2336 .69395 m .23299 .69749 L .23593 .69596 L F
.919 .968 .785 r
.23169 .69736 m .23299 .69749 L .2336 .69395 L F
.489 .819 1 r
.29776 .53872 m .29714 .54014 L .29541 .53891 L F
.29776 .53872 m .29947 .53957 L .29714 .54014 L F
0 0 .074 r
.51094 .62075 m .50911 .62459 L .51168 .62411 L F
.51094 .62075 m .51033 .62319 L .50911 .62459 L F
.485 .818 .999 r
.50911 .62459 m .51033 .62319 L .51168 .62411 L F
.51 .293 .521 r
.51168 .62411 m .50915 .62745 L .50911 .62459 L F
.753 .783 .877 r
.80082 .42463 m .80211 .42636 L .7985 .4261 L F
.529 .692 .943 r
.80473 .426 m .80211 .42636 L .80082 .42463 L F
.506 0 0 r
.24393 .62539 m .24817 .62483 L .24589 .62515 L F
.926 .885 .772 r
.56046 .53943 m .55755 .54124 L .55876 .53813 L F
.56046 .53943 m .55854 .54229 L .55755 .54124 L F
.719 .336 .322 r
.55373 .51154 m .55612 .51383 L .55747 .51188 L F
.722 .339 .324 r
.55747 .51188 m .55612 .51383 L .55991 .51416 L F
.39 0 0 r
.5448 .52078 m .54396 .52209 L .54023 .52119 L F
.468 0 0 r
.54664 .52276 m .5448 .52078 L .54607 .52151 L F
.54664 .52276 m .54396 .52209 L .5448 .52078 L F
.424 .554 .882 r
.78119 .43501 m .78275 .43809 L .78495 .43797 L F
.756 .563 .636 r
.45928 .64841 m .46364 .64605 L .45958 .64576 L F
.45928 .64841 m .46322 .64867 L .46364 .64605 L F
.421 .786 .995 r
.15181 .60542 m .14772 .60484 L .14969 .60583 L F
.289 .033 .341 r
.14847 .57259 m .15009 .57433 L .15042 .57209 L F
.14847 .57259 m .14787 .57529 L .15009 .57433 L F
.475 .328 .6 r
.45447 .62392 m .45651 .62077 L .4547 .62152 L F
.218 0 .18 r
.50373 .60023 m .50572 .59971 L .50689 .59773 L F
.418 .446 .782 r
.50373 .60023 m .50683 .60208 L .50572 .59971 L F
.725 .666 .792 r
.83175 .40462 m .83364 .4061 L .83549 .40525 L F
.434 .241 .518 r
.31602 .6051 m .31408 .60325 L .31643 .60275 L F
.31602 .6051 m .31388 .6058 L .31408 .60325 L F
.485 .798 .999 r
.30548 .54144 m .30711 .54248 L .30321 .54188 L F
.252 .559 .933 r
.30761 .54101 m .30711 .54248 L .30548 .54144 L F
.30761 .54101 m .3097 .54338 L .30711 .54248 L F
.963 .762 .584 r
.57741 .58634 m .57945 .58494 L .57803 .58396 L F
.57741 .58634 m .57896 .58735 L .57945 .58494 L F
.73 .201 0 r
.50276 .55519 m .50189 .55574 L .49961 .55326 L F
.667 .115 0 r
.50395 .55647 m .50189 .55574 L .50276 .55519 L F
.409 .493 .834 r
.786 .4401 m .78761 .43759 L .78495 .43797 L F
.786 .4401 m .78877 .44088 L .78761 .43759 L F
.212 .731 .861 r
.23001 .53627 m .23195 .53655 L .22975 .53679 L F
.729 .856 .941 r
.55367 .59969 m .5573 .59982 L .55581 .59843 L F
.648 .803 .958 r
.55581 .59843 m .5573 .59982 L .56022 .5989 L F
.532 .567 .836 r
.1573 .61185 m .15791 .6079 L .15563 .60833 L F
.1573 .61185 m .15954 .61156 L .15791 .6079 L F
.323 .094 .405 r
.14306 .58133 m .14596 .57765 L .14363 .57871 L F
.866 .59 .519 r
.55784 .52708 m .55594 .52895 L .55476 .52608 L F
.55784 .52708 m .55795 .52963 L .55594 .52895 L F
.677 .653 .819 r
.32464 .58454 m .32387 .58789 L .32257 .58523 L F
.32464 .58454 m .32643 .58787 L .32387 .58789 L F
.543 .337 .551 r
.32617 .58995 m .32387 .58789 L .32643 .58787 L F
.32617 .58995 m .32344 .59077 L .32387 .58789 L F
0 0 0 r
.17917 .55152 m .17578 .55383 L .1779 .55277 L F
.095 0 0 r
.1779 .55277 m .1809 .55077 L .17917 .55152 L F
.277 0 0 r
.26303 .55561 m .25831 .55688 L .25964 .55627 L F
.639 .635 .83 r
.84014 .39739 m .83665 .39599 L .8394 .39528 L F
.06 .385 .847 r
.8394 .39528 m .84291 .39838 L .84014 .39739 L F
.764 .664 .752 r
.75339 .39 m .75173 .38638 L .75075 .38934 L F
0 0 0 r
.25919 .65133 m .26375 .64908 L .26168 .65076 L F
.738 .743 .856 r
.26607 .6457 m .26375 .64908 L .26181 .64571 L F
.181 0 0 r
.26375 .64908 m .26407 .65023 L .26168 .65076 L F
.26375 .64908 m .26605 .64864 L .26407 .65023 L F
.556 .489 .735 r
.26607 .6457 m .26605 .64864 L .26375 .64908 L F
.48 .799 1 r
.26066 .53628 m .26292 .53585 L .26464 .53687 L F
.404 .783 .992 r
.26292 .53585 m .2669 .53642 L .26464 .53687 L F
0 .478 .819 r
.76771 .41536 m .77096 .41663 L .76835 .41719 L F
.092 .147 .628 r
.1404 .5941 m .14049 .59404 L .1399 .59074 L F
0 .071 .627 r
.50024 .57578 m .50213 .57811 L .50224 .57887 L F
.985 .802 .404 r
.50213 .57811 m .50251 .58108 L .50224 .57887 L F
.791 .625 .676 r
.47777 .63368 m .47885 .63511 L .48168 .63329 L F
.576 .502 .735 r
.48163 .63052 m .48168 .63329 L .48409 .63002 L F
.424 .132 .362 r
.47278 .61842 m .47253 .62052 L .46997 .62098 L F
.416 .125 .36 r
.4747 .61977 m .47278 .61842 L .47366 .61661 L F
.4747 .61977 m .47253 .62052 L .47278 .61842 L F
.034 .201 .705 r
.47366 .61661 m .4747 .61977 L .47278 .61842 L F
0 .325 .811 r
.76668 .42015 m .76922 .42192 L .76727 .41906 L F
.636 .52 .705 r
.22693 .69785 m .22855 .69315 L .2254 .69424 L F
.22693 .69785 m .23017 .69643 L .22855 .69315 L F
.532 .354 .584 r
.31388 .6058 m .31153 .60892 L .31155 .60632 L F
.498 .282 .517 r
.46424 .62464 m .46424 .62723 L .462 .62755 L F
.529 .272 .47 r
.46672 .62408 m .46424 .62723 L .46424 .62464 L F
.835 .62 .612 r
.56804 .56585 m .56957 .56887 L .5718 .56684 L F
.753 .318 .218 r
.79569 .39843 m .79802 .4008 L .7992 .39928 L F
.668 .212 .161 r
.7992 .39928 m .79802 .4008 L .80205 .40121 L F
.787 .367 .251 r
.55413 .52391 m .55282 .52544 L .55196 .52365 L F
.895 .531 .344 r
.55476 .52608 m .55282 .52544 L .55413 .52391 L F
.619 .788 .963 r
.83665 .39599 m .83298 .39527 L .83575 .39432 L F
.596 .762 .958 r
.83877 .39366 m .83665 .39599 L .83575 .39432 L F
.83877 .39366 m .8394 .39528 L .83665 .39599 L F
.202 .723 .864 r
.23195 .53655 m .2343 .53634 L .23598 .53655 L F
.499 0 0 r
.24385 .64251 m .23976 .64256 L .23919 .64315 L F
.34 .575 .928 r
.80474 .44145 m .80777 .44412 L .80871 .44399 L F
.402 .818 .973 r
.2669 .53642 m .26912 .53602 L .27087 .53655 L F
.364 .801 .962 r
.26912 .53602 m .27317 .53616 L .27087 .53655 L F
.574 .538 .777 r
.44365 .58533 m .44461 .58581 L .44463 .58559 L F
.779 .615 .676 r
.56309 .55405 m .56683 .55453 L .56523 .55091 L F
.818 .568 .56 r
.56309 .55405 m .56677 .55684 L .56683 .55453 L F
.466 0 0 r
.4977 .5487 m .50041 .54975 L .50169 .54906 L F
.517 0 0 r
.50041 .54975 m .50422 .55031 L .50169 .54906 L F
0 0 0 r
.25268 .66066 m .2516 .66196 L .24976 .66556 L F
0 .313 .739 r
.54208 .5778 m .53928 .57636 L .5396 .57687 L F
.54208 .5778 m .54353 .57889 L .53928 .57636 L F
.693 .711 .862 r
.83175 .40462 m .83549 .40525 L .8342 .4021 L F
.695 .712 .862 r
.8342 .4021 m .83549 .40525 L .83815 .40386 L F
.791 .748 .813 r
.83678 .4157 m .83815 .41743 L .83527 .41676 L F
.888 .74 .693 r
.83815 .41743 m .8349 .41928 L .83527 .41676 L F
.83815 .41743 m .83767 .42055 L .8349 .41928 L F
.641 .708 .896 r
.83989 .41396 m .83815 .41743 L .83678 .4157 L F
.83989 .41396 m .84082 .41664 L .83815 .41743 L F
.352 .817 .917 r
.19842 .54278 m .20059 .54229 L .20237 .54248 L F
.327 .807 .891 r
.20059 .54229 m .20456 .54188 L .20237 .54248 L F
.94 .577 .276 r
.7944 .40522 m .79284 .40417 L .79215 .40185 L F
.926 .541 .224 r
.7944 .40522 m .79359 .4064 L .79284 .40417 L F
.679 .175 .039 r
.7944 .40522 m .79707 .40717 L .79359 .4064 L F
.532 .29 .493 r
.46835 .61263 m .4705 .61426 L .47152 .61184 L F
.46835 .61263 m .46796 .61496 L .4705 .61426 L F
.133 .426 .867 r
.21077 .64067 m .21133 .63928 L .20923 .63927 L F
.21077 .64067 m .21441 .64235 L .21133 .63928 L F
.277 0 0 r
.26303 .55561 m .26087 .55673 L .25831 .55688 L F
0 0 0 r
.26298 .55583 m .26303 .55561 L .26463 .55386 L F
.26298 .55583 m .26087 .55673 L .26303 .55561 L F
.66 .292 .337 r
.45469 .66102 m .4524 .65889 L .45222 .66283 L F
.45469 .66102 m .45818 .66148 L .4524 .65889 L F
.179 .708 .702 r
.21441 .64235 m .21642 .64189 L .21749 .64163 L F
.979 .813 .606 r
.55437 .56384 m .55239 .56563 L .55362 .56205 L F
.55437 .56384 m .5538 .56687 L .55239 .56563 L F
.43 .22 .491 r
.1682 .7095 m .16591 .70982 L .16832 .7067 L F
.1682 .7095 m .16591 .70982 L .16832 .7067 L F
.764 .869 .439 r
.50868 .59406 m .50749 .59581 L .50479 .59489 L F
.50868 .59406 m .50689 .59773 L .50749 .59581 L F
.811 .383 .228 r
.50749 .59581 m .50868 .59406 L .50914 .59239 L F
.529 .349 .582 r
.50689 .59773 m .51057 .59677 L .50868 .59406 L F
.811 .383 .228 r
.50749 .59581 m .51057 .59677 L .50868 .59406 L F
.811 .384 .231 r
.50868 .59406 m .51057 .59677 L .51265 .59695 L F
.722 .783 .901 r
.79633 .44258 m .79854 .44121 L .79501 .44075 L F
.855 .539 .452 r
.51921 .56292 m .52332 .56078 L .51937 .55977 L F
.51921 .56292 m .52321 .56308 L .52332 .56078 L F
.602 .478 .684 r
.32874 .57207 m .32628 .57015 L .32841 .56977 L F
.32874 .57207 m .32622 .57264 L .32628 .57015 L F
.58 .574 .811 r
.53022 .52054 m .53133 .52375 L .53393 .52275 L F
.576 .763 .967 r
.19994 .61475 m .19968 .61711 L .19786 .61564 L F
.19994 .61475 m .2023 .61658 L .19968 .61711 L F
.463 .1 .262 r
.28396 .63598 m .27933 .63866 L .27996 .63726 L F
.615 .73 .928 r
.78967 .44301 m .79143 .44027 L .78877 .44088 L F
.78967 .44301 m .79278 .44211 L .79143 .44027 L F
.555 .155 .238 r
.51182 .55558 m .51547 .55493 L .51333 .5546 L F
.51182 .55558 m .51443 .55644 L .51547 .55493 L F
.967 .751 .559 r
.51728 .55637 m .51547 .55493 L .51443 .55644 L F
.686 .334 0 r
.52584 .57863 m .52558 .57818 L .52425 .57496 L F
0 0 .376 r
.52584 .57863 m .52725 .58092 L .52558 .57818 L F
.954 .881 .723 r
.56632 .53814 m .56908 .53621 L .56792 .53516 L F
.56632 .53814 m .56737 .53946 L .56908 .53621 L F
.61 .541 .752 r
.45072 .66741 m .45222 .66283 L .45007 .66444 L F
0 .04 .609 r
.17556 .59236 m .17576 .59415 L .17399 .59053 L F
0 0 0 r
.17556 .59236 m .17431 .59613 L .17576 .59415 L F
.742 .63 .735 r
.75339 .39 m .75683 .39099 L .75578 .38717 L F
.766 .425 .408 r
.75675 .39308 m .75683 .39099 L .75339 .39 L F
.736 .399 .409 r
.75675 .39308 m .75827 .39207 L .75683 .39099 L F
.512 .912 .898 r
.83247 .39496 m .83043 .39638 L .82947 .39552 L F
.83247 .39496 m .83298 .39527 L .83043 .39638 L F
.438 .029 .165 r
.80555 .40058 m .80819 .40022 L .80554 .39932 L F
.438 0 .107 r
.80554 .39932 m .80819 .40022 L .80828 .39915 L F
.239 0 .27 r
.18752 .54732 m .18928 .54693 L .18956 .54632 L F
.18752 .54732 m .18726 .54809 L .18928 .54693 L F
.105 0 0 r
.16176 .5627 m .16355 .56249 L .16494 .56029 L F
.112 0 0 r
.16494 .56029 m .1654 .56172 L .16694 .55954 L F
.16494 .56029 m .16355 .56249 L .1654 .56172 L F
.755 .7 .801 r
.54726 .59981 m .54873 .60318 L .5512 .60057 L F
.989 .732 .434 r
.26076 .64515 m .2623 .64277 L .26181 .64571 L F
.528 0 0 r
.2623 .64277 m .26607 .6457 L .26181 .64571 L F
.948 .777 .319 r
.26181 .64571 m .2623 .64277 L .26137 .64386 L F
.495 .12 .258 r
.46049 .61806 m .46259 .61943 L .46302 .61834 L F
.46049 .61806 m .45898 .61996 L .46259 .61943 L F
.745 .717 .825 r
.83468 .43099 m .83221 .43306 L .83066 .43091 L F
.299 0 0 r
.24098 .54942 m .23664 .54981 L .23839 .54964 L F
.398 .239 .546 r
.82717 .42603 m .82489 .42897 L .82333 .42546 L F
.82717 .42603 m .82724 .42851 L .82489 .42897 L F
.293 .777 .912 r
.27317 .53616 m .27542 .53582 L .27709 .5361 L F
.477 .802 1 r
.27542 .53582 m .27909 .53633 L .27709 .5361 L F
.401 .113 .355 r
.29661 .62442 m .29567 .62695 L .29357 .62745 L F
.484 .192 .394 r
.29808 .62649 m .29661 .62442 L .2991 .62392 L F
.29808 .62649 m .29567 .62695 L .29661 .62442 L F
.901 .786 .725 r
.56405 .54738 m .56523 .55091 L .5658 .54853 L F
.56405 .54738 m .5625 .55062 L .56523 .55091 L F
.859 .737 .727 r
.56133 .55268 m .56523 .55091 L .5625 .55062 L F
.56133 .55268 m .56309 .55405 L .56523 .55091 L F
.646 .515 .689 r
.13948 .60359 m .13991 .60313 L .13941 .60317 L F
.699 .724 .869 r
.81973 .42505 m .81827 .42887 L .81715 .42737 L F
.81973 .42505 m .82149 .42697 L .81827 .42887 L F
.371 .415 .777 r
.17568 .60125 m .176 .60285 L .17426 .60329 L F
.362 .377 .741 r
.176 .60285 m .17645 .6051 L .17426 .60329 L F
.814 .392 .24 r
.53721 .58701 m .53877 .58594 L .53476 .58402 L F
.573 .065 .009 r
.53721 .58701 m .54137 .58722 L .53877 .58594 L F
.516 .301 .526 r
.53877 .58594 m .54137 .58722 L .54159 .58443 L F
.537 .271 .46 r
.28822 .63329 m .28578 .63537 L .28589 .63344 L F
.596 .615 .842 r
.32871 .58709 m .32643 .58787 L .32464 .58454 L F
.633 .31 .407 r
.32643 .58787 m .32861 .59008 L .32617 .58995 L F
.497 .316 .565 r
.32871 .58709 m .32861 .59008 L .32643 .58787 L F
.574 .315 .486 r
.3095 .61498 m .30648 .61761 L .30715 .61559 L F
.541 .093 .136 r
.54023 .52119 m .53886 .52296 L .53633 .52275 L F
.346 .818 .901 r
.54396 .52209 m .53886 .52296 L .54023 .52119 L F
.5 .754 .986 r
.2238 .64164 m .22739 .64263 L .22576 .64154 L F
.361 .764 .984 r
.22739 .64263 m .22782 .6416 L .22576 .64154 L F
.22739 .64263 m .22956 .64242 L .22782 .6416 L F
.599 .627 .85 r
.18206 .79845 m .1844 .79791 L .18184 .79803 L F
.31 0 .26 r
.27169 .55571 m .27407 .55426 L .27128 .55467 L F
.198 .004 .376 r
.26719 .60624 m .26675 .60869 L .26875 .6054 L F
.747 .789 .886 r
.18584 .61208 m .18173 .61197 L .18416 .61039 L F
.395 .667 .968 r
.18657 .61048 m .18584 .61208 L .18416 .61039 L F
.18657 .61048 m .1879 .61197 L .18584 .61208 L F
.409 .121 .361 r
.32138 .59387 m .32077 .59644 L .31822 .59704 L F
.516 .398 .658 r
.32344 .59077 m .32361 .59335 L .32138 .59387 L F
.471 .196 .415 r
.32361 .59335 m .32077 .59644 L .32138 .59387 L F
.551 .863 .996 r
.82588 .39518 m .82417 .39676 L .82298 .3965 L F
.82588 .39518 m .82674 .39601 L .82417 .39676 L F
.134 0 .196 r
.16176 .5627 m .16269 .56452 L .16355 .56249 L F
.16176 .5627 m .16099 .56555 L .16269 .56452 L F
.013 .546 .85 r
.31542 .54436 m .31887 .54539 L .31714 .54524 L F
.335 0 0 r
.24817 .62483 m .25014 .62521 L .25184 .6241 L F
.252 0 0 r
.25014 .62521 m .25405 .62318 L .25184 .6241 L F
.77 .69 .775 r
.54991 .57589 m .54586 .57803 L .54831 .57499 L F
.798 .752 .81 r
.55039 .57246 m .54991 .57589 L .54831 .57499 L F
.481 .283 .535 r
.30146 .5756 m .30371 .57513 L .30401 .57254 L F
.49 .252 .481 r
.30107 .57807 m .30371 .57513 L .30146 .5756 L F
.481 .283 .535 r
.30401 .57254 m .30371 .57513 L .30146 .5756 L F
.49 .252 .481 r
.30107 .57807 m .30371 .57513 L .30146 .5756 L F
.595 .281 .406 r
.54738 .5137 m .55026 .51177 L .54767 .51205 L F
.628 .873 .988 r
.242 .55682 m .24373 .55772 L .24419 .55589 L F
.242 .55682 m .24373 .55772 L .24419 .55589 L F
.574 .605 .846 r
.16982 .61845 m .17212 .62208 L .17416 .62132 L F
0 0 .37 r
.77096 .41663 m .77256 .42013 L .77243 .42015 L F
.589 .054 0 r
.77256 .42013 m .77494 .42045 L .77243 .42015 L F
.655 .128 0 r
.53324 .57499 m .53374 .57497 L .53202 .57216 L F
.53324 .57499 m .53596 .57711 L .53374 .57497 L F
.28 .235 .627 r
.14049 .59404 m .14174 .59009 L .1399 .59074 L F
.14049 .59404 m .142 .59382 L .14174 .59009 L F
.3 .381 .779 r
.14049 .59404 m .14316 .59606 L .142 .59382 L F
.427 .387 .712 r
.14049 .59404 m .14135 .5972 L .14316 .59606 L F
.645 .793 .953 r
.74812 .38595 m .74912 .38742 L .75173 .38638 L F
.74812 .38595 m .74912 .38742 L .75173 .38638 L F
.576 .451 .673 r
.32874 .57207 m .32657 .57521 L .32622 .57264 L F
.523 .121 .221 r
.47632 .63622 m .47561 .63834 L .47338 .63711 L F
.645 .597 .786 r
.47548 .63359 m .47632 .63622 L .47885 .63511 L F
.174 .289 .742 r
.47548 .63359 m .47783 .63531 L .47632 .63622 L F
.572 .417 .633 r
.47338 .63711 m .47649 .63662 L .47548 .63359 L F
.47649 .63662 m .47661 .6366 L .47657 .63651 L F
0 0 0 r
.47716 .63571 m .47594 .63736 L .47632 .63622 L F
.572 .417 .633 r
.47649 .63662 m .47657 .63651 L .47548 .63359 L F
0 0 0 r
.47661 .6366 m .47561 .63834 L .47783 .63531 L F
.47783 .63531 m .47561 .63834 L .47594 .63736 L F
.47783 .63531 m .47657 .63651 L .47716 .63571 L F
.336 .286 .654 r
.47548 .63359 m .47657 .63651 L .47783 .63531 L F
.47657 .63651 m .47661 .6366 L .47783 .63531 L F
0 0 0 r
.47783 .63531 m .47594 .63736 L .47657 .63651 L F
.86 .637 .599 r
.83767 .42055 m .83484 .42241 L .8349 .41928 L F
.347 .153 .468 r
.46389 .62916 m .462 .62755 L .46424 .62723 L F
.46389 .62916 m .46186 .63015 L .462 .62755 L F
.892 .684 .169 r
.51262 .6021 m .51314 .60576 L .51386 .60315 L F
0 0 .192 r
.27933 .57331 m .2805 .57252 L .28126 .56909 L F
0 0 0 r
.17054 .57777 m .16815 .58065 L .16884 .57874 L F
.707 .885 .963 r
.43574 .65465 m .43323 .65398 L .43412 .65344 L F
.43574 .65465 m .43323 .65398 L .43412 .65344 L F
.977 .679 .369 r
.43574 .65465 m .43576 .65725 L .43412 .65344 L F
.43574 .65465 m .43576 .65725 L .43412 .65344 L F
.486 .439 .729 r
.24754 .68175 m .24558 .68244 L .24507 .67984 L F
.379 .808 .967 r
.23822 .53611 m .24039 .5357 L .2421 .53621 L F
.213 .73 .869 r
.24039 .5357 m .24435 .53569 L .2421 .53621 L F
.96 .73 .283 r
.84416 .41863 m .84488 .41704 L .84406 .41571 L F
.84416 .41863 m .84489 .41982 L .84488 .41704 L F
.245 .527 .916 r
.21753 .6234 m .21691 .62479 L .21574 .62308 L F
.344 .646 .966 r
.21753 .6234 m .21913 .62496 L .21691 .62479 L F
.806 .375 .222 r
.51057 .59677 m .51137 .5985 L .51265 .59695 L F
.945 .607 .349 r
.51137 .5985 m .51328 .59974 L .51265 .59695 L F
.826 .919 .899 r
.2108 .73407 m .21287 .73476 L .21347 .73272 L F
0 0 0 r
.26504 .55493 m .26298 .55583 L .26463 .55386 L F
.572 .417 .633 r
.47338 .63711 m .47548 .63359 L .47323 .63348 L F
.67 .932 .97 r
.22768 .62568 m .22711 .6274 L .22537 .6266 L F
.22768 .62568 m .22966 .62606 L .22711 .6274 L F
.408 .276 .588 r
.27971 .56617 m .28141 .56255 L .27984 .56514 L F
.521 .612 .884 r
.272 .55812 m .27316 .55586 L .27169 .55571 L F
.272 .55812 m .27456 .55772 L .27316 .55586 L F
.442 .1 .289 r
.22306 .71576 m .22536 .71485 L .22489 .71303 L F
.28 0 0 r
.22536 .71485 m .2303 .71277 L .22489 .71303 L F
.802 .637 .678 r
.5397 .57884 m .54353 .57889 L .54208 .5778 L F
.5397 .57884 m .5423 .58216 L .54353 .57889 L F
.711 .791 .914 r
.54385 .57622 m .54353 .57889 L .54208 .5778 L F
.54385 .57622 m .54586 .57803 L .54353 .57889 L F
.067 0 .022 r
.15679 .56693 m .15765 .56759 L .15895 .56638 L F
.15679 .56693 m .1558 .56861 L .15765 .56759 L F
.28 0 0 r
.22536 .71485 m .22774 .7147 L .2303 .71277 L F
.331 .098 .403 r
.23148 .71473 m .2303 .71277 L .23169 .71212 L F
.23148 .71473 m .22961 .71544 L .2303 .71277 L F
0 0 0 r
.2303 .71277 m .22999 .71331 L .23169 .71212 L F
.2303 .71277 m .22774 .7147 L .22999 .71331 L F
.638 .563 .754 r
.32995 .56083 m .32733 .56344 L .32738 .56191 L F
.68 .633 .795 r
.32991 .56297 m .32733 .56344 L .32995 .56083 L F
.567 .356 .553 r
.23381 .67332 m .23624 .67272 L .23644 .67012 L F
.398 .379 .721 r
.44461 .58581 m .44612 .58734 L .44463 .58559 L F
.403 .551 .889 r
.76922 .42192 m .76953 .42376 L .77112 .42174 L F
.46 .634 .93 r
.76953 .42376 m .77204 .42389 L .77112 .42174 L F
.624 .849 .985 r
.54514 .60084 m .54606 .59886 L .54147 .59983 L F
.54514 .60084 m .54726 .59981 L .54606 .59886 L F
.775 .306 .129 r
.50694 .55738 m .50576 .55856 L .50395 .55647 L F
.801 .343 .151 r
.50694 .55738 m .50947 .56032 L .50576 .55856 L F
.771 .382 .317 r
.51106 .56006 m .50947 .56032 L .50694 .55738 L F
.578 .825 .992 r
.24304 .67132 m .24476 .66988 L .24285 .67003 L F
.56 .424 .653 r
.32426 .57832 m .32487 .58426 L .32241 .58439 L F
.682 .514 .652 r
.32777 .58302 m .32426 .57832 L .32664 .57766 L F
.32777 .58302 m .32487 .58426 L .32426 .57832 L F
.545 .427 .669 r
.32464 .58454 m .32241 .58439 L .32487 .58426 L F
.32464 .58454 m .32257 .58523 L .32241 .58439 L F
.782 .547 .58 r
.52886 .57156 m .53208 .56961 L .52786 .56976 L F
.52886 .57156 m .53202 .57216 L .53208 .56961 L F
.741 .666 .777 r
.45397 .6581 m .45588 .65793 L .45454 .65434 L F
.077 .248 .737 r
.45454 .65434 m .45588 .65793 L .45689 .65655 L F
.43 .333 .644 r
.45588 .65793 m .45836 .65997 L .45689 .65655 L F
.45588 .65793 m .45818 .66148 L .45836 .65997 L F
0 .439 .848 r
.19604 .63519 m .19755 .63653 L .19724 .63553 L F
0 .421 .839 r
.19755 .63653 m .19886 .6369 L .19724 .63553 L F
.867 .424 .044 r
.19755 .63653 m .19863 .63805 L .19886 .6369 L F
.946 .61 .355 r
.51766 .55854 m .51909 .55751 L .51728 .55637 L F
.51766 .55854 m .51937 .55977 L .51909 .55751 L F
.4 .296 .62 r
.1399 .59074 m .14174 .59009 L .14145 .58741 L F
.772 .659 .737 r
.51052 .55424 m .51333 .5546 L .5126 .55167 L F
.904 .496 .192 r
.51052 .55424 m .51182 .55558 L .51333 .5546 L F
.74 .469 .519 r
.51333 .5546 m .51301 .55051 L .5126 .55167 L F
.6 .244 .339 r
.45082 .64884 m .4531 .65075 L .4533 .64892 L F
.119 0 .097 r
.24449 .66967 m .24535 .66766 L .24285 .67003 L F
.416 .051 .234 r
.24699 .66902 m .24535 .66766 L .24449 .66967 L F
.396 .055 .265 r
.24699 .66902 m .24759 .667 L .24535 .66766 L F
.805 .709 .759 r
.7608 .41394 m .7621 .41809 L .76399 .41533 L F
.203 .701 .914 r
.76621 .4148 m .76771 .41536 L .76399 .41533 L F
.132 .222 .692 r
.76399 .41533 m .76727 .41906 L .76621 .4148 L F
.961 .739 .558 r
.50643 .58435 m .50615 .58682 L .50781 .58766 L F
.929 .547 .186 r
.50735 .58962 m .50781 .58766 L .50615 .58682 L F
.50735 .58962 m .50879 .59063 L .50781 .58766 L F
.515 .305 .533 r
.4209 .65789 m .42345 .65478 L .42042 .65451 L F
.177 0 0 r
.53259 .51999 m .53514 .5194 L .53643 .51797 L F
0 0 0 r
.53643 .51797 m .53689 .51827 L .53843 .51676 L F
.53643 .51797 m .53514 .5194 L .53689 .51827 L F
.515 .305 .533 r
.4209 .65789 m .42331 .65741 L .42345 .65478 L F
.42345 .65478 m .42331 .65741 L .4209 .65789 L F
.493 .807 1 r
.42409 .65316 m .42581 .6543 L .42345 .65478 L F
.981 .734 .484 r
.42581 .6543 m .42345 .65478 L .42331 .65741 L F
.42581 .6543 m .42409 .65316 L .42345 .65478 L F
.492 .287 .529 r
.42581 .6543 m .42331 .65741 L .42345 .65478 L F
.224 .74 .728 r
.48683 .56622 m .48562 .56648 L .48565 .56653 L F
.635 .242 .282 r
.50422 .55031 m .50734 .55076 L .50857 .54886 L F
.481 .074 .191 r
.50857 .54886 m .51135 .54991 L .51039 .54736 L F
.50857 .54886 m .50734 .55076 L .51135 .54991 L F
.597 .427 .622 r
.24742 .67903 m .24754 .68175 L .24507 .67984 L F
.904 .496 .192 r
.51052 .55424 m .51164 .55688 L .51182 .55558 L F
.649 .294 .357 r
.51164 .55688 m .51443 .55644 L .51182 .55558 L F
.004 0 0 r
.16815 .58065 m .16508 .58342 L .16632 .58156 L F
.286 .175 .547 r
.82974 .41986 m .83127 .41886 L .82897 .42087 L F
.493 .688 .954 r
.81216 .4451 m .81402 .44316 L .8115 .44326 L F
.81216 .4451 m .81512 .44493 L .81402 .44316 L F
.297 .398 .797 r
.24449 .66967 m .24285 .67003 L .24476 .66988 L F
.576 .451 .673 r
.32874 .57207 m .32989 .57553 L .32657 .57521 L F
.579 .383 .58 r
.32989 .57553 m .32664 .57766 L .32657 .57521 L F
.974 .708 .294 r
.51286 .54459 m .513 .54727 L .51389 .54816 L F
.905 .844 .773 r
.513 .54727 m .51301 .55051 L .51389 .54816 L F
.499 0 0 r
.24385 .64251 m .24208 .64296 L .23976 .64256 L F
.318 0 0 r
.24385 .64251 m .24597 .64242 L .24208 .64296 L F
.589 .869 .546 r
.76378 .39592 m .76123 .39874 L .76337 .39796 L F
.6 .497 .708 r
.76156 .40177 m .76337 .39796 L .76123 .39874 L F
.217 .303 .738 r
.22855 .69315 m .23169 .69736 L .23107 .69344 L F
.22855 .69315 m .23017 .69643 L .23169 .69736 L F
.282 .369 .776 r
.3295 .55224 m .32857 .55426 L .32715 .55032 L F
.351 .452 .824 r
.3295 .55224 m .33073 .5546 L .32857 .55426 L F
.583 .581 .816 r
.33073 .5546 m .3291 .55731 L .32857 .55426 L F
.484 .498 .796 r
.14135 .5972 m .14429 .59963 L .14316 .59606 L F
.547 .143 .227 r
.45453 .66651 m .45327 .66881 L .45072 .66741 L F
.346 0 .137 r
.45544 .66635 m .45531 .66726 L .45453 .66651 L F
.45682 .66611 m .45612 .66665 L .45544 .66635 L F
.45612 .66665 m .45531 .66726 L .45544 .66635 L F
.45682 .66611 m .45655 .66664 L .45569 .66721 L F
.45682 .66611 m .45569 .66721 L .45524 .66731 L F
.272 0 .222 r
.45682 .66611 m .45902 .66532 L .45961 .66353 L F
.548 .806 .993 r
.45682 .66611 m .45902 .66532 L .45961 .66353 L F
.4 .056 .262 r
.45902 .66532 m .45782 .6664 L .45682 .66611 L F
.596 .609 .835 r
.45675 .66695 m .45799 .66636 L .45675 .66687 L F
.4 .056 .262 r
.45902 .66532 m .45869 .66618 L .45782 .6664 L F
.596 .609 .835 r
.45799 .66636 m .45881 .66597 L .45782 .6664 L F
.45799 .66636 m .45782 .6664 L .45675 .66687 L F
.45714 .66685 m .45892 .6662 L .45722 .66679 L F
.45693 .66691 m .45722 .66679 L .45675 .66695 L F
.45714 .66685 m .45722 .66679 L .45693 .66691 L F
.861 .725 .711 r
.45902 .66532 m .46258 .66665 L .46345 .66404 L F
.579 .338 .515 r
.46122 .66509 m .46099 .66519 L .45902 .66532 L F
.854 .737 .733 r
.45902 .66532 m .46094 .66963 L .46258 .66665 L F
.579 .338 .515 r
.46112 .66518 m .45869 .66618 L .45902 .66532 L F
.388 .323 .662 r
.46057 .66214 m .46122 .66509 L .45902 .66532 L F
.608 .615 .833 r
.45672 .66173 m .45888 .6661 L .46122 .66509 L F
.45888 .6661 m .45892 .6662 L .46122 .66509 L F
.579 .338 .515 r
.45806 .66784 m .46122 .66509 L .45892 .6662 L F
.46122 .66509 m .46112 .66518 L .46099 .66519 L F
.46112 .66518 m .45806 .66784 L .45869 .66618 L F
.389 .032 .234 r
.45892 .6662 m .45566 .66832 L .45675 .667 L F
.45892 .6662 m .45806 .66784 L .45566 .66832 L F
.4 .056 .262 r
.45782 .6664 m .45806 .66784 L .45566 .66832 L F
.596 .609 .835 r
.45675 .66695 m .45892 .6662 L .45881 .66597 L F
.4 .056 .262 r
.45869 .66618 m .45806 .66784 L .45782 .6664 L F
.596 .609 .835 r
.45675 .667 m .45714 .66685 L .45675 .66695 L F
.45675 .667 m .45675 .66691 L .45671 .6669 L F
.4 .056 .262 r
.45782 .6664 m .45566 .66832 L .45633 .66705 L F
.559 .457 .695 r
.45649 .66696 m .45675 .667 L .45671 .6669 L F
.334 0 .111 r
.45327 .66881 m .45675 .667 L .45576 .66716 L F
.45327 .66881 m .45566 .66832 L .45675 .667 L F
.346 0 .137 r
.45576 .66716 m .45566 .66832 L .45327 .66881 L F
.45655 .66664 m .45634 .66703 L .45576 .66716 L F
.559 .457 .695 r
.45576 .66716 m .45622 .66708 L .45634 .66703 L F
.346 0 .137 r
.45634 .66703 m .45566 .66832 L .45576 .66716 L F
.559 .457 .695 r
.45562 .66718 m .45576 .66716 L .45649 .66696 L F
.45576 .66716 m .45634 .66703 L .45649 .66696 L F
.45622 .66708 m .45675 .667 L .45649 .66696 L F
.4 .056 .262 r
.45782 .6664 m .45633 .66705 L .45634 .66703 L F
.45772 .66637 m .45634 .66703 L .45682 .66611 L F
.45782 .6664 m .45634 .66703 L .45772 .66637 L F
.596 .609 .835 r
.45675 .66687 m .45881 .66597 L .45672 .66173 L F
.346 0 .137 r
.45524 .66731 m .45569 .66721 L .45327 .66881 L F
.45531 .66726 m .45327 .66881 L .45392 .66761 L F
.334 0 .111 r
.45327 .66881 m .45576 .66716 L .45393 .66745 L F
.596 .609 .835 r
.45671 .6669 m .45672 .66173 L .45469 .66102 L F
.45675 .66691 m .45672 .66173 L .45671 .6669 L F
.346 0 .137 r
.45531 .66726 m .45392 .66761 L .45453 .66651 L F
.559 .457 .695 r
.45393 .66745 m .45562 .66718 L .45469 .66102 L F
.45562 .66718 m .45671 .6669 L .45469 .66102 L F
.631 .132 .045 r
.48856 .56686 m .48562 .56648 L .48683 .56622 L F
.568 .523 .765 r
.27183 .58481 m .27512 .58767 L .27359 .58412 L F
.328 .606 .949 r
.20313 .63919 m .19886 .6369 L .19863 .63805 L F
0 0 .121 r
.55066 .56955 m .55068 .57204 L .55097 .57013 L F
.55 .286 .469 r
.29104 .58471 m .28764 .58768 L .28677 .58421 L F
.29104 .58471 m .29009 .58753 L .28764 .58768 L F
.28764 .58768 m .29009 .58753 L .29104 .58471 L F
.455 .674 .958 r
.29426 .58429 m .29348 .58453 L .29463 .58313 L F
.406 .81 .981 r
.29368 .58437 m .29348 .58453 L .29426 .58429 L F
.29104 .58471 m .29348 .58453 L .29368 .58437 L F
.6 .561 .782 r
.29331 .58674 m .29438 .58382 L .29348 .58453 L F
.29407 .58406 m .29463 .58313 L .29348 .58453 L F
.63 .368 .502 r
.29104 .58471 m .29331 .58674 L .29348 .58453 L F
.29104 .58471 m .29009 .58753 L .29331 .58674 L F
0 0 0 r
.29326 .58458 m .29104 .58471 L .29426 .58429 L F
.29135 .58511 m .29115 .58485 L .29326 .58458 L F
.29115 .58485 m .29104 .58471 L .29326 .58458 L F
.6 .561 .782 r
.29331 .58674 m .29579 .58663 L .29503 .58434 L F
.29415 .58446 m .29503 .58434 L .29463 .58313 L F
.29331 .58674 m .29503 .58434 L .29415 .58446 L F
.786 .99 .888 r
.29135 .58511 m .29387 .5844 L .29463 .58313 L F
.29387 .5844 m .29426 .58429 L .29463 .58313 L F
.6 .561 .782 r
.29438 .58382 m .29463 .58313 L .29407 .58406 L F
0 0 0 r
.29135 .58511 m .29009 .58753 L .29104 .58471 L F
.585 .172 .225 r
.2483 .55025 m .24698 .5514 L .24454 .55098 L F
.266 0 0 r
.25052 .54985 m .24698 .5514 L .2483 .55025 L F
.097 .643 .832 r
.24435 .53569 m .2466 .53573 L .24831 .53604 L F
.185 .712 .853 r
.2466 .53573 m .25054 .53573 L .24831 .53604 L F
.45 .207 .453 r
.47253 .62052 m .47022 .62321 L .46997 .62098 L F
.541 0 0 r
.43526 .67699 m .43651 .67514 L .43799 .67818 L F
.43526 .67699 m .43594 .67809 L .43389 .67673 L F
.527 0 0 r
.43799 .67818 m .43594 .67809 L .43526 .67699 L F
0 0 0 r
.20681 .54137 m .20902 .54076 L .21099 .53965 L F
.21099 .53965 m .20902 .54076 L .21113 .53982 L F
.499 .454 .738 r
.50572 .59971 m .50749 .59581 L .50689 .59773 L F
.529 .272 .47 r
.46672 .62408 m .46699 .62693 L .46424 .62723 L F
.449 .216 .467 r
.46939 .6261 m .46672 .62408 L .47022 .62321 L F
.46939 .6261 m .46699 .62693 L .46672 .62408 L F
.645 .715 .898 r
.75957 .40758 m .76347 .40828 L .76148 .4069 L F
.728 .583 .693 r
.76117 .41089 m .76347 .40828 L .75957 .40758 L F
.761 .711 .806 r
.76148 .4069 m .76347 .40828 L .76623 .40568 L F
.388 .219 .527 r
.49512 .57496 m .49698 .57741 L .49729 .5743 L F
.126 .674 .803 r
.23157 .62663 m .23552 .62657 L .23326 .62672 L F
.474 .308 .575 r
.42173 .63864 m .41948 .63942 L .41944 .63654 L F
.42173 .63864 m .41948 .63942 L .41944 .63654 L F
.865 .685 .657 r
.56973 .57151 m .57331 .56974 L .56957 .56887 L F
.56973 .57151 m .57305 .57242 L .57331 .56974 L F
.818 .568 .56 r
.56309 .55405 m .56306 .55659 L .56677 .55684 L F
.859 .695 .677 r
.56291 .55918 m .56677 .55684 L .56306 .55659 L F
.56291 .55918 m .56511 .56019 L .56677 .55684 L F
.533 .328 .549 r
.30401 .57254 m .30616 .57449 L .30595 .57189 L F
.30401 .57254 m .30371 .57513 L .30616 .57449 L F
.061 0 .225 r
.30595 .57189 m .30371 .57513 L .30401 .57254 L F
.574 .626 .866 r
.83023 .4277 m .82855 .43121 L .82724 .42851 L F
.83023 .4277 m .83066 .43091 L .82855 .43121 L F
.463 .542 .853 r
.17003 .59019 m .16863 .59112 L .16639 .58701 L F
.566 .545 .79 r
.16863 .59112 m .1712 .59349 L .17003 .59019 L F
0 0 .337 r
.26932 .60307 m .2709 .60183 L .27066 .59881 L F
0 0 .147 r
.26932 .60307 m .27028 .60416 L .2709 .60183 L F
.26932 .60307 m .26875 .6054 L .27028 .60416 L F
.971 .851 .665 r
.55528 .5572 m .55526 .55276 L .55675 .55412 L F
.903 .842 .775 r
.55929 .54891 m .55675 .55412 L .55526 .55276 L F
.492 .904 .873 r
.21675 .53782 m .21781 .53678 L .21943 .53743 L F
.21675 .53782 m .21536 .53794 L .21781 .53678 L F
.509 .682 .944 r
.19611 .61384 m .19448 .61619 L .19405 .61504 L F
.19611 .61384 m .19786 .61564 L .19448 .61619 L F
.662 .15 0 r
.5153 .56538 m .51331 .56348 L .51449 .56342 L F
.943 .732 .589 r
.51269 .61747 m .5146 .61906 L .51424 .61641 L F
.339 .039 .302 r
.47682 .60961 m .47873 .61074 L .47917 .60887 L F
.47682 .60961 m .47645 .61146 L .47873 .61074 L F
.999 .801 .497 r
.55824 .54513 m .55755 .54124 L .55854 .54229 L F
0 0 0 r
.24976 .66556 m .24759 .667 L .25045 .66698 L F
.509 .33 .573 r
.24976 .66556 m .25432 .66494 L .25231 .66322 L F
.81 .521 .5 r
.25231 .66322 m .25432 .66494 L .2527 .66493 L F
0 0 0 r
.252 .66181 m .24976 .66556 L .25231 .66322 L F
.81 .521 .5 r
.25231 .66322 m .2527 .66493 L .24953 .6649 L F
0 0 0 r
.25268 .66066 m .252 .66181 L .25231 .66322 L F
.509 .33 .573 r
.24976 .66556 m .25045 .66698 L .25432 .66494 L F
.554 .373 .59 r
.5612 .60301 m .56388 .60301 L .56365 .59992 L F
.755 .635 .728 r
.75578 .38717 m .75794 .38395 L .75425 .38331 L F
.674 .678 .845 r
.79624 .42743 m .7922 .42618 L .79481 .42537 L F
.709 .721 .859 r
.79481 .42537 m .7985 .4261 L .79624 .42743 L F
.835 .762 .781 r
.51139 .6115 m .51275 .6161 L .51466 .61184 L F
.545 .113 .171 r
.21779 .55477 m .21616 .55654 L .21317 .55636 L F
.761 .988 .896 r
.21879 .55275 m .21779 .55477 L .2196 .5532 L F
.088 .179 .664 r
.21879 .55275 m .2194 .55643 L .21779 .55477 L F
.632 .216 .237 r
.2194 .55643 m .21616 .55654 L .21779 .55477 L F
.469 .788 .999 r
.25711 .54875 m .25766 .54719 L .25569 .54837 L F
.25711 .54875 m .25941 .54825 L .25766 .54719 L F
.459 .806 .998 r
.27909 .53633 m .28164 .53584 L .28341 .5368 L F
.602 .864 .992 r
.28341 .5368 m .28382 .53501 L .2854 .53611 L F
.28341 .5368 m .28164 .53584 L .28382 .53501 L F
.726 .693 .819 r
.5587 .54897 m .55389 .55152 L .55276 .54845 L F
.903 .842 .775 r
.55929 .54891 m .55526 .55276 L .55819 .5495 L F
.55929 .54891 m .55819 .5495 L .55857 .5491 L F
.726 .693 .819 r
.55954 .54904 m .55797 .54973 L .5587 .54897 L F
.55819 .5495 m .55389 .55152 L .5587 .54897 L F
.903 .842 .775 r
.55929 .54891 m .55854 .54911 L .55885 .54882 L F
.733 .435 .475 r
.55467 .54679 m .55925 .54901 L .55276 .54845 L F
.55925 .54901 m .55925 .54902 L .55923 .54901 L F
.55925 .54901 m .55923 .54901 L .55276 .54845 L F
.744 .864 .936 r
.55817 .54916 m .55819 .5495 L .55389 .55152 L F
.55881 .54881 m .55854 .54911 L .55817 .54916 L F
.55854 .54911 m .55819 .5495 L .55817 .54916 L F
.55819 .5495 m .55526 .55276 L .55389 .55152 L F
.726 .693 .819 r
.55797 .54973 m .55389 .55152 L .55819 .5495 L F
.903 .842 .775 r
.55857 .5491 m .55819 .5495 L .55854 .54911 L F
.55885 .54882 m .55854 .54911 L .55881 .54881 L F
.733 .435 .475 r
.55889 .54879 m .55954 .54904 L .55925 .54902 L F
.932 .86 .747 r
.55824 .54513 m .55715 .5479 L .55509 .54643 L F
.348 0 0 r
.55715 .5479 m .55954 .54904 L .55509 .54643 L F
.733 .435 .475 r
.55509 .54643 m .55898 .54871 L .55889 .54879 L F
.347 0 0 r
.55929 .54891 m .55885 .54882 L .55715 .5479 L F
.55885 .54882 m .55861 .5487 L .55715 .5479 L F
.348 0 0 r
.55715 .5479 m .55861 .5487 L .55954 .54904 L F
.733 .435 .475 r
.55895 .54883 m .55925 .54902 L .55861 .5487 L F
.347 0 0 r
.55885 .54882 m .55881 .54881 L .55861 .5487 L F
.348 0 0 r
.55861 .5487 m .55881 .54881 L .55954 .54904 L F
.733 .435 .475 r
.55509 .54643 m .55895 .54883 L .55467 .54679 L F
.55895 .54883 m .55861 .5487 L .55467 .54679 L F
.55898 .54871 m .55954 .54904 L .55889 .54879 L F
.553 .513 .765 r
.21833 .71876 m .22066 .71844 L .21986 .71542 L F
.269 0 0 r
.19257 .78296 m .1943 .78306 L .19025 .78241 L F
.19257 .78296 m .1943 .78306 L .19025 .78241 L F
.428 .835 .973 r
.1943 .78306 m .19472 .78207 L .19257 .78296 L F
.1943 .78306 m .19656 .78256 L .19472 .78207 L F
.19472 .78207 m .1943 .78306 L .19257 .78296 L F
.19472 .78207 m .19656 .78256 L .1943 .78306 L F
.019 .102 .609 r
.84065 .42822 m .84014 .42931 L .83968 .42596 L F
.724 .89 .5 r
.84065 .42822 m .83905 .43068 L .84014 .42931 L F
.452 .233 .489 r
.49428 .60263 m .49442 .60517 L .49198 .60577 L F
.472 .386 .678 r
.49617 .59933 m .49707 .6024 L .49428 .60263 L F
.319 .067 .366 r
.49707 .6024 m .49442 .60517 L .49428 .60263 L F
.34 .812 .908 r
.81857 .40435 m .81932 .40465 L .82201 .40408 L F
.6 .77 .961 r
.8282 .40355 m .83175 .40462 L .83079 .40278 L F
.756 .835 .913 r
.83079 .40278 m .83175 .40462 L .8342 .4021 L F
.755 .7 .801 r
.54726 .59981 m .5512 .60057 L .54994 .59922 L F
.627 .809 .97 r
.54994 .59922 m .5512 .60057 L .55367 .59969 L F
.171 0 0 r
.15042 .57209 m .15222 .5717 L .15405 .56962 L F
.313 0 .167 r
.15222 .5717 m .1558 .56861 L .15405 .56962 L F
.583 .581 .816 r
.33073 .5546 m .33231 .5579 L .3291 .55731 L F
.696 .519 .645 r
.3322 .55968 m .3291 .55731 L .33231 .5579 L F
.3322 .55968 m .32995 .56083 L .3291 .55731 L F
.621 .812 .973 r
.77283 .3806 m .77559 .37975 L .77443 .37829 L F
.77443 .37829 m .77559 .37975 L .77283 .3806 L F
.77443 .37829 m .77559 .37975 L .77283 .3806 L F
.821 .341 .028 r
.51775 .56718 m .51691 .56787 L .5153 .56538 L F
.692 .156 0 r
.51775 .56718 m .51978 .5691 L .51691 .56787 L F
.385 .582 .92 r
.20432 .63747 m .20328 .63897 L .20562 .63892 L F
.20328 .63897 m .20313 .63919 L .2035 .63915 L F
.20328 .63897 m .2035 .63915 L .20562 .63892 L F
.109 .534 .913 r
.19886 .6369 m .20308 .6388 L .19904 .63579 L F
.727 .819 .923 r
.2035 .63915 m .20749 .63922 L .20562 .63892 L F
.20313 .63919 m .20344 .63919 L .2035 .63915 L F
.20344 .63919 m .20749 .63922 L .2035 .63915 L F
.385 .582 .92 r
.20432 .63747 m .20443 .63941 L .20313 .63919 L F
.109 .534 .913 r
.20308 .6388 m .20363 .63905 L .20194 .63785 L F
.20308 .6388 m .20194 .63785 L .19904 .63579 L F
.20363 .63905 m .20443 .63941 L .20375 .63896 L F
.20363 .63905 m .20375 .63896 L .19904 .63579 L F
.047 .607 .801 r
.20749 .63922 m .20923 .63927 L .20562 .63892 L F
.34 0 0 r
.46813 .56923 m .46727 .56991 L .46418 .57028 L F
.525 .532 .806 r
.46933 .56608 m .46813 .56923 L .46704 .56611 L F
.46933 .56608 m .47011 .56796 L .46813 .56923 L F
.098 0 0 r
.47011 .56796 m .46727 .56991 L .46813 .56923 L F
.513 .518 .799 r
.16508 .58342 m .16423 .58726 L .16241 .58408 L F
.16508 .58342 m .16639 .58701 L .16423 .58726 L F
.794 .576 .606 r
.23976 .64256 m .23936 .64497 L .23585 .64199 L F
0 0 0 r
.23998 .64303 m .23976 .64256 L .24208 .64296 L F
.512 .84 .999 r
.24207 .64273 m .24016 .64254 L .23998 .64303 L F
.24016 .64254 m .23821 .64235 L .23998 .64303 L F
0 0 0 r
.23998 .64303 m .23936 .64497 L .23945 .64443 L F
.23998 .64303 m .23945 .64443 L .23976 .64256 L F
.315 .549 .917 r
.2785 .55864 m .27897 .55676 L .27673 .55688 L F
.2785 .55864 m .28096 .55937 L .27897 .55676 L F
0 0 0 r
.46259 .61943 m .46513 .61743 L .46302 .61834 L F
.755 .619 .708 r
.45928 .64841 m .46115 .65122 L .46322 .64867 L F
.372 .84 .835 r
.82563 .40443 m .82754 .40343 L .82483 .4042 L F
.82563 .40443 m .8282 .40355 L .82754 .40343 L F
.367 0 0 r
.80819 .40022 m .81173 .39839 L .80828 .39915 L F
.80819 .40022 m .8109 .39993 L .81173 .39839 L F
.068 0 0 r
.8109 .39993 m .81445 .39839 L .81173 .39839 L F
.549 .711 .947 r
.56022 .5989 m .56365 .59992 L .56389 .59993 L F
.555 .721 .951 r
.56365 .59992 m .5668 .59946 L .56613 .59899 L F
.56456 .59904 m .56613 .59899 L .56525 .59836 L F
.56365 .59992 m .56613 .59899 L .56456 .59904 L F
.594 .656 .881 r
.56022 .5989 m .56108 .59914 L .56141 .59544 L F
.56108 .59914 m .56389 .59993 L .56341 .59907 L F
.56108 .59914 m .56341 .59907 L .56141 .59544 L F
.555 .721 .951 r
.56365 .59992 m .56525 .59836 L .56389 .59993 L F
.489 .325 .584 r
.56365 .59992 m .56622 .60203 L .5668 .59946 L F
.56365 .59992 m .56388 .60301 L .56622 .60203 L F
.815 .803 .84 r
.54831 .57499 m .54586 .57803 L .54385 .57622 L F
.688 .591 .741 r
.3322 .55968 m .32991 .56297 L .32995 .56083 L F
.3322 .55968 m .33352 .56327 L .32991 .56297 L F
.636 .466 .636 r
.33343 .56595 m .32991 .56297 L .33352 .56327 L F
.33343 .56595 m .33146 .56672 L .32991 .56297 L F
.558 .626 .875 r
.32143 .54516 m .32101 .54903 L .31887 .54539 L F
.32143 .54516 m .32297 .54865 L .32101 .54903 L F
.764 .664 .752 r
.75339 .39 m .75578 .38717 L .75376 .38559 L F
.755 .635 .728 r
.75578 .38717 m .75425 .38331 L .75376 .38559 L F
.136 .549 .923 r
.20839 .64915 m .20612 .64865 L .20671 .64777 L F
0 .511 .828 r
.20839 .64915 m .20612 .64865 L .20431 .64785 L F
.20431 .64785 m .20612 .64865 L .20839 .64915 L F
.656 .612 .793 r
.75411 .39619 m .75675 .39308 L .75493 .3931 L F
.75411 .39619 m .757 .3956 L .75675 .39308 L F
.697 .272 .235 r
.46695 .65427 m .46896 .65681 L .47105 .65457 L F
.956 .682 .477 r
.46896 .65681 m .47123 .65748 L .47105 .65457 L F
.357 .817 .716 r
.2265 .55004 m .22592 .55047 L .22823 .54993 L F
.2265 .55004 m .22455 .55096 L .22592 .55047 L F
.745 .717 .825 r
.83468 .43099 m .83066 .43091 L .83372 .42868 L F
.826 .802 .828 r
.83372 .42868 m .83701 .4285 L .83468 .43099 L F
.764 .664 .752 r
.75339 .39 m .75376 .38559 L .75173 .38638 L F
.766 .425 .408 r
.75675 .39308 m .75339 .39 L .75493 .3931 L F
.532 .325 .545 r
.5397 .57884 m .54208 .5778 L .5396 .57687 L F
.668 .429 .55 r
.53617 .57832 m .5396 .57687 L .53596 .57711 L F
.53617 .57832 m .5397 .57884 L .5396 .57687 L F
.544 .175 .291 r
.4705 .61426 m .47431 .61238 L .47152 .61184 L F
.101 .645 .841 r
.25054 .53573 m .25272 .53577 L .25446 .53611 L F
.065 .622 .809 r
.25272 .53577 m .25667 .5361 L .25446 .53611 L F
.754 .255 0 r
.50479 .59489 m .50202 .59339 L .50216 .59566 L F
.86 .793 .784 r
.53393 .57819 m .53596 .57711 L .53324 .57499 L F
.768 .538 .585 r
.53393 .57819 m .53617 .57832 L .53596 .57711 L F
.654 .46 .609 r
.48636 .60907 m .48641 .61176 L .48395 .6117 L F
.489 .253 .483 r
.48904 .60885 m .48641 .61176 L .48636 .60907 L F
.83 .639 .644 r
.56511 .56019 m .5645 .56263 L .56806 .56333 L F
.824 .59 .584 r
.5645 .56263 m .56804 .56585 L .56806 .56333 L F
.214 .082 .475 r
.14145 .58741 m .14407 .5824 L .1411 .58483 L F
.452 .181 .411 r
.29113 .63054 m .29052 .63279 L .28822 .63329 L F
.464 .192 .416 r
.29286 .63229 m .29113 .63054 L .29314 .62978 L F
.29286 .63229 m .29052 .63279 L .29113 .63054 L F
.688 .195 .072 r
.46186 .63015 m .45798 .62922 L .45934 .63105 L F
.613 .603 .817 r
.24459 .68936 m .24364 .69124 L .24258 .68804 L F
.077 0 0 r
.24454 .6924 m .24364 .69124 L .24459 .68936 L F
.24454 .6924 m .24242 .69348 L .24364 .69124 L F
.375 .139 .422 r
.29519 .62913 m .29357 .62745 L .29567 .62695 L F
.29519 .62913 m .29314 .62978 L .29357 .62745 L F
.972 .828 .414 r
.24697 .67819 m .25017 .67606 L .24856 .67606 L F
.336 .777 .963 r
.25107 .67516 m .25017 .67606 L .24856 .67606 L F
.25107 .67516 m .25281 .67586 L .25017 .67606 L F
.25107 .67516 m .25017 .67606 L .24856 .67606 L F
.25107 .67516 m .25281 .67586 L .25017 .67606 L F
0 0 0 r
.17578 .55383 m .17597 .55479 L .1779 .55277 L F
.17578 .55383 m .17402 .55566 L .17597 .55479 L F
.926 .801 .704 r
.75675 .39308 m .757 .3956 L .75827 .39207 L F
.388 .458 .811 r
.45568 .62904 m .45674 .62623 L .45536 .62876 L F
.45568 .62904 m .45798 .62922 L .45674 .62623 L F
.637 .651 .848 r
.75957 .40758 m .76098 .40312 L .75901 .40461 L F
.75957 .40758 m .76148 .4069 L .76098 .40312 L F
.663 .385 .49 r
.20552 .55728 m .20475 .55996 L .20217 .5597 L F
0 0 .187 r
.2062 .55843 m .20552 .55728 L .20677 .55626 L F
.2062 .55843 m .20475 .55996 L .20552 .55728 L F
.488 .174 .36 r
.47338 .63711 m .47561 .63834 L .47661 .6366 L F
.797 .721 .781 r
.17003 .59019 m .16756 .59317 L .1712 .59349 L F
.307 0 0 r
.16756 .59317 m .16918 .59359 L .1712 .59349 L F
.757 .702 .799 r
.17003 .59019 m .1712 .59349 L .17399 .59053 L F
.17399 .59053 m .1712 .59349 L .17003 .59019 L F
.657 .808 .956 r
.17297 .58945 m .17003 .59019 L .17399 .59053 L F
.644 .177 .13 r
.17274 .59078 m .17297 .58945 L .17003 .59019 L F
.259 .391 .807 r
.17101 .5904 m .1712 .59349 L .17274 .59078 L F
.1702 .59068 m .1712 .59349 L .17101 .5904 L F
.88 .988 .814 r
.16872 .59026 m .16756 .59317 L .16883 .59163 L F
.16878 .59026 m .16883 .59163 L .17003 .59019 L F
.16872 .59026 m .16883 .59163 L .16878 .59026 L F
.463 .542 .853 r
.17003 .59019 m .16639 .58701 L .16811 .58907 L F
0 .129 .676 r
.16839 .58759 m .16871 .58829 L .16811 .58907 L F
.641 .599 .792 r
.17096 .59055 m .16913 .59136 L .16872 .59026 L F
.16913 .59136 m .16888 .59146 L .16872 .59026 L F
.941 .587 .313 r
.16811 .58907 m .16872 .59026 L .17003 .59019 L F
0 .162 .687 r
.16811 .58907 m .16837 .58934 L .16872 .59026 L F
.641 .599 .792 r
.17274 .59078 m .16888 .59146 L .17096 .59055 L F
.484 0 0 r
.16872 .59026 m .17002 .59114 L .17274 .59078 L F
0 .162 .687 r
.16837 .58934 m .17002 .59114 L .16872 .59026 L F
0 .129 .676 r
.16871 .58829 m .17002 .59114 L .16876 .58977 L F
.16871 .58829 m .16876 .58977 L .16811 .58907 L F
.641 .599 .792 r
.17274 .59078 m .16918 .59359 L .16888 .59146 L F
.644 .177 .13 r
.17274 .59078 m .17002 .59114 L .17297 .58945 L F
0 0 0 r
.17232 .58996 m .17002 .59114 L .17237 .58994 L F
.17174 .59016 m .17131 .5904 L .17232 .58996 L F
.17131 .5904 m .17002 .59114 L .17232 .58996 L F
.17297 .58945 m .17174 .59016 L .17319 .58953 L F
.17174 .59016 m .17237 .58994 L .17319 .58953 L F
.259 .391 .807 r
.17003 .59019 m .1702 .59068 L .17101 .5904 L F
.731 .981 .912 r
.1712 .59349 m .16918 .59359 L .17274 .59078 L F
.505 .649 .922 r
.17792 .62439 m .18265 .62721 L .18 .62402 L F
.352 .536 .896 r
.18265 .62721 m .18181 .62373 L .18 .62402 L F
.18265 .62721 m .18389 .62661 L .18181 .62373 L F
.726 .386 .403 r
.55998 .51645 m .56356 .51474 L .55991 .51416 L F
.55998 .51645 m .56378 .51671 L .56356 .51474 L F
.627 .451 .625 r
.18236 .5696 m .18272 .57235 L .18067 .57155 L F
.231 0 .263 r
.18446 .56852 m .18236 .5696 L .18581 .56614 L F
0 0 0 r
.18446 .56852 m .18272 .57235 L .18236 .5696 L F
.852 .715 .711 r
.76675 .40078 m .76781 .40439 L .76867 .4021 L F
.625 .417 .58 r
.7608 .41394 m .76384 .41341 L .76117 .41089 L F
.253 0 .01 r
.18532 .54966 m .18928 .54693 L .18726 .54809 L F
.763 .883 .932 r
.83631 .42729 m .83701 .4285 L .83372 .42868 L F
.836 .926 .891 r
.83968 .42453 m .83701 .4285 L .83631 .42729 L F
.83968 .42453 m .83968 .42596 L .83701 .4285 L F
0 0 0 r
.25828 .55392 m .25927 .55285 L .26075 .55124 L F
.519 .816 .482 r
.25828 .55392 m .25662 .55571 L .25927 .55285 L F
.51 .259 .47 r
.49198 .60577 m .49161 .60867 L .48904 .60885 L F
.423 .185 .447 r
.49397 .60794 m .49198 .60577 L .49442 .60517 L F
.49397 .60794 m .49161 .60867 L .49198 .60577 L F
.508 .358 .612 r
.32077 .59644 m .31835 .59952 L .31822 .59704 L F
.527 .714 .958 r
.80848 .42729 m .80473 .426 L .80738 .42545 L F
.615 .738 .934 r
.81113 .42638 m .80848 .42729 L .80738 .42545 L F
.848 .705 .705 r
.82478 .42229 m .82333 .42546 L .82211 .42166 L F
.563 .122 .161 r
.24597 .64242 m .24326 .64447 L .24208 .64296 L F
0 0 0 r
.24618 .64227 m .24597 .64242 L .24808 .64268 L F
.24618 .64227 m .24326 .64447 L .24597 .64242 L F
.302 .771 .938 r
.23213 .55011 m .23044 .54967 L .22823 .54993 L F
.191 .707 .886 r
.23444 .54992 m .23044 .54967 L .23213 .55011 L F
.565 .78 .98 r
.21574 .62308 m .21323 .62367 L .2115 .62227 L F
.402 .514 .857 r
.77669 .42795 m .77699 .42972 L .77868 .42766 L F
.37 .466 .828 r
.77699 .42972 m .77999 .43122 L .77868 .42766 L F
.634 .315 .413 r
.55026 .51177 m .55384 .51319 L .55373 .51154 L F
.717 .338 .33 r
.55384 .51319 m .55612 .51383 L .55373 .51154 L F
.837 .63 .624 r
.5673 .51734 m .56701 .52032 L .56913 .52068 L F
.847 .607 .574 r
.56725 .52239 m .56913 .52068 L .56701 .52032 L F
.56725 .52239 m .56912 .52335 L .56913 .52068 L F
.729 .612 .727 r
.33591 .56028 m .33352 .56327 L .3322 .55968 L F
.672 .529 .682 r
.33629 .5631 m .33352 .56327 L .33591 .56028 L F
.695 .456 .557 r
.33624 .56571 m .33352 .56327 L .33629 .5631 L F
.33624 .56571 m .33343 .56595 L .33352 .56327 L F
.404 .627 .944 r
.79019 .4215 m .78837 .42318 L .78779 .42156 L F
.401 .621 .941 r
.79114 .42312 m .78837 .42318 L .79019 .4215 L F
.455 .555 .868 r
.7922 .42618 m .78837 .42318 L .79114 .42312 L F
.204 .577 .941 r
.22537 .6266 m .22354 .6264 L .22166 .62477 L F
.673 .821 .955 r
.23172 .64191 m .2337 .64307 L .23585 .64199 L F
.612 .303 .423 r
.4531 .65075 m .4578 .64784 L .4533 .64892 L F
.761 .711 .806 r
.76148 .4069 m .76623 .40568 L .76451 .40385 L F
.749 .707 .812 r
.76623 .40568 m .76781 .40439 L .76451 .40385 L F
.539 .799 .993 r
.29379 .53767 m .29317 .53952 L .29145 .5382 L F
.29379 .53767 m .29541 .53891 L .29317 .53952 L F
.114 0 0 r
.18067 .57155 m .17829 .57439 L .17653 .57502 L F
.08 0 0 r
.18272 .57235 m .17829 .57439 L .18067 .57155 L F
.754 .75 .849 r
.79501 .44075 m .79854 .44121 L .79791 .43818 L F
.765 .757 .845 r
.79791 .43818 m .79854 .44121 L .8011 .43855 L F
.013 0 0 r
.19585 .56242 m .19179 .56418 L .19364 .56307 L F
.353 .474 .843 r
.25941 .54825 m .26075 .55124 L .26208 .54924 L F
0 0 0 r
.26075 .55124 m .26093 .55181 L .26208 .54924 L F
.26075 .55124 m .25927 .55285 L .26093 .55181 L F
.867 .93 .864 r
.81894 .44506 m .82054 .44115 L .81791 .44376 L F
.81894 .44506 m .82057 .44337 L .82054 .44115 L F
.713 .653 .789 r
.33442 .5568 m .33591 .56028 L .3322 .55968 L F
.644 .618 .809 r
.33844 .55982 m .33591 .56028 L .33442 .5568 L F
.553 .444 .684 r
.33865 .56252 m .33591 .56028 L .33844 .55982 L F
.33865 .56252 m .33629 .5631 L .33591 .56028 L F
.429 .662 .958 r
.20566 .61811 m .2023 .61658 L .2041 .6165 L F
.229 .572 .941 r
.2041 .6165 m .20605 .61683 L .20566 .61811 L F
.233 .577 .943 r
.20605 .61683 m .20771 .61842 L .20566 .61811 L F
.482 .104 .245 r
.27289 .64159 m .27344 .63997 L .27694 .63888 L F
.736 .66 .776 r
.76337 .39796 m .76569 .39473 L .76378 .39592 L F
.695 .712 .862 r
.8342 .4021 m .83815 .40386 L .83692 .40133 L F
.625 .757 .941 r
.83815 .40386 m .84001 .40084 L .83692 .40133 L F
.83815 .40386 m .84076 .40295 L .84001 .40084 L F
.655 .916 .978 r
.50936 .61303 m .50799 .613 L .51139 .6115 L F
.645 .597 .786 r
.47548 .63359 m .47885 .63511 L .47777 .63368 L F
.846 .785 .792 r
.50858 .55228 m .5126 .55167 L .51135 .54991 L F
.50858 .55228 m .51052 .55424 L .5126 .55167 L F
.875 .869 .829 r
.51135 .54991 m .5126 .55167 L .51301 .55051 L F
.754 .255 0 r
.50479 .59489 m .50272 .59327 L .50202 .59339 L F
.50479 .59489 m .50371 .59474 L .50272 .59327 L F
.54 .333 .548 r
.30155 .62112 m .30139 .62358 L .2991 .62392 L F
.504 .308 .548 r
.30403 .61808 m .30386 .62062 L .30155 .62112 L F
.498 .296 .536 r
.30386 .62062 m .30139 .62358 L .30155 .62112 L F
.466 .611 .91 r
.18755 .62996 m .19014 .63318 L .19177 .6326 L F
.699 .67 .818 r
.19135 .63503 m .19177 .6326 L .19014 .63318 L F
.861 .588 .523 r
.56974 .57405 m .57305 .57242 L .56973 .57151 L F
.56974 .57405 m .57319 .57493 L .57305 .57242 L F
.034 .245 .746 r
.50147 .59056 m .50221 .58907 L .4999 .58696 L F
.657 .292 0 r
.50147 .59056 m .50191 .5916 L .50221 .58907 L F
.049 .063 .552 r
.50202 .59339 m .50272 .59327 L .50147 .59056 L F
.657 .292 0 r
.50147 .59056 m .50272 .59327 L .50191 .5916 L F
.899 .512 .074 r
.1659 .72746 m .16597 .72766 L .16611 .72778 L F
.858 .948 .873 r
.16611 .72778 m .16597 .72766 L .16587 .72776 L F
.855 .573 .509 r
.57496 .58342 m .57792 .58161 L .57543 .58082 L F
.57496 .58342 m .57803 .58396 L .57792 .58161 L F
.781 .91 .929 r
.82057 .44337 m .82282 .43978 L .82054 .44115 L F
.82057 .44337 m .82375 .44094 L .82282 .43978 L F
.648 .803 .958 r
.55581 .59843 m .56022 .5989 L .55885 .59656 L F
.594 .656 .881 r
.56022 .5989 m .56141 .59544 L .55885 .59656 L F
0 .253 .764 r
.49238 .54981 m .49028 .54711 L .49133 .54873 L F
.638 .152 .083 r
.49553 .55147 m .4979 .55333 L .49427 .55293 L F
.637 .091 0 r
.49961 .55326 m .4979 .55333 L .49553 .55147 L F
.221 0 0 r
.23064 .7062 m .23065 .7055 L .22803 .70633 L F
.957 .721 .54 r
.22803 .70633 m .23065 .7055 L .23064 .7062 L F
.769 .259 0 r
.49304 .54611 m .49582 .54769 L .49421 .54554 L F
.073 0 .185 r
.27813 .57439 m .27986 .57417 L .2805 .57252 L F
.195 0 .202 r
.27813 .57439 m .27925 .57638 L .27986 .57417 L F
.27813 .57439 m .27734 .57738 L .27925 .57638 L F
.883 .837 .796 r
.56262 .54386 m .56656 .54167 L .56549 .5398 L F
.56262 .54386 m .56424 .54485 L .56656 .54167 L F
.914 .831 .749 r
.56549 .5398 m .56656 .54167 L .56737 .53946 L F
.487 .283 .528 r
.31153 .60892 m .31134 .61157 L .30905 .61207 L F
.592 .498 .716 r
.31134 .61157 m .3095 .61498 L .30905 .61207 L F
.076 0 0 r
.19378 .77247 m .1985 .77117 L .19565 .77244 L F
.922 .615 .443 r
.1985 .77117 m .19596 .76971 L .19565 .77244 L F
.544 .175 .291 r
.4705 .61426 m .47352 .61416 L .47431 .61238 L F
.52 .248 .442 r
.47352 .61416 m .47645 .61146 L .47431 .61238 L F
.31 0 .26 r
.27169 .55571 m .27316 .55586 L .27407 .55426 L F
.967 .87 .475 r
.57741 .58634 m .5772 .59054 L .57896 .58735 L F
.088 .355 .824 r
.79215 .40185 m .79228 .40033 L .78934 .39866 L F
0 0 .273 r
.79215 .40185 m .79259 .40283 L .79228 .40033 L F
0 0 .311 r
.79284 .40417 m .79359 .4064 L .79259 .40283 L F
0 0 .273 r
.79238 .40261 m .79284 .40417 L .79259 .40283 L F
.981 .747 .508 r
.79359 .4064 m .79222 .40543 L .79259 .40283 L F
.988 .8 .409 r
.79259 .40283 m .79231 .40478 L .7915 .40365 L F
.79231 .40478 m .79222 .40543 L .7915 .40365 L F
.443 .774 .997 r
.79054 .4026 m .79079 .40265 L .7915 .40365 L F
.264 0 0 r
.7915 .40365 m .79281 .40305 L .79259 .40283 L F
.7915 .40365 m .79411 .40335 L .79497 .40207 L F
.443 .774 .997 r
.79079 .40265 m .79411 .40335 L .7915 .40365 L F
.264 0 0 r
.79281 .40305 m .79497 .40207 L .79259 .40283 L F
0 0 .273 r
.79215 .40185 m .79238 .40261 L .79259 .40283 L F
.816 .609 .622 r
.5105 .60793 m .51314 .60576 L .51268 .60468 L F
.5105 .60793 m .5127 .60876 L .51314 .60576 L F
.892 .684 .169 r
.51262 .6021 m .51268 .60468 L .51314 .60576 L F
.532 .354 .584 r
.31388 .6058 m .3139 .60845 L .31153 .60892 L F
.496 .282 .517 r
.3139 .60845 m .31134 .61157 L .31153 .60892 L F
.621 .487 .677 r
.43478 .66883 m .43705 .67284 L .43842 .66945 L F
.914 .831 .749 r
.56549 .5398 m .56737 .53946 L .56632 .53814 L F
.89 .48 .221 r
.76907 .39526 m .76789 .39358 L .76569 .39473 L F
.35 .356 .725 r
.49599 .5815 m .49799 .58124 L .49698 .57741 L F
.892 .627 .531 r
.45928 .64841 m .4591 .65096 L .46115 .65122 L F
.877 .561 .447 r
.4591 .65096 m .45935 .65328 L .46115 .65122 L F
.883 .57 .452 r
.46115 .65122 m .45935 .65328 L .4608 .6533 L F
.329 .096 .401 r
.19118 .82829 m .18961 .83111 L .18869 .83136 L F
.303 .036 .332 r
.18869 .83136 m .18961 .83111 L .18844 .83219 L F
.484 .457 .752 r
.25205 .64342 m .25271 .64536 L .25448 .6448 L F
.635 .58 .775 r
.25336 .64856 m .25448 .6448 L .25271 .64536 L F
.862 .729 .714 r
.56877 .52594 m .57011 .52948 L .57069 .52722 L F
.232 .446 .863 r
.30392 .54011 m .30321 .54188 L .30133 .53883 L F
.512 .771 .99 r
.30392 .54011 m .30548 .54144 L .30321 .54188 L F
.482 .104 .245 r
.27289 .64159 m .27694 .63888 L .27504 .64108 L F
.58 .21 .305 r
.27933 .63866 m .27504 .64108 L .27694 .63888 L F
.675 .77 .29 r
.54159 .58443 m .54216 .58294 L .54296 .58109 L F
.958 .945 .702 r
.54137 .58722 m .54216 .58294 L .54159 .58443 L F
.706 .762 .895 r
.17895 .60357 m .18118 .60533 L .17645 .6051 L F
.754 .646 .741 r
.18118 .60533 m .17808 .60874 L .17645 .6051 L F
.237 .586 .946 r
.18101 .6039 m .18118 .60533 L .17895 .60357 L F
0 0 .41 r
.18101 .6039 m .18238 .60776 L .18118 .60533 L F
.451 .206 .45 r
.18118 .60533 m .18238 .60776 L .18018 .60829 L F
.544 .258 .432 r
.30139 .62358 m .29808 .62649 L .2991 .62392 L F
.925 .705 .216 r
.24705 .68094 m .24742 .67903 L .24697 .67819 L F
.24705 .68094 m .24754 .68175 L .24742 .67903 L F
.61 .541 .752 r
.45072 .66741 m .45393 .66745 L .45222 .66283 L F
.54 .159 .268 r
.45072 .66741 m .45327 .66881 L .45393 .66745 L F
.467 .283 .547 r
.78934 .39866 m .79228 .40033 L .79239 .39777 L F
.521 .387 .638 r
.25481 .65461 m .25706 .65412 L .25682 .65147 L F
.25481 .65461 m .25706 .65412 L .25682 .65147 L F
.34 .667 .975 r
.31402 .54302 m .31344 .54438 L .31306 .54328 L F
.31402 .54302 m .31542 .54436 L .31344 .54438 L F
.392 0 .144 r
.20217 .5597 m .19834 .5617 L .19948 .56066 L F
.852 .676 .663 r
.5127 .60876 m .51139 .6115 L .51466 .61184 L F
.297 .51 .893 r
.28372 .56947 m .27971 .56617 L .28126 .56909 L F
.348 .115 .412 r
.28126 .56909 m .28253 .57129 L .28372 .56947 L F
.28126 .56909 m .2805 .57252 L .28253 .57129 L F
.537 .271 .46 r
.28822 .63329 m .28796 .63533 L .28578 .63537 L F
.502 .26 .48 r
.29052 .63279 m .28796 .63533 L .28822 .63329 L F
.499 .304 .546 r
.30615 .6201 m .30403 .61808 L .30648 .61761 L F
.30615 .6201 m .30386 .62062 L .30403 .61808 L F
.61 .683 .894 r
.84242 .41322 m .84082 .41664 L .83989 .41396 L F
.84242 .41322 m .84406 .41571 L .84082 .41664 L F
.184 0 .301 r
.26497 .61214 m .2658 .61347 L .26647 .61121 L F
.26497 .61214 m .26425 .61452 L .2658 .61347 L F
.636 .653 .849 r
.79379 .42198 m .7922 .42618 L .79114 .42312 L F
.79379 .42198 m .79481 .42537 L .7922 .42618 L F
.463 .1 .262 r
.28396 .63598 m .28166 .63847 L .27933 .63866 L F
.568 .253 .394 r
.28578 .63537 m .28166 .63847 L .28396 .63598 L F
.888 .68 .615 r
.56402 .51922 m .5673 .51734 L .56378 .51671 L F
.56402 .51922 m .56701 .52032 L .5673 .51734 L F
.845 .644 .63 r
.56133 .55268 m .56306 .55659 L .56309 .55405 L F
.725 .816 .921 r
.21924 .64156 m .2238 .64164 L .22166 .64114 L F
.206 .709 .906 r
.22166 .64114 m .2238 .64164 L .22576 .64154 L F
.689 .771 .914 r
.2336 .69395 m .23593 .69596 L .23357 .69381 L F
.699 .782 .916 r
.23593 .69596 m .23501 .69332 L .23357 .69381 L F
.735 .686 .803 r
.28237 .59654 m .2799 .59915 L .28023 .5967 L F
0 0 .073 r
.2806 .59768 m .28023 .5967 L .28237 .59654 L F
.2806 .59768 m .2799 .59915 L .28023 .5967 L F
.301 .769 .94 r
.25667 .5361 m .25892 .53585 L .26066 .53628 L F
.175 .705 .848 r
.25892 .53585 m .26292 .53585 L .26066 .53628 L F
.484 .457 .752 r
.25205 .64342 m .25448 .6448 L .25432 .64318 L F
.028 0 0 r
.25205 .64342 m .25432 .64318 L .25394 .64335 L F
.25205 .64342 m .25394 .64335 L .25119 .6427 L F
.65 .457 .61 r
.1882 .83117 m .19118 .82829 L .18796 .82829 L F
.216 0 0 r
.18928 .54693 m .19171 .54637 L .18956 .54632 L F
.751 .374 0 r
.52425 .57496 m .52478 .57687 L .52292 .57397 L F
.52425 .57496 m .52558 .57818 L .52478 .57687 L F
.595 .281 .406 r
.54738 .5137 m .55002 .51376 L .55026 .51177 L F
.634 .315 .413 r
.55026 .51177 m .55002 .51376 L .55384 .51319 L F
.481 .448 .744 r
.14582 .6047 m .14683 .6027 L .14369 .60236 L F
.14582 .6047 m .14772 .60484 L .14683 .6027 L F
.022 0 0 r
.26425 .61452 m .26221 .61547 L .26106 .61681 L F
.274 .278 .682 r
.45447 .62392 m .45536 .62876 L .45674 .62623 L F
.436 .167 .406 r
.48409 .63002 m .48641 .6295 L .48675 .62722 L F
.48409 .63002 m .48641 .6295 L .48675 .62722 L F
.362 .105 .384 r
.48675 .62722 m .48886 .62865 L .48943 .62751 L F
.48675 .62722 m .48641 .6295 L .48886 .62865 L F
.48675 .62722 m .48886 .62865 L .48943 .62751 L F
.48675 .62722 m .48641 .6295 L .48886 .62865 L F
.551 .902 .973 r
.83575 .39432 m .83298 .39527 L .83484 .3937 L F
.556 .933 .89 r
.83484 .3937 m .83298 .39527 L .83247 .39496 L F
.428 .202 .467 r
.3185 .6021 m .31602 .6051 L .31643 .60275 L F
.767 .671 .757 r
.76451 .40385 m .76781 .40439 L .76675 .40078 L F
.327 .159 .494 r
.51085 .61881 m .51094 .62075 L .51269 .61747 L F
.613 .531 .738 r
.33093 .56906 m .32874 .57207 L .32841 .56977 L F
.593 .504 .723 r
.33097 .57159 m .32874 .57207 L .33093 .56906 L F
.62 .477 .665 r
.33226 .57515 m .32874 .57207 L .33097 .57159 L F
.33226 .57515 m .32989 .57553 L .32874 .57207 L F
.716 .333 .323 r
.55055 .52302 m .54882 .52514 L .54664 .52276 L F
.711 .327 .319 r
.55282 .52544 m .55055 .52302 L .55196 .52365 L F
.55282 .52544 m .54882 .52514 L .55055 .52302 L F
.858 .447 0 r
.51025 .55531 m .51052 .55424 L .50858 .55228 L F
.51025 .55531 m .51164 .55688 L .51052 .55424 L F
.004 0 0 r
.16815 .58065 m .16658 .58294 L .16508 .58342 L F
0 0 0 r
.17054 .57777 m .16907 .57973 L .16815 .58065 L F
.16907 .57973 m .16658 .58294 L .16815 .58065 L F
.661 .512 .671 r
.48458 .56416 m .48785 .56388 L .48356 .56323 L F
.712 .414 .47 r
.16583 .72766 m .16597 .72766 L .1659 .72746 L F
.914 .745 .659 r
.56877 .52594 m .56882 .52928 L .57011 .52948 L F
.955 .837 .687 r
.56755 .53058 m .57011 .52948 L .56882 .52928 L F
.56755 .53058 m .56868 .53274 L .57011 .52948 L F
.444 .694 .972 r
.5408 .60063 m .53974 .59896 L .53744 .59909 L F
.353 .598 .939 r
.54147 .59983 m .53974 .59896 L .5408 .60063 L F
.305 0 0 r
.47788 .61527 m .47624 .61647 L .47366 .61661 L F
.762 .959 .654 r
.47866 .61336 m .47788 .61527 L .48044 .61482 L F
.47866 .61336 m .47624 .61647 L .47788 .61527 L F
.984 .726 .458 r
.47624 .61647 m .47691 .61875 L .47788 .61527 L F
.775 .305 0 r
.51106 .56006 m .51187 .56227 L .50947 .56032 L F
.51106 .56006 m .51331 .56348 L .51187 .56227 L F
.58 .574 .811 r
.53022 .52054 m .53393 .52275 L .53259 .51999 L F
.772 .612 .68 r
.53497 .58183 m .53617 .57832 L .53393 .57819 L F
.666 .495 .644 r
.53497 .58183 m .5397 .57884 L .53617 .57832 L F
.735 .686 .803 r
.28237 .59654 m .28402 .59972 L .2799 .59915 L F
.651 .424 .562 r
.28095 .60222 m .28402 .59972 L .2799 .59915 L F
.28095 .60222 m .28384 .60228 L .28402 .59972 L F
0 .165 .703 r
.28402 .59972 m .28426 .59831 L .28237 .59654 L F
0 0 .293 r
.28402 .59972 m .28503 .60081 L .28426 .59831 L F
.28402 .59972 m .28384 .60228 L .28503 .60081 L F
.868 .968 .857 r
.57359 .59273 m .5772 .59054 L .57662 .58998 L F
.57359 .59273 m .57339 .59433 L .5772 .59054 L F
.967 .87 .475 r
.57741 .58634 m .57662 .58998 L .5772 .59054 L F
.083 .134 .618 r
.27545 .5931 m .27714 .59271 L .27636 .59098 L F
0 0 .047 r
.27545 .5931 m .27484 .59539 L .27714 .59271 L F
.721 .293 0 r
.52686 .56842 m .52886 .57156 L .52786 .56976 L F
.635 .58 .775 r
.25336 .64856 m .25595 .64767 L .25448 .6448 L F
0 .219 .712 r
.25336 .64856 m .25682 .65147 L .25595 .64767 L F
0 0 0 r
.26106 .61681 m .25962 .61832 L .25823 .61985 L F
.466 .306 .579 r
.31602 .6051 m .3139 .60845 L .31388 .6058 L F
.67 .869 .975 r
.42507 .66367 m .42296 .66436 L .42302 .66266 L F
.452 .32 .609 r
.42456 .66611 m .42296 .66436 L .42507 .66367 L F
.42296 .66436 m .42456 .66611 L .42302 .66266 L F
.42296 .66436 m .42254 .6671 L .42456 .66611 L F
.42456 .66611 m .42254 .6671 L .42296 .66436 L F
.541 .696 .94 r
.82989 .4174 m .82974 .41986 L .82851 .41733 L F
.82989 .4174 m .83127 .41886 L .82974 .41986 L F
.404 .218 .512 r
.32617 .58995 m .32361 .59335 L .32344 .59077 L F
.465 .654 .942 r
.16566 .61395 m .16659 .61544 L .16753 .61354 L F
.315 .469 .854 r
.16659 .61544 m .16949 .61691 L .16753 .61354 L F
.181 .387 .83 r
.20987 .61963 m .20921 .62134 L .20771 .61842 L F
.244 .464 .873 r
.20987 .61963 m .2115 .62227 L .20921 .62134 L F
.53 .226 .396 r
.28764 .58768 m .28965 .58944 L .29009 .58753 L F
.28764 .58768 m .28965 .58944 L .29009 .58753 L F
.596 .445 .647 r
.33865 .56252 m .33624 .56571 L .33629 .5631 L F
.475 .328 .6 r
.45447 .62392 m .45659 .62349 L .45651 .62077 L F
.274 .278 .682 r
.45447 .62392 m .45674 .62623 L .45659 .62349 L F
.378 .042 .265 r
.48395 .6117 m .48289 .61415 L .48044 .61482 L F
.135 0 .144 r
.48481 .6131 m .48395 .6117 L .48641 .61176 L F
.48481 .6131 m .48289 .61415 L .48395 .6117 L F
.607 .602 .82 r
.816 .42456 m .81479 .42811 L .81372 .4253 L F
.816 .42456 m .81715 .42737 L .81479 .42811 L F
.506 0 0 r
.24393 .62539 m .24625 .62594 L .24817 .62483 L F
0 0 0 r
.24625 .62594 m .25014 .62521 L .24817 .62483 L F
.542 .629 .888 r
.56141 .59544 m .56389 .59993 L .56525 .59836 L F
.721 .629 .754 r
.27763 .58472 m .27512 .58767 L .27743 .58691 L F
.414 .228 .517 r
.27743 .58691 m .28004 .58341 L .27763 .58472 L F
.27743 .58691 m .28076 .58768 L .28004 .58341 L F
.418 .158 .41 r
.27743 .58691 m .27942 .589 L .28076 .58768 L F
.27743 .58691 m .27636 .59098 L .27942 .589 L F
.743 .664 .773 r
.27359 .58412 m .27512 .58767 L .27763 .58472 L F
.809 .89 .902 r
.82903 .43744 m .83003 .43871 L .83195 .43716 L F
.515 .309 .538 r
.82968 .42546 m .82724 .42851 L .82717 .42603 L F
.932 .86 .747 r
.55824 .54513 m .55509 .54643 L .5572 .5442 L F
.999 .801 .497 r
.55824 .54513 m .5572 .5442 L .55755 .54124 L F
.782 .589 .64 r
.57634 .57785 m .57685 .57548 L .57319 .57493 L F
.99 .788 .538 r
.51094 .62075 m .51033 .62319 L .51168 .62411 L F
.663 .641 .818 r
.46058 .65652 m .46441 .65404 L .4608 .6533 L F
.46058 .65652 m .46432 .6572 L .46441 .65404 L F
0 0 0 r
.46432 .6572 m .46695 .65427 L .46441 .65404 L F
.238 0 0 r
.22161 .53746 m .22379 .5375 L .22554 .53674 L F
0 0 0 r
.22379 .5375 m .22751 .53673 L .22554 .53674 L F
.34 .575 .928 r
.80474 .44145 m .80871 .44399 L .80772 .44237 L F
.608 .752 .947 r
.80871 .44399 m .81084 .4416 L .80772 .44237 L F
.80871 .44399 m .8115 .44326 L .81084 .4416 L F
.151 .683 .859 r
.27421 .55027 m .27167 .54995 L .27117 .5501 L F
0 0 .455 r
.27421 .55027 m .27385 .54939 L .27167 .54995 L F
.775 .674 .751 r
.44462 .65392 m .44583 .65759 L .442 .65713 L F
.653 .171 .096 r
.44583 .65759 m .44392 .65899 L .442 .65713 L F
.165 .288 .745 r
.447 .65615 m .44583 .65759 L .44462 .65392 L F
.604 .907 .635 r
.447 .65615 m .44392 .65899 L .44583 .65759 L F
0 0 0 r
.16694 .55954 m .16851 .55912 L .16992 .55716 L F
.012 0 0 r
.16992 .55716 m .17031 .55821 L .17203 .5565 L F
.16992 .55716 m .16851 .55912 L .17031 .55821 L F
0 0 0 r
.19171 .54637 m .19367 .54533 L .19545 .54367 L F
.19545 .54367 m .19648 .54343 L .19842 .54278 L F
.19545 .54367 m .19367 .54533 L .19648 .54343 L F
.507 .448 .725 r
.26819 .64794 m .26605 .64864 L .26607 .6457 L F
.538 .816 .997 r
.26412 .64752 m .26605 .64864 L .26819 .64794 L F
.686 .739 .891 r
.79728 .42426 m .7985 .4261 L .79481 .42537 L F
.748 .762 .864 r
.80082 .42463 m .7985 .4261 L .79728 .42426 L F
.671 .59 .757 r
.33442 .5568 m .3322 .55968 L .33231 .5579 L F
.535 .356 .585 r
.49023 .60268 m .49238 .59896 L .49078 .59985 L F
.699 .67 .818 r
.19135 .63503 m .19497 .63576 L .19177 .6326 L F
.363 .565 .914 r
.19177 .6326 m .19497 .63576 L .19604 .63519 L F
.475 .824 .997 r
.18469 .79662 m .1844 .79791 L .18653 .7974 L F
.18469 .79662 m .1844 .79791 L .18653 .7974 L F
.65 .457 .61 r
.1882 .83117 m .18961 .83111 L .19118 .82829 L F
.985 .802 .404 r
.50213 .57811 m .50181 .58022 L .50251 .58108 L F
0 0 .531 r
.50393 .58245 m .50251 .58108 L .50181 .58022 L F
.827 .431 .299 r
.50251 .58108 m .50435 .58398 L .50643 .58435 L F
0 0 .531 r
.50393 .58245 m .50435 .58398 L .50251 .58108 L F
.672 .853 .969 r
.24094 .68705 m .24009 .68895 L .23793 .68964 L F
.24094 .68705 m .24258 .68804 L .24009 .68895 L F
.936 .716 .58 r
.56246 .54596 m .56424 .54485 L .56262 .54386 L F
.56246 .54596 m .56405 .54738 L .56424 .54485 L F
.612 .303 .423 r
.4531 .65075 m .45569 .65074 L .4578 .64784 L F
.756 .488 .527 r
.4578 .64784 m .4591 .65096 L .45928 .64841 L F
.4578 .64784 m .45569 .65074 L .4591 .65096 L F
.252 0 0 r
.25014 .62521 m .25238 .62483 L .25405 .62318 L F
0 0 .043 r
.25405 .62318 m .25518 .62334 L .25643 .62073 L F
.019 0 0 r
.25449 .62436 m .25405 .62318 L .25238 .62483 L F
.25449 .62436 m .25518 .62334 L .25405 .62318 L F
.731 .65 .769 r
.16587 .72776 m .16597 .72766 L .16583 .72766 L F
.429 .658 .956 r
.78665 .41907 m .78423 .42119 L .78353 .41975 L F
.78665 .41907 m .78779 .42156 L .78423 .42119 L F
.323 .094 .405 r
.14306 .58133 m .14586 .58092 L .14596 .57765 L F
.304 .088 .411 r
.14407 .5824 m .14586 .58092 L .14306 .58133 L F
.465 .792 .999 r
.17423 .58912 m .17399 .59053 L .17297 .58945 L F
.1745 .5893 m .17399 .59053 L .17423 .58912 L F
.1745 .5893 m .17682 .5903 L .17399 .59053 L F
.846 .691 .69 r
.17436 .58921 m .1745 .5893 L .17535 .58893 L F
.1745 .5893 m .17539 .58955 L .17535 .58893 L F
.945 .764 .626 r
.17535 .58893 m .17539 .58955 L .17682 .5903 L F
.465 .792 .999 r
.17565 .58962 m .17682 .5903 L .1745 .5893 L F
0 .04 .609 r
.17556 .59236 m .17399 .59053 L .17682 .5903 L F
.945 .764 .626 r
.17539 .58955 m .17556 .59236 L .17682 .5903 L F
.465 .792 .999 r
.17462 .58902 m .17565 .58962 L .17539 .58955 L F
.17458 .58912 m .17539 .58955 L .1745 .5893 L F
.17462 .58902 m .17539 .58955 L .17458 .58912 L F
.846 .691 .69 r
.1745 .5893 m .17541 .58986 L .17539 .58955 L F
.17319 .58953 m .17556 .59236 L .17541 .58986 L F
.17319 .58953 m .17541 .58986 L .17436 .58921 L F
.465 .792 .999 r
.17462 .58902 m .17436 .58921 L .17423 .58912 L F
.846 .691 .69 r
.17319 .58953 m .17436 .58921 L .17462 .58902 L F
.17436 .58921 m .17535 .58893 L .17462 .58902 L F
.465 .792 .999 r
.17462 .58902 m .1745 .5893 L .17436 .58921 L F
.482 .685 .956 r
.30985 .54073 m .3097 .54338 L .30761 .54101 L F
.30985 .54073 m .31306 .54328 L .3097 .54338 L F
.726 .726 .851 r
.82169 .41994 m .81864 .4191 L .82129 .41611 L F
.803 .575 .592 r
.81888 .42092 m .82169 .41994 L .82211 .42166 L F
.81888 .42092 m .81864 .4191 L .82169 .41994 L F
.71 .715 .853 r
.8245 .41833 m .82169 .41994 L .82129 .41611 L F
.928 .886 .472 r
.83983 .42363 m .83968 .42596 L .83968 .42453 L F
.704 .561 .691 r
.75173 .38638 m .75376 .38559 L .75425 .38331 L F
.815 .803 .84 r
.54768 .57516 m .54385 .57622 L .54728 .57443 L F
0 0 0 r
.54385 .57622 m .54577 .57575 L .54728 .57443 L F
.93 .951 .619 r
.54728 .57443 m .54577 .57575 L .5468 .57357 L F
.54728 .57443 m .5468 .57357 L .54751 .57205 L F
.815 .803 .84 r
.54831 .57499 m .54768 .57516 L .54728 .57443 L F
.798 .752 .81 r
.55039 .57246 m .54831 .57499 L .55068 .57204 L F
.372 .617 .946 r
.20237 .61433 m .2023 .61658 L .19994 .61475 L F
.20237 .61433 m .2041 .6165 L .2023 .61658 L F
.77 .737 .823 r
.82333 .42546 m .82149 .42697 L .81973 .42505 L F
.619 .322 .444 r
.80462 .40748 m .80091 .40993 L .80074 .40764 L F
.80462 .40748 m .80353 .40983 L .80091 .40993 L F
.592 .293 .43 r
.80722 .40926 m .80462 .40748 L .80701 .40746 L F
.80722 .40926 m .80353 .40983 L .80462 .40748 L F
.478 .208 .426 r
.18635 .56796 m .18581 .56614 L .18756 .56624 L F
.18635 .56796 m .18446 .56852 L .18581 .56614 L F
.263 0 0 r
.22768 .62568 m .23157 .62663 L .22966 .62606 L F
0 0 0 r
.17377 .57542 m .17182 .57685 L .17054 .57777 L F
.17533 .57626 m .17182 .57685 L .17377 .57542 L F
.421 0 .127 r
.17653 .57502 m .17533 .57626 L .17377 .57542 L F
.569 .898 .983 r
.23819 .69536 m .24059 .69443 L .23851 .69386 L F
.179 .708 .702 r
.21441 .64235 m .21749 .64163 L .21627 .64085 L F
.28 .724 .962 r
.21749 .64163 m .21766 .64086 L .21627 .64085 L F
.21749 .64163 m .21924 .64156 L .21766 .64086 L F
.747 .667 .772 r
.45875 .65741 m .46169 .65817 L .46058 .65652 L F
0 0 0 r
.45836 .65997 m .46169 .65817 L .45875 .65741 L F
.663 .641 .818 r
.46058 .65652 m .46169 .65817 L .46432 .6572 L F
.544 .318 .522 r
.46169 .65817 m .46393 .66016 L .46432 .6572 L F
.492 .694 .958 r
.83877 .39366 m .84156 .39348 L .8394 .39528 L F
.331 .396 .779 r
.8394 .39528 m .84156 .39348 L .84275 .39716 L F
.06 .385 .847 r
.8394 .39528 m .84275 .39716 L .84291 .39838 L F
.344 0 0 r
.23001 .53627 m .2343 .53634 L .23195 .53655 L F
.633 .42 .575 r
.79239 .39777 m .79464 .39999 L .79569 .39843 L F
.75 .322 .234 r
.79464 .39999 m .79802 .4008 L .79569 .39843 L F
.971 .851 .665 r
.55528 .5572 m .55386 .55657 L .55526 .55276 L F
.922 .737 .634 r
.55528 .5572 m .55287 .55871 L .55386 .55657 L F
.55528 .5572 m .55483 .56011 L .55287 .55871 L F
.873 .668 .622 r
.55795 .52963 m .55482 .53132 L .55594 .52895 L F
.55795 .52963 m .55764 .53225 L .55482 .53132 L F
.297 .51 .893 r
.28372 .56947 m .2841 .5693 L .27971 .56617 L F
.4 .854 .801 r
.28582 .56859 m .2841 .5693 L .28372 .56947 L F
0 0 0 r
.28372 .56947 m .28433 .57031 L .28582 .56859 L F
.28372 .56947 m .28253 .57129 L .28433 .57031 L F
.521 .727 .967 r
.15563 .60833 m .15606 .60601 L .1536 .60558 L F
.15563 .60833 m .15791 .6079 L .15606 .60601 L F
.364 .801 .962 r
.26912 .53602 m .27143 .53561 L .27317 .53616 L F
.52 .878 .983 r
.27317 .53616 m .27365 .53483 L .27542 .53582 L F
.27317 .53616 m .27143 .53561 L .27365 .53483 L F
.404 .783 .992 r
.26292 .53585 m .26518 .53556 L .2669 .53642 L F
.171 .686 .891 r
.26518 .53556 m .26912 .53602 L .2669 .53642 L F
.408 .276 .588 r
.27971 .56617 m .28157 .5665 L .28141 .56255 L F
.272 .502 .895 r
.27971 .56617 m .2841 .5693 L .28157 .5665 L F
.81 .322 0 r
.49582 .54769 m .49665 .54912 L .4977 .5487 L F
.427 0 0 r
.49665 .54912 m .50041 .54975 L .4977 .5487 L F
.574 .315 .486 r
.3095 .61498 m .30901 .61738 L .30648 .61761 L F
.592 .498 .716 r
.31134 .61157 m .31191 .61467 L .3095 .61498 L F
.524 .262 .46 r
.31191 .61467 m .30901 .61738 L .3095 .61498 L F
0 .414 .795 r
.49729 .5743 m .49919 .57503 L .50024 .57578 L F
.853 .397 .038 r
.49919 .57503 m .50213 .57811 L .50024 .57578 L F
.822 .535 .503 r
.80074 .40764 m .79764 .40912 L .79707 .40717 L F
.80074 .40764 m .80091 .40993 L .79764 .40912 L F
.502 .695 .955 r
.32769 .5483 m .32715 .55032 L .32575 .54863 L F
.32769 .5483 m .32928 .54996 L .32715 .55032 L F
.282 .369 .776 r
.3295 .55224 m .32715 .55032 L .32928 .54996 L F
.652 .957 .937 r
.22006 .55173 m .2196 .5532 L .22222 .55185 L F
.22006 .55173 m .21879 .55275 L .2196 .5532 L F
.188 0 0 r
.23603 .53664 m .24039 .5357 L .23822 .53611 L F
.299 .782 .706 r
.19842 .54278 m .19847 .54263 L .20059 .54229 L F
.19842 .54278 m .19648 .54343 L .19847 .54263 L F
.487 .822 .999 r
.82831 .39463 m .82674 .39601 L .82588 .39518 L F
.82831 .39463 m .82947 .39552 L .82674 .39601 L F
.818 .609 .62 r
.24699 .66902 m .25045 .66698 L .24759 .667 L F
.518 .709 .958 r
.15954 .61156 m .16045 .60936 L .15791 .6079 L F
.15954 .61156 m .16156 .61103 L .16045 .60936 L F
.754 .265 .073 r
.50189 .55574 m .4979 .55333 L .49961 .55326 L F
.489 .253 .483 r
.48904 .60885 m .48892 .61128 L .48641 .61176 L F
.514 .273 .488 r
.49161 .60867 m .48892 .61128 L .48904 .60885 L F
.18 .313 .764 r
.14429 .59963 m .14405 .59581 L .14316 .59606 L F
.14429 .59963 m .14538 .59956 L .14405 .59581 L F
.511 .519 .8 r
.14772 .60484 m .14865 .60143 L .14683 .6027 L F
.358 .328 .688 r
.14865 .60143 m .14756 .60285 L .14683 .6027 L F
.179 .354 .802 r
.14429 .59963 m .14756 .60285 L .14538 .59956 L F
.316 .398 .788 r
.14683 .6027 m .14429 .59963 L .14369 .60236 L F
.14683 .6027 m .14756 .60285 L .14429 .59963 L F
.802 .692 .743 r
.76569 .39473 m .76713 .39843 L .76907 .39526 L F
.449 .653 .947 r
.46845 .56436 m .46933 .56608 L .46704 .56611 L F
.46845 .56436 m .46933 .56608 L .46704 .56611 L F
0 0 .041 r
.57327 .59751 m .57339 .59433 L .57359 .59273 L F
.625 .247 .306 r
.81055 .40726 m .80982 .4093 L .80701 .40746 L F
.25 0 .003 r
.81291 .40691 m .80982 .4093 L .81055 .40726 L F
.718 .631 .759 r
.53261 .59254 m .53327 .59414 L .53215 .59019 L F
.415 .513 .85 r
.53625 .59571 m .53471 .5921 L .53327 .59414 L F
0 0 0 r
.17556 .59236 m .17494 .59486 L .17462 .5952 L F
.907 .67 .569 r
.17319 .58953 m .17494 .59486 L .17556 .59236 L F
0 0 .381 r
.17519 .59459 m .17494 .59486 L .17476 .59389 L F
.176 .59592 m .17494 .59486 L .17519 .59459 L F
0 0 0 r
.17462 .5952 m .17494 .59486 L .17431 .59613 L F
0 0 .143 r
.17494 .59486 m .17449 .59673 L .17431 .59613 L F
.596 .615 .842 r
.32871 .58709 m .32464 .58454 L .32719 .58607 L F
.191 .564 .936 r
.32941 .58609 m .32871 .58709 L .32719 .58607 L F
.32941 .58609 m .33081 .58755 L .32871 .58709 L F
.55 .358 .574 r
.33143 .58951 m .32871 .58709 L .33081 .58755 L F
.33143 .58951 m .32861 .59008 L .32871 .58709 L F
.524 .593 .866 r
.8011 .43855 m .80474 .44145 L .80374 .43778 L F
.459 .499 .813 r
.80374 .43778 m .80474 .44145 L .80682 .43907 L F
.46 .5 .814 r
.80474 .44145 m .80772 .44237 L .80682 .43907 L F
.327 .807 .891 r
.20059 .54229 m .20278 .5418 L .20456 .54188 L F
0 .31 .75 r
.1923 .61417 m .19209 .61352 L .19038 .61205 L F
.1923 .61417 m .19405 .61504 L .19209 .61352 L F
.529 .692 .943 r
.80473 .426 m .80082 .42463 L .8032 .42332 L F
.573 .639 .878 r
.80738 .42545 m .80473 .426 L .8032 .42332 L F
.567 .85 .997 r
.30133 .53883 m .29947 .53957 L .29776 .53872 L F
.6 .497 .708 r
.76156 .40177 m .76471 .40156 L .76337 .39796 L F
.809 .721 .769 r
.76098 .40312 m .76471 .40156 L .76156 .40177 L F
0 .478 .819 r
.76771 .41536 m .76963 .41589 L .77096 .41663 L F
0 .065 .609 r
.77277 .41732 m .77096 .41663 L .76963 .41589 L F
.77277 .41732 m .77256 .42013 L .77096 .41663 L F
0 0 .22 r
.24454 .55098 m .24491 .55174 L .24287 .54975 L F
.7 .424 .502 r
.24698 .5514 m .24509 .55317 L .24454 .55098 L F
0 0 .22 r
.24454 .55098 m .24509 .55317 L .24491 .55174 L F
.266 .313 .726 r
.17449 .59673 m .17568 .60125 L .17394 .59908 L F
.789 .547 .571 r
.43651 .67514 m .43969 .67815 L .43799 .67818 L F
.033 .603 .745 r
.43969 .67815 m .43594 .67809 L .43799 .67818 L F
.905 .844 .773 r
.513 .54727 m .51135 .54991 L .51301 .55051 L F
.815 .953 .908 r
.83678 .4157 m .83441 .41588 L .83618 .41342 L F
.83678 .4157 m .83527 .41676 L .83441 .41588 L F
.657 .775 .936 r
.83989 .41396 m .83678 .4157 L .83618 .41342 L F
.753 .381 .349 r
.52886 .57156 m .53061 .57418 L .53202 .57216 L F
.8 .444 .381 r
.53061 .57418 m .53324 .57499 L .53202 .57216 L F
.421 .786 .995 r
.15181 .60542 m .14978 .60449 L .14772 .60484 L F
.303 .528 .905 r
.15181 .60542 m .15215 .60336 L .14978 .60449 L F
.15181 .60542 m .1536 .60558 L .15215 .60336 L F
.214 .082 .475 r
.14145 .58741 m .1428 .5869 L .14407 .5824 L F
.28 .253 .649 r
.14145 .58741 m .14339 .58942 L .1428 .5869 L F
.357 .265 .612 r
.14174 .59009 m .14339 .58942 L .14145 .58741 L F
.094 0 0 r
.54078 .5159 m .54398 .5145 L .54482 .51381 L F
.516 .086 .162 r
.54398 .5145 m .54738 .5137 L .54482 .51381 L F
.848 .834 .833 r
.47817 .55983 m .47582 .56287 L .47413 .56143 L F
.52 .347 .587 r
.47817 .55983 m .47828 .56255 L .47582 .56287 L F
.125 .674 .743 r
.47582 .56287 m .47624 .5627 L .47413 .56143 L F
.47582 .56287 m .47828 .56255 L .47624 .5627 L F
.559 .843 .997 r
.449 .58658 m .44462 .58628 L .44612 .58734 L F
.449 .58658 m .44462 .58628 L .44612 .58734 L F
.375 .059 .296 r
.1654 .56172 m .16851 .55912 L .16694 .55954 L F
.579 .383 .58 r
.32989 .57553 m .32958 .57801 L .32664 .57766 L F
.482 .424 .716 r
.3308 .58071 m .32664 .57766 L .32958 .57801 L F
.3308 .58071 m .32777 .58302 L .32664 .57766 L F
.86 .737 .726 r
.55957 .53591 m .55876 .53813 L .55751 .53472 L F
.586 .321 .482 r
.46513 .61743 m .46765 .61734 L .46796 .61496 L F
.623 .402 .561 r
.46765 .61734 m .4705 .61426 L .46796 .61496 L F
.506 .521 .806 r
.23107 .69344 m .23357 .69381 L .23233 .69031 L F
.492 .361 .63 r
.23107 .69344 m .2336 .69395 L .23357 .69381 L F
.23107 .69344 m .23169 .69736 L .2336 .69395 L F
.792 .678 .738 r
.82211 .42166 m .82333 .42546 L .81973 .42505 L F
.998 .812 .467 r
.83441 .41588 m .83527 .41676 L .8349 .41928 L F
.911 .958 .808 r
.8427 .42293 m .84416 .41863 L .84311 .42082 L F
.8427 .42293 m .84489 .41982 L .84416 .41863 L F
0 0 0 r
.84235 .4253 m .8427 .42293 L .84311 .42082 L F
.568 .253 .394 r
.28578 .63537 m .28409 .63844 L .28166 .63847 L F
.556 .251 .406 r
.28796 .63533 m .28409 .63844 L .28578 .63537 L F
.865 .621 .568 r
.55594 .52895 m .55282 .52544 L .55476 .52608 L F
.574 .605 .846 r
.16982 .61845 m .17416 .62132 L .17312 .6197 L F
.472 .63 .922 r
.17312 .6197 m .17416 .62132 L .17498 .61933 L F
.501 .663 .934 r
.17416 .62132 m .17604 .62083 L .17498 .61933 L F
.303 .507 .889 r
.17416 .62132 m .17792 .62439 L .17604 .62083 L F
.85 .733 .734 r
.45454 .65434 m .45082 .65385 L .4531 .65075 L F
.735 .267 .138 r
.45454 .65434 m .45321 .65565 L .45082 .65385 L F
.599 .867 .532 r
.45545 .65309 m .45321 .65565 L .45454 .65434 L F
.708 .232 .117 r
.45454 .65434 m .45321 .65565 L .45545 .65309 L F
.45454 .65434 m .45689 .65655 L .45321 .65565 L F
.715 .729 .861 r
.83023 .4277 m .83372 .42868 L .83066 .43091 L F
.809 .89 .902 r
.82903 .43744 m .83195 .43716 L .8309 .43579 L F
.781 .949 .93 r
.83195 .43716 m .83429 .4338 L .8309 .43579 L F
.83195 .43716 m .83504 .43479 L .83429 .4338 L F
.785 .756 .827 r
.76148 .4069 m .76451 .40385 L .76098 .40312 L F
.679 .871 .971 r
.42514 .66232 m .42507 .66367 L .42302 .66266 L F
.955 .726 .553 r
.42302 .66266 m .42507 .66367 L .42514 .66232 L F
.42302 .66266 m .42456 .66611 L .42507 .66367 L F
.49 .162 .338 r
.32777 .58302 m .32464 .58454 L .32487 .58426 L F
.32777 .58302 m .32632 .58505 L .32464 .58454 L F
.259 0 .176 r
.32978 .58335 m .32777 .58302 L .3308 .58071 L F
.32978 .58335 m .32632 .58505 L .32777 .58302 L F
.69 .63 .785 r
.18416 .61039 m .18173 .61197 L .18018 .60829 L F
.736 .775 .885 r
.79278 .44211 m .79501 .44075 L .79143 .44027 L F
.076 0 0 r
.19378 .77247 m .19565 .77244 L .19343 .77292 L F
.523 .598 .871 r
.16156 .61103 m .16591 .6156 L .16566 .61395 L F
.464 .136 .324 r
.46699 .62693 m .46389 .62916 L .46424 .62723 L F
.661 .512 .671 r
.48458 .56416 m .48848 .56536 L .48785 .56388 L F
.495 .323 .576 r
.48409 .63002 m .48648 .63216 L .48641 .6295 L F
.48409 .63002 m .48648 .63216 L .48641 .6295 L F
.818 .609 .62 r
.24699 .66902 m .25096 .67021 L .25045 .66698 L F
.707 .486 0 r
.25045 .66698 m .2506 .66801 L .25432 .66494 L F
.25045 .66698 m .25065 .66823 L .2506 .66801 L F
.825 .754 .785 r
.24953 .6649 m .25432 .66494 L .2506 .66801 L F
0 .098 .606 r
.25053 .66768 m .2506 .66801 L .25169 .66889 L F
.825 .754 .785 r
.24953 .6649 m .2506 .66801 L .24995 .66707 L F
0 .098 .606 r
.24995 .66707 m .2506 .66801 L .25053 .66768 L F
.707 .486 0 r
.25065 .66823 m .25096 .67021 L .2506 .66801 L F
.471 .196 .415 r
.32361 .59335 m .32315 .59597 L .32077 .59644 L F
.404 .218 .512 r
.32617 .58995 m .32577 .59269 L .32361 .59335 L F
.504 .281 .509 r
.32577 .59269 m .32315 .59597 L .32361 .59335 L F
.413 .362 .692 r
.32632 .58505 m .32719 .58607 L .32464 .58454 L F
.515 .555 .834 r
.18389 .62661 m .18563 .63033 L .18755 .62996 L F
.213 .73 .869 r
.24039 .5357 m .24258 .5355 L .24435 .53569 L F
.087 .642 .806 r
.24435 .53569 m .24478 .53542 L .2466 .53573 L F
.24435 .53569 m .24258 .5355 L .24478 .53542 L F
.644 .618 .809 r
.33844 .55982 m .33442 .5568 L .33666 .55868 L F
.55 .568 .825 r
.33935 .55555 m .33844 .55982 L .33666 .55868 L F
.33935 .55555 m .341 .55927 L .33844 .55982 L F
.412 .288 .6 r
.34079 .56167 m .33844 .55982 L .341 .55927 L F
.34079 .56167 m .33865 .56252 L .33844 .55982 L F
.731 .21 0 r
.25835 .64219 m .26054 .64489 L .25928 .6442 L F
.2584 .64288 m .25928 .6442 L .25847 .64376 L F
.25835 .64219 m .25928 .6442 L .2584 .64288 L F
.334 .767 .969 r
.26076 .64515 m .26181 .64571 L .26181 .64571 L F
.26076 .64515 m .26181 .64571 L .25826 .64567 L F
.26076 .64515 m .25826 .64567 L .25805 .64737 L F
.931 .925 .78 r
.25935 .64545 m .26076 .64515 L .25853 .6461 L F
.26014 .64483 m .26076 .64515 L .25935 .64545 L F
.731 .21 0 r
.26054 .64489 m .26076 .64515 L .2603 .64488 L F
.26054 .64489 m .2603 .64488 L .25847 .64376 L F
.879 .836 .8 r
.25847 .64376 m .26076 .64515 L .26137 .64386 L F
.931 .925 .78 r
.26137 .64386 m .26076 .64515 L .26014 .64483 L F
.372 .076 .328 r
.25805 .64737 m .25826 .64567 L .25595 .64767 L F
.747 .989 .891 r
.26076 .64515 m .25805 .64737 L .25664 .64743 L F
.26076 .64515 m .25664 .64743 L .25853 .6461 L F
.377 .119 .391 r
.26033 .64579 m .25853 .6461 L .26019 .64619 L F
.879 .836 .8 r
.25847 .64376 m .26137 .64386 L .26121 .64324 L F
.931 .925 .78 r
.26137 .64386 m .26009 .64487 L .26121 .64324 L F
.26009 .64487 m .2597 .64485 L .26121 .64324 L F
.377 .119 .391 r
.26121 .64324 m .2597 .64485 L .26033 .64579 L F
.931 .925 .78 r
.26009 .64487 m .25853 .6461 L .2597 .64485 L F
.377 .119 .391 r
.2597 .64485 m .25853 .6461 L .26033 .64579 L F
.195 0 .094 r
.18962 .56547 m .18635 .56796 L .18756 .56624 L F
.751 .499 .551 r
.45673 .63612 m .45526 .63704 L .45488 .63586 L F
.45543 .6351 m .45488 .63586 L .45435 .63426 L F
.45673 .63612 m .45488 .63586 L .45543 .6351 L F
.582 .373 .562 r
.45293 .63849 m .45488 .63586 L .45387 .63659 L F
.587 .528 .756 r
.45289 .63378 m .45387 .63659 L .45488 .63586 L F
.372 .609 .942 r
.45623 .63487 m .45673 .63612 L .45435 .63426 L F
.587 .528 .756 r
.45435 .63426 m .45488 .63586 L .45623 .63487 L F
.45289 .63378 m .45488 .63586 L .45435 .63426 L F
.684 .583 .736 r
.45052 .63599 m .45387 .63659 L .45277 .63343 L F
.694 .382 .443 r
.45052 .63599 m .45293 .63849 L .45387 .63659 L F
.751 .499 .551 r
.45526 .63704 m .45293 .63849 L .45435 .63426 L F
.582 .373 .562 r
.45293 .63849 m .45623 .63487 L .45488 .63586 L F
.751 .499 .551 r
.45435 .63426 m .45293 .63849 L .45402 .63399 L F
.587 .528 .756 r
.45277 .63343 m .45289 .63378 L .45435 .63426 L F
.45429 .63406 m .45435 .63426 L .45623 .63487 L F
.45277 .63343 m .45435 .63426 L .45429 .63406 L F
.372 .609 .942 r
.45623 .63487 m .45435 .63426 L .45402 .63399 L F
.751 .499 .551 r
.45673 .63612 m .45665 .63871 L .45293 .63849 L F
.202 0 0 r
.45665 .63871 m .45278 .6408 L .45293 .63849 L F
.582 .373 .562 r
.45293 .63849 m .45514 .63907 L .45613 .63522 L F
.45614 .63497 m .45613 .63522 L .45623 .63487 L F
.45293 .63849 m .45613 .63522 L .45614 .63497 L F
.982 .749 .342 r
.45611 .63652 m .45665 .63871 L .45673 .63612 L F
.45563 .63683 m .4561 .63769 L .45611 .63652 L F
.4561 .63769 m .45665 .63871 L .45611 .63652 L F
.921 .661 .172 r
.45623 .63487 m .4559 .63494 L .45673 .63612 L F
.763 .758 .245 r
.45623 .63487 m .45563 .63683 L .4559 .63494 L F
.982 .749 .342 r
.45563 .63683 m .45673 .63612 L .4559 .63494 L F
.656 .763 .929 r
.27359 .58412 m .27763 .58472 L .27592 .58329 L F
.76 .78 .869 r
.27592 .58329 m .27763 .58472 L .28004 .58341 L F
.645 .935 .967 r
.21342 .73188 m .21748 .73127 L .21924 .73013 L F
0 .067 .54 r
.23585 .64199 m .23936 .64497 L .23579 .64193 L F
.462 .713 .977 r
.23579 .64193 m .23936 .64497 L .23998 .64303 L F
.61 .269 .367 r
.80701 .40746 m .80982 .4093 L .80722 .40926 L F
.949 .671 .219 r
.84291 .39838 m .84236 .39955 L .84316 .40075 L F
.876 .778 .279 r
.84291 .39838 m .84275 .39716 L .84236 .39955 L F
.736 .66 .776 r
.76337 .39796 m .76713 .39843 L .76569 .39473 L F
.747 .569 .653 r
.76471 .40156 m .76713 .39843 L .76337 .39796 L F
.76471 .40156 m .76675 .40078 L .76713 .39843 L F
.686 .632 .789 r
.33442 .5568 m .33231 .5579 L .33073 .5546 L F
.907 .745 .67 r
.53305 .58376 m .53476 .58402 L .53363 .58098 L F
.869 .505 .357 r
.53362 .58588 m .53476 .58402 L .53305 .58376 L F
.856 .728 .721 r
.53476 .58402 m .53497 .58183 L .53363 .58098 L F
.799 .407 .313 r
.53362 .58588 m .53721 .58701 L .53476 .58402 L F
.321 .108 .426 r
.14596 .57765 m .1479 .57756 L .14787 .57529 L F
.279 .062 .394 r
.14596 .57765 m .14712 .57993 L .1479 .57756 L F
.14596 .57765 m .14586 .58092 L .14712 .57993 L F
0 0 .199 r
.26875 .6054 m .26675 .60869 L .26813 .60729 L F
0 0 0 r
.26647 .61121 m .26813 .60729 L .26675 .60869 L F
.315 .576 .934 r
.16982 .61845 m .17076 .61697 L .16949 .61691 L F
.16982 .61845 m .17312 .6197 L .17076 .61697 L F
.49 .252 .481 r
.30107 .57807 m .3034 .57758 L .30371 .57513 L F
.30107 .57807 m .3034 .57758 L .30371 .57513 L F
.549 .321 .522 r
.3034 .57758 m .30616 .57449 L .30371 .57513 L F
.061 0 .225 r
.30595 .57189 m .30499 .57583 L .30371 .57513 L F
.581 .699 .923 r
.30499 .57583 m .3034 .57758 L .30371 .57513 L F
.491 .827 .999 r
.22782 .6416 m .22956 .64242 L .23172 .64191 L F
.845 .478 .359 r
.50435 .58398 m .50468 .58592 L .50643 .58435 L F
.979 .762 .54 r
.50468 .58592 m .50615 .58682 L .50643 .58435 L F
.968 .725 .516 r
.23845 .67219 m .24001 .67573 L .23821 .67504 L F
0 .181 .708 r
.24052 .67436 m .24001 .67573 L .23845 .67219 L F
.539 .868 .994 r
.23821 .67504 m .24001 .67573 L .24052 .67436 L F
0 0 0 r
.17182 .57685 m .16907 .57973 L .17054 .57777 L F
.48892 .61128 m .48481 .6131 L .48641 .61176 L F
.75 .672 .775 r
.53393 .52275 m .5298 .52295 L .53259 .51999 L F
.388 .011 .196 r
.53393 .52275 m .53028 .52555 L .5298 .52295 L F
.53393 .52275 m .53276 .5252 L .53028 .52555 L F
.549 .558 .816 r
.53514 .5194 m .53393 .52275 L .53259 .51999 L F
.53514 .5194 m .53633 .52275 L .53393 .52275 L F
.53514 .5194 m .53393 .52275 L .53259 .51999 L F
.53514 .5194 m .53633 .52275 L .53393 .52275 L F
.267 0 .017 r
.53633 .52275 m .53276 .5252 L .53393 .52275 L F
.455 .092 .26 r
.48151 .60807 m .48401 .60778 L .485 .60552 L F
.78 .595 .65 r
.48401 .60778 m .48721 .60432 L .485 .60552 L F
.66 .55 .72 r
.18844 .83219 m .18961 .83111 L .1882 .83117 L F
.508 .358 .612 r
.32077 .59644 m .32089 .59897 L .31835 .59952 L F
.525 .363 .604 r
.32089 .59897 m .3185 .6021 L .31835 .59952 L F
.872 .742 .716 r
.55876 .53813 m .55596 .53752 L .55751 .53472 L F
.977 .715 .466 r
.55755 .54124 m .55596 .53752 L .55876 .53813 L F
.08 0 0 r
.18272 .57235 m .18054 .57385 L .17829 .57439 L F
.595 .904 .634 r
.18491 .56976 m .18318 .57136 L .18332 .57106 L F
0 0 0 r
.18363 .57034 m .18332 .57106 L .18272 .57235 L F
.707 .961 .703 r
.18332 .57106 m .18054 .57385 L .18272 .57235 L F
.595 .904 .634 r
.18318 .57136 m .18182 .57263 L .18332 .57106 L F
0 0 0 r
.18446 .56852 m .18332 .57106 L .18363 .57034 L F
0 0 .461 r
.24208 .64296 m .24207 .64273 L .23998 .64303 L F
.24208 .64296 m .24326 .64447 L .24207 .64273 L F
0 0 0 r
.25509 .66503 m .25399 .6662 L .25458 .66523 L F
.25512 .66494 m .25458 .66523 L .25566 .66346 L F
.25509 .66503 m .25458 .66523 L .25512 .66494 L F
.25509 .66503 m .25566 .66346 L .25428 .66279 L F
0 0 .469 r
.25468 .66074 m .25545 .66475 L .25428 .66279 L F
.739 .64 .749 r
.25802 .66542 m .25572 .6686 L .25509 .66503 L F
.728 .389 .405 r
.25577 .66637 m .25802 .66542 L .25509 .66503 L F
0 0 .469 r
.25545 .66475 m .25577 .66637 L .25516 .66491 L F
.25545 .66475 m .25516 .66491 L .25428 .66279 L F
.061 .228 .723 r
.45836 .65997 m .46057 .66214 L .45961 .66353 L F
.416 .807 .988 r
.1882 .83117 m .18961 .83111 L .18892 .83024 L F
.645 .644 .835 r
.26756 .64236 m .2704 .64185 L .26679 .64202 L F
.748 .762 .864 r
.80082 .42463 m .79728 .42426 L .80006 .42202 L F
.641 .687 .878 r
.80259 .42092 m .80082 .42463 L .80006 .42202 L F
.80259 .42092 m .8032 .42332 L .80082 .42463 L F
.537 .623 .885 r
.17792 .62439 m .17914 .62239 L .17604 .62083 L F
.17792 .62439 m .18 .62402 L .17914 .62239 L F
.867 .679 .647 r
.56291 .55918 m .5645 .56263 L .56511 .56019 L F
.877 .982 .832 r
.55068 .57204 m .54728 .57443 L .54901 .57289 L F
.887 .991 .777 r
.55068 .57204 m .54901 .57289 L .55097 .57013 L F
.477 .802 1 r
.27542 .53582 m .27762 .53535 L .27909 .53633 L F
.521 .742 .975 r
.27992 .53425 m .27909 .53633 L .27762 .53535 L F
.27992 .53425 m .28164 .53584 L .27909 .53633 L F
.302 .235 .614 r
.47293 .56174 m .47413 .56143 L .47269 .56029 L F
.095 0 0 r
.1779 .55277 m .17919 .55295 L .1809 .55077 L F
.137 0 0 r
.1809 .55077 m .18124 .55222 L .18316 .5503 L F
.1809 .55077 m .17919 .55295 L .18124 .55222 L F
.7 .683 .143 r
.26607 .6457 m .26679 .64202 L .26755 .64522 L F
.583 .248 .367 r
.26679 .64202 m .26906 .64413 L .26755 .64522 L F
.26679 .64202 m .2704 .64185 L .26906 .64413 L F
.86 .793 .784 r
.53393 .57819 m .53324 .57499 L .53255 .57532 L F
.963 .846 .68 r
.53393 .57819 m .53192 .57984 L .53363 .58098 L F
.53393 .57819 m .53255 .57532 L .53192 .57984 L F
.772 .612 .68 r
.53497 .58183 m .53393 .57819 L .53363 .58098 L F
.765 .757 .845 r
.79791 .43818 m .8011 .43855 L .80009 .4368 L F
.628 .712 .907 r
.8011 .43855 m .80374 .43778 L .80009 .4368 L F
.718 .394 .431 r
.26181 .64571 m .26607 .6457 L .26412 .64752 L F
.738 .743 .856 r
.26607 .6457 m .26181 .64571 L .26412 .64752 L F
.575 .459 .684 r
.26755 .64522 m .26819 .64794 L .26607 .6457 L F
.587 .44 .649 r
.45402 .63399 m .45052 .63599 L .45277 .63343 L F
.56 .389 .606 r
.45402 .63399 m .45293 .63849 L .45052 .63599 L F
.52 .492 .766 r
.25682 .65147 m .25805 .64737 L .25595 .64767 L F
.25682 .65147 m .25919 .65133 L .25805 .64737 L F
.513 .381 .638 r
.25919 .65133 m .25706 .65412 L .25682 .65147 L F
.25919 .65133 m .25706 .65412 L .25682 .65147 L F
.544 .774 .983 r
.77712 .37777 m .77559 .37975 L .77443 .37829 L F
.77443 .37829 m .77559 .37975 L .77712 .37777 L F
.25 0 .003 r
.81291 .40691 m .81242 .40857 L .80982 .4093 L F
.558 .844 .511 r
.81709 .40409 m .8149 .40651 L .81544 .40602 L F
0 0 0 r
.81544 .40602 m .8147 .40673 L .81242 .40857 L F
.558 .844 .511 r
.8149 .40651 m .8147 .40673 L .81544 .40602 L F
0 0 0 r
.81291 .40691 m .81597 .40553 L .81544 .40602 L F
.81597 .40553 m .8161 .40548 L .81544 .40602 L F
.011 0 0 r
.81544 .40602 m .81242 .40857 L .81291 .40691 L F
0 .043 .585 r
.53261 .59254 m .53215 .59019 L .53158 .58773 L F
.981 .734 .484 r
.42581 .6543 m .42419 .65601 L .42409 .65316 L F
0 0 0 r
.42744 .65094 m .42581 .6543 L .42409 .65316 L F
.42744 .65094 m .42665 .65299 L .42581 .6543 L F
.42658 .65499 m .42581 .6543 L .42665 .65299 L F
.42658 .65499 m .42419 .65601 L .42581 .6543 L F
.409 .126 .37 r
.25518 .62334 m .25862 .61956 L .25643 .62073 L F
.085 0 .05 r
.25823 .61985 m .25643 .62073 L .25862 .61956 L F
.265 .04 .375 r
.27066 .59881 m .27275 .59857 L .27373 .59641 L F
.176 .008 .4 r
.27066 .59881 m .27199 .60092 L .27275 .59857 L F
.27066 .59881 m .2709 .60183 L .27199 .60092 L F
.025 0 0 r
.53843 .51676 m .54011 .51663 L .54078 .5159 L F
.53843 .51676 m .53689 .51827 L .54011 .51663 L F
.185 .712 .853 r
.2466 .53573 m .24883 .53552 L .25054 .53573 L F
.339 .785 .957 r
.24883 .53552 m .25272 .53577 L .25054 .53573 L F
.695 .594 .739 r
.27316 .55586 m .27584 .55265 L .27407 .55426 L F
.39 .793 .984 r
.54994 .59922 m .54606 .59886 L .54726 .59981 L F
.731 .752 .869 r
.54994 .59922 m .55367 .59969 L .55239 .59847 L F
.746 .754 .859 r
.55239 .59847 m .55367 .59969 L .55581 .59843 L F
.46 .592 .898 r
.28986 .53507 m .28942 .53833 L .28749 .53668 L F
.28986 .53507 m .29145 .5382 L .28942 .53833 L F
.607 .391 .562 r
.51039 .54736 m .513 .54727 L .51286 .54459 L F
.373 .515 .871 r
.77204 .42389 m .77444 .42252 L .77112 .42174 L F
.77204 .42389 m .77502 .42458 L .77444 .42252 L F
.463 .277 .542 r
.2327 .70539 m .23249 .70873 L .23065 .7055 L F
.723 .497 .583 r
.23064 .7062 m .2327 .70539 L .23065 .7055 L F
.2327 .70539 m .23064 .7062 L .23065 .7055 L F
.994 .846 .585 r
.51148 .60065 m .51328 .59974 L .51137 .5985 L F
.51148 .60065 m .51262 .6021 L .51328 .59974 L F
.76 .78 .869 r
.27592 .58329 m .28004 .58341 L .27782 .58265 L F
.817 .843 .869 r
.27782 .58265 m .28004 .58341 L .28227 .58088 L F
.526 .377 .62 r
.28004 .58341 m .28248 .58379 L .28227 .58088 L F
.437 .243 .518 r
.28004 .58341 m .28198 .58601 L .28248 .58379 L F
.28004 .58341 m .28076 .58768 L .28198 .58601 L F
.193 .685 .921 r
.21781 .53678 m .22161 .53746 L .21943 .53743 L F
.01 0 0 r
.15895 .56638 m .15765 .56759 L .16099 .56555 L F
.768 .441 .433 r
.4685 .66056 m .46517 .66195 L .46393 .66016 L F
.393 .116 .37 r
.47014 .65976 m .46773 .66264 L .4685 .66056 L F
.255 .157 .546 r
.24888 .55216 m .24698 .5514 L .25052 .54985 L F
.784 .555 .59 r
.25282 .54922 m .24888 .55216 L .25052 .54985 L F
.848 .834 .833 r
.47817 .55983 m .47413 .56143 L .47614 .56074 L F
.472 .31 .58 r
.47817 .55983 m .48054 .5618 L .47828 .56255 L F
.665 .118 0 r
.47843 .56119 m .47817 .55983 L .47614 .56074 L F
.47843 .56119 m .48054 .5618 L .47817 .55983 L F
.397 .238 .545 r
.25572 .6686 m .25388 .6698 L .25399 .6662 L F
.688 .195 .072 r
.46186 .63015 m .46017 .6313 L .45798 .62922 L F
.504 0 0 r
.46315 .63139 m .46186 .63015 L .46389 .62916 L F
.425 .545 .874 r
.32391 .54606 m .32297 .54865 L .32143 .54516 L F
.511 .641 .913 r
.32391 .54606 m .32575 .54863 L .32297 .54865 L F
.824 .59 .584 r
.5645 .56263 m .56442 .56523 L .56804 .56585 L F
.816 .62 .638 r
.56442 .56523 m .56814 .56852 L .56804 .56585 L F
.827 .618 .62 r
.56814 .56852 m .56957 .56887 L .56804 .56585 L F
.803 .544 .545 r
.56815 .57143 m .56957 .56887 L .56814 .56852 L F
.56815 .57143 m .56973 .57151 L .56957 .56887 L F
.966 .909 .553 r
.24624 .6839 m .24754 .68175 L .24705 .68094 L F
.289 .713 .971 r
.26087 .55673 m .25662 .55571 L .25831 .55688 L F
.58 .275 .415 r
.22961 .71544 m .22881 .71754 L .2262 .71748 L F
.365 .065 .317 r
.23079 .71665 m .22961 .71544 L .23148 .71473 L F
.23079 .71665 m .22881 .71754 L .22961 .71544 L F
.489 .74 .983 r
.21975 .62319 m .21913 .62496 L .21753 .6234 L F
.21975 .62319 m .22166 .62477 L .21913 .62496 L F
.551 .889 .985 r
.19472 .78207 m .19656 .78256 L .1969 .78128 L F
.1969 .78128 m .19656 .78256 L .19472 .78207 L F
.19472 .78207 m .19656 .78256 L .1969 .78128 L F
.075 0 0 r
.23378 .62668 m .23552 .62657 L .23157 .62663 L F
.039 .609 .733 r
.23609 .62651 m .23552 .62657 L .23378 .62668 L F
.23609 .62651 m .2378 .62651 L .23552 .62657 L F
.084 .317 .796 r
.77531 .42633 m .77669 .42795 L .77502 .42458 L F
.068 0 0 r
.8109 .39993 m .81356 .39929 L .81445 .39839 L F
0 0 0 r
.81445 .39839 m .8161 .39846 L .81708 .39766 L F
.81445 .39839 m .81356 .39929 L .8161 .39846 L F
.598 .409 .597 r
.45659 .62349 m .45898 .61996 L .45651 .62077 L F
.271 .335 .746 r
.54296 .58109 m .54478 .57995 L .54208 .5778 L F
0 0 0 r
.54296 .58109 m .54216 .58294 L .54478 .57995 L F
.661 .609 .786 r
.78119 .43501 m .78289 .43025 L .77999 .43122 L F
.78119 .43501 m .78384 .43385 L .78289 .43025 L F
.424 .554 .882 r
.78119 .43501 m .78495 .43797 L .78384 .43385 L F
.784 .488 .486 r
.55619 .51586 m .55991 .51416 L .55612 .51383 L F
.55619 .51586 m .55998 .51645 L .55991 .51416 L F
.667 .585 .754 r
.21986 .71542 m .22066 .71844 L .22306 .71576 L F
.589 .763 .962 r
.18994 .61101 m .1879 .61197 L .18657 .61048 L F
.18994 .61101 m .1879 .61197 L .18657 .61048 L F
.613 .603 .817 r
.24459 .68936 m .24258 .68804 L .2454 .68721 L F
.304 .272 .657 r
.24671 .68696 m .24459 .68936 L .2454 .68721 L F
.24671 .68696 m .24713 .68958 L .24459 .68936 L F
.652 .459 .61 r
.24713 .68958 m .24454 .6924 L .24459 .68936 L F
.862 .712 .694 r
.27971 .60228 m .27831 .60255 L .2799 .59915 L F
.798 .627 .671 r
.2799 .59915 m .2797 .60237 L .28095 .60222 L F
0 0 0 r
.27992 .59984 m .27972 .60212 L .2799 .59915 L F
.27972 .60212 m .27971 .60228 L .2799 .59915 L F
.798 .627 .671 r
.2799 .59915 m .27831 .60255 L .2795 .6024 L F
.616 .34 .475 r
.27747 .60492 m .27774 .60472 L .27831 .60255 L F
.27774 .60472 m .28095 .60222 L .2795 .6024 L F
.27774 .60472 m .2795 .6024 L .27831 .60255 L F
.792 .83 .36 r
.27952 .60238 m .27831 .60255 L .27971 .60228 L F
.27773 .60329 m .27747 .60492 L .27831 .60255 L F
.27773 .60329 m .27831 .60255 L .27952 .60238 L F
.798 .627 .671 r
.27971 .60235 m .2795 .6024 L .2797 .60237 L F
.85 .982 .692 r
.27972 .60212 m .27952 .60238 L .27971 .60228 L F
.798 .627 .671 r
.27972 .60212 m .27952 .60238 L .27971 .60235 L F
.27952 .60238 m .2795 .6024 L .27971 .60235 L F
.85 .982 .692 r
.27992 .59984 m .27773 .60329 L .27952 .60238 L F
.798 .627 .671 r
.2799 .59915 m .2795 .6024 L .27972 .60212 L F
.85 .982 .692 r
.27952 .60238 m .27952 .60238 L .27952 .60238 L F
.27992 .59984 m .27952 .60238 L .27952 .60238 L F
.27992 .59984 m .27952 .60238 L .27972 .60212 L F
.616 .34 .475 r
.27747 .60492 m .28007 .60474 L .28095 .60222 L F
.43 .155 .394 r
.28095 .60222 m .28266 .60409 L .28384 .60228 L F
.28095 .60222 m .28007 .60474 L .28266 .60409 L F
.831 .986 .873 r
.19084 .76376 m .19237 .76369 L .19263 .76191 L F
.19263 .76191 m .19237 .76369 L .19084 .76376 L F
.535 .875 .99 r
.8282 .40355 m .82986 .40198 L .82754 .40343 L F
.8282 .40355 m .83079 .40278 L .82986 .40198 L F
.575 .901 .983 r
.18892 .83024 m .18961 .83111 L .19202 .8298 L F
.782 .589 .64 r
.57634 .57785 m .57319 .57493 L .57341 .57723 L F
.853 .628 .597 r
.57326 .57996 m .57634 .57785 L .57341 .57723 L F
.57326 .57996 m .57543 .58082 L .57634 .57785 L F
.806 .911 .912 r
.82375 .44094 m .82471 .43812 L .82282 .43978 L F
.82375 .44094 m .82569 .4393 L .82471 .43812 L F
.036 0 .419 r
.50683 .60208 m .50837 .59887 L .50572 .59971 L F
.50683 .60208 m .50819 .60122 L .50837 .59887 L F
.969 .752 .556 r
.50992 .60263 m .50766 .60384 L .50683 .60208 L F
.313 .128 .462 r
.50766 .60384 m .50819 .60122 L .50683 .60208 L F
.673 .821 .955 r
.23172 .64191 m .23585 .64199 L .23405 .64197 L F
0 .067 .54 r
.23585 .64199 m .23579 .64193 L .23405 .64197 L F
.547 .516 .772 r
.78384 .43385 m .78495 .43797 L .78761 .43759 L F
.633 .567 .763 r
.17895 .60357 m .17645 .6051 L .176 .60285 L F
.482 .264 .506 r
.19565 .77244 m .19375 .77013 L .19343 .77292 L F
.19565 .77244 m .19596 .76971 L .19375 .77013 L F
.874 .662 .612 r
.56725 .52239 m .56877 .52594 L .56912 .52335 L F
.779 .866 .914 r
.45689 .65655 m .46058 .65652 L .45935 .65328 L F
.45689 .65655 m .45875 .65741 L .46058 .65652 L F
.904 .815 .749 r
.45935 .65328 m .46058 .65652 L .4608 .6533 L F
.583 .377 .567 r
.33226 .57515 m .32958 .57801 L .32989 .57553 L F
.572 .597 .839 r
.78761 .43759 m .78877 .44088 L .79143 .44027 L F
.787 .384 .29 r
.51422 .56002 m .51937 .55977 L .51766 .55854 L F
.559 .24 .384 r
.51987 .56171 m .51921 .56292 L .51937 .55977 L F
.787 .384 .29 r
.51422 .56002 m .51987 .56171 L .51937 .55977 L F
.915 .967 .793 r
.21336 .53916 m .21374 .53633 L .21536 .53794 L F
.955 .796 .645 r
.47014 .65976 m .47123 .65748 L .46896 .65681 L F
0 0 0 r
.27992 .59984 m .2799 .59915 L .2806 .59768 L F
.644 .486 .654 r
.33343 .56595 m .33093 .56906 L .33146 .56672 L F
.859 .655 .626 r
.56402 .51922 m .56725 .52239 L .56701 .52032 L F
0 0 0 r
.46432 .6572 m .46612 .65599 L .46695 .65427 L F
.713 .27 .197 r
.46612 .65599 m .46896 .65681 L .46695 .65427 L F
.443 0 .019 r
.50799 .613 m .50826 .61415 L .50505 .61401 L F
.424 0 0 r
.50505 .61401 m .50801 .61522 L .50826 .61415 L F
.50799 .613 m .50801 .61522 L .50505 .61401 L F
.13 0 .085 r
.50799 .613 m .50981 .61388 L .50826 .61415 L F
.083 0 0 r
.50981 .61388 m .50801 .61522 L .50826 .61415 L F
.164 0 0 r
.50981 .61388 m .50801 .61522 L .50799 .613 L F
0 0 0 r
.81544 .40602 m .8161 .40548 L .81857 .40435 L F
.812 .623 .647 r
.5105 .60793 m .51139 .6115 L .5127 .60876 L F
.631 .132 .045 r
.48856 .56686 m .48811 .56782 L .48562 .56648 L F
.891 .795 .309 r
.48848 .56536 m .48811 .56782 L .48856 .56686 L F
.879 .451 .17 r
.48856 .56686 m .48978 .56896 L .48811 .56782 L F
.275 .543 .921 r
.2861 .53452 m .2854 .53611 L .28382 .53501 L F
.2861 .53452 m .28749 .53668 L .2854 .53611 L F
.816 .432 .327 r
.51921 .56292 m .52213 .56479 L .52321 .56308 L F
.746 .543 .62 r
.52213 .56479 m .52541 .56319 L .52321 .56308 L F
.633 .656 .855 r
.27316 .55586 m .27456 .55772 L .27673 .55688 L F
.938 .741 .611 r
.45689 .65655 m .45836 .65997 L .45875 .65741 L F
.969 .752 .556 r
.50992 .60263 m .5085 .60587 L .50766 .60384 L F
.391 .669 .97 r
.52224 .57187 m .52314 .57031 L .52101 .57037 L F
0 0 .141 r
.52292 .57397 m .52314 .57031 L .52224 .57187 L F
.124 .674 .753 r
.23044 .54967 m .2265 .55004 L .22823 .54993 L F
.809 .721 .769 r
.76098 .40312 m .76451 .40385 L .76471 .40156 L F
.788 .703 .771 r
.76451 .40385 m .76675 .40078 L .76471 .40156 L F
.098 0 0 r
.1779 .55277 m .17597 .55479 L .17919 .55295 L F
.435 .215 .479 r
.43389 .67673 m .43594 .67809 L .43651 .67514 L F
.48 .428 .722 r
.28096 .55937 m .28141 .56255 L .2835 .56176 L F
.31 .202 .565 r
.28141 .56255 m .28346 .56434 L .2835 .56176 L F
.28141 .56255 m .28157 .5665 L .28346 .56434 L F
.662 .15 0 r
.5153 .56538 m .51454 .56504 L .51331 .56348 L F
.862 .416 .03 r
.51691 .56787 m .51454 .56504 L .5153 .56538 L F
.34 .812 .908 r
.81857 .40435 m .82201 .40408 L .82112 .40336 L F
.435 .685 .969 r
.82201 .40408 m .82372 .40251 L .82112 .40336 L F
.82201 .40408 m .82483 .4042 L .82372 .40251 L F
.635 .777 .949 r
.46418 .57028 m .46527 .56784 L .46424 .56794 L F
.46418 .57028 m .46727 .56991 L .46527 .56784 L F
.934 .821 .709 r
.55362 .56205 m .55287 .55871 L .55483 .56011 L F
.71 .715 .853 r
.8245 .41833 m .82129 .41611 L .82343 .41558 L F
.586 .733 .945 r
.82631 .41507 m .8245 .41833 L .82343 .41558 L F
.82631 .41507 m .82851 .41733 L .8245 .41833 L F
.656 .516 .681 r
.33357 .56839 m .33097 .57159 L .33093 .56906 L F
.33357 .56839 m .335 .57317 L .33097 .57159 L F
.7 .539 .666 r
.33478 .57448 m .33097 .57159 L .335 .57317 L F
.33478 .57448 m .33226 .57515 L .33097 .57159 L F
.171 .401 .843 r
.52725 .58092 m .52826 .5795 L .52558 .57818 L F
.067 .249 .741 r
.52725 .58092 m .52983 .58315 L .52826 .5795 L F
.454 .577 .888 r
.77112 .42174 m .77444 .42252 L .77398 .42164 L F
.589 .054 0 r
.77256 .42013 m .77393 .42162 L .77494 .42045 L F
.77393 .42162 m .77393 .42162 L .77393 .42162 L F
.77393 .42162 m .77393 .42162 L .77494 .42045 L F
.77393 .42162 m .774 .42164 L .77494 .42045 L F
0 0 0 r
.77494 .42045 m .77681 .41884 L .77711 .41979 L F
.77494 .42045 m .77399 .42164 L .77681 .41884 L F
.486 .677 .949 r
.77482 .42199 m .77597 .42041 L .77398 .42164 L F
0 0 0 r
.77399 .42164 m .77398 .42167 L .77403 .42161 L F
.77399 .42164 m .77403 .42161 L .77681 .41884 L F
.82 .744 .78 r
.77681 .41884 m .77426 .41933 L .77533 .41716 L F
.77681 .41884 m .77399 .42154 L .77426 .41933 L F
.498 .449 .733 r
.77533 .41716 m .77401 .42154 L .774 .4215 L F
.77426 .41933 m .774 .4215 L .77367 .42055 L F
.77533 .41716 m .774 .4215 L .77426 .41933 L F
.82 .744 .78 r
.77681 .41884 m .77403 .42161 L .77399 .42154 L F
.498 .449 .733 r
.77401 .42154 m .77393 .42152 L .77367 .42055 L F
.77533 .41716 m .77367 .42055 L .77277 .41732 L F
0 .003 .561 r
.77277 .41732 m .77367 .42055 L .77256 .42013 L F
.77367 .42055 m .77393 .42152 L .77369 .42128 L F
.82 .744 .78 r
.77426 .41933 m .77399 .42154 L .77292 .41959 L F
.486 .677 .949 r
.77398 .42164 m .77403 .42161 L .77401 .42157 L F
.77398 .42164 m .77403 .42155 L .77396 .42153 L F
.77398 .42164 m .77394 .4214 L .77393 .42155 L F
.498 .449 .733 r
.77399 .42154 m .77398 .42167 L .77393 .42152 L F
.82 .744 .78 r
.77403 .42161 m .77398 .42167 L .77399 .42154 L F
.498 .449 .733 r
.77401 .42154 m .77398 .42167 L .77399 .42154 L F
0 .003 .561 r
.77367 .42055 m .77369 .42128 L .77256 .42013 L F
.454 .577 .888 r
.77393 .42162 m .77398 .42164 L .77393 .42155 L F
.589 .054 0 r
.77393 .42162 m .77398 .42167 L .774 .42164 L F
0 .003 .561 r
.77393 .42152 m .77398 .42167 L .77393 .42162 L F
.77393 .42155 m .77393 .42162 L .77393 .42162 L F
.77393 .42152 m .77393 .42162 L .77393 .42155 L F
.77393 .42152 m .77393 .42162 L .77256 .42013 L F
.454 .577 .888 r
.77186 .42085 m .77393 .42162 L .77292 .41959 L F
.77393 .42162 m .77393 .42155 L .77292 .41959 L F
.486 .677 .949 r
.77393 .42155 m .77394 .4214 L .77292 .41959 L F
.82 .744 .78 r
.77399 .42154 m .77398 .42167 L .77292 .41959 L F
.486 .677 .949 r
.77401 .42157 m .77405 .42159 L .77403 .42155 L F
.77403 .42161 m .77405 .42159 L .77401 .42157 L F
.77396 .42153 m .77403 .42155 L .77394 .4214 L F
.82 .744 .78 r
.77426 .41933 m .77362 .41946 L .77533 .41716 L F
.77362 .41946 m .77292 .41959 L .7736 .41891 L F
.77362 .41946 m .7736 .41891 L .77533 .41716 L F
.486 .677 .949 r
.77405 .42159 m .77597 .42041 L .77555 .42029 L F
.77405 .42159 m .77555 .42029 L .77292 .41959 L F
.77444 .42252 m .77482 .42199 L .77398 .42164 L F
.454 .577 .888 r
.77112 .42174 m .77398 .42164 L .77186 .42085 L F
.192 .309 .755 r
.2841 .5693 m .28346 .56434 L .28157 .5665 L F
.2841 .5693 m .2852 .56866 L .28346 .56434 L F
.4 .854 .801 r
.28582 .56859 m .2852 .56866 L .2841 .5693 L F
.661 .634 .812 r
.7961 .42113 m .79481 .42537 L .79379 .42198 L F
.7961 .42113 m .79728 .42426 L .79481 .42537 L F
0 0 0 r
.26813 .60729 m .27028 .60416 L .26875 .6054 L F
.424 0 .005 r
.48886 .62865 m .49139 .62853 L .48943 .62751 L F
.48943 .62751 m .49139 .62853 L .48886 .62865 L F
.499 .454 .738 r
.50572 .59971 m .50837 .59887 L .50749 .59581 L F
.686 .632 .789 r
.33442 .5568 m .33073 .5546 L .33306 .55342 L F
.555 .591 .845 r
.33662 .55616 m .33442 .5568 L .33306 .55342 L F
.476 .31 .576 r
.33662 .55616 m .33666 .55868 L .33442 .5568 L F
.183 .715 .747 r
.22455 .55096 m .22006 .55173 L .22222 .55185 L F
.026 0 .336 r
.46432 .6572 m .46568 .65858 L .46612 .65599 L F
.46432 .6572 m .46393 .66016 L .46568 .65858 L F
.938 .573 .185 r
.50798 .59155 m .50879 .59063 L .50735 .58962 L F
.50798 .59155 m .50914 .59239 L .50879 .59063 L F
.544 .258 .432 r
.30139 .62358 m .30033 .62633 L .29808 .62649 L F
.498 .296 .536 r
.30386 .62062 m .30368 .62318 L .30139 .62358 L F
.562 .277 .441 r
.30357 .62566 m .30139 .62358 L .30368 .62318 L F
.30357 .62566 m .30033 .62633 L .30139 .62358 L F
.661 .437 .569 r
.47873 .61074 m .48151 .60807 L .47917 .60887 L F
.746 .754 .859 r
.55239 .59847 m .55581 .59843 L .55514 .59639 L F
.681 .81 .944 r
.55514 .59639 m .55581 .59843 L .55885 .59656 L F
.328 .606 .949 r
.20313 .63919 m .20443 .63941 L .19886 .6369 L F
.559 .457 .695 r
.45393 .66745 m .45469 .66102 L .45222 .66283 L F
.245 .052 .409 r
.14787 .57529 m .14929 .57669 L .15009 .57433 L F
.14787 .57529 m .1479 .57756 L .14929 .57669 L F
.45 .207 .453 r
.47253 .62052 m .47214 .62341 L .47022 .62321 L F
.373 .114 .387 r
.4747 .61977 m .47214 .62341 L .47253 .62052 L F
.666 .81 .953 r
.81512 .44493 m .81672 .44232 L .81402 .44316 L F
.81512 .44493 m .81791 .44376 L .81672 .44232 L F
.557 .268 .433 r
.29772 .62878 m .29567 .62695 L .29808 .62649 L F
.29772 .62878 m .29519 .62913 L .29567 .62695 L F
.614 .424 .601 r
.33624 .56571 m .33357 .56839 L .33343 .56595 L F
.33624 .56571 m .33675 .56873 L .33357 .56839 L F
.596 .445 .647 r
.33865 .56252 m .33968 .56524 L .33624 .56571 L F
.317 .222 .587 r
.33862 .56761 m .33624 .56571 L .33968 .56524 L F
.33862 .56761 m .33675 .56873 L .33624 .56571 L F
.424 .133 .363 r
.30901 .61738 m .30615 .6201 L .30648 .61761 L F
.757 .752 .848 r
.79143 .44027 m .79501 .44075 L .7941 .43765 L F
.754 .75 .849 r
.7941 .43765 m .79501 .44075 L .79791 .43818 L F
.766 .56 .619 r
.4922 .60215 m .49617 .59933 L .49238 .59896 L F
.4922 .60215 m .49707 .6024 L .49617 .59933 L F
.329 .297 .67 r
.49846 .60133 m .49617 .59933 L .49876 .59924 L F
.49846 .60133 m .49707 .6024 L .49617 .59933 L F
.49846 .60133 m .49617 .59933 L .49876 .59924 L F
.49846 .60133 m .49707 .6024 L .49617 .59933 L F
.657 .806 .955 r
.50254 .63387 m .50416 .63592 L .50132 .63455 L F
.892 .53 .349 r
.50132 .63455 m .50416 .63592 L .50242 .63726 L F
.389 .668 .97 r
.50254 .63387 m .50521 .63447 L .50416 .63592 L F
.626 .912 .627 r
.50416 .63592 m .50521 .63447 L .50242 .63726 L F
.922 .818 .727 r
.56076 .54952 m .56405 .54738 L .56246 .54596 L F
.56076 .54952 m .5625 .55062 L .56405 .54738 L F
.528 .826 .999 r
.83744 .39243 m .83575 .39432 L .83484 .3937 L F
.83744 .39243 m .83877 .39366 L .83575 .39432 L F
.281 .039 .358 r
.15042 .57209 m .15168 .57368 L .15222 .5717 L F
.15042 .57209 m .15009 .57433 L .15168 .57368 L F
.889 .64 .556 r
.55751 .53472 m .55482 .53132 L .55764 .53225 L F
.565 .78 .98 r
.21574 .62308 m .2115 .62227 L .21378 .6219 L F
.202 .544 .929 r
.21604 .62177 m .21574 .62308 L .21378 .6219 L F
.21604 .62177 m .21753 .6234 L .21574 .62308 L F
.57 .428 .649 r
.30595 .57189 m .30869 .57383 L .30823 .57133 L F
.30595 .57189 m .30616 .57449 L .30869 .57383 L F
0 0 .134 r
.30654 .57352 m .30595 .57189 L .30823 .57133 L F
.30654 .57352 m .30499 .57583 L .30595 .57189 L F
.191 .275 .722 r
.16658 .58294 m .16639 .58701 L .16508 .58342 L F
.16658 .58294 m .16764 .5866 L .16639 .58701 L F
.159 .173 .624 r
.16764 .5866 m .16811 .58907 L .16639 .58701 L F
.558 .509 .756 r
.53974 .59896 m .53625 .59571 L .53744 .59909 L F
.814 .735 .777 r
.56525 .59836 m .5689 .59659 L .56748 .59537 L F
.56525 .59836 m .5668 .59946 L .5689 .59659 L F
.712 .691 .828 r
.5689 .59659 m .56979 .59218 L .56748 .59537 L F
.5689 .59659 m .57092 .59447 L .56979 .59218 L F
0 .474 .73 r
.5689 .59659 m .57327 .59751 L .57092 .59447 L F
.013 0 0 r
.19585 .56242 m .19342 .56385 L .19179 .56418 L F
0 0 0 r
.19834 .5617 m .19342 .56385 L .19585 .56242 L F
.934 .821 .709 r
.55362 .56205 m .55136 .56191 L .55287 .55871 L F
.938 .779 .659 r
.55362 .56205 m .55066 .56443 L .55136 .56191 L F
.55362 .56205 m .55239 .56563 L .55066 .56443 L F
.69 .63 .785 r
.18416 .61039 m .18018 .60829 L .18238 .60776 L F
.779 .303 .105 r
.18238 .60776 m .18657 .61048 L .18416 .61039 L F
.339 .28 .644 r
.14174 .59009 m .14381 .59215 L .14339 .58942 L F
.14174 .59009 m .142 .59382 L .14381 .59215 L F
.065 .622 .809 r
.25272 .53577 m .25474 .53575 L .25667 .5361 L F
.126 .672 .815 r
.25474 .53575 m .25892 .53585 L .25667 .5361 L F
.013 .546 .85 r
.31542 .54436 m .31741 .54474 L .31887 .54539 L F
.325 .751 .973 r
.31741 .54474 m .32143 .54516 L .31887 .54539 L F
.407 .53 .869 r
.76922 .42192 m .76999 .41914 L .76727 .41906 L F
.76922 .42192 m .77112 .42174 L .76999 .41914 L F
.886 .721 .672 r
.21171 .74204 m .21326 .74549 L .21389 .74291 L F
.468 0 0 r
.54664 .52276 m .54489 .52243 L .54396 .52209 L F
.599 .087 0 r
.54664 .52276 m .54753 .52403 L .54489 .52243 L F
.54664 .52276 m .54882 .52514 L .54753 .52403 L F
.725 .194 0 r
.50576 .55856 m .50189 .55574 L .50395 .55647 L F
.576 .376 .574 r
.24307 .68078 m .24697 .67819 L .24242 .6774 L F
.737 .901 .952 r
.84316 .40075 m .84001 .40084 L .84076 .40295 L F
.496 .282 .517 r
.3139 .60845 m .31367 .61106 L .31134 .61157 L F
.466 .306 .579 r
.31602 .6051 m .31602 .60788 L .3139 .60845 L F
.518 .333 .568 r
.31602 .60788 m .31367 .61106 L .3139 .60845 L F
.387 .2 .501 r
.23356 .71394 m .23169 .71212 L .23407 .7119 L F
.23307 .71346 m .23148 .71473 L .23169 .71212 L F
.23356 .71394 m .23257 .71432 L .23307 .71346 L F
.23257 .71432 m .23148 .71473 L .23307 .71346 L F
.785 .461 .439 r
.22999 .71331 m .23407 .7119 L .23169 .71212 L F
.22999 .71331 m .23165 .71458 L .23407 .7119 L F
.843 .99 .854 r
.23101 .7148 m .23148 .71473 L .23255 .71432 L F
.23245 .71431 m .23255 .71432 L .23336 .714 L F
.23101 .7148 m .23255 .71432 L .23245 .71431 L F
.785 .461 .439 r
.23165 .71458 m .23245 .71431 L .23407 .7119 L F
.709 .869 .462 r
.23422 .7115 m .23243 .71431 L .23457 .71058 L F
.785 .461 .439 r
.23165 .71458 m .23206 .71489 L .23245 .71431 L F
.709 .869 .462 r
.23243 .71431 m .23206 .71489 L .23236 .71437 L F
.2334 .7129 m .23245 .71431 L .23422 .7115 L F
.23245 .71431 m .23206 .71489 L .23243 .71431 L F
.23245 .71431 m .23243 .71431 L .23422 .7115 L F
.843 .99 .854 r
.23336 .714 m .23255 .71432 L .23356 .71394 L F
.23255 .71432 m .23148 .71473 L .23257 .71432 L F
.23255 .71432 m .23257 .71432 L .23356 .71394 L F
.766 .912 .529 r
.23457 .71058 m .2324 .7143 L .23343 .71204 L F
.133 0 0 r
.23356 .71394 m .23215 .71457 L .23236 .71437 L F
.23247 .7143 m .23236 .71437 L .23244 .71431 L F
.843 .99 .854 r
.23247 .7143 m .23251 .71429 L .23336 .714 L F
.133 0 0 r
.23356 .71394 m .23236 .71437 L .23247 .7143 L F
.843 .99 .854 r
.23091 .71481 m .23101 .7148 L .23165 .71458 L F
.396 .241 .551 r
.23165 .71458 m .23091 .71481 L .23206 .71489 L F
.22999 .71331 m .23091 .71481 L .23165 .71458 L F
.843 .99 .854 r
.23091 .71481 m .23165 .71458 L .23251 .71429 L F
.23091 .71481 m .23251 .71429 L .23247 .7143 L F
.133 0 0 r
.23244 .71431 m .23231 .71442 L .23091 .71481 L F
.802 .921 .917 r
.23228 .71443 m .23206 .71489 L .23091 .71481 L F
.133 0 0 r
.23231 .71442 m .23215 .71457 L .23091 .71481 L F
.802 .921 .917 r
.23343 .71204 m .23228 .71443 L .23091 .71481 L F
.766 .912 .529 r
.2324 .7143 m .23236 .71437 L .23234 .71431 L F
.23236 .71437 m .23206 .71489 L .23228 .71443 L F
.23236 .71437 m .23228 .71443 L .23234 .71431 L F
.2324 .7143 m .23234 .71431 L .23343 .71204 L F
.133 0 0 r
.23356 .71394 m .2343 .71415 L .23215 .71457 L F
.709 .869 .462 r
.23243 .71431 m .23243 .71431 L .2324 .7143 L F
.23243 .71431 m .23236 .71437 L .2324 .7143 L F
.23243 .71431 m .2324 .7143 L .23457 .71058 L F
.23407 .7119 m .2334 .7129 L .23422 .7115 L F
.175 0 0 r
.2378 .62651 m .24023 .62646 L .24151 .62598 L F
.225 .745 .759 r
.24151 .62598 m .24222 .62568 L .24393 .62539 L F
.269 .758 .673 r
.24151 .62598 m .24023 .62646 L .24222 .62568 L F
.534 .347 .573 r
.57502 .59905 m .57482 .59621 L .57236 .5993 L F
.57502 .59905 m .57482 .59621 L .57236 .5993 L F
.48 .275 .523 r
.30615 .6201 m .30368 .62318 L .30386 .62062 L F
.051 0 0 r
.17829 .57439 m .17533 .57626 L .17653 .57502 L F
.456 .159 .372 r
.29009 .58753 m .29244 .58747 L .29331 .58674 L F
.29244 .58747 m .29009 .58753 L .29135 .58511 L F
.29244 .58747 m .28965 .58944 L .29009 .58753 L F
.29009 .58753 m .28965 .58944 L .29244 .58747 L F
.808 .65 .687 r
.24824 .67435 m .25096 .67021 L .24699 .66902 L F
.467 .826 .995 r
.25096 .67021 m .25169 .66889 L .2506 .66801 L F
.25096 .67021 m .25388 .6698 L .25169 .66889 L F
.372 .609 .942 r
.45623 .63487 m .45402 .63399 L .45277 .63343 L F
.615 .738 .934 r
.81113 .42638 m .80738 .42545 L .81003 .4247 L F
.662 .751 .916 r
.81241 .42371 m .81113 .42638 L .81003 .4247 L F
.81241 .42371 m .81372 .4253 L .81113 .42638 L F
.58 .21 .305 r
.27933 .63866 m .27772 .64112 L .27504 .64108 L F
.539 .191 .326 r
.28166 .63847 m .27772 .64112 L .27933 .63866 L F
.873 .556 .448 r
.57165 .5759 m .57319 .57493 L .56974 .57405 L F
.57165 .5759 m .57341 .57723 L .57319 .57493 L F
.535 .334 .554 r
.32819 .59214 m .32617 .58995 L .32861 .59008 L F
.32819 .59214 m .32577 .59269 L .32617 .58995 L F
.283 .771 .909 r
.21022 .6481 m .21453 .64808 L .21272 .64771 L F
.21272 .64771 m .21453 .64808 L .21022 .6481 L F
.641 .943 .957 r
.21499 .64665 m .21453 .64808 L .21272 .64771 L F
.21272 .64771 m .21453 .64808 L .21499 .64665 L F
.961 .844 .681 r
.56651 .53407 m .56868 .53274 L .56755 .53058 L F
.56651 .53407 m .56792 .53516 L .56868 .53274 L F
.515 .309 .538 r
.82968 .42546 m .83023 .4277 L .82724 .42851 L F
.687 .511 .643 r
.83153 .42242 m .83023 .4277 L .82968 .42546 L F
.34 0 0 r
.28305 .55891 m .27897 .55676 L .28096 .55937 L F
.48 .428 .722 r
.28096 .55937 m .2835 .56176 L .28305 .55891 L F
.096 .637 .848 r
.24618 .64227 m .24808 .64268 L .25119 .6427 L F
.711 .581 .708 r
.33357 .56839 m .33093 .56906 L .33343 .56595 L F
.577 .469 .695 r
.33669 .57172 m .33357 .56839 L .33675 .56873 L F
.33669 .57172 m .335 .57317 L .33357 .56839 L F
.253 0 .01 r
.18532 .54966 m .18754 .5491 L .18928 .54693 L F
.197 0 0 r
.18928 .54693 m .18969 .54846 L .19146 .54654 L F
.18928 .54693 m .18754 .5491 L .18969 .54846 L F
.216 0 0 r
.18928 .54693 m .19146 .54654 L .19171 .54637 L F
.402 .525 .867 r
.77502 .42458 m .77669 .42795 L .77868 .42766 L F
.913 .634 .141 r
.53158 .58773 m .53215 .59019 L .53117 .58626 L F
.338 .375 .753 r
.53117 .58626 m .53215 .59019 L .53354 .5887 L F
.332 .366 .747 r
.53215 .59019 m .53471 .5921 L .53354 .5887 L F
.756 .835 .913 r
.83079 .40278 m .8342 .4021 L .8339 .40107 L F
.645 .745 .922 r
.8342 .4021 m .83608 .3996 L .8339 .40107 L F
.8342 .4021 m .83692 .40133 L .83608 .3996 L F
.7 .424 .502 r
.24698 .5514 m .24746 .55323 L .24509 .55317 L F
.255 .157 .546 r
.24888 .55216 m .24746 .55323 L .24698 .5514 L F
.882 .476 .038 r
.52686 .56842 m .52795 .57112 L .52886 .57156 L F
.773 .382 .314 r
.52693 .5734 m .52886 .57156 L .52795 .57112 L F
.52693 .5734 m .53061 .57418 L .52886 .57156 L F
.313 0 .167 r
.15222 .5717 m .15446 .57129 L .1558 .56861 L F
.204 0 .112 r
.1558 .56861 m .15657 .57038 L .15765 .56759 L F
.1558 .56861 m .15446 .57129 L .15657 .57038 L F
.283 .022 .33 r
.442 .65713 m .44408 .65685 L .44462 .65392 L F
.766 .691 .78 r
.44695 .65103 m .44462 .65392 L .44306 .65064 L F
0 0 0 r
.44638 .65264 m .44462 .65392 L .44695 .65103 L F
.284 .428 .83 r
.44306 .65064 m .44462 .65392 L .44638 .65264 L F
.627 .321 .431 r
.447 .65615 m .44408 .65685 L .44462 .65392 L F
.218 .3 .735 r
.44638 .65264 m .447 .65615 L .44462 .65392 L F
.733 .525 .611 r
.81624 .42206 m .81864 .4191 L .81888 .42092 L F
.758 .8 .887 r
.818 .41615 m .81864 .4191 L .81496 .4184 L F
.834 .681 .693 r
.81496 .4184 m .81864 .4191 L .81624 .42206 L F
.77 .807 .883 r
.82129 .41611 m .81864 .4191 L .818 .41615 L F
0 .433 .737 r
.76621 .4148 m .76963 .41589 L .76771 .41536 L F
.317 .335 .722 r
.50749 .59581 m .51137 .5985 L .51057 .59677 L F
.277 .587 .945 r
.25941 .54825 m .25973 .54683 L .25766 .54719 L F
.25941 .54825 m .26085 .54866 L .25973 .54683 L F
.353 .474 .843 r
.25941 .54825 m .26208 .54924 L .26085 .54866 L F
.464 .251 .504 r
.29507 .63174 m .29314 .62978 L .29519 .62913 L F
.29507 .63174 m .29286 .63229 L .29314 .62978 L F
.598 .409 .597 r
.45659 .62349 m .45933 .62339 L .45898 .61996 L F
.482 .25 .484 r
.45933 .62339 m .46259 .61943 L .45898 .61996 L F
.845 .644 .63 r
.56133 .55268 m .5599 .55599 L .56306 .55659 L F
.843 .63 .614 r
.5599 .55599 m .56291 .55918 L .56306 .55659 L F
.834 .632 .63 r
.57457 .58599 m .57803 .58396 L .57496 .58342 L F
.57457 .58599 m .57741 .58634 L .57803 .58396 L F
.361 .39 .756 r
.16872 .59026 m .16918 .59359 L .16756 .59317 L F
.424 .74 .992 r
.29573 .53776 m .29541 .53891 L .29379 .53767 L F
.29573 .53776 m .29776 .53872 L .29541 .53891 L F
.191 .707 .886 r
.23444 .54992 m .23266 .54956 L .23044 .54967 L F
.195 .709 .888 r
.23664 .54981 m .23266 .54956 L .23444 .54992 L F
.584 .818 .988 r
.20562 .63892 m .20923 .63927 L .20766 .63811 L F
.384 .613 .941 r
.20923 .63927 m .20991 .6375 L .20766 .63811 L F
.20923 .63927 m .21133 .63928 L .20991 .6375 L F
.649 .294 .357 r
.51164 .55688 m .51397 .55874 L .51443 .55644 L F
.701 .344 .368 r
.51443 .55644 m .51766 .55854 L .51728 .55637 L F
.51443 .55644 m .51397 .55874 L .51766 .55854 L F
.236 0 0 r
.29405 .58744 m .29331 .58674 L .29244 .58747 L F
.29405 .58744 m .29579 .58663 L .29331 .58674 L F
.727 .665 .788 r
.816 .42456 m .81973 .42505 L .81715 .42737 L F
.392 0 .144 r
.20217 .5597 m .20035 .56176 L .19834 .5617 L F
.221 0 .02 r
.20254 .56106 m .20217 .5597 L .20475 .55996 L F
.20254 .56106 m .20035 .56176 L .20217 .5597 L F
.497 .819 1 r
.42056 .6478 m .42142 .64717 L .42436 .64802 L F
.785 .308 .097 r
.42455 .6508 m .42056 .6478 L .42436 .64802 L F
.348 .791 .96 r
.42142 .64717 m .42712 .64745 L .42436 .64802 L F
.738 .584 .683 r
.42712 .64745 m .42455 .6508 L .42436 .64802 L F
0 0 .501 r
.4999 .58696 m .50126 .58722 L .49911 .58334 L F
0 .065 .569 r
.4999 .58696 m .50106 .58785 L .50126 .58722 L F
.4999 .58696 m .50221 .58907 L .50106 .58785 L F
.299 0 0 r
.24098 .54942 m .23892 .54998 L .23664 .54981 L F
.339 0 0 r
.24287 .54975 m .23892 .54998 L .24098 .54942 L F
.535 .449 .705 r
.31367 .61106 m .31191 .61467 L .31134 .61157 L F
.516 .086 .162 r
.54398 .5145 m .54613 .51559 L .54738 .5137 L F
.586 .161 .203 r
.54738 .5137 m .54993 .51527 L .55002 .51376 L F
.54738 .5137 m .54613 .51559 L .54993 .51527 L F
.407 .442 .785 r
.17726 .60086 m .176 .60285 L .17568 .60125 L F
.633 .567 .763 r
.17895 .60357 m .176 .60285 L .17726 .60086 L F
.966 .705 .488 r
.17535 .58893 m .17682 .5903 L .17462 .58902 L F
.937 .639 .45 r
.5298 .52295 m .52845 .52341 L .52908 .52235 L F
.5298 .52295 m .53028 .52555 L .52845 .52341 L F
.694 .948 .672 r
.53259 .51999 m .5298 .52295 L .53111 .5209 L F
.689 .968 .93 r
.5298 .52295 m .52908 .52235 L .53111 .5209 L F
.524 .262 .46 r
.31191 .61467 m .31155 .61704 L .30901 .61738 L F
.535 .449 .705 r
.31367 .61106 m .31415 .6145 L .31191 .61467 L F
.423 .175 .431 r
.31369 .61641 m .31191 .61467 L .31415 .6145 L F
.31369 .61641 m .31155 .61704 L .31191 .61467 L F
.493 0 0 r
.21347 .73272 m .21117 .73153 L .21242 .73259 L F
.889 .621 .527 r
.21347 .73272 m .21197 .73072 L .21242 .73259 L F
.826 .919 .899 r
.2108 .73407 m .21347 .73272 L .21242 .73259 L F
.739 .927 .953 r
.21347 .73272 m .21342 .73188 L .21242 .73259 L F
.614 .43 .609 r
.51039 .54736 m .51135 .54991 L .513 .54727 L F
.821 .74 .774 r
.79623 .41065 m .79594 .40893 L .79612 .40826 L F
.669 .158 .016 r
.79644 .40703 m .79612 .40826 L .79359 .4064 L F
0 .282 .783 r
.79359 .4064 m .79612 .40826 L .7956 .40685 L F
.821 .74 .774 r
.79594 .40893 m .7956 .40685 L .79612 .40826 L F
.669 .158 .016 r
.79707 .40717 m .79612 .40826 L .79644 .40703 L F
.901 .493 .207 r
.79707 .40717 m .79764 .40912 L .79612 .40826 L F
0 0 0 r
.46259 .61943 m .46376 .61927 L .46513 .61743 L F
.613 .181 .197 r
.46513 .61743 m .46376 .61927 L .46753 .61932 L F
.555 .223 .362 r
.46513 .61743 m .46753 .61932 L .46765 .61734 L F
.028 .052 .549 r
.14316 .59606 m .14381 .59215 L .142 .59382 L F
.14316 .59606 m .14405 .59581 L .14381 .59215 L F
.681 .277 .274 r
.79871 .40253 m .80205 .40121 L .79802 .4008 L F
.79871 .40253 m .80234 .40268 L .80205 .40121 L F
.628 .24 .289 r
.80234 .40268 m .80501 .40303 L .80205 .40121 L F
.603 .284 .403 r
.80205 .40121 m .80501 .40303 L .80555 .40058 L F
.623 .402 .561 r
.46765 .61734 m .47039 .61723 L .4705 .61426 L F
.637 .414 .562 r
.4705 .61426 m .47366 .61661 L .47352 .61416 L F
.4705 .61426 m .47039 .61723 L .47366 .61661 L F
.611 .887 .99 r
.27421 .5825 m .27359 .58412 L .27592 .58329 L F
0 0 .097 r
.27421 .5825 m .27359 .58412 L .27442 .57997 L F
.27442 .57997 m .27359 .58412 L .27421 .5825 L F
.649 .922 .976 r
.27215 .58358 m .27359 .58412 L .27421 .5825 L F
.502 .26 .48 r
.29052 .63279 m .29025 .6351 L .28796 .63533 L F
.57 .318 .495 r
.29052 .63279 m .29269 .63495 L .29025 .6351 L F
.513 .319 .555 r
.29286 .63229 m .29269 .63495 L .29052 .63279 L F
.381 .135 .411 r
.47159 .62536 m .47022 .62321 L .47214 .62341 L F
.47159 .62536 m .46939 .6261 L .47022 .62321 L F
.303 .761 .952 r
.52378 .52284 m .52252 .52222 L .52005 .5225 L F
.52005 .5225 m .52252 .52222 L .52378 .52284 L F
.585 .911 .977 r
.52378 .52284 m .52494 .52132 L .52252 .52222 L F
.52252 .52222 m .52494 .52132 L .52378 .52284 L F
.335 .216 .565 r
.442 .65713 m .44392 .65899 L .44408 .65685 L F
0 0 .496 r
.26887 .64662 m .26755 .64522 L .26906 .64413 L F
0 0 0 r
.26952 .6465 m .26887 .64662 L .27159 .64525 L F
0 0 .496 r
.26887 .64662 m .26819 .64794 L .26792 .6468 L F
.538 .816 .997 r
.26412 .64752 m .26819 .64794 L .26538 .64871 L F
.659 .972 .86 r
.26538 .64871 m .26819 .64794 L .26887 .64662 L F
0 0 0 r
.26684 .64811 m .26887 .64662 L .26952 .6465 L F
0 0 .496 r
.26887 .64662 m .26792 .6468 L .26755 .64522 L F
.228 0 0 r
.48044 .61482 m .48289 .61415 L .47866 .61336 L F
.48044 .61482 m .48168 .61552 L .48289 .61415 L F
.48289 .61415 m .48168 .61552 L .48044 .61482 L F
.45 .269 .543 r
.28266 .60409 m .28503 .60081 L .28384 .60228 L F
.684 .903 .974 r
.82903 .43744 m .82471 .43812 L .82569 .4393 L F
.493 .754 .988 r
.30614 .53969 m .30548 .54144 L .30392 .54011 L F
.30614 .53969 m .30761 .54101 L .30548 .54144 L F
.319 .067 .366 r
.49707 .6024 m .49638 .60466 L .49442 .60517 L F
0 0 .264 r
.49546 .60626 m .49442 .60517 L .49638 .60466 L F
.49546 .60626 m .49397 .60794 L .49442 .60517 L F
.856 .983 .855 r
.83504 .43479 m .83714 .43108 L .83429 .4338 L F
.83504 .43479 m .83778 .43199 L .83714 .43108 L F
.109 .534 .913 r
.19886 .6369 m .19904 .63579 L .19724 .63553 L F
.235 .151 .552 r
.34079 .56167 m .33968 .56524 L .33865 .56252 L F
.623 .265 .342 r
.20968 .73191 m .21242 .73259 L .21117 .73153 L F
0 0 .271 r
.49729 .5743 m .49835 .5753 L .49919 .57503 L F
.49729 .5743 m .49698 .57741 L .49835 .5753 L F
.519 .155 .29 r
.2704 .64185 m .27146 .64425 L .26906 .64413 L F
.2704 .64185 m .27289 .64159 L .27146 .64425 L F
.157 0 0 r
.47207 .56782 m .46965 .56879 L .47011 .56796 L F
.616 .825 .98 r
.47186 .56778 m .46965 .56879 L .47207 .56782 L F
.098 0 0 r
.47011 .56796 m .46965 .56879 L .46744 .5698 L F
.272 .377 .788 r
.46933 .56608 m .47207 .56782 L .47011 .56796 L F
.616 .825 .98 r
.4679 .56718 m .46965 .56879 L .47186 .56778 L F
.098 0 0 r
.46744 .5698 m .46965 .56879 L .46727 .56991 L F
.873 .713 .68 r
.5652 .52786 m .56882 .52928 L .56877 .52594 L F
.894 .599 .48 r
.5652 .52786 m .56755 .53058 L .56882 .52928 L F
.566 .403 .619 r
.32331 .59844 m .32077 .59644 L .32315 .59597 L F
.32331 .59844 m .32089 .59897 L .32077 .59644 L F
.175 .705 .848 r
.25892 .53585 m .26092 .53559 L .26292 .53585 L F
.185 .714 .842 r
.26092 .53559 m .26518 .53556 L .26292 .53585 L F
.842 .672 .672 r
.56308 .56202 m .5645 .56263 L .56291 .55918 L F
.839 .614 .597 r
.56308 .56202 m .56442 .56523 L .5645 .56263 L F
.515 .757 .984 r
.44999 .67054 m .45149 .6724 L .44843 .67238 L F
.607 .319 .454 r
.44843 .67238 m .45149 .6724 L .45077 .67467 L F
.098 .256 .738 r
.44843 .67238 m .45077 .67467 L .44941 .6715 L F
0 0 .056 r
.44941 .67149 m .44843 .67238 L .44941 .67151 L F
.44948 .67114 m .44843 .67238 L .44941 .67149 L F
.098 .256 .738 r
.44843 .67238 m .44941 .6715 L .44936 .6714 L F
.44843 .67238 m .44936 .6714 L .44963 .67132 L F
.943 .616 .384 r
.44936 .6714 m .44938 .67165 L .44776 .67244 L F
.44938 .67165 m .44958 .67441 L .44898 .67376 L F
.44938 .67165 m .44898 .67376 L .44776 .67244 L F
0 0 .056 r
.44999 .67054 m .44948 .67114 L .44963 .67132 L F
.44948 .67114 m .44941 .67151 L .44963 .67132 L F
.449 .649 .944 r
.81084 .4416 m .8115 .44326 L .81299 .44144 L F
.81299 .44144 m .8115 .44326 L .81402 .44316 L F
.874 .662 .612 r
.56725 .52239 m .56572 .52518 L .56877 .52594 L F
.873 .713 .68 r
.5652 .52786 m .56877 .52594 L .56572 .52518 L F
.44 .103 .296 r
.80501 .40303 m .80819 .40022 L .80555 .40058 L F
.737 .598 .702 r
.81888 .42092 m .82211 .42166 L .81973 .42505 L F
.894 .858 .798 r
.55961 .55168 m .56133 .55268 L .56076 .54952 L F
.945 .785 .653 r
.55831 .55507 m .56133 .55268 L .55961 .55168 L F
.55831 .55507 m .5599 .55599 L .56133 .55268 L F
.874 .848 .815 r
.56076 .54952 m .56133 .55268 L .5625 .55062 L F
.922 .919 .794 r
.83954 .42695 m .84065 .42822 L .84235 .4253 L F
.939 .965 .711 r
.83866 .4297 m .84065 .42822 L .83954 .42695 L F
.83866 .4297 m .83905 .43068 L .84065 .42822 L F
.52 .248 .442 r
.47352 .61416 m .47605 .61382 L .47645 .61146 L F
.53 .257 .445 r
.47645 .61146 m .47866 .61336 L .47873 .61074 L F
.47645 .61146 m .47605 .61382 L .47866 .61336 L F
.958 .945 .702 r
.54137 .58722 m .54051 .58635 L .54216 .58294 L F
.674 .251 .233 r
.53902 .58911 m .54137 .58722 L .53721 .58701 L F
.962 .941 .691 r
.53902 .58911 m .54051 .58635 L .54137 .58722 L F
.567 0 0 r
.50947 .56032 m .50817 .56028 L .50576 .55856 L F
.579 .004 0 r
.50947 .56032 m .51187 .56227 L .50817 .56028 L F
.633 .831 .977 r
.46727 .56991 m .4679 .56718 L .46527 .56784 L F
.46727 .56991 m .46965 .56879 L .4679 .56718 L F
.816 .62 .638 r
.56442 .56523 m .56423 .568 L .56814 .56852 L F
.826 .575 .56 r
.56438 .57051 m .56814 .56852 L .56423 .568 L F
.56438 .57051 m .56815 .57143 L .56814 .56852 L F
.535 .736 .967 r
.77992 .4208 m .77711 .41979 L .77892 .4191 L F
.618 .833 .982 r
.78239 .41838 m .77992 .4208 L .77892 .4191 L F
.78239 .41838 m .78353 .41975 L .77992 .4208 L F
.791 .961 .919 r
.83778 .43199 m .83905 .43068 L .83866 .4297 L F
.511 .519 .8 r
.14772 .60484 m .14978 .60449 L .14865 .60143 L F
.817 .843 .869 r
.27967 .58191 m .28227 .58088 L .28052 .58094 L F
.385 0 0 r
.28458 .58022 m .28052 .58094 L .28227 .58088 L F
.427 .302 .607 r
.28227 .58088 m .2847 .58297 L .28458 .58022 L F
.28227 .58088 m .28248 .58379 L .2847 .58297 L F
.385 0 0 r
.28458 .58022 m .28365 .58136 L .28052 .58094 L F
.415 .524 .86 r
.28052 .58094 m .28365 .58136 L .28215 .57909 L F
.28052 .58094 m .28215 .57909 L .28154 .57818 L F
.817 .843 .869 r
.27782 .58265 m .27967 .58191 L .28052 .58094 L F
.289 0 0 r
.45469 .66102 m .45836 .65997 L .45818 .66148 L F
.45469 .66102 m .45672 .66173 L .45836 .65997 L F
0 0 .034 r
.18491 .56976 m .18446 .56852 L .18635 .56796 L F
.18491 .56976 m .18332 .57106 L .18446 .56852 L F
.171 0 0 r
.22166 .64114 m .22576 .64154 L .22392 .64146 L F
.018 .589 .758 r
.22576 .64154 m .22598 .64144 L .22392 .64146 L F
.22576 .64154 m .22782 .6416 L .22598 .64144 L F
.576 .901 .983 r
.23851 .69386 m .24059 .69443 L .24242 .69348 L F
.519 .82 1 r
.44576 .65 m .44695 .65103 L .44306 .65064 L F
.965 .643 .265 r
.44576 .65 m .44638 .65264 L .44695 .65103 L F
.977 .715 .466 r
.55755 .54124 m .55588 .54028 L .55596 .53752 L F
.957 .74 .568 r
.55755 .54124 m .55546 .54294 L .55588 .54028 L F
.55755 .54124 m .5572 .5442 L .55546 .54294 L F
0 .253 .764 r
.49238 .54981 m .49258 .54857 L .49028 .54711 L F
.865 .621 .568 r
.55594 .52895 m .55268 .52812 L .55282 .52544 L F
.818 .642 .664 r
.55482 .53132 m .55268 .52812 L .55594 .52895 L F
.68 .44 .552 r
.33469 .57727 m .33226 .57515 L .33478 .57448 L F
.636 .57 .764 r
.33669 .57172 m .33478 .57448 L .335 .57317 L F
.595 .515 .734 r
.33753 .57389 m .33478 .57448 L .33669 .57172 L F
.541 .336 .551 r
.33753 .57389 m .33469 .57727 L .33478 .57448 L F
0 .235 .711 r
.20705 .74559 m .21014 .74782 L .20968 .74558 L F
.519 .329 .563 r
.54208 .5778 m .54478 .57995 L .54385 .57622 L F
.556 .251 .406 r
.28796 .63533 m .28658 .63842 L .28409 .63844 L F
.533 .227 .395 r
.2905 .63702 m .28796 .63533 L .29025 .6351 L F
.2905 .63702 m .28658 .63842 L .28796 .63533 L F
.456 .822 .994 r
.21924 .64156 m .21989 .64043 L .21766 .64086 L F
.21924 .64156 m .22166 .64114 L .21989 .64043 L F
.132 0 0 r
.81708 .39766 m .81979 .39733 L .82051 .39693 L F
.146 0 0 r
.81979 .39733 m .82298 .3965 L .82051 .39693 L F
.628 .599 .801 r
.33306 .55342 m .33073 .5546 L .3295 .55224 L F
.171 .686 .891 r
.26518 .53556 m .26715 .53545 L .26912 .53602 L F
.457 .84 .986 r
.26715 .53545 m .27143 .53561 L .26912 .53602 L F
.583 .377 .567 r
.33226 .57515 m .33284 .57794 L .32958 .57801 L F
.68 .44 .552 r
.33469 .57727 m .33284 .57794 L .33226 .57515 L F
.989 .732 .434 r
.26076 .64515 m .26181 .64571 L .26137 .64386 L F
.931 .924 .781 r
.26076 .64515 m .26181 .64571 L .26137 .64386 L F
.653 .44 .583 r
.33143 .58951 m .32819 .59214 L .32861 .59008 L F
.922 .919 .794 r
.83954 .42695 m .84235 .4253 L .84085 .42396 L F
0 0 0 r
.84235 .4253 m .84311 .42082 L .84085 .42396 L F
.576 .376 .574 r
.24307 .68078 m .24705 .68094 L .24697 .67819 L F
.733 .597 .704 r
.24174 .68386 m .24705 .68094 L .24307 .68078 L F
0 0 .428 r
.84367 .41504 m .84406 .41571 L .84242 .41322 L F
.982 .695 .379 r
.84291 .41736 m .84406 .41571 L .84367 .41504 L F
.84291 .41736 m .84416 .41863 L .84406 .41571 L F
.888 .464 .081 r
.50564 .58797 m .50615 .58682 L .50468 .58592 L F
.50564 .58797 m .50735 .58962 L .50615 .58682 L F
.853 .397 .038 r
.49919 .57503 m .50038 .57726 L .50213 .57811 L F
.852 .759 .76 r
.50038 .57726 m .50181 .58022 L .50213 .57811 L F
.964 .88 .701 r
.56651 .53407 m .56632 .53814 L .56792 .53516 L F
.657 .744 .914 r
.83287 .41802 m .8349 .41928 L .83127 .41886 L F
.735 .601 .707 r
.8349 .41928 m .8325 .42188 L .83127 .41886 L F
.72 .577 .693 r
.8349 .41928 m .83484 .42241 L .8325 .42188 L F
.998 .812 .467 r
.83441 .41588 m .8349 .41928 L .83287 .41802 L F
.022 0 0 r
.26425 .61452 m .26106 .61681 L .26308 .61631 L F
0 0 0 r
.2658 .61347 m .26425 .61452 L .26308 .61631 L F
0 .131 .676 r
.28237 .59654 m .28293 .59706 L .28313 .59659 L F
.28293 .59706 m .28426 .59831 L .28313 .59659 L F
.633 .894 .57 r
.28353 .59567 m .28352 .59568 L .28313 .59659 L F
0 .131 .676 r
.28237 .59654 m .28313 .59659 L .2806 .59768 L F
0 0 0 r
.28087 .59869 m .2806 .59768 L .28313 .59659 L F
.633 .894 .57 r
.28352 .59568 m .28087 .59869 L .28313 .59659 L F
.053 0 0 r
.53111 .5209 m .53514 .5194 L .53259 .51999 L F
.153 .692 .721 r
.83136 .3951 m .82947 .39552 L .82831 .39463 L F
.83136 .3951 m .83247 .39496 L .82947 .39552 L F
.601 .443 .64 r
.8325 .42188 m .83507 .42413 L .83153 .42242 L F
.594 .449 .655 r
.83507 .42413 m .83241 .42691 L .83153 .42242 L F
.633 .651 .85 r
.78384 .43385 m .78536 .42974 L .78289 .43025 L F
.78384 .43385 m .78678 .4329 L .78536 .42974 L F
.547 .516 .772 r
.78384 .43385 m .78761 .43759 L .78678 .4329 L F
.246 0 .017 r
.17031 .55821 m .17402 .55566 L .17203 .5565 L F
.319 .746 .972 r
.18469 .79662 m .18653 .7974 L .18711 .79654 L F
.18711 .79654 m .18653 .7974 L .18469 .79662 L F
.344 0 0 r
.23001 .53627 m .23225 .53668 L .2343 .53634 L F
.2 0 0 r
.2343 .53634 m .23225 .53668 L .23603 .53664 L F
0 0 0 r
.20441 .56017 m .20475 .55996 L .2062 .55843 L F
.20441 .56017 m .20254 .56106 L .20475 .55996 L F
.549 .321 .522 r
.3034 .57758 m .30589 .57725 L .30616 .57449 L F
.534 .313 .526 r
.30589 .57725 m .30869 .57383 L .30616 .57449 L F
.744 .706 .815 r
.83241 .42691 m .83372 .42868 L .83023 .4277 L F
.738 .704 .819 r
.83631 .42729 m .83372 .42868 L .83241 .42691 L F
.428 .202 .467 r
.3185 .6021 m .31819 .60452 L .31602 .6051 L F
.382 .204 .512 r
.31819 .60452 m .31602 .60788 L .31602 .6051 L F
.251 0 0 r
.20278 .5418 m .20455 .54214 L .20681 .54137 L F
.417 .856 .755 r
.20681 .54137 m .20662 .54107 L .20902 .54076 L F
.20681 .54137 m .20455 .54214 L .20662 .54107 L F
.525 .363 .604 r
.32089 .59897 m .32088 .60159 L .3185 .6021 L F
.454 .224 .475 r
.32046 .60394 m .3185 .6021 L .32088 .60159 L F
.32046 .60394 m .31819 .60452 L .3185 .6021 L F
.474 .31 .578 r
.45659 .62349 m .45899 .62558 L .45933 .62339 L F
.45659 .62349 m .45674 .62623 L .45899 .62558 L F
.757 .514 .565 r
.22306 .71576 m .22336 .71794 L .2262 .71748 L F
.94 .667 .495 r
.21323 .74828 m .21326 .74549 L .21128 .74735 L F
.806 .517 .501 r
.56021 .51834 m .56378 .51671 L .55998 .51645 L F
.56021 .51834 m .56402 .51922 L .56378 .51671 L F
.466 .611 .91 r
.18755 .62996 m .19177 .6326 L .19013 .63109 L F
.552 .752 .97 r
.19177 .6326 m .19268 .63055 L .19013 .63109 L F
.19177 .6326 m .1941 .63213 L .19268 .63055 L F
.363 .565 .914 r
.19177 .6326 m .19604 .63519 L .1941 .63213 L F
.907 .568 .094 r
.21197 .73072 m .21242 .73259 L .21119 .73003 L F
.576 .939 .814 r
.2135 .72917 m .21197 .73072 L .21119 .73003 L F
.665 .658 .834 r
.53625 .59571 m .53817 .59299 L .53471 .5921 L F
.559 .511 .758 r
.53625 .59571 m .53882 .59533 L .53817 .59299 L F
.558 .509 .756 r
.53974 .59896 m .53882 .59533 L .53625 .59571 L F
.721 .985 .803 r
.28653 .56706 m .2852 .56866 L .28582 .56859 L F
.705 .897 .525 r
.28582 .56859 m .28433 .57031 L .28653 .56706 L F
0 0 0 r
.19847 .54263 m .20278 .5418 L .20059 .54229 L F
.984 .731 .341 r
.51154 .60327 m .51262 .6021 L .51148 .60065 L F
.51154 .60327 m .51268 .60468 L .51262 .6021 L F
.675 .201 .12 r
.50041 .54975 m .50283 .55173 L .50422 .55031 L F
.849 .441 .265 r
.50422 .55031 m .50283 .55173 L .50466 .55204 L F
.737 .365 .346 r
.50422 .55031 m .50858 .55228 L .50734 .55076 L F
.50422 .55031 m .50466 .55204 L .50858 .55228 L F
.531 .84 .999 r
.27542 .53582 m .27598 .53421 L .27762 .53535 L F
.27542 .53582 m .27365 .53483 L .27598 .53421 L F
.256 .588 .947 r
.31565 .5428 m .31542 .54436 L .31402 .54302 L F
.31565 .5428 m .31741 .54474 L .31542 .54436 L F
0 .511 .828 r
.20839 .64915 m .20431 .64785 L .20671 .64777 L F
.20431 .64785 m .20839 .64915 L .20671 .64777 L F
.693 .823 .945 r
.20878 .64673 m .20839 .64915 L .20671 .64777 L F
.20878 .64673 m .21022 .6481 L .20839 .64915 L F
.20839 .64915 m .20878 .64673 L .20671 .64777 L F
.20839 .64915 m .21022 .6481 L .20878 .64673 L F
.776 .423 .387 r
.80091 .40993 m .79799 .41134 L .79764 .40912 L F
.80091 .40993 m .8015 .41195 L .79799 .41134 L F
.685 .369 .435 r
.80091 .40993 m .80372 .41213 L .8015 .41195 L F
.64 .396 .533 r
.80353 .40983 m .80372 .41213 L .80091 .40993 L F
.847 .681 .676 r
.52983 .58315 m .53305 .58376 L .53363 .58098 L F
.737 .901 .952 r
.84316 .40075 m .84236 .39955 L .84001 .40084 L F
.567 .85 .997 r
.30133 .53883 m .29776 .53872 L .30017 .53822 L F
.139 .44 .876 r
.30269 .53819 m .30133 .53883 L .30017 .53822 L F
.30269 .53819 m .30392 .54011 L .30133 .53883 L F
.917 .766 .678 r
.55526 .55276 m .55186 .55532 L .55389 .55152 L F
.55526 .55276 m .55386 .55657 L .55186 .55532 L F
.124 .384 .84 r
.20794 .61688 m .20771 .61842 L .20605 .61683 L F
.20794 .61688 m .20987 .61963 L .20771 .61842 L F
.78 .595 .65 r
.48401 .60778 m .48933 .61063 L .48721 .60432 L F
.324 .237 .601 r
.48933 .61063 m .49061 .60266 L .48721 .60432 L F
.859 .655 .626 r
.56402 .51922 m .56379 .52184 L .56725 .52239 L F
.879 .669 .614 r
.56369 .5244 m .56725 .52239 L .56379 .52184 L F
.56369 .5244 m .56572 .52518 L .56725 .52239 L F
.598 .594 .818 r
.2262 .71748 m .22675 .71649 L .22567 .71583 L F
.2262 .71748 m .22881 .71754 L .22774 .7147 L F
.666 .125 0 r
.22554 .71619 m .22775 .71711 L .22747 .71766 L F
.22775 .71711 m .22881 .71754 L .22851 .71757 L F
.22775 .71711 m .22851 .71757 L .22747 .71766 L F
.598 .594 .818 r
.22567 .71583 m .22774 .7147 L .22536 .71485 L F
.22675 .71649 m .22774 .7147 L .22567 .71583 L F
.523 .598 .871 r
.16156 .61103 m .16566 .61395 L .16318 .61072 L F
.459 .694 .968 r
.16566 .61395 m .16659 .61223 L .16318 .61072 L F
.16566 .61395 m .16753 .61354 L .16659 .61223 L F
.628 .873 .988 r
.2424 .55505 m .242 .55682 L .24419 .55589 L F
.2424 .55505 m .242 .55682 L .24419 .55589 L F
.728 .404 .433 r
.83484 .42241 m .83507 .42413 L .8325 .42188 L F
.6 .488 .698 r
.20968 .73191 m .2108 .73407 L .21242 .73259 L F
.464 .136 .324 r
.46699 .62693 m .46639 .62878 L .46389 .62916 L F
.579 .335 .511 r
.46939 .6261 m .46639 .62878 L .46699 .62693 L F
.324 .237 .601 r
.48933 .61063 m .49029 .60995 L .49061 .60266 L F
.49029 .60995 m .49117 .60934 L .49077 .60949 L F
0 0 0 r
.49223 .60914 m .49019 .61006 L .49106 .60942 L F
.49117 .60934 m .49019 .61006 L .49156 .60906 L F
.49161 .60867 m .49077 .60949 L .49029 .60995 L F
.49037 .60987 m .49029 .60995 L .48901 .61119 L F
.49161 .60867 m .49029 .60995 L .49037 .60987 L F
.49029 .60995 m .49019 .61006 L .49117 .60934 L F
.48933 .61063 m .49019 .61006 L .49029 .60995 L F
.49106 .60942 m .49019 .61006 L .49077 .60949 L F
.49205 .60901 m .49077 .60949 L .49161 .60867 L F
.49223 .60914 m .49077 .60949 L .49205 .60901 L F
.324 .237 .601 r
.49077 .60949 m .49156 .60906 L .49152 .60877 L F
.49117 .60934 m .49156 .60906 L .49077 .60949 L F
.49029 .60995 m .49152 .60877 L .49061 .60266 L F
0 0 0 r
.48901 .61119 m .49019 .61006 L .48892 .61128 L F
.49077 .60949 m .49019 .61006 L .48901 .61119 L F
.49223 .60914 m .49161 .60867 L .49397 .60794 L F
.264 .591 .948 r
.15791 .6079 m .15806 .60641 L .15606 .60601 L F
.062 .377 .842 r
.15791 .6079 m .16045 .60936 L .15806 .60641 L F
.693 .255 .206 r
.45672 .66173 m .46057 .66214 L .45836 .65997 L F
.204 .577 .941 r
.22537 .6266 m .22166 .62477 L .22387 .62505 L F
.273 .601 .952 r
.22584 .6253 m .22537 .6266 L .22387 .62505 L F
.569 .903 .98 r
.22768 .62568 m .22537 .6266 L .22584 .6253 L F
.22768 .62568 m .22537 .6266 L .22584 .6253 L F
.77 .619 .692 r
.81624 .42206 m .81973 .42505 L .816 .42456 L F
.81624 .42206 m .81888 .42092 L .81973 .42505 L F
.364 .8 .963 r
.21048 .55617 m .2092 .55603 L .20677 .55626 L F
.623 .138 .081 r
.21317 .55636 m .21231 .55775 L .2092 .55603 L F
.689 .213 .117 r
.21317 .55636 m .21517 .5583 L .21231 .55775 L F
.599 .258 .364 r
.21616 .55654 m .21517 .5583 L .21317 .55636 L F
.749 .466 .503 r
.45569 .65074 m .45935 .65328 L .4591 .65096 L F
.671 .724 .889 r
.77999 .43122 m .78101 .42746 L .77868 .42766 L F
.77999 .43122 m .78289 .43025 L .78101 .42746 L F
.605 .12 .076 r
.4922 .60215 m .49471 .60389 L .49707 .6024 L F
.588 .099 .06 r
.49854 .60392 m .49707 .6024 L .49846 .60133 L F
.363 .107 .385 r
.49854 .60392 m .49638 .60466 L .49707 .6024 L F
.588 .099 .06 r
.49854 .60392 m .49471 .60389 L .49707 .6024 L F
.363 .107 .385 r
.49854 .60392 m .49707 .6024 L .49846 .60133 L F
.653 .734 .909 r
.19994 .61475 m .19786 .61564 L .19611 .61384 L F
.459 .499 .813 r
.80374 .43778 m .80682 .43907 L .80636 .43699 L F
.65 .703 .885 r
.80009 .4368 m .80374 .43778 L .80291 .43595 L F
.595 .673 .894 r
.80291 .43595 m .80374 .43778 L .80636 .43699 L F
.239 .448 .863 r
.48562 .56648 m .48536 .56567 L .48458 .56416 L F
.48562 .56648 m .48811 .56782 L .48536 .56567 L F
.188 0 0 r
.23603 .53664 m .23846 .53651 L .24039 .5357 L F
.125 0 0 r
.23846 .53651 m .24258 .5355 L .24039 .5357 L F
.657 .102 0 r
.51067 .55744 m .51164 .55688 L .51025 .55531 L F
.51067 .55744 m .51397 .55874 L .51164 .55688 L F
.618 .427 .602 r
.332 .58017 m .32958 .57801 L .33284 .57794 L F
.332 .58017 m .3308 .58071 L .32958 .57801 L F
.573 .639 .878 r
.80738 .42545 m .8032 .42332 L .80676 .42351 L F
.61 .665 .879 r
.80923 .42285 m .80738 .42545 L .80676 .42351 L F
.80923 .42285 m .81003 .4247 L .80738 .42545 L F
.535 .356 .585 r
.49023 .60268 m .4922 .60215 L .49238 .59896 L F
.56 .109 .136 r
.21128 .74735 m .20968 .74558 L .21014 .74782 L F
.628 .745 .932 r
.33162 .5492 m .32928 .54996 L .32769 .5483 L F
.661 .565 .736 r
.33162 .5492 m .3295 .55224 L .32928 .54996 L F
.39 .793 .984 r
.54994 .59922 m .54859 .59854 L .54606 .59886 L F
.585 .921 .967 r
.55239 .59847 m .55118 .59777 L .54994 .59922 L F
.549 .869 .994 r
.55118 .59777 m .54859 .59854 L .54994 .59922 L F
.267 0 .017 r
.53633 .52275 m .53512 .52471 L .53276 .5252 L F
.028 0 0 r
.53861 .52391 m .53512 .52471 L .53633 .52275 L F
.517 .042 .068 r
.53886 .52296 m .53861 .52391 L .53633 .52275 L F
.567 .269 .422 r
.47413 .56143 m .47744 .56215 L .47614 .56074 L F
.43 .3 .602 r
.47614 .56074 m .4777 .56197 L .47843 .56119 L F
.55 .834 .998 r
.47828 .56255 m .47837 .56172 L .47744 .56225 L F
.47837 .56172 m .47839 .56149 L .47744 .56215 L F
.43 .3 .602 r
.4777 .56197 m .4781 .56229 L .47843 .56119 L F
.55 .834 .998 r
.47707 .56264 m .47744 .56225 L .4767 .56267 L F
.47828 .56255 m .47744 .56225 L .47707 .56264 L F
.47837 .56172 m .47744 .56215 L .4767 .56267 L F
.524 .061 .096 r
.47624 .5627 m .4781 .56229 L .47744 .56215 L F
.47624 .5627 m .47744 .56215 L .47413 .56143 L F
.567 .269 .422 r
.47744 .56215 m .4781 .56229 L .4777 .56197 L F
.47744 .56215 m .4777 .56197 L .47614 .56074 L F
.55 .834 .998 r
.4767 .56267 m .47843 .56119 L .47624 .5627 L F
.47839 .56149 m .47843 .56119 L .4767 .56267 L F
.47828 .56255 m .48054 .5618 L .47843 .56119 L F
.784 .555 .59 r
.25282 .54922 m .25284 .5527 L .24888 .55216 L F
.545 .906 .965 r
.25282 .54922 m .25569 .54837 L .25523 .54836 L F
.487 .292 .542 r
.25523 .54836 m .25284 .5527 L .25282 .54922 L F
.628 .452 .626 r
.22166 .72704 m .22481 .72716 L .22421 .72393 L F
.79 .827 .355 r
.22437 .72526 m .22328 .72595 L .22438 .72534 L F
0 0 0 r
.22421 .72393 m .22176 .72691 L .22328 .72595 L F
.79 .827 .355 r
.22415 .72298 m .22421 .72393 L .22328 .72595 L F
.22415 .72298 m .22328 .72595 L .22437 .72526 L F
0 0 0 r
.22176 .72691 m .22166 .72704 L .22328 .72595 L F
.309 .237 .611 r
.22619 .72614 m .22421 .72393 L .22714 .72401 L F
.22619 .72614 m .22481 .72716 L .22421 .72393 L F
0 0 .056 r
.22619 .72614 m .22714 .72401 L .22838 .72301 L F
.22619 .72614 m .22838 .72301 L .22829 .7258 L F
.778 .551 .591 r
.22438 .72534 m .22829 .7258 L .22835 .72371 L F
.22742 .72356 m .22835 .72371 L .22838 .72301 L F
.248 .716 .945 r
.22415 .72305 m .22714 .72401 L .22421 .72393 L F
.22453 .72311 m .22714 .72401 L .22415 .72305 L F
.591 .874 .994 r
.22838 .72301 m .22714 .72401 L .22415 .72298 L F
.778 .551 .591 r
.22438 .72534 m .22835 .72371 L .22742 .72356 L F
.248 .716 .945 r
.22415 .72298 m .22453 .72311 L .22415 .72305 L F
.426 .588 .909 r
.17522 .59796 m .17568 .60125 L .17449 .59673 L F
.17522 .59796 m .17726 .60086 L .17568 .60125 L F
.677 .642 .808 r
.80006 .42202 m .79728 .42426 L .7961 .42113 L F
.62 .283 .378 r
.55002 .51376 m .55259 .51575 L .55384 .51319 L F
.729 .406 .433 r
.55384 .51319 m .55619 .51586 L .55612 .51383 L F
.55384 .51319 m .55259 .51575 L .55619 .51586 L F
.569 .383 .59 r
.24476 .66988 m .24699 .66902 L .24449 .66967 L F
0 .323 .806 r
.46997 .56581 m .46933 .56608 L .46845 .56436 L F
.46997 .56581 m .47207 .56782 L .46933 .56608 L F
.738 .704 .819 r
.83631 .42729 m .83241 .42691 L .83507 .42413 L F
.925 .974 .741 r
.564 .53969 m .56262 .54386 L .56549 .5398 L F
.96 .932 .719 r
.56529 .53731 m .56549 .5398 L .56632 .53814 L F
.56529 .53731 m .564 .53969 L .56549 .5398 L F
.469 .657 .942 r
.17076 .61697 m .17312 .6197 L .17498 .61933 L F
.402 .563 .899 r
.18181 .62373 m .18389 .62661 L .18501 .62477 L F
.408 .57 .902 r
.18389 .62661 m .18574 .6266 L .18501 .62477 L F
.515 .555 .834 r
.18389 .62661 m .18755 .62996 L .18574 .6266 L F
.398 .488 .835 r
.17942 .60035 m .17895 .60357 L .17726 .60086 L F
.17942 .60035 m .18101 .6039 L .17895 .60357 L F
.491 .827 .999 r
.22782 .6416 m .23172 .64191 L .22974 .64128 L F
.015 .588 .749 r
.23172 .64191 m .23137 .64176 L .22974 .64128 L F
.23172 .64191 m .23405 .64197 L .23137 .64176 L F
.859 .629 .589 r
.4238 .64559 m .42614 .64682 L .4271 .64693 L F
.589 .741 .948 r
.4238 .64559 m .42648 .64682 L .42619 .64684 L F
.4238 .64559 m .42619 .64684 L .42142 .64717 L F
.859 .629 .589 r
.4238 .64559 m .42419 .64659 L .42614 .64682 L F
.348 .791 .96 r
.42142 .64717 m .42565 .64688 L .42712 .64745 L F
.42565 .64688 m .42619 .64684 L .4263 .64691 L F
.42565 .64688 m .4263 .64691 L .42712 .64745 L F
.738 .584 .683 r
.42712 .64745 m .42744 .65094 L .42455 .6508 L F
.3 .757 .953 r
.42712 .64745 m .42658 .64693 L .42917 .64722 L F
.781 .718 .793 r
.42711 .64698 m .42714 .64698 L .42712 .64695 L F
.42708 .64695 m .42712 .64695 L .4271 .64693 L F
0 .545 .759 r
.42917 .64722 m .42648 .64682 L .4271 .64693 L F
.798 .514 .507 r
.4271 .64693 m .42714 .64698 L .42917 .64722 L F
.18 .06 .47 r
.42917 .64722 m .42744 .65094 L .42712 .64745 L F
.42917 .64722 m .42937 .64988 L .42744 .65094 L F
.798 .514 .507 r
.42714 .64698 m .42937 .64988 L .42917 .64722 L F
.3 .757 .953 r
.42714 .64698 m .42648 .64682 L .4283 .6471 L F
.42658 .64693 m .42657 .64691 L .42704 .64697 L F
.42658 .64693 m .42704 .64697 L .42707 .64697 L F
.348 .791 .96 r
.42619 .64684 m .42654 .64689 L .42712 .64745 L F
.859 .629 .589 r
.42419 .64659 m .42543 .64981 L .42707 .64697 L F
.42654 .64689 m .42707 .64697 L .42708 .64695 L F
.42419 .64659 m .42707 .64697 L .42654 .64689 L F
.781 .718 .793 r
.42543 .64981 m .42712 .64695 L .42708 .64695 L F
.3 .757 .953 r
.42707 .64697 m .42704 .64697 L .42714 .64698 L F
.859 .629 .589 r
.42611 .64681 m .42708 .64695 L .4271 .64693 L F
.42419 .64659 m .42654 .64689 L .42611 .64681 L F
.42654 .64689 m .42708 .64695 L .42611 .64681 L F
.3 .757 .953 r
.42704 .64697 m .42648 .64682 L .42714 .64698 L F
.42657 .64691 m .42654 .64689 L .42704 .64697 L F
.42654 .64689 m .42648 .64682 L .42704 .64697 L F
.42658 .64693 m .4283 .6471 L .42917 .64722 L F
.781 .718 .793 r
.42543 .64981 m .42937 .64988 L .42714 .64698 L F
.42543 .64981 m .42714 .64698 L .42711 .64698 L F
.348 .791 .96 r
.42619 .64684 m .42648 .64682 L .42654 .64689 L F
.769 .98 .912 r
.55292 .59623 m .55239 .59847 L .55514 .59639 L F
.55292 .59623 m .55118 .59777 L .55239 .59847 L F
.359 0 .111 r
.54506 .51506 m .54398 .5145 L .54078 .5159 L F
.34 0 0 r
.54506 .51506 m .54613 .51559 L .54398 .5145 L F
.424 .133 .363 r
.30901 .61738 m .3084 .61968 L .30615 .6201 L F
.488 .191 .387 r
.3109 .61917 m .3084 .61968 L .30901 .61738 L F
.497 .19 .376 r
.31155 .61704 m .3109 .61917 L .30901 .61738 L F
0 0 0 r
.17297 .58945 m .17319 .58953 L .17462 .58902 L F
.484 .374 .653 r
.2353 .69381 m .23357 .69381 L .23501 .69332 L F
.795 .556 .576 r
.2353 .69381 m .23233 .69031 L .23357 .69381 L F
.512 .305 .535 r
.23821 .67504 m .24052 .67436 L .23845 .67219 L F
.496 .816 1 r
.42144 .64638 m .42142 .64717 L .42056 .6478 L F
.785 .308 .097 r
.42455 .6508 m .42298 .65069 L .42056 .6478 L F
.589 .741 .948 r
.4238 .64559 m .42142 .64717 L .42144 .64638 L F
.032 .202 .707 r
.42056 .6478 m .42298 .65069 L .42144 .64638 L F
.555 .575 .829 r
.42302 .66266 m .42456 .66611 L .42597 .66264 L F
.023 .596 .742 r
.24478 .53542 m .24883 .53552 L .2466 .53573 L F
.754 .75 .849 r
.7941 .43765 m .79791 .43818 L .79654 .43656 L F
.764 .796 .879 r
.79791 .43818 m .80009 .4368 L .79654 .43656 L F
.695 .594 .739 r
.27316 .55586 m .27673 .55688 L .27584 .55265 L F
.401 .665 .966 r
.16156 .61103 m .16195 .60924 L .16045 .60936 L F
.16156 .61103 m .16318 .61072 L .16195 .60924 L F
.574 .742 .956 r
.19904 .63579 m .20443 .63941 L .20432 .63747 L F
0 0 0 r
.26647 .61121 m .26739 .60985 L .26813 .60729 L F
0 0 .042 r
.26647 .61121 m .26688 .61238 L .26739 .60985 L F
.26647 .61121 m .2658 .61347 L .26688 .61238 L F
.949 .954 .72 r
.54478 .57995 m .54577 .57575 L .54385 .57622 L F
.46 .551 .862 r
.18574 .6266 m .18755 .62996 L .18876 .6278 L F
.399 .475 .822 r
.18755 .62996 m .19013 .63109 L .18876 .6278 L F
.202 0 0 r
.45665 .63871 m .45517 .64029 L .45278 .6408 L F
.763 .758 .245 r
.45623 .63487 m .45514 .63907 L .45563 .63683 L F
.999 .839 .524 r
.45563 .63683 m .45517 .64029 L .45665 .63871 L F
0 .517 .789 r
.22966 .62604 m .23157 .62663 L .22768 .62568 L F
.018 .591 .748 r
.23206 .62655 m .23157 .62663 L .22966 .62604 L F
.23206 .62655 m .23378 .62668 L .23157 .62663 L F
.426 .262 .554 r
.48886 .62865 m .48648 .63216 L .48641 .6295 L F
.48886 .62865 m .48942 .63198 L .48648 .63216 L F
.023 0 .444 r
.48641 .6295 m .48789 .63125 L .48886 .62865 L F
.48641 .6295 m .48648 .63216 L .48789 .63125 L F
0 0 .144 r
.45798 .62922 m .45899 .62558 L .45674 .62623 L F
.45798 .62922 m .45877 .62803 L .45899 .62558 L F
0 .199 .715 r
.45798 .62922 m .46017 .6313 L .45877 .62803 L F
0 0 .451 r
.27629 .5548 m .27673 .55688 L .27679 .55471 L F
.433 0 0 r
.27897 .55676 m .27679 .55471 L .27673 .55688 L F
.27897 .55676 m .2751 .55785 L .27679 .55471 L F
0 0 0 r
.27679 .55471 m .27563 .55635 L .27752 .55458 L F
.27679 .55471 m .27752 .55458 L .27861 .55356 L F
0 0 .451 r
.27584 .55265 m .27629 .5548 L .27679 .55471 L F
.159 0 0 r
.18316 .5503 m .18343 .55158 L .18532 .54966 L F
.18316 .5503 m .18124 .55222 L .18343 .55158 L F
.113 0 .055 r
.27442 .57997 m .27734 .57738 L .2754 .57806 L F
.552 .38 .602 r
.46313 .64118 m .4605 .64173 L .46291 .63856 L F
0 0 0 r
.46141 .64361 m .46313 .64118 L .4605 .64173 L F
.552 .38 .602 r
.46313 .64118 m .4605 .64173 L .46291 .63856 L F
.784 .571 .612 r
.46313 .64118 m .46141 .64361 L .4605 .64173 L F
.112 .027 .471 r
.25268 .66066 m .25231 .66322 L .25297 .66076 L F
.633 .42 .575 r
.79239 .39777 m .79228 .40033 L .79464 .39999 L F
.138 0 .096 r
.21774 .55619 m .21616 .55654 L .2194 .55643 L F
.406 .739 .992 r
.21999 .55493 m .2194 .55643 L .21879 .55275 L F
.21999 .55493 m .22181 .55633 L .2194 .55643 L F
.617 .939 .955 r
.21999 .55493 m .2194 .55643 L .22181 .55633 L F
.21999 .55493 m .21774 .55619 L .2194 .55643 L F
0 0 0 r
.48892 .61128 m .48713 .61241 L .48481 .6131 L F
.524 .881 .651 r
.49019 .61006 m .48713 .61241 L .48892 .61128 L F
.656 .737 .91 r
.83287 .41802 m .83127 .41886 L .82989 .4174 L F
.36 .498 .862 r
.20395 .61325 m .2041 .6165 L .20237 .61433 L F
.20395 .61325 m .20605 .61683 L .2041 .6165 L F
.793 .982 .713 r
.20632 .55714 m .2062 .55843 L .20677 .55626 L F
.20632 .55714 m .20677 .55626 L .2092 .55603 L F
.148 .395 .843 r
.26085 .54866 m .26235 .5475 L .25973 .54683 L F
.26085 .54866 m .26208 .54924 L .26235 .5475 L F
.501 .603 .887 r
.17914 .62239 m .18 .62402 L .1815 .62208 L F
.47 .558 .863 r
.1815 .62208 m .18 .62402 L .18181 .62373 L F
.593 .648 .874 r
.21924 .73013 m .21547 .72863 L .2177 .72936 L F
.645 .935 .967 r
.21342 .73188 m .21924 .73013 L .2177 .72936 L F
.891 .909 .831 r
.22166 .72704 m .21924 .73013 L .2177 .72936 L F
.466 0 0 r
.2177 .72936 m .21924 .73013 L .22213 .73212 L F
.626 .464 .644 r
.22166 .72704 m .22232 .7306 L .21924 .73013 L F
.586 .177 .232 r
.21924 .73013 m .22232 .7306 L .22213 .73212 L F
.645 .262 .305 r
.54993 .51527 m .55259 .51575 L .55002 .51376 L F
.467 .085 .231 r
.49061 .60266 m .4922 .60215 L .49023 .60268 L F
.588 .636 .865 r
.80519 .42031 m .8032 .42332 L .80259 .42092 L F
.80519 .42031 m .80676 .42351 L .8032 .42332 L F
.611 .887 .99 r
.27421 .5825 m .27289 .58122 L .27215 .58358 L F
.27421 .5825 m .27442 .57997 L .27289 .58122 L F
.577 .645 .881 r
.53217 .58519 m .53117 .58626 L .52983 .58315 L F
.338 .375 .753 r
.53117 .58626 m .53354 .5887 L .53362 .58588 L F
.677 .938 .965 r
.82986 .40198 m .83079 .40278 L .8339 .40107 L F
.891 .909 .831 r
.22166 .72704 m .2177 .72936 L .22006 .72923 L F
.487 .371 .647 r
.22378 .72926 m .22166 .72704 L .22481 .72716 L F
.22378 .72926 m .22232 .7306 L .22166 .72704 L F
.862 .756 .744 r
.22006 .72923 m .22328 .72595 L .22166 .72704 L F
.573 .105 0 r
.51331 .56348 m .51344 .56374 L .51187 .56227 L F
.51331 .56348 m .51454 .56504 L .51344 .56374 L F
.419 .601 .921 r
.78849 .41952 m .78779 .42156 L .78665 .41907 L F
.78849 .41952 m .79019 .4215 L .78779 .42156 L F
.889 .64 .556 r
.55751 .53472 m .55477 .53426 L .55482 .53132 L F
.934 .77 .655 r
.55596 .53752 m .55477 .53426 L .55751 .53472 L F
.329 0 0 r
.54011 .51663 m .54506 .51506 L .54078 .5159 L F
.637 .764 .94 r
.21781 .53678 m .21536 .53794 L .21374 .53633 L F
.289 .713 .971 r
.26087 .55673 m .2585 .5556 L .25662 .55571 L F
.241 0 0 r
.26298 .55583 m .2585 .5556 L .26087 .55673 L F
.732 .7 .82 r
.56979 .59218 m .57092 .59447 L .57359 .59273 L F
0 0 .041 r
.57327 .59751 m .57359 .59273 L .57092 .59447 L F
.51 .708 .96 r
.21195 .61998 m .2115 .62227 L .20987 .61963 L F
.21195 .61998 m .21378 .6219 L .2115 .62227 L F
.504 .258 .475 r
.45082 .65385 m .4519 .65375 L .4531 .65075 L F
.601 .359 .523 r
.4519 .65375 m .45545 .65309 L .4531 .65075 L F
.627 .357 .49 r
.4531 .65075 m .45545 .65309 L .45569 .65074 L F
.569 .383 .59 r
.24476 .66988 m .2465 .67147 L .24699 .66902 L F
.885 .462 .18 r
.24476 .66988 m .24824 .67435 L .2465 .67147 L F
.141 .332 .794 r
.16949 .61691 m .16884 .61352 L .16753 .61354 L F
.16949 .61691 m .17076 .61697 L .16884 .61352 L F
.309 .592 .944 r
.2217 .62297 m .22166 .62477 L .21975 .62319 L F
.2217 .62297 m .22387 .62505 L .22166 .62477 L F
.843 .63 .614 r
.5599 .55599 m .5595 .55851 L .56291 .55918 L F
.885 .644 .57 r
.5595 .55851 m .56308 .56202 L .56291 .55918 L F
.317 0 .18 r
.27146 .64425 m .27289 .64159 L .27504 .64108 L F
.435 .556 .879 r
.17604 .62083 m .17722 .61894 L .17498 .61933 L F
.17604 .62083 m .17914 .62239 L .17722 .61894 L F
.195 .313 .758 r
.33171 .58521 m .33081 .58755 L .32941 .58609 L F
.33171 .58521 m .33297 .58894 L .33081 .58755 L F
.355 .293 .649 r
.33081 .58755 m .33297 .58894 L .33143 .58951 L F
.728 .199 0 r
.51978 .5691 m .51892 .56931 L .51691 .56787 L F
.51978 .5691 m .52101 .57037 L .51892 .56931 L F
.692 .416 .499 r
.46753 .61932 m .47039 .61723 L .46765 .61734 L F
.177 .356 .804 r
.19604 .63519 m .19527 .63167 L .1941 .63213 L F
.19604 .63519 m .19724 .63553 L .19527 .63167 L F
.257 .531 .917 r
.31173 .54038 m .31306 .54328 L .30985 .54073 L F
.31173 .54038 m .31402 .54302 L .31306 .54328 L F
.076 .636 .779 r
.23815 .62631 m .2378 .62651 L .23609 .62651 L F
.23815 .62631 m .24023 .62646 L .2378 .62651 L F
.581 .699 .923 r
.30499 .57583 m .30589 .57725 L .3034 .57758 L F
.531 .267 .461 r
.30589 .57725 m .30548 .57952 L .3034 .57758 L F
.3034 .57758 m .30548 .57952 L .30589 .57725 L F
.851 .679 .669 r
.57468 .58804 m .57741 .58634 L .57457 .58599 L F
.57468 .58804 m .57662 .58998 L .57741 .58634 L F
.792 .492 .482 r
.56815 .57143 m .56802 .57366 L .56973 .57151 L F
.867 .607 .543 r
.56802 .57366 m .56974 .57405 L .56973 .57151 L F
.581 .318 .482 r
.80722 .40926 m .80372 .41213 L .80353 .40983 L F
.497 .34 .597 r
.32978 .58335 m .32719 .58607 L .32632 .58505 L F
.685 .559 .706 r
.50734 .55076 m .50858 .55228 L .51135 .54991 L F
.339 .785 .957 r
.24883 .53552 m .25078 .53505 L .25272 .53577 L F
.134 .65 .891 r
.25078 .53505 m .25474 .53575 L .25272 .53577 L F
.709 .438 .513 r
.48978 .56896 m .49178 .57114 L .48921 .5703 L F
.911 .69 .591 r
.48978 .56896 m .48921 .5703 L .48811 .56782 L F
0 0 .391 r
.33935 .55555 m .34063 .55795 L .341 .55927 L F
0 .117 .642 r
.34063 .55795 m .34079 .56167 L .341 .55927 L F
.373 .114 .387 r
.4747 .61977 m .47434 .62272 L .47214 .62341 L F
.564 .561 .809 r
.47691 .61875 m .4747 .61977 L .47366 .61661 L F
.324 .075 .373 r
.47642 .62172 m .4747 .61977 L .47691 .61875 L F
.47642 .62172 m .47434 .62272 L .4747 .61977 L F
.568 .665 .904 r
.83692 .40133 m .83872 .39892 L .83608 .3996 L F
.83692 .40133 m .84001 .40084 L .83872 .39892 L F
0 0 0 r
.19171 .54637 m .19146 .54654 L .19367 .54533 L F
.42744 .65094 m .42409 .65316 L .42455 .6508 L F
0 0 .033 r
.42937 .64988 m .42665 .65299 L .42744 .65094 L F
.587 .798 .98 r
.20432 .63747 m .20562 .63892 L .20766 .63811 L F
.741 .667 .777 r
.33663 .55323 m .33306 .55342 L .3352 .55038 L F
.555 .591 .845 r
.33662 .55616 m .33306 .55342 L .33663 .55323 L F
.555 .658 .905 r
.33784 .55156 m .33663 .55323 L .3352 .55038 L F
.33784 .55156 m .33882 .55284 L .33663 .55323 L F
.605 .468 .668 r
.33935 .55555 m .33663 .55323 L .33882 .55284 L F
.33935 .55555 m .33662 .55616 L .33663 .55323 L F
0 0 .22 r
.24961 .66485 m .24953 .6649 L .24995 .66707 L F
.24949 .66415 m .24953 .6649 L .24961 .66485 L F
.858 .722 .199 r
.24924 .66507 m .24953 .6649 L .24949 .66415 L F
.81 .521 .5 r
.24968 .6648 m .24953 .6649 L .24924 .66507 L F
.481 .294 .55 r
.25065 .66421 m .25215 .66672 L .25168 .66425 L F
.24949 .66415 m .24998 .66462 L .25009 .66455 L F
.24949 .66415 m .25009 .66455 L .25025 .66419 L F
.81 .521 .5 r
.25231 .66322 m .24953 .6649 L .24957 .66488 L F
.481 .294 .55 r
.24998 .66462 m .24995 .66707 L .25215 .66672 L F
.24949 .66415 m .24961 .66485 L .24998 .66462 L F
.81 .521 .5 r
.24998 .66462 m .24957 .66488 L .24961 .66485 L F
.481 .294 .55 r
.24961 .66485 m .24995 .66707 L .24998 .66462 L F
.81 .521 .5 r
.25009 .66455 m .24998 .66462 L .24968 .6648 L F
.24998 .66462 m .24961 .66485 L .24968 .6648 L F
.226 0 0 r
.24924 .66507 m .24949 .66415 L .25025 .66419 L F
.584 .854 .995 r
.25052 .66395 m .25231 .66322 L .25009 .66455 L F
.481 .294 .55 r
.25025 .66419 m .25009 .66455 L .25065 .66421 L F
.81 .521 .5 r
.25231 .66322 m .24957 .66488 L .25009 .66455 L F
.481 .294 .55 r
.24998 .66462 m .25215 .66672 L .25065 .66421 L F
.226 0 0 r
.24924 .66507 m .25025 .66419 L .25168 .66425 L F
.584 .854 .995 r
.25232 .66141 m .25232 .66238 L .25052 .66395 L F
.25232 .66238 m .25231 .66322 L .25052 .66395 L F
.25053 .66353 m .25009 .66455 L .24924 .66507 L F
.25232 .66141 m .25009 .66455 L .25053 .66353 L F
.25232 .66141 m .25428 .66279 L .25231 .66322 L F
.549 .303 .495 r
.3002 .62819 m .29808 .62649 L .30033 .62633 L F
.3002 .62819 m .29772 .62878 L .29808 .62649 L F
.239 0 .273 r
.2805 .57252 m .2817 .57337 L .28253 .57129 L F
.2805 .57252 m .27986 .57417 L .2817 .57337 L F
.455 .255 .519 r
.32331 .59844 m .32088 .60159 L .32089 .59897 L F
.922 .685 .561 r
.27784 .60759 m .27596 .60749 L .27747 .60492 L F
.27747 .60492 m .27596 .60749 L .27784 .60759 L F
.555 .428 .663 r
.27878 .60483 m .28018 .60686 L .28007 .60474 L F
.27747 .60492 m .27841 .60559 L .27878 .60483 L F
.27841 .60559 m .28018 .60686 L .27878 .60483 L F
.27747 .60492 m .27784 .60759 L .28018 .60686 L F
.979 .913 .653 r
.27773 .60329 m .2767 .60677 L .27754 .60738 L F
.27782 .60681 m .27754 .60738 L .27784 .60759 L F
.27773 .60329 m .27784 .60759 L .27747 .60492 L F
.27773 .60329 m .27754 .60738 L .27782 .60681 L F
.789 .547 .571 r
.43651 .67514 m .43594 .67809 L .43969 .67815 L F
.603 .436 .628 r
.47366 .61661 m .47605 .61382 L .47352 .61416 L F
.482 .25 .484 r
.45933 .62339 m .46203 .62279 L .46259 .61943 L F
.294 .087 .419 r
.46259 .61943 m .46368 .62176 L .46376 .61927 L F
.46259 .61943 m .46203 .62279 L .46368 .62176 L F
.242 0 .243 r
.16355 .56249 m .16269 .56452 L .1654 .56172 L F
.013 0 0 r
.8161 .39846 m .81979 .39733 L .81708 .39766 L F
.695 .782 .918 r
.79019 .4215 m .79379 .42198 L .79114 .42312 L F
.661 .437 .569 r
.47873 .61074 m .48161 .61074 L .48151 .60807 L F
.547 .347 .562 r
.48161 .61074 m .48401 .60778 L .48151 .60807 L F
.615 .684 .891 r
.80772 .44237 m .80915 .43891 L .80682 .43907 L F
.80772 .44237 m .81084 .4416 L .80915 .43891 L F
0 0 0 r
.23385 .71164 m .23457 .71058 L .23343 .71204 L F
.705 .856 .438 r
.23557 .7091 m .23407 .7119 L .23457 .71058 L F
.6 .543 .762 r
.23579 .7087 m .23702 .7117 L .23407 .7119 L F
.436 .451 .776 r
.23861 .71076 m .23702 .7117 L .23579 .7087 L F
.291 .435 .834 r
.2368 .70723 m .23861 .71076 L .23579 .7087 L F
0 .229 .743 r
.23798 .70865 m .23861 .71076 L .23728 .70816 L F
0 .045 .558 r
.2376 .70802 m .2391 .70945 L .2368 .70723 L F
0 .229 .743 r
.2391 .70945 m .23728 .70816 L .23753 .7081 L F
.724 .494 .578 r
.23755 .70811 m .2391 .70945 L .2376 .70802 L F
0 .229 .743 r
.2391 .70945 m .23896 .70982 L .23798 .70865 L F
.23896 .70982 m .23861 .71076 L .23798 .70865 L F
.591 .306 .453 r
.23702 .7117 m .23356 .71394 L .23407 .7119 L F
.724 .494 .578 r
.23533 .71196 m .2391 .70945 L .23755 .70811 L F
0 .229 .743 r
.23793 .70832 m .23755 .70811 L .23766 .70806 L F
0 0 0 r
.2376 .70802 m .23753 .7081 L .23755 .70811 L F
0 .229 .743 r
.23755 .70811 m .23753 .7081 L .23753 .70809 L F
.23755 .70811 m .23753 .70809 L .23766 .70806 L F
.2391 .70945 m .23753 .7081 L .23793 .70832 L F
0 0 0 r
.23755 .70811 m .23343 .71204 L .23533 .71196 L F
.23753 .7081 m .23343 .71204 L .23755 .70811 L F
.705 .856 .438 r
.23579 .7087 m .23557 .7091 L .23457 .71058 L F
.723 .594 .711 r
.23486 .70503 m .23579 .7087 L .23249 .70873 L F
.63 .237 .279 r
.23579 .7087 m .23457 .71058 L .23249 .70873 L F
0 0 .091 r
.23681 .70716 m .23579 .7087 L .23715 .70508 L F
.2368 .70723 m .23678 .70725 L .23681 .70716 L F
.23678 .70725 m .23579 .7087 L .23681 .70716 L F
.601 .446 .643 r
.23391 .70701 m .23457 .71058 L .23617 .70923 L F
.23654 .70804 m .23617 .70923 L .23725 .70832 L F
.112 .186 .662 r
.23674 .70716 m .23579 .7087 L .23486 .70503 L F
.23678 .70725 m .23579 .7087 L .23674 .70716 L F
.601 .446 .643 r
.23391 .70701 m .23617 .70923 L .23654 .70804 L F
.112 .186 .662 r
.2368 .70723 m .23678 .70725 L .23674 .70716 L F
.601 .446 .643 r
.2374 .70797 m .23751 .7081 L .2376 .70802 L F
0 0 0 r
.2376 .70802 m .23751 .7081 L .23753 .7081 L F
.601 .446 .643 r
.2374 .70797 m .2376 .70802 L .2368 .70723 L F
0 .229 .743 r
.23766 .70806 m .23751 .7081 L .2368 .70723 L F
.23751 .7081 m .23728 .70816 L .2368 .70723 L F
.601 .446 .643 r
.23391 .70701 m .2374 .70797 L .2368 .70723 L F
.2371 .70798 m .23725 .70832 L .23751 .7081 L F
.23391 .70701 m .23725 .70832 L .2371 .70798 L F
.23391 .70701 m .23751 .7081 L .2374 .70797 L F
0 0 0 r
.23753 .7081 m .23457 .71058 L .23385 .71164 L F
.23751 .7081 m .23457 .71058 L .23753 .7081 L F
.661 .565 .736 r
.33162 .5492 m .33306 .55342 L .3295 .55224 L F
.488 .508 .804 r
.14538 .59956 m .14756 .60285 L .14865 .60143 L F
.998 .781 .459 r
.50393 .58245 m .50468 .58592 L .50435 .58398 L F
.885 .644 .57 r
.5595 .55851 m .55944 .56112 L .56308 .56202 L F
.915 .743 .655 r
.55934 .56373 m .56308 .56202 L .55944 .56112 L F
.55934 .56373 m .56113 .56461 L .56308 .56202 L F
.839 .614 .597 r
.56308 .56202 m .56113 .56461 L .56442 .56523 L F
.228 0 .229 r
.25862 .61956 m .26106 .61681 L .25823 .61985 L F
.25862 .61956 m .26026 .61943 L .26106 .61681 L F
.256 0 .24 r
.26106 .61681 m .26243 .61865 L .26308 .61631 L F
.26106 .61681 m .26026 .61943 L .26243 .61865 L F
.479 .487 .788 r
.29463 .58313 m .29579 .58663 L .29778 .58608 L F
0 0 0 r
.29778 .58608 m .29579 .58663 L .29405 .58744 L F
.673 .896 .977 r
.25169 .66889 m .25388 .6698 L .25572 .6686 L F
0 0 0 r
.26813 .60729 m .26904 .60631 L .27028 .60416 L F
.26813 .60729 m .26739 .60985 L .26904 .60631 L F
.577 .789 .979 r
.45337 .67146 m .45149 .6724 L .44999 .67054 L F
.233 0 .295 r
.45077 .67467 m .45149 .6724 L .45337 .67146 L F
.834 .876 .874 r
.81791 .44376 m .81945 .43974 L .81672 .44232 L F
.81791 .44376 m .82054 .44115 L .81945 .43974 L F
.475 .846 .608 r
.18962 .56547 m .18754 .56695 L .18635 .56796 L F
0 0 0 r
.18959 .56618 m .18962 .56547 L .19179 .56418 L F
.18959 .56618 m .18754 .56695 L .18962 .56547 L F
.966 .93 .698 r
.49911 .58334 m .49911 .58076 L .49799 .58124 L F
.49911 .58334 m .4981 .58223 L .49911 .58076 L F
.78 .297 0 r
.49911 .58334 m .50126 .58722 L .49947 .58534 L F
.611 .887 .99 r
.27421 .5825 m .27592 .58329 L .27442 .57997 L F
.279 .767 .911 r
.27782 .58265 m .27442 .57997 L .27592 .58329 L F
0 0 0 r
.19834 .5617 m .19617 .56307 L .19342 .56385 L F
.181 0 0 r
.19822 .56274 m .19834 .5617 L .20035 .56176 L F
.19822 .56274 m .19617 .56307 L .19834 .5617 L F
.711 .538 .653 r
.447 .65615 m .44392 .65899 L .44408 .65685 L F
.677 .328 .375 r
.44354 .65848 m .44559 .65868 L .44433 .65391 L F
.44433 .65391 m .44559 .65868 L .44354 .65848 L F
.444 .189 .431 r
.44559 .65868 m .44806 .65799 L .44433 .65391 L F
.44433 .65391 m .44806 .65799 L .44559 .65868 L F
.393 .116 .37 r
.47014 .65976 m .46981 .66187 L .46773 .66264 L F
.164 .362 .813 r
.4717 .65852 m .47014 .65976 L .46896 .65681 L F
.149 0 .29 r
.47162 .66113 m .47014 .65976 L .4717 .65852 L F
.47162 .66113 m .46981 .66187 L .47014 .65976 L F
.542 .629 .888 r
.56141 .59544 m .56525 .59836 L .56355 .59491 L F
.736 .757 .869 r
.56355 .59491 m .56525 .59836 L .56748 .59537 L F
.291 .789 .798 r
.22448 .55063 m .22227 .55128 L .22455 .55096 L F
.339 0 0 r
.22431 .55085 m .22227 .55128 L .22448 .55063 L F
.183 .715 .747 r
.22455 .55096 m .22227 .55128 L .22043 .55167 L F
.339 0 0 r
.22298 .55253 m .22227 .55128 L .22431 .55085 L F
.183 .715 .747 r
.22043 .55167 m .22227 .55128 L .22006 .55173 L F
.291 .789 .798 r
.22448 .55063 m .22455 .55096 L .2265 .55004 L F
.642 .742 .922 r
.25919 .65133 m .26065 .64913 L .25805 .64737 L F
.25919 .65133 m .26168 .65076 L .26065 .64913 L F
.687 .25 .207 r
.50466 .55204 m .50683 .55421 L .50858 .55228 L F
0 .528 .825 r
.50683 .55421 m .50917 .55496 L .50798 .55294 L F
.50683 .55421 m .5089 .55471 L .51025 .55531 L F
.683 .251 0 r
.5089 .55471 m .51032 .55709 L .51061 .55737 L F
.51034 .55691 m .51061 .55737 L .51067 .55744 L F
.5089 .55471 m .51061 .55737 L .51034 .55691 L F
0 .528 .825 r
.50798 .55294 m .51025 .55531 L .50858 .55228 L F
.50917 .55496 m .51025 .55531 L .50798 .55294 L F
.734 .823 .92 r
.79654 .43656 m .80009 .4368 L .79893 .43525 L F
.647 .774 .941 r
.80009 .4368 m .80178 .43429 L .79893 .43525 L F
.80009 .4368 m .80291 .43595 L .80178 .43429 L F
.513 .868 .988 r
.22181 .55633 m .22404 .55556 L .22557 .55616 L F
.22557 .55616 m .22404 .55556 L .22181 .55633 L F
.365 .794 .97 r
.22785 .55583 m .22404 .55556 L .22557 .55616 L F
.22785 .55583 m .22404 .55556 L .22557 .55616 L F
.513 .868 .988 r
.22557 .55616 m .22404 .55556 L .22181 .55633 L F
.709 .597 .729 r
.81624 .42206 m .816 .42456 L .81372 .4253 L F
.829 .792 .816 r
.81624 .42206 m .81372 .4253 L .81241 .42371 L F
.204 0 0 r
.15765 .56759 m .15835 .5688 L .16099 .56555 L F
.256 0 .027 r
.16099 .56555 m .16104 .5678 L .16269 .56452 L F
.16099 .56555 m .15835 .5688 L .16104 .5678 L F
.626 .783 .957 r
.28382 .53501 m .28164 .53584 L .27992 .53425 L F
.465 .805 .999 r
.77892 .4191 m .77711 .41979 L .77681 .41884 L F
.478 0 0 r
.21781 .53678 m .21976 .53747 L .22161 .53746 L F
.086 0 0 r
.22151 .53773 m .22161 .53746 L .21976 .53747 L F
.22151 .53773 m .22379 .5375 L .22161 .53746 L F
.304 .088 .411 r
.14407 .5824 m .14518 .58247 L .14586 .58092 L F
.314 .178 .53 r
.14407 .5824 m .14597 .58461 L .14518 .58247 L F
.14407 .5824 m .1428 .5869 L .14597 .58461 L F
0 0 0 r
.25766 .54719 m .25523 .54836 L .25569 .54837 L F
.051 0 0 r
.48458 .56416 m .48345 .56419 L .48046 .56408 L F
.48458 .56416 m .48345 .56419 L .48046 .56408 L F
.661 .512 .671 r
.48458 .56416 m .48536 .56567 L .48848 .56536 L F
.582 .777 .972 r
.24898 .67381 m .24856 .67606 L .25107 .67516 L F
.24898 .67381 m .24856 .67606 L .25107 .67516 L F
.522 .595 .868 r
.32657 .54555 m .32575 .54863 L .32391 .54606 L F
.32657 .54555 m .32769 .5483 L .32575 .54863 L F
.906 .869 .791 r
.56197 .54303 m .56246 .54596 L .56262 .54386 L F
.925 .974 .741 r
.564 .53969 m .56197 .54303 L .56262 .54386 L F
0 0 0 r
.18754 .56695 m .18491 .56976 L .18635 .56796 L F
.504 .281 .509 r
.32577 .59269 m .32535 .59551 L .32315 .59597 L F
.438 .191 .441 r
.32819 .59214 m .32535 .59551 L .32577 .59269 L F
.235 .151 .552 r
.34079 .56167 m .34114 .56494 L .33968 .56524 L F
.745 .819 .351 r
.33897 .56641 m .33968 .56524 L .34114 .56494 L F
.33897 .56641 m .33862 .56761 L .33968 .56524 L F
.657 .775 .936 r
.83989 .41396 m .83618 .41342 L .8389 .41236 L F
.619 .733 .928 r
.84139 .4113 m .83989 .41396 L .8389 .41236 L F
.878 .459 .036 r
.84276 .40855 m .84139 .4113 L .84285 .40833 L F
.619 .733 .928 r
.84139 .4113 m .84242 .41322 L .84008 .4139 L F
.709 .239 0 r
.84247 .41384 m .84242 .41322 L .84139 .4113 L F
.878 .459 .036 r
.84111 .41254 m .84247 .41384 L .84139 .4113 L F
.84111 .41254 m .84139 .4113 L .84276 .40855 L F
.619 .733 .928 r
.84139 .4113 m .84008 .4139 L .83989 .41396 L F
0 0 0 r
.81544 .40602 m .81857 .40435 L .81731 .4044 L F
.398 .854 .831 r
.81857 .40435 m .82009 .40333 L .81731 .4044 L F
.81857 .40435 m .82112 .40336 L .82009 .40333 L F
.43 .603 .919 r
.15215 .60336 m .1536 .60558 L .15422 .60335 L F
.376 .544 .894 r
.1536 .60558 m .15606 .60601 L .15422 .60335 L F
.666 .206 .15 r
.48395 .61049 m .48933 .61063 L .48401 .60778 L F
.48395 .61049 m .48821 .61153 L .48933 .61063 L F
0 0 0 r
.48933 .61063 m .48821 .61153 L .49019 .61006 L F
0 0 .446 r
.33796 .56989 m .33675 .56873 L .33862 .56761 L F
.33796 .56989 m .33669 .57172 L .33675 .56873 L F
0 .169 .707 r
.19039 .61065 m .19209 .61352 L .19038 .61205 L F
.539 .191 .326 r
.28166 .63847 m .28007 .64106 L .27772 .64112 L F
.571 .226 .345 r
.28363 .64033 m .28007 .64106 L .28166 .63847 L F
.56 .228 .363 r
.28409 .63844 m .28363 .64033 L .28166 .63847 L F
.723 .497 .583 r
.23064 .7062 m .23249 .70873 L .2327 .70539 L F
.2327 .70539 m .23249 .70873 L .23064 .7062 L F
.723 .594 .711 r
.23486 .70503 m .23249 .70873 L .2327 .70539 L F
.185 .052 .455 r
.23391 .70701 m .2327 .70539 L .23486 .70503 L F
.23391 .70701 m .23249 .70873 L .2327 .70539 L F
.326 .08 .379 r
.28248 .58379 m .28198 .58601 L .2847 .58297 L F
.412 .564 .895 r
.29258 .53608 m .29145 .5382 L .28986 .53507 L F
.551 .737 .962 r
.29258 .53608 m .29379 .53767 L .29145 .5382 L F
.964 .88 .701 r
.56651 .53407 m .56529 .53731 L .56632 .53814 L F
.44 .103 .296 r
.80501 .40303 m .80791 .40242 L .80819 .40022 L F
.285 0 .261 r
.80819 .40022 m .81025 .40145 L .8109 .39993 L F
.80819 .40022 m .80791 .40242 L .81025 .40145 L F
.883 .51 .33 r
.53028 .52555 m .52735 .52546 L .52845 .52341 L F
.53028 .52555 m .52886 .52741 L .52735 .52546 L F
.176 0 0 r
.53138 .5267 m .53028 .52555 L .53276 .5252 L F
.53138 .5267 m .52886 .52741 L .53028 .52555 L F
.096 .637 .848 r
.24618 .64227 m .25119 .6427 L .24691 .64204 L F
.161 .673 .897 r
.25394 .64335 m .24691 .64204 L .25119 .6427 L F
.25394 .64335 m .25331 .64247 L .24691 .64204 L F
0 .47 .858 r
.25394 .64335 m .25328 .64187 L .25331 .64247 L F
.25394 .64335 m .25632 .64383 L .25328 .64187 L F
.25632 .64383 m .25606 .64339 L .25328 .64187 L F
.062 .617 .816 r
.24691 .64204 m .25331 .64247 L .24882 .64197 L F
.833 .633 .633 r
.25328 .64187 m .25716 .644 L .25676 .64277 L F
.695 .803 .932 r
.24882 .64197 m .25331 .64247 L .25328 .64187 L F
.295 .736 .964 r
.25595 .64318 m .25099 .64206 L .25328 .64187 L F
.25592 .64317 m .25276 .64221 L .25099 .64206 L F
.25595 .64318 m .25592 .64317 L .25592 .64317 L F
.25592 .64317 m .25276 .64221 L .25592 .64317 L F
0 .47 .858 r
.25632 .64383 m .25716 .644 L .25606 .64339 L F
.297 .394 .793 r
.14405 .59581 m .14538 .59956 L .14658 .59755 L F
.488 .508 .804 r
.14538 .59956 m .14865 .60143 L .14658 .59755 L F
.94 .825 .703 r
.55117 .56819 m .55066 .56443 L .55239 .56563 L F
.719 .625 .752 r
.21133 .63928 m .21441 .64235 L .21627 .64085 L F
.762 .436 .434 r
.79464 .39999 m .79871 .40253 L .79802 .4008 L F
.572 .597 .839 r
.78761 .43759 m .79143 .44027 L .79026 .43676 L F
.711 .665 .803 r
.79026 .43676 m .79143 .44027 L .7941 .43765 L F
.395 .824 .962 r
.23266 .54956 m .23085 .54915 L .22874 .54961 L F
0 0 0 r
.23085 .54915 m .23065 .54921 L .22874 .54961 L F
.275 .777 .865 r
.23044 .54967 m .22874 .54961 L .22684 .55001 L F
0 0 0 r
.23065 .54921 m .22672 .55028 L .22874 .54961 L F
.275 .777 .865 r
.22684 .55001 m .22874 .54961 L .2265 .55004 L F
.395 .824 .962 r
.23266 .54956 m .22874 .54961 L .23044 .54967 L F
0 0 .365 r
.17494 .59486 m .17522 .59796 L .17449 .59673 L F
.857 .489 .352 r
.49304 .54611 m .49665 .54912 L .49582 .54769 L F
.48 .275 .523 r
.30615 .6201 m .30603 .62274 L .30368 .62318 L F
.592 .421 .619 r
.30603 .62274 m .30357 .62566 L .30368 .62318 L F
.172 .064 .481 r
.14339 .58942 m .14597 .58461 L .1428 .5869 L F
.068 .33 .809 r
.27584 .55265 m .27639 .55123 L .27385 .54939 L F
0 0 .464 r
.27584 .55265 m .27679 .55471 L .27639 .55123 L F
.541 .436 .684 r
.30869 .57383 m .31055 .57077 L .30823 .57133 L F
.426 .027 .177 r
.31055 .57077 m .30654 .57352 L .30823 .57133 L F
.572 .502 .738 r
.78678 .4329 m .78761 .43759 L .79026 .43676 L F
.756 .419 .415 r
.25503 .65564 m .25678 .65371 L .25743 .65584 L F
0 0 0 r
.25605 .65457 m .25678 .65371 L .25503 .65564 L F
0 0 .453 r
.25743 .65584 m .25678 .65371 L .25834 .65501 L F
.439 0 0 r
.25834 .65501 m .25678 .65371 L .25605 .65457 L F
.848 .648 .633 r
.57326 .57996 m .57496 .58342 L .57543 .58082 L F
.234 .277 .702 r
.49799 .58124 m .49911 .58076 L .49698 .57741 L F
0 0 0 r
.19146 .54654 m .19162 .54756 L .19367 .54533 L F
.19146 .54654 m .18969 .54846 L .19162 .54756 L F
.746 .544 .622 r
.55268 .52812 m .54882 .52514 L .55282 .52544 L F
.678 .396 .488 r
.53354 .5887 m .53721 .58701 L .53362 .58588 L F
.53354 .5887 m .53769 .59014 L .53721 .58701 L F
.45 .241 .503 r
.53769 .59014 m .53902 .58911 L .53721 .58701 L F
.352 .367 .737 r
.52558 .57818 m .52691 .57619 L .52478 .57687 L F
.52558 .57818 m .52826 .5795 L .52691 .57619 L F
.843 .99 .854 r
.23091 .71481 m .23079 .71665 L .23148 .71473 L F
.492 .212 .416 r
.24746 .55323 m .24419 .55589 L .24509 .55317 L F
.24746 .55323 m .24657 .55559 L .24419 .55589 L F
.388 .11 .366 r
.24882 .55487 m .24746 .55323 L .24888 .55216 L F
.24882 .55487 m .24657 .55559 L .24746 .55323 L F
.75 .46 .491 r
.52314 .57031 m .52686 .56842 L .52646 .56638 L F
.52314 .57031 m .52795 .57112 L .52686 .56842 L F
.703 .837 .947 r
.52686 .56842 m .52847 .5656 L .52646 .56638 L F
.52686 .56842 m .52906 .56627 L .52847 .5656 L F
.808 .65 .687 r
.24824 .67435 m .24699 .66902 L .2465 .67147 L F
.567 .346 .538 r
.30853 .62231 m .30615 .6201 L .3084 .61968 L F
.30853 .62231 m .30603 .62274 L .30615 .6201 L F
.787 .287 0 r
.50272 .59327 m .50098 .59316 L .50191 .5916 L F
.945 .718 .563 r
.50098 .59316 m .502 .59512 L .50196 .59364 L F
.50098 .59316 m .50196 .59364 L .50191 .5916 L F
.787 .287 0 r
.50272 .59327 m .50196 .59364 L .50175 .59321 L F
0 0 .44 r
.50191 .5916 m .50196 .59364 L .50389 .59263 L F
.964 .636 .281 r
.50098 .59316 m .50092 .59642 L .502 .59512 L F
.913 .555 .342 r
.50203 .59377 m .50092 .59642 L .50098 .59316 L F
.50275 .59419 m .50224 .59481 L .50203 .59377 L F
.597 .587 .812 r
.50092 .59642 m .50224 .59481 L .502 .59512 L F
0 0 .44 r
.50196 .59364 m .502 .59512 L .50224 .59481 L F
.50196 .59364 m .50224 .59481 L .50203 .59377 L F
.913 .555 .342 r
.50238 .59554 m .50092 .59642 L .50203 .59377 L F
0 0 .44 r
.50203 .59377 m .50224 .59481 L .50242 .59457 L F
.787 .287 0 r
.50272 .59327 m .50346 .59437 L .50196 .59364 L F
.50346 .59437 m .50371 .59474 L .50275 .59419 L F
.50285 .59407 m .50275 .59419 L .50098 .59316 L F
.50346 .59437 m .50275 .59419 L .50285 .59407 L F
.597 .587 .812 r
.50092 .59642 m .50184 .59525 L .50224 .59481 L F
0 0 .44 r
.50196 .59364 m .50242 .59457 L .50389 .59263 L F
.597 .587 .812 r
.50184 .59525 m .50389 .59263 L .50242 .59457 L F
.50184 .59525 m .50242 .59457 L .50224 .59481 L F
.913 .555 .342 r
.50371 .59474 m .50238 .59554 L .50224 .59481 L F
.50371 .59474 m .50224 .59481 L .50275 .59419 L F
.787 .287 0 r
.50175 .59321 m .50196 .59364 L .50098 .59316 L F
.947 .732 .579 r
.42455 .6508 m .42409 .65316 L .42298 .65069 L F
.846 .648 .634 r
.56086 .56713 m .56442 .56523 L .56113 .56461 L F
.56086 .56713 m .56423 .568 L .56442 .56523 L F
.899 .64 .538 r
.47561 .63834 m .47582 .64116 L .47317 .63937 L F
.466 0 0 r
.47317 .63937 m .4751 .63976 L .47561 .63834 L F
.825 .509 0 r
.4751 .63976 m .47582 .64116 L .47561 .63834 L F
.684 .903 .974 r
.82903 .43744 m .82823 .4364 L .82471 .43812 L F
.825 .948 .901 r
.82996 .43479 m .82903 .43744 L .8309 .43579 L F
.82996 .43479 m .82823 .4364 L .82903 .43744 L F
0 0 0 r
.24625 .62594 m .24854 .62556 L .24924 .62538 L F
.261 .766 .871 r
.2466 .62547 m .24854 .62556 L .24625 .62594 L F
.097 0 0 r
.24748 .62583 m .24854 .62556 L .2466 .62547 L F
.24883 .62638 m .24854 .62556 L .24748 .62583 L F
0 0 0 r
.24924 .62538 m .24854 .62556 L .25014 .62521 L F
.19 .72 .743 r
.24854 .62556 m .25238 .62483 L .25014 .62521 L F
.723 .357 .355 r
.55634 .51794 m .55998 .51645 L .55619 .51586 L F
.55634 .51794 m .56021 .51834 L .55998 .51645 L F
.425 0 0 r
.24222 .62568 m .24625 .62594 L .24393 .62539 L F
.126 .672 .815 r
.25474 .53575 m .25702 .53564 L .25892 .53585 L F
.16 .697 .829 r
.25702 .53564 m .26092 .53559 L .25892 .53585 L F
.596 .772 .964 r
.82483 .4042 m .82639 .40175 L .82372 .40251 L F
.82483 .4042 m .82754 .40343 L .82639 .40175 L F
.483 .19 .391 r
.46639 .62878 m .46315 .63139 L .46389 .62916 L F
.621 .129 .063 r
.18657 .61048 m .1882 .61169 L .18994 .61101 L F
0 .169 .707 r
.19039 .61065 m .18994 .61101 L .1882 .61169 L F
.737 .69 .805 r
.56979 .59218 m .57359 .59273 L .57216 .58913 L F
.751 .691 .793 r
.57359 .59273 m .57468 .58804 L .57216 .58913 L F
.57359 .59273 m .57662 .58998 L .57468 .58804 L F
.346 .818 .901 r
.54396 .52209 m .54126 .52238 L .53886 .52296 L F
.255 0 .006 r
.54126 .52238 m .53861 .52391 L .53886 .52296 L F
.757 .644 .736 r
.81496 .4184 m .81624 .42206 L .81496 .42068 L F
.829 .792 .816 r
.81624 .42206 m .81241 .42371 L .81496 .42068 L F
.582 .393 .59 r
.33935 .55555 m .33666 .55868 L .33662 .55616 L F
.62 .742 .934 r
.28986 .53507 m .28749 .53668 L .2861 .53452 L F
.952 .882 .481 r
.50798 .59155 m .50749 .59581 L .50914 .59239 L F
.431 .745 .993 r
.84027 .39216 m .83877 .39366 L .83744 .39243 L F
.84027 .39216 m .84156 .39348 L .83877 .39366 L F
.719 .625 .752 r
.21133 .63928 m .21627 .64085 L .21502 .63971 L F
.224 .671 .952 r
.21627 .64085 m .21588 .63992 L .21502 .63971 L F
.21627 .64085 m .21766 .64086 L .21588 .63992 L F
.7 .807 .932 r
.19611 .61384 m .19405 .61504 L .19209 .61352 L F
.518 .333 .568 r
.31602 .60788 m .31601 .61053 L .31367 .61106 L F
.642 .526 .707 r
.31686 .61333 m .31367 .61106 L .31601 .61053 L F
.31686 .61333 m .31415 .6145 L .31367 .61106 L F
0 0 .141 r
.52292 .57397 m .52322 .57284 L .52314 .57031 L F
0 .014 .587 r
.52292 .57397 m .52478 .57687 L .52322 .57284 L F
.138 0 .096 r
.21774 .55619 m .21517 .5583 L .21616 .55654 L F
.749 .466 .503 r
.45569 .65074 m .45545 .65309 L .45935 .65328 L F
.879 .874 .827 r
.24419 .55589 m .2424 .55505 L .24491 .55174 L F
.24419 .55589 m .24433 .55507 L .24448 .555 L F
.391 0 0 r
.24657 .55559 m .2424 .55505 L .24419 .55589 L F
.24657 .55559 m .24427 .5557 L .24355 .55545 L F
.24396 .55526 m .24355 .55545 L .2424 .55505 L F
.24657 .55559 m .24355 .55545 L .24396 .55526 L F
.879 .874 .827 r
.24448 .555 m .24491 .55174 L .24509 .55317 L F
.24433 .55507 m .24491 .55174 L .24448 .555 L F
0 0 .508 r
.49698 .57741 m .49806 .57838 L .49835 .5753 L F
.49698 .57741 m .49911 .58076 L .49806 .57838 L F
.612 .462 .654 r
.29507 .63174 m .29269 .63495 L .29286 .63229 L F
.761 .319 .203 r
.53255 .57532 m .53324 .57499 L .53061 .57418 L F
.499 .648 .924 r
.21117 .64611 m .21022 .6481 L .21272 .64771 L F
.21117 .64611 m .21022 .6481 L .21272 .64771 L F
.657 .489 .645 r
.48536 .56567 m .48811 .56782 L .48848 .56536 L F
.529 .392 .638 r
.44306 .65064 m .44638 .65264 L .44576 .65 L F
.328 0 .16 r
.27167 .54995 m .27048 .55226 L .26819 .55278 L F
.236 0 .084 r
.27385 .54939 m .27048 .55226 L .27167 .54995 L F
.735 .84 .929 r
.82054 .44115 m .82153 .43845 L .81945 .43974 L F
.82054 .44115 m .82282 .43978 L .82153 .43845 L F
.724 .663 .789 r
.22774 .7147 m .22881 .71754 L .22554 .71619 L F
.489 .903 .873 r
.22747 .71766 m .22881 .71754 L .23079 .71665 L F
0 .282 .783 r
.79359 .4064 m .7956 .40685 L .79222 .40543 L F
.508 .318 .558 r
.28018 .60686 m .28266 .60409 L .28007 .60474 L F
.509 .649 .92 r
.78101 .42746 m .78289 .43025 L .78536 .42974 L F
.467 .204 .431 r
.45933 .62339 m .46135 .62504 L .46203 .62279 L F
.45933 .62339 m .45899 .62558 L .46135 .62504 L F
.676 .573 .733 r
.3352 .55038 m .33306 .55342 L .33162 .5492 L F
.57 .305 .475 r
.31686 .61333 m .31369 .61641 L .31415 .6145 L F
.525 .829 1 r
.25468 .66074 m .25428 .66279 L .25232 .66141 L F
.728 .389 .405 r
.25577 .66637 m .25509 .66503 L .25428 .66279 L F
0 .185 .707 r
.46393 .66016 m .46568 .66121 L .46568 .65858 L F
.46393 .66016 m .46517 .66195 L .46568 .66121 L F
.286 .395 .799 r
.33796 .56989 m .33924 .57342 L .33669 .57172 L F
.387 .395 .746 r
.33669 .57172 m .33924 .57342 L .33753 .57389 L F
.382 .204 .512 r
.31819 .60452 m .31796 .60736 L .31602 .60788 L F
.503 .321 .566 r
.31832 .60999 m .31602 .60788 L .31796 .60736 L F
.31832 .60999 m .31601 .61053 L .31602 .60788 L F
.581 .318 .482 r
.80722 .40926 m .80672 .41173 L .80372 .41213 L F
.528 .269 .466 r
.80933 .41111 m .80722 .40926 L .80982 .4093 L F
.80933 .41111 m .80672 .41173 L .80722 .40926 L F
.569 .439 .664 r
.32535 .59551 m .32331 .59844 L .32315 .59597 L F
.297 .198 .569 r
.53974 .59896 m .54172 .59499 L .53882 .59533 L F
.53974 .59896 m .54194 .59718 L .54172 .59499 L F
.449 0 0 r
.54147 .59983 m .54289 .59965 L .54147 .59983 L F
.54606 .59886 m .54289 .59965 L .54147 .59983 L F
.54606 .59886 m .54476 .60023 L .54289 .59965 L F
.358 .358 .723 r
.54289 .59965 m .54476 .60023 L .54459 .59943 L F
.54289 .59965 m .54459 .59943 L .54386 .59592 L F
.486 .52 .818 r
.53974 .59896 m .54289 .59965 L .54194 .59718 L F
.353 .598 .939 r
.54147 .59983 m .54289 .59965 L .53974 .59896 L F
.892 .826 .776 r
.5572 .5442 m .55542 .54461 L .55546 .54294 L F
.5572 .5442 m .55509 .54643 L .55542 .54461 L F
.825 .676 .697 r
.27756 .61045 m .27596 .60749 L .27784 .60759 L F
.27699 .6094 m .27531 .61091 L .27596 .60749 L F
.27756 .61045 m .2768 .61061 L .27699 .6094 L F
.2768 .61061 m .27531 .61091 L .27699 .6094 L F
0 0 .029 r
.27596 .60749 m .27586 .60914 L .27784 .60759 L F
.995 .869 .566 r
.2767 .60677 m .27586 .60914 L .27721 .60808 L F
.27735 .60724 m .27721 .60808 L .27784 .60759 L F
.2767 .60677 m .27721 .60808 L .27735 .60724 L F
.536 .343 .566 r
.27756 .61045 m .28018 .60686 L .27784 .60759 L F
.409 .126 .37 r
.25518 .62334 m .25735 .62293 L .25862 .61956 L F
.376 .095 .354 r
.25862 .61956 m .25987 .62197 L .26026 .61943 L F
.25862 .61956 m .25735 .62293 L .25987 .62197 L F
.906 .869 .791 r
.56197 .54303 m .55989 .54541 L .56246 .54596 L F
.976 .892 .675 r
.5599 .54826 m .56246 .54596 L .55989 .54541 L F
.5599 .54826 m .56076 .54952 L .56246 .54596 L F
.541 .336 .551 r
.33753 .57389 m .33711 .57704 L .33469 .57727 L F
.581 .458 .677 r
.33924 .57342 m .33711 .57704 L .33753 .57389 L F
.379 0 0 r
.23664 .54981 m .23513 .55021 L .23266 .54956 L F
.115 0 0 r
.23664 .54981 m .23692 .55003 L .23513 .55021 L F
.23664 .54981 m .23892 .54998 L .23692 .55003 L F
.401 .061 .27 r
.45278 .6408 m .45514 .63907 L .45293 .63849 L F
.793 .668 .725 r
.47866 .61336 m .48289 .61415 L .48161 .61074 L F
.513 .516 .796 r
.48161 .61074 m .48289 .61415 L .48481 .6131 L F
0 0 0 r
.48481 .6131 m .48168 .61552 L .48289 .61415 L F
.48481 .6131 m .48168 .61552 L .48289 .61415 L F
.77 .807 .883 r
.82129 .41611 m .818 .41615 L .82009 .41463 L F
.551 .737 .962 r
.82343 .41558 m .82129 .41611 L .82009 .41463 L F
.41 .179 .449 r
.49028 .54711 m .49258 .54857 L .49304 .54611 L F
.327 .313 .691 r
.2835 .56176 m .28531 .56092 L .28305 .55891 L F
.227 .077 .458 r
.2835 .56176 m .28522 .56337 L .28531 .56092 L F
.2835 .56176 m .28346 .56434 L .28522 .56337 L F
.534 .313 .526 r
.30589 .57725 m .30838 .57694 L .30869 .57383 L F
.541 .436 .684 r
.30869 .57383 m .31104 .57334 L .31055 .57077 L F
.52 .301 .523 r
.30869 .57383 m .31083 .57634 L .31104 .57334 L F
.30869 .57383 m .30838 .57694 L .31083 .57634 L F
.487 .292 .542 r
.25523 .54836 m .25509 .55213 L .25284 .5527 L F
0 0 0 r
.25766 .54719 m .25616 .54862 L .25523 .54836 L F
0 0 .046 r
.25539 .54994 m .25523 .54836 L .25616 .54862 L F
.25539 .54994 m .25509 .55213 L .25523 .54836 L F
.69 .857 .962 r
.2106 .7492 m .21128 .74735 L .21014 .74782 L F
.2106 .7492 m .21323 .74828 L .21128 .74735 L F
.653 .734 .909 r
.19994 .61475 m .19611 .61384 L .19856 .61282 L F
.502 .738 .979 r
.20044 .61289 m .19994 .61475 L .19856 .61282 L F
.20044 .61289 m .20237 .61433 L .19994 .61475 L F
.711 .278 .218 r
.21231 .55775 m .20632 .55714 L .2092 .55603 L F
.397 .795 .986 r
.78501 .4186 m .78353 .41975 L .78239 .41838 L F
.78501 .4186 m .78665 .41907 L .78353 .41975 L F
.053 .587 .858 r
.22166 .64114 m .22141 .64064 L .21989 .64043 L F
.22166 .64114 m .22392 .64146 L .22141 .64064 L F
.692 .416 .499 r
.46753 .61932 m .47028 .61966 L .47039 .61723 L F
.494 .186 .373 r
.47028 .61966 m .47366 .61661 L .47039 .61723 L F
.454 .878 .775 r
.83484 .3937 m .83247 .39496 L .83136 .3951 L F
.086 .373 .837 r
.25805 .64737 m .25853 .6461 L .25664 .64743 L F
.25805 .64737 m .26065 .64913 L .25853 .6461 L F
.856 .633 .599 r
.57165 .5759 m .57326 .57996 L .57341 .57723 L F
.429 0 0 r
.29573 .53776 m .30017 .53822 L .29776 .53872 L F
.934 .77 .655 r
.55596 .53752 m .55418 .53672 L .55477 .53426 L F
.923 .657 .516 r
.55596 .53752 m .55398 .53928 L .55418 .53672 L F
.55596 .53752 m .55588 .54028 L .55398 .53928 L F
.792 .864 .903 r
.21242 .73259 m .2135 .72917 L .21119 .73003 L F
.21242 .73259 m .21342 .73188 L .2135 .72917 L F
.94 .825 .703 r
.55117 .56819 m .54956 .5675 L .55066 .56443 L F
.979 .759 .537 r
.55117 .56819 m .54952 .56852 L .54956 .5675 L F
.55117 .56819 m .55097 .57013 L .54952 .56852 L F
.653 .44 .583 r
.33143 .58951 m .33097 .59254 L .32819 .59214 L F
.561 .435 .665 r
.33297 .58894 m .33097 .59254 L .33143 .58951 L F
.194 0 .163 r
.15765 .56759 m .15841 .56942 L .15835 .5688 L F
.15765 .56759 m .15657 .57038 L .15841 .56942 L F
0 0 0 r
.22379 .5375 m .22605 .53712 L .22751 .53673 L F
.384 .505 .858 r
.78536 .42974 m .78678 .4329 L .78905 .43312 L F
.572 .502 .738 r
.78678 .4329 m .79026 .43676 L .78905 .43312 L F
.845 .387 0 r
.49835 .5753 m .50038 .57726 L .49919 .57503 L F
.803 .503 .481 r
.56444 .57296 m .56815 .57143 L .56438 .57051 L F
.56444 .57296 m .56802 .57366 L .56815 .57143 L F
.185 .714 .842 r
.26092 .53559 m .26331 .53537 L .26518 .53556 L F
.119 .666 .816 r
.26331 .53537 m .26715 .53545 L .26518 .53556 L F
.34 0 0 r
.28305 .55891 m .28131 .55801 L .28046 .55755 L F
.025 .254 .756 r
.28305 .55891 m .28408 .55818 L .28131 .55801 L F
.538 .038 .016 r
.28408 .55818 m .28219 .55849 L .28131 .55801 L F
.28219 .55849 m .27949 .55894 L .28131 .55801 L F
.34 0 0 r
.28046 .55755 m .28131 .55801 L .27897 .55676 L F
.025 .254 .756 r
.28305 .55891 m .28531 .56092 L .28408 .55818 L F
.481 .81 1 r
.49427 .55293 m .4979 .55333 L .49722 .55227 L F
0 0 .535 r
.4979 .55333 m .50023 .55163 L .49722 .55227 L F
.754 .265 .073 r
.50189 .55574 m .49936 .55543 L .4979 .55333 L F
0 0 .535 r
.4979 .55333 m .4991 .55446 L .50023 .55163 L F
.4979 .55333 m .49936 .55543 L .4991 .55446 L F
.22 .223 .65 r
.29318 .58453 m .29244 .58747 L .29135 .58511 L F
.29318 .58453 m .29405 .58744 L .29244 .58747 L F
.741 .595 .695 r
.33469 .57727 m .332 .58017 L .33284 .57794 L F
.608 .398 .571 r
.33469 .57727 m .33481 .57987 L .332 .58017 L F
.204 0 .266 r
.33711 .57704 m .33481 .57987 L .33469 .57727 L F
.679 .871 .971 r
.42514 .66232 m .42302 .66266 L .42435 .66046 L F
.955 .726 .553 r
.42302 .66266 m .42514 .66232 L .42597 .66264 L F
0 .235 .75 r
.42435 .66046 m .42597 .66264 L .42514 .66232 L F
.603 .35 .505 r
.29269 .63495 m .2905 .63702 L .29025 .6351 L F
.381 .099 .356 r
.15222 .5717 m .1538 .57305 L .15446 .57129 L F
.15222 .5717 m .15168 .57368 L .1538 .57305 L F
.62 .411 .577 r
.29762 .63136 m .29519 .62913 L .29772 .62878 L F
.29762 .63136 m .29507 .63174 L .29519 .62913 L F
.852 .759 .76 r
.50038 .57726 m .49911 .58076 L .50181 .58022 L F
.657 .122 0 r
.50215 .58132 m .50181 .58022 L .49911 .58076 L F
.50215 .58132 m .50393 .58245 L .50181 .58022 L F
.728 .478 .549 r
.49665 .54912 m .50023 .55163 L .50041 .54975 L F
.611 .273 .373 r
.50023 .55163 m .50283 .55173 L .50041 .54975 L F
.467 .085 .231 r
.49061 .60266 m .49247 .60331 L .4922 .60215 L F
.366 .262 .602 r
.49156 .60906 m .49247 .60331 L .49061 .60266 L F
.406 .737 .992 r
.76859 .41465 m .76933 .4158 L .76621 .4148 L F
.919 .631 .145 r
.76859 .41465 m .7689 .4168 L .76804 .41379 L F
.76859 .41465 m .76804 .41379 L .76781 .41301 L F
.406 .737 .992 r
.76859 .41465 m .76963 .41589 L .76933 .4158 L F
.389 .42 .772 r
.77161 .41389 m .76963 .41589 L .76859 .41465 L F
.77161 .41389 m .77277 .41732 L .76963 .41589 L F
.634 .875 .522 r
.54722 .59713 m .54606 .59886 L .54859 .59854 L F
.54722 .59713 m .54476 .60023 L .54606 .59886 L F
.656 .737 .91 r
.83287 .41802 m .82989 .4174 L .83298 .41455 L F
.877 .867 .825 r
.83441 .41588 m .83287 .41802 L .83298 .41455 L F
0 0 0 r
.82298 .3965 m .82492 .39523 L .82588 .39518 L F
.366 .836 .862 r
.82492 .39523 m .82831 .39463 L .82588 .39518 L F
.17 0 .314 r
.27373 .59641 m .27275 .59857 L .27484 .59539 L F
.888 .795 .751 r
.55386 .55657 m .55287 .55871 L .55186 .55532 L F
.497 .34 .597 r
.32978 .58335 m .32941 .58609 L .32719 .58607 L F
.279 .767 .911 r
.27782 .58265 m .27421 .5825 L .27442 .57997 L F
.27782 .58265 m .27695 .58218 L .27421 .5825 L F
.919 .974 .695 r
.27905 .5786 m .27782 .58265 L .28052 .58094 L F
.27905 .5786 m .27695 .58218 L .27782 .58265 L F
.681 .81 .944 r
.55514 .59639 m .55885 .59656 L .55731 .59504 L F
.74 .779 .885 r
.55731 .59504 m .55885 .59656 L .56141 .59544 L F
.441 0 0 r
.24287 .54975 m .24129 .55076 L .23892 .54998 L F
.591 .051 0 r
.24287 .54975 m .24318 .55052 L .24129 .55076 L F
.24287 .54975 m .24491 .55174 L .24318 .55052 L F
.495 .65 .928 r
.30856 .5388 m .30761 .54101 L .30614 .53969 L F
.30856 .5388 m .30985 .54073 L .30761 .54101 L F
.779 .303 .105 r
.18238 .60776 m .18432 .61028 L .18657 .61048 L F
.485 0 0 r
.18654 .61076 m .18657 .61048 L .18432 .61028 L F
.18654 .61076 m .1882 .61169 L .18657 .61048 L F
.139 0 0 r
.17829 .57439 m .17417 .57647 L .17533 .57626 L F
.17829 .57439 m .17635 .57599 L .17417 .57647 L F
.013 0 0 r
.17845 .57526 m .17829 .57439 L .18054 .57385 L F
.17845 .57526 m .17635 .57599 L .17829 .57439 L F
.628 .745 .932 r
.33162 .5492 m .32769 .5483 L .33003 .54706 L F
.648 .763 .933 r
.33373 .54806 m .33162 .5492 L .33003 .54706 L F
.609 .63 .847 r
.33373 .54806 m .3352 .55038 L .33162 .5492 L F
.679 .594 .754 r
.22619 .72614 m .22378 .72926 L .22481 .72716 L F
0 .024 .591 r
.1827 .60622 m .18238 .60776 L .18101 .6039 L F
0 .092 .645 r
.1827 .60622 m .18432 .61028 L .18238 .60776 L F
.132 0 .085 r
.23739 .69121 m .24094 .68705 L .23793 .68964 L F
.734 .484 .55 r
.23707 .69152 m .23739 .69121 L .23793 .68964 L F
.632 .135 0 r
.50943 .60686 m .5085 .60587 L .51268 .60468 L F
.156 .057 .482 r
.51154 .60327 m .50943 .60686 L .51268 .60468 L F
.146 0 0 r
.81979 .39733 m .82282 .39687 L .82298 .3965 L F
0 0 0 r
.82298 .3965 m .82282 .39687 L .82492 .39523 L F
.19847 .54263 m .20087 .54231 L .20278 .5418 L F
.358 .813 .937 r
.20087 .54231 m .20455 .54214 L .20278 .5418 L F
.543 .441 .689 r
.4519 .65375 m .45321 .65565 L .45082 .65385 L F
.85 .719 .719 r
.81496 .4184 m .81496 .42068 L .81132 .42031 L F
.847 .733 .738 r
.81132 .42031 m .81496 .42068 L .81241 .42371 L F
.463 .694 .967 r
.21975 .62319 m .21753 .6234 L .21604 .62177 L F
.588 .162 .201 r
.49247 .60331 m .49471 .60389 L .4922 .60215 L F
.235 .003 .343 r
.1479 .57756 m .14872 .57908 L .14929 .57669 L F
.1479 .57756 m .14712 .57993 L .14872 .57908 L F
.713 .802 .92 r
.21342 .73188 m .2177 .72936 L .2135 .72917 L F
0 0 0 r
.17533 .57626 m .17417 .57647 L .17182 .57685 L F
.786 .99 .888 r
.29135 .58511 m .29463 .58313 L .29318 .58453 L F
.479 .487 .788 r
.29463 .58313 m .29778 .58608 L .297 .58264 L F
.696 .505 .625 r
.297 .58264 m .29318 .58453 L .29463 .58313 L F
.51 .564 .846 r
.23501 .69332 m .23707 .69152 L .2353 .69381 L F
.319 .627 .96 r
.19268 .63055 m .1941 .63213 L .19439 .63055 L F
.325 .632 .962 r
.19439 .63055 m .1941 .63213 L .19527 .63167 L F
.812 .483 .433 r
.51422 .56002 m .51815 .5637 L .51987 .56171 L F
.755 .55 .618 r
.51423 .56014 m .51815 .5637 L .51422 .56002 L F
.255 0 0 r
.51423 .56014 m .51422 .56002 L .51766 .55854 L F
.51423 .56014 m .51766 .55854 L .51397 .55874 L F
.724 .761 .882 r
.79234 .4205 m .79379 .42198 L .79019 .4215 L F
.738 .763 .873 r
.7961 .42113 m .79379 .42198 L .79234 .4205 L F
.172 .064 .481 r
.14339 .58942 m .14469 .58891 L .14597 .58461 L F
.234 .222 .64 r
.14339 .58942 m .14523 .59144 L .14469 .58891 L F
.294 .234 .617 r
.14381 .59215 m .14523 .59144 L .14339 .58942 L F
.053 0 0 r
.53111 .5209 m .53337 .52044 L .53514 .5194 L F
.498 .095 .206 r
.53337 .52044 m .53689 .51827 L .53514 .5194 L F
.732 .899 .954 r
.8309 .43579 m .83343 .43262 L .82996 .43479 L F
.8309 .43579 m .83429 .4338 L .83343 .43262 L F
.756 .383 .348 r
.46773 .66264 m .46676 .66467 L .46517 .66195 L F
0 0 0 r
.46925 .6619 m .46773 .66264 L .46981 .66187 L F
.46925 .6619 m .46676 .66467 L .46773 .66264 L F
.845 .65 .638 r
.22378 .72926 m .22213 .73212 L .22232 .7306 L F
.61 .577 .791 r
.14865 .60143 m .14978 .60449 L .15215 .60336 L F
.455 .255 .519 r
.32331 .59844 m .32317 .60097 L .32088 .60159 L F
.455 .219 .466 r
.32317 .60097 m .32046 .60394 L .32088 .60159 L F
.277 .032 .35 r
.15009 .57433 m .14929 .57669 L .15168 .57368 L F
.764 .473 .492 r
.52213 .56479 m .52161 .56685 L .52646 .56638 L F
.52213 .56479 m .52646 .56638 L .52592 .56623 L F
.746 .543 .62 r
.52213 .56479 m .52592 .56623 L .52541 .56319 L F
.551 .519 .773 r
.52592 .56623 m .52559 .56366 L .52541 .56319 L F
.218 .496 .901 r
.26065 .64913 m .26168 .65076 L .26221 .64931 L F
.523 .832 1 r
.26168 .65076 m .26407 .65023 L .26221 .64931 L F
.876 .867 .826 r
.83618 .41342 m .83441 .41588 L .83298 .41455 L F
.548 .369 .591 r
.27636 .59098 m .27714 .59271 L .27942 .589 L F
.733 .231 .036 r
.50189 .55574 m .50077 .55676 L .49936 .55543 L F
.746 .249 .047 r
.50189 .55574 m .50406 .55798 L .50077 .55676 L F
.725 .194 0 r
.50576 .55856 m .50406 .55798 L .50189 .55574 L F
.325 .751 .973 r
.31741 .54474 m .31867 .54373 L .32143 .54516 L F
.12 .595 .916 r
.31867 .54373 m .32391 .54606 L .32143 .54516 L F
.694 .616 .766 r
.79877 .41804 m .80006 .42202 L .7961 .42113 L F
.694 .629 .78 r
.80165 .41534 m .80123 .42131 L .79877 .41804 L F
.643 .585 .774 r
.80393 .41622 m .80123 .42131 L .80165 .41534 L F
.593 .515 .736 r
.80393 .41622 m .80259 .42092 L .80123 .42131 L F
.651 .592 .775 r
.80259 .42092 m .79877 .41804 L .80123 .42131 L F
.80259 .42092 m .80006 .42202 L .79877 .41804 L F
.224 .075 .458 r
.22006 .55173 m .21999 .55493 L .21879 .55275 L F
.054 .564 .879 r
.22798 .62517 m .22768 .62568 L .22584 .6253 L F
.22798 .62517 m .22966 .62604 L .22768 .62568 L F
.835 .772 .791 r
.55186 .55532 m .55287 .55871 L .5517 .55751 L F
.941 .801 .678 r
.55136 .56191 m .5517 .55751 L .55287 .55871 L F
.499 .236 .447 r
.31369 .61641 m .3109 .61917 L .31155 .61704 L F
.125 0 0 r
.23846 .53651 m .24078 .5363 L .24258 .5355 L F
0 0 0 r
.24078 .5363 m .24478 .53542 L .24258 .5355 L F
.9 .864 .796 r
.84311 .42082 m .84291 .41736 L .84072 .4205 L F
.84311 .42082 m .84416 .41863 L .84291 .41736 L F
.895 .85 .791 r
.84085 .42396 m .84311 .42082 L .84072 .4205 L F
.928 .719 .601 r
.55777 .55774 m .5599 .55599 L .55831 .55507 L F
.55777 .55774 m .5595 .55851 L .5599 .55599 L F
.818 .642 .664 r
.55482 .53132 m .55242 .53127 L .55268 .52812 L F
.927 .675 .537 r
.55482 .53132 m .55282 .53315 L .55242 .53127 L F
.55482 .53132 m .55477 .53426 L .55282 .53315 L F
.523 .919 .879 r
.20902 .54076 m .2095 .5399 L .21113 .53982 L F
.20902 .54076 m .20662 .54107 L .2095 .5399 L F
.245 0 0 r
.48648 .63216 m .48942 .63198 L .48898 .63234 L F
.256 .442 .853 r
.48648 .63216 m .48898 .63234 L .48789 .63125 L F
.738 .763 .873 r
.7961 .42113 m .79234 .4205 L .79519 .41752 L F
.765 .734 .824 r
.79877 .41804 m .7961 .42113 L .79519 .41752 L F
.27 0 .305 r
.47362 .62462 m .47214 .62341 L .47434 .62272 L F
.47362 .62462 m .47159 .62536 L .47214 .62341 L F
.507 .612 .891 r
.77444 .42252 m .77502 .42458 L .77681 .42228 L F
.448 .526 .845 r
.77502 .42458 m .77734 .42463 L .77681 .42228 L F
.402 .525 .867 r
.77502 .42458 m .77868 .42766 L .77734 .42463 L F
.816 .751 .792 r
.24174 .68386 m .24094 .68705 L .24319 .68658 L F
.199 0 0 r
.24112 .68855 m .24094 .68705 L .23739 .69121 L F
.24112 .68855 m .24319 .68658 L .24094 .68705 L F
.558 .287 .461 r
.30357 .62566 m .3002 .62819 L .30033 .62633 L F
.493 .645 .925 r
.17914 .62239 m .17863 .61913 L .17722 .61894 L F
.17914 .62239 m .1815 .62208 L .17863 .61913 L F
.435 .548 .871 r
.76999 .41914 m .77112 .42174 L .77292 .41959 L F
.747 .578 .004 r
.28458 .58022 m .28453 .58139 L .28365 .58136 L F
.28458 .58022 m .2847 .58297 L .28453 .58139 L F
.587 .597 .829 r
.80903 .42111 m .80676 .42351 L .80519 .42031 L F
.80903 .42111 m .80923 .42285 L .80676 .42351 L F
.462 .6 .903 r
.21133 .63928 m .21213 .63701 L .20991 .6375 L F
.21133 .63928 m .21502 .63971 L .21213 .63701 L F
0 0 0 r
.26443 .61544 m .2658 .61347 L .26308 .61631 L F
.26688 .61238 m .2658 .61347 L .26443 .61544 L F
.643 .113 0 r
.50576 .55856 m .50427 .55953 L .50406 .55798 L F
.50576 .55856 m .50817 .56028 L .50427 .55953 L F
.107 0 0 r
.22782 .6416 m .22808 .64235 L .22598 .64144 L F
.22782 .6416 m .22974 .64128 L .22808 .64235 L F
.653 .629 .813 r
.81132 .42031 m .81003 .4247 L .80923 .42285 L F
.81132 .42031 m .81241 .42371 L .81003 .4247 L F
.576 .53 .767 r
.53882 .59533 m .54068 .59239 L .53817 .59299 L F
.53882 .59533 m .54172 .59499 L .54068 .59239 L F
.317 .335 .722 r
.50749 .59581 m .50837 .59887 L .5097 .59764 L F
.09 0 .436 r
.50819 .60122 m .5097 .59764 L .50837 .59887 L F
.326 0 .247 r
.81224 .41001 m .80982 .4093 L .81242 .40857 L F
.81224 .41001 m .80933 .41111 L .80982 .4093 L F
.793 .668 .725 r
.47866 .61336 m .48161 .61074 L .47873 .61074 L F
.579 .701 .925 r
.82938 .41419 m .82851 .41733 L .82631 .41507 L F
.82938 .41419 m .82989 .4174 L .82851 .41733 L F
.454 .087 .251 r
.28658 .63842 m .28363 .64033 L .28409 .63844 L F
.579 .335 .511 r
.46939 .6261 m .46906 .62856 L .46639 .62878 L F
.507 .313 .552 r
.47159 .62536 m .46906 .62856 L .46939 .6261 L F
.473 .384 .674 r
.79259 .40283 m .79497 .40207 L .79228 .40033 L F
.6 .324 .469 r
.79228 .40033 m .79497 .40207 L .79464 .39999 L F
.473 .384 .674 r
.79259 .40283 m .79497 .40207 L .79228 .40033 L F
.793 .543 .559 r
.56141 .59544 m .56076 .59617 L .55731 .59504 L F
.452 .466 .782 r
.56141 .59544 m .5622 .59129 L .56076 .59617 L F
.56141 .59544 m .56355 .59491 L .5622 .59129 L F
.737 .448 .49 r
.54489 .52243 m .54126 .52238 L .54396 .52209 L F
.246 0 .017 r
.17031 .55821 m .17244 .55771 L .17402 .55566 L F
.239 0 .013 r
.17402 .55566 m .1747 .55706 L .17597 .55479 L F
.17402 .55566 m .17244 .55771 L .1747 .55706 L F
.317 .335 .722 r
.50749 .59581 m .5097 .59764 L .51137 .5985 L F
.93 .667 .517 r
.5097 .59764 m .51148 .60065 L .51137 .5985 L F
.887 .55 .405 r
.79764 .40912 m .79623 .41065 L .79612 .40826 L F
.79764 .40912 m .79799 .41134 L .79623 .41065 L F
.876 .867 .826 r
.83618 .41342 m .83298 .41455 L .8354 .4121 L F
.633 .837 .979 r
.8389 .41236 m .83618 .41342 L .8354 .4121 L F
.576 .901 .983 r
.23851 .69386 m .24242 .69348 L .24045 .69286 L F
.607 .887 .99 r
.24045 .69286 m .24242 .69348 L .24454 .6924 L F
.056 .589 .86 r
.45321 .65565 m .45689 .65655 L .45569 .656 L F
.898 .956 .827 r
.45569 .656 m .45689 .65655 L .45935 .65328 L F
.655 .464 .613 r
.33205 .58294 m .3308 .58071 L .332 .58017 L F
.33205 .58294 m .32978 .58335 L .3308 .58071 L F
.681 .175 .032 r
.50749 .59581 m .50592 .59689 L .50371 .59474 L F
.952 .882 .481 r
.50798 .59155 m .50698 .59492 L .50749 .59581 L F
.941 .944 .611 r
.50698 .59492 m .50592 .59689 L .50749 .59581 L F
.146 .673 .873 r
.23405 .64197 m .23438 .64135 L .23137 .64176 L F
.23405 .64197 m .23579 .64193 L .23438 .64135 L F
.856 .579 .518 r
.56095 .56959 m .56423 .568 L .56086 .56713 L F
.56095 .56959 m .56438 .57051 L .56423 .568 L F
.494 .186 .373 r
.47028 .61966 m .47314 .61923 L .47366 .61661 L F
.603 .436 .628 r
.47366 .61661 m .47624 .61647 L .47605 .61382 L F
.564 .561 .809 r
.47691 .61875 m .47366 .61661 L .47624 .61647 L F
.317 .035 .317 r
.47366 .61661 m .47529 .61844 L .47624 .61647 L F
.47366 .61661 m .47314 .61923 L .47529 .61844 L F
.784 .571 .612 r
.46313 .64118 m .46351 .64409 L .46141 .64361 L F
0 0 0 r
.46141 .64361 m .46192 .64309 L .46313 .64118 L F
.387 .288 .62 r
.46545 .64321 m .46351 .64409 L .46313 .64118 L F
.643 .237 .261 r
.46192 .64309 m .46545 .64321 L .46313 .64118 L F
.469 .277 .536 r
.32047 .60667 m .31819 .60452 L .32046 .60394 L F
.32047 .60667 m .31796 .60736 L .31819 .60452 L F
0 0 0 r
.42435 .66046 m .42302 .66266 L .42434 .66071 L F
.528 .646 .908 r
.42302 .66266 m .42597 .66264 L .42434 .66071 L F
.472 0 0 r
.54489 .52243 m .54374 .52347 L .54126 .52238 L F
.596 .066 0 r
.54489 .52243 m .54753 .52403 L .54374 .52347 L F
.457 .84 .986 r
.26715 .53545 m .26955 .5349 L .27143 .53561 L F
.498 .858 .989 r
.27143 .53561 m .27175 .53428 L .27365 .53483 L F
.27143 .53561 m .26955 .5349 L .27175 .53428 L F
.641 .858 .982 r
.27992 .53425 m .27762 .53535 L .27598 .53421 L F
.197 .471 .888 r
.30622 .57537 m .30589 .57725 L .30499 .57583 L F
.565 .577 .825 r
.30622 .57537 m .30548 .57952 L .30589 .57725 L F
.421 .127 .358 r
.30548 .57952 m .30838 .57694 L .30589 .57725 L F
.84 .932 .889 r
.54901 .57289 m .54728 .57443 L .54751 .57205 L F
.517 .588 .865 r
.33598 .54757 m .3352 .55038 L .33373 .54806 L F
.462 .53 .842 r
.33598 .54757 m .33784 .55156 L .3352 .55038 L F
.569 .439 .664 r
.32535 .59551 m .32573 .59806 L .32331 .59844 L F
.573 .37 .568 r
.32573 .59806 m .32317 .60097 L .32331 .59844 L F
.816 .438 .34 r
.51815 .5637 m .51921 .56292 L .51987 .56171 L F
.502 .451 .732 r
.31565 .5428 m .31867 .54373 L .31741 .54474 L F
.305 0 0 r
.18892 .83024 m .19202 .8298 L .19127 .83036 L F
.18892 .83024 m .19202 .8298 L .19127 .83036 L F
0 0 0 r
.19127 .83036 m .19202 .8298 L .19337 .82956 L F
.19337 .82956 m .19202 .8298 L .19127 .83036 L F
.85 .719 .719 r
.81496 .4184 m .81132 .42031 L .81389 .41685 L F
.778 .892 .925 r
.81562 .416 m .81496 .4184 L .81389 .41685 L F
.81562 .416 m .818 .41615 L .81496 .4184 L F
.25 0 0 r
.25284 .5527 m .25142 .55266 L .24888 .55216 L F
0 .565 .709 r
.25343 .55271 m .25284 .5527 L .25509 .55213 L F
.25343 .55271 m .25142 .55266 L .25284 .5527 L F
.47 .501 .808 r
.52101 .57037 m .52161 .56685 L .51892 .56931 L F
.52101 .57037 m .52314 .57031 L .52161 .56685 L F
.973 .682 .286 r
.84275 .39716 m .84156 .39348 L .84168 .39597 L F
1 .811 .507 r
.84236 .39955 m .84275 .39716 L .84168 .39597 L F
.579 .727 .944 r
.80291 .43595 m .80423 .43299 L .80178 .43429 L F
.80291 .43595 m .80595 .4354 L .80423 .43299 L F
.595 .673 .894 r
.80291 .43595 m .80636 .43699 L .80595 .4354 L F
.968 .751 .556 r
.21733 .73211 m .21902 .73278 L .2177 .72936 L F
.21733 .73211 m .21902 .73278 L .2177 .72936 L F
.451 .383 .689 r
.80636 .43699 m .80682 .43907 L .80915 .43891 L F
.606 .685 .898 r
.80595 .4354 m .80636 .43699 L .80818 .43588 L F
.469 .38 .672 r
.80636 .43699 m .80915 .43891 L .80818 .43588 L F
.412 0 .118 r
.19342 .56385 m .18959 .56618 L .19179 .56418 L F
.863 .66 .626 r
.56063 .5208 m .56402 .51922 L .56021 .51834 L F
.56063 .5208 m .56379 .52184 L .56402 .51922 L F
.631 .749 .933 r
.81402 .44316 m .81672 .44232 L .81299 .44144 L F
.233 .734 .904 r
.23426 .62604 m .23378 .62668 L .23206 .62655 L F
.23426 .62604 m .23609 .62651 L .23378 .62668 L F
.864 .652 .614 r
.57317 .5827 m .57496 .58342 L .57326 .57996 L F
.904 .74 .667 r
.57272 .58498 m .57496 .58342 L .57317 .5827 L F
.57272 .58498 m .57457 .58599 L .57496 .58342 L F
.813 .738 .781 r
.52826 .5795 m .53192 .57984 L .53071 .57634 L F
.825 .685 .709 r
.52826 .5795 m .52983 .58315 L .53192 .57984 L F
.885 .768 .728 r
.53192 .57984 m .53255 .57532 L .53071 .57634 L F
.57 .305 .475 r
.31686 .61333 m .31636 .61623 L .31369 .61641 L F
.548 .521 .778 r
.31911 .61277 m .31686 .61333 L .31601 .61053 L F
.466 .213 .445 r
.31871 .61553 m .31686 .61333 L .31911 .61277 L F
.31871 .61553 m .31636 .61623 L .31686 .61333 L F
.677 .938 .965 r
.82986 .40198 m .8339 .40107 L .83283 .39946 L F
.752 .848 .922 r
.8339 .40107 m .83608 .3996 L .83283 .39946 L F
.25 .197 .6 r
.26093 .55181 m .26235 .5475 L .26208 .54924 L F
.208 0 .069 r
.49854 .60392 m .49546 .60626 L .49638 .60466 L F
.586 .423 .628 r
.47605 .61382 m .47624 .61647 L .47866 .61336 L F
.862 .416 .03 r
.51691 .56787 m .51549 .56694 L .51454 .56504 L F
.533 0 0 r
.51892 .56931 m .51549 .56694 L .51691 .56787 L F
.711 .665 .803 r
.79026 .43676 m .7941 .43765 L .79286 .43578 L F
.708 .711 .851 r
.7941 .43765 m .79654 .43656 L .79286 .43578 L F
.155 0 0 r
.8109 .39993 m .81281 .40052 L .81356 .39929 L F
.8109 .39993 m .81025 .40145 L .81281 .40052 L F
.393 .794 .984 r
.56979 .59218 m .56853 .59137 L .56599 .59174 L F
.797 .664 .716 r
.56599 .59174 m .56748 .59537 L .56979 .59218 L F
.911 .946 .812 r
.5709 .58811 m .56979 .59218 L .57216 .58913 L F
.5709 .58811 m .56853 .59137 L .56979 .59218 L F
.895 .921 .831 r
.55097 .57013 m .54901 .57289 L .54751 .57205 L F
.523 .313 .537 r
.33481 .57987 m .33205 .58294 L .332 .58017 L F
.836 .818 .833 r
.25927 .55285 m .25662 .55571 L .25705 .55318 L F
.445 .446 .765 r
.25662 .55571 m .2585 .5556 L .25705 .55318 L F
.433 0 0 r
.27897 .55676 m .27736 .55802 L .2751 .55785 L F
.603 .135 .115 r
.28131 .55801 m .27736 .55802 L .27897 .55676 L F
0 .117 .642 r
.34063 .55795 m .34185 .56071 L .34079 .56167 L F
.957 .902 .727 r
.34185 .56071 m .34128 .56247 L .34079 .56167 L F
0 0 .251 r
.34128 .56247 m .34114 .56494 L .34079 .56167 L F
.074 0 0 r
.49464 .60859 m .49397 .60794 L .49546 .60626 L F
.49464 .60859 m .49223 .60914 L .49397 .60794 L F
.591 .306 .453 r
.23702 .7117 m .23606 .7142 L .23356 .71394 L F
.46 .255 .513 r
.23861 .71076 m .23606 .7142 L .23702 .7117 L F
.565 .329 .517 r
.48054 .5618 m .48345 .56419 L .48046 .56408 L F
.48054 .5618 m .48345 .56419 L .48046 .56408 L F
.257 0 0 r
.18343 .55158 m .18754 .5491 L .18532 .54966 L F
.547 .347 .562 r
.48161 .61074 m .48395 .61049 L .48401 .60778 L F
.553 .34 .545 r
.22554 .71619 m .22747 .71766 L .22774 .7147 L F
.673 .65 .819 r
.53471 .5921 m .53817 .59299 L .53731 .59109 L F
.569 .549 .792 r
.53817 .59299 m .53902 .58911 L .53731 .59109 L F
.53817 .59299 m .54068 .59239 L .53902 .58911 L F
.561 .812 .992 r
.22181 .55633 m .22404 .55556 L .21999 .55493 L F
.22181 .55633 m .22404 .55556 L .21999 .55493 L F
.898 .956 .827 r
.45569 .656 m .45935 .65328 L .45545 .65309 L F
.811 .905 .906 r
.82282 .43978 m .82414 .43654 L .82153 .43845 L F
.82282 .43978 m .82471 .43812 L .82414 .43654 L F
.264 .044 .381 r
.14518 .58247 m .14712 .57993 L .14586 .58092 L F
.375 .059 .296 r
.1654 .56172 m .16758 .56113 L .16851 .55912 L F
.372 .056 .294 r
.16851 .55912 m .16977 .56053 L .17031 .55821 L F
.16851 .55912 m .16758 .56113 L .16977 .56053 L F
.405 .511 .853 r
.77734 .42463 m .77868 .42766 L .78048 .42565 L F
.49 .644 .925 r
.77868 .42766 m .78101 .42746 L .78048 .42565 L F
.833 .582 .559 r
.56802 .57366 m .57165 .5759 L .56974 .57405 L F
.733 .597 .704 r
.24174 .68386 m .24624 .6839 L .24705 .68094 L F
.477 .337 .611 r
.24624 .6839 m .24894 .68376 L .24705 .68094 L F
.966 .909 .553 r
.24624 .6839 m .24705 .68094 L .24894 .68376 L F
.505 .162 .319 r
.79876 .40523 m .80234 .40268 L .79871 .40253 L F
.79876 .40523 m .80143 .40512 L .80234 .40268 L F
.439 .013 .131 r
.80143 .40512 m .80501 .40303 L .80234 .40268 L F
.732 .809 .912 r
.83298 .41455 m .82989 .4174 L .82938 .41419 L F
.586 .568 .8 r
.50132 .63455 m .50349 .63594 L .50254 .63387 L F
.759 .479 .51 r
.50242 .63726 m .50349 .63594 L .50132 .63455 L F
.295 .339 .738 r
.76621 .4148 m .76727 .41906 L .7689 .4168 L F
.518 .649 .916 r
.76727 .41906 m .76999 .41914 L .7689 .4168 L F
.438 .191 .441 r
.32819 .59214 m .32757 .59505 L .32535 .59551 L F
.527 .272 .471 r
.33033 .59426 m .32757 .59505 L .32819 .59214 L F
.626 .259 .328 r
.33097 .59254 m .33033 .59426 L .32819 .59214 L F
.632 .135 0 r
.50943 .60686 m .50898 .6065 L .5085 .60587 L F
.824 .408 0 r
.50943 .60686 m .50965 .60858 L .50898 .6065 L F
.156 .057 .482 r
.51154 .60327 m .51133 .60631 L .50943 .60686 L F
.793 .982 .713 r
.20632 .55714 m .20582 .55829 L .2062 .55843 L F
.845 .971 .656 r
.20582 .55829 m .20441 .56017 L .2062 .55843 L F
.013 0 0 r
.8161 .39846 m .81886 .39793 L .81979 .39733 L F
0 0 0 r
.81979 .39733 m .82138 .39712 L .82282 .39687 L F
.81979 .39733 m .81886 .39793 L .82138 .39712 L F
.26308 .61631 m .26243 .61865 L .26443 .61544 L F
.965 .644 .351 r
.48996 .56992 m .49047 .57235 L .49178 .57114 L F
.48996 .56992 m .49047 .57235 L .49178 .57114 L F
.155 .065 .493 r
.49269 .57172 m .49263 .57274 L .49178 .57114 L F
.241 0 0 r
.26298 .55583 m .26158 .55603 L .2585 .5556 L F
.373 0 0 r
.26504 .55493 m .26158 .55603 L .26298 .55583 L F
.626 .783 .957 r
.28382 .53501 m .27992 .53425 L .2822 .53326 L F
.531 .72 .96 r
.2822 .53326 m .2861 .53452 L .28382 .53501 L F
.952 .724 .557 r
.54882 .52514 m .54669 .5269 L .54753 .52403 L F
.54882 .52514 m .54877 .52803 L .54669 .5269 L F
.746 .544 .622 r
.55268 .52812 m .54877 .52803 L .54882 .52514 L F
.5 .146 .297 r
.25705 .55318 m .26093 .55181 L .25927 .55285 L F
.692 .569 .711 r
.34163 .55242 m .33935 .55555 L .33882 .55284 L F
.696 .712 .861 r
.34163 .55242 m .33882 .55284 L .33784 .55156 L F
.34163 .55242 m .33784 .55156 L .34018 .55088 L F
0 0 .096 r
.34018 .55088 m .33935 .55555 L .34163 .55242 L F
.34018 .55088 m .33979 .55587 L .33935 .55555 L F
0 0 .423 r
.34003 .5561 m .33935 .55555 L .33979 .55587 L F
.34003 .5561 m .34063 .55795 L .33935 .55555 L F
.273 .022 .338 r
.27986 .57417 m .27925 .57638 L .2817 .57337 L F
.833 .582 .559 r
.56802 .57366 m .5698 .57646 L .57165 .5759 L F
.846 .619 .595 r
.5698 .57646 m .56989 .57942 L .57165 .5759 L F
.856 .633 .599 r
.57165 .5759 m .56989 .57942 L .57326 .57996 L F
.284 0 .28 r
.28253 .57129 m .28371 .57258 L .28433 .57031 L F
.28253 .57129 m .2817 .57337 L .28371 .57258 L F
0 .043 .594 r
.46517 .66195 m .46676 .66467 L .46568 .66121 L F
.809 .839 .873 r
.18887 .76251 m .19084 .76376 L .19263 .76191 L F
.18887 .76251 m .19084 .76376 L .19263 .76191 L F
.709 .239 0 r
.84247 .41384 m .84367 .41504 L .84242 .41322 L F
.894 .599 .48 r
.5652 .52786 m .56538 .53051 L .56755 .53058 L F
.913 .771 .69 r
.56538 .53051 m .56651 .53407 L .56755 .53058 L F
.898 .852 .788 r
.84072 .4205 m .83907 .42365 L .84085 .42396 L F
.96 .863 .699 r
.83831 .42593 m .84085 .42396 L .83907 .42365 L F
.83831 .42593 m .83954 .42695 L .84085 .42396 L F
.113 0 .055 r
.27442 .57997 m .27651 .57916 L .27734 .57738 L F
.523 .134 .246 r
.27734 .57738 m .27905 .5786 L .27925 .57638 L F
.27734 .57738 m .27651 .57916 L .27905 .5786 L F
.513 .516 .796 r
.48161 .61074 m .48481 .6131 L .48395 .61049 L F
.571 .57 .813 r
.53731 .59109 m .53354 .5887 L .53471 .5921 L F
.096 0 .288 r
.27199 .60092 m .2709 .60183 L .27028 .60416 L F
.675 .397 .494 r
.52691 .57619 m .53061 .57418 L .52693 .5734 L F
.52691 .57619 m .53071 .57634 L .53061 .57418 L F
.761 .319 .203 r
.53255 .57532 m .53061 .57418 L .53071 .57634 L F
.262 .517 .907 r
.16753 .61354 m .16806 .61187 L .16659 .61223 L F
.16753 .61354 m .16884 .61352 L .16806 .61187 L F
.7 .807 .932 r
.19611 .61384 m .19209 .61352 L .19463 .61218 L F
.672 .742 .903 r
.19856 .61282 m .19611 .61384 L .19463 .61218 L F
.525 .021 .002 r
.24451 .68551 m .24624 .6839 L .24174 .68386 L F
0 .029 .539 r
.24785 .6859 m .24671 .68696 L .24624 .6839 L F
.421 .105 .321 r
.24785 .6859 m .24624 .6839 L .24451 .68551 L F
.24785 .6859 m .24894 .68376 L .24624 .6839 L F
0 .029 .539 r
.24785 .6859 m .24624 .6839 L .24894 .68376 L F
.637 .764 .94 r
.21781 .53678 m .21374 .53633 L .21616 .53571 L F
.093 0 0 r
.21976 .53747 m .21616 .53571 L .21781 .53678 L F
.444 .467 .789 r
.28346 .56434 m .2852 .56866 L .28653 .56706 L F
.762 .436 .434 r
.79464 .39999 m .79497 .40207 L .79871 .40253 L F
.023 .596 .742 r
.24478 .53542 m .24686 .53542 L .24883 .53552 L F
.234 .751 .837 r
.24686 .53542 m .25078 .53505 L .24883 .53552 L F
.351 .565 .918 r
.18574 .6266 m .18665 .62488 L .18501 .62477 L F
.18574 .6266 m .18876 .6278 L .18665 .62488 L F
.725 .903 .53 r
.27484 .59539 m .27275 .59857 L .27345 .59702 L F
0 0 0 r
.27275 .59857 m .27291 .59951 L .27345 .59702 L F
.27275 .59857 m .27199 .60092 L .27291 .59951 L F
.469 .596 .897 r
.81084 .4416 m .81188 .43886 L .80915 .43891 L F
.81084 .4416 m .81299 .44144 L .81188 .43886 L F
.469 .657 .942 r
.17076 .61697 m .17498 .61933 L .17272 .61625 L F
.498 .745 .983 r
.17498 .61933 m .17594 .61749 L .17272 .61625 L F
.17498 .61933 m .17722 .61894 L .17594 .61749 L F
.783 .56 .597 r
.8015 .41195 m .79783 .41459 L .79799 .41134 L F
.8015 .41195 m .80165 .41534 L .79783 .41459 L F
.668 .47 .607 r
.80387 .41436 m .8015 .41195 L .80372 .41213 L F
.80387 .41436 m .80165 .41534 L .8015 .41195 L F
.636 .469 .64 r
.4519 .65375 m .45321 .65565 L .45545 .65309 L F
.594 .382 .564 r
.80659 .41371 m .80372 .41213 L .80672 .41173 L F
.80659 .41371 m .80387 .41436 L .80372 .41213 L F
.793 .783 .844 r
.24207 .64273 m .24326 .64447 L .24618 .64227 L F
.49 .649 .929 r
.21426 .61956 m .21378 .6219 L .21195 .61998 L F
.21426 .61956 m .21604 .62177 L .21378 .6219 L F
.483 .891 .929 r
.24222 .62568 m .24023 .62646 L .23815 .62631 L F
.489 .903 .873 r
.22747 .71766 m .23079 .71665 L .22948 .71657 L F
.843 .99 .854 r
.23091 .71481 m .22948 .71657 L .23079 .71665 L F
.895 .921 .831 r
.55097 .57013 m .54751 .57205 L .54952 .56852 L F
.83 .984 .703 r
.52845 .52341 m .52747 .52333 L .52908 .52235 L F
.83 .742 .221 r
.52735 .52546 m .52747 .52333 L .52845 .52341 L F
.265 .327 .74 r
.16886 .58497 m .16764 .5866 L .16658 .58294 L F
0 0 0 r
.16886 .58497 m .16811 .58907 L .16764 .5866 L F
.401 .563 .899 r
.18181 .62373 m .18271 .62171 L .1815 .62208 L F
.18181 .62373 m .18501 .62477 L .18271 .62171 L F
.673 .896 .977 r
.25169 .66889 m .25572 .6686 L .25393 .66798 L F
.888 .466 .172 r
.25393 .66798 m .25572 .6686 L .2563 .67189 L F
.557 .391 .612 r
.25802 .66542 m .25846 .66846 L .25572 .6686 L F
.497 .165 .335 r
.25572 .6686 m .25846 .66846 L .2563 .67189 L F
.337 .295 .663 r
.14381 .59215 m .14405 .59581 L .14585 .59406 L F
.402 .395 .737 r
.14405 .59581 m .14658 .59755 L .14585 .59406 L F
.56 .598 .848 r
.42409 .65316 m .42543 .64981 L .42298 .65069 L F
.42409 .65316 m .42665 .65299 L .42543 .64981 L F
.355 .234 .574 r
.42658 .65499 m .42409 .65316 L .42665 .65299 L F
.42658 .65499 m .42419 .65601 L .42409 .65316 L F
.896 .649 .557 r
.47582 .64116 m .47536 .64363 L .47317 .63937 L F
.874 .647 .591 r
.47317 .63937 m .47536 .64363 L .47246 .64267 L F
.322 0 0 r
.47536 .64363 m .47455 .64347 L .47246 .64267 L F
.418 .241 .532 r
.4751 .63976 m .47455 .64347 L .47575 .64255 L F
.825 .509 0 r
.4751 .63976 m .47526 .64044 L .47582 .64116 L F
0 0 .062 r
.47628 .64214 m .47582 .64116 L .47526 .64044 L F
.47628 .64214 m .47536 .64363 L .47582 .64116 L F
.418 .241 .532 r
.47526 .64044 m .47575 .64255 L .47628 .64214 L F
0 0 .062 r
.47628 .64214 m .47526 .64044 L .47523 .64041 L F
.418 .241 .532 r
.4751 .63976 m .47526 .64044 L .47628 .64214 L F
.825 .509 0 r
.4751 .63976 m .47523 .64041 L .47526 .64044 L F
.636 .466 .636 r
.3002 .62819 m .29762 .63136 L .29772 .62878 L F
.733 .435 .475 r
.55509 .54643 m .55276 .54845 L .55542 .54461 L F
0 .359 .764 r
.20597 .75893 m .20589 .75929 L .20787 .76013 L F
.20597 .75893 m .20589 .75929 L .20787 .76013 L F
.756 .41 .399 r
.50283 .55173 m .50683 .55421 L .50466 .55204 L F
.373 .666 .972 r
.34018 .55088 m .34227 .55087 L .34163 .55242 L F
.34018 .55088 m .34227 .55087 L .34163 .55242 L F
0 .164 .703 r
.3421 .5522 m .344 .55474 L .34163 .55242 L F
.317 0 .18 r
.27146 .64425 m .27504 .64108 L .27454 .64343 L F
.525 .237 .421 r
.27454 .64343 m .27504 .64108 L .27721 .64292 L F
.583 .217 .314 r
.27504 .64108 m .27772 .64112 L .27721 .64292 L F
.587 .798 .98 r
.20432 .63747 m .20766 .63811 L .20462 .63795 L F
.187 0 0 r
.20991 .6375 m .20462 .63795 L .20766 .63811 L F
.82 .614 .623 r
.56951 .58204 m .57326 .57996 L .56989 .57942 L F
.56951 .58204 m .57317 .5827 L .57326 .57996 L F
.295 0 .083 r
.25666 .62406 m .25518 .62334 L .25449 .62436 L F
.25666 .62406 m .25735 .62293 L .25518 .62334 L F
.55 .689 .932 r
.17744 .59787 m .17726 .60086 L .17522 .59796 L F
.17744 .59787 m .17942 .60035 L .17726 .60086 L F
.87 .701 .67 r
.56369 .5244 m .5652 .52786 L .56572 .52518 L F
.899 .863 .795 r
.5709 .58811 m .57457 .58599 L .57272 .58498 L F
.5709 .58811 m .57216 .58913 L .57457 .58599 L F
.709 .541 .659 r
.57457 .58599 m .57216 .58913 L .57468 .58804 L F
.912 .934 .812 r
.23726 .70169 m .23418 .70352 L .23558 .70168 L F
.23726 .70169 m .23486 .70503 L .23418 .70352 L F
.598 .425 .618 r
.23726 .70169 m .23715 .70508 L .23486 .70503 L F
.461 .887 .898 r
.23976 .70078 m .23726 .70169 L .23558 .70168 L F
.639 .631 .827 r
.23976 .70078 m .24048 .70268 L .23726 .70169 L F
.653 .47 .624 r
.24071 .70397 m .23726 .70169 L .24048 .70268 L F
.24071 .70397 m .23715 .70508 L .23726 .70169 L F
.929 .546 .224 r
.50564 .58797 m .50798 .59155 L .50735 .58962 L F
.552 .582 .837 r
.18179 .59987 m .18101 .6039 L .17942 .60035 L F
.18179 .59987 m .18351 .60339 L .18101 .6039 L F
0 .024 .591 r
.1827 .60622 m .18101 .6039 L .18351 .60339 L F
.582 .631 .865 r
.33003 .54706 m .32769 .5483 L .32657 .54555 L F
.337 .295 .663 r
.14381 .59215 m .14585 .59406 L .14523 .59144 L F
0 0 0 r
.22874 .54961 m .22448 .55063 L .2265 .55004 L F
.344 .823 .823 r
.82009 .40333 m .82112 .40336 L .82372 .40251 L F
.122 .669 .703 r
.22392 .53747 m .22379 .5375 L .22151 .53773 L F
.22392 .53747 m .22605 .53712 L .22379 .5375 L F
.867 .687 .656 r
.55268 .52812 m .54929 .53005 L .54877 .52803 L F
.55268 .52812 m .55242 .53127 L .54929 .53005 L F
.434 .24 .516 r
.22774 .7147 m .22948 .71657 L .22999 .71331 L F
.22774 .7147 m .22747 .71766 L .22948 .71657 L F
.554 .568 .823 r
.19013 .63109 m .19107 .62727 L .18876 .6278 L F
.19013 .63109 m .19268 .63055 L .19107 .62727 L F
.425 0 .084 r
.26906 .64413 m .27159 .64525 L .26887 .64662 L F
.26906 .64413 m .27146 .64425 L .27159 .64525 L F
.434 .246 .525 r
.44935 .65296 m .44915 .65569 L .447 .65615 L F
.771 .701 .786 r
.44935 .65296 m .447 .65615 L .44638 .65264 L F
.793 .783 .844 r
.24207 .64273 m .24618 .64227 L .24479 .6426 L F
.449 .871 .747 r
.24673 .64149 m .24618 .64227 L .24691 .64204 L F
.24673 .64149 m .24479 .6426 L .24618 .64227 L F
.405 .614 .935 r
.47904 .61754 m .47691 .61875 L .47624 .61647 L F
.47904 .61754 m .47943 .61868 L .47691 .61875 L F
.611 .407 .58 r
.47943 .61868 m .47642 .62172 L .47691 .61875 L F
.571 .57 .813 r
.53731 .59109 m .53769 .59014 L .53354 .5887 L F
.597 .574 .798 r
.50349 .63594 m .50521 .63447 L .50254 .63387 L F
0 0 0 r
.50242 .63726 m .50521 .63447 L .50349 .63594 L F
.241 0 0 r
.25973 .54683 m .25616 .54862 L .25766 .54719 L F
.074 0 0 r
.2444 .62584 m .24625 .62594 L .24222 .62568 L F
.261 .766 .871 r
.2466 .62547 m .24625 .62594 L .2444 .62584 L F
.755 .742 .841 r
.27531 .61091 m .27519 .61327 L .2727 .614 L F
.542 .351 .571 r
.27261 .61678 m .27519 .61327 L .2727 .614 L F
0 0 .289 r
.27346 .61481 m .2727 .614 L .27519 .61327 L F
.755 .742 .841 r
.27531 .61091 m .27519 .61327 L .2727 .614 L F
.542 .351 .571 r
.27261 .61678 m .27527 .61632 L .27519 .61327 L F
.554 .379 .598 r
.27756 .61045 m .27519 .61327 L .27531 .61091 L F
0 0 0 r
.27531 .61222 m .27531 .61168 L .27638 .61029 L F
.27531 .61168 m .27519 .61327 L .2753 .611 L F
.82 .949 .601 r
.27346 .61481 m .27519 .61327 L .27531 .61168 L F
0 0 0 r
.27437 .61394 m .27531 .61168 L .27531 .61222 L F
.27531 .61168 m .2753 .611 L .27531 .61091 L F
.554 .379 .598 r
.27756 .61045 m .27765 .61304 L .27519 .61327 L F
.424 .26 .553 r
.27519 .61327 m .27731 .61555 L .27765 .61304 L F
.27519 .61327 m .27527 .61632 L .27731 .61555 L F
.808 .67 .711 r
.52161 .56685 m .52314 .57031 L .52646 .56638 L F
.462 .33 .615 r
.52847 .5656 m .52592 .56623 L .52646 .56638 L F
.558 .443 .678 r
.27421 .5825 m .27651 .57916 L .27442 .57997 L F
.483 .19 .391 r
.46639 .62878 m .46625 .63121 L .46315 .63139 L F
.623 .304 .409 r
.46878 .63092 m .46625 .63121 L .46639 .62878 L F
.574 .317 .489 r
.46906 .62856 m .46878 .63092 L .46639 .62878 L F
.787 .462 .439 r
.55263 .51729 m .55619 .51586 L .55259 .51575 L F
.55263 .51729 m .55634 .51794 L .55619 .51586 L F
.426 .027 .177 r
.31055 .57077 m .30898 .57318 L .30654 .57352 L F
.519 .401 .658 r
.31104 .57334 m .31295 .57024 L .31055 .57077 L F
.31104 .57334 m .31334 .57284 L .31295 .57024 L F
.703 .334 .345 r
.31055 .57077 m .31334 .57284 L .31295 .57024 L F
.31055 .57077 m .30898 .57318 L .31334 .57284 L F
.31334 .57284 m .30898 .57318 L .31055 .57077 L F
.31334 .57284 m .30898 .57318 L .31055 .57077 L F
.19 .72 .743 r
.24854 .62556 m .25068 .62509 L .25238 .62483 L F
.192 .721 .744 r
.25238 .62483 m .25068 .62509 L .25449 .62436 L F
.346 .633 .96 r
.16318 .61072 m .16373 .60918 L .16195 .60924 L F
.256 .53 .916 r
.16318 .61072 m .16659 .61223 L .16373 .60918 L F
.476 .166 .36 r
.19367 .54533 m .19588 .54504 L .19648 .54343 L F
.344 .041 .299 r
.19648 .54343 m .19802 .54419 L .19847 .54263 L F
.19648 .54343 m .19588 .54504 L .19802 .54419 L F
.572 .613 .855 r
.14658 .59755 m .14865 .60143 L .15112 .60077 L F
.61 .577 .791 r
.14865 .60143 m .15215 .60336 L .15112 .60077 L F
.539 .632 .891 r
.23391 .70701 m .23418 .70352 L .23486 .70503 L F
.112 .186 .662 r
.2368 .70723 m .23486 .70503 L .23715 .70508 L F
.72 .729 .857 r
.84001 .40084 m .84236 .39955 L .83872 .39892 L F
.757 .973 .701 r
.27714 .59271 m .27484 .59539 L .27547 .59385 L F
.736 .908 .534 r
.27547 .59385 m .27484 .59539 L .27345 .59702 L F
.505 .767 .99 r
.30452 .53837 m .30392 .54011 L .30269 .53819 L F
.30452 .53837 m .30614 .53969 L .30392 .54011 L F
.603 .35 .505 r
.29269 .63495 m .29241 .63731 L .2905 .63702 L F
.612 .462 .654 r
.29507 .63174 m .2952 .63471 L .29269 .63495 L F
.572 .318 .493 r
.2952 .63471 m .29241 .63731 L .29269 .63495 L F
0 .286 .675 r
.29258 .53608 m .29573 .53776 L .29379 .53767 L F
.69 .708 .861 r
.55731 .59504 m .56076 .59617 L .55849 .59091 L F
.788 .754 .822 r
.55849 .59091 m .56076 .59617 L .5622 .59129 L F
.124 .354 .817 r
.20655 .61513 m .20605 .61683 L .20395 .61325 L F
.4 .665 .967 r
.20655 .61513 m .20794 .61688 L .20605 .61683 L F
0 .277 .781 r
.21024 .61846 m .20987 .61963 L .20794 .61688 L F
.195 .562 .936 r
.21195 .61998 m .20987 .61963 L .21024 .61846 L F
.374 .324 .674 r
.24219 .70049 m .24048 .70268 L .23976 .70078 L F
.24219 .70049 m .24232 .70338 L .24048 .70268 L F
.518 .361 .607 r
.24232 .70338 m .24071 .70397 L .24048 .70268 L F
.558 .287 .461 r
.30357 .62566 m .30324 .62799 L .3002 .62819 L F
.592 .421 .619 r
.30603 .62274 m .30604 .62537 L .30357 .62566 L F
.567 .295 .463 r
.30567 .62768 m .30357 .62566 L .30604 .62537 L F
.30567 .62768 m .30324 .62799 L .30357 .62566 L F
.835 .796 .814 r
.28076 .58768 m .27942 .589 L .28198 .58601 L F
.612 .387 .551 r
.49139 .62853 m .48942 .63198 L .48886 .62865 L F
.812 .64 .668 r
.48789 .63125 m .49139 .62853 L .48886 .62865 L F
0 0 0 r
.1654 .56172 m .16269 .56452 L .16445 .56324 L F
.276 0 .111 r
.1654 .56172 m .16674 .56245 L .16758 .56113 L F
.1654 .56172 m .16445 .56324 L .16674 .56245 L F
.264 .044 .381 r
.14518 .58247 m .14653 .58223 L .14712 .57993 L F
.334 .204 .55 r
.14597 .58461 m .14653 .58223 L .14518 .58247 L F
.313 .128 .462 r
.50766 .60384 m .50795 .60408 L .50819 .60122 L F
.09 0 .436 r
.50819 .60122 m .50968 .60021 L .5097 .59764 L F
.372 .175 .48 r
.50819 .60122 m .5094 .6031 L .50968 .60021 L F
.50819 .60122 m .50795 .60408 L .5094 .6031 L F
.593 .515 .736 r
.80393 .41622 m .80519 .42031 L .80259 .42092 L F
.532 .739 .97 r
.49427 .55293 m .49481 .55092 L .49286 .55184 L F
.49427 .55293 m .49722 .55227 L .49481 .55092 L F
.653 .748 .919 r
.79286 .43578 m .79654 .43656 L .79538 .43482 L F
.735 .836 .927 r
.79654 .43656 m .79755 .43387 L .79538 .43482 L F
.79654 .43656 m .79893 .43525 L .79755 .43387 L F
.548 .521 .778 r
.31911 .61277 m .31601 .61053 L .31832 .60999 L F
.713 .598 .726 r
.44815 .66232 m .44629 .6659 L .44625 .6644 L F
.44815 .66232 m .44629 .6659 L .44625 .6644 L F
.546 .595 .854 r
.25855 .66175 m .25802 .66542 L .25577 .66637 L F
.25855 .66175 m .26065 .66533 L .25802 .66542 L F
.552 .387 .612 r
.26065 .66533 m .25846 .66846 L .25802 .66542 L F
.543 .441 .689 r
.32757 .59505 m .32573 .59806 L .32535 .59551 L F
0 0 .289 r
.27346 .61481 m .27261 .61678 L .2727 .614 L F
.495 .226 .436 r
.27225 .61896 m .27527 .61632 L .27261 .61678 L F
0 0 .104 r
.27333 .61782 m .27261 .61678 L .27346 .61481 L F
.27333 .61782 m .27225 .61896 L .27261 .61678 L F
.67 .661 .833 r
.79026 .43676 m .79162 .4324 L .78905 .43312 L F
.79026 .43676 m .79286 .43578 L .79162 .4324 L F
.355 .279 .631 r
.23249 .70873 m .23457 .71058 L .23391 .70701 L F
.536 .343 .566 r
.27756 .61045 m .27995 .61011 L .28018 .60686 L F
.508 .318 .558 r
.28018 .60686 m .28286 .60665 L .28266 .60409 L F
.549 .354 .569 r
.28018 .60686 m .28223 .60876 L .28286 .60665 L F
.28018 .60686 m .27995 .61011 L .28223 .60876 L F
.551 .519 .773 r
.52592 .56623 m .52881 .56467 L .52559 .56366 L F
.439 .013 .131 r
.80143 .40512 m .80502 .40454 L .80501 .40303 L F
.459 .027 .131 r
.80501 .40303 m .80502 .40454 L .80752 .40404 L F
.441 .106 .3 r
.80501 .40303 m .80752 .40404 L .80791 .40242 L F
.499 .783 .996 r
.21766 .64086 m .21834 .63928 L .21588 .63992 L F
.21766 .64086 m .21989 .64043 L .21834 .63928 L F
.026 .518 .876 r
.23266 .54956 m .23298 .54898 L .23085 .54915 L F
.23266 .54956 m .23513 .55021 L .23298 .54898 L F
.448 .519 .839 r
.19527 .63167 m .19724 .63553 L .19874 .63405 L F
.333 .335 .712 r
.19724 .63553 m .19904 .63579 L .19874 .63405 L F
.698 .846 .954 r
.82471 .43812 m .82713 .435 L .82414 .43654 L F
.82471 .43812 m .82823 .4364 L .82713 .435 L F
.51 .35 .601 r
.33171 .58521 m .32978 .58335 L .33205 .58294 L F
.33171 .58521 m .32941 .58609 L .32978 .58335 L F
.772 .939 .936 r
.55605 .59408 m .55514 .59639 L .55731 .59504 L F
.55605 .59408 m .55292 .59623 L .55514 .59639 L F
.845 .65 .638 r
.22378 .72926 m .22478 .73227 L .22213 .73212 L F
.868 .704 .677 r
.22478 .73227 m .22235 .73381 L .22213 .73212 L F
.22478 .73227 m .22423 .73462 L .22244 .73384 L F
.22478 .73227 m .22244 .73384 L .22243 .73376 L F
.677 .128 0 r
.22235 .73381 m .22423 .73462 L .2236 .73502 L F
.281 .245 .639 r
.22224 .73196 m .2236 .73502 L .22291 .73102 L F
.22213 .73212 m .22229 .73245 L .22224 .73196 L F
.22229 .73245 m .2236 .73502 L .22224 .73196 L F
.868 .704 .677 r
.22243 .73376 m .22244 .73384 L .22235 .73381 L F
.692 .572 .715 r
.22678 .72946 m .22478 .73227 L .22378 .72926 L F
.927 .859 .423 r
.2236 .73502 m .22423 .73462 L .22478 .73227 L F
.318 0 .249 r
.22779 .73162 m .22593 .7323 L .22678 .72946 L F
.594 .709 .924 r
.22648 .73127 m .22593 .7323 L .22779 .73162 L F
.927 .859 .423 r
.22473 .73305 m .22478 .73227 L .22678 .72946 L F
.2236 .73502 m .22678 .72946 L .22593 .7323 L F
.594 .709 .924 r
.22485 .73083 m .22573 .73203 L .22648 .73127 L F
.22573 .73203 m .22593 .7323 L .22648 .73127 L F
.927 .859 .423 r
.2236 .73502 m .22423 .73356 L .22473 .73305 L F
.22423 .73356 m .22478 .73227 L .22473 .73305 L F
0 0 0 r
.53356 .52537 m .53276 .5252 L .53512 .52471 L F
.53356 .52537 m .53138 .5267 L .53276 .5252 L F
.975 .799 .381 r
.50221 .58907 m .50133 .59023 L .50106 .58785 L F
.50221 .58907 m .50191 .5916 L .50133 .59023 L F
.709 .823 .935 r
.82639 .40175 m .82754 .40343 L .82986 .40198 L F
.401 .061 .27 r
.45278 .6408 m .45517 .64029 L .45514 .63907 L F
0 0 .117 r
.45514 .63907 m .45517 .64029 L .45563 .63683 L F
.769 .727 .814 r
.79783 .41459 m .79877 .41804 L .79519 .41752 L F
.737 .709 .825 r
.80165 .41534 m .79877 .41804 L .79783 .41459 L F
.933 .94 .777 r
.56076 .54952 m .55844 .55053 L .55961 .55168 L F
.988 .88 .541 r
.55844 .55053 m .55831 .55507 L .55961 .55168 L F
0 0 0 r
.16886 .58497 m .16839 .58759 L .16811 .58907 L F
.15 0 0 r
.20254 .56106 m .19822 .56274 L .20035 .56176 L F
.862 .756 .744 r
.22006 .72923 m .22378 .72926 L .22328 .72595 L F
.769 .359 .275 r
.22291 .73102 m .22378 .72926 L .22006 .72923 L F
.692 .572 .715 r
.22678 .72946 m .22378 .72926 L .22725 .7295 L F
.43 .042 .2 r
.22712 .72941 m .22678 .72946 L .22725 .7295 L F
.679 .594 .754 r
.22493 .72777 m .22725 .7295 L .22378 .72926 L F
.22721 .72938 m .22725 .7295 L .22712 .72941 L F
.601 .586 .809 r
.22829 .7258 m .22728 .72938 L .22619 .72614 L F
.22728 .72938 m .22725 .7295 L .22721 .72938 L F
.22728 .72938 m .22721 .72938 L .22619 .72614 L F
.43 .042 .2 r
.2273 .72938 m .2268 .7295 L .22712 .72941 L F
.601 .586 .809 r
.22829 .7258 m .22945 .72905 L .22725 .7295 L F
.43 .042 .2 r
.22945 .72905 m .22712 .72941 L .22725 .7295 L F
.22945 .72905 m .22754 .72938 L .2273 .72938 L F
.22754 .72938 m .2268 .7295 L .2273 .72938 L F
.22945 .72905 m .22779 .73162 L .2268 .7295 L F
.22712 .72941 m .2268 .7295 L .22678 .72946 L F
.679 .594 .754 r
.22619 .72614 m .22721 .72938 L .22493 .72777 L F
.22721 .72938 m .22712 .72941 L .22493 .72777 L F
.025 .134 .642 r
.22328 .72595 m .22378 .72926 L .22518 .72837 L F
0 0 0 r
.22518 .72837 m .22378 .72926 L .22291 .73102 L F
.464 .211 .444 r
.17182 .57685 m .17126 .57927 L .16907 .57973 L F
.246 .019 .359 r
.17284 .57847 m .17182 .57685 L .17417 .57647 L F
.17284 .57847 m .17126 .57927 L .17182 .57685 L F
.518 .323 .556 r
.30853 .62231 m .30604 .62537 L .30603 .62274 L F
.009 0 .177 r
.27942 .589 m .27714 .59271 L .27877 .59094 L F
.272 .009 .319 r
.28198 .58601 m .27942 .589 L .28126 .58812 L F
.226 0 .269 r
.27877 .59094 m .28126 .58812 L .27942 .589 L F
.789 .623 .675 r
.29566 .59177 m .29324 .59467 L .29686 .59391 L F
.716 .408 .456 r
.29324 .59467 m .29539 .59705 L .29686 .59391 L F
.638 .458 .623 r
.29686 .59391 m .29963 .59214 L .29679 .59188 L F
.29642 .5922 m .29679 .59188 L .29633 .59183 L F
.29686 .59391 m .29679 .59188 L .29642 .5922 L F
.29686 .59391 m .29633 .59183 L .29585 .5921 L F
.745 .709 .817 r
.29776 .591 m .29566 .59177 L .29816 .58893 L F
0 0 0 r
.29776 .591 m .29753 .59118 L .29566 .59177 L F
.699 .633 .779 r
.29566 .59177 m .29679 .59188 L .29704 .59134 L F
.499 .234 .443 r
.29779 .59101 m .29769 .5911 L .29773 .59103 L F
.29779 .59098 m .29773 .59103 L .29776 .591 L F
0 0 0 r
.29776 .591 m .29773 .59103 L .29767 .59107 L F
.30053 .58788 m .29776 .591 L .29816 .58893 L F
.699 .633 .779 r
.29679 .59188 m .29785 .59096 L .29816 .58893 L F
.29785 .59096 m .29874 .59019 L .29867 .59004 L F
.29785 .59096 m .29867 .59004 L .29816 .58893 L F
.663 .542 .706 r
.29963 .59214 m .3018 .58953 L .29944 .58914 L F
0 0 0 r
.29862 .59004 m .29931 .5893 L .29776 .591 L F
.30051 .5879 m .29944 .58914 L .29862 .59004 L F
.29944 .58914 m .29931 .5893 L .29862 .59004 L F
.766 .768 .854 r
.29954 .58627 m .29816 .58893 L .30053 .58788 L F
.709 .694 .834 r
.29816 .58893 m .29944 .58914 L .29954 .58627 L F
.614 .658 .87 r
.30118 .58721 m .3018 .58953 L .30376 .58869 L F
.226 0 .046 r
.30067 .5879 m .30076 .58776 L .30079 .58774 L F
0 0 .19 r
.3023 .58574 m .30053 .58788 L .29954 .58627 L F
.614 .658 .87 r
.29954 .58627 m .30067 .5879 L .30118 .58721 L F
.30067 .5879 m .3018 .58953 L .30118 .58721 L F
.30228 .58574 m .30376 .58869 L .3023 .58574 L F
.29954 .58627 m .30118 .58721 L .30228 .58574 L F
.30119 .58721 m .30376 .58869 L .30228 .58576 L F
0 0 .19 r
.3023 .58574 m .30211 .58705 L .30079 .58774 L F
.3023 .58574 m .30079 .58774 L .30053 .58788 L F
.614 .658 .87 r
.30118 .58721 m .30119 .58721 L .30228 .58574 L F
.30119 .58721 m .30228 .58576 L .30228 .58574 L F
.226 0 .046 r
.3006 .58801 m .30065 .58792 L .30211 .58705 L F
.709 .694 .834 r
.29987 .58921 m .3018 .58953 L .30071 .58796 L F
.3006 .58801 m .30071 .58796 L .30067 .5879 L F
.29987 .58921 m .30071 .58796 L .3006 .58801 L F
.226 0 .046 r
.3006 .58801 m .30053 .58788 L .30076 .58776 L F
.709 .694 .834 r
.29987 .58921 m .30067 .5879 L .30063 .58785 L F
.663 .542 .706 r
.29874 .59019 m .29944 .58914 L .29867 .59004 L F
.29963 .59214 m .29947 .58954 L .29874 .59019 L F
.29947 .58954 m .29944 .58914 L .29874 .59019 L F
.699 .633 .779 r
.29679 .59188 m .29963 .59214 L .29886 .59046 L F
.29769 .5911 m .29886 .59046 L .29874 .59019 L F
.29679 .59188 m .29886 .59046 L .29769 .5911 L F
0 0 0 r
.29753 .59118 m .29627 .59298 L .29448 .59361 L F
.29767 .59107 m .29763 .59113 L .29753 .59118 L F
.29763 .59113 m .29627 .59298 L .29753 .59118 L F
.499 .234 .443 r
.29914 .59035 m .29627 .59298 L .29764 .59117 L F
.29775 .59107 m .29764 .59117 L .29769 .5911 L F
.29914 .59035 m .29764 .59117 L .29775 .59107 L F
.226 0 .046 r
.30151 .58963 m .29914 .59035 L .30039 .58811 L F
.3006 .58801 m .30039 .58811 L .30053 .58788 L F
.30151 .58963 m .30039 .58811 L .3006 .58801 L F
.30065 .58792 m .30067 .5879 L .30067 .5879 L F
.30065 .58792 m .30067 .5879 L .30211 .58705 L F
.30067 .5879 m .30079 .58774 L .30211 .58705 L F
.30151 .58963 m .3006 .58801 L .30211 .58705 L F
.709 .694 .834 r
.29944 .58914 m .29987 .58921 L .30063 .58785 L F
0 0 0 r
.30053 .58788 m .30051 .5879 L .29776 .591 L F
.30051 .5879 m .30041 .58809 L .29931 .5893 L F
.709 .694 .834 r
.29944 .58914 m .30063 .58785 L .29954 .58627 L F
0 0 0 r
.30041 .58809 m .29785 .59096 L .29776 .591 L F
.663 .542 .706 r
.29867 .59004 m .29944 .58914 L .29816 .58893 L F
0 0 0 r
.30041 .58809 m .29914 .59035 L .29785 .59096 L F
.638 .458 .623 r
.29585 .5921 m .29633 .59183 L .29566 .59177 L F
0 0 0 r
.29753 .59118 m .29448 .59361 L .29566 .59177 L F
.699 .633 .779 r
.29566 .59177 m .29704 .59134 L .29816 .58893 L F
.499 .234 .443 r
.29914 .59035 m .29769 .5911 L .29779 .59101 L F
.29914 .59035 m .29773 .59103 L .29779 .59098 L F
0 0 0 r
.29773 .59103 m .29627 .59298 L .29767 .59107 L F
.638 .458 .623 r
.29686 .59391 m .29932 .59464 L .29963 .59214 L F
.654 .307 .373 r
.29798 .59725 m .29686 .59391 L .29539 .59705 L F
.29798 .59725 m .29932 .59464 L .29686 .59391 L F
.465 .269 .529 r
.3109 .61917 m .30853 .62231 L .3084 .61968 L F
.166 .612 .936 r
.22409 .62418 m .22387 .62505 L .2217 .62297 L F
.22409 .62418 m .22584 .6253 L .22387 .62505 L F
.23 0 .132 r
.16269 .56452 m .16361 .56641 L .16445 .56324 L F
.16269 .56452 m .16104 .5678 L .16361 .56641 L F
.941 .801 .678 r
.55136 .56191 m .54971 .56104 L .5517 .55751 L F
.944 .793 .662 r
.55136 .56191 m .55066 .56443 L .54971 .56104 L F
.052 0 .113 r
.2847 .58297 m .28198 .58601 L .28363 .58484 L F
.099 0 .213 r
.28126 .58812 m .28363 .58484 L .28198 .58601 L F
.358 .504 .867 r
.3151 .54126 m .31402 .54302 L .31173 .54038 L F
.3151 .54126 m .31565 .5428 L .31402 .54302 L F
0 .418 .778 r
.23892 .54998 m .23929 .54974 L .23692 .55003 L F
.23892 .54998 m .24129 .55076 L .23929 .54974 L F
0 0 .55 r
.5085 .60587 m .50898 .6065 L .50766 .60384 L F
.525 .021 .002 r
.24451 .68551 m .24174 .68386 L .24319 .68658 L F
.507 .781 .994 r
.45081 .67019 m .45337 .67146 L .44999 .67054 L F
.233 0 .295 r
.45077 .67467 m .45337 .67146 L .45317 .67434 L F
.432 0 0 r
.45081 .67019 m .45296 .67151 L .45337 .67146 L F
.726 .701 .827 r
.45551 .67147 m .45317 .67434 L .45334 .67189 L F
.45551 .67147 m .45334 .67189 L .45337 .67146 L F
.45551 .67147 m .45653 .67329 L .45317 .67434 L F
.657 .633 .814 r
.45801 .67045 m .45653 .67329 L .45551 .67147 L F
.811 .583 .593 r
.45418 .67284 m .45677 .67122 L .45551 .67147 L F
.45677 .67122 m .45801 .67045 L .45551 .67147 L F
.011 0 0 r
.45337 .67146 m .45296 .67151 L .45551 .67147 L F
.43 .226 .5 r
.27765 .61304 m .27995 .61011 L .27756 .61045 L F
.782 .657 .725 r
.56355 .59491 m .56748 .59537 L .56599 .59174 L F
.434 0 .052 r
.29811 .58669 m .29631 .58733 L .29405 .58744 L F
0 0 0 r
.2947 .58732 m .29405 .58744 L .29445 .58742 L F
.29778 .58608 m .29405 .58744 L .2947 .58732 L F
.434 0 .052 r
.29811 .58669 m .29677 .58694 L .2981 .58669 L F
.29677 .58694 m .29405 .58744 L .29677 .58694 L F
.29677 .58694 m .29677 .58694 L .2981 .58669 L F
0 0 0 r
.29746 .58621 m .29445 .58742 L .29668 .58698 L F
.29746 .58621 m .29668 .58698 L .29674 .58696 L F
.29778 .58608 m .29746 .58621 L .29674 .58696 L F
.575 .883 .597 r
.29778 .58608 m .29677 .58694 L .29737 .58637 L F
.169 .232 .685 r
.297 .58264 m .29778 .58608 L .29904 .58467 L F
.575 .883 .597 r
.29829 .58551 m .29789 .58589 L .29831 .58548 L F
.29789 .58589 m .29791 .58587 L .29831 .58548 L F
.289 .253 .644 r
.29904 .58467 m .29811 .58669 L .29789 .58589 L F
.29904 .58467 m .29789 .58589 L .297 .58264 L F
.696 .505 .625 r
.29789 .58589 m .29738 .58637 L .29318 .58453 L F
.575 .883 .597 r
.29789 .58589 m .29737 .58637 L .29791 .58587 L F
.29778 .58608 m .29737 .58637 L .29829 .58551 L F
.696 .505 .625 r
.297 .58264 m .29789 .58589 L .29318 .58453 L F
.29789 .58589 m .29811 .58669 L .29738 .58637 L F
.434 0 .052 r
.2981 .58669 m .29405 .58744 L .29318 .58453 L F
.696 .505 .625 r
.29811 .58669 m .2981 .58669 L .29737 .58637 L F
.29738 .58637 m .29737 .58637 L .29318 .58453 L F
.29811 .58669 m .29737 .58637 L .29738 .58637 L F
.575 .883 .597 r
.29737 .58637 m .29631 .58733 L .29831 .58548 L F
.29677 .58694 m .29674 .58696 L .29737 .58637 L F
.29674 .58696 m .29631 .58733 L .29737 .58637 L F
.29831 .58548 m .29631 .58733 L .29904 .58467 L F
.696 .505 .625 r
.29811 .58669 m .29811 .58669 L .2981 .58669 L F
0 0 0 r
.29674 .58696 m .29445 .58742 L .29631 .58733 L F
.969 .65 .32 r
.44936 .6714 m .45077 .67467 L .44958 .67441 L F
.455 .8 .998 r
.45077 .67467 m .45166 .67334 L .44958 .67441 L F
.45077 .67467 m .45317 .67434 L .45166 .67334 L F
.495 .055 .131 r
.54126 .52238 m .53761 .52432 L .53861 .52391 L F
.54126 .52238 m .53964 .52442 L .53761 .52432 L F
.482 .041 .123 r
.54374 .52347 m .53964 .52442 L .54126 .52238 L F
.429 0 0 r
.29573 .53776 m .29824 .53877 L .30017 .53822 L F
.052 0 0 r
.29824 .53877 m .30269 .53819 L .30017 .53822 L F
.785 .549 .578 r
.46351 .64409 m .46324 .64689 L .46141 .64361 L F
.733 .5 .576 r
.46659 .64675 m .46351 .64409 L .46545 .64321 L F
.46659 .64675 m .46324 .64689 L .46351 .64409 L F
.415 .161 .418 r
.46527 .56784 m .4679 .56718 L .46845 .56436 L F
.71 .43 .5 r
.4679 .56718 m .46997 .56581 L .46845 .56436 L F
.639 .53 .715 r
.42419 .65601 m .42435 .66046 L .42257 .65894 L F
.045 0 .281 r
.42257 .65894 m .42374 .65877 L .42419 .65601 L F
.652 .109 0 r
.42257 .65894 m .42435 .66046 L .42434 .66071 L F
.112 .257 .735 r
.42257 .65894 m .42434 .66071 L .42374 .65877 L F
.788 .816 .875 r
.83283 .39946 m .83608 .3996 L .83508 .3981 L F
.358 .829 .883 r
.83608 .3996 m .83818 .399 L .83508 .3981 L F
.83608 .3996 m .83872 .39892 L .83818 .399 L F
.966 .722 .515 r
.55791 .56016 m .5595 .55851 L .55777 .55774 L F
.55791 .56016 m .55944 .56112 L .5595 .55851 L F
.9 .656 .56 r
.56171 .52365 m .56379 .52184 L .56063 .5208 L F
.56171 .52365 m .56369 .5244 L .56379 .52184 L F
.613 .463 .654 r
.29818 .63388 m .29507 .63174 L .29762 .63136 L F
.29818 .63388 m .2952 .63471 L .29507 .63174 L F
.415 .524 .86 r
.28052 .58094 m .28154 .57818 L .27905 .5786 L F
.789 .379 .272 r
.51249 .5605 m .51397 .55874 L .51067 .55744 L F
.51249 .5605 m .51423 .56014 L .51397 .55874 L F
.332 .082 .376 r
.21374 .53633 m .21113 .53982 L .21328 .53858 L F
.551 .344 .553 r
.21328 .53858 m .21616 .53571 L .21374 .53633 L F
.398 .138 .4 r
.21374 .53633 m .21328 .53858 L .21616 .53571 L F
.271 .693 .968 r
.18948 .82932 m .19127 .83036 L .18892 .83024 L F
.18892 .83024 m .19127 .83036 L .18948 .82932 L F
.18948 .82932 m .19127 .83036 L .18892 .83024 L F
.329 0 0 r
.54011 .51663 m .54235 .51703 L .54506 .51506 L F
.423 0 0 r
.54235 .51703 m .54613 .51559 L .54506 .51506 L F
.998 .781 .459 r
.50393 .58245 m .5036 .58492 L .50468 .58592 L F
.861 .45 .249 r
.50338 .58732 m .50468 .58592 L .5036 .58492 L F
.50338 .58732 m .50564 .58797 L .50468 .58592 L F
.454 .878 .775 r
.83484 .3937 m .83136 .3951 L .83432 .39487 L F
.614 .905 .985 r
.83744 .39243 m .83484 .3937 L .83641 .39256 L F
0 0 0 r
.83641 .39256 m .83484 .3937 L .83432 .39487 L F
.816 .438 .34 r
.51815 .5637 m .52213 .56479 L .51921 .56292 L F
.842 .554 .501 r
.51815 .5637 m .52161 .56685 L .52213 .56479 L F
.848 .921 .88 r
.83429 .4338 m .83626 .42974 L .83343 .43262 L F
.83429 .4338 m .83714 .43108 L .83626 .42974 L F
.561 .435 .665 r
.33297 .58894 m .33331 .59209 L .33097 .59254 L F
.485 .12 .271 r
.33291 .59388 m .33097 .59254 L .33331 .59209 L F
.33291 .59388 m .33033 .59426 L .33097 .59254 L F
.204 0 .266 r
.33711 .57704 m .33666 .57908 L .33481 .57987 L F
.581 .458 .677 r
.33924 .57342 m .34044 .57664 L .33711 .57704 L F
.646 .321 .408 r
.34014 .57871 m .33711 .57704 L .34044 .57664 L F
.34014 .57871 m .33666 .57908 L .33711 .57704 L F
.207 0 0 r
.19367 .54533 m .19384 .54694 L .19588 .54504 L F
.19367 .54533 m .19162 .54756 L .19384 .54694 L F
.663 .542 .706 r
.29963 .59214 m .30196 .59196 L .3018 .58953 L F
.502 .258 .478 r
.29932 .59464 m .30196 .59196 L .29963 .59214 L F
.947 .956 .67 r
.54216 .58294 m .54051 .58635 L .5404 .58417 L F
.885 .99 .79 r
.54216 .58294 m .54222 .58104 L .54478 .57995 L F
.54216 .58294 m .54151 .58229 L .54222 .58104 L F
.947 .956 .671 r
.54216 .58294 m .5404 .58417 L .54151 .58229 L F
.312 0 0 r
.47529 .61844 m .47904 .61754 L .47624 .61647 L F
.416 .352 .678 r
.2491 .68901 m .24671 .68696 L .24785 .6859 L F
.2491 .68901 m .24713 .68958 L .24671 .68696 L F
.371 .504 .862 r
.16045 .60936 m .16012 .60603 L .15806 .60641 L F
.16045 .60936 m .16195 .60924 L .16012 .60603 L F
.478 .134 .304 r
.27547 .59385 m .27877 .59094 L .27714 .59271 L F
.715 .712 .846 r
.79234 .4205 m .79019 .4215 L .78849 .41952 L F
.776 .899 .929 r
.81912 .4134 m .818 .41615 L .81562 .416 L F
.81912 .4134 m .82009 .41463 L .818 .41615 L F
.705 .68 .823 r
.82272 .41349 m .82343 .41558 L .82009 .41463 L F
.569 .566 .811 r
.82559 .4128 m .82343 .41558 L .82272 .41349 L F
.82559 .4128 m .82631 .41507 L .82343 .41558 L F
.571 .134 .171 r
.54613 .51559 m .54861 .51707 L .54993 .51527 L F
.557 .096 .114 r
.54861 .51707 m .55259 .51575 L .54993 .51527 L F
.479 .281 .534 r
.31104 .57334 m .3133 .57562 L .31334 .57284 L F
.31138 .57369 m .31083 .57634 L .3133 .57562 L F
.311 .57385 m .31083 .57634 L .31138 .57369 L F
0 0 0 r
.3131 .5731 m .3108 .57412 L .31333 .57285 L F
.31334 .57284 m .31333 .57285 L .31334 .57284 L F
.3131 .5731 m .31333 .57285 L .31334 .57284 L F
.479 .281 .534 r
.31104 .57334 m .311 .57385 L .31138 .57369 L F
.236 0 .084 r
.27385 .54939 m .27275 .55163 L .27048 .55226 L F
0 0 0 r
.27433 .55029 m .27385 .54939 L .27639 .55123 L F
.27433 .55029 m .27275 .55163 L .27385 .54939 L F
.744 .864 .936 r
.55881 .54881 m .55389 .55152 L .55954 .54904 L F
.946 .911 .752 r
.5599 .54826 m .55844 .55053 L .56076 .54952 L F
.523 .313 .537 r
.33481 .57987 m .33453 .58246 L .33205 .58294 L F
.536 .324 .54 r
.33703 .58196 m .33481 .57987 L .33666 .57908 L F
.33703 .58196 m .33453 .58246 L .33481 .57987 L F
.857 .489 .352 r
.49304 .54611 m .49455 .54885 L .49665 .54912 L F
.885 .578 .463 r
.49455 .54885 m .49481 .55092 L .49665 .54912 L F
.889 .586 .468 r
.49481 .55092 m .49722 .55227 L .49665 .54912 L F
.728 .478 .549 r
.49665 .54912 m .49722 .55227 L .50023 .55163 L F
.503 .303 .542 r
.44915 .65569 m .45154 .6552 L .44935 .65296 L F
.454 .087 .251 r
.28658 .63842 m .28603 .64007 L .28363 .64033 L F
.613 .316 .441 r
.2905 .63702 m .28603 .64007 L .28658 .63842 L F
0 0 0 r
.29448 .59361 m .29324 .59467 L .29566 .59177 L F
.884 .76 .72 r
.56465 .5332 m .56651 .53407 L .56538 .53051 L F
.922 .811 .72 r
.56347 .53623 m .56651 .53407 L .56465 .5332 L F
.56347 .53623 m .56529 .53731 L .56651 .53407 L F
.536 .275 .467 r
.3342 .58468 m .33205 .58294 L .33453 .58246 L F
.3342 .58468 m .33171 .58521 L .33205 .58294 L F
.746 .969 .931 r
.26458 .64835 m .26407 .65023 L .26538 .64871 L F
.626 .867 .988 r
.26221 .64931 m .26407 .65023 L .26458 .64835 L F
.012 0 0 r
.22605 .53712 m .22829 .53679 L .23001 .53627 L F
.291 0 0 r
.23035 .53675 m .23001 .53627 L .22829 .53679 L F
.23035 .53675 m .23225 .53668 L .23001 .53627 L F
.887 .705 .651 r
.56369 .5244 m .5632 .52734 L .5652 .52786 L F
.901 .605 .475 r
.56341 .52942 m .5652 .52786 L .5632 .52734 L F
.56341 .52942 m .56538 .53051 L .5652 .52786 L F
.983 .711 .33 r
.55389 .55152 m .55278 .5509 L .55276 .54845 L F
.865 .732 .715 r
.55389 .55152 m .55077 .55252 L .55278 .5509 L F
.55389 .55152 m .55186 .55532 L .55077 .55252 L F
.983 .711 .33 r
.55389 .55152 m .55278 .5509 L .55276 .54845 L F
.148 .677 .866 r
.22392 .64146 m .2249 .64101 L .22141 .64064 L F
.22392 .64146 m .22598 .64144 L .2249 .64101 L F
.797 .614 .654 r
.52322 .57284 m .52795 .57112 L .52314 .57031 L F
.52322 .57284 m .52693 .5734 L .52795 .57112 L F
.465 .887 .909 r
.24753 .55457 m .24657 .55559 L .24882 .55487 L F
.24753 .55457 m .24427 .5557 L .24657 .55559 L F
.088 0 0 r
.54011 .51663 m .53689 .51827 L .54001 .51726 L F
.301 0 0 r
.54001 .51726 m .54235 .51703 L .54011 .51663 L F
.644 .691 .879 r
.46807 .65497 m .46896 .65681 L .46612 .65599 L F
.527 .627 .894 r
.4704 .65463 m .46896 .65681 L .46807 .65497 L F
.328 .361 .743 r
.4704 .65463 m .4717 .65852 L .46896 .65681 L F
.608 .442 .632 r
.46135 .62504 m .46368 .62176 L .46203 .62279 L F
.977 .68 .314 r
.84168 .39597 m .84156 .39348 L .84027 .39216 L F
.957 .63 .354 r
.15422 .60335 m .15112 .60077 L .15215 .60336 L F
.755 .38 .345 r
.55242 .53127 m .54912 .53261 L .54929 .53005 L F
.55242 .53127 m .55282 .53315 L .54912 .53261 L F
.92 .871 .774 r
.55542 .54461 m .55416 .5419 L .55546 .54294 L F
.55542 .54461 m .5521 .54533 L .55416 .5419 L F
.926 .84 .741 r
.55542 .54461 m .55276 .54845 L .5521 .54533 L F
.768 .357 .271 r
.50592 .59689 m .50285 .5966 L .50371 .59474 L F
.50285 .5966 m .50192 .59582 L .50371 .59474 L F
.50592 .59689 m .50435 .59812 L .50092 .59642 L F
.855 .749 .746 r
.50439 .59861 m .50226 .59804 L .50423 .59811 L F
.768 .357 .271 r
.50435 .59812 m .50417 .59826 L .5039 .5981 L F
.50435 .59812 m .5039 .5981 L .50092 .59642 L F
.855 .749 .746 r
.50439 .59861 m .50217 .59833 L .50226 .59804 L F
.768 .357 .271 r
.50285 .5966 m .50092 .59642 L .50192 .59582 L F
.597 .587 .812 r
.50092 .59642 m .5039 .5981 L .50319 .59488 L F
.855 .749 .746 r
.50423 .59811 m .5039 .5981 L .50319 .59488 L F
.597 .587 .812 r
.5039 .5981 m .50417 .59826 L .50319 .59488 L F
.855 .749 .746 r
.5039 .5981 m .50226 .59804 L .50319 .59488 L F
.986 .89 .635 r
.50611 .59325 m .50426 .59802 L .50592 .59689 L F
.50426 .59802 m .50417 .59826 L .50428 .59817 L F
.50426 .59802 m .50428 .59817 L .50592 .59689 L F
.112 .275 .751 r
.50319 .59488 m .50408 .59749 L .50408 .59764 L F
.919 .761 .669 r
.50319 .59488 m .50417 .59826 L .50426 .59802 L F
.50319 .59488 m .50426 .59802 L .50611 .59325 L F
.112 .275 .751 r
.50319 .59488 m .5041 .59682 L .50408 .59749 L F
.5041 .59682 m .50474 .59819 L .50423 .59776 L F
.5041 .59682 m .50423 .59776 L .50408 .59764 L F
.50319 .59488 m .50553 .59724 L .50474 .59819 L F
.50408 .59764 m .50474 .59819 L .50439 .59861 L F
.404 .523 .864 r
.28426 .59831 m .28492 .59533 L .28313 .59659 L F
.28426 .59831 m .28632 .59791 L .28492 .59533 L F
.378 .337 .686 r
.28426 .59831 m .28666 .60021 L .28632 .59791 L F
.371 .337 .691 r
.28503 .60081 m .28666 .60021 L .28426 .59831 L F
.318 .803 .763 r
.47162 .66113 m .46925 .6619 L .46981 .66187 L F
.908 .723 .639 r
.25503 .65564 m .2562 .65894 L .25381 .65874 L F
.525 .829 1 r
.25468 .66074 m .25381 .65874 L .2562 .65894 L F
.286 .375 .78 r
.25786 .6588 m .2562 .65894 L .25503 .65564 L F
.135 0 0 r
.25468 .66074 m .2562 .65894 L .25786 .6588 L F
.437 .223 .49 r
.16879 .58231 m .16658 .58294 L .16907 .57973 L F
.485 .347 .618 r
.16879 .58231 m .16886 .58497 L .16658 .58294 L F
0 0 0 r
.17919 .55295 m .17597 .55479 L .17793 .55388 L F
.17793 .55388 m .18124 .55222 L .17919 .55295 L F
.45 .269 .543 r
.28266 .60409 m .28493 .60345 L .28503 .60081 L F
.134 0 .294 r
.28286 .60665 m .28493 .60345 L .28266 .60409 L F
.737 .76 .872 r
.53731 .59109 m .53902 .58911 L .53769 .59014 L F
.133 0 0 r
.23356 .71394 m .23606 .7142 L .2343 .71415 L F
.845 .521 .439 r
.79497 .40207 m .79876 .40523 L .79871 .40253 L F
.563 .214 .335 r
.28007 .64106 m .27721 .64292 L .27772 .64112 L F
.949 .954 .72 r
.54478 .57995 m .54395 .57922 L .54577 .57575 L F
.887 .98 .822 r
.54478 .57995 m .54222 .58104 L .54395 .57922 L F
.444 .467 .789 r
.28346 .56434 m .28653 .56706 L .28522 .56337 L F
.431 .085 .276 r
.26819 .55278 m .2674 .55455 L .26504 .55493 L F
.263 0 .192 r
.2694 .55385 m .26819 .55278 L .27048 .55226 L F
.2694 .55385 m .2674 .55455 L .26819 .55278 L F
.135 .585 .926 r
.15606 .60601 m .1558 .60509 L .15422 .60335 L F
.15606 .60601 m .15806 .60641 L .1558 .60509 L F
.507 .312 .55 r
.45806 .66784 m .45801 .67045 L .45566 .66832 L F
.648 .763 .933 r
.33373 .54806 m .33003 .54706 L .3326 .54678 L F
.281 0 0 r
.3326 .54678 m .33598 .54757 L .33373 .54806 L F
.605 .421 .606 r
.17126 .57927 m .16879 .58231 L .16907 .57973 L F
.902 .71 .633 r
.5517 .55751 m .54874 .55448 L .55186 .55532 L F
.5517 .55751 m .54813 .55701 L .54874 .55448 L F
.951 .821 .68 r
.5517 .55751 m .5481 .55983 L .54813 .55701 L F
.5517 .55751 m .54971 .56104 L .5481 .55983 L F
.12 .595 .916 r
.31867 .54373 m .32223 .54502 L .32391 .54606 L F
.798 .896 .913 r
.32391 .54606 m .32484 .54303 L .32657 .54555 L F
.32391 .54606 m .32223 .54502 L .32484 .54303 L F
.938 .727 .593 r
.55913 .56626 m .56113 .56461 L .55934 .56373 L F
.55913 .56626 m .56086 .56713 L .56113 .56461 L F
.402 .815 .618 r
.52908 .52235 m .52953 .522 L .53111 .5209 L F
.52908 .52235 m .52747 .52333 L .52953 .522 L F
.366 .836 .862 r
.82492 .39523 m .82796 .39429 L .82831 .39463 L F
.116 0 0 r
.82987 .39488 m .82831 .39463 L .82796 .39429 L F
.82987 .39488 m .83136 .3951 L .82831 .39463 L F
.254 .036 .377 r
.14712 .57993 m .14653 .58223 L .14872 .57908 L F
0 0 .533 r
.51454 .56504 m .51501 .56502 L .51344 .56374 L F
.446 .242 .508 r
.51549 .56694 m .51623 .56603 L .51501 .56502 L F
.51623 .56603 m .51815 .5637 L .51344 .56374 L F
0 0 .533 r
.51501 .56502 m .51549 .56694 L .51537 .56501 L F
.51454 .56504 m .51549 .56694 L .51501 .56502 L F
.446 .242 .508 r
.51549 .56694 m .51501 .56502 L .51344 .56374 L F
0 0 .533 r
.51501 .56502 m .51537 .56501 L .51344 .56374 L F
.967 .854 .677 r
.83831 .42593 m .83866 .4297 L .83954 .42695 L F
.145 .168 .626 r
.28363 .58484 m .28453 .58139 L .2847 .58297 L F
.982 .694 .375 r
.55546 .54294 m .55398 .53928 L .55588 .54028 L F
.286 .375 .78 r
.25786 .6588 m .25503 .65564 L .25743 .65584 L F
0 0 .358 r
.25786 .6588 m .25743 .65584 L .25834 .65501 L F
.542 .339 .555 r
.45321 .65565 m .45569 .656 L .45545 .65309 L F
.26 0 0 r
.22808 .64235 m .22974 .64128 L .23137 .64176 L F
.78 .806 .873 r
.83714 .43108 m .83747 .4279 L .83626 .42974 L F
.83714 .43108 m .83866 .4297 L .83747 .4279 L F
0 .286 .675 r
.29258 .53608 m .29461 .53707 L .29573 .53776 L F
0 .388 .828 r
.29673 .53733 m .29573 .53776 L .29461 .53707 L F
.29673 .53733 m .29824 .53877 L .29573 .53776 L F
.745 .697 .805 r
.83872 .39892 m .84236 .39955 L .84168 .39597 L F
.859 .629 .589 r
.4238 .64559 m .4271 .64693 L .42648 .64682 L F
.702 .346 .37 r
.46315 .63139 m .46246 .63379 L .46017 .6313 L F
.628 .271 .347 r
.46619 .63331 m .46315 .63139 L .46625 .63121 L F
.46619 .63331 m .46246 .63379 L .46315 .63139 L F
.116 .666 .801 r
.23225 .53668 m .2345 .53655 L .23603 .53664 L F
.235 .744 .88 r
.2345 .53655 m .23846 .53651 L .23603 .53664 L F
.911 .507 .189 r
.54877 .52803 m .54768 .52907 L .54669 .5269 L F
.54877 .52803 m .54929 .53005 L .54768 .52907 L F
.608 .798 .972 r
.54722 .59713 m .54859 .59854 L .55118 .59777 L F
.573 .37 .568 r
.32573 .59806 m .32566 .60063 L .32317 .60097 L F
.543 .441 .689 r
.32757 .59505 m .32806 .59755 L .32573 .59806 L F
.563 .39 .605 r
.32806 .59755 m .32566 .60063 L .32573 .59806 L F
.652 .459 .61 r
.24713 .68958 m .24744 .69285 L .24454 .6924 L F
.21 .136 .549 r
.24866 .69133 m .24713 .68958 L .2491 .68901 L F
.24866 .69133 m .24744 .69285 L .24713 .68958 L F
0 .555 .804 r
.45321 .65565 m .45569 .656 L .45154 .6552 L F
.582 .387 .583 r
.45877 .62803 m .46135 .62504 L .45899 .62558 L F
0 0 0 r
.18182 .57263 m .18054 .57385 L .18332 .57106 L F
.908 .739 .66 r
.55477 .53426 m .55418 .53672 L .55282 .53315 L F
.637 .459 .625 r
.80933 .41111 m .80659 .41371 L .80672 .41173 L F
.556 .583 .837 r
.34018 .55088 m .33784 .55156 L .33598 .54757 L F
.181 .103 .526 r
.42658 .65499 m .42435 .66046 L .42419 .65601 L F
.42658 .65499 m .42662 .65846 L .42435 .66046 L F
.73 .259 0 r
.42434 .66071 m .42597 .66264 L .42435 .66046 L F
0 0 0 r
.42435 .66046 m .42662 .65846 L .42434 .66071 L F
.578 .375 .569 r
.25142 .55266 m .24882 .55487 L .24888 .55216 L F
.687 .793 .93 r
.20395 .61325 m .20237 .61433 L .20044 .61289 L F
.616 .825 .98 r
.4679 .56718 m .47207 .56782 L .46997 .56581 L F
.655 .393 .511 r
.46368 .62176 m .46753 .61932 L .46376 .61927 L F
.46368 .62176 m .46722 .6218 L .46753 .61932 L F
.614 .357 .504 r
.46753 .61932 m .46722 .6218 L .46988 .62149 L F
.676 .338 .394 r
.46753 .61932 m .46988 .62149 L .47028 .61966 L F
.793 .569 .597 r
.56996 .58487 m .57317 .5827 L .56951 .58204 L F
.56996 .58487 m .57272 .58498 L .57317 .5827 L F
.039 0 0 r
.18066 .57465 m .18054 .57385 L .18182 .57263 L F
.18066 .57465 m .17845 .57526 L .18054 .57385 L F
.683 .251 0 r
.5089 .55471 m .51067 .55744 L .51025 .55531 L F
.741 .71 .822 r
.81132 .42031 m .80923 .42285 L .80903 .42111 L F
.636 .466 .636 r
.3002 .62819 m .30047 .63122 L .29762 .63136 L F
.465 .263 .52 r
.30324 .62799 m .30047 .63122 L .3002 .62819 L F
.465 .805 .999 r
.77892 .4191 m .77681 .41884 L .7787 .41746 L F
.603 .808 .979 r
.7818 .41698 m .77892 .4191 L .7787 .41746 L F
.7818 .41698 m .78239 .41838 L .77892 .4191 L F
.514 .81 .999 r
.18024 .76577 m .18427 .76627 L .18242 .76525 L F
.18024 .76577 m .18427 .76627 L .18242 .76525 L F
.561 .828 .996 r
.18242 .76525 m .18427 .76627 L .18643 .7656 L F
.18643 .7656 m .18427 .76627 L .18242 .76525 L F
.421 .127 .358 r
.30548 .57952 m .30777 .57897 L .30838 .57694 L F
.597 .354 .519 r
.30777 .57897 m .31083 .57634 L .30838 .57694 L F
.672 .742 .903 r
.19856 .61282 m .19463 .61218 L .19588 .61063 L F
.345 .536 .899 r
.19814 .61011 m .19856 .61282 L .19588 .61063 L F
.19814 .61011 m .20044 .61289 L .19856 .61282 L F
.503 .419 .693 r
.3018 .58953 m .30416 .59125 L .30376 .58869 L F
.3018 .58953 m .30196 .59196 L .30416 .59125 L F
.499 .236 .447 r
.31369 .61641 m .3133 .61873 L .3109 .61917 L F
.54 .272 .458 r
.31581 .61831 m .31369 .61641 L .31636 .61623 L F
.31581 .61831 m .3133 .61873 L .31369 .61641 L F
.102 0 .192 r
.15168 .57368 m .14929 .57669 L .15091 .57573 L F
.165 0 .331 r
.14929 .57669 m .15033 .57817 L .15091 .57573 L F
.14929 .57669 m .14872 .57908 L .15033 .57817 L F
.657 .739 .91 r
.81299 .44144 m .81672 .44232 L .81529 .44055 L F
.827 .892 .888 r
.81672 .44232 m .81843 .4384 L .81529 .44055 L F
.81672 .44232 m .81945 .43974 L .81843 .4384 L F
.599 .313 .454 r
.17319 .58953 m .17641 .59106 L .17462 .58902 L F
.034 0 0 r
.2095 .5399 m .21328 .53858 L .21113 .53982 L F
.674 .184 .079 r
.21517 .5583 m .21311 .55909 L .21231 .55775 L F
.752 .994 .858 r
.21774 .55619 m .21604 .55659 L .21583 .55776 L F
.959 .698 .497 r
.21564 .55412 m .21562 .55669 L .21774 .55619 L F
0 0 .305 r
.21614 .55617 m .21649 .55809 L .2161 .55627 L F
.21648 .55687 m .21649 .55809 L .21614 .55617 L F
.752 .994 .858 r
.21583 .55776 m .21568 .55698 L .21517 .5583 L F
.21568 .55698 m .21562 .55669 L .21552 .55706 L F
.21568 .55698 m .21552 .55706 L .21517 .5583 L F
.711 .278 .218 r
.21231 .55775 m .21257 .55902 L .20632 .55714 L F
0 0 .144 r
.21224 .55734 m .21257 .55902 L .21231 .55775 L F
0 0 .403 r
.21231 .55775 m .21311 .55909 L .21224 .55734 L F
.698 .367 .413 r
.20918 .55932 m .20632 .55714 L .21257 .55902 L F
.232 0 0 r
.21224 .55734 m .20918 .55932 L .21257 .55902 L F
.666 .571 .738 r
.21224 .55734 m .21311 .55909 L .21562 .55669 L F
.367 .829 .911 r
.21421 .55769 m .21141 .55876 L .21224 .55734 L F
.766 .996 .824 r
.21562 .55669 m .21311 .55909 L .21517 .5583 L F
.367 .829 .911 r
.21649 .55809 m .2122 .55865 L .21421 .55769 L F
.2122 .55865 m .21141 .55876 L .21421 .55769 L F
.752 .994 .858 r
.21604 .55659 m .21562 .55669 L .21583 .55776 L F
.484 .297 .551 r
.21564 .55412 m .21649 .55809 L .21562 .55669 L F
.597 .333 .488 r
.21562 .55669 m .21649 .55809 L .21224 .55734 L F
.367 .829 .911 r
.21649 .55809 m .21364 .55819 L .21141 .55876 L F
0 0 .305 r
.21645 .55526 m .21648 .55687 L .21614 .55617 L F
.733 .93 .955 r
.21539 .5572 m .21649 .55809 L .21645 .55526 L F
.21539 .5572 m .21364 .55819 L .21649 .55809 L F
.34 0 0 r
.21788 .5584 m .21364 .55819 L .21649 .55809 L F
.735 .776 .886 r
.21539 .5572 m .21364 .55819 L .21788 .5584 L F
.21539 .5572 m .21364 .55819 L .21788 .5584 L F
.793 .757 .821 r
.22001 .55647 m .21788 .5584 L .21539 .5572 L F
.129 0 .106 r
.22001 .55647 m .21959 .55768 L .21788 .5584 L F
.554 .05 .012 r
.21959 .55768 m .21539 .5572 L .21788 .5584 L F
.116 .668 .769 r
.21691 .55777 m .2138 .55854 L .21539 .5572 L F
.21834 .55832 m .21719 .55837 L .21691 .55777 L F
.21719 .55837 m .2138 .55854 L .21691 .55777 L F
0 0 .305 r
.21632 .55508 m .2161 .55627 L .21564 .55412 L F
.21645 .55526 m .2161 .55627 L .21632 .55508 L F
0 0 0 r
.24451 .68551 m .24319 .68658 L .24112 .68855 L F
.658 .812 .958 r
.79893 .43525 m .80081 .43237 L .79755 .43387 L F
.79893 .43525 m .80178 .43429 L .80081 .43237 L F
.029 0 .47 r
.53902 .58911 m .5404 .58417 L .54051 .58635 L F
.502 .258 .478 r
.29932 .59464 m .30168 .59429 L .30196 .59196 L F
.409 .18 .453 r
.30196 .59196 m .30168 .59429 L .30416 .59125 L F
.556 .147 .221 r
.17002 .59114 m .17253 .59196 L .17319 .58953 L F
.537 .392 .631 r
.17319 .58953 m .17476 .59389 L .17641 .59106 L F
0 0 .407 r
.17459 .59198 m .17476 .59389 L .17319 .58953 L F
0 0 .35 r
.17476 .59389 m .17494 .59486 L .17319 .58953 L F
0 0 .407 r
.17459 .59198 m .17319 .58953 L .17253 .59196 L F
.165 0 0 r
.48481 .6131 m .48821 .61153 L .48395 .61049 L F
.48481 .6131 m .48713 .61241 L .48821 .61153 L F
.608 .615 .833 r
.45672 .66173 m .46122 .66509 L .46057 .66214 L F
.341 .291 .656 r
.46122 .66509 m .46284 .6643 L .46057 .66214 L F
.46122 .66509 m .46284 .6643 L .46057 .66214 L F
.435 .23 .501 r
.46612 .65599 m .46814 .65834 L .46807 .65497 L F
.46612 .65599 m .46568 .65858 L .46814 .65834 L F
.492 .353 .621 r
.8147 .40673 m .81224 .41001 L .81242 .40857 L F
.715 .712 .846 r
.79234 .4205 m .78849 .41952 L .79182 .41701 L F
.782 .768 .84 r
.79519 .41752 m .79234 .4205 L .79182 .41701 L F
.633 .837 .979 r
.8389 .41236 m .8354 .4121 L .83791 .41092 L F
.716 .801 .918 r
.83791 .41092 m .84139 .4113 L .8389 .41236 L F
.595 .582 .809 r
.16884 .61352 m .17076 .61697 L .17272 .61625 L F
.702 .711 .855 r
.21117 .64611 m .21499 .64665 L .21272 .64771 L F
.21117 .64611 m .21499 .64665 L .21272 .64771 L F
.477 .359 .64 r
.32048 .60945 m .31796 .60736 L .32047 .60667 L F
.32048 .60945 m .31832 .60999 L .31796 .60736 L F
.498 .095 .206 r
.53337 .52044 m .5348 .52072 L .53689 .51827 L F
.154 0 0 r
.53689 .51827 m .54013 .51871 L .54001 .51726 L F
.53689 .51827 m .5348 .52072 L .54013 .51871 L F
.875 .961 .624 r
.49911 .58076 m .4981 .58223 L .49818 .58113 L F
.948 .89 .739 r
.49806 .57838 m .49911 .58076 L .50038 .57726 L F
.246 0 0 r
.49818 .58113 m .50215 .58132 L .49911 .58076 L F
.812 .64 .668 r
.48789 .63125 m .48942 .63198 L .49139 .62853 L F
.299 .682 .975 r
.52559 .56366 m .53149 .56453 L .52966 .56448 L F
.645 .58 .768 r
.52966 .56448 m .53183 .5672 L .52906 .56627 L F
.613 .422 .6 r
.52881 .56467 m .53149 .56453 L .52559 .56366 L F
.463 .694 .967 r
.21975 .62319 m .21604 .62177 L .21803 .62203 L F
.419 .746 .994 r
.2217 .62297 m .21975 .62319 L .21803 .62203 L F
.476 .66 .942 r
.31062 .53866 m .30985 .54073 L .30856 .5388 L F
.31062 .53866 m .31173 .54038 L .30985 .54073 L F
.354 0 0 r
.22227 .55128 m .21751 .55323 L .22006 .55173 L F
.424 .443 .776 r
.54172 .59499 m .54342 .59412 L .54068 .59239 L F
.464 .377 .673 r
.54194 .59718 m .54342 .59412 L .54172 .59499 L F
.558 .844 .511 r
.81709 .40409 m .81544 .40602 L .81731 .4044 L F
.558 .399 .622 r
.42749 .65587 m .42697 .65761 L .4266 .65624 L F
.799 .601 .634 r
.42773 .65611 m .42895 .65501 L .42658 .65499 L F
.558 .399 .622 r
.42774 .65577 m .42764 .65602 L .42749 .65587 L F
.42764 .65602 m .42697 .65761 L .42749 .65587 L F
.4274 .65554 m .4266 .65624 L .42658 .65499 L F
.42774 .65577 m .4266 .65624 L .4274 .65554 L F
.799 .601 .634 r
.42705 .65673 m .42773 .65611 L .42658 .65499 L F
.558 .399 .622 r
.42697 .65761 m .42661 .65774 L .4266 .65624 L F
.431 .348 .662 r
.42374 .65878 m .42705 .65673 L .42374 .65877 L F
.42434 .66071 m .42628 .65786 L .42374 .65878 L F
.42628 .65786 m .42705 .65673 L .42374 .65878 L F
.558 .399 .622 r
.42697 .65761 m .42662 .65846 L .42661 .65774 L F
.36 .114 .399 r
.42627 .65653 m .42374 .65877 L .42705 .65673 L F
.42419 .65601 m .42374 .65876 L .42627 .65653 L F
.42374 .65876 m .42374 .65877 L .42627 .65653 L F
.42419 .65601 m .42705 .65673 L .42658 .65499 L F
0 0 .381 r
.176 .59592 m .17522 .59796 L .17494 .59486 L F
.613 .316 .441 r
.2905 .63702 m .28849 .64007 L .28603 .64007 L F
.573 .269 .414 r
.29233 .63918 m .2905 .63702 L .29241 .63731 L F
.29233 .63918 m .28849 .64007 L .2905 .63702 L F
.358 .358 .723 r
.54289 .59965 m .54386 .59592 L .54194 .59718 L F
.289 0 .286 r
.15168 .57368 m .1527 .57503 L .1538 .57305 L F
.15168 .57368 m .15091 .57573 L .1527 .57503 L F
.556 .265 .429 r
.46988 .62149 m .47314 .61923 L .47028 .61966 L F
.93 .667 .517 r
.5097 .59764 m .50968 .60021 L .51148 .60065 L F
.741 .48 .536 r
.5094 .6031 m .51148 .60065 L .50968 .60021 L F
.5094 .6031 m .51154 .60327 L .51148 .60065 L F
.937 .859 .737 r
.56265 .53858 m .56529 .53731 L .56347 .53623 L F
.56265 .53858 m .564 .53969 L .56529 .53731 L F
.455 .219 .466 r
.32317 .60097 m .32289 .60335 L .32046 .60394 L F
.572 .329 .51 r
.32566 .60063 m .32289 .60335 L .32317 .60097 L F
0 0 0 r
.44936 .6714 m .44776 .67244 L .44963 .67132 L F
.882 .598 .502 r
.5614 .57195 m .56438 .57051 L .56095 .56959 L F
.5614 .57195 m .56444 .57296 L .56438 .57051 L F
.463 .216 .453 r
.51243 .52402 m .50961 .52696 L .51003 .5245 L F
.996 .793 .433 r
.51003 .5245 m .50888 .5257 L .50961 .52696 L F
.463 .216 .453 r
.51243 .52402 m .50961 .52696 L .51003 .5245 L F
.985 .717 .432 r
.46324 .64689 m .46263 .64516 L .46222 .64507 L F
.46263 .64516 m .46192 .64309 L .46222 .64507 L F
.46324 .64689 m .46201 .64656 L .46192 .64309 L F
.189 0 .077 r
.46201 .64656 m .46397 .64587 L .46419 .64546 L F
.46331 .64529 m .46419 .64546 L .46545 .64321 L F
.46201 .64656 m .46419 .64546 L .46331 .64529 L F
.985 .717 .432 r
.46222 .64507 m .46192 .64309 L .46141 .64361 L F
.641 .858 .982 r
.27992 .53425 m .27598 .53421 L .27832 .53356 L F
.522 .853 .997 r
.27992 .53425 m .28045 .53291 L .2822 .53326 L F
.27992 .53425 m .27832 .53356 L .28045 .53291 L F
.423 0 0 r
.54235 .51703 m .54481 .51714 L .54613 .51559 L F
.578 .098 .08 r
.54613 .51559 m .54481 .51714 L .54861 .51707 L F
.542 .331 .543 r
.30047 .63122 m .29818 .63388 L .29762 .63136 L F
.197 .471 .888 r
.30622 .57537 m .30499 .57583 L .30654 .57352 L F
.509 .649 .92 r
.78101 .42746 m .78536 .42974 L .78468 .42773 L F
.37 .563 .91 r
.78468 .42773 m .78536 .42974 L .78688 .42805 L F
.351 .534 .894 r
.78536 .42974 m .78757 .4305 L .78688 .42805 L F
.384 .505 .858 r
.78536 .42974 m .78905 .43312 L .78757 .4305 L F
.557 .096 .114 r
.54861 .51707 m .55105 .51752 L .55259 .51575 L F
.765 .35 .263 r
.55259 .51575 m .55105 .51752 L .55263 .51729 L F
.572 .318 .493 r
.2952 .63471 m .29492 .63726 L .29241 .63731 L F
.527 .279 .483 r
.29738 .63675 m .2952 .63471 L .29818 .63388 L F
.29738 .63675 m .29492 .63726 L .2952 .63471 L F
.478 .356 .635 r
.28521 .54772 m .28287 .55 L .28295 .5482 L F
.414 .168 .429 r
.28295 .5482 m .28521 .54772 L .28287 .55 L F
.28295 .5482 m .28453 .55063 L .28521 .54772 L F
.313 0 .167 r
.28521 .54772 m .28506 .54881 L .28295 .5482 L F
.257 .12 .495 r
.28506 .54881 m .28453 .55063 L .28295 .5482 L F
.501 .451 .733 r
.42298 .65069 m .4238 .64559 L .42144 .64638 L F
.42298 .65069 m .42543 .64981 L .4238 .64559 L F
.828 .744 .771 r
.55066 .56443 m .54773 .56393 L .54971 .56104 L F
.919 .708 .601 r
.54956 .5675 m .54773 .56393 L .55066 .56443 L F
.892 .989 .749 r
.25539 .54994 m .25343 .55271 L .25509 .55213 L F
.164 .579 .935 r
.23 .62499 m .22966 .62604 L .22798 .62517 L F
.23 .62499 m .23206 .62655 L .22966 .62604 L F
.093 0 0 r
.21976 .53747 m .21563 .53892 L .21616 .53571 L F
.21976 .53747 m .21789 .53855 L .21563 .53892 L F
0 0 0 r
.21789 .53855 m .22151 .53773 L .21976 .53747 L F
.853 .555 .484 r
.56444 .57296 m .56819 .57617 L .56802 .57366 L F
.781 .575 .622 r
.56819 .57617 m .5698 .57646 L .56802 .57366 L F
.826 .985 .708 r
.33897 .56641 m .33891 .5659 L .33862 .56761 L F
.96 .747 .57 r
.33622 .56857 m .33862 .56761 L .33891 .5659 L F
.33622 .56857 m .33796 .56989 L .33862 .56761 L F
.651 .718 .898 r
.79286 .43578 m .79403 .43207 L .79162 .4324 L F
.79286 .43578 m .79538 .43482 L .79403 .43207 L F
.718 .461 .535 r
.49258 .54857 m .49455 .54885 L .49304 .54611 L F
.733 .721 .84 r
.25676 .64277 m .25847 .64376 L .26121 .64324 L F
.647 .178 .125 r
.26121 .64324 m .2593 .64449 L .25676 .64277 L F
0 .215 .684 r
.25674 .64252 m .2593 .64449 L .25672 .64218 L F
.25676 .64277 m .25755 .64331 L .25674 .64252 L F
.795 .928 .923 r
.25716 .644 m .25847 .64376 L .25676 .64277 L F
0 .215 .684 r
.25755 .64331 m .2593 .64449 L .25674 .64252 L F
.795 .928 .923 r
.25716 .644 m .25737 .64579 L .25831 .64406 L F
.25809 .64383 m .25831 .64406 L .25847 .64376 L F
.25716 .644 m .25831 .64406 L .25809 .64383 L F
.59 .367 .545 r
.32293 .60624 m .32046 .60394 L .32289 .60335 L F
.32293 .60624 m .32047 .60667 L .32046 .60394 L F
.963 .802 .634 r
.84158 .41599 m .84367 .41504 L .84247 .41384 L F
.84158 .41599 m .84291 .41736 L .84367 .41504 L F
0 0 0 r
.48821 .61153 m .48713 .61241 L .49019 .61006 L F
.373 .014 .221 r
.24071 .70397 m .2368 .70723 L .23715 .70508 L F
.131 .678 .803 r
.27175 .53428 m .27598 .53421 L .27365 .53483 L F
.69 .708 .861 r
.55731 .59504 m .55849 .59091 L .55605 .59408 L F
.929 .943 .784 r
.34128 .56247 m .33897 .56641 L .34114 .56494 L F
.462 .713 .977 r
.23579 .64193 m .23998 .64303 L .23821 .64235 L F
.507 .313 .552 r
.47159 .62536 m .47157 .62802 L .46906 .62856 L F
.486 .245 .474 r
.47157 .62802 m .46878 .63092 L .46906 .62856 L F
.597 .571 .795 r
.23767 .70059 m .23558 .70168 L .23552 .70097 L F
.461 .887 .898 r
.23609 .70157 m .23558 .70168 L .23594 .70149 L F
.387 .255 .576 r
.23585 .70152 m .23553 .70488 L .23731 .70394 L F
.23552 .70097 m .23552 .70163 L .23585 .70152 L F
.23552 .70163 m .23553 .70488 L .23585 .70152 L F
.23558 .70131 m .23731 .70394 L .23577 .70243 L F
.23579 .70141 m .23731 .70394 L .23558 .70131 L F
.461 .887 .898 r
.23976 .70078 m .23609 .70157 L .23767 .70059 L F
.458 .782 .998 r
.23983 .69911 m .23976 .70078 L .23767 .70059 L F
0 0 0 r
.23931 .70038 m .23891 .70043 L .23577 .70243 L F
.23891 .70043 m .23767 .70059 L .23721 .70103 L F
.23891 .70043 m .23721 .70103 L .23577 .70243 L F
.387 .255 .576 r
.23552 .70097 m .23579 .70141 L .23558 .70131 L F
.461 .887 .898 r
.23609 .70157 m .23594 .70149 L .23767 .70059 L F
.458 .782 .998 r
.23983 .69911 m .24219 .70049 L .23976 .70078 L F
.365 .705 .985 r
.22006 .72923 m .2177 .72936 L .21795 .72806 L F
.22006 .72923 m .2177 .72936 L .21795 .72806 L F
.466 0 0 r
.2177 .72936 m .22213 .73212 L .22006 .72923 L F
.48 .677 .951 r
.80423 .43299 m .80595 .4354 L .80857 .43497 L F
.606 .685 .898 r
.80595 .4354 m .80818 .43588 L .80857 .43497 L F
.274 .121 .484 r
.28493 .60345 m .28666 .60021 L .28503 .60081 L F
.505 .106 .219 r
.81281 .40052 m .8161 .39846 L .81356 .39929 L F
.274 0 .301 r
.15446 .57129 m .15567 .57218 L .15657 .57038 L F
.15446 .57129 m .1538 .57305 L .15567 .57218 L F
.751 .456 .483 r
.55634 .51794 m .55856 .52076 L .56021 .51834 L F
.8 .521 .516 r
.56021 .51834 m .55856 .52076 L .56063 .5208 L F
.495 .512 .804 r
.33461 .58651 m .33297 .58894 L .33171 .58521 L F
.443 .443 .764 r
.33461 .58651 m .33515 .58883 L .33297 .58894 L F
.61 .47 .666 r
.3363 .59102 m .33297 .58894 L .33515 .58883 L F
.3363 .59102 m .33331 .59209 L .33297 .58894 L F
.717 .735 .865 r
.82161 .41042 m .82009 .41463 L .81912 .4134 L F
.82161 .41042 m .82272 .41349 L .82009 .41463 L F
.217 0 .093 r
.17597 .55479 m .17671 .55639 L .17793 .55388 L F
.17597 .55479 m .1747 .55706 L .17671 .55639 L F
.197 .678 .931 r
.23821 .64235 m .23438 .64135 L .23579 .64193 L F
.518 .323 .556 r
.30853 .62231 m .30839 .62491 L .30604 .62537 L F
.522 .282 .492 r
.30839 .62491 m .30567 .62768 L .30604 .62537 L F
.257 0 0 r
.18343 .55158 m .18579 .55106 L .18754 .5491 L F
.097 0 0 r
.18754 .5491 m .18787 .55032 L .18969 .54846 L F
.18754 .5491 m .18579 .55106 L .18787 .55032 L F
.643 .585 .774 r
.80393 .41622 m .80165 .41534 L .80387 .41436 L F
.637 .494 .671 r
.80659 .41371 m .80393 .41622 L .80387 .41436 L F
.181 .699 .884 r
.23815 .62631 m .23609 .62651 L .23426 .62604 L F
.449 .532 .851 r
.76999 .41914 m .77177 .41661 L .7689 .4168 L F
.76999 .41914 m .77292 .41959 L .77177 .41661 L F
.62 .742 .934 r
.28986 .53507 m .2861 .53452 L .28843 .53406 L F
.41 .564 .896 r
.29036 .53306 m .28986 .53507 L .28843 .53406 L F
.29036 .53306 m .29258 .53608 L .28986 .53507 L F
.448 .125 .324 r
.52966 .56448 m .52847 .5656 L .52906 .56627 L F
.028 0 0 r
.53861 .52391 m .53761 .52432 L .53512 .52471 L F
.948 .89 .739 r
.49806 .57838 m .50038 .57726 L .49835 .5753 L F
.402 .368 .706 r
.32048 .60945 m .31911 .61277 L .31832 .60999 L F
.32048 .60945 m .32126 .61241 L .31911 .61277 L F
.31 .093 .414 r
.32065 .61479 m .31911 .61277 L .32126 .61241 L F
.32065 .61479 m .31871 .61553 L .31911 .61277 L F
.574 .742 .956 r
.19904 .63579 m .20432 .63747 L .20082 .63492 L F
0 .404 .836 r
.20082 .63492 m .20432 .63747 L .20375 .6363 L F
0 0 .366 r
.20432 .63747 m .20462 .63795 L .20375 .6363 L F
.607 .397 .571 r
.47642 .62172 m .47362 .62462 L .47434 .62272 L F
.241 .47 .879 r
.25853 .6461 m .26065 .64913 L .26221 .64931 L F
.469 .172 .378 r
.30132 .59645 m .29932 .59464 L .29798 .59725 L F
.30132 .59645 m .30168 .59429 L .29932 .59464 L F
.194 .211 .65 r
.80818 .43588 m .81092 .43691 L .80857 .43497 L F
.80818 .43588 m .80915 .43891 L .81092 .43691 L F
.5 .146 .297 r
.25705 .55318 m .26035 .55378 L .26093 .55181 L F
.521 .55 .826 r
.2585 .5556 m .26035 .55378 L .25705 .55318 L F
.936 .75 .626 r
.33733 .57244 m .33924 .57342 L .33796 .56989 L F
.105 .178 .656 r
.34107 .57556 m .34044 .57664 L .33924 .57342 L F
0 0 .46 r
.33993 .57422 m .33924 .57342 L .33733 .57244 L F
.564 .615 .862 r
.34076 .57343 m .34036 .57472 L .33993 .57422 L F
0 0 .46 r
.33993 .57422 m .34107 .57556 L .33927 .57346 L F
.486 .451 .744 r
.34107 .57556 m .34014 .57871 L .34044 .57664 L F
.34107 .57556 m .3419 .57864 L .34014 .57871 L F
.375 .378 .735 r
.3435 .57755 m .3419 .57864 L .34107 .57556 L F
.815 .574 .575 r
.33993 .57422 m .3435 .57755 L .34107 .57556 L F
.33993 .57422 m .33965 .57696 L .3435 .57755 L F
.564 .615 .862 r
.34036 .57472 m .33965 .57696 L .33993 .57422 L F
0 0 .46 r
.33993 .57422 m .33927 .57346 L .33924 .57342 L F
.742 .727 .837 r
.5622 .59129 m .56599 .59174 L .56467 .58839 L F
.773 .644 .719 r
.5622 .59129 m .56355 .59491 L .56599 .59174 L F
.205 .39 .825 r
.56599 .59174 m .56714 .59022 L .56467 .58839 L F
.472 .767 .995 r
.56599 .59174 m .56853 .59137 L .56714 .59022 L F
.913 .826 .747 r
.83747 .4279 m .83866 .4297 L .83831 .42593 L F
.629 .618 .82 r
.23707 .69152 m .23851 .69386 L .24045 .69286 L F
.221 .091 .482 r
.47318 .62664 m .47159 .62536 L .47362 .62462 L F
.47318 .62664 m .47157 .62802 L .47159 .62536 L F
.134 .65 .891 r
.25078 .53505 m .25326 .53524 L .25474 .53575 L F
.092 .637 .839 r
.25326 .53524 m .25702 .53564 L .25474 .53575 L F
.486 .677 .949 r
.77444 .42252 m .77681 .42228 L .77597 .42041 L F
.099 0 0 r
.46659 .64675 m .4626 .64879 L .46324 .64689 L F
.46659 .64675 m .46459 .64829 L .4626 .64879 L F
.967 .68 .264 r
.46545 .64321 m .4657 .64591 L .46659 .64675 L F
.983 .903 .642 r
.4657 .64591 m .46459 .64829 L .46659 .64675 L F
.564 .596 .843 r
.54068 .59239 m .54267 .59018 L .53902 .58911 L F
.54068 .59239 m .54259 .59168 L .54267 .59018 L F
.513 .429 .698 r
.54068 .59239 m .54342 .59412 L .54259 .59168 L F
.465 .269 .529 r
.3109 .61917 m .31076 .62176 L .30853 .62231 L F
.508 .332 .577 r
.31076 .62176 m .30839 .62491 L .30853 .62231 L F
0 0 0 r
.27199 .60092 m .27028 .60416 L .27088 .60314 L F
0 0 .074 r
.27199 .60092 m .27279 .60203 L .27291 .59951 L F
.27199 .60092 m .27088 .60314 L .27279 .60203 L F
.557 .641 .89 r
.18876 .6278 m .18893 .62417 L .18665 .62488 L F
.18876 .6278 m .19107 .62727 L .18893 .62417 L F
0 0 .029 r
.27596 .60749 m .27531 .61091 L .27586 .60914 L F
.892 .675 .603 r
.79799 .41134 m .79783 .41459 L .79623 .41065 L F
.184 0 0 r
.24292 .69276 m .24397 .69287 L .24485 .69399 L F
.231 .268 .694 r
.2446 .69289 m .24292 .69276 L .24485 .69399 L F
.607 .887 .99 r
.24195 .69269 m .24454 .6924 L .24292 .69276 L F
.184 0 0 r
.24292 .69276 m .24454 .6924 L .24397 .69287 L F
.345 0 0 r
.24454 .6924 m .24744 .69285 L .24397 .69287 L F
.738 .922 .953 r
.24397 .69287 m .24744 .69285 L .24866 .69133 L F
.733 .926 .955 r
.24397 .69287 m .24866 .69133 L .24729 .69075 L F
.24397 .69287 m .24729 .69075 L .24485 .69399 L F
.231 .268 .694 r
.24393 .68996 m .24292 .69276 L .2446 .69289 L F
.607 .887 .99 r
.24045 .69286 m .24195 .69269 L .24292 .69276 L F
.3 .567 .931 r
.1815 .62208 m .1817 .6202 L .17863 .61913 L F
.1815 .62208 m .18271 .62171 L .1817 .6202 L F
.25 .197 .6 r
.26093 .55181 m .26289 .55101 L .26235 .5475 L F
.351 .126 .426 r
.26035 .55378 m .26289 .55101 L .26093 .55181 L F
.646 .757 .93 r
.21564 .55412 m .21774 .55619 L .21999 .55493 L F
.812 .592 .604 r
.56834 .57858 m .5698 .57646 L .56819 .57617 L F
.56834 .57858 m .56989 .57942 L .5698 .57646 L F
.565 .577 .825 r
.30622 .57537 m .30777 .57897 L .30548 .57952 L F
.718 .656 .787 r
.19463 .61218 m .19209 .61352 L .19039 .61065 L F
.483 .891 .929 r
.24222 .62568 m .23815 .62631 L .2401 .62592 L F
0 .564 .759 r
.24245 .62554 m .24222 .62568 L .2401 .62592 L F
.24245 .62554 m .2444 .62584 L .24222 .62568 L F
.583 .941 .81 r
.82282 .39687 m .82437 .39534 L .82492 .39523 L F
.82282 .39687 m .82138 .39712 L .82437 .39534 L F
.112 .053 .504 r
.46017 .6313 m .46145 .62767 L .45877 .62803 L F
.46017 .6313 m .46165 .63089 L .46145 .62767 L F
.471 .164 .363 r
.45864 .63313 m .46017 .6313 L .46246 .63379 L F
.45864 .63313 m .46165 .63089 L .46017 .6313 L F
.744 .61 .71 r
.52478 .57687 m .52691 .57619 L .52693 .5734 L F
.692 .553 .691 r
.52691 .57619 m .52826 .5795 L .53071 .57634 L F
0 .141 .676 r
.50766 .60384 m .50898 .6065 L .50795 .60408 L F
.187 0 0 r
.20991 .6375 m .20837 .63784 L .20462 .63795 L F
.2 .725 .731 r
.21213 .63701 m .20837 .63784 L .20991 .6375 L F
.781 .718 .793 r
.42543 .64981 m .42665 .65299 L .42937 .64988 L F
.641 .302 .383 r
.42665 .65299 m .42895 .65501 L .42658 .65499 L F
.42658 .65499 m .42895 .65501 L .42665 .65299 L F
.845 .521 .439 r
.79497 .40207 m .79561 .40448 L .79876 .40523 L F
.783 .557 .593 r
.79561 .40448 m .79882 .40692 L .79876 .40523 L F
.531 .225 .393 r
.79882 .40692 m .80157 .40682 L .79876 .40523 L F
.528 .228 .403 r
.79876 .40523 m .80157 .40682 L .80143 .40512 L F
.273 .032 .355 r
.17031 .55821 m .17166 .55964 L .17244 .55771 L F
.17031 .55821 m .16977 .56053 L .17166 .55964 L F
.43 .226 .5 r
.27765 .61304 m .2798 .61256 L .27995 .61011 L F
.424 .182 .441 r
.27765 .61304 m .2795 .61489 L .2798 .61256 L F
.27765 .61304 m .27731 .61555 L .2795 .61489 L F
.787 .671 .735 r
.52322 .57284 m .52478 .57687 L .52693 .5734 L F
.04 0 .231 r
.26904 .60631 m .27088 .60314 L .27028 .60416 L F
.119 .666 .816 r
.26331 .53537 m .26563 .53528 L .26715 .53545 L F
.114 0 0 r
.26563 .53528 m .26955 .5349 L .26715 .53545 L F
.723 .371 .38 r
.79222 .40543 m .78902 .40703 L .7915 .40365 L F
.79222 .40543 m .79264 .40731 L .78902 .40703 L F
.548 .259 .428 r
.79222 .40543 m .7956 .40685 L .79264 .40731 L F
.779 .663 .736 r
.49471 .60389 m .49546 .60626 L .49854 .60392 L F
.722 .667 .795 r
.46498 .62419 m .47036 .62577 L .46988 .62149 L F
.122 0 .347 r
.47318 .62664 m .47122 .63042 L .47157 .62802 L F
.671 .385 .478 r
.46498 .62419 m .4727 .62755 L .47036 .62577 L F
.132 .209 .678 r
.46988 .62149 m .47036 .62577 L .47198 .62274 L F
0 0 .237 r
.4727 .62755 m .47198 .62274 L .47036 .62577 L F
.982 .694 .375 r
.55546 .54294 m .55416 .5419 L .55398 .53928 L F
.373 .014 .221 r
.24071 .70397 m .23904 .70677 L .2368 .70723 L F
.518 .361 .607 r
.24232 .70338 m .24244 .70432 L .24071 .70397 L F
0 0 0 r
.24018 .7058 m .24071 .70397 L .24244 .70432 L F
.24018 .7058 m .23904 .70677 L .24071 .70397 L F
.241 0 0 r
.25973 .54683 m .2589 .54807 L .25616 .54862 L F
0 0 0 r
.26047 .54711 m .25973 .54683 L .26235 .5475 L F
.26047 .54711 m .2589 .54807 L .25973 .54683 L F
.59 .605 .835 r
.78757 .4305 m .78905 .43312 L .79162 .4324 L F
.674 .874 .974 r
.19039 .61065 m .1882 .61169 L .18654 .61076 L F
.613 .527 .733 r
.80814 .41762 m .80519 .42031 L .80393 .41622 L F
.66 .606 .784 r
.80814 .41762 m .80903 .42111 L .80519 .42031 L F
.432 .498 .827 r
.77734 .42463 m .77912 .42208 L .77681 .42228 L F
.77734 .42463 m .78048 .42565 L .77912 .42208 L F
.557 .069 .052 r
.26697 .55642 m .26558 .55753 L .26342 .55638 L F
.134 .362 .821 r
.26342 .55638 m .26558 .55753 L .26524 .55695 L F
.373 0 0 r
.26504 .55493 m .26342 .55638 L .26194 .55591 L F
.698 .368 .413 r
.2674 .55455 m .26342 .55638 L .26504 .55493 L F
.2674 .55455 m .26697 .55642 L .26342 .55638 L F
.134 .362 .821 r
.26342 .55638 m .26524 .55695 L .26408 .55495 L F
.373 0 0 r
.26194 .55591 m .26342 .55638 L .26158 .55603 L F
.745 .831 .917 r
.81945 .43974 m .82015 .4371 L .81843 .4384 L F
.81945 .43974 m .82153 .43845 L .82015 .4371 L F
.902 .738 .668 r
.55282 .53315 m .55418 .53672 L .55218 .53577 L F
.868 .677 .642 r
.55398 .53928 m .55218 .53577 L .55418 .53672 L F
.674 .685 .852 r
.28495 .53239 m .2861 .53452 L .2822 .53326 L F
.518 .606 .881 r
.2871 .53192 m .2861 .53452 L .28495 .53239 L F
.558 .651 .898 r
.2871 .53192 m .28843 .53406 L .2861 .53452 L F
.836 .789 .807 r
.25636 .66713 m .25846 .66846 L .26065 .66533 L F
.92 .709 .602 r
.2563 .67189 m .25846 .66846 L .25636 .66713 L F
.729 .863 .441 r
.2751 .55785 m .27563 .55635 L .27679 .55471 L F
.18 .255 .706 r
.27679 .55471 m .27861 .55356 L .27639 .55123 L F
.438 .076 .252 r
.4991 .55446 m .50283 .55173 L .50023 .55163 L F
.596 .41 .6 r
.3133 .61873 m .31076 .62176 L .3109 .61917 L F
.366 .262 .602 r
.49156 .60906 m .49314 .60816 L .49247 .60331 L F
.576 .409 .619 r
.49247 .60331 m .49539 .60662 L .49471 .60389 L F
.49247 .60331 m .49314 .60816 L .49539 .60662 L F
.459 .341 .631 r
.31334 .57284 m .31511 .56967 L .31295 .57024 L F
.31334 .57284 m .31511 .56967 L .31295 .57024 L F
.462 .667 .952 r
.78101 .42746 m .78265 .42556 L .78048 .42565 L F
.78101 .42746 m .78468 .42773 L .78265 .42556 L F
0 0 .224 r
.50898 .6065 m .5094 .6031 L .50795 .60408 L F
.50898 .6065 m .50968 .60531 L .5094 .6031 L F
.754 .684 .784 r
.50965 .60858 m .50968 .60531 L .50898 .6065 L F
.652 .845 .974 r
.82639 .40175 m .82986 .40198 L .82885 .40074 L F
.805 .897 .908 r
.82885 .40074 m .82986 .40198 L .83283 .39946 L F
.558 .443 .678 r
.27421 .5825 m .27695 .58218 L .27651 .57916 L F
.641 .851 .98 r
.79882 .40692 m .79612 .40826 L .7956 .40685 L F
0 0 0 r
.49156 .60906 m .49223 .60914 L .49314 .60816 L F
.49156 .60906 m .49019 .61006 L .49223 .60914 L F
.682 .799 .937 r
.7787 .41746 m .77681 .41884 L .77533 .41716 L F
.16 .697 .829 r
.25702 .53564 m .25937 .53546 L .26092 .53559 L F
.146 .688 .813 r
.25937 .53546 m .26331 .53537 L .26092 .53559 L F
.347 .124 .427 r
.26026 .61943 m .26172 .62106 L .26243 .61865 L F
.26026 .61943 m .25987 .62197 L .26172 .62106 L F
.807 .693 .739 r
.47843 .56119 m .4781 .56229 L .47624 .5627 L F
.521 .55 .826 r
.2585 .5556 m .26158 .55603 L .26035 .55378 L F
.637 .494 .671 r
.80659 .41371 m .80814 .41762 L .80393 .41622 L F
.344 .823 .823 r
.82009 .40333 m .82372 .40251 L .82312 .40234 L F
0 0 0 r
.82372 .40251 m .82639 .40175 L .82553 .40243 L F
.82372 .40251 m .82553 .40243 L .82312 .40234 L F
.22392 .53747 m .22829 .53679 L .22605 .53712 L F
.192 .485 .898 r
.21651 .6203 m .21604 .62177 L .21426 .61956 L F
.278 .584 .944 r
.21651 .6203 m .21803 .62203 L .21604 .62177 L F
.963 .908 .546 r
.25404 .65684 m .25503 .65564 L .25381 .65874 L F
0 0 0 r
.25605 .65457 m .25503 .65564 L .25404 .65684 L F
.086 .485 .896 r
.17594 .61749 m .17722 .61894 L .17725 .61777 L F
.132 .533 .919 r
.17722 .61894 m .17863 .61913 L .17725 .61777 L F
0 0 0 r
.22874 .54961 m .22672 .55028 L .22448 .55063 L F
.664 .974 .855 r
.47628 .64214 m .47455 .64347 L .47536 .64363 L F
.54 .692 .938 r
.1796 .59738 m .17942 .60035 L .17744 .59787 L F
.1796 .59738 m .18179 .59987 L .17942 .60035 L F
.8 .39 .273 r
.51187 .56227 m .51063 .56351 L .50817 .56028 L F
.669 .215 .164 r
.51187 .56227 m .51344 .56374 L .51063 .56351 L F
.966 .728 .526 r
.55791 .56016 m .55934 .56373 L .55944 .56112 L F
.563 .214 .335 r
.28007 .64106 m .27968 .64286 L .27721 .64292 L F
.6 .266 .376 r
.28363 .64033 m .27968 .64286 L .28007 .64106 L F
.009 0 0 r
.17445 .57741 m .17417 .57647 L .17635 .57599 L F
.17445 .57741 m .17284 .57847 L .17417 .57647 L F
.183 0 .257 r
.27925 .57638 m .28084 .57574 L .2817 .57337 L F
.365 .313 .667 r
.27925 .57638 m .28154 .57818 L .28084 .57574 L F
.494 .3 .546 r
.27905 .5786 m .28154 .57818 L .27925 .57638 L F
0 0 .44 r
.50191 .5916 m .50389 .59263 L .50133 .59023 L F
0 .275 .78 r
.20821 .61537 m .20794 .61688 L .20655 .61513 L F
.20821 .61537 m .21024 .61846 L .20794 .61688 L F
.412 0 .118 r
.19342 .56385 m .19199 .56592 L .18959 .56618 L F
.397 .033 .225 r
.19617 .56307 m .19199 .56592 L .19342 .56385 L F
.939 .641 .449 r
.55913 .56626 m .56095 .56959 L .56086 .56713 L F
.517 .914 .823 r
.28313 .59659 m .28492 .59533 L .28353 .59567 L F
.579 .338 .515 r
.45806 .66784 m .46061 .66775 L .46122 .66509 L F
.46122 .66509 m .46061 .66775 L .45806 .66784 L F
.639 .524 .708 r
.46061 .66775 m .46284 .6643 L .46122 .66509 L F
.644 .531 .711 r
.46284 .6643 m .46061 .66775 L .46122 .66509 L F
.919 .708 .601 r
.54956 .5675 m .54703 .56655 L .54773 .56393 L F
.868 .709 .682 r
.54952 .56852 m .54703 .56655 L .54956 .5675 L F
.025 .134 .642 r
.22328 .72595 m .22518 .72837 L .22438 .72534 L F
0 0 0 r
.27531 .61168 m .27531 .61091 L .27586 .60914 L F
.929 .546 .224 r
.50564 .58797 m .50648 .5907 L .50798 .59155 L F
.994 .862 .595 r
.50611 .59325 m .50798 .59155 L .50648 .5907 L F
.50611 .59325 m .50698 .59492 L .50798 .59155 L F
.495 .226 .436 r
.27225 .61896 m .2747 .61858 L .27527 .61632 L F
.456 .23 .481 r
.2747 .61858 m .27731 .61555 L .27527 .61632 L F
.909 .729 .647 r
.56064 .52588 m .56369 .5244 L .56171 .52365 L F
.56064 .52588 m .5632 .52734 L .56369 .5244 L F
.81 .711 .756 r
.55077 .55252 m .55186 .55532 L .54874 .55448 L F
.965 .925 .705 r
.56265 .53858 m .56197 .54303 L .564 .53969 L F
.591 .874 .994 r
.22838 .72301 m .22415 .72298 L .22721 .72289 L F
.778 .551 .591 r
.22438 .72534 m .22838 .72301 L .22721 .72289 L F
.61 .95 .919 r
.22906 .7218 m .22838 .72301 L .22721 .72289 L F
.22906 .7218 m .22838 .72301 L .22721 .72289 L F
.718 .656 .787 r
.19463 .61218 m .19039 .61065 L .19286 .60983 L F
.663 .755 .918 r
.19588 .61063 m .19463 .61218 L .19286 .60983 L F
.097 0 0 r
.24883 .62638 m .25068 .62509 L .24854 .62556 L F
0 0 0 r
.28087 .59869 m .27992 .59984 L .2806 .59768 L F
.816 .882 .893 r
.82713 .435 m .82823 .4364 L .82996 .43479 L F
.609 .646 .862 r
.8243 .40948 m .82272 .41349 L .82161 .41042 L F
.8243 .40948 m .82559 .4128 L .82272 .41349 L F
.104 0 .216 r
.2817 .57337 m .28268 .5746 L .28371 .57258 L F
.2817 .57337 m .28084 .57574 L .28268 .5746 L F
.277 0 .246 r
.80791 .40242 m .80752 .40404 L .81025 .40145 L F
.636 .818 .97 r
.30856 .5388 m .30614 .53969 L .30452 .53837 L F
0 0 0 r
.23239 .53672 m .23225 .53668 L .23035 .53675 L F
.23239 .53672 m .2345 .53655 L .23225 .53668 L F
.556 .291 .469 r
.25666 .62406 m .25987 .62197 L .25735 .62293 L F
.6 .266 .376 r
.28363 .64033 m .28217 .643 L .27968 .64286 L F
.62 .289 .387 r
.28586 .6424 m .28363 .64033 L .28603 .64007 L F
.28586 .6424 m .28217 .643 L .28363 .64033 L F
.384 .021 .221 r
.16674 .56245 m .16977 .56053 L .16758 .56113 L F
.381 .186 .487 r
.27995 .61011 m .28203 .61168 L .28223 .60876 L F
.27995 .61011 m .2798 .61256 L .28203 .61168 L F
.988 .88 .541 r
.55844 .55053 m .55765 .55426 L .55831 .55507 L F
.99 .881 .616 r
.55765 .55426 m .55777 .55774 L .55831 .55507 L F
.148 .291 .754 r
.23049 .7278 m .22945 .72905 L .22829 .7258 L F
.587 .21 .295 r
.23084 .73077 m .22945 .72905 L .23049 .7278 L F
.23084 .73077 m .22779 .73162 L .22945 .72905 L F
.371 .26 .595 r
.14597 .58461 m .14469 .58891 L .14823 .58654 L F
.358 .272 .621 r
.14523 .59144 m .14823 .58654 L .14469 .58891 L F
0 0 0 r
.28653 .56706 m .28433 .57031 L .28517 .56934 L F
0 0 .262 r
.28371 .57258 m .28517 .56934 L .28433 .57031 L F
.071 .42 .867 r
.19527 .63167 m .19559 .63049 L .19439 .63055 L F
.19527 .63167 m .19874 .63405 L .19559 .63049 L F
.802 .736 .791 r
.79519 .41752 m .79182 .41701 L .79421 .41403 L F
.762 .714 .807 r
.79783 .41459 m .79519 .41752 L .79421 .41403 L F
.121 0 0 r
.19588 .54504 m .19598 .54633 L .19802 .54419 L F
.19588 .54504 m .19384 .54694 L .19598 .54633 L F
.597 .267 .381 r
.33597 .59267 m .33331 .59209 L .3363 .59102 L F
.33597 .59267 m .33291 .59388 L .33331 .59209 L F
.836 .789 .807 r
.25765 .66659 m .26065 .66533 L .25785 .66624 L F
.323 .475 .856 r
.26153 .66358 m .26065 .66533 L .25988 .66402 L F
.26153 .66358 m .25988 .66402 L .25855 .66175 L F
.58 .003 0 r
.25888 .66292 m .26153 .66358 L .25855 .66175 L F
.294 .767 .935 r
.26289 .66322 m .26153 .66358 L .25888 .66292 L F
.26372 .66328 m .26153 .66358 L .26289 .66322 L F
.75 .98 .914 r
.25785 .66624 m .26065 .66533 L .26153 .66358 L F
.25785 .66624 m .26153 .66358 L .26235 .66705 L F
.195 .468 .887 r
.25855 .66504 m .25785 .66624 L .26045 .66653 L F
.746 .694 .801 r
.25855 .66175 m .25577 .66637 L .25562 .6656 L F
.257 .66134 m .25562 .6656 L .25468 .66074 L F
.25855 .66175 m .25562 .6656 L .257 .66134 L F
0 0 .358 r
.25786 .6588 m .25834 .65501 L .2586 .6565 L F
.709 .761 .262 r
.25795 .65843 m .25786 .6588 L .2586 .6565 L F
.746 .694 .801 r
.25855 .66175 m .25468 .66074 L .25693 .66146 L F
.135 0 0 r
.25468 .66074 m .25786 .6588 L .25693 .66146 L F
.709 .761 .262 r
.25693 .66146 m .25739 .66014 L .25795 .65843 L F
.25739 .66014 m .25786 .6588 L .25795 .65843 L F
.195 .468 .887 r
.2566 .66349 m .25785 .66624 L .25855 .66504 L F
.836 .789 .807 r
.25636 .66713 m .25765 .66659 L .25785 .66624 L F
.46 .255 .513 r
.23861 .71076 m .23829 .71347 L .23606 .7142 L F
.595 .159 .183 r
.23829 .71347 m .2343 .71415 L .23606 .7142 L F
.278 .51 .898 r
.18501 .62477 m .18584 .62373 L .18271 .62171 L F
.18501 .62477 m .18665 .62488 L .18584 .62373 L F
0 0 .198 r
.1831 .60018 m .18351 .60339 L .18179 .59987 L F
.1831 .60018 m .18371 .60396 L .18351 .60339 L F
.728 .745 .231 r
.18302 .60466 m .18351 .60339 L .18371 .60396 L F
.18302 .60466 m .1827 .60622 L .18351 .60339 L F
.303 .348 .743 r
.29448 .59361 m .29539 .59705 L .29324 .59467 L F
.792 .79 .85 r
.83872 .39892 m .84 .39458 L .83818 .399 L F
.83872 .39892 m .84168 .39597 L .84 .39458 L F
.689 .148 0 r
.21588 .63992 m .21213 .63701 L .21502 .63971 L F
0 0 .179 r
.23924 .71222 m .23861 .71076 L .2391 .70945 L F
.23924 .71222 m .23829 .71347 L .23861 .71076 L F
.572 .613 .855 r
.14658 .59755 m .15112 .60077 L .14945 .5988 L F
.404 .656 .962 r
.14945 .5988 m .15112 .60077 L .15183 .59985 L F
.957 .63 .354 r
.15422 .60335 m .15183 .59985 L .15112 .60077 L F
.407 0 .124 r
.45317 .67434 m .45653 .67329 L .45556 .67469 L F
.094 .576 .905 r
.45166 .67334 m .45317 .67434 L .45556 .67469 L F
.917 .953 .801 r
.5595 .54389 m .55989 .54541 L .56197 .54303 L F
.965 .925 .705 r
.56265 .53858 m .5609 .54217 L .56197 .54303 L F
.915 .955 .803 r
.5609 .54217 m .5595 .54389 L .56197 .54303 L F
.542 .331 .543 r
.30047 .63122 m .30044 .63354 L .29818 .63388 L F
.465 .263 .52 r
.30324 .62799 m .30291 .63076 L .30047 .63122 L F
.516 .336 .575 r
.30291 .63076 m .30044 .63354 L .30047 .63122 L F
.657 .737 .908 r
.81299 .44144 m .81482 .43804 L .81188 .43886 L F
.81299 .44144 m .81529 .44055 L .81482 .43804 L F
.422 .746 .994 r
.21834 .63928 m .21989 .64043 L .22035 .63902 L F
.238 .545 .927 r
.22035 .63902 m .21989 .64043 L .22141 .64064 L F
.4 .476 .823 r
.19268 .63055 m .19289 .62702 L .19107 .62727 L F
.19268 .63055 m .19439 .63055 L .19289 .62702 L F
.512 .84 .999 r
.24207 .64273 m .2407 .64177 L .23821 .64235 L F
.289 .612 .956 r
.24207 .64273 m .24301 .64126 L .2407 .64177 L F
.24207 .64273 m .24479 .6426 L .24301 .64126 L F
.982 .742 .498 r
.27736 .55802 m .27563 .55635 L .2751 .55785 L F
.15 0 0 r
.20254 .56106 m .20041 .56239 L .19822 .56274 L F
0 0 0 r
.20248 .56156 m .20254 .56106 L .20441 .56017 L F
.20248 .56156 m .20041 .56239 L .20254 .56106 L F
.479 .099 .242 r
.27146 .64425 m .27321 .64552 L .27159 .64525 L F
.27146 .64425 m .27454 .64343 L .27321 .64552 L F
.853 .555 .484 r
.56444 .57296 m .56452 .57532 L .56819 .57617 L F
.839 .593 .567 r
.56441 .57792 m .56819 .57617 L .56452 .57532 L F
.56441 .57792 m .56834 .57858 L .56819 .57617 L F
.469 .294 .561 r
.31126 .54879 m .31356 .55068 L .31347 .54772 L F
.31126 .54879 m .31356 .55068 L .31347 .54772 L F
.158 0 0 r
.44963 .67132 m .44776 .67244 L .4503 .67167 L F
.507 .781 .994 r
.45081 .67019 m .44999 .67054 L .44963 .67132 L F
.73 .988 .887 r
.44963 .67132 m .4503 .66963 L .45081 .67019 L F
0 0 .454 r
.44963 .67132 m .4503 .67167 L .4503 .66963 L F
.762 .987 .756 r
.4503 .66963 m .44776 .67244 L .44963 .67132 L F
.698 .637 .785 r
.44776 .67244 m .4503 .66963 L .44963 .67132 L F
.984 .749 .501 r
.50214 .58385 m .50393 .58245 L .50215 .58132 L F
.50214 .58385 m .5036 .58492 L .50393 .58245 L F
.725 .632 .754 r
.81032 .41636 m .81132 .42031 L .80903 .42111 L F
.752 .648 .746 r
.81389 .41685 m .81132 .42031 L .81032 .41636 L F
.163 .67 .905 r
.14464 .63128 m .14281 .63068 L .14151 .63064 L F
.14151 .63064 m .14281 .63068 L .14464 .63128 L F
.498 .854 .991 r
.14495 .63005 m .14464 .63128 L .14681 .63077 L F
.14495 .63005 m .14281 .63068 L .14464 .63128 L F
.14464 .63128 m .14495 .63005 L .14681 .63077 L F
.14464 .63128 m .14281 .63068 L .14495 .63005 L F
.163 .67 .905 r
.14464 .63128 m .14281 .63068 L .14151 .63064 L F
.448 .125 .324 r
.52966 .56448 m .53149 .56453 L .52847 .5656 L F
.478 .553 .855 r
.28408 .55818 m .28531 .56092 L .28632 .56004 L F
.155 .026 .441 r
.28531 .56092 m .28522 .56337 L .28632 .56004 L F
.725 .632 .754 r
.81032 .41636 m .80903 .42111 L .80814 .41762 L F
.507 .176 .341 r
.29492 .63726 m .29233 .63918 L .29241 .63731 L F
.637 .459 .625 r
.80933 .41111 m .81019 .41462 L .80659 .41371 L F
.591 .465 .677 r
.81224 .41001 m .81019 .41462 L .80933 .41111 L F
.029 0 .47 r
.53902 .58911 m .54072 .58705 L .5404 .58417 L F
.428 .572 .895 r
.53902 .58911 m .54267 .59018 L .54072 .58705 L F
.941 .576 .265 r
.79411 .40335 m .79561 .40448 L .79497 .40207 L F
.734 .484 .55 r
.23707 .69152 m .24045 .69286 L .23739 .69121 L F
.56 .585 .835 r
.24045 .69286 m .24112 .68855 L .23739 .69121 L F
.498 .685 .95 r
.32742 .54321 m .32657 .54555 L .32484 .54303 L F
.32742 .54321 m .32847 .54493 L .32657 .54555 L F
.582 .631 .865 r
.33003 .54706 m .32657 .54555 L .32847 .54493 L F
.99 .755 .482 r
.46324 .64689 m .4626 .64879 L .46201 .64656 L F
.397 .131 .389 r
.19847 .54263 m .20008 .54348 L .20087 .54231 L F
.19847 .54263 m .19802 .54419 L .20008 .54348 L F
.464 .377 .673 r
.54194 .59718 m .54386 .59592 L .54342 .59412 L F
.465 0 .013 r
.25449 .62436 m .25068 .62509 L .25258 .62613 L F
.556 .151 .229 r
.25258 .62613 m .25666 .62406 L .25449 .62436 L F
.643 .821 .969 r
.25169 .66889 m .25215 .66672 L .24995 .66707 L F
.25169 .66889 m .25393 .66798 L .25215 .66672 L F
.313 .596 .946 r
.16884 .61352 m .16961 .61203 L .16806 .61187 L F
.16884 .61352 m .17297 .61487 L .16961 .61203 L F
.595 .582 .809 r
.16884 .61352 m .17272 .61625 L .17297 .61487 L F
.413 .239 .533 r
.33033 .59426 m .32806 .59755 L .32757 .59505 L F
.548 .326 .53 r
.33703 .58196 m .3342 .58468 L .33453 .58246 L F
.657 .633 .814 r
.45801 .67045 m .45932 .67372 L .45653 .67329 L F
.371 0 0 r
.45653 .67329 m .4582 .67397 L .45556 .67469 L F
.45653 .67329 m .45932 .67372 L .4582 .67397 L F
.606 .784 .966 r
.80081 .43237 m .80178 .43429 L .80423 .43299 L F
.558 .317 .507 r
.31871 .61553 m .31581 .61831 L .31636 .61623 L F
.707 .731 .869 r
.81289 .41398 m .81389 .41685 L .81032 .41636 L F
.684 .746 .898 r
.81568 .41305 m .81389 .41685 L .81289 .41398 L F
.81568 .41305 m .81562 .416 L .81389 .41685 L F
.377 .581 .921 r
.16659 .61223 m .16576 .60902 L .16373 .60918 L F
.16659 .61223 m .16806 .61187 L .16576 .60902 L F
.807 .378 .225 r
.50406 .55798 m .50272 .55942 L .50077 .55676 L F
.828 .409 .243 r
.50427 .55953 m .50272 .55942 L .50406 .55798 L F
.685 .676 .835 r
.83508 .3981 m .83818 .399 L .83657 .39412 L F
.704 .687 .831 r
.83657 .39412 m .83818 .399 L .84 .39458 L F
.687 .793 .93 r
.20395 .61325 m .20044 .61289 L .20274 .61222 L F
.045 .335 .815 r
.20434 .61207 m .20395 .61325 L .20274 .61222 L F
.20434 .61207 m .20655 .61513 L .20395 .61325 L F
.444 0 0 r
.28131 .55801 m .27949 .55894 L .27736 .55802 L F
.695 .522 .65 r
.81032 .41636 m .80659 .41371 L .81019 .41462 L F
.81032 .41636 m .80814 .41762 L .80659 .41371 L F
.523 .369 .614 r
.49269 .57172 m .49457 .57236 L .49263 .57274 L F
.49263 .57274 m .49457 .57236 L .49269 .57172 L F
.235 .744 .88 r
.2345 .53655 m .23676 .53629 L .23846 .53651 L F
.39 .819 .963 r
.23676 .53629 m .24078 .5363 L .23846 .53651 L F
.822 .984 .705 r
.24491 .55174 m .2424 .55505 L .24286 .55322 L F
.986 .734 .461 r
.24375 .55552 m .24286 .55322 L .2424 .55505 L F
.24427 .5557 m .24411 .55543 L .24375 .55552 L F
.24411 .55543 m .24286 .55322 L .24375 .55552 L F
.24427 .5557 m .24279 .55577 L .24286 .55322 L F
0 0 0 r
.24753 .55457 m .24279 .55577 L .24427 .5557 L F
.24508 .55519 m .24504 .5552 L .24279 .55577 L F
.24753 .55457 m .24575 .55502 L .24508 .55519 L F
.24575 .55502 m .24504 .5552 L .24508 .55519 L F
.478 .134 .304 r
.27547 .59385 m .27789 .59369 L .27877 .59094 L F
.226 0 .269 r
.27877 .59094 m .28087 .59077 L .28126 .58812 L F
.178 0 .184 r
.27877 .59094 m .2798 .5927 L .28087 .59077 L F
.27877 .59094 m .27789 .59369 L .2798 .5927 L F
.798 .64 .686 r
.56996 .58487 m .5709 .58811 L .57272 .58498 L F
.521 .262 .462 r
.30044 .63354 m .29738 .63675 L .29818 .63388 L F
.874 .647 .591 r
.47317 .63937 m .47246 .64267 L .4751 .63976 L F
.411 .796 .99 r
.1945 .67324 m .19526 .67401 L .19128 .67357 L F
.716 .304 .266 r
.19337 .67596 m .19526 .67401 L .19128 .67357 L F
.982 .91 .615 r
.1945 .67324 m .19526 .67401 L .19337 .67596 L F
.534 .329 .548 r
.21106 .75001 m .21356 .74929 L .21128 .74735 L F
.057 0 0 r
.53761 .52432 m .53356 .52537 L .53512 .52471 L F
.539 .632 .891 r
.23391 .70701 m .23553 .70488 L .23418 .70352 L F
.23391 .70701 m .2368 .70723 L .23553 .70488 L F
.732 .809 .912 r
.83298 .41455 m .82938 .41419 L .83142 .41298 L F
.821 .817 .845 r
.83421 .41015 m .83298 .41455 L .83142 .41298 L F
.83421 .41015 m .8354 .4121 L .83298 .41455 L F
.539 .577 .842 r
.33102 .54483 m .33003 .54706 L .32847 .54493 L F
.33102 .54483 m .3326 .54678 L .33003 .54706 L F
.458 .728 .984 r
.78684 .41819 m .78849 .41952 L .78665 .41907 L F
.745 .82 .91 r
.79182 .41701 m .78849 .41952 L .78684 .41819 L F
.099 0 .213 r
.28126 .58812 m .28312 .58754 L .28363 .58484 L F
0 0 .196 r
.28126 .58812 m .28223 .5896 L .28312 .58754 L F
.28126 .58812 m .28087 .59077 L .28223 .5896 L F
.264 .199 .594 r
.77445 .41261 m .77277 .41732 L .77161 .41389 L F
.77445 .41261 m .77523 .41554 L .77277 .41732 L F
.479 .605 .9 r
.77523 .41554 m .77533 .41716 L .77277 .41732 L F
.769 .359 .275 r
.22291 .73102 m .22006 .72923 L .22213 .73212 L F
.281 .245 .639 r
.22213 .73212 m .22235 .73381 L .2236 .73502 L F
.592 .847 .993 r
.19337 .82956 m .19127 .83036 L .18948 .82932 L F
.19337 .82956 m .19127 .83036 L .18948 .82932 L F
.818 .878 .443 r
.32278 .56314 m .32149 .56703 L .32295 .56381 L F
.32278 .56314 m .32158 .56581 L .32149 .56703 L F
.431 .319 .625 r
.32149 .56703 m .32176 .56716 L .32295 .56381 L F
.32176 .56716 m .32325 .56784 L .32321 .56726 L F
.32176 .56716 m .32321 .56726 L .32295 .56381 L F
.728 .543 .64 r
.32295 .56381 m .32325 .56784 L .32722 .56547 L F
.369 0 .083 r
.32287 .56771 m .32722 .56547 L .32325 .56784 L F
.32287 .56771 m .32577 .56769 L .32593 .56744 L F
.32369 .56729 m .32593 .56744 L .32722 .56547 L F
.32287 .56771 m .32593 .56744 L .32369 .56729 L F
.34 0 0 r
.32287 .56771 m .32325 .56784 L .32323 .56783 L F
.32287 .56771 m .32323 .56783 L .32149 .56703 L F
.97 .674 .409 r
.32158 .56581 m .32287 .56771 L .32149 .56703 L F
.32158 .56581 m .32178 .56732 L .32287 .56771 L F
.32178 .56732 m .32193 .56852 L .32287 .56771 L F
.492 .53 .824 r
.78413 .41587 m .78239 .41838 L .7818 .41698 L F
.78413 .41587 m .78501 .4186 L .78239 .41838 L F
.767 .362 0 r
.4981 .58223 m .49839 .58337 L .49818 .58113 L F
.4981 .58223 m .49947 .58534 L .49839 .58337 L F
.572 .329 .51 r
.32566 .60063 m .32525 .60309 L .32289 .60335 L F
.563 .39 .605 r
.32806 .59755 m .32812 .6003 L .32566 .60063 L F
.361 .144 .444 r
.32726 .60214 m .32566 .60063 L .32812 .6003 L F
.32726 .60214 m .32525 .60309 L .32566 .60063 L F
.533 0 0 r
.51892 .56931 m .51795 .56889 L .51549 .56694 L F
.998 .823 .481 r
.51823 .56624 m .51892 .56931 L .52161 .56685 L F
.51823 .56624 m .51795 .56889 L .51892 .56931 L F
0 .355 .778 r
.22598 .64144 m .22658 .64123 L .2249 .64101 L F
.22598 .64144 m .22808 .64235 L .22658 .64123 L F
0 0 0 r
.53111 .5209 m .53229 .52075 L .53337 .52044 L F
.53111 .5209 m .52953 .522 L .53229 .52075 L F
.438 .076 .252 r
.4991 .55446 m .50173 .55428 L .50283 .55173 L F
.762 .415 .397 r
.50283 .55173 m .50173 .55428 L .50317 .55384 L F
.756 .41 .399 r
.50283 .55173 m .50317 .55384 L .50683 .55421 L F
.565 .354 .553 r
.27225 .61896 m .2696 .62192 L .27216 .6215 L F
.27225 .61896 m .2696 .62192 L .27216 .6215 L F
.47 .276 .535 r
.27225 .61896 m .27336 .62001 L .2747 .61858 L F
.27336 .62001 m .27434 .62093 L .2747 .61861 L F
.27336 .62001 m .2747 .61861 L .2747 .61858 L F
.27225 .61896 m .27216 .6215 L .27434 .62093 L F
.884 .949 .847 r
.27333 .61782 m .27216 .6215 L .27225 .61896 L F
.27333 .61782 m .27054 .62096 L .27199 .62144 L F
.27227 .62114 m .27199 .62144 L .27216 .6215 L F
.27333 .61782 m .27199 .62144 L .27227 .62114 L F
.822 .984 .705 r
.24491 .55174 m .24286 .55322 L .24318 .55052 L F
.145 .168 .626 r
.28363 .58484 m .28523 .58406 L .28453 .58139 L F
.119 0 .22 r
.28363 .58484 m .28475 .58655 L .28523 .58406 L F
.28363 .58484 m .28312 .58754 L .28475 .58655 L F
.776 .423 .386 r
.55263 .51729 m .55482 .52001 L .55634 .51794 L F
.796 .449 .4 r
.55482 .52001 m .55856 .52076 L .55634 .51794 L F
.396 .241 .551 r
.22999 .71331 m .22948 .71657 L .23091 .71481 L F
.476 .258 .503 r
.46807 .65497 m .46814 .65834 L .4704 .65463 L F
.358 .813 .937 r
.20087 .54231 m .20297 .54185 L .20455 .54214 L F
0 0 0 r
.20297 .54185 m .20662 .54107 L .20455 .54214 L F
0 0 .032 r
.20632 .55714 m .20441 .56017 L .20582 .55829 L F
0 .014 .585 r
.28522 .56337 m .28653 .56706 L .28673 .56538 L F
0 0 0 r
.28653 .56706 m .28624 .56794 L .28673 .56538 L F
.28653 .56706 m .28517 .56934 L .28624 .56794 L F
.242 .328 .753 r
.49471 .60389 m .49712 .60551 L .49546 .60626 L F
0 0 .05 r
.49712 .60551 m .49464 .60859 L .49546 .60626 L F
.134 0 .294 r
.28286 .60665 m .28425 .60602 L .28493 .60345 L F
0 0 .105 r
.28223 .60876 m .28425 .60602 L .28286 .60665 L F
.701 .761 .898 r
.54722 .59713 m .55118 .59777 L .54953 .59612 L F
.729 .767 .883 r
.54953 .59612 m .55118 .59777 L .55292 .59623 L F
.294 0 0 r
.31334 .57284 m .30818 .57399 L .30898 .57318 L F
.31334 .57284 m .3108 .57412 L .30818 .57399 L F
.459 .341 .631 r
.31334 .57284 m .31538 .57221 L .31511 .56967 L F
.245 .097 .473 r
.31334 .57284 m .31484 .57477 L .31538 .57221 L F
.3137 .5733 m .3133 .57562 L .31484 .57477 L F
.31334 .57284 m .31333 .57357 L .3137 .5733 L F
.31333 .57357 m .3133 .57562 L .3137 .5733 L F
0 0 0 r
.3131 .5731 m .31334 .57284 L .31538 .57221 L F
.459 .341 .631 r
.31334 .57284 m .31538 .57221 L .31511 .56967 L F
.472 .35 .633 r
.31511 .56967 m .31748 .57162 L .31538 .57221 L F
.31538 .57221 m .31748 .57162 L .31511 .56967 L F
.537 .918 .78 r
.3159 .57133 m .3131 .5731 L .31496 .57238 L F
.31553 .57196 m .31496 .57238 L .31538 .57221 L F
.3159 .57133 m .31496 .57238 L .31553 .57196 L F
.344 .442 .817 r
.17297 .61487 m .17272 .61625 L .17424 .61429 L F
.395 .515 .861 r
.17272 .61625 m .17594 .61749 L .17424 .61429 L F
.605 .421 .606 r
.17126 .57927 m .17137 .582 L .16879 .58231 L F
.123 .054 .499 r
.17276 .58062 m .17126 .57927 L .17284 .57847 L F
.17276 .58062 m .17137 .582 L .17126 .57927 L F
.716 .801 .918 r
.83791 .41092 m .84118 .40958 L .84139 .4113 L F
.658 .76 .925 r
.84139 .4113 m .84118 .40958 L .84285 .40833 L F
.597 .354 .519 r
.30777 .57897 m .31019 .57886 L .31083 .57634 L F
.57 .377 .581 r
.31019 .57886 m .3133 .57562 L .31083 .57634 L F
0 0 0 r
.24078 .5363 m .24299 .53588 L .24478 .53542 L F
.165 0 0 r
.24478 .53542 m .24299 .53588 L .24686 .53542 L F
.6 .65 .871 r
.3023 .58574 m .30376 .58869 L .30591 .58772 L F
.411 .331 .656 r
.30376 .58869 m .30603 .59047 L .30591 .58772 L F
.30376 .58869 m .30416 .59125 L .30603 .59047 L F
.826 .743 .773 r
.83651 .42248 m .83907 .42365 L .84072 .4205 L F
.875 .668 .619 r
.83651 .42248 m .83831 .42593 L .83907 .42365 L F
.758 .833 .909 r
.82015 .4371 m .82153 .43845 L .82414 .43654 L F
.816 .882 .893 r
.82713 .435 m .82996 .43479 L .8297 .43222 L F
.74 .819 .914 r
.82996 .43479 m .83214 .43102 L .8297 .43222 L F
.82996 .43479 m .83343 .43262 L .83214 .43102 L F
.48 .646 .93 r
.80915 .43891 m .81188 .43886 L .81092 .43691 L F
.671 .158 .011 r
.50817 .56028 m .50716 .56152 L .50427 .55953 L F
.441 .569 .887 r
.51063 .56351 m .50983 .56252 L .50841 .56321 L F
.577 .119 0 r
.50817 .56028 m .51063 .56351 L .50967 .56231 L F
.834 .945 .585 r
.50963 .56226 m .50841 .56321 L .50967 .56231 L F
.577 .119 0 r
.50817 .56028 m .50963 .56226 L .50716 .56152 L F
.834 .945 .585 r
.50922 .56174 m .5089 .56232 L .50963 .56226 L F
.495 0 0 r
.50841 .56321 m .50503 .5621 L .509 .56233 L F
.834 .945 .585 r
.50902 .56231 m .50841 .56321 L .50963 .56226 L F
.495 0 0 r
.50841 .56321 m .509 .56233 L .50971 .56237 L F
.834 .945 .585 r
.5089 .56232 m .50841 .56321 L .50902 .56231 L F
.577 .119 0 r
.50963 .56226 m .50964 .56228 L .5096 .56226 L F
.50963 .56226 m .5096 .56226 L .50716 .56152 L F
.50963 .56226 m .50967 .56231 L .50964 .56228 L F
.50817 .56028 m .50967 .56231 L .50963 .56226 L F
.834 .945 .585 r
.50985 .56059 m .50922 .56174 L .5112 .56121 L F
.50922 .56174 m .50967 .56231 L .5112 .56121 L F
.441 .569 .887 r
.51102 .56194 m .50976 .56225 L .50841 .56321 L F
.577 .119 0 r
.50964 .56228 m .51063 .56351 L .50971 .56237 L F
.441 .569 .887 r
.51063 .56351 m .51102 .56194 L .50983 .56252 L F
.51102 .56194 m .5112 .56121 L .50976 .56225 L F
.577 .119 0 r
.50964 .56228 m .50971 .56237 L .50952 .56231 L F
.50964 .56228 m .50952 .56231 L .50716 .56152 L F
.02 0 0 r
.28045 .53291 m .28495 .53239 L .2822 .53326 L F
.334 .204 .55 r
.14597 .58461 m .1465 .58458 L .14653 .58223 L F
.275 .059 .394 r
.14653 .58223 m .14816 .58172 L .14872 .57908 L F
.478 .376 .66 r
.1465 .58458 m .14816 .58172 L .14653 .58223 L F
.627 .717 .911 r
.46007 .67102 m .45932 .67372 L .45801 .67045 L F
.46006 .67105 m .46134 .67252 L .45932 .67372 L F
0 0 0 r
.45932 .67372 m .46134 .67252 L .46056 .67329 L F
.515 .355 .603 r
.45894 .67149 m .4582 .67397 L .46056 .67329 L F
.45801 .67045 m .45808 .67183 L .45894 .67149 L F
.45808 .67183 m .4582 .67397 L .45894 .67149 L F
.627 .717 .911 r
.46007 .67102 m .46008 .67104 L .46006 .67105 L F
.46008 .67104 m .46134 .67252 L .46006 .67105 L F
0 0 0 r
.45932 .67372 m .46056 .67329 L .4582 .67397 L F
.458 .728 .984 r
.78684 .41819 m .78665 .41907 L .78501 .4186 L F
.882 .844 .802 r
.84072 .4205 m .84291 .41736 L .84158 .41599 L F
.525 .283 .491 r
.30567 .62768 m .30291 .63076 L .30324 .62799 L F
.817 .881 .892 r
.29904 .58467 m .29631 .58733 L .29811 .58669 L F
0 .07 .629 r
.18453 .60854 m .18432 .61028 L .1827 .60622 L F
.267 .56 .932 r
.18453 .60854 m .18654 .61076 L .18432 .61028 L F
.469 .116 .284 r
.27454 .64343 m .27563 .64523 L .27321 .64552 L F
.27454 .64343 m .27721 .64292 L .27563 .64523 L F
.608 .442 .632 r
.46135 .62504 m .46389 .62495 L .46368 .62176 L F
.775 .57 .621 r
.46368 .62176 m .46498 .62419 L .46722 .6218 L F
.46368 .62176 m .46389 .62495 L .46498 .62419 L F
.587 .377 .562 r
.46061 .66775 m .45801 .67045 L .45806 .66784 L F
.46061 .66775 m .45801 .67045 L .45806 .66784 L F
.541 .742 .969 r
.25016 .68264 m .24894 .68376 L .24839 .68147 L F
.973 .927 .641 r
.24839 .68147 m .24894 .68376 L .24675 .6842 L F
0 0 0 r
.24785 .6859 m .24894 .68376 L .25016 .68264 L F
.55 .812 .445 r
.19045 .79176 m .18933 .79314 L .18958 .79236 L F
0 0 0 r
.19009 .7922 m .19045 .79176 L .18958 .79236 L F
.55 .812 .445 r
.19045 .79176 m .19052 .79167 L .18933 .79314 L F
.568 .387 .597 r
.19182 .79006 m .19189 .79298 L .18933 .79314 L F
0 0 0 r
.19195 .79161 m .19045 .79176 L .19009 .7922 L F
.55 .812 .445 r
.19045 .79176 m .19182 .79006 L .19052 .79167 L F
.282 .757 .934 r
.18933 .79314 m .19189 .79298 L .18958 .79236 L F
.838 .924 .889 r
.2489 .55112 m .24882 .55487 L .25142 .55266 L F
.915 .963 .797 r
.2489 .55112 m .24753 .55457 L .24882 .55487 L F
0 0 0 r
.26538 .64871 m .26887 .64662 L .26684 .64811 L F
.582 .387 .583 r
.45877 .62803 m .46145 .62767 L .46135 .62504 L F
.491 .255 .483 r
.46145 .62767 m .46389 .62495 L .46135 .62504 L F
.393 .391 .738 r
.14658 .59755 m .14741 .59344 L .14585 .59406 L F
.14658 .59755 m .14838 .59714 L .14741 .59344 L F
.405 .453 .797 r
.14658 .59755 m .14945 .5988 L .14838 .59714 L F
.348 .735 .985 r
.22621 .62416 m .22584 .6253 L .22409 .62418 L F
.22621 .62416 m .22798 .62517 L .22584 .6253 L F
.358 .272 .621 r
.14523 .59144 m .14677 .59094 L .14823 .58654 L F
.375 .322 .67 r
.14523 .59144 m .14741 .59344 L .14677 .59094 L F
.362 .321 .677 r
.14585 .59406 m .14741 .59344 L .14523 .59144 L F
.662 .794 .945 r
.79538 .43482 m .79709 .43172 L .79403 .43207 L F
.79538 .43482 m .79755 .43387 L .79709 .43172 L F
.413 .239 .533 r
.33033 .59426 m .33013 .59689 L .32806 .59755 L F
.424 .282 .582 r
.33021 .59948 m .32806 .59755 L .33013 .59689 L F
.33021 .59948 m .32812 .6003 L .32806 .59755 L F
.619 .625 .835 r
.82795 .41217 m .82631 .41507 L .82559 .4128 L F
.82795 .41217 m .82938 .41419 L .82631 .41507 L F
.645 .625 .815 r
.32657 .56236 m .3303 .56398 L .32869 .56027 L F
.608 .307 .434 r
.32722 .56547 m .3303 .56398 L .32657 .56236 L F
.32722 .56547 m .32981 .56592 L .3303 .56398 L F
.541 .568 .831 r
.32869 .56027 m .3303 .56398 L .33242 .56325 L F
.525 .302 .517 r
.32981 .56592 m .33242 .56325 L .3303 .56398 L F
.446 .619 .924 r
.176 .59592 m .17744 .59787 L .17522 .59796 L F
0 0 .049 r
.19195 .79161 m .19189 .79298 L .19182 .79006 L F
.19195 .79161 m .19182 .79006 L .19045 .79176 L F
.595 .904 .634 r
.18491 .56976 m .18285 .57131 L .18182 .57263 L F
0 0 0 r
.18285 .57131 m .18066 .57465 L .18182 .57263 L F
.17793 .55388 m .17941 .55357 L .18124 .55222 L F
.258 0 0 r
.17941 .55357 m .18343 .55158 L .18124 .55222 L F
0 .225 .745 r
.49936 .55543 m .50077 .55676 L .4991 .55446 L F
.615 .57 .781 r
.46568 .66121 m .46814 .65834 L .46568 .65858 L F
.789 .787 .85 r
.32624 .5612 m .32295 .56381 L .32657 .56236 L F
.728 .543 .64 r
.32295 .56381 m .32722 .56547 L .32657 .56236 L F
.645 .625 .815 r
.32657 .56236 m .32869 .56027 L .32624 .5612 L F
.838 .924 .889 r
.2489 .55112 m .25142 .55266 L .24901 .55076 L F
.637 .085 0 r
.25343 .55271 m .24901 .55076 L .25142 .55266 L F
.499 .679 .946 r
.15806 .60641 m .15835 .60403 L .1558 .60509 L F
.15806 .60641 m .16012 .60603 L .15835 .60403 L F
.891 .5 .279 r
.50338 .58732 m .50648 .5907 L .50564 .58797 L F
.667 .759 .919 r
.83791 .41092 m .8354 .4121 L .83421 .41015 L F
0 0 0 r
.83641 .39256 m .84027 .39216 L .83744 .39243 L F
.982 .876 .653 r
.76813 .41249 m .76859 .41465 L .76781 .41301 L F
.702 .746 .886 r
.76813 .41249 m .77161 .41389 L .76859 .41465 L F
.826 .743 .773 r
.83651 .42248 m .84072 .4205 L .83903 .41914 L F
.882 .844 .802 r
.84072 .4205 m .84158 .41599 L .83903 .41914 L F
.08 0 0 r
.27105 .55309 m .27048 .55226 L .27275 .55163 L F
.27105 .55309 m .2694 .55385 L .27048 .55226 L F
.798 .736 .795 r
.25016 .68264 m .25186 .68602 L .24785 .6859 L F
.806 .698 .745 r
.25186 .68602 m .2491 .68901 L .24785 .6859 L F
.648 .448 .599 r
.25186 .68602 m .25195 .68919 L .2491 .68901 L F
.502 .474 .758 r
.25269 .68339 m .25186 .68602 L .25016 .68264 L F
.25269 .68339 m .25397 .68557 L .25186 .68602 L F
.412 .265 .57 r
.25382 .68838 m .25186 .68602 L .25397 .68557 L F
.25382 .68838 m .25195 .68919 L .25186 .68602 L F
.371 .26 .595 r
.14597 .58461 m .14823 .58654 L .1465 .58458 L F
.56 .585 .835 r
.24045 .69286 m .24292 .69276 L .24112 .68855 L F
.842 .554 .501 r
.51815 .5637 m .51823 .56624 L .52161 .56685 L F
.611 .446 .634 r
.17137 .582 m .16886 .58497 L .16879 .58231 L F
.914 .751 .665 r
.56341 .52942 m .56465 .5332 L .56538 .53051 L F
.857 .808 .801 r
.55276 .54845 m .54967 .5483 L .5521 .54533 L F
.553 .017 0 r
.55278 .5509 m .54967 .5483 L .55276 .54845 L F
.052 0 0 r
.29824 .53877 m .30042 .53864 L .30269 .53819 L F
.206 0 0 r
.30269 .53819 m .30042 .53864 L .30452 .53837 L F
.495 .512 .804 r
.33461 .58651 m .33171 .58521 L .3342 .58468 L F
.84 .494 .401 r
.48789 .63125 m .48942 .63198 L .48898 .63234 L F
.805 .897 .908 r
.82885 .40074 m .83283 .39946 L .83164 .39796 L F
.746 .674 .781 r
.83283 .39946 m .83136 .3951 L .83164 .39796 L F
.83283 .39946 m .83432 .39487 L .83136 .3951 L F
.83283 .39946 m .83508 .3981 L .83432 .39487 L F
.034 0 0 r
.2095 .5399 m .21113 .53978 L .21328 .53858 L F
.551 .344 .553 r
.21328 .53858 m .21563 .53892 L .21616 .53571 L F
0 0 0 r
.21328 .53858 m .21405 .53878 L .21563 .53892 L F
.21328 .53858 m .21113 .53978 L .21405 .53878 L F
.26904 .60631 m .26739 .60985 L .26835 .60845 L F
0 0 .183 r
.26739 .60985 m .26811 .61115 L .26835 .60845 L F
.26739 .60985 m .26688 .61238 L .26811 .61115 L F
.556 .265 .429 r
.46988 .62149 m .47252 .62157 L .47314 .61923 L F
.296 .03 .33 r
.47314 .61923 m .47455 .6202 L .47529 .61844 L F
.47314 .61923 m .47252 .62157 L .47455 .6202 L F
.756 .796 .885 r
.56145 .5911 m .55849 .59091 L .5622 .59129 L F
.775 .784 .861 r
.56145 .5911 m .5622 .59129 L .56467 .58839 L F
.936 .613 .402 r
.56152 .52824 m .5632 .52734 L .56064 .52588 L F
.56152 .52824 m .56341 .52942 L .5632 .52734 L F
0 0 .105 r
.28223 .60876 m .28361 .60817 L .28425 .60602 L F
.081 0 .31 r
.28223 .60876 m .28341 .61108 L .28361 .60817 L F
.28223 .60876 m .28203 .61168 L .28341 .61108 L F
.98 .738 .496 r
.2696 .62192 m .26785 .62357 L .26946 .62454 L F
.509 .829 .523 r
.27054 .62096 m .2696 .62192 L .27216 .6215 L F
.27054 .62096 m .26785 .62357 L .2696 .62192 L F
.554 .344 .55 r
.26946 .62454 m .27216 .6215 L .2696 .62192 L F
.409 .464 .806 r
.16195 .60924 m .16232 .6055 L .16012 .60603 L F
.16195 .60924 m .16373 .60918 L .16232 .6055 L F
.68 .814 .947 r
.20597 .75893 m .20996 .75922 L .20787 .76013 L F
.20597 .75893 m .20996 .75922 L .20787 .76013 L F
.685 .676 .835 r
.83508 .3981 m .83657 .39412 L .83432 .39487 L F
.831 .652 .66 r
.56834 .57858 m .56951 .58204 L .56989 .57942 L F
.788 .637 .694 r
.79623 .41065 m .79783 .41459 L .79421 .41403 L F
.446 .242 .508 r
.51549 .56694 m .51344 .56374 L .51537 .56501 L F
.51549 .56694 m .51823 .56624 L .51815 .5637 L F
.473 .317 .587 r
.51549 .56694 m .51795 .56889 L .51823 .56624 L F
.232 0 .256 r
.16445 .56324 m .16539 .56523 L .16674 .56245 L F
.16445 .56324 m .16361 .56641 L .16539 .56523 L F
.234 .751 .837 r
.24686 .53542 m .24914 .53504 L .25078 .53505 L F
.455 .828 .992 r
.24914 .53504 m .25326 .53524 L .25078 .53505 L F
.544 .46 .71 r
.24463 .70032 m .24232 .70338 L .24219 .70049 L F
.34 .235 .586 r
.2446 .70391 m .24232 .70338 L .24463 .70032 L F
.2446 .70391 m .24244 .70432 L .24232 .70338 L F
.553 .932 .838 r
.81922 .40278 m .81731 .4044 L .82009 .40333 L F
.81922 .40278 m .81709 .40409 L .81731 .4044 L F
.957 .63 .354 r
.15422 .60335 m .1537 .60321 L .15183 .59985 L F
.704 .166 0 r
.1558 .60509 m .1537 .60321 L .15422 .60335 L F
.959 .853 .438 r
.51287 .56324 m .51423 .56014 L .51249 .5605 L F
.51287 .56324 m .51344 .56374 L .51423 .56014 L F
.755 .55 .618 r
.51423 .56014 m .51344 .56374 L .51815 .5637 L F
.914 .751 .665 r
.56341 .52942 m .56217 .53239 L .56465 .5332 L F
.957 .822 .669 r
.56194 .53527 m .56465 .5332 L .56217 .53239 L F
.56194 .53527 m .56347 .53623 L .56465 .5332 L F
.624 .502 .693 r
.52847 .5656 m .53149 .56453 L .52881 .56467 L F
.868 .709 .682 r
.54952 .56852 m .54673 .56904 L .54703 .56655 L F
.873 .785 .761 r
.54952 .56852 m .54751 .57205 L .54673 .56904 L F
.221 0 .248 r
.18681 .56892 m .18491 .56976 L .18754 .56695 L F
.168 0 0 r
.18681 .56892 m .18285 .57131 L .18491 .56976 L F
.274 .121 .484 r
.28493 .60345 m .28654 .60278 L .28666 .60021 L F
.336 .09 .385 r
.28493 .60345 m .28623 .60529 L .28654 .60278 L F
.28493 .60345 m .28425 .60602 L .28623 .60529 L F
.923 .631 .472 r
.55632 .55936 m .55777 .55774 L .55676 .55663 L F
.55632 .55936 m .55791 .56016 L .55777 .55774 L F
.99 .881 .616 r
.55765 .55426 m .55676 .55663 L .55777 .55774 L F
.533 .804 .996 r
.21235 .61845 m .21195 .61998 L .21024 .61846 L F
.21235 .61845 m .21426 .61956 L .21195 .61998 L F
.34 .707 .984 r
.23298 .54898 m .23513 .55021 L .23692 .55003 L F
.674 .874 .974 r
.19039 .61065 m .18654 .61076 L .18877 .60893 L F
.561 .762 .972 r
.19286 .60983 m .19039 .61065 L .18877 .60893 L F
.283 .094 .438 r
.14816 .58172 m .15033 .57817 L .14872 .57908 L F
.131 .678 .803 r
.27175 .53428 m .27392 .53409 L .27598 .53421 L F
.106 0 0 r
.27392 .53409 m .27832 .53356 L .27598 .53421 L F
.611 .407 .58 r
.47943 .61868 m .47939 .62167 L .47642 .62172 L F
.474 .664 .945 r
.47943 .61868 m .48117 .61803 L .47904 .61754 L F
.109 0 .366 r
.48117 .61803 m .47939 .62167 L .47943 .61868 L F
0 .105 .647 r
.29036 .53306 m .2926 .53523 L .29258 .53608 L F
0 .358 .809 r
.2926 .53523 m .29461 .53707 L .29258 .53608 L F
.334 .036 .302 r
.18904 .56809 m .18754 .56695 L .18959 .56618 L F
.18904 .56809 m .18681 .56892 L .18754 .56695 L F
.977 .68 .314 r
.84168 .39597 m .84027 .39216 L .84 .39458 L F
.638 .748 .928 r
.33856 .59005 m .33929 .59131 L .3363 .59102 L F
.499 .123 .257 r
.33929 .59131 m .33597 .59267 L .3363 .59102 L F
.33929 .59131 m .33861 .59296 L .33597 .59267 L F
.52 .685 .942 r
.34044 .58928 m .33929 .59131 L .33856 .59005 L F
.355 0 .194 r
.34095 .5924 m .33929 .59131 L .34044 .58928 L F
.34095 .5924 m .33861 .59296 L .33929 .59131 L F
.354 0 0 r
.22227 .55128 m .22011 .55298 L .21751 .55323 L F
.339 0 0 r
.22298 .55253 m .22011 .55298 L .22227 .55128 L F
.419 .746 .994 r
.2217 .62297 m .21803 .62203 L .22023 .6217 L F
0 .365 .813 r
.22254 .62269 m .2217 .62297 L .22023 .6217 L F
.22254 .62269 m .22409 .62418 L .2217 .62297 L F
.124 0 0 r
.33456 .54737 m .33797 .54677 L .33598 .54757 L F
.493 .903 .897 r
.33797 .54677 m .33798 .54661 L .33741 .54689 L F
.742 .833 .379 r
.33797 .54677 m .33903 .54381 L .34093 .54673 L F
.369 .717 .987 r
.33797 .54677 m .34093 .54673 L .33835 .54644 L F
.556 .583 .837 r
.34018 .55088 m .33723 .54856 L .33835 .54644 L F
.493 .903 .897 r
.33797 .54677 m .33741 .54689 L .33598 .54757 L F
.556 .583 .837 r
.33723 .54856 m .33598 .54757 L .33798 .54661 L F
.742 .833 .379 r
.33797 .54677 m .33789 .54686 L .33798 .54661 L F
.493 .903 .897 r
.33797 .54677 m .33835 .54644 L .33798 .54661 L F
.556 .583 .837 r
.33723 .54856 m .33798 .54661 L .33835 .54644 L F
.742 .833 .379 r
.33798 .54661 m .33762 .54716 L .33803 .54617 L F
.124 0 0 r
.33521 .54733 m .33762 .54716 L .33797 .54677 L F
.742 .833 .379 r
.33789 .54686 m .33762 .54716 L .33798 .54661 L F
.33797 .54677 m .33803 .54617 L .33903 .54381 L F
.124 0 0 r
.33456 .54737 m .33521 .54733 L .33797 .54677 L F
.746 .511 .575 r
.33569 .55386 m .34018 .55088 L .33895 .55003 L F
.33569 .55386 m .33979 .55587 L .34018 .55088 L F
.468 .483 .791 r
.34093 .54673 m .34018 .55088 L .33835 .54644 L F
.34093 .54673 m .34227 .55087 L .34018 .55088 L F
.054 .581 .866 r
.34227 .55087 m .33895 .55003 L .34018 .55088 L F
.63 .54 .734 r
.46568 .66121 m .46676 .66467 L .46925 .6619 L F
.428 .61 .925 r
.78757 .4305 m .7892 .42825 L .78688 .42805 L F
.78757 .4305 m .79093 .43065 L .7892 .42825 L F
.59 .605 .835 r
.78757 .4305 m .79162 .4324 L .79093 .43065 L F
.431 .348 .662 r
.42434 .66071 m .42662 .65846 L .42705 .65673 L F
.641 .375 .501 r
.46349 .62727 m .46498 .62419 L .46389 .62495 L F
.46349 .62727 m .46757 .62876 L .46498 .62419 L F
.722 .667 .795 r
.46498 .62419 m .46988 .62149 L .46722 .6218 L F
.671 .385 .478 r
.46498 .62419 m .46757 .62876 L .4727 .62755 L F
.688 .859 .964 r
.24263 .69885 m .24219 .70049 L .23983 .69911 L F
.544 .46 .71 r
.24463 .70032 m .24219 .70049 L .24263 .69885 L F
.481 .387 .672 r
.33913 .58126 m .33666 .57908 L .34014 .57871 L F
.228 0 .248 r
.34174 .57885 m .34014 .57871 L .3419 .57864 L F
.34174 .57885 m .33913 .58126 L .34014 .57871 L F
.807 .611 .638 r
.54753 .52403 m .54363 .52633 L .54374 .52347 L F
.54753 .52403 m .54669 .5269 L .54363 .52633 L F
.522 .282 .492 r
.30839 .62491 m .30808 .62738 L .30567 .62768 L F
.508 .332 .577 r
.31076 .62176 m .3107 .6244 L .30839 .62491 L F
.539 .324 .537 r
.3107 .6244 m .30808 .62738 L .30839 .62491 L F
0 0 0 r
.26538 .64871 m .26684 .64811 L .26458 .64835 L F
.281 0 0 r
.3326 .54678 m .33456 .54737 L .33598 .54757 L F
.3326 .54678 m .33456 .54737 L .33598 .54757 L F
.832 .537 .491 r
.56129 .57476 m .56444 .57296 L .5614 .57195 L F
.56129 .57476 m .56452 .57532 L .56444 .57296 L F
0 0 0 r
.1527 .57503 m .15567 .57218 L .1538 .57305 L F
.189 0 .077 r
.46201 .64656 m .46545 .64321 L .46192 .64309 L F
.915 .621 .473 r
.46545 .64321 m .46397 .64587 L .4657 .64591 L F
.485 .59 .884 r
.31698 .54071 m .31565 .5428 L .3151 .54126 L F
.502 .451 .732 r
.31565 .5428 m .31851 .5448 L .31867 .54373 L F
.381 .452 .808 r
.31698 .54071 m .31851 .5448 L .31565 .5428 L F
.342 .1 .394 r
.30416 .59125 m .30168 .59429 L .30365 .59358 L F
.314 .042 .332 r
.30365 .59358 m .30168 .59429 L .30132 .59645 L F
.695 .539 .671 r
.27651 .57916 m .27695 .58218 L .27905 .5786 L F
.639 .756 .933 r
.77445 .41261 m .77161 .41389 L .76813 .41249 L F
0 0 0 r
.27717 .60564 m .2767 .60677 L .27773 .60329 L F
0 0 .129 r
.27717 .60564 m .27586 .60914 L .2767 .60677 L F
.426 .222 .498 r
.30365 .59358 m .30603 .59047 L .30416 .59125 L F
.858 .51 .393 r
.55856 .52076 m .56171 .52365 L .56063 .5208 L F
.831 .652 .66 r
.56834 .57858 m .566 .58152 L .56951 .58204 L F
.813 .618 .639 r
.5657 .58408 m .56951 .58204 L .566 .58152 L F
.5657 .58408 m .56996 .58487 L .56951 .58204 L F
.613 .808 .975 r
.33402 .56953 m .33796 .56989 L .33622 .56857 L F
.783 .548 .581 r
.33402 .56953 m .33733 .57244 L .33796 .56989 L F
.751 .8 .892 r
.81912 .4134 m .81562 .416 L .81568 .41305 L F
.901 .812 .75 r
.5595 .54389 m .5599 .54826 L .55989 .54541 L F
.486 .245 .474 r
.47157 .62802 m .47122 .63042 L .46878 .63092 L F
0 0 0 r
.83641 .39256 m .83432 .39487 L .83657 .39412 L F
.741 .546 .63 r
.83657 .39412 m .84027 .39216 L .83641 .39256 L F
.615 .57 .781 r
.46568 .66121 m .46925 .6619 L .46814 .65834 L F
.425 .305 .613 r
.49471 .60389 m .49539 .60662 L .49712 .60551 L F
.28 0 .153 r
.17793 .55388 m .17882 .55575 L .17941 .55357 L F
.17793 .55388 m .17671 .55639 L .17882 .55575 L F
0 0 .133 r
.27992 .59984 m .27949 .60227 L .27773 .60329 L F
.376 .269 .603 r
.27949 .60227 m .27717 .60564 L .27773 .60329 L F
.603 .458 .656 r
.49258 .54857 m .49481 .55092 L .49455 .54885 L F
.645 .559 .743 r
.19874 .63405 m .19904 .63579 L .20082 .63492 L F
.959 .751 .579 r
.50968 .60531 m .51154 .60327 L .5094 .6031 L F
.50968 .60531 m .51133 .60631 L .51154 .60327 L F
.868 .677 .642 r
.55398 .53928 m .55185 .53869 L .55218 .53577 L F
.871 .593 .514 r
.55398 .53928 m .55227 .54085 L .55185 .53869 L F
.55398 .53928 m .55416 .5419 L .55227 .54085 L F
.948 .913 .54 r
.49205 .59125 m .49067 .59284 L .49163 .59075 L F
0 0 0 r
.49163 .59075 m .49067 .59284 L .49164 .5912 L F
.826 .492 0 r
.49205 .59125 m .49163 .59075 L .49162 .59013 L F
.132 .297 .765 r
.49278 .58928 m .49205 .59125 L .49067 .58768 L F
0 0 0 r
.49163 .59075 m .49164 .5912 L .49278 .58928 L F
.826 .492 0 r
.49162 .59013 m .49163 .59075 L .49067 .58768 L F
.769 .912 .528 r
.49278 .58928 m .49067 .59284 L .49205 .59125 L F
.613 .559 .77 r
.81289 .41398 m .81032 .41636 L .81019 .41462 L F
.04 0 .231 r
.26904 .60631 m .27087 .60544 L .27088 .60314 L F
.223 0 .333 r
.26835 .60845 m .27087 .60544 L .26904 .60631 L F
.924 .729 .62 r
.55791 .56016 m .55775 .56339 L .55934 .56373 L F
.958 .733 .555 r
.55749 .5648 m .55934 .56373 L .55775 .56339 L F
.55749 .5648 m .55913 .56626 L .55934 .56373 L F
.354 .11 .398 r
.30818 .57399 m .30654 .57352 L .30898 .57318 L F
.30818 .57399 m .30622 .57537 L .30654 .57352 L F
.638 .748 .928 r
.33856 .59005 m .3363 .59102 L .33515 .58883 L F
.421 .468 .803 r
.54267 .59018 m .54259 .59168 L .5446 .58996 L F
.605 .602 .822 r
.54342 .59412 m .5446 .58996 L .54259 .59168 L F
.241 0 .239 r
.15657 .57038 m .15567 .57218 L .15841 .56942 L F
.603 .458 .656 r
.49258 .54857 m .49286 .55184 L .49481 .55092 L F
.517 .372 .623 r
.32276 .60885 m .32047 .60667 L .32293 .60624 L F
.32276 .60885 m .32048 .60945 L .32047 .60667 L F
.368 .647 .964 r
.31246 .53897 m .31173 .54038 L .31062 .53866 L F
.31246 .53897 m .3151 .54126 L .31173 .54038 L F
.481 .387 .672 r
.33913 .58126 m .33703 .58196 L .33666 .57908 L F
.469 .274 .532 r
.32525 .60309 m .32293 .60624 L .32289 .60335 L F
.605 .322 .461 r
.80157 .40682 m .80502 .40454 L .80143 .40512 L F
.095 0 0 r
.18969 .54846 m .18998 .54963 L .19162 .54756 L F
.18969 .54846 m .18787 .55032 L .18998 .54963 L F
.305 .419 .814 r
.34227 .55087 m .344 .55474 L .3421 .5522 L F
.092 .637 .839 r
.25326 .53524 m .25539 .5353 L .25702 .53564 L F
.244 .741 .908 r
.25702 .53564 m .25539 .5353 L .25937 .53546 L F
.596 .41 .6 r
.3133 .61873 m .31329 .62144 L .31076 .62176 L F
.568 .38 .587 r
.31581 .61831 m .31329 .62144 L .3133 .61873 L F
.727 .784 .898 r
.81482 .43804 m .81529 .44055 L .81843 .4384 L F
.511 .199 .375 r
.2446 .70391 m .24018 .7058 L .24244 .70432 L F
0 0 .171 r
.27088 .60314 m .27169 .60435 L .27279 .60203 L F
.27088 .60314 m .27087 .60544 L .27169 .60435 L F
.646 .431 .577 r
.46878 .63092 m .46619 .63331 L .46625 .63121 L F
.83 .742 .221 r
.52735 .52546 m .52706 .52593 L .52747 .52333 L F
.796 .321 0 r
.52735 .52546 m .52886 .52741 L .52706 .52593 L F
.913 .803 .724 r
.54751 .57205 m .54487 .57218 L .54673 .56904 L F
.87 .751 .728 r
.54751 .57205 m .54394 .57434 L .54487 .57218 L F
.54751 .57205 m .54577 .57575 L .54394 .57434 L F
.879 .448 .159 r
.50948 .55843 m .51067 .55744 L .51032 .55709 L F
.50948 .55843 m .51249 .5605 L .51067 .55744 L F
.91 .902 .805 r
.54971 .56104 m .54719 .56199 L .5481 .55983 L F
.54971 .56104 m .54773 .56393 L .54719 .56199 L F
.345 .446 .821 r
.30949 .57732 m .30777 .57897 L .30622 .57537 L F
.576 .281 .431 r
.30777 .57897 m .30992 .58097 L .31019 .57886 L F
.237 .271 .694 r
.30949 .57732 m .30992 .58097 L .30777 .57897 L F
.557 .33 .527 r
.2694 .55385 m .26697 .55642 L .2674 .55455 L F
.821 .74 .774 r
.79623 .41065 m .79291 .41025 L .7956 .40685 L F
.823 .687 .713 r
.79623 .41065 m .79263 .41227 L .79291 .41025 L F
.79623 .41065 m .79421 .41403 L .79263 .41227 L F
.505 .106 .219 r
.81281 .40052 m .81554 .40045 L .8161 .39846 L F
.554 .213 .344 r
.81554 .40045 m .81886 .39793 L .8161 .39846 L F
.684 .843 .959 r
.55705 .58982 m .56145 .5911 L .55969 .58689 L F
.55705 .58982 m .55849 .59091 L .56145 .5911 L F
.796 .796 .852 r
.55969 .58689 m .56145 .5911 L .56322 .58709 L F
.775 .784 .861 r
.56145 .5911 m .56467 .58839 L .56322 .58709 L F
.573 .78 .977 r
.50614 .52643 m .50888 .5257 L .50961 .52696 L F
.50614 .52643 m .50888 .5257 L .50961 .52696 L F
.418 .194 .464 r
.20214 .77145 m .20263 .76849 L .20012 .77162 L F
.20214 .77145 m .20263 .76849 L .20012 .77162 L F
.838 .663 .665 r
.56441 .57792 m .566 .58152 L .56834 .57858 L F
.28 .775 .892 r
.2466 .62547 m .2444 .62584 L .24245 .62554 L F
.852 .804 .803 r
.55077 .55252 m .54678 .55375 L .54939 .55117 L F
.55077 .55252 m .54874 .55448 L .54678 .55375 L F
.745 .863 .934 r
.55278 .5509 m .55077 .55252 L .54939 .55117 L F
.146 .688 .813 r
.25937 .53546 m .26165 .53528 L .26331 .53537 L F
.09 .647 .783 r
.26331 .53537 m .26165 .53528 L .26563 .53528 L F
.646 .431 .577 r
.46878 .63092 m .46883 .63356 L .46619 .63331 L F
.515 .328 .565 r
.47122 .63042 m .46883 .63356 L .46878 .63092 L F
.487 .773 .995 r
.4704 .65463 m .47287 .65418 L .47413 .65538 L F
.4704 .65463 m .47287 .65418 L .47413 .65538 L F
.448 .173 .403 r
.20263 .76849 m .20423 .77109 L .20214 .77145 L F
.44 .547 .868 r
.20214 .77145 m .20362 .77193 L .20394 .77114 L F
.448 .173 .403 r
.20423 .77109 m .20432 .77123 L .20214 .77145 L F
.20263 .76849 m .20485 .76808 L .20434 .77109 L F
.20423 .77109 m .20434 .77109 L .20432 .77123 L F
.20263 .76849 m .20434 .77109 L .20423 .77109 L F
.44 .547 .868 r
.20214 .77145 m .20394 .77114 L .20396 .77108 L F
.20285 .77107 m .20396 .77108 L .20427 .77029 L F
.20214 .77145 m .20396 .77108 L .20285 .77107 L F
.369 .001 .2 r
.20427 .77029 m .20263 .76849 L .20214 .77145 L F
.20427 .77029 m .20485 .76808 L .20263 .76849 L F
.647 .165 .095 r
.22597 .72755 m .22829 .7258 L .22438 .72534 L F
.676 .127 0 r
.22903 .72752 m .22829 .7258 L .22597 .72755 L F
.22903 .72752 m .23049 .7278 L .22829 .7258 L F
.552 .679 .923 r
.19559 .63049 m .19874 .63405 L .20073 .63302 L F
.645 .559 .743 r
.19874 .63405 m .20082 .63492 L .20073 .63302 L F
.467 .222 .459 r
.33291 .59388 m .33013 .59689 L .33033 .59426 L F
.76 .619 .703 r
.56706 .58784 m .5709 .58811 L .56996 .58487 L F
.888 .871 .815 r
.56714 .59022 m .5709 .58811 L .56706 .58784 L F
.56714 .59022 m .56853 .59137 L .5709 .58811 L F
.375 .128 .406 r
.15091 .57573 m .15229 .57732 L .1527 .57503 L F
.15091 .57573 m .15033 .57817 L .15229 .57732 L F
.415 .571 .9 r
.18893 .62417 m .19107 .62727 L .19289 .62702 L F
.325 .089 .393 r
.28521 .54772 m .28453 .55063 L .28699 .54745 L F
.254 0 .155 r
.28699 .54745 m .28506 .54881 L .28521 .54772 L F
0 0 0 r
.43895 .66321 m .43699 .66451 L .43749 .66399 L F
.43749 .66399 m .43699 .66451 L .43895 .66321 L F
.827 .654 .668 r
.55282 .53315 m .54886 .53518 L .54912 .53261 L F
.55282 .53315 m .55218 .53577 L .54886 .53518 L F
.402 0 .02 r
.82437 .39534 m .82796 .39429 L .82492 .39523 L F
.02 0 0 r
.28045 .53291 m .28284 .53274 L .28495 .53239 L F
.024 0 0 r
.28284 .53274 m .2871 .53192 L .28495 .53239 L F
.607 .397 .571 r
.47642 .62172 m .47623 .62446 L .47362 .62462 L F
.483 .217 .435 r
.47939 .62167 m .47623 .62446 L .47642 .62172 L F
.636 .818 .97 r
.30856 .5388 m .30452 .53837 L .30684 .53781 L F
.323 .728 .98 r
.30684 .53781 m .31062 .53866 L .30856 .5388 L F
.2 .725 .731 r
.21213 .63701 m .2098 .63745 L .20837 .63784 L F
.572 .058 0 r
.21213 .63701 m .21256 .63769 L .2098 .63745 L F
.21213 .63701 m .21416 .63916 L .21256 .63769 L F
.689 .148 0 r
.21588 .63992 m .21416 .63916 L .21213 .63701 L F
.472 .241 .481 r
.31329 .62144 m .3107 .6244 L .31076 .62176 L F
.507 .176 .341 r
.29492 .63726 m .2947 .63904 L .29233 .63918 L F
.613 .267 .36 r
.29492 .63726 m .29689 .63927 L .2947 .63904 L F
.525 .273 .476 r
.29738 .63675 m .29689 .63927 L .29492 .63726 L F
.407 .605 .928 r
.79093 .43065 m .79162 .4324 L .79325 .43065 L F
.472 .708 .972 r
.79325 .43065 m .79162 .4324 L .79403 .43207 L F
0 .235 .685 r
.4503 .66963 m .45296 .67151 L .45081 .67019 L F
.568 .294 .46 r
.28849 .64007 m .28586 .6424 L .28603 .64007 L F
.114 0 0 r
.26563 .53528 m .26789 .53525 L .26955 .5349 L F
.182 .711 .711 r
.26955 .5349 m .27168 .53439 L .27175 .53428 L F
.26955 .5349 m .26789 .53525 L .27168 .53439 L F
.525 .283 .491 r
.30567 .62768 m .30545 .63037 L .30291 .63076 L F
.58 .329 .501 r
.30798 .63004 m .30567 .62768 L .30808 .62738 L F
.30798 .63004 m .30545 .63037 L .30567 .62768 L F
.49 .776 .995 r
.21564 .55412 m .21999 .55493 L .21751 .55323 L F
.976 .78 .574 r
.24729 .69075 m .24866 .69133 L .2491 .68901 L F
.238 0 0 r
.24729 .69075 m .2491 .68901 L .24997 .68982 L F
.369 0 0 r
.2491 .68901 m .25195 .68919 L .24997 .68982 L F
.958 .761 .595 r
.54773 .56393 m .54566 .56563 L .54719 .56199 L F
.54773 .56393 m .54703 .56655 L .54566 .56563 L F
.904 .806 .33 r
.32322 .55978 m .32295 .56381 L .32624 .5612 L F
.32322 .55978 m .32278 .56314 L .32295 .56381 L F
.477 .017 .081 r
.32577 .56769 m .32981 .56592 L .32722 .56547 L F
.966 .725 .522 r
.54929 .53005 m .54912 .53261 L .54768 .52907 L F
.628 .887 .988 r
.21699 .63812 m .21588 .63992 L .21834 .63928 L F
.21699 .63812 m .21416 .63916 L .21588 .63992 L F
.621 .899 .987 r
.82639 .40175 m .82885 .40074 L .82821 .39978 L F
.553 .861 .558 r
.82553 .40243 m .82639 .40175 L .82821 .39978 L F
0 0 .51 r
.17459 .59198 m .176 .59592 L .17476 .59389 L F
.817 .519 .484 r
.48898 .63234 m .48775 .63359 L .48789 .63125 L F
.986 .89 .635 r
.50611 .59325 m .50592 .59689 L .50698 .59492 L F
.531 .258 .446 r
.17166 .55964 m .1747 .55706 L .17244 .55771 L F
.226 0 0 r
.24924 .66507 m .25168 .66425 L .25232 .66141 L F
.487 .325 .587 r
.25381 .65874 m .25232 .66141 L .25468 .66074 L F
.405 .132 .382 r
.25468 .66074 m .25232 .66141 L .25168 .66425 L F
.525 .829 1 r
.25468 .66074 m .25232 .66141 L .25381 .65874 L F
.621 .682 .886 r
.29036 .53306 m .28843 .53406 L .2871 .53192 L F
.982 .742 .498 r
.27736 .55802 m .2755 .55906 L .27563 .55635 L F
.447 0 0 r
.27949 .55894 m .2755 .55906 L .27736 .55802 L F
.478 .376 .66 r
.1465 .58458 m .14877 .58428 L .14816 .58172 L F
.312 .146 .488 r
.14823 .58654 m .14877 .58428 L .1465 .58458 L F
.698 .265 .216 r
.50317 .55384 m .50471 .55573 L .50683 .55421 L F
.144 0 0 r
.50471 .55573 m .5089 .55471 L .50683 .55421 L F
.497 .758 .988 r
.23426 .62604 m .23206 .62655 L .23 .62499 L F
.682 .799 .937 r
.7787 .41746 m .77533 .41716 L .77788 .41636 L F
.511 .784 .994 r
.78107 .41595 m .7787 .41746 L .77788 .41636 L F
.78107 .41595 m .7818 .41698 L .7787 .41746 L F
.6 .796 .974 r
.20129 .61093 m .20044 .61289 L .19814 .61011 L F
.20129 .61093 m .20274 .61222 L .20044 .61289 L F
.413 .668 .965 r
.77681 .42228 m .77838 .42059 L .77597 .42041 L F
.77681 .42228 m .77912 .42208 L .77838 .42059 L F
.749 .686 .79 r
.23558 .70168 m .23418 .70352 L .23552 .70097 L F
.395 .26 .578 r
.23552 .70097 m .23418 .70352 L .23553 .70488 L F
0 0 0 r
.17024 .58402 m .16886 .58497 L .17137 .582 L F
.349 .209 .545 r
.17024 .58402 m .16839 .58759 L .16886 .58497 L F
.577 .627 .865 r
.27643 .55016 m .28071 .55294 L .27876 .54935 L F
.104 0 0 r
.27876 .54935 m .27783 .5499 L .27643 .55016 L F
0 .105 .656 r
.27639 .55123 m .27643 .55016 L .27474 .55048 L F
.27639 .55123 m .27861 .55356 L .27643 .55016 L F
.577 .627 .865 r
.27643 .55016 m .27861 .55356 L .28071 .55294 L F
.104 0 0 r
.27783 .5499 m .27505 .55152 L .27643 .55016 L F
0 .105 .656 r
.27474 .55048 m .27643 .55016 L .27433 .55029 L F
.811 .583 .593 r
.45418 .67284 m .45551 .67147 L .45296 .67151 L F
.759 .598 .678 r
.50981 .61388 m .51041 .61598 L .50801 .61522 L F
0 0 0 r
.50801 .61522 m .50885 .61478 L .50981 .61388 L F
.979 .682 .359 r
.50981 .61388 m .50885 .61478 L .51041 .61598 L F
.683 .831 .954 r
.25393 .66798 m .25636 .66713 L .25215 .66672 L F
.888 .466 .172 r
.25393 .66798 m .2563 .67189 L .25636 .66713 L F
.47 0 0 r
.25258 .62613 m .25068 .62509 L .24883 .62638 L F
.931 .788 .681 r
.21789 .74823 m .21728 .74995 L .216 .74732 L F
.771 .623 .696 r
.21905 .74492 m .21964 .7442 L .21678 .74442 L F
.62 .507 .703 r
.21905 .74492 m .21789 .74823 L .21678 .74769 L F
.21964 .7442 m .21924 .7451 L .21905 .74491 L F
.771 .623 .696 r
.21909 .74493 m .21964 .7442 L .21905 .74492 L F
.62 .507 .703 r
.21964 .7442 m .21893 .7448 L .21678 .74442 L F
.577 .773 .972 r
.21868 .74454 m .21893 .7448 L .21678 .74442 L F
.21893 .7448 m .21905 .74492 L .21678 .74442 L F
.62 .507 .703 r
.21893 .7448 m .216 .74732 L .21678 .74442 L F
.21964 .7442 m .21678 .74769 L .216 .74732 L F
.21964 .7442 m .21972 .74685 L .21789 .74823 L F
.127 .674 .717 r
.22078 .744 m .22222 .7438 L .21964 .7442 L F
.648 .962 .92 r
.22125 .74337 m .22222 .7438 L .22264 .74253 L F
.22049 .74404 m .22222 .7438 L .22111 .74331 L F
.707 .783 .91 r
.22264 .74253 m .22085 .74361 L .21864 .74216 L F
.648 .962 .92 r
.22075 .74372 m .22111 .74331 L .2211 .7433 L F
.22049 .74404 m .22111 .74331 L .22075 .74372 L F
.499 .739 .98 r
.22085 .74361 m .2162 .74224 L .21864 .74216 L F
.22132 .74391 m .22075 .74372 L .22085 .74361 L F
.22075 .74372 m .2162 .74224 L .22085 .74361 L F
.707 .783 .91 r
.22264 .74253 m .22132 .74391 L .22085 .74361 L F
.648 .962 .92 r
.2211 .7433 m .22125 .74337 L .22264 .74253 L F
.499 .739 .98 r
.22057 .74367 m .21868 .74454 L .21643 .74232 L F
.22075 .74372 m .22069 .74375 L .22057 .74367 L F
.22069 .74375 m .21868 .74454 L .22057 .74367 L F
.21643 .74232 m .21868 .74454 L .2162 .74224 L F
.577 .773 .972 r
.2162 .74224 m .21868 .74454 L .21678 .74442 L F
.83 .945 .898 r
.21638 .74554 m .21911 .74429 L .21866 .74223 L F
.21862 .7422 m .21866 .74223 L .21864 .74216 L F
.21638 .74554 m .21866 .74223 L .21862 .7422 L F
.648 .962 .92 r
.21927 .74422 m .22049 .74404 L .2211 .7433 L F
.499 .739 .98 r
.22132 .74391 m .22042 .74412 L .22075 .74372 L F
.22042 .74412 m .21868 .74454 L .22075 .74372 L F
.127 .674 .717 r
.22132 .74391 m .22222 .7438 L .22078 .744 L F
.22017 .74443 m .21964 .7442 L .21909 .74493 L F
.691 .563 .706 r
.21964 .7442 m .22222 .7438 L .21972 .74685 L F
.888 .933 .842 r
.21972 .74685 m .22222 .7438 L .22074 .74403 L F
.127 .674 .717 r
.22054 .74427 m .22074 .74403 L .22017 .74443 L F
.22078 .744 m .21964 .7442 L .22017 .74443 L F
.499 .739 .98 r
.22047 .74411 m .21909 .74493 L .21868 .74454 L F
.888 .933 .842 r
.22054 .74427 m .22074 .74403 L .22046 .74408 L F
.127 .674 .717 r
.22132 .74391 m .22074 .74403 L .22054 .74427 L F
.499 .739 .98 r
.22132 .74391 m .22054 .74427 L .22047 .74411 L F
.22054 .74427 m .21909 .74493 L .22047 .74411 L F
.888 .933 .842 r
.21942 .74557 m .22054 .74427 L .21911 .74429 L F
.22054 .74427 m .22046 .74408 L .21911 .74429 L F
.21972 .74685 m .22074 .74403 L .21942 .74557 L F
.648 .962 .92 r
.22074 .74403 m .22222 .7438 L .22078 .744 L F
.127 .674 .717 r
.22132 .74391 m .22078 .744 L .22074 .74403 L F
.648 .962 .92 r
.21911 .74429 m .22074 .74403 L .21927 .74422 L F
.22074 .74403 m .22078 .744 L .21927 .74422 L F
.62 .507 .703 r
.21905 .74491 m .21924 .74511 L .21905 .74492 L F
.21924 .7451 m .21924 .74511 L .21905 .74491 L F
.21924 .74511 m .21789 .74823 L .21905 .74492 L F
.577 .773 .972 r
.21868 .74454 m .21909 .74493 L .21905 .74492 L F
.492 .293 .538 r
.21789 .74823 m .21972 .74685 L .21728 .74995 L F
.758 .833 .909 r
.82015 .4371 m .82414 .43654 L .8233 .43473 L F
.7 .812 .935 r
.8233 .43473 m .82414 .43654 L .82713 .435 L F
.729 .767 .883 r
.54953 .59612 m .55292 .59623 L .55204 .59366 L F
.754 .776 .871 r
.55204 .59366 m .55292 .59623 L .55605 .59408 L F
.433 .593 .91 r
.50126 .58722 m .50106 .58785 L .49947 .58534 L F
.215 .462 .879 r
.50106 .58785 m .5022 .58656 L .49947 .58534 L F
.704 .441 .524 r
.50178 .58896 m .50456 .58992 L .50338 .58732 L F
.50128 .58948 m .50188 .58956 L .50178 .58896 L F
.50188 .58956 m .50456 .58992 L .50178 .58896 L F
.885 .908 .501 r
.50133 .59023 m .50172 .58857 L .50106 .58785 L F
.50172 .58857 m .5022 .58656 L .50153 .58731 L F
.50172 .58857 m .50153 .58731 L .50106 .58785 L F
0 0 0 r
.23085 .54915 m .22896 .54972 L .22672 .55028 L F
.273 .778 .805 r
.23298 .54898 m .22896 .54972 L .23085 .54915 L F
.585 .632 .864 r
.82795 .41217 m .82559 .4128 L .8243 .40948 L F
.799 .687 .742 r
.5657 .58408 m .56706 .58784 L .56996 .58487 L F
.57 .221 .337 r
.33597 .59267 m .33493 .59577 L .33291 .59388 L F
.56 .231 .369 r
.33861 .59296 m .33493 .59577 L .33597 .59267 L F
0 0 .032 r
.20632 .55714 m .20557 .55956 L .20441 .56017 L F
0 0 0 r
.20557 .55956 m .20248 .56156 L .20441 .56017 L F
.22392 .53747 m .22624 .53723 L .22829 .53679 L F
.1 .655 .717 r
.22624 .53723 m .23035 .53675 L .22829 .53679 L F
0 0 0 r
.20008 .54348 m .20297 .54185 L .20087 .54231 L F
.855 .631 .598 r
.49616 .57512 m .49806 .57838 L .49835 .5753 L F
.49835 .5753 m .49806 .57838 L .49616 .57512 L F
.666 .176 .077 r
.53138 .5267 m .52706 .52593 L .52886 .52741 L F
.521 .262 .462 r
.30044 .63354 m .2998 .63638 L .29738 .63675 L F
.516 .336 .575 r
.30291 .63076 m .30291 .63323 L .30044 .63354 L F
.53 .27 .465 r
.30259 .63568 m .30044 .63354 L .30291 .63323 L F
.30259 .63568 m .2998 .63638 L .30044 .63354 L F
.974 .749 .536 r
.20713 .7676 m .20885 .76843 L .20692 .77038 L F
.20692 .77038 m .20885 .76843 L .20713 .7676 L F
.033 0 0 r
.19802 .54419 m .19803 .54552 L .20008 .54348 L F
.19802 .54419 m .19598 .54633 L .19803 .54552 L F
.491 .255 .483 r
.46145 .62767 m .46349 .62727 L .46389 .62495 L F
.548 .326 .53 r
.33703 .58196 m .33678 .5844 L .3342 .58468 L F
.487 .305 .559 r
.33913 .58126 m .33678 .5844 L .33703 .58196 L F
.263 .379 .794 r
.34193 .55601 m .34063 .55795 L .34003 .5561 L F
.34193 .55601 m .34282 .5571 L .34063 .55795 L F
.225 .267 .696 r
.34282 .5571 m .34185 .56071 L .34063 .55795 L F
.088 .424 .869 r
.28365 .58136 m .28368 .57993 L .28154 .57818 L F
.28365 .58136 m .28453 .58139 L .28368 .57993 L F
.233 .656 .958 r
.51041 .61598 m .50885 .61478 L .50801 .61522 L F
.45 .742 .991 r
.24129 .55076 m .2415 .5492 L .23929 .54974 L F
.24129 .55076 m .24318 .55052 L .2415 .5492 L F
.132 .209 .678 r
.46988 .62149 m .47198 .62274 L .47252 .62157 L F
.265 .035 .366 r
.17276 .58062 m .17024 .58402 L .17137 .582 L F
.591 .465 .677 r
.81224 .41001 m .81289 .41398 L .81019 .41462 L F
.901 .812 .75 r
.5595 .54389 m .55795 .54745 L .5599 .54826 L F
.904 .809 .743 r
.55795 .54745 m .55844 .55053 L .5599 .54826 L F
.557 .198 .315 r
.27721 .64292 m .27829 .64536 L .27563 .64523 L F
.27721 .64292 m .27968 .64286 L .27829 .64536 L F
.455 .103 .279 r
.17845 .57526 m .17445 .57741 L .17635 .57599 L F
.487 .325 .587 r
.25381 .65874 m .25468 .66074 L .25404 .65684 L F
.102 0 .407 r
.28522 .56337 m .28648 .56279 L .28632 .56004 L F
.171 .132 .569 r
.28522 .56337 m .28673 .56538 L .28648 .56279 L F
.062 .617 .816 r
.24691 .64204 m .24882 .64197 L .24673 .64149 L F
.605 .602 .822 r
.54342 .59412 m .54586 .59372 L .5446 .58996 L F
.699 .629 .774 r
.54386 .59592 m .54586 .59372 L .54342 .59412 L F
.721 .605 .727 r
.54386 .59592 m .54476 .60023 L .54722 .59713 L F
.369 .398 .76 r
.25853 .6461 m .26127 .6475 L .26019 .64619 L F
.241 .47 .879 r
.25853 .6461 m .26221 .64931 L .26127 .6475 L F
.558 .317 .507 r
.31871 .61553 m .31827 .61821 L .31581 .61831 L F
.405 .183 .46 r
.32052 .6174 m .31871 .61553 L .32065 .61479 L F
.32052 .6174 m .31827 .61821 L .31871 .61553 L F
.644 .531 .711 r
.46284 .6643 m .46378 .6677 L .46061 .66775 L F
.639 .524 .708 r
.46383 .66762 m .46394 .66762 L .46284 .6643 L F
0 0 .291 r
.46314 .66788 m .46061 .66775 L .46378 .6677 L F
.423 .11 .327 r
.46007 .67102 m .46361 .6679 L .46314 .66788 L F
.46059 .66784 m .46314 .66788 L .46061 .66775 L F
.46007 .67102 m .46314 .66788 L .46059 .66784 L F
.181 0 .241 r
.46375 .66789 m .46335 .66992 L .46363 .66789 L F
.46378 .6677 m .46387 .66767 L .46335 .66992 L F
.423 .11 .327 r
.46387 .66768 m .46335 .66992 L .46394 .66762 L F
.172 0 .233 r
.46335 .66992 m .46584 .6669 L .46394 .66762 L F
.181 0 .241 r
.46387 .66767 m .46584 .6669 L .46335 .66992 L F
.423 .11 .327 r
.46007 .67102 m .46335 .66992 L .46363 .66789 L F
.582 .243 .361 r
.46378 .6677 m .46335 .66992 L .46063 .66857 L F
.423 .11 .327 r
.46363 .66789 m .46335 .66992 L .46387 .66768 L F
.181 0 .241 r
.46363 .66789 m .46335 .66992 L .46314 .66788 L F
.46314 .66788 m .46335 .66992 L .46063 .66857 L F
.46378 .6677 m .46375 .66789 L .46314 .66788 L F
0 0 .291 r
.46063 .66857 m .46061 .66775 L .46314 .66788 L F
.423 .11 .327 r
.46361 .6679 m .46388 .66767 L .46061 .66775 L F
.46388 .66767 m .46394 .66762 L .46383 .66762 L F
.385 .367 .716 r
.46383 .66762 m .46388 .66767 L .46385 .66768 L F
.46284 .6643 m .46385 .66768 L .46378 .6677 L F
.423 .11 .327 r
.46388 .66767 m .46383 .66762 L .46061 .66775 L F
.375 .366 .721 r
.46394 .66762 m .46584 .6669 L .46284 .6643 L F
.385 .367 .716 r
.46284 .6643 m .46584 .6669 L .46388 .66767 L F
.46284 .6643 m .46388 .66767 L .46383 .66762 L F
.639 .524 .708 r
.46061 .66775 m .46383 .66762 L .46284 .6643 L F
0 0 .291 r
.46063 .66857 m .46007 .67102 L .46061 .66775 L F
.528 .295 .505 r
.46061 .66775 m .46007 .67102 L .45801 .67045 L F
.593 .625 .853 r
.28492 .59533 m .28632 .59791 L .28822 .59604 L F
.152 .075 .508 r
.28666 .60021 m .28822 .59604 L .28632 .59791 L F
.384 .021 .221 r
.16674 .56245 m .16884 .56204 L .16977 .56053 L F
.18 0 .099 r
.16977 .56053 m .17072 .56133 L .17166 .55964 L F
.16977 .56053 m .16884 .56204 L .17072 .56133 L F
.934 .705 .225 r
.31291 .54847 m .31356 .55068 L .31347 .54772 L F
.696 .47 .577 r
.31347 .54772 m .31699 .55048 L .31555 .54703 L F
.31347 .54772 m .31356 .55068 L .31699 .55048 L F
.934 .705 .225 r
.31291 .54847 m .31347 .54772 L .31555 .54703 L F
.372 .443 .805 r
.17135 .58935 m .17002 .59114 L .16839 .58759 L F
.17135 .58935 m .17188 .59086 L .17002 .59114 L F
.373 .494 .853 r
.17188 .59086 m .17253 .59196 L .17002 .59114 L F
.622 .952 .929 r
.20773 .74577 m .20728 .74699 L .20579 .74691 L F
.20773 .74577 m .20728 .74699 L .20579 .74691 L F
.519 .339 .577 r
.2795 .61489 m .28203 .61168 L .2798 .61256 L F
.434 0 0 r
.54001 .51726 m .54099 .5186 L .54235 .51703 L F
.54001 .51726 m .54013 .51871 L .54099 .5186 L F
.33 .588 .938 r
.18208 .59826 m .18179 .59987 L .1796 .59738 L F
.102 .343 .813 r
.18208 .59826 m .1831 .60018 L .18179 .59987 L F
.595 .159 .183 r
.23829 .71347 m .2364 .71535 L .2343 .71415 L F
.463 .24 .489 r
.23924 .71222 m .2364 .71535 L .23829 .71347 L F
.292 .454 .85 r
.20082 .63492 m .20204 .63279 L .20073 .63302 L F
.20082 .63492 m .20375 .6363 L .20204 .63279 L F
.454 .188 .419 r
.33021 .59948 m .32726 .60214 L .32812 .6003 L F
0 0 0 r
.2589 .54807 m .25539 .54994 L .25616 .54862 L F
.197 .724 .843 r
.23455 .53612 m .2345 .53655 L .23239 .53672 L F
.23455 .53612 m .23676 .53629 L .2345 .53655 L F
.152 .075 .508 r
.28666 .60021 m .28754 .59972 L .28822 .59604 L F
0 0 .378 r
.28666 .60021 m .28809 .60183 L .28754 .59972 L F
.28666 .60021 m .28654 .60278 L .28809 .60183 L F
.557 .643 .891 r
.2368 .70723 m .23731 .70394 L .23553 .70488 L F
.2368 .70723 m .23904 .70677 L .23731 .70394 L F
.506 .339 .588 r
.23904 .70677 m .2391 .70945 L .2368 .70723 L F
.543 .312 .515 r
.19128 .67357 m .1945 .67324 L .19337 .67596 L F
.44 .241 .513 r
.33678 .5844 m .33461 .58651 L .3342 .58468 L F
.709 .761 .262 r
.25693 .66146 m .25786 .6588 L .2586 .6565 L F
.928 .693 .563 r
.25693 .66146 m .25855 .66175 L .25786 .6588 L F
.873 .651 .6 r
.55913 .56626 m .55924 .5697 L .56095 .56959 L F
.718 .268 .182 r
.55924 .5697 m .5597 .57094 L .56095 .56959 L F
.924 .58 .366 r
.5597 .57094 m .5614 .57195 L .56095 .56959 L F
.831 .84 .854 r
.83214 .43102 m .83343 .43262 L .83626 .42974 L F
.538 .038 .016 r
.28408 .55818 m .28189 .5595 L .27949 .55894 L F
.478 .553 .855 r
.28408 .55818 m .28632 .56004 L .28577 .55669 L F
.324 0 0 r
.28573 .55881 m .28408 .55818 L .28577 .55669 L F
.28573 .55881 m .28189 .5595 L .28408 .55818 L F
.353 .396 .767 r
.26158 .55603 m .26252 .55322 L .26035 .55378 L F
.26158 .55603 m .26342 .55638 L .26252 .55322 L F
.621 .421 .591 r
.47246 .64267 m .47455 .64347 L .4751 .63976 L F
.418 .241 .532 r
.4751 .63976 m .47628 .64214 L .47523 .64041 L F
.472 .832 .995 r
.14495 .63005 m .14681 .63077 L .14899 .63026 L F
.14899 .63026 m .14681 .63077 L .14495 .63005 L F
.824 .654 .671 r
.32322 .55978 m .32624 .5612 L .3249 .55726 L F
.673 .575 .737 r
.3249 .55726 m .32624 .5612 L .32869 .56027 L F
.657 .791 .946 r
.79709 .43172 m .79755 .43387 L .80081 .43237 L F
.699 .629 .774 r
.54386 .59592 m .54722 .59713 L .54586 .59372 L F
.677 .644 .81 r
.54722 .59713 m .54838 .59328 L .54586 .59372 L F
.54722 .59713 m .54953 .59612 L .54838 .59328 L F
.592 .589 .818 r
.33683 .58594 m .33515 .58883 L .33461 .58651 L F
.33683 .58594 m .33856 .59005 L .33515 .58883 L F
.941 .663 .485 r
.83657 .42493 m .83831 .42593 L .83651 .42248 L F
.896 .797 .742 r
.83657 .42493 m .83747 .4279 L .83831 .42593 L F
.905 .714 .633 r
.54874 .55448 m .54813 .55701 L .54678 .55375 L F
.989 .723 .41 r
.50214 .58385 m .50338 .58732 L .5036 .58492 L F
.405 .079 .297 r
.49314 .60816 m .49464 .60859 L .49539 .60662 L F
.49314 .60816 m .49223 .60914 L .49464 .60859 L F
.772 .603 .669 r
.46349 .62727 m .46964 .63043 L .46757 .62876 L F
.46349 .62727 m .46271 .63037 L .46964 .63043 L F
.838 .598 .577 r
.46345 .63213 m .46964 .63043 L .46271 .63037 L F
.502 .04 .087 r
.46619 .63331 m .46496 .63492 L .46246 .63379 L F
.698 .322 .331 r
.46883 .63356 m .46496 .63492 L .46619 .63331 L F
.46883 .63356 m .46733 .63594 L .46496 .63492 L F
.838 .598 .577 r
.46833 .6345 m .46857 .63461 L .46873 .63399 L F
.057 0 .165 r
.47039 .63254 m .46883 .63356 L .47122 .63042 L F
.414 .243 .539 r
.46873 .63399 m .4719 .62894 L .46964 .63043 L F
.46857 .63461 m .46906 .63379 L .46873 .63399 L F
.46906 .63379 m .4719 .62894 L .46873 .63399 L F
.699 .338 .36 r
.46496 .63492 m .46819 .63465 L .46345 .63213 L F
.46819 .63465 m .46857 .63461 L .46833 .6345 L F
.46819 .63465 m .46833 .6345 L .46345 .63213 L F
.502 .212 .406 r
.46931 .63325 m .46833 .6345 L .46883 .63356 L F
.699 .338 .36 r
.46819 .63465 m .46733 .63594 L .46857 .63461 L F
.502 .212 .406 r
.46819 .63465 m .46785 .63512 L .46807 .63477 L F
.46802 .63489 m .46785 .63512 L .46819 .63465 L F
.699 .338 .36 r
.46496 .63492 m .46733 .63594 L .46819 .63465 L F
.502 .212 .406 r
.46833 .6345 m .46802 .63489 L .46819 .63465 L F
.46833 .6345 m .46807 .63477 L .46883 .63356 L F
.46932 .63363 m .46733 .63594 L .46785 .63512 L F
.414 .243 .539 r
.46857 .63461 m .47017 .63337 L .46998 .63323 L F
.466 .295 .564 r
.47018 .63529 m .47258 .6316 L .47097 .63274 L F
.47258 .6316 m .47018 .63529 L .47032 .63348 L F
.47125 .63217 m .47032 .63348 L .47039 .63254 L F
.414 .243 .539 r
.47077 .63284 m .47097 .63274 L .47104 .63246 L F
.466 .295 .564 r
.47258 .6316 m .47104 .63246 L .47125 .63217 L F
0 0 0 r
.47333 .62682 m .47122 .63042 L .47318 .62664 L F
.47335 .62685 m .47311 .62726 L .47333 .62682 L F
.47311 .62726 m .47122 .63042 L .47333 .62682 L F
.502 .212 .406 r
.47039 .63254 m .46985 .63314 L .46959 .63335 L F
.47039 .63254 m .46785 .63512 L .46931 .63325 L F
.414 .243 .539 r
.46906 .63379 m .47032 .63276 L .4719 .62894 L F
.217 .053 .432 r
.47335 .62685 m .47258 .6316 L .47039 .63254 L F
.414 .243 .539 r
.47032 .63276 m .47113 .63209 L .47157 .63028 L F
.217 .053 .432 r
.47335 .62685 m .47039 .63254 L .47122 .63042 L F
.414 .243 .539 r
.47032 .63276 m .47157 .63028 L .4719 .62894 L F
.243 .085 .458 r
.4719 .62894 m .47104 .63246 L .47258 .6316 L F
.47104 .63246 m .47097 .63274 L .47258 .6316 L F
.466 .295 .564 r
.47258 .6316 m .47032 .63348 L .47104 .63246 L F
.502 .212 .406 r
.47039 .63254 m .47032 .63348 L .46985 .63314 L F
.414 .243 .539 r
.46998 .63323 m .47077 .63284 L .47113 .63209 L F
.47077 .63284 m .47104 .63246 L .47113 .63209 L F
.46857 .63461 m .47113 .63209 L .46906 .63379 L F
.502 .212 .406 r
.46992 .63359 m .47018 .63529 L .46733 .63594 L F
.534 .287 .486 r
.46733 .63594 m .47017 .63337 L .46857 .63461 L F
.502 .212 .406 r
.47032 .63348 m .47018 .63529 L .46985 .63314 L F
.534 .287 .486 r
.46733 .63594 m .47097 .63274 L .47017 .63337 L F
.502 .212 .406 r
.46985 .63314 m .46992 .63359 L .46733 .63594 L F
.414 .243 .539 r
.47017 .63337 m .47097 .63274 L .46998 .63323 L F
.502 .212 .406 r
.46959 .63335 m .46953 .6335 L .46932 .63363 L F
.46985 .63314 m .46953 .6335 L .46959 .63335 L F
.46953 .6335 m .46733 .63594 L .46932 .63363 L F
.838 .598 .577 r
.46345 .63213 m .46833 .6345 L .46964 .63043 L F
.46833 .6345 m .46873 .63399 L .46964 .63043 L F
.563 .788 .984 r
.46757 .62876 m .46964 .63043 L .4719 .62894 L F
.556 .291 .469 r
.25666 .62406 m .25918 .62404 L .25987 .62197 L F
.306 .052 .355 r
.25987 .62197 m .25918 .62404 L .26172 .62106 L F
.783 .557 .593 r
.79561 .40448 m .7956 .40685 L .79882 .40692 L F
.373 0 0 r
.7956 .40685 m .79817 .40767 L .79882 .40692 L F
.412 0 0 r
.79817 .40767 m .80157 .40682 L .79882 .40692 L F
.456 .23 .481 r
.2747 .61858 m .27691 .61801 L .27731 .61555 L F
.524 .324 .551 r
.27691 .61801 m .2795 .61489 L .27731 .61555 L F
.268 .773 .781 r
.47545 .62599 m .47318 .62664 L .47362 .62462 L F
.497 .093 .203 r
.47623 .62446 m .47545 .62599 L .47362 .62462 L F
.042 0 0 r
.51492 .52305 m .51727 .52294 L .51762 .52247 L F
.51492 .52305 m .51727 .52294 L .51762 .52247 L F
.218 .377 .81 r
.77177 .41661 m .77292 .41959 L .77428 .41797 L F
.335 .554 .915 r
.77292 .41959 m .77597 .42041 L .77428 .41797 L F
.663 .755 .918 r
.19588 .61063 m .19286 .60983 L .19507 .60862 L F
.592 .742 .947 r
.19707 .60835 m .19588 .61063 L .19507 .60862 L F
.19707 .60835 m .19814 .61011 L .19588 .61063 L F
.839 .976 .878 r
.28632 .56004 m .28822 .55644 L .28577 .55669 L F
.28632 .56004 m .28573 .55881 L .28822 .55644 L F
0 0 .313 r
.28632 .56004 m .28734 .56103 L .28573 .55881 L F
.28632 .56004 m .28648 .56279 L .28734 .56103 L F
.48 .677 .951 r
.80423 .43299 m .80857 .43497 L .80753 .43332 L F
.378 .634 .955 r
.80753 .43332 m .80857 .43497 L .80967 .43331 L F
.127 .289 .759 r
.80967 .43331 m .80857 .43497 L .81092 .43691 L F
.39 .819 .963 r
.23676 .53629 m .23907 .53579 L .24078 .5363 L F
.501 .874 .979 r
.24078 .5363 m .24098 .53513 L .24299 .53588 L F
.24078 .5363 m .23907 .53579 L .24098 .53513 L F
.482 .26 .5 r
.27434 .62093 m .27691 .61801 L .2747 .61858 L F
0 0 .499 r
.1537 .60321 m .15267 .59855 L .15183 .59985 L F
.1537 .60321 m .15404 .60252 L .15267 .59855 L F
.704 .166 0 r
.1558 .60509 m .15423 .60463 L .1537 .60321 L F
0 0 .234 r
.1537 .60321 m .15423 .60463 L .15404 .60252 L F
.583 .903 .983 r
.18958 .79236 m .19189 .79298 L .19195 .79161 L F
.218 .495 .9 r
.26127 .6475 m .26221 .64931 L .26291 .64792 L F
.579 .907 .979 r
.26291 .64792 m .26221 .64931 L .26458 .64835 L F
.26291 .64792 m .26221 .64931 L .26458 .64835 L F
.554 .344 .55 r
.26946 .62454 m .27194 .6242 L .27216 .6215 L F
.53 .35 .581 r
.27194 .6242 m .27434 .62093 L .27216 .6215 L F
.508 .348 .599 r
.46145 .62767 m .46271 .63037 L .46349 .62727 L F
.46145 .62767 m .46165 .63089 L .46271 .63037 L F
.58 .003 0 r
.25888 .66292 m .25855 .66175 L .25693 .66146 L F
.74 .643 .752 r
.46814 .65834 m .47162 .66113 L .4717 .65852 L F
.46814 .65834 m .46925 .6619 L .47162 .66113 L F
.896 .797 .742 r
.83657 .42493 m .83481 .42808 L .83747 .4279 L F
.888 .834 .787 r
.83481 .42808 m .83626 .42974 L .83747 .4279 L F
.858 .51 .393 r
.55856 .52076 m .55869 .52278 L .56171 .52365 L F
.92 .645 .502 r
.55869 .52278 m .56064 .52588 L .56171 .52365 L F
0 .076 .632 r
.18302 .60466 m .18453 .60854 L .1827 .60622 L F
.92 .699 .586 r
.54394 .57434 m .54577 .57575 L .54331 .574 L F
.929 .875 .762 r
.54577 .57575 m .54256 .57775 L .54331 .574 L F
.54577 .57575 m .54395 .57922 L .54256 .57775 L F
.365 .567 .915 r
.78468 .42773 m .78635 .42624 L .78265 .42556 L F
.78468 .42773 m .78688 .42805 L .78635 .42624 L F
0 0 .1 r
.28055 .60117 m .27992 .59984 L .28087 .59869 L F
.28055 .60117 m .27949 .60227 L .27992 .59984 L F
.509 .349 .599 r
.32276 .60885 m .32284 .6115 L .32048 .60945 L F
.37 .346 .702 r
.32284 .6115 m .32126 .61241 L .32048 .60945 L F
.562 .375 .585 r
.48106 .61543 m .48117 .61803 L .48392 .61516 L F
.48106 .61543 m .48117 .61803 L .48392 .61516 L F
.66 .45 .589 r
.47904 .61754 m .48117 .61803 L .48106 .61543 L F
0 0 .262 r
.28371 .57258 m .28543 .57133 L .28517 .56934 L F
.281 .073 .41 r
.28268 .5746 m .28543 .57133 L .28371 .57258 L F
.469 .274 .532 r
.32525 .60309 m .32515 .60569 L .32293 .60624 L F
.508 .319 .559 r
.32515 .60569 m .32276 .60885 L .32293 .60624 L F
.637 .696 .888 r
.44958 .67441 m .45166 .67334 L .44776 .67244 L F
0 .524 .818 r
.53337 .52044 m .53466 .52047 L .5348 .52072 L F
.001 0 0 r
.53457 .5207 m .53337 .52044 L .53229 .52075 L F
.53457 .5207 m .53466 .52047 L .53337 .52044 L F
.057 0 0 r
.53761 .52432 m .53608 .52501 L .53356 .52537 L F
.662 .134 0 r
.53761 .52432 m .53955 .52585 L .53608 .52501 L F
.572 .278 .43 r
.53964 .52442 m .53955 .52585 L .53761 .52432 L F
.786 .681 .748 r
.78997 .41569 m .79182 .41701 L .7883 .41645 L F
.745 .82 .91 r
.79182 .41701 m .78684 .41819 L .7883 .41645 L F
.771 .685 .768 r
.79421 .41403 m .79182 .41701 L .78997 .41569 L F
.825 .361 .112 r
.55192 .51813 m .55263 .51729 L .55105 .51752 L F
.55192 .51813 m .55482 .52001 L .55263 .51729 L F
.771 .623 .696 r
.46814 .65834 m .4717 .65852 L .4704 .65463 L F
.388 .795 .982 r
.21859 .62095 m .21803 .62203 L .21651 .6203 L F
.21859 .62095 m .22023 .6217 L .21803 .62203 L F
.568 .294 .46 r
.28849 .64007 m .28827 .64233 L .28586 .6424 L F
.531 .224 .393 r
.29233 .63918 m .28827 .64233 L .28849 .64007 L F
.757 .675 .772 r
.8366 .40697 m .83791 .41092 L .83421 .41015 L F
.701 .682 .828 r
.83934 .40628 m .83791 .41092 L .8366 .40697 L F
.83934 .40628 m .84118 .40958 L .83791 .41092 L F
.969 .721 .508 r
.79411 .40335 m .7956 .40685 L .79561 .40448 L F
.253 .34 .76 r
.76781 .41301 m .7689 .4168 L .77053 .41501 L F
.501 .728 .975 r
.7689 .4168 m .77177 .41661 L .77053 .41501 L F
.919 .727 .627 r
.55218 .53577 m .54932 .53757 L .54886 .53518 L F
.55218 .53577 m .55185 .53869 L .54932 .53757 L F
.811 .583 .593 r
.45418 .67284 m .4582 .67397 L .45801 .67045 L F
.515 .355 .603 r
.45801 .67045 m .46056 .67329 L .46007 .67102 L F
.522 .318 .544 r
.46063 .66857 m .46007 .67102 L .45801 .67045 L F
.643 .778 .945 r
.24318 .55052 m .24716 .55117 L .24558 .54951 L F
.469 .256 .506 r
.24318 .55052 m .24558 .54951 L .24716 .55117 L F
.497 .728 .975 r
.24716 .55117 m .24775 .54923 L .24558 .54951 L F
.24716 .55117 m .24901 .55076 L .24775 .54923 L F
.24716 .55117 m .24775 .54923 L .24558 .54951 L F
.24716 .55117 m .24901 .55076 L .24775 .54923 L F
.63 .479 .658 r
.22438 .72534 m .22721 .72289 L .22415 .72298 L F
.327 .029 .296 r
.80752 .40404 m .80956 .40373 L .81025 .40145 L F
0 0 .124 r
.81025 .40145 m .81194 .40154 L .81281 .40052 L F
.81025 .40145 m .80956 .40373 L .81194 .40154 L F
.263 .658 .967 r
.22141 .64064 m .22205 .63959 L .22035 .63902 L F
.22141 .64064 m .2249 .64101 L .22205 .63959 L F
.993 .779 .507 r
.2942 .59746 m .29459 .5993 L .29531 .59729 L F
.524 .028 0 r
.29633 .59808 m .29539 .59705 L .29459 .5993 L F
.728 .649 .771 r
.2913 .59907 m .29459 .5993 L .2942 .59746 L F
.683 .972 .916 r
.29189 .59761 m .2913 .59907 L .2942 .59746 L F
.326 0 0 r
.2942 .59746 m .29633 .59808 L .29265 .59769 L F
.2942 .59746 m .29265 .59769 L .29189 .59761 L F
.993 .779 .507 r
.2942 .59746 m .29531 .59729 L .29539 .59705 L F
0 0 .488 r
.29627 .59298 m .29539 .59705 L .29448 .59361 L F
.29627 .59298 m .29663 .59609 L .29539 .59705 L F
.431 .163 .404 r
.29663 .59609 m .2942 .59746 L .29539 .59705 L F
.524 .028 0 r
.29633 .59808 m .29684 .59861 L .29539 .59705 L F
.44 0 0 r
.29539 .59705 m .29684 .59861 L .29798 .59725 L F
.777 .545 .584 r
.79264 .40731 m .78923 .40955 L .78902 .40703 L F
.79264 .40731 m .79291 .41025 L .78923 .40955 L F
.532 .831 .999 r
.79264 .40731 m .79415 .40595 L .7956 .40685 L F
.601 .415 .602 r
.7956 .40685 m .79291 .41025 L .79264 .40731 L F
.832 .972 .661 r
.54222 .58104 m .54151 .58229 L .54207 .58034 L F
0 0 .375 r
.5404 .58417 m .54207 .58034 L .54151 .58229 L F
.678 .946 .959 r
.26257 .54588 m .26235 .5475 L .26444 .54717 L F
.26257 .54588 m .26047 .54711 L .26235 .5475 L F
.342 .262 .619 r
.26235 .5475 m .26447 .55005 L .26444 .54717 L F
.26235 .5475 m .26289 .55101 L .26447 .55005 L F
.857 .926 .539 r
.34074 .56217 m .33897 .56641 L .34128 .56247 L F
.34074 .56217 m .33891 .5659 L .33897 .56641 L F
0 0 .505 r
.50968 .60531 m .50965 .60858 L .51133 .60631 L F
.692 .463 .57 r
.33571 .57089 m .33402 .56953 L .33622 .56857 L F
.783 .548 .581 r
.33402 .56953 m .33365 .5721 L .33733 .57244 L F
.692 .463 .57 r
.33571 .57089 m .33365 .5721 L .33402 .56953 L F
0 0 0 r
.20527 .54147 m .2095 .5399 L .20662 .54107 L F
.20527 .54147 m .20753 .54092 L .2095 .5399 L F
.2095 .5399 m .20968 .54018 L .21113 .53978 L F
.2095 .5399 m .20753 .54092 L .20968 .54018 L F
.877 .882 .834 r
.21728 .74995 m .21796 .74606 L .216 .74732 L F
.21728 .74995 m .21972 .74685 L .21796 .74606 L F
.954 .828 .682 r
.56194 .53527 m .56265 .53858 L .56347 .53623 L F
.585 .411 .613 r
.30545 .63037 m .30291 .63323 L .30291 .63076 L F
0 .487 .865 r
.17863 .61913 m .17953 .61879 L .17725 .61777 L F
.17863 .61913 m .1817 .6202 L .17953 .61879 L F
.025 .476 .877 r
.215 .619 m .21426 .61956 L .21235 .61845 L F
.215 .619 m .21651 .6203 L .21426 .61956 L F
.556 .151 .229 r
.25258 .62613 m .25508 .62636 L .25666 .62406 L F
0 0 0 r
.25666 .62406 m .25705 .62508 L .25918 .62404 L F
.25666 .62406 m .25508 .62636 L .25705 .62508 L F
.20297 .54185 m .20527 .54147 L .20662 .54107 L F
.26443 .61544 m .26243 .61865 L .26326 .61778 L F
.26688 .61238 m .26443 .61544 L .2658 .61416 L F
.019 0 .114 r
.26443 .61544 m .26519 .61681 L .2658 .61416 L F
.26443 .61544 m .26326 .61778 L .26519 .61681 L F
.736 .908 .534 r
.27547 .59385 m .27345 .59702 L .27456 .59611 L F
.218 .017 .379 r
.27345 .59702 m .27459 .59858 L .27456 .59611 L F
.27345 .59702 m .27291 .59951 L .27459 .59858 L F
.831 .84 .854 r
.83214 .43102 m .83626 .42974 L .83481 .42808 L F
.605 .322 .461 r
.80157 .40682 m .80421 .40718 L .80502 .40454 L F
.761 .549 .61 r
.80421 .40718 m .80752 .40404 L .80502 .40454 L F
.71 .749 .882 r
.56322 .58709 m .56467 .58839 L .56706 .58784 L F
.632 .375 .512 r
.56467 .58839 m .56714 .59022 L .56706 .58784 L F
.466 .53 .839 r
.24112 .68855 m .24292 .69276 L .24393 .68996 L F
.741 .546 .63 r
.83657 .39412 m .84 .39458 L .84027 .39216 L F
.57 .377 .581 r
.31019 .57886 m .3131 .57849 L .3133 .57562 L F
.539 .249 .423 r
.31019 .57886 m .31268 .58031 L .3131 .57849 L F
.31019 .57886 m .30992 .58097 L .31268 .58031 L F
0 .223 .669 r
.54768 .52907 m .54363 .52633 L .54669 .5269 L F
.489 .322 .581 r
.32726 .60214 m .32515 .60569 L .32525 .60309 L F
.6 .65 .871 r
.3023 .58574 m .30591 .58772 L .30496 .58479 L F
.533 .54 .808 r
.30496 .58479 m .30591 .58772 L .30822 .58674 L F
.453 .307 .591 r
.30591 .58772 m .3082 .58961 L .30822 .58674 L F
.30591 .58772 m .30603 .59047 L .3082 .58961 L F
.341 .812 .739 r
.24997 .68982 m .25195 .68919 L .25382 .68838 L F
.258 0 0 r
.17941 .55357 m .18181 .55319 L .18343 .55158 L F
.078 0 0 r
.18181 .55319 m .18579 .55106 L .18343 .55158 L F
.58 .523 .756 r
.31867 .54373 m .32038 .54188 L .32223 .54502 L F
0 0 0 r
.3249 .55726 m .32372 .55966 L .32322 .55978 L F
.75 .729 .833 r
.32484 .54303 m .32223 .54502 L .32038 .54188 L F
.636 .603 .8 r
.32729 .55427 m .3249 .55726 L .32757 .5568 L F
.673 .575 .737 r
.3249 .55726 m .32869 .56027 L .32757 .5568 L F
.308 0 .108 r
.32757 .5568 m .32372 .55966 L .3249 .55726 L F
.636 .603 .8 r
.32729 .55427 m .3249 .55726 L .32757 .5568 L F
.96 .726 .539 r
.19289 .62702 m .19439 .63055 L .19254 .62976 L F
.157 .507 .912 r
.19439 .63055 m .19469 .62925 L .19254 .62976 L F
.19439 .63055 m .19559 .63049 L .19469 .62925 L F
.794 .779 .839 r
.25628 .67053 m .25796 .67365 L .25314 .67278 L F
.794 .522 .526 r
.25796 .67365 m .25335 .67543 L .25314 .67278 L F
.25796 .67365 m .25735 .67597 L .25335 .67543 L F
.49 .52 .815 r
.2586 .66918 m .25796 .67365 L .25628 .67053 L F
.2586 .66918 m .26028 .67308 L .25796 .67365 L F
.362 .105 .384 r
.26028 .67308 m .25735 .67597 L .25796 .67365 L F
.771 .685 .768 r
.79421 .41403 m .78997 .41569 L .79263 .41227 L F
.073 0 .292 r
.26243 .61865 m .26288 .62005 L .26326 .61778 L F
.26243 .61865 m .26172 .62106 L .26288 .62005 L F
.383 .619 .945 r
.1817 .6202 m .18271 .62171 L .18344 .62006 L F
.277 .492 .886 r
.18271 .62171 m .18584 .62373 L .18344 .62006 L F
.197 .678 .931 r
.23821 .64235 m .23662 .64163 L .23438 .64135 L F
.276 .761 .92 r
.2407 .64177 m .23662 .64163 L .23821 .64235 L F
.187 .126 .552 r
.28154 .57818 m .28268 .5746 L .28084 .57574 L F
.979 .721 .469 r
.26785 .62357 m .26897 .62672 L .26946 .62454 L F
.579 .278 .423 r
.26897 .62672 m .27155 .62659 L .26946 .62454 L F
.979 .721 .469 r
.26785 .62357 m .26897 .62672 L .26946 .62454 L F
.534 .282 .48 r
.26946 .62454 m .27155 .62659 L .27194 .6242 L F
.766 .761 .848 r
.83079 .40985 m .82938 .41419 L .82795 .41217 L F
.83079 .40985 m .83142 .41298 L .82938 .41419 L F
.718 .815 .925 r
.25215 .66672 m .25636 .66713 L .25441 .66577 L F
.73 .812 .916 r
.25636 .66713 m .2566 .66349 L .25441 .66577 L F
.25636 .66713 m .25785 .66624 L .2566 .66349 L F
.168 .01 .408 r
.33365 .5721 m .33483 .57203 L .33733 .57244 L F
0 .209 .685 r
.33852 .57287 m .33993 .57422 L .33733 .57244 L F
.33852 .57287 m .33733 .57244 L .33483 .57203 L F
.401 .616 .938 r
.17297 .61487 m .17147 .61171 L .16961 .61203 L F
.17297 .61487 m .17424 .61429 L .17147 .61171 L F
.492 .353 .621 r
.8147 .40673 m .81502 .40924 L .81224 .41001 L F
.584 .46 .678 r
.81568 .41305 m .81224 .41001 L .81502 .40924 L F
.81568 .41305 m .81289 .41398 L .81224 .41001 L F
.197 .342 .785 r
.78048 .42565 m .78191 .42401 L .77912 .42208 L F
.386 .631 .951 r
.78048 .42565 m .78265 .42556 L .78191 .42401 L F
.815 .473 .409 r
.55516 .52188 m .55856 .52076 L .55482 .52001 L F
.55516 .52188 m .55869 .52278 L .55856 .52076 L F
.888 .933 .842 r
.21972 .74685 m .21911 .74429 L .21796 .74606 L F
.144 0 0 r
.50471 .55573 m .5075 .55559 L .5089 .55471 L F
0 0 .567 r
.50992 .55503 m .51032 .55709 L .5089 .55471 L F
.50992 .55503 m .5089 .55471 L .5075 .55559 L F
0 0 0 r
.24299 .53588 m .24544 .53564 L .24686 .53542 L F
.387 .844 .898 r
.24544 .53564 m .24914 .53504 L .24686 .53542 L F
.437 .418 .74 r
.334 .54469 m .3326 .54678 L .33102 .54483 L F
.334 .54469 m .33456 .54737 L .3326 .54678 L F
.571 .435 .657 r
.32284 .6115 m .32065 .61479 L .32126 .61241 L F
.106 0 0 r
.27392 .53409 m .27624 .53402 L .27832 .53356 L F
.263 .767 .743 r
.27832 .53356 m .27855 .5333 L .28045 .53291 L F
.27832 .53356 m .27624 .53402 L .27855 .5333 L F
.557 .367 .579 r
.3133 .57562 m .31517 .57787 L .31484 .57477 L F
.3133 .57562 m .3131 .57849 L .31517 .57787 L F
.597 .571 .795 r
.23767 .70059 m .23552 .70097 L .23577 .70243 L F
.28 0 .189 r
.16674 .56245 m .16741 .56459 L .16884 .56204 L F
.16674 .56245 m .16539 .56523 L .16741 .56459 L F
0 0 0 r
.26688 .61238 m .26732 .61347 L .26811 .61115 L F
.26688 .61238 m .2658 .61416 L .26732 .61347 L F
.432 .805 .993 r
.2909 .54785 m .28925 .54705 L .28699 .54745 L F
.97 .69 .445 r
.28925 .54705 m .29078 .5503 L .2909 .54785 L F
.47 .823 .997 r
.29318 .54734 m .28925 .54705 L .2909 .54785 L F
.575 .378 .577 r
.29078 .5503 m .29318 .54734 L .2909 .54785 L F
.496 .762 .99 r
.47287 .65418 m .47151 .65284 L .4704 .65463 L F
.47287 .65418 m .47151 .65284 L .4704 .65463 L F
.71 .749 .882 r
.56322 .58709 m .56706 .58784 L .5657 .58408 L F
.957 .902 .727 r
.34185 .56071 m .34074 .56217 L .34128 .56247 L F
.43 .407 .733 r
.32869 .56027 m .32964 .55637 L .32757 .5568 L F
.32869 .56027 m .33081 .56014 L .32964 .55637 L F
.541 .568 .831 r
.32869 .56027 m .33242 .56325 L .33081 .56014 L F
.891 .574 .442 r
.50077 .55676 m .49897 .55669 L .4991 .55446 L F
.82 .351 .099 r
.50077 .55676 m .49982 .55796 L .49897 .55669 L F
.50077 .55676 m .50272 .55942 L .49982 .55796 L F
.568 .38 .587 r
.31581 .61831 m .31599 .62109 L .31329 .62144 L F
.345 .214 .555 r
.31774 .62026 m .31581 .61831 L .31827 .61821 L F
.31774 .62026 m .31599 .62109 L .31581 .61831 L F
.96 .636 .353 r
.46056 .67329 m .46134 .67252 L .46007 .67102 L F
.843 .781 .279 r
.54222 .58104 m .54256 .57775 L .54395 .57922 L F
.971 .708 .476 r
.83021 .39634 m .83136 .3951 L .82987 .39488 L F
.83021 .39634 m .83164 .39796 L .83136 .3951 L F
.91 .682 .581 r
.5565 .56785 m .55913 .56626 L .55749 .5648 L F
.5565 .56785 m .55924 .5697 L .55913 .56626 L F
.761 .549 .61 r
.80421 .40718 m .808 .40706 L .80752 .40404 L F
.472 .35 .632 r
.80752 .40404 m .80997 .40567 L .80956 .40373 L F
.80752 .40404 m .808 .40706 L .80997 .40567 L F
.369 .125 .407 r
.4991 .55446 m .50171 .55542 L .50173 .55428 L F
.4991 .55446 m .49897 .55669 L .50171 .55542 L F
.467 .222 .459 r
.33291 .59388 m .33246 .59643 L .33013 .59689 L F
.479 .234 .463 r
.33493 .59577 m .33246 .59643 L .33291 .59388 L F
.802 .921 .917 r
.23343 .71204 m .23091 .71481 L .2343 .71415 L F
.744 .68 .788 r
.25306 .6816 m .25269 .68339 L .25016 .68264 L F
.464 .405 .707 r
.25518 .6818 m .25269 .68339 L .25306 .6816 L F
.23 .339 .769 r
.25548 .68428 m .25269 .68339 L .25518 .6818 L F
.25548 .68428 m .25397 .68557 L .25269 .68339 L F
.558 .399 .622 r
.42774 .65577 m .42658 .65499 L .42895 .65501 L F
.779 .769 .844 r
.83421 .41015 m .83142 .41298 L .83079 .40985 L F
.44 .241 .513 r
.33678 .5844 m .33683 .58594 L .33461 .58651 L F
0 0 0 r
.22518 .72837 m .22291 .73102 L .22485 .73083 L F
.835 .787 .806 r
.2236 .73502 m .22485 .73083 L .22291 .73102 L F
.73 .799 .907 r
.55204 .59366 m .55605 .59408 L .55424 .59278 L F
.828 .794 .82 r
.55424 .59278 m .55605 .59408 L .55849 .59091 L F
.472 .296 .561 r
.15835 .5688 m .16054 .5688 L .16104 .5678 L F
.15835 .5688 m .15841 .56942 L .16054 .5688 L F
0 .204 .645 r
.51344 .56374 m .51287 .56324 L .51063 .56351 L F
.51344 .56374 m .51537 .56501 L .51287 .56324 L F
.51287 .56324 m .51537 .56501 L .51344 .56374 L F
.763 .551 .61 r
.54374 .52347 m .53955 .52585 L .53964 .52442 L F
.54374 .52347 m .54363 .52633 L .53955 .52585 L F
.421 .504 .839 r
.54267 .59018 m .54308 .5865 L .54072 .58705 L F
.54267 .59018 m .5446 .58996 L .54308 .5865 L F
.455 .828 .992 r
.24914 .53504 m .25144 .53456 L .25326 .53524 L F
.187 .678 .922 r
.25144 .53456 m .25539 .5353 L .25326 .53524 L F
.472 .241 .481 r
.31329 .62144 m .313 .62389 L .3107 .6244 L F
.562 .317 .503 r
.31567 .62344 m .31329 .62144 L .31599 .62109 L F
.31567 .62344 m .313 .62389 L .31329 .62144 L F
.181 .699 .884 r
.23815 .62631 m .23426 .62604 L .23668 .62575 L F
.382 .799 .976 r
.2401 .62592 m .23815 .62631 L .23668 .62575 L F
.491 .688 .955 r
.31557 .53882 m .3151 .54126 L .31246 .53897 L F
.31557 .53882 m .31698 .54071 L .3151 .54126 L F
.717 .984 .797 r
.22264 .74253 m .22222 .7438 L .22132 .74391 L F
.484 .276 .522 r
.17445 .57741 m .17276 .58062 L .17284 .57847 L F
.038 0 0 r
.21405 .53878 m .21789 .53855 L .21563 .53892 L F
.157 .602 .933 r
.32742 .54321 m .33102 .54483 L .32847 .54493 L F
.537 .918 .78 r
.31631 .5714 m .31538 .57221 L .31748 .57162 L F
.458 .201 .435 r
.31538 .57221 m .31716 .57421 L .31748 .57162 L F
.31538 .57221 m .31484 .57477 L .31716 .57421 L F
.748 .975 .923 r
.31786 .56977 m .3159 .57133 L .31748 .57162 L F
.499 .266 .492 r
.31716 .57421 m .31993 .57095 L .31748 .57162 L F
.31716 .57421 m .31954 .57373 L .31993 .57095 L F
.476 .451 .751 r
.31723 .57112 m .31829 .57392 L .31565 .57452 L F
.31786 .56977 m .31798 .57089 L .31723 .57112 L F
.572 .836 .995 r
.31786 .56977 m .31748 .57162 L .31993 .57095 L F
.476 .451 .751 r
.31798 .57089 m .31829 .57392 L .31723 .57112 L F
.537 .918 .78 r
.3159 .57133 m .31576 .57157 L .31631 .5714 L F
.31576 .57157 m .31538 .57221 L .31631 .5714 L F
.516 .053 .093 r
.54099 .5186 m .54481 .51714 L .54235 .51703 L F
.676 .633 .8 r
.78598 .41548 m .78501 .4186 L .78413 .41587 L F
.78598 .41548 m .78684 .41819 L .78501 .4186 L F
.636 .938 .963 r
.82202 .40131 m .82009 .40333 L .82312 .40234 L F
.82202 .40131 m .81922 .40278 L .82009 .40333 L F
.328 .725 .982 r
.23 .62499 m .22798 .62517 L .22621 .62416 L F
.783 .762 .835 r
.81767 .41176 m .81912 .4134 L .81568 .41305 L F
.862 .88 .849 r
.8206 .409 m .81912 .4134 L .81767 .41176 L F
.8206 .409 m .82161 .41042 L .81912 .4134 L F
.349 .792 .959 r
.20462 .63795 m .20639 .63723 L .20375 .6363 L F
.20462 .63795 m .20837 .63784 L .20639 .63723 L F
.483 .217 .435 r
.47939 .62167 m .47895 .624 L .47623 .62446 L F
.109 0 .366 r
.48117 .61803 m .48117 .62071 L .47939 .62167 L F
.156 0 .316 r
.48062 .62287 m .47939 .62167 L .48117 .62071 L F
.48062 .62287 m .47895 .624 L .47939 .62167 L F
.799 .746 .803 r
.55795 .54745 m .55531 .55047 L .55844 .55053 L F
.937 .789 .671 r
.55568 .55306 m .55844 .55053 L .55531 .55047 L F
.55568 .55306 m .55765 .55426 L .55844 .55053 L F
.931 .776 .667 r
.56045 .53137 m .56341 .52942 L .56152 .52824 L F
.56045 .53137 m .56217 .53239 L .56341 .52942 L F
.627 .689 .888 r
.18584 .62373 m .18665 .62488 L .18893 .62417 L F
0 0 .305 r
.21645 .55526 m .21564 .55412 L .21751 .55323 L F
.58 .223 .328 r
.27829 .64536 m .27968 .64286 L .28165 .64475 L F
.586 .222 .318 r
.27968 .64286 m .28217 .643 L .28165 .64475 L F
.308 .742 .969 r
.46246 .63379 m .4611 .63302 L .45864 .63313 L F
.177 .362 .81 r
.46246 .63379 m .46345 .63213 L .4611 .63302 L F
.46246 .63379 m .46496 .63492 L .46345 .63213 L F
.75 .657 .759 r
.83283 .40406 m .83387 .40739 L .83049 .40673 L F
.988 .724 .42 r
.83387 .40739 m .83331 .40738 L .83049 .40673 L F
.83387 .40739 m .83421 .41015 L .83331 .40738 L F
.618 .566 .773 r
.8356 .40318 m .83387 .40739 L .83283 .40406 L F
.8356 .40318 m .8366 .40697 L .83387 .40739 L F
.6 .452 .653 r
.8366 .40697 m .83421 .41015 L .83387 .40739 L F
0 0 .208 r
.28517 .56934 m .28591 .5703 L .28624 .56794 L F
.28517 .56934 m .28543 .57133 L .28591 .5703 L F
.525 .302 .517 r
.32981 .56592 m .33223 .56565 L .33242 .56325 L F
.499 .539 .829 r
.33242 .56325 m .33315 .55929 L .33081 .56014 L F
.33242 .56325 m .33444 .56265 L .33315 .55929 L F
.561 .405 .628 r
.33223 .56565 m .33444 .56265 L .33242 .56325 L F
.955 .727 .553 r
.55632 .55936 m .55775 .56339 L .55791 .56016 L F
.799 .601 .634 r
.42705 .65673 m .42774 .65577 L .42895 .65501 L F
.351 .126 .426 r
.26035 .55378 m .26252 .55322 L .26289 .55101 L F
.919 .975 .699 r
.34282 .5571 m .34152 .56026 L .34192 .56044 L F
.853 .855 .843 r
.33988 .56039 m .34074 .56217 L .34282 .5571 L F
.33988 .56039 m .34282 .5571 L .34257 .55963 L F
.476 .895 .826 r
.3413 .55882 m .34043 .55979 L .34257 .55963 L F
.34043 .55979 m .33988 .56039 L .34105 .56006 L F
.34043 .55979 m .34105 .56006 L .34257 .55963 L F
.919 .975 .699 r
.34192 .56044 m .34074 .56217 L .34185 .56071 L F
.34152 .56026 m .34074 .56217 L .34192 .56044 L F
.209 0 .283 r
.49539 .60662 m .49464 .60859 L .49712 .60551 L F
.553 .751 .969 r
.16012 .60603 m .16057 .60376 L .15835 .60403 L F
.16012 .60603 m .16232 .6055 L .16057 .60376 L F
.663 .637 .813 r
.54953 .59612 m .55204 .59366 L .54838 .59328 L F
.616 .69 .896 r
.81188 .43886 m .81341 .43606 L .81092 .43691 L F
.81188 .43886 m .81482 .43804 L .81341 .43606 L F
.477 .306 .57 r
.3435 .57755 m .34174 .57885 L .3419 .57864 L F
.795 .783 .842 r
.83374 .42131 m .83651 .42248 L .8363 .41894 L F
.889 .617 .519 r
.83657 .42493 m .83651 .42248 L .83374 .42131 L F
.857 .827 .817 r
.8363 .41894 m .83651 .42248 L .83903 .41914 L F
.556 .316 .506 r
.2998 .63638 m .29689 .63927 L .29738 .63675 L F
.93 .75 .636 r
.4626 .64879 m .46106 .64865 L .46201 .64656 L F
.887 .532 .369 r
.4626 .64879 m .46113 .65059 L .46106 .64865 L F
.552 .562 .817 r
.4626 .64879 m .46397 .64587 L .46201 .64656 L F
.4626 .64879 m .46459 .64829 L .46397 .64587 L F
.839 .917 .887 r
.4626 .64879 m .46397 .64587 L .46459 .64829 L F
.4626 .64879 m .46106 .64865 L .46397 .64587 L F
.591 .14 .149 r
.46467 .65043 m .4626 .64879 L .46459 .64829 L F
.46467 .65043 m .46113 .65059 L .4626 .64879 L F
.539 .324 .537 r
.3107 .6244 m .31051 .62696 L .30808 .62738 L F
.538 .324 .537 r
.31294 .62654 m .3107 .6244 L .313 .62389 L F
.31294 .62654 m .31051 .62696 L .3107 .6244 L F
.531 .224 .393 r
.29233 .63918 m .2907 .64223 L .28827 .64233 L F
.522 .216 .389 r
.2947 .63904 m .2907 .64223 L .29233 .63918 L F
.942 .842 .715 r
.84158 .41599 m .84247 .41384 L .84111 .41254 L F
.278 .434 .838 r
.16806 .61187 m .16786 .60832 L .16576 .60902 L F
.16806 .61187 m .16961 .61203 L .16786 .60832 L F
.578 .582 .82 r
.34072 .58786 m .33856 .59005 L .33683 .58594 L F
.52 .685 .942 r
.34044 .58928 m .33856 .59005 L .34072 .58786 L F
0 0 .534 r
.22438 .72534 m .22518 .72837 L .22597 .72755 L F
.194 .277 .721 r
.25548 .68428 m .25616 .68779 L .25397 .68557 L F
.518 .328 .563 r
.25397 .68557 m .25616 .68779 L .25382 .68838 L F
.553 .017 0 r
.55278 .5509 m .55152 .54999 L .54967 .5483 L F
.745 .863 .934 r
.55278 .5509 m .54939 .55117 L .55152 .54999 L F
.425 .651 .953 r
.24263 .69885 m .24643 .69997 L .24463 .70032 L F
.328 .189 .535 r
.24639 .70272 m .24463 .70032 L .24643 .69997 L F
.24639 .70272 m .2446 .70391 L .24463 .70032 L F
.633 .731 .918 r
.77788 .41636 m .77533 .41716 L .77523 .41554 L F
0 0 0 r
.22672 .55028 m .22298 .55253 L .22448 .55063 L F
.835 .787 .806 r
.2236 .73502 m .22593 .7323 L .22485 .73083 L F
.397 .033 .225 r
.19617 .56307 m .19441 .56551 L .19199 .56592 L F
.036 0 0 r
.19622 .5645 m .19617 .56307 L .19822 .56274 L F
.19622 .5645 m .19441 .56551 L .19617 .56307 L F
.477 .017 .081 r
.32577 .56769 m .3282 .56772 L .32981 .56592 L F
.439 .002 .108 r
.3282 .56772 m .33223 .56565 L .32981 .56592 L F
.502 .2 .386 r
.27456 .59611 m .27789 .59369 L .27547 .59385 L F
.607 .875 .992 r
.78785 .4032 m .78518 .40413 L .78681 .40221 L F
.918 .727 .629 r
.78785 .4032 m .78749 .4055 L .78518 .40413 L F
.001 .375 .839 r
.78518 .40413 m .78685 .404 L .78681 .40221 L F
.78518 .40413 m .78749 .4055 L .78685 .404 L F
.562 .412 .635 r
.33246 .59643 m .33021 .59948 L .33013 .59689 L F
.312 0 0 r
.47529 .61844 m .47759 .61827 L .47904 .61754 L F
.639 .234 .26 r
.47904 .61754 m .47759 .61827 L .48117 .61803 L F
.727 .784 .898 r
.81482 .43804 m .81843 .4384 L .81721 .43677 L F
.788 .824 .88 r
.81721 .43677 m .81843 .4384 L .82015 .4371 L F
0 0 .129 r
.27717 .60564 m .27705 .60798 L .27586 .60914 L F
0 0 .092 r
.27638 .61029 m .27586 .60914 L .27705 .60798 L F
.27638 .61029 m .27531 .61168 L .27586 .60914 L F
.236 .676 .957 r
.20837 .63784 m .20785 .63676 L .20639 .63723 L F
.20837 .63784 m .2098 .63745 L .20785 .63676 L F
.121 0 0 r
.18453 .60854 m .18877 .60893 L .18654 .61076 L F
.5 .764 .99 r
.1779 .59622 m .17744 .59787 L .176 .59592 L F
.1779 .59622 m .1796 .59738 L .17744 .59787 L F
.554 .213 .344 r
.81554 .40045 m .81892 .40021 L .81886 .39793 L F
.354 .05 .303 r
.81892 .40021 m .82138 .39712 L .81886 .39793 L F
.028 0 0 r
.30496 .58479 m .30211 .58705 L .3023 .58574 L F
.747 .524 .592 r
.34637 .56929 m .34516 .57139 L .34447 .56847 L F
.34637 .56929 m .34645 .5719 L .34516 .57139 L F
.842 .809 .819 r
.34903 .56622 m .34637 .56929 L .34447 .56847 L F
.54 .341 .559 r
.34903 .56622 m .34894 .56886 L .34637 .56929 L F
.399 .176 .456 r
.34894 .56886 m .34645 .5719 L .34637 .56929 L F
.856 .828 .82 r
.8363 .41894 m .83903 .41914 L .83762 .41772 L F
.844 .828 .832 r
.83762 .41772 m .83903 .41914 L .84158 .41599 L F
.842 .809 .819 r
.34903 .56622 m .34447 .56847 L .34719 .5652 L F
.503 .822 1 r
.34903 .56622 m .34719 .5652 L .3496 .56528 L F
.287 .139 .499 r
.35069 .56801 m .34903 .56622 L .3496 .56528 L F
.35069 .56801 m .34894 .56886 L .34903 .56622 L F
.609 .152 .143 r
.54481 .51714 m .5473 .51876 L .54861 .51707 L F
.536 .071 .097 r
.54861 .51707 m .55176 .5184 L .55105 .51752 L F
.54861 .51707 m .5473 .51876 L .55176 .5184 L F
.84 .977 .877 r
.82821 .39978 m .82885 .40074 L .83164 .39796 L F
.516 .8 .997 r
.24675 .6842 m .24785 .6859 L .24451 .68551 L F
.511 .813 1 r
.78785 .4032 m .79054 .4026 L .7915 .40365 L F
.775 .661 .737 r
.7915 .40365 m .78902 .40703 L .78785 .4032 L F
.289 .765 .932 r
.25539 .5353 m .25761 .53503 L .25937 .53546 L F
.435 .82 .988 r
.25761 .53503 m .26165 .53528 L .25937 .53546 L F
0 0 0 r
.15841 .56942 m .15567 .57218 L .15734 .57108 L F
.151 0 .001 r
.15734 .57108 m .16054 .5688 L .15841 .56942 L F
.283 .195 .576 r
.14823 .58654 m .14677 .59094 L .1492 .58899 L F
.456 .422 .733 r
.14741 .59344 m .1492 .58899 L .14677 .59094 L F
.606 .784 .966 r
.80081 .43237 m .80423 .43299 L .80316 .43146 L F
.459 .657 .946 r
.80423 .43299 m .80592 .43136 L .80316 .43146 L F
.80423 .43299 m .80753 .43332 L .80592 .43136 L F
.586 .249 .366 r
.49067 .58768 m .49278 .58928 L .49319 .5877 L F
.366 .307 .658 r
.49067 .58768 m .49163 .59075 L .49278 .58928 L F
.586 .249 .366 r
.49067 .58768 m .49278 .58928 L .49319 .5877 L F
.464 .141 .333 r
.19199 .56592 m .18904 .56809 L .18959 .56618 L F
.828 .794 .82 r
.55424 .59278 m .55849 .59091 L .55705 .58982 L F
.222 .307 .74 r
.32374 .53921 m .32381 .5394 L .32263 .54137 L F
.75 .729 .833 r
.32484 .54303 m .32206 .54231 L .32263 .54137 L F
.718 .227 .074 r
.32263 .54137 m .32742 .54321 L .32484 .54303 L F
.32263 .54137 m .32547 .54396 L .32742 .54321 L F
.222 .307 .74 r
.32381 .5394 m .32547 .54396 L .32263 .54137 L F
.75 .729 .833 r
.32206 .54231 m .32038 .54188 L .32263 .54137 L F
.138 .466 .891 r
.17594 .61749 m .17625 .61625 L .17424 .61429 L F
.17594 .61749 m .17725 .61777 L .17625 .61625 L F
.764 .706 .798 r
.83934 .40628 m .84296 .40685 L .84118 .40958 L F
.333 .157 .487 r
.84118 .40958 m .84296 .40685 L .84285 .40833 L F
.935 .781 .665 r
.46397 .64587 m .46459 .64829 L .4657 .64591 L F
.891 .816 .768 r
.55416 .5419 m .55041 .54399 L .55227 .54085 L F
.55416 .5419 m .5521 .54533 L .55041 .54399 L F
0 .535 .781 r
.25785 .66624 m .26235 .66705 L .26045 .66653 L F
.304 .149 .499 r
.26045 .66653 m .25785 .66624 L .2586 .66918 L F
.26045 .66653 m .25785 .66624 L .2586 .66918 L F
.892 .803 .754 r
.56098 .53756 m .56265 .53858 L .56194 .53527 L F
.946 .867 .728 r
.5597 .54081 m .56265 .53858 L .56098 .53756 L F
.5597 .54081 m .5609 .54217 L .56265 .53858 L F
.408 .073 .283 r
.47455 .6202 m .47759 .61827 L .47529 .61844 L F
.283 .094 .438 r
.14816 .58172 m .14979 .58103 L .15033 .57817 L F
.358 .255 .6 r
.14816 .58172 m .14997 .58361 L .14979 .58103 L F
.276 .243 .64 r
.14877 .58428 m .14997 .58361 L .14816 .58172 L F
.157 .602 .933 r
.32742 .54321 m .3291 .54334 L .33102 .54483 L F
.48 .732 .982 r
.33119 .54238 m .33102 .54483 L .3291 .54334 L F
.33119 .54238 m .334 .54469 L .33102 .54483 L F
.529 .324 .547 r
.46063 .66857 m .46335 .66992 L .46007 .67102 L F
.541 .411 .652 r
.30818 .57399 m .30949 .57732 L .30622 .57537 L F
.004 0 0 r
.47895 .624 m .47545 .62599 L .47623 .62446 L F
.708 .563 .688 r
.44354 .65848 m .44287 .66105 L .44559 .65868 L F
.44354 .65848 m .44287 .66105 L .44559 .65868 L F
0 0 0 r
.1527 .57503 m .15449 .57417 L .15567 .57218 L F
.409 .121 .361 r
.15449 .57417 m .15734 .57108 L .15567 .57218 L F
.379 .728 .99 r
.29877 .53747 m .29824 .53877 L .29673 .53733 L F
.29877 .53747 m .30042 .53864 L .29824 .53877 L F
.656 .815 .96 r
.8243 .40948 m .82161 .41042 L .8206 .409 L F
.735 .32 .261 r
.50716 .56152 m .50272 .55942 L .50427 .55953 L F
.923 .727 .62 r
.54768 .52907 m .54912 .53261 L .54725 .53169 L F
.948 .701 .532 r
.54886 .53518 m .54725 .53169 L .54912 .53261 L F
.396 .702 .983 r
.20434 .61207 m .20274 .61222 L .20129 .61093 L F
.706 .651 .792 r
.7883 .41645 m .78684 .41819 L .78598 .41548 L F
.843 .781 .279 r
.54222 .58104 m .54207 .58034 L .54256 .57775 L F
.547 .338 .549 r
.31039 .62959 m .30808 .62738 L .31051 .62696 L F
.31039 .62959 m .30798 .63004 L .30808 .62738 L F
.404 .656 .962 r
.14945 .5988 m .15183 .59985 L .15195 .59928 L F
.529 .86 .995 r
.15195 .59928 m .15183 .59985 L .15267 .59855 L F
0 0 0 r
.27433 .55029 m .27105 .55309 L .27275 .55163 L F
.464 .864 .967 r
.30042 .53864 m .30279 .53797 L .30452 .53837 L F
.178 .711 .825 r
.30279 .53797 m .30684 .53781 L .30452 .53837 L F
.891 .5 .279 r
.50338 .58732 m .50456 .58992 L .50648 .5907 L F
.921 .69 .572 r
.50456 .58992 m .50611 .59325 L .50648 .5907 L F
.021 .319 .807 r
.20434 .61207 m .20688 .61375 L .20655 .61513 L F
.168 .491 .903 r
.20688 .61375 m .20821 .61537 L .20655 .61513 L F
.906 .653 .544 r
.55227 .54085 m .54932 .53757 L .55185 .53869 L F
.627 .658 .861 r
.54586 .59372 m .54707 .5895 L .5446 .58996 L F
.54586 .59372 m .54838 .59328 L .54707 .5895 L F
.694 .265 .225 r
.50171 .55542 m .50317 .55384 L .50173 .55428 L F
.50171 .55542 m .50471 .55573 L .50317 .55384 L F
.182 0 0 r
.27168 .53439 m .27392 .53409 L .27175 .53428 L F
.648 .747 .921 r
.77297 .41023 m .76813 .41249 L .77033 .41108 L F
.77297 .41023 m .77445 .41261 L .76906 .41251 L F
.76915 .41202 m .76906 .41251 L .76813 .41249 L F
.77297 .41023 m .76906 .41251 L .76915 .41202 L F
.982 .876 .653 r
.76813 .41249 m .76781 .41301 L .77033 .41108 L F
.808 .894 .905 r
.76957 .40967 m .76915 .41198 L .76781 .41301 L F
.76941 .40936 m .76781 .41301 L .7684 .41029 L F
0 0 .453 r
.76866 .40977 m .76844 .4102 L .76935 .41203 L F
.76844 .4102 m .7684 .41029 L .76852 .41051 L F
.808 .894 .905 r
.76941 .40936 m .76871 .41131 L .76866 .41109 L F
0 0 .453 r
.76844 .4102 m .76852 .41051 L .76935 .41203 L F
.808 .894 .905 r
.76941 .40936 m .76957 .40967 L .76871 .41131 L F
.76866 .41109 m .76871 .41131 L .76781 .41301 L F
.76957 .40967 m .77033 .41108 L .76915 .41198 L F
.505 .272 .495 r
.28361 .60817 m .28623 .60529 L .28425 .60602 L F
.885 .908 .501 r
.50133 .59023 m .50128 .58948 L .5022 .58656 L F
.678 .156 0 r
.50133 .59023 m .50389 .59263 L .50169 .59184 L F
.50133 .59023 m .50169 .59184 L .50128 .58948 L F
.77 .327 .2 r
.25676 .64277 m .25595 .64318 L .25328 .64187 L F
0 .215 .684 r
.25676 .64277 m .25672 .64218 L .25595 .64318 L F
.168 .01 .408 r
.33365 .5721 m .33483 .57203 L .33571 .57089 L F
.752 .686 .788 r
.33685 .56564 m .33622 .56857 L .33891 .5659 L F
.33467 .56535 m .33622 .56857 L .33685 .56564 L F
0 .065 .585 r
.33674 .56731 m .33574 .57079 L .33622 .56857 L F
.33574 .57079 m .33571 .57089 L .33622 .56857 L F
.33674 .56731 m .33734 .56981 L .33571 .57089 L F
.522 .51 .784 r
.33734 .56981 m .33483 .57203 L .33571 .57089 L F
.843 .628 .612 r
.56094 .57746 m .56452 .57532 L .56129 .57476 L F
.56094 .57746 m .56441 .57792 L .56452 .57532 L F
.7 .812 .935 r
.8233 .43473 m .82713 .435 L .82564 .43308 L F
.772 .742 .826 r
.82564 .43308 m .82713 .435 L .8297 .43222 L F
.698 .367 .413 r
.20918 .55932 m .20557 .55956 L .20632 .55714 L F
.435 .512 .839 r
.16373 .60918 m .16358 .60507 L .16232 .6055 L F
.16373 .60918 m .16576 .60902 L .16358 .60507 L F
.728 .646 .767 r
.54813 .55701 m .54414 .55687 L .54678 .55375 L F
.755 .531 .593 r
.54813 .55701 m .54413 .55931 L .54414 .55687 L F
.54813 .55701 m .5481 .55983 L .54413 .55931 L F
0 0 0 r
.26684 .64811 m .27159 .64525 L .26904 .64777 L F
.564 .134 .182 r
.27159 .64525 m .27152 .64762 L .26904 .64777 L F
.27159 .64525 m .27321 .64552 L .27152 .64762 L F
0 0 0 r
.25605 .65457 m .25404 .65684 L .25561 .65645 L F
.594 .537 .76 r
.25468 .66074 m .25561 .65645 L .25404 .65684 L F
.409 .755 .994 r
.21834 .63928 m .21864 .63794 L .21699 .63812 L F
.21834 .63928 m .22035 .63902 L .21864 .63794 L F
.094 .576 .905 r
.45166 .67334 m .45556 .67469 L .45418 .67284 L F
.684 .76 .909 r
.45556 .67469 m .4582 .67397 L .45418 .67284 L F
.187 .126 .552 r
.28154 .57818 m .28257 .57852 L .28268 .5746 L F
.077 .252 .742 r
.28154 .57818 m .28368 .57993 L .28257 .57852 L F
.054 .581 .866 r
.34227 .55087 m .34025 .55004 L .33895 .55003 L F
.706 .693 .157 r
.34316 .54648 m .34227 .55087 L .34093 .54673 L F
.517 .737 .974 r
.34395 .54456 m .34316 .54648 L .34159 .54497 L F
.34395 .54456 m .34547 .54608 L .34316 .54648 L F
.448 .154 .373 r
.3449 .54837 m .34316 .54648 L .34547 .54608 L F
.609 .493 .695 r
.34352 .54463 m .3449 .54837 L .34395 .54456 L F
.34159 .54497 m .34313 .54655 L .34352 .54463 L F
.34313 .54655 m .3449 .54837 L .34352 .54463 L F
.706 .693 .157 r
.34316 .54648 m .34269 .54871 L .34227 .55087 L F
.34269 .54871 m .34256 .5493 L .34251 .54955 L F
.34269 .54871 m .34251 .54955 L .34227 .55087 L F
.447 .397 .709 r
.34256 .5493 m .34025 .55004 L .34227 .55087 L F
.621 .682 .886 r
.29036 .53306 m .2871 .53192 L .28883 .53215 L F
0 .038 .553 r
.29113 .53362 m .29036 .53306 L .28883 .53215 L F
.29113 .53362 m .2926 .53523 L .29036 .53306 L F
.58 .523 .756 r
.31867 .54373 m .31851 .5448 L .32038 .54188 L F
.647 .612 .8 r
.32038 .54188 m .31851 .5448 L .31698 .54071 L F
.974 .749 .536 r
.20713 .7676 m .20432 .77123 L .20485 .76808 L F
.336 0 .19 r
.20713 .7676 m .20485 .76808 L .20427 .77029 L F
.405 .615 .936 r
.77574 .41145 m .77445 .41261 L .77297 .41023 L F
.301 .222 .598 r
.77675 .41479 m .77445 .41261 L .77574 .41145 L F
.77675 .41479 m .77523 .41554 L .77445 .41261 L F
.15 .689 .829 r
.26165 .53528 m .26381 .53514 L .26563 .53528 L F
.47 .835 .993 r
.26381 .53514 m .26789 .53525 L .26563 .53528 L F
.168 0 0 r
.18681 .56892 m .18504 .57073 L .18285 .57131 L F
.32 0 .073 r
.18904 .56809 m .18504 .57073 L .18681 .56892 L F
.754 .825 .907 r
.25102 .6794 m .25306 .6816 L .25016 .68264 L F
.834 .837 .848 r
.25478 .67901 m .25306 .6816 L .25102 .6794 L F
.464 .405 .707 r
.25518 .6818 m .25306 .6816 L .25478 .67901 L F
.947 .787 .65 r
.54703 .56655 m .54673 .56904 L .54566 .56563 L F
.34 .707 .984 r
.23298 .54898 m .23692 .55003 L .23551 .54881 L F
.49 .77 .994 r
.23692 .55003 m .23763 .54848 L .23551 .54881 L F
.23692 .55003 m .23929 .54974 L .23763 .54848 L F
.808 .804 .848 r
.81721 .43677 m .82015 .4371 L .81998 .43393 L F
.722 .74 .866 r
.81998 .43393 m .82015 .4371 L .8233 .43473 L F
.26 0 0 r
.22808 .64235 m .23137 .64176 L .23019 .64153 L F
.446 .802 .997 r
.23137 .64176 m .23262 .64089 L .23019 .64153 L F
.23137 .64176 m .23438 .64135 L .23262 .64089 L F
.46 .789 .999 r
.23532 .72084 m .23305 .72217 L .23263 .72115 L F
.23532 .72084 m .23545 .72186 L .23305 .72217 L F
.326 0 0 r
.23305 .72217 m .23154 .7245 L .23263 .72115 L F
.23305 .72217 m .23371 .72345 L .23154 .7245 L F
.23305 .72217 m .23545 .72186 L .23371 .72345 L F
.314 .042 .332 r
.30365 .59358 m .30132 .59645 L .30298 .59636 L F
.426 .222 .498 r
.30365 .59358 m .30569 .5929 L .30603 .59047 L F
.376 .116 .387 r
.30527 .59545 m .30365 .59358 L .30298 .59636 L F
.30527 .59545 m .30569 .5929 L .30365 .59358 L F
.561 .762 .972 r
.19286 .60983 m .18877 .60893 L .19102 .60783 L F
.691 .697 .851 r
.19507 .60862 m .19286 .60983 L .19102 .60783 L F
.918 .727 .629 r
.78785 .4032 m .78902 .40703 L .78749 .4055 L F
.817 .635 .657 r
.78923 .40955 m .78749 .4055 L .78902 .40703 L F
0 0 .375 r
.5404 .58417 m .54202 .58278 L .54207 .58034 L F
.565 .552 .798 r
.54072 .58705 m .54202 .58278 L .5404 .58417 L F
0 0 0 r
.21789 .53855 m .2202 .5381 L .22151 .53773 L F
.304 .79 .734 r
.22151 .53773 m .22235 .53729 L .22392 .53747 L F
.22151 .53773 m .2202 .5381 L .22235 .53729 L F
.758 .599 .681 r
.78997 .41569 m .78705 .41282 L .78893 .41194 L F
.78997 .41569 m .78598 .41548 L .78705 .41282 L F
.78997 .41569 m .7883 .41645 L .78598 .41548 L F
.776 .694 .773 r
.79263 .41227 m .78997 .41569 L .78893 .41194 L F
.373 .784 .981 r
.16306 .73746 m .16347 .73645 L .16269 .73636 L F
.16306 .73746 m .1654 .73721 L .16347 .73645 L F
.16306 .73746 m .16347 .73645 L .16269 .73636 L F
.16306 .73746 m .1654 .73721 L .16347 .73645 L F
.517 .473 .747 r
.14741 .59344 m .14838 .59714 L .1501 .59658 L F
.518 .498 .774 r
.14945 .5988 m .1501 .59658 L .14838 .59714 L F
.531 .258 .446 r
.17166 .55964 m .1741 .55936 L .1747 .55706 L F
.354 .096 .378 r
.1747 .55706 m .1741 .55936 L .17671 .55639 L F
.872 .804 .78 r
.84012 .41458 m .84158 .41599 L .84111 .41254 L F
.844 .828 .832 r
.83762 .41772 m .84158 .41599 L .84012 .41458 L F
.422 .436 .769 r
.18418 .60159 m .18371 .60396 L .1831 .60018 L F
.894 .884 .456 r
.18418 .60159 m .18302 .60466 L .18371 .60396 L F
.243 0 .143 r
.47198 .62274 m .47455 .6202 L .47252 .62157 L F
.942 .779 .65 r
.55568 .55306 m .55676 .55663 L .55765 .55426 L F
.395 0 0 r
.29798 .59725 m .29977 .59812 L .30132 .59645 L F
.29798 .59725 m .29684 .59861 L .29977 .59812 L F
.284 .098 .443 r
.15229 .57732 m .15449 .57417 L .1527 .57503 L F
.979 .878 .509 r
.2162 .74224 m .21678 .74442 L .216 .74732 L F
.518 .498 .774 r
.14945 .5988 m .15195 .59928 L .1501 .59658 L F
.734 .815 .914 r
.33017 .54844 m .32825 .54997 L .33199 .55034 L F
.806 .71 .759 r
.32825 .54997 m .32992 .55389 L .33199 .55034 L F
.664 .521 .68 r
.33199 .55034 m .32992 .55389 L .33343 .55342 L F
.809 .828 .865 r
.33017 .54844 m .33199 .55034 L .33456 .54737 L F
.676 .598 .76 r
.33199 .55034 m .33594 .55099 L .33456 .54737 L F
.72 .577 .694 r
.33343 .55342 m .33594 .55099 L .33199 .55034 L F
.591 .227 .32 r
.28165 .64475 m .28586 .6424 L .28404 .64435 L F
.28165 .64475 m .28217 .643 L .28586 .6424 L F
.734 .432 .469 r
.28827 .64233 m .28404 .64435 L .28586 .6424 L F
.585 .632 .864 r
.82795 .41217 m .8243 .40948 L .82693 .40888 L F
.681 .695 .857 r
.83079 .40985 m .82795 .41217 L .82693 .40888 L F
.28 .775 .892 r
.2466 .62547 m .24245 .62554 L .24484 .62609 L F
.466 0 0 r
.24484 .62609 m .24883 .62638 L .2466 .62547 L F
.731 .882 .95 r
.32805 .55253 m .32729 .55427 L .32992 .55389 L F
.982 .727 .467 r
.32805 .55253 m .32992 .55389 L .32825 .54997 L F
.479 .268 .515 r
.32757 .5568 m .32992 .55389 L .32729 .55427 L F
.32757 .5568 m .32964 .55637 L .32992 .55389 L F
.982 .727 .467 r
.32805 .55253 m .32992 .55389 L .32825 .54997 L F
.644 .418 .561 r
.32964 .55637 m .33343 .55342 L .32992 .55389 L F
0 0 0 r
.20008 .54348 m .20106 .54328 L .20297 .54185 L F
.20008 .54348 m .19803 .54552 L .20106 .54328 L F
.308 0 .108 r
.32757 .5568 m .32601 .55923 L .32372 .55966 L F
.553 .595 .85 r
.32805 .55253 m .32757 .5568 L .32729 .55427 L F
.32805 .55253 m .32964 .55637 L .32757 .5568 L F
.343 0 .128 r
.32919 .55797 m .32757 .5568 L .32964 .55637 L F
.32919 .55797 m .32601 .55923 L .32757 .5568 L F
.496 .826 .999 r
.5184 .52076 m .51762 .52247 L .51727 .52294 L F
.5184 .52076 m .52034 .52189 L .51762 .52247 L F
.171 0 0 r
.51762 .52247 m .5184 .52076 L .51727 .52294 L F
.51762 .52247 m .52034 .52189 L .51838 .52368 L F
.51762 .52247 m .51838 .52368 L .5184 .52076 L F
.557 .33 .527 r
.2694 .55385 m .26914 .55611 L .26697 .55642 L F
.22 .048 .423 r
.27078 .55523 m .2694 .55385 L .27105 .55309 L F
.27078 .55523 m .26914 .55611 L .2694 .55385 L F
.754 .825 .907 r
.25102 .6794 m .25016 .68264 L .24839 .68147 L F
.977 .712 .46 r
.79411 .40335 m .79415 .40595 L .7956 .40685 L F
.358 0 0 r
.79681 .4077 m .7956 .40685 L .79415 .40595 L F
.79681 .4077 m .79817 .40767 L .7956 .40685 L F
.046 0 0 r
.19839 .56375 m .19822 .56274 L .20041 .56239 L F
.19839 .56375 m .19622 .5645 L .19822 .56274 L F
.487 .305 .559 r
.33913 .58126 m .33906 .58421 L .33678 .5844 L F
.352 .085 .363 r
.33906 .58421 m .33683 .58594 L .33678 .5844 L F
.114 0 0 r
.19162 .54756 m .19207 .54881 L .19384 .54694 L F
.19162 .54756 m .18998 .54963 L .19207 .54881 L F
0 0 .523 r
.26293 .66566 m .26235 .66705 L .26153 .66358 L F
.576 .91 .975 r
.26045 .66653 m .26235 .66705 L .26293 .66566 L F
.354 .578 .926 r
.19888 .60826 m .19814 .61011 L .19707 .60835 L F
.19888 .60826 m .20129 .61093 L .19814 .61011 L F
.061 0 0 r
.22874 .73173 m .22779 .73162 L .23084 .73077 L F
.149 .2 .661 r
.23251 .73025 m .23084 .73077 L .23049 .7278 L F
0 0 0 r
.22874 .73173 m .23084 .73077 L .23251 .73025 L F
.547 .657 .908 r
.28492 .59533 m .28738 .59393 L .28353 .59567 L F
.28492 .59533 m .28822 .59604 L .28738 .59393 L F
.232 0 0 r
.21224 .55734 m .21141 .55876 L .20918 .55932 L F
.779 .769 .844 r
.83421 .41015 m .83079 .40985 L .83331 .40738 L F
.955 .727 .553 r
.55632 .55936 m .55614 .56304 L .55775 .56339 L F
.919 .69 .576 r
.55614 .56304 m .55749 .5648 L .55775 .56339 L F
0 .115 .661 r
.20921 .61665 m .21024 .61846 L .20821 .61537 L F
.068 .628 .788 r
.21058 .61824 m .21024 .61846 L .20921 .61665 L F
.21058 .61824 m .21235 .61845 L .21024 .61846 L F
.376 .269 .603 r
.27949 .60227 m .27934 .60475 L .27717 .60564 L F
0 0 .155 r
.27801 .60679 m .27717 .60564 L .27934 .60475 L F
.27801 .60679 m .27705 .60798 L .27717 .60564 L F
.098 0 .37 r
.28654 .60278 m .28798 .604 L .28809 .60183 L F
.28654 .60278 m .28623 .60529 L .28798 .604 L F
.914 .542 .306 r
.50948 .55843 m .5112 .56121 L .51249 .5605 L F
.931 .578 .334 r
.5112 .56121 m .51287 .56324 L .51249 .5605 L F
.829 .66 .673 r
.56441 .57792 m .56262 .58109 L .566 .58152 L F
.812 .665 .7 r
.56262 .58109 m .5657 .58408 L .566 .58152 L F
.642 .819 .968 r
.2415 .5492 m .24318 .55052 L .24558 .54951 L F
.469 .256 .506 r
.24318 .55052 m .24286 .55322 L .24558 .54951 L F
.676 .448 .568 r
.49839 .58337 m .50215 .58132 L .49818 .58113 L F
.61 .228 .293 r
.31356 .55068 m .31578 .55243 L .31699 .55048 L F
.621 .559 .763 r
.31699 .55048 m .31823 .54728 L .31555 .54703 L F
.31699 .55048 m .31942 .55031 L .31823 .54728 L F
.647 .27 .315 r
.31699 .55048 m .31923 .55241 L .31942 .55031 L F
.31699 .55048 m .31578 .55243 L .31923 .55241 L F
.786 .639 .698 r
.79263 .41227 m .78923 .40955 L .79291 .41025 L F
.79263 .41227 m .78893 .41194 L .78923 .40955 L F
.85 .753 .756 r
.54673 .56904 m .54401 .56867 L .54566 .56563 L F
.895 .771 .717 r
.54673 .56904 m .54317 .57108 L .54401 .56867 L F
.54673 .56904 m .54487 .57218 L .54317 .57108 L F
0 0 .028 r
.52747 .52333 m .52798 .5231 L .52953 .522 L F
.52747 .52333 m .52706 .52593 L .52798 .5231 L F
.983 .709 .422 r
.30347 .58293 m .30496 .58479 L .30368 .58106 L F
.028 0 0 r
.30496 .58479 m .30379 .58645 L .30211 .58705 L F
.983 .737 .484 r
.30347 .58293 m .30379 .58645 L .30496 .58479 L F
.624 .572 .776 r
.30368 .58106 m .30496 .58479 L .30744 .58409 L F
.533 .54 .808 r
.30496 .58479 m .30822 .58674 L .30744 .58409 L F
.101 0 .329 r
.26289 .55101 m .26387 .55237 L .26447 .55005 L F
.26289 .55101 m .26252 .55322 L .26387 .55237 L F
.54 .797 .992 r
.25803 .65384 m .25834 .65501 L .25605 .65457 L F
.816 .642 .666 r
.25561 .65645 m .25834 .65501 L .25605 .65457 L F
.25561 .65645 m .2586 .6565 L .25834 .65501 L F
.937 .894 .76 r
.54967 .5483 m .55041 .54399 L .5521 .54533 L F
.405 .132 .382 r
.25468 .66074 m .25168 .66425 L .25364 .66227 L F
.594 .537 .76 r
.25468 .66074 m .25693 .66146 L .25561 .65645 L F
.662 .319 .382 r
.2566 .66349 m .25468 .66074 L .25364 .66227 L F
.2566 .66349 m .25693 .66146 L .25468 .66074 L F
.748 .438 .458 r
.47723 .61996 m .48117 .61803 L .47759 .61827 L F
.47723 .61996 m .48117 .62071 L .48117 .61803 L F
.27 0 0 r
.32287 .56771 m .32193 .56852 L .32577 .56769 L F
0 0 0 r
.53466 .52047 m .54013 .51871 L .5348 .52072 L F
.302 .116 .455 r
.30603 .59047 m .30784 .59213 L .3082 .58961 L F
.30603 .59047 m .30569 .5929 L .30784 .59213 L F
.349 .209 .545 r
.17024 .58402 m .17019 .58725 L .16839 .58759 L F
.404 .493 .836 r
.17019 .58725 m .17135 .58935 L .16839 .58759 L F
.949 .885 .734 r
.42705 .65673 m .42662 .65846 L .42774 .65577 L F
0 0 0 r
.42774 .65577 m .42756 .65698 L .42705 .65673 L F
.024 0 0 r
.28284 .53274 m .2848 .53262 L .2871 .53192 L F
.27 .776 .833 r
.2848 .53262 m .28883 .53215 L .2871 .53192 L F
.402 0 .02 r
.82437 .39534 m .82715 .39598 L .82796 .39429 L F
.807 .421 .323 r
.82715 .39598 m .82987 .39488 L .82796 .39429 L F
.764 .751 .841 r
.4503 .67167 m .44776 .67244 L .4503 .66963 L F
.283 .761 .93 r
.26458 .64835 m .26684 .64811 L .26291 .64792 L F
.26458 .64835 m .26684 .64811 L .26291 .64792 L F
.816 .67 .702 r
.25561 .65645 m .25693 .66146 L .2586 .6565 L F
.13 0 0 r
.26789 .53525 m .27027 .535 L .27168 .53439 L F
0 0 0 r
.27027 .535 m .27392 .53409 L .27168 .53439 L F
.879 .442 .092 r
.31291 .54847 m .31578 .55243 L .31356 .55068 L F
.585 .411 .613 r
.30545 .63037 m .30547 .63287 L .30291 .63323 L F
.533 .288 .489 r
.30547 .63287 m .30259 .63568 L .30291 .63323 L F
.666 .176 .077 r
.53138 .5267 m .52983 .52788 L .52706 .52593 L F
.337 0 .07 r
.53356 .52537 m .52983 .52788 L .53138 .5267 L F
.84 .977 .877 r
.82821 .39978 m .83164 .39796 L .83021 .39634 L F
.412 0 0 r
.79817 .40767 m .80084 .408 L .80157 .40682 L F
.478 0 0 r
.80157 .40682 m .80084 .408 L .80467 .40803 L F
.497 0 0 r
.80157 .40682 m .80467 .40803 L .80421 .40718 L F
.87 .957 .86 r
.15639 .60197 m .1558 .60509 L .15835 .60403 L F
.15639 .60197 m .15423 .60463 L .1558 .60509 L F
.261 .075 .429 r
.15033 .57817 m .15189 .57977 L .15229 .57732 L F
.15033 .57817 m .14979 .58103 L .15189 .57977 L F
.471 .164 .363 r
.45864 .63313 m .4611 .63302 L .46165 .63089 L F
.393 .094 .334 r
.46165 .63089 m .46345 .63213 L .46271 .63037 L F
.46165 .63089 m .4611 .63302 L .46345 .63213 L F
.1 .655 .717 r
.22624 .53723 m .22855 .53694 L .23035 .53675 L F
.141 .686 .788 r
.22855 .53694 m .23239 .53672 L .23035 .53675 L F
.456 .422 .733 r
.14741 .59344 m .14927 .59293 L .1492 .58899 L F
.517 .473 .747 r
.14741 .59344 m .1501 .59658 L .14927 .59293 L F
.916 .806 .724 r
.82958 .40399 m .83049 .40673 L .8292 .40566 L F
.762 .523 .572 r
.83049 .40673 m .82693 .40888 L .8292 .40566 L F
.83049 .40673 m .83079 .40985 L .82693 .40888 L F
.863 .88 .848 r
.83189 .40271 m .83049 .40673 L .82958 .40399 L F
.83189 .40271 m .83283 .40406 L .83049 .40673 L F
.668 .454 .585 r
.83049 .40673 m .83331 .40738 L .83079 .40985 L F
.732 .893 .953 r
.78413 .41587 m .7818 .41698 L .78107 .41595 L F
.455 .103 .279 r
.17845 .57526 m .17749 .57738 L .17445 .57741 L F
.449 .098 .276 r
.17981 .57689 m .17845 .57526 L .18066 .57465 L F
.17981 .57689 m .17749 .57738 L .17845 .57526 L F
.039 0 0 r
.23983 .69911 m .23767 .70059 L .23931 .70038 L F
.138 .327 .79 r
.76781 .41301 m .76935 .41203 L .7684 .41029 L F
.76781 .41301 m .77053 .41501 L .76935 .41203 L F
.048 0 0 r
.20106 .54328 m .20527 .54147 L .20297 .54185 L F
.215 .681 .943 r
.30907 .53789 m .31062 .53866 L .30684 .53781 L F
.199 .571 .939 r
.31116 .53749 m .31062 .53866 L .30907 .53789 L F
.31116 .53749 m .31246 .53897 L .31062 .53866 L F
.775 .971 .921 r
.50971 .56237 m .51063 .56351 L .50841 .56321 L F
.441 .569 .887 r
.51063 .56351 m .51287 .56324 L .5112 .56121 L F
.676 .448 .568 r
.49839 .58337 m .50214 .58385 L .50215 .58132 L F
.715 .713 .847 r
.23731 .70394 m .23904 .70677 L .24018 .7058 L F
.87 .98 .844 r
.54678 .55375 m .54414 .55687 L .54394 .55562 L F
.815 .649 .098 r
.54414 .55687 m .54381 .55547 L .54394 .55562 L F
.54414 .55687 m .54413 .55931 L .54381 .55547 L F
.301 .792 .881 r
.23696 .53564 m .23676 .53629 L .23455 .53612 L F
.23696 .53564 m .23907 .53579 L .23676 .53629 L F
.596 .113 .078 r
.80467 .40803 m .808 .40706 L .80421 .40718 L F
.80467 .40803 m .80731 .40863 L .808 .40706 L F
.164 0 0 r
.808 .40706 m .80998 .40765 L .80997 .40567 L F
.808 .40706 m .80731 .40863 L .80998 .40765 L F
.37 .055 .295 r
.16104 .5678 m .16271 .56819 L .16361 .56641 L F
.16104 .5678 m .16054 .5688 L .16271 .56819 L F
.4 .56 .897 r
.20432 .77123 m .20362 .77193 L .20214 .77145 L F
.869 .516 .379 r
.5565 .56785 m .5597 .57094 L .55924 .5697 L F
0 0 0 r
.2589 .54807 m .25745 .54902 L .25539 .54994 L F
.26047 .54711 m .25745 .54902 L .2589 .54807 L F
.989 .723 .41 r
.50214 .58385 m .5022 .58656 L .50338 .58732 L F
.704 .441 .524 r
.50128 .58948 m .50338 .58732 L .5022 .58656 L F
.472 .832 .995 r
.14495 .63005 m .14899 .63026 L .14719 .62949 L F
.14899 .63026 m .14495 .63005 L .14719 .62949 L F
.698 .637 .785 r
.44776 .67244 m .45166 .67334 L .4503 .66963 L F
.525 .409 .663 r
.45166 .67334 m .45296 .67151 L .4503 .66963 L F
.45166 .67334 m .45418 .67284 L .45296 .67151 L F
.72 .577 .694 r
.33343 .55342 m .33569 .55386 L .33594 .55099 L F
.715 .618 .748 r
.33456 .54737 m .33594 .55099 L .33895 .55003 L F
.746 .511 .575 r
.33569 .55386 m .33895 .55003 L .33594 .55099 L F
0 0 .148 r
.32345 .56155 m .32322 .55978 L .32372 .55966 L F
.32345 .56155 m .32278 .56314 L .32322 .55978 L F
0 0 0 r
.24451 .68551 m .24112 .68855 L .24359 .68785 L F
.058 0 .206 r
.24675 .6842 m .24451 .68551 L .24359 .68785 L F
.206 0 .261 r
.26172 .62106 m .25918 .62404 L .26092 .62298 L F
0 0 0 r
.25918 .62404 m .2595 .62393 L .26092 .62298 L F
.25918 .62404 m .25705 .62508 L .2595 .62393 L F
.47335 .62685 m .47318 .62664 L .47273 .62722 L F
.268 .773 .781 r
.47545 .62599 m .47475 .62606 L .47318 .62664 L F
0 0 0 r
.47475 .62606 m .47273 .62722 L .47318 .62664 L F
.325 .365 .749 r
.2343 .71415 m .23533 .71196 L .23343 .71204 L F
.2343 .71415 m .2364 .71535 L .23533 .71196 L F
.53 .35 .581 r
.27194 .6242 m .2744 .62372 L .27434 .62093 L F
.523 .285 .496 r
.27155 .62659 m .2744 .62372 L .27194 .6242 L F
0 0 0 r
.81638 .40509 m .8147 .40673 L .81709 .40409 L F
.215 .247 .679 r
.81638 .40509 m .8169 .40861 L .8147 .40673 L F
.348 .251 .601 r
.8147 .40673 m .8169 .40861 L .81502 .40924 L F
.556 .644 .892 r
.18344 .62006 m .18584 .62373 L .18804 .62289 L F
.627 .689 .888 r
.18584 .62373 m .18893 .62417 L .18804 .62289 L F
.539 .808 .996 r
.8424 .40563 m .84296 .40685 L .83934 .40628 L F
.996 .761 .449 r
.84285 .40833 m .84296 .40685 L .84175 .40785 L F
.981 .892 .546 r
.84175 .40785 m .84296 .40685 L .8424 .40563 L F
.715 .618 .748 r
.33456 .54737 m .33895 .55003 L .33762 .54716 L F
.151 .312 .773 r
.33895 .55003 m .3394 .54802 L .33762 .54716 L F
.33895 .55003 m .34025 .55004 L .3394 .54802 L F
.616 .812 .976 r
.22658 .64123 m .22808 .64235 L .23019 .64153 L F
.534 .741 .97 r
.79403 .43207 m .79601 .43022 L .79325 .43065 L F
.79403 .43207 m .79709 .43172 L .79601 .43022 L F
.497 .758 .988 r
.23426 .62604 m .23 .62499 L .23245 .62498 L F
.454 .767 .996 r
.23497 .62459 m .23426 .62604 L .23245 .62498 L F
.23497 .62459 m .23668 .62575 L .23426 .62604 L F
.371 .562 .91 r
.29474 .53451 m .29461 .53707 L .2926 .53523 L F
.29474 .53451 m .29673 .53733 L .29461 .53707 L F
.225 .702 .936 r
.24299 .53588 m .24317 .53496 L .24544 .53564 L F
.24299 .53588 m .24098 .53513 L .24317 .53496 L F
.77 .746 .226 r
.49319 .5877 m .49278 .58928 L .49343 .58616 L F
.49343 .58616 m .49278 .58928 L .49319 .5877 L F
.773 .54 .582 r
.30033 .59752 m .30298 .59636 L .30132 .59645 L F
.30077 .59757 m .30298 .59636 L .30033 .59752 L F
.29977 .59812 m .30217 .59939 L .30298 .59636 L F
.502 .27 .494 r
.30298 .59636 m .30513 .59844 L .30527 .59545 L F
.30298 .59636 m .30217 .59939 L .30275 .5992 L F
.30376 .59711 m .30275 .5992 L .30513 .59844 L F
.30298 .59636 m .30275 .5992 L .30376 .59711 L F
.306 .394 .789 r
.30367 .59663 m .30321 .59786 L .30089 .5944 L F
.267 .349 .763 r
.30217 .59939 m .30292 .60126 L .30488 .60158 L F
.537 .351 .576 r
.30217 .59939 m .30243 .59961 L .30513 .59844 L F
.30243 .59961 m .30271 .59983 L .30399 .59909 L F
.30243 .59961 m .30399 .59909 L .30513 .59844 L F
.773 .54 .582 r
.29977 .59812 m .30077 .59757 L .30033 .59752 L F
.62 .605 .814 r
.30089 .5944 m .30239 .59962 L .29977 .59812 L F
.30239 .59962 m .30246 .59987 L .30218 .59969 L F
.30239 .59962 m .30218 .59969 L .29977 .59812 L F
.306 .394 .789 r
.30321 .59786 m .30252 .59971 L .30184 .5977 L F
.30252 .59971 m .30246 .59987 L .30239 .59962 L F
.30252 .59971 m .30239 .59962 L .30184 .5977 L F
.537 .351 .576 r
.30271 .59983 m .30488 .60158 L .30491 .60124 L F
.30271 .59983 m .30491 .60124 L .30513 .59844 L F
.306 .394 .789 r
.30321 .59786 m .30184 .5977 L .30089 .5944 L F
.917 .569 .114 r
.30203 .60047 m .30292 .60126 L .30217 .59939 L F
.748 .238 0 r
.30246 .59987 m .30203 .60047 L .29977 .59812 L F
.609 .56 .775 r
.30367 .59663 m .30203 .60047 L .30238 .59997 L F
.30254 .59964 m .30238 .59997 L .30246 .59987 L F
.30367 .59663 m .30238 .59997 L .30254 .59964 L F
.637 .47 .64 r
.30798 .63004 m .30547 .63287 L .30545 .63037 L F
.637 .085 0 r
.25343 .55271 m .25147 .55257 L .24901 .55076 L F
.779 .526 .553 r
.25539 .54994 m .25147 .55257 L .25343 .55271 L F
.25539 .54994 m .25545 .55305 L .25147 .55257 L F
0 0 0 r
.25745 .54902 m .25545 .55305 L .25539 .54994 L F
0 0 .079 r
.33965 .57696 m .33913 .58126 L .34174 .57885 L F
.33965 .57696 m .33955 .58033 L .33913 .58126 L F
0 .095 .651 r
.33955 .58033 m .34099 .58309 L .33913 .58126 L F
.355 .2 .528 r
.34099 .58309 m .33906 .58421 L .33913 .58126 L F
.678 .54 .689 r
.28699 .54745 m .28453 .55063 L .28506 .54881 L F
.656 .813 .959 r
.83189 .40271 m .8356 .40318 L .83283 .40406 L F
.754 .684 .784 r
.50965 .60858 m .50721 .60897 L .50968 .60531 L F
.365 .127 .414 r
.50797 .61014 m .50721 .60897 L .50965 .60858 L F
0 0 .505 r
.50968 .60531 m .51042 .60827 L .50965 .60858 L F
0 0 0 r
.51042 .60827 m .50797 .61014 L .50965 .60858 L F
.691 .421 .51 r
.54325 .52799 m .53955 .52585 L .54363 .52633 L F
0 .223 .669 r
.54768 .52907 m .54652 .52813 L .54363 .52633 L F
.576 .205 .301 r
.54363 .52633 m .54652 .52813 L .54325 .52799 L F
.024 0 .18 r
.26092 .62298 m .26288 .62005 L .26172 .62106 L F
.28 .706 .968 r
.22455 .62326 m .22409 .62418 L .22254 .62269 L F
.22455 .62326 m .22621 .62416 L .22409 .62418 L F
.168 .01 .408 r
.33365 .5721 m .33354 .5745 L .33483 .57203 L F
.33365 .5721 m .33354 .5745 L .33483 .57203 L F
.316 0 .257 r
.31268 .58031 m .31517 .57787 L .3131 .57849 L F
.508 .319 .559 r
.32515 .60569 m .32515 .60833 L .32276 .60885 L F
.548 .38 .605 r
.3253 .61099 m .32276 .60885 L .32515 .60833 L F
.3253 .61099 m .32284 .6115 L .32276 .60885 L F
0 0 0 r
.32307 .56396 m .32278 .56314 L .32345 .56155 L F
.32307 .56396 m .32158 .56581 L .32278 .56314 L F
.56 .231 .369 r
.33861 .59296 m .33752 .59553 L .33493 .59577 L F
.519 .228 .412 r
.34095 .5924 m .33752 .59553 L .33861 .59296 L F
.312 .146 .488 r
.14823 .58654 m .14858 .58666 L .14877 .58428 L F
.255 .122 .499 r
.14858 .58666 m .14997 .58361 L .14877 .58428 L F
.482 .26 .5 r
.27434 .62093 m .27664 .6205 L .27691 .61801 L F
.524 .324 .551 r
.27691 .61801 m .27927 .61759 L .2795 .61489 L F
.466 .226 .466 r
.27664 .6205 m .27927 .61759 L .27691 .61801 L F
.315 .174 .525 r
.22518 .72837 m .2268 .73008 L .22597 .72755 L F
.22518 .72837 m .22485 .73083 L .2268 .73008 L F
.117 0 0 r
.26914 .55611 m .26558 .55753 L .26697 .55642 L F
.519 .339 .577 r
.2795 .61489 m .28193 .61448 L .28203 .61168 L F
.443 .256 .531 r
.2795 .61489 m .28144 .61692 L .28193 .61448 L F
.2795 .61489 m .27927 .61759 L .28144 .61692 L F
.937 .894 .76 r
.54967 .5483 m .54849 .54756 L .55041 .54399 L F
.84 .576 .539 r
.55152 .54999 m .54849 .54756 L .54967 .5483 L F
.471 .215 .444 r
.32052 .6174 m .31774 .62026 L .31827 .61821 L F
.415 .571 .9 r
.18893 .62417 m .19289 .62702 L .19065 .62408 L F
.171 .439 .871 r
.19065 .62408 m .19289 .62702 L .19334 .62547 L F
.445 .239 .504 r
.19289 .62702 m .19469 .62925 L .19334 .62547 L F
.19289 .62702 m .19254 .62976 L .19469 .62925 L F
.273 .778 .805 r
.23298 .54898 m .23122 .54914 L .22896 .54972 L F
.221 0 0 r
.23551 .54881 m .23122 .54914 L .23298 .54898 L F
.807 .421 .323 r
.82715 .39598 m .83021 .39634 L .82987 .39488 L F
.667 .438 .564 r
.33343 .55342 m .33577 .55604 L .33569 .55386 L F
.768 .469 .48 r
.33569 .55386 m .34003 .5561 L .33979 .55587 L F
.33569 .55386 m .33577 .55604 L .34003 .5561 L F
.596 .826 .987 r
.83839 .40504 m .8366 .40697 L .8356 .40318 L F
.83839 .40504 m .83934 .40628 L .8366 .40697 L F
.616 .507 .707 r
.28822 .59604 m .28754 .59972 L .2913 .59907 L F
.123 0 .33 r
.28754 .59972 m .28948 .60066 L .2913 .59907 L F
.28754 .59972 m .28809 .60183 L .28948 .60066 L F
.423 .267 .563 r
.27434 .62093 m .27642 .62302 L .27664 .6205 L F
.27434 .62093 m .2744 .62372 L .27642 .62302 L F
.824 .733 .765 r
.56201 .58363 m .55969 .58689 L .56322 .58709 L F
.798 .721 .78 r
.56201 .58363 m .56322 .58709 L .5657 .58408 L F
.812 .665 .7 r
.56262 .58109 m .56201 .58363 L .5657 .58408 L F
.768 .295 0 r
.78293 .4143 m .7824 .41406 L .78287 .41188 L F
.78293 .4143 m .78413 .41587 L .7824 .41406 L F
.665 .635 .81 r
.78705 .41282 m .78293 .4143 L .78287 .41188 L F
.682 .561 .712 r
.78598 .41548 m .78293 .4143 L .78705 .41282 L F
.78598 .41548 m .78413 .41587 L .78293 .4143 L F
.766 .823 .897 r
.33988 .56039 m .33744 .56297 L .34074 .56217 L F
.844 .637 .623 r
.33744 .56297 m .33891 .5659 L .34074 .56217 L F
.552 .679 .923 r
.19559 .63049 m .20073 .63302 L .19813 .63139 L F
.191 .38 .821 r
.20073 .63302 m .20166 .63245 L .19813 .63139 L F
.20073 .63302 m .20204 .63279 L .20166 .63245 L F
.976 .921 .628 r
.5597 .54081 m .5595 .54389 L .5609 .54217 L F
.464 .836 .99 r
.17301 .70858 m .17259 .70975 L .17076 .70911 L F
.17301 .70858 m .17259 .70975 L .17076 .70911 L F
.484 .777 .996 r
.28699 .54745 m .28925 .54705 L .28758 .54585 L F
.882 .797 .309 r
.28758 .54585 m .28726 .54956 L .28699 .54745 L F
.885 .556 .42 r
.27152 .64762 m .27321 .64552 L .27326 .64733 L F
.793 .642 .694 r
.27563 .64523 m .27326 .64733 L .27321 .64552 L F
.772 .742 .826 r
.82564 .43308 m .8297 .43222 L .82831 .43027 L F
.698 .687 .836 r
.8297 .43222 m .83214 .43102 L .82831 .43027 L F
.276 .761 .92 r
.2407 .64177 m .23884 .64138 L .23662 .64163 L F
.165 .701 .826 r
.24301 .64126 m .23884 .64138 L .2407 .64177 L F
.452 .666 .954 r
.18804 .62289 m .18893 .62417 L .18975 .62237 L F
.39 .591 .924 r
.18893 .62417 m .19065 .62408 L .18975 .62237 L F
.92 .645 .502 r
.55869 .52278 m .55875 .52527 L .56064 .52588 L F
.89 .608 .503 r
.55875 .52527 m .56152 .52824 L .56064 .52588 L F
.915 .676 .563 r
.55939 .57394 m .5614 .57195 L .5597 .57094 L F
.55939 .57394 m .56129 .57476 L .5614 .57195 L F
.078 0 0 r
.18181 .55319 m .18391 .55264 L .18579 .55106 L F
0 0 0 r
.18579 .55106 m .18587 .55175 L .18787 .55032 L F
.18579 .55106 m .18391 .55264 L .18587 .55175 L F
.822 .767 .8 r
.28697 .55365 m .28577 .55669 L .28824 .55348 L F
.444 .237 .503 r
.28577 .55669 m .28822 .55644 L .28824 .55348 L F
.432 .193 .45 r
.28822 .55644 m .28577 .55669 L .28697 .55365 L F
.28822 .55644 m .28573 .55881 L .28577 .55669 L F
.261 0 .115 r
.16884 .56204 m .16954 .56393 L .17072 .56133 L F
.16884 .56204 m .16741 .56459 L .16954 .56393 L F
.934 .705 .225 r
.31291 .54847 m .31555 .54703 L .31441 .54766 L F
.069 .631 .704 r
.31823 .54728 m .31441 .54766 L .31555 .54703 L F
.284 .093 .435 r
.31774 .62026 m .31567 .62344 L .31599 .62109 L F
.644 .418 .561 r
.32964 .55637 m .33313 .55643 L .33343 .55342 L F
.667 .438 .564 r
.33343 .55342 m .33313 .55643 L .33577 .55604 L F
.489 .322 .581 r
.32726 .60214 m .32741 .60523 L .32515 .60569 L F
.615 .47 .662 r
.32741 .60523 m .32515 .60833 L .32515 .60569 L F
.346 .326 .693 r
.33577 .55604 m .33831 .55826 L .34003 .5561 L F
.293 .687 .974 r
.33966 .55463 m .34193 .55601 L .34003 .5561 L F
.904 .93 .553 r
.34003 .5561 m .33831 .55826 L .33966 .55463 L F
0 0 .425 r
.28523 .58406 m .28368 .57993 L .28453 .58139 L F
.176 .441 .872 r
.2211 .62073 m .22023 .6217 L .21859 .62095 L F
.2211 .62073 m .22254 .62269 L .22023 .6217 L F
0 0 0 r
.27437 .61394 m .27346 .61481 L .27531 .61168 L F
0 0 .297 r
.2741 .61647 m .27346 .61481 L .27437 .61394 L F
.2741 .61647 m .27333 .61782 L .27346 .61481 L F
.732 .893 .953 r
.78413 .41587 m .78107 .41595 L .7824 .41406 L F
0 .349 .818 r
.77053 .41501 m .77177 .41661 L .77428 .41797 L F
.657 .791 .946 r
.79709 .43172 m .80081 .43237 L .79972 .43073 L F
.639 .787 .953 r
.79972 .43073 m .80081 .43237 L .80316 .43146 L F
.263 .097 .459 r
.27291 .59951 m .27279 .60203 L .27459 .59858 L F
0 0 .523 r
.26293 .66566 m .26153 .66358 L .26372 .66328 L F
.559 .774 .979 r
.77297 .41023 m .77033 .41108 L .76941 .40936 L F
.454 .188 .419 r
.33021 .59948 m .3297 .60173 L .32726 .60214 L F
.562 .412 .635 r
.33246 .59643 m .33265 .59908 L .33021 .59948 L F
.477 .208 .427 r
.33222 .60121 m .33021 .59948 L .33265 .59908 L F
.33222 .60121 m .3297 .60173 L .33021 .59948 L F
.211 0 0 r
.17072 .56133 m .1741 .55936 L .17166 .55964 L F
.368 .655 .968 r
.24775 .54923 m .24901 .55076 L .24965 .54927 L F
.24775 .54923 m .24901 .55076 L .24965 .54927 L F
.556 .934 .857 r
.24714 .55396 m .24753 .55457 L .2489 .55112 L F
.692 .383 .446 r
.24985 .55215 m .24714 .55396 L .2489 .55112 L F
.842 .533 .466 r
.2494 .55152 m .24736 .55206 L .24985 .55215 L F
.24775 .54923 m .24755 .5507 L .2494 .55152 L F
.24755 .5507 m .24736 .55206 L .2494 .55152 L F
.601 .03 0 r
.24901 .55076 m .25107 .55227 L .2489 .55112 L F
.25107 .55227 m .25147 .55257 L .25047 .552 L F
.25107 .55227 m .25047 .552 L .2489 .55112 L F
.516 .053 .093 r
.54099 .5186 m .54363 .51878 L .54481 .51714 L F
.609 .154 .147 r
.54481 .51714 m .54363 .51878 L .5473 .51876 L F
.518 .032 .043 r
.55176 .5184 m .55192 .51813 L .55105 .51752 L F
.531 .336 .561 r
.49947 .58534 m .50214 .58385 L .49839 .58337 L F
.49947 .58534 m .5022 .58656 L .50214 .58385 L F
.424 .574 .898 r
.79093 .43065 m .79264 .42872 L .7892 .42825 L F
.79093 .43065 m .79325 .43065 L .79264 .42872 L F
0 .032 .595 r
.28726 .54956 m .28824 .55348 L .2906 .55318 L F
.28726 .54956 m .28878 .55236 L .28824 .55348 L F
.637 .449 .612 r
.2906 .55318 m .28824 .55348 L .28878 .55236 L F
.511 .289 .514 r
.28824 .55348 m .28822 .55644 L .2906 .55318 L F
.637 .449 .612 r
.2906 .55318 m .28697 .55365 L .28824 .55348 L F
.115 0 0 r
.27855 .5333 m .28284 .53274 L .28045 .53291 L F
.387 .844 .898 r
.24544 .53564 m .24765 .53497 L .24914 .53504 L F
.247 .76 .838 r
.24765 .53497 m .25144 .53456 L .24914 .53504 L F
0 .185 .715 r
.33467 .56535 m .33674 .56731 L .33622 .56857 L F
.522 .216 .389 r
.2947 .63904 m .29317 .64205 L .2907 .64223 L F
.557 .253 .408 r
.2966 .64089 m .2947 .63904 L .29689 .63927 L F
.2966 .64089 m .29317 .64205 L .2947 .63904 L F
0 0 0 r
.81194 .40154 m .81554 .40045 L .81281 .40052 L F
.519 .658 .922 r
.2593 .64449 m .26019 .64619 L .26179 .64415 L F
.365 .396 .761 r
.26019 .64619 m .26291 .64792 L .26179 .64415 L F
.26019 .64619 m .26127 .6475 L .26291 .64792 L F
.556 .316 .506 r
.2998 .63638 m .29952 .63897 L .29689 .63927 L F
.515 .28 .497 r
.30181 .63843 m .2998 .63638 L .30259 .63568 L F
.30181 .63843 m .29952 .63897 L .2998 .63638 L F
.838 .673 .678 r
.56059 .58013 m .56441 .57792 L .56094 .57746 L F
.56059 .58013 m .56262 .58109 L .56441 .57792 L F
.694 .774 .913 r
.54707 .5895 m .54904 .58979 L .54696 .5873 L F
.717 .781 .903 r
.54696 .5873 m .54884 .58955 L .5523 .58632 L F
.54884 .58955 m .54904 .58979 L .54935 .58947 L F
.54884 .58955 m .54935 .58947 L .5523 .58632 L F
.598 .801 .977 r
.54904 .58979 m .55092 .58992 L .55327 .5894 L F
.555 .808 .992 r
.54831 .58968 m .55092 .58992 L .54904 .58979 L F
.598 .801 .977 r
.54904 .58979 m .55327 .5894 L .5523 .58632 L F
.555 .808 .992 r
.54707 .5895 m .55092 .58992 L .54831 .58968 L F
.729 .717 .839 r
.54831 .58964 m .54838 .59328 L .55092 .58992 L F
.54707 .5895 m .54718 .58982 L .54831 .58964 L F
.54718 .58982 m .54838 .59328 L .54831 .58964 L F
.668 .625 .797 r
.54838 .59328 m .55204 .59366 L .55092 .58992 L F
.484 .276 .522 r
.17445 .57741 m .17492 .58016 L .17276 .58062 L F
0 0 0 r
.17749 .57738 m .17492 .58016 L .17445 .57741 L F
.945 .67 .486 r
.19623 .78532 m .19878 .7863 L .19647 .78839 L F
.478 .825 .998 r
.20086 .78576 m .19878 .7863 L .19623 .78532 L F
.112 0 0 r
.19647 .78839 m .19878 .7863 L .20086 .78576 L F
.95 .762 .614 r
.25335 .67543 m .25478 .67901 L .25273 .67798 L F
.834 .837 .848 r
.25478 .67901 m .25102 .6794 L .25273 .67798 L F
.779 .71 .786 r
.25335 .67543 m .25735 .67597 L .25478 .67901 L F
.251 0 .317 r
.25478 .67901 m .25735 .67597 L .25693 .67811 L F
.389 .278 .606 r
.25693 .67811 m .25518 .6818 L .25478 .67901 L F
.067 .325 .805 r
.77912 .42208 m .7813 .42223 L .77838 .42059 L F
.77912 .42208 m .78191 .42401 L .7813 .42223 L F
.941 .724 .582 r
.56008 .53396 m .56217 .53239 L .56045 .53137 L F
.56008 .53396 m .56194 .53527 L .56217 .53239 L F
.591 .753 .955 r
.19476 .60751 m .19507 .60862 L .19102 .60783 L F
.465 .683 .96 r
.19568 .60676 m .19507 .60862 L .19476 .60751 L F
.19568 .60676 m .19707 .60835 L .19507 .60862 L F
.348 .219 .559 r
.3108 .57412 m .30949 .57732 L .30818 .57399 L F
.471 .595 .895 r
.17269 .589 m .17253 .59196 L .17188 .59086 L F
.17269 .589 m .17459 .59198 L .17253 .59196 L F
.554 .383 .605 r
.46056 .67329 m .46335 .66992 L .46007 .67102 L F
.46056 .67329 m .46335 .66992 L .46007 .67102 L F
.688 .859 .964 r
.24263 .69885 m .23983 .69911 L .24208 .69849 L F
0 .517 .841 r
.24437 .69901 m .24263 .69885 L .24208 .69849 L F
.24437 .69901 m .24643 .69997 L .24263 .69885 L F
.966 .876 .694 r
.54331 .574 m .54317 .57108 L .54394 .57434 L F
.846 .8 .806 r
.54487 .57218 m .54394 .57434 L .54317 .57108 L F
.633 .731 .918 r
.77788 .41636 m .77523 .41554 L .77675 .41479 L F
.513 .754 .983 r
.77963 .41429 m .77788 .41636 L .77675 .41479 L F
.77963 .41429 m .78107 .41595 L .77788 .41636 L F
.793 .642 .694 r
.27563 .64523 m .27707 .64848 L .27326 .64733 L F
.496 0 0 r
.27326 .64733 m .27661 .64834 L .27578 .64848 L F
0 .157 .685 r
.27769 .64714 m .27707 .64848 L .27563 .64523 L F
.63 .162 .123 r
.27326 .64733 m .27578 .64848 L .2731 .64967 L F
.577 .936 .787 r
.27502 .64861 m .27578 .64848 L .27769 .64714 L F
.2731 .64967 m .27578 .64848 L .27502 .64861 L F
.496 0 0 r
.27661 .64834 m .27707 .64848 L .27578 .64848 L F
.667 .973 .892 r
.27578 .64848 m .27707 .64848 L .27769 .64714 L F
.413 .253 .553 r
.28203 .61168 m .28385 .61369 L .28341 .61108 L F
.28203 .61168 m .28193 .61448 L .28385 .61369 L F
.121 0 0 r
.18453 .60854 m .18714 .60884 L .18877 .60893 L F
.486 .891 .937 r
.18877 .60893 m .18932 .60801 L .19102 .60783 L F
.18877 .60893 m .18714 .60884 L .18932 .60801 L F
.737 .769 .879 r
.82331 .40765 m .8243 .40948 L .8206 .409 L F
.577 .646 .882 r
.82626 .40602 m .8243 .40948 L .82331 .40765 L F
.82626 .40602 m .82693 .40888 L .8243 .40948 L F
.951 .68 .486 r
.34645 .5719 m .34435 .57263 L .34516 .57139 L F
.34645 .5719 m .34614 .57424 L .34435 .57263 L F
.399 .176 .456 r
.34894 .56886 m .34856 .57129 L .34645 .5719 L F
.775 .679 .757 r
.34856 .57129 m .34614 .57424 L .34645 .5719 L F
.715 .713 .847 r
.23731 .70394 m .24018 .7058 L .2397 .70322 L F
.501 .535 .823 r
.24018 .7058 m .24203 .70231 L .2397 .70322 L F
.511 .199 .375 r
.2446 .70391 m .2435 .70604 L .24018 .7058 L F
.501 .535 .823 r
.24018 .7058 m .2435 .70604 L .24203 .70231 L F
.464 .141 .333 r
.19199 .56592 m .19119 .56775 L .18904 .56809 L F
.285 0 .242 r
.19309 .56705 m .19199 .56592 L .19441 .56551 L F
.19309 .56705 m .19119 .56775 L .19199 .56592 L F
.571 .435 .657 r
.32284 .6115 m .32308 .6144 L .32065 .61479 L F
.526 .322 .546 r
.32281 .61689 m .32065 .61479 L .32308 .6144 L F
.32281 .61689 m .32052 .6174 L .32065 .61479 L F
.473 0 0 r
.81554 .40045 m .81922 .40278 L .81892 .40021 L F
.81757 .40174 m .81776 .40201 L .81922 .40278 L F
.81554 .40045 m .81776 .40201 L .81757 .40174 L F
0 0 .291 r
.81744 .40064 m .81793 .40226 L .81776 .40201 L F
.374 .233 .558 r
.81776 .40201 m .81811 .40346 L .81922 .40278 L F
0 0 .291 r
.81793 .40226 m .81851 .40411 L .81776 .40201 L F
.81734 .40033 m .81744 .40064 L .81776 .40201 L F
.374 .233 .558 r
.81776 .40201 m .81709 .40409 L .81811 .40346 L F
.81776 .40201 m .81638 .40509 L .81709 .40409 L F
.906 .653 .544 r
.55227 .54085 m .54923 .54024 L .54932 .53757 L F
.909 .76 .683 r
.55227 .54085 m .54865 .54268 L .54923 .54024 L F
.55227 .54085 m .55041 .54399 L .54865 .54268 L F
.469 0 0 r
.29318 .54734 m .29198 .54804 L .28925 .54705 L F
.575 .378 .577 r
.29078 .5503 m .29281 .55108 L .29318 .54734 L F
.215 .007 .368 r
.29281 .55108 m .29544 .54653 L .29318 .54734 L F
.691 .348 .39 r
.29544 .54653 m .29198 .54804 L .29318 .54734 L F
.143 .123 .574 r
.28822 .59604 m .28955 .59345 L .28738 .59393 L F
.28822 .59604 m .2894 .59565 L .28955 .59345 L F
.616 .507 .707 r
.28822 .59604 m .2913 .59907 L .2894 .59565 L F
.87 .98 .844 r
.54678 .55375 m .54394 .55562 L .54593 .55328 L F
.852 .953 .879 r
.54939 .55117 m .54678 .55375 L .54675 .55081 L F
.923 .974 .755 r
.54678 .55375 m .54593 .55328 L .54675 .55081 L F
.499 .821 1 r
.78681 .40221 m .79054 .4026 L .78785 .4032 L F
.465 .204 .432 r
.50721 .60897 m .50716 .61102 L .50472 .61155 L F
.50721 .60897 m .50716 .61102 L .50472 .61155 L F
.622 .832 .436 r
.50968 .60531 m .50721 .60897 L .50848 .60693 L F
.365 .127 .414 r
.50721 .60897 m .50731 .60893 L .50848 .60693 L F
.50721 .60897 m .50797 .61014 L .50731 .60893 L F
.50721 .60897 m .50716 .61102 L .50797 .61014 L F
.50797 .61014 m .50716 .61102 L .50721 .60897 L F
.556 .934 .857 r
.24714 .55396 m .24504 .5552 L .24753 .55457 L F
.976 .725 .311 r
.34516 .57139 m .34348 .56711 L .34447 .56847 L F
.79 .641 .696 r
.34351 .5704 m .34076 .57343 L .34009 .57053 L F
.34237 .57003 m .34009 .57053 L .33977 .56918 L F
.34351 .5704 m .34009 .57053 L .34237 .57003 L F
.34351 .5704 m .34237 .57003 L .34131 .57003 L F
.34237 .57003 m .33977 .56918 L .34131 .57003 L F
.14 0 0 r
.34131 .57003 m .3429 .56968 L .34368 .56975 L F
.34367 .56975 m .34368 .56975 L .34368 .56975 L F
.34131 .57003 m .34368 .56975 L .34367 .56975 L F
.976 .725 .311 r
.34454 .56982 m .34368 .56975 L .34348 .56711 L F
.856 .946 .876 r
.34719 .5652 m .34447 .56847 L .34348 .56711 L F
.282 .193 .573 r
.34368 .56975 m .34522 .56918 L .34348 .56711 L F
.14 0 0 r
.3429 .56968 m .34522 .56918 L .34368 .56975 L F
.976 .725 .311 r
.34516 .57139 m .34368 .56975 L .34454 .56982 L F
.983 .746 .343 r
.34516 .57139 m .34435 .57263 L .34368 .56975 L F
.948 .701 .532 r
.54886 .53518 m .54713 .5344 L .54725 .53169 L F
.939 .62 .406 r
.54886 .53518 m .5474 .53675 L .54713 .5344 L F
.915 .573 .379 r
.54932 .53757 m .5474 .53675 L .54886 .53518 L F
.534 .371 .606 r
.3297 .60173 m .32741 .60523 L .32726 .60214 L F
.753 .978 .918 r
.23227 .7263 m .23049 .7278 L .22903 .72752 L F
.582 .501 .729 r
.23227 .7263 m .23335 .7278 L .23049 .7278 L F
.149 .2 .661 r
.23251 .73025 m .23049 .7278 L .23335 .7278 L F
0 0 0 r
.28087 .59077 m .2798 .5927 L .28223 .5896 L F
.292 .51 .895 r
.78688 .42805 m .78829 .4266 L .78635 .42624 L F
.354 .61 .946 r
.78688 .42805 m .7892 .42825 L .78829 .4266 L F
.604 .861 .992 r
.25008 .68802 m .25382 .68838 L .25364 .68729 L F
.817 .737 .776 r
.24997 .68982 m .25382 .68838 L .25008 .68802 L F
.754 .555 0 r
.25364 .68729 m .25382 .68838 L .25366 .68775 L F
.502 .285 .517 r
.25616 .68779 m .25583 .69045 L .25382 .68838 L F
.597 .067 0 r
.25382 .68838 m .25528 .69018 L .25366 .68775 L F
.25382 .68838 m .25583 .69045 L .25528 .69018 L F
.038 0 0 r
.21405 .53878 m .21567 .5388 L .21789 .53855 L F
.093 0 0 r
.21567 .5388 m .2202 .5381 L .21789 .53855 L F
.594 .709 .924 r
.22485 .73083 m .22779 .73162 L .2268 .73008 L F
0 .313 .799 r
.2268 .73008 m .22779 .73162 L .22874 .73173 L F
.073 .445 .879 r
.26444 .54717 m .26477 .54604 L .26257 .54588 L F
.26444 .54717 m .26573 .54722 L .26477 .54604 L F
.352 .208 .542 r
.26444 .54717 m .26447 .55005 L .26627 .54917 L F
.26444 .54717 m .26621 .5491 L .26573 .54722 L F
.26621 .5491 m .26625 .54909 L .26573 .54722 L F
.971 .655 .304 r
.26573 .54722 m .26625 .54909 L .26477 .54604 L F
.352 .208 .542 r
.26621 .5491 m .26627 .54917 L .26625 .54909 L F
.971 .655 .304 r
.26625 .54909 m .26627 .54917 L .26624 .5491 L F
.26625 .54909 m .26624 .5491 L .26477 .54604 L F
.498 .551 .842 r
.26477 .54604 m .26627 .54917 L .26798 .54783 L F
.143 0 0 r
.26691 .54899 m .26297 .55014 L .26053 .55028 L F
.371 0 .109 r
.26349 .54976 m .26556 .54969 L .26297 .55014 L F
.143 0 0 r
.26618 .54911 m .26359 .54965 L .26468 .54936 L F
.26359 .54965 m .26093 .5502 L .26315 .5497 L F
.26359 .54965 m .26315 .5497 L .26468 .54936 L F
.246 .033 .38 r
.2667 .54908 m .26639 .54907 L .26627 .54917 L F
.26723 .54897 m .26674 .54903 L .2667 .54908 L F
.26674 .54903 m .26639 .54907 L .2667 .54908 L F
.143 0 0 r
.26651 .54906 m .26665 .54905 L .26643 .54907 L F
.26691 .54899 m .26669 .54904 L .26651 .54906 L F
.26669 .54904 m .26665 .54905 L .26651 .54906 L F
.26093 .5502 m .26082 .55021 L .26468 .54936 L F
.26643 .54907 m .26603 .54915 L .26618 .54911 L F
.26603 .54915 m .26053 .55028 L .26618 .54911 L F
.26665 .54905 m .26053 .55028 L .26643 .54907 L F
.743 .401 .403 r
.26468 .54936 m .26047 .54711 L .26257 .54588 L F
.26468 .54936 m .25908 .54924 L .26047 .54711 L F
.247 0 .259 r
.26053 .55028 m .25908 .54924 L .26468 .54936 L F
.544 .563 .825 r
.26477 .54604 m .26468 .54936 L .26257 .54588 L F
.26477 .54604 m .26678 .54882 L .26468 .54936 L F
.26678 .54882 m .26691 .54899 L .26651 .54906 L F
.246 .033 .38 r
.26651 .54906 m .2672 .54844 L .26639 .54907 L F
.544 .563 .825 r
.26678 .54882 m .26651 .54906 L .26468 .54936 L F
.246 .033 .38 r
.26723 .54897 m .26798 .54783 L .2672 .54844 L F
.498 .551 .842 r
.26477 .54604 m .26643 .54696 L .26729 .54698 L F
.26643 .54696 m .26798 .54783 L .26729 .54698 L F
.653 .73 .906 r
.26729 .54698 m .27062 .54699 L .27007 .54628 L F
.035 0 0 r
.26926 .54702 m .26729 .54698 L .27007 .54628 L F
.246 .033 .38 r
.26545 .55168 m .26741 .55107 L .26798 .54783 L F
.653 .73 .906 r
.26729 .54698 m .26798 .54783 L .27062 .54699 L F
.333 .106 .413 r
.26798 .54783 m .26934 .55034 L .27062 .54699 L F
.26798 .54783 m .26741 .55107 L .26934 .55034 L F
.035 0 0 r
.26759 .54855 m .26729 .54698 L .26926 .54702 L F
.395 .498 .846 r
.26729 .54698 m .26691 .54899 L .26477 .54604 L F
.371 0 .109 r
.26696 .54871 m .26672 .54905 L .26691 .54899 L F
.246 .033 .38 r
.26723 .54897 m .2672 .54844 L .26651 .54906 L F
.371 0 .109 r
.26729 .54698 m .26297 .55014 L .26672 .54905 L F
.26729 .54698 m .26672 .54905 L .26696 .54871 L F
.246 .033 .38 r
.26545 .55168 m .26723 .54897 L .26627 .54917 L F
.035 0 0 r
.26759 .54855 m .26622 .54932 L .26729 .54698 L F
.246 .009 .343 r
.26447 .55005 m .26387 .55237 L .26627 .54917 L F
.035 0 0 r
.26622 .54932 m .26556 .54969 L .26576 .54938 L F
.26622 .54932 m .26576 .54938 L .26729 .54698 L F
.371 0 .109 r
.26729 .54698 m .26576 .54938 L .26349 .54976 L F
.26576 .54938 m .26556 .54969 L .26349 .54976 L F
.143 0 0 r
.26093 .5502 m .26053 .55028 L .26082 .55021 L F
.223 .392 .821 r
.18157 .82546 m .18213 .82574 L .18182 .82595 L F
0 0 0 r
.18182 .82595 m .18213 .82574 L .18151 .82617 L F
.816 .439 .342 r
.55347 .52129 m .55482 .52001 L .55192 .51813 L F
.55347 .52129 m .55516 .52188 L .55482 .52001 L F
.846 .999 .805 r
.55588 .54839 m .55531 .55047 L .55795 .54745 L F
.938 .607 .381 r
.55392 .55185 m .55531 .55047 L .55588 .54839 L F
.55392 .55185 m .55568 .55306 L .55531 .55047 L F
.076 0 .149 r
.28312 .58754 m .28223 .5896 L .28475 .58655 L F
.889 .617 .519 r
.83657 .42493 m .83374 .42131 L .83397 .42383 L F
.855 .732 .727 r
.83316 .42636 m .83657 .42493 L .83397 .42383 L F
.83316 .42636 m .83481 .42808 L .83657 .42493 L F
.96 .943 .699 r
.55878 .54313 m .55795 .54745 L .5595 .54389 L F
.976 .921 .628 r
.5597 .54081 m .55878 .54313 L .5595 .54389 L F
.271 .365 .776 r
.46397 .64587 m .46641 .647 L .46459 .64829 L F
.613 .585 .799 r
.46641 .647 m .46467 .65043 L .46459 .64829 L F
.469 .717 .977 r
.34159 .54497 m .34093 .54673 L .33903 .54381 L F
.34159 .54497 m .34316 .54648 L .34093 .54673 L F
.848 .515 .423 r
.50762 .55824 m .51032 .55709 L .50992 .55503 L F
.50762 .55824 m .50948 .55843 L .51032 .55709 L F
.223 0 .333 r
.26835 .60845 m .27015 .60786 L .27087 .60544 L F
.008 0 .312 r
.26835 .60845 m .26925 .61014 L .27015 .60786 L F
.26835 .60845 m .26811 .61115 L .26925 .61014 L F
.633 .74 .926 r
.24301 .64126 m .24479 .6426 L .24673 .64149 L F
.439 .002 .108 r
.3282 .56772 m .33076 .56758 L .33223 .56565 L F
.561 .405 .628 r
.33223 .56565 m .33467 .56535 L .33444 .56265 L F
.172 0 0 r
.33076 .56758 m .33467 .56535 L .33223 .56565 L F
.624 .572 .776 r
.30368 .58106 m .30744 .58409 L .30531 .58126 L F
.367 .088 .352 r
.30531 .58126 m .30347 .58293 L .30368 .58106 L F
.39 .082 .318 r
.25888 .66292 m .25693 .66146 L .2566 .66349 L F
.635 .953 .763 r
.27477 .59596 m .27592 .59447 L .27789 .59369 L F
.473 .765 .994 r
.27847 .59268 m .27802 .59433 L .2767 .59346 L F
.27718 .59282 m .2767 .59346 L .27595 .59297 L F
.27847 .59268 m .2767 .59346 L .27718 .59282 L F
.635 .953 .763 r
.27456 .59611 m .27547 .59465 L .27592 .59447 L F
.27456 .59611 m .27592 .59447 L .27477 .59596 L F
.137 0 0 r
.27789 .59369 m .27802 .59433 L .2798 .5927 L F
.27789 .59369 m .27547 .59465 L .27802 .59433 L F
.901 .703 .626 r
.54768 .52907 m .54431 .53012 L .54652 .52813 L F
.54768 .52907 m .54725 .53169 L .54431 .53012 L F
.355 .652 .968 r
.16057 .60376 m .16232 .6055 L .16268 .60391 L F
.351 .648 .966 r
.16232 .6055 m .16358 .60507 L .16268 .60391 L F
0 0 .177 r
.26288 .62005 m .26519 .61681 L .26326 .61778 L F
.454 .78 .998 r
.25367 .53422 m .25539 .5353 L .25144 .53456 L F
.415 .764 .995 r
.25593 .53396 m .25539 .5353 L .25367 .53422 L F
.25593 .53396 m .25761 .53503 L .25539 .5353 L F
.005 0 .161 r
.2658 .61416 m .26662 .61579 L .26732 .61347 L F
.2658 .61416 m .26519 .61681 L .26662 .61579 L F
0 .092 .63 r
.26252 .55322 m .26342 .55638 L .26408 .55495 L F
.543 .338 .553 r
.31294 .62654 m .31039 .62959 L .31051 .62696 L F
.691 .719 .871 r
.81482 .43804 m .81721 .43677 L .81341 .43606 L F
.64 .565 .754 r
.31942 .55031 m .32122 .54768 L .31823 .54728 L F
.31942 .55031 m .32209 .5501 L .32122 .54768 L F
.63 .372 .509 r
.31923 .55241 m .32209 .5501 L .31942 .55031 L F
.3 .699 .976 r
.82312 .40234 m .82463 .40156 L .82202 .40131 L F
.82312 .40234 m .82553 .40243 L .82463 .40156 L F
.472 .24 .48 r
.35091 .5707 m .34894 .56886 L .35069 .56801 L F
.35091 .5707 m .34856 .57129 L .34894 .56886 L F
.102 0 .117 r
.25898 .67548 m .25735 .67597 L .26028 .67308 L F
.284 .258 .653 r
.25949 .67816 m .25735 .67597 L .25898 .67548 L F
.58 .28 .423 r
.25693 .67811 m .25735 .67597 L .25915 .67782 L F
.25693 .67811 m .25915 .67782 L .25849 .67814 L F
.25693 .67811 m .25735 .67597 L .25949 .67816 L F
.891 .892 .824 r
.25339 .67947 m .25518 .6818 L .25693 .67811 L F
.591 .32 .474 r
.25693 .67811 m .25779 .6785 L .25339 .67947 L F
.25693 .67811 m .25949 .67816 L .25779 .6785 L F
.786 .91 .926 r
.25339 .67947 m .25769 .67852 L .25608 .67607 L F
.25769 .67852 m .25779 .6785 L .25778 .67848 L F
.25769 .67852 m .25778 .67848 L .25608 .67607 L F
.58 .28 .423 r
.25849 .67814 m .25915 .67782 L .25949 .67816 L F
.809 .828 .865 r
.33017 .54844 m .33456 .54737 L .33348 .54688 L F
.006 .105 .618 r
.33544 .54522 m .33456 .54737 L .334 .54469 L F
.763 .974 .921 r
.33544 .54522 m .33348 .54688 L .33456 .54737 L F
.734 .432 .469 r
.28827 .64233 m .28765 .64438 L .28404 .64435 L F
.445 .148 .366 r
.28827 .64233 m .29013 .64387 L .28765 .64438 L F
.497 .133 .278 r
.2907 .64223 m .29013 .64387 L .28827 .64233 L F
.477 .306 .57 r
.34174 .57885 m .3435 .57755 L .33965 .57696 L F
.34174 .57885 m .34376 .58019 L .3435 .57755 L F
.3435 .57755 m .34376 .58019 L .34174 .57885 L F
.408 .073 .283 r
.47455 .6202 m .47723 .61996 L .47759 .61827 L F
.466 .53 .839 r
.24112 .68855 m .24393 .68996 L .24359 .68785 L F
.641 .47 .635 r
.31567 .62344 m .31294 .62654 L .313 .62389 L F
0 0 0 r
.82138 .39712 m .82353 .3962 L .82437 .39534 L F
.366 0 0 r
.82437 .39534 m .82353 .3962 L .82715 .39598 L F
.304 .654 .97 r
.47369 .65305 m .47151 .65284 L .47287 .65418 L F
.47287 .65418 m .47151 .65284 L .47369 .65305 L F
.707 .648 .788 r
.55092 .58992 m .55204 .59366 L .55424 .59278 L F
.824 .687 .712 r
.28726 .54956 m .29078 .5503 L .28925 .54705 L F
0 .032 .595 r
.28726 .54956 m .2906 .55318 L .29078 .5503 L F
.978 .789 .372 r
.29078 .5503 m .2906 .55318 L .29028 .55252 L F
.606 .281 .393 r
.29078 .5503 m .29028 .55252 L .29281 .55108 L F
.872 .519 .378 r
.54719 .56199 m .54413 .55931 L .5481 .55983 L F
.54719 .56199 m .54395 .56218 L .54413 .55931 L F
.994 .769 .484 r
.54566 .56563 m .54395 .56218 L .54719 .56199 L F
.714 .59 .716 r
.81767 .41176 m .81502 .40924 L .8169 .40861 L F
.81767 .41176 m .81568 .41305 L .81502 .40924 L F
.754 .756 .855 r
.8206 .409 m .81767 .41176 L .8169 .40861 L F
.283 .195 .576 r
.14823 .58654 m .1492 .58899 L .14858 .58666 L F
.655 .533 .702 r
.25215 .66672 m .25364 .66227 L .25168 .66425 L F
.674 .79 .936 r
.43497 .66274 m .43699 .66451 L .43895 .66321 L F
.43497 .66274 m .43699 .66451 L .43895 .66321 L F
.885 .759 .719 r
.55505 .55552 m .55676 .55663 L .55568 .55306 L F
.938 .767 .643 r
.55505 .55552 m .55632 .55936 L .55676 .55663 L F
.361 .656 .969 r
.1817 .6202 m .18171 .61853 L .17953 .61879 L F
.1817 .6202 m .18344 .62006 L .18171 .61853 L F
.752 .686 .788 r
.33467 .56535 m .33891 .5659 L .33634 .56534 L F
.844 .637 .623 r
.33744 .56297 m .33634 .56534 L .33891 .5659 L F
.655 .533 .702 r
.25215 .66672 m .25441 .66577 L .25364 .66227 L F
.265 .035 .366 r
.17276 .58062 m .17217 .58332 L .17024 .58402 L F
.234 .119 .51 r
.17212 .58465 m .17024 .58402 L .17217 .58332 L F
.17212 .58465 m .17019 .58725 L .17024 .58402 L F
.352 .085 .363 r
.33906 .58421 m .33844 .58648 L .33683 .58594 L F
.578 .582 .82 r
.34072 .58786 m .33683 .58594 L .33844 .58648 L F
0 0 0 r
.22672 .55028 m .22483 .55192 L .22298 .55253 L F
.2269 .55093 m .22672 .55028 L .22896 .54972 L F
.2269 .55093 m .22483 .55192 L .22672 .55028 L F
.382 .799 .976 r
.2401 .62592 m .23668 .62575 L .23861 .62612 L F
.351 .804 .944 r
.24082 .62521 m .2401 .62592 L .23861 .62612 L F
.24082 .62521 m .24245 .62554 L .2401 .62592 L F
.853 .952 .878 r
.54939 .55117 m .54864 .54995 L .55152 .54999 L F
.54939 .55117 m .54675 .55081 L .54864 .54995 L F
0 .366 .828 r
.18259 .82528 m .18157 .82546 L .17981 .82418 L F
.18259 .82528 m .18213 .82574 L .18157 .82546 L F
.96 .943 .699 r
.55878 .54313 m .55706 .5468 L .55795 .54745 L F
.923 .969 .773 r
.55706 .5468 m .55588 .54839 L .55795 .54745 L F
.161 0 .314 r
.3031 .58869 m .30211 .58705 L .30379 .58645 L F
.3031 .58869 m .30151 .58963 L .30211 .58705 L F
.547 .482 .735 r
.30744 .58409 m .30822 .58674 L .31057 .58601 L F
.372 .198 .511 r
.3082 .58961 m .31057 .58601 L .30822 .58674 L F
.583 .401 .601 r
.24639 .70272 m .2435 .70604 L .2446 .70391 L F
.59 .932 .951 r
.20362 .77193 m .20522 .77023 L .20427 .77029 L F
.612 .93 .965 r
.20432 .77123 m .20692 .77038 L .20362 .77193 L F
.974 .749 .536 r
.20713 .7676 m .20692 .77038 L .20432 .77123 L F
.59 .932 .951 r
.20362 .77193 m .20692 .77038 L .20522 .77023 L F
.426 .309 .617 r
.33479 .59838 m .33246 .59643 L .33493 .59577 L F
.33479 .59838 m .33265 .59908 L .33246 .59643 L F
.938 .767 .643 r
.55505 .55552 m .5536 .55837 L .55632 .55936 L F
.947 .718 .56 r
.55341 .56112 m .55632 .55936 L .5536 .55837 L F
.55341 .56112 m .55614 .56304 L .55632 .55936 L F
.979 .878 .509 r
.2162 .74224 m .216 .74732 L .21389 .74659 L F
.727 .941 .954 r
.216 .74732 m .21638 .74554 L .21389 .74659 L F
.216 .74732 m .21796 .74606 L .21638 .74554 L F
.782 .695 .768 r
.30531 .58126 m .30744 .58409 L .30992 .58097 L F
.655 .505 .668 r
.30992 .58097 m .30744 .58409 L .30999 .58358 L F
.547 .482 .735 r
.30744 .58409 m .31057 .58601 L .30999 .58358 L F
.355 .607 .944 r
.77597 .42041 m .7777 .41897 L .77428 .41797 L F
.77597 .42041 m .77838 .42059 L .7777 .41897 L F
.243 0 .143 r
.47198 .62274 m .47385 .62254 L .47455 .6202 L F
.451 .093 .265 r
.47385 .62254 m .47723 .61996 L .47455 .6202 L F
.435 .82 .988 r
.25761 .53503 m .25983 .53456 L .26165 .53528 L F
.401 .751 .994 r
.26209 .53395 m .26165 .53528 L .25983 .53456 L F
.26209 .53395 m .26381 .53514 L .26165 .53528 L F
.563 .788 .984 r
.46757 .62876 m .4719 .62894 L .4727 .62755 L F
0 0 .237 r
.4727 .62755 m .47273 .62722 L .47198 .62274 L F
0 0 0 r
.4727 .62755 m .47335 .62685 L .47273 .62722 L F
.4727 .62755 m .4719 .62894 L .47335 .62685 L F
.952 .855 .709 r
.83993 .41124 m .84285 .40833 L .84175 .40785 L F
.83993 .41124 m .84111 .41254 L .84285 .40833 L F
.429 .837 .973 r
.22235 .53729 m .22624 .53723 L .22392 .53747 L F
.782 .695 .768 r
.30531 .58126 m .30992 .58097 L .30851 .5813 L F
.652 .587 .769 r
.31268 .58031 m .30992 .58097 L .30949 .57732 L F
.348 .825 .82 r
.31268 .58031 m .30851 .5813 L .30992 .58097 L F
.56 .39 .608 r
.30999 .58358 m .31268 .58031 L .30992 .58097 L F
.994 .809 .549 r
.30949 .57732 m .30851 .5813 L .30992 .58097 L F
.243 .356 .78 r
.17269 .589 m .17188 .59086 L .17135 .58935 L F
.354 .05 .303 r
.81892 .40021 m .82153 .39932 L .82138 .39712 L F
.142 0 .273 r
.82153 .39932 m .82353 .3962 L .82138 .39712 L F
.7 .684 .831 r
.82831 .43027 m .83214 .43102 L .83123 .42761 L F
.781 .732 .807 r
.83123 .42761 m .83214 .43102 L .83481 .42808 L F
0 0 .414 r
.18467 .59796 m .1831 .60018 L .18208 .59826 L F
.18467 .59796 m .18418 .60159 L .1831 .60018 L F
.151 0 .001 r
.15734 .57108 m .15902 .57091 L .16054 .5688 L F
.236 0 .053 r
.16054 .5688 m .16134 .57021 L .16271 .56819 L F
.16054 .5688 m .15902 .57091 L .16134 .57021 L F
.637 .47 .64 r
.30798 .63004 m .30803 .63284 L .30547 .63287 L F
.571 .417 .634 r
.31039 .62959 m .30803 .63284 L .30798 .63004 L F
0 .157 .685 r
.27769 .64714 m .27563 .64523 L .27829 .64536 L F
0 0 0 r
.20386 .63206 m .20436 .63208 L .20385 .63215 L F
.20386 .63206 m .20166 .63245 L .20204 .63279 L F
.20386 .63206 m .20385 .63215 L .20166 .63245 L F
.552 .474 .721 r
.20204 .63279 m .20495 .63466 L .20386 .63206 L F
.331 .479 .857 r
.20301 .63341 m .20375 .6363 L .20495 .63466 L F
.20262 .63398 m .20375 .6363 L .20301 .63341 L F
.945 .623 .391 r
.20386 .63206 m .20495 .63466 L .20288 .63388 L F
0 0 0 r
.20356 .63261 m .20288 .63388 L .20385 .6323 L F
0 0 .458 r
.20475 .63082 m .20436 .63208 L .20386 .63206 L F
.377 .618 .946 r
.20385 .63215 m .20436 .63208 L .20407 .63184 L F
0 0 0 r
.20385 .63219 m .20385 .6323 L .20443 .63133 L F
.20356 .63261 m .20385 .6323 L .20385 .63219 L F
.377 .618 .946 r
.20166 .63245 m .20385 .63215 L .20052 .629 L F
.20385 .63215 m .20407 .63184 L .20052 .629 L F
0 0 0 r
.20386 .63206 m .20367 .6324 L .20475 .63082 L F
.20367 .6324 m .20356 .63261 L .20413 .63176 L F
.20367 .6324 m .20407 .63184 L .20475 .63082 L F
.536 .674 .927 r
.20052 .629 m .20407 .63184 L .20475 .63082 L F
.20407 .63184 m .20436 .63208 L .20475 .63082 L F
0 0 0 r
.20407 .63184 m .20413 .63176 L .20475 .63082 L F
.20356 .63261 m .20443 .63133 L .20475 .63082 L F
.331 .479 .857 r
.20204 .63279 m .20262 .63398 L .20301 .63341 L F
.358 .516 .878 r
.20375 .6363 m .20639 .63723 L .20495 .63466 L F
.787 .65 .711 r
.81998 .43393 m .8233 .43473 L .82205 .4305 L F
.707 .605 .741 r
.82205 .4305 m .8233 .43473 L .82564 .43308 L F
0 0 0 r
.52953 .522 m .53105 .52173 L .53229 .52075 L F
.118 0 0 r
.53229 .52075 m .53105 .52173 L .53457 .5207 L F
.866 .507 .369 r
.55516 .52188 m .55875 .52527 L .55869 .52278 L F
.921 .69 .572 r
.50456 .58992 m .50389 .59263 L .50611 .59325 L F
.919 .761 .669 r
.50319 .59488 m .50611 .59325 L .50389 .59263 L F
.533 .288 .489 r
.30547 .63287 m .30498 .63534 L .30259 .63568 L F
.405 .071 .282 r
.30803 .63284 m .30498 .63534 L .30547 .63287 L F
.499 .234 .443 r
.29914 .59035 m .29867 .59259 L .29627 .59298 L F
.4 .146 .409 r
.30091 .59191 m .29914 .59035 L .30151 .58963 L F
.30091 .59191 m .29867 .59259 L .29914 .59035 L F
.396 .702 .983 r
.20434 .61207 m .20129 .61093 L .20292 .61101 L F
0 .305 .799 r
.20575 .61185 m .20434 .61207 L .20292 .61101 L F
.20575 .61185 m .20688 .61375 L .20434 .61207 L F
.297 .732 .968 r
.2415 .5492 m .23763 .54848 L .23929 .54974 L F
.38 .1 .357 r
.17941 .55357 m .18095 .55512 L .18181 .55319 L F
.17941 .55357 m .17882 .55575 L .18095 .55512 L F
.862 .639 .105 r
.28648 .56279 m .28608 .56357 L .28734 .56103 L F
.28648 .56279 m .28673 .56538 L .28608 .56357 L F
.7 .639 .785 r
.33444 .56265 m .33744 .56297 L .33647 .56014 L F
.621 .372 .519 r
.33467 .56535 m .33744 .56297 L .33444 .56265 L F
.33467 .56535 m .33634 .56534 L .33744 .56297 L F
.648 .609 .797 r
.33647 .56014 m .33744 .56297 L .33988 .56039 L F
.316 0 .257 r
.31268 .58031 m .31492 .5797 L .31517 .57787 L F
.512 .421 .689 r
.31517 .57787 m .31716 .57421 L .31484 .57477 L F
.31517 .57787 m .31716 .57769 L .31716 .57421 L F
.435 .099 .295 r
.31492 .5797 m .31716 .57769 L .31517 .57787 L F
.817 .635 .657 r
.78923 .40955 m .78587 .4091 L .78749 .4055 L F
.808 .691 .736 r
.78923 .40955 m .78705 .41282 L .78587 .4091 L F
.745 .601 .696 r
.78893 .41194 m .78705 .41282 L .78923 .40955 L F
0 0 .425 r
.28523 .58406 m .28506 .5826 L .28368 .57993 L F
0 0 .178 r
.28523 .58406 m .28562 .58505 L .28506 .5826 L F
.28523 .58406 m .28475 .58655 L .28562 .58505 L F
.933 .726 .599 r
.26785 .62357 m .26698 .62603 L .26897 .62672 L F
.934 .689 .542 r
.26698 .62603 m .26677 .62878 L .26897 .62672 L F
.656 .249 .26 r
.26897 .62672 m .27105 .62866 L .27155 .62659 L F
.26897 .62672 m .26677 .62878 L .27105 .62866 L F
.42 .218 .497 r
.44806 .65799 m .45 .65954 L .45032 .65695 L F
.44806 .65799 m .45 .65954 L .45032 .65695 L F
.606 .744 .942 r
.31936 .54 m .31698 .54071 L .31557 .53882 L F
.647 .612 .8 r
.32038 .54188 m .31698 .54071 L .31936 .54 L F
0 0 .439 r
.23549 .72086 m .23545 .72186 L .23532 .72084 L F
.764 .961 .657 r
.23371 .72345 m .23545 .72186 L .23549 .72086 L F
.434 .56 .883 r
.33407 .54072 m .334 .54469 L .33119 .54238 L F
.33407 .54072 m .33551 .54479 L .334 .54469 L F
.249 .664 .963 r
.33551 .54479 m .33801 .54534 L .334 .54469 L F
.006 .105 .618 r
.33544 .54522 m .334 .54469 L .33801 .54534 L F
.419 0 .051 r
.2605 .67197 m .26222 .67303 L .26185 .67301 L F
0 .075 .635 r
.2605 .67197 m .26028 .67308 L .25946 .67117 L F
.784 .874 .444 r
.25898 .67548 m .26028 .67308 L .2605 .67197 L F
.25898 .67548 m .2605 .67197 L .25935 .67284 L F
.419 0 .051 r
.2605 .67197 m .26185 .67301 L .25935 .67284 L F
0 .075 .635 r
.2605 .67197 m .25946 .67117 L .2586 .66918 L F
.554 .198 .319 r
.29689 .63927 m .29896 .64101 L .2966 .64089 L F
.519 .21 .383 r
.29952 .63897 m .29896 .64101 L .29689 .63927 L F
.707 .648 .788 r
.55092 .58992 m .55424 .59278 L .55327 .5894 L F
.765 .725 .815 r
.55327 .5894 m .55424 .59278 L .55705 .58982 L F
.794 .297 0 r
.79054 .4026 m .79415 .40595 L .79411 .40335 L F
.346 .375 .748 r
.14927 .59293 m .1501 .59658 L .15181 .595 L F
.22 .362 .795 r
.1501 .59658 m .15267 .59855 L .15181 .595 L F
.1501 .59658 m .15195 .59928 L .15267 .59855 L F
.004 0 0 r
.47895 .624 m .47732 .62532 L .47545 .62599 L F
0 0 0 r
.48062 .62287 m .47732 .62532 L .47895 .624 L F
.158 .698 .805 r
.19102 .60783 m .19167 .60753 L .19476 .60751 L F
.203 .73 .768 r
.19102 .60783 m .18932 .60801 L .19167 .60753 L F
.582 .824 .99 r
.83461 .40192 m .8356 .40318 L .83189 .40271 L F
0 .259 .744 r
.83839 .40504 m .8356 .40318 L .83461 .40192 L F
.914 .906 .801 r
.53955 .52585 m .53628 .52751 L .53608 .52501 L F
.53955 .52585 m .53744 .52869 L .53628 .52751 L F
.524 .306 .525 r
.53955 .52585 m .53993 .52845 L .53744 .52869 L F
.691 .421 .51 r
.54325 .52799 m .53993 .52845 L .53955 .52585 L F
.666 .77 .927 r
.21256 .63769 m .21416 .63916 L .21699 .63812 L F
.178 .711 .825 r
.30279 .53797 m .30494 .53773 L .30684 .53781 L F
.078 .627 .83 r
.30886 .53769 m .30684 .53781 L .30494 .53773 L F
.30886 .53769 m .30907 .53789 L .30684 .53781 L F
.775 .679 .757 r
.34856 .57129 m .34994 .57479 L .34614 .57424 L F
.641 .512 .69 r
.34934 .57677 m .34629 .57436 L .34994 .57479 L F
.34629 .57436 m .34628 .57426 L .34994 .57479 L F
.34934 .57677 m .34607 .57764 L .34614 .57424 L F
0 0 .318 r
.34647 .57587 m .34718 .576 L .34724 .57253 L F
.34607 .57764 m .34659 .57687 L .34647 .57587 L F
.34659 .57687 m .34718 .576 L .34647 .57587 L F
.641 .512 .69 r
.34629 .57436 m .34614 .57424 L .34628 .57426 L F
.228 .357 .787 r
.35105 .57332 m .34994 .57479 L .34856 .57129 L F
.533 .44 .695 r
.35105 .57332 m .34934 .57677 L .34994 .57479 L F
.509 .436 .71 r
.25364 .66227 m .25441 .66577 L .2566 .66349 L F
.637 .449 .612 r
.2906 .55318 m .28822 .55644 L .28697 .55365 L F
.7 .639 .785 r
.33444 .56265 m .33647 .56014 L .33315 .55929 L F
.724 .494 .578 r
.23533 .71196 m .23924 .71222 L .2391 .70945 L F
.436 .275 .563 r
.24109 .70895 m .23924 .71222 L .2391 .70945 L F
.24109 .70895 m .23924 .71222 L .2391 .70945 L F
.021 .473 .876 r
.21859 .62095 m .21651 .6203 L .215 .619 L F
.238 .578 .943 r
.18019 .59641 m .1796 .59738 L .1779 .59622 L F
.18019 .59641 m .18208 .59826 L .1796 .59738 L F
.117 0 0 r
.26914 .55611 m .26764 .55718 L .26558 .55753 L F
.206 0 0 r
.27078 .55523 m .26764 .55718 L .26914 .55611 L F
.069 .631 .704 r
.31823 .54728 m .31637 .54747 L .31441 .54766 L F
.303 .782 .919 r
.32122 .54768 m .31637 .54747 L .31823 .54728 L F
.544 .897 .975 r
.26428 .53381 m .26381 .53514 L .26209 .53395 L F
.26428 .53381 m .26416 .53393 L .26381 .53514 L F
.47 .835 .993 r
.26381 .53514 m .26416 .53393 L .26789 .53525 L F
.164 .678 .895 r
.26416 .53393 m .27027 .535 L .26789 .53525 L F
.238 .537 .923 r
.17147 .61171 m .17424 .61429 L .17447 .61301 L F
0 .214 .735 r
.17424 .61429 m .17625 .61625 L .17447 .61301 L F
.389 .62 .944 r
.80592 .43136 m .80753 .43332 L .80967 .43331 L F
.252 0 .152 r
.25855 .55124 m .25632 .55217 L .25745 .54902 L F
.35 .826 .818 r
.25708 .55155 m .25632 .55217 L .25855 .55124 L F
.25614 .55174 m .25632 .55217 L .25708 .55155 L F
0 0 0 r
.25558 .55279 m .25632 .55217 L .25545 .55305 L F
.25745 .54902 m .25632 .55217 L .25558 .55279 L F
.128 0 .028 r
.26047 .54711 m .25908 .54924 L .25745 .54902 L F
.252 0 .152 r
.25855 .55124 m .25745 .54902 L .25908 .54924 L F
.462 .479 .79 r
.17736 .59259 m .176 .59592 L .17459 .59198 L F
.382 .388 .742 r
.17736 .59259 m .1779 .59622 L .176 .59592 L F
0 0 0 r
.49982 .55796 m .50171 .55542 L .49897 .55669 L F
.447 .625 .928 r
.78265 .42556 m .78386 .42363 L .78191 .42401 L F
.78265 .42556 m .78635 .42624 L .78386 .42363 L F
.328 .725 .982 r
.23 .62499 m .22621 .62416 L .22815 .62414 L F
.151 .678 .871 r
.23062 .62457 m .23 .62499 L .22815 .62414 L F
.23062 .62457 m .23245 .62498 L .23 .62499 L F
.297 .01 .297 r
.17492 .58016 m .17217 .58332 L .17276 .58062 L F
.262 0 .236 r
.27861 .55356 m .27563 .55635 L .27766 .55548 L F
.465 .152 .35 r
.27766 .55548 m .28016 .5551 L .27861 .55356 L F
.421 .153 .4 r
.27861 .55356 m .28016 .5551 L .28071 .55294 L F
.582 .443 .658 r
.32581 .61382 m .32284 .6115 L .3253 .61099 L F
.32581 .61382 m .32308 .6144 L .32284 .6115 L F
.247 .684 .959 r
.25595 .64318 m .25594 .64207 L .25276 .64221 L F
.25595 .64318 m .25672 .64218 L .25594 .64207 L F
.966 .876 .694 r
.54331 .574 m .54194 .57321 L .54317 .57108 L F
.952 .79 .644 r
.54331 .574 m .54174 .57696 L .54194 .57321 L F
.54331 .574 m .54256 .57775 L .54174 .57696 L F
.085 .288 .771 r
.33042 .5545 m .32964 .55637 L .32805 .55253 L F
.577 .498 .729 r
.32964 .55637 m .33315 .55929 L .33313 .55643 L F
.32964 .55637 m .33081 .56014 L .33315 .55929 L F
.299 .243 .625 r
.33042 .5545 m .32919 .55797 L .32964 .55637 L F
.553 .833 .998 r
.30115 .53697 m .30042 .53864 L .29877 .53747 L F
.30115 .53697 m .30279 .53797 L .30042 .53864 L F
.452 .215 .463 r
.16271 .56819 m .16539 .56523 L .16361 .56641 L F
.823 .587 .582 r
.29097 .60111 m .29459 .5993 L .2913 .59907 L F
.29097 .60111 m .2946 .60193 L .29459 .5993 L F
.029 0 .437 r
.29459 .5993 m .2961 .60061 L .29633 .59808 L F
.29459 .5993 m .2946 .60193 L .2961 .60061 L F
.524 .668 .927 r
.5446 .58996 m .54562 .58804 L .54308 .5865 L F
.5446 .58996 m .54707 .5895 L .54562 .58804 L F
.642 .819 .968 r
.2415 .5492 m .24558 .54951 L .24386 .54844 L F
.669 .118 0 r
.24374 .55218 m .24391 .55342 L .24307 .5533 L F
.237 0 0 r
.2388 .55529 m .24286 .55322 L .24279 .55577 L F
.23902 .55518 m .24102 .55496 L .24286 .55322 L F
.2388 .55529 m .24102 .55496 L .23902 .55518 L F
.445 .692 .97 r
.24102 .55496 m .24342 .55493 L .24321 .55472 L F
.558 .858 .545 r
.24286 .55322 m .24102 .55496 L .24374 .55218 L F
.445 .692 .97 r
.24102 .55496 m .24321 .55472 L .24215 .55367 L F
.808 .997 .779 r
.24374 .55218 m .24102 .55496 L .24157 .5531 L F
.445 .692 .97 r
.24102 .55496 m .24215 .55367 L .24157 .5531 L F
.669 .118 0 r
.24374 .55218 m .24307 .5533 L .24157 .5531 L F
0 0 0 r
.24558 .54951 m .24428 .55128 L .24374 .55218 L F
.24428 .55128 m .24286 .55322 L .24374 .55218 L F
.414 .766 .995 r
.24558 .54951 m .24601 .54819 L .24386 .54844 L F
.24558 .54951 m .24775 .54923 L .24601 .54819 L F
.635 .335 .446 r
.24374 .55218 m .24775 .54923 L .24558 .54951 L F
.707 .605 .741 r
.82205 .4305 m .82564 .43308 L .82602 .4312 L F
.69 .57 .715 r
.82602 .4312 m .82564 .43308 L .82831 .43027 L F
.19 0 0 r
.20248 .56156 m .19839 .56375 L .20041 .56239 L F
0 0 0 r
.46397 .64587 m .46106 .64865 L .46335 .64675 L F
.164 0 .365 r
.46106 .64865 m .46311 .64944 L .46335 .64675 L F
.46106 .64865 m .46113 .65059 L .46311 .64944 L F
.465 .855 .652 r
.18151 .82617 m .18169 .8275 L .17956 .82704 L F
.18151 .82617 m .18213 .82574 L .18259 .82528 L F
.18151 .82617 m .18259 .82528 L .18169 .8275 L F
0 0 .309 r
.80997 .40567 m .81194 .40154 L .80956 .40373 L F
.061 0 0 r
.2406 .6995 m .23983 .69911 L .23931 .70038 L F
.2406 .6995 m .24208 .69849 L .23983 .69911 L F
.736 .828 .922 r
.34426 .5827 m .34302 .5842 L .34099 .58309 L F
.34511 .5826 m .34335 .58395 L .34426 .5827 L F
.34335 .58395 m .34302 .5842 L .34426 .5827 L F
.34518 .58266 m .34302 .5842 L .34511 .5826 L F
.514 .356 .604 r
.3453 .58257 m .34509 .58571 L .34302 .5842 L F
.736 .828 .922 r
.3453 .58257 m .34274 .58288 L .34376 .58019 L F
.34274 .58288 m .34099 .58309 L .3421 .58192 L F
.34274 .58288 m .3421 .58192 L .34376 .58019 L F
.102 .34 .81 r
.34322 .5836 m .34509 .58571 L .34354 .58261 L F
.34302 .5842 m .34418 .58505 L .34322 .5836 L F
.34418 .58505 m .34509 .58571 L .34322 .5836 L F
.736 .828 .922 r
.3453 .58257 m .34518 .58266 L .34511 .5826 L F
.939 .733 .597 r
.34465 .58206 m .34509 .58571 L .3453 .58257 L F
.396 .344 .683 r
.34509 .58571 m .34704 .58557 L .34468 .58212 L F
.34466 .58215 m .34468 .58212 L .34465 .58206 L F
.34509 .58571 m .34468 .58212 L .34466 .58215 L F
.976 .755 .539 r
.34354 .58261 m .34509 .58571 L .34466 .58215 L F
.3446 .58209 m .34466 .58215 L .34465 .58206 L F
.34354 .58261 m .34466 .58215 L .3446 .58209 L F
.102 .34 .81 r
.34302 .5842 m .34354 .58261 L .34099 .58309 L F
.571 .337 .523 r
.34509 .58571 m .34237 .58692 L .34302 .5842 L F
.925 .708 .59 r
.34302 .5842 m .34237 .58692 L .34099 .58309 L F
.256 .017 .347 r
.30784 .59213 m .30569 .5929 L .30527 .59545 L F
.134 0 .068 r
.27433 .55029 m .27348 .55277 L .27105 .55309 L F
0 0 .012 r
.27505 .55152 m .27433 .55029 L .27643 .55016 L F
.27505 .55152 m .27348 .55277 L .27433 .55029 L F
0 0 .338 r
.27563 .55635 m .27675 .55725 L .27766 .55548 L F
.27563 .55635 m .2755 .55906 L .27675 .55725 L F
.919 .69 .576 r
.55614 .56304 m .55488 .56473 L .55749 .5648 L F
.907 .748 .673 r
.55488 .56473 m .5565 .56785 L .55749 .5648 L F
.611 .677 .888 r
.32188 .53946 m .32038 .54188 L .31936 .54 L F
.32188 .53946 m .32263 .54137 L .32038 .54188 L F
.861 .693 .673 r
.78749 .4055 m .78416 .40764 L .78685 .404 L F
.78749 .4055 m .78587 .4091 L .78416 .40764 L F
.053 .444 .876 r
.22035 .63902 m .22062 .63795 L .21864 .63794 L F
.22035 .63902 m .22205 .63959 L .22062 .63795 L F
.281 .073 .41 r
.28268 .5746 m .28468 .57393 L .28543 .57133 L F
.021 0 .477 r
.28268 .5746 m .28411 .57618 L .28468 .57393 L F
.28268 .5746 m .28257 .57852 L .28411 .57618 L F
.157 0 0 r
.19384 .54694 m .19425 .54818 L .19598 .54633 L F
.19384 .54694 m .19207 .54881 L .19425 .54818 L F
.492 .839 .996 r
.43029 .66645 m .42762 .66681 L .42614 .66616 L F
.43029 .66645 m .42762 .66681 L .42614 .66616 L F
.565 .552 .798 r
.54072 .58705 m .54308 .5865 L .54202 .58278 L F
.32 0 .073 r
.18904 .56809 m .18731 .57029 L .18504 .57073 L F
.172 0 0 r
.18941 .56958 m .18904 .56809 L .19119 .56775 L F
.18941 .56958 m .18731 .57029 L .18904 .56809 L F
.91 .504 .15 r
.32081 .57987 m .32248 .58202 L .32243 .58086 L F
.501 .825 1 r
.32488 .58034 m .32081 .57987 L .32243 .58086 L F
.652 .23 .229 r
.32248 .58202 m .32456 .58281 L .32243 .58086 L F
.5 .272 .501 r
.32243 .58086 m .32456 .58281 L .32488 .58034 L F
.95 .61 .336 r
.50848 .60693 m .51042 .60827 L .50968 .60531 L F
0 0 .101 r
.17879 .58564 m .17699 .58703 L .1794 .58379 L F
0 0 0 r
.17708 .58949 m .17879 .58564 L .17699 .58703 L F
0 0 .101 r
.1794 .58379 m .17699 .58703 L .17879 .58564 L F
.74 .634 .742 r
.17879 .58564 m .17708 .58949 L .17699 .58703 L F
.71 .633 .77 r
.82205 .4305 m .82602 .4312 L .82477 .42767 L F
.716 .654 .787 r
.82602 .4312 m .82732 .42652 L .82477 .42767 L F
.82602 .4312 m .82831 .43027 L .82732 .42652 L F
0 0 .4 r
.32285 .56659 m .32158 .56581 L .32307 .56396 L F
.32285 .56659 m .32193 .56852 L .32158 .56581 L F
.402 .639 .952 r
.2249 .64101 m .22624 .63998 L .22205 .63959 L F
.2249 .64101 m .22658 .64123 L .22624 .63998 L F
.194 .506 .91 r
.17625 .61625 m .17725 .61777 L .17759 .61625 L F
.127 .43 .871 r
.17725 .61777 m .17953 .61879 L .17759 .61625 L F
.455 .725 .984 r
.23438 .64135 m .23532 .64048 L .23262 .64089 L F
.23438 .64135 m .23662 .64163 L .23532 .64048 L F
.846 .407 .178 r
.50272 .55942 m .50144 .56045 L .49982 .55796 L F
.767 .288 .099 r
.50272 .55942 m .50503 .5621 L .50144 .56045 L F
.735 .32 .261 r
.50716 .56152 m .50503 .5621 L .50272 .55942 L F
.56 .39 .608 r
.30999 .58358 m .31292 .58367 L .31268 .58031 L F
.291 .03 .335 r
.31057 .58601 m .31292 .58367 L .30999 .58358 L F
.963 .721 .524 r
.52983 .52788 m .52798 .5231 L .52706 .52593 L F
.506 .409 .679 r
.34237 .58692 m .34044 .58928 L .34072 .58786 L F
0 0 .441 r
.3413 .58772 m .34044 .58928 L .34072 .58786 L F
.3413 .58772 m .34136 .58847 L .34044 .58928 L F
.07 .233 .725 r
.34136 .58847 m .34287 .59132 L .34044 .58928 L F
.272 .252 .653 r
.34044 .58928 m .34287 .59132 L .34095 .5924 L F
.546 .8 .992 r
.83839 .40504 m .8424 .40563 L .83934 .40628 L F
.336 0 .19 r
.20713 .7676 m .20427 .77029 L .20522 .77023 L F
0 0 .083 r
.20738 .7692 m .20692 .77038 L .20713 .7676 L F
.20738 .7692 m .20713 .7676 L .20522 .77023 L F
.348 .031 .278 r
.24774 .68422 m .24839 .68147 L .24675 .6842 L F
0 0 0 r
.25102 .6794 m .24839 .68147 L .24956 .68055 L F
0 0 .07 r
.24956 .68055 m .24839 .68147 L .24774 .68422 L F
.446 .517 .837 r
.19559 .63049 m .19723 .62865 L .19469 .62925 L F
.19559 .63049 m .19813 .63139 L .19723 .62865 L F
.505 .272 .495 r
.28361 .60817 m .28583 .60775 L .28623 .60529 L F
.34 .208 .551 r
.28583 .60775 m .28798 .604 L .28623 .60529 L F
.465 .671 .953 r
.24738 .698 m .24643 .69997 L .24437 .69901 L F
.24738 .698 m .24844 .69965 L .24643 .69997 L F
.427 .246 .531 r
.24844 .69965 m .24639 .70272 L .24643 .69997 L F
.89 .608 .503 r
.55875 .52527 m .55881 .52781 L .56152 .52824 L F
.897 .712 .644 r
.55881 .52781 m .56045 .53137 L .56152 .52824 L F
.284 .098 .443 r
.15229 .57732 m .15428 .57692 L .15449 .57417 L F
.219 0 .295 r
.15189 .57977 m .15428 .57692 L .15229 .57732 L F
.781 .732 .807 r
.83123 .42761 m .83481 .42808 L .83316 .42636 L F
.409 .121 .361 r
.15449 .57417 m .15664 .57389 L .15734 .57108 L F
.312 .036 .324 r
.15734 .57108 m .15865 .57315 L .15902 .57091 L F
.15734 .57108 m .15664 .57389 L .15865 .57315 L F
.831 .792 .815 r
.32394 .54954 m .32173 .55251 L .32651 .55019 L F
.521 .143 .264 r
.32173 .55251 m .32446 .55266 L .32651 .55019 L F
0 0 0 r
.32651 .55019 m .32446 .55266 L .32634 .55134 L F
.639 .086 0 r
.32651 .55019 m .32634 .55134 L .32394 .54954 L F
.838 .999 .785 r
.32742 .54321 m .32785 .54101 L .3291 .54334 L F
.32742 .54321 m .32547 .54396 L .32785 .54101 L F
.385 .792 .982 r
.52079 .52069 m .52034 .52189 L .5184 .52076 L F
.52079 .52069 m .52242 .52143 L .52034 .52189 L F
.52034 .52189 m .52079 .52069 L .51838 .52368 L F
.52034 .52189 m .52242 .52143 L .52079 .52069 L F
0 0 .414 r
.18467 .59796 m .18482 .60134 L .18418 .60159 L F
0 0 0 r
.18424 .60315 m .18418 .60159 L .18482 .60134 L F
.18424 .60315 m .18302 .60466 L .18418 .60159 L F
.064 0 0 r
.26575 .66343 m .26717 .66349 L .26372 .66328 L F
.26372 .66328 m .26717 .66349 L .26575 .66343 L F
.726 .984 .9 r
.26727 .66213 m .26717 .66349 L .26575 .66343 L F
.26727 .66213 m .26717 .66349 L .26575 .66343 L F
0 0 0 r
.52953 .522 m .52798 .5231 L .53105 .52173 L F
.008 0 .266 r
.27236 .5543 m .27105 .55309 L .27348 .55277 L F
.27236 .5543 m .27078 .55523 L .27105 .55309 L F
.788 .856 .901 r
.78151 .41013 m .78102 .41078 L .78146 .40993 L F
.867 .841 .817 r
.78102 .41078 m .78287 .41188 L .78151 .41013 L F
.788 .856 .901 r
.78162 .41058 m .78287 .41188 L .78102 .41078 L F
.986 .802 .572 r
.78287 .41188 m .782 .41213 L .78162 .41058 L F
.78287 .41188 m .78162 .41058 L .78151 .41013 L F
.788 .856 .901 r
.78587 .4091 m .78287 .41188 L .78162 .41058 L F
.78587 .4091 m .78102 .41078 L .78272 .40853 L F
.902 .866 .794 r
.78222 .40844 m .78102 .41078 L .78103 .40952 L F
.867 .841 .817 r
.78102 .41078 m .78151 .41013 L .78103 .40952 L F
.986 .802 .572 r
.78151 .41013 m .78118 .41236 L .78103 .40952 L F
.782 .41213 m .78118 .41236 L .78151 .41013 L F
.788 .856 .901 r
.78272 .40853 m .78151 .41013 L .78222 .40844 L F
.78151 .41013 m .78146 .40993 L .78222 .40844 L F
.986 .802 .572 r
.78287 .41188 m .7824 .41406 L .78118 .41236 L F
.665 .635 .81 r
.78705 .41282 m .78287 .41188 L .78587 .4091 L F
0 0 .358 r
.27459 .59858 m .27543 .59733 L .27547 .59465 L F
.608 .848 .48 r
.27459 .59858 m .27301 .60047 L .27543 .59733 L F
0 0 0 r
.27533 .59747 m .27301 .60047 L .27407 .59922 L F
.27543 .59733 m .27528 .59752 L .27533 .59747 L F
.27528 .59752 m .27301 .60047 L .27533 .59747 L F
0 0 .358 r
.27458 .59827 m .27547 .59465 L .27456 .59611 L F
.27459 .59858 m .27468 .59817 L .27458 .59827 L F
.27468 .59817 m .27547 .59465 L .27458 .59827 L F
.255 .122 .499 r
.14858 .58666 m .14994 .58626 L .14997 .58361 L F
.345 .258 .612 r
.1492 .58899 m .14994 .58626 L .14858 .58666 L F
0 .461 .714 r
.21282 .61849 m .21235 .61845 L .21058 .61824 L F
.21282 .61849 m .215 .619 L .21235 .61845 L F
.114 0 .154 r
.17671 .55639 m .1741 .55936 L .17594 .55816 L F
.275 0 .238 r
.17671 .55639 m .17779 .55745 L .17882 .55575 L F
.17671 .55639 m .17594 .55816 L .17779 .55745 L F
.303 0 0 r
.16057 .60376 m .15639 .60197 L .15835 .60403 L F
.242 .168 .57 r
.14979 .58103 m .15168 .58236 L .15189 .57977 L F
.14979 .58103 m .14997 .58361 L .15168 .58236 L F
.616 .812 .976 r
.22658 .64123 m .23019 .64153 L .22851 .64056 L F
.577 .81 .987 r
.23019 .64153 m .23097 .63949 L .22851 .64056 L F
.23019 .64153 m .23262 .64089 L .23097 .63949 L F
.409 .32 .643 r
.4517 .64785 m .45355 .64715 L .45096 .6462 L F
.4517 .64785 m .45355 .64715 L .45096 .6462 L F
.594 .41 .602 r
.45096 .6462 m .44885 .65047 L .4517 .64785 L F
.119 0 0 r
.25328 .64187 m .25099 .64206 L .24882 .64197 L F
0 .092 .63 r
.26252 .55322 m .26408 .55495 L .26387 .55237 L F
.485 .516 .814 r
.16961 .61203 m .16968 .60761 L .16786 .60832 L F
.16961 .61203 m .17147 .61171 L .16968 .60761 L F
.655 .667 .849 r
.81092 .43691 m .81246 .4326 L .80967 .43331 L F
.81092 .43691 m .81341 .43606 L .81246 .4326 L F
.63 .372 .509 r
.31923 .55241 m .32173 .55251 L .32209 .5501 L F
.463 .516 .828 r
.32209 .5501 m .32274 .54657 L .32122 .54768 L F
.32209 .5501 m .32394 .54954 L .32274 .54657 L F
.327 .11 .423 r
.32209 .5501 m .32173 .55251 L .32394 .54954 L F
.32209 .5501 m .32173 .55251 L .32394 .54954 L F
.212 .228 .659 r
.17212 .58465 m .17135 .58935 L .17019 .58725 L F
.17212 .58465 m .17269 .589 L .17135 .58935 L F
.523 .285 .496 r
.27155 .62659 m .27401 .62616 L .2744 .62372 L F
.441 .237 .506 r
.27401 .62616 m .27642 .62302 L .2744 .62372 L F
.547 .292 .481 r
.30467 .63779 m .30259 .63568 L .30498 .63534 L F
.30467 .63779 m .30181 .63843 L .30259 .63568 L F
.903 .661 .563 r
.83192 .42325 m .83374 .42131 L .83184 .42065 L F
.82 .849 .87 r
.83374 .42131 m .83503 .41758 L .83184 .42065 L F
.83374 .42131 m .8363 .41894 L .83503 .41758 L F
.859 .582 .518 r
.83192 .42325 m .83397 .42383 L .83374 .42131 L F
.639 .652 .847 r
.83123 .42761 m .82732 .42652 L .82831 .43027 L F
.397 .284 .607 r
.29842 .59491 m .29627 .59298 L .29867 .59259 L F
.29842 .59491 m .29663 .59609 L .29627 .59298 L F
0 0 .309 r
.80997 .40567 m .81186 .40399 L .81194 .40154 L F
0 0 .105 r
.80997 .40567 m .80998 .40765 L .81186 .40399 L F
0 0 0 r
.81186 .40399 m .81366 .40242 L .81466 .40095 L F
.773 .865 .429 r
.81466 .40095 m .81366 .40242 L .81426 .40125 L F
0 0 0 r
.81194 .40154 m .81466 .40095 L .81515 .40057 L F
.773 .865 .429 r
.81466 .40095 m .81426 .40125 L .81462 .40055 L F
0 0 0 r
.81515 .40057 m .81466 .40095 L .81554 .40045 L F
0 .276 .78 r
.81734 .40033 m .81776 .40201 L .81554 .40045 L F
.81734 .40033 m .81554 .40045 L .81466 .40095 L F
0 0 .054 r
.27087 .60544 m .27015 .60786 L .27169 .60435 L F
.22 0 0 r
.20918 .55932 m .20706 .55986 L .20557 .55956 L F
.191 .715 .699 r
.21141 .55876 m .20706 .55986 L .20918 .55932 L F
.92 .844 .752 r
.55947 .53629 m .56194 .53527 L .56008 .53396 L F
.55947 .53629 m .56098 .53756 L .56194 .53527 L F
.912 .696 .596 r
.55939 .57394 m .56094 .57746 L .56129 .57476 L F
.117 0 0 r
.27949 .55894 m .27742 .55933 L .2755 .55906 L F
.022 .594 .742 r
.28189 .5595 m .27742 .55933 L .27949 .55894 L F
.466 .226 .466 r
.27664 .6205 m .27891 .62006 L .27927 .61759 L F
.477 .262 .508 r
.27891 .62006 m .28144 .61692 L .27927 .61759 L F
.048 0 0 r
.20106 .54328 m .2033 .54273 L .20527 .54147 L F
0 0 0 r
.20527 .54147 m .20547 .54203 L .20753 .54092 L F
.20527 .54147 m .2033 .54273 L .20547 .54203 L F
0 0 .441 r
.3413 .58772 m .34072 .58786 L .33844 .58648 L F
.211 0 0 r
.17072 .56133 m .17236 .56163 L .1741 .55936 L F
.089 0 0 r
.1741 .55936 m .17435 .56077 L .17594 .55816 L F
.1741 .55936 m .17236 .56163 L .17435 .56077 L F
.337 0 .07 r
.53356 .52537 m .53241 .52743 L .52983 .52788 L F
.633 .295 .38 r
.53608 .52501 m .53241 .52743 L .53356 .52537 L F
.672 .158 .009 r
.53993 .52845 m .53628 .52751 L .53744 .52869 L F
.933 .59 .356 r
.54413 .55931 m .54275 .5608 L .54381 .55547 L F
.54413 .55931 m .54395 .56218 L .54275 .5608 L F
0 0 .501 r
.2568 .68363 m .25518 .6818 L .25339 .67947 L F
.285 .153 .519 r
.2568 .68363 m .25548 .68428 L .25518 .6818 L F
.662 .833 .966 r
.26291 .64792 m .26684 .64811 L .26529 .64693 L F
.469 .759 .993 r
.26529 .64693 m .26684 .64811 L .26904 .64777 L F
.22 0 .306 r
.34099 .58309 m .33844 .58648 L .33906 .58421 L F
.926 .768 .666 r
.55784 .53962 m .56098 .53756 L .55947 .53629 L F
.55784 .53962 m .5597 .54081 L .56098 .53756 L F
.515 .123 .236 r
.33017 .54844 m .32805 .55253 L .32825 .54997 L F
.618 .277 .37 r
.1794 .58379 m .18148 .58579 L .17879 .58564 L F
.1794 .58379 m .18148 .58579 L .17879 .58564 L F
.011 0 .183 r
.18285 .57131 m .18202 .57379 L .18066 .57465 L F
0 0 .07 r
.18156 .57534 m .18066 .57465 L .18202 .57379 L F
.18156 .57534 m .17981 .57689 L .18066 .57465 L F
.823 .789 .819 r
.81906 .43017 m .82205 .4305 L .82145 .42726 L F
.846 .734 .741 r
.81998 .43393 m .82205 .4305 L .81906 .43017 L F
.782 .763 .836 r
.82145 .42726 m .82205 .4305 L .82477 .42767 L F
.073 .309 .791 r
.2894 .59565 m .2913 .59907 L .29189 .59761 L F
.894 .555 .398 r
.28948 .60066 m .29097 .60111 L .2913 .59907 L F
.869 .874 .838 r
.8363 .41894 m .83762 .41772 L .83764 .41453 L F
.876 .879 .834 r
.83764 .41453 m .83762 .41772 L .84012 .41458 L F
.946 .627 .397 r
.54713 .5344 m .54431 .53012 L .54725 .53169 L F
.024 0 .18 r
.26092 .62298 m .26253 .62269 L .26288 .62005 L F
0 0 0 r
.2595 .62393 m .26253 .62269 L .26092 .62298 L F
.639 .787 .953 r
.79972 .43073 m .80316 .43146 L .80224 .42977 L F
.482 .692 .96 r
.80316 .43146 m .80498 .42957 L .80224 .42977 L F
.80316 .43146 m .80592 .43136 L .80498 .42957 L F
.753 .978 .918 r
.23227 .7263 m .22903 .72752 L .23023 .72716 L F
.355 .323 .685 r
.23371 .72345 m .23227 .7263 L .23023 .72716 L F
.23371 .72345 m .23438 .72711 L .23227 .7263 L F
.27 .376 .788 r
.23438 .72711 m .23335 .7278 L .23227 .7263 L F
.58 .395 .595 r
.33479 .59838 m .33222 .60121 L .33265 .59908 L F
.058 0 .206 r
.24675 .6842 m .24359 .68785 L .24544 .68751 L F
.664 .677 .852 r
.24393 .68996 m .24544 .68751 L .24359 .68785 L F
.853 .778 .275 r
.28673 .56538 m .28613 .56691 L .28608 .56357 L F
.28673 .56538 m .28624 .56794 L .28613 .56691 L F
.519 .228 .412 r
.34095 .5924 m .33992 .59548 L .33752 .59553 L F
.553 .401 .628 r
.34287 .59132 m .33992 .59548 L .34095 .5924 L F
.615 .47 .662 r
.32741 .60523 m .32772 .60801 L .32515 .60833 L F
.61 .444 .633 r
.32772 .60801 m .3253 .61099 L .32515 .60833 L F
.344 .461 .835 r
.16358 .60507 m .16576 .60902 L .16653 .6069 L F
.544 .687 .932 r
.16653 .6069 m .16576 .60902 L .16786 .60832 L F
.496 .782 .996 r
.25103 .67173 m .25314 .67278 L .25023 .67263 L F
.805 .617 .647 r
.25314 .67278 m .24974 .67473 L .25023 .67263 L F
0 0 .058 r
.25103 .67173 m .25023 .67263 L .24974 .67473 L F
.616 .49 .687 r
.3435 .57755 m .34607 .57764 L .34614 .57424 L F
.632 .895 .575 r
.34376 .58019 m .34607 .57764 L .3435 .57755 L F
.616 .49 .687 r
.3435 .57755 m .34607 .57764 L .34614 .57424 L F
.371 .092 .355 r
.34607 .57764 m .34376 .58019 L .3435 .57755 L F
0 0 0 r
.27027 .535 m .27255 .53447 L .27392 .53409 L F
.166 .705 .771 r
.27255 .53447 m .27624 .53402 L .27392 .53409 L F
.723 .682 .81 r
.81341 .43606 m .81721 .43677 L .81621 .43328 L F
.756 .701 .8 r
.81621 .43328 m .81721 .43677 L .81998 .43393 L F
0 0 0 r
.48891 .57356 m .48935 .57344 L .49037 .57365 L F
.48935 .57344 m .48891 .57356 L .49037 .57365 L F
.372 .198 .511 r
.3082 .58961 m .3106 .58898 L .31057 .58601 L F
.344 .1 .393 r
.3082 .58961 m .30987 .59138 L .3106 .58898 L F
.3082 .58961 m .30784 .59213 L .30987 .59138 L F
.481 .267 .512 r
.28341 .61108 m .28583 .60775 L .28361 .60817 L F
.405 .071 .282 r
.30803 .63284 m .3073 .63486 L .30498 .63534 L F
.522 .181 .331 r
.30803 .63284 m .31 .63462 L .3073 .63486 L F
.6 .456 .657 r
.31039 .62959 m .31063 .63275 L .30803 .63284 L F
.529 .18 .319 r
.31063 .63275 m .31 .63462 L .30803 .63284 L F
.652 .587 .769 r
.31268 .58031 m .30949 .57732 L .31096 .57675 L F
.348 .825 .82 r
.31268 .58031 m .31099 .58052 L .30851 .5813 L F
.524 .659 .921 r
.31267 .58014 m .31268 .58031 L .3126 .58016 L F
.31266 .57721 m .31492 .5797 L .31268 .58031 L F
0 0 0 r
.31492 .5797 m .31099 .58052 L .31268 .58031 L F
.31385 .57992 m .31308 .5801 L .31099 .58052 L F
.31492 .5797 m .31423 .57985 L .31385 .57992 L F
.31423 .57985 m .31308 .5801 L .31385 .57992 L F
.524 .659 .921 r
.31266 .57721 m .31267 .58014 L .31096 .57675 L F
.31267 .58014 m .3126 .58016 L .31096 .57675 L F
.429 .292 .592 r
.31268 .58031 m .31478 .58271 L .31492 .5797 L F
.31268 .58031 m .31292 .58367 L .31478 .58271 L F
.527 .346 .579 r
.28144 .61692 m .28385 .61369 L .28193 .61448 L F
.171 .23 .683 r
.28368 .57993 m .28411 .57618 L .28257 .57852 L F
.785 .537 .56 r
.50169 .59184 m .50456 .58992 L .50128 .58948 L F
.83 .945 .898 r
.21638 .74554 m .21796 .74606 L .21911 .74429 L F
.644 .838 .975 r
.79709 .43172 m .79872 .42948 L .79601 .43022 L F
.79709 .43172 m .79972 .43073 L .79872 .42948 L F
.921 .898 .788 r
.54401 .56867 m .54441 .56487 L .54566 .56563 L F
.994 .769 .484 r
.54566 .56563 m .54441 .56487 L .54395 .56218 L F
.898 .842 .782 r
.83764 .41453 m .84012 .41458 L .84111 .41254 L F
.176 .571 .936 r
.23698 .62474 m .23668 .62575 L .23497 .62459 L F
.23698 .62474 m .23861 .62612 L .23668 .62575 L F
.306 0 0 r
.25116 .62657 m .25258 .62613 L .24883 .62638 L F
.201 0 0 r
.25341 .62648 m .25258 .62613 L .25116 .62657 L F
.25341 .62648 m .25508 .62636 L .25258 .62613 L F
.522 .015 0 r
.46335 .64675 m .46641 .647 L .46397 .64587 L F
.647 .818 .965 r
.55327 .5894 m .55705 .58982 L .55536 .58862 L F
.828 .836 .854 r
.55536 .58862 m .55705 .58982 L .55969 .58689 L F
.72 .598 .72 r
.24393 .68996 m .24485 .69399 L .24729 .69075 L F
.241 0 .299 r
.32531 .56073 m .32372 .55966 L .32601 .55923 L F
.32531 .56073 m .32345 .56155 L .32372 .55966 L F
.58 .376 .569 r
.32581 .61382 m .32281 .61689 L .32308 .6144 L F
.641 .47 .635 r
.31567 .62344 m .31564 .62645 L .31294 .62654 L F
.323 .137 .466 r
.31774 .62026 m .31749 .62288 L .31567 .62344 L F
.599 .435 .631 r
.31869 .62574 m .31567 .62344 L .31749 .62288 L F
.31869 .62574 m .31564 .62645 L .31567 .62344 L F
.83 .684 .702 r
.56059 .58013 m .56201 .58363 L .56262 .58109 L F
.363 .833 .872 r
.24547 .53501 m .24544 .53564 L .24317 .53496 L F
.24547 .53501 m .24765 .53497 L .24544 .53564 L F
.431 .163 .404 r
.29663 .59609 m .29633 .59808 L .2942 .59746 L F
.235 .066 .437 r
.27664 .6205 m .27803 .62215 L .27891 .62006 L F
.27664 .6205 m .27642 .62302 L .27803 .62215 L F
.303 .782 .919 r
.32122 .54768 m .31858 .54714 L .31637 .54747 L F
.682 .951 .954 r
.32125 .5457 m .32122 .54768 L .32274 .54657 L F
.32125 .5457 m .31858 .54714 L .32122 .54768 L F
.785 .537 .56 r
.50169 .59184 m .50389 .59263 L .50456 .58992 L F
.664 .677 .852 r
.24393 .68996 m .24729 .69075 L .24544 .68751 L F
.737 .707 .822 r
.24544 .68751 m .24729 .69075 L .25008 .68802 L F
.238 0 0 r
.24729 .69075 m .24997 .68982 L .25008 .68802 L F
0 0 .177 r
.26288 .62005 m .26459 .61906 L .26519 .61681 L F
.127 0 .21 r
.26288 .62005 m .26425 .62152 L .26459 .61906 L F
.26288 .62005 m .26253 .62269 L .26425 .62152 L F
.697 .719 .866 r
.3159 .57133 m .31565 .57452 L .3131 .5731 L F
.354 0 .075 r
.31565 .57452 m .31266 .57721 L .3131 .5731 L F
.31565 .57452 m .31495 .57703 L .31266 .57721 L F
.476 .451 .751 r
.31786 .56977 m .31565 .57452 L .3159 .57133 L F
.414 .341 .666 r
.31716 .57421 m .31716 .57769 L .31962 .57632 L F
.31716 .57421 m .31962 .57632 L .31954 .57373 L F
.81 .575 .582 r
.31829 .57392 m .31495 .57703 L .31565 .57452 L F
.912 .579 .107 r
.18368 .60705 m .18453 .60854 L .18302 .60466 L F
.289 .679 .973 r
.18482 .60726 m .18453 .60854 L .18368 .60705 L F
.18482 .60726 m .18714 .60884 L .18453 .60854 L F
.898 .842 .782 r
.83764 .41453 m .84111 .41254 L .83993 .41124 L F
.471 .739 .986 r
.23662 .64163 m .23771 .64013 L .23532 .64048 L F
.23662 .64163 m .23884 .64138 L .23771 .64013 L F
.607 .304 .429 r
.27105 .62866 m .27373 .62873 L .27155 .62659 L F
.531 .31 .524 r
.27155 .62659 m .27373 .62873 L .27401 .62616 L F
.243 .085 .458 r
.4719 .62894 m .47258 .6316 L .47335 .62685 L F
.31 0 0 r
.23696 .53564 m .24098 .53513 L .23907 .53579 L F
.269 .541 .921 r
.20175 .60927 m .20129 .61093 L .19888 .60826 L F
.20175 .60927 m .20292 .61101 L .20129 .61093 L F
.984 .904 .6 r
.82958 .40399 m .8292 .40566 L .82861 .40389 L F
.879 .83 .795 r
.8292 .40566 m .82626 .40602 L .82861 .40389 L F
.8292 .40566 m .82693 .40888 L .82626 .40602 L F
.348 .219 .559 r
.3108 .57412 m .31096 .57675 L .30949 .57732 L F
0 0 0 r
.29281 .55108 m .29028 .55252 L .29482 .55013 L F
.215 .007 .368 r
.29281 .55108 m .29482 .55013 L .29509 .54852 L F
.29418 .5487 m .29509 .54852 L .29544 .54653 L F
.29281 .55108 m .29509 .54852 L .29418 .5487 L F
0 0 0 r
.29778 .54727 m .29697 .54771 L .29685 .54762 L F
.29778 .54727 m .29685 .54762 L .29702 .54703 L F
.273 0 .238 r
.29482 .55013 m .29602 .55055 L .29639 .54924 L F
.29578 .54894 m .29639 .54924 L .29685 .54762 L F
.29482 .55013 m .29639 .54924 L .29578 .54894 L F
.579 .32 .489 r
.29544 .54653 m .29509 .54852 L .29656 .5474 L F
0 0 0 r
.29702 .54703 m .29685 .54762 L .29544 .54653 L F
.579 .32 .489 r
.29544 .54653 m .29779 .54646 L .29778 .54727 L F
.29509 .54852 m .29667 .54784 L .29779 .54646 L F
0 0 0 r
.29697 .54771 m .29559 .54845 L .29544 .54653 L F
.29559 .54845 m .29436 .5491 L .29491 .54779 L F
.29559 .54845 m .29491 .54779 L .29544 .54653 L F
.29778 .54727 m .29758 .54745 L .29697 .54771 L F
.273 0 .238 r
.29685 .54762 m .29683 .54779 L .29779 .54646 L F
.784 .341 .197 r
.29827 .54798 m .29756 .54783 L .29778 .54727 L F
.2974 .54821 m .29736 .54764 L .29778 .54727 L F
.349 .25 .599 r
.29779 .54646 m .29827 .54798 L .29778 .54727 L F
.853 .532 .443 r
.29779 .54646 m .29737 .54779 L .29827 .54798 L F
.29737 .54779 m .29646 .5507 L .29827 .54798 L F
.784 .341 .197 r
.29827 .54798 m .2974 .54821 L .29756 .54783 L F
.273 0 .238 r
.29683 .54779 m .29646 .5507 L .29737 .54779 L F
.784 .341 .197 r
.2974 .54821 m .29637 .54848 L .29736 .54764 L F
.273 0 .238 r
.29736 .54764 m .29737 .54779 L .29742 .54762 L F
.29683 .54779 m .29737 .54779 L .29736 .54764 L F
0 0 0 r
.29758 .54745 m .29736 .54764 L .29697 .54771 L F
.29736 .54764 m .29694 .54776 L .29697 .54771 L F
.273 0 .238 r
.29683 .54779 m .29742 .54762 L .29779 .54646 L F
0 0 0 r
.29736 .54764 m .2967 .5482 L .29694 .54776 L F
.273 0 .238 r
.29602 .55055 m .29646 .5507 L .29685 .54762 L F
.579 .32 .489 r
.29544 .54653 m .29656 .5474 L .29779 .54646 L F
.29509 .54852 m .29482 .55013 L .29667 .54784 L F
0 0 0 r
.29697 .54771 m .2967 .5482 L .29567 .5484 L F
.94 .675 .506 r
.29827 .54798 m .29646 .5507 L .29637 .54848 L F
.847 .994 .746 r
.29663 .54637 m .29637 .54848 L .29828 .55016 L F
.29841 .55023 m .29828 .55016 L .29845 .55032 L F
.29663 .54637 m .29828 .55016 L .29841 .55023 L F
0 0 0 r
.29567 .5484 m .29637 .54848 L .29436 .5491 L F
.2967 .5482 m .29637 .54848 L .29567 .5484 L F
.326 0 0 r
.29081 .55165 m .29482 .55013 L .29028 .55252 L F
.29123 .55096 m .29258 .55065 L .29081 .55165 L F
.29258 .55065 m .29482 .55013 L .29081 .55165 L F
.287 0 .222 r
.29637 .54848 m .2963 .54855 L .29436 .5491 L F
.326 0 0 r
.29123 .55096 m .29353 .55099 L .29482 .55013 L F
.287 0 .222 r
.2963 .54855 m .29353 .55099 L .29405 .54982 L F
.2963 .54855 m .29405 .54982 L .29436 .5491 L F
.685 .887 .972 r
.2906 .55318 m .29123 .55096 L .29028 .55252 L F
.2906 .55318 m .28878 .55236 L .29123 .55096 L F
.728 .99 .865 r
.2539 .67128 m .25628 .67053 L .25314 .67278 L F
0 0 0 r
.25625 .67081 m .25628 .67053 L .2539 .67128 L F
.25625 .67081 m .2586 .66918 L .25628 .67053 L F
.835 .645 .647 r
.22011 .55298 m .21645 .55526 L .21751 .55323 L F
.805 .617 .647 r
.25314 .67278 m .25335 .67543 L .24974 .67473 L F
.728 .99 .865 r
.2539 .67128 m .25314 .67278 L .25103 .67173 L F
.115 0 0 r
.27855 .5333 m .28095 .53322 L .28284 .53274 L F
0 0 0 r
.28095 .53322 m .2848 .53262 L .28284 .53274 L F
.354 0 0 r
.29198 .54804 m .28758 .54585 L .28925 .54705 L F
.11 .177 .653 r
.16667 .76012 m .16735 .76102 L .16695 .76132 L F
0 0 0 r
.16695 .76132 m .16735 .76102 L .16652 .76177 L F
.301 .283 .671 r
.14927 .59293 m .15033 .58875 L .1492 .58899 L F
.14927 .59293 m .15072 .59257 L .15033 .58875 L F
.322 .372 .759 r
.14927 .59293 m .15181 .595 L .15072 .59257 L F
0 0 0 r
.26965 .62229 m .26785 .62357 L .27054 .62096 L F
.136 0 .386 r
.26965 .62229 m .26698 .62603 L .26785 .62357 L F
.221 0 0 r
.23551 .54881 m .23381 .54921 L .23122 .54914 L F
0 0 0 r
.23763 .54848 m .23381 .54921 L .23551 .54881 L F
.869 .874 .838 r
.8363 .41894 m .83764 .41453 L .83503 .41758 L F
.247 .76 .838 r
.24765 .53497 m .24991 .53455 L .25144 .53456 L F
.37 .836 .883 r
.25144 .53456 m .25211 .53388 L .25367 .53422 L F
.25144 .53456 m .24991 .53455 L .25211 .53388 L F
.388 0 0 r
.24437 .69901 m .24208 .69849 L .2406 .6995 L F
0 0 0 r
.20968 .54018 m .21405 .53878 L .21113 .53978 L F
.84 .576 .539 r
.55152 .54999 m .54864 .54995 L .54849 .54756 L F
.499 .729 .975 r
.31358 .53694 m .31246 .53897 L .31116 .53749 L F
.31358 .53694 m .31557 .53882 L .31246 .53897 L F
.644 .317 .402 r
.16626 .76103 m .16735 .76102 L .16667 .76012 L F
.297 0 0 r
.25545 .55305 m .25419 .55313 L .25147 .55257 L F
.474 .895 .871 r
.25632 .55217 m .25419 .55313 L .25545 .55305 L F
.28 .706 .968 r
.22815 .62414 m .22621 .62416 L .22455 .62326 L F
.473 .105 .258 r
.29317 .64205 m .29013 .64387 L .2907 .64223 L F
.029 0 .012 r
.18504 .57073 m .18202 .57379 L .18285 .57131 L F
0 0 0 r
.18998 .54963 m .18787 .55032 L .18587 .55175 L F
.435 .457 .783 r
.25785 .68716 m .25616 .68779 L .25548 .68428 L F
.277 .058 .391 r
.25735 .68942 m .25616 .68779 L .25785 .68716 L F
.214 .044 .423 r
.25735 .68942 m .25583 .69045 L .25616 .68779 L F
.611 .429 .612 r
.31304 .62916 m .31039 .62959 L .31294 .62654 L F
.526 .363 .604 r
.31533 .62861 m .31294 .62654 L .31564 .62645 L F
.31533 .62861 m .31304 .62916 L .31294 .62654 L F
.823 .932 .557 r
.27459 .59858 m .27279 .60203 L .27301 .60047 L F
0 0 .272 r
.27169 .60435 m .27301 .60047 L .27279 .60203 L F
.853 .746 .745 r
.82715 .39598 m .82821 .39978 L .83021 .39634 L F
.689 .522 .656 r
.33313 .55643 m .33315 .55929 L .33577 .55604 L F
.921 .898 .788 r
.54401 .56867 m .54261 .56778 L .54441 .56487 L F
.936 .77 .651 r
.54401 .56867 m .54145 .56998 L .54261 .56778 L F
.54401 .56867 m .54317 .57108 L .54145 .56998 L F
.63 .162 .123 r
.27326 .64733 m .2731 .64967 L .27152 .64762 L F
.984 .904 .6 r
.82958 .40399 m .82861 .40389 L .82854 .40212 L F
.731 .759 .875 r
.82854 .40212 m .83189 .40271 L .82958 .40399 L F
.471 .215 .444 r
.32052 .6174 m .3201 .61977 L .31774 .62026 L F
.604 .384 .556 r
.32281 .61689 m .3201 .61977 L .32052 .6174 L F
.534 .371 .606 r
.3297 .60173 m .32977 .60478 L .32741 .60523 L F
.548 .421 .66 r
.32977 .60478 m .32772 .60801 L .32741 .60523 L F
0 0 .146 r
.23251 .73025 m .23335 .7278 L .23438 .72711 L F
.172 0 0 r
.33076 .56758 m .33306 .56701 L .33467 .56535 L F
.67 .227 .191 r
.33467 .56535 m .33306 .56701 L .33674 .56731 L F
.667 .819 .957 r
.8206 .409 m .8169 .40861 L .81948 .40756 L F
.743 .862 .935 r
.8218 .40622 m .8206 .409 L .81948 .40756 L F
.8218 .40622 m .82331 .40765 L .8206 .409 L F
.556 .644 .892 r
.18344 .62006 m .18804 .62289 L .18555 .61961 L F
.451 .634 .933 r
.18804 .62289 m .18706 .61955 L .18555 .61961 L F
.18804 .62289 m .18975 .62237 L .18706 .61955 L F
.492 .839 .996 r
.43029 .66645 m .42614 .66616 L .42865 .66548 L F
.43029 .66645 m .42614 .66616 L .42865 .66548 L F
.112 .512 .909 r
.33762 .54716 m .33801 .54534 L .33903 .54381 L F
.33762 .54716 m .33544 .54522 L .33801 .54534 L F
.558 .202 .32 r
.33738 .5457 m .33722 .54582 L .33544 .54522 L F
.112 .512 .909 r
.33762 .54716 m .33757 .54593 L .33722 .54582 L F
.33612 .54583 m .33722 .54582 L .33544 .54522 L F
.33762 .54716 m .33724 .54587 L .33666 .54631 L F
.023 .418 .862 r
.33762 .54716 m .3394 .54802 L .33757 .54576 L F
.829 .852 .864 r
.33757 .54576 m .3394 .54802 L .34159 .54497 L F
.314 .476 .86 r
.34071 .54381 m .34159 .54497 L .33903 .54381 L F
.829 .852 .864 r
.33757 .54576 m .34159 .54497 L .3403 .54411 L F
0 0 0 r
.338 .54551 m .33639 .54736 L .33731 .54581 L F
.33753 .54565 m .33731 .54581 L .33738 .5457 L F
.3403 .54411 m .33738 .5457 L .33757 .54576 L F
.338 .54551 m .33731 .54581 L .33753 .54565 L F
.112 .512 .909 r
.33666 .54631 m .33722 .54582 L .33612 .54583 L F
.33724 .54587 m .33722 .54582 L .33666 .54631 L F
.096 0 0 r
.33639 .54736 m .33495 .54742 L .33722 .54582 L F
.33731 .54581 m .33722 .54582 L .33738 .5457 L F
.33639 .54736 m .33722 .54582 L .33731 .54581 L F
.558 .202 .32 r
.33722 .54582 m .33495 .54742 L .33544 .54522 L F
.112 .512 .909 r
.33757 .54593 m .33757 .54576 L .33544 .54522 L F
.746 .605 .701 r
.33315 .55929 m .33647 .56014 L .33577 .55604 L F
.648 .609 .797 r
.33647 .56014 m .33988 .56039 L .33831 .55826 L F
.895 .559 .071 r
.33805 .55974 m .33805 .55975 L .33717 .55924 L F
.939 .899 .503 r
.33809 .55976 m .33709 .56107 L .33772 .55963 L F
.895 .559 .071 r
.33823 .5608 m .33769 .56067 L .33717 .55924 L F
.874 .488 .305 r
.33709 .56107 m .33867 .56335 L .33809 .55976 L F
.895 .559 .071 r
.33812 .55998 m .33867 .56335 L .33805 .55974 L F
.476 .895 .826 r
.3413 .55882 m .33779 .5607 L .33988 .56039 L F
.33779 .5607 m .33822 .5608 L .33988 .56039 L F
.895 .559 .071 r
.33823 .5608 m .33867 .56335 L .33769 .56067 L F
0 0 .257 r
.33717 .55924 m .3378 .56098 L .33791 .56119 L F
.3378 .56098 m .33867 .56335 L .33791 .56126 L F
.037 .234 .735 r
.33791 .56126 m .33867 .56335 L .33709 .56107 L F
.33921 .56155 m .33867 .56335 L .33791 .56126 L F
0 0 .257 r
.33791 .56126 m .33867 .56335 L .33816 .56191 L F
.3378 .56098 m .33816 .56191 L .33791 .56119 L F
.037 .234 .735 r
.33921 .56155 m .33791 .56126 L .3413 .55882 L F
.33791 .56126 m .33781 .56124 L .33788 .56118 L F
.33791 .56126 m .33788 .56118 L .3413 .55882 L F
.476 .895 .826 r
.33779 .5607 m .33709 .56107 L .33822 .5608 L F
.037 .234 .735 r
.33781 .56124 m .33709 .56107 L .33779 .5607 L F
.33781 .56124 m .33779 .5607 L .3413 .55882 L F
.895 .559 .071 r
.33805 .55975 m .33823 .5608 L .33778 .56014 L F
.33777 .55964 m .33778 .56014 L .33734 .55949 L F
.33805 .55975 m .33778 .56014 L .33777 .55964 L F
.33805 .55975 m .33734 .55949 L .33717 .55924 L F
.952 .913 .544 r
.33809 .55976 m .33717 .55924 L .33831 .55826 L F
.939 .899 .503 r
.33809 .55976 m .33772 .55963 L .33831 .55826 L F
.895 .559 .071 r
.33809 .55976 m .33812 .55998 L .33805 .55974 L F
.346 .326 .693 r
.33577 .55604 m .33647 .56014 L .33776 .55882 L F
.33731 .55738 m .33776 .55882 L .33831 .55826 L F
.33577 .55604 m .33776 .55882 L .33731 .55738 L F
.27 .776 .833 r
.2848 .53262 m .28721 .53209 L .28883 .53215 L F
0 .18 .605 r
.28949 .53253 m .28883 .53215 L .28721 .53209 L F
.28949 .53253 m .2898 .53277 L .28883 .53215 L F
.446 0 0 r
.28721 .53209 m .28556 .53253 L .28949 .53253 L F
.182 0 0 r
.28804 .53258 m .28932 .53241 L .28949 .53253 L F
.28932 .53241 m .29177 .53209 L .28949 .53253 L F
0 .18 .605 r
.28949 .53253 m .29113 .53362 L .2898 .53277 L F
0 0 0 r
.20968 .54018 m .21193 .53962 L .21405 .53878 L F
.098 0 0 r
.21405 .53878 m .21193 .53962 L .21567 .5388 L F
0 0 .204 r
.28055 .60117 m .27934 .60475 L .27949 .60227 L F
.886 .703 .65 r
.56027 .58242 m .56201 .58363 L .56059 .58013 L F
.84 .76 .775 r
.55795 .58557 m .56201 .58363 L .56027 .58242 L F
.55795 .58557 m .55969 .58689 L .56201 .58363 L F
.724 .245 0 r
.20803 .61583 m .20821 .61537 L .20688 .61375 L F
.20803 .61583 m .20921 .61665 L .20821 .61537 L F
.597 .531 .751 r
.81892 .40021 m .81922 .40278 L .82202 .40131 L F
.709 .684 .143 r
.54256 .57775 m .54238 .57855 L .54174 .57696 L F
.54256 .57775 m .54207 .58034 L .54238 .57855 L F
.495 0 0 r
.50841 .56321 m .50772 .56352 L .50503 .5621 L F
.834 .945 .585 r
.50889 .56234 m .50772 .56352 L .50841 .56321 L F
.516 0 0 r
.50716 .56152 m .50909 .56216 L .50503 .5621 L F
.50909 .56216 m .50891 .56232 L .50503 .5621 L F
.834 .945 .585 r
.50985 .56059 m .50795 .5632 L .50889 .56234 L F
.50795 .5632 m .50772 .56352 L .50889 .56234 L F
.516 0 0 r
.50909 .56216 m .50971 .56237 L .50891 .56232 L F
.532 .648 .908 r
.17466 .58872 m .17459 .59198 L .17269 .589 L F
.17466 .58872 m .17749 .59188 L .17459 .59198 L F
.462 .479 .79 r
.17736 .59259 m .17459 .59198 L .17749 .59188 L F
.564 .615 .862 r
.34076 .57343 m .33993 .57422 L .33852 .57287 L F
.403 .566 .901 r
.29679 .53438 m .29673 .53733 L .29474 .53451 L F
.29679 .53438 m .29877 .53747 L .29673 .53733 L F
0 0 0 r
.27202 .61932 m .27054 .62096 L .27333 .61782 L F
.2741 .61647 m .27202 .61932 L .27333 .61782 L F
.297 .793 .79 r
.47717 .62532 m .47545 .62599 L .47732 .62532 L F
.47717 .62532 m .47475 .62606 L .47545 .62599 L F
.065 0 0 r
.19622 .5645 m .19309 .56705 L .19441 .56551 L F
.834 .549 .507 r
.55176 .5184 m .55347 .52129 L .55192 .51813 L F
0 0 0 r
.27037 .62145 m .27054 .62096 L .27202 .61932 L F
.27037 .62145 m .26965 .62229 L .27054 .62096 L F
.572 .297 .46 r
.27495 .5832 m .27414 .58608 L .277 .58566 L F
.27495 .5832 m .27414 .58608 L .277 .58566 L F
.589 .447 .657 r
.3131 .63233 m .31039 .62959 L .31304 .62916 L F
.3131 .63233 m .31063 .63275 L .31039 .62959 L F
.602 .084 0 r
.21058 .61824 m .20921 .61665 L .20803 .61583 L F
.85 .873 .857 r
.31786 .56977 m .31993 .57095 L .32193 .56852 L F
.744 .961 .67 r
.32193 .56852 m .31993 .57095 L .32071 .56959 L F
.083 .121 .603 r
.31993 .57095 m .3217 .5731 L .32071 .56959 L F
.41 .19 .466 r
.31954 .57373 m .3217 .5731 L .31993 .57095 L F
.142 0 .106 r
.17072 .56133 m .17142 .56294 L .17236 .56163 L F
.17072 .56133 m .16954 .56393 L .17142 .56294 L F
.593 .552 .778 r
.23731 .70394 m .23934 .70083 L .23577 .70243 L F
.23731 .70394 m .2397 .70322 L .23934 .70083 L F
.093 0 0 r
.21567 .5388 m .21798 .53868 L .2202 .5381 L F
.518 .915 .825 r
.2202 .5381 m .21992 .53751 L .22235 .53729 L F
.2202 .5381 m .21798 .53868 L .21992 .53751 L F
.694 .582 .726 r
.19647 .78839 m .19756 .78551 L .19623 .78532 L F
.19756 .78551 m .19803 .78426 L .19623 .78532 L F
.112 0 0 r
.19647 .78839 m .19779 .7876 L .19894 .78738 L F
.19779 .7876 m .20086 .78576 L .19894 .78738 L F
.476 .825 .549 r
.19894 .78738 m .20086 .78576 L .20247 .78433 L F
.19894 .78738 m .20247 .78433 L .20107 .78731 L F
.44 .425 .745 r
.2008 .78704 m .19894 .78738 L .20107 .78731 L F
.478 .825 .998 r
.19883 .78566 m .19623 .78532 L .19845 .78564 L F
.20086 .78576 m .19645 .78534 L .19883 .78566 L F
.19645 .78534 m .19623 .78532 L .19883 .78566 L F
.44 .425 .745 r
.19951 .78575 m .19894 .78738 L .2008 .78704 L F
.6 .944 .93 r
.20247 .78433 m .20086 .78576 L .19883 .78566 L F
.44 .425 .745 r
.19916 .78539 m .19883 .78566 L .19918 .78541 L F
.19803 .78426 m .19871 .78546 L .19916 .78539 L F
.19871 .78546 m .19883 .78566 L .19916 .78539 L F
.6 .944 .93 r
.20247 .78433 m .19883 .78566 L .19918 .78541 L F
.44 .425 .745 r
.19803 .78426 m .19918 .78541 L .20031 .78481 L F
.6 .944 .93 r
.19926 .78537 m .19918 .78541 L .19922 .78538 L F
.20247 .78433 m .19918 .78541 L .19926 .78537 L F
.20247 .78433 m .19926 .78537 L .20109 .785 L F
.44 .425 .745 r
.19918 .78541 m .20107 .78731 L .20031 .78481 L F
.6 .944 .93 r
.19926 .78537 m .19922 .78538 L .20109 .785 L F
.44 .425 .745 r
.20031 .78481 m .20041 .78514 L .20109 .785 L F
.20041 .78514 m .20107 .78731 L .20109 .785 L F
.19918 .78541 m .19883 .78566 L .19951 .78575 L F
.6 .944 .93 r
.19922 .78538 m .19843 .78564 L .19991 .78528 L F
.19922 .78538 m .19991 .78528 L .20109 .785 L F
.19922 .78538 m .19883 .78566 L .19843 .78564 L F
.44 .425 .745 r
.19803 .78426 m .19842 .7856 L .19883 .78566 L F
.19842 .7856 m .19894 .78738 L .19951 .78575 L F
.694 .582 .726 r
.19647 .78839 m .19894 .78738 L .19842 .7856 L F
.19756 .78551 m .19842 .7856 L .19803 .78426 L F
.19647 .78839 m .19842 .7856 L .19756 .78551 L F
.478 .825 .998 r
.19845 .78564 m .19756 .78551 L .19843 .78564 L F
.19756 .78551 m .19623 .78532 L .19754 .78551 L F
.19756 .78551 m .19754 .78551 L .19843 .78564 L F
.288 .444 .843 r
.19065 .62408 m .19156 .62211 L .18975 .62237 L F
.19065 .62408 m .19334 .62547 L .19156 .62211 L F
.948 .672 .48 r
.28734 .56103 m .28594 .56206 L .28506 .5602 L F
0 .197 .714 r
.28506 .5602 m .28594 .56206 L .28546 .56039 L F
.359 0 0 r
.28531 .55889 m .28506 .5602 L .2831 .55928 L F
.28573 .55881 m .28538 .55955 L .28531 .55889 L F
.28538 .55955 m .28506 .5602 L .28531 .55889 L F
.767 .483 0 r
.28594 .56206 m .28604 .56278 L .28548 .56065 L F
0 .197 .714 r
.28506 .5602 m .28546 .56039 L .28497 .55871 L F
.948 .672 .48 r
.28734 .56103 m .28506 .5602 L .28573 .55881 L F
.767 .483 0 r
.28546 .56039 m .28548 .56065 L .28497 .55871 L F
.28594 .56206 m .28548 .56065 L .28546 .56039 L F
.359 0 0 r
.2831 .55928 m .28506 .5602 L .28189 .5595 L F
.869 .516 .379 r
.5565 .56785 m .5577 .57089 L .5597 .57094 L F
.916 .691 .583 r
.5577 .57089 m .55939 .57394 L .5597 .57094 L F
.632 .801 .964 r
.3496 .56528 m .34719 .5652 L .34943 .56438 L F
0 0 .437 r
.34943 .56438 m .35069 .56801 L .3496 .56528 L F
.545 .912 .955 r
.19476 .60751 m .19167 .60753 L .19568 .60676 L F
.691 .348 .39 r
.29544 .54653 m .29436 .5491 L .29198 .54804 L F
.524 .682 .938 r
.18273 .59527 m .18208 .59826 L .18019 .59641 L F
.18273 .59527 m .18467 .59796 L .18208 .59826 L F
.666 .77 .927 r
.21256 .63769 m .21699 .63812 L .21465 .63699 L F
.342 .715 .985 r
.21699 .63812 m .21704 .63683 L .21465 .63699 L F
.21699 .63812 m .21864 .63794 L .21704 .63683 L F
.165 .701 .826 r
.24158 .6413 m .24113 .64117 L .23884 .64138 L F
.168 0 0 r
.24113 .64117 m .24141 .64203 L .2403 .64094 L F
.43 .757 .995 r
.23884 .64138 m .24113 .64117 L .23931 .63997 L F
.168 0 0 r
.24113 .64117 m .2403 .64094 L .23931 .63997 L F
.165 .701 .826 r
.24301 .64126 m .24113 .64117 L .24158 .6413 L F
.13 .677 .808 r
.2451 .64112 m .24113 .64117 L .24301 .64126 L F
.633 .74 .926 r
.24301 .64126 m .24673 .64149 L .2451 .64112 L F
.763 .688 .779 r
.81621 .43328 m .81998 .43393 L .81906 .43017 L F
.564 .934 .815 r
.31441 .54766 m .31264 .54804 L .31291 .54847 L F
.292 .785 .749 r
.31469 .54732 m .31441 .54766 L .31637 .54747 L F
.31469 .54732 m .31264 .54804 L .31441 .54766 L F
.261 .15 .533 r
.14994 .58626 m .15168 .58236 L .14997 .58361 L F
.174 .594 .939 r
.24314 .6248 m .24245 .62554 L .24082 .62521 L F
.24314 .6248 m .24484 .62609 L .24245 .62554 L F
.504 .702 .959 r
.19792 .60636 m .19707 .60835 L .19568 .60676 L F
.416 .601 .922 r
.19792 .60636 m .19888 .60826 L .19707 .60835 L F
.294 .767 .935 r
.26372 .66328 m .25888 .66292 L .2613 .66215 L F
.119 .612 .908 r
.26575 .66343 m .26372 .66328 L .2613 .66215 L F
.064 0 0 r
.26372 .66328 m .26575 .66343 L .26293 .66566 L F
.607 .356 .511 r
.30181 .63843 m .29896 .64101 L .29952 .63897 L F
.493 .264 .495 r
.44885 .65047 m .45164 .65031 L .4517 .64785 L F
.44885 .65047 m .45164 .65031 L .4517 .64785 L F
.458 .761 .995 r
.2593 .64449 m .25843 .64264 L .25672 .64218 L F
.2593 .64449 m .26179 .64415 L .25843 .64264 L F
.685 .244 .199 r
.50171 .55542 m .5037 .55732 L .50471 .55573 L F
.985 .789 .557 r
.50623 .55719 m .50471 .55573 L .5037 .55732 L F
.50623 .55719 m .5075 .55559 L .50471 .55573 L F
.333 .694 .981 r
.24673 .64149 m .24735 .64076 L .2451 .64112 L F
.24673 .64149 m .24882 .64197 L .24735 .64076 L F
0 .411 .817 r
.34417 .55752 m .3459 .5588 L .34282 .5571 L F
.976 .728 .495 r
.3459 .5588 m .34257 .55963 L .34282 .5571 L F
.3459 .5588 m .34408 .56046 L .34257 .55963 L F
.3459 .5588 m .34567 .5615 L .34408 .56046 L F
.525 .523 .796 r
.34697 .55508 m .3459 .5588 L .34417 .55752 L F
.34697 .55508 m .34818 .55837 L .3459 .5588 L F
.689 .559 .702 r
.34818 .55837 m .34567 .5615 L .3459 .5588 L F
.797 .314 0 r
.25899 .67058 m .2586 .66918 L .25625 .67081 L F
.25899 .67058 m .2605 .67197 L .2586 .66918 L F
.445 .26 .535 r
.33222 .60121 m .32977 .60478 L .3297 .60173 L F
.512 .436 .707 r
.47198 .62274 m .47475 .62606 L .47385 .62254 L F
.47198 .62274 m .47273 .62722 L .47475 .62606 L F
.615 .392 .555 r
.33752 .59553 m .33479 .59838 L .33493 .59577 L F
.556 .016 0 r
.78979 .40371 m .79048 .40259 L .78681 .40221 L F
.78979 .40371 m .78681 .40221 L .78685 .404 L F
.424 .76 .996 r
.78861 .40272 m .78979 .40371 L .78685 .404 L F
.931 .557 .169 r
.78943 .40429 m .78979 .40371 L .78861 .40272 L F
.79048 .4063 m .78979 .40371 L .78943 .40429 L F
.556 .016 0 r
.78979 .40371 m .79054 .4026 L .79048 .40259 L F
.808 .328 .06 r
.78979 .40371 m .79265 .40524 L .79054 .4026 L F
.794 .297 0 r
.79054 .4026 m .79265 .40524 L .79415 .40595 L F
.876 .784 .757 r
.55041 .54399 m .54671 .54598 L .54865 .54268 L F
.55041 .54399 m .54849 .54756 L .54671 .54598 L F
.828 .836 .854 r
.55536 .58862 m .55969 .58689 L .55795 .58557 L F
.801 .725 .78 r
.82145 .42726 m .82477 .42767 L .82364 .42391 L F
.695 .663 .814 r
.82477 .42767 m .82614 .42306 L .82364 .42391 L F
.82477 .42767 m .82732 .42652 L .82614 .42306 L F
.912 .678 .571 r
.55301 .5638 m .55614 .56304 L .55341 .56112 L F
.55301 .5638 m .55488 .56473 L .55614 .56304 L F
.293 .105 .446 r
.15449 .57417 m .15597 .57607 L .15664 .57389 L F
.15449 .57417 m .15428 .57692 L .15597 .57607 L F
.736 .747 .86 r
.33753 .54095 m .33551 .54479 L .33407 .54072 L F
.668 .522 .677 r
.33903 .54381 m .33551 .54479 L .33753 .54095 L F
.33903 .54381 m .33801 .54534 L .33551 .54479 L F
.222 .307 .74 r
.32374 .53921 m .32263 .54137 L .32188 .53946 L F
.757 .348 .276 r
.24974 .67473 m .25335 .67543 L .25168 .67698 L F
.993 .83 .578 r
.25168 .67698 m .25335 .67543 L .25273 .67798 L F
.25168 .67698 m .25335 .67543 L .25273 .67798 L F
.551 .812 .994 r
.22658 .64123 m .22687 .63941 L .22624 .63998 L F
.22658 .64123 m .22851 .64056 L .22687 .63941 L F
.228 .357 .787 r
.35105 .57332 m .34856 .57129 L .35091 .5707 L F
.448 .154 .373 r
.3449 .54837 m .34256 .5493 L .34316 .54648 L F
.292 0 0 r
.23122 .54914 m .2269 .55093 L .22896 .54972 L F
.562 .187 .288 r
.27829 .64536 m .28165 .64475 L .28021 .64733 L F
.486 .203 .41 r
.28165 .64475 m .28361 .64632 L .28021 .64733 L F
.28165 .64475 m .28404 .64435 L .28361 .64632 L F
.852 .996 .762 r
.34468 .5815 m .3453 .58257 L .34463 .58153 L F
.34571 .58081 m .34551 .58167 L .34468 .5815 L F
.34551 .58167 m .3453 .58257 L .34468 .5815 L F
.34596 .57973 m .34571 .58081 L .34376 .58019 L F
.34571 .58081 m .34463 .58153 L .34376 .58019 L F
.34596 .57973 m .34465 .58206 L .3453 .58257 L F
.584 .331 .499 r
.34632 .58185 m .35029 .58507 L .34465 .58206 L F
.34966 .58142 m .34987 .58261 L .34632 .58185 L F
.34987 .58261 m .35029 .58507 L .34632 .58185 L F
.219 .039 .411 r
.34853 .58157 m .3482 .57891 L .34966 .58142 L F
.34465 .58206 m .34657 .58035 L .34853 .58157 L F
.34657 .58035 m .3482 .57891 L .34853 .58157 L F
.34465 .58206 m .34707 .58225 L .34809 .57922 L F
.34465 .58206 m .34809 .57922 L .34712 .57987 L F
.852 .996 .762 r
.34596 .57973 m .34354 .58261 L .34465 .58206 L F
.835 .774 .794 r
.34376 .58019 m .34099 .58309 L .33955 .58033 L F
.871 .836 .809 r
.34186 .58132 m .34354 .58261 L .34596 .57973 L F
.844 .421 .227 r
.3458 .57987 m .34707 .58225 L .34425 .58121 L F
.34596 .57973 m .34611 .58007 L .3458 .57987 L F
.34611 .58007 m .34707 .58225 L .3458 .57987 L F
.219 .039 .411 r
.34712 .57987 m .34809 .57922 L .3482 .57891 L F
.14 0 0 r
.20491 .56044 m .20248 .56156 L .20557 .55956 L F
.261 0 .012 r
.20706 .55986 m .20491 .56044 L .20557 .55956 L F
.886 .872 .818 r
.7824 .41406 m .78107 .41595 L .77963 .41429 L F
0 0 .204 r
.28055 .60117 m .28025 .6037 L .27934 .60475 L F
0 0 0 r
.28025 .6037 m .27801 .60679 L .27934 .60475 L F
.508 .291 .519 r
.31992 .62234 m .31774 .62026 L .3201 .61977 L F
.31992 .62234 m .31749 .62288 L .31774 .62026 L F
.562 .187 .288 r
.27829 .64536 m .28021 .64733 L .27769 .64714 L F
.367 .088 .352 r
.30531 .58126 m .30532 .58247 L .30347 .58293 L F
.344 .264 .62 r
.30533 .58536 m .30347 .58293 L .30532 .58247 L F
.30533 .58536 m .30379 .58645 L .30347 .58293 L F
.429 .837 .973 r
.22235 .53729 m .22453 .53678 L .22624 .53723 L F
.33 .784 .95 r
.22624 .53723 m .22453 .53678 L .22855 .53694 L F
.072 0 0 r
.2364 .71535 m .23865 .71508 L .23603 .716 L F
.463 .24 .489 r
.23924 .71222 m .23865 .71508 L .2364 .71535 L F
0 0 .496 r
.23533 .71196 m .2364 .71535 L .23718 .71539 L F
.072 0 0 r
.2364 .71535 m .23603 .716 L .23718 .71539 L F
.729 .26 .135 r
.29097 .60111 m .29353 .60286 L .2946 .60193 L F
.49 .275 .514 r
.29353 .60286 m .2961 .60061 L .2946 .60193 L F
.452 .215 .463 r
.16271 .56819 m .16493 .56763 L .16539 .56523 L F
.396 .166 .443 r
.16539 .56523 m .16493 .56763 L .16741 .56459 L F
.991 .746 .452 r
.54932 .53757 m .54802 .53914 L .5474 .53675 L F
.54932 .53757 m .54923 .54024 L .54802 .53914 L F
.606 .744 .942 r
.31936 .54 m .31557 .53882 L .31788 .53828 L F
.435 .834 .98 r
.31982 .53884 m .31936 .54 L .31788 .53828 L F
.31982 .53884 m .32188 .53946 L .31936 .54 L F
.264 .677 .967 r
.24882 .64197 m .24941 .64099 L .24735 .64076 L F
.24882 .64197 m .25099 .64206 L .24941 .64099 L F
.553 .861 .558 r
.82553 .40243 m .82821 .39978 L .82854 .40212 L F
.459 .798 .999 r
.82553 .40243 m .82854 .40212 L .82463 .40156 L F
.809 .523 .506 r
.47723 .61996 m .48062 .62287 L .48117 .62071 L F
.501 .782 .995 r
.25816 .53333 m .25761 .53503 L .25593 .53396 L F
.25816 .53333 m .25983 .53456 L .25761 .53503 L F
.467 .696 .967 r
.34435 .57263 m .34614 .57424 L .34724 .57253 L F
0 0 .318 r
.34607 .57764 m .34724 .57253 L .34614 .57424 L F
.332 .138 .461 r
.45355 .64715 m .45164 .65031 L .4517 .64785 L F
.45355 .64715 m .45164 .65031 L .4517 .64785 L F
.721 .548 .656 r
.22346 .55338 m .22011 .55298 L .22298 .55253 L F
.22346 .55338 m .22001 .55647 L .22011 .55298 L F
.433 .111 .318 r
.22346 .55338 m .21959 .55768 L .22001 .55647 L F
.22346 .55338 m .22195 .55722 L .21959 .55768 L F
0 0 .224 r
.22483 .55192 m .22346 .55338 L .22298 .55253 L F
.22483 .55192 m .22333 .55553 L .22346 .55338 L F
.525 .201 .36 r
.22333 .55553 m .22195 .55722 L .22346 .55338 L F
.744 .721 .83 r
.81246 .4326 m .81341 .43606 L .81621 .43328 L F
.886 .872 .818 r
.7824 .41406 m .77963 .41429 L .78118 .41236 L F
.888 .467 .182 r
.79265 .40524 m .79331 .40697 L .79415 .40595 L F
.668 .155 .011 r
.79415 .40595 m .79331 .40697 L .79681 .4077 L F
.559 .774 .979 r
.77297 .41023 m .76941 .40936 L .77171 .40827 L F
.4 .515 .859 r
.77507 .40825 m .77297 .41023 L .77171 .40827 L F
.77507 .40825 m .77571 .411 L .77297 .41023 L F
.405 .615 .936 r
.77574 .41145 m .77297 .41023 L .77571 .411 L F
.297 0 0 r
.32193 .56852 m .32444 .56837 L .32577 .56769 L F
.132 0 0 r
.32444 .56837 m .3282 .56772 L .32577 .56769 L F
.455 .454 .768 r
.34306 .55209 m .34193 .55601 L .33966 .55463 L F
.34306 .55209 m .34418 .55527 L .34193 .55601 L F
.409 .315 .637 r
.34418 .55527 m .34417 .55752 L .34193 .55601 L F
0 .411 .817 r
.34417 .55752 m .34282 .5571 L .34193 .55601 L F
.418 .205 .481 r
.3131 .5731 m .31096 .57675 L .3108 .57412 L F
.656 .816 .961 r
.82494 .40468 m .82331 .40765 L .8218 .40622 L F
.82494 .40468 m .82626 .40602 L .82331 .40765 L F
.866 .507 .369 r
.55516 .52188 m .557 .52476 L .55875 .52527 L F
.864 .585 .514 r
.55727 .52723 m .55875 .52527 L .557 .52476 L F
.55727 .52723 m .55881 .52781 L .55875 .52527 L F
.115 0 0 r
.19154 .56892 m .19119 .56775 L .19309 .56705 L F
.19154 .56892 m .18941 .56958 L .19119 .56775 L F
.141 .686 .788 r
.22855 .53694 m .2308 .53671 L .23239 .53672 L F
.146 .689 .731 r
.2308 .53671 m .23455 .53612 L .23239 .53672 L F
.523 .204 .368 r
.30851 .5813 m .30532 .58247 L .30531 .58126 L F
.291 .03 .335 r
.31057 .58601 m .31225 .58558 L .31292 .58367 L F
.389 .211 .515 r
.31057 .58601 m .3122 .58847 L .31225 .58558 L F
.31057 .58601 m .3106 .58898 L .3122 .58847 L F
.316 .071 .376 r
.32772 .60801 m .32722 .61043 L .3253 .61099 L F
.429 .35 .666 r
.32771 .613 m .3253 .61099 L .32722 .61043 L F
.32771 .613 m .32581 .61382 L .3253 .61099 L F
.125 .664 .846 r
.24704 .62608 m .24883 .62638 L .24484 .62609 L F
.01 .578 .78 r
.24886 .62615 m .24883 .62638 L .24704 .62608 L F
.24886 .62615 m .25116 .62657 L .24883 .62638 L F
.758 .307 .18 r
.50439 .59861 m .50318 .60035 L .50217 .59833 L F
0 0 0 r
.50553 .59724 m .50318 .60035 L .50439 .59861 L F
.297 .732 .968 r
.2415 .5492 m .23975 .54834 L .23763 .54848 L F
.046 0 0 r
.24386 .54844 m .23975 .54834 L .2415 .5492 L F
0 0 .496 r
.23533 .71196 m .23718 .71539 L .23924 .71222 L F
.406 .188 .468 r
.2407 .71424 m .23865 .71508 L .23924 .71222 L F
.313 .791 .713 r
.23603 .716 m .23865 .71508 L .2407 .71424 L F
.23603 .716 m .23945 .71471 L .2392 .71433 L F
.23945 .71471 m .2407 .71424 L .2392 .71433 L F
.747 .24 .01 r
.2392 .71433 m .2407 .71424 L .23924 .71222 L F
.703 .98 .901 r
.24284 .71255 m .2407 .71424 L .2392 .71433 L F
.2392 .71433 m .2407 .71424 L .24284 .71255 L F
.2392 .71433 m .24284 .71255 L .2409 .71539 L F
0 .203 .677 r
.23889 .71384 m .2392 .71433 L .24005 .71473 L F
.747 .24 .01 r
.2392 .71433 m .23924 .71222 L .23819 .71384 L F
.872 .801 .778 r
.24141 .71029 m .2392 .71433 L .23721 .71256 L F
0 .203 .677 r
.23721 .71256 m .2392 .71433 L .23889 .71384 L F
.24005 .71473 m .2392 .71433 L .2409 .71539 L F
.747 .24 .01 r
.2392 .71433 m .23819 .71384 L .23718 .71539 L F
.069 0 0 r
.16134 .57021 m .16493 .56763 L .16271 .56819 L F
.846 .743 .75 r
.82644 .39835 m .82821 .39978 L .82715 .39598 L F
.78 .518 .54 r
.82463 .40156 m .82821 .39978 L .82644 .39835 L F
.82463 .40156 m .82854 .40212 L .82821 .39978 L F
.597 .531 .751 r
.81892 .40021 m .82202 .40131 L .82153 .39932 L F
.555 .89 .639 r
.76941 .40936 m .7684 .41029 L .76866 .40977 L F
.968 .728 .522 r
.34567 .5615 m .34719 .5652 L .34547 .56405 L F
.856 .946 .876 r
.34719 .5652 m .34348 .56711 L .34547 .56405 L F
.612 .598 .812 r
.34943 .56438 m .34719 .5652 L .34567 .5615 L F
.773 .412 .374 r
.83062 .40432 m .83189 .40271 L .82854 .40212 L F
.718 .508 .604 r
.83062 .40432 m .83461 .40192 L .83189 .40271 L F
.525 .843 .541 r
.28082 .59162 m .27802 .59433 L .27924 .59278 L F
0 0 0 r
.28071 .59189 m .28082 .59162 L .27924 .59278 L F
.28272 .59066 m .28082 .59162 L .28071 .59189 L F
.28223 .5896 m .28101 .59115 L .28082 .59162 L F
.28101 .59115 m .2798 .5927 L .28082 .59162 L F
.525 .843 .541 r
.28082 .59162 m .2798 .5927 L .27802 .59433 L F
.435 .099 .295 r
.31492 .5797 m .31731 .58001 L .31716 .57769 L F
.204 0 .279 r
.31716 .57769 m .32081 .57987 L .31999 .57742 L F
.31716 .57769 m .31999 .57742 L .31932 .57648 L F
.31716 .57769 m .31857 .57776 L .32081 .57987 L F
.31716 .57769 m .31731 .58001 L .31857 .57776 L F
.81 .575 .582 r
.31816 .57766 m .31816 .57766 L .31495 .57703 L F
.895 .755 .699 r
.31808 .578 m .31857 .57776 L .31823 .57768 L F
.63 .506 .692 r
.31962 .57632 m .3217 .5731 L .31954 .57373 L F
.753 .599 .686 r
.31841 .58255 m .32081 .57987 L .31857 .57776 L F
.31841 .58255 m .31857 .57776 L .31731 .58001 L F
.014 0 .421 r
.32016 .57506 m .31825 .57847 L .31826 .5776 L F
.31953 .57468 m .31826 .5776 L .31829 .57392 L F
.32016 .57506 m .31826 .5776 L .31953 .57468 L F
.81 .575 .582 r
.31816 .57766 m .31744 .57811 L .31495 .57703 L F
.31781 .57436 m .31816 .57766 L .31495 .57703 L F
.895 .755 .699 r
.31581 .57926 m .31857 .57776 L .31574 .5792 L F
.81 .575 .582 r
.31828 .57502 m .31826 .57745 L .31781 .57436 L F
.895 .755 .699 r
.31808 .578 m .31823 .57768 L .31816 .57766 L F
.957 .873 .713 r
.31857 .57776 m .31761 .57824 L .31816 .57766 L F
.81 .575 .582 r
.31826 .57745 m .31825 .57847 L .31816 .57758 L F
.31826 .57745 m .31816 .57758 L .31781 .57436 L F
.895 .755 .699 r
.31581 .57926 m .31731 .58001 L .31857 .57776 L F
.124 .594 .919 r
.31626 .57948 m .31731 .58001 L .31658 .57992 L F
.31574 .5792 m .31658 .57992 L .31492 .5797 L F
.671 .637 .807 r
.31478 .58271 m .31731 .58001 L .31492 .5797 L F
.168 0 0 r
.31492 .5797 m .31731 .58001 L .3145 .57997 L F
.895 .755 .699 r
.3145 .57997 m .31731 .58001 L .31581 .57926 L F
.124 .594 .919 r
.31595 .57907 m .31731 .58001 L .31626 .57948 L F
.957 .873 .713 r
.31857 .57776 m .31657 .5795 L .31761 .57824 L F
.523 .342 .578 r
.31683 .57735 m .31548 .57726 L .31744 .57811 L F
.497 .331 .586 r
.31495 .57703 m .31575 .57867 L .31266 .57721 L F
.895 .755 .699 r
.31573 .57917 m .31816 .57766 L .31573 .57871 L F
.497 .331 .586 r
.31575 .57867 m .3156 .57887 L .31266 .57721 L F
.895 .755 .699 r
.3156 .57887 m .31573 .57871 L .31556 .57878 L F
.31573 .57917 m .31573 .57871 L .3156 .57887 L F
.31573 .57871 m .31816 .57766 L .31635 .57788 L F
.523 .342 .578 r
.31683 .57735 m .31595 .57907 L .31575 .57867 L F
.31683 .57735 m .31495 .57703 L .31548 .57726 L F
.31683 .57735 m .31575 .57867 L .31495 .57703 L F
.497 .331 .586 r
.31575 .57867 m .31595 .57907 L .3156 .57887 L F
.895 .755 .699 r
.31635 .57788 m .31816 .57766 L .31683 .57735 L F
.31556 .57878 m .31573 .57871 L .31635 .57788 L F
.124 .594 .919 r
.31574 .5792 m .31492 .5797 L .3156 .57887 L F
.895 .755 .699 r
.31458 .57989 m .31573 .57917 L .31556 .57878 L F
.124 .594 .919 r
.3156 .57887 m .31492 .5797 L .31266 .57721 L F
.895 .755 .699 r
.3145 .57997 m .31816 .57766 L .31458 .57989 L F
.124 .594 .919 r
.31595 .57907 m .31574 .5792 L .3156 .57887 L F
.957 .873 .713 r
.31816 .57766 m .31752 .57807 L .31683 .57735 L F
.523 .342 .578 r
.31683 .57735 m .31716 .57776 L .31733 .57787 L F
.31716 .57776 m .31744 .57811 L .31764 .5782 L F
.957 .873 .713 r
.31752 .57807 m .31595 .57907 L .31683 .57735 L F
.895 .755 .699 r
.31574 .5792 m .31756 .57827 L .31744 .57812 L F
.957 .873 .713 r
.31761 .57824 m .31595 .57907 L .31752 .57807 L F
.895 .755 .699 r
.31744 .57812 m .31808 .578 L .31816 .57766 L F
.31756 .57827 m .31808 .578 L .31744 .57812 L F
.81 .575 .582 r
.31816 .57766 m .31765 .5782 L .31744 .57811 L F
.957 .873 .713 r
.31765 .5782 m .31752 .57807 L .31816 .57766 L F
.31761 .57824 m .31752 .57807 L .31765 .5782 L F
.523 .342 .578 r
.31716 .57776 m .31764 .5782 L .31765 .5782 L F
.957 .873 .713 r
.31857 .57776 m .31809 .57861 L .31785 .57839 L F
.81 .575 .582 r
.31816 .57766 m .31825 .57847 L .31765 .5782 L F
.523 .342 .578 r
.31733 .57787 m .31765 .5782 L .31825 .57847 L F
.31716 .57776 m .31765 .5782 L .31733 .57787 L F
.31683 .57735 m .31733 .57787 L .31825 .57847 L F
.957 .873 .713 r
.31785 .57839 m .31731 .58001 L .31657 .5795 L F
.31809 .57861 m .31731 .58001 L .31785 .57839 L F
.31761 .57824 m .31657 .5795 L .31595 .57907 L F
.75 .866 .933 r
.31683 .57735 m .31825 .57847 L .32016 .57506 L F
.285 0 .172 r
.31934 .5769 m .31881 .57747 L .31683 .57735 L F
.31881 .57747 m .31624 .58019 L .31683 .57735 L F
.895 .755 .699 r
.3145 .57997 m .31581 .57926 L .31574 .5792 L F
.124 .594 .919 r
.31595 .57907 m .31658 .57992 L .31574 .5792 L F
.81 .575 .582 r
.31829 .57392 m .31828 .57502 L .31781 .57436 L F
.204 0 .279 r
.31932 .57648 m .31999 .57742 L .31962 .57632 L F
.686 .332 0 r
.31264 .54804 m .31414 .55147 L .31291 .54847 L F
.879 .442 .092 r
.31291 .54847 m .31414 .55147 L .31578 .55243 L F
.327 .116 .432 r
.28543 .57133 m .28659 .57308 L .28591 .5703 L F
.28543 .57133 m .28468 .57393 L .28659 .57308 L F
.522 .51 .784 r
.33734 .56981 m .33852 .57287 L .33483 .57203 L F
.841 .749 .763 r
.55392 .55185 m .55505 .55552 L .55568 .55306 L F
.472 .207 .431 r
.32772 .60801 m .32968 .60988 L .32722 .61043 L F
.791 .747 .813 r
.32943 .60603 m .32772 .60801 L .32977 .60478 L F
.42 .209 .485 r
.32943 .60603 m .32968 .60988 L .32772 .60801 L F
.907 .748 .673 r
.55488 .56473 m .55435 .56724 L .5565 .56785 L F
.844 .507 .416 r
.55438 .56972 m .5565 .56785 L .55435 .56724 L F
.55438 .56972 m .5577 .57089 L .5565 .56785 L F
.584 .93 .95 r
.20522 .77023 m .20692 .77038 L .20738 .7692 L F
.835 .645 .647 r
.22011 .55298 m .22001 .55647 L .21645 .55526 L F
.086 .101 .579 r
.2755 .55906 m .27742 .55933 L .27675 .55725 L F
.656 .291 .341 r
.31578 .55243 m .31781 .55459 L .31923 .55241 L F
.682 .321 .357 r
.31923 .55241 m .32109 .55461 L .32173 .55251 L F
.31923 .55241 m .31781 .55459 L .32109 .55461 L F
.527 .587 .858 r
.27876 .54935 m .28071 .55294 L .28262 .55209 L F
.278 .027 .342 r
.28071 .55294 m .28016 .5551 L .28262 .55209 L F
.485 .617 .906 r
.79264 .42872 m .79325 .43065 L .795 .42848 L F
.554 .72 .951 r
.79325 .43065 m .79601 .43022 L .795 .42848 L F
.171 .23 .683 r
.28368 .57993 m .28415 .58023 L .28411 .57618 L F
.332 .181 .521 r
.28368 .57993 m .28506 .5826 L .28415 .58023 L F
.127 0 .15 r
.18181 .55319 m .18282 .55403 L .18391 .55264 L F
.18181 .55319 m .18095 .55512 L .18282 .55403 L F
0 0 0 r
.48891 .57356 m .49189 .57289 L .48935 .57344 L F
.48935 .57344 m .49189 .57289 L .48891 .57356 L F
.578 .315 .481 r
.31794 .62827 m .31564 .62645 L .31869 .62574 L F
.31794 .62827 m .31533 .62861 L .31564 .62645 L F
.107 0 0 r
.46467 .65043 m .46103 .65321 L .46113 .65059 L F
.46467 .65043 m .46334 .65266 L .46103 .65321 L F
.613 .585 .799 r
.46641 .647 m .46747 .65052 L .46467 .65043 L F
.372 0 0 r
.46747 .65052 m .46334 .65266 L .46467 .65043 L F
.632 .895 .575 r
.34376 .58019 m .34411 .57938 L .34607 .57764 L F
.371 .092 .355 r
.34607 .57764 m .34596 .57973 L .34376 .58019 L F
.336 .066 .348 r
.3482 .57891 m .34607 .57764 L .34934 .57677 L F
0 0 0 r
.34607 .57764 m .3467 .57805 L .34718 .576 L F
.336 .066 .348 r
.3482 .57891 m .34596 .57973 L .34607 .57764 L F
0 0 0 r
.34607 .57764 m .34411 .57938 L .3467 .57805 L F
.584 .181 .244 r
.54325 .52799 m .54247 .53011 L .53993 .52845 L F
.824 .443 .333 r
.54431 .53012 m .54325 .52799 L .54652 .52813 L F
.54431 .53012 m .54247 .53011 L .54325 .52799 L F
.731 .457 .513 r
.29977 .59812 m .29663 .59609 L .29842 .59491 L F
.29977 .59812 m .29684 .59861 L .29663 .59609 L F
.297 .01 .297 r
.17492 .58016 m .17383 .58309 L .17217 .58332 L F
0 0 0 r
.17749 .57738 m .176 .57921 L .17492 .58016 L F
.721 .431 .486 r
.17772 .58272 m .17492 .58016 L .176 .57921 L F
.17772 .58272 m .17383 .58309 L .17492 .58016 L F
.629 .955 .925 r
.28353 .59567 m .28738 .59393 L .28492 .59456 L F
.191 .333 .779 r
.2894 .59565 m .29189 .59761 L .28992 .59345 L F
.786 .686 .141 r
.28955 .59345 m .29244 .5928 L .29048 .59151 L F
.29012 .59163 m .29048 .59151 L .29021 .59133 L F
.28955 .59345 m .29048 .59151 L .29012 .59163 L F
.775 .837 .9 r
.29021 .59133 m .29244 .5928 L .29319 .59047 L F
.51 .911 .82 r
.28873 .59308 m .28955 .59345 L .29021 .59133 L F
.496 .117 .251 r
.28949 .59254 m .29319 .59047 L .29244 .5928 L F
.28949 .59254 m .29482 .59146 L .29333 .59056 L F
.29261 .5908 m .29333 .59056 L .29319 .59047 L F
.28949 .59254 m .29333 .59056 L .29261 .5908 L F
.786 .686 .141 r
.28955 .59345 m .28949 .59254 L .29244 .5928 L F
.191 .333 .779 r
.28946 .59353 m .28992 .59345 L .28949 .59254 L F
0 0 0 r
.28852 .5937 m .28676 .59423 L .28492 .59456 L F
.28955 .59345 m .28676 .59423 L .28852 .5937 L F
.694 .727 .875 r
.28873 .59308 m .2865 .59431 L .28676 .59423 L F
.022 0 0 r
.28492 .59456 m .28676 .59423 L .28322 .59668 L F
.694 .727 .875 r
.2865 .59431 m .28596 .59461 L .28676 .59423 L F
0 0 0 r
.28955 .59345 m .28858 .59368 L .28819 .59375 L F
.28858 .59368 m .28492 .59456 L .28819 .59375 L F
.51 .911 .82 r
.28873 .59308 m .28676 .59423 L .28866 .5937 L F
.28908 .59324 m .28866 .5937 L .28955 .59345 L F
.28873 .59308 m .28866 .5937 L .28908 .59324 L F
.786 .686 .141 r
.28955 .59345 m .2894 .59565 L .28949 .59254 L F
.191 .333 .779 r
.2894 .59565 m .28992 .59345 L .28946 .59353 L F
0 0 .044 r
.28947 .59281 m .28972 .59463 L .28923 .59404 L F
.28933 .59324 m .28923 .59404 L .28912 .59392 L F
.28947 .59281 m .28923 .59404 L .28933 .59324 L F
.28981 .59173 m .28979 .59246 L .28947 .59281 L F
.347 .229 .573 r
.29189 .59761 m .29482 .59146 L .28949 .59254 L F
0 0 .044 r
.28979 .59246 m .28972 .59463 L .28947 .59281 L F
0 0 0 r
.28819 .59375 m .28492 .59456 L .28738 .59393 L F
.44 .748 .993 r
.30335 .53646 m .30279 .53797 L .30115 .53697 L F
.30335 .53646 m .30494 .53773 L .30279 .53797 L F
.386 .198 .499 r
.47258 .6316 m .47455 .63102 L .47335 .62685 L F
.47258 .6316 m .47455 .63102 L .47335 .62685 L F
.85 .873 .857 r
.31786 .56977 m .32193 .56852 L .32128 .56844 L F
.759 .985 .748 r
.32285 .56659 m .32128 .56844 L .32193 .56852 L F
0 0 0 r
.32071 .56959 m .32444 .56837 L .32193 .56852 L F
.759 .985 .748 r
.32285 .56659 m .32128 .56844 L .32193 .56852 L F
0 0 0 r
.28239 .59779 m .28087 .59869 L .28353 .59567 L F
.28322 .59668 m .28353 .59567 L .28492 .59456 L F
.28322 .59668 m .28239 .59779 L .28353 .59567 L F
.841 .749 .763 r
.55392 .55185 m .5517 .55498 L .55505 .55552 L F
.864 .653 .615 r
.55152 .55762 m .55505 .55552 L .5517 .55498 L F
.55152 .55762 m .5536 .55837 L .55505 .55552 L F
.43 .641 .946 r
.7892 .42825 m .79272 .4273 L .78829 .4266 L F
.7892 .42825 m .79264 .42872 L .79272 .4273 L F
.641 .887 .547 r
.28475 .58655 m .28223 .5896 L .28321 .58811 L F
.001 0 0 r
.28223 .5896 m .28272 .59066 L .28321 .58811 L F
.28223 .5896 m .28082 .59162 L .28272 .59066 L F
.597 .587 .812 r
.50092 .59642 m .50319 .59488 L .50389 .59263 L F
.804 .962 .912 r
.50731 .60893 m .50797 .61014 L .51042 .60827 L F
.831 .674 .689 r
.55928 .57658 m .56094 .57746 L .55939 .57394 L F
.818 .666 .694 r
.55928 .57658 m .56059 .58013 L .56094 .57746 L F
.164 .678 .895 r
.26416 .53393 m .26769 .53419 L .27027 .535 L F
.332 .793 .94 r
.26769 .53419 m .27255 .53447 L .27027 .535 L F
0 0 .274 r
.28194 .60011 m .28087 .59869 L .28239 .59779 L F
.28194 .60011 m .28055 .60117 L .28087 .59869 L F
.668 .368 .456 r
.17981 .57689 m .176 .57921 L .17749 .57738 L F
.922 .725 .235 r
.54207 .58034 m .54178 .58068 L .54238 .57855 L F
.54207 .58034 m .54202 .58278 L .54178 .58068 L F
.498 .269 .497 r
.3073 .63486 m .30467 .63779 L .30498 .63534 L F
0 0 0 r
.28475 .58655 m .28447 .58719 L .28562 .58505 L F
.28475 .58655 m .28321 .58811 L .28447 .58719 L F
.631 .958 .918 r
.25705 .62508 m .25508 .62636 L .25341 .62648 L F
.315 .377 .768 r
.15267 .59855 m .15404 .60252 L .15513 .60021 L F
.548 .403 .636 r
.15404 .60252 m .15639 .60197 L .15513 .60021 L F
.15404 .60252 m .15423 .60463 L .15639 .60197 L F
.774 .717 .799 r
.78416 .40764 m .78587 .4091 L .78222 .40844 L F
.515 .123 .236 r
.33017 .54844 m .32634 .55134 L .32805 .55253 L F
.464 0 0 r
.32772 .55232 m .32805 .55253 L .32634 .55134 L F
.515 .123 .236 r
.33017 .54844 m .32772 .55232 L .32634 .55134 L F
0 0 0 r
.33348 .54688 m .33007 .54852 L .33017 .54844 L F
.235 0 0 r
.33495 .54742 m .33007 .54852 L .33348 .54688 L F
.523 .125 .227 r
.33495 .54742 m .33397 .54821 L .33007 .54852 L F
.668 .125 0 r
.33397 .54821 m .33097 .54702 L .33007 .54852 L F
.33097 .54702 m .32961 .54648 L .33007 .54852 L F
.619 .808 .388 r
.33007 .54852 m .32772 .55232 L .32895 .55037 L F
.33007 .54852 m .32895 .55037 L .33017 .54844 L F
.022 .594 .742 r
.28189 .5595 m .27916 .55936 L .27742 .55933 L F
.724 .482 .56 r
.27675 .55725 m .28021 .55902 L .28016 .5551 L F
.182 .469 .889 r
.28189 .5595 m .28203 .55822 L .28051 .55889 L F
.27991 .5594 m .28027 .5591 L .27941 .55937 L F
.28027 .5591 m .27976 .55922 L .27941 .55937 L F
.448 0 0 r
.27971 .55923 m .27916 .55936 L .28054 .55919 L F
.27742 .55933 m .27916 .55936 L .27971 .55923 L F
.27742 .55933 m .27971 .55923 L .27675 .55725 L F
.182 .469 .889 r
.28027 .5591 m .2805 .5589 L .27976 .55922 L F
.2805 .5589 m .28021 .55902 L .27976 .55922 L F
.448 0 0 r
.27971 .55923 m .28054 .55919 L .28021 .55902 L F
.27971 .55923 m .28021 .55902 L .27675 .55725 L F
.182 .469 .889 r
.2805 .5589 m .28051 .55889 L .28021 .55902 L F
.28189 .5595 m .28051 .55889 L .27991 .5594 L F
.411 .253 .555 r
.28016 .5551 m .28051 .55889 L .2821 .55755 L F
.724 .482 .56 r
.28021 .55902 m .28051 .55889 L .28016 .5551 L F
.182 .469 .889 r
.28203 .55822 m .2821 .55755 L .27941 .55937 L F
.411 .253 .555 r
.28051 .55889 m .28054 .55919 L .2821 .55755 L F
.724 .482 .56 r
.28021 .55902 m .28054 .55919 L .28051 .55889 L F
.182 .469 .889 r
.27941 .55937 m .2821 .55755 L .27916 .55936 L F
.28189 .5595 m .28506 .5602 L .2821 .55755 L F
.889 .615 .517 r
.54849 .54756 m .54624 .54849 L .54671 .54598 L F
.54849 .54756 m .54864 .54995 L .54624 .54849 L F
0 .248 .76 r
.22281 .62172 m .22254 .62269 L .2211 .62073 L F
.103 .516 .908 r
.22281 .62172 m .22455 .62326 L .22254 .62269 L F
.575 .742 .955 r
.29474 .53451 m .2926 .53523 L .29113 .53362 L F
.418 .804 .989 r
.32488 .58034 m .32277 .57945 L .32081 .57987 L F
0 .175 .711 r
.32488 .58034 m .32488 .5788 L .32277 .57945 L F
.32488 .58034 m .327 .58227 L .32488 .5788 L F
.512 .283 .504 r
.32488 .58034 m .32456 .58281 L .327 .58227 L F
.757 .359 .298 r
.2489 .55112 m .25147 .55257 L .24985 .55215 L F
.628 .179 .166 r
.28404 .64435 m .28765 .64438 L .28606 .64613 L F
.487 .076 .187 r
.29013 .64387 m .28606 .64613 L .28765 .64438 L F
.599 .719 .929 r
.2098 .63745 m .21032 .6356 L .20785 .63676 L F
.2098 .63745 m .21256 .63769 L .21032 .6356 L F
.549 .603 .86 r
.34102 .5434 m .34159 .54497 L .34071 .54381 L F
.34245 .54148 m .34184 .54395 L .34107 .54333 L F
.167 .094 .524 r
.34245 .54148 m .34071 .54381 L .34131 .54323 L F
.318 .515 .891 r
.33843 .53916 m .34131 .54323 L .33993 .5424 L F
.33771 .54059 m .33993 .5424 L .33753 .54095 L F
.33843 .53916 m .33993 .5424 L .33771 .54059 L F
.549 .603 .86 r
.34107 .54333 m .3418 .54412 L .34102 .5434 L F
.34184 .54395 m .3418 .54412 L .34107 .54333 L F
.3418 .54412 m .34159 .54497 L .34102 .5434 L F
.336 .356 .734 r
.33993 .5424 m .33903 .54381 L .33753 .54095 L F
.34131 .54323 m .34094 .54332 L .33993 .5424 L F
.34094 .54332 m .33903 .54381 L .33993 .5424 L F
.34131 .54323 m .34071 .54381 L .33903 .54381 L F
.737 .707 .822 r
.24544 .68751 m .25008 .68802 L .24769 .68701 L F
.536 .877 .989 r
.25008 .68802 m .25364 .68729 L .24982 .6868 L F
.35 .737 .986 r
.24769 .68701 m .25008 .68802 L .24982 .6868 L F
.62 .336 .465 r
.3131 .63233 m .31 .63462 L .31063 .63275 L F
.694 .612 .761 r
.16652 .76177 m .16735 .76102 L .16626 .76103 L F
.523 .818 .999 r
.23262 .64089 m .23283 .63925 L .23097 .63949 L F
.23262 .64089 m .23532 .64048 L .23283 .63925 L F
.32 0 0 r
.23173 .72301 m .23263 .72115 L .23154 .7245 L F
.23173 .72301 m .23532 .72084 L .23263 .72115 L F
0 0 0 r
.53466 .52047 m .53734 .51971 L .54013 .51871 L F
.074 0 0 r
.53719 .52007 m .53466 .52047 L .53457 .5207 L F
.53719 .52007 m .53734 .51971 L .53466 .52047 L F
.659 .312 .374 r
.5473 .51876 m .54977 .52093 L .55176 .5184 L F
.834 .549 .507 r
.55176 .5184 m .54977 .52093 L .55347 .52129 L F
.519 .73 .97 r
.18171 .61853 m .18344 .62006 L .18555 .61961 L F
.229 .324 .754 r
.54202 .58278 m .54308 .5865 L .54448 .58478 L F
.328 .469 .85 r
.54308 .5865 m .54562 .58804 L .54448 .58478 L F
.739 .297 .202 r
.28552 .55006 m .28638 .55025 L .28702 .54858 L F
.882 .797 .309 r
.28744 .5475 m .28702 .54858 L .28726 .54956 L F
0 0 .441 r
.28702 .54858 m .28878 .55236 L .28726 .54956 L F
.023 .243 .746 r
.28702 .54858 m .28935 .5509 L .28878 .55236 L F
.739 .297 .202 r
.28638 .55025 m .28935 .5509 L .28702 .54858 L F
.882 .797 .309 r
.28758 .54585 m .28702 .54858 L .28744 .5475 L F
.832 .54 .495 r
.55347 .52129 m .55355 .52428 L .55516 .52188 L F
.812 .513 .482 r
.55516 .52188 m .55355 .52428 L .557 .52476 L F
.875 .708 .671 r
.55843 .53052 m .56045 .53137 L .55881 .52781 L F
.917 .678 .56 r
.55843 .53052 m .56008 .53396 L .56045 .53137 L F
.697 .94 .644 r
.54394 .55562 m .54423 .55466 L .54593 .55328 L F
.672 .864 .472 r
.54381 .55547 m .54423 .55466 L .54394 .55562 L F
.949 .611 .342 r
.48891 .57356 m .48758 .57541 L .48706 .57262 L F
.488 .82 .999 r
.48706 .57262 m .49189 .57289 L .48891 .57356 L F
.949 .611 .342 r
.48706 .57262 m .48891 .57356 L .49189 .57289 L F
.48706 .57262 m .48758 .57541 L .48891 .57356 L F
.279 .773 .894 r
.23289 .6244 m .23245 .62498 L .23062 .62457 L F
.23289 .6244 m .23497 .62459 L .23245 .62498 L F
.898 .563 .403 r
.50985 .56059 m .50948 .55843 L .50762 .55824 L F
.50985 .56059 m .5112 .56121 L .50948 .55843 L F
.534 .287 .486 r
.46733 .63594 m .47018 .63529 L .47097 .63274 L F
.511 .275 .493 r
.30089 .5944 m .29867 .59259 L .30091 .59191 L F
.30089 .5944 m .29842 .59491 L .29867 .59259 L F
.408 .792 .991 r
.24279 .55577 m .24102 .55496 L .2388 .55529 L F
.122 .664 .837 r
.24504 .5552 m .24102 .55496 L .24279 .55577 L F
0 .091 .645 r
.24203 .70231 m .2435 .70604 L .2443 .70497 L F
.583 .401 .601 r
.24639 .70272 m .24649 .70619 L .2435 .70604 L F
.549 .214 .353 r
.24649 .70619 m .24769 .7072 L .2435 .70604 L F
.158 .551 .928 r
.2435 .70604 m .24769 .7072 L .2443 .70497 L F
0 0 .31 r
.77571 .411 m .77675 .41479 L .77574 .41145 L F
.357 0 .127 r
.19425 .54818 m .19803 .54552 L .19598 .54633 L F
0 .023 .563 r
.31687 .55326 m .31578 .55243 L .31414 .55147 L F
.31687 .55326 m .31781 .55459 L .31578 .55243 L F
.506 .452 .73 r
.32977 .60478 m .33283 .60705 L .32943 .60603 L F
.591 .334 .496 r
.33231 .60953 m .32943 .60603 L .33283 .60705 L F
.33231 .60953 m .32968 .60988 L .32943 .60603 L F
.443 .382 .695 r
.34025 .55004 m .34159 .54497 L .3394 .54802 L F
.34025 .55004 m .34256 .5493 L .34159 .54497 L F
.447 .397 .709 r
.34025 .55004 m .34306 .55209 L .34256 .5493 L F
.34256 .5493 m .34306 .55209 L .34025 .55004 L F
.245 .757 .854 r
.31116 .53749 m .30907 .53789 L .30886 .53769 L F
0 0 .136 r
.26925 .61014 m .26811 .61115 L .26732 .61347 L F
.155 0 .304 r
.3031 .58869 m .30091 .59191 L .30151 .58963 L F
.163 .619 .934 r
.19813 .63139 m .20166 .63245 L .19897 .63073 L F
.377 .618 .946 r
.20166 .63245 m .20052 .629 L .19897 .63073 L F
.345 .258 .612 r
.1492 .58899 m .15033 .58875 L .14994 .58626 L F
.771 .678 .761 r
.24203 .70231 m .24639 .70272 L .24437 .69901 L F
0 .091 .645 r
.24203 .70231 m .24494 .70293 L .24639 .70272 L F
.758 .674 .769 r
.24437 .69901 m .24639 .70272 L .24844 .69965 L F
.328 .205 .555 r
.24805 .70493 m .24649 .70619 L .24639 .70272 L F
.478 0 0 r
.24494 .70293 m .24805 .70493 L .24639 .70272 L F
0 .145 .689 r
.24437 .69901 m .24639 .70272 L .2466 .7013 L F
.562 .631 .878 r
.20495 .63466 m .20639 .63723 L .20785 .63676 L F
.746 .685 .792 r
.83192 .42325 m .83316 .42636 L .83397 .42383 L F
.83192 .42325 m .82957 .42598 L .83316 .42636 L F
.753 .666 .765 r
.83316 .42636 m .82957 .42598 L .83123 .42761 L F
.639 .652 .847 r
.83123 .42761 m .82957 .42598 L .82732 .42652 L F
.628 .568 .768 r
.82732 .42652 m .83047 .42313 L .82614 .42306 L F
.82732 .42652 m .82957 .42598 L .83047 .42313 L F
.578 .418 .629 r
.31592 .63184 m .31304 .62916 L .31533 .62861 L F
.31592 .63184 m .3131 .63233 L .31304 .62916 L F
.804 .962 .912 r
.50731 .60893 m .51042 .60827 L .50848 .60693 L F
.642 .85 .98 r
.79972 .43073 m .80128 .42856 L .79872 .42948 L F
.79972 .43073 m .80224 .42977 L .80128 .42856 L F
.635 .335 .446 r
.24374 .55218 m .24736 .55206 L .24775 .54923 L F
.318 .678 .977 r
.24775 .54923 m .2482 .54798 L .24601 .54819 L F
.24775 .54923 m .24965 .54927 L .2482 .54798 L F
.115 .665 .71 r
.21516 .76055 m .21364 .76079 L .21242 .76096 L F
.21242 .76096 m .21364 .76079 L .21516 .76055 L F
.946 .627 .397 r
.54713 .5344 m .54543 .53368 L .54431 .53012 L F
.946 .626 .395 r
.54713 .5344 m .54561 .53571 L .54543 .53368 L F
.54713 .5344 m .5474 .53675 L .54561 .53571 L F
.665 .802 .948 r
.26291 .64792 m .26393 .64482 L .26179 .64415 L F
.26291 .64792 m .26529 .64693 L .26393 .64482 L F
.74 .753 .863 r
.26963 .65397 m .27103 .65488 L .27044 .65526 L F
.26963 .65397 m .27044 .65526 L .26799 .65684 L F
.508 .285 .511 r
.26799 .65684 m .27103 .65488 L .27008 .65902 L F
.138 .017 .441 r
.26955 .65647 m .26799 .65684 L .26963 .65397 L F
.984 .73 .467 r
.2688 .65265 m .26963 .65397 L .26955 .65647 L F
.26877 .65251 m .26963 .65397 L .2688 .65265 L F
.198 .24 .681 r
.26955 .65647 m .26799 .65684 L .27008 .65902 L F
.481 .267 .512 r
.28341 .61108 m .28574 .61056 L .28583 .60775 L F
.34 .208 .551 r
.28583 .60775 m .28724 .60809 L .28798 .604 L F
.569 .42 .64 r
.28574 .61056 m .28724 .60809 L .28583 .60775 L F
.724 .482 .56 r
.27675 .55725 m .28016 .5551 L .27766 .55548 L F
.19 0 0 r
.20248 .56156 m .20055 .56328 L .19839 .56375 L F
0 0 0 r
.20233 .56246 m .20248 .56156 L .20491 .56044 L F
.20233 .56246 m .20055 .56328 L .20248 .56156 L F
.917 .782 .697 r
.55784 .53962 m .55878 .54313 L .5597 .54081 L F
.163 .619 .934 r
.19813 .63139 m .19888 .62813 L .19723 .62865 L F
.19813 .63139 m .19897 .63073 L .19888 .62813 L F
0 0 .29 r
.28591 .5703 m .28613 .56691 L .28624 .56794 L F
.633 .295 .38 r
.53608 .52501 m .53583 .52743 L .53241 .52743 L F
.98 .694 .319 r
.53628 .52751 m .53583 .52743 L .53608 .52501 L F
.818 .666 .694 r
.55928 .57658 m .55696 .57959 L .56059 .58013 L F
.818 .636 .657 r
.55683 .58213 m .56059 .58013 L .55696 .57959 L F
.55683 .58213 m .56027 .58242 L .56059 .58013 L F
.615 .392 .555 r
.33752 .59553 m .33753 .59815 L .33479 .59838 L F
.544 .336 .548 r
.33992 .59548 m .33753 .59815 L .33752 .59553 L F
.85 .932 .553 r
.54194 .57321 m .54182 .57259 L .54233 .57254 L F
0 0 .529 r
.54174 .57696 m .54182 .57259 L .54194 .57321 L F
.54174 .57696 m .54264 .57535 L .54182 .57259 L F
0 0 .449 r
.54182 .57259 m .54264 .57535 L .54293 .57342 L F
.54182 .57259 m .54293 .57342 L .54123 .57265 L F
.54182 .57259 m .54123 .57265 L .53999 .57209 L F
.85 .932 .553 r
.54233 .57254 m .54182 .57259 L .54317 .57108 L F
.948 .628 .392 r
.54317 .57108 m .54182 .57259 L .54145 .56998 L F
.54317 .57108 m .54182 .57259 L .54145 .56998 L F
.221 .385 .816 r
.76935 .41203 m .77053 .41501 L .77179 .41343 L F
.317 .527 .9 r
.77053 .41501 m .77391 .41611 L .77179 .41343 L F
0 .349 .818 r
.77053 .41501 m .77428 .41797 L .77391 .41611 L F
.58 .376 .569 r
.32581 .61382 m .32535 .61674 L .32281 .61689 L F
.554 .352 .561 r
.32809 .61616 m .32581 .61382 L .32771 .613 L F
.32809 .61616 m .32535 .61674 L .32581 .61382 L F
.529 .484 .75 r
.35232 .5639 m .35069 .56801 L .34943 .56438 L F
.35232 .5639 m .35281 .56744 L .35069 .56801 L F
.492 .355 .623 r
.35281 .56744 m .35314 .5701 L .35069 .56801 L F
.35069 .56801 m .35314 .5701 L .35091 .5707 L F
.166 .705 .771 r
.27255 .53447 m .27486 .53411 L .27624 .53402 L F
.157 .692 .696 r
.27486 .53411 m .27855 .5333 L .27624 .53402 L F
.507 .308 .544 r
.31225 .58558 m .31478 .58271 L .31292 .58367 L F
0 0 .536 r
.18434 .60553 m .18302 .60466 L .18424 .60315 L F
.18434 .60553 m .18368 .60705 L .18302 .60466 L F
.325 .46 .842 r
.16358 .60507 m .16764 .60585 L .16268 .60391 L F
.16358 .60507 m .16653 .6069 L .16764 .60585 L F
.288 .513 .899 r
.78635 .42624 m .78764 .42475 L .78386 .42363 L F
.78635 .42624 m .78829 .4266 L .78764 .42475 L F
.523 .918 .84 r
.21184 .55798 m .20913 .55932 L .21141 .55876 L F
0 0 0 r
.21184 .55798 m .21086 .55885 L .20913 .55932 L F
.191 .715 .699 r
.21141 .55876 m .20913 .55932 L .20781 .55967 L F
0 0 0 r
.21086 .55885 m .21012 .55951 L .20913 .55932 L F
.191 .715 .699 r
.20781 .55967 m .20913 .55932 L .20706 .55986 L F
.523 .918 .84 r
.21184 .55798 m .21141 .55876 L .21364 .55819 L F
.672 .158 .009 r
.53993 .52845 m .5386 .52944 L .53628 .52751 L F
.602 .072 0 r
.53993 .52845 m .54247 .53011 L .5386 .52944 L F
.319 .202 .559 r
.30292 .60126 m .30343 .60412 L .30488 .60158 L F
.944 .625 .187 r
.30308 .60319 m .30343 .60412 L .30312 .60236 L F
.591 .797 .978 r
.29959 .60354 m .30343 .60412 L .30073 .60323 L F
.711 .494 .593 r
.29959 .60354 m .30236 .60432 L .30343 .60412 L F
.08 0 .359 r
.30488 .60158 m .30343 .60412 L .30511 .60328 L F
.289 0 .231 r
.30236 .60432 m .30511 .60328 L .30343 .60412 L F
.30304 .60407 m .304 .60554 L .30511 .60328 L F
.30236 .60432 m .303 .6048 L .30304 .60407 L F
.303 .6048 m .304 .60554 L .30304 .60407 L F
.944 .625 .187 r
.30203 .60047 m .30308 .60319 L .30292 .60126 L F
.30308 .60319 m .30312 .60236 L .30292 .60126 L F
.512 .688 .947 r
.21032 .6356 m .21256 .63769 L .21465 .63699 L F
.182 0 .062 r
.17779 .55745 m .18095 .55512 L .17882 .55575 L F
0 0 0 r
.20753 .54092 m .20765 .54135 L .20968 .54018 L F
.20753 .54092 m .20547 .54203 L .20765 .54135 L F
.857 .677 .658 r
.83883 .40748 m .8424 .40563 L .83839 .40504 L F
.83883 .40748 m .84175 .40785 L .8424 .40563 L F
.451 .093 .265 r
.47385 .62254 m .47532 .62234 L .47723 .61996 L F
.782 .507 .519 r
.47532 .62234 m .47787 .62282 L .47723 .61996 L F
.809 .523 .506 r
.47723 .61996 m .47787 .62282 L .48062 .62287 L F
.835 .774 .794 r
.34376 .58019 m .34024 .58031 L .34186 .58132 L F
.599 .919 .68 r
.34376 .58019 m .34186 .58132 L .34411 .57938 L F
.871 .836 .809 r
.34186 .58132 m .34596 .57973 L .34411 .57938 L F
.586 .415 .617 r
.34411 .57938 m .34186 .58132 L .34075 .57842 L F
.712 .983 .797 r
.34411 .57938 m .34243 .57996 L .34186 .58132 L F
.026 .267 .766 r
.34243 .57996 m .34354 .58237 L .34186 .58132 L F
.721 .932 .603 r
.34186 .58132 m .34099 .58309 L .34354 .58261 L F
.026 .267 .766 r
.34354 .58237 m .34402 .58343 L .34186 .58132 L F
.835 .774 .794 r
.34024 .58031 m .33955 .58033 L .34186 .58132 L F
.74 .634 .742 r
.17879 .58564 m .17911 .5903 L .17708 .58949 L F
.678 .149 0 r
.17911 .5903 m .17927 .59112 L .17708 .58949 L F
.516 .462 .735 r
.18214 .5888 m .17911 .5903 L .17893 .58775 L F
.18214 .5888 m .17893 .58775 L .18022 .58699 L F
.18214 .5888 m .17879 .58564 L .18148 .58579 L F
.062 0 .02 r
.1791 .58905 m .18036 .58894 L .18128 .58636 L F
.1809 .58658 m .18128 .58636 L .18148 .58579 L F
.1791 .58905 m .18128 .58636 L .1809 .58658 L F
.516 .462 .735 r
.18022 .58699 m .17893 .58775 L .17879 .58564 L F
.459 .193 .422 r
.18214 .5888 m .17927 .59112 L .17911 .5903 L F
.116 .407 .857 r
.77838 .42059 m .77945 .41967 L .7777 .41897 L F
.77838 .42059 m .7813 .42223 L .77945 .41967 L F
.694 .774 .913 r
.54707 .5895 m .54696 .5873 L .54562 .58804 L F
.418 .205 .481 r
.3131 .5731 m .31266 .57721 L .31096 .57675 L F
0 0 0 r
.27437 .61394 m .27638 .61029 L .27574 .61275 L F
0 0 .283 r
.27527 .61522 m .27437 .61394 L .27574 .61275 L F
.27527 .61522 m .2741 .61647 L .27437 .61394 L F
.441 .237 .506 r
.27401 .62616 m .27619 .62556 L .27642 .62302 L F
.477 .279 .533 r
.27373 .62873 m .27619 .62556 L .27401 .62616 L F
.693 .697 .85 r
.29438 .57682 m .29199 .57711 L .29511 .57473 L F
.692 .46 .567 r
.29211 .57716 m .29419 .57799 L .29393 .57732 L F
.29419 .57799 m .29569 .57859 L .29428 .57757 L F
.29419 .57799 m .29428 .57757 L .29393 .57732 L F
.29393 .57732 m .29569 .57859 L .2956 .5775 L F
.29199 .57711 m .29183 .57967 L .29569 .57859 L F
.638 .285 .356 r
.29404 .57999 m .29393 .58175 L .29183 .57967 L F
.615 .29 .397 r
.29183 .57967 m .29393 .58175 L .29415 .58135 L F
.29408 .57904 m .29411 .5799 L .29569 .57859 L F
.29412 .57989 m .29417 .58133 L .29569 .57859 L F
.29411 .5799 m .29411 .58 L .29412 .57989 L F
.29411 .58 m .29417 .58133 L .29412 .57989 L F
0 0 .173 r
.29411 .58 m .29393 .58175 L .29404 .57999 L F
.615 .29 .397 r
.29411 .5799 m .29415 .58135 L .29417 .58133 L F
.672 .356 .43 r
.29569 .57859 m .29417 .58133 L .29725 .58121 L F
.29417 .58133 m .29393 .58175 L .29417 .58171 L F
.29417 .58133 m .29417 .58171 L .29725 .58121 L F
0 0 .173 r
.29537 .58013 m .29415 .58001 L .29559 .5778 L F
.29415 .58001 m .29411 .58 L .29415 .57995 L F
.29415 .58001 m .29415 .57995 L .29559 .5778 L F
.29537 .58013 m .29393 .58175 L .29411 .58 L F
.29411 .58 m .29404 .57999 L .29411 .5799 L F
.29411 .58 m .29411 .5799 L .29559 .5778 L F
0 0 .247 r
.29411 .5799 m .29404 .57999 L .29409 .5795 L F
.615 .29 .397 r
.29183 .57967 m .29415 .58135 L .29408 .57904 L F
0 0 .247 r
.29559 .5778 m .29411 .5799 L .29432 .57735 L F
.29411 .5799 m .29409 .5795 L .29432 .57735 L F
.29443 .57685 m .29439 .57704 L .29438 .57682 L F
.29439 .57704 m .29434 .57718 L .29438 .57682 L F
.659 .625 .804 r
.29199 .57711 m .29439 .57704 L .29511 .57473 L F
.29513 .57486 m .29539 .57613 L .29513 .57484 L F
.29539 .57613 m .29556 .57701 L .29539 .57613 L F
.29539 .57613 m .29539 .57613 L .29513 .57484 L F
0 0 .247 r
.29445 .57687 m .29438 .57682 L .29526 .57624 L F
.556 .547 .799 r
.29526 .57624 m .29438 .57682 L .29511 .57473 L F
.659 .625 .804 r
.29439 .57704 m .29533 .57701 L .29513 .57486 L F
.29533 .57701 m .29556 .57701 L .29513 .57486 L F
.549 .549 .807 r
.29511 .57473 m .29556 .57701 L .29651 .5754 L F
0 0 .247 r
.29559 .5778 m .29445 .57687 L .29651 .5754 L F
.29445 .57687 m .29526 .57624 L .29651 .5754 L F
.556 .547 .799 r
.29651 .5754 m .29526 .57624 L .29511 .57473 L F
.659 .625 .804 r
.29439 .57704 m .29513 .57484 L .29511 .57473 L F
0 0 .247 r
.29439 .57704 m .29432 .57735 L .29434 .57718 L F
.66 .431 .562 r
.29438 .57682 m .29432 .57735 L .29393 .57732 L F
.29438 .57682 m .29393 .57732 L .29199 .57711 L F
.692 .46 .567 r
.29199 .57711 m .2956 .5775 L .29556 .57701 L F
0 0 .247 r
.29559 .5778 m .29432 .57735 L .29443 .57685 L F
.66 .431 .562 r
.29393 .57732 m .29404 .57999 L .29183 .57967 L F
.29432 .57735 m .29404 .57999 L .29393 .57732 L F
.692 .46 .567 r
.29199 .57711 m .29211 .57716 L .29393 .57732 L F
.66 .431 .562 r
.29393 .57732 m .29183 .57967 L .29199 .57711 L F
.473 .105 .258 r
.29317 .64205 m .29255 .6437 L .29013 .64387 L F
.561 .226 .358 r
.2966 .64089 m .29255 .6437 L .29317 .64205 L F
.42 .171 .428 r
.25279 .68021 m .25102 .6794 L .24956 .68055 L F
.25279 .68021 m .25273 .67798 L .25102 .6794 L F
.642 .673 .864 r
.5523 .58632 m .55327 .5894 L .55536 .58862 L F
0 0 0 r
.49982 .55796 m .50041 .55758 L .50171 .55542 L F
.50171 .55542 m .50243 .55624 L .5037 .55732 L F
.50171 .55542 m .50041 .55758 L .50243 .55624 L F
.75 .732 .836 r
.21911 .74429 m .22264 .74253 L .21864 .74216 L F
.092 0 .238 r
.30533 .58536 m .3031 .58869 L .30379 .58645 L F
.286 .552 .925 r
.77428 .41797 m .77558 .41676 L .77391 .41611 L F
.77428 .41797 m .7777 .41897 L .77558 .41676 L F
.519 .387 .641 r
.34704 .58557 m .35029 .58507 L .34465 .58206 L F
.406 0 0 r
.34695 .58342 m .35029 .58507 L .34814 .58413 L F
.34465 .58206 m .34843 .58408 L .34695 .58342 L F
.34843 .58408 m .35029 .58507 L .34695 .58342 L F
.34465 .58206 m .34814 .58413 L .34707 .58225 L F
.697 .342 .37 r
.34707 .58225 m .34559 .58282 L .34425 .58121 L F
.34559 .58282 m .34402 .58343 L .34415 .58218 L F
.34559 .58282 m .34415 .58218 L .34425 .58121 L F
0 0 .119 r
.27169 .60435 m .27015 .60786 L .27101 .60678 L F
0 0 0 r
.27101 .60678 m .27015 .60786 L .26925 .61014 L F
.297 .402 .801 r
.16968 .60761 m .17147 .61171 L .17247 .60952 L F
.413 .543 .877 r
.17147 .61171 m .17447 .61301 L .17247 .60952 L F
.604 .384 .556 r
.32281 .61689 m .32277 .61948 L .3201 .61977 L F
.524 .32 .545 r
.325 .61899 m .32281 .61689 L .32535 .61674 L F
.325 .61899 m .32277 .61948 L .32281 .61689 L F
.389 .62 .944 r
.80592 .43136 m .80967 .43331 L .80877 .43179 L F
.596 .588 .814 r
.80967 .43331 m .81133 .42899 L .80877 .43179 L F
.80967 .43331 m .81246 .4326 L .81133 .42899 L F
.753 .673 .773 r
.24965 .54927 m .25147 .55257 L .24985 .55215 L F
.214 .395 .826 r
.25147 .55257 m .25293 .55146 L .24965 .54927 L F
.338 .629 .959 r
.25147 .55257 m .25419 .55313 L .25293 .55146 L F
.183 .546 .929 r
.27106 .65353 m .27423 .65676 L .27103 .65488 L F
.81 .391 .25 r
.27103 .65488 m .27423 .65676 L .27075 .65752 L F
.146 .521 .917 r
.27474 .65569 m .27423 .65676 L .27106 .65353 L F
.582 .945 .877 r
.27075 .65752 m .27423 .65676 L .27474 .65569 L F
.435 .457 .783 r
.25785 .68716 m .25548 .68428 L .2568 .68363 L F
.323 .09 .397 r
.17383 .58309 m .17212 .58465 L .17217 .58332 L F
.195 .468 .887 r
.2566 .66349 m .26045 .66653 L .25888 .66292 L F
.469 .759 .993 r
.26561 .647 m .26583 .64705 L .26768 .6469 L F
.34 0 0 r
.26904 .64777 m .27152 .64762 L .26989 .64913 L F
.01 .047 .552 r
.27024 .64639 m .26867 .64826 L .26989 .64913 L F
.27046 .64468 m .2694 .6468 L .27024 .64639 L F
.2694 .6468 m .26867 .64826 L .27024 .64639 L F
.469 .759 .993 r
.26583 .64705 m .26792 .64752 L .26771 .64692 L F
.26792 .64752 m .26904 .64777 L .26833 .64732 L F
.26792 .64752 m .26833 .64732 L .26771 .64692 L F
.422 .553 .883 r
.26768 .6469 m .26864 .64525 L .26771 .64633 L F
.402 .657 .962 r
.26393 .64482 m .26529 .64693 L .26768 .6469 L F
.469 .759 .993 r
.26583 .64705 m .26768 .64692 L .26768 .6469 L F
.26529 .64693 m .26561 .647 L .26768 .6469 L F
.803 .655 .698 r
.26768 .6469 m .26842 .64891 L .26744 .64886 L F
.26626 .64752 m .26744 .64886 L .26363 .64867 L F
.26768 .6469 m .26744 .64886 L .26626 .64752 L F
.26639 .64774 m .26363 .64867 L .26559 .64825 L F
.402 .657 .962 r
.26637 .6477 m .26768 .6469 L .26644 .64779 L F
.803 .655 .698 r
.26768 .6469 m .26626 .64752 L .26637 .6477 L F
.402 .657 .962 r
.26393 .64482 m .26768 .6469 L .26637 .6477 L F
.803 .655 .698 r
.26768 .6469 m .26637 .6477 L .26639 .64774 L F
.26626 .64752 m .26363 .64867 L .26639 .64774 L F
.593 .11 0 r
.26393 .64484 m .26637 .64771 L .26398 .64507 L F
.26637 .64771 m .26644 .64779 L .26637 .64772 L F
.26637 .64771 m .26637 .64772 L .26398 .64507 L F
.26393 .64482 m .26435 .64532 L .26393 .64484 L F
.26435 .64532 m .26644 .64779 L .26393 .64484 L F
.422 .553 .883 r
.26768 .6469 m .26771 .64633 L .26644 .64779 L F
.469 .759 .993 r
.26768 .64692 m .26771 .64692 L .26768 .6469 L F
.404 .538 .877 r
.26864 .64525 m .26866 .64685 L .27046 .64468 L F
.26866 .64685 m .26867 .64826 L .2694 .6468 L F
.26866 .64685 m .2694 .6468 L .27046 .64468 L F
.422 .553 .883 r
.26768 .6469 m .26867 .64826 L .26866 .64685 L F
.26768 .6469 m .26866 .64685 L .26864 .64525 L F
.34 0 0 r
.26904 .64777 m .26989 .64913 L .26842 .64891 L F
.835 .82 .339 r
.47787 .62282 m .47732 .62532 L .48062 .62287 L F
.423 .135 .369 r
.32173 .55251 m .32358 .55382 L .32446 .55266 L F
.32173 .55251 m .32109 .55461 L .32358 .55382 L F
.48 .163 .352 r
.46733 .63594 m .46962 .63724 L .47018 .63529 L F
.46733 .63594 m .46962 .63724 L .47018 .63529 L F
.728 .536 .631 r
.50991 .55257 m .5075 .55559 L .50992 .55503 L F
.549 .461 .708 r
.28385 .61369 m .28574 .61056 L .28341 .61108 L F
.477 .262 .508 r
.27891 .62006 m .28121 .61952 L .28144 .61692 L F
.527 .346 .579 r
.28144 .61692 m .28386 .61653 L .28385 .61369 L F
.435 .227 .497 r
.28144 .61692 m .28339 .61885 L .28386 .61653 L F
.28144 .61692 m .28121 .61952 L .28339 .61885 L F
.711 .267 .196 r
.2466 .7013 m .25073 .7018 L .24838 .70327 L F
0 .126 .673 r
.24834 .70319 m .2466 .7013 L .24838 .70327 L F
.758 .674 .769 r
.24452 .69903 m .24844 .69965 L .2466 .7013 L F
.11 .437 .876 r
.24899 .69844 m .24844 .69965 L .24819 .69925 L F
.24899 .69844 m .24819 .69925 L .24738 .698 L F
.568 .903 .979 r
.2451 .69759 m .24738 .698 L .24437 .69901 L F
.219 0 0 r
.24899 .69844 m .24738 .698 L .2451 .69759 L F
.603 .319 .459 r
.25192 .69517 m .24899 .69844 L .25007 .69586 L F
.752 .664 .764 r
.2451 .69759 m .2466 .7013 L .24899 .69844 L F
.603 .319 .459 r
.25192 .69517 m .25187 .69829 L .24899 .69844 L F
0 0 .212 r
.25007 .69586 m .24899 .69844 L .25052 .69721 L F
.498 .891 .732 r
.24978 .69765 m .24899 .69844 L .24672 .69947 L F
.25052 .69721 m .24899 .69844 L .24978 .69765 L F
.684 .922 .603 r
.2466 .7013 m .24844 .69965 L .24899 .69844 L F
.784 .718 .789 r
.24899 .69844 m .25073 .7018 L .2466 .7013 L F
.845 .998 .786 r
.24899 .69844 m .2466 .7013 L .24672 .69947 L F
0 .126 .673 r
.24672 .69947 m .2466 .7013 L .24834 .70319 L F
.758 .674 .769 r
.24437 .69901 m .24452 .69903 L .2466 .7013 L F
.599 .825 .986 r
.18932 .60801 m .18714 .60884 L .18482 .60726 L F
.753 .269 .091 r
.29977 .59812 m .30203 .60047 L .30217 .59939 L F
.793 .757 .821 r
.22001 .55647 m .21539 .5572 L .21645 .55526 L F
.464 0 0 r
.32772 .55232 m .33042 .5545 L .32805 .55253 L F
.321 0 .183 r
.17435 .56077 m .17779 .55745 L .17594 .55816 L F
.396 .254 .568 r
.19623 .78532 m .19453 .78855 L .19647 .78839 L F
.384 .191 .492 r
.19417 .79121 m .19453 .78855 L .19647 .78839 L F
.945 .67 .486 r
.19623 .78532 m .19647 .78839 L .19453 .78855 L F
.384 .191 .492 r
.19647 .78839 m .19453 .78855 L .19417 .79121 L F
.241 0 0 r
.79681 .4077 m .80084 .408 L .79817 .40767 L F
.31 0 0 r
.23696 .53564 m .23931 .53582 L .24098 .53513 L F
0 0 0 r
.24098 .53513 m .24153 .53507 L .24317 .53496 L F
.24098 .53513 m .23931 .53582 L .24153 .53507 L F
.132 0 0 r
.32444 .56837 m .32691 .56835 L .3282 .56772 L F
.407 0 0 r
.32691 .56835 m .33076 .56758 L .3282 .56772 L F
.418 .646 .952 r
.17831 .59421 m .1779 .59622 L .17736 .59259 L F
.17831 .59421 m .18019 .59641 L .1779 .59622 L F
.383 .064 .295 r
.27891 .62006 m .28049 .62149 L .28121 .61952 L F
.27891 .62006 m .27803 .62215 L .28049 .62149 L F
.108 0 .34 r
.27619 .62556 m .27803 .62215 L .27642 .62302 L F
.72 .731 .86 r
.82856 .42014 m .83184 .42065 L .83151 .41721 L F
.782 .562 .602 r
.83047 .42313 m .83184 .42065 L .82856 .42014 L F
.83047 .42313 m .83192 .42325 L .83184 .42065 L F
.777 .772 .848 r
.83151 .41721 m .83184 .42065 L .83503 .41758 L F
.561 .226 .358 r
.2966 .64089 m .29504 .6437 L .29255 .6437 L F
.581 .248 .369 r
.29882 .64288 m .2966 .64089 L .29896 .64101 L F
.29882 .64288 m .29504 .6437 L .2966 .64089 L F
.169 0 0 r
.24547 .53501 m .24991 .53455 L .24765 .53497 L F
.726 .26 0 r
.25366 .68775 m .25528 .69018 L .25434 .689 L F
.734 .24 .065 r
.24982 .6868 m .25339 .68726 L .25366 .68775 L F
.726 .26 0 r
.25366 .68775 m .25249 .68672 L .24982 .6868 L F
.25366 .68775 m .25434 .689 L .25249 .68672 L F
.734 .24 .065 r
.25339 .68726 m .25364 .68729 L .25366 .68775 L F
0 .328 .665 r
.1802 .82431 m .17981 .82418 L .17795 .82393 L F
.1802 .82431 m .18259 .82528 L .17981 .82418 L F
.463 .799 .999 r
.4268 .63395 m .42774 .63492 L .4258 .63537 L F
.439 .25 .526 r
.42774 .63492 m .42801 .63738 L .4258 .63537 L F
0 0 .292 r
.54174 .57696 m .54238 .57855 L .54264 .57535 L F
.336 .207 .553 r
.46103 .65321 m .46311 .64944 L .46113 .65059 L F
.445 .26 .535 r
.33222 .60121 m .33206 .60422 L .32977 .60478 L F
.503 .452 .733 r
.33206 .60422 m .33283 .60705 L .32977 .60478 L F
.563 .674 .913 r
.80592 .43136 m .8078 .42855 L .80498 .42957 L F
.80592 .43136 m .80877 .43179 L .8078 .42855 L F
.607 .356 .511 r
.30181 .63843 m .30161 .64106 L .29896 .64101 L F
.508 .273 .493 r
.30389 .6405 m .30181 .63843 L .30467 .63779 L F
.30389 .6405 m .30161 .64106 L .30181 .63843 L F
.692 .596 .744 r
.22597 .72755 m .2268 .73008 L .22903 .72752 L F
.844 .873 .863 r
.22903 .72752 m .2268 .73008 L .22485 .72889 L F
0 .483 .846 r
.22485 .72889 m .2268 .73008 L .22832 .73034 L F
0 .313 .799 r
.2268 .73008 m .22874 .73173 L .22832 .73034 L F
.528 .632 .897 r
.26558 .55753 m .26556 .55445 L .26408 .55495 L F
.26558 .55753 m .26764 .55718 L .26556 .55445 L F
.344 .666 .974 r
.23771 .64013 m .23884 .64138 L .23931 .63997 L F
.29 .334 .735 r
.28411 .57618 m .28415 .58023 L .2866 .57825 L F
.061 .042 .52 r
.28415 .58023 m .28652 .58072 L .2866 .57825 L F
.28415 .58023 m .28506 .5826 L .28652 .58072 L F
.641 .587 .778 r
.2397 .70322 m .24203 .70231 L .23934 .70083 L F
.892 .627 .531 r
.15547 .60047 m .15626 .60025 L .15513 .60021 L F
.15881 .60304 m .15626 .60025 L .15547 .60047 L F
.303 0 0 r
.15926 .6032 m .15881 .60304 L .15639 .60197 L F
.892 .627 .531 r
.15881 .60304 m .15513 .60021 L .15639 .60197 L F
.15881 .60304 m .15702 .60324 L .15626 .60025 L F
.31 .329 .719 r
.15702 .60324 m .15754 .59991 L .15626 .60025 L F
.15754 .59991 m .15764 .59929 L .15626 .60025 L F
.152 0 .261 r
.15873 .60269 m .15824 .60285 L .15881 .60304 L F
.15824 .60285 m .15702 .60324 L .15881 .60304 L F
.303 0 0 r
.16057 .60376 m .15881 .60304 L .15926 .6032 L F
.135 .644 .899 r
.16057 .60376 m .16268 .60391 L .15881 .60304 L F
0 0 .448 r
.26013 .67628 m .25898 .67548 L .25935 .67284 L F
.26013 .67628 m .25949 .67816 L .25898 .67548 L F
.533 .44 .695 r
.35105 .57332 m .35121 .57632 L .34934 .57677 L F
.759 .513 .561 r
.35121 .57632 m .3482 .57891 L .34934 .57677 L F
.618 .544 .749 r
.81948 .40756 m .8169 .40861 L .81638 .40509 L F
.841 .682 .685 r
.32081 .57987 m .32041 .58303 L .32248 .58202 L F
.662 .317 .378 r
.32041 .58303 m .32045 .58486 L .32248 .58202 L F
.508 .087 .178 r
.32045 .58486 m .32456 .58281 L .32248 .58202 L F
.793 .768 .83 r
.54013 .51871 m .53734 .51971 L .54099 .5186 L F
.503 .043 .092 r
.53719 .52007 m .54099 .5186 L .53734 .51971 L F
.53719 .52007 m .53968 .52032 L .54099 .5186 L F
.571 .116 .133 r
.54099 .5186 m .54361 .52011 L .54363 .51878 L F
.54099 .5186 m .53968 .52032 L .54361 .52011 L F
.206 0 0 r
.27078 .55523 m .26966 .55677 L .26764 .55718 L F
0 0 0 r
.27236 .5543 m .26966 .55677 L .27078 .55523 L F
.659 .255 .267 r
.54363 .51878 m .54596 .52063 L .5473 .51876 L F
.689 .29 .286 r
.5473 .51876 m .54596 .52063 L .54977 .52093 L F
.542 .529 .791 r
.77963 .41429 m .77675 .41479 L .77571 .411 L F
.549 .461 .708 r
.28385 .61369 m .28621 .61322 L .28574 .61056 L F
.463 .296 .568 r
.28385 .61369 m .28607 .61598 L .28621 .61322 L F
.28385 .61369 m .28386 .61653 L .28607 .61598 L F
.632 .672 .87 r
.19469 .62925 m .19506 .62537 L .19334 .62547 L F
.19469 .62925 m .19723 .62865 L .19506 .62537 L F
.745 .72 .829 r
.81246 .4326 m .81621 .43328 L .8147 .4316 L F
.826 .808 .833 r
.81621 .43328 m .81747 .42872 L .8147 .4316 L F
.81621 .43328 m .81906 .43017 L .81747 .42872 L F
.623 .603 .81 r
.21389 .74659 m .21464 .74192 L .2162 .74224 L F
.21389 .74659 m .21638 .74554 L .21464 .74192 L F
.276 .327 .734 r
.15181 .595 m .15267 .59855 L .15384 .59736 L F
.309 .377 .771 r
.15267 .59855 m .15513 .60021 L .15384 .59736 L F
0 0 .124 r
.27801 .60679 m .27638 .61029 L .27705 .60798 L F
.969 .656 .277 r
.25168 .67698 m .25273 .67798 L .25279 .68021 L F
.021 .473 .876 r
.21859 .62095 m .215 .619 L .21657 .61974 L F
.296 .778 .916 r
.21898 .62025 m .21859 .62095 L .21657 .61974 L F
.21898 .62025 m .2211 .62073 L .21859 .62095 L F
.576 .94 .906 r
.25528 .69018 m .25583 .69045 L .25735 .68942 L F
.62 .605 .814 r
.30089 .5944 m .29977 .59812 L .29842 .59491 L F
.519 .717 .963 r
.22205 .63959 m .2227 .63747 L .22062 .63795 L F
.22205 .63959 m .22624 .63998 L .2227 .63747 L F
.862 .689 .665 r
.55775 .57263 m .55939 .57394 L .5577 .57089 L F
.872 .701 .667 r
.55775 .57263 m .55928 .57658 L .55939 .57394 L F
.336 .769 .969 r
.25419 .53332 m .25367 .53422 L .25211 .53388 L F
.25419 .53332 m .25593 .53396 L .25367 .53422 L F
.634 .737 .922 r
.33119 .54238 m .3291 .54334 L .32785 .54101 L F
.029 0 .012 r
.18504 .57073 m .18368 .57322 L .18202 .57379 L F
.292 0 .155 r
.18584 .57256 m .18504 .57073 L .18731 .57029 L F
.18584 .57256 m .18368 .57322 L .18504 .57073 L F
.552 .81 .994 r
.34852 .59178 m .34624 .59243 L .34684 .59059 L F
.701 .949 .956 r
.34624 .59243 m .34452 .59176 L .34684 .59059 L F
.544 .208 .349 r
.34852 .59178 m .34549 .59369 L .34624 .59243 L F
.531 .647 .908 r
.17927 .59112 m .17466 .58872 L .1775 .58989 L F
.456 0 0 r
.17744 .58985 m .17927 .59112 L .17746 .58987 L F
.17708 .58949 m .17927 .59112 L .17744 .58985 L F
.531 .647 .908 r
.17927 .59112 m .1775 .58989 L .17766 .58996 L F
0 0 0 r
.17708 .58949 m .17744 .58985 L .17879 .58564 L F
.17744 .58985 m .17748 .58982 L .1775 .58975 L F
.17746 .58979 m .1775 .58975 L .17879 .58564 L F
.17744 .58985 m .1775 .58975 L .17746 .58979 L F
.134 0 .009 r
.17766 .58996 m .17907 .58993 L .1791 .58905 L F
.164 .425 .862 r
.17767 .58958 m .17907 .58993 L .17766 .58996 L F
.515 .233 .423 r
.17879 .58564 m .17747 .58983 L .1791 .58905 L F
.148 .534 .921 r
.17748 .58982 m .17766 .58996 L .17742 .58986 L F
.17749 .58981 m .17752 .58983 L .17748 .58982 L F
.17752 .58983 m .17766 .58996 L .17748 .58982 L F
.515 .233 .423 r
.17747 .58983 m .17746 .58987 L .17753 .58983 L F
.164 .425 .862 r
.17754 .58983 m .17766 .58996 L .17752 .58983 L F
.134 0 .009 r
.17766 .58996 m .1791 .58905 L .17754 .58983 L F
.164 .425 .862 r
.17766 .58983 m .17766 .58996 L .17754 .58983 L F
.134 0 .009 r
.17766 .58996 m .17754 .58983 L .17746 .58987 L F
.515 .233 .423 r
.17752 .58983 m .17753 .58983 L .17754 .58983 L F
.17747 .58983 m .17753 .58983 L .17752 .58983 L F
.17747 .58983 m .17754 .58983 L .1791 .58905 L F
.164 .425 .862 r
.17771 .58774 m .17766 .58983 L .17521 .58781 L F
.17766 .58983 m .17752 .58983 L .17521 .58781 L F
.17771 .58774 m .1784 .58885 L .17767 .58958 L F
.1784 .58885 m .17907 .58993 L .17767 .58958 L F
.148 .534 .921 r
.17521 .58781 m .17749 .58981 L .17466 .58872 L F
.17749 .58981 m .17742 .58986 L .17466 .58872 L F
0 0 0 r
.17744 .58985 m .17746 .58987 L .17748 .58982 L F
.556 .809 .992 r
.25608 .67607 m .25779 .6785 L .26013 .67628 L F
.584 .864 .995 r
.25779 .6785 m .25949 .67816 L .26013 .67628 L F
.743 .939 .608 r
.33923 .58472 m .33844 .58648 L .34099 .58309 L F
.343 .575 .927 r
.33923 .58472 m .3413 .58772 L .33844 .58648 L F
.228 .393 .82 r
.17447 .61301 m .17625 .61625 L .17759 .61625 L F
.564 .615 .862 r
.33978 .57654 m .34362 .57852 L .33965 .57696 L F
.34274 .57694 m .34362 .57852 L .33978 .57654 L F
.248 .081 .448 r
.34075 .57842 m .33965 .57696 L .34362 .57852 L F
.588 .627 .858 r
.3451 .57717 m .34362 .57852 L .34076 .57343 L F
.606 .268 .371 r
.3451 .57717 m .34075 .57842 L .34362 .57852 L F
.34488 .57723 m .34411 .57938 L .34075 .57842 L F
.3451 .57717 m .34506 .57726 L .34488 .57723 L F
.34506 .57726 m .34411 .57938 L .34488 .57723 L F
.564 .615 .862 r
.34076 .57343 m .34274 .57694 L .33978 .57654 L F
.248 .081 .448 r
.34075 .57842 m .33955 .58033 L .33965 .57696 L F
.721 .932 .603 r
.34186 .58132 m .33923 .58472 L .34099 .58309 L F
.498 .751 .986 r
.31521 .53671 m .31557 .53882 L .31358 .53694 L F
.31521 .53671 m .31788 .53828 L .31557 .53882 L F
.811 .701 .744 r
.55683 .58213 m .55795 .58557 L .56027 .58242 L F
.659 .63 .809 r
.26045 .66653 m .2613 .66215 L .25888 .66292 L F
.26045 .66653 m .26293 .66566 L .2613 .66215 L F
.648 .724 .904 r
.16653 .6069 m .16786 .60832 L .16968 .60761 L F
.261 .15 .533 r
.14994 .58626 m .15145 .58569 L .15168 .58236 L F
.297 .242 .626 r
.14994 .58626 m .15184 .5883 L .15145 .58569 L F
.332 .249 .61 r
.15033 .58875 m .15184 .5883 L .14994 .58626 L F
.438 .501 .827 r
.32274 .54657 m .32394 .54954 L .32545 .54735 L F
.312 .332 .72 r
.32394 .54954 m .32634 .55134 L .32545 .54735 L F
.372 0 0 r
.46747 .65052 m .46602 .65218 L .46334 .65266 L F
.04 .192 .695 r
.46845 .6491 m .46747 .65052 L .46641 .647 L F
.608 .852 .489 r
.46845 .6491 m .46602 .65218 L .46747 .65052 L F
.656 .269 .3 r
.3289 .56039 m .32601 .55923 L .32919 .55797 L F
.3289 .56039 m .32531 .56073 L .32601 .55923 L F
.28 .706 .968 r
.22815 .62414 m .22455 .62326 L .22669 .62313 L F
.11 .577 .914 r
.23062 .62457 m .22815 .62414 L .22669 .62313 L F
.136 0 .386 r
.26965 .62229 m .26901 .6251 L .26698 .62603 L F
0 0 .26 r
.2679 .62723 m .26698 .62603 L .26901 .6251 L F
.2679 .62723 m .26677 .62878 L .26698 .62603 L F
.775 .581 .638 r
.50169 .59184 m .50319 .59488 L .50389 .59263 L F
.50169 .59184 m .50319 .59488 L .50389 .59263 L F
.873 .73 .701 r
.76805 .40514 m .76941 .40936 L .76775 .40805 L F
.84 .372 .026 r
.76775 .40805 m .76941 .40936 L .76866 .40977 L F
.621 .572 .778 r
.77075 .40423 m .76941 .40936 L .76805 .40514 L F
.77075 .40423 m .77171 .40827 L .76941 .40936 L F
.536 .545 .811 r
.82202 .40131 m .82348 .39787 L .82153 .39932 L F
.82202 .40131 m .82463 .40156 L .82348 .39787 L F
0 0 0 r
.54593 .55328 m .54571 .55116 L .54675 .55081 L F
.54593 .55328 m .5464 .55353 L .54571 .55116 L F
.54593 .55328 m .54423 .55466 L .5464 .55353 L F
.709 .531 .646 r
.80084 .408 m .80423 .41009 L .80467 .40803 L F
.54 .278 .467 r
.80467 .40803 m .807 .40942 L .80731 .40863 L F
.80467 .40803 m .80423 .41009 L .807 .40942 L F
.64 .802 .961 r
.24082 .62521 m .23861 .62612 L .23698 .62474 L F
.396 .578 .912 r
.7813 .42223 m .78191 .42401 L .78331 .42232 L F
.506 .744 .98 r
.78191 .42401 m .78386 .42363 L .78331 .42232 L F
.573 .222 .336 r
.52242 .52143 m .52435 .52252 L .52225 .52321 L F
.952 .61 .32 r
.52242 .52143 m .52225 .52321 L .52079 .52069 L F
.367 0 0 r
.52079 .52069 m .52435 .52252 L .52242 .52143 L F
0 0 0 r
.18998 .54963 m .18587 .55175 L .18789 .55096 L F
.19207 .54881 m .18998 .54963 L .18789 .55096 L F
.822 .531 .498 r
.54975 .52328 m .55347 .52129 L .54977 .52093 L F
.54975 .52328 m .55355 .52428 L .55347 .52129 L F
.225 .727 .904 r
.21464 .74192 m .21864 .74216 L .2162 .74224 L F
.911 .78 .703 r
.55716 .54222 m .55878 .54313 L .55784 .53962 L F
.953 .901 .735 r
.55656 .54439 m .55878 .54313 L .55716 .54222 L F
.55656 .54439 m .55706 .5468 L .55878 .54313 L F
.256 .017 .347 r
.30784 .59213 m .30527 .59545 L .30762 .59486 L F
.45 .292 .574 r
.30527 .59545 m .30777 .59777 L .30762 .59486 L F
.30527 .59545 m .30513 .59844 L .30777 .59777 L F
.872 .701 .667 r
.55775 .57263 m .55573 .57602 L .55928 .57658 L F
.864 .742 .727 r
.55573 .57602 m .55696 .57959 L .55928 .57658 L F
.194 .719 .854 r
.2451 .64112 m .24339 .64095 L .24113 .64117 L F
.609 .151 .14 r
.24735 .64076 m .24339 .64095 L .2451 .64112 L F
.705 .661 .804 r
.81351 .42322 m .81731 .42392 L .81583 .42052 L F
.676 .235 .196 r
.81648 .42516 m .81731 .42392 L .81351 .42322 L F
.68 .649 .812 r
.81583 .42052 m .81731 .42392 L .81984 .42102 L F
.645 .199 .177 r
.81648 .42516 m .82008 .4256 L .81731 .42392 L F
.667 .627 .801 r
.81731 .42392 m .82129 .42442 L .81984 .42102 L F
.639 .234 .259 r
.82008 .4256 m .82129 .42442 L .81731 .42392 L F
.738 .87 .942 r
.22874 .73173 m .23112 .729 L .22832 .73034 L F
.22874 .73173 m .23251 .73025 L .23112 .729 L F
.523 .335 .568 r
.46321 .61933 m .46072 .62246 L .46072 .61984 L F
.46321 .61933 m .46072 .62246 L .46072 .61984 L F
.546 .419 .659 r
.24544 .68751 m .24774 .68422 L .24675 .6842 L F
.668 .368 .456 r
.17981 .57689 m .17878 .57961 L .176 .57921 L F
.422 .121 .348 r
.18127 .57897 m .17981 .57689 L .18156 .57534 L F
.18127 .57897 m .17878 .57961 L .17981 .57689 L F
0 0 0 r
.23763 .54848 m .236 .54879 L .23381 .54921 L F
.015 0 0 r
.23975 .54834 m .236 .54879 L .23763 .54848 L F
0 0 .272 r
.27169 .60435 m .27284 .60305 L .27301 .60047 L F
0 0 .207 r
.27101 .60678 m .27284 .60305 L .27169 .60435 L F
.868 .723 .699 r
.24736 .55206 m .24714 .55396 L .24985 .55215 L F
.512 .226 .418 r
.28361 .64632 m .28404 .64435 L .28606 .64613 L F
.522 .5 .773 r
.32035 .62527 m .31869 .62574 L .31749 .62288 L F
.46 .24 .492 r
.32035 .62527 m .31794 .62827 L .31869 .62574 L F
.168 0 0 r
.31492 .5797 m .3145 .57997 L .31308 .5801 L F
0 0 .1 r
.28608 .56357 m .28594 .56206 L .28734 .56103 L F
.185 0 0 r
.21992 .53751 m .22453 .53678 L .22235 .53729 L F
.531 .647 .908 r
.17927 .59112 m .17749 .59188 L .17466 .58872 L F
.305 .08 .399 r
.17927 .59112 m .17736 .59259 L .17749 .59188 L F
.612 .598 .812 r
.34943 .56438 m .34567 .5615 L .3497 .56315 L F
.584 .571 .804 r
.35063 .56006 m .34943 .56438 L .3497 .56315 L F
.35063 .56006 m .35232 .5639 L .34943 .56438 L F
.58 .395 .595 r
.33479 .59838 m .33468 .60105 L .33222 .60121 L F
.547 .343 .557 r
.33454 .60354 m .33222 .60121 L .33468 .60105 L F
.33454 .60354 m .33206 .60422 L .33222 .60121 L F
.833 .807 .826 r
.81747 .42872 m .81906 .43017 L .82145 .42726 L F
.542 .692 .937 r
.17953 .61879 m .17986 .61604 L .17759 .61625 L F
.17953 .61879 m .18171 .61853 L .17986 .61604 L F
0 .086 .638 r
.49982 .55796 m .50144 .56045 L .50041 .55758 L F
0 0 0 r
.2741 .61647 m .27332 .61872 L .27202 .61932 L F
.27332 .61872 m .27037 .62145 L .27202 .61932 L F
.183 .546 .929 r
.27106 .65353 m .27103 .65488 L .26963 .65397 L F
.81 .391 .25 r
.27103 .65488 m .27075 .65752 L .27008 .65902 L F
.161 0 0 r
.23251 .73025 m .23273 .73153 L .23112 .729 L F
.23251 .73025 m .23471 .72973 L .23273 .73153 L F
0 0 .146 r
.23251 .73025 m .23438 .72711 L .23471 .72973 L F
.17 0 .275 r
.26387 .55237 m .26545 .55168 L .26627 .54917 L F
.311 .211 .577 r
.26408 .55495 m .26545 .55168 L .26387 .55237 L F
.346 .718 .985 r
.2452 .62489 m .24484 .62609 L .24314 .6248 L F
.2452 .62489 m .24704 .62608 L .24484 .62609 L F
.764 .715 .806 r
.83047 .42313 m .82957 .42598 L .83192 .42325 L F
.595 .536 .758 r
.29569 .57859 m .29651 .5754 L .29556 .57701 L F
0 0 0 r
.23931 .70038 m .23577 .70243 L .23934 .70083 L F
.558 .604 .855 r
.23934 .70083 m .2406 .6995 L .23931 .70038 L F
.235 0 0 r
.33495 .54742 m .33348 .54688 L .33544 .54522 L F
.496 .326 .579 r
.33697 .60041 m .33479 .59838 L .33753 .59815 L F
.33697 .60041 m .33468 .60105 L .33479 .59838 L F
.402 0 0 r
.21657 .61974 m .215 .619 L .21282 .61849 L F
.835 .82 .339 r
.47787 .62282 m .47717 .62532 L .47732 .62532 L F
.994 .802 .432 r
.54865 .54268 m .54802 .53914 L .54923 .54024 L F
.284 .035 .349 r
.28468 .57393 m .28411 .57618 L .28659 .57308 L F
.848 .733 .736 r
.83993 .41124 m .84175 .40785 L .83883 .40748 L F
.773 .412 .374 r
.83062 .40432 m .82854 .40212 L .82861 .40389 L F
.917 .678 .56 r
.55843 .53052 m .55837 .53343 L .56008 .53396 L F
.956 .824 .674 r
.55785 .53455 m .56008 .53396 L .55837 .53343 L F
.55785 .53455 m .55947 .53629 L .56008 .53396 L F
.62 .336 .465 r
.3131 .63233 m .3125 .63448 L .31 .63462 L F
.652 .368 .476 r
.316 .63436 m .3131 .63233 L .31592 .63184 L F
.316 .63436 m .3125 .63448 L .3131 .63233 L F
.412 .772 .995 r
.23283 .63925 m .23532 .64048 L .23771 .64013 L F
.609 .383 .548 r
.32258 .62195 m .3201 .61977 L .32277 .61948 L F
.32258 .62195 m .31992 .62234 L .3201 .61977 L F
.541 .414 .657 r
.35314 .5701 m .35105 .57332 L .35091 .5707 L F
0 0 .058 r
.25103 .67173 m .24974 .67473 L .2476 .67416 L F
0 .149 .692 r
.24974 .67473 m .2497 .67314 L .2476 .67416 L F
.24974 .67473 m .25168 .67698 L .2497 .67314 L F
.018 .156 .667 r
.18434 .60553 m .18482 .60726 L .18368 .60705 L F
.515 .233 .423 r
.17879 .58564 m .1791 .58905 L .18148 .58579 L F
.065 0 0 r
.19622 .5645 m .19486 .56672 L .19309 .56705 L F
.04 0 0 r
.19668 .56581 m .19622 .5645 L .19839 .56375 L F
.19668 .56581 m .19486 .56672 L .19622 .5645 L F
.238 .738 .904 r
.22453 .53678 m .22665 .5366 L .22855 .53694 L F
.056 .621 .772 r
.22665 .5366 m .2308 .53671 L .22855 .53694 L F
.608 .933 .96 r
.23262 .55567 m .2338 .55396 L .23498 .55515 L F
.23262 .55567 m .23091 .55541 L .2338 .55396 L F
.502 0 0 r
.23498 .55515 m .23091 .55541 L .23262 .55567 L F
.292 0 0 r
.23122 .54914 m .22927 .5507 L .2269 .55093 L F
.693 .249 .192 r
.23122 .54914 m .23237 .55148 L .22927 .5507 L F
.548 .185 .304 r
.23381 .54921 m .23237 .55148 L .23122 .54914 L F
.455 .316 .602 r
.28809 .60183 m .28956 .60318 L .28948 .60066 L F
.28809 .60183 m .28798 .604 L .28956 .60318 L F
.976 .739 .513 r
.34567 .5615 m .34547 .56405 L .34408 .56046 L F
.689 .559 .702 r
.34818 .55837 m .3497 .56315 L .34567 .5615 L F
.219 0 .295 r
.15189 .57977 m .15356 .57907 L .15428 .57692 L F
.399 .255 .568 r
.15168 .58236 m .15356 .57907 L .15189 .57977 L F
.638 .26 .312 r
.26714 .63037 m .27105 .62866 L .26677 .62878 L F
.26714 .63037 m .26949 .63099 L .27105 .62866 L F
.638 .261 .312 r
.27105 .62866 m .27296 .63055 L .27373 .62873 L F
.27105 .62866 m .26949 .63099 L .27296 .63055 L F
.24 .327 .752 r
.18483 .59395 m .18467 .59796 L .18273 .59527 L F
.18483 .59395 m .18587 .59754 L .18467 .59796 L F
.24 .196 .605 r
.18632 .60016 m .18467 .59796 L .18587 .59754 L F
.18632 .60016 m .18482 .60134 L .18467 .59796 L F
.276 .492 .886 r
.29943 .5356 m .29877 .53747 L .29679 .53438 L F
.53 .776 .988 r
.29943 .5356 m .30115 .53697 L .29877 .53747 L F
.546 .419 .659 r
.24544 .68751 m .24769 .68701 L .24774 .68422 L F
.469 .305 .576 r
.30762 .59486 m .30987 .59138 L .30784 .59213 L F
.844 .873 .863 r
.22903 .72752 m .22485 .72889 L .22717 .72682 L F
.416 .811 .986 r
.23023 .72716 m .22903 .72752 L .22717 .72682 L F
.454 0 0 r
.22912 .72778 m .22903 .72752 L .22717 .72682 L F
.22912 .72778 m .23112 .729 L .22903 .72752 L F
.22912 .72778 m .22903 .72752 L .22717 .72682 L F
.22912 .72778 m .23112 .729 L .22903 .72752 L F
.785 .799 .863 r
.78349 .40446 m .78416 .40764 L .78222 .40844 L F
.835 .827 .84 r
.78685 .404 m .78416 .40764 L .78349 .40446 L F
.288 .547 .921 r
.2075 .61212 m .20688 .61375 L .20575 .61185 L F
.674 .253 0 r
.20726 .61476 m .20688 .61375 L .2075 .61212 L F
.20726 .61476 m .20803 .61583 L .20688 .61375 L F
.804 .447 .38 r
.82356 .41868 m .82542 .41812 L .82473 .41717 L F
.82169 .41924 m .82484 .41921 L .82542 .41812 L F
.738 .817 .913 r
.82357 .41559 m .82473 .41717 L .82487 .41582 L F
.82473 .41717 m .82542 .41812 L .82519 .41716 L F
.82473 .41717 m .82519 .41716 L .82487 .41582 L F
.797 .632 .677 r
.82484 .41921 m .82803 .41761 L .82711 .41711 L F
.99 .855 .493 r
.82542 .41812 m .82519 .41716 L .82536 .41617 L F
.797 .632 .677 r
.82546 .41624 m .82711 .41711 L .82547 .41622 L F
.82673 .41712 m .82711 .41711 L .82546 .41624 L F
.653 .673 .857 r
.82536 .41617 m .82803 .41761 L .82775 .41634 L F
.82536 .41617 m .82775 .41634 L .82673 .41712 L F
.82536 .41617 m .82673 .41712 L .82542 .41812 L F
.797 .632 .677 r
.82527 .41716 m .82673 .41712 L .82546 .41624 L F
.99 .855 .493 r
.82542 .41812 m .82484 .41921 L .82519 .41716 L F
.797 .632 .677 r
.82532 .41642 m .82547 .41622 L .82536 .41617 L F
.82519 .41716 m .82547 .41622 L .82532 .41642 L F
.82527 .41716 m .82547 .41622 L .82519 .41716 L F
.738 .817 .913 r
.82487 .41582 m .82519 .41716 L .82775 .41634 L F
.82519 .41716 m .82542 .41812 L .82673 .41712 L F
.82519 .41716 m .82673 .41712 L .82775 .41634 L F
.797 .632 .677 r
.82484 .41921 m .82527 .41716 L .82519 .41716 L F
.82484 .41921 m .82711 .41711 L .82527 .41716 L F
.804 .447 .38 r
.82169 .41924 m .82356 .41868 L .82357 .41559 L F
.82356 .41868 m .82473 .41717 L .82357 .41559 L F
.151 .685 .851 r
.25132 .62611 m .25116 .62657 L .24886 .62615 L F
.25132 .62611 m .25341 .62648 L .25116 .62657 L F
.381 .185 .485 r
.32531 .56073 m .32307 .56396 L .32345 .56155 L F
0 .231 .634 r
.34257 .55963 m .34408 .56046 L .3413 .55882 L F
.607 .833 .986 r
.22687 .63941 m .22851 .64056 L .23097 .63949 L F
.522 .5 .773 r
.32035 .62527 m .31749 .62288 L .31992 .62234 L F
.696 .671 .822 r
.82129 .42442 m .82264 .42055 L .81984 .42102 L F
.82129 .42442 m .82364 .42391 L .82264 .42055 L F
.854 .809 .805 r
.82008 .4256 m .82364 .42391 L .82129 .42442 L F
.374 .233 .558 r
.81776 .40201 m .81851 .40411 L .81638 .40509 L F
.618 .544 .749 r
.81948 .40756 m .81638 .40509 L .81851 .40411 L F
.1 .254 .736 r
.34625 .54421 m .34547 .54608 L .34395 .54456 L F
.34625 .54421 m .34714 .54692 L .34547 .54608 L F
.389 .109 .363 r
.34702 .54728 m .34547 .54608 L .34714 .54692 L F
.34702 .54728 m .3449 .54837 L .34547 .54608 L F
.236 .325 .753 r
.25802 .68491 m .25762 .6864 L .2568 .68363 L F
.25943 .68641 m .2568 .68363 L .25896 .68342 L F
.211 0 0 r
.25896 .68342 m .2568 .68363 L .2548 .68549 L F
.25848 .68314 m .2548 .68549 L .25781 .68274 L F
.25896 .68342 m .25833 .68373 L .25848 .68314 L F
.25833 .68373 m .2548 .68549 L .25848 .68314 L F
.236 .325 .753 r
.25943 .68641 m .25785 .68716 L .25762 .6864 L F
.25943 .68641 m .25762 .6864 L .25802 .68491 L F
.03 0 .278 r
.25735 .68942 m .25785 .68716 L .25943 .68641 L F
.855 .464 .303 r
.55355 .52428 m .55727 .52723 L .557 .52476 L F
.595 .536 .758 r
.29569 .57859 m .29807 .57958 L .29651 .5754 L F
.672 .356 .43 r
.29569 .57859 m .29725 .58121 L .29807 .57958 L F
0 0 0 r
.18368 .57322 m .18156 .57534 L .18202 .57379 L F
.275 .746 .94 r
.31982 .53884 m .32374 .53921 L .32188 .53946 L F
.723 .775 .894 r
.8078 .42855 m .80877 .43179 L .81133 .42899 L F
.747 .608 .703 r
.5075 .55559 m .50762 .55824 L .50992 .55503 L F
.45 .201 .444 r
.30851 .5813 m .30533 .58536 L .30532 .58247 L F
.345 .716 .985 r
.21864 .63794 m .21894 .63671 L .21704 .63683 L F
.294 .664 .972 r
.21864 .63794 m .22062 .63795 L .21894 .63671 L F
.833 .807 .826 r
.81747 .42872 m .82145 .42726 L .82008 .4256 L F
.854 .809 .805 r
.82008 .4256 m .82145 .42726 L .82364 .42391 L F
.147 .279 .743 r
.34913 .55672 m .34818 .55837 L .34697 .55508 L F
.217 .373 .806 r
.34913 .55672 m .35063 .56006 L .34818 .55837 L F
.389 .378 .726 r
.35063 .56006 m .3497 .56315 L .34818 .55837 L F
.857 .687 .67 r
.54864 .54995 m .54675 .55081 L .54624 .54849 L F
.061 .291 .779 r
.54202 .58278 m .54296 .58149 L .54178 .58068 L F
.54202 .58278 m .54448 .58478 L .54296 .58149 L F
.718 .508 .604 r
.83062 .40432 m .83467 .40465 L .83461 .40192 L F
0 .259 .744 r
.83839 .40504 m .83461 .40192 L .83467 .40465 L F
0 0 0 r
.20706 .55986 m .20233 .56246 L .20491 .56044 L F
.562 .631 .878 r
.20495 .63466 m .20785 .63676 L .20642 .63477 L F
.672 .791 .938 r
.20642 .63477 m .20785 .63676 L .21032 .6356 L F
.761 .688 .782 r
.55426 .58533 m .55795 .58557 L .55683 .58213 L F
.55426 .58533 m .55595 .58628 L .55795 .58557 L F
.747 .632 .733 r
.55595 .58628 m .55536 .58862 L .55795 .58557 L F
.364 .225 .555 r
.19843 .78564 m .19623 .78532 L .19803 .78426 L F
.925 .914 .789 r
.55491 .54721 m .55706 .5468 L .55656 .54439 L F
.55491 .54721 m .55588 .54839 L .55706 .5468 L F
.069 0 0 r
.16134 .57021 m .16317 .56958 L .16493 .56763 L F
0 0 0 r
.16741 .56459 m .16493 .56763 L .16627 .56637 L F
.132 0 0 r
.16493 .56763 m .1653 .56886 L .16627 .56637 L F
.16493 .56763 m .16317 .56958 L .1653 .56886 L F
.779 .779 .853 r
.80996 .4228 m .81351 .42322 L .81272 .4202 L F
.789 .438 .391 r
.8138 .42573 m .81351 .42322 L .80996 .4228 L F
.771 .774 .855 r
.81272 .4202 m .81351 .42322 L .81583 .42052 L F
.638 .325 .424 r
.8138 .42573 m .81648 .42516 L .81351 .42322 L F
.288 .521 .904 r
.1996 .60652 m .19888 .60826 L .19792 .60636 L F
.1996 .60652 m .20175 .60927 L .19888 .60826 L F
.046 0 0 r
.24386 .54844 m .24195 .54842 L .24081 .54836 L F
.167 .704 .81 r
.24601 .54819 m .24195 .54842 L .24386 .54844 L F
.272 0 0 r
.24601 .54819 m .24438 .54862 L .24195 .54842 L F
.297 0 0 r
.24438 .54862 m .24316 .54848 L .24195 .54842 L F
.24316 .54848 m .23986 .54811 L .24195 .54842 L F
.046 0 0 r
.24081 .54836 m .24195 .54842 L .23975 .54834 L F
.402 .741 .993 r
.25843 .64264 m .26179 .64415 L .26196 .64271 L F
.074 .403 .857 r
.26196 .64271 m .26179 .64415 L .26393 .64482 L F
.05 0 .234 r
.26519 .61681 m .26459 .61906 L .26662 .61579 L F
.074 0 0 r
.20106 .54328 m .19803 .54552 L .19989 .54473 L F
0 0 0 r
.19989 .54473 m .2033 .54273 L .20106 .54328 L F
.572 .534 .774 r
.47385 .62254 m .47475 .62606 L .47717 .62532 L F
.49 .292 .539 r
.47475 .62606 m .47702 .62791 L .47717 .62532 L F
.47475 .62606 m .47702 .62791 L .47717 .62532 L F
.215 .541 .927 r
.20314 .60958 m .20292 .61101 L .20175 .60927 L F
.20314 .60958 m .20575 .61185 L .20292 .61101 L F
.535 .84 .999 r
.26034 .53306 m .25983 .53456 L .25816 .53333 L F
.26034 .53306 m .26209 .53395 L .25983 .53456 L F
.075 0 0 r
.19352 .56816 m .19309 .56705 L .19486 .56672 L F
.19352 .56816 m .19154 .56892 L .19309 .56705 L F
.922 .755 .658 r
.55659 .52936 m .55881 .52781 L .55727 .52723 L F
.55659 .52936 m .55843 .53052 L .55881 .52781 L F
.147 0 .02 r
.16627 .56637 m .16954 .56393 L .16741 .56459 L F
.43 0 0 r
.22281 .62172 m .2211 .62073 L .21898 .62025 L F
0 0 0 r
.32071 .56959 m .32273 .56902 L .32438 .56838 L F
.235 .084 .463 r
.32285 .56659 m .32273 .56902 L .32143 .56862 L F
.419 .406 .738 r
.3217 .5731 m .32273 .56902 L .32071 .56959 L F
0 0 0 r
.32059 .57013 m .32143 .56862 L .32273 .56902 L F
.493 .283 .522 r
.3252 .56606 m .3252 .56838 L .32395 .56743 L F
.32498 .56611 m .32395 .56743 L .32285 .56659 L F
.3252 .56606 m .32395 .56743 L .32498 .56611 L F
0 0 .157 r
.3235 .56657 m .32285 .56659 L .32395 .56743 L F
.3235 .56657 m .32395 .56743 L .3252 .56838 L F
.3235 .56657 m .32273 .56902 L .32285 .56659 L F
.854 .993 .746 r
.3235 .56657 m .32094 .5697 L .32269 .56903 L F
.32274 .56896 m .32269 .56903 L .32273 .56902 L F
.3235 .56657 m .32269 .56903 L .32274 .56896 L F
.32094 .5697 m .32059 .57013 L .32273 .56902 L F
0 0 0 r
.32438 .56838 m .32273 .56902 L .32444 .56837 L F
.32444 .56837 m .3252 .56838 L .32691 .56835 L F
.32444 .56837 m .32273 .56902 L .3252 .56838 L F
.423 .732 .99 r
.80128 .42856 m .80224 .42977 L .80498 .42957 L F
.355 .323 .685 r
.23371 .72345 m .23023 .72716 L .23154 .7245 L F
.764 .961 .657 r
.23371 .72345 m .23549 .72086 L .23634 .72257 L F
.538 .413 .659 r
.23634 .72257 m .23438 .72711 L .23371 .72345 L F
.469 .22 .453 r
.16916 .75992 m .17122 .75764 L .17078 .76063 L F
.17078 .76063 m .17122 .75764 L .16916 .75992 L F
.557 .296 .476 r
.17318 .7599 m .17122 .75764 L .17078 .76063 L F
.17078 .76063 m .17122 .75764 L .17318 .7599 L F
.558 .604 .855 r
.23934 .70083 m .24203 .70231 L .2406 .6995 L F
0 .25 .647 r
.23934 .70083 m .24203 .70231 L .24049 .70142 L F
.855 .753 .75 r
.82348 .39787 m .82644 .39835 L .82715 .39598 L F
.862 .73 .715 r
.82348 .39787 m .82463 .40156 L .82644 .39835 L F
.404 .69 .978 r
.18975 .62237 m .1908 .62092 L .18706 .61955 L F
.18975 .62237 m .19156 .62211 L .1908 .62092 L F
.642 .673 .864 r
.5523 .58632 m .55536 .58862 L .55595 .58628 L F
0 0 .058 r
.25103 .67173 m .2476 .67416 L .2497 .67314 L F
.215 0 0 r
.25223 .67246 m .25103 .67173 L .2497 .67314 L F
.25223 .67246 m .2539 .67128 L .25103 .67173 L F
.146 .689 .731 r
.2308 .53671 m .23309 .53631 L .23455 .53612 L F
.181 .714 .749 r
.23455 .53612 m .23309 .53631 L .23696 .53564 L F
.963 .721 .524 r
.52983 .52788 m .52822 .52735 L .52798 .5231 L F
.936 .59 .345 r
.52983 .52788 m .52846 .52914 L .52822 .52735 L F
.069 0 0 r
.53241 .52743 m .52846 .52914 L .52983 .52788 L F
.468 .629 .923 r
.17356 .58672 m .17269 .589 L .17212 .58465 L F
.17356 .58672 m .17466 .58872 L .17269 .589 L F
.299 .243 .625 r
.33042 .5545 m .33099 .55746 L .32919 .55797 L F
.575 .53 .768 r
.33099 .55746 m .3289 .56039 L .32919 .55797 L F
.567 .835 .996 r
.79601 .43022 m .79764 .42835 L .795 .42848 L F
.79601 .43022 m .79872 .42948 L .79764 .42835 L F
.757 .47 .498 r
.83883 .40748 m .83839 .40504 L .83467 .40465 L F
.351 .085 .363 r
.15597 .57607 m .15865 .57315 L .15664 .57389 L F
0 0 0 r
.23549 .72086 m .23532 .72084 L .23173 .72301 L F
0 0 .027 r
.18632 .60016 m .18424 .60315 L .18482 .60134 L F
.718 .589 .711 r
.28948 .60066 m .29353 .60286 L .29097 .60111 L F
.498 .269 .497 r
.3073 .63486 m .30701 .63752 L .30467 .63779 L F
.591 .357 .53 r
.31 .63462 m .30701 .63752 L .3073 .63486 L F
.631 .958 .918 r
.25705 .62508 m .25341 .62648 L .25594 .6255 L F
.388 .84 .748 r
.2595 .62393 m .25705 .62508 L .25791 .62446 L F
.396 .837 .715 r
.25791 .62446 m .25705 .62508 L .25594 .6255 L F
.142 0 .273 r
.82153 .39932 m .82348 .39787 L .82353 .3962 L F
.855 .753 .75 r
.82348 .39787 m .82715 .39598 L .82353 .3962 L F
.351 .113 .406 r
.15902 .57091 m .16064 .57242 L .16134 .57021 L F
.15902 .57091 m .15865 .57315 L .16064 .57242 L F
.365 .332 .688 r
.15033 .58875 m .15072 .59257 L .15261 .59078 L F
.347 .353 .724 r
.15181 .595 m .15261 .59078 L .15072 .59257 L F
0 0 .233 r
.50217 .59833 m .50294 .5976 L .50319 .59488 L F
0 0 .494 r
.50217 .59833 m .50318 .60035 L .50294 .5976 L F
.514 .833 .999 r
.54035 .56144 m .53964 .56045 L .54275 .5608 L F
.984 .902 .587 r
.54035 .56144 m .53881 .56295 L .53964 .56045 L F
.688 .241 .185 r
.54261 .56328 m .53881 .56295 L .54035 .56144 L F
.5 .34 .595 r
.54275 .5608 m .54261 .56328 L .54035 .56144 L F
.351 .121 .418 r
.15356 .57907 m .15597 .57607 L .15428 .57692 L F
.347 .353 .724 r
.15181 .595 m .15326 .5944 L .15261 .59078 L F
.276 .327 .734 r
.15181 .595 m .15384 .59736 L .15326 .5944 L F
.332 .793 .94 r
.26769 .53419 m .27021 .53388 L .27255 .53447 L F
.358 .806 .95 r
.27021 .53388 m .27486 .53411 L .27255 .53447 L F
.988 .864 .624 r
.55785 .53455 m .55784 .53962 L .55947 .53629 L F
.381 .009 .202 r
.807 .40942 m .80998 .40765 L .80731 .40863 L F
.281 .046 .368 r
.17927 .59112 m .17831 .59421 L .17736 .59259 L F
.797 .632 .677 r
.82484 .41921 m .82856 .42014 L .82803 .41761 L F
.546 .6 .859 r
.82803 .41761 m .82978 .41561 L .82775 .41634 L F
.576 .646 .883 r
.82803 .41761 m .83151 .41721 L .82978 .41561 L F
.72 .731 .86 r
.82856 .42014 m .83151 .41721 L .82803 .41761 L F
.353 .754 .984 r
.25099 .64206 m .25117 .64092 L .24941 .64099 L F
.25099 .64206 m .25276 .64221 L .25117 .64092 L F
.745 .736 .843 r
.77957 .4037 m .78012 .40781 L .77924 .40716 L F
.719 .717 .848 r
.78027 .4076 m .78012 .40781 L .78008 .40751 L F
.731 .736 .855 r
.78012 .40781 m .78027 .4076 L .77924 .40716 L F
.902 .866 .794 r
.78027 .4076 m .77999 .40955 L .77924 .40716 L F
.731 .736 .855 r
.78012 .40781 m .78222 .40844 L .78027 .4076 L F
.785 .799 .863 r
.78031 .40762 m .78222 .40844 L .78012 .40781 L F
.902 .866 .794 r
.78222 .40844 m .78031 .40762 L .78027 .4076 L F
.785 .799 .863 r
.78349 .40446 m .78222 .40844 L .78031 .40762 L F
.902 .866 .794 r
.78222 .40844 m .78209 .4085 L .78031 .40762 L F
.78209 .4085 m .77999 .40955 L .78027 .4076 L F
.719 .717 .848 r
.78264 .40429 m .78027 .4076 L .77957 .4037 L F
.78027 .4076 m .78008 .40751 L .77957 .4037 L F
.78349 .40446 m .78012 .40781 L .78264 .40429 L F
.902 .866 .794 r
.78222 .40844 m .78103 .40952 L .77999 .40955 L F
.69 .621 .773 r
.82364 .42391 m .82484 .41921 L .82264 .42055 L F
.82364 .42391 m .82614 .42306 L .82484 .41921 L F
.783 .67 .739 r
.82614 .42306 m .82856 .42014 L .82484 .41921 L F
.694 .534 .666 r
.82614 .42306 m .83047 .42313 L .82856 .42014 L F
.445 .779 .998 r
.30585 .53631 m .30494 .53773 L .30335 .53646 L F
.30585 .53631 m .30886 .53769 L .30494 .53773 L F
.777 .772 .848 r
.83151 .41721 m .83503 .41758 L .83356 .41602 L F
.843 .838 .84 r
.83503 .41758 m .83633 .41307 L .83356 .41602 L F
.83503 .41758 m .83764 .41453 L .83633 .41307 L F
.473 .248 .492 r
.3076 .58672 m .30518 .58792 L .30527 .58646 L F
.30572 .58559 m .30527 .58646 L .30533 .58536 L F
.3076 .58672 m .30527 .58646 L .30572 .58559 L F
.708 .517 .628 r
.31037 .58418 m .30572 .58559 L .30851 .5813 L F
.30572 .58559 m .30563 .58562 L .30594 .58514 L F
.30572 .58559 m .30594 .58514 L .30851 .5813 L F
.473 .248 .492 r
.3076 .58672 m .30572 .58559 L .30563 .58562 L F
.30572 .58559 m .30533 .58536 L .30563 .58562 L F
.708 .517 .628 r
.31118 .58545 m .30563 .58562 L .31037 .58418 L F
.45 .201 .444 r
.30851 .5813 m .30563 .58562 L .30533 .58536 L F
.235 0 0 r
.31099 .58052 m .31102 .58149 L .30851 .5813 L F
.708 .517 .628 r
.31118 .58545 m .30851 .5813 L .31102 .58149 L F
.354 .818 .917 r
.17772 .58272 m .176 .5825 L .17383 .58309 L F
.776 .836 .374 r
.17878 .57961 m .17772 .58272 L .176 .57921 L F
.17862 .58009 m .17798 .58127 L .17772 .58272 L F
.663 .953 .95 r
.17798 .58127 m .176 .5825 L .17772 .58272 L F
0 0 0 r
.18079 .5794 m .17736 .58244 L .17798 .58127 L F
.17736 .58244 m .177 .58275 L .17798 .58127 L F
.776 .836 .374 r
.17878 .57961 m .17798 .58127 L .17862 .58009 L F
.668 .242 .226 r
.54361 .52011 m .54596 .52063 L .54363 .51878 L F
.487 .076 .187 r
.29013 .64387 m .28848 .64609 L .28606 .64613 L F
.578 .219 .323 r
.29255 .6437 m .28848 .64609 L .29013 .64387 L F
.971 .725 .507 r
.29552 .60322 m .29703 .60678 L .29734 .60424 L F
.548 .837 .998 r
.29959 .60354 m .29552 .60322 L .29734 .60424 L F
.555 .363 .575 r
.29703 .60678 m .29959 .60354 L .29734 .60424 L F
.32 .757 .968 r
.3494 .55198 m .35275 .55164 L .35317 .55234 L F
.031 0 0 r
.35317 .55234 m .34922 .55436 L .3494 .55198 L F
.35317 .55234 m .35141 .55371 L .34922 .55436 L F
.811 1 .821 r
.35317 .55234 m .35275 .55164 L .35346 .55053 L F
.088 0 0 r
.35377 .55308 m .35317 .55234 L .35346 .55053 L F
.35377 .55308 m .35141 .55371 L .35317 .55234 L F
.053 0 .412 r
.28194 .60011 m .28025 .6037 L .28055 .60117 L F
.642 .673 .864 r
.5523 .58632 m .55595 .58628 L .55426 .58533 L F
.793 .711 .774 r
.2406 .6995 m .24203 .70231 L .24437 .69901 L F
0 .091 .645 r
.24203 .70231 m .2443 .70497 L .24494 .70293 L F
.397 .173 .453 r
.30987 .59138 m .3122 .58847 L .3106 .58898 L F
.583 .332 .503 r
.3281 .61854 m .32535 .61674 L .32809 .61616 L F
.3281 .61854 m .325 .61899 L .32535 .61674 L F
.353 .244 .589 r
.24805 .70493 m .24769 .7072 L .24649 .70619 L F
.115 .665 .71 r
.21516 .76055 m .2133 .7581 L .21509 .75661 L F
.579 .306 .466 r
.2133 .7581 m .21508 .75751 L .21509 .75661 L F
.115 .665 .71 r
.21482 .7601 m .21242 .76096 L .2133 .7581 L F
.21516 .76055 m .2147 .76062 L .21482 .7601 L F
.2147 .76062 m .21242 .76096 L .21482 .7601 L F
.225 0 0 r
.21329 .75916 m .21482 .75807 L .2133 .7581 L F
.21482 .75807 m .21508 .75751 L .2133 .7581 L F
.939 .778 .654 r
.21451 .75672 m .21475 .75775 L .21329 .75916 L F
.225 0 0 r
.21537 .75768 m .21608 .75717 L .21543 .75739 L F
.956 .701 .251 r
.21505 .75986 m .21508 .75751 L .21476 .7582 L F
.225 0 0 r
.21482 .75807 m .21522 .75746 L .21508 .75751 L F
.939 .778 .654 r
.21552 .75701 m .21537 .75768 L .21482 .75807 L F
.21475 .75775 m .21482 .75807 L .21329 .75916 L F
.956 .701 .251 r
.21508 .75751 m .21509 .75661 L .21476 .7582 L F
.939 .778 .654 r
.21552 .75701 m .21482 .75807 L .21475 .75775 L F
.956 .701 .251 r
.21516 .76055 m .21514 .75943 L .21505 .75986 L F
.21514 .75943 m .21509 .75661 L .21506 .75906 L F
.21514 .75943 m .21506 .75906 L .21505 .75986 L F
.21476 .7582 m .21481 .75799 L .21451 .75672 L F
.21481 .75799 m .21509 .75661 L .21451 .75672 L F
.579 .306 .466 r
.21508 .75751 m .21608 .75717 L .21509 .75661 L F
.939 .778 .654 r
.21451 .75672 m .21552 .75701 L .21475 .75775 L F
.21552 .75701 m .21608 .75717 L .21537 .75768 L F
.494 0 0 r
.21509 .75661 m .21608 .75717 L .21451 .75672 L F
.538 .413 .659 r
.23634 .72257 m .23654 .72949 L .23438 .72711 L F
0 .191 .722 r
.23438 .72711 m .23521 .72802 L .23599 .72831 L F
.23521 .72802 m .23654 .72949 L .23599 .72831 L F
.291 .219 .601 r
.23838 .72602 m .23654 .72949 L .23634 .72257 L F
.74 .768 .876 r
.23599 .72831 m .23654 .72949 L .23838 .72602 L F
.218 0 0 r
.23715 .72874 m .23599 .72831 L .23769 .72862 L F
.23526 .72915 m .23599 .72831 L .23715 .72874 L F
0 .191 .722 r
.23438 .72711 m .23599 .72831 L .23471 .72973 L F
.555 .39 .613 r
.31794 .62827 m .31592 .63184 L .31533 .62861 L F
0 0 .443 r
.31909 .57106 m .31829 .57392 L .31786 .56977 L F
.014 0 .421 r
.32016 .57506 m .31829 .57392 L .31909 .57106 L F
.508 .087 .178 r
.32045 .58486 m .32327 .58514 L .32456 .58281 L F
.067 0 0 r
.32456 .58281 m .32516 .5841 L .327 .58227 L F
.32456 .58281 m .32327 .58514 L .32516 .5841 L F
.575 .742 .955 r
.29474 .53451 m .29113 .53362 L .29337 .53307 L F
.364 .703 .985 r
.29526 .53328 m .29474 .53451 L .29337 .53307 L F
.29526 .53328 m .29679 .53438 L .29474 .53451 L F
.02 .19 .699 r
.28562 .58505 m .28657 .58379 L .28506 .5826 L F
0 0 0 r
.28562 .58505 m .28447 .58719 L .28657 .58379 L F
.27527 .61522 m .27332 .61872 L .2741 .61647 L F
.17 0 0 r
.19167 .60753 m .19305 .60771 L .19568 .60676 L F
.56 .931 .805 r
.19568 .60676 m .19606 .60588 L .19792 .60636 L F
.19568 .60676 m .19305 .60771 L .19606 .60588 L F
.738 .667 .78 r
.26293 .66566 m .26575 .66343 L .2613 .66215 L F
.122 .664 .837 r
.24504 .5552 m .24342 .55493 L .24102 .55496 L F
.669 .118 0 r
.24374 .55218 m .24556 .55389 L .24391 .55342 L F
.24556 .55389 m .24609 .55439 L .2446 .55373 L F
.24556 .55389 m .2446 .55373 L .24391 .55342 L F
0 0 0 r
.24687 .55412 m .24342 .55493 L .24504 .5552 L F
.24714 .55396 m .24667 .55408 L .24687 .55412 L F
.24667 .55408 m .24342 .55493 L .24687 .55412 L F
.563 .245 .388 r
.29896 .64101 m .30108 .64292 L .29882 .64288 L F
.576 .242 .365 r
.30161 .64106 m .30108 .64292 L .29896 .64101 L F
.943 .771 .639 r
.83842 .40984 m .83993 .41124 L .83883 .40748 L F
.868 .811 .791 r
.83764 .41453 m .83993 .41124 L .83842 .40984 L F
.582 .671 .9 r
.54562 .58804 m .54678 .58442 L .54448 .58478 L F
.54562 .58804 m .54696 .5873 L .54678 .58442 L F
.293 .744 .958 r
.25276 .64221 m .25415 .64098 L .25117 .64092 L F
.25276 .64221 m .25594 .64207 L .25415 .64098 L F
.627 .356 .488 r
.50319 .59488 m .50294 .5976 L .50553 .59724 L F
0 .27 .681 r
.50503 .5621 m .50608 .56249 L .50578 .56032 L F
.50503 .5621 m .50578 .56032 L .50584 .56158 L F
.086 .55 .905 r
.50503 .5621 m .50584 .56158 L .50144 .56045 L F
0 .27 .681 r
.50503 .5621 m .50772 .56352 L .50608 .56249 L F
.931 .886 .767 r
.54865 .54268 m .54539 .54492 L .54774 .54185 L F
.54865 .54268 m .54671 .54598 L .54539 .54492 L F
.994 .802 .432 r
.54865 .54268 m .54774 .54185 L .54802 .53914 L F
.712 .259 .174 r
.26989 .64913 m .27152 .64762 L .2731 .64967 L F
.528 .336 .564 r
.28016 .5551 m .28255 .55469 L .28262 .55209 L F
.411 .253 .555 r
.28016 .5551 m .2821 .55755 L .28255 .55469 L F
.528 .336 .564 r
.28016 .5551 m .28255 .55469 L .28262 .55209 L F
.521 .363 .607 r
.29477 .61028 m .29703 .60678 L .29473 .60731 L F
0 0 .184 r
.29534 .60914 m .29473 .60731 L .29703 .60678 L F
.29534 .60914 m .29477 .61028 L .29473 .60731 L F
.575 .308 .473 r
.3071 .63989 m .30467 .63779 L .30701 .63752 L F
.3071 .63989 m .30389 .6405 L .30467 .63779 L F
.123 0 .154 r
.33922 .59735 m .33753 .59815 L .33992 .59548 L F
.432 .097 .295 r
.3418 .59679 m .33922 .59735 L .33992 .59548 L F
.553 .401 .628 r
.34287 .59132 m .3425 .59535 L .33992 .59548 L F
.46 .081 .232 r
.3425 .59535 m .3418 .59679 L .33992 .59548 L F
.365 .332 .688 r
.15033 .58875 m .15261 .59078 L .15184 .5883 L F
0 .543 .722 r
.23289 .6244 m .23698 .62474 L .23497 .62459 L F
.985 .789 .557 r
.50623 .55719 m .50762 .55824 L .5075 .55559 L F
.796 .562 .583 r
.54431 .53012 m .54226 .53313 L .54247 .53011 L F
.54431 .53012 m .54543 .53368 L .54226 .53313 L F
.568 .903 .979 r
.2451 .69759 m .24437 .69901 L .24272 .69839 L F
.684 .139 0 r
.24272 .69839 m .24437 .69901 L .2466 .7013 L F
.556 .75 .968 r
.16653 .6069 m .16968 .60761 L .16883 .60631 L F
.43 .678 .967 r
.16883 .60631 m .16968 .60761 L .17072 .6061 L F
.225 .394 .822 r
.16968 .60761 m .17247 .60952 L .17072 .6061 L F
.877 .803 .773 r
.55231 .5505 m .55588 .54839 L .55491 .54721 L F
.55231 .5505 m .55392 .55185 L .55588 .54839 L F
.466 .295 .564 r
.47018 .63529 m .47255 .63446 L .47258 .6316 L F
.506 .253 .465 r
.47255 .63446 m .46962 .63724 L .47018 .63529 L F
0 0 0 r
.47018 .63529 m .47076 .63562 L .47255 .63446 L F
.47018 .63529 m .46962 .63724 L .47076 .63562 L F
.466 .295 .564 r
.47258 .6316 m .47255 .63446 L .47018 .63529 L F
.399 .838 .942 r
.50226 .53371 m .50432 .53284 L .50481 .53317 L F
.50226 .53371 m .50432 .53284 L .50481 .53317 L F
.976 .824 .628 r
.50623 .55719 m .50578 .56032 L .50762 .55824 L F
.84 .541 .483 r
.50762 .55824 m .50578 .56032 L .50985 .56059 L F
.97 .654 .341 r
.18148 .58579 m .18036 .58894 L .18214 .5888 L F
.655 .103 0 r
.53628 .52751 m .53663 .52876 L .53583 .52743 L F
.53628 .52751 m .5386 .52944 L .53663 .52876 L F
.345 .497 .867 r
.19334 .62547 m .19431 .62353 L .19156 .62211 L F
.19334 .62547 m .19506 .62537 L .19431 .62353 L F
.476 .332 .605 r
.28798 .604 m .29026 .60733 L .28956 .60318 L F
.28798 .604 m .28724 .60809 L .29026 .60733 L F
.077 0 0 r
.18391 .55264 m .18282 .55403 L .18587 .55175 L F
.407 0 0 r
.32691 .56835 m .32883 .56875 L .33076 .56758 L F
.463 0 .068 r
.32883 .56875 m .33306 .56701 L .33076 .56758 L F
.893 .733 .676 r
.55301 .5638 m .55435 .56724 L .55488 .56473 L F
.104 0 0 r
.27876 .54935 m .27709 .55095 L .27505 .55152 L F
.581 .777 .973 r
.27693 .54764 m .27876 .54935 L .27943 .54714 L F
.399 .583 .916 r
.27876 .54935 m .28076 .5492 L .27943 .54714 L F
.527 .587 .858 r
.27876 .54935 m .28262 .55209 L .28076 .5492 L F
.519 .73 .97 r
.18171 .61853 m .18555 .61961 L .18411 .61802 L F
.336 .434 .813 r
.18555 .61961 m .18673 .61777 L .18411 .61802 L F
.18555 .61961 m .18706 .61955 L .18673 .61777 L F
.507 .308 .544 r
.31225 .58558 m .31452 .58509 L .31478 .58271 L F
.595 .391 .575 r
.31225 .58558 m .31498 .5873 L .31452 .58509 L F
.31225 .58558 m .3122 .58847 L .31498 .5873 L F
.753 .599 .686 r
.31841 .58255 m .32041 .58303 L .32081 .57987 L F
.478 .407 .699 r
.32081 .57987 m .32232 .57616 L .31962 .57632 L F
.32081 .57987 m .32277 .57945 L .32232 .57616 L F
.462 .591 .896 r
.19506 .62537 m .19723 .62865 L .19888 .62813 L F
.688 .253 .211 r
.29633 .59808 m .2937 .59969 L .29189 .59761 L F
.928 .674 .533 r
.29633 .59808 m .2961 .60061 L .29395 .59978 L F
.29633 .59808 m .29395 .59978 L .29391 .59956 L F
.317 .211 .573 r
.29349 .59699 m .29542 .59904 L .2953 .59533 L F
.29342 .59706 m .29352 .59715 L .29349 .59699 L F
.29352 .59715 m .29542 .59904 L .29349 .59699 L F
.928 .674 .533 r
.29391 .59956 m .29395 .59978 L .2937 .59969 L F
.442 .081 .256 r
.46311 .64944 m .46641 .647 L .46335 .64675 L F
.943 .766 .634 r
.50608 .56249 m .50985 .56059 L .50578 .56032 L F
.50608 .56249 m .50772 .56352 L .50985 .56059 L F
.946 .705 .541 r
.55583 .53188 m .55843 .53052 L .55659 .52936 L F
.55583 .53188 m .55837 .53343 L .55843 .53052 L F
.759 .747 .842 r
.26317 .66876 m .2605 .67197 L .25899 .67058 L F
.696 .644 .794 r
.26317 .66876 m .2642 .6713 L .2605 .67197 L F
.419 0 .051 r
.2605 .67197 m .26366 .6714 L .26222 .67303 L F
.614 .589 .802 r
.25935 .67284 m .26222 .67303 L .26116 .67078 L F
.952 .683 .49 r
.26019 .67228 m .26222 .67303 L .26072 .67489 L F
.419 0 .051 r
.26366 .6714 m .2642 .6713 L .26222 .67303 L F
.517 .545 .823 r
.26594 .67093 m .2642 .6713 L .26317 .66876 L F
.177 0 0 r
.26441 .6718 m .2642 .6713 L .26594 .67093 L F
.26222 .67303 m .26361 .67182 L .26441 .6718 L F
.26361 .67182 m .2642 .6713 L .26441 .6718 L F
.766 .626 .705 r
.26508 .66787 m .26936 .66857 L .26594 .67093 L F
.517 .545 .823 r
.26594 .67093 m .26317 .66876 L .26508 .66787 L F
.177 0 0 r
.26222 .67303 m .26594 .67093 L .26498 .67227 L F
.968 .934 .675 r
.26498 .67227 m .26594 .67093 L .26542 .67053 L F
.265 .67178 m .26542 .67053 L .26506 .67026 L F
.26498 .67227 m .26542 .67053 L .265 .67178 L F
.689 .239 .178 r
.26552 .67024 m .26632 .6695 L .26579 .67175 L F
.26508 .66787 m .26594 .66899 L .26552 .67024 L F
.26594 .66899 m .26632 .6695 L .26552 .67024 L F
.26571 .67175 m .26579 .67175 L .26574 .67197 L F
.26508 .66787 m .26506 .67026 L .26594 .67093 L F
.26508 .66787 m .26579 .67175 L .26571 .67175 L F
.788 .776 .842 r
.26222 .67303 m .26498 .67227 L .26328 .67154 L F
.26222 .67303 m .2641 .67039 L .26116 .67078 L F
.26211 .67103 m .26498 .67227 L .26222 .67303 L F
.26222 .67303 m .26506 .67026 L .2641 .67039 L F
.26222 .67303 m .26328 .67154 L .26211 .67103 L F
.906 .857 .783 r
.26211 .67103 m .26222 .67303 L .26019 .67228 L F
.991 .884 .577 r
.26082 .67462 m .26222 .67303 L .26211 .67103 L F
.26072 .67489 m .26222 .67303 L .26082 .67462 L F
.576 .716 .938 r
.28262 .55209 m .28362 .54965 L .28076 .5492 L F
.28262 .55209 m .28496 .55154 L .28362 .54965 L F
.304 .07 .384 r
.28255 .55469 m .28496 .55154 L .28262 .55209 L F
.513 .671 .935 r
.3422 .58714 m .3413 .58772 L .33923 .58472 L F
.457 .416 .724 r
.3422 .58714 m .34136 .58847 L .3413 .58772 L F
.253 .006 .332 r
.26911 .61255 m .26732 .61347 L .26662 .61579 L F
0 0 .136 r
.26925 .61014 m .26732 .61347 L .26911 .61255 L F
.357 0 .127 r
.19425 .54818 m .19659 .54778 L .19803 .54552 L F
0 0 0 r
.19803 .54552 m .19848 .54671 L .19989 .54473 L F
.19803 .54552 m .19659 .54778 L .19848 .54671 L F
.332 .643 .966 r
.2227 .63747 m .22624 .63998 L .22687 .63941 L F
.92 .782 .692 r
.34368 .56975 m .34435 .57263 L .34351 .5704 L F
.588 .627 .858 r
.3451 .57717 m .34351 .5704 L .34435 .57263 L F
.478 .366 .648 r
.34718 .576 m .34435 .57263 L .34724 .57253 L F
.34718 .576 m .3451 .57717 L .34435 .57263 L F
.193 0 .249 r
.17383 .58309 m .17284 .58553 L .17212 .58465 L F
0 0 .485 r
.17284 .58553 m .17356 .58672 L .17212 .58465 L F
.491 .308 .56 r
.33922 .59735 m .33697 .60041 L .33753 .59815 L F
.725 .84 .935 r
.82089 .40415 m .81948 .40756 L .81851 .40411 L F
.82089 .40415 m .8218 .40622 L .81948 .40756 L F
.585 .648 .879 r
.77718 .40834 m .77571 .411 L .77507 .40825 L F
.522 .568 .843 r
.77718 .40834 m .77911 .4111 L .77571 .411 L F
.542 .529 .791 r
.77963 .41429 m .77571 .411 L .77911 .4111 L F
.534 .426 .678 r
.32994 .61241 m .32722 .61043 L .32968 .60988 L F
.32994 .61241 m .32771 .613 L .32722 .61043 L F
.72 .756 .881 r
.5049 .54848 m .50874 .54899 L .50734 .54747 L F
.5049 .54848 m .50874 .54899 L .50734 .54747 L F
.375 .617 .946 r
.50874 .54899 m .50981 .54736 L .50734 .54747 L F
.50734 .54747 m .50981 .54736 L .50874 .54899 L F
.36 0 0 r
.21539 .5572 m .21184 .55798 L .21364 .55819 L F
.833 .668 .679 r
.55438 .56972 m .55775 .57263 L .5577 .57089 L F
.152 0 0 r
.53105 .52173 m .53359 .52131 L .53457 .5207 L F
.122 0 0 r
.53359 .52131 m .53719 .52007 L .53457 .5207 L F
.843 .447 .296 r
.79048 .4063 m .79265 .40524 L .78979 .40371 L F
.79048 .4063 m .79331 .40697 L .79265 .40524 L F
.355 .161 .473 r
.30283 .59122 m .30091 .59191 L .3031 .58869 L F
.378 .211 .525 r
.30283 .59122 m .30272 .59397 L .30091 .59191 L F
.364 .209 .533 r
.30091 .59191 m .30272 .59397 L .30089 .5944 L F
0 0 .07 r
.24956 .68055 m .24774 .68422 L .24961 .6834 L F
.55 .249 .411 r
.25229 .68259 m .24956 .68055 L .24961 .6834 L F
.25229 .68259 m .25279 .68021 L .24956 .68055 L F
.456 .69 .967 r
.79264 .42872 m .79413 .42694 L .79272 .4273 L F
.79264 .42872 m .795 .42848 L .79413 .42694 L F
.868 .811 .791 r
.83764 .41453 m .83842 .40984 L .83633 .41307 L F
.819 .398 .246 r
.25293 .55146 m .2482 .54798 L .24965 .54927 L F
.302 0 0 r
.20765 .54135 m .21193 .53962 L .20968 .54018 L F
0 .309 .667 r
.29198 .54804 m .29436 .5491 L .28982 .54704 L F
.769 .592 .658 r
.29353 .55099 m .28982 .54704 L .29436 .5491 L F
.29353 .55099 m .28935 .5509 L .28982 .54704 L F
.567 .407 .625 r
.28982 .54704 m .28935 .5509 L .29323 .5492 L F
.28982 .54704 m .29323 .5492 L .29043 .54999 L F
0 0 .499 r
.28982 .54704 m .29043 .54999 L .29044 .54739 L F
.354 0 0 r
.29198 .54804 m .28982 .54704 L .28878 .54645 L F
0 0 .499 r
.28982 .54704 m .29044 .54739 L .29045 .54373 L F
.354 0 0 r
.28878 .54645 m .28982 .54704 L .28758 .54585 L F
.213 .735 .742 r
.82494 .40468 m .82861 .40389 L .82626 .40602 L F
.282 .299 .701 r
.35439 .56612 m .35281 .56744 L .35232 .5639 L F
.264 .217 .616 r
.35439 .56612 m .35314 .5701 L .35281 .56744 L F
.765 .585 .654 r
.79331 .40697 m .79712 .41026 L .79681 .4077 L F
.747 .561 .644 r
.79712 .41026 m .80084 .408 L .79681 .4077 L F
.556 .547 .799 r
.29651 .5754 m .29511 .57473 L .29683 .57339 L F
.549 .549 .807 r
.29511 .57473 m .29651 .5754 L .29683 .57339 L F
.604 .584 .804 r
.29856 .57306 m .29651 .5754 L .29683 .57339 L F
.591 .564 .793 r
.29651 .5754 m .29856 .57306 L .29683 .57339 L F
.865 .634 .586 r
.55144 .56031 m .5536 .55837 L .55152 .55762 L F
.55144 .56031 m .55341 .56112 L .5536 .55837 L F
.952 .666 .46 r
.5474 .53675 m .5459 .53851 L .54561 .53571 L F
.881 .534 .388 r
.54802 .53914 m .5459 .53851 L .5474 .53675 L F
.994 .796 .53 r
.28577 .54726 m .28702 .54858 L .28758 .54585 L F
.717 .946 .646 r
.28815 .54448 m .28758 .54585 L .28982 .54704 L F
.28815 .54448 m .28577 .54726 L .28758 .54585 L F
.878 .816 .784 r
.54999 .55401 m .55392 .55185 L .55231 .5505 L F
.54999 .55401 m .5517 .55498 L .55392 .55185 L F
.779 .673 .746 r
.21464 .74192 m .21638 .74554 L .21864 .74216 L F
.041 .576 .855 r
.20495 .63466 m .20642 .63477 L .20288 .63388 L F
.336 .013 .261 r
.27373 .62873 m .27512 .63001 L .27599 .6282 L F
.27373 .62873 m .27296 .63055 L .27512 .63001 L F
.477 .279 .533 r
.27373 .62873 m .27599 .6282 L .27619 .62556 L F
.282 0 .053 r
.32446 .55266 m .32585 .5532 L .32634 .55134 L F
.32446 .55266 m .32358 .55382 L .32585 .5532 L F
.541 .414 .657 r
.35314 .5701 m .35362 .57285 L .35105 .57332 L F
.359 .212 .541 r
.35362 .57285 m .35121 .57632 L .35105 .57332 L F
.524 .687 .942 r
.17447 .61301 m .17393 .60978 L .17247 .60952 L F
.17447 .61301 m .17675 .61256 L .17393 .60978 L F
.228 .393 .82 r
.17447 .61301 m .17759 .61625 L .17675 .61256 L F
.833 .668 .679 r
.55438 .56972 m .55412 .57255 L .55775 .57263 L F
.832 .641 .646 r
.55412 .57255 m .55573 .57602 L .55775 .57263 L F
.577 .936 .787 r
.2731 .64967 m .27769 .64714 L .27652 .64887 L F
.152 0 0 r
.27769 .64714 m .27831 .64748 L .27652 .64887 L F
.27769 .64714 m .28021 .64733 L .27831 .64748 L F
.546 .335 .545 r
.32489 .62145 m .32277 .61948 L .325 .61899 L F
.32489 .62145 m .32258 .62195 L .32277 .61948 L F
.649 .944 .958 r
.28878 .55236 m .28935 .5509 L .29123 .55096 L F
.28878 .55236 m .28935 .5509 L .29123 .55096 L F
.922 .901 .788 r
.54441 .56487 m .54131 .56673 L .54261 .56328 L F
.54441 .56487 m .54261 .56778 L .54131 .56673 L F
.913 .737 .65 r
.54395 .56218 m .54441 .56487 L .54261 .56328 L F
.671 .637 .807 r
.31478 .58271 m .31841 .58255 L .31731 .58001 L F
.658 .439 .575 r
.31452 .58509 m .31841 .58255 L .31478 .58271 L F
.157 .692 .696 r
.27486 .53411 m .27713 .53361 L .27855 .5333 L F
.197 .721 .718 r
.27855 .5333 m .27868 .53317 L .28095 .53322 L F
.27855 .5333 m .27713 .53361 L .27868 .53317 L F
.211 .717 .9 r
.22606 .6228 m .22455 .62326 L .22281 .62172 L F
.22606 .6228 m .22669 .62313 L .22455 .62326 L F
.759 .513 .561 r
.35121 .57632 m .35144 .57959 L .3482 .57891 L F
.359 .212 .541 r
.35362 .57285 m .35376 .57531 L .35121 .57632 L F
.439 .305 .601 r
.35376 .57531 m .35144 .57959 L .35121 .57632 L F
.534 .542 .809 r
.77288 .40405 m .77171 .40827 L .77075 .40423 L F
.77288 .40405 m .77507 .40825 L .77171 .40827 L F
.735 .681 .798 r
.81246 .4326 m .81392 .4281 L .81133 .42899 L F
.81246 .4326 m .8147 .4316 L .81392 .4281 L F
.182 0 .062 r
.17779 .55745 m .1796 .55767 L .18095 .55512 L F
.191 0 .067 r
.18095 .55512 m .18151 .55688 L .18282 .55403 L F
.18095 .55512 m .1796 .55767 L .18151 .55688 L F
0 0 0 r
.81186 .40399 m .81466 .40095 L .81194 .40154 L F
.747 .561 .644 r
.79712 .41026 m .80091 .41062 L .80084 .408 L F
.709 .531 .646 r
.80084 .408 m .80091 .41062 L .80423 .41009 L F
.943 .644 .442 r
.25632 .55217 m .25293 .55146 L .25419 .55313 L F
.311 .211 .577 r
.26408 .55495 m .26556 .55445 L .26545 .55168 L F
.317 .167 .514 r
.30513 .59844 m .30576 .59941 L .30777 .59777 L F
.30576 .59941 m .30739 .59922 L .30777 .59777 L F
.389 .219 .527 r
.30762 .59486 m .30777 .59777 L .30984 .59658 L F
.782 .685 .756 r
.30741 .59913 m .3096 .59683 L .30777 .59777 L F
.30739 .59922 m .30748 .59912 L .30741 .59913 L F
.30748 .59912 m .3096 .59683 L .30741 .59913 L F
.30867 .59951 m .31046 .59983 L .31014 .59818 L F
.771 .663 .744 r
.30867 .59951 m .30833 .59911 L .30836 .59911 L F
.30867 .59951 m .30688 .60114 L .30823 .599 L F
.782 .685 .756 r
.30827 .59899 m .31014 .59818 L .30984 .59658 L F
.771 .663 .744 r
.30833 .59911 m .30823 .599 L .30829 .59901 L F
.30833 .59911 m .30829 .59901 L .30836 .59911 L F
.782 .685 .756 r
.30688 .60114 m .30867 .59951 L .30827 .59899 L F
.30867 .59951 m .31014 .59818 L .30827 .59899 L F
.771 .663 .744 r
.30836 .59911 m .30829 .59901 L .30873 .59907 L F
.30906 .59996 m .30867 .59951 L .30873 .59907 L F
.30867 .59951 m .30836 .59911 L .30873 .59907 L F
.782 .685 .756 r
.30688 .60114 m .30926 .60027 L .30867 .59951 L F
.30926 .60027 m .31046 .59983 L .30867 .59951 L F
.771 .663 .744 r
.30906 .59996 m .30688 .60114 L .30867 .59951 L F
.645 .594 .783 r
.30984 .59658 m .31046 .59983 L .31301 .59743 L F
.424 .554 .882 r
.31119 .59842 m .30906 .59996 L .30866 .59889 L F
.782 .685 .756 r
.3096 .59683 m .30972 .59664 L .30777 .59777 L F
.30827 .59899 m .30984 .59658 L .30739 .59922 L F
.424 .554 .882 r
.31115 .5984 m .30866 .59889 L .30735 .59537 L F
.31119 .59842 m .30866 .59889 L .31115 .5984 L F
.782 .685 .756 r
.30688 .60114 m .30827 .59899 L .30739 .59922 L F
.317 .167 .514 r
.30576 .59941 m .30688 .60114 L .30739 .59922 L F
.771 .663 .744 r
.30823 .599 m .30688 .60114 L .30551 .59588 L F
.782 .685 .756 r
.3096 .59683 m .30984 .59658 L .30972 .59664 L F
.771 .663 .744 r
.30823 .599 m .30551 .59588 L .30857 .59891 L F
.30823 .599 m .30857 .59891 L .30873 .59907 L F
.30873 .59907 m .30551 .59588 L .30735 .59537 L F
.317 .167 .514 r
.30513 .59844 m .30488 .60158 L .30688 .60114 L F
.09 0 .291 r
.28386 .61653 m .28492 .61788 L .28607 .61598 L F
.28386 .61653 m .28339 .61885 L .28492 .61788 L F
.415 .397 .731 r
.33977 .56918 m .33852 .57287 L .33734 .56981 L F
.33977 .56918 m .34076 .57343 L .33852 .57287 L F
.568 .547 .791 r
.35144 .57959 m .34966 .58142 L .3482 .57891 L F
.35144 .57959 m .35245 .58111 L .34966 .58142 L F
.565 .611 .857 r
.35245 .58111 m .35216 .58238 L .34966 .58142 L F
.709 .412 .472 r
.35216 .58238 m .35029 .58507 L .34966 .58142 L F
.457 .416 .724 r
.3422 .58714 m .34399 .58804 L .34136 .58847 L F
.376 .404 .763 r
.3436 .58879 m .34136 .58847 L .34399 .58804 L F
.3436 .58879 m .34287 .59132 L .34136 .58847 L F
.442 .081 .256 r
.46311 .64944 m .46606 .64886 L .46641 .647 L F
.639 .255 .302 r
.46641 .647 m .46845 .6491 L .46606 .64886 L F
.835 .827 .84 r
.78685 .404 m .78349 .40446 L .78609 .40278 L F
.424 .76 .996 r
.78861 .40272 m .78685 .404 L .78609 .40278 L F
.192 .557 .933 r
.32274 .54657 m .3227 .54524 L .32125 .5457 L F
.32274 .54657 m .32545 .54735 L .3227 .54524 L F
.464 .46 .768 r
.29651 .5754 m .29807 .57958 L .29842 .57935 L F
.29651 .5754 m .29842 .57935 L .29876 .57746 L F
.604 .584 .804 r
.29856 .57306 m .29962 .57541 L .29651 .5754 L F
.538 .53 .794 r
.29856 .57306 m .2992 .57544 L .29954 .57537 L F
0 0 0 r
.29955 .57545 m .2992 .57544 L .29962 .57541 L F
.2992 .57544 m .29859 .57541 L .29962 .57541 L F
.96 .935 .713 r
.29928 .57457 m .29907 .57569 L .29953 .57546 L F
.29956 .57527 m .29953 .57546 L .29962 .57541 L F
0 0 .343 r
.29956 .57527 m .29962 .57541 L .29856 .57306 L F
.538 .53 .794 r
.29856 .57306 m .29954 .57537 L .29956 .57527 L F
.29856 .57306 m .29956 .57527 L .29984 .57375 L F
0 0 .343 r
.29874 .57326 m .29956 .57527 L .29856 .57306 L F
.96 .935 .713 r
.29928 .57457 m .29953 .57546 L .29956 .57527 L F
.538 .53 .794 r
.29984 .57375 m .29954 .57537 L .30186 .57483 L F
.2992 .57544 m .2994 .57619 L .30061 .57552 L F
.2992 .57544 m .30061 .57552 L .30186 .57483 L F
0 0 0 r
.2992 .57544 m .29651 .5754 L .29859 .57541 L F
.591 .564 .793 r
.29651 .5754 m .2994 .57619 L .2992 .57544 L F
.464 .46 .768 r
.29651 .5754 m .2998 .57842 L .2994 .57619 L F
0 0 0 r
.29662 .57695 m .29651 .5754 L .29955 .57545 L F
.591 .564 .793 r
.29651 .5754 m .2992 .57544 L .29856 .57306 L F
.96 .935 .713 r
.29874 .57326 m .29662 .57695 L .29907 .57569 L F
.29874 .57326 m .29907 .57569 L .29928 .57457 L F
.464 .46 .768 r
.29876 .57746 m .29842 .57935 L .2998 .57842 L F
.297 .032 .332 r
.29725 .58121 m .2998 .57842 L .29807 .57958 L F
.599 .825 .986 r
.18932 .60801 m .18482 .60726 L .18713 .60672 L F
.538 .817 .997 r
.19167 .60753 m .18932 .60801 L .18713 .60672 L F
.929 .838 .733 r
.23154 .7245 m .22863 .72636 L .23173 .72301 L F
.23154 .7245 m .23023 .72716 L .22863 .72636 L F
.549 .603 .86 r
.34245 .54148 m .34395 .54456 L .34159 .54497 L F
0 .553 .756 r
.34395 .54456 m .3403 .54411 L .34159 .54497 L F
.609 .493 .695 r
.34159 .54497 m .34256 .5493 L .3449 .54837 L F
.714 .667 .803 r
.81392 .4281 m .8147 .4316 L .81747 .42872 L F
0 0 .29 r
.28591 .5703 m .28662 .56941 L .28613 .56691 L F
.554 .72 .951 r
.28659 .57308 m .28662 .56941 L .28591 .5703 L F
.573 .247 .379 r
.31789 .58498 m .32041 .58303 L .31841 .58255 L F
.31789 .58498 m .32045 .58486 L .32041 .58303 L F
.185 .385 .827 r
.76866 .40977 m .76935 .41203 L .77179 .41343 L F
.169 0 0 r
.24547 .53501 m .24779 .53505 L .24991 .53455 L F
.031 0 0 r
.24779 .53505 m .25211 .53388 L .24991 .53455 L F
.783 .6 .653 r
.47532 .62234 m .47717 .62532 L .47787 .62282 L F
.569 .42 .64 r
.28574 .61056 m .28817 .60995 L .28724 .60809 L F
.589 .488 .708 r
.28574 .61056 m .28621 .61322 L .28817 .60995 L F
.079 0 .418 r
.27106 .65353 m .26963 .65397 L .26955 .65647 L F
.734 .64 .755 r
.3494 .55198 m .3449 .54837 L .34702 .54728 L F
.3494 .55198 m .34687 .55235 L .3449 .54837 L F
.731 .61 .723 r
.3494 .55198 m .34697 .55508 L .34687 .55235 L F
.42 .197 .466 r
.34922 .55436 m .34697 .55508 L .3494 .55198 L F
.494 .438 .723 r
.35128 .5488 m .3494 .55198 L .34702 .54728 L F
.35128 .5488 m .35275 .55164 L .3494 .55198 L F
.631 .395 .542 r
.33735 .60326 m .33468 .60105 L .33697 .60041 L F
.33735 .60326 m .33454 .60354 L .33468 .60105 L F
.245 .757 .854 r
.31116 .53749 m .30886 .53769 L .31096 .53747 L F
0 0 0 r
.31179 .53781 m .31116 .53749 L .31096 .53747 L F
.31179 .53781 m .31358 .53694 L .31116 .53749 L F
.382 .498 .852 r
.17956 .82704 m .1802 .82431 L .17772 .82658 L F
.17956 .82704 m .18169 .8275 L .1802 .82431 L F
.736 .747 .86 r
.33753 .54095 m .33407 .54072 L .33606 .53964 L F
.318 .515 .891 r
.33843 .53916 m .33753 .54095 L .33606 .53964 L F
.572 .534 .774 r
.47385 .62254 m .47717 .62532 L .47532 .62234 L F
.108 0 .34 r
.27619 .62556 m .27737 .62504 L .27803 .62215 L F
.27 .111 .472 r
.27619 .62556 m .27763 .62729 L .27737 .62504 L F
.27619 .62556 m .27599 .6282 L .27763 .62729 L F
.712 .603 .733 r
.34697 .55508 m .34306 .55209 L .34687 .55235 L F
.34697 .55508 m .34418 .55527 L .34306 .55209 L F
.708 .559 .683 r
.34697 .55508 m .34417 .55752 L .34418 .55527 L F
.147 .279 .743 r
.34913 .55672 m .34697 .55508 L .34922 .55436 L F
.247 .76 .771 r
.21567 .5388 m .21254 .53949 L .21421 .53903 L F
.418 .849 .945 r
.21421 .53903 m .21798 .53868 L .21567 .5388 L F
.21421 .53903 m .21633 .53842 L .21798 .53868 L F
0 0 0 r
.21421 .53903 m .21424 .53931 L .21619 .53848 L F
.21421 .53903 m .21619 .53848 L .21633 .53842 L F
.247 .76 .771 r
.21254 .53949 m .21193 .53962 L .21421 .53903 L F
.87 .745 .722 r
.55549 .57853 m .55696 .57959 L .55573 .57602 L F
.807 .632 .665 r
.55307 .58157 m .55696 .57959 L .55549 .57853 L F
.55307 .58157 m .55683 .58213 L .55696 .57959 L F
.599 .731 .937 r
.18273 .59527 m .18019 .59641 L .17831 .59421 L F
.964 .894 .707 r
.54145 .56998 m .54131 .56673 L .54261 .56778 L F
.634 .737 .922 r
.33119 .54238 m .32785 .54101 L .32968 .54064 L F
.733 .828 .924 r
.33407 .54072 m .33119 .54238 L .32968 .54064 L F
.336 .207 .553 r
.46103 .65321 m .46334 .65266 L .46311 .64944 L F
.594 .035 0 r
.46103 .65321 m .46357 .65536 L .4618 .65441 L F
.375 .348 .701 r
.46334 .65266 m .46357 .65536 L .46103 .65321 L F
.594 .035 0 r
.46103 .65321 m .4618 .65441 L .46334 .65266 L F
.64 .802 .961 r
.24082 .62521 m .23698 .62474 L .23913 .62428 L F
.452 .799 .998 r
.23913 .62428 m .24314 .6248 L .24082 .62521 L F
.558 .202 .32 r
.33738 .5457 m .33544 .54522 L .33757 .54576 L F
.411 .253 .555 r
.47455 .63102 m .47255 .63446 L .47258 .6316 L F
.47455 .63102 m .47255 .63446 L .47258 .6316 L F
.248 0 0 r
.29353 .55099 m .29646 .5507 L .29482 .55013 L F
.578 .337 .514 r
.28049 .62149 m .28339 .61885 L .28121 .61952 L F
.321 0 .183 r
.17435 .56077 m .17653 .56023 L .17779 .55745 L F
.292 0 .169 r
.17779 .55745 m .17872 .55954 L .1796 .55767 L F
.17779 .55745 m .17653 .56023 L .17872 .55954 L F
.985 .816 .593 r
.54671 .54598 m .54624 .54849 L .54539 .54492 L F
0 0 0 r
.28095 .53322 m .28325 .53294 L .2848 .53262 L F
.28325 .53294 m .28721 .53209 L .2848 .53262 L F
.455 .345 .639 r
.24774 .68422 m .24982 .6868 L .24961 .6834 L F
.24774 .68422 m .24769 .68701 L .24982 .6868 L F
.98 .785 .57 r
.34418 .55527 m .34265 .55681 L .34417 .55752 L F
0 0 .496 r
.54178 .58068 m .54296 .58149 L .54238 .57855 L F
.894 .733 .675 r
.55256 .56627 m .55435 .56724 L .55301 .5638 L F
.824 .627 .637 r
.55256 .56627 m .55438 .56972 L .55435 .56724 L F
.766 .619 .695 r
.78103 .40952 m .77911 .4111 L .77999 .40955 L F
.78103 .40952 m .77963 .41429 L .77911 .4111 L F
.78103 .40952 m .78118 .41236 L .77963 .41429 L F
.168 0 0 r
.24113 .64117 m .24339 .64095 L .24141 .64203 L F
.503 .383 .649 r
.28817 .60995 m .28621 .61322 L .28844 .61276 L F
.369 .19 .502 r
.28621 .61322 m .28799 .61514 L .28844 .61276 L F
.28621 .61322 m .28607 .61598 L .28799 .61514 L F
.225 0 0 r
.21329 .75916 m .2133 .7581 L .21242 .76096 L F
.526 .809 .998 r
.16764 .60585 m .16653 .6069 L .16883 .60631 L F
.34 0 .178 r
.236 .54879 m .23237 .55148 L .23381 .54921 L F
.286 0 .097 r
.188 .57198 m .18731 .57029 L .18941 .56958 L F
.188 .57198 m .18584 .57256 L .18731 .57029 L F
.439 .771 .997 r
.26764 .55718 m .26642 .55596 L .26556 .55445 L F
.26764 .55718 m .26966 .55677 L .26642 .55596 L F
.007 0 .181 r
.34348 .56711 m .3444 .56702 L .34547 .56405 L F
.052 .137 .635 r
.34348 .56711 m .34522 .56918 L .3444 .56702 L F
.648 .252 .281 r
.3289 .56039 m .32748 .56272 L .32531 .56073 L F
.575 .53 .768 r
.33099 .55746 m .33156 .56064 L .3289 .56039 L F
0 0 0 r
.33156 .56064 m .32748 .56272 L .3289 .56039 L F
.496 .804 1 r
.28949 .53253 m .29337 .53307 L .29113 .53362 L F
.012 .07 .576 r
.33717 .55924 m .33481 .55591 L .33899 .55567 L F
.757 .678 .774 r
.33899 .55567 m .33717 .55924 L .33481 .55591 L F
.638 .856 .982 r
.33899 .55567 m .33481 .55591 L .33765 .55462 L F
.652 .096 0 r
.33857 .55599 m .33899 .55567 L .33765 .55462 L F
.782 .841 .381 r
.33938 .55537 m .33831 .55826 L .33899 .55567 L F
.845 .943 .58 r
.33831 .55826 m .33717 .55924 L .33899 .55567 L F
.652 .096 0 r
.3394 .55722 m .33899 .55567 L .33857 .55599 L F
.782 .841 .381 r
.33966 .55463 m .33938 .55537 L .33899 .55567 L F
.479 0 0 r
.33306 .56701 m .33466 .56804 L .33674 .56731 L F
.795 .998 .801 r
.33674 .56731 m .33728 .5655 L .33905 .56704 L F
.33674 .56731 m .33466 .56804 L .33728 .5655 L F
.494 .415 .695 r
.33905 .56704 m .33734 .56981 L .33674 .56731 L F
.389 .708 .986 r
.23754 .72111 m .23634 .72257 L .23549 .72086 L F
.23754 .72111 m .23891 .72235 L .23634 .72257 L F
.291 .219 .601 r
.23838 .72602 m .23634 .72257 L .23891 .72235 L F
.927 .942 .593 r
.22337 .55328 m .22333 .55553 L .22483 .55192 L F
.213 0 0 r
.2269 .55093 m .22337 .55328 L .22483 .55192 L F
0 0 .055 r
.27759 .60894 m .27638 .61029 L .27801 .60679 L F
.13 0 .326 r
.27732 .61181 m .27638 .61029 L .27759 .60894 L F
.27732 .61181 m .27574 .61275 L .27638 .61029 L F
.36 0 0 r
.21539 .5572 m .2138 .55854 L .21184 .55798 L F
.554 .05 .012 r
.21959 .55768 m .21834 .55832 L .21539 .5572 L F
0 0 .501 r
.2568 .68363 m .25339 .67947 L .25446 .68349 L F
.835 .468 .359 r
.2548 .68549 m .2568 .68363 L .25446 .68349 L F
.606 .692 .904 r
.18171 .61853 m .18214 .61519 L .17986 .61604 L F
.18171 .61853 m .18411 .61802 L .18214 .61519 L F
.621 .818 .976 r
.47113 .66138 m .47284 .66277 L .47499 .6618 L F
.47113 .66138 m .47284 .66277 L .47499 .6618 L F
.369 .165 .467 r
.30518 .58792 m .3031 .58869 L .30533 .58536 L F
.359 .158 .466 r
.30518 .58792 m .30283 .59122 L .3031 .58869 L F
.545 .433 .677 r
.32994 .61241 m .32809 .61616 L .32771 .613 L F
.554 .331 .532 r
.42774 .63492 m .4308 .63695 L .42801 .63738 L F
.42801 .63738 m .4308 .63695 L .42774 .63492 L F
.46 .24 .492 r
.32035 .62527 m .32015 .62775 L .31794 .62827 L F
.511 .378 .637 r
.32258 .62195 m .32035 .62527 L .31992 .62234 L F
.32258 .62195 m .32269 .62488 L .32035 .62527 L F
.559 .364 .574 r
.32269 .62488 m .32015 .62775 L .32035 .62527 L F
.28 .303 .707 r
.3436 .58879 m .34452 .59176 L .34287 .59132 L F
.639 .476 .646 r
.34549 .59369 m .34287 .59132 L .34452 .59176 L F
.34549 .59369 m .3425 .59535 L .34287 .59132 L F
0 0 .004 r
.2679 .62723 m .26714 .63037 L .26677 .62878 L F
.399 .255 .568 r
.15168 .58236 m .15362 .5817 L .15356 .57907 L F
.393 .26 .579 r
.15168 .58236 m .1537 .58444 L .15362 .5817 L F
.15168 .58236 m .15145 .58569 L .1537 .58444 L F
.466 .373 .666 r
.28724 .60809 m .29011 .60917 L .29026 .60733 L F
.28724 .60809 m .28817 .60995 L .29011 .60917 L F
.544 .208 .349 r
.34852 .59178 m .34822 .59363 L .34549 .59369 L F
.871 .864 .83 r
.35094 .5886 m .34852 .59178 L .34684 .59059 L F
.64 .293 .369 r
.34852 .59178 m .35073 .59391 L .34822 .59363 L F
.505 .318 .56 r
.35091 .5912 m .34852 .59178 L .35094 .5886 L F
.502 .31 .552 r
.35091 .5912 m .35073 .59391 L .34852 .59178 L F
.864 .752 .737 r
.55307 .58157 m .55092 .58514 L .55426 .58533 L F
.805 .858 .889 r
.55092 .58514 m .5523 .58632 L .55426 .58533 L F
.786 .714 .784 r
.55307 .58157 m .55426 .58533 L .55683 .58213 L F
.714 .632 .765 r
.3449 .54837 m .34687 .55235 L .34306 .55209 L F
.43 0 0 r
.16268 .60391 m .16092 .6038 L .15881 .60304 L F
.062 .503 .894 r
.16268 .60391 m .16302 .60304 L .16092 .6038 L F
.16268 .60391 m .16764 .60585 L .16302 .60304 L F
.913 .737 .65 r
.54395 .56218 m .54261 .56328 L .54275 .5608 L F
.93 .719 .596 r
.54999 .55401 m .55152 .55762 L .5517 .55498 L F
.583 .863 .995 r
.18414 .8244 m .18259 .82528 L .1802 .82431 L F
.156 0 .241 r
.18169 .8275 m .18259 .82528 L .18414 .8244 L F
.977 .848 .452 r
.76805 .40514 m .76775 .40805 L .76718 .40617 L F
0 0 .424 r
.76718 .40617 m .76775 .40805 L .76866 .40977 L F
.228 .568 .939 r
.78386 .42363 m .78666 .42329 L .78331 .42232 L F
.78386 .42363 m .78764 .42475 L .78666 .42329 L F
.844 .421 .227 r
.34596 .57973 m .34425 .58121 L .34411 .57938 L F
.855 .464 .303 r
.55355 .52428 m .55378 .5261 L .55727 .52723 L F
.918 .611 .448 r
.55378 .5261 m .55659 .52936 L .55727 .52723 L F
.977 .848 .452 r
.76805 .40514 m .76718 .40617 L .76692 .4037 L F
.69 .794 .929 r
.76692 .4037 m .77075 .40423 L .76805 .40514 L F
.213 .735 .742 r
.82494 .40468 m .82761 .40403 L .82861 .40389 L F
.647 .136 0 r
.82955 .40543 m .82861 .40389 L .82761 .40403 L F
.82955 .40543 m .83124 .40692 L .82861 .40389 L F
.682 .374 .445 r
.82861 .40389 m .83228 .40468 L .83062 .40432 L F
.82861 .40389 m .83124 .40692 L .83228 .40468 L F
.555 .39 .613 r
.31794 .62827 m .31836 .63144 L .31592 .63184 L F
.591 .442 .647 r
.31836 .63144 m .316 .63436 L .31592 .63184 L F
0 0 0 r
.27101 .60678 m .26925 .61014 L .27105 .6092 L F
0 0 .317 r
.26925 .61014 m .27035 .61157 L .27105 .6092 L F
.26925 .61014 m .26911 .61255 L .27035 .61157 L F
.554 .413 .644 r
.32015 .62775 m .31836 .63144 L .31794 .62827 L F
.734 .451 .5 r
.83228 .40468 m .83467 .40465 L .83062 .40432 L F
.83228 .40468 m .83496 .40691 L .83467 .40465 L F
.757 .47 .498 r
.83883 .40748 m .83467 .40465 L .83496 .40691 L F
.528 .338 .567 r
.51838 .52368 m .52079 .52069 L .5184 .52076 L F
.738 .817 .913 r
.82357 .41559 m .82775 .41634 L .82487 .41519 L F
.55 .62 .875 r
.82775 .41634 m .8292 .41208 L .82487 .41519 L F
.82775 .41634 m .82978 .41561 L .8292 .41208 L F
.609 .151 .14 r
.24735 .64076 m .24541 .64246 L .24339 .64095 L F
0 0 0 r
.24747 .64098 m .24735 .64076 L .24941 .64099 L F
.24747 .64098 m .24541 .64246 L .24735 .64076 L F
.581 .563 .799 r
.22337 .55328 m .22195 .55722 L .22333 .55553 L F
.419 .662 .961 r
.78829 .4266 m .78999 .42495 L .78764 .42475 L F
.78829 .4266 m .79272 .4273 L .78999 .42495 L F
.658 .439 .575 r
.31452 .58509 m .31789 .58498 L .31841 .58255 L F
.709 .412 .472 r
.35216 .58238 m .35261 .58546 L .35029 .58507 L F
.356 .398 .768 r
.35245 .58111 m .35418 .58135 L .35216 .58238 L F
.339 .16 .486 r
.35465 .58347 m .35216 .58238 L .35418 .58135 L F
.35465 .58347 m .35261 .58546 L .35216 .58238 L F
.639 .223 .238 r
.31781 .55459 m .31993 .55632 L .32109 .55461 L F
.307 0 .082 r
.31993 .55632 m .32358 .55382 L .32109 .55461 L F
0 0 .207 r
.27101 .60678 m .2724 .60556 L .27284 .60305 L F
.096 0 .284 r
.27101 .60678 m .27249 .60822 L .2724 .60556 L F
.27101 .60678 m .27105 .6092 L .27249 .60822 L F
0 0 .021 r
.28194 .60011 m .28239 .59779 L .28322 .59668 L F
0 0 0 r
.29662 .57695 m .29559 .5778 L .29651 .5754 L F
.488 .195 .394 r
.80119 .4133 m .80423 .41009 L .80091 .41062 L F
.80119 .4133 m .8041 .4128 L .80423 .41009 L F
.248 .012 .347 r
.80423 .41009 m .8062 .4115 L .807 .40942 L F
.80423 .41009 m .8041 .4128 L .8062 .4115 L F
.771 .774 .855 r
.81272 .4202 m .81583 .42052 L .81509 .41888 L F
.5 .723 .972 r
.81583 .42052 m .81756 .41884 L .81509 .41888 L F
.81583 .42052 m .8186 .42047 L .81756 .41884 L F
.68 .649 .812 r
.81583 .42052 m .81984 .42102 L .8186 .42047 L F
.05 0 0 r
.22195 .55722 m .21834 .55832 L .21959 .55768 L F
.212 0 0 r
.31364 .58001 m .31099 .58052 L .31308 .5801 L F
.31364 .58001 m .31102 .58149 L .31099 .58052 L F
0 0 0 r
.19207 .54881 m .18789 .55096 L .19012 .55044 L F
.083 0 0 r
.19425 .54818 m .19207 .54881 L .19012 .55044 L F
.185 0 0 r
.21992 .53751 m .22244 .53746 L .22453 .53678 L F
.189 .718 .729 r
.22244 .53746 m .22665 .5366 L .22453 .53678 L F
.591 .357 .53 r
.31 .63462 m .30983 .63723 L .30701 .63752 L F
.676 .452 .573 r
.3125 .63448 m .30983 .63723 L .31 .63462 L F
.469 .305 .576 r
.30762 .59486 m .30981 .59445 L .30987 .59138 L F
.389 .219 .527 r
.30762 .59486 m .30984 .59658 L .30981 .59445 L F
.985 .705 .375 r
.34408 .56046 m .34547 .56405 L .34406 .56282 L F
0 0 .024 r
.34547 .56405 m .3444 .56702 L .34603 .56509 L F
.34547 .56405 m .34603 .56509 L .34406 .56282 L F
.672 .864 .472 r
.54381 .55547 m .54171 .55847 L .54423 .55466 L F
.937 .792 .675 r
.54381 .55547 m .54275 .5608 L .54171 .55847 L F
.512 .688 .947 r
.21032 .6356 m .21465 .63699 L .2128 .63675 L F
.499 .692 .954 r
.21465 .63699 m .21496 .63487 L .2128 .63675 L F
.582 .665 .895 r
.21894 .63671 m .2162 .63545 L .21704 .63683 L F
.2162 .63545 m .21496 .63487 L .21546 .63535 L F
.2162 .63545 m .21546 .63535 L .21704 .63683 L F
.496 .607 .893 r
.21884 .63435 m .21795 .63568 L .21911 .63457 L F
.499 .692 .954 r
.21465 .63699 m .21704 .63683 L .21546 .63535 L F
.582 .665 .895 r
.21894 .63671 m .2168 .6374 L .21496 .63487 L F
.496 .607 .893 r
.21795 .63568 m .2168 .6374 L .21818 .63572 L F
.21795 .63568 m .21818 .63572 L .21911 .63457 L F
.21597 .63213 m .21643 .63506 L .21884 .63435 L F
.21643 .63506 m .2168 .6374 L .21884 .63435 L F
.499 .692 .954 r
.21486 .63552 m .21546 .63535 L .21496 .63487 L F
.21465 .63699 m .21546 .63535 L .21486 .63552 L F
.616 .782 .961 r
.81984 .42102 m .82169 .41924 L .8186 .42047 L F
.81984 .42102 m .82264 .42055 L .82169 .41924 L F
.247 0 .259 r
.26053 .55028 m .25855 .55124 L .25908 .54924 L F
0 0 0 r
.24714 .55396 m .24609 .55439 L .24342 .55493 L F
.6 .241 .331 r
.24374 .55218 m .24609 .55439 L .24736 .55206 L F
.309 .41 .803 r
.35351 .56216 m .35232 .5639 L .35063 .56006 L F
.215 .282 .717 r
.35351 .56216 m .35439 .56612 L .35232 .5639 L F
.871 .864 .83 r
.35094 .5886 m .34684 .59059 L .34937 .58768 L F
.736 .923 .954 r
.35094 .5886 m .34937 .58768 L .35074 .58733 L F
.062 .126 .618 r
.35074 .58733 m .35091 .5912 L .35094 .5886 L F
.011 0 0 r
.25419 .53332 m .25816 .53333 L .25593 .53396 L F
.672 .791 .938 r
.20642 .63477 m .21032 .6356 L .20948 .63446 L F
.267 .368 .781 r
.21032 .6356 m .21145 .63311 L .20948 .63446 L F
.21032 .6356 m .2128 .63675 L .21145 .63311 L F
.326 .335 .717 r
.33438 .60625 m .33283 .60705 L .33206 .60422 L F
.571 .337 .523 r
.33512 .60902 m .33283 .60705 L .33438 .60625 L F
.33512 .60902 m .33231 .60953 L .33283 .60705 L F
.714 .632 .765 r
.3449 .54837 m .34306 .55209 L .34256 .5493 L F
.451 .399 .709 r
.34256 .5493 m .3446 .55072 L .3449 .54837 L F
.34256 .5493 m .34306 .55209 L .3446 .55072 L F
.606 .345 .495 r
.30389 .6405 m .30108 .64292 L .30161 .64106 L F
.494 .415 .695 r
.33905 .56704 m .33977 .56918 L .33734 .56981 L F
0 0 0 r
.20706 .55986 m .20443 .56149 L .20233 .56246 L F
.109 0 0 r
.20652 .56095 m .20706 .55986 L .20913 .55932 L F
.20652 .56095 m .20443 .56149 L .20706 .55986 L F
.36 .706 .985 r
.34193 .55185 m .34259 .55232 L .34138 .55329 L F
.449 .829 .592 r
.34025 .55419 m .34138 .55329 L .34306 .55209 L F
.067 0 0 r
.34138 .55329 m .3446 .55072 L .34306 .55209 L F
.34138 .55329 m .3433 .55282 L .3446 .55072 L F
.36 .706 .985 r
.34259 .55232 m .3433 .55282 L .34138 .55329 L F
.449 .829 .592 r
.33966 .55463 m .34138 .55329 L .34025 .55419 L F
.326 .335 .717 r
.33438 .60625 m .33206 .60422 L .33454 .60354 L F
.55 .052 .024 r
.52732 .52251 m .53105 .52173 L .52798 .5231 L F
.52732 .52251 m .52975 .52308 L .53105 .52173 L F
.121 0 0 r
.53105 .52173 m .53223 .52245 L .53359 .52131 L F
.53105 .52173 m .52975 .52308 L .53223 .52245 L F
.63 .506 .692 r
.31962 .57632 m .32232 .57616 L .3217 .5731 L F
.718 .607 .732 r
.176 .5825 m .17284 .58553 L .17383 .58309 L F
.775 .837 .9 r
.29021 .59133 m .29319 .59047 L .29257 .58994 L F
.286 .582 .942 r
.29319 .59047 m .29593 .59081 L .29257 .58994 L F
.499 .241 .454 r
.29482 .59146 m .29593 .59081 L .29319 .59047 L F
.602 .084 0 r
.21058 .61824 m .20803 .61583 L .20888 .61887 L F
.359 0 0 r
.20888 .61887 m .21282 .61849 L .21058 .61824 L F
.58 .874 .567 r
.23273 .73153 m .23471 .72973 L .23599 .72831 L F
.416 .811 .986 r
.23023 .72716 m .22717 .72682 L .22863 .72636 L F
.717 .738 .868 r
.31786 .56977 m .32128 .56844 L .32143 .56862 L F
0 0 .443 r
.31909 .57106 m .31786 .56977 L .32143 .56862 L F
.764 .492 .522 r
.79712 .41026 m .80119 .4133 L .80091 .41062 L F
.944 .725 .575 r
.54182 .57259 m .54026 .56899 L .54145 .56998 L F
.964 .894 .707 r
.54145 .56998 m .54026 .56899 L .54131 .56673 L F
.113 .576 .916 r
.24886 .62615 m .24704 .62608 L .2452 .62489 L F
.95 .827 .688 r
.55559 .54095 m .55784 .53962 L .55676 .5387 L F
.55559 .54095 m .55716 .54222 L .55784 .53962 L F
.988 .864 .624 r
.55785 .53455 m .55676 .5387 L .55784 .53962 L F
.766 .625 .704 r
.26881 .66565 m .26936 .66857 L .26508 .66787 L F
.689 .239 .178 r
.26508 .66787 m .26936 .66857 L .26632 .6695 L F
.485 .435 .726 r
.27134 .66781 m .26936 .66857 L .26881 .66565 L F
.3 .787 .731 r
.26632 .6695 m .26936 .66857 L .27134 .66781 L F
.426 .739 .992 r
.30819 .53574 m .30886 .53769 L .30585 .53631 L F
.30819 .53574 m .31096 .53747 L .30886 .53769 L F
.717 .781 .903 r
.54696 .5873 m .5523 .58632 L .55092 .58514 L F
.148 .655 .903 r
.26034 .53306 m .26428 .53381 L .26209 .53395 L F
0 .115 .658 r
.26989 .64913 m .26867 .64826 L .26768 .6469 L F
.662 .9 .98 r
.82401 .40379 m .8218 .40622 L .82089 .40415 L F
.82401 .40379 m .82494 .40468 L .8218 .40622 L F
.056 .621 .772 r
.22774 .53663 m .22837 .53652 L .2308 .53671 L F
0 0 0 r
.22709 .53685 m .22874 .53646 L .22837 .53652 L F
.368 .826 .924 r
.22837 .53652 m .2307 .536 L .23309 .53631 L F
0 0 0 r
.22874 .53646 m .2307 .536 L .22837 .53652 L F
.056 .621 .772 r
.22665 .5366 m .22837 .53652 L .22774 .53663 L F
.368 .826 .924 r
.22837 .53652 m .23309 .53631 L .2308 .53671 L F
.287 0 .222 r
.29637 .54848 m .29353 .55099 L .29436 .5491 L F
.963 .738 .55 r
.54675 .55081 m .54571 .55116 L .54624 .54849 L F
.576 .284 .436 r
.25548 .67351 m .2539 .67128 L .25223 .67246 L F
.25548 .67351 m .25625 .67081 L .2539 .67128 L F
.179 .664 .926 r
.29943 .5356 m .30335 .53646 L .30115 .53697 L F
.534 .727 .963 r
.21242 .76096 m .21516 .76055 L .21329 .75916 L F
.468 .882 .936 r
.31709 .5465 m .31637 .54747 L .31858 .54714 L F
.31709 .5465 m .31469 .54732 L .31637 .54747 L F
.053 0 0 r
.19869 .56496 m .19839 .56375 L .20055 .56328 L F
.19869 .56496 m .19668 .56581 L .19839 .56375 L F
.288 .068 .395 r
.27982 .60588 m .27801 .60679 L .28025 .6037 L F
.075 0 .185 r
.27904 .60825 m .27801 .60679 L .27982 .60588 L F
.27904 .60825 m .27759 .60894 L .27801 .60679 L F
.521 .363 .607 r
.29477 .61028 m .29725 .60967 L .29703 .60678 L F
.427 .846 .961 r
.29534 .60914 m .29725 .60967 L .29477 .61028 L F
.502 0 0 r
.23498 .55515 m .23286 .55631 L .23091 .55541 L F
.98 .88 .658 r
.2338 .55396 m .23286 .55631 L .23498 .55515 L F
.554 .173 .275 r
.25528 .69018 m .25735 .68942 L .25633 .69181 L F
.03 0 .278 r
.25735 .68942 m .25943 .68641 L .25866 .68856 L F
0 0 0 r
.25633 .69181 m .25735 .68942 L .25866 .68856 L F
.5 .239 .451 r
.31025 .58478 m .30563 .58562 L .31118 .58545 L F
.248 .183 .584 r
.31349 .5824 m .31289 .5831 L .31209 .58243 L F
.001 .117 .633 r
.31209 .58243 m .31118 .58545 L .31102 .58154 L F
.248 .183 .584 r
.31289 .5831 m .31105 .58525 L .31209 .58243 L F
.001 .117 .633 r
.31209 .58243 m .31102 .58154 L .31102 .58149 L F
.269 .187 .575 r
.31209 .58243 m .31025 .58478 L .31118 .58545 L F
0 0 0 r
.28021 .64733 m .28361 .64632 L .28234 .64682 L F
.416 0 .134 r
.28361 .64632 m .28431 .6483 L .28234 .64682 L F
.28361 .64632 m .28606 .64613 L .28431 .6483 L F
.718 .589 .711 r
.28948 .60066 m .28956 .60318 L .29353 .60286 L F
.48 .34 .613 r
.28956 .60318 m .29267 .60559 L .29353 .60286 L F
0 0 0 r
.29267 .60559 m .29552 .60322 L .29353 .60286 L F
.49 .275 .514 r
.29353 .60286 m .29552 .60322 L .2961 .60061 L F
.578 .219 .323 r
.29255 .6437 m .29107 .64633 L .28848 .64609 L F
.545 .183 .304 r
.29458 .64531 m .29107 .64633 L .29255 .6437 L F
.546 .183 .303 r
.29504 .6437 m .29458 .64531 L .29255 .6437 L F
.522 .901 .955 r
.25594 .6255 m .25341 .62648 L .25132 .62611 L F
.257 .508 .902 r
.31854 .53686 m .31788 .53828 L .31521 .53671 L F
.31854 .53686 m .31982 .53884 L .31788 .53828 L F
.766 .625 .704 r
.26881 .66565 m .26508 .66787 L .26734 .66453 L F
.705 .676 .819 r
.26734 .66453 m .27154 .66517 L .26881 .66565 L F
.485 .435 .726 r
.27134 .66781 m .26881 .66565 L .27154 .66517 L F
.962 .914 .561 r
.50432 .53284 m .50328 .53457 L .50481 .53317 L F
.397 .837 .942 r
.50481 .53317 m .50714 .53253 L .50432 .53284 L F
.50432 .53284 m .50714 .53253 L .50481 .53317 L F
.962 .914 .561 r
.50432 .53284 m .50328 .53457 L .50481 .53317 L F
.264 .217 .616 r
.35439 .56612 m .35472 .56954 L .35314 .5701 L F
.298 .314 .71 r
.35472 .56954 m .35546 .57208 L .35314 .5701 L F
.406 .321 .647 r
.35546 .57208 m .35362 .57285 L .35314 .5701 L F
.726 .473 .544 r
.52798 .5231 m .52435 .52252 L .52732 .52251 L F
.52798 .5231 m .52492 .5243 L .52435 .52252 L F
0 .075 .571 r
.52822 .52735 m .52492 .5243 L .52798 .5231 L F
.545 .433 .677 r
.32994 .61241 m .33037 .61588 L .32809 .61616 L F
.598 .428 .623 r
.33037 .61588 m .3281 .61854 L .32809 .61616 L F
.297 .095 .429 r
.27803 .62215 m .27984 .62382 L .28049 .62149 L F
.27803 .62215 m .27737 .62504 L .27984 .62382 L F
.191 0 .231 r
.20107 .78731 m .20247 .78433 L .20366 .78427 L F
.057 0 0 r
.20366 .78427 m .20247 .78433 L .20109 .785 L F
.462 .214 .452 r
.1806 .59356 m .17927 .59112 L .18132 .59114 L F
.1806 .59356 m .17831 .59421 L .17927 .59112 L F
.459 .193 .422 r
.18214 .5888 m .18132 .59114 L .17927 .59112 L F
.975 .703 .299 r
.76677 .40098 m .76692 .4037 L .76583 .40003 L F
.914 .946 .807 r
.76677 .40098 m .76781 .39734 L .76952 .39803 L F
.76677 .40098 m .76583 .40003 L .76781 .39734 L F
.546 .362 .583 r
.76952 .39803 m .76985 .40046 L .76677 .40098 L F
.778 .693 .77 r
.76985 .40046 m .76692 .4037 L .76677 .40098 L F
.815 .418 .3 r
.54561 .53571 m .54226 .53313 L .54543 .53368 L F
.682 .585 .74 r
.32785 .54101 m .32547 .54396 L .32374 .53921 L F
.617 .859 .989 r
.79764 .42835 m .79872 .42948 L .80128 .42856 L F
.325 .531 .901 r
.77179 .41343 m .77391 .41611 L .77523 .4145 L F
.243 .41 .829 r
.77523 .4145 m .77391 .41611 L .77558 .41676 L F
.381 .185 .485 r
.32531 .56073 m .3251 .56325 L .32307 .56396 L F
.524 .371 .616 r
.3251 .56325 m .32285 .56659 L .32307 .56396 L F
.196 .726 .795 r
.23975 .54834 m .23806 .54843 L .236 .54879 L F
.31 .784 .926 r
.24195 .54842 m .23806 .54843 L .23975 .54834 L F
.78 .676 .749 r
.33899 .55567 m .34138 .55329 L .33966 .55463 L F
.425 .271 .567 r
.24961 .6834 m .25238 .68518 L .25229 .68259 L F
.24961 .6834 m .24982 .6868 L .25238 .68518 L F
.516 .814 .999 r
.327 .58227 m .32761 .58064 L .32488 .5788 L F
.327 .58227 m .32921 .58166 L .32761 .58064 L F
.456 .045 .17 r
.32516 .5841 m .32921 .58166 L .327 .58227 L F
.037 0 0 r
.26031 .62428 m .26253 .62269 L .2595 .62393 L F
0 0 0 r
.26425 .62152 m .26253 .62269 L .26031 .62428 L F
.975 .787 .587 r
.55559 .54095 m .55656 .54439 L .55716 .54222 L F
.349 .517 .882 r
.18034 .58946 m .1791 .58905 L .17907 .58993 L F
.997 .85 .56 r
.18076 .58891 m .18132 .59114 L .18214 .5888 L F
.1805 .58925 m .18132 .59114 L .18076 .58891 L F
.349 .517 .882 r
.18165 .58897 m .18132 .59114 L .1805 .58925 L F
.18165 .58897 m .18069 .589 L .1805 .58925 L F
.18069 .589 m .1791 .58905 L .18034 .58946 L F
.997 .85 .56 r
.18036 .58894 m .1805 .58925 L .18076 .58891 L F
.349 .517 .882 r
.18165 .58897 m .1805 .58925 L .18036 .58894 L F
.18165 .58897 m .1805 .58925 L .18034 .58946 L F
.674 .743 .903 r
.54678 .58442 m .54696 .5873 L .55092 .58514 L F
0 0 0 r
.19989 .54473 m .20153 .54422 L .2033 .54273 L F
.102 0 0 r
.2033 .54273 m .20367 .54363 L .20547 .54203 L F
.2033 .54273 m .20153 .54422 L .20367 .54363 L F
.069 0 0 r
.53241 .52743 m .53092 .52855 L .52846 .52914 L F
.412 0 0 r
.53513 .5282 m .53241 .52743 L .53583 .52743 L F
.53513 .5282 m .53092 .52855 L .53241 .52743 L F
.158 0 .236 r
.28411 .57618 m .28567 .57588 L .28659 .57308 L F
.271 .331 .742 r
.28411 .57618 m .2866 .57825 L .28567 .57588 L F
.147 0 .02 r
.16627 .56637 m .16817 .56607 L .16954 .56393 L F
.278 0 .171 r
.16817 .56607 m .17142 .56294 L .16954 .56393 L F
.538 .322 .533 r
.27394 .66499 m .27134 .66781 L .27154 .66517 L F
.457 .761 .995 r
.27192 .66456 m .27394 .66499 L .27154 .66517 L F
.27263 .66341 m .27363 .66461 L .27192 .66456 L F
.27363 .66461 m .27394 .66499 L .27192 .66456 L F
.642 .908 .601 r
.27196 .66671 m .27309 .66583 L .27303 .66578 L F
.27309 .66583 m .27337 .66561 L .27322 .66568 L F
.27309 .66583 m .27322 .66568 L .27303 .66578 L F
.317 0 0 r
.27322 .66568 m .27154 .66517 L .26734 .66453 L F
.27322 .66568 m .26734 .66453 L .26734 .66443 L F
.27348 .66573 m .27325 .66567 L .27322 .66568 L F
.27348 .66573 m .27322 .66568 L .27322 .66568 L F
.27322 .66568 m .26734 .66453 L .27322 .66568 L F
.27143 .66455 m .26734 .66443 L .26727 .66213 L F
.457 .761 .995 r
.27339 .66548 m .27338 .66548 L .27348 .66573 L F
.27338 .66548 m .27314 .66548 L .2733 .6656 L F
.642 .908 .601 r
.27325 .66567 m .27337 .66561 L .27338 .66548 L F
.457 .761 .995 r
.27338 .66548 m .2733 .6656 L .27348 .66573 L F
.642 .908 .601 r
.27338 .66548 m .27337 .66561 L .27394 .66499 L F
.457 .761 .995 r
.27192 .66456 m .27154 .66517 L .27348 .66573 L F
.317 0 0 r
.27328 .66562 m .26734 .66443 L .27143 .66455 L F
.642 .908 .601 r
.27322 .66568 m .27325 .66567 L .2733 .6656 L F
.317 0 0 r
.27348 .66573 m .27322 .66568 L .27328 .66562 L F
.27325 .66567 m .27154 .66517 L .27322 .66568 L F
.27322 .66568 m .26734 .66443 L .27328 .66562 L F
.642 .908 .601 r
.27303 .66578 m .27322 .66568 L .27338 .66548 L F
.267 .512 .902 r
.27331 .66557 m .27328 .66562 L .26727 .66213 L F
.642 .908 .601 r
.27322 .66568 m .2733 .6656 L .27338 .66548 L F
.267 .512 .902 r
.27331 .66557 m .27348 .66573 L .27328 .66562 L F
.642 .908 .601 r
.2732 .66574 m .27308 .66592 L .27337 .66561 L F
.27196 .66671 m .27308 .66592 L .2732 .66574 L F
.457 .761 .995 r
.27263 .66341 m .27192 .66456 L .27314 .66548 L F
.27263 .66341 m .27314 .66548 L .27339 .66548 L F
.356 .552 .906 r
.27263 .66341 m .27339 .66548 L .26821 .66066 L F
.27339 .66548 m .27348 .66573 L .27323 .66549 L F
.193 0 0 r
.27338 .66548 m .27338 .66548 L .27338 .66548 L F
.356 .552 .906 r
.27339 .66548 m .27323 .66549 L .26821 .66066 L F
.193 0 0 r
.27338 .66548 m .2744 .66605 L .27196 .66671 L F
.27338 .66548 m .2744 .66605 L .27338 .66548 L F
.27394 .66499 m .27416 .66548 L .27338 .66548 L F
.27416 .66548 m .2744 .66605 L .27338 .66548 L F
.267 .512 .902 r
.26821 .66066 m .27331 .66557 L .26727 .66213 L F
.642 .908 .601 r
.27196 .66671 m .27134 .66781 L .27308 .66592 L F
.676 .452 .573 r
.3125 .63448 m .31248 .63714 L .30983 .63723 L F
.639 .422 .571 r
.31591 .63661 m .3125 .63448 L .316 .63436 L F
.31591 .63661 m .31248 .63714 L .3125 .63448 L F
.5 .239 .451 r
.31025 .58478 m .3076 .58672 L .30563 .58562 L F
.381 .009 .202 r
.807 .40942 m .80959 .40873 L .80998 .40765 L F
.35 .211 .547 r
.81186 .40399 m .80998 .40765 L .81213 .4062 L F
.017 0 .048 r
.80959 .40873 m .81213 .4062 L .80998 .40765 L F
.954 .749 .587 r
.50144 .56045 m .4998 .56031 L .50041 .55758 L F
.587 .081 .018 r
.50584 .56158 m .4998 .56031 L .50144 .56045 L F
.48 .34 .613 r
.28956 .60318 m .29026 .60733 L .29267 .60559 L F
.821 .857 .874 r
.82264 .42055 m .82484 .41921 L .82169 .41924 L F
.892 .963 .832 r
.25166 .69397 m .25192 .69517 L .25007 .69586 L F
0 0 .264 r
.25194 .69477 m .25192 .69517 L .25166 .69397 L F
.135 0 .368 r
.2533 .69734 m .25192 .69517 L .25194 .69477 L F
.2533 .69734 m .25187 .69829 L .25192 .69517 L F
.936 .807 .693 r
.54539 .54492 m .54624 .54849 L .54463 .54719 L F
.731 .632 .749 r
.54571 .55116 m .54463 .54719 L .54624 .54849 L F
.634 .186 .169 r
.83124 .40692 m .83496 .40691 L .83228 .40468 L F
.037 0 0 r
.26031 .62428 m .2595 .62393 L .25791 .62446 L F
.166 .529 .921 r
.31687 .55326 m .3179 .55322 L .31781 .55459 L F
0 .165 .68 r
.31862 .55468 m .31781 .55459 L .3179 .55322 L F
.31862 .55468 m .31993 .55632 L .31781 .55459 L F
0 .037 .606 r
.31264 .54804 m .31443 .55025 L .31414 .55147 L F
0 .339 .82 r
.31443 .55025 m .31687 .55326 L .31414 .55147 L F
.175 0 .058 r
.17236 .56163 m .17142 .56294 L .17435 .56077 L F
.554 .72 .951 r
.28659 .57308 m .28781 .57067 L .28662 .56941 L F
.28659 .57308 m .28882 .57251 L .28781 .57067 L F
.01 0 .164 r
.28659 .57308 m .28778 .57338 L .28882 .57251 L F
.28659 .57308 m .28567 .57588 L .28778 .57338 L F
.367 0 0 r
.52079 .52069 m .52343 .52213 L .52435 .52252 L F
.688 .453 .56 r
.52435 .52252 m .52492 .5243 L .52225 .52321 L F
.125 .661 .856 r
.52343 .52213 m .52732 .52251 L .52435 .52252 L F
.345 .627 .957 r
.7813 .42223 m .78258 .42078 L .77945 .41967 L F
.7813 .42223 m .78331 .42232 L .78258 .42078 L F
.969 .656 .277 r
.25168 .67698 m .25279 .68021 L .25339 .67947 L F
.825 .589 .582 r
.25229 .68259 m .25339 .67947 L .25279 .68021 L F
.246 .53 .918 r
.77558 .41676 m .7777 .41897 L .77879 .41772 L F
.181 .431 .864 r
.77879 .41772 m .7777 .41897 L .77945 .41967 L F
.57 .921 .729 r
.24783 .55301 m .24609 .55439 L .24714 .55396 L F
.24783 .55301 m .24609 .55439 L .24714 .55396 L F
.235 .084 .463 r
.32285 .56659 m .32143 .56862 L .32128 .56844 L F
0 0 0 r
.32059 .57013 m .31909 .57106 L .32143 .56862 L F
.948 .675 .486 r
.5571 .53355 m .55837 .53343 L .55583 .53188 L F
.5571 .53355 m .55785 .53455 L .55837 .53343 L F
.778 .693 .77 r
.76985 .40046 m .77075 .40423 L .76692 .4037 L F
.233 .322 .751 r
.77235 .4023 m .77075 .40423 L .76985 .40046 L F
.432 .619 .93 r
.77288 .40405 m .77075 .40423 L .77235 .4023 L F
0 0 0 r
.27505 .55152 m .27236 .5543 L .27348 .55277 L F
.252 0 0 r
.2482 .54798 m .24438 .54862 L .24601 .54819 L F
.397 .173 .453 r
.30987 .59138 m .31201 .59085 L .3122 .58847 L F
.329 .194 .541 r
.30987 .59138 m .31173 .59334 L .31201 .59085 L F
.30987 .59138 m .30981 .59445 L .31173 .59334 L F
.358 .806 .95 r
.27021 .53388 m .2726 .53351 L .27486 .53411 L F
.408 .835 .959 r
.27512 .53303 m .27486 .53411 L .2726 .53351 L F
.27512 .53303 m .27713 .53361 L .27486 .53411 L F
.745 .736 .843 r
.77957 .4037 m .77924 .40716 L .77723 .40662 L F
.8 .537 .541 r
.77924 .40716 m .77718 .40834 L .77723 .40662 L F
.77924 .40716 m .77999 .40955 L .77718 .40834 L F
.304 .07 .384 r
.28255 .55469 m .28444 .55428 L .28496 .55154 L F
.466 .287 .554 r
.2821 .55755 m .28444 .55428 L .28255 .55469 L F
.588 .627 .858 r
.3451 .57717 m .34076 .57343 L .34351 .5704 L F
.532 .191 .335 r
.3467 .57805 m .3451 .57717 L .34718 .576 L F
.3467 .57805 m .34411 .57938 L .3451 .57717 L F
.306 .394 .789 r
.30367 .59663 m .30089 .5944 L .30272 .59397 L F
.419 .406 .738 r
.3217 .5731 m .32352 .5729 L .32273 .56902 L F
.536 .442 .696 r
.3217 .5731 m .32452 .57508 L .32352 .5729 L F
.3217 .5731 m .32232 .57616 L .32452 .57508 L F
.754 .977 .919 r
.29047 .58984 m .29021 .59133 L .29257 .58994 L F
.457 .521 .836 r
.29257 .58994 m .2936 .5868 L .29047 .58984 L F
.29257 .58994 m .29593 .59081 L .2936 .5868 L F
.353 .121 .416 r
.4858 .62213 m .48534 .62489 L .48333 .62524 L F
.48333 .62524 m .48534 .62489 L .4858 .62213 L F
.324 .783 .945 r
.26363 .64867 m .26842 .64891 L .26559 .64825 L F
0 .495 .742 r
.26559 .64825 m .26842 .64891 L .26989 .64913 L F
.963 .752 .57 r
.26727 .66213 m .26734 .66453 L .26505 .66371 L F
.267 .512 .902 r
.26821 .66066 m .26727 .66213 L .26505 .66371 L F
.607 .833 .986 r
.22687 .63941 m .23097 .63949 L .2293 .63876 L F
.359 .775 .979 r
.23283 .63925 m .2293 .63876 L .23097 .63949 L F
.347 .229 .573 r
.29189 .59761 m .29342 .59706 L .29482 .59146 L F
.349 .235 .579 r
.29189 .59761 m .2937 .59969 L .29342 .59706 L F
.759 .747 .842 r
.26317 .66876 m .25899 .67058 L .26116 .67078 L F
.43 .139 .368 r
.26506 .67026 m .26317 .66876 L .26116 .67078 L F
.26506 .67026 m .26508 .66787 L .26317 .66876 L F
.053 0 .412 r
.28194 .60011 m .28183 .60258 L .28025 .6037 L F
0 0 .254 r
.28183 .60258 m .27982 .60588 L .28025 .6037 L F
0 0 0 r
.23549 .72086 m .23173 .72301 L .23376 .72163 L F
.128 0 0 r
.23625 .7212 m .23549 .72086 L .23376 .72163 L F
.23625 .7212 m .23754 .72111 L .23549 .72086 L F
.758 .384 .346 r
.54993 .5255 m .55355 .52428 L .54975 .52328 L F
.54993 .5255 m .55378 .5261 L .55355 .52428 L F
.412 .772 .995 r
.23283 .63925 m .23771 .64013 L .23514 .63866 L F
.343 .668 .975 r
.23771 .64013 m .23795 .63847 L .23514 .63866 L F
.23771 .64013 m .23931 .63997 L .23795 .63847 L F
.461 .816 .997 r
.32893 .53969 m .32968 .54064 L .3282 .53982 L F
.733 .828 .924 r
.33407 .54072 m .32968 .54064 L .32928 .54014 L F
.611 .873 .991 r
.33407 .54072 m .32928 .54014 L .33501 .53897 L F
.32928 .54014 m .32899 .5401 L .32917 .54007 L F
.32928 .54014 m .32917 .54007 L .33501 .53897 L F
.148 .692 .769 r
.33057 .5394 m .33501 .53897 L .32917 .54007 L F
.461 .816 .997 r
.33057 .5394 m .32929 .54001 L .32893 .53969 L F
.148 .692 .769 r
.33057 .5394 m .32917 .54007 L .32899 .5401 L F
.461 .816 .997 r
.33057 .5394 m .3298 .54047 L .32929 .54001 L F
.3298 .54047 m .32968 .54064 L .32928 .54014 L F
.3298 .54047 m .32928 .54014 L .32893 .53969 L F
.733 .828 .924 r
.32928 .54014 m .32968 .54064 L .32899 .5401 L F
.611 .873 .991 r
.33407 .54072 m .33501 .53897 L .33606 .53964 L F
.555 .363 .575 r
.29959 .60354 m .29703 .60678 L .29552 .60322 L F
.29959 .60354 m .29945 .60651 L .29703 .60678 L F
.29703 .60678 m .29945 .60651 L .29959 .60354 L F
.711 .494 .593 r
.29959 .60354 m .29945 .60651 L .30236 .60432 L F
0 0 .369 r
.30065 .60513 m .29959 .60354 L .30073 .60323 L F
.30065 .60513 m .29945 .60651 L .29959 .60354 L F
.612 .276 .377 r
.2443 .70497 m .24753 .70473 L .24494 .70293 L F
.478 0 0 r
.24494 .70293 m .24753 .70473 L .24805 .70493 L F
.513 .671 .935 r
.3422 .58714 m .33923 .58472 L .34163 .58437 L F
.374 .396 .755 r
.34402 .58343 m .3422 .58714 L .34163 .58437 L F
.34402 .58343 m .3456 .5873 L .3422 .58714 L F
.362 .443 .81 r
.3422 .58714 m .3456 .5873 L .34399 .58804 L F
.79 .641 .696 r
.34351 .5704 m .34131 .57003 L .34368 .56975 L F
.642 .373 .495 r
.3173 .58723 m .31452 .58509 L .31498 .5873 L F
.3173 .58723 m .31789 .58498 L .31452 .58509 L F
.782 .748 .823 r
.54275 .5608 m .53964 .56045 L .54171 .55847 L F
.484 .361 .636 r
.34075 .57842 m .34186 .58132 L .33955 .58033 L F
.85 .683 .674 r
.55144 .56031 m .55301 .5638 L .55341 .56112 L F
.508 .712 .963 r
.50548 .55558 m .5037 .55732 L .50243 .55624 L F
.50548 .55558 m .50623 .55719 L .5037 .55732 L F
.402 0 0 r
.21657 .61974 m .21282 .61849 L .21493 .6185 L F
.084 .536 .905 r
.21898 .62025 m .21657 .61974 L .21493 .6185 L F
.733 .625 .739 r
.81392 .4281 m .81747 .42872 L .81648 .42516 L F
.723 .619 .742 r
.81747 .42872 m .82008 .4256 L .81648 .42516 L F
.119 0 .366 r
.3122 .58847 m .31335 .58989 L .31498 .5873 L F
.3122 .58847 m .31201 .59085 L .31335 .58989 L F
.485 .574 .87 r
.25258 .70127 m .25073 .7018 L .24899 .69844 L F
0 0 0 r
.24838 .70327 m .25073 .7018 L .25258 .70127 L F
.572 .371 .57 r
.32731 .62103 m .325 .61899 L .3281 .61854 L F
.32731 .62103 m .32489 .62145 L .325 .61899 L F
0 0 0 r
.23309 .53631 m .23539 .53594 L .23696 .53564 L F
.197 .723 .846 r
.23539 .53594 m .23931 .53582 L .23696 .53564 L F
.926 .603 .141 r
.48706 .57262 m .48758 .57541 L .48621 .57183 L F
.48706 .57262 m .48758 .57541 L .48621 .57183 L F
0 0 .242 r
.28613 .56691 m .28604 .56278 L .28608 .56357 L F
.28613 .56691 m .28638 .56563 L .28604 .56278 L F
.734 .472 0 r
.28613 .56691 m .28633 .56832 L .28638 .56563 L F
.28613 .56691 m .28662 .56941 L .28633 .56832 L F
.521 .207 .377 r
.34549 .59369 m .3418 .59679 L .3425 .59535 L F
.298 .328 .724 r
.17675 .61256 m .17759 .61625 L .17847 .61372 L F
.491 .54 .835 r
.17847 .61372 m .17759 .61625 L .17986 .61604 L F
.288 .176 .548 r
.15184 .5883 m .1537 .58444 L .15145 .58569 L F
.168 .193 .643 r
.28506 .5826 m .28657 .58379 L .28652 .58072 L F
.717 .454 .527 r
.25548 .67351 m .25899 .67058 L .25625 .67081 L F
.25548 .67351 m .25935 .67284 L .25899 .67058 L F
.614 .589 .802 r
.25935 .67284 m .26116 .67078 L .25899 .67058 L F
.468 .199 .423 r
.48846 .62158 m .48534 .62489 L .4858 .62213 L F
.48534 .62489 m .48846 .62158 L .4858 .62213 L F
.579 .35 .533 r
.19803 .78426 m .20109 .785 L .19843 .78564 L F
.248 .146 .537 r
.15513 .60021 m .15636 .59724 L .15384 .59736 L F
.15513 .60021 m .15626 .60025 L .15636 .59724 L F
0 0 .464 r
.77124 .39861 m .76952 .39803 L .76781 .39734 L F
.77124 .39861 m .76985 .40046 L .76952 .39803 L F
.71 .371 .402 r
.4657 .63804 m .46962 .63724 L .46754 .64099 L F
.426 .274 .57 r
.46962 .63724 m .46978 .64016 L .46754 .64099 L F
.506 .253 .465 r
.47255 .63446 m .47209 .63682 L .46962 .63724 L F
.272 .158 .536 r
.47153 .63863 m .46962 .63724 L .47209 .63682 L F
.47153 .63863 m .46978 .64016 L .46962 .63724 L F
0 0 0 r
.47031 .63627 m .46742 .64096 L .47076 .63562 L F
.46962 .63724 m .46904 .63823 L .47031 .63627 L F
.46904 .63823 m .46742 .64096 L .47031 .63627 L F
.713 .728 .862 r
.4657 .63804 m .4674 .64076 L .46338 .6403 L F
.4674 .64076 m .46754 .64099 L .46728 .64094 L F
.4674 .64076 m .46728 .64094 L .46338 .6403 L F
0 0 0 r
.4658 .64174 m .46338 .6403 L .46754 .64099 L F
.46978 .64016 m .4658 .64174 L .46754 .64099 L F
.227 .516 .912 r
.28496 .55154 m .28552 .55006 L .28362 .54965 L F
.395 .148 .417 r
.28496 .55154 m .28671 .55303 L .28552 .55006 L F
.28496 .55154 m .28444 .55428 L .28671 .55303 L F
.389 .513 .862 r
.29842 .60602 m .29701 .60732 L .29867 .60617 L F
.581 .028 0 r
.29703 .60678 m .29701 .60732 L .29595 .60829 L F
.389 .513 .862 r
.29581 .60442 m .29701 .60732 L .29842 .60602 L F
.581 .028 0 r
.29595 .60829 m .29701 .60732 L .29534 .60914 L F
.004 0 .475 r
.29703 .60678 m .29725 .60967 L .29812 .60795 L F
.581 .028 0 r
.29703 .60678 m .29812 .60795 L .29701 .60732 L F
.416 .004 .146 r
.29812 .60795 m .29945 .60651 L .29703 .60678 L F
.973 .668 .364 r
.81017 .42521 m .80996 .4228 L .80866 .42112 L F
.78 .781 .854 r
.80866 .42112 m .80996 .4228 L .81272 .4202 L F
.789 .438 .391 r
.8138 .42573 m .80996 .4228 L .81017 .42521 L F
0 0 0 r
.26662 .61579 m .26459 .61906 L .26593 .61768 L F
0 0 .063 r
.26425 .62152 m .26593 .61768 L .26459 .61906 L F
.217 0 .289 r
.16134 .57021 m .16241 .57156 L .16317 .56958 L F
.16134 .57021 m .16064 .57242 L .16241 .57156 L F
.123 .673 .749 r
.28116 .53306 m .28095 .53322 L .27868 .53317 L F
.28116 .53306 m .28325 .53294 L .28095 .53322 L F
.881 .703 .657 r
.83561 .40964 m .83883 .40748 L .83496 .40691 L F
.83561 .40964 m .83842 .40984 L .83883 .40748 L F
.351 .121 .418 r
.15356 .57907 m .15549 .57847 L .15597 .57607 L F
.341 .184 .518 r
.15362 .5817 m .15549 .57847 L .15356 .57907 L F
.538 .817 .997 r
.19167 .60753 m .18713 .60672 L .18926 .60614 L F
.078 .43 .872 r
.19155 .60573 m .19167 .60753 L .18926 .60614 L F
.19155 .60573 m .19305 .60771 L .19167 .60753 L F
.68 .169 .017 r
.53583 .52743 m .53663 .52876 L .53513 .5282 L F
.647 .456 .611 r
.30983 .63723 m .3071 .63989 L .30701 .63752 L F
.591 .442 .647 r
.31836 .63144 m .31851 .63405 L .316 .63436 L F
.628 .415 .574 r
.31851 .63405 m .31591 .63661 L .316 .63436 L F
.765 .585 .654 r
.79331 .40697 m .79353 .41 L .79712 .41026 L F
.771 .467 .472 r
.79353 .41 m .79743 .41299 L .79712 .41026 L F
.764 .492 .522 r
.79712 .41026 m .79743 .41299 L .80119 .4133 L F
0 0 .378 r
.26545 .55168 m .26655 .55274 L .26741 .55107 L F
.26545 .55168 m .26556 .55445 L .26655 .55274 L F
.11 .577 .914 r
.23062 .62457 m .22669 .62313 L .22931 .62337 L F
.294 .753 .952 r
.23111 .62381 m .23062 .62457 L .22931 .62337 L F
.23111 .62381 m .23289 .6244 L .23062 .62457 L F
.506 .288 .517 r
.32748 .56272 m .3251 .56325 L .32531 .56073 L F
.255 .199 .599 r
.28817 .60995 m .28997 .61125 L .29011 .60917 L F
.28817 .60995 m .28844 .61276 L .28997 .61125 L F
.807 .987 .726 r
.2701 .65782 m .27008 .65902 L .27075 .65752 L F
0 0 .276 r
.26955 .65647 m .27008 .65902 L .2701 .65782 L F
.474 .769 .995 r
.22446 .74744 m .22233 .74784 L .22331 .7463 L F
.22446 .74744 m .22233 .74784 L .22331 .7463 L F
.148 .534 .921 r
.17521 .58781 m .17466 .58872 L .17356 .58672 L F
.351 .085 .363 r
.15597 .57607 m .15799 .57542 L .15865 .57315 L F
.264 .008 .324 r
.15865 .57315 m .15983 .57456 L .16064 .57242 L F
.15865 .57315 m .15799 .57542 L .15983 .57456 L F
.531 .348 .577 r
.33231 .60953 m .32994 .61241 L .32968 .60988 L F
.463 0 .068 r
.33044 .56809 m .33123 .56895 L .33306 .56701 L F
.442 0 .054 r
.33306 .56701 m .33123 .56895 L .33466 .56804 L F
.777 .699 .776 r
.33123 .56895 m .33247 .57167 L .33466 .56804 L F
0 0 .511 r
.33193 .56657 m .33233 .57016 L .33123 .56895 L F
.33233 .57016 m .33245 .57127 L .33123 .56895 L F
.463 0 .068 r
.32883 .56875 m .33123 .56895 L .33044 .56809 L F
.299 0 .205 r
.16627 .56637 m .16746 .56817 L .16817 .56607 L F
.16627 .56637 m .1653 .56886 L .16746 .56817 L F
.926 .716 .6 r
.2961 .60061 m .29552 .60322 L .2937 .59969 L F
.568 .419 .639 r
.32489 .62145 m .32269 .62488 L .32258 .62195 L F
.726 .67 .795 r
.83151 .41721 m .83356 .41602 L .82978 .41561 L F
.127 .675 .803 r
.24153 .53507 m .24547 .53501 L .24317 .53496 L F
.834 .931 .552 r
.28873 .59308 m .29021 .59133 L .29047 .58984 L F
.49 .192 .388 r
.30488 .60158 m .30784 .60273 L .30688 .60114 L F
.30488 .60158 m .30511 .60328 L .30784 .60273 L F
.143 .675 .861 r
.23512 .62437 m .23698 .62474 L .23289 .6244 L F
.325 .802 .908 r
.23739 .62409 m .23698 .62474 L .23512 .62437 L F
.23739 .62409 m .23913 .62428 L .23698 .62474 L F
.45 .107 .291 r
.29945 .60651 m .30191 .60652 L .30236 .60432 L F
.282 0 .241 r
.30236 .60432 m .30191 .60652 L .304 .60554 L F
.557 .642 .89 r
.33063 .55119 m .33042 .5545 L .32772 .55232 L F
.33063 .55119 m .33268 .55399 L .33042 .5545 L F
.296 .241 .625 r
.3324 .55648 m .33042 .5545 L .33268 .55399 L F
.3324 .55648 m .33099 .55746 L .33042 .5545 L F
.446 .831 .986 r
.22062 .63795 m .22137 .63686 L .21894 .63671 L F
.22062 .63795 m .2227 .63747 L .22137 .63686 L F
.246 .76 .8 r
.27831 .64748 m .28021 .64733 L .28234 .64682 L F
.943 .644 .442 r
.25632 .55217 m .25364 .55041 L .25293 .55146 L F
.25632 .55217 m .25393 .55252 L .25504 .55134 L F
.35 .826 .818 r
.25614 .55174 m .25393 .55252 L .25632 .55217 L F
.389 0 .128 r
.25614 .55174 m .25228 .55428 L .25393 .55252 L F
.25228 .55428 m .25215 .55437 L .25393 .55252 L F
.943 .644 .442 r
.25504 .55134 m .25393 .55252 L .25364 .55041 L F
.317 0 0 r
.52492 .5243 m .52089 .52588 L .52225 .52321 L F
.74 .635 .743 r
.52079 .52069 m .52225 .52321 L .51838 .52368 L F
.647 .305 .378 r
.51838 .52368 m .52225 .52321 L .52089 .52588 L F
.869 .59 .513 r
.54656 .52208 m .54977 .52093 L .54596 .52063 L F
.54656 .52208 m .54975 .52328 L .54977 .52093 L F
0 .073 .636 r
.2497 .67314 m .25168 .67698 L .25198 .67591 L F
.161 .57 .933 r
.25198 .67591 m .25168 .67698 L .25378 .67726 L F
.969 .656 .277 r
.25168 .67698 m .25339 .67947 L .25378 .67726 L F
.93 .719 .596 r
.54999 .55401 m .54981 .55719 L .55152 .55762 L F
.981 .745 .508 r
.54985 .55909 m .55152 .55762 L .54981 .55719 L F
.54985 .55909 m .55144 .56031 L .55152 .55762 L F
.825 .589 .582 r
.25229 .68259 m .25446 .68349 L .25339 .67947 L F
.786 .91 .926 r
.25339 .67947 m .25608 .67607 L .25378 .67726 L F
.83 .688 .706 r
.2443 .70497 m .24805 .70493 L .24753 .70473 L F
.2443 .70497 m .24769 .7072 L .24805 .70493 L F
.115 0 0 r
.18587 .55175 m .18282 .55403 L .18484 .55307 L F
.095 0 0 r
.18587 .55175 m .18674 .55229 L .18789 .55096 L F
.18587 .55175 m .18484 .55307 L .18674 .55229 L F
.27 .599 .951 r
.19156 .62211 m .19189 .62069 L .1908 .62092 L F
.132 .446 .88 r
.19156 .62211 m .19431 .62353 L .19189 .62069 L F
.524 .826 1 r
.3221 .53823 m .32374 .53921 L .31982 .53884 L F
.163 .49 .903 r
.32427 .5379 m .32374 .53921 L .3221 .53823 L F
.32427 .5379 m .32533 .53951 L .32374 .53921 L F
.682 .585 .74 r
.32785 .54101 m .32374 .53921 L .32533 .53951 L F
.688 .952 .689 r
.81466 .40095 m .8163 .39873 L .81734 .40033 L F
.81466 .40095 m .81462 .40055 L .8163 .39873 L F
.48 .374 .657 r
.2998 .57842 m .30186 .57483 L .2994 .57619 L F
0 .328 .813 r
.15636 .59724 m .15326 .5944 L .15384 .59736 L F
0 .115 .658 r
.26989 .64913 m .26768 .6469 L .26559 .64825 L F
.423 .732 .99 r
.80128 .42856 m .80498 .42957 L .80407 .42799 L F
.641 .709 .897 r
.80498 .42957 m .80635 .42682 L .80407 .42799 L F
.80498 .42957 m .8078 .42855 L .80635 .42682 L F
.513 .432 .702 r
.32232 .57616 m .32488 .5788 L .32452 .57508 L F
.32232 .57616 m .32277 .57945 L .32488 .5788 L F
.609 .56 .775 r
.30367 .59663 m .30562 .60153 L .30203 .60047 L F
.111 0 .311 r
.30288 .60192 m .30203 .60047 L .30562 .60153 L F
.30288 .60192 m .30073 .60323 L .30203 .60047 L F
.302 0 0 r
.20765 .54135 m .21007 .54113 L .21193 .53962 L F
.143 0 0 r
.21007 .54113 m .21421 .53903 L .21193 .53962 L F
.38 .146 .429 r
.15597 .57607 m .15549 .57847 L .15799 .57542 L F
.011 .586 .73 r
.29123 .55096 m .28935 .5509 L .29353 .55099 L F
.214 0 .061 r
.807 .40942 m .8094 .40939 L .80959 .40873 L F
.807 .40942 m .8062 .4115 L .8094 .40939 L F
.579 .61 .848 r
.25528 .69018 m .2548 .68549 L .25249 .68672 L F
.25528 .69018 m .25738 .68956 L .2548 .68549 L F
.415 .133 .374 r
.25633 .69181 m .25528 .69018 L .25388 .6921 L F
.25633 .69181 m .25738 .68956 L .25528 .69018 L F
.554 .173 .275 r
.25528 .69018 m .25633 .69181 L .25388 .6921 L F
0 .559 .796 r
.19606 .60588 m .1996 .60652 L .19792 .60636 L F
.19606 .60588 m .1996 .60652 L .19792 .60636 L F
.607 .527 .738 r
.34395 .54456 m .3449 .54837 L .34702 .54728 L F
.137 0 .259 r
.3446 .55072 m .34702 .54728 L .3449 .54837 L F
.535 .67 .924 r
.18411 .61802 m .18426 .61481 L .18214 .61519 L F
.18411 .61802 m .18673 .61777 L .18426 .61481 L F
.908 .88 .795 r
.26505 .66371 m .26734 .66453 L .26508 .66787 L F
.781 .686 .76 r
.8078 .42855 m .81133 .42899 L .81017 .42521 L F
.741 .665 .775 r
.81017 .42521 m .81133 .42899 L .8138 .42573 L F
.703 .607 .747 r
.81133 .42899 m .81392 .4281 L .8138 .42573 L F
.411 .253 .555 r
.47455 .63102 m .47462 .63363 L .47255 .63446 L F
.584 .415 .618 r
.47462 .63363 m .47209 .63682 L .47255 .63446 L F
.576 .177 .249 r
.47076 .63562 m .47462 .63363 L .47255 .63446 L F
.411 .253 .555 r
.47455 .63102 m .47462 .63363 L .47255 .63446 L F
.079 0 .418 r
.27106 .65353 m .26955 .65647 L .27041 .65489 L F
0 0 .276 r
.26955 .65647 m .2701 .65782 L .27041 .65489 L F
0 0 .187 r
.26983 .62397 m .26965 .62229 L .27037 .62145 L F
.26983 .62397 m .26901 .6251 L .26965 .62229 L F
.142 .434 .872 r
.20314 .60958 m .20175 .60927 L .1996 .60652 L F
.947 .945 .744 r
.3324 .55648 m .33156 .56064 L .33099 .55746 L F
.3324 .55648 m .3305 .56038 L .33156 .56064 L F
.224 .202 .622 r
.33179 .55947 m .33208 .56113 L .3305 .56038 L F
.33208 .56113 m .33216 .56162 L .33162 .56122 L F
.33208 .56113 m .33162 .56122 L .3305 .56038 L F
0 0 0 r
.32973 .56157 m .32955 .56207 L .32748 .56272 L F
.33156 .56064 m .33043 .56144 L .32973 .56157 L F
.33043 .56144 m .32955 .56207 L .32973 .56157 L F
.992 .864 .605 r
.3305 .56038 m .32955 .56207 L .33156 .56064 L F
.598 .654 .876 r
.34245 .54148 m .34131 .54323 L .33843 .53916 L F
.122 0 0 r
.53359 .52131 m .53595 .52076 L .53719 .52007 L F
.341 0 0 r
.53595 .52076 m .53968 .52032 L .53719 .52007 L F
.176 .644 .934 r
.32533 .53951 m .32968 .54064 L .32785 .54101 L F
0 0 .068 r
.82104 .39972 m .81851 .40411 L .81734 .40033 L F
.82104 .39972 m .82045 .40215 L .81851 .40411 L F
.393 .529 .875 r
.82045 .40215 m .82089 .40415 L .81851 .40411 L F
.1 0 .344 r
.35546 .57208 m .35376 .57531 L .35362 .57285 L F
.2 0 .101 r
.18079 .5794 m .17878 .57961 L .18127 .57897 L F
.18079 .5794 m .17798 .58127 L .17878 .57961 L F
0 0 0 r
.3403 .54411 m .338 .54551 L .33738 .5457 L F
.739 .297 .202 r
.28552 .55006 m .28702 .54858 L .28577 .54726 L F
.351 .083 .361 r
.27512 .63001 m .27763 .62729 L .27599 .6282 L F
.867 .689 .659 r
.54247 .53011 m .53903 .53143 L .5386 .52944 L F
.54247 .53011 m .54226 .53313 L .53903 .53143 L F
.253 .006 .332 r
.26911 .61255 m .26662 .61579 L .26789 .61464 L F
0 0 0 r
.26789 .61464 m .26662 .61579 L .26593 .61768 L F
.707 .707 .848 r
.82978 .41561 m .83356 .41602 L .83285 .41261 L F
.785 .757 .827 r
.83285 .41261 m .83356 .41602 L .83633 .41307 L F
.359 .026 .257 r
.19848 .54671 m .20153 .54422 L .19989 .54473 L F
.878 .719 .681 r
.55391 .57543 m .55549 .57853 L .55573 .57602 L F
.55391 .57543 m .55194 .57819 L .55549 .57853 L F
.863 .787 .775 r
.55194 .57819 m .55307 .58157 L .55549 .57853 L F
.136 .476 .897 r
.29811 .53383 m .29679 .53438 L .29526 .53328 L F
.29811 .53383 m .29943 .5356 L .29679 .53438 L F
0 .483 .846 r
.22485 .72889 m .22832 .73034 L .22711 .72982 L F
.753 .842 .918 r
.22832 .73034 m .22912 .72778 L .22711 .72982 L F
.22832 .73034 m .23112 .729 L .22912 .72778 L F
.521 .207 .377 r
.34549 .59369 m .34434 .59651 L .3418 .59679 L F
.513 .183 .345 r
.34822 .59363 m .34434 .59651 L .34549 .59369 L F
.966 .686 .451 r
.55141 .56264 m .55301 .5638 L .55144 .56031 L F
.939 .783 .66 r
.55115 .56489 m .55301 .5638 L .55141 .56264 L F
.55115 .56489 m .55256 .56627 L .55301 .5638 L F
.871 .665 .621 r
.79006 .40883 m .79331 .40697 L .79048 .4063 L F
.79006 .40883 m .79353 .41 L .79331 .40697 L F
.063 0 0 r
.21633 .53842 m .21992 .53751 L .21798 .53868 L F
.218 .218 .644 r
.32634 .55134 m .32724 .54705 L .32545 .54735 L F
.32634 .55134 m .32772 .55232 L .32724 .54705 L F
.254 0 .11 r
.32585 .5532 m .32772 .55232 L .32634 .55134 L F
.373 .357 .712 r
.3537 .57887 m .35245 .58111 L .35144 .57959 L F
.3537 .57887 m .35418 .58135 L .35245 .58111 L F
.521 .122 .225 r
.31903 .58732 m .31789 .58498 L .3173 .58723 L F
.31903 .58732 m .32045 .58486 L .31789 .58498 L F
.688 .538 .677 r
.46334 .65266 m .46606 .64886 L .46311 .64944 L F
0 0 0 r
.27035 .61157 m .26911 .61255 L .26789 .61464 L F
.997 .789 .498 r
.46469 .64346 m .4632 .64513 L .4637 .6433 L F
.282 .02 .326 r
.4637 .6433 m .4632 .64513 L .46358 .64471 L F
.973 .663 .344 r
.46469 .64346 m .4637 .6433 L .46386 .64145 L F
0 0 0 r
.4658 .64174 m .46469 .64346 L .46338 .6403 L F
.46579 .64206 m .46581 .64225 L .4659 .64199 L F
.019 0 0 r
.4659 .64199 m .4658 .64203 L .4658 .64174 L F
0 0 0 r
.4658 .64174 m .4658 .64203 L .46579 .64205 L F
.4658 .64174 m .46579 .64205 L .46576 .64181 L F
.46576 .64204 m .46641 .64095 L .46338 .6403 L F
.46576 .64181 m .46579 .64205 L .46469 .64346 L F
.46579 .64206 m .4658 .64203 L .46576 .64204 L F
.019 0 0 r
.46599 .64173 m .4659 .64199 L .4658 .64174 L F
.46887 .64089 m .4658 .64174 L .46978 .64016 L F
.46809 .64151 m .46684 .64164 L .46887 .64089 L F
.46684 .64164 m .4658 .64174 L .46887 .64089 L F
0 0 0 r
.4658 .64203 m .46581 .64202 L .46576 .64204 L F
.46581 .64202 m .46641 .64095 L .46577 .64204 L F
.46581 .64202 m .46577 .64204 L .46576 .64204 L F
.019 0 0 r
.4659 .64199 m .46581 .64225 L .4658 .64203 L F
.46809 .64151 m .46581 .64225 L .46599 .64173 L F
0 0 0 r
.4659 .64199 m .46581 .64225 L .46731 .64115 L F
.4658 .64203 m .46581 .64225 L .46547 .64261 L F
.4637 .6433 m .46581 .64225 L .46579 .64206 L F
.4658 .64203 m .46547 .64261 L .46469 .64346 L F
.973 .663 .344 r
.46386 .64145 m .4637 .6433 L .46338 .6403 L F
0 0 0 r
.4637 .6433 m .46579 .64206 L .46338 .6403 L F
.46579 .64206 m .46731 .64115 L .46641 .64095 L F
.46581 .64225 m .4632 .64513 L .46469 .64346 L F
.282 .02 .326 r
.4637 .6433 m .46358 .64471 L .46581 .64225 L F
.038 .181 .685 r
.18668 .59597 m .18587 .59754 L .18483 .59395 L F
.206 .402 .835 r
.18668 .59597 m .18857 .59943 L .18587 .59754 L F
.519 .411 .671 r
.18857 .59943 m .18632 .60016 L .18587 .59754 L F
.635 .072 0 r
.20314 .60958 m .2075 .61212 L .20575 .61185 L F
.733 .625 .739 r
.81392 .4281 m .81648 .42516 L .8138 .42573 L F
.547 .341 .552 r
.33684 .60573 m .33454 .60354 L .33735 .60326 L F
.33684 .60573 m .33438 .60625 L .33454 .60354 L F
.491 .308 .56 r
.33922 .59735 m .33926 .59995 L .33697 .60041 L F
.497 .38 .65 r
.33926 .59995 m .33735 .60326 L .33697 .60041 L F
.524 .554 .828 r
.35126 .55614 m .35063 .56006 L .34913 .55672 L F
.35126 .55614 m .35281 .55971 L .35063 .56006 L F
.309 .41 .803 r
.35351 .56216 m .35063 .56006 L .35281 .55971 L F
.51 .699 .955 r
.3428 .5414 m .34395 .54456 L .34245 .54148 L F
.34351 .54125 m .34368 .54256 L .3428 .5414 L F
.34368 .54256 m .34369 .54266 L .34297 .54188 L F
.34369 .54266 m .34395 .54456 L .34321 .54252 L F
.34369 .54266 m .34321 .54252 L .34297 .54188 L F
0 .07 .627 r
.34383 .54257 m .34395 .54456 L .34625 .54421 L F
.34383 .54257 m .34388 .54265 L .34395 .54456 L F
.51 .699 .955 r
.34388 .54277 m .34625 .54421 L .34395 .54456 L F
0 .07 .627 r
.34388 .54265 m .34492 .54456 L .34395 .54456 L F
.51 .699 .955 r
.34369 .54266 m .34388 .54277 L .34395 .54456 L F
.736 .31 .237 r
.34383 .54257 m .34371 .54259 L .34417 .54319 L F
.205 0 .125 r
.34386 .5426 m .34382 .54261 L .34383 .54257 L F
.51 .699 .955 r
.34368 .54256 m .34382 .54261 L .34369 .54266 L F
.736 .31 .237 r
.34374 .54258 m .34381 .54269 L .34371 .54259 L F
.34383 .54257 m .34382 .54261 L .34374 .54258 L F
.562 .669 .91 r
.34777 .54178 m .34625 .54421 L .34383 .54257 L F
.51 .699 .955 r
.34386 .5426 m .34625 .54421 L .34369 .54266 L F
.56 .684 .922 r
.34643 .54206 m .34625 .54421 L .34466 .5425 L F
.562 .669 .91 r
.34777 .54178 m .34875 .54367 L .34625 .54421 L F
.56 .684 .922 r
.34643 .54206 m .34875 .54367 L .34625 .54421 L F
.34651 .54111 m .34722 .54193 L .34643 .54206 L F
.34722 .54193 m .34875 .54367 L .34643 .54206 L F
.205 0 .125 r
.34746 .54213 m .34487 .54244 L .34685 .54199 L F
.431 .132 .355 r
.34974 .54192 m .34777 .54178 L .34875 .54367 L F
.424 .623 .935 r
.34774 .54193 m .34875 .54367 L .34722 .54193 L F
.51 .699 .955 r
.34466 .5425 m .34625 .54421 L .34386 .5426 L F
.607 .527 .738 r
.34395 .54456 m .34702 .54728 L .34625 .54421 L F
.559 .567 .818 r
.34875 .54367 m .34714 .54692 L .34625 .54421 L F
.34875 .54367 m .34714 .54692 L .34625 .54421 L F
.673 .635 .804 r
.34902 .54579 m .35128 .5488 L .34702 .54728 L F
0 0 0 r
.34702 .54728 m .34902 .54579 L .34714 .54692 L F
.673 .635 .804 r
.34902 .54579 m .34702 .54728 L .34714 .54692 L F
0 0 0 r
.34702 .54728 m .3485 .54648 L .34902 .54579 L F
.376 .415 .774 r
.34702 .54728 m .3485 .54648 L .34625 .54421 L F
.589 .173 .222 r
.34937 .54416 m .34534 .54446 L .34765 .54191 L F
.34789 .54196 m .34765 .54191 L .34777 .54178 L F
.424 .623 .935 r
.34951 .54233 m .34875 .54367 L .34776 .54196 L F
.34789 .54196 m .34776 .54196 L .34774 .54193 L F
.34951 .54233 m .34776 .54196 L .34789 .54196 L F
.34974 .54192 m .34951 .54233 L .34774 .54193 L F
.431 .132 .355 r
.34974 .54192 m .34937 .54416 L .34789 .54196 L F
.34974 .54192 m .34789 .54196 L .34777 .54178 L F
.589 .173 .222 r
.34937 .54416 m .34765 .54191 L .34789 .54196 L F
.205 0 .125 r
.34771 .54185 m .34722 .54193 L .34777 .54178 L F
.34722 .54193 m .3471 .54193 L .34777 .54178 L F
.424 .623 .935 r
.34935 .54182 m .34722 .54193 L .34651 .54111 L F
.34974 .54192 m .34722 .54193 L .34935 .54182 L F
.205 0 .125 r
.34722 .54193 m .34685 .54199 L .3471 .54193 L F
.34746 .54213 m .34685 .54199 L .34771 .54185 L F
.34487 .54244 m .34383 .54257 L .34669 .542 L F
.34487 .54244 m .34669 .542 L .34777 .54178 L F
.56 .684 .922 r
.34651 .54111 m .34643 .54206 L .34351 .54125 L F
.34643 .54206 m .34466 .5425 L .34351 .54125 L F
.51 .699 .955 r
.34455 .54238 m .34466 .5425 L .34386 .5426 L F
.205 0 .125 r
.34534 .54446 m .34386 .5426 L .34746 .54213 L F
.34386 .5426 m .34383 .54257 L .34746 .54213 L F
.736 .31 .237 r
.34382 .54261 m .34381 .54269 L .34374 .54258 L F
.51 .699 .955 r
.34351 .54125 m .34455 .54238 L .34382 .54261 L F
.34351 .54125 m .34382 .54261 L .34368 .54256 L F
.205 0 .125 r
.34396 .54273 m .34381 .54269 L .34382 .54261 L F
.34396 .54273 m .34382 .54261 L .34386 .5426 L F
.736 .31 .237 r
.34417 .54319 m .34064 .54294 L .34492 .54456 L F
.34371 .54259 m .34064 .54294 L .34417 .54319 L F
0 .553 .756 r
.34395 .54456 m .34492 .54456 L .34095 .54418 L F
.34068 .54416 m .34095 .54418 L .3403 .54411 L F
.34395 .54456 m .34095 .54418 L .34068 .54416 L F
.205 0 .125 r
.34534 .54446 m .34332 .54536 L .34351 .54433 L F
.709 .968 .728 r
.34064 .54294 m .3403 .54411 L .34095 .54418 L F
.34314 .54389 m .34095 .54418 L .34492 .54456 L F
.34064 .54294 m .34095 .54418 L .34314 .54389 L F
.205 0 .125 r
.34532 .54444 m .34351 .54433 L .3436 .54382 L F
.34467 .54368 m .3436 .54382 L .34381 .54269 L F
.34532 .54444 m .3436 .54382 L .34467 .54368 L F
.34534 .54446 m .34351 .54433 L .34532 .54444 L F
.34534 .54446 m .34381 .54269 L .34396 .54273 L F
.736 .31 .237 r
.34371 .54259 m .34332 .54536 L .34064 .54294 L F
.34381 .54269 m .34332 .54536 L .34371 .54259 L F
.51 .699 .955 r
.34368 .54256 m .34368 .54256 L .3428 .5414 L F
.34368 .54256 m .34297 .54188 L .3428 .5414 L F
.125 0 0 r
.22705 .62337 m .22669 .62313 L .22606 .6228 L F
.22705 .62337 m .22931 .62337 L .22669 .62313 L F
.43 0 .039 r
.17753 .82432 m .1802 .82431 L .17795 .82393 L F
.554 .413 .644 r
.32015 .62775 m .32069 .63101 L .31836 .63144 L F
.58 .447 .665 r
.32069 .63101 m .31851 .63405 L .31836 .63144 L F
.47 .326 .602 r
.34724 .57253 m .34718 .576 L .34946 .5753 L F
.34724 .57253 m .34718 .576 L .34946 .5753 L F
.325 .315 .694 r
.15326 .5944 m .15425 .59026 L .15261 .59078 L F
.15326 .5944 m .15489 .59412 L .15425 .59026 L F
.224 .168 .581 r
.15819 .59613 m .15686 .59743 L .15636 .59724 L F
0 .328 .813 r
.15636 .59724 m .15686 .59743 L .15679 .59737 L F
0 0 .332 r
.15668 .59733 m .15819 .59613 L .15636 .59724 L F
.15682 .59736 m .15819 .59613 L .15635 .5976 L F
.44 .507 .832 r
.15682 .59736 m .15686 .59743 L .15819 .59613 L F
0 0 .332 r
.15787 .59683 m .15819 .59613 L .15682 .59736 L F
.44 .507 .832 r
.15489 .59412 m .15682 .59736 L .15819 .59613 L F
0 .328 .813 r
.15636 .59724 m .15679 .59737 L .15326 .5944 L F
0 0 .332 r
.15635 .5976 m .15668 .59733 L .15636 .59724 L F
.344 .456 .831 r
.15679 .59737 m .15686 .59743 L .15682 .59736 L F
0 0 .332 r
.15626 .60025 m .15787 .59683 L .15635 .5976 L F
.344 .456 .831 r
.15326 .5944 m .15679 .59737 L .15489 .59412 L F
.15679 .59737 m .15682 .59736 L .15489 .59412 L F
.481 0 0 r
.17836 .61203 m .17393 .60978 L .17675 .61256 L F
.298 .328 .724 r
.17675 .61256 m .17847 .61372 L .17836 .61203 L F
.462 .591 .896 r
.19506 .62537 m .19888 .62813 L .19695 .62532 L F
.224 .457 .873 r
.19695 .62532 m .19888 .62813 L .1997 .62667 L F
.41 .256 .559 r
.19888 .62813 m .20052 .629 L .1997 .62667 L F
.19888 .62813 m .19897 .63073 L .20052 .629 L F
0 0 .268 r
.27691 .61421 m .27574 .61275 L .27732 .61181 L F
.27691 .61421 m .27527 .61522 L .27574 .61275 L F
.893 .502 .06 r
.54774 .54185 m .5459 .53851 L .54802 .53914 L F
.336 0 .168 r
.31498 .5873 m .31668 .58787 L .3173 .58723 L F
.31498 .5873 m .31335 .58989 L .31668 .58787 L F
.193 .616 .946 r
.25594 .64207 m .25662 .64094 L .25415 .64098 L F
.25594 .64207 m .25825 .64213 L .25662 .64094 L F
.154 .625 .928 r
.25843 .64264 m .25594 .64207 L .25672 .64218 L F
.25843 .64264 m .25825 .64213 L .25594 .64207 L F
.697 .536 .665 r
.30288 .60192 m .30065 .60513 L .30073 .60323 L F
.606 .345 .495 r
.30389 .6405 m .30356 .64298 L .30108 .64292 L F
.572 .309 .48 r
.3071 .63989 m .30356 .64298 L .30389 .6405 L F
.439 .305 .601 r
.35376 .57531 m .3537 .57887 L .35144 .57959 L F
.031 0 0 r
.24779 .53505 m .2501 .53468 L .25211 .53388 L F
.026 0 0 r
.2501 .53468 m .25419 .53332 L .25211 .53388 L F
.625 .3 .4 r
.29882 .64288 m .29458 .64531 L .29504 .6437 L F
0 0 .1 r
.28608 .56357 m .28604 .56278 L .28594 .56206 L F
.052 0 0 r
.31179 .53781 m .31521 .53671 L .31358 .53694 L F
0 0 .272 r
.27301 .60047 m .27391 .60147 L .27407 .59922 L F
.27301 .60047 m .27284 .60305 L .27391 .60147 L F
.531 .348 .577 r
.33231 .60953 m .33221 .61201 L .32994 .61241 L F
.499 .4 .673 r
.33258 .6148 m .32994 .61241 L .33221 .61201 L F
.33258 .6148 m .33037 .61588 L .32994 .61241 L F
0 0 0 r
.28325 .53294 m .28556 .53253 L .28721 .53209 L F
.637 .823 .972 r
.8186 .42047 m .82064 .4179 L .81756 .41884 L F
.8186 .42047 m .82169 .41924 L .82064 .4179 L F
.407 .26 .567 r
.24339 .64095 m .24541 .64246 L .24682 .64121 L F
.24339 .64095 m .24682 .64121 L .24141 .64203 L F
.288 .176 .548 r
.15184 .5883 m .1534 .58786 L .1537 .58444 L F
.34 .349 .724 r
.15184 .5883 m .15425 .59026 L .1534 .58786 L F
.391 .351 .694 r
.15261 .59078 m .15425 .59026 L .15184 .5883 L F
.13 0 .05 r
.28799 .61514 m .28607 .61598 L .28492 .61788 L F
.824 .627 .637 r
.55256 .56627 m .55108 .56957 L .55438 .56972 L F
.801 .639 .682 r
.5503 .5719 m .55438 .56972 L .55108 .56957 L F
.5503 .5719 m .55412 .57255 L .55438 .56972 L F
.79 .996 .865 r
.22533 .72771 m .22717 .72682 L .22485 .72889 L F
.303 .469 .859 r
.22485 .72889 m .22711 .72982 L .22533 .72771 L F
.496 .804 1 r
.28949 .53253 m .29177 .53209 L .29337 .53307 L F
.042 .581 .849 r
.29405 .53271 m .29337 .53307 L .29177 .53209 L F
.29405 .53271 m .29526 .53328 L .29337 .53307 L F
.867 .789 .772 r
.83633 .41307 m .83842 .40984 L .83561 .40964 L F
.76 .714 .809 r
.26553 .66724 m .26966 .66747 L .26794 .66656 L F
0 0 0 r
.26584 .66733 m .26553 .66724 L .26794 .66656 L F
.908 .88 .795 r
.26508 .66711 m .26508 .66787 L .26553 .66724 L F
.689 .239 .178 r
.26508 .66787 m .26574 .67197 L .26506 .67026 L F
.402 .427 .772 r
.26506 .67026 m .26553 .66724 L .26508 .66787 L F
.26506 .67026 m .26574 .67197 L .26553 .66724 L F
.709 .954 .951 r
.26632 .6695 m .27134 .66781 L .26966 .66747 L F
.26632 .6695 m .26966 .66747 L .26574 .67197 L F
.76 .714 .809 r
.26553 .66724 m .26569 .67076 L .26966 .66747 L F
.26569 .67076 m .26574 .67197 L .26715 .67036 L F
.26569 .67076 m .26715 .67036 L .26966 .66747 L F
.788 .776 .842 r
.26222 .67303 m .26211 .67103 L .26506 .67026 L F
.667 .397 .503 r
.26211 .67103 m .26336 .6714 L .26506 .67026 L F
.968 .934 .675 r
.26498 .67227 m .26506 .67026 L .26701 .67251 L F
.667 .397 .503 r
.26336 .6714 m .26701 .67251 L .26553 .67081 L F
.26336 .6714 m .26553 .67081 L .26506 .67026 L F
0 0 0 r
.26367 .66812 m .26553 .66724 L .26584 .66733 L F
.908 .88 .795 r
.26505 .66371 m .26508 .66711 L .26553 .66724 L F
.813 .707 .748 r
.26222 .67303 m .26396 .67721 L .26013 .67628 L F
.807 .719 .768 r
.26013 .67628 m .26396 .67721 L .26143 .68015 L F
.488 .258 .49 r
.26143 .68015 m .26396 .67721 L .26375 .67967 L F
.539 .567 .832 r
.26629 .67669 m .26396 .67721 L .26222 .67303 L F
.448 .225 .481 r
.26375 .67967 m .26396 .67721 L .26629 .67669 L F
.807 .719 .768 r
.26013 .67628 m .26143 .68015 L .26375 .67967 L F
.26013 .67628 m .26375 .67967 L .26212 .67912 L F
.788 .376 .269 r
.26013 .67628 m .26396 .67721 L .26212 .67912 L F
.213 .706 .921 r
.23913 .62428 m .24137 .62424 L .24314 .6248 L F
.227 .675 .952 r
.24352 .62397 m .24314 .6248 L .24137 .62424 L F
.24352 .62397 m .2452 .62489 L .24314 .6248 L F
.5 .717 .969 r
.79413 .42694 m .795 .42848 L .79663 .4266 L F
.462 .658 .946 r
.795 .42848 m .79764 .42835 L .79663 .4266 L F
.946 .661 .206 r
.4952 .58147 m .4954 .58415 L .49608 .58407 L F
.4952 .58147 m .4954 .58415 L .49608 .58407 L F
.526 .809 .998 r
.16764 .60585 m .16883 .60631 L .16705 .60534 L F
.422 .691 .975 r
.16883 .60631 m .16922 .60468 L .16705 .60534 L F
.16883 .60631 m .17072 .6061 L .16922 .60468 L F
.359 .158 .466 r
.30518 .58792 m .30452 .59067 L .30283 .59122 L F
.428 .266 .557 r
.30452 .59067 m .30272 .59397 L .30283 .59122 L F
.423 .5 .834 r
.18673 .61777 m .18706 .61955 L .18866 .61752 L F
.457 .549 .862 r
.18706 .61955 m .1908 .62092 L .18866 .61752 L F
.801 .309 0 r
.22912 .72778 m .23112 .729 L .23273 .73153 L F
.85 .647 .628 r
.55391 .57543 m .55573 .57602 L .55412 .57255 L F
.062 .126 .618 r
.35074 .58733 m .35267 .59068 L .35091 .5912 L F
0 0 .302 r
.35217 .59181 m .35091 .5912 L .35267 .59068 L F
.35217 .59181 m .35073 .59391 L .35091 .5912 L F
.28 0 .205 r
.18151 .55688 m .18484 .55307 L .18282 .55403 L F
.625 .3 .4 r
.29882 .64288 m .29706 .64572 L .29458 .64531 L F
.592 .273 .399 r
.30108 .64292 m .29706 .64572 L .29882 .64288 L F
0 0 0 r
.51929 .52321 m .52079 .52069 L .51838 .52368 L F
.51645 .52537 m .51838 .52368 L .51809 .52522 L F
.647 .305 .378 r
.51838 .52368 m .52089 .52588 L .51809 .52522 L F
0 0 0 r
.51645 .52537 m .51929 .52321 L .51838 .52368 L F
.578 .337 .514 r
.28049 .62149 m .28302 .62132 L .28339 .61885 L F
.105 0 .351 r
.28339 .61885 m .28471 .61981 L .28492 .61788 L F
.28339 .61885 m .28302 .62132 L .28471 .61981 L F
0 0 .004 r
.2679 .62723 m .26749 .62994 L .26714 .63037 L F
.052 .557 .881 r
.26749 .62994 m .26949 .63099 L .26714 .63037 L F
.67 .503 .65 r
.50294 .5976 m .50318 .60035 L .50553 .59724 L F
.71 .371 .402 r
.4657 .63804 m .46742 .64096 L .46962 .63724 L F
.304 0 .161 r
.19154 .56892 m .188 .57198 L .18941 .56958 L F
.459 .277 .546 r
.35141 .55371 m .34913 .55672 L .34922 .55436 L F
.947 .611 .352 r
.20654 .61779 m .20803 .61583 L .20726 .61476 L F
.20654 .61779 m .20888 .61887 L .20803 .61583 L F
.05 0 0 r
.22195 .55722 m .22 .55825 L .21834 .55832 L F
.581 .563 .799 r
.22337 .55328 m .22436 .55697 L .22195 .55722 L F
0 0 0 r
.22436 .55697 m .22 .55825 L .22195 .55722 L F
.002 0 .268 r
.28997 .61125 m .28844 .61276 L .28799 .61514 L F
.307 0 .082 r
.31993 .55632 m .32219 .55587 L .32358 .55382 L F
.202 0 .022 r
.32358 .55382 m .32437 .55511 L .32585 .5532 L F
.32358 .55382 m .32219 .55587 L .32437 .55511 L F
0 0 .44 r
.27547 .59465 m .27543 .59733 L .27638 .59607 L F
.156 0 0 r
.27543 .59733 m .2761 .59855 L .27638 .59607 L F
.27543 .59733 m .27407 .59922 L .2761 .59855 L F
.131 0 0 r
.53359 .52131 m .53619 .52122 L .53595 .52076 L F
.53359 .52131 m .53223 .52245 L .53619 .52122 L F
0 0 0 r
.23437 .55031 m .23237 .55148 L .236 .54879 L F
.004 0 0 r
.23806 .54843 m .23437 .55031 L .236 .54879 L F
.269 .154 .533 r
.81186 .40399 m .81414 .40327 L .81366 .40242 L F
.81186 .40399 m .81213 .4062 L .81414 .40327 L F
.659 .829 .965 r
.27802 .59433 m .27547 .59465 L .27595 .59297 L F
0 0 .44 r
.27547 .59465 m .27638 .59607 L .27802 .59433 L F
.42 .786 .995 r
.27663 .59173 m .27847 .59268 L .27595 .59297 L F
.765 .989 .892 r
.27725 .59234 m .27847 .59268 L .27663 .59173 L F
.741 .988 .891 r
.27917 .59287 m .27802 .59433 L .27847 .59268 L F
.473 .765 .994 r
.27847 .59268 m .27802 .59433 L .27595 .59297 L F
.468 .331 .611 r
.27638 .59607 m .27847 .59268 L .27802 .59433 L F
.27638 .59607 m .27879 .59537 L .27847 .59268 L F
.765 .989 .892 r
.27872 .59378 m .27847 .59268 L .27725 .59234 L F
.741 .988 .891 r
.27924 .59278 m .27917 .59287 L .27847 .59268 L F
.827 .652 .665 r
.54261 .56328 m .53873 .56614 L .53881 .56295 L F
.54261 .56328 m .54131 .56673 L .53873 .56614 L F
.464 .288 .556 r
.34148 .59927 m .33922 .59735 L .3418 .59679 L F
.34148 .59927 m .33926 .59995 L .33922 .59735 L F
.43 0 0 r
.26949 .63099 m .2719 .63125 L .27296 .63055 L F
.297 0 0 r
.27296 .63055 m .27349 .63176 L .27512 .63001 L F
.27296 .63055 m .2719 .63125 L .27349 .63176 L F
.571 .189 .278 r
.51929 .52321 m .52343 .52213 L .52079 .52069 L F
.5 .592 .878 r
.28076 .5492 m .28169 .54656 L .27943 .54714 L F
.28076 .5492 m .28362 .54965 L .28169 .54656 L F
.781 .848 .902 r
.28054 .55919 m .27916 .55936 L .2821 .55755 L F
.189 .718 .729 r
.22244 .53746 m .22476 .53693 L .22665 .5366 L F
.111 0 0 r
.22476 .53693 m .22837 .53652 L .22665 .5366 L F
.658 .201 .156 r
.79743 .41299 m .80048 .41503 L .80119 .4133 L F
.346 0 .04 r
.80119 .4133 m .80363 .41413 L .8041 .4128 L F
.80119 .4133 m .80048 .41503 L .80363 .41413 L F
.742 .645 .752 r
.77999 .40955 m .77911 .4111 L .77718 .40834 L F
.332 .643 .966 r
.2227 .63747 m .22687 .63941 L .22514 .63825 L F
.522 .784 .992 r
.22514 .63825 m .22687 .63941 L .2293 .63876 L F
.866 .729 .709 r
.34406 .56282 m .3413 .55882 L .34408 .56046 L F
.559 .364 .574 r
.32269 .62488 m .32301 .62785 L .32015 .62775 L F
.568 .419 .639 r
.32489 .62145 m .32573 .62455 L .32269 .62488 L F
.579 .379 .574 r
.3256 .62736 m .32269 .62488 L .32573 .62455 L F
.3256 .62736 m .32301 .62785 L .32269 .62488 L F
.78 .781 .854 r
.80866 .42112 m .81272 .4202 L .81141 .41837 L F
.726 .761 .881 r
.81141 .41837 m .81272 .4202 L .81509 .41888 L F
.918 .757 .665 r
.54929 .56844 m .55256 .56627 L .55115 .56489 L F
.54929 .56844 m .55108 .56957 L .55256 .56627 L F
.565 .421 .644 r
.32319 .63039 m .32015 .62775 L .32301 .62785 L F
.32319 .63039 m .32069 .63101 L .32015 .62775 L F
.292 .415 .816 r
.31364 .58001 m .31308 .5801 L .3145 .57997 L F
.655 .318 .39 r
.29393 .58175 m .29648 .58378 L .29725 .58121 L F
.297 .032 .332 r
.29725 .58121 m .29912 .5813 L .2998 .57842 L F
.319 .015 .284 r
.29648 .58378 m .29912 .5813 L .29725 .58121 L F
.015 0 .296 r
.28321 .58811 m .28377 .58911 L .28447 .58719 L F
.28321 .58811 m .28272 .59066 L .28377 .58911 L F
.637 .465 .633 r
.33512 .60902 m .33221 .61201 L .33231 .60953 L F
.458 0 0 r
.53968 .52032 m .54223 .52131 L .54361 .52011 L F
.596 .088 .015 r
.54223 .52131 m .54596 .52063 L .54361 .52011 L F
.152 0 .261 r
.15873 .60269 m .15881 .60304 L .16092 .6038 L F
.918 .611 .448 r
.55378 .5261 m .55402 .52851 L .55659 .52936 L F
.964 .726 .528 r
.55437 .53081 m .55659 .52936 L .55402 .52851 L F
.55437 .53081 m .55583 .53188 L .55659 .52936 L F
.323 .482 .863 r
.19431 .62353 m .19506 .62537 L .19591 .62351 L F
.447 .631 .933 r
.19506 .62537 m .19695 .62532 L .19591 .62351 L F
.771 .386 .326 r
.54226 .53313 m .54138 .53477 L .53903 .53143 L F
.54226 .53313 m .54268 .53511 L .54138 .53477 L F
.815 .418 .3 r
.54561 .53571 m .54268 .53511 L .54226 .53313 L F
.635 .09 0 r
.32724 .54705 m .3227 .54524 L .32545 .54735 L F
.083 0 0 r
.19425 .54818 m .19012 .55044 L .19227 .54974 L F
.133 0 0 r
.19444 .54907 m .19425 .54818 L .19227 .54974 L F
.19444 .54907 m .19659 .54778 L .19425 .54818 L F
.317 0 0 r
.52492 .5243 m .52334 .52564 L .52089 .52588 L F
0 .075 .571 r
.5259 .5252 m .52729 .52637 L .52492 .5243 L F
.52822 .52735 m .52729 .52637 L .5259 .5252 L F
0 .343 .768 r
.53092 .52855 m .5299 .52763 L .52729 .52637 L F
.54 0 0 r
.52729 .52637 m .5299 .52763 L .52855 .52743 L F
.932 .617 .158 r
.52822 .52735 m .52846 .52914 L .52729 .52637 L F
0 .343 .768 r
.53092 .52855 m .52729 .52637 L .52846 .52914 L F
.54 0 0 r
.52729 .52637 m .52855 .52743 L .52575 .527 L F
.654 .194 .148 r
.52492 .5243 m .52729 .52637 L .52334 .52564 L F
.466 .885 .919 r
.2731 .64967 m .27652 .64887 L .27581 .64849 L F
.58 .941 .907 r
.27581 .64849 m .27652 .64887 L .27831 .64748 L F
.084 0 .428 r
.18267 .57499 m .18249 .5775 L .18156 .57534 L F
0 0 0 r
.18368 .57322 m .18267 .57499 L .18156 .57534 L F
.041 0 .431 r
.18249 .5775 m .18127 .57897 L .18156 .57534 L F
.509 .529 .813 r
.54448 .58478 m .54548 .58077 L .54296 .58149 L F
.54448 .58478 m .54678 .58442 L .54548 .58077 L F
.853 .764 .764 r
.54763 .55301 m .55231 .5505 L .55126 .54977 L F
.54763 .55301 m .54999 .55401 L .55231 .5505 L F
.923 .968 .774 r
.55362 .54623 m .55231 .5505 L .55491 .54721 L F
.55362 .54623 m .55126 .54977 L .55231 .5505 L F
.41 .209 .494 r
.31469 .54732 m .31443 .55025 L .31264 .54804 L F
.79 .714 .78 r
.1802 .82431 m .18169 .8275 L .18414 .8244 L F
.501 .304 .546 r
.18414 .8244 m .18393 .82718 L .18169 .8275 L F
.547 .369 .592 r
.4998 .56031 m .50243 .55624 L .50041 .55758 L F
.213 0 0 r
.2269 .55093 m .22442 .55381 L .22441 .55381 L F
.22499 .5522 m .22441 .55381 L .22337 .55328 L F
.2269 .55093 m .22441 .55381 L .22499 .5522 L F
0 .051 .606 r
.22392 .55228 m .22441 .55381 L .22337 .55328 L F
.22441 .55381 m .22442 .55382 L .22337 .55328 L F
.22442 .55382 m .22489 .55531 L .22388 .55396 L F
.22442 .55382 m .22388 .55396 L .22337 .55328 L F
0 0 0 r
.22835 .55076 m .2269 .55093 L .22927 .5507 L F
.509 .874 .982 r
.23094 .55106 m .22804 .55096 L .22835 .55076 L F
0 0 0 r
.22835 .55076 m .22804 .55096 L .2269 .55093 L F
.22804 .55096 m .22577 .55234 L .22589 .5522 L F
.22804 .55096 m .22589 .5522 L .2269 .55093 L F
.509 .874 .982 r
.23094 .55106 m .22835 .55076 L .22927 .5507 L F
.459 .856 .972 r
.23216 .5502 m .2282 .55086 L .23094 .55106 L F
.509 .874 .982 r
.22804 .55096 m .22772 .55094 L .22835 .55076 L F
.459 .856 .972 r
.2282 .55086 m .22772 .55094 L .22804 .55096 L F
.2282 .55086 m .22804 .55096 L .23094 .55106 L F
.323 0 0 r
.22809 .55088 m .22787 .55088 L .22772 .55094 L F
0 0 0 r
.22465 .55375 m .22442 .55381 L .2269 .55093 L F
.22818 .55087 m .22465 .55375 L .22577 .55234 L F
.22824 .55085 m .22465 .55375 L .22818 .55087 L F
.22465 .55375 m .22427 .55406 L .22442 .55381 L F
.22427 .55406 m .22407 .55422 L .22441 .55383 L F
.569 .422 .642 r
.22392 .55228 m .22407 .55422 L .22427 .55406 L F
.959 .655 .233 r
.22422 .55436 m .22429 .55415 L .22392 .55228 L F
.22429 .55415 m .22441 .55381 L .22392 .55228 L F
0 0 0 r
.22427 .55406 m .22441 .55383 L .22442 .55381 L F
.959 .655 .233 r
.22422 .55436 m .22489 .55531 L .22442 .55382 L F
.22441 .55383 m .22442 .55382 L .22441 .55381 L F
.569 .422 .642 r
.22392 .55228 m .22427 .55406 L .22824 .55085 L F
.959 .655 .233 r
.22422 .55436 m .22442 .55382 L .22441 .55383 L F
0 0 0 r
.22835 .55076 m .22824 .55085 L .22818 .55087 L F
.569 .422 .642 r
.22793 .55091 m .22824 .55085 L .22835 .55076 L F
.323 0 0 r
.2282 .55086 m .22817 .55087 L .22809 .55088 L F
.22817 .55087 m .2281 .55088 L .22809 .55088 L F
.569 .422 .642 r
.22392 .55228 m .22824 .55085 L .22793 .55091 L F
.323 0 0 r
.22817 .55087 m .22813 .55087 L .2281 .55088 L F
.569 .422 .642 r
.22392 .55228 m .22793 .55091 L .22592 .55174 L F
.22793 .55091 m .22835 .55076 L .22806 .55088 L F
.22793 .55091 m .22806 .55088 L .22592 .55174 L F
.355 .821 .745 r
.22787 .55088 m .22835 .55076 L .22772 .55094 L F
.22787 .55088 m .22806 .55088 L .22835 .55076 L F
.323 0 0 r
.22813 .55087 m .22787 .55088 L .22806 .55088 L F
.22813 .55087 m .22806 .55088 L .22809 .55088 L F
.355 .821 .745 r
.22787 .55088 m .22592 .55174 L .22806 .55088 L F
.323 0 0 r
.23216 .5502 m .22857 .55077 L .2282 .55086 L F
.22857 .55077 m .22787 .55088 L .2282 .55086 L F
.213 0 0 r
.22442 .55381 m .22407 .55422 L .22337 .55328 L F
0 0 .324 r
.22337 .55328 m .22407 .55422 L .22392 .55228 L F
.959 .655 .233 r
.2238 .55378 m .22422 .55436 L .22392 .55228 L F
.901 .986 .769 r
.26024 .68028 m .26143 .68015 L .25896 .68342 L F
.704 .542 .666 r
.26143 .68015 m .26162 .68313 L .25896 .68342 L F
.422 .831 .974 r
.26212 .67912 m .26143 .68015 L .26024 .68028 L F
.26212 .67912 m .26375 .67967 L .26143 .68015 L F
.544 .421 .664 r
.26375 .67967 m .26162 .68313 L .26143 .68015 L F
.244 .406 .826 r
.17072 .6061 m .17247 .60952 L .17348 .60802 L F
.201 .347 .788 r
.17247 .60952 m .17393 .60978 L .17348 .60802 L F
.349 .06 .326 r
.27161 .5561 m .26966 .55677 L .27236 .5543 L F
0 0 0 r
.27505 .55152 m .27346 .55346 L .27236 .5543 L F
.034 0 .222 r
.27346 .55346 m .27161 .5561 L .27236 .5543 L F
.679 .167 .014 r
.26966 .55677 m .26823 .55712 L .26642 .55596 L F
.191 0 0 r
.27161 .5561 m .26823 .55712 L .26966 .55677 L F
.975 .787 .587 r
.55559 .54095 m .55495 .54398 L .55656 .54439 L F
.935 .901 .768 r
.55495 .54398 m .55491 .54721 L .55656 .54439 L F
.474 .753 .991 r
.26646 .5334 m .26416 .53393 L .26428 .53381 L F
.26646 .5334 m .26769 .53419 L .26416 .53393 L F
.095 .652 .728 r
.21126 .61861 m .21282 .61849 L .20888 .61887 L F
.22 .694 .938 r
.21323 .61779 m .21282 .61849 L .21126 .61861 L F
.21323 .61779 m .21493 .6185 L .21282 .61849 L F
0 0 .427 r
.26642 .55596 m .26655 .55274 L .26556 .55445 L F
0 0 0 r
.25465 .53386 m .257 .53335 L .25637 .53334 L F
.011 0 0 r
.25545 .53332 m .25637 .53334 L .25816 .53333 L F
.213 .737 .827 r
.25637 .53334 m .2587 .53298 L .26034 .53306 L F
0 0 0 r
.257 .53335 m .2587 .53298 L .25637 .53334 L F
.011 0 0 r
.25419 .53332 m .25637 .53334 L .25545 .53332 L F
.213 .737 .827 r
.25637 .53334 m .26034 .53306 L .25816 .53333 L F
.831 .629 .631 r
.55021 .5746 m .55412 .57255 L .5503 .5719 L F
.55021 .5746 m .55391 .57543 L .55412 .57255 L F
.598 .428 .623 r
.33037 .61588 m .33059 .61831 L .3281 .61854 L F
.565 .331 .52 r
.33059 .61831 m .32731 .62103 L .3281 .61854 L F
.687 .801 .936 r
.34096 .56559 m .33905 .56704 L .33728 .5655 L F
.81 .851 .393 r
.34096 .56559 m .33977 .56918 L .33905 .56704 L F
.78 .893 .924 r
.77696 .4056 m .77507 .40825 L .77288 .40405 L F
.77696 .4056 m .77723 .40662 L .77507 .40825 L F
.585 .648 .879 r
.77718 .40834 m .77507 .40825 L .77723 .40662 L F
.634 .186 .169 r
.83124 .40692 m .83358 .40781 L .83496 .40691 L F
.851 .514 .416 r
.83358 .40781 m .83561 .40964 L .83496 .40691 L F
.48 .374 .657 r
.2998 .57842 m .30211 .57772 L .30186 .57483 L F
.455 .201 .439 r
.29912 .5813 m .30211 .57772 L .2998 .57842 L F
.727 .746 .867 r
.8292 .41208 m .82978 .41561 L .83285 .41261 L F
.814 .5 .458 r
.79003 .41147 m .79353 .41 L .79006 .40883 L F
.79003 .41147 m .7938 .41252 L .79353 .41 L F
.771 .467 .472 r
.79353 .41 m .7938 .41252 L .79743 .41299 L F
.118 0 .239 r
.18632 .60016 m .18533 .60316 L .18424 .60315 L F
.116 .24 .716 r
.18533 .60316 m .18596 .60475 L .18424 .60315 L F
.369 .275 .616 r
.18596 .60475 m .18434 .60553 L .18424 .60315 L F
0 0 .041 r
.18711 .6004 m .18632 .60016 L .18857 .59943 L F
.18711 .6004 m .18533 .60316 L .18632 .60016 L F
.596 .088 .015 r
.54223 .52131 m .54459 .52197 L .54596 .52063 L F
.698 .213 .091 r
.54596 .52063 m .54459 .52197 L .54656 .52208 L F
.617 .859 .989 r
.79764 .42835 m .80128 .42856 L .8004 .42763 L F
.542 .761 .978 r
.80128 .42856 m .80298 .42656 L .8004 .42763 L F
.80128 .42856 m .80407 .42799 L .80298 .42656 L F
.497 .099 .216 r
.28606 .64613 m .28695 .64856 L .28431 .6483 L F
.28606 .64613 m .28848 .64609 L .28695 .64856 L F
.792 .746 .81 r
.83285 .41261 m .83633 .41307 L .83561 .40964 L F
.647 .456 .611 r
.30983 .63723 m .30971 .63979 L .3071 .63989 L F
.573 .325 .503 r
.31248 .63714 m .30971 .63979 L .30983 .63723 L F
.497 .38 .65 r
.33926 .59995 m .33957 .60268 L .33735 .60326 L F
.411 .154 .41 r
.33957 .60268 m .33684 .60573 L .33735 .60326 L F
.593 .555 .781 r
.18713 .60672 m .18482 .60726 L .18434 .60553 L F
.599 .731 .937 r
.18273 .59527 m .17831 .59421 L .1806 .59356 L F
.743 .76 .866 r
.18483 .59395 m .18273 .59527 L .1806 .59356 L F
.041 0 0 r
.32125 .5457 m .31709 .5465 L .31858 .54714 L F
.286 0 .146 r
.1849 .57426 m .18368 .57322 L .18584 .57256 L F
.1849 .57426 m .18267 .57499 L .18368 .57322 L F
.236 .716 .935 r
.25843 .64264 m .25963 .64205 L .25825 .64213 L F
.25843 .64264 m .26196 .64271 L .25963 .64205 L F
0 0 0 r
.21012 .55951 m .20652 .56095 L .20913 .55932 L F
.003 0 0 r
.20075 .56422 m .20055 .56328 L .20233 .56246 L F
.20075 .56422 m .19869 .56496 L .20055 .56328 L F
.872 .79 .768 r
.55111 .5808 m .55307 .58157 L .55194 .57819 L F
.839 .713 .725 r
.54932 .58354 m .55307 .58157 L .55111 .5808 L F
.54932 .58354 m .55092 .58514 L .55307 .58157 L F
.644 .626 .817 r
.3538 .54766 m .35128 .5488 L .34902 .54579 L F
.392 .387 .735 r
.35346 .55053 m .35128 .5488 L .3538 .54766 L F
.35346 .55053 m .35275 .55164 L .35128 .5488 L F
.478 .277 .529 r
.22863 .72636 m .22717 .72682 L .22912 .72778 L F
.556 .109 .145 r
.22912 .72778 m .22717 .72682 L .22533 .72771 L F
.524 .371 .616 r
.3251 .56325 m .3252 .56606 L .32285 .56659 L F
.193 .72 .843 r
.2307 .536 m .23539 .53594 L .23309 .53631 L F
.518 .393 .648 r
.33258 .6148 m .33059 .61831 L .33037 .61588 L F
.636 .417 .569 r
.27062 .54699 m .2734 .54501 L .2716 .54627 L F
.27062 .54699 m .27323 .54772 L .2734 .54501 L F
0 0 .126 r
.2734 .54501 m .27323 .54772 L .27389 .54571 L F
.2734 .54501 m .27389 .54571 L .2716 .54627 L F
.752 .657 .756 r
.20288 .63388 m .20642 .63477 L .20475 .63082 L F
.27 .383 .795 r
.20475 .63082 m .20642 .63477 L .2072 .63261 L F
.543 .692 .936 r
.20642 .63477 m .20948 .63446 L .2072 .63261 L F
.719 .717 .848 r
.78349 .40446 m .77957 .4037 L .78229 .40297 L F
.748 .968 .932 r
.78494 .40222 m .78349 .40446 L .78229 .40297 L F
.78494 .40222 m .78609 .40278 L .78349 .40446 L F
.539 .435 .685 r
.46338 .6403 m .46731 .64115 L .4657 .63804 L F
.394 .161 .438 r
.3076 .58672 m .30452 .59067 L .30518 .58792 L F
.39 .222 .529 r
.30984 .59658 m .31173 .59334 L .30981 .59445 L F
0 .197 .714 r
.28506 .5602 m .28497 .55871 L .2821 .55755 L F
.137 0 .259 r
.3446 .55072 m .34642 .55018 L .34702 .54728 L F
.41 0 .034 r
.3446 .55072 m .34616 .55226 L .34642 .55018 L F
.3446 .55072 m .3433 .55282 L .34616 .55226 L F
.179 .664 .926 r
.29943 .5356 m .30171 .53573 L .30335 .53646 L F
.322 .746 .974 r
.30383 .53525 m .30335 .53646 L .30171 .53573 L F
.30383 .53525 m .30585 .53631 L .30335 .53646 L F
.436 .218 .483 r
.23091 .55541 m .23286 .55631 L .2338 .55396 L F
.296 .414 .813 r
.76718 .40617 m .76866 .40977 L .77016 .40785 L F
.266 .369 .783 r
.76866 .40977 m .77137 .41144 L .77016 .40785 L F
.185 .385 .827 r
.76866 .40977 m .77179 .41343 L .77137 .41144 L F
.558 .654 .9 r
.21496 .63487 m .2168 .6374 L .21597 .63213 L F
.584 .742 .951 r
.21911 .63457 m .2168 .6374 L .21894 .63671 L F
.628 .415 .574 r
.31851 .63405 m .31846 .63657 L .31591 .63661 L F
.58 .447 .665 r
.32069 .63101 m .32093 .63366 L .31851 .63405 L F
.556 .356 .565 r
.32093 .63366 m .31846 .63657 L .31851 .63405 L F
.718 .607 .732 r
.176 .5825 m .17676 .58645 L .17284 .58553 L F
.587 .128 .131 r
.17676 .58645 m .17356 .58672 L .17284 .58553 L F
.17676 .58645 m .17521 .58781 L .17356 .58672 L F
0 0 .509 r
.177 .58275 m .17676 .58645 L .176 .5825 L F
.535 .446 .701 r
.177 .58275 m .17521 .58781 L .17676 .58645 L F
.31 .784 .926 r
.24195 .54842 m .23986 .54811 L .23806 .54843 L F
.347 .77 .975 r
.27551 .66413 m .27394 .66499 L .27263 .66341 L F
.27551 .66413 m .27625 .66471 L .27394 .66499 L F
.193 0 0 r
.27394 .66499 m .27625 .66471 L .2744 .66605 L F
.341 .184 .518 r
.15362 .5817 m .15537 .58106 L .15549 .57847 L F
.363 .232 .565 r
.15362 .5817 m .15546 .5837 L .15537 .58106 L F
.15362 .5817 m .1537 .58444 L .15546 .5837 L F
0 0 0 r
.27709 .55095 m .27346 .55346 L .27505 .55152 L F
.805 .963 .911 r
.29812 .60795 m .29725 .60967 L .29534 .60914 L F
.944 .725 .575 r
.54182 .57259 m .53999 .57209 L .54026 .56899 L F
.554 .854 .998 r
.82678 .40304 m .82494 .40468 L .82401 .40379 L F
.82678 .40304 m .82761 .40403 L .82494 .40468 L F
.375 0 .146 r
.32187 .58622 m .32045 .58486 L .31903 .58732 L F
.459 0 .015 r
.32187 .58622 m .32327 .58514 L .32045 .58486 L F
.573 .325 .503 r
.31248 .63714 m .31224 .63962 L .30971 .63979 L F
.562 .281 .446 r
.31591 .63661 m .31224 .63962 L .31248 .63714 L F
.07 .632 .771 r
.24941 .64099 m .24985 .64081 L .24747 .64098 L F
.24941 .64099 m .25117 .64092 L .24985 .64081 L F
0 .15 .686 r
.31008 .53537 m .31096 .53747 L .30819 .53574 L F
.31008 .53537 m .31179 .53781 L .31096 .53747 L F
.538 .53 .794 r
.29856 .57306 m .30186 .57483 L .30097 .57285 L F
0 0 .343 r
.29874 .57326 m .29856 .57306 L .30097 .57285 L F
.522 .901 .955 r
.25594 .6255 m .25132 .62611 L .25361 .62593 L F
.502 .909 .851 r
.25791 .62446 m .25594 .6255 L .25361 .62593 L F
.394 .26 .578 r
.27763 .62729 m .27984 .62382 L .27737 .62504 L F
.644 .465 .627 r
.3283 .62422 m .32489 .62145 L .32731 .62103 L F
.3283 .62422 m .32573 .62455 L .32489 .62145 L F
.801 .551 .56 r
.54561 .53571 m .54226 .53773 L .54268 .53511 L F
.54561 .53571 m .5459 .53851 L .54226 .53773 L F
.413 .461 .801 r
.32764 .56536 m .32691 .56835 L .3252 .56606 L F
.32764 .56536 m .32883 .56875 L .32691 .56835 L F
.415 .448 .786 r
.30688 .60114 m .30562 .60153 L .30367 .59663 L F
.736 .492 .56 r
.30688 .60114 m .30288 .60192 L .30562 .60153 L F
.877 .778 .749 r
.23517 .71338 m .23718 .71539 L .23603 .716 L F
.63 .748 .933 r
.2392 .71433 m .23718 .71539 L .23517 .71338 L F
.473 .262 .512 r
.34642 .55018 m .3485 .54648 L .34702 .54728 L F
.148 .655 .903 r
.26034 .53306 m .26254 .5331 L .26175 .53333 L F
.263 0 0 r
.2587 .53298 m .26254 .5331 L .26034 .53306 L F
.2587 .53298 m .26087 .53331 L .26254 .5331 L F
.198 .727 .763 r
.26087 .53331 m .26319 .53291 L .26254 .5331 L F
.26319 .53291 m .26482 .53263 L .26254 .5331 L F
.148 .655 .903 r
.26175 .53333 m .26254 .5331 L .26428 .53381 L F
.398 .802 .983 r
.26482 .53263 m .26428 .53381 L .26254 .5331 L F
.26482 .53263 m .26646 .5334 L .26428 .53381 L F
.199 .71 .893 r
.54011 .55108 m .54058 .55053 L .54297 .55112 L F
.63 .325 .435 r
.54297 .55112 m .54228 .5531 L .54011 .55108 L F
.725 .304 0 r
.54228 .5531 m .54058 .55053 L .54011 .55108 L F
.444 .631 .934 r
.30065 .60513 m .30191 .60652 L .29945 .60651 L F
.197 .723 .846 r
.23539 .53594 m .2376 .53569 L .23931 .53582 L F
.11 .66 .699 r
.2376 .53569 m .24153 .53507 L .23931 .53582 L F
.229 .728 .909 r
.27868 .53317 m .27713 .53361 L .27512 .53303 L F
.207 .315 .755 r
.76583 .40003 m .76692 .4037 L .76881 .40194 L F
.057 .008 .479 r
.76692 .4037 m .7689 .40408 L .76881 .40194 L F
.76692 .4037 m .76718 .40617 L .7689 .40408 L F
.652 .915 .979 r
.33606 .53964 m .33705 .53801 L .33843 .53916 L F
.33606 .53964 m .33501 .53897 L .33705 .53801 L F
.957 .676 .461 r
.54975 .5616 m .55144 .56031 L .54985 .55909 L F
.54975 .5616 m .55141 .56264 L .55144 .56031 L F
.412 .59 .916 r
.79272 .4273 m .79302 .42437 L .78999 .42495 L F
.79272 .4273 m .79413 .42694 L .79302 .42437 L F
.956 .701 .251 r
.21516 .76055 m .21451 .75672 L .21624 .75684 L F
.856 .747 .742 r
.21329 .75916 m .21516 .76055 L .21624 .75684 L F
.468 .199 .423 r
.48846 .62158 m .48797 .6246 L .48534 .62489 L F
.48534 .62489 m .48797 .6246 L .48846 .62158 L F
.618 .332 .462 r
.48846 .62158 m .48797 .6246 L .49114 .62348 L F
.48846 .62158 m .48797 .6246 L .49114 .62348 L F
.214 .321 .757 r
.77124 .39861 m .77235 .4023 L .76985 .40046 L F
.257 0 .082 r
.27984 .62382 m .28302 .62132 L .28049 .62149 L F
.935 .901 .768 r
.55495 .54398 m .55362 .54623 L .55491 .54721 L F
.703 .98 .901 r
.24284 .71255 m .2392 .71433 L .24141 .71029 L F
.969 .662 .376 r
.24141 .71029 m .24177 .71313 L .24284 .71255 L F
.995 .869 .554 r
.24284 .71255 m .24177 .71313 L .2409 .71539 L F
.21 0 0 r
.20547 .54203 m .20627 .54295 L .20765 .54135 L F
.20547 .54203 m .20367 .54363 L .20627 .54295 L F
0 0 0 r
.17435 .56077 m .17142 .56294 L .17323 .56191 L F
.163 0 0 r
.17323 .56191 m .17653 .56023 L .17435 .56077 L F
.498 .885 .963 r
.26966 .66747 m .27134 .66781 L .27196 .66671 L F
.824 .459 .366 r
.2548 .68549 m .25446 .68349 L .25229 .68259 L F
.58 .874 .567 r
.23273 .73153 m .23599 .72831 L .23526 .72915 L F
.469 .165 .367 r
.23769 .72862 m .24038 .72829 L .2395 .7302 L F
0 .06 .547 r
.2388 .72957 m .23769 .72862 L .2395 .7302 L F
.74 .768 .876 r
.23663 .7277 m .23838 .72602 L .23769 .72862 L F
0 .06 .547 r
.23593 .72699 m .23769 .72862 L .2388 .72957 L F
.74 .768 .876 r
.23599 .72831 m .23663 .7277 L .23769 .72862 L F
.997 .859 .541 r
.50474 .55864 m .50578 .56032 L .50623 .55719 L F
.999 .842 .53 r
.50548 .55558 m .50474 .55864 L .50623 .55719 L F
.583 .44 .653 r
.17772 .82658 m .1802 .82431 L .17753 .82432 L F
.667 .819 .956 r
.54763 .55301 m .5464 .55353 L .54999 .55401 L F
.623 .122 0 r
.5464 .55353 m .54981 .55719 L .54999 .55401 L F
.359 .775 .979 r
.23283 .63925 m .23142 .63852 L .2293 .63876 L F
.134 .674 .84 r
.23514 .63866 m .23142 .63852 L .23283 .63925 L F
0 0 0 r
.26983 .62397 m .2679 .62723 L .26901 .6251 L F
.607 .635 .852 r
.24982 .6868 m .25249 .68672 L .25238 .68518 L F
.43 0 0 r
.22281 .62172 m .21898 .62025 L .22107 .62071 L F
.356 .574 .922 r
.22359 .61993 m .22281 .62172 L .22107 .62071 L F
.22359 .61993 m .22606 .6228 L .22281 .62172 L F
.918 .903 .794 r
.54423 .55466 m .5414 .55541 L .54228 .5531 L F
.54423 .55466 m .54171 .55847 L .5414 .55541 L F
.644 .779 .945 r
.5464 .55353 m .54423 .55466 L .54228 .5531 L F
.834 .524 .465 r
.29637 .54848 m .29323 .5492 L .29353 .55099 L F
.854 .463 .303 r
.29323 .5492 m .2945 .54998 L .29353 .55099 L F
.248 0 0 r
.29353 .55099 m .29602 .55091 L .29646 .5507 L F
.854 .463 .303 r
.2945 .54998 m .29602 .55091 L .29421 .55096 L F
.2945 .54998 m .29421 .55096 L .29353 .55099 L F
.847 .994 .746 r
.29663 .54637 m .29485 .54883 L .29637 .54848 L F
.854 .463 .303 r
.2945 .54998 m .2954 .55122 L .29602 .55091 L F
.29323 .5492 m .29423 .55013 L .2945 .54998 L F
.29423 .55013 m .2954 .55122 L .2945 .54998 L F
.834 .524 .465 r
.29637 .54848 m .29423 .55013 L .29323 .5492 L F
.29423 .55013 m .29347 .55071 L .29323 .5492 L F
.847 .994 .746 r
.29368 .55043 m .29347 .55071 L .29423 .55013 L F
.854 .463 .303 r
.29323 .5492 m .29418 .55182 L .2954 .55122 L F
.413 .233 .526 r
.29475 .54783 m .29364 .55033 L .29663 .54637 L F
.29364 .55033 m .29347 .55071 L .29368 .55043 L F
.29364 .55033 m .29368 .55043 L .29663 .54637 L F
.854 .463 .303 r
.29323 .5492 m .29397 .55193 L .29417 .55183 L F
.29364 .55033 m .29417 .55183 L .29418 .55182 L F
.29323 .5492 m .29417 .55183 L .29364 .55033 L F
.42 .24 .53 r
.29323 .5492 m .29347 .55071 L .29364 .55033 L F
.29323 .5492 m .29364 .55033 L .29475 .54783 L F
.847 .994 .746 r
.29485 .54883 m .29368 .55043 L .29453 .5499 L F
.29368 .55043 m .29423 .55013 L .29453 .5499 L F
.29485 .54883 m .29453 .5499 L .29637 .54848 L F
.49 .239 .461 r
.29637 .54848 m .29602 .55091 L .29845 .55032 L F
.642 .824 .97 r
.16964 .72169 m .17152 .72288 L .16733 .72261 L F
.16733 .72261 m .17152 .72288 L .16964 .72169 L F
.437 .751 .994 r
.17213 .72152 m .17152 .72288 L .16964 .72169 L F
.17213 .72152 m .17152 .72288 L .16964 .72169 L F
.928 .775 .672 r
.55494 .53745 m .55785 .53455 L .5571 .53355 L F
.55494 .53745 m .55676 .5387 L .55785 .53455 L F
.572 .309 .48 r
.3071 .63989 m .30607 .64288 L .30356 .64298 L F
.589 .326 .487 r
.30931 .642 m .3071 .63989 L .30971 .63979 L F
.30931 .642 m .30607 .64288 L .3071 .63989 L F
.81 .851 .393 r
.34096 .56559 m .33982 .5678 L .33977 .56918 L F
0 .292 .788 r
.33982 .5678 m .34131 .57003 L .33977 .56918 L F
.478 .41 .702 r
.26136 .68554 m .25896 .68342 L .26162 .68313 L F
.544 .421 .664 r
.26375 .67967 m .264 .68296 L .26162 .68313 L F
.461 .195 .422 r
.264 .68296 m .26136 .68554 L .26162 .68313 L F
.813 .997 .853 r
.54171 .55847 m .53964 .56045 L .53996 .55867 L F
.838 .846 .383 r
.53964 .56045 m .5389 .56114 L .53996 .55867 L F
.53964 .56045 m .53881 .56295 L .5389 .56114 L F
.349 .517 .882 r
.18165 .58897 m .18279 .5907 L .18132 .59114 L F
.175 0 .318 r
.18279 .5907 m .1806 .59356 L .18132 .59114 L F
.375 0 0 r
.2138 .55854 m .21012 .55951 L .21184 .55798 L F
.319 .562 .924 r
.34527 .58857 m .3436 .58879 L .34399 .58804 L F
.34527 .58857 m .34684 .59059 L .3436 .58879 L F
.668 .543 .703 r
.34684 .59059 m .34452 .59176 L .3436 .58879 L F
.939 .778 .654 r
.21451 .75672 m .21329 .75916 L .21624 .75684 L F
.319 .562 .924 r
.34527 .58857 m .34399 .58804 L .3456 .5873 L F
.563 .766 .974 r
.24391 .55342 m .24342 .55493 L .24157 .5531 L F
.24391 .55342 m .24609 .55439 L .24342 .55493 L F
.278 0 .171 r
.16817 .56607 m .17023 .56547 L .17142 .56294 L F
.243 0 .154 r
.17142 .56294 m .17229 .56475 L .17323 .56191 L F
.17142 .56294 m .17023 .56547 L .17229 .56475 L F
.901 .986 .769 r
.26024 .68028 m .25896 .68342 L .25781 .68274 L F
.478 .41 .702 r
.26136 .68554 m .25943 .68641 L .25896 .68342 L F
0 0 0 r
.29267 .60559 m .29369 .60481 L .29552 .60322 L F
0 .235 .752 r
.28882 .57251 m .28879 .57119 L .28781 .57067 L F
.334 .335 .711 r
.28778 .57338 m .28879 .57119 L .28882 .57251 L F
.97 .93 .632 r
.29552 .60322 m .29369 .60481 L .29479 .60249 L F
.461 .318 .6 r
.29369 .60481 m .29479 .60289 L .29479 .60249 L F
.835 .452 0 r
.29552 .60322 m .29479 .60249 L .2948 .60182 L F
.461 .318 .6 r
.29479 .60289 m .29552 .60162 L .29479 .60249 L F
.835 .452 0 r
.2948 .60182 m .29479 .60249 L .2937 .59969 L F
.636 .417 .569 r
.27062 .54699 m .2716 .54627 L .27007 .54628 L F
.755 .459 .483 r
.27062 .54699 m .27626 .55042 L .27323 .54772 L F
.27062 .54699 m .26934 .55034 L .27626 .55042 L F
.456 .045 .17 r
.32516 .5841 m .32805 .58393 L .32921 .58166 L F
0 0 0 r
.32921 .58166 m .32805 .58393 L .32975 .58271 L F
.32921 .58166 m .32975 .58271 L .32761 .58064 L F
.593 .555 .781 r
.18713 .60672 m .18434 .60553 L .18596 .60475 L F
.624 .81 .972 r
.81141 .41837 m .81509 .41888 L .81416 .41747 L F
.546 .769 .98 r
.81416 .41747 m .81509 .41888 L .8168 .41693 L F
.464 .64 .933 r
.81509 .41888 m .81756 .41884 L .8168 .41693 L F
0 0 .254 r
.28183 .60258 m .28131 .60509 L .27982 .60588 L F
0 0 .031 r
.28131 .60509 m .27904 .60825 L .27982 .60588 L F
.684 .139 0 r
.24272 .69839 m .2466 .7013 L .2451 .69759 L F
.267 .361 .775 r
.29537 .58013 m .29648 .58378 L .29393 .58175 L F
.343 .526 .891 r
.77179 .41343 m .77361 .41169 L .77137 .41144 L F
.77179 .41343 m .77523 .4145 L .77361 .41169 L F
.614 .546 .754 r
.2403 .71954 m .23891 .72235 L .23754 .72111 L F
.2403 .71954 m .24003 .72213 L .23891 .72235 L F
.567 .384 .593 r
.24003 .72213 m .23838 .72602 L .23891 .72235 L F
.341 0 0 r
.53595 .52076 m .53844 .52142 L .53968 .52032 L F
.452 0 0 r
.53968 .52032 m .53844 .52142 L .54223 .52131 L F
.731 .632 .749 r
.54571 .55116 m .54297 .55112 L .54463 .54719 L F
.748 .482 .529 r
.54571 .55116 m .54228 .5531 L .54297 .55112 L F
.54571 .55116 m .5464 .55353 L .54228 .5531 L F
.017 0 .048 r
.80959 .40873 m .81172 .40806 L .81213 .4062 L F
0 0 0 r
.80959 .40873 m .8094 .40939 L .81172 .40806 L F
.116 .668 .769 r
.21834 .55832 m .21626 .55831 L .2138 .55854 L F
.032 .603 .725 r
.22 .55825 m .21626 .55831 L .21834 .55832 L F
.504 .351 .606 r
.27931 .55023 m .27693 .54764 L .27943 .54714 L F
.27931 .55023 m .27709 .55095 L .27693 .54764 L F
.563 .756 .968 r
.32055 .53668 m .31982 .53884 L .31854 .53686 L F
.32055 .53668 m .3221 .53823 L .31982 .53884 L F
.774 .85 .909 r
.82357 .41559 m .82487 .41519 L .8258 .41162 L F
.715 .791 .912 r
.8258 .41162 m .82487 .41519 L .8292 .41208 L F
.593 .11 0 r
.26393 .64482 m .26397 .64503 L .26196 .64271 L F
.628 .608 .811 r
.26296 .644 m .26597 .64394 L .26263 .64277 L F
.717 .265 .177 r
.26196 .64271 m .26398 .64507 L .26316 .64473 L F
.628 .608 .811 r
.26316 .64473 m .26356 .64462 L .26296 .644 L F
.593 .11 0 r
.26397 .64503 m .26379 .64485 L .26196 .64271 L F
.628 .608 .811 r
.26356 .64462 m .26597 .64394 L .26296 .644 L F
.593 .11 0 r
.26397 .64503 m .26398 .64507 L .26379 .64485 L F
.764 .725 .816 r
.18483 .59395 m .1806 .59356 L .18279 .5907 L F
.363 .536 .892 r
.18595 .5925 m .18483 .59395 L .18279 .5907 L F
.136 .207 .674 r
.18595 .5925 m .18668 .59597 L .18483 .59395 L F
.991 .774 .51 r
.2932 .55582 m .29301 .55863 L .29459 .55673 L F
.492 .192 .384 r
.29719 .55111 m .2932 .55582 L .29459 .55673 L F
.722 .306 .258 r
.29301 .55863 m .29722 .55956 L .29459 .55673 L F
.58 .436 .65 r
.29459 .55673 m .29714 .55648 L .29719 .55111 L F
.556 .329 .527 r
.29459 .55673 m .29722 .55956 L .29714 .55648 L F
.513 .183 .345 r
.34822 .59363 m .34704 .59626 L .34434 .59651 L F
.25 0 .212 r
.34904 .59535 m .34822 .59363 L .35073 .59391 L F
.34904 .59535 m .34704 .59626 L .34822 .59363 L F
0 0 0 r
.26425 .62152 m .26031 .62428 L .26255 .62351 L F
0 0 .063 r
.26425 .62152 m .26524 .62045 L .26593 .61768 L F
0 0 0 r
.26425 .62152 m .26255 .62351 L .26524 .62045 L F
.264 0 .286 r
.25866 .68856 m .25943 .68641 L .26136 .68554 L F
.22 .709 .925 r
.78494 .40222 m .78861 .40272 L .78609 .40278 L F
.732 .523 .609 r
.25608 .67607 m .25935 .67284 L .25548 .67351 L F
.25608 .67607 m .26013 .67628 L .25935 .67284 L F
.252 0 0 r
.24628 .5483 m .24693 .54906 L .24438 .54862 L F
.24693 .54906 m .24715 .54932 L .24686 .54924 L F
.24693 .54906 m .24686 .54924 L .24438 .54862 L F
.869 .49 .008 r
.24751 .55077 m .24705 .5509 L .24664 .54977 L F
.486 .885 .731 r
.24468 .54798 m .24438 .54862 L .24715 .54932 L F
.869 .49 .008 r
.24676 .54948 m .24664 .54977 L .24616 .54844 L F
.24751 .55077 m .24664 .54977 L .24676 .54948 L F
.715 .249 0 r
.2482 .54798 m .24849 .54905 L .24715 .54932 L F
.252 0 0 r
.24759 .54876 m .24715 .54932 L .24628 .5483 L F
.793 .371 .244 r
.24468 .54798 m .24715 .54932 L .24849 .54905 L F
.24468 .54798 m .24806 .54893 L .24616 .54844 L F
.24806 .54893 m .24849 .54905 L .24815 .54896 L F
.24806 .54893 m .24815 .54896 L .24616 .54844 L F
.252 0 0 r
.2482 .54798 m .24759 .54876 L .24628 .5483 L F
.715 .249 0 r
.2482 .54798 m .25052 .55153 L .24849 .54905 L F
.819 .398 .246 r
.25293 .55146 m .25053 .55153 L .2482 .54798 L F
.267 .76 .689 r
.25364 .55041 m .25098 .55137 L .25293 .55146 L F
.25098 .55137 m .25078 .55152 L .25293 .55146 L F
.25053 .55153 m .25053 .55153 L .25293 .55146 L F
.684 .226 .158 r
.25184 .55357 m .2499 .55498 L .24783 .55301 L F
.564 .02 0 r
.24783 .55301 m .25054 .55389 L .25184 .55357 L F
.105 0 0 r
.25285 .55307 m .25054 .55389 L .25184 .55357 L F
.25393 .55252 m .25306 .55287 L .25285 .55307 L F
.25306 .55287 m .25054 .55389 L .25285 .55307 L F
.05 0 0 r
.25215 .55437 m .25184 .55357 L .25393 .55252 L F
.105 0 0 r
.25393 .55252 m .25332 .55319 L .25054 .55389 L F
.976 .671 .334 r
.25393 .55252 m .25332 .55319 L .25364 .55041 L F
0 0 .095 r
.25364 .55041 m .25339 .55258 L .25482 .54873 L F
.25339 .55258 m .25332 .55319 L .25358 .55241 L F
.25339 .55258 m .25358 .55241 L .25482 .54873 L F
.267 .76 .689 r
.25364 .55041 m .25348 .55044 L .25218 .55092 L F
.531 .384 .627 r
.25193 .55101 m .25332 .55319 L .25201 .55352 L F
.554 .409 .638 r
.25052 .55153 m .25348 .55044 L .25183 .54816 L F
.531 .384 .627 r
.25192 .55058 m .25211 .55094 L .25193 .55101 L F
.25211 .55094 m .25332 .55319 L .25193 .55101 L F
.819 .398 .246 r
.25053 .55153 m .25049 .55149 L .2482 .54798 L F
.25053 .55153 m .25052 .55153 L .25049 .55149 L F
.554 .409 .638 r
.25052 .55153 m .25183 .54816 L .24849 .54905 L F
.531 .384 .627 r
.25183 .54816 m .25112 .55131 L .24849 .54905 L F
.267 .76 .689 r
.25098 .55137 m .2514 .55121 L .25063 .55149 L F
.2514 .55121 m .25115 .5513 L .25063 .55149 L F
.25053 .55153 m .25063 .55149 L .25052 .55153 L F
.25098 .55137 m .25063 .55149 L .25053 .55153 L F
.25098 .55137 m .25053 .55153 L .25078 .55152 L F
.25053 .55153 m .25052 .55153 L .25053 .55153 L F
.531 .384 .627 r
.25112 .55131 m .25054 .55389 L .24966 .55183 L F
.25112 .55131 m .24966 .55183 L .24849 .54905 L F
.267 .76 .689 r
.2514 .55121 m .25218 .55092 L .25115 .5513 L F
.25364 .55041 m .25218 .55092 L .25098 .55137 L F
.622 .874 .529 r
.25482 .54873 m .25348 .55044 L .25364 .55041 L F
.456 .379 .681 r
.25183 .54816 m .25348 .55044 L .25482 .54873 L F
.467 .346 .631 r
.25482 .54873 m .25436 .5501 L .25244 .55022 L F
.25436 .5501 m .25332 .55319 L .2526 .55076 L F
.25436 .5501 m .2526 .55076 L .25244 .55022 L F
.25443 .54866 m .25244 .55022 L .25183 .54816 L F
.25482 .54873 m .25244 .55022 L .25443 .54866 L F
.531 .384 .627 r
.25183 .54816 m .25244 .55022 L .25192 .55058 L F
.25244 .55022 m .25332 .55319 L .25192 .55058 L F
.25094 .55209 m .25201 .55352 L .25054 .55389 L F
.25183 .54816 m .25201 .55352 L .25094 .55209 L F
.857 .506 .388 r
.5386 .52944 m .53666 .531 L .53663 .52876 L F
.859 .511 .391 r
.53903 .53143 m .53666 .531 L .5386 .52944 L F
.389 0 0 r
.26954 .63237 m .26949 .63099 L .26749 .62994 L F
.26954 .63237 m .2719 .63125 L .26949 .63099 L F
.163 0 .26 r
.3467 .57805 m .34946 .5753 L .34718 .576 L F
.34946 .5753 m .3467 .57805 L .34718 .576 L F
.475 .8 1 r
.26989 .64913 m .2731 .64967 L .27195 .64857 L F
.548 .838 .998 r
.27195 .64857 m .2731 .64967 L .27581 .64849 L F
0 0 0 r
.19668 .56581 m .19352 .56816 L .19486 .56672 L F
.674 .604 .769 r
.29011 .60917 m .29267 .60559 L .29026 .60733 L F
.382 .397 .751 r
.34522 .56918 m .34603 .56509 L .3444 .56702 L F
.275 .776 .87 r
.28366 .53234 m .28325 .53294 L .28116 .53306 L F
.28366 .53234 m .28556 .53253 L .28325 .53294 L F
0 .375 .804 r
.13852 .65127 m .13906 .65151 L .13982 .6523 L F
.753 .931 .946 r
.13982 .6523 m .13906 .65151 L .13845 .65193 L F
.127 .675 .803 r
.24153 .53507 m .24381 .53492 L .24547 .53501 L F
.01 .584 .735 r
.24547 .53501 m .24381 .53492 L .24779 .53505 L F
0 0 .509 r
.177 .58275 m .176 .5825 L .17798 .58127 L F
.467 .807 .999 r
.26898 .53308 m .26769 .53419 L .26646 .5334 L F
.26898 .53308 m .27021 .53388 L .26769 .53419 L F
.821 .75 .785 r
.80635 .42682 m .8078 .42855 L .81017 .42521 L F
.495 .571 .861 r
.2548 .68549 m .25738 .68956 L .25866 .68856 L F
0 0 .106 r
.25866 .68856 m .25738 .68956 L .25633 .69181 L F
.257 .22 .624 r
.54264 .57535 m .54238 .57855 L .54435 .5769 L F
.56 .395 .615 r
.54238 .57855 m .54548 .58077 L .54435 .5769 L F
.54238 .57855 m .54296 .58149 L .54548 .58077 L F
.592 .273 .399 r
.30108 .64292 m .29965 .64569 L .29706 .64572 L F
.573 .253 .389 r
.30313 .64484 m .30108 .64292 L .30356 .64298 L F
.30313 .64484 m .29965 .64569 L .30108 .64292 L F
.306 .556 .923 r
.2227 .63747 m .22335 .63578 L .22137 .63686 L F
.2227 .63747 m .22514 .63825 L .22335 .63578 L F
.521 .369 .616 r
.32764 .56536 m .3251 .56325 L .32748 .56272 L F
.32764 .56536 m .3252 .56606 L .3251 .56325 L F
.973 .668 .364 r
.81017 .42521 m .80866 .42112 L .80698 .42473 L F
.821 .75 .785 r
.80635 .42682 m .81017 .42521 L .80698 .42473 L F
.459 .494 .807 r
.16162 .75286 m .16384 .75318 L .16191 .75362 L F
.147 0 0 r
.16191 .75362 m .16384 .75318 L .16151 .75406 L F
.879 .935 .852 r
.77957 .4037 m .77723 .40662 L .77696 .4056 L F
.1 0 .344 r
.35546 .57208 m .35508 .5747 L .35376 .57531 L F
.449 .313 .603 r
.35557 .57709 m .35376 .57531 L .35508 .5747 L F
.35557 .57709 m .3537 .57887 L .35376 .57531 L F
.651 .79 .948 r
.82028 .39929 m .81734 .40033 L .8163 .39873 L F
.638 .844 .979 r
.82104 .39972 m .81734 .40033 L .82028 .39929 L F
.546 .169 .278 r
.46357 .65536 m .45968 .65782 L .4618 .65441 L F
.46357 .65536 m .46239 .65771 L .45968 .65782 L F
.179 0 .291 r
.46357 .65536 m .46602 .65218 L .46506 .6546 L F
.273 0 .222 r
.46506 .6546 m .46239 .65771 L .46357 .65536 L F
.699 .596 .737 r
.46334 .65266 m .46602 .65218 L .46357 .65536 L F
.46334 .65266 m .46602 .65218 L .46357 .65536 L F
.143 0 0 r
.21007 .54113 m .21246 .54056 L .21421 .53903 L F
0 0 0 r
.21421 .53903 m .21246 .54056 L .21424 .53931 L F
.066 0 0 r
.26053 .55028 m .25614 .55174 L .25855 .55124 L F
.539 .567 .832 r
.26629 .67669 m .26222 .67303 L .26498 .67227 L F
.518 .434 .699 r
.26848 .67612 m .26498 .67227 L .26701 .67251 L F
.26848 .67612 m .26629 .67669 L .26498 .67227 L F
.838 .787 .803 r
.50474 .55864 m .50584 .56158 L .50578 .56032 L F
.315 .607 .951 r
.78764 .42475 m .78918 .4235 L .78666 .42329 L F
.78764 .42475 m .78999 .42495 L .78918 .4235 L F
.252 .716 .948 r
.23334 .62365 m .23289 .6244 L .23111 .62381 L F
.23334 .62365 m .23512 .62437 L .23289 .6244 L F
.954 .655 .431 r
.50772 .56352 m .50634 .56507 L .50608 .56249 L F
.50608 .56249 m .50634 .56507 L .50772 .56352 L F
.346 .506 .874 r
.77558 .41676 m .77721 .41477 L .77523 .4145 L F
.77558 .41676 m .77879 .41772 L .77721 .41477 L F
.492 .192 .384 r
.29719 .55111 m .29561 .55566 L .2932 .55582 L F
.454 .334 .626 r
.29714 .55648 m .29952 .55574 L .29719 .55111 L F
.342 .051 .317 r
.29778 .55489 m .29719 .55111 L .29952 .55574 L F
.29778 .55489 m .29561 .55566 L .29719 .55111 L F
.562 .281 .446 r
.31591 .63661 m .31465 .6394 L .31224 .63962 L F
.62 .343 .476 r
.31815 .639 m .31591 .63661 L .31846 .63657 L F
.31815 .639 m .31465 .6394 L .31591 .63661 L F
.539 .515 .777 r
.32452 .57508 m .32696 .57453 L .32352 .5729 L F
.385 .324 .666 r
.32452 .57508 m .32688 .57768 L .32696 .57453 L F
.32452 .57508 m .32488 .5788 L .32688 .57768 L F
.306 .532 .907 r
.78331 .42232 m .78523 .42092 L .78258 .42078 L F
.78331 .42232 m .78666 .42329 L .78523 .42092 L F
.24 .477 .884 r
.33063 .55119 m .33347 .55234 L .33268 .55399 L F
.061 .247 .741 r
.33347 .55234 m .33481 .55591 L .33268 .55399 L F
.514 .292 .515 r
.33481 .55591 m .3324 .55648 L .33268 .55399 L F
.965 .917 .708 r
.54171 .55847 m .53996 .55867 L .5414 .55541 L F
.349 .517 .882 r
.18165 .58897 m .18036 .58894 L .1791 .58905 L F
.508 .308 .543 r
.2497 .67314 m .25198 .67591 L .25223 .67246 L F
.688 .538 .677 r
.46334 .65266 m .46602 .65218 L .46606 .64886 L F
.685 .536 .677 r
.46606 .64886 m .46602 .65218 L .46845 .6491 L F
.709 .968 .728 r
.34064 .54294 m .338 .54551 L .3403 .54411 L F
.851 .556 .489 r
.54656 .52208 m .54993 .5255 L .54975 .52328 L F
.466 .287 .554 r
.2821 .55755 m .28437 .557 L .28444 .55428 L F
.526 .503 .773 r
.2821 .55755 m .28497 .55871 L .28437 .557 L F
0 0 0 r
.27227 .62036 m .27037 .62145 L .27332 .61872 L F
0 0 .158 r
.2745 .61768 m .27332 .61872 L .27527 .61522 L F
.256 0 .255 r
.2745 .61768 m .27227 .62036 L .27332 .61872 L F
.001 .117 .633 r
.31209 .58243 m .31102 .58149 L .31364 .58001 L F
.147 0 .038 r
.3145 .57997 m .31209 .58243 L .31364 .58001 L F
.837 .777 .795 r
.54774 .54185 m .54376 .54349 L .54657 .54075 L F
.54774 .54185 m .54539 .54492 L .54376 .54349 L F
.893 .502 .06 r
.54774 .54185 m .54657 .54075 L .5459 .53851 L F
.892 .937 .838 r
.54297 .55112 m .54397 .54687 L .54463 .54719 L F
.54297 .55112 m .54058 .55053 L .54397 .54687 L F
.091 .52 .906 r
.16302 .60304 m .16764 .60585 L .16705 .60534 L F
.538 .511 .774 r
.35665 .56546 m .35439 .56612 L .35351 .56216 L F
.526 .421 .678 r
.35665 .56546 m .35472 .56954 L .35439 .56612 L F
.829 .64 .647 r
.55021 .5746 m .55194 .57819 L .55391 .57543 L F
.457 .297 .574 r
.32319 .63039 m .32093 .63366 L .32069 .63101 L F
.045 0 0 r
.28556 .53253 m .28804 .53258 L .28949 .53253 L F
.712 .573 .697 r
.20107 .78731 m .20366 .78427 L .20109 .785 L F
.948 .958 .696 r
.82169 .41924 m .82357 .41559 L .82307 .41455 L F
.774 .85 .909 r
.82357 .41559 m .8258 .41162 L .82307 .41455 L F
.132 0 .388 r
.31201 .59085 m .31173 .59334 L .31335 .58989 L F
.123 .017 .451 r
.29482 .59146 m .29342 .59706 L .2953 .59533 L F
.317 .211 .573 r
.29342 .59706 m .2937 .59969 L .29542 .59904 L F
.314 .485 .868 r
.77945 .41967 m .78196 .4188 L .77879 .41772 L F
.77945 .41967 m .78258 .42078 L .78196 .4188 L F
.637 .465 .633 r
.33512 .60902 m .33554 .61175 L .33221 .61201 L F
.55 .486 .736 r
.3374 .60813 m .33512 .60902 L .33438 .60625 L F
.645 .537 .717 r
.3374 .60813 m .33554 .61175 L .33512 .60902 L F
.951 .912 .541 r
.54463 .54719 m .54397 .54687 L .54539 .54492 L F
.948 .656 .449 r
.54539 .54492 m .54397 .54687 L .54376 .54349 L F
.54539 .54492 m .54397 .54687 L .54376 .54349 L F
.674 .604 .769 r
.29011 .60917 m .29408 .60911 L .29267 .60559 L F
.599 .23 .313 r
.29139 .61054 m .29011 .60917 L .28997 .61125 L F
.29139 .61054 m .29408 .60911 L .29011 .60917 L F
.041 0 0 r
.32125 .5457 m .31936 .54627 L .31709 .5465 L F
.432 0 0 r
.3227 .54524 m .31936 .54627 L .32125 .5457 L F
.21 .582 .943 r
.23931 .63997 m .23958 .63875 L .23795 .63847 L F
0 .162 .702 r
.23931 .63997 m .24141 .64203 L .23958 .63875 L F
.334 0 0 r
.16081 .75315 m .16384 .75318 L .16162 .75286 L F
.413 .599 .922 r
.18673 .61777 m .18605 .6144 L .18426 .61481 L F
.18673 .61777 m .18866 .61752 L .18605 .6144 L F
.176 .644 .934 r
.32533 .53951 m .3282 .53982 L .32968 .54064 L F
.461 .816 .997 r
.33057 .5394 m .32899 .5401 L .32968 .54064 L F
.57 .824 .993 r
.82209 .39886 m .82104 .39972 L .82028 .39929 L F
0 0 .124 r
.82209 .39886 m .82045 .40215 L .82104 .39972 L F
.08 .638 .792 r
.23973 .62408 m .23913 .62428 L .23739 .62409 L F
.23973 .62408 m .24137 .62424 L .23913 .62428 L F
.592 .874 .554 r
.18249 .5775 m .18079 .5794 L .18127 .57897 L F
.665 .176 .079 r
.79408 .41373 m .79743 .41299 L .7938 .41252 L F
.79408 .41373 m .79644 .41421 L .79743 .41299 L F
.658 .168 .074 r
.79644 .41421 m .80048 .41503 L .79743 .41299 L F
.163 0 .26 r
.3467 .57805 m .34884 .57731 L .34946 .5753 L F
.34946 .5753 m .34884 .57731 L .3467 .57805 L F
.256 0 .25 r
.16317 .56958 m .16433 .57079 L .1653 .56886 L F
.16317 .56958 m .16241 .57156 L .16433 .57079 L F
.32 0 .101 r
.18674 .55229 m .19012 .55044 L .18789 .55096 L F
.728 .49 .567 r
.30688 .60114 m .30925 .60186 L .31046 .59983 L F
.76 .818 .898 r
.31301 .59743 m .31046 .59983 L .31186 .59785 L F
.694 .585 .729 r
.30925 .60186 m .31186 .59785 L .31046 .59983 L F
.71 .711 .849 r
.54678 .58442 m .55092 .58514 L .54932 .58354 L F
.874 .874 .833 r
.33764 .58363 m .33923 .58472 L .34186 .58132 L F
.526 .663 .923 r
.33961 .58299 m .33923 .58472 L .33764 .58363 L F
.33961 .58299 m .34163 .58437 L .33923 .58472 L F
.539 .324 .537 r
.33554 .61175 m .33258 .6148 L .33221 .61201 L F
0 0 0 r
.27227 .62036 m .26983 .62397 L .27037 .62145 L F
.485 .574 .87 r
.25258 .70127 m .24899 .69844 L .25187 .69829 L F
.997 .801 .52 r
.25331 .70003 m .25271 .7022 L .25258 .70127 L F
.876 .529 .03 r
.25267 .70235 m .25305 .70303 L .25269 .70223 L F
.997 .801 .52 r
.25269 .70223 m .25267 .70235 L .25267 .70224 L F
0 0 0 r
.25162 .70173 m .25258 .70127 L .25267 .70224 L F
.876 .529 .03 r
.25267 .70235 m .25269 .70223 L .25158 .69982 L F
.997 .801 .52 r
.25271 .7022 m .25267 .70235 L .25269 .70223 L F
.25271 .7022 m .25267 .70224 L .25258 .70127 L F
0 .007 .582 r
.25273 .70224 m .2527 .70226 L .25273 .70224 L F
.997 .801 .52 r
.25271 .7022 m .25305 .70303 L .25267 .70235 L F
.25331 .70003 m .25305 .70303 L .25271 .7022 L F
0 .007 .582 r
.2532 .70178 m .25273 .70224 L .25325 .70184 L F
.25273 .70224 m .25273 .70224 L .25325 .70184 L F
.25158 .69982 m .25269 .70223 L .2532 .70178 L F
.25269 .70223 m .2527 .70226 L .2532 .70178 L F
.2527 .70226 m .25305 .70303 L .25314 .70248 L F
.2527 .70226 m .25314 .70248 L .25325 .70184 L F
0 0 0 r
.24838 .70327 m .25162 .70173 L .25267 .70235 L F
.25162 .70173 m .25267 .70224 L .25267 .70235 L F
.961 .711 .511 r
.25328 .69786 m .2533 .69734 L .25459 .69635 L F
0 .036 .588 r
.25331 .70003 m .25258 .70127 L .2524 .7005 L F
.25331 .70003 m .2524 .7005 L .25193 .69854 L F
.25331 .70003 m .25187 .69829 L .2533 .69734 L F
.25331 .70003 m .25193 .69854 L .25203 .69849 L F
.961 .711 .511 r
.25158 .69982 m .25331 .70003 L .2533 .69734 L F
.243 .75 .881 r
.25386 .69975 m .25331 .70003 L .25158 .69982 L F
.25582 .69969 m .25331 .70003 L .25386 .69975 L F
.961 .711 .511 r
.25158 .69982 m .25275 .69813 L .25328 .69786 L F
.25275 .69813 m .2533 .69734 L .25328 .69786 L F
0 .036 .588 r
.25203 .69849 m .25193 .69854 L .25187 .69829 L F
.55 .486 .736 r
.3374 .60813 m .33438 .60625 L .33684 .60573 L F
.565 .331 .52 r
.33059 .61831 m .33037 .62121 L .32731 .62103 L F
.518 .393 .648 r
.33258 .6148 m .33282 .61784 L .33059 .61831 L F
.503 .279 .507 r
.3326 .62066 m .33059 .61831 L .33282 .61784 L F
.3326 .62066 m .33037 .62121 L .33059 .61831 L F
.823 .671 .695 r
.54131 .56673 m .54026 .56899 L .53873 .56614 L F
.849 .825 .824 r
.80555 .42111 m .80866 .42112 L .80794 .41804 L F
.83 .639 .645 r
.80513 .42351 m .80866 .42112 L .80555 .42111 L F
.80513 .42351 m .80698 .42473 L .80866 .42112 L F
.787 .791 .856 r
.80794 .41804 m .80866 .42112 L .81141 .41837 L F
.193 0 .245 r
.16064 .57242 m .15983 .57456 L .16241 .57156 L F
.641 .608 .801 r
.17986 .61604 m .18214 .61519 L .17847 .61372 L F
.31 .588 .942 r
.7758 .40322 m .77288 .40405 L .77235 .4023 L F
.7758 .40322 m .775 .40485 L .7739 .40376 L F
.988 .724 .367 r
.77126 .40111 m .77235 .4023 L .77124 .39861 L F
.395 0 0 r
.77454 .40384 m .7758 .40322 L .77235 .4023 L F
.77454 .40384 m .77262 .40249 L .77126 .40111 L F
.77262 .40249 m .77235 .4023 L .77159 .40147 L F
.77262 .40249 m .77159 .40147 L .77126 .40111 L F
.31 .588 .942 r
.7758 .40322 m .77696 .4056 L .775 .40485 L F
.7739 .40376 m .775 .40485 L .77288 .40405 L F
.697 .342 .37 r
.34707 .58225 m .34814 .58413 L .34402 .58343 L F
.459 .277 .546 r
.35141 .55371 m .35126 .55614 L .34913 .55672 L F
.425 .41 .739 r
.32273 .56902 m .32352 .5729 L .32596 .57161 L F
.476 .533 .837 r
.32352 .5729 m .32696 .57453 L .32596 .57161 L F
.53 .233 .407 r
.31224 .63962 m .30931 .642 L .30971 .63979 L F
.567 .384 .593 r
.24003 .72213 m .24095 .72498 L .23838 .72602 L F
.42 .372 .698 r
.24297 .72205 m .24003 .72213 L .2403 .71954 L F
.088 .104 .58 r
.24225 .72442 m .24003 .72213 L .24297 .72205 L F
.24198 .72413 m .24095 .72498 L .24003 .72213 L F
.689 .249 .2 r
.24169 .72424 m .24297 .72205 L .23835 .72165 L F
.858 .973 .661 r
.2421 .72309 m .2425 .72266 L .24169 .72424 L F
.2421 .72309 m .24257 .72253 L .2425 .72266 L F
.24257 .72253 m .24297 .72205 L .24236 .7231 L F
.043 0 .225 r
.24429 .7211 m .24225 .72442 L .24297 .72205 L F
.858 .973 .661 r
.2421 .72309 m .24429 .7211 L .24297 .72205 L F
.24257 .72253 m .24236 .7231 L .24169 .72424 L F
.2421 .72309 m .24225 .72442 L .24429 .7211 L F
0 0 .127 r
.2433 .72186 m .2421 .72309 L .24233 .72374 L F
.42 .372 .698 r
.24297 .72205 m .2403 .71954 L .24267 .71912 L F
.786 .556 .587 r
.23835 .72165 m .24297 .72205 L .24267 .71912 L F
.624 .059 0 r
.23851 .7228 m .24169 .72424 L .23835 .72165 L F
.667 .798 .945 r
.2421 .72309 m .24169 .72424 L .23851 .7228 L F
.479 .208 .425 r
.23838 .72602 m .24095 .72498 L .24038 .72829 L F
.761 .668 .759 r
.23851 .7228 m .24024 .72643 L .2421 .72309 L F
.23851 .7228 m .2421 .72309 L .24096 .72429 L F
.667 .798 .945 r
.2421 .72309 m .23851 .7228 L .24164 .72357 L F
.088 .104 .58 r
.24225 .72442 m .2418 .72461 L .24198 .72413 L F
.2418 .72461 m .24095 .72498 L .24198 .72413 L F
0 0 .236 r
.24038 .72829 m .24095 .72498 L .24225 .72442 L F
.963 .718 .518 r
.24024 .72643 m .24225 .72442 L .2421 .72309 L F
.667 .798 .945 r
.2421 .72309 m .24164 .72357 L .24233 .72374 L F
.424 .64 .947 r
.24188 .72333 m .24233 .72374 L .24164 .72357 L F
.695 .726 .874 r
.2433 .72186 m .24233 .72374 L .24188 .72333 L F
0 0 0 r
.24225 .72294 m .2421 .72309 L .2433 .72186 L F
.2418 .72341 m .2421 .72309 L .24225 .72294 L F
.493 .212 .416 r
.24267 .71912 m .24429 .7211 L .24297 .72205 L F
.24429 .7211 m .24267 .71912 L .24297 .72205 L F
.695 .726 .874 r
.2433 .72186 m .24188 .72333 L .23958 .72124 L F
0 0 0 r
.24131 .72392 m .24156 .72366 L .24166 .72355 L F
.24156 .72366 m .2421 .72309 L .24178 .72343 L F
.24156 .72366 m .24178 .72343 L .24166 .72355 L F
.24096 .72429 m .2421 .72309 L .24131 .72392 L F
.424 .64 .947 r
.23958 .72124 m .24188 .72333 L .23851 .7228 L F
.24188 .72333 m .24164 .72357 L .23851 .7228 L F
0 0 0 r
.24166 .72355 m .2418 .72341 L .24225 .72294 L F
.15549 .57847 m .1568 .57771 L .15799 .57542 L F
.263 .158 .542 r
.15537 .58106 m .1568 .57771 L .15549 .57847 L F
.19 0 .378 r
.27284 .60305 m .27385 .60476 L .27391 .60147 L F
.27284 .60305 m .2724 .60556 L .27385 .60476 L F
.424 .408 .737 r
.32488 .5788 m .32761 .58064 L .32688 .57768 L F
.893 .736 .679 r
.35029 .58507 m .34937 .58768 L .34814 .58413 L F
.782 .601 .656 r
.35074 .58733 m .35029 .58507 L .35261 .58546 L F
.35074 .58733 m .34937 .58768 L .35029 .58507 L F
0 0 0 r
.22436 .55697 m .22213 .55767 L .22 .55825 L F
0 .057 .608 r
.22489 .55531 m .22436 .55697 L .22337 .55328 L F
.604 .389 .562 r
.22489 .55531 m .22213 .55767 L .22436 .55697 L F
.636 .442 .602 r
.35405 .58687 m .35261 .58546 L .35465 .58347 L F
.35405 .58687 m .35074 .58733 L .35261 .58546 L F
.318 0 0 r
.53619 .52122 m .53844 .52142 L .53595 .52076 L F
.785 .763 .834 r
.34937 .58768 m .34684 .59059 L .34527 .58857 L F
0 .447 .718 r
.23237 .55148 m .23094 .55106 L .22927 .5507 L F
.449 0 0 r
.23437 .55031 m .23094 .55106 L .23237 .55148 L F
.499 .241 .454 r
.29482 .59146 m .29543 .59308 L .29593 .59081 L F
.123 .017 .451 r
.29482 .59146 m .2953 .59533 L .29543 .59308 L F
.927 .758 .652 r
.28038 .64747 m .2819 .65108 L .27936 .64995 L F
.765 .704 .795 r
.28431 .6483 m .2819 .65108 L .28038 .64747 L F
.712 .199 0 r
.28038 .64747 m .28252 .65004 L .28142 .64895 L F
.638 .114 0 r
.28038 .64747 m .28431 .6483 L .28252 .65004 L F
.765 .704 .795 r
.28431 .6483 m .28038 .64747 L .28252 .65004 L F
.712 .199 0 r
.28038 .64747 m .28228 .64933 L .28174 .6494 L F
.924 .909 .516 r
.27883 .64976 m .27973 .64843 L .27936 .64995 L F
.27973 .64843 m .28038 .64747 L .27973 .64905 L F
.27973 .64843 m .27973 .64905 L .27936 .64995 L F
.712 .199 0 r
.28038 .64747 m .28174 .6494 L .27883 .64976 L F
.246 .76 .8 r
.27831 .64748 m .28047 .64713 L .28038 .64747 L F
.28047 .64713 m .28056 .64711 L .28038 .64747 L F
.712 .199 0 r
.28038 .64747 m .28252 .65004 L .28029 .64781 L F
.222 .687 .945 r
.27646 .64663 m .27831 .64748 L .28038 .64747 L F
.27646 .64663 m .28038 .64747 L .27873 .64625 L F
.712 .199 0 r
.28038 .64747 m .28023 .64776 L .27873 .64625 L F
.28038 .64747 m .27873 .64625 L .28025 .64794 L F
.28038 .64747 m .28142 .64895 L .28023 .64776 L F
.28038 .64747 m .28025 .64794 L .28048 .64819 L F
.002 .22 .731 r
.27873 .64625 m .27973 .64736 L .27956 .64503 L F
.27973 .64736 m .28048 .64819 L .27973 .64564 L F
.27973 .64736 m .27973 .64564 L .27956 .64503 L F
.246 .76 .8 r
.28056 .64711 m .28234 .64682 L .28038 .64747 L F
.638 .114 0 r
.28038 .64747 m .28234 .64682 L .28431 .6483 L F
.378 0 0 r
.35315 .59468 m .35073 .59391 L .35217 .59181 L F
.35315 .59468 m .34904 .59535 L .35073 .59391 L F
.133 .019 .446 r
.46584 .65464 m .46713 .65346 L .46569 .65425 L F
.46584 .65464 m .46569 .65425 L .46506 .6546 L F
.58 .238 .354 r
.46584 .65464 m .46588 .65402 L .46569 .65425 L F
.699 .787 .31 r
.46554 .65518 m .46584 .65464 L .46713 .65346 L F
0 0 .044 r
.46569 .65425 m .46554 .65518 L .46713 .65346 L F
.46506 .6546 m .46523 .6548 L .46555 .65441 L F
.58 .238 .354 r
.4654 .65461 m .46334 .65266 L .4618 .65441 L F
.46584 .65464 m .46555 .65441 L .4654 .65461 L F
0 0 .044 r
.46506 .6546 m .46555 .65441 L .46568 .65426 L F
.58 .238 .354 r
.46555 .65441 m .46334 .65266 L .4654 .65461 L F
0 0 .044 r
.46568 .65426 m .46555 .65441 L .46569 .65425 L F
.273 0 .222 r
.46506 .6546 m .46481 .65706 L .46239 .65771 L F
.296 0 .279 r
.46505 .65534 m .46481 .65706 L .46584 .65464 L F
.46239 .65771 m .46481 .65706 L .46505 .65534 L F
0 0 .044 r
.46506 .6546 m .46495 .65568 L .46505 .65534 L F
.46514 .65469 m .46505 .65534 L .46521 .65478 L F
.46506 .6546 m .46505 .65534 L .46514 .65469 L F
.46521 .65478 m .46481 .65706 L .46554 .65518 L F
.46495 .65568 m .46481 .65706 L .46521 .65478 L F
.296 0 .279 r
.4652 .65481 m .46584 .65464 L .4654 .65461 L F
.46239 .65771 m .46505 .65534 L .4652 .65481 L F
.46505 .65534 m .46584 .65464 L .4652 .65481 L F
.46233 .65742 m .4654 .65461 L .4618 .65441 L F
.46239 .65771 m .4654 .65461 L .46233 .65742 L F
0 0 .044 r
.46523 .6548 m .46554 .65518 L .46567 .65436 L F
.58 .238 .354 r
.46584 .65464 m .46498 .65237 L .46334 .65266 L F
0 0 .044 r
.46535 .65465 m .46567 .65436 L .46569 .65425 L F
.46523 .6548 m .46567 .65436 L .46535 .65465 L F
.58 .238 .354 r
.46569 .65425 m .46602 .65218 L .46498 .65237 L F
.46588 .65402 m .46602 .65218 L .46569 .65425 L F
0 .416 .836 r
.27301 .65429 m .27474 .65569 L .27248 .65436 L F
0 0 0 r
.27354 .65422 m .27301 .65429 L .27154 .6549 L F
.609 .862 .991 r
.27499 .65373 m .27474 .65569 L .27365 .65481 L F
.27499 .65373 m .27365 .65481 L .27301 .65429 L F
.27499 .65373 m .27716 .6548 L .27474 .65569 L F
.803 .962 .912 r
.27562 .65383 m .27716 .6548 L .27499 .65373 L F
.76 .669 .761 r
.27353 .65563 m .27655 .65247 L .27499 .65373 L F
.281 .367 .774 r
.27562 .65383 m .27499 .65373 L .27658 .65244 L F
.76 .669 .761 r
.27655 .65247 m .27658 .65244 L .27499 .65373 L F
0 0 0 r
.27499 .65373 m .27301 .65429 L .27354 .65422 L F
0 .416 .836 r
.27301 .65429 m .27248 .65436 L .27106 .65353 L F
.713 .531 .642 r
.27474 .65569 m .27529 .65858 L .27075 .65752 L F
.487 .268 .507 r
.27474 .65569 m .27716 .6548 L .27657 .6573 L F
.329 .272 .641 r
.27657 .6573 m .27529 .65858 L .27474 .65569 L F
0 0 0 r
.23027 .72514 m .23173 .72301 L .22863 .72636 L F
.109 .075 .534 r
.23027 .72514 m .22863 .72636 L .22912 .72778 L F
.081 0 .097 r
.15799 .57542 m .15894 .57643 L .15983 .57456 L F
.15799 .57542 m .1568 .57771 L .15894 .57643 L F
0 0 .332 r
.15626 .60025 m .15764 .59929 L .15819 .59613 L F
.254 0 .11 r
.32585 .5532 m .32798 .55261 L .32772 .55232 L F
0 0 0 r
.32585 .5532 m .3263 .5541 L .32798 .55261 L F
.32585 .5532 m .32437 .55511 L .3263 .5541 L F
.523 .341 .575 r
.22803 .73508 m .22979 .73804 L .23039 .73466 L F
.851 .655 .637 r
.23039 .73466 m .22979 .73804 L .22803 .73508 L F
.947 .595 .299 r
.55437 .53081 m .5571 .53355 L .55583 .53188 L F
.55437 .53081 m .55487 .53295 L .5571 .53355 L F
.961 .823 .661 r
.55347 .53639 m .5571 .53355 L .55487 .53295 L F
.55347 .53639 m .55494 .53745 L .5571 .53355 L F
.428 .266 .557 r
.30452 .59067 m .30458 .59372 L .30272 .59397 L F
.458 .425 .734 r
.30458 .59372 m .30551 .59588 L .30272 .59397 L F
.449 .425 .74 r
.30551 .59588 m .30367 .59663 L .30272 .59397 L F
.096 0 0 r
.33639 .54736 m .33397 .54821 L .33495 .54742 L F
0 0 .499 r
.28982 .54704 m .29045 .54373 L .28815 .54448 L F
.28982 .54704 m .29043 .54999 L .29045 .54373 L F
.584 .415 .618 r
.47462 .63363 m .47467 .6366 L .47209 .63682 L F
.43 0 .118 r
.47467 .6366 m .4739 .63802 L .47209 .63682 L F
0 0 .487 r
.47076 .63562 m .47209 .63682 L .4739 .63802 L F
.47076 .63562 m .47153 .63863 L .47209 .63682 L F
.631 .464 .638 r
.47076 .63562 m .46742 .64096 L .47036 .6396 L F
.45 .101 .281 r
.47153 .63863 m .46882 .6409 L .46978 .64016 L F
.46882 .6409 m .46809 .64151 L .46827 .64137 L F
.46882 .6409 m .46827 .64137 L .46978 .64016 L F
.47153 .63863 m .47063 .64114 L .46809 .64151 L F
.631 .464 .638 r
.47169 .63847 m .47036 .6396 L .47183 .63892 L F
.47076 .63562 m .47036 .6396 L .47169 .63847 L F
.166 0 .087 r
.81213 .4062 m .81456 .40579 L .81414 .40327 L F
.81213 .4062 m .81172 .40806 L .81456 .40579 L F
.495 .097 .215 r
.28695 .64856 m .28848 .64609 L .29053 .64741 L F
.519 .064 .111 r
.28848 .64609 m .29107 .64633 L .29053 .64741 L F
.28 0 .205 r
.18151 .55688 m .18365 .55623 L .18484 .55307 L F
.235 0 .185 r
.18484 .55307 m .18569 .55525 L .18674 .55229 L F
.18484 .55307 m .18365 .55623 L .18569 .55525 L F
.806 .747 .797 r
.23517 .71338 m .23603 .716 L .2325 .71613 L F
.202 .727 .841 r
.2325 .71613 m .23603 .716 L .23459 .7158 L F
.63 .748 .933 r
.2392 .71433 m .23517 .71338 L .23721 .71256 L F
.737 .802 .904 r
.23603 .716 m .23721 .71256 L .23517 .71338 L F
.23603 .716 m .2392 .71433 L .23772 .71301 L F
.23695 .71333 m .23772 .71301 L .23721 .71256 L F
.23603 .716 m .23772 .71301 L .23695 .71333 L F
0 .151 .685 r
.23701 .71522 m .23603 .716 L .23517 .71338 L F
.524 .226 .403 r
.23701 .71522 m .23566 .71387 L .23459 .7158 L F
.23566 .71387 m .23517 .71338 L .23498 .71415 L F
.23566 .71387 m .23498 .71415 L .23459 .7158 L F
.37 .835 .889 r
.23459 .7158 m .23603 .716 L .23701 .71522 L F
.921 .527 .18 r
.82955 .40543 m .83035 .40745 L .83124 .40692 L F
.529 0 0 r
.83035 .40745 m .83358 .40781 L .83124 .40692 L F
.607 .865 .992 r
.16123 .60181 m .16092 .6038 L .16302 .60304 L F
.16123 .60181 m .15873 .60269 L .16092 .6038 L F
.372 .233 .559 r
.34148 .59927 m .33957 .60268 L .33926 .59995 L F
0 0 .069 r
.27584 .61638 m .27527 .61522 L .27691 .61421 L F
.27584 .61638 m .2745 .61768 L .27527 .61522 L F
.874 .874 .833 r
.33764 .58363 m .34186 .58132 L .33961 .58299 L F
.84 .603 .581 r
.34186 .58132 m .34163 .58437 L .33961 .58299 L F
.592 .384 .568 r
.34402 .58343 m .34163 .58437 L .34186 .58132 L F
.415 .448 .786 r
.30688 .60114 m .30367 .59663 L .30551 .59588 L F
.879 .935 .852 r
.77957 .4037 m .77696 .4056 L .77781 .4038 L F
.444 .864 .947 r
.7814 .40262 m .77957 .4037 L .77781 .4038 L F
.7814 .40262 m .78229 .40297 L .77957 .4037 L F
.348 .771 .975 r
.20907 .6177 m .20888 .61887 L .20654 .61779 L F
.20907 .6177 m .21126 .61861 L .20888 .61887 L F
.457 .234 .486 r
.34387 .59857 m .3418 .59679 L .34434 .59651 L F
.34387 .59857 m .34148 .59927 L .3418 .59679 L F
.644 .626 .817 r
.3538 .54766 m .35003 .54619 L .35206 .54617 L F
.35003 .54619 m .34902 .54579 L .35206 .54617 L F
.572 .754 .964 r
.35599 .54701 m .3538 .54766 L .35206 .54617 L F
.35599 .54701 m .35206 .54617 L .35759 .54629 L F
.268 .751 .925 r
.35206 .54617 m .35456 .54584 L .35759 .54629 L F
.467 .232 .473 r
.35157 .54841 m .35421 .54614 L .35206 .54617 L F
.35421 .54614 m .35456 .54584 L .35206 .54617 L F
.462 .015 .1 r
.3485 .54648 m .35206 .54617 L .34902 .54579 L F
.063 0 0 r
.21633 .53842 m .21858 .53809 L .21992 .53751 L F
.004 0 0 r
.21858 .53809 m .22244 .53746 L .21992 .53751 L F
.196 0 0 r
.31668 .58787 m .31903 .58732 L .3173 .58723 L F
.596 .535 .756 r
.35562 .55715 m .35281 .55971 L .35126 .55614 L F
.35562 .55715 m .3554 .55961 L .35281 .55971 L F
.469 .387 .681 r
.35555 .56108 m .35281 .55971 L .3554 .55961 L F
.35555 .56108 m .35351 .56216 L .35281 .55971 L F
.78 .676 .749 r
.33899 .55567 m .34265 .55681 L .34138 .55329 L F
.673 .146 0 r
.33899 .55567 m .34181 .55805 L .34265 .55681 L F
.193 .267 .711 r
.34265 .55681 m .3433 .55282 L .34138 .55329 L F
.34265 .55681 m .34363 .55618 L .3433 .55282 L F
.815 .512 .478 r
.34181 .55805 m .34363 .55618 L .34265 .55681 L F
.581 .47 .692 r
.33037 .62121 m .3283 .62422 L .32731 .62103 L F
.347 .462 .835 r
.2936 .5868 m .29593 .59081 L .29703 .58962 L F
0 0 .164 r
.29593 .59081 m .29543 .59308 L .29703 .58962 L F
.89 .97 .829 r
.25027 .69484 m .25166 .69397 L .25007 .69586 L F
.554 .145 .22 r
.25194 .69477 m .25166 .69397 L .25027 .69484 L F
.026 0 0 r
.2501 .53468 m .25238 .53422 L .25419 .53332 L F
.175 0 0 r
.25419 .53332 m .25238 .53422 L .25637 .53334 L F
.497 .339 .597 r
.35599 .54701 m .35346 .55053 L .3538 .54766 L F
.576 .177 .249 r
.47076 .63562 m .47315 .63566 L .47462 .63363 L F
.483 .335 .604 r
.47462 .63363 m .47721 .63586 L .47467 .6366 L F
.667 .283 .309 r
.47315 .63566 m .47721 .63586 L .47462 .63363 L F
.495 .31 .56 r
.28444 .55428 m .28666 .55633 L .28671 .55303 L F
.28444 .55428 m .28437 .557 L .28666 .55633 L F
.052 0 0 r
.31179 .53781 m .3141 .53744 L .31521 .53671 L F
0 0 0 r
.31521 .53671 m .31652 .53653 L .31854 .53686 L F
.31521 .53671 m .3141 .53744 L .31652 .53653 L F
.563 .623 .87 r
.18596 .60475 m .18926 .60614 L .18713 .60672 L F
0 0 .212 r
.25007 .69586 m .25052 .69721 L .25027 .69484 L F
.394 .161 .438 r
.3076 .58672 m .30887 .58964 L .30452 .59067 L F
.821 .362 .132 r
.3119 .59052 m .3076 .58672 L .31025 .58478 L F
.3119 .59052 m .30887 .58964 L .3076 .58672 L F
.424 .278 .578 r
.354 .58939 m .35074 .58733 L .35405 .58687 L F
.354 .58939 m .35267 .59068 L .35074 .58733 L F
0 0 0 r
.28244 .59917 m .28194 .60011 L .28322 .59668 L F
.072 0 .42 r
.28275 .60162 m .28194 .60011 L .28244 .59917 L F
.28275 .60162 m .28183 .60258 L .28194 .60011 L F
.326 .208 .562 r
.1537 .58444 m .15543 .5864 L .15546 .5837 L F
.1537 .58444 m .1534 .58786 L .15543 .5864 L F
.824 .459 .366 r
.2548 .68549 m .25229 .68259 L .25238 .68518 L F
.609 .431 .616 r
.53881 .56295 m .53873 .56614 L .53651 .566 L F
.626 .856 .485 r
.53651 .566 m .53704 .56508 L .5373 .56495 L F
.795 .31 0 r
.53873 .56614 m .53704 .56508 L .53651 .566 L F
.702 .247 0 r
.53704 .56508 m .53796 .56658 L .53685 .56517 L F
.53704 .56508 m .53685 .56517 L .5368 .56511 L F
.626 .856 .485 r
.5373 .56495 m .53704 .56508 L .53881 .56295 L F
.868 .938 .566 r
.53881 .56295 m .53704 .56508 L .5389 .56114 L F
.547 .369 .592 r
.4998 .56031 m .5038 .56037 L .50243 .55624 L F
.392 .281 .607 r
.50243 .55624 m .50474 .55864 L .50548 .55558 L F
.50243 .55624 m .5038 .56037 L .50474 .55864 L F
.815 .448 .362 r
.54993 .5255 m .55402 .52851 L .55378 .5261 L F
0 .179 .705 r
.54264 .57535 m .54435 .5769 L .54293 .57342 L F
0 .268 .773 r
.82857 .40364 m .82761 .40403 L .82678 .40304 L F
.82857 .40364 m .82955 .40543 L .82761 .40403 L F
.558 .691 .929 r
.32724 .54705 m .33007 .54852 L .32961 .54648 L F
.772 .639 .714 r
.32724 .54705 m .32772 .55232 L .33007 .54852 L F
0 .416 .836 r
.27301 .65429 m .27106 .65353 L .27041 .65489 L F
.346 .67 .975 r
.29999 .53417 m .29943 .5356 L .29811 .53383 L F
.29999 .53417 m .30171 .53573 L .29943 .5356 L F
.598 .654 .876 r
.34245 .54148 m .33843 .53916 L .34194 .54043 L F
.068 .504 .896 r
.34277 .54064 m .34245 .54148 L .34194 .54043 L F
.34277 .54064 m .34351 .54125 L .34245 .54148 L F
.64 .472 .639 r
.32093 .63366 m .32133 .63654 L .31846 .63657 L F
.457 .297 .574 r
.32319 .63039 m .32325 .63304 L .32093 .63366 L F
.452 .282 .559 r
.32325 .63304 m .32306 .63574 L .32093 .63366 L F
.364 .276 .621 r
.32306 .63574 m .32133 .63654 L .32093 .63366 L F
.304 0 .161 r
.19154 .56892 m .19022 .57147 L .188 .57198 L F
.258 0 .137 r
.1923 .57076 m .19154 .56892 L .19352 .56816 L F
.1923 .57076 m .19022 .57147 L .19154 .56892 L F
.286 .569 .935 r
.19431 .62353 m .19393 .62176 L .19189 .62069 L F
.19431 .62353 m .19591 .62351 L .19393 .62176 L F
.749 .54 .613 r
.304 .60554 m .30784 .60273 L .30511 .60328 L F
.948 .958 .696 r
.82169 .41924 m .82307 .41455 L .82064 .4179 L F
.257 0 .082 r
.27984 .62382 m .28168 .62347 L .28302 .62132 L F
.241 0 .073 r
.28302 .62132 m .28375 .62283 L .28471 .61981 L F
.28302 .62132 m .28168 .62347 L .28375 .62283 L F
.536 .674 .927 r
.20052 .629 m .20475 .63082 L .20476 .63021 L F
.454 .651 .944 r
.20476 .63021 m .20475 .63082 L .20594 .62923 L F
.266 .383 .796 r
.20475 .63082 m .2072 .63261 L .20594 .62923 L F
.269 .187 .575 r
.31209 .58243 m .31105 .58525 L .31025 .58478 L F
.43 .414 .74 r
.31105 .58525 m .3119 .59052 L .31025 .58478 L F
.658 .674 .854 r
.25238 .68518 m .25249 .68672 L .2548 .68549 L F
.577 .32 .49 r
.80363 .41413 m .8062 .4115 L .8041 .4128 L F
.779 .546 .583 r
.28362 .54965 m .27943 .54714 L .28169 .54656 L F
.28362 .54965 m .27931 .55023 L .27943 .54714 L F
.515 .913 .816 r
.28289 .54865 m .28065 .54978 L .28168 .54981 L F
.188 .72 .777 r
.28235 .54982 m .28168 .54981 L .27931 .55023 L F
0 0 0 r
.2794 .55042 m .27931 .55023 L .28168 .54981 L F
.515 .913 .816 r
.28065 .54978 m .2794 .55042 L .28168 .54981 L F
.188 .72 .777 r
.28362 .54965 m .28168 .54981 L .28235 .54982 L F
.478 .896 .887 r
.28388 .54885 m .28362 .54965 L .28552 .55006 L F
.28388 .54885 m .28168 .54981 L .28362 .54965 L F
.623 .122 0 r
.54747 .55469 m .5485 .55605 L .54981 .55719 L F
0 0 .506 r
.54937 .55621 m .54954 .55745 L .5485 .55605 L F
.97 .667 .277 r
.5485 .55605 m .54985 .55909 L .54981 .55719 L F
0 0 .506 r
.54954 .55745 m .54969 .5585 L .5485 .55605 L F
.623 .122 0 r
.5464 .55353 m .5485 .55605 L .54747 .55469 L F
.14 0 0 r
.34131 .57003 m .34396 .56987 L .34522 .56918 L F
.382 .397 .751 r
.34522 .56918 m .34665 .56889 L .34603 .56509 L F
.434 0 .003 r
.34396 .56987 m .34665 .56889 L .34522 .56918 L F
0 0 0 r
.19848 .54671 m .19659 .54778 L .19444 .54907 L F
.526 .421 .678 r
.35665 .56546 m .3571 .56943 L .35472 .56954 L F
.467 .386 .682 r
.3571 .56943 m .35546 .57208 L .35472 .56954 L F
.344 .789 .958 r
.17281 .74693 m .17543 .7466 L .17087 .74639 L F
.17281 .74693 m .17543 .7466 L .17087 .74639 L F
.628 .066 0 r
.24352 .62397 m .24757 .62598 L .2452 .62489 L F
.113 .576 .916 r
.24886 .62615 m .2452 .62489 L .24757 .62598 L F
.635 .072 0 r
.20314 .60958 m .20549 .61145 L .2075 .61212 L F
.997 .788 .437 r
.20633 .6134 m .2075 .61212 L .20549 .61145 L F
.20633 .6134 m .20726 .61476 L .2075 .61212 L F
.587 .081 .018 r
.50324 .56103 m .50235 .56182 L .4998 .56031 L F
.50584 .56158 m .50235 .56182 L .50324 .56103 L F
0 .235 .671 r
.4998 .56031 m .50235 .56182 L .50095 .56077 L F
.984 .716 .43 r
.50095 .56077 m .50103 .56297 L .50235 .56182 L F
.50103 .56297 m .50105 .56375 L .50235 .56182 L F
.838 .787 .803 r
.50535 .56027 m .50235 .56182 L .50584 .56158 L F
0 .235 .671 r
.4998 .56031 m .50074 .56069 L .5038 .56037 L F
.838 .787 .803 r
.50474 .55864 m .50338 .56045 L .50535 .56027 L F
.50338 .56045 m .50235 .56182 L .50535 .56027 L F
0 .235 .671 r
.50074 .56069 m .50095 .56077 L .50306 .56048 L F
.50074 .56069 m .50306 .56048 L .5038 .56037 L F
.977 .841 .643 r
.55494 .53745 m .55559 .54095 L .55676 .5387 L F
0 0 .427 r
.26642 .55596 m .26705 .55496 L .26655 .55274 L F
.113 .412 .86 r
.26642 .55596 m .26823 .55712 L .26705 .55496 L F
.145 .283 .748 r
.29267 .60559 m .29408 .60911 L .29534 .60914 L F
.105 0 0 r
.29534 .60914 m .29408 .60911 L .29139 .61054 L F
.881 .981 .829 r
.26375 .67967 m .26473 .67674 L .26212 .67912 L F
.26375 .67967 m .26629 .67669 L .26473 .67674 L F
.734 .212 0 r
.2638 .68136 m .26375 .67967 L .26212 .67912 L F
.405 .316 .642 r
.26597 .68195 m .264 .68296 L .26375 .67967 L F
.734 .212 0 r
.2638 .68136 m .26597 .68195 L .26375 .67967 L F
0 0 0 r
.23376 .72163 m .23173 .72301 L .23027 .72514 L F
0 0 .474 r
.33728 .5655 m .33791 .56119 L .33867 .56335 L F
.687 .801 .936 r
.34096 .56559 m .33867 .56335 L .33921 .56155 L F
.34096 .56559 m .33728 .5655 L .33867 .56335 L F
.604 .418 .603 r
.32815 .62694 m .32573 .62455 L .3283 .62422 L F
.32815 .62694 m .3256 .62736 L .32573 .62455 L F
.012 0 0 r
.26934 .55034 m .27131 .55037 L .27626 .55042 L F
.039 .316 .802 r
.27626 .55042 m .27389 .54571 L .27323 .54772 L F
.27626 .55042 m .27725 .55082 L .27389 .54571 L F
.572 .912 .971 r
.27626 .55042 m .27435 .5494 L .27725 .55082 L F
.27626 .55042 m .27131 .55037 L .27435 .5494 L F
.509 .38 .64 r
.30887 .58964 m .30458 .59372 L .30452 .59067 L F
.298 .794 .836 r
.26473 .67674 m .26629 .67669 L .26848 .67612 L F
.173 .264 .718 r
.30871 .60143 m .30688 .60114 L .30906 .59996 L F
0 0 0 r
.31119 .59842 m .30871 .60143 L .30906 .59996 L F
.693 .627 .779 r
.21145 .63311 m .2128 .63675 L .21496 .63487 L F
.394 .261 .579 r
.30186 .57483 m .30363 .57178 L .30097 .57285 L F
.30186 .57483 m .30376 .57428 L .30363 .57178 L F
.534 .461 .72 r
.30211 .57772 m .30376 .57428 L .30186 .57483 L F
.467 .386 .682 r
.3571 .56943 m .35752 .57141 L .35546 .57208 L F
.457 .255 .516 r
.35752 .57141 m .35508 .5747 L .35546 .57208 L F
.051 0 0 r
.27847 .59268 m .28272 .59066 L .27924 .59278 L F
.27847 .59268 m .27983 .5926 L .28272 .59066 L F
.841 .991 .731 r
.28272 .59066 m .28106 .59066 L .28377 .58911 L F
.28272 .59066 m .27983 .5926 L .28106 .59066 L F
.624 .354 .488 r
.31846 .63657 m .32073 .63892 L .31815 .639 L F
.619 .354 .494 r
.32133 .63654 m .32073 .63892 L .31846 .63657 L F
.314 .456 .843 r
.19695 .62532 m .19789 .62323 L .19591 .62351 L F
.19695 .62532 m .1997 .62667 L .19789 .62323 L F
.502 .875 .978 r
.18211 .82675 m .18393 .82718 L .18431 .82606 L F
.18211 .82675 m .18393 .82718 L .18431 .82606 L F
.682 .56 .71 r
.35377 .55308 m .35126 .55614 L .35141 .55371 L F
.401 0 0 r
.52343 .52213 m .52546 .52265 L .52732 .52251 L F
.485 0 0 r
.52546 .52265 m .52975 .52308 L .52732 .52251 L F
.382 .631 .953 r
.32627 .5379 m .32533 .53951 L .32427 .5379 L F
.32627 .5379 m .3282 .53982 L .32533 .53951 L F
.191 0 0 r
.27161 .5561 m .27069 .55681 L .26823 .55712 L F
.034 0 .222 r
.27346 .55346 m .27304 .55611 L .27161 .5561 L F
.02 0 0 r
.27161 .5561 m .27304 .55611 L .27069 .55681 L F
.504 .73 .974 r
.16922 .60468 m .17072 .6061 L .17171 .60417 L F
.243 .406 .826 r
.17072 .6061 m .17348 .60802 L .17171 .60417 L F
.613 .46 .65 r
.32576 .63003 m .32301 .62785 L .3256 .62736 L F
.32576 .63003 m .32319 .63039 L .32301 .62785 L F
.894 .785 .734 r
.54929 .56844 m .5503 .5719 L .55108 .56957 L F
.736 .903 .524 r
.26072 .67489 m .26222 .67303 L .26013 .67628 L F
.788 .776 .842 r
.26211 .67103 m .26222 .67303 L .26072 .67489 L F
.685 .76 .909 r
.19904 .60488 m .1996 .60652 L .19606 .60588 L F
.129 .369 .828 r
.20011 .6048 m .1996 .60652 L .19904 .60488 L F
.23 .487 .893 r
.20011 .6048 m .20268 .60796 L .1996 .60652 L F
.142 .434 .872 r
.20314 .60958 m .1996 .60652 L .20268 .60796 L F
.77 .981 .909 r
.28322 .59668 m .28676 .59423 L .28596 .59461 L F
.048 0 .114 r
.28596 .59461 m .28244 .59917 L .28322 .59668 L F
.425 .41 .739 r
.32273 .56902 m .32596 .57161 L .3252 .56838 L F
0 0 0 r
.76781 .39734 m .76583 .40003 L .76782 .39789 L F
.201 .488 .899 r
.77062 .3969 m .77124 .39861 L .76781 .39734 L F
.77062 .3969 m .76781 .39734 L .76782 .39789 L F
.528 .202 .359 r
.30356 .64298 m .30556 .64476 L .30313 .64484 L F
.537 .2 .344 r
.30607 .64288 m .30556 .64476 L .30356 .64298 L F
.199 .336 .778 r
.31667 .54969 m .31687 .55326 L .31443 .55025 L F
.31667 .54969 m .3179 .55322 L .31687 .55326 L F
.802 .798 .848 r
.26398 .64507 m .26644 .64779 L .26864 .64525 L F
.351 .083 .361 r
.27512 .63001 m .2772 .62929 L .27763 .62729 L F
.394 .26 .578 r
.27763 .62729 m .27964 .62683 L .27984 .62382 L F
.552 .367 .584 r
.2772 .62929 m .27964 .62683 L .27763 .62729 L F
.935 .654 .484 r
.51246 .54223 m .5113 .54409 L .51292 .54404 L F
.51292 .54404 m .5113 .54409 L .51246 .54223 L F
.606 .464 .662 r
.51246 .54223 m .51292 .54404 L .51479 .54115 L F
.576 .284 .436 r
.25548 .67351 m .25223 .67246 L .25458 .67008 L F
.798 .577 .601 r
.25198 .67591 m .25548 .67351 L .25447 .67305 L F
.25198 .67591 m .25608 .67607 L .25548 .67351 L F
.006 .152 .667 r
.25639 .67228 m .25548 .67351 L .25458 .67008 L F
.545 .897 .976 r
.25447 .67305 m .25548 .67351 L .25639 .67228 L F
.049 .305 .793 r
.20354 .60791 m .20314 .60958 L .20268 .60796 L F
0 .228 .741 r
.20426 .60961 m .20314 .60958 L .20354 .60791 L F
.20426 .60961 m .20549 .61145 L .20314 .60958 L F
.151 .085 .522 r
.2866 .57825 m .28778 .57338 L .28567 .57588 L F
.2866 .57825 m .28783 .57741 L .28778 .57338 L F
.083 0 .421 r
.28652 .58072 m .28783 .57741 L .2866 .57825 L F
0 0 .336 r
.27834 .61059 m .27759 .60894 L .27904 .60825 L F
.27834 .61059 m .27732 .61181 L .27759 .60894 L F
.079 0 0 r
.28802 .616 m .28799 .61514 L .28492 .61788 L F
.002 0 .268 r
.28997 .61125 m .28799 .61514 L .28919 .6143 L F
.626 .496 .685 r
.28802 .616 m .28919 .6143 L .28799 .61514 L F
.306 0 .21 r
.23742 .54951 m .23834 .5499 L .23642 .54983 L F
.23806 .54931 m .23834 .5499 L .23742 .54951 L F
.341 0 0 r
.23797 .54983 m .24028 .55064 L .23834 .5499 L F
.571 .217 .329 r
.23802 .54981 m .24028 .55064 L .23797 .54983 L F
.304 0 0 r
.23834 .5499 m .24028 .55064 L .23882 .55011 L F
.297 0 0 r
.24438 .54862 m .24272 .54908 L .23986 .54811 L F
.342 0 0 r
.24272 .54908 m .23806 .54931 L .23986 .54811 L F
.341 0 0 r
.23797 .54983 m .23834 .5499 L .23806 .54931 L F
.342 0 0 r
.24272 .54908 m .23797 .54983 L .23806 .54931 L F
.662 .381 .485 r
.24468 .54798 m .23797 .54983 L .24272 .54908 L F
.571 .217 .329 r
.24468 .54798 m .24028 .55064 L .23802 .54981 L F
.304 0 0 r
.23882 .55011 m .24028 .55064 L .23937 .55034 L F
.004 0 0 r
.23806 .54843 m .23642 .54983 L .23535 .54981 L F
.025 0 0 r
.23806 .54931 m .23642 .54983 L .23806 .54843 L F
.313 .773 .948 r
.23834 .5499 m .23647 .54939 L .23431 .54967 L F
.304 0 0 r
.23834 .5499 m .23937 .55034 L .23647 .54939 L F
.313 .773 .948 r
.23834 .5499 m .23741 .54985 L .23642 .54983 L F
.23741 .54985 m .23431 .54967 L .23642 .54983 L F
.004 0 0 r
.23535 .54981 m .23642 .54983 L .23437 .55031 L F
.025 0 0 r
.23806 .54931 m .23806 .54843 L .23986 .54811 L F
.64 .71 .898 r
.16151 .75406 m .16384 .75318 L .16081 .75315 L F
.995 .803 .436 r
.54026 .56899 m .53999 .57209 L .53912 .57049 L F
0 0 .51 r
.53873 .56614 m .54026 .56899 L .53973 .56757 L F
.982 .844 .457 r
.54026 .56899 m .53912 .57049 L .53973 .56757 L F
.921 .564 .336 r
.34411 .57938 m .34425 .58121 L .34243 .57996 L F
.619 .704 .906 r
.34383 .56409 m .34096 .56559 L .33921 .56155 L F
.077 0 0 r
.34383 .56409 m .33982 .5678 L .34096 .56559 L F
.883 .781 .743 r
.54929 .56844 m .54764 .57178 L .5503 .5719 L F
.816 .663 .694 r
.54764 .57178 m .55021 .5746 L .5503 .5719 L F
.526 .464 .729 r
.35643 .58072 m .35418 .58135 L .3537 .57887 L F
.456 .259 .524 r
.35643 .58072 m .35631 .58345 L .35418 .58135 L F
.326 .25 .616 r
.35418 .58135 m .35631 .58345 L .35465 .58347 L F
.239 .299 .724 r
.1908 .62092 m .19176 .62061 L .18866 .61752 L F
.1908 .62092 m .19189 .62069 L .19176 .62061 L F
.498 .533 .824 r
.18929 .59602 m .18857 .59943 L .18668 .59597 L F
.18929 .59602 m .19066 .59884 L .18857 .59943 L F
.737 .521 .6 r
.19066 .59884 m .18711 .6004 L .18857 .59943 L F
0 0 .485 r
.4657 .63804 m .46731 .64115 L .46742 .64096 L F
.489 .793 .999 r
.32064 .55476 m .31993 .55632 L .31862 .55468 L F
.32064 .55476 m .32219 .55587 L .31993 .55632 L F
.866 .729 .709 r
.34406 .56282 m .33921 .56155 L .3413 .55882 L F
.619 .704 .906 r
.34383 .56409 m .33921 .56155 L .34406 .56282 L F
.717 .312 .28 r
.34406 .56282 m .34603 .56509 L .34383 .56409 L F
.977 .841 .643 r
.55494 .53745 m .55416 .54011 L .55559 .54095 L F
.995 .823 .557 r
.5537 .54251 m .55559 .54095 L .55416 .54011 L F
.5537 .54251 m .55495 .54398 L .55559 .54095 L F
.119 .62 .904 r
.29405 .53271 m .29811 .53383 L .29526 .53328 L F
.68 .603 .763 r
.22533 .72771 m .22711 .72982 L .22912 .72778 L F
.438 0 0 r
.24757 .62598 m .25132 .62611 L .24886 .62615 L F
.683 .373 .444 r
.5459 .53851 m .54276 .54011 L .54226 .53773 L F
.5459 .53851 m .54657 .54075 L .54276 .54011 L F
.193 .72 .843 r
.2307 .536 m .2332 .53574 L .23539 .53594 L F
.106 .66 .784 r
.2332 .53574 m .2376 .53569 L .23539 .53594 L F
.387 .033 .237 r
.188 .57198 m .1849 .57426 L .18584 .57256 L F
.074 0 0 r
.27512 .63001 m .27558 .631 L .2772 .62929 L F
.27512 .63001 m .27349 .63176 L .27558 .631 L F
.457 .24 .495 r
.31709 .5465 m .31443 .55025 L .31469 .54732 L F
.502 .909 .851 r
.25791 .62446 m .25361 .62593 L .25585 .62575 L F
.093 .651 .755 r
.25775 .62432 m .25791 .62446 L .25585 .62575 L F
.25775 .62432 m .26031 .62428 L .25791 .62446 L F
.483 .648 .931 r
.17847 .61372 m .18083 .61367 L .17836 .61203 L F
.17847 .61372 m .18214 .61519 L .18083 .61367 L F
.307 .306 .695 r
.76782 .39789 m .76583 .40003 L .76881 .40194 L F
.337 .411 .79 r
.76718 .40617 m .77016 .40785 L .7689 .40408 L F
.064 0 .231 r
.27105 .6092 m .27035 .61157 L .27249 .60822 L F
.441 .611 .92 r
.21894 .63671 m .22137 .63686 L .21911 .63457 L F
.253 0 0 r
.23835 .72165 m .2403 .71954 L .23754 .72111 L F
.786 .556 .587 r
.23835 .72165 m .24267 .71912 L .2403 .71954 L F
.481 0 0 r
.17836 .61203 m .17913 .61257 L .17393 .60978 L F
.269 .442 .848 r
.17836 .61203 m .18083 .61367 L .17948 .61047 L F
.093 .19 .674 r
.17948 .61047 m .17913 .61257 L .17836 .61203 L F
.148 .394 .843 r
.27075 .65752 m .27039 .66074 L .2701 .65782 L F
.72 .44 .502 r
.27075 .65752 m .27529 .65858 L .27447 .66058 L F
.148 .394 .843 r
.27075 .65752 m .27241 .65888 L .27316 .65812 L F
.27241 .65888 m .27447 .66058 L .27316 .65812 L F
.525 .917 .817 r
.27369 .65759 m .27316 .65812 L .27514 .65694 L F
.148 .394 .843 r
.27075 .65752 m .27316 .65812 L .27039 .66074 L F
.525 .917 .817 r
.27106 .65876 m .27316 .65812 L .27369 .65759 L F
.285 0 0 r
.23111 .62381 m .22931 .62337 L .22705 .62337 L F
.526 .464 .729 r
.35643 .58072 m .3537 .57887 L .35557 .57709 L F
.717 .265 .177 r
.26196 .64271 m .26316 .64473 L .25963 .64205 L F
.486 .885 .731 r
.24468 .54798 m .24272 .54908 L .24438 .54862 L F
.479 .208 .425 r
.23838 .72602 m .24038 .72829 L .23769 .72862 L F
.129 .634 .902 r
.21701 .61858 m .21493 .6185 L .21323 .61779 L F
.084 .536 .905 r
.21898 .62025 m .21493 .6185 L .21701 .61858 L F
.587 .703 .923 r
.79764 .42835 m .7992 .42584 L .79663 .4266 L F
.79764 .42835 m .8004 .42763 L .7992 .42584 L F
0 0 0 r
.27709 .55095 m .27567 .55256 L .27346 .55346 L F
.27761 .55169 m .27709 .55095 L .27931 .55023 L F
.27761 .55169 m .27567 .55256 L .27709 .55095 L F
.315 .596 .945 r
.21944 .61895 m .21898 .62025 L .21701 .61858 L F
.21944 .61895 m .22107 .62071 L .21898 .62025 L F
.251 0 .262 r
.33957 .60268 m .3387 .60513 L .33684 .60573 L F
.372 .233 .559 r
.34148 .59927 m .34152 .60192 L .33957 .60268 L F
.456 .215 .459 r
.34152 .60192 m .3387 .60513 L .33957 .60268 L F
.539 .324 .537 r
.33554 .61175 m .33531 .61467 L .33258 .6148 L F
.645 .537 .717 r
.3374 .60813 m .33797 .61171 L .33554 .61175 L F
.601 .378 .549 r
.33785 .61424 m .33554 .61175 L .33797 .61171 L F
.33785 .61424 m .33531 .61467 L .33554 .61175 L F
.446 .245 .513 r
.29714 .55648 m .29935 .55857 L .29952 .55574 L F
.29714 .55648 m .29722 .55956 L .29935 .55857 L F
0 0 .118 r
.28447 .58719 m .28611 .58626 L .28657 .58379 L F
0 0 .123 r
.28377 .58911 m .28611 .58626 L .28447 .58719 L F
.74 .812 .909 r
.25378 .67726 m .25608 .67607 L .25198 .67591 L F
.522 .784 .992 r
.22514 .63825 m .2293 .63876 L .22752 .63777 L F
.461 .734 .986 r
.2293 .63876 m .22813 .63672 L .22752 .63777 L F
.2293 .63876 m .23142 .63852 L .22813 .63672 L F
0 0 .066 r
.27447 .66058 m .27529 .65858 L .27657 .6573 L F
.538 .511 .774 r
.35665 .56546 m .35351 .56216 L .35555 .56108 L F
.705 .651 .794 r
.80407 .42799 m .80513 .42351 L .80298 .42656 L F
.80407 .42799 m .80635 .42682 L .80513 .42351 L F
.476 .672 .95 r
.20052 .629 m .20128 .62667 L .1997 .62667 L F
.20052 .629 m .20476 .63021 L .20128 .62667 L F
.872 .801 .778 r
.24141 .71029 m .23721 .71256 L .24177 .71313 L F
.415 .384 .716 r
.28604 .56278 m .28715 .55841 L .28497 .55871 L F
.28604 .56278 m .28782 .56205 L .28715 .55841 L F
.325 .169 .51 r
.28604 .56278 m .28771 .56461 L .28782 .56205 L F
.221 .155 .566 r
.28604 .56278 m .28638 .56563 L .28771 .56461 L F
.777 .685 .762 r
.34937 .58768 m .3456 .5873 L .34814 .58413 L F
.785 .763 .834 r
.34937 .58768 m .34527 .58857 L .3456 .5873 L F
.427 .815 .988 r
.2711 .53286 m .27021 .53388 L .26898 .53308 L F
.2711 .53286 m .2726 .53351 L .27021 .53388 L F
.007 .153 .667 r
.26013 .67628 m .26212 .67912 L .26072 .67489 L F
0 .016 .537 r
.28657 .58379 m .28785 .58278 L .28652 .58072 L F
.243 0 .216 r
.28657 .58379 m .2882 .58546 L .28785 .58278 L F
.28657 .58379 m .28611 .58626 L .2882 .58546 L F
.745 .829 .916 r
.81043 .41692 m .80794 .41804 L .81141 .41837 L F
.63 .78 .953 r
.81043 .41692 m .81141 .41837 L .81416 .41747 L F
.433 .857 .717 r
.32798 .55261 m .33063 .55119 L .32772 .55232 L F
.057 0 0 r
.2716 .54627 m .26759 .54855 L .27007 .54628 L F
0 0 0 r
.32516 .5841 m .32327 .58514 L .32187 .58622 L F
.697 .64 .788 r
.54548 .58077 m .54678 .58442 L .54932 .58354 L F
.753 .71 .811 r
.8292 .41208 m .83285 .41261 L .83144 .41106 L F
.703 .593 .73 r
.83285 .41261 m .83358 .40781 L .83144 .41106 L F
.83285 .41261 m .83561 .40964 L .83358 .40781 L F
.485 .367 .644 r
.33516 .61716 m .33258 .6148 L .33531 .61467 L F
.33516 .61716 m .33282 .61784 L .33258 .6148 L F
.702 .467 .566 r
.3119 .59052 m .30634 .59498 L .30887 .58964 L F
.39 .222 .529 r
.30984 .59658 m .3115 .59605 L .31173 .59334 L F
.224 .073 .455 r
.31173 .59334 m .31296 .59384 L .31335 .58989 L F
.058 .222 .718 r
.31225 .59355 m .3128 .59414 L .31287 .5938 L F
.31173 .59334 m .31274 .59426 L .31225 .59355 L F
.31274 .59426 m .31421 .59562 L .31225 .59355 L F
.3 .773 .932 r
.3115 .59605 m .31421 .59562 L .31173 .59334 L F
.702 .467 .566 r
.31079 .59141 m .31189 .59504 L .30634 .59498 L F
.31189 .59303 m .31189 .59504 L .31079 .59141 L F
.118 0 .413 r
.31335 .58989 m .31296 .59384 L .31398 .59247 L F
.501 .238 .448 r
.31548 .58925 m .31491 .59122 L .3174 .59063 L F
.31548 .58925 m .31491 .59122 L .3174 .59063 L F
.348 0 0 r
.31614 .59089 m .31491 .59122 L .3174 .59063 L F
.118 0 .413 r
.31378 .59026 m .31389 .59149 L .31491 .59122 L F
.31335 .58989 m .31398 .59247 L .31378 .59026 L F
.255 .115 .491 r
.31363 .59251 m .3119 .59052 L .31375 .5899 L F
.31363 .59251 m .31375 .5899 L .31377 .59016 L F
.118 0 .413 r
.31389 .59149 m .31398 .59247 L .31491 .59122 L F
.31335 .58989 m .31491 .59122 L .31548 .58925 L F
.142 0 .394 r
.31491 .59122 m .31363 .59251 L .31379 .58988 L F
.31491 .59122 m .31379 .58988 L .31548 .58925 L F
.973 .762 .559 r
.31548 .58925 m .31299 .5912 L .31491 .59122 L F
.348 0 0 r
.31323 .59151 m .31491 .59122 L .31614 .59089 L F
.255 .115 .491 r
.31377 .59016 m .31375 .5899 L .31379 .58988 L F
.31363 .59251 m .31189 .59504 L .3119 .59052 L F
.808 .986 .886 r
.31077 .59319 m .31189 .59504 L .31292 .59354 L F
.3131 .59264 m .31292 .59354 L .31363 .59251 L F
.31077 .59319 m .31292 .59354 L .3131 .59264 L F
.058 .222 .718 r
.31287 .5938 m .31421 .59562 L .31296 .59384 L F
.3128 .59414 m .31421 .59562 L .31287 .5938 L F
.702 .467 .566 r
.3119 .59052 m .31189 .59303 L .31079 .59141 L F
.001 0 0 r
.31335 .58989 m .31495 .58941 L .31668 .58787 L F
.31495 .58941 m .31548 .58925 L .31552 .58921 L F
.31495 .58941 m .31552 .58921 L .31668 .58787 L F
.43 .414 .74 r
.3119 .5905 m .31379 .58988 L .3119 .59052 L F
.31105 .58525 m .31376 .58984 L .3119 .5905 L F
.31376 .58984 m .31379 .58988 L .3119 .5905 L F
.091 .52 .906 r
.16302 .60304 m .16705 .60534 L .16526 .6019 L F
.537 .608 .871 r
.16526 .6019 m .16705 .60534 L .16922 .60468 L F
.719 .726 .855 r
.2072 .63261 m .20948 .63446 L .21145 .63311 L F
.752 .801 .892 r
.19606 .60588 m .19305 .60771 L .19155 .60573 L F
.185 0 .108 r
.26741 .55107 m .26655 .55274 L .26934 .55034 L F
.11 .66 .699 r
.2376 .53569 m .23931 .53542 L .24153 .53507 L F
.286 .786 .851 r
.23931 .53542 m .24381 .53492 L .24153 .53507 L F
.01 .047 .552 r
.27046 .64468 m .26989 .64913 L .27195 .64857 L F
.104 0 0 r
.20627 .54295 m .21007 .54113 L .20765 .54135 L F
.736 .492 .56 r
.30688 .60114 m .30784 .60273 L .30288 .60192 L F
.728 .49 .567 r
.30688 .60114 m .30784 .60273 L .30925 .60186 L F
.173 .264 .718 r
.30871 .60143 m .30784 .60273 L .30688 .60114 L F
0 0 0 r
.20443 .56149 m .20378 .56193 L .20233 .56246 L F
.345 0 .196 r
.20378 .56193 m .20075 .56422 L .20233 .56246 L F
.508 .659 .928 r
.18083 .61367 m .18214 .61519 L .18426 .61481 L F
.614 .246 .322 r
.29458 .64531 m .29053 .64741 L .29107 .64633 L F
.29458 .64531 m .29295 .64784 L .29053 .64741 L F
.471 .043 .144 r
.29706 .64572 m .29295 .64784 L .29458 .64531 L F
.962 .816 .653 r
.54929 .56351 m .55141 .56264 L .54975 .5616 L F
.54929 .56351 m .55115 .56489 L .55141 .56264 L F
.31 .329 .719 r
.15702 .60324 m .15873 .60269 L .15764 .59929 L F
.152 0 .261 r
.15702 .60324 m .15651 .60515 L .15873 .60269 L F
.15873 .60269 m .15651 .60515 L .15702 .60324 L F
.931 .797 .69 r
.54765 .56727 m .55115 .56489 L .54929 .56351 L F
.54765 .56727 m .54929 .56844 L .55115 .56489 L F
.581 .47 .692 r
.33037 .62121 m .3307 .62382 L .3283 .62422 L F
.55 .348 .56 r
.3307 .62382 m .32815 .62694 L .3283 .62422 L F
.933 .723 .242 r
.82045 .40215 m .82046 .40474 L .82089 .40415 L F
0 0 0 r
.82089 .40415 m .82301 .40385 L .82401 .40379 L F
.82089 .40415 m .82046 .40474 L .82301 .40385 L F
.692 .561 .702 r
.31186 .59785 m .31613 .59953 L .31581 .59823 L F
.645 .594 .783 r
.30984 .59658 m .31301 .59743 L .31285 .59729 L F
.748 .729 .835 r
.31301 .59743 m .31528 .59611 L .3115 .59605 L F
.692 .561 .702 r
.31186 .59785 m .31528 .59611 L .31301 .59743 L F
.31292 .59731 m .31581 .59823 L .31528 .59611 L F
.31186 .59785 m .31581 .59823 L .31292 .59731 L F
.645 .594 .783 r
.31022 .59646 m .31285 .59729 L .3115 .59605 L F
.30984 .59658 m .31285 .59729 L .31022 .59646 L F
.851 .781 .783 r
.30784 .60273 m .30811 .60342 L .30925 .60186 L F
.742 .559 .646 r
.30719 .60648 m .30925 .60186 L .30811 .60342 L F
.30719 .60648 m .31163 .60571 L .30925 .60186 L F
.694 .585 .729 r
.30925 .60186 m .31362 .6026 L .31186 .59785 L F
.41 .191 .468 r
.31163 .60571 m .31362 .6026 L .30925 .60186 L F
.342 .039 .299 r
.1796 .55767 m .18089 .55872 L .18151 .55688 L F
.1796 .55767 m .17872 .55954 L .18089 .55872 L F
.455 .201 .439 r
.29912 .5813 m .30126 .58086 L .30211 .57772 L F
.534 .461 .72 r
.30211 .57772 m .30446 .5775 L .30376 .57428 L F
.587 .326 .488 r
.30211 .57772 m .30456 .58008 L .30446 .5775 L F
.30211 .57772 m .30126 .58086 L .30456 .58008 L F
.461 .195 .422 r
.264 .68296 m .2639 .68447 L .26136 .68554 L F
.316 .081 .39 r
.26561 .68445 m .264 .68296 L .26597 .68195 L F
.26561 .68445 m .2639 .68447 L .264 .68296 L F
.684 .772 .918 r
.24783 .55301 m .24609 .55439 L .24391 .55342 L F
.24783 .55301 m .24609 .55439 L .24391 .55342 L F
.624 .956 .804 r
.24783 .55301 m .24603 .5538 L .24609 .55439 L F
.372 .041 .268 r
.28671 .55303 m .28935 .5509 L .28552 .55006 L F
.28671 .55303 m .28882 .55256 L .28935 .5509 L F
.187 0 .193 r
.28935 .5509 m .29152 .55078 L .29323 .5492 L F
.28935 .5509 m .28882 .55256 L .29152 .55078 L F
.388 .325 .665 r
.35631 .58345 m .35405 .58687 L .35465 .58347 L F
.35631 .58345 m .35674 .58653 L .35405 .58687 L F
.494 .253 .478 r
.35674 .58653 m .354 .58939 L .35405 .58687 L F
.509 .299 .531 r
.54763 .55301 m .5485 .55605 L .5464 .55353 L F
.816 .666 .698 r
.51645 .52537 m .51809 .52522 L .51517 .52622 L F
.543 .217 .366 r
.51809 .52522 m .51419 .52869 L .51517 .52622 L F
.51809 .52522 m .51728 .52812 L .51419 .52869 L F
.453 .852 .659 r
.52089 .52588 m .51728 .52812 L .51809 .52522 L F
.651 .79 .948 r
.82028 .39929 m .8163 .39873 L .81977 .39761 L F
.572 .822 .992 r
.82042 .39811 m .82028 .39929 L .81977 .39761 L F
.82042 .39811 m .82209 .39886 L .82028 .39929 L F
.135 .663 .871 r
.28604 .53201 m .28556 .53253 L .28366 .53234 L F
.28604 .53201 m .28804 .53258 L .28556 .53253 L F
0 0 0 r
.50981 .54736 m .51292 .54404 L .5113 .54409 L F
.512 .292 .518 r
.51292 .54404 m .50981 .54736 L .5113 .54409 L F
0 0 0 r
.50981 .54736 m .51136 .54426 L .51292 .54404 L F
.512 .292 .518 r
.51292 .54404 m .5124 .547 L .50981 .54736 L F
.979 .825 .422 r
.51292 .54404 m .5117 .54617 L .51136 .54426 L F
.51292 .54404 m .5124 .547 L .5117 .54617 L F
.232 .194 .607 r
.15425 .59026 m .15543 .5864 L .1534 .58786 L F
.012 .07 .576 r
.33717 .55924 m .33765 .55462 L .33481 .55591 L F
.33717 .55924 m .33862 .55998 L .33765 .55462 L F
.33862 .55998 m .33863 .55991 L .33765 .55462 L F
.161 0 .343 r
.33717 .55924 m .33791 .56119 L .33865 .56 L F
.134 .157 .619 r
.33765 .55462 m .33793 .55613 L .3394 .55722 L F
.33793 .55613 m .33865 .56 L .3391 .55832 L F
.33793 .55613 m .3391 .55832 L .3394 .55722 L F
.815 .512 .478 r
.34181 .55805 m .34219 .55908 L .34363 .55618 L F
.34 0 .232 r
.34363 .55618 m .34219 .55908 L .34251 .55893 L F
.34373 .55625 m .34251 .55893 L .34555 .55742 L F
.34363 .55618 m .34251 .55893 L .34373 .55625 L F
.732 .403 .423 r
.33946 .55898 m .34203 .55996 L .34181 .55805 L F
.34203 .55996 m .34307 .56036 L .34241 .55914 L F
.519 .297 .517 r
.34307 .56036 m .34555 .55742 L .34219 .55908 L F
.257 .216 .619 r
.34181 .55805 m .34307 .56036 L .34219 .55908 L F
.732 .403 .423 r
.34203 .55996 m .34241 .55914 L .34181 .55805 L F
.918 .978 .748 r
.33791 .56119 m .33743 .55979 L .3392 .55749 L F
.33791 .56119 m .3392 .55749 L .33903 .55821 L F
.012 .07 .576 r
.33862 .55998 m .33865 .56 L .33863 .55991 L F
.918 .978 .748 r
.33791 .56119 m .3394 .55722 L .33865 .56 L F
.732 .403 .423 r
.33743 .55979 m .34003 .56005 L .33946 .55898 L F
.34003 .56005 m .34307 .56036 L .33946 .55898 L F
.918 .978 .748 r
.33903 .55821 m .3392 .55749 L .3394 .55722 L F
.296 0 0 r
.27349 .63176 m .2719 .63125 L .26954 .63237 L F
.158 .169 .621 r
.2937 .59969 m .29552 .60162 L .29542 .59904 L F
.2937 .59969 m .29479 .60249 L .29552 .60162 L F
.407 .374 .711 r
.15425 .59026 m .15489 .59412 L .15709 .59249 L F
.44 .507 .832 r
.15489 .59412 m .15819 .59613 L .15709 .59249 L F
.163 0 0 r
.17323 .56191 m .17513 .56181 L .17653 .56023 L F
0 0 0 r
.17653 .56023 m .17705 .56101 L .17872 .55954 L F
.17653 .56023 m .17513 .56181 L .17705 .56101 L F
.915 .657 .161 r
.53663 .52876 m .5334 .52864 L .53513 .5282 L F
.53663 .52876 m .53603 .52982 L .5334 .52864 L F
.53663 .52876 m .53666 .531 L .53603 .52982 L F
.53 .233 .407 r
.31224 .63962 m .31184 .64174 L .30931 .642 L F
.608 .303 .427 r
.31224 .63962 m .31443 .6418 L .31184 .64174 L F
.571 .307 .478 r
.31465 .6394 m .31443 .6418 L .31224 .63962 L F
.804 .564 .576 r
.3617 .54737 m .35859 .5468 L .35875 .54658 L F
.3617 .54737 m .36042 .54889 L .35859 .5468 L F
0 0 .082 r
.3617 .54737 m .35942 .55159 L .36042 .54889 L F
.3617 .54737 m .36049 .55146 L .35942 .55159 L F
.222 .017 .376 r
.36437 .5463 m .3617 .54737 L .35875 .54658 L F
.36437 .5463 m .36378 .54905 L .3617 .54737 L F
.388 .052 .269 r
.36378 .54905 m .36049 .55146 L .3617 .54737 L F
.567 .895 .985 r
.2785 .66378 m .27625 .66471 L .27551 .66413 L F
0 0 0 r
.2744 .66605 m .27625 .66471 L .2785 .66378 L F
.497 .339 .597 r
.35599 .54701 m .35612 .55011 L .35346 .55053 L F
.503 .363 .623 r
.35612 .55011 m .35377 .55308 L .35346 .55053 L F
.931 .557 .169 r
.79048 .4063 m .78861 .40272 L .78877 .40517 L F
.915 .736 .647 r
.78877 .40517 m .79006 .40883 L .79048 .4063 L F
0 0 0 r
.50981 .54736 m .51038 .54683 L .51136 .54426 L F
.786 .354 .222 r
.5124 .547 m .51038 .54683 L .50981 .54736 L F
.234 .342 .77 r
.33007 .56697 m .32883 .56875 L .32764 .56536 L F
.453 .646 .941 r
.33007 .56697 m .33123 .56895 L .32883 .56875 L F
.461 .841 .987 r
.30631 .53505 m .30585 .53631 L .30383 .53525 L F
.30631 .53505 m .30819 .53574 L .30585 .53631 L F
0 0 .086 r
.27802 .6125 m .27732 .61181 L .27834 .61059 L F
.27802 .6125 m .27691 .61421 L .27732 .61181 L F
0 .447 .819 r
.33921 .53893 m .33843 .53916 L .33705 .53801 L F
.33921 .53893 m .34194 .54043 L .33843 .53916 L F
.415 .228 .516 r
.32955 .56207 m .32938 .56468 L .32748 .56272 L F
.339 .221 .569 r
.32748 .56272 m .32938 .56468 L .32764 .56536 L F
.048 0 .114 r
.28596 .59461 m .28484 .59817 L .28244 .59917 L F
.694 .727 .875 r
.28873 .59308 m .28912 .59392 L .28596 .59461 L F
.014 0 .1 r
.28651 .59686 m .28596 .59461 L .28912 .59392 L F
.28651 .59686 m .28484 .59817 L .28596 .59461 L F
.749 .54 .613 r
.304 .60554 m .30811 .60342 L .30784 .60273 L F
.304 .60554 m .30719 .60648 L .30644 .60429 L F
.905 .549 .085 r
.30618 .60487 m .30719 .60648 L .304 .60554 L F
.30618 .60487 m .30767 .60788 L .30719 .60648 L F
.30767 .60788 m .30783 .60821 L .30719 .60648 L F
.749 .54 .613 r
.30644 .60429 m .30719 .60648 L .30811 .60342 L F
.421 .822 .981 r
.24381 .53492 m .24608 .53446 L .24779 .53505 L F
.379 .806 .968 r
.24826 .53414 m .24779 .53505 L .24608 .53446 L F
.24826 .53414 m .2501 .53468 L .24779 .53505 L F
.601 .409 .594 r
.32576 .63003 m .32325 .63304 L .32319 .63039 L F
.474 .715 .975 r
.32427 .5379 m .3221 .53823 L .32055 .53668 L F
.41 .191 .468 r
.31163 .60571 m .31339 .6054 L .31362 .6026 L F
.502 .331 .582 r
.31362 .6026 m .31613 .59953 L .31186 .59785 L F
.31362 .6026 m .3162 .60211 L .31613 .59953 L F
.574 .376 .574 r
.31339 .6054 m .3162 .60211 L .31362 .6026 L F
.05 0 0 r
.25215 .55437 m .2499 .55498 L .25184 .55357 L F
.134 0 .173 r
.31683 .57735 m .31624 .58019 L .3145 .57997 L F
.75 .866 .933 r
.31683 .57735 m .32016 .57506 L .31934 .5769 L F
.56 .374 .585 r
.5334 .52864 m .53092 .52855 L .53513 .5282 L F
.391 .284 .612 r
.3387 .60513 m .33901 .60779 L .33684 .60573 L F
.283 .273 .671 r
.33684 .60573 m .33901 .60779 L .3374 .60813 L F
0 0 .097 r
.26983 .62397 m .26949 .6262 L .2679 .62723 L F
0 0 .099 r
.26838 .62838 m .2679 .62723 L .26949 .6262 L F
.26838 .62838 m .26749 .62994 L .2679 .62723 L F
.131 .656 .878 r
.25117 .64092 m .25224 .64053 L .24985 .64081 L F
.25117 .64092 m .25415 .64098 L .25224 .64053 L F
.603 .097 .024 r
.79285 .4137 m .7938 .41252 L .79003 .41147 L F
.79285 .4137 m .79408 .41373 L .7938 .41252 L F
.011 0 .258 r
.3324 .55648 m .33179 .55947 L .3305 .56038 L F
.475 .143 .323 r
.3305 .56038 m .33216 .56162 L .32955 .56207 L F
.3305 .56038 m .33216 .56162 L .32955 .56207 L F
.693 .627 .779 r
.21145 .63311 m .21496 .63487 L .21327 .63526 L F
.558 .654 .9 r
.21496 .63487 m .21597 .63213 L .21327 .63526 L F
.353 .765 .98 r
.26715 .53235 m .26646 .5334 L .26482 .53263 L F
.26715 .53235 m .26898 .53308 L .26646 .5334 L F
.999 .802 .461 r
.27041 .65489 m .2701 .65782 L .26919 .65658 L F
0 0 0 r
.27154 .6549 m .27041 .65489 L .26919 .65658 L F
.27154 .6549 m .27301 .65429 L .27041 .65489 L F
0 0 .369 r
.33123 .56895 m .33245 .57127 L .33247 .57167 L F
.482 .323 .588 r
.33247 .57167 m .33528 .57235 L .33466 .56804 L F
.859 .492 .354 r
.33245 .57127 m .33528 .57235 L .33247 .57167 L F
.797 .704 .763 r
.54785 .58011 m .55111 .5808 L .55194 .57819 L F
.798 .702 .76 r
.54785 .58011 m .54932 .58354 L .55111 .5808 L F
.159 0 .231 r
.16817 .56607 m .16919 .56722 L .17023 .56547 L F
.16817 .56607 m .16746 .56817 L .16919 .56722 L F
.605 .606 .825 r
.33765 .55462 m .33481 .55591 L .33347 .55234 L F
.33765 .55462 m .33754 .55456 L .33568 .55355 L F
.33687 .5542 m .33347 .55234 L .33568 .55355 L F
0 .36 .737 r
.3343 .5528 m .33453 .55287 L .33427 .55278 L F
.33568 .55355 m .33453 .55287 L .3343 .5528 L F
.624 .412 .575 r
.33451 .55291 m .33568 .55355 L .33453 .55287 L F
.367 0 0 r
.33392 .55266 m .33568 .55355 L .33347 .55234 L F
0 .36 .737 r
.33568 .55355 m .33427 .55278 L .33392 .55266 L F
0 0 0 r
.33283 .55658 m .3324 .55648 L .33481 .55591 L F
.624 .412 .575 r
.33283 .55658 m .33568 .55355 L .33451 .55291 L F
.554 .124 .179 r
.33765 .55462 m .33405 .55609 L .33481 .55591 L F
.33405 .55609 m .33283 .55658 L .33336 .55641 L F
.33405 .55609 m .33336 .55641 L .33481 .55591 L F
.605 .606 .825 r
.33754 .55456 m .33687 .5542 L .33568 .55355 L F
.228 .662 .956 r
.33568 .55355 m .33773 .5536 L .33765 .55462 L F
.432 .246 .526 r
.33568 .55355 m .33546 .55544 L .33773 .5536 L F
.554 .124 .179 r
.33765 .55462 m .3353 .55684 L .33283 .55658 L F
.432 .246 .526 r
.33546 .55544 m .3353 .55684 L .33682 .55482 L F
.33546 .55544 m .33682 .55482 L .33773 .5536 L F
.76 .954 .64 r
.33773 .5536 m .3353 .55684 L .33765 .55462 L F
.624 .412 .575 r
.33283 .55658 m .3353 .55684 L .33568 .55355 L F
.539 0 0 r
.33773 .5536 m .33749 .55521 L .33481 .55309 L F
.33498 .55297 m .33481 .55309 L .33453 .55287 L F
.33773 .5536 m .33481 .55309 L .33498 .55297 L F
0 .113 .649 r
.33453 .55287 m .33749 .55521 L .33603 .55332 L F
.76 .559 .626 r
.33788 .55097 m .33773 .5536 L .33453 .55287 L F
0 .113 .649 r
.33453 .55287 m .33603 .55332 L .33546 .55259 L F
.624 .412 .575 r
.33283 .55658 m .33453 .55287 L .33151 .55411 L F
0 0 .411 r
.33254 .54933 m .33392 .55266 L .33347 .55234 L F
.33283 .54981 m .33392 .55266 L .33254 .54933 L F
.668 .125 0 r
.33397 .54821 m .33179 .54811 L .33117 .5471 L F
.33179 .54811 m .33063 .54806 L .33117 .5471 L F
.168 .706 .765 r
.33639 .54736 m .33063 .54806 L .33397 .54821 L F
.33639 .54736 m .33237 .54772 L .33063 .54806 L F
.33237 .54772 m .33223 .54773 L .33207 .54777 L F
.33237 .54772 m .33207 .54777 L .33063 .54806 L F
.668 .125 0 r
.33117 .5471 m .33063 .54806 L .32961 .54648 L F
.635 .09 0 r
.32724 .54705 m .32526 .54693 L .3227 .54524 L F
.583 .157 .198 r
.32961 .54648 m .32526 .54693 L .32724 .54705 L F
.32627 .54682 m .32775 .54851 L .32526 .54693 L F
.32961 .54648 m .32775 .54851 L .32627 .54682 L F
.488 .048 .129 r
.33063 .54806 m .32775 .54851 L .32961 .54648 L F
.712 .648 .783 r
.33063 .54806 m .32917 .55176 L .32784 .5487 L F
.32806 .54846 m .32784 .5487 L .32775 .54851 L F
.33063 .54806 m .32784 .5487 L .32806 .54846 L F
.27 .474 .874 r
.33063 .54806 m .33063 .55119 L .33037 .5513 L F
.33013 .54933 m .33037 .5513 L .32917 .55176 L F
.33063 .54806 m .33037 .5513 L .33013 .54933 L F
.449 0 0 r
.33745 .54828 m .33227 .54777 L .33639 .54736 L F
.135 0 .197 r
.33063 .54806 m .33218 .54792 L .33237 .5477 L F
.449 0 0 r
.33227 .54777 m .33205 .54775 L .33223 .54773 L F
.33227 .54777 m .33223 .54773 L .33639 .54736 L F
.135 0 .197 r
.33237 .5477 m .33231 .54781 L .33242 .5477 L F
.73 .659 .779 r
.33788 .55097 m .33223 .54785 L .33745 .54828 L F
.33223 .54785 m .33205 .54775 L .33227 .54777 L F
.33223 .54785 m .33227 .54777 L .33745 .54828 L F
.135 0 .197 r
.33223 .54785 m .33224 .54791 L .33237 .5477 L F
.73 .659 .779 r
.33788 .55097 m .33213 .54797 L .33223 .54785 L F
.135 0 .197 r
.33218 .54792 m .33221 .54791 L .33223 .54785 L F
.33221 .54791 m .33224 .54791 L .33223 .54785 L F
.33231 .54781 m .33224 .54791 L .33232 .54782 L F
.33231 .54781 m .33232 .54782 L .33242 .5477 L F
.73 .659 .779 r
.33788 .55097 m .33392 .55266 L .33213 .54797 L F
.33223 .54785 m .33213 .54797 L .33205 .54775 L F
0 0 .411 r
.3321 .54792 m .33347 .55234 L .33063 .54806 L F
.27 .474 .874 r
.33063 .54806 m .33347 .55234 L .33063 .55119 L F
.135 0 .197 r
.33063 .54806 m .32956 .55121 L .33216 .54801 L F
.3321 .54792 m .33216 .54801 L .33224 .54791 L F
.33063 .54806 m .33216 .54801 L .3321 .54792 L F
0 0 .411 r
.3321 .54792 m .33283 .54981 L .33254 .54933 L F
.33205 .54775 m .33213 .54797 L .3321 .54792 L F
.33213 .54797 m .33283 .54981 L .3321 .54792 L F
.135 0 .197 r
.33063 .54806 m .33242 .5477 L .33273 .54732 L F
.168 .706 .765 r
.33223 .54773 m .33221 .54774 L .33063 .54806 L F
.116 0 .151 r
.33204 .54777 m .33179 .54793 L .33063 .54806 L F
0 0 .411 r
.33179 .54793 m .3318 .54795 L .33063 .54806 L F
.116 0 .151 r
.33179 .54793 m .33075 .54863 L .33063 .54806 L F
.33273 .54732 m .33204 .54777 L .33063 .54806 L F
.168 .706 .765 r
.33221 .54774 m .33205 .54775 L .33063 .54806 L F
0 0 .411 r
.33177 .54781 m .33179 .54793 L .33063 .54806 L F
.647 .779 .944 r
.33013 .54806 m .33075 .54863 L .33179 .54793 L F
.33177 .54781 m .33179 .54793 L .33204 .54777 L F
.33013 .54806 m .33179 .54793 L .33177 .54781 L F
0 0 .411 r
.33205 .54775 m .3321 .54792 L .3318 .54795 L F
.33205 .54775 m .3318 .54795 L .33177 .54781 L F
.569 .426 .648 r
.32955 .5508 m .32858 .55004 L .32775 .54851 L F
0 0 .54 r
.32917 .55176 m .32937 .55148 L .32911 .55101 L F
.32857 .55037 m .32911 .55101 L .32784 .5487 L F
.32917 .55176 m .32911 .55101 L .32857 .55037 L F
.541 .916 .941 r
.32437 .55511 m .32275 .55503 L .3263 .5541 L F
.3 0 0 r
.32275 .55503 m .32532 .55484 L .3263 .5541 L F
.572 .378 .58 r
.32916 .55107 m .32532 .55484 L .32788 .55198 L F
.32955 .5508 m .32921 .55112 L .32916 .55107 L F
.32921 .55112 m .32532 .55484 L .32916 .55107 L F
.688 .455 .563 r
.32317 .54688 m .32179 .55124 L .32144 .54852 L F
.657 .167 .075 r
.32224 .54583 m .3238 .5467 L .3233 .54662 L F
.32201 .54613 m .3233 .54662 L .32181 .54639 L F
.32224 .54583 m .3233 .54662 L .32201 .54613 L F
.688 .455 .563 r
.32361 .54674 m .32788 .55198 L .32179 .55124 L F
.657 .167 .075 r
.32454 .54645 m .32526 .54693 L .32379 .54668 L F
.32379 .54668 m .32526 .54693 L .3238 .5467 L F
.3227 .54524 m .3238 .5467 L .32224 .54583 L F
.706 .35 .371 r
.3238 .54627 m .32181 .54639 L .32526 .54693 L F
.688 .455 .563 r
.3238 .54627 m .32433 .54701 L .32361 .54674 L F
.32433 .54701 m .32788 .55198 L .32361 .54674 L F
.3238 .54627 m .32361 .54674 L .32317 .54688 L F
.32361 .54674 m .32179 .55124 L .32317 .54688 L F
.657 .167 .075 r
.3227 .54524 m .32454 .54645 L .32379 .54668 L F
.569 .426 .648 r
.32805 .54906 m .3238 .54627 L .32775 .54851 L F
.32858 .55004 m .32563 .54772 L .32805 .54906 L F
.32563 .54772 m .3238 .54627 L .32805 .54906 L F
.433 .857 .717 r
.32888 .55213 m .32917 .55176 L .33063 .55119 L F
.32798 .55261 m .32917 .55176 L .32888 .55213 L F
.478 .473 .774 r
.32883 .55369 m .32918 .5525 L .32917 .55176 L F
.32918 .5525 m .32939 .5515 L .32917 .55176 L F
0 0 .54 r
.32937 .55148 m .32938 .55147 L .32897 .55073 L F
0 0 0 r
.32798 .55261 m .3263 .5541 L .32917 .55176 L F
.484 .22 .439 r
.3263 .5541 m .32883 .55369 L .32917 .55176 L F
.572 .378 .58 r
.3294 .55144 m .32865 .55471 L .32921 .55112 L F
.3294 .55145 m .32938 .55155 L .3294 .55144 L F
.32938 .55155 m .32865 .55471 L .3294 .55144 L F
.478 .473 .774 r
.32883 .55369 m .33151 .55411 L .32991 .55211 L F
.973 .918 .682 r
.32956 .55395 m .33151 .55411 L .32966 .55382 L F
.32972 .55432 m .33151 .55411 L .32956 .55395 L F
.32972 .55531 m .33089 .55452 L .32921 .55438 L F
.33089 .55452 m .33151 .55411 L .32921 .55438 L F
.76 .559 .626 r
.33788 .55097 m .33453 .55287 L .33392 .55266 L F
.666 .524 .682 r
.32991 .55211 m .33453 .55287 L .33267 .55089 L F
.32991 .55211 m .33151 .55411 L .33453 .55287 L F
.973 .918 .682 r
.33005 .55508 m .33009 .55671 L .33151 .55411 L F
.32972 .55531 m .32988 .55594 L .33005 .55508 L F
.32988 .55594 m .33009 .55671 L .33005 .55508 L F
0 0 0 r
.33283 .55658 m .33179 .55947 L .3324 .55648 L F
.903 .752 .683 r
.33151 .55411 m .33009 .55671 L .33283 .55658 L F
.864 .547 .45 r
.33009 .55671 m .33056 .55908 L .33283 .55658 L F
.973 .918 .682 r
.32872 .55444 m .32883 .55369 L .32815 .55452 L F
.32921 .55438 m .32921 .55438 L .32872 .55444 L F
.32921 .55438 m .32883 .55369 L .32872 .55444 L F
.367 0 .012 r
.32532 .55484 m .32883 .55369 L .3263 .5541 L F
.572 .378 .58 r
.32815 .55452 m .32865 .55471 L .32601 .55481 L F
.32869 .55445 m .32601 .55481 L .32532 .55484 L F
.687 .281 .272 r
.32865 .55471 m .32807 .55476 L .32532 .55484 L F
.367 0 .012 r
.32532 .55484 m .32724 .55551 L .32795 .55476 L F
.687 .281 .272 r
.32865 .55471 m .32667 .55603 L .32807 .55476 L F
.151 0 0 r
.32064 .55476 m .32437 .55511 L .32219 .55587 L F
.231 .746 .735 r
.32532 .55484 m .32179 .55571 L .32275 .55503 L F
.32532 .55484 m .32179 .55571 L .32275 .55503 L F
.32532 .55484 m .32387 .55511 L .32179 .55571 L F
.32532 .55484 m .32387 .55511 L .32179 .55571 L F
.313 .298 .683 r
.32387 .55511 m .3262 .5578 L .32717 .55581 L F
.687 .281 .272 r
.32696 .55577 m .32696 .55577 L .3276 .55518 L F
.367 0 .012 r
.32724 .55551 m .3276 .55518 L .32795 .55476 L F
.326 0 0 r
.32387 .55511 m .32724 .55551 L .32532 .55484 L F
.687 .281 .272 r
.32807 .55476 m .32724 .55551 L .32387 .55511 L F
.32724 .55551 m .32662 .55607 L .32387 .55511 L F
.326 0 0 r
.32387 .55511 m .32731 .55554 L .32724 .55551 L F
.313 .298 .683 r
.32387 .55511 m .32717 .55581 L .32731 .55554 L F
.687 .281 .272 r
.32667 .55603 m .32662 .55607 L .32696 .55577 L F
.32667 .55603 m .32696 .55577 L .32696 .55577 L F
.32667 .55603 m .3276 .55518 L .32807 .55476 L F
.572 .378 .58 r
.32869 .55445 m .32869 .55446 L .32815 .55452 L F
.32869 .55446 m .32865 .55471 L .32815 .55452 L F
.973 .918 .682 r
.32786 .5552 m .32835 .55449 L .32731 .55554 L F
.32879 .55443 m .32835 .55449 L .32786 .5552 L F
.32835 .55449 m .3276 .55518 L .32731 .55554 L F
.514 .188 .353 r
.32761 .55512 m .327 .55591 L .32883 .55435 L F
.687 .281 .272 r
.32719 .55569 m .32683 .55614 L .32662 .55607 L F
.32865 .55471 m .32717 .55587 L .32719 .55569 L F
.32717 .55587 m .32683 .55614 L .32719 .55569 L F
.514 .188 .353 r
.327 .55591 m .32683 .55614 L .32732 .5557 L F
.32747 .55552 m .32732 .5557 L .32805 .55504 L F
.775 .575 .63 r
.32717 .55581 m .32723 .5558 L .32731 .55554 L F
.32723 .5558 m .32747 .55552 L .32731 .55554 L F
.514 .188 .353 r
.327 .55591 m .32732 .5557 L .32747 .55552 L F
.775 .575 .63 r
.32723 .5558 m .32972 .55531 L .32747 .55552 L F
.32713 .55618 m .32972 .55531 L .32717 .55581 L F
.32814 .55619 m .32972 .55531 L .32713 .55618 L F
.32818 .5564 m .32972 .55531 L .32706 .5568 L F
.568 .375 .579 r
.32879 .55443 m .3288 .55434 L .3288 .55434 L F
.514 .188 .353 r
.327 .55591 m .32805 .55504 L .32883 .55435 L F
.32879 .55443 m .32683 .55614 L .32865 .55471 L F
.32883 .55435 m .32805 .55504 L .32879 .55443 L F
.32805 .55504 m .32683 .55614 L .32879 .55443 L F
.973 .918 .682 r
.32972 .55531 m .32921 .55438 L .32786 .5552 L F
.32747 .55552 m .32786 .5552 L .32731 .55554 L F
.32972 .55531 m .32786 .5552 L .32747 .55552 L F
.514 .188 .353 r
.3279 .55474 m .32918 .55554 L .32683 .55614 L F
.416 .337 .659 r
.33406 .56036 m .33179 .55947 L .33283 .55658 L F
.568 .561 .806 r
.3353 .55684 m .33406 .56036 L .33283 .55658 L F
.3353 .55684 m .33749 .56132 L .33406 .56036 L F
.643 .24 .265 r
.33283 .55658 m .33056 .55908 L .33485 .55874 L F
.748 .487 0 r
.32972 .55531 m .33056 .55908 L .33009 .55671 L F
.283 .313 .716 r
.33064 .55628 m .33056 .55908 L .32972 .55531 L F
.33195 .55765 m .3306 .55904 L .33064 .55628 L F
.3306 .55904 m .33056 .55908 L .33064 .55628 L F
.309 .319 .708 r
.33015 .55576 m .32972 .55531 L .33021 .55519 L F
.33195 .55765 m .331 .55873 L .32972 .55531 L F
.514 .188 .353 r
.33021 .55515 m .33026 .55566 L .3279 .55474 L F
.33026 .55566 m .32969 .55586 L .3279 .55474 L F
.973 .918 .682 r
.32921 .55438 m .32879 .55443 L .32786 .5552 L F
.32835 .55449 m .32815 .55452 L .3276 .55518 L F
.367 0 .012 r
.32532 .55484 m .32815 .55452 L .32883 .55369 L F
.572 .378 .58 r
.32921 .55112 m .32869 .55445 L .32532 .55484 L F
.973 .918 .682 r
.32921 .55438 m .32972 .55432 L .32956 .55395 L F
.3291 .55418 m .32966 .55382 L .32883 .55369 L F
.32921 .55438 m .32966 .55382 L .3291 .55418 L F
.687 .281 .272 r
.32807 .55476 m .32387 .55511 L .32532 .55484 L F
.568 .375 .579 r
.3288 .55434 m .32938 .55155 L .32955 .5508 L F
.3288 .55434 m .32918 .5525 L .3288 .55434 L F
.32918 .5525 m .32938 .55155 L .32918 .5525 L F
.478 .473 .774 r
.32883 .55369 m .32991 .55211 L .32918 .5525 L F
.568 .375 .579 r
.32918 .5525 m .32918 .5525 L .3288 .55434 L F
.32986 .55222 m .32878 .55444 L .32941 .55146 L F
.32986 .55222 m .32941 .55146 L .32955 .5508 L F
.478 .473 .774 r
.32918 .5525 m .32991 .55211 L .32956 .55121 L F
.32918 .5525 m .32918 .5525 L .32938 .55155 L F
.568 .375 .579 r
.32878 .55444 m .32865 .55471 L .32938 .55155 L F
.514 .188 .353 r
.32991 .55211 m .32761 .55512 L .32883 .55435 L F
.32991 .55211 m .33021 .55515 L .3279 .55474 L F
.309 .319 .708 r
.33195 .55765 m .33015 .55576 L .33102 .55529 L F
.33015 .55576 m .33021 .55519 L .33205 .55473 L F
.283 .313 .716 r
.33195 .55765 m .33015 .55576 L .33205 .55473 L F
.33015 .55576 m .32972 .55531 L .33021 .55519 L F
.33015 .55576 m .33021 .55519 L .33205 .55473 L F
0 0 .231 r
.33039 .55583 m .33024 .55551 L .33021 .55515 L F
.33025 .55474 m .33021 .55515 L .32991 .55211 L F
.33039 .55583 m .33021 .55515 L .33025 .55474 L F
.33098 .55213 m .33039 .55583 L .33025 .55474 L F
.33031 .55404 m .33025 .55474 L .3302 .55436 L F
.33098 .55213 m .33025 .55474 L .33031 .55404 L F
.33064 .55212 m .3302 .55436 L .32991 .55211 L F
.33098 .55213 m .3302 .55436 L .33064 .55212 L F
.33039 .55583 m .33032 .55625 L .33024 .55551 L F
.969 .89 .694 r
.32943 .55123 m .33032 .55625 L .33068 .55403 L F
.33071 .55197 m .33068 .55403 L .33098 .55213 L F
.568 .375 .579 r
.32991 .55211 m .32986 .55222 L .32955 .5508 L F
.969 .89 .694 r
.32943 .55123 m .33068 .55403 L .33071 .55197 L F
.775 .575 .63 r
.32818 .5564 m .331 .55873 L .33016 .55648 L F
.32846 .5562 m .33016 .55648 L .32972 .55531 L F
.32818 .5564 m .33016 .55648 L .32846 .5562 L F
.514 .188 .353 r
.32918 .55554 m .32869 .55596 L .32683 .55614 L F
.32969 .55586 m .32874 .5562 L .32683 .55614 L F
.435 .446 .772 r
.31953 .55172 m .32064 .55476 L .31862 .55468 L F
.151 0 0 r
.32064 .55476 m .32275 .55503 L .32437 .55511 L F
.518 .473 .746 r
.32179 .55124 m .32064 .55476 L .31953 .55172 L F
.32179 .55124 m .32275 .55503 L .32064 .55476 L F
.549 .326 .529 r
.32788 .55198 m .32275 .55503 L .32179 .55124 L F
.32788 .55198 m .32532 .55484 L .32275 .55503 L F
.804 .351 .163 r
.32387 .55511 m .3196 .55235 L .32179 .55571 L F
.32387 .55511 m .3217 .55556 L .3196 .55235 L F
.076 .614 .856 r
.32874 .5562 m .3234 .55492 L .3257 .55574 L F
.32842 .55619 m .3257 .55574 L .32683 .55614 L F
.32874 .5562 m .3257 .55574 L .32842 .55619 L F
.514 .188 .353 r
.32918 .55554 m .32969 .55586 L .32869 .55596 L F
.775 .575 .63 r
.3262 .5578 m .32649 .55786 L .32818 .5564 L F
.32649 .55786 m .331 .55873 L .32818 .5564 L F
.514 .188 .353 r
.32969 .55586 m .33032 .55625 L .32874 .5562 L F
.076 .614 .856 r
.33032 .55625 m .33013 .55622 L .32874 .5562 L F
.33013 .55622 m .3234 .55492 L .32874 .5562 L F
.775 .575 .63 r
.32706 .5568 m .32814 .55619 L .32713 .55618 L F
.32702 .55722 m .32818 .5564 L .32706 .5568 L F
.514 .188 .353 r
.33026 .55566 m .33032 .55625 L .32969 .55586 L F
.775 .575 .63 r
.3262 .5578 m .32702 .55722 L .32706 .5568 L F
.32662 .55696 m .32706 .5568 L .32717 .55581 L F
.3262 .5578 m .32706 .5568 L .32662 .55696 L F
.367 0 .012 r
.32724 .55551 m .32731 .55554 L .3276 .55518 L F
.32532 .55484 m .32795 .55476 L .32815 .55452 L F
.309 .319 .708 r
.33203 .55547 m .33102 .55529 L .33205 .55473 L F
.33195 .55765 m .33102 .55529 L .33203 .55547 L F
.569 .426 .648 r
.32955 .5508 m .32893 .55065 L .32858 .55004 L F
.32955 .5508 m .32916 .55107 L .32893 .55065 L F
0 0 .54 r
.32898 .55076 m .32956 .55121 L .32784 .5487 L F
.32938 .55147 m .3294 .55144 L .32898 .55076 L F
.572 .378 .58 r
.32955 .5508 m .3294 .55145 L .32921 .55112 L F
0 0 .54 r
.3294 .55144 m .32956 .55121 L .32898 .55076 L F
.478 .473 .774 r
.32938 .55155 m .32953 .55132 L .32939 .5515 L F
.32918 .5525 m .32953 .55132 L .32938 .55155 L F
.32953 .55132 m .32956 .55121 L .32917 .55176 L F
0 0 .54 r
.32885 .55053 m .32897 .55073 L .32858 .55004 L F
.32937 .55148 m .32897 .55073 L .32885 .55053 L F
.32937 .55148 m .32858 .55004 L .32784 .5487 L F
.569 .426 .648 r
.32858 .55004 m .32653 .55009 L .32743 .54913 L F
.32893 .55065 m .32653 .55009 L .32858 .55004 L F
.741 .248 0 r
.32775 .54851 m .32956 .55121 L .32955 .5508 L F
.616 .296 .404 r
.32775 .54851 m .32956 .55121 L .33023 .54925 L F
.32806 .54846 m .33023 .54925 L .33063 .54806 L F
.32775 .54851 m .33023 .54925 L .32806 .54846 L F
.469 .017 .093 r
.33063 .54806 m .33075 .54863 L .32775 .54851 L F
.458 .705 .974 r
.32775 .54851 m .33004 .5486 L .32851 .54657 L F
.33004 .5486 m .33075 .54863 L .32995 .54789 L F
.33004 .5486 m .32995 .54789 L .32851 .54657 L F
0 0 .54 r
.32784 .5487 m .32956 .55121 L .32775 .54851 L F
.569 .426 .648 r
.32893 .55065 m .32788 .55198 L .32653 .55009 L F
.32916 .55107 m .32788 .55198 L .32893 .55065 L F
.32743 .54913 m .32653 .55009 L .3238 .54627 L F
0 .07 .607 r
.32851 .54657 m .32936 .55034 L .32775 .54851 L F
.32936 .55034 m .32956 .55121 L .32775 .54851 L F
.647 .779 .944 r
.32851 .54657 m .33013 .54806 L .33273 .54732 L F
.33013 .54806 m .33204 .54777 L .33273 .54732 L F
0 .146 .677 r
.33453 .55287 m .33463 .55021 L .33267 .55089 L F
.33453 .55287 m .33546 .55259 L .33463 .55021 L F
.722 .3 .244 r
.33546 .55259 m .33267 .55089 L .33463 .55021 L F
.33546 .55259 m .33098 .55213 L .33267 .55089 L F
.699 .25 .183 r
.33546 .55259 m .3327 .55459 L .33098 .55213 L F
.969 .89 .694 r
.32943 .55123 m .32797 .55542 L .33032 .55625 L F
.622 .163 0 r
.33098 .55213 m .3327 .55459 L .33076 .55208 L F
.435 .819 .581 r
.33589 .55221 m .33279 .55452 L .33546 .55259 L F
.33469 .5531 m .33279 .55452 L .33589 .55221 L F
.33279 .55452 m .3327 .55459 L .33292 .55443 L F
.33279 .55452 m .33292 .55443 L .33546 .55259 L F
.54 .553 .817 r
.33463 .55021 m .33546 .55259 L .33713 .55134 L F
.33463 .55021 m .33546 .55259 L .33713 .55134 L F
.7 .811 .934 r
.33347 .55146 m .33302 .5533 L .33597 .55214 L F
.33302 .5533 m .3327 .55459 L .33469 .5531 L F
.33302 .5533 m .33469 .5531 L .33597 .55214 L F
.502 .56 .847 r
.33347 .55146 m .33367 .5543 L .3327 .55459 L F
.726 .548 .65 r
.33337 .55408 m .33076 .55208 L .3322 .55395 L F
.33337 .55408 m .3322 .55395 L .3327 .55459 L F
.33367 .5543 m .33337 .55408 L .3327 .55459 L F
.33337 .55408 m .32876 .55511 L .32971 .55368 L F
.33244 .55336 m .32971 .55368 L .33076 .55208 L F
.33337 .55408 m .32971 .55368 L .33244 .55336 L F
.33367 .5543 m .33289 .55443 L .33337 .55408 L F
.33289 .55443 m .32876 .55511 L .33337 .55408 L F
.435 .819 .581 r
.33597 .55214 m .33469 .5531 L .33589 .55221 L F
.147 0 .038 r
.3145 .57997 m .31349 .5824 L .31209 .58243 L F
.221 0 .123 r
.31624 .58019 m .31349 .5824 L .3145 .57997 L F
.821 .973 .894 r
.81462 .40055 m .8154 .3979 L .8163 .39873 L F
.011 0 .423 r
.81366 .40242 m .8154 .3979 L .81462 .40055 L F
.402 .756 .994 r
.49114 .62348 m .49452 .62409 L .49319 .62304 L F
.49114 .62348 m .49452 .62409 L .49319 .62304 L F
0 .169 .687 r
.22705 .62337 m .22606 .6228 L .22359 .61993 L F
.232 .194 .607 r
.15425 .59026 m .15558 .58994 L .15543 .5864 L F
.272 .364 .775 r
.15425 .59026 m .15709 .59249 L .15558 .58994 L F
.568 .412 .63 r
.32306 .63574 m .32073 .63892 L .32133 .63654 L F
.432 0 0 r
.3227 .54524 m .32181 .54639 L .31936 .54627 L F
.697 .64 .788 r
.54548 .58077 m .54932 .58354 L .54785 .58011 L F
.145 .283 .748 r
.29267 .60559 m .29534 .60914 L .29369 .60481 L F
.802 .798 .848 r
.26398 .64507 m .26864 .64525 L .26597 .64394 L F
.406 .775 .994 r
.26597 .64394 m .26864 .64525 L .27046 .64468 L F
.761 .68 .773 r
.80513 .42351 m .80635 .42682 L .80698 .42473 L F
.534 .591 .858 r
.79413 .42694 m .79547 .42316 L .79302 .42437 L F
.79413 .42694 m .79663 .4266 L .79547 .42316 L F
.514 .32 .555 r
.28471 .61981 m .28802 .616 L .28492 .61788 L F
.263 .158 .542 r
.15537 .58106 m .15683 .58039 L .1568 .57771 L F
.27 .172 .555 r
.15537 .58106 m .15701 .58301 L .15683 .58039 L F
.288 .176 .547 r
.15546 .5837 m .15701 .58301 L .15537 .58106 L F
.65 .404 .533 r
.47721 .63586 m .4739 .63802 L .47467 .6366 L F
.51 .314 .551 r
.25223 .67246 m .25447 .67305 L .25458 .67008 L F
.511 .31 .544 r
.25198 .67591 m .25447 .67305 L .25223 .67246 L F
.851 .655 .637 r
.23039 .73466 m .2316 .73755 L .22979 .73804 L F
.598 .679 .898 r
.23221 .73535 m .2316 .73755 L .23039 .73466 L F
.23221 .73535 m .23437 .73814 L .2316 .73755 L F
.644 .191 .161 r
.2316 .73755 m .23219 .73974 L .22979 .73804 L F
.2316 .73755 m .23437 .73814 L .23285 .73925 L F
.2316 .73755 m .23285 .73925 L .23195 .73885 L F
.568 .447 .675 r
.22989 .73792 m .23269 .73908 L .23221 .73535 L F
.22979 .73804 m .23159 .73868 L .22989 .73792 L F
.23159 .73868 m .23269 .73908 L .22989 .73792 L F
.644 .191 .161 r
.23195 .73885 m .23276 .73921 L .23219 .73974 L F
.531 .257 .444 r
.22979 .73804 m .23219 .73974 L .23052 .74068 L F
.308 0 0 r
.23145 .73888 m .23269 .73908 L .22979 .73804 L F
.561 .668 .91 r
.23482 .73502 m .23437 .73814 L .23221 .73535 L F
0 .025 .533 r
.23221 .73535 m .23269 .73908 L .23371 .7363 L F
.863 .991 .733 r
.23371 .7363 m .23269 .73908 L .23145 .73888 L F
.685 .539 .682 r
.23052 .74068 m .23219 .73974 L .22978 .74281 L F
.467 .633 .926 r
.23219 .73974 m .23327 .73794 L .23024 .74154 L F
.23219 .73974 m .23024 .74154 L .23024 .74154 L F
.644 .191 .161 r
.23276 .73921 m .23285 .73925 L .23219 .73974 L F
.621 .703 .904 r
.304 .60554 m .30191 .60652 L .30065 .60513 L F
.522 .218 .391 r
.34434 .59651 m .34639 .59832 L .34387 .59857 L F
.526 .217 .385 r
.34704 .59626 m .34639 .59832 L .34434 .59651 L F
.591 .778 .969 r
.28169 .54656 m .28577 .54726 L .28378 .54569 L F
.701 .271 .224 r
.28169 .54656 m .28388 .54885 L .28577 .54726 L F
.842 .813 .822 r
.28378 .54569 m .28577 .54726 L .28815 .54448 L F
.973 .75 .542 r
.28388 .54885 m .28552 .55006 L .28577 .54726 L F
.387 .154 .435 r
.51419 .52869 m .51517 .52622 L .51206 .52883 L F
.51419 .52869 m .51517 .52622 L .51206 .52883 L F
.869 .53 .405 r
.25609 .69408 m .25633 .69181 L .25558 .69326 L F
0 0 .106 r
.25866 .68856 m .25633 .69181 L .25856 .69119 L F
.39 .101 .349 r
.25666 .69341 m .25633 .69181 L .25609 .69408 L F
.664 .275 .299 r
.25666 .69341 m .25841 .69395 L .25669 .69353 L F
.25633 .69181 m .25718 .69268 L .25666 .69341 L F
.471 .288 .551 r
.25856 .69119 m .25841 .69395 L .25633 .69181 L F
.39 .101 .349 r
.25856 .69119 m .25666 .69341 L .25784 .69255 L F
.25666 .69341 m .25609 .69408 L .25627 .69392 L F
.68 .368 .439 r
.25659 .69351 m .25841 .69395 L .25623 .69397 L F
.39 .101 .349 r
.25659 .69351 m .25627 .69392 L .25635 .69385 L F
.25666 .69341 m .25627 .69392 L .25659 .69351 L F
.68 .368 .439 r
.25623 .69397 m .25841 .69395 L .25793 .6958 L F
.25558 .69326 m .25659 .69351 L .25623 .69397 L F
.664 .275 .299 r
.25718 .69268 m .25775 .69326 L .25666 .69341 L F
.39 .101 .349 r
.25666 .69341 m .25635 .69385 L .25784 .69255 L F
.25856 .69119 m .25633 .69181 L .25666 .69341 L F
.664 .275 .299 r
.25633 .69181 m .25669 .69353 L .25558 .69326 L F
.767 .501 .532 r
.25052 .69721 m .2533 .69734 L .25194 .69477 L F
.69 .507 .635 r
.2521 .69578 m .25609 .69408 L .25558 .69326 L F
.382 .628 .95 r
.25522 .6944 m .2521 .69578 L .25558 .69326 L F
.436 .872 .794 r
.25562 .69421 m .25609 .69408 L .2521 .69578 L F
.68 .368 .439 r
.25522 .6944 m .25793 .6958 L .25459 .69635 L F
.25558 .69326 m .25621 .69395 L .25522 .6944 L F
.591 .948 .845 r
.25635 .69385 m .25628 .69391 L .25516 .69435 L F
.25628 .69391 m .25609 .69408 L .25574 .69418 L F
.68 .368 .439 r
.25621 .69395 m .25574 .69418 L .25522 .6944 L F
.591 .948 .845 r
.25628 .69391 m .25574 .69418 L .25516 .69435 L F
.68 .368 .439 r
.25621 .69395 m .25624 .69398 L .25574 .69418 L F
.25624 .69398 m .25793 .6958 L .25522 .6944 L F
.436 .872 .794 r
.25232 .69518 m .25562 .69421 L .25522 .6944 L F
.25215 .69565 m .25522 .6944 L .2521 .69578 L F
.25232 .69518 m .25522 .6944 L .25215 .69565 L F
.382 .628 .95 r
.2552 .69445 m .2521 .69578 L .25522 .6944 L F
.25459 .69635 m .25261 .69589 L .2552 .69445 L F
.25261 .69589 m .2521 .69578 L .2552 .69445 L F
.591 .948 .845 r
.25784 .69255 m .25648 .69374 L .25232 .69518 L F
.25648 .69374 m .25635 .69385 L .25617 .69391 L F
.25648 .69374 m .25617 .69391 L .25232 .69518 L F
.25635 .69385 m .25516 .69435 L .25232 .69518 L F
.664 .275 .299 r
.25775 .69326 m .25841 .69395 L .25709 .69354 L F
.25775 .69326 m .25709 .69354 L .25666 .69341 L F
0 0 0 r
.25633 .69181 m .25866 .68856 L .25856 .69119 L F
.543 .718 .954 r
.22514 .63825 m .22527 .63549 L .22335 .63578 L F
.22514 .63825 m .22752 .63777 L .22527 .63549 L F
.854 .751 .749 r
.83035 .40745 m .83144 .41106 L .83358 .40781 L F
.527 .08 .131 r
.29397 .55193 m .29845 .55032 L .29602 .55091 L F
.587 .367 .548 r
.28919 .6143 m .29139 .61054 L .28997 .61125 L F
.182 0 0 r
.28804 .53258 m .28991 .53277 L .29177 .53209 L F
.181 0 0 r
.28991 .53277 m .29405 .53271 L .29177 .53209 L F
.499 .437 .719 r
.28497 .55871 m .28666 .55633 L .28437 .557 L F
.28497 .55871 m .28715 .55841 L .28666 .55633 L F
.818 .561 .551 r
.53903 .53143 m .53589 .53346 L .53666 .531 L F
.53903 .53143 m .54138 .53477 L .53589 .53346 L F
.109 .075 .534 r
.23027 .72514 m .22912 .72778 L .22946 .72727 L F
.021 .524 .871 r
.22946 .72727 m .22912 .72778 L .23126 .72828 L F
.801 .309 0 r
.22912 .72778 m .23273 .73153 L .23126 .72828 L F
.842 .813 .822 r
.28378 .54569 m .28815 .54448 L .28628 .54548 L F
.323 0 0 r
.29045 .54373 m .28628 .54548 L .28815 .54448 L F
.766 .686 .774 r
.35769 .55587 m .3554 .55961 L .35562 .55715 L F
.163 0 .341 r
.35769 .55587 m .35727 .55877 L .3554 .55961 L F
.35769 .55587 m .35727 .55877 L .3554 .55961 L F
.459 .377 .676 r
.35727 .55877 m .35555 .56108 L .3554 .55961 L F
.136 0 0 r
.21424 .53931 m .21858 .53809 L .21633 .53842 L F
.803 .962 .912 r
.27562 .65383 m .28003 .6524 L .27716 .6548 L F
.622 .059 0 r
.27716 .6548 m .27746 .65623 L .27657 .6573 L F
.27716 .6548 m .28236 .65761 L .27746 .65623 L F
.683 .597 .753 r
.28003 .6524 m .28019 .65535 L .27716 .6548 L F
.705 .448 .533 r
.28019 .65535 m .28236 .65761 L .27716 .6548 L F
.856 .726 .719 r
.32618 .58619 m .32913 .58732 L .32892 .58479 L F
.883 .608 .517 r
.32618 .58619 m .32892 .58958 L .32913 .58732 L F
.695 .608 .755 r
.32892 .58479 m .32913 .58732 L .3325 .58698 L F
.638 .37 .496 r
.32892 .58958 m .3325 .58698 L .32913 .58732 L F
.36 .706 .985 r
.34193 .55185 m .3433 .55282 L .34138 .55329 L F
.264 0 .286 r
.25866 .68856 m .26136 .68554 L .26098 .68846 L F
.637 .466 .634 r
.2639 .68447 m .26098 .68846 L .26136 .68554 L F
.795 .31 0 r
.53873 .56614 m .53796 .56658 L .53704 .56508 L F
.756 .247 0 r
.53973 .56757 m .53796 .56658 L .53873 .56614 L F
.617 .759 .947 r
.81756 .41884 m .81935 .41628 L .8168 .41693 L F
.81756 .41884 m .82064 .4179 L .81935 .41628 L F
.298 .773 .93 r
.23556 .62368 m .23512 .62437 L .23334 .62365 L F
.23556 .62368 m .23739 .62409 L .23512 .62437 L F
.462 .666 .951 r
.20128 .62667 m .20476 .63021 L .20594 .62923 L F
0 .227 .748 r
.28662 .56941 m .28781 .57067 L .28633 .56832 L F
.064 0 .233 r
.27478 .55448 m .27346 .55346 L .27567 .55256 L F
.27478 .55448 m .27304 .55611 L .27346 .55346 L F
.452 .45 .766 r
.33901 .60779 m .33797 .61171 L .3374 .60813 L F
.33901 .60779 m .33997 .61134 L .33797 .61171 L F
.611 .468 .662 r
.33997 .61134 m .33785 .61424 L .33797 .61171 L F
.255 0 .237 r
.17323 .56191 m .17426 .56392 L .17513 .56181 L F
.17323 .56191 m .17229 .56475 L .17426 .56392 L F
0 0 .343 r
.29874 .57326 m .30097 .57285 L .29924 .57217 L F
.741 .863 .938 r
.29924 .57217 m .30097 .57285 L .30363 .57178 L F
.865 .651 .61 r
.54226 .53773 m .54138 .53477 L .54268 .53511 L F
.478 .843 .595 r
.20374 .78575 m .20591 .78414 L .20406 .78561 L F
.537 0 0 r
.20374 .78575 m .20406 .78561 L .20562 .78687 L F
.496 .268 .498 r
.20406 .78561 m .20591 .78414 L .20562 .78687 L F
.237 0 .296 r
.34946 .5753 m .34884 .57731 L .3514 .57428 L F
.34946 .5753 m .34884 .57731 L .3514 .57428 L F
.538 .047 .038 r
.13818 .65149 m .13906 .65151 L .13852 .65127 L F
.505 .873 .982 r
.78411 .40159 m .78229 .40297 L .7814 .40262 L F
.78411 .40159 m .78494 .40222 L .78229 .40297 L F
.485 .594 .887 r
.17393 .60978 m .17504 .60748 L .17348 .60802 L F
.17393 .60978 m .17913 .61257 L .17504 .60748 L F
0 0 0 r
.2936 .5868 m .29256 .58865 L .29047 .58984 L F
.544 .366 .59 r
.2936 .5868 m .29661 .58633 L .29648 .58378 L F
0 0 0 r
.29648 .58378 m .29467 .58567 L .2936 .5868 L F
.347 .462 .835 r
.2936 .5868 m .29703 .58962 L .29661 .58633 L F
0 0 0 r
.29467 .58567 m .29256 .58865 L .2936 .5868 L F
.618 .938 .956 r
.19428 .60098 m .19254 .60082 L .19169 .60226 L F
.963 .738 .551 r
.19254 .60082 m .19428 .60098 L .19169 .60226 L F
.066 0 0 r
.26053 .55028 m .25847 .55133 L .25614 .55174 L F
.281 0 0 r
.26297 .55014 m .25847 .55133 L .26053 .55028 L F
0 0 .474 r
.33728 .5655 m .33864 .56417 L .33791 .56119 L F
.518 .878 .65 r
.33728 .5655 m .3363 .56601 L .33864 .56417 L F
.625 .544 .744 r
.3363 .56601 m .33764 .56642 L .33864 .56417 L F
.313 .633 .963 r
.3363 .56601 m .33764 .56642 L .33665 .56548 L F
.3363 .56601 m .33665 .56548 L .33583 .5647 L F
.636 .922 .648 r
.33728 .5655 m .33552 .56721 L .3363 .56601 L F
.33552 .56721 m .33466 .56804 L .3363 .56601 L F
.533 .504 .77 r
.18711 .6004 m .18596 .60475 L .18533 .60316 L F
.18711 .6004 m .18821 .60417 L .18596 .60475 L F
.551 .626 .88 r
.18821 .60417 m .18926 .60614 L .18596 .60475 L F
.561 .668 .91 r
.23482 .73502 m .23657 .73761 L .23437 .73814 L F
.252 0 .003 r
.23437 .73814 m .23471 .73994 L .23219 .73974 L F
.23437 .73814 m .23657 .73761 L .23471 .73994 L F
0 0 .044 r
.28981 .59173 m .28912 .59392 L .28873 .59308 L F
0 0 0 r
.28972 .59463 m .28651 .59686 L .28912 .59392 L F
.939 .899 .759 r
.28981 .59173 m .28873 .59308 L .29047 .58984 L F
0 0 .335 r
.29205 .59118 m .28981 .59173 L .29047 .58984 L F
0 0 .088 r
.29101 .59328 m .28981 .59173 L .29205 .59118 L F
.29101 .59328 m .28972 .59463 L .28981 .59173 L F
.618 .474 .663 r
.32815 .62694 m .32576 .63003 L .3256 .62736 L F
.805 .963 .911 r
.29812 .60795 m .29534 .60914 L .29701 .60732 L F
.486 .709 .969 r
.77781 .4038 m .77696 .4056 L .7758 .40322 L F
0 0 0 r
.18079 .5794 m .17836 .5822 L .177 .58275 L F
.305 .118 .455 r
.18249 .5775 m .18246 .57951 L .18079 .5794 L F
0 0 0 r
.18246 .57951 m .17836 .5822 L .18079 .5794 L F
.293 0 .094 r
.30783 .60821 m .31163 .60571 L .30719 .60648 L F
.30783 .60821 m .30971 .60806 L .31163 .60571 L F
.264 0 .071 r
.30971 .60806 m .31339 .6054 L .31163 .60571 L F
.32 0 .101 r
.18674 .55229 m .18818 .55378 L .19012 .55044 L F
.051 0 0 r
.19012 .55044 m .19067 .55189 L .19227 .54974 L F
.19012 .55044 m .18818 .55378 L .19067 .55189 L F
.741 .863 .938 r
.29924 .57217 m .30363 .57178 L .30192 .57134 L F
0 .188 .72 r
.30363 .57178 m .30453 .57123 L .30192 .57134 L F
.30363 .57178 m .30578 .57378 L .30453 .57123 L F
.429 .287 .586 r
.30376 .57428 m .30578 .57378 L .30363 .57178 L F
0 0 .265 r
.28228 .60329 m .28183 .60258 L .28275 .60162 L F
.28228 .60329 m .28131 .60509 L .28183 .60258 L F
.386 .185 .481 r
.1849 .57426 m .18249 .5775 L .18267 .57499 L F
.475 .271 .522 r
.33524 .62002 m .33282 .61784 L .33516 .61716 L F
.33524 .62002 m .3326 .62066 L .33282 .61784 L F
.568 .447 .675 r
.22979 .73804 m .23221 .73535 L .23039 .73466 L F
.453 .852 .659 r
.51868 .52725 m .5196 .52654 L .51728 .52812 L F
.52089 .52588 m .5196 .52654 L .51868 .52725 L F
.444 0 0 r
.52089 .52588 m .52307 .52693 L .5196 .52654 L F
.55 .008 0 r
.52307 .52693 m .52233 .52743 L .5196 .52654 L F
.291 .59 .945 r
.5196 .52654 m .52233 .52743 L .52076 .52563 L F
.5196 .52654 m .52076 .52563 L .52052 .52536 L F
.445 .035 .167 r
.52334 .52564 m .52307 .52693 L .52089 .52588 L F
.428 .542 .869 r
.32696 .57453 m .32666 .57137 L .32596 .57161 L F
.32696 .57453 m .32863 .5739 L .32657 .57038 L F
.034 0 .364 r
.32723 .57159 m .32722 .57159 L .32724 .57158 L F
.305 .471 .86 r
.32657 .57038 m .32863 .5739 L .32951 .57208 L F
.428 .542 .869 r
.32666 .57137 m .32657 .57038 L .32617 .57119 L F
0 .013 .544 r
.3252 .56838 m .32596 .57161 L .32657 .57038 L F
.794 .703 .765 r
.32724 .57158 m .32314 .56994 L .32657 .57038 L F
.428 .542 .869 r
.32666 .57137 m .32617 .57119 L .32596 .57161 L F
.794 .703 .765 r
.32724 .57158 m .32326 .5727 L .32314 .56994 L F
0 .476 .753 r
.32951 .57208 m .32724 .57158 L .32657 .57038 L F
.279 .753 .936 r
.32738 .57146 m .32931 .57202 L .33218 .57036 L F
0 .476 .753 r
.32951 .57208 m .32768 .5715 L .32757 .57152 L F
.32951 .57208 m .32757 .57152 L .32724 .57158 L F
0 0 0 r
.32757 .57152 m .32733 .57171 L .32724 .57158 L F
.32733 .57171 m .32563 .57303 L .32663 .57213 L F
.32733 .57171 m .32663 .57213 L .32724 .57158 L F
.279 .753 .936 r
.32733 .5717 m .32931 .57202 L .32762 .57153 L F
.32733 .5717 m .32762 .57153 L .32738 .57146 L F
.32673 .57161 m .32733 .5717 L .32738 .57146 L F
.32733 .5717 m .32928 .57204 L .32931 .57202 L F
.32733 .57171 m .32928 .57204 L .32733 .5717 L F
.32733 .57171 m .32768 .5715 L .32951 .57208 L F
.034 0 .364 r
.32447 .57409 m .32722 .57159 L .32723 .57159 L F
.279 .753 .936 r
.32673 .57161 m .32733 .57171 L .32733 .5717 L F
.32673 .57161 m .32768 .5715 L .32733 .57171 L F
0 0 0 r
.32768 .5715 m .32447 .57409 L .32563 .57303 L F
.32768 .5715 m .32563 .57303 L .32757 .57152 L F
.279 .753 .936 r
.32928 .57204 m .32951 .57208 L .32979 .5719 L F
.32928 .57204 m .32979 .5719 L .33218 .57036 L F
.034 0 .364 r
.32562 .57304 m .32326 .5727 L .32722 .57159 L F
.32447 .57409 m .32395 .57349 L .32562 .57304 L F
.32395 .57349 m .32326 .5727 L .32562 .57304 L F
.517 .424 .689 r
.32688 .57768 m .32863 .5739 L .32696 .57453 L F
.623 .473 .658 r
.28666 .55633 m .28882 .55256 L .28671 .55303 L F
.587 .472 .689 r
.2819 .65108 m .28019 .65535 L .28003 .6524 L F
.2819 .65108 m .28267 .65479 L .28019 .65535 L F
0 .181 .712 r
.2817 .65613 m .28019 .65535 L .28267 .65479 L F
.677 .785 .315 r
.28197 .65536 m .2817 .65613 L .2821 .65505 L F
0 .181 .712 r
.2817 .65613 m .2815 .65671 L .28019 .65535 L F
.2817 .65613 m .28236 .65761 L .2815 .65671 L F
.693 .849 .957 r
.27746 .65623 m .28236 .65761 L .2817 .65613 L F
.646 .206 .191 r
.27746 .65623 m .2817 .65613 L .28065 .65833 L F
.677 .785 .315 r
.28065 .65833 m .2817 .65613 L .28197 .65536 L F
.154 0 .026 r
.19668 .56581 m .19512 .56828 L .19352 .56816 L F
.115 0 .004 r
.19722 .56732 m .19668 .56581 L .19869 .56496 L F
.19722 .56732 m .19512 .56828 L .19668 .56581 L F
.972 .683 .417 r
.78731 .4039 m .78861 .40272 L .78494 .40222 L F
.78731 .4039 m .78877 .40517 L .78861 .40272 L F
.301 0 .208 r
.1653 .56886 m .16433 .57079 L .16746 .56817 L F
.495 .571 .861 r
.2548 .68549 m .25866 .68856 L .25655 .68522 L F
.182 .416 .852 r
.25655 .68522 m .25866 .68856 L .2593 .68695 L F
.557 .351 .557 r
.25866 .68856 m .26098 .68846 L .25856 .69119 L F
.869 .858 .828 r
.25856 .69119 m .2593 .68695 L .25866 .68856 L F
.258 .045 .387 r
.24682 .64121 m .24541 .64246 L .24747 .64098 L F
.314 .04 .329 r
.25655 .68522 m .25781 .68274 L .2548 .68549 L F
.653 .378 .492 r
.30931 .642 m .30556 .64476 L .30607 .64288 L F
.485 0 0 r
.52546 .52265 m .52821 .52384 L .52975 .52308 L F
.372 .809 .652 r
.52975 .52308 m .5302 .52272 L .53223 .52245 L F
.52975 .52308 m .52821 .52384 L .5302 .52272 L F
0 0 0 r
.55126 .54977 m .55042 .55152 L .54763 .55301 L F
0 0 .485 r
.54964 .55371 m .5498 .55185 L .55042 .55152 L F
.813 .826 .351 r
.54998 .55157 m .54964 .55371 L .55042 .55152 L F
.713 .659 .106 r
.54998 .55157 m .54952 .55509 L .54964 .55371 L F
.54952 .55509 m .54937 .55621 L .54964 .55371 L F
0 0 .485 r
.54964 .55371 m .54763 .55301 L .5498 .55185 L F
.54964 .55371 m .5485 .55605 L .54763 .55301 L F
.752 .801 .892 r
.19606 .60588 m .19155 .60573 L .19413 .60504 L F
.966 .719 .51 r
.19606 .60588 m .19656 .60125 L .19904 .60488 L F
.19606 .60588 m .19428 .60098 L .19656 .60125 L F
.19606 .60588 m .19413 .60504 L .19428 .60098 L F
.43 .433 .761 r
.35724 .56074 m .35665 .56546 L .35555 .56108 L F
.35724 .56074 m .3586 .56486 L .35665 .56546 L F
.517 .451 .721 r
.3586 .56486 m .3571 .56943 L .35665 .56546 L F
.781 .624 .686 r
.54808 .57764 m .55194 .57819 L .55021 .5746 L F
.797 .704 .763 r
.54785 .58011 m .55194 .57819 L .54808 .57764 L F
.641 .786 .951 r
.2072 .63261 m .21145 .63311 L .21005 .63156 L F
.332 .632 .961 r
.21005 .63156 m .21145 .63311 L .2118 .63156 L F
0 .1 .65 r
.21145 .63311 m .21327 .63526 L .2118 .63156 L F
0 0 0 r
.2166 .53904 m .21885 .53848 L .2209 .53786 L F
.21885 .53848 m .21953 .53822 L .2209 .53786 L F
.004 0 0 r
.21858 .53809 m .2209 .53786 L .2224 .53747 L F
0 0 0 r
.21953 .53822 m .22294 .53691 L .2209 .53786 L F
.004 0 0 r
.2224 .53747 m .2209 .53786 L .22244 .53746 L F
.401 .851 .774 r
.22244 .53746 m .22294 .53691 L .22476 .53693 L F
.22244 .53746 m .2209 .53786 L .22294 .53691 L F
.185 .708 .868 r
.32055 .53668 m .31854 .53686 L .31652 .53653 L F
.767 .501 .532 r
.25052 .69721 m .25194 .69477 L .25027 .69484 L F
.695 .608 .755 r
.32892 .58479 m .3325 .58698 L .33135 .58381 L F
.638 .37 .496 r
.32892 .58958 m .33216 .58945 L .3325 .58698 L F
.643 .462 .624 r
.33135 .58381 m .33389 .58352 L .33383 .58034 L F
.473 .328 .603 r
.33383 .58034 m .33389 .58352 L .33496 .58318 L F
.45 .488 .806 r
.33135 .58381 m .3346 .58327 L .33389 .58352 L F
.851 .418 0 r
.3346 .58327 m .33496 .58318 L .33389 .58352 L F
.45 .488 .806 r
.33135 .58381 m .3325 .58698 L .3346 .58327 L F
.592 .528 .751 r
.33216 .58945 m .3346 .58327 L .3325 .58698 L F
.134 .674 .84 r
.23514 .63866 m .23356 .63845 L .23142 .63852 L F
.506 .887 .966 r
.23581 .63767 m .23514 .63866 L .23795 .63847 L F
.23581 .63767 m .23356 .63845 L .23514 .63866 L F
.359 .026 .257 r
.19848 .54671 m .20063 .54619 L .20153 .54422 L F
.20153 .54422 m .20063 .54619 L .20367 .54363 L F
0 0 0 r
.24181 .6242 m .24137 .62424 L .23973 .62408 L F
.24181 .6242 m .24352 .62397 L .24137 .62424 L F
.51 .426 .697 r
.30618 .60487 m .30288 .60192 L .30784 .60273 L F
.234 0 .076 r
.30839 .60415 m .30784 .60273 L .30871 .60143 L F
.30839 .60415 m .30618 .60487 L .30784 .60273 L F
.625 .543 .743 r
.29045 .54373 m .29043 .54999 L .29475 .54783 L F
.42 .24 .53 r
.29323 .5492 m .29475 .54783 L .29043 .54999 L F
.325 0 .056 r
.29043 .54999 m .29152 .55078 L .29323 .5492 L F
.473 .262 .512 r
.34642 .55018 m .34859 .54991 L .3485 .54648 L F
.568 .335 .522 r
.3485 .54648 m .35157 .54841 L .35206 .54617 L F
.3485 .54648 m .34859 .54991 L .35157 .54841 L F
.536 0 0 r
.27069 .55681 m .26705 .55496 L .26823 .55712 L F
.682 .56 .71 r
.35377 .55308 m .35562 .55715 L .35126 .55614 L F
.271 .335 .746 r
.33466 .56804 m .33729 .57075 L .3363 .56601 L F
.576 .388 .59 r
.33466 .56804 m .33528 .57235 L .33729 .57075 L F
0 0 .375 r
.2724 .60556 m .27362 .60694 L .27385 .60476 L F
.2724 .60556 m .27249 .60822 L .27362 .60694 L F
.3 .773 .932 r
.3115 .59605 m .31528 .59611 L .31421 .59562 L F
.707 .584 .716 r
.31752 .59553 m .32142 .59879 L .31963 .59396 L F
.584 .493 .718 r
.31528 .59611 m .31595 .59665 L .31752 .59553 L F
.31595 .59665 m .31889 .59904 L .31752 .59553 L F
.707 .584 .716 r
.31752 .59553 m .31889 .59904 L .32142 .59879 L F
0 0 0 r
.31915 .59438 m .31752 .59553 L .31696 .59628 L F
.31963 .59396 m .31752 .59553 L .31915 .59438 L F
.584 .493 .718 r
.31528 .59611 m .31613 .59953 L .31889 .59904 L F
0 0 0 r
.31788 .59568 m .31696 .59628 L .31605 .59749 L F
.31963 .59396 m .3178 .59555 L .31818 .59539 L F
.31963 .59396 m .3161 .59745 L .3181 .59678 L F
.3161 .59745 m .31605 .59749 L .3181 .59678 L F
.749 .657 .759 r
.31963 .59396 m .32142 .59879 L .32388 .59569 L F
.804 .556 .564 r
.31963 .59396 m .32388 .59569 L .32408 .59314 L F
.191 0 .068 r
.3181 .59678 m .32076 .59427 L .32066 .59633 L F
0 .089 .644 r
.31978 .59622 m .3181 .59678 L .32066 .59633 L F
0 0 0 r
.31818 .59539 m .31696 .59628 L .31788 .59568 L F
.3178 .59555 m .31696 .59628 L .31818 .59539 L F
.409 .84 .951 r
.31572 .59558 m .31528 .59611 L .31752 .59553 L F
.31421 .59562 m .31476 .59587 L .31572 .59558 L F
.31476 .59587 m .31528 .59611 L .31572 .59558 L F
.718 .312 .277 r
.31421 .59562 m .31752 .59553 L .31605 .59749 L F
.191 0 .068 r
.3181 .59678 m .31963 .59396 L .32076 .59427 L F
0 .089 .644 r
.31646 .59578 m .3181 .59678 L .31978 .59622 L F
.491 .529 .823 r
.31849 .59474 m .31689 .59577 L .31864 .5952 L F
.238 0 .292 r
.32004 .59262 m .31752 .59553 L .31963 .59396 L F
.32004 .59262 m .31752 .59553 L .31963 .59396 L F
.491 .529 .823 r
.31668 .59529 m .31689 .59577 L .31849 .59474 L F
.701 .641 .786 r
.31421 .59562 m .31689 .59577 L .31491 .59122 L F
.746 .703 .811 r
.31421 .59562 m .31119 .59842 L .30962 .59579 L F
.568 .405 .62 r
.31372 .59791 m .31119 .59842 L .31381 .59599 L F
.31414 .59598 m .31381 .59599 L .31421 .59562 L F
.31372 .59791 m .31381 .59599 L .31414 .59598 L F
.014 0 0 r
.31564 .59589 m .31626 .59585 L .31689 .59577 L F
0 0 0 r
.31606 .59588 m .31876 .59514 L .31689 .59577 L F
.718 .312 .277 r
.31454 .59596 m .31605 .59749 L .31414 .59598 L F
.014 0 0 r
.31586 .59589 m .31606 .59588 L .31626 .59585 L F
.31622 .59583 m .31689 .59577 L .3165 .59575 L F
.31622 .59583 m .3165 .59575 L .31421 .59562 L F
.718 .312 .277 r
.31421 .59562 m .31454 .59596 L .31414 .59598 L F
.014 0 0 r
.31195 .59625 m .31622 .59583 L .31421 .59562 L F
0 0 0 r
.31414 .59614 m .31781 .59535 L .31606 .59588 L F
.31781 .59535 m .31876 .59514 L .31606 .59588 L F
.718 .312 .277 r
.31402 .5965 m .31605 .59749 L .31372 .59791 L F
.31414 .59598 m .31458 .59633 L .31402 .5965 L F
.31458 .59633 m .31605 .59749 L .31402 .5965 L F
.014 0 0 r
.31195 .59625 m .31414 .59614 L .31606 .59588 L F
.31195 .59625 m .31606 .59588 L .31586 .59589 L F
.31195 .59625 m .31626 .59585 L .31564 .59589 L F
.491 .529 .823 r
.31883 .59507 m .31864 .5952 L .31887 .59512 L F
0 0 0 r
.31876 .59514 m .31887 .59512 L .31864 .5952 L F
.31876 .59514 m .31864 .5952 L .31689 .59577 L F
.491 .529 .823 r
.31849 .59474 m .31864 .5952 L .31883 .59507 L F
.31491 .59122 m .31668 .59529 L .31849 .59474 L F
.458 .273 .54 r
.25458 .67008 m .25447 .67305 L .25639 .67228 L F
.941 .742 .605 r
.78842 .40779 m .79006 .40883 L .78877 .40517 L F
.93 .688 .55 r
.78749 .40959 m .79006 .40883 L .78842 .40779 L F
.78749 .40959 m .79003 .41147 L .79006 .40883 L F
0 0 .123 r
.28377 .58911 m .28545 .58839 L .28611 .58626 L F
0 0 0 r
.28377 .58911 m .28106 .59066 L .28545 .58839 L F
.27227 .62036 m .27124 .62284 L .26983 .62397 L F
0 0 .01 r
.27006 .6251 m .26983 .62397 L .27124 .62284 L F
.27006 .6251 m .26949 .6262 L .26983 .62397 L F
.652 .096 0 r
.3394 .55722 m .34181 .55805 L .33899 .55567 L F
.944 .685 .514 r
.20562 .78687 m .20591 .78414 L .20374 .78575 L F
.896 .714 .648 r
.54376 .54349 m .54116 .54285 L .54276 .54011 L F
.891 .605 .497 r
.54376 .54349 m .543 .54474 L .54116 .54285 L F
.54376 .54349 m .54397 .54687 L .543 .54474 L F
.668 .593 .762 r
.54657 .54075 m .54376 .54349 L .54276 .54011 L F
.448 .264 .538 r
.5462 .54575 m .54397 .54687 L .54376 .54349 L F
.5462 .54575 m .54397 .54687 L .54376 .54349 L F
.851 .556 .489 r
.54656 .52208 m .54824 .52554 L .54993 .5255 L F
.816 .458 .379 r
.54824 .52554 m .54836 .52743 L .54993 .5255 L F
.81 .449 .374 r
.54836 .52743 m .55198 .52843 L .54993 .5255 L F
.815 .448 .362 r
.54993 .5255 m .55198 .52843 L .55402 .52851 L F
.771 .705 .79 r
.23273 .73153 m .23526 .72915 L .23126 .72828 L F
.172 0 0 r
.46731 .64115 m .46809 .64151 L .46742 .64096 L F
.46731 .64115 m .46581 .64225 L .46809 .64151 L F
.449 0 0 r
.23437 .55031 m .23341 .55097 L .23094 .55106 L F
0 0 0 r
.23642 .54983 m .23341 .55097 L .23437 .55031 L F
.319 .015 .284 r
.29648 .58378 m .29853 .58321 L .29912 .5813 L F
.354 .025 .262 r
.29853 .58321 m .30126 .58086 L .29912 .5813 L F
.471 .043 .144 r
.29706 .64572 m .29521 .64795 L .29295 .64784 L F
.648 .246 .268 r
.29919 .64769 m .29521 .64795 L .29706 .64572 L F
.59 .267 .392 r
.29965 .64569 m .29919 .64769 L .29706 .64572 L F
.993 .766 .396 r
.20649 .61566 m .20726 .61476 L .20633 .6134 L F
0 0 .324 r
.20634 .61196 m .20723 .61611 L .20651 .61394 L F
.20634 .6128 m .20651 .61394 L .20633 .6134 L F
.20634 .61196 m .20651 .61394 L .20634 .6128 L F
.982 .832 .437 r
.20654 .61779 m .20688 .61636 L .20649 .61566 L F
.20688 .61636 m .20726 .61476 L .20673 .61538 L F
.20688 .61636 m .20673 .61538 L .20649 .61566 L F
.077 0 0 r
.31668 .58787 m .31776 .58843 L .31903 .58732 L F
.31668 .58787 m .31548 .58925 L .31776 .58843 L F
.598 .433 .628 r
.3162 .60211 m .31889 .59904 L .31613 .59953 L F
.725 .304 0 r
.54228 .5531 m .54148 .55215 L .54058 .55053 L F
.992 .871 .604 r
.54228 .5531 m .54033 .55427 L .54148 .55215 L F
.54228 .5531 m .5414 .55541 L .54033 .55427 L F
.261 .658 .966 r
.25662 .64094 m .25825 .64213 L .25963 .64205 L F
.334 0 0 r
.51929 .52321 m .52186 .52362 L .52343 .52213 L F
0 0 0 r
.52186 .52362 m .52546 .52265 L .52343 .52213 L F
.107 .432 .873 r
.53999 .57209 m .54088 .57094 L .53912 .57049 L F
.53999 .57209 m .54293 .57342 L .54088 .57094 L F
.248 .183 .584 r
.31349 .5824 m .31382 .58507 L .31105 .58525 L F
.433 .486 .815 r
.31382 .58507 m .31379 .58988 L .31105 .58525 L F
.366 0 0 r
.2189 .7436 m .22265 .74391 L .22105 .74407 L F
.22105 .74407 m .22265 .74391 L .2189 .7436 L F
.914 .63 .491 r
.22265 .74391 m .22331 .7463 L .22105 .74407 L F
.614 .678 .888 r
.22338 .74081 m .22265 .74391 L .22105 .74407 L F
.22338 .74081 m .22516 .74353 L .22265 .74391 L F
.599 .454 .655 r
.22516 .74353 m .22331 .7463 L .22265 .74391 L F
.119 0 0 r
.22265 .74391 m .22353 .74423 L .22105 .74407 L F
.22265 .74391 m .22516 .74353 L .22353 .74423 L F
.645 .454 .61 r
.35859 .5468 m .35612 .55011 L .35599 .54701 L F
.057 0 0 r
.35599 .54701 m .35784 .54696 L .35859 .5468 L F
.309 0 .08 r
.35759 .54629 m .35784 .54696 L .35599 .54701 L F
.333 .056 .336 r
.23459 .7158 m .23517 .71338 L .2325 .71613 L F
.083 0 .421 r
.28652 .58072 m .28763 .58013 L .28783 .57741 L F
.126 .068 .515 r
.28652 .58072 m .28785 .58278 L .28763 .58013 L F
.597 .65 .873 r
.19062 .60352 m .18926 .60614 L .18821 .60417 L F
.536 .574 .841 r
.19062 .60352 m .19155 .60573 L .18926 .60614 L F
0 0 0 r
.23376 .72163 m .23027 .72514 L .23244 .72413 L F
.352 0 .114 r
.23438 .72367 m .23376 .72163 L .23244 .72413 L F
.23438 .72367 m .23625 .7212 L .23376 .72163 L F
.702 .696 .842 r
.13845 .65193 m .13906 .65151 L .13818 .65149 L F
.601 .815 .413 r
.51419 .52869 m .51645 .52537 L .51517 .52622 L F
.51419 .52869 m .5156 .52656 L .51645 .52537 L F
0 0 0 r
.51828 .52456 m .51929 .52321 L .51645 .52537 L F
.757 .546 .611 r
.5156 .52656 m .51828 .52456 L .51645 .52537 L F
.488 .319 .578 r
.34387 .59857 m .34152 .60192 L .34148 .59927 L F
.818 .564 .554 r
.54138 .53477 m .53892 .53694 L .53589 .53346 L F
.865 .651 .61 r
.54226 .53773 m .53892 .53694 L .54138 .53477 L F
.96 .88 .711 r
.81934 .40095 m .82209 .39886 L .82042 .39811 L F
.81934 .40095 m .82045 .40215 L .82209 .39886 L F
0 0 .335 r
.29205 .59118 m .29047 .58984 L .29256 .58865 L F
.344 0 .193 r
.19479 .57005 m .19352 .56816 L .19512 .56828 L F
.19479 .57005 m .1923 .57076 L .19352 .56816 L F
.816 .663 .694 r
.54764 .57178 m .54662 .57406 L .55021 .5746 L F
.814 .673 .708 r
.54662 .57406 m .54808 .57764 L .55021 .5746 L F
.72 .758 .882 r
.23126 .72828 m .23526 .72915 L .2345 .72738 L F
.334 .521 .891 r
.2345 .72738 m .23526 .72915 L .23593 .72699 L F
.588 .796 .979 r
.23526 .72915 m .23769 .72862 L .23593 .72699 L F
.524 .408 .664 r
.3326 .62066 m .3307 .62382 L .33037 .62121 L F
.132 .006 .429 r
.28638 .56563 m .28633 .56832 L .28771 .56461 L F
0 0 0 r
.32618 .58619 m .32892 .58479 L .32714 .58577 L F
.692 .837 .953 r
.32805 .58393 m .32892 .58479 L .33135 .58381 L F
.982 .787 .566 r
.32714 .58577 m .32892 .58479 L .32805 .58393 L F
.732 .872 .458 r
.34131 .57003 m .34046 .57119 L .34062 .57091 L F
.34131 .57003 m .34062 .57091 L .34396 .56987 L F
.719 .576 .694 r
.35769 .55587 m .35377 .55308 L .35741 .55478 L F
.35769 .55587 m .35562 .55715 L .35377 .55308 L F
.464 .405 .706 r
.35942 .55159 m .35769 .55587 L .35741 .55478 L F
.35942 .55159 m .35974 .55554 L .35769 .55587 L F
.521 .257 .455 r
.35969 .5581 m .35727 .55877 L .35769 .55587 L F
.428 .248 .533 r
.35974 .55554 m .35969 .5581 L .35769 .55587 L F
.35974 .55554 m .35969 .5581 L .35769 .55587 L F
.895 .953 .833 r
.53092 .52855 m .52845 .53167 L .52798 .5301 L F
.546 .363 .584 r
.53092 .52855 m .53109 .53124 L .52845 .53167 L F
.818 .414 .285 r
.53109 .53124 m .52798 .5301 L .52845 .53167 L F
.652 .112 0 r
.35456 .54584 m .35784 .54696 L .35759 .54629 L F
.438 0 0 r
.24757 .62598 m .24953 .62653 L .25132 .62611 L F
.057 0 0 r
.25132 .62611 m .24953 .62653 L .25361 .62593 L F
.106 0 .426 r
.28484 .59817 m .28275 .60162 L .28244 .59917 L F
.76 .326 .221 r
.55198 .52843 m .55254 .52993 L .55402 .52851 L F
.939 .621 .406 r
.55402 .52851 m .55254 .52993 L .55437 .53081 L F
.58 .288 .436 r
.31815 .639 m .31443 .6418 L .31465 .6394 L F
0 0 0 r
.16241 .57156 m .15983 .57456 L .16134 .57343 L F
.216 0 .238 r
.15894 .57643 m .16134 .57343 L .15983 .57456 L F
.509 .38 .64 r
.30887 .58964 m .30634 .59498 L .30458 .59372 L F
.433 .443 .771 r
.30634 .59498 m .30551 .59588 L .30458 .59372 L F
.628 .655 .857 r
.18518 .59006 m .18279 .5907 L .18165 .58897 L F
.363 .536 .892 r
.18595 .5925 m .18279 .5907 L .18518 .59006 L F
.237 .13 .523 r
.27984 .62382 m .28132 .62524 L .28168 .62347 L F
.27984 .62382 m .27964 .62683 L .28132 .62524 L F
.334 .335 .711 r
.28778 .57338 m .2896 .57322 L .28879 .57119 L F
.387 .289 .622 r
.28783 .57741 m .2896 .57322 L .28778 .57338 L F
.658 .576 .752 r
.35612 .55011 m .35741 .55478 L .35377 .55308 L F
.76 .725 .82 r
.32004 .59262 m .32408 .59314 L .32263 .59025 L F
.804 .556 .564 r
.31963 .59396 m .32408 .59314 L .32004 .59262 L F
.57 .614 .857 r
.32408 .59314 m .32475 .58915 L .32263 .59025 L F
.32408 .59314 m .32639 .59264 L .32475 .58915 L F
.446 .247 .516 r
.32408 .59314 m .32614 .59508 L .32639 .59264 L F
.32408 .59314 m .32388 .59569 L .32614 .59508 L F
0 .324 .801 r
.15707 .73994 m .15762 .74026 L .15775 .74069 L F
.749 .982 .911 r
.15775 .74069 m .15762 .74026 L .15699 .74074 L F
.75 .698 .801 r
.8292 .41208 m .83144 .41106 L .83035 .40745 L F
0 .055 .612 r
.29635 .58161 m .29648 .58378 L .29537 .58013 L F
.966 .919 .58 r
.29635 .58161 m .29467 .58567 L .29648 .58378 L F
.342 .175 .505 r
.29661 .58633 m .29853 .58321 L .29648 .58378 L F
.668 .502 .651 r
.32576 .63003 m .32573 .63306 L .32325 .63304 L F
.673 .55 .707 r
.32833 .62968 m .32576 .63003 L .32815 .62694 L F
.642 .481 .649 r
.32933 .6322 m .32576 .63003 L .32833 .62968 L F
.32933 .6322 m .32573 .63306 L .32576 .63003 L F
.555 .879 .991 r
.21143 .61719 m .21126 .61861 L .20907 .6177 L F
.21143 .61719 m .21323 .61779 L .21126 .61861 L F
.207 0 .149 r
.16134 .57343 m .16433 .57079 L .16241 .57156 L F
.824 .608 .611 r
.26072 .67489 m .26211 .67103 L .26019 .67228 L F
.788 .776 .842 r
.26211 .67103 m .26072 .67489 L .26366 .67454 L F
.47 0 0 r
.26523 .6724 m .26211 .67103 L .26366 .67454 L F
.26523 .6724 m .26701 .67251 L .26211 .67103 L F
0 0 .286 r
.29703 .58962 m .29543 .59308 L .29661 .59232 L F
.112 .089 .55 r
.29543 .59308 m .29695 .59509 L .29661 .59232 L F
.302 .134 .48 r
.2953 .59533 m .29695 .59509 L .29543 .59308 L F
.975 .915 .675 r
.5537 .54251 m .55362 .54623 L .55495 .54398 L F
.493 .212 .416 r
.24267 .71912 m .24508 .71886 L .24429 .7211 L F
.24429 .7211 m .24508 .71886 L .24267 .71912 L F
.049 0 .379 r
.29662 .57695 m .29537 .58013 L .29559 .5778 L F
0 0 0 r
.82301 .40385 m .82678 .40304 L .82401 .40379 L F
.549 .521 .776 r
.35729 .57436 m .35557 .57709 L .35508 .5747 L F
.35729 .57436 m .35837 .57763 L .35557 .57709 L F
.531 .426 .68 r
.35837 .57763 m .35643 .58072 L .35557 .57709 L F
.862 .646 .608 r
.54276 .54011 m .53892 .53694 L .54226 .53773 L F
.765 .742 .832 r
.82779 .41057 m .8258 .41162 L .8292 .41208 L F
.75 .698 .801 r
.8292 .41208 m .83035 .40745 L .82779 .41057 L F
.202 0 .186 r
.18674 .55229 m .18766 .55417 L .18818 .55378 L F
.18674 .55229 m .18569 .55525 L .18766 .55417 L F
.895 .953 .833 r
.53092 .52855 m .52798 .5301 L .5299 .52763 L F
.56 .374 .585 r
.5334 .52864 m .53109 .53124 L .53092 .52855 L F
.375 .705 .985 r
.30233 .53424 m .30171 .53573 L .29999 .53417 L F
.30233 .53424 m .30383 .53525 L .30171 .53573 L F
.256 0 .255 r
.2745 .61768 m .2741 .62021 L .27227 .62036 L F
0 0 .14 r
.27527 .6188 m .2745 .61768 L .27584 .61638 L F
.27527 .6188 m .2741 .62021 L .2745 .61768 L F
.882 .56 .435 r
.54487 .52395 m .54656 .52208 L .54459 .52197 L F
.54487 .52395 m .54824 .52554 L .54656 .52208 L F
.517 .451 .721 r
.3586 .56486 m .36003 .56974 L .3571 .56943 L F
.166 .18 .629 r
.35893 .56999 m .3571 .56943 L .36003 .56974 L F
.35893 .56999 m .35752 .57141 L .3571 .56943 L F
.548 .682 .927 r
.78999 .42495 m .79185 .42256 L .78918 .4235 L F
.78999 .42495 m .79302 .42437 L .79185 .42256 L F
.111 0 0 r
.22476 .53693 m .22709 .53685 L .22837 .53652 L F
.148 .692 .769 r
.33057 .5394 m .33278 .53909 L .33501 .53897 L F
.197 0 0 r
.33278 .53909 m .33705 .53801 L .33501 .53897 L F
.653 .378 .492 r
.30931 .642 m .30811 .64494 L .30556 .64476 L F
.596 .318 .466 r
.31149 .64437 m .30931 .642 L .31184 .64174 L F
.31149 .64437 m .30811 .64494 L .30931 .642 L F
.053 .184 .683 r
.28781 .57067 m .28865 .56923 L .28633 .56832 L F
.28781 .57067 m .28879 .57119 L .28865 .56923 L F
.528 .837 .523 r
.25895 .68156 m .26024 .68028 L .25781 .68274 L F
0 0 0 r
.26212 .67912 m .26024 .68028 L .25895 .68156 L F
.916 .631 .488 r
.26505 .66371 m .26289 .66429 L .26404 .66287 L F
.26505 .66371 m .26553 .66724 L .26285 .6643 L F
.926 .596 .394 r
.26285 .6643 m .26553 .66724 L .26367 .66812 L F
.504 .321 .566 r
.26387 .6628 m .26367 .66812 L .26606 .66517 L F
.903 .867 .793 r
.26383 .66276 m .26404 .66287 L .26285 .6643 L F
.504 .321 .566 r
.26383 .66276 m .26383 .66286 L .26387 .6628 L F
.26383 .66286 m .26367 .66812 L .26387 .6628 L F
.916 .631 .488 r
.26289 .66429 m .26285 .6643 L .26302 .66408 L F
.26289 .66429 m .26302 .66408 L .26404 .66287 L F
0 0 0 r
.26697 .66287 m .26821 .66066 L .26505 .66371 L F
.26697 .66287 m .26505 .66371 L .26404 .66287 L F
.253 0 0 r
.23835 .72165 m .23754 .72111 L .23625 .7212 L F
.697 .536 .665 r
.30288 .60192 m .304 .60554 L .30065 .60513 L F
.51 .426 .697 r
.30618 .60487 m .304 .60554 L .30288 .60192 L F
.411 0 0 r
.26632 .67572 m .26688 .67603 L .26883 .67733 L F
.587 .676 .901 r
.26366 .67454 m .26688 .67603 L .26496 .67484 L F
.411 0 0 r
.26496 .67484 m .26688 .67603 L .26632 .67572 L F
.298 .794 .836 r
.26473 .67674 m .26737 .6763 L .26688 .67603 L F
.26737 .6763 m .26848 .67612 L .26688 .67603 L F
.207 0 0 r
.26848 .67612 m .2708 .67575 L .26883 .67733 L F
0 0 0 r
.26974 .67603 m .2708 .67575 L .26848 .67612 L F
.26974 .67603 m .26848 .67612 L .26701 .67251 L F
.207 0 0 r
.26848 .67612 m .26883 .67733 L .26688 .67603 L F
.384 .45 .805 r
.77016 .40785 m .77137 .41144 L .77322 .40932 L F
.395 .465 .815 r
.77137 .41144 m .77361 .41169 L .77322 .40932 L F
.899 .857 .792 r
.32975 .58271 m .33383 .58034 L .33217 .57963 L F
.32975 .58271 m .33135 .58381 L .33383 .58034 L F
.345 .788 .96 r
.33383 .58034 m .3364 .57994 L .33217 .57963 L F
.473 .328 .603 r
.33383 .58034 m .33496 .58318 L .3364 .57994 L F
0 0 0 r
.26789 .61464 m .26593 .61768 L .26673 .61683 L F
0 0 .147 r
.26593 .61768 m .26524 .62045 L .26673 .61683 L F
.387 .033 .237 r
.188 .57198 m .18705 .57379 L .1849 .57426 L F
.321 0 .201 r
.19022 .57147 m .18705 .57379 L .188 .57198 L F
.457 .24 .495 r
.31709 .5465 m .31667 .54969 L .31443 .55025 L F
.361 .113 .397 r
.31936 .54627 m .31667 .54969 L .31709 .5465 L F
0 0 .005 r
.25895 .68156 m .25781 .68274 L .25655 .68522 L F
.808 .859 .887 r
.27936 .64995 m .28003 .6524 L .27562 .65383 L F
.27936 .64995 m .2819 .65108 L .28003 .6524 L F
0 .349 .825 r
.18605 .6144 m .18866 .61752 L .18862 .61609 L F
0 .289 .788 r
.18866 .61752 m .19176 .62061 L .18862 .61609 L F
.653 .488 .648 r
.33091 .62651 m .32815 .62694 L .3307 .62382 L F
.524 .408 .664 r
.3326 .62066 m .333 .6233 L .3307 .62382 L F
.54 .403 .643 r
.33328 .62593 m .3307 .62382 L .333 .6233 L F
.33328 .62593 m .33091 .62651 L .3307 .62382 L F
.453 .683 .964 r
.3235 .56657 m .3252 .56838 L .32579 .56646 L F
.83 .683 .7 r
.32657 .57038 m .32579 .56646 L .3252 .56838 L F
.532 .847 .998 r
.27423 .64736 m .27831 .64748 L .27646 .64663 L F
.766 .721 .81 r
.27581 .64849 m .27831 .64748 L .27423 .64736 L F
.234 .342 .77 r
.33007 .56697 m .32764 .56536 L .32938 .56468 L F
.717 .634 .764 r
.54435 .5769 m .54548 .58077 L .54808 .57764 L F
.643 .524 .703 r
.54808 .57764 m .54548 .58077 L .54785 .58011 L F
.709 .579 .708 r
.34814 .58413 m .3456 .5873 L .34402 .58343 L F
.587 .367 .548 r
.28919 .6143 m .29177 .61449 L .29139 .61054 L F
.105 0 0 r
.29534 .60914 m .29139 .61054 L .2941 .61059 L F
.302 .162 .519 r
.29139 .61054 m .29381 .61236 L .2941 .61059 L F
.29139 .61054 m .29177 .61449 L .29381 .61236 L F
.199 .715 .881 r
.2711 .53286 m .27512 .53303 L .2726 .53351 L F
.501 .601 .885 r
.17504 .60748 m .17913 .61257 L .17948 .61047 L F
.875 .758 .73 r
.34425 .58121 m .34402 .58343 L .34243 .57996 L F
0 0 .014 r
.28385 .64984 m .2819 .65108 L .28431 .6483 L F
.391 .339 .68 r
.28428 .65437 m .2819 .65108 L .28385 .64984 L F
.28428 .65437 m .28267 .65479 L .2819 .65108 L F
.424 .574 .899 r
.77361 .41169 m .77523 .4145 L .77682 .41253 L F
.344 .457 .832 r
.77682 .41253 m .77523 .4145 L .77721 .41477 L F
.63 .78 .953 r
.81043 .41692 m .81416 .41747 L .81317 .41619 L F
.571 .686 .918 r
.81416 .41747 m .81588 .41551 L .81317 .41619 L F
.81416 .41747 m .8168 .41693 L .81588 .41551 L F
.618 .911 .982 r
.8163 .39873 m .81838 .39657 L .81977 .39761 L F
.8163 .39873 m .8154 .3979 L .81838 .39657 L F
0 .092 .644 r
.27389 .54571 m .27725 .55082 L .27577 .54762 L F
.27389 .54571 m .27577 .54762 L .27563 .54743 L F
.27389 .54571 m .27573 .54753 L .27614 .54521 L F
.812 .579 .586 r
.27458 .54602 m .27371 .54857 L .27169 .54753 L F
.27614 .54521 m .27507 .54668 L .27458 .54602 L F
.27507 .54668 m .27371 .54857 L .27458 .54602 L F
.816 .982 .889 r
.2768 .54524 m .27548 .54666 L .27573 .54753 L F
0 .092 .644 r
.27563 .54743 m .27571 .54755 L .27573 .54753 L F
.27571 .54755 m .27574 .54759 L .27573 .54753 L F
.688 .184 .036 r
.26964 .54797 m .27435 .5494 L .27131 .55037 L F
.26964 .54797 m .27174 .54991 L .27435 .5494 L F
.201 0 0 r
.27305 .54966 m .27573 .54753 L .27435 .5494 L F
.27174 .54991 m .27365 .54877 L .27305 .54966 L F
.27365 .54877 m .27573 .54753 L .27305 .54966 L F
.816 .982 .889 r
.27548 .54666 m .27371 .54857 L .27573 .54753 L F
.201 0 0 r
.27174 .54991 m .27404 .54937 L .27573 .54753 L F
.667 .939 .667 r
.27584 .54593 m .27371 .54857 L .2768 .54524 L F
0 0 0 r
.27584 .54593 m .27404 .54937 L .27374 .54864 L F
.27417 .54801 m .27374 .54864 L .27371 .54857 L F
.27584 .54593 m .27374 .54864 L .27417 .54801 L F
.656 .411 .537 r
.27404 .54937 m .27595 .54714 L .27573 .54753 L F
.816 .982 .889 r
.2768 .54524 m .27573 .54753 L .27688 .54605 L F
.656 .411 .537 r
.27595 .54714 m .27688 .54605 L .27573 .54753 L F
0 .092 .644 r
.27574 .54759 m .27577 .54762 L .27573 .54753 L F
.782 .873 .914 r
.27725 .55082 m .27435 .5494 L .27573 .54753 L F
.284 0 .055 r
.32353 .58546 m .32516 .5841 L .32187 .58622 L F
.54 .174 .295 r
.32714 .58577 m .32516 .5841 L .32353 .58546 L F
.515 .183 .342 r
.32714 .58577 m .32805 .58393 L .32516 .5841 L F
.433 .443 .771 r
.30634 .59498 m .30735 .59537 L .30551 .59588 L F
.446 .292 .578 r
.28378 .54569 m .28388 .54885 L .28169 .54656 L F
.417 .863 .894 r
.26255 .62351 m .26031 .62428 L .25775 .62432 L F
.106 .66 .784 r
.2332 .53574 m .23552 .5356 L .2376 .53569 L F
.225 .742 .857 r
.23552 .5356 m .23931 .53542 L .2376 .53569 L F
.833 .788 .809 r
.22352 .61759 m .22107 .62071 L .21944 .61895 L F
.531 .344 .572 r
.22359 .61993 m .22107 .62071 L .22352 .61759 L F
.713 .85 .947 r
.16123 .60181 m .16302 .60304 L .16526 .6019 L F
.104 0 0 r
.20627 .54295 m .20844 .54245 L .21007 .54113 L F
0 0 0 r
.20844 .54245 m .21246 .54056 L .21007 .54113 L F
.2794 .55042 m .27761 .55169 L .27931 .55023 L F
.988 .756 .496 r
.54985 .55909 m .54827 .56061 L .54975 .5616 L F
0 0 .364 r
.5485 .55605 m .54969 .5585 L .54985 .55909 L F
.82 .951 .604 r
.54969 .5585 m .54827 .56061 L .54985 .55909 L F
.472 .863 .67 r
.8094 .40939 m .8062 .4115 L .80865 .40972 L F
.018 0 0 r
.80865 .40972 m .81172 .40806 L .8094 .40939 L F
.434 0 .003 r
.34396 .56987 m .34608 .57021 L .34665 .56889 L F
.39 .403 .753 r
.34603 .56509 m .34665 .56889 L .34868 .56688 L F
0 0 0 r
.34665 .56889 m .34608 .57021 L .34868 .56688 L F
.19848 .54671 m .19444 .54907 L .19654 .54826 L F
.19855 .5473 m .19848 .54671 L .19654 .54826 L F
.19855 .5473 m .20063 .54619 L .19848 .54671 L F
.495 .318 .57 r
.32325 .63304 m .32546 .63526 L .32306 .63574 L F
.63 .312 .414 r
.32573 .63306 m .32546 .63526 L .32325 .63304 L F
.32 0 0 r
.26879 .66194 m .26821 .66066 L .26697 .66287 L F
.356 .552 .906 r
.27263 .66341 m .26821 .66066 L .27039 .66074 L F
.32 0 0 r
.26879 .66194 m .27039 .66074 L .26821 .66066 L F
.531 .426 .68 r
.35837 .57763 m .35876 .58018 L .35643 .58072 L F
.528 .318 .538 r
.35876 .58282 m .35643 .58072 L .35876 .58018 L F
.35876 .58282 m .35631 .58345 L .35643 .58072 L F
.368 .162 .463 r
.27391 .60147 m .2761 .59855 L .27407 .59922 L F
.457 .255 .516 r
.35752 .57141 m .35729 .57436 L .35508 .5747 L F
.488 .256 .489 r
.27638 .59607 m .27884 .59795 L .27879 .59537 L F
.27638 .59607 m .2761 .59855 L .27884 .59795 L F
.289 .201 .58 r
.32761 .58064 m .3293 .57725 L .32688 .57768 L F
.32761 .58064 m .32957 .58009 L .3293 .57725 L F
.311 .271 .652 r
.32761 .58064 m .32975 .58271 L .32957 .58009 L F
.53 .611 .878 r
.17948 .61047 m .18083 .61367 L .18309 .61308 L F
.508 .659 .928 r
.18083 .61367 m .18426 .61481 L .18309 .61308 L F
.693 .719 .869 r
.18165 .58897 m .17907 .58993 L .17771 .58774 L F
.589 .534 .76 r
.35942 .55159 m .35741 .55478 L .35612 .55011 L F
.594 .489 .704 r
.33093 .62907 m .32815 .62694 L .33091 .62651 L F
.33093 .62907 m .32833 .62968 L .32815 .62694 L F
.801 .951 .611 r
.55176 .54791 m .55362 .54623 L .5525 .54566 L F
.55176 .54791 m .55126 .54977 L .55362 .54623 L F
.975 .915 .675 r
.5537 .54251 m .5525 .54566 L .55362 .54623 L F
.347 .208 .545 r
.15546 .5837 m .15717 .58567 L .15701 .58301 L F
.15546 .5837 m .15543 .5864 L .15717 .58567 L F
.967 .694 .462 r
.35784 .54696 m .35674 .54809 L .35859 .5468 L F
.73 .57 .674 r
.36042 .54889 m .35612 .55011 L .35859 .5468 L F
.603 .484 .691 r
.35875 .54658 m .35859 .5468 L .35935 .54648 L F
.592 .434 .636 r
.36355 .5432 m .36392 .5446 L .35875 .54658 L F
.36392 .5446 m .36423 .54575 L .35935 .54648 L F
.36392 .5446 m .35935 .54648 L .35875 .54658 L F
.603 .484 .691 r
.35875 .54658 m .35935 .54648 L .36092 .54583 L F
.592 .434 .636 r
.36355 .5432 m .35875 .54658 L .36092 .54583 L F
.361 .826 .754 r
.35935 .54648 m .35996 .54604 L .36092 .54583 L F
.35859 .5468 m .3586 .54679 L .35935 .54648 L F
.3586 .54679 m .35996 .54604 L .35935 .54648 L F
.592 .434 .636 r
.36423 .54575 m .36437 .5463 L .35878 .54657 L F
.36423 .54575 m .35878 .54657 L .35879 .54657 L F
0 0 0 r
.3586 .54679 m .35958 .54685 L .35996 .54604 L F
.35859 .5468 m .35859 .5468 L .3586 .54679 L F
.35859 .5468 m .35958 .54685 L .3586 .54679 L F
.592 .434 .636 r
.35879 .54657 m .35878 .54657 L .35875 .54658 L F
0 0 0 r
.35859 .5468 m .35674 .54809 L .35958 .54685 L F
.498 .636 .916 r
.3133 .53581 m .31179 .53781 L .31008 .53537 L F
.3133 .53581 m .3141 .53744 L .31179 .53781 L F
.594 .45 .655 r
.33093 .62907 m .32933 .6322 L .32833 .62968 L F
.707 .372 .408 r
.81772 .40439 m .81366 .40242 L .81414 .40327 L F
.156 0 0 r
.81456 .40579 m .81772 .40439 L .81414 .40327 L F
.28 0 0 r
.52729 .52637 m .52307 .52693 L .52334 .52564 L F
.52729 .52637 m .52575 .527 L .52307 .52693 L F
.833 .788 .809 r
.22352 .61759 m .21944 .61895 L .22216 .6184 L F
.987 .724 .428 r
.22216 .6184 m .22359 .61993 L .22352 .61759 L F
.129 .384 .839 r
.19815 .60186 m .19904 .60488 L .19656 .60125 L F
.19815 .60186 m .20011 .6048 L .19904 .60488 L F
.151 0 .231 r
.18151 .55688 m .18269 .55737 L .18365 .55623 L F
.18151 .55688 m .18089 .55872 L .18269 .55737 L F
.636 .483 .658 r
.45968 .65782 m .46239 .65771 L .4618 .65441 L F
.505 .429 .705 r
.35893 .56999 m .35729 .57436 L .35752 .57141 L F
.706 .648 .092 r
.34642 .55018 m .34646 .5498 L .34786 .55 L F
.427 .456 .787 r
.3433 .55282 m .34608 .55482 L .34616 .55226 L F
.598 .174 .208 r
.34539 .55351 m .34193 .55185 L .3461 .54978 L F
.34651 .54973 m .3461 .54978 L .34657 .54955 L F
0 0 .234 r
.34651 .54973 m .34657 .54955 L .34646 .54972 L F
.34655 .54974 m .34657 .54955 L .34651 .54973 L F
.598 .174 .208 r
.34651 .54973 m .34651 .54973 L .34657 .54955 L F
.706 .648 .092 r
.34646 .5498 m .34646 .54974 L .34655 .54974 L F
.34646 .54974 m .34651 .54973 L .34655 .54974 L F
.598 .174 .208 r
.34539 .55351 m .3461 .54978 L .34651 .54973 L F
.706 .648 .092 r
.34646 .54974 m .34646 .54972 L .34651 .54973 L F
.34646 .5498 m .34655 .54974 L .34786 .55 L F
0 0 .234 r
.34608 .55482 m .34684 .5539 L .34658 .54972 L F
.34655 .54974 m .34658 .54972 L .34657 .54955 L F
.34608 .55482 m .34658 .54972 L .34655 .54974 L F
.34608 .55482 m .34655 .54974 L .34646 .54972 L F
.706 .648 .092 r
.34642 .55018 m .34616 .55226 L .34645 .54984 L F
.34646 .54974 m .34645 .54984 L .34646 .54972 L F
.34642 .55018 m .34645 .54984 L .34646 .54974 L F
0 0 .041 r
.34616 .55226 m .34608 .55482 L .34645 .54996 L F
.34645 .54984 m .34645 .54996 L .34646 .54972 L F
.34616 .55226 m .34645 .54996 L .34645 .54984 L F
.353 .176 .496 r
.34651 .54973 m .3468 .55343 L .34632 .55376 L F
.34644 .55031 m .34632 .55376 L .34597 .55367 L F
.34651 .54973 m .34632 .55376 L .34644 .55031 L F
.34643 .55003 m .34597 .55367 L .34539 .55351 L F
.34651 .54973 m .34597 .55367 L .34643 .55003 L F
.34658 .54972 m .34684 .5539 L .34651 .54973 L F
.427 .456 .787 r
.3433 .55282 m .34363 .55618 L .34608 .55482 L F
.34 0 .232 r
.34363 .55618 m .34555 .55742 L .34608 .55482 L F
.466 .856 .978 r
.34547 .55551 m .34539 .55351 L .34684 .5539 L F
.891 .99 .76 r
.3471 .55133 m .34461 .55452 L .34547 .5555 L F
.34549 .55548 m .34547 .5555 L .34547 .55551 L F
.3471 .55133 m .34547 .5555 L .34549 .55548 L F
.353 .176 .496 r
.3468 .55343 m .34684 .5539 L .34655 .55383 L F
.3468 .55343 m .34655 .55383 L .34632 .55376 L F
.34657 .54955 m .34658 .54972 L .34651 .54973 L F
.706 .648 .092 r
.34786 .55 m .34651 .54973 L .34859 .54991 L F
.34651 .54973 m .34646 .54972 L .34654 .54973 L F
.34651 .54973 m .34654 .54973 L .34859 .54991 L F
.577 .32 .49 r
.80363 .41413 m .80629 .41422 L .8062 .4115 L F
.598 .492 .705 r
.80629 .41422 m .80865 .40972 L .8062 .4115 L F
.367 .724 .988 r
.23142 .63852 m .23196 .63732 L .22813 .63672 L F
.23142 .63852 m .23356 .63845 L .23196 .63732 L F
.567 .556 .801 r
.24849 .54905 m .24783 .55301 L .24751 .55077 L F
.24849 .54905 m .25054 .55389 L .24783 .55301 L F
.916 .958 .799 r
.24783 .55301 m .24603 .5538 L .24751 .55077 L F
.666 .241 .228 r
.24783 .55301 m .2499 .55498 L .24719 .55389 L F
.764 .364 .294 r
.24719 .55389 m .24603 .5538 L .24783 .55301 L F
.552 .367 .584 r
.2772 .62929 m .27988 .62903 L .27964 .62683 L F
.485 .066 .168 r
.27558 .631 m .27988 .62903 L .2772 .62929 L F
.548 .838 .998 r
.27195 .64857 m .27581 .64849 L .27423 .64736 L F
.577 .247 .373 r
.45968 .65782 m .46197 .65964 L .46239 .65771 L F
.46239 .65771 m .46197 .65964 L .45968 .65782 L F
.589 .534 .76 r
.35942 .55159 m .35612 .55011 L .36042 .54889 L F
.286 .786 .851 r
.23931 .53542 m .24151 .53492 L .24381 .53492 L F
.29 .788 .859 r
.24151 .53492 m .24608 .53446 L .24381 .53492 L F
.58 .288 .436 r
.31815 .639 m .317 .64168 L .31443 .6418 L F
.641 .352 .465 r
.32039 .6412 m .31815 .639 L .32073 .63892 L F
.32039 .6412 m .317 .64168 L .31815 .639 L F
.862 .646 .608 r
.54276 .54011 m .53868 .53957 L .53892 .53694 L F
.881 .659 .597 r
.54116 .54285 m .53868 .53957 L .54276 .54011 L F
.683 .745 .899 r
.7992 .42584 m .8004 .42763 L .80298 .42656 L F
.637 .466 .634 r
.2639 .68447 m .26406 .68653 L .26098 .68846 L F
.229 .161 .568 r
.26567 .68758 m .2639 .68447 L .26561 .68445 L F
.26567 .68758 m .26406 .68653 L .2639 .68447 L F
.965 .684 .26 r
.2701 .65782 m .27039 .66074 L .26919 .65658 L F
0 0 .487 r
.47076 .63562 m .47207 .63864 L .47153 .63863 L F
.489 .302 .553 r
.4718 .63864 m .47077 .64076 L .47153 .63863 L F
.47182 .63864 m .4716 .63908 L .4718 .63864 L F
.4716 .63908 m .47077 .64076 L .4718 .63864 L F
.504 .231 .433 r
.4716 .63908 m .47063 .64114 L .47183 .63892 L F
.46809 .64151 m .47063 .64114 L .4716 .63908 L F
.46809 .64151 m .4716 .63908 L .46742 .64096 L F
.4716 .63908 m .47183 .63892 L .47163 .63901 L F
.4716 .63908 m .47163 .63901 L .46742 .64096 L F
.489 .302 .553 r
.47063 .64114 m .47207 .63864 L .47183 .63892 L F
.47207 .63864 m .47063 .64114 L .47077 .64076 L F
.47207 .63864 m .47077 .64076 L .47182 .63864 L F
0 0 0 r
.27035 .61157 m .26789 .61464 L .26911 .61319 L F
.26911 .61319 m .26789 .61464 L .26673 .61683 L F
.576 .37 .564 r
.33785 .61424 m .33516 .61716 L .33531 .61467 L F
0 .203 .677 r
.23721 .71256 m .2409 .71539 L .24177 .71313 L F
.616 .338 .473 r
.24177 .71313 m .24373 .71556 L .2409 .71539 L F
.24177 .71313 m .24373 .71556 L .2409 .71539 L F
.593 .591 .82 r
.18763 .59183 m .18668 .59597 L .18595 .5925 L F
.18763 .59183 m .18929 .59602 L .18668 .59597 L F
.338 .357 .734 r
.32145 .57273 m .32016 .57506 L .31909 .57106 L F
.14 0 .298 r
.32231 .57468 m .32016 .57506 L .32145 .57273 L F
.32231 .57468 m .31934 .5769 L .32016 .57506 L F
.592 .281 .41 r
.30313 .64484 m .29919 .64769 L .29965 .64569 L F
.637 .441 .6 r
.34904 .59535 m .34639 .59832 L .34704 .59626 L F
.46 .574 .883 r
.77721 .41477 m .77879 .41772 L .78066 .41555 L F
.425 .521 .852 r
.77879 .41772 m .78196 .4188 L .78066 .41555 L F
.153 0 0 r
.2138 .55854 m .21236 .55927 L .21012 .55951 L F
.079 0 0 r
.21626 .55831 m .21236 .55927 L .2138 .55854 L F
0 0 .511 r
.33193 .56657 m .33123 .56895 L .33007 .56697 L F
.616 .673 .881 r
.21911 .63457 m .22137 .63686 L .22335 .63578 L F
.46 .626 .924 r
.18862 .61609 m .19176 .62061 L .19378 .61916 L F
.383 .457 .812 r
.19189 .62069 m .19378 .61916 L .19176 .62061 L F
.535 .446 .701 r
.177 .58275 m .17771 .58774 L .17521 .58781 L F
.517 .424 .689 r
.32688 .57768 m .3293 .57725 L .32863 .5739 L F
.838 .774 .791 r
.27316 .65812 m .27447 .66058 L .27657 .6573 L F
.505 .441 .719 r
.30376 .57428 m .3065 .57694 L .30578 .57378 L F
.30376 .57428 m .30446 .5775 L .3065 .57694 L F
.521 .571 .847 r
.24672 .69947 m .24838 .70327 L .25267 .70235 L F
.291 .18 .55 r
.1568 .57771 m .15879 .57911 L .15894 .57643 L F
.1568 .57771 m .15683 .58039 L .15879 .57911 L F
.609 .789 .967 r
.26966 .66747 m .27003 .66521 L .26794 .66656 L F
.26966 .66747 m .27196 .66671 L .27003 .66521 L F
.258 .356 .773 r
.15709 .59249 m .15819 .59613 L .15916 .59542 L F
.179 .208 .654 r
.15819 .59613 m .15994 .59783 L .15916 .59542 L F
.398 .23 .533 r
.15819 .59613 m .15764 .59929 L .15994 .59783 L F
.478 .629 .919 r
.19591 .62351 m .19587 .62061 L .19393 .62176 L F
.19591 .62351 m .19789 .62323 L .19587 .62061 L F
.418 .484 .821 r
.31953 .55172 m .3179 .55322 L .31667 .54969 L F
.435 .446 .772 r
.31953 .55172 m .31862 .55468 L .3179 .55322 L F
.219 .603 .95 r
.2189 .7436 m .22105 .74407 L .21923 .74248 L F
.21923 .74248 m .22105 .74407 L .2189 .7436 L F
.011 0 .423 r
.81366 .40242 m .81564 .40035 L .8154 .3979 L F
.707 .372 .408 r
.81772 .40439 m .81716 .40538 L .81677 .40505 L F
.156 0 0 r
.81456 .40579 m .8161 .40552 L .81677 .40505 L F
.81616 .40509 m .81677 .40505 L .81772 .40439 L F
.81456 .40579 m .81677 .40505 L .81616 .40509 L F
.707 .372 .408 r
.81772 .40439 m .81677 .40505 L .81366 .40242 L F
.305 .397 .793 r
.81366 .40242 m .81677 .40505 L .81564 .40035 L F
.81677 .40505 m .81716 .40538 L .81706 .40503 L F
.156 0 0 r
.8161 .40552 m .81682 .40539 L .81721 .40495 L F
.81611 .40551 m .81721 .40495 L .81772 .40439 L F
.8161 .40552 m .81721 .40495 L .81611 .40551 L F
.79 .705 .771 r
.81564 .40035 m .81706 .40503 L .81934 .40095 L F
.279 0 0 r
.81829 .40452 m .81682 .40539 L .81956 .40479 L F
.81772 .40439 m .81721 .40495 L .81829 .40452 L F
.79 .705 .771 r
.81706 .40503 m .81716 .40538 L .81741 .40487 L F
.81706 .40503 m .81741 .40487 L .81721 .40495 L F
.279 0 0 r
.81721 .40495 m .81682 .40539 L .81829 .40452 L F
.79 .705 .771 r
.81721 .40495 m .81741 .40487 L .81742 .40485 L F
.81706 .40503 m .81742 .40485 L .81934 .40095 L F
.305 .397 .793 r
.81677 .40505 m .81706 .40503 L .81564 .40035 L F
.439 .559 .879 r
.78666 .42329 m .78799 .42138 L .78523 .42092 L F
.78666 .42329 m .78918 .4235 L .78799 .42138 L F
.523 .722 .964 r
.32954 .53816 m .3282 .53982 L .32627 .5379 L F
.32954 .53816 m .33057 .5394 L .3282 .53982 L F
.848 .719 .72 r
.80189 .42285 m .80513 .42351 L .80555 .42111 L F
.845 .729 .736 r
.80189 .42285 m .80298 .42656 L .80513 .42351 L F
.619 .604 .814 r
.20594 .62923 m .2072 .63261 L .21005 .63156 L F
.454 .285 .561 r
.30446 .5775 m .30649 .57936 L .3065 .57694 L F
.30446 .5775 m .30456 .58008 L .30649 .57936 L F
.74 .807 .332 r
.55176 .54791 m .55042 .55152 L .55126 .54977 L F
.386 .185 .481 r
.1849 .57426 m .18457 .5773 L .18249 .5775 L F
.581 .453 .671 r
.18457 .5773 m .18246 .57951 L .18249 .5775 L F
.801 .5 .481 r
.29323 .5492 m .29152 .55078 L .29347 .55071 L F
.719 .377 .399 r
.29152 .55078 m .29397 .55193 L .29323 .5492 L F
.848 .719 .72 r
.80189 .42285 m .80555 .42111 L .80399 .41955 L F
.81 .754 .8 r
.80399 .41955 m .80555 .42111 L .80794 .41804 L F
.737 .521 .6 r
.19066 .59884 m .19138 .60301 L .18711 .6004 L F
.315 .233 .602 r
.19066 .59884 m .19138 .60301 L .19254 .60082 L F
.555 .044 0 r
.19121 .59962 m .19066 .59884 L .18857 .59775 L F
.19121 .59962 m .19254 .60082 L .19066 .59884 L F
.567 .895 .985 r
.2785 .66378 m .27551 .66413 L .27703 .66272 L F
0 0 0 r
.2744 .66605 m .2785 .66378 L .2764 .66534 L F
.986 .823 .597 r
.2764 .66534 m .2785 .66378 L .27703 .66272 L F
.692 .837 .953 r
.32805 .58393 m .33135 .58381 L .32975 .58271 L F
0 0 0 r
.17872 .55954 m .17883 .56012 L .18089 .55872 L F
.17872 .55954 m .17705 .56101 L .17883 .56012 L F
.89 .721 .667 r
.82857 .40364 m .83035 .40745 L .82955 .40543 L F
.352 0 0 r
.51828 .52456 m .52186 .52362 L .51929 .52321 L F
.242 .758 .82 r
.25014 .53429 m .24964 .53454 L .24826 .53414 L F
.21 0 0 r
.24637 .53459 m .24876 .53468 L .25014 .53429 L F
.253 .756 .708 r
.25014 .53429 m .24876 .53468 L .25054 .53409 L F
.25014 .53429 m .25054 .53409 L .25099 .53394 L F
.242 .758 .82 r
.25014 .53429 m .2501 .53468 L .24964 .53454 L F
.25014 .53429 m .25238 .53422 L .2501 .53468 L F
.285 .748 .948 r
.22922 .62318 m .23111 .62381 L .22705 .62337 L F
.329 .75 .976 r
.23149 .62283 m .23111 .62381 L .22922 .62318 L F
.23149 .62283 m .23334 .62365 L .23111 .62381 L F
.787 .573 .611 r
.28922 .55781 m .29301 .55863 L .2932 .55582 L F
.28922 .55781 m .2932 .55582 L .29134 .55709 L F
0 0 0 r
.29362 .55601 m .2932 .55582 L .29561 .55566 L F
.29362 .55601 m .29134 .55709 L .2932 .55582 L F
.704 .783 .913 r
.24141 .64203 m .24682 .64121 L .24193 .63876 L F
.196 .623 .947 r
.24193 .63876 m .24682 .64121 L .246 .64027 L F
.258 .045 .387 r
.24682 .64121 m .24747 .64098 L .246 .64027 L F
0 0 0 r
.27249 .60822 m .27035 .61157 L .27129 .61028 L F
.589 .828 .449 r
.27129 .61028 m .27035 .61157 L .26911 .61319 L F
.786 .354 .222 r
.5124 .547 m .5105 .54831 L .51038 .54683 L F
.96 .944 .657 r
.5117 .54617 m .5105 .54831 L .5124 .547 L F
.573 .329 .508 r
.28431 .6483 m .28659 .64974 L .28385 .64984 L F
.28431 .6483 m .28695 .64856 L .28659 .64974 L F
.587 .275 .407 r
.32805 .63484 m .32573 .63306 L .32933 .6322 L F
.32805 .63484 m .32546 .63526 L .32573 .63306 L F
.476 .601 .897 r
.78196 .4188 m .78258 .42078 L .78432 .41863 L F
.44 .547 .869 r
.78258 .42078 m .78523 .42092 L .78432 .41863 L F
.412 .299 .615 r
.29778 .55489 m .29946 .55481 L .29939 .55216 L F
0 0 .256 r
.29921 .55101 m .29895 .55196 L .29925 .55106 L F
.29845 .55032 m .29884 .5516 L .29921 .55101 L F
.29884 .5516 m .29895 .55196 L .29921 .55101 L F
.226 0 0 r
.29845 .55032 m .29921 .55101 L .30102 .54985 L F
.544 .434 .679 r
.29845 .55032 m .30102 .54985 L .29978 .54797 L F
.411 .384 .718 r
.29978 .54797 m .30102 .54985 L .30213 .54827 L F
.794 .998 .798 r
.30102 .54985 m .29921 .55101 L .30213 .54827 L F
.226 0 0 r
.29845 .55032 m .29875 .55131 L .29921 .55101 L F
.794 .998 .798 r
.29921 .55101 m .29875 .55131 L .29937 .55075 L F
.171 0 .084 r
.29935 .55076 m .29937 .55076 L .30213 .54827 L F
.794 .998 .798 r
.29926 .55097 m .29936 .55077 L .30213 .54827 L F
0 0 .439 r
.29936 .55077 m .29946 .55481 L .30072 .55263 L F
.29935 .55076 m .29935 .55079 L .29936 .55077 L F
.29935 .55079 m .29946 .55481 L .29936 .55077 L F
.794 .998 .798 r
.29921 .55101 m .29935 .55078 L .29936 .55077 L F
.29921 .55101 m .29936 .55077 L .29926 .55097 L F
0 0 .439 r
.29935 .55076 m .29936 .55077 L .29937 .55076 L F
.794 .998 .798 r
.29935 .55078 m .29936 .55077 L .29937 .55076 L F
.29935 .55078 m .29937 .55076 L .30213 .54827 L F
0 0 .439 r
.29937 .55076 m .30072 .55263 L .30139 .55042 L F
.29936 .55077 m .30072 .55263 L .29937 .55076 L F
.171 0 .084 r
.29937 .55076 m .30139 .55042 L .30213 .54827 L F
.794 .998 .798 r
.29936 .55077 m .29937 .55075 L .30213 .54827 L F
.171 0 .084 r
.29935 .55076 m .30213 .54827 L .29937 .55075 L F
0 0 .256 r
.29908 .5509 m .29925 .55106 L .29935 .55076 L F
.171 0 .084 r
.29935 .55076 m .29937 .55075 L .29875 .55131 L F
0 0 .256 r
.29845 .55032 m .29908 .5509 L .29935 .55076 L F
.412 .299 .615 r
.29895 .55196 m .29939 .55216 L .29935 .55076 L F
0 0 .256 r
.29895 .55196 m .29915 .55261 L .29935 .55076 L F
.412 .299 .615 r
.2989 .55194 m .29895 .55196 L .29935 .55076 L F
.29778 .55489 m .29939 .55216 L .2989 .55194 L F
.527 .08 .131 r
.29832 .55037 m .2989 .55194 L .29845 .55032 L F
.2989 .55194 m .29915 .55261 L .29895 .55196 L F
.2989 .55194 m .29895 .55196 L .29845 .55032 L F
.412 .299 .615 r
.29778 .55489 m .2989 .55194 L .29915 .55261 L F
.2989 .55194 m .29935 .55076 L .29915 .55261 L F
.527 .08 .131 r
.29397 .55193 m .29915 .55261 L .29832 .55037 L F
.744 .687 .796 r
.29663 .54637 m .29845 .55032 L .29978 .54797 L F
0 0 .256 r
.29845 .55032 m .29935 .55076 L .29875 .55131 L F
.422 .47 .804 r
.30839 .60415 m .30783 .60821 L .30618 .60487 L F
.30839 .60415 m .30971 .60806 L .30783 .60821 L F
.473 .772 .996 r
.309 .5342 m .30819 .53574 L .30631 .53505 L F
.309 .5342 m .31008 .53537 L .30819 .53574 L F
.917 .833 .748 r
.54585 .57081 m .54929 .56844 L .54765 .56727 L F
.54585 .57081 m .54764 .57178 L .54929 .56844 L F
.459 .617 .918 r
.18309 .61308 m .18426 .61481 L .18605 .6144 L F
.838 .774 .791 r
.27316 .65812 m .27657 .6573 L .27514 .65694 L F
.472 .877 .953 r
.27514 .65694 m .27657 .6573 L .27746 .65623 L F
.415 .529 .864 r
.17348 .60802 m .17306 .60418 L .17171 .60417 L F
.17348 .60802 m .17504 .60748 L .17306 .60418 L F
0 0 .32 r
.23032 .73939 m .22979 .73804 L .23021 .73955 L F
.308 0 0 r
.23145 .73888 m .22979 .73804 L .23032 .73939 L F
.255 .747 .914 r
.23068 .73887 m .23032 .73939 L .22674 .73882 L F
.23145 .73888 m .23032 .73939 L .23068 .73887 L F
0 0 .32 r
.23032 .73939 m .23021 .73955 L .23052 .74068 L F
.046 .231 .73 r
.20218 .60438 m .20268 .60796 L .20011 .6048 L F
.20218 .60438 m .20354 .60791 L .20268 .60796 L F
.459 .377 .676 r
.35727 .55877 m .35724 .56074 L .35555 .56108 L F
.098 0 0 r
.2817 .65613 m .28267 .65479 L .28428 .65437 L F
.383 .457 .812 r
.19189 .62069 m .19362 .62057 L .19378 .61916 L F
.38 .487 .843 r
.19189 .62069 m .19393 .62176 L .19362 .62057 L F
.765 .959 .652 r
.16787 .59975 m .16638 .60166 L .16642 .60211 L F
.537 .608 .871 r
.16526 .6019 m .16647 .60274 L .16642 .60211 L F
.738 .307 .227 r
.16642 .60211 m .16356 .60056 L .16526 .6019 L F
.724 .844 .938 r
.16356 .60056 m .16123 .60181 L .16526 .6019 L F
.738 .307 .227 r
.16642 .60211 m .16533 .60301 L .16356 .60056 L F
.765 .959 .652 r
.16638 .60166 m .16533 .60301 L .16642 .60211 L F
.537 .608 .871 r
.16647 .60274 m .16922 .60468 L .16642 .60211 L F
.51 .712 .963 r
.16922 .60468 m .16791 .60153 L .16642 .60211 L F
.16922 .60468 m .17171 .60417 L .16791 .60153 L F
.592 .281 .41 r
.30313 .64484 m .30174 .64767 L .29919 .64769 L F
.586 .274 .407 r
.30537 .64696 m .30313 .64484 L .30556 .64476 L F
.30537 .64696 m .30174 .64767 L .30313 .64484 L F
.186 0 0 r
.53223 .52245 m .53462 .52209 L .53619 .52122 L F
.304 0 0 r
.53462 .52209 m .53844 .52142 L .53619 .52122 L F
.323 0 0 r
.29045 .54373 m .28869 .5453 L .28628 .54548 L F
.625 .543 .743 r
.29045 .54373 m .29219 .54539 L .29316 .54501 L F
.29219 .54539 m .29475 .54783 L .29316 .54501 L F
0 0 0 r
.29531 .54436 m .2945 .54447 L .29316 .54501 L F
.195 .725 .82 r
.29316 .54501 m .28869 .5453 L .29045 .54373 L F
0 0 0 r
.2945 .54447 m .29105 .54498 L .29316 .54501 L F
.254 .709 .954 r
.28604 .53201 m .28991 .53277 L .28804 .53258 L F
.963 .738 .551 r
.19254 .60082 m .19221 .60369 L .19428 .60098 L F
0 0 .141 r
.19428 .60098 m .19466 .60347 L .19656 .60125 L F
.097 0 0 r
.19428 .60098 m .19254 .60082 L .19656 .60125 L F
0 0 .141 r
.19428 .60098 m .19254 .60082 L .19221 .60369 L F
.19428 .60098 m .19656 .60125 L .19254 .60082 L F
.19428 .60098 m .19413 .60504 L .19466 .60347 L F
.272 .43 .837 r
.19789 .62323 m .1997 .62667 L .20076 .62505 L F
.266 .421 .831 r
.1997 .62667 m .20128 .62667 L .20076 .62505 L F
.616 .543 .749 r
.27988 .62903 m .28132 .62524 L .27964 .62683 L F
.716 .195 0 r
.26803 .63155 m .26954 .63237 L .26749 .62994 L F
.26803 .63155 m .26749 .62994 L .26838 .62838 L F
.869 .858 .828 r
.25856 .69119 m .26098 .68846 L .2593 .68695 L F
.89 .473 .072 r
.2593 .68695 m .26098 .68846 L .26076 .69092 L F
.162 0 .008 r
.26098 .68846 m .26406 .68653 L .26076 .69092 L F
.073 0 .138 r
.27286 .62165 m .27227 .62036 L .2741 .62021 L F
.27286 .62165 m .27124 .62284 L .27227 .62036 L F
.841 .822 .831 r
.34087 .56171 m .33864 .56417 L .34383 .56409 L F
.825 .686 .71 r
.33764 .56642 m .34383 .56409 L .33864 .56417 L F
.33764 .56642 m .33982 .5678 L .34383 .56409 L F
0 0 .257 r
.34383 .56409 m .34307 .56036 L .34087 .56171 L F
.365 0 0 r
.34603 .56509 m .34405 .56434 L .34383 .56409 L F
0 0 .257 r
.34383 .56409 m .34405 .56434 L .34307 .56036 L F
.119 .62 .904 r
.29405 .53271 m .29627 .53299 L .29811 .53383 L F
.025 .545 .864 r
.29834 .53331 m .29811 .53383 L .29627 .53299 L F
.29834 .53331 m .29999 .53417 L .29811 .53383 L F
.539 .643 .901 r
.22757 .74239 m .22516 .74353 L .22338 .74081 L F
.321 .787 .671 r
.22353 .74423 m .22516 .74353 L .22757 .74239 L F
.86 .407 .076 r
.78935 .41251 m .79003 .41147 L .78749 .40959 L F
.71 .188 0 r
.78935 .41251 m .79285 .4137 L .79003 .41147 L F
.639 .525 .708 r
.33328 .62593 m .33093 .62907 L .33091 .62651 L F
.778 .679 .755 r
.26934 .55034 m .26556 .54969 L .26759 .54855 L F
.26934 .55034 m .26655 .55274 L .26556 .54969 L F
.278 .507 .897 r
.26964 .54797 m .26934 .55034 L .26759 .54855 L F
.26964 .54797 m .27131 .55037 L .26934 .55034 L F
.719 .63 .758 r
.54435 .5769 m .54808 .57764 L .54662 .57406 L F
.728 .804 .912 r
.27195 .64857 m .27274 .64577 L .27046 .64468 L F
.27195 .64857 m .27423 .64736 L .27274 .64577 L F
.81 .754 .8 r
.80399 .41955 m .80794 .41804 L .80656 .41638 L F
.732 .715 .835 r
.80656 .41638 m .80794 .41804 L .81043 .41692 L F
.573 .022 0 r
.15634 .74008 m .15762 .74026 L .15707 .73994 L F
.704 .783 .913 r
.24141 .64203 m .24193 .63876 L .23958 .63875 L F
.889 .895 .827 r
.50095 .56077 m .50474 .55864 L .5038 .56037 L F
0 .207 .687 r
.78601 .4026 m .78494 .40222 L .78411 .40159 L F
0 .362 .829 r
.78514 .40117 m .78601 .4026 L .78411 .40159 L F
.944 .73 .583 r
.785 .4015 m .78601 .4026 L .78514 .40117 L F
0 .207 .687 r
.78601 .4026 m .78701 .40368 L .78494 .40222 L F
.944 .73 .583 r
.78363 .40475 m .78601 .4026 L .785 .4015 L F
0 .207 .687 r
.78601 .4026 m .78731 .4039 L .78701 .40368 L F
.991 .877 .609 r
.55315 .5388 m .55494 .53745 L .55347 .53639 L F
.55315 .5388 m .55416 .54011 L .55494 .53745 L F
0 0 0 r
.27362 .60694 m .27249 .60822 L .27129 .61028 L F
.338 .357 .734 r
.32145 .57273 m .31909 .57106 L .32059 .57013 L F
.908 .978 .787 r
.82064 .4179 m .82307 .41455 L .82248 .4136 L F
.852 .981 .862 r
.82248 .4136 m .82307 .41455 L .8258 .41162 L F
.281 0 0 r
.26297 .55014 m .26091 .55128 L .25847 .55133 L F
.418 0 0 r
.26491 .55104 m .26297 .55014 L .26556 .54969 L F
.26491 .55104 m .26091 .55128 L .26297 .55014 L F
.626 .412 .572 r
.29949 .57468 m .29662 .57695 L .29874 .57326 L F
0 0 0 r
.30192 .57134 m .29874 .57326 L .29924 .57217 L F
.30192 .57134 m .30049 .57229 L .29874 .57326 L F
0 0 .224 r
.30049 .57229 m .29949 .57468 L .29874 .57326 L F
.514 .32 .555 r
.28471 .61981 m .28714 .61893 L .28802 .616 L F
.565 .325 .511 r
.28375 .62283 m .28714 .61893 L .28471 .61981 L F
.258 .572 .94 r
.23795 .63847 m .23832 .63731 L .23581 .63767 L F
.23795 .63847 m .23958 .63875 L .23832 .63731 L F
.419 0 .038 r
.29325 .561 m .29722 .55956 L .29301 .55863 L F
.29325 .561 m .29468 .56105 L .29722 .55956 L F
.267 0 0 r
.29722 .55956 m .29804 .56034 L .29935 .55857 L F
.29722 .55956 m .29468 .56105 L .29804 .56034 L F
0 0 0 r
.25238 .53422 m .25465 .53386 L .25637 .53334 L F
.32 .044 .329 r
.33216 .56162 m .32938 .56468 L .32955 .56207 L F
.593 .324 .479 r
.79644 .41421 m .79945 .41575 L .80048 .41503 L F
.484 0 0 r
.79945 .41575 m .80285 .41596 L .80048 .41503 L F
.509 .17 .328 r
.80048 .41503 m .80285 .41596 L .80363 .41413 L F
.574 .376 .574 r
.31339 .6054 m .31626 .60495 L .3162 .60211 L F
.598 .433 .628 r
.3162 .60211 m .3187 .60182 L .31889 .59904 L F
.655 .44 .579 r
.3162 .60211 m .31882 .60452 L .3187 .60182 L F
.3162 .60211 m .31626 .60495 L .31882 .60452 L F
.587 .101 .067 r
.22 .55825 m .21875 .55903 L .21626 .55831 L F
.011 0 0 r
.22213 .55767 m .21875 .55903 L .22 .55825 L F
.994 .748 .418 r
.81934 .40095 m .82046 .40474 L .82045 .40215 L F
.731 .983 .905 r
.22752 .63777 m .22795 .63515 L .22527 .63549 L F
.22752 .63777 m .22813 .63672 L .22795 .63515 L F
.136 0 0 r
.21424 .53931 m .2166 .53904 L .21858 .53809 L F
0 0 0 r
.2166 .53904 m .2209 .53786 L .21858 .53809 L F
.456 .215 .459 r
.34152 .60192 m .34135 .60483 L .3387 .60513 L F
.488 .319 .578 r
.34387 .59857 m .3438 .60147 L .34152 .60192 L F
.591 .325 .482 r
.34387 .60413 m .34152 .60192 L .3438 .60147 L F
.34387 .60413 m .34135 .60483 L .34152 .60192 L F
.308 .294 .681 r
.29661 .58633 m .29703 .58962 L .29908 .58826 L F
.418 .292 .601 r
.29661 .59232 m .29908 .58826 L .29703 .58962 L F
.053 0 .409 r
.29952 .55574 m .29946 .55481 L .29778 .55489 L F
.29952 .55574 m .30068 .55695 L .29946 .55481 L F
.29952 .55574 m .29935 .55857 L .30068 .55695 L F
.474 .715 .975 r
.32427 .5379 m .32055 .53668 L .32287 .53619 L F
.354 .672 .976 r
.32491 .53654 m .32427 .5379 L .32287 .53619 L F
.32491 .53654 m .32627 .5379 L .32427 .5379 L F
0 0 0 r
.27993 .60743 m .27904 .60825 L .28131 .60509 L F
0 0 .151 r
.27834 .61059 m .27904 .60825 L .27993 .60743 L F
.458 .278 .548 r
.26056 .69337 m .25841 .69395 L .25856 .69119 L F
.73 .238 .069 r
.26056 .69337 m .25856 .69119 L .25784 .69255 L F
.068 0 .026 r
.17023 .56547 m .17107 .56617 L .17229 .56475 L F
.17023 .56547 m .16919 .56722 L .17107 .56617 L F
.966 .77 .589 r
.78842 .40779 m .78877 .40517 L .78731 .4039 L F
.075 .633 .797 r
.2377 .62382 m .23739 .62409 L .23556 .62368 L F
.2377 .62382 m .23973 .62408 L .23739 .62409 L F
.923 .726 .618 r
.24658 .70952 m .24743 .71262 L .24557 .71226 L F
0 0 .061 r
.24679 .71077 m .24557 .71226 L .24685 .71092 L F
.24679 .71077 m .24685 .71092 L .24727 .71048 L F
.435 .74 .991 r
.24685 .71092 m .24743 .71262 L .24718 .71172 L F
.24689 .71105 m .24743 .71262 L .24685 .71092 L F
.24689 .71105 m .2507 .71308 L .24743 .71262 L F
.46 .45 .76 r
.24685 .71092 m .24691 .711 L .24727 .71048 L F
.435 .74 .991 r
.24679 .71077 m .24718 .71172 L .24658 .70952 L F
.46 .45 .76 r
.24691 .711 m .24694 .71104 L .24697 .71099 L F
.24691 .711 m .24697 .71099 L .24727 .71048 L F
.614 .799 .971 r
.25224 .7119 m .24746 .71091 L .25015 .71024 L F
.24746 .71091 m .24749 .71085 L .25015 .71024 L F
.24746 .71091 m .24734 .71088 L .24749 .71085 L F
.46 .45 .76 r
.24694 .71104 m .24747 .71094 L .24727 .71048 L F
.228 .315 .746 r
.24727 .71048 m .24744 .71086 L .24753 .71079 L F
.614 .799 .971 r
.24734 .71088 m .24679 .71077 L .24776 .71062 L F
.24744 .71086 m .24776 .71062 L .24899 .71042 L F
.24734 .71088 m .24776 .71062 L .24744 .71086 L F
.435 .74 .991 r
.24718 .711 m .2507 .71308 L .24689 .71105 L F
.682 .395 .48 r
.24743 .71262 m .2507 .71308 L .24957 .71525 L F
.614 .799 .971 r
.25224 .7119 m .2507 .71308 L .24718 .711 L F
.24734 .71088 m .24718 .711 L .24679 .71077 L F
.25224 .7119 m .24718 .711 L .24734 .71088 L F
.46 .45 .76 r
.24718 .711 m .24864 .71354 L .24747 .71094 L F
.24694 .71104 m .247 .71113 L .24718 .711 L F
.247 .71113 m .24864 .71354 L .24718 .711 L F
.228 .315 .746 r
.24753 .71079 m .24864 .71354 L .25004 .71382 L F
.24744 .71086 m .24864 .71354 L .24753 .71079 L F
.614 .799 .971 r
.24734 .71088 m .24899 .71042 L .25015 .71024 L F
0 0 0 r
.24762 .71064 m .24854 .71026 L .25015 .71024 L F
.228 .315 .746 r
.24727 .71048 m .24753 .71079 L .24776 .7104 L F
0 0 0 r
.24679 .71077 m .24854 .71026 L .24762 .71064 L F
.228 .315 .746 r
.24776 .7104 m .24786 .71054 L .24854 .71026 L F
.24786 .71054 m .25004 .71382 L .24854 .71026 L F
.24753 .71079 m .25004 .71382 L .24776 .7104 L F
.435 .74 .991 r
.24679 .71077 m .24689 .71105 L .24685 .71092 L F
.24679 .71077 m .24718 .711 L .24689 .71105 L F
0 .032 .593 r
.24743 .71262 m .24957 .71525 L .24864 .71354 L F
.24743 .71262 m .24864 .71354 L .24557 .71226 L F
.46 .45 .76 r
.24557 .71226 m .24744 .71304 L .24685 .71092 L F
.24744 .71304 m .24864 .71354 L .24685 .71092 L F
.623 .473 .658 r
.28666 .55633 m .28828 .55824 L .28882 .55256 L F
.477 .441 .738 r
.28922 .55781 m .28828 .55824 L .28869 .5575 L F
.192 .102 .517 r
.28857 .55771 m .28828 .55824 L .28857 .55778 L F
.28882 .55256 m .28828 .55824 L .28857 .55771 L F
.28882 .55256 m .28857 .55778 L .28859 .55773 L F
.28882 .55256 m .28859 .55774 L .2904 .55371 L F
.477 .441 .738 r
.28869 .5575 m .28828 .55824 L .28666 .55633 L F
.49 .472 .765 r
.28857 .55778 m .28828 .55824 L .28922 .55781 L F
.477 .441 .738 r
.28922 .55781 m .28869 .5575 L .28846 .55803 L F
.49 .472 .765 r
.29089 .55407 m .28857 .55778 L .28922 .55781 L F
.477 .441 .738 r
.28846 .55803 m .28817 .55776 L .28715 .55841 L F
.28817 .55776 m .28666 .55633 L .28698 .5577 L F
.28817 .55776 m .28698 .5577 L .28715 .55841 L F
.28869 .5575 m .28666 .55633 L .28846 .55803 L F
.192 .102 .517 r
.28859 .55773 m .28857 .55778 L .28859 .55774 L F
.2904 .55371 m .28859 .55774 L .29089 .55407 L F
.601 .552 .772 r
.28782 .56205 m .28922 .55781 L .28846 .55803 L F
.28748 .56021 m .28846 .55803 L .28715 .55841 L F
.28782 .56205 m .28846 .55803 L .28748 .56021 L F
.28782 .56205 m .29047 .56162 L .28922 .55781 L F
.56 .359 .566 r
.28782 .56205 m .28771 .56461 L .29047 .56162 L F
.693 .719 .869 r
.18165 .58897 m .17771 .58774 L .17962 .58661 L F
.585 .726 .941 r
.18414 .58841 m .18165 .58897 L .17962 .58661 L F
.628 .655 .857 r
.18518 .59006 m .18165 .58897 L .18414 .58841 L F
.515 .258 .464 r
.32073 .63892 m .32285 .64098 L .32039 .6412 L F
.568 .412 .63 r
.32306 .63574 m .3232 .63857 L .32073 .63892 L F
.522 .258 .456 r
.3232 .63857 m .32285 .64098 L .32073 .63892 L F
.597 .674 .894 r
.18673 .58955 m .18518 .59006 L .18414 .58841 L F
.36 .291 .643 r
.18673 .58955 m .18595 .5925 L .18518 .59006 L F
.18673 .58955 m .18763 .59183 L .18595 .5925 L F
.197 0 0 r
.33387 .53882 m .33521 .53894 L .33705 .53801 L F
.429 0 0 r
.33705 .53801 m .33521 .53894 L .33921 .53893 L F
.413 0 0 r
.33521 .53894 m .33659 .53938 L .33921 .53893 L F
.25 .414 .83 r
.33616 .53699 m .33653 .53906 L .33521 .53894 L F
.33653 .53906 m .33659 .53938 L .33521 .53894 L F
.197 0 0 r
.33278 .53909 m .33521 .53894 L .33387 .53882 L F
.521 .649 .914 r
.23893 .73718 m .23657 .73761 L .23482 .73502 L F
.268 0 .013 r
.23471 .73994 m .23657 .73761 L .23893 .73718 L F
.642 .162 0 r
.27185 .66273 m .27263 .66341 L .27039 .66074 L F
.84 .372 .051 r
.27238 .66527 m .27263 .66341 L .27185 .66273 L F
.27238 .66527 m .2744 .66605 L .27263 .66341 L F
.679 .414 .514 r
.27263 .66341 m .27551 .66413 L .2744 .66605 L F
.908 .978 .787 r
.82064 .4179 m .82248 .4136 L .81935 .41628 L F
.742 .267 0 r
.32694 .58752 m .32892 .58958 L .32618 .58619 L F
.82 .731 .767 r
.32475 .58915 m .32892 .58958 L .32694 .58752 L F
.32475 .58915 m .32639 .59264 L .32892 .58958 L F
.597 .397 .582 r
.32639 .59264 m .32888 .5923 L .32892 .58958 L F
.652 .443 .587 r
.32892 .58958 m .33189 .5913 L .33216 .58945 L F
.32892 .58958 m .32888 .5923 L .33189 .5913 L F
.609 .602 .819 r
.79663 .4266 m .79811 .42228 L .79547 .42316 L F
.79663 .4266 m .7992 .42584 L .79811 .42228 L F
.387 .289 .622 r
.28783 .57741 m .29084 .57662 L .2896 .57322 L F
.274 .13 .496 r
.28783 .57741 m .29038 .57803 L .29084 .57662 L F
.28783 .57741 m .28763 .58013 L .29038 .57803 L F
.467 .254 .505 r
.18647 .57584 m .1849 .57426 L .18705 .57379 L F
.18647 .57584 m .18457 .5773 L .1849 .57426 L F
.449 0 0 r
.33745 .54828 m .33639 .54736 L .338 .54551 L F
.641 .224 .238 r
.53844 .52142 m .5408 .52338 L .54223 .52131 L F
.757 .415 .404 r
.5408 .52338 m .54459 .52197 L .54223 .52131 L F
.433 .486 .815 r
.31382 .58507 m .31548 .58925 L .31379 .58988 L F
.755 .667 .765 r
.28714 .61893 m .29093 .6199 L .29003 .61725 L F
.757 .361 .303 r
.28714 .61893 m .29023 .62082 L .29093 .6199 L F
.585 .512 .739 r
.29093 .6199 m .29292 .61677 L .29003 .61725 L F
.29093 .6199 m .29346 .61998 L .29292 .61677 L F
.545 .141 .227 r
.29023 .62082 m .29346 .61998 L .29093 .6199 L F
.762 .726 .819 r
.25157 .69588 m .2533 .69734 L .25052 .69721 L F
.382 .628 .95 r
.25459 .69635 m .2533 .69734 L .25157 .69588 L F
.452 .055 .196 r
.26076 .69092 m .26406 .68653 L .26567 .68758 L F
.732 .715 .835 r
.80656 .41638 m .81043 .41692 L .8092 .41386 L F
.644 .719 .903 r
.81043 .41692 m .81198 .41311 L .8092 .41386 L F
.81043 .41692 m .81317 .41619 L .81198 .41311 L F
0 0 .445 r
.20634 .61196 m .20549 .61145 L .20426 .60961 L F
.20634 .61196 m .20633 .6134 L .20549 .61145 L F
0 0 0 r
.20367 .54363 m .20063 .54619 L .20259 .54483 L F
.20367 .54363 m .20369 .54443 L .20627 .54295 L F
.20367 .54363 m .20259 .54483 L .20369 .54443 L F
.971 .903 .547 r
.53996 .55867 m .54033 .55427 L .5414 .55541 L F
0 0 0 r
.52186 .52362 m .52445 .52315 L .52546 .52265 L F
.446 0 0 r
.52445 .52315 m .52821 .52384 L .52546 .52265 L F
.429 .868 .901 r
.22476 .53693 m .22533 .53616 L .22709 .53685 L F
.22476 .53693 m .22294 .53691 L .22533 .53616 L F
.192 .102 .517 r
.28882 .55256 m .29089 .55407 L .29152 .55078 L F
.285 0 .172 r
.31934 .5769 m .31834 .57948 L .31624 .58019 L F
.435 .202 .461 r
.32231 .57468 m .31834 .57948 L .31934 .5769 L F
0 0 0 r
.19227 .54974 m .1925 .55077 L .19444 .54907 L F
.19227 .54974 m .19067 .55189 L .1925 .55077 L F
.342 .175 .505 r
.29661 .58633 m .29844 .58574 L .29853 .58321 L F
.308 .294 .681 r
.29661 .58633 m .29908 .58826 L .29844 .58574 L F
.536 0 0 r
.27069 .55681 m .26861 .55621 L .26705 .55496 L F
.185 0 0 r
.27304 .55611 m .26982 .55618 L .27069 .55681 L F
.26982 .55618 m .26861 .55621 L .26912 .55636 L F
.27304 .55611 m .27079 .5564 L .26861 .55621 L F
.197 0 0 r
.27478 .55448 m .27079 .5564 L .27304 .55611 L F
.27278 .55544 m .27307 .556 L .27079 .5564 L F
.27478 .55448 m .27406 .55512 L .27278 .55544 L F
.27406 .55512 m .27307 .556 L .27278 .55544 L F
.185 0 0 r
.26982 .55618 m .26912 .55636 L .27069 .55681 L F
.928 .82 .719 r
.54585 .57081 m .54662 .57406 L .54764 .57178 L F
.229 .728 .909 r
.27868 .53317 m .27512 .53303 L .27749 .53271 L F
.395 .775 .991 r
.27978 .53237 m .27868 .53317 L .27749 .53271 L F
.27978 .53237 m .28116 .53306 L .27868 .53317 L F
.576 .37 .564 r
.33785 .61424 m .33773 .61697 L .33516 .61716 L F
.611 .468 .662 r
.33997 .61134 m .3404 .61393 L .33785 .61424 L F
.587 .378 .566 r
.34028 .61653 m .33785 .61424 L .3404 .61393 L F
.34028 .61653 m .33773 .61697 L .33785 .61424 L F
.441 .306 .601 r
.33524 .62002 m .333 .6233 L .3326 .62066 L F
.588 .424 .627 r
.31889 .59904 m .32121 .60132 L .32142 .59879 L F
.31889 .59904 m .3187 .60182 L .32121 .60132 L F
.264 0 .071 r
.30971 .60806 m .31184 .60742 L .31339 .6054 L F
.785 .623 .68 r
.31184 .60742 m .31626 .60495 L .31339 .6054 L F
.683 .591 .746 r
.29369 .60481 m .29534 .60914 L .29701 .60732 L F
.204 0 .005 r
.29534 .60914 m .29709 .60895 L .29701 .60732 L F
.29534 .60914 m .2941 .61059 L .29709 .60895 L F
.683 .591 .746 r
.29369 .60481 m .29534 .60914 L .29701 .60732 L F
.197 .727 .814 r
.26704 .68156 m .26597 .68195 L .2638 .68136 L F
.489 .255 .486 r
.26597 .68195 m .26836 .68159 L .26561 .68445 L F
.197 .727 .814 r
.26704 .68156 m .26692 .68181 L .26597 .68195 L F
.495 .09 .201 r
.2651 .68323 m .26704 .68156 L .2638 .68136 L F
.527 .857 .577 r
.2671 .68143 m .26704 .68156 L .2651 .68323 L F
.26861 .68008 m .26704 .68156 L .2671 .68143 L F
.197 .727 .814 r
.26704 .68156 m .26836 .68159 L .26692 .68181 L F
0 0 .537 r
.47183 .63892 m .47207 .63864 L .47076 .63562 L F
0 0 .487 r
.47076 .63562 m .4739 .63802 L .47315 .63566 L F
.493 .301 .548 r
.32142 .59879 m .32379 .59829 L .32388 .59569 L F
.448 .216 .469 r
.32121 .60132 m .32379 .59829 L .32142 .59879 L F
.989 .734 .441 r
.26556 .54969 m .26655 .55274 L .26491 .55104 L F
0 0 .436 r
.26705 .55496 m .26491 .55104 L .26655 .55274 L F
.3 .005 .287 r
.46239 .65771 m .46197 .65964 L .46481 .65706 L F
.46239 .65771 m .46197 .65964 L .46481 .65706 L F
.628 .066 0 r
.24352 .62397 m .24569 .62566 L .24757 .62598 L F
.204 0 0 r
.2477 .62604 m .24757 .62598 L .24569 .62566 L F
.2477 .62604 m .24953 .62653 L .24757 .62598 L F
.3 0 .085 r
.19138 .60301 m .18821 .60417 L .18711 .6004 L F
.19138 .60301 m .19062 .60352 L .18821 .60417 L F
.532 .243 .422 r
.31443 .6418 m .31149 .64437 L .31184 .64174 L F
.129 .634 .902 r
.21701 .61858 m .21323 .61779 L .21508 .61773 L F
.042 .584 .845 r
.21757 .6183 m .21701 .61858 L .21508 .61773 L F
.21757 .6183 m .21944 .61895 L .21701 .61858 L F
.65 .404 .533 r
.4739 .63802 m .47721 .63586 L .47315 .63566 L F
.4739 .63802 m .47685 .63831 L .47721 .63586 L F
.47721 .63586 m .47685 .63831 L .4739 .63802 L F
.754 .684 .784 r
.54293 .57342 m .54435 .5769 L .54662 .57406 L F
.693 .844 .42 r
.27993 .60743 m .28131 .60509 L .28228 .60329 L F
.626 .496 .685 r
.28802 .616 m .29003 .61725 L .28919 .6143 L F
.667 .474 .615 r
.28802 .616 m .28714 .61893 L .29003 .61725 L F
0 0 0 r
.16433 .57079 m .16605 .56984 L .16746 .56817 L F
.084 0 0 r
.16605 .56984 m .16919 .56722 L .16746 .56817 L F
.354 .025 .262 r
.29853 .58321 m .30073 .58266 L .30126 .58086 L F
.473 .112 .273 r
.30073 .58266 m .30456 .58008 L .30126 .58086 L F
.46 .277 .544 r
.25639 .67228 m .25447 .67305 L .25647 .67485 L F
.25647 .67485 m .25447 .67305 L .25639 .67228 L F
.881 .517 .351 r
.54547 .52599 m .54824 .52554 L .54487 .52395 L F
.54547 .52599 m .54836 .52743 L .54824 .52554 L F
.485 .893 .774 r
.36092 .54583 m .36196 .54484 L .36355 .5432 L F
.36092 .54583 m .35996 .54604 L .36196 .54484 L F
.682 .657 .819 r
.34199 .60657 m .34256 .60762 L .34387 .60413 L F
.722 .524 .622 r
.34199 .60657 m .3387 .60513 L .34107 .60486 L F
.34256 .60762 m .33957 .60569 L .34199 .60657 L F
.33957 .60569 m .3387 .60513 L .34199 .60657 L F
.7 .678 .825 r
.34309 .60622 m .34256 .60762 L .34216 .60669 L F
.682 .657 .819 r
.34185 .60676 m .34256 .60762 L .34199 .60657 L F
.722 .524 .622 r
.34216 .60669 m .34107 .60486 L .34135 .60483 L F
.34256 .60762 m .34205 .60667 L .34216 .60669 L F
.34205 .60667 m .34107 .60486 L .34216 .60669 L F
.503 .374 .637 r
.34438 .60984 m .3419 .60682 L .34261 .60676 L F
.34326 .60687 m .34261 .60676 L .3432 .60671 L F
.34438 .60984 m .34261 .60676 L .34326 .60687 L F
.3419 .60682 m .34185 .60676 L .34203 .60675 L F
.3419 .60682 m .34203 .60675 L .3432 .60671 L F
.7 .678 .825 r
.34387 .60413 m .34309 .60622 L .34213 .60662 L F
.34309 .60622 m .34216 .60669 L .34213 .60662 L F
.682 .657 .819 r
.34199 .60657 m .34387 .60413 L .34213 .60662 L F
.7 .678 .825 r
.34387 .60413 m .34213 .60662 L .34135 .60483 L F
.682 .657 .819 r
.34213 .60662 m .34387 .60413 L .34246 .60674 L F
.34246 .60674 m .34387 .60413 L .3432 .60671 L F
.34185 .60676 m .34199 .60657 L .34246 .60674 L F
.722 .524 .622 r
.34256 .60762 m .33901 .60779 L .3387 .60513 L F
.967 .728 .524 r
.27681 .589 m .27847 .59268 L .27663 .59173 L F
.182 .19 .632 r
.27927 .58825 m .27847 .59268 L .27681 .589 L F
.27927 .58825 m .27983 .5926 L .27847 .59268 L F
0 0 .265 r
.27847 .59268 m .27901 .59427 L .27983 .5926 L F
.765 .989 .892 r
.27872 .59378 m .27983 .5926 L .27847 .59268 L F
0 0 .265 r
.27847 .59268 m .27879 .59537 L .27901 .59427 L F
.751 .786 .881 r
.15699 .74074 m .15762 .74026 L .15634 .74008 L F
.108 .66 .707 r
.5302 .52272 m .53462 .52209 L .53223 .52245 L F
.507 .837 .544 r
.31903 .58732 m .31873 .58755 L .32126 .58664 L F
.882 .724 .681 r
.31873 .58755 m .31586 .58417 L .3174 .584 L F
.31873 .58755 m .31776 .58843 L .31586 .58417 L F
0 .266 .773 r
.31811 .58589 m .31961 .58569 L .31873 .58755 L F
.3174 .584 m .31961 .58569 L .31811 .58589 L F
.402 .025 .205 r
.3214 .58489 m .32052 .58556 L .31961 .58569 L F
.662 .843 .433 r
.31961 .58569 m .3183 .58782 L .31873 .58755 L F
.795 .938 .581 r
.31961 .58569 m .3177 .58771 L .31752 .58908 L F
.402 .025 .205 r
.32052 .58556 m .3177 .58771 L .31961 .58569 L F
.507 .837 .544 r
.31886 .58747 m .31776 .58843 L .31873 .58755 L F
.804 .856 .405 r
.31873 .58755 m .3174 .59063 L .31776 .58843 L F
.726 .488 .566 r
.3174 .59063 m .31873 .58755 L .31776 .58843 L F
.662 .843 .433 r
.3183 .58782 m .31752 .58908 L .31873 .58755 L F
.507 .837 .544 r
.31903 .58732 m .31886 .58747 L .31873 .58755 L F
.375 0 .146 r
.32187 .58622 m .31903 .58732 L .32126 .58664 L F
.106 0 .426 r
.28484 .59817 m .28475 .60073 L .28275 .60162 L F
0 0 0 r
.28475 .60073 m .28228 .60329 L .28275 .60162 L F
.057 0 0 r
.2716 .54627 m .26964 .54797 L .26759 .54855 L F
.081 0 0 r
.27389 .54571 m .26964 .54797 L .2716 .54627 L F
.489 .399 .681 r
.2953 .59533 m .29778 .59824 L .29695 .59509 L F
.2953 .59533 m .29542 .59904 L .29778 .59824 L F
.072 0 0 r
.1991 .56643 m .19869 .56496 L .20075 .56422 L F
.1991 .56643 m .19722 .56732 L .19869 .56496 L F
.264 0 0 r
.24181 .6242 m .24569 .62566 L .24352 .62397 L F
.476 .251 .493 r
.30913 .54594 m .3087 .54856 L .30681 .54649 L F
.30681 .54649 m .3087 .54856 L .30913 .54594 L F
.30913 .54594 m .3087 .54856 L .30681 .54649 L F
.995 .787 .508 r
.54827 .56061 m .54929 .56351 L .54975 .5616 L F
.818 .414 .285 r
.53109 .53124 m .52968 .53296 L .52798 .5301 L F
0 0 0 r
.53204 .53027 m .53109 .53124 L .5334 .52864 L F
.409 .047 .234 r
.53204 .53027 m .52968 .53296 L .53109 .53124 L F
.243 .307 .73 r
.34307 .56036 m .34372 .56302 L .34398 .5619 L F
.34372 .56302 m .34405 .56434 L .34398 .5619 L F
.553 .448 .688 r
.34307 .56036 m .34398 .5619 L .34529 .5601 L F
.644 .256 .294 r
.34138 .56172 m .34429 .56051 L .34398 .5619 L F
.34429 .56051 m .34529 .5601 L .34398 .5619 L F
.829 .398 .213 r
.34712 .56484 m .34398 .5619 L .34405 .56434 L F
.867 .421 .058 r
.34398 .5619 m .34484 .56413 L .34301 .5625 L F
.34398 .5619 m .34297 .5624 L .34138 .56172 L F
.644 .256 .294 r
.34138 .56172 m .34302 .56256 L .34262 .56121 L F
.867 .421 .058 r
.34297 .5624 m .34292 .56242 L .34138 .56172 L F
0 .307 .791 r
.34603 .56509 m .3467 .56493 L .34405 .56434 L F
.3467 .56493 m .34712 .56484 L .3461 .56467 L F
.3467 .56493 m .3461 .56467 L .34405 .56434 L F
.829 .398 .213 r
.34712 .56484 m .34515 .56492 L .34398 .5619 L F
.644 .256 .294 r
.34262 .56121 m .3435 .56253 L .34529 .5601 L F
.3435 .56253 m .34365 .56254 L .34529 .5601 L F
.867 .421 .058 r
.34484 .56413 m .34515 .56492 L .34419 .56385 L F
.34484 .56413 m .34419 .56385 L .34292 .56242 L F
.719 .654 .784 r
.34398 .56254 m .34515 .56492 L .34774 .56259 L F
.34302 .56253 m .3434 .56296 L .34398 .56254 L F
.3434 .56296 m .34515 .56492 L .34398 .56254 L F
.112 0 .024 r
.34529 .5601 m .34402 .56247 L .34614 .56097 L F
.34402 .56247 m .34398 .56254 L .34416 .56241 L F
.34402 .56247 m .34416 .56241 L .34614 .56097 L F
.719 .654 .784 r
.34416 .56241 m .34797 .56238 L .34658 .56141 L F
.867 .421 .058 r
.34398 .5619 m .34301 .5625 L .34297 .5624 L F
.644 .256 .294 r
.34302 .56256 m .34377 .56294 L .34262 .56121 L F
.867 .421 .058 r
.34297 .5624 m .34301 .5625 L .34292 .56242 L F
.719 .654 .784 r
.34292 .56242 m .34302 .56253 L .34404 .5625 L F
.34416 .56241 m .34404 .5625 L .34797 .56238 L F
.34292 .56242 m .34404 .5625 L .34416 .56241 L F
.644 .256 .294 r
.34358 .56265 m .34386 .56277 L .34398 .56254 L F
.34365 .56254 m .34398 .56254 L .34529 .5601 L F
.34358 .56265 m .34398 .56254 L .34365 .56254 L F
.719 .654 .784 r
.34302 .56253 m .34774 .56259 L .34797 .56238 L F
.112 0 .024 r
.34614 .56097 m .34377 .56294 L .34658 .56141 L F
.34398 .56254 m .34377 .56294 L .34614 .56097 L F
.719 .654 .784 r
.3436 .56224 m .34416 .56241 L .34658 .56141 L F
.649 .763 .933 r
.34658 .56141 m .34377 .56294 L .34391 .56222 L F
.638 .479 .651 r
.34516 .56217 m .34448 .56205 L .34658 .56141 L F
.34391 .56222 m .3436 .56224 L .34658 .56141 L F
.519 .297 .517 r
.34307 .56036 m .34529 .5601 L .34555 .55742 L F
.649 .763 .933 r
.34658 .56141 m .34391 .56222 L .3444 .55969 L F
.039 .109 .609 r
.3444 .55969 m .34516 .56217 L .34658 .56141 L F
0 0 .111 r
.34591 .56141 m .34558 .56225 L .34516 .56217 L F
.34558 .56225 m .34446 .56503 L .34516 .56217 L F
.638 .479 .651 r
.34516 .56217 m .34391 .56222 L .34448 .56205 L F
.34467 .56057 m .34404 .56155 L .34377 .56294 L F
.719 .654 .784 r
.34292 .56242 m .34348 .56242 L .3436 .56224 L F
.638 .479 .651 r
.34516 .56217 m .34292 .56242 L .3436 .56224 L F
.34516 .56217 m .34467 .56057 L .34405 .56222 L F
.34516 .56217 m .34405 .56222 L .34377 .56294 L F
.34467 .56057 m .3444 .55969 L .34404 .56155 L F
.719 .654 .784 r
.34348 .56242 m .34416 .56241 L .3436 .56224 L F
.644 .256 .294 r
.3435 .56253 m .34358 .56265 L .34365 .56254 L F
.34358 .56265 m .34377 .56294 L .34386 .56277 L F
0 .307 .791 r
.34603 .56509 m .34868 .56688 L .34712 .56484 L F
.588 .418 .619 r
.25224 .7119 m .24957 .71525 L .2507 .71308 L F
.049 0 .379 r
.29662 .57695 m .29633 .57955 L .29537 .58013 L F
0 .055 .612 r
.29635 .58161 m .29537 .58013 L .29633 .57955 L F
.038 .2 .704 r
.53912 .57049 m .53796 .56658 L .53973 .56757 L F
.512 .059 .114 r
.2368 .72346 m .23625 .7212 L .23438 .72367 L F
.2368 .72346 m .23835 .72165 L .23625 .7212 L F
.744 .687 .796 r
.29663 .54637 m .29978 .54797 L .29845 .54592 L F
0 .312 .748 r
.30213 .54827 m .29845 .54592 L .29978 .54797 L F
.441 0 0 r
.31189 .59504 m .30735 .59537 L .30634 .59498 L F
.31189 .59504 m .30962 .59579 L .30735 .59537 L F
.808 .986 .886 r
.31077 .59319 m .30962 .59579 L .31189 .59504 L F
.166 0 0 r
.26715 .53235 m .2711 .53286 L .26898 .53308 L F
.627 .458 .634 r
.32547 .6382 m .32306 .63574 L .32546 .63526 L F
.32547 .6382 m .3232 .63857 L .32306 .63574 L F
.745 .677 .784 r
.7992 .42584 m .80298 .42656 L .80189 .42285 L F
.594 .45 .655 r
.33093 .62907 m .33152 .63232 L .32933 .6322 L F
.644 .399 .533 r
.33152 .63232 m .32805 .63484 L .32933 .6322 L F
.36 .19 .511 r
.29552 .60162 m .29778 .59824 L .29542 .59904 L F
.778 .459 .448 r
.80363 .41413 m .80656 .41638 L .80629 .41422 L F
.80363 .41413 m .80285 .41596 L .80656 .41638 L F
.92 .622 .463 r
.55254 .52993 m .55487 .53295 L .55437 .53081 L F
.52 .352 .594 r
.32379 .59829 m .32614 .59508 L .32388 .59569 L F
.655 .431 .567 r
.33786 .61968 m .33516 .61716 L .33773 .61697 L F
.33786 .61968 m .33524 .62002 L .33516 .61716 L F
.719 .982 .783 r
.32077 .59109 m .32004 .59262 L .32263 .59025 L F
0 0 0 r
.31963 .59396 m .32004 .59262 L .32077 .59109 L F
.642 .627 .82 r
.29316 .54501 m .29475 .54783 L .29663 .54637 L F
.61 .375 .536 r
.32614 .59508 m .32888 .5923 L .32639 .59264 L F
0 0 0 r
.82301 .40385 m .82627 .40318 L .82678 .40304 L F
.298 0 0 r
.82678 .40304 m .82627 .40318 L .82857 .40364 L F
.781 .859 .908 r
.82469 .41019 m .82779 .41057 L .82736 .40729 L F
.82469 .41019 m .8258 .41162 L .82779 .41057 L F
.85 .85 .842 r
.82736 .40729 m .82779 .41057 L .83035 .40745 L F
.699 .787 .31 r
.46554 .65518 m .46481 .65706 L .46584 .65464 L F
.852 .981 .862 r
.82248 .4136 m .8258 .41162 L .82469 .41019 L F
.377 .101 .362 r
.24429 .7211 m .24508 .71886 L .24722 .71831 L F
.24429 .7211 m .24508 .71886 L .24722 .71831 L F
.513 .183 .344 r
.5334 .52864 m .53603 .52982 L .53204 .53027 L F
.423 .467 .801 r
.7689 .40408 m .77016 .40785 L .77225 .40583 L F
.408 .444 .786 r
.77016 .40785 m .77322 .40932 L .77225 .40583 L F
.473 .258 .505 r
.34639 .59832 m .3438 .60147 L .34387 .59857 L F
.328 .269 .638 r
.15543 .5864 m .15738 .5884 L .15717 .58567 L F
.15543 .5864 m .15558 .58994 L .15738 .5884 L F
.884 .547 .405 r
.543 .54474 m .53855 .54223 L .54116 .54285 L F
.543 .54474 m .53868 .54447 L .53855 .54223 L F
.935 .613 .163 r
.54034 .54833 m .53868 .54447 L .543 .54474 L F
.874 .858 .822 r
.54397 .54687 m .54034 .54833 L .543 .54474 L F
.65 .511 .68 r
.28919 .6143 m .29292 .61677 L .29177 .61449 L F
.28919 .6143 m .29003 .61725 L .29292 .61677 L F
0 0 0 r
.22709 .53685 m .22936 .53633 L .2307 .536 L F
.284 .785 .84 r
.22936 .53633 m .2332 .53574 L .2307 .536 L F
.571 .75 .961 r
.27274 .64577 m .27423 .64736 L .27646 .64663 L F
.529 .501 .769 r
.34231 .61064 m .33997 .61134 L .33901 .60779 L F
.463 .349 .638 r
.34231 .61064 m .3404 .61393 L .33997 .61134 L F
.317 .213 .575 r
.15701 .58301 m .15879 .57911 L .15683 .58039 L F
.548 .52 .776 r
.36045 .57598 m .35837 .57763 L .35729 .57436 L F
.45 .361 .664 r
.36045 .57598 m .35876 .58018 L .35837 .57763 L F
.716 .671 .805 r
.23126 .72828 m .23027 .72514 L .22946 .72727 L F
.23126 .72828 m .23244 .72413 L .23027 .72514 L F
.23126 .72828 m .2345 .72738 L .23244 .72413 L F
.407 .777 .994 r
.24747 .64098 m .24846 .63997 L .246 .64027 L F
.24747 .64098 m .24985 .64081 L .24846 .63997 L F
.615 .619 .832 r
.19413 .60504 m .19155 .60573 L .19062 .60352 L F
.083 .545 .905 r
.33921 .53893 m .34277 .54064 L .34194 .54043 L F
.734 .229 0 r
.26719 .67385 m .26701 .67251 L .26523 .6724 L F
.26719 .67385 m .26974 .67603 L .26701 .67251 L F
0 0 0 r
.2708 .67575 m .27327 .67242 L .27229 .67443 L F
.934 .941 .595 r
.27354 .66977 m .27327 .67242 L .27252 .67274 L F
.988 .728 .365 r
.27252 .67274 m .27327 .67242 L .27251 .67404 L F
.527 .645 .909 r
.27354 .66977 m .27576 .67228 L .27327 .67242 L F
.469 .121 .294 r
.27327 .67242 m .27576 .67228 L .27229 .67443 L F
.698 .741 .232 r
.53474 .53411 m .53603 .52982 L .53666 .531 L F
.412 .213 .499 r
.53589 .53346 m .53474 .53411 L .53666 .531 L F
.639 .525 .708 r
.33328 .62593 m .33455 .63115 L .33093 .62907 L F
.347 0 .083 r
.33455 .63115 m .33152 .63232 L .33093 .62907 L F
.032 0 .023 r
.36647 .5403 m .36355 .5432 L .36345 .54047 L F
.097 0 0 r
.36345 .54047 m .36528 .54052 L .36647 .5403 L F
.032 0 .023 r
.36647 .5403 m .36571 .54218 L .36355 .5432 L F
.368 .835 .801 r
.36647 .5403 m .36528 .54052 L .36828 .53953 L F
.451 .055 .195 r
.36791 .54179 m .36647 .5403 L .36828 .53953 L F
.36791 .54179 m .36571 .54218 L .36647 .5403 L F
.199 .715 .881 r
.2711 .53286 m .27339 .53272 L .27512 .53303 L F
.117 .666 .803 r
.27339 .53272 m .27749 .53271 L .27512 .53303 L F
.536 .817 .998 r
.18912 .59405 m .18929 .59602 L .18763 .59183 L F
.18912 .59405 m .19154 .59518 L .18929 .59602 L F
.32 .061 .356 r
.19154 .59518 m .18857 .59775 L .18929 .59602 L F
0 .306 .755 r
.22365 .61939 m .22359 .61993 L .22216 .6184 L F
.22365 .61939 m .22621 .62144 L .22359 .61993 L F
0 .169 .687 r
.22705 .62337 m .22359 .61993 L .22621 .62144 L F
.874 .748 .72 r
.49682 .53976 m .49831 .54336 L .49552 .54225 L F
.732 .828 .925 r
.49552 .54225 m .49831 .54336 L .49767 .54187 L F
.165 .343 .797 r
.49931 .54168 m .49831 .54336 L .49682 .53976 L F
.353 .592 .936 r
.49767 .54187 m .49831 .54336 L .49931 .54168 L F
.889 .895 .827 r
.50095 .56077 m .50235 .56182 L .50474 .55864 L F
.104 0 0 r
.50338 .56276 m .50235 .56182 L .50095 .56077 L F
.50338 .56276 m .50105 .56375 L .50235 .56182 L F
.592 .528 .751 r
.33216 .58945 m .33459 .58877 L .3346 .58327 L F
.352 .087 .365 r
.33189 .5913 m .33459 .58877 L .33216 .58945 L F
0 0 .061 r
.24679 .71077 m .24658 .70952 L .24557 .71226 L F
.867 .887 .458 r
.53915 .56057 m .53886 .56025 L .53996 .55867 L F
.53903 .56085 m .53886 .56025 L .53915 .56057 L F
.957 .66 .229 r
.53886 .56025 m .53794 .55945 L .53758 .55656 L F
.021 .334 .816 r
.53886 .56025 m .53863 .55944 L .53794 .55945 L F
.766 .606 .68 r
.53794 .55945 m .53857 .55994 L .53886 .56025 L F
.969 .852 .448 r
.53996 .55867 m .53886 .56025 L .53943 .55769 L F
.957 .66 .229 r
.53886 .56025 m .53758 .55656 L .53943 .55769 L F
.021 .334 .816 r
.53886 .56025 m .54189 .56249 L .54001 .5594 L F
.766 .606 .68 r
.53857 .55994 m .54189 .56249 L .53886 .56025 L F
.021 .334 .816 r
.53886 .56025 m .54001 .5594 L .53863 .55944 L F
.867 .887 .458 r
.5389 .56114 m .53886 .56025 L .53903 .56085 L F
.971 .903 .547 r
.53996 .55867 m .53943 .55769 L .54033 .55427 L F
.332 0 0 r
.24953 .62653 m .25159 .62701 L .25361 .62593 L F
.179 0 0 r
.25159 .62701 m .25585 .62575 L .25361 .62593 L F
0 0 0 r
.26212 .67912 m .25895 .68156 L .26262 .68301 L F
.801 .777 .831 r
.26212 .67912 m .26366 .67454 L .26072 .67489 L F
.26212 .67912 m .26473 .67674 L .26366 .67454 L F
.673 .353 .424 r
.26262 .68301 m .2638 .68136 L .26212 .67912 L F
.186 0 0 r
.21012 .55951 m .20865 .56102 L .20652 .56095 L F
0 0 0 r
.21048 .56021 m .21012 .55951 L .21236 .55927 L F
.21048 .56021 m .20865 .56102 L .21012 .55951 L F
.284 0 .055 r
.32353 .58546 m .32187 .58622 L .32126 .58664 L F
.698 .741 .232 r
.53474 .53411 m .53513 .53269 L .53603 .52982 L F
0 0 .225 r
.53474 .53411 m .53549 .53468 L .53513 .53269 L F
.734 .571 .671 r
.53589 .53346 m .53473 .53665 L .53474 .53411 L F
0 0 .225 r
.53474 .53411 m .53473 .53665 L .53549 .53468 L F
.185 .708 .868 r
.32055 .53668 m .31652 .53653 L .31893 .53563 L F
.378 .821 .948 r
.32107 .53581 m .32055 .53668 L .31893 .53563 L F
.32107 .53581 m .32287 .53619 L .32055 .53668 L F
0 0 0 r
.28771 .56461 m .28633 .56832 L .28703 .56704 L F
.35 .448 .821 r
.28633 .56832 m .28865 .56923 L .28703 .56704 L F
.03 .144 .65 r
.15764 .59929 m .15932 .60051 L .15994 .59783 L F
.15764 .59929 m .15873 .60269 L .15932 .60051 L F
.092 0 .202 r
.354 .58939 m .35217 .59181 L .35267 .59068 L F
.643 .363 .48 r
.28695 .64856 m .29053 .64741 L .28951 .65025 L F
.538 .042 .026 r
.29053 .64741 m .29118 .64935 L .28951 .65025 L F
.29053 .64741 m .29295 .64784 L .29118 .64935 L F
.368 .162 .463 r
.27391 .60147 m .27594 .60103 L .2761 .59855 L F
.166 .125 .563 r
.27391 .60147 m .2756 .60358 L .27594 .60103 L F
.27391 .60147 m .27385 .60476 L .2756 .60358 L F
.683 .591 .746 r
.29369 .60481 m .29701 .60732 L .29581 .60442 L F
.566 .489 .727 r
.29709 .60895 m .29867 .60617 L .29701 .60732 L F
0 0 0 r
.27703 .66272 m .27551 .66413 L .2744 .66605 L F
.665 .893 .544 r
.51321 .52965 m .5156 .52656 L .51419 .52869 L F
.185 0 0 r
.51419 .52869 m .51566 .52923 L .51321 .52965 L F
.51419 .52869 m .51728 .52812 L .51566 .52923 L F
.507 0 0 r
.32526 .54693 m .32775 .54851 L .3238 .54627 L F
.199 .694 .918 r
.21508 .61773 m .21323 .61779 L .21143 .61719 L F
.777 .336 .203 r
.54897 .52902 m .55198 .52843 L .54836 .52743 L F
.54897 .52902 m .55254 .52993 L .55198 .52843 L F
.599 .943 .777 r
.26974 .67603 m .2708 .67575 L .27229 .67443 L F
.495 .844 .576 r
.26883 .67733 m .2708 .67575 L .27229 .67443 L F
.374 .416 .776 r
.15558 .58994 m .15824 .59176 L .15738 .5884 L F
.15558 .58994 m .15709 .59249 L .15824 .59176 L F
0 0 .005 r
.25895 .68156 m .25655 .68522 L .25762 .68365 L F
.267 .428 .837 r
.25655 .68522 m .2593 .68695 L .25762 .68365 L F
.757 .415 .404 r
.5408 .52338 m .54487 .52395 L .54459 .52197 L F
.331 .266 .632 r
.36355 .5432 m .36528 .54052 L .36345 .54047 L F
.36355 .5432 m .36571 .54218 L .36528 .54052 L F
.45 0 0 r
.36355 .5432 m .36536 .54439 L .36571 .54218 L F
.099 .121 .595 r
.36536 .54439 m .36437 .5463 L .36355 .5432 L F
.45 0 0 r
.36355 .5432 m .36196 .54484 L .36536 .54439 L F
.099 .121 .595 r
.36536 .54439 m .36355 .5432 L .36571 .54218 L F
.996 .791 .513 r
.55261 .54128 m .55416 .54011 L .55315 .5388 L F
.55261 .54128 m .5537 .54251 L .55416 .54011 L F
.931 .706 .224 r
.77062 .3969 m .77126 .40111 L .77124 .39861 L F
.261 .658 .966 r
.25662 .64094 m .25963 .64205 L .25855 .64077 L F
0 .377 .838 r
.25963 .64205 m .2606 .64165 L .25855 .64077 L F
.25963 .64205 m .26316 .64473 L .2606 .64165 L F
.416 .337 .659 r
.33406 .56036 m .33216 .56162 L .33179 .55947 L F
.328 .488 .866 r
.23244 .72413 m .2345 .72738 L .23593 .72699 L F
.942 .577 .217 r
.32382 .58871 m .32353 .58546 L .32126 .58664 L F
.32382 .58871 m .32475 .58915 L .32353 .58546 L F
.742 .267 0 r
.32694 .58752 m .32618 .58619 L .32714 .58577 L F
.598 .423 .615 r
.32353 .58546 m .32694 .58752 L .32714 .58577 L F
.32353 .58546 m .32475 .58915 L .32694 .58752 L F
.733 .717 .836 r
.54293 .57342 m .54662 .57406 L .54585 .57081 L F
.441 .306 .601 r
.33524 .62002 m .33522 .62295 L .333 .6233 L F
.57 .439 .663 r
.33565 .62549 m .333 .6233 L .33522 .62295 L F
.33565 .62549 m .33328 .62593 L .333 .6233 L F
0 0 .168 r
.2756 .60358 m .27385 .60476 L .27362 .60694 L F
.417 .863 .894 r
.26255 .62351 m .25775 .62432 L .25979 .62343 L F
.527 .917 .915 r
.26385 .62176 m .2634 .62238 L .26055 .62262 L F
.584 .857 .521 r
.26524 .62045 m .26265 .6234 L .2634 .62238 L F
0 0 0 r
.26673 .61683 m .26524 .62045 L .26619 .61885 L F
.669 .899 .556 r
.26619 .61885 m .26524 .62045 L .2634 .62238 L F
.26619 .61885 m .2634 .62238 L .2654 .62136 L F
.527 .917 .915 r
.2654 .62136 m .2634 .62238 L .26385 .62176 L F
.584 .857 .521 r
.26265 .6234 m .26255 .62351 L .2634 .62238 L F
.542 .919 .935 r
.2634 .62238 m .26255 .62351 L .25979 .62343 L F
.634 .795 .959 r
.15932 .60051 m .15873 .60269 L .16123 .60181 L F
.452 0 0 r
.81838 .39657 m .82042 .39811 L .81977 .39761 L F
.873 .648 .594 r
.81731 .40021 m .82042 .39811 L .81838 .39657 L F
.81731 .40021 m .81934 .40095 L .82042 .39811 L F
.461 .318 .6 r
.29369 .60481 m .29581 .60442 L .29552 .60162 L F
.772 .648 .726 r
.28922 .55781 m .29047 .56162 L .29301 .55863 L F
.638 .449 .611 r
.29301 .55863 m .29047 .56162 L .29325 .561 L F
.587 .676 .901 r
.26366 .67454 m .26473 .67674 L .26688 .67603 L F
.456 .778 .998 r
.25415 .64098 m .25521 .63979 L .25224 .64053 L F
.25415 .64098 m .25662 .64094 L .25521 .63979 L F
0 .025 .533 r
.23221 .73535 m .23371 .7363 L .23482 .73502 L F
.486 .263 .5 r
.28132 .62524 m .28375 .62283 L .28168 .62347 L F
.729 .667 .79 r
.34185 .60676 m .33901 .60779 L .34256 .60762 L F
.361 .113 .397 r
.31936 .54627 m .31884 .54916 L .31667 .54969 L F
.484 .219 .436 r
.32144 .54852 m .31884 .54916 L .31936 .54627 L F
.565 .22 .343 r
.32181 .54639 m .32144 .54852 L .31936 .54627 L F
.207 0 .149 r
.16134 .57343 m .16323 .57315 L .16433 .57079 L F
.261 0 .177 r
.16433 .57079 m .16534 .57244 L .16605 .56984 L F
.16433 .57079 m .16323 .57315 L .16534 .57244 L F
.61 .687 .898 r
.81935 .41628 m .81588 .41551 L .8168 .41693 L F
.693 .844 .42 r
.27993 .60743 m .28228 .60329 L .28191 .60615 L F
0 0 0 r
.28475 .60073 m .28375 .60273 L .28228 .60329 L F
0 0 .072 r
.28375 .60273 m .28191 .60615 L .28228 .60329 L F
0 .561 .791 r
.26597 .64394 m .27046 .64468 L .26812 .64417 L F
0 .279 .65 r
.27046 .64468 m .27073 .64477 L .26812 .64417 L F
.27046 .64468 m .27274 .64577 L .27073 .64477 L F
.859 .492 .354 r
.33245 .57127 m .3332 .57287 L .33528 .57235 L F
.297 .789 .755 r
.33528 .57235 m .33547 .57208 L .33729 .57075 L F
.33528 .57235 m .3332 .57287 L .33547 .57208 L F
.89 .721 .667 r
.82857 .40364 m .82736 .40729 L .83035 .40745 L F
.751 .386 .362 r
.79285 .4137 m .79644 .41421 L .79408 .41373 L F
.747 .426 .439 r
.793 .41578 m .79644 .41421 L .79285 .4137 L F
.793 .41578 m .79685 .41626 L .79644 .41421 L F
.593 .324 .479 r
.79644 .41421 m .79685 .41626 L .79945 .41575 L F
0 0 0 r
.20844 .54245 m .21028 .54192 L .21246 .54056 L F
.165 0 0 r
.21246 .54056 m .21315 .54133 L .21424 .53931 L F
.21246 .54056 m .21028 .54192 L .21315 .54133 L F
.874 .858 .822 r
.54397 .54687 m .54058 .55053 L .54034 .54833 L F
.093 0 .398 r
.29836 .57778 m .29662 .57695 L .29949 .57468 L F
0 0 .224 r
.30049 .57229 m .3004 .57507 L .29949 .57468 L F
0 0 .129 r
.3004 .57507 m .29836 .57778 L .29949 .57468 L F
.966 .77 .589 r
.78842 .40779 m .78731 .4039 L .78688 .40668 L F
.963 .778 .606 r
.78621 .40888 m .78842 .40779 L .78688 .40668 L F
.78621 .40888 m .78749 .40959 L .78842 .40779 L F
.515 .913 .816 r
.28289 .54865 m .28168 .54981 L .28388 .54885 L F
.271 .429 .836 r
.32863 .5739 m .3303 .5745 L .32951 .57208 L F
.517 .424 .689 r
.32863 .5739 m .33156 .57647 L .3303 .5745 L F
.32863 .5739 m .3293 .57725 L .33156 .57647 L F
.472 .362 .648 r
.36055 .56138 m .3586 .56486 L .35724 .56074 L F
.36055 .56138 m .3612 .56449 L .3586 .56486 L F
.485 .443 .735 r
.3612 .56449 m .36133 .56649 L .3586 .56486 L F
.572 .478 .709 r
.3633 .56668 m .36254 .56714 L .36133 .56649 L F
.499 .44 .721 r
.36133 .56649 m .36091 .56755 L .35865 .56505 L F
.36091 .56755 m .36003 .56974 L .359 .56624 L F
.36091 .56755 m .359 .56624 L .35865 .56505 L F
.906 .945 .82 r
.3603 .56847 m .36003 .56974 L .36083 .56775 L F
.3603 .56847 m .36083 .56775 L .36133 .56649 L F
.3603 .56847 m .35893 .56999 L .36003 .56974 L F
.578 .479 .706 r
.36203 .5731 m .35909 .57015 L .3603 .56847 L F
.35909 .57015 m .35893 .56999 L .3603 .56847 L F
.547 .414 .651 r
.36448 .57246 m .3603 .56847 L .36347 .56931 L F
.3646 .57008 m .36347 .56931 L .36462 .56961 L F
.36448 .57246 m .36347 .56931 L .3646 .57008 L F
.572 .478 .709 r
.36254 .56714 m .3603 .56847 L .36133 .56649 L F
.499 .44 .721 r
.36133 .56649 m .35865 .56505 L .3586 .56486 L F
.532 .123 .211 r
.26262 .68301 m .25895 .68156 L .25762 .68365 L F
.258 .291 .706 r
.36049 .55146 m .35974 .55554 L .35942 .55159 L F
.493 .828 .999 r
.36173 .55775 m .35969 .5581 L .35974 .55554 L F
.334 .346 .724 r
.36293 .55335 m .36173 .55775 L .36049 .55146 L F
.493 .828 .999 r
.36173 .55775 m .36217 .55758 L .35969 .5581 L F
.196 .246 .688 r
.36178 .56014 m .35969 .5581 L .36191 .55763 L F
.36213 .55781 m .36191 .55763 L .36217 .55758 L F
.36178 .56014 m .36191 .55763 L .36213 .55781 L F
.258 .291 .706 r
.36049 .55146 m .36167 .55744 L .35974 .55554 L F
.36167 .55744 m .36173 .55775 L .36088 .5568 L F
.36167 .55744 m .36088 .5568 L .35974 .55554 L F
.45 .361 .664 r
.36045 .57598 m .36083 .57955 L .35876 .58018 L F
.483 .338 .608 r
.36083 .57955 m .35876 .58282 L .35876 .58018 L F
.485 .066 .168 r
.27558 .631 m .27847 .63105 L .27988 .62903 L F
.616 .543 .749 r
.27988 .62903 m .2824 .62902 L .28132 .62524 L F
.578 .274 .416 r
.28224 .63084 m .27988 .62903 L .27847 .63105 L F
.28224 .63084 m .2824 .62902 L .27988 .62903 L F
.555 .446 .684 r
.35901 .58508 m .35631 .58345 L .35876 .58282 L F
.35901 .58508 m .35674 .58653 L .35631 .58345 L F
.018 0 0 r
.80865 .40972 m .81078 .4092 L .81172 .40806 L F
.815 .977 .895 r
.81456 .40579 m .81172 .40806 L .81262 .4055 L F
.777 .88 .457 r
.81172 .40806 m .81078 .4092 L .81262 .4055 L F
.473 .112 .273 r
.30073 .58266 m .3031 .58259 L .30456 .58008 L F
.437 .075 .252 r
.30456 .58008 m .3058 .58201 L .30649 .57936 L F
.30456 .58008 m .3031 .58259 L .3058 .58201 L F
0 0 0 r
.19855 .5473 m .20259 .54483 L .20063 .54619 L F
.629 .345 .468 r
.30556 .64476 m .30777 .64714 L .30537 .64696 L F
.645 .343 .446 r
.30811 .64494 m .30777 .64714 L .30556 .64476 L F
.611 .322 .455 r
.20652 .56095 m .20378 .56193 L .20443 .56149 L F
.592 .438 .642 r
.3187 .60182 m .31882 .60452 L .32121 .60132 L F
.934 .562 .266 r
.27003 .66521 m .27196 .66671 L .27262 .67102 L F
.497 .236 .449 r
.27196 .66671 m .2744 .66605 L .27262 .67102 L F
.462 .271 .535 r
.29853 .58321 m .29844 .58574 L .30073 .58266 L F
.532 .243 .422 r
.31443 .6418 m .31399 .64409 L .31149 .64437 L F
.567 .275 .432 r
.31657 .64375 m .31399 .64409 L .31443 .6418 L F
.576 .273 .419 r
.317 .64168 m .31657 .64375 L .31443 .6418 L F
.544 .071 .082 r
.35432 .54795 m .35784 .54696 L .35456 .54584 L F
.35432 .54795 m .35674 .54809 L .35784 .54696 L F
.523 0 0 r
.22045 .75909 m .22144 .75871 L .2175 .75798 L F
.483 .818 .999 r
.21799 .75773 m .22144 .75871 L .22364 .75822 L F
.21665 .75761 m .21798 .75777 L .21799 .75773 L F
.279 .745 .946 r
.21857 .75751 m .21798 .75777 L .21665 .75761 L F
.21798 .75777 m .2175 .75798 L .21665 .75761 L F
.483 .818 .999 r
.21665 .75761 m .21797 .75792 L .21798 .75777 L F
.21797 .75792 m .22144 .75871 L .21799 .75773 L F
.21923 .75777 m .22364 .75822 L .22193 .7578 L F
.21799 .75773 m .22364 .75822 L .21833 .75767 L F
0 0 0 r
.22364 .75822 m .22144 .75871 L .22045 .75909 L F
.17 .672 .909 r
.2175 .75798 m .22144 .75871 L .21797 .75792 L F
0 0 0 r
.22364 .75822 m .22045 .75909 L .22193 .7578 L F
.415 .729 .99 r
.22421 .75685 m .22364 .75822 L .22193 .7578 L F
.22421 .75685 m .22644 .75836 L .22364 .75822 L F
.407 0 0 r
.22193 .7578 m .22364 .75822 L .22467 .75896 L F
.321 0 0 r
.22364 .75822 m .22644 .75836 L .22467 .75896 L F
.407 0 0 r
.22193 .7578 m .22467 .75896 L .22442 .75783 L F
.22193 .7578 m .22442 .75783 L .22421 .75685 L F
.483 .818 .999 r
.21833 .75767 m .21923 .75777 L .22193 .7578 L F
.21665 .75761 m .21799 .75773 L .21833 .75767 L F
.207 .555 .933 r
.21832 .75767 m .2189 .75779 L .21797 .75792 L F
.21857 .75751 m .21833 .75767 L .21832 .75767 L F
.321 .754 .97 r
.21665 .75761 m .21833 .75767 L .21857 .75751 L F
.21833 .75767 m .22193 .7578 L .21857 .75751 L F
.207 .555 .933 r
.21857 .75751 m .21869 .75761 L .21833 .75767 L F
.21869 .75761 m .2189 .75779 L .21832 .75767 L F
.21798 .75777 m .21797 .75792 L .2175 .75798 L F
.21857 .75751 m .21797 .75792 L .21798 .75777 L F
.2189 .75779 m .22045 .75909 L .2175 .75798 L F
.17 .672 .909 r
.2175 .75798 m .21797 .75792 L .21665 .75761 L F
.728 .849 .413 r
.81934 .40095 m .81772 .40439 L .82046 .40474 L F
.81934 .40095 m .81716 .40538 L .81772 .40439 L F
.279 0 0 r
.81772 .40439 m .81956 .40479 L .82046 .40474 L F
.261 .762 .887 r
.81262 .4055 m .81682 .40539 L .81456 .40579 L F
.258 .356 .773 r
.15709 .59249 m .15916 .59542 L .15824 .59176 L F
.462 .666 .951 r
.20128 .62667 m .20594 .62923 L .20411 .62627 L F
.553 .597 .852 r
.20594 .62923 m .20636 .62509 L .20411 .62627 L F
.20594 .62923 m .20841 .62868 L .20636 .62509 L F
.619 .604 .814 r
.20594 .62923 m .21005 .63156 L .20841 .62868 L F
.249 0 .15 r
.20515 .56294 m .20378 .56193 L .20652 .56095 L F
.463 .096 .256 r
.20865 .56102 m .20515 .56294 L .20652 .56095 L F
0 0 0 r
.28628 .54548 m .28388 .54885 L .28378 .54569 L F
.155 .671 .891 r
.34277 .54064 m .34651 .54111 L .34351 .54125 L F
.304 0 0 r
.53462 .52209 m .5375 .52252 L .53844 .52142 L F
.708 .215 .069 r
.5375 .52252 m .5408 .52338 L .53844 .52142 L F
.491 .414 .697 r
.17962 .58661 m .177 .58275 L .17836 .5822 L F
.17962 .58661 m .17771 .58774 L .177 .58275 L F
.044 0 0 r
.19022 .57147 m .18896 .57307 L .18705 .57379 L F
.202 0 0 r
.19185 .572 m .19022 .57147 L .1923 .57076 L F
.19185 .572 m .18896 .57307 L .19022 .57147 L F
.498 .891 .732 r
.25052 .69721 m .24672 .69947 L .24899 .69924 L F
.869 .959 .861 r
.25157 .69588 m .25052 .69721 L .24985 .69523 L F
.958 .947 .689 r
.24985 .69523 m .25052 .69721 L .24899 .69924 L F
.362 .811 .677 r
.32077 .59109 m .32263 .59025 L .32475 .58915 L F
.611 .42 .598 r
.35151 .59752 m .34904 .59535 L .35315 .59468 L F
.553 .518 .77 r
.35409 .59289 m .35315 .59468 L .35217 .59181 L F
.653 .394 .515 r
.35315 .59468 m .35497 .5976 L .35151 .59752 L F
.619 .6 .809 r
.35409 .59289 m .35561 .59557 L .35315 .59468 L F
.718 .41 .456 r
.35561 .59557 m .35497 .5976 L .35315 .59468 L F
.455 .681 .962 r
.2606 .64165 m .26316 .64473 L .26263 .64277 L F
.628 .608 .811 r
.26316 .64473 m .26398 .64507 L .26597 .64394 L F
.597 .674 .894 r
.18673 .58955 m .18414 .58841 L .18633 .58795 L F
0 0 .515 r
.18807 .58966 m .18673 .58955 L .18633 .58795 L F
.18807 .58966 m .18763 .59183 L .18673 .58955 L F
.536 .698 .944 r
.21911 .63457 m .22335 .63578 L .22241 .63333 L F
.464 .642 .934 r
.22335 .63578 m .22501 .63375 L .22241 .63333 L F
.22335 .63578 m .22527 .63549 L .22501 .63375 L F
.955 .947 .717 r
.3364 .57994 m .33496 .58318 L .33403 .58147 L F
.851 .418 0 r
.33496 .58318 m .3316 .58371 L .33403 .58147 L F
.33496 .58318 m .3346 .58327 L .3316 .58371 L F
.33496 .58318 m .33574 .58543 L .3346 .58327 L F
.3346 .58327 m .33574 .58543 L .33496 .58318 L F
.485 .561 .858 r
.19362 .62057 m .19393 .62176 L .19587 .62061 L F
.084 .634 .825 r
.23581 .63767 m .23196 .63732 L .23356 .63845 L F
.841 .85 .851 r
.22338 .74081 m .22105 .74407 L .21923 .74248 L F
.347 .681 .979 r
.22105 .74407 m .22147 .74247 L .21923 .74248 L F
.22105 .74407 m .22353 .74423 L .22147 .74247 L F
.489 .259 .492 r
.2761 .59855 m .27594 .60103 L .27884 .59795 L F
.352 .613 .949 r
.21005 .63156 m .21038 .62987 L .20841 .62868 L F
.21005 .63156 m .2118 .63156 L .21038 .62987 L F
.496 .607 .893 r
.21597 .63213 m .21911 .63457 L .21692 .63221 L F
.536 .701 .946 r
.21692 .63221 m .21911 .63457 L .22241 .63333 L F
.797 .998 .85 r
.27039 .66074 m .27106 .65876 L .26919 .65658 L F
.27039 .66074 m .27316 .65812 L .27106 .65876 L F
.467 .466 .774 r
.27165 .6636 m .27003 .66521 L .27238 .66527 L F
.741 .289 .178 r
.27178 .66271 m .27039 .66074 L .26908 .66173 L F
.27185 .66273 m .27183 .6627 L .27178 .66271 L F
.27183 .6627 m .27039 .66074 L .27178 .66271 L F
.772 .694 .776 r
.26879 .66194 m .27003 .66521 L .27185 .66273 L F
.896 .918 .829 r
.26842 .6646 m .27003 .66521 L .27068 .6629 L F
.741 .289 .178 r
.27185 .66273 m .26908 .66173 L .26969 .66217 L F
.896 .918 .829 r
.26994 .66302 m .27068 .6629 L .27094 .66199 L F
.26842 .6646 m .27068 .6629 L .26994 .66302 L F
.467 .466 .774 r
.27094 .66199 m .27068 .6629 L .27165 .6636 L F
.27068 .6629 m .27003 .66521 L .27165 .6636 L F
.741 .289 .178 r
.26969 .66217 m .26908 .66173 L .26879 .66194 L F
.29 .788 .859 r
.24151 .53492 m .24408 .53435 L .24608 .53446 L F
.277 0 0 r
.24408 .53435 m .24826 .53414 L .24608 .53446 L F
.125 .367 .827 r
.22758 .62177 m .22705 .62337 L .22621 .62144 L F
.43 .715 .984 r
.22758 .62177 m .22922 .62318 L .22705 .62337 L F
.63 .805 .967 r
.17936 .74581 m .18338 .74625 L .18218 .74491 L F
.17936 .74581 m .18338 .74625 L .18218 .74491 L F
.701 .641 .786 r
.31421 .59562 m .31491 .59122 L .31296 .59384 L F
.637 .441 .6 r
.34904 .59535 m .34906 .59805 L .34639 .59832 L F
.611 .42 .598 r
.35151 .59752 m .34906 .59805 L .34904 .59535 L F
.466 .697 .968 r
.20723 .61611 m .20654 .61779 L .20649 .61566 L F
.20723 .61611 m .20907 .6177 L .20654 .61779 L F
.546 .573 .833 r
.34522 .54686 m .34711 .54937 L .34657 .54955 L F
.393 0 0 r
.34672 .54966 m .35157 .54841 L .34662 .54974 L F
.34662 .54974 m .35157 .54841 L .34859 .54991 L F
.34701 .54958 m .34761 .54971 L .35157 .54841 L F
.34672 .54966 m .34743 .5497 L .34701 .54958 L F
.34743 .5497 m .34761 .54971 L .34701 .54958 L F
.34761 .54971 m .3493 .54982 L .34942 .54974 L F
.34761 .54971 m .34942 .54974 L .35157 .54841 L F
.34837 .54979 m .3493 .54982 L .34672 .54966 L F
.14 0 0 r
.34745 .54981 m .3493 .54982 L .34765 .54976 L F
.393 0 0 r
.34646 .54972 m .34672 .54966 L .34662 .54974 L F
.34646 .54972 m .34701 .54968 L .34672 .54966 L F
.648 .295 .36 r
.34657 .54955 m .34701 .54968 L .34646 .54972 L F
.34701 .54968 m .34745 .54981 L .34646 .54972 L F
.338 .333 .706 r
.34746 .54971 m .34745 .54981 L .34737 .54971 L F
.546 .573 .833 r
.34737 .54971 m .34745 .54981 L .34701 .54968 L F
.393 0 0 r
.34646 .54972 m .34837 .54979 L .34701 .54968 L F
.14 0 0 r
.34745 .54981 m .34765 .54976 L .34646 .54972 L F
.34745 .54981 m .34887 .54992 L .3493 .54982 L F
.338 .333 .706 r
.34796 .5497 m .34887 .54992 L .34796 .54985 L F
.34787 .54648 m .34876 .54952 L .34796 .5497 L F
.34876 .54952 m .34887 .54992 L .34796 .5497 L F
.34746 .54971 m .34796 .54985 L .34745 .54981 L F
.34787 .54648 m .34796 .54985 L .34746 .54971 L F
.34787 .54648 m .34746 .54971 L .34522 .54686 L F
.34746 .54971 m .34737 .54971 L .34522 .54686 L F
.546 .573 .833 r
.34711 .54937 m .34737 .54971 L .34678 .54961 L F
.34737 .54971 m .34701 .54968 L .34678 .54961 L F
.34711 .54937 m .34678 .54961 L .34657 .54955 L F
.459 .856 .972 r
.23216 .5502 m .23094 .55106 L .23341 .55097 L F
.479 .847 .99 r
.23431 .54967 m .23341 .55097 L .23642 .54983 L F
.23431 .54967 m .23216 .5502 L .23341 .55097 L F
.216 0 .238 r
.15894 .57643 m .16063 .57589 L .16134 .57343 L F
.292 .011 .302 r
.16063 .57589 m .16323 .57315 L .16134 .57343 L F
.643 .363 .48 r
.28695 .64856 m .28951 .65025 L .28659 .64974 L F
.463 .349 .638 r
.34231 .61064 m .34251 .61336 L .3404 .61393 L F
.554 .403 .631 r
.34251 .61336 m .34028 .61653 L .3404 .61393 L F
0 0 0 r
.18246 .57951 m .17996 .58163 L .17836 .5822 L F
.581 .453 .671 r
.18457 .5773 m .18498 .57947 L .18246 .57951 L F
.574 .169 .237 r
.18498 .57947 m .17996 .58163 L .18246 .57951 L F
0 0 .506 r
.54937 .55621 m .5485 .55605 L .54964 .55371 L F
.786 .693 .762 r
.80285 .41596 m .80399 .41955 L .80656 .41638 L F
.604 .552 .769 r
.80629 .41422 m .80656 .41638 L .8092 .41386 L F
.418 .484 .821 r
.31953 .55172 m .31667 .54969 L .31884 .54916 L F
.505 .429 .705 r
.35893 .56999 m .35968 .57398 L .35729 .57436 L F
.548 .52 .776 r
.36045 .57598 m .35729 .57436 L .35968 .57398 L F
.461 .023 .119 r
.34396 .56987 m .34062 .57091 L .34608 .57021 L F
.672 .973 .807 r
.82046 .40474 m .8221 .4027 L .82301 .40385 L F
.82046 .40474 m .81956 .40479 L .8221 .4027 L F
.706 .35 .371 r
.3238 .54627 m .32144 .54852 L .32181 .54639 L F
.32 .044 .329 r
.33216 .56162 m .33152 .56471 L .32938 .56468 L F
0 0 .047 r
.33269 .56253 m .33216 .56162 L .33406 .56036 L F
.33269 .56253 m .33152 .56471 L .33216 .56162 L F
.841 .998 .824 r
.29567 .55402 m .29561 .55566 L .29778 .55489 L F
.29567 .55402 m .29362 .55601 L .29561 .55566 L F
.728 .656 .778 r
.3363 .56601 m .33729 .57075 L .33982 .5678 L F
.239 .687 .955 r
.33547 .57208 m .33793 .57291 L .33729 .57075 L F
.64 .521 .703 r
.33729 .57075 m .34046 .57119 L .33982 .5678 L F
.779 .553 .594 r
.33793 .57291 m .34046 .57119 L .33729 .57075 L F
.679 .744 .9 r
.79302 .42437 m .79547 .42316 L .79185 .42256 L F
.635 .701 .894 r
.81317 .41619 m .81463 .41218 L .81198 .41311 L F
.81317 .41619 m .81588 .41551 L .81463 .41218 L F
.529 .501 .769 r
.34231 .61064 m .33901 .60779 L .34185 .60676 L F
.345 0 .196 r
.20378 .56193 m .20297 .56367 L .20075 .56422 L F
.249 0 .15 r
.20515 .56294 m .20297 .56367 L .20378 .56193 L F
.712 .199 0 r
.28038 .64747 m .28048 .64819 L .28228 .64933 L F
0 0 0 r
.18089 .55872 m .18082 .55927 L .18269 .55737 L F
.18089 .55872 m .17883 .56012 L .18082 .55927 L F
.234 .75 .848 r
.25242 .53375 m .25238 .53422 L .25014 .53429 L F
.25242 .53375 m .25465 .53386 L .25238 .53422 L F
.679 .707 .869 r
.28865 .56923 m .28879 .57119 L .29179 .57012 L F
.568 .466 .698 r
.28879 .57119 m .29206 .57233 L .29179 .57012 L F
.28879 .57119 m .2896 .57322 L .29206 .57233 L F
.955 .947 .717 r
.3364 .57994 m .33403 .58147 L .33217 .57963 L F
.565 .325 .511 r
.28375 .62283 m .28626 .62259 L .28714 .61893 L F
.602 .361 .523 r
.28714 .61893 m .29035 .62198 L .29023 .62082 L F
.28714 .61893 m .28626 .62259 L .29035 .62198 L F
0 0 0 r
.20591 .54378 m .20627 .54295 L .20369 .54443 L F
.20591 .54378 m .20844 .54245 L .20627 .54295 L F
.503 .374 .637 r
.34438 .60984 m .34231 .61064 L .34185 .60676 L F
.442 .642 .942 r
.31088 .53315 m .31008 .53537 L .309 .5342 L F
.31088 .53315 m .3133 .53581 L .31008 .53537 L F
.643 .478 .644 r
.28771 .56461 m .29062 .56437 L .29047 .56162 L F
.589 .402 .596 r
.29062 .56437 m .29325 .561 L .29047 .56162 L F
0 .5 .846 r
.367 .55783 m .36774 .55815 L .36907 .55906 L F
.737 .788 .894 r
.37022 .55985 m .36907 .55906 L .3699 .55849 L F
0 0 .348 r
.37073 .55944 m .37055 .56121 L .37042 .56067 L F
.37073 .55944 m .37042 .56067 L .3699 .55849 L F
0 .5 .846 r
.36774 .55815 m .37073 .55944 L .36907 .55906 L F
0 0 .348 r
.37073 .55944 m .3699 .55849 L .36907 .55906 L F
.737 .788 .894 r
.37055 .56121 m .36597 .56076 L .36907 .55906 L F
.737 .908 .953 r
.36907 .55906 m .36597 .56076 L .367 .55783 L F
.702 .168 0 r
.367 .55783 m .36947 .55955 L .37073 .55944 L F
.523 .55 .825 r
.37101 .55832 m .37073 .55944 L .36947 .55955 L F
.37136 .55804 m .37073 .55944 L .37101 .55832 L F
.737 .788 .894 r
.37055 .56121 m .36907 .55906 L .37022 .55985 L F
.093 0 .398 r
.29836 .57778 m .29633 .57955 L .29662 .57695 L F
.845 .722 .728 r
.80076 .41912 m .80399 .41955 L .80285 .41596 L F
.843 .729 .738 r
.80076 .41912 m .80189 .42285 L .80399 .41955 L F
0 0 0 r
.27584 .61638 m .27691 .61421 L .27802 .6125 L F
.53 .611 .878 r
.17948 .61047 m .18309 .61308 L .18054 .61053 L F
.445 .768 .997 r
.18309 .61308 m .18605 .61205 L .18054 .61053 L F
.18309 .61308 m .18564 .61274 L .18605 .61205 L F
.459 .617 .918 r
.18309 .61308 m .18605 .6144 L .18564 .61274 L F
.32 .24 .608 r
.33565 .62549 m .33455 .63115 L .33328 .62593 L F
.665 .386 .487 r
.32513 .6409 m .3232 .63857 L .32547 .6382 L F
.32513 .6409 m .32285 .64098 L .3232 .63857 L F
.073 .03 .497 r
.28763 .58013 m .28957 .57984 L .29038 .57803 L F
.28763 .58013 m .28785 .58278 L .28957 .57984 L F
.181 0 0 r
.28991 .53277 m .29222 .53294 L .29405 .53271 L F
.243 0 0 r
.29222 .53294 m .29627 .53299 L .29405 .53271 L F
.782 .821 .883 r
.24719 .55389 m .24362 .55509 L .24603 .5538 L F
.402 0 .057 r
.24719 .55389 m .24533 .55616 L .24362 .55509 L F
.278 0 0 r
.2499 .55498 m .24533 .55616 L .24719 .55389 L F
.704 .516 .631 r
.28703 .56704 m .29062 .56437 L .28771 .56461 L F
.407 .286 .602 r
.3065 .57694 m .30849 .57326 L .30578 .57378 L F
.3065 .57694 m .30905 .57626 L .30849 .57326 L F
.181 0 .343 r
.30649 .57936 m .30905 .57626 L .3065 .57694 L F
.436 .872 .794 r
.25232 .69518 m .2521 .69578 L .25157 .69588 L F
.382 .628 .95 r
.25459 .69635 m .25157 .69588 L .2521 .69578 L F
.494 .253 .478 r
.35674 .58653 m .35474 .58933 L .354 .58939 L F
.617 .406 .572 r
.35938 .58875 m .35674 .58653 L .35901 .58508 L F
.35938 .58875 m .35474 .58933 L .35674 .58653 L F
.498 .69 .954 r
.33172 .53756 m .33057 .5394 L .32954 .53816 L F
.33172 .53756 m .33278 .53909 L .33057 .5394 L F
.545 .141 .227 r
.29023 .62082 m .2921 .62214 L .29346 .61998 L F
0 0 .399 r
.29346 .61998 m .29431 .61613 L .29292 .61677 L F
.29346 .61998 m .2945 .61876 L .29431 .61613 L F
.394 0 .141 r
.29346 .61998 m .29501 .62158 L .2945 .61876 L F
.29346 .61998 m .2921 .62214 L .29501 .62158 L F
.34 .167 .495 r
.51038 .54683 m .5117 .54617 L .51136 .54426 L F
.391 .201 .498 r
.51136 .54426 m .5117 .54617 L .51341 .54253 L F
.863 .927 .867 r
.19254 .60082 m .19062 .60352 L .19138 .60301 L F
.079 0 0 r
.21626 .55831 m .21497 .55896 L .21236 .55927 L F
.253 .754 .894 r
.21875 .55903 m .21497 .55896 L .21626 .55831 L F
.519 .373 .622 r
.25582 .69969 m .25305 .70303 L .25331 .70003 L F
.374 .082 .335 r
.25793 .6958 m .25841 .69395 L .26056 .69337 L F
.765 .989 .892 r
.27872 .59378 m .27879 .59537 L .27901 .59427 L F
0 0 .303 r
.27879 .59537 m .27939 .59705 L .27872 .59378 L F
.27879 .59537 m .27884 .59795 L .27939 .59705 L F
0 .152 .694 r
.27872 .59378 m .27879 .59537 L .27663 .59173 L F
.27663 .59173 m .27879 .59537 L .27872 .59378 L F
.61 .375 .536 r
.32614 .59508 m .3289 .59493 L .32888 .5923 L F
.458 .256 .518 r
.32888 .5923 m .33123 .5942 L .33189 .5913 L F
.32888 .5923 m .3289 .59493 L .33123 .5942 L F
.594 .859 .993 r
.28366 .53234 m .28116 .53306 L .27978 .53237 L F
.308 .515 .894 r
.31493 .5358 m .3141 .53744 L .3133 .53581 L F
.63 .898 .986 r
.31652 .53653 m .3141 .53744 L .31493 .5358 L F
.31652 .53653 m .3141 .53744 L .31493 .5358 L F
.615 .505 .706 r
.35969 .5581 m .35724 .56074 L .35727 .55877 L F
.636 .538 .726 r
.35969 .5581 m .36055 .56138 L .35724 .56074 L F
.47 .265 .519 r
.29804 .56034 m .30068 .55695 L .29935 .55857 L F
.881 .659 .597 r
.54116 .54285 m .53855 .54223 L .53868 .53957 L F
0 0 0 r
.26911 .61319 m .26673 .61683 L .26834 .61577 L F
.26834 .61577 m .26673 .61683 L .26619 .61885 L F
.293 .784 .734 r
.78045 .4028 m .7814 .40262 L .77781 .4038 L F
.62 .828 .98 r
.78313 .40012 m .7814 .40262 L .78045 .4028 L F
.78313 .40012 m .78411 .40159 L .7814 .40262 L F
.622 .446 .623 r
.3293 .57725 m .33217 .57963 L .33156 .57647 L F
.3293 .57725 m .32957 .58009 L .33217 .57963 L F
.534 .56 .828 r
.35772 .59473 m .35561 .59557 L .35409 .59289 L F
.532 .31 .523 r
.35772 .59473 m .35497 .5976 L .35561 .59557 L F
.995 .787 .508 r
.54827 .56061 m .54785 .56272 L .54929 .56351 L F
.963 .896 .71 r
.54785 .56272 m .54765 .56727 L .54929 .56351 L F
.109 0 0 r
.18365 .55623 m .18269 .55737 L .18569 .55525 L F
.155 .671 .891 r
.34277 .54064 m .34568 .5406 L .34651 .54111 L F
.729 .226 .035 r
.34568 .5406 m .34974 .54192 L .34651 .54111 L F
.39 .651 .961 r
.26861 .55621 m .26955 .55492 L .26666 .55386 L F
.204 .67 .941 r
.26955 .55492 m .26702 .55422 L .26666 .55386 L F
0 0 .436 r
.26705 .55496 m .26666 .55386 L .26621 .55341 L F
.204 .67 .941 r
.26702 .55422 m .26544 .55379 L .26666 .55386 L F
0 0 .436 r
.26621 .55341 m .26666 .55386 L .26491 .55104 L F
0 .12 .649 r
.26705 .55496 m .26861 .55621 L .26666 .55386 L F
.678 .821 .952 r
.51728 .52812 m .51805 .5285 L .51566 .52923 L F
.51728 .52812 m .5196 .52654 L .5156 .52656 L F
.51728 .52812 m .5156 .52656 L .51805 .5285 L F
.785 .623 .68 r
.31184 .60742 m .31632 .60761 L .31626 .60495 L F
.682 .541 .687 r
.31626 .60495 m .31632 .60761 L .31882 .60452 L F
.511 .526 .808 r
.33152 .56471 m .33007 .56697 L .32938 .56468 L F
.035 .369 .838 r
.19789 .62323 m .19808 .62188 L .19587 .62061 L F
.048 .384 .847 r
.19789 .62323 m .20076 .62505 L .19808 .62188 L F
.642 .341 .445 r
.31143 .64687 m .30811 .64494 L .31149 .64437 L F
.31143 .64687 m .30777 .64714 L .30811 .64494 L F
.424 .554 .882 r
.31119 .59842 m .30735 .59537 L .30962 .59579 L F
.192 .687 .918 r
.23418 .62295 m .23334 .62365 L .23149 .62283 L F
.23418 .62295 m .23556 .62368 L .23334 .62365 L F
.751 .686 .789 r
.79811 .42228 m .7992 .42584 L .80189 .42285 L F
.585 .726 .941 r
.18414 .58841 m .17962 .58661 L .18193 .58584 L F
.491 .612 .9 r
.18393 .58487 m .18414 .58841 L .18193 .58584 L F
.18393 .58487 m .18633 .58795 L .18414 .58841 L F
.604 .389 .562 r
.22489 .55531 m .22464 .55805 L .22213 .55767 L F
.652 .105 0 r
.22495 .55624 m .22489 .55531 L .2238 .55378 L F
.467 .272 .531 r
.22689 .55733 m .22464 .55805 L .22489 .55531 L F
.652 .105 0 r
.22495 .55624 m .22689 .55733 L .22489 .55531 L F
.562 .369 .577 r
.31119 .59842 m .31122 .60115 L .30871 .60143 L F
.381 .227 .545 r
.31316 .60025 m .31119 .59842 L .31372 .59791 L F
.31316 .60025 m .31122 .60115 L .31119 .59842 L F
.27 .053 .389 r
.18794 .57369 m .18705 .57379 L .18896 .57307 L F
.18794 .57369 m .18647 .57584 L .18705 .57379 L F
.436 .872 .794 r
.25232 .69518 m .25157 .69588 L .24985 .69523 L F
.372 .815 .952 r
.21983 .61803 m .21944 .61895 L .21757 .6183 L F
.21983 .61803 m .22216 .6184 L .21944 .61895 L F
.734 .571 .671 r
.53589 .53346 m .53892 .53694 L .53473 .53665 L F
.644 .399 .533 r
.33152 .63232 m .33127 .63508 L .32805 .63484 L F
.347 0 .083 r
.33455 .63115 m .33417 .63184 L .33152 .63232 L F
.537 .316 .527 r
.33417 .63184 m .33127 .63508 L .33152 .63232 L F
.389 0 .128 r
.25614 .55174 m .25453 .55411 L .25215 .55437 L F
.227 0 .035 r
.25677 .55339 m .25614 .55174 L .25847 .55133 L F
.25677 .55339 m .25453 .55411 L .25614 .55174 L F
.674 .617 .784 r
.76881 .40194 m .77062 .3969 L .76782 .39789 L F
.81 .979 .691 r
.354 .58939 m .35214 .59063 L .35217 .59181 L F
.049 .45 .878 r
.35214 .59063 m .35372 .59219 L .35217 .59181 L F
.553 .518 .77 r
.35409 .59289 m .35217 .59181 L .35372 .59219 L F
.352 .087 .365 r
.33189 .5913 m .33405 .59172 L .33459 .58877 L F
.159 0 .245 r
.33189 .5913 m .33291 .59347 L .33405 .59172 L F
.33189 .5913 m .33123 .5942 L .33291 .59347 L F
.464 0 0 r
.27271 .63283 m .27349 .63176 L .26954 .63237 L F
.057 0 0 r
.27558 .631 m .27349 .63176 L .27271 .63283 L F
.566 .874 .581 r
.34064 .54294 m .33889 .54442 L .338 .54551 L F
.589 .542 .77 r
.33889 .54442 m .33745 .54828 L .338 .54551 L F
0 .145 .669 r
.54058 .55053 m .54148 .55215 L .54034 .54833 L F
.757 .922 .556 r
.19656 .60125 m .19691 .59999 L .19815 .60186 L F
.19656 .60125 m .19466 .60347 L .19691 .59999 L F
.199 0 .19 r
.27761 .55169 m .27478 .55448 L .27567 .55256 L F
0 0 0 r
.25465 .53386 m .25705 .53336 L .2587 .53298 L F
.301 .793 .762 r
.2587 .53298 m .25908 .53265 L .26087 .53331 L F
.2587 .53298 m .25705 .53336 L .25908 .53265 L F
.36 .19 .511 r
.29552 .60162 m .29762 .60095 L .29778 .59824 L F
.403 .276 .592 r
.29552 .60162 m .29773 .60411 L .29762 .60095 L F
.29552 .60162 m .29581 .60442 L .29773 .60411 L F
.479 .544 .845 r
.77361 .41169 m .77541 .40904 L .77322 .40932 L F
.77361 .41169 m .77682 .41253 L .77541 .40904 L F
.212 0 .229 r
.17513 .56181 m .17613 .56302 L .17705 .56101 L F
.17513 .56181 m .17426 .56392 L .17613 .56302 L F
.521 .571 .847 r
.24672 .69947 m .25267 .70235 L .24899 .69924 L F
.198 .727 .763 r
.26087 .53331 m .26315 .53284 L .26482 .53263 L F
.089 .646 .705 r
.26482 .53263 m .26315 .53284 L .26715 .53235 L F
.45 .194 .432 r
.31122 .60115 m .30839 .60415 L .30871 .60143 L F
.711 .71 .848 r
.30453 .57123 m .30578 .57378 L .3066 .57075 L F
.624 .62 .826 r
.3066 .57075 m .30578 .57378 L .30849 .57326 L F
.459 0 0 r
.29118 .64935 m .29295 .64784 L .29533 .64878 L F
.463 .024 .117 r
.29295 .64784 m .29521 .64795 L .29533 .64878 L F
.589 .828 .449 r
.27129 .61028 m .26911 .61319 L .27071 .61268 L F
0 0 .084 r
.27071 .61268 m .26911 .61319 L .26834 .61577 L F
.467 .232 .473 r
.35157 .54841 m .35432 .54795 L .35456 .54584 L F
0 0 0 r
.3493 .54982 m .35432 .54795 L .35157 .54841 L F
.32 .24 .608 r
.33565 .62549 m .33592 .62999 L .33455 .63115 L F
.414 0 .115 r
.33655 .63149 m .33455 .63115 L .33592 .62999 L F
.33655 .63149 m .33417 .63184 L .33455 .63115 L F
.31 .604 .95 r
.23832 .63731 m .23958 .63875 L .2402 .6373 L F
.368 .671 .974 r
.23958 .63875 m .24193 .63876 L .2402 .6373 L F
.795 .583 .614 r
.53892 .53694 m .53512 .539 L .53473 .53665 L F
.53892 .53694 m .53868 .53957 L .53512 .539 L F
.291 .016 .313 r
.28611 .58626 m .28545 .58839 L .2882 .58546 L F
.478 .563 .863 r
.77721 .41477 m .77915 .41221 L .77682 .41253 L F
.77721 .41477 m .78066 .41555 L .77915 .41221 L F
.443 0 0 r
.14122 .66516 m .14318 .66622 L .14297 .66609 L F
.14122 .66516 m .14318 .66622 L .14297 .66609 L F
0 0 0 r
.30236 .57163 m .30192 .57134 L .30453 .57123 L F
.30236 .57163 m .30049 .57229 L .30192 .57134 L F
.425 .792 .995 r
.35615 .59116 m .35214 .59063 L .354 .58939 L F
.489 .236 .458 r
.35474 .58933 m .35615 .59116 L .354 .58939 L F
.207 0 .254 r
.51038 .54683 m .5105 .54831 L .5117 .54617 L F
.607 .45 .643 r
.34028 .61653 m .33786 .61968 L .33773 .61697 L F
.357 .724 .987 r
.25521 .63979 m .25662 .64094 L .25855 .64077 L F
.317 .213 .575 r
.15701 .58301 m .15845 .58244 L .15879 .57911 L F
.313 .203 .565 r
.15701 .58301 m .15872 .58507 L .15845 .58244 L F
.3 .2 .57 r
.15717 .58567 m .15872 .58507 L .15701 .58301 L F
0 0 .151 r
.27834 .61059 m .27993 .60743 L .27879 .61152 L F
.561 .281 .447 r
.27802 .6125 m .27834 .61059 L .27879 .61152 L F
.478 0 0 r
.2377 .62382 m .24181 .6242 L .23973 .62408 L F
.644 .18 .138 r
.31447 .60918 m .31632 .60761 L .31184 .60742 L F
.123 0 0 r
.31637 .60862 m .31632 .60761 L .31447 .60918 L F
.31637 .60862 m .31871 .60716 L .31632 .60761 L F
.521 .323 .552 r
.31632 .60761 m .31871 .60716 L .31882 .60452 L F
.29 .235 .621 r
.2896 .57322 m .29305 .57599 L .29206 .57233 L F
.2896 .57322 m .29084 .57662 L .29305 .57599 L F
.319 .295 .675 r
.29292 .61677 m .29381 .61236 L .29177 .61449 L F
.29292 .61677 m .29431 .61613 L .29381 .61236 L F
.563 .401 .619 r
.31882 .60452 m .32129 .6041 L .32121 .60132 L F
.53 .33 .553 r
.31882 .60452 m .32114 .60667 L .32129 .6041 L F
.31882 .60452 m .31871 .60716 L .32114 .60667 L F
.306 .138 .482 r
.19254 .60082 m .19221 .60369 L .19062 .60352 L F
.615 .619 .832 r
.19413 .60504 m .19062 .60352 L .19221 .60369 L F
.398 .142 .406 r
.3235 .56657 m .32314 .56994 L .32059 .57013 L F
.473 .204 .424 r
.32579 .56646 m .32314 .56994 L .3235 .56657 L F
.484 .563 .86 r
.78196 .4188 m .78312 .41529 L .78066 .41555 L F
.78196 .4188 m .78432 .41863 L .78312 .41529 L F
.63 .532 .725 r
.30689 .5645 m .30945 .56426 L .30916 .56136 L F
.983 .728 .464 r
.30945 .56426 m .30924 .5667 L .30689 .5645 L F
.63 .532 .725 r
.30689 .5645 m .30945 .56426 L .30916 .56136 L F
.592 .348 .515 r
.30689 .5645 m .30924 .5667 L .30945 .56426 L F
.993 .766 .396 r
.20649 .61566 m .20633 .6134 L .20723 .61611 L F
.195 .725 .82 r
.29316 .54501 m .29105 .54498 L .28869 .5453 L F
.642 .627 .82 r
.29316 .54501 m .29663 .54637 L .29531 .54436 L F
.674 .617 .784 r
.76881 .40194 m .77126 .40111 L .77062 .3969 L F
.483 .392 .676 r
.76881 .40194 m .77133 .40365 L .77126 .40111 L F
.76881 .40194 m .7689 .40408 L .77133 .40365 L F
.473 .258 .505 r
.34639 .59832 m .3462 .601 L .3438 .60147 L F
.678 .43 .539 r
.34886 .60058 m .3462 .601 L .34639 .59832 L F
.636 .438 .597 r
.34906 .59805 m .34886 .60058 L .34639 .59832 L F
.412 .816 .98 r
.22533 .53616 m .22936 .53633 L .22709 .53685 L F
.593 .918 .682 r
.19004 .59623 m .18857 .59775 L .19154 .59518 L F
.261 .275 .686 r
.19004 .59623 m .19121 .59962 L .18857 .59775 L F
.5 .338 .593 r
.3462 .601 m .34387 .60413 L .3438 .60147 L F
.623 .655 .861 r
.78799 .42138 m .78918 .4235 L .79185 .42256 L F
.519 .655 .92 r
.29663 .54637 m .29749 .54397 L .29531 .54436 L F
.29663 .54637 m .29845 .54592 L .29749 .54397 L F
.74 .301 .208 r
.34064 .54294 m .34332 .54536 L .33889 .54442 L F
.011 0 0 r
.22213 .55767 m .22091 .55844 L .21875 .55903 L F
.431 .856 .947 r
.22464 .55805 m .22091 .55844 L .22213 .55767 L F
.598 .492 .705 r
.80629 .41422 m .8092 .41386 L .80865 .40972 L F
.234 .393 .818 r
.18564 .61274 m .18605 .6144 L .18691 .61267 L F
.243 .404 .825 r
.18605 .6144 m .18862 .61609 L .18691 .61267 L F
.495 .803 .999 r
.2118 .63156 m .21597 .63213 L .21408 .63102 L F
.766 .666 .753 r
.2118 .63156 m .21327 .63526 L .21597 .63213 L F
.375 .746 .99 r
.21408 .63102 m .21597 .63213 L .21613 .63084 L F
.07 .432 .873 r
.21597 .63213 m .21692 .63221 L .21613 .63084 L F
0 0 0 r
.31963 .59396 m .32077 .59109 L .32076 .59427 L F
0 0 .236 r
.24038 .72829 m .24225 .72442 L .2421 .72714 L F
.092 0 .157 r
.2395 .7302 m .24038 .72829 L .2421 .72714 L F
.501 .601 .885 r
.17504 .60748 m .17948 .61047 L .17672 .60735 L F
.096 .306 .784 r
.17948 .61047 m .18015 .60902 L .17672 .60735 L F
.17948 .61047 m .18054 .61053 L .18015 .60902 L F
.589 .402 .596 r
.29062 .56437 m .29354 .56405 L .29325 .561 L F
.39 .257 .577 r
.29325 .561 m .29498 .56323 L .29468 .56105 L F
.29325 .561 m .29354 .56405 L .29498 .56323 L F
.977 .732 .498 r
.28746 .65413 m .28617 .65596 L .28378 .65566 L F
.045 .583 .852 r
.28378 .65566 m .28617 .65596 L .28523 .65575 L F
.098 0 0 r
.28251 .65557 m .28428 .65437 L .28378 .65566 L F
.977 .732 .498 r
.28746 .65413 m .28378 .65566 L .28428 .65437 L F
.045 .583 .852 r
.28378 .65566 m .28523 .65575 L .2821 .65505 L F
.098 0 0 r
.2817 .65613 m .28251 .65557 L .28378 .65566 L F
.598 .451 .653 r
.28659 .64974 m .28428 .65437 L .28385 .64984 L F
.28659 .64974 m .28746 .65413 L .28428 .65437 L F
.081 0 0 r
.27389 .54571 m .27169 .54753 L .26964 .54797 L F
.812 .579 .586 r
.27614 .54521 m .27169 .54753 L .27389 .54571 L F
.869 .49 .008 r
.24751 .55077 m .24616 .54844 L .24849 .54905 L F
.423 .467 .801 r
.7689 .40408 m .77225 .40583 L .77133 .40365 L F
0 0 0 r
.19444 .54907 m .1946 .54988 L .19654 .54826 L F
.19444 .54907 m .1925 .55077 L .1946 .54988 L F
.27362 .60694 m .27129 .61028 L .27289 .60928 L F
0 0 .059 r
.27289 .60928 m .27129 .61028 L .27071 .61268 L F
.069 0 0 r
.17229 .56475 m .17107 .56617 L .17426 .56392 L F
.385 .72 .989 r
.32765 .53668 m .32627 .5379 L .32491 .53654 L F
.32765 .53668 m .32954 .53816 L .32627 .5379 L F
.311 .028 .312 r
.26561 .68445 m .26836 .68159 L .26801 .68444 L F
.568 .239 .372 r
.26801 .68444 m .26836 .68159 L .27027 .68354 L F
.648 .965 .907 r
.2686 .68079 m .26836 .68159 L .26704 .68156 L F
0 .132 .678 r
.27027 .68354 m .26836 .68159 L .2686 .68079 L F
.591 .287 .423 r
.31984 .64326 m .317 .64168 L .32039 .6412 L F
.31984 .64326 m .31657 .64375 L .317 .64168 L F
.579 .594 .832 r
.31034 .60398 m .30971 .60806 L .30839 .60415 L F
.31034 .60398 m .31184 .60742 L .30971 .60806 L F
.647 .219 .216 r
.29919 .64769 m .29533 .64878 L .29521 .64795 L F
.907 .501 .194 r
.29702 .65125 m .2971 .64954 L .29728 .65162 L F
.647 .219 .216 r
.29716 .64826 m .2971 .64954 L .29533 .64878 L F
0 .353 .724 r
.29533 .64878 m .2971 .64954 L .2951 .64848 L F
.907 .501 .194 r
.2951 .64848 m .2971 .64954 L .29702 .65125 L F
.647 .219 .216 r
.29919 .64769 m .2971 .64954 L .29716 .64826 L F
.619 .184 .192 r
.30127 .64951 m .2971 .64954 L .29919 .64769 L F
.568 .21 .321 r
.30174 .64767 m .30127 .64951 L .29919 .64769 L F
.465 .737 .987 r
.19466 .60347 m .19413 .60504 L .19221 .60369 L F
.308 .57 .932 r
.17171 .60417 m .17223 .60265 L .16791 .60153 L F
.17171 .60417 m .17306 .60418 L .17223 .60265 L F
0 0 0 r
.27499 .65373 m .27154 .6549 L .27353 .65563 L F
.502 .471 .755 r
.28132 .62524 m .2824 .62902 L .28449 .62856 L F
.645 .468 .629 r
.28224 .63084 m .28449 .62856 L .2824 .62902 L F
.743 .738 .847 r
.54088 .57094 m .54293 .57342 L .54585 .57081 L F
.298 .134 .483 r
.15879 .57911 m .16063 .57589 L .15894 .57643 L F
.368 .796 .97 r
.24985 .64081 m .25048 .63995 L .24846 .63997 L F
.24985 .64081 m .25224 .64053 L .25048 .63995 L F
.946 .704 .539 r
.33864 .56417 m .33749 .56132 L .33791 .56119 L F
.935 .804 .344 r
.33791 .56119 m .33749 .56132 L .33743 .55979 L F
.448 .216 .469 r
.32121 .60132 m .3235 .60073 L .32379 .59829 L F
.52 .352 .594 r
.32379 .59829 m .32617 .59775 L .32614 .59508 L F
.592 .392 .579 r
.3235 .60073 m .32617 .59775 L .32379 .59829 L F
.408 .395 .733 r
.33459 .58877 m .33574 .58543 L .3346 .58327 L F
.33459 .58877 m .33684 .58819 L .33574 .58543 L F
.396 .124 .379 r
.33459 .58877 m .33615 .59103 L .33684 .58819 L F
.33459 .58877 m .33405 .59172 L .33615 .59103 L F
.636 .856 .983 r
.28228 .64933 m .28659 .64974 L .28385 .64984 L F
.28228 .64933 m .28659 .64974 L .28385 .64984 L F
.319 .263 .637 r
.28934 .65278 m .28659 .64974 L .28951 .65025 L F
.28934 .65278 m .28746 .65413 L .28659 .64974 L F
.418 .292 .601 r
.29661 .59232 m .29855 .59168 L .29908 .58826 L F
.429 .317 .625 r
.29661 .59232 m .29894 .59458 L .29855 .59168 L F
.29661 .59232 m .29695 .59509 L .29894 .59458 L F
.728 .656 .778 r
.3363 .56601 m .33982 .5678 L .33764 .56642 L F
.811 .902 .493 r
.5389 .56114 m .53704 .56508 L .53749 .56308 L F
.78 .84 .38 r
.53749 .56308 m .53704 .56508 L .5368 .56511 L F
.702 .247 0 r
.53704 .56508 m .53796 .56658 L .5368 .56511 L F
.759 .586 .662 r
.32285 .64098 m .31984 .64326 L .32039 .6412 L F
.283 .344 .75 r
.15824 .59176 m .15916 .59542 L .16071 .59383 L F
.276 .294 .699 r
.15994 .59783 m .16071 .59383 L .15916 .59542 L F
.596 .502 .719 r
.32814 .63751 m .32547 .6382 L .32546 .63526 L F
.696 .546 .679 r
.32814 .63751 m .32513 .6409 L .32547 .6382 L F
.445 .209 .462 r
.34677 .60415 m .3432 .60671 L .34387 .60413 L F
.34677 .60415 m .34672 .60643 L .3432 .60671 L F
.444 .317 .612 r
.34672 .60825 m .3432 .60671 L .34672 .60643 L F
.34672 .60825 m .34438 .60984 L .3432 .60671 L F
.634 .274 .343 r
.31873 .58755 m .32382 .58871 L .32126 .58664 L F
.74 .49 .553 r
.36743 .54911 m .36437 .5463 L .36536 .54439 L F
.36743 .54911 m .36378 .54905 L .36437 .5463 L F
.496 .269 .499 r
.30913 .54594 m .31165 .54896 L .3087 .54856 L F
.654 .139 0 r
.30938 .54684 m .30913 .54594 L .3087 .54856 L F
.30918 .54613 m .31165 .54896 L .30913 .54594 L F
.3111 .54845 m .31165 .54896 L .30918 .54613 L F
.444 0 .091 r
.3087 .54856 m .30988 .54988 L .31165 .54896 L F
.654 .139 0 r
.30938 .54684 m .3111 .54845 L .30918 .54613 L F
.746 .697 .805 r
.30938 .54684 m .31165 .54896 L .31366 .54737 L F
.753 .993 .87 r
.31165 .54896 m .30988 .54988 L .31366 .54737 L F
.562 .265 .422 r
.31143 .54885 m .31293 .54942 L .31366 .54737 L F
.30988 .54988 m .31202 .54956 L .31143 .54885 L F
.31202 .54956 m .31293 .54942 L .31143 .54885 L F
.635 .141 .06 r
.2477 .62604 m .25159 .62701 L .24953 .62653 L F
.038 .2 .704 r
.53912 .57049 m .54008 .56902 L .53796 .56658 L F
.228 .468 .88 r
.53912 .57049 m .54088 .57094 L .54008 .56902 L F
.034 .118 .622 r
.19378 .61916 m .19362 .62057 L .19455 .61864 L F
.485 .561 .858 r
.19362 .62057 m .19587 .62061 L .19455 .61864 L F
.92 .622 .463 r
.55254 .52993 m .55269 .53266 L .55487 .53295 L F
.996 .823 .552 r
.55269 .53266 m .55347 .53639 L .55487 .53295 L F
.334 .671 .976 r
.3006 .53279 m .29999 .53417 L .29834 .53331 L F
.3006 .53279 m .30233 .53424 L .29999 .53417 L F
.108 .66 .707 r
.5302 .52272 m .53322 .52228 L .53462 .52209 L F
.173 0 0 r
.53462 .52209 m .53322 .52228 L .5375 .52252 L F
.34 .288 .653 r
.26801 .68444 m .26779 .68673 L .26561 .68445 L F
.466 .305 .579 r
.26779 .68673 m .26567 .68758 L .26561 .68445 L F
.225 .419 .843 r
.17306 .60418 m .17504 .60748 L .17584 .6057 L F
.373 .599 .935 r
.17504 .60748 m .17672 .60735 L .17584 .6057 L F
.521 .649 .914 r
.23893 .73718 m .23482 .73502 L .23663 .73483 L F
.268 0 .013 r
.23471 .73994 m .23893 .73718 L .23711 .73937 L F
.436 .686 .97 r
.23956 .73555 m .23893 .73718 L .23663 .73483 L F
.756 .919 .551 r
.23711 .73937 m .23893 .73718 L .23956 .73555 L F
.624 .059 0 r
.23851 .7228 m .23835 .72165 L .2368 .72346 L F
.409 .047 .234 r
.53204 .53027 m .5322 .53252 L .52968 .53296 L F
.705 .27 .214 r
.53513 .53269 m .53204 .53027 L .53603 .52982 L F
.53513 .53269 m .5322 .53252 L .53204 .53027 L F
.361 .522 .882 r
.2008 .60263 m .20011 .6048 L .19815 .60186 L F
.531 .708 .952 r
.2008 .60263 m .20218 .60438 L .20011 .6048 L F
0 0 0 r
.18647 .57584 m .18498 .57947 L .18457 .5773 L F
.486 .316 .575 r
.32121 .60132 m .32348 .60342 L .3235 .60073 L F
.454 .316 .602 r
.32121 .60132 m .32129 .6041 L .32348 .60342 L F
.036 0 .341 r
.28151 .60866 m .27993 .60743 L .28191 .60615 L F
.28151 .60866 m .27879 .61152 L .27993 .60743 L F
.408 .215 .505 r
.34046 .57119 m .34272 .57266 L .34062 .57091 L F
.607 .131 .098 r
.34062 .57091 m .34576 .57269 L .34608 .57021 L F
.779 .553 .594 r
.33793 .57291 m .33995 .57452 L .34046 .57119 L F
.408 .215 .505 r
.34046 .57119 m .33995 .57452 L .34272 .57266 L F
.8 .611 .646 r
.33793 .57291 m .33918 .57509 L .33995 .57452 L F
.642 .967 .87 r
.33918 .57509 m .34272 .57266 L .33995 .57452 L F
.33918 .57509 m .33864 .57428 L .34272 .57266 L F
.173 0 0 r
.34272 .57266 m .33864 .57428 L .34041 .57386 L F
0 0 .103 r
.34608 .57021 m .34576 .57269 L .34662 .57105 L F
.607 .131 .098 r
.34391 .57205 m .34272 .57266 L .34576 .57269 L F
.173 0 0 r
.34272 .57266 m .34587 .57258 L .34576 .57269 L F
.34272 .57266 m .34041 .57386 L .34587 .57258 L F
.607 .131 .098 r
.34062 .57091 m .34272 .57266 L .34391 .57205 L F
0 0 .118 r
.29089 .55407 m .29239 .55068 L .29152 .55078 L F
.753 .682 .782 r
.79811 .42228 m .80189 .42285 L .80076 .41912 L F
.704 .516 .631 r
.28703 .56704 m .29082 .56711 L .29062 .56437 L F
.567 .394 .606 r
.29082 .56711 m .29354 .56405 L .29062 .56437 L F
.49 .472 .765 r
.29089 .55407 m .28922 .55781 L .29134 .55709 L F
.558 .88 .991 r
.27681 .589 m .27743 .58765 L .27927 .58825 L F
.212 .074 .465 r
.27681 .589 m .27874 .59024 L .27743 .58765 L F
.27681 .589 m .27663 .59173 L .27874 .59024 L F
.655 .433 .57 r
.2976 .58375 m .29467 .58567 L .29635 .58161 L F
.552 .6 .855 r
.29836 .57778 m .29635 .58161 L .29633 .57955 L F
.29836 .57778 m .30102 .58238 L .29635 .58161 L F
.506 .2 .381 r
.30102 .58238 m .2976 .58375 L .29635 .58161 L F
.561 .122 .164 r
.29035 .62198 m .2921 .62214 L .29023 .62082 L F
.166 0 0 r
.26715 .53235 m .2694 .53272 L .2711 .53286 L F
.141 .683 .823 r
.2711 .53286 m .2694 .53272 L .27339 .53272 L F
.565 .598 .845 r
.78523 .42092 m .78684 .41796 L .78432 .41863 L F
.78523 .42092 m .78799 .42138 L .78684 .41796 L F
.805 .997 .856 r
.31299 .5912 m .31363 .59251 L .31491 .59122 L F
.31299 .5912 m .31077 .59319 L .31363 .59251 L F
.714 .969 .933 r
.24603 .5538 m .24362 .55509 L .24411 .55336 L F
.823 .98 .886 r
.24603 .5538 m .24705 .5509 L .24751 .55077 L F
.24603 .5538 m .24411 .55336 L .24705 .5509 L F
.663 .471 .615 r
.31399 .64409 m .31143 .64687 L .31149 .64437 L F
.511 .526 .808 r
.33152 .56471 m .33193 .56657 L .33007 .56697 L F
.841 .85 .851 r
.22338 .74081 m .21923 .74248 L .22147 .74247 L F
.123 0 0 r
.22358 .74187 m .22338 .74081 L .22147 .74247 L F
.539 .643 .901 r
.22757 .74239 m .22338 .74081 L .22612 .73992 L F
.123 0 0 r
.22358 .74187 m .22612 .73992 L .22338 .74081 L F
.117 .666 .803 r
.27339 .53272 m .27573 .5326 L .27749 .53271 L F
.503 .899 .94 r
.27749 .53271 m .27795 .53171 L .27978 .53237 L F
.27749 .53271 m .27573 .5326 L .27795 .53171 L F
.959 .655 .233 r
.2238 .55378 m .22392 .55228 L .22592 .55174 L F
.894 .841 .785 r
.53512 .539 m .53549 .53468 L .53473 .53665 L F
.698 .164 0 r
.26606 .66517 m .26404 .66287 L .26383 .66276 L F
.584 .28 .418 r
.26606 .66517 m .26697 .66287 L .26404 .66287 L F
.606 .439 .63 r
.33772 .62224 m .33524 .62002 L .33786 .61968 L F
.33772 .62224 m .33522 .62295 L .33524 .62002 L F
.722 .81 .92 r
.15932 .60051 m .16123 .60181 L .16356 .60056 L F
.794 .94 .585 r
.24362 .55509 m .24184 .55702 L .24411 .55336 L F
.405 0 .045 r
.24533 .55616 m .24184 .55702 L .24362 .55509 L F
.798 .497 .48 r
.7892 .41501 m .79285 .4137 L .78935 .41251 L F
.7892 .41501 m .793 .41578 L .79285 .4137 L F
.479 .789 .999 r
.30508 .53402 m .30383 .53525 L .30233 .53424 L F
.30508 .53402 m .30631 .53505 L .30383 .53525 L F
0 0 .43 r
.52798 .5301 m .52575 .527 L .5299 .52763 L F
.52798 .5301 m .52731 .52913 L .52575 .527 L F
.85 .394 .1 r
.52798 .5301 m .52742 .53162 L .52731 .52913 L F
.52798 .5301 m .52968 .53296 L .52742 .53162 L F
.179 0 0 r
.25159 .62701 m .25379 .62682 L .25585 .62575 L F
.472 .852 .631 r
.25585 .62575 m .25685 .62488 L .25775 .62432 L F
.473 .869 .69 r
.25585 .62575 m .25379 .62682 L .25685 .62488 L F
.866 .915 .861 r
.27703 .66272 m .2744 .66605 L .27238 .66527 L F
.33 .075 .368 r
.27262 .67102 m .2744 .66605 L .2764 .66534 L F
.284 .785 .84 r
.22936 .53633 m .23158 .53581 L .2332 .53574 L F
.05 .617 .718 r
.2332 .53574 m .23158 .53581 L .23552 .5356 L F
.399 .21 .506 r
.27757 .67413 m .27576 .67228 L .27777 .6715 L F
.512 .304 .534 r
.27777 .6715 m .2802 .67097 L .27757 .67413 L F
.57 .834 .478 r
.27757 .67413 m .27868 .67268 L .27714 .6724 L F
.27609 .67271 m .27714 .6724 L .27544 .67209 L F
.27757 .67413 m .27714 .6724 L .27609 .67271 L F
0 0 0 r
.27229 .67443 m .27408 .67332 L .27397 .67388 L F
.27408 .67332 m .27576 .67228 L .27486 .67309 L F
.27408 .67332 m .27486 .67309 L .27397 .67388 L F
.651 .189 .143 r
.27397 .67388 m .27576 .67228 L .27757 .67413 L F
.555 .656 .903 r
.27777 .6715 m .27576 .67228 L .27354 .66977 L F
0 .034 .603 r
.35577 .59021 m .35474 .58933 L .35938 .58875 L F
.35577 .59021 m .35615 .59116 L .35474 .58933 L F
.963 .718 .518 r
.24024 .72643 m .2421 .72714 L .24225 .72442 L F
.811 .902 .493 r
.5389 .56114 m .53749 .56308 L .53886 .56025 L F
.596 .502 .719 r
.32814 .63751 m .32546 .63526 L .32805 .63484 L F
.914 .815 .735 r
.54414 .5697 m .54765 .56727 L .54646 .56633 L F
.54414 .5697 m .54585 .57081 L .54765 .56727 L F
.963 .896 .71 r
.54785 .56272 m .54646 .56633 L .54765 .56727 L F
.029 .218 .723 r
.20422 .60622 m .20354 .60791 L .20218 .60438 L F
.091 .238 .723 r
.20422 .60622 m .20426 .60961 L .20354 .60791 L F
.679 .707 .869 r
.28865 .56923 m .29179 .57012 L .29082 .56711 L F
.574 .537 .776 r
.29179 .57012 m .29332 .5669 L .29082 .56711 L F
.29179 .57012 m .29436 .56957 L .29332 .5669 L F
.432 .243 .521 r
.29206 .57233 m .29436 .56957 L .29179 .57012 L F
.836 .744 .763 r
.25793 .6958 m .25776 .69951 L .25582 .69969 L F
.426 .133 .362 r
.25776 .69951 m .25565 .7026 L .25582 .69969 L F
.25776 .69951 m .25798 .70213 L .25565 .7026 L F
.386 .36 .707 r
.26037 .69888 m .25776 .69951 L .25793 .6958 L F
.28 .035 .352 r
.25987 .7013 m .25776 .69951 L .26037 .69888 L F
.25987 .7013 m .25798 .70213 L .25776 .69951 L F
.083 .545 .905 r
.33921 .53893 m .34157 .53958 L .34277 .54064 L F
.358 .633 .958 r
.3436 .5389 m .34277 .54064 L .34157 .53958 L F
.3436 .5389 m .34568 .5406 L .34277 .54064 L F
.155 0 0 r
.20125 .56565 m .20075 .56422 L .20297 .56367 L F
.20125 .56565 m .1991 .56643 L .20075 .56422 L F
.483 .338 .608 r
.36083 .57955 m .36098 .58232 L .35876 .58282 L F
.572 .485 .717 r
.36098 .58232 m .35901 .58508 L .35876 .58282 L F
.746 .703 .811 r
.31421 .59562 m .30962 .59579 L .31195 .59625 L F
.616 .055 0 r
.23075 .63666 m .22795 .63515 L .22806 .63611 L F
.23196 .63732 m .23015 .63653 L .22795 .63515 L F
0 .463 .709 r
.23364 .63725 m .2324 .63697 L .23015 .63653 L F
.23416 .63736 m .23401 .63733 L .23364 .63725 L F
.23401 .63733 m .2324 .63697 L .23364 .63725 L F
.616 .055 0 r
.23196 .63732 m .23075 .63666 L .22813 .63672 L F
.23075 .63666 m .22806 .63611 L .22813 .63672 L F
.976 .9 .675 r
.54148 .55215 m .54033 .55427 L .53957 .55308 L F
.978 .704 .309 r
.54148 .55215 m .54045 .55106 L .54034 .54833 L F
.977 .898 .674 r
.54148 .55215 m .53957 .55308 L .54045 .55106 L F
.573 .904 .98 r
.52575 .527 m .52233 .52743 L .52307 .52693 L F
.523 .562 .837 r
.35615 .59116 m .35409 .59289 L .35372 .59219 L F
.35615 .59116 m .35772 .59473 L .35409 .59289 L F
.951 .858 .713 r
.55112 .54456 m .5537 .54251 L .55261 .54128 L F
.55112 .54456 m .5525 .54566 L .5537 .54251 L F
.571 .75 .961 r
.27274 .64577 m .27646 .64663 L .2746 .64469 L F
.515 .727 .969 r
.2746 .64469 m .27646 .64663 L .27873 .64625 L F
.225 .742 .857 r
.23552 .5356 m .23785 .5353 L .23931 .53542 L F
.029 0 0 r
.23785 .5353 m .24151 .53492 L .23931 .53542 L F
.486 .263 .5 r
.28132 .62524 m .28355 .62488 L .28375 .62283 L F
.502 .471 .755 r
.28132 .62524 m .28449 .62856 L .28355 .62488 L F
.139 0 0 r
.21497 .55896 m .21048 .56021 L .21236 .55927 L F
.038 .587 .834 r
.32107 .53581 m .32491 .53654 L .32287 .53619 L F
.445 .428 .746 r
.32314 .56994 m .32326 .5727 L .32059 .57013 L F
.484 .434 .726 r
.32059 .57013 m .32326 .5727 L .32145 .57273 L F
.351 .602 .942 r
.26597 .64394 m .26674 .64229 L .26263 .64277 L F
.26597 .64394 m .26812 .64417 L .26674 .64229 L F
.196 .246 .688 r
.36178 .56014 m .36055 .56138 L .35969 .5581 L F
.703 .514 .63 r
.36325 .56399 m .36055 .56138 L .36178 .56014 L F
.36325 .56399 m .3612 .56449 L .36055 .56138 L F
.582 .87 .995 r
.31893 .53563 m .31652 .53653 L .31721 .53486 L F
.6 .888 .99 r
.31652 .53653 m .31493 .5358 L .31721 .53486 L F
.707 .554 .678 r
.35151 .59752 m .34886 .60058 L .34906 .59805 L F
.473 .275 .53 r
.77454 .40384 m .77126 .40111 L .77133 .40365 L F
.519 .373 .622 r
.25582 .69969 m .25565 .7026 L .25305 .70303 L F
.476 .231 .464 r
.25305 .70303 m .25565 .7026 L .25293 .70533 L F
.868 .904 .855 r
.25293 .70533 m .25325 .70184 L .25305 .70303 L F
.488 .327 .589 r
.32614 .59508 m .32841 .59723 L .3289 .59493 L F
.32614 .59508 m .32617 .59775 L .32841 .59723 L F
.747 .992 .874 r
.27054 .65479 m .27154 .6549 L .26919 .65658 L F
.304 0 0 r
.27353 .65563 m .27154 .6549 L .27054 .65479 L F
.522 .89 .972 r
.17973 .74465 m .18218 .74491 L .17936 .74581 L F
.17973 .74465 m .18218 .74491 L .17936 .74581 L F
0 0 .56 r
.18807 .58966 m .18912 .59405 L .18763 .59183 L F
.084 0 0 r
.16605 .56984 m .16774 .56927 L .16919 .56722 L F
.246 0 .046 r
.16919 .56722 m .16997 .56866 L .17107 .56617 L F
.16919 .56722 m .16774 .56927 L .16997 .56866 L F
.565 .565 .812 r
.31776 .58843 m .31548 .58925 L .31382 .58507 L F
.501 .238 .448 r
.31548 .58925 m .3174 .59063 L .31776 .58843 L F
.31548 .58925 m .3174 .59063 L .31776 .58843 L F
.618 .704 .906 r
.81588 .41551 m .81731 .41152 L .81463 .41218 L F
.81588 .41551 m .81847 .41337 L .81731 .41152 L F
.61 .687 .898 r
.81935 .41628 m .81847 .41337 L .81588 .41551 L F
.129 .432 .872 r
.24864 .71354 m .24957 .71525 L .25004 .71382 L F
.588 .418 .619 r
.25224 .7119 m .25245 .71554 L .24957 .71525 L F
.204 0 0 r
.24957 .71525 m .25245 .71554 L .25175 .71563 L F
.18 .493 .904 r
.25004 .71382 m .24957 .71525 L .25175 .71563 L F
.502 .312 .556 r
.34021 .61914 m .33786 .61968 L .34028 .61653 L F
.611 .395 .563 r
.34029 .62176 m .33786 .61968 L .34021 .61914 L F
.34029 .62176 m .33772 .62224 L .33786 .61968 L F
.718 .707 .839 r
.79185 .42256 m .79547 .42316 L .79439 .42146 L F
.682 .693 .854 r
.79439 .42146 m .79547 .42316 L .79811 .42228 L F
.786 .711 .781 r
.37055 .56121 m .36742 .56441 L .36597 .56076 L F
.572 .372 .571 r
.37055 .56121 m .3702 .56421 L .36742 .56441 L F
0 .097 .651 r
.37073 .55944 m .37236 .5632 L .37055 .56121 L F
.389 .214 .52 r
.37236 .5632 m .3702 .56421 L .37055 .56121 L F
0 0 0 r
.28628 .54548 m .2847 .54805 L .28388 .54885 L F
.437 .873 .903 r
.2847 .54805 m .28289 .54865 L .28388 .54885 L F
0 0 0 r
.30073 .58266 m .29844 .58574 L .29929 .58502 L F
.1 .059 .519 r
.29844 .58574 m .29945 .58737 L .29962 .58474 L F
.29945 .58737 m .29967 .58619 L .29962 .58474 L F
0 0 0 r
.30023 .58359 m .29929 .58502 L .29962 .58474 L F
.974 .909 .683 r
.29975 .58423 m .29939 .58705 L .2976 .58375 L F
.29974 .58581 m .29939 .58705 L .29975 .58423 L F
0 .007 .533 r
.29908 .58826 m .29939 .58827 L .29844 .58574 L F
.29939 .58827 m .30001 .58828 L .29945 .58737 L F
.29939 .58827 m .29945 .58737 L .29844 .58574 L F
.663 .363 .453 r
.29939 .58705 m .29819 .5867 L .29832 .5865 L F
.29915 .58661 m .29841 .58636 L .29874 .58585 L F
.974 .909 .683 r
.29949 .58672 m .29726 .58597 L .29939 .58705 L F
.29974 .58581 m .29954 .58583 L .29949 .58672 L F
.29954 .58583 m .29726 .58597 L .29949 .58672 L F
.333 .226 .58 r
.29962 .58474 m .29996 .5849 L .29997 .58456 L F
.974 .909 .683 r
.29997 .58428 m .29974 .58581 L .29975 .58423 L F
.30016 .58433 m .29995 .58508 L .29997 .58428 L F
.333 .226 .58 r
.29996 .5849 m .30001 .58828 L .302 .5858 L F
.29962 .58474 m .29974 .5859 L .29996 .5849 L F
.974 .909 .683 r
.29995 .58508 m .29982 .58555 L .29996 .5849 L F
.333 .226 .58 r
.29974 .5859 m .30001 .58828 L .29996 .5849 L F
.974 .909 .683 r
.29996 .5849 m .29974 .58581 L .29997 .58428 L F
.29982 .58555 m .29974 .58581 L .29996 .5849 L F
.333 .226 .58 r
.29997 .58456 m .302 .5858 L .30173 .58366 L F
.29996 .5849 m .29999 .58491 L .29997 .58456 L F
.974 .909 .683 r
.29995 .58508 m .30001 .58441 L .29974 .58581 L F
.30016 .58433 m .30013 .58435 L .29995 .58508 L F
.333 .226 .58 r
.29999 .58491 m .30006 .58462 L .29997 .58456 L F
.974 .909 .683 r
.30013 .58435 m .30001 .58441 L .29995 .58508 L F
.333 .226 .58 r
.29999 .58491 m .302 .5858 L .30006 .58462 L F
.663 .363 .453 r
.29874 .58585 m .29467 .58567 L .2976 .58375 L F
.29819 .5867 m .29467 .58567 L .29874 .58585 L F
0 0 0 r
.30073 .58266 m .29929 .58502 L .30023 .58359 L F
.974 .909 .683 r
.30001 .58441 m .29726 .58597 L .29974 .58581 L F
.1 .059 .519 r
.29945 .58737 m .29974 .58785 L .29967 .58619 L F
.29974 .58785 m .30001 .58828 L .29974 .5859 L F
.29974 .58785 m .29974 .5859 L .29962 .58474 L F
.328 .488 .866 r
.23244 .72413 m .23593 .72699 L .23438 .72367 L F
0 0 0 r
.27006 .6251 m .26838 .62838 L .26949 .6262 L F
.813 .884 .896 r
.81935 .41628 m .82121 .41219 L .81847 .41337 L F
.81935 .41628 m .82248 .4136 L .82121 .41219 L F
.594 .859 .993 r
.28366 .53234 m .27978 .53237 L .28207 .53162 L F
.396 .798 .984 r
.28428 .53133 m .28366 .53234 L .28207 .53162 L F
.28428 .53133 m .28604 .53201 L .28366 .53234 L F
.726 .682 .808 r
.36597 .56076 m .36742 .56441 L .36325 .56399 L F
.647 .455 .609 r
.36708 .56579 m .36325 .56399 L .36742 .56441 L F
.496 .116 .249 r
.36742 .56441 m .36936 .56575 L .36708 .56579 L F
.489 .121 .267 r
.3702 .56421 m .36936 .56575 L .36742 .56441 L F
.547 .715 .95 r
.20128 .62667 m .2023 .6247 L .20076 .62505 L F
.20128 .62667 m .20411 .62627 L .2023 .6247 L F
.476 .345 .622 r
.51111 .55105 m .5084 .54884 L .5105 .54831 L F
.51111 .55105 m .50877 .55198 L .5084 .54884 L F
0 0 .372 r
.5084 .54884 m .50965 .5506 L .5105 .54831 L F
.5084 .54884 m .50877 .55198 L .50965 .5506 L F
.245 .234 .648 r
.27054 .65479 m .26919 .65658 L .27106 .65876 L F
.461 .328 .614 r
.34438 .60984 m .34251 .61336 L .34231 .61064 L F
.569 .335 .521 r
.28355 .62488 m .28626 .62259 L .28375 .62283 L F
.121 0 0 r
.23663 .73483 m .23482 .73502 L .23371 .7363 L F
.642 .527 .708 r
.32957 .58009 m .32975 .58271 L .33217 .57963 L F
.021 .395 .851 r
.33056 .58199 m .32975 .58271 L .32766 .58436 L F
.31 0 0 r
.33574 .58543 m .33187 .58545 L .3346 .58327 L F
0 0 0 r
.33187 .58545 m .32831 .58668 L .32977 .58497 L F
.31 0 0 r
.33574 .58543 m .33353 .58612 L .33187 .58545 L F
0 0 0 r
.32903 .58643 m .33017 .58629 L .32831 .58668 L F
.33187 .58545 m .3309 .58593 L .32903 .58643 L F
.3309 .58593 m .33017 .58629 L .32903 .58643 L F
.547 .421 .66 r
.33387 .58514 m .33541 .58514 L .33527 .58485 L F
.308 0 0 r
.33353 .58612 m .3335 .58612 L .33187 .58545 L F
.3335 .58612 m .33017 .58629 L .3309 .58593 L F
.3335 .58612 m .3309 .58593 L .33187 .58545 L F
.547 .421 .66 r
.33028 .58589 m .33172 .58571 L .33387 .58514 L F
.3294 .58607 m .33049 .5859 L .33028 .58589 L F
.33049 .5859 m .33172 .58571 L .33028 .58589 L F
.33172 .58571 m .33541 .58514 L .33387 .58514 L F
.777 .773 .849 r
.3316 .58371 m .3346 .58327 L .32977 .58497 L F
.561 .208 .328 r
.32977 .58497 m .3346 .58327 L .33187 .58545 L F
.775 .874 .92 r
.33403 .58147 m .3316 .58371 L .33056 .58199 L F
.33403 .58147 m .33056 .58199 L .3334 .58097 L F
.547 .421 .66 r
.33193 .58285 m .33527 .58485 L .3334 .58097 L F
.021 .395 .851 r
.33053 .58202 m .3316 .58371 L .32975 .58271 L F
.33061 .58207 m .3316 .58371 L .33053 .58202 L F
.547 .421 .66 r
.3294 .58607 m .33527 .58485 L .33193 .58285 L F
.021 .395 .851 r
.33056 .58199 m .33061 .58207 L .33053 .58202 L F
.253 .754 .894 r
.21875 .55903 m .21653 .55864 L .21497 .55896 L F
.256 .763 .865 r
.22091 .55844 m .21653 .55864 L .21875 .55903 L F
.532 .344 .571 r
.26285 .6643 m .26367 .66812 L .26383 .66276 L F
.321 .787 .671 r
.22353 .74423 m .22757 .74239 L .22599 .74347 L F
.656 .508 .67 r
.23052 .74068 m .22757 .74239 L .22612 .73992 L F
.23052 .74068 m .22978 .74281 L .22757 .74239 L F
.261 0 0 r
.22757 .74239 m .22826 .74278 L .22599 .74347 L F
.22757 .74239 m .22978 .74281 L .22826 .74278 L F
.991 .804 .557 r
.78564 .40502 m .78731 .4039 L .78601 .4026 L F
.78564 .40502 m .78688 .40668 L .78731 .4039 L F
.358 .048 .295 r
.29381 .61236 m .29709 .60895 L .2941 .61059 L F
.574 .169 .237 r
.18498 .57947 m .1836 .58328 L .17996 .58163 L F
0 0 0 r
.18647 .57584 m .18542 .57844 L .18498 .57947 L F
.76 .78 .28 r
.18439 .58057 m .18498 .57947 L .18542 .57844 L F
.18439 .58057 m .1836 .58328 L .18498 .57947 L F
.572 .478 .709 r
.3633 .56668 m .36462 .56961 L .3603 .56847 L F
.547 .414 .651 r
.36448 .57246 m .36203 .5731 L .3603 .56847 L F
.04 .021 .505 r
.28785 .58278 m .28906 .58429 L .28957 .57984 L F
.28785 .58278 m .2882 .58546 L .28906 .58429 L F
.278 0 0 r
.2499 .55498 m .24778 .55607 L .24533 .55616 L F
.215 0 0 r
.25215 .55437 m .24778 .55607 L .2499 .55498 L F
.194 .025 .411 r
.32326 .5727 m .32231 .57468 L .32145 .57273 L F
.181 0 .343 r
.30649 .57936 m .30841 .57854 L .30905 .57626 L F
.354 .062 .323 r
.30649 .57936 m .308 .58119 L .30841 .57854 L F
.30649 .57936 m .3058 .58201 L .308 .58119 L F
.465 .44 .746 r
.29695 .59509 m .29778 .59824 L .2999 .59665 L F
.421 .285 .589 r
.29762 .60095 m .2999 .59665 L .29778 .59824 L F
0 .241 .684 r
.25327 .71246 m .25224 .7119 L .25018 .71027 L F
.25327 .71246 m .25018 .71027 L .25021 .71029 L F
.25327 .71246 m .25015 .71024 L .25274 .70799 L F
.5 .401 .674 r
.25004 .71382 m .25214 .7142 L .25167 .71119 L F
.25116 .71087 m .25167 .71119 L .25148 .71002 L F
.25004 .71382 m .25167 .71119 L .25116 .71087 L F
0 .241 .684 r
.25021 .71029 m .25018 .71027 L .25015 .71024 L F
.018 .195 .705 r
.25327 .71246 m .25451 .71457 L .25224 .7119 L F
.465 .325 .606 r
.25451 .71457 m .25245 .71554 L .25224 .7119 L F
.504 .451 .731 r
.36203 .5731 m .36045 .57598 L .35968 .57398 L F
.36203 .5731 m .36276 .57594 L .36045 .57598 L F
.367 .3 .649 r
.36296 .57793 m .36045 .57598 L .36276 .57594 L F
.36296 .57793 m .36083 .57955 L .36045 .57598 L F
.732 .403 .423 r
.33743 .55979 m .34181 .55805 L .3394 .55722 L F
.084 .634 .825 r
.23581 .63767 m .23416 .63736 L .23196 .63732 L F
.441 .859 .954 r
.2364 .63672 m .23581 .63767 L .23832 .63731 L F
.2364 .63672 m .23416 .63736 L .23581 .63767 L F
.767 .985 .743 r
.27883 .64976 m .27936 .64995 L .27562 .65383 L F
.221 0 .123 r
.31624 .58019 m .31545 .58184 L .31349 .5824 L F
.298 0 .161 r
.31752 .58124 m .31624 .58019 L .31834 .57948 L F
.31752 .58124 m .31545 .58184 L .31624 .58019 L F
.983 .728 .464 r
.30945 .56426 m .30751 .56548 L .30924 .5667 L F
.804 .602 .041 r
.30894 .5615 m .30945 .56426 L .30916 .56136 L F
.97 .929 .629 r
.30894 .5615 m .30751 .56548 L .30945 .56426 L F
.585 .442 .653 r
.30945 .56426 m .31178 .56086 L .30916 .56136 L F
.30945 .56426 m .31196 .56391 L .31178 .56086 L F
.538 .296 .496 r
.30924 .5667 m .31196 .56391 L .30945 .56426 L F
.632 .456 .626 r
.33127 .63508 m .32814 .63751 L .32805 .63484 L F
.826 .368 .129 r
.54547 .52599 m .54722 .5285 L .54836 .52743 L F
.803 .333 .108 r
.54836 .52743 m .54722 .5285 L .54897 .52902 L F
.116 0 .286 r
.19632 .5689 m .19512 .56828 L .19722 .56732 L F
.19632 .5689 m .19479 .57005 L .19512 .56828 L F
.921 .762 .667 r
.82587 .40574 m .82857 .40364 L .82627 .40318 L F
.82587 .40574 m .82736 .40729 L .82857 .40364 L F
.486 .709 .969 r
.77781 .4038 m .7758 .40322 L .77777 .40378 L F
.293 .784 .734 r
.78045 .4028 m .77781 .4038 L .77777 .40378 L F
.614 .544 .752 r
.33848 .62468 m .33565 .62549 L .33522 .62295 L F
.449 .339 .637 r
.33849 .62768 m .33565 .62549 L .33848 .62468 L F
.33849 .62768 m .33592 .62999 L .33565 .62549 L F
0 0 .026 r
.27286 .62165 m .27006 .6251 L .27124 .62284 L F
.47 0 0 r
.26523 .6724 m .26366 .67454 L .26496 .67484 L F
.955 .631 .366 r
.2633 .67339 m .26523 .6724 L .26496 .67484 L F
.532 0 0 r
.26719 .67385 m .26523 .6724 L .2633 .67339 L F
0 0 0 r
.19855 .5473 m .2018 .54553 L .20259 .54483 L F
.20259 .54483 m .2018 .54553 L .20369 .54443 L F
.554 .403 .631 r
.34251 .61336 m .34277 .61611 L .34028 .61653 L F
.536 .341 .562 r
.34277 .61611 m .34021 .61914 L .34028 .61653 L F
.199 .694 .918 r
.21508 .61773 m .21143 .61719 L .21378 .61748 L F
0 .485 .739 r
.21378 .61748 m .21757 .6183 L .21508 .61773 L F
.289 .651 .969 r
.2702 .63105 m .26954 .63237 L .26803 .63155 L F
.2702 .63105 m .27271 .63283 L .26954 .63237 L F
.362 .811 .677 r
.32077 .59109 m .32475 .58915 L .32323 .59056 L F
.994 .835 .577 r
.32323 .59056 m .32475 .58915 L .32382 .58871 L F
.624 .907 .984 r
.8154 .3979 m .81709 .39595 L .81838 .39657 L F
.688 .418 .51 r
.8154 .3979 m .81731 .40021 L .81709 .39595 L F
.8154 .3979 m .81564 .40035 L .81731 .40021 L F
.566 .528 .771 r
.32144 .54852 m .31953 .55172 L .31884 .54916 L F
.32144 .54852 m .32179 .55124 L .31953 .55172 L F
0 0 0 r
.49552 .54225 m .49565 .54205 L .49682 .53976 L F
.644 .304 .382 r
.49682 .53976 m .49565 .54205 L .49931 .54168 L F
.561 .346 .546 r
.49939 .53916 m .49931 .54168 L .49682 .53976 L F
.49939 .53916 m .49931 .54168 L .49682 .53976 L F
.276 .294 .699 r
.15994 .59783 m .16135 .59768 L .16071 .59383 L F
.722 .81 .92 r
.15932 .60051 m .16135 .59768 L .15994 .59783 L F
.543 .185 .311 r
.30537 .64696 m .30127 .64951 L .30174 .64767 L F
.852 .456 .293 r
.78734 .41158 m .78749 .40959 L .78621 .40888 L F
.78734 .41158 m .78935 .41251 L .78749 .40959 L F
.566 .835 .483 r
.27286 .62165 m .2741 .62021 L .27527 .6188 L F
.427 .352 .669 r
.15738 .5884 m .15872 .58507 L .15717 .58567 L F
.188 0 .117 r
.18737 .57761 m .18647 .57584 L .18794 .57369 L F
.18737 .57761 m .18542 .57844 L .18647 .57584 L F
.398 0 0 r
.77777 .40378 m .7758 .40322 L .77454 .40384 L F
.358 .048 .295 r
.29381 .61236 m .29587 .61213 L .29709 .60895 L F
.566 .489 .727 r
.29709 .60895 m .29966 .60993 L .29867 .60617 L F
.641 .217 .222 r
.29816 .61168 m .29709 .60895 L .29587 .61213 L F
.29816 .61168 m .29966 .60993 L .29709 .60895 L F
.247 0 .002 r
.28869 .5453 m .2847 .54805 L .28628 .54548 L F
.829 .612 .609 r
.53868 .53957 m .53512 .54151 L .53512 .539 L F
.53868 .53957 m .53855 .54223 L .53512 .54151 L F
.572 .485 .717 r
.36098 .58232 m .36192 .58465 L .35901 .58508 L F
.538 .415 .66 r
.36174 .58818 m .35901 .58508 L .36192 .58465 L F
.36174 .58818 m .35938 .58875 L .35901 .58508 L F
.757 .85 .92 r
.29567 .55402 m .29915 .55261 L .29397 .55193 L F
0 .01 .576 r
.29478 .55223 m .29397 .55193 L .29239 .55068 L F
.29478 .55223 m .29567 .55402 L .29397 .55193 L F
.405 .12 .363 r
.31605 .59749 m .31316 .60025 L .31372 .59791 L F
.435 .544 .868 r
.3066 .57075 m .30849 .57326 L .30998 .57253 L F
0 0 .505 r
.30849 .57326 m .30975 .57525 L .30998 .57253 L F
.30849 .57326 m .30905 .57626 L .30975 .57525 L F
.443 .002 .103 r
.1923 .57076 m .19376 .5719 L .19185 .572 L F
.369 .025 .245 r
.19479 .57005 m .19376 .5719 L .1923 .57076 L F
.429 0 0 r
.30173 .58366 m .30468 .58373 L .3031 .58259 L F
.355 0 .082 r
.3031 .58259 m .30468 .58373 L .3058 .58201 L F
.174 .395 .838 r
.30039 .58055 m .30419 .58337 L .30102 .58238 L F
.30139 .58 m .30419 .58337 L .30039 .58055 L F
.037 0 .053 r
.30076 .58269 m .30252 .58304 L .3031 .58259 L F
.174 .395 .838 r
.30419 .58337 m .30328 .58319 L .30102 .58238 L F
.037 0 .053 r
.30073 .58266 m .30076 .58269 L .3031 .58259 L F
.30076 .58269 m .30173 .58366 L .30252 .58304 L F
.444 0 0 r
.30102 .58238 m .30436 .58357 L .30173 .58366 L F
.174 .395 .838 r
.30419 .58337 m .30436 .58357 L .30328 .58319 L F
.191 .404 .84 r
.3022 .57941 m .30436 .58357 L .29937 .57758 L F
.573 .605 .847 r
.3022 .57941 m .30173 .58366 L .30436 .58357 L F
.115 .257 .733 r
.30463 .5817 m .30305 .58363 L .30223 .57955 L F
.30231 .57951 m .30223 .57955 L .3022 .57941 L F
.30463 .5817 m .30223 .57955 L .30231 .57951 L F
.174 .395 .838 r
.29937 .57758 m .30139 .58 L .30039 .58055 L F
.037 0 .053 r
.30073 .58266 m .29962 .58474 L .30173 .58366 L F
.869 .604 .075 r
.5523 .53529 m .55315 .5388 L .55347 .53639 L F
.996 .823 .552 r
.55269 .53266 m .5523 .53529 L .55347 .53639 L F
.752 .586 .671 r
.79945 .41575 m .80076 .41912 L .80285 .41596 L F
0 0 0 r
.54937 .55621 m .54827 .56061 L .54969 .5585 L F
.57 .43 .651 r
.32977 .58497 m .32694 .58752 L .32714 .58577 L F
.32977 .58497 m .32694 .58752 L .32714 .58577 L F
.985 .789 .558 r
.55112 .54456 m .55176 .54791 L .5525 .54566 L F
.55112 .54456 m .55176 .54791 L .5525 .54566 L F
.804 .602 .041 r
.30894 .5615 m .30916 .56136 L .31178 .56086 L F
.562 .677 .916 r
.2809 .66245 m .28038 .66575 L .27995 .66514 L F
.2809 .66245 m .2828 .66567 L .28038 .66575 L F
.309 0 0 r
.28036 .66578 m .27892 .66738 L .27995 .66514 L F
.28038 .66575 m .28081 .66698 L .27892 .66738 L F
.377 .217 .533 r
.27995 .66514 m .27892 .66738 L .28081 .66698 L F
.27995 .66514 m .28081 .66698 L .27961 .6646 L F
.27995 .66514 m .27961 .6646 L .27904 .66347 L F
.309 0 0 r
.28038 .66575 m .28036 .66578 L .27995 .66514 L F
.28038 .66575 m .2828 .66567 L .28081 .66698 L F
.44 .516 .84 r
.29581 .60442 m .29867 .60617 L .29773 .60411 L F
.277 0 0 r
.24408 .53435 m .24637 .53459 L .24826 .53414 L F
.21 0 0 r
.24637 .53459 m .25014 .53429 L .24826 .53414 L F
.613 .443 .628 r
.36528 .54052 m .36791 .54179 L .36828 .53953 L F
.812 .566 .566 r
.37326 .53905 m .37056 .54047 L .36985 .53911 L F
.917 .783 .698 r
.37056 .54047 m .37044 .54004 L .36985 .53911 L F
.241 .01 .348 r
.37079 .53636 m .36985 .53911 L .36929 .53825 L F
.37079 .53636 m .36985 .53911 L .36828 .53953 L F
.38 .772 .988 r
.36676 .53583 m .36886 .53545 L .37079 .53636 L F
.36676 .53583 m .36886 .53545 L .37079 .53636 L F
.959 .777 .613 r
.37079 .53636 m .36985 .53911 L .36886 .53545 L F
.713 .475 .563 r
.37326 .53905 m .36985 .53911 L .37079 .53636 L F
.917 .783 .698 r
.37044 .54004 m .36986 .53792 L .36985 .53911 L F
.241 .01 .348 r
.36929 .53825 m .36985 .53911 L .36828 .53953 L F
.569 .321 .501 r
.29498 .56323 m .29804 .56034 L .29468 .56105 L F
.489 .302 .553 r
.47063 .64114 m .473 .64061 L .47207 .63864 L F
.47207 .63864 m .473 .64061 L .47063 .64114 L F
.528 .746 .975 r
.82435 .40208 m .82301 .40385 L .8221 .4027 L F
.82435 .40208 m .82627 .40318 L .82301 .40385 L F
0 0 .059 r
.34868 .56688 m .34608 .57021 L .34764 .56907 L F
0 .498 .854 r
.35077 .56642 m .34712 .56484 L .34868 .56688 L F
0 0 0 r
.34764 .56907 m .35077 .56642 L .34868 .56688 L F
.254 .709 .954 r
.28604 .53201 m .28826 .53203 L .28991 .53277 L F
.344 .678 .978 r
.29058 .53152 m .28991 .53277 L .28826 .53203 L F
.29058 .53152 m .29222 .53294 L .28991 .53277 L F
.511 .874 .983 r
.22674 .73882 m .23032 .73939 L .22612 .73992 L F
.731 .587 .695 r
.23032 .73939 m .23052 .74068 L .22612 .73992 L F
.465 .44 .746 r
.29695 .59509 m .2999 .59665 L .29894 .59458 L F
.561 .281 .447 r
.27802 .6125 m .27879 .61152 L .27937 .61133 L F
.108 0 .434 r
.27937 .61133 m .27879 .61152 L .28151 .60866 L F
0 .212 .736 r
.20636 .62509 m .20841 .62868 L .20849 .62699 L F
.035 .337 .818 r
.20841 .62868 m .21038 .62987 L .20849 .62699 L F
.433 .823 .986 r
.2821 .65505 m .2817 .65613 L .28378 .65566 L F
.531 .614 .88 r
.19273 .60085 m .19254 .60082 L .19121 .59962 L F
.19273 .60085 m .19221 .60369 L .19254 .60082 L F
.76 .669 .761 r
.27353 .65563 m .27384 .65568 L .27658 .65244 L F
.767 .985 .743 r
.27869 .64994 m .27562 .65383 L .27658 .65244 L F
.76 .669 .761 r
.27384 .65568 m .27746 .65623 L .27658 .65244 L F
.767 .985 .743 r
.27883 .64976 m .27869 .64994 L .27658 .65244 L F
.676 .808 .946 r
.81564 .40035 m .81934 .40095 L .81731 .40021 L F
.091 .238 .723 r
.20422 .60622 m .20579 .61055 L .20426 .60961 L F
.159 .227 .684 r
.20579 .61055 m .20634 .61196 L .20426 .60961 L F
.45 .194 .432 r
.31122 .60115 m .31034 .60398 L .30839 .60415 L F
.508 .31 .546 r
.31316 .60025 m .31034 .60398 L .31122 .60115 L F
.683 .584 .738 r
.3462 .601 m .34677 .60415 L .34387 .60413 L F
0 0 0 r
.27594 .60103 m .27733 .59982 L .27884 .59795 L F
.069 0 .084 r
.27733 .59982 m .27939 .59705 L .27884 .59795 L F
.196 .623 .947 r
.24193 .63876 m .246 .64027 L .2454 .63957 L F
.384 .783 .986 r
.246 .64027 m .24679 .63926 L .2454 .63957 L F
.246 .64027 m .24846 .63997 L .24679 .63926 L F
.608 .814 .979 r
.22353 .74423 m .22358 .74187 L .22147 .74247 L F
.22353 .74423 m .22599 .74347 L .22358 .74187 L F
.295 0 .232 r
.19185 .572 m .18794 .57369 L .18896 .57307 L F
.19185 .572 m .19034 .57469 L .18794 .57369 L F
.457 .193 .425 r
.19034 .57469 m .18737 .57761 L .18794 .57369 L F
0 0 0 r
.21424 .53931 m .21476 .5405 L .2166 .53904 L F
.21424 .53931 m .21315 .54133 L .21476 .5405 L F
.18269 .55737 m .18401 .55711 L .18569 .55525 L F
.025 0 0 r
.18269 .55737 m .18294 .55843 L .18401 .55711 L F
.18269 .55737 m .18082 .55927 L .18294 .55843 L F
.561 .843 .997 r
.20946 .61582 m .20907 .6177 L .20723 .61611 L F
.20946 .61582 m .21143 .61719 L .20907 .6177 L F
.686 .706 .863 r
.32951 .57208 m .3303 .5745 L .3332 .57287 L F
.443 .453 .774 r
.3303 .5745 m .33339 .57557 L .3332 .57287 L F
.3303 .5745 m .33156 .57647 L .33339 .57557 L F
.729 .226 .035 r
.34568 .5406 m .34751 .54181 L .34974 .54192 L F
.247 .755 .872 r
.34974 .54192 m .34751 .54181 L .35176 .54159 L F
.612 .388 .553 r
.35176 .54159 m .34937 .54416 L .34974 .54192 L F
.679 .707 .869 r
.28865 .56923 m .29082 .56711 L .28703 .56704 L F
.689 .851 .96 r
.3363 .56601 m .33193 .56657 L .33518 .56477 L F
.293 .293 .688 r
.33457 .56898 m .33193 .56657 L .3363 .56601 L F
.946 .704 .539 r
.33864 .56417 m .33705 .56403 L .33706 .564 L F
.3374 .56378 m .33706 .564 L .33711 .56369 L F
.33864 .56417 m .33706 .564 L .3374 .56378 L F
.33864 .56417 m .33711 .56369 L .33792 .56238 L F
.851 .821 .819 r
.33701 .56403 m .33864 .56417 L .33916 .56279 L F
.774 .521 .552 r
.33749 .56132 m .33703 .5642 L .33269 .56253 L F
0 0 0 r
.3381 .56342 m .33683 .56414 L .33916 .56279 L F
.851 .821 .819 r
.33583 .5647 m .33864 .56417 L .33701 .56403 L F
.618 .684 .89 r
.33684 .56413 m .33518 .56477 L .33269 .56253 L F
.33703 .5642 m .33634 .56441 L .33684 .56413 L F
0 0 0 r
.33693 .56408 m .33645 .56435 L .33701 .56403 L F
.618 .684 .89 r
.33634 .56441 m .33518 .56477 L .33684 .56413 L F
0 0 0 r
.33683 .56414 m .33583 .5647 L .33645 .56435 L F
.33683 .56414 m .33645 .56435 L .33693 .56408 L F
.33683 .56414 m .33701 .56403 L .33916 .56279 L F
.946 .704 .539 r
.33864 .56417 m .33703 .5642 L .33705 .56403 L F
.33792 .56238 m .33711 .56369 L .33749 .56132 L F
0 0 0 r
.3381 .56342 m .33716 .56421 L .33667 .56439 L F
.493 .264 .495 r
.33703 .5642 m .33583 .5647 L .33518 .56477 L F
0 0 0 r
.33683 .56414 m .33667 .56439 L .33583 .5647 L F
.3381 .56342 m .33667 .56439 L .33683 .56414 L F
.313 .633 .963 r
.3363 .56601 m .33583 .5647 L .3353 .5649 L F
.973 .898 .542 r
.33583 .5647 m .3363 .56601 L .33764 .56642 L F
.33583 .5647 m .33457 .56898 L .3363 .56601 L F
.851 .821 .819 r
.33583 .5647 m .33764 .56642 L .33864 .56417 L F
.33583 .5647 m .33764 .56642 L .33864 .56417 L F
.33583 .5647 m .33864 .56417 L .33703 .5642 L F
.909 .752 .675 r
.33299 .56609 m .33457 .56898 L .33583 .5647 L F
0 0 0 r
.33716 .56421 m .33504 .56599 L .33583 .5647 L F
.313 .633 .963 r
.3353 .5649 m .33583 .5647 L .33518 .56477 L F
.728 .936 .609 r
.22978 .74281 m .23219 .73974 L .23024 .74154 L F
.467 .633 .926 r
.23219 .73974 m .23471 .73994 L .23327 .73794 L F
.83 .683 .7 r
.32657 .57038 m .32314 .56994 L .32579 .56646 L F
.74 .504 .573 r
.79322 .41841 m .79685 .41626 L .793 .41578 L F
.79322 .41841 m .79689 .41878 L .79685 .41626 L F
.745 .583 .674 r
.79689 .41878 m .79945 .41575 L .79685 .41626 L F
.567 .394 .606 r
.29082 .56711 m .29332 .5669 L .29354 .56405 L F
.294 .792 .839 r
.49767 .54187 m .49565 .54205 L .49552 .54225 L F
.093 .65 .723 r
.49931 .54168 m .49565 .54205 L .49767 .54187 L F
.361 .818 .933 r
.25469 .53298 m .25465 .53386 L .25242 .53375 L F
.25469 .53298 m .25705 .53336 L .25465 .53386 L F
.521 .304 .526 r
.49417 .58826 m .49368 .59074 L .49126 .58871 L F
.49417 .58826 m .49368 .59074 L .49126 .58871 L F
.606 .574 .792 r
.8092 .41386 m .81078 .4092 L .80865 .40972 L F
.734 .635 .749 r
.36325 .56399 m .36133 .56649 L .3612 .56449 L F
.545 .375 .601 r
.36325 .56399 m .3633 .56668 L .36133 .56649 L F
.424 .309 .618 r
.31586 .58417 m .31349 .5824 L .31545 .58184 L F
.31586 .58417 m .31382 .58507 L .31349 .5824 L F
.652 .165 .083 r
.5408 .52338 m .54361 .52533 L .54487 .52395 L F
.895 .507 .283 r
.54487 .52395 m .54361 .52533 L .54547 .52599 L F
.981 .785 .566 r
.4972 .61619 m .49659 .61854 L .49804 .61954 L F
.4972 .61619 m .49659 .61854 L .49804 .61954 L F
.722 .81 .92 r
.15932 .60051 m .16356 .60056 L .16135 .59768 L F
.003 .337 .819 r
.16356 .60056 m .16379 .5993 L .16135 .59768 L F
0 .019 .592 r
.16356 .60056 m .16533 .60301 L .16379 .5993 L F
.44 .257 .535 r
.16533 .60301 m .16327 .60357 L .16356 .60056 L F
.578 .479 .706 r
.36203 .5731 m .35968 .57398 L .35893 .56999 L F
.496 .565 .855 r
.25762 .68365 m .2593 .68695 L .26144 .68669 L F
.89 .473 .072 r
.2593 .68695 m .26076 .69092 L .26144 .68669 L F
.534 .83 .999 r
.4378 .65592 m .43392 .65557 L .43552 .6566 L F
.4378 .65592 m .43392 .65557 L .43552 .6566 L F
.431 .856 .947 r
.22464 .55805 m .22324 .5577 L .22091 .55844 L F
.76 .974 .922 r
.22495 .55624 m .22464 .55805 L .22689 .55733 L F
.22495 .55624 m .22324 .5577 L .22464 .55805 L F
.757 .85 .92 r
.29567 .55402 m .29778 .55489 L .29915 .55261 L F
.437 .8 .996 r
.22973 .62196 m .22922 .62318 L .22758 .62177 L F
.22973 .62196 m .23149 .62283 L .22922 .62318 L F
0 0 .203 r
.27594 .60103 m .27695 .60175 L .27733 .59982 L F
.27594 .60103 m .2756 .60358 L .27695 .60175 L F
0 0 0 r
.5196 .52654 m .52186 .52362 L .51828 .52456 L F
.757 .546 .611 r
.5156 .52656 m .5196 .52654 L .51828 .52456 L F
.118 0 0 r
.18569 .55525 m .18611 .55637 L .18766 .55417 L F
.18569 .55525 m .18401 .55711 L .18611 .55637 L F
.513 .305 .534 r
.32129 .6041 m .32372 .60601 L .32348 .60342 L F
.32129 .6041 m .32114 .60667 L .32372 .60601 L F
.205 .186 .615 r
.15824 .59176 m .15926 .58777 L .15738 .5884 L F
.15824 .59176 m .15952 .59151 L .15926 .58777 L F
.234 .337 .765 r
.15824 .59176 m .16071 .59383 L .15952 .59151 L F
.585 .854 .995 r
.27073 .64477 m .27274 .64577 L .2746 .64469 L F
.076 .308 .79 r
.22501 .63375 m .22527 .63549 L .22583 .63397 L F
.26 .53 .916 r
.22527 .63549 m .22795 .63515 L .22583 .63397 L F
.614 .544 .752 r
.33848 .62468 m .33522 .62295 L .33772 .62224 L F
.633 .958 .919 r
.22826 .74278 m .22978 .74281 L .23024 .74154 L F
.707 .554 .678 r
.35151 .59752 m .35203 .60056 L .34886 .60058 L F
.285 .004 .299 r
.35497 .5976 m .35203 .60056 L .35151 .59752 L F
.537 .316 .527 r
.33417 .63184 m .33385 .63464 L .33127 .63508 L F
.58 .353 .537 r
.33646 .63403 m .33417 .63184 L .33655 .63149 L F
.33646 .63403 m .33385 .63464 L .33417 .63184 L F
.958 .947 .689 r
.24985 .69523 m .24899 .69924 L .24969 .69848 L F
.196 .613 .947 r
.24899 .69924 m .25158 .69982 L .24969 .69848 L F
.876 .529 .03 r
.25267 .70235 m .25158 .69982 L .24899 .69924 L F
.543 .185 .311 r
.30537 .64696 m .3038 .64947 L .30127 .64951 L F
.609 .259 .352 r
.3076 .64906 m .30537 .64696 L .30777 .64714 L F
.3076 .64906 m .3038 .64947 L .30537 .64696 L F
.866 .915 .861 r
.27703 .66272 m .2747 .66443 L .2764 .66534 L F
.27703 .66272 m .27238 .66527 L .2747 .66443 L F
0 .087 .621 r
.18008 .58442 m .17962 .58661 L .17836 .5822 L F
.594 .781 .97 r
.18193 .58584 m .17962 .58661 L .18008 .58442 L F
0 0 .218 r
.27759 .6154 m .27584 .61638 L .27802 .6125 L F
0 0 .147 r
.27759 .6154 m .27527 .6188 L .27584 .61638 L F
.17 0 0 r
.259 .55269 m .25847 .55133 L .26091 .55128 L F
.259 .55269 m .25677 .55339 L .25847 .55133 L F
.394 .817 .968 r
.29453 .53249 m .29627 .53299 L .29222 .53294 L F
.183 .59 .941 r
.29671 .53197 m .29627 .53299 L .29453 .53249 L F
.29671 .53197 m .29834 .53331 L .29627 .53299 L F
.743 .738 .847 r
.54088 .57094 m .54585 .57081 L .54414 .5697 L F
.74 .49 .553 r
.36743 .54911 m .36536 .54439 L .36552 .54767 L F
.014 0 .106 r
.36552 .54767 m .36378 .54905 L .36743 .54911 L F
0 0 .217 r
.36808 .54457 m .36743 .54911 L .36552 .54767 L F
.36808 .54457 m .3679 .54808 L .36743 .54911 L F
.645 .247 .276 r
.3679 .54808 m .36552 .54767 L .36743 .54911 L F
.418 .325 .643 r
.36296 .57793 m .36098 .58232 L .36083 .57955 L F
0 .441 .861 r
.22758 .62177 m .22621 .62144 L .22365 .61939 L F
.518 .772 .989 r
.2118 .63156 m .21251 .62975 L .21038 .62987 L F
.2118 .63156 m .21408 .63102 L .21251 .62975 L F
.804 .602 .041 r
.30894 .5615 m .31178 .56086 L .31035 .56021 L F
.632 .916 .98 r
.3123 .55912 m .31178 .56086 L .31376 .55858 L F
.3123 .55912 m .31035 .56021 L .31178 .56086 L F
.612 .691 .899 r
.31376 .55858 m .31178 .56086 L .31424 .56043 L F
.598 .456 .659 r
.31196 .56391 m .31424 .56043 L .31178 .56086 L F
.822 .46 .37 r
.54897 .52902 m .55078 .53176 L .55254 .52993 L F
.917 .619 .465 r
.55078 .53176 m .55269 .53266 L .55254 .52993 L F
.293 .293 .688 r
.33457 .56898 m .33245 .57127 L .33193 .56657 L F
.667 .902 .978 r
.33457 .56898 m .33218 .57036 L .33245 .57127 L F
0 .362 .829 r
.78514 .40117 m .78411 .40159 L .78313 .40012 L F
.606 .574 .792 r
.8092 .41386 m .81198 .41311 L .81078 .4092 L F
.614 .28 .382 r
.26327 .68361 m .2638 .68136 L .26262 .68301 L F
.495 .09 .201 r
.2651 .68323 m .2638 .68136 L .26327 .68361 L F
.432 .243 .521 r
.29206 .57233 m .29439 .57259 L .29436 .56957 L F
.466 .218 .453 r
.29206 .57233 m .2938 .57494 L .29439 .57259 L F
.29206 .57233 m .29305 .57599 L .2938 .57494 L F
0 .312 .748 r
.30213 .54827 m .3023 .5482 L .29845 .54592 L F
.049 0 .039 r
.30213 .54827 m .30313 .54948 L .3037 .54707 L F
0 0 0 r
.3037 .54707 m .3023 .5482 L .30213 .54827 L F
.049 0 .039 r
.30213 .54827 m .30139 .55042 L .30313 .54948 L F
.077 0 .289 r
.28934 .65278 m .28951 .65025 L .29118 .64935 L F
.461 .328 .614 r
.34438 .60984 m .34468 .61278 L .34251 .61336 L F
.46 .334 .621 r
.34488 .61545 m .34251 .61336 L .34468 .61278 L F
.34488 .61545 m .34277 .61611 L .34251 .61336 L F
.305 .524 .902 r
.31285 .53272 m .3133 .53581 L .31088 .53315 L F
.31285 .53272 m .31493 .5358 L .3133 .53581 L F
.456 .495 .811 r
.77322 .40932 m .77422 .40533 L .77225 .40583 L F
.77322 .40932 m .77541 .40904 L .77422 .40533 L F
0 0 .103 r
.34608 .57021 m .34662 .57105 L .34764 .56907 L F
.525 .917 .817 r
.27106 .65876 m .27514 .65694 L .27353 .65563 L F
.607 .794 .971 r
.27514 .65694 m .27746 .65623 L .27353 .65563 L F
.682 .693 .854 r
.79439 .42146 m .79811 .42228 L .79689 .41878 L F
.734 .652 .768 r
.79689 .41878 m .79811 .42228 L .80076 .41912 L F
.474 .748 .989 r
.33361 .53753 m .33278 .53909 L .33172 .53756 L F
.33361 .53753 m .33521 .53894 L .33278 .53909 L F
.771 .674 .756 r
.16327 .60357 m .16472 .60712 L .16066 .60667 L F
.313 .759 .961 r
.16066 .60667 m .16472 .60712 L .16311 .60647 L F
.975 .719 .48 r
.16311 .60647 m .16472 .60712 L .16327 .60357 L F
.599 .943 .777 r
.26974 .67603 m .27229 .67443 L .27251 .67404 L F
.495 .844 .576 r
.26883 .67733 m .27229 .67443 L .27128 .67731 L F
.035 0 .145 r
.27128 .67731 m .27229 .67443 L .27397 .67388 L F
.73 .238 .069 r
.26056 .69337 m .25784 .69255 L .25912 .69313 L F
.374 .082 .335 r
.25793 .6958 m .26056 .69337 L .26038 .69588 L F
.526 .787 .992 r
.26082 .6917 m .26284 .69287 L .26056 .69337 L F
.772 .981 .91 r
.26082 .6917 m .26056 .69337 L .25912 .69313 L F
.983 .724 .455 r
.25912 .69313 m .26056 .69337 L .26038 .69588 L F
.689 .538 .677 r
.26284 .69287 m .26038 .69588 L .26056 .69337 L F
0 0 0 r
.20795 .54288 m .20844 .54245 L .20591 .54378 L F
.20795 .54288 m .21028 .54192 L .20844 .54245 L F
.682 .135 0 r
.34608 .55482 m .34547 .55551 L .34684 .5539 L F
.566 .357 .557 r
.34555 .55742 m .34857 .55701 L .34608 .55482 L F
.682 .135 0 r
.34608 .55482 m .34857 .55701 L .34547 .55551 L F
.706 .247 .158 r
.31637 .60862 m .3209 .60916 L .31871 .60716 L F
.527 .322 .546 r
.31871 .60716 m .3209 .60916 L .32114 .60667 L F
.624 .544 .743 r
.34954 .60304 m .34677 .60415 L .3462 .601 L F
.026 0 .06 r
.34954 .60304 m .34672 .60643 L .34677 .60415 L F
.903 .887 .806 r
.82121 .41219 m .82248 .4136 L .82469 .41019 L F
.977 .732 .498 r
.28746 .65413 m .28798 .65663 L .28617 .65596 L F
.28617 .65596 m .28798 .65663 L .28746 .65413 L F
0 0 .529 r
.33156 .57647 m .33282 .5779 L .33339 .57557 L F
.33156 .57647 m .33217 .57963 L .33282 .5779 L F
.239 .738 .906 r
.25908 .53265 m .26315 .53284 L .26087 .53331 L F
.684 .67 .83 r
.78684 .41796 m .78799 .42138 L .79064 .41862 L F
.623 .655 .861 r
.78799 .42138 m .79185 .42256 L .79064 .41862 L F
.903 .887 .806 r
.82121 .41219 m .82469 .41019 L .82362 .40891 L F
.845 .903 .877 r
.82362 .40891 m .82469 .41019 L .82736 .40729 L F
0 0 0 r
.5196 .52654 m .52052 .52536 L .52186 .52362 L F
.755 .505 .555 r
.52052 .52536 m .52445 .52315 L .52186 .52362 L F
.738 .702 .817 r
.36597 .56076 m .36325 .56399 L .36178 .56014 L F
.647 .455 .609 r
.36708 .56579 m .3633 .56668 L .36325 .56399 L F
.183 0 .223 r
.26879 .66194 m .26697 .66287 L .26606 .66517 L F
.226 .747 .814 r
.26315 .53284 m .26544 .5324 L .26715 .53235 L F
.366 .79 .973 r
.26544 .5324 m .2694 .53272 L .26715 .53235 L F
.977 .732 .498 r
.28617 .65596 m .28746 .65413 L .28934 .65278 L F
.346 .453 .828 r
.31195 .59625 m .30962 .59579 L .31077 .59319 L F
.804 .856 .405 r
.31873 .58755 m .31752 .58908 L .3174 .59063 L F
.726 .488 .566 r
.3174 .59063 m .32077 .59109 L .31873 .58755 L F
.57 .434 .657 r
.31873 .58755 m .32323 .59056 L .32382 .58871 L F
.31873 .58755 m .32077 .59109 L .32323 .59056 L F
.564 .355 .555 r
.32841 .59723 m .33123 .5942 L .3289 .59493 L F
.075 .239 .73 r
.33217 .57963 m .33403 .58147 L .33282 .5779 L F
.073 .599 .872 r
.2377 .62382 m .23556 .62368 L .23418 .62295 L F
.588 .886 .991 r
.30678 .53339 m .30631 .53505 L .30508 .53402 L F
.30678 .53339 m .309 .5342 L .30631 .53505 L F
.496 .795 .998 r
.32978 .53636 m .32954 .53816 L .32765 .53668 L F
.32978 .53636 m .33172 .53756 L .32954 .53816 L F
.765 .989 .892 r
.27872 .59378 m .27901 .59427 L .27983 .5926 L F
.517 .44 .708 r
.28106 .59066 m .27983 .5926 L .27927 .58825 L F
.696 .546 .679 r
.32814 .63751 m .32913 .64084 L .32513 .6409 L F
.632 .456 .626 r
.33127 .63508 m .33141 .63797 L .32814 .63751 L F
.625 .505 .696 r
.33141 .63797 m .32913 .64084 L .32814 .63751 L F
.172 .704 .845 r
.24187 .62519 m .24445 .62523 L .24391 .62501 L F
.264 0 0 r
.24347 .62482 m .24391 .62501 L .24569 .62566 L F
.076 .594 .88 r
.24391 .62501 m .24591 .62525 L .2477 .62604 L F
.172 .704 .845 r
.24445 .62523 m .24591 .62525 L .24391 .62501 L F
.264 0 0 r
.24181 .6242 m .24391 .62501 L .24347 .62482 L F
.076 .594 .88 r
.24391 .62501 m .2477 .62604 L .24569 .62566 L F
0 0 .493 r
.28001 .58441 m .27927 .58825 L .27743 .58765 L F
.28001 .58441 m .28049 .58731 L .27927 .58825 L F
.073 .231 .723 r
.28049 .58731 m .2816 .59008 L .27927 .58825 L F
.517 .44 .708 r
.28069 .59016 m .27927 .58825 L .2816 .59008 L F
.922 .7 .585 r
.28049 .58731 m .27967 .58957 L .2816 .59008 L F
.052 .596 .843 r
.27967 .58957 m .28206 .59004 L .2816 .59008 L F
.544 .1 .145 r
.2816 .59008 m .28545 .58839 L .28106 .59066 L F
.2816 .59008 m .28373 .59036 L .28545 .58839 L F
.052 .596 .843 r
.28206 .59004 m .28373 .59036 L .2816 .59008 L F
.517 .44 .708 r
.28106 .59066 m .28069 .59016 L .2816 .59008 L F
.705 .655 .798 r
.79064 .41862 m .79185 .42256 L .79439 .42146 L F
0 0 0 r
.26367 .66812 m .26794 .66656 L .26606 .66517 L F
.766 .937 .939 r
.26794 .66656 m .26842 .6646 L .26606 .66517 L F
.26794 .66656 m .27003 .66521 L .26842 .6646 L F
.057 0 0 r
.27558 .631 m .27271 .63283 L .27473 .63259 L F
.369 0 0 r
.27649 .63216 m .27558 .631 L .27473 .63259 L F
.27649 .63216 m .27847 .63105 L .27558 .631 L F
.222 .486 .894 r
.18605 .61205 m .18564 .61274 L .18691 .61267 L F
.439 .857 .955 r
.25224 .64053 m .25273 .63963 L .25048 .63995 L F
.25224 .64053 m .25521 .63979 L .25273 .63963 L F
.321 .661 .973 r
.36306 .53847 m .36528 .54052 L .36714 .539 L F
.36306 .53847 m .36528 .54052 L .36714 .539 L F
.613 .443 .628 r
.36528 .54052 m .36571 .54218 L .36791 .54179 L F
.891 .605 .497 r
.36528 .54052 m .36405 .54405 L .36571 .54218 L F
.45 .295 .578 r
.29354 .56405 m .29554 .56577 L .29498 .56323 L F
.29354 .56405 m .29332 .5669 L .29554 .56577 L F
.663 .471 .615 r
.31399 .64409 m .31399 .64679 L .31143 .64687 L F
.619 .436 .612 r
.31657 .64375 m .31399 .64679 L .31399 .64409 L F
.25 .067 .426 r
.28651 .59686 m .28611 .59947 L .28484 .59817 L F
.202 .065 .46 r
.28611 .59947 m .28475 .60073 L .28484 .59817 L F
.66 .938 .672 r
.22674 .73882 m .22612 .73992 L .22358 .74187 L F
0 .014 .589 r
.23438 .72367 m .23593 .72699 L .23618 .72596 L F
.108 .514 .909 r
.23618 .72596 m .23593 .72699 L .23815 .72759 L F
0 .06 .547 r
.23593 .72699 m .2395 .7302 L .23815 .72759 L F
.407 .493 .835 r
.31348 .60534 m .31184 .60742 L .31034 .60398 L F
.318 .365 .753 r
.31348 .60534 m .31447 .60918 L .31184 .60742 L F
.573 .904 .98 r
.52575 .527 m .52416 .52632 L .52233 .52743 L F
0 0 .426 r
.52575 .527 m .52616 .52752 L .52416 .52632 L F
.52575 .527 m .52731 .52913 L .52616 .52752 L F
.412 .816 .98 r
.22533 .53616 m .22756 .53572 L .22936 .53633 L F
.448 .834 .985 r
.22756 .53572 m .23158 .53581 L .22936 .53633 L F
.298 .134 .483 r
.15879 .57911 m .16045 .57839 L .16063 .57589 L F
.327 .222 .579 r
.15879 .57911 m .1606 .58119 L .16045 .57839 L F
.15879 .57911 m .15845 .58244 L .1606 .58119 L F
.889 .824 .778 r
.25793 .6958 m .25433 .69825 L .25459 .69635 L F
.25793 .6958 m .25582 .69969 L .25433 .69825 L F
.386 .36 .707 r
.26037 .69888 m .25793 .6958 L .26038 .69588 L F
.585 .419 .624 r
.33386 .63735 m .33127 .63508 L .33385 .63464 L F
.33386 .63735 m .33141 .63797 L .33127 .63508 L F
.888 .818 .773 r
.26076 .69092 m .26567 .68758 L .26382 .68601 L F
.599 .785 .969 r
.26382 .68601 m .26567 .68758 L .26779 .68673 L F
.471 .543 .849 r
.36326 .55587 m .36173 .55775 L .36293 .55335 L F
.36326 .55587 m .36217 .55758 L .36173 .55775 L F
.46 .626 .924 r
.18862 .61609 m .19378 .61916 L .19059 .61583 L F
.184 .424 .858 r
.19378 .61916 m .1927 .61586 L .19059 .61583 L F
.19378 .61916 m .19455 .61864 L .1927 .61586 L F
.774 .521 .552 r
.33749 .56132 m .33269 .56253 L .33406 .56036 L F
.532 .31 .523 r
.35772 .59473 m .35743 .59726 L .35497 .5976 L F
0 0 .521 r
.35648 .59065 m .35772 .59473 L .35615 .59116 L F
.427 .502 .833 r
.35648 .59065 m .35743 .59726 L .35772 .59473 L F
.68 .887 .974 r
.37079 .53636 m .37126 .53423 L .37319 .53574 L F
.37079 .53636 m .36886 .53545 L .37126 .53423 L F
.713 .475 .563 r
.37326 .53905 m .37079 .53636 L .37319 .53574 L F
.52 .247 .442 r
.35203 .60056 m .34954 .60304 L .34886 .60058 L F
.35203 .60056 m .3517 .60271 L .34954 .60304 L F
.285 .004 .299 r
.35497 .5976 m .35457 .59977 L .35203 .60056 L F
.498 .316 .564 r
.35457 .59977 m .3517 .60271 L .35203 .60056 L F
.624 .544 .743 r
.34954 .60304 m .3462 .601 L .34886 .60058 L F
.69 .981 .867 r
.50866 .53293 m .50922 .53169 L .51113 .53122 L F
.646 .5 .671 r
.51113 .53122 m .51107 .53349 L .50866 .53293 L F
0 0 0 r
.51107 .53349 m .50922 .53169 L .50866 .53293 L F
.745 .583 .674 r
.79689 .41878 m .80076 .41912 L .79945 .41575 L F
.441 .607 .917 r
.29749 .54397 m .29845 .54592 L .29955 .54384 L F
.373 .521 .876 r
.29845 .54592 m .3023 .5482 L .29955 .54384 L F
.759 .586 .662 r
.32285 .64098 m .3233 .64441 L .31984 .64326 L F
.353 .15 .46 r
.32513 .6409 m .3233 .64441 L .32285 .64098 L F
.592 .392 .579 r
.3235 .60073 m .32602 .60056 L .32617 .59775 L F
.613 .47 .663 r
.32602 .60056 m .32841 .59723 L .32617 .59775 L F
.427 .352 .669 r
.15738 .5884 m .15926 .58777 L .15872 .58507 L F
.675 .46 .587 r
.36174 .58818 m .35577 .59021 L .35938 .58875 L F
.243 .75 .881 r
.25582 .69969 m .25158 .69982 L .25433 .69825 L F
.331 .28 .649 r
.27663 .59173 m .27872 .59378 L .27874 .59024 L F
.242 0 .303 r
.27759 .6154 m .27802 .6125 L .27937 .61133 L F
.934 .941 .595 r
.27354 .66977 m .27252 .67274 L .27262 .67102 L F
.247 .384 .805 r
.27262 .67102 m .27252 .67274 L .27308 .67103 L F
0 0 .208 r
.27308 .67103 m .27252 .67274 L .27251 .67404 L F
.404 0 0 r
.52445 .52315 m .52765 .52426 L .52821 .52384 L F
.378 0 .021 r
.52765 .52426 m .5302 .52272 L .52821 .52384 L F
.533 .098 .159 r
.34193 .55185 m .33773 .5536 L .33974 .55133 L F
.34193 .55185 m .34025 .55363 L .33773 .5536 L F
.687 .791 .929 r
.34657 .54955 m .34193 .55185 L .33974 .55133 L F
.598 .174 .208 r
.34539 .55351 m .34025 .55363 L .34193 .55185 L F
.506 .2 .381 r
.30102 .58238 m .30016 .58433 L .2976 .58375 L F
.261 .762 .887 r
.81456 .40545 m .81556 .40527 L .81682 .40539 L F
.276 .778 .86 r
.81556 .40527 m .81956 .40479 L .81682 .40539 L F
.81556 .40527 m .81862 .40457 L .81956 .40479 L F
.609 .453 .645 r
.81556 .40527 m .82008 .40831 L .81868 .40473 L F
.81556 .40527 m .81868 .40473 L .81862 .40457 L F
.261 .762 .887 r
.81262 .4055 m .81556 .40527 L .81456 .40545 L F
.353 .15 .46 r
.32513 .6409 m .32534 .64383 L .3233 .64441 L F
.71 .412 .472 r
.32895 .6434 m .32513 .6409 L .32913 .64084 L F
.32895 .6434 m .32534 .64383 L .32513 .6409 L F
.961 .711 .511 r
.25158 .69982 m .25459 .69635 L .25433 .69825 L F
.475 .522 .827 r
.77682 .41253 m .77801 .40857 L .77541 .40904 L F
.77682 .41253 m .77915 .41221 L .77801 .40857 L F
.385 .838 .751 r
.19855 .5473 m .19654 .54826 L .19745 .54765 L F
0 0 0 r
.19654 .54826 m .19675 .5491 L .19745 .54765 L F
.19654 .54826 m .1946 .54988 L .19675 .5491 L F
0 0 .031 r
.29467 .58567 m .29354 .58828 L .29256 .58865 L F
.202 0 .368 r
.2935 .59017 m .29256 .58865 L .29354 .58828 L F
.2935 .59017 m .29205 .59118 L .29256 .58865 L F
.157 0 .178 r
.17705 .56101 m .17613 .56302 L .17883 .56012 L F
.258 .766 .763 r
.30468 .57097 m .30453 .57123 L .30658 .57005 L F
.30468 .57097 m .30236 .57163 L .30453 .57123 L F
.711 .71 .848 r
.30453 .57123 m .3066 .57075 L .30658 .57005 L F
.423 0 0 r
.22184 .61836 m .22216 .6184 L .21983 .61803 L F
.22184 .61836 m .22365 .61939 L .22216 .6184 L F
0 0 0 r
.27761 .55169 m .27666 .5536 L .27478 .55448 L F
.672 .791 .327 r
.27736 .55201 m .27761 .55169 L .2794 .55042 L F
.27736 .55201 m .27666 .5536 L .27761 .55169 L F
.988 .721 .414 r
.50095 .56077 m .50105 .56375 L .49948 .56201 L F
.467 0 0 r
.50179 .56152 m .50095 .56077 L .49948 .56201 L F
.50179 .56152 m .50338 .56276 L .50095 .56077 L F
.875 .896 .844 r
.2395 .7302 m .24024 .72643 L .23815 .72759 L F
.2395 .7302 m .2421 .72714 L .24024 .72643 L F
.626 .491 .678 r
.33911 .63113 m .33592 .62999 L .33849 .62768 L F
.33911 .63113 m .33655 .63149 L .33592 .62999 L F
.93 .805 .701 r
.54033 .55427 m .53758 .55656 L .53957 .55308 L F
.54033 .55427 m .53943 .55769 L .53758 .55656 L F
.707 .688 .149 r
.54827 .56061 m .54791 .56231 L .54785 .56272 L F
0 0 0 r
.54937 .55621 m .5486 .55984 L .54827 .56061 L F
.5486 .55984 m .54791 .56231 L .54827 .56061 L F
.518 .893 .966 r
.50965 .5506 m .50877 .55198 L .51111 .55105 L F
.985 .818 .595 r
.78621 .40888 m .78688 .40668 L .78564 .40502 L F
.01 0 0 r
.23158 .53581 m .23393 .53574 L .23552 .5356 L F
.254 .765 .841 r
.23393 .53574 m .23785 .5353 L .23552 .5356 L F
.587 .312 .468 r
.35743 .59726 m .35457 .59977 L .35497 .5976 L F
.357 .724 .987 r
.25521 .63979 m .25855 .64077 L .25675 .63991 L F
.326 0 0 r
.25855 .64077 m .2589 .6411 L .25675 .63991 L F
.25855 .64077 m .2606 .64165 L .2589 .6411 L F
.327 .211 .564 r
.29908 .58826 m .30072 .59031 L .30001 .58828 L F
.29908 .58826 m .29855 .59168 L .30072 .59031 L F
.569 .335 .521 r
.28355 .62488 m .28605 .62481 L .28626 .62259 L F
.433 .106 .309 r
.28605 .62481 m .29035 .62198 L .28626 .62259 L F
.325 .197 .547 r
.17996 .58163 m .18008 .58442 L .17836 .5822 L F
0 0 0 r
.29531 .54436 m .29338 .5447 L .29105 .54498 L F
.124 .67 .696 r
.29749 .54397 m .29338 .5447 L .29531 .54436 L F
.56 .288 .461 r
.27666 .5536 m .27307 .556 L .27478 .55448 L F
0 .212 .724 r
.2027 .60307 m .20218 .60438 L .2008 .60263 L F
.2027 .60307 m .20422 .60622 L .20218 .60438 L F
0 .254 .763 r
.18393 .58487 m .18697 .58749 L .18633 .58795 L F
0 .05 .616 r
.18697 .58749 m .18807 .58966 L .18633 .58795 L F
.765 .959 .652 r
.16787 .59975 m .16642 .60211 L .16791 .60153 L F
.705 .655 .798 r
.79064 .41862 m .79439 .42146 L .79322 .41841 L F
.727 .656 .778 r
.79322 .41841 m .79439 .42146 L .79689 .41878 L F
.299 .041 .344 r
.16605 .56984 m .16723 .57167 L .16774 .56927 L F
.16605 .56984 m .16534 .57244 L .16723 .57167 L F
0 0 0 r
.3493 .54982 m .35041 .54954 L .35432 .54795 L F
.104 0 0 r
.35432 .54795 m .35041 .54954 L .35574 .54806 L F
.231 .749 .761 r
.35574 .54806 m .35379 .54839 L .35513 .54806 L F
.104 0 0 r
.35432 .54795 m .35574 .54806 L .35624 .54806 L F
.231 .749 .761 r
.35574 .54806 m .35513 .54806 L .35627 .54778 L F
.104 0 0 r
.35624 .54806 m .35574 .54806 L .35674 .54809 L F
.935 .613 .163 r
.54034 .54833 m .53942 .54757 L .53868 .54447 L F
.933 .641 .464 r
.54034 .54833 m .53848 .55007 L .53942 .54757 L F
.54034 .54833 m .54045 .55106 L .53848 .55007 L F
.551 .046 0 r
.30927 .5493 m .3087 .54856 L .30938 .54684 L F
.30927 .5493 m .30988 .54988 L .3087 .54856 L F
.221 .734 .878 r
.2694 .53272 m .2717 .53249 L .27339 .53272 L F
.222 .724 .905 r
.27409 .53218 m .27339 .53272 L .2717 .53249 L F
.27409 .53218 m .27573 .5326 L .27339 .53272 L F
.323 .58 .935 r
.17223 .60265 m .17306 .60418 L .17367 .60244 L F
.183 .417 .853 r
.17306 .60418 m .17584 .6057 L .17367 .60244 L F
.525 .533 .807 r
.3066 .57075 m .3089 .56906 L .30658 .57005 L F
.3066 .57075 m .30998 .57253 L .3089 .56906 L F
.549 .873 .993 r
.27978 .53237 m .28023 .5309 L .28207 .53162 L F
.27978 .53237 m .27795 .53171 L .28023 .5309 L F
.539 .321 .532 r
.32913 .64084 m .33135 .643 L .32895 .6434 L F
.669 .567 .731 r
.33141 .63797 m .33175 .64117 L .32913 .64084 L F
.654 .305 .368 r
.33175 .64117 m .33135 .643 L .32913 .64084 L F
0 0 0 r
.2882 .58546 m .28545 .58839 L .28704 .58727 L F
.219 0 0 r
.28545 .58839 m .28619 .58974 L .28704 .58727 L F
.28545 .58839 m .28373 .59036 L .28619 .58974 L F
.467 .466 .774 r
.27094 .66199 m .27003 .66521 L .27238 .66527 L F
.934 .562 .266 r
.27003 .66521 m .27262 .67102 L .27238 .66527 L F
.13 .653 .881 r
.23832 .63731 m .2402 .6373 L .2364 .63672 L F
.143 0 0 r
.17107 .56617 m .17276 .56592 L .17426 .56392 L F
.217 0 .028 r
.17426 .56392 m .1751 .56517 L .17613 .56302 L F
.17426 .56392 m .17276 .56592 L .1751 .56517 L F
.667 .311 .361 r
.30777 .64714 m .3099 .6494 L .3076 .64906 L F
.634 .317 .417 r
.31143 .64687 m .3099 .6494 L .30777 .64714 L F
.347 .668 .975 r
.24193 .63876 m .24263 .63745 L .2402 .6373 L F
.24193 .63876 m .2454 .63957 L .24263 .63745 L F
.43 .167 .411 r
.35958 .54685 m .36196 .54484 L .35996 .54604 L F
.628 .224 .259 r
.26491 .55104 m .26303 .55312 L .26091 .55128 L F
.76 .395 .364 r
.26491 .55104 m .26666 .55386 L .26303 .55312 L F
.476 .523 .827 r
.78066 .41555 m .78202 .41158 L .77915 .41221 L F
.78066 .41555 m .78312 .41529 L .78202 .41158 L F
.031 0 .202 r
.28704 .58727 m .28906 .58429 L .2882 .58546 L F
.734 .421 .45 r
.53855 .54223 m .53493 .54414 L .53512 .54151 L F
.53855 .54223 m .53868 .54447 L .53493 .54414 L F
.295 .693 .975 r
.37377 .53452 m .37319 .53574 L .37126 .53423 L F
.37377 .53452 m .37522 .53554 L .37319 .53574 L F
.674 .493 .633 r
.37674 .53873 m .37319 .53574 L .37522 .53554 L F
.37674 .53873 m .37326 .53905 L .37319 .53574 L F
.847 .789 .795 r
.53796 .56658 m .53381 .56744 L .5368 .56511 L F
.613 .165 .162 r
.53796 .56658 m .5363 .56825 L .53381 .56744 L F
.633 .121 0 r
.53796 .56658 m .53876 .56792 L .5363 .56825 L F
.53796 .56658 m .54008 .56902 L .53876 .56792 L F
.331 .221 .575 r
.15872 .58507 m .1606 .58119 L .15845 .58244 L F
.533 0 0 r
.2023 .6247 m .19808 .62188 L .20076 .62505 L F
.125 .557 .921 r
.33999 .5383 m .33921 .53893 L .33659 .53938 L F
.33999 .5383 m .34157 .53958 L .33921 .53893 L F
.594 .402 .591 r
.3235 .60073 m .32348 .60342 L .32602 .60056 L F
.3235 .60073 m .32348 .60342 L .32602 .60056 L F
.538 .296 .496 r
.30924 .5667 m .31172 .56633 L .31196 .56391 L F
.598 .456 .659 r
.31196 .56391 m .31523 .56346 L .31424 .56043 L F
.414 .11 .339 r
.31172 .56633 m .31523 .56346 L .31196 .56391 L F
.645 .468 .629 r
.28224 .63084 m .28475 .6313 L .28449 .62856 L F
.394 .382 .728 r
.28355 .62488 m .28449 .62856 L .28618 .62797 L F
.355 .253 .6 r
.28449 .62856 m .28645 .63071 L .28618 .62797 L F
.28449 .62856 m .28475 .6313 L .28645 .63071 L F
.629 .607 .809 r
.33518 .56477 m .33193 .56657 L .33152 .56471 L F
0 0 0 r
.21885 .53848 m .22109 .53791 L .22294 .53691 L F
.231 0 0 r
.22109 .53791 m .22533 .53616 L .22294 .53691 L F
.228 .389 .816 r
.19587 .62061 m .19639 .61825 L .19455 .61864 L F
.19587 .62061 m .19808 .62188 L .19639 .61825 L F
.403 .366 .703 r
.29436 .56957 m .29554 .56577 L .29332 .5669 L F
.29436 .56957 m .29604 .56919 L .29554 .56577 L F
.285 .13 .488 r
.29436 .56957 m .29583 .57142 L .29604 .56919 L F
.29436 .56957 m .29439 .57259 L .29583 .57142 L F
.8 .611 .646 r
.33793 .57291 m .33768 .57587 L .33918 .57509 L F
.503 .193 .374 r
.33767 .57734 m .33918 .57509 L .33768 .57587 L F
.33767 .57734 m .33904 .57831 L .33918 .57509 L F
.424 .44 .772 r
.33904 .57831 m .33864 .57428 L .33918 .57509 L F
.331 .165 .5 r
.29038 .57803 m .29305 .57599 L .29084 .57662 L F
.602 .607 .829 r
.78432 .41863 m .7857 .41439 L .78312 .41529 L F
.78432 .41863 m .78684 .41796 L .7857 .41439 L F
.388 .052 .269 r
.36378 .54905 m .36303 .5512 L .36049 .55146 L F
.014 0 .106 r
.36552 .54767 m .36303 .5512 L .36378 .54905 L F
.373 .18 .486 r
.51321 .52965 m .51107 .53349 L .51113 .53122 L F
.974 .706 .462 r
.51158 .53174 m .51113 .53122 L .50922 .53169 L F
.51158 .53174 m .51321 .52965 L .51113 .53122 L F
.009 0 0 r
.20336 .56465 m .20297 .56367 L .20515 .56294 L F
.20336 .56465 m .20125 .56565 L .20297 .56367 L F
.143 0 .078 r
.37236 .5632 m .36936 .56575 L .3702 .56421 L F
.763 .753 .844 r
.50859 .56684 m .50483 .5663 L .50707 .56517 L F
.757 .364 .31 r
.50859 .56684 m .50696 .56879 L .50483 .5663 L F
.322 .58 .935 r
.50707 .56517 m .50961 .56531 L .50859 .56684 L F
.647 .225 .228 r
.51114 .56864 m .50859 .56684 L .50961 .56531 L F
.51114 .56864 m .50696 .56879 L .50859 .56684 L F
.597 .511 .728 r
.341 .62415 m .33772 .62224 L .34029 .62176 L F
.341 .62415 m .33848 .62468 L .33772 .62224 L F
.194 .621 .946 r
.21219 .61633 m .21143 .61719 L .20946 .61582 L F
.21219 .61633 m .21378 .61748 L .21143 .61719 L F
.675 .125 0 r
.19691 .59999 m .2008 .60263 L .19815 .60186 L F
.563 .789 .984 r
.22835 .75765 m .22644 .75836 L .22421 .75685 L F
.271 .763 .694 r
.22467 .75896 m .22644 .75836 L .22835 .75765 L F
.031 0 .403 r
.34075 .62559 m .33848 .62468 L .341 .62415 L F
.34075 .62559 m .33849 .62768 L .33848 .62468 L F
.239 .687 .955 r
.33547 .57208 m .33765 .57249 L .33793 .57291 L F
.709 .626 .062 r
.3378 .57432 m .33793 .57291 L .33765 .57249 L F
.3378 .57432 m .33768 .57587 L .33793 .57291 L F
.544 .529 .789 r
.29089 .55407 m .29134 .55709 L .29362 .55601 L F
.457 .886 .844 r
.25175 .71563 m .25245 .71554 L .25451 .71457 L F
.565 .565 .812 r
.31776 .58843 m .31382 .58507 L .31586 .58417 L F
.558 .62 .87 r
.2831 .66141 m .2828 .66567 L .2809 .66245 L F
.2831 .66141 m .28528 .66516 L .2828 .66567 L F
.287 0 .033 r
.2828 .66567 m .28337 .66725 L .28081 .66698 L F
.2828 .66567 m .28528 .66516 L .28337 .66725 L F
.796 .645 .694 r
.79064 .41862 m .793 .41578 L .7892 .41501 L F
.709 .513 .622 r
.79064 .41862 m .79322 .41841 L .793 .41578 L F
.666 .356 .437 r
.31367 .64895 m .31143 .64687 L .31399 .64679 L F
.31367 .64895 m .3099 .6494 L .31143 .64687 L F
.394 .382 .728 r
.28355 .62488 m .28618 .62797 L .28605 .62481 L F
.348 0 0 r
.31323 .59151 m .31299 .5912 L .31491 .59122 L F
.752 .376 .341 r
.31646 .59578 m .32066 .59633 L .32074 .59463 L F
.32035 .59441 m .32074 .59463 L .32076 .59427 L F
.491 .529 .823 r
.31507 .59139 m .31887 .59512 L .31825 .59321 L F
.678 .595 .756 r
.3174 .59063 m .31887 .59512 L .32076 .59427 L F
.752 .376 .341 r
.31646 .59578 m .32076 .59427 L .31887 .59512 L F
.31646 .59578 m .32074 .59463 L .32035 .59441 L F
.491 .529 .823 r
.31491 .59122 m .31507 .59139 L .3174 .59063 L F
.31507 .59139 m .31825 .59321 L .3174 .59063 L F
.845 .903 .877 r
.82362 .40891 m .82736 .40729 L .82587 .40574 L F
.158 .648 .919 r
.31721 .53486 m .32107 .53581 L .31893 .53563 L F
.222 .691 .942 r
.23196 .63732 m .23416 .63736 L .23015 .63653 L F
.435 .202 .461 r
.32231 .57468 m .32102 .57894 L .31834 .57948 L F
.194 .025 .411 r
.32326 .5727 m .32329 .5753 L .32231 .57468 L F
.136 0 .314 r
.3226 .57759 m .32231 .57468 L .32329 .5753 L F
.3226 .57759 m .32102 .57894 L .32231 .57468 L F
.617 .215 .26 r
.28289 .6335 m .28224 .63084 L .28079 .63299 L F
.28289 .6335 m .28475 .6313 L .28224 .63084 L F
.733 .52 .604 r
.28289 .6335 m .28645 .63071 L .28475 .6313 L F
.28289 .6335 m .28678 .63329 L .28645 .63071 L F
0 .206 .731 r
.28406 .6334 m .28327 .63347 L .28163 .63154 L F
.28327 .63347 m .28289 .6335 L .28257 .63301 L F
.28327 .63347 m .28257 .63301 L .28163 .63154 L F
.558 .088 .096 r
.28079 .63299 m .28133 .6322 L .27847 .63105 L F
.28133 .6322 m .28224 .63084 L .27948 .63099 L F
.28133 .6322 m .27948 .63099 L .27847 .63105 L F
.55 .447 .69 r
.36326 .55587 m .36178 .56014 L .36217 .55758 L F
.655 .451 .596 r
.33911 .63113 m .33646 .63403 L .33655 .63149 L F
.084 0 0 r
.36571 .54218 m .36808 .54457 L .36791 .54179 L F
.597 .388 .569 r
.36791 .54179 m .36663 .5431 L .36571 .54218 L F
.36663 .5431 m .36536 .54439 L .36571 .54218 L F
.66 .481 .631 r
.36663 .5431 m .36808 .54457 L .36536 .54439 L F
.36791 .54179 m .36808 .54457 L .36663 .5431 L F
.084 0 0 r
.36663 .5431 m .36649 .54292 L .36785 .54434 L F
.36571 .54218 m .36579 .54225 L .36663 .5431 L F
.36579 .54225 m .36649 .54292 L .36663 .5431 L F
.36571 .54218 m .36785 .54434 L .36808 .54457 L F
.454 .075 .231 r
.36649 .54292 m .37056 .54047 L .36808 .54457 L F
.36649 .54292 m .36887 .54291 L .37056 .54047 L F
.197 .697 .911 r
.36483 .54239 m .36763 .54275 L .36649 .54292 L F
.36763 .54275 m .36887 .54291 L .36649 .54292 L F
.084 0 0 r
.36571 .54218 m .36484 .54316 L .36649 .54292 L F
.36484 .54316 m .36405 .54405 L .36649 .54292 L F
.623 .454 .633 r
.3222 .646 m .31984 .64326 L .3233 .64441 L F
.185 0 .055 r
.32534 .64383 m .3222 .646 L .3233 .64441 L F
.569 .321 .501 r
.29498 .56323 m .29762 .56328 L .29804 .56034 L F
.47 .265 .519 r
.29804 .56034 m .30082 .55995 L .30068 .55695 L F
.489 .266 .502 r
.29762 .56328 m .30082 .55995 L .29804 .56034 L F
.388 .3 .634 r
.29894 .59458 m .30072 .59031 L .29855 .59168 L F
.991 .734 .424 r
.34172 .64074 m .34051 .64032 L .34082 .63736 L F
.265 .082 .436 r
.344 .6376 m .34323 .64039 L .34172 .64074 L F
.92 .956 .794 r
.34274 .63701 m .34172 .64074 L .34082 .63736 L F
.34274 .63701 m .34051 .64032 L .34172 .64074 L F
.326 .285 .659 r
.34323 .64039 m .34393 .64284 L .34172 .64074 L F
.265 .082 .436 r
.34172 .64074 m .34323 .64039 L .344 .6376 L F
.344 .6376 m .34323 .64039 L .34172 .64074 L F
.289 .767 .928 r
.34172 .64074 m .34323 .64039 L .34051 .64032 L F
.326 .285 .659 r
.34323 .64039 m .34393 .64284 L .34172 .64074 L F
.302 .282 .671 r
.29381 .61236 m .29431 .61613 L .29615 .61466 L F
.406 .258 .566 r
.29431 .61613 m .29637 .61812 L .29615 .61466 L F
.29431 .61613 m .2945 .61876 L .29637 .61812 L F
.869 .907 .498 r
.55061 .5495 m .55042 .55152 L .55176 .54791 L F
.813 .826 .351 r
.54998 .55157 m .55042 .55152 L .55061 .5495 L F
.412 .181 .451 r
.34277 .61611 m .3424 .6186 L .34021 .61914 L F
.596 .515 .733 r
.3424 .6186 m .34029 .62176 L .34021 .61914 L F
.302 .282 .671 r
.29381 .61236 m .29615 .61466 L .29587 .61213 L F
.391 .669 .97 r
.21613 .63084 m .21692 .63221 L .21937 .63115 L F
.536 .701 .946 r
.21692 .63221 m .22241 .63333 L .21937 .63115 L F
.644 .912 .981 r
.35958 .54685 m .35674 .54809 L .35779 .54629 L F
.721 .989 .855 r
.35674 .54809 m .35574 .54806 L .35779 .54629 L F
.421 .285 .589 r
.29762 .60095 m .29995 .6005 L .2999 .59665 L F
.288 .194 .57 r
.29762 .60095 m .29943 .60188 L .29995 .6005 L F
.29762 .60095 m .29773 .60411 L .29943 .60188 L F
.515 .727 .969 r
.2746 .64469 m .27873 .64625 L .27684 .64392 L F
.209 .517 .915 r
.27684 .64392 m .27873 .64625 L .27956 .64503 L F
0 0 0 r
.26985 .62657 m .26838 .62838 L .27006 .6251 L F
0 0 .026 r
.27286 .62165 m .27195 .62427 L .27006 .6251 L F
.005 0 .072 r
.27195 .62427 m .26985 .62657 L .27006 .6251 L F
.508 .363 .619 r
.34716 .61213 m .34438 .60984 L .34672 .60825 L F
.34716 .61213 m .34468 .61278 L .34438 .60984 L F
.474 .365 .65 r
.77133 .40365 m .77422 .40533 L .77454 .40384 L F
.391 .39 .738 r
.77225 .40583 m .77422 .40533 L .77133 .40365 L F
.513 .873 .642 r
.25775 .62432 m .25858 .62347 L .25979 .62343 L F
.25775 .62432 m .25685 .62488 L .25858 .62347 L F
.174 .395 .838 r
.29937 .57758 m .30102 .58238 L .29836 .57778 L F
.444 0 0 r
.30102 .58238 m .30173 .58366 L .30016 .58433 L F
.614 .626 .839 r
.29867 .60617 m .29943 .60188 L .29773 .60411 L F
.29867 .60617 m .30099 .60602 L .29943 .60188 L F
.617 .604 .815 r
.29867 .60617 m .30148 .60657 L .30099 .60602 L F
.488 .439 .728 r
.29867 .60617 m .3016 .60892 L .30148 .60657 L F
.29867 .60617 m .29966 .60993 L .3016 .60892 L F
.52 .274 .482 r
.34486 .61809 m .3424 .6186 L .34277 .61611 L F
.438 .276 .563 r
.34488 .61545 m .34486 .61809 L .34277 .61611 L F
.34488 .61545 m .34486 .61809 L .34277 .61611 L F
0 0 0 r
.3016 .60892 m .29966 .60993 L .29816 .61168 L F
.663 .363 .453 r
.29939 .58705 m .29354 .58828 L .29467 .58567 L F
.185 .377 .819 r
.30068 .55695 m .3021 .55639 L .29946 .55481 L F
.49 .28 .521 r
.30068 .55695 m .30312 .55899 L .3021 .55639 L F
.30068 .55695 m .30082 .55995 L .30312 .55899 L F
.373 .18 .486 r
.51321 .52965 m .5131 .53223 L .51107 .53349 L F
.974 .706 .462 r
.51158 .53174 m .5131 .53223 L .51321 .52965 L F
.494 .313 .564 r
.51321 .52965 m .51566 .52923 L .5156 .52656 L F
.479 .265 .51 r
.51321 .52965 m .51566 .52923 L .5131 .53223 L F
.51321 .52965 m .51566 .52923 L .5131 .53223 L F
.644 .472 .635 r
.31663 .64648 m .31399 .64679 L .31657 .64375 L F
.654 .479 .634 r
.31984 .64326 m .31663 .64648 L .31657 .64375 L F
.86 .953 .871 r
.30673 .60571 m .30842 .60605 L .30762 .60246 L F
0 .476 .712 r
.3082 .60595 m .30842 .60605 L .30673 .60571 L F
.508 .31 .546 r
.31316 .60025 m .31244 .60447 L .31034 .60398 L F
.17 .015 .415 r
.31451 .60224 m .31306 .6038 L .31316 .60025 L F
.31306 .6038 m .31244 .60447 L .3126 .6035 L F
.31306 .6038 m .3126 .6035 L .31316 .60025 L F
.179 .427 .861 r
.31505 .60557 m .31244 .60447 L .31451 .60224 L F
.995 .871 .566 r
.31426 .60348 m .31505 .60557 L .31427 .60342 L F
0 .121 .668 r
.31372 .60446 m .31459 .60483 L .31458 .60482 L F
.31364 .60417 m .31476 .60489 L .31261 .60041 L F
.31372 .60446 m .31476 .60489 L .31364 .60417 L F
.465 .467 .775 r
.31637 .60862 m .31447 .60918 L .31348 .60534 L F
.179 .427 .861 r
.31338 .60487 m .31337 .60524 L .31279 .60476 L F
.31298 .6047 m .31279 .60476 L .31244 .60447 L F
.31338 .60487 m .31279 .60476 L .31298 .6047 L F
.403 .494 .839 r
.31244 .60447 m .31348 .60534 L .31034 .60398 L F
.53 .758 .98 r
.30762 .60246 m .30842 .60605 L .31339 .60456 L F
.238 .749 .729 r
.31352 .60452 m .30842 .60605 L .3082 .60595 L F
.53 .758 .98 r
.3134 .60436 m .31339 .60456 L .31372 .60446 L F
.238 .749 .729 r
.31372 .60446 m .31339 .60456 L .31352 .60452 L F
.31339 .60456 m .30842 .60605 L .31352 .60452 L F
.179 .427 .861 r
.31505 .60557 m .31337 .60524 L .31338 .60487 L F
.465 .467 .775 r
.31637 .60862 m .31348 .60534 L .31505 .60557 L F
.238 .749 .729 r
.31372 .60446 m .3082 .60595 L .31179 .60455 L F
.11 0 .207 r
.31366 .60709 m .31372 .60461 L .31179 .60455 L F
.31372 .60461 m .31372 .60446 L .31358 .60447 L F
.31372 .60461 m .31358 .60447 L .31179 .60455 L F
.179 .427 .861 r
.31453 .60547 m .31348 .60534 L .31337 .60524 L F
.31505 .60557 m .31456 .6055 L .31453 .60547 L F
.31456 .6055 m .31348 .60534 L .31453 .60547 L F
.53 .758 .98 r
.30762 .60246 m .31339 .60456 L .3134 .60436 L F
.995 .871 .566 r
.31366 .60709 m .31482 .60582 L .31459 .60483 L F
.31482 .60582 m .31505 .60557 L .31426 .60348 L F
.11 0 .207 r
.31366 .60709 m .31476 .6049 L .31459 .60483 L F
.31366 .60709 m .31459 .60483 L .31372 .60446 L F
0 .181 .706 r
.31261 .60041 m .31445 .60424 L .31427 .60342 L F
.31445 .60424 m .31476 .6049 L .31427 .60342 L F
.995 .871 .566 r
.31366 .60709 m .31458 .60485 L .31426 .60348 L F
.31458 .60485 m .31459 .60483 L .31445 .60424 L F
.31458 .60485 m .31445 .60424 L .31426 .60348 L F
0 .121 .668 r
.31458 .60482 m .31476 .6049 L .31476 .60489 L F
.31459 .60483 m .31476 .6049 L .31458 .60482 L F
.418 .325 .643 r
.36296 .57793 m .36293 .58185 L .36098 .58232 L F
.439 .408 .727 r
.36293 .58185 m .3638 .58411 L .36098 .58232 L F
.434 .409 .731 r
.36098 .58232 m .3638 .58411 L .36192 .58465 L F
.779 .986 .739 r
.33916 .56279 m .33864 .56417 L .34087 .56171 L F
.318 .715 .98 r
.28665 .53099 m .28604 .53201 L .28428 .53133 L F
.28665 .53099 m .28826 .53203 L .28604 .53201 L F
.029 0 0 r
.23785 .5353 m .24013 .53516 L .24151 .53492 L F
.192 .721 .737 r
.24013 .53516 m .24408 .53435 L .24151 .53492 L F
.558 .656 .901 r
.2764 .66871 m .27777 .6715 L .27354 .66977 L F
.579 .56 .797 r
.27892 .66738 m .27777 .6715 L .2764 .66871 L F
.27892 .66738 m .2802 .67097 L .27777 .6715 L F
.456 .564 .876 r
.18862 .61609 m .18845 .61266 L .18691 .61267 L F
.18862 .61609 m .19059 .61583 L .18845 .61266 L F
.914 .626 .483 r
.32766 .58436 m .32977 .58497 L .32831 .58668 L F
.878 .843 .807 r
.2768 .54524 m .2809 .54519 L .2789 .54417 L F
.2768 .54524 m .27688 .54605 L .2809 .54519 L F
0 0 .343 r
.27688 .54605 m .27808 .54664 L .2809 .54519 L F
0 0 .366 r
.2809 .54519 m .2813 .54247 L .2789 .54417 L F
.2809 .54519 m .28222 .5473 L .2813 .54247 L F
.736 .282 .173 r
.27808 .54664 m .28222 .5473 L .2809 .54519 L F
.68 .575 .731 r
.33468 .64024 m .33175 .64117 L .33141 .63797 L F
.541 .217 .367 r
.33468 .64024 m .33135 .643 L .33175 .64117 L F
.894 .841 .785 r
.53512 .539 m .53343 .5381 L .53549 .53468 L F
.909 .636 .51 r
.53512 .539 m .53319 .54074 L .53343 .5381 L F
.53512 .539 m .53512 .54151 L .53319 .54074 L F
.447 .739 .99 r
.30275 .53254 m .30233 .53424 L .3006 .53279 L F
.30275 .53254 m .30508 .53402 L .30233 .53424 L F
.246 .512 .907 r
.17672 .60735 m .17731 .60577 L .17584 .6057 L F
.17672 .60735 m .18015 .60902 L .17731 .60577 L F
.292 .011 .302 r
.16063 .57589 m .16253 .57527 L .16323 .57315 L F
.341 .054 .324 r
.16323 .57315 m .16459 .57463 L .16534 .57244 L F
.16323 .57315 m .16253 .57527 L .16459 .57463 L F
.247 0 .002 r
.28869 .5453 m .28707 .54738 L .2847 .54805 L F
.32 0 .046 r
.28942 .54682 m .28869 .5453 L .29105 .54498 L F
.28942 .54682 m .28707 .54738 L .28869 .5453 L F
.558 .656 .901 r
.2764 .66871 m .27354 .66977 L .27262 .67102 L F
.419 .229 .514 r
.2702 .63105 m .26838 .62838 L .26985 .62657 L F
.2702 .63105 m .26803 .63155 L .26838 .62838 L F
0 0 0 r
.51107 .53349 m .50711 .53496 L .50922 .53169 L F
.51107 .53349 m .50925 .53431 L .50711 .53496 L F
.51107 .53349 m .51188 .53397 L .50925 .53431 L F
.51107 .53349 m .5131 .53223 L .51188 .53397 L F
.918 .858 .766 r
.27262 .67102 m .2764 .66534 L .2747 .66443 L F
0 0 0 r
.34138 .56172 m .34087 .56171 L .34307 .56036 L F
.34138 .56172 m .33916 .56279 L .34087 .56171 L F
.344 .159 .479 r
.16045 .57839 m .16253 .57527 L .16063 .57589 L F
.981 .835 .624 r
.32326 .5727 m .32129 .57146 L .32314 .56994 L F
.034 0 .364 r
.32447 .57409 m .32329 .5753 L .32326 .5727 L F
.869 .604 .075 r
.5523 .53529 m .55267 .538 L .55315 .5388 L F
.957 .902 .728 r
.55267 .538 m .55261 .54128 L .55315 .5388 L F
.571 .217 .329 r
.24468 .54798 m .24188 .55131 L .24028 .55064 L F
.707 .389 .436 r
.24705 .5509 m .24468 .54798 L .24616 .54844 L F
.24705 .5509 m .24188 .55131 L .24468 .54798 L F
.656 .577 .754 r
.31424 .56043 m .31646 .55733 L .31376 .55858 L F
.31424 .56043 m .31718 .56065 L .31646 .55733 L F
.611 .463 .656 r
.31424 .56043 m .31696 .56287 L .31718 .56065 L F
.31424 .56043 m .31523 .56346 L .31696 .56287 L F
.049 0 0 r
.32102 .57894 m .31752 .58124 L .31834 .57948 L F
.733 .761 .875 r
.2023 .6247 m .20411 .62627 L .20636 .62509 L F
.215 0 0 r
.25215 .55437 m .25016 .55577 L .24778 .55607 L F
.269 0 0 r
.25453 .55411 m .25016 .55577 L .25215 .55437 L F
.868 .904 .855 r
.25293 .70533 m .25565 .7026 L .25325 .70184 L F
.371 .817 .948 r
.25565 .7026 m .25605 .70172 L .25325 .70184 L F
.25565 .7026 m .25798 .70213 L .25605 .70172 L F
0 0 .168 r
.2756 .60358 m .27362 .60694 L .27481 .60582 L F
0 0 .185 r
.27481 .60582 m .27362 .60694 L .27289 .60928 L F
.81 .885 .899 r
.26957 .67314 m .26974 .67603 L .26719 .67385 L F
.26957 .67314 m .27251 .67404 L .26974 .67603 L F
.242 0 .303 r
.27759 .6154 m .27937 .61133 L .2787 .61432 L F
.108 0 .434 r
.27937 .61133 m .28151 .60866 L .28111 .61118 L F
0 0 .098 r
.2787 .61432 m .27937 .61133 L .28111 .61118 L F
.683 .229 .169 r
.35214 .59063 m .35615 .59116 L .35372 .59219 L F
.253 .139 .525 r
.30841 .57854 m .30975 .57525 L .30905 .57626 L F
.517 .782 .993 r
.22358 .74187 m .22599 .74347 L .22826 .74278 L F
.337 .092 .388 r
.2744 .62023 m .27286 .62165 L .27527 .6188 L F
0 0 .02 r
.27342 .62306 m .27286 .62165 L .2744 .62023 L F
.27342 .62306 m .27195 .62427 L .27286 .62165 L F
.713 .677 .813 r
.32951 .57208 m .3332 .57287 L .33218 .57036 L F
.559 .405 .629 r
.33339 .57557 m .33547 .57208 L .3332 .57287 L F
.647 .737 .915 r
.22193 .7578 m .22045 .75909 L .21857 .75751 L F
.589 .542 .77 r
.33889 .54442 m .34011 .54803 L .33745 .54828 L F
.824 .561 .542 r
.33974 .55133 m .33745 .54828 L .34011 .54803 L F
.33974 .55133 m .33788 .55097 L .33745 .54828 L F
.665 .758 .919 r
.54008 .56902 m .54088 .57094 L .54414 .5697 L F
.245 0 .172 r
.17107 .56617 m .17197 .56795 L .17276 .56592 L F
.17107 .56617 m .16997 .56866 L .17197 .56795 L F
.256 .763 .865 r
.22091 .55844 m .2186 .55827 L .21653 .55864 L F
.205 0 0 r
.22324 .5577 m .2186 .55827 L .22091 .55844 L F
.636 .509 .691 r
.36713 .56929 m .3633 .56668 L .36708 .56579 L F
.36713 .56929 m .36462 .56961 L .3633 .56668 L F
.632 .9 .985 r
.31088 .53315 m .309 .5342 L .30678 .53339 L F
.708 .215 .069 r
.5375 .52252 m .53916 .52345 L .5408 .52338 L F
.735 .259 .113 r
.53916 .52345 m .53971 .52475 L .5408 .52338 L F
.651 .155 .058 r
.53971 .52475 m .54361 .52533 L .5408 .52338 L F
0 0 0 r
.19632 .5689 m .19376 .5719 L .19479 .57005 L F
.559 .715 .945 r
.26674 .64229 m .26812 .64417 L .26957 .64191 L F
.425 .535 .865 r
.26812 .64417 m .27073 .64477 L .26957 .64191 L F
.627 .565 .765 r
.34269 .54748 m .33889 .54442 L .34332 .54536 L F
.575 .265 .406 r
.34522 .54686 m .34332 .54536 L .34534 .54446 L F
.34522 .54686 m .34269 .54748 L .34332 .54536 L F
.567 .299 .469 r
.31399 .64679 m .31618 .64894 L .31367 .64895 L F
.591 .296 .436 r
.31663 .64648 m .31618 .64894 L .31399 .64679 L F
0 0 0 r
.22592 .55174 m .22465 .55351 L .2238 .55378 L F
.22581 .55218 m .22592 .55174 L .22787 .55088 L F
.22581 .55218 m .22465 .55351 L .22592 .55174 L F
.531 .614 .88 r
.19273 .60085 m .19466 .60347 L .19221 .60369 L F
0 0 0 r
.2166 .53904 m .21664 .53956 L .21885 .53848 L F
.2166 .53904 m .21476 .5405 L .21664 .53956 L F
.026 0 .06 r
.34954 .60304 m .34834 .60561 L .34672 .60643 L F
.356 0 .18 r
.3517 .60271 m .34834 .60561 L .34954 .60304 L F
0 0 0 r
.3156 .59582 m .31646 .59578 L .31887 .59512 L F
0 .142 .66 r
.31731 .59412 m .31773 .59571 L .31646 .59578 L F
.32 .044 .329 r
.3181 .59678 m .31548 .59963 L .31605 .59749 L F
.516 .293 .514 r
.3181 .59678 m .31788 .59923 L .31548 .59963 L F
0 .089 .644 r
.31646 .59578 m .31788 .59923 L .3181 .59678 L F
0 .142 .66 r
.31773 .59571 m .31835 .59808 L .31646 .59578 L F
0 0 0 r
.31414 .59614 m .31646 .59578 L .3156 .59582 L F
.966 .874 .693 r
.81709 .39595 m .81731 .40021 L .81838 .39657 L F
.984 .732 .47 r
.30751 .56548 m .3089 .56906 L .30924 .5667 L F
.53 .272 .469 r
.30924 .5667 m .3089 .56906 L .31172 .56633 L F
0 0 .147 r
.27759 .6154 m .27686 .61786 L .27527 .6188 L F
0 0 0 r
.27584 .6198 m .27527 .6188 L .27686 .61786 L F
.27584 .6198 m .2744 .62023 L .27527 .6188 L F
0 0 .208 r
.27308 .67103 m .27251 .67404 L .26957 .67314 L F
.473 .341 .62 r
.36303 .5512 m .36293 .55335 L .36049 .55146 L F
.394 .279 .603 r
.36458 .58594 m .36192 .58465 L .3638 .58411 L F
.36458 .58594 m .36174 .58818 L .36192 .58465 L F
.685 .306 .322 r
.28061 .65168 m .28228 .64933 L .27883 .64976 L F
.5 .728 .974 r
.28048 .64819 m .28228 .64933 L .28405 .64848 L F
0 0 0 r
.28405 .64848 m .28228 .64933 L .28061 .65168 L F
0 0 .474 r
.51197 .54925 m .51111 .55105 L .5105 .54831 L F
.51197 .54925 m .5105 .54831 L .50965 .5506 L F
.756 .505 .553 r
.34555 .55742 m .34943 .56029 L .34857 .55701 L F
.34555 .55742 m .34529 .5601 L .34943 .56029 L F
.362 .517 .877 r
.18015 .60902 m .18054 .61053 L .18144 .60847 L F
.483 .66 .939 r
.18054 .61053 m .18605 .61205 L .18144 .60847 L F
.68 .575 .731 r
.33468 .64024 m .33141 .63797 L .33386 .63735 L F
.738 .702 .817 r
.36597 .56076 m .36178 .56014 L .36398 .56179 L F
.845 .996 .761 r
.36597 .56076 m .36398 .56179 L .367 .55783 L F
.794 .983 .716 r
.16327 .60357 m .16066 .60667 L .16102 .60515 L F
.947 .686 .508 r
.16102 .60515 m .16311 .60647 L .16327 .60357 L F
.472 .379 .669 r
.36448 .57246 m .36276 .57594 L .36203 .5731 L F
.36448 .57246 m .365 .5754 L .36276 .57594 L F
.081 0 .198 r
.365 .5754 m .36296 .57793 L .36276 .57594 L F
.151 0 .107 r
.1991 .56643 m .19632 .5689 L .19722 .56732 L F
.11 .217 .695 r
.27658 .65244 m .27746 .65623 L .27846 .65434 L F
.234 .376 .803 r
.27746 .65623 m .28065 .65833 L .27846 .65434 L F
.487 .307 .563 r
.51566 .52923 m .51805 .5285 L .5156 .52656 L F
.471 .804 .999 r
.29267 .53151 m .29222 .53294 L .29058 .53152 L F
.29267 .53151 m .29453 .53249 L .29222 .53294 L F
.351 .362 .731 r
.33574 .58543 m .33684 .58819 L .33827 .58719 L F
.418 0 0 r
.33574 .58543 m .33652 .58603 L .33353 .58612 L F
.33574 .58543 m .33827 .58719 L .33652 .58603 L F
.596 .515 .733 r
.3424 .6186 m .34326 .62156 L .34029 .62176 L F
.525 .37 .613 r
.34326 .62156 m .341 .62415 L .34029 .62176 L F
.405 .12 .363 r
.31605 .59749 m .31548 .59963 L .31316 .60025 L F
.745 .815 .907 r
.19722 .59736 m .19327 .59716 L .19579 .59572 L F
.982 .752 .514 r
.19722 .59736 m .19579 .59572 L .19327 .59716 L F
0 0 0 r
.19329 .59794 m .19327 .59716 L .19579 .59572 L F
.967 .791 .614 r
.19579 .59572 m .19422 .597 L .19433 .59701 L F
.19579 .59572 m .19433 .59701 L .19722 .59736 L F
.982 .752 .514 r
.19579 .59572 m .19722 .59736 L .19422 .597 L F
0 0 0 r
.19329 .598 m .19329 .59794 L .19579 .59572 L F
.982 .752 .514 r
.19722 .59736 m .19691 .59999 L .19579 .59572 L F
.19579 .59572 m .19691 .59999 L .19722 .59736 L F
.66 .192 .129 r
.26303 .55312 m .259 .55269 L .26091 .55128 L F
0 .014 .589 r
.23438 .72367 m .23618 .72596 L .2368 .72346 L F
.704 .842 .949 r
.24969 .69848 m .25158 .69982 L .25433 .69825 L F
.432 .743 .993 r
.16066 .60667 m .16311 .60647 L .16102 .60515 L F
.038 .587 .834 r
.32107 .53581 m .32318 .53601 L .32491 .53654 L F
.089 .627 .855 r
.32318 .53601 m .32765 .53668 L .32491 .53654 L F
.541 .217 .367 r
.33468 .64024 m .33415 .64315 L .33135 .643 L F
.293 .362 .763 r
.33386 .63735 m .33648 .63997 L .33468 .64024 L F
.22 0 .272 r
.33602 .64198 m .33468 .64024 L .33648 .63997 L F
.33602 .64198 m .33415 .64315 L .33468 .64024 L F
.569 .765 .971 r
.23471 .73994 m .23541 .73775 L .23327 .73794 L F
.23471 .73994 m .23711 .73937 L .23541 .73775 L F
.63 .573 .771 r
.81198 .41311 m .81344 .40835 L .81078 .4092 L F
.81198 .41311 m .81463 .41218 L .81344 .40835 L F
.554 .784 .984 r
.33616 .53699 m .33521 .53894 L .33361 .53753 L F
.685 .552 .698 r
.3209 .60916 m .32372 .60601 L .32114 .60667 L F
0 0 0 r
.22581 .55218 m .22506 .5531 L .22465 .55351 L F
.965 .817 .647 r
.22465 .55351 m .22495 .55624 L .22398 .55415 L F
.22465 .55351 m .22332 .55527 L .22495 .55624 L F
0 0 0 r
.22506 .5531 m .22332 .55527 L .22465 .55351 L F
.965 .817 .647 r
.22465 .55351 m .22398 .55415 L .2238 .55378 L F
.469 .873 .957 r
.25908 .53265 m .25705 .53336 L .25469 .53298 L F
.158 0 .036 r
.18818 .55378 m .1896 .55337 L .19067 .55189 L F
.18818 .55378 m .18766 .55417 L .1896 .55337 L F
.171 .647 .929 r
.23418 .62295 m .23149 .62283 L .22973 .62196 L F
.325 .679 .978 r
.22241 .63333 m .22307 .63255 L .21937 .63115 L F
.22241 .63333 m .22501 .63375 L .22307 .63255 L F
.197 0 .016 r
.18766 .55417 m .18823 .5557 L .1896 .55337 L F
.18766 .55417 m .18611 .55637 L .18823 .5557 L F
.496 .125 .264 r
.2297 .55723 m .22884 .55868 L .22689 .55733 L F
.2297 .55723 m .22884 .55868 L .22689 .55733 L F
.629 .607 .809 r
.33518 .56477 m .33152 .56471 L .33269 .56253 L F
0 0 0 r
.27695 .60175 m .2756 .60358 L .27481 .60582 L F
.654 .479 .634 r
.31984 .64326 m .31992 .64664 L .31663 .64648 L F
.623 .454 .633 r
.3222 .646 m .31992 .64664 L .31984 .64326 L F
.807 .6 .622 r
.7857 .41439 m .78935 .41251 L .78734 .41158 L F
.7857 .41439 m .7892 .41501 L .78935 .41251 L F
.825 .618 .622 r
.33974 .55133 m .33773 .5536 L .33788 .55097 L F
.626 .559 .759 r
.34269 .54748 m .33974 .55133 L .34011 .54803 L F
.687 .791 .929 r
.34657 .54955 m .33974 .55133 L .34269 .54748 L F
.666 .802 .947 r
.18393 .58487 m .18193 .58584 L .18008 .58442 L F
.682 .979 .854 r
.81956 .40479 m .82036 .40367 L .8221 .4027 L F
.81956 .40479 m .81862 .40457 L .82036 .40367 L F
0 0 .333 r
.55112 .54456 m .5519 .54744 L .55176 .54791 L F
.695 .862 .455 r
.5519 .54744 m .55061 .5495 L .55176 .54791 L F
.254 .71 .953 r
.24846 .63997 m .25048 .63995 L .24679 .63926 L F
.591 .948 .845 r
.25784 .69255 m .25232 .69518 L .25535 .69508 L F
.472 .119 .284 r
.25912 .69313 m .25777 .69263 L .25808 .69367 L F
.25808 .69367 m .25777 .69263 L .25535 .69508 L F
.25912 .69313 m .25535 .69508 L .25837 .69277 L F
.57 .442 .667 r
.26082 .6917 m .25912 .69313 L .25837 .69277 L F
.225 0 .329 r
.26007 .69212 m .25837 .69277 L .25815 .69391 L F
.25856 .69526 m .25815 .69391 L .25744 .69758 L F
.26007 .69212 m .25815 .69391 L .25856 .69526 L F
.472 .119 .284 r
.25912 .69313 m .25784 .69255 L .25777 .69263 L F
0 .002 .55 r
.33772 .5753 m .33767 .57734 L .33768 .57587 L F
.218 0 0 r
.33762 .57599 m .33525 .57745 L .33777 .57633 L F
0 .002 .55 r
.3378 .57432 m .33839 .57605 L .33767 .57734 L F
.218 0 0 r
.33775 .576 m .33777 .57633 L .33839 .57605 L F
0 .002 .55 r
.33774 .57568 m .33767 .57734 L .33772 .5753 L F
.218 0 0 r
.33762 .57599 m .33777 .57633 L .33775 .576 L F
0 .002 .55 r
.3378 .57432 m .33774 .57568 L .33772 .5753 L F
.647 .816 .964 r
.20556 .62381 m .2023 .6247 L .20636 .62509 L F
.286 .597 .949 r
.20636 .62509 m .20678 .62362 L .20556 .62381 L F
0 .226 .742 r
.20636 .62509 m .20849 .62699 L .20678 .62362 L F
.455 .681 .962 r
.2606 .64165 m .26263 .64277 L .2641 .64168 L F
.416 .806 .988 r
.26263 .64277 m .26471 .64161 L .2641 .64168 L F
.26263 .64277 m .26674 .64229 L .26471 .64161 L F
.433 .106 .309 r
.28605 .62481 m .28845 .62437 L .29035 .62198 L F
.414 .026 .191 r
.28845 .62437 m .2921 .62214 L .29035 .62198 L F
.951 .756 .604 r
.34082 .63736 m .33853 .63661 L .33957 .63424 L F
.722 .441 .5 r
.34082 .63736 m .33648 .63997 L .33853 .63661 L F
.34082 .63736 m .34051 .64032 L .33648 .63997 L F
.32 .763 .963 r
.33853 .63661 m .34274 .63701 L .34082 .63736 L F
.139 0 0 r
.21497 .55896 m .21276 .55992 L .21048 .56021 L F
.424 0 .08 r
.21653 .55864 m .21276 .55992 L .21497 .55896 L F
.478 0 0 r
.2377 .62382 m .23996 .62445 L .24181 .6242 L F
.522 0 0 r
.23996 .62445 m .24391 .62501 L .24181 .6242 L F
.391 .725 .99 r
.27315 .63133 m .27271 .63283 L .2702 .63105 L F
.27315 .63133 m .27473 .63259 L .27271 .63283 L F
.532 .123 .211 r
.26262 .68301 m .25762 .68365 L .25962 .68344 L F
.496 .565 .855 r
.25762 .68365 m .26144 .68669 L .25962 .68344 L F
.397 .468 .816 r
.33743 .55979 m .33749 .56132 L .3353 .55684 L F
.323 0 0 r
.23216 .5502 m .23022 .55094 L .22787 .55088 L F
0 0 0 r
.23431 .54967 m .23022 .55094 L .23216 .5502 L F
.569 .08 .056 r
.28079 .63299 m .27847 .63105 L .27649 .63216 L F
.678 .595 .756 r
.3174 .59063 m .32076 .59427 L .32077 .59109 L F
.412 .272 .58 r
.32076 .59427 m .32323 .59056 L .32077 .59109 L F
.32076 .59427 m .32317 .59383 L .32323 .59056 L F
.327 .031 .301 r
.32275 .59569 m .32076 .59427 L .32317 .59383 L F
.32275 .59569 m .32066 .59633 L .32076 .59427 L F
.412 .272 .58 r
.32076 .59427 m .32323 .59056 L .32077 .59109 L F
.32076 .59427 m .32317 .59383 L .32323 .59056 L F
.327 .031 .301 r
.32275 .59569 m .32076 .59427 L .32317 .59383 L F
.32275 .59569 m .32066 .59633 L .32076 .59427 L F
.689 .538 .677 r
.26284 .69287 m .26284 .69558 L .26038 .69588 L F
.408 .74 .992 r
.26473 .6924 m .26284 .69287 L .26082 .6917 L F
.475 .365 .648 r
.26549 .69492 m .26284 .69287 L .26473 .6924 L F
.26549 .69492 m .26284 .69558 L .26284 .69287 L F
.528 .491 .759 r
.31646 .55733 m .31718 .56065 L .31887 .55958 L F
.388 .223 .533 r
.31696 .56287 m .31887 .55958 L .31718 .56065 L F
.292 .603 .951 r
.2454 .63957 m .244 .63703 L .24263 .63745 L F
.2454 .63957 m .24679 .63926 L .244 .63703 L F
0 0 0 r
.34138 .56172 m .34307 .56036 L .33743 .55979 L F
.639 .438 .595 r
.34587 .57258 m .34662 .57105 L .34576 .57269 L F
.479 .507 .809 r
.30148 .60657 m .30258 .60348 L .30099 .60602 L F
.475 .305 .57 r
.30148 .60657 m .3016 .60892 L .30437 .60591 L F
.30421 .60622 m .30437 .60591 L .30437 .6062 L F
0 0 .05 r
.3016 .60892 m .30208 .6102 L .30421 .60622 L F
.30383 .6065 m .30421 .60622 L .30437 .60591 L F
.3016 .60892 m .30421 .60622 L .30383 .6065 L F
.475 .305 .57 r
.30148 .60657 m .30437 .60591 L .30421 .60622 L F
.479 .507 .809 r
.30148 .60657 m .30421 .60622 L .30258 .60348 L F
.788 .291 .003 r
.30531 .60829 m .30448 .60618 L .30215 .61038 L F
.30436 .60619 m .30437 .60591 L .30423 .60621 L F
0 0 .05 r
.30208 .6102 m .30215 .61038 L .30422 .60621 L F
.3042 .60623 m .30422 .60621 L .30437 .60591 L F
.30208 .6102 m .30422 .60621 L .3042 .60623 L F
.732 .729 .847 r
.30432 .60613 m .30481 .60317 L .30258 .60348 L F
.30436 .60619 m .30438 .60609 L .30432 .60613 L F
.30438 .60609 m .30481 .60317 L .30432 .60613 L F
.30437 .6062 m .30437 .60619 L .30436 .60619 L F
.30437 .60619 m .30481 .60317 L .30436 .60619 L F
.651 .425 .563 r
.30437 .60591 m .30657 .6083 L .30673 .60571 L F
.30437 .60591 m .30673 .60571 L .30451 .60617 L F
.30437 .60591 m .30451 .60617 L .30437 .6062 L F
.788 .291 .003 r
.30446 .60614 m .30451 .60617 L .30437 .60591 L F
.30565 .60829 m .30657 .6083 L .30437 .60591 L F
.732 .729 .847 r
.30438 .60609 m .30673 .60571 L .30481 .60317 L F
.30437 .6062 m .30451 .60617 L .30446 .60614 L F
.788 .291 .003 r
.30448 .60618 m .30447 .60617 L .30437 .60619 L F
.30437 .60619 m .30437 .60619 L .30436 .60619 L F
.30448 .60618 m .30437 .60619 L .30437 .60619 L F
.732 .729 .847 r
.30437 .6062 m .30446 .60614 L .30437 .60619 L F
.788 .291 .003 r
.30437 .60619 m .30437 .60591 L .30436 .60619 L F
.30447 .60617 m .30446 .60614 L .30437 .60619 L F
.30446 .60614 m .30437 .60591 L .30437 .60619 L F
.732 .729 .847 r
.30451 .60617 m .30673 .60571 L .30462 .60605 L F
.30446 .60614 m .30462 .60605 L .30438 .60609 L F
.30451 .60617 m .30462 .60605 L .30446 .60614 L F
.30437 .60619 m .30446 .60614 L .30438 .60609 L F
.788 .291 .003 r
.30531 .60829 m .30565 .60829 L .30451 .60617 L F
.30531 .60829 m .30451 .60617 L .30446 .60614 L F
.479 .507 .809 r
.30421 .60622 m .30437 .6062 L .30436 .60619 L F
.30421 .60622 m .30436 .60619 L .30423 .60621 L F
.788 .291 .003 r
.30448 .60618 m .30423 .60621 L .30215 .61038 L F
.479 .507 .809 r
.30423 .60621 m .30436 .60619 L .30432 .60613 L F
.30421 .60622 m .30432 .60613 L .30258 .60348 L F
.521 .333 .567 r
.33646 .63403 m .33386 .63735 L .33385 .63464 L F
.231 0 0 r
.22109 .53791 m .22345 .53761 L .22533 .53616 L F
.078 0 0 r
.22345 .53761 m .22756 .53572 L .22533 .53616 L F
0 0 0 r
.24679 .71077 m .24727 .71048 L .24854 .71026 L F
.398 0 0 r
.77777 .40378 m .77454 .40384 L .77728 .40245 L F
.673 .789 .936 r
.77895 .40136 m .77777 .40378 L .77728 .40245 L F
.77895 .40136 m .78045 .4028 L .77777 .40378 L F
0 0 .014 r
.28611 .59947 m .28375 .60273 L .28475 .60073 L F
.552 .729 .957 r
.52233 .52743 m .52416 .52632 L .52052 .52536 L F
.655 .451 .596 r
.33911 .63113 m .33957 .63424 L .33646 .63403 L F
.55 .62 .875 r
.34048 .62651 m .33911 .63113 L .34024 .62606 L F
.34075 .62559 m .34163 .63114 L .33911 .63113 L F
.324 .221 .581 r
.34122 .63319 m .33911 .63113 L .34163 .63114 L F
.34122 .63319 m .33957 .63424 L .33911 .63113 L F
.498 .581 .869 r
.34369 .63013 m .34163 .63114 L .34086 .6263 L F
.34128 .62641 m .34086 .6263 L .34075 .62559 L F
.34369 .63013 m .34086 .6263 L .34128 .62641 L F
.577 .51 .743 r
.34176 .62647 m .34176 .62655 L .34415 .62602 L F
.498 .581 .869 r
.34369 .63013 m .34128 .62641 L .34176 .62647 L F
.34128 .62641 m .34075 .62559 L .34176 .62647 L F
.577 .51 .743 r
.34176 .62647 m .34177 .62829 L .34349 .62665 L F
.34176 .62647 m .34349 .62665 L .34415 .62602 L F
.34176 .62655 m .34177 .62829 L .34319 .62694 L F
.34176 .62655 m .34319 .62694 L .34415 .62602 L F
.701 .526 .647 r
.33952 .62946 m .33936 .63226 L .34156 .62864 L F
.34146 .62845 m .34156 .62864 L .34177 .62829 L F
.33952 .62946 m .34156 .62864 L .34146 .62845 L F
.55 .62 .875 r
.34024 .62606 m .33911 .63113 L .33849 .62768 L F
.34075 .62559 m .34048 .62651 L .34024 .62606 L F
.499 .271 .5 r
.33684 .58819 m .33864 .59019 L .33827 .58719 L F
.33684 .58819 m .33615 .59103 L .33864 .59019 L F
0 0 0 r
.27342 .62306 m .2744 .62023 L .27584 .6198 L F
.392 .161 .441 r
.29554 .56577 m .29762 .56328 L .29498 .56323 L F
.812 .566 .566 r
.37326 .53905 m .37274 .54162 L .37056 .54047 L F
.725 .478 .553 r
.37703 .54132 m .37326 .53905 L .37674 .53873 L F
.37703 .54132 m .37274 .54162 L .37326 .53905 L F
.253 0 .278 r
.32348 .60342 m .32567 .60266 L .32602 .60056 L F
.613 .47 .663 r
.32602 .60056 m .32849 .60028 L .32841 .59723 L F
.672 .4 .502 r
.32567 .60266 m .32849 .60028 L .32602 .60056 L F
.681 .5 .635 r
.38417 .54653 m .38339 .54167 L .38479 .5447 L F
.535 .332 .552 r
.38331 .54173 m .38044 .54757 L .38058 .54391 L F
.38339 .54167 m .38335 .54176 L .38331 .54173 L F
.38335 .54176 m .38044 .54757 L .38331 .54173 L F
0 .229 .74 r
.38312 .54116 m .38537 .54317 L .38521 .54359 L F
.681 .5 .635 r
.38417 .54653 m .38044 .54757 L .38339 .54167 L F
.87 .508 .014 r
.38312 .54116 m .38479 .5447 L .38339 .54167 L F
0 .229 .74 r
.38346 .54187 m .38521 .54359 L .38479 .5447 L F
.38312 .54116 m .38521 .54359 L .38346 .54187 L F
.525 .494 .765 r
.38537 .54317 m .38417 .54653 L .38479 .5447 L F
.292 .781 .901 r
.34751 .54181 m .35052 .54129 L .35176 .54159 L F
.612 .388 .553 r
.35176 .54159 m .35154 .54446 L .34937 .54416 L F
.571 .831 .994 r
.35432 .54085 m .35176 .54159 L .352 .53975 L F
.793 .99 .886 r
.35176 .54159 m .35052 .54129 L .352 .53975 L F
.5 .293 .531 r
.35432 .54085 m .35154 .54446 L .35176 .54159 L F
.419 .241 .531 r
.36936 .56575 m .36713 .56929 L .36708 .56579 L F
.239 .738 .906 r
.25908 .53265 m .26139 .53247 L .26315 .53284 L F
.329 .8 .919 r
.26371 .53216 m .26315 .53284 L .26139 .53247 L F
.26371 .53216 m .26544 .5324 L .26315 .53284 L F
.463 .096 .256 r
.20865 .56102 m .20754 .56263 L .20515 .56294 L F
.222 0 .125 r
.21048 .56021 m .20754 .56263 L .20865 .56102 L F
.921 .584 .385 r
.52968 .53296 m .52837 .53448 L .52742 .53162 L F
.468 .046 .154 r
.5322 .53252 m .52837 .53448 L .52968 .53296 L F
.397 .468 .816 r
.33743 .55979 m .33764 .55627 L .3394 .55722 L F
.836 .975 .671 r
.33769 .5585 m .3394 .55722 L .33764 .55627 L F
.33769 .5585 m .33743 .55979 L .3394 .55722 L F
.607 .695 .906 r
.25401 .70855 m .25327 .71246 L .25274 .70799 L F
.25401 .70855 m .25537 .71137 L .25327 .71246 L F
.485 .429 .719 r
.2564 .71373 m .25327 .71246 L .25537 .71137 L F
.2564 .71373 m .25451 .71457 L .25327 .71246 L F
.331 .165 .5 r
.29038 .57803 m .29177 .57872 L .29305 .57599 L F
.458 .197 .429 r
.28957 .57984 m .29177 .57872 L .29038 .57803 L F
.546 .37 .594 r
.36693 .57182 m .36462 .56961 L .36713 .56929 L F
.36693 .57182 m .36448 .57246 L .36462 .56961 L F
.067 0 0 r
.25521 .63979 m .25675 .63991 L .25273 .63963 L F
.566 .462 .695 r
.26144 .68669 m .26327 .68361 L .25962 .68344 L F
.26144 .68669 m .26382 .68601 L .26327 .68361 L F
.888 .818 .773 r
.26076 .69092 m .26382 .68601 L .26144 .68669 L F
.39 .651 .961 r
.26861 .55621 m .27079 .5564 L .26955 .55492 L F
.985 .818 .595 r
.78621 .40888 m .78564 .40502 L .78422 .40831 L F
.848 .558 .497 r
.78433 .41059 m .78621 .40888 L .78422 .40831 L F
.78433 .41059 m .78734 .41158 L .78621 .40888 L F
.601 .286 .407 r
.31992 .64664 m .31618 .64894 L .31663 .64648 L F
.554 .591 .845 r
.29943 .60188 m .30099 .60602 L .30258 .60348 L F
.411 .274 .583 r
.27169 .54753 m .27174 .54991 L .26964 .54797 L F
.648 .965 .907 r
.2686 .68079 m .26861 .68008 L .27027 .68354 L F
.2686 .68079 m .26704 .68156 L .26861 .68008 L F
.286 0 .139 r
.33291 .59347 m .33615 .59103 L .33405 .59172 L F
.17 .015 .415 r
.31451 .60224 m .31316 .60025 L .31548 .59963 L F
.419 .723 .988 r
.21408 .63102 m .21451 .62951 L .21251 .62975 L F
.21408 .63102 m .21613 .63084 L .21451 .62951 L F
0 .216 .653 r
.53549 .53468 m .5322 .53252 L .53513 .53269 L F
.118 0 .077 r
.19067 .55189 m .1896 .55337 L .1925 .55077 L F
.388 .3 .634 r
.29894 .59458 m .30088 .59385 L .30072 .59031 L F
.394 .315 .649 r
.29894 .59458 m .30116 .59652 L .30088 .59385 L F
.204 .295 .736 r
.29894 .59458 m .2999 .59665 L .30116 .59652 L F
0 .498 .854 r
.35077 .56642 m .3491 .5654 L .34712 .56484 L F
0 0 0 r
.34764 .56907 m .3492 .56809 L .35077 .56642 L F
.972 .701 .456 r
.35077 .56642 m .3492 .56809 L .3491 .5654 L F
.545 .329 .538 r
.26284 .69558 m .26037 .69888 L .26038 .69588 L F
.276 .377 .786 r
.29946 .55481 m .3021 .55639 L .30072 .55263 L F
.292 0 0 r
.3089 .56906 m .30468 .57097 L .30658 .57005 L F
.851 .452 .286 r
.54361 .52533 m .54722 .5285 L .54547 .52599 L F
.564 .355 .555 r
.32841 .59723 m .33097 .59681 L .33123 .5942 L F
.498 .299 .54 r
.33123 .5942 m .33334 .59615 L .33291 .59347 L F
.33123 .5942 m .33097 .59681 L .33334 .59615 L F
.474 .594 .893 r
.19077 .59429 m .19004 .59623 L .18912 .59405 L F
.19077 .59429 m .19327 .59716 L .19004 .59623 L F
.489 .32 .578 r
.19327 .59716 m .19121 .59962 L .19004 .59623 L F
0 .485 .739 r
.21378 .61748 m .21573 .61784 L .21757 .6183 L F
.294 .766 .936 r
.21573 .61784 m .21983 .61803 L .21757 .6183 L F
.716 .608 .735 r
.78684 .41796 m .79064 .41862 L .7892 .41501 L F
.37 .225 .551 r
.32348 .60342 m .3254 .60548 L .32567 .60266 L F
.323 .219 .578 r
.32372 .60601 m .3254 .60548 L .32348 .60342 L F
.448 .834 .985 r
.22756 .53572 m .22956 .53522 L .23158 .53581 L F
.214 0 0 r
.22956 .53522 m .23393 .53574 L .23158 .53581 L F
.587 .312 .468 r
.35743 .59726 m .35703 .59987 L .35457 .59977 L F
.427 .502 .833 r
.35648 .59065 m .35924 .59675 L .35743 .59726 L F
0 0 .117 r
.35807 .59831 m .35743 .59726 L .35924 .59675 L F
.35807 .59831 m .35703 .59987 L .35743 .59726 L F
.957 .902 .728 r
.55267 .538 m .55143 .5401 L .55261 .54128 L F
.945 .858 .724 r
.54971 .54346 m .55261 .54128 L .55143 .5401 L F
.54971 .54346 m .55112 .54456 L .55261 .54128 L F
.675 .46 .587 r
.36174 .58818 m .36185 .59049 L .35577 .59021 L F
.565 .47 .706 r
.36458 .58594 m .36185 .59049 L .36174 .58818 L F
.331 .221 .575 r
.15872 .58507 m .16029 .58499 L .1606 .58119 L F
.34 .344 .718 r
.15872 .58507 m .16111 .5871 L .16029 .58499 L F
.423 .349 .669 r
.15872 .58507 m .15926 .58777 L .16111 .5871 L F
0 0 .118 r
.29089 .55407 m .29178 .5533 L .29239 .55068 L F
.544 .529 .789 r
.29089 .55407 m .29262 .55491 L .29178 .5533 L F
.29089 .55407 m .29362 .55601 L .29262 .55491 L F
.519 .876 .984 r
.36536 .54439 m .36196 .54484 L .36405 .54405 L F
.962 .735 .55 r
.36405 .54405 m .36552 .54767 L .36536 .54439 L F
.36405 .54405 m .36552 .54767 L .36536 .54439 L F
0 0 .217 r
.36808 .54457 m .36552 .54767 L .36536 .54439 L F
.614 .28 .382 r
.26327 .68361 m .26262 .68301 L .25962 .68344 L F
.647 .202 .18 r
.34529 .5601 m .34797 .56238 L .34943 .56029 L F
.104 .21 .69 r
.34857 .55701 m .34943 .56029 L .35049 .55886 L F
.216 0 0 r
.34943 .56029 m .35 .56146 L .35049 .55886 L F
.34943 .56029 m .34797 .56238 L .35 .56146 L F
0 .081 .63 r
.30998 .57253 m .3106 .57126 L .3089 .56906 L F
.102 0 .398 r
.30998 .57253 m .31175 .57318 L .3106 .57126 L F
.30998 .57253 m .30975 .57525 L .31175 .57318 L F
.909 .716 .63 r
.55078 .53176 m .5523 .53529 L .55269 .53266 L F
.454 .565 .877 r
.29955 .54384 m .3023 .5482 L .3037 .54707 L F
.472 0 0 r
.24805 .6266 m .2477 .62604 L .24591 .62525 L F
.24805 .6266 m .24998 .62761 L .2477 .62604 L F
.635 .141 .06 r
.2477 .62604 m .24998 .62761 L .25159 .62701 L F
.366 .79 .973 r
.26544 .5324 m .26774 .53207 L .2694 .53272 L F
.409 .767 .995 r
.26989 .53141 m .2694 .53272 L .26774 .53207 L F
.26989 .53141 m .2717 .53249 L .2694 .53272 L F
.599 .785 .969 r
.26382 .68601 m .26779 .68673 L .26597 .68578 L F
.757 .659 .754 r
.26801 .68444 m .27027 .68354 L .26779 .68673 L F
.81 .982 .704 r
.26779 .68673 m .26834 .68489 L .26597 .68578 L F
.26779 .68673 m .27027 .68354 L .26834 .68489 L F
.075 .634 .792 r
.17223 .60265 m .16787 .59975 L .16791 .60153 L F
.425 .792 .995 r
.35615 .59116 m .3552 .59025 L .35214 .59063 L F
.683 .229 .169 r
.35214 .59063 m .35437 .59267 L .35615 .59116 L F
.992 .882 .599 r
.35615 .59116 m .35437 .59267 L .3552 .59025 L F
0 0 .521 r
.35648 .59065 m .35615 .59116 L .35577 .59021 L F
.756 .919 .551 r
.23711 .73937 m .23956 .73555 L .24065 .73903 L F
.298 .789 .884 r
.23711 .73937 m .24065 .73903 L .23896 .73893 L F
.552 .657 .905 r
.2416 .73573 m .24065 .73903 L .23956 .73555 L F
.084 .09 .566 r
.2452 .73415 m .24432 .7348 L .24383 .73198 L F
.2452 .73415 m .24432 .7348 L .24383 .73198 L F
.433 .828 .613 r
.2452 .73415 m .24432 .7348 L .24346 .73536 L F
.051 .316 .8 r
.24395 .73791 m .24291 .7386 L .24193 .73645 L F
.24218 .73627 m .24193 .73645 L .2416 .73573 L F
.24395 .73791 m .24193 .73645 L .24218 .73627 L F
.24395 .73791 m .2416 .73573 L .24432 .7348 L F
.127 0 0 r
.24169 .73653 m .24432 .7348 L .2416 .73573 L F
.433 .828 .613 r
.24445 .73466 m .24346 .73536 L .24271 .73586 L F
.24294 .73568 m .24271 .73586 L .24169 .73653 L F
.24445 .73466 m .24271 .73586 L .24294 .73568 L F
.2452 .73415 m .24346 .73536 L .24445 .73466 L F
.552 .657 .905 r
.24125 .73694 m .24291 .7386 L .24065 .73903 L F
.2416 .73573 m .24193 .73645 L .24125 .73694 L F
.24193 .73645 m .24291 .7386 L .24125 .73694 L F
.292 .786 .88 r
.24065 .73903 m .24127 .73848 L .23896 .73893 L F
.24065 .73903 m .24291 .7386 L .24127 .73848 L F
.643 .24 .265 r
.33283 .55658 m .33485 .55874 L .3353 .55684 L F
.525 .37 .613 r
.34326 .62156 m .34282 .62415 L .341 .62415 L F
.865 .496 .346 r
.34282 .62415 m .34075 .62559 L .341 .62415 L F
.919 .821 .734 r
.54485 .56513 m .54785 .56272 L .54791 .56231 L F
.54485 .56513 m .54646 .56633 L .54785 .56272 L F
.093 .184 .667 r
.20816 .61406 m .20723 .61611 L .20634 .61196 L F
.383 .539 .886 r
.20816 .61406 m .20946 .61582 L .20723 .61611 L F
.545 .329 .538 r
.26284 .69558 m .26281 .69857 L .26037 .69888 L F
0 0 .051 r
.26306 .69598 m .26284 .69558 L .26549 .69492 L F
.26306 .69598 m .26281 .69857 L .26284 .69558 L F
.459 0 0 r
.29118 .64935 m .29533 .64878 L .29364 .64796 L F
0 .353 .724 r
.29533 .64878 m .2951 .64848 L .29364 .64796 L F
.288 .123 .475 r
.31752 .58124 m .31586 .58417 L .31545 .58184 L F
.421 .258 .554 r
.34716 .61213 m .34488 .61545 L .34468 .61278 L F
0 0 .431 r
.36985 .53911 m .36986 .53792 L .36886 .53545 L F
.453 .754 .994 r
.24017 .55584 m .24184 .55702 L .23943 .55715 L F
.24017 .55584 m .24184 .55702 L .23943 .55715 L F
.944 .882 .742 r
.53749 .56308 m .5377 .5614 L .53886 .56025 L F
.53749 .56308 m .53619 .56261 L .53794 .55945 L F
.857 .778 .772 r
.53736 .56414 m .54189 .56249 L .53682 .5626 L F
.921 .924 .797 r
.5368 .56511 m .53619 .56261 L .53749 .56308 L F
.857 .778 .772 r
.53651 .56303 m .53682 .5626 L .53619 .56261 L F
.53736 .56414 m .53682 .5626 L .53651 .56303 L F
.944 .882 .742 r
.5377 .5614 m .53794 .55945 L .53866 .56008 L F
.5377 .5614 m .53866 .56008 L .53886 .56025 L F
0 0 0 r
.19977 .54698 m .2018 .54553 L .19855 .5473 L F
.20369 .54443 m .2018 .54553 L .19977 .54698 L F
.522 .372 .618 r
.28618 .62797 m .28845 .62437 L .28605 .62481 L F
.477 .329 .601 r
.2999 .59665 m .3025 .59931 L .30116 .59652 L F
.2999 .59665 m .29995 .6005 L .3025 .59931 L F
.016 .097 .606 r
.16071 .59383 m .16135 .59768 L .16227 .59586 L F
.237 .38 .805 r
.16135 .59768 m .16379 .5993 L .16227 .59586 L F
.133 0 0 r
.25159 .62701 m .24998 .62761 L .25379 .62682 L F
.01 0 0 r
.21315 .54133 m .21028 .54192 L .20795 .54288 L F
.606 .602 .822 r
.37922 .53818 m .37674 .53873 L .37522 .53554 L F
.575 .444 .665 r
.37922 .53818 m .37703 .54132 L .37674 .53873 L F
0 0 0 r
.28869 .59549 m .28651 .59686 L .28972 .59463 L F
.339 .107 .409 r
.28869 .59549 m .28611 .59947 L .28651 .59686 L F
.733 .272 .157 r
.30751 .56548 m .31172 .56633 L .3089 .56906 L F
0 0 0 r
.30896 .56759 m .31405 .56607 L .31172 .56633 L F
.119 0 0 r
.31405 .56607 m .31446 .56611 L .31172 .56633 L F
.193 0 0 r
.31405 .56607 m .31622 .56623 L .3167 .56532 L F
.31405 .56607 m .3167 .56532 L .31446 .56611 L F
.414 .11 .339 r
.31172 .56633 m .31446 .56611 L .31523 .56346 L F
.64 .325 .421 r
.31523 .56346 m .3167 .56532 L .31696 .56287 L F
.31523 .56346 m .31446 .56611 L .3167 .56532 L F
.451 0 0 r
.50105 .56375 m .50044 .56326 L .49948 .56201 L F
.138 .482 .9 r
.50083 .56358 m .50177 .56269 L .50078 .56305 L F
.5009 .56425 m .50113 .56383 L .50083 .56358 L F
.50113 .56383 m .50177 .56269 L .50083 .56358 L F
.925 .716 .601 r
.50338 .56276 m .50304 .56538 L .50105 .56375 L F
.50338 .56276 m .50483 .5663 L .50304 .56538 L F
.732 .646 .763 r
.50707 .56517 m .50483 .5663 L .50338 .56276 L F
.138 .482 .9 r
.50113 .56383 m .5047 .56551 L .50177 .56269 L F
.5009 .56425 m .50139 .56404 L .50113 .56383 L F
.451 0 0 r
.50056 .56336 m .50108 .56378 L .50044 .56326 L F
.279 .678 .971 r
.5009 .56425 m .50078 .56305 L .50044 .56326 L F
.186 .602 .943 r
.50044 .56326 m .50139 .56404 L .5009 .56425 L F
.50139 .56404 m .50304 .56538 L .5009 .56425 L F
.138 .482 .9 r
.5009 .56425 m .50216 .56467 L .50139 .56404 L F
.451 0 0 r
.50105 .56375 m .50255 .56498 L .50108 .56378 L F
.50255 .56498 m .50304 .56538 L .50066 .56344 L F
.50255 .56498 m .50066 .56344 L .50044 .56326 L F
.138 .482 .9 r
.50216 .56467 m .5047 .56551 L .50113 .56383 L F
.451 0 0 r
.50105 .56375 m .50108 .56378 L .50056 .56336 L F
.332 .191 .535 r
.34838 .6081 m .34672 .60643 L .34834 .60561 L F
.34838 .6081 m .34672 .60825 L .34672 .60643 L F
.671 .968 .921 r
.31752 .58908 m .31323 .59151 L .3174 .59063 L F
.414 .026 .191 r
.28845 .62437 m .29089 .62421 L .2921 .62214 L F
.616 .239 .305 r
.2921 .62214 m .29089 .62421 L .29422 .62399 L F
.529 .266 .461 r
.2921 .62214 m .29422 .62399 L .29501 .62158 L F
.235 .393 .818 r
.27147 .68324 m .27027 .68354 L .26861 .68008 L F
0 0 0 r
.26834 .68489 m .27027 .68354 L .27147 .68324 L F
.29038 .59472 m .28972 .59463 L .29101 .59328 L F
.29038 .59472 m .28869 .59549 L .28972 .59463 L F
.65 .499 .666 r
.32841 .59723 m .33157 .59999 L .33097 .59681 L F
.32841 .59723 m .32849 .60028 L .33157 .59999 L F
.254 .765 .841 r
.23393 .53574 m .23621 .5353 L .23785 .5353 L F
.452 .85 .975 r
.23621 .5353 m .24013 .53516 L .23785 .5353 L F
0 0 0 r
.34764 .56907 m .34662 .57105 L .3492 .56809 L F
.486 .898 .905 r
.26055 .62262 m .2634 .62238 L .25979 .62343 L F
.781 .71 .785 r
.78684 .41796 m .7892 .41501 L .7857 .41439 L F
.241 .757 .823 r
.14638 .64014 m .1503 .63962 L .14835 .64034 L F
.14638 .64014 m .1503 .63962 L .14835 .64034 L F
.523 .784 .992 r
.2989 .53149 m .29834 .53331 L .29671 .53197 L F
.2989 .53149 m .3006 .53279 L .29834 .53331 L F
.43 .167 .411 r
.35958 .54685 m .36112 .54668 L .36196 .54484 L F
.134 0 0 r
.35779 .54629 m .36112 .54668 L .35958 .54685 L F
.876 .695 .653 r
.82435 .40208 m .82587 .40574 L .82627 .40318 L F
.411 0 0 r
.26496 .67484 m .26883 .67733 L .26719 .67385 L F
0 .027 .599 r
.26719 .67385 m .26883 .67733 L .26901 .67617 L F
.356 .756 .984 r
.26883 .67733 m .27128 .67731 L .26901 .67617 L F
.183 0 .223 r
.26879 .66194 m .26606 .66517 L .26842 .6646 L F
.755 .505 .555 r
.52052 .52536 m .52416 .52632 L .52445 .52315 L F
.544 .32 .527 r
.52445 .52315 m .52416 .52632 L .52765 .52426 L F
.613 .441 .625 r
.81262 .4055 m .81078 .4092 L .81344 .40835 L F
.677 .478 .61 r
.81262 .4055 m .81344 .40835 L .81556 .40527 L F
.633 .435 .596 r
.34671 .63968 m .34323 .64039 L .344 .6376 L F
.34671 .63968 m .34323 .64039 L .344 .6376 L F
0 0 0 r
.26834 .61577 m .26619 .61885 L .26725 .61769 L F
0 0 .132 r
.26725 .61769 m .26619 .61885 L .2654 .62136 L F
.901 .628 .515 r
.37568 .56512 m .37344 .56451 L .3741 .56403 L F
.889 .62 .524 r
.37568 .56512 m .3751 .56811 L .376 .56733 L F
.901 .628 .515 r
.37568 .56512 m .37588 .56651 L .3754 .56667 L F
.37588 .56651 m .376 .56733 L .37566 .56696 L F
.37588 .56651 m .37566 .56696 L .3754 .56667 L F
.429 .176 .428 r
.37516 .56802 m .3751 .56811 L .37568 .56512 L F
.699 .567 .702 r
.3751 .56811 m .37344 .56451 L .3754 .56667 L F
.3751 .56811 m .3754 .56667 L .376 .56733 L F
.429 .176 .428 r
.37796 .56404 m .37516 .56802 L .3754 .56667 L F
.37574 .56509 m .3754 .56667 L .37568 .56512 L F
.37796 .56404 m .3754 .56667 L .37574 .56509 L F
0 0 .003 r
.37796 .56404 m .37704 .56692 L .37513 .56809 L F
.37516 .56802 m .37513 .56809 L .3751 .56811 L F
.37796 .56404 m .37513 .56809 L .37516 .56802 L F
.901 .628 .515 r
.37568 .56512 m .3754 .56667 L .37344 .56451 L F
.668 .863 .973 r
.37836 .56375 m .37568 .56512 L .3741 .56403 L F
.67 .845 .967 r
.37796 .56404 m .37568 .56512 L .37836 .56375 L F
0 0 0 r
.19977 .54698 m .19855 .5473 L .19745 .54765 L F
.319 .658 .972 r
.33201 .53614 m .33172 .53756 L .32978 .53636 L F
.33201 .53614 m .33361 .53753 L .33172 .53756 L F
.524 .884 .98 r
.3272 .64288 m .32534 .64383 L .32895 .6434 L F
.393 .821 .963 r
.33135 .643 m .3272 .64288 L .32895 .6434 L F
.944 .73 .583 r
.78363 .40475 m .78564 .40502 L .78601 .4026 L F
.212 0 .245 r
.29338 .59173 m .29205 .59118 L .2935 .59017 L F
.29338 .59173 m .29101 .59328 L .29205 .59118 L F
.419 .603 .923 r
.21038 .62987 m .21031 .62701 L .20849 .62699 L F
.21038 .62987 m .21251 .62975 L .21031 .62701 L F
.203 .079 .478 r
.29501 .62158 m .29637 .61812 L .2945 .61876 L F
.548 .898 .977 r
.27795 .53171 m .27573 .5326 L .27409 .53218 L F
.767 .442 .436 r
.30127 .64951 m .29728 .65162 L .2971 .64954 L F
.30127 .64951 m .29959 .6519 L .29728 .65162 L F
.576 .209 .308 r
.30328 .65148 m .29959 .6519 L .30127 .64951 L F
.553 .213 .346 r
.3038 .64947 m .30328 .65148 L .30127 .64951 L F
.563 .935 .827 r
.31421 .55778 m .31376 .55858 L .31646 .55733 L F
.244 .755 .743 r
.317 .55701 m .31646 .55733 L .31873 .55649 L F
.317 .55701 m .31421 .55778 L .31646 .55733 L F
.528 .491 .759 r
.31646 .55733 m .31887 .55958 L .31873 .55649 L F
.415 .8 .99 r
.28023 .5309 m .28428 .53133 L .28207 .53162 L F
.831 .459 .35 r
.54755 .53074 m .54897 .52902 L .54722 .5285 L F
.54755 .53074 m .55078 .53176 L .54897 .52902 L F
.739 .645 .756 r
.30958 .61545 m .3129 .6158 L .31189 .61216 L F
.784 .574 .616 r
.30989 .61795 m .3129 .6158 L .30958 .61545 L F
.30989 .61795 m .31337 .6185 L .3129 .6158 L F
.494 .464 .753 r
.3129 .6158 m .31424 .61166 L .31189 .61216 L F
.3129 .6158 m .31539 .61558 L .31424 .61166 L F
.566 .426 .65 r
.3129 .6158 m .31584 .61798 L .31539 .61558 L F
.3129 .6158 m .31337 .6185 L .31584 .61798 L F
.689 .558 .702 r
.27054 .65479 m .27106 .65876 L .27353 .65563 L F
.585 .854 .995 r
.27073 .64477 m .2746 .64469 L .2732 .64385 L F
.576 .848 .996 r
.2746 .64469 m .27546 .64314 L .2732 .64385 L F
.2746 .64469 m .27684 .64392 L .27546 .64314 L F
.378 0 .021 r
.52765 .52426 m .52926 .52439 L .5302 .52272 L F
.244 0 0 r
.52926 .52439 m .53322 .52228 L .5302 .52272 L F
.069 0 .084 r
.27733 .59982 m .27874 .5993 L .27939 .59705 L F
0 .075 .61 r
.27939 .59705 m .28026 .59553 L .27872 .59378 L F
0 0 0 r
.27939 .59705 m .27874 .5993 L .28026 .59553 L F
0 .312 .769 r
.34581 .54014 m .34568 .5406 L .3436 .5389 L F
.34581 .54014 m .34751 .54181 L .34568 .5406 L F
.776 .413 .369 r
.36185 .59049 m .35648 .59065 L .35577 .59021 L F
.863 .991 .733 r
.23371 .7363 m .23145 .73888 L .23327 .73794 L F
.121 0 0 r
.23663 .73483 m .23371 .7363 L .23549 .73564 L F
.384 .161 .447 r
.23541 .73775 m .23371 .7363 L .23327 .73794 L F
.23541 .73775 m .23549 .73564 L .23371 .7363 L F
.695 .718 .867 r
.81847 .41337 m .81948 .41043 L .81731 .41152 L F
.81847 .41337 m .82121 .41219 L .81948 .41043 L F
.886 .842 .796 r
.54261 .56843 m .54646 .56633 L .54485 .56513 L F
.54261 .56843 m .54414 .5697 L .54646 .56633 L F
.568 .375 .579 r
.32991 .55211 m .32955 .5508 L .32956 .55121 L F
.798 .543 .552 r
.38058 .54391 m .37703 .54132 L .37942 .54083 L F
.38058 .54391 m .37672 .54407 L .37703 .54132 L F
.841 .592 .563 r
.38058 .54391 m .37666 .54608 L .37672 .54407 L F
.38058 .54391 m .38044 .54757 L .37666 .54608 L F
.736 .702 .818 r
.38312 .54116 m .38058 .54391 L .37942 .54083 L F
.87 .508 .014 r
.38312 .54116 m .38339 .54167 L .38058 .54391 L F
.521 .333 .567 r
.33646 .63403 m .33687 .63794 L .33386 .63735 L F
.503 .404 .676 r
.33687 .63794 m .33648 .63997 L .33386 .63735 L F
.356 0 .18 r
.3517 .60271 m .35074 .60511 L .34834 .60561 L F
.498 .316 .564 r
.35457 .59977 m .35475 .60265 L .3517 .60271 L F
.728 .518 .606 r
.35475 .60265 m .35074 .60511 L .3517 .60271 L F
.344 .079 .361 r
.36196 .54484 m .36112 .54668 L .36405 .54405 L F
.472 0 0 r
.29531 .55505 m .29423 .55542 L .29567 .55402 L F
.091 .117 .594 r
.29478 .55223 m .29531 .55505 L .29567 .55402 L F
.29478 .55223 m .29652 .55463 L .29531 .55505 L F
.29652 .55463 m .29657 .5547 L .29531 .55505 L F
.472 0 0 r
.29531 .55505 m .29362 .55601 L .29423 .55542 L F
.514 .533 .813 r
.77422 .40533 m .77541 .40904 L .77801 .40857 L F
.866 .948 .866 r
.5368 .56511 m .53381 .56744 L .53493 .56445 L F
.921 .924 .797 r
.5368 .56511 m .53493 .56445 L .53619 .56261 L F
.676 .416 .521 r
.30468 .58373 m .308 .58119 L .3058 .58201 L F
.555 .72 .95 r
.34223 .53719 m .34157 .53958 L .33999 .5383 L F
.34223 .53719 m .3436 .5389 L .34157 .53958 L F
.69 .496 .62 r
.81344 .40835 m .8169 .40898 L .81556 .40527 L F
.609 .453 .645 r
.81556 .40527 m .8169 .40898 L .82008 .40831 L F
.623 .69 .892 r
.31721 .53486 m .31493 .5358 L .31285 .53272 L F
0 0 0 r
.27071 .61268 m .26834 .61577 L .26954 .61462 L F
.26954 .61462 m .26834 .61577 L .26725 .61769 L F
.657 .946 .957 r
.50965 .5506 m .51111 .55105 L .51197 .54925 L F
.501 .307 .55 r
.33011 .56631 m .32673 .57161 L .32792 .56613 L F
.33011 .56631 m .32673 .57161 L .32792 .56613 L F
.341 .171 .5 r
.28276 .67177 m .28015 .67656 L .2806 .67295 L F
.419 .515 .85 r
.28056 .67728 m .27983 .67711 L .27971 .67665 L F
.27983 .67711 m .27873 .67686 L .27966 .67666 L F
.27983 .67711 m .27966 .67666 L .27971 .67665 L F
.28056 .67728 m .27968 .67875 L .27873 .67686 L F
.27971 .67665 m .27873 .67686 L .27799 .67539 L F
.613 .47 .663 r
.27868 .67268 m .27957 .67653 L .27799 .67539 L F
.918 .612 .132 r
.27898 .67482 m .27948 .67642 L .27907 .67546 L F
.613 .47 .663 r
.27957 .67653 m .27975 .67729 L .27799 .67539 L F
.918 .612 .132 r
.27948 .67642 m .27975 .67729 L .27939 .67631 L F
.27948 .67642 m .27939 .67631 L .27907 .67546 L F
.27868 .67268 m .27951 .67625 L .27898 .67482 L F
.27951 .67625 m .27957 .67653 L .27898 .67482 L F
.27957 .67653 m .27975 .67729 L .27948 .67642 L F
.27957 .67653 m .27948 .67642 L .27898 .67482 L F
.419 .515 .85 r
.281 .67761 m .27964 .6766 L .28052 .67721 L F
.27964 .6766 m .27799 .67539 L .27957 .67653 L F
.341 .171 .5 r
.28015 .67656 m .28 .67683 L .27988 .67661 L F
.28 .67683 m .27975 .67729 L .27986 .67674 L F
.651 .189 .143 r
.27397 .67388 m .27757 .67413 L .27754 .6741 L F
.12 0 .34 r
.27527 .67172 m .27544 .67209 L .27541 .67092 L F
.651 .189 .143 r
.27477 .67291 m .27609 .67348 L .27544 .67209 L F
.27397 .67388 m .27754 .6741 L .27477 .67291 L F
.12 0 .34 r
.27478 .6737 m .27397 .67388 L .27544 .67209 L F
.103 0 .271 r
.27349 .67605 m .27397 .67388 L .27478 .6737 L F
.636 .47 .641 r
.27544 .67209 m .27478 .6737 L .27349 .67605 L F
.27478 .6737 m .27379 .6761 L .27349 .67605 L F
.103 0 .271 r
.27349 .67605 m .27478 .6737 L .27493 .67367 L F
.024 0 .236 r
.2745 .674 m .27477 .67291 L .27481 .67337 L F
.636 .47 .641 r
.27488 .67345 m .27461 .67625 L .27451 .67435 L F
.27544 .67209 m .27592 .67457 L .27488 .67345 L F
.12 0 .34 r
.27493 .67367 m .27478 .6737 L .27544 .67209 L F
.27493 .67367 m .27482 .67352 L .27483 .67363 L F
.27493 .67367 m .275 .67324 L .27487 .67343 L F
.636 .47 .641 r
.27488 .67345 m .2763 .67656 L .27461 .67625 L F
.27592 .67457 m .2763 .67656 L .27488 .67345 L F
0 0 .147 r
.27544 .67209 m .27481 .67337 L .275 .67448 L F
.636 .47 .641 r
.27451 .67435 m .27461 .67625 L .27379 .6761 L F
.103 0 .271 r
.27349 .67605 m .27493 .67367 L .275 .67448 L F
.733 .215 0 r
.275 .67448 m .27493 .67367 L .27481 .67362 L F
0 0 .147 r
.27481 .67362 m .27349 .67605 L .2748 .67469 L F
.27477 .67345 m .27349 .67605 L .27481 .67362 L F
.12 0 .34 r
.27483 .67363 m .27481 .67359 L .27481 .67362 L F
0 0 .147 r
.27481 .67337 m .2748 .67469 L .275 .67448 L F
.024 0 .236 r
.2745 .674 m .27397 .67388 L .27477 .67291 L F
.27349 .67605 m .27366 .67525 L .2745 .674 L F
.27366 .67525 m .27397 .67388 L .2745 .674 L F
.733 .215 0 r
.275 .67448 m .27481 .67362 L .27198 .67252 L F
0 0 .147 r
.27481 .67337 m .27477 .67345 L .27481 .67362 L F
.12 0 .34 r
.27481 .67362 m .27444 .67298 L .27198 .67252 L F
.27481 .67359 m .27444 .67298 L .27481 .67362 L F
.27482 .67352 m .27444 .67298 L .27483 .67363 L F
.024 0 .236 r
.27481 .67337 m .27477 .67291 L .27544 .67209 L F
.12 0 .34 r
.27487 .67343 m .27541 .67092 L .27434 .67097 L F
.275 .67324 m .27541 .67092 L .27487 .67343 L F
.27444 .67298 m .27434 .67097 L .27308 .67103 L F
.27493 .67367 m .27434 .67097 L .27444 .67298 L F
.27444 .67298 m .27423 .67268 L .27416 .67268 L F
.27444 .67298 m .27416 .67268 L .27198 .67252 L F
.27493 .67367 m .27544 .67209 L .27527 .67172 L F
.651 .189 .143 r
.27609 .67348 m .27754 .6741 L .27544 .67209 L F
.12 0 .34 r
.27423 .67268 m .27308 .67103 L .27243 .67191 L F
.27423 .67268 m .27243 .67191 L .27198 .67252 L F
.401 .312 .64 r
.27799 .67539 m .2763 .67656 L .27544 .67209 L F
.956 .72 .543 r
.27799 .67539 m .27768 .6772 L .2763 .67656 L F
.27768 .6772 m .27751 .67815 L .27721 .67775 L F
.27768 .6772 m .27721 .67775 L .2763 .67656 L F
.709 .692 .832 r
.27872 .67597 m .27975 .67729 L .27942 .67639 L F
.956 .72 .543 r
.27799 .67539 m .27968 .67875 L .27751 .67815 L F
.709 .692 .832 r
.27629 .67449 m .27847 .67626 L .27872 .67597 L F
.27847 .67626 m .27975 .67729 L .27872 .67597 L F
.773 .268 0 r
.27629 .67449 m .27799 .67539 L .27544 .67209 L F
.709 .692 .832 r
.27725 .67483 m .27942 .67639 L .27907 .67546 L F
0 .151 .596 r
.27872 .67589 m .27989 .67673 L .27799 .67539 L F
.419 .515 .85 r
.27957 .67653 m .27799 .67539 L .27955 .67649 L F
.709 .692 .832 r
.27629 .67449 m .27942 .67639 L .27872 .67589 L F
.758 .561 .63 r
.27988 .67661 m .27986 .67674 L .27951 .67625 L F
.419 .515 .85 r
.27964 .6766 m .27957 .67653 L .27983 .67673 L F
.27964 .6766 m .27997 .67681 L .27975 .67668 L F
.758 .561 .63 r
.27986 .67674 m .27975 .67729 L .27957 .67653 L F
.27986 .67674 m .27957 .67653 L .27951 .67625 L F
.419 .515 .85 r
.27983 .67673 m .27957 .67653 L .27997 .67681 L F
.813 .744 .787 r
.27939 .67631 m .27942 .67639 L .27991 .67675 L F
0 .151 .596 r
.27972 .67658 m .27989 .67673 L .27942 .67639 L F
.2788 .67594 m .27942 .67639 L .27872 .67589 L F
.27972 .67658 m .27942 .67639 L .2788 .67594 L F
.341 .171 .5 r
.28 .67683 m .27986 .67674 L .27986 .67672 L F
.28 .67683 m .27986 .67672 L .27999 .67681 L F
.813 .744 .787 r
.27991 .67675 m .27975 .67729 L .28 .67683 L F
0 .151 .596 r
.28031 .67703 m .28012 .6769 L .27799 .67539 L F
.419 .515 .85 r
.28003 .67685 m .27957 .67653 L .27995 .67679 L F
.27957 .67653 m .27955 .67649 L .28035 .67706 L F
.813 .744 .787 r
.27942 .67639 m .27975 .67729 L .27991 .67675 L F
0 .151 .596 r
.27972 .67658 m .27872 .67589 L .27629 .67449 L F
.27872 .67589 m .27799 .67539 L .27629 .67449 L F
.709 .692 .832 r
.27629 .67449 m .27872 .67589 L .27725 .67483 L F
.341 .171 .5 r
.27999 .67681 m .27986 .67672 L .27988 .67661 L F
.28015 .67656 m .27988 .67661 L .2806 .67295 L F
.758 .561 .63 r
.2806 .67295 m .27988 .67661 L .27868 .67268 L F
.27988 .67661 m .27951 .67625 L .27868 .67268 L F
.813 .744 .787 r
.27939 .67631 m .28 .67683 L .28276 .67177 L F
0 .151 .596 r
.27972 .67658 m .28031 .67703 L .27989 .67673 L F
.28031 .67703 m .28035 .67706 L .28012 .6769 L F
.419 .515 .85 r
.27975 .67668 m .27997 .67681 L .28052 .67721 L F
.813 .744 .787 r
.27907 .67546 m .27939 .67631 L .28276 .67177 L F
.419 .515 .85 r
.28052 .67721 m .28003 .67685 L .28035 .67706 L F
.28003 .67685 m .27995 .67679 L .28035 .67706 L F
.281 .67761 m .28094 .67766 L .28056 .67728 L F
.28094 .67766 m .27968 .67875 L .28056 .67728 L F
.918 .612 .132 r
.27868 .67268 m .27907 .67546 L .2785 .67284 L F
.441 .42 .74 r
.27541 .67092 m .27868 .67268 L .27744 .66897 L F
.918 .612 .132 r
.27868 .67268 m .2785 .67284 L .2782 .67145 L F
.57 .834 .478 r
.27757 .67413 m .27901 .6724 L .27868 .67268 L F
.27901 .6724 m .2802 .67097 L .27868 .67268 L F
.39 .443 .795 r
.28149 .66988 m .2802 .67097 L .27892 .66738 L F
0 0 0 r
.27868 .67268 m .2802 .67097 L .28149 .66988 L F
.559 .405 .629 r
.33339 .57557 m .33762 .57599 L .33547 .57208 L F
.374 0 .179 r
.33282 .5779 m .33762 .57599 L .33339 .57557 L F
.277 .578 .941 r
.18144 .60847 m .18605 .61205 L .18607 .61117 L F
.222 .486 .894 r
.18605 .61205 m .18691 .61267 L .18607 .61117 L F
.344 .159 .479 r
.16045 .57839 m .16228 .5778 L .16253 .57527 L F
.365 .237 .57 r
.1606 .58119 m .16228 .5778 L .16045 .57839 L F
.693 .931 .967 r
.25175 .71563 m .25451 .71457 L .25214 .7142 L F
.536 .891 .978 r
.25214 .7142 m .25451 .71457 L .2564 .71373 L F
.91 .771 .695 r
.54045 .55106 m .53957 .55308 L .53848 .55007 L F
.601 .421 .61 r
.34787 .54648 m .34534 .54446 L .34937 .54416 L F
.623 .327 .448 r
.35154 .54446 m .34787 .54648 L .34937 .54416 L F
.579 .09 0 r
.50483 .5663 m .50566 .56745 L .50304 .56538 L F
.50483 .5663 m .50696 .56879 L .50566 .56745 L F
.119 .651 .867 r
.2589 .6411 m .2606 .64165 L .2641 .64168 L F
0 0 0 r
.17883 .56012 m .17613 .56302 L .17767 .5619 L F
.137 0 .054 r
.17767 .5619 m .18082 .55927 L .17883 .56012 L F
.55 .447 .69 r
.36326 .55587 m .36498 .5604 L .36178 .56014 L F
.54 .245 .415 r
.36498 .5604 m .36398 .56179 L .36178 .56014 L F
.781 .612 .67 r
.22467 .75896 m .22835 .75765 L .22421 .75685 L F
.548 .69 .933 r
.22886 .75557 m .23089 .75719 L .22835 .75765 L F
.472 .22 .451 r
.22835 .75765 m .23089 .75719 L .23018 .75957 L F
.052 .161 .659 r
.22886 .75557 m .22835 .75765 L .23018 .75957 L F
.194 .178 .611 r
.15926 .58777 m .16097 .58965 L .16111 .5871 L F
.15926 .58777 m .15952 .59151 L .16097 .58965 L F
.419 .241 .531 r
.36936 .56575 m .36945 .56872 L .36713 .56929 L F
.451 .337 .633 r
.36945 .56872 m .36943 .57152 L .36713 .56929 L F
.568 .339 .528 r
.36713 .56929 m .36943 .57152 L .36693 .57182 L F
.36713 .56929 m .36943 .57152 L .36693 .57182 L F
.634 .552 .745 r
.37042 .54399 m .36808 .54457 L .37056 .54047 L F
.685 .527 .667 r
.37129 .54668 m .36808 .54457 L .37042 .54399 L F
.37129 .54668 m .3679 .54808 L .36808 .54457 L F
.733 .272 .157 r
.30751 .56548 m .30896 .56759 L .31172 .56633 L F
.402 0 0 r
.29749 .54397 m .29509 .54571 L .29338 .5447 L F
.301 0 0 r
.2977 .54538 m .29749 .54397 L .29955 .54384 L F
.2977 .54538 m .29509 .54571 L .29749 .54397 L F
.732 .646 .763 r
.50707 .56517 m .50338 .56276 L .50556 .56254 L F
.319 .582 .937 r
.5085 .56362 m .50707 .56517 L .50556 .56254 L F
.5085 .56362 m .50961 .56531 L .50707 .56517 L F
.546 .352 .569 r
.33853 .63661 m .33687 .63794 L .33646 .63403 L F
.643 .365 .483 r
.33957 .63424 m .33853 .63661 L .33646 .63403 L F
.031 0 .202 r
.28704 .58727 m .28897 .5867 L .28906 .58429 L F
.082 0 .086 r
.28704 .58727 m .28799 .58865 L .28897 .5867 L F
.28704 .58727 m .28619 .58974 L .28799 .58865 L F
.627 .565 .765 r
.34269 .54748 m .34011 .54803 L .33889 .54442 L F
.575 .397 .603 r
.30852 .62477 m .31103 .62429 L .31102 .62163 L F
0 0 0 r
.30988 .62338 m .30852 .62477 L .31102 .62163 L F
.725 .536 .636 r
.30761 .62698 m .31103 .62429 L .30852 .62477 L F
0 0 0 r
.30761 .62698 m .30852 .62477 L .30988 .62338 L F
.693 .931 .967 r
.25175 .71563 m .25214 .7142 L .25004 .71382 L F
.797 .69 .747 r
.33011 .56631 m .32673 .57161 L .33218 .57036 L F
.608 .609 .827 r
.33011 .56631 m .33218 .57036 L .33457 .56898 L F
0 .441 .861 r
.22758 .62177 m .22365 .61939 L .22562 .6194 L F
0 .265 .77 r
.22562 .6194 m .22776 .62079 L .22758 .62177 L F
.217 .644 .954 r
.22776 .62079 m .22973 .62196 L .22758 .62177 L F
.253 .139 .525 r
.30841 .57854 m .30995 .57781 L .30975 .57525 L F
.42 .217 .496 r
.30841 .57854 m .31023 .58047 L .30995 .57781 L F
.30841 .57854 m .308 .58119 L .31023 .58047 L F
.68 .315 .348 r
.23549 .73564 m .23956 .73555 L .23663 .73483 L F
0 0 0 r
.28163 .54939 m .2794 .55042 L .28289 .54865 L F
.576 .892 .619 r
.27925 .55022 m .2794 .55042 L .28163 .54939 L F
.27925 .55022 m .27736 .55201 L .2794 .55042 L F
.258 0 .093 r
.19376 .5719 m .19034 .57469 L .19185 .572 L F
.375 .422 .782 r
.16071 .59383 m .16097 .58965 L .15952 .59151 L F
.601 .286 .407 r
.31992 .64664 m .31909 .64898 L .31618 .64894 L F
.558 .258 .414 r
.3222 .646 m .31909 .64898 L .31992 .64664 L F
.978 .73 .49 r
.24831 .69479 m .24969 .69848 L .24985 .69523 L F
.24831 .69479 m .24969 .69848 L .24985 .69523 L F
.704 .842 .949 r
.24969 .69848 m .25232 .69518 L .24985 .69523 L F
0 0 0 r
.29939 .58705 m .2935 .59017 L .29354 .58828 L F
.29939 .58705 m .29546 .58923 L .29473 .58952 L F
.931 .949 .777 r
.29726 .58597 m .29546 .58923 L .29939 .58705 L F
0 0 .071 r
.29602 .58902 m .29546 .58923 L .29611 .58808 L F
.29592 .59013 m .29546 .58923 L .29602 .58902 L F
0 0 0 r
.29473 .58952 m .29546 .58923 L .2935 .59017 L F
.557 .447 .684 r
.81463 .41218 m .8169 .40898 L .81344 .40835 L F
.81463 .41218 m .81731 .41152 L .8169 .40898 L F
.584 .349 .526 r
.37703 .54132 m .3745 .54416 L .37274 .54162 L F
.37703 .54132 m .37672 .54407 L .3745 .54416 L F
.52 .373 .622 r
.37922 .53818 m .37942 .54083 L .37703 .54132 L F
.308 .022 .306 r
.1751 .56517 m .17767 .5619 L .17613 .56302 L F
.565 .624 .869 r
.28743 .66441 m .28528 .66516 L .2831 .66141 L F
.144 0 0 r
.28337 .66725 m .28528 .66516 L .28743 .66441 L F
.073 .598 .873 r
.31721 .53486 m .31934 .53513 L .32107 .53581 L F
.259 .621 .959 r
.32183 .5346 m .32107 .53581 L .31934 .53513 L F
.32183 .5346 m .32318 .53601 L .32107 .53581 L F
.892 .953 .837 r
.31021 .62067 m .31102 .62163 L .31337 .6185 L F
.994 .793 .422 r
.30988 .62338 m .31102 .62163 L .31021 .62067 L F
.55 .391 .619 r
.31102 .62163 m .31342 .62115 L .31337 .6185 L F
.591 .435 .638 r
.31103 .62429 m .31342 .62115 L .31102 .62163 L F
.665 .758 .919 r
.54008 .56902 m .54414 .5697 L .54261 .56843 L F
.375 .422 .782 r
.16071 .59383 m .16213 .59323 L .16097 .58965 L F
.016 .097 .606 r
.16071 .59383 m .16227 .59586 L .16213 .59323 L F
.229 .332 .763 r
.20655 .60814 m .20579 .61055 L .20422 .60622 L F
.004 .13 .645 r
.20696 .61002 m .20579 .61055 L .20655 .60814 L F
.20696 .61002 m .20634 .61196 L .20579 .61055 L F
0 0 0 r
.27883 .64976 m .27658 .65244 L .27792 .65162 L F
.15 .226 .688 r
.27792 .65162 m .27658 .65244 L .27846 .65434 L F
.448 .04 .172 r
.29338 .5447 m .28942 .54682 L .29105 .54498 L F
0 0 .036 r
.27289 .60928 m .27071 .61268 L .2719 .61146 L F
0 0 0 r
.2719 .61146 m .27071 .61268 L .26954 .61462 L F
.907 .683 .586 r
.53512 .54151 m .53493 .54414 L .53319 .54074 L F
.063 .32 .802 r
.22501 .63375 m .22542 .63263 L .22307 .63255 L F
.22501 .63375 m .22583 .63397 L .22542 .63263 L F
.558 .821 .995 r
.55112 .54456 m .54734 .5441 L .54971 .54346 L F
.55112 .54456 m .54734 .5441 L .54971 .54346 L F
.937 .585 .168 r
.55058 .54612 m .55112 .54456 L .54971 .54346 L F
.55058 .54612 m .5519 .54744 L .55112 .54456 L F
.505 .811 1 r
.28665 .53099 m .29058 .53152 L .28826 .53203 L F
.3 .562 .928 r
.18607 .61117 m .18691 .61267 L .18746 .61102 L F
.302 .563 .929 r
.18746 .61102 m .18691 .61267 L .18845 .61266 L F
.066 .26 .751 r
.33839 .57605 m .33904 .57831 L .33767 .57734 L F
.546 .573 .833 r
.34522 .54686 m .34657 .54955 L .34269 .54748 L F
.529 .279 .48 r
.26037 .69888 m .26244 .70081 L .25987 .7013 L F
.26037 .69888 m .26281 .69857 L .26244 .70081 L F
.672 .4 .502 r
.32567 .60266 m .32814 .60287 L .32849 .60028 L F
.704 .489 .593 r
.32814 .60287 m .33157 .59999 L .32849 .60028 L F
.388 .223 .533 r
.31696 .56287 m .31929 .56204 L .31887 .55958 L F
.483 .258 .496 r
.31696 .56287 m .31735 .56453 L .31929 .56204 L F
.31696 .56287 m .3167 .56532 L .31735 .56453 L F
.908 .599 .11 r
.33282 .5779 m .33403 .58147 L .3334 .58097 L F
.269 0 0 r
.25453 .55411 m .25262 .55551 L .25016 .55577 L F
.253 0 0 r
.25677 .55339 m .25262 .55551 L .25453 .55411 L F
.253 .756 .708 r
.25014 .53429 m .25099 .53394 L .25242 .53375 L F
.918 .858 .766 r
.27262 .67102 m .2747 .66443 L .27238 .66527 L F
.396 .099 .339 r
.27541 .67092 m .27262 .67102 L .27308 .67103 L F
.27541 .67092 m .2764 .66871 L .27262 .67102 L F
.474 .868 .969 r
.23466 .63629 m .23416 .63736 L .2364 .63672 L F
.23466 .63629 m .2324 .63697 L .23416 .63736 L F
.489 .32 .578 r
.19327 .59716 m .19273 .60085 L .19121 .59962 L F
.195 0 0 r
.20754 .56263 m .20336 .56465 L .20515 .56294 L F
.837 .898 .882 r
.78207 .39878 m .78045 .4028 L .77895 .40136 L F
.78207 .39878 m .78313 .40012 L .78045 .4028 L F
.195 0 .367 r
.29439 .57259 m .2938 .57494 L .29583 .57142 L F
.474 .237 .474 r
.36525 .55009 m .36303 .5512 L .36552 .54767 L F
.531 .286 .488 r
.36776 .54964 m .36525 .55009 L .36552 .54767 L F
.645 .247 .276 r
.3679 .54808 m .36776 .54964 L .36552 .54767 L F
.958 .712 .523 r
.2633 .67339 m .26496 .67484 L .26312 .67603 L F
.662 .787 .941 r
.26496 .67484 m .26719 .67385 L .2633 .67339 L F
.613 .816 .978 r
.34108 .56949 m .34121 .57163 L .33851 .5701 L F
0 0 .396 r
.34108 .56949 m .34071 .57055 L .34121 .57163 L F
.462 .803 .999 r
.33765 .57249 m .34121 .57163 L .34167 .57263 L F
.3 .015 .302 r
.33963 .57362 m .33765 .57249 L .34272 .57266 L F
.486 .775 .996 r
.33851 .5701 m .34004 .57097 L .33765 .57249 L F
.34004 .57097 m .34121 .57163 L .33878 .57222 L F
.34004 .57097 m .33878 .57222 L .33765 .57249 L F
0 0 .396 r
.34071 .57055 m .33963 .57362 L .34121 .57163 L F
.462 .803 .999 r
.34167 .57263 m .34121 .57163 L .34272 .57266 L F
.946 .881 .739 r
.34121 .57163 m .33963 .57362 L .34272 .57266 L F
0 0 .396 r
.34085 .57016 m .34104 .5729 L .33963 .57362 L F
.34108 .56949 m .34108 .56993 L .34085 .57016 L F
.34108 .56993 m .34104 .5729 L .34085 .57016 L F
.545 .765 .979 r
.34547 .55551 m .34857 .55701 L .35027 .5561 L F
.104 .21 .69 r
.34857 .55701 m .35049 .55886 L .35027 .5561 L F
.696 .781 .917 r
.23618 .72596 m .23815 .72759 L .24024 .72643 L F
.666 .802 .947 r
.18393 .58487 m .18008 .58442 L .18231 .58372 L F
.167 .36 .811 r
.18465 .58307 m .18393 .58487 L .18231 .58372 L F
.18465 .58307 m .18697 .58749 L .18393 .58487 L F
0 0 .083 r
.29239 .55068 m .29304 .55155 L .29478 .55223 L F
.29239 .55068 m .29178 .5533 L .29304 .55155 L F
.401 .228 .529 r
.30236 .57163 m .3004 .57507 L .30049 .57229 L F
.501 .33 .581 r
.18231 .58372 m .17996 .58163 L .1836 .58328 L F
.18231 .58372 m .18008 .58442 L .17996 .58163 L F
.331 .305 .68 r
.33547 .57208 m .3378 .57432 L .33765 .57249 L F
.33547 .57208 m .33762 .57599 L .3378 .57432 L F
.383 .027 .232 r
.25148 .71002 m .25274 .70799 L .25015 .71024 L F
.201 0 .12 r
.25401 .70855 m .25274 .70799 L .25148 .71002 L F
0 0 .157 r
.33765 .57249 m .3384 .57288 L .33851 .5701 L F
.3 .015 .302 r
.33963 .57362 m .3378 .57432 L .33765 .57249 L F
0 0 .157 r
.33765 .57249 m .3378 .57432 L .3384 .57288 L F
.077 0 0 r
.28396 .54867 m .28289 .54865 L .2847 .54805 L F
.28396 .54867 m .28163 .54939 L .28289 .54865 L F
.634 .174 .143 r
.53322 .52228 m .53599 .52436 L .5375 .52252 L F
.708 .264 .194 r
.5375 .52252 m .53971 .52475 L .53916 .52345 L F
.5375 .52252 m .53599 .52436 L .53971 .52475 L F
.472 0 0 r
.29531 .55505 m .29262 .55491 L .29362 .55601 L F
.541 .523 .785 r
.77915 .41221 m .78084 .40774 L .77801 .40857 L F
.77915 .41221 m .78202 .41158 L .78084 .40774 L F
.486 .898 .905 r
.26055 .62262 m .25979 .62343 L .25858 .62347 L F
.464 .366 .659 r
.34486 .61809 m .34326 .62156 L .3424 .6186 L F
.34486 .61809 m .34493 .6211 L .34326 .62156 L F
.417 .263 .564 r
.34493 .6211 m .34282 .62415 L .34326 .62156 L F
.749 .44 .46 r
.82036 .40367 m .82283 .40534 L .8221 .4027 L F
.854 .688 .675 r
.82283 .40534 m .82435 .40208 L .8221 .4027 L F
0 .56 .763 r
.19368 .81007 m .19495 .8103 L .19242 .81001 L F
.668 .224 .189 r
.19068 .80981 m .19495 .8103 L .19275 .81182 L F
.156 0 .254 r
.19403 .81008 m .19368 .81007 L .19275 .81182 L F
.522 .91 .932 r
.19368 .81007 m .19702 .80941 L .19514 .80857 L F
.156 0 .254 r
.19514 .80857 m .19368 .81007 L .19403 .81008 L F
0 .56 .763 r
.19368 .81007 m .19242 .81001 L .19068 .80981 L F
.522 .91 .932 r
.19368 .81007 m .19495 .8103 L .19702 .80941 L F
0 0 0 r
.19275 .81182 m .19495 .8103 L .19702 .80941 L F
.97 .71 .484 r
.55078 .53176 m .5507 .53435 L .5523 .53529 L F
.956 .628 .357 r
.5507 .53435 m .55105 .53679 L .5523 .53529 L F
.969 .66 .375 r
.55105 .53679 m .55267 .538 L .5523 .53529 L F
.516 .887 .973 r
.25605 .70172 m .25798 .70213 L .25987 .7013 L F
.711 .485 .579 r
.25848 .70286 m .25912 .70253 L .25987 .7013 L F
.694 .539 .672 r
.25957 .7066 m .25957 .70658 L .25848 .70286 L F
.25957 .7066 m .25909 .70306 L .25848 .70286 L F
.906 .58 .097 r
.25836 .70325 m .25957 .7066 L .25848 .70286 L F
.967 .724 .518 r
.25836 .70325 m .25919 .70379 L .25957 .7066 L F
.25919 .70379 m .26022 .70446 L .25957 .7066 L F
.694 .539 .672 r
.25957 .7066 m .25957 .7066 L .25957 .70658 L F
.967 .724 .518 r
.25987 .7013 m .26022 .70446 L .25919 .70379 L F
.25987 .7013 m .25919 .70379 L .25915 .70344 L F
.25987 .7013 m .25906 .7037 L .25912 .70253 L F
.457 .278 .549 r
.26244 .70081 m .26022 .70446 L .25987 .7013 L F
.26244 .70081 m .26237 .70408 L .26022 .70446 L F
.396 .108 .354 r
.26022 .70446 m .26237 .70408 L .25957 .7066 L F
.694 .539 .672 r
.25957 .7066 m .26237 .70408 L .25909 .70306 L F
.967 .724 .518 r
.25915 .70344 m .25919 .70379 L .25906 .7037 L F
.25912 .70253 m .25906 .7037 L .2586 .7034 L F
.711 .485 .579 r
.25912 .70253 m .26237 .70408 L .26244 .70081 L F
.25848 .70286 m .25909 .70306 L .25912 .70253 L F
.25909 .70306 m .26237 .70408 L .25912 .70253 L F
.25912 .70253 m .26244 .70081 L .25987 .7013 L F
.967 .724 .518 r
.25987 .7013 m .2586 .7034 L .25836 .70325 L F
0 0 0 r
.25848 .70286 m .25987 .7013 L .25836 .70325 L F
.516 .887 .973 r
.25842 .70283 m .25987 .7013 L .25848 .70286 L F
.024 0 0 r
.25835 .70291 m .25798 .70213 L .25987 .7013 L F
.25827 .70298 m .25827 .70297 L .25835 .70291 L F
.25824 .70287 m .25798 .70213 L .25832 .70285 L F
.516 .887 .973 r
.25605 .70172 m .25987 .7013 L .25842 .70283 L F
.291 .568 .933 r
.25605 .70172 m .25842 .70283 L .25648 .69987 L F
.25842 .70283 m .25848 .70286 L .25845 .70282 L F
.25842 .70283 m .25845 .70282 L .25648 .69987 L F
.024 0 0 r
.25827 .70297 m .25824 .70287 L .25835 .70291 L F
.25824 .70287 m .25832 .70285 L .25835 .70291 L F
.851 .838 .832 r
.25648 .69987 m .25845 .70282 L .26013 .70007 L F
.25845 .70282 m .25848 .70286 L .25854 .70276 L F
.25845 .70282 m .25854 .70276 L .26013 .70007 L F
.024 0 0 r
.25836 .70325 m .25827 .70298 L .25987 .7013 L F
0 0 .145 r
.37062 .56205 m .36936 .56575 L .37236 .5632 L F
.975 .711 .464 r
.37062 .56205 m .37236 .5632 L .37073 .55944 L F
.819 .643 .664 r
.31815 .61169 m .3209 .60916 L .31637 .60862 L F
.757 .537 .597 r
.31815 .61169 m .32071 .61245 L .3209 .60916 L F
.685 .552 .698 r
.3209 .60916 m .32378 .60925 L .32372 .60601 L F
.646 .441 .591 r
.3209 .60916 m .32385 .61151 L .32378 .60925 L F
.3209 .60916 m .32071 .61245 L .32385 .61151 L F
.025 .082 .585 r
.29554 .56577 m .29604 .56919 L .29725 .56766 L F
.132 .084 .532 r
.29583 .57142 m .29725 .56766 L .29604 .56919 L F
.854 .688 .675 r
.82283 .40534 m .82587 .40574 L .82435 .40208 L F
.822 .734 .768 r
.82183 .40733 m .82587 .40574 L .82283 .40534 L F
.82183 .40733 m .82362 .40891 L .82587 .40574 L F
.603 .539 .756 r
.27238 .66527 m .2747 .66443 L .27094 .66199 L F
.27238 .66527 m .2747 .66443 L .27094 .66199 L F
.79 .292 0 r
.31077 .59319 m .31414 .59614 L .31195 .59625 L F
.484 .408 .695 r
.26327 .68361 m .26597 .68578 L .2651 .68323 L F
.26327 .68361 m .26382 .68601 L .26597 .68578 L F
.697 .302 .295 r
.27792 .65162 m .28061 .65168 L .27883 .64976 L F
.427 .178 .431 r
.16723 .57167 m .16997 .56866 L .16774 .56927 L F
.672 .96 .74 r
.29867 .58468 m .30016 .58433 L .30173 .58366 L F
.29867 .58468 m .29726 .58597 L .30016 .58433 L F
.213 0 .34 r
.31144 .61456 m .30958 .61545 L .31189 .61216 L F
0 0 .473 r
.31096 .6171 m .30958 .61545 L .31144 .61456 L F
.31096 .6171 m .30989 .61795 L .30958 .61545 L F
.367 0 0 r
.23022 .55094 m .22581 .55218 L .22787 .55088 L F
.704 .842 .949 r
.24969 .69848 m .25433 .69825 L .25232 .69518 L F
.944 .581 .243 r
.25232 .69518 m .25433 .69825 L .25225 .69859 L F
.995 .862 .537 r
.25225 .69859 m .25433 .69825 L .25325 .70184 L F
.83 .913 .894 r
.77568 .40094 m .77728 .40245 L .77454 .40384 L F
.616 .852 .988 r
.77568 .40094 m .77895 .40136 L .77728 .40245 L F
.632 .9 .985 r
.31088 .53315 m .30678 .53339 L .30905 .5329 L F
.033 0 0 r
.30905 .5329 m .31285 .53272 L .31088 .53315 L F
.081 0 .198 r
.365 .5754 m .36432 .57745 L .36296 .57793 L F
.339 .261 .62 r
.36473 .5801 m .36296 .57793 L .36432 .57745 L F
.36473 .5801 m .36293 .58185 L .36296 .57793 L F
.677 .189 0 r
.18789 .59135 m .18817 .59164 L .18845 .59144 L F
.818 .555 0 r
.18845 .59144 m .18912 .59405 L .18849 .59142 L F
.186 .569 .937 r
.18939 .59286 m .18912 .59405 L .18845 .59144 L F
.677 .189 0 r
.18817 .59164 m .18939 .59286 L .18845 .59144 L F
.818 .555 0 r
.18845 .59144 m .18849 .59142 L .18807 .58966 L F
.186 .569 .937 r
.18939 .59286 m .19077 .59429 L .18912 .59405 L F
.943 .605 .185 r
.78539 .39649 m .78478 .39767 L .78583 .39863 L F
.78539 .39649 m .78478 .39767 L .78583 .39863 L F
.601 .421 .61 r
.34787 .54648 m .34522 .54686 L .34534 .54446 L F
.534 .337 .559 r
.36693 .57182 m .36684 .57442 L .36448 .57246 L F
.422 .345 .664 r
.36684 .57442 m .365 .5754 L .36448 .57246 L F
.421 .258 .554 r
.34716 .61213 m .34699 .61503 L .34488 .61545 L F
.422 .264 .56 r
.34699 .61503 m .34486 .61809 L .34488 .61545 L F
.192 .721 .737 r
.24013 .53516 m .2424 .53465 L .24408 .53435 L F
.304 0 0 r
.24408 .53435 m .2424 .53465 L .24637 .53459 L F
.397 .468 .816 r
.33743 .55979 m .3353 .55684 L .33764 .55627 L F
.84 .402 .189 r
.33769 .5585 m .34138 .56172 L .33743 .55979 L F
0 0 0 r
.21885 .53848 m .21887 .53873 L .22109 .53791 L F
.21885 .53848 m .21664 .53956 L .21887 .53873 L F
.589 .655 .883 r
.27956 .64503 m .28048 .64819 L .2827 .64738 L F
.5 .728 .974 r
.28048 .64819 m .28405 .64848 L .2827 .64738 L F
.626 .382 .529 r
.33485 .55874 m .33764 .55627 L .3353 .55684 L F
0 0 0 r
.3016 .60892 m .29816 .61168 L .30077 .61141 L F
0 0 .05 r
.3016 .60892 m .30077 .61141 L .30215 .61038 L F
.278 .002 .302 r
.16534 .57244 m .16459 .57463 L .16723 .57167 L F
.832 .676 .69 r
.7857 .41439 m .78734 .41158 L .78433 .41059 L F
0 0 .08 r
.27481 .60582 m .27289 .60928 L .27458 .60826 L F
0 0 .021 r
.27458 .60826 m .27289 .60928 L .2719 .61146 L F
.288 .123 .475 r
.31752 .58124 m .3174 .584 L .31586 .58417 L F
.075 .634 .792 r
.17223 .60265 m .16754 .60247 L .16787 .59975 L F
.17223 .60265 m .17014 .60246 L .16754 .60247 L F
.178 .708 .846 r
.17223 .60265 m .17367 .60244 L .17014 .60246 L F
.035 .167 .672 r
.20696 .61002 m .20816 .61406 L .20634 .61196 L F
.718 .366 .38 r
.53868 .54447 m .5371 .54675 L .53493 .54414 L F
.896 .615 .504 r
.53868 .54447 m .53942 .54757 L .5371 .54675 L F
0 0 .145 r
.37062 .56205 m .37018 .56488 L .36936 .56575 L F
.553 .343 .55 r
.37344 .56451 m .36936 .56575 L .37018 .56488 L F
.37344 .56451 m .36945 .56872 L .36936 .56575 L F
.472 .647 .935 r
.19455 .61864 m .19568 .61602 L .1927 .61586 L F
.19455 .61864 m .19639 .61825 L .19568 .61602 L F
.414 .774 .995 r
.18015 .60902 m .17961 .60749 L .17731 .60577 L F
.18015 .60902 m .18144 .60847 L .17961 .60749 L F
.318 .731 .977 r
.22412 .61851 m .22365 .61939 L .22184 .61836 L F
.22412 .61851 m .22562 .6194 L .22365 .61939 L F
.392 .161 .441 r
.29554 .56577 m .29758 .56561 L .29762 .56328 L F
.025 .082 .585 r
.29554 .56577 m .29725 .56766 L .29758 .56561 L F
.458 .715 .979 r
.23541 .73775 m .23711 .73937 L .23896 .73893 L F
.92 .652 .515 r
.2297 .55723 m .22884 .55868 L .2276 .55721 L F
.733 .497 .571 r
.2276 .55721 m .23082 .55691 L .2297 .55723 L F
.034 0 0 r
.23082 .55691 m .22884 .55868 L .2297 .55723 L F
.675 .125 0 r
.19691 .59999 m .19894 .60198 L .2008 .60263 L F
0 .484 .775 r
.19894 .60198 m .2027 .60307 L .2008 .60263 L F
.496 .759 .989 r
.30678 .53339 m .30508 .53402 L .30275 .53254 L F
.44 .356 .665 r
.32372 .60601 m .32625 .60819 L .3254 .60548 L F
.32372 .60601 m .32378 .60925 L .32625 .60819 L F
.794 .699 .76 r
.19691 .59999 m .19466 .60347 L .19273 .60085 L F
.19691 .59999 m .19273 .60085 L .1949 .60063 L F
0 .055 .584 r
.1975 .60024 m .19894 .60198 L .19691 .59999 L F
.1975 .60024 m .19691 .59999 L .1949 .60063 L F
.519 .702 .954 r
.34848 .53946 m .34751 .54181 L .34581 .54014 L F
.34848 .53946 m .35052 .54129 L .34751 .54181 L F
.623 .476 .662 r
.3497 .61175 m .34672 .60825 L .34838 .6081 L F
.3497 .61175 m .34716 .61213 L .34672 .60825 L F
.571 .286 .445 r
.25744 .69758 m .25837 .69277 L .25535 .69508 L F
.57 .442 .667 r
.26082 .6917 m .25837 .69277 L .26007 .69212 L F
.522 .372 .618 r
.28618 .62797 m .28829 .628 L .28845 .62437 L F
.667 .569 .735 r
.28645 .63071 m .28829 .628 L .28618 .62797 L F
.563 .935 .827 r
.31421 .55778 m .3123 .55912 L .31376 .55858 L F
.61 .168 .174 r
.23682 .73777 m .23956 .73555 L .23549 .73564 L F
.243 0 0 r
.2416 .73573 m .23956 .73555 L .23682 .73777 L F
.641 .579 .77 r
.78312 .41529 m .78433 .41059 L .78202 .41158 L F
.78312 .41529 m .7857 .41439 L .78433 .41059 L F
.533 0 0 r
.2023 .6247 m .2007 .62389 L .19808 .62188 L F
.733 .915 .956 r
.2028 .62228 m .2023 .6247 L .20556 .62381 L F
.2028 .62228 m .2007 .62389 L .2023 .6247 L F
.124 .567 .922 r
.21406 .61661 m .21378 .61748 L .21219 .61633 L F
.21406 .61661 m .21573 .61784 L .21378 .61748 L F
.977 .732 .498 r
.28617 .65596 m .28934 .65278 L .28819 .65468 L F
.891 .844 .792 r
.28685 .65105 m .28934 .65278 L .29118 .64935 L F
.951 .788 .644 r
.28819 .65468 m .28934 .65278 L .28685 .65105 L F
.221 .133 .538 r
.28906 .58429 m .29087 .58071 L .28957 .57984 L F
.28906 .58429 m .29125 .58338 L .29087 .58071 L F
.087 0 .214 r
.28906 .58429 m .28897 .5867 L .29125 .58338 L F
.413 .781 .994 r
.2364 .63672 m .2402 .6373 L .2385 .6364 L F
.217 .665 .95 r
.2402 .6373 m .24082 .63653 L .2385 .6364 L F
.2402 .6373 m .24263 .63745 L .24082 .63653 L F
.791 .738 .804 r
.82183 .40733 m .82008 .40831 L .82362 .40891 L F
.812 .73 .773 r
.81948 .41043 m .82362 .40891 L .82008 .40831 L F
.81948 .41043 m .82121 .41219 L .82362 .40891 L F
.489 .266 .502 r
.29762 .56328 m .30036 .56286 L .30082 .55995 L F
.309 .099 .423 r
.29762 .56328 m .29952 .56467 L .30036 .56286 L F
.29762 .56328 m .29758 .56561 L .29952 .56467 L F
.112 0 .024 r
.34529 .5601 m .34658 .56141 L .34797 .56238 L F
.909 .752 .675 r
.33299 .56609 m .33583 .5647 L .33504 .56599 L F
.192 0 .27 r
.34369 .63013 m .34122 .63319 L .34163 .63114 L F
.068 .341 .817 r
.18845 .61266 m .19059 .61583 L .19108 .61446 L F
.367 .692 .982 r
.19059 .61583 m .1927 .61586 L .19108 .61446 L F
.134 0 0 r
.23431 .54967 m .2318 .55109 L .23022 .55094 L F
0 0 0 r
.23489 .54957 m .23431 .54967 L .23647 .54939 L F
.23489 .54957 m .2318 .55109 L .23431 .54967 L F
.371 .491 .851 r
.34712 .56484 m .34797 .56238 L .34515 .56492 L F
.34712 .56484 m .3491 .5654 L .34797 .56238 L F
.271 .031 .355 r
.23851 .7228 m .2368 .72346 L .23618 .72596 L F
.939 .678 .515 r
.52731 .52913 m .52524 .53047 L .52616 .52752 L F
.52731 .52913 m .52742 .53162 L .52524 .53047 L F
.892 .953 .837 r
.31021 .62067 m .31337 .6185 L .30989 .61795 L F
.613 .471 .665 r
.31342 .62115 m .31584 .61798 L .31337 .6185 L F
.808 .938 .575 r
.30851 .55325 m .30675 .55518 L .30656 .55656 L F
.563 .312 .494 r
.30851 .55325 m .30723 .55674 L .31102 .55568 L F
0 .154 .696 r
.30723 .55674 m .30917 .55941 L .30656 .55656 L F
.563 .312 .494 r
.30723 .55674 m .30713 .55701 L .3074 .55692 L F
.30723 .55674 m .3074 .55692 L .31102 .55568 L F
0 .154 .696 r
.30729 .55676 m .3074 .55692 L .30723 .55674 L F
.3074 .55692 m .30917 .55941 L .30723 .55674 L F
.65 .525 .698 r
.3074 .55692 m .30917 .55941 L .31102 .55568 L F
0 .154 .696 r
.30772 .55688 m .30917 .55941 L .30729 .55676 L F
.65 .525 .698 r
.30713 .55701 m .30917 .55941 L .3074 .55692 L F
.003 0 .2 r
.30656 .55656 m .30713 .55701 L .30723 .55674 L F
.30656 .55656 m .30723 .55674 L .30851 .55325 L F
0 .154 .696 r
.30675 .55518 m .30772 .55688 L .30656 .55656 L F
0 .027 .568 r
.30656 .55656 m .30917 .55941 L .30713 .55701 L F
.47 .804 .999 r
.29671 .53197 m .29453 .53249 L .29267 .53151 L F
.523 .143 .262 r
.37079 .54934 m .3679 .54808 L .37129 .54668 L F
.37079 .54934 m .36776 .54964 L .3679 .54808 L F
.64 .269 .325 r
.31367 .64895 m .30966 .6511 L .3099 .6494 L F
.31367 .64895 m .31208 .65133 L .30966 .6511 L F
.584 .205 .289 r
.31569 .65109 m .31367 .64895 L .31618 .64894 L F
.31569 .65109 m .31208 .65133 L .31367 .64895 L F
.776 .413 .369 r
.36185 .59049 m .36066 .59259 L .35648 .59065 L F
.565 .47 .706 r
.36458 .58594 m .36424 .59005 L .36185 .59049 L F
.295 0 .07 r
.36424 .59005 m .36066 .59259 L .36185 .59049 L F
.529 .397 .645 r
.32385 .61151 m .32625 .60819 L .32378 .60925 L F
0 0 0 r
.27695 .60175 m .27481 .60582 L .27672 .60506 L F
0 0 .106 r
.27481 .60582 m .27568 .60716 L .27672 .60506 L F
.27481 .60582 m .27458 .60826 L .27568 .60716 L F
.417 .219 .502 r
.16253 .57527 m .16228 .5778 L .16459 .57463 L F
.339 .107 .409 r
.28869 .59549 m .2879 .59978 L .28611 .59947 L F
.357 .123 .416 r
.2899 .59877 m .28869 .59549 L .29038 .59472 L F
.2899 .59877 m .2879 .59978 L .28869 .59549 L F
.079 0 .299 r
.28323 .60523 m .28191 .60615 L .28375 .60273 L F
.113 0 .356 r
.28151 .60866 m .28191 .60615 L .28323 .60523 L F
.116 .314 .785 r
.19639 .61825 m .19808 .62188 L .19879 .62016 L F
.116 .314 .786 r
.19808 .62188 m .2007 .62389 L .19879 .62016 L F
.435 .262 .546 r
.29615 .61466 m .29816 .61168 L .29587 .61213 L F
.558 .258 .414 r
.3222 .646 m .32219 .64872 L .31909 .64898 L F
0 .137 .67 r
.3211 .64265 m .3222 .646 L .32534 .64383 L F
.3211 .64265 m .32297 .64462 L .3222 .646 L F
0 0 .222 r
.32306 .64736 m .3222 .646 L .32297 .64462 L F
.32306 .64736 m .32219 .64872 L .3222 .646 L F
.487 .266 .504 r
.31447 .60918 m .31424 .61166 L .31189 .61216 L F
.31447 .60918 m .31424 .61166 L .31189 .61216 L F
.581 .432 .644 r
.31637 .60862 m .31424 .61166 L .31447 .60918 L F
.31637 .60862 m .31424 .61166 L .31447 .60918 L F
.447 .229 .489 r
.30082 .55995 m .30243 .56212 L .30312 .55899 L F
.30082 .55995 m .30036 .56286 L .30243 .56212 L F
.578 .514 .747 r
.37371 .54602 m .37129 .54668 L .37042 .54399 L F
.137 0 .085 r
.37371 .54602 m .37079 .54934 L .37129 .54668 L F
.706 .474 .569 r
.35727 .60256 m .35457 .59977 L .35703 .59987 L F
.35727 .60256 m .35475 .60265 L .35457 .59977 L F
.526 .367 .608 r
.32323 .59056 m .32555 .58999 L .32609 .58806 L F
.526 .365 .606 r
.32317 .59383 m .32555 .58999 L .32323 .59056 L F
.526 .367 .608 r
.32323 .59056 m .32555 .58999 L .32609 .58806 L F
.526 .365 .606 r
.32317 .59383 m .32555 .58999 L .32323 .59056 L F
.56 .502 .748 r
.5363 .56825 m .53426 .56974 L .53381 .56744 L F
.5363 .56825 m .53426 .56974 L .53381 .56744 L F
0 0 0 r
.33267 .55089 m .33098 .55213 L .32991 .55211 L F
.768 .671 .756 r
.16379 .5993 m .16533 .60301 L .16787 .59975 L F
.744 .628 .731 r
.32327 .64203 m .3272 .64288 L .3259 .63902 L F
.12 0 .265 r
.32534 .64104 m .3251 .64141 L .32327 .64203 L F
0 .137 .67 r
.32129 .64271 m .32534 .64383 L .32327 .64203 L F
.534 .76 .98 r
.32327 .64203 m .32534 .64383 L .3272 .64288 L F
.12 0 .265 r
.3251 .64141 m .32297 .64462 L .32327 .64203 L F
0 .137 .67 r
.3211 .64265 m .32129 .64271 L .32327 .64203 L F
.826 .937 .569 r
.53758 .55656 m .53904 .55324 L .53957 .55308 L F
.193 .351 .794 r
.53939 .55257 m .54115 .5518 L .53848 .55007 L F
.231 .352 .781 r
.53848 .55007 m .54115 .5518 L .53982 .54817 L F
.973 .762 .335 r
.53778 .55515 m .53719 .55137 L .53904 .55324 L F
.193 .351 .794 r
.53957 .55308 m .54115 .5518 L .53939 .55257 L F
.09 0 .434 r
.53719 .55137 m .54115 .5518 L .53904 .55324 L F
.53719 .55137 m .53819 .553 L .54115 .5518 L F
.301 .335 .731 r
.54115 .5518 m .54215 .54847 L .53982 .54817 L F
.77 .573 .632 r
.53819 .553 m .54238 .55125 L .54115 .5518 L F
.301 .335 .731 r
.54115 .5518 m .5428 .55107 L .54215 .54847 L F
.77 .573 .632 r
.54238 .55125 m .5428 .55107 L .54115 .5518 L F
.479 .872 .69 r
.53957 .55308 m .53904 .55324 L .54115 .5518 L F
0 0 0 r
.1925 .55077 m .1896 .55337 L .19144 .55206 L F
.238 0 .093 r
.19144 .55206 m .1946 .54988 L .1925 .55077 L F
.073 .599 .872 r
.2377 .62382 m .23418 .62295 L .23589 .62388 L F
.43 0 0 r
.23589 .62388 m .23996 .62445 L .2377 .62382 L F
.248 .221 .631 r
.36473 .5801 m .3638 .58411 L .36293 .58185 L F
.469 .873 .957 r
.25908 .53265 m .25469 .53298 L .25743 .53212 L F
.224 .731 .893 r
.25945 .53204 m .25908 .53265 L .25743 .53212 L F
.25945 .53204 m .26139 .53247 L .25908 .53265 L F
.079 0 .179 r
.34122 .63319 m .33853 .63661 L .33957 .63424 L F
.456 .806 .998 r
.16656 .59961 m .16597 .59885 L .16379 .5993 L F
.534 .594 .861 r
.16379 .5993 m .16597 .59885 L .164 .5954 L F
.749 .268 0 r
.16597 .59885 m .166 .59997 L .16518 .59783 L F
.16597 .59885 m .16518 .59783 L .16497 .59728 L F
.456 .806 .998 r
.16787 .59975 m .16597 .59885 L .16656 .59961 L F
0 0 0 r
.16787 .59975 m .16754 .60247 L .16771 .60157 L F
.16787 .59975 m .16771 .60157 L .16597 .59885 L F
.4 .308 .636 r
.30851 .55325 m .30885 .55358 L .31033 .55419 L F
.30885 .55358 m .31032 .555 L .31033 .55422 L F
.30885 .55358 m .31033 .55422 L .31033 .55419 L F
.516 .105 .2 r
.31048 .55428 m .31035 .55423 L .31039 .5542 L F
.731 .397 .414 r
.31039 .5542 m .31035 .55423 L .31035 .55421 L F
.31039 .5542 m .31035 .55421 L .31034 .55418 L F
.78 .625 .688 r
.31034 .55402 m .31039 .5542 L .31034 .55418 L F
.4 .308 .636 r
.31032 .555 m .31102 .55568 L .31055 .55383 L F
.31034 .55402 m .31055 .55383 L .31037 .5531 L F
.31032 .555 m .31055 .55383 L .31034 .55402 L F
.787 .587 .631 r
.30732 .55253 m .30988 .54988 L .30927 .5493 L F
.30915 .55064 m .31035 .55303 L .30988 .54988 L F
.30732 .55253 m .31009 .55299 L .30915 .55064 L F
.31009 .55299 m .31035 .55303 L .30915 .55064 L F
.285 .733 .96 r
.30851 .55325 m .31035 .55303 L .31009 .55299 L F
.30828 .55311 m .31009 .55299 L .30732 .55253 L F
.30851 .55325 m .31009 .55299 L .30828 .55311 L F
.516 .105 .2 r
.31228 .55213 m .31039 .5542 L .3123 .55204 L F
.333 .239 .598 r
.31102 .55568 m .31253 .55222 L .31206 .5524 L F
.31102 .55568 m .31206 .5524 L .31173 .55278 L F
.516 .105 .2 r
.31047 .55427 m .31039 .5542 L .31228 .55213 L F
.476 .428 .725 r
.31138 .55308 m .31055 .55383 L .31126 .55307 L F
.31138 .55308 m .31039 .5542 L .31034 .55402 L F
.333 .239 .598 r
.31102 .55568 m .31181 .55249 L .31055 .55383 L F
.476 .428 .725 r
.3123 .55204 m .31138 .55308 L .31135 .55303 L F
.393 .312 .645 r
.30988 .54988 m .31035 .55303 L .31181 .55249 L F
.30988 .54988 m .31181 .55249 L .31197 .55229 L F
.516 .105 .2 r
.31228 .55215 m .31206 .5524 L .31228 .55213 L F
.393 .312 .645 r
.30988 .54988 m .31206 .5524 L .31236 .55207 L F
.333 .239 .598 r
.31055 .55383 m .31181 .55249 L .31035 .55303 L F
.476 .428 .725 r
.31224 .55199 m .31135 .55303 L .30927 .5493 L F
.3123 .55204 m .31135 .55303 L .31224 .55199 L F
.393 .312 .645 r
.31197 .55229 m .31181 .55249 L .31206 .5524 L F
.333 .239 .598 r
.31102 .55568 m .31289 .55494 L .31253 .55222 L F
0 0 .064 r
.31281 .55275 m .31178 .55535 L .31228 .55215 L F
.3123 .55205 m .31228 .55215 L .3123 .55204 L F
.393 .312 .645 r
.31228 .55215 m .31225 .55233 L .31253 .55222 L F
0 0 .064 r
.31281 .55275 m .31228 .55215 L .3123 .55205 L F
.393 .312 .645 r
.31236 .55207 m .31228 .55215 L .31253 .55222 L F
.31228 .55215 m .31206 .5524 L .31225 .55233 L F
.516 .105 .2 r
.31178 .55535 m .31047 .55427 L .31206 .5524 L F
.31178 .55535 m .31206 .5524 L .31228 .55215 L F
.333 .239 .598 r
.31173 .55278 m .31206 .5524 L .31181 .55249 L F
.476 .428 .725 r
.31126 .55307 m .31045 .55392 L .31021 .55298 L F
.31055 .55383 m .31045 .55392 L .31126 .55307 L F
.31128 .5529 m .31021 .55298 L .30927 .5493 L F
.31138 .55308 m .31021 .55298 L .31128 .5529 L F
.4 .308 .636 r
.31014 .55305 m .31033 .55413 L .31035 .55303 L F
.31032 .555 m .31037 .5531 L .31035 .55303 L F
.476 .428 .725 r
.31045 .55392 m .31034 .55402 L .31014 .55312 L F
.31045 .55392 m .31014 .55312 L .30927 .5493 L F
.767 .67 .755 r
.31102 .55568 m .30917 .55941 L .30712 .55583 L F
.30861 .5554 m .30712 .55583 L .30675 .55518 L F
.31102 .55568 m .30712 .55583 L .30861 .5554 L F
.731 .397 .414 r
.31035 .55421 m .30865 .5556 L .30675 .55518 L F
.30865 .5556 m .30812 .55603 L .30675 .55518 L F
.767 .67 .755 r
.31102 .55568 m .30861 .5554 L .30866 .5556 L F
.31102 .55568 m .30866 .5556 L .3106 .55602 L F
.018 .041 .54 r
.30829 .55602 m .30812 .55603 L .30873 .55592 L F
.516 .105 .2 r
.30873 .55592 m .30812 .55603 L .30866 .5556 L F
.731 .397 .414 r
.30866 .5556 m .30812 .55603 L .30865 .5556 L F
.667 .12 0 r
.30812 .55603 m .30912 .55723 L .30675 .55518 L F
.018 .041 .54 r
.30829 .55602 m .30912 .55723 L .30812 .55603 L F
.767 .67 .755 r
.30866 .5556 m .30788 .55543 L .30901 .55707 L F
.3106 .55602 m .30938 .55576 L .30912 .55723 L F
.30938 .55576 m .30875 .55591 L .30912 .55723 L F
.30861 .5554 m .30903 .55715 L .30912 .55723 L F
.018 .041 .54 r
.31028 .55596 m .30912 .55723 L .30829 .55602 L F
.767 .67 .755 r
.30901 .55707 m .30675 .55518 L .30903 .55715 L F
.30788 .55543 m .30675 .55518 L .30901 .55707 L F
.30861 .5554 m .30675 .55518 L .30866 .5556 L F
.731 .397 .414 r
.31035 .55423 m .30866 .5556 L .31035 .55421 L F
.30866 .5556 m .30865 .5556 L .31035 .55421 L F
.018 .041 .54 r
.31028 .55596 m .30829 .55602 L .31178 .55535 L F
.30829 .55602 m .30873 .55592 L .31178 .55535 L F
.767 .67 .755 r
.30938 .55576 m .30866 .5556 L .30875 .55591 L F
.516 .105 .2 r
.31178 .55535 m .30873 .55592 L .30907 .55526 L F
.30873 .55592 m .30866 .5556 L .30907 .55526 L F
.31096 .55471 m .30907 .55526 L .31035 .55423 L F
.31178 .55535 m .30907 .55526 L .31096 .55471 L F
.31178 .55535 m .31035 .55423 L .31048 .55428 L F
.4 .308 .636 r
.31027 .5541 m .31033 .55419 L .31033 .55413 L F
.30851 .55325 m .31033 .55419 L .31027 .5541 L F
.30851 .55325 m .31033 .55413 L .31014 .55305 L F
.998 .822 .542 r
.30732 .55253 m .30675 .55518 L .30851 .55325 L F
.731 .397 .414 r
.31034 .55418 m .30675 .55518 L .30732 .55253 L F
.31035 .55421 m .30675 .55518 L .31034 .55418 L F
.78 .625 .688 r
.30927 .5493 m .31034 .55402 L .30732 .55253 L F
.31034 .55402 m .31034 .55418 L .30732 .55253 L F
.244 0 .078 r
.1896 .55337 m .19044 .55504 L .19144 .55206 L F
.1896 .55337 m .18823 .5557 L .19044 .55504 L F
.368 .115 .392 r
.34393 .64284 m .34671 .63968 L .34323 .64039 L F
.34671 .63968 m .34393 .64284 L .34323 .64039 L F
.628 .745 .931 r
.27073 .64477 m .27139 .64193 L .26957 .64191 L F
.27073 .64477 m .2732 .64385 L .27139 .64193 L F
.622 .508 .703 r
.31887 .55958 m .32179 .55571 L .31873 .55649 L F
.31887 .55958 m .32224 .55926 L .32179 .55571 L F
.541 .325 .536 r
.31887 .55958 m .32226 .56137 L .32224 .55926 L F
.31887 .55958 m .31929 .56204 L .32226 .56137 L F
.292 0 0 r
.3089 .56906 m .30712 .57068 L .30468 .57097 L F
.711 .274 .21 r
.3089 .56906 m .3106 .57126 L .30712 .57068 L F
.184 .714 .839 r
.3235 .62438 m .32233 .62425 L .32102 .62458 L F
.558 .275 .442 r
.32102 .62458 m .32321 .6266 L .3235 .62438 L F
.093 .24 .725 r
.32233 .62425 m .32321 .6266 L .32102 .62458 L F
.416 0 .122 r
.3076 .64906 m .30328 .65148 L .3038 .64947 L F
.463 .204 .435 r
.31189 .61216 m .31377 .61404 L .31144 .61456 L F
.31189 .61216 m .31424 .61166 L .31377 .61404 L F
.377 0 0 r
.23996 .62445 m .24187 .62519 L .24391 .62501 L F
.267 0 .228 r
.19832 .56816 m .19632 .5689 L .1991 .56643 L F
.263 0 .226 r
.20045 .56723 m .1991 .56643 L .20125 .56565 L F
.20045 .56723 m .19832 .56816 L .1991 .56643 L F
.891 .844 .792 r
.28685 .65105 m .29118 .64935 L .28934 .6483 L F
.697 .871 .964 r
.28934 .6483 m .29118 .64935 L .29364 .64796 L F
.513 .118 .229 r
.24533 .55616 m .24375 .5584 L .24184 .55702 L F
.558 .183 .286 r
.24778 .55607 m .24375 .5584 L .24533 .55616 L F
.466 .368 .66 r
.33157 .59999 m .33334 .59615 L .33097 .59681 L F
.02 .575 .82 r
.24679 .63926 m .25048 .63995 L .24838 .63938 L F
.386 .801 .977 r
.25048 .63995 m .25045 .6389 L .24838 .63938 L F
.25048 .63995 m .25273 .63963 L .25045 .6389 L F
0 0 0 r
.28001 .58441 m .27743 .58765 L .27906 .58613 L F
.331 .288 .659 r
.27743 .58765 m .27967 .58957 L .27906 .58613 L F
.15 .269 .732 r
.27874 .59024 m .27967 .58957 L .27743 .58765 L F
.205 0 0 r
.22324 .5577 m .22089 .55832 L .2186 .55827 L F
.893 .974 .821 r
.22332 .55527 m .22324 .5577 L .22495 .55624 L F
.22332 .55527 m .22089 .55832 L .22324 .5577 L F
.454 .784 .998 r
.35214 .59063 m .3552 .59025 L .35297 .5892 L F
.031 .234 .737 r
.35297 .5892 m .35437 .59267 L .35214 .59063 L F
.01 0 0 r
.21035 .54217 m .20795 .54288 L .21012 .54217 L F
.193 0 0 r
.21012 .54217 m .20795 .54288 L .2062 .54529 L F
.21012 .54217 m .2062 .54529 L .20846 .54447 L F
.726 .881 .479 r
.20982 .54216 m .21012 .54217 L .20846 .54447 L F
.21071 .54065 m .21012 .54217 L .20982 .54216 L F
.01 0 0 r
.21315 .54133 m .21035 .54217 L .21012 .54217 L F
.411 .858 .788 r
.21476 .5405 m .21315 .54133 L .21012 .54217 L F
.614 .696 .902 r
.33999 .5383 m .33659 .53938 L .33616 .53699 L F
0 .389 .846 r
.78407 .39965 m .78313 .40012 L .78207 .39878 L F
.78407 .39965 m .78514 .40117 L .78313 .40012 L F
.078 0 .166 r
.35334 .54346 m .35154 .54446 L .35432 .54085 L F
.289 .356 .759 r
.35477 .53697 m .35432 .54085 L .352 .53975 L F
.35477 .53697 m .35584 .54079 L .35432 .54085 L F
.496 .26 .486 r
.35584 .54079 m .35334 .54346 L .35432 .54085 L F
.467 .243 .489 r
.19574 .57127 m .19376 .5719 L .19632 .5689 L F
0 0 0 r
.19832 .56816 m .19574 .57127 L .19632 .5689 L F
.416 0 .122 r
.3076 .64906 m .30575 .65116 L .30328 .65148 L F
.645 .255 .291 r
.30966 .6511 m .3076 .64906 L .3099 .6494 L F
.30966 .6511 m .30575 .65116 L .3076 .64906 L F
.273 .464 .865 r
.17584 .6057 m .17488 .60199 L .17367 .60244 L F
.17584 .6057 m .17731 .60577 L .17488 .60199 L F
.468 .046 .154 r
.5322 .53252 m .53103 .53432 L .52837 .53448 L F
0 .216 .653 r
.53549 .53468 m .53453 .53393 L .5322 .53252 L F
.553 .135 .202 r
.53453 .53393 m .53103 .53432 L .5322 .53252 L F
.517 .782 .993 r
.22358 .74187 m .22826 .74278 L .22601 .74131 L F
.694 .852 .958 r
.22601 .74131 m .22826 .74278 L .23024 .74154 L F
.035 0 .145 r
.27128 .67731 m .27397 .67388 L .27349 .67605 L F
.609 .866 .991 r
.26901 .67617 m .27128 .67731 L .27349 .67605 L F
.699 .57 .706 r
.37274 .54162 m .37042 .54399 L .37056 .54047 L F
.37274 .54162 m .3745 .54416 L .37042 .54399 L F
.578 .514 .747 r
.37371 .54602 m .37042 .54399 L .3745 .54416 L F
.865 .496 .346 r
.34282 .62415 m .34176 .62647 L .34075 .62559 L F
.417 .263 .564 r
.34493 .6211 m .34489 .62426 L .34282 .62415 L F
.367 0 .126 r
.34489 .62426 m .34176 .62647 L .34282 .62415 L F
.606 .602 .822 r
.37922 .53818 m .37522 .53554 L .37854 .53689 L F
.801 .308 0 r
.37854 .53689 m .38163 .53988 L .37922 .53818 L F
.573 .812 .989 r
.38163 .53988 m .37942 .54083 L .37922 .53818 L F
.222 0 .125 r
.21048 .56021 m .20959 .56199 L .20754 .56263 L F
.361 0 .196 r
.21194 .56141 m .21048 .56021 L .21276 .55992 L F
.21194 .56141 m .20959 .56199 L .21048 .56021 L F
.924 .918 .791 r
.30917 .55941 m .30894 .5615 L .31035 .56021 L F
.642 .894 .985 r
.30917 .55941 m .31035 .56021 L .3123 .55912 L F
.704 .489 .593 r
.32814 .60287 m .33164 .60257 L .33157 .59999 L F
.466 .368 .66 r
.33157 .59999 m .33367 .59954 L .33334 .59615 L F
.552 .421 .656 r
.33164 .60257 m .33367 .59954 L .33157 .59999 L F
.705 .668 .812 r
.19579 .59572 m .19327 .59716 L .19077 .59429 L F
0 0 0 r
.19329 .598 m .19273 .60085 L .19327 .59716 L F
.049 0 0 r
.32102 .57894 m .31945 .58068 L .31752 .58124 L F
0 0 0 r
.3226 .57759 m .31945 .58068 L .32102 .57894 L F
.781 .588 .64 r
.32888 .64613 m .32876 .64932 L .32618 .64877 L F
.32888 .64613 m .32876 .64932 L .32618 .64877 L F
.9 .693 .613 r
.32888 .64613 m .32876 .64932 L .32894 .64637 L F
.32888 .64613 m .32876 .64932 L .32894 .64637 L F
.399 .758 .994 r
.32482 .64828 m .32876 .64932 L .32618 .64877 L F
.32482 .64828 m .32876 .64932 L .32618 .64877 L F
.764 .653 .096 r
.32876 .64932 m .32859 .65169 L .32894 .64637 L F
.32894 .64637 m .32859 .65169 L .32876 .64932 L F
0 0 .129 r
.3004 .57507 m .29937 .57758 L .29836 .57778 L F
.525 .731 .968 r
.27079 .5564 m .27208 .55447 L .26955 .55492 L F
.27079 .5564 m .27307 .556 L .27208 .55447 L F
.286 0 .139 r
.33291 .59347 m .33535 .59277 L .33615 .59103 L F
.685 .441 .548 r
.33535 .59277 m .33864 .59019 L .33615 .59103 L F
.573 .812 .989 r
.38163 .53988 m .38312 .54116 L .37942 .54083 L F
0 .118 .643 r
.38281 .54031 m .38312 .54116 L .38163 .53988 L F
.38281 .54031 m .38537 .54317 L .38312 .54116 L F
.935 .953 .767 r
.53343 .5381 m .53453 .53393 L .53549 .53468 L F
0 .441 .854 r
.37629 .53505 m .37522 .53554 L .37377 .53452 L F
.37629 .53505 m .37854 .53689 L .37522 .53554 L F
.258 0 .093 r
.19376 .5719 m .19238 .57418 L .19034 .57469 L F
.125 0 .02 r
.1944 .57333 m .19376 .5719 L .19574 .57127 L F
.1944 .57333 m .19238 .57418 L .19376 .5719 L F
.452 .844 .98 r
.26371 .53216 m .26774 .53207 L .26544 .5324 L F
.517 .149 .28 r
.24017 .55584 m .24411 .55336 L .24184 .55702 L F
0 .214 .736 r
.24184 .55702 m .24375 .5584 L .24238 .55612 L F
.754 .472 .506 r
.24375 .5584 m .23958 .55852 L .24017 .55584 L F
.24375 .5584 m .24054 .5561 L .24111 .55729 L F
.24054 .5561 m .24017 .55584 L .24111 .55729 L F
.65 .219 .211 r
.24375 .5584 m .24175 .5603 L .23958 .55852 L F
.667 .184 .095 r
.23958 .55852 m .24175 .5603 L .23779 .55965 L F
.374 .096 .357 r
.23991 .55981 m .2415 .55809 L .24111 .55729 L F
.2415 .55809 m .24288 .55659 L .24111 .55729 L F
0 0 0 r
.24238 .55612 m .24111 .55729 L .24332 .55572 L F
.24238 .55612 m .24332 .55572 L .24445 .55491 L F
0 .214 .736 r
.24125 .5566 m .24238 .55612 L .24017 .55584 L F
.24184 .55702 m .24238 .55612 L .24125 .5566 L F
.931 .833 .726 r
.78422 .40831 m .78564 .40502 L .78363 .40475 L F
.479 .438 .734 r
.36522 .55282 m .36326 .55587 L .36293 .55335 L F
.36522 .55282 m .36558 .55554 L .36326 .55587 L F
.5 .419 .697 r
.367 .55783 m .36326 .55587 L .36558 .55554 L F
.367 .55783 m .36498 .5604 L .36326 .55587 L F
.203 .079 .478 r
.29501 .62158 m .29616 .62132 L .29637 .61812 L F
.227 .163 .572 r
.29501 .62158 m .29657 .62393 L .29616 .62132 L F
.514 .252 .455 r
.29422 .62399 m .29657 .62393 L .29501 .62158 L F
.078 0 0 r
.22345 .53761 m .22573 .53704 L .22756 .53572 L F
0 0 0 r
.22756 .53572 m .2278 .53586 L .22956 .53522 L F
.22756 .53572 m .22573 .53704 L .2278 .53586 L F
.487 .247 .477 r
.29995 .6005 m .30223 .60076 L .3025 .59931 L F
.29995 .6005 m .29943 .60188 L .30223 .60076 L F
.244 0 0 r
.27371 .54857 m .27174 .54991 L .27169 .54753 L F
.27371 .54857 m .27404 .54937 L .27174 .54991 L F
.261 .222 .624 r
.27874 .59024 m .27872 .59378 L .28003 .59187 L F
.184 .122 .548 r
.27872 .59378 m .28026 .59553 L .28003 .59187 L F
.251 0 0 r
.26666 .55386 m .26544 .55379 L .26303 .55312 L F
.623 .327 .448 r
.35154 .54446 m .35121 .54729 L .34787 .54648 L F
.233 .024 .378 r
.35334 .54346 m .35121 .54729 L .35154 .54446 L F
.144 0 .275 r
.32431 .57656 m .32329 .5753 L .32447 .57409 L F
.32431 .57656 m .3226 .57759 L .32329 .5753 L F
.458 .197 .429 r
.28957 .57984 m .29087 .58071 L .29177 .57872 L F
.422 .261 .557 r
.50711 .53496 m .50925 .53431 L .50922 .53169 L F
.395 .195 .487 r
.50697 .53763 m .50925 .53431 L .50711 .53496 L F
.50697 .53763 m .50925 .53431 L .50711 .53496 L F
.918 .642 .503 r
.27906 .58613 m .28049 .58731 L .28001 .58441 L F
.141 0 0 r
.3817 .56442 m .37704 .56692 L .37796 .56404 L F
.506 .332 .579 r
.38074 .56196 m .3817 .56442 L .37796 .56404 L F
.38074 .56196 m .37796 .56404 L .37836 .56375 L F
.807 .884 .901 r
.22906 .73843 m .23327 .73794 L .23145 .73888 L F
.255 .747 .914 r
.23145 .73888 m .22674 .73882 L .22906 .73843 L F
.854 .757 .754 r
.23024 .74154 m .23327 .73794 L .22906 .73843 L F
0 0 .208 r
.27308 .67103 m .26957 .67314 L .27198 .67252 L F
.536 .263 .447 r
.37672 .54407 m .37371 .54602 L .3745 .54416 L F
.19 0 .251 r
.36684 .57442 m .36432 .57745 L .365 .5754 L F
.532 .095 .156 r
.34025 .55363 m .34011 .55476 L .33773 .5536 L F
.988 .741 .466 r
.5363 .56825 m .53493 .56445 L .53381 .56744 L F
.8 .754 .811 r
.32977 .64158 m .3272 .64288 L .33135 .643 L F
.524 .615 .884 r
.33135 .643 m .33219 .6397 L .32977 .64158 L F
.33135 .643 m .33415 .64315 L .33219 .6397 L F
.632 .457 .627 r
.3034 .63364 m .30627 .63358 L .30599 .63055 L F
0 0 0 r
.3034 .63364 m .30599 .63055 L .30463 .6323 L F
.611 .532 .741 r
.30599 .63055 m .30871 .63035 L .30761 .62698 L F
0 0 .243 r
.30758 .62961 m .30599 .63055 L .30761 .62698 L F
.525 .336 .566 r
.30627 .63358 m .30871 .63035 L .30599 .63055 L F
0 0 0 r
.30463 .6323 m .30599 .63055 L .30758 .62961 L F
.248 .221 .631 r
.36473 .5801 m .36508 .58364 L .3638 .58411 L F
.215 .133 .542 r
.36508 .58364 m .36534 .58643 L .3638 .58411 L F
0 .045 .574 r
.3638 .58411 m .36534 .58643 L .36458 .58594 L F
.626 .51 .702 r
.32766 .58436 m .3294 .58607 L .33056 .58199 L F
.081 0 0 r
.32831 .58668 m .3294 .58607 L .32766 .58436 L F
.156 0 0 r
.24998 .62761 m .25268 .62741 L .25379 .62682 L F
0 0 0 r
.25379 .62682 m .25464 .6263 L .25685 .62488 L F
.36 .799 .636 r
.25379 .62682 m .25268 .62741 L .25464 .6263 L F
.182 0 0 r
.25273 .63963 m .25675 .63991 L .25473 .64006 L F
.458 0 0 r
.25675 .63991 m .25702 .64066 L .25473 .64006 L F
.25675 .63991 m .2589 .6411 L .25702 .64066 L F
.565 .394 .609 r
.28699 .6019 m .28375 .60273 L .28611 .59947 L F
.514 .264 .473 r
.28323 .60523 m .28375 .60273 L .28699 .6019 L F
.134 0 0 r
.35779 .54629 m .36037 .54666 L .36112 .54668 L F
.694 .972 .764 r
.36112 .54668 m .3622 .54476 L .36405 .54405 L F
.694 .973 .771 r
.36112 .54668 m .36037 .54666 L .3622 .54476 L F
.461 .145 .342 r
.31738 .60153 m .31548 .59963 L .31788 .59923 L F
.31738 .60153 m .31451 .60224 L .31548 .59963 L F
.029 0 0 r
.27744 .66897 m .27892 .66738 L .2764 .66871 L F
.39 .443 .795 r
.28149 .66988 m .27892 .66738 L .28081 .66698 L F
.104 0 0 r
.28081 .66698 m .27892 .66738 L .27744 .66897 L F
.472 .815 .998 r
.19383 .70345 m .19697 .70468 L .19293 .70429 L F
.147 .674 .871 r
.19539 .70428 m .19697 .70468 L .19293 .70429 L F
.659 .104 0 r
.19539 .70428 m .19697 .70468 L .19383 .70345 L F
.346 .226 .571 r
.28845 .62437 m .29054 .626 L .29089 .62421 L F
.28845 .62437 m .28829 .628 L .29054 .626 L F
.444 .599 .91 r
.2571 .70973 m .25537 .71137 L .25401 .70855 L F
0 .125 .645 r
.25713 .71175 m .25537 .71137 L .2571 .70973 L F
0 0 0 r
.25811 .71119 m .25713 .71175 L .25931 .71003 L F
0 .125 .645 r
.25713 .71175 m .2564 .71373 L .25585 .71247 L F
.536 .891 .978 r
.25214 .7142 m .2564 .71373 L .25444 .71552 L F
.794 .959 .637 r
.25444 .71552 m .2564 .71373 L .25713 .71175 L F
0 .125 .645 r
.25713 .71175 m .25585 .71247 L .25537 .71137 L F
.795 .701 .761 r
.2527 .71219 m .25444 .71552 L .25713 .71175 L F
0 0 0 r
.25499 .71422 m .25713 .71175 L .25811 .71119 L F
0 0 .409 r
.36886 .53545 m .36938 .53547 L .37126 .53423 L F
.36886 .53545 m .36986 .53792 L .36938 .53547 L F
.089 .627 .855 r
.32318 .53601 m .32582 .53621 L .32765 .53668 L F
.473 .828 .996 r
.32582 .53621 m .32978 .53636 L .32765 .53668 L F
.49 .312 .567 r
.30975 .57525 m .31224 .57703 L .31175 .57318 L F
.30975 .57525 m .30995 .57781 L .31224 .57703 L F
0 0 0 r
.23185 .53569 m .23019 .53579 L .23112 .53574 L F
.214 0 0 r
.23295 .53562 m .23185 .53569 L .23393 .53574 L F
.03 0 0 r
.23185 .53569 m .23621 .5353 L .23393 .53574 L F
0 0 0 r
.23185 .53569 m .23112 .53574 L .2341 .53559 L F
.214 0 0 r
.22956 .53522 m .23185 .53569 L .23295 .53562 L F
.909 .81 .738 r
.53319 .54074 m .53251 .53728 L .53343 .5381 L F
.935 .953 .767 r
.53343 .5381 m .53251 .53728 L .53453 .53393 L F
.365 .237 .57 r
.1606 .58119 m .16238 .58044 L .16228 .5778 L F
.359 .244 .584 r
.1606 .58119 m .16249 .58325 L .16238 .58044 L F
.1606 .58119 m .16029 .58499 L .16249 .58325 L F
.008 0 0 r
.25685 .62488 m .25691 .62564 L .25858 .62347 L F
.25685 .62488 m .25464 .6263 L .25691 .62564 L F
.951 .688 .5 r
.51114 .56864 m .50944 .5691 L .50696 .56879 L F
.51114 .56864 m .51105 .57145 L .50944 .5691 L F
.503 .593 .877 r
.51125 .56509 m .51118 .56737 L .50961 .56531 L F
.51118 .56737 m .51114 .56864 L .51055 .56736 L F
.51118 .56737 m .51055 .56736 L .50961 .56531 L F
.51172 .56609 m .51114 .56864 L .51125 .56509 L F
.51197 .565 m .51249 .56731 L .51114 .56864 L F
.111 0 .422 r
.51249 .56731 m .51105 .57145 L .51114 .56864 L F
.8 .712 .767 r
.50944 .5691 m .51105 .57145 L .51241 .56754 L F
.50944 .5691 m .51241 .56754 L .51234 .5674 L F
.50944 .5691 m .51234 .5674 L .51258 .56853 L F
.51234 .5674 m .51241 .56754 L .51249 .56731 L F
.51234 .5674 m .51249 .56731 L .51249 .5674 L F
.51234 .5674 m .51249 .5674 L .51258 .56853 L F
.503 .593 .877 r
.51197 .565 m .51172 .56609 L .51125 .56509 L F
.746 .697 .805 r
.30938 .54684 m .31366 .54737 L .31139 .5446 L F
.704 .694 .838 r
.31357 .54617 m .3132 .54623 L .31139 .5446 L F
.483 .64 .925 r
.3132 .54623 m .31366 .54737 L .31394 .5469 L F
.31139 .5446 m .31274 .54624 L .3132 .54623 L F
.31274 .54624 m .31366 .54737 L .3132 .54623 L F
.005 0 .426 r
.31085 .5476 m .30938 .54684 L .3132 .54623 L F
.31347 .54623 m .3132 .54623 L .31357 .54617 L F
.439 .647 .946 r
.31139 .5446 m .31473 .54556 L .31357 .54617 L F
.483 .64 .925 r
.31139 .5446 m .31329 .54632 L .31473 .54556 L F
.209 0 0 r
.31473 .54556 m .31347 .54623 L .31357 .54617 L F
.483 .64 .925 r
.31329 .54632 m .31394 .5469 L .31473 .54556 L F
.005 0 .426 r
.31085 .5476 m .3132 .54623 L .31347 .54623 L F
.209 0 0 r
.31473 .54556 m .31085 .5476 L .31347 .54623 L F
.704 .694 .838 r
.3132 .54623 m .30938 .54684 L .31139 .5446 L F
.275 0 .291 r
.31366 .54737 m .31506 .54872 L .31473 .54556 L F
.31366 .54737 m .31293 .54942 L .31506 .54872 L F
.375 .191 .499 r
.31953 .58322 m .31752 .58124 L .31945 .58068 L F
.31953 .58322 m .3174 .584 L .31752 .58124 L F
.458 .28 .551 r
.36525 .55009 m .36293 .55335 L .36303 .5512 L F
.466 .464 .772 r
.50439 .55859 m .50338 .56276 L .50179 .56152 L F
.50439 .55859 m .50556 .56254 L .50338 .56276 L F
.431 .729 .989 r
.21451 .62951 m .21613 .63084 L .21657 .62926 L F
.45 .749 .993 r
.21613 .63084 m .21803 .63048 L .21657 .62926 L F
.391 .669 .97 r
.21613 .63084 m .21937 .63115 L .21803 .63048 L F
.343 .817 .898 r
.24127 .73848 m .24291 .7386 L .24395 .73791 L F
.537 .813 .997 r
.54008 .56902 m .54261 .56843 L .53876 .56792 L F
.029 0 0 r
.27744 .66897 m .2764 .66871 L .27541 .67092 L F
.173 0 0 r
.28722 .54785 m .2847 .54805 L .28707 .54738 L F
.28722 .54785 m .28396 .54867 L .2847 .54805 L F
.725 .536 .636 r
.30761 .62698 m .31108 .6273 L .31103 .62429 L F
.591 .435 .638 r
.31103 .62429 m .31384 .62398 L .31342 .62115 L F
.492 .297 .544 r
.31108 .6273 m .31384 .62398 L .31103 .62429 L F
.888 .886 .459 r
.3196 .55235 m .31873 .55649 L .32179 .55571 L F
.715 .274 .201 r
.31953 .55633 m .31771 .55723 L .31736 .55679 L F
.844 .997 .773 r
.3185 .55504 m .317 .55701 L .31873 .55649 L F
.31844 .55469 m .31809 .55527 L .3185 .55504 L F
.31809 .55527 m .317 .55701 L .3185 .55504 L F
.888 .886 .459 r
.31929 .55382 m .3185 .55504 L .31873 .55649 L F
.715 .274 .201 r
.31953 .55633 m .317 .55701 L .31844 .55469 L F
.31953 .55633 m .31548 .55443 L .317 .55701 L F
.31809 .55566 m .31736 .55679 L .31674 .55602 L F
.31771 .55548 m .31674 .55602 L .31548 .55443 L F
.31809 .55566 m .31674 .55602 L .31771 .55548 L F
.31953 .55633 m .31736 .55679 L .31809 .55566 L F
.31828 .55467 m .31844 .55469 L .31758 .55373 L F
.888 .886 .459 r
.31862 .55473 m .31844 .55469 L .3185 .55504 L F
.715 .274 .201 r
.31953 .55633 m .31844 .55469 L .31828 .55467 L F
.888 .886 .459 r
.3196 .55235 m .31844 .55469 L .31862 .55473 L F
.3196 .55235 m .3185 .55504 L .31929 .55382 L F
.261 .222 .624 r
.27874 .59024 m .28003 .59187 L .27967 .58957 L F
.381 .763 .99 r
.26989 .53141 m .27409 .53218 L .2717 .53249 L F
.184 .179 .618 r
.28744 .60023 m .28611 .59947 L .2879 .59978 L F
.28744 .60023 m .28699 .6019 L .28611 .59947 L F
.826 .937 .569 r
.53758 .55656 m .53778 .55515 L .53814 .55528 L F
0 0 .321 r
.53758 .55656 m .5386 .55753 L .53778 .55515 L F
.81 .44 0 r
.53778 .55515 m .5386 .55753 L .53745 .55502 L F
.53778 .55515 m .53745 .55502 L .53709 .55423 L F
.826 .937 .569 r
.53814 .55528 m .53778 .55515 L .53904 .55324 L F
0 0 .321 r
.53758 .55656 m .53794 .55945 L .5386 .55753 L F
0 0 0 r
.20369 .54443 m .19977 .54698 L .20172 .54645 L F
.153 0 0 r
.20591 .54378 m .20369 .54443 L .20172 .54645 L F
.694 .742 .888 r
.27923 .66076 m .2831 .66141 L .2809 .66245 L F
.677 .785 .315 r
.28065 .65833 m .2821 .65505 L .28123 .65683 L F
.417 .479 .817 r
.27846 .65434 m .28065 .65833 L .28123 .65683 L F
.81 .917 .527 r
.28123 .65683 m .28065 .65833 L .27923 .66076 L F
.752 .662 .762 r
.28123 .65683 m .27923 .66076 L .28065 .65833 L F
.28123 .65683 m .2831 .66141 L .27923 .66076 L F
.354 .18 .501 r
.28036 .66045 m .28122 .66297 L .28165 .66011 L F
.27923 .66076 m .27991 .66151 L .28036 .66045 L F
.27991 .66151 m .28122 .66297 L .28036 .66045 L F
.96 .927 .721 r
.2809 .66245 m .27995 .66514 L .27907 .66352 L F
.2791 .66344 m .27907 .66352 L .27904 .66347 L F
.2809 .66245 m .27907 .66352 L .2791 .66344 L F
0 .398 .704 r
.24028 .55064 m .2384 .54999 L .23647 .54939 L F
0 .275 .72 r
.24028 .55064 m .24104 .55069 L .2384 .54999 L F
.575 .177 .251 r
.24188 .55131 m .24281 .55208 L .24028 .55064 L F
0 .275 .72 r
.24028 .55064 m .24281 .55208 L .24104 .55069 L F
.196 0 0 r
.18401 .55711 m .18506 .55775 L .18611 .55637 L F
.18401 .55711 m .18294 .55843 L .18506 .55775 L F
.757 .463 .487 r
.2821 .65505 m .28617 .65596 L .2847 .65766 L F
.038 0 0 r
.2847 .65766 m .28617 .65596 L .28819 .65468 L F
.184 .136 .566 r
.30072 .59031 m .302 .5858 L .30001 .58828 L F
.30072 .59031 m .30194 .58994 L .302 .5858 L F
.345 .267 .623 r
.30072 .59031 m .30283 .59238 L .30194 .58994 L F
.30072 .59031 m .30088 .59385 L .30283 .59238 L F
.55 .092 .118 r
.34539 .55351 m .34011 .55476 L .34025 .55363 L F
.34539 .55351 m .34226 .55528 L .34011 .55476 L F
.466 .856 .978 r
.34547 .55551 m .34226 .55528 L .34539 .55351 L F
.499 .778 .995 r
.27649 .63216 m .27473 .63259 L .27315 .63133 L F
.497 .788 .997 r
.26674 .64229 m .26856 .64075 L .26471 .64161 L F
.26674 .64229 m .26957 .64191 L .26856 .64075 L F
.527 .857 .577 r
.26861 .68008 m .2651 .68323 L .2671 .68169 L F
.235 .393 .818 r
.27147 .68324 m .26861 .68008 L .27046 .6802 L F
.3 0 0 r
.27046 .6802 m .26861 .68008 L .2671 .68169 L F
.564 .203 .314 r
.3047 .63605 m .3034 .63364 L .30286 .63635 L F
.3047 .63605 m .30627 .63358 L .3034 .63364 L F
0 0 .125 r
.30286 .63635 m .3034 .63364 L .30463 .6323 L F
0 .562 .72 r
.21573 .61784 m .21778 .61792 L .21983 .61803 L F
0 .543 .817 r
.21995 .61772 m .21983 .61803 L .21778 .61792 L F
.21995 .61772 m .22184 .61836 L .21983 .61803 L F
.909 .683 .584 r
.53319 .54074 m .53493 .54414 L .53296 .54332 L F
.91 .629 .497 r
.53493 .54414 m .5331 .54627 L .53296 .54332 L F
.735 .363 .347 r
.53493 .54414 m .5371 .54675 L .5331 .54627 L F
.504 .263 .482 r
.19275 .81182 m .19368 .81007 L .19068 .80981 L F
.126 .295 .765 r
.20497 .60455 m .20422 .60622 L .2027 .60307 L F
.143 .316 .779 r
.20497 .60455 m .20655 .60814 L .20422 .60622 L F
.77 .671 .754 r
.23618 .72596 m .24024 .72643 L .23851 .7228 L F
.517 .149 .28 r
.24017 .55584 m .24238 .55612 L .24411 .55336 L F
.767 .693 .782 r
.24705 .5509 m .24411 .55336 L .24188 .55131 L F
.335 .683 .979 r
.24411 .55336 m .24462 .55209 L .24281 .55208 L F
.003 0 0 r
.24411 .55336 m .24445 .55491 L .24462 .55209 L F
.24411 .55336 m .24238 .55612 L .24445 .55491 L F
0 .102 .594 r
.24188 .55131 m .24411 .55336 L .24281 .55208 L F
.452 .85 .975 r
.23621 .5353 m .23839 .53468 L .24013 .53516 L F
.449 .844 .979 r
.23839 .53468 m .2424 .53465 L .24013 .53516 L F
.235 0 .203 r
.18737 .57761 m .18439 .58057 L .18542 .57844 L F
.471 .236 .476 r
.3497 .61175 m .34699 .61503 L .34716 .61213 L F
.548 .898 .977 r
.27795 .53171 m .27409 .53218 L .27641 .53157 L F
.283 .785 .824 r
.27641 .53157 m .28023 .5309 L .27795 .53171 L F
.099 .495 .902 r
.27684 .64392 m .2781 .64351 L .27546 .64314 L F
.27684 .64392 m .27956 .64503 L .2781 .64351 L F
.416 .731 .991 r
.30105 .53121 m .3006 .53279 L .2989 .53149 L F
.30105 .53121 m .30275 .53254 L .3006 .53279 L F
.637 .503 .682 r
.8169 .40898 m .81948 .41043 L .82008 .40831 L F
.8169 .40898 m .81731 .41152 L .81948 .41043 L F
.195 0 0 r
.20754 .56263 m .20563 .56424 L .20336 .56465 L F
.733 .48 .545 r
.20959 .56199 m .20563 .56424 L .20754 .56263 L F
.241 .757 .823 r
.14638 .64014 m .14932 .63957 L .1503 .63962 L F
.14638 .64014 m .14932 .63957 L .1503 .63962 L F
.906 .984 .76 r
.1503 .63962 m .14932 .63957 L .14992 .63812 L F
.14992 .63812 m .14932 .63957 L .1503 .63962 L F
.668 .863 .973 r
.37836 .56375 m .3741 .56403 L .37688 .56238 L F
.771 .853 .912 r
.38074 .56196 m .37836 .56375 L .37688 .56238 L F
.516 .405 .667 r
.77454 .40384 m .77422 .40533 L .77673 .40509 L F
.514 .533 .813 r
.77422 .40533 m .77801 .40857 L .77673 .40509 L F
0 0 .143 r
.2787 .61432 m .27686 .61786 L .27759 .6154 L F
.244 0 0 r
.52926 .52439 m .53182 .52395 L .53322 .52228 L F
.634 .172 .138 r
.53182 .52395 m .53599 .52436 L .53322 .52228 L F
0 0 0 r
.28405 .64848 m .28061 .65168 L .28402 .65154 L F
.374 .597 .933 r
.2827 .64738 m .28405 .64848 L .28559 .64753 L F
.621 .545 .747 r
.28402 .65154 m .28559 .64753 L .28405 .64848 L F
.207 0 .243 r
.29338 .59173 m .29038 .59472 L .29101 .59328 L F
.623 .69 .892 r
.31721 .53486 m .31285 .53272 L .31597 .53335 L F
.18 .631 .94 r
.31755 .53407 m .31721 .53486 L .31597 .53335 L F
.31755 .53407 m .31934 .53513 L .31721 .53486 L F
.318 0 .131 r
.34887 .54992 m .35041 .54954 L .3493 .54982 L F
.553 .866 .996 r
.26787 .67241 m .26957 .67314 L .26719 .67385 L F
0 .109 .644 r
.26787 .67241 m .26719 .67385 L .26901 .67617 L F
.667 .569 .735 r
.28645 .63071 m .28957 .63036 L .28829 .628 L F
.649 .46 .614 r
.28645 .63071 m .28678 .63329 L .28957 .63036 L F
.61 .168 .174 r
.23682 .73777 m .23549 .73564 L .23541 .73775 L F
.368 .115 .392 r
.34393 .64284 m .34612 .64234 L .34671 .63968 L F
.34671 .63968 m .34612 .64234 L .34393 .64284 L F
.528 .257 .448 r
.34671 .63968 m .34612 .64234 L .34862 .64182 L F
.34671 .63968 m .34612 .64234 L .34862 .64182 L F
.73 .76 .877 r
.3769 .55583 m .37304 .5563 L .37555 .55441 L F
.58 .167 .224 r
.3769 .55583 m .37568 .55843 L .37304 .5563 L F
.172 .508 .912 r
.37555 .55441 m .37784 .55521 L .3769 .55583 L F
0 0 0 r
.37784 .55521 m .37568 .55843 L .3769 .55583 L F
.717 .706 .174 r
.54893 .55801 m .5486 .55984 L .54937 .55621 L F
.786 .778 .274 r
.5482 .56016 m .5486 .55984 L .54893 .55801 L F
.5482 .56016 m .54791 .56231 L .5486 .55984 L F
.139 0 .256 r
.27733 .59982 m .27695 .60175 L .27874 .5993 L F
.424 0 .08 r
.21653 .55864 m .21451 .56059 L .21276 .55992 L F
.221 0 0 r
.2186 .55827 m .21451 .56059 L .21653 .55864 L F
.336 .008 .253 r
.17276 .56592 m .17411 .56735 L .1751 .56517 L F
.17276 .56592 m .17197 .56795 L .17411 .56735 L F
.755 .7 .16 r
.26244 .70081 m .26281 .69857 L .26306 .69598 L F
.069 0 0 r
.28396 .54867 m .27925 .55022 L .28163 .54939 L F
.613 .471 .665 r
.31342 .62115 m .31633 .621 L .31584 .61798 L F
.468 .259 .512 r
.31384 .62398 m .31633 .621 L .31342 .62115 L F
.415 .8 .99 r
.28023 .5309 m .28257 .53055 L .28428 .53133 L F
.404 .795 .988 r
.28257 .53055 m .28665 .53099 L .28428 .53133 L F
.516 .405 .667 r
.77454 .40384 m .77673 .40509 L .77568 .40094 L F
.79 .753 .819 r
.78084 .40774 m .78422 .40831 L .78363 .40475 L F
.687 .499 .627 r
.78202 .41158 m .78422 .40831 L .78084 .40774 L F
.78202 .41158 m .78433 .41059 L .78422 .40831 L F
.325 .619 .956 r
.22795 .63515 m .23015 .63653 L .22959 .63534 L F
.349 .637 .961 r
.22959 .63534 m .23015 .63653 L .23071 .63503 L F
.303 .584 .941 r
.23015 .63653 m .2324 .63697 L .23071 .63503 L F
.527 .917 .915 r
.2654 .62136 m .26055 .62262 L .26351 .62122 L F
0 0 0 r
.26725 .61769 m .2654 .62136 L .26608 .62031 L F
.478 .889 .928 r
.26608 .62031 m .2654 .62136 L .26351 .62122 L F
.713 .659 .106 r
.54998 .55157 m .54945 .55551 L .54937 .55621 L F
.735 .71 .177 r
.54945 .55551 m .54893 .55801 L .54937 .55621 L F
.117 .563 .918 r
.19243 .59401 m .19348 .59388 L .19364 .59489 L F
.517 .562 .841 r
.19348 .59388 m .19345 .59454 L .19364 .59489 L F
.705 .668 .812 r
.19378 .59514 m .19077 .59429 L .19364 .59489 L F
.134 .574 .925 r
.19243 .59401 m .19364 .59489 L .19077 .59429 L F
.517 .562 .841 r
.19345 .59454 m .19329 .598 L .19364 .59489 L F
.705 .668 .812 r
.19579 .59572 m .19378 .59514 L .19364 .59489 L F
.955 .752 .589 r
.19364 .59489 m .19422 .597 L .19579 .59572 L F
.957 .734 .561 r
.19364 .59489 m .19579 .59572 L .19422 .597 L F
.19364 .59489 m .19329 .598 L .19579 .59572 L F
.27 .656 .968 r
.20556 .62381 m .20522 .62238 L .2028 .62228 L F
.20556 .62381 m .20678 .62362 L .20522 .62238 L F
.917 .783 .698 r
.37056 .54047 m .36892 .54033 L .36986 .53792 L F
.915 .665 .544 r
.37056 .54047 m .36887 .54291 L .36892 .54033 L F
0 0 0 r
.3105 .56713 m .31138 .56697 L .31405 .56607 L F
0 0 .218 r
.31251 .56585 m .31232 .5668 L .31138 .56697 L F
.707 .477 .573 r
.31138 .56697 m .31472 .56882 L .3143 .56649 L F
.31138 .56697 m .31176 .56963 L .31472 .56882 L F
0 0 .218 r
.31232 .5668 m .31176 .56963 L .31138 .56697 L F
0 0 0 r
.30896 .56759 m .31138 .56697 L .3105 .56713 L F
.092 0 0 r
.31405 .56607 m .3143 .56649 L .31622 .56623 L F
.31405 .56607 m .31138 .56697 L .3143 .56649 L F
0 0 .038 r
.29546 .58923 m .29338 .59173 L .2935 .59017 L F
.944 .581 .243 r
.25232 .69518 m .25225 .69859 L .25535 .69508 L F
.995 .862 .537 r
.25225 .69859 m .25325 .70184 L .25654 .69769 L F
.606 .525 .737 r
.25325 .70184 m .25605 .70172 L .25654 .69769 L F
.291 .568 .933 r
.25605 .70172 m .25647 .69992 L .25654 .69769 L F
.25647 .69992 m .25648 .69987 L .2565 .69941 L F
.25647 .69992 m .2565 .69941 L .25654 .69769 L F
.571 .286 .445 r
.25657 .69775 m .25535 .69508 L .25225 .69859 L F
.25744 .69758 m .25662 .6966 L .25657 .69775 L F
.25662 .6966 m .25535 .69508 L .25657 .69775 L F
.676 .416 .521 r
.30468 .58373 m .30761 .58364 L .308 .58119 L F
.458 .221 .466 r
.308 .58119 m .30997 .58307 L .31023 .58047 L F
.308 .58119 m .30761 .58364 L .30997 .58307 L F
.89 .474 .2 r
.54755 .53074 m .5507 .53435 L .55078 .53176 L F
.458 .28 .551 r
.36525 .55009 m .36522 .55282 L .36293 .55335 L F
.909 .904 .807 r
.3397 .63875 m .3397 .63874 L .33853 .63661 L F
.33984 .63867 m .34274 .63701 L .3411 .63685 L F
.33984 .63867 m .34051 .64032 L .34274 .63701 L F
.616 .469 .66 r
.33965 .6389 m .33961 .63896 L .33962 .63893 L F
.909 .904 .807 r
.3397 .63874 m .33965 .6389 L .33984 .63867 L F
0 0 .425 r
.33972 .63884 m .33965 .6389 L .33971 .63876 L F
.33965 .6389 m .33962 .63893 L .33968 .6388 L F
.33965 .6389 m .33968 .6388 L .33971 .63876 L F
.896 .753 .253 r
.33962 .63893 m .33956 .63906 L .33917 .63905 L F
.909 .904 .807 r
.33917 .63905 m .33938 .63925 L .33953 .63906 L F
.046 0 0 r
.34051 .64032 m .33602 .64198 L .33648 .63997 L F
.34051 .64032 m .33836 .64147 L .33602 .64198 L F
.979 .854 .645 r
.33917 .63905 m .33836 .64147 L .34051 .64032 L F
.896 .753 .253 r
.33956 .63906 m .33836 .64147 L .33917 .63905 L F
.909 .904 .807 r
.33917 .63905 m .33953 .63906 L .33965 .6389 L F
.856 .495 .367 r
.33962 .63893 m .33917 .63905 L .33853 .63661 L F
.909 .904 .807 r
.33917 .63905 m .33965 .6389 L .3397 .63874 L F
.33938 .63925 m .34051 .64032 L .33984 .63867 L F
.616 .469 .66 r
.33972 .63884 m .33955 .63908 L .33961 .63896 L F
.33972 .63884 m .33961 .63896 L .33965 .6389 L F
.896 .753 .253 r
.33962 .63893 m .33907 .64057 L .33836 .64147 L F
.33962 .63893 m .33896 .64032 L .33907 .64057 L F
.616 .469 .66 r
.34181 .63679 m .33896 .64032 L .33955 .63908 L F
.34181 .63679 m .33955 .63908 L .33972 .63884 L F
.909 .904 .807 r
.3397 .63874 m .33984 .63867 L .33935 .63669 L F
.33984 .63867 m .3411 .63685 L .33935 .63669 L F
.3397 .63874 m .33935 .63669 L .33853 .63661 L F
0 0 .425 r
.34181 .63679 m .33972 .63884 L .34096 .6362 L F
.33972 .63884 m .33971 .63876 L .34096 .6362 L F
.856 .495 .367 r
.33971 .63876 m .33853 .63661 L .34096 .6362 L F
.33962 .63893 m .33853 .63661 L .33971 .63876 L F
.909 .904 .807 r
.33917 .63905 m .3397 .63875 L .33853 .63661 L F
.468 .314 .589 r
.29305 .57599 m .29362 .57761 L .2938 .57494 L F
0 0 .125 r
.29583 .57142 m .2938 .57494 L .29541 .57364 L F
.123 0 .421 r
.2938 .57494 m .29495 .57603 L .29541 .57364 L F
.2938 .57494 m .29362 .57761 L .29495 .57603 L F
.683 .603 .76 r
.3476 .6175 m .34486 .61809 L .34699 .61503 L F
.619 .462 .647 r
.3476 .6175 m .34493 .6211 L .34486 .61809 L F
.324 0 .11 r
.35041 .54954 m .35379 .54839 L .35515 .54822 L F
.35041 .54954 m .3511 .54988 L .35379 .54839 L F
.658 .431 .564 r
.35379 .54839 m .3511 .54988 L .35121 .54729 L F
.65 .963 .793 r
.35246 .54829 m .35221 .54858 L .35379 .54839 L F
.35221 .54858 m .3511 .54988 L .35379 .54839 L F
.324 0 .11 r
.35515 .54822 m .35379 .54839 L .35574 .54806 L F
.231 .749 .761 r
.35574 .54806 m .35627 .54778 L .35779 .54629 L F
.186 0 .28 r
.30139 .55042 m .30072 .55263 L .30313 .54948 L F
.081 0 0 r
.32831 .58668 m .33017 .58629 L .3294 .58607 L F
.547 .421 .66 r
.3294 .58607 m .3334 .58097 L .33056 .58199 L F
.217 .739 .758 r
.33017 .58629 m .33541 .58514 L .3294 .58607 L F
.125 .673 .804 r
.2424 .53465 m .24472 .5345 L .24637 .53459 L F
.337 .786 .955 r
.24472 .5345 m .24876 .53468 L .24637 .53459 L F
.374 0 .179 r
.33282 .5779 m .33525 .57745 L .33762 .57599 L F
.403 .265 .577 r
.33282 .5779 m .33567 .5776 L .33525 .57745 L F
.33282 .5779 m .3334 .58097 L .33567 .5776 L F
0 0 0 r
.19275 .81182 m .19702 .80941 L .19514 .80857 L F
.96 .927 .721 r
.2809 .66245 m .27904 .66347 L .27923 .66076 L F
.408 .74 .992 r
.26473 .6924 m .26516 .69326 L .26562 .69343 L F
.559 .075 0 r
.26473 .6924 m .26562 .69343 L .26476 .69243 L F
0 0 .537 r
.26576 .69448 m .26549 .69492 L .26539 .69459 L F
.26534 .69363 m .26539 .69459 L .26473 .6924 L F
.26576 .69448 m .26539 .69459 L .26534 .69363 L F
.695 .273 .24 r
.26259 .69468 m .26533 .69355 L .26082 .6917 L F
.26533 .69355 m .26516 .69326 L .26082 .6917 L F
.26533 .69355 m .26562 .69343 L .26516 .69326 L F
.922 .906 .79 r
.26529 .69276 m .26562 .69343 L .26533 .69355 L F
0 0 .537 r
.2662 .69377 m .26583 .69437 L .26473 .6924 L F
.26583 .69437 m .26516 .69326 L .26473 .6924 L F
.408 .74 .992 r
.26473 .6924 m .26082 .6917 L .26516 .69326 L F
.559 .075 0 r
.26473 .6924 m .26476 .69243 L .2661 .6911 L F
0 .067 .621 r
.26476 .69243 m .26562 .69343 L .26533 .69285 L F
.922 .906 .79 r
.26529 .69276 m .2653 .69293 L .26259 .69468 L F
.2653 .69293 m .26533 .69355 L .26493 .69372 L F
.2653 .69293 m .26493 .69372 L .26259 .69468 L F
0 0 .537 r
.2653 .69293 m .26473 .6924 L .26473 .6924 L F
.2662 .69377 m .2653 .69293 L .2653 .69293 L F
.2653 .69293 m .26473 .6924 L .2653 .69293 L F
.394 .393 .74 r
.2661 .6911 m .26476 .69243 L .2682 .69175 L F
.482 .002 .039 r
.2661 .6911 m .26879 .69138 L .26837 .69177 L F
.2682 .69175 m .26837 .69177 L .26834 .69179 L F
.2661 .6911 m .26837 .69177 L .2682 .69175 L F
0 0 .537 r
.26612 .69179 m .26473 .6924 L .2661 .6911 L F
.381 .718 .988 r
.26819 .69175 m .26476 .69243 L .26475 .69242 L F
.394 .393 .74 r
.2661 .6911 m .2682 .69175 L .26888 .69162 L F
.381 .718 .988 r
.26888 .69162 m .2682 .69175 L .26819 .69175 L F
.2682 .69175 m .26476 .69243 L .26819 .69175 L F
.482 .002 .039 r
.26707 .69166 m .26834 .69179 L .26793 .69216 L F
.2661 .6911 m .2682 .69175 L .26707 .69166 L F
.394 .393 .74 r
.2661 .6911 m .26888 .69162 L .26879 .69138 L F
.381 .718 .988 r
.26849 .69149 m .26475 .69242 L .26751 .69116 L F
.415 0 0 r
.26793 .69216 m .26879 .69138 L .27326 .69206 L F
.381 .718 .988 r
.26888 .69162 m .26876 .69164 L .26849 .69149 L F
.26876 .69164 m .26475 .69242 L .26849 .69149 L F
.482 .002 .039 r
.26612 .69179 m .26793 .69216 L .2662 .69377 L F
.2661 .6911 m .26707 .69166 L .26612 .69179 L F
.26707 .69166 m .26793 .69216 L .26612 .69179 L F
.381 .718 .988 r
.2665 .69162 m .26612 .69179 L .26441 .69146 L F
0 0 .537 r
.26475 .69242 m .26473 .6924 L .26612 .69179 L F
.381 .718 .988 r
.26612 .69179 m .26475 .69242 L .2646 .692 L F
.26612 .69179 m .2646 .692 L .26441 .69146 L F
.26751 .69116 m .2665 .69162 L .264 .69004 L F
.26424 .69008 m .264 .69004 L .26386 .68996 L F
.26751 .69116 m .264 .69004 L .26424 .69008 L F
.278 0 0 r
.27326 .69206 m .26879 .69138 L .26888 .69162 L F
.378 .682 .978 r
.2662 .68968 m .27326 .69206 L .26888 .69162 L F
.558 .691 .929 r
.26793 .69216 m .27326 .69206 L .27036 .69109 L F
.381 .718 .988 r
.26888 .69162 m .26386 .68996 L .2662 .68968 L F
.558 .691 .929 r
.26677 .6905 m .27036 .69109 L .2662 .68968 L F
.482 .002 .039 r
.2682 .69175 m .26834 .69179 L .26707 .69166 L F
.558 .691 .929 r
.26793 .69216 m .27036 .69109 L .26677 .6905 L F
.381 .718 .988 r
.2665 .69162 m .26441 .69146 L .26386 .68996 L F
0 0 .537 r
.26619 .6935 m .26475 .69242 L .26612 .69179 L F
0 .067 .621 r
.26476 .69243 m .26533 .69285 L .26475 .69242 L F
0 0 .537 r
.2662 .69377 m .26473 .6924 L .26619 .6935 L F
0 .067 .621 r
.26475 .69242 m .26533 .69285 L .26386 .68996 L F
.922 .906 .79 r
.26386 .68996 m .26529 .69276 L .26259 .69468 L F
.814 .879 .893 r
.26377 .69263 m .26793 .69216 L .26677 .6905 L F
.26593 .69001 m .26677 .6905 L .2662 .68968 L F
.26377 .69263 m .26677 .6905 L .26593 .69001 L F
0 0 .537 r
.26583 .69437 m .26576 .69448 L .26516 .69326 L F
0 .236 .726 r
.22635 .61923 m .22562 .6194 L .22412 .61851 L F
.22635 .61923 m .22776 .62079 L .22562 .6194 L F
.882 .727 .685 r
.53942 .54757 m .53848 .55007 L .5371 .54675 L F
.976 .717 .472 r
.27968 .67875 m .28121 .67982 L .27976 .68195 L F
.582 .83 .992 r
.281 .67761 m .28121 .67982 L .27968 .67875 L F
.92 .911 .518 r
.27976 .68195 m .28121 .67982 L .281 .67761 L F
.584 .019 0 r
.33827 .58719 m .33839 .58808 L .33652 .58603 L F
.483 .384 .666 r
.33827 .58719 m .33864 .59019 L .34097 .5893 L F
.584 .019 0 r
.33827 .58719 m .34097 .5893 L .33839 .58808 L F
.383 .027 .232 r
.25148 .71002 m .25015 .71024 L .24854 .71026 L F
.5 .401 .674 r
.25004 .71382 m .25148 .71002 L .24854 .71026 L F
.492 .303 .551 r
.36693 .57182 m .36921 .57387 L .36684 .57442 L F
.554 .296 .479 r
.36943 .57152 m .36921 .57387 L .36693 .57182 L F
.618 .91 .982 r
.36649 .54292 m .36405 .54405 L .36483 .54239 L F
.734 .982 .763 r
.36405 .54405 m .3622 .54476 L .36483 .54239 L F
.554 .591 .845 r
.29943 .60188 m .30258 .60348 L .30223 .60076 L F
.404 .313 .639 r
.29637 .61812 m .29828 .614 L .29615 .61466 L F
.29637 .61812 m .29757 .61796 L .29828 .614 L F
.405 .243 .546 r
.29637 .61812 m .29785 .62086 L .29757 .61796 L F
.29637 .61812 m .29616 .62132 L .29785 .62086 L F
.435 .262 .546 r
.29615 .61466 m .29828 .614 L .29816 .61168 L F
.448 .04 .172 r
.29338 .5447 m .29245 .54644 L .28942 .54682 L F
.341 0 .118 r
.29509 .54571 m .29245 .54644 L .29338 .5447 L F
.358 .374 .74 r
.34469 .53643 m .3436 .5389 L .34223 .53719 L F
.34469 .53643 m .34581 .54014 L .3436 .5389 L F
.519 .28 .491 r
.52416 .52632 m .52616 .52752 L .52765 .52426 L F
.695 .273 .24 r
.26259 .69468 m .26082 .6917 L .26007 .69212 L F
.558 .183 .286 r
.24778 .55607 m .2463 .55864 L .24375 .5584 L F
.364 0 .153 r
.25016 .55577 m .2463 .55864 L .24778 .55607 L F
0 0 .417 r
.31098 .61903 m .30989 .61795 L .31096 .6171 L F
.31098 .61903 m .31021 .62067 L .30989 .61795 L F
.548 .365 .585 r
.50925 .53431 m .51158 .53174 L .50922 .53169 L F
.353 0 0 r
.28665 .53099 m .28872 .53153 L .29058 .53152 L F
.039 0 0 r
.29088 .53168 m .29058 .53152 L .28872 .53153 L F
.29088 .53168 m .29267 .53151 L .29058 .53152 L F
.534 .421 .672 r
.35935 .59933 m .35703 .59987 L .35807 .59831 L F
.35935 .59933 m .35727 .60256 L .35703 .59987 L F
.851 .452 .286 r
.54361 .52533 m .5452 .528 L .54722 .5285 L F
.884 .552 .416 r
.5452 .528 m .54552 .53029 L .54722 .5285 L F
.886 .556 .419 r
.54722 .5285 m .54552 .53029 L .54755 .53074 L F
.14 0 .33 r
.30184 .57405 m .3004 .57507 L .30236 .57163 L F
.326 .048 .328 r
.30154 .57688 m .3004 .57507 L .30184 .57405 L F
.30154 .57688 m .29937 .57758 L .3004 .57507 L F
.295 .241 .626 r
.30088 .59385 m .30315 .59501 L .30283 .59238 L F
.30088 .59385 m .30116 .59652 L .30315 .59501 L F
.441 .849 .968 r
.23658 .63577 m .2364 .63672 L .2385 .6364 L F
.23658 .63577 m .23466 .63629 L .2364 .63672 L F
.885 .641 .564 r
.52837 .53448 m .52524 .53047 L .52742 .53162 L F
.253 0 0 r
.25677 .55339 m .25495 .55513 L .25262 .55551 L F
.16 0 0 r
.2573 .55453 m .25677 .55339 L .259 .55269 L F
.2573 .55453 m .25495 .55513 L .25677 .55339 L F
.095 .027 .481 r
.16111 .5871 m .16249 .58325 L .16029 .58499 L F
.89 .658 .581 r
.23018 .75957 m .23089 .75719 L .22886 .75557 L F
.536 .917 .931 r
.3243 .62314 m .3235 .62438 L .32585 .62356 L F
.3243 .62314 m .32233 .62425 L .3235 .62438 L F
.608 .419 .601 r
.32321 .6266 m .32585 .62356 L .3235 .62438 L F
.468 .314 .589 r
.29305 .57599 m .29177 .57872 L .29362 .57761 L F
.306 .044 .342 r
.29177 .57872 m .29087 .58071 L .29362 .57761 L F
.781 .498 .508 r
.32876 .64932 m .32859 .65169 L .32618 .64877 L F
.32618 .64877 m .32859 .65169 L .32876 .64932 L F
.313 .803 .803 r
.25242 .53375 m .25326 .53322 L .25469 .53298 L F
.25242 .53375 m .25099 .53394 L .25326 .53322 L F
.608 .609 .827 r
.33011 .56631 m .33457 .56898 L .33299 .56609 L F
.984 .876 .518 r
.55058 .54612 m .55061 .5495 L .5519 .54744 L F
.515 .443 .714 r
.32224 .55926 m .32387 .55511 L .32179 .55571 L F
.367 0 0 r
.23022 .55094 m .22819 .55227 L .22581 .55218 L F
.136 0 0 r
.2318 .55109 m .22819 .55227 L .23022 .55094 L F
.641 .483 .653 r
.32609 .58806 m .3273 .58944 L .32831 .58668 L F
.3273 .58944 m .32609 .58806 L .32831 .58668 L F
0 0 0 r
.3273 .58944 m .33017 .58629 L .32831 .58668 L F
.665 .633 .808 r
.33017 .58629 m .3273 .58944 L .32831 .58668 L F
.558 .116 .156 r
.31622 .56623 m .31735 .56453 L .3167 .56532 L F
.31622 .56623 m .31822 .56689 L .31735 .56453 L F
.245 0 .203 r
.31735 .56453 m .32226 .56137 L .31929 .56204 L F
.31735 .56453 m .32096 .56404 L .32226 .56137 L F
.307 0 .248 r
.31735 .56453 m .32042 .56612 L .32096 .56404 L F
.31735 .56453 m .31822 .56689 L .32042 .56612 L F
.523 .55 .825 r
.37136 .55804 m .37062 .56205 L .37073 .55944 L F
.64 .301 .381 r
.31618 .64894 m .31834 .65112 L .31569 .65109 L F
.607 .306 .433 r
.31909 .64898 m .31834 .65112 L .31618 .64894 L F
.5 .459 .743 r
.36066 .59259 m .35924 .59675 L .35648 .59065 L F
.36066 .59259 m .36165 .5961 L .35924 .59675 L F
.77 .589 .654 r
.36165 .5961 m .35807 .59831 L .35924 .59675 L F
0 0 0 r
.32945 .5678 m .32673 .57161 L .33011 .56631 L F
.23 0 0 r
.33299 .56609 m .32945 .5678 L .33011 .56631 L F
.526 .365 .606 r
.32317 .59383 m .32551 .59353 L .32555 .58999 L F
.381 .043 .261 r
.32551 .59353 m .32275 .59569 L .32317 .59383 L F
.526 .365 .606 r
.32317 .59383 m .32551 .59353 L .32555 .58999 L F
.381 .043 .261 r
.32275 .59569 m .32551 .59353 L .32317 .59383 L F
.452 .338 .634 r
.33334 .59615 m .33535 .59277 L .33291 .59347 L F
.565 .624 .869 r
.28743 .66441 m .2841 .6621 L .28524 .66165 L F
0 0 0 r
.28617 .66129 m .28524 .66165 L .28367 .66244 L F
.552 .699 .937 r
.28961 .66379 m .28524 .66165 L .28702 .66089 L F
0 0 0 r
.28702 .66089 m .28524 .66165 L .28617 .66129 L F
.565 .624 .869 r
.2841 .6621 m .2831 .66141 L .28524 .66165 L F
.144 0 0 r
.28337 .66725 m .28743 .66441 L .28685 .66659 L F
.552 .699 .937 r
.28961 .66379 m .28743 .66441 L .28524 .66165 L F
.594 .273 .395 r
.28743 .66441 m .28952 .6665 L .28685 .66659 L F
.456 .277 .548 r
.28961 .66379 m .28952 .6665 L .28743 .66441 L F
.377 .571 .914 r
.22542 .63263 m .22583 .63397 L .22677 .63216 L F
.37 .563 .91 r
.22583 .63397 m .22959 .63534 L .22677 .63216 L F
.325 .619 .956 r
.22795 .63515 m .22959 .63534 L .22583 .63397 L F
.66 .149 .019 r
.31928 .61377 m .32071 .61245 L .31815 .61169 L F
0 0 0 r
.32112 .61268 m .32071 .61245 L .31928 .61377 L F
.32112 .61268 m .32311 .61222 L .32071 .61245 L F
.327 0 0 r
.32071 .61245 m .32311 .61222 L .32385 .61151 L F
.574 .737 .953 r
.33485 .53523 m .33361 .53753 L .33201 .53614 L F
.33485 .53523 m .33616 .53699 L .33361 .53753 L F
.86 .953 .871 r
.30673 .60571 m .30762 .60246 L .30481 .60317 L F
0 .476 .712 r
.3082 .60595 m .30673 .60571 L .30657 .6083 L F
0 0 0 r
.26954 .61462 m .26725 .61769 L .26898 .61665 L F
.26725 .61769 m .26787 .61877 L .26898 .61665 L F
.26725 .61769 m .26608 .62031 L .26787 .61877 L F
.132 .084 .532 r
.29583 .57142 m .29753 .57045 L .29725 .56766 L F
.25 .055 .409 r
.29541 .57364 m .29753 .57045 L .29583 .57142 L F
.201 .555 .933 r
.244 .63703 m .24679 .63926 L .24838 .63938 L F
.137 0 .054 r
.17767 .5619 m .17966 .56146 L .18082 .55927 L F
.102 0 .036 r
.18082 .55927 m .18147 .56064 L .18294 .55843 L F
.18082 .55927 m .17966 .56146 L .18147 .56064 L F
.364 .076 .336 r
.22601 .74131 m .22674 .73882 L .22358 .74187 L F
.573 .27 .417 r
.22601 .74131 m .22832 .73977 L .22674 .73882 L F
.459 .345 .636 r
.22674 .73882 m .22832 .73977 L .22906 .73843 L F
.22674 .73882 m .22832 .73977 L .22906 .73843 L F
.641 .483 .653 r
.32609 .58806 m .32555 .58999 L .3273 .58944 L F
.3273 .58944 m .32555 .58999 L .32609 .58806 L F
.707 .181 0 r
.38044 .54757 m .37912 .54839 L .37666 .54608 L F
.56 0 0 r
.38276 .54888 m .37912 .54839 L .38044 .54757 L F
.554 .215 .348 r
.38417 .54653 m .38276 .54888 L .38044 .54757 L F
.29 0 .161 r
.19745 .54765 m .19892 .54836 L .19977 .54698 L F
.19745 .54765 m .19675 .5491 L .19892 .54836 L F
.754 .633 .726 r
.81862 .40457 m .82183 .40733 L .82036 .40367 L F
.627 .522 .715 r
.82036 .40367 m .82183 .40733 L .82283 .40534 L F
.702 .252 .18 r
.53971 .52475 m .54208 .52682 L .54361 .52533 L F
.845 .454 .306 r
.54208 .52682 m .5452 .528 L .54361 .52533 L F
.619 .462 .647 r
.3476 .6175 m .34837 .62077 L .34493 .6211 L F
.545 .327 .534 r
.34837 .62077 m .34489 .62426 L .34493 .6211 L F
.116 .165 .637 r
.31539 .61558 m .31584 .61798 L .31766 .61571 L F
.289 .419 .82 r
.31766 .61571 m .31584 .61798 L .31727 .6176 L F
.508 .484 .765 r
.31633 .621 m .31727 .6176 L .31584 .61798 L F
.609 .947 .783 r
.26306 .69598 m .26549 .69492 L .2662 .69377 L F
.91 .828 .752 r
.55105 .53679 m .55143 .5401 L .55267 .538 L F
.536 .263 .447 r
.37672 .54407 m .37666 .54608 L .37371 .54602 L F
.924 .918 .791 r
.30917 .55941 m .30752 .562 L .30894 .5615 L F
.965 .86 .687 r
.30752 .562 m .30751 .56548 L .30894 .5615 L F
.276 .354 .763 r
.30312 .55899 m .30455 .55808 L .3021 .55639 L F
.62 .377 .527 r
.30312 .55899 m .30577 .56167 L .30455 .55808 L F
.30312 .55899 m .30243 .56212 L .30577 .56167 L F
.768 .653 .735 r
.27846 .65434 m .2821 .65505 L .28061 .65168 L F
.417 .479 .817 r
.27846 .65434 m .28123 .65683 L .2821 .65505 L F
.268 .378 .791 r
.28061 .65168 m .2821 .65505 L .28354 .65385 L F
.757 .463 .487 r
.2821 .65505 m .2847 .65766 L .28123 .65683 L F
0 0 0 r
.28354 .65385 m .2821 .65505 L .28123 .65683 L F
.767 .66 .744 r
.33273 .54732 m .32956 .55121 L .32851 .54657 L F
.277 0 0 r
.23824 .62443 m .23996 .62445 L .23589 .62388 L F
.302 0 0 r
.24036 .62482 m .23996 .62445 L .23824 .62443 L F
.24036 .62482 m .24187 .62519 L .23996 .62445 L F
.515 .443 .714 r
.32224 .55926 m .32451 .55892 L .32387 .55511 L F
.646 .464 .623 r
.32226 .56137 m .32451 .55892 L .32224 .55926 L F
.525 .494 .765 r
.38537 .54317 m .38548 .54669 L .38417 .54653 L F
.691 .419 .507 r
.38548 .54669 m .38276 .54888 L .38417 .54653 L F
.511 .503 .784 r
.37466 .55055 m .37396 .55471 L .37153 .55365 L F
.37466 .55055 m .37667 .55476 L .37396 .55471 L F
.783 .555 .592 r
.37667 .55476 m .37389 .55416 L .37396 .55471 L F
.37389 .55416 m .37153 .55365 L .37396 .55471 L F
.684 .98 .86 r
.37555 .55441 m .37407 .55552 L .37396 .55471 L F
.37407 .55552 m .37304 .5563 L .37396 .55471 L F
.061 .224 .72 r
.37304 .5563 m .37568 .55843 L .37396 .55471 L F
0 .343 .758 r
.23234 .62209 m .2328 .62242 L .23223 .62242 L F
.171 .647 .929 r
.23418 .62295 m .2318 .62242 L .23223 .62242 L F
.494 0 0 r
.23223 .62242 m .23589 .62388 L .23418 .62295 L F
0 .343 .758 r
.2328 .62242 m .23405 .62331 L .23223 .62242 L F
.171 .647 .929 r
.2318 .62242 m .22973 .62196 L .23223 .62242 L F
0 0 0 r
.31299 .5912 m .31196 .59275 L .31077 .59319 L F
.79 .292 0 r
.31077 .59319 m .31223 .59553 L .31414 .59614 L F
.044 .074 .567 r
.31196 .59275 m .31223 .59553 L .31077 .59319 L F
.472 .641 .93 r
.21251 .62975 m .21212 .62686 L .21031 .62701 L F
.21251 .62975 m .21451 .62951 L .21212 .62686 L F
.594 .527 .749 r
.31424 .61166 m .31539 .61558 L .31707 .6146 L F
.116 .165 .637 r
.31539 .61558 m .31766 .61571 L .31707 .6146 L F
0 .502 .793 r
.19894 .60198 m .20114 .60246 L .2027 .60307 L F
0 .264 .766 r
.20288 .60205 m .2027 .60307 L .20114 .60246 L F
.20288 .60205 m .20497 .60455 L .2027 .60307 L F
.561 .336 .53 r
.28957 .63036 m .28678 .63329 L .2892 .63285 L F
.525 .506 .777 r
.28829 .628 m .28957 .63036 L .29174 .62965 L F
.686 .567 .716 r
.2892 .63285 m .29174 .62965 L .28957 .63036 L F
0 0 0 r
.32567 .60266 m .32576 .60315 L .32814 .60287 L F
.32567 .60266 m .32542 .60531 L .32576 .60315 L F
0 0 .466 r
.32142 .59937 m .32205 .60047 L .32091 .59863 L F
.385 .614 .941 r
.32592 .60215 m .32303 .60189 L .32292 .60172 L F
.32292 .60172 m .32303 .60189 L .32254 .60167 L F
.32592 .60215 m .32576 .60315 L .32303 .60189 L F
.215 0 0 r
.32323 .60199 m .32757 .60238 L .32321 .60176 L F
.32323 .60199 m .32321 .60176 L .32254 .60167 L F
0 0 .466 r
.32323 .60199 m .32245 .60098 L .32142 .59937 L F
.827 .559 .534 r
.32576 .60315 m .32559 .60441 L .32254 .60167 L F
.06 .305 .791 r
.3254 .60548 m .32789 .60752 L .32576 .60315 L F
.841 .754 .767 r
.32576 .60315 m .32789 .60752 L .32989 .60477 L F
.985 .741 .483 r
.32576 .60315 m .32789 .60752 L .32559 .60441 L F
.877 .699 .657 r
.3275 .60394 m .32576 .6045 L .32576 .60315 L F
.957 .702 .508 r
.32461 .60486 m .32559 .60441 L .32518 .60401 L F
.877 .699 .657 r
.32526 .60408 m .32461 .60486 L .32518 .60401 L F
0 .146 .642 r
.32307 .60192 m .32518 .60401 L .32254 .60167 L F
.32518 .60401 m .32559 .60441 L .32455 .60348 L F
.32518 .60401 m .32455 .60348 L .32254 .60167 L F
.32323 .60199 m .32486 .60367 L .32307 .60192 L F
.32486 .60367 m .32559 .60441 L .32473 .60356 L F
.32486 .60367 m .32473 .60356 L .32307 .60192 L F
0 0 0 r
.32542 .60531 m .3254 .60548 L .32576 .60315 L F
.384 .362 .711 r
.32625 .60819 m .32789 .60752 L .3254 .60548 L F
.877 .699 .657 r
.3275 .60394 m .32673 .60686 L .32461 .60486 L F
.503 .281 .51 r
.32461 .60486 m .32681 .60523 L .32682 .60521 L F
.724 .199 0 r
.32576 .60315 m .32989 .60477 L .32814 .60287 L F
.385 .614 .941 r
.32757 .60238 m .3275 .60394 L .32576 .60315 L F
.503 .281 .51 r
.32547 .60414 m .32682 .60521 L .32757 .60238 L F
.974 .77 .566 r
.32526 .60408 m .32559 .60441 L .32461 .60486 L F
.877 .699 .657 r
.32576 .6045 m .32461 .60486 L .32526 .60408 L F
.503 .281 .51 r
.32461 .60486 m .32682 .60521 L .32547 .60414 L F
.974 .77 .566 r
.32323 .60199 m .32526 .60408 L .32461 .60486 L F
.957 .702 .508 r
.32518 .60401 m .32559 .60441 L .32576 .60315 L F
.877 .699 .657 r
.32576 .6045 m .32518 .60401 L .32576 .60315 L F
.829 .819 .839 r
.32323 .60199 m .31937 .6043 L .32064 .60199 L F
.32323 .60199 m .32298 .60276 L .31937 .6043 L F
0 0 .066 r
.32326 .6023 m .32323 .60199 L .32225 .60042 L F
.75 .73 .833 r
.32298 .60276 m .32461 .60486 L .32323 .60199 L F
0 0 .066 r
.32363 .60299 m .32298 .60276 L .32304 .60259 L F
.32363 .60299 m .32304 .60259 L .32323 .60199 L F
.385 .614 .941 r
.32757 .60238 m .32576 .60315 L .32592 .60215 L F
.503 .281 .51 r
.32461 .60486 m .32757 .60238 L .32323 .60199 L F
0 0 .066 r
.32363 .60299 m .32323 .60199 L .32326 .6023 L F
0 0 .522 r
.32225 .60042 m .32323 .60199 L .32091 .59863 L F
0 0 .472 r
.32243 .59941 m .32363 .60299 L .32225 .60042 L F
.981 .757 .527 r
.3221 .60183 m .32363 .60299 L .32243 .59941 L F
0 0 .523 r
.32429 .60343 m .32363 .60299 L .3221 .60183 L F
.32436 .60348 m .32363 .60299 L .32429 .60343 L F
0 0 .466 r
.32245 .60098 m .32205 .60047 L .32142 .59937 L F
.335 .802 .705 r
.22109 .53791 m .221 .53776 L .22345 .53761 L F
.22109 .53791 m .21887 .53873 L .221 .53776 L F
.56 .288 .461 r
.27666 .5536 m .27573 .55589 L .27307 .556 L F
.267 0 .309 r
.27768 .55498 m .27666 .5536 L .27736 .55201 L F
.27768 .55498 m .27573 .55589 L .27666 .5536 L F
.054 .06 .545 r
.33944 .56144 m .33916 .56279 L .34138 .56172 L F
.33944 .56144 m .3381 .56342 L .33916 .56279 L F
.615 .615 .828 r
.26597 .68578 m .2671 .68169 L .2651 .68323 L F
.587 .576 .808 r
.34943 .61464 m .3476 .6175 L .34699 .61503 L F
.34943 .61464 m .35079 .6178 L .3476 .6175 L F
.573 .433 .652 r
.35047 .62038 m .3476 .6175 L .35079 .6178 L F
.35047 .62038 m .34837 .62077 L .3476 .6175 L F
.295 0 .07 r
.36424 .59005 m .36302 .59204 L .36066 .59259 L F
.295 .333 .731 r
.36683 .58474 m .36757 .58747 L .36534 .58643 L F
.36757 .58747 m .36782 .58839 L .36684 .58761 L F
.36757 .58747 m .36694 .58759 L .36534 .58643 L F
.269 .212 .607 r
.36733 .58787 m .36694 .58759 L .36534 .58643 L F
.36694 .58759 m .36458 .58594 L .36534 .58643 L F
.36694 .58759 m .36684 .58761 L .36458 .58594 L F
.36684 .58761 m .3644 .5881 L .36454 .58643 L F
.36684 .58761 m .36454 .58643 L .36458 .58594 L F
.295 .333 .731 r
.36694 .58759 m .36684 .58761 L .36534 .58643 L F
.032 .289 .782 r
.36534 .58643 m .36684 .58761 L .36733 .58787 L F
.36684 .58761 m .36782 .58839 L .36733 .58787 L F
.269 .212 .607 r
.36733 .58787 m .36424 .59005 L .3644 .5881 L F
.36733 .58787 m .3644 .5881 L .36694 .58759 L F
.68 .605 .764 r
.36733 .58787 m .36302 .59204 L .36424 .59005 L F
.626 .382 .529 r
.33485 .55874 m .33769 .5585 L .33764 .55627 L F
.643 .939 .963 r
.33836 .55458 m .33764 .55627 L .34011 .55476 L F
.741 .967 .694 r
.33836 .55458 m .33749 .55521 L .33764 .55627 L F
.534 .594 .861 r
.16379 .5993 m .164 .5954 L .16227 .59586 L F
.434 .576 .896 r
.19329 .598 m .1949 .60063 L .19273 .60085 L F
.209 .417 .846 r
.30162 .54353 m .30435 .54524 L .30415 .54273 L F
.246 0 0 r
.30415 .54273 m .30327 .54311 L .30162 .54353 L F
.454 .565 .877 r
.29977 .544 m .3037 .54707 L .30162 .54353 L F
.209 .417 .846 r
.30162 .54353 m .3037 .54707 L .30435 .54524 L F
.246 0 0 r
.30327 .54311 m .29972 .5446 L .30162 .54353 L F
.454 .565 .877 r
.29955 .54384 m .29977 .544 L .30162 .54353 L F
0 0 .24 r
.3037 .54707 m .30482 .54793 L .30435 .54524 L F
.3037 .54707 m .30313 .54948 L .30482 .54793 L F
0 0 0 r
.29972 .5446 m .29955 .54384 L .30162 .54353 L F
.29972 .5446 m .2977 .54538 L .29955 .54384 L F
.087 .558 .905 r
.23044 .62138 m .22973 .62196 L .22776 .62079 L F
.23044 .62138 m .23223 .62242 L .22973 .62196 L F
.589 .655 .883 r
.27956 .64503 m .2827 .64738 L .28104 .64589 L F
.291 .648 .968 r
.28104 .64589 m .2827 .64738 L .28559 .64753 L F
.487 .279 .523 r
.30871 .63035 m .31108 .6273 L .30761 .62698 L F
.30871 .63035 m .31104 .62978 L .31108 .6273 L F
.492 .297 .544 r
.31108 .6273 m .31371 .62674 L .31384 .62398 L F
.438 .241 .514 r
.31108 .6273 m .31324 .6291 L .31371 .62674 L F
.31108 .6273 m .31104 .62978 L .31324 .6291 L F
.85 .572 .516 r
.32989 .60477 m .33164 .60257 L .32814 .60287 L F
.32989 .60477 m .33158 .60519 L .33164 .60257 L F
.552 .421 .656 r
.33164 .60257 m .33408 .60222 L .33367 .59954 L F
.668 .415 .528 r
.33164 .60257 m .33436 .60493 L .33408 .60222 L F
.33164 .60257 m .33158 .60519 L .33436 .60493 L F
.338 .534 .899 r
.20849 .62699 m .20936 .62529 L .20678 .62362 L F
.20849 .62699 m .21031 .62701 L .20936 .62529 L F
0 0 0 r
.367 .55783 m .36398 .56179 L .36498 .5604 L F
.806 .981 .701 r
.26197 .55035 m .26093 .5517 L .2612 .55251 L F
.301 .755 .956 r
.26135 .55294 m .2612 .55251 L .259 .55269 L F
.031 0 0 r
.25939 .5537 m .259 .55269 L .2612 .55251 L F
.806 .981 .701 r
.26093 .5517 m .25939 .5537 L .2612 .55251 L F
.301 .755 .956 r
.26303 .55312 m .2612 .55251 L .26135 .55294 L F
.272 .443 .848 r
.26303 .55312 m .26359 .55015 L .2612 .55251 L F
.26303 .55312 m .26544 .55379 L .26359 .55015 L F
.525 .506 .777 r
.28829 .628 m .29174 .62965 L .29054 .626 L F
0 0 0 r
.31323 .59151 m .31196 .59275 L .31299 .5912 L F
.556 .359 .568 r
.36776 .54964 m .36522 .55282 L .36525 .55009 L F
0 0 0 r
.2719 .61146 m .26954 .61462 L .27186 .61436 L F
0 0 .021 r
.27458 .60826 m .2719 .61146 L .27374 .6104 L F
.143 0 .217 r
.2719 .61146 m .27327 .61308 L .27374 .6104 L F
.2719 .61146 m .27186 .61436 L .27327 .61308 L F
.525 .336 .566 r
.30627 .63358 m .30856 .63286 L .30871 .63035 L F
.748 .537 .61 r
.3047 .63605 m .30856 .63286 L .30627 .63358 L F
.677 .571 .729 r
.33853 .63661 m .33648 .63997 L .33687 .63794 L F
.721 .59 .709 r
.37215 .56826 m .36945 .56872 L .37344 .56451 L F
.616 .958 .864 r
.37344 .56451 m .37281 .56409 L .3741 .56403 L F
.402 .853 .901 r
.37344 .56451 m .37018 .56488 L .37281 .56409 L F
.699 .567 .702 r
.3751 .56811 m .37215 .56826 L .37344 .56451 L F
.202 0 .224 r
.30468 .57097 m .30184 .57405 L .30236 .57163 L F
.137 0 .085 r
.37371 .54602 m .37265 .5486 L .37079 .54934 L F
0 0 0 r
.37666 .54608 m .37265 .5486 L .37371 .54602 L F
.427 .178 .431 r
.16723 .57167 m .16941 .57109 L .16997 .56866 L F
.45 .23 .486 r
.16941 .57109 m .17197 .56795 L .16997 .56866 L F
.429 .224 .498 r
.32327 .64203 m .32297 .64462 L .3211 .64265 L F
.095 .027 .481 r
.16111 .5871 m .16215 .5869 L .16249 .58325 L F
.135 .216 .684 r
.16111 .5871 m .16305 .58912 L .16215 .5869 L F
.439 .266 .548 r
.16097 .58965 m .16305 .58912 L .16111 .5871 L F
.632 .65 .85 r
.77801 .40857 m .77991 .40453 L .77673 .40509 L F
.77801 .40857 m .78084 .40774 L .77991 .40453 L F
.523 .345 .581 r
.30856 .63286 m .31104 .62978 L .30871 .63035 L F
.529 .397 .645 r
.32385 .61151 m .32644 .61131 L .32625 .60819 L F
.298 0 0 r
.32311 .61222 m .32644 .61131 L .32385 .61151 L F
.618 .417 .587 r
.37215 .56826 m .36943 .57152 L .36945 .56872 L F
.37215 .56826 m .37235 .57127 L .36943 .57152 L F
.529 .26 .451 r
.3751 .56811 m .37235 .57127 L .37215 .56826 L F
.635 .433 .593 r
.35707 .60497 m .35475 .60265 L .35727 .60256 L F
.63 .544 .739 r
.35935 .59933 m .35986 .60233 L .35727 .60256 L F
.65 .422 .561 r
.35986 .60233 m .35707 .60497 L .35727 .60256 L F
.909 .81 .738 r
.53319 .54074 m .53009 .54147 L .53251 .53728 L F
.89 .664 .59 r
.53319 .54074 m .53017 .54215 L .53009 .54147 L F
.53319 .54074 m .53296 .54332 L .53017 .54215 L F
.471 .236 .476 r
.3497 .61175 m .34943 .61464 L .34699 .61503 L F
.507 .403 .671 r
.35187 .60863 m .3497 .61175 L .34838 .6081 L F
.35187 .60863 m .35191 .61121 L .3497 .61175 L F
.531 .287 .489 r
.35185 .61396 m .3497 .61175 L .35191 .61121 L F
.35185 .61396 m .34943 .61464 L .3497 .61175 L F
.138 0 .261 r
.16228 .5778 m .16385 .5771 L .16459 .57463 L F
.273 .172 .553 r
.16228 .5778 m .16393 .57979 L .16385 .5771 L F
.283 .174 .549 r
.16238 .58044 m .16393 .57979 L .16228 .5778 L F
.697 .871 .964 r
.28934 .6483 m .29364 .64796 L .29227 .65213 L F
.491 .107 .239 r
.29227 .65213 m .2933 .64901 L .29414 .64972 L F
.29227 .65213 m .29413 .64973 L .29382 .64989 L F
.29414 .64972 m .29364 .64796 L .2951 .64848 L F
.29413 .64973 m .2951 .64848 L .29382 .64989 L F
.91 .847 .77 r
.29227 .65213 m .29382 .64989 L .29187 .64931 L F
.483 0 0 r
.29382 .64989 m .29548 .65134 L .29335 .65014 L F
.29382 .64989 m .29335 .65014 L .29187 .64931 L F
.528 .765 .984 r
.29703 .65444 m .29583 .65072 L .29728 .65162 L F
.531 .269 .462 r
.29959 .6519 m .29703 .65444 L .29728 .65162 L F
.528 .765 .984 r
.29669 .65336 m .29796 .65266 L .29583 .65072 L F
.29703 .65444 m .29796 .65266 L .29669 .65336 L F
.531 .269 .462 r
.29959 .6519 m .29951 .65415 L .29703 .65444 L F
.455 .095 .264 r
.29986 .65187 m .29951 .65415 L .29959 .6519 L F
.30328 .65148 m .29951 .65415 L .29986 .65187 L F
.503 .247 .459 r
.29951 .65415 m .30185 .65408 L .29913 .65652 L F
.847 .847 .843 r
.29913 .65652 m .29915 .65642 L .29951 .65415 L F
.455 .095 .264 r
.30328 .65148 m .30185 .65408 L .29951 .65415 L F
.847 .847 .843 r
.29915 .65642 m .30004 .65235 L .29951 .65415 L F
.358 .773 .979 r
.29884 .65218 m .29796 .65266 L .30004 .65235 L F
.591 .046 0 r
.29583 .65072 m .29796 .65266 L .29657 .65185 L F
.358 .773 .979 r
.29657 .65185 m .29796 .65266 L .29884 .65218 L F
.591 .046 0 r
.29483 .65031 m .29657 .65185 L .29382 .64989 L F
.29583 .65072 m .29646 .65169 L .29483 .65031 L F
.29646 .65169 m .29657 .65185 L .29483 .65031 L F
.491 .107 .239 r
.2933 .64901 m .29364 .64796 L .29414 .64972 L F
.905 .676 .582 r
.27906 .58613 m .27967 .58957 L .28049 .58731 L F
0 0 .108 r
.32945 .5678 m .32768 .5715 L .32673 .57161 L F
.691 .52 .65 r
.3273 .58944 m .32551 .59353 L .32555 .58999 L F
.3273 .58944 m .32889 .5922 L .32551 .59353 L F
0 0 .385 r
.32555 .58999 m .32689 .59074 L .3273 .58944 L F
.32555 .58999 m .32551 .59353 L .32689 .59074 L F
.756 .712 .811 r
.22832 .73977 m .23024 .74154 L .22906 .73843 L F
.694 .852 .958 r
.22601 .74131 m .23024 .74154 L .22832 .73977 L F
0 .245 .759 r
.50304 .56538 m .5047 .56551 L .5009 .56425 L F
.50304 .56538 m .50566 .56745 L .5047 .56551 L F
.086 0 .242 r
.26954 .61462 m .27075 .61628 L .27186 .61436 L F
.26954 .61462 m .26898 .61665 L .27075 .61628 L F
.308 .022 .306 r
.1751 .56517 m .17711 .56452 L .17767 .5619 L F
.259 0 .289 r
.17767 .5619 m .179 .56376 L .17966 .56146 L F
.17767 .5619 m .17711 .56452 L .179 .56376 L F
.525 .821 .999 r
.29703 .65444 m .29488 .65508 L .293 .65397 L F
.621 .074 0 r
.293 .65397 m .29488 .65508 L .29682 .65702 L F
.439 .236 .506 r
.29682 .65702 m .29488 .65508 L .29703 .65444 L F
.521 .377 .626 r
.35074 .60511 m .34838 .6081 L .34834 .60561 L F
.199 .728 .81 r
.31413 .59579 m .31414 .59614 L .31223 .59553 L F
.31413 .59579 m .31646 .59578 L .31414 .59614 L F
.754 .633 .726 r
.81862 .40457 m .82008 .40831 L .82183 .40733 L F
0 0 0 r
.19832 .56816 m .19718 .57062 L .19574 .57127 L F
.19623 .57241 m .19574 .57127 L .19718 .57062 L F
.19623 .57241 m .1944 .57333 L .19574 .57127 L F
.685 .441 .548 r
.33535 .59277 m .33821 .59282 L .33864 .59019 L F
.567 .4 .615 r
.33821 .59282 m .34097 .5893 L .33864 .59019 L F
.819 .643 .664 r
.31815 .61169 m .31637 .60862 L .31685 .61147 L F
.66 .149 .019 r
.31928 .61377 m .31815 .61169 L .31685 .61147 L F
.393 .312 .645 r
.30988 .54988 m .31228 .552 L .31228 .552 L F
.31032 .54982 m .31228 .552 L .31293 .54942 L F
.30988 .54988 m .31228 .552 L .31032 .54982 L F
.31228 .552 m .31254 .55216 L .31293 .54942 L F
.551 .361 .576 r
.31253 .55222 m .31506 .54872 L .31293 .54942 L F
0 .179 .694 r
.31318 .55004 m .31231 .55203 L .31085 .5476 L F
.31231 .55203 m .3123 .55204 L .31229 .552 L F
.31231 .55203 m .31229 .552 L .31085 .5476 L F
.476 .428 .725 r
.31229 .552 m .30927 .5493 L .31085 .5476 L F
.3123 .55204 m .3122 .55195 L .31229 .552 L F
.3122 .55195 m .30927 .5493 L .31229 .552 L F
.393 .312 .645 r
.31231 .55202 m .31253 .55222 L .31254 .55216 L F
.31231 .55202 m .31253 .55222 L .31231 .55202 L F
.551 .361 .576 r
.31253 .55222 m .31494 .55187 L .31506 .54872 L F
.638 .456 .62 r
.31253 .55222 m .31548 .55443 L .31494 .55187 L F
.31359 .55302 m .31289 .55494 L .31548 .55443 L F
.31253 .55222 m .31277 .55402 L .31359 .55302 L F
.31277 .55402 m .31289 .55494 L .31359 .55302 L F
.311 .073 .382 r
.31281 .55275 m .31028 .55596 L .31164 .55541 L F
.31186 .55514 m .31164 .55541 L .31178 .55535 L F
.31281 .55275 m .31164 .55541 L .31186 .55514 L F
0 0 .064 r
.31281 .55275 m .3123 .55205 L .31318 .55004 L F
.3123 .55205 m .3123 .55204 L .31231 .55203 L F
.3123 .55205 m .31231 .55203 L .31318 .55004 L F
.393 .312 .645 r
.31228 .552 m .31231 .55202 L .31231 .55202 L F
.51 .488 .768 r
.30223 .60076 m .30258 .60348 L .30481 .60317 L F
.771 .853 .912 r
.38074 .56196 m .37688 .56238 L .37902 .56122 L F
.506 .627 .904 r
.38066 .5586 m .38074 .56196 L .37902 .56122 L F
.38066 .5586 m .38317 .56193 L .38074 .56196 L F
.532 .345 .573 r
.38317 .56193 m .3817 .56442 L .38074 .56196 L F
.312 .272 .652 r
.30116 .59652 m .3032 .59862 L .30315 .59501 L F
.119 .23 .705 r
.30116 .59652 m .3025 .59931 L .3032 .59862 L F
0 0 0 r
.26834 .68489 m .27147 .68324 L .27065 .6845 L F
.598 .644 .867 r
.27288 .68014 m .27147 .68324 L .27046 .6802 L F
.27288 .68014 m .27542 .68241 L .27147 .68324 L F
.766 .633 .714 r
.27542 .68241 m .27237 .68374 L .27147 .68324 L F
.27542 .68241 m .27488 .68479 L .27065 .6845 L F
.508 .621 .899 r
.27591 .68105 m .27542 .68241 L .27288 .68014 L F
.27591 .68105 m .27542 .68241 L .27288 .68014 L F
.712 .679 .817 r
.27123 .68029 m .27368 .68331 L .27591 .68105 L F
.714 .591 .717 r
.27735 .68027 m .27746 .68287 L .27542 .68241 L F
.859 .994 .822 r
.27591 .68105 m .27735 .68027 L .27542 .68241 L F
.59 .713 .928 r
.27542 .68241 m .27746 .68287 L .27591 .68105 L F
0 0 .036 r
.27591 .68105 m .27488 .68479 L .27542 .68241 L F
.712 .679 .817 r
.27368 .68331 m .27488 .68479 L .27545 .68271 L F
.27368 .68331 m .27545 .68271 L .27591 .68105 L F
.766 .633 .714 r
.27237 .68374 m .27065 .6845 L .2708 .68427 L F
.27237 .68374 m .2708 .68427 L .27147 .68324 L F
.656 .411 .537 r
.27404 .54937 m .27726 .5494 L .27688 .54605 L F
0 0 .343 r
.27688 .54605 m .27726 .5494 L .27808 .54664 L F
.766 .606 .68 r
.53794 .55945 m .53619 .56261 L .54189 .56249 L F
.857 .778 .772 r
.53736 .56414 m .53868 .56534 L .54189 .56249 L F
.712 .502 .603 r
.53868 .56534 m .54175 .56534 L .54189 .56249 L F
.131 .509 .911 r
.5416 .56202 m .54117 .56099 L .54001 .5594 L F
0 .071 .632 r
.54001 .5594 m .54117 .56099 L .54085 .55942 L F
.817 .421 .303 r
.54117 .56099 m .53863 .56251 L .54063 .55973 L F
.54117 .56099 m .54063 .55973 L .54085 .55942 L F
.131 .509 .911 r
.54189 .56249 m .54117 .56099 L .5416 .56202 L F
.54189 .56249 m .54242 .56229 L .54117 .56099 L F
.765 .548 .603 r
.54189 .56249 m .5439 .56388 L .54242 .56229 L F
.535 .923 .898 r
.54501 .56266 m .54377 .56335 L .5439 .56388 L F
.765 .548 .603 r
.54189 .56249 m .54402 .56439 L .5439 .56388 L F
.54189 .56249 m .54175 .56534 L .54485 .56513 L F
.839 .371 .026 r
.54378 .56376 m .54295 .56379 L .54117 .56099 L F
.5439 .56388 m .54295 .56379 L .54378 .56376 L F
.5439 .56388 m .54117 .56099 L .54242 .56229 L F
.817 .421 .303 r
.54117 .56099 m .54295 .56379 L .53863 .56251 L F
.763 .293 .129 r
.54295 .56379 m .54103 .5647 L .53863 .56251 L F
.913 .98 .721 r
.54311 .56146 m .54158 .56385 L .54295 .56379 L F
.54158 .56385 m .54103 .5647 L .54295 .56379 L F
.535 .923 .898 r
.54377 .56335 m .54295 .56379 L .5439 .56388 L F
.765 .548 .603 r
.54402 .56439 m .54485 .56513 L .5439 .56388 L F
.529 .26 .451 r
.3751 .56811 m .37474 .571 L .37235 .57127 L F
.243 .024 .369 r
.37701 .56926 m .3751 .56811 L .37704 .56692 L F
.37701 .56926 m .37474 .571 L .3751 .56811 L F
.201 0 .247 r
.29828 .614 m .30077 .61141 L .29816 .61168 L F
.388 .211 .516 r
.35121 .54729 m .34887 .54992 L .34787 .54648 L F
.579 .807 .986 r
.2732 .64385 m .27365 .64195 L .27139 .64193 L F
.2732 .64385 m .27546 .64314 L .27365 .64195 L F
.305 .615 .956 r
.1927 .61586 m .19283 .61411 L .19108 .61446 L F
.1927 .61586 m .19568 .61602 L .19283 .61411 L F
0 .448 .803 r
.25273 .63963 m .25453 .63996 L .25045 .6389 L F
.25273 .63963 m .25473 .64006 L .25453 .63996 L F
.038 0 0 r
.2847 .65766 m .28819 .65468 L .28677 .65785 L F
.951 .788 .644 r
.28819 .65468 m .28914 .65422 L .28929 .65332 L F
0 0 0 r
.28868 .65442 m .28819 .65468 L .28915 .65349 L F
.951 .788 .644 r
.28868 .65442 m .28685 .65105 L .28911 .65419 L F
.28819 .65468 m .28817 .65464 L .28868 .65442 L F
.28817 .65464 m .28685 .65105 L .28868 .65442 L F
.28819 .65468 m .28911 .65419 L .28914 .65422 L F
0 0 0 r
.28677 .65785 m .28868 .65442 L .28914 .65422 L F
.28868 .65442 m .28929 .65332 L .28914 .65422 L F
.783 .289 0 r
.28726 .65278 m .28911 .6542 L .28685 .65105 L F
.28911 .6542 m .28914 .65422 L .28911 .65419 L F
.28911 .6542 m .28911 .65419 L .28685 .65105 L F
0 0 0 r
.28915 .65357 m .28915 .65349 L .28929 .65332 L F
.28868 .65442 m .28915 .65349 L .28915 .65357 L F
.28677 .65785 m .28819 .65468 L .28868 .65442 L F
.421 .671 .965 r
.32389 .53399 m .32318 .53601 L .32183 .5346 L F
.32389 .53399 m .32582 .53621 L .32318 .53601 L F
.29 .662 .971 r
.21937 .63115 m .22307 .63255 L .21943 .63014 L F
0 .568 .723 r
.22307 .63255 m .22394 .63255 L .21943 .63014 L F
.22307 .63255 m .22542 .63263 L .22394 .63255 L F
.988 .741 .466 r
.5363 .56825 m .53492 .56745 L .53493 .56445 L F
.544 .544 .805 r
.5363 .56825 m .53736 .56414 L .53492 .56745 L F
.5363 .56825 m .53876 .56792 L .53736 .56414 L F
.113 0 .356 r
.28151 .60866 m .28323 .60523 L .28229 .60808 L F
.012 0 .32 r
.28111 .61118 m .28151 .60866 L .28229 .60808 L F
.452 .338 .634 r
.33334 .59615 m .33545 .59558 L .33535 .59277 L F
.584 .504 .731 r
.33367 .59954 m .33545 .59558 L .33334 .59615 L F
0 0 0 r
.30761 .62698 m .30988 .62338 L .30932 .62604 L F
.023 0 .276 r
.30758 .62961 m .30761 .62698 L .30932 .62604 L F
.322 .762 .965 r
.25056 .62659 m .24998 .62761 L .24805 .6266 L F
.25056 .62659 m .25268 .62741 L .24998 .62761 L F
.158 .358 .811 r
.18845 .61266 m .18937 .61085 L .18746 .61102 L F
.18845 .61266 m .19108 .61446 L .18937 .61085 L F
0 0 0 r
.30288 .55199 m .30163 .55307 L .30234 .55283 L F
0 0 .535 r
.3021 .55639 m .30109 .55321 L .30095 .55325 L F
.3021 .55639 m .30214 .55484 L .30109 .55321 L F
.30095 .55325 m .30109 .55321 L .30072 .55263 L F
.708 .232 0 r
.30072 .55263 m .30108 .55319 L .30092 .55369 L F
.30108 .55319 m .30214 .55484 L .30092 .55369 L F
.724 .493 .576 r
.30214 .55484 m .29862 .55421 L .30092 .55369 L F
.30214 .55484 m .29928 .55715 L .29862 .55421 L F
.566 0 0 r
.3021 .55639 m .30455 .55808 L .3026 .55749 L F
.3021 .55639 m .3026 .55749 L .30214 .55484 L F
.724 .493 .576 r
.30214 .55484 m .3026 .55749 L .29928 .55715 L F
.224 .137 .541 r
.30234 .55283 m .30226 .55574 L .30092 .55369 L F
.785 .598 .648 r
.30234 .55283 m .30082 .55399 L .30092 .55369 L F
.724 .275 .183 r
.29943 .55505 m .30226 .55574 L .30092 .55369 L F
.785 .598 .648 r
.30082 .55399 m .29943 .55505 L .30092 .55369 L F
0 0 0 r
.30163 .55307 m .30092 .55369 L .30216 .55293 L F
.30163 .55307 m .30216 .55293 L .30234 .55283 L F
.965 .86 .687 r
.30752 .562 m .30566 .56443 L .30751 .56548 L F
.645 .178 0 r
.30696 .56496 m .30751 .56548 L .30666 .565 L F
.30696 .56496 m .30896 .56759 L .30751 .56548 L F
.523 .504 .777 r
.31037 .56328 m .30896 .56759 L .30696 .56496 L F
.218 0 0 r
.30644 .56592 m .30806 .56483 L .30696 .56496 L F
.30806 .56483 m .31037 .56328 L .30696 .56496 L F
.645 .178 0 r
.30696 .56496 m .30666 .565 L .30566 .56443 L F
.728 .518 .606 r
.35475 .60265 m .35444 .60533 L .35074 .60511 L F
.635 .433 .593 r
.35707 .60497 m .35444 .60533 L .35475 .60265 L F
.291 .732 .964 r
.16754 .60247 m .17014 .60246 L .16771 .60157 L F
.055 0 0 r
.36938 .53547 m .37377 .53452 L .37126 .53423 L F
.656 .194 .145 r
.23345 .55683 m .23808 .55682 L .23524 .55779 L F
.686 .411 .5 r
.23808 .55682 m .2376 .5593 L .23524 .55779 L F
.693 .504 .627 r
.23524 .55779 m .23082 .55691 L .23345 .55683 L F
.23524 .55779 m .23131 .55918 L .23082 .55691 L F
.267 0 0 r
.23524 .55779 m .23314 .55957 L .23131 .55918 L F
.078 .639 .733 r
.2376 .5593 m .23314 .55957 L .23524 .55779 L F
.656 .194 .145 r
.23345 .55683 m .23677 .55906 L .23808 .55682 L F
.391 .144 .415 r
.23958 .55852 m .23808 .55682 L .24017 .55584 L F
0 0 0 r
.23808 .55682 m .23807 .557 L .24017 .55584 L F
.23808 .55682 m .23677 .55906 L .23807 .557 L F
.391 .144 .415 r
.23958 .55852 m .2376 .5593 L .23808 .55682 L F
.005 0 .426 r
.31085 .5476 m .30927 .5493 L .30938 .54684 L F
.389 0 0 r
.3398 .57891 m .34186 .57981 L .33904 .57831 L F
.424 .44 .772 r
.33904 .57831 m .34066 .57856 L .33864 .57428 L F
.463 .316 .596 r
.33904 .57831 m .34186 .57981 L .34066 .57856 L F
.389 0 0 r
.3398 .57891 m .33904 .57831 L .33839 .57605 L F
.247 0 .273 r
.16723 .57167 m .16459 .57463 L .16647 .57384 L F
.235 0 .268 r
.16723 .57167 m .16832 .57297 L .16941 .57109 L F
.16723 .57167 m .16647 .57384 L .16832 .57297 L F
.277 .578 .941 r
.18144 .60847 m .18607 .61117 L .18349 .60808 L F
.305 .536 .91 r
.18349 .60808 m .18607 .61117 L .18746 .61102 L F
.619 .958 .886 r
.23684 .54828 m .23647 .54939 L .2384 .54999 L F
.23684 .54828 m .23489 .54957 L .23647 .54939 L F
.581 .432 .644 r
.31637 .60862 m .31685 .61147 L .31424 .61166 L F
.432 .005 .126 r
.31424 .61166 m .31586 .61352 L .31377 .61404 L F
.594 .527 .749 r
.31424 .61166 m .31707 .6146 L .31685 .61147 L F
.432 .005 .126 r
.31424 .61166 m .31685 .61147 L .31586 .61352 L F
.581 .432 .644 r
.31637 .60862 m .31685 .61147 L .31424 .61166 L F
.616 .714 .915 r
.49583 .55579 m .49569 .55925 L .49559 .55706 L F
.49583 .55579 m .49873 .55875 L .49603 .55919 L F
.77 .651 .73 r
.49873 .55875 m .4964 .56063 L .49569 .55925 L F
.49873 .55875 m .49948 .56201 L .4964 .56063 L F
.777 .317 .152 r
.49948 .56201 m .49802 .5622 L .4964 .56063 L F
0 0 .203 r
.4964 .56063 m .49652 .56076 L .49559 .55707 L F
.49559 .55708 m .49559 .55707 L .49559 .55706 L F
.616 .714 .915 r
.49583 .55579 m .49603 .55919 L .49575 .55784 L F
0 0 .203 r
.4964 .56063 m .49559 .55707 L .49559 .55708 L F
.616 .714 .915 r
.49575 .55784 m .49603 .55919 L .49569 .55925 L F
0 0 .203 r
.4964 .56063 m .49559 .55706 L .49569 .55925 L F
.581 .831 .992 r
.25987 .7013 m .26244 .70081 L .26013 .70007 L F
.837 .967 .644 r
.25848 .70286 m .25987 .7013 L .26013 .70007 L F
.298 .776 .925 r
.26175 .53167 m .26139 .53247 L .25945 .53204 L F
.26175 .53167 m .26371 .53216 L .26139 .53247 L F
.238 0 .093 r
.19144 .55206 m .19328 .5522 L .1946 .54988 L F
.185 0 .065 r
.1946 .54988 m .19529 .55145 L .19675 .5491 L F
.1946 .54988 m .19328 .5522 L .19529 .55145 L F
.316 .383 .773 r
.16097 .58965 m .16213 .59323 L .16374 .59189 L F
.396 .346 .684 r
.16227 .59586 m .16374 .59189 L .16213 .59323 L F
.04 .066 .56 r
.27129 .62877 m .2702 .63105 L .26985 .62657 L F
.492 .616 .902 r
.27129 .62877 m .27315 .63133 L .2702 .63105 L F
.863 .574 .046 r
.18776 .58905 m .18845 .59144 L .18807 .58966 L F
.887 .624 .535 r
.18697 .58749 m .186 .58948 L .18798 .58965 L F
.18793 .58937 m .18798 .58965 L .18807 .58966 L F
.18697 .58749 m .18798 .58965 L .18793 .58937 L F
.863 .574 .046 r
.18776 .58905 m .18789 .59135 L .18835 .59142 L F
.1881 .59023 m .18835 .59142 L .18845 .59144 L F
.18776 .58905 m .18835 .59142 L .1881 .59023 L F
0 0 0 r
.27868 .67268 m .28149 .66988 L .2806 .67295 L F
.206 .288 .728 r
.28311 .66927 m .28149 .66988 L .28081 .66698 L F
.01 0 .176 r
.2806 .67295 m .28149 .66988 L .28311 .66927 L F
.806 .972 .672 r
.33237 .5654 m .33299 .56609 L .33504 .56599 L F
0 0 0 r
.3381 .56342 m .33749 .56529 L .33504 .56599 L F
.082 .642 .764 r
.33749 .56529 m .33237 .5654 L .33504 .56599 L F
.134 .574 .925 r
.19243 .59401 m .19077 .59429 L .18939 .59286 L F
.468 .259 .512 r
.31384 .62398 m .31619 .62341 L .31633 .621 L F
.478 .286 .541 r
.31384 .62398 m .31598 .62598 L .31619 .62341 L F
.31384 .62398 m .31371 .62674 L .31598 .62598 L F
.416 .607 .927 r
.19568 .61602 m .19639 .61825 L .19746 .61649 L F
.208 .331 .771 r
.19639 .61825 m .19879 .62016 L .19746 .61649 L F
.367 .488 .85 r
.34797 .56238 m .3491 .5654 L .35063 .56398 L F
.127 .038 .476 r
.3491 .5654 m .35083 .56609 L .35063 .56398 L F
.3491 .5654 m .3492 .56809 L .35083 .56609 L F
.308 .639 .966 r
.50696 .56879 m .50797 .56744 L .50566 .56745 L F
.50696 .56879 m .50944 .5691 L .50797 .56744 L F
.447 .049 .191 r
.21443 .56105 m .21276 .55992 L .21451 .56059 L F
.21443 .56105 m .21194 .56141 L .21276 .55992 L F
.399 .694 .98 r
.19383 .70345 m .19539 .70428 L .19293 .70429 L F
.104 0 .106 r
.52616 .52752 m .52926 .52439 L .52765 .52426 L F
.779 .664 .737 r
.54175 .56534 m .54261 .56843 L .54485 .56513 L F
.344 0 0 r
.54791 .56231 m .5439 .56388 L .54485 .56513 L F
.242 0 .31 r
.16459 .57463 m .16561 .57624 L .16647 .57384 L F
.16459 .57463 m .16385 .5771 L .16561 .57624 L F
.558 .094 .108 r
.28364 .63346 m .28495 .63499 L .28678 .63329 L F
.971 .731 .516 r
.28495 .63499 m .28667 .63597 L .28678 .63329 L F
.745 .646 .087 r
.28647 .63707 m .28667 .63597 L .28495 .63499 L F
0 0 .565 r
.28533 .63371 m .2863 .63657 L .28495 .63499 L F
.2863 .63657 m .28647 .63707 L .28495 .63499 L F
.558 .094 .108 r
.28289 .6335 m .28495 .63499 L .28364 .63346 L F
.632 .456 .626 r
.28667 .63597 m .2892 .63285 L .28678 .63329 L F
0 0 .542 r
.27044 .62689 m .27129 .62877 L .26985 .62657 L F
.005 0 .072 r
.27195 .62427 m .27044 .62689 L .26985 .62657 L F
.256 .387 .804 r
.5371 .54675 m .53848 .55007 L .53982 .54817 L F
.8 .449 .392 r
.77991 .40453 m .77895 .40136 L .77568 .40094 L F
.68 .975 .806 r
.78207 .39878 m .77895 .40136 L .78035 .3998 L F
.636 .499 .679 r
.77991 .40453 m .78035 .3998 L .77895 .40136 L F
.743 .658 .766 r
.2847 .65766 m .2831 .66141 L .28123 .65683 L F
.168 .316 .771 r
.28406 .65981 m .2831 .66141 L .28123 .65683 L F
.319 .517 .892 r
.28524 .66165 m .2831 .66141 L .28406 .65981 L F
.285 0 .196 r
.20364 .56522 m .20125 .56565 L .20336 .56465 L F
.20364 .56522 m .20045 .56723 L .20125 .56565 L F
.545 .765 .979 r
.34547 .55551 m .35027 .5561 L .34873 .55253 L F
.383 .139 .415 r
.35027 .5561 m .35241 .55504 L .34873 .55253 L F
.35027 .5561 m .35251 .55546 L .35241 .55504 L F
.461 .336 .623 r
.35027 .5561 m .35268 .55829 L .35251 .55546 L F
.467 .336 .619 r
.35049 .55886 m .35268 .55829 L .35027 .5561 L F
.642 .894 .985 r
.30917 .55941 m .3123 .55912 L .31079 .55869 L F
.543 .566 .828 r
.31102 .55568 m .3123 .55912 L .31421 .55778 L F
.162 .316 .773 r
.31102 .55568 m .3123 .55912 L .31305 .55741 L F
.73 .967 .935 r
.31305 .55741 m .31079 .55869 L .3123 .55912 L F
.656 .895 .982 r
.31305 .55741 m .3123 .55912 L .31421 .55778 L F
.48 .084 .212 r
.28003 .59187 m .28373 .59036 L .27967 .58957 L F
.28003 .59187 m .28219 .59227 L .28373 .59036 L F
.389 0 .148 r
.28373 .59036 m .28493 .59153 L .28619 .58974 L F
.28373 .59036 m .28219 .59227 L .28493 .59153 L F
0 .089 .644 r
.31646 .59578 m .31835 .59808 L .31788 .59923 L F
.45 .137 .342 r
.31973 .6007 m .31788 .59923 L .31835 .59808 L F
.31973 .6007 m .31738 .60153 L .31788 .59923 L F
.281 .344 .75 r
.29262 .55491 m .29304 .55155 L .29178 .5533 L F
.466 .669 .951 r
.20994 .61421 m .20946 .61582 L .20816 .61406 L F
.20994 .61421 m .21219 .61633 L .20946 .61582 L F
.024 .39 .849 r
.27307 .556 m .27328 .55478 L .27208 .55447 L F
.393 .777 .99 r
.27573 .55589 m .27328 .55478 L .27307 .556 L F
.537 .263 .448 r
.29952 .56467 m .30243 .56212 L .30036 .56286 L F
.47 .804 .999 r
.29671 .53197 m .29267 .53151 L .29465 .53178 L F
.363 .818 .935 r
.29714 .5311 m .29671 .53197 L .29465 .53178 L F
.29714 .5311 m .2989 .53149 L .29671 .53197 L F
.665 .633 .808 r
.33017 .58629 m .33168 .58992 L .3273 .58944 L F
0 0 0 r
.3273 .58944 m .32907 .58859 L .33017 .58629 L F
.685 .426 .524 r
.3273 .58944 m .33143 .59217 L .32889 .5922 L F
.3273 .58944 m .33168 .58992 L .33143 .59217 L F
.064 0 .098 r
.32689 .59074 m .32907 .58859 L .3273 .58944 L F
.054 .06 .545 r
.33944 .56144 m .33992 .56341 L .3381 .56342 L F
.556 .298 .48 r
.33992 .56341 m .33749 .56529 L .3381 .56342 L F
.273 .195 .583 r
.30995 .57781 m .31158 .57971 L .31224 .57703 L F
.30995 .57781 m .31023 .58047 L .31158 .57971 L F
.774 .686 .767 r
.22884 .55868 m .22504 .55826 L .2276 .55721 L F
.735 .35 .323 r
.22884 .55868 m .22695 .56076 L .22504 .55826 L F
.488 .019 .066 r
.23131 .55918 m .22695 .56076 L .22884 .55868 L F
.629 .463 .638 r
.23082 .55691 m .23131 .55918 L .22884 .55868 L F
.318 0 .131 r
.34887 .54992 m .3511 .54988 L .35041 .54954 L F
.388 .211 .516 r
.35121 .54729 m .3511 .54988 L .34887 .54992 L F
.156 0 0 r
.3511 .54988 m .34932 .55066 L .34887 .54992 L F
.418 .824 .978 r
.29304 .55155 m .29506 .55108 L .29478 .55223 L F
0 0 .563 r
.29506 .55108 m .29657 .5547 L .29478 .55223 L F
.458 .715 .979 r
.23541 .73775 m .23896 .73893 L .23682 .73777 L F
.477 .797 .999 r
.23682 .73777 m .23896 .73893 L .24127 .73848 L F
.001 0 0 r
.2278 .53586 m .23185 .53569 L .22956 .53522 L F
.514 .264 .473 r
.28323 .60523 m .28699 .6019 L .28545 .60463 L F
.07 0 .042 r
.28724 .60369 m .28699 .6019 L .28744 .60023 L F
.28724 .60369 m .28545 .60463 L .28699 .6019 L F
.991 .73 .405 r
.27691 .55917 m .2772 .56242 L .2758 .55992 L F
0 .153 .672 r
.27651 .55798 m .27691 .55917 L .2758 .55992 L F
.27651 .55798 m .27936 .56129 L .27691 .55917 L F
.477 .344 .621 r
.27936 .56129 m .2772 .56242 L .27691 .55917 L F
.508 .484 .765 r
.31633 .621 m .31874 .62041 L .31727 .6176 L F
.425 .224 .502 r
.31633 .621 m .31863 .62245 L .31874 .62041 L F
.31633 .621 m .31619 .62341 L .31863 .62245 L F
.496 .759 .989 r
.30678 .53339 m .30275 .53254 L .30526 .53243 L F
.464 .818 .997 r
.30797 .53224 m .30678 .53339 L .30526 .53243 L F
.30797 .53224 m .30905 .5329 L .30678 .53339 L F
.207 0 .243 r
.29338 .59173 m .29258 .59485 L .29038 .59472 L F
.244 .05 .407 r
.29225 .59739 m .29038 .59472 L .29258 .59485 L F
.29225 .59739 m .2899 .59877 L .29038 .59472 L F
.508 .562 .846 r
.18845 .58617 m .18697 .58749 L .18465 .58307 L F
.787 .492 .488 r
.18776 .58905 m .18697 .58749 L .18845 .58617 L F
.18776 .58905 m .186 .58948 L .18697 .58749 L F
.607 .657 .873 r
.33219 .6397 m .33415 .64315 L .33602 .64198 L F
.538 0 0 r
.28707 .54738 m .28892 .54865 L .28722 .54785 L F
.444 .105 .294 r
.28942 .54682 m .28892 .54865 L .28707 .54738 L F
.615 .615 .828 r
.26597 .68578 m .26834 .68489 L .2671 .68169 L F
.765 .639 .722 r
.3259 .63902 m .32977 .64158 L .32909 .63972 L F
.3259 .63902 m .3272 .64288 L .32977 .64158 L F
.596 .637 .862 r
.32909 .63972 m .32977 .64158 L .33219 .6397 L F
.225 .674 .952 r
.21594 .61698 m .21573 .61784 L .21406 .61661 L F
.21594 .61698 m .21778 .61792 L .21573 .61784 L F
.23 .371 .8 r
.23851 .7228 m .24096 .72429 L .23958 .72124 L F
.218 0 0 r
.33762 .57599 m .33839 .57605 L .3378 .57432 L F
.718 .422 .475 r
.32193 .65103 m .31909 .64898 L .32219 .64872 L F
.32193 .65103 m .31834 .65112 L .31909 .64898 L F
.466 .856 .978 r
.34547 .55551 m .34461 .55452 L .34226 .55528 L F
.891 .99 .76 r
.3471 .55133 m .34547 .55551 L .34873 .55253 L F
.033 0 0 r
.30905 .5329 m .3116 .53285 L .31285 .53272 L F
.309 0 0 r
.3116 .53285 m .31597 .53335 L .31285 .53272 L F
0 0 0 r
.25858 .62347 m .25984 .62297 L .26055 .62262 L F
.25858 .62347 m .25691 .62564 L .25984 .62297 L F
.117 .645 .874 r
.244 .63703 m .24082 .63653 L .24263 .63745 L F
.21 0 .206 r
.19144 .55206 m .19238 .55408 L .19328 .5522 L F
.19144 .55206 m .19044 .55504 L .19238 .55408 L F
.733 .497 .571 r
.2276 .55721 m .23093 .55878 L .23082 .55691 L F
0 0 .296 r
.23082 .55691 m .23173 .55702 L .23345 .55683 L F
.23082 .55691 m .23093 .55878 L .23173 .55702 L F
.926 .974 .74 r
.3741 .56403 m .37473 .56153 L .37688 .56238 L F
.3741 .56403 m .37281 .56409 L .37473 .56153 L F
.162 0 .256 r
.34122 .63319 m .34096 .6362 L .33853 .63661 L F
.452 .844 .98 r
.26371 .53216 m .26596 .53152 L .26774 .53207 L F
.397 .83 .954 r
.26596 .53152 m .26989 .53141 L .26774 .53207 L F
.775 .662 .738 r
.53876 .56792 m .54261 .56843 L .54175 .56534 L F
.064 0 .049 r
.19897 .56956 m .19832 .56816 L .20045 .56723 L F
.19897 .56956 m .19718 .57062 L .19832 .56816 L F
.235 0 0 r
.29054 .626 m .29422 .62399 L .29089 .62421 L F
.29054 .626 m .29272 .62568 L .29422 .62399 L F
.165 0 0 r
.29422 .62399 m .29487 .62516 L .29657 .62393 L F
.29422 .62399 m .29272 .62568 L .29487 .62516 L F
.201 0 .12 r
.25401 .70855 m .25148 .71002 L .25358 .70984 L F
0 0 .418 r
.25148 .71002 m .2527 .71219 L .25358 .70984 L F
.25148 .71002 m .25214 .7142 L .2527 .71219 L F
.457 .193 .425 r
.19034 .57469 m .18971 .57727 L .18737 .57761 L F
.296 .05 .361 r
.19161 .57624 m .19034 .57469 L .19238 .57418 L F
.19161 .57624 m .18971 .57727 L .19034 .57469 L F
.03 0 0 r
.23185 .53569 m .2341 .53559 L .23621 .5353 L F
.421 .867 .841 r
.23621 .5353 m .2363 .53468 L .23839 .53468 L F
.23621 .5353 m .2341 .53559 L .2363 .53468 L F
.172 .704 .845 r
.24187 .62519 m .24428 .62502 L .24591 .62525 L F
0 .209 .651 r
.24647 .62542 m .24591 .62525 L .24428 .62502 L F
.24647 .62542 m .24805 .6266 L .24591 .62525 L F
.707 .52 .634 r
.2416 .73573 m .24432 .7348 L .24383 .73198 L F
.2416 .73573 m .24432 .7348 L .24383 .73198 L F
.401 .797 .986 r
.27198 .67252 m .26957 .67314 L .26787 .67241 L F
.271 .414 .823 r
.31787 .60739 m .31637 .60862 L .31505 .60557 L F
.755 .516 0 r
.31653 .61026 m .31685 .61147 L .31637 .60862 L F
.31653 .61026 m .31637 .60862 L .31787 .60739 L F
.279 .043 .367 r
.29758 .56561 m .29725 .56766 L .29952 .56467 L F
.705 .819 .936 r
.17014 .60246 m .17367 .60244 L .17201 .60109 L F
.17014 .60246 m .17367 .60244 L .17201 .60109 L F
.526 .761 .983 r
.17201 .60109 m .17367 .60244 L .17454 .60068 L F
.304 .491 .877 r
.17367 .60244 m .17488 .60199 L .17454 .60068 L F
.499 .778 .995 r
.27649 .63216 m .27315 .63133 L .27482 .63086 L F
.594 .808 .982 r
.27961 .63121 m .27649 .63216 L .27482 .63086 L F
.569 .08 .056 r
.28079 .63299 m .27649 .63216 L .27961 .63121 L F
.441 .42 .74 r
.27541 .67092 m .27544 .67209 L .27868 .67268 L F
.773 .268 0 r
.27629 .67449 m .27544 .67209 L .275 .67448 L F
.573 .605 .847 r
.3022 .57941 m .30305 .58363 L .30173 .58366 L F
0 0 0 r
.30243 .58359 m .30173 .58366 L .30305 .58363 L F
.717 .573 .692 r
.302 .5858 m .30468 .58373 L .30173 .58366 L F
0 0 0 r
.30243 .58359 m .29867 .58468 L .30173 .58366 L F
.91 .828 .752 r
.55105 .53679 m .54894 .54021 L .55143 .5401 L F
.945 .96 .699 r
.54928 .54227 m .55143 .5401 L .54894 .54021 L F
.54928 .54227 m .54971 .54346 L .55143 .5401 L F
.612 .345 .489 r
.37154 .57362 m .36943 .57152 L .37235 .57127 L F
.37154 .57362 m .36921 .57387 L .36943 .57152 L F
.921 .747 .649 r
.3552 .59025 m .35437 .59267 L .35297 .5892 L F
.298 .665 .973 r
.26856 .64075 m .26957 .64191 L .27139 .64193 L F
.614 .696 .902 r
.33999 .5383 m .33616 .53699 L .33818 .53728 L F
.671 .867 .973 r
.34223 .53719 m .33999 .5383 L .33818 .53728 L F
0 .496 .712 r
.3551 .54587 m .36037 .54666 L .35779 .54629 L F
.677 .373 .452 r
.35627 .54778 m .36037 .54666 L .35779 .54629 L F
.412 .105 .332 r
.32187 .57987 m .31945 .58068 L .3226 .57759 L F
.43 .21 .477 r
.32431 .57656 m .32187 .57987 L .3226 .57759 L F
.728 .76 .878 r
.352 .53975 m .35052 .54129 L .34848 .53946 L F
.498 .655 .93 r
.18144 .60847 m .1821 .60645 L .17961 .60749 L F
.18144 .60847 m .18349 .60808 L .1821 .60645 L F
.153 0 0 r
.20591 .54378 m .20172 .54645 L .20399 .54599 L F
.02 0 0 r
.20795 .54288 m .20591 .54378 L .20399 .54599 L F
.778 .669 .743 r
.27846 .65434 m .28061 .65168 L .27792 .65162 L F
.268 .378 .791 r
.28061 .65168 m .28354 .65385 L .28402 .65154 L F
.917 .787 .702 r
.78213 .40328 m .78514 .40117 L .78407 .39965 L F
.78213 .40328 m .78363 .40475 L .78514 .40117 L F
.691 .419 .507 r
.38548 .54669 m .38567 .54951 L .38276 .54888 L F
.333 .337 .714 r
.38537 .54317 m .38793 .54525 L .38548 .54669 L F
.175 .043 .451 r
.38765 .54767 m .38548 .54669 L .38793 .54525 L F
.38765 .54767 m .38567 .54951 L .38548 .54669 L F
.225 0 .329 r
.26007 .69212 m .25744 .69758 L .25525 .69379 L F
.764 .612 .69 r
.25525 .69379 m .26259 .69468 L .26007 .69212 L F
.306 .299 .687 r
.30223 .60076 m .3032 .59862 L .3025 .59931 L F
.584 .504 .731 r
.33367 .59954 m .33632 .59906 L .33545 .59558 L F
.606 .458 .655 r
.33367 .59954 m .33676 .60172 L .33632 .59906 L F
.33367 .59954 m .33408 .60222 L .33676 .60172 L F
.425 .307 .615 r
.31953 .58322 m .31961 .58569 L .3174 .584 L F
.528 .874 .989 r
.24413 .71521 m .2436 .71651 L .24165 .71582 L F
.24413 .71521 m .2436 .71651 L .24165 .71582 L F
.194 0 .01 r
.18611 .55637 m .18506 .55775 L .18823 .5557 L F
.473 .828 .996 r
.32582 .53621 m .32797 .53558 L .32978 .53636 L F
.437 .757 .995 r
.33019 .53492 m .32978 .53636 L .32797 .53558 L F
.33019 .53492 m .33201 .53614 L .32978 .53636 L F
.646 .55 .731 r
.35074 .60511 m .35187 .60863 L .34838 .6081 L F
.399 .153 .421 r
.31357 .61647 m .31144 .61456 L .31377 .61404 L F
.31357 .61647 m .31096 .6171 L .31144 .61456 L F
.141 0 .344 r
.28471 .6067 m .28323 .60523 L .28545 .60463 L F
.28471 .6067 m .28229 .60808 L .28323 .60523 L F
.449 .844 .979 r
.23839 .53468 m .24062 .53412 L .2424 .53465 L F
.26 .74 .932 r
.24062 .53412 m .24472 .5345 L .2424 .53465 L F
0 0 0 r
.27826 .54457 m .2768 .54524 L .2789 .54417 L F
.27826 .54457 m .27584 .54593 L .2768 .54524 L F
.069 0 0 r
.28396 .54867 m .28217 .5498 L .27925 .55022 L F
.717 .367 .384 r
.28722 .54785 m .28217 .5498 L .28396 .54867 L F
.381 .763 .99 r
.26989 .53141 m .27223 .53119 L .27409 .53218 L F
.279 .751 .939 r
.27223 .53119 m .27641 .53157 L .27409 .53218 L F
.464 .519 .83 r
.33372 .58917 m .33168 .58992 L .33017 .58629 L F
.308 .105 .434 r
.33143 .59217 m .33168 .58992 L .33372 .58917 L F
.915 .781 .698 r
.36986 .53792 m .36769 .53734 L .36938 .53547 L F
.36986 .53792 m .36892 .54033 L .36769 .53734 L F
.665 .719 .889 r
.5006 .55863 m .49948 .56201 L .49873 .55875 L F
.5006 .55863 m .50179 .56152 L .49948 .56201 L F
.182 .492 .903 r
.50044 .56326 m .49802 .5622 L .49948 .56201 L F
.172 .579 .937 r
.21803 .63048 m .21841 .62947 L .21657 .62926 L F
.21803 .63048 m .21943 .63014 L .21841 .62947 L F
.29 .662 .971 r
.21937 .63115 m .21943 .63014 L .21803 .63048 L F
.445 .659 .952 r
.51076 .56349 m .50961 .56531 L .5085 .56362 L F
.426 .634 .942 r
.51076 .56349 m .51197 .565 L .50961 .56531 L F
0 0 .005 r
.27342 .62306 m .27044 .62689 L .27195 .62427 L F
.283 .785 .824 r
.27641 .53157 m .27871 .531 L .28023 .5309 L F
.304 .795 .873 r
.27871 .531 m .28257 .53055 L .28023 .5309 L F
.869 .869 .835 r
.33936 .63226 m .34122 .63319 L .34369 .63013 L F
.938 .587 .329 r
.33936 .63226 m .34096 .6362 L .34122 .63319 L F
.66 .149 .019 r
.31928 .61377 m .31685 .61147 L .31707 .6146 L F
.032 0 .082 r
.31928 .61377 m .31707 .6146 L .31766 .61571 L F
.651 .809 .372 r
.53794 .55945 m .53619 .56261 L .53716 .56078 L F
.53794 .55945 m .53619 .56261 L .53716 .56078 L F
.365 .607 .942 r
.53794 .55945 m .54001 .5594 L .5386 .55753 L F
.344 0 0 r
.54791 .56231 m .54645 .56382 L .5439 .56388 L F
.871 .943 .577 r
.5482 .56016 m .54645 .56382 L .54791 .56231 L F
.989 .892 .603 r
.54995 .54865 m .54998 .55157 L .55061 .5495 L F
.984 .876 .518 r
.55058 .54612 m .54995 .54865 L .55061 .5495 L F
.65 .422 .561 r
.35986 .60233 m .35964 .60492 L .35707 .60497 L F
.506 .457 .737 r
.36228 .60154 m .35986 .60233 L .35935 .59933 L F
.424 .232 .513 r
.36191 .60403 m .35986 .60233 L .36228 .60154 L F
.36191 .60403 m .35964 .60492 L .35986 .60233 L F
0 0 0 r
.331 .56071 m .33485 .55874 L .33056 .55908 L F
.331 .56071 m .33341 .55993 L .33485 .55874 L F
.557 .103 .131 r
.33341 .55993 m .33769 .5585 L .33485 .55874 L F
.501 .295 .533 r
.36684 .57442 m .36673 .57702 L .36432 .57745 L F
.527 .432 .69 r
.36673 .57702 m .36473 .5801 L .36432 .57745 L F
.306 .299 .687 r
.30223 .60076 m .30394 .60079 L .3032 .59862 L F
.51 .488 .768 r
.30223 .60076 m .30481 .60317 L .30394 .60079 L F
.435 .23 .501 r
.50965 .5506 m .51197 .54925 L .51196 .54664 L F
0 0 .474 r
.51197 .54925 m .50965 .5506 L .51196 .54664 L F
.28 .781 .853 r
.51278 .54617 m .51452 .54611 L .51196 .54664 L F
.841 .436 .273 r
.51452 .54611 m .51196 .54664 L .51197 .54925 L F
.51452 .54611 m .51278 .54617 L .51196 .54664 L F
.49 .273 .51 r
.51452 .54611 m .51197 .54925 L .51196 .54664 L F
.918 .525 .149 r
.54906 .54494 m .54971 .54346 L .54928 .54227 L F
.54906 .54494 m .55058 .54612 L .54971 .54346 L F
0 0 0 r
.29362 .57761 m .29087 .58071 L .29251 .57927 L F
0 0 .299 r
.29125 .58338 m .29251 .57927 L .29087 .58071 L F
.548 .365 .585 r
.50925 .53431 m .51188 .53397 L .51158 .53174 L F
0 0 .224 r
.3107 .62251 m .31021 .62067 L .31098 .61903 L F
.3107 .62251 m .30988 .62338 L .31021 .62067 L F
.764 .996 .843 r
.32768 .5715 m .32419 .5723 L .32447 .57409 L F
0 0 .108 r
.32945 .5678 m .32884 .57029 L .32768 .5715 L F
.817 .557 .546 r
.32884 .57029 m .32419 .5723 L .32768 .5715 L F
.17 .687 .888 r
.21071 .54065 m .21192 .54077 L .21208 .54103 L F
.411 .858 .788 r
.21476 .5405 m .21231 .54138 L .21208 .54103 L F
.447 .881 .834 r
.21664 .53956 m .21476 .5405 L .21208 .54103 L F
.21664 .53956 m .21208 .54103 L .21469 .54105 L F
.17 .687 .888 r
.21192 .54077 m .21469 .54105 L .21208 .54103 L F
.411 .858 .788 r
.21231 .54138 m .21012 .54217 L .21208 .54103 L F
.545 .327 .534 r
.34837 .62077 m .34827 .62384 L .34489 .62426 L F
.578 .354 .539 r
.35123 .62322 m .34837 .62077 L .35047 .62038 L F
.35123 .62322 m .34827 .62384 L .34837 .62077 L F
.472 0 0 r
.29531 .55505 m .29406 .5555 L .29262 .55491 L F
0 0 0 r
.29657 .5547 m .29406 .5555 L .29531 .55505 L F
.279 .468 .866 r
.17488 .60199 m .17731 .60577 L .17803 .60389 L F
.158 .324 .781 r
.17731 .60577 m .17961 .60749 L .17803 .60389 L F
.485 .282 .529 r
.36921 .57387 m .36673 .57702 L .36684 .57442 L F
.316 .049 .341 r
.29251 .57927 m .29495 .57603 L .29362 .57761 L F
.145 .668 .881 r
.37396 .55471 m .37784 .55521 L .37555 .55441 L F
.89 .474 .2 r
.54755 .53074 m .54925 .53374 L .5507 .53435 L F
.932 .608 .403 r
.54919 .5356 m .5507 .53435 L .54925 .53374 L F
.54919 .5356 m .55105 .53679 L .5507 .53435 L F
.559 .489 .732 r
.18465 .58307 m .18231 .58372 L .1836 .58328 L F
.429 .302 .605 r
.29616 .62132 m .29848 .62247 L .29785 .62086 L F
.29616 .62132 m .29657 .62393 L .29848 .62247 L F
.52 .39 .644 r
.36782 .55211 m .36558 .55554 L .36522 .55282 L F
.36782 .55211 m .3686 .55555 L .36558 .55554 L F
.401 .396 .738 r
.3686 .5569 m .36558 .55554 L .3686 .55555 L F
.3686 .5569 m .367 .55783 L .36558 .55554 L F
.281 .344 .75 r
.29262 .55491 m .29406 .5555 L .29304 .55155 L F
.005 .565 .808 r
.21995 .61772 m .22412 .61851 L .22184 .61836 L F
.204 .67 .941 r
.26955 .55492 m .26779 .55402 L .26544 .55379 L F
.528 .845 .999 r
.26952 .55346 m .26955 .55492 L .27208 .55447 L F
.26952 .55346 m .26779 .55402 L .26955 .55492 L F
.869 .869 .835 r
.33936 .63226 m .34369 .63013 L .34177 .62829 L F
.636 .781 .951 r
.28163 .63154 m .28289 .6335 L .28079 .63299 L F
0 .206 .731 r
.28406 .6334 m .28495 .63499 L .28289 .6335 L F
.354 .06 .319 r
.18657 .57976 m .18439 .58057 L .18737 .57761 L F
.357 .063 .321 r
.18886 .57898 m .18737 .57761 L .18971 .57727 L F
.18886 .57898 m .18657 .57976 L .18737 .57761 L F
.346 .259 .613 r
.29828 .614 m .29757 .61796 L .30036 .61628 L F
.345 .205 .544 r
.29757 .61796 m .30043 .61927 L .30036 .61628 L F
.29757 .61796 m .29785 .62086 L .30043 .61927 L F
.323 .752 .972 r
.31755 .53407 m .32183 .5346 L .31934 .53513 L F
.755 .7 .16 r
.26244 .70081 m .26306 .69598 L .26462 .70038 L F
.423 .784 .996 r
.26013 .70007 m .26244 .70081 L .26462 .70038 L F
.392 .226 .534 r
.26442 .70306 m .26244 .70081 L .26462 .70038 L F
.26442 .70306 m .26237 .70408 L .26244 .70081 L F
.26442 .70306 m .26244 .70081 L .26462 .70038 L F
.26442 .70306 m .26237 .70408 L .26244 .70081 L F
.527 .432 .69 r
.36673 .57702 m .3672 .5797 L .36473 .5801 L F
.319 .19 .543 r
.3672 .5797 m .36508 .58364 L .36473 .5801 L F
.244 .727 .929 r
.28486 .53046 m .28665 .53099 L .28257 .53055 L F
.056 .543 .889 r
.28708 .53044 m .28665 .53099 L .28486 .53046 L F
.28708 .53044 m .28872 .53153 L .28665 .53099 L F
.364 0 .153 r
.25016 .55577 m .24862 .55827 L .2463 .55864 L F
.363 0 .115 r
.25262 .55551 m .24862 .55827 L .25016 .55577 L F
.037 .451 .876 r
.2781 .64351 m .27956 .64503 L .2797 .64401 L F
0 .322 .804 r
.27956 .64503 m .28104 .64589 L .2797 .64401 L F
.885 .641 .564 r
.52837 .53448 m .52527 .53384 L .52524 .53047 L F
.715 .62 .75 r
.52813 .5365 m .52527 .53384 L .52837 .53448 L F
.58 .272 .411 r
.53077 .5362 m .52837 .53448 L .53103 .53432 L F
.53077 .5362 m .52813 .5365 L .52837 .53448 L F
.337 .786 .955 r
.24472 .5345 m .24699 .53414 L .24876 .53468 L F
.503 .87 .983 r
.24876 .53468 m .24927 .53344 L .25099 .53394 L F
.24876 .53468 m .24699 .53414 L .24927 .53344 L F
.567 .427 .65 r
.32625 .60819 m .32864 .61074 L .32789 .60752 L F
.32625 .60819 m .32644 .61131 L .32864 .61074 L F
.335 .028 .288 r
.17411 .56735 m .17711 .56452 L .1751 .56517 L F
0 0 .038 r
.29546 .58923 m .29446 .5915 L .29338 .59173 L F
0 0 .086 r
.29446 .5915 m .29258 .59485 L .29338 .59173 L F
.367 .244 .578 r
.16238 .58044 m .16426 .58251 L .16393 .57979 L F
.16238 .58044 m .16249 .58325 L .16426 .58251 L F
.609 .866 .991 r
.26901 .67617 m .27349 .67605 L .27157 .67568 L F
.54 .637 .896 r
.27349 .67605 m .2763 .67656 L .275 .67448 L F
.698 .945 .959 r
.27157 .67568 m .27349 .67605 L .275 .67448 L F
.168 .316 .771 r
.28406 .65981 m .28123 .65683 L .2847 .65766 L F
.038 0 0 r
.2847 .65766 m .28677 .65785 L .28431 .65722 L F
.932 .801 .337 r
.28406 .65981 m .2847 .65766 L .28431 .65722 L F
.367 0 .126 r
.34489 .62426 m .34415 .62602 L .34176 .62647 L F
.584 .166 .215 r
.34842 .62554 m .34489 .62426 L .34827 .62384 L F
.34842 .62554 m .34415 .62602 L .34489 .62426 L F
.649 .555 .735 r
.33864 .57428 m .34066 .57856 L .34518 .57708 L F
.33864 .57428 m .34518 .57708 L .34587 .57258 L F
.459 .347 .64 r
.33963 .57362 m .33839 .57605 L .3378 .57432 L F
.33963 .57362 m .33839 .57605 L .3378 .57432 L F
.646 .377 .497 r
.33567 .5776 m .33839 .57605 L .33525 .57745 L F
.148 0 0 r
.22459 .75573 m .22886 .75557 L .22728 .75588 L F
.22459 .75573 m .22886 .75557 L .22728 .75588 L F
.417 .863 .803 r
.32551 .59353 m .32889 .5922 L .32663 .59277 L F
.135 0 0 r
.32889 .5922 m .32933 .5926 L .32663 .59277 L F
.32889 .5922 m .33143 .59217 L .32933 .5926 L F
.097 .212 .695 r
.50666 .56089 m .50556 .56254 L .50439 .55859 L F
.327 .532 .901 r
.50666 .56089 m .5085 .56362 L .50556 .56254 L F
.717 .573 .692 r
.302 .5858 m .30499 .58664 L .30468 .58373 L F
.236 .215 .631 r
.30468 .58373 m .30651 .58588 L .30761 .58364 L F
.30468 .58373 m .30499 .58664 L .30651 .58588 L F
.8 .449 .392 r
.77991 .40453 m .77568 .40094 L .77673 .40509 L F
.347 0 .095 r
.2186 .55827 m .21443 .56105 L .21451 .56059 L F
.2186 .55827 m .21673 .5606 L .21443 .56105 L F
.429 .009 .139 r
.22089 .55832 m .21673 .5606 L .2186 .55827 L F
.79 .802 .863 r
.2782 .67145 m .27932 .66816 L .27857 .66842 L F
.104 0 0 r
.28081 .66698 m .2781 .66858 L .27857 .66842 L F
0 .112 .665 r
.27904 .66347 m .28081 .66698 L .28127 .66603 L F
.63 .936 .699 r
.28127 .66603 m .28081 .66698 L .27857 .66842 L F
.79 .802 .863 r
.27932 .66816 m .27954 .66751 L .27857 .66842 L F
.104 0 0 r
.2781 .66858 m .27744 .66897 L .27857 .66842 L F
.206 .288 .728 r
.28311 .66927 m .28081 .66698 L .28337 .66725 L F
0 0 .299 r
.32607 .57389 m .32447 .57409 L .32419 .5723 L F
.32607 .57389 m .32431 .57656 L .32447 .57409 L F
.43 .871 .826 r
.25469 .53298 m .2555 .53223 L .25743 .53212 L F
.25469 .53298 m .25326 .53322 L .2555 .53223 L F
.464 .796 .999 r
.3035 .53125 m .30275 .53254 L .30105 .53121 L F
.3035 .53125 m .30526 .53243 L .30275 .53254 L F
.772 .592 .023 r
.53296 .54332 m .53289 .54471 L .53017 .54215 L F
.53296 .54332 m .5331 .54627 L .53289 .54471 L F
.625 .45 .626 r
.36782 .55211 m .36522 .55282 L .36776 .54964 L F
.563 .353 .553 r
.37079 .54934 m .36782 .55211 L .36776 .54964 L F
0 0 .212 r
.27808 .61665 m .27686 .61786 L .2787 .61432 L F
0 0 0 r
.27584 .6198 m .27686 .61786 L .27808 .61665 L F
.748 .537 .61 r
.3047 .63605 m .30907 .63588 L .30856 .63286 L F
.523 .345 .581 r
.30856 .63286 m .31095 .63219 L .31104 .62978 L F
.639 .511 .691 r
.30907 .63588 m .31095 .63219 L .30856 .63286 L F
.482 .319 .582 r
.51188 .53397 m .51426 .53317 L .51158 .53174 L F
.51188 .53397 m .51426 .53317 L .51158 .53174 L F
.751 .564 .643 r
.33514 .62374 m .33689 .62742 L .33547 .62416 L F
.768 .533 .577 r
.33197 .62345 m .33514 .62374 L .33528 .62412 L F
.829 .591 .578 r
.33514 .62374 m .33514 .62407 L .33528 .62412 L F
.33514 .62374 m .33665 .62771 L .33689 .62742 L F
.768 .533 .577 r
.33528 .62412 m .33514 .62374 L .33547 .62416 L F
.33197 .62345 m .33178 .62615 L .33478 .624 L F
.33197 .62345 m .33478 .624 L .33514 .62374 L F
.638 .757 .934 r
.33197 .62345 m .33515 .6241 L .33234 .62303 L F
.33515 .6241 m .33528 .62412 L .33514 .62407 L F
.33515 .6241 m .33514 .62407 L .33234 .62303 L F
.98 .742 .334 r
.33444 .62809 m .33524 .62944 L .33514 .62407 L F
.3351 .62397 m .33514 .62407 L .33514 .62374 L F
.638 .757 .934 r
.33528 .62412 m .33547 .62416 L .33234 .62303 L F
.98 .742 .334 r
.33444 .62809 m .33514 .62407 L .3351 .62397 L F
.33444 .62809 m .3351 .62397 L .33178 .62615 L F
.3351 .62397 m .33514 .62374 L .33478 .624 L F
.3351 .62397 m .33478 .624 L .33178 .62615 L F
.638 .757 .934 r
.33234 .62303 m .33497 .62398 L .33351 .62172 L F
.33497 .62398 m .33526 .62409 L .33517 .62397 L F
.33497 .62398 m .33517 .62397 L .33351 .62172 L F
.33526 .62409 m .33547 .62416 L .33543 .62412 L F
.33526 .62409 m .33543 .62412 L .33351 .62172 L F
.829 .591 .578 r
.33528 .62412 m .33524 .62944 L .33665 .62771 L F
.33514 .62407 m .33524 .62944 L .33528 .62412 L F
.623 .595 .801 r
.35279 .61685 m .35079 .6178 L .34943 .61464 L F
.291 .154 .516 r
.3525 .61915 m .35079 .6178 L .35279 .61685 L F
.3525 .61915 m .35047 .62038 L .35079 .6178 L F
.43 .735 .99 r
.35807 .59831 m .36132 .59921 L .35935 .59933 L F
.506 .457 .737 r
.36228 .60154 m .35935 .59933 L .36132 .59921 L F
.316 .383 .773 r
.16097 .58965 m .16374 .59189 L .16305 .58912 L F
.845 .994 .843 r
.3082 .60595 m .30657 .6083 L .30531 .60829 L F
.496 .26 .486 r
.35584 .54079 m .35649 .54322 L .35334 .54346 L F
.427 .445 .776 r
.35702 .53663 m .35584 .54079 L .35477 .53697 L F
.35702 .53663 m .35769 .54054 L .35584 .54079 L F
.568 .303 .474 r
.35844 .5425 m .35584 .54079 L .35769 .54054 L F
.35844 .5425 m .35649 .54322 L .35584 .54079 L F
.53 .758 .98 r
.30762 .60246 m .31372 .60446 L .30983 .60122 L F
0 .121 .668 r
.31372 .60446 m .31261 .60041 L .30983 .60122 L F
.775 .428 .399 r
.53599 .52436 m .5379 .52685 L .53971 .52475 L F
.67 .289 .316 r
.53971 .52475 m .5379 .52685 L .54208 .52682 L F
.529 0 0 r
.22332 .55527 m .2276 .55721 L .22504 .55826 L F
.22332 .55527 m .22569 .55691 L .2276 .55721 L F
.259 0 0 r
.22569 .55691 m .23093 .55878 L .2276 .55721 L F
.578 .731 .947 r
.33351 .62172 m .33547 .62416 L .33739 .62272 L F
.608 .498 .703 r
.33547 .62416 m .33689 .62742 L .34075 .62559 L F
.33547 .62416 m .34075 .62559 L .33851 .62524 L F
.472 .509 .815 r
.33547 .62416 m .33851 .62524 L .33739 .62272 L F
.385 .636 .954 r
.3369 .53521 m .33616 .53699 L .33485 .53523 L F
.291 .525 .906 r
.3369 .53521 m .33818 .53728 L .33616 .53699 L F
.397 .039 .235 r
.30761 .58364 m .30873 .58529 L .30997 .58307 L F
.30761 .58364 m .30651 .58588 L .30873 .58529 L F
.415 0 0 r
.23405 .62331 m .23589 .62388 L .23223 .62242 L F
0 .477 .77 r
.23623 .62372 m .23589 .62388 L .23405 .62331 L F
.23623 .62372 m .23824 .62443 L .23589 .62388 L F
.145 0 .357 r
.28026 .59553 m .28219 .59227 L .28003 .59187 L F
.25 .017 .352 r
.35 .56146 m .35268 .55829 L .35049 .55886 L F
.381 .043 .261 r
.32551 .59353 m .32508 .59515 L .32275 .59569 L F
.32275 .59569 m .32508 .59515 L .32551 .59353 L F
0 0 .024 r
.32551 .59353 m .32663 .59277 L .32689 .59074 L F
.32551 .59353 m .32508 .59515 L .32663 .59277 L F
.417 .863 .803 r
.32551 .59353 m .32663 .59277 L .32508 .59515 L F
.381 .043 .261 r
.32551 .59353 m .32508 .59515 L .32275 .59569 L F
.369 0 .161 r
.30575 .65116 m .30185 .65408 L .30328 .65148 L F
.588 .727 .94 r
.23071 .63503 m .2324 .63697 L .23466 .63629 L F
.61 .935 .725 r
.30463 .5817 m .30243 .58359 L .30305 .58363 L F
.031 0 0 r
.25939 .5537 m .2573 .55453 L .259 .55269 L F
.817 .808 .842 r
.78084 .40774 m .78213 .40328 L .77991 .40453 L F
.78084 .40774 m .78363 .40475 L .78213 .40328 L F
.319 .19 .543 r
.3672 .5797 m .3673 .58291 L .36508 .58364 L F
.104 .053 .509 r
.36683 .58474 m .36508 .58364 L .3673 .58291 L F
.36683 .58474 m .36534 .58643 L .36508 .58364 L F
.488 .019 .066 r
.23131 .55918 m .22934 .56098 L .22695 .56076 L F
.266 0 0 r
.23314 .55957 m .22934 .56098 L .23131 .55918 L F
.15 .353 .81 r
.2527 .71219 m .25214 .7142 L .25444 .71552 L F
.459 .286 .558 r
.25214 .7142 m .25202 .71838 L .25444 .71552 L F
.3 .551 .921 r
.21212 .61413 m .21219 .61633 L .20994 .61421 L F
.21212 .61413 m .21406 .61661 L .21219 .61633 L F
.775 .662 .738 r
.53876 .56792 m .54175 .56534 L .53868 .56534 L F
.66 .558 .728 r
.35435 .60792 m .35074 .60511 L .35444 .60533 L F
.523 .3 .517 r
.35707 .60497 m .35435 .60792 L .35444 .60533 L F
.351 .273 .627 r
.302 .5858 m .3041 .58844 L .30499 .58664 L F
.728 .591 .703 r
.3041 .58844 m .30651 .58588 L .30499 .58664 L F
.733 .48 .545 r
.20959 .56199 m .20913 .5646 L .20563 .56424 L F
.516 .278 .493 r
.21172 .56393 m .20959 .56199 L .21194 .56141 L F
.21172 .56393 m .20913 .5646 L .20959 .56199 L F
.144 .654 .9 r
.2385 .6364 m .23779 .63603 L .23658 .63577 L F
.2385 .6364 m .24082 .63653 L .23779 .63603 L F
.194 .035 .424 r
.31023 .58047 m .31134 .58194 L .31158 .57971 L F
.31023 .58047 m .30997 .58307 L .31134 .58194 L F
.156 .579 .933 r
.13341 .66249 m .13446 .66268 L .13526 .66384 L F
.793 .961 .919 r
.13526 .66384 m .13446 .66268 L .13329 .66364 L F
.632 .456 .626 r
.28667 .63597 m .28961 .63585 L .2892 .63285 L F
.686 .567 .716 r
.2892 .63285 m .29205 .63248 L .29174 .62965 L F
.464 .337 .622 r
.2892 .63285 m .29162 .63528 L .29205 .63248 L F
.2892 .63285 m .28961 .63585 L .29162 .63528 L F
.355 .415 .785 r
.20857 .6102 m .20816 .61406 L .20696 .61002 L F
.20857 .6102 m .20994 .61421 L .20816 .61406 L F
.424 .378 .703 r
.18845 .58617 m .19097 .58887 L .18776 .58905 L F
.375 .044 .271 r
.19097 .58887 m .18789 .59135 L .18776 .58905 L F
.641 .708 .896 r
.51197 .565 m .5134 .56601 L .51249 .56731 L F
0 0 .14 r
.5134 .56601 m .51258 .56853 L .51249 .56731 L F
.81 .917 .527 r
.28123 .65683 m .27923 .66076 L .28165 .66011 L F
.354 .18 .501 r
.27923 .66076 m .27904 .66347 L .28122 .66297 L F
.396 .346 .684 r
.16227 .59586 m .164 .5954 L .16374 .59189 L F
.118 .2 .674 r
.3334 .58097 m .33488 .58169 L .33567 .5776 L F
.3334 .58097 m .33541 .58514 L .33488 .58169 L F
.81 .79 .835 r
.50439 .55859 m .50179 .56152 L .5006 .55863 L F
.621 .545 .747 r
.28402 .65154 m .28685 .65105 L .28559 .64753 L F
.404 0 .121 r
.28501 .65313 m .28402 .65154 L .28354 .65385 L F
.28501 .65313 m .28685 .65105 L .28402 .65154 L F
.525 0 0 r
.23807 .557 m .24111 .55729 L .24017 .55584 L F
.523 .55 .825 r
.37136 .55804 m .37361 .5616 L .37062 .56205 L F
.505 .312 .553 r
.37281 .56409 m .37062 .56205 L .37361 .5616 L F
.37281 .56409 m .37018 .56488 L .37062 .56205 L F
.425 .638 .945 r
.49945 .55682 m .49873 .55875 L .49583 .55579 L F
.319 .516 .891 r
.5006 .55863 m .49873 .55875 L .49945 .55682 L F
.609 .473 .67 r
.33408 .60222 m .33436 .60493 L .33676 .60172 L F
0 0 0 r
.221 .53776 m .22573 .53704 L .22345 .53761 L F
.481 .78 .997 r
.26146 .54956 m .26409 .54936 L .2619 .54793 L F
.341 0 0 r
.26146 .54956 m .26359 .55015 L .26409 .54936 L F
.923 .635 .479 r
.2619 .54793 m .26359 .55015 L .26146 .54956 L F
.351 .273 .627 r
.302 .5858 m .30194 .58994 L .3041 .58844 L F
.3 0 0 r
.27046 .6802 m .2671 .68169 L .26808 .68153 L F
.042 0 0 r
.27123 .68029 m .27046 .6802 L .26808 .68153 L F
.27123 .68029 m .27288 .68014 L .27046 .6802 L F
.162 0 0 r
.32436 .61265 m .32311 .61222 L .32112 .61268 L F
.32436 .61265 m .32403 .61232 L .32311 .61222 L F
.298 0 0 r
.32311 .61222 m .32403 .61232 L .32644 .61131 L F
.431 .643 .946 r
.19987 .60018 m .19894 .60198 L .1975 .60024 L F
.362 .558 .909 r
.19987 .60018 m .20114 .60246 L .19894 .60198 L F
.231 0 .104 r
.19977 .54698 m .19892 .54836 L .20172 .54645 L F
.157 0 .007 r
.18294 .55843 m .18347 .55995 L .18506 .55775 L F
.18294 .55843 m .18147 .56064 L .18347 .55995 L F
0 0 .305 r
.24395 .73791 m .24432 .7348 L .2452 .73415 L F
.44 .234 .502 r
.30313 .54948 m .30072 .55263 L .30288 .55199 L F
.708 .232 0 r
.30072 .55263 m .30092 .55369 L .30288 .55199 L F
.233 .024 .378 r
.35334 .54346 m .35387 .54703 L .35121 .54729 L F
.727 .355 .344 r
.3551 .54587 m .35422 .54683 L .35334 .54346 L F
.838 .96 .624 r
.35392 .54701 m .3551 .54587 L .35395 .54658 L F
.35379 .54839 m .3551 .54587 L .35392 .54701 L F
.727 .355 .344 r
.35422 .54683 m .35389 .54718 L .35387 .54705 L F
.834 .999 .817 r
.35392 .54697 m .35374 .54719 L .35379 .54839 L F
.658 .431 .564 r
.35379 .54839 m .35121 .54729 L .35374 .54719 L F
.834 .999 .817 r
.35374 .54719 m .35283 .54831 L .35379 .54839 L F
.658 .431 .564 r
.35379 .54839 m .35374 .54719 L .35389 .54718 L F
.727 .355 .344 r
.35392 .54701 m .35387 .54705 L .35387 .54703 L F
.35422 .54683 m .35387 .54705 L .35392 .54701 L F
.35422 .54683 m .35387 .54703 L .35334 .54346 L F
.834 .999 .817 r
.35353 .54723 m .35246 .54829 L .35283 .54831 L F
.233 .024 .378 r
.35387 .54703 m .35374 .54719 L .35121 .54729 L F
.834 .999 .817 r
.35395 .54658 m .35322 .54742 L .35353 .54723 L F
.35322 .54742 m .35246 .54829 L .35353 .54723 L F
.35395 .54658 m .35283 .54831 L .35392 .54697 L F
.233 .024 .378 r
.35387 .54703 m .35389 .54718 L .35374 .54719 L F
.727 .355 .344 r
.3551 .54587 m .35334 .54346 L .35649 .54322 L F
.775 .732 .813 r
.36769 .53734 m .36892 .54033 L .366 .53939 L F
.755 .28 .117 r
.36892 .54033 m .36753 .54105 L .366 .53939 L F
0 0 .23 r
.36892 .54033 m .36887 .54291 L .36968 .541 L F
.36892 .54033 m .36968 .541 L .36753 .54105 L F
.784 .704 .775 r
.32688 .63232 m .32441 .63545 L .32863 .63577 L F
0 .139 .679 r
.32441 .63545 m .3259 .63902 L .32863 .63577 L F
.706 .562 .689 r
.3259 .63902 m .32909 .63972 L .32863 .63577 L F
.469 .75 .991 r
.32863 .63577 m .32825 .63379 L .32688 .63232 L F
.32863 .63577 m .33075 .63535 L .32825 .63379 L F
.136 .14 .598 r
.32863 .63577 m .33032 .63733 L .33075 .63535 L F
.32863 .63577 m .32909 .63972 L .33032 .63733 L F
.861 .496 .356 r
.54592 .53243 m .54755 .53074 L .54552 .53029 L F
.54592 .53243 m .54925 .53374 L .54755 .53074 L F
.201 0 .247 r
.29828 .614 m .29993 .61358 L .30077 .61141 L F
.346 .259 .613 r
.29828 .614 m .30036 .61628 L .29993 .61358 L F
.933 .73 .604 r
.53736 .56414 m .53876 .56792 L .53868 .56534 L F
.391 .623 .945 r
.29103 .66268 m .28897 .66308 L .28702 .66089 L F
.563 0 0 r
.28768 .6619 m .29103 .66268 L .28702 .66089 L F
.28789 .66222 m .28882 .66236 L .28768 .6619 L F
.28882 .66236 m .29103 .66268 L .28768 .6619 L F
.768 .584 .65 r
.28906 .66235 m .29311 .66233 L .28892 .66024 L F
.391 .623 .945 r
.29103 .66268 m .28961 .66379 L .28897 .66308 L F
.534 .186 .325 r
.28337 .66725 m .28685 .66659 L .28558 .66851 L F
.595 .278 .401 r
.28685 .66659 m .2889 .66875 L .28509 .66924 L F
.28685 .66659 m .28952 .6665 L .2889 .66875 L F
.659 .715 .89 r
.28476 .66569 m .28881 .66798 L .28944 .66474 L F
.28881 .66798 m .28916 .66818 L .28918 .66792 L F
.119 .123 .587 r
.2913 .66576 m .28961 .66379 L .29103 .66268 L F
.307 .158 .509 r
.2913 .66576 m .28952 .6665 L .28961 .66379 L F
.659 .715 .89 r
.28881 .66798 m .28918 .66792 L .2894 .66525 L F
.28937 .66524 m .2894 .66525 L .28943 .66496 L F
.28881 .66798 m .2894 .66525 L .28937 .66524 L F
.28935 .66521 m .28943 .66496 L .2894 .66497 L F
.28881 .66798 m .28938 .6652 L .28935 .66521 L F
.28938 .6652 m .28943 .66496 L .28935 .66521 L F
.577 .26 .395 r
.2889 .66875 m .28952 .6665 L .29154 .66856 L F
.257 .613 .956 r
.28368 .66544 m .28916 .66818 L .28476 .66569 L F
.724 .206 0 r
.28411 .66681 m .28916 .66818 L .28368 .66544 L F
.81 .844 .876 r
.28873 .66502 m .28916 .66818 L .28411 .66681 L F
.659 .715 .89 r
.2894 .66497 m .28943 .66496 L .28944 .66474 L F
.81 .844 .876 r
.28944 .66474 m .2894 .66525 L .28873 .66502 L F
.2894 .66525 m .28916 .66818 L .28881 .66562 L F
.28934 .66523 m .28881 .66562 L .28873 .66502 L F
.2894 .66525 m .28881 .66562 L .28934 .66523 L F
.28944 .66474 m .28411 .66681 L .28906 .66731 L F
.28954 .6656 m .28906 .66731 L .28974 .66738 L F
.978 .765 .548 r
.28944 .66553 m .2913 .66576 L .28951 .66523 L F
.81 .844 .876 r
.2895 .66526 m .28944 .66553 L .28954 .6656 L F
.28944 .66553 m .28906 .66731 L .28954 .6656 L F
.28944 .66474 m .28906 .66731 L .2895 .66526 L F
.349 .252 .602 r
.29154 .66856 m .28952 .6665 L .2913 .66576 L F
.29154 .66856 m .28952 .6665 L .2913 .66576 L F
.447 .842 .98 r
.29205 .66755 m .29154 .66856 L .2913 .66576 L F
.671 .477 .613 r
.2895 .66526 m .28926 .66551 L .28944 .66474 L F
.978 .765 .548 r
.28926 .66551 m .28944 .66553 L .2895 .66526 L F
.447 .842 .98 r
.29155 .66636 m .29106 .66611 L .28926 .66551 L F
.29106 .66611 m .2901 .66561 L .28926 .66551 L F
.671 .477 .613 r
.28954 .6656 m .28926 .66551 L .2895 .66526 L F
.28974 .66738 m .28926 .66551 L .28954 .6656 L F
.978 .765 .548 r
.28926 .66551 m .2895 .66526 L .28951 .66523 L F
.447 .842 .98 r
.29205 .66755 m .29197 .66735 L .28926 .66551 L F
.29197 .66735 m .29155 .66636 L .28957 .66562 L F
.29197 .66735 m .28957 .66562 L .28926 .66551 L F
.978 .765 .548 r
.28951 .66523 m .2913 .66576 L .29109 .66343 L F
0 0 0 r
.29481 .66137 m .29375 .66197 L .28926 .66551 L F
.29375 .66197 m .29311 .66233 L .29181 .6634 L F
.29375 .66197 m .29181 .6634 L .28926 .66551 L F
.978 .765 .548 r
.28926 .66551 m .29109 .66343 L .29103 .66268 L F
0 0 0 r
.29481 .66137 m .29311 .66233 L .29047 .66451 L F
.29131 .66398 m .29047 .66451 L .28926 .66551 L F
.29481 .66137 m .29047 .66451 L .29131 .66398 L F
.447 .842 .98 r
.29155 .66636 m .2913 .66576 L .2901 .66561 L F
.978 .765 .548 r
.29047 .66451 m .29103 .66268 L .29311 .66233 L F
.28926 .66551 m .28967 .66486 L .29047 .66451 L F
.28967 .66486 m .29103 .66268 L .29047 .66451 L F
.534 .186 .325 r
.2846 .66867 m .28558 .66851 L .28509 .66924 L F
.28337 .66725 m .28558 .66851 L .2846 .66867 L F
.659 .715 .89 r
.28476 .66569 m .28944 .66474 L .28893 .66391 L F
.28703 .66317 m .28893 .66391 L .28789 .66222 L F
.28476 .66569 m .28893 .66391 L .28703 .66317 L F
.768 .584 .65 r
.28917 .664 m .2917 .66349 L .28907 .66245 L F
.28926 .66551 m .29047 .66451 L .28917 .664 L F
.29047 .66451 m .2917 .66349 L .28917 .664 L F
.28926 .66551 m .28789 .66222 L .28944 .66474 L F
.28926 .66551 m .28906 .66235 L .28789 .66222 L F
.28906 .66235 m .28892 .66024 L .28789 .66222 L F
.259 .756 .9 r
.28906 .66235 m .29103 .66268 L .28882 .66236 L F
.29282 .66233 m .29134 .66262 L .28906 .66235 L F
.29134 .66262 m .29103 .66268 L .28906 .66235 L F
.29286 .66232 m .29282 .66233 L .28789 .66222 L F
.29282 .66233 m .28882 .66236 L .28789 .66222 L F
.768 .584 .65 r
.28907 .66245 m .29311 .66233 L .28906 .66235 L F
.259 .756 .9 r
.29311 .66233 m .29103 .66268 L .29286 .66232 L F
.768 .584 .65 r
.2917 .66349 m .29311 .66233 L .28907 .66245 L F
.84 .402 .189 r
.33769 .5585 m .33944 .56144 L .34138 .56172 L F
.399 .468 .815 r
.34292 .56242 m .34377 .56294 L .34138 .56172 L F
.479 0 0 r
.33944 .56144 m .34292 .56242 L .34138 .56172 L F
0 0 0 r
.27695 .60175 m .27743 .60135 L .27874 .5993 L F
0 0 .388 r
.27695 .60175 m .27769 .60399 L .27743 .60135 L F
.065 0 .411 r
.27695 .60175 m .27672 .60506 L .27769 .60399 L F
.557 .103 .131 r
.33341 .55993 m .33574 .56035 L .33769 .5585 L F
.789 .405 .328 r
.33574 .56035 m .33944 .56144 L .33769 .5585 L F
.167 0 0 r
.29465 .53178 m .29267 .53151 L .29088 .53168 L F
.919 .848 .401 r
.31586 .61352 m .31685 .61147 L .31653 .61026 L F
.838 .822 .833 r
.35463 .63363 m .35202 .63474 L .35393 .63464 L F
.867 .877 .842 r
.35394 .63397 m .35393 .63464 L .35463 .63363 L F
.762 .798 .882 r
.3544 .63424 m .35751 .63599 L .35393 .63464 L F
.863 .495 .348 r
.35751 .63599 m .35579 .63766 L .35393 .63464 L F
.419 .727 .989 r
.35827 .63453 m .35751 .63599 L .3544 .63424 L F
.57 .436 .659 r
.3544 .63424 m .35481 .63424 L .35472 .63396 L F
.35393 .63464 m .35472 .63396 L .35463 .63363 L F
.625 .468 .65 r
.35463 .63363 m .35481 .63424 L .35827 .63453 L F
.35481 .63424 m .35579 .63766 L .35827 .63453 L F
.419 .727 .989 r
.35614 .63426 m .35481 .63424 L .35394 .63397 L F
.35481 .63424 m .3544 .63424 L .35434 .6342 L F
.35481 .63424 m .35434 .6342 L .35394 .63397 L F
.35827 .63453 m .3544 .63424 L .35614 .63426 L F
.57 .436 .659 r
.35393 .63464 m .35579 .63766 L .35481 .63424 L F
.35393 .63464 m .35481 .63424 L .3544 .63424 L F
.762 .798 .882 r
.35394 .63397 m .3544 .63424 L .35393 .63464 L F
.689 .914 .578 r
.35827 .63453 m .35579 .63766 L .35751 .63599 L F
.559 .489 .732 r
.18465 .58307 m .1836 .58328 L .18439 .58057 L F
.282 .107 .457 r
.18657 .57976 m .18465 .58307 L .18439 .58057 L F
.668 .417 .532 r
.37522 .57341 m .37235 .57127 L .37474 .571 L F
.37522 .57341 m .37154 .57362 L .37235 .57127 L F
.639 .438 .595 r
.34587 .57258 m .34708 .57395 L .34662 .57105 L F
.172 0 .229 r
.34662 .57105 m .34843 .57038 L .3492 .56809 L F
.316 .214 .576 r
.34662 .57105 m .34852 .57297 L .34843 .57038 L F
.312 .213 .579 r
.34662 .57105 m .34708 .57395 L .34852 .57297 L F
.731 .525 .613 r
.29245 .54644 m .28892 .54865 L .28942 .54682 L F
.442 0 0 r
.2772 .56242 m .27716 .56268 L .2758 .55992 L F
.2772 .56242 m .27917 .56376 L .27716 .56268 L F
.391 .183 .473 r
.27936 .56129 m .27917 .56376 L .2772 .56242 L F
.324 .808 .874 r
.22394 .63255 m .22542 .63263 L .22677 .63216 L F
.534 .186 .325 r
.28337 .66725 m .28509 .66924 L .28311 .66927 L F
.608 .419 .601 r
.32321 .6266 m .32597 .62678 L .32585 .62356 L F
.613 .926 .97 r
.32637 .62204 m .32585 .62356 L .32815 .62301 L F
.32637 .62204 m .3243 .62314 L .32585 .62356 L F
.478 .319 .587 r
.32585 .62356 m .32817 .62608 L .32815 .62301 L F
.32585 .62356 m .32597 .62678 L .32817 .62608 L F
.992 .837 .471 r
.28036 .6281 m .28147 .62672 L .28067 .62964 L F
.716 .223 .069 r
.22695 .56076 m .22332 .56006 L .22504 .55826 L F
.22695 .56076 m .22556 .56082 L .22332 .56006 L F
.89 .564 .425 r
.22695 .56076 m .22513 .56251 L .22556 .56082 L F
.735 .457 .508 r
.22513 .56251 m .22332 .56006 L .22556 .56082 L F
.34 0 .182 r
.22768 .55764 m .2259 .56006 L .23028 .55863 L F
.2259 .56006 m .22641 .56053 L .23028 .55863 L F
.713 .397 .442 r
.22569 .55691 m .22507 .56119 L .22768 .55764 L F
.34 0 .182 r
.2259 .56006 m .22507 .56119 L .22641 .56053 L F
.259 0 0 r
.22692 .55735 m .22768 .55764 L .23093 .55878 L F
.602 .887 .99 r
.23093 .55878 m .22768 .55764 L .23173 .55702 L F
.34 0 .182 r
.22768 .55764 m .23028 .55863 L .23063 .55845 L F
.725 .723 .847 r
.23063 .55845 m .22507 .56119 L .22638 .55906 L F
.23063 .55845 m .22638 .55906 L .22649 .55749 L F
.502 .531 .819 r
.22655 .56065 m .22649 .55749 L .22638 .55906 L F
.22666 .56167 m .22662 .56072 L .22655 .56065 L F
.22662 .56072 m .22649 .55749 L .22655 .56065 L F
.259 0 0 r
.22569 .55691 m .22768 .55764 L .22692 .55735 L F
0 0 .125 r
.30286 .63635 m .30463 .6323 L .3047 .63605 L F
.473 .384 .674 r
.30286 .63635 m .30536 .63831 L .3047 .63605 L F
.30286 .63635 m .30536 .63831 L .3047 .63605 L F
.623 .607 .813 r
.19879 .62016 m .2007 .62389 L .2028 .62228 L F
.66 .558 .728 r
.35435 .60792 m .35187 .60863 L .35074 .60511 L F
.351 .138 .445 r
.35435 .60792 m .35191 .61121 L .35187 .60863 L F
.546 .404 .639 r
.31095 .63219 m .31324 .6291 L .31104 .62978 L F
.055 0 0 r
.36938 .53547 m .37212 .5352 L .37377 .53452 L F
.24 0 0 r
.37212 .5352 m .37629 .53505 L .37377 .53452 L F
0 .336 .814 r
.20678 .62362 m .20699 .62255 L .20522 .62238 L F
.20678 .62362 m .20936 .62529 L .20699 .62255 L F
0 0 0 r
.2555 .53223 m .25945 .53204 L .25743 .53212 L F
.248 .002 .33 r
.28029 .61345 m .2787 .61432 L .28111 .61118 L F
.051 0 .259 r
.27989 .61601 m .2787 .61432 L .28029 .61345 L F
.27989 .61601 m .27808 .61665 L .2787 .61432 L F
.576 .186 .265 r
.78035 .3998 m .78407 .39965 L .78207 .39878 L F
.523 .326 .556 r
.78407 .39965 m .78478 .39767 L .78207 .39878 L F
.806 .89 .905 r
.3471 .55133 m .34873 .55253 L .3511 .54988 L F
.635 .579 .775 r
.34873 .55253 m .35241 .55504 L .3511 .54988 L F
.572 .052 0 r
.27768 .55498 m .27328 .55478 L .27573 .55589 L F
.789 .68 .744 r
.30577 .56167 m .30917 .55941 L .30646 .55884 L F
.30577 .56167 m .30752 .562 L .30917 .55941 L F
.676 .888 .975 r
.30912 .55723 m .30917 .55941 L .31079 .55869 L F
.30912 .55723 m .30646 .55884 L .30917 .55941 L F
.119 .651 .867 r
.2589 .6411 m .2641 .64168 L .26121 .64118 L F
.402 .797 .987 r
.2641 .64168 m .26471 .64161 L .26121 .64118 L F
.313 .298 .683 r
.3248 .55618 m .32451 .55892 L .3262 .5578 L F
.32387 .55511 m .32411 .55657 L .3248 .55618 L F
.32411 .55657 m .32451 .55892 L .3248 .55618 L F
.509 .851 .995 r
.32683 .55614 m .3217 .55556 L .32387 .55511 L F
.32519 .55596 m .3234 .55492 L .3217 .55556 L F
.32683 .55614 m .32562 .55571 L .32519 .55596 L F
.32562 .55571 m .3234 .55492 L .32519 .55596 L F
.745 .646 .087 r
.28647 .63707 m .28647 .63856 L .28667 .63597 L F
.52 .248 .443 r
.28647 .63856 m .28961 .63585 L .28667 .63597 L F
.646 .464 .623 r
.32226 .56137 m .32473 .56146 L .32451 .55892 L F
.37 .304 .652 r
.32473 .56146 m .3262 .5578 L .32451 .55892 L F
.202 0 .224 r
.30468 .57097 m .304 .57321 L .30184 .57405 L F
.418 .097 .311 r
.30639 .57251 m .30468 .57097 L .30712 .57068 L F
.30639 .57251 m .304 .57321 L .30468 .57097 L F
.571 .345 .534 r
.33545 .59558 m .33821 .59282 L .33535 .59277 L F
.306 .193 .557 r
.30288 .55199 m .30482 .54793 L .30313 .54948 L F
.418 .367 .695 r
.29174 .62965 m .29205 .63248 L .2944 .63195 L F
.495 .293 .534 r
.29162 .63528 m .2944 .63195 L .29205 .63248 L F
.23 0 0 r
.33299 .56609 m .3317 .56728 L .33084 .56712 L F
.806 .972 .672 r
.33237 .5654 m .3317 .56728 L .33299 .56609 L F
.456 .209 .45 r
.33312 .56753 m .3317 .56728 L .33237 .5654 L F
.33341 .56837 m .3317 .56728 L .33312 .56753 L F
.23 0 0 r
.33084 .56712 m .3317 .56728 L .32945 .5678 L F
.173 .123 .556 r
.30283 .59238 m .3041 .58844 L .30194 .58994 L F
.051 .584 .86 r
.27546 .64314 m .27603 .64273 L .27365 .64195 L F
.27546 .64314 m .2781 .64351 L .27603 .64273 L F
0 0 0 r
.32306 .64736 m .32193 .65103 L .32219 .64872 L F
.716 .312 0 r
.164 .5954 m .16597 .59885 L .16497 .59728 L F
.749 .268 0 r
.16597 .59885 m .16771 .60157 L .166 .59997 L F
.27 .282 .689 r
.53716 .56078 m .53736 .56414 L .53619 .56261 L F
.558 .365 .576 r
.53493 .56445 m .53736 .56414 L .53619 .56261 L F
.27 .282 .689 r
.53716 .56078 m .53736 .56414 L .53619 .56261 L F
.012 0 .32 r
.28111 .61118 m .28229 .60808 L .2839 .6098 L F
.396 .141 .405 r
.28029 .61345 m .28111 .61118 L .2839 .6098 L F
.897 .884 .811 r
.28685 .65105 m .28934 .6483 L .28731 .64836 L F
.752 .282 .13 r
.28731 .64836 m .28934 .6483 L .29227 .65213 L F
.475 .404 .698 r
.30154 .57688 m .3022 .57941 L .29937 .57758 L F
.461 .686 .963 r
.21451 .62951 m .21606 .62763 L .21212 .62686 L F
.21451 .62951 m .21657 .62926 L .21606 .62763 L F
0 0 0 r
.28026 .59553 m .27874 .5993 L .27985 .5975 L F
.27874 .5993 m .27956 .59985 L .27985 .5975 L F
.27874 .5993 m .27743 .60135 L .27956 .59985 L F
.26 .375 .791 r
.20681 .60461 m .20655 .60814 L .20497 .60455 L F
.20681 .60461 m .20783 .60778 L .20655 .60814 L F
.228 .246 .671 r
.20783 .60778 m .20857 .6102 L .20655 .60814 L F
.284 .256 .65 r
.20857 .6102 m .20696 .61002 L .20655 .60814 L F
.405 .225 .521 r
.304 .57321 m .30154 .57688 L .30184 .57405 L F
.367 .408 .771 r
.29054 .626 m .29174 .62965 L .29329 .62929 L F
.418 .367 .695 r
.29174 .62965 m .2944 .63195 L .29329 .62929 L F
.301 .035 .332 r
.2899 .59877 m .28744 .60023 L .2879 .59978 L F
.2899 .59877 m .28987 .60081 L .28744 .60023 L F
.182 0 .303 r
.28891 .60277 m .28744 .60023 L .28987 .60081 L F
.28891 .60277 m .28724 .60369 L .28744 .60023 L F
.87 .527 .399 r
.54208 .52682 m .54552 .53029 L .5452 .528 L F
.685 .972 .919 r
.31731 .59412 m .31646 .59578 L .31413 .59579 L F
.301 .034 .331 r
.32534 .64104 m .32327 .64203 L .3259 .63902 L F
0 .139 .679 r
.32441 .63545 m .32656 .63781 L .3259 .63902 L F
.279 .278 .679 r
.32656 .63781 m .32534 .64104 L .3259 .63902 L F
.991 .766 .386 r
.38222 .56069 m .38222 .56342 L .38317 .56193 L F
.061 0 0 r
.38263 .56256 m .38222 .56342 L .38271 .56227 L F
.642 .816 .391 r
.38317 .56193 m .38222 .56342 L .38188 .56412 L F
.061 0 0 r
.38213 .56436 m .38222 .56342 L .38263 .56256 L F
.642 .816 .391 r
.38188 .56412 m .38222 .56342 L .3817 .56442 L F
.574 .123 0 r
.38222 .56069 m .38317 .56193 L .38171 .56 L F
0 0 0 r
.3832 .55916 m .3827 .56133 L .38222 .56069 L F
.3827 .56133 m .38222 .56342 L .38222 .56069 L F
.574 .123 0 r
.38222 .56069 m .38171 .56 L .38066 .5586 L F
.449 .143 .354 r
.3492 .56809 m .35088 .56976 L .35083 .56609 L F
.3492 .56809 m .34843 .57038 L .35088 .56976 L F
.719 .882 .956 r
.16771 .60157 m .17014 .60246 L .17201 .60109 L F
.571 .345 .534 r
.33545 .59558 m .33796 .5954 L .33821 .59282 L F
.567 .4 .615 r
.33821 .59282 m .34132 .59234 L .34097 .5893 L F
.627 .446 .618 r
.33796 .5954 m .34132 .59234 L .33821 .59282 L F
.442 .5 .823 r
.33195 .55765 m .331 .56071 L .33056 .55908 L F
0 .55 .75 r
.33109 .55873 m .32902 .55841 L .33234 .55881 L F
.442 .5 .823 r
.33195 .55765 m .33274 .55888 L .3316 .55878 L F
0 .55 .75 r
.331 .55873 m .33234 .55881 L .33195 .55765 L F
.331 .55873 m .33097 .55872 L .33109 .55873 L F
.417 .338 .66 r
.32854 .55825 m .32902 .55841 L .331 .55873 L F
.3262 .5578 m .32902 .55841 L .32854 .55825 L F
.537 .538 .803 r
.32949 .56076 m .33041 .56361 L .33277 .56279 L F
0 .55 .75 r
.33097 .55872 m .32902 .55841 L .33109 .55873 L F
.442 .5 .823 r
.3316 .55878 m .33341 .55993 L .331 .56071 L F
.33274 .55888 m .33341 .55993 L .3316 .55878 L F
.778 .771 .847 r
.32902 .55841 m .32949 .56076 L .33234 .55881 L F
.537 .538 .803 r
.32949 .56076 m .33277 .56279 L .33234 .55881 L F
.764 .372 .31 r
.33234 .55881 m .33 .56139 L .32902 .55841 L F
0 0 .352 r
.32902 .55841 m .33 .56139 L .32948 .55856 L F
.728 .816 .92 r
.33234 .55881 m .32902 .55841 L .33099 .5569 L F
.748 .911 .948 r
.33099 .5569 m .32902 .55841 L .3291 .55651 L F
0 0 .352 r
.32902 .55841 m .32948 .55856 L .3291 .55651 L F
.804 .552 .556 r
.30577 .56167 m .30566 .56443 L .30752 .562 L F
.801 .308 0 r
.37854 .53689 m .37986 .53913 L .38163 .53988 L F
.143 .435 .872 r
.38226 .53856 m .38163 .53988 L .37986 .53913 L F
.38226 .53856 m .38281 .54031 L .38163 .53988 L F
.351 .138 .445 r
.35435 .60792 m .35419 .61045 L .35191 .61121 L F
0 0 0 r
.35419 .61045 m .35185 .61396 L .35191 .61121 L F
.759 .661 .754 r
.22504 .55826 m .22089 .55832 L .22332 .55527 L F
.558 .069 .051 r
.22504 .55826 m .22332 .56006 L .22089 .55832 L F
.752 .723 .825 r
.352 .53975 m .34848 .53946 L .3508 .53646 L F
.772 .733 .817 r
.35477 .53697 m .352 .53975 L .3508 .53646 L F
.017 .47 .874 r
.37629 .53505 m .37832 .53597 L .37854 .53689 L F
0 0 .43 r
.37832 .53597 m .37986 .53913 L .37854 .53689 L F
.539 0 0 r
.5371 .54675 m .53601 .5477 L .5331 .54627 L F
.664 .898 .556 r
.5386 .54446 m .5371 .54675 L .53982 .54817 L F
.5386 .54446 m .53601 .5477 L .5371 .54675 L F
.342 .549 .909 r
.22677 .63216 m .22959 .63534 L .23071 .63503 L F
.521 .725 .967 r
.3261 .53388 m .32582 .53621 L .32389 .53399 L F
.3261 .53388 m .32797 .53558 L .32582 .53621 L F
0 0 0 r
.37666 .54608 m .37465 .54788 L .37265 .5486 L F
.37 .779 .982 r
.37912 .54839 m .37465 .54788 L .37666 .54608 L F
.45 .503 .822 r
.3686 .5569 m .36947 .55955 L .367 .55783 L F
.446 .215 .469 r
.31598 .62598 m .31371 .62674 L .31324 .6291 L F
.596 .637 .862 r
.32909 .63972 m .33219 .6397 L .33032 .63733 L F
.956 .715 .534 r
.32233 .62425 m .3214 .62602 L .32321 .6266 L F
.174 .678 .908 r
.32366 .62581 m .32321 .6266 L .3214 .62602 L F
.32366 .62581 m .32597 .62678 L .32321 .6266 L F
.243 0 0 r
.2416 .73573 m .23682 .73777 L .23953 .73772 L F
.127 0 0 r
.24169 .73653 m .2416 .73573 L .23953 .73772 L F
.72 .433 .489 r
.33689 .62742 m .33952 .62946 L .34075 .62559 L F
.33689 .62742 m .33524 .62944 L .33952 .62946 L F
.904 .52 .286 r
.2951 .64848 m .29583 .65072 L .29382 .64989 L F
.907 .501 .194 r
.2951 .64848 m .29728 .65162 L .29583 .65072 L F
.621 .074 0 r
.293 .65397 m .29682 .65702 L .29703 .65444 L F
.528 .765 .984 r
.29703 .65444 m .29951 .65415 L .29796 .65266 L F
.533 .273 .467 r
.29703 .65444 m .29913 .65652 L .29682 .65702 L F
.29703 .65444 m .29951 .65415 L .29913 .65652 L F
.29703 .65444 m .29913 .65652 L .29682 .65702 L F
.29703 .65444 m .29951 .65415 L .29913 .65652 L F
0 0 0 r
.32644 .61131 m .32814 .61071 L .32864 .61074 L F
.32644 .61131 m .32403 .61232 L .32814 .61071 L F
.841 .675 .677 r
.38418 .5525 m .38131 .55222 L .38276 .54888 L F
.73 .51 .592 r
.38287 .55459 m .38131 .55222 L .38418 .5525 L F
.571 .542 .783 r
.38658 .55193 m .38418 .5525 L .38276 .54888 L F
.383 .012 .204 r
.38674 .55356 m .38418 .5525 L .38658 .55193 L F
.38674 .55356 m .38287 .55459 L .38418 .5525 L F
.63 .576 .775 r
.3511 .54988 m .35241 .55504 L .35497 .5529 L F
.643 .544 .728 r
.35251 .55546 m .35497 .5529 L .35241 .55504 L F
.367 .831 .904 r
.26413 .53136 m .26371 .53216 L .26175 .53167 L F
.26413 .53136 m .26596 .53152 L .26371 .53216 L F
.894 .637 .124 r
.31427 .60342 m .31505 .60557 L .31451 .60224 L F
.31427 .60342 m .31451 .60224 L .31738 .60153 L F
.783 .622 .681 r
.32789 .60752 m .33158 .60519 L .32989 .60477 L F
.32789 .60752 m .33184 .60812 L .33158 .60519 L F
.596 .417 .609 r
.33184 .60812 m .33436 .60493 L .33158 .60519 L F
.504 .765 .99 r
.26834 .68489 m .26948 .68349 L .2671 .68169 L F
.26834 .68489 m .27065 .6845 L .26948 .68349 L F
.45 .23 .486 r
.16941 .57109 m .17161 .57051 L .17197 .56795 L F
.357 .15 .456 r
.17197 .56795 m .17356 .56967 L .17411 .56735 L F
.17197 .56795 m .17161 .57051 L .17356 .56967 L F
.537 .263 .448 r
.29952 .56467 m .30195 .56449 L .30243 .56212 L F
.677 .442 .558 r
.30195 .56449 m .30577 .56167 L .30243 .56212 L F
.689 .525 .66 r
.34186 .57981 m .34518 .57708 L .34066 .57856 L F
.687 .34 .382 r
.25358 .70984 m .2571 .70973 L .25401 .70855 L F
.77 .589 .654 r
.36165 .5961 m .36132 .59921 L .35807 .59831 L F
.611 .529 .737 r
.3641 .59565 m .36165 .5961 L .36066 .59259 L F
.403 .265 .577 r
.36362 .59831 m .36165 .5961 L .3641 .59565 L F
.36362 .59831 m .36132 .59921 L .36165 .5961 L F
.56 .373 .585 r
.53493 .56445 m .53492 .56745 L .53736 .56414 L F
.69 .368 .427 r
.30966 .6511 m .30787 .6537 L .30575 .65116 L F
.68 .356 .42 r
.31188 .65355 m .30966 .6511 L .31208 .65133 L F
.31188 .65355 m .30787 .6537 L .30966 .6511 L F
.724 .435 .488 r
.32207 .65348 m .31834 .65112 L .32193 .65103 L F
0 0 0 r
.32306 .64736 m .32238 .65016 L .32193 .65103 L F
.682 .426 .529 r
.32207 .65348 m .32238 .65016 L .32193 .65103 L F
.277 .514 .902 r
.3106 .57126 m .31176 .56963 L .30927 .57056 L F
.041 0 0 r
.31176 .56963 m .31076 .57039 L .30927 .57056 L F
.266 .724 .953 r
.3106 .57126 m .30927 .57056 L .30753 .57075 L F
.041 0 0 r
.31076 .57039 m .3088 .57188 L .30927 .57056 L F
.266 .724 .953 r
.30753 .57075 m .30927 .57056 L .30712 .57068 L F
.277 .514 .902 r
.3106 .57126 m .31382 .57284 L .31176 .56963 L F
.553 .477 .724 r
.31175 .57318 m .31382 .57284 L .3106 .57126 L F
0 0 0 r
.16832 .57297 m .17161 .57051 L .16941 .57109 L F
.476 .319 .589 r
.32175 .5823 m .31945 .58068 L .32187 .57987 L F
.32175 .5823 m .31953 .58322 L .31945 .58068 L F
.029 0 0 r
.27075 .61628 m .26898 .61665 L .26787 .61877 L F
.636 .781 .951 r
.28163 .63154 m .28079 .63299 L .27961 .63121 L F
0 .177 .712 r
.28486 .60981 m .28229 .60808 L .28471 .6067 L F
.28486 .60981 m .2839 .6098 L .28229 .60808 L F
.511 .877 .659 r
.26055 .62262 m .26156 .6216 L .26351 .62122 L F
.26055 .62262 m .25984 .62297 L .26156 .6216 L F
.497 0 0 r
.4964 .56063 m .49802 .5622 L .49652 .56076 L F
.596 .417 .609 r
.33184 .60812 m .33439 .60788 L .33436 .60493 L F
.423 .233 .517 r
.33436 .60493 m .33659 .6043 L .33676 .60172 L F
.537 .408 .652 r
.33439 .60788 m .33659 .6043 L .33436 .60493 L F
.523 .3 .517 r
.35707 .60497 m .35686 .60753 L .35435 .60792 L F
.611 .375 .534 r
.35946 .60727 m .35707 .60497 L .35964 .60492 L F
.35946 .60727 m .35686 .60753 L .35707 .60497 L F
.185 0 .044 r
.19675 .5491 m .19742 .55064 L .19892 .54836 L F
.19675 .5491 m .19529 .55145 L .19742 .55064 L F
.53 .312 .529 r
.49398 .59815 m .49355 .60109 L .492 .5991 L F
.492 .5991 m .49355 .60109 L .49398 .59815 L F
.199 .459 .88 r
.38281 .54031 m .38605 .54161 L .38537 .54317 L F
.07 .294 .78 r
.38605 .54161 m .38793 .54525 L .38537 .54317 L F
.671 .867 .973 r
.34223 .53719 m .33818 .53728 L .34061 .53683 L F
.222 .744 .817 r
.34061 .53683 m .34469 .53643 L .34223 .53719 L F
.217 0 0 r
.32096 .56404 m .32473 .56146 L .32226 .56137 L F
.81 .79 .835 r
.50439 .55859 m .5006 .55863 L .50319 .55783 L F
0 .16 .697 r
.50494 .55719 m .50439 .55859 L .50319 .55783 L F
.50494 .55719 m .50666 .56089 L .50439 .55859 L F
.104 0 .106 r
.52616 .52752 m .52839 .52684 L .52926 .52439 L F
.525 .153 .276 r
.52926 .52439 m .53174 .52601 L .53182 .52395 L F
.52926 .52439 m .52839 .52684 L .53174 .52601 L F
.408 0 0 r
.27722 .54798 m .27458 .5488 L .27472 .54835 L F
0 0 0 r
.27491 .54772 m .27472 .54835 L .27404 .54937 L F
.655 .345 .435 r
.27376 .55167 m .27591 .55219 L .27404 .54937 L F
.81 .352 .143 r
.27404 .54937 m .27736 .55201 L .27726 .5494 L F
.655 .345 .435 r
.27267 .54999 m .27472 .54835 L .2722 .54926 L F
.27376 .55167 m .27403 .55074 L .27267 .54999 L F
.81 .352 .143 r
.27404 .54937 m .27547 .55152 L .27736 .55201 L F
.655 .345 .435 r
.27388 .55066 m .27404 .54937 L .27472 .54835 L F
.27376 .55167 m .27388 .55066 L .27472 .54835 L F
.27403 .55074 m .27472 .54835 L .27267 .54999 L F
.81 .352 .143 r
.27547 .55152 m .27591 .55219 L .27654 .55211 L F
.27547 .55152 m .27654 .55211 L .27736 .55201 L F
.408 0 0 r
.27458 .5488 m .27283 .54934 L .27472 .54835 L F
0 0 0 r
.27584 .54593 m .27472 .54835 L .27491 .54772 L F
.543 .566 .828 r
.31102 .55568 m .31421 .55778 L .31305 .55741 L F
.376 .348 .7 r
.31102 .55568 m .31305 .55741 L .31289 .55494 L F
.703 .253 .18 r
.31102 .55568 m .30912 .55723 L .31305 .55741 L F
.328 .723 .982 r
.30797 .53224 m .30526 .53243 L .3035 .53125 L F
.581 .625 .86 r
.30481 .60317 m .30782 .60101 L .30394 .60079 L F
.30481 .60317 m .30762 .60246 L .30782 .60101 L F
0 .518 .719 r
.26121 .64118 m .26471 .64161 L .2617 .64122 L F
0 0 0 r
.26471 .64161 m .26856 .64075 L .26593 .64135 L F
.26471 .64161 m .26533 .64175 L .2617 .64122 L F
.26471 .64161 m .26593 .64135 L .26533 .64175 L F
.568 .499 .737 r
.31224 .57703 m .31382 .57284 L .31175 .57318 L F
.31224 .57703 m .31471 .57661 L .31382 .57284 L F
.39 .121 .38 r
.31158 .57971 m .31471 .57661 L .31224 .57703 L F
0 0 0 r
.28354 .65385 m .28123 .65683 L .28431 .65722 L F
.708 .55 .672 r
.28165 .66011 m .28431 .65722 L .28123 .65683 L F
.825 .834 .363 r
.52524 .53047 m .52534 .52909 L .52616 .52752 L F
.096 0 0 r
.52616 .52752 m .52758 .52823 L .52839 .52684 L F
.52616 .52752 m .52534 .52909 L .52758 .52823 L F
.141 0 0 r
.3817 .56442 m .37898 .5665 L .37704 .56692 L F
.662 .943 .685 r
.38222 .56342 m .37898 .5665 L .3817 .56442 L F
.31 0 .16 r
.20563 .56424 m .20364 .56522 L .20336 .56465 L F
.327 .164 .501 r
.33839 .57605 m .33909 .58039 L .3398 .57891 L F
.646 .377 .497 r
.33567 .5776 m .33875 .58052 L .33839 .57605 L F
.33875 .58052 m .33909 .58039 L .33839 .57605 L F
.574 .365 .56 r
.33821 .58111 m .33875 .58052 L .33567 .5776 L F
.76 .658 .75 r
.33837 .58067 m .33875 .58052 L .3398 .57891 L F
.33875 .58052 m .34026 .57993 L .33994 .57924 L F
.33875 .58052 m .33994 .57924 L .3398 .57891 L F
.574 .365 .56 r
.33488 .58169 m .33821 .58111 L .33567 .5776 L F
.76 .658 .75 r
.3373 .58199 m .34026 .57993 L .33884 .58049 L F
.3373 .58199 m .33884 .58049 L .33837 .58067 L F
.33884 .58092 m .34144 .58253 L .34026 .57993 L F
.3373 .58199 m .33827 .58212 L .33884 .58092 L F
.33827 .58212 m .34144 .58253 L .33884 .58092 L F
.574 .365 .56 r
.33821 .58111 m .3373 .58199 L .33918 .58093 L F
.33488 .58169 m .3373 .58199 L .33821 .58111 L F
.33821 .58111 m .33918 .58093 L .33875 .58052 L F
.327 .164 .501 r
.33909 .58039 m .33918 .58093 L .3398 .57891 L F
.646 .377 .497 r
.33875 .58052 m .33918 .58093 L .33909 .58039 L F
.27 0 0 r
.34011 .55476 m .34226 .55528 L .33836 .55458 L F
.563 .353 .553 r
.37079 .54934 m .37095 .55198 L .36782 .55211 L F
0 0 .42 r
.37183 .55095 m .37079 .54934 L .37265 .5486 L F
.37183 .55095 m .37095 .55198 L .37079 .54934 L F
0 0 .121 r
.30077 .61141 m .29993 .61358 L .30215 .61038 L F
.544 .712 .949 r
.27321 .62884 m .27315 .63133 L .27129 .62877 L F
.27321 .62884 m .27482 .63086 L .27315 .63133 L F
.71 .617 .751 r
.3525 .61915 m .35123 .62322 L .35047 .62038 L F
.045 .598 .824 r
.32902 .60753 m .33184 .60812 L .32789 .60752 L F
.32902 .60753 m .32864 .61074 L .33049 .60808 L F
.546 .013 0 r
.33227 .60875 m .33184 .60812 L .33133 .60802 L F
.33049 .60808 m .33133 .60802 L .32902 .60753 L F
.33227 .60875 m .33133 .60802 L .33049 .60808 L F
.045 .598 .824 r
.32902 .60753 m .32789 .60752 L .32864 .61074 L F
.77 .988 .753 r
.32864 .61074 m .32814 .61071 L .33047 .60808 L F
.045 .598 .824 r
.32902 .60753 m .33049 .60808 L .33053 .60801 L F
.77 .988 .753 r
.33049 .60808 m .33047 .60808 L .33053 .60801 L F
.368 .483 .844 r
.33072 .60558 m .33122 .60659 L .32902 .60753 L F
.546 .013 0 r
.33238 .60892 m .33227 .60875 L .33052 .60809 L F
.33036 .60805 m .33052 .60809 L .32902 .60753 L F
.637 .243 .281 r
.32902 .60753 m .33053 .60801 L .33036 .60805 L F
.32902 .60753 m .33036 .60805 L .32569 .60903 L F
.546 .013 0 r
.33018 .60801 m .33036 .60805 L .32902 .60753 L F
.33238 .60892 m .33052 .60809 L .33018 .60801 L F
.802 .813 .86 r
.33036 .60805 m .32814 .61071 L .32569 .60903 L F
.33053 .60801 m .33047 .60808 L .33036 .60805 L F
.33047 .60808 m .32814 .61071 L .33036 .60805 L F
.368 .483 .844 r
.33122 .60659 m .33238 .60892 L .33038 .60809 L F
.33122 .60659 m .33038 .60809 L .32902 .60753 L F
.77 .988 .753 r
.32994 .60887 m .33047 .60808 L .33049 .60808 L F
.32864 .61074 m .32998 .6088 L .32994 .60887 L F
.32998 .6088 m .33047 .60808 L .32994 .60887 L F
.546 .013 0 r
.33238 .60892 m .334 .61017 L .33184 .60812 L F
.56 .286 .457 r
.334 .61017 m .33439 .60788 L .33184 .60812 L F
.438 .337 .642 r
.3706 .55455 m .36782 .55211 L .37095 .55198 L F
.3706 .55455 m .3686 .55555 L .36782 .55211 L F
.65 .904 .982 r
.25464 .6263 m .25268 .62741 L .25056 .62659 L F
.22 0 .182 r
.28493 .59153 m .28799 .58865 L .28619 .58974 L F
.55 .395 .624 r
.31598 .62598 m .31863 .62245 L .31619 .62341 L F
.763 .708 .801 r
.37568 .55843 m .37688 .56238 L .37473 .56153 L F
.67 .655 .826 r
.37902 .56122 m .37688 .56238 L .37568 .55843 L F
.611 .529 .737 r
.3641 .59565 m .36066 .59259 L .36302 .59204 L F
.639 .55 .738 r
.34848 .53946 m .34581 .54014 L .34469 .53643 L F
.398 .251 .563 r
.34587 .57258 m .3466 .57612 L .34708 .57395 L F
.34587 .57258 m .34518 .57708 L .3466 .57612 L F
.848 .766 .771 r
.53453 .53393 m .53077 .5362 L .53103 .53432 L F
.53453 .53393 m .53251 .53728 L .53077 .5362 L F
.302 .711 .976 r
.2589 .6411 m .25942 .6402 L .25702 .64066 L F
.2589 .6411 m .26121 .64118 L .25942 .6402 L F
0 0 .464 r
.275 .67448 m .2763 .67656 L .27751 .67815 L F
.729 .213 0 r
.24104 .55069 m .23684 .54828 L .2384 .54999 L F
.139 0 0 r
.3116 .53285 m .31391 .53317 L .31597 .53335 L F
0 .358 .782 r
.31611 .53288 m .31597 .53335 L .31391 .53317 L F
.31611 .53288 m .31755 .53407 L .31597 .53335 L F
.989 .892 .603 r
.54995 .54865 m .549 .55119 L .54998 .55157 L F
.96 .841 .419 r
.54886 .55339 m .54998 .55157 L .549 .55119 L F
.54886 .55339 m .54945 .55551 L .54998 .55157 L F
.596 .635 .859 r
.34354 .58726 m .34336 .58805 L .34099 .58786 L F
.357 .76 .984 r
.33891 .58817 m .34097 .5893 L .34166 .58869 L F
.33839 .58808 m .33891 .58817 L .34099 .58786 L F
.33891 .58817 m .34166 .58869 L .34099 .58786 L F
.234 .161 .566 r
.34097 .5893 m .34261 .59126 L .34166 .58869 L F
.873 .514 .02 r
.34166 .58869 m .34261 .59126 L .34099 .58786 L F
.596 .635 .859 r
.34261 .59126 m .34349 .58747 L .34099 .58786 L F
.34349 .58747 m .34354 .58726 L .34099 .58786 L F
.34336 .58805 m .34261 .59126 L .34111 .58811 L F
.34336 .58805 m .34111 .58811 L .34099 .58786 L F
.357 .76 .984 r
.33839 .58808 m .33861 .58818 L .33891 .58817 L F
.33861 .58818 m .34097 .5893 L .33891 .58817 L F
.234 .161 .566 r
.34097 .5893 m .34132 .59234 L .34261 .59126 L F
.201 .555 .933 r
.244 .63703 m .24838 .63938 L .24747 .63767 L F
.54 .676 .926 r
.24838 .63938 m .2498 .63724 L .24747 .63767 L F
.24838 .63938 m .25045 .6389 L .2498 .63724 L F
.607 .657 .873 r
.33219 .6397 m .33602 .64198 L .33408 .63879 L F
.495 .816 1 r
.33602 .64198 m .33907 .64057 L .33408 .63879 L F
.33602 .64198 m .33836 .64147 L .33907 .64057 L F
.765 .542 .595 r
.32815 .62301 m .33178 .62615 L .33197 .62345 L F
.32815 .62301 m .33182 .62343 L .3307 .62359 L F
.32815 .62301 m .32817 .62608 L .33178 .62615 L F
.388 0 0 r
.32815 .62301 m .3307 .62359 L .32856 .62413 L F
.671 .321 .373 r
.33279 .62222 m .32935 .62377 L .3307 .62359 L F
.32935 .62377 m .32856 .62413 L .3307 .62359 L F
.765 .542 .595 r
.33182 .62343 m .33197 .62345 L .3307 .62359 L F
.628 .918 .641 r
.33351 .62172 m .33279 .62222 L .33197 .62345 L F
.606 .954 .865 r
.33279 .62222 m .3307 .62359 L .33197 .62345 L F
.739 .47 .522 r
.51828 .55203 m .51917 .54968 L .51703 .54929 L F
.538 0 0 r
.5174 .55055 m .51703 .54929 L .51828 .55203 L F
.5174 .55055 m .51917 .54968 L .51703 .54929 L F
.541 .916 .762 r
.519 .54919 m .51917 .54968 L .5174 .55055 L F
.519 .54919 m .5207 .54851 L .51917 .54968 L F
.535 .367 .6 r
.5207 .54851 m .51828 .55203 L .51917 .54968 L F
.25 .749 .901 r
.30105 .53121 m .2989 .53149 L .29714 .5311 L F
.558 .487 .732 r
.33545 .59558 m .33632 .59906 L .33849 .59813 L F
.178 .038 .441 r
.33676 .60172 m .33849 .59813 L .33632 .59906 L F
.6 .341 .496 r
.35679 .61013 m .35435 .60792 L .35686 .60753 L F
.35679 .61013 m .35419 .61045 L .35435 .60792 L F
0 0 0 r
.29657 .62393 m .29689 .62434 L .29848 .62247 L F
.29657 .62393 m .29487 .62516 L .29689 .62434 L F
.477 .797 .999 r
.23682 .73777 m .24127 .73848 L .23953 .73772 L F
.572 .808 .988 r
.24127 .73848 m .24169 .73653 L .23953 .73772 L F
.24127 .73848 m .24395 .73791 L .24169 .73653 L F
.057 .549 .889 r
.24462 .55209 m .24104 .55069 L .24281 .55208 L F
.696 .431 .517 r
.31569 .65109 m .31188 .65355 L .31208 .65133 L F
.717 .367 .384 r
.28722 .54785 m .28483 .55082 L .28217 .5498 L F
.489 .077 .184 r
.28892 .54865 m .28483 .55082 L .28722 .54785 L F
.464 .519 .83 r
.33372 .58917 m .33017 .58629 L .33353 .58612 L F
.581 .413 .619 r
.33618 .58849 m .33353 .58612 L .33652 .58603 L F
.33611 .58852 m .33353 .58612 L .33618 .58849 L F
.33616 .58857 m .33372 .58917 L .33353 .58612 L F
.308 .105 .434 r
.33143 .59217 m .33281 .59037 L .3335 .59129 L F
.33281 .59037 m .33372 .58917 L .33365 .58983 L F
.33281 .59037 m .33365 .58983 L .3335 .59129 L F
.383 .226 .541 r
.33509 .58903 m .33438 .58911 L .33588 .58864 L F
.33438 .58911 m .33372 .58917 L .33447 .58899 L F
.33438 .58911 m .33447 .58899 L .33588 .58864 L F
.33401 .58943 m .33372 .58917 L .33509 .58903 L F
.217 .739 .758 r
.3311 .58609 m .3325 .58574 L .33541 .58514 L F
.33017 .58629 m .3325 .58574 L .3311 .58609 L F
.345 .164 .487 r
.3325 .58574 m .33488 .58169 L .33541 .58514 L F
.439 .273 .557 r
.33663 .58817 m .33671 .58845 L .33616 .58857 L F
.383 .226 .541 r
.33406 .58949 m .33404 .58956 L .33372 .58917 L F
.33404 .58956 m .3335 .59129 L .33365 .58983 L F
.33404 .58956 m .33365 .58983 L .33372 .58918 L F
.645 .129 .001 r
.33078 .58984 m .33411 .58951 L .32907 .58859 L F
.383 .226 .541 r
.3341 .58952 m .33401 .58943 L .33401 .58943 L F
.645 .129 .001 r
.33411 .58951 m .33421 .5895 L .33407 .58948 L F
.805 .626 .66 r
.33407 .58948 m .33421 .5895 L .33415 .58938 L F
.653 .561 .738 r
.33415 .58938 m .33421 .5895 L .33509 .58903 L F
.383 .226 .541 r
.33411 .58951 m .33401 .58943 L .33509 .58903 L F
.3341 .58952 m .33401 .58943 L .33411 .58951 L F
.645 .129 .001 r
.33411 .58951 m .33411 .58951 L .33407 .58948 L F
.33411 .58951 m .33407 .58948 L .33407 .58948 L F
.33411 .58951 m .33407 .58948 L .32907 .58859 L F
.383 .226 .541 r
.33374 .58919 m .33372 .58918 L .33372 .58917 L F
.33404 .58956 m .33372 .58918 L .33374 .58919 L F
.653 .561 .738 r
.33415 .58938 m .33509 .58903 L .3367 .58817 L F
.661 .957 .942 r
.33591 .5884 m .33438 .58937 L .3343 .58938 L F
.805 .626 .66 r
.32907 .58859 m .33407 .58948 L .3325 .58574 L F
.33407 .58948 m .33407 .58947 L .3325 .58574 L F
.33407 .58948 m .33415 .58938 L .3325 .58574 L F
.439 .273 .557 r
.33622 .58819 m .33657 .58817 L .3364 .58834 L F
.33618 .58849 m .3364 .58834 L .33616 .58857 L F
.33622 .58819 m .3364 .58834 L .33618 .58849 L F
.33652 .58603 m .33818 .58785 L .33665 .58812 L F
.33625 .58794 m .33665 .58812 L .33622 .58819 L F
.33652 .58603 m .33665 .58812 L .33625 .58794 L F
.139 .403 .851 r
.33431 .5851 m .33665 .58812 L .33798 .58774 L F
.33665 .58812 m .3367 .58817 L .33675 .58816 L F
.33665 .58812 m .33675 .58816 L .33798 .58774 L F
.653 .561 .738 r
.3325 .58574 m .33415 .58938 L .3365 .58827 L F
.33661 .58812 m .3365 .58827 L .3367 .58817 L F
.439 .273 .557 r
.33657 .58817 m .33663 .58817 L .33647 .58831 L F
.661 .957 .942 r
.33663 .58819 m .33438 .58937 L .33591 .5884 L F
.3367 .58817 m .33651 .58827 L .33663 .58819 L F
.33651 .58827 m .33438 .58937 L .33663 .58819 L F
.653 .561 .738 r
.3325 .58574 m .3365 .58827 L .33661 .58812 L F
.439 .273 .557 r
.33657 .58817 m .33647 .58831 L .33616 .58857 L F
.661 .957 .942 r
.33557 .58849 m .3343 .58938 L .33078 .58984 L F
.33591 .5884 m .3343 .58938 L .33557 .58849 L F
.805 .626 .66 r
.33407 .58948 m .33407 .58948 L .33407 .58947 L F
.383 .226 .541 r
.33585 .59111 m .33372 .59127 L .33406 .58949 L F
.33372 .59127 m .3335 .59129 L .33406 .58949 L F
.661 .957 .942 r
.33449 .58935 m .33421 .5895 L .33419 .58951 L F
.383 .226 .541 r
.33585 .59111 m .3341 .58952 L .33616 .58857 L F
.661 .957 .942 r
.33509 .58903 m .33449 .58935 L .33442 .58936 L F
.383 .226 .541 r
.3341 .58952 m .33588 .58864 L .33616 .58857 L F
.661 .957 .942 r
.3367 .58817 m .33509 .58903 L .33438 .58937 L F
.33509 .58903 m .33442 .58936 L .33438 .58937 L F
.33449 .58935 m .33419 .58951 L .33078 .58984 L F
.581 .413 .619 r
.33616 .58857 m .33611 .58852 L .33618 .58849 L F
.154 0 0 r
.33248 .59209 m .3335 .59129 L .33585 .59111 L F
.657 .472 .622 r
.33839 .58808 m .33585 .59111 L .33616 .58857 L F
.154 0 0 r
.33248 .59209 m .33585 .59111 L .33445 .59199 L F
.33431 .59206 m .33445 .59199 L .33434 .59206 L F
.33248 .59209 m .33445 .59199 L .33431 .59206 L F
.661 .957 .942 r
.33666 .58829 m .33078 .58984 L .33526 .5916 L F
.33576 .59136 m .33526 .5916 L .33564 .59175 L F
.439 .273 .557 r
.33666 .58829 m .33839 .58808 L .33671 .58845 L F
0 0 .13 r
.33675 .58816 m .3367 .58817 L .33666 .58829 L F
.661 .957 .942 r
.3367 .58817 m .33663 .58819 L .33666 .58829 L F
.439 .273 .557 r
.33663 .58817 m .33674 .58816 L .33666 .58829 L F
.33674 .58816 m .33839 .58808 L .33666 .58829 L F
.653 .561 .738 r
.33661 .58812 m .3367 .58817 L .33665 .58812 L F
.439 .273 .557 r
.33818 .58785 m .33839 .58808 L .33622 .58819 L F
0 0 .13 r
.33798 .58774 m .33675 .58816 L .33581 .59118 L F
.33675 .58816 m .33666 .58829 L .33581 .59118 L F
.33602 .5911 m .33581 .59118 L .33564 .59175 L F
0 0 0 r
.33593 .5911 m .33603 .59109 L .33581 .59118 L F
0 0 .13 r
.33798 .58774 m .33581 .59118 L .33602 .5911 L F
.661 .957 .942 r
.33581 .59118 m .33526 .5916 L .33576 .59136 L F
.33531 .59147 m .33526 .5916 L .33581 .59118 L F
.752 .438 .453 r
.33434 .59206 m .33564 .59175 L .33517 .59156 L F
0 0 0 r
.33517 .59156 m .33448 .59197 L .33445 .59199 L F
.397 .853 .811 r
.32933 .5926 m .33143 .59217 L .3335 .59129 L F
.32933 .5926 m .3335 .59129 L .33248 .59209 L F
.752 .438 .453 r
.33434 .59206 m .33517 .59156 L .33078 .58984 L F
0 0 0 r
.33603 .59109 m .33624 .59107 L .33602 .5911 L F
.657 .472 .622 r
.33839 .58808 m .33865 .59079 L .33585 .59111 L F
0 0 .13 r
.33798 .58774 m .33602 .5911 L .33624 .59107 L F
.33602 .5911 m .33564 .59175 L .33624 .59107 L F
0 0 0 r
.33602 .5911 m .33624 .59107 L .33581 .59118 L F
.33581 .59118 m .33624 .59107 L .33448 .59197 L F
.33581 .59118 m .33448 .59197 L .33517 .59156 L F
.33445 .59199 m .33624 .59107 L .33434 .59206 L F
.33585 .59111 m .33593 .5911 L .33445 .59199 L F
.661 .957 .942 r
.33666 .58829 m .33531 .59147 L .33581 .59118 L F
.33663 .58819 m .33078 .58984 L .33666 .58829 L F
.653 .561 .738 r
.3325 .58574 m .33661 .58812 L .33444 .58526 L F
.33661 .58812 m .33665 .58812 L .33444 .58526 L F
.3325 .58574 m .33444 .58526 L .33431 .5851 L F
.976 .717 .472 r
.27968 .67875 m .27746 .68287 L .27735 .68027 L F
.27968 .67875 m .27976 .68195 L .27746 .68287 L F
.602 .717 .926 r
.27591 .68105 m .27746 .68287 L .27976 .68195 L F
.332 .745 .979 r
.30797 .53224 m .3116 .53285 L .30905 .5329 L F
.397 .83 .954 r
.26596 .53152 m .26823 .53103 L .26989 .53141 L F
.254 .747 .913 r
.26989 .53141 m .27019 .53068 L .27223 .53119 L F
.26989 .53141 m .26823 .53103 L .27019 .53068 L F
.282 .186 .564 r
.16249 .58325 m .16418 .585 L .16426 .58251 L F
.16249 .58325 m .16215 .5869 L .16418 .585 L F
.117 .645 .874 r
.244 .63703 m .24357 .6366 L .24082 .63653 L F
.113 .615 .901 r
.244 .63703 m .24528 .6366 L .24357 .6366 L F
.244 .63703 m .24747 .63767 L .24528 .6366 L F
.957 .678 .466 r
.27591 .55219 m .27768 .55498 L .27736 .55201 L F
.6 .511 .725 r
.27726 .5494 m .27736 .55201 L .27925 .55022 L F
.672 .236 .206 r
.31366 .60709 m .31787 .60739 L .31505 .60557 L F
.834 .693 .707 r
.53251 .53728 m .52813 .5365 L .53077 .5362 L F
.53251 .53728 m .5282 .53906 L .52813 .5365 L F
.53251 .53728 m .53009 .54147 L .5282 .53906 L F
.558 .487 .732 r
.33545 .59558 m .33849 .59813 L .33796 .5954 L F
.527 .806 .997 r
.50944 .5691 m .51064 .56717 L .50797 .56744 L F
.50944 .5691 m .51258 .56853 L .51064 .56717 L F
0 0 .187 r
.31435 .6156 m .31377 .61404 L .31586 .61352 L F
.31435 .6156 m .31357 .61647 L .31377 .61404 L F
.982 .761 .529 r
.31758 .55373 m .31844 .55469 L .3196 .55235 L F
.783 .355 .234 r
.3196 .55235 m .3217 .55556 L .31758 .55373 L F
.765 .253 0 r
.23212 .55886 m .2334 .55949 L .23173 .55702 L F
.078 .639 .733 r
.23557 .55942 m .23475 .55945 L .23314 .55957 L F
.589 .188 .249 r
.23475 .55945 m .23325 .56027 L .23314 .55957 L F
.23544 .55939 m .23476 .55972 L .23475 .55945 L F
.23476 .55972 m .23108 .56146 L .23475 .55945 L F
.23544 .55939 m .23372 .5618 L .23108 .56146 L F
.765 .253 0 r
.2334 .55949 m .23478 .56017 L .23411 .55947 L F
.23478 .56017 m .23478 .56015 L .23411 .55947 L F
.2334 .55949 m .23411 .55947 L .23173 .55702 L F
.078 .639 .733 r
.2376 .5593 m .23544 .55939 L .23475 .55945 L F
.2376 .5593 m .23475 .55945 L .23557 .55942 L F
.764 .408 .382 r
.23173 .55702 m .2348 .56018 L .23677 .55906 L F
.401 0 0 r
.23825 .55904 m .23544 .55939 L .2376 .5593 L F
.23958 .55852 m .23705 .55905 L .23825 .55904 L F
.23958 .55852 m .23779 .55965 L .23608 .55947 L F
.23705 .55905 m .23608 .55947 L .23544 .55939 L F
.23705 .55905 m .23544 .55939 L .23825 .55904 L F
.23958 .55852 m .23608 .55947 L .23705 .55905 L F
.08 0 0 r
.236 .5595 m .23595 .55906 L .23677 .55906 L F
.2348 .56018 m .23512 .55988 L .236 .5595 L F
.23512 .55988 m .2355 .55951 L .236 .5595 L F
0 0 0 r
.2355 .55951 m .23544 .55939 L .23608 .55947 L F
.2354 .55951 m .23541 .55948 L .2355 .55951 L F
.23541 .55948 m .23544 .55939 L .2355 .55951 L F
.08 0 0 r
.2355 .55951 m .23599 .55947 L .236 .5595 L F
0 0 0 r
.2354 .55951 m .23608 .55947 L .23779 .55965 L F
.08 0 0 r
.2355 .55951 m .23595 .55906 L .23599 .55947 L F
.63 .079 0 r
.23173 .55702 m .23677 .55906 L .23345 .55683 L F
.08 0 0 r
.23595 .55906 m .23807 .557 L .23677 .55905 L F
.23595 .55906 m .23677 .55905 L .23677 .55906 L F
.2355 .55951 m .23655 .55961 L .23807 .557 L F
.23655 .55961 m .23662 .55956 L .23807 .557 L F
.2348 .56018 m .23624 .55972 L .2355 .55951 L F
0 0 0 r
.23648 .55974 m .2354 .55951 L .23779 .55965 L F
.08 0 0 r
.23624 .55972 m .23659 .55961 L .2355 .55951 L F
0 0 0 r
.23528 .55983 m .23372 .5618 L .23478 .56032 L F
.23534 .55965 m .23478 .56032 L .23544 .55939 L F
.412 .758 .995 r
.23349 .55951 m .23624 .55972 L .23486 .56016 L F
0 0 0 r
.23528 .55983 m .23478 .56032 L .23534 .55965 L F
.412 .758 .995 r
.23543 .55955 m .23651 .5596 L .23624 .55972 L F
.23212 .55886 m .23553 .55943 L .23543 .55955 L F
.23553 .55943 m .23651 .5596 L .23543 .55955 L F
.701 .981 .896 r
.23832 .55806 m .23634 .55975 L .23818 .55849 L F
.412 .758 .995 r
.23651 .5596 m .23659 .55961 L .2365 .55964 L F
.23651 .5596 m .2365 .55964 L .23624 .55972 L F
0 0 0 r
.23528 .55983 m .23534 .55965 L .23648 .55974 L F
.701 .981 .896 r
.23651 .5596 m .23528 .55983 L .23634 .55975 L F
0 0 0 r
.23807 .557 m .23659 .55961 L .23832 .55806 L F
.701 .981 .896 r
.23832 .55806 m .23663 .55904 L .23651 .5596 L F
0 0 0 r
.23534 .55965 m .2354 .55951 L .23648 .55974 L F
.412 .758 .995 r
.23212 .55886 m .23624 .55972 L .23349 .55951 L F
.276 0 0 r
.23212 .55886 m .2346 .55952 L .2363 .5596 L F
.701 .981 .896 r
.23568 .5596 m .23528 .55983 L .23651 .5596 L F
.276 0 0 r
.23651 .5596 m .2363 .5596 L .23659 .55961 L F
.23212 .55886 m .2363 .5596 L .23651 .5596 L F
.701 .981 .896 r
.23651 .5596 m .23528 .55983 L .23651 .5596 L F
.23663 .55904 m .23568 .5596 L .23651 .5596 L F
.23818 .55849 m .23634 .55975 L .23779 .55965 L F
.08 0 0 r
.23655 .55961 m .23659 .55961 L .23662 .55956 L F
.765 .253 0 r
.23478 .56017 m .2348 .56018 L .23478 .56015 L F
.412 .758 .995 r
.23478 .56017 m .23486 .56016 L .2348 .56018 L F
.23212 .55886 m .23486 .56016 L .23478 .56017 L F
.589 .188 .249 r
.23325 .56027 m .23108 .56146 L .23231 .56033 L F
.23325 .56027 m .23231 .56033 L .23314 .55957 L F
.245 0 0 r
.2463 .55864 m .24175 .5603 L .24375 .5584 L F
.623 .595 .801 r
.35279 .61685 m .34943 .61464 L .35185 .61396 L F
.436 .595 .91 r
.20936 .62529 m .21031 .62701 L .21137 .62506 L F
.439 .598 .912 r
.21031 .62701 m .21212 .62686 L .21137 .62506 L F
.592 .696 .914 r
.19546 .59765 m .1949 .60063 L .19329 .598 L F
.19546 .59765 m .1975 .60024 L .1949 .60063 L F
.797 .925 .921 r
.27751 .67815 m .27735 .68027 L .27591 .68105 L F
.27751 .67815 m .27968 .67875 L .27735 .68027 L F
.222 .744 .817 r
.34061 .53683 m .3431 .53641 L .34469 .53643 L F
.474 .867 .97 r
.34709 .53572 m .34469 .53643 L .34546 .53511 L F
.561 .935 .897 r
.34469 .53643 m .3431 .53641 L .34546 .53511 L F
.639 .55 .738 r
.34848 .53946 m .34469 .53643 L .34709 .53572 L F
.74 .498 .564 r
.30849 .63841 m .30907 .63588 L .3047 .63605 L F
.639 .511 .691 r
.30907 .63588 m .31169 .63547 L .31095 .63219 L F
.572 .288 .447 r
.31092 .63818 m .30907 .63588 L .30849 .63841 L F
.31092 .63818 m .31169 .63547 L .30907 .63588 L F
.755 .688 .787 r
.27065 .6845 m .27488 .68479 L .27123 .68029 L F
.429 .512 .842 r
.35365 .61411 m .35279 .61685 L .35185 .61396 L F
.35365 .61411 m .35545 .61654 L .35279 .61685 L F
.423 .184 .445 r
.35545 .61654 m .3525 .61915 L .35279 .61685 L F
.173 .123 .556 r
.30283 .59238 m .30432 .59173 L .3041 .58844 L F
.226 .158 .568 r
.30283 .59238 m .30449 .5944 L .30432 .59173 L F
.30283 .59238 m .30315 .59501 L .30449 .5944 L F
.497 .248 .467 r
.3317 .56728 m .32884 .57029 L .32945 .5678 L F
.706 .799 .923 r
.35477 .53697 m .3508 .53646 L .35303 .53535 L F
.44 .61 .921 r
.3548 .53415 m .35477 .53697 L .35303 .53535 L F
.3548 .53415 m .35702 .53663 L .35477 .53697 L F
.279 .751 .939 r
.27223 .53119 m .27477 .53082 L .27641 .53157 L F
.041 0 0 r
.27477 .53082 m .27871 .531 L .27641 .53157 L F
.615 .828 .982 r
.33485 .53523 m .33201 .53614 L .33019 .53492 L F
.422 .076 .271 r
.20364 .56522 m .19897 .56956 L .20045 .56723 L F
.305 .045 .345 r
.16561 .57624 m .16832 .57297 L .16647 .57384 L F
.766 .824 .898 r
.34785 .55975 m .34797 .56238 L .35 .56146 L F
.752 .903 .944 r
.34658 .56141 m .35 .56146 L .34785 .55975 L F
.34658 .56141 m .34797 .56238 L .35 .56146 L F
.35 .56146 m .34658 .56141 L .34785 .55975 L F
.35 .56146 m .34797 .56238 L .34658 .56141 L F
.367 .488 .85 r
.34797 .56238 m .35063 .56398 L .35 .56146 L F
.25 .017 .352 r
.35 .56146 m .35229 .56055 L .35268 .55829 L F
.149 .02 .437 r
.35063 .56398 m .35229 .56055 L .35 .56146 L F
.347 .759 .98 r
.2181 .6169 m .21778 .61792 L .21594 .61698 L F
.2181 .6169 m .21995 .61772 L .21778 .61792 L F
.038 0 .043 r
.3243 .62314 m .3214 .62602 L .32233 .62425 L F
.805 .626 .66 r
.32907 .58859 m .3325 .58574 L .33017 .58629 L F
.303 0 0 r
.30693 .65442 m .30416 .65376 L .30621 .65373 L F
.30693 .65442 m .30621 .65373 L .30787 .6537 L F
.745 .223 0 r
.30787 .6537 m .30789 .6555 L .30693 .65442 L F
0 0 .502 r
.30693 .65442 m .30789 .6555 L .30723 .65472 L F
.725 .365 .368 r
.30787 .6537 m .30416 .65376 L .30575 .65116 L F
0 0 .502 r
.30693 .65442 m .30683 .65111 L .30515 .65272 L F
.369 0 .161 r
.30575 .65116 m .30416 .65376 L .30272 .65342 L F
.844 .915 .882 r
.30515 .65272 m .30683 .65111 L .30487 .65006 L F
0 0 .502 r
.30693 .65442 m .30527 .65238 L .30683 .65111 L F
.30693 .65442 m .30723 .65472 L .30527 .65238 L F
0 .453 .753 r
.30674 .65437 m .30416 .65376 L .30693 .65442 L F
.30218 .65304 m .30416 .65376 L .30674 .65437 L F
.369 0 .161 r
.30272 .65342 m .30416 .65376 L .30185 .65408 L F
.614 .446 .631 r
.36191 .60403 m .35946 .60727 L .35964 .60492 L F
.363 0 .115 r
.25262 .55551 m .25106 .55782 L .24862 .55827 L F
.281 0 .067 r
.25341 .55716 m .25262 .55551 L .25495 .55513 L F
.25341 .55716 m .25106 .55782 L .25262 .55551 L F
.327 .81 .869 r
.2363 .53468 m .24062 .53412 L .23839 .53468 L F
.643 .544 .728 r
.35251 .55546 m .35522 .55521 L .35497 .5529 L F
.472 .344 .625 r
.35251 .55546 m .35484 .55752 L .35522 .55521 L F
.35251 .55546 m .35268 .55829 L .35484 .55752 L F
.145 0 .357 r
.28026 .59553 m .28213 .59452 L .28219 .59227 L F
.2 0 .289 r
.27985 .5975 m .28213 .59452 L .28026 .59553 L F
.696 .431 .517 r
.31569 .65109 m .31434 .6538 L .31188 .65355 L F
.656 .384 .496 r
.31815 .6535 m .31569 .65109 L .31834 .65112 L F
.31815 .6535 m .31434 .6538 L .31569 .65109 L F
.178 .038 .441 r
.33676 .60172 m .33817 .60114 L .33849 .59813 L F
.368 .189 .502 r
.33676 .60172 m .33853 .60373 L .33817 .60114 L F
.33676 .60172 m .33659 .6043 L .33853 .60373 L F
.978 .726 .485 r
.52524 .53047 m .52359 .53222 L .52534 .52909 L F
.52524 .53047 m .52527 .53384 L .52359 .53222 L F
.261 0 .272 r
.1944 .57333 m .19161 .57624 L .19238 .57418 L F
.209 0 0 r
.31473 .54556 m .31327 .54723 L .31085 .5476 L F
.508 .356 .609 r
.31506 .54872 m .31743 .545 L .31473 .54556 L F
0 0 0 r
.31689 .54515 m .31327 .54723 L .31473 .54556 L F
.535 .342 .566 r
.31743 .545 m .31689 .54515 L .31473 .54556 L F
.304 .795 .873 r
.27871 .531 m .28087 .53052 L .28257 .53055 L F
.093 .649 .784 r
.28262 .53025 m .28257 .53055 L .28087 .53052 L F
.28262 .53025 m .28486 .53046 L .28257 .53055 L F
.6 .511 .725 r
.27726 .5494 m .27925 .55022 L .27808 .54664 L F
.709 .899 .528 r
.29125 .58338 m .28897 .5867 L .28981 .5853 L F
0 0 .299 r
.29125 .58338 m .2924 .58229 L .29251 .57927 L F
.069 0 .227 r
.28981 .5853 m .2924 .58229 L .29125 .58338 L F
.305 .536 .91 r
.18349 .60808 m .18746 .61102 L .18537 .60769 L F
.358 .514 .877 r
.18537 .60769 m .18746 .61102 L .18937 .61085 L F
.52 .248 .443 r
.28647 .63856 m .28899 .6383 L .28961 .63585 L F
.369 .111 .386 r
.28961 .63585 m .29112 .63756 L .29162 .63528 L F
.28961 .63585 m .28899 .6383 L .29112 .63756 L F
.847 .888 .869 r
.31548 .55443 m .31421 .55778 L .317 .55701 L F
.31548 .55443 m .31305 .55741 L .31421 .55778 L F
.31 .28 .662 r
.31395 .59455 m .31196 .59275 L .31323 .59151 L F
0 0 0 r
.31752 .58908 m .31511 .59159 L .3138 .59119 L F
.978 .734 .498 r
.31378 .5898 m .31511 .59159 L .31477 .59006 L F
.31378 .5898 m .31477 .59006 L .31413 .58713 L F
.205 0 0 r
.31002 .58881 m .31202 .58936 L .31378 .5898 L F
0 .43 .804 r
.3122 .58938 m .31378 .5898 L .31202 .58936 L F
.817 .555 .543 r
.31002 .58881 m .31378 .5898 L .31413 .58713 L F
0 .43 .804 r
.31463 .58968 m .31378 .5898 L .3122 .58938 L F
0 .161 .687 r
.31378 .5898 m .31519 .59161 L .31511 .59159 L F
.621 .302 .409 r
.31731 .59412 m .31323 .59151 L .31511 .59159 L F
.31731 .59412 m .31511 .59159 L .31624 .59296 L F
0 .161 .687 r
.31519 .59161 m .31624 .59296 L .31511 .59159 L F
0 0 0 r
.3138 .59119 m .31511 .59159 L .31323 .59151 L F
.621 .302 .409 r
.31731 .59412 m .31395 .59455 L .31323 .59151 L F
.367 .408 .771 r
.29054 .626 m .29329 .62929 L .29272 .62568 L F
.282 .107 .457 r
.18657 .57976 m .18614 .58302 L .18465 .58307 L F
.508 .562 .846 r
.18845 .58617 m .18465 .58307 L .18654 .58527 L F
.295 .23 .612 r
.18614 .58302 m .18654 .58527 L .18465 .58307 L F
.594 .808 .982 r
.27961 .63121 m .27482 .63086 L .27747 .62935 L F
.483 .465 .762 r
.28067 .62964 m .27961 .63121 L .27747 .62935 L F
.28067 .62964 m .28163 .63154 L .27961 .63121 L F
.542 .909 .957 r
.22072 .75584 m .22242 .75606 L .22282 .75494 L F
.406 .792 .99 r
.22282 .75494 m .22242 .75606 L .22459 .75573 L F
.542 .909 .957 r
.22282 .75494 m .22242 .75606 L .22072 .75584 L F
.406 .792 .99 r
.22459 .75573 m .22242 .75606 L .22282 .75494 L F
.22282 .75494 m .22242 .75606 L .22459 .75573 L F
.897 .884 .811 r
.28685 .65105 m .28731 .64836 L .28559 .64753 L F
.783 .289 0 r
.28726 .65278 m .28685 .65105 L .28501 .65313 L F
.26 .74 .932 r
.24062 .53412 m .2428 .53396 L .24472 .5345 L F
.168 .696 .864 r
.2428 .53396 m .24699 .53414 L .24472 .5345 L F
.273 .135 .504 r
.16393 .57979 m .16561 .57624 L .16385 .5771 L F
.677 .442 .558 r
.30195 .56449 m .30566 .56443 L .30577 .56167 L F
.789 .68 .744 r
.30577 .56167 m .30646 .55884 L .30455 .55808 L F
0 0 .495 r
.31727 .6176 m .31832 .61869 L .31766 .61571 L F
.31727 .6176 m .31892 .61948 L .31832 .61869 L F
0 .149 .684 r
.31727 .6176 m .31874 .62041 L .31892 .61948 L F
.02 0 0 r
.20795 .54288 m .20399 .54599 L .2062 .54529 L F
0 0 .096 r
.29952 .56467 m .29725 .56766 L .29928 .56623 L F
.089 0 .435 r
.29753 .57045 m .29928 .56623 L .29725 .56766 L F
.945 .82 .374 r
.54886 .55339 m .54893 .55801 L .54945 .55551 L F
0 0 .197 r
.28799 .58865 m .28981 .5853 L .28897 .5867 L F
.724 .823 .927 r
.24946 .54722 m .24738 .5491 L .25117 .54916 L F
.282 0 .232 r
.2482 .55184 m .25117 .54916 L .24738 .5491 L F
.2482 .55184 m .25038 .55122 L .25117 .54916 L F
0 0 .249 r
.25252 .55017 m .25399 .54694 L .2517 .54761 L F
.779 .507 .526 r
.25399 .54694 m .25303 .54725 L .2517 .54761 L F
.355 .65 .967 r
.25117 .54916 m .2517 .54761 L .25018 .54803 L F
.243 0 .214 r
.25117 .54916 m .25252 .55017 L .2517 .54761 L F
.779 .507 .526 r
.25303 .54725 m .24944 .5484 L .2517 .54761 L F
.355 .65 .967 r
.25018 .54803 m .2517 .54761 L .24946 .54722 L F
.243 0 .214 r
.25117 .54916 m .25038 .55122 L .25252 .55017 L F
.672 .531 .685 r
.36942 .57672 m .36673 .57702 L .36921 .57387 L F
.437 .228 .496 r
.36942 .57672 m .3672 .5797 L .36673 .57702 L F
0 0 0 r
.18506 .55775 m .18639 .55743 L .18823 .5557 L F
.042 0 0 r
.18823 .5557 m .18855 .55667 L .19044 .55504 L F
.18823 .5557 m .18639 .55743 L .18855 .55667 L F
.134 .599 .923 r
.29088 .53168 m .28872 .53153 L .28708 .53044 L F
.217 0 0 r
.32096 .56404 m .32319 .56351 L .32473 .56146 L F
.37 .304 .652 r
.32473 .56146 m .32666 .56108 L .3262 .5578 L F
.736 .338 .296 r
.32473 .56146 m .32688 .5636 L .32666 .56108 L F
.32473 .56146 m .32319 .56351 L .32688 .5636 L F
.005 .565 .808 r
.21995 .61772 m .22256 .61802 L .22412 .61851 L F
0 .416 .769 r
.22455 .61832 m .22412 .61851 L .22256 .61802 L F
.22455 .61832 m .22635 .61923 L .22412 .61851 L F
.652 .27 .307 r
.25648 .69987 m .25225 .69859 L .25654 .69769 L F
.839 .673 .676 r
.38276 .54888 m .37839 .55102 L .37912 .54839 L F
.38276 .54888 m .38131 .55222 L .37839 .55102 L F
.571 .542 .783 r
.38658 .55193 m .38276 .54888 L .38567 .54951 L F
.533 .523 .79 r
.26787 .67241 m .26901 .67617 L .27157 .67568 L F
.298 .665 .973 r
.26856 .64075 m .27139 .64193 L .26976 .64081 L F
.218 .698 .934 r
.27139 .64193 m .27177 .64127 L .26976 .64081 L F
.27139 .64193 m .27365 .64195 L .27177 .64127 L F
0 0 .034 r
.31874 .62041 m .31863 .62245 L .31892 .61948 L F
.641 .708 .896 r
.51197 .565 m .51405 .5644 L .5134 .56601 L F
0 0 .14 r
.5134 .56601 m .5137 .56763 L .51258 .56853 L F
.44 .478 .803 r
.51405 .5644 m .51732 .56604 L .5134 .56601 L F
.357 0 .088 r
.5134 .56601 m .51732 .56604 L .5137 .56763 L F
.484 .65 .932 r
.18349 .60808 m .18492 .60562 L .1821 .60645 L F
.18349 .60808 m .18537 .60769 L .18492 .60562 L F
.295 .263 .652 r
.16305 .58912 m .16418 .585 L .16215 .5869 L F
.967 .741 .545 r
.49217 .5975 m .49355 .60109 L .49398 .59815 L F
.49398 .59815 m .49355 .60109 L .49217 .5975 L F
.543 .374 .602 r
.37154 .57362 m .36942 .57672 L .36921 .57387 L F
.16 0 .383 r
.31089 .62514 m .30988 .62338 L .3107 .62251 L F
.31089 .62514 m .30932 .62604 L .30988 .62338 L F
.546 .404 .639 r
.31095 .63219 m .3136 .63264 L .31324 .6291 L F
.526 .438 .698 r
.31095 .63219 m .31392 .63492 L .3136 .63264 L F
.31095 .63219 m .31169 .63547 L .31392 .63492 L F
.466 .421 .724 r
.36362 .59831 m .36428 .6008 L .36132 .59921 L F
.468 .421 .722 r
.36428 .6008 m .36228 .60154 L .36132 .59921 L F
.841 .436 .273 r
.51452 .54611 m .51299 .54753 L .51278 .54617 L F
.187 .292 .74 r
.51498 .54255 m .51452 .54611 L .51278 .54617 L F
.51498 .54255 m .51607 .54504 L .51452 .54611 L F
.257 0 .175 r
.51607 .54504 m .51299 .54753 L .51452 .54611 L F
.76 .661 .752 r
.35844 .5425 m .36037 .54666 L .3551 .54587 L F
.339 .756 .978 r
.3551 .54587 m .35856 .54589 L .36037 .54666 L F
.677 .373 .452 r
.35627 .54778 m .35896 .5487 L .36037 .54666 L F
.575 .573 .813 r
.3622 .54476 m .36037 .54666 L .35844 .5425 L F
.724 .435 .488 r
.32207 .65348 m .31815 .6535 L .31834 .65112 L F
.578 .818 .99 r
.2619 .54793 m .26409 .54936 L .26632 .54858 L F
.662 .403 .517 r
.26359 .55015 m .26632 .54858 L .26409 .54936 L F
0 .225 .743 r
.18876 .58462 m .18845 .58617 L .18654 .58527 L F
.18876 .58462 m .19097 .58887 L .18845 .58617 L F
.624 .21 .238 r
.29928 .56623 m .30159 .56651 L .29952 .56467 L F
.53 .244 .424 r
.29952 .56467 m .30159 .56651 L .30195 .56449 L F
.129 .678 .782 r
.24927 .53344 m .25326 .53322 L .25099 .53394 L F
0 0 0 r
.2813 .54247 m .27826 .54457 L .2789 .54417 L F
.638 .479 .651 r
.34516 .56217 m .34377 .56294 L .34292 .56242 L F
.19 .582 .941 r
.22818 .61979 m .22776 .62079 L .22635 .61923 L F
.22818 .61979 m .23044 .62138 L .22776 .62079 L F
.682 .426 .529 r
.32207 .65348 m .32533 .65379 L .32346 .65175 L F
.32207 .65348 m .32346 .65175 L .32339 .65216 L F
.651 .135 0 r
.32339 .65216 m .32533 .65379 L .32346 .65175 L F
.63 .576 .775 r
.3511 .54988 m .35497 .5529 L .35379 .54839 L F
.838 .96 .624 r
.35379 .54839 m .35389 .54718 L .3551 .54587 L F
.589 .48 .697 r
.35379 .54839 m .3572 .55175 L .35627 .54778 L F
.35379 .54839 m .35497 .5529 L .3572 .55175 L F
.524 .412 .668 r
.37756 .57282 m .37474 .571 L .37701 .56926 L F
.37756 .57282 m .37522 .57341 L .37474 .571 L F
.322 .249 .617 r
.29785 .62086 m .30005 .62142 L .30043 .61927 L F
.29785 .62086 m .29848 .62247 L .30005 .62142 L F
.731 .525 .613 r
.29245 .54644 m .29256 .54891 L .28892 .54865 L F
.498 .308 .554 r
.29509 .54571 m .29256 .54891 L .29245 .54644 L F
.895 .799 .747 r
.54753 .5391 m .55105 .53679 L .54919 .5356 L F
.54753 .5391 m .54894 .54021 L .55105 .53679 L F
.589 .42 .62 r
.35222 .62938 m .35278 .63218 L .34974 .63251 L F
.556 .298 .48 r
.34974 .63251 m .35202 .63474 L .35278 .63218 L F
.589 .42 .62 r
.34974 .63251 m .35278 .63218 L .35222 .62938 L F
.556 .298 .48 r
.35278 .63218 m .35202 .63474 L .34974 .63251 L F
.589 .42 .62 r
.34974 .63251 m .35278 .63218 L .35222 .62938 L F
0 .394 .78 r
.23044 .62138 m .23234 .62209 L .23223 .62242 L F
.393 .113 .364 r
.19161 .57624 m .18886 .57898 L .18971 .57727 L F
.429 .009 .139 r
.22089 .55832 m .21915 .5605 L .21673 .5606 L F
.524 .112 .202 r
.22332 .56006 m .21915 .5605 L .22089 .55832 L F
.291 .648 .968 r
.28104 .64589 m .28559 .64753 L .28367 .64683 L F
0 .334 .741 r
.28559 .64753 m .28546 .6471 L .28367 .64683 L F
.28559 .64753 m .28731 .64836 L .28546 .6471 L F
.155 .647 .917 r
.29139 .65304 m .293 .65397 L .28929 .65332 L F
.613 .155 .14 r
.28929 .65332 m .29115 .65568 L .28914 .65422 L F
.28929 .65332 m .293 .65397 L .29115 .65568 L F
.155 .647 .917 r
.29139 .65304 m .28929 .65332 L .28914 .65422 L F
.87 .425 .084 r
.28726 .65278 m .28929 .65332 L .28914 .65422 L F
0 0 0 r
.32814 .61071 m .32403 .61232 L .32436 .61265 L F
.767 .697 .785 r
.24738 .5491 m .24462 .55209 L .2482 .55184 L F
.393 .016 .2 r
.24445 .55491 m .2482 .55184 L .24462 .55209 L F
.24445 .55491 m .24664 .55479 L .2482 .55184 L F
.477 .157 .345 r
.24664 .55479 m .25038 .55122 L .2482 .55184 L F
.73 .53 .62 r
.36483 .54239 m .36819 .54527 L .36887 .54291 L F
.278 .219 .609 r
.36819 .54527 m .36968 .541 L .36887 .54291 L F
.71 .767 .896 r
.36483 .54239 m .36887 .54291 L .36753 .54105 L F
.607 .088 0 r
.52198 .53701 m .52329 .53513 L .52372 .53679 L F
.52198 .53701 m .52046 .53811 L .52329 .53513 L F
.52198 .53701 m .52431 .5386 L .52046 .53811 L F
.533 .22 .383 r
.52372 .53679 m .52431 .5386 L .52198 .53701 L F
.618 .408 .575 r
.21443 .56105 m .21172 .56393 L .21194 .56141 L F
.588 .727 .94 r
.23071 .63503 m .23466 .63629 L .2329 .63462 L F
.556 .75 .967 r
.2329 .63462 m .23466 .63629 L .23658 .63577 L F
.748 .637 .738 r
.34075 .62559 m .34177 .62829 L .34176 .62647 L F
.34075 .62559 m .33952 .62946 L .34177 .62829 L F
.296 .733 .967 r
.33963 .57362 m .34104 .5729 L .3384 .57288 L F
.577 .584 .824 r
.37136 .55804 m .36947 .55955 L .3686 .5569 L F
.366 .178 .488 r
.31297 .61851 m .31096 .6171 L .31357 .61647 L F
.31297 .61851 m .31098 .61903 L .31096 .6171 L F
.397 .767 .993 r
.24248 .62411 m .24187 .62519 L .24036 .62482 L F
.24248 .62411 m .24428 .62502 L .24187 .62519 L F
0 0 0 r
.49559 .55706 m .49576 .55637 L .49583 .55579 L F
0 0 .27 r
.49559 .55706 m .49652 .56076 L .49576 .55637 L F
.437 .228 .496 r
.36942 .57672 m .36941 .57918 L .3672 .5797 L F
.464 .3 .574 r
.36934 .58218 m .3672 .5797 L .36941 .57918 L F
.36934 .58218 m .3673 .58291 L .3672 .5797 L F
0 0 0 r
.22581 .55218 m .22462 .55441 L .22332 .55527 L F
.149 .274 .737 r
.22462 .55441 m .22569 .55691 L .22332 .55527 L F
.795 .701 .761 r
.2527 .71219 m .25713 .71175 L .25499 .71422 L F
.645 .243 .268 r
.25644 .71223 m .2571 .70973 L .25358 .70984 L F
.546 .354 .572 r
.27342 .62306 m .27373 .62756 L .27044 .62689 L F
.214 0 .308 r
.27453 .62313 m .27342 .62306 L .27584 .6198 L F
.513 .383 .64 r
.27453 .62313 m .27373 .62756 L .27342 .62306 L F
.25 .055 .409 r
.29541 .57364 m .29709 .57302 L .29753 .57045 L F
0 0 .244 r
.29495 .57603 m .29709 .57302 L .29541 .57364 L F
.389 .292 .623 r
.27904 .66347 m .28127 .66603 L .28122 .66297 L F
.681 .614 .774 r
.3508 .53646 m .34848 .53946 L .34709 .53572 L F
.547 .518 .775 r
.36626 .59499 m .3641 .59565 L .36302 .59204 L F
.455 .206 .447 r
.3659 .59764 m .3641 .59565 L .36626 .59499 L F
.3659 .59764 m .36362 .59831 L .3641 .59565 L F
.543 .374 .602 r
.37154 .57362 m .37198 .57648 L .36942 .57672 L F
.453 .24 .499 r
.37164 .57853 m .36942 .57672 L .37198 .57648 L F
.37164 .57853 m .36941 .57918 L .36942 .57672 L F
.681 .535 .681 r
.35123 .62322 m .34842 .62554 L .34827 .62384 L F
.392 .02 .208 r
.27808 .54664 m .27584 .54593 L .27826 .54457 L F
.27808 .54664 m .27472 .54835 L .27584 .54593 L F
.652 .27 .307 r
.25648 .69987 m .25744 .69758 L .25225 .69859 L F
.423 .784 .996 r
.26013 .70007 m .26462 .70038 L .26306 .69598 L F
.26013 .70007 m .2617 .69788 L .26283 .69655 L F
.2617 .69788 m .26306 .69598 L .26283 .69655 L F
.609 .947 .783 r
.26306 .69598 m .2662 .69377 L .26283 .69655 L F
.821 .878 .886 r
.26283 .69655 m .2662 .69377 L .26547 .69343 L F
.26283 .69655 m .26547 .69343 L .26377 .69263 L F
.721 .664 .792 r
.25525 .69379 m .25857 .69807 L .26283 .69655 L F
.25857 .69807 m .26013 .70007 L .26217 .69741 L F
.25857 .69807 m .26217 .69741 L .26283 .69655 L F
0 .059 .603 r
.25888 .69836 m .26013 .70007 L .25857 .69807 L F
.25888 .69836 m .25857 .69807 L .25525 .69379 L F
.25888 .69836 m .25839 .6981 L .25648 .69987 L F
.25839 .6981 m .25744 .69758 L .25712 .69833 L F
.25839 .6981 m .25712 .69833 L .25648 .69987 L F
.25888 .69836 m .25525 .69379 L .25744 .69758 L F
.514 .594 .872 r
.26544 .55379 m .26588 .55096 L .26359 .55015 L F
.26544 .55379 m .26779 .55402 L .26588 .55096 L F
0 0 0 r
.27584 .6198 m .27808 .61665 L .2778 .61896 L F
.034 0 .203 r
.27453 .62313 m .27584 .6198 L .2778 .61896 L F
.19 .005 .384 r
.32175 .5823 m .31961 .58569 L .31953 .58322 L F
.429 .509 .839 r
.19277 .61416 m .19108 .61446 L .19283 .61411 L F
.43 .533 .861 r
.18937 .61085 m .19108 .61446 L .19277 .61416 L F
.128 0 .109 r
.30997 .58307 m .31093 .58434 L .31134 .58194 L F
.30997 .58307 m .30873 .58529 L .31093 .58434 L F
.413 .166 .427 r
.27373 .62756 m .27129 .62877 L .27044 .62689 L F
.319 .517 .892 r
.28524 .66165 m .28406 .65981 L .28367 .66244 L F
.67 .655 .826 r
.37902 .56122 m .37568 .55843 L .37756 .56029 L F
.939 .879 .749 r
.37902 .56122 m .37769 .5577 L .38066 .5586 L F
.37902 .56122 m .37756 .56029 L .37769 .5577 L F
0 0 0 r
.21887 .53873 m .21664 .53956 L .21469 .54105 L F
.489 .866 .98 r
.32817 .62608 m .32597 .62678 L .32366 .62581 L F
.602 .036 0 r
.30646 .55884 m .3026 .55749 L .30455 .55808 L F
.845 .994 .843 r
.3082 .60595 m .30531 .60829 L .30755 .60777 L F
.347 .01 .243 r
.30755 .60777 m .31179 .60455 L .3082 .60595 L F
.243 .104 .484 r
.27208 .55447 m .27038 .55153 L .26952 .55346 L F
.27208 .55447 m .27376 .55167 L .27038 .55153 L F
.27208 .55447 m .27328 .55478 L .27376 .55167 L F
.806 .981 .701 r
.26269 .55026 m .2612 .55251 L .26359 .55015 L F
.578 .818 .99 r
.2619 .54793 m .26632 .54858 L .26423 .54705 L F
.923 .635 .479 r
.2619 .54793 m .26197 .55035 L .26359 .55015 L F
.806 .981 .701 r
.26197 .55035 m .26128 .5523 L .26269 .55026 L F
.26128 .5523 m .2612 .55251 L .26269 .55026 L F
.566 .014 0 r
.26359 .55015 m .26588 .55096 L .26197 .55035 L F
.26359 .55015 m .26588 .55096 L .26197 .55035 L F
.662 .403 .517 r
.26359 .55015 m .26588 .55096 L .26632 .54858 L F
.285 .031 .343 r
.26423 .54705 m .26306 .55045 L .26263 .55041 L F
.35 .429 .802 r
.26306 .55045 m .26613 .5524 L .26288 .5507 L F
.2647 .54825 m .26537 .5502 L .26306 .55045 L F
.26537 .5502 m .26613 .5524 L .26306 .55045 L F
0 0 .01 r
.2647 .54825 m .26306 .55045 L .26356 .54901 L F
.35 .429 .802 r
.2647 .54825 m .26288 .5507 L .26259 .55055 L F
.524 .209 .375 r
.26635 .55349 m .26372 .55143 L .26613 .5524 L F
.26288 .55077 m .26259 .55055 L .26288 .5507 L F
.26288 .55077 m .26288 .5507 L .26613 .5524 L F
.26635 .55349 m .26251 .55476 L .26259 .55055 L F
0 0 .01 r
.2647 .54825 m .26285 .55122 L .26306 .55045 L F
.26285 .55122 m .26274 .55139 L .26286 .55104 L F
.26285 .55122 m .26286 .55104 L .26306 .55045 L F
.35 .429 .802 r
.2647 .54825 m .26264 .5505 L .26274 .55139 L F
.26264 .5505 m .26259 .55055 L .26274 .55139 L F
.285 .031 .343 r
.26252 .54955 m .26263 .55041 L .26197 .55035 L F
.26423 .54705 m .26263 .55041 L .26252 .54955 L F
.302 .1 .431 r
.26259 .55055 m .26143 .55242 L .26197 .55035 L F
.26259 .55055 m .26197 .55035 L .26238 .55091 L F
.505 .194 .373 r
.26259 .55055 m .26251 .55476 L .2617 .55488 L F
.302 .1 .431 r
.26259 .55055 m .26238 .55091 L .26249 .55105 L F
.505 .194 .373 r
.26259 .55055 m .2617 .55488 L .26 .55513 L F
.302 .1 .431 r
.26259 .55055 m .26249 .55105 L .26274 .55139 L F
.59 .633 .862 r
.2644 .54807 m .26267 .55117 L .2647 .54825 L F
.505 .194 .373 r
.26259 .55055 m .26145 .55251 L .26143 .55242 L F
.26145 .55251 m .26072 .55376 L .26114 .55297 L F
.26145 .55251 m .26114 .55297 L .26143 .55242 L F
.285 .031 .343 r
.26306 .55045 m .26281 .5512 L .26291 .55047 L F
.26281 .5512 m .26274 .55139 L .26291 .55047 L F
.26291 .55047 m .26274 .55139 L .26212 .55055 L F
.59 .633 .862 r
.26267 .55117 m .26285 .55122 L .2647 .54825 L F
.505 .194 .373 r
.26259 .55055 m .262 .55159 L .26188 .55177 L F
.285 .031 .343 r
.26306 .55045 m .26212 .55055 L .26197 .55035 L F
.26423 .54705 m .26197 .55035 L .2619 .54793 L F
.613 .647 .86 r
.25953 .54712 m .26274 .55139 L .26097 .54614 L F
.396 .186 .473 r
.26143 .55242 m .25939 .5537 L .26197 .55035 L F
.323 .773 .957 r
.25791 .55032 m .26274 .55139 L .25953 .54712 L F
.469 .027 .114 r
.26244 .55105 m .2647 .54825 L .26285 .55122 L F
0 0 .01 r
.26448 .54768 m .26356 .54901 L .26423 .54705 L F
.59 .633 .862 r
.26097 .54614 m .26254 .5508 L .2644 .54807 L F
.469 .027 .114 r
.26048 .55024 m .26415 .54851 L .26244 .55105 L F
0 0 .01 r
.2647 .54825 m .26356 .54901 L .26448 .54768 L F
.59 .633 .862 r
.26254 .5508 m .26267 .55117 L .2644 .54807 L F
.469 .027 .114 r
.26415 .54851 m .2647 .54825 L .26244 .55105 L F
.505 .194 .373 r
.26188 .55177 m .26 .55513 L .26072 .55376 L F
.262 .55159 m .26 .55513 L .26188 .55177 L F
.59 .633 .862 r
.26267 .55117 m .26274 .55139 L .26285 .55122 L F
.469 .027 .114 r
.26255 .55129 m .26285 .55122 L .26274 .55139 L F
.26048 .55024 m .26285 .55122 L .26255 .55129 L F
.524 .209 .375 r
.26372 .55143 m .26329 .5511 L .26464 .55166 L F
.26329 .5511 m .26288 .55077 L .26345 .55106 L F
.26329 .5511 m .26345 .55106 L .26464 .55166 L F
.26372 .55143 m .26464 .55166 L .26613 .5524 L F
.045 0 0 r
.22647 .55344 m .22581 .55218 L .22819 .55227 L F
.22647 .55344 m .22462 .55441 L .22581 .55218 L F
.34 .42 .798 r
.19746 .61649 m .19879 .62016 L .20033 .61996 L F
.19879 .62016 m .20123 .62114 L .20033 .61996 L F
.623 .607 .813 r
.19879 .62016 m .2028 .62228 L .20123 .62114 L F
.655 .711 .888 r
.33032 .63733 m .33219 .6397 L .33408 .63879 L F
0 0 0 r
.30463 .6323 m .30758 .62961 L .30671 .63177 L F
0 0 .472 r
.3059 .63438 m .30463 .6323 L .30671 .63177 L F
.3059 .63438 m .3047 .63605 L .30463 .6323 L F
.164 0 .347 r
.34708 .57395 m .3466 .57612 L .34852 .57297 L F
.66 .955 .946 r
.37784 .55521 m .37667 .55476 L .37916 .55328 L F
.37784 .55521 m .37667 .55476 L .37916 .55328 L F
.47 .302 .57 r
.37904 .55477 m .37667 .55476 L .37916 .55328 L F
.145 .668 .881 r
.37422 .55474 m .37667 .55476 L .37784 .55521 L F
.788 .62 .672 r
.37784 .55521 m .37396 .55471 L .37667 .55476 L F
.3762 .55765 m .37568 .55843 L .37507 .55711 L F
.11 0 .175 r
.37784 .55521 m .37769 .5577 L .37568 .55843 L F
.835 .654 .658 r
.37473 .56153 m .37136 .55804 L .37568 .55843 L F
.732 .597 .706 r
.37293 .55603 m .37568 .55843 L .37136 .55804 L F
.697 .582 .723 r
.37396 .55471 m .37568 .55843 L .37354 .55632 L F
.732 .597 .706 r
.37507 .55711 m .37344 .55648 L .37367 .55641 L F
.581 .242 .359 r
.37386 .55654 m .37377 .55659 L .37363 .55642 L F
.37367 .55641 m .37363 .55642 L .37354 .55632 L F
.37386 .55654 m .37363 .55642 L .37367 .55641 L F
.732 .597 .706 r
.37507 .55711 m .37568 .55843 L .37344 .55648 L F
.37367 .55641 m .37344 .55648 L .37293 .55603 L F
.63 .095 0 r
.37585 .55908 m .37568 .55843 L .37354 .55632 L F
.37598 .55923 m .37597 .55919 L .37585 .55908 L F
.37597 .55919 m .37568 .55843 L .37585 .55908 L F
.556 0 0 r
.37348 .55631 m .37367 .55641 L .37354 .55632 L F
.979 .917 .622 r
.37354 .55632 m .37348 .55631 L .37396 .55471 L F
.732 .597 .706 r
.37396 .55471 m .37348 .55631 L .37293 .55603 L F
.768 .957 .645 r
.37396 .55471 m .37136 .55804 L .37213 .55623 L F
.979 .917 .622 r
.37348 .55631 m .37213 .55623 L .37396 .55471 L F
.732 .597 .706 r
.37396 .55471 m .37507 .55711 L .37348 .55631 L F
.63 .095 0 r
.37598 .55923 m .37756 .56029 L .37568 .55843 L F
.581 .242 .359 r
.37665 .55847 m .37598 .55923 L .37585 .55908 L F
.37665 .55847 m .37585 .55908 L .37377 .55659 L F
.37665 .55847 m .37377 .55659 L .37386 .55654 L F
.556 0 0 r
.37213 .55623 m .37665 .55847 L .37386 .55654 L F
.788 .62 .672 r
.37784 .55521 m .3762 .55765 L .37462 .55612 L F
.3762 .55765 m .37507 .55711 L .37462 .55612 L F
.37655 .55505 m .37462 .55612 L .37396 .55471 L F
.37784 .55521 m .37462 .55612 L .37655 .55505 L F
.783 .555 .592 r
.37667 .55476 m .37665 .55847 L .37386 .55709 L F
.556 0 0 r
.37213 .55623 m .37386 .55654 L .37337 .55631 L F
.783 .555 .592 r
.37279 .55602 m .37386 .55709 L .37213 .55623 L F
.556 0 0 r
.37337 .55631 m .37386 .55654 L .37367 .55641 L F
.37337 .55631 m .37367 .55641 L .37348 .55631 L F
.783 .555 .592 r
.37667 .55476 m .37386 .55709 L .37279 .55602 L F
.337 0 .212 r
.37784 .55521 m .37769 .5577 L .38032 .55466 L F
.902 .753 .687 r
.38066 .5586 m .37769 .5577 L .38032 .55466 L F
0 0 0 r
.38032 .55466 m .37769 .5577 L .37891 .55637 L F
.47 .302 .57 r
.37891 .55637 m .37667 .55476 L .37904 .55477 L F
.145 .668 .881 r
.37396 .55471 m .37667 .55476 L .37422 .55474 L F
0 .056 .604 r
.29304 .55155 m .29406 .5555 L .29466 .55378 L F
.584 .86 .995 r
.29466 .55378 m .29406 .5555 L .29657 .5547 L F
.613 .499 .701 r
.38919 .55105 m .38567 .54951 L .38765 .54767 L F
.38919 .55105 m .38658 .55193 L .38567 .54951 L F
.111 .463 .889 r
.2797 .64401 m .28104 .64589 L .28367 .64683 L F
.713 .36 .378 r
.53182 .52395 m .53394 .52642 L .53599 .52436 L F
.762 .43 .423 r
.53599 .52436 m .53394 .52642 L .5379 .52685 L F
0 0 0 r
.221 .53776 m .22327 .53747 L .22573 .53704 L F
.581 .148 .185 r
.22327 .53747 m .2278 .53586 L .22573 .53704 L F
.42 .146 .389 r
.31392 .63492 m .31169 .63547 L .31092 .63818 L F
.26 .392 .807 r
.5331 .54627 m .53441 .54416 L .53289 .54471 L F
.5331 .54627 m .53601 .5477 L .53441 .54416 L F
.5331 .54627 m .53601 .5477 L .53441 .54416 L F
.639 .531 .715 r
.36428 .6008 m .36191 .60403 L .36228 .60154 L F
.097 0 0 r
.18506 .55775 m .18548 .55914 L .18639 .55743 L F
.18506 .55775 m .18347 .55995 L .18548 .55914 L F
.43 .21 .477 r
.32431 .57656 m .3242 .57925 L .32187 .57987 L F
.49 .257 .489 r
.32663 .57834 m .32431 .57656 L .32607 .57389 L F
.32663 .57834 m .3242 .57925 L .32431 .57656 L F
.316 .049 .341 r
.29251 .57927 m .29471 .57885 L .29495 .57603 L F
0 0 .244 r
.29495 .57603 m .29656 .57538 L .29709 .57302 L F
.107 0 .283 r
.29495 .57603 m .29621 .57787 L .29656 .57538 L F
.29495 .57603 m .29471 .57885 L .29621 .57787 L F
.382 .027 .233 r
.3088 .57188 m .30712 .57068 L .30927 .57056 L F
.3088 .57188 m .30639 .57251 L .30712 .57068 L F
.537 .408 .652 r
.33439 .60788 m .33702 .60712 L .33659 .6043 L F
.627 .434 .601 r
.334 .61017 m .33702 .60712 L .33439 .60788 L F
.835 .654 .658 r
.37473 .56153 m .37361 .5616 L .37136 .55804 L F
.838 .687 .696 r
.37473 .56153 m .37281 .56409 L .37361 .5616 L F
.612 .516 .721 r
.30315 .59501 m .3032 .59862 L .3061 .59784 L F
.599 .471 .677 r
.3032 .59862 m .30394 .60079 L .3061 .59784 L F
.636 .499 .679 r
.77991 .40453 m .78213 .40328 L .78035 .3998 L F
.676 .516 .66 r
.78035 .3998 m .78213 .40328 L .78407 .39965 L F
.44 .722 .985 r
.29796 .65266 m .29951 .65415 L .30004 .65235 L F
.928 .632 .461 r
.36769 .53734 m .36596 .53806 L .3655 .53337 L F
.483 .832 .997 r
.36596 .53806 m .36192 .5378 L .3655 .53337 L F
.404 .793 .989 r
.36596 .53806 m .36783 .53753 L .36564 .53733 L F
.36596 .53806 m .36564 .53733 L .36416 .53718 L F
.844 .999 .804 r
.36636 .53896 m .36596 .53806 L .36769 .53734 L F
.366 .53939 m .36596 .53806 L .36636 .53896 L F
0 .144 .689 r
.366 .53939 m .36753 .54105 L .36596 .53806 L F
.541 .333 .547 r
.366 .53939 m .36483 .54239 L .36753 .54105 L F
.422 .076 .271 r
.20364 .56522 m .20127 .56919 L .19897 .56956 L F
.31 0 .16 r
.20563 .56424 m .2044 .56637 L .20364 .56522 L F
.53 .252 .438 r
.2044 .56637 m .20127 .56919 L .20364 .56522 L F
.852 .658 .639 r
.33625 .63121 m .33952 .62946 L .33524 .62944 L F
.33625 .63121 m .33936 .63226 L .33952 .62946 L F
.314 .717 .978 r
.2028 .62228 m .20326 .62134 L .20123 .62114 L F
.2028 .62228 m .20522 .62238 L .20326 .62134 L F
.636 .736 .921 r
.31382 .57284 m .31749 .57355 L .31658 .57208 L F
.74 .609 .711 r
.31382 .57284 m .31471 .57661 L .31749 .57355 L F
.591 .389 .575 r
.31471 .57661 m .31753 .57642 L .31749 .57355 L F
.489 .659 .937 r
.31658 .57208 m .31749 .57355 L .31859 .57235 L F
.259 .133 .511 r
.31749 .57355 m .31929 .5752 L .31859 .57235 L F
.31749 .57355 m .31753 .57642 L .31929 .5752 L F
.295 .263 .652 r
.16305 .58912 m .16447 .58865 L .16418 .585 L F
.298 .271 .66 r
.16305 .58912 m .16509 .59111 L .16447 .58865 L F
.294 .271 .662 r
.16374 .59189 m .16509 .59111 L .16305 .58912 L F
.521 .359 .602 r
.37452 .57588 m .37154 .57362 L .37522 .57341 L F
.37452 .57588 m .37198 .57648 L .37154 .57362 L F
.335 .028 .288 r
.17411 .56735 m .17622 .56671 L .17711 .56452 L F
.233 0 .236 r
.17711 .56452 m .17622 .56671 L .179 .56376 L F
0 0 0 r
.27672 .60506 m .27568 .60716 L .27769 .60399 L F
.323 .752 .972 r
.31755 .53407 m .32039 .5339 L .32183 .5346 L F
.539 .838 .999 r
.32039 .5339 m .32389 .53399 L .32183 .5346 L F
.708 .842 .946 r
.53107 .56955 m .53264 .57099 L .53459 .56954 L F
.53107 .56955 m .53264 .57099 L .53459 .56954 L F
.719 .882 .956 r
.16771 .60157 m .17201 .60109 L .17065 .60138 L F
.4 .814 .976 r
.17454 .60068 m .17249 .60006 L .17201 .60109 L F
.599 .95 .828 r
.17249 .60006 m .17065 .60138 L .17201 .60109 L F
.512 .325 .563 r
.18886 .57898 m .18614 .58302 L .18657 .57976 L F
.299 .471 .862 r
.17488 .60199 m .17604 .60051 L .17454 .60068 L F
.17488 .60199 m .17803 .60389 L .17604 .60051 L F
.98 .823 .617 r
.54857 .54752 m .55058 .54612 L .54906 .54494 L F
.54857 .54752 m .54995 .54865 L .55058 .54612 L F
.689 .525 .66 r
.34186 .57981 m .34414 .58066 L .34518 .57708 L F
.12 0 .389 r
.34518 .57708 m .34751 .57814 L .3466 .57612 L F
.34518 .57708 m .34414 .58066 L .34751 .57814 L F
.435 .819 .581 r
.33597 .55214 m .33546 .55259 L .33713 .55134 L F
.73 .303 .236 r
.33546 .55259 m .33836 .55458 L .33713 .55134 L F
.33546 .55259 m .33749 .55521 L .33836 .55458 L F
.555 .035 0 r
.20913 .5646 m .20761 .56547 L .20563 .56424 L F
.323 0 0 r
.21172 .56393 m .20761 .56547 L .20913 .5646 L F
0 0 0 r
.35099 .54973 m .35041 .55042 L .34932 .55066 L F
.35041 .55042 m .3483 .55293 L .34932 .55066 L F
.806 .89 .905 r
.3471 .55133 m .34839 .55087 L .34932 .55066 L F
.34839 .55087 m .3511 .54988 L .34932 .55066 L F
.65 .963 .793 r
.35246 .54829 m .34932 .55066 L .3511 .54988 L F
.498 .386 .657 r
.35522 .55521 m .3572 .55175 L .35497 .5529 L F
.35522 .55521 m .35739 .55456 L .3572 .55175 L F
.413 .171 .435 r
.35484 .55752 m .35739 .55456 L .35522 .55521 L F
.256 0 0 r
.28672 .63983 m .28899 .6383 L .28647 .63856 L F
.28672 .63983 m .28647 .63856 L .28647 .63707 L F
.373 .554 .903 r
.19012 .59081 m .18939 .59286 L .18789 .59135 L F
.19012 .59081 m .19243 .59401 L .18939 .59286 L F
.851 .838 .832 r
.25648 .69987 m .26013 .70007 L .25888 .69836 L F
0 0 0 r
.31973 .6007 m .31427 .60342 L .31738 .60153 L F
.879 .467 .231 r
.54592 .53243 m .54919 .5356 L .54925 .53374 L F
.466 .271 .531 r
.32373 .58176 m .32187 .57987 L .3242 .57925 L F
.32373 .58176 m .32175 .5823 L .32187 .57987 L F
.307 .05 .351 r
.17966 .56146 m .18094 .56301 L .18147 .56064 L F
.17966 .56146 m .179 .56376 L .18094 .56301 L F
.305 .54 .913 r
.20557 .60278 m .20497 .60455 L .20288 .60205 L F
.285 .518 .902 r
.20557 .60278 m .20681 .60461 L .20497 .60455 L F
.6 .58 .803 r
.33739 .62272 m .33851 .62524 L .34047 .62466 L F
.456 .579 .888 r
.34075 .62559 m .34047 .62466 L .33851 .62524 L F
.6 .316 .459 r
.35268 .55829 m .35509 .56027 L .35484 .55752 L F
.35268 .55829 m .35229 .56055 L .35509 .56027 L F
.306 .193 .557 r
.30288 .55199 m .30576 .55062 L .30482 .54793 L F
0 0 0 r
.30288 .55199 m .30234 .55283 L .30576 .55062 L F
.456 .579 .888 r
.34075 .62559 m .34176 .62647 L .34047 .62466 L F
.587 .635 .866 r
.34176 .62647 m .34242 .62338 L .34047 .62466 L F
.34176 .62647 m .34415 .62602 L .34242 .62338 L F
.979 .707 .438 r
.30435 .54524 m .30239 .54434 L .30415 .54273 L F
.174 0 .19 r
.30473 .54469 m .30397 .54442 L .30239 .54434 L F
.246 0 0 r
.30415 .54273 m .30239 .54434 L .30058 .54424 L F
.174 0 .19 r
.30397 .54442 m .30062 .54323 L .30239 .54434 L F
.246 0 0 r
.30058 .54424 m .30239 .54434 L .29972 .5446 L F
.184 0 .267 r
.32634 .63419 m .32441 .63545 L .32688 .63232 L F
.392 .26 .58 r
.32634 .63419 m .32656 .63781 L .32441 .63545 L F
.237 .482 .888 r
.49802 .5622 m .49925 .5606 L .49652 .56076 L F
.49802 .5622 m .50078 .56305 L .49925 .5606 L F
.182 .492 .903 r
.50044 .56326 m .50078 .56305 L .49802 .5622 L F
.447 .656 .949 r
.50764 .56126 m .50776 .56251 L .50666 .56089 L F
.431 .519 .848 r
.50808 .55878 m .50903 .56177 L .50666 .56089 L F
.804 .73 .782 r
.50177 .56269 m .5047 .56551 L .50763 .56168 L F
.50177 .56269 m .50763 .56168 L .50648 .56291 L F
0 0 .408 r
.50763 .56168 m .50761 .56086 L .50648 .56291 L F
.50761 .56086 m .5076 .56041 L .50757 .56046 L F
.50761 .56086 m .50757 .56046 L .50648 .56291 L F
.447 .656 .949 r
.50903 .56177 m .5085 .56362 L .50776 .56251 L F
.50903 .56177 m .50776 .56251 L .50764 .56126 L F
.50903 .56177 m .51076 .56349 L .5085 .56362 L F
.267 0 0 r
.26156 .6216 m .26608 .62031 L .26351 .62122 L F
.059 .403 .857 r
.27853 .55933 m .27936 .56129 L .27651 .55798 L F
.955 .687 .49 r
.27716 .56268 m .27936 .56129 L .27853 .55933 L F
.27716 .56268 m .27917 .56376 L .27936 .56129 L F
0 .071 .632 r
.54001 .5594 m .54085 .55942 L .5386 .55753 L F
.464 .452 .76 r
.27925 .55022 m .28127 .54787 L .27808 .54664 L F
.27925 .55022 m .28217 .5498 L .28127 .54787 L F
.396 .141 .405 r
.28029 .61345 m .2839 .6098 L .28232 .61276 L F
.054 0 .16 r
.27989 .61601 m .28029 .61345 L .28232 .61276 L F
0 0 0 r
.35419 .61045 m .3533 .61251 L .35185 .61396 L F
.268 .499 .893 r
.3533 .61251 m .35365 .61411 L .35185 .61396 L F
.224 0 0 r
.30396 .56607 m .30696 .56496 L .30566 .56443 L F
.30396 .56607 m .30644 .56592 L .30696 .56496 L F
.069 .614 .841 r
.24357 .6366 m .23779 .63603 L .24082 .63653 L F
.155 .46 .886 r
.38305 .5382 m .38281 .54031 L .38226 .53856 L F
.38305 .5382 m .38605 .54161 L .38281 .54031 L F
.024 0 .164 r
.3706 .55455 m .3686 .5569 L .3686 .55555 L F
0 0 0 r
.24096 .72429 m .2433 .72186 L .24303 .72472 L F
.761 .509 .551 r
.24303 .72472 m .23958 .72124 L .24096 .72429 L F
.456 .702 .973 r
.20144 .60041 m .20114 .60246 L .19987 .60018 L F
.20144 .60041 m .20288 .60205 L .20114 .60246 L F
.973 .762 .335 r
.53769 .55453 m .53709 .55423 L .53719 .55137 L F
.879 .635 .567 r
.53719 .55137 m .53709 .55423 L .53347 .55099 L F
.53719 .55137 m .53347 .55099 L .53523 .55051 L F
.272 .383 .793 r
.53523 .55051 m .53709 .55423 L .53719 .55137 L F
.09 0 .434 r
.53719 .55137 m .53709 .55423 L .53819 .553 L F
.7 .621 .765 r
.53709 .55423 m .54116 .55527 L .53819 .553 L F
.54 .411 .654 r
.54116 .55527 m .54306 .55385 L .53886 .55311 L F
.53854 .55327 m .53886 .55311 L .53819 .553 L F
.54116 .55527 m .53886 .55311 L .53854 .55327 L F
.756 .251 0 r
.53709 .55423 m .53511 .55372 L .53507 .55367 L F
.53708 .55422 m .53507 .55367 L .53347 .55099 L F
.53709 .55423 m .53507 .55367 L .53708 .55422 L F
.77 .573 .632 r
.53819 .553 m .54306 .55385 L .5428 .55107 L F
.272 .383 .793 r
.53523 .55051 m .53887 .55258 L .53709 .55423 L F
.938 .966 .721 r
.53534 .55355 m .53519 .5537 L .53601 .55095 L F
.15 0 .044 r
.53501 .55377 m .53443 .55444 L .53195 .55531 L F
.938 .966 .721 r
.53519 .5537 m .53443 .55444 L .53509 .55367 L F
.15 0 .044 r
.53511 .55372 m .53443 .55444 L .53501 .55377 L F
.938 .966 .721 r
.53509 .55367 m .53443 .55444 L .53481 .55359 L F
.15 0 .044 r
.53507 .55367 m .53195 .55531 L .53347 .55099 L F
.53511 .55372 m .53501 .55377 L .53507 .55367 L F
.53501 .55377 m .53195 .55531 L .53507 .55367 L F
.938 .966 .721 r
.53531 .55329 m .53481 .55359 L .53601 .55095 L F
.53519 .5537 m .53507 .55367 L .53531 .55329 L F
.53507 .55367 m .53481 .55359 L .53531 .55329 L F
.581 .941 .911 r
.53887 .55258 m .53571 .55354 L .53682 .5541 L F
.53768 .55369 m .53682 .5541 L .53709 .55423 L F
.53887 .55258 m .53682 .5541 L .53768 .55369 L F
.53571 .55354 m .53569 .55354 L .53709 .55423 L F
.53569 .55354 m .53527 .55376 L .53709 .55423 L F
.973 .762 .335 r
.53778 .55515 m .53709 .55423 L .53769 .55453 L F
.7 .621 .765 r
.53709 .55423 m .5386 .55753 L .54116 .55527 L F
.422 .186 .449 r
.53965 .55352 m .53696 .55638 L .53542 .55369 L F
.53567 .55355 m .53542 .55369 L .53534 .55355 L F
.53965 .55352 m .53542 .55369 L .53567 .55355 L F
.627 .257 .322 r
.5351 .55379 m .53696 .55638 L .53443 .55444 L F
.53534 .55355 m .53542 .55369 L .5351 .55379 L F
.581 .941 .911 r
.53542 .55369 m .53522 .55375 L .53527 .55376 L F
.627 .257 .322 r
.53542 .55369 m .53696 .55638 L .5351 .55379 L F
.581 .941 .911 r
.53569 .55354 m .53511 .55372 L .53522 .55375 L F
.53569 .55354 m .53522 .55375 L .53542 .55369 L F
.379 .016 .218 r
.28607 .62567 m .28371 .62619 L .28137 .62815 L F
.28607 .62567 m .28371 .62619 L .28137 .62815 L F
.388 0 0 r
.32815 .62301 m .32856 .62413 L .32637 .62204 L F
.364 .047 .287 r
.28213 .59452 m .28493 .59153 L .28219 .59227 L F
.74 .498 .564 r
.30849 .63841 m .3047 .63605 L .30536 .63831 L F
.343 .303 .669 r
.30708 .63791 m .3047 .63605 L .3059 .63438 L F
.30708 .63791 m .30536 .63831 L .3047 .63605 L F
.519 .868 .99 r
.29387 .65271 m .293 .65397 L .29139 .65304 L F
.619 .891 .575 r
.29115 .65568 m .293 .65397 L .29387 .65271 L F
.508 .356 .609 r
.31506 .54872 m .31726 .548 L .31743 .545 L F
.439 .252 .528 r
.31494 .55187 m .31726 .548 L .31506 .54872 L F
.237 .584 .946 r
.23909 .62338 m .23824 .62443 L .23623 .62372 L F
.23909 .62338 m .24036 .62482 L .23824 .62443 L F
.422 .113 .335 r
.37702 .57504 m .37522 .57341 L .37756 .57282 L F
.37702 .57504 m .37452 .57588 L .37522 .57341 L F
.001 0 0 r
.2278 .53586 m .23019 .53579 L .23185 .53569 L F
.588 .066 0 r
.27123 .68029 m .27591 .68105 L .27288 .68014 L F
.021 0 .167 r
.2778 .61896 m .27808 .61665 L .27989 .61601 L F
.647 .902 .579 r
.25444 .71552 m .25202 .71838 L .25251 .71735 L F
.511 .355 .606 r
.25444 .71552 m .25482 .71844 L .25202 .71838 L F
.496 .244 .461 r
.25202 .71838 m .25482 .71844 L .25406 .72087 L F
0 .051 .618 r
.25251 .71735 m .25202 .71838 L .25406 .72087 L F
.31 .28 .662 r
.31395 .59455 m .31223 .59553 L .31196 .59275 L F
.301 .26 .645 r
.31395 .59455 m .31413 .59579 L .31223 .59553 L F
.711 .764 .894 r
.33836 .55458 m .34226 .55528 L .34088 .55367 L F
.244 .671 .961 r
.34461 .55452 m .34088 .55367 L .34226 .55528 L F
.627 .446 .618 r
.33796 .5954 m .34093 .59525 L .34132 .59234 L F
.539 .448 .701 r
.34093 .59525 m .34261 .59126 L .34132 .59234 L F
.793 .949 .608 r
.3177 .58771 m .31511 .59159 L .31752 .58908 L F
.445 .155 .378 r
.32688 .63232 m .32825 .63379 L .32634 .63419 L F
.207 0 0 r
.2318 .55109 m .22941 .55262 L .22819 .55227 L F
.236 0 .01 r
.23489 .54957 m .23445 .55062 L .2318 .55109 L F
.043 0 0 r
.23194 .55185 m .2318 .55109 L .23445 .55062 L F
.23194 .55185 m .22941 .55262 L .2318 .55109 L F
.495 .103 .226 r
.38658 .55193 m .38847 .5536 L .38674 .55356 L F
.438 .114 .318 r
.38919 .55105 m .38847 .5536 L .38658 .55193 L F
.715 .62 .75 r
.52813 .5365 m .52372 .53679 L .52527 .53384 L F
.778 .529 .56 r
.52813 .5365 m .52431 .5386 L .52372 .53679 L F
.52813 .5365 m .5282 .53906 L .52431 .5386 L F
.612 .516 .721 r
.30324 .5951 m .3061 .59784 L .30449 .5944 L F
.96 .634 .247 r
.30449 .5944 m .3061 .59784 L .30492 .59707 L F
.172 .088 .512 r
.30449 .5944 m .30492 .59707 L .30585 .59362 L F
.30449 .5944 m .30585 .59362 L .30586 .59361 L F
.612 .516 .721 r
.30315 .59501 m .30324 .5951 L .30449 .5944 L F
.446 .215 .469 r
.31598 .62598 m .31324 .6291 L .31574 .62855 L F
.55 .395 .624 r
.31598 .62598 m .31844 .62557 L .31863 .62245 L F
.503 .245 .457 r
.31802 .6278 m .31598 .62598 L .31574 .62855 L F
.31802 .6278 m .31844 .62557 L .31598 .62598 L F
0 0 0 r
.28232 .61276 m .2839 .6098 L .28486 .60981 L F
.256 .525 .913 r
.21459 .61503 m .21406 .61661 L .21212 .61413 L F
.273 .544 .923 r
.21459 .61503 m .21594 .61698 L .21406 .61661 L F
.352 .137 .441 r
.33849 .59813 m .34093 .59525 L .33796 .5954 L F
.705 .392 0 r
.27744 .66897 m .27868 .67268 L .2782 .67145 L F
.27744 .66897 m .2782 .67145 L .27857 .66842 L F
.535 .524 .79 r
.36006 .53825 m .35769 .54054 L .35702 .53663 L F
.372 .3 .646 r
.36006 .53825 m .35844 .5425 L .35769 .54054 L F
.543 .405 .644 r
.3136 .63264 m .31574 .62855 L .31324 .6291 L F
.937 .736 .607 r
.3566 .59471 m .35619 .5981 L .35807 .59831 L F
.041 .237 .737 r
.3566 .59471 m .35807 .59831 L .35883 .59676 L F
.611 .92 .975 r
.35807 .59831 m .35619 .5981 L .35883 .59676 L F
.323 .618 .956 r
.19568 .61602 m .19626 .61497 L .19283 .61411 L F
.19568 .61602 m .19746 .61649 L .19626 .61497 L F
.207 .688 .932 r
.24839 .6258 m .24805 .6266 L .24647 .62542 L F
.24839 .6258 m .25056 .62659 L .24805 .6266 L F
0 0 .305 r
.24395 .73791 m .2452 .73415 L .24566 .73654 L F
.626 .824 .976 r
.24169 .73653 m .24395 .73791 L .24566 .73654 L F
.126 .356 .818 r
.2671 .68169 m .26948 .68349 L .26808 .68153 L F
.366 .785 .977 r
.24747 .63767 m .2475 .63648 L .24528 .6366 L F
.24747 .63767 m .2498 .63724 L .2475 .63648 L F
.658 .761 .925 r
.27747 .62935 m .27482 .63086 L .27321 .62884 L F
.12 0 .265 r
.32534 .64104 m .32514 .64358 L .32297 .64462 L F
.195 .102 .516 r
.32494 .64623 m .32297 .64462 L .32514 .64358 L F
.32494 .64623 m .32306 .64736 L .32297 .64462 L F
0 0 0 r
.20172 .54645 m .19892 .54836 L .20098 .54723 L F
.123 0 0 r
.19892 .54836 m .19942 .54986 L .20098 .54723 L F
.19892 .54836 m .19742 .55064 L .19942 .54986 L F
.094 0 .27 r
.27458 .60826 m .27374 .6104 L .27568 .60716 L F
.422 .731 .99 r
.32825 .63379 m .33075 .63535 L .33151 .63389 L F
.241 .508 .905 r
.33075 .63535 m .33216 .63557 L .33151 .63389 L F
.747 .661 .765 r
.33032 .63733 m .33216 .63557 L .33075 .63535 L F
.922 .706 .593 r
.3398 .57891 m .34144 .58253 L .34186 .57981 L F
.581 .02 0 r
.34334 .58134 m .34186 .57981 L .34144 .58253 L F
.34334 .58134 m .34414 .58066 L .34186 .57981 L F
.523 .504 .777 r
.31037 .56328 m .31138 .56697 L .30896 .56759 L F
.477 .308 .573 r
.30896 .56759 m .31176 .56963 L .31138 .56697 L F
.30896 .56759 m .30927 .57056 L .31176 .56963 L F
.30896 .56759 m .31176 .56963 L .31138 .56697 L F
.30896 .56759 m .30927 .57056 L .31176 .56963 L F
.535 .033 .012 r
.3143 .56649 m .31822 .56689 L .31622 .56623 L F
.01 0 .176 r
.2806 .67295 m .28311 .66927 L .28276 .67177 L F
.39 .121 .38 r
.31158 .57971 m .3145 .57898 L .31471 .57661 L F
.568 .266 .416 r
.31471 .57661 m .3145 .57898 L .31673 .57854 L F
.557 .268 .431 r
.31471 .57661 m .31673 .57854 L .31753 .57642 L F
.245 0 0 r
.2463 .55864 m .24404 .56023 L .24175 .5603 L F
.112 0 0 r
.24862 .55827 m .24404 .56023 L .2463 .55864 L F
.071 0 0 r
.20098 .54723 m .20399 .54599 L .20172 .54645 L F
.755 .688 .787 r
.27065 .6845 m .27123 .68029 L .26948 .68349 L F
.64 .733 .916 r
.51076 .56349 m .51405 .5644 L .51197 .565 L F
0 .255 .764 r
.53017 .54215 m .5282 .53906 L .53009 .54147 L F
.714 .675 .811 r
.28431 .65722 m .28501 .65313 L .28354 .65385 L F
.925 .975 .733 r
.52527 .53384 m .52372 .53679 L .52329 .53513 L F
.222 0 .317 r
.29166 .59982 m .2899 .59877 L .29225 .59739 L F
.29166 .59982 m .28987 .60081 L .2899 .59877 L F
.273 .135 .504 r
.16393 .57979 m .16546 .57935 L .16561 .57624 L F
.321 .279 .655 r
.16393 .57979 m .166 .58181 L .16546 .57935 L F
.38 .286 .622 r
.16426 .58251 m .166 .58181 L .16393 .57979 L F
.533 .523 .79 r
.26787 .67241 m .27157 .67568 L .27198 .67252 L F
.733 .215 0 r
.275 .67448 m .27198 .67252 L .27157 .67568 L F
.714 .675 .811 r
.28431 .65722 m .28677 .65785 L .28501 .65313 L F
.694 .665 .817 r
.28501 .65313 m .28677 .65785 L .28914 .65422 L F
.456 .598 .904 r
.19764 .59715 m .1975 .60024 L .19546 .59765 L F
.19764 .59715 m .19987 .60018 L .1975 .60024 L F
.65 .904 .982 r
.25464 .6263 m .25056 .62659 L .25264 .62601 L F
.096 .653 .734 r
.25264 .62601 m .25691 .62564 L .25464 .6263 L F
0 0 0 r
.16832 .57297 m .16983 .57203 L .17161 .57051 L F
.269 0 .023 r
.16983 .57203 m .17356 .56967 L .17161 .57051 L F
0 .378 .751 r
.25942 .6402 m .26121 .64118 L .2617 .64122 L F
.161 .449 .879 r
.21657 .62926 m .21703 .62779 L .21606 .62763 L F
.265 .57 .938 r
.21657 .62926 m .21841 .62947 L .21703 .62779 L F
.572 .052 0 r
.27768 .55498 m .27628 .55625 L .27328 .55478 L F
.361 .511 .872 r
.27919 .55379 m .27768 .55498 L .27591 .55219 L F
.711 .487 .583 r
.27919 .55379 m .27628 .55625 L .27768 .55498 L F
.457 .266 .532 r
.31134 .58194 m .3145 .57898 L .31158 .57971 L F
.443 0 .084 r
.23661 .55036 m .23489 .54957 L .23684 .54828 L F
.23661 .55036 m .23445 .55062 L .23489 .54957 L F
.71 .596 .727 r
.36614 .533 m .36769 .53734 L .3655 .53337 L F
.66 .569 .742 r
.36938 .53547 m .36769 .53734 L .36614 .533 L F
.394 .368 .712 r
.164 .5954 m .16509 .59111 L .16374 .59189 L F
.164 .5954 m .16571 .59488 L .16509 .59111 L F
0 0 .132 r
.16497 .59728 m .16571 .59488 L .164 .5954 L F
.645 .243 .268 r
.25644 .71223 m .25358 .70984 L .2527 .71219 L F
.193 .714 .87 r
.32817 .62608 m .32989 .62589 L .33178 .62615 L F
.455 0 0 r
.33236 .62673 m .33178 .62615 L .32989 .62589 L F
.33236 .62673 m .33444 .62809 L .33178 .62615 L F
.19 .005 .384 r
.32175 .5823 m .3214 .58489 L .31961 .58569 L F
.51 .14 .273 r
.20761 .56547 m .2044 .56637 L .20563 .56424 L F
.5 .424 .702 r
.50566 .56745 m .50763 .56168 L .5047 .56551 L F
.50566 .56745 m .50797 .56744 L .50763 .56168 L F
.614 .405 .575 r
.35946 .60727 m .35679 .61013 L .35686 .60753 L F
.389 .138 .409 r
.17411 .56735 m .17356 .56967 L .17622 .56671 L F
.761 .509 .551 r
.24303 .72472 m .2433 .72186 L .23958 .72124 L F
.483 .803 1 r
.23658 .63577 m .23779 .63603 L .23693 .63428 L F
.16 .612 .934 r
.23779 .63603 m .23952 .63468 L .23693 .63428 L F
.23779 .63603 m .24135 .63607 L .23952 .63468 L F
.069 .614 .841 r
.24357 .6366 m .24135 .63607 L .23779 .63603 L F
.535 .923 .898 r
.54501 .56266 m .5439 .56388 L .54645 .56382 L F
.352 .137 .441 r
.33849 .59813 m .3409 .5975 L .34093 .59525 L F
.239 .089 .466 r
.33849 .59813 m .34032 .59991 L .3409 .5975 L F
.33849 .59813 m .33817 .60114 L .34032 .59991 L F
.616 .493 .69 r
.30394 .60079 m .30782 .60101 L .3061 .59784 L F
.089 0 .435 r
.29753 .57045 m .29979 .5713 L .29928 .56623 L F
.109 0 .39 r
.29733 .57422 m .29842 .57274 L .29823 .57176 L F
.169 0 .205 r
.29823 .57176 m .29979 .5713 L .29801 .57062 L F
0 0 .16 r
.29928 .56623 m .29958 .56923 L .29965 .56807 L F
.29958 .56923 m .29979 .5713 L .29974 .57009 L F
.29958 .56923 m .29974 .57009 L .29965 .56807 L F
.109 0 .39 r
.29842 .57274 m .29986 .57078 L .29823 .57176 L F
.29986 .57078 m .29995 .57067 L .29985 .57073 L F
.086 .038 .501 r
.29823 .57176 m .29965 .56807 L .29979 .5713 L F
.109 0 .39 r
.29986 .57078 m .29985 .57073 L .29823 .57176 L F
.169 0 .205 r
.29823 .57176 m .29801 .57062 L .29753 .57045 L F
0 0 .281 r
.29753 .57045 m .29709 .57302 L .29823 .57176 L F
.772 .766 .847 r
.54116 .55527 m .5386 .55753 L .54238 .55804 L F
.697 .227 .13 r
.5386 .55753 m .54085 .55942 L .54238 .55804 L F
.295 .484 .874 r
.54238 .55804 m .54381 .55653 L .54116 .55527 L F
.533 .848 .545 r
.54238 .55804 m .54085 .55942 L .54381 .55653 L F
.279 .278 .679 r
.32656 .63781 m .32721 .64079 L .32534 .64104 L F
.183 0 .267 r
.32721 .64079 m .32514 .64358 L .32534 .64104 L F
.556 .788 .986 r
.33881 .53515 m .33818 .53728 L .3369 .53521 L F
.33881 .53515 m .34061 .53683 L .33818 .53728 L F
.023 0 .276 r
.30758 .62961 m .30932 .62604 L .30865 .6284 L F
0 0 .001 r
.30671 .63177 m .30758 .62961 L .30865 .6284 L F
.68 .605 .764 r
.36733 .58787 m .36651 .59222 L .36302 .59204 L F
.547 .518 .775 r
.36626 .59499 m .36302 .59204 L .36651 .59222 L F
0 0 .287 r
.37183 .55095 m .3706 .55455 L .37095 .55198 L F
.631 .624 .825 r
.31382 .57284 m .31472 .56882 L .31176 .56963 L F
.31382 .57284 m .31658 .57208 L .31472 .56882 L F
.147 0 0 r
.26593 .64135 m .26856 .64075 L .26976 .64081 L F
.694 .642 .794 r
.17803 .60389 m .17961 .60749 L .1821 .60645 L F
0 0 0 r
.31689 .54515 m .31472 .54656 L .31327 .54723 L F
.678 .972 .792 r
.31897 .54309 m .31753 .54358 L .31689 .54515 L F
.701 .95 .672 r
.31753 .54358 m .31472 .54656 L .31689 .54515 L F
.618 .674 .882 r
.31897 .54309 m .31689 .54515 L .31743 .545 L F
0 .255 .764 r
.53017 .54215 m .53053 .54095 L .5282 .53906 L F
.767 .679 .765 r
.53289 .54471 m .53053 .54095 L .53017 .54215 L F
.185 .3 .749 r
.21079 .61203 m .20994 .61421 L .20857 .6102 L F
.423 .578 .902 r
.21079 .61203 m .21212 .61413 L .20994 .61421 L F
.87 .527 .399 r
.54208 .52682 m .54257 .52948 L .54552 .53029 L F
.804 .593 .616 r
.54257 .52948 m .54592 .53243 L .54552 .53029 L F
0 0 .214 r
.54925 .54072 m .54894 .54021 L .54753 .5391 L F
.54925 .54072 m .54928 .54227 L .54894 .54021 L F
.405 .705 .983 r
.23775 .73636 m .23953 .73772 L .23682 .73777 L F
.23682 .73777 m .23953 .73772 L .23775 .73636 L F
.419 0 0 r
.29256 .54891 m .29119 .54912 L .28892 .54865 L F
.498 .308 .554 r
.29509 .54571 m .29474 .54842 L .29256 .54891 L F
.419 0 .016 r
.29474 .54842 m .29119 .54912 L .29256 .54891 L F
0 0 0 r
.29611 .58808 m .29546 .58923 L .29726 .58597 L F
0 0 .071 r
.29592 .59013 m .29446 .5915 L .29546 .58923 L F
.308 0 0 r
.30967 .53276 m .3116 .53285 L .30797 .53224 L F
.051 .588 .854 r
.31231 .53251 m .3116 .53285 L .30967 .53276 L F
.31231 .53251 m .31391 .53317 L .3116 .53285 L F
.336 .242 .598 r
.27769 .60399 m .27956 .59985 L .27743 .60135 L F
0 0 .464 r
.275 .67448 m .27751 .67815 L .27629 .67449 L F
.666 .364 .452 r
.53174 .52601 m .53394 .52642 L .53182 .52395 L F
.648 .478 .64 r
.35844 .5425 m .3551 .54587 L .35649 .54322 L F
.977 .846 .645 r
.38131 .55222 m .37916 .55328 L .37839 .55102 L F
.38131 .55222 m .38032 .55466 L .37916 .55328 L F
.73 .51 .592 r
.38287 .55459 m .38032 .55466 L .38131 .55222 L F
.342 .549 .909 r
.22677 .63216 m .23071 .63503 L .22927 .63383 L F
.5 .748 .984 r
.23071 .63503 m .23151 .63354 L .22927 .63383 L F
.23071 .63503 m .2329 .63462 L .23151 .63354 L F
.405 .225 .521 r
.304 .57321 m .3037 .57614 L .30154 .57688 L F
.356 .271 .621 r
.3037 .57614 m .3022 .57941 L .30154 .57688 L F
.261 .081 .438 r
.29251 .57927 m .29417 .58125 L .29471 .57885 L F
.29251 .57927 m .2924 .58229 L .29417 .58125 L F
0 .394 .711 r
.27603 .64273 m .2781 .64351 L .2797 .64401 L F
0 0 0 r
.2813 .54247 m .2793 .54398 L .27826 .54457 L F
.697 .561 .697 r
.2813 .54247 m .28604 .54492 L .28336 .54247 L F
.2813 .54247 m .28222 .5473 L .28604 .54492 L F
0 0 0 r
.28135 .54302 m .2813 .54247 L .28336 .54247 L F
.28135 .54302 m .2793 .54398 L .2813 .54247 L F
.34751 .57814 m .34414 .58066 L .34334 .58134 L F
.269 .489 .886 r
.2498 .63724 m .25045 .6389 L .2513 .63733 L F
.405 .661 .964 r
.25045 .6389 m .25453 .63996 L .2513 .63733 L F
.666 .704 .875 r
.30782 .60101 m .30762 .60246 L .30983 .60122 L F
.615 .828 .982 r
.33485 .53523 m .33019 .53492 L .33265 .53384 L F
.406 .608 .931 r
.33538 .53297 m .33485 .53523 L .33265 .53384 L F
.33538 .53297 m .3369 .53521 L .33485 .53523 L F
.725 .212 .001 r
.33625 .63121 m .33797 .63302 L .33936 .63226 L F
0 .101 .625 r
.34102 .63444 m .34096 .6362 L .33936 .63226 L F
.753 .252 .029 r
.33797 .63302 m .34102 .63444 L .33936 .63226 L F
.078 0 0 r
.26413 .53136 m .26823 .53103 L .26596 .53152 L F
.057 .549 .889 r
.24462 .55209 m .24282 .55103 L .24104 .55069 L F
.68 .866 .969 r
.24504 .54956 m .24462 .55209 L .24738 .5491 L F
.24504 .54956 m .24282 .55103 L .24462 .55209 L F
.22 0 .182 r
.28493 .59153 m .28702 .59125 L .28799 .58865 L F
0 0 .197 r
.28799 .58865 m .2895 .5878 L .28981 .5853 L F
.122 0 .138 r
.28799 .58865 m .28893 .59018 L .2895 .5878 L F
.28799 .58865 m .28702 .59125 L .28893 .59018 L F
.041 0 0 r
.27477 .53082 m .27661 .53092 L .27871 .531 L F
.167 .705 .781 r
.27661 .53092 m .28087 .53052 L .27871 .531 L F
.618 .408 .575 r
.21443 .56105 m .21431 .56367 L .21172 .56393 L F
.554 .365 .579 r
.21673 .5606 m .21431 .56367 L .21443 .56105 L F
.71 .617 .751 r
.3525 .61915 m .35412 .62336 L .35123 .62322 L F
.339 .175 .506 r
.35521 .6235 m .35435 .6299 L .35375 .62887 L F
.509 .378 .638 r
.35272 .62484 m .35086 .62595 L .35123 .62322 L F
.35318 .62535 m .35238 .62537 L .35272 .62484 L F
.35318 .62535 m .35272 .62484 L .35412 .62336 L F
.071 0 .124 r
.35582 .62234 m .35318 .62535 L .35412 .62336 L F
0 0 0 r
.35521 .6235 m .35318 .62535 L .35582 .62234 L F
.339 .175 .506 r
.35521 .6235 m .35238 .62537 L .35318 .62535 L F
.35238 .62537 m .3519 .62568 L .35318 .62535 L F
.509 .378 .638 r
.35318 .62535 m .35223 .62559 L .35238 .62537 L F
.494 .334 .593 r
.35062 .62593 m .35225 .62556 L .3519 .62568 L F
.35225 .62556 m .35318 .62535 L .3519 .62568 L F
.339 .175 .506 r
.35241 .6255 m .35375 .62887 L .35203 .62591 L F
.35278 .6251 m .35285 .62535 L .35241 .6255 L F
.35285 .62535 m .35375 .62887 L .35241 .6255 L F
.494 .334 .593 r
.35062 .62593 m .35086 .62595 L .35318 .62535 L F
.509 .378 .638 r
.35223 .62559 m .35086 .62595 L .35272 .62484 L F
.339 .175 .506 r
.35238 .62537 m .35203 .62591 L .3519 .62568 L F
.35278 .6251 m .35203 .62591 L .35238 .62537 L F
.35521 .6235 m .35375 .62887 L .35278 .6251 L F
.509 .378 .638 r
.35272 .62484 m .35123 .62322 L .35231 .62327 L F
.35272 .62484 m .35231 .62327 L .35412 .62336 L F
.467 .481 .789 r
.35582 .62234 m .35412 .62336 L .3525 .61915 L F
.508 .171 .332 r
.29689 .62434 m .30005 .62142 L .29848 .62247 L F
.324 .808 .874 r
.22394 .63255 m .22677 .63216 L .22572 .63075 L F
.334 .624 .957 r
.22572 .63075 m .22677 .63216 L .22735 .63063 L F
.168 .427 .863 r
.22677 .63216 m .22927 .63383 L .22735 .63063 L F
.617 .494 .69 r
.35627 .54778 m .35977 .55124 L .35896 .5487 L F
.35627 .54778 m .3572 .55175 L .35977 .55124 L F
.149 .02 .437 r
.35063 .56398 m .35218 .56311 L .35229 .56055 L F
.657 .649 .83 r
.35083 .56609 m .35218 .56311 L .35063 .56398 L F
.595 .754 .954 r
.33019 .53492 m .32797 .53558 L .3261 .53388 L F
.998 .845 .549 r
.54893 .55801 m .54731 .55943 L .5482 .56016 L F
.945 .82 .374 r
.54886 .55339 m .54845 .55725 L .54893 .55801 L F
.935 .948 .617 r
.54845 .55725 m .54731 .55943 L .54893 .55801 L F
.433 .828 .613 r
.2452 .73415 m .24169 .73653 L .24566 .73654 L F
.951 .621 .361 r
.33444 .62809 m .33625 .63121 L .33524 .62944 L F
.6 .196 .249 r
.34842 .62554 m .34664 .62742 L .34415 .62602 L F
.681 .535 .681 r
.35123 .62322 m .35086 .62595 L .34842 .62554 L F
.676 .291 .31 r
.35062 .62593 m .34842 .62554 L .35086 .62595 L F
.35062 .62593 m .34664 .62742 L .34842 .62554 L F
.648 .274 .321 r
.30769 .64069 m .30849 .63841 L .30536 .63831 L F
.803 .621 .656 r
.30769 .64069 m .31092 .63818 L .30849 .63841 L F
.893 .882 .817 r
.32537 .54176 m .32387 .54558 L .32663 .54545 L F
.32537 .54176 m .32307 .54568 L .32387 .54558 L F
.474 0 0 r
.32307 .54568 m .32663 .54545 L .32387 .54558 L F
.497 .248 .467 r
.3317 .56728 m .33089 .56991 L .32884 .57029 L F
.456 .209 .45 r
.33341 .56837 m .33089 .56991 L .3317 .56728 L F
0 0 0 r
.28214 .67977 m .28036 .68032 L .28219 .67975 L F
.28036 .68032 m .27976 .68195 L .28022 .68034 L F
.28036 .68032 m .28022 .68034 L .281 .67761 L F
.28053 .68031 m .28036 .68032 L .28214 .67977 L F
.721 .837 .937 r
.27823 .68048 m .27976 .68195 L .28036 .68032 L F
0 0 0 r
.27993 .6805 m .28036 .68032 L .28053 .68031 L F
.27854 .68109 m .27993 .6805 L .28214 .67977 L F
.602 .717 .926 r
.27591 .68105 m .2773 .68137 L .27823 .68048 L F
.2773 .68137 m .27976 .68195 L .27868 .68092 L F
.2773 .68137 m .27868 .68092 L .27823 .68048 L F
.16 0 .145 r
.19328 .5522 m .19436 .55305 L .19529 .55145 L F
.19328 .5522 m .19238 .55408 L .19436 .55305 L F
.48 .847 .99 r
.34546 .53511 m .3513 .53531 L .34709 .53572 L F
.626 .678 .879 r
.3513 .53531 m .3508 .53646 L .34709 .53572 L F
.443 .758 .995 r
.51258 .56853 m .51354 .56691 L .51064 .56717 L F
.51258 .56853 m .5137 .56763 L .51354 .56691 L F
.432 .614 .926 r
.20936 .62529 m .20893 .62215 L .20699 .62255 L F
.20936 .62529 m .21137 .62506 L .20893 .62215 L F
.734 .487 .555 r
.32187 .65567 m .31815 .6535 L .32207 .65348 L F
.682 .426 .529 r
.32207 .65348 m .32339 .65216 L .32238 .65016 L F
.689 .446 .55 r
.32533 .65379 m .32187 .65567 L .32207 .65348 L F
.425 .346 .664 r
.33659 .6043 m .33899 .60646 L .33853 .60373 L F
.452 .347 .645 r
.33702 .60712 m .33899 .60646 L .33659 .6043 L F
.413 .166 .427 r
.27373 .62756 m .27321 .62884 L .27129 .62877 L F
.226 0 0 r
.25535 .55625 m .25495 .55513 L .2573 .55453 L F
.25535 .55625 m .25341 .55716 L .25495 .55513 L F
.334 .27 .635 r
.30769 .64069 m .30536 .63831 L .30708 .63791 L F
.202 0 .097 r
.3655 .53337 m .36006 .53825 L .35947 .53571 L F
.681 .411 .506 r
.35947 .53571 m .36177 .53588 L .3655 .53337 L F
.202 0 .097 r
.3655 .53337 m .36192 .5378 L .36006 .53825 L F
.866 .811 .794 r
.3655 .53337 m .36402 .53189 L .36614 .533 L F
.3655 .53337 m .36177 .53588 L .36402 .53189 L F
.618 .674 .882 r
.31897 .54309 m .31743 .545 L .31997 .54455 L F
.295 .053 .366 r
.31726 .548 m .31997 .54455 L .31743 .545 L F
.278 0 0 r
.30159 .56651 m .30566 .56443 L .30195 .56449 L F
.306 .751 .963 r
.27264 .53021 m .27223 .53119 L .27019 .53068 L F
.27264 .53021 m .27477 .53082 L .27223 .53119 L F
.435 .729 .988 r
.31843 .53228 m .31755 .53407 L .31611 .53288 L F
.31843 .53228 m .32039 .5339 L .31755 .53407 L F
.476 .289 .547 r
.29719 .54763 m .29509 .54571 L .2977 .54538 L F
.29719 .54763 m .29474 .54842 L .29509 .54571 L F
.663 .588 .761 r
.36806 .5912 m .36651 .59222 L .36733 .58787 L F
.066 0 .297 r
.36806 .5912 m .36626 .59499 L .36651 .59222 L F
.099 0 .268 r
.30865 .6284 m .30932 .62604 L .31089 .62514 L F
0 .002 .504 r
.31892 .61948 m .31863 .62245 L .31953 .62233 L F
.681 .665 .828 r
.31844 .62557 m .31953 .62233 L .31863 .62245 L F
.84 .788 .802 r
.36478 .52998 m .36614 .533 L .36402 .53189 L F
.832 .786 .808 r
.36845 .53014 m .36614 .533 L .36478 .52998 L F
.386 .157 .44 r
.36845 .53014 m .36821 .53259 L .36614 .533 L F
.66 .569 .742 r
.36938 .53547 m .36614 .533 L .36821 .53259 L F
.514 .277 .492 r
.28311 .66927 m .28509 .66924 L .28276 .67177 L F
0 .238 .649 r
.35129 .62973 m .35019 .62908 L .34888 .62794 L F
.35019 .62908 m .34689 .62713 L .34888 .62794 L F
.529 .069 .105 r
.3478 .62699 m .34888 .62794 L .34664 .62742 L F
.35062 .62593 m .34888 .62794 L .3478 .62699 L F
.642 .252 .29 r
.3519 .62568 m .34888 .62794 L .35062 .62593 L F
.345 .164 .487 r
.3325 .58574 m .33431 .5851 L .33488 .58169 L F
0 0 0 r
.33517 .62147 m .33351 .62172 L .33739 .62272 L F
.501 .824 1 r
.33736 .62111 m .33739 .62272 L .33993 .62186 L F
.33736 .62111 m .33517 .62147 L .33739 .62272 L F
.6 .58 .803 r
.33739 .62272 m .34047 .62466 L .33993 .62186 L F
.925 .975 .733 r
.52527 .53384 m .52329 .53513 L .52359 .53222 L F
.327 .81 .869 r
.2363 .53468 m .23866 .53407 L .24062 .53412 L F
.291 .782 .896 r
.23866 .53407 m .2428 .53396 L .24062 .53412 L F
.644 .232 .248 r
.5379 .52685 m .54029 .52866 L .54208 .52682 L F
.842 .507 .419 r
.54029 .52866 m .54257 .52948 L .54208 .52682 L F
.149 .195 .655 r
.29272 .62568 m .29329 .62929 L .29468 .62766 L F
.227 .312 .743 r
.29329 .62929 m .2957 .63131 L .29468 .62766 L F
.284 .319 .722 r
.29329 .62929 m .2944 .63195 L .2957 .63131 L F
.514 .343 .586 r
.29993 .61358 m .30227 .61305 L .30215 .61038 L F
.493 .282 .522 r
.29993 .61358 m .30202 .61571 L .30227 .61305 L F
.34 .268 .629 r
.30036 .61628 m .30202 .61571 L .29993 .61358 L F
.708 .55 .672 r
.28165 .66011 m .28406 .65981 L .28431 .65722 L F
.372 .3 .646 r
.36006 .53825 m .35997 .54256 L .35844 .5425 L F
.575 .573 .813 r
.3622 .54476 m .35844 .5425 L .35997 .54256 L F
.736 .282 .173 r
.27808 .54664 m .28127 .54787 L .28222 .5473 L F
.368 0 .136 r
.28127 .54787 m .28604 .54492 L .28222 .5473 L F
.776 .822 .889 r
.30912 .55723 m .31079 .55869 L .31305 .55741 L F
.747 .661 .765 r
.33032 .63733 m .33408 .63879 L .33216 .63557 L F
0 .214 .738 r
.33216 .63557 m .33408 .63879 L .33352 .63679 L F
0 .442 .795 r
.33408 .63879 m .336 .63902 L .33352 .63679 L F
.33408 .63879 m .33907 .64057 L .33617 .63904 L F
.916 .655 .16 r
.33622 .63922 m .33621 .6404 L .33364 .6383 L F
.3367 .6394 m .33661 .63959 L .33622 .63922 L F
.33661 .63959 m .33621 .6404 L .33622 .63922 L F
0 .442 .795 r
.336 .63902 m .33617 .63904 L .33437 .63751 L F
.336 .63902 m .33437 .63751 L .33352 .63679 L F
.832 .786 .808 r
.36845 .53014 m .36478 .52998 L .36667 .52851 L F
.542 .796 .992 r
.36926 .52811 m .36845 .53014 L .36667 .52851 L F
.36926 .52811 m .37092 .52954 L .36845 .53014 L F
.456 .21 .452 r
.37092 .52954 m .36821 .53259 L .36845 .53014 L F
0 0 0 r
.31973 .6007 m .31831 .60193 L .31427 .60342 L F
.416 0 0 r
.31835 .59808 m .32185 .60028 L .31973 .6007 L F
.447 0 .064 r
.32185 .60028 m .31831 .60193 L .31973 .6007 L F
.739 .772 .88 r
.28036 .6281 m .28067 .62964 L .27747 .62935 L F
0 .06 .619 r
.28095 .62849 m .28067 .62964 L .28036 .6281 L F
0 .066 .628 r
.28196 .63019 m .28067 .62964 L .28095 .62849 L F
.28196 .63019 m .28092 .63014 L .28067 .62964 L F
.855 .417 .172 r
.27993 .62972 m .28196 .63019 L .28095 .62849 L F
.561 .007 0 r
.27993 .62972 m .28249 .63021 L .28196 .63019 L F
.28249 .63021 m .28413 .63053 L .28196 .63019 L F
0 .066 .628 r
.28196 .63019 m .28163 .63154 L .28092 .63014 L F
.701 .767 .903 r
.35303 .53535 m .3508 .53646 L .3513 .53531 L F
.896 .886 .461 r
.54995 .54865 m .54885 .55017 L .549 .55119 L F
.979 .682 .362 r
.54857 .54752 m .54885 .55017 L .54995 .54865 L F
.045 0 .047 r
.29867 .58468 m .29611 .58808 L .29726 .58597 L F
.489 .077 .184 r
.28892 .54865 m .28758 .5507 L .28483 .55082 L F
.279 0 0 r
.29119 .54912 m .28758 .5507 L .28892 .54865 L F
.535 .367 .6 r
.5207 .54851 m .52113 .55136 L .51828 .55203 L F
.68 .184 .063 r
.52113 .55136 m .5174 .55055 L .51828 .55203 L F
.024 0 .164 r
.3706 .55455 m .36978 .55675 L .3686 .5569 L F
.577 .584 .824 r
.37136 .55804 m .3686 .5569 L .36978 .55675 L F
.734 .478 .542 r
.35278 .63218 m .35202 .63474 L .35463 .63363 L F
.965 .872 .696 r
.54925 .54072 m .54906 .54494 L .54928 .54227 L F
.25 .749 .901 r
.30105 .53121 m .29714 .5311 L .29954 .53062 L F
.347 .731 .986 r
.30233 .53013 m .30105 .53121 L .29954 .53062 L F
.30233 .53013 m .3035 .53125 L .30105 .53121 L F
.178 0 .361 r
.37898 .5665 m .37701 .56926 L .37704 .56692 L F
0 .056 .604 r
.29304 .55155 m .29466 .55378 L .29506 .55108 L F
.368 0 .136 r
.28127 .54787 m .28368 .54742 L .28604 .54492 L F
.504 .659 .93 r
.28604 .54492 m .28573 .54273 L .28336 .54247 L F
.28604 .54492 m .28707 .54439 L .28573 .54273 L F
.33 0 .183 r
.28368 .54742 m .28707 .54439 L .28604 .54492 L F
.39 0 0 r
.13296 .66273 m .13446 .66268 L .13341 .66249 L F
.202 0 .272 r
.28471 .6067 m .28545 .60463 L .28724 .60369 L F
.053 .618 .767 r
.28523 .53028 m .28486 .53046 L .28262 .53025 L F
.28523 .53028 m .28708 .53044 L .28486 .53046 L F
.54 .553 .817 r
.33463 .55021 m .33713 .55134 L .3367 .54857 L F
.33463 .55021 m .33713 .55134 L .3367 .54857 L F
.725 .988 .88 r
.24787 .5479 m .24738 .5491 L .24946 .54722 L F
.457 .074 .225 r
.24787 .5479 m .24504 .54956 L .24738 .5491 L F
.637 .965 .861 r
.35254 .66299 m .3515 .66305 L .35343 .66165 L F
.389 .201 .501 r
.35343 .66165 m .3515 .66305 L .35254 .66299 L F
.159 .623 .931 r
.22077 .61701 m .21995 .61772 L .2181 .6169 L F
.22077 .61701 m .22256 .61802 L .21995 .61772 L F
.369 .626 .952 r
.21212 .62686 m .21286 .62525 L .21137 .62506 L F
.21212 .62686 m .21606 .62763 L .21286 .62525 L F
.628 .925 .974 r
.21208 .54103 m .21012 .54217 L .21071 .54065 L F
.54 .887 .651 r
.35688 .54418 m .3551 .54587 L .35856 .54589 L F
.35688 .54418 m .35395 .54658 L .3551 .54587 L F
.453 .827 .583 r
.25644 .71223 m .25713 .71175 L .25931 .71003 L F
.356 .271 .621 r
.3037 .57614 m .30388 .57887 L .3022 .57941 L F
.367 .301 .65 r
.30388 .57887 m .30463 .5817 L .3022 .57941 L F
0 .292 .79 r
.28196 .63019 m .28406 .6334 L .28163 .63154 L F
.364 .047 .287 r
.28213 .59452 m .28445 .59405 L .28493 .59153 L F
.128 0 .211 r
.28493 .59153 m .28615 .59303 L .28702 .59125 L F
.28493 .59153 m .28445 .59405 L .28615 .59303 L F
.48 .34 .613 r
.34843 .57038 m .35073 .57209 L .35088 .56976 L F
.34843 .57038 m .34852 .57297 L .35073 .57209 L F
.663 .471 .614 r
.3622 .54476 m .36459 .54547 L .36483 .54239 L F
.73 .53 .62 r
.36483 .54239 m .36459 .54547 L .36819 .54527 L F
.694 .642 .794 r
.17803 .60389 m .1821 .60645 L .18054 .60332 L F
.481 .618 .909 r
.1821 .60645 m .18213 .60294 L .18054 .60332 L F
.1821 .60645 m .18492 .60562 L .18213 .60294 L F
.666 .575 .743 r
.31289 .55494 m .31305 .55741 L .31548 .55443 L F
.359 .69 .981 r
.22459 .75573 m .22728 .75588 L .22519 .75444 L F
.22459 .75573 m .22728 .75588 L .22519 .75444 L F
.278 0 0 r
.30182 .56639 m .30396 .56607 L .30566 .56443 L F
.477 .757 .992 r
.30456 .56433 m .30621 .56573 L .30396 .56607 L F
.30621 .56573 m .30644 .56592 L .30396 .56607 L F
.278 0 0 r
.30159 .56651 m .30396 .56607 L .30182 .56639 L F
.196 0 .044 r
.35571 .61108 m .35419 .61045 L .35679 .61013 L F
.35571 .61108 m .3533 .61251 L .35419 .61045 L F
.495 .532 .824 r
.37067 .53196 m .36938 .53547 L .36821 .53259 L F
.37067 .53196 m .37212 .5352 L .36938 .53547 L F
.069 0 .227 r
.28981 .5853 m .29179 .58439 L .2924 .58229 L F
.254 0 .289 r
.28981 .5853 m .29147 .58694 L .29179 .58439 L F
.28981 .5853 m .2895 .5878 L .29147 .58694 L F
.797 .925 .921 r
.27751 .67815 m .27591 .68105 L .27823 .68048 L F
.653 .689 .871 r
.50319 .55783 m .5006 .55863 L .49945 .55682 L F
.942 .662 .479 r
.25251 .71735 m .25482 .71844 L .25444 .71552 L F
.574 .304 .47 r
.37466 .55055 m .37183 .55095 L .37265 .5486 L F
.419 .304 .616 r
.37465 .54788 m .37466 .55055 L .37265 .5486 L F
.37465 .54788 m .37466 .55055 L .37265 .5486 L F
0 0 .342 r
.33367 .5543 m .33205 .55473 L .33368 .55496 L F
.679 .626 .789 r
.33368 .55496 m .33195 .55765 L .33205 .55473 L F
0 0 .342 r
.33367 .5543 m .33195 .55765 L .33205 .55473 L F
.614 .446 .631 r
.36191 .60403 m .36248 .60697 L .35946 .60727 L F
.639 .531 .715 r
.36428 .6008 m .36443 .6039 L .36191 .60403 L F
.524 .386 .635 r
.36459 .60595 m .36191 .60403 L .36443 .6039 L F
.36459 .60595 m .36248 .60697 L .36191 .60403 L F
.689 .446 .55 r
.32533 .65379 m .32442 .65637 L .32187 .65567 L F
0 .156 .628 r
.32339 .65216 m .32623 .65447 L .32533 .65379 L F
.657 .412 .537 r
.32903 .65608 m .32442 .65637 L .32533 .65379 L F
.32903 .65608 m .32533 .65379 L .32623 .65447 L F
.539 .448 .701 r
.34093 .59525 m .34337 .59467 L .34261 .59126 L F
.254 .063 .418 r
.34093 .59525 m .34256 .59673 L .34337 .59467 L F
.34093 .59525 m .3409 .5975 L .34256 .59673 L F
.44 .278 .564 r
.31318 .62118 m .31098 .61903 L .31297 .61851 L F
.31318 .62118 m .3107 .62251 L .31098 .61903 L F
.305 .045 .345 r
.16561 .57624 m .16789 .5755 L .16832 .57297 L F
.308 .127 .464 r
.16789 .5755 m .16983 .57203 L .16832 .57297 L F
.495 .293 .534 r
.29162 .63528 m .29405 .63478 L .2944 .63195 L F
.44 .165 .398 r
.29112 .63756 m .29405 .63478 L .29162 .63528 L F
.556 .75 .967 r
.2329 .63462 m .23658 .63577 L .23526 .63397 L F
.483 .803 1 r
.23658 .63577 m .23693 .63428 L .23526 .63397 L F
.224 .554 .933 r
.19746 .61649 m .19775 .61507 L .19626 .61497 L F
.024 .327 .811 r
.19746 .61649 m .19975 .61808 L .19775 .61507 L F
.34 .42 .798 r
.19746 .61649 m .20033 .61996 L .19975 .61808 L F
.598 .142 .142 r
.3061 .59784 m .30415 .59961 L .30492 .59707 L F
.514 .777 .991 r
.30782 .60101 m .30758 .59968 L .3061 .59784 L F
.598 .142 .142 r
.3061 .59784 m .30758 .59968 L .30415 .59961 L F
.249 .253 .668 r
.27651 .55798 m .2758 .55992 L .27675 .55883 L F
.127 .077 .527 r
.2758 .55992 m .27716 .56268 L .27675 .55883 L F
0 .381 .696 r
.27177 .64127 m .27365 .64195 L .27603 .64273 L F
.674 .588 .751 r
.3827 .55678 m .38066 .5586 L .38032 .55466 L F
.383 .418 .774 r
.3832 .55916 m .38066 .5586 L .3827 .55678 L F
.3832 .55916 m .38222 .56069 L .38066 .5586 L F
.167 0 0 r
.29465 .53178 m .29088 .53168 L .29328 .53122 L F
.521 .846 .998 r
.29588 .53037 m .29465 .53178 L .29328 .53122 L F
.29588 .53037 m .29714 .5311 L .29465 .53178 L F
.846 .811 .816 r
.26423 .54705 m .26632 .54858 L .26854 .54526 L F
.577 .432 .647 r
.26632 .54858 m .26938 .54847 L .26854 .54526 L F
.426 .189 .449 r
.26632 .54858 m .26811 .55031 L .26938 .54847 L F
.26632 .54858 m .26588 .55096 L .26811 .55031 L F
.352 .204 .536 r
.16418 .585 m .166 .58181 L .16426 .58251 L F
.728 .591 .703 r
.3041 .58844 m .30729 .58876 L .30651 .58588 L F
0 0 .477 r
.3041 .58844 m .30539 .59023 L .30729 .58876 L F
0 0 .54 r
.30651 .58588 m .30729 .58876 L .30784 .58701 L F
.787 .968 .666 r
.30729 .58876 m .30539 .59023 L .30784 .58701 L F
.614 .405 .575 r
.35946 .60727 m .35933 .61027 L .35679 .61013 L F
.635 .423 .578 r
.36208 .60978 m .35946 .60727 L .36248 .60697 L F
.36208 .60978 m .35933 .61027 L .35946 .60727 L F
.764 .612 .69 r
.25525 .69379 m .26283 .69655 L .26259 .69468 L F
.922 .906 .79 r
.26386 .68996 m .26259 .69468 L .26377 .69263 L F
.821 .878 .886 r
.26283 .69655 m .26377 .69263 L .26259 .69468 L F
.129 .678 .782 r
.24927 .53344 m .25173 .53321 L .25326 .53322 L F
0 0 0 r
.25173 .53321 m .2555 .53223 L .25326 .53322 L F
.561 .616 .865 r
.26588 .55096 m .26779 .55402 L .26952 .55346 L F
.583 .619 .854 r
.33993 .62186 m .34047 .62466 L .34242 .62338 L F
0 0 0 r
.2555 .53223 m .25781 .53213 L .25945 .53204 L F
.367 .83 .907 r
.25781 .53213 m .26175 .53167 L .25945 .53204 L F
.517 .562 .841 r
.19348 .59388 m .19546 .59765 L .19329 .598 L F
.134 .284 .753 r
.20895 .60643 m .20783 .60778 L .20681 .60461 L F
.495 .565 .856 r
.20895 .60643 m .20857 .6102 L .20783 .60778 L F
.662 .973 .84 r
.30295 .60901 m .30531 .60829 L .30215 .61038 L F
.123 .049 .492 r
.30215 .61038 m .30403 .61171 L .30295 .60901 L F
.30215 .61038 m .30227 .61305 L .30403 .61171 L F
.193 .549 .93 r
.2342 .62181 m .23405 .62331 L .23234 .62209 L F
.2342 .62181 m .23623 .62372 L .23405 .62331 L F
.459 .527 .84 r
.29677 .55335 m .29657 .5547 L .2958 .55285 L F
.29711 .55101 m .29862 .55421 L .29657 .5547 L F
.667 .225 .19 r
.29862 .55421 m .29466 .55378 L .29657 .5547 L F
.29837 .55418 m .29725 .55552 L .29466 .55378 L F
.29862 .55421 m .29855 .55428 L .29837 .55418 L F
.829 .678 .696 r
.29862 .55421 m .29928 .55715 L .29726 .5555 L F
0 0 0 r
.29726 .5555 m .29725 .55552 L .29862 .55421 L F
.667 .225 .19 r
.29855 .55428 m .29725 .55552 L .29837 .55418 L F
.459 .527 .84 r
.29711 .55101 m .29677 .55335 L .29506 .55108 L F
.29677 .55335 m .2958 .55285 L .29506 .55108 L F
.059 0 .042 r
.19897 .56956 m .19623 .57241 L .19718 .57062 L F
0 0 0 r
.22941 .55262 m .22647 .55344 L .22819 .55227 L F
0 0 .54 r
.30651 .58588 m .30784 .58701 L .30873 .58529 L F
0 .182 .695 r
.30435 .54524 m .30473 .54469 L .30239 .54434 L F
.30435 .54524 m .30686 .54726 L .30473 .54469 L F
.398 .325 .657 r
.30482 .54793 m .30686 .54726 L .30435 .54524 L F
0 0 0 r
.19044 .55504 m .19055 .55583 L .19238 .55408 L F
.19044 .55504 m .18855 .55667 L .19055 .55583 L F
.30496 .60887 m .30531 .60829 L .30295 .60901 L F
.30496 .60887 m .30755 .60777 L .30531 .60829 L F
0 .487 .855 r
.28546 .6471 m .28731 .64836 L .29112 .6493 L F
.752 .282 .13 r
.28731 .64836 m .29227 .65213 L .29112 .6493 L F
.235 .293 .72 r
.52198 .54756 m .5207 .54851 L .519 .54919 L F
.52198 .54756 m .52113 .55136 L .5207 .54851 L F
.71 .216 .065 r
.33574 .56035 m .33723 .56223 L .33944 .56144 L F
.402 .281 .599 r
.33944 .56144 m .34196 .56288 L .33992 .56341 L F
.557 .013 0 r
.33723 .56223 m .34196 .56288 L .33944 .56144 L F
.027 .555 .858 r
.24461 .6246 m .24428 .62502 L .24248 .62411 L F
.24461 .6246 m .24647 .62542 L .24428 .62502 L F
.577 .747 .957 r
.51327 .56285 m .51405 .5644 L .51076 .56349 L F
.327 .49 .868 r
.51554 .56266 m .51405 .5644 L .51327 .56285 L F
.51554 .56266 m .51732 .56604 L .51405 .5644 L F
.536 .572 .838 r
.39012 .54709 m .38919 .55105 L .38765 .54767 L F
.39012 .54709 m .39156 .55055 L .38919 .55105 L F
.35 .036 .285 r
.3906 .5529 m .38919 .55105 L .39156 .55055 L F
.507 .826 1 r
.39296 .55234 m .3906 .5529 L .39315 .55 L F
.39296 .55234 m .39263 .55233 L .3906 .5529 L F
.35 .036 .285 r
.3906 .5529 m .3885 .55349 L .38919 .55105 L F
.12 0 .146 r
.39315 .55 m .3906 .5529 L .39156 .55055 L F
.507 .826 1 r
.39263 .55233 m .38966 .55228 L .3906 .5529 L F
.35 .036 .285 r
.3906 .5529 m .38847 .5536 L .3885 .55349 L F
.473 .204 .425 r
.36898 .58388 m .3673 .58291 L .36934 .58218 L F
.36898 .58388 m .36683 .58474 L .3673 .58291 L F
.411 .23 .523 r
.30598 .57519 m .304 .57321 L .30639 .57251 L F
.30598 .57519 m .3037 .57614 L .304 .57321 L F
.678 .432 .542 r
.28367 .66244 m .28406 .65981 L .28165 .66011 L F
.782 .728 .803 r
.2722 .54926 m .27038 .55153 L .27376 .55167 L F
.916 .808 .339 r
.27376 .55167 m .27328 .55478 L .27277 .55165 L F
.27376 .55167 m .27288 .55165 L .27591 .55219 L F
.27288 .55165 m .27307 .5517 L .27591 .55219 L F
.711 .487 .583 r
.27919 .55379 m .2782 .55696 L .27628 .55625 L F
.421 .197 .466 r
.28128 .55581 m .2782 .55696 L .27919 .55379 L F
.478 0 0 r
.27578 .55217 m .27919 .55379 L .27591 .55219 L F
.27709 .55307 m .27919 .55379 L .27578 .55217 L F
.27329 .55182 m .27919 .55379 L .27307 .5517 L F
.527 .638 .903 r
.27344 .55187 m .27359 .55205 L .27919 .55379 L F
.27384 .55214 m .2773 .554 L .27879 .55384 L F
.27349 .55202 m .27394 .55226 L .27384 .55214 L F
.27394 .55226 m .2773 .554 L .27384 .55214 L F
.27349 .55202 m .27879 .55384 L .27919 .55379 L F
.478 0 0 r
.27307 .5517 m .27709 .55307 L .27578 .55217 L F
.527 .638 .903 r
.27349 .55202 m .27628 .55625 L .2773 .554 L F
.27313 .55213 m .27606 .55595 L .27352 .55206 L F
.131 .422 .865 r
.27328 .55478 m .27628 .55625 L .27313 .55213 L F
.27282 .55199 m .27313 .55213 L .27277 .55165 L F
.27328 .55478 m .27313 .55213 L .27282 .55199 L F
.348 .111 .406 r
.27379 .5521 m .27355 .55231 L .27352 .55206 L F
.27355 .55231 m .27306 .55274 L .27339 .55224 L F
.27355 .55231 m .27339 .55224 L .27352 .55206 L F
.27367 .55203 m .27352 .55206 L .27357 .55198 L F
.27379 .5521 m .27352 .55206 L .27367 .55203 L F
.527 .638 .903 r
.27277 .55165 m .27313 .55213 L .27349 .55202 L F
.27313 .55213 m .27352 .55206 L .27349 .55202 L F
.27606 .55595 m .27628 .55625 L .27349 .55202 L F
.818 .75 .789 r
.27526 .54945 m .27353 .55204 L .27349 .55202 L F
.527 .638 .903 r
.27277 .55165 m .27349 .55202 L .27359 .55205 L F
.27277 .55165 m .27359 .55205 L .27344 .55187 L F
.478 0 0 r
.27277 .55165 m .27329 .55182 L .27307 .5517 L F
.916 .808 .339 r
.27288 .55165 m .27277 .55165 L .27307 .5517 L F
.818 .75 .789 r
.27312 .55145 m .27349 .55202 L .27277 .55177 L F
.27526 .54945 m .27349 .55202 L .27312 .55145 L F
.459 .144 .344 r
.27827 .55259 m .27577 .55329 L .27464 .55306 L F
.27433 .5527 m .27464 .55306 L .27306 .55274 L F
.27827 .55259 m .27464 .55306 L .27433 .5527 L F
.348 .111 .406 r
.27761 .54873 m .27822 .55096 L .27392 .55244 L F
.2737 .55218 m .27392 .55244 L .27306 .55274 L F
.27761 .54873 m .27392 .55244 L .2737 .55218 L F
.818 .75 .789 r
.27277 .55177 m .27306 .55274 L .27265 .55188 L F
.27353 .55204 m .27306 .55274 L .27277 .55177 L F
.474 0 0 r
.2773 .554 m .27945 .55357 L .27919 .55379 L F
.61 .861 .508 r
.27945 .55357 m .27838 .5547 L .28108 .55134 L F
.034 .16 .666 r
.2773 .554 m .27821 .55494 L .27838 .5547 L F
.474 0 0 r
.2773 .554 m .27802 .55507 L .27838 .5547 L F
.61 .861 .508 r
.27838 .5547 m .27802 .55507 L .27866 .55429 L F
.27838 .5547 m .27866 .55429 L .28108 .55134 L F
.034 .16 .666 r
.27838 .5547 m .27931 .55608 L .27902 .55511 L F
.27821 .55494 m .27931 .55608 L .27838 .5547 L F
.474 0 0 r
.2773 .554 m .27838 .5547 L .2788 .55425 L F
.27817 .55382 m .2788 .55425 L .27945 .55357 L F
.2773 .554 m .2788 .55425 L .27817 .55382 L F
.801 .696 .749 r
.28108 .55134 m .27866 .55429 L .27827 .55259 L F
.034 .16 .666 r
.2773 .554 m .27883 .55499 L .27827 .55259 L F
.709 .286 .242 r
.27628 .55625 m .27812 .5573 L .2782 .55696 L F
0 0 0 r
.28128 .55581 m .27812 .5573 L .2782 .55696 L F
.27884 .55696 m .27967 .5568 L .27812 .5573 L F
.28128 .55581 m .27967 .5568 L .27884 .55696 L F
.421 .197 .466 r
.28128 .55581 m .27919 .55379 L .27945 .55357 L F
.244 .366 .789 r
.2821 .55457 m .28128 .55581 L .27945 .55357 L F
.707 .979 .779 r
.2821 .55457 m .27967 .5568 L .28128 .55581 L F
0 .294 .722 r
.28192 .55766 m .27967 .5568 L .2821 .55457 L F
.28192 .55766 m .28029 .55668 L .27967 .5568 L F
.28029 .55668 m .27931 .55608 L .27967 .5568 L F
0 .036 .582 r
.27967 .5568 m .2773 .554 L .27812 .5573 L F
.27967 .5568 m .27944 .55634 L .2773 .554 L F
.27944 .55634 m .27931 .55608 L .27901 .55577 L F
.27944 .55634 m .27901 .55577 L .2773 .554 L F
.801 .696 .749 r
.27866 .55429 m .27826 .55478 L .27827 .55259 L F
.27826 .55478 m .27802 .55507 L .27808 .55453 L F
.27826 .55478 m .27808 .55453 L .27827 .55259 L F
.034 .16 .666 r
.27883 .55499 m .27902 .55511 L .27827 .55259 L F
.348 .111 .406 r
.27398 .55193 m .27379 .5521 L .27366 .55185 L F
.27379 .5521 m .27357 .55198 L .27366 .55185 L F
.27761 .54873 m .27398 .55193 L .27526 .54945 L F
.27398 .55193 m .27366 .55185 L .27526 .54945 L F
.612 .473 .668 r
.3572 .55175 m .35739 .55456 L .35977 .55124 L F
.421 .229 .512 r
.2944 .63195 m .29616 .63405 L .2957 .63131 L F
.2944 .63195 m .29405 .63478 L .29616 .63405 L F
.168 .696 .864 r
.2428 .53396 m .24501 .53377 L .24699 .53414 L F
0 0 0 r
.24501 .53377 m .24927 .53344 L .24699 .53414 L F
.817 .557 .546 r
.32884 .57029 m .32809 .57315 L .32419 .5723 L F
.421 .167 .421 r
.33066 .57221 m .32884 .57029 L .33089 .56991 L F
.33066 .57221 m .32809 .57315 L .32884 .57029 L F
.323 0 0 r
.21172 .56393 m .20996 .56541 L .20761 .56547 L F
.595 .128 .114 r
.21355 .56542 m .21172 .56393 L .21431 .56367 L F
.21355 .56542 m .20996 .56541 L .21172 .56393 L F
.283 .143 .507 r
.16561 .57624 m .16749 .57786 L .16789 .5755 L F
.16561 .57624 m .16546 .57935 L .16749 .57786 L F
0 0 0 r
.27568 .60716 m .27374 .6104 L .27456 .60939 L F
0 0 .194 r
.27374 .6104 m .27399 .61168 L .27456 .60939 L F
.27374 .6104 m .27327 .61308 L .27399 .61168 L F
.543 .405 .644 r
.3136 .63264 m .3158 .6321 L .31574 .62855 L F
.533 .436 .69 r
.3136 .63264 m .3162 .63438 L .3158 .6321 L F
.3136 .63264 m .31392 .63492 L .3162 .63438 L F
.149 0 .334 r
.34852 .57297 m .3466 .57612 L .34783 .57567 L F
.232 .152 .555 r
.3466 .57612 m .34806 .57812 L .34783 .57567 L F
.743 .221 0 r
.34751 .57814 m .34806 .57812 L .3466 .57612 L F
.547 .342 .555 r
.33488 .58169 m .33734 .58432 L .3373 .58199 L F
.33488 .58169 m .33431 .5851 L .33734 .58432 L F
.519 .213 .387 r
.29968 .54715 m .2977 .54538 L .29972 .5446 L F
.29968 .54715 m .29719 .54763 L .2977 .54538 L F
.329 .056 .338 r
.1944 .57333 m .19367 .57558 L .19161 .57624 L F
.377 .1 .36 r
.19594 .57486 m .1944 .57333 L .19623 .57241 L F
.19594 .57486 m .19367 .57558 L .1944 .57333 L F
.045 0 .047 r
.29867 .58468 m .29823 .58714 L .29611 .58808 L F
.295 .791 .788 r
.30243 .58359 m .30058 .58388 L .29867 .58468 L F
.034 0 .045 r
.29981 .58616 m .29867 .58468 L .30058 .58388 L F
.29981 .58616 m .29823 .58714 L .29867 .58468 L F
.678 .432 .542 r
.28367 .66244 m .28165 .66011 L .28122 .66297 L F
.831 .539 0 r
.49583 .55579 m .49576 .55637 L .49506 .55344 L F
.624 .68 .883 r
.49788 .55381 m .49583 .55579 L .49506 .55344 L F
.568 .584 .829 r
.49788 .55381 m .49945 .55682 L .49583 .55579 L F
.662 .308 .363 r
.31188 .65355 m .30989 .65608 L .30787 .6537 L F
.742 .412 .424 r
.31408 .65631 m .30989 .65608 L .31188 .65355 L F
.693 .413 .493 r
.31434 .6538 m .31408 .65631 L .31188 .65355 L F
.418 .77 .996 r
.20522 .62238 m .20546 .62108 L .20326 .62134 L F
.227 .579 .943 r
.20522 .62238 m .20699 .62255 L .20546 .62108 L F
.311 .514 .892 r
.18492 .60562 m .18537 .60769 L .18623 .60601 L F
.33 .538 .905 r
.18537 .60769 m .18894 .60959 L .18623 .60601 L F
.358 .514 .877 r
.18537 .60769 m .18937 .61085 L .18894 .60959 L F
.483 .224 .445 r
.37452 .57588 m .37164 .57853 L .37198 .57648 L F
.393 .113 .364 r
.19161 .57624 m .19147 .57834 L .18886 .57898 L F
.429 .141 .371 r
.19316 .57784 m .19161 .57624 L .19367 .57558 L F
.19316 .57784 m .19147 .57834 L .19161 .57624 L F
.149 .195 .655 r
.29272 .62568 m .29468 .62766 L .29487 .62516 L F
.663 .588 .761 r
.36806 .5912 m .36733 .58787 L .36782 .58839 L F
.066 0 .297 r
.36806 .5912 m .36899 .59358 L .36626 .59499 L F
.235 .272 .697 r
.36782 .58839 m .37001 .59039 L .36806 .5912 L F
.435 .045 .198 r
.37027 .59298 m .36806 .5912 L .37001 .59039 L F
.37027 .59298 m .36899 .59358 L .36806 .5912 L F
0 0 .132 r
.16497 .59728 m .16528 .5975 L .16571 .59488 L F
0 0 .372 r
.16497 .59728 m .166 .59997 L .16528 .5975 L F
.563 .912 .967 r
.16486 .61212 m .16286 .61312 L .16433 .61339 L F
.16433 .61339 m .16286 .61312 L .16486 .61212 L F
0 0 0 r
.21887 .53873 m .21469 .54105 L .21701 .54065 L F
.333 .801 .703 r
.21887 .53873 m .21993 .53816 L .221 .53776 L F
0 0 0 r
.21701 .54065 m .21993 .53816 L .21887 .53873 L F
.06 0 .327 r
.36828 .59597 m .36626 .59499 L .36899 .59358 L F
.36828 .59597 m .3659 .59764 L .36626 .59499 L F
.411 .857 .785 r
.22934 .56098 m .22513 .56251 L .22695 .56076 L F
.076 .614 .856 r
.33032 .55625 m .32797 .55542 L .3234 .55492 L F
.602 .036 0 r
.30646 .55884 m .30433 .55947 L .3026 .55749 L F
.375 0 0 r
.30771 .55743 m .30814 .55758 L .30748 .55711 L F
.415 .852 .737 r
.3063 .55834 m .30646 .55884 L .30822 .55777 L F
.30815 .55761 m .30822 .55777 L .30912 .55723 L F
.3063 .55834 m .30822 .55777 L .30815 .55761 L F
.299 0 0 r
.30957 .55806 m .3063 .55834 L .30912 .55723 L F
.375 0 0 r
.30814 .55758 m .30957 .55806 L .30805 .55737 L F
.30814 .55758 m .30805 .55737 L .30748 .55711 L F
.747 .979 .732 r
.3026 .55749 m .29981 .5603 L .29928 .55715 L F
.3026 .55749 m .30061 .55837 L .29981 .5603 L F
.765 .647 .731 r
.30476 .56171 m .30061 .55837 L .30308 .55823 L F
.566 .162 .235 r
.30308 .55823 m .30309 .55981 L .30331 .55978 L F
.415 .852 .737 r
.30632 .55842 m .30433 .55947 L .30646 .55884 L F
.30553 .55878 m .30433 .55947 L .30632 .55842 L F
0 0 .531 r
.3026 .55749 m .30433 .55947 L .30226 .55574 L F
.379 .393 .749 r
.30226 .55574 m .30433 .55947 L .3063 .55834 L F
.536 .745 .972 r
.30583 .55945 m .30476 .56171 L .30308 .55823 L F
.566 .162 .235 r
.30493 .55905 m .30331 .55978 L .30583 .55945 L F
.30308 .55823 m .30331 .55978 L .30493 .55905 L F
.415 .852 .737 r
.3063 .55834 m .30553 .55878 L .30632 .55842 L F
.301 0 .038 r
.31472 .56882 m .31822 .56689 L .3143 .56649 L F
.95 .807 .667 r
.31427 .60342 m .31476 .6049 L .31366 .60709 L F
0 0 0 r
.29112 .63756 m .28899 .6383 L .28672 .63983 L F
.689 .408 .493 r
.31809 .65592 m .31434 .6538 L .31815 .6535 L F
.31809 .65592 m .31408 .65631 L .31434 .6538 L F
0 .337 .717 r
.3217 .55556 m .3262 .5578 L .32172 .55738 L F
.3217 .55556 m .32387 .55655 L .32559 .5575 L F
.686 .501 .63 r
.3217 .55556 m .32172 .55738 L .31953 .55633 L F
.48 .46 .757 r
.3234 .55492 m .32502 .55707 L .3217 .55556 L F
.194 .394 .831 r
.32172 .55738 m .32213 .55559 L .32004 .55611 L F
.32213 .55559 m .32225 .55508 L .32169 .55534 L F
.733 .647 .763 r
.3217 .55556 m .31953 .55633 L .31758 .55373 L F
.194 .394 .831 r
.32213 .55559 m .32169 .55534 L .32004 .55611 L F
0 .337 .717 r
.32559 .5575 m .32502 .55707 L .3262 .5578 L F
.32387 .55655 m .32502 .55707 L .32559 .5575 L F
.316 0 0 r
.3262 .5578 m .32424 .55814 L .32172 .55738 L F
.098 .608 .892 r
.32502 .55707 m .32776 .55721 L .3262 .5578 L F
.225 .742 .739 r
.32776 .55721 m .32424 .55814 L .3262 .5578 L F
.417 .338 .66 r
.3262 .5578 m .32666 .56108 L .32902 .55841 L F
.48 .715 .973 r
.34415 .62602 m .34625 .62422 L .34242 .62338 L F
.34415 .62602 m .34589 .6255 L .34625 .62422 L F
.421 .361 .685 r
.34415 .62602 m .34664 .62742 L .34589 .6255 L F
.411 .235 .529 r
.27769 .60399 m .27568 .60716 L .27773 .60641 L F
.264 0 .206 r
.27456 .60939 m .27773 .60641 L .27568 .60716 L F
0 0 0 r
.33517 .62147 m .33279 .62222 L .33351 .62172 L F
.482 .172 .363 r
.28137 .62815 m .28607 .62567 L .286 .62799 L F
.696 .555 .691 r
.28542 .62832 m .28572 .63097 L .28621 .62797 L F
.28623 .62787 m .28572 .63097 L .28821 .62776 L F
.614 .277 .376 r
.286 .62799 m .28821 .62776 L .28599 .62834 L F
.28607 .62567 m .28821 .62776 L .286 .62799 L F
.696 .555 .691 r
.286 .62799 m .28621 .62797 L .28623 .62787 L F
.28542 .62832 m .28621 .62797 L .286 .62799 L F
.508 .418 .688 r
.28542 .62832 m .28572 .63097 L .28137 .62815 L F
.696 .555 .691 r
.28488 .62861 m .28572 .63097 L .28542 .62832 L F
.508 .418 .688 r
.28599 .62834 m .28572 .63097 L .28542 .62832 L F
.482 .172 .363 r
.28542 .62832 m .286 .62799 L .28599 .62834 L F
.28137 .62815 m .286 .62799 L .28542 .62832 L F
.696 .555 .691 r
.28465 .62795 m .28488 .62861 L .28623 .62787 L F
.37 .003 .205 r
.28465 .62795 m .28607 .62567 L .28137 .62815 L F
.467 .426 .729 r
.28137 .62815 m .28572 .63097 L .28465 .62795 L F
0 0 .477 r
.3041 .58844 m .30432 .59173 L .30539 .59023 L F
.394 .156 .431 r
.32373 .58176 m .3214 .58489 L .32175 .5823 L F
.048 0 .177 r
.31753 .57642 m .31673 .57854 L .31929 .5752 L F
.328 .723 .982 r
.30797 .53224 m .3035 .53125 L .30702 .53089 L F
.003 .406 .853 r
.3082 .53123 m .30797 .53224 L .30702 .53089 L F
.047 .457 .88 r
.3082 .53123 m .30967 .53276 L .30797 .53224 L F
.272 .036 .362 r
.32427 .64938 m .32306 .64736 L .32494 .64623 L F
.32427 .64938 m .32238 .65016 L .32306 .64736 L F
.192 .49 .901 r
.35997 .54256 m .36202 .54342 L .3622 .54476 L F
.913 .757 .268 r
.35967 .54106 m .35997 .54256 L .36006 .53825 L F
.192 .49 .901 r
.36202 .54342 m .36312 .54388 L .36284 .54415 L F
.36202 .54342 m .36284 .54415 L .3622 .54476 L F
.516 .398 .657 r
.35997 .54256 m .36131 .54541 L .36312 .54388 L F
.749 .652 .754 r
.35688 .54418 m .36131 .54541 L .35982 .54145 L F
.35954 .54121 m .35982 .54145 L .35967 .54106 L F
.35688 .54418 m .35982 .54145 L .35954 .54121 L F
.283 .634 .964 r
.36312 .54388 m .36459 .54547 L .3622 .54476 L F
.239 .652 .96 r
.25473 .64006 m .25538 .63962 L .25453 .63996 L F
.25473 .64006 m .25702 .64066 L .25538 .63962 L F
.267 0 0 r
.26156 .6216 m .26398 .62148 L .26608 .62031 L F
.808 .997 .776 r
.26608 .62031 m .26665 .61855 L .26787 .61877 L F
.26608 .62031 m .26398 .62148 L .26665 .61855 L F
.674 .588 .751 r
.3827 .55678 m .38032 .55466 L .38287 .55459 L F
.383 .145 .424 r
.38674 .55356 m .3827 .55678 L .38287 .55459 L F
.427 .701 .979 r
.20588 .79454 m .20733 .79581 L .20806 .79442 L F
.20588 .79454 m .20733 .79581 L .20806 .79442 L F
.969 .921 .695 r
.31549 .60894 m .31787 .60739 L .31373 .6071 L F
.31549 .60894 m .31653 .61026 L .31787 .60739 L F
0 .127 .666 r
.31554 .60858 m .317 .61052 L .31549 .60894 L F
.317 .61052 m .31704 .61058 L .31549 .60894 L F
.969 .921 .695 r
.31549 .60894 m .31373 .6071 L .31366 .60709 L F
.489 .866 .98 r
.32817 .62608 m .32366 .62581 L .32628 .62507 L F
.396 .663 .966 r
.32856 .62413 m .32817 .62608 L .32628 .62507 L F
.32856 .62413 m .32989 .62589 L .32817 .62608 L F
.01 .34 .821 r
.28406 .6334 m .28533 .63371 L .28495 .63499 L F
.42 .146 .389 r
.31392 .63492 m .31092 .63818 L .31289 .63716 L F
.401 .087 .315 r
.3162 .63438 m .31392 .63492 L .31289 .63716 L F
.67 .633 .804 r
.23562 .75211 m .23728 .75578 L .23408 .75311 L F
.818 .338 .04 r
.23408 .75311 m .23728 .75578 L .23553 .75534 L F
.269 .402 .812 r
.23756 .7527 m .23728 .75578 L .23562 .75211 L F
.873 .938 .859 r
.23553 .75534 m .23728 .75578 L .23756 .7527 L F
.635 .283 .357 r
.35463 .63363 m .35827 .63453 L .35394 .63397 L F
.681 .665 .828 r
.31844 .62557 m .3214 .62602 L .31953 .62233 L F
.612 .129 .083 r
.32034 .62725 m .3214 .62602 L .31844 .62557 L F
.774 .704 .786 r
.31953 .62233 m .3214 .62602 L .3243 .62314 L F
.107 0 0 r
.32366 .62581 m .3214 .62602 L .32034 .62725 L F
.814 .879 .893 r
.26377 .69263 m .2662 .69377 L .26793 .69216 L F
.301 .582 .94 r
.21943 .63014 m .22301 .62998 L .21841 .62947 L F
.21943 .63014 m .22394 .63255 L .22301 .62998 L F
.423 .184 .445 r
.35545 .61654 m .35433 .61907 L .3525 .61915 L F
.467 .481 .789 r
.35582 .62234 m .3525 .61915 L .35433 .61907 L F
.532 .773 .986 r
.37213 .55623 m .37136 .55804 L .36978 .55675 L F
.204 .701 .917 r
.17454 .60068 m .17604 .60051 L .17249 .60006 L F
.627 .434 .601 r
.334 .61017 m .33714 .61012 L .33702 .60712 L F
.429 .283 .58 r
.33714 .61012 m .33899 .60646 L .33702 .60712 L F
.962 .943 .668 r
.33953 .58408 m .34144 .58253 L .3373 .58199 L F
.33953 .58408 m .33988 .58569 L .34144 .58253 L F
.488 .368 .642 r
.33988 .58569 m .34334 .58134 L .34144 .58253 L F
.628 .855 .985 r
.33155 .54426 m .32919 .5449 L .33361 .54476 L F
.607 .299 .421 r
.32913 .54776 m .33361 .54476 L .32919 .5449 L F
.32913 .54776 m .33206 .54791 L .33361 .54476 L F
.474 .631 .922 r
.33361 .54476 m .33541 .54395 L .33155 .54426 L F
.33361 .54476 m .33588 .54551 L .33541 .54395 L F
.62 .313 .428 r
.33361 .54476 m .33206 .54791 L .33581 .54699 L F
.684 .297 .307 r
.33361 .54476 m .33581 .54699 L .33588 .54551 L F
.48 .461 .759 r
.35856 .54589 m .35896 .5487 L .36113 .54649 L F
.539 .435 .684 r
.35896 .5487 m .36214 .55065 L .36113 .54649 L F
.35896 .5487 m .35977 .55124 L .36214 .55065 L F
.847 .847 .843 r
.29913 .65652 m .30185 .65408 L .30004 .65235 L F
.358 .789 .969 r
.30185 .65408 m .30218 .65304 L .30004 .65235 L F
.30185 .65408 m .30416 .65376 L .30218 .65304 L F
.68 .609 .77 r
.13329 .66364 m .13446 .66268 L .13296 .66273 L F
.518 .345 .585 r
.37183 .58152 m .36941 .57918 L .37164 .57853 L F
.37183 .58152 m .36934 .58218 L .36941 .57918 L F
.846 .811 .816 r
.26423 .54705 m .26854 .54526 L .26775 .54591 L F
0 .028 .555 r
.26854 .54526 m .26938 .54847 L .26981 .54729 L F
.18 .578 .938 r
.26981 .54729 m .26775 .54591 L .26854 .54526 L F
.422 .185 .447 r
.32319 .56351 m .32544 .56448 L .32688 .5636 L F
.718 .202 0 r
.32544 .56448 m .32919 .56603 L .32688 .5636 L F
.696 .633 .782 r
.32688 .5636 m .32949 .56076 L .32666 .56108 L F
.32688 .5636 m .33041 .56361 L .32949 .56076 L F
.632 .265 .33 r
.32688 .5636 m .32919 .56603 L .33041 .56361 L F
.734 .487 .555 r
.32187 .65567 m .31809 .65592 L .31815 .6535 L F
.657 .649 .83 r
.35083 .56609 m .35358 .56677 L .35218 .56311 L F
.474 .354 .636 r
.35083 .56609 m .35291 .56864 L .35358 .56677 L F
.35083 .56609 m .35088 .56976 L .35291 .56864 L F
.558 .099 .119 r
.36459 .54547 m .36663 .5469 L .36819 .54527 L F
.278 .219 .609 r
.36819 .54527 m .37049 .54455 L .36968 .541 L F
0 0 0 r
.36819 .54527 m .36663 .5469 L .37049 .54455 L F
.779 .712 .789 r
.35218 .56311 m .35358 .56677 L .35618 .56365 L F
.461 .258 .517 r
.35358 .56677 m .35559 .56804 L .35618 .56365 L F
.699 .47 .572 r
.3582 .56526 m .35559 .56804 L .35919 .56605 L F
.35618 .56365 m .3557 .56721 L .3582 .56526 L F
.3557 .56721 m .35559 .56804 L .3582 .56526 L F
.21 .735 .762 r
.35291 .56864 m .35422 .56836 L .35358 .56677 L F
.35422 .56836 m .35584 .56801 L .35516 .56763 L F
.528 .148 .265 r
.35584 .56801 m .35919 .56605 L .35559 .56804 L F
0 .304 .798 r
.35584 .56801 m .35559 .56804 L .35358 .56677 L F
.21 .735 .762 r
.35422 .56836 m .35516 .56763 L .35358 .56677 L F
.476 .39 .679 r
.30043 .61927 m .30202 .61571 L .30036 .61628 L F
.612 .129 .083 r
.32034 .62725 m .31844 .62557 L .31802 .6278 L F
.622 .275 .361 r
.28465 .62795 m .28821 .62776 L .28607 .62567 L F
.642 .252 .29 r
.3519 .62568 m .35129 .62973 L .34888 .62794 L F
.589 .204 .281 r
.35435 .62925 m .3519 .62568 L .35435 .6299 L F
.35435 .62925 m .35129 .62973 L .3519 .62568 L F
0 0 0 r
.28702 .66089 m .28367 .66244 L .28636 .65931 L F
.563 0 0 r
.28789 .66222 m .28702 .66089 L .28636 .65931 L F
.729 .213 0 r
.24104 .55069 m .2389 .55048 L .23684 .54828 L F
.179 0 0 r
.24104 .55069 m .24282 .55103 L .2389 .55048 L F
.439 .252 .528 r
.31494 .55187 m .31713 .55132 L .31726 .548 L F
.491 .413 .695 r
.31494 .55187 m .31758 .55373 L .31713 .55132 L F
.31494 .55187 m .31548 .55443 L .31758 .55373 L F
.601 .474 .68 r
.33552 .55767 m .33341 .55993 L .33195 .55765 L F
.33552 .55767 m .33574 .56035 L .33341 .55993 L F
.445 .197 .443 r
.34666 .55378 m .34461 .55452 L .3471 .55133 L F
.213 0 .359 r
.3483 .55293 m .3471 .55133 L .34932 .55066 L F
.3483 .55293 m .34666 .55378 L .3471 .55133 L F
.295 .053 .366 r
.31726 .548 m .3196 .54729 L .31997 .54455 L F
.288 .131 .487 r
.31726 .548 m .31928 .5498 L .3196 .54729 L F
.31726 .548 m .31713 .55132 L .31928 .5498 L F
.495 .565 .856 r
.20895 .60643 m .21044 .60964 L .20857 .6102 L F
.428 .316 .624 r
.21044 .60964 m .21079 .61203 L .20857 .6102 L F
.674 .57 .73 r
.33713 .55134 m .33836 .55458 L .34088 .55367 L F
0 0 0 r
.33786 .55611 m .33713 .55719 L .3378 .55576 L F
.657 .619 .8 r
.33713 .55719 m .33368 .55496 L .33786 .55611 L F
.339 0 0 r
.33568 .55587 m .3379 .55639 L .33786 .55611 L F
0 0 .089 r
.33786 .55611 m .33817 .55645 L .33713 .55719 L F
.339 0 0 r
.3379 .55639 m .33817 .55645 L .33786 .55611 L F
0 0 0 r
.33786 .55611 m .3378 .55576 L .33836 .55458 L F
.778 .482 .486 r
.5282 .53906 m .52454 .54105 L .52431 .5386 L F
.5282 .53906 m .52914 .54225 L .52454 .54105 L F
.471 .305 .574 r
.53053 .54095 m .52914 .54225 L .5282 .53906 L F
.457 .266 .532 r
.31134 .58194 m .31335 .58164 L .3145 .57898 L F
.652 .401 .526 r
.31093 .58434 m .31335 .58164 L .31134 .58194 L F
.669 .696 .866 r
.35947 .53571 m .35702 .53663 L .3548 .53415 L F
.535 .524 .79 r
.36006 .53825 m .35702 .53663 L .35947 .53571 L F
.107 0 0 r
.32366 .62581 m .32034 .62725 L .3221 .62683 L F
.364 .82 .93 r
.3221 .62683 m .32153 .6251 L .32196 .62425 L F
.774 .704 .786 r
.31953 .62233 m .32266 .62286 L .32196 .62425 L F
0 .179 .679 r
.31953 .62233 m .32015 .62282 L .32077 .62282 L F
.32015 .62282 m .32196 .62425 L .32077 .62282 L F
.774 .704 .786 r
.32266 .62286 m .3243 .62314 L .32196 .62425 L F
.366 .811 .67 r
.32196 .62425 m .3243 .62314 L .32637 .62204 L F
.32196 .62425 m .32637 .62204 L .32628 .62507 L F
.701 .658 .804 r
.32196 .62425 m .32628 .62507 L .32366 .62581 L F
0 .109 .646 r
.32077 .62282 m .32383 .62593 L .32141 .62278 L F
.32077 .62282 m .32141 .62278 L .32139 .62281 L F
.364 .82 .93 r
.32153 .6251 m .32077 .62282 L .32196 .62425 L F
.107 0 0 r
.32366 .62581 m .3221 .62683 L .32196 .62425 L F
.876 .603 .521 r
.32196 .62425 m .32366 .62581 L .3221 .62683 L F
.364 .82 .93 r
.3221 .62683 m .32383 .62593 L .32077 .62282 L F
0 .109 .646 r
.32077 .62282 m .32139 .62281 L .31986 .62469 L F
.581 .148 .185 r
.22327 .53747 m .22623 .5377 L .2278 .53586 L F
0 0 0 r
.22623 .5377 m .23019 .53579 L .2278 .53586 L F
.474 0 0 r
.32307 .54568 m .32679 .54821 L .32663 .54545 L F
.622 .562 .766 r
.32537 .54176 m .32663 .54545 L .32919 .5449 L F
.596 .446 .648 r
.32663 .54545 m .32679 .54821 L .32919 .5449 L F
.781 .397 .328 r
.53537 .5283 m .5379 .52685 L .53394 .52642 L F
.53537 .5283 m .53861 .52943 L .5379 .52685 L F
.591 .281 .412 r
.5379 .52685 m .53861 .52943 L .54029 .52866 L F
.64 .646 .84 r
.31997 .54455 m .32307 .54568 L .32137 .54154 L F
.618 .325 .45 r
.31997 .54455 m .32269 .54676 L .32307 .54568 L F
.79 .721 .787 r
.32137 .54154 m .32307 .54568 L .32537 .54176 L F
.62 .137 .085 r
.32269 .54676 m .32549 .54746 L .32307 .54568 L F
0 0 0 r
.32549 .54746 m .32559 .54784 L .3256 .54783 L F
.474 0 0 r
.32543 .54729 m .32549 .54746 L .32679 .54821 L F
.647 .896 .984 r
.32679 .54821 m .32549 .54746 L .32742 .54617 L F
0 0 0 r
.32549 .54746 m .3256 .54783 L .32742 .54617 L F
.474 0 0 r
.32307 .54568 m .32549 .54746 L .32543 .54729 L F
.6 .231 .314 r
.33041 .56361 m .33237 .5654 L .33277 .56279 L F
.33041 .56361 m .32919 .56603 L .33237 .5654 L F
0 0 0 r
.35933 .61027 m .35571 .61108 L .35679 .61013 L F
.57 .383 .589 r
.3384 .57288 m .34108 .56949 L .33851 .5701 L F
.446 .852 .968 r
.23052 .53577 m .23242 .53516 L .2341 .53559 L F
.514 .883 .976 r
.2341 .53559 m .23242 .53516 L .23468 .53438 L F
.17 0 0 r
.23041 .53631 m .23427 .53456 L .23242 .53516 L F
.23427 .53456 m .23468 .53438 L .23242 .53516 L F
.446 .852 .968 r
.23019 .53579 m .23242 .53516 L .23052 .53577 L F
.541 .906 .962 r
.2341 .53559 m .23468 .53438 L .2363 .53468 L F
.458 .539 .852 r
.31472 .56882 m .31658 .57208 L .31836 .57164 L F
.489 .659 .937 r
.31658 .57208 m .31859 .57235 L .31836 .57164 L F
.178 0 .361 r
.37898 .5665 m .37846 .56923 L .37701 .56926 L F
.388 .345 .689 r
.37943 .56981 m .37701 .56926 L .37846 .56923 L F
.37943 .56981 m .37756 .57282 L .37701 .56926 L F
.217 .567 .938 r
.2513 .63733 m .25453 .63996 L .25538 .63962 L F
0 .246 .754 r
.38605 .54161 m .38834 .54355 L .38793 .54525 L F
0 .242 .751 r
.38834 .54355 m .39012 .54709 L .38793 .54525 L F
.471 .281 .54 r
.38793 .54525 m .39012 .54709 L .38765 .54767 L F
.512 .325 .563 r
.18886 .57898 m .18889 .58403 L .18614 .58302 L F
.431 .261 .549 r
.19082 .58238 m .18886 .57898 L .19147 .57834 L F
.19082 .58238 m .18889 .58403 L .18886 .57898 L F
.459 .294 .569 r
.35883 .59676 m .35619 .5981 L .3566 .59471 L F
0 .073 .628 r
.53982 .54817 m .54025 .54678 L .5386 .54446 L F
.938 .579 .302 r
.54215 .54847 m .54025 .54678 L .53982 .54817 L F
.988 .762 .508 r
.27325 .69107 m .27452 .69066 L .27404 .69314 L F
.627 .472 .652 r
.27652 .69001 m .27404 .69314 L .27452 .69066 L F
.988 .762 .508 r
.27273 .68972 m .27404 .69314 L .27273 .6914 L F
.212 .494 .901 r
.27309 .69127 m .27486 .69201 L .27652 .69001 L F
.27273 .6914 m .27295 .69146 L .27309 .69127 L F
.27295 .69146 m .27486 .69201 L .27309 .69127 L F
.988 .762 .508 r
.27273 .68972 m .27383 .6903 L .27325 .69107 L F
.27383 .6903 m .27452 .69066 L .27325 .69107 L F
.485 .839 .995 r
.27652 .69001 m .27452 .69066 L .27273 .68972 L F
.485 .24 .467 r
.32042 .56612 m .32319 .56351 L .32096 .56404 L F
.076 .109 .592 r
.19294 .59007 m .19243 .59401 L .19012 .59081 L F
.19294 .59007 m .19348 .59388 L .19243 .59401 L F
.413 .171 .435 r
.35484 .55752 m .35715 .5569 L .35739 .55456 L F
.627 .493 .679 r
.35739 .55456 m .36043 .55427 L .35977 .55124 L F
.671 .448 .573 r
.35715 .5569 m .36043 .55427 L .35739 .55456 L F
.701 .767 .903 r
.35303 .53535 m .3513 .53531 L .3517 .53434 L F
.102 .657 .755 r
.3517 .53434 m .3548 .53415 L .35303 .53535 L F
.552 .758 .973 r
.34128 .53445 m .34061 .53683 L .33881 .53515 L F
.34128 .53445 m .3431 .53641 L .34061 .53683 L F
.539 .777 .986 r
.25702 .64066 m .2574 .63882 L .25538 .63962 L F
.25702 .64066 m .25942 .6402 L .2574 .63882 L F
.337 .21 .557 r
.30482 .54793 m .30678 .55011 L .30686 .54726 L F
.30482 .54793 m .30576 .55062 L .30678 .55011 L F
.879 .467 .231 r
.54592 .53243 m .54737 .53501 L .54919 .5356 L F
.96 .945 .674 r
.54708 .53783 m .54919 .5356 L .54737 .53501 L F
.54708 .53783 m .54753 .5391 L .54919 .5356 L F
.782 .897 .924 r
.22301 .62998 m .22394 .63255 L .22572 .63075 L F
0 0 .065 r
.29377 .59362 m .29258 .59485 L .29446 .5915 L F
.109 0 .379 r
.29356 .59649 m .29258 .59485 L .29377 .59362 L F
.29356 .59649 m .29225 .59739 L .29258 .59485 L F
.508 .377 .637 r
.18876 .58462 m .18614 .58302 L .18889 .58403 L F
.18876 .58462 m .18654 .58527 L .18614 .58302 L F
.64 .646 .84 r
.31997 .54455 m .32137 .54154 L .31897 .54309 L F
.618 .325 .45 r
.31997 .54455 m .3196 .54729 L .32269 .54676 L F
.383 .145 .424 r
.38674 .55356 m .38555 .55668 L .3827 .55678 L F
.27 .045 .377 r
.38555 .55668 m .3832 .55916 L .3827 .55678 L F
.779 .634 .701 r
.26948 .68349 m .27123 .68029 L .26808 .68153 L F
.236 .556 .933 r
.28242 .67706 m .281 .67761 L .28035 .67706 L F
.068 0 .342 r
.28219 .67975 m .281 .67761 L .28242 .67706 L F
.28219 .67975 m .28036 .68032 L .281 .67761 L F
.745 .223 0 r
.30787 .6537 m .30989 .65608 L .30789 .6555 L F
.582 .587 .823 r
.38226 .53856 m .37986 .53913 L .37832 .53597 L F
.43 .533 .861 r
.18937 .61085 m .19277 .61416 L .19129 .61016 L F
.464 .501 .812 r
.19129 .61016 m .19277 .61416 L .19462 .61201 L F
.511 .571 .852 r
.19283 .61411 m .19462 .61201 L .19277 .61416 L F
.374 .322 .671 r
.36664 .60287 m .36443 .6039 L .36428 .6008 L F
.501 .388 .657 r
.36664 .60287 m .36459 .60595 L .36443 .6039 L F
.343 .057 .327 r
.3791 .57427 m .37756 .57282 L .37943 .56981 L F
.3791 .57427 m .37702 .57504 L .37756 .57282 L F
0 .002 .504 r
.31892 .61948 m .31953 .62233 L .31832 .61869 L F
.438 .772 .997 r
.16771 .60157 m .16778 .59984 L .166 .59997 L F
.16771 .60157 m .17065 .60138 L .16778 .59984 L F
.137 .432 .871 r
.23106 .62018 m .23044 .62138 L .22818 .61979 L F
.23106 .62018 m .23234 .62209 L .23044 .62138 L F
.896 .739 .679 r
.53601 .5477 m .53719 .55137 L .53523 .55051 L F
.53601 .5477 m .53719 .55137 L .53523 .55051 L F
.61 .55 .763 r
.33713 .55134 m .33916 .54798 L .3367 .54857 L F
0 0 .406 r
.33764 .54936 m .33713 .55134 L .3367 .54857 L F
.503 .561 .847 r
.33743 .55431 m .33538 .55284 L .33765 .55242 L F
.755 .559 .631 r
.33747 .55003 m .33597 .55214 L .33713 .55134 L F
.33627 .55164 m .33597 .55214 L .33747 .55003 L F
.33764 .54936 m .33627 .55164 L .33747 .55003 L F
.61 .55 .763 r
.33713 .55134 m .3399 .55111 L .33916 .54798 L F
.674 .57 .73 r
.33713 .55134 m .34088 .55367 L .3399 .55111 L F
.755 .559 .631 r
.33764 .54936 m .33765 .55242 L .33597 .55214 L F
.304 .73 .972 r
.33597 .55214 m .33765 .55242 L .33347 .55146 L F
.503 .561 .847 r
.33538 .55284 m .33347 .55146 L .33598 .55204 L F
.33538 .55284 m .33598 .55204 L .33765 .55242 L F
.236 .025 .376 r
.34852 .57297 m .34998 .57467 L .35073 .57209 L F
.34852 .57297 m .34783 .57567 L .34998 .57467 L F
.529 .288 .493 r
.23684 .54828 m .2389 .55048 L .23661 .55036 L F
.375 .044 .271 r
.19097 .58887 m .19012 .59081 L .18789 .59135 L F
.592 .62 .849 r
.19332 .5883 m .19097 .58887 L .18876 .58462 L F
.547 .214 .356 r
.19294 .59007 m .19097 .58887 L .19332 .5883 L F
.19294 .59007 m .19012 .59081 L .19097 .58887 L F
.482 .345 .618 r
.3158 .6321 m .31802 .6278 L .31574 .62855 L F
.826 .543 0 r
.3178 .59661 m .31835 .59808 L .31731 .59412 L F
0 .269 .738 r
.3208 .59906 m .31835 .59808 L .3178 .59661 L F
.447 0 .064 r
.32185 .60028 m .32064 .60199 L .31831 .60193 L F
.416 0 0 r
.31835 .59808 m .32205 .60047 L .32185 .60028 L F
0 .269 .738 r
.3208 .59906 m .32205 .60047 L .31835 .59808 L F
.426 .326 .638 r
.3659 .59764 m .36428 .6008 L .36362 .59831 L F
.514 .777 .991 r
.30782 .60101 m .30983 .60122 L .30758 .59968 L F
.684 .829 .953 r
.30758 .59968 m .30983 .60122 L .31261 .60041 L F
.336 .242 .598 r
.27769 .60399 m .27952 .6034 L .27956 .59985 L F
.36 .196 .519 r
.27769 .60399 m .27948 .60572 L .27952 .6034 L F
.27769 .60399 m .27773 .60641 L .27948 .60572 L F
.37 .779 .982 r
.37912 .54839 m .37751 .54763 L .37465 .54788 L F
.962 .83 .666 r
.37912 .54839 m .37839 .55102 L .37751 .54763 L F
.996 .779 .488 r
.38032 .55466 m .37891 .55637 L .37916 .55328 L F
.253 0 0 r
.23314 .55957 m .23108 .56146 L .22934 .56098 L F
.138 .101 .55 r
.33817 .60114 m .34004 .60248 L .34032 .59991 L F
.33817 .60114 m .33853 .60373 L .34004 .60248 L F
.477 .157 .345 r
.24664 .55479 m .2499 .55424 L .25038 .55122 L F
.127 0 .243 r
.25038 .55122 m .25146 .55277 L .25252 .55017 L F
.25038 .55122 m .2499 .55424 L .25146 .55277 L F
0 .179 .694 r
.31318 .55004 m .31085 .5476 L .31327 .54723 L F
.51 .383 .644 r
.35509 .56027 m .35715 .5569 L .35484 .55752 L F
.571 .054 0 r
.24606 .55987 m .24526 .56069 L .24504 .56066 L F
.112 0 0 r
.24754 .55873 m .24606 .55987 L .24404 .56023 L F
.571 .054 0 r
.24606 .55987 m .24211 .56022 L .24404 .56023 L F
.24606 .55987 m .24504 .56066 L .24211 .56022 L F
.112 0 0 r
.24862 .55827 m .24606 .55987 L .24754 .55873 L F
.097 0 0 r
.25027 .55837 m .24606 .55987 L .24862 .55827 L F
.091 0 0 r
.25106 .55782 m .25027 .55837 L .24862 .55827 L F
.448 .556 .873 r
.36753 .54105 m .36783 .53753 L .36596 .53806 L F
.36753 .54105 m .36968 .541 L .36783 .53753 L F
.301 0 .038 r
.31472 .56882 m .31747 .56845 L .31822 .56689 L F
0 0 0 r
.31747 .56845 m .32042 .56612 L .31822 .56689 L F
.513 .383 .64 r
.27453 .62313 m .27428 .62771 L .27373 .62756 L F
.034 0 .203 r
.27453 .62313 m .2778 .61896 L .2772 .62144 L F
.185 .109 .531 r
.27686 .62383 m .27453 .62313 L .2772 .62144 L F
.27686 .62383 m .27428 .62771 L .27453 .62313 L F
.683 .479 .605 r
.3338 .61263 m .33714 .61012 L .334 .61017 L F
0 0 .112 r
.33452 .61111 m .3338 .61263 L .334 .61017 L F
.33452 .61111 m .334 .61017 L .33238 .60892 L F
.511 .571 .852 r
.19283 .61411 m .19626 .61497 L .19462 .61201 L F
.426 .326 .638 r
.3659 .59764 m .36627 .60025 L .36428 .6008 L F
.426 .324 .636 r
.36627 .60025 m .36664 .60287 L .36428 .6008 L F
.947 .663 .466 r
.31771 .55723 m .31758 .55373 L .31548 .55443 L F
.61 .448 .638 r
.33575 .64723 m .3385 .64729 L .33822 .64409 L F
.583 .288 .433 r
.33575 .64723 m .33795 .64935 L .3385 .64729 L F
.61 .448 .638 r
.33822 .64409 m .3385 .64729 L .33575 .64723 L F
.583 .288 .433 r
.33575 .64723 m .33795 .64935 L .3385 .64729 L F
.61 .448 .638 r
.33575 .64723 m .3385 .64729 L .33822 .64409 L F
.901 .745 .678 r
.30613 .64336 m .30926 .64404 L .30826 .6412 L F
.876 .612 .536 r
.30552 .64541 m .30926 .64404 L .30613 .64336 L F
.30552 .64541 m .3089 .64665 L .30926 .64404 L F
.526 .369 .611 r
.30926 .64404 m .31152 .64086 L .30826 .6412 L F
.30926 .64404 m .31163 .64356 L .31152 .64086 L F
.561 .349 .55 r
.3089 .64665 m .31163 .64356 L .30926 .64404 L F
.603 .634 .854 r
.17604 .60051 m .17803 .60389 L .18054 .60332 L F
.191 0 .273 r
.27327 .61308 m .27186 .61436 L .27075 .61628 L F
.798 .549 .562 r
.35229 .56055 m .35618 .56365 L .35509 .56027 L F
.35229 .56055 m .35218 .56311 L .35618 .56365 L F
.208 .306 .745 r
.35509 .56027 m .35618 .56365 L .35711 .56256 L F
.406 .604 .928 r
.35618 .56365 m .35772 .56324 L .35711 .56256 L F
.699 .47 .572 r
.35618 .56365 m .35919 .56605 L .35772 .56324 L F
.096 .653 .734 r
.25264 .62601 m .25514 .62576 L .25691 .62564 L F
0 0 0 r
.25984 .62297 m .25691 .62564 L .25848 .62441 L F
.5 .905 .906 r
.25691 .62564 m .25774 .62461 L .25848 .62441 L F
.25691 .62564 m .25514 .62576 L .25774 .62461 L F
.607 .729 .931 r
.18937 .61085 m .19041 .60864 L .18894 .60959 L F
.18937 .61085 m .19129 .61016 L .19041 .60864 L F
.252 0 .282 r
.31831 .61583 m .31928 .61377 L .31766 .61571 L F
.236 0 .272 r
.32112 .61268 m .31928 .61377 L .31831 .61583 L F
.39 .161 .442 r
.32663 .57834 m .32373 .58176 L .3242 .57925 L F
.916 .978 .72 r
.26965 .69505 m .27175 .69362 L .26913 .69689 L F
.828 .635 .643 r
.27175 .69362 m .27177 .69669 L .26913 .69689 L F
.127 .075 .524 r
.27308 .69524 m .27177 .69669 L .27175 .69362 L F
.616 .147 .117 r
.27308 .69524 m .27175 .69362 L .26965 .69505 L F
.425 .126 .351 r
.27175 .69362 m .27404 .69314 L .27308 .69524 L F
.902 .496 .212 r
.51278 .54617 m .51125 .54663 L .5113 .54391 L F
.51278 .54617 m .51299 .54753 L .51125 .54663 L F
.824 .785 .815 r
.5113 .54391 m .51498 .54255 L .51278 .54617 L F
.566 .678 .915 r
.32663 .59277 m .32813 .59059 L .32689 .59074 L F
.32663 .59277 m .32933 .5926 L .32813 .59059 L F
.648 .686 .872 r
.32902 .55841 m .32666 .56108 L .32949 .56076 L F
.554 .365 .579 r
.21673 .5606 m .21673 .56325 L .21431 .56367 L F
.304 .168 .525 r
.21879 .562 m .21673 .5606 L .21915 .5605 L F
.21879 .562 m .21673 .56325 L .21673 .5606 L F
0 0 0 r
.179 .56376 m .17622 .56671 L .17758 .56563 L F
.092 0 0 r
.17758 .56563 m .18094 .56301 L .179 .56376 L F
.347 .01 .243 r
.30755 .60777 m .30973 .60712 L .31179 .60455 L F
.881 .46 .198 r
.31165 .6071 m .31179 .60455 L .30973 .60712 L F
.31165 .6071 m .31366 .60709 L .31179 .60455 L F
.539 .838 .999 r
.32039 .5339 m .32258 .53326 L .32389 .53399 L F
.41 .768 .995 r
.3251 .53292 m .32389 .53399 L .32258 .53326 L F
.3251 .53292 m .3261 .53388 L .32389 .53399 L F
0 0 .425 r
.34181 .63679 m .34096 .6362 L .34102 .63444 L F
.622 .163 0 r
.33098 .55213 m .33076 .55208 L .32943 .55123 L F
.441 .08 .256 r
.21673 .56325 m .21355 .56542 L .21431 .56367 L F
.534 .367 .602 r
.32889 .63707 m .32634 .63419 L .32825 .63379 L F
.32889 .63707 m .32656 .63781 L .32634 .63419 L F
.581 .609 .845 r
.51185 .55953 m .51076 .56349 L .50903 .56177 L F
.51185 .55953 m .51327 .56285 L .51076 .56349 L F
0 0 .097 r
.31297 .61851 m .31357 .61647 L .31435 .6156 L F
.773 .98 .911 r
.33195 .55765 m .33099 .5569 L .33367 .5543 L F
.321 .227 .59 r
.33195 .55765 m .33412 .5593 L .33234 .55881 L F
.88 .503 .03 r
.33195 .55765 m .33234 .55881 L .33099 .5569 L F
.679 .626 .789 r
.33368 .55496 m .33552 .55767 L .33195 .55765 L F
.321 .227 .59 r
.33195 .55765 m .33412 .5593 L .33234 .55881 L F
.419 0 .016 r
.29474 .54842 m .29346 .54982 L .29119 .54912 L F
.599 .142 .138 r
.29583 .54984 m .29474 .54842 L .29719 .54763 L F
.29583 .54984 m .29346 .54982 L .29474 .54842 L F
.692 .966 .74 r
.25848 .62441 m .26156 .6216 L .25984 .62297 L F
.554 .333 .533 r
.50284 .54202 m .5054 .5442 L .50544 .54117 L F
0 .121 .626 r
.50284 .54202 m .50423 .54287 L .50544 .54117 L F
.50284 .54202 m .5054 .5442 L .50423 .54287 L F
.071 0 0 r
.20098 .54723 m .20233 .54734 L .20399 .54599 L F
.048 0 0 r
.20098 .54723 m .20127 .54893 L .20233 .54734 L F
.20098 .54723 m .19942 .54986 L .20127 .54893 L F
.523 .384 .633 r
.34081 .64635 m .33822 .64409 L .34036 .64402 L F
.34081 .64635 m .3385 .64729 L .33822 .64409 L F
.34081 .64635 m .33822 .64409 L .34036 .64402 L F
.34081 .64635 m .3385 .64729 L .33822 .64409 L F
.348 .106 .399 r
.18147 .56064 m .18094 .56301 L .18347 .55995 L F
0 0 .406 r
.33764 .54936 m .3367 .54857 L .33916 .54798 L F
.585 .717 .934 r
.50192 .55619 m .50319 .55783 L .49945 .55682 L F
.481 .48 .779 r
.50412 .55334 m .50319 .55783 L .50192 .55619 L F
.50412 .55334 m .50494 .55719 L .50319 .55783 L F
.48 .847 .99 r
.34568 .53512 m .34933 .53474 L .3513 .53531 L F
.568 .88 .992 r
.3513 .53531 m .34772 .53427 L .3517 .53434 L F
.616 .299 .41 r
.3476 .53688 m .35137 .53644 L .35167 .53449 L F
.3514 .53452 m .35167 .53449 L .3517 .53434 L F
.3476 .53688 m .35167 .53449 L .3514 .53452 L F
.48 .847 .99 r
.34546 .53511 m .34772 .53427 L .34933 .53474 L F
.34546 .53511 m .34933 .53474 L .34568 .53512 L F
.279 .546 .922 r
.20348 .60028 m .20288 .60205 L .20144 .60041 L F
.20348 .60028 m .20557 .60278 L .20288 .60205 L F
.595 .754 .954 r
.33019 .53492 m .3261 .53388 L .32804 .53294 L F
.626 .819 .974 r
.33265 .53384 m .33019 .53492 L .32804 .53294 L F
.472 .405 .701 r
.34088 .55367 m .34275 .55106 L .3399 .55111 L F
.34088 .55367 m .34377 .55379 L .34275 .55106 L F
.244 .671 .961 r
.34351 .55427 m .34377 .55379 L .34088 .55367 L F
.081 0 .288 r
.34223 .55582 m .34408 .55322 L .34377 .55379 L F
.071 .163 .654 r
.34275 .55106 m .34377 .55379 L .34465 .5524 L F
.081 0 .288 r
.34408 .55322 m .34465 .5524 L .34377 .55379 L F
.244 .671 .961 r
.34461 .55452 m .34377 .55379 L .34351 .55427 L F
.677 .766 .918 r
.33541 .54395 m .33588 .54551 L .33804 .54506 L F
.668 .539 .698 r
.33804 .54506 m .33588 .54551 L .3393 .54506 L F
.778 .58 .631 r
.33581 .54699 m .3393 .54506 L .33588 .54551 L F
.922 .883 .778 r
.54501 .56266 m .54645 .56382 L .5482 .56016 L F
0 0 .287 r
.37183 .55095 m .37153 .55365 L .3706 .55455 L F
.515 .373 .627 r
.37153 .55365 m .36978 .55675 L .3706 .55455 L F
.429 .75 .994 r
.31476 .53163 m .31391 .53317 L .31231 .53251 L F
.31476 .53163 m .31611 .53288 L .31391 .53317 L F
0 .112 .661 r
.33352 .63679 m .33151 .63389 L .33216 .63557 L F
.576 .041 0 r
.3626 .54601 m .36663 .5469 L .36459 .54547 L F
.658 .761 .925 r
.27747 .62935 m .27321 .62884 L .27548 .62863 L F
.599 .944 .928 r
.27797 .62845 m .27747 .62935 L .27548 .62863 L F
.27797 .62845 m .28036 .6281 L .27747 .62935 L F
.994 .872 .561 r
.54885 .55017 m .54886 .55339 L .549 .55119 L F
0 0 .201 r
.29709 .57302 m .29656 .57538 L .29823 .57176 L F
.078 0 0 r
.26413 .53136 m .26638 .53134 L .26823 .53103 L F
0 0 0 r
.26638 .53134 m .27019 .53068 L .26823 .53103 L F
.561 .769 .976 r
.24248 .62411 m .24036 .62482 L .23909 .62338 L F
.451 .546 .862 r
.19975 .61808 m .20033 .61996 L .20176 .61783 L F
.446 .509 .83 r
.20123 .62114 m .20176 .61783 L .20033 .61996 L F
.24 0 0 r
.37346 .53515 m .37456 .53526 L .37629 .53505 L F
.665 .183 .097 r
.37456 .53526 m .37832 .53597 L .37629 .53505 L F
.346 .12 .421 r
.37456 .53526 m .37644 .5361 L .37832 .53597 L F
.195 .401 .837 r
.3791 .53394 m .37832 .53597 L .37709 .53606 L F
.47 .476 .781 r
.37567 .53063 m .37755 .5355 L .37456 .53526 L F
.37755 .5355 m .37751 .53555 L .37456 .53526 L F
.37758 .53556 m .3776 .53562 L .37456 .53526 L F
.346 .12 .421 r
.37644 .5361 m .37456 .53526 L .37747 .5356 L F
.195 .401 .837 r
.37747 .5356 m .37709 .53606 L .37644 .5361 L F
.346 .12 .421 r
.37644 .5361 m .37747 .5356 L .3776 .53562 L F
.57 .534 .775 r
.3791 .53394 m .3776 .53562 L .37755 .5355 L F
.3791 .53394 m .37755 .5355 L .37567 .53063 L F
.195 .401 .837 r
.37836 .53454 m .37755 .5355 L .37644 .5361 L F
.37755 .5355 m .37747 .5356 L .37744 .53562 L F
.37755 .5355 m .37744 .53562 L .37644 .5361 L F
.3791 .53394 m .37709 .53606 L .37836 .53454 L F
.47 .476 .781 r
.37755 .5355 m .37758 .53556 L .37751 .53555 L F
.24 0 0 r
.37212 .5352 m .37456 .53526 L .37346 .53515 L F
.422 .679 .969 r
.21636 .61511 m .21594 .61698 L .21459 .61503 L F
.21636 .61511 m .2181 .6169 L .21594 .61698 L F
.227 .112 .506 r
.31831 .61583 m .31766 .61571 L .31832 .61869 L F
.525 .361 .601 r
.36459 .60595 m .36208 .60978 L .36248 .60697 L F
.824 .774 .805 r
.3444 .55969 m .34658 .56141 L .34785 .55975 L F
.039 .109 .609 r
.3444 .55969 m .34658 .56141 L .34785 .55975 L F
0 0 0 r
.32814 .61071 m .32573 .6117 L .32569 .60903 L F
.32814 .61071 m .32436 .61265 L .32573 .6117 L F
.556 .446 .684 r
.35977 .55124 m .36295 .55341 L .36214 .55065 L F
.35977 .55124 m .36043 .55427 L .36295 .55341 L F
.477 .212 .433 r
.27428 .62771 m .27321 .62884 L .27373 .62756 L F
.269 .436 .843 r
.35365 .61411 m .35638 .61574 L .35545 .61654 L F
.67 .45 .577 r
.35803 .61878 m .35545 .61654 L .35638 .61574 L F
.35803 .61878 m .35433 .61907 L .35545 .61654 L F
0 0 0 r
.24111 .55729 m .24288 .55659 L .24445 .55491 L F
.392 0 .068 r
.24288 .55659 m .24664 .55479 L .24445 .55491 L F
0 0 0 r
.20399 .54599 m .20438 .54665 L .2062 .54529 L F
.20399 .54599 m .20233 .54734 L .20438 .54665 L F
.863 .831 .814 r
.28276 .67177 m .28509 .66924 L .28353 .6671 L F
.494 .047 .117 r
.28509 .66924 m .2889 .66875 L .28743 .67052 L F
0 .296 .788 r
.28353 .6671 m .28509 .66924 L .28743 .67052 L F
.989 .773 .386 r
.31549 .60894 m .31645 .61101 L .31653 .61026 L F
.919 .848 .401 r
.31586 .61352 m .31653 .61026 L .31645 .61101 L F
.422 .861 .919 r
.26787 .61877 m .26879 .61787 L .27075 .61628 L F
.26787 .61877 m .26665 .61855 L .26879 .61787 L F
.024 0 .063 r
.17622 .56671 m .17356 .56967 L .17522 .56864 L F
.167 0 .145 r
.17622 .56671 m .17698 .56767 L .17758 .56563 L F
.17622 .56671 m .17522 .56864 L .17698 .56767 L F
0 0 0 r
.32185 .60028 m .32205 .60047 L .32064 .60199 L F
.686 .344 .391 r
.32187 .65567 m .32022 .65836 L .31809 .65592 L F
.677 .334 .386 r
.32404 .65821 m .32187 .65567 L .32442 .65637 L F
.32404 .65821 m .32022 .65836 L .32187 .65567 L F
.167 .705 .781 r
.27661 .53092 m .27893 .53058 L .28087 .53052 L F
.225 .742 .856 r
.27893 .53058 m .28262 .53025 L .28087 .53052 L F
.461 .696 .969 r
.22927 .63383 m .22857 .63093 L .22735 .63063 L F
.22927 .63383 m .23151 .63354 L .22857 .63093 L F
.273 0 .294 r
.29578 .59285 m .29446 .5915 L .29592 .59013 L F
.29578 .59285 m .29377 .59362 L .29446 .5915 L F
.402 0 0 r
.2889 .66875 m .28896 .67059 L .28743 .67052 L F
.2889 .66875 m .29154 .66856 L .28896 .67059 L F
.279 0 0 r
.29119 .54912 m .28999 .55044 L .28758 .5507 L F
.414 0 0 r
.29346 .54982 m .28999 .55044 L .29119 .54912 L F
.115 .628 .892 r
.28242 .67706 m .28035 .67706 L .27972 .67658 L F
.803 .621 .656 r
.30769 .64069 m .31152 .64086 L .31092 .63818 L F
.467 .405 .704 r
.31092 .63818 m .31356 .64034 L .31289 .63716 L F
.31092 .63818 m .31152 .64086 L .31356 .64034 L F
.649 .425 .567 r
.30784 .58701 m .31093 .58434 L .30873 .58529 L F
.269 0 .023 r
.16983 .57203 m .17195 .57168 L .17356 .56967 L F
.406 .076 .29 r
.17195 .57168 m .17522 .56864 L .17356 .56967 L F
.065 .499 .895 r
.22661 .61835 m .22635 .61923 L .22455 .61832 L F
.22661 .61835 m .22818 .61979 L .22635 .61923 L F
.515 .749 .98 r
.35856 .54589 m .36131 .54541 L .35688 .54418 L F
.48 .461 .759 r
.35856 .54589 m .36113 .54649 L .36131 .54541 L F
.2 0 .289 r
.27985 .5975 m .28152 .59683 L .28213 .59452 L F
.259 .075 .431 r
.27956 .59985 m .28152 .59683 L .27985 .5975 L F
.066 .187 .681 r
.31075 .56465 m .31251 .56585 L .31138 .56697 L F
0 0 .218 r
.31251 .56585 m .31266 .56776 L .31176 .56963 L F
.698 .833 .948 r
.31509 .56694 m .31214 .56948 L .31266 .56776 L F
.526 .222 .395 r
.31509 .56694 m .31266 .56776 L .31251 .56585 L F
.698 .833 .948 r
.31509 .56694 m .31266 .56776 L .31292 .5669 L F
0 0 .218 r
.31266 .56776 m .31234 .56882 L .31176 .56963 L F
.041 0 0 r
.31176 .56963 m .31118 .57162 L .31105 .57081 L F
0 0 0 r
.3112 .57028 m .31104 .57075 L .31118 .57162 L F
.31104 .57075 m .31008 .57353 L .31118 .57162 L F
.041 0 0 r
.31105 .57081 m .31118 .57162 L .31051 .5717 L F
.31159 .56976 m .31051 .5717 L .3088 .57188 L F
.31176 .56963 m .31051 .5717 L .31159 .56976 L F
.179 0 .27 r
.31008 .57353 m .3088 .57188 L .31051 .5717 L F
0 0 .189 r
.31005 .57251 m .31008 .57353 L .31104 .57075 L F
.179 0 .27 r
.31008 .57353 m .31051 .5717 L .31118 .57162 L F
0 0 .189 r
.30987 .56667 m .30989 .56757 L .30999 .56754 L F
.30987 .56667 m .31054 .57157 L .31097 .56967 L F
.066 .187 .681 r
.31037 .56328 m .31251 .56585 L .31075 .56465 L F
.712 .309 .283 r
.30873 .56536 m .31251 .56585 L .31037 .56328 L F
.932 .952 .775 r
.30987 .56667 m .3112 .57028 L .31072 .56687 L F
.588 .066 0 r
.30873 .56536 m .31072 .56687 L .31251 .56585 L F
.218 0 0 r
.30764 .56512 m .30873 .56536 L .31037 .56328 L F
.082 .219 .708 r
.30965 .56317 m .3104 .56574 L .30873 .56536 L F
.3104 .56574 m .31072 .56687 L .30873 .56536 L F
.218 0 0 r
.30644 .56592 m .30873 .56536 L .30764 .56512 L F
0 0 .189 r
.30999 .56754 m .31005 .57251 L .31054 .57157 L F
.30989 .56757 m .31005 .57251 L .30999 .56754 L F
.31005 .57251 m .31104 .57075 L .3112 .57028 L F
.179 0 .27 r
.31008 .57353 m .30812 .57459 L .3088 .57188 L F
0 0 .494 r
.31035 .57236 m .31149 .57566 L .31008 .57353 L F
.6 .576 .799 r
.31357 .57264 m .31149 .57566 L .31035 .57236 L F
.31368 .57265 m .31365 .57271 L .31357 .57264 L F
.31365 .57271 m .31149 .57566 L .31357 .57264 L F
0 0 .189 r
.31004 .57215 m .31035 .57236 L .31008 .57353 L F
.382 .155 .441 r
.31011 .57592 m .30812 .57459 L .31008 .57353 L F
.149 .046 .472 r
.31008 .57353 m .31149 .57566 L .31011 .57592 L F
0 0 0 r
.31261 .57454 m .31149 .57566 L .31368 .57265 L F
.6 .576 .799 r
.31368 .57265 m .31035 .57236 L .313 .5712 L F
.781 .553 .59 r
.30853 .57346 m .31261 .57454 L .3129 .57206 L F
.31231 .57155 m .3129 .57206 L .313 .5712 L F
.30853 .57346 m .3129 .57206 L .31231 .57155 L F
.30853 .57346 m .31051 .57246 L .31035 .57236 L F
.31051 .57246 m .313 .5712 L .31035 .57236 L F
0 0 .189 r
.30989 .56757 m .31035 .57236 L .31004 .57215 L F
.992 .845 .592 r
.31072 .56687 m .30991 .56751 L .30987 .56667 L F
0 0 .189 r
.30987 .56667 m .30991 .56751 L .30989 .56757 L F
.992 .845 .592 r
.30991 .56751 m .30886 .56834 L .30987 .56667 L F
0 0 .189 r
.30987 .56667 m .30993 .56739 L .30991 .56751 L F
.30993 .56739 m .31035 .57236 L .30989 .56757 L F
0 .152 .671 r
.31145 .56513 m .31072 .56687 L .30965 .56317 L F
.76 .963 .666 r
.31145 .56513 m .31003 .56689 L .31072 .56687 L F
.906 .682 .588 r
.3085 .57148 m .31035 .57236 L .30993 .56739 L F
.30956 .56774 m .30993 .56739 L .30987 .56667 L F
.76 .963 .666 r
.30965 .56766 m .3093 .56799 L .30978 .56761 L F
.906 .682 .588 r
.3085 .57148 m .30993 .56739 L .30956 .56774 L F
.76 .963 .666 r
.3093 .56796 m .30886 .56834 L .3093 .56799 L F
.906 .682 .588 r
.3085 .57148 m .30956 .56774 L .30886 .56834 L F
.30956 .56774 m .30987 .56667 L .30886 .56834 L F
.76 .963 .666 r
.3093 .56779 m .30886 .56834 L .3093 .56796 L F
.3093 .56779 m .3093 .56799 L .30965 .56766 L F
.31003 .56689 m .3093 .56779 L .30993 .56738 L F
.31003 .56689 m .30993 .56738 L .31072 .56687 L F
.3093 .56779 m .30978 .56761 L .31072 .56687 L F
0 0 .189 r
.31097 .56967 m .31054 .57157 L .3112 .57028 L F
.363 0 0 r
.3112 .57028 m .31176 .56963 L .31234 .56882 L F
.3112 .57028 m .31118 .57162 L .31176 .56963 L F
.698 .833 .948 r
.31382 .56692 m .3112 .57028 L .31509 .56694 L F
.31072 .56687 m .3112 .57028 L .31382 .56692 L F
.31214 .56948 m .3112 .57028 L .31292 .5669 L F
.363 0 0 r
.3112 .57028 m .31234 .56882 L .31271 .5683 L F
.526 .222 .395 r
.31509 .56694 m .31271 .5683 L .31266 .56776 L F
0 0 .218 r
.31266 .56776 m .31271 .5683 L .31234 .56882 L F
.698 .833 .948 r
.31292 .5669 m .3112 .57028 L .31072 .56687 L F
.521 0 0 r
.31251 .56585 m .31072 .56687 L .31409 .56693 L F
.31251 .56585 m .31409 .56693 L .31509 .56694 L F
.518 .873 .986 r
.34661 .5589 m .3444 .55969 L .34785 .55975 L F
.556 .298 .48 r
.33992 .56341 m .33939 .56607 L .33749 .56529 L F
.772 .692 .775 r
.34196 .56288 m .33939 .56607 L .33992 .56341 L F
.185 0 0 r
.26533 .64175 m .26976 .64081 L .26742 .64196 L F
.26533 .64175 m .26593 .64135 L .26976 .64081 L F
.319 0 0 r
.26976 .64081 m .26994 .64154 L .26742 .64196 L F
.26976 .64081 m .27177 .64127 L .26994 .64154 L F
0 0 .48 r
.30432 .59173 m .30572 .59279 L .30539 .59023 L F
.30432 .59173 m .30449 .5944 L .30572 .59279 L F
.514 .48 .756 r
.36995 .58772 m .36782 .58839 L .36683 .58474 L F
.449 .288 .57 r
.36995 .58772 m .37001 .59039 L .36782 .58839 L F
.565 .774 .976 r
.23151 .63354 m .2329 .63462 L .23526 .63397 L F
.344 .301 .666 r
.16418 .585 m .16447 .58865 L .16638 .58723 L F
.419 .381 .71 r
.16509 .59111 m .16638 .58723 L .16447 .58865 L F
.694 .665 .817 r
.28501 .65313 m .28914 .65422 L .28726 .65278 L F
.605 .769 .958 r
.29139 .65304 m .28914 .65422 L .28726 .65278 L F
.447 .34 .64 r
.28914 .65422 m .29139 .65304 L .28726 .65278 L F
.28914 .65422 m .29115 .65568 L .29139 .65304 L F
.368 .183 .494 r
.35073 .57209 m .35291 .56864 L .35088 .56976 L F
.695 .835 .95 r
.32383 .54038 m .32137 .54154 L .32537 .54176 L F
.632 .815 .97 r
.32383 .54038 m .32537 .54176 L .32782 .54072 L F
.622 .562 .766 r
.32537 .54176 m .32919 .5449 L .32782 .54072 L F
.684 .829 .953 r
.30758 .59968 m .31261 .60041 L .30979 .59848 L F
.356 .708 .985 r
.31261 .60041 m .31287 .59891 L .30979 .59848 L F
.31261 .60041 m .31436 .60009 L .31287 .59891 L F
0 .181 .706 r
.31261 .60041 m .31427 .60342 L .31436 .60009 L F
.352 .204 .536 r
.16418 .585 m .16597 .58442 L .166 .58181 L F
.344 .301 .666 r
.16418 .585 m .16638 .58723 L .16597 .58442 L F
.33 0 .183 r
.28368 .54742 m .28578 .54701 L .28707 .54439 L F
.524 .59 .863 r
.28876 .54401 m .28573 .54273 L .28707 .54439 L F
.486 .116 .262 r
.28707 .54439 m .29178 .54511 L .28876 .54401 L F
.28707 .54439 m .28578 .54701 L .29178 .54511 L F
.215 .734 .86 r
.30425 .53076 m .3035 .53125 L .30233 .53013 L F
.30425 .53076 m .30702 .53089 L .3035 .53125 L F
0 0 .472 r
.50797 .56744 m .5091 .56553 L .50763 .56168 L F
.473 .732 .983 r
.50797 .56744 m .51064 .56717 L .5091 .56553 L F
.497 .302 .546 r
.23408 .75311 m .23553 .75534 L .23562 .75211 L F
.414 .497 .835 r
.50808 .55878 m .50666 .56089 L .50494 .55719 L F
.657 .619 .8 r
.33713 .55719 m .33552 .55767 L .33368 .55496 L F
.477 .381 .667 r
.33788 .55965 m .33552 .55767 L .33713 .55719 L F
.33788 .55965 m .33574 .56035 L .33552 .55767 L F
.941 .73 .591 r
.25406 .72087 m .25482 .71844 L .25251 .71735 L F
.534 .366 .6 r
.32679 .54821 m .32913 .54776 L .32919 .5449 L F
.647 .896 .984 r
.32679 .54821 m .32742 .54617 L .32913 .54776 L F
.922 .883 .778 r
.54501 .56266 m .5482 .56016 L .54731 .55943 L F
.064 0 .098 r
.32689 .59074 m .32813 .59059 L .32907 .58859 L F
.641 .493 .666 r
.28122 .66297 m .28127 .66603 L .28367 .66244 L F
0 0 .002 r
.30769 .63077 m .30671 .63177 L .30865 .6284 L F
0 0 .121 r
.3059 .63438 m .30671 .63177 L .30769 .63077 L F
.305 .126 .467 r
.30227 .61305 m .30374 .61534 L .30403 .61171 L F
.30227 .61305 m .30202 .61571 L .30374 .61534 L F
.446 .509 .83 r
.20123 .62114 m .20326 .62134 L .20176 .61783 L F
.883 .706 .657 r
.3275 .60394 m .32902 .60753 L .32673 .60686 L F
.637 .243 .281 r
.32902 .60753 m .32569 .60903 L .32673 .60686 L F
.326 .419 .804 r
.33072 .60558 m .32902 .60753 L .3275 .60394 L F
.79 .711 .777 r
.34099 .58786 m .34261 .59126 L .33865 .59079 L F
.694 .233 .153 r
.33865 .59079 m .34261 .59126 L .34067 .59263 L F
.596 .635 .859 r
.34354 .58726 m .34507 .59081 L .34261 .59126 L F
.34261 .59126 m .34507 .59081 L .34354 .58726 L F
.152 .692 .724 r
.34261 .59126 m .34272 .59116 L .34067 .59263 L F
.34261 .59126 m .34507 .59081 L .34272 .59116 L F
.58 .476 .7 r
.34337 .59467 m .34507 .59081 L .34261 .59126 L F
.517 .388 .644 r
.31318 .62118 m .31089 .62514 L .3107 .62251 L F
.189 .721 .807 r
.28573 .54273 m .28268 .54293 L .28336 .54247 L F
.28268 .54293 m .28135 .54302 L .28186 .54288 L F
.28573 .54273 m .28394 .54269 L .28135 .54302 L F
.569 .754 .965 r
.28876 .54401 m .28966 .54406 L .28905 .54389 L F
.28876 .54401 m .28905 .54389 L .28922 .54395 L F
.28905 .54389 m .29231 .5442 L .29277 .54232 L F
.28905 .54389 m .29277 .54232 L .28922 .54395 L F
.302 .737 .968 r
.28922 .54395 m .28394 .54269 L .28483 .54271 L F
.524 .59 .863 r
.28876 .54401 m .28922 .54395 L .28573 .54273 L F
.302 .737 .968 r
.28902 .54388 m .28483 .54271 L .28573 .54273 L F
.28922 .54395 m .28483 .54271 L .28902 .54388 L F
.569 .754 .965 r
.28966 .54406 m .29231 .5442 L .28905 .54389 L F
.302 .737 .968 r
.28572 .54312 m .28638 .54273 L .28394 .54269 L F
.28922 .54395 m .28753 .54323 L .28572 .54312 L F
.28753 .54323 m .28638 .54273 L .28572 .54312 L F
.189 .721 .807 r
.28268 .54293 m .28186 .54288 L .28336 .54247 L F
.254 0 .313 r
.28213 .59452 m .28341 .59597 L .28445 .59405 L F
.28213 .59452 m .28152 .59683 L .28341 .59597 L F
.178 0 0 r
.25939 .5537 m .25535 .55625 L .2573 .55453 L F
.433 .873 .887 r
.31427 .60342 m .31722 .60181 L .31436 .60009 L F
.31427 .60342 m .31831 .60193 L .31722 .60181 L F
.749 .732 .837 r
.37751 .54763 m .37839 .55102 L .37466 .55055 L F
.784 .629 .688 r
.37839 .55102 m .37667 .55476 L .37466 .55055 L F
.458 .258 .519 r
.37916 .55328 m .37667 .55476 L .37839 .55102 L F
.855 .417 .172 r
.27993 .62972 m .28036 .6281 L .27797 .62845 L F
.27993 .62972 m .28095 .62849 L .28036 .6281 L F
.255 .427 .841 r
.19952 .59684 m .19987 .60018 L .19764 .59715 L F
.19952 .59684 m .20144 .60041 L .19987 .60018 L F
.677 .766 .918 r
.33541 .54395 m .33804 .54506 L .33641 .54127 L F
.719 .803 .917 r
.33641 .54127 m .34053 .5421 L .3388 .53988 L F
.33793 .54158 m .33804 .54506 L .34053 .5421 L F
.33641 .54127 m .33732 .54341 L .33793 .54158 L F
.33732 .54341 m .33804 .54506 L .33793 .54158 L F
.675 .447 .568 r
.33641 .54127 m .3388 .54269 L .3388 .53988 L F
.356 .733 .987 r
.33695 .54151 m .33835 .54028 L .33909 .53785 L F
.33835 .54028 m .3388 .53988 L .33904 .53819 L F
.33835 .54028 m .33904 .53819 L .33909 .53785 L F
.668 .538 .697 r
.33804 .54506 m .34183 .54474 L .34053 .5421 L F
.33804 .54506 m .3393 .54506 L .34183 .54474 L F
.815 .849 .875 r
.27971 .66467 m .28127 .66603 L .27857 .66842 L F
.27971 .66467 m .27857 .66842 L .27954 .66751 L F
.134 .599 .923 r
.29088 .53168 m .28708 .53044 L .28972 .53036 L F
.574 .746 .959 r
.29178 .52953 m .29088 .53168 L .28972 .53036 L F
.29178 .52953 m .29328 .53122 L .29088 .53168 L F
.349 .068 .339 r
.3088 .57188 m .30598 .57519 L .30639 .57251 L F
0 0 .16 r
.29928 .56623 m .29965 .56807 L .30159 .56651 L F
.692 .842 .955 r
.30826 .6412 m .31152 .64086 L .30769 .64069 L F
.543 .383 .613 r
.31152 .64086 m .31405 .64301 L .31356 .64034 L F
.31152 .64086 m .31163 .64356 L .31405 .64301 L F
.581 .59 .827 r
.50192 .55619 m .49945 .55682 L .49788 .55381 L F
.45 .176 .404 r
.33341 .56837 m .33066 .57221 L .33089 .56991 L F
.207 .723 .686 r
.30691 .60793 m .30755 .60777 L .30496 .60887 L F
.30691 .60793 m .30973 .60712 L .30755 .60777 L F
.553 .018 0 r
.54778 .53963 m .54753 .5391 L .54708 .53783 L F
.54778 .53963 m .54925 .54072 L .54753 .5391 L F
.565 .735 .955 r
.33951 .58613 m .33988 .58569 L .33953 .58408 L F
.33951 .58613 m .33839 .58808 L .33988 .58569 L F
.357 .76 .984 r
.33839 .58808 m .34099 .58786 L .33988 .58569 L F
.488 .368 .642 r
.33988 .58569 m .34408 .58654 L .34334 .58134 L F
.523 .39 .64 r
.3405 .5869 m .34277 .58667 L .33988 .58569 L F
.34277 .58667 m .34408 .58654 L .34208 .58614 L F
.34277 .58667 m .34208 .58614 L .33988 .58569 L F
.34267 .58714 m .34313 .58695 L .3405 .5869 L F
.34313 .58695 m .34408 .58654 L .34277 .58667 L F
.34313 .58695 m .34277 .58667 L .3405 .5869 L F
.34099 .58786 m .34267 .58714 L .3405 .5869 L F
.34099 .58786 m .34354 .58726 L .34408 .58654 L F
.522 .807 .998 r
.34179 .58618 m .34354 .58726 L .34099 .58786 L F
.543 .013 0 r
.34381 .58775 m .34355 .58727 L .34179 .58618 L F
.34355 .58727 m .34354 .58726 L .3435 .58724 L F
.34355 .58727 m .3435 .58724 L .34179 .58618 L F
.3435 .58724 m .34381 .58775 L .34179 .58618 L F
.34354 .58726 m .34355 .58727 L .3435 .58724 L F
0 .209 .73 r
.34547 .58909 m .34507 .59081 L .34354 .58726 L F
.501 .803 .999 r
.34507 .59081 m .34547 .58909 L .34354 .58726 L F
.543 .013 0 r
.34355 .58727 m .34381 .58775 L .3435 .58724 L F
.464 .313 .591 r
.34408 .58654 m .34354 .58726 L .34652 .58753 L F
.197 .636 .947 r
.34652 .58753 m .34432 .58733 L .34179 .58618 L F
.34432 .58733 m .34354 .58726 L .3435 .58724 L F
.34432 .58733 m .3435 .58724 L .34179 .58618 L F
.476 .39 .679 r
.30043 .61927 m .30266 .61864 L .30202 .61571 L F
.359 .178 .494 r
.30005 .62142 m .30266 .61864 L .30043 .61927 L F
.561 .616 .865 r
.26588 .55096 m .26952 .55346 L .26811 .55031 L F
.508 .282 .506 r
.27064 .54989 m .26811 .55031 L .26952 .55346 L F
.525 0 0 r
.26959 .55194 m .26613 .5524 L .26888 .5512 L F
.508 .282 .506 r
.27049 .55079 m .26952 .55346 L .27038 .55153 L F
.27026 .55109 m .26952 .55346 L .27049 .55079 L F
.525 0 0 r
.27035 .55272 m .26904 .55262 L .26959 .55194 L F
.26904 .55262 m .26613 .5524 L .26959 .55194 L F
.508 .282 .506 r
.27064 .54989 m .27026 .55109 L .27049 .55079 L F
.211 .634 .952 r
.21841 .62947 m .22033 .62918 L .21703 .62779 L F
.21841 .62947 m .22301 .62998 L .22033 .62918 L F
.291 .782 .896 r
.23866 .53407 m .24094 .53369 L .2428 .53396 L F
.378 .808 .965 r
.24094 .53369 m .24501 .53377 L .2428 .53396 L F
.456 .21 .452 r
.37092 .52954 m .37067 .53196 L .36821 .53259 L F
.569 .807 .989 r
.37359 .52894 m .37092 .52954 L .36926 .52811 L F
.562 .299 .476 r
.37342 .53105 m .37092 .52954 L .37359 .52894 L F
.37342 .53105 m .37067 .53196 L .37092 .52954 L F
.411 .857 .785 r
.22934 .56098 m .22666 .56167 L .22513 .56251 L F
.409 .837 .956 r
.23108 .56146 m .22666 .56167 L .22934 .56098 L F
.464 .586 .89 r
.31859 .57235 m .32073 .57099 L .31836 .57164 L F
.31859 .57235 m .32131 .57288 L .32073 .57099 L F
.573 .403 .613 r
.31859 .57235 m .31929 .5752 L .32131 .57288 L F
.24 0 0 r
.52758 .52823 m .53174 .52601 L .52839 .52684 L F
0 0 .408 r
.50763 .56168 m .5091 .56553 L .5076 .56041 L F
.669 .696 .866 r
.35947 .53571 m .3548 .53415 L .35811 .53286 L F
.653 .68 .863 r
.36046 .53167 m .35947 .53571 L .35811 .53286 L F
.36046 .53167 m .36177 .53588 L .35947 .53571 L F
.235 .293 .72 r
.52198 .54756 m .52239 .55006 L .52113 .55136 L F
.251 0 0 r
.52251 .552 m .52113 .55136 L .52239 .55006 L F
.52251 .552 m .5196 .55269 L .52113 .55136 L F
.68 .184 .063 r
.52113 .55136 m .5196 .55269 L .5174 .55055 L F
.721 .813 .922 r
.23775 .73636 m .24169 .73653 L .23953 .73772 L F
.23775 .73636 m .24169 .73653 L .23953 .73772 L F
.804 .593 .616 r
.54257 .52948 m .54204 .53189 L .54592 .53243 L F
.743 .406 .412 r
.54216 .53412 m .54592 .53243 L .54204 .53189 L F
.54216 .53412 m .54434 .53506 L .54592 .53243 L F
.794 .472 .443 r
.54592 .53243 m .54434 .53506 L .54737 .53501 L F
.768 .746 .833 r
.2782 .67145 m .28276 .67177 L .28142 .66887 L F
.813 .744 .787 r
.27907 .67546 m .28276 .67177 L .2782 .67145 L F
.863 .831 .814 r
.28276 .67177 m .28353 .6671 L .28142 .66887 L F
.307 0 .152 r
.19529 .55145 m .19653 .55243 L .19742 .55064 L F
.19529 .55145 m .19436 .55305 L .19653 .55243 L F
.948 .846 .71 r
.31435 .6156 m .31586 .61352 L .31645 .61101 L F
.577 .868 .995 r
.25264 .62601 m .25056 .62659 L .24839 .6258 L F
.482 .345 .618 r
.3158 .6321 m .31822 .63199 L .31802 .6278 L F
.468 .374 .666 r
.3158 .6321 m .31835 .63374 L .31822 .63199 L F
.3158 .6321 m .3162 .63438 L .31835 .63374 L F
.788 .483 .472 r
.26913 .69689 m .27177 .69669 L .27141 .69903 L F
0 0 .199 r
.27141 .69903 m .27177 .69669 L .27308 .69524 L F
.099 0 .268 r
.30865 .6284 m .31089 .62514 L .31079 .62766 L F
.32 .037 .318 r
.30769 .63077 m .30865 .6284 L .31079 .62766 L F
.193 .573 .939 r
.2498 .63724 m .24993 .63595 L .2475 .63648 L F
.2498 .63724 m .2513 .63733 L .24993 .63595 L F
.57 .383 .589 r
.3384 .57288 m .34104 .5729 L .34108 .56949 L F
.531 .352 .583 r
.34108 .56949 m .34363 .57217 L .34304 .56935 L F
.34108 .56949 m .34104 .5729 L .34363 .57217 L F
.34108 .56949 m .34363 .57217 L .34304 .56935 L F
.34108 .56949 m .34104 .5729 L .34363 .57217 L F
.477 .212 .433 r
.27428 .62771 m .27548 .62863 L .27321 .62884 L F
.634 .596 .794 r
.27686 .62383 m .27548 .62863 L .27428 .62771 L F
.407 .549 .885 r
.29583 .54984 m .29711 .55101 L .29506 .55108 L F
0 .056 .61 r
.29466 .55378 m .29346 .54982 L .29506 .55108 L F
.657 .161 .058 r
.35247 .61496 m .35638 .61574 L .35365 .61411 L F
.982 .906 .595 r
.3533 .61251 m .35247 .61496 L .35365 .61411 L F
.865 .994 .811 r
.27064 .54989 m .27038 .55153 L .2722 .54926 L F
.439 .401 .719 r
.16509 .59111 m .16571 .59488 L .1678 .59296 L F
0 0 .294 r
.16571 .59488 m .16679 .59578 L .1678 .59296 L F
.16571 .59488 m .16528 .5975 L .16679 .59578 L F
.24 0 0 r
.52758 .52823 m .53068 .52756 L .53174 .52601 L F
.646 .197 .171 r
.53068 .52756 m .53394 .52642 L .53174 .52601 L F
.359 .439 .808 r
.33775 .53218 m .3369 .53521 L .33538 .53297 L F
.33775 .53218 m .33881 .53515 L .3369 .53521 L F
.268 .691 .967 r
.36142 .6119 m .35756 .61077 L .35933 .61027 L F
.195 .678 .929 r
.35756 .61077 m .35982 .61086 L .35872 .61061 L F
0 0 0 r
.35933 .61027 m .35756 .61077 L .35633 .61094 L F
.195 .678 .929 r
.35756 .61077 m .35872 .61061 L .35616 .61005 L F
0 0 0 r
.35633 .61094 m .35756 .61077 L .35571 .61108 L F
.541 .192 .325 r
.36208 .60978 m .36142 .6119 L .35933 .61027 L F
0 0 0 r
.27172 .61543 m .27327 .61308 L .27075 .61628 L F
.47 .827 .561 r
.27172 .61543 m .27075 .61628 L .26879 .61787 L F
.464 .607 .908 r
.18623 .60601 m .18894 .60959 L .19041 .60864 L F
.778 .58 .631 r
.33581 .54699 m .33916 .54798 L .3393 .54506 L F
.625 .449 .624 r
.3393 .54506 m .34171 .54722 L .34183 .54474 L F
.3393 .54506 m .33916 .54798 L .34171 .54722 L F
.962 .629 .311 r
.3376 .56473 m .33939 .56607 L .33723 .56223 L F
.149 .353 .81 r
.33723 .56223 m .33939 .56607 L .34016 .56435 L F
.784 .542 .57 r
.34016 .56435 m .33792 .5655 L .3376 .56473 L F
.792 .405 .321 r
.33752 .56533 m .33738 .56544 L .33795 .5655 L F
.082 .642 .764 r
.33749 .56529 m .33704 .56514 L .33429 .56529 L F
.33502 .56535 m .33429 .56529 L .33237 .5654 L F
.33749 .56529 m .33429 .56529 L .33502 .56535 L F
0 0 .229 r
.33277 .56279 m .33237 .5654 L .33347 .56391 L F
.082 .642 .764 r
.33704 .56514 m .33697 .56514 L .33237 .5654 L F
.33704 .56514 m .33703 .56513 L .33697 .56514 L F
.509 .586 .867 r
.33703 .56513 m .33341 .56837 L .33237 .5654 L F
0 0 0 r
.33237 .5654 m .33229 .56605 L .33347 .56391 L F
.568 .389 .599 r
.33229 .56605 m .33387 .56741 L .33347 .56391 L F
.977 .692 .302 r
.33347 .56391 m .33362 .56524 L .3325 .56327 L F
.33362 .56524 m .33387 .56741 L .33314 .56521 L F
.33362 .56524 m .33314 .56521 L .3325 .56327 L F
.483 .55 .848 r
.33816 .56599 m .33506 .56788 L .33694 .56526 L F
.33713 .56525 m .33694 .56526 L .337 .56517 L F
.33816 .56599 m .33694 .56526 L .33713 .56525 L F
.792 .405 .321 r
.33738 .56544 m .33605 .56646 L .33767 .56564 L F
.33738 .56544 m .33767 .56564 L .33795 .5655 L F
.483 .55 .848 r
.33816 .56599 m .337 .56517 L .33703 .56513 L F
.271 0 0 r
.33939 .56607 m .33714 .56518 L .33749 .56529 L F
.33714 .56518 m .3371 .56516 L .33749 .56529 L F
.33709 .56516 m .33704 .56514 L .33749 .56529 L F
.792 .405 .321 r
.33724 .56514 m .33605 .56646 L .33778 .56513 L F
.784 .542 .57 r
.33792 .5655 m .33605 .56646 L .33713 .56525 L F
.792 .405 .321 r
.33778 .56513 m .33752 .56533 L .33795 .5655 L F
.3376 .56473 m .33724 .56514 L .33778 .56513 L F
.483 .55 .848 r
.33816 .56599 m .33719 .56525 L .3376 .56473 L F
.784 .542 .57 r
.33722 .56521 m .33713 .56525 L .33718 .5652 L F
.33719 .56525 m .33713 .56525 L .33722 .56521 L F
.271 0 0 r
.33714 .56518 m .33709 .56516 L .3371 .56516 L F
.33709 .56516 m .33703 .56513 L .33704 .56514 L F
.483 .55 .848 r
.33719 .56525 m .33703 .56513 L .3376 .56473 L F
.784 .542 .57 r
.33732 .56525 m .33719 .56525 L .33722 .56521 L F
.33792 .5655 m .33713 .56525 L .33732 .56525 L F
.33792 .5655 m .33718 .5652 L .3376 .56473 L F
.792 .405 .321 r
.33795 .5655 m .33605 .56646 L .33816 .56599 L F
.128 0 .377 r
.30598 .57519 m .30388 .57887 L .3037 .57614 L F
.124 .282 .754 r
.20737 .60276 m .20681 .60461 L .20557 .60278 L F
.20737 .60276 m .20895 .60643 L .20681 .60461 L F
.172 .088 .512 r
.30449 .5944 m .30586 .59361 L .30572 .59279 L F
.622 .457 .638 r
.33918 .58093 m .3373 .58199 L .3398 .57891 L F
.523 .305 .525 r
.33734 .58432 m .33953 .58408 L .3373 .58199 L F
0 .151 .596 r
.27972 .67658 m .27629 .67449 L .27751 .67815 L F
.201 0 0 r
.27823 .68048 m .28036 .68032 L .27854 .68109 L F
0 .026 .562 r
.27751 .67815 m .27961 .6806 L .27972 .67658 L F
.27751 .67815 m .27823 .68048 L .27961 .6806 L F
.4 .188 .473 r
.33574 .56035 m .33723 .56223 L .33788 .55965 L F
.222 .212 .635 r
.16546 .57935 m .16748 .58049 L .16749 .57786 L F
.16546 .57935 m .166 .58181 L .16748 .58049 L F
.168 .694 .868 r
.28754 .52993 m .28708 .53044 L .28523 .53028 L F
.28754 .52993 m .28972 .53036 L .28708 .53044 L F
.528 .066 .098 r
.2517 .54761 m .24787 .5479 L .24946 .54722 L F
0 0 0 r
.25173 .53321 m .25326 .53285 L .2555 .53223 L F
.294 .792 .83 r
.25326 .53285 m .25781 .53213 L .2555 .53223 L F
.202 0 .272 r
.28471 .6067 m .28724 .60369 L .28665 .60605 L F
.245 .124 .51 r
.28631 .6085 m .28471 .6067 L .28665 .60605 L F
.28631 .6085 m .28486 .60981 L .28471 .6067 L F
.659 .603 .781 r
.32782 .54072 m .32919 .5449 L .33155 .54426 L F
.671 .448 .573 r
.35715 .5569 m .36017 .55711 L .36043 .55427 L F
.516 .313 .544 r
.36043 .55427 m .36254 .55617 L .36295 .55341 L F
.36043 .55427 m .36017 .55711 L .36254 .55617 L F
.803 .927 .551 r
.26938 .54847 m .26811 .55031 L .26981 .54729 L F
.651 .301 .365 r
.32442 .65637 m .32633 .6586 L .32404 .65821 L F
.621 .301 .407 r
.32903 .65608 m .32633 .6586 L .32442 .65637 L F
.682 .14 0 r
.31549 .60894 m .31366 .60709 L .31165 .6071 L F
.951 .621 .361 r
.33444 .62809 m .33451 .6306 L .33625 .63121 L F
.695 .154 0 r
.33576 .63198 m .33625 .63121 L .33451 .6306 L F
.33576 .63198 m .33797 .63302 L .33625 .63121 L F
.85 .787 .79 r
.36402 .53189 m .36177 .53588 L .36046 .53167 L F
.357 .513 .875 r
.21261 .61174 m .21212 .61413 L .21079 .61203 L F
.21261 .61174 m .21459 .61503 L .21212 .61413 L F
.368 0 0 r
.25331 .71354 m .2527 .71219 L .25499 .71422 L F
.25331 .71354 m .25644 .71223 L .2527 .71219 L F
0 0 0 r
.31591 .61399 m .31435 .6156 L .31645 .61101 L F
0 .062 .621 r
.31704 .61058 m .31645 .61101 L .31549 .60894 L F
0 0 0 r
.31704 .61058 m .31591 .61399 L .31645 .61101 L F
.44 .165 .398 r
.29112 .63756 m .29343 .63705 L .29405 .63478 L F
.487 .256 .489 r
.29343 .63705 m .29616 .63405 L .29405 .63478 L F
0 .156 .628 r
.32339 .65216 m .326 .65408 L .32623 .65447 L F
0 .42 .689 r
.326 .65408 m .32761 .65449 L .32623 .65447 L F
.237 .536 .922 r
.32761 .65449 m .32903 .65608 L .32623 .65447 L F
.523 .919 .861 r
.30196 .58286 m .30243 .58359 L .30463 .5817 L F
.121 0 0 r
.30487 .58234 m .30196 .58286 L .30463 .5817 L F
.647 .829 .97 r
.30273 .58126 m .30196 .58286 L .30487 .58234 L F
.769 .762 .25 r
.30273 .58126 m .3025 .58229 L .30196 .58286 L F
.523 .919 .861 r
.30196 .58286 m .30105 .58381 L .30243 .58359 L F
.769 .762 .25 r
.3025 .58229 m .30185 .58526 L .30196 .58286 L F
.523 .919 .861 r
.30196 .58286 m .30058 .58388 L .30105 .58381 L F
.715 .947 .65 r
.30159 .56651 m .30224 .56507 L .30396 .56607 L F
.30159 .56651 m .29965 .56807 L .30224 .56507 L F
.416 .829 .972 r
.29801 .53012 m .29714 .5311 L .29588 .53037 L F
.29801 .53012 m .29954 .53062 L .29714 .5311 L F
.58 .476 .7 r
.34337 .59467 m .34584 .59418 L .34507 .59081 L F
.128 0 .152 r
.34337 .59467 m .34445 .59556 L .34584 .59418 L F
.34337 .59467 m .34256 .59673 L .34445 .59556 L F
.514 .48 .756 r
.36995 .58772 m .36683 .58474 L .36898 .58388 L F
.51 .383 .644 r
.35509 .56027 m .35735 .55967 L .35715 .5569 L F
.208 .306 .745 r
.35509 .56027 m .35711 .56256 L .35735 .55967 L F
0 0 0 r
.24501 .53377 m .24723 .53365 L .24927 .53344 L F
.266 .774 .799 r
.24927 .53344 m .24955 .53305 L .25173 .53321 L F
.24927 .53344 m .24723 .53365 L .24955 .53305 L F
.71 .863 .45 r
.27399 .61168 m .27327 .61308 L .27172 .61543 L F
.739 .9 .516 r
.2611 .70882 m .2592 .71214 L .25972 .71066 L F
.582 .52 .751 r
.2611 .70882 m .26167 .71198 L .2592 .71214 L F
.45 .771 .997 r
.2592 .71214 m .26167 .71198 L .25972 .71066 L F
.367 .83 .907 r
.25781 .53213 m .26009 .53154 L .26175 .53167 L F
.401 .848 .917 r
.26175 .53167 m .26233 .53089 L .26413 .53136 L F
.26175 .53167 m .26009 .53154 L .26233 .53089 L F
.534 .152 .263 r
.35803 .61878 m .35582 .62234 L .35433 .61907 L F
.35803 .61878 m .35415 .6209 L .35582 .62234 L F
.204 0 .042 r
.3572 .62277 m .35582 .62234 L .35415 .6209 L F
.3572 .62277 m .35521 .6235 L .35582 .62234 L F
.561 .81 .992 r
.32031 .53189 m .32039 .5339 L .31843 .53228 L F
.32031 .53189 m .32258 .53326 L .32039 .5339 L F
.111 .463 .889 r
.2797 .64401 m .28367 .64683 L .28138 .64406 L F
.277 .549 .925 r
.28138 .64406 m .28367 .64683 L .28442 .64533 L F
.271 .541 .921 r
.28442 .64533 m .28367 .64683 L .28546 .6471 L F
.987 .766 .518 r
.37717 .56818 m .37846 .56923 L .37898 .5665 L F
.711 .97 .734 r
.38222 .56342 m .37977 .56496 L .37898 .5665 L F
.701 .924 .596 r
.37977 .56496 m .37717 .56818 L .37898 .5665 L F
0 0 0 r
.3832 .55916 m .38271 .56227 L .38222 .56342 L F
.061 0 0 r
.38213 .56436 m .37977 .56496 L .38222 .56342 L F
.546 .364 .586 r
.37183 .58152 m .36898 .58388 L .36934 .58218 L F
0 .394 .711 r
.27603 .64273 m .2797 .64401 L .27812 .64339 L F
.065 .595 .866 r
.27812 .64339 m .2797 .64401 L .28138 .64406 L F
0 0 .531 r
.3026 .55749 m .30308 .55823 L .30061 .55837 L F
.785 .598 .648 r
.30234 .55283 m .30226 .55574 L .29943 .55505 L F
0 0 .531 r
.3026 .55749 m .30226 .55574 L .30307 .55821 L F
.30308 .55822 m .30307 .55821 L .30308 .55823 L F
.3026 .55749 m .30307 .55821 L .30308 .55822 L F
.78 .619 .681 r
.29943 .55505 m .30061 .55837 L .30226 .55574 L F
.673 .564 .724 r
.29943 .55505 m .30308 .55823 L .30226 .55574 L F
.714 .251 .15 r
.30226 .55574 m .30331 .55727 L .29943 .55505 L F
.403 .525 .866 r
.29943 .55505 m .30272 .55694 L .30113 .55458 L F
.30272 .55694 m .30331 .55727 L .30256 .55634 L F
.30272 .55694 m .30256 .55634 L .30113 .55458 L F
.667 .913 .592 r
.2845 .66103 m .28636 .65931 L .28367 .66244 L F
.731 .306 .241 r
.28789 .66222 m .28636 .65931 L .2845 .66103 L F
.433 .725 .987 r
.22519 .75444 m .22728 .75588 L .22748 .75426 L F
.22748 .75426 m .22728 .75588 L .22519 .75444 L F
0 0 0 r
.32004 .55611 m .31953 .55633 L .32172 .55738 L F
.32004 .55611 m .31771 .55723 L .31953 .55633 L F
.528 .408 .659 r
.33234 .55881 m .33544 .56194 L .33412 .5593 L F
.33234 .55881 m .33277 .56279 L .33544 .56194 L F
.579 .191 .271 r
.33412 .5593 m .33 .56139 L .33234 .55881 L F
.683 .479 .605 r
.3338 .61263 m .33713 .61211 L .33714 .61012 L F
.429 .283 .58 r
.33714 .61012 m .33903 .60935 L .33899 .60646 L F
.683 .608 .766 r
.33713 .61211 m .33903 .60935 L .33714 .61012 L F
.921 .866 .768 r
.37769 .5577 m .37756 .56029 L .37598 .55923 L F
.482 .315 .578 r
.34054 .55878 m .33713 .55719 L .33817 .55645 L F
.34054 .55878 m .33788 .55965 L .33713 .55719 L F
.156 .672 .892 r
.24357 .6366 m .24352 .6361 L .24135 .63607 L F
.24357 .6366 m .24528 .6366 L .24352 .6361 L F
.592 .358 .53 r
.37466 .55055 m .37153 .55365 L .37183 .55095 L F
.342 .146 .464 r
.3145 .57898 m .31598 .58059 L .31673 .57854 L F
.3145 .57898 m .31335 .58164 L .31598 .58059 L F
.074 0 0 r
.23503 .55103 m .23445 .55062 L .23661 .55036 L F
.23503 .55103 m .23194 .55185 L .23445 .55062 L F
.431 0 0 r
.28184 .66682 m .28127 .66603 L .27971 .66467 L F
.28184 .66682 m .28353 .6671 L .28127 .66603 L F
.641 .494 .667 r
.28127 .66603 m .28368 .66544 L .28367 .66244 L F
.549 .254 .419 r
.28353 .6671 m .28368 .66544 L .28127 .66603 L F
.767 .679 .765 r
.53289 .54471 m .5281 .54432 L .53053 .54095 L F
.782 .477 .471 r
.53289 .54471 m .52866 .54617 L .5281 .54432 L F
.53289 .54471 m .53236 .54775 L .52866 .54617 L F
.85 .698 .693 r
.53441 .54416 m .53236 .54775 L .53289 .54471 L F
.139 .403 .851 r
.33431 .5851 m .33798 .58774 L .33734 .58432 L F
.419 .381 .71 r
.16509 .59111 m .1669 .59065 L .16638 .58723 L F
.439 .401 .719 r
.16509 .59111 m .1678 .59296 L .1669 .59065 L F
.483 .832 .997 r
.36596 .53806 m .36416 .53718 L .36192 .5378 L F
0 0 0 r
.36416 .53718 m .36376 .5373 L .36192 .5378 L F
.913 .757 .268 r
.35967 .54106 m .36005 .53831 L .36192 .5378 L F
.915 .979 .765 r
.35933 .53856 m .35967 .54106 L .36192 .5378 L F
0 0 0 r
.36376 .5373 m .35933 .53856 L .36192 .5378 L F
.913 .757 .268 r
.36005 .53831 m .36006 .53825 L .36192 .5378 L F
.671 .271 .279 r
.14361 .70277 m .14749 .70262 L .1427 .70237 L F
.335 .802 .928 r
.14614 .7023 m .14749 .70262 L .14361 .70277 L F
.14614 .7023 m .14749 .70262 L .14361 .70277 L F
.339 .804 .928 r
.14614 .7023 m .14974 .7022 L .14749 .70262 L F
.14614 .7023 m .14974 .7022 L .14749 .70262 L F
.645 .129 .001 r
.33078 .58984 m .32907 .58859 L .32813 .59059 L F
.24 .511 .907 r
.20893 .62215 m .21137 .62506 L .21191 .62355 L F
.205 .47 .886 r
.21137 .62506 m .21286 .62525 L .21191 .62355 L F
.811 .495 .455 r
.52431 .5386 m .52302 .54031 L .52046 .53811 L F
.52431 .5386 m .52454 .54105 L .52302 .54031 L F
.394 .156 .431 r
.32373 .58176 m .32274 .58653 L .3214 .58489 L F
.39 .161 .442 r
.32663 .57834 m .32607 .58128 L .32373 .58176 L F
.488 .24 .464 r
.32604 .58384 m .32373 .58176 L .32607 .58128 L F
.32604 .58384 m .32274 .58653 L .32373 .58176 L F
0 0 .008 r
.29179 .58439 m .29417 .58125 L .2924 .58229 L F
.555 .438 .674 r
.33853 .60373 m .34134 .60595 L .34004 .60248 L F
.33853 .60373 m .33899 .60646 L .34134 .60595 L F
.315 .448 .836 r
.19629 .59579 m .19546 .59765 L .19348 .59388 L F
.535 .711 .952 r
.19629 .59579 m .19764 .59715 L .19546 .59765 L F
.772 .692 .775 r
.34196 .56288 m .3434 .56645 L .33939 .56607 L F
.12 0 0 r
.3434 .56645 m .34214 .56639 L .33939 .56607 L F
.14 .311 .775 r
.34446 .56503 m .3434 .56645 L .34196 .56288 L F
.32 .018 .287 r
.34446 .56503 m .34214 .56639 L .3434 .56645 L F
.742 .867 .443 r
.50544 .54117 m .50488 .54118 L .50817 .54055 L F
.50544 .54117 m .50423 .54287 L .50488 .54118 L F
.516 .302 .527 r
.50791 .54343 m .50544 .54117 L .50817 .54055 L F
.50791 .54343 m .5054 .5442 L .50544 .54117 L F
.483 .224 .445 r
.37452 .57588 m .37401 .57807 L .37164 .57853 L F
.582 .361 .547 r
.37702 .57504 m .37401 .57807 L .37452 .57588 L F
.194 0 .326 r
.28665 .60605 m .28724 .60369 L .28891 .60277 L F
0 .033 .575 r
.28367 .66244 m .28476 .66569 L .2845 .66103 L F
.257 .613 .956 r
.28368 .66544 m .28476 .66569 L .28367 .66244 L F
.628 .578 .779 r
.28217 .5498 m .28368 .54742 L .28127 .54787 L F
.508 .171 .332 r
.29689 .62434 m .2994 .62417 L .30005 .62142 L F
.359 .178 .494 r
.30005 .62142 m .3023 .62138 L .30266 .61864 L F
.502 .238 .447 r
.2994 .62417 m .3023 .62138 L .30005 .62142 L F
.509 .256 .466 r
.19843 .57198 m .19623 .57241 L .19897 .56956 L F
.293 .064 .385 r
.20057 .57108 m .19897 .56956 L .20127 .56919 L F
.20057 .57108 m .19843 .57198 L .19897 .56956 L F
.447 .842 .98 r
.29205 .66755 m .29395 .66808 L .29154 .66856 L F
.193 0 0 r
.29154 .66856 m .29217 .66975 L .28896 .67059 L F
.29154 .66856 m .29395 .66808 L .29217 .66975 L F
.608 .518 .727 r
.3399 .55111 m .34171 .54722 L .33916 .54798 L F
.3399 .55111 m .34275 .55106 L .34171 .54722 L F
.01 0 0 r
.19238 .55408 m .1926 .55505 L .19436 .55305 L F
.19238 .55408 m .19055 .55583 L .1926 .55505 L F
.584 .465 .684 r
.27675 .55883 m .27853 .55933 L .27651 .55798 L F
.296 .778 .696 r
.31959 .54274 m .31897 .54309 L .32137 .54154 L F
.31959 .54274 m .31753 .54358 L .31897 .54309 L F
.578 .557 .795 r
.23562 .75211 m .23814 .7518 L .23735 .74979 L F
.23648 .7496 m .23735 .74979 L .23685 .74853 L F
.23562 .75211 m .23735 .74979 L .23648 .7496 L F
.2365 .74954 m .23814 .7518 L .23562 .75211 L F
.23685 .74853 m .23726 .74957 L .2365 .74954 L F
.23726 .74957 m .23814 .7518 L .2365 .74954 L F
.23562 .75211 m .23635 .74997 L .23606 .75132 L F
.489 .056 .143 r
.23169 .75355 m .23601 .75153 L .23464 .75369 L F
.448 .084 .253 r
.23562 .75211 m .23814 .7518 L .23756 .7527 L F
.064 .464 .885 r
.23633 .75145 m .23562 .75211 L .23756 .7527 L F
.411 .234 .527 r
.23562 .75211 m .23553 .75534 L .23756 .7527 L F
0 0 0 r
.23464 .75369 m .2364 .75143 L .23644 .7525 L F
.747 .647 .749 r
.23685 .74853 m .24053 .74864 L .23814 .7518 L F
.779 .897 .491 r
.23756 .7527 m .23841 .75044 L .23739 .75079 L F
0 0 0 r
.23645 .75137 m .23651 .7513 L .2365 .75134 L F
.779 .897 .491 r
.23633 .75145 m .23645 .75137 L .23628 .75139 L F
.489 .056 .143 r
.2363 .7514 m .23632 .75139 L .2364 .75143 L F
.23632 .75139 m .23651 .7513 L .23645 .75137 L F
.23632 .75139 m .23645 .75137 L .2364 .75143 L F
.779 .897 .491 r
.23628 .75139 m .23739 .75079 L .23611 .75122 L F
.23645 .75137 m .23739 .75079 L .23628 .75139 L F
.23756 .7527 m .23739 .75079 L .23633 .75145 L F
0 0 0 r
.2364 .75143 m .23645 .75137 L .2365 .75141 L F
.23645 .75137 m .2365 .75134 L .2365 .75141 L F
.2364 .75143 m .2365 .75141 L .23644 .7525 L F
.064 .464 .885 r
.23628 .75139 m .2362 .75147 L .23633 .75145 L F
.2362 .75147 m .23562 .75211 L .23633 .75145 L F
.23611 .75122 m .23606 .75132 L .23628 .75139 L F
.23606 .75132 m .23562 .75211 L .23628 .75139 L F
.489 .056 .143 r
.23601 .75153 m .2363 .7514 L .2359 .75208 L F
.2363 .7514 m .2364 .75143 L .2359 .75208 L F
.23601 .75153 m .2359 .75208 L .23464 .75369 L F
.578 .557 .795 r
.23606 .75132 m .2365 .74954 L .23611 .75122 L F
.23635 .74997 m .2365 .74954 L .23606 .75132 L F
.2365 .74954 m .23685 .74853 L .23611 .75122 L F
.509 .103 .205 r
.23169 .75355 m .23617 .74953 L .23611 .75122 L F
.23617 .74953 m .23617 .74953 L .23617 .74953 L F
.23617 .74953 m .23617 .74953 L .23611 .75122 L F
.654 .287 .336 r
.22989 .75105 m .23617 .74953 L .23169 .75355 L F
.603 .178 .21 r
.23611 .75122 m .23617 .74953 L .23262 .75102 L F
.23617 .74953 m .23617 .74953 L .23616 .74953 L F
.23617 .74953 m .23616 .74953 L .23262 .75102 L F
.583 .619 .854 r
.33993 .62186 m .34242 .62338 L .34093 .62191 L F
0 .486 .864 r
.34625 .62422 m .34093 .62191 L .34242 .62338 L F
.592 .376 .557 r
.33795 .64935 m .34081 .64635 L .3385 .64729 L F
.33795 .64935 m .34081 .64635 L .3385 .64729 L F
.195 .401 .837 r
.3791 .53394 m .38095 .53724 L .37832 .53597 L F
.582 .587 .823 r
.38226 .53856 m .37832 .53597 L .38095 .53724 L F
.695 .541 .674 r
.31731 .59412 m .31413 .59579 L .31395 .59455 L F
.742 .665 .775 r
.27629 .67449 m .27907 .67546 L .2782 .67145 L F
.115 0 .135 r
.28891 .60277 m .28987 .60081 L .29166 .59982 L F
.628 .578 .779 r
.28217 .5498 m .28483 .55082 L .28368 .54742 L F
.832 .822 .839 r
.36402 .53189 m .36251 .52879 L .36478 .52998 L F
.36402 .53189 m .36046 .53167 L .36251 .52879 L F
0 0 0 r
.27472 .54835 m .27064 .54989 L .2722 .54926 L F
.701 .351 .381 r
.23807 .557 m .23991 .55981 L .24111 .55729 L F
.782 .897 .924 r
.22301 .62998 m .22572 .63075 L .22407 .62936 L F
.27 .687 .968 r
.22572 .63075 m .22552 .62955 L .22407 .62936 L F
.22572 .63075 m .22735 .63063 L .22552 .62955 L F
.54 .411 .654 r
.54116 .55527 m .54381 .55653 L .54306 .55385 L F
.965 .872 .696 r
.54925 .54072 m .54755 .54408 L .54906 .54494 L F
.943 .82 .693 r
.54755 .54408 m .54857 .54752 L .54906 .54494 L F
.955 .611 .29 r
.29981 .5603 m .29726 .5555 L .29928 .55715 L F
.663 .707 .881 r
.34183 .54474 m .3426 .54076 L .34053 .5421 L F
.34183 .54474 m .34439 .54468 L .3426 .54076 L F
.671 .46 .591 r
.34171 .54722 m .34439 .54468 L .34183 .54474 L F
.642 .288 .357 r
.31809 .65592 m .31625 .6585 L .31408 .65631 L F
.688 .344 .388 r
.32022 .65836 m .31625 .6585 L .31809 .65592 L F
.414 .694 .978 r
.3925 .54883 m .39156 .55055 L .39012 .54709 L F
.3925 .54883 m .39315 .55 L .39156 .55055 L F
0 0 .101 r
.52359 .53222 m .52462 .53175 L .52534 .52909 L F
.4 .075 .296 r
.52534 .52909 m .52714 .53101 L .52758 .52823 L F
.52534 .52909 m .52462 .53175 L .52714 .53101 L F
.401 .087 .315 r
.3162 .63438 m .31289 .63716 L .31558 .63682 L F
.332 .045 .318 r
.31835 .63374 m .3162 .63438 L .31558 .63682 L F
.272 .35 .761 r
.50078 .56305 m .50173 .55998 L .49925 .5606 L F
.50078 .56305 m .50177 .56269 L .50173 .55998 L F
.097 0 .283 r
.3409 .5975 m .34182 .59905 L .34256 .59673 L F
.3409 .5975 m .34032 .59991 L .34182 .59905 L F
.34 0 .182 r
.22768 .55764 m .23063 .55845 L .23173 .55702 L F
.765 .253 0 r
.23212 .55886 m .23173 .55702 L .23063 .55845 L F
.646 .197 .171 r
.53068 .52756 m .53253 .52795 L .53394 .52642 L F
.718 .288 .225 r
.53394 .52642 m .53253 .52795 L .53537 .5283 L F
.373 .633 .956 r
.31804 .59246 m .31731 .59412 L .31624 .59296 L F
0 0 .476 r
.31861 .59431 m .31731 .59412 L .31804 .59246 L F
.31861 .59431 m .3178 .59661 L .31731 .59412 L F
.525 .361 .601 r
.36459 .60595 m .36439 .60974 L .36208 .60978 L F
.58 .229 .339 r
.36447 .6112 m .36208 .60978 L .36439 .60974 L F
.36447 .6112 m .36142 .6119 L .36208 .60978 L F
.458 .539 .852 r
.31472 .56882 m .31836 .57164 L .31747 .56845 L F
.66 .803 .951 r
.34546 .53511 m .3431 .53641 L .34128 .53445 L F
0 .547 .818 r
.33993 .62186 m .34093 .62191 L .33736 .62111 L F
.901 .745 .678 r
.30613 .64336 m .30826 .6412 L .30769 .64069 L F
.479 .847 .99 r
.32721 .53248 m .3261 .53388 L .3251 .53292 L F
.32721 .53248 m .32804 .53294 L .3261 .53388 L F
.094 .006 .455 r
.2793 .54398 m .27808 .54664 L .27826 .54457 L F
.603 .42 .608 r
.27675 .55883 m .27716 .56268 L .27853 .55933 L F
.015 .517 .869 r
.24714 .62499 m .24647 .62542 L .24461 .6246 L F
.24714 .62499 m .24839 .6258 L .24647 .62542 L F
0 0 0 r
.29112 .63756 m .28672 .63983 L .29051 .63967 L F
.42 .12 .347 r
.29275 .63923 m .29112 .63756 L .29051 .63967 L F
.29275 .63923 m .29343 .63705 L .29112 .63756 L F
.55 .409 .642 r
.37751 .54763 m .37466 .55055 L .37465 .54788 L F
0 0 0 r
.22623 .5377 m .22828 .53702 L .23019 .53579 L F
.23019 .53579 m .23041 .53631 L .23242 .53516 L F
.17 0 0 r
.23041 .53631 m .23277 .53584 L .23468 .53438 L F
.279 .775 .886 r
.22891 .53609 m .23182 .5359 L .23041 .53631 L F
.23182 .5359 m .23277 .53584 L .23041 .53631 L F
0 0 0 r
.23019 .53579 m .22853 .53686 L .23041 .53631 L F
.22853 .53686 m .22828 .53702 L .23041 .53631 L F
.388 .353 .698 r
.32777 .57474 m .32663 .57834 L .32607 .57389 L F
.32777 .57474 m .32889 .57736 L .32663 .57834 L F
.434 .264 .55 r
.32889 .57736 m .32607 .58128 L .32663 .57834 L F
.328 .682 .979 r
.2574 .63882 m .25942 .6402 L .26006 .63896 L F
.183 .505 .91 r
.26006 .63896 m .25942 .6402 L .26127 .64071 L F
0 .378 .751 r
.25942 .6402 m .2617 .64122 L .26127 .64071 L F
.898 .76 .701 r
.32761 .65449 m .32633 .6586 L .32903 .65608 L F
.955 .611 .29 r
.29981 .5603 m .29826 .55939 L .29726 .5555 L F
.884 .695 .642 r
.30061 .55837 m .29826 .55939 L .29981 .5603 L F
.841 .632 .62 r
.54029 .52866 m .54204 .53189 L .54257 .52948 L F
.528 .148 .265 r
.35584 .56801 m .35832 .56813 L .35919 .56605 L F
.444 .509 .831 r
.35772 .56324 m .35919 .56605 L .36109 .56383 L F
.319 .121 .447 r
.35832 .56813 m .36109 .56383 L .35919 .56605 L F
.364 .823 .924 r
.23468 .53438 m .23866 .53407 L .2363 .53468 L F
.809 .64 .673 r
.53346 .54774 m .53177 .54994 L .53236 .54775 L F
.53601 .5477 m .53309 .54924 L .53346 .54774 L F
.53309 .54924 m .53177 .54994 L .53346 .54774 L F
.53601 .5477 m .53236 .54775 L .53321 .54868 L F
.85 .698 .693 r
.53441 .54416 m .53321 .54868 L .53236 .54775 L F
.792 .788 .289 r
.5337 .54585 m .53321 .54868 L .53348 .54765 L F
.53423 .54459 m .53348 .54765 L .53441 .54416 L F
.5337 .54585 m .53348 .54765 L .53423 .54459 L F
.809 .64 .673 r
.53601 .5477 m .53523 .55051 L .53177 .54994 L F
.768 .673 .758 r
.53441 .54416 m .53601 .5477 L .5386 .54446 L F
.343 .587 .935 r
.53321 .54868 m .53523 .55051 L .53601 .5477 L F
.592 .62 .849 r
.19332 .5883 m .18876 .58462 L .19135 .58397 L F
.554 .584 .838 r
.19581 .58752 m .19332 .5883 L .19135 .58397 L F
.336 .077 .364 r
.19581 .58752 m .19294 .59007 L .19332 .5883 L F
.565 .735 .955 r
.33951 .58613 m .34099 .58786 L .33839 .58808 L F
.596 .427 .623 r
.34099 .58786 m .33865 .59079 L .33839 .58808 L F
.818 .395 .238 r
.33367 .5543 m .33786 .55611 L .33368 .55496 L F
.913 .98 .721 r
.54311 .56146 m .54295 .56379 L .54501 .56266 L F
.128 0 .377 r
.30598 .57519 m .3057 .57791 L .30388 .57887 L F
0 0 0 r
.3057 .57791 m .30463 .5817 L .30388 .57887 L F
.359 .171 .485 r
.29689 .62434 m .29487 .62516 L .29468 .62766 L F
.441 .08 .256 r
.21673 .56325 m .21597 .56502 L .21355 .56542 L F
.573 .21 .316 r
.21673 .56325 m .21837 .56541 L .21597 .56502 L F
.296 .154 .512 r
.21879 .562 m .21837 .56541 L .21673 .56325 L F
.21879 .562 m .21837 .56541 L .21673 .56325 L F
.353 .581 .928 r
.19041 .60864 m .19129 .61016 L .19206 .60855 L F
.286 .498 .888 r
.19129 .61016 m .19462 .61201 L .19206 .60855 L F
.532 .373 .611 r
.37419 .58084 m .37164 .57853 L .37401 .57807 L F
.37419 .58084 m .37183 .58152 L .37164 .57853 L F
.116 0 .299 r
.29471 .57885 m .29417 .58125 L .29621 .57787 L F
0 0 0 r
.35246 .54829 m .35099 .54973 L .34932 .55066 L F
.68 .671 .835 r
.32933 .5926 m .33078 .58984 L .32813 .59059 L F
.32933 .5926 m .33248 .59209 L .33078 .58984 L F
.748 .73 .835 r
.53692 .54135 m .53441 .54416 L .5386 .54446 L F
.364 .372 .735 r
.5386 .54446 m .53959 .54023 L .53692 .54135 L F
.5386 .54446 m .54032 .54409 L .53959 .54023 L F
.956 .785 .337 r
.54025 .54678 m .54032 .54409 L .5386 .54446 L F
.19 0 .337 r
.29334 .59879 m .29225 .59739 L .29356 .59649 L F
.29334 .59879 m .29166 .59982 L .29225 .59739 L F
.603 .634 .854 r
.17604 .60051 m .18054 .60332 L .17796 .60063 L F
.009 .465 .87 r
.18213 .60294 m .17796 .60063 L .18054 .60332 L F
.515 0 0 r
.29657 .65185 m .29642 .65349 L .29548 .65134 L F
0 0 .454 r
.29607 .65189 m .29548 .65134 L .29642 .65349 L F
.483 0 0 r
.29425 .65019 m .29657 .65185 L .29548 .65134 L F
0 0 .454 r
.29557 .64958 m .29548 .65134 L .29607 .65189 L F
.483 0 0 r
.29382 .64989 m .29425 .65019 L .29548 .65134 L F
.476 .334 .609 r
.3313 .63613 m .32825 .63379 L .33151 .63389 L F
.3313 .63613 m .32889 .63707 L .32825 .63379 L F
.141 .505 .91 r
.38234 .53702 m .38226 .53856 L .38095 .53724 L F
.38234 .53702 m .38305 .5382 L .38226 .53856 L F
.256 .176 .569 r
.16597 .58442 m .16748 .58049 L .166 .58181 L F
.532 .29 .493 r
.32637 .62204 m .32856 .62413 L .32628 .62507 L F
.251 0 0 r
.25341 .55716 m .25027 .55837 L .25106 .55782 L F
0 0 0 r
.19594 .57486 m .19316 .57784 L .19367 .57558 L F
.671 .46 .591 r
.34171 .54722 m .34538 .54724 L .34439 .54468 L F
.558 .65 .896 r
.3426 .54076 m .34439 .54468 L .34695 .5435 L F
.54 .392 .629 r
.34439 .54468 m .34663 .54433 L .34695 .5435 L F
.34439 .54468 m .34538 .54724 L .34663 .54433 L F
.239 .33 .756 r
.30834 .63634 m .30708 .63791 L .3059 .63438 L F
.399 .313 .642 r
.30919 .63937 m .30708 .63791 L .30834 .63634 L F
.30919 .63937 m .30769 .64069 L .30708 .63791 L F
.783 .555 .592 r
.37667 .55476 m .37213 .55623 L .37153 .55365 L F
.47 .302 .57 r
.37891 .55637 m .37665 .55847 L .37667 .55476 L F
.402 .025 .205 r
.3214 .58489 m .32002 .58776 L .3177 .58771 L F
.577 .211 .31 r
.32274 .58653 m .32002 .58776 L .3214 .58489 L F
.173 .437 .869 r
.21606 .62763 m .21634 .62635 L .21286 .62525 L F
.21606 .62763 m .21703 .62779 L .21634 .62635 L F
.264 0 .206 r
.27456 .60939 m .2766 .60912 L .27773 .60641 L F
.255 0 .202 r
.27773 .60641 m .27882 .60825 L .27948 .60572 L F
.27773 .60641 m .27661 .6091 L .27882 .60825 L F
.279 0 .243 r
.27948 .60572 m .27882 .60825 L .281 .60742 L F
.549 .847 .998 r
.28099 .60742 m .27882 .60825 L .27675 .60718 L F
.28099 .60742 m .27675 .60718 L .27699 .60711 L F
0 0 .087 r
.27456 .60939 m .27503 .61036 L .2766 .60912 L F
.27456 .60939 m .27399 .61168 L .27503 .61036 L F
.802 .944 .918 r
.27882 .60825 m .27397 .6099 L .27653 .60707 L F
.255 0 .202 r
.27661 .6091 m .2766 .60912 L .27882 .60825 L F
0 0 0 r
.2766 .60912 m .27503 .61036 L .27882 .60825 L F
.802 .944 .918 r
.27882 .60825 m .27503 .61036 L .27397 .6099 L F
.937 .918 .542 r
.27503 .61036 m .2737 .61214 L .27397 .6099 L F
.549 .847 .998 r
.281 .60742 m .2771 .60712 L .27902 .60619 L F
.71 .863 .45 r
.27399 .61168 m .27172 .61543 L .27396 .61427 L F
0 0 .121 r
.27399 .61168 m .27396 .61427 L .27503 .61036 L F
.937 .918 .542 r
.27503 .61036 m .27396 .61427 L .2737 .61214 L F
.451 .231 .487 r
.27742 .60687 m .2737 .61214 L .27546 .61158 L F
.2775 .60668 m .27731 .60695 L .27742 .60687 L F
.27731 .60695 m .2737 .61214 L .27742 .60687 L F
.549 .847 .998 r
.2771 .60712 m .27699 .60711 L .27728 .60698 L F
.2771 .60712 m .27722 .60702 L .27902 .60619 L F
.27722 .60702 m .2773 .60697 L .27902 .60619 L F
.345 .058 .326 r
.27769 .6067 m .27778 .61094 L .27874 .6068 L F
.2775 .60668 m .27751 .60682 L .27769 .6067 L F
.27751 .60682 m .27778 .61094 L .27769 .6067 L F
.549 .847 .998 r
.27722 .60702 m .27728 .60698 L .2773 .60697 L F
.451 .231 .487 r
.2775 .60668 m .27707 .60707 L .27731 .60695 L F
.549 .847 .998 r
.27699 .60711 m .27653 .60707 L .27852 .60637 L F
.197 0 0 r
.2775 .60668 m .27769 .6067 L .27902 .60619 L F
.549 .847 .998 r
.27699 .60711 m .2784 .60643 L .27902 .60619 L F
.197 0 0 r
.27769 .6067 m .27874 .6068 L .27902 .60619 L F
.549 .847 .998 r
.2784 .60643 m .27852 .60637 L .27902 .60619 L F
.451 .231 .487 r
.27731 .60695 m .27705 .60709 L .27726 .60702 L F
.27707 .60707 m .27705 .60709 L .27731 .60695 L F
.27726 .60702 m .27397 .6099 L .2737 .61214 L F
.27705 .60709 m .27397 .6099 L .27726 .60702 L F
.549 .847 .998 r
.27699 .60711 m .27675 .60718 L .27653 .60707 L F
.281 .60742 m .27882 .60825 L .28099 .60742 L F
.419 .409 .742 r
.36828 .59597 m .36627 .60025 L .3659 .59764 L F
.032 0 .163 r
.31929 .5752 m .31673 .57854 L .31833 .57727 L F
.356 .098 .378 r
.31598 .58059 m .31833 .57727 L .31673 .57854 L F
.064 0 0 r
.221 .53776 m .21993 .53816 L .22327 .53747 L F
0 0 .097 r
.31297 .61851 m .31435 .6156 L .31446 .61817 L F
.391 .268 .592 r
.31522 .62059 m .31297 .61851 L .31446 .61817 L F
.31522 .62059 m .31318 .62118 L .31297 .61851 L F
0 0 .211 r
.22638 .55906 m .22507 .56119 L .22569 .55691 L F
.22638 .55906 m .22569 .55691 L .22337 .55629 L F
.921 .667 .537 r
.22462 .55441 m .22337 .55629 L .22569 .55691 L F
.45 .176 .404 r
.33341 .56837 m .33322 .57158 L .33066 .57221 L F
.509 .586 .867 r
.33703 .56513 m .33506 .56788 L .33341 .56837 L F
.292 .053 .37 r
.33513 .57057 m .33341 .56837 L .33506 .56788 L F
.33513 .57057 m .33322 .57158 L .33341 .56837 L F
.372 .385 .744 r
.54215 .54847 m .5428 .55107 L .54541 .54865 L F
.029 0 .413 r
.54306 .55385 m .54541 .54865 L .5428 .55107 L F
.194 .394 .831 r
.32172 .55738 m .32424 .55814 L .32225 .55508 L F
.476 .145 .326 r
.27808 .54664 m .27722 .54798 L .27472 .54835 L F
.094 .006 .455 r
.2793 .54398 m .27932 .54666 L .27808 .54664 L F
.084 0 .069 r
.27932 .54666 m .27722 .54798 L .27808 .54664 L F
.374 .373 .731 r
.49576 .55637 m .49652 .56076 L .4979 .55806 L F
.516 .545 .824 r
.49652 .56076 m .49925 .5606 L .4979 .55806 L F
.517 .388 .644 r
.31318 .62118 m .31319 .62455 L .31089 .62514 L F
.464 .286 .555 r
.313 .62709 m .31089 .62514 L .31319 .62455 L F
.313 .62709 m .31079 .62766 L .31089 .62514 L F
0 0 0 r
.23749 .55038 m .23661 .55036 L .2389 .55048 L F
.23749 .55038 m .23503 .55103 L .23661 .55036 L F
.974 .883 .678 r
.51295 .55266 m .5145 .5522 L .5141 .55438 L F
.998 .789 .445 r
.5141 .55438 m .51292 .55499 L .51295 .55266 L F
.352 .273 .627 r
.5145 .5522 m .51607 .55197 L .5141 .55438 L F
.702 .482 .586 r
.51607 .55197 m .51292 .55499 L .5141 .55438 L F
.659 .603 .781 r
.32782 .54072 m .33155 .54426 L .32976 .54122 L F
.627 .758 .94 r
.33155 .54426 m .33226 .54159 L .32976 .54122 L F
.33155 .54426 m .33541 .54395 L .33226 .54159 L F
.142 .6 .927 r
.22281 .61722 m .22256 .61802 L .22077 .61701 L F
.22281 .61722 m .22455 .61832 L .22256 .61802 L F
.299 0 0 r
.30957 .55806 m .30912 .55723 L .31028 .55596 L F
.385 .741 .992 r
.49506 .55344 m .49788 .55381 L .49639 .55238 L F
.407 .457 .8 r
.49576 .55637 m .49639 .55238 L .49506 .55344 L F
0 0 0 r
.23807 .557 m .23832 .55806 L .23991 .55981 L F
.652 .452 .6 r
.38847 .5536 m .38555 .55668 L .38674 .55356 L F
.935 .81 .698 r
.26913 .69689 m .26917 .69977 L .26737 .69854 L F
.788 .483 .472 r
.26913 .69689 m .27141 .69903 L .26917 .69977 L F
.581 .815 .988 r
.26737 .69854 m .26917 .69977 L .27141 .69903 L F
.652 .401 .526 r
.31093 .58434 m .31394 .5846 L .31335 .58164 L F
.576 .449 .67 r
.31394 .5846 m .31598 .58059 L .31335 .58164 L F
.94 .641 .445 r
.33896 .64032 m .33617 .63904 L .33907 .64057 L F
.69 .239 .175 r
.17249 .60006 m .16778 .59984 L .17065 .60138 L F
.331 .815 .813 r
.51732 .56604 m .51354 .56691 L .5137 .56763 L F
.51732 .56604 m .51602 .56612 L .51354 .56691 L F
.44 .581 .898 r
.51554 .56266 m .51952 .56554 L .51732 .56604 L F
.813 .815 .852 r
.51952 .56554 m .51602 .56612 L .51732 .56604 L F
.647 .592 .779 r
.37342 .53105 m .37212 .5352 L .37067 .53196 L F
.37342 .53105 m .37456 .53526 L .37212 .5352 L F
.413 .347 .674 r
.33152 .62362 m .32989 .62589 L .32856 .62413 L F
.33152 .62362 m .33236 .62673 L .32989 .62589 L F
.196 .483 .897 r
.38305 .5382 m .38657 .54001 L .38605 .54161 L F
0 .246 .754 r
.38657 .54001 m .38834 .54355 L .38605 .54161 L F
0 0 0 r
.27472 .54835 m .27283 .54934 L .27064 .54989 L F
0 0 .331 r
.34589 .6255 m .34617 .62581 L .34625 .62422 L F
.34589 .6255 m .34664 .62742 L .34617 .62581 L F
.456 .325 .613 r
.31802 .6278 m .32048 .63015 L .32034 .62725 L F
.31802 .6278 m .31822 .63199 L .32048 .63015 L F
.53 .252 .438 r
.2044 .56637 m .20377 .56901 L .20127 .56919 L F
.456 .184 .412 r
.20609 .56839 m .2044 .56637 L .20761 .56547 L F
.20609 .56839 m .20377 .56901 L .2044 .56637 L F
.696 .416 .495 r
.22332 .56006 m .21879 .562 L .21915 .5605 L F
.286 .745 .952 r
.23911 .5477 m .23948 .54693 L .24167 .54763 L F
.23911 .5477 m .23948 .54693 L .24167 .54763 L F
.457 .75 .992 r
.29972 .5446 m .30239 .54434 L .30062 .54323 L F
.579 .584 .821 r
.30062 .54323 m .29968 .54715 L .29972 .5446 L F
.724 .206 0 r
.28411 .66681 m .28368 .66544 L .28353 .6671 L F
.533 .364 .598 r
.33899 .60646 m .33903 .60935 L .34142 .60872 L F
.574 .545 .785 r
.33903 .60935 m .34255 .61203 L .34142 .60872 L F
.573 .386 .59 r
.34142 .60872 m .34356 .60567 L .34134 .60595 L F
.587 .546 .776 r
.34142 .60872 m .34255 .61203 L .34507 .61149 L F
.573 .386 .59 r
.34142 .60872 m .34316 .60825 L .34356 .60567 L F
.587 .546 .776 r
.34142 .60872 m .34507 .61149 L .34316 .60825 L F
0 0 .355 r
.34219 .6068 m .3423 .61001 L .3407 .61026 L F
.34071 .61003 m .3407 .61026 L .34059 .61028 L F
.533 .364 .598 r
.34074 .60608 m .34142 .60872 L .34134 .60595 L F
.34072 .60807 m .34142 .60872 L .34074 .60608 L F
0 0 .355 r
.34219 .6068 m .3407 .61026 L .34071 .61003 L F
.533 .364 .598 r
.33899 .60646 m .34072 .60807 L .34074 .60608 L F
.671 .321 .373 r
.33279 .62222 m .33152 .62362 L .32856 .62413 L F
.637 .277 .345 r
.33279 .62222 m .33483 .62414 L .33152 .62362 L F
.497 .298 .541 r
.33517 .62147 m .33483 .62414 L .33279 .62222 L F
.561 .349 .55 r
.3089 .64665 m .31141 .64629 L .31163 .64356 L F
.611 .434 .618 r
.31141 .64629 m .31405 .64301 L .31163 .64356 L F
.577 .868 .995 r
.25264 .62601 m .24839 .6258 L .25112 .62464 L F
.541 .708 .948 r
.25348 .62362 m .25264 .62601 L .25112 .62464 L F
.25348 .62362 m .25514 .62576 L .25264 .62601 L F
.604 .279 .393 r
.32809 .57315 m .32607 .57389 L .32419 .5723 L F
.32809 .57315 m .32777 .57474 L .32607 .57389 L F
.373 .077 .327 r
.33066 .57221 m .32777 .57474 L .32809 .57315 L F
0 0 .367 r
.33483 .62414 m .33444 .62809 L .33236 .62673 L F
.33483 .62414 m .33511 .62699 L .33444 .62809 L F
0 0 .208 r
.33512 .6293 m .33444 .62809 L .33511 .62699 L F
.33512 .6293 m .33451 .6306 L .33444 .62809 L F
.236 0 .272 r
.32112 .61268 m .31831 .61583 L .32096 .61533 L F
.472 .303 .569 r
.31831 .61583 m .32074 .61784 L .32096 .61533 L F
.31831 .61583 m .31832 .61869 L .32074 .61784 L F
.603 .606 .828 r
.30092 .55369 m .29862 .55421 L .29711 .55101 L F
.119 0 0 r
.30092 .55369 m .29725 .55552 L .29862 .55421 L F
.30092 .55369 m .29725 .55552 L .29862 .55421 L F
.067 .611 .843 r
.24175 .5603 m .23991 .55981 L .23779 .55965 L F
.171 0 0 r
.24404 .56023 m .23991 .55981 L .24175 .5603 L F
.501 .388 .657 r
.36664 .60287 m .36683 .6059 L .36459 .60595 L F
.4 .257 .569 r
.36692 .60848 m .36459 .60595 L .36683 .6059 L F
.36692 .60848 m .36439 .60974 L .36459 .60595 L F
.576 .311 .477 r
.32096 .61533 m .32436 .61265 L .32112 .61268 L F
0 .08 .629 r
.28368 .54742 m .28483 .55082 L .28526 .54863 L F
.556 .24 .387 r
.28758 .5507 m .28693 .55273 L .28483 .55082 L F
.977 .734 .5 r
.28693 .55273 m .28645 .55155 L .28483 .55082 L F
.28645 .55155 m .28526 .54863 L .28488 .5506 L F
.28645 .55155 m .28488 .5506 L .28483 .55082 L F
.28693 .55273 m .28528 .55223 L .28526 .54863 L F
.334 .033 .297 r
.28912 .55198 m .28693 .55273 L .28758 .5507 L F
.468 0 0 r
.28912 .55198 m .28528 .55223 L .28693 .55273 L F
.28736 .55209 m .28733 .55319 L .28528 .55223 L F
.28912 .55198 m .2882 .5526 L .28736 .55209 L F
.2882 .5526 m .28733 .55319 L .28736 .55209 L F
.201 .129 .546 r
.34783 .57567 m .34954 .57758 L .34998 .57467 L F
.34783 .57567 m .34806 .57812 L .34954 .57758 L F
.471 .41 .707 r
.32938 .63987 m .32656 .63781 L .32889 .63707 L F
.32938 .63987 m .32721 .64079 L .32656 .63781 L F
.031 0 0 r
.22647 .55344 m .22337 .55629 L .22462 .55441 L F
.342 0 0 r
.32943 .60499 m .33072 .60558 L .3275 .60394 L F
.32943 .60499 m .3275 .60394 L .32757 .60238 L F
.174 0 .11 r
.18639 .55743 m .18743 .55828 L .18855 .55667 L F
.18639 .55743 m .18548 .55914 L .18743 .55828 L F
.242 .164 .564 r
.31758 .55373 m .31928 .5498 L .31713 .55132 L F
.664 .221 .19 r
.31408 .65631 m .31213 .65806 L .30989 .65608 L F
.697 .265 .218 r
.31408 .65631 m .31625 .6585 L .31213 .65806 L F
.481 .637 .923 r
.20699 .62255 m .20792 .62046 L .20546 .62108 L F
.20699 .62255 m .20893 .62215 L .20792 .62046 L F
.441 .088 .27 r
.20996 .56541 m .20609 .56839 L .20761 .56547 L F
.368 .183 .494 r
.35073 .57209 m .35256 .57149 L .35291 .56864 L F
.476 .224 .453 r
.34998 .57467 m .35256 .57149 L .35073 .57209 L F
.664 .205 .153 r
.36251 .52879 m .36667 .52851 L .36478 .52998 L F
.212 .494 .901 r
.27273 .6914 m .27404 .69314 L .27486 .69201 L F
.627 .472 .652 r
.27652 .69001 m .27676 .69272 L .27404 .69314 L F
.482 .846 .991 r
.27404 .69314 m .27676 .69272 L .27486 .69201 L F
.428 .656 .955 r
.19975 .61808 m .20029 .61612 L .19775 .61507 L F
.19975 .61808 m .20176 .61783 L .20029 .61612 L F
.052 .589 .854 r
.2617 .64122 m .26396 .64129 L .26127 .64071 L F
.2617 .64122 m .26533 .64175 L .26396 .64129 L F
.102 .657 .755 r
.3517 .53434 m .35397 .53413 L .3548 .53415 L F
.329 .813 .821 r
.3548 .53415 m .35662 .53338 L .35811 .53286 L F
.3548 .53415 m .35397 .53413 L .35662 .53338 L F
0 0 0 r
.29823 .58714 m .29592 .59013 L .29611 .58808 L F
.016 0 0 r
.27961 .6806 m .27823 .68048 L .27854 .68109 L F
.747 .323 .242 r
.33581 .54699 m .33764 .54936 L .33916 .54798 L F
0 0 .249 r
.25252 .55017 m .25368 .54964 L .25399 .54694 L F
0 0 0 r
.25252 .55017 m .25146 .55277 L .25368 .54964 L F
.678 .419 .523 r
.34666 .55378 m .34223 .55582 L .34377 .55379 L F
.34666 .55378 m .34191 .55705 L .34223 .55582 L F
.34666 .55378 m .3463 .55647 L .34191 .55705 L F
0 0 .258 r
.34844 .55377 m .34666 .55378 L .3483 .55293 L F
.34844 .55377 m .3463 .55647 L .34666 .55378 L F
.433 .696 .975 r
.20588 .79454 m .20628 .79279 L .20344 .79407 L F
.20588 .79454 m .20806 .79442 L .20628 .79279 L F
.153 0 0 r
.20588 .79454 m .20538 .7955 L .20344 .79407 L F
.20588 .79454 m .20806 .79442 L .20538 .7955 L F
.485 .24 .467 r
.32042 .56612 m .32281 .56564 L .32319 .56351 L F
.422 .185 .447 r
.32319 .56351 m .32281 .56564 L .32544 .56448 L F
.814 .879 .893 r
.26377 .69263 m .2662 .68968 L .26386 .68996 L F
0 .139 .668 r
.31832 .61869 m .31953 .62233 L .32021 .62067 L F
0 .179 .679 r
.31953 .62233 m .32077 .62282 L .32021 .62067 L F
.28 .485 .88 r
.19626 .61497 m .19542 .61171 L .19462 .61201 L F
.19626 .61497 m .19775 .61507 L .19542 .61171 L F
0 .559 .774 r
.24282 .55103 m .24123 .55071 L .2389 .55048 L F
.115 0 0 r
.24504 .54956 m .24123 .55071 L .24282 .55103 L F
.173 .361 .81 r
.21133 .60812 m .21044 .60964 L .20895 .60643 L F
.39 .289 .619 r
.21261 .61174 m .21044 .60964 L .21133 .60812 L F
.21261 .61174 m .21079 .61203 L .21044 .60964 L F
.723 .697 .825 r
.28572 .63097 m .28406 .6334 L .28196 .63019 L F
.513 .298 .524 r
.19806 .57423 m .19623 .57241 L .19843 .57198 L F
.19806 .57423 m .19594 .57486 L .19623 .57241 L F
.48 .451 .748 r
.51434 .55877 m .51327 .56285 L .51185 .55953 L F
.51434 .55877 m .51554 .56266 L .51327 .56285 L F
.546 .364 .586 r
.37183 .58152 m .37158 .58363 L .36898 .58388 L F
.476 .406 .699 r
.37188 .58695 m .36898 .58388 L .37158 .58363 L F
.37188 .58695 m .36995 .58772 L .36898 .58388 L F
.692 .966 .74 r
.25848 .62441 m .25922 .62291 L .26156 .6216 L F
.693 .964 .73 r
.25848 .62441 m .25774 .62461 L .25922 .62291 L F
.644 .363 .478 r
.3338 .61263 m .33623 .61505 L .33713 .61211 L F
.048 .26 .756 r
.33452 .61111 m .33623 .61505 L .3338 .61263 L F
.257 0 .175 r
.51607 .54504 m .51523 .54743 L .51299 .54753 L F
.494 .472 .762 r
.51498 .54255 m .51791 .54378 L .51607 .54504 L F
.04 0 .085 r
.51607 .54504 m .51791 .54378 L .51523 .54743 L F
.039 .004 .485 r
.32427 .64938 m .32339 .65216 L .32238 .65016 L F
.483 .818 .999 r
.23707 .62224 m .23623 .62372 L .2342 .62181 L F
.23707 .62224 m .23909 .62338 L .23623 .62372 L F
.534 .152 .263 r
.35803 .61878 m .35612 .62172 L .35434 .6208 L F
.614 .179 .19 r
.36029 .6211 m .35612 .62172 L .35803 .61878 L F
.36029 .6211 m .35918 .62182 L .35612 .62172 L F
.683 .637 .797 r
.35984 .61617 m .35803 .61878 L .35638 .61574 L F
.35984 .61617 m .35638 .61574 L .35878 .61558 L F
.366 .819 .704 r
.35429 .61752 m .35878 .61558 L .35638 .61574 L F
.205 0 0 r
.3523 .61774 m .35638 .61574 L .35247 .61496 L F
.469 .512 .82 r
.35488 .61751 m .35578 .61914 L .35288 .61775 L F
.366 .819 .704 r
.3544 .61752 m .35878 .61558 L .35429 .61752 L F
.205 0 0 r
.3523 .61774 m .35429 .61752 L .35638 .61574 L F
.469 .512 .82 r
.35244 .61754 m .35578 .61914 L .3523 .61774 L F
0 .02 .559 r
.35589 .61544 m .35585 .61677 L .35381 .61556 L F
.366 .819 .704 r
.35545 .61697 m .35596 .61671 L .35604 .61668 L F
.3552 .61716 m .35604 .61668 L .35878 .61558 L F
.3544 .61752 m .35577 .61681 L .3552 .61716 L F
.35577 .61681 m .35604 .61668 L .3552 .61716 L F
.69 .728 .88 r
.35612 .62172 m .35918 .62182 L .35604 .61734 L F
0 .02 .559 r
.35585 .61677 m .35603 .61743 L .35578 .61914 L F
.35603 .61743 m .35595 .61922 L .35578 .61914 L F
.69 .728 .88 r
.35593 .61964 m .35604 .61734 L .35567 .61682 L F
0 .045 .593 r
.35595 .61922 m .35612 .62172 L .35578 .61914 L F
.69 .728 .88 r
.35612 .62172 m .35604 .61734 L .35595 .61922 L F
.679 .631 .794 r
.35984 .61617 m .36053 .61915 L .35803 .61878 L F
.688 .35 .396 r
.36053 .61915 m .36029 .6211 L .35803 .61878 L F
.563 .554 .802 r
.36331 .61768 m .36053 .61915 L .35984 .61617 L F
.844 .769 .779 r
.356 .61684 m .35918 .62182 L .36093 .61704 L F
0 .02 .559 r
.35599 .61668 m .35605 .61748 L .35585 .61677 L F
.844 .769 .779 r
.35567 .61682 m .35604 .61734 L .356 .61684 L F
.35604 .61734 m .35918 .62182 L .356 .61684 L F
.662 .164 .054 r
.35878 .61558 m .35592 .61673 L .36093 .61704 L F
.35592 .61673 m .35567 .61682 L .356 .61684 L F
.35592 .61673 m .356 .61684 L .36093 .61704 L F
0 .02 .559 r
.35608 .61694 m .3566 .61954 L .35605 .61748 L F
.3561 .61662 m .35617 .61706 L .35608 .61694 L F
.35617 .61706 m .3566 .61954 L .35608 .61694 L F
.3561 .61662 m .35605 .61748 L .35599 .61668 L F
.075 .142 .63 r
.35782 .61789 m .3566 .61954 L .35589 .61544 L F
.577 .82 .442 r
.35782 .61789 m .35735 .61852 L .3566 .61954 L F
0 .045 .593 r
.3566 .61954 m .35602 .62033 L .35595 .61922 L F
.69 .728 .88 r
.35612 .62172 m .35595 .61922 L .35593 .61964 L F
.398 .532 .875 r
.35417 .61762 m .35578 .61914 L .35321 .6181 L F
.69 .728 .88 r
.35607 .62116 m .35568 .61686 L .35563 .62068 L F
0 .02 .559 r
.35585 .61677 m .35478 .61732 L .35381 .61556 L F
.366 .819 .704 r
.35417 .61762 m .35567 .61682 L .35596 .61671 L F
.69 .728 .88 r
.35568 .61686 m .35567 .61682 L .35567 .61686 L F
0 .02 .559 r
.35585 .61677 m .35578 .61914 L .35478 .61732 L F
.69 .728 .88 r
.35568 .61686 m .35567 .61686 L .35563 .62068 L F
.469 .512 .82 r
.35282 .61768 m .35288 .61775 L .35276 .61769 L F
.398 .532 .875 r
.35417 .61762 m .35321 .6181 L .3523 .61774 L F
.577 .82 .442 r
.35735 .61852 m .35542 .62106 L .3566 .61954 L F
0 .045 .593 r
.3566 .61954 m .35612 .62172 L .35602 .62033 L F
0 .02 .559 r
.35603 .61743 m .3566 .61954 L .35595 .61922 L F
.35589 .61544 m .3561 .61662 L .35585 .61677 L F
.366 .819 .704 r
.35417 .61762 m .35596 .61671 L .35545 .61697 L F
.35417 .61762 m .35604 .61668 L .3544 .61752 L F
.469 .512 .82 r
.35381 .61556 m .35478 .61732 L .35244 .61754 L F
.35478 .61732 m .35488 .61751 L .3544 .61752 L F
.35478 .61732 m .3544 .61752 L .35244 .61754 L F
.69 .728 .88 r
.35563 .62068 m .35567 .61682 L .35417 .61762 L F
.35612 .62172 m .35607 .62116 L .35563 .62068 L F
.469 .512 .82 r
.35488 .61751 m .35288 .61775 L .35282 .61768 L F
.35429 .61752 m .35276 .61769 L .35244 .61754 L F
.35488 .61751 m .35276 .61769 L .35429 .61752 L F
.205 0 0 r
.3523 .61774 m .35417 .61762 L .35429 .61752 L F
.366 .819 .704 r
.35417 .61762 m .3544 .61752 L .35429 .61752 L F
.168 .362 .812 r
.3566 .61954 m .3583 .62285 L .35612 .62172 L F
.3583 .62285 m .35831 .62287 L .35612 .62172 L F
.534 .152 .263 r
.35434 .6208 m .35612 .62172 L .35415 .6209 L F
.817 .923 .907 r
.50027 .55087 m .49788 .55381 L .49639 .55238 L F
.598 .549 .771 r
.50027 .55087 m .50059 .55377 L .49788 .55381 L F
.581 .59 .827 r
.50192 .55619 m .49788 .55381 L .50059 .55377 L F
0 0 .229 r
.33277 .56279 m .33347 .56391 L .33544 .56194 L F
.212 .494 .901 r
.27273 .6914 m .27652 .69001 L .27273 .68972 L F
.552 .438 .677 r
.27876 .68957 m .27676 .69272 L .27652 .69001 L F
.258 0 0 r
.27876 .68957 m .27652 .69001 L .27486 .69201 L F
.683 .608 .766 r
.33713 .61211 m .34015 .61257 L .33903 .60935 L F
.729 .472 .538 r
.33623 .61505 m .34015 .61257 L .33713 .61211 L F
0 0 0 r
.31747 .56845 m .31838 .56797 L .32042 .56612 L F
.04 0 0 r
.32042 .56612 m .32085 .56702 L .32281 .56564 L F
.32042 .56612 m .31838 .56797 L .32085 .56702 L F
.824 .785 .815 r
.5113 .54391 m .51414 .54072 L .51498 .54255 L F
.454 .49 .807 r
.51667 .54012 m .51498 .54255 L .51414 .54072 L F
.51667 .54012 m .51791 .54378 L .51498 .54255 L F
.501 .803 .999 r
.34507 .59081 m .34758 .59036 L .34547 .58909 L F
.745 .99 .884 r
.34272 .59116 m .34507 .59081 L .34547 .58909 L F
.679 .54 .688 r
.34507 .59081 m .34871 .59378 L .34758 .59036 L F
.34507 .59081 m .34584 .59418 L .34871 .59378 L F
.183 0 .267 r
.32721 .64079 m .32653 .64299 L .32514 .64358 L F
.396 .113 .362 r
.32885 .64238 m .32721 .64079 L .32938 .63987 L F
.32885 .64238 m .32653 .64299 L .32721 .64079 L F
0 0 .146 r
.52359 .53222 m .52406 .53329 L .52462 .53175 L F
.52359 .53222 m .52329 .53513 L .52406 .53329 L F
.938 .579 .302 r
.54215 .54847 m .54109 .54972 L .54025 .54678 L F
.372 .385 .744 r
.54215 .54847 m .54541 .54865 L .54565 .54786 L F
0 0 0 r
.54339 .54881 m .54215 .54847 L .54421 .54811 L F
.54339 .54881 m .54109 .54972 L .54215 .54847 L F
.256 0 0 r
.54339 .54881 m .54054 .5502 L .54109 .54972 L F
.54054 .5502 m .53951 .5507 L .54038 .55016 L F
.54054 .5502 m .54038 .55016 L .54109 .54972 L F
.343 .587 .935 r
.53321 .54868 m .53845 .54848 L .53523 .55051 L F
0 .217 .616 r
.53601 .55095 m .53523 .55051 L .53608 .54997 L F
.53683 .55011 m .53608 .54997 L .53845 .54848 L F
.53601 .55095 m .53608 .54997 L .53683 .55011 L F
.947 .732 .58 r
.53845 .54848 m .53962 .55016 L .53963 .54917 L F
.939 .602 .361 r
.54109 .54972 m .54083 .54988 L .53963 .54917 L F
.53961 .54902 m .53963 .54917 L .53845 .54848 L F
.54109 .54972 m .53963 .54917 L .53961 .54902 L F
.932 .577 .325 r
.54025 .54678 m .53845 .54848 L .53965 .54607 L F
.54025 .54678 m .54109 .54972 L .53961 .54902 L F
.53937 .54761 m .53961 .54902 L .53845 .54848 L F
.54025 .54678 m .53961 .54902 L .53937 .54761 L F
0 0 .41 r
.53965 .54607 m .53963 .54915 L .54082 .54722 L F
.53963 .54915 m .53963 .54917 L .53963 .54917 L F
.53963 .54915 m .53963 .54917 L .54082 .54722 L F
.53963 .54917 m .53962 .55016 L .53973 .54989 L F
.939 .602 .361 r
.54083 .54988 m .54038 .55016 L .53968 .54955 L F
.53962 .54917 m .53968 .54955 L .53845 .54848 L F
.54083 .54988 m .53968 .54955 L .53962 .54917 L F
.91 .63 .501 r
.53978 .55017 m .53973 .54989 L .53962 .55016 L F
.064 0 0 r
.53859 .5502 m .53977 .55018 L .53962 .55016 L F
.939 .602 .361 r
.54038 .55016 m .53926 .55018 L .53845 .54848 L F
.256 0 0 r
.54339 .54881 m .54235 .55028 L .53951 .5507 L F
.91 .63 .501 r
.54106 .55031 m .54082 .54722 L .53973 .54989 L F
.54106 .55031 m .53973 .54989 L .53978 .55017 L F
0 0 .41 r
.53963 .54917 m .53973 .54989 L .54082 .54722 L F
.947 .732 .58 r
.53845 .54848 m .53963 .54917 L .53965 .54607 L F
.939 .602 .361 r
.54038 .55016 m .53951 .5507 L .53926 .55018 L F
.064 0 0 r
.53686 .55012 m .53737 .55014 L .53962 .55016 L F
.53737 .55014 m .53906 .55018 L .53962 .55016 L F
.82 .812 .843 r
.53544 .55009 m .53601 .55095 L .53845 .54848 L F
.064 0 0 r
.53544 .55009 m .53962 .55016 L .53845 .54848 L F
.53544 .55009 m .53845 .54848 L .53926 .55018 L F
.53544 .55009 m .53926 .55018 L .53951 .5507 L F
.53737 .55014 m .53859 .5502 L .53906 .55018 L F
.53859 .5502 m .54091 .5503 L .53977 .55018 L F
.53544 .55009 m .53708 .55016 L .53686 .55012 L F
.53708 .55016 m .54091 .5503 L .53686 .55012 L F
.54091 .5503 m .54106 .55031 L .54085 .55028 L F
.54091 .5503 m .54085 .55028 L .53962 .55016 L F
.842 .883 .45 r
.54382 .5467 m .54272 .54938 L .54339 .54881 L F
.54272 .54938 m .54235 .55028 L .54339 .54881 L F
0 0 0 r
.54339 .54881 m .54421 .54811 L .54565 .54786 L F
.308 .127 .464 r
.16789 .5755 m .16965 .57473 L .16983 .57203 L F
.304 .106 .437 r
.16749 .57786 m .16965 .57473 L .16789 .5755 L F
.401 .33 .662 r
.31289 .63716 m .31567 .64 L .31558 .63682 L F
.31289 .63716 m .31356 .64034 L .31567 .64 L F
.505 .542 .828 r
.31747 .56845 m .31836 .57164 L .32073 .57099 L F
.752 .438 .453 r
.33434 .59206 m .33078 .58984 L .33248 .59209 L F
.588 .343 .513 r
.29968 .54715 m .29583 .54984 L .29719 .54763 L F
.265 .549 .926 r
.14243 .70161 m .14361 .70277 L .1427 .70237 L F
.1427 .70237 m .14361 .70277 L .14243 .70161 L F
.28 .007 .309 r
.36331 .61768 m .36029 .6211 L .36053 .61915 L F
.429 .732 .99 r
.31053 .5312 m .30967 .53276 L .3082 .53123 L F
.31053 .5312 m .31231 .53251 L .30967 .53276 L F
0 .502 .734 r
.27264 .53021 m .27661 .53092 L .27477 .53082 L F
.24 .321 .746 r
.29468 .62766 m .2957 .63131 L .29689 .62939 L F
.236 .316 .743 r
.2957 .63131 m .29813 .63332 L .29689 .62939 L F
.425 .327 .641 r
.2957 .63131 m .29616 .63405 L .29813 .63332 L F
.597 .533 .754 r
.36113 .54649 m .36214 .55065 L .36468 .54983 L F
.441 .385 .7 r
.36214 .55065 m .36477 .5525 L .36468 .54983 L F
.36214 .55065 m .36295 .55341 L .36477 .5525 L F
.752 .866 .932 r
.51295 .55266 m .51607 .55197 L .5145 .5522 L F
0 0 0 r
.35395 .54658 m .35099 .54973 L .35246 .54829 L F
0 .224 .743 r
.32992 .54735 m .32913 .54776 L .32742 .54617 L F
.534 .096 .155 r
.32913 .54776 m .3311 .54911 L .33206 .54791 L F
0 .224 .743 r
.32992 .54735 m .3311 .54911 L .32913 .54776 L F
.599 .757 .954 r
.29588 .53037 m .29328 .53122 L .29178 .52953 L F
.947 .663 .466 r
.31771 .55723 m .31554 .55639 L .31758 .55373 L F
.242 .164 .564 r
.31758 .55373 m .31906 .55334 L .31928 .5498 L F
0 0 0 r
.31758 .55373 m .3184 .55421 L .31906 .55334 L F
.31758 .55373 m .31554 .55639 L .3184 .55421 L F
.514 .386 .644 r
.35715 .5569 m .35944 .55903 L .36017 .55711 L F
.35715 .5569 m .35735 .55967 L .35944 .55903 L F
0 0 0 r
.33585 .59111 m .33865 .59079 L .33624 .59107 L F
.259 .075 .431 r
.27956 .59985 m .28121 .59939 L .28152 .59683 L F
.271 .19 .577 r
.27956 .59985 m .28138 .6021 L .28121 .59939 L F
.27956 .59985 m .27952 .6034 L .28138 .6021 L F
0 0 0 r
.25922 .62291 m .26398 .62148 L .26156 .6216 L F
.626 .819 .974 r
.33265 .53384 m .32804 .53294 L .33064 .53238 L F
.624 .817 .974 r
.33538 .53297 m .33265 .53384 L .33064 .53238 L F
.859 .494 .357 r
.30879 .64866 m .3089 .64665 L .30552 .64541 L F
.666 .314 .366 r
.30879 .64866 m .3111 .64893 L .3089 .64665 L F
.554 .324 .522 r
.3089 .64665 m .3111 .64893 L .31141 .64629 L F
.24 .081 .455 r
.1929 .58019 m .19147 .57834 L .19316 .57784 L F
.1929 .58019 m .19082 .58238 L .19147 .57834 L F
.664 .205 .153 r
.36251 .52879 m .36514 .5303 L .36667 .52851 L F
.627 .858 .488 r
.36667 .52851 m .3674 .52727 L .36926 .52811 L F
.36667 .52851 m .36514 .5303 L .3674 .52727 L F
.021 0 0 r
.2062 .54529 m .20657 .54598 L .20846 .54447 L F
.2062 .54529 m .20438 .54665 L .20657 .54598 L F
.729 .472 .538 r
.33623 .61505 m .33998 .61506 L .34015 .61257 L F
.574 .545 .785 r
.33903 .60935 m .34015 .61257 L .34255 .61203 L F
.649 .479 .64 r
.33998 .61506 m .34255 .61203 L .34015 .61257 L F
.361 .21 .537 r
.32679 .64527 m .32514 .64358 L .32653 .64299 L F
.32679 .64527 m .32494 .64623 L .32514 .64358 L F
.994 .872 .561 r
.54885 .55017 m .54812 .55258 L .54886 .55339 L F
.996 .843 .571 r
.54724 .55518 m .54886 .55339 L .54812 .55258 L F
.54724 .55518 m .54845 .55725 L .54886 .55339 L F
.349 .068 .339 r
.3088 .57188 m .30812 .57459 L .30598 .57519 L F
.656 .788 .945 r
.17249 .60006 m .17604 .60051 L .17508 .59907 L F
.17 .495 .905 r
.17508 .59907 m .17604 .60051 L .17629 .59908 L F
.261 .594 .949 r
.17604 .60051 m .17796 .60063 L .17629 .59908 L F
.91 .847 .77 r
.29227 .65213 m .29187 .64931 L .29112 .6493 L F
.021 0 .167 r
.2778 .61896 m .27989 .61601 L .27855 .61774 L F
.012 0 .277 r
.27841 .62048 m .2778 .61896 L .27855 .61774 L F
.27841 .62048 m .2772 .62144 L .2778 .61896 L F
.685 .682 .841 r
.51139 .5599 m .50855 .56025 L .50808 .55878 L F
0 .14 .68 r
.50752 .56037 m .50926 .55961 L .50686 .56003 L F
.5076 .56041 m .50773 .56035 L .50752 .56037 L F
.50773 .56035 m .50926 .55961 L .50752 .56037 L F
.685 .682 .841 r
.51185 .55953 m .51139 .5599 L .50808 .55878 L F
.51139 .5599 m .50903 .56177 L .50855 .56025 L F
.202 .21 .644 r
.16528 .5975 m .16729 .59821 L .16679 .59578 L F
.16528 .5975 m .166 .59997 L .16729 .59821 L F
0 0 .01 r
.2647 .54825 m .26423 .54705 L .26775 .54591 L F
.943 .82 .693 r
.54755 .54408 m .54625 .54717 L .54857 .54752 L F
.137 .334 .797 r
.5459 .54614 m .54636 .5475 L .54565 .54786 L F
.943 .82 .693 r
.54625 .54717 m .54611 .5475 L .54636 .5475 L F
.54625 .54717 m .54636 .5475 L .54857 .54752 L F
.829 .661 .675 r
.54576 .54345 m .54605 .54683 L .54755 .54408 L F
.54605 .54683 m .54611 .5475 L .54625 .54717 L F
.54605 .54683 m .54625 .54717 L .54755 .54408 L F
.137 .334 .797 r
.546 .54545 m .54696 .54721 L .54643 .54747 L F
.54633 .5473 m .54643 .54747 L .54636 .5475 L F
.546 .54545 m .54643 .54747 L .54633 .5473 L F
.546 .54545 m .54636 .5475 L .5459 .54614 L F
.329 .81 .886 r
.54857 .54752 m .54636 .5475 L .54565 .54786 L F
.344 0 0 r
.54565 .54786 m .54766 .54848 L .54857 .54752 L F
.137 .334 .797 r
.54696 .54721 m .54766 .54848 L .54565 .54786 L F
.329 .81 .886 r
.54636 .5475 m .54611 .5475 L .54565 .54786 L F
.971 .682 .279 r
.54766 .54848 m .54885 .55017 L .54857 .54752 L F
.954 .688 .494 r
.51125 .54663 m .51299 .54753 L .51297 .5501 L F
.326 .306 .683 r
.51299 .54753 m .51579 .55126 L .51297 .5501 L F
.51299 .54753 m .51523 .54743 L .51583 .5512 L F
.555 .541 .794 r
.5174 .5505 m .51607 .55197 L .51554 .55138 L F
.326 .306 .683 r
.51579 .55126 m .51583 .5512 L .51586 .55134 L F
.51299 .54753 m .51583 .5512 L .51579 .55126 L F
.555 .541 .794 r
.51849 .54932 m .5174 .5505 L .51581 .55124 L F
.326 .306 .683 r
.51579 .55126 m .51573 .55129 L .51297 .5501 L F
.555 .541 .794 r
.51588 .55112 m .51581 .55124 L .51553 .55136 L F
.51849 .54932 m .51581 .55124 L .51583 .5512 L F
.5174 .5505 m .51554 .55138 L .51553 .55136 L F
.619 .487 .679 r
.51583 .5512 m .51849 .54932 L .51586 .55134 L F
.51523 .54743 m .51849 .54932 L .51583 .5512 L F
.555 .541 .794 r
.51849 .54932 m .51583 .5512 L .51588 .55112 L F
.326 .306 .683 r
.51579 .55126 m .51586 .55134 L .51573 .55129 L F
.44 .019 .143 r
.35094 .66322 m .34935 .66464 L .34698 .66469 L F
.35112 .66315 m .34935 .66464 L .34698 .66469 L F
.836 .988 .717 r
.35157 .66265 m .34935 .66464 L .3518 .66124 L F
.3515 .66305 m .34935 .66464 L .35157 .66265 L F
.44 .019 .143 r
.35112 .66315 m .34935 .66464 L .35094 .66322 L F
.581 .004 0 r
.3515 .66305 m .35322 .66442 L .35112 .66315 L F
.836 .988 .717 r
.3515 .66305 m .3518 .66124 L .35343 .66165 L F
.389 .201 .501 r
.35343 .66165 m .35322 .66442 L .3515 .66305 L F
.704 .232 .127 r
.36926 .52811 m .37149 .53029 L .37359 .52894 L F
.428 .26 .55 r
.37559 .52817 m .37342 .53105 L .37359 .52894 L F
.37559 .52817 m .37567 .53063 L .37342 .53105 L F
.986 .716 .419 r
.37414 .52859 m .37559 .52817 L .37316 .52909 L F
.37414 .52859 m .37316 .52909 L .37243 .52936 L F
.183 .416 .852 r
.37486 .52693 m .37539 .52797 L .37414 .52859 L F
.986 .716 .419 r
.37414 .52859 m .37567 .53063 L .37562 .52917 L F
.3755 .5282 m .3756 .52839 L .37559 .52817 L F
.183 .416 .852 r
.37539 .52797 m .37608 .52935 L .37414 .52859 L F
.096 .454 .885 r
.37608 .52935 m .37567 .53063 L .3742 .52868 L F
.37428 .52865 m .3742 .52868 L .37414 .52859 L F
.37608 .52935 m .3742 .52868 L .37428 .52865 L F
.863 .985 .704 r
.37359 .52894 m .37306 .52913 L .37559 .52817 L F
.37306 .52913 m .37243 .52936 L .37344 .52898 L F
.37306 .52913 m .37344 .52898 L .37559 .52817 L F
.37359 .52894 m .37149 .53029 L .37243 .52936 L F
.807 .532 .522 r
.53523 .55051 m .53347 .55099 L .53177 .54994 L F
.432 .25 .532 r
.53601 .5531 m .53568 .55355 L .53534 .55355 L F
0 .217 .616 r
.53711 .55158 m .53887 .55258 L .53566 .55075 L F
.938 .945 .766 r
.53711 .55158 m .53601 .5531 L .53887 .55258 L F
0 .217 .616 r
.53566 .55075 m .53887 .55258 L .53523 .55051 L F
.53601 .55095 m .53711 .55158 L .53566 .55075 L F
.938 .945 .766 r
.53601 .55095 m .53568 .55354 L .53711 .55158 L F
.432 .25 .532 r
.53951 .5507 m .53601 .5531 L .53601 .55095 L F
.53601 .5531 m .53534 .55355 L .53601 .55095 L F
.938 .945 .766 r
.53601 .5531 m .53568 .55354 L .53601 .55345 L F
.53601 .5531 m .53601 .55345 L .53887 .55258 L F
.53601 .55095 m .53511 .55372 L .53568 .55354 L F
.432 .25 .532 r
.53772 .55193 m .53965 .55352 L .53568 .55355 L F
.53772 .55193 m .53568 .55355 L .53601 .5531 L F
.53951 .5507 m .53962 .55301 L .53772 .55193 L F
.53962 .55301 m .53965 .55352 L .53772 .55193 L F
.632 .815 .97 r
.32383 .54038 m .32782 .54072 L .32612 .53997 L F
0 .483 .801 r
.32782 .54072 m .32976 .54122 L .32612 .53997 L F
.576 .311 .477 r
.32096 .61533 m .32364 .61504 L .32436 .61265 L F
.414 .157 .411 r
.32436 .61265 m .32595 .6144 L .32573 .6117 L F
.32436 .61265 m .32364 .61504 L .32595 .6144 L F
.759 .262 .045 r
.33797 .63302 m .34011 .63551 L .34102 .63444 L F
.947 .589 .233 r
.34011 .63551 m .34181 .63679 L .34102 .63444 L F
.735 .699 .817 r
.36783 .53753 m .36968 .541 L .3723 .53731 L F
.648 .574 .758 r
.36968 .541 m .37251 .54113 L .3723 .53731 L F
.596 .425 .62 r
.36968 .541 m .3723 .54411 L .37251 .54113 L F
.36968 .541 m .37049 .54455 L .3723 .54411 L F
.175 0 .124 r
.24944 .5484 m .24787 .5479 L .2517 .54761 L F
.501 .46 .743 r
.5066 .55274 m .50494 .55719 L .50412 .55334 L F
.5066 .55274 m .50795 .55686 L .50494 .55719 L F
.502 .477 .761 r
.50795 .55686 m .50808 .55878 L .50494 .55719 L F
.092 0 0 r
.17758 .56563 m .17962 .56494 L .18094 .56301 L F
0 0 0 r
.18347 .55995 m .18094 .56301 L .18233 .56158 L F
.273 0 .274 r
.17962 .56494 m .18233 .56158 L .18094 .56301 L F
.561 .769 .976 r
.24248 .62411 m .23909 .62338 L .24091 .62314 L F
.157 .54 .924 r
.24317 .62312 m .24248 .62411 L .24091 .62314 L F
.24317 .62312 m .24461 .6246 L .24248 .62411 L F
.039 .004 .485 r
.32427 .64938 m .32436 .65253 L .32339 .65216 L F
0 .237 .748 r
.32436 .65253 m .326 .65408 L .32339 .65216 L F
.23 0 0 r
.31833 .57727 m .32198 .57535 L .31929 .5752 L F
.62 .468 .655 r
.31929 .5752 m .32198 .57535 L .32131 .57288 L F
0 .112 .661 r
.33352 .63679 m .33362 .63601 L .33151 .63389 L F
0 .158 .694 r
.33352 .63679 m .33617 .63904 L .33362 .63601 L F
.787 .637 .695 r
.52914 .54225 m .52431 .54376 L .52454 .54105 L F
.52914 .54225 m .5281 .54432 L .52431 .54376 L F
.358 .146 .448 r
.53053 .54095 m .5281 .54432 L .52914 .54225 L F
.565 .774 .976 r
.23151 .63354 m .23526 .63397 L .23386 .63286 L F
.055 .372 .839 r
.23495 .63314 m .23567 .63179 L .23517 .63243 L F
0 .475 .862 r
.23481 .63361 m .23495 .63314 L .23386 .63286 L F
.931 .557 .265 r
.23495 .63314 m .23359 .63216 L .23386 .63286 L F
.117 .585 .917 r
.23386 .63286 m .23359 .63216 L .22857 .63093 L F
.931 .557 .265 r
.23363 .63219 m .2337 .63327 L .23359 .63216 L F
.23495 .63314 m .2337 .63327 L .23363 .63219 L F
.965 .646 .354 r
.23495 .63314 m .23366 .63438 L .2337 .63327 L F
.171 0 .339 r
.2337 .63327 m .23366 .63438 L .23376 .63424 L F
.2337 .63327 m .23376 .63424 L .23567 .63179 L F
.055 .372 .839 r
.23495 .63314 m .23517 .63243 L .23366 .63438 L F
0 .475 .862 r
.23526 .63397 m .23495 .63314 L .23481 .63361 L F
.078 .558 .9 r
.23526 .63397 m .23693 .63428 L .23495 .63314 L F
.27 .045 .377 r
.38555 .55668 m .38514 .55922 L .3832 .55916 L F
.072 0 .242 r
.38457 .56021 m .3832 .55916 L .38514 .55922 L F
.38457 .56021 m .38271 .56227 L .3832 .55916 L F
.696 .416 .495 r
.22332 .56006 m .22254 .56247 L .21879 .562 L F
.735 .457 .508 r
.22513 .56251 m .22254 .56247 L .22332 .56006 L F
0 0 .124 r
.29823 .57176 m .29656 .57538 L .29733 .57422 L F
0 0 .307 r
.29621 .57787 m .29733 .57422 L .29656 .57538 L F
.47 .476 .781 r
.37567 .53063 m .37456 .53526 L .37342 .53105 L F
.346 .12 .421 r
.37644 .5361 m .37441 .5375 L .37456 .53526 L F
.37456 .53526 m .37441 .5375 L .37644 .5361 L F
.156 .031 .446 r
.31457 .54913 m .31327 .54723 L .31472 .54656 L F
.31457 .54913 m .31318 .55004 L .31327 .54723 L F
.405 0 0 r
.21636 .61511 m .22077 .61701 L .2181 .6169 L F
.6 .577 .8 r
.51055 .53899 m .51185 .54168 L .50817 .54055 L F
0 0 0 r
.50928 .54001 m .51055 .53899 L .50817 .54055 L F
.253 .76 .735 r
.50539 .54108 m .50925 .54002 L .50817 .54055 L F
.50488 .54118 m .50589 .54091 L .50539 .54108 L F
.50589 .54091 m .50925 .54002 L .50539 .54108 L F
.657 .499 .658 r
.50817 .54055 m .5113 .54391 L .50791 .54343 L F
.50817 .54055 m .51185 .54168 L .5113 .54391 L F
.097 0 0 r
.50752 .54105 m .5099 .54009 L .51052 .53934 L F
.50944 .5397 m .51127 .53842 L .50935 .53986 L F
0 0 0 r
.51127 .53842 m .51055 .53899 L .50928 .54001 L F
.484 .859 .637 r
.50922 .53996 m .51127 .53842 L .50928 .54001 L F
.097 0 0 r
.50944 .5397 m .51052 .53934 L .51127 .53842 L F
.167 0 0 r
.50471 .54136 m .50752 .54105 L .50922 .53996 L F
.097 0 0 r
.50752 .54105 m .50944 .5397 L .50922 .53996 L F
.50944 .5397 m .50935 .53986 L .50922 .53996 L F
.253 .76 .735 r
.50925 .54002 m .50928 .54001 L .50924 .54003 L F
.50925 .54002 m .50924 .54003 L .50817 .54055 L F
.50488 .54118 m .50922 .53996 L .50928 .54001 L F
.097 0 0 r
.50752 .54105 m .51052 .53934 L .50944 .5397 L F
.271 0 .164 r
.18233 .56158 m .18548 .55914 L .18347 .55995 L F
.37 .368 .726 r
.30202 .61571 m .30457 .61771 L .30374 .61534 L F
.444 .368 .677 r
.30202 .61571 m .30266 .61864 L .30457 .61771 L F
.21 .735 .762 r
.35291 .56864 m .35578 .56796 L .35584 .56801 L F
.093 0 .195 r
.35256 .57149 m .35578 .56796 L .35291 .56864 L F
.499 .79 .997 r
.31686 .53128 m .31611 .53288 L .31476 .53163 L F
.31686 .53128 m .31843 .53228 L .31611 .53288 L F
.567 .904 .669 r
.5174 .55055 m .51849 .54932 L .519 .54919 L F
.033 .19 .696 r
.5174 .55055 m .5196 .55269 L .51849 .54932 L F
.065 0 0 r
.31165 .6071 m .30973 .60712 L .30691 .60793 L F
0 .381 .696 r
.27177 .64127 m .27603 .64273 L .27417 .64231 L F
.267 0 0 r
.27603 .64273 m .27812 .64339 L .27417 .64231 L F
.697 .635 .783 r
.50412 .55334 m .50192 .55619 L .50059 .55377 L F
.419 .409 .742 r
.36828 .59597 m .36811 .59984 L .36627 .60025 L F
.492 .415 .697 r
.36811 .59984 m .36664 .60287 L .36627 .60025 L F
.776 .555 .6 r
.34557 .59632 m .34883 .59661 L .34871 .59378 L F
0 0 0 r
.3475 .59491 m .34557 .59632 L .34871 .59378 L F
.3475 .59491 m .34584 .59418 L .34445 .59556 L F
.3475 .59491 m .34871 .59378 L .34584 .59418 L F
.36 0 0 r
.33641 .54127 m .33226 .54159 L .33541 .54395 L F
.392 0 .068 r
.24288 .55659 m .24523 .55642 L .24664 .55479 L F
.461 .022 .115 r
.24664 .55479 m .24523 .55642 L .24862 .55557 L F
.45 .098 .276 r
.24664 .55479 m .24862 .55557 L .2499 .55424 L F
.491 .323 .581 r
.264 .70834 m .26167 .71198 L .2611 .70882 L F
.264 .70834 m .26423 .71141 L .26167 .71198 L F
.335 .809 .906 r
.26167 .71198 m .26219 .71125 L .25972 .71066 L F
.26167 .71198 m .26423 .71141 L .26219 .71125 L F
.8 .307 0 r
.34888 .62794 m .34617 .62581 L .34664 .62742 L F
.453 0 0 r
.26994 .64154 m .27177 .64127 L .27417 .64231 L F
.335 .149 .473 r
.16983 .57203 m .17149 .57399 L .17195 .57168 L F
.16983 .57203 m .16965 .57473 L .17149 .57399 L F
.645 .655 .845 r
.2845 .66103 m .28476 .66569 L .28789 .66222 L F
.342 .773 .97 r
.36875 .55664 m .36847 .55606 L .36584 .55634 L F
.36978 .55675 m .36847 .55606 L .36584 .55634 L F
.36584 .55634 m .36847 .55606 L .36978 .55675 L F
.531 .541 .811 r
.36584 .55634 m .36847 .55606 L .36674 .55205 L F
0 0 0 r
.36479 .55817 m .36847 .55606 L .36584 .55634 L F
.36479 .55817 m .36674 .55744 L .36847 .55606 L F
.875 .976 .672 r
.36847 .55606 m .36674 .55744 L .36807 .55522 L F
.013 .212 .722 r
.36674 .55205 m .36847 .55606 L .36879 .554 L F
.875 .976 .672 r
.36847 .55606 m .36807 .55522 L .36879 .554 L F
.342 .773 .97 r
.36978 .55675 m .36847 .55606 L .36875 .55664 L F
.515 .373 .627 r
.37153 .55365 m .37213 .55623 L .36978 .55675 L F
.445 .831 .986 r
.36978 .55675 m .36847 .55606 L .37213 .55623 L F
.029 0 .413 r
.54306 .55385 m .54482 .55378 L .54541 .54865 L F
.447 .184 .421 r
.54193 .5554 m .54482 .55378 L .54306 .55385 L F
.561 .164 .248 r
.32383 .54038 m .31959 .54274 L .32137 .54154 L F
.407 .457 .8 r
.49576 .55637 m .49764 .55597 L .49639 .55238 L F
.374 .373 .731 r
.49576 .55637 m .4979 .55806 L .49764 .55597 L F
.604 .823 .984 r
.16486 .61212 m .16286 .61312 L .16283 .61089 L F
.16486 .61212 m .16286 .61312 L .16283 .61089 L F
.94 .822 .7 r
.5458 .55821 m .54845 .55725 L .54724 .55518 L F
.5458 .55821 m .54731 .55943 L .54845 .55725 L F
.03 0 .421 r
.31617 .61654 m .31435 .6156 L .31591 .61399 L F
.31617 .61654 m .31446 .61817 L .31435 .6156 L F
.701 .463 .56 r
.30234 .55283 m .30678 .55011 L .30576 .55062 L F
.572 .495 .73 r
.34171 .54722 m .34275 .55106 L .34496 .54928 L F
.071 .163 .654 r
.34275 .55106 m .34465 .5524 L .34496 .54928 L F
.366 .632 .956 r
.22891 .61795 m .22818 .61979 L .22661 .61835 L F
.22891 .61795 m .23106 .62018 L .22818 .61979 L F
.256 .085 .447 r
.37188 .58695 m .37001 .59039 L .36995 .58772 L F
.47 .471 .777 r
.35772 .56324 m .35977 .56166 L .35711 .56256 L F
.35772 .56324 m .36109 .56383 L .35977 .56166 L F
.631 .548 .743 r
.52547 .5626 m .52338 .56602 L .52205 .56208 L F
.52547 .5626 m .5263 .56514 L .52338 .56602 L F
.782 .643 .708 r
.52205 .56208 m .52338 .56602 L .51952 .56554 L F
.311 .787 .921 r
.5263 .56514 m .522 .56516 L .52338 .56602 L F
.435 .8 .995 r
.51952 .56554 m .52338 .56602 L .522 .56516 L F
.572 .495 .73 r
.34171 .54722 m .34496 .54928 L .34538 .54724 L F
.617 .549 .755 r
.19135 .58397 m .18876 .58462 L .18889 .58403 L F
.307 0 .24 r
.25499 .71422 m .25644 .71223 L .25331 .71354 L F
.25499 .71422 m .25931 .71003 L .25644 .71223 L F
0 0 0 r
.35395 .54658 m .35293 .54879 L .35099 .54973 L F
0 .213 .725 r
.35385 .5433 m .35388 .54447 L .35688 .54418 L F
.35388 .54447 m .35395 .54658 L .3556 .54523 L F
.35388 .54447 m .3556 .54523 L .35688 .54418 L F
.35385 .5433 m .35476 .5451 L .35395 .54658 L F
.496 0 0 r
.35285 .544 m .35315 .54444 L .35476 .5451 L F
.35164 .54331 m .35215 .5437 L .35285 .544 L F
.35215 .5437 m .35315 .54444 L .35285 .544 L F
0 0 0 r
.35476 .5451 m .35293 .54879 L .35395 .54658 L F
.544 .676 .924 r
.14243 .70161 m .14614 .7023 L .14361 .70277 L F
.14243 .70161 m .14614 .7023 L .14361 .70277 L F
0 0 .121 r
.3059 .63438 m .30769 .63077 L .3075 .6339 L F
.336 .339 .715 r
.3075 .6339 m .30834 .63634 L .3059 .63438 L F
.902 .878 .446 r
.50686 .56003 m .50648 .56291 L .5076 .56041 L F
0 .14 .68 r
.5076 .56041 m .51068 .56312 L .50926 .55961 L F
.202 .162 .587 r
.5076 .56041 m .5091 .56553 L .51068 .56312 L F
.322 .483 .864 r
.32073 .57099 m .32131 .57288 L .3224 .57107 L F
.491 .389 .666 r
.32131 .57288 m .32345 .57352 L .3224 .57107 L F
.32131 .57288 m .32198 .57535 L .32345 .57352 L F
.217 .567 .938 r
.2513 .63733 m .25538 .63962 L .25397 .63839 L F
.578 .814 .988 r
.25397 .63839 m .25538 .63962 L .2574 .63882 L F
.091 0 0 r
.24955 .53305 m .25326 .53285 L .25173 .53321 L F
.878 .907 .845 r
.29641 .66492 m .29395 .66808 L .29205 .66755 L F
.575 .417 .63 r
.29641 .66492 m .29661 .66833 L .29395 .66808 L F
.593 .628 .855 r
.29673 .66537 m .29661 .66833 L .29641 .66492 L F
.164 .678 .894 r
.29205 .66755 m .29395 .66808 L .29667 .66768 L F
.179 .663 .926 r
.29395 .66808 m .29661 .66833 L .29667 .66768 L F
.276 0 .182 r
.28702 .59125 m .28828 .59236 L .28893 .59018 L F
.28702 .59125 m .28615 .59303 L .28828 .59236 L F
.042 0 0 r
.30979 .59848 m .30954 .59932 L .30758 .59968 L F
.326 0 0 r
.31287 .59891 m .30954 .59932 L .30979 .59848 L F
.582 .361 .547 r
.37702 .57504 m .37659 .57776 L .37401 .57807 L F
.553 .336 .539 r
.37948 .57698 m .37702 .57504 L .3791 .57427 L F
.37948 .57698 m .37659 .57776 L .37702 .57504 L F
.523 .619 .889 r
.20326 .62134 m .20328 .61802 L .20176 .61783 L F
.20326 .62134 m .20546 .62108 L .20328 .61802 L F
.148 .529 .92 r
.18492 .60562 m .18458 .60443 L .18213 .60294 L F
.18492 .60562 m .18623 .60601 L .18458 .60443 L F
.513 .305 .534 r
.33865 .59079 m .34067 .59263 L .33836 .59337 L F
.538 .001 0 r
.33865 .59079 m .33914 .5915 L .33624 .59107 L F
.33865 .59079 m .34067 .59263 L .33914 .5915 L F
0 0 0 r
.3057 .57791 m .30483 .58148 L .30463 .5817 L F
.121 0 0 r
.30487 .58234 m .30463 .5817 L .30483 .58148 L F
.054 0 .16 r
.27989 .61601 m .28232 .61276 L .28131 .61473 L F
0 0 0 r
.28232 .61276 m .28486 .60981 L .28372 .61161 L F
0 0 .001 r
.28131 .61473 m .28232 .61276 L .28372 .61161 L F
.686 .254 .218 r
.21282 .54278 m .21469 .54105 L .21071 .54065 L F
.145 0 0 r
.21505 .54194 m .21469 .54105 L .21282 .54278 L F
.21505 .54194 m .21701 .54065 L .21469 .54105 L F
0 0 .489 r
.30686 .54726 m .30735 .54354 L .30473 .54469 L F
.30686 .54726 m .30765 .54671 L .30735 .54354 L F
0 0 .525 r
.30686 .54726 m .30809 .54922 L .30765 .54671 L F
.179 .072 .487 r
.30686 .54726 m .30678 .55011 L .30809 .54922 L F
.178 0 0 r
.25939 .5537 m .2579 .55578 L .25535 .55625 L F
.187 0 0 r
.26 .55513 m .25939 .5537 L .26143 .55242 L F
.26 .55513 m .2579 .55578 L .25939 .5537 L F
.699 .612 .756 r
.36254 .55617 m .36477 .5525 L .36295 .55341 L F
.465 .633 .928 r
.23331 .61996 m .23234 .62209 L .23106 .62018 L F
.431 .594 .911 r
.23331 .61996 m .2342 .62181 L .23234 .62209 L F
.582 .352 .532 r
.35944 .55903 m .36254 .55617 L .36017 .55711 L F
0 0 0 r
.30613 .64336 m .30769 .64069 L .30676 .64254 L F
0 0 .062 r
.30676 .64254 m .30769 .64069 L .30919 .63937 L F
.503 .744 .982 r
.51064 .56717 m .51198 .56528 L .5091 .56553 L F
.51064 .56717 m .51354 .56691 L .51198 .56528 L F
.958 .68 .464 r
.33896 .64032 m .34036 .64402 L .33876 .64275 L F
.091 0 .384 r
.34223 .64012 m .34036 .64402 L .33896 .64032 L F
.34223 .64012 m .34186 .64298 L .34036 .64402 L F
.105 .141 .615 r
.34036 .64402 m .34203 .64614 L .34081 .64635 L F
.55 .097 .129 r
.34186 .64298 m .33876 .64275 L .34036 .64402 L F
.105 .141 .615 r
.34036 .64402 m .34203 .64614 L .34081 .64635 L F
0 0 0 r
.27855 .61774 m .27989 .61601 L .28131 .61473 L F
.117 .585 .917 r
.23386 .63286 m .22857 .63093 L .23151 .63354 L F
.259 0 0 r
.3082 .53123 m .30702 .53089 L .30425 .53076 L F
.291 .727 .966 r
.24373 .54694 m .24616 .54686 L .24787 .5479 L F
.457 .074 .225 r
.24787 .5479 m .24504 .54956 L .24373 .54694 L F
.24787 .5479 m .24737 .54949 L .24504 .54956 L F
.24787 .5479 m .24737 .54949 L .24504 .54956 L F
.503 .846 .996 r
.24787 .5479 m .24616 .54686 L .24864 .54631 L F
.175 0 .124 r
.24944 .5484 m .24787 .5479 L .24864 .54631 L F
.24944 .5484 m .24737 .54949 L .24787 .5479 L F
.24944 .5484 m .24737 .54949 L .24787 .5479 L F
.773 .663 .741 r
.26737 .69854 m .26965 .69505 L .26913 .69689 L F
.467 .34 .624 r
.36131 .54541 m .3626 .54601 L .36312 .54388 L F
.36131 .54541 m .36113 .54649 L .3626 .54601 L F
.374 .816 .951 r
.30029 .52977 m .29954 .53062 L .29801 .53012 L F
.30029 .52977 m .30233 .53013 L .29954 .53062 L F
.477 .757 .992 r
.30456 .56433 m .30396 .56607 L .30224 .56507 L F
.819 1 .812 r
.52329 .53513 m .52046 .53811 L .52137 .53553 L F
.863 .796 .784 r
.52302 .54031 m .52137 .53553 L .52046 .53811 L F
.891 .529 .352 r
.54434 .53506 m .54708 .53783 L .54737 .53501 L F
.699 .425 0 r
.29726 .5555 m .29826 .55939 L .29725 .55552 L F
.379 .641 .958 r
.34179 .58618 m .34099 .58786 L .33951 .58613 L F
.746 .605 .701 r
.54029 .52866 m .53816 .53184 L .54204 .53189 L F
.594 .13 .122 r
.53816 .53184 m .54125 .5336 L .54204 .53189 L F
.978 .68 .324 r
.54204 .53189 m .54125 .5336 L .54216 .53412 L F
.43 .341 .654 r
.33734 .58432 m .33951 .58613 L .33953 .58408 L F
.33734 .58432 m .33798 .58774 L .33951 .58613 L F
.137 0 .33 r
.29578 .59285 m .29356 .59649 L .29377 .59362 L F
.173 .663 .922 r
.32031 .53189 m .3251 .53292 L .32258 .53326 L F
.467 .263 .52 r
.28893 .59018 m .29147 .58694 L .2895 .5878 L F
0 .08 .629 r
.28368 .54742 m .28526 .54863 L .28578 .54701 L F
.597 .533 .754 r
.36113 .54649 m .36468 .54983 L .3626 .54601 L F
.498 .885 .963 r
.29178 .52953 m .28972 .53036 L .28754 .52993 L F
.234 0 .184 r
.19742 .55064 m .19653 .55243 L .19942 .54986 L F
.259 .756 .9 r
.29311 .66233 m .28789 .66222 L .28892 .66024 L F
.742 .952 .646 r
.34196 .56288 m .33939 .56607 L .34016 .56435 L F
.962 .71 .507 r
.34214 .56639 m .34016 .56435 L .33939 .56607 L F
0 .056 .61 r
.29466 .55378 m .29541 .55255 L .29346 .54982 L F
.072 .36 .83 r
.29466 .55378 m .29725 .55552 L .29541 .55255 L F
.413 .844 .948 r
.27676 .69272 m .27714 .69181 L .27486 .69201 L F
.552 .438 .677 r
.27876 .68957 m .27948 .69206 L .27676 .69272 L F
.413 .844 .948 r
.27676 .69272 m .27948 .69206 L .27714 .69181 L F
.617 .549 .755 r
.19135 .58397 m .18889 .58403 L .19082 .58238 L F
.336 .077 .364 r
.19581 .58752 m .19506 .58983 L .19294 .59007 L F
.161 .172 .623 r
.19501 .59248 m .19294 .59007 L .19506 .58983 L F
.19501 .59248 m .19348 .59388 L .19294 .59007 L F
.507 .491 .773 r
.34871 .59378 m .34965 .58987 L .34758 .59036 L F
.34871 .59378 m .35096 .59336 L .34965 .58987 L F
.488 .34 .606 r
.34883 .59661 m .35096 .59336 L .34871 .59378 L F
.652 .452 .6 r
.38847 .5536 m .38834 .5566 L .38555 .55668 L F
.551 .845 .998 r
.38966 .55228 m .38847 .5536 L .3906 .5529 L F
0 0 .344 r
.38956 .55493 m .38847 .5536 L .38966 .55228 L F
.38956 .55493 m .38834 .5566 L .38847 .5536 L F
.391 .56 .901 r
.2065 .60073 m .20557 .60278 L .20348 .60028 L F
.2065 .60073 m .20737 .60276 L .20557 .60278 L F
.445 .33 .629 r
.31539 .62361 m .31318 .62118 L .31522 .62059 L F
.31539 .62361 m .31319 .62455 L .31318 .62118 L F
.55 .383 .608 r
.37419 .58084 m .37158 .58363 L .37183 .58152 L F
.086 .038 .501 r
.29823 .57176 m .29995 .57067 L .29965 .56807 L F
.294 .792 .83 r
.25326 .53285 m .25547 .53226 L .25781 .53213 L F
0 0 0 r
.25547 .53226 m .26009 .53154 L .25781 .53213 L F
.406 .076 .29 r
.17195 .57168 m .1743 .57129 L .17522 .56864 L F
.267 0 .23 r
.17522 .56864 m .17637 .57046 L .17698 .56767 L F
.17522 .56864 m .1743 .57129 L .17637 .57046 L F
.435 .701 .977 r
.36665 .55045 m .36862 .55088 L .36737 .54964 L F
.36737 .54964 m .36862 .55088 L .36665 .55045 L F
.738 .483 .543 r
.52866 .54617 m .52431 .54376 L .5281 .54432 L F
.725 .687 .813 r
.52701 .55683 m .52836 .55974 L .52445 .55918 L F
.599 .501 .714 r
.52753 .56182 m .52445 .55918 L .52836 .55974 L F
.37 .491 .851 r
.52991 .55826 m .52836 .55974 L .52701 .55683 L F
.563 .473 .711 r
.52991 .55826 m .52753 .56182 L .52836 .55974 L F
.78 .964 .659 r
.23886 .75084 m .24053 .74864 L .23955 .74947 L F
.379 .799 .974 r
.23942 .74786 m .24053 .74864 L .23685 .74853 L F
.78 .964 .659 r
.23886 .75084 m .23955 .74947 L .23841 .75044 L F
.689 .256 .215 r
.23841 .75044 m .24053 .74864 L .24244 .75081 L F
.617 .1 0 r
.24244 .75081 m .24053 .74864 L .23942 .74786 L F
.24244 .75081 m .24005 .74848 L .24114 .74801 L F
.24005 .74848 m .23942 .74786 L .24033 .74794 L F
.24005 .74848 m .24033 .74794 L .24114 .74801 L F
.78 .964 .659 r
.23814 .7518 m .23886 .75084 L .23841 .75044 L F
.779 .897 .491 r
.23756 .7527 m .23814 .7518 L .23841 .75044 L F
.102 0 .412 r
.27948 .60572 m .28138 .6021 L .27952 .6034 L F
.901 .798 .737 r
.34538 .65833 m .34433 .65568 L .34645 .65573 L F
.573 .153 .207 r
.34433 .65568 m .34807 .65491 L .34645 .65573 L F
.727 .662 .785 r
.34807 .65491 m .34538 .65833 L .34645 .65573 L F
.034 0 .055 r
.28445 .59405 m .28341 .59597 L .28615 .59303 L F
.921 .866 .768 r
.37769 .5577 m .37598 .55923 L .37891 .55637 L F
.496 .374 .643 r
.35735 .55967 m .35977 .56166 L .35944 .55903 L F
.35735 .55967 m .35711 .56256 L .35977 .56166 L F
.473 .252 .496 r
.3196 .54729 m .3214 .54921 L .32269 .54676 L F
.3196 .54729 m .31928 .5498 L .3214 .54921 L F
.169 .685 .891 r
.26233 .53089 m .26638 .53134 L .26413 .53136 L F
.133 0 0 r
.33206 .54791 m .33331 .54828 L .33581 .54699 L F
0 0 .559 r
.33664 .54739 m .33764 .54936 L .33591 .54711 L F
.33664 .54739 m .33591 .54711 L .33581 .54699 L F
.33664 .54739 m .33581 .54699 L .33331 .54828 L F
.115 .663 .817 r
.3332 .54733 m .33424 .54716 L .33664 .54739 L F
.33299 .54732 m .33424 .54716 L .3332 .54733 L F
.631 .299 .39 r
.33631 .54635 m .33523 .547 L .33424 .54716 L F
.177 0 0 r
.33424 .54716 m .33704 .54755 L .33664 .54739 L F
.133 0 0 r
.33206 .54791 m .3311 .54911 L .33331 .54828 L F
.609 .69 .9 r
.33331 .54828 m .3311 .54911 L .32992 .54735 L F
.33331 .54828 m .32992 .54735 L .33299 .54732 L F
.115 .663 .817 r
.33299 .54732 m .33664 .54739 L .33331 .54828 L F
.926 .921 .789 r
.33424 .54716 m .33347 .55146 L .33526 .54986 L F
.357 0 0 r
.32949 .55097 m .33105 .55158 L .33347 .55146 L F
.32949 .55097 m .33105 .55158 L .33347 .55146 L F
.926 .921 .789 r
.33424 .54716 m .33105 .55158 L .33347 .55146 L F
.214 .468 .884 r
.33664 .54739 m .33831 .54772 L .33764 .54936 L F
.342 .621 .955 r
.33831 .54772 m .33986 .54904 L .33764 .54936 L F
.63 .571 .769 r
.33424 .54716 m .33799 .54935 L .33831 .54772 L F
.33424 .54716 m .33526 .54986 L .33799 .54935 L F
.872 .791 .767 r
.33013 .54925 m .33105 .55158 L .33424 .54716 L F
.631 .299 .39 r
.33523 .547 m .33258 .54861 L .33424 .54716 L F
.177 0 0 r
.33704 .54755 m .33831 .54772 L .33664 .54739 L F
0 0 0 r
.28372 .61161 m .28486 .60981 L .28631 .6085 L F
.403 .048 .246 r
.20305 .5704 m .20057 .57108 L .20127 .56919 L F
.438 .026 .158 r
.20377 .56901 m .20305 .5704 L .20127 .56919 L F
.706 .567 .696 r
.29115 .65568 m .29387 .65271 L .29139 .65304 L F
.79 .802 .863 r
.2782 .67145 m .28142 .66887 L .27954 .66751 L F
.054 .437 .874 r
.38131 .57054 m .38264 .5721 L .37943 .56981 L F
.529 .186 .331 r
.38264 .5721 m .3791 .57427 L .37943 .56981 L F
.38264 .5721 m .38162 .57425 L .3791 .57427 L F
.856 .833 .823 r
.38512 .56896 m .38264 .5721 L .38131 .57054 L F
.262 0 .194 r
.38443 .57319 m .38264 .5721 L .38515 .57192 L F
.38443 .57319 m .38162 .57425 L .38264 .5721 L F
.484 .283 .532 r
.38512 .56896 m .38515 .57192 L .38264 .5721 L F
.94 .641 .445 r
.33896 .64032 m .3367 .6394 L .33617 .63904 L F
.953 .642 .406 r
.33876 .64275 m .3367 .6394 L .33896 .64032 L F
.616 .469 .66 r
.34181 .63679 m .34223 .64012 L .33896 .64032 L F
.42 .809 .988 r
.26401 .70829 m .264 .70834 L .25981 .70815 L F
.717 .742 .872 r
.25981 .70815 m .264 .70834 L .2611 .70882 L F
.515 .888 .971 r
.26562 .70758 m .264 .70834 L .26401 .70829 L F
0 0 .241 r
.26469 .71059 m .264 .70834 L .26562 .70758 L F
.26469 .71059 m .26423 .71141 L .264 .70834 L F
.614 .28 .381 r
.22989 .75105 m .23262 .75102 L .23169 .75355 L F
.852 .831 .358 r
.23188 .75254 m .23262 .75102 L .23169 .75355 L F
.509 .047 .091 r
.23262 .75102 m .23296 .7503 L .22989 .75105 L F
.852 .831 .358 r
.23252 .74909 m .23262 .75102 L .23188 .75254 L F
.509 .047 .091 r
.23262 .75102 m .23617 .74953 L .23296 .7503 L F
.592 .376 .557 r
.33795 .64935 m .34043 .64926 L .34081 .64635 L F
.33795 .64935 m .34043 .64926 L .34081 .64635 L F
.529 .32 .541 r
.34339 .64848 m .34081 .64635 L .34203 .64614 L F
.34339 .64848 m .34043 .64926 L .34081 .64635 L F
.34339 .64848 m .34081 .64635 L .34203 .64614 L F
.34339 .64848 m .34043 .64926 L .34081 .64635 L F
.665 .266 .279 r
.21355 .56542 m .21178 .56746 L .20996 .56541 L F
0 0 0 r
.21327 .56614 m .21355 .56542 L .21597 .56502 L F
.21327 .56614 m .21178 .56746 L .21355 .56542 L F
.548 .445 .689 r
.31356 .64034 m .31644 .64231 L .31567 .64 L F
.31356 .64034 m .31405 .64301 L .31644 .64231 L F
.33 .105 .414 r
.32673 .60686 m .32681 .60523 L .32461 .60486 L F
.32673 .60686 m .32783 .60827 L .32681 .60523 L F
.32673 .60686 m .32569 .60903 L .32783 .60827 L F
.084 0 .143 r
.34779 .58004 m .34806 .57812 L .34744 .58017 L F
0 0 .185 r
.34751 .57814 m .34744 .58017 L .34806 .57812 L F
.052 0 .135 r
.34954 .57758 m .34806 .57812 L .34779 .58004 L F
.17 .248 .703 r
.31861 .59431 m .3208 .59906 L .3178 .59661 L F
.496 .635 .916 r
.3234 .55492 m .32797 .55542 L .32465 .55228 L F
.811 .998 .784 r
.32465 .55228 m .32225 .55508 L .3234 .55492 L F
.863 .414 .093 r
.32225 .55508 m .32502 .55707 L .3234 .55492 L F
.755 .618 .707 r
.53861 .52943 m .53816 .53184 L .54029 .52866 L F
.256 .176 .569 r
.16597 .58442 m .16741 .58399 L .16748 .58049 L F
.292 .284 .679 r
.16597 .58442 m .16811 .58649 L .16741 .58399 L F
.372 .295 .639 r
.16638 .58723 m .16811 .58649 L .16597 .58442 L F
.327 .449 .832 r
.19501 .59248 m .19629 .59579 L .19348 .59388 L F
.987 .89 .563 r
.30492 .59707 m .30545 .59655 L .30586 .59361 L F
.30492 .59707 m .30415 .59961 L .30335 .59881 L F
.30492 .59707 m .30335 .59881 L .30545 .59655 L F
0 0 0 r
.22941 .55262 m .22865 .55298 L .22647 .55344 L F
.314 .777 .644 r
.23071 .55198 m .22941 .55262 L .23194 .55185 L F
.23071 .55198 m .22865 .55298 L .22941 .55262 L F
.265 .742 .936 r
.24528 .6366 m .2475 .63648 L .24352 .6361 L F
.611 .886 .569 r
.53692 .54135 m .53566 .54249 L .53441 .54416 L F
.792 .788 .289 r
.5337 .54585 m .53441 .54416 L .53566 .54249 L F
.815 .663 .694 r
.34191 .55705 m .3444 .55969 L .34054 .55878 L F
.895 .904 .825 r
.3444 .55969 m .34066 .56149 L .34054 .55878 L F
.3444 .55969 m .34196 .56288 L .34066 .56149 L F
.638 .479 .651 r
.34516 .56217 m .34196 .56288 L .3444 .55969 L F
.566 .627 .872 r
.34661 .5589 m .3444 .55969 L .34191 .55705 L F
.402 .17 .444 r
.34661 .5589 m .34591 .56141 L .3444 .55969 L F
.039 .109 .609 r
.3444 .55969 m .34591 .56141 L .34516 .56217 L F
.546 .339 .551 r
.30266 .61864 m .3048 .62074 L .30457 .61771 L F
.30266 .61864 m .3023 .62138 L .3048 .62074 L F
.739 .9 .516 r
.2611 .70882 m .25972 .71066 L .25981 .70815 L F
.334 .033 .297 r
.28912 .55198 m .28758 .5507 L .28999 .55044 L F
.634 .596 .794 r
.27686 .62383 m .27797 .62845 L .27548 .62863 L F
.561 .505 .751 r
.3723 .53731 m .37251 .54113 L .37529 .54037 L F
.549 .347 .558 r
.37251 .54113 m .37504 .54349 L .37529 .54037 L F
.37251 .54113 m .3723 .54411 L .37504 .54349 L F
.487 .256 .489 r
.29343 .63705 m .29579 .63659 L .29616 .63405 L F
.339 .129 .441 r
.29616 .63405 m .29579 .63659 L .29813 .63332 L F
.767 .996 .825 r
.52329 .53513 m .52137 .53553 L .52406 .53329 L F
.149 .353 .81 r
.33723 .56223 m .34016 .56435 L .34196 .56288 L F
.994 .824 .568 r
.34196 .56288 m .34016 .56435 L .34066 .56149 L F
.14 .311 .775 r
.34446 .56503 m .34196 .56288 L .34516 .56217 L F
.878 .907 .845 r
.29641 .66492 m .29205 .66755 L .29607 .66544 L F
.063 0 0 r
.29673 .66537 m .29641 .66492 L .29607 .66544 L F
.997 .857 .559 r
.26531 .70587 m .26648 .70524 L .26562 .70758 L F
.151 0 .195 r
.34054 .55878 m .33723 .56223 L .33788 .55965 L F
.32 .037 .318 r
.30769 .63077 m .31079 .62766 L .31031 .62974 L F
.374 .074 .322 r
.31031 .62974 m .31079 .62766 L .313 .62709 L F
.856 .833 .823 r
.38512 .56896 m .38158 .57042 L .38365 .57003 L F
.436 .721 .985 r
.38512 .56896 m .38775 .56858 L .38594 .56735 L F
.38594 .56735 m .38775 .56858 L .38512 .56896 L F
.982 .707 .422 r
.38365 .57003 m .38515 .57192 L .38512 .56896 L F
.433 .244 .523 r
.38775 .56858 m .38515 .57192 L .38512 .56896 L F
.71 .942 .639 r
.38512 .56896 m .38365 .57003 L .38594 .56735 L F
.443 .465 .787 r
.3842 .56627 m .38575 .56963 L .38365 .57003 L F
.38575 .56963 m .3861 .5704 L .38365 .57003 L F
.856 .833 .823 r
.38158 .57042 m .38131 .57054 L .38365 .57003 L F
.744 .357 .32 r
.26888 .5512 m .26613 .5524 L .26811 .55031 L F
.834 .946 .59 r
.26981 .54729 m .26811 .55031 L .26846 .54856 L F
.836 .957 .617 r
.26811 .55031 m .26613 .5524 L .26846 .54856 L F
.744 .357 .32 r
.26888 .5512 m .26613 .5524 L .26811 .55031 L F
.508 .282 .506 r
.27064 .54989 m .26888 .5512 L .26811 .55031 L F
0 .144 .688 r
.21261 .61174 m .21479 .61392 L .21459 .61503 L F
.222 .635 .955 r
.21479 .61392 m .21636 .61511 L .21459 .61503 L F
0 0 .283 r
.28152 .59683 m .28207 .59767 L .28341 .59597 L F
.28152 .59683 m .28121 .59939 L .28207 .59767 L F
.138 0 .377 r
.34496 .54928 m .34663 .54433 L .34538 .54724 L F
.793 .942 .924 r
.3291 .55651 m .32616 .55833 L .32902 .55841 L F
.3291 .55651 m .32616 .55833 L .32902 .55841 L F
.321 .373 .76 r
.166 .59997 m .16778 .59984 L .16729 .59821 L F
0 0 0 r
.29823 .58714 m .29711 .58933 L .29592 .59013 L F
.28 .228 .62 r
.29711 .58933 m .29578 .59285 L .29592 .59013 L F
.054 .437 .874 r
.38131 .57054 m .37943 .56981 L .37846 .56923 L F
.725 .597 .713 r
.31413 .58713 m .31511 .59159 L .3177 .58771 L F
.369 .581 .923 r
.31804 .59246 m .31624 .59296 L .31378 .5898 L F
.593 .87 .994 r
.14258 .66094 m .14405 .66185 L .14029 .66205 L F
.605 .158 .162 r
.14029 .66205 m .14405 .66185 L .14197 .6637 L F
.985 .807 .584 r
.14197 .6637 m .14405 .66185 L .14258 .66094 L F
.504 .288 .519 r
.30999 .63331 m .30769 .63077 L .31031 .62974 L F
.30999 .63331 m .3075 .6339 L .30769 .63077 L F
.184 0 0 r
.3214 .54921 m .32549 .54746 L .32269 .54676 L F
.442 .669 .959 r
.19629 .59579 m .19952 .59684 L .19764 .59715 L F
0 0 0 r
.34751 .57814 m .34334 .58134 L .34702 .58123 L F
.536 .319 .532 r
.34408 .58654 m .34702 .58123 L .34334 .58134 L F
.34408 .58654 m .34663 .58468 L .34702 .58123 L F
0 0 .185 r
.34751 .57814 m .34702 .58123 L .34744 .58017 L F
.029 0 .353 r
.34702 .58123 m .34809 .58344 L .34744 .58017 L F
.34702 .58123 m .34663 .58468 L .34809 .58344 L F
.275 .051 .381 r
.17698 .56767 m .17962 .56494 L .17758 .56563 L F
.588 .343 .513 r
.29968 .54715 m .29935 .55028 L .29583 .54984 L F
.579 .584 .821 r
.30062 .54323 m .30211 .54673 L .29968 .54715 L F
.503 .27 .494 r
.30179 .54938 m .29968 .54715 L .30211 .54673 L F
.30179 .54938 m .29935 .55028 L .29968 .54715 L F
.181 0 0 r
.35662 .53338 m .36046 .53167 L .35811 .53286 L F
.603 .606 .828 r
.30092 .55369 m .29711 .55101 L .29935 .55028 L F
.119 0 0 r
.30092 .55369 m .29943 .55505 L .29725 .55552 L F
.30092 .55369 m .29943 .55505 L .29725 .55552 L F
.415 .529 .865 r
.30234 .55283 m .30092 .55369 L .29935 .55028 L F
.375 .165 .462 r
.30783 .57682 m .30598 .57519 L .30812 .57459 L F
.30783 .57682 m .3057 .57791 L .30598 .57519 L F
.138 0 .377 r
.34496 .54928 m .34645 .54865 L .34663 .54433 L F
.284 .168 .54 r
.34663 .54433 m .34888 .54299 L .34695 .5435 L F
.34663 .54433 m .34911 .54542 L .34888 .54299 L F
.545 .393 .626 r
.34645 .54865 m .34911 .54542 L .34663 .54433 L F
.559 .392 .611 r
.37695 .58001 m .37401 .57807 L .37659 .57776 L F
.37695 .58001 m .37419 .58084 L .37401 .57807 L F
.484 .725 .978 r
.36737 .54964 m .36862 .55088 L .36516 .54996 L F
.652 .795 .951 r
.36737 .54964 m .36862 .55088 L .36937 .54882 L F
.699 .524 .647 r
.36674 .55205 m .36888 .54941 L .36737 .54964 L F
.36888 .54941 m .36937 .54882 L .36737 .54964 L F
.484 .725 .978 r
.36737 .54964 m .36516 .54996 L .36468 .54983 L F
.747 .99 .883 r
.5205 .56104 m .52445 .55918 L .52205 .56208 L F
.658 .536 .704 r
.52445 .55918 m .52547 .5626 L .52205 .56208 L F
.834 .825 .84 r
.52064 .564 m .5205 .56104 L .52205 .56208 L F
.52017 .56466 m .52024 .56391 L .52064 .564 L F
.52024 .56391 m .5205 .56104 L .52064 .564 L F
.44 .581 .898 r
.51554 .56266 m .51894 .56362 L .51952 .56554 L F
0 .476 .724 r
.51894 .56362 m .51921 .56367 L .51681 .56314 L F
.834 .825 .84 r
.5198 .56427 m .5205 .56104 L .52017 .56466 L F
.51952 .56554 m .51894 .56362 L .5205 .56104 L F
0 .476 .724 r
.51921 .56367 m .52062 .56393 L .51775 .56333 L F
.51921 .56367 m .51775 .56333 L .51681 .56314 L F
.071 .514 .899 r
.522 .56516 m .52062 .56393 L .51921 .56367 L F
.51938 .56384 m .51921 .56367 L .51894 .56362 L F
.522 .56516 m .51921 .56367 L .51938 .56384 L F
.834 .825 .84 r
.51952 .56554 m .5198 .56427 L .52017 .56466 L F
.408 0 0 r
.27722 .54798 m .27526 .54945 L .27283 .54934 L F
.035 0 0 r
.27761 .54873 m .27722 .54798 L .27932 .54666 L F
.27761 .54873 m .27526 .54945 L .27722 .54798 L F
.749 .633 .731 r
.28821 .62776 m .28572 .63097 L .28599 .62834 L F
.251 0 0 r
.25341 .55716 m .2525 .55809 L .25027 .55837 L F
.548 .152 .244 r
.25535 .55625 m .2525 .55809 L .25341 .55716 L F
.483 .821 .999 r
.26035 .70697 m .26401 .70829 L .25981 .70815 L F
.26112 .70692 m .26401 .70829 L .26035 .70697 L F
.759 .897 .939 r
.26531 .70587 m .26401 .70829 L .2605 .70663 L F
.515 .888 .971 r
.26562 .70758 m .26401 .70829 L .26531 .70587 L F
0 0 .473 r
.26685 .70786 m .26562 .70758 L .26531 .70587 L F
0 0 .006 r
.26469 .71059 m .26562 .70758 L .26685 .70786 L F
0 0 .131 r
.2618 .7076 m .25972 .71066 L .26203 .70778 L F
.26039 .70721 m .25972 .71066 L .2618 .7076 L F
.441 0 0 r
.26491 .70851 m .26504 .70846 L .26149 .70759 L F
.26504 .70846 m .26685 .70786 L .26181 .70761 L F
.26504 .70846 m .26181 .70761 L .26149 .70759 L F
.483 .821 .999 r
.2605 .70663 m .26112 .70692 L .26035 .70697 L F
0 0 .131 r
.2605 .70663 m .26039 .70721 L .2618 .7076 L F
.457 0 .033 r
.26685 .70786 m .2659 .70663 L .26164 .70756 L F
.636 .783 .952 r
.26219 .71125 m .26281 .70878 L .26203 .70778 L F
.685 .29 .292 r
.26177 .70772 m .26203 .70778 L .26281 .70878 L F
.2618 .7076 m .26203 .70778 L .26164 .70769 L F
.441 0 0 r
.26491 .70851 m .2617 .70765 L .26281 .70878 L F
.448 .498 .818 r
.25972 .71066 m .26219 .71125 L .26205 .70828 L F
.26183 .70802 m .26205 .70828 L .26203 .70778 L F
.25972 .71066 m .26205 .70828 L .26183 .70802 L F
.441 0 0 r
.2617 .70765 m .26149 .70759 L .26281 .70878 L F
.685 .29 .292 r
.26146 .70756 m .26281 .70878 L .26149 .70759 L F
.759 .897 .939 r
.26531 .70587 m .2605 .70663 L .26149 .70759 L F
.685 .29 .292 r
.2605 .70663 m .26133 .7074 L .26146 .70756 L F
.26133 .7074 m .26281 .70878 L .26146 .70756 L F
.26164 .70769 m .26177 .70772 L .26281 .70878 L F
.457 0 .033 r
.26179 .70761 m .26164 .70756 L .26149 .70759 L F
.2618 .7076 m .26164 .70756 L .26179 .70761 L F
.685 .29 .292 r
.2605 .70663 m .2618 .7076 L .26164 .70769 L F
.457 0 .033 r
.26181 .70761 m .2618 .7076 L .26179 .70761 L F
.26685 .70786 m .26164 .70756 L .26181 .70761 L F
.2659 .70663 m .26531 .70587 L .26328 .70679 L F
.2659 .70663 m .26328 .70679 L .26149 .70759 L F
.586 .063 0 r
.31436 .60009 m .31449 .60161 L .31287 .59891 L F
.31436 .60009 m .31722 .60181 L .31449 .60161 L F
.474 .361 .645 r
.31822 .63199 m .32043 .63243 L .32048 .63015 L F
.31822 .63199 m .31835 .63374 L .32043 .63243 L F
.196 .483 .897 r
.37945 .56806 m .37846 .56923 L .37717 .56818 L F
.37945 .56806 m .38131 .57054 L .37846 .56923 L F
0 0 .115 r
.36692 .60848 m .36447 .6112 L .36439 .60974 L F
.206 0 0 r
.32919 .56603 m .33229 .56605 L .33237 .5654 L F
.057 .284 .774 r
.38834 .54355 m .39076 .54545 L .39012 .54709 L F
.055 .283 .773 r
.39076 .54545 m .3925 .54883 L .39012 .54709 L F
.363 0 0 r
.24373 .54694 m .23948 .54693 L .24167 .54763 L F
.21 0 0 r
.23948 .54693 m .24373 .54694 L .24167 .54763 L F
.365 0 0 r
.23707 .62224 m .24091 .62314 L .23909 .62338 L F
.405 .062 .267 r
.29494 .63855 m .29343 .63705 L .29275 .63923 L F
.29494 .63855 m .29579 .63659 L .29343 .63705 L F
.468 0 0 r
.29657 .65185 m .30004 .65235 L .298 .65243 L F
.366 0 0 r
.30004 .65235 m .30047 .6532 L .298 .65243 L F
.30004 .65235 m .30218 .65304 L .30047 .6532 L F
.056 0 .227 r
.29689 .62434 m .29468 .62766 L .29596 .62749 L F
.132 .306 .774 r
.29468 .62766 m .29689 .62939 L .29596 .62749 L F
.18 .578 .938 r
.26981 .54729 m .26951 .54641 L .26775 .54591 L F
.834 .946 .59 r
.26981 .54729 m .26846 .54856 L .26951 .54641 L F
.701 .981 .896 r
.23832 .55806 m .23779 .55965 L .23991 .55981 L F
.256 0 .128 r
.29178 .54511 m .29231 .5442 L .28876 .54401 L F
.281 .444 .845 r
.20218 .59829 m .20144 .60041 L .19952 .59684 L F
.417 .598 .92 r
.20218 .59829 m .20348 .60028 L .20144 .60041 L F
.277 .083 .427 r
.1996 .57331 m .19843 .57198 L .20057 .57108 L F
.1996 .57331 m .19806 .57423 L .19843 .57198 L F
0 0 .008 r
.29179 .58439 m .29305 .58352 L .29417 .58125 L F
.198 .029 .413 r
.29179 .58439 m .29287 .58599 L .29305 .58352 L F
.29179 .58439 m .29147 .58694 L .29287 .58599 L F
.54 .279 .468 r
.33151 .63389 m .33362 .63601 L .3313 .63613 L F
.492 .415 .697 r
.36811 .59984 m .36884 .60235 L .36664 .60287 L F
.536 .415 .662 r
.36816 .6034 m .36664 .60287 L .36884 .60235 L F
.36816 .6034 m .36683 .6059 L .36664 .60287 L F
.435 .219 .485 r
.31832 .61869 m .32021 .62067 L .32074 .61784 L F
.602 .355 .515 r
.32074 .61784 m .32334 .61769 L .32096 .61533 L F
.59 .355 .528 r
.32334 .61769 m .32364 .61504 L .32096 .61533 L F
.72 .773 .895 r
.34452 .53382 m .34546 .53511 L .34128 .53445 L F
.491 .583 .875 r
.34545 .53155 m .34546 .53511 L .34452 .53382 L F
.34545 .53155 m .34772 .53427 L .34546 .53511 L F
.419 .351 .674 r
.34546 .53511 m .34755 .53683 L .34772 .53427 L F
.745 .668 .775 r
.34622 .53505 m .34525 .54044 L .34684 .54028 L F
.34745 .53729 m .34684 .54028 L .34898 .54006 L F
.34622 .53505 m .34684 .54028 L .34745 .53729 L F
.419 .351 .674 r
.34755 .53683 m .3476 .53688 L .34762 .53651 L F
.34755 .53683 m .34762 .53651 L .34772 .53427 L F
.162 0 .298 r
.28822 .60534 m .28665 .60605 L .28891 .60277 L F
.209 .024 .397 r
.28631 .6085 m .28665 .60605 L .28822 .60534 L F
0 .524 .778 r
.28413 .63053 m .28415 .63064 L .28196 .63019 L F
.561 .007 0 r
.28361 .63043 m .28219 .63104 L .28413 .63053 L F
.27993 .62972 m .28219 .63104 L .28361 .63043 L F
.38 0 0 r
.27817 .63148 m .27979 .63229 L .28219 .63104 L F
.631 .946 .739 r
.28219 .63104 m .27979 .63229 L .28022 .63189 L F
.571 .115 .132 r
.27993 .62972 m .27817 .63148 L .28219 .63104 L F
.631 .946 .739 r
.28219 .63104 m .28022 .63189 L .28201 .63022 L F
.344 0 0 r
.28219 .63104 m .28411 .6304 L .28413 .63053 L F
.28411 .6304 m .28647 .6296 L .28413 .63053 L F
0 .524 .778 r
.28413 .63053 m .28572 .63097 L .28415 .63064 L F
.287 .221 .607 r
.33093 .63892 m .32889 .63707 L .3313 .63613 L F
.33093 .63892 m .32938 .63987 L .32889 .63707 L F
0 0 0 r
.19594 .57486 m .19444 .57683 L .19316 .57784 L F
0 0 .225 r
.19413 .57928 m .19316 .57784 L .19444 .57683 L F
.19413 .57928 m .1929 .58019 L .19316 .57784 L F
.148 .493 .905 r
.2513 .63733 m .25165 .63601 L .24993 .63595 L F
.2513 .63733 m .25397 .63839 L .25165 .63601 L F
.611 .434 .618 r
.31141 .64629 m .31408 .64606 L .31405 .64301 L F
.599 .459 .663 r
.31408 .64606 m .31644 .64231 L .31405 .64301 L F
.595 .593 .82 r
.34004 .60248 m .34134 .60595 L .34326 .60288 L F
.615 .619 .832 r
.34134 .60595 m .34356 .60567 L .34326 .60288 L F
.673 .753 .911 r
.52042 .54579 m .519 .54919 L .51849 .54932 L F
.52042 .54579 m .52198 .54756 L .519 .54919 L F
.697 .622 .769 r
.50412 .55334 m .50059 .55377 L .50027 .55087 L F
.626 .746 .934 r
.25774 .62461 m .25514 .62576 L .25348 .62362 L F
.591 .019 0 r
.30789 .6555 m .30989 .65608 L .30887 .65634 L F
.631 .069 0 r
.30989 .65608 m .31213 .65806 L .30887 .65634 L F
.918 .555 .323 r
.53537 .5283 m .53816 .53184 L .53861 .52943 L F
.113 0 0 r
.19436 .55305 m .19473 .55431 L .19653 .55243 L F
.19436 .55305 m .1926 .55505 L .19473 .55431 L F
.69 .239 .175 r
.17249 .60006 m .17026 .60146 L .16778 .59984 L F
.624 .883 .989 r
.17273 .59831 m .17249 .60006 L .17508 .59907 L F
.841 .994 .746 r
.17273 .59831 m .17026 .60146 L .17249 .60006 L F
0 0 0 r
.26638 .53134 m .26873 .53096 L .27019 .53068 L F
.417 .864 .817 r
.27019 .53068 m .27097 .52999 L .27264 .53021 L F
.27019 .53068 m .26873 .53096 L .27097 .52999 L F
.676 .136 0 r
.34011 .63551 m .34313 .63697 L .34181 .63679 L F
.505 .389 .655 r
.34452 .63936 m .34181 .63679 L .34313 .63697 L F
.34452 .63936 m .34223 .64012 L .34181 .63679 L F
.535 .586 .852 r
.29935 .55028 m .29711 .55101 L .29583 .54984 L F
.147 .405 .851 r
.28546 .6471 m .28624 .64569 L .28442 .64533 L F
0 .487 .855 r
.28546 .6471 m .29112 .6493 L .2881 .64855 L F
.147 .405 .851 r
.28546 .6471 m .2881 .64855 L .28624 .64569 L F
.441 .356 .664 r
.34304 .56935 m .34363 .57217 L .34549 .57104 L F
.34549 .57104 m .34363 .57217 L .34304 .56935 L F
.543 .331 .542 r
.33736 .62111 m .33483 .62414 L .33517 .62147 L F
.548 .152 .244 r
.25535 .55625 m .25497 .55827 L .2525 .55809 L F
0 0 .099 r
.25662 .55699 m .25535 .55625 L .2579 .55578 L F
.25662 .55699 m .25497 .55827 L .25535 .55625 L F
.563 .382 .595 r
.32711 .64865 m .32494 .64623 L .32679 .64527 L F
.32711 .64865 m .32427 .64938 L .32494 .64623 L F
.61 .042 0 r
.35878 .61558 m .36331 .61768 L .35984 .61617 L F
.23 0 0 r
.31833 .57727 m .32065 .57697 L .32198 .57535 L F
.35 .038 .288 r
.32065 .57697 m .32345 .57352 L .32198 .57535 L F
.433 .146 .375 r
.52758 .52823 m .52938 .53035 L .53068 .52756 L F
.52758 .52823 m .52714 .53101 L .52938 .53035 L F
.364 .823 .924 r
.23468 .53438 m .23694 .53386 L .23866 .53407 L F
.299 .785 .903 r
.23866 .53407 m .23694 .53386 L .24094 .53369 L F
.923 .631 .473 r
.50581 .54607 m .50423 .54287 L .5054 .5442 L F
.817 .62 .636 r
.50791 .54343 m .50581 .54607 L .5054 .5442 L F
.773 .663 .741 r
.26737 .69854 m .27141 .69903 L .26965 .69505 L F
.75 .653 .754 r
.26965 .69505 m .27141 .69903 L .27308 .69524 L F
.435 .813 .992 r
.24123 .55071 m .23749 .55038 L .2389 .55048 L F
.381 .583 .922 r
.21634 .62635 m .21703 .62779 L .21813 .6262 L F
.361 .556 .908 r
.21703 .62779 m .22033 .62918 L .21813 .6262 L F
0 .42 .689 r
.326 .65408 m .32695 .65431 L .32761 .65449 L F
0 0 .144 r
.32778 .65689 m .32633 .6586 L .32761 .65449 L F
.32778 .65689 m .32761 .65449 L .32695 .65431 L F
.662 .634 .811 r
.51055 .53899 m .51414 .54072 L .51185 .54168 L F
.638 .48 .652 r
.51185 .54168 m .51414 .54072 L .5113 .54391 L F
.649 .425 .567 r
.30784 .58701 m .3103 .58736 L .31093 .58434 L F
.739 .514 .587 r
.31093 .58434 m .31413 .58713 L .31394 .5846 L F
.31093 .58434 m .3103 .58736 L .31413 .58713 L F
.918 .555 .323 r
.53537 .5283 m .53652 .53164 L .53816 .53184 L F
0 .218 .616 r
.53892 .53227 m .53816 .53184 L .53652 .53164 L F
.53892 .53227 m .54125 .5336 L .53816 .53184 L F
.288 .788 .819 r
.22327 .53747 m .21993 .53816 L .22229 .53755 L F
.412 .816 .98 r
.22229 .53755 m .22623 .5377 L .22327 .53747 L F
.818 .969 .899 r
.28142 .66887 m .28184 .66682 L .27954 .66751 L F
.28142 .66887 m .28353 .6671 L .28184 .66682 L F
.163 0 .316 r
.33816 .56599 m .33513 .57057 L .33506 .56788 L F
.609 .373 .534 r
.31141 .64629 m .31371 .64849 L .31408 .64606 L F
.31141 .64629 m .3111 .64893 L .31371 .64849 L F
.88 .785 .753 r
.54085 .55942 m .53863 .56251 L .5374 .56037 L F
.54085 .55942 m .5374 .56037 L .53968 .56102 L F
.674 .947 .687 r
.54381 .55653 m .54085 .55942 L .54199 .55798 L F
.723 .267 .168 r
.54085 .55942 m .54311 .56146 L .54199 .55798 L F
.54085 .55942 m .53968 .56102 L .54311 .56146 L F
0 0 0 r
.37891 .55637 m .37598 .55923 L .37665 .55847 L F
.832 .655 .664 r
.54576 .54345 m .54925 .54072 L .54778 .53963 L F
.54576 .54345 m .54755 .54408 L .54925 .54072 L F
.571 .377 .579 r
.35766 .62823 m .35521 .6235 L .3572 .62277 L F
.35766 .62823 m .35435 .6299 L .35521 .6235 L F
.593 .507 .726 r
.34004 .60248 m .34182 .59905 L .34032 .59991 L F
.386 .208 .513 r
.31516 .62607 m .31319 .62455 L .31539 .62361 L F
.31516 .62607 m .313 .62709 L .31319 .62455 L F
.57 .29 .452 r
.34043 .64926 m .34017 .65148 L .33795 .64935 L F
.34043 .64926 m .34017 .65148 L .33795 .64935 L F
.153 .588 .932 r
.19462 .61201 m .19406 .61061 L .19206 .60855 L F
.19462 .61201 m .19542 .61171 L .19406 .61061 L F
.616 .299 .41 r
.3476 .53688 m .3517 .53434 L .34772 .53427 L F
.598 .352 .515 r
.35137 .53644 m .35397 .53413 L .3517 .53434 L F
.347 .08 .359 r
.28891 .60277 m .29166 .59982 L .29102 .60202 L F
.15 0 .27 r
.29102 .60202 m .29166 .59982 L .29334 .59879 L F
.626 .239 .291 r
.54381 .55653 m .5458 .55821 L .54199 .55798 L F
.062 .255 .748 r
.54381 .55653 m .54487 .5549 L .54193 .5554 L F
.54381 .55653 m .5458 .55821 L .54487 .5549 L F
.259 .719 .952 r
.31831 .60193 m .31904 .60135 L .31722 .60181 L F
.31831 .60193 m .32064 .60199 L .31904 .60135 L F
.384 .35 .697 r
.1669 .59065 m .16811 .58649 L .16638 .58723 L F
.1669 .59065 m .16847 .59007 L .16811 .58649 L F
.368 .306 .656 r
.1669 .59065 m .16908 .59266 L .16847 .59007 L F
.233 .288 .715 r
.1678 .59296 m .16908 .59266 L .1669 .59065 L F
0 0 .538 r
.54565 .54786 m .54611 .5475 L .546 .54545 L F
.358 0 0 r
.54541 .54865 m .54766 .54848 L .54565 .54786 L F
.343 0 0 r
.54766 .54848 m .54339 .54881 L .54565 .54786 L F
.27 .736 .946 r
.36935 .63332 m .37205 .63324 L .37327 .63385 L F
.36935 .63332 m .37205 .63324 L .37327 .63385 L F
.577 .585 .825 r
.50177 .56269 m .50376 .55947 L .50173 .55998 L F
.50177 .56269 m .50648 .56291 L .50376 .55947 L F
0 0 .322 r
.33232 .60876 m .33238 .60892 L .33072 .60558 L F
.992 .775 .508 r
.33294 .61283 m .33452 .61111 L .33328 .61017 L F
.33328 .61017 m .33452 .61111 L .33294 .61283 L F
0 0 .313 r
.33396 .61045 m .33328 .61017 L .33294 .61283 L F
.633 .544 .736 r
.33703 .60795 m .33452 .61111 L .33232 .60876 L F
0 0 .313 r
.3345 .60918 m .3335 .60999 L .33396 .61045 L F
0 0 .51 r
.33237 .60888 m .33452 .61111 L .33238 .60892 L F
.33232 .60876 m .33317 .60967 L .33237 .60888 L F
.33317 .60967 m .33452 .61111 L .33237 .60888 L F
.883 .463 .052 r
.33232 .60876 m .33452 .61111 L .33328 .61017 L F
0 0 .313 r
.3335 .60999 m .33328 .61017 L .33396 .61045 L F
.967 .775 .593 r
.28789 .66222 m .28892 .66024 L .28681 .66054 L F
.28789 .66222 m .28892 .66024 L .28681 .66054 L F
0 0 0 r
.19806 .57423 m .19444 .57683 L .19594 .57486 L F
.543 .394 .629 r
.36468 .54983 m .36663 .5469 L .3626 .54601 L F
.36468 .54983 m .36737 .54964 L .36663 .5469 L F
.32 .08 .384 r
.36477 .5525 m .36737 .54964 L .36468 .54983 L F
.697 .622 .769 r
.50412 .55334 m .50027 .55087 L .50257 .55004 L F
.596 .646 .87 r
.50538 .54946 m .50412 .55334 L .50257 .55004 L F
.50538 .54946 m .5066 .55274 L .50412 .55334 L F
.698 .446 .539 r
.30758 .59968 m .30393 .60226 L .30415 .59961 L F
.30758 .59968 m .30718 .60203 L .30393 .60226 L F
0 0 .185 r
.30853 .60042 m .30758 .59968 L .30954 .59932 L F
.30853 .60042 m .30718 .60203 L .30758 .59968 L F
.736 .455 .503 r
.38865 .55911 m .38555 .55668 L .38834 .5566 L F
.38865 .55911 m .38514 .55922 L .38555 .55668 L F
.642 .948 .951 r
.33624 .59107 m .33564 .59175 L .33434 .59206 L F
.856 .627 .592 r
.52431 .54376 m .52302 .54031 L .52454 .54105 L F
.332 .045 .318 r
.31835 .63374 m .31558 .63682 L .31778 .63652 L F
.334 .119 .432 r
.32043 .63243 m .31835 .63374 L .31778 .63652 L F
.561 .164 .248 r
.32383 .54038 m .32243 .54283 L .31959 .54274 L F
.266 0 .09 r
.32457 .54217 m .32383 .54038 L .32612 .53997 L F
.32457 .54217 m .32243 .54283 L .32383 .54038 L F
.198 0 .315 r
.29161 .6032 m .28891 .60277 L .29102 .60202 L F
.29161 .6032 m .28822 .60534 L .28891 .60277 L F
.812 .937 .911 r
.32091 .59863 m .32205 .60047 L .3208 .59906 L F
.852 .795 .795 r
.54311 .56146 m .54731 .55943 L .5458 .55821 L F
.54311 .56146 m .54501 .56266 L .54731 .55943 L F
0 .502 .734 r
.27264 .53021 m .27498 .53058 L .27661 .53092 L F
.31 .783 .928 r
.27661 .53092 m .27498 .53058 L .27893 .53058 L F
.076 .239 .729 r
.28732 .63547 m .28647 .63707 L .28533 .63371 L F
0 0 .152 r
.28687 .63833 m .28647 .63707 L .28732 .63547 L F
.28687 .63833 m .28672 .63983 L .28647 .63707 L F
.624 .817 .974 r
.33538 .53297 m .33064 .53238 L .33363 .53188 L F
.605 .839 .988 r
.33775 .53218 m .33538 .53297 L .33363 .53188 L F
0 0 0 r
.29621 .57787 m .29417 .58125 L .29515 .57977 L F
.228 .089 .474 r
.29305 .58352 m .29515 .57977 L .29417 .58125 L F
.017 0 0 r
.29277 .54232 m .28638 .54273 L .28922 .54395 L F
.464 .607 .908 r
.18623 .60601 m .19041 .60864 L .18768 .60609 L F
.347 .595 .938 r
.19041 .60864 m .19148 .60707 L .18768 .60609 L F
.19041 .60864 m .19206 .60855 L .19148 .60707 L F
.202 .589 .944 r
.32225 .55508 m .32776 .55721 L .32502 .55707 L F
.184 0 0 r
.3214 .54921 m .32412 .54869 L .32549 .54746 L F
0 0 0 r
.32549 .54746 m .32412 .54869 L .32559 .54784 L F
.375 0 0 r
.35571 .61108 m .35139 .61113 L .3533 .61251 L F
.181 .299 .749 r
.35139 .61113 m .35247 .61496 L .3533 .61251 L F
.55 .383 .608 r
.37419 .58084 m .37388 .5834 L .37158 .58363 L F
.41 .247 .547 r
.37388 .5834 m .37188 .58695 L .37158 .58363 L F
.554 .584 .838 r
.19581 .58752 m .19135 .58397 L .19318 .58365 L F
.441 .567 .885 r
.19696 .58652 m .19581 .58752 L .19318 .58365 L F
0 0 .146 r
.19696 .58652 m .19506 .58983 L .19581 .58752 L F
.369 .793 .972 r
.25088 .7351 m .25274 .73579 L .25031 .73605 L F
.506 .208 .396 r
.25198 .73781 m .25274 .73579 L .25031 .73605 L F
.25212 .73796 m .25217 .73778 L .25198 .73781 L F
.25217 .73778 m .25274 .73579 L .25198 .73781 L F
0 .099 .653 r
.25212 .73796 m .25031 .73605 L .25088 .7351 L F
.572 .586 .829 r
.25088 .7351 m .24965 .73819 L .24881 .73619 L F
.24965 .73819 m .24965 .73819 L .24965 .73819 L F
.24965 .73819 m .24965 .73819 L .24881 .73619 L F
.336 .028 .287 r
.33066 .57221 m .33001 .57438 L .32777 .57474 L F
.395 .081 .311 r
.3323 .57344 m .33001 .57438 L .33066 .57221 L F
.404 .078 .295 r
.33322 .57158 m .3323 .57344 L .33066 .57221 L F
.747 .99 .883 r
.5205 .56104 m .52363 .55867 L .52445 .55918 L F
.851 .998 .806 r
.52445 .55918 m .52567 .55625 L .52701 .55683 L F
.52445 .55918 m .52363 .55867 L .52567 .55625 L F
.599 .501 .714 r
.52753 .56182 m .52547 .5626 L .52445 .55918 L F
.202 .088 .492 r
.28093 .5451 m .2793 .54398 L .28135 .54302 L F
.28093 .5451 m .27932 .54666 L .2793 .54398 L F
.518 .417 .68 r
.32048 .63015 m .3221 .62683 L .32034 .62725 L F
0 0 0 r
.33798 .58774 m .33839 .58854 L .33951 .58613 L F
.33798 .58774 m .33624 .59107 L .33839 .58854 L F
.256 0 .128 r
.29178 .54511 m .29161 .54572 L .29231 .5442 L F
.558 .028 0 r
.29393 .54204 m .29277 .54232 L .29231 .5442 L F
.289 0 .144 r
.29231 .5442 m .29161 .54572 L .29384 .54493 L F
.565 .535 .781 r
.29231 .5442 m .29477 .54387 L .29393 .54204 L F
.325 0 .004 r
.29231 .5442 m .29384 .54493 L .29477 .54387 L F
.378 .808 .965 r
.24094 .53369 m .24328 .53327 L .24501 .53377 L F
.239 .728 .924 r
.24501 .53377 m .24328 .53327 L .24723 .53365 L F
.328 .719 .982 r
.22735 .63063 m .22749 .62938 L .22552 .62955 L F
0 .366 .835 r
.22735 .63063 m .22857 .63093 L .22749 .62938 L F
.482 0 0 r
.2893 .6408 m .29051 .63967 L .28672 .63983 L F
.334 0 .186 r
.2915 .64168 m .29051 .63967 L .2893 .6408 L F
.2915 .64168 m .29275 .63923 L .29051 .63967 L F
.679 .339 .392 r
.32404 .65821 m .32249 .66087 L .32022 .65836 L F
.57 .216 .329 r
.32723 .65997 m .32404 .65821 L .32633 .6586 L F
.32723 .65997 m .32249 .66087 L .32404 .65821 L F
.562 .18 .275 r
.32085 .56702 m .32544 .56448 L .32281 .56564 L F
.374 .223 .545 r
.32569 .60903 m .32792 .61111 L .32783 .60827 L F
.32569 .60903 m .32573 .6117 L .32792 .61111 L F
0 0 .307 r
.29621 .57787 m .29783 .57684 L .29733 .57422 L F
.109 0 .39 r
.29733 .57422 m .29964 .5733 L .29995 .57067 L F
0 0 .286 r
.29733 .57422 m .29861 .57543 L .29964 .5733 L F
.29733 .57422 m .29783 .57684 L .29861 .57543 L F
.552 .599 .854 r
.34758 .59036 m .3481 .58607 L .34547 .58909 L F
.34758 .59036 m .34965 .58987 L .3481 .58607 L F
.311 .787 .921 r
.5263 .56514 m .52442 .56477 L .522 .56516 L F
.451 .364 .666 r
.52753 .56182 m .5263 .56514 L .52547 .5626 L F
.52753 .56182 m .52799 .56412 L .5263 .56514 L F
.128 0 0 r
.52799 .56412 m .52442 .56477 L .5263 .56514 L F
0 .296 .788 r
.28353 .6671 m .28743 .67052 L .28411 .66681 L F
.609 .596 .813 r
.34128 .53445 m .33881 .53515 L .33775 .53218 L F
.107 0 0 r
.35578 .56796 m .35832 .56813 L .35584 .56801 L F
.661 .637 .815 r
.51434 .55877 m .51681 .55586 L .51604 .56058 L F
.475 .309 .575 r
.51604 .56058 m .51554 .56266 L .51434 .55877 L F
.51604 .56058 m .51827 .56199 L .51554 .56266 L F
.415 .3 .613 r
.51898 .55522 m .51604 .56058 L .51681 .55586 L F
.51898 .55522 m .51961 .55836 L .51604 .56058 L F
.668 .584 .751 r
.51961 .55836 m .51827 .56199 L .51604 .56058 L F
0 .514 .858 r
.32735 .56498 m .32919 .56603 L .32544 .56448 L F
.097 .61 .889 r
.32735 .56498 m .33229 .56605 L .32919 .56603 L F
.434 .264 .55 r
.32889 .57736 m .32877 .58063 L .32607 .58128 L F
.235 .007 .351 r
.32877 .58063 m .32604 .58384 L .32607 .58128 L F
.102 0 .412 r
.27948 .60572 m .28128 .60466 L .28138 .6021 L F
.279 0 .243 r
.27948 .60572 m .281 .60742 L .28128 .60466 L F
.404 .361 .697 r
.1929 .58019 m .19135 .58397 L .19082 .58238 L F
.1929 .58019 m .19318 .58365 L .19135 .58397 L F
.317 .678 .977 r
.22497 .61706 m .22455 .61832 L .22281 .61722 L F
.22497 .61706 m .22661 .61835 L .22455 .61832 L F
.283 .554 .927 r
.26127 .64071 m .26206 .63916 L .26006 .63896 L F
.26127 .64071 m .26396 .64129 L .26206 .63916 L F
.304 .106 .437 r
.16749 .57786 m .16925 .57721 L .16965 .57473 L F
.373 .237 .565 r
.16748 .58049 m .16925 .57721 L .16749 .57786 L F
.416 .606 .926 r
.21286 .62525 m .21367 .62318 L .21191 .62355 L F
.21286 .62525 m .21634 .62635 L .21367 .62318 L F
.774 .581 .638 r
.53347 .55099 m .53048 .55275 L .53177 .54994 L F
.701 .475 .578 r
.53195 .55531 m .53048 .55275 L .53347 .55099 L F
.418 .509 .845 r
.27628 .55625 m .27812 .5573 L .2773 .554 L F
.893 .706 .194 r
.34898 .54006 m .34888 .54299 L .34906 .54049 L F
.659 .618 .796 r
.34906 .54049 m .35137 .53644 L .34898 .54006 L F
.34906 .54049 m .35267 .54052 L .35137 .53644 L F
.569 .233 .36 r
.34888 .54299 m .35267 .54052 L .34906 .54049 L F
.624 .914 .98 r
.23573 .74947 m .23262 .75102 L .23252 .74909 L F
.137 0 0 r
.23497 .74942 m .23573 .74947 L .23252 .74909 L F
.603 .178 .21 r
.23611 .75122 m .23573 .74947 L .23657 .74953 L F
.137 0 0 r
.23665 .74964 m .23573 .74947 L .23497 .74942 L F
.603 .178 .21 r
.23657 .74953 m .23573 .74947 L .23685 .74853 L F
0 0 0 r
.23942 .74786 m .23685 .74853 L .23573 .74947 L F
.741 .525 .602 r
.5113 .54391 m .50786 .54656 L .50791 .54343 L F
.5113 .54391 m .51125 .54663 L .50786 .54656 L F
.502 .883 .969 r
.35343 .66165 m .35412 .66043 L .35565 .66108 L F
.35343 .66165 m .35187 .66125 L .35412 .66043 L F
.591 .894 .988 r
.35565 .66108 m .35412 .66043 L .35666 .65943 L F
.222 0 0 r
.35231 .66189 m .35629 .65963 L .35412 .66043 L F
.35629 .65963 m .35666 .65943 L .35412 .66043 L F
.502 .883 .969 r
.35187 .66125 m .3518 .66124 L .35412 .66043 L F
.501 .316 .561 r
.35565 .66108 m .35322 .66442 L .35343 .66165 L F
.441 .088 .27 r
.20996 .56541 m .20858 .56797 L .20609 .56839 L F
.613 .271 .365 r
.21178 .56746 m .20858 .56797 L .20996 .56541 L F
.114 0 .243 r
.1678 .59296 m .16679 .59578 L .16908 .59266 L F
.052 0 0 r
.2615 .62243 m .26306 .62236 L .26321 .62221 L F
.546 .921 .778 r
.26398 .62148 m .2615 .62243 L .26485 .62046 L F
.052 0 0 r
.2615 .62243 m .26321 .62221 L .26485 .62046 L F
0 0 0 r
.26033 .62258 m .2615 .62243 L .26398 .62148 L F
.25922 .62291 m .2615 .62243 L .26033 .62258 L F
.543 .833 .499 r
.26398 .62148 m .26485 .62046 L .26665 .61855 L F
.699 .979 .9 r
.31509 .56694 m .3112 .57028 L .31271 .5683 L F
.366 .179 .489 r
.36885 .60778 m .36683 .6059 L .36816 .6034 L F
.36885 .60778 m .36692 .60848 L .36683 .6059 L F
.092 0 0 r
.53314 .54913 m .53845 .54848 L .53321 .54868 L F
0 0 0 r
.53321 .54868 m .53314 .54913 L .5337 .54585 L F
.649 .479 .64 r
.33998 .61506 m .34274 .61556 L .34255 .61203 L F
.619 .456 .639 r
.34255 .61203 m .34454 .61376 L .34507 .61149 L F
.34255 .61203 m .34274 .61556 L .34454 .61376 L F
.202 0 .266 r
.34256 .59673 m .34182 .59905 L .34445 .59556 L F
.137 0 .021 r
.18855 .55667 m .18743 .55828 L .19055 .55583 L F
.356 .098 .378 r
.31598 .58059 m .31792 .58005 L .31833 .57727 L F
.501 .281 .512 r
.31792 .58005 m .32065 .57697 L .31833 .57727 L F
.424 0 .101 r
.29797 .62616 m .29689 .62434 L .29596 .62749 L F
.29797 .62616 m .2994 .62417 L .29689 .62434 L F
.093 0 .304 r
.30552 .64541 m .30613 .64336 L .30676 .64254 L F
.041 0 .325 r
.27841 .62048 m .27686 .62383 L .2772 .62144 L F
.529 .703 .95 r
.20817 .79188 m .20806 .79442 L .20628 .79279 L F
.20817 .79188 m .21049 .79408 L .20806 .79442 L F
.004 0 0 r
.20806 .79442 m .20738 .79496 L .20538 .7955 L F
.20806 .79442 m .21049 .79408 L .20738 .79496 L F
0 .018 .578 r
.27836 .62592 m .27797 .62845 L .27686 .62383 L F
.034 .235 .737 r
.27993 .62972 m .27797 .62845 L .27836 .62592 L F
.439 .366 .678 r
.33001 .57438 m .33047 .57704 L .32777 .57474 L F
.41 .365 .697 r
.32777 .57474 m .33047 .57704 L .32889 .57736 L F
0 0 0 r
.21897 .53925 m .21993 .53816 L .21701 .54065 L F
.251 0 0 r
.22229 .53755 m .21993 .53816 L .21897 .53925 L F
.828 .444 .326 r
.33576 .63198 m .34011 .63551 L .33797 .63302 L F
.652 .693 .875 r
.3388 .53988 m .34053 .5421 L .3426 .54076 L F
0 0 .131 r
.2605 .70663 m .25981 .70815 L .25972 .71066 L F
0 .284 .785 r
.30586 .59361 m .30772 .59438 L .30572 .59279 L F
.30586 .59361 m .30867 .59617 L .30772 .59438 L F
.275 .028 .346 r
.30586 .59361 m .30772 .59438 L .30867 .59617 L F
.30586 .59361 m .30545 .59655 L .30772 .59438 L F
.726 .881 .479 r
.21071 .54065 m .20846 .54447 L .2106 .54346 L F
.475 .286 .543 r
.21071 .54065 m .2106 .54346 L .21282 .54278 L F
.21071 .54065 m .2106 .54346 L .21282 .54278 L F
.558 .828 .473 r
.27044 .69406 m .27273 .6914 L .26965 .69505 L F
.616 .147 .117 r
.27308 .69524 m .26965 .69505 L .27273 .6914 L F
.262 .237 .641 r
.27504 .69505 m .27273 .6914 L .27486 .69201 L F
.27504 .69505 m .27308 .69524 L .27282 .6924 L F
.27504 .69505 m .27282 .6924 L .27291 .69239 L F
.27504 .69505 m .27281 .69227 L .27328 .69226 L F
.452 .311 .598 r
.27714 .69431 m .27504 .69505 L .27486 .69201 L F
.175 0 0 r
.27507 .69298 m .2749 .6922 L .27274 .69358 L F
.2749 .6922 m .27486 .69201 L .27455 .69224 L F
.2749 .6922 m .27455 .69224 L .27274 .69358 L F
.262 .237 .641 r
.27291 .69239 m .27282 .6924 L .27281 .69227 L F
.27328 .69226 m .27281 .69227 L .27273 .6914 L F
.476 .029 .108 r
.27455 .69224 m .27044 .69406 L .27274 .69358 L F
.27486 .69201 m .27436 .69224 L .27455 .69224 L F
.27436 .69224 m .27044 .69406 L .27455 .69224 L F
.27486 .69201 m .27273 .6914 L .27044 .69406 L F
.991 .842 .597 r
.54766 .54848 m .54812 .55258 L .54885 .55017 L F
.954 .688 .494 r
.51125 .54663 m .51297 .5501 L .51129 .54869 L F
.614 .395 .56 r
.51297 .5501 m .5091 .55274 L .51129 .54869 L F
.51297 .5501 m .51208 .5537 L .5091 .55274 L F
.51297 .5501 m .51295 .55266 L .51208 .5537 L F
.611 .354 .503 r
.51297 .5501 m .51553 .55136 L .51295 .55266 L F
.51297 .5501 m .51586 .55134 L .51553 .55136 L F
.583 .413 .616 r
.25139 .72668 m .25401 .72657 L .25387 .72355 L F
.25139 .72668 m .25401 .72657 L .25387 .72355 L F
.662 .634 .811 r
.51055 .53899 m .51274 .53712 L .51414 .54072 L F
.583 .662 .893 r
.51391 .53785 m .51414 .54072 L .51274 .53712 L F
.51391 .53785 m .51667 .54012 L .51414 .54072 L F
.582 .352 .532 r
.35944 .55903 m .36252 .55882 L .36254 .55617 L F
.699 .612 .756 r
.36254 .55617 m .36584 .55634 L .36477 .5525 L F
.204 0 .007 r
.36252 .55882 m .36584 .55634 L .36254 .55617 L F
.258 0 0 r
.27876 .68957 m .27486 .69201 L .27714 .69181 L F
.51 .098 .196 r
.2788 .69146 m .27876 .68957 L .27714 .69181 L F
.898 .569 .081 r
.2788 .69146 m .27948 .69206 L .27876 .68957 L F
.63 .896 .578 r
.35967 .54106 m .35716 .54348 L .35688 .54418 L F
.233 .715 .933 r
.35688 .54418 m .35716 .54348 L .35385 .5433 L F
.256 .085 .447 r
.37188 .58695 m .37196 .58961 L .37001 .59039 L F
.167 .043 .456 r
.37196 .58961 m .37027 .59298 L .37001 .59039 L F
.727 .662 .785 r
.34807 .65491 m .34946 .65852 L .34538 .65833 L F
.508 .312 .55 r
.34815 .6599 m .34538 .65833 L .34946 .65852 L F
0 .099 .649 r
.34807 .65491 m .35031 .65696 L .34946 .65852 L F
.547 0 0 r
.34638 .65715 m .34846 .65882 L .34864 .65891 L F
.404 .362 .698 r
.35024 .65708 m .349 .65874 L .34946 .65852 L F
.35031 .65696 m .35011 .65724 L .35024 .65708 L F
.35011 .65724 m .349 .65874 L .35024 .65708 L F
.547 0 0 r
.34638 .65715 m .34864 .65891 L .34889 .65879 L F
.518 .093 .172 r
.34715 .65613 m .35031 .65696 L .34807 .65491 L F
.34638 .65715 m .34864 .65704 L .34715 .65613 L F
.34864 .65704 m .35031 .65696 L .34715 .65613 L F
.581 .142 .172 r
.34665 .65585 m .34638 .65715 L .34433 .65568 L F
.573 .153 .207 r
.34433 .65568 m .34638 .65715 L .34715 .65613 L F
.34602 .65533 m .34663 .65576 L .34807 .65491 L F
.653 .624 .808 r
.34662 .65576 m .34665 .65585 L .34433 .65568 L F
.216 0 .089 r
.34679 .65587 m .34671 .65586 L .34672 .65582 L F
.34671 .65586 m .34665 .65585 L .34666 .65583 L F
.573 .153 .207 r
.34433 .65568 m .34715 .65613 L .34602 .65533 L F
.653 .624 .808 r
.34517 .65056 m .34662 .65576 L .34433 .65568 L F
.573 .153 .207 r
.34663 .65576 m .34715 .65613 L .3474 .65579 L F
.34663 .65576 m .3474 .65579 L .34807 .65491 L F
.216 0 .089 r
.34907 .6562 m .34679 .65587 L .34751 .6526 L F
.34679 .65587 m .34672 .65582 L .34751 .6526 L F
.34671 .65586 m .34666 .65583 L .34751 .6526 L F
.404 .362 .698 r
.349 .65874 m .34815 .6599 L .34942 .65856 L F
.34894 .65883 m .35025 .65968 L .34815 .6599 L F
.349 .65874 m .34942 .65856 L .34946 .65852 L F
.547 0 0 r
.34638 .65715 m .35025 .65968 L .35031 .65696 L F
.959 .786 .625 r
.34961 .6578 m .34846 .65882 L .34907 .6562 L F
.547 0 0 r
.34889 .65879 m .34864 .65891 L .35025 .65968 L F
.959 .786 .625 r
.35025 .65968 m .34864 .65891 L .34961 .6578 L F
.34864 .65891 m .34846 .65882 L .34961 .6578 L F
.705 .464 .556 r
.28219 .67975 m .27972 .67658 L .27961 .6806 L F
.28219 .67975 m .28242 .67706 L .27972 .67658 L F
.457 .706 .975 r
.18458 .60443 m .18623 .60601 L .18695 .60423 L F
.245 .457 .868 r
.18623 .60601 m .18768 .60609 L .18695 .60423 L F
.34 .421 .799 r
.21 .60418 m .20895 .60643 L .20737 .60276 L F
.302 .376 .772 r
.21 .60418 m .21133 .60812 L .20895 .60643 L F
.505 .542 .828 r
.31747 .56845 m .32073 .57099 L .31838 .56797 L F
.654 .496 .658 r
.33483 .62414 m .33236 .62673 L .33152 .62362 L F
.701 .463 .56 r
.30234 .55283 m .30666 .55273 L .30678 .55011 L F
.044 0 .393 r
.30678 .55011 m .30776 .55172 L .30809 .54922 L F
.30678 .55011 m .30666 .55273 L .30776 .55172 L F
.563 .569 .817 r
.49925 .5606 m .50173 .55998 L .4979 .55806 L F
.503 .313 .556 r
.22914 .7731 m .22908 .77594 L .2267 .77633 L F
.22914 .7731 m .22908 .77594 L .2267 .77633 L F
.011 0 0 r
.27218 .69569 m .27504 .69505 L .27419 .69662 L F
0 .347 .797 r
.27401 .6965 m .27218 .69569 L .27419 .69662 L F
.75 .653 .754 r
.27088 .69512 m .27308 .69524 L .27218 .69569 L F
.011 0 0 r
.27218 .69569 m .27308 .69524 L .27504 .69505 L F
0 .347 .797 r
.27044 .69406 m .27218 .69569 L .27401 .6965 L F
.75 .653 .754 r
.26965 .69505 m .27088 .69512 L .27218 .69569 L F
0 0 0 r
.26665 .61855 m .26686 .61946 L .26879 .61787 L F
.26665 .61855 m .26485 .62046 L .26686 .61946 L F
.707 .646 .786 r
.31413 .58713 m .3177 .58771 L .31626 .58409 L F
.323 .421 .807 r
.31626 .58409 m .3177 .58771 L .31911 .58589 L F
.421 .561 .889 r
.3177 .58771 m .32002 .58776 L .31911 .58589 L F
.204 0 .007 r
.36252 .55882 m .36479 .55817 L .36584 .55634 L F
.531 .541 .811 r
.36584 .55634 m .36674 .55205 L .36477 .5525 L F
.735 .699 .817 r
.36783 .53753 m .3723 .53731 L .37087 .53677 L F
.217 0 0 r
.37441 .5375 m .37087 .53677 L .3723 .53731 L F
.561 .505 .751 r
.3723 .53731 m .37529 .54037 L .37441 .5375 L F
.008 0 0 r
.20846 .54447 m .20873 .54524 L .2106 .54346 L F
.20846 .54447 m .20657 .54598 L .20873 .54524 L F
.115 0 0 r
.24504 .54956 m .24348 .5503 L .24123 .55071 L F
.538 .585 .85 r
.24616 .54686 m .24504 .54956 L .24373 .54694 L F
.24616 .54686 m .24737 .54949 L .24504 .54956 L F
.061 0 0 r
.24737 .54949 m .24348 .5503 L .24504 .54956 L F
.964 .689 .463 r
.24373 .54694 m .24504 .54956 L .24234 .54735 L F
.689 .677 .834 r
.51088 .55651 m .51185 .55953 L .50808 .55878 L F
.687 .641 .798 r
.51292 .55499 m .51185 .55953 L .51088 .55651 L F
.51292 .55499 m .51434 .55877 L .51185 .55953 L F
.863 .796 .784 r
.52302 .54031 m .5192 .53983 L .52137 .53553 L F
.885 .674 .612 r
.52302 .54031 m .52095 .54327 L .5192 .53983 L F
.856 .627 .592 r
.52431 .54376 m .52095 .54327 L .52302 .54031 L F
.48 .776 .996 r
.22513 .56251 m .22666 .56167 L .22318 .5612 L F
.624 .83 .979 r
.22318 .5612 m .22254 .56247 L .22513 .56251 L F
.572 .172 .245 r
.33102 .54085 m .33031 .54099 L .32612 .53997 L F
0 .526 .843 r
.32612 .53997 m .32976 .54122 L .32847 .54054 L F
.23 0 0 r
.33226 .54159 m .32877 .5406 L .32976 .54122 L F
.32877 .5406 m .32833 .54047 L .32847 .54054 L F
.32877 .5406 m .32847 .54054 L .32976 .54122 L F
.572 .172 .245 r
.33018 .54102 m .32457 .54217 L .32961 .54085 L F
.138 0 0 r
.33018 .54102 m .32412 .54424 L .32457 .54217 L F
.33102 .54085 m .33048 .54111 L .33018 .54102 L F
.33048 .54111 m .32412 .54424 L .33018 .54102 L F
.23 0 0 r
.32877 .5406 m .32924 .54074 L .32833 .54047 L F
.138 0 0 r
.33048 .54111 m .3265 .54365 L .32412 .54424 L F
.33102 .54085 m .33055 .54114 L .33048 .54111 L F
.33055 .54114 m .3265 .54365 L .33048 .54111 L F
.769 .614 .686 r
.3317 .54152 m .3265 .54365 L .33055 .54114 L F
.23 0 0 r
.33226 .54159 m .33191 .54155 L .33051 .54112 L F
.33226 .54159 m .33051 .54112 L .32987 .54091 L F
.769 .614 .686 r
.3317 .54152 m .33055 .54114 L .33102 .54085 L F
.23 0 0 r
.32987 .54091 m .33051 .54112 L .32877 .5406 L F
.32924 .54074 m .33117 .54135 L .32857 .54054 L F
.33117 .54135 m .3317 .54152 L .33123 .54137 L F
.33117 .54135 m .33123 .54137 L .32857 .54054 L F
.32924 .54074 m .32857 .54054 L .32833 .54047 L F
.33191 .54155 m .3317 .54152 L .32877 .5406 L F
.572 .172 .245 r
.32961 .54085 m .32457 .54217 L .32602 .54011 L F
.33031 .54099 m .33018 .54102 L .32961 .54085 L F
.32847 .54054 m .32602 .54011 L .32612 .53997 L F
.33031 .54099 m .32602 .54011 L .32847 .54054 L F
0 .526 .843 r
.32612 .53997 m .32847 .54054 L .32833 .54047 L F
.065 .241 .735 r
.33544 .56194 m .33632 .5613 L .33412 .5593 L F
0 0 0 r
.33544 .56194 m .33347 .56391 L .33632 .5613 L F
.477 .171 .367 r
.36663 .5469 m .36868 .54726 L .37049 .54455 L F
.497 .193 .38 r
.37049 .54455 m .36868 .54726 L .37176 .54613 L F
.502 .193 .376 r
.37049 .54455 m .37176 .54613 L .3723 .54411 L F
.599 .757 .954 r
.29588 .53037 m .29178 .52953 L .29391 .52905 L F
.419 .744 .993 r
.29801 .53012 m .29588 .53037 L .29391 .52905 L F
.813 .815 .852 r
.51952 .56554 m .51894 .56362 L .51602 .56612 L F
.071 .514 .899 r
.522 .56516 m .51894 .56362 L .51952 .56554 L F
.359 .517 .878 r
.20893 .62215 m .20982 .62016 L .20792 .62046 L F
.20893 .62215 m .21191 .62355 L .20982 .62016 L F
.476 .224 .453 r
.34998 .57467 m .35245 .57412 L .35256 .57149 L F
.093 0 .195 r
.35256 .57149 m .35462 .57041 L .35578 .56796 L F
.426 .185 .443 r
.35256 .57149 m .35456 .57336 L .35462 .57041 L F
.35256 .57149 m .35245 .57412 L .35456 .57336 L F
.508 .282 .506 r
.27064 .54989 m .27035 .55272 L .26888 .5512 L F
.46 .317 .6 r
.25609 .72583 m .25401 .72657 L .25387 .72355 L F
.25609 .72583 m .25401 .72657 L .25387 .72355 L F
.495 .067 .157 r
.29346 .54982 m .28912 .55198 L .28999 .55044 L F
.29346 .54982 m .29151 .55205 L .28912 .55198 L F
.688 .296 .299 r
.29346 .54982 m .29541 .55255 L .29151 .55205 L F
.412 .816 .98 r
.22229 .53755 m .22504 .53709 L .22459 .53764 L F
.139 0 0 r
.22238 .53861 m .22504 .53709 L .22229 .53755 L F
.56 .911 .707 r
.22566 .53634 m .22504 .53709 L .22238 .53861 L F
.22641 .53582 m .22504 .53709 L .22566 .53634 L F
.412 .816 .98 r
.22459 .53764 m .22504 .53709 L .22623 .5377 L F
.607 .909 .982 r
.22623 .5377 m .22641 .53582 L .22828 .53702 L F
.22623 .5377 m .22504 .53709 L .22641 .53582 L F
.891 .529 .352 r
.54434 .53506 m .5445 .53874 L .54708 .53783 L F
.823 .793 .824 r
.5445 .53874 m .54778 .53963 L .54708 .53783 L F
.983 .748 .505 r
.30415 .59961 m .30393 .60226 L .30236 .60123 L F
.981 .911 .605 r
.30335 .59881 m .30415 .59961 L .30236 .60123 L F
.768 .496 .523 r
.34557 .59632 m .34843 .59899 L .34883 .59661 L F
.488 .34 .606 r
.34883 .59661 m .35104 .59604 L .35096 .59336 L F
.429 .187 .443 r
.34883 .59661 m .34843 .59899 L .35104 .59604 L F
.221 0 0 r
.3601 .54262 m .35967 .54106 L .35933 .53856 L F
.3601 .54262 m .35716 .54348 L .35967 .54106 L F
.887 .459 .124 r
.53177 .54994 m .52866 .54617 L .53236 .54775 L F
.53177 .54994 m .52998 .54898 L .52866 .54617 L F
.963 .853 .685 r
.53177 .54994 m .52927 .55021 L .52998 .54898 L F
.53177 .54994 m .53048 .55275 L .52927 .55021 L F
.152 0 .22 r
.29515 .57977 m .29783 .57684 L .29621 .57787 L F
.517 .776 .991 r
.30456 .56433 m .30873 .56536 L .30644 .56592 L F
.493 .29 .532 r
.27954 .66751 m .28184 .66682 L .27971 .66467 L F
.779 .507 .526 r
.25399 .54694 m .25368 .54964 L .24944 .5484 L F
.528 .283 .487 r
.25634 .54877 m .25368 .54964 L .25399 .54694 L F
.25634 .54877 m .25368 .54964 L .25399 .54694 L F
.566 .627 .872 r
.34661 .5589 m .34191 .55705 L .3463 .55647 L F
0 0 .422 r
.34844 .55377 m .34661 .5589 L .3463 .55647 L F
.719 .357 .363 r
.33623 .61505 m .33915 .61698 L .33998 .61506 L F
.515 .184 .345 r
.33998 .61506 m .33915 .61698 L .34204 .61638 L F
.573 .096 .084 r
.34204 .61638 m .34274 .61556 L .33998 .61506 L F
.375 0 0 r
.35571 .61108 m .35399 .61167 L .35139 .61113 L F
.608 .948 .79 r
.35616 .61005 m .35571 .61108 L .35756 .61077 L F
.35616 .61005 m .35399 .61167 L .35571 .61108 L F
.364 .44 .806 r
.30295 .60901 m .30496 .60887 L .30411 .60691 L F
.333 .401 .783 r
.30295 .60901 m .30575 .61092 L .30411 .60691 L F
.44 .397 .714 r
.30403 .61171 m .30575 .61092 L .30295 .60901 L F
.545 .395 .628 r
.36663 .5469 m .36937 .54882 L .36868 .54726 L F
.36663 .5469 m .36737 .54964 L .36937 .54882 L F
.171 0 0 r
.24404 .56023 m .24211 .56022 L .23991 .55981 L F
.185 0 .123 r
.22647 .55344 m .22508 .55588 L .22337 .55629 L F
0 0 0 r
.2268 .55452 m .22647 .55344 L .22865 .55298 L F
.2268 .55452 m .22508 .55588 L .22647 .55344 L F
.545 .578 .839 r
.39482 .55114 m .39315 .55 L .3925 .54883 L F
.39482 .55114 m .39296 .55234 L .39315 .55 L F
.289 .103 .446 r
.31465 .55175 m .31318 .55004 L .31457 .54913 L F
.31465 .55175 m .31281 .55275 L .31318 .55004 L F
.8 .307 0 r
.34888 .62794 m .34689 .62713 L .34617 .62581 L F
.144 .64 .912 r
.26533 .64175 m .2661 .64136 L .26396 .64129 L F
.26533 .64175 m .26742 .64196 L .2661 .64136 L F
.551 .408 .64 r
.34465 .5524 m .34645 .54865 L .34496 .54928 L F
.576 .449 .67 r
.31394 .5846 m .31626 .58409 L .31598 .58059 L F
.583 .476 .697 r
.31394 .5846 m .31413 .58713 L .31626 .58409 L F
.526 .398 .648 r
.39105 .55851 m .38834 .5566 L .38956 .55493 L F
.39105 .55851 m .38865 .55911 L .38834 .5566 L F
.876 .864 .824 r
.34028 .60723 m .34059 .61028 L .33849 .61156 L F
0 0 .408 r
.33978 .61289 m .33849 .61156 L .34059 .61028 L F
0 0 .355 r
.34219 .6068 m .34059 .61028 L .34028 .60723 L F
0 0 0 r
.3423 .61001 m .33978 .61289 L .34059 .61028 L F
.579 .191 .271 r
.33412 .5593 m .33352 .56145 L .33 .56139 L F
.641 .251 .29 r
.33632 .5613 m .33352 .56145 L .33412 .5593 L F
.137 0 .33 r
.29578 .59285 m .29571 .59536 L .29356 .59649 L F
.162 0 .394 r
.29571 .59536 m .29334 .59879 L .29356 .59649 L F
.818 .395 .238 r
.33367 .5543 m .33568 .55587 L .33786 .55611 L F
.339 0 0 r
.33568 .55587 m .33817 .55645 L .33786 .55611 L F
.533 .323 .541 r
.33987 .62315 m .33736 .62111 L .34093 .62191 L F
.366 0 0 r
.34093 .62191 m .34232 .62262 L .33987 .62315 L F
0 .486 .864 r
.34625 .62422 m .34554 .62335 L .34093 .62191 L F
.366 0 0 r
.34093 .62191 m .34554 .62335 L .34232 .62262 L F
.458 .259 .522 r
.34463 .64193 m .34223 .64012 L .34452 .63936 L F
.34463 .64193 m .34186 .64298 L .34223 .64012 L F
.593 .628 .855 r
.29673 .66537 m .29906 .66763 L .29661 .66833 L F
.529 .857 .996 r
.29661 .66833 m .2977 .66659 L .29667 .66768 L F
.29661 .66833 m .29906 .66763 L .2977 .66659 L F
.247 .471 .878 r
.20176 .61783 m .20245 .61615 L .20029 .61612 L F
.20176 .61783 m .20328 .61802 L .20245 .61615 L F
.817 .923 .907 r
.50027 .55087 m .49707 .54997 L .49863 .54876 L F
.50027 .55087 m .49639 .55238 L .49643 .54979 L F
.622 .714 .912 r
.50257 .55004 m .50027 .55087 L .49863 .54876 L F
.718 .664 .796 r
.50237 .54844 m .50257 .55004 L .49863 .54876 L F
.699 .751 .892 r
.50038 .54689 m .50237 .54844 L .49863 .54876 L F
.476 .324 .594 r
.49863 .55191 m .50014 .54757 L .49863 .54876 L F
.50014 .54757 m .50038 .54689 L .49863 .54876 L F
.817 .923 .907 r
.49707 .54997 m .49643 .54979 L .49863 .54876 L F
0 0 .485 r
.32734 .6597 m .32633 .6586 L .32778 .65689 L F
.32734 .6597 m .32723 .65997 L .32633 .6586 L F
.508 .524 .808 r
.5192 .53983 m .51791 .54378 L .51667 .54012 L F
.5192 .53983 m .52095 .54327 L .51791 .54378 L F
.526 .31 .529 r
.52042 .54579 m .51791 .54378 L .52095 .54327 L F
.52042 .54579 m .51947 .54678 L .51791 .54378 L F
.575 .33 .507 r
.51791 .54378 m .51947 .54678 L .51523 .54743 L F
.444 .209 .462 r
.37948 .57698 m .37695 .58001 L .37659 .57776 L F
0 0 0 r
.51127 .53842 m .51274 .53712 L .51055 .53899 L F
.438 .83 .612 r
.21897 .53925 m .21701 .54065 L .21505 .54194 L F
.371 .179 .485 r
.14258 .66094 m .14029 .66205 L .14197 .6637 L F
.602 .541 .758 r
.53959 .54023 m .54032 .54409 L .54436 .54243 L F
0 0 0 r
.53999 .54039 m .53692 .54135 L .53959 .54023 L F
.602 .541 .758 r
.53959 .54023 m .54436 .54243 L .54227 .54087 L F
0 0 0 r
.53999 .54039 m .53566 .54249 L .53692 .54135 L F
.956 .785 .337 r
.54025 .54678 m .53965 .54607 L .54032 .54409 L F
.234 0 .1 r
.54032 .54409 m .54199 .54511 L .54436 .54243 L F
.54032 .54409 m .53965 .54607 L .54199 .54511 L F
.533 .523 .79 r
.51827 .56199 m .51894 .56362 L .51554 .56266 L F
0 0 0 r
.2499 .55424 m .24862 .55557 L .25146 .55277 L F
.817 .555 .543 r
.31002 .58881 m .31413 .58713 L .3103 .58736 L F
.272 .42 .828 r
.18325 .60129 m .18323 .60328 L .18213 .60294 L F
.009 .465 .87 r
.18213 .60294 m .18323 .60328 L .18322 .60328 L F
.271 .418 .827 r
.18213 .60294 m .18458 .60443 L .18422 .60359 L F
.18222 .60282 m .18323 .60321 L .18325 .60129 L F
.692 .789 .925 r
.18322 .60328 m .18323 .60328 L .18325 .60129 L F
.271 .418 .827 r
.18323 .60321 m .18422 .60359 L .18325 .60129 L F
.18322 .60328 m .18422 .60359 L .18222 .60282 L F
.692 .789 .925 r
.1788 .60083 m .18322 .60328 L .18325 .60129 L F
0 .322 .715 r
.17796 .60063 m .18322 .60328 L .1788 .60083 L F
.18322 .60328 m .18323 .60328 L .18322 .60328 L F
.18322 .60328 m .18322 .60328 L .1788 .60083 L F
.271 .418 .827 r
.18213 .60294 m .18322 .60328 L .18222 .60282 L F
.009 .465 .87 r
.18213 .60294 m .18322 .60328 L .17796 .60063 L F
.526 .332 .56 r
.32334 .61769 m .32595 .6144 L .32364 .61504 L F
0 0 0 r
.21732 .56492 m .21597 .56502 L .21837 .56541 L F
.21732 .56492 m .21327 .56614 L .21597 .56502 L F
.35099 .54973 m .35023 .55192 L .3483 .55293 L F
.35293 .54879 m .35023 .55192 L .35099 .54973 L F
.315 .505 .884 r
.19542 .61171 m .19775 .61507 L .19866 .61332 L F
.297 .483 .872 r
.19775 .61507 m .20029 .61612 L .19866 .61332 L F
0 0 .329 r
.30539 .59023 m .30469 .58549 L .30784 .58701 L F
.30539 .59023 m .30569 .58872 L .30469 .58549 L F
0 0 .345 r
.30539 .59023 m .30633 .59109 L .30569 .58872 L F
.30539 .59023 m .30572 .59279 L .30633 .59109 L F
.576 .405 .612 r
.31567 .64 m .31778 .63652 L .31558 .63682 L F
.555 .004 0 r
.23952 .63468 m .23495 .63314 L .23693 .63428 L F
.656 .576 .753 r
.34356 .60567 m .34603 .6021 L .34326 .60288 L F
.34356 .60567 m .34696 .60561 L .34603 .6021 L F
.666 .486 .632 r
.34316 .60825 m .34696 .60561 L .34356 .60567 L F
.251 .044 .391 r
.32885 .64238 m .32679 .64527 L .32653 .64299 L F
.801 .503 .486 r
.53267 .53021 m .53537 .5283 L .53253 .52795 L F
.53267 .53021 m .53652 .53164 L .53537 .5283 L F
.501 .416 .691 r
.5243 .54629 m .52239 .55006 L .52198 .54756 L F
.5243 .54629 m .52492 .54937 L .52239 .55006 L F
.679 .589 .747 r
.52492 .54937 m .52251 .552 L .52239 .55006 L F
.519 .183 .339 r
.20609 .56839 m .20305 .5704 L .20377 .56901 L F
.393 .17 .453 r
.37695 .58001 m .37388 .5834 L .37419 .58084 L F
.577 .043 0 r
.36989 .52911 m .36926 .52811 L .3674 .52727 L F
.36989 .52911 m .37149 .53029 L .36926 .52811 L F
0 0 0 r
.35023 .55192 m .34844 .55377 L .3483 .55293 L F
.35322 .66442 m .34935 .66464 L .35112 .66315 L F
.558 .65 .896 r
.3426 .54076 m .34695 .5435 L .34525 .54044 L F
.744 .626 .729 r
.34525 .54044 m .34695 .5435 L .34898 .54006 L F
.368 .171 .477 r
.34695 .5435 m .34888 .54299 L .34898 .54006 L F
.34695 .5435 m .34888 .54299 L .34898 .54006 L F
.778 .516 .54 r
.52431 .54376 m .52042 .54579 L .52095 .54327 L F
.52431 .54376 m .5243 .54629 L .52042 .54579 L F
.738 .483 .543 r
.52866 .54617 m .5243 .54629 L .52431 .54376 L F
.564 .093 .095 r
.32022 .65836 m .31845 .66005 L .31625 .6585 L F
.743 .317 .238 r
.32022 .65836 m .32249 .66087 L .31845 .66005 L F
.276 .78 .79 r
.23294 .55135 m .23194 .55185 L .23503 .55103 L F
.23294 .55135 m .23071 .55198 L .23194 .55185 L F
.361 0 0 r
.27417 .64231 m .27812 .64339 L .27625 .64308 L F
.069 .632 .756 r
.27812 .64339 m .27868 .64324 L .27625 .64308 L F
.27833 .64339 m .28041 .6433 L .27868 .64324 L F
.065 .595 .866 r
.27812 .64339 m .28138 .64406 L .28041 .6433 L F
.049 .492 .888 r
.28138 .64406 m .2828 .64387 L .28041 .6433 L F
.223 0 0 r
.27868 .64324 m .2828 .64387 L .28082 .64372 L F
0 .483 .765 r
.27868 .64324 m .28082 .64372 L .27882 .64318 L F
.27868 .64324 m .27882 .64318 L .27699 .64269 L F
.069 .632 .756 r
.27812 .64339 m .27833 .64339 L .27868 .64324 L F
.9 .761 .699 r
.347 .53456 m .3476 .53688 L .34772 .53427 L F
.745 .668 .775 r
.34622 .53505 m .34793 .53815 L .3476 .53688 L F
.747 .67 .775 r
.3426 .54076 m .34525 .54044 L .34622 .53505 L F
.778 .715 .792 r
.34126 .53898 m .3426 .54076 L .34622 .53505 L F
.34126 .53898 m .34622 .53505 L .345 .53543 L F
.34469 .5356 m .345 .53543 L .34479 .5355 L F
.34126 .53898 m .345 .53543 L .34469 .5356 L F
.935 .617 .411 r
.34622 .53505 m .3476 .53688 L .34557 .5352 L F
.34622 .53505 m .3452 .53529 L .34479 .5355 L F
.34557 .5352 m .3476 .53688 L .3452 .53529 L F
.9 .761 .699 r
.34551 .53516 m .3476 .53688 L .347 .53456 L F
.3452 .53529 m .34523 .53531 L .34551 .53516 L F
.34523 .53531 m .3476 .53688 L .34551 .53516 L F
.745 .668 .775 r
.34793 .53815 m .34898 .54006 L .3476 .53688 L F
.696 .649 .799 r
.3476 .53688 m .34898 .54006 L .35137 .53644 L F
.815 .663 .694 r
.34191 .55705 m .34054 .55878 L .34223 .55582 L F
.049 .492 .888 r
.28138 .64406 m .28442 .64533 L .2828 .64387 L F
.512 .879 .979 r
.24714 .62499 m .25112 .62464 L .24839 .6258 L F
.447 .231 .491 r
.27265 .55188 m .27064 .54989 L .27283 .54934 L F
.27265 .55188 m .27035 .55272 L .27064 .54989 L F
.307 .353 .746 r
.3291 .55651 m .33367 .5543 L .33099 .5569 L F
.343 0 .229 r
.36447 .6112 m .3613 .61437 L .36142 .6119 L F
.36447 .6112 m .36376 .61407 L .3613 .61437 L F
0 0 .115 r
.36692 .60848 m .36618 .61094 L .36447 .6112 L F
0 0 .11 r
.36618 .61094 m .36376 .61407 L .36447 .6112 L F
.271 0 .164 r
.18233 .56158 m .18447 .56131 L .18548 .55914 L F
.231 0 .144 r
.18548 .55914 m .18642 .56064 L .18743 .55828 L F
.18548 .55914 m .18447 .56131 L .18642 .56064 L F
.598 .652 .874 r
.20328 .61802 m .20546 .62108 L .20792 .62046 L F
.271 .641 .965 r
.30685 .5858 m .30784 .58701 L .30469 .58549 L F
.598 .183 .227 r
.30784 .58701 m .31002 .58881 L .3103 .58736 L F
.72 .198 0 r
.30685 .5858 m .31002 .58881 L .30784 .58701 L F
.642 .586 .776 r
.50795 .55686 m .51088 .55651 L .50808 .55878 L F
.416 .233 .522 r
.16925 .57721 m .17149 .57399 L .16965 .57473 L F
.237 .029 .382 r
.33058 .64155 m .32938 .63987 L .33093 .63892 L F
.33058 .64155 m .32885 .64238 L .32938 .63987 L F
.386 .272 .6 r
.32611 .651 m .32427 .64938 L .32711 .64865 L F
.32611 .651 m .32436 .65253 L .32427 .64938 L F
.16 .157 .605 r
.31617 .61654 m .31613 .62058 L .31446 .61817 L F
.071 .125 .614 r
.31446 .61817 m .31613 .62058 L .31522 .62059 L F
.198 0 .056 r
.20233 .54734 m .20127 .54893 L .20438 .54665 L F
.093 0 .304 r
.30552 .64541 m .30676 .64254 L .30632 .64528 L F
0 0 .062 r
.30676 .64254 m .30919 .63937 L .30963 .64272 L F
.276 0 .265 r
.30632 .64528 m .30676 .64254 L .30963 .64272 L F
.552 .399 .628 r
.38176 .57624 m .3791 .57427 L .38162 .57425 L F
.38176 .57624 m .37948 .57698 L .3791 .57427 L F
.204 0 .042 r
.3572 .62277 m .35415 .6209 L .35612 .62172 L F
.611 .738 .936 r
.51354 .56691 m .51427 .56411 L .51198 .56528 L F
.51354 .56691 m .51602 .56612 L .51427 .56411 L F
.203 0 .036 r
.22254 .56247 m .21837 .56541 L .21879 .562 L F
.241 .553 .931 r
.28896 .67059 m .29 .67143 L .28743 .67052 L F
.28896 .67059 m .29 .67143 L .28743 .67052 L F
.711 .701 .839 r
.28896 .67059 m .29122 .67389 L .29 .67143 L F
.296 .035 .337 r
.28131 .61473 m .28115 .61868 L .27855 .61774 L F
.043 0 .107 r
.28115 .61868 m .27841 .62048 L .27855 .61774 L F
.64 .814 .967 r
.31476 .53163 m .31231 .53251 L .31053 .5312 L F
.578 .814 .988 r
.25397 .63839 m .2574 .63882 L .25597 .63811 L F
.311 .685 .977 r
.2574 .63882 m .2585 .63776 L .25597 .63811 L F
.2574 .63882 m .26006 .63896 L .2585 .63776 L F
.275 .051 .381 r
.17698 .56767 m .1791 .5676 L .17962 .56494 L F
.161 0 .224 r
.17698 .56767 m .17814 .56952 L .1791 .5676 L F
.17698 .56767 m .17637 .57046 L .17814 .56952 L F
.569 .233 .36 r
.34888 .54299 m .35164 .54331 L .35267 .54052 L F
.627 .614 .818 r
.35267 .54052 m .3539 .53655 L .35137 .53644 L F
.35267 .54052 m .35526 .54028 L .3539 .53655 L F
.657 .368 .47 r
.35164 .54331 m .35526 .54028 L .35267 .54052 L F
.901 .798 .737 r
.34538 .65833 m .34141 .65963 L .34433 .65568 L F
.825 .715 .744 r
.34538 .66074 m .34141 .65963 L .34538 .65833 L F
.508 .312 .55 r
.34815 .6599 m .34538 .66074 L .34538 .65833 L F
.4 .324 .655 r
.36884 .60235 m .37127 .60441 L .36816 .6034 L F
.509 .337 .582 r
.37127 .60441 m .36885 .60778 L .36816 .6034 L F
.599 .459 .663 r
.31408 .64606 m .31683 .6464 L .31644 .64231 L F
.707 .57 .698 r
.31371 .64849 m .31683 .6464 L .31408 .64606 L F
.543 .331 .542 r
.33736 .62111 m .33753 .62371 L .33483 .62414 L F
.533 .323 .541 r
.33987 .62315 m .33753 .62371 L .33736 .62111 L F
.181 .299 .749 r
.35139 .61113 m .35383 .61358 L .35247 .61496 L F
0 0 .349 r
.35381 .61556 m .35247 .61496 L .35383 .61358 L F
.35381 .61556 m .3523 .61774 L .35247 .61496 L F
.313 0 0 r
.30029 .52977 m .30425 .53076 L .30233 .53013 L F
.458 .239 .493 r
.35977 .56166 m .36252 .55882 L .35944 .55903 L F
.651 .621 .807 r
.51292 .55499 m .51681 .55586 L .51434 .55877 L F
.752 .866 .932 r
.51295 .55266 m .51553 .55136 L .51607 .55197 L F
.702 .482 .586 r
.51607 .55197 m .51681 .55586 L .51292 .55499 L F
.555 .541 .794 r
.51849 .54932 m .5196 .55269 L .51607 .55197 L F
.588 .477 .695 r
.51607 .55197 m .51898 .55522 L .51681 .55586 L F
.51607 .55197 m .5196 .55269 L .51898 .55522 L F
.151 0 .195 r
.34054 .55878 m .339 .56175 L .33723 .56223 L F
.612 .532 .74 r
.339 .56175 m .3376 .56473 L .33723 .56223 L F
.502 .238 .447 r
.2994 .62417 m .30171 .62387 L .3023 .62138 L F
.546 .279 .462 r
.3023 .62138 m .30513 .62163 L .3048 .62074 L F
.3023 .62138 m .30171 .62387 L .30513 .62163 L F
.067 0 0 r
.25027 .55837 m .2486 .55942 L .24606 .55987 L F
.101 .655 .718 r
.2525 .55809 m .25082 .55826 L .25027 .55837 L F
0 0 0 r
.25082 .55826 m .2486 .55942 L .25027 .55837 L F
.672 .718 .883 r
.53469 .56222 m .53863 .56251 L .5374 .56037 L F
.53469 .56222 m .53863 .56251 L .5374 .56037 L F
.244 .367 .79 r
.53863 .56251 m .53968 .56102 L .5374 .56037 L F
.53863 .56251 m .54103 .5647 L .53968 .56102 L F
.217 0 0 r
.37441 .5375 m .37281 .53725 L .37287 .53718 L F
.4 .364 .703 r
.37441 .5375 m .37529 .54037 L .37707 .53942 L F
.434 0 0 r
.37441 .5375 m .37516 .53811 L .37281 .53725 L F
0 0 0 r
.37347 .53696 m .37281 .53725 L .37516 .53811 L F
.37347 .53696 m .37268 .53739 L .37281 .53725 L F
.37268 .53739 m .37135 .53812 L .37281 .53725 L F
.217 0 0 r
.37287 .53718 m .37281 .53725 L .37087 .53677 L F
.434 0 0 r
.37441 .5375 m .37707 .53942 L .37516 .53811 L F
.489 .352 .621 r
.37441 .5375 m .37707 .53942 L .37644 .5361 L F
.374 .096 .357 r
.23991 .55981 m .24222 .56001 L .24288 .55659 L F
.21 0 .3 r
.24288 .55659 m .24459 .55717 L .24523 .55642 L F
.24285 .55674 m .24222 .56001 L .24459 .55717 L F
.744 .669 .777 r
.24459 .55717 m .24222 .56001 L .24124 .5588 L F
.293 0 0 r
.24315 .55789 m .24557 .55742 L .24459 .55717 L F
.24557 .55742 m .24708 .55712 L .24459 .55717 L F
.21 0 .3 r
.24288 .55659 m .24285 .55674 L .24459 .55717 L F
.424 .456 .79 r
.31188 .63848 m .30919 .63937 L .30834 .63634 L F
.263 .028 .357 r
.30963 .64272 m .30919 .63937 L .31188 .63848 L F
.181 0 .326 r
.17195 .57168 m .17321 .57295 L .1743 .57129 L F
.17195 .57168 m .17149 .57399 L .17321 .57295 L F
.923 .754 .655 r
.35752 .53056 m .35852 .53196 L .35893 .52785 L F
.086 .016 .472 r
.35871 .53101 m .35852 .53196 L .35866 .53175 L F
.35867 .53051 m .35852 .53196 L .35871 .53101 L F
.181 0 0 r
.35662 .53338 m .35887 .53288 L .36046 .53167 L F
.822 .399 0 r
.35752 .53056 m .35887 .53288 L .35852 .53196 L F
.898 .609 .489 r
.35871 .53101 m .35887 .53288 L .35752 .53056 L F
.36046 .53167 m .35888 .53287 L .35876 .53158 L F
.36046 .53167 m .35876 .53158 L .35872 .53101 L F
.35888 .53287 m .35887 .53288 L .35871 .53101 L F
.891 .705 .643 r
.35893 .52785 m .36046 .53167 L .35871 .53101 L F
.709 .628 .765 r
.36251 .52879 m .36046 .53167 L .35893 .52785 L F
.638 .627 .823 r
.35887 .53288 m .36058 .52874 L .35876 .53158 L F
.35887 .53288 m .35876 .53158 L .35852 .53196 L F
.898 .609 .489 r
.35872 .53101 m .35876 .53158 L .35871 .53101 L F
.086 .016 .472 r
.35893 .52785 m .35867 .53051 L .35871 .53101 L F
.35893 .52785 m .35866 .53175 L .36058 .52874 L F
.891 .705 .643 r
.35893 .52785 m .35871 .53101 L .35752 .53056 L F
.004 .146 .661 r
.33512 .6293 m .33576 .63198 L .33451 .6306 L F
.737 .399 .408 r
.32004 .55611 m .31554 .55639 L .31771 .55723 L F
.439 .865 .936 r
.26219 .71125 m .26423 .71141 L .26469 .71059 L F
.207 .711 .905 r
.24352 .6361 m .2475 .63648 L .24591 .63602 L F
.506 .823 1 r
.2475 .63648 m .24812 .63499 L .24591 .63602 L F
.2475 .63648 m .24993 .63595 L .24812 .63499 L F
.41 .247 .547 r
.37388 .5834 m .37433 .58653 L .37188 .58695 L F
.575 .418 .631 r
.37433 .58653 m .37196 .58961 L .37188 .58695 L F
.682 .14 0 r
.31549 .60894 m .31165 .6071 L .31447 .60702 L F
.211 .452 .873 r
.31554 .60858 m .31549 .60894 L .31447 .60702 L F
0 0 0 r
.25547 .53226 m .25791 .53192 L .26009 .53154 L F
.208 .729 .724 r
.25791 .53192 m .26233 .53089 L .26009 .53154 L F
.721 .848 .942 r
.16543 .61054 m .16486 .61212 L .16283 .61089 L F
.16543 .61054 m .16486 .61212 L .16283 .61089 L F
.268 .691 .967 r
.36142 .6119 m .35982 .61086 L .35786 .61086 L F
.982 .714 .442 r
.36142 .6119 m .3613 .61437 L .35982 .61086 L F
.46 .519 .832 r
.3613 .61437 m .36127 .61086 L .35982 .61086 L F
.36127 .61086 m .36126 .60952 L .35982 .61086 L F
.268 .691 .967 r
.35786 .61086 m .35982 .61086 L .35756 .61077 L F
.156 .62 .93 r
.32073 .57099 m .32061 .57004 L .31838 .56797 L F
.32073 .57099 m .3224 .57107 L .32061 .57004 L F
.529 .895 .97 r
.27714 .69181 m .27948 .69206 L .2788 .69146 L F
.713 .495 .593 r
.54125 .5336 m .54434 .53506 L .54216 .53412 L F
.618 .331 .46 r
.34339 .65117 m .34043 .64926 L .34339 .64848 L F
.34339 .65117 m .34017 .65148 L .34043 .64926 L F
.34339 .65117 m .34043 .64926 L .34339 .64848 L F
.34339 .65117 m .34017 .65148 L .34043 .64926 L F
.543 .013 0 r
.34354 .58726 m .34547 .58909 L .34381 .58775 L F
.34381 .58775 m .34547 .58909 L .34354 .58726 L F
.324 .741 .977 r
.31686 .53128 m .32031 .53189 L .31843 .53228 L F
.203 0 .036 r
.22254 .56247 m .22056 .56503 L .21837 .56541 L F
.239 0 .06 r
.22304 .56379 m .22254 .56247 L .22318 .5612 L F
.22304 .56379 m .22056 .56503 L .22254 .56247 L F
.352 .498 .865 r
.38189 .5355 m .38095 .53724 L .3791 .53394 L F
.262 .383 .798 r
.38189 .5355 m .38234 .53702 L .38095 .53724 L F
.61 .042 0 r
.35878 .61558 m .36093 .61704 L .36331 .61768 L F
.953 .92 .739 r
.36093 .61704 m .36029 .6211 L .36331 .61768 L F
.287 .485 .877 r
.28411 .66681 m .28743 .67052 L .28896 .67059 L F
.35 .038 .288 r
.32065 .57697 m .32286 .57645 L .32345 .57352 L F
.494 .641 .921 r
.32345 .57352 m .32467 .57137 L .3224 .57107 L F
.32345 .57352 m .32632 .57364 L .32467 .57137 L F
.393 .021 .208 r
.32286 .57645 m .32632 .57364 L .32345 .57352 L F
.736 .654 .768 r
.33849 .61156 m .33829 .61456 L .33623 .61505 L F
0 0 .259 r
.33742 .6156 m .33623 .61505 L .33829 .61456 L F
0 0 .408 r
.33978 .61289 m .33829 .61456 L .33849 .61156 L F
.409 .239 .537 r
.33978 .61289 m .33742 .6156 L .33829 .61456 L F
.546 .796 .991 r
.52846 .55482 m .52701 .55683 L .52567 .55625 L F
.52846 .55482 m .52987 .55594 L .52701 .55683 L F
.37 .491 .851 r
.52991 .55826 m .52701 .55683 L .52987 .55594 L F
.456 .319 .605 r
.31906 .55334 m .3214 .54921 L .31928 .5498 L F
.174 0 .19 r
.30473 .54469 m .30211 .54673 L .30062 .54323 L F
.30473 .54469 m .30401 .54598 L .30211 .54673 L F
.456 .225 .474 r
.304 .54865 m .30211 .54673 L .30401 .54598 L F
.304 .54865 m .30179 .54938 L .30211 .54673 L F
.347 .729 .986 r
.24135 .63607 m .24185 .63495 L .23952 .63468 L F
.24135 .63607 m .24352 .6361 L .24185 .63495 L F
.645 .799 .957 r
.36416 .53718 m .36783 .53753 L .36651 .53624 L F
.65 .801 .955 r
.36651 .53624 m .36783 .53753 L .37087 .53677 L F
.544 .202 .339 r
.28526 .54863 m .29178 .54511 L .28578 .54701 L F
.067 .6 .863 r
.17508 .59907 m .17629 .59908 L .17273 .59831 L F
.625 .829 .979 r
.29112 .6493 m .29187 .64931 L .29078 .64793 L F
0 .365 .832 r
.29187 .64931 m .29238 .64832 L .29078 .64793 L F
.29187 .64931 m .29548 .65134 L .29238 .64832 L F
.532 .221 .386 r
.3723 .54411 m .37519 .5445 L .37504 .54349 L F
.3723 .54411 m .37176 .54613 L .37519 .5445 L F
.482 .39 .675 r
.30374 .61534 m .30575 .61092 L .30403 .61171 L F
.662 .968 .911 r
.5374 .56037 m .53469 .56222 L .53592 .56045 L F
.5374 .56037 m .53469 .56222 L .53592 .56045 L F
0 .374 .801 r
.38518 .53882 m .38305 .5382 L .38234 .53702 L F
.38518 .53882 m .38657 .54001 L .38305 .5382 L F
.369 .358 .716 r
.22508 .55588 m .22638 .55906 L .22337 .55629 L F
.351 .796 .957 r
.26813 .69453 m .26965 .69505 L .26575 .69486 L F
.26813 .69453 m .26965 .69505 L .26575 .69486 L F
.558 .828 .473 r
.27044 .69406 m .26965 .69505 L .26813 .69453 L F
.206 .582 .943 r
.26965 .69505 m .27044 .69406 L .26813 .69453 L F
.26965 .69505 m .27218 .69569 L .27044 .69406 L F
.953 .92 .739 r
.36093 .61704 m .35918 .62182 L .36029 .6211 L F
.26 .019 .346 r
.28326 .61401 m .28131 .61473 L .28372 .61161 L F
.264 .012 .331 r
.28321 .61679 m .28131 .61473 L .28326 .61401 L F
.28321 .61679 m .28115 .61868 L .28131 .61473 L F
.535 .92 .915 r
.292 .65475 m .29331 .65484 L .29409 .65374 L F
.292 .65475 m .29331 .65484 L .29409 .65374 L F
.173 .663 .922 r
.32031 .53189 m .323 .53203 L .3251 .53292 L F
.422 .802 .992 r
.323 .53203 m .32721 .53248 L .3251 .53292 L F
.515 0 0 r
.29657 .65185 m .298 .65243 L .29642 .65349 L F
.962 .71 .507 r
.34214 .56639 m .34005 .56707 L .34016 .56435 L F
0 0 0 r
.34242 .56647 m .34214 .56639 L .34423 .56606 L F
.34242 .56647 m .34005 .56707 L .34214 .56639 L F
.32 .018 .287 r
.34446 .56503 m .34423 .56606 L .34214 .56639 L F
.671 .477 .613 r
.28974 .66738 m .29205 .66755 L .28926 .66551 L F
0 0 0 r
.19806 .57423 m .19603 .57613 L .19444 .57683 L F
.077 0 0 r
.19877 .57522 m .19806 .57423 L .1996 .57331 L F
.19877 .57522 m .19603 .57613 L .19806 .57423 L F
.301 .157 .513 r
.33033 .57964 m .32889 .57736 L .33047 .57704 L F
.33033 .57964 m .32877 .58063 L .32889 .57736 L F
.08 .44 .877 r
.2893 .6408 m .28672 .63983 L .28687 .63833 L F
.467 .263 .52 r
.28893 .59018 m .29132 .58959 L .29147 .58694 L F
.404 .115 .356 r
.28893 .59018 m .28828 .59236 L .29132 .58959 L F
.444 .679 .964 r
.23193 .6185 m .23106 .62018 L .22891 .61795 L F
.23193 .6185 m .23331 .61996 L .23106 .62018 L F
.736 .654 .768 r
.33849 .61156 m .33623 .61505 L .33452 .61111 L F
.719 .357 .363 r
.33623 .61505 m .33626 .61686 L .33915 .61698 L F
0 0 .259 r
.33742 .6156 m .33626 .61686 L .33623 .61505 L F
.59 .561 .79 r
.4979 .55806 m .50007 .55552 L .49764 .55597 L F
.4979 .55806 m .50173 .55998 L .50007 .55552 L F
.435 .25 .529 r
.49639 .55238 m .49863 .54876 L .49643 .54979 L F
.233 .721 .926 r
.26233 .53089 m .26466 .5308 L .26638 .53134 L F
.351 .794 .959 r
.26466 .5308 m .26873 .53096 L .26638 .53134 L F
.273 0 .274 r
.17962 .56494 m .18161 .56425 L .18233 .56158 L F
.271 0 .274 r
.18233 .56158 m .18354 .56355 L .18447 .56131 L F
.18233 .56158 m .18161 .56425 L .18354 .56355 L F
.817 .62 .636 r
.50791 .54343 m .50786 .54656 L .50581 .54607 L F
0 0 0 r
.19942 .54986 m .19653 .55243 L .19851 .55117 L F
.133 0 .056 r
.19851 .55117 m .20127 .54893 L .19942 .54986 L F
.194 .616 .947 r
.24513 .62372 m .24461 .6246 L .24317 .62312 L F
.24513 .62372 m .24714 .62499 L .24461 .6246 L F
0 .322 .715 r
.17796 .60063 m .1788 .60083 L .17629 .59908 L F
.713 .495 .593 r
.54125 .5336 m .54314 .53612 L .54434 .53506 L F
.905 .544 .343 r
.54314 .53612 m .5445 .53874 L .54434 .53506 L F
.455 .323 .611 r
.33727 .62631 m .33483 .62414 L .33753 .62371 L F
.33727 .62631 m .33511 .62699 L .33483 .62414 L F
.439 .339 .645 r
.31626 .58409 m .31792 .58005 L .31598 .58059 L F
.765 .642 .726 r
.30226 .55574 m .30771 .55743 L .30666 .55273 L F
.379 .393 .749 r
.30226 .55574 m .30528 .55768 L .30771 .55743 L F
.765 .642 .726 r
.30226 .55574 m .30666 .55273 L .30234 .55283 L F
.097 .035 .49 r
.30423 .5541 m .30226 .55574 L .30234 .55283 L F
.138 .104 .553 r
.30423 .5541 m .30331 .55727 L .30226 .55574 L F
.628 .61 .813 r
.30113 .55458 m .30283 .55668 L .30423 .5541 L F
.30283 .55668 m .30331 .55727 L .30341 .55692 L F
.30283 .55668 m .30341 .55692 L .30423 .5541 L F
.379 .393 .749 r
.30528 .55768 m .3063 .55834 L .30652 .55819 L F
.30528 .55768 m .30652 .55819 L .30771 .55743 L F
.921 .648 .161 r
.30666 .55273 m .30771 .55743 L .30689 .55527 L F
.375 0 0 r
.30771 .55743 m .30748 .55711 L .30689 .55527 L F
.30771 .55743 m .3063 .55834 L .30957 .55806 L F
.451 .851 .973 r
.32721 .53248 m .33064 .53238 L .32804 .53294 L F
.125 0 0 r
.27097 .52999 m .27498 .53058 L .27264 .53021 L F
.32 .08 .384 r
.36477 .5525 m .36674 .55205 L .36737 .54964 L F
.158 .075 .504 r
.28121 .59939 m .28275 .6005 L .28207 .59767 L F
.144 .078 .518 r
.28121 .59939 m .28138 .6021 L .28275 .6005 L F
.627 .589 .792 r
.37063 .59701 m .36811 .59984 L .36828 .59597 L F
0 .024 .569 r
.36966 .60079 m .36811 .59984 L .37063 .59701 L F
.36966 .60079 m .36884 .60235 L .36811 .59984 L F
.693 .53 .661 r
.31937 .6043 m .31904 .60135 L .32064 .60199 L F
.625 .829 .979 r
.29112 .6493 m .29078 .64793 L .2881 .64855 L F
.464 .313 .591 r
.34408 .58654 m .34652 .58753 L .34663 .58468 L F
.498 .885 .963 r
.29178 .52953 m .28754 .52993 L .28985 .52907 L F
.349 .804 .942 r
.29391 .52905 m .29178 .52953 L .28985 .52907 L F
.615 .923 .973 r
.34625 .62422 m .3443 .62354 L .34554 .62335 L F
0 0 .463 r
.34617 .62581 m .3443 .62354 L .34625 .62422 L F
.607 .548 .763 r
.34965 .58987 m .35096 .59336 L .35344 .59265 L F
.568 .406 .622 r
.35104 .59604 m .35344 .59265 L .35096 .59336 L F
.106 0 0 r
.38865 .55911 m .38457 .56021 L .38514 .55922 L F
.38865 .55911 m .38672 .56003 L .38457 .56021 L F
.094 0 0 r
.39105 .55851 m .38672 .56003 L .38865 .55911 L F
.405 0 0 r
.21636 .61511 m .21867 .6163 L .22077 .61701 L F
.22 .635 .955 r
.22103 .61601 m .22077 .61701 L .21867 .6163 L F
.22103 .61601 m .22281 .61722 L .22077 .61701 L F
.328 .116 .432 r
.29813 .63332 m .29579 .63659 L .2978 .63581 L F
.199 0 .167 r
.2978 .63581 m .29579 .63659 L .29494 .63855 L F
0 0 .422 r
.34844 .55377 m .34793 .55873 L .34661 .5589 L F
0 0 .031 r
.34708 .55965 m .34661 .5589 L .34793 .55873 L F
.34708 .55965 m .34591 .56141 L .34661 .5589 L F
.593 .507 .726 r
.34004 .60248 m .34314 .60258 L .34182 .59905 L F
.595 .593 .82 r
.34004 .60248 m .34326 .60288 L .34314 .60258 L F
.445 .105 .294 r
.34204 .61638 m .34454 .61376 L .34274 .61556 L F
.331 .618 .955 r
.2347 .62035 m .2342 .62181 L .23331 .61996 L F
.2347 .62035 m .23707 .62224 L .2342 .62181 L F
.512 .329 .57 r
.34954 .57758 m .35245 .57412 L .34998 .57467 L F
.525 .462 .728 r
.31644 .64231 m .318 .63941 L .31567 .64 L F
.31644 .64231 m .31878 .64188 L .318 .63941 L F
.493 .381 .655 r
.31644 .64231 m .31894 .64478 L .31878 .64188 L F
.31644 .64231 m .31683 .6464 L .31894 .64478 L F
.221 .068 .45 r
.29147 .58694 m .29132 .58959 L .29287 .58599 L F
.252 .464 .871 r
.20813 .60094 m .20737 .60276 L .2065 .60073 L F
.221 .426 .85 r
.20813 .60094 m .21 .60418 L .20737 .60276 L F
.374 .074 .322 r
.31031 .62974 m .313 .62709 L .31249 .62927 L F
.194 0 .235 r
.31416 .62866 m .313 .62709 L .31516 .62607 L F
.31416 .62866 m .31249 .62927 L .313 .62709 L F
.261 .003 .321 r
.28372 .61161 m .28631 .6085 L .28566 .61095 L F
.419 .204 .479 r
.28566 .61095 m .28326 .61401 L .28372 .61161 L F
.563 .473 .711 r
.52991 .55826 m .53134 .56225 L .52753 .56182 L F
0 .033 .55 r
.52929 .56267 m .52753 .56182 L .53134 .56225 L F
.52929 .56267 m .52799 .56412 L .52753 .56182 L F
.609 .626 .843 r
.19735 .5937 m .19629 .59579 L .19501 .59248 L F
.613 .631 .845 r
.19735 .5937 m .19952 .59684 L .19629 .59579 L F
.482 .39 .675 r
.30374 .61534 m .30575 .61472 L .30575 .61092 L F
.456 .398 .704 r
.30457 .61771 m .30575 .61472 L .30374 .61534 L F
.373 .237 .565 r
.16748 .58049 m .1693 .57978 L .16925 .57721 L F
.351 .252 .601 r
.16748 .58049 m .16891 .58388 L .1693 .57978 L F
.16748 .58049 m .16741 .58399 L .16891 .58388 L F
.363 0 0 r
.24373 .54694 m .24234 .54735 L .23948 .54693 L F
.48 .651 .934 r
.23948 .54693 m .24234 .54735 L .24221 .54717 L F
.21 0 0 r
.2395 .54693 m .24223 .54716 L .24373 .54694 L F
.24221 .54717 m .24227 .54717 L .24373 .54694 L F
0 0 0 r
.24864 .54631 m .24452 .54677 L .24616 .54686 L F
.284 0 0 r
.24458 .54676 m .24864 .54631 L .24616 .54686 L F
0 0 0 r
.24864 .54631 m .24454 .54677 L .24452 .54677 L F
.575 .676 .908 r
.24452 .54677 m .24472 .54322 L .24261 .54393 L F
.24452 .54677 m .24454 .54677 L .24472 .54322 L F
.284 0 0 r
.24456 .54676 m .24864 .54631 L .24458 .54676 L F
.24522 .54661 m .24864 .54631 L .24456 .54676 L F
.24576 .54668 m .2469 .54677 L .24864 .54631 L F
0 0 0 r
.24864 .54631 m .24714 .54655 L .24599 .54665 L F
.24864 .54631 m .24599 .54665 L .24454 .54677 L F
.284 0 0 r
.24522 .54661 m .24599 .54665 L .24864 .54631 L F
.575 .676 .908 r
.24522 .54661 m .24714 .54655 L .24689 .54621 L F
.24454 .54677 m .24599 .54665 L .24522 .54661 L F
.24599 .54665 m .24714 .54655 L .24522 .54661 L F
.284 0 0 r
.24508 .54662 m .24576 .54668 L .24599 .54665 L F
.24508 .54662 m .24599 .54665 L .24522 .54661 L F
.575 .676 .908 r
.24454 .54677 m .24689 .54621 L .24472 .54322 L F
.284 0 0 r
.2439 .54672 m .24522 .54661 L .24456 .54676 L F
.2439 .54672 m .24624 .54695 L .2469 .54677 L F
.2439 .54672 m .2469 .54677 L .24508 .54662 L F
.507 .631 .907 r
.24236 .54717 m .24452 .54677 L .24438 .54656 L F
.24242 .54639 m .24438 .54656 L .24261 .54393 L F
.24236 .54717 m .24438 .54656 L .24242 .54639 L F
.24234 .54735 m .24283 .54722 L .24236 .54717 L F
.326 .808 .885 r
.24234 .54735 m .24616 .54686 L .24373 .54694 L F
.311 .799 .88 r
.24228 .54717 m .24616 .54686 L .24373 .54694 L F
.507 .631 .907 r
.24303 .54714 m .24242 .54716 L .24236 .54717 L F
.24314 .54713 m .24304 .54714 L .24303 .54714 L F
.24304 .54714 m .24242 .54716 L .24303 .54714 L F
.311 .799 .88 r
.2417 .54726 m .2439 .54672 L .24456 .54676 L F
.24304 .54714 m .24616 .54686 L .24228 .54717 L F
.24304 .54714 m .24445 .54679 L .24616 .54686 L F
.326 .808 .885 r
.24234 .54735 m .24445 .54679 L .24616 .54686 L F
.24445 .54679 m .24452 .54677 L .24616 .54686 L F
.311 .799 .88 r
.24445 .54679 m .24456 .54676 L .24616 .54686 L F
.2417 .54726 m .24304 .54714 L .24236 .54717 L F
.24227 .54717 m .24236 .54717 L .24228 .54717 L F
.2417 .54726 m .24236 .54717 L .24227 .54717 L F
.507 .631 .907 r
.24234 .54735 m .24236 .54717 L .24227 .54717 L F
.24222 .54717 m .24227 .54717 L .24221 .54717 L F
.24234 .54735 m .24227 .54717 L .24222 .54717 L F
.24314 .54713 m .24452 .54677 L .24242 .54716 L F
.21 0 0 r
.24221 .54717 m .24227 .54717 L .24227 .54717 L F
.311 .799 .88 r
.2417 .54726 m .24456 .54676 L .24304 .54714 L F
.507 .631 .907 r
.24283 .54722 m .24314 .54713 L .24236 .54717 L F
.21 0 0 r
.23948 .54693 m .24221 .54717 L .24223 .54716 L F
.23948 .54693 m .24223 .54716 L .2395 .54693 L F
.507 .631 .907 r
.24221 .54717 m .24261 .54393 L .24015 .54439 L F
.24236 .54717 m .24261 .54393 L .24221 .54717 L F
.48 .651 .934 r
.23948 .54693 m .24221 .54717 L .24015 .54439 L F
.21 0 0 r
.23948 .54693 m .2417 .54726 L .24193 .54714 L F
.888 .949 .842 r
.23953 .54673 m .23984 .54986 L .2417 .54726 L F
.77 .357 .267 r
.2417 .54726 m .23979 .54915 L .24091 .54767 L F
.314 .474 .859 r
.24015 .54439 m .2417 .54726 L .23948 .54693 L F
.974 .707 .464 r
.24015 .54439 m .23953 .54673 L .2417 .54726 L F
.483 .875 .966 r
.2417 .54726 m .23953 .54673 L .24208 .54611 L F
.77 .357 .267 r
.2417 .54726 m .24208 .54611 L .23953 .54673 L F
.2417 .54726 m .24091 .54767 L .24208 .54611 L F
.21 0 0 r
.24193 .54714 m .2417 .54726 L .24227 .54717 L F
.442 0 0 r
.34067 .53205 m .34452 .53382 L .34128 .53445 L F
.609 .596 .813 r
.34128 .53445 m .33775 .53218 L .34067 .53205 L F
.442 0 0 r
.34067 .53205 m .3402 .53218 L .34452 .53382 L F
.873 .885 .84 r
.34452 .53382 m .34452 .52927 L .34545 .53155 L F
.426 .759 .996 r
.33871 .53082 m .34067 .53205 L .33775 .53218 L F
.838 .499 0 r
.34016 .53205 m .34067 .53205 L .33871 .53082 L F
.34016 .53205 m .3402 .53218 L .34067 .53205 L F
.873 .885 .84 r
.34452 .53382 m .3402 .53218 L .34143 .53135 L F
.34452 .53382 m .34143 .53135 L .34452 .52936 L F
.826 .603 .6 r
.34056 .53365 m .3424 .53176 L .34038 .53203 L F
.692 .434 .529 r
.34452 .52927 m .3402 .53218 L .34016 .53205 L F
.826 .603 .6 r
.34019 .53215 m .34038 .53203 L .34016 .53205 L F
.34056 .53365 m .34038 .53203 L .34019 .53215 L F
.873 .885 .84 r
.34452 .52936 m .34143 .53135 L .34452 .52927 L F
.074 0 .437 r
.37529 .54037 m .37652 .54203 L .37707 .53942 L F
.37529 .54037 m .37504 .54349 L .37652 .54203 L F
.002 0 0 r
.19653 .55243 m .19675 .55347 L .19851 .55117 L F
.19653 .55243 m .19473 .55431 L .19675 .55347 L F
.28 .228 .62 r
.29711 .58933 m .29765 .59192 L .29578 .59285 L F
.25 .021 .359 r
.2973 .59457 m .29578 .59285 L .29765 .59192 L F
.2973 .59457 m .29571 .59536 L .29578 .59285 L F
.456 .319 .605 r
.31906 .55334 m .32177 .55274 L .3214 .54921 L F
.333 0 .07 r
.3184 .55421 m .32177 .55274 L .31906 .55334 L F
0 .511 .709 r
.30425 .53076 m .30654 .53102 L .3082 .53123 L F
.183 .688 .907 r
.30901 .5307 m .3082 .53123 L .30654 .53102 L F
.30901 .5307 m .31053 .5312 L .3082 .53123 L F
.708 .659 .799 r
.50766 .5484 m .5091 .55274 L .5066 .55274 L F
.687 .404 .487 r
.5091 .55274 m .51208 .5537 L .5066 .55274 L F
.733 .673 .792 r
.50766 .5484 m .51129 .54869 L .5091 .55274 L F
0 0 0 r
.5408 .53885 m .53959 .54023 L .54227 .54087 L F
.5408 .53885 m .53999 .54039 L .53959 .54023 L F
.444 .122 .325 r
.52866 .54617 m .52492 .54937 L .5243 .54629 L F
.52866 .54617 m .52676 .54919 L .52492 .54937 L F
.7 .416 .49 r
.52998 .54898 m .52676 .54919 L .52866 .54617 L F
.054 0 0 r
.23277 .53584 m .23694 .53386 L .23468 .53438 L F
.903 .521 .083 r
.30549 .64741 m .30713 .64908 L .30552 .64541 L F
.859 .494 .357 r
.30879 .64866 m .30552 .64541 L .30713 .64908 L F
.903 .521 .083 r
.30549 .64741 m .30552 .64541 L .30632 .64528 L F
.605 .839 .988 r
.33775 .53218 m .33363 .53188 L .336 .53102 L F
.426 .759 .996 r
.33871 .53082 m .33775 .53218 L .336 .53102 L F
.501 .464 .748 r
.29725 .55552 m .29826 .55939 L .30061 .55837 L F
.423 .28 .58 r
.29826 .55939 m .30031 .56116 L .30061 .55837 L F
.884 .695 .642 r
.30061 .55837 m .30031 .56116 L .29826 .55939 L F
.629 .477 .657 r
.51208 .5537 m .50795 .55686 L .5066 .55274 L F
.51208 .5537 m .51088 .55651 L .50795 .55686 L F
.544 .202 .339 r
.28575 .54837 m .28778 .5486 L .29178 .54511 L F
.549 .222 .366 r
.28778 .5486 m .29161 .54572 L .29178 .54511 L F
.28778 .5486 m .29039 .5489 L .29161 .54572 L F
.371 .669 .973 r
.28817 .54681 m .29039 .54889 L .28778 .5486 L F
.29039 .54889 m .29039 .5489 L .28778 .5486 L F
.544 .202 .339 r
.28526 .54863 m .28778 .5486 L .28575 .54837 L F
.953 .642 .406 r
.33876 .64275 m .33688 .64185 L .3367 .6394 L F
.958 .673 .451 r
.33876 .64275 m .33703 .64449 L .33688 .64185 L F
.123 0 0 r
.34005 .64333 m .33876 .64275 L .34147 .64374 L F
.34005 .64333 m .33703 .64449 L .33876 .64275 L F
.55 .097 .129 r
.34186 .64298 m .34147 .64374 L .33876 .64275 L F
.577 .211 .31 r
.32274 .58653 m .32317 .58777 L .32002 .58776 L F
.384 .109 .369 r
.32542 .58623 m .32274 .58653 L .32604 .58384 L F
.32542 .58623 m .32317 .58777 L .32274 .58653 L F
.518 .417 .68 r
.32048 .63015 m .32283 .62983 L .3221 .62683 L F
.377 .276 .611 r
.32048 .63015 m .32241 .6324 L .32283 .62983 L F
.32048 .63015 m .32043 .63243 L .32241 .6324 L F
.209 .024 .397 r
.28631 .6085 m .28822 .60534 L .28824 .60763 L F
.269 .01 .324 r
.28566 .61095 m .28631 .6085 L .28824 .60763 L F
.666 .486 .632 r
.34316 .60825 m .34725 .6083 L .34696 .60561 L F
.48 .463 .761 r
.34603 .6021 m .34696 .60561 L .34912 .60532 L F
.558 .408 .633 r
.34696 .60561 m .34972 .60782 L .34912 .60532 L F
.34696 .60561 m .34725 .6083 L .34972 .60782 L F
.742 .493 .553 r
.51125 .54663 m .50766 .5484 L .50786 .54656 L F
.51125 .54663 m .51129 .54869 L .50766 .5484 L F
0 .331 .793 r
.35612 .62172 m .35831 .62287 L .3572 .62277 L F
.203 .132 .548 r
.35934 .62589 m .3572 .62277 L .35831 .62287 L F
.35934 .62589 m .35766 .62823 L .3572 .62277 L F
.107 0 0 r
.35578 .56796 m .3561 .56805 L .35832 .56813 L F
.319 .121 .447 r
.35832 .56813 m .36025 .56795 L .36109 .56383 L F
.866 .893 .852 r
.35832 .56813 m .35911 .56422 L .36025 .56795 L F
.35832 .56813 m .3561 .56805 L .35911 .56422 L F
.233 .242 .664 r
.38365 .57003 m .38443 .57319 L .38515 .57192 L F
.473 .845 .988 r
.25088 .7351 m .25274 .73579 L .25484 .73512 L F
.325 .044 .324 r
.25212 .73796 m .25274 .73579 L .25484 .73512 L F
.473 .845 .988 r
.25484 .73512 m .25274 .73579 L .25088 .7351 L F
.301 .022 .312 r
.30185 .58526 m .30058 .58388 L .30196 .58286 L F
.30185 .58526 m .29981 .58616 L .30058 .58388 L F
.445 .105 .294 r
.34204 .61638 m .34446 .61615 L .34454 .61376 L F
.454 .348 .644 r
.34454 .61376 m .34717 .61094 L .34507 .61149 L F
.34454 .61376 m .34767 .61408 L .34717 .61094 L F
.477 .151 .335 r
.34446 .61615 m .34767 .61408 L .34454 .61376 L F
.498 .53 .82 r
.28691 .63289 m .28533 .63371 L .28413 .63053 L F
.384 .274 .604 r
.28691 .63289 m .28732 .63547 L .28533 .63371 L F
0 .191 .72 r
.38657 .54001 m .38885 .5422 L .38834 .54355 L F
0 .266 .772 r
.38885 .5422 m .39076 .54545 L .38834 .54355 L F
.181 0 .196 r
.28341 .59597 m .28516 .59539 L .28615 .59303 L F
.341 .033 .29 r
.28516 .59539 m .28828 .59236 L .28615 .59303 L F
.562 .27 .429 r
.52406 .53329 m .52714 .53101 L .52462 .53175 L F
.708 .659 .799 r
.50766 .5484 m .5066 .55274 L .50538 .54946 L F
.393 .17 .453 r
.37695 .58001 m .37652 .58265 L .37388 .5834 L F
.51 .316 .553 r
.37676 .58581 m .37388 .5834 L .37652 .58265 L F
.37676 .58581 m .37433 .58653 L .37388 .5834 L F
.699 .39 .449 r
.30683 .65111 m .30879 .64866 L .30713 .64908 L F
.674 .343 .406 r
.31068 .65105 m .30879 .64866 L .30683 .65111 L F
.31068 .65105 m .3111 .64893 L .30879 .64866 L F
.47 .827 .561 r
.27172 .61543 m .26879 .61787 L .27063 .61667 L F
0 0 0 r
.27396 .61427 m .27172 .61543 L .27063 .61667 L F
.815 .721 .761 r
.34223 .55582 m .34054 .55878 L .33817 .55645 L F
.34223 .55582 m .33817 .55645 L .33945 .55671 L F
.823 .662 .683 r
.33934 .5567 m .33913 .55677 L .33743 .55431 L F
.451 0 .011 r
.33817 .55645 m .33744 .55732 L .33987 .55679 L F
.823 .662 .683 r
.33913 .55677 m .33744 .55732 L .33744 .55706 L F
.552 .208 .338 r
.33568 .55587 m .33744 .55732 L .33817 .55645 L F
.823 .662 .683 r
.33913 .55677 m .33744 .55706 L .33743 .55431 L F
.815 .721 .761 r
.34053 .55652 m .33945 .55671 L .33987 .55679 L F
.34223 .55582 m .33945 .55671 L .34053 .55652 L F
.081 0 .288 r
.34223 .55582 m .34406 .5551 L .34465 .5524 L F
0 0 0 r
.34223 .55582 m .33987 .55679 L .34406 .5551 L F
.817 .685 .718 r
.32465 .55228 m .32943 .55123 L .32715 .55155 L F
.32465 .55228 m .32797 .55542 L .32943 .55123 L F
.656 .138 0 r
.33076 .55208 m .32715 .55155 L .32943 .55123 L F
.307 .789 .908 r
.2375 .53383 m .23923 .53345 L .24094 .53369 L F
.443 .849 .969 r
.23923 .53345 m .24328 .53327 L .24094 .53369 L F
.23923 .53345 m .24145 .53286 L .24328 .53327 L F
.205 0 0 r
.23729 .53463 m .24099 .53306 L .23923 .53345 L F
.24099 .53306 m .24145 .53286 L .23923 .53345 L F
.307 .789 .908 r
.23694 .53386 m .23923 .53345 L .2375 .53383 L F
.283 0 .009 r
.27997 .54801 m .27932 .54666 L .28093 .5451 L F
.27997 .54801 m .27761 .54873 L .27932 .54666 L F
.408 .218 .509 r
.31601 .54714 m .31457 .54913 L .31472 .54656 L F
.31666 .54743 m .31641 .54763 L .31601 .54714 L F
.31641 .54763 m .31457 .54913 L .31601 .54714 L F
.473 .23 .464 r
.32144 .54494 m .31585 .54694 L .31753 .54358 L F
.408 .218 .509 r
.31666 .54743 m .31601 .54714 L .31537 .54712 L F
.31601 .54714 m .31472 .54656 L .31537 .54712 L F
.473 .23 .464 r
.31585 .54694 m .31537 .54712 L .31564 .54668 L F
.31585 .54694 m .31564 .54668 L .31753 .54358 L F
.408 .157 .418 r
.31753 .54358 m .31537 .54712 L .31472 .54656 L F
.473 .23 .464 r
.32144 .54494 m .31753 .54358 L .31959 .54274 L F
.018 .263 .765 r
.22033 .62918 m .21969 .62587 L .21813 .6262 L F
.075 0 0 r
.22407 .62936 m .22033 .62918 L .22301 .62998 L F
.22407 .62936 m .22144 .62929 L .22033 .62918 L F
.018 .263 .765 r
.22033 .62918 m .22144 .62929 L .21969 .62587 L F
.404 .312 .638 r
.32573 .6117 m .32804 .6138 L .32792 .61111 L F
.442 .313 .609 r
.32573 .6117 m .32595 .6144 L .32804 .6138 L F
.799 .556 .57 r
.34066 .56149 m .339 .56175 L .34054 .55878 L F
.304 .503 .886 r
.24124 .5588 m .23991 .55981 L .23832 .55806 L F
.24124 .5588 m .24222 .56001 L .23991 .55981 L F
.221 .345 .779 r
.23991 .55981 m .24124 .5588 L .23832 .55806 L F
.23991 .55981 m .24211 .56022 L .24166 .55949 L F
.628 .153 .105 r
.24217 .55994 m .24016 .56163 L .2406 .55955 L F
.24526 .56069 m .2406 .55955 L .24211 .56022 L F
.24526 .56069 m .24341 .56103 L .24217 .55994 L F
.24341 .56103 m .24016 .56163 L .24217 .55994 L F
.221 .345 .779 r
.24105 .55894 m .24166 .55949 L .24124 .5588 L F
.23991 .55981 m .24166 .55949 L .24105 .55894 L F
.797 .972 .91 r
.37644 .5361 m .3776 .53562 L .3791 .53394 L F
.581 .517 .748 r
.3475 .59491 m .34843 .59899 L .34557 .59632 L F
.546 .563 .823 r
.49764 .55597 m .49863 .55191 L .49639 .55238 L F
.49764 .55597 m .50007 .55552 L .49863 .55191 L F
.456 .398 .704 r
.30457 .61771 m .30656 .61722 L .30575 .61472 L F
.53 .446 .705 r
.3048 .62074 m .30656 .61722 L .30457 .61771 L F
.736 .625 .735 r
.34538 .66074 m .34698 .66469 L .343 .66363 L F
.587 .129 .131 r
.34698 .66469 m .3435 .66467 L .343 .66363 L F
.34698 .66469 m .34664 .66544 L .3435 .66467 L F
.553 .513 .766 r
.34815 .6599 m .34698 .66469 L .34538 .66074 L F
.34815 .6599 m .34935 .66464 L .34698 .66469 L F
.222 0 0 r
.34935 .66464 m .34664 .66544 L .34698 .66469 L F
.849 .662 .65 r
.54541 .54865 m .54812 .55258 L .54766 .54848 L F
.54541 .54865 m .54482 .55378 L .54812 .55258 L F
.87 .52 .386 r
.54482 .55378 m .54724 .55518 L .54812 .55258 L F
.308 0 0 r
.29993 .62578 m .2994 .62417 L .29797 .62616 L F
.29993 .62578 m .30171 .62387 L .2994 .62417 L F
.712 .765 .894 r
.5243 .54629 m .52198 .54756 L .52042 .54579 L F
0 0 0 r
.30783 .57682 m .30483 .58148 L .3057 .57791 L F
.646 .163 .092 r
.31625 .6585 m .31443 .65988 L .31213 .65806 L F
.573 .074 .03 r
.31845 .66005 m .31443 .65988 L .31625 .6585 L F
.409 .837 .956 r
.23108 .56146 m .22874 .56108 L .22666 .56167 L F
0 .527 .74 r
.23372 .5618 m .22874 .56108 L .23108 .56146 L F
.675 .462 .59 r
.37035 .59457 m .36899 .59358 L .37027 .59298 L F
.167 .043 .456 r
.37196 .58961 m .3718 .59235 L .37027 .59298 L F
.255 .261 .674 r
.3718 .59235 m .37229 .59486 L .37027 .59298 L F
.442 .276 .559 r
.37027 .59298 m .37229 .59486 L .37035 .59457 L F
.431 .251 .534 r
.25609 .72583 m .25401 .72657 L .25596 .72875 L F
.25596 .72875 m .25401 .72657 L .25609 .72583 L F
.554 .21 .34 r
.32249 .61987 m .32074 .61784 L .32021 .62067 L F
.32249 .61987 m .32334 .61769 L .32074 .61784 L F
.406 .844 .938 r
.22379 .6287 m .22407 .62936 L .22552 .62955 L F
.22379 .6287 m .22144 .62929 L .22407 .62936 L F
.46 .266 .529 r
.28207 .59767 m .28516 .59539 L .28341 .59597 L F
.235 .007 .351 r
.32877 .58063 m .32806 .58315 L .32604 .58384 L F
.2 0 .265 r
.32806 .58315 m .32542 .58623 L .32604 .58384 L F
.382 .155 .441 r
.31011 .57592 m .30783 .57682 L .30812 .57459 L F
0 .148 .676 r
.21324 .61022 m .21261 .61174 L .21133 .60812 L F
.012 .216 .725 r
.21324 .61022 m .21479 .61392 L .21261 .61174 L F
.683 .707 .866 r
.33962 .66288 m .3405 .66442 L .33676 .66415 L F
.722 .575 .689 r
.3405 .66442 m .33838 .6658 L .33676 .66415 L F
.679 .492 .626 r
.3405 .66442 m .34051 .66773 L .33838 .6658 L F
.689 .709 .864 r
.343 .66363 m .3405 .66442 L .33962 .66288 L F
.679 .492 .626 r
.3435 .66467 m .3405 .66442 L .343 .66363 L F
.3435 .66467 m .34051 .66773 L .3405 .66442 L F
.811 .333 .068 r
.33232 .60876 m .33072 .60558 L .33001 .60651 L F
.924 .535 .18 r
.33001 .60651 m .33072 .60558 L .32943 .60499 L F
.435 .813 .992 r
.24123 .55071 m .23984 .54986 L .23749 .55038 L F
.879 .94 .852 r
.2417 .54726 m .24123 .55071 L .24348 .5503 L F
.2417 .54726 m .23984 .54986 L .24123 .55071 L F
.531 .597 .865 r
.20108 .5941 m .19952 .59684 L .19735 .5937 L F
.402 .434 .779 r
.20108 .5941 m .20218 .59829 L .19952 .59684 L F
.598 .352 .515 r
.35137 .53644 m .3539 .53655 L .35397 .53413 L F
.68 .42 .522 r
.35397 .53413 m .35699 .53612 L .35662 .53338 L F
.35397 .53413 m .3539 .53655 L .35699 .53612 L F
.53 .511 .78 r
.29813 .63332 m .29923 .62907 L .29689 .62939 L F
.29813 .63332 m .30042 .63275 L .29923 .62907 L F
.534 .333 .554 r
.2978 .63581 m .30042 .63275 L .29813 .63332 L F
.719 .473 .553 r
.31068 .65105 m .31371 .64849 L .3111 .64893 L F
.589 .507 .729 r
.30999 .63331 m .30834 .63634 L .3075 .6339 L F
.53 .307 .52 r
.32681 .60523 m .32943 .60499 L .32757 .60238 L F
.031 0 .355 r
.34663 .58468 m .34652 .58753 L .34794 .58382 L F
.34663 .58468 m .34794 .58382 L .34802 .5835 L F
.944 .8 .67 r
.3464 .58492 m .34785 .58389 L .34798 .58322 L F
.778 .677 .752 r
.348 .58359 m .3481 .58607 L .34814 .58319 L F
.031 0 .355 r
.34803 .58349 m .34794 .58382 L .34809 .58344 L F
.34802 .5835 m .348 .58359 L .34803 .58349 L F
.944 .8 .67 r
.34749 .58566 m .3481 .58607 L .348 .58359 L F
.031 0 .355 r
.348 .58359 m .34794 .58382 L .34803 .58349 L F
.778 .677 .752 r
.34814 .58319 m .3481 .58607 L .35043 .58277 L F
.944 .601 .336 r
.34744 .58017 m .34806 .58333 L .34798 .58322 L F
.778 .677 .752 r
.34798 .58322 m .348 .58359 L .34808 .58335 L F
.944 .601 .336 r
.34806 .58333 m .34809 .58344 L .34798 .58322 L F
.778 .677 .752 r
.34798 .58322 m .34808 .58335 L .34814 .58319 L F
.944 .8 .67 r
.3464 .58492 m .34809 .58344 L .34794 .58382 L F
.84 .838 .844 r
.34381 .58775 m .34547 .58909 L .34631 .58812 L F
.944 .8 .67 r
.34647 .58654 m .34794 .58382 L .34652 .58753 L F
.84 .838 .844 r
.34646 .58671 m .34631 .58812 L .3481 .58607 L F
.197 .636 .947 r
.34652 .58753 m .34179 .58618 L .34474 .58639 L F
.34522 .58669 m .34474 .58639 L .34477 .58639 L F
.34652 .58753 m .34474 .58639 L .34522 .58669 L F
.84 .838 .844 r
.34381 .58775 m .34631 .58812 L .34639 .5874 L F
.944 .8 .67 r
.3464 .58492 m .34652 .58753 L .34477 .58639 L F
.84 .838 .844 r
.34573 .587 m .34639 .5874 L .34646 .58671 L F
.34381 .58775 m .34639 .5874 L .34573 .587 L F
.944 .8 .67 r
.3464 .58492 m .34666 .58474 L .34647 .58654 L F
.34666 .58474 m .34794 .58382 L .34647 .58654 L F
.3464 .58492 m .34749 .58566 L .34785 .58389 L F
.34749 .58566 m .348 .58359 L .34798 .58322 L F
.709 .628 .765 r
.36251 .52879 m .35893 .52785 L .36116 .5271 L F
.551 .409 .642 r
.36492 .52778 m .36251 .52879 L .36116 .5271 L F
.36492 .52778 m .36514 .5303 L .36251 .52879 L F
.034 .376 .842 r
.21669 .61384 m .21636 .61511 L .21479 .61392 L F
.21669 .61384 m .21867 .6163 L .21636 .61511 L F
.542 .523 .784 r
.29393 .54204 m .29673 .54348 L .29477 .54387 L F
.174 0 0 r
.29384 .54493 m .29673 .54348 L .29477 .54387 L F
.622 .244 .305 r
.30393 .60226 m .30718 .60203 L .30622 .60425 L F
0 0 0 r
.30622 .60425 m .30718 .60203 L .30853 .60042 L F
.419 .244 .536 r
.34507 .61149 m .34725 .6083 L .34316 .60825 L F
.626 .746 .934 r
.25774 .62461 m .25348 .62362 L .25531 .62346 L F
.522 .048 .07 r
.25531 .62346 m .25922 .62291 L .25774 .62461 L F
.416 .403 .738 r
.33624 .59107 m .33914 .5915 L .33839 .58854 L F
.389 .552 .895 r
.21634 .62635 m .21565 .62274 L .21367 .62318 L F
.21634 .62635 m .21813 .6262 L .21565 .62274 L F
.78 .469 .461 r
.26846 .54856 m .26775 .54591 L .26951 .54641 L F
.26846 .54856 m .2647 .54825 L .26775 .54591 L F
.085 .282 .765 r
.36966 .60079 m .37127 .60441 L .36884 .60235 L F
.413 .327 .649 r
.31789 .62252 m .31522 .62059 L .31613 .62058 L F
.31789 .62252 m .31539 .62361 L .31522 .62059 L F
.419 .244 .536 r
.34507 .61149 m .34717 .61094 L .34725 .6083 L F
.973 .768 .568 r
.53048 .55275 m .52846 .55482 L .52927 .55021 L F
.53048 .55275 m .52987 .55594 L .52846 .55482 L F
.701 .475 .578 r
.53195 .55531 m .52987 .55594 L .53048 .55275 L F
.521 .305 .527 r
.33364 .6383 m .3313 .63613 L .33362 .63601 L F
.33364 .6383 m .33093 .63892 L .3313 .63613 L F
.144 .162 .62 r
.32611 .651 m .326 .65408 L .32436 .65253 L F
.153 .691 .831 r
.27498 .53058 m .27731 .53042 L .27893 .53058 L F
.244 .753 .873 r
.27731 .53042 m .28131 .53026 L .27893 .53058 L F
.459 .82 .995 r
.27973 .53009 m .28003 .53012 L .28131 .53026 L F
.225 .742 .856 r
.2818 .53032 m .28131 .53026 L .28262 .53025 L F
.208 0 0 r
.28131 .53026 m .28361 .53046 L .28523 .53028 L F
.459 .82 .995 r
.28003 .53012 m .28361 .53046 L .28131 .53026 L F
.225 .742 .856 r
.27893 .53058 m .28131 .53026 L .2818 .53032 L F
.685 .673 .833 r
.3481 .58607 m .34965 .58987 L .35177 .58687 L F
.622 .584 .79 r
.34965 .58987 m .35227 .58949 L .35177 .58687 L F
.607 .548 .763 r
.34965 .58987 m .35344 .59265 L .35227 .58949 L F
.669 .424 .542 r
.33839 .58854 m .34179 .58618 L .33951 .58613 L F
.737 .399 .408 r
.32004 .55611 m .31632 .55753 L .31554 .55639 L F
.32004 .55611 m .31822 .55833 L .31632 .55753 L F
.285 0 .081 r
.32176 .55725 m .32004 .55611 L .32225 .55508 L F
.32176 .55725 m .31822 .55833 L .32004 .55611 L F
.657 .368 .47 r
.35164 .54331 m .35385 .5433 L .35526 .54028 L F
.56 .477 .717 r
.35526 .54028 m .35699 .53612 L .3539 .53655 L F
.35526 .54028 m .35769 .53975 L .35699 .53612 L F
0 0 0 r
.35526 .54028 m .35505 .54136 L .35769 .53975 L F
.35526 .54028 m .35385 .5433 L .35505 .54136 L F
.169 0 .164 r
.33513 .57057 m .3323 .57344 L .33322 .57158 L F
.513 .599 .877 r
.29725 .55552 m .29774 .55192 L .29541 .55255 L F
.29725 .55552 m .29943 .55505 L .29774 .55192 L F
.501 .464 .748 r
.29725 .55552 m .30061 .55837 L .29943 .55505 L F
.251 0 0 r
.22229 .53755 m .21897 .53925 L .22033 .54033 L F
.139 0 0 r
.22238 .53861 m .22229 .53755 L .22033 .54033 L F
.211 .452 .873 r
.31554 .60858 m .31447 .60702 L .31662 .6048 L F
.464 .455 .763 r
.31961 .60708 m .31554 .60858 L .31662 .6048 L F
.125 0 .356 r
.31961 .60708 m .31704 .61058 L .31554 .60858 L F
.664 .683 .858 r
.3388 .53988 m .3426 .54076 L .34126 .53898 L F
.439 .339 .645 r
.31626 .58409 m .31783 .58398 L .31792 .58005 L F
.445 .412 .728 r
.31626 .58409 m .31911 .58589 L .31783 .58398 L F
.761 .558 .623 r
.26113 .71661 m .26096 .72019 L .25845 .7196 L F
0 0 0 r
.2598 .71871 m .26113 .71661 L .25845 .7196 L F
.379 .238 .561 r
.26322 .71905 m .26113 .71661 L .2634 .71637 L F
.26322 .71905 m .26096 .72019 L .2611 .71721 L F
.26153 .71708 m .2611 .71721 L .26113 .71661 L F
.26322 .71905 m .2611 .71721 L .26153 .71708 L F
.282 0 .011 r
.26321 .71655 m .2598 .71871 L .26149 .7182 L F
.2634 .71637 m .26303 .71661 L .26321 .71655 L F
.26303 .71661 m .2598 .71871 L .26321 .71655 L F
.2634 .71637 m .26113 .71661 L .2598 .71871 L F
.458 .239 .493 r
.35977 .56166 m .36231 .5613 L .36252 .55882 L F
.719 .244 .118 r
.36109 .56383 m .36231 .5613 L .35977 .56166 L F
.108 0 .163 r
.29981 .58616 m .29711 .58933 L .29823 .58714 L F
.693 .41 .491 r
.53068 .52756 m .53267 .53021 L .53253 .52795 L F
.53068 .52756 m .52938 .53035 L .53267 .53021 L F
.334 .119 .432 r
.32043 .63243 m .31778 .63652 L .32018 .63551 L F
.364 .157 .46 r
.32241 .6324 m .32043 .63243 L .32018 .63551 L F
.64 .473 .641 r
.51295 .55266 m .51088 .55651 L .51208 .5537 L F
.51295 .55266 m .51292 .55499 L .51088 .55651 L F
.675 .462 .59 r
.37035 .59457 m .36828 .59597 L .36899 .59358 L F
.726 .877 .951 r
.33914 .5915 m .34067 .59263 L .34272 .59116 L F
.444 .209 .462 r
.37948 .57698 m .37903 .57995 L .37695 .58001 L F
.38131 .57929 m .37948 .57698 L .38176 .57624 L F
.38131 .57929 m .37903 .57995 L .37948 .57698 L F
.51 .69 .949 r
.30772 .59438 m .30867 .59617 L .31002 .59406 L F
.30772 .59438 m .30867 .59617 L .31002 .59406 L F
.576 .405 .612 r
.31567 .64 m .318 .63941 L .31778 .63652 L F
.43 .296 .596 r
.31778 .63652 m .31993 .63937 L .32018 .63551 L F
.31778 .63652 m .318 .63941 L .31993 .63937 L F
.682 .794 .934 r
.33655 .61031 m .33849 .61156 L .33452 .61111 L F
.876 .864 .824 r
.34028 .60723 m .33849 .61156 L .33655 .61031 L F
.562 .18 .275 r
.32085 .56702 m .32376 .56706 L .32544 .56448 L F
.168 0 .04 r
.32544 .56448 m .32586 .56625 L .32735 .56498 L F
.32544 .56448 m .32376 .56706 L .32586 .56625 L F
.893 .9 .826 r
.33676 .66415 m .33416 .6671 L .33244 .66619 L F
.726 .575 .685 r
.33676 .66415 m .33838 .6658 L .33416 .6671 L F
.893 .9 .826 r
.33676 .66415 m .33244 .66619 L .33551 .66599 L F
.33676 .66415 m .33551 .66599 L .33455 .6636 L F
.697 .954 .952 r
.33676 .66415 m .33707 .6621 L .33962 .66288 L F
.33676 .66415 m .33455 .6636 L .33707 .6621 L F
.503 .673 .94 r
.38257 .56856 m .38131 .57054 L .37945 .56806 L F
.38257 .56856 m .38365 .57003 L .38131 .57054 L F
.164 0 0 r
.2106 .54346 m .21099 .54466 L .21282 .54278 L F
.2106 .54346 m .20873 .54524 L .21099 .54466 L F
.128 0 0 r
.52799 .56412 m .5275 .56457 L .52442 .56477 L F
.538 .838 .516 r
.52929 .56267 m .5275 .56457 L .52799 .56412 L F
.415 .529 .865 r
.30234 .55283 m .29935 .55028 L .30179 .54938 L F
.451 .851 .973 r
.32721 .53248 m .32898 .53189 L .33064 .53238 L F
.445 .845 .975 r
.32898 .53189 m .33363 .53188 L .33064 .53238 L F
.343 0 0 r
.33416 .6671 m .33838 .6658 L .33604 .66801 L F
.807 .378 .227 r
.33838 .6658 m .33862 .66889 L .33604 .66801 L F
.33838 .6658 m .34051 .66773 L .33862 .66889 L F
.251 .044 .391 r
.32885 .64238 m .32842 .64516 L .32679 .64527 L F
.486 .398 .682 r
.32887 .64785 m .32679 .64527 L .32842 .64516 L F
.32887 .64785 m .32711 .64865 L .32679 .64527 L F
.164 .678 .894 r
.29205 .66755 m .29667 .66768 L .29607 .66544 L F
.063 0 0 r
.29673 .66537 m .29607 .66544 L .29686 .66573 L F
0 0 .354 r
.29686 .66573 m .29607 .66544 L .29667 .66768 L F
.512 .879 .979 r
.24714 .62499 m .25017 .62417 L .25112 .62464 L F
.834 .972 .885 r
.25112 .62464 m .25133 .62249 L .25348 .62362 L F
.25112 .62464 m .25017 .62417 L .25133 .62249 L F
.273 0 0 r
.24459 .55717 m .24862 .55557 L .24523 .55642 L F
.24459 .55717 m .24708 .55712 L .24862 .55557 L F
.188 0 .183 r
.24862 .55557 m .25037 .55502 L .25146 .55277 L F
.767 .483 .504 r
.24708 .55712 m .25037 .55502 L .24862 .55557 L F
.014 .584 .773 r
.24328 .53327 m .24541 .53339 L .24723 .53365 L F
.422 .85 .947 r
.24723 .53365 m .24774 .53276 L .24955 .53305 L F
.24723 .53365 m .24541 .53339 L .24774 .53276 L F
0 0 0 r
.35322 .66442 m .35164 .66455 L .34935 .66464 L F
.501 .316 .561 r
.35565 .66108 m .35557 .66414 L .35322 .66442 L F
.246 .759 .84 r
.35557 .66414 m .35164 .66455 L .35322 .66442 L F
.061 0 0 r
.24737 .54949 m .24578 .5502 L .24348 .5503 L F
.593 .616 .844 r
.24944 .5484 m .24737 .54949 L .24616 .54686 L F
.578 .172 .236 r
.24944 .5484 m .24578 .5502 L .24737 .54949 L F
.809 .975 .678 r
.25368 .54964 m .25269 .55103 L .25232 .55075 L F
.267 .768 .88 r
.25459 .5504 m .25199 .5505 L .25232 .55075 L F
.187 .715 .845 r
.25232 .55075 m .2478 .55078 L .24944 .5484 L F
.267 .768 .88 r
.25199 .5505 m .25006 .55058 L .25232 .55075 L F
.809 .975 .678 r
.25269 .55103 m .25146 .55277 L .25232 .55075 L F
.482 .16 .344 r
.25146 .55277 m .2531 .5544 L .25232 .55075 L F
.25146 .55277 m .25037 .55502 L .2531 .5544 L F
.418 .661 .96 r
.20397 .59844 m .20348 .60028 L .20218 .59829 L F
.20397 .59844 m .2065 .60073 L .20348 .60028 L F
.719 .244 .118 r
.36109 .56383 m .36172 .56303 L .36231 .5613 L F
.36109 .56383 m .35911 .56422 L .36172 .56303 L F
.584 .361 .543 r
.36109 .56383 m .36025 .56795 L .36301 .56577 L F
.36301 .56548 m .36301 .56577 L .36318 .56563 L F
.36296 .56547 m .36301 .56577 L .36301 .56548 L F
.36292 .56537 m .36318 .56563 L .3632 .56561 L F
.484 .214 .427 r
.36025 .56795 m .36313 .56745 L .3633 .56554 L F
.585 .297 .446 r
.3633 .56554 m .36313 .56745 L .36296 .56547 L F
.3633 .56554 m .36296 .56547 L .36295 .56538 L F
.584 .361 .543 r
.36296 .56544 m .36296 .56547 L .36301 .56548 L F
.36109 .56383 m .36301 .56577 L .36296 .56544 L F
.952 .627 .212 r
.36295 .5654 m .36313 .56745 L .36274 .56658 L F
.36295 .56538 m .36296 .56547 L .36295 .5654 L F
.36296 .56547 m .36313 .56745 L .36295 .5654 L F
.541 .513 .775 r
.36274 .56658 m .35911 .56422 L .36292 .56537 L F
.36295 .5654 m .36292 .56537 L .36295 .56538 L F
.36274 .56658 m .36292 .56537 L .36295 .5654 L F
.584 .361 .543 r
.36109 .56383 m .36318 .56563 L .36292 .56537 L F
.719 .244 .118 r
.36109 .56383 m .36295 .56538 L .36292 .56537 L F
.584 .361 .543 r
.36109 .56383 m .3633 .56554 L .36295 .56538 L F
.36109 .56383 m .3632 .56561 L .3633 .56554 L F
.719 .244 .118 r
.36109 .56383 m .36292 .56537 L .35911 .56422 L F
.61 .861 .508 r
.27945 .55357 m .28108 .55134 L .2821 .55457 L F
.349 .075 .35 r
.35578 .56796 m .35682 .5696 L .3561 .56805 L F
.35578 .56796 m .35462 .57041 L .35682 .5696 L F
.589 .507 .729 r
.30999 .63331 m .31089 .63579 L .30834 .63634 L F
.424 .456 .79 r
.31188 .63848 m .30834 .63634 L .31089 .63579 L F
.558 .028 0 r
.29393 .54204 m .29263 .54269 L .29277 .54232 L F
.679 .182 .058 r
.29393 .54204 m .29673 .54348 L .29263 .54269 L F
.15 0 .27 r
.29102 .60202 m .29334 .59879 L .29276 .60106 L F
0 0 .25 r
.29188 .60343 m .29102 .60202 L .29276 .60106 L F
.29188 .60343 m .29161 .6032 L .29102 .60202 L F
.287 .485 .877 r
.28411 .66681 m .28896 .67059 L .28974 .66738 L F
.653 .35 .447 r
.29217 .66975 m .28974 .66738 L .28896 .67059 L F
.29217 .66975 m .29205 .66755 L .28974 .66738 L F
0 .203 .731 r
.30393 .60226 m .30479 .60157 L .30236 .60123 L F
.30393 .60226 m .30622 .60425 L .30479 .60157 L F
.921 .648 .161 r
.30666 .55273 m .30689 .55527 L .30776 .55172 L F
.7 .269 .223 r
.37087 .53677 m .36878 .53859 L .36651 .53624 L F
.063 0 0 r
.37281 .53725 m .36878 .53859 L .37087 .53677 L F
0 0 .218 r
.19696 .58652 m .19618 .58916 L .19506 .58983 L F
.14 .069 .508 r
.19618 .58916 m .19637 .59181 L .19506 .58983 L F
.215 .091 .487 r
.19506 .58983 m .19637 .59181 L .19501 .59248 L F
.504 .599 .882 r
.51794 .53788 m .51667 .54012 L .51391 .53785 L F
.51794 .53788 m .5192 .53983 L .51667 .54012 L F
.109 0 0 r
.30218 .65304 m .30278 .65357 L .30047 .6532 L F
0 .453 .753 r
.30218 .65304 m .30693 .65442 L .30515 .65272 L F
.109 0 0 r
.30218 .65304 m .30515 .65272 L .30278 .65357 L F
.444 .667 .957 r
.21244 .79374 m .21049 .79408 L .20817 .79188 L F
0 0 0 r
.20738 .79496 m .21049 .79408 L .21244 .79374 L F
.572 .172 .245 r
.33102 .54085 m .32612 .53997 L .32833 .54047 L F
.411 .862 .84 r
.51127 .53842 m .51391 .53785 L .51274 .53712 L F
.279 .245 .64 r
.16811 .58649 m .16891 .58388 L .16741 .58399 L F
0 0 .199 r
.27771 .62341 m .27686 .62383 L .27841 .62048 L F
.024 .075 .578 r
.27836 .62592 m .27686 .62383 L .27771 .62341 L F
0 0 0 r
.26879 .61787 m .26889 .61853 L .27063 .61667 L F
.26879 .61787 m .26686 .61946 L .26889 .61853 L F
.23749 .55038 m .23294 .55135 L .23503 .55103 L F
.453 0 0 r
.26994 .64154 m .27417 .64231 L .27241 .64153 L F
0 .383 .739 r
.27417 .64231 m .27422 .64209 L .27241 .64153 L F
.27417 .64231 m .27625 .64308 L .27422 .64209 L F
.086 .016 .472 r
.35893 .52785 m .36058 .52874 L .36116 .5271 L F
.392 .713 .987 r
.25397 .63839 m .25516 .63689 L .25165 .63601 L F
.25397 .63839 m .25597 .63811 L .25516 .63689 L F
.83 .992 .861 r
.21908 .56327 m .21837 .56541 L .22056 .56503 L F
.21908 .56327 m .21732 .56492 L .21837 .56541 L F
.351 .212 .547 r
.31223 .63196 m .31031 .62974 L .31249 .62927 L F
.31223 .63196 m .30999 .63331 L .31031 .62974 L F
.659 .896 .981 r
.34432 .60123 m .34314 .60258 L .34603 .6021 L F
.761 .781 .869 r
.34314 .60258 m .34326 .60288 L .34603 .6021 L F
.628 .887 .988 r
.34635 .60033 m .34603 .6021 L .34843 .59899 L F
.34635 .60033 m .34432 .60123 L .34603 .6021 L F
.517 .339 .579 r
.34603 .6021 m .34848 .60155 L .34843 .59899 L F
.48 .463 .761 r
.34603 .6021 m .34912 .60532 L .34848 .60155 L F
.287 0 .249 r
.34239 .66858 m .34051 .66773 L .3435 .66467 L F
.613 .213 .26 r
.3435 .66467 m .34444 .66823 L .34239 .66858 L F
.3435 .66467 m .34664 .66544 L .34444 .66823 L F
0 .057 .59 r
.50325 .54759 m .50257 .55004 L .50237 .54844 L F
.548 .73 .959 r
.50325 .54759 m .50538 .54946 L .50257 .55004 L F
.365 0 0 r
.23707 .62224 m .23902 .62294 L .24091 .62314 L F
.076 .634 .797 r
.24091 .62314 m .23902 .62294 L .24317 .62312 L F
.28 0 .158 r
.29494 .63855 m .29275 .63923 L .2915 .64168 L F
.819 .553 .537 r
.50786 .54656 m .50766 .5484 L .50581 .54607 L F
.113 .308 .781 r
.30572 .59279 m .30772 .59438 L .30633 .59109 L F
.311 .073 .382 r
.31281 .55275 m .31218 .55511 L .31028 .55596 L F
.324 .056 .343 r
.31218 .55511 m .30957 .55806 L .31028 .55596 L F
0 0 0 r
.36416 .53718 m .3609 .53833 L .35933 .53856 L F
.36377 .53754 m .36416 .53718 L .36651 .53624 L F
.36377 .53754 m .3609 .53833 L .36416 .53718 L F
.601 .601 .823 r
.32225 .55508 m .32424 .55814 L .32776 .55721 L F
.547 .388 .617 r
.32424 .55814 m .32616 .55833 L .32776 .55721 L F
.32424 .55814 m .32616 .55833 L .32776 .55721 L F
.448 .217 .47 r
.37875 .58203 m .37695 .58001 L .37903 .57995 L F
.37875 .58203 m .37652 .58265 L .37695 .58001 L F
.53 .446 .705 r
.3048 .62074 m .30732 .62023 L .30656 .61722 L F
.414 .189 .461 r
.30513 .62163 m .30732 .62023 L .3048 .62074 L F
.065 0 0 r
.31165 .6071 m .30753 .60782 L .30917 .60708 L F
.439 .79 .997 r
.31159 .60549 m .31165 .6071 L .30917 .60708 L F
.224 .158 .569 r
.30917 .60708 m .31115 .60834 L .31133 .60609 L F
.30917 .60708 m .31133 .60609 L .31135 .60584 L F
.065 0 0 r
.30753 .60782 m .30691 .60793 L .30917 .60708 L F
.439 .79 .997 r
.31159 .60549 m .31447 .60702 L .31165 .6071 L F
.695 .541 .673 r
.52251 .552 m .51898 .55522 L .5196 .55269 L F
.52251 .552 m .52215 .5555 L .51898 .55522 L F
.679 .589 .747 r
.52492 .54937 m .52564 .55248 L .52251 .552 L F
.609 .404 .579 r
.52564 .55248 m .52215 .5555 L .52251 .552 L F
.483 .34 .61 r
.38443 .57319 m .38176 .57624 L .38162 .57425 L F
.386 .206 .511 r
.3176 .62571 m .31539 .62361 L .31789 .62252 L F
.3176 .62571 m .31516 .62607 L .31539 .62361 L F
.323 .773 .957 r
.25791 .55032 m .26048 .55024 L .26274 .55139 L F
.731 .306 .241 r
.28789 .66222 m .2845 .66103 L .28681 .66054 L F
.645 .655 .845 r
.2845 .66103 m .28789 .66222 L .28681 .66054 L F
.653 .863 .979 r
.33909 .53785 m .3388 .53988 L .34126 .53898 L F
.356 .733 .987 r
.33695 .54151 m .3388 .54269 L .3388 .53988 L F
.64 .814 .967 r
.31476 .53163 m .31053 .5312 L .31299 .53072 L F
.462 .803 .999 r
.31515 .53033 m .31476 .53163 L .31299 .53072 L F
.31515 .53033 m .31686 .53128 L .31476 .53163 L F
.591 .894 .988 r
.35565 .66108 m .35666 .65943 L .35829 .66053 L F
.518 .33 .565 r
.35812 .66358 m .35565 .66108 L .35829 .66053 L F
.35812 .66358 m .35557 .66414 L .35565 .66108 L F
.346 .098 .388 r
.34445 .59556 m .34182 .59905 L .34392 .59846 L F
.34 .004 .24 r
.34392 .59846 m .3475 .59491 L .34445 .59556 L F
.432 .466 .795 r
.50007 .55552 m .50173 .55998 L .50305 .55692 L F
.629 .696 .893 r
.50305 .55692 m .50173 .55998 L .50376 .55947 L F
.347 .322 .688 r
.16811 .58649 m .16847 .59007 L .17038 .58855 L F
.355 .311 .67 r
.16908 .59266 m .17038 .58855 L .16847 .59007 L F
.208 .258 .695 r
.30376 .55131 m .30234 .55283 L .30179 .54938 L F
.097 .035 .49 r
.30423 .5541 m .30234 .55283 L .30376 .55131 L F
.461 .166 .378 r
.20538 .7955 m .20628 .79279 L .20344 .79407 L F
.765 .647 .731 r
.30476 .56171 m .3023 .5627 L .30061 .55837 L F
.782 .52 .539 r
.30476 .56171 m .30053 .56381 L .3023 .5627 L F
.30476 .56171 m .30456 .56433 L .30053 .56381 L F
.536 .745 .972 r
.30583 .55945 m .30715 .56118 L .30476 .56171 L F
.773 .676 .757 r
.30715 .56118 m .30456 .56433 L .30476 .56171 L F
.464 .829 .993 r
.26742 .64196 m .26839 .64086 L .2661 .64136 L F
.26742 .64196 m .26994 .64154 L .26839 .64086 L F
.529 .332 .557 r
.32887 .64785 m .32611 .651 L .32711 .64865 L F
.991 .733 .399 r
.30683 .65111 m .30713 .64908 L .30549 .64741 L F
.28 .768 .688 r
.2486 .55942 m .24526 .56069 L .24606 .55987 L F
0 0 0 r
.20305 .5704 m .1996 .57331 L .20057 .57108 L F
.519 .183 .339 r
.20609 .56839 m .20538 .5703 L .20305 .5704 L F
.525 .219 .39 r
.20858 .56797 m .20538 .5703 L .20609 .56839 L F
.27 0 .101 r
.34463 .64193 m .34147 .64374 L .34186 .64298 L F
.6 .629 .852 r
.3011 .66637 m .29906 .66763 L .29673 .66537 L F
.66 .914 .978 r
.29935 .66648 m .29906 .66763 L .3011 .66637 L F
.412 .688 .976 r
.2992 .66533 m .3011 .66637 L .29673 .66537 L F
.66 .914 .978 r
.2977 .66659 m .29833 .66707 L .29935 .66648 L F
.29833 .66707 m .29906 .66763 L .29935 .66648 L F
.2977 .66659 m .3011 .66637 L .30067 .66931 L F
.423 .204 .474 r
.30332 .66587 m .3011 .66637 L .30067 .66931 L F
.30332 .66587 m .30067 .66931 L .30297 .66874 L F
.666 .433 .558 r
.30297 .66874 m .30004 .66609 L .30067 .66931 L F
.30004 .66609 m .2992 .66533 L .29958 .66635 L F
.30004 .66609 m .29958 .66635 L .30067 .66931 L F
.414 .202 .48 r
.36231 .5613 m .36479 .55817 L .36252 .55882 L F
.223 0 0 r
.27868 .64324 m .28041 .6433 L .2828 .64387 L F
.707 .57 .698 r
.31371 .64849 m .31733 .64863 L .31683 .6464 L F
.571 .496 .732 r
.31733 .64863 m .31894 .64478 L .31683 .6464 L F
.489 .726 .977 r
.22727 .61643 m .22661 .61835 L .22497 .61706 L F
.22727 .61643 m .22891 .61795 L .22661 .61835 L F
.45 .795 .998 r
.522 .56516 m .52298 .56382 L .52062 .56393 L F
.522 .56516 m .52442 .56477 L .52298 .56382 L F
0 0 0 r
.18743 .55828 m .18918 .55759 L .19055 .55583 L F
.084 0 0 r
.19055 .55583 m .19123 .55679 L .1926 .55505 L F
.19055 .55583 m .18918 .55759 L .19123 .55679 L F
.162 0 .394 r
.29571 .59536 m .29516 .59862 L .29334 .59879 L F
0 0 0 r
.29516 .59862 m .29276 .60106 L .29334 .59879 L F
.648 .598 .785 r
.51586 .55134 m .51849 .54932 L .51553 .55136 L F
.187 .003 .385 r
.29161 .6032 m .28824 .60763 L .28822 .60534 L F
.478 .548 .85 r
.50376 .55947 m .50648 .56291 L .50686 .56003 L F
.603 .212 .275 r
.27961 .6806 m .28219 .67975 L .27854 .68109 L F
0 0 .049 r
.29965 .56807 m .30053 .56381 L .30224 .56507 L F
.29965 .56807 m .30023 .56655 L .30053 .56381 L F
0 0 .454 r
.29965 .56807 m .30059 .5697 L .30023 .56655 L F
.29965 .56807 m .29995 .57067 L .30059 .5697 L F
.684 .568 .719 r
.31465 .55175 m .31218 .55511 L .31281 .55275 L F
.689 .709 .864 r
.343 .66363 m .33962 .66288 L .34142 .66036 L F
.813 .752 .795 r
.34538 .66074 m .343 .66363 L .34142 .66036 L F
.74 .62 .725 r
.35104 .59604 m .3475 .59491 L .34964 .59464 L F
.35104 .59604 m .34843 .59899 L .3475 .59491 L F
.603 .1 .029 r
.34922 .59744 m .35104 .59604 L .34964 .59464 L F
.34922 .59744 m .35285 .59776 L .35104 .59604 L F
.568 .406 .622 r
.35104 .59604 m .35353 .59592 L .35344 .59265 L F
.49 .128 .279 r
.35104 .59604 m .35285 .59776 L .35353 .59592 L F
.419 .531 .864 r
.21191 .62355 m .21179 .6198 L .20982 .62016 L F
.21191 .62355 m .21367 .62318 L .21179 .6198 L F
0 0 0 r
.32742 .54617 m .32745 .54666 L .32992 .54735 L F
.32742 .54617 m .32559 .54784 L .32745 .54666 L F
.368 .61 .943 r
.19148 .60707 m .19206 .60855 L .19284 .60683 L F
.018 .171 .682 r
.19206 .60855 m .19406 .61061 L .19284 .60683 L F
.346 .112 .409 r
.17962 .56494 m .18113 .56677 L .18161 .56425 L F
.17962 .56494 m .1791 .5676 L .18113 .56677 L F
.619 .487 .679 r
.51523 .54743 m .51947 .54678 L .51849 .54932 L F
.719 .473 .553 r
.31068 .65105 m .31373 .65156 L .31371 .64849 L F
.68 .441 .553 r
.31371 .64849 m .31707 .65082 L .31733 .64863 L F
.31371 .64849 m .31373 .65156 L .31707 .65082 L F
0 0 0 r
.36679 .60996 m .36692 .60848 L .36885 .60778 L F
.36679 .60996 m .36618 .61094 L .36692 .60848 L F
.598 .652 .874 r
.20328 .61802 m .20792 .62046 L .20608 .61875 L F
.433 .646 .947 r
.20792 .62046 m .20867 .6188 L .20608 .61875 L F
.20792 .62046 m .20982 .62016 L .20867 .6188 L F
.36 0 0 r
.33641 .54127 m .3346 .5421 L .33226 .54159 L F
.575 .915 .696 r
.3332 .54034 m .33226 .54159 L .3346 .5421 L F
.3332 .54034 m .3317 .54152 L .33226 .54159 L F
.571 .496 .732 r
.31733 .64863 m .31987 .6482 L .31894 .64478 L F
.524 .281 .488 r
.31707 .65082 m .31946 .65075 L .31733 .64863 L F
.514 .281 .499 r
.31733 .64863 m .31946 .65075 L .31987 .6482 L F
.8 .72 .776 r
.24881 .73619 m .24965 .73819 L .24738 .73727 L F
.685 .494 .622 r
.24738 .73727 m .24822 .73889 L .24847 .73776 L F
.24738 .73727 m .24847 .73776 L .24881 .73619 L F
0 0 .263 r
.24881 .73619 m .24847 .73776 L .24973 .73669 L F
.24847 .73776 m .24822 .73889 L .24883 .738 L F
.376 0 0 r
.24829 .73764 m .24965 .73819 L .24847 .73776 L F
0 0 .263 r
.24847 .73776 m .24883 .738 L .24973 .73669 L F
.376 0 0 r
.24847 .73776 m .24965 .73819 L .24891 .73795 L F
.24738 .73727 m .24829 .73764 L .24847 .73776 L F
.24738 .73727 m .24891 .73795 L .24801 .73767 L F
.572 .586 .829 r
.25088 .7351 m .25212 .73796 L .24965 .73819 L F
.635 .768 .943 r
.24973 .73669 m .24893 .73785 L .24801 .73767 L F
.24893 .73785 m .24822 .73889 L .24801 .73767 L F
.139 .685 .791 r
.24965 .73819 m .24987 .73804 L .24801 .73767 L F
.24987 .73804 m .25004 .73792 L .24801 .73767 L F
.24965 .73819 m .25212 .73796 L .25004 .73792 L F
.825 .715 .744 r
.34538 .66074 m .34142 .66036 L .34141 .65963 L F
0 0 .157 r
.34591 .56141 m .34517 .5648 L .34446 .56503 L F
0 .12 .659 r
.34517 .5648 m .34635 .56725 L .34446 .56503 L F
.603 .268 .375 r
.34446 .56503 m .34635 .56725 L .34423 .56606 L F
.456 .226 .475 r
.33708 .62873 m .33511 .62699 L .33727 .62631 L F
.33708 .62873 m .33512 .6293 L .33511 .62699 L F
.521 .37 .616 r
.34055 .55163 m .33764 .54936 L .33986 .54904 L F
.34055 .55163 m .33765 .55242 L .33764 .54936 L F
.419 .744 .993 r
.29801 .53012 m .29391 .52905 L .29625 .52877 L F
.488 .756 .989 r
.29853 .52818 m .29801 .53012 L .29625 .52877 L F
.29853 .52818 m .30029 .52977 L .29801 .53012 L F
.536 .248 .425 r
.30469 .58549 m .30569 .58872 L .30685 .5858 L F
.208 0 0 r
.28131 .53026 m .28523 .53028 L .28262 .53025 L F
.567 .642 .884 r
.5091 .56553 m .51198 .56528 L .51068 .56312 L F
0 0 .463 r
.34617 .62581 m .34606 .62565 L .3443 .62354 L F
.637 .238 0 r
.34617 .62581 m .34689 .62713 L .34606 .62565 L F
.079 .513 .901 r
.2828 .64387 m .28442 .64533 L .28474 .64452 L F
.101 .539 .911 r
.28474 .64452 m .28442 .64533 L .28624 .64569 L F
.096 .454 .885 r
.37608 .52935 m .37763 .53121 L .37567 .53063 L F
.57 .534 .775 r
.3791 .53394 m .37567 .53063 L .37763 .53121 L F
.036 0 .386 r
.28138 .6021 m .28128 .60466 L .28275 .6005 L F
.458 .886 .887 r
.28523 .53028 m .28598 .52946 L .28754 .52993 L F
.28523 .53028 m .28361 .53046 L .28598 .52946 L F
.767 .666 .751 r
.34717 .61094 m .34972 .60782 L .34725 .6083 L F
.091 0 0 r
.24955 .53305 m .25185 .53306 L .25326 .53285 L F
0 0 0 r
.25185 .53306 m .25547 .53226 L .25326 .53285 L F
.457 .24 .495 r
.37977 .56496 m .37945 .56806 L .37717 .56818 L F
.493 .278 .515 r
.38213 .56436 m .37945 .56806 L .37977 .56496 L F
.609 .404 .579 r
.52564 .55248 m .52567 .55625 L .52215 .5555 L F
.027 .133 .64 r
.52675 .55084 m .52564 .55248 L .52492 .54937 L F
.49 .31 .564 r
.52846 .55482 m .52564 .55248 L .52675 .55084 L F
.52846 .55482 m .52567 .55625 L .52564 .55248 L F
.228 .089 .474 r
.29305 .58352 m .29491 .5827 L .29515 .57977 L F
0 0 .181 r
.29287 .58599 m .29491 .5827 L .29305 .58352 L F
.944 .601 .336 r
.34744 .58017 m .34798 .58322 L .34779 .58004 L F
0 .268 .648 r
.33244 .66619 m .33416 .6671 L .33604 .66801 L F
.468 .43 .732 r
.16778 .59984 m .16938 .59796 L .16729 .59821 L F
.16778 .59984 m .17026 .60146 L .16938 .59796 L F
.837 .929 .891 r
.51602 .56612 m .51681 .56314 L .51427 .56411 L F
.51602 .56612 m .51894 .56362 L .51681 .56314 L F
.16 .689 .863 r
.24352 .6361 m .24421 .63572 L .24185 .63495 L F
.24352 .6361 m .24591 .63602 L .24421 .63572 L F
.366 .413 .777 r
.34848 .60155 m .34635 .60033 L .34843 .59899 L F
.209 0 0 r
.22934 .55398 m .22865 .55298 L .23071 .55198 L F
.22934 .55398 m .2268 .55452 L .22865 .55298 L F
.773 .676 .757 r
.30715 .56118 m .30873 .56536 L .30456 .56433 L F
.448 .246 .512 r
.30957 .55806 m .30937 .56061 L .30715 .56118 L F
.537 .745 .972 r
.30583 .55945 m .30937 .56061 L .30715 .56118 L F
.139 .289 .756 r
.30856 .5623 m .30873 .56536 L .30715 .56118 L F
.30965 .56317 m .30715 .56118 L .30937 .56061 L F
.792 .435 .38 r
.30583 .55945 m .30656 .56196 L .30937 .56061 L F
.938 .893 .758 r
.30826 .55952 m .30656 .56196 L .30811 .55938 L F
.30937 .56061 m .30842 .56106 L .30826 .55952 L F
.30842 .56106 m .30656 .56196 L .30826 .55952 L F
.139 .289 .756 r
.30965 .56317 m .30885 .56508 L .30856 .5623 L F
.30885 .56508 m .30873 .56536 L .30856 .5623 L F
.701 .492 .602 r
.52215 .5555 m .51961 .55836 L .51898 .55522 L F
.482 .542 .842 r
.34313 .63697 m .34671 .63874 L .34452 .63936 L F
0 0 .374 r
.34551 .64052 m .34452 .63936 L .34671 .63874 L F
.34551 .64052 m .34463 .64193 L .34452 .63936 L F
.052 0 .135 r
.34954 .57758 m .34779 .58004 L .34964 .57952 L F
.512 .329 .57 r
.34954 .57758 m .35257 .57716 L .35245 .57412 L F
.756 .601 .685 r
.34964 .57952 m .35257 .57716 L .34954 .57758 L F
.144 .162 .62 r
.32611 .651 m .32695 .65431 L .326 .65408 L F
.9 .761 .699 r
.3452 .53529 m .34772 .53427 L .34657 .53359 L F
.868 .426 .044 r
.34545 .53155 m .34657 .53359 L .3474 .53388 L F
0 .07 .62 r
.34678 .53145 m .34657 .53359 L .34545 .53155 L F
.853 .982 .86 r
.34678 .53145 m .34524 .53313 L .34657 .53359 L F
.34524 .53313 m .34414 .53433 L .34657 .53359 L F
.868 .426 .044 r
.3474 .53388 m .34657 .53359 L .34772 .53427 L F
.821 .71 .743 r
.53968 .56102 m .54103 .5647 L .54311 .56146 L F
.686 .566 .714 r
.54199 .55798 m .54311 .56146 L .5458 .55821 L F
0 0 .349 r
.37519 .5445 m .37652 .54203 L .37504 .54349 L F
.438 .83 .612 r
.21897 .53925 m .21505 .54194 L .21736 .54167 L F
.048 0 0 r
.22033 .54033 m .21897 .53925 L .21736 .54167 L F
.416 .233 .522 r
.16925 .57721 m .17131 .57658 L .17149 .57399 L F
.397 .239 .547 r
.1693 .57978 m .17131 .57658 L .16925 .57721 L F
.582 .817 .988 r
.30456 .56433 m .30224 .56507 L .30053 .56381 L F
.279 .245 .64 r
.16811 .58649 m .16954 .58597 L .16891 .58388 L F
.347 .322 .688 r
.16811 .58649 m .17038 .58855 L .16954 .58597 L F
.576 .445 .665 r
.35699 .53612 m .35887 .53288 L .35662 .53338 L F
0 .55 .751 r
.22641 .53582 m .23041 .53631 L .22828 .53702 L F
.429 .036 .19 r
.32512 .61913 m .32334 .61769 L .32249 .61987 L F
.32512 .61913 m .32588 .61754 L .32334 .61769 L F
.526 .332 .56 r
.32334 .61769 m .32588 .61754 L .32595 .6144 L F
.524 .561 .835 r
.29689 .62939 m .29797 .62616 L .29596 .62749 L F
.29689 .62939 m .29923 .62907 L .29797 .62616 L F
.162 0 0 r
.25497 .55827 m .25082 .55826 L .2525 .55809 L F
.302 0 .272 r
.30618 .54502 m .30473 .54469 L .30735 .54354 L F
.30618 .54502 m .30401 .54598 L .30473 .54469 L F
.509 .103 .205 r
.23169 .75355 m .23611 .75122 L .23651 .7513 L F
.571 0 0 r
.23644 .7525 m .23651 .7513 L .23611 .75122 L F
.441 .567 .885 r
.19696 .58652 m .19318 .58365 L .19526 .58313 L F
.307 .452 .843 r
.19798 .58495 m .19696 .58652 L .19526 .58313 L F
.498 .413 .69 r
.19798 .58495 m .19618 .58916 L .19696 .58652 L F
.627 .589 .792 r
.37063 .59701 m .36828 .59597 L .37035 .59457 L F
.517 .433 .699 r
.37229 .59486 m .37063 .59701 L .37035 .59457 L F
.691 .827 .948 r
.2314 .55993 m .22874 .56108 L .23372 .5618 L F
.696 .828 .946 r
.2314 .55993 m .23372 .5618 L .23528 .55983 L F
.63 .644 .846 r
.54436 .54243 m .54576 .54345 L .54462 .53934 L F
.766 .479 .499 r
.54436 .54243 m .546 .54545 L .54576 .54345 L F
0 0 .122 r
.546 .54545 m .54611 .5475 L .54576 .54345 L F
.836 .764 .783 r
.54462 .53934 m .54576 .54345 L .54778 .53963 L F
0 0 .122 r
.546 .54545 m .54611 .5475 L .54576 .54345 L F
.55 .095 .125 r
.30853 .60042 m .31287 .59891 L .31101 .60053 L F
.30853 .60042 m .30954 .59932 L .31287 .59891 L F
.831 .443 .315 r
.31287 .59891 m .31449 .60161 L .31101 .60053 L F
.372 .167 .468 r
.16679 .59578 m .16873 .59527 L .16908 .59266 L F
.515 .465 .739 r
.16729 .59821 m .16873 .59527 L .16679 .59578 L F
.475 .291 .551 r
.32595 .6144 m .32812 .61663 L .32804 .6138 L F
.32595 .6144 m .32588 .61754 L .32812 .61663 L F
.681 .483 .612 r
.3214 .54921 m .32465 .55228 L .32412 .54869 L F
.3214 .54921 m .32177 .55274 L .32465 .55228 L F
.518 .504 .78 r
.19413 .57928 m .19318 .58365 L .1929 .58019 L F
.19413 .57928 m .19526 .58313 L .19318 .58365 L F
.74 .697 .811 r
.29918 .54038 m .29673 .54348 L .30062 .54323 L F
.428 0 0 r
.29636 .54425 m .30062 .54323 L .29673 .54348 L F
.29636 .54425 m .29877 .54452 L .30062 .54323 L F
.587 .626 .857 r
.29918 .54038 m .30062 .54323 L .30296 .5425 L F
.062 0 0 r
.29877 .54452 m .30296 .5425 L .30062 .54323 L F
.119 .114 .577 r
.35344 .59265 m .35445 .58855 L .35227 .58949 L F
.35344 .59265 m .35472 .59285 L .35445 .58855 L F
.227 .141 .544 r
.35344 .59265 m .35534 .59453 L .35472 .59285 L F
.35344 .59265 m .35353 .59592 L .35534 .59453 L F
.45 .465 .783 r
.32681 .60523 m .32783 .60827 L .33001 .60651 L F
.65 .574 .757 r
.32792 .61111 m .33001 .60651 L .32783 .60827 L F
.316 .728 .977 r
.24812 .63499 m .24993 .63595 L .25022 .63489 L F
.219 .629 .954 r
.25022 .63489 m .24993 .63595 L .25165 .63601 L F
.559 .321 .512 r
.27526 .54945 m .27265 .55188 L .27283 .54934 L F
.767 .666 .751 r
.34717 .61094 m .35139 .61113 L .34972 .60782 L F
.447 .343 .643 r
.34717 .61094 m .34954 .6134 L .35139 .61113 L F
.474 .469 .772 r
.35139 .61113 m .35224 .60723 L .34972 .60782 L F
.35139 .61113 m .35399 .61167 L .35224 .60723 L F
.713 .339 .338 r
.35139 .61113 m .34954 .6134 L .35383 .61358 L F
0 0 0 r
.30783 .57682 m .30609 .58056 L .30483 .58148 L F
.479 .57 .869 r
.30477 .58229 m .30551 .57877 L .30273 .58126 L F
.30487 .58234 m .30491 .58211 L .30477 .58229 L F
.30491 .58211 m .30551 .57877 L .30477 .58229 L F
0 0 0 r
.30609 .58056 m .30598 .5808 L .30585 .58088 L F
.30609 .58056 m .30585 .58088 L .30483 .58148 L F
.47 .474 .78 r
.30598 .5808 m .30487 .58234 L .30483 .58148 L F
.623 .397 .553 r
.39128 .55449 m .38966 .55228 L .39296 .55234 L F
.545 .578 .839 r
.39482 .55114 m .39522 .55181 L .39296 .55234 L F
.661 .457 .598 r
.39522 .55181 m .39128 .55449 L .39296 .55234 L F
.673 .599 .764 r
.5205 .56104 m .51894 .56362 L .51827 .56199 L F
.394 .852 .862 r
.36082 .52169 m .36056 .52106 L .36253 .52053 L F
.737 .458 .505 r
.36371 .52427 m .36082 .52169 L .36253 .52053 L F
.986 .717 .418 r
.36156 .52094 m .36371 .52427 L .3626 .52074 L F
.36156 .52094 m .3626 .52074 L .36253 .52053 L F
.096 0 0 r
.36056 .52106 m .36095 .52105 L .36156 .52094 L F
.282 .278 .678 r
.36317 .52103 m .36357 .52403 L .36156 .52094 L F
.737 .458 .505 r
.36371 .52427 m .35997 .52414 L .36082 .52169 L F
.591 .109 .079 r
.35997 .52414 m .36227 .52557 L .36371 .52427 L F
.985 .747 .49 r
.36371 .52427 m .36227 .52557 L .36156 .52094 L F
.096 0 0 r
.36095 .52105 m .36317 .52103 L .36156 .52094 L F
.606 .885 .572 r
.36116 .5271 m .36214 .52574 L .36371 .52427 L F
.659 .607 .785 r
.36371 .52427 m .36492 .52778 L .36116 .5271 L F
.606 .885 .572 r
.36214 .52574 m .36234 .5255 L .36371 .52427 L F
.168 0 0 r
.36371 .52427 m .36227 .52557 L .36376 .5255 L F
.282 .278 .678 r
.36357 .52403 m .36376 .5255 L .36324 .52442 L F
.36357 .52403 m .36324 .52442 L .36156 .52094 L F
.606 .885 .572 r
.36214 .52574 m .36227 .52557 L .36234 .5255 L F
.46 .355 .649 r
.36058 .52874 m .36227 .52557 L .36116 .5271 L F
.228 .355 .785 r
.34203 .64614 m .3451 .64803 L .34339 .64848 L F
.432 .395 .717 r
.3451 .64803 m .34339 .65117 L .34339 .64848 L F
.228 .355 .785 r
.34203 .64614 m .3451 .64803 L .34339 .64848 L F
.432 .395 .717 r
.3451 .64803 m .34339 .65117 L .34339 .64848 L F
.483 .24 .468 r
.33081 .64442 m .32885 .64238 L .33058 .64155 L F
.33081 .64442 m .32842 .64516 L .32885 .64238 L F
.286 .786 .837 r
.2881 .64855 m .29063 .64772 L .28624 .64569 L F
.2881 .64855 m .29078 .64793 L .29063 .64772 L F
.46 .266 .529 r
.28207 .59767 m .28525 .59795 L .28516 .59539 L F
.552 .388 .612 r
.28275 .6005 m .28525 .59795 L .28207 .59767 L F
.369 .581 .923 r
.31804 .59246 m .31378 .5898 L .31639 .59076 L F
.212 .264 .7 r
.31906 .5888 m .31804 .59246 L .31639 .59076 L F
.31906 .5888 m .31934 .59202 L .31804 .59246 L F
.22 .291 .724 r
.31934 .59202 m .32044 .59446 L .31804 .59246 L F
.307 .299 .686 r
.31804 .59246 m .32044 .59446 L .31861 .59431 L F
.303 .336 .731 r
.34182 .59905 m .34432 .60123 L .34392 .59846 L F
.34182 .59905 m .34314 .60258 L .34432 .60123 L F
.324 .741 .977 r
.31686 .53128 m .31959 .53118 L .32031 .53189 L F
.351 .658 .971 r
.32166 .53067 m .32031 .53189 L .31959 .53118 L F
.32166 .53067 m .323 .53203 L .32031 .53189 L F
.371 .237 .565 r
.38457 .56021 m .38459 .56365 L .38271 .56227 L F
.459 .214 .455 r
.38459 .56365 m .38213 .56436 L .38271 .56227 L F
.208 .729 .724 r
.25791 .53192 m .26019 .53133 L .26233 .53089 L F
.289 .785 .761 r
.26233 .53089 m .26262 .53053 L .26466 .5308 L F
.26233 .53089 m .26019 .53133 L .26262 .53053 L F
.341 .023 .272 r
.29161 .54572 m .29265 .54811 L .29384 .54493 L F
.29161 .54572 m .29039 .5489 L .29265 .54811 L F
.701 .492 .602 r
.52215 .5555 m .52363 .55867 L .51961 .55836 L F
.6 .448 .647 r
.52567 .55625 m .52363 .55867 L .52215 .5555 L F
.364 .82 .93 r
.3221 .62683 m .32383 .62648 L .32383 .62593 L F
.388 .333 .674 r
.3221 .62683 m .3245 .62893 L .3248 .62628 L F
.3221 .62683 m .32283 .62983 L .32392 .62924 L F
.32403 .62852 m .32392 .62924 L .3245 .62893 L F
.3221 .62683 m .32392 .62924 L .32403 .62852 L F
.364 .82 .93 r
.32383 .62648 m .3248 .62628 L .32383 .62593 L F
.971 .754 .553 r
.32439 .62613 m .32283 .62843 L .32383 .62593 L F
.3248 .62628 m .32428 .62684 L .32439 .62613 L F
.32428 .62684 m .32283 .62843 L .32439 .62613 L F
.093 .395 .852 r
.32141 .62278 m .32383 .62593 L .32412 .62451 L F
.32394 .62428 m .32412 .62451 L .32416 .62431 L F
.661 .496 .65 r
.32346 .62121 m .32397 .62446 L .3262 .621 L F
.177 .156 .595 r
.32416 .62431 m .32397 .62446 L .32394 .62428 L F
.32416 .62431 m .32394 .62428 L .32346 .62121 L F
.093 .395 .852 r
.32382 .62412 m .32394 .62428 L .32416 .62431 L F
.32141 .62278 m .32412 .62451 L .32382 .62412 L F
.32141 .62278 m .32382 .62412 L .32346 .62121 L F
.32382 .62412 m .32416 .62431 L .32346 .62121 L F
.95 .689 .506 r
.32383 .62418 m .32397 .62446 L .32394 .62428 L F
.32226 .6228 m .32385 .62434 L .32383 .62418 L F
.32385 .62434 m .32397 .62446 L .32383 .62418 L F
.32254 .62243 m .32394 .62428 L .32346 .62121 L F
.32226 .6228 m .32394 .62428 L .32254 .62243 L F
.764 .824 .355 r
.32383 .62533 m .32383 .62593 L .32283 .62843 L F
.32416 .62431 m .32383 .62593 L .32383 .62533 L F
0 .43 .804 r
.31463 .58968 m .31639 .59076 L .31378 .5898 L F
.603 .178 .21 r
.23611 .75122 m .23262 .75102 L .23573 .74947 L F
.647 .52 .694 r
.36868 .54726 m .36937 .54882 L .37176 .54613 L F
.75 .343 .279 r
.25368 .54964 m .25232 .55075 L .24944 .5484 L F
.955 .821 .671 r
.37243 .52936 m .36989 .52911 L .37161 .52631 L F
.37243 .52936 m .37149 .53029 L .36989 .52911 L F
.183 .416 .852 r
.37486 .52693 m .37243 .52936 L .37161 .52631 L F
.37486 .52693 m .37414 .52859 L .37243 .52936 L F
0 .391 .837 r
.29096 .67161 m .29 .67143 L .28896 .67059 L F
.29096 .67161 m .29 .67143 L .28896 .67059 L F
0 0 .132 r
.30945 .53974 m .30735 .54354 L .30971 .54044 L F
.91 .974 .683 r
.30741 .54137 m .30735 .54354 L .30945 .53974 L F
0 0 .105 r
.30735 .54354 m .30736 .54296 L .30971 .54044 L F
.30735 .54354 m .30765 .54671 L .30736 .54296 L F
.27 .261 .665 r
.30765 .54671 m .30928 .5479 L .30736 .54296 L F
.30765 .54671 m .30809 .54922 L .30928 .5479 L F
.567 .341 .533 r
.33972 .62591 m .33753 .62371 L .33987 .62315 L F
.33972 .62591 m .33727 .62631 L .33753 .62371 L F
.351 .661 .972 r
.25392 .62185 m .25348 .62362 L .25133 .62249 L F
.25392 .62185 m .25531 .62346 L .25348 .62362 L F
.276 0 .196 r
.18743 .55828 m .18849 .55995 L .18918 .55759 L F
.18743 .55828 m .18642 .56064 L .18849 .55995 L F
.39 0 0 r
.29642 .65349 m .298 .65243 L .30047 .6532 L F
.633 .451 .619 r
.35766 .62823 m .35435 .62925 L .35435 .6299 L F
.3 .713 .975 r
.30029 .52977 m .30252 .52974 L .30425 .53076 L F
.26 .654 .966 r
.30482 .52963 m .30425 .53076 L .30252 .52974 L F
.30482 .52963 m .30654 .53102 L .30425 .53076 L F
.726 .303 .244 r
.3388 .54269 m .3346 .5421 L .33641 .54127 L F
.649 .8 .955 r
.33617 .63904 m .3367 .6394 L .33364 .6383 L F
.916 .655 .16 r
.3367 .6394 m .33688 .64185 L .33621 .6404 L F
.564 .04 0 r
.32002 .58776 m .31906 .5888 L .31911 .58589 L F
.32002 .58776 m .3223 .58872 L .31906 .5888 L F
.591 .248 .357 r
.32002 .58776 m .32317 .58777 L .3223 .58872 L F
.832 .699 .717 r
.33076 .55208 m .32876 .55511 L .32715 .55155 L F
.884 .695 .642 r
.30061 .55837 m .3023 .5627 L .30031 .56116 L F
.907 .657 .549 r
.3023 .5627 m .30053 .56381 L .30031 .56116 L F
.165 0 .042 r
.1743 .57129 m .17321 .57295 L .17637 .57046 L F
.972 .759 .556 r
.36082 .52169 m .35997 .52414 L .35826 .52188 L F
.394 .852 .862 r
.36082 .52169 m .35826 .52188 L .36056 .52106 L F
.452 .834 .602 r
.20438 .54665 m .20127 .54893 L .20276 .54777 L F
.004 0 0 r
.20276 .54777 m .20657 .54598 L .20438 .54665 L F
.348 .617 .951 r
.18768 .60609 m .18828 .60443 L .18695 .60423 L F
.18768 .60609 m .19148 .60707 L .18828 .60443 L F
.525 0 0 r
.27035 .55272 m .26834 .55366 L .26613 .5524 L F
.613 .215 .266 r
.27265 .55188 m .26834 .55366 L .27035 .55272 L F
.418 .352 .676 r
.33229 .5762 m .33001 .57438 L .3323 .57344 L F
.33229 .5762 m .33047 .57704 L .33001 .57438 L F
.515 .465 .739 r
.16729 .59821 m .16938 .59796 L .16873 .59527 L F
.043 0 .107 r
.28115 .61868 m .28031 .61968 L .27841 .62048 L F
.213 .004 .363 r
.28088 .62088 m .27841 .62048 L .28031 .61968 L F
.28088 .62088 m .27771 .62341 L .27841 .62048 L F
.452 .311 .598 r
.27714 .69431 m .27486 .69201 L .27714 .69181 L F
.175 0 0 r
.27507 .69298 m .27714 .69181 L .27486 .69201 L F
0 0 0 r
.50325 .54759 m .5045 .54575 L .50237 .54844 L F
0 .057 .59 r
.50325 .54759 m .50237 .54844 L .5045 .54575 L F
0 0 0 r
.50325 .54759 m .50237 .54844 L .50038 .54689 L F
.435 .25 .529 r
.49639 .55238 m .49863 .55191 L .49863 .54876 L F
.498 .53 .82 r
.28691 .63289 m .28413 .63053 L .28647 .6296 L F
0 .005 .575 r
.30309 .62585 m .30361 .62837 L .30402 .6268 L F
.30253 .62528 m .3026 .62548 L .30309 .62585 L F
.3026 .62548 m .30361 .62837 L .30309 .62585 L F
.255 0 .102 r
.30513 .62163 m .30171 .62387 L .30251 .6254 L F
.865 .671 .638 r
.30172 .6268 m .30361 .62837 L .3026 .62548 L F
.255 0 .102 r
.3026 .62548 m .30251 .6254 L .30256 .62552 L F
.405 0 .02 r
.30245 .62558 m .30171 .62387 L .29993 .62578 L F
.865 .671 .638 r
.30172 .6268 m .3026 .62548 L .30221 .62589 L F
.405 0 .02 r
.30259 .62557 m .30256 .62552 L .30245 .62558 L F
.30256 .62552 m .30171 .62387 L .30245 .62558 L F
.865 .671 .638 r
.30246 .62557 m .3026 .62548 L .30253 .62528 L F
.30256 .62552 m .3026 .62548 L .30235 .62563 L F
.405 0 .02 r
.30259 .62557 m .30245 .62558 L .30253 .62528 L F
.30245 .62558 m .29993 .62578 L .30253 .62528 L F
.865 .671 .638 r
.30235 .62563 m .30246 .62557 L .30253 .62528 L F
.30221 .62589 m .30256 .62552 L .30235 .62563 L F
.255 0 .102 r
.30263 .6255 m .3026 .62548 L .30259 .62557 L F
.3026 .62548 m .30256 .62552 L .30259 .62557 L F
.514 .165 .314 r
.30599 .62494 m .30513 .62163 L .30259 .62557 L F
.255 0 .102 r
.30295 .625 m .30251 .6254 L .30263 .6255 L F
.682 .443 .554 r
.30253 .62528 m .30599 .62494 L .30259 .62557 L F
0 .005 .575 r
.30299 .62524 m .30402 .6268 L .30599 .62494 L F
.30253 .62528 m .30309 .62585 L .30299 .62524 L F
.30309 .62585 m .30402 .6268 L .30299 .62524 L F
.255 0 .102 r
.30513 .62163 m .30292 .6248 L .30295 .625 L F
.30292 .6248 m .30251 .6254 L .30295 .625 L F
.414 .189 .461 r
.30513 .62163 m .30686 .62307 L .30732 .62023 L F
.514 .165 .314 r
.30599 .62494 m .30686 .62307 L .30513 .62163 L F
.196 0 .332 r
.32982 .58197 m .32877 .58063 L .33033 .57964 L F
.32982 .58197 m .32806 .58315 L .32877 .58063 L F
.731 .391 .405 r
.33626 .61686 m .33839 .61947 L .33915 .61698 L F
.296 0 .247 r
.33915 .61698 m .34044 .61887 L .34204 .61638 L F
.33915 .61698 m .33839 .61947 L .34044 .61887 L F
.887 .813 .769 r
.54487 .5549 m .5458 .55821 L .54724 .55518 L F
.87 .52 .386 r
.54482 .55378 m .54487 .5549 L .54724 .55518 L F
.362 0 0 r
.33862 .66889 m .34051 .66773 L .34239 .66858 L F
.46 .519 .832 r
.3613 .61437 m .36376 .61407 L .36126 .60952 L F
.665 .757 .271 r
.30776 .55172 m .30928 .5479 L .30809 .54922 L F
.263 .349 .764 r
.21252 .60773 m .21133 .60812 L .21 .60418 L F
.223 .216 .639 r
.21252 .60773 m .21324 .61022 L .21133 .60812 L F
.556 .328 .524 r
.28361 .54331 m .28135 .54302 L .28394 .54269 L F
.28361 .54331 m .28093 .5451 L .28135 .54302 L F
.454 .466 .781 r
.35177 .58687 m .35227 .58949 L .35445 .58855 L F
.393 .021 .208 r
.32286 .57645 m .32542 .57599 L .32632 .57364 L F
.352 .566 .918 r
.32467 .57137 m .32632 .57364 L .32742 .572 L F
.461 .315 .596 r
.32542 .57599 m .32742 .572 L .32632 .57364 L F
.382 .656 .966 r
.26396 .64129 m .26486 .63981 L .26206 .63916 L F
.26396 .64129 m .2661 .64136 L .26486 .63981 L F
.823 .793 .824 r
.5445 .53874 m .54462 .53934 L .54778 .53963 L F
.612 .532 .74 r
.339 .56175 m .34016 .56435 L .3376 .56473 L F
.628 .137 .069 r
.23841 .75044 m .24244 .75081 L .24054 .75178 L F
0 0 .493 r
.24203 .74913 m .24244 .75081 L .2418 .74943 L F
.24203 .74913 m .2418 .74943 L .24174 .7493 L F
.548 .819 .462 r
.24213 .749 m .24203 .74913 L .24263 .7484 L F
.88 .993 .77 r
.24054 .75178 m .24244 .75081 L .24203 .74913 L F
0 0 0 r
.24226 .74899 m .24203 .74913 L .24174 .74982 L F
.24263 .7484 m .24203 .74913 L .24226 .74899 L F
.24263 .7484 m .24174 .74982 L .24211 .74903 L F
.24263 .7484 m .24211 .74903 L .2437 .74562 L F
.548 .819 .462 r
.24227 .74882 m .24213 .749 L .24263 .7484 L F
0 0 .493 r
.24203 .74913 m .24174 .7493 L .24114 .74801 L F
.616 .081 0 r
.23841 .75044 m .24022 .75158 L .23888 .75237 L F
.24022 .75158 m .24054 .75178 L .23888 .75237 L F
.88 .993 .769 r
.23888 .75237 m .24054 .75178 L .24133 .75038 L F
.24073 .7505 m .24133 .75038 L .24197 .74924 L F
.23888 .75237 m .24133 .75038 L .24073 .7505 L F
.355 0 0 r
.23979 .75068 m .23665 .74964 L .23515 .74971 L F
.88 .993 .769 r
.24112 .75007 m .24197 .74924 L .24183 .74934 L F
.23888 .75237 m .24118 .75004 L .24112 .75007 L F
.24118 .75004 m .24197 .74924 L .24112 .75007 L F
.571 0 0 r
.23644 .7525 m .23611 .75122 L .23841 .75044 L F
.616 .081 0 r
.23841 .75044 m .23888 .75237 L .23644 .7525 L F
.355 0 0 r
.23928 .75092 m .23515 .74971 L .23671 .75103 L F
.88 .993 .769 r
.24112 .75007 m .24203 .74913 L .2413 .74995 L F
.24089 .75036 m .2413 .74995 L .24055 .75079 L F
.24112 .75007 m .2413 .74995 L .24089 .75036 L F
.463 .013 .095 r
.24203 .74913 m .24114 .74801 L .2407 .75063 L F
.88 .993 .769 r
.23888 .75237 m .24112 .75007 L .24056 .75078 L F
.429 0 .089 r
.24061 .75073 m .24114 .74801 L .23942 .74786 L F
.24066 .75086 m .2407 .75063 L .24061 .75073 L F
.2407 .75063 m .24114 .74801 L .24061 .75073 L F
.24053 .75082 m .24043 .75031 L .23996 .75065 L F
.24066 .75086 m .24061 .75073 L .24053 .75082 L F
.88 .993 .769 r
.24052 .75083 m .24056 .75078 L .24055 .75079 L F
.24052 .75083 m .24055 .75079 L .24053 .75082 L F
.429 0 .089 r
.24061 .75073 m .24043 .75031 L .24053 .75082 L F
.88 .993 .769 r
.24053 .75082 m .24055 .75079 L .24054 .75081 L F
.23888 .75237 m .24056 .75078 L .24052 .75083 L F
.843 .792 .802 r
.2437 .74562 m .24201 .74925 L .23986 .74861 L F
.463 .013 .095 r
.24203 .74913 m .24066 .75086 L .24174 .74982 L F
.843 .792 .802 r
.24201 .74925 m .24174 .74982 L .24156 .7497 L F
.88 .993 .769 r
.24183 .74934 m .24197 .74924 L .24203 .74913 L F
.463 .013 .095 r
.24203 .74913 m .2407 .75063 L .24068 .7507 L F
.88 .993 .769 r
.24054 .75081 m .24203 .74913 L .2414 .74987 L F
.463 .013 .095 r
.24203 .74913 m .24068 .7507 L .24092 .75053 L F
.933 .662 .502 r
.24156 .7497 m .24174 .74982 L .24062 .75074 L F
.88 .993 .769 r
.24064 .75071 m .2414 .74987 L .24084 .75053 L F
.24054 .75081 m .2414 .74987 L .24064 .75071 L F
.463 .013 .095 r
.24092 .75053 m .24068 .7507 L .24066 .75086 L F
.933 .662 .502 r
.24062 .75074 m .24174 .74982 L .24066 .75086 L F
.88 .993 .769 r
.24055 .75079 m .24203 .74913 L .24054 .75081 L F
.933 .662 .502 r
.23986 .74861 m .24155 .74969 L .24062 .75074 L F
.548 .819 .462 r
.24084 .75053 m .2414 .74987 L .24227 .74882 L F
.2414 .74987 m .2415 .74975 L .24152 .74973 L F
.843 .792 .802 r
.24194 .74923 m .24155 .74969 L .23986 .74861 L F
.548 .819 .462 r
.2414 .74987 m .24152 .74973 L .24227 .74882 L F
.933 .662 .502 r
.24155 .74969 m .24156 .7497 L .2414 .74987 L F
.24155 .74969 m .2414 .74987 L .24062 .75074 L F
.548 .819 .462 r
.2415 .74975 m .24203 .74913 L .24212 .74901 L F
.2415 .74975 m .24212 .74901 L .24227 .74882 L F
.843 .792 .802 r
.24201 .74925 m .24156 .7497 L .24155 .74969 L F
.24201 .74925 m .24155 .74969 L .24194 .74923 L F
.355 0 0 r
.2405 .75086 m .23979 .75068 L .23928 .75092 L F
.24066 .75086 m .24052 .75083 L .2405 .75086 L F
.24052 .75083 m .23979 .75068 L .2405 .75086 L F
.23979 .75068 m .23515 .74971 L .23928 .75092 L F
.24066 .75086 m .23996 .75065 L .23979 .75068 L F
.23996 .75065 m .23665 .74964 L .23979 .75068 L F
.281 0 0 r
.23644 .7525 m .23888 .75237 L .23663 .7539 L F
.597 .915 .667 r
.23765 .75309 m .23888 .75237 L .24053 .75082 L F
.23987 .75131 m .24053 .75082 L .24084 .75053 L F
.23765 .75309 m .24053 .75082 L .23987 .75131 L F
.23663 .7539 m .23888 .75237 L .23765 .75309 L F
.429 0 .089 r
.23996 .75065 m .23942 .74786 L .23665 .74964 L F
.24043 .75031 m .23942 .74786 L .23996 .75065 L F
0 0 .304 r
.30741 .54137 m .30618 .54502 L .30735 .54354 L F
.795 .352 .192 r
.24578 .5502 m .2417 .54726 L .24348 .5503 L F
.727 .954 .661 r
.3108 .53981 m .30945 .53974 L .31167 .54181 L F
.681 .133 0 r
.30971 .54044 m .31167 .54181 L .30945 .53974 L F
.761 .666 .758 r
.30736 .54296 m .31167 .54181 L .30971 .54044 L F
.283 .423 .826 r
.31269 .53955 m .31124 .53983 L .31012 .53823 L F
.475 .633 .923 r
.3108 .53981 m .31269 .53955 L .31012 .53823 L F
.714 .596 .723 r
.31124 .53983 m .31119 .53985 L .31012 .53823 L F
.475 .633 .923 r
.31167 .54181 m .312 .54108 L .3108 .53981 L F
.31091 .53992 m .31119 .53985 L .3108 .53981 L F
.312 .54108 m .3112 .53986 L .31091 .53992 L F
.3112 .53986 m .31119 .53985 L .31091 .53992 L F
.312 .54108 m .31249 .54 L .31119 .53985 L F
.044 0 0 r
.31125 .53985 m .31124 .53983 L .31269 .53955 L F
.132 .003 .425 r
.31122 .53985 m .31119 .53985 L .31124 .53983 L F
.475 .633 .923 r
.31249 .54 m .31269 .53955 L .3108 .53981 L F
.044 0 0 r
.31143 .54114 m .31125 .53985 L .31269 .53955 L F
.727 .954 .661 r
.31012 .53823 m .30964 .53933 L .3108 .53981 L F
.30964 .53933 m .30945 .53974 L .3108 .53981 L F
.31012 .53823 m .30741 .54137 L .30945 .53974 L F
.714 .596 .723 r
.31119 .53985 m .30741 .54137 L .31012 .53823 L F
.132 .003 .425 r
.31114 .53995 m .31105 .53991 L .31119 .53985 L F
.31114 .53995 m .31119 .53985 L .31122 .53985 L F
.30908 .54236 m .30741 .54137 L .31105 .53991 L F
.30908 .54236 m .31105 .53991 L .31114 .53995 L F
.699 .524 .647 r
.36674 .55205 m .3702 .55222 L .36937 .54882 L F
.233 0 .302 r
.36937 .54882 m .37126 .54843 L .37176 .54613 L F
.396 .356 .696 r
.3702 .55222 m .37126 .54843 L .36937 .54882 L F
.027 .133 .64 r
.52675 .55084 m .52492 .54937 L .52676 .54919 L F
.63 .644 .846 r
.54436 .54243 m .54462 .53934 L .54227 .54087 L F
.766 .479 .499 r
.54436 .54243 m .54199 .54511 L .546 .54545 L F
.34 .004 .24 r
.34392 .59846 m .34642 .59805 L .3475 .59491 L F
.636 .389 .528 r
.34642 .59805 m .34964 .59464 L .3475 .59491 L F
.603 .469 .672 r
.32144 .54494 m .31666 .54743 L .31537 .54712 L F
.066 .565 .889 r
.22857 .63093 m .23074 .63096 L .22749 .62938 L F
.23074 .63096 m .23079 .63074 L .22749 .62938 L F
.384 0 0 r
.22749 .62938 m .22911 .63005 L .22775 .62999 L F
.22911 .63005 m .23133 .63096 L .22775 .62999 L F
.358 .703 .984 r
.22552 .62955 m .22749 .62938 L .226 .62823 L F
.384 0 0 r
.22749 .62938 m .22775 .62999 L .226 .62823 L F
.51 .162 .312 r
.226 .62823 m .22775 .62999 L .22603 .62996 L F
.679 .978 .85 r
.22852 .62867 m .22693 .62996 L .22775 .62999 L F
0 0 0 r
.22775 .62999 m .22386 .63045 L .22603 .62996 L F
.679 .978 .85 r
.22693 .62996 m .22672 .63013 L .22775 .62999 L F
.749 .799 .893 r
.22775 .62999 m .23089 .63039 L .23033 .62969 L F
.23089 .63039 m .23259 .63061 L .23101 .62997 L F
.23089 .63039 m .23101 .62997 L .23033 .62969 L F
.066 .565 .889 r
.23074 .63096 m .23133 .63096 L .23079 .63074 L F
.488 .586 .879 r
.23259 .63061 m .23301 .63162 L .23462 .63013 L F
.066 .565 .889 r
.22857 .63093 m .23359 .63216 L .23217 .63141 L F
.913 .597 .117 r
.23359 .63216 m .23259 .63061 L .23133 .63096 L F
.23359 .63216 m .2337 .63327 L .23259 .63061 L F
.488 .586 .879 r
.23301 .63162 m .2337 .63327 L .2341 .63189 L F
.23301 .63162 m .2341 .63189 L .23462 .63013 L F
.066 .565 .889 r
.23033 .63095 m .23217 .63141 L .23133 .63096 L F
.22857 .63093 m .23217 .63141 L .23033 .63095 L F
.239 .498 .899 r
.19542 .61171 m .19622 .61023 L .19406 .61061 L F
.19542 .61171 m .19866 .61332 L .19622 .61023 L F
.668 .584 .751 r
.51961 .55836 m .5205 .56104 L .51827 .56199 L F
.355 .311 .67 r
.16908 .59266 m .17083 .59234 L .17038 .58855 L F
.466 .308 .583 r
.16873 .59527 m .17083 .59234 L .16908 .59266 L F
.964 .697 .479 r
.53263 .5327 m .53426 .53369 L .53267 .53021 L F
.961 .669 .433 r
.53263 .5327 m .53294 .53532 L .53426 .53369 L F
0 0 0 r
.53426 .53369 m .53652 .53164 L .53267 .53021 L F
.53426 .53369 m .53509 .53296 L .53652 .53164 L F
.581 .311 .471 r
.53294 .53532 m .53509 .53296 L .53426 .53369 L F
0 0 0 r
.34617 .56222 m .34591 .56141 L .34708 .55965 L F
.34617 .56222 m .34517 .5648 L .34591 .56141 L F
.217 .449 .869 r
.20245 .61615 m .20328 .61802 L .20403 .61627 L F
.321 .576 .933 r
.20328 .61802 m .20608 .61875 L .20403 .61627 L F
.49 .651 .93 r
.18458 .60443 m .18439 .60161 L .18325 .60129 L F
.18458 .60443 m .18695 .60423 L .18439 .60161 L F
.416 .59 .914 r
.20029 .61612 m .20011 .61322 L .19866 .61332 L F
.20029 .61612 m .20245 .61615 L .20011 .61322 L F
.477 .032 .111 r
.53652 .53164 m .53509 .53296 L .53892 .53227 L F
.588 .388 .577 r
.34888 .54299 m .34911 .54542 L .35164 .54331 L F
.34888 .54299 m .34911 .54542 L .35164 .54331 L F
.596 .438 .638 r
.35257 .57716 m .35456 .57336 L .35245 .57412 L F
.227 .634 .957 r
.2585 .63776 m .26006 .63896 L .26039 .63791 L F
.218 .624 .953 r
.26039 .63791 m .26006 .63896 L .26206 .63916 L F
.786 .888 .918 r
.31662 .6048 m .31447 .60702 L .31159 .60549 L F
.816 .622 .64 r
.34066 .56149 m .34016 .56435 L .339 .56175 L F
.867 .928 .863 r
.33962 .66288 m .33976 .6594 L .34142 .66036 L F
.33962 .66288 m .33707 .6621 L .33976 .6594 L F
.204 .042 .427 r
.17131 .57658 m .17321 .57295 L .17149 .57399 L F
0 0 0 r
.20305 .5704 m .20144 .57276 L .1996 .57331 L F
.299 0 0 r
.20079 .57479 m .1996 .57331 L .20144 .57276 L F
.20079 .57479 m .19877 .57522 L .1996 .57331 L F
.094 0 0 r
.39105 .55851 m .38906 .5596 L .38672 .56003 L F
0 0 .498 r
.39128 .55449 m .39105 .55851 L .38956 .55493 L F
.39128 .55449 m .39216 .55731 L .39105 .55851 L F
.561 .911 .701 r
.39216 .55731 m .38906 .5596 L .39105 .55851 L F
0 0 0 r
.20817 .79188 m .20628 .79279 L .20643 .79279 L F
.20643 .79279 m .20628 .79279 L .20538 .7955 L F
.385 0 0 r
.5374 .56037 m .53968 .56102 L .53592 .56045 L F
.5374 .56037 m .53968 .56102 L .53592 .56045 L F
.113 .215 .692 r
.32091 .59863 m .31861 .59431 L .32044 .59446 L F
.32091 .59863 m .3208 .59906 L .31861 .59431 L F
.623 .397 .553 r
.39128 .55449 m .38956 .55493 L .38966 .55228 L F
.307 .353 .746 r
.3291 .55651 m .32876 .55511 L .33367 .5543 L F
.502 .56 .847 r
.33347 .55146 m .33568 .55587 L .33367 .5543 L F
.803 .491 .461 r
.33568 .55587 m .33483 .55765 L .33367 .5543 L F
.33568 .55587 m .33483 .55765 L .33367 .5543 L F
.562 .27 .429 r
.52406 .53329 m .52671 .53307 L .52714 .53101 L F
.602 .306 .44 r
.52714 .53101 m .53114 .5322 L .52938 .53035 L F
.52714 .53101 m .52671 .53307 L .53114 .5322 L F
.351 .794 .959 r
.26466 .5308 m .26702 .53044 L .26873 .53096 L F
.311 .799 .874 r
.26702 .53044 m .27097 .52999 L .26873 .53096 L F
.587 .57 .801 r
.36601 .52357 m .36492 .52778 L .36371 .52427 L F
.36601 .52357 m .3674 .52727 L .36492 .52778 L F
.555 .412 .642 r
.3674 .52727 m .36514 .5303 L .36492 .52778 L F
.649 .8 .955 r
.33617 .63904 m .33364 .6383 L .33362 .63601 L F
.486 .569 .865 r
.3805 .5315 m .3791 .53394 L .37763 .53121 L F
.3805 .5315 m .38127 .53345 L .3791 .53394 L F
.352 .498 .865 r
.38189 .5355 m .3791 .53394 L .38127 .53345 L F
.633 .451 .619 r
.35766 .62823 m .35477 .63059 L .35435 .62925 L F
0 0 0 r
.35856 .62808 m .3552 .63031 L .35766 .62823 L F
.3552 .63031 m .35477 .63059 L .35578 .62977 L F
.3552 .63031 m .35578 .62977 L .35766 .62823 L F
.29 .394 .797 r
.35873 .63086 m .35477 .63059 L .35856 .62808 L F
.233 .387 .813 r
.35477 .63059 m .35535 .63069 L .35435 .62925 L F
.661 .401 .516 r
.35513 .63037 m .35129 .62973 L .35435 .62925 L F
.35535 .63069 m .3549 .63058 L .35513 .63037 L F
.3549 .63058 m .35129 .62973 L .35513 .63037 L F
.779 .695 .771 r
.34798 .58322 m .34964 .57952 L .34779 .58004 L F
.501 .281 .512 r
.31792 .58005 m .32051 .57971 L .32065 .57697 L F
.357 .166 .478 r
.32065 .57697 m .32251 .57893 L .32286 .57645 L F
.32065 .57697 m .32051 .57971 L .32251 .57893 L F
.162 .353 .807 r
.3933 .54721 m .3925 .54883 L .39076 .54545 L F
.155 .345 .801 r
.3933 .54721 m .39482 .55114 L .3925 .54883 L F
.12 0 .066 r
.29132 .58959 m .28828 .59236 L .28995 .59153 L F
0 0 0 r
.29132 .58959 m .2921 .58816 L .29287 .58599 L F
.622 .823 .415 r
.28995 .59153 m .2921 .58816 L .29132 .58959 L F
.721 .981 .907 r
.23659 .55961 m .23528 .55983 L .23832 .55806 L F
.826 .366 .124 r
.31213 .65806 m .31009 .65774 L .30887 .65634 L F
.588 .013 0 r
.31443 .65988 m .31009 .65774 L .31213 .65806 L F
.557 .18 .283 r
.31937 .6043 m .32298 .60276 L .32129 .60634 L F
0 0 0 r
.32129 .60634 m .32298 .60276 L .32363 .60299 L F
.485 .291 .541 r
.304 .54865 m .30376 .55131 L .30179 .54938 L F
.492 .301 .549 r
.53195 .55531 m .52991 .55826 L .52987 .55594 L F
.53195 .55531 m .53237 .55769 L .52991 .55826 L F
.637 .514 .697 r
.53333 .56117 m .52991 .55826 L .53237 .55769 L F
.53333 .56117 m .53134 .56225 L .52991 .55826 L F
.433 .422 .747 r
.318 .63941 m .3208 .64139 L .31993 .63937 L F
.458 .42 .729 r
.31878 .64188 m .3208 .64139 L .318 .63941 L F
.754 .632 .725 r
.34339 .65117 m .34433 .65568 L .34006 .65454 L F
.79 .495 0 r
.34141 .65963 m .34006 .65454 L .34433 .65568 L F
.653 .624 .808 r
.34517 .65056 m .34433 .65568 L .34339 .65117 L F
.445 .845 .975 r
.32898 .53189 m .33185 .53059 L .33363 .53188 L F
.734 .229 .027 r
.33185 .53059 m .336 .53102 L .33363 .53188 L F
.732 .85 .414 r
.50423 .54287 m .50471 .54136 L .50488 .54118 L F
0 0 .282 r
.50423 .54287 m .50499 .54365 L .50471 .54136 L F
.923 .631 .473 r
.50523 .5449 m .5045 .54575 L .50423 .54287 L F
.50581 .54607 m .5045 .54575 L .50523 .5449 L F
.465 .394 .693 r
.50325 .54759 m .50359 .54682 L .5045 .54575 L F
0 0 .282 r
.50423 .54287 m .5045 .54575 L .50499 .54365 L F
.465 .394 .693 r
.50359 .54682 m .50499 .54365 L .5045 .54575 L F
.775 .815 .885 r
.28899 .62745 m .29008 .62906 L .28647 .6296 L F
.368 .387 .749 r
.28899 .63177 m .28647 .6296 L .29008 .62906 L F
.648 .767 .935 r
.29237 .628 m .29008 .62906 L .28899 .62745 L F
.259 0 .19 r
.29093 .62961 m .28974 .62992 L .29008 .62906 L F
.481 .52 .82 r
.28899 .62745 m .28987 .62985 L .29064 .62969 L F
.259 0 .19 r
.29064 .62969 m .28899 .63177 L .28974 .62992 L F
.244 0 .158 r
.29064 .62969 m .28899 .63177 L .28987 .62985 L F
.29195 .62941 m .28899 .63177 L .29064 .62969 L F
.29195 .62941 m .28899 .63177 L .29195 .62941 L F
.29195 .62941 m .29104 .63112 L .28899 .63177 L F
.412 .016 .175 r
.29195 .62941 m .29104 .63112 L .29243 .62801 L F
.29147 .63082 m .29104 .63112 L .29195 .62941 L F
.244 0 .158 r
.29196 .62941 m .29104 .63112 L .29195 .62941 L F
.259 0 .19 r
.29237 .628 m .29179 .62937 L .29093 .62961 L F
.29237 .628 m .29093 .62961 L .29008 .62906 L F
.481 .52 .82 r
.28899 .62745 m .29016 .62904 L .29189 .62936 L F
.29016 .62904 m .29064 .62969 L .29182 .62938 L F
.29016 .62904 m .29182 .62938 L .29189 .62936 L F
.412 .016 .175 r
.29243 .62801 m .29182 .62938 L .29237 .628 L F
.29182 .62938 m .29104 .63112 L .29179 .62937 L F
.29182 .62938 m .29179 .62937 L .29237 .628 L F
.29489 .62847 m .29147 .63082 L .29243 .62801 L F
.244 0 .158 r
.29196 .62941 m .29195 .62941 L .29195 .62941 L F
.481 .52 .82 r
.29093 .62961 m .29064 .62969 L .29073 .62967 L F
.259 0 .19 r
.29093 .62961 m .28899 .63177 L .29064 .62969 L F
.29093 .62961 m .29104 .63112 L .28899 .63177 L F
.481 .52 .82 r
.29189 .62936 m .29093 .62961 L .29196 .62941 L F
.29093 .62961 m .29073 .62967 L .29196 .62941 L F
.259 0 .19 r
.29179 .62937 m .29104 .63112 L .29093 .62961 L F
.054 0 0 r
.23277 .53584 m .23504 .53524 L .23694 .53386 L F
.055 0 0 r
.23694 .53386 m .23729 .53463 L .23923 .53345 L F
.23694 .53386 m .23504 .53524 L .23729 .53463 L F
.222 0 0 r
.34935 .66464 m .34874 .66514 L .34664 .66544 L F
.71 .613 .748 r
.3518 .66124 m .34935 .66464 L .34815 .6599 L F
.246 0 0 r
.35004 .66584 m .34935 .66464 L .35164 .66455 L F
.35004 .66584 m .34874 .66514 L .34935 .66464 L F
.568 .46 .691 r
.53443 .55444 m .53237 .55769 L .53195 .55531 L F
.416 .596 .918 r
.50376 .55947 m .50496 .55703 L .50305 .55692 L F
.50376 .55947 m .50686 .56003 L .50496 .55703 L F
.756 .879 .935 r
.34257 .53515 m .34126 .53898 L .34479 .5355 L F
.34257 .53515 m .33909 .53785 L .34126 .53898 L F
.844 .546 .484 r
.50581 .54607 m .50325 .54759 L .5045 .54575 L F
.50581 .54607 m .50766 .5484 L .50325 .54759 L F
.755 .425 .425 r
.25845 .7196 m .26096 .72019 L .26074 .72219 L F
.544 .36 .583 r
.26322 .71905 m .26074 .72219 L .26096 .72019 L F
.483 .34 .61 r
.38443 .57319 m .38461 .5762 L .38176 .57624 L F
.557 .288 .464 r
.3843 .5787 m .38176 .57624 L .38461 .5762 L F
.3843 .5787 m .38131 .57929 L .38176 .57624 L F
.412 .688 .976 r
.2992 .66533 m .29673 .66537 L .29686 .66573 L F
.506 .804 .999 r
.27328 .52948 m .27498 .53058 L .27097 .52999 L F
.31 .722 .976 r
.27328 .52948 m .27731 .53042 L .27498 .53058 L F
.769 .662 .744 r
.16543 .61054 m .16542 .61126 L .16283 .61089 L F
.29 .788 .857 r
.16283 .61089 m .16472 .61035 L .16543 .61054 L F
.384 .776 .988 r
.16542 .61126 m .16472 .61035 L .16283 .61089 L F
.194 .182 .616 r
.16728 .60982 m .16542 .61126 L .16543 .61054 L F
.32 .807 .862 r
.16543 .61054 m .16472 .61035 L .16728 .60982 L F
.544 .876 .991 r
.16728 .60982 m .16472 .61035 L .16542 .61126 L F
.538 .542 .807 r
.30691 .60793 m .30496 .60887 L .30411 .60691 L F
.405 .367 .703 r
.30575 .61092 m .30691 .60793 L .30411 .60691 L F
.30575 .61092 m .30751 .61051 L .30691 .60793 L F
.434 .351 .664 r
.30575 .61092 m .30871 .61291 L .30751 .61051 L F
.30575 .61092 m .30575 .61472 L .30871 .61291 L F
.322 .147 .482 r
.33229 .5762 m .33033 .57964 L .33047 .57704 L F
.57 .418 .636 r
.31666 .54743 m .31465 .55175 L .31457 .54913 L F
.361 .275 .622 r
.31792 .58005 m .32031 .58197 L .32051 .57971 L F
.31792 .58005 m .31783 .58398 L .32031 .58197 L F
.754 .632 .725 r
.34339 .65117 m .34006 .65454 L .34017 .65148 L F
.658 .48 .632 r
.34017 .65148 m .34368 .65405 L .34339 .65117 L F
.34017 .65148 m .34006 .65454 L .34368 .65405 L F
.503 .561 .847 r
.33743 .55431 m .33568 .55587 L .33347 .55146 L F
.808 .712 .759 r
.33463 .56025 m .339 .56175 L .33744 .55732 L F
.366 .451 .816 r
.33754 .55738 m .339 .56175 L .34039 .55917 L F
.33744 .55732 m .33747 .5574 L .33754 .55738 L F
.33747 .5574 m .339 .56175 L .33754 .55738 L F
.33744 .55732 m .34039 .55917 L .33987 .55679 L F
0 0 0 r
.33997 .55678 m .33763 .55757 L .33871 .55702 L F
.33963 .55674 m .33871 .55702 L .33934 .5567 L F
.33997 .55678 m .33871 .55702 L .33963 .55674 L F
.552 .208 .338 r
.33744 .55732 m .33483 .55765 L .33568 .55587 L F
.33568 .55587 m .33483 .55765 L .33744 .55732 L F
.115 0 0 r
.33934 .5567 m .33573 .55758 L .33744 .55732 L F
.944 .716 .564 r
.33282 .55846 m .33463 .56025 L .33483 .55765 L F
.808 .712 .759 r
.33463 .56025 m .33744 .55732 L .33483 .55765 L F
.944 .716 .564 r
.33416 .55813 m .33483 .55765 L .33744 .55732 L F
.33282 .55846 m .33364 .55813 L .33416 .55813 L F
.33364 .55813 m .33483 .55765 L .33416 .55813 L F
.33282 .55846 m .33744 .55732 L .33573 .55758 L F
.113 .357 .821 r
.33763 .55757 m .33751 .55812 L .33573 .55758 L F
.33751 .55812 m .33708 .56011 L .33602 .55812 L F
.33751 .55812 m .33602 .55812 L .33573 .55758 L F
.115 0 0 r
.33809 .557 m .33763 .55757 L .33573 .55758 L F
.33934 .5567 m .3387 .55703 L .33809 .557 L F
.3387 .55703 m .33763 .55757 L .33809 .557 L F
.552 .208 .338 r
.33744 .55698 m .33568 .55587 L .33743 .55431 L F
.33744 .55732 m .33701 .55697 L .33744 .55698 L F
.33701 .55697 m .33568 .55587 L .33744 .55698 L F
0 0 0 r
.23749 .55038 m .23528 .551 L .23294 .55135 L F
.365 .829 .764 r
.23745 .55006 m .23749 .55038 L .23984 .54986 L F
.23745 .55006 m .23528 .551 L .23749 .55038 L F
.032 0 0 r
.29767 .54231 m .2951 .54285 L .29522 .54305 L F
0 .558 .799 r
.29531 .5432 m .29522 .54305 L .29263 .54269 L F
.121 .671 .729 r
.29522 .54305 m .29075 .5436 L .29263 .54269 L F
.032 0 0 r
.2951 .54285 m .2932 .54325 L .29522 .54305 L F
0 .558 .799 r
.29673 .54348 m .29522 .54305 L .29531 .5432 L F
.174 0 0 r
.29384 .54493 m .29636 .54425 L .29673 .54348 L F
.542 .412 .653 r
.29918 .54038 m .29898 .54363 L .29673 .54348 L F
.329 .687 .98 r
.29673 .54348 m .29767 .54231 L .29522 .54305 L F
.29673 .54348 m .29898 .54363 L .29767 .54231 L F
.358 .703 .984 r
.22552 .62955 m .226 .62823 L .22379 .6287 L F
.524 .433 .694 r
.31894 .64478 m .3208 .64139 L .31878 .64188 L F
.71 .639 .776 r
.32177 .55274 m .32225 .55508 L .32465 .55228 L F
.062 .088 .575 r
.32105 .55386 m .32176 .55725 L .32225 .55508 L F
.996 .78 .491 r
.32105 .55386 m .32225 .55508 L .32177 .55274 L F
.39 .39 .739 r
.31256 .63526 m .30999 .63331 L .31223 .63196 L F
.31256 .63526 m .31089 .63579 L .30999 .63331 L F
.262 .173 .562 r
.30656 .61722 m .30871 .61291 L .30575 .61472 L F
.108 0 0 r
.26 .55513 m .25662 .55699 L .2579 .55578 L F
.447 .184 .421 r
.54193 .5554 m .54487 .5549 L .54482 .55378 L F
.551 .408 .64 r
.34465 .5524 m .3473 .55224 L .34645 .54865 L F
.625 .359 .495 r
.34465 .5524 m .34844 .55377 L .3473 .55224 L F
.34465 .5524 m .34406 .5551 L .34844 .55377 L F
.535 .796 .993 r
.22336 .61549 m .22281 .61722 L .22103 .61601 L F
.44 .696 .974 r
.22336 .61549 m .22497 .61706 L .22281 .61722 L F
.712 .654 .79 r
.22318 .5612 m .22666 .56167 L .22638 .55906 L F
.502 .531 .819 r
.22666 .56167 m .22874 .56108 L .22649 .55749 L F
.726 .877 .951 r
.33914 .5915 m .34272 .59116 L .34086 .59052 L F
.669 .424 .542 r
.33839 .58854 m .34205 .58948 L .34179 .58618 L F
.792 .84 .887 r
.34272 .59116 m .34356 .58852 L .34214 .58957 L F
.34118 .59063 m .34214 .58957 L .34086 .59052 L F
.34272 .59116 m .34214 .58957 L .34118 .59063 L F
.498 .316 .564 r
.34179 .58618 m .34246 .58922 L .34381 .58775 L F
.669 .424 .542 r
.34205 .58948 m .34246 .58922 L .34179 .58618 L F
.792 .84 .887 r
.34205 .58948 m .34381 .58775 L .34179 .58965 L F
.34356 .58852 m .34372 .58803 L .34205 .58948 L F
.34372 .58803 m .34381 .58775 L .34205 .58948 L F
.34356 .58852 m .34179 .58965 L .34086 .59052 L F
.558 .498 .744 r
.34205 .58948 m .34086 .59052 L .34255 .58961 L F
.33839 .58854 m .34086 .59052 L .34205 .58948 L F
.498 .316 .564 r
.34246 .58922 m .34255 .58961 L .34381 .58775 L F
.669 .424 .542 r
.34205 .58948 m .34255 .58961 L .34246 .58922 L F
.792 .84 .887 r
.34272 .59116 m .34547 .58909 L .34381 .58775 L F
.319 0 .084 r
.37176 .54613 m .37322 .54664 L .37519 .5445 L F
.37322 .54664 m .37389 .54633 L .37519 .5445 L F
0 0 0 r
.37519 .5445 m .37389 .54633 L .37633 .54448 L F
.711 .57 .693 r
.37633 .54448 m .37411 .54616 L .37425 .54616 L F
.43 .334 .645 r
.37346 .54708 m .37528 .54935 L .37411 .54616 L F
0 0 0 r
.37411 .54616 m .37383 .54655 L .37633 .54448 L F
.37389 .54633 m .37383 .54655 L .37411 .54616 L F
.711 .57 .693 r
.37633 .54448 m .37269 .54613 L .37411 .54616 L F
.37633 .54448 m .37383 .54655 L .37269 .54613 L F
0 0 0 r
.37389 .54633 m .37358 .54677 L .37383 .54655 L F
.319 0 .084 r
.37322 .54664 m .37358 .54677 L .37389 .54633 L F
.711 .57 .693 r
.37383 .54655 m .37358 .54677 L .37269 .54613 L F
.43 .334 .645 r
.37411 .54616 m .37432 .54673 L .37471 .54617 L F
.37432 .54673 m .37528 .54935 L .37484 .54693 L F
.37432 .54673 m .37484 .54693 L .37471 .54617 L F
.37269 .54613 m .37346 .54708 L .37411 .54616 L F
.711 .57 .693 r
.37511 .54575 m .37425 .54616 L .37471 .54617 L F
.37633 .54448 m .37425 .54616 L .37511 .54575 L F
0 0 .349 r
.37519 .5445 m .37633 .54448 L .37652 .54203 L F
.45 .465 .783 r
.32681 .60523 m .33001 .60651 L .32943 .60499 L F
.313 .753 .966 r
.24145 .53286 m .24541 .53339 L .24328 .53327 L F
.575 .418 .631 r
.37433 .58653 m .37434 .58908 L .37196 .58961 L F
.539 .344 .565 r
.37427 .59169 m .37196 .58961 L .37434 .58908 L F
.37427 .59169 m .3718 .59235 L .37196 .58961 L F
.609 .626 .843 r
.19735 .5937 m .19501 .59248 L .19637 .59181 L F
.476 .651 .936 r
.19893 .59135 m .19735 .5937 L .19637 .59181 L F
.19893 .59135 m .20108 .5941 L .19735 .5937 L F
.517 .433 .699 r
.37229 .59486 m .37285 .59839 L .37063 .59701 L F
.341 0 .165 r
.37285 .59839 m .36966 .60079 L .37063 .59701 L F
.518 .394 .651 r
.32241 .6324 m .3245 .62893 L .32283 .62983 L F
.633 .544 .736 r
.33703 .60795 m .33655 .61031 L .33452 .61111 L F
.576 .445 .665 r
.35699 .53612 m .35967 .53623 L .35887 .53288 L F
.331 .317 .692 r
.35699 .53612 m .35933 .53856 L .35967 .53623 L F
.35699 .53612 m .35769 .53975 L .35933 .53856 L F
.417 .387 .718 r
.33708 .62873 m .33576 .63198 L .33512 .6293 L F
.33708 .62873 m .33717 .63248 L .33576 .63198 L F
.828 .444 .326 r
.33576 .63198 m .33821 .63567 L .34011 .63551 L F
.444 .361 .667 r
.33717 .63248 m .33821 .63567 L .33576 .63198 L F
.105 .596 .906 r
.32467 .57137 m .32061 .57004 L .3224 .57107 L F
.334 .22 .571 r
.31279 .63793 m .31089 .63579 L .31256 .63526 L F
.153 .183 .639 r
.31279 .63793 m .31188 .63848 L .31089 .63579 L F
.566 .318 .499 r
.34055 .55163 m .33743 .55431 L .33765 .55242 L F
.307 .353 .746 r
.3291 .55651 m .33135 .55728 L .32876 .55511 L F
.139 .17 .631 r
.3291 .55651 m .33135 .56005 L .33135 .55728 L F
.3291 .55651 m .33 .56139 L .33135 .56005 L F
.195 .538 .926 r
.23193 .6185 m .23362 .61862 L .23331 .61996 L F
.087 .415 .864 r
.23362 .61862 m .2347 .62035 L .23331 .61996 L F
.133 0 .056 r
.19851 .55117 m .19995 .55143 L .20127 .54893 L F
.14 0 0 r
.19851 .55117 m .19675 .55347 L .19995 .55143 L F
0 .391 .837 r
.29096 .67161 m .28896 .67059 L .29217 .66975 L F
.29096 .67161 m .28896 .67059 L .29217 .66975 L F
.167 0 .074 r
.20127 .54893 m .20204 .55046 L .20276 .54777 L F
.20127 .54893 m .19995 .55143 L .20204 .55046 L F
.676 .136 0 r
.34011 .63551 m .34247 .63763 L .34313 .63697 L F
.618 .066 0 r
.34247 .63763 m .34671 .63874 L .34313 .63697 L F
.401 .815 .621 r
.35769 .53975 m .35898 .53887 L .35933 .53856 L F
.35769 .53975 m .35505 .54136 L .35898 .53887 L F
.027 .221 .727 r
.3884 .54044 m .38657 .54001 L .38518 .53882 L F
.3884 .54044 m .38885 .5422 L .38657 .54001 L F
.368 .387 .749 r
.28899 .63177 m .28691 .63289 L .28647 .6296 L F
.09 .069 .538 r
.28878 .63426 m .28691 .63289 L .28899 .63177 L F
.28878 .63426 m .28732 .63547 L .28691 .63289 L F
.568 .592 .837 r
.50007 .55552 m .50102 .55135 L .49863 .55191 L F
.50007 .55552 m .50228 .55487 L .50102 .55135 L F
.525 .422 .68 r
.50007 .55552 m .50305 .55692 L .50228 .55487 L F
.346 .067 .34 r
.32249 .61987 m .32021 .62067 L .31961 .62257 L F
0 0 .15 r
.37176 .54613 m .37269 .54613 L .37358 .54677 L F
.37176 .54613 m .37126 .54843 L .37269 .54613 L F
0 .238 .649 r
.35129 .62973 m .34962 .62867 L .34689 .62713 L F
.993 .752 .457 r
.35129 .62973 m .35097 .63232 L .34962 .62867 L F
.29 .394 .797 r
.35873 .63086 m .35718 .63232 L .35477 .63059 L F
.233 .387 .813 r
.35477 .63059 m .35718 .63232 L .35535 .63069 L F
.661 .401 .516 r
.35535 .63069 m .35097 .63232 L .35129 .62973 L F
.472 .875 .957 r
.24798 .62385 m .24714 .62499 L .24513 .62372 L F
.24798 .62385 m .25017 .62417 L .24714 .62499 L F
.518 .69 .946 r
.51658 .53583 m .51391 .53785 L .51331 .53757 L F
.5161 .53619 m .51794 .53788 L .51391 .53785 L F
.51679 .53615 m .51794 .53788 L .5161 .53619 L F
.731 .789 .898 r
.52104 .53556 m .51794 .53788 L .51658 .53583 L F
.371 .812 .662 r
.51331 .53757 m .51484 .53671 L .51658 .53583 L F
.142 0 0 r
.51484 .53671 m .51864 .53644 L .51973 .53596 L F
.51851 .53604 m .51973 .53596 L .52031 .53571 L F
.51484 .53671 m .51973 .53596 L .51851 .53604 L F
.518 .69 .946 r
.51658 .53583 m .51679 .53615 L .5161 .53619 L F
.411 .862 .84 r
.51185 .5383 m .51331 .53757 L .51391 .53785 L F
.558 .301 .482 r
.51256 .53943 m .5147 .53689 L .51331 .53757 L F
.5147 .53689 m .51484 .53671 L .51331 .53757 L F
.411 .862 .84 r
.51127 .53842 m .51331 .53757 L .51185 .5383 L F
.244 .753 .873 r
.27731 .53042 m .27973 .53009 L .28131 .53026 L F
.345 .053 .318 r
.21011 .56943 m .20858 .56797 L .21178 .56746 L F
.664 .943 .961 r
.21327 .56614 m .21195 .56608 L .21178 .56746 L F
.828 .937 .567 r
.21195 .56608 m .21011 .56943 L .21178 .56746 L F
.175 0 .037 r
.20347 .57201 m .20305 .5704 L .20538 .5703 L F
.20347 .57201 m .20144 .57276 L .20305 .5704 L F
.593 .616 .844 r
.24944 .5484 m .24616 .54686 L .24864 .54631 L F
.52 .307 .531 r
.33482 .6398 m .33093 .63892 L .33364 .6383 L F
.33482 .6398 m .33058 .64155 L .33093 .63892 L F
.422 .802 .992 r
.323 .53203 m .32535 .53168 L .32721 .53248 L F
.487 .832 .997 r
.32777 .53116 m .32721 .53248 L .32535 .53168 L F
.32777 .53116 m .32898 .53189 L .32721 .53248 L F
.808 .783 .83 r
.50325 .54759 m .50766 .5484 L .50538 .54946 L F
.234 0 .26 r
.30942 .57902 m .30783 .57682 L .30829 .57664 L F
.30942 .57902 m .30829 .57664 L .30979 .57737 L F
.30941 .57901 m .30598 .5808 L .30783 .57682 L F
.30942 .57902 m .30936 .57904 L .30941 .57901 L F
.30936 .57904 m .30598 .5808 L .30941 .57901 L F
.5 .483 .769 r
.30904 .58125 m .30598 .5808 L .30942 .57902 L F
.527 .597 .868 r
.30551 .57877 m .30773 .58033 L .30781 .57768 L F
.30773 .58033 m .30904 .58125 L .30851 .57971 L F
.30773 .58033 m .30851 .57971 L .30781 .57768 L F
.516 .162 .305 r
.31193 .57782 m .30942 .57902 L .31011 .57592 L F
.404 .184 .463 r
.31193 .57782 m .30904 .58125 L .30942 .57902 L F
.587 .561 .792 r
.30781 .57768 m .31094 .57899 L .31193 .57782 L F
.372 0 0 r
.31063 .57778 m .3099 .57782 L .30781 .57768 L F
.31193 .57782 m .31072 .57782 L .31063 .57778 L F
.31072 .57782 m .3099 .57782 L .31063 .57778 L F
.234 0 .26 r
.30979 .57737 m .30829 .57664 L .31011 .57592 L F
0 0 .181 r
.29287 .58599 m .29443 .585 L .29491 .5827 L F
0 0 0 r
.29287 .58599 m .2921 .58816 L .29443 .585 L F
.341 .033 .29 r
.28516 .59539 m .28737 .59466 L .28828 .59236 L F
.04 0 .137 r
.28828 .59236 m .28933 .5936 L .28995 .59153 L F
.28828 .59236 m .28737 .59466 L .28933 .5936 L F
.859 .666 .64 r
.31722 .60181 m .31448 .60302 L .31449 .60161 L F
.31722 .60181 m .31662 .6048 L .31448 .60302 L F
.604 .413 .596 r
.31904 .60135 m .31662 .6048 L .31722 .60181 L F
.725 .242 .098 r
.36878 .53859 m .36377 .53754 L .36651 .53624 L F
.58 .362 .548 r
.3176 .62571 m .31416 .62866 L .31516 .62607 L F
.166 .29 .746 r
.34751 .6526 m .34665 .65585 L .34517 .65056 L F
.216 0 .089 r
.34907 .6562 m .34638 .65715 L .34665 .65585 L F
.721 .954 .668 r
.30545 .59655 m .30335 .59881 L .30393 .59771 L F
.802 .621 .656 r
.30393 .59771 m .30772 .59438 L .30545 .59655 L F
.314 .729 .976 r
.26994 .64154 m .27069 .64062 L .26839 .64086 L F
.26994 .64154 m .27241 .64153 L .27069 .64062 L F
0 0 .263 r
.24881 .73619 m .24973 .73669 L .25088 .7351 L F
.431 .251 .534 r
.25609 .72583 m .25354 .72774 L .2549 .72561 L F
.25609 .72583 m .25596 .72875 L .25354 .72774 L F
.52 .726 .967 r
.25825 .72533 m .25609 .72583 L .25702 .72384 L F
.764 .991 .887 r
.25702 .72384 m .25609 .72583 L .2549 .72561 L F
.438 .256 .536 r
.25806 .72802 m .25609 .72583 L .25825 .72533 L F
.25806 .72802 m .25596 .72875 L .25609 .72583 L F
.295 0 0 r
.34664 .66544 m .34768 .66635 L .34444 .66823 L F
.34664 .66544 m .34874 .66514 L .34768 .66635 L F
.996 .866 .566 r
.33347 .56391 m .3325 .56327 L .33352 .56145 L F
.746 .672 .779 r
.33632 .5613 m .33347 .56391 L .33352 .56145 L F
.259 .256 .665 r
.32172 .54465 m .32144 .54494 L .31959 .54274 L F
.589 .239 .344 r
.32243 .54283 m .32172 .54465 L .31959 .54274 L F
.696 .599 .744 r
.51961 .55836 m .52363 .55867 L .5205 .56104 L F
.545 .393 .626 r
.34645 .54865 m .34928 .54839 L .34911 .54542 L F
.659 .476 .626 r
.34645 .54865 m .35023 .55192 L .34928 .54839 L F
.34645 .54865 m .3473 .55224 L .35023 .55192 L F
.791 .546 .566 r
.27783 .68204 m .27961 .6806 L .27854 .68109 L F
.349 .804 .942 r
.29391 .52905 m .28985 .52907 L .29222 .52839 L F
.425 .773 .996 r
.29452 .52773 m .29391 .52905 L .29222 .52839 L F
.29452 .52773 m .29625 .52877 L .29391 .52905 L F
.175 .133 .568 r
.31911 .58589 m .31902 .58585 L .32031 .58197 L F
.31911 .58589 m .32031 .58197 L .31783 .58398 L F
0 0 0 r
.23942 .74786 m .23573 .74947 L .23665 .74964 L F
.592 .768 .963 r
.17273 .59831 m .17629 .59908 L .17511 .59762 L F
.17273 .59831 m .17629 .59908 L .17511 .59762 L F
.024 .324 .81 r
.17629 .59908 m .17661 .59778 L .17511 .59762 L F
.17629 .59908 m .1788 .60083 L .17661 .59778 L F
.224 .495 .9 r
.20671 .59895 m .2065 .60073 L .20397 .59844 L F
.20671 .59895 m .20813 .60094 L .2065 .60073 L F
.237 0 0 r
.21099 .54466 m .21505 .54194 L .21282 .54278 L F
.782 .691 .763 r
.25088 .7351 m .25484 .73512 L .25212 .73796 L F
.269 .01 .324 r
.28566 .61095 m .28824 .60763 L .28792 .61028 L F
.187 .003 .385 r
.29161 .6032 m .29068 .60739 L .28824 .60763 L F
.127 0 .234 r
.28936 .60935 m .28824 .60763 L .29068 .60739 L F
.28936 .60935 m .28792 .61028 L .28824 .60763 L F
.397 .239 .547 r
.1693 .57978 m .17128 .5792 L .17131 .57658 L F
.365 .252 .59 r
.1693 .57978 m .17135 .58192 L .17128 .5792 L F
.1693 .57978 m .16891 .58388 L .17135 .58192 L F
.603 .254 .35 r
.33352 .56145 m .3325 .56327 L .33 .56139 L F
.232 .319 .748 r
.33 .56139 m .3325 .56327 L .33135 .56005 L F
.097 .61 .889 r
.32735 .56498 m .33174 .56535 L .33229 .56605 L F
0 0 0 r
.32735 .56498 m .32776 .56541 L .33174 .56535 L F
.32735 .56498 m .32586 .56625 L .32776 .56541 L F
.689 .208 .101 r
.33821 .63567 m .34247 .63763 L .34011 .63551 L F
.525 .219 .39 r
.20858 .56797 m .2079 .57021 L .20538 .5703 L F
.345 .053 .318 r
.21011 .56943 m .2079 .57021 L .20858 .56797 L F
.444 .398 .713 r
.34848 .60155 m .34912 .60532 L .35113 .60348 L F
.575 .479 .708 r
.34912 .60532 m .35224 .60723 L .35113 .60348 L F
.34912 .60532 m .34972 .60782 L .35224 .60723 L F
.019 0 0 r
.3223 .58872 m .32317 .58777 L .32542 .58623 L F
.397 .261 .576 r
.30605 .54776 m .30401 .54598 L .30618 .54502 L F
.30605 .54776 m .304 .54865 L .30401 .54598 L F
.347 .741 .985 r
.31836 .53023 m .31686 .53128 L .31515 .53033 L F
.31836 .53023 m .31959 .53118 L .31686 .53128 L F
.534 .333 .554 r
.2978 .63581 m .3003 .63536 L .30042 .63275 L F
.638 .655 .85 r
.30042 .63275 m .30125 .62891 L .29923 .62907 L F
.30042 .63275 m .30308 .63245 L .30125 .62891 L F
.62 .41 .576 r
.3003 .63536 m .30308 .63245 L .30042 .63275 L F
.199 0 .167 r
.2978 .63581 m .29494 .63855 L .29754 .63816 L F
.489 .267 .503 r
.2978 .63581 m .29994 .63734 L .3003 .63536 L F
.2978 .63581 m .29754 .63816 L .29994 .63734 L F
.403 .806 .982 r
.24774 .53276 m .25185 .53306 L .24955 .53305 L F
.29 0 0 r
.25497 .55827 m .25309 .55864 L .25082 .55826 L F
.608 .217 .278 r
.25662 .55699 m .25309 .55864 L .25497 .55827 L F
.282 .352 .758 r
.25845 .7196 m .26074 .72219 L .2598 .71871 L F
.484 .09 .217 r
.28638 .54273 m .28361 .54331 L .28394 .54269 L F
.456 .117 .301 r
.28394 .54269 m .28605 .54302 L .28361 .54331 L F
.366 0 0 r
.28638 .54273 m .28605 .54302 L .28394 .54269 L F
.815 .854 .878 r
.22151 .55982 m .21944 .56166 L .22318 .5612 L F
.726 .463 .528 r
.21908 .56327 m .22318 .5612 L .21944 .56166 L F
.21908 .56327 m .22304 .56379 L .22318 .5612 L F
.775 .852 .908 r
.22151 .55982 m .22318 .5612 L .22638 .55906 L F
.63 .924 .975 r
.28754 .52993 m .2883 .5283 L .28985 .52907 L F
.28754 .52993 m .28598 .52946 L .2883 .5283 L F
0 0 .538 r
.22617 .55652 m .22508 .55588 L .2268 .55452 L F
.065 .176 .67 r
.22649 .55749 m .22638 .55906 L .22508 .55588 L F
.875 .904 .848 r
.22649 .55749 m .22618 .55763 L .22638 .55906 L F
0 0 .538 r
.22601 .55643 m .22638 .55906 L .22508 .55588 L F
.875 .904 .848 r
.22618 .55763 m .22368 .55874 L .22638 .55906 L F
0 0 .538 r
.22617 .55652 m .22638 .55906 L .22601 .55643 L F
.555 .004 0 r
.23952 .63468 m .23768 .6346 L .23495 .63314 L F
.055 .372 .839 r
.23495 .63314 m .23768 .6346 L .23567 .63179 L F
.441 .827 .987 r
.3116 .52993 m .31053 .5312 L .30901 .5307 L F
.3116 .52993 m .31299 .53072 L .31053 .5312 L F
.881 .673 .616 r
.53892 .53227 m .54067 .53613 L .54125 .5336 L F
.713 .495 .593 r
.54125 .5336 m .54067 .53613 L .54314 .53612 L F
0 .07 .62 r
.34678 .53145 m .34545 .53155 L .34452 .52927 L F
.05 .483 .887 r
.23747 .62151 m .23707 .62224 L .2347 .62035 L F
.23747 .62151 m .23902 .62294 L .23707 .62224 L F
0 0 0 r
.27396 .61427 m .27063 .61667 L .27186 .61568 L F
.876 .981 .835 r
.2737 .61214 m .27396 .61427 L .27186 .61568 L F
.26 .753 .674 r
.53333 .56117 m .52929 .56267 L .53134 .56225 L F
.578 .172 .236 r
.24944 .5484 m .2478 .55078 L .24578 .5502 L F
.411 0 0 r
.29151 .55205 m .28733 .55319 L .28912 .55198 L F
0 0 .288 r
.29995 .57067 m .3006 .57206 L .30059 .5697 L F
.29995 .57067 m .29964 .5733 L .3006 .57206 L F
.602 .062 0 r
.34423 .56606 m .34635 .56725 L .34242 .56647 L F
.479 .294 .551 r
.35285 .59776 m .35534 .59453 L .35353 .59592 L F
.419 .204 .479 r
.28566 .61095 m .28533 .61323 L .28326 .61401 L F
.177 0 .32 r
.28461 .61574 m .28326 .61401 L .28533 .61323 L F
.28461 .61574 m .28321 .61679 L .28326 .61401 L F
.529 .332 .557 r
.32887 .64785 m .3291 .65088 L .32611 .651 L F
.464 .371 .666 r
.32927 .65362 m .32611 .651 L .3291 .65088 L F
.32927 .65362 m .32695 .65431 L .32611 .651 L F
.506 0 0 r
.22649 .55749 m .23212 .55886 L .23063 .55845 L F
.65 .594 .778 r
.22649 .55749 m .2314 .55993 L .23212 .55886 L F
.444 0 .057 r
.23212 .55886 m .2314 .55993 L .2346 .55952 L F
0 0 .346 r
.27827 .55259 m .27802 .55507 L .2773 .554 L F
.733 .929 .955 r
.25649 .54674 m .25634 .54877 L .25884 .54732 L F
.504 .06 .128 r
.25459 .5504 m .25634 .54877 L .25649 .54674 L F
.25459 .5504 m .25791 .55032 L .25634 .54877 L F
.556 .359 .569 r
.25884 .54732 m .25634 .54877 L .25953 .54712 L F
.384 .067 .299 r
.25634 .54877 m .25791 .55032 L .25953 .54712 L F
.606 .046 0 r
.32876 .55511 m .32465 .55228 L .32715 .55155 L F
.32876 .55511 m .32702 .55429 L .32465 .55228 L F
.266 .347 .76 r
.32876 .55511 m .33135 .55728 L .33005 .5521 L F
.746 .906 .948 r
.33005 .5521 m .32702 .55429 L .32876 .55511 L F
.181 0 .231 r
.299 .58845 m .29711 .58933 L .29981 .58616 L F
.019 0 .037 r
.30185 .58526 m .299 .58845 L .29981 .58616 L F
0 0 0 r
.35856 .62808 m .35766 .62823 L .35934 .62589 L F
.366 .413 .777 r
.34848 .60155 m .34922 .59744 L .34635 .60033 L F
.34848 .60155 m .35038 .60115 L .34922 .59744 L F
.444 .398 .713 r
.34848 .60155 m .35113 .60348 L .35038 .60115 L F
.5 .357 .619 r
.37667 .58852 m .37433 .58653 L .37676 .58581 L F
.37667 .58852 m .37434 .58908 L .37433 .58653 L F
.635 .251 .299 r
.36674 .55205 m .36879 .554 L .3702 .55222 L F
.262 .173 .562 r
.30656 .61722 m .30819 .61694 L .30871 .61291 L F
.296 .366 .766 r
.30656 .61722 m .30929 .61943 L .30819 .61694 L F
.424 .377 .702 r
.30732 .62023 m .30929 .61943 L .30656 .61722 L F
0 0 0 r
.34204 .61638 m .34273 .61693 L .34446 .61615 L F
.34204 .61638 m .34044 .61887 L .34273 .61693 L F
.71 .613 .748 r
.3518 .66124 m .34815 .6599 L .35025 .65968 L F
.708 .261 .187 r
.35025 .65968 m .35412 .66043 L .3518 .66124 L F
.518 .869 .989 r
.54586 .54802 m .54339 .54881 L .54766 .54848 L F
.946 .681 .503 r
.546 .54545 m .54586 .54802 L .54766 .54848 L F
.251 0 .245 r
.33513 .57057 m .33411 .57297 L .3323 .57344 L F
.77 .69 .775 r
.33387 .56741 m .33513 .57057 L .33816 .56599 L F
.49 .537 .832 r
.33655 .56856 m .33513 .57057 L .33387 .56741 L F
.363 .184 .499 r
.33655 .56856 m .33411 .57297 L .33513 .57057 L F
.432 .395 .717 r
.3451 .64803 m .34517 .65056 L .34339 .65117 L F
.904 .959 .626 r
.34368 .65405 m .34517 .65056 L .34339 .65117 L F
.432 .395 .717 r
.3451 .64803 m .34517 .65056 L .34339 .65117 L F
.967 .723 .517 r
.28526 .54863 m .28528 .55223 L .28356 .55059 L F
.7 .899 .535 r
.28526 .54863 m .28581 .54734 L .28778 .5486 L F
.28526 .54863 m .28356 .55059 L .28581 .54734 L F
.668 .582 .749 r
.35456 .57336 m .35682 .5696 L .35462 .57041 L F
.277 .305 .71 r
.33742 .6156 m .33839 .61947 L .33626 .61686 L F
.467 0 0 r
.33215 .56595 m .33229 .56605 L .33174 .56535 L F
.33215 .56595 m .33387 .56741 L .33229 .56605 L F
.728 .609 .724 r
.51849 .54932 m .51947 .54678 L .52042 .54579 L F
.017 0 0 r
.29277 .54232 m .28873 .54263 L .28638 .54273 L F
.509 0 0 r
.29263 .54269 m .28873 .54263 L .29277 .54232 L F
.027 0 .386 r
.299 .58845 m .29765 .59192 L .29711 .58933 L F
0 0 .106 r
.35864 .66216 m .35812 .66358 L .35829 .66053 L F
.35864 .66216 m .35829 .66053 L .35666 .65943 L F
.734 .446 .492 r
.32225 .66264 m .31845 .66005 L .32249 .66087 L F
.693 .301 .3 r
.32249 .66087 m .3245 .66307 L .32225 .66264 L F
.614 .311 .433 r
.32723 .65997 m .3245 .66307 L .32249 .66087 L F
.437 .403 .723 r
.38461 .53494 m .38234 .53702 L .38189 .5355 L F
.38461 .53494 m .38518 .53882 L .38234 .53702 L F
.246 .759 .84 r
.35557 .66414 m .35392 .66413 L .35164 .66455 L F
.198 .728 .789 r
.35812 .66358 m .35392 .66413 L .35557 .66414 L F
.673 .564 .724 r
.29943 .55505 m .30061 .55837 L .30308 .55823 L F
.417 .275 .579 r
.30061 .55837 m .30309 .55981 L .30308 .55823 L F
.30061 .55837 m .30031 .56116 L .30309 .55981 L F
.122 .304 .775 r
.2536 .73757 m .25212 .73796 L .25088 .7351 L F
.198 .727 .818 r
.25004 .73792 m .25212 .73796 L .2536 .73757 L F
.77 .684 .768 r
.33968 .60558 m .34028 .60723 L .33703 .60795 L F
.876 .864 .824 r
.34028 .60723 m .33655 .61031 L .33703 .60795 L F
.378 .259 .589 r
.34202 .60427 m .34028 .60723 L .33968 .60558 L F
.34202 .60427 m .34219 .6068 L .34028 .60723 L F
.522 .048 .07 r
.25531 .62346 m .25751 .62451 L .25922 .62291 L F
.187 0 0 r
.25751 .62451 m .2615 .62243 L .25922 .62291 L F
0 .013 .587 r
.24801 .73767 m .24822 .73889 L .24738 .73727 L F
.973 .753 .546 r
.3388 .54269 m .33695 .54151 L .3346 .5421 L F
.3388 .54269 m .33805 .54513 L .33695 .54151 L F
.356 .733 .987 r
.33695 .54151 m .34038 .54218 L .3388 .54269 L F
.724 .655 .781 r
.34038 .54218 m .33805 .54513 L .3388 .54269 L F
.727 .603 .718 r
.3481 .58607 m .35177 .58687 L .35043 .58277 L F
.68 .577 .732 r
.35043 .58277 m .35177 .58687 L .35451 .58598 L F
.454 .466 .781 r
.35177 .58687 m .35445 .58855 L .35451 .58598 L F
.459 .144 .344 r
.27827 .55259 m .27306 .55274 L .27822 .55096 L F
.621 .225 .271 r
.27577 .55329 m .27265 .55188 L .27306 .55274 L F
.433 .447 .774 r
.33098 .64687 m .32887 .64785 L .32842 .64516 L F
.532 .415 .666 r
.33098 .64687 m .3291 .65088 L .32887 .64785 L F
0 .121 .649 r
.30527 .65238 m .30789 .6555 L .30887 .65634 L F
.238 .058 .424 r
.19603 .57613 m .19413 .57928 L .19444 .57683 L F
0 0 .303 r
.31704 .61058 m .31676 .61345 L .31591 .61399 L F
0 0 .243 r
.31676 .61345 m .31617 .61654 L .31591 .61399 L F
.396 .356 .696 r
.3702 .55222 m .37214 .55132 L .37126 .54843 L F
.49 .213 .42 r
.36879 .554 m .37214 .55132 L .3702 .55222 L F
.516 .852 .996 r
.25151 .71283 m .25331 .71354 L .25385 .71218 L F
.25151 .71283 m .25331 .71354 L .25385 .71218 L F
0 0 .295 r
.28674 .61235 m .28566 .61095 L .28792 .61028 L F
.28674 .61235 m .28533 .61323 L .28566 .61095 L F
.692 .291 .282 r
.52927 .55021 m .52676 .54919 L .52998 .54898 L F
.618 .464 .651 r
.5337 .54585 m .53314 .54913 L .52998 .54898 L F
.502 .047 .102 r
.53314 .54913 m .53325 .54979 L .52998 .54898 L F
.618 .464 .651 r
.5337 .54585 m .53314 .54913 L .52998 .54898 L F
.502 .047 .102 r
.53314 .54913 m .53325 .54979 L .52998 .54898 L F
0 0 .16 r
.37707 .53942 m .37713 .53815 L .37516 .53811 L F
.37707 .53942 m .37792 .54038 L .37713 .53815 L F
.37707 .53942 m .37652 .54203 L .37792 .54038 L F
.146 .062 .495 r
.31987 .6482 m .32127 .64444 L .31894 .64478 L F
.31987 .6482 m .32076 .64836 L .32127 .64444 L F
.503 .361 .621 r
.31946 .65075 m .32076 .64836 L .31987 .6482 L F
.634 .846 .981 r
.33632 .5613 m .33352 .56145 L .33463 .56025 L F
.447 .343 .643 r
.34717 .61094 m .34767 .61408 L .34954 .6134 L F
.39 .453 .806 r
.29943 .55505 m .30005 .5513 L .29774 .55192 L F
.29943 .55505 m .30113 .55458 L .30005 .5513 L F
.703 .791 .92 r
.5408 .53885 m .54227 .54087 L .54462 .53934 L F
.388 0 0 r
.32833 .54047 m .3317 .54152 L .33102 .54085 L F
.298 .157 .514 r
.33394 .57536 m .3323 .57344 L .33411 .57297 L F
.33394 .57536 m .33229 .5762 L .3323 .57344 L F
.524 .433 .694 r
.31894 .64478 m .32127 .64444 L .3208 .64139 L F
.638 .627 .823 r
.35887 .53288 m .36124 .5326 L .36058 .52874 L F
.637 .562 .753 r
.35887 .53288 m .36227 .53303 L .36124 .5326 L F
.581 .449 .665 r
.35887 .53288 m .36198 .53574 L .36227 .53303 L F
.35887 .53288 m .35967 .53623 L .36198 .53574 L F
0 .494 .806 r
.31509 .56694 m .31752 .56752 L .31838 .56797 L F
.31509 .56694 m .31752 .56752 L .31838 .56797 L F
.82 .981 .887 r
.31838 .56797 m .31878 .5659 L .32085 .56702 L F
.31838 .56797 m .31752 .56752 L .31878 .5659 L F
.539 .355 .58 r
.31838 .56797 m .31878 .5659 L .31752 .56752 L F
.31838 .56797 m .32085 .56702 L .31878 .5659 L F
.31838 .56797 m .32061 .57004 L .32085 .56702 L F
.526 .681 .936 r
.33056 .54443 m .32992 .54735 L .32745 .54666 L F
.33056 .54443 m .33299 .54732 L .32992 .54735 L F
.541 .262 .441 r
.32734 .6597 m .3245 .66307 L .32723 .65997 L F
.28 0 .158 r
.29494 .63855 m .2915 .64168 L .29407 .64135 L F
.483 .151 .327 r
.29663 .64086 m .29494 .63855 L .29407 .64135 L F
.29663 .64086 m .29754 .63816 L .29494 .63855 L F
.436 .522 .848 r
.21034 .60061 m .21 .60418 L .20813 .60094 L F
.21034 .60061 m .21196 .604 L .21 .60418 L F
.263 .349 .764 r
.21252 .60773 m .21 .60418 L .21196 .604 L F
.965 .913 .563 r
.30776 .55172 m .30689 .55527 L .30639 .55384 L F
.30776 .55172 m .30639 .55384 L .30651 .55281 L F
.665 .757 .271 r
.30776 .55172 m .30813 .55073 L .30837 .55014 L F
.30864 .5495 m .30837 .55014 L .30928 .5479 L F
.30776 .55172 m .30837 .55014 L .30864 .5495 L F
.721 .438 .497 r
.30819 .55056 m .30838 .55067 L .30868 .55275 L F
.092 0 .063 r
.30862 .55156 m .30832 .55059 L .30817 .55061 L F
.30903 .55243 m .3086 .55134 L .30862 .55156 L F
.721 .438 .497 r
.30838 .55067 m .3086 .55134 L .30868 .55275 L F
.092 0 .063 r
.3086 .55134 m .30832 .55059 L .30862 .55156 L F
.30868 .55275 m .30903 .55243 L .30817 .55061 L F
.30868 .55275 m .31081 .55196 L .31148 .55018 L F
.721 .438 .497 r
.3086 .55134 m .30903 .55262 L .30868 .55275 L F
.28 0 0 r
.30886 .55201 m .30889 .55218 L .30873 .55172 L F
.30894 .55218 m .30893 .55218 L .30886 .55201 L F
.30893 .55218 m .30889 .55218 L .30886 .55201 L F
.665 .757 .271 r
.30813 .55073 m .30813 .55071 L .30928 .5479 L F
.30813 .55072 m .30822 .55048 L .30928 .5479 L F
.30822 .55048 m .30825 .55041 L .30827 .55037 L F
.30822 .55048 m .30827 .55037 L .30928 .5479 L F
.308 .089 .409 r
.30928 .5479 m .31186 .54732 L .31196 .54396 L F
.578 .118 .124 r
.30928 .5479 m .31148 .55018 L .31186 .54732 L F
.873 .731 .703 r
.30999 .54984 m .30894 .55218 L .3083 .55036 L F
.578 .118 .124 r
.30825 .55041 m .30844 .5505 L .30938 .55014 L F
.30936 .55006 m .30938 .55014 L .31089 .54957 L F
.30825 .55041 m .30938 .55014 L .30936 .55006 L F
.30999 .54984 m .30998 .54986 L .31089 .54957 L F
.721 .438 .497 r
.30825 .55041 m .30831 .55045 L .30819 .55056 L F
.30831 .55045 m .30837 .55065 L .30819 .55056 L F
.616 .474 .666 r
.30763 .55197 m .30669 .55125 L .30819 .55056 L F
.665 .757 .271 r
.30813 .55072 m .30817 .55061 L .30825 .55041 L F
.578 .118 .124 r
.30825 .55041 m .30817 .55061 L .30844 .5505 L F
.30831 .55055 m .30817 .55061 L .30832 .55059 L F
.28 0 0 r
.30834 .55083 m .3082 .55053 L .30828 .55038 L F
.578 .118 .124 r
.30827 .55037 m .30825 .55041 L .30998 .54986 L F
.28 0 0 r
.3083 .55044 m .30828 .55038 L .3083 .55036 L F
.30834 .55083 m .30828 .55038 L .3083 .55044 L F
.092 0 .063 r
.30895 .55214 m .30974 .5504 L .30856 .55055 L F
.721 .438 .497 r
.30831 .55045 m .30947 .55115 L .30837 .55065 L F
.092 0 .063 r
.3091 .55223 m .31148 .55018 L .30974 .5504 L F
.30903 .55243 m .30921 .55226 L .3091 .55223 L F
.30921 .55226 m .31148 .55018 L .3091 .55223 L F
0 0 0 r
.30974 .5504 m .30894 .55218 L .30999 .54984 L F
.092 0 .063 r
.30898 .55208 m .30974 .5504 L .30898 .55208 L F
.30903 .55243 m .30973 .55041 L .30898 .55208 L F
0 0 0 r
.30898 .55208 m .30894 .55218 L .30974 .5504 L F
.092 0 .063 r
.30973 .55041 m .30974 .5504 L .30898 .55208 L F
0 0 0 r
.30952 .55089 m .30898 .55208 L .30974 .5504 L F
0 0 .414 r
.30954 .55098 m .30897 .5521 L .30952 .55089 L F
.30897 .5521 m .30894 .55218 L .30898 .55208 L F
.30897 .5521 m .30898 .55208 L .30952 .55089 L F
.30917 .55192 m .30894 .55218 L .30954 .55098 L F
.092 0 .063 r
.30896 .55216 m .30898 .55208 L .30895 .55214 L F
.30903 .55243 m .30898 .55208 L .30896 .55216 L F
.28 0 0 r
.30894 .55218 m .30896 .55219 L .30893 .55218 L F
.092 0 .063 r
.30903 .55243 m .30856 .55055 L .3086 .55134 L F
.721 .438 .497 r
.30916 .55196 m .31081 .55196 L .30957 .55242 L F
.30923 .55151 m .31081 .55196 L .30916 .55196 L F
.30947 .55115 m .31081 .55196 L .30944 .55123 L F
.31 .55119 m .31081 .55196 L .30947 .55115 L F
.30954 .55098 m .30947 .55115 L .30825 .55041 L F
.31 .55119 m .30947 .55115 L .30954 .55098 L F
.578 .118 .124 r
.30827 .55037 m .30998 .54986 L .30999 .54984 L F
.31089 .54957 m .309 .55029 L .31148 .55018 L F
.309 .55029 m .30831 .55055 L .3091 .55046 L F
.309 .55029 m .3091 .55046 L .31148 .55018 L F
.721 .438 .497 r
.30889 .55218 m .30957 .55242 L .30903 .55262 L F
.732 .315 .256 r
.30973 .55254 m .30938 .55402 L .30859 .55217 L F
0 0 0 r
.30974 .5525 m .30938 .55402 L .30973 .55254 L F
.655 .278 .317 r
.30966 .55283 m .30938 .55402 L .31004 .55307 L F
0 0 .414 r
.30955 .55169 m .30973 .55254 L .30911 .55225 L F
.30971 .55215 m .30973 .55254 L .30955 .55169 L F
.28 0 0 r
.30889 .55218 m .30973 .55254 L .30859 .55217 L F
.30893 .55218 m .30907 .55224 L .30889 .55218 L F
.30907 .55224 m .30973 .55254 L .30889 .55218 L F
.30896 .55219 m .30973 .55254 L .30893 .55218 L F
.655 .278 .317 r
.30859 .55217 m .31004 .55307 L .30968 .55207 L F
0 0 0 r
.30986 .55203 m .30938 .55402 L .30974 .5525 L F
.655 .278 .317 r
.30859 .55217 m .30938 .55402 L .30966 .55283 L F
.30968 .55207 m .31004 .55307 L .31081 .55196 L F
.578 .118 .124 r
.30831 .55055 m .30832 .55059 L .30911 .55048 L F
.3091 .55046 m .30911 .55048 L .31148 .55018 L F
.30831 .55055 m .30911 .55048 L .3091 .55046 L F
0 0 .414 r
.30962 .55141 m .30911 .55225 L .30917 .55192 L F
.721 .438 .497 r
.30858 .55077 m .31081 .55196 L .3086 .55134 L F
.3096 .55081 m .30968 .55207 L .31081 .55196 L F
0 0 .414 r
.30958 .55121 m .30954 .55098 L .3096 .55083 L F
.721 .438 .497 r
.3096 .55081 m .31 .55119 L .30959 .55101 L F
.3096 .55081 m .30959 .55101 L .3083 .55044 L F
.578 .118 .124 r
.30928 .5479 m .30827 .55037 L .31089 .54957 L F
.873 .731 .703 r
.31118 .54718 m .30999 .54984 L .30829 .55032 L F
.30999 .54984 m .3083 .55036 L .30829 .55032 L F
.31118 .54718 m .30829 .55032 L .30903 .54848 L F
.721 .438 .497 r
.30851 .54977 m .3096 .55081 L .3083 .55044 L F
.30938 .5506 m .30956 .55147 L .3096 .55081 L F
.30956 .55147 m .30968 .55207 L .3096 .55081 L F
0 0 .414 r
.30962 .55141 m .30958 .55121 L .31095 .54771 L F
.30958 .55121 m .3096 .55083 L .31095 .54771 L F
.3108 .55008 m .30968 .55152 L .30962 .55141 L F
.30968 .55152 m .30911 .55225 L .30962 .55141 L F
.721 .438 .497 r
.30827 .55035 m .3083 .55044 L .30825 .55041 L F
.28 0 0 r
.3083 .55036 m .30828 .55038 L .30829 .55032 L F
.30828 .55038 m .30827 .55035 L .30829 .55032 L F
.721 .438 .497 r
.30851 .54977 m .3083 .55044 L .30827 .55035 L F
.28 0 0 r
.30828 .55038 m .3082 .55053 L .30827 .55035 L F
0 0 .414 r
.30917 .55192 m .30911 .55225 L .30894 .55218 L F
.721 .438 .497 r
.3086 .55134 m .30923 .55151 L .30916 .55196 L F
.3086 .55134 m .30957 .55242 L .30889 .55218 L F
.28 0 0 r
.30894 .55218 m .30834 .55083 L .3083 .55036 L F
.873 .731 .703 r
.30903 .54848 m .30829 .55032 L .30788 .54917 L F
.721 .438 .497 r
.30838 .55067 m .30858 .55077 L .3086 .55134 L F
.092 0 .063 r
.3086 .55134 m .30856 .55055 L .30832 .55059 L F
.28 0 0 r
.30873 .55172 m .30859 .55217 L .3082 .55053 L F
.30889 .55218 m .30859 .55217 L .30873 .55172 L F
.30829 .55032 m .30827 .55035 L .30788 .54917 L F
.721 .438 .497 r
.30788 .54917 m .30827 .55035 L .30819 .55056 L F
.28 0 0 r
.30827 .55035 m .3082 .55053 L .30788 .54917 L F
.721 .438 .497 r
.30788 .54917 m .30851 .54977 L .30827 .55035 L F
.30788 .54917 m .30859 .55217 L .30968 .55207 L F
0 0 .414 r
.30959 .55163 m .30968 .55207 L .30955 .55169 L F
.721 .438 .497 r
.30947 .55115 m .30944 .55123 L .30819 .55056 L F
0 0 .414 r
.30958 .55121 m .30917 .55192 L .30954 .55098 L F
.30962 .55141 m .30956 .55147 L .30958 .55121 L F
.30956 .55147 m .30917 .55192 L .30958 .55121 L F
.721 .438 .497 r
.30788 .54917 m .30954 .55183 L .30938 .5506 L F
.30954 .55183 m .30968 .55207 L .30956 .55147 L F
.30954 .55183 m .30956 .55147 L .30938 .5506 L F
0 0 .414 r
.30968 .55152 m .30971 .55215 L .30968 .55207 L F
.30968 .55152 m .30968 .55207 L .30959 .55163 L F
.3108 .55008 m .30995 .55203 L .30968 .55152 L F
.30995 .55203 m .30973 .55254 L .30968 .55152 L F
.30954 .55098 m .30952 .55089 L .30998 .54986 L F
.30954 .55098 m .30998 .54986 L .31095 .54771 L F
.3108 .55008 m .30962 .55141 L .31095 .54771 L F
0 0 0 r
.31095 .54771 m .30952 .55089 L .31118 .54718 L F
.30952 .55089 m .30999 .54984 L .31118 .54718 L F
.665 .757 .271 r
.30813 .55073 m .30813 .55072 L .30813 .55071 L F
.616 .474 .666 r
.30819 .55056 m .30669 .55125 L .30788 .54917 L F
.30868 .55275 m .30813 .55072 L .30819 .55056 L F
.243 0 0 r
.30813 .55072 m .30868 .55275 L .30817 .55061 L F
.30776 .55172 m .30868 .55275 L .30813 .55072 L F
.616 .474 .666 r
.30868 .55275 m .30763 .55197 L .30813 .55072 L F
.30669 .55125 m .30591 .55067 L .30683 .54997 L F
.30669 .55125 m .30683 .54997 L .30788 .54917 L F
.965 .913 .563 r
.30651 .55281 m .30639 .55384 L .30615 .55313 L F
.685 .378 0 r
.30689 .55527 m .30748 .55711 L .30615 .55313 L F
.063 0 0 r
.37253 .53734 m .37135 .53812 L .36878 .53859 L F
0 0 0 r
.37135 .53812 m .36799 .5399 L .36878 .53859 L F
.37135 .53812 m .36967 .53961 L .36799 .5399 L F
.864 .956 .612 r
.37172 .53591 m .37001 .53901 L .37135 .53812 L F
.37001 .53901 m .36967 .53961 L .37135 .53812 L F
.063 0 0 r
.37281 .53725 m .37135 .53812 L .37253 .53734 L F
.669 .45 .579 r
.34413 .62348 m .33987 .62315 L .34232 .62262 L F
.34413 .62348 m .33972 .62591 L .33987 .62315 L F
.469 .321 .597 r
.34179 .58618 m .34381 .58775 L .34477 .58639 L F
.794 .694 .755 r
.26846 .54856 m .26613 .5524 L .2647 .54825 L F
.438 .877 .85 r
.33605 .56646 m .33387 .56741 L .33816 .56599 L F
.784 .542 .57 r
.34016 .56435 m .34005 .56707 L .33605 .56646 L F
0 0 0 r
.30393 .59771 m .30335 .59881 L .30236 .60123 L F
.654 .785 .944 r
.33708 .56011 m .339 .56175 L .33463 .56025 L F
.454 .144 .35 r
.33708 .56011 m .34039 .55917 L .339 .56175 L F
.672 .69 .859 r
.51198 .56528 m .51427 .56411 L .51068 .56312 L F
.556 .269 .435 r
.30685 .5858 m .30569 .58872 L .30858 .58799 L F
.72 .198 0 r
.30685 .5858 m .30858 .58799 L .31002 .58881 L F
.39 .775 .99 r
.52442 .56477 m .52606 .56356 L .52298 .56382 L F
.52442 .56477 m .5275 .56457 L .52606 .56356 L F
0 0 0 r
.29516 .59862 m .29424 .60016 L .29276 .60106 L F
.29424 .60016 m .29188 .60343 L .29276 .60106 L F
.518 .063 .11 r
.26613 .5524 m .26834 .55366 L .26635 .55349 L F
.928 .597 .143 r
.27923 .62936 m .27993 .62972 L .27836 .62592 L F
.959 .937 .621 r
.27923 .62936 m .27817 .63148 L .27993 .62972 L F
0 .028 .587 r
.20261 .59656 m .20218 .59829 L .20108 .5941 L F
.282 .534 .914 r
.20261 .59656 m .20397 .59844 L .20218 .59829 L F
.414 .202 .48 r
.36231 .5613 m .36463 .56065 L .36479 .55817 L F
.649 .462 .618 r
.36172 .56303 m .36463 .56065 L .36231 .5613 L F
.125 0 .356 r
.31961 .60708 m .31927 .60944 L .31704 .61058 L F
.214 .06 .445 r
.31927 .60944 m .31676 .61345 L .31704 .61058 L F
.511 .716 .965 r
.30332 .66587 m .3011 .66637 L .2992 .66533 L F
.693 .53 .661 r
.31937 .6043 m .31662 .6048 L .31904 .60135 L F
.333 0 .07 r
.3184 .55421 m .32105 .55386 L .32177 .55274 L F
.247 0 .157 r
.27419 .69662 m .27504 .69505 L .27714 .69431 L F
.353 .57 .92 r
.21813 .6262 m .219 .62458 L .21565 .62274 L F
.21813 .6262 m .21969 .62587 L .219 .62458 L F
.518 .153 .286 r
.31309 .65356 m .31707 .65082 L .31373 .65156 L F
.31309 .65356 m .31559 .65337 L .31707 .65082 L F
.683 .336 .381 r
.31707 .65082 m .31938 .6534 L .31946 .65075 L F
.31707 .65082 m .31559 .65337 L .31938 .6534 L F
.205 .718 .886 r
.23902 .62294 m .24123 .62279 L .24317 .62312 L F
0 .41 .724 r
.24347 .62304 m .24317 .62312 L .24123 .62279 L F
.24347 .62304 m .24513 .62372 L .24317 .62312 L F
.146 .627 .921 r
.27422 .64209 m .27625 .64308 L .27868 .64324 L F
.376 .156 .448 r
.30732 .62023 m .30899 .62217 L .30929 .61943 L F
.30732 .62023 m .30686 .62307 L .30899 .62217 L F
.286 0 .252 r
.18447 .56131 m .18557 .56284 L .18642 .56064 L F
.18447 .56131 m .18354 .56355 L .18557 .56284 L F
.529 .38 .622 r
.37903 .58519 m .37652 .58265 L .37875 .58203 L F
.37903 .58519 m .37676 .58581 L .37652 .58265 L F
.324 .056 .343 r
.31218 .55511 m .31176 .55735 L .30957 .55806 L F
.684 .568 .719 r
.31465 .55175 m .31554 .55639 L .31218 .55511 L F
.748 .435 .455 r
.31632 .55753 m .31218 .55511 L .31554 .55639 L F
.31632 .55753 m .31176 .55735 L .31218 .55511 L F
.641 .808 .963 r
.30288 .56294 m .30456 .56433 L .30053 .56381 L F
.30288 .56294 m .30456 .56433 L .30053 .56381 L F
.476 .744 .987 r
.30544 .56271 m .30456 .56433 L .30288 .56294 L F
.30544 .56271 m .30456 .56433 L .30288 .56294 L F
.27 0 .101 r
.34457 .64196 m .34359 .64358 L .34147 .64374 L F
.34463 .64193 m .34359 .64358 L .34457 .64196 L F
.946 .679 .499 r
.34359 .64358 m .34367 .64656 L .34277 .64492 L F
.079 .631 .82 r
.34359 .64358 m .34005 .64333 L .34147 .64374 L F
.34217 .64348 m .34189 .64331 L .34005 .64333 L F
.34359 .64358 m .34189 .64331 L .34217 .64348 L F
.709 .966 .72 r
.34189 .64331 m .33998 .64449 L .34148 .64305 L F
.795 .759 .82 r
.33668 .63721 m .33838 .64012 L .34078 .63786 L F
.807 .999 .841 r
.34078 .63786 m .33838 .64012 L .33957 .63856 L F
.348 .428 .802 r
.34005 .64333 m .34189 .64331 L .33957 .63856 L F
.297 .398 .797 r
.33973 .6387 m .34189 .64331 L .34313 .64147 L F
.33957 .63856 m .33965 .63873 L .33973 .6387 L F
.33965 .63873 m .34189 .64331 L .33973 .6387 L F
.348 .428 .802 r
.34005 .64333 m .33957 .63856 L .33838 .64012 L F
.817 .794 .298 r
.33668 .63721 m .33621 .6404 L .33838 .64012 L F
.454 .073 .225 r
.34136 .63812 m .34043 .63845 L .34062 .63832 L F
.34064 .63831 m .34062 .63832 L .34063 .63832 L F
.34136 .63812 m .34062 .63832 L .34064 .63831 L F
.136 .359 .818 r
.33957 .63856 m .33973 .6387 L .34043 .63845 L F
.33973 .6387 m .34313 .64147 L .34136 .63812 L F
.638 .322 .42 r
.33364 .6383 m .33621 .6404 L .33482 .6398 L F
.373 .199 .511 r
.33571 .64246 m .33482 .6398 L .33621 .6404 L F
.817 .794 .298 r
.33668 .63721 m .33563 .64181 L .33621 .6404 L F
.986 .899 .63 r
.33536 .63982 m .33563 .64181 L .33668 .63721 L F
.273 .24 .639 r
.33745 .64048 m .33536 .63982 L .3403 .63841 L F
.34043 .63845 m .3403 .63841 L .34063 .63832 L F
.33745 .64048 m .3403 .63841 L .34043 .63845 L F
.136 .359 .818 r
.34025 .63839 m .34043 .63845 L .34136 .63812 L F
.694 .435 .527 r
.34001 .63814 m .33536 .63982 L .33668 .63721 L F
.689 .208 .101 r
.34162 .63724 m .34078 .63786 L .34247 .63763 L F
.33821 .63567 m .34078 .63786 L .34162 .63724 L F
0 0 0 r
.33957 .63856 m .34023 .63826 L .34078 .63786 L F
0 0 .544 r
.34263 .63718 m .34247 .63763 L .34078 .63786 L F
0 0 0 r
.34023 .63826 m .34263 .63718 L .34078 .63786 L F
.34233 .63732 m .34136 .63812 L .34263 .63718 L F
.33957 .63856 m .34021 .6384 L .34233 .63732 L F
0 .156 .675 r
.33921 .6358 m .34078 .63786 L .33821 .63567 L F
.795 .759 .82 r
.33668 .63721 m .34078 .63786 L .33921 .6358 L F
.694 .435 .527 r
.34058 .63824 m .33668 .63721 L .33921 .6358 L F
.34063 .63832 m .34049 .63828 L .34058 .63824 L F
.34049 .63828 m .33668 .63721 L .34058 .63824 L F
0 0 0 r
.34021 .6384 m .34028 .63839 L .34049 .63828 L F
.34021 .6384 m .34049 .63828 L .34233 .63732 L F
.694 .435 .527 r
.34063 .63832 m .34028 .63839 L .34049 .63828 L F
0 .185 .713 r
.34058 .63824 m .34136 .63812 L .34063 .63832 L F
0 0 0 r
.34056 .63824 m .34136 .63812 L .34233 .63732 L F
0 .185 .713 r
.33921 .6358 m .34136 .63812 L .34058 .63824 L F
0 0 0 r
.34028 .63839 m .34136 .63812 L .34056 .63824 L F
.694 .435 .527 r
.34063 .63832 m .3403 .63841 L .34028 .63839 L F
.34049 .63828 m .34028 .63839 L .34001 .63814 L F
.136 .359 .818 r
.33957 .63856 m .34036 .63846 L .34025 .63839 L F
.694 .435 .527 r
.3403 .63841 m .33536 .63982 L .34001 .63814 L F
.136 .359 .818 r
.34036 .63846 m .34043 .63845 L .3403 .63841 L F
.34036 .63846 m .3403 .63841 L .34025 .63839 L F
.454 .073 .225 r
.34136 .63812 m .33745 .64048 L .34043 .63845 L F
.709 .966 .72 r
.34189 .64331 m .34148 .64305 L .34313 .64147 L F
.946 .679 .499 r
.34359 .64358 m .34277 .64492 L .34189 .64331 L F
.978 .713 .459 r
.36989 .52911 m .36993 .53179 L .37149 .53029 L F
.36989 .52911 m .36993 .53179 L .37149 .53029 L F
.403 .679 .973 r
.3009 .52802 m .30029 .52977 L .29853 .52818 L F
.3009 .52802 m .30252 .52974 L .30029 .52977 L F
.615 .517 .72 r
.32412 .54869 m .32465 .55228 L .32715 .55155 L F
.55 .334 .539 r
.32715 .55155 m .32702 .55429 L .32465 .55228 L F
.696 .763 .27 r
.28128 .60466 m .28168 .60335 L .28275 .6005 L F
.957 .714 .529 r
.28128 .60466 m .27902 .60619 L .28168 .60335 L F
.28128 .60466 m .281 .60742 L .27902 .60619 L F
.45 .117 .309 r
.29384 .54493 m .29535 .54741 L .29636 .54425 L F
.29384 .54493 m .29265 .54811 L .29535 .54741 L F
.777 .937 .584 r
.52137 .53553 m .52334 .53203 L .52406 .53329 L F
.567 .285 .448 r
.52406 .53329 m .52653 .53525 L .52671 .53307 L F
.441 0 0 r
.52515 .53416 m .52406 .53329 L .52334 .53203 L F
.52515 .53416 m .52653 .53525 L .52406 .53329 L F
.282 0 .011 r
.2634 .71637 m .26149 .7182 L .26322 .71905 L F
.724 .481 .558 r
.53114 .5322 m .53267 .53021 L .52938 .53035 L F
.53114 .5322 m .53263 .5327 L .53267 .53021 L F
.493 .278 .515 r
.38213 .56436 m .3824 .56767 L .37945 .56806 L F
.519 .297 .517 r
.3842 .56627 m .3824 .56767 L .38213 .56436 L F
.495 .298 .543 r
.38459 .56365 m .3842 .56627 L .38213 .56436 L F
.976 .676 .37 r
.35892 .63568 m .35808 .63599 L .35718 .63232 L F
.962 .634 .333 r
.35892 .63568 m .35721 .6376 L .35808 .63599 L F
.369 .288 .633 r
.34536 .57362 m .34606 .57663 L .34759 .57564 L F
.34759 .57564 m .34606 .57663 L .34536 .57362 L F
.23 .406 .83 r
.35718 .63232 m .36035 .63479 L .35892 .63568 L F
.244 0 0 r
.35958 .63683 m .35892 .63568 L .36035 .63479 L F
.35958 .63683 m .35721 .6376 L .35892 .63568 L F
.152 0 .22 r
.29515 .57977 m .29691 .57899 L .29783 .57684 L F
0 0 .331 r
.29515 .57977 m .29598 .58125 L .29691 .57899 L F
.29515 .57977 m .29491 .5827 L .29598 .58125 L F
.127 0 0 r
.19123 .55679 m .19473 .55431 L .1926 .55505 L F
.646 .414 .553 r
.28361 .54331 m .28337 .54789 L .27997 .54801 L F
.484 .09 .217 r
.28638 .54273 m .28542 .54469 L .28361 .54331 L F
.523 .311 .534 r
.28581 .54734 m .28396 .54396 L .28542 .54469 L F
.28396 .54396 m .28361 .54331 L .28426 .54381 L F
.28396 .54396 m .28426 .54381 L .28542 .54469 L F
.28581 .54734 m .28337 .54789 L .28361 .54331 L F
.646 .414 .553 r
.28361 .54331 m .28266 .54454 L .28093 .5451 L F
.178 0 0 r
.28056 .54413 m .2825 .54439 L .28605 .54302 L F
.332 .798 .693 r
.28568 .54311 m .2825 .54439 L .28482 .54332 L F
.28602 .54302 m .28524 .54333 L .28568 .54311 L F
.28524 .54333 m .2825 .54439 L .28568 .54311 L F
.28605 .54302 m .28598 .54305 L .28602 .54302 L F
.28598 .54305 m .2825 .54439 L .28602 .54302 L F
.646 .414 .553 r
.28266 .54454 m .27997 .54801 L .28085 .54535 L F
.28266 .54454 m .28085 .54535 L .28093 .5451 L F
.779 .695 .771 r
.34798 .58322 m .35043 .58277 L .34964 .57952 L F
.965 .783 .609 r
.34873 .58223 m .35043 .58277 L .34964 .57952 L F
.34873 .58223 m .35043 .58277 L .34964 .57952 L F
.742 .673 .783 r
.34964 .57952 m .35043 .58277 L .3529 .57983 L F
.695 .6 .745 r
.35043 .58277 m .35449 .58335 L .3529 .57983 L F
.68 .577 .732 r
.35043 .58277 m .35451 .58598 L .35449 .58335 L F
.545 .15 .244 r
.34006 .65454 m .34484 .65599 L .34368 .65405 L F
.64 .964 .828 r
.33976 .6594 m .34035 .65813 L .34053 .65804 L F
.79 .495 0 r
.34122 .65893 m .34067 .65817 L .34059 .65772 L F
.34072 .65704 m .34059 .65772 L .34006 .65454 L F
.34122 .65893 m .34059 .65772 L .34072 .65704 L F
.34096 .6586 m .34067 .65817 L .34122 .65893 L F
.64 .964 .828 r
.34096 .6586 m .34484 .65599 L .34067 .65817 L F
.545 .15 .244 r
.34006 .65454 m .34067 .65817 L .34484 .65599 L F
.64 .964 .828 r
.34096 .6586 m .34053 .65804 L .34484 .65599 L F
0 0 0 r
.34484 .65599 m .34053 .65804 L .34268 .65739 L F
.34053 .65804 m .34035 .65813 L .34053 .65807 L F
.34053 .65804 m .34053 .65807 L .34268 .65739 L F
.64 .964 .828 r
.33976 .6594 m .34096 .6586 L .34067 .65817 L F
.953 .812 .667 r
.34072 .65829 m .33976 .6594 L .34067 .65817 L F
.64 .964 .828 r
.33976 .6594 m .34072 .65829 L .34096 .6586 L F
.953 .812 .667 r
.34141 .65963 m .33976 .6594 L .34072 .65829 L F
.64 .964 .828 r
.33976 .6594 m .34053 .65804 L .34072 .65829 L F
.79 .495 0 r
.34124 .65899 m .34096 .6586 L .34122 .65893 L F
.34141 .65963 m .34067 .65817 L .34124 .65899 L F
0 0 .256 r
.31911 .58589 m .31906 .5888 L .32005 .58752 L F
.31911 .58589 m .32005 .58752 L .31902 .58585 L F
0 0 .369 r
.32031 .58197 m .31902 .58585 L .32053 .58454 L F
0 0 .245 r
.31902 .58585 m .32005 .58752 L .32053 .58454 L F
.106 0 0 r
.23294 .55135 m .22934 .55398 L .23071 .55198 L F
.443 .465 .787 r
.3842 .56627 m .38365 .57003 L .38257 .56856 L F
.488 .301 .552 r
.3861 .5704 m .38573 .57252 L .38365 .57003 L F
.233 .242 .664 r
.38365 .57003 m .38573 .57252 L .38443 .57319 L F
.844 .915 .882 r
.30515 .65272 m .30487 .65006 L .30527 .65238 L F
.30515 .65272 m .30527 .65238 L .30278 .65357 L F
.168 0 0 r
.36371 .52427 m .36376 .5255 L .36601 .52357 L F
.465 .269 .529 r
.28516 .59539 m .2871 .59722 L .28737 .59466 L F
.28516 .59539 m .28525 .59795 L .2871 .59722 L F
.587 .626 .857 r
.29918 .54038 m .30296 .5425 L .30111 .53972 L F
.062 0 0 r
.29877 .54452 m .30106 .54391 L .30296 .5425 L F
.196 .431 .86 r
.30296 .5425 m .30431 .54152 L .30111 .53972 L F
0 0 0 r
.30296 .5425 m .30106 .54391 L .30431 .54152 L F
.685 .895 .973 r
.27186 .61568 m .27063 .61667 L .27115 .61505 L F
.812 .946 .594 r
.27115 .61505 m .27063 .61667 L .26889 .61853 L F
.615 .517 .72 r
.32412 .54869 m .32715 .55155 L .32559 .54784 L F
.805 .716 .767 r
.52137 .53553 m .5192 .53983 L .51794 .53788 L F
.84 .838 .844 r
.34381 .58775 m .3481 .58607 L .3464 .58492 L F
.533 .292 .496 r
.38105 .5816 m .37903 .57995 L .38131 .57929 L F
.38105 .5816 m .37875 .58203 L .37903 .57995 L F
.364 .157 .46 r
.32241 .6324 m .32018 .63551 L .32204 .63487 L F
.365 .237 .571 r
.32018 .63551 m .32217 .63742 L .32204 .63487 L F
.32018 .63551 m .31993 .63937 L .32217 .63742 L F
.329 .276 .646 r
.16891 .58388 m .17142 .58456 L .17135 .58192 L F
.16891 .58388 m .16954 .58597 L .17142 .58456 L F
.65 .574 .757 r
.32792 .61111 m .33051 .61062 L .33001 .60651 L F
.634 .491 .671 r
.32792 .61111 m .32804 .6138 L .33051 .61062 L F
.409 .775 .994 r
.1448 .67473 m .14469 .67607 L .14272 .67509 L F
.1448 .67473 m .14469 .67607 L .14272 .67509 L F
.444 .667 .957 r
.21244 .79374 m .20817 .79188 L .21067 .79269 L F
0 0 0 r
.20738 .79496 m .21244 .79374 L .21067 .79269 L F
.276 .692 .97 r
.21067 .79269 m .21244 .79374 L .21275 .79272 L F
.21067 .79269 m .21244 .79374 L .21275 .79272 L F
.707 .666 .807 r
.35449 .58335 m .35536 .57917 L .3529 .57983 L F
.35449 .58335 m .35719 .58301 L .35536 .57917 L F
.702 .573 .707 r
.35449 .58335 m .35451 .58598 L .35719 .58301 L F
.438 .666 .958 r
.22947 .61608 m .22891 .61795 L .22727 .61643 L F
.22947 .61608 m .23193 .6185 L .22891 .61795 L F
.191 0 .229 r
.35451 .58598 m .35628 .58539 L .35719 .58301 L F
.354 .288 .644 r
.35451 .58598 m .35674 .58799 L .35628 .58539 L F
.47 .29 .554 r
.35445 .58855 m .35674 .58799 L .35451 .58598 L F
.26 .753 .674 r
.53333 .56117 m .53177 .56173 L .52929 .56267 L F
.562 .52 .766 r
.53592 .56045 m .53333 .56117 L .53237 .55769 L F
.538 .915 .763 r
.53497 .55967 m .53333 .56117 L .53592 .56045 L F
.562 .52 .766 r
.53577 .55947 m .53237 .55769 L .53548 .55754 L F
.53592 .56045 m .53519 .55988 L .53577 .55947 L F
.53519 .55988 m .53237 .55769 L .53577 .55947 L F
.538 .915 .763 r
.53497 .55967 m .53177 .56173 L .5333 .56118 L F
.53338 .56112 m .5333 .56118 L .53333 .56117 L F
.53497 .55967 m .5333 .56118 L .53338 .56112 L F
.6 .798 .379 r
.34551 .64052 m .34359 .64358 L .34463 .64193 L F
.771 .702 .787 r
.35031 .56772 m .34826 .56523 L .35037 .56557 L F
.35031 .56772 m .34635 .56725 L .34826 .56523 L F
.447 .805 .996 r
.35031 .56772 m .34866 .56662 L .34635 .56725 L F
.463 .269 .53 r
.35269 .56688 m .35031 .56772 L .35287 .5642 L F
.575 .583 .823 r
.35269 .56688 m .35031 .56772 L .35037 .56557 L F
.053 .616 .785 r
.35269 .56688 m .34866 .56662 L .35031 .56772 L F
.718 .591 .712 r
.3184 .55421 m .31554 .55639 L .31504 .5538 L F
.31543 .55226 m .31504 .5538 L .31465 .55175 L F
.3184 .55421 m .31504 .5538 L .31543 .55226 L F
.3184 .55421 m .31543 .55226 L .3158 .55263 L F
.57 .418 .636 r
.31666 .54743 m .31567 .55254 L .31465 .55175 L F
.31567 .55254 m .31549 .55347 L .31465 .55175 L F
.718 .591 .712 r
.3173 .55379 m .3158 .55263 L .31671 .55357 L F
.3184 .55421 m .3158 .55263 L .3173 .55379 L F
.517 .483 .758 r
.31595 .55285 m .31671 .55357 L .31549 .55347 L F
.718 .591 .712 r
.31543 .55226 m .3161 .55303 L .31671 .55357 L F
.517 .483 .758 r
.31806 .54996 m .31671 .55357 L .31595 .55285 L F
.718 .591 .712 r
.31595 .55285 m .31465 .55175 L .3161 .55303 L F
.31543 .55226 m .31504 .55201 L .31595 .55285 L F
.31504 .55201 m .31465 .55175 L .31595 .55285 L F
.07 0 .413 r
.31806 .54996 m .31595 .55285 L .31665 .54749 L F
.31595 .55285 m .31549 .55347 L .31567 .55254 L F
.31595 .55285 m .31567 .55254 L .31665 .54749 L F
.31666 .54743 m .31665 .54749 L .31666 .54743 L F
.31806 .54996 m .31665 .54749 L .31666 .54743 L F
.352 .787 .966 r
.3184 .55421 m .31671 .55357 L .32105 .55386 L F
.386 .198 .499 r
.3142 .63138 m .31249 .62927 L .31416 .62866 L F
.3142 .63138 m .31223 .63196 L .31249 .62927 L F
.501 .106 .224 r
.32766 .61891 m .32588 .61754 L .32512 .61913 L F
.402 .145 .406 r
.32812 .61663 m .32588 .61754 L .32766 .61891 L F
.01 .03 .531 r
.31748 .61865 m .31613 .62058 L .31617 .61654 L F
.649 .698 .882 r
.31748 .61865 m .31789 .62252 L .31613 .62058 L F
.596 .92 .971 r
.24421 .63572 m .24591 .63602 L .24812 .63499 L F
.784 .866 .427 r
.29063 .64772 m .29078 .64793 L .29094 .64673 L F
.082 .458 .885 r
.29094 .64673 m .29078 .64793 L .29238 .64832 L F
.44 .325 .625 r
.31176 .55735 m .3118 .56008 L .30957 .55806 L F
.995 .76 .451 r
.30957 .55806 m .30811 .55938 L .30748 .55711 L F
.30957 .55806 m .30937 .56061 L .30811 .55938 L F
.539 .322 .533 r
.3118 .56008 m .30937 .56061 L .30957 .55806 L F
.432 .519 .847 r
.35536 .57917 m .35719 .58301 L .35864 .5816 L F
.324 .026 .294 r
.35719 .58301 m .35851 .58473 L .35864 .5816 L F
.35719 .58301 m .35628 .58539 L .35851 .58473 L F
0 0 .188 r
.36479 .55817 m .36525 .5589 L .36674 .55744 L F
.36479 .55817 m .36463 .56065 L .36525 .5589 L F
.708 .386 .43 r
.31068 .65105 m .31309 .65356 L .31373 .65156 L F
.496 0 0 r
.35164 .54331 m .35476 .5451 L .35385 .5433 L F
.466 .208 .438 r
.34911 .54542 m .35211 .546 L .35164 .54331 L F
.898 .784 .727 r
.35239 .54572 m .35476 .5451 L .35335 .54452 L F
.35096 .5475 m .35157 .54712 L .35239 .54572 L F
.35157 .54712 m .35476 .5451 L .35239 .54572 L F
.317 .135 .469 r
.35164 .54331 m .35251 .54552 L .35315 .54444 L F
.35251 .54552 m .35274 .54612 L .35315 .54444 L F
.466 .208 .438 r
.35211 .546 m .35274 .54612 L .35251 .54552 L F
.35211 .546 m .35251 .54552 L .35164 .54331 L F
.898 .784 .727 r
.35096 .5475 m .35335 .54452 L .35164 .54656 L F
.464 .235 .481 r
.35211 .546 m .35096 .5475 L .35274 .54612 L F
.34911 .54542 m .35096 .5475 L .35211 .546 L F
.898 .784 .727 r
.35164 .54656 m .35211 .546 L .35315 .54444 L F
.35211 .546 m .35335 .54452 L .35326 .54448 L F
.35211 .546 m .35326 .54448 L .35315 .54444 L F
.35096 .5475 m .35293 .54879 L .35476 .5451 L F
.541 .513 .775 r
.36274 .56658 m .36025 .56795 L .35911 .56422 L F
.576 .602 .841 r
.36274 .56658 m .36313 .56745 L .36025 .56795 L F
.692 .291 .282 r
.52927 .55021 m .52675 .55084 L .52676 .54919 L F
.331 .157 .488 r
.38672 .56003 m .38459 .56365 L .38457 .56021 L F
.448 .799 .998 r
.25597 .63811 m .25658 .63678 L .25516 .63689 L F
.25597 .63811 m .2585 .63776 L .25658 .63678 L F
.689 .432 .528 r
.30962 .65373 m .31068 .65105 L .30683 .65111 L F
.655 .395 .514 r
.30962 .65373 m .31309 .65356 L .31068 .65105 L F
.971 .754 .553 r
.3248 .62628 m .3245 .62893 L .32283 .62843 L F
0 0 .325 r
.30022 .54129 m .29918 .54038 L .30111 .53972 L F
.30022 .54129 m .29898 .54363 L .29918 .54038 L F
.775 .852 .908 r
.22151 .55982 m .22638 .55906 L .22368 .55874 L F
.833 .927 .894 r
.22617 .55652 m .22368 .55874 L .22638 .55906 L F
.78 .697 .773 r
.35518 .5636 m .3561 .56805 L .35269 .56688 L F
0 .53 .844 r
.35269 .56688 m .3561 .56805 L .35461 .56728 L F
.75 .679 .782 r
.35911 .56422 m .3561 .56805 L .35518 .5636 L F
.155 .38 .83 r
.3561 .56805 m .35758 .56658 L .35461 .56728 L F
.3561 .56805 m .35883 .56934 L .35758 .56658 L F
.407 .289 .606 r
.35682 .5696 m .35883 .56934 L .3561 .56805 L F
.422 .456 .79 r
.31563 .56304 m .31509 .56694 L .31414 .56584 L F
.31563 .56304 m .31752 .56752 L .31509 .56694 L F
.475 0 0 r
.31752 .56752 m .31414 .56584 L .31509 .56694 L F
.583 .86 .995 r
.31509 .56694 m .31072 .56687 L .31414 .56584 L F
.179 0 .078 r
.32498 .58658 m .32442 .58787 L .3223 .58872 L F
.152 0 .144 r
.32342 .59026 m .3223 .58872 L .32442 .58787 L F
.926 .848 .404 r
.32344 .59012 m .32442 .58787 L .32386 .58654 L F
.32342 .59026 m .32442 .58787 L .32344 .59012 L F
.179 0 .078 r
.32542 .58623 m .32442 .58787 L .32498 .58658 L F
.382 0 .049 r
.32922 .58387 m .32794 .58451 L .32708 .58485 L F
0 0 0 r
.32708 .58485 m .32542 .58623 L .32634 .58515 L F
.928 .921 .543 r
.32386 .58654 m .32542 .58623 L .32708 .58485 L F
.382 0 .049 r
.32794 .58451 m .32386 .58654 L .32708 .58485 L F
0 0 0 r
.32708 .58485 m .32634 .58515 L .32806 .58315 L F
.928 .921 .543 r
.32386 .58654 m .32442 .58787 L .32542 .58623 L F
0 .55 .751 r
.22849 .53608 m .22891 .53609 L .23041 .53631 L F
0 0 0 r
.22898 .53655 m .23005 .53612 L .22891 .53609 L F
.279 .775 .886 r
.22891 .53609 m .2311 .53569 L .23277 .53584 L F
0 0 0 r
.23005 .53612 m .2311 .53569 L .22891 .53609 L F
0 .55 .751 r
.22641 .53582 m .22891 .53609 L .22849 .53608 L F
.307 .212 .581 r
.34911 .54542 m .34928 .54839 L .35096 .5475 L F
.478 .177 .377 r
.32457 .54217 m .32172 .54465 L .32243 .54283 L F
.006 0 0 r
.2783 .5444 m .28056 .54413 L .28352 .54333 L F
.2783 .5444 m .28056 .54413 L .28361 .54331 L F
.506 .737 .978 r
.2783 .5444 m .27854 .54211 L .27634 .54291 L F
.2783 .5444 m .28056 .54413 L .27854 .54211 L F
.7 .194 .03 r
.27634 .54291 m .28056 .54413 L .2783 .5444 L F
.27634 .54291 m .27844 .5447 L .28056 .54413 L F
.27844 .5447 m .27859 .54483 L .28056 .54413 L F
.006 0 0 r
.28352 .54333 m .28056 .54413 L .28361 .54331 L F
.892 .985 .801 r
.28299 .54026 m .28361 .54331 L .28605 .54302 L F
.28299 .54026 m .28056 .54413 L .28361 .54331 L F
.178 0 0 r
.28056 .54413 m .28605 .54302 L .28361 .54331 L F
.743 .306 .213 r
.35982 .61086 m .3581 .6124 L .35616 .61005 L F
0 0 0 r
.36126 .60952 m .36066 .61024 L .35982 .61086 L F
.163 0 0 r
.36088 .61165 m .35982 .61086 L .36066 .61024 L F
.36088 .61165 m .3581 .6124 L .35982 .61086 L F
.419 .217 .497 r
.29724 .59762 m .29571 .59536 L .2973 .59457 L F
.29724 .59762 m .29516 .59862 L .29571 .59536 L F
.607 .406 .584 r
.33972 .62591 m .33708 .62873 L .33727 .62631 L F
0 0 0 r
.25185 .53306 m .25416 .5326 L .25547 .53226 L F
.187 .719 .75 r
.25416 .5326 m .25791 .53192 L .25547 .53226 L F
.792 .295 0 r
.36956 .63901 m .36763 .63821 L .3676 .63728 L F
.157 0 0 r
.3676 .63728 m .36988 .63719 L .36956 .63901 L F
.648 .907 .982 r
.36956 .63901 m .36763 .63821 L .36988 .63719 L F
.661 .457 .598 r
.39522 .55181 m .39544 .55428 L .39128 .55449 L F
.18 .377 .822 r
.39482 .55114 m .39648 .55114 L .39522 .55181 L F
.541 .549 .812 r
.39648 .55114 m .39544 .55428 L .39522 .55181 L F
0 .027 .587 r
.19575 .58146 m .19526 .58313 L .19413 .57928 L F
.163 .423 .861 r
.19575 .58146 m .19798 .58495 L .19526 .58313 L F
.991 .733 .399 r
.30683 .65111 m .30549 .64741 L .30487 .65006 L F
.689 .432 .528 r
.30962 .65373 m .30683 .65111 L .30527 .65238 L F
.941 .871 .741 r
.30527 .65238 m .30683 .65111 L .30487 .65006 L F
.705 .581 .714 r
.16938 .59796 m .17026 .60146 L .17273 .59831 L F
.767 .483 .504 r
.24708 .55712 m .25082 .55826 L .25037 .55502 L F
.448 .26 .532 r
.25037 .55502 m .2524 .5574 L .2531 .5544 L F
.25037 .55502 m .25082 .55826 L .2524 .5574 L F
.429 .505 .835 r
.29797 .62616 m .29923 .62907 L .30125 .62891 L F
.623 .149 .107 r
.29541 .55255 m .29388 .5538 L .29151 .55205 L F
.513 .85 .573 r
.29553 .55228 m .29541 .55255 L .29774 .55192 L F
.29553 .55228 m .29388 .5538 L .29541 .55255 L F
.553 .515 .767 r
.36468 .60709 m .36679 .60996 L .36885 .60778 L F
.36468 .60709 m .36885 .60778 L .36681 .60818 L F
.151 0 0 r
.3712 .60899 m .36681 .60818 L .36885 .60778 L F
.509 .337 .582 r
.37127 .60441 m .37132 .60725 L .36885 .60778 L F
.355 0 .182 r
.37132 .60725 m .3712 .60899 L .36885 .60778 L F
.632 .912 .981 r
.25865 .54566 m .25884 .54732 L .26097 .54614 L F
.25865 .54566 m .25649 .54674 L .25884 .54732 L F
.613 .647 .86 r
.25953 .54712 m .26097 .54614 L .25884 .54732 L F
.62 .41 .576 r
.3003 .63536 m .30311 .63539 L .30308 .63245 L F
.564 .613 .86 r
.30308 .63245 m .30361 .62837 L .30125 .62891 L F
.30308 .63245 m .30549 .6321 L .30361 .62837 L F
.41 .246 .545 r
.30308 .63245 m .30514 .63451 L .30549 .6321 L F
.30308 .63245 m .30311 .63539 L .30514 .63451 L F
0 .468 .781 r
.31079 .58879 m .31002 .58881 L .30858 .58799 L F
.31079 .58879 m .31202 .58936 L .31002 .58881 L F
0 .403 .738 r
.34826 .56523 m .35287 .5642 L .35037 .56557 L F
.575 .583 .823 r
.35269 .56688 m .35037 .56557 L .35287 .5642 L F
0 .403 .738 r
.34826 .56523 m .35269 .56688 L .35287 .5642 L F
.491 .298 .547 r
.35269 .56688 m .35518 .5636 L .35287 .5642 L F
.78 .697 .773 r
.35518 .5636 m .35269 .56688 L .35287 .5642 L F
.699 .647 .794 r
.28647 .6296 m .28987 .62985 L .28899 .62745 L F
.794 .486 .468 r
.28448 .63109 m .28987 .62985 L .28647 .6296 L F
.28448 .63109 m .28899 .63177 L .28987 .62985 L F
.513 .331 .571 r
.37667 .58852 m .37427 .59169 L .37434 .58908 L F
.243 0 0 r
.30776 .55172 m .30615 .55313 L .30868 .55275 L F
.234 0 .175 r
.1791 .5676 m .18013 .5687 L .18113 .56677 L F
.1791 .5676 m .17814 .56952 L .18013 .5687 L F
.613 .215 .266 r
.27265 .55188 m .27087 .55413 L .26834 .55366 L F
.621 .225 .271 r
.27577 .55329 m .27087 .55413 L .27265 .55188 L F
.08 .44 .877 r
.2893 .6408 m .28687 .63833 L .28775 .64064 L F
.467 0 0 r
.28775 .64064 m .2915 .64168 L .2893 .6408 L F
.828 .992 .863 r
.33724 .60597 m .33968 .60558 L .33703 .60795 L F
.605 .953 .883 r
.34202 .60427 m .33968 .60558 L .33724 .60597 L F
.204 .042 .427 r
.17131 .57658 m .17281 .57583 L .17321 .57295 L F
.235 .104 .49 r
.17131 .57658 m .17271 .5785 L .17281 .57583 L F
.218 .1 .496 r
.17128 .5792 m .17271 .5785 L .17131 .57658 L F
.468 .281 .544 r
.2794 .69342 m .27714 .69431 L .27714 .69181 L F
.63 .123 .026 r
.2794 .69342 m .27714 .69181 L .27507 .69298 L F
.637 .208 .213 r
.34554 .62335 m .3443 .62354 L .34232 .62262 L F
0 0 0 r
.3443 .62354 m .34413 .62348 L .34232 .62262 L F
.285 .066 .396 r
.18161 .56425 m .18296 .56589 L .18354 .56355 L F
.18161 .56425 m .18113 .56677 L .18296 .56589 L F
.177 .71 .828 r
.26262 .53053 m .26702 .53044 L .26466 .5308 L F
.498 .413 .69 r
.19798 .58495 m .20047 .58919 L .19618 .58916 L F
0 0 .324 r
.19713 .59031 m .19618 .58916 L .20047 .58919 L F
.19713 .59031 m .19637 .59181 L .19618 .58916 L F
.603 .469 .672 r
.32144 .54494 m .3196 .5472 L .31666 .54743 L F
.07 0 .413 r
.31806 .54996 m .31666 .54743 L .3196 .5472 L F
.545 .385 .615 r
.30031 .56116 m .30288 .56294 L .30309 .55981 L F
.30031 .56116 m .30053 .56381 L .30288 .56294 L F
.783 .918 .536 r
.5343 .54401 m .5337 .54585 L .53566 .54249 L F
.838 .93 .548 r
.53823 .53962 m .53731 .54135 L .53753 .5414 L F
.414 .86 .79 r
.5378 .54145 m .53753 .5414 L .53566 .54249 L F
0 0 0 r
.53642 .54305 m .53566 .54249 L .53753 .5414 L F
.838 .93 .548 r
.53731 .54135 m .53642 .54305 L .53753 .5414 L F
.414 .86 .79 r
.53999 .54039 m .53753 .5414 L .5378 .54145 L F
0 0 0 r
.53642 .54305 m .5343 .54401 L .53566 .54249 L F
.232 .252 .676 r
.31549 .55347 m .31671 .55357 L .31465 .55175 L F
.805 .716 .767 r
.52137 .53553 m .51794 .53788 L .52104 .53556 L F
.777 .937 .584 r
.52137 .53553 m .52104 .53556 L .52334 .53203 L F
.487 .51 .807 r
.36958 .52644 m .3674 .52727 L .36601 .52357 L F
.439 .368 .68 r
.36958 .52644 m .36989 .52911 L .3674 .52727 L F
.596 .438 .638 r
.35257 .57716 m .35531 .57645 L .35456 .57336 L F
.668 .582 .749 r
.35456 .57336 m .35783 .57337 L .35682 .5696 L F
.678 .499 .636 r
.35531 .57645 m .35783 .57337 L .35456 .57336 L F
.463 .727 .983 r
.30707 .529 m .30654 .53102 L .30482 .52963 L F
.30707 .529 m .30901 .5307 L .30654 .53102 L F
.471 .665 .947 r
.20867 .6188 m .20982 .62016 L .21179 .6198 L F
.678 .664 .83 r
.16938 .59796 m .1708 .59488 L .16873 .59527 L F
.16938 .59796 m .17273 .59831 L .1708 .59488 L F
.802 .621 .656 r
.30393 .59771 m .30656 .5997 L .30772 .59438 L F
.525 .629 .896 r
.30772 .59438 m .30762 .59054 L .30633 .59109 L F
.30772 .59438 m .31002 .59406 L .30762 .59054 L F
.699 .574 .711 r
.30656 .5997 m .31002 .59406 L .30772 .59438 L F
.518 .394 .651 r
.32241 .6324 m .32496 .63167 L .3245 .62893 L F
.581 .393 .592 r
.32204 .63487 m .32496 .63167 L .32241 .6324 L F
.344 0 0 r
.28219 .63104 m .28448 .63109 L .28647 .6296 L F
.636 .783 .952 r
.26219 .71125 m .26469 .71059 L .26281 .70878 L F
.594 .626 .853 r
.1708 .59488 m .17273 .59831 L .17511 .59762 L F
.29 .172 .541 r
.28878 .63426 m .28687 .63833 L .28732 .63547 L F
.311 .799 .874 r
.26702 .53044 m .26944 .52992 L .27097 .52999 L F
.225 .746 .82 r
.26944 .52992 m .27328 .52948 L .27097 .52999 L F
.729 .69 .148 r
.53351 .54641 m .5337 .54585 L .5343 .54401 L F
.53351 .54641 m .53314 .54913 L .5337 .54585 L F
.734 .229 .027 r
.33185 .53059 m .33408 .53167 L .336 .53102 L F
.679 .262 .246 r
.33408 .53167 m .33871 .53082 L .336 .53102 L F
.373 .37 .727 r
.34689 .62713 m .34845 .62577 L .34606 .62565 L F
.34689 .62713 m .34962 .62867 L .34845 .62577 L F
.422 .788 .995 r
.31961 .62257 m .32077 .62282 L .31789 .62252 L F
.683 .277 .27 r
.31789 .62252 m .32077 .62282 L .31986 .62469 L F
.537 .612 .875 r
.3824 .56767 m .38257 .56856 L .37945 .56806 L F
.263 .028 .357 r
.30963 .64272 m .31188 .63848 L .31197 .64091 L F
.033 0 .399 r
.31197 .64091 m .31188 .63848 L .31279 .63793 L F
.786 .888 .918 r
.31662 .6048 m .31159 .60549 L .31448 .60302 L F
.464 .455 .763 r
.31961 .60708 m .31662 .6048 L .31937 .6043 L F
.715 .738 .869 r
.33415 .60679 m .33232 .60876 L .33147 .60684 L F
.308 .477 .864 r
.33212 .60734 m .33414 .60679 L .33402 .60601 L F
.774 .855 .911 r
.33415 .60679 m .33703 .60795 L .33232 .60876 L F
.33507 .60654 m .33703 .60795 L .33415 .60679 L F
.828 .992 .863 r
.33724 .60597 m .33703 .60795 L .33484 .60637 L F
.715 .738 .869 r
.33415 .60679 m .33415 .60679 L .33414 .60679 L F
.545 .329 .538 r
.3345 .60918 m .33591 .60599 L .33414 .60679 L F
.828 .992 .863 r
.33724 .60597 m .33484 .60637 L .33466 .60624 L F
.545 .329 .538 r
.33581 .60621 m .33724 .60597 L .33591 .60599 L F
.3345 .60918 m .33724 .60597 L .33581 .60621 L F
.774 .855 .911 r
.33415 .60679 m .33507 .60654 L .33415 .60679 L F
.545 .329 .538 r
.33415 .60679 m .33545 .60599 L .33402 .60601 L F
.774 .855 .911 r
.33466 .60624 m .33484 .60637 L .33415 .60679 L F
.33484 .60637 m .33507 .60654 L .33415 .60679 L F
.545 .329 .538 r
.33414 .60679 m .33415 .60679 L .33402 .60601 L F
.33415 .60679 m .33591 .60599 L .33545 .60599 L F
.715 .738 .869 r
.33466 .60624 m .33415 .60679 L .33147 .60684 L F
.33415 .60679 m .33414 .60679 L .33147 .60684 L F
.308 .477 .864 r
.33147 .60684 m .33212 .60734 L .33288 .60682 L F
.33147 .60684 m .33288 .60682 L .33402 .60601 L F
.33212 .60734 m .3345 .60918 L .33414 .60679 L F
.488 .761 .991 r
.21939 .61468 m .21867 .6163 L .21669 .61384 L F
.21939 .61468 m .22103 .61601 L .21867 .6163 L F
.266 .077 .428 r
.30605 .54776 m .30376 .55131 L .304 .54865 L F
.004 0 0 r
.20276 .54777 m .20474 .54727 L .20657 .54598 L F
.008 0 0 r
.20474 .54727 m .20873 .54524 L .20657 .54598 L F
.648 .767 .935 r
.29237 .628 m .28899 .62745 L .29145 .62671 L F
0 .466 .702 r
.29529 .62853 m .29237 .628 L .29145 .62671 L F
.29529 .62853 m .29489 .62847 L .29237 .628 L F
.756 .601 .685 r
.34964 .57952 m .3529 .57983 L .35257 .57716 L F
.564 .463 .698 r
.35257 .57716 m .35536 .57917 L .35531 .57645 L F
.35257 .57716 m .3529 .57983 L .35536 .57917 L F
.692 .499 .621 r
.38719 .57614 m .38443 .57319 L .38573 .57252 L F
.38719 .57614 m .38461 .5762 L .38443 .57319 L F
.557 .18 .283 r
.31937 .6043 m .32129 .60634 L .31961 .60708 L F
.255 0 .261 r
.32982 .58197 m .32708 .58485 L .32806 .58315 L F
0 0 .41 r
.53965 .54607 m .54082 .54722 L .54199 .54511 L F
.521 .667 .928 r
.21367 .62318 m .21559 .62143 L .21179 .6198 L F
.21367 .62318 m .21565 .62274 L .21559 .62143 L F
.558 .389 .608 r
.32804 .6138 m .33053 .61334 L .33051 .61062 L F
.505 .319 .562 r
.32812 .61663 m .33053 .61334 L .32804 .6138 L F
.443 0 0 r
.35716 .54348 m .35505 .54136 L .35385 .5433 L F
.097 0 0 r
.2079 .57021 m .20347 .57201 L .20538 .5703 L F
.781 .524 .548 r
.33688 .64185 m .33571 .64246 L .33621 .6404 L F
.33688 .64185 m .3333 .64382 L .33571 .64246 L F
.33688 .64185 m .33703 .64449 L .3333 .64382 L F
.55 .196 .321 r
.35535 .63069 m .35329 .63421 L .35097 .63232 L F
.834 .612 .602 r
.35718 .63232 m .35329 .63421 L .35535 .63069 L F
.14 .522 .916 r
.39517 .54961 m .39482 .55114 L .3933 .54721 L F
.39517 .54961 m .39648 .55114 L .39482 .55114 L F
.276 0 .159 r
.17321 .57295 m .17528 .57231 L .17637 .57046 L F
.132 0 .075 r
.17637 .57046 m .17707 .57142 L .17814 .56952 L F
.17637 .57046 m .17528 .57231 L .17707 .57142 L F
.222 .119 .519 r
.32927 .65362 m .32778 .65689 L .32695 .65431 L F
.423 .139 .374 r
.34413 .62348 m .3399 .62859 L .33972 .62591 L F
.34413 .62348 m .34233 .62808 L .3399 .62859 L F
0 0 0 r
.3443 .62354 m .34429 .6245 L .34413 .62348 L F
.423 .138 .374 r
.34514 .62727 m .34233 .62808 L .34413 .62348 L F
.34514 .62727 m .34413 .62348 L .34429 .6245 L F
.021 .295 .789 r
.38885 .5422 m .39129 .54407 L .39076 .54545 L F
.05 .333 .813 r
.39129 .54407 m .3933 .54721 L .39076 .54545 L F
.534 .507 .772 r
.38341 .53356 m .38189 .5355 L .38127 .53345 L F
.38341 .53356 m .38461 .53494 L .38189 .5355 L F
.594 .596 .823 r
.36058 .52874 m .36124 .5326 L .3637 .53023 L F
.64 .56 .749 r
.36124 .5326 m .36486 .53258 L .3637 .53023 L F
.36124 .5326 m .36227 .53303 L .36486 .53258 L F
.466 .308 .583 r
.16873 .59527 m .1708 .59488 L .17083 .59234 L F
.476 .324 .594 r
.49863 .55191 m .50102 .55135 L .50038 .54689 L F
.473 .28 .538 r
.50102 .55135 m .50325 .54759 L .50038 .54689 L F
.027 0 .386 r
.299 .58845 m .29883 .59108 L .29765 .59192 L F
.177 .199 .646 r
.29883 .59108 m .29954 .59394 L .29765 .59192 L F
.447 .241 .505 r
.29954 .59394 m .2973 .59457 L .29765 .59192 L F
.563 .462 .698 r
.37427 .59169 m .37229 .59486 L .3718 .59235 L F
.904 .959 .626 r
.34368 .65405 m .34321 .65201 L .34517 .65056 L F
.994 .788 .519 r
.34484 .65599 m .34321 .65201 L .34368 .65405 L F
.585 .613 .846 r
.21969 .62587 m .22144 .62929 L .22379 .6287 L F
.846 .543 .475 r
.31449 .60161 m .31089 .60292 L .31101 .60053 L F
.31449 .60161 m .31448 .60302 L .31089 .60292 L F
.614 .583 .795 r
.32106 .59082 m .31906 .5888 L .3223 .58872 L F
.152 0 .144 r
.32342 .59026 m .32106 .59082 L .3223 .58872 L F
.828 .952 .899 r
.25133 .62249 m .25017 .62417 L .24798 .62385 L F
.47 .821 .997 r
.2661 .64136 m .26672 .64004 L .26486 .63981 L F
.2661 .64136 m .26839 .64086 L .26672 .64004 L F
.563 .462 .698 r
.37427 .59169 m .37481 .5944 L .37229 .59486 L F
.385 .262 .587 r
.37481 .5944 m .37285 .59839 L .37229 .59486 L F
.289 .404 .806 r
.21577 .61202 m .21479 .61392 L .21324 .61022 L F
.419 .566 .894 r
.21577 .61202 m .21669 .61384 L .21479 .61392 L F
.842 .883 .45 r
.54382 .5467 m .54339 .54881 L .54586 .54802 L F
.28 .519 .904 r
.28624 .64569 m .28734 .64441 L .28474 .64452 L F
.28624 .64569 m .29063 .64772 L .28734 .64441 L F
.795 .583 .614 r
.5408 .53885 m .54314 .53612 L .54067 .53613 L F
.5408 .53885 m .54462 .53934 L .54314 .53612 L F
0 .095 .64 r
.54314 .53612 m .54462 .53934 L .5445 .53874 L F
.478 0 0 r
.20643 .79279 m .21067 .79269 L .20817 .79188 L F
.617 .55 .756 r
.35224 .60723 m .35399 .61167 L .35616 .61005 L F
.541 .262 .441 r
.32734 .6597 m .32749 .66272 L .3245 .66307 L F
0 0 .409 r
.32778 .65689 m .32824 .65944 L .32734 .6597 L F
.525 .392 .642 r
.32824 .65944 m .32749 .66272 L .32734 .6597 L F
.364 .242 .577 r
.33664 .54739 m .33831 .54772 L .33805 .54513 L F
.217 0 0 r
.34768 .66635 m .34874 .66514 L .35004 .66584 L F
.608 .838 .987 r
.29767 .54231 m .29898 .54363 L .30022 .54129 L F
.739 .991 .869 r
.24928 .54479 m .24864 .54631 L .25017 .54446 L F
.24928 .54479 m .24714 .54655 L .24864 .54631 L F
.263 .764 .725 r
.24864 .54631 m .24849 .5462 L .25017 .54446 L F
.24864 .54631 m .24624 .54695 L .24849 .5462 L F
.091 .558 .907 r
.25165 .63601 m .25191 .63523 L .25022 .63489 L F
.25165 .63601 m .25516 .63689 L .25191 .63523 L F
0 0 0 r
.29783 .57684 m .29691 .57899 L .29861 .57543 L F
.546 .358 .576 r
.37254 .61341 m .37023 .61656 L .36999 .61375 L F
.37254 .61341 m .37023 .61656 L .36999 .61375 L F
.477 .151 .335 r
.34446 .61615 m .34681 .61604 L .34767 .61408 L F
.257 0 .224 r
.34767 .61408 m .34681 .61604 L .34954 .6134 L F
.433 .447 .774 r
.33098 .64687 m .32842 .64516 L .33081 .64442 L F
.899 .633 .526 r
.54382 .5467 m .546 .54545 L .54199 .54511 L F
.54382 .5467 m .54586 .54802 L .546 .54545 L F
.382 0 .169 r
.28818 .54406 m .28542 .54469 L .28638 .54273 L F
.415 0 .097 r
.28873 .54263 m .28818 .54406 L .28638 .54273 L F
.084 0 0 r
.28638 .54273 m .28716 .54292 L .28605 .54302 L F
.263 .233 .636 r
.2804 .62457 m .27771 .62341 L .28088 .62088 L F
.2804 .62457 m .27836 .62592 L .27771 .62341 L F
.219 .245 .674 r
.37203 .60025 m .37127 .60441 L .36966 .60079 L F
.37203 .60025 m .37272 .60387 L .37127 .60441 L F
.2 .191 .623 r
.37272 .60387 m .37317 .60646 L .37127 .60441 L F
.353 .215 .551 r
.37317 .60646 m .37132 .60725 L .37127 .60441 L F
0 0 .324 r
.35967 .53623 m .36086 .53736 L .36198 .53574 L F
.35967 .53623 m .35933 .53856 L .36086 .53736 L F
.276 0 .265 r
.30632 .64528 m .30963 .64272 L .30785 .6442 L F
.129 0 .239 r
.30549 .64741 m .30632 .64528 L .30785 .6442 L F
.692 .789 .925 r
.1788 .60083 m .18325 .60129 L .18312 .60047 L F
.794 .999 .84 r
.18312 .60047 m .18325 .60129 L .18314 .59988 L F
0 .366 .835 r
.18325 .60129 m .18439 .60161 L .18314 .59988 L F
.371 .669 .973 r
.28817 .54681 m .28778 .5486 L .28581 .54734 L F
.411 0 0 r
.29151 .55205 m .28982 .5533 L .28733 .55319 L F
.627 .129 .048 r
.29151 .55205 m .29388 .5538 L .28982 .5533 L F
.358 .654 .968 r
.19148 .60707 m .19166 .60548 L .18828 .60443 L F
.19148 .60707 m .19284 .60683 L .19166 .60548 L F
.199 .012 .387 r
.33196 .57886 m .33033 .57964 L .33229 .5762 L F
.506 .353 .608 r
.33196 .57886 m .32982 .58197 L .33033 .57964 L F
.953 .812 .667 r
.34141 .65963 m .34142 .66036 L .33976 .6594 L F
.656 .813 .958 r
.24849 .74274 m .24968 .7441 L .24565 .74373 L F
.718 .322 .296 r
.24565 .74373 m .24968 .7441 L .24794 .74616 L F
.259 .6 .952 r
.25023 .74285 m .24968 .7441 L .24849 .74274 L F
.697 .894 .526 r
.24794 .74616 m .24968 .7441 L .25023 .74285 L F
.397 .371 .713 r
.33977 .63114 m .33717 .63248 L .33708 .62873 L F
.085 .14 .623 r
.33952 .63456 m .33717 .63248 L .33977 .63114 L F
.33952 .63456 m .33821 .63567 L .33717 .63248 L F
.69 .397 .474 r
.23832 .55806 m .23779 .5599 L .2406 .55955 L F
.695 .39 .455 r
.23832 .55806 m .2406 .55955 L .24124 .5588 L F
.542 .419 .662 r
.34392 .59846 m .34635 .60033 L .34642 .59805 L F
.34392 .59846 m .34432 .60123 L .34635 .60033 L F
.568 .46 .691 r
.53443 .55444 m .53548 .55754 L .53237 .55769 L F
.718 .886 .958 r
.31906 .5888 m .31639 .59076 L .31463 .58968 L F
.503 .325 .573 r
.36227 .53303 m .3644 .53498 L .36486 .53258 L F
.36227 .53303 m .36198 .53574 L .3644 .53498 L F
.279 .551 .926 r
.18439 .60161 m .18695 .60423 L .18771 .60277 L F
.153 .389 .838 r
.18695 .60423 m .18828 .60443 L .18771 .60277 L F
.28 .768 .688 r
.2486 .55942 m .24687 .56005 L .24526 .56069 L F
.29 .774 .693 r
.24941 .55905 m .2486 .55942 L .25082 .55826 L F
.24941 .55905 m .24687 .56005 L .2486 .55942 L F
.944 .8 .67 r
.3464 .58492 m .34798 .58322 L .34809 .58344 L F
.791 .294 0 r
.34247 .63763 m .34551 .64052 L .34671 .63874 L F
.31 .722 .976 r
.27328 .52948 m .27557 .52944 L .27731 .53042 L F
.444 .783 .998 r
.2778 .52895 m .27731 .53042 L .27557 .52944 L F
.2778 .52895 m .27973 .53009 L .27731 .53042 L F
.842 .662 .659 r
.53737 .53525 m .54067 .53613 L .53892 .53227 L F
.925 .631 .466 r
.53892 .53779 m .54067 .53613 L .53737 .53525 L F
.53892 .53779 m .5408 .53885 L .54067 .53613 L F
.157 0 0 r
.3676 .63728 m .36763 .63821 L .36988 .63719 L F
.482 .287 .539 r
.39454 .55646 m .39128 .55449 L .39544 .55428 L F
.39454 .55646 m .39216 .55731 L .39128 .55449 L F
.665 .509 .663 r
.35023 .55192 m .34844 .55377 L .3473 .55224 L F
.823 .662 .683 r
.33934 .5567 m .33743 .55431 L .34007 .55416 L F
.429 .367 .687 r
.34032 .55361 m .33934 .5567 L .34007 .55416 L F
.644 .437 .588 r
.33987 .55679 m .34275 .55773 L .34328 .55668 L F
.34011 .5567 m .34328 .55668 L .34406 .5551 L F
.33987 .55679 m .34328 .55668 L .34011 .5567 L F
0 0 0 r
.33997 .55678 m .33935 .5567 L .34239 .55671 L F
.33935 .5567 m .33934 .5567 L .33952 .5567 L F
.33935 .5567 m .33952 .5567 L .34239 .55671 L F
.429 .367 .687 r
.34032 .55361 m .34239 .55671 L .33934 .5567 L F
.811 .333 .068 r
.33232 .60876 m .33001 .60651 L .33147 .60684 L F
.608 .645 .862 r
.33051 .61062 m .33147 .60684 L .33001 .60651 L F
.33051 .61062 m .33328 .61017 L .33147 .60684 L F
.992 .775 .508 r
.33294 .61283 m .33051 .61062 L .33053 .61334 L F
.33294 .61283 m .33328 .61017 L .33051 .61062 L F
.47 .474 .78 r
.30598 .5808 m .30696 .58192 L .30487 .58234 L F
.5 .483 .769 r
.30904 .58125 m .30696 .58192 L .30598 .5808 L F
.479 .57 .869 r
.30487 .58234 m .30696 .58192 L .30551 .57877 L F
0 0 0 r
.26485 .62046 m .26497 .62111 L .26686 .61946 L F
.26485 .62046 m .26306 .62236 L .26497 .62111 L F
.701 .664 .811 r
.21908 .56327 m .22056 .56503 L .22304 .56379 L F
.459 .82 .995 r
.27973 .53009 m .28198 .52955 L .28361 .53046 L F
.571 .87 .995 r
.28361 .53046 m .28419 .52876 L .28598 .52946 L F
.28361 .53046 m .28198 .52955 L .28419 .52876 L F
.341 0 .165 r
.37285 .59839 m .37203 .60025 L .36966 .60079 L F
.385 .262 .587 r
.37481 .5944 m .37548 .5976 L .37285 .59839 L F
.271 0 .134 r
.3751 .59824 m .37285 .59839 L .37548 .5976 L F
.3751 .59824 m .37203 .60025 L .37285 .59839 L F
.557 .392 .613 r
.3333 .64382 m .33058 .64155 L .33482 .6398 L F
.3333 .64382 m .33081 .64442 L .33058 .64155 L F
.481 .098 .236 r
.31632 .55753 m .3118 .56008 L .31176 .55735 L F
.31632 .55753 m .31446 .55985 L .3118 .56008 L F
.634 .277 .348 r
.31812 .55947 m .31446 .55985 L .31632 .55753 L F
.711 .252 .16 r
.31822 .55833 m .31812 .55947 L .31632 .55753 L F
.558 .498 .744 r
.33839 .58854 m .33914 .5915 L .34086 .59052 L F
0 0 .528 r
.32169 .59712 m .32091 .59863 L .32044 .59446 L F
0 .091 .649 r
.32243 .59941 m .32091 .59863 L .32169 .59712 L F
.32243 .59941 m .32225 .60042 L .32091 .59863 L F
.283 .505 .894 r
.19866 .61332 m .19937 .61158 L .19622 .61023 L F
.19866 .61332 m .20011 .61322 L .19937 .61158 L F
.505 .758 .987 r
.32484 .53083 m .323 .53203 L .32166 .53067 L F
.32484 .53083 m .32535 .53168 L .323 .53203 L F
.275 .055 .387 r
.32031 .58197 m .32251 .57893 L .32051 .57971 L F
.319 .552 .918 r
.29238 .64832 m .29548 .65134 L .29557 .64958 L F
.096 0 0 r
.36056 .52106 m .36156 .52094 L .36253 .52053 L F
.815 .364 .167 r
.25392 .62185 m .25751 .62451 L .25531 .62346 L F
.981 .729 .479 r
.35997 .52414 m .3581 .52504 L .35826 .52188 L F
.205 .328 .768 r
.35997 .52414 m .36056 .52106 L .3581 .52504 L F
.35997 .52414 m .36227 .52557 L .36056 .52106 L F
.544 .681 .928 r
.20608 .61875 m .2063 .61573 L .20403 .61627 L F
.20608 .61875 m .20867 .6188 L .2063 .61573 L F
.999 .838 .511 r
.25513 .55692 m .25662 .55699 L .25744 .55585 L F
.026 0 0 r
.2618 .55636 m .25875 .55675 L .25726 .55676 L F
.2618 .55636 m .25538 .55692 L .25561 .55688 L F
.589 .946 .826 r
.26 .55513 m .25744 .55585 L .25685 .55666 L F
.26 .55513 m .25685 .55666 L .25738 .55657 L F
.515 0 0 r
.2618 .55636 m .25744 .55585 L .26 .55513 L F
.439 .051 .205 r
.26251 .55476 m .2618 .55636 L .26 .55513 L F
.418 .03 .192 r
.26635 .55349 m .2618 .55636 L .26251 .55476 L F
.26635 .55349 m .26418 .556 L .2618 .55636 L F
.589 .946 .826 r
.25738 .55657 m .25685 .55666 L .25662 .55699 L F
.026 0 0 r
.2618 .55636 m .25513 .55692 L .25744 .55585 L F
.823 .548 .522 r
.26418 .556 m .25917 .55668 L .2618 .55636 L F
.026 0 0 r
.25875 .55675 m .25744 .55691 L .25726 .55676 L F
.823 .548 .522 r
.25917 .55668 m .25744 .55691 L .25875 .55675 L F
.25917 .55668 m .25875 .55675 L .2618 .55636 L F
.174 0 .011 r
.26225 .5546 m .261 .55639 L .26284 .55608 L F
.823 .548 .522 r
.26418 .556 m .26383 .55839 L .25744 .55691 L F
.174 0 .011 r
.261 .55639 m .26076 .55673 L .26272 .55612 L F
.261 .55639 m .26272 .55612 L .26284 .55608 L F
.26076 .55673 m .2606 .55696 L .26119 .55673 L F
.26076 .55673 m .26119 .55673 L .26284 .55608 L F
.026 0 0 r
.25726 .55676 m .25744 .55691 L .25538 .55692 L F
.25561 .55688 m .25538 .55692 L .25513 .55692 L F
.678 .499 .636 r
.35531 .57645 m .35812 .57607 L .35783 .57337 L F
.507 .479 .76 r
.35682 .5696 m .35783 .57337 L .35974 .57273 L F
.401 .274 .59 r
.35812 .57607 m .35974 .57273 L .35783 .57337 L F
.899 .954 .827 r
.34657 .53359 m .34414 .53433 L .3452 .53529 L F
.456 .522 .837 r
.50102 .55135 m .50228 .55487 L .504 .55301 L F
.36 .35 .712 r
.50305 .55692 m .504 .55301 L .50228 .55487 L F
.532 .122 .208 r
.30217 .63693 m .30311 .63539 L .3003 .63536 L F
.104 0 0 r
.30514 .63451 m .30311 .63539 L .30217 .63693 L F
.30514 .63451 m .30217 .63693 L .30484 .63706 L F
.149 .674 .877 r
.30083 .63662 m .30331 .63689 L .30217 .63693 L F
.30331 .63689 m .30484 .63706 L .30217 .63693 L F
.327 .786 .946 r
.3 .63701 m .30217 .63693 L .3003 .63536 L F
.29994 .63734 m .30217 .63693 L .3 .63701 L F
.384 .374 .724 r
.16954 .58597 m .17208 .58794 L .17142 .58456 L F
.395 .374 .717 r
.17038 .58855 m .17208 .58794 L .16954 .58597 L F
.122 .304 .775 r
.2536 .73757 m .25088 .7351 L .25376 .73539 L F
.702 .556 .685 r
.24973 .73669 m .25376 .73539 L .25088 .7351 L F
.105 .596 .906 r
.32467 .57137 m .32295 .57022 L .32061 .57004 L F
.056 .556 .885 r
.32742 .572 m .32295 .57022 L .32467 .57137 L F
.649 .698 .882 r
.31748 .61865 m .31961 .62257 L .31789 .62252 L F
.683 .277 .27 r
.31789 .62252 m .31986 .62469 L .3176 .62571 L F
.82 .812 .843 r
.53544 .55009 m .53314 .54913 L .53325 .54979 L F
.53544 .55009 m .53845 .54848 L .53314 .54913 L F
.823 .757 .79 r
.53351 .54641 m .53325 .54979 L .53314 .54913 L F
.498 .732 .977 r
.51068 .56312 m .51427 .56411 L .51298 .56261 L F
.611 .903 .985 r
.51681 .56314 m .51536 .56239 L .51427 .56411 L F
.456 .71 .977 r
.51427 .56411 m .51536 .56239 L .51298 .56261 L F
.72 .726 .855 r
.35786 .56238 m .35911 .56422 L .35518 .5636 L F
.665 .705 .878 r
.36172 .56303 m .35911 .56422 L .35786 .56238 L F
0 0 .243 r
.31676 .61345 m .31655 .61652 L .31617 .61654 L F
0 0 .514 r
.31655 .61652 m .31748 .61865 L .31617 .61654 L F
.471 .214 .442 r
.32251 .57893 m .32542 .57599 L .32286 .57645 L F
.126 .571 .922 r
.26206 .63916 m .26307 .63857 L .26039 .63791 L F
.26206 .63916 m .26486 .63981 L .26307 .63857 L F
.953 .689 .496 r
.25354 .72774 m .25596 .72875 L .25384 .73033 L F
0 0 0 r
.25429 .73009 m .25596 .72875 L .25806 .72802 L F
.25409 .73014 m .25596 .72875 L .25429 .73009 L F
.25384 .73033 m .25806 .72802 L .25606 .72995 L F
.468 .338 .62 r
.25354 .72774 m .25575 .72968 L .25565 .72731 L F
.25575 .72968 m .25606 .72995 L .256 .72961 L F
.25575 .72968 m .256 .72961 L .25565 .72731 L F
0 0 0 r
.25384 .73033 m .25409 .73014 L .25429 .73009 L F
.495 .399 .676 r
.34606 .62565 m .34827 .62238 L .3443 .62354 L F
.34606 .62565 m .34845 .62577 L .34827 .62238 L F
.173 .513 .915 r
.20245 .61615 m .2027 .61474 L .20011 .61322 L F
.20245 .61615 m .20403 .61627 L .2027 .61474 L F
0 0 .216 r
.32085 .56702 m .32159 .56818 L .32376 .56706 L F
.32085 .56702 m .32061 .57004 L .32159 .56818 L F
.758 .913 .943 r
.34414 .53433 m .34479 .5355 L .3452 .53529 L F
.65 .356 .46 r
.52671 .53307 m .52937 .53509 L .53114 .5322 L F
.52671 .53307 m .52653 .53525 L .52937 .53509 L F
.564 .574 .822 r
.32715 .55155 m .32949 .55097 L .32559 .54784 L F
.483 .279 .526 r
.32949 .55097 m .32702 .55429 L .32715 .55155 L F
.34 .116 .421 r
.2904 .59022 m .29084 .58997 L .29084 .59004 L F
0 0 0 r
.29084 .59004 m .29239 .58911 L .29325 .58674 L F
.34 .116 .421 r
.29084 .58997 m .29239 .58911 L .29084 .59004 L F
.622 .823 .415 r
.29085 .59012 m .29084 .59004 L .2921 .58816 L F
.28995 .59153 m .29084 .59004 L .29085 .59012 L F
0 0 0 r
.28995 .59153 m .28933 .5936 L .29084 .59004 L F
.857 .687 .671 r
.52927 .55021 m .52846 .55482 L .52675 .55084 L F
.432 0 .104 r
.29075 .5436 m .28873 .54263 L .29263 .54269 L F
.569 .755 .965 r
.22727 .61643 m .22497 .61706 L .22336 .61549 L F
0 .438 .792 r
.27069 .64062 m .27241 .64153 L .27422 .64209 L F
.797 .581 .609 r
.2977 .66659 m .2992 .66533 L .29686 .66573 L F
.2977 .66659 m .30067 .66931 L .2992 .66533 L F
.666 .433 .558 r
.30297 .66874 m .30332 .66587 L .2992 .66533 L F
.515 .345 .589 r
.37903 .58519 m .37667 .58852 L .37676 .58581 L F
.696 .828 .946 r
.2314 .55993 m .23528 .55983 L .2346 .55952 L F
.161 .661 .911 r
.23528 .55983 m .23634 .55949 L .2346 .55952 L F
.23528 .55983 m .23634 .55949 L .2346 .55952 L F
.313 .753 .966 r
.24145 .53286 m .24363 .53267 L .24541 .53339 L F
.506 .849 .995 r
.24541 .53339 m .24597 .532 L .24774 .53276 L F
.24541 .53339 m .24363 .53267 L .24597 .532 L F
.605 .953 .883 r
.34202 .60427 m .33724 .60597 L .33968 .60555 L F
0 0 .447 r
.34278 .60564 m .34219 .6068 L .34214 .60605 L F
.34278 .60564 m .34214 .60605 L .34202 .60427 L F
.691 .199 .072 r
.34278 .60564 m .34202 .60427 L .33968 .60555 L F
.368 .819 .939 r
.34475 .6044 m .34278 .60564 L .34208 .60513 L F
.34484 .60438 m .34278 .60564 L .34475 .6044 L F
.074 0 0 r
.35392 .66413 m .35004 .66584 L .35164 .66455 L F
.979 .737 .499 r
.33215 .56595 m .33204 .56856 L .33387 .56741 L F
.568 .564 .809 r
.3325 .56327 m .33387 .56741 L .33605 .56646 L F
.979 .737 .499 r
.33387 .56741 m .33215 .56595 L .33605 .56646 L F
.33387 .56741 m .33204 .56856 L .33215 .56595 L F
.49 .537 .832 r
.33655 .56856 m .33387 .56741 L .33605 .56646 L F
.679 .477 .606 r
.32176 .55725 m .31812 .55947 L .31822 .55833 L F
.382 .058 .286 r
.29994 .63734 m .29754 .63816 L .29663 .64086 L F
.039 0 0 r
.24124 .5588 m .24315 .55789 L .24459 .55717 L F
0 0 0 r
.28528 .55223 m .28108 .55134 L .28356 .55059 L F
.28528 .55223 m .2821 .55457 L .28108 .55134 L F
.28528 .55223 m .28394 .5536 L .2821 .55457 L F
.28546 .55223 m .28528 .55223 L .28733 .55319 L F
.28546 .55223 m .28394 .5536 L .28528 .55223 L F
.30393 .59771 m .30236 .60123 L .30415 .59922 L F
.431 .444 .772 r
.30415 .59922 m .30236 .60123 L .30479 .60157 L F
.976 .922 .649 r
.25606 .73473 m .25726 .73479 L .2552 .73656 L F
.794 .999 .84 r
.25715 .73344 m .25726 .73479 L .25606 .73473 L F
.861 .976 .672 r
.2552 .73656 m .25726 .73479 L .25715 .73344 L F
.069 .631 .778 r
.2883 .5283 m .29222 .52839 L .28985 .52907 L F
.512 .505 .785 r
.35224 .60723 m .35329 .60294 L .35113 .60348 L F
.35224 .60723 m .35443 .60668 L .35329 .60294 L F
.617 .55 .756 r
.35224 .60723 m .35616 .61005 L .35443 .60668 L F
0 0 .203 r
.29861 .57543 m .3006 .57206 L .29964 .5733 L F
.552 .388 .612 r
.28275 .6005 m .28524 .60037 L .28525 .59795 L F
.477 .142 .319 r
.28168 .60335 m .28524 .60037 L .28275 .6005 L F
.491 .62 .906 r
.52062 .56393 m .522 .56181 L .51929 .56224 L F
.52062 .56393 m .52298 .56382 L .522 .56181 L F
.64 .756 .932 r
.51681 .56314 m .52062 .56393 L .51929 .56224 L F
.346 .067 .34 r
.32249 .61987 m .31961 .62257 L .32141 .62278 L F
.042 .322 .806 r
.32141 .62278 m .31961 .62257 L .31748 .61865 L F
.237 0 0 r
.21099 .54466 m .2133 .54408 L .21505 .54194 L F
.156 0 0 r
.21505 .54194 m .21549 .54338 L .21736 .54167 L F
.21505 .54194 m .2133 .54408 L .21549 .54338 L F
.443 .682 .966 r
.37843 .52926 m .37763 .53121 L .37608 .52935 L F
.37843 .52926 m .3805 .5315 L .37763 .53121 L F
0 0 .354 r
.29686 .66573 m .29667 .66768 L .2977 .66659 L F
.32 .357 .744 r
.31993 .63937 m .32245 .64117 L .32217 .63742 L F
.31993 .63937 m .3208 .64139 L .32245 .64117 L F
.392 .291 .62 r
.30751 .61051 m .30917 .60708 L .30691 .60793 L F
.48 .802 1 r
.31366 .52923 m .31299 .53072 L .3116 .52993 L F
.31366 .52923 m .31515 .53033 L .31299 .53072 L F
.888 .949 .842 r
.23953 .54673 m .23745 .55006 L .23984 .54986 L F
0 0 .304 r
.30741 .54137 m .30727 .544 L .30618 .54502 L F
.14 .091 .536 r
.30727 .544 m .30605 .54776 L .30618 .54502 L F
.819 .993 .749 r
.35085 .55011 m .35023 .55192 L .35293 .54879 L F
.943 .694 .531 r
.35096 .5475 m .35085 .55011 L .35293 .54879 L F
.47 .057 .174 r
.34039 .55917 m .34275 .55773 L .33987 .55679 L F
.519 .639 .907 r
.50686 .56003 m .50745 .55651 L .50496 .55703 L F
.50686 .56003 m .50926 .55961 L .50745 .55651 L F
.735 .623 .734 r
.34233 .54883 m .34055 .55163 L .33986 .54904 L F
.586 .634 .865 r
.34332 .54914 m .34051 .55332 L .34053 .54972 L F
.34051 .55332 m .34032 .55361 L .34033 .55335 L F
.566 .318 .499 r
.34055 .55163 m .34022 .55337 L .33813 .55371 L F
.995 .781 .501 r
.34032 .55361 m .34055 .55163 L .34053 .54972 L F
.34032 .55361 m .34007 .55416 L .34055 .55163 L F
.586 .634 .865 r
.34051 .55332 m .34033 .55335 L .34053 .54972 L F
.566 .318 .499 r
.33813 .55371 m .34007 .55416 L .33743 .55431 L F
.34022 .55337 m .34007 .55416 L .33813 .55371 L F
0 0 .393 r
.34053 .54972 m .34055 .55163 L .33986 .54904 L F
.222 .119 .519 r
.32927 .65362 m .32922 .65622 L .32778 .65689 L F
.115 0 .412 r
.32922 .65622 m .32824 .65944 L .32778 .65689 L F
.59 .275 .404 r
.34954 .6134 m .34905 .61524 L .35211 .61356 L F
.099 0 0 r
.34954 .6134 m .35206 .61356 L .35206 .61356 L F
.35164 .61349 m .35229 .61356 L .35383 .61358 L F
.623 .306 .413 r
.34796 .61784 m .35241 .61834 L .35247 .61358 L F
.35227 .61357 m .35247 .61358 L .35247 .61337 L F
.34796 .61784 m .35247 .61358 L .35227 .61357 L F
0 .062 .559 r
.35253 .61358 m .35383 .61358 L .35229 .61356 L F
.35415 .61372 m .35399 .61365 L .35253 .61358 L F
.35399 .61365 m .35383 .61358 L .35253 .61358 L F
.615 .3 .413 r
.35253 .61358 m .35253 .61359 L .35415 .61372 L F
.35253 .61359 m .3536 .61745 L .35414 .61377 L F
.35253 .61358 m .35241 .61834 L .3536 .61745 L F
.35247 .61337 m .35247 .61358 L .35253 .61358 L F
.35247 .61358 m .35241 .61834 L .35253 .61358 L F
0 .062 .559 r
.35415 .61372 m .35253 .61358 L .35168 .61355 L F
.35253 .61358 m .35229 .61356 L .35203 .61356 L F
.35253 .61358 m .35203 .61356 L .35168 .61355 L F
.615 .3 .413 r
.35247 .61337 m .35253 .61358 L .35415 .61372 L F
.35253 .61359 m .35414 .61377 L .35415 .61372 L F
.099 0 0 r
.35001 .61342 m .35206 .61356 L .35229 .61356 L F
.35001 .61342 m .35229 .61356 L .35164 .61349 L F
.34954 .6134 m .35206 .61356 L .35001 .61342 L F
.623 .306 .413 r
.34796 .61784 m .35226 .61357 L .34905 .61524 L F
.35226 .61357 m .35247 .61337 L .35211 .61356 L F
.35226 .61357 m .35211 .61356 L .34905 .61524 L F
.59 .275 .404 r
.34954 .6134 m .35211 .61356 L .35247 .61337 L F
.099 0 0 r
.34954 .6134 m .35168 .61355 L .35206 .61356 L F
0 .062 .559 r
.35415 .61372 m .35589 .61544 L .35383 .61358 L F
.42 .291 .599 r
.35383 .61358 m .35589 .61544 L .35381 .61556 L F
.36 0 0 r
.29452 .52773 m .29853 .52818 L .29625 .52877 L F
.039 0 0 r
.24124 .5588 m .2406 .55955 L .24315 .55789 L F
.308 .089 .409 r
.30928 .5479 m .31196 .54396 L .30736 .54296 L F
.238 .058 .424 r
.19603 .57613 m .19569 .5786 L .19413 .57928 L F
.282 .152 .52 r
.19569 .5786 m .19575 .58146 L .19413 .57928 L F
.696 .568 .707 r
.3451 .5788 m .34759 .57564 L .34606 .57663 L F
.773 .685 .767 r
.34759 .57564 m .3451 .5788 L .34606 .57663 L F
.628 .153 .105 r
.24526 .56069 m .24257 .5623 L .24016 .56163 L F
.332 0 0 r
.24687 .56005 m .24257 .5623 L .24526 .56069 L F
.403 .806 .982 r
.24774 .53276 m .25 .53234 L .25185 .53306 L F
.419 .817 .984 r
.25 .53234 m .25416 .5326 L .25185 .53306 L F
.457 .551 .863 r
.38255 .53124 m .38127 .53345 L .3805 .5315 L F
.52 .632 .902 r
.38255 .53124 m .38341 .53356 L .38127 .53345 L F
0 .133 .67 r
.20185 .59313 m .20108 .5941 L .19893 .59135 L F
.20185 .59313 m .20194 .59451 L .20108 .5941 L F
0 .028 .587 r
.20261 .59656 m .20108 .5941 L .20194 .59451 L F
.414 .816 .982 r
.32777 .53116 m .33185 .53059 L .32898 .53189 L F
.007 .094 .605 r
.21362 .6062 m .21252 .60773 L .21196 .604 L F
.113 .145 .616 r
.21448 .60828 m .21252 .60773 L .21362 .6062 L F
.21448 .60828 m .21324 .61022 L .21252 .60773 L F
.26 .089 .45 r
.17321 .57295 m .17487 .57464 L .17528 .57231 L F
.17321 .57295 m .17281 .57583 L .17487 .57464 L F
.337 .297 .666 r
.17038 .58855 m .17272 .59042 L .17208 .58794 L F
.17038 .58855 m .17083 .59234 L .17272 .59042 L F
.724 .655 .781 r
.34038 .54218 m .34256 .5457 L .33805 .54513 L F
.855 .994 .751 r
.34201 .54638 m .33986 .54904 L .34073 .54695 L F
.733 .596 .703 r
.34233 .54883 m .33986 .54904 L .34256 .5457 L F
.689 .806 .937 r
.34073 .54695 m .33986 .54904 L .34233 .54883 L F
0 0 .505 r
.34053 .54972 m .33951 .5475 L .34073 .54695 L F
.534 .365 .598 r
.33805 .54513 m .33831 .54772 L .34073 .54695 L F
.34073 .54695 m .33831 .54772 L .33805 .54513 L F
0 0 .505 r
.33951 .5475 m .33876 .54588 L .34073 .54695 L F
.855 .994 .751 r
.34256 .5457 m .34201 .54638 L .34073 .54695 L F
.534 .365 .598 r
.34073 .54695 m .33805 .54513 L .34256 .5457 L F
.435 .528 .854 r
.34408 .54422 m .34256 .5457 L .34038 .54218 L F
.967 .807 .632 r
.34256 .5457 m .34233 .54883 L .34073 .54695 L F
.599 .388 .567 r
.34408 .54422 m .34073 .54695 L .34256 .5457 L F
0 .072 .602 r
.34928 .54839 m .35085 .55011 L .35096 .5475 L F
.3496 .54959 m .35023 .55192 L .35085 .55011 L F
.488 .446 .737 r
.35159 .55271 m .34924 .55192 L .35085 .55011 L F
.418 .313 .628 r
.35322 .54953 m .35159 .55271 L .35085 .55011 L F
.351 0 .076 r
.3495 .55181 m .3517 .55046 L .35085 .55011 L F
.3517 .55046 m .35322 .54953 L .35085 .55011 L F
0 .072 .602 r
.34928 .54839 m .3496 .54959 L .35085 .55011 L F
.817 .765 .804 r
.30479 .60157 m .30622 .60425 L .30853 .60042 L F
.65 .594 .778 r
.22649 .55749 m .22874 .56108 L .2314 .55993 L F
0 0 .059 r
.28461 .61574 m .28533 .61323 L .28674 .61235 L F
.938 .945 .766 r
.53601 .55095 m .53443 .55444 L .53511 .55372 L F
.38 .159 .448 r
.33415 .57793 m .33229 .5762 L .33394 .57536 L F
.33415 .57793 m .33196 .57886 L .33229 .5762 L F
.613 .77 .955 r
.25965 .72377 m .25825 .72533 L .25702 .72384 L F
0 0 .366 r
.25897 .72769 m .25825 .72533 L .25965 .72377 L F
.25897 .72769 m .25806 .72802 L .25825 .72533 L F
.198 .728 .789 r
.35812 .66358 m .3555 .66379 L .35392 .66413 L F
.65 .958 .934 r
.35864 .66216 m .3555 .66379 L .35812 .66358 L F
.204 0 0 r
.33105 .55158 m .33526 .54986 L .33347 .55146 L F
.066 0 .088 r
.32249 .61987 m .32346 .62121 L .32512 .61913 L F
.32249 .61987 m .32141 .62278 L .32346 .62121 L F
.765 .399 .361 r
.34273 .61693 m .34681 .61604 L .34446 .61615 L F
.314 .306 .69 r
.3208 .64139 m .32312 .64349 L .32245 .64117 L F
.352 .31 .671 r
.3208 .64139 m .32127 .64444 L .32312 .64349 L F
.607 .406 .584 r
.33972 .62591 m .3399 .62859 L .33708 .62873 L F
.187 0 0 r
.25751 .62451 m .25963 .6241 L .2615 .62243 L F
0 0 0 r
.25963 .6241 m .26306 .62236 L .2615 .62243 L F
.879 .992 .751 r
.34617 .56222 m .34477 .56423 L .34517 .5648 L F
.72 .336 0 r
.34477 .56423 m .34635 .56725 L .34517 .5648 L F
.516 .908 .93 r
.34844 .55377 m .34565 .55462 L .34618 .55407 L F
.42 .177 .437 r
.3447 .55584 m .34693 .5533 L .34618 .55407 L F
.697 .983 .849 r
.34924 .55192 m .34618 .55407 L .34784 .55226 L F
.42 .177 .437 r
.34693 .5533 m .34784 .55226 L .34618 .55407 L F
.516 .908 .93 r
.34565 .55462 m .34406 .5551 L .34618 .55407 L F
0 .135 .656 r
.34923 .55468 m .34951 .55575 L .34844 .55377 L F
.513 .394 .654 r
.35037 .55734 m .34793 .55873 L .34844 .55377 L F
.693 .24 .17 r
.34618 .55407 m .34923 .55468 L .34844 .55377 L F
.744 .658 .765 r
.34861 .55236 m .34923 .55468 L .34618 .55407 L F
.34924 .55192 m .34923 .55468 L .34861 .55236 L F
0 .135 .656 r
.34923 .55468 m .35037 .55734 L .34951 .55575 L F
.761 .666 .758 r
.30736 .54296 m .31196 .54396 L .31167 .54181 L F
.376 .325 .673 r
.31196 .54396 m .31379 .54149 L .31167 .54181 L F
.31196 .54396 m .31458 .54411 L .31379 .54149 L F
.419 .194 .464 r
.31186 .54732 m .31458 .54411 L .31196 .54396 L F
.065 .261 .752 r
.34962 .62867 m .35097 .63232 L .35183 .63064 L F
.533 0 0 r
.35097 .63232 m .35256 .63362 L .35173 .63333 L F
.35256 .63362 m .35329 .63421 L .35173 .63333 L F
.04 .297 .788 r
.35085 .63303 m .35173 .63333 L .35044 .6333 L F
.533 0 0 r
.35097 .63232 m .35173 .63333 L .35183 .63064 L F
.831 .924 .536 r
.35329 .63421 m .35183 .63064 L .35173 .63333 L F
.04 .297 .788 r
.35243 .63201 m .35173 .63333 L .35085 .63303 L F
.708 .261 .187 r
.35025 .65968 m .35231 .66189 L .35412 .66043 L F
.743 .649 .756 r
.36126 .60952 m .36376 .61407 L .36618 .61094 L F
.392 .291 .62 r
.30751 .61051 m .30922 .60998 L .30917 .60708 L F
.401 .318 .646 r
.30751 .61051 m .30988 .61251 L .30922 .60998 L F
.317 .314 .698 r
.30871 .61291 m .30988 .61251 L .30751 .61051 L F
.239 .485 .89 r
.23173 .61587 m .23193 .6185 L .22947 .61608 L F
.23173 .61587 m .23362 .61862 L .23193 .6185 L F
0 0 .028 r
.34406 .5551 m .3447 .55584 L .34618 .55407 L F
.34406 .5551 m .34275 .55773 L .3447 .55584 L F
.633 .182 .161 r
.31845 .66005 m .31667 .66184 L .31443 .65988 L F
.815 .424 .312 r
.31845 .66005 m .32091 .66312 L .31667 .66184 L F
.734 .446 .492 r
.32225 .66264 m .32091 .66312 L .31845 .66005 L F
.481 .52 .82 r
.28899 .62745 m .29196 .62941 L .29145 .62671 L F
.443 0 0 r
.35716 .54348 m .35315 .54444 L .35505 .54136 L F
.35716 .54348 m .3563 .54455 L .35315 .54444 L F
.016 0 0 r
.35842 .54372 m .35716 .54348 L .3601 .54262 L F
.35842 .54372 m .3563 .54455 L .35716 .54348 L F
.516 .162 .305 r
.31193 .57782 m .31011 .57592 L .31149 .57566 L F
.437 .355 .666 r
.1708 .59488 m .17272 .59042 L .17083 .59234 L F
.773 .685 .767 r
.34759 .57564 m .34964 .57952 L .3451 .5788 L F
.696 .568 .707 r
.3451 .5788 m .34711 .58001 L .34716 .57952 L F
.966 .785 .609 r
.34964 .57952 m .34862 .58003 L .34746 .57963 L F
.34964 .57952 m .34746 .57963 L .3475 .57952 L F
.34964 .57952 m .34716 .57952 L .34664 .57904 L F
.693 .569 .71 r
.34705 .58081 m .34742 .57975 L .34711 .58001 L F
.413 .316 .636 r
.34716 .57952 m .34711 .58001 L .34742 .57975 L F
.716 .191 0 r
.3451 .5788 m .34705 .58081 L .34711 .58001 L F
.966 .785 .609 r
.34862 .58003 m .34705 .58081 L .3451 .5788 L F
.036 .275 .771 r
.35002 .57761 m .34964 .57952 L .34759 .57564 L F
.693 .569 .71 r
.34705 .58081 m .35002 .57761 L .34742 .57975 L F
.966 .785 .609 r
.3475 .57952 m .34746 .57963 L .34716 .57952 L F
.34664 .57904 m .34716 .57952 L .3451 .5788 L F
.413 .316 .636 r
.34759 .57564 m .34716 .57952 L .35002 .57761 L F
.34716 .57952 m .34742 .57975 L .35002 .57761 L F
.696 .568 .707 r
.3451 .5788 m .34716 .57952 L .34759 .57564 L F
.966 .785 .609 r
.34964 .57952 m .34873 .58223 L .34705 .58081 L F
.341 .103 .4 r
.35082 .58167 m .34873 .58223 L .34964 .57952 L F
.435 .365 .679 r
.35082 .58167 m .35117 .58408 L .34873 .58223 L F
.35082 .58167 m .35117 .58408 L .34873 .58223 L F
.591 .477 .692 r
.35414 .5834 m .35117 .58408 L .35082 .58167 L F
.579 .414 .622 r
.34705 .58081 m .35132 .58288 L .3514 .58218 L F
.35109 .5808 m .3515 .58116 L .35154 .58079 L F
.292 .327 .726 r
.35109 .5808 m .35082 .58167 L .35056 .58033 L F
.35142 .58109 m .35056 .58033 L .35002 .57761 L F
.341 .103 .4 r
.35082 .58167 m .34964 .57952 L .34981 .57867 L F
.35056 .58033 m .34981 .57867 L .35002 .57761 L F
.35082 .58167 m .34981 .57867 L .35056 .58033 L F
.693 .569 .71 r
.34705 .58081 m .35109 .5808 L .35002 .57761 L F
.35109 .5808 m .35154 .58079 L .35002 .57761 L F
.292 .327 .726 r
.35142 .58109 m .35125 .58126 L .35109 .5808 L F
.35125 .58126 m .35082 .58167 L .35109 .5808 L F
.22 .319 .753 r
.35154 .58079 m .35272 .5798 L .35002 .57761 L F
.292 .327 .726 r
.35272 .5798 m .35142 .58109 L .35002 .57761 L F
0 0 .074 r
.35154 .58079 m .35158 .58096 L .35272 .5798 L F
.459 .597 .902 r
.35145 .5811 m .35151 .58112 L .35087 .58168 L F
.35151 .58112 m .3535 .58193 L .35124 .58171 L F
.35151 .58112 m .35124 .58171 L .35087 .58168 L F
.591 .477 .692 r
.35414 .5834 m .35082 .58167 L .3535 .58193 L F
0 0 .074 r
.35158 .58096 m .35132 .58288 L .3518 .58204 L F
.35154 .58079 m .35151 .58111 L .35158 .58096 L F
.35151 .58111 m .35132 .58288 L .35158 .58096 L F
.459 .597 .902 r
.35272 .5798 m .35341 .58168 L .35142 .58109 L F
.35341 .58168 m .3535 .58193 L .35142 .58109 L F
0 0 .074 r
.35158 .58096 m .3518 .58204 L .35272 .5798 L F
.459 .597 .902 r
.35142 .58109 m .35145 .5811 L .35082 .58167 L F
.35145 .5811 m .35087 .58168 L .35082 .58167 L F
.579 .414 .622 r
.35125 .58103 m .3514 .58218 L .3515 .58116 L F
.35077 .5808 m .35082 .5809 L .35125 .58103 L F
.35082 .5809 m .3514 .58218 L .35125 .58103 L F
.35077 .5808 m .3515 .58116 L .35109 .5808 L F
.34705 .58081 m .3514 .58218 L .35077 .5808 L F
.288 .76 .937 r
.35031 .65696 m .35323 .65702 L .35277 .65724 L F
.35031 .65696 m .35323 .65702 L .35277 .65724 L F
.642 .852 .98 r
.3427 .60013 m .34432 .60123 L .34635 .60033 L F
.551 .813 .994 r
.26469 .71059 m .26491 .70851 L .26281 .70878 L F
0 0 .006 r
.26469 .71059 m .26685 .70786 L .26723 .70997 L F
.551 .813 .994 r
.26469 .71059 m .26723 .70997 L .26491 .70851 L F
.577 .597 .836 r
.26074 .72219 m .26149 .7182 L .2598 .71871 L F
.544 .36 .583 r
.26322 .71905 m .26324 .72184 L .26074 .72219 L F
.577 .597 .836 r
.26074 .72219 m .26324 .72184 L .26149 .7182 L F
.371 .75 .989 r
.2391 .62163 m .23902 .62294 L .23747 .62151 L F
.2391 .62163 m .24123 .62279 L .23902 .62294 L F
.721 .414 .458 r
.3346 .5421 m .33056 .54443 L .3332 .54034 L F
.3346 .5421 m .33357 .54474 L .33056 .54443 L F
0 0 .054 r
.33541 .54255 m .3346 .5421 L .33695 .54151 L F
.33541 .54255 m .33357 .54474 L .3346 .5421 L F
.019 0 .037 r
.30185 .58526 m .30116 .5874 L .299 .58845 L F
.769 .762 .25 r
.30273 .58126 m .30184 .58482 L .30185 .58526 L F
.769 .764 .254 r
.30184 .58482 m .30116 .5874 L .30185 .58526 L F
.292 .112 .457 r
.30053 .56381 m .30289 .56363 L .30288 .56294 L F
.30053 .56381 m .30023 .56655 L .30289 .56363 L F
0 0 .101 r
.29491 .5827 m .29443 .585 L .29598 .58125 L F
.307 0 0 r
.34005 .56707 m .33655 .56856 L .33605 .56646 L F
.34005 .56707 m .33866 .56869 L .33655 .56856 L F
.192 0 0 r
.34242 .56647 m .33866 .56869 L .34005 .56707 L F
.129 .187 .656 r
.33357 .54474 m .33299 .54732 L .33056 .54443 L F
.33357 .54474 m .33424 .54716 L .33299 .54732 L F
.481 .429 .722 r
.25253 .55097 m .2531 .5544 L .25507 .55354 L F
.25238 .55101 m .2531 .5544 L .25253 .55097 L F
.25232 .55075 m .25507 .55354 L .25459 .5504 L F
0 0 0 r
.25437 .55055 m .25178 .55126 L .2544 .55046 L F
.25457 .55041 m .2544 .55046 L .25459 .5504 L F
.25437 .55055 m .2544 .55046 L .25457 .55041 L F
.481 .429 .722 r
.25232 .55075 m .25238 .55101 L .25253 .55097 L F
.308 .068 .377 r
.2524 .5574 m .25507 .55354 L .2531 .5544 L F
.541 .549 .812 r
.39648 .55114 m .39745 .55399 L .39544 .55428 L F
.66 .379 .483 r
.39745 .55399 m .39454 .55646 L .39544 .55428 L F
.234 0 0 r
.23952 .63468 m .24185 .63495 L .23768 .6346 L F
.729 .498 .576 r
.52937 .53509 m .53263 .5327 L .53114 .5322 L F
.614 .583 .795 r
.32106 .59082 m .31934 .59202 L .31906 .5888 L F
0 0 .542 r
.32046 .59275 m .31934 .59202 L .32106 .59082 L F
.32046 .59275 m .32044 .59446 L .31934 .59202 L F
.409 .318 .641 r
.3245 .62893 m .32494 .63153 L .32683 .63102 L F
.32494 .63153 m .32496 .63167 L .32683 .63102 L F
.415 .809 .986 r
.32871 .6305 m .32683 .63102 L .32884 .63051 L F
.619 .063 0 r
.3245 .62893 m .32458 .629 L .32525 .6303 L F
.32458 .629 m .32683 .63102 L .32525 .6303 L F
.415 .809 .986 r
.32525 .6303 m .32683 .63102 L .32871 .6305 L F
.769 .651 .731 r
.32525 .6303 m .32884 .63051 L .32723 .62547 L F
0 0 .053 r
.32554 .63085 m .32525 .6303 L .3266 .62941 L F
.32439 .63241 m .32525 .6303 L .32554 .63085 L F
.619 .063 0 r
.3245 .62893 m .32525 .6303 L .32283 .62843 L F
.487 .401 .684 r
.35445 .58855 m .35697 .59067 L .35674 .58799 L F
.35445 .58855 m .35472 .59285 L .35697 .59067 L F
.737 .452 .496 r
.53509 .53296 m .53737 .53525 L .53892 .53227 L F
.767 .793 .874 r
.34782 .64759 m .34359 .64358 L .34653 .64372 L F
.34782 .64759 m .34367 .64656 L .34359 .64358 L F
.34782 .64759 m .3451 .64803 L .34367 .64656 L F
.505 .278 .504 r
.34782 .64759 m .34517 .65056 L .3451 .64803 L F
.34782 .64759 m .34778 .65021 L .34517 .65056 L F
.484 .615 .905 r
.34793 .64404 m .34782 .64759 L .34653 .64372 L F
.34793 .64404 m .35061 .6472 L .34782 .64759 L F
.281 .105 .456 r
.34952 .64945 m .34782 .64759 L .35061 .6472 L F
.34952 .64945 m .34778 .65021 L .34782 .64759 L F
.187 .715 .845 r
.25232 .55075 m .25006 .55058 L .2478 .55078 L F
.471 .811 .999 r
.32166 .53067 m .31959 .53118 L .31836 .53023 L F
.503 .361 .621 r
.31946 .65075 m .32176 .65039 L .32076 .64836 L F
.485 .295 .547 r
.31946 .65075 m .31938 .6534 L .32176 .65039 L F
.876 .981 .835 r
.2737 .61214 m .27186 .61568 L .27115 .61505 L F
.636 .389 .528 r
.34642 .59805 m .34922 .59744 L .34964 .59464 L F
.507 .479 .76 r
.35682 .5696 m .35974 .57273 L .35883 .56934 L F
.879 .887 .835 r
.2657 .71591 m .26322 .71905 L .26149 .7182 L F
.579 .406 .612 r
.2657 .71591 m .26593 .71884 L .26322 .71905 L F
.452 .288 .567 r
.26533 .72128 m .26322 .71905 L .26593 .71884 L F
.26533 .72128 m .26324 .72184 L .26322 .71905 L F
.508 .544 .828 r
.51068 .56312 m .51157 .55923 L .50926 .55961 L F
.51068 .56312 m .51298 .56261 L .51157 .55923 L F
.608 .257 .349 r
.31015 .65433 m .31309 .65356 L .30962 .65373 L F
.595 .582 .808 r
.3101 .65433 m .30887 .65634 L .31051 .65449 L F
.492 .427 .712 r
.30887 .65634 m .31009 .65774 L .31051 .65449 L F
.595 .582 .808 r
.30527 .65238 m .31051 .65449 L .30962 .65373 L F
.3 .318 .712 r
.31009 .65774 m .31138 .65575 L .31051 .65449 L F
.608 .257 .349 r
.31138 .65575 m .30962 .65373 L .31051 .65449 L F
.31138 .65575 m .31227 .65462 L .31015 .65433 L F
.31227 .65462 m .31309 .65356 L .31015 .65433 L F
.595 .582 .808 r
.30527 .65238 m .30662 .65386 L .3101 .65433 L F
.30662 .65386 m .30887 .65634 L .3101 .65433 L F
.389 0 0 r
.2828 .64387 m .28474 .64452 L .28082 .64372 L F
.729 .498 .576 r
.52937 .53509 m .53294 .53532 L .53263 .5327 L F
.407 .291 .608 r
.32127 .64444 m .32372 .6463 L .32312 .64349 L F
.32127 .64444 m .32076 .64836 L .32372 .6463 L F
.412 .138 .384 r
.18918 .55759 m .19086 .55929 L .19123 .55679 L F
.18918 .55759 m .18849 .55995 L .19086 .55929 L F
.683 .519 .659 r
.35531 .57645 m .35536 .57917 L .35812 .57607 L F
.275 .259 .66 r
.31423 .63382 m .31256 .63526 L .31223 .63196 L F
.17 .1 .53 r
.31444 .63721 m .31256 .63526 L .31423 .63382 L F
.31444 .63721 m .31279 .63793 L .31256 .63526 L F
.59 .633 .862 r
.26097 .54614 m .2647 .54825 L .26308 .54585 L F
.469 .027 .114 r
.26048 .55024 m .26264 .55025 L .2647 .54825 L F
.577 .708 .932 r
.26308 .54585 m .2647 .54825 L .26664 .54725 L F
.428 0 .083 r
.2647 .54825 m .26653 .5496 L .26664 .54725 L F
.2647 .54825 m .26264 .55025 L .26653 .5496 L F
.36 .35 .712 r
.50305 .55692 m .50496 .55703 L .504 .55301 L F
.01 .053 .558 r
.27985 .62771 m .27836 .62592 L .2804 .62457 L F
.27985 .62771 m .27923 .62936 L .27836 .62592 L F
.758 .913 .943 r
.34414 .53433 m .34257 .53515 L .34479 .5355 L F
0 0 .393 r
.34053 .54972 m .33986 .54904 L .33831 .54772 L F
.244 .467 .875 r
.23546 .61852 m .2347 .62035 L .23362 .61862 L F
.23546 .61852 m .23747 .62151 L .2347 .62035 L F
.167 0 0 r
.50471 .54136 m .50922 .53996 L .50488 .54118 L F
.579 .613 .851 r
.36486 .53258 m .36605 .52912 L .3637 .53023 L F
.36486 .53258 m .36728 .53204 L .36605 .52912 L F
.441 .198 .449 r
.36486 .53258 m .36684 .53429 L .36728 .53204 L F
.36486 .53258 m .3644 .53498 L .36684 .53429 L F
.15 .013 .426 r
.37652 .54203 m .37779 .54329 L .37792 .54038 L F
.37652 .54203 m .37633 .54448 L .37779 .54329 L F
.647 .114 0 r
.28982 .64231 m .2915 .64168 L .28775 .64064 L F
.459 0 0 r
.29384 .6427 m .2915 .64168 L .28982 .64231 L F
.479 .106 .253 r
.29384 .6427 m .29407 .64135 L .2915 .64168 L F
.596 .92 .971 r
.24663 .63527 m .24812 .63499 L .24615 .63504 L F
.097 0 0 r
.24812 .63499 m .24899 .63542 L .24615 .63504 L F
0 .543 .801 r
.2455 .63473 m .24615 .63504 L .24899 .63542 L F
.24446 .63452 m .24615 .63504 L .2455 .63473 L F
.596 .92 .971 r
.24421 .63572 m .24663 .63527 L .24615 .63504 L F
.097 0 0 r
.24812 .63499 m .25022 .63489 L .24899 .63542 L F
.519 .848 .562 r
.36601 .52357 m .36704 .52249 L .36797 .52295 L F
.36601 .52357 m .36376 .5255 L .36704 .52249 L F
.487 .51 .807 r
.36958 .52644 m .36601 .52357 L .36797 .52295 L F
.532 .415 .666 r
.33098 .64687 m .33159 .65046 L .3291 .65088 L F
.549 .377 .601 r
.33168 .65305 m .3291 .65088 L .33159 .65046 L F
.33168 .65305 m .32927 .65362 L .3291 .65088 L F
.581 .311 .471 r
.53294 .53532 m .5348 .53525 L .53509 .53296 L F
.737 .452 .496 r
.53509 .53296 m .5348 .53525 L .53737 .53525 L F
0 0 0 r
.35037 .55734 m .34708 .55965 L .34793 .55873 L F
.485 .32 .582 r
.38105 .5816 m .37903 .58519 L .37875 .58203 L F
.553 .357 .57 r
.38654 .57818 m .38461 .5762 L .38719 .57614 L F
.38654 .57818 m .3843 .5787 L .38461 .5762 L F
0 0 0 r
.20643 .79279 m .20538 .7955 L .20738 .79496 L F
.331 .157 .488 r
.38672 .56003 m .38651 .56348 L .38459 .56365 L F
.343 .172 .499 r
.38651 .56348 m .3842 .56627 L .38459 .56365 L F
.581 .389 .586 r
.35472 .59285 m .35802 .59412 L .35697 .59067 L F
.35472 .59285 m .35534 .59453 L .35802 .59412 L F
.757 .622 .71 r
.36126 .60952 m .36618 .61094 L .36468 .60709 L F
.553 .515 .767 r
.36468 .60709 m .36618 .61094 L .36679 .60996 L F
.74 .73 .842 r
.34242 .56647 m .34635 .56725 L .34477 .56423 L F
.332 .074 .364 r
.34635 .56725 m .34866 .56662 L .34826 .56523 L F
.545 .391 .622 r
.3221 .54642 m .3196 .5472 L .32144 .54494 L F
.441 .084 .262 r
.3221 .54642 m .31806 .54996 L .3196 .5472 L F
.246 .141 .531 r
.17135 .58192 m .17271 .5785 L .17128 .5792 L F
.443 .736 .99 r
.19713 .59031 m .19893 .59135 L .19637 .59181 L F
.739 .343 .3 r
.27916 .55075 m .27822 .55096 L .27761 .54873 L F
.838 .622 .611 r
.27997 .54801 m .27916 .55075 L .27761 .54873 L F
.879 .887 .835 r
.2657 .71591 m .26149 .7182 L .26379 .71775 L F
.25 0 0 r
.26569 .71747 m .2657 .71591 L .26379 .71775 L F
.755 .567 0 r
.26569 .71747 m .26593 .71884 L .2657 .71591 L F
.429 .505 .835 r
.29797 .62616 m .30125 .62891 L .29731 .62829 L F
.29797 .62616 m .29731 .62829 L .29993 .62578 L F
.812 .936 .911 r
.52606 .56356 m .5275 .56457 L .52929 .56267 L F
.187 .719 .75 r
.25416 .5326 m .25646 .53212 L .25791 .53192 L F
.205 .73 .742 r
.25646 .53212 m .26019 .53133 L .25791 .53192 L F
.397 .371 .713 r
.33977 .63114 m .33708 .62873 L .3399 .62859 L F
.333 .374 .754 r
.30059 .5697 m .30289 .56853 L .30023 .56655 L F
.174 .024 .425 r
.3006 .57206 m .30289 .56853 L .30059 .5697 L F
.212 .628 .952 r
.31228 .58821 m .31202 .58936 L .31079 .58879 L F
.31228 .58821 m .31463 .58968 L .31202 .58936 L F
.802 .687 .738 r
.21276 .56354 m .21732 .56492 L .21568 .56156 L F
.922 .853 .757 r
.21276 .56354 m .21327 .56614 L .21732 .56492 L F
.754 .669 .767 r
.21568 .56156 m .21732 .56492 L .21908 .56327 L F
0 0 .286 r
.283 .55591 m .2821 .55457 L .28394 .5536 L F
.283 .55591 m .28192 .55766 L .2821 .55457 L F
.505 .319 .562 r
.32812 .61663 m .33049 .6161 L .33053 .61334 L F
.462 .204 .436 r
.33006 .61844 m .32812 .61663 L .32766 .61891 L F
.33006 .61844 m .33049 .6161 L .32812 .61663 L F
.305 .011 .29 r
.29636 .54425 m .29755 .54637 L .29877 .54452 L F
.29636 .54425 m .29535 .54741 L .29755 .54637 L F
.411 .733 .991 r
.38836 .57469 m .38719 .57614 L .38573 .57252 L F
.38836 .57469 m .38986 .57596 L .38719 .57614 L F
0 0 .189 r
.38836 .57469 m .38719 .57614 L .38986 .57596 L F
.38836 .57469 m .38654 .57818 L .38719 .57614 L F
.275 .259 .66 r
.31423 .63382 m .31223 .63196 L .3142 .63138 L F
.852 .831 .358 r
.23252 .74909 m .23169 .75355 L .23083 .75231 L F
.177 0 0 r
.23169 .75355 m .23464 .75369 L .23269 .75397 L F
.23169 .75355 m .23269 .75397 L .23083 .75231 L F
.922 .853 .757 r
.21276 .56354 m .21195 .56608 L .21327 .56614 L F
.106 0 0 r
.23294 .55135 m .23148 .5533 L .22934 .55398 L F
0 0 0 r
.23317 .55217 m .23294 .55135 L .23528 .551 L F
.23317 .55217 m .23148 .5533 L .23294 .55135 L F
.076 0 0 r
.24185 .63495 m .23997 .63481 L .23768 .6346 L F
0 .441 .779 r
.24185 .63495 m .24235 .63484 L .23997 .63481 L F
.24185 .63495 m .24421 .63572 L .24235 .63484 L F
.99 .819 .439 r
.3451 .64803 m .34517 .65056 L .34424 .64839 L F
.995 .865 .543 r
.34517 .65056 m .34321 .65201 L .34424 .64839 L F
.166 .29 .746 r
.34751 .6526 m .34517 .65056 L .34778 .65021 L F
.13 0 0 r
.23277 .53584 m .23243 .53593 L .23504 .53524 L F
.23277 .53584 m .2311 .53569 L .23243 .53593 L F
.608 .217 .278 r
.25662 .55699 m .25529 .55936 L .25309 .55864 L F
.999 .838 .511 r
.25513 .55692 m .25529 .55936 L .25662 .55699 L F
.552 .357 .571 r
.3118 .56008 m .30965 .56317 L .30937 .56061 L F
0 .268 .648 r
.33244 .66619 m .33604 .66801 L .33551 .66599 L F
.527 .61 .879 r
.19406 .61061 m .19448 .60711 L .19284 .60683 L F
.19406 .61061 m .19622 .61023 L .19448 .60711 L F
0 0 0 r
.30785 .6442 m .30963 .64272 L .31197 .64091 L F
.754 .669 .767 r
.21568 .56156 m .21908 .56327 L .21749 .56028 L F
.887 .799 .756 r
.21749 .56028 m .21908 .56327 L .21944 .56166 L F
.549 .328 .533 r
.3843 .5787 m .38105 .5816 L .38131 .57929 L F
.629 .442 .611 r
.35536 .57917 m .35769 .57874 L .35812 .57607 L F
.401 .274 .59 r
.35812 .57607 m .36012 .57565 L .35974 .57273 L F
.707 .663 .805 r
.35769 .57874 m .36012 .57565 L .35812 .57607 L F
0 0 0 r
.34716 .62241 m .3443 .62354 L .34827 .62238 L F
.34716 .62241 m .34429 .6245 L .3443 .62354 L F
.284 .523 .907 r
.28605 .54302 m .28562 .53951 L .28299 .54026 L F
.28605 .54302 m .28716 .54292 L .28562 .53951 L F
.332 .798 .693 r
.28605 .54302 m .28482 .54332 L .28716 .54292 L F
.425 .331 .645 r
.37126 .54843 m .37367 .55025 L .37269 .54613 L F
.363 .335 .693 r
.37126 .54843 m .37214 .55132 L .37367 .55025 L F
.286 .1 .445 r
.28524 .60037 m .2871 .59722 L .28525 .59795 L F
.127 0 0 r
.19123 .55679 m .1932 .55622 L .19473 .55431 L F
.169 0 0 r
.1932 .55622 m .19675 .55347 L .19473 .55431 L F
.478 .177 .377 r
.32457 .54217 m .32412 .54424 L .32172 .54465 L F
.834 .612 .602 r
.35718 .63232 m .35808 .63599 L .35329 .63421 L F
.307 .422 .816 r
.35873 .63086 m .36035 .63479 L .35718 .63232 L F
.78 .779 .852 r
.3842 .56627 m .38257 .56856 L .3824 .56767 L F
.247 0 .157 r
.27419 .69662 m .27714 .69431 L .27592 .6961 L F
.362 .074 .334 r
.27592 .6961 m .27714 .69431 L .2794 .69342 L F
0 .403 .738 r
.34826 .56523 m .3527 .56661 L .35269 .56688 L F
.38 .1 .357 r
.34866 .56662 m .3527 .56661 L .34826 .56523 L F
.812 .371 0 r
.32047 .596 m .32044 .59446 L .32046 .59275 L F
.32047 .596 m .32169 .59712 L .32044 .59446 L F
.324 .203 .557 r
.2871 .59722 m .28933 .5936 L .28737 .59466 L F
.135 .628 .912 r
.2585 .63776 m .25858 .63708 L .25658 .63678 L F
.2585 .63776 m .26039 .63791 L .25858 .63708 L F
0 0 0 r
.31159 .60549 m .31089 .60292 L .31448 .60302 L F
.123 .251 .725 r
.33695 .54151 m .33805 .54513 L .33918 .5433 L F
.534 .365 .598 r
.33805 .54513 m .34073 .54695 L .33918 .5433 L F
.665 .369 .461 r
.36086 .53736 m .3644 .53498 L .36198 .53574 L F
.354 .199 .528 r
.33053 .61334 m .33244 .6153 L .33294 .61283 L F
.33053 .61334 m .33049 .6161 L .33244 .6153 L F
.608 .893 .989 r
.24525 .74614 m .24356 .74726 L .2437 .74562 L F
.119 .288 .761 r
.30549 .6321 m .30533 .62826 L .30361 .62837 L F
.30549 .6321 m .30681 .63167 L .30533 .62826 L F
.086 .178 .664 r
.30549 .6321 m .30742 .63391 L .30681 .63167 L F
.439 .197 .449 r
.30549 .6321 m .30514 .63451 L .30742 .63391 L F
.513 .331 .571 r
.37667 .58852 m .3767 .59117 L .37427 .59169 L F
.541 .445 .694 r
.3767 .59117 m .37481 .5944 L .37427 .59169 L F
.439 .16 .392 r
.18557 .56284 m .18849 .55995 L .18642 .56064 L F
.787 .676 .741 r
.20541 .58852 m .20147 .58802 L .20385 .58479 L F
.664 .182 .097 r
.20541 .58852 m .20277 .58951 L .20147 .58802 L F
.698 .919 .585 r
.20789 .58537 m .20541 .58852 L .20385 .58479 L F
.20789 .58537 m .20601 .58721 L .20541 .58852 L F
.674 .976 .832 r
.20601 .58721 m .20277 .58951 L .20541 .58852 L F
.505 .667 .935 r
.20865 .59865 m .20813 .60094 L .20671 .59895 L F
.20865 .59865 m .21034 .60061 L .20813 .60094 L F
.145 .33 .791 r
.35616 .61005 m .35737 .60896 L .35443 .60668 L F
.063 .187 .682 r
.35616 .61005 m .3581 .6124 L .35737 .60896 L F
.35 .331 .697 r
.53696 .55638 m .53548 .55754 L .53443 .55444 L F
.643 .275 .33 r
.32159 .56818 m .32586 .56625 L .32376 .56706 L F
.053 .616 .785 r
.35269 .56688 m .3527 .56661 L .34866 .56662 L F
.491 .298 .547 r
.35269 .56688 m .35461 .56728 L .35518 .5636 L F
.2 .714 .886 r
.26308 .54585 m .25865 .54566 L .26097 .54614 L F
.402 .679 .973 r
.30326 .52813 m .30252 .52974 L .3009 .52802 L F
.415 .694 .977 r
.30326 .52813 m .30482 .52963 L .30252 .52974 L F
.532 0 0 r
.30111 .53972 m .30166 .54075 L .30022 .54129 L F
.30111 .53972 m .30431 .54152 L .30166 .54075 L F
0 .156 .675 r
.33921 .6358 m .33821 .63567 L .33952 .63456 L F
.266 .077 .428 r
.30605 .54776 m .30591 .55067 L .30376 .55131 L F
.386 .259 .584 r
.30615 .55313 m .30376 .55131 L .30591 .55067 L F
.30615 .55313 m .30423 .5541 L .30376 .55131 L F
.513 .366 .618 r
.32076 .64836 m .32377 .64992 L .32372 .6463 L F
.32076 .64836 m .32176 .65039 L .32377 .64992 L F
.154 .69 .693 r
.30005 .5513 m .29553 .55228 L .29774 .55192 L F
.934 .951 .771 r
.53696 .55638 m .53592 .56045 L .53548 .55754 L F
.53696 .55638 m .53497 .55967 L .53592 .56045 L F
.097 0 0 r
.2079 .57021 m .2059 .5715 L .20347 .57201 L F
0 0 0 r
.20786 .57041 m .2079 .57021 L .21011 .56943 L F
.20786 .57041 m .2059 .5715 L .2079 .57021 L F
.475 .633 .923 r
.31167 .54181 m .31379 .54149 L .31269 .53955 L F
.396 0 0 r
.30853 .60042 m .30952 .60172 L .30698 .60111 L F
.232 .478 .887 r
.30874 .60112 m .30698 .60111 L .30952 .60172 L F
.817 .765 .804 r
.3063 .6011 m .30853 .60042 L .30698 .60111 L F
.699 .574 .711 r
.30656 .5997 m .31007 .59882 L .31002 .59406 L F
.397 .852 .885 r
.30749 .5986 m .30656 .5997 L .30625 .59921 L F
.30749 .5986 m .31007 .59882 L .30656 .5997 L F
.232 .478 .887 r
.30625 .59921 m .30698 .60111 L .30874 .60112 L F
.817 .765 .804 r
.30479 .60157 m .3063 .6011 L .30698 .60111 L F
.396 0 0 r
.30853 .60042 m .31101 .60053 L .30952 .60172 L F
.594 .626 .853 r
.1708 .59488 m .17511 .59762 L .17498 .59654 L F
0 .276 .78 r
.17511 .59762 m .17535 .59621 L .17498 .59654 L F
.22 .564 .937 r
.17517 .59726 m .17655 .5977 L .17535 .59621 L F
.738 .992 .836 r
.17661 .59778 m .17712 .59614 L .17535 .59621 L F
.17661 .59778 m .17606 .59747 L .17712 .59614 L F
.351 .689 .981 r
.17606 .59747 m .18002 .59882 L .18187 .59938 L F
.18002 .59882 m .18314 .59988 L .18231 .59955 L F
.086 .618 .865 r
.18187 .59938 m .18467 .59989 L .18361 .59809 L F
.77 .719 .186 r
.18212 .59935 m .18187 .59938 L .18361 .59809 L F
.351 .689 .981 r
.1818 .59939 m .18231 .59955 L .18187 .59938 L F
.17606 .59747 m .18312 .60047 L .18314 .59988 L F
.77 .719 .186 r
.1816 .59979 m .18187 .59938 L .18212 .59935 L F
.351 .689 .981 r
.18002 .59882 m .1818 .59939 L .18187 .59938 L F
.22 .564 .937 r
.17511 .59762 m .17661 .59778 L .17655 .5977 L F
.17511 .59762 m .17655 .5977 L .17517 .59726 L F
.342 .471 .846 r
.35934 .61972 m .35831 .62287 L .35666 .61965 L F
.248 .366 .787 r
.35934 .61972 m .36097 .62479 L .35831 .62287 L F
0 0 .282 r
.36089 .6207 m .36097 .62479 L .35934 .61972 L F
.568 0 0 r
.35915 .61942 m .36089 .6207 L .35934 .61972 L F
.35915 .61942 m .36089 .6207 L .35934 .61972 L F
.217 .201 .625 r
.36273 .61901 m .36089 .6207 L .36073 .61954 L F
.36273 .61901 m .36073 .61954 L .36048 .61782 L F
.195 .184 .618 r
.36048 .61782 m .36089 .6207 L .36133 .61956 L F
.596 .172 .208 r
.36048 .61782 m .3594 .61587 L .36136 .61539 L F
.36048 .61782 m .35782 .61789 L .3594 .61587 L F
0 0 .029 r
.36134 .61689 m .36048 .61782 L .36126 .61566 L F
.36134 .61689 m .36126 .61566 L .36136 .61539 L F
.813 .64 .668 r
.35951 .61638 m .3614 .61793 L .36134 .61689 L F
.217 .201 .625 r
.36273 .61901 m .36048 .61782 L .36134 .61689 L F
.813 .64 .668 r
.3614 .61793 m .36273 .61901 L .36134 .61689 L F
.195 .184 .618 r
.36048 .61782 m .36133 .61956 L .35782 .61789 L F
.075 .142 .63 r
.35782 .61789 m .35589 .61544 L .3594 .61587 L F
.823 .347 .058 r
.36133 .61956 m .35716 .61627 L .35782 .61789 L F
.36133 .61956 m .3585 .61875 L .35716 .61627 L F
.813 .64 .668 r
.35951 .61638 m .3585 .61875 L .36265 .61901 L F
.36264 .61894 m .36265 .61901 L .36273 .61901 L F
.35951 .61638 m .36265 .61901 L .36264 .61894 L F
.399 .853 .883 r
.36123 .61922 m .36391 .6187 L .36273 .61901 L F
.571 .548 .79 r
.36537 .61842 m .36273 .61901 L .36443 .61627 L F
.36443 .61627 m .36273 .61901 L .36537 .61842 L F
.36537 .61842 m .36273 .61901 L .36443 .61627 L F
.36537 .61842 m .36273 .61901 L .36443 .61627 L F
.399 .853 .883 r
.36391 .6187 m .36537 .61842 L .36273 .61901 L F
.288 0 0 r
.35934 .61972 m .35827 .62092 L .36088 .61976 L F
.35934 .61972 m .36088 .61976 L .36133 .61956 L F
.342 .471 .846 r
.35934 .61972 m .35666 .61965 L .3566 .61954 L F
.408 .37 .704 r
.36097 .62479 m .35934 .62589 L .35831 .62287 L F
0 .198 .659 r
.30625 .59921 m .30656 .5997 L .30393 .59771 L F
.483 .875 .966 r
.2417 .54726 m .24208 .54611 L .2439 .54672 L F
.77 .357 .267 r
.2417 .54726 m .24377 .55025 L .23979 .54915 L F
.795 .352 .192 r
.24578 .5502 m .24377 .55025 L .2417 .54726 L F
.227 0 .169 r
.30899 .62217 m .30686 .62307 L .30599 .62494 L F
.257 .074 .431 r
.19767 .57747 m .19603 .57613 L .19877 .57522 L F
.19767 .57747 m .19569 .5786 L .19603 .57613 L F
0 .347 .797 r
.27044 .69406 m .27419 .69662 L .27274 .69358 L F
.636 .681 .875 r
.27419 .69662 m .27507 .69298 L .27274 .69358 L F
.27419 .69662 m .27592 .6961 L .27507 .69298 L F
.228 .709 .933 r
.20385 .58479 m .20721 .58492 L .20789 .58537 L F
.668 .954 .95 r
.20789 .58537 m .20721 .58492 L .20839 .58381 L F
.573 .725 .945 r
.20839 .58381 m .20721 .58492 L .20609 .58348 L F
.978 .917 .618 r
.20621 .58418 m .20789 .58537 L .20839 .58381 L F
.518 .699 .952 r
.20609 .58348 m .20721 .58492 L .20385 .58479 L F
.978 .917 .618 r
.20621 .58418 m .20601 .58721 L .20789 .58537 L F
.373 .484 .843 r
.21342 .6021 m .21196 .604 L .21034 .60061 L F
.121 .127 .591 r
.21342 .6021 m .21362 .6062 L .21196 .604 L F
.649 .462 .618 r
.36172 .56303 m .36516 .56284 L .36463 .56065 L F
.377 .732 .99 r
.36516 .56284 m .36525 .5589 L .36463 .56065 L F
.6 .474 .681 r
.3333 .64382 m .33098 .64687 L .33081 .64442 L F
.521 .811 .999 r
.22155 .61435 m .22103 .61601 L .21939 .61468 L F
.22155 .61435 m .22336 .61549 L .22103 .61601 L F
.123 0 .371 r
.30116 .5874 m .29883 .59108 L .299 .58845 L F
.463 .346 .635 r
.35113 .60348 m .35298 .60049 L .35038 .60115 L F
.35113 .60348 m .35329 .60294 L .35298 .60049 L F
.16 0 .153 r
.37317 .60646 m .3712 .60899 L .37132 .60725 L F
.591 .182 .235 r
.2406 .55955 m .24016 .56163 L .23779 .5599 L F
.281 0 0 r
.23779 .5599 m .23853 .56052 L .2406 .55955 L F
0 0 0 r
.2406 .55955 m .24113 .55965 L .24315 .55789 L F
.2406 .55955 m .23853 .56052 L .24113 .55965 L F
.122 .645 .881 r
.24573 .6232 m .24513 .62372 L .24347 .62304 L F
.24573 .6232 m .24798 .62385 L .24513 .62372 L F
.482 .445 .739 r
.34044 .61887 m .33839 .61947 L .33742 .6156 L F
.392 .186 .476 r
.34044 .61887 m .33814 .62236 L .33839 .61947 L F
.34044 .61887 m .33814 .62236 L .33839 .61947 L F
.674 .309 .346 r
.54199 .54511 m .54082 .54722 L .54382 .5467 L F
.543 .68 .928 r
.2063 .61573 m .20867 .6188 L .21123 .6177 L F
.471 .665 .947 r
.20867 .6188 m .21179 .6198 L .21123 .6177 L F
0 0 .371 r
.34299 .60818 m .34219 .6068 L .34278 .60564 L F
.34299 .60818 m .3423 .61001 L .34219 .6068 L F
.609 .676 .889 r
.20043 .58388 m .19798 .58495 L .19575 .58146 L F
.596 .627 .852 r
.20043 .58388 m .20193 .58553 L .19798 .58495 L F
.698 .486 .597 r
.20147 .58802 m .19798 .58495 L .20193 .58553 L F
.20147 .58802 m .20047 .58919 L .19798 .58495 L F
.199 0 .123 r
.29724 .59762 m .29424 .60016 L .29516 .59862 L F
0 0 .288 r
.35518 .5636 m .35632 .56492 L .35786 .56238 L F
.35518 .5636 m .35461 .56728 L .35632 .56492 L F
.492 .234 .451 r
.36417 .60873 m .36126 .60952 L .36468 .60709 L F
.432 .091 .286 r
.36681 .60818 m .36417 .60873 L .36468 .60709 L F
.304 0 0 r
.30278 .65357 m .30527 .65238 L .3056 .65318 L F
0 0 .252 r
.3056 .65318 m .30527 .65238 L .30487 .65006 L F
.828 .952 .899 r
.25133 .62249 m .24798 .62385 L .24981 .62371 L F
.138 0 0 r
.24981 .62371 m .25392 .62185 L .25133 .62249 L F
.825 .893 .89 r
.21956 .55885 m .21944 .56166 L .22151 .55982 L F
.887 .799 .756 r
.21749 .56028 m .21944 .56166 L .21956 .55885 L F
.363 .184 .499 r
.33655 .56856 m .33657 .57218 L .33411 .57297 L F
.309 .138 .48 r
.33619 .57436 m .33411 .57297 L .33657 .57218 L F
.33619 .57436 m .33394 .57536 L .33411 .57297 L F
0 0 0 r
.35933 .53856 m .35898 .53887 L .36086 .53736 L F
.581 .46 .68 r
.36246 .54178 m .35933 .53856 L .3609 .53833 L F
.36246 .54178 m .3601 .54262 L .35933 .53856 L F
.308 .406 .799 r
.21448 .60828 m .21577 .61202 L .21324 .61022 L F
.214 .06 .445 r
.31927 .60944 m .31907 .61242 L .31676 .61345 L F
0 0 .311 r
.31796 .61417 m .31676 .61345 L .31907 .61242 L F
.31796 .61417 m .31655 .61652 L .31676 .61345 L F
.585 .613 .846 r
.21969 .62587 m .22379 .6287 L .22143 .6256 L F
.477 0 0 r
.226 .62823 m .22143 .6256 L .22379 .6287 L F
.225 .746 .82 r
.26944 .52992 m .27174 .52951 L .27328 .52948 L F
.139 .674 .855 r
.2733 .52901 m .27328 .52948 L .27174 .52951 L F
.2733 .52901 m .27557 .52944 L .27328 .52948 L F
.592 .886 .991 r
.51681 .56314 m .51766 .56146 L .51536 .56239 L F
.51681 .56314 m .51929 .56224 L .51766 .56146 L F
.91 .74 .244 r
.31002 .59406 m .31007 .59882 L .30916 .59497 L F
.953 .948 .72 r
.30916 .59497 m .31007 .59882 L .30749 .5986 L F
0 0 .233 r
.29144 .60595 m .29161 .6032 L .29188 .60343 L F
.29144 .60595 m .29068 .60739 L .29161 .6032 L F
.432 0 .104 r
.29075 .5436 m .28818 .54406 L .28873 .54263 L F
.718 .322 .296 r
.24565 .74373 m .24794 .74616 L .24525 .74614 L F
.146 0 0 r
.24613 .74492 m .24565 .74373 L .24525 .74614 L F
.24613 .74492 m .24849 .74274 L .24565 .74373 L F
.308 .477 .864 r
.33147 .60684 m .33328 .61017 L .3345 .60918 L F
.692 .434 .529 r
.34452 .52927 m .34016 .53205 L .3424 .53176 L F
.619 .307 .421 r
.34452 .52927 m .3424 .53176 L .34678 .53145 L F
.515 .345 .589 r
.37903 .58519 m .37917 .58809 L .37667 .58852 L F
.591 .392 .581 r
.37943 .59079 m .37667 .58852 L .37917 .58809 L F
.37943 .59079 m .3767 .59117 L .37667 .58852 L F
.432 .519 .847 r
.35536 .57917 m .35864 .5816 L .35769 .57874 L F
.578 .243 .365 r
.33703 .64449 m .33338 .64642 L .3333 .64382 L F
.33703 .64449 m .33666 .64656 L .33338 .64642 L F
.702 .821 .938 r
.33571 .64246 m .33703 .64449 L .34005 .64333 L F
0 0 .151 r
.33814 .6451 m .33703 .64449 L .33571 .64246 L F
.33814 .6451 m .33666 .64656 L .33703 .64449 L F
.088 .64 .817 r
.31671 .55357 m .31907 .55358 L .32105 .55386 L F
0 0 .48 r
.32121 .55306 m .32105 .55386 L .31907 .55358 L F
.32121 .55306 m .3227 .55656 L .32105 .55386 L F
.062 .088 .575 r
.32105 .55386 m .3227 .55656 L .32176 .55725 L F
.541 .445 .694 r
.3767 .59117 m .37721 .59388 L .37481 .5944 L F
.346 .236 .583 r
.37691 .59655 m .37481 .5944 L .37721 .59388 L F
.37691 .59655 m .37548 .5976 L .37481 .5944 L F
.693 .565 .707 r
.34255 .58961 m .34086 .59052 L .34381 .58775 L F
.545 .391 .622 r
.3221 .54642 m .32144 .54494 L .32172 .54465 L F
.177 .71 .828 r
.26262 .53053 m .26487 .53031 L .26702 .53044 L F
.448 .875 .923 r
.26702 .53044 m .26721 .52952 L .26944 .52992 L F
.26702 .53044 m .26487 .53031 L .26721 .52952 L F
.635 .768 .943 r
.24973 .73669 m .24801 .73767 L .25004 .73792 L F
.679 .262 .246 r
.33408 .53167 m .33997 .53259 L .33871 .53082 L F
.605 .25 .341 r
.33871 .53082 m .33997 .53259 L .34016 .53205 L F
.675 .464 .591 r
.29963 .5967 m .2973 .59457 L .29954 .59394 L F
.29963 .5967 m .29724 .59762 L .2973 .59457 L F
.273 .047 .378 r
.37633 .54448 m .37471 .54617 L .37822 .54378 L F
.338 .126 .438 r
.37528 .54935 m .37822 .54378 L .37471 .54617 L F
0 0 .507 r
.30762 .59054 m .30953 .59334 L .30899 .59224 L F
.929 .83 .377 r
.30899 .59224 m .30841 .59199 L .30858 .5914 L F
.485 .89 .759 r
.30762 .59054 m .31079 .58879 L .30858 .58799 L F
.30762 .59054 m .30916 .58936 L .31079 .58879 L F
.929 .83 .377 r
.30899 .59224 m .30916 .58936 L .30762 .59054 L F
.30899 .59224 m .30858 .5914 L .30916 .58936 L F
0 0 .507 r
.30953 .59334 m .31002 .59406 L .30899 .59224 L F
.91 .74 .244 r
.31002 .59406 m .30916 .59497 L .30899 .59224 L F
.275 .013 .323 r
.28258 .61893 m .28031 .61968 L .28115 .61868 L F
.216 0 .342 r
.28258 .61893 m .28088 .62088 L .28031 .61968 L F
.275 .013 .323 r
.28258 .61893 m .28115 .61868 L .28321 .61679 L F
.518 .229 .414 r
.22934 .55398 m .22617 .55652 L .2268 .55452 L F
.581 .739 .951 r
.1788 .60083 m .17606 .59747 L .17661 .59778 L F
.1788 .60083 m .18312 .60047 L .17606 .59747 L F
.581 .393 .592 r
.32204 .63487 m .32492 .63464 L .32496 .63167 L F
.476 .31 .576 r
.32204 .63487 m .32448 .63696 L .32492 .63464 L F
.32204 .63487 m .32217 .63742 L .32448 .63696 L F
.586 .634 .865 r
.34332 .54914 m .34619 .55379 L .34032 .55361 L F
.452 .376 .68 r
.3447 .55584 m .34032 .55361 L .34619 .55379 L F
.3447 .55584 m .34239 .55671 L .34032 .55361 L F
.665 .705 .878 r
.36172 .56303 m .35786 .56238 L .35958 .56069 L F
.292 .579 .94 r
.35958 .56069 m .36254 .56181 L .36172 .56303 L F
.61 .314 .441 r
.36172 .56303 m .36323 .56605 L .36516 .56284 L F
.377 .732 .99 r
.36516 .56284 m .36785 .56342 L .36642 .56228 L F
0 0 .015 r
.36516 .56284 m .36642 .56228 L .36785 .56342 L F
.377 .732 .99 r
.36516 .56284 m .36642 .56228 L .36525 .5589 L F
0 0 .015 r
.36516 .56284 m .36323 .56605 L .36642 .56228 L F
.36516 .56284 m .36323 .56605 L .36642 .56228 L F
0 0 .543 r
.36228 .5622 m .36323 .56605 L .36172 .56303 L F
.36272 .56294 m .36323 .56605 L .36228 .5622 L F
.36254 .56181 m .36272 .56294 L .36228 .5622 L F
.514 .556 .836 r
.35786 .56238 m .36252 .56303 L .35958 .56069 L F
.047 0 0 r
.35786 .56238 m .35863 .5639 L .36159 .56324 L F
.35947 .5626 m .36159 .56324 L .36252 .56303 L F
.35786 .56238 m .36159 .56324 L .35947 .5626 L F
.516 .556 .835 r
.35958 .56069 m .36252 .56303 L .36254 .56181 L F
.748 .318 .231 r
.36252 .56303 m .35863 .5639 L .36199 .56408 L F
.36252 .56303 m .36199 .56408 L .36254 .56181 L F
.973 .766 .565 r
.36199 .56408 m .36323 .56605 L .36254 .56181 L F
.751 .511 .569 r
.36525 .5589 m .36642 .56228 L .36254 .56181 L F
.401 .17 .446 r
.36466 .56166 m .36254 .56181 L .36642 .56228 L F
.36254 .56181 m .36215 .56341 L .36466 .56166 L F
.36215 .56341 m .36199 .56408 L .36258 .56354 L F
.36215 .56341 m .36258 .56354 L .36466 .56166 L F
.837 .787 .803 r
.36642 .56228 m .36323 .56605 L .36199 .56408 L F
.36642 .56228 m .36313 .56361 L .36489 .56416 L F
.36313 .56361 m .36199 .56408 L .36343 .56412 L F
.36313 .56361 m .36343 .56412 L .36489 .56416 L F
.546 .041 .007 r
.30615 .55313 m .30221 .55298 L .30423 .5541 L F
.595 .047 0 r
.30493 .55411 m .30426 .55399 L .30221 .55298 L F
.2 .323 .765 r
.3003 .55203 m .30113 .55458 L .30221 .55298 L F
.628 .61 .813 r
.30113 .55458 m .30423 .5541 L .30221 .55298 L F
.595 .047 0 r
.30426 .55399 m .30097 .55338 L .30221 .55298 L F
.2 .323 .765 r
.30005 .5513 m .3003 .55203 L .30221 .55298 L F
.412 .016 .175 r
.29489 .62847 m .2935 .63097 L .29104 .63112 L F
0 0 .412 r
.29542 .62755 m .29489 .62847 L .29529 .62853 L F
.082 0 .005 r
.29546 .62996 m .29489 .62847 L .29542 .62755 L F
.29546 .62996 m .2935 .63097 L .29489 .62847 L F
.58 .362 .548 r
.3176 .62571 m .31672 .62842 L .31416 .62866 L F
.632 .495 .677 r
.31986 .62469 m .31672 .62842 L .3176 .62571 L F
.008 0 0 r
.20474 .54727 m .20678 .54669 L .20873 .54524 L F
.023 0 0 r
.20873 .54524 m .20898 .54603 L .21099 .54466 L F
.20873 .54524 m .20678 .54669 L .20898 .54603 L F
.333 .057 .337 r
.20276 .54777 m .20414 .54964 L .20474 .54727 L F
.20276 .54777 m .20204 .55046 L .20414 .54964 L F
.391 .241 .556 r
.32496 .63167 m .3272 .63388 L .32683 .63102 L F
.32496 .63167 m .32492 .63464 L .3272 .63388 L F
.427 .241 .524 r
.34907 .6562 m .34846 .65882 L .34638 .65715 L F
.191 .374 .816 r
.21559 .62143 m .21565 .62274 L .21657 .62111 L F
.29 .504 .891 r
.21565 .62274 m .219 .62458 L .21657 .62111 L F
.14 0 .13 r
.18113 .56677 m .18013 .5687 L .18296 .56589 L F
.389 .834 .716 r
.25169 .54353 m .24928 .54479 L .25017 .54446 L F
.446 .153 .373 r
.24849 .5462 m .25169 .54353 L .25017 .54446 L F
.453 .456 .772 r
.38618 .53458 m .38518 .53882 L .38461 .53494 L F
.38618 .53458 m .38729 .53837 L .38518 .53882 L F
.461 .51 .822 r
.38729 .53837 m .3884 .54044 L .38518 .53882 L F
.561 .345 .544 r
.38989 .56186 m .38672 .56003 L .38906 .5596 L F
.38989 .56186 m .38651 .56348 L .38672 .56003 L F
.499 .835 .998 r
.31796 .54179 m .31679 .54081 L .31379 .54149 L F
.631 .141 .071 r
.31379 .54149 m .31583 .54307 L .31796 .54179 L F
.986 .885 .639 r
.31796 .54179 m .31583 .54307 L .31679 .54081 L F
.99 .819 .439 r
.3451 .64803 m .34424 .64839 L .34367 .64656 L F
.409 .239 .537 r
.33978 .61289 m .33964 .61507 L .33742 .6156 L F
.482 .445 .739 r
.34044 .61887 m .33742 .6156 L .33964 .61507 L F
.464 .589 .893 r
.20506 .59622 m .20397 .59844 L .20261 .59656 L F
.20506 .59622 m .20671 .59895 L .20397 .59844 L F
.29 .48 .872 r
.32061 .57004 m .32295 .57022 L .32159 .56818 L F
.064 0 .223 r
.30633 .59109 m .30858 .58799 L .30569 .58872 L F
.30633 .59109 m .30762 .59054 L .30858 .58799 L F
.646 .591 .778 r
.34922 .59744 m .35298 .60049 L .35285 .59776 L F
.479 .294 .551 r
.35285 .59776 m .3553 .5973 L .35534 .59453 L F
.566 .44 .667 r
.35298 .60049 m .3553 .5973 L .35285 .59776 L F
.367 .77 .984 r
.26839 .64086 m .27069 .64062 L .26672 .64004 L F
.47 .057 .174 r
.34039 .55917 m .34254 .56021 L .34275 .55773 L F
.477 .063 .175 r
.34275 .55773 m .34579 .55883 L .3447 .55584 L F
.34275 .55773 m .34254 .56021 L .34579 .55883 L F
.588 .013 0 r
.31443 .65988 m .31281 .65969 L .31009 .65774 L F
0 .073 .569 r
.31443 .65988 m .3155 .66067 L .31281 .65969 L F
.31443 .65988 m .31667 .66184 L .3155 .66067 L F
.694 .185 .024 r
.28817 .54681 m .29265 .54811 L .29039 .5489 L F
.112 .069 .525 r
.30929 .61943 m .31083 .61504 L .30819 .61694 L F
.30929 .61943 m .31041 .61878 L .31083 .61504 L F
.141 .128 .581 r
.30929 .61943 m .31092 .62136 L .31041 .61878 L F
.349 .168 .489 r
.30929 .61943 m .30899 .62217 L .31092 .62136 L F
.49 .213 .42 r
.36879 .554 m .37141 .55357 L .37214 .55132 L F
.055 0 .213 r
.37214 .55132 m .37141 .55357 L .37367 .55025 L F
.803 .784 .836 r
.34477 .58639 m .34381 .58775 L .3464 .58492 L F
.376 .752 .99 r
.33156 .55554 m .33374 .5553 L .33174 .55489 L F
0 0 .476 r
.33005 .5521 m .33122 .55676 L .33156 .55554 L F
.89 .465 .109 r
.33005 .5521 m .33074 .55368 L .32992 .55453 L F
.33074 .55368 m .33156 .55554 L .32992 .55453 L F
.376 .752 .99 r
.33156 .55554 m .33174 .55489 L .32992 .55453 L F
.204 0 0 r
.33105 .55158 m .3332 .55173 L .33526 .54986 L F
.3332 .55173 m .33347 .55172 L .33352 .55166 L F
.33338 .55156 m .33352 .55166 L .33526 .54986 L F
.3332 .55173 m .33352 .55166 L .33338 .55156 L F
.529 .031 .019 r
.33526 .54986 m .33349 .55175 L .3361 .55117 L F
.377 .341 .692 r
.33358 .5514 m .3361 .55117 L .33355 .55174 L F
.33358 .5514 m .33355 .55174 L .33349 .55175 L F
.204 0 0 r
.33344 .55175 m .33352 .55171 L .33526 .54986 L F
.529 .031 .019 r
.33526 .54986 m .3361 .55117 L .33799 .54935 L F
.377 .341 .692 r
.33358 .5514 m .3345 .5504 L .33607 .55055 L F
.3345 .5504 m .336 .54875 L .33607 .5505 L F
.3345 .5504 m .33607 .5505 L .33607 .55055 L F
.33358 .5514 m .33258 .54861 L .336 .54875 L F
.814 .425 .316 r
.33086 .55016 m .33501 .55198 L .33077 .55024 L F
.377 .341 .692 r
.33358 .5514 m .33366 .55054 L .33258 .54861 L F
.33436 .55133 m .33607 .55055 L .3361 .55117 L F
.33358 .5514 m .33607 .55055 L .33436 .55133 L F
.3343 .55169 m .33479 .55167 L .33258 .54861 L F
.814 .425 .316 r
.33258 .54861 m .33384 .55035 L .33086 .55016 L F
.377 .341 .692 r
.33358 .5514 m .3343 .55169 L .33366 .55054 L F
.3343 .55169 m .33501 .55198 L .33479 .55167 L F
.814 .425 .316 r
.33384 .55035 m .33501 .55198 L .33086 .55016 L F
0 0 .428 r
.33358 .5514 m .3336 .55171 L .33379 .55185 L F
.204 0 0 r
.3332 .55173 m .33344 .55175 L .33347 .55172 L F
.33344 .55175 m .33349 .55175 L .33352 .55171 L F
.761 .649 .738 r
.32992 .55453 m .33374 .5553 L .33362 .55238 L F
.33279 .55208 m .33362 .55238 L .33358 .5514 L F
.32992 .55453 m .33362 .55238 L .33279 .55208 L F
.263 .16 .544 r
.33358 .5514 m .33349 .55175 L .33105 .55158 L F
.33358 .5514 m .33105 .55158 L .33037 .55239 L F
.761 .649 .738 r
.32992 .55453 m .33279 .55208 L .33037 .55239 L F
.33279 .55208 m .33358 .5514 L .33083 .55225 L F
.33279 .55208 m .33083 .55225 L .33037 .55239 L F
0 0 .428 r
.3336 .55171 m .3336 .55192 L .33379 .55185 L F
.3336 .55192 m .33374 .5553 L .33378 .55222 L F
.3336 .55192 m .33378 .55222 L .33379 .55185 L F
.33384 .55197 m .33374 .5553 L .33456 .55353 L F
.35 .018 .254 r
.33374 .55216 m .33456 .55353 L .33353 .55219 L F
.33501 .55198 m .33456 .55353 L .33374 .55216 L F
.33405 .55158 m .33369 .552 L .33077 .55024 L F
.33369 .552 m .33353 .55219 L .33331 .55203 L F
.33369 .552 m .33331 .55203 L .33077 .55024 L F
0 0 .428 r
.33358 .5514 m .33384 .55197 L .33501 .55198 L F
.35 .018 .254 r
.33501 .55198 m .33374 .55216 L .33384 .55197 L F
0 0 .428 r
.33384 .55197 m .33456 .55353 L .33501 .55198 L F
.35 .018 .254 r
.33501 .55198 m .33384 .55197 L .33405 .55158 L F
0 0 .428 r
.33379 .55185 m .33378 .55208 L .33384 .55197 L F
.35 .018 .254 r
.33374 .55216 m .33353 .55219 L .33405 .55158 L F
0 0 .428 r
.33378 .55208 m .33374 .5553 L .33384 .55197 L F
.394 0 .117 r
.33353 .55219 m .32931 .55516 L .32992 .55453 L F
.32931 .55516 m .32812 .556 L .32992 .55453 L F
0 0 .476 r
.33122 .55676 m .33135 .55728 L .33156 .55554 L F
0 .208 .732 r
.33135 .55728 m .33282 .55846 L .33156 .55554 L F
.751 .556 .632 r
.33187 .55775 m .33463 .56025 L .33282 .55846 L F
.33135 .55728 m .33135 .56005 L .3335 .56018 L F
.33389 .55957 m .3335 .56018 L .33463 .56025 L F
.33135 .55728 m .3335 .56018 L .33389 .55957 L F
.749 .629 .727 r
.33135 .56005 m .3325 .56327 L .33463 .56025 L F
.938 .854 .733 r
.33261 .5616 m .33069 .5625 L .33282 .55846 L F
.3325 .56327 m .33175 .56295 L .33261 .5616 L F
.33175 .56295 m .33069 .5625 L .33261 .5616 L F
.3325 .56327 m .33282 .55846 L .33463 .56025 L F
.675 .756 .912 r
.33708 .56011 m .33463 .56025 L .33282 .55846 L F
.389 .073 .304 r
.33216 .56079 m .33387 .55925 L .33282 .55846 L F
.675 .756 .912 r
.33708 .56011 m .33282 .55846 L .33573 .55758 L F
.389 .073 .304 r
.33387 .55925 m .33573 .55758 L .33282 .55846 L F
.751 .556 .632 r
.33135 .55728 m .33187 .55775 L .33282 .55846 L F
0 0 .052 r
.30677 .64654 m .30549 .64741 L .30785 .6442 L F
.046 0 .281 r
.30487 .65006 m .30549 .64741 L .30677 .64654 L F
.168 0 .332 r
.32129 .60634 m .31927 .60944 L .31961 .60708 L F
.39 0 0 r
.29642 .65349 m .30047 .6532 L .29868 .65356 L F
.406 0 0 r
.30047 .6532 m .30278 .65357 L .29868 .65356 L F
.106 .262 .741 r
.38666 .56832 m .3861 .5704 L .3842 .56627 L F
.322 .332 .715 r
.38666 .56832 m .38573 .57252 L .3861 .5704 L F
.3 .318 .712 r
.31009 .65774 m .31281 .65969 L .31138 .65575 L F
.205 0 0 r
.23729 .53463 m .23981 .53418 L .24145 .53286 L F
0 0 0 r
.23981 .53418 m .24363 .53267 L .24145 .53286 L F
.387 .202 .504 r
.33855 .57134 m .33655 .56856 L .33866 .56869 L F
.33855 .57134 m .33657 .57218 L .33655 .56856 L F
.39 .287 .616 r
.30871 .61291 m .31083 .61504 L .30988 .61251 L F
.30871 .61291 m .30819 .61694 L .31083 .61504 L F
.367 .415 .779 r
.38498 .53081 m .38341 .53356 L .38255 .53124 L F
.38498 .53081 m .38618 .53458 L .38341 .53356 L F
.324 .436 .821 r
.38341 .53356 m .38618 .53458 L .38461 .53494 L F
.437 .355 .666 r
.1708 .59488 m .17284 .59483 L .17272 .59042 L F
.412 .555 .888 r
.1708 .59488 m .17498 .59654 L .17284 .59483 L F
0 0 0 r
.30785 .6442 m .31197 .64091 L .31009 .64347 L F
.033 0 .399 r
.31197 .64091 m .31279 .63793 L .31286 .64056 L F
0 0 0 r
.31009 .64347 m .31197 .64091 L .31286 .64056 L F
.349 .098 .386 r
.18354 .56355 m .18296 .56589 L .18557 .56284 L F
.42 .57 .897 r
.21123 .6177 m .21179 .6198 L .21293 .61774 L F
.412 .559 .892 r
.21179 .6198 m .21559 .62143 L .21293 .61774 L F
.646 .591 .778 r
.34922 .59744 m .35038 .60115 L .35298 .60049 L F
.57 .325 .505 r
.31416 .62866 m .31658 .63083 L .3142 .63138 L F
.31416 .62866 m .31672 .62842 L .31658 .63083 L F
.431 .627 .936 r
.21969 .62587 m .22087 .62405 L .219 .62458 L F
.21969 .62587 m .22143 .6256 L .22087 .62405 L F
.593 .86 .994 r
.22181 .55799 m .22151 .55982 L .22368 .55874 L F
.22181 .55799 m .21956 .55885 L .22151 .55982 L F
.853 .991 .733 r
.36525 .5589 m .36465 .55867 L .36674 .55744 L F
.299 .105 .441 r
.36879 .554 m .36674 .55744 L .36856 .5563 L F
0 0 0 r
.36674 .55744 m .36707 .55774 L .36856 .5563 L F
.36674 .55744 m .36465 .55867 L .36707 .55774 L F
.707 .663 .805 r
.35769 .57874 m .36157 .57895 L .36012 .57565 L F
.569 .324 .505 r
.35864 .5816 m .36157 .57895 L .35769 .57874 L F
.35864 .5816 m .36128 .58137 L .36157 .57895 L F
.527 .568 .84 r
.36012 .57565 m .36157 .57895 L .36367 .57819 L F
.41 .189 .464 r
.36157 .57895 m .36341 .58044 L .36367 .57819 L F
.36157 .57895 m .36128 .58137 L .36341 .58044 L F
.382 .058 .286 r
.29994 .63734 m .29663 .64086 L .29857 .64007 L F
.327 .786 .946 r
.29994 .63734 m .30083 .63662 L .30217 .63693 L F
.561 .411 .636 r
.29857 .64007 m .30083 .63662 L .29994 .63734 L F
.315 .747 .97 r
.32484 .53083 m .32777 .53116 L .32535 .53168 L F
.846 .777 .785 r
.33771 .53486 m .33567 .53787 L .33909 .53785 L F
.852 .747 .747 r
.33567 .53787 m .33695 .54151 L .33909 .53785 L F
.702 .718 .861 r
.33771 .53486 m .33909 .53785 L .34257 .53515 L F
.838 .622 .611 r
.27997 .54801 m .28108 .55134 L .27916 .55075 L F
.623 .51 .704 r
.28356 .55059 m .27997 .54801 L .28337 .54789 L F
.28356 .55059 m .28108 .55134 L .27997 .54801 L F
.446 .046 .186 r
.5099 .54009 m .51331 .53757 L .51127 .53842 L F
.531 .758 .98 r
.3116 .52993 m .30901 .5307 L .30707 .529 L F
0 .276 .643 r
.29166 .6268 m .29529 .62853 L .29145 .62671 L F
.2917 .62681 m .29256 .62723 L .29166 .6268 L F
.29256 .62723 m .29529 .62853 L .29166 .6268 L F
.786 .494 .493 r
.29217 .62908 m .29546 .62996 L .29543 .6286 L F
.666 .819 .957 r
.29542 .62755 m .29529 .62853 L .2917 .62681 L F
.786 .494 .493 r
.29432 .62807 m .29543 .6286 L .29542 .62755 L F
.29217 .62908 m .29543 .6286 L .29432 .62807 L F
.2915 .6294 m .29226 .62951 L .29217 .62908 L F
.29226 .62951 m .29546 .62996 L .29217 .62908 L F
0 .276 .643 r
.29172 .62707 m .29145 .62671 L .29196 .62941 L F
.2917 .62681 m .29166 .6268 L .29172 .62707 L F
.29166 .6268 m .29145 .62671 L .29172 .62707 L F
.757 .854 .412 r
.29196 .62941 m .2915 .6294 L .2917 .62681 L F
.29196 .62941 m .29104 .63112 L .2915 .6294 L F
.338 .03 .287 r
.30677 .64654 m .30785 .6442 L .31009 .64347 L F
.453 0 0 r
.23779 .5599 m .24016 .56163 L .23853 .56052 L F
.121 .671 .729 r
.29522 .54305 m .2932 .54325 L .29075 .5436 L F
.485 .32 .582 r
.38105 .5816 m .38143 .58467 L .37903 .58519 L F
.482 .32 .584 r
.38155 .58751 m .37903 .58519 L .38143 .58467 L F
.38155 .58751 m .37917 .58809 L .37903 .58519 L F
.16 0 .14 r
.35323 .65702 m .35176 .65941 L .35025 .65968 L F
.959 .786 .625 r
.35025 .65968 m .34907 .6562 L .35031 .65696 L F
.284 .255 .649 r
.35176 .65941 m .35231 .66189 L .35025 .65968 L F
.721 .628 .753 r
.35323 .65702 m .35025 .65968 L .35031 .65696 L F
.965 .709 .497 r
.35025 .65968 m .34837 .66154 L .34846 .65882 L F
0 0 0 r
.26686 .61946 m .26688 .62 L .26889 .61853 L F
.26686 .61946 m .26497 .62111 L .26688 .62 L F
.479 .809 1 r
.28014 .52858 m .27973 .53009 L .2778 .52895 L F
.28014 .52858 m .28198 .52955 L .27973 .53009 L F
.417 0 0 r
.24578 .5502 m .2478 .55078 L .24377 .55025 L F
.6 .474 .681 r
.3333 .64382 m .33338 .64642 L .33098 .64687 L F
.546 .425 .666 r
.33404 .64986 m .33098 .64687 L .33338 .64642 L F
.33404 .64986 m .33159 .65046 L .33098 .64687 L F
.648 .966 .9 r
.32559 .54784 m .3266 .54628 L .32745 .54666 L F
.263 .498 .893 r
.32559 .54784 m .32949 .55097 L .3266 .54628 L F
.644 .301 .376 r
.31138 .65575 m .31536 .6558 L .31309 .65356 L F
.577 .312 .478 r
.31309 .65356 m .31536 .6558 L .31559 .65337 L F
.624 .479 .664 r
.36097 .62479 m .35856 .62808 L .35934 .62589 L F
.454 .144 .35 r
.33708 .56011 m .33969 .5613 L .34039 .55917 L F
.113 .357 .821 r
.33763 .55757 m .33969 .5613 L .33708 .56011 L F
0 0 .206 r
.29691 .57899 m .29831 .57807 L .29861 .57543 L F
0 0 .204 r
.29598 .58125 m .29831 .57807 L .29691 .57899 L F
.354 .061 .321 r
.34954 .6134 m .34681 .61604 L .34905 .61524 L F
.59 .275 .404 r
.34954 .6134 m .35247 .61337 L .35168 .61355 L F
.451 .597 .905 r
.38064 .52825 m .3805 .5315 L .37843 .52926 L F
.38064 .52825 m .38255 .53124 L .3805 .5315 L F
.668 .311 .36 r
.3245 .66307 m .32047 .66502 L .32225 .66264 L F
.3245 .66307 m .32445 .66489 L .32047 .66502 L F
.644 .382 .508 r
.32749 .66272 m .32445 .66489 L .3245 .66307 L F
.475 0 0 r
.31752 .56752 m .3166 .56757 L .31414 .56584 L F
.568 .539 .783 r
.31878 .5659 m .31752 .56752 L .31563 .56304 L F
.254 .761 .744 r
.31769 .56729 m .31752 .56752 L .31878 .5659 L F
.31769 .56729 m .3166 .56757 L .31752 .56752 L F
.56 .911 .707 r
.22641 .53582 m .22238 .53861 L .22446 .53767 L F
.456 0 0 r
.22668 .53707 m .22641 .53582 L .22446 .53767 L F
.22668 .53707 m .22891 .53609 L .22641 .53582 L F
.069 .631 .778 r
.2883 .5283 m .29057 .52826 L .29222 .52839 L F
.249 .762 .821 r
.29057 .52826 m .29452 .52773 L .29222 .52839 L F
.473 .28 .538 r
.50102 .55135 m .50335 .55067 L .50325 .54759 L F
.465 .394 .693 r
.50325 .54759 m .50552 .5468 L .50499 .54365 L F
.488 .328 .589 r
.50335 .55067 m .50552 .5468 L .50325 .54759 L F
.127 .65 .881 r
.29731 .62829 m .30125 .62891 L .29962 .62831 L F
.575 .685 .916 r
.30125 .62891 m .30172 .6268 L .29962 .62831 L F
.30125 .62891 m .30361 .62837 L .30172 .6268 L F
.047 0 0 r
.35786 .56238 m .35632 .56492 L .35863 .5639 L F
.415 .52 .857 r
.39038 .54028 m .38885 .5422 L .3884 .54044 L F
.29 .34 .741 r
.39038 .54028 m .39129 .54407 L .38885 .5422 L F
.471 .214 .442 r
.32251 .57893 m .32494 .57848 L .32542 .57599 L F
.461 .315 .596 r
.32542 .57599 m .32778 .5753 L .32742 .572 L F
.427 .175 .427 r
.32542 .57599 m .32729 .57783 L .32778 .5753 L F
.32542 .57599 m .32494 .57848 L .32729 .57783 L F
.515 .048 .084 r
.35808 .63599 m .35347 .63734 L .35329 .63421 L F
.35808 .63599 m .35721 .6376 L .35347 .63734 L F
.255 0 .261 r
.32982 .58197 m .32922 .58387 L .32708 .58485 L F
.506 .353 .608 r
.33196 .57886 m .33202 .58142 L .32982 .58197 L F
.286 0 .206 r
.33202 .58142 m .32922 .58387 L .32982 .58197 L F
.119 0 .047 r
.32342 .59026 m .32046 .59275 L .32106 .59082 L F
.467 .707 .973 r
.31576 .52827 m .31515 .53033 L .31366 .52923 L F
.31576 .52827 m .31836 .53023 L .31515 .53033 L F
.459 .357 .652 r
.35674 .58799 m .35851 .58473 L .35628 .58539 L F
.387 .011 .199 r
.32225 .66264 m .31817 .6654 L .32091 .66312 L F
.32225 .66264 m .32047 .66502 L .31817 .6654 L F
.477 .142 .319 r
.28168 .60335 m .28411 .60314 L .28524 .60037 L F
.286 .1 .445 r
.28524 .60037 m .28724 .59984 L .2871 .59722 L F
.515 .275 .489 r
.28411 .60314 m .28724 .59984 L .28524 .60037 L F
.487 .28 .525 r
.29574 .6434 m .29407 .64135 L .29384 .6427 L F
.29574 .6434 m .29663 .64086 L .29407 .64135 L F
.35 .794 .957 r
.34635 .60033 m .3427 .60013 L .34505 .5996 L F
.741 .363 .335 r
.34635 .60033 m .34518 .60293 L .3427 .60013 L F
.7 .617 .761 r
.34642 .59805 m .34635 .60033 L .34922 .59744 L F
.501 .88 .972 r
.34505 .5996 m .34743 .59904 L .34635 .60033 L F
0 0 0 r
.34743 .59904 m .34518 .60293 L .34635 .60033 L F
.275 .055 .387 r
.32031 .58197 m .32212 .58136 L .32251 .57893 L F
0 0 .369 r
.32031 .58197 m .32053 .58454 L .32212 .58136 L F
.941 .657 .473 r
.33455 .6636 m .33302 .66475 L .33272 .66201 L F
.712 .761 .891 r
.33707 .6621 m .33455 .6636 L .33272 .66201 L F
.915 .599 .432 r
.33455 .6636 m .33551 .66599 L .33302 .66475 L F
.123 .251 .725 r
.33695 .54151 m .33918 .5433 L .34038 .54218 L F
0 .38 .811 r
.34146 .5422 m .34408 .54422 L .34038 .54218 L F
.34146 .5422 m .34038 .54218 L .33918 .5433 L F
.559 .756 .97 r
.22573 .61489 m .22727 .61643 L .22336 .61549 L F
.384 .67 .972 r
.22781 .61481 m .22727 .61643 L .22573 .61489 L F
.473 .765 .994 r
.22781 .61481 m .22947 .61608 L .22727 .61643 L F
.952 .699 .519 r
.32949 .55097 m .32578 .55029 L .32602 .54881 L F
.32949 .55097 m .32698 .55192 L .32578 .55029 L F
.399 .176 .456 r
.33005 .5521 m .32702 .55429 L .32949 .55097 L F
0 0 0 r
.33013 .54925 m .32698 .55192 L .32949 .55097 L F
.092 .313 .79 r
.32949 .55097 m .33105 .55158 L .33013 .54925 L F
.309 .139 .481 r
.32949 .55097 m .33005 .5521 L .33105 .55158 L F
.32949 .55097 m .33005 .5521 L .33105 .55158 L F
.97 .739 .533 r
.3325 .56327 m .33215 .56595 L .33069 .5625 L F
.568 .564 .809 r
.3325 .56327 m .33605 .56646 L .33215 .56595 L F
.53 .341 .569 r
.30288 .56294 m .30583 .55945 L .30309 .55981 L F
.30288 .56294 m .30544 .56271 L .30583 .55945 L F
.145 0 0 r
.30289 .56363 m .30544 .56271 L .30288 .56294 L F
.46 .355 .649 r
.36058 .52874 m .36272 .52787 L .36227 .52557 L F
.594 .596 .823 r
.36058 .52874 m .3637 .53023 L .36272 .52787 L F
.226 0 0 r
.28503 .63158 m .28728 .63153 L .28448 .63109 L F
.464 .889 .892 r
.28602 .63136 m .28728 .63153 L .28503 .63158 L F
.122 0 0 r
.28448 .63109 m .28728 .63153 L .2883 .63167 L F
.464 .889 .892 r
.28943 .6306 m .28728 .63153 L .28602 .63136 L F
.122 0 0 r
.2883 .63167 m .28728 .63153 L .28899 .63177 L F
.512 .901 .945 r
.28899 .63177 m .28943 .6306 L .29104 .63112 L F
.28899 .63177 m .2877 .63159 L .28943 .6306 L F
.81 .613 .636 r
.28701 .63207 m .29079 .62982 L .28943 .6306 L F
.638 .929 .971 r
.29104 .63112 m .28943 .6306 L .2915 .6294 L F
.81 .613 .636 r
.29079 .62982 m .2915 .6294 L .28943 .6306 L F
.512 .901 .945 r
.2877 .63159 m .28728 .63153 L .28943 .6306 L F
.372 .182 .488 r
.29075 .63372 m .28899 .63177 L .29104 .63112 L F
.29075 .63372 m .28878 .63426 L .28899 .63177 L F
.602 .25 .346 r
.26834 .55366 m .26418 .556 L .26635 .55349 L F
.823 .757 .79 r
.53351 .54641 m .53544 .55009 L .53325 .54979 L F
.416 .5 .837 r
.218 .61165 m .21669 .61384 L .21577 .61202 L F
.218 .61165 m .21939 .61468 L .21669 .61384 L F
.29 .172 .541 r
.28878 .63426 m .28905 .63711 L .28687 .63833 L F
.015 .147 .659 r
.28894 .63988 m .28687 .63833 L .28905 .63711 L F
.28894 .63988 m .28775 .64064 L .28687 .63833 L F
.447 .246 .513 r
.34198 .63047 m .3399 .62859 L .34233 .62808 L F
.34198 .63047 m .33977 .63114 L .3399 .62859 L F
.14 .091 .536 r
.30727 .544 m .30765 .54655 L .30605 .54776 L F
.191 .019 .405 r
.30788 .54917 m .30605 .54776 L .30765 .54655 L F
.30788 .54917 m .30591 .55067 L .30605 .54776 L F
.328 .388 .772 r
.35883 .56934 m .35974 .57273 L .36136 .57125 L F
.476 .327 .598 r
.35974 .57273 m .36237 .57526 L .36136 .57125 L F
.35974 .57273 m .36012 .57565 L .36237 .57526 L F
.742 .62 .723 r
.36799 .5399 m .36377 .53754 L .36878 .53859 L F
.764 .807 .887 r
.53823 .53962 m .5408 .53885 L .53892 .53779 L F
.53823 .53962 m .53999 .54039 L .5408 .53885 L F
.385 .669 .971 r
.19166 .60548 m .19284 .60683 L .1935 .60527 L F
.162 .402 .846 r
.19284 .60683 m .19448 .60711 L .1935 .60527 L F
0 0 0 r
.28419 .52876 m .2883 .5283 L .28598 .52946 L F
.318 .12 .447 r
.36879 .554 m .37024 .55556 L .37141 .55357 L F
.36879 .554 m .36856 .5563 L .37024 .55556 L F
0 0 0 r
.17707 .57142 m .18013 .5687 L .17814 .56952 L F
.766 .454 .457 r
.26892 .70891 m .26907 .70635 L .26685 .70786 L F
.512 .622 .897 r
.26892 .70891 m .26685 .70786 L .26907 .70635 L F
.477 .209 .428 r
.26892 .70891 m .26907 .70635 L .27125 .7083 L F
.26892 .70891 m .26907 .70635 L .27125 .7083 L F
.064 0 0 r
.53544 .55009 m .53951 .5507 L .53601 .55095 L F
.63 .445 .614 r
.3553 .5973 m .35802 .59412 L .35534 .59453 L F
.641 .493 .667 r
.34551 .64052 m .34653 .64372 L .34359 .64358 L F
.156 0 .266 r
.32412 .54424 m .3221 .54642 L .32172 .54465 L F
.549 .328 .533 r
.3843 .5787 m .38405 .58139 L .38105 .5816 L F
.47 .259 .509 r
.38405 .58139 m .38143 .58467 L .38105 .5816 L F
.373 .199 .511 r
.33571 .64246 m .3333 .64382 L .33482 .6398 L F
.465 .229 .47 r
.38654 .57818 m .38405 .58139 L .3843 .5787 L F
.184 .537 .925 r
.29238 .64832 m .29277 .64721 L .29094 .64673 L F
.29238 .64832 m .29557 .64958 L .29277 .64721 L F
.074 0 0 r
.35392 .66413 m .35258 .66525 L .35004 .66584 L F
0 0 0 r
.35392 .66413 m .3545 .66401 L .35258 .66525 L F
.35392 .66413 m .3555 .66379 L .3545 .66401 L F
.506 .826 1 r
.24597 .532 m .25 .53234 L .24774 .53276 L F
.763 .431 .422 r
.24708 .55712 m .24941 .55905 L .25082 .55826 L F
.533 .423 .675 r
.2524 .5574 m .25309 .55864 L .25082 .55826 L F
.502 .026 .058 r
.27577 .55329 m .27279 .55534 L .27087 .55413 L F
.545 .133 .211 r
.27827 .55259 m .27279 .55534 L .27577 .55329 L F
.017 0 .429 r
.31374 .64074 m .31279 .63793 L .31444 .63721 L F
.31374 .64074 m .31286 .64056 L .31279 .63793 L F
0 0 .462 r
.34626 .64039 m .34551 .64052 L .34435 .64018 L F
.34626 .64039 m .34435 .64018 L .34646 .64003 L F
.107 0 0 r
.34646 .64003 m .3443 .64096 L .34435 .64018 L F
.3443 .64096 m .34313 .64147 L .34435 .64018 L F
.791 .294 0 r
.34439 .63945 m .34435 .64018 L .34551 .64052 L F
.34247 .63763 m .34435 .64018 L .34439 .63945 L F
0 0 .462 r
.34626 .64039 m .34653 .64372 L .34551 .64052 L F
.238 .106 .491 r
.17281 .57583 m .17416 .57765 L .17487 .57464 L F
.17281 .57583 m .17271 .5785 L .17416 .57765 L F
.488 .446 .737 r
.35159 .55271 m .34923 .55468 L .34924 .55192 L F
.355 .355 .722 r
.35177 .55605 m .34923 .55468 L .35159 .55271 L F
.35177 .55605 m .35037 .55734 L .34923 .55468 L F
.148 .175 .632 r
.35958 .63683 m .35882 .64084 L .357 .63993 L F
.35958 .63683 m .36023 .64079 L .35882 .64084 L F
.452 0 0 r
.36023 .64079 m .357 .63993 L .35882 .64084 L F
.718 .886 .958 r
.31906 .5888 m .31463 .58968 L .31695 .58922 L F
.628 .959 .903 r
.31906 .5888 m .31695 .58922 L .32005 .58752 L F
0 0 0 r
.25606 .72995 m .25806 .72802 L .25897 .72769 L F
.769 .762 .846 r
.27592 .6961 m .2794 .69342 L .27507 .69298 L F
.446 .248 .517 r
.33168 .65305 m .32922 .65622 L .32927 .65362 L F
.632 .574 .772 r
.37099 .52226 m .36958 .52644 L .36797 .52295 L F
.37099 .52226 m .37161 .52631 L .36958 .52644 L F
.629 .508 .696 r
.37161 .52631 m .36989 .52911 L .36958 .52644 L F
.656 .971 .858 r
.34901 .62099 m .34827 .62238 L .35053 .62198 L F
.34901 .62099 m .34716 .62241 L .34827 .62238 L F
.67 .535 .691 r
.34827 .62238 m .35161 .62542 L .35053 .62198 L F
.34827 .62238 m .34845 .62577 L .35161 .62542 L F
.316 0 0 r
.36246 .54178 m .36064 .54265 L .3601 .54262 L F
.36246 .54178 m .36084 .54338 L .35842 .54372 L F
.572 .521 .759 r
.36377 .53754 m .36246 .54178 L .3609 .53833 L F
.597 .503 .719 r
.36086 .53736 m .36073 .54251 L .36166 .54229 L F
.233 0 0 r
.3642 .54203 m .36246 .54178 L .36491 .54123 L F
.36379 .54249 m .3635 .54233 L .3642 .54203 L F
.3635 .54233 m .36246 .54178 L .3642 .54203 L F
.3635 .54233 m .36084 .54338 L .36246 .54178 L F
.417 .012 .161 r
.36084 .54338 m .36106 .54336 L .36134 .54318 L F
.36106 .54336 m .36338 .54311 L .36348 .54233 L F
.233 0 0 r
.36379 .54249 m .36084 .54338 L .3635 .54233 L F
.417 .012 .161 r
.36084 .54338 m .36134 .54318 L .36355 .54183 L F
.36106 .54336 m .36348 .54233 L .36355 .54183 L F
.597 .503 .719 r
.36344 .54165 m .36166 .54229 L .36355 .54183 L F
.572 .521 .759 r
.36377 .53754 m .36491 .54123 L .36246 .54178 L F
.597 .503 .719 r
.36086 .53736 m .36166 .54229 L .36344 .54165 L F
.316 0 0 r
.36064 .54265 m .35842 .54372 L .35934 .54312 L F
.36064 .54265 m .35934 .54312 L .3601 .54262 L F
.492 .234 .451 r
.36417 .60873 m .36066 .61024 L .36126 .60952 L F
0 0 0 r
.21736 .54167 m .21746 .5423 L .21942 .54042 L F
.21736 .54167 m .21549 .54338 L .21746 .5423 L F
.048 0 0 r
.22033 .54033 m .21736 .54167 L .21942 .54042 L F
0 .198 .659 r
.30625 .59921 m .30393 .59771 L .30415 .59922 L F
.812 .936 .911 r
.52606 .56356 m .52929 .56267 L .52804 .56197 L F
.632 .91 .982 r
.53041 .56089 m .52929 .56267 L .53177 .56173 L F
.53041 .56089 m .52804 .56197 L .52929 .56267 L F
0 0 0 r
.31159 .60549 m .30917 .60708 L .31135 .60584 L F
.224 .158 .569 r
.30917 .60708 m .30922 .60998 L .31115 .60834 L F
.548 .506 .761 r
.50102 .55135 m .504 .55301 L .50335 .55067 L F
.222 0 0 r
.35231 .66189 m .35468 .66139 L .35666 .65943 L F
.707 .214 0 r
.35707 .6608 m .35666 .65943 L .35468 .66139 L F
.35707 .6608 m .35864 .66216 L .35666 .65943 L F
.146 .627 .921 r
.27637 .64265 m .27868 .64324 L .27699 .64269 L F
.757 .336 .248 r
.27699 .64269 m .28082 .64372 L .27899 .64536 L F
0 .072 .632 r
.27699 .64269 m .27899 .64536 L .27791 .64275 L F
.27699 .64269 m .27791 .64275 L .27746 .64166 L F
.146 .627 .921 r
.27422 .64209 m .27637 .64265 L .27699 .64269 L F
.626 .834 .98 r
.37255 .56209 m .37419 .56333 L .37678 .56256 L F
.37255 .56209 m .37678 .56256 L .37517 .56112 L F
.04 .164 .667 r
.37517 .56112 m .37419 .56333 L .37255 .56209 L F
.504 .235 .44 r
.37419 .56333 m .37619 .56547 L .37678 .56256 L F
.04 .164 .667 r
.37517 .56112 m .37619 .56547 L .37419 .56333 L F
.528 .57 .841 r
.26149 .7182 m .26324 .72184 L .26533 .72128 L F
.871 .804 .317 r
.26533 .72128 m .26593 .71884 L .26569 .71747 L F
.76 .731 .825 r
.27653 .60707 m .27397 .6099 L .2775 .60668 L F
.451 .615 .92 r
.23768 .6346 m .23997 .63481 L .23751 .63126 L F
.441 .693 .972 r
.23567 .63179 m .23751 .63126 L .23631 .63024 L F
0 .336 .811 r
.23881 .63294 m .23631 .63024 L .23751 .63126 L F
.2388 .63293 m .23889 .63179 L .23631 .63024 L F
.342 .554 .913 r
.23751 .63126 m .23997 .63481 L .23881 .63294 L F
0 .336 .811 r
.23881 .63294 m .23881 .63294 L .2388 .63293 L F
.23881 .63294 m .23889 .63179 L .2388 .63293 L F
.451 .615 .92 r
.23768 .6346 m .23753 .63173 L .23567 .63179 L F
.23753 .63173 m .23751 .63126 L .23715 .63136 L F
.23753 .63173 m .23715 .63136 L .23567 .63179 L F
.801 .696 .749 r
.28108 .55134 m .27827 .55259 L .27916 .55075 L F
.991 .734 .399 r
.28252 .55986 m .28117 .5587 L .28192 .55766 L F
0 0 .439 r
.28252 .55986 m .28305 .56051 L .28117 .5587 L F
.466 .158 .359 r
.28543 .55912 m .28422 .56203 L .28252 .55986 L F
0 0 .439 r
.28252 .55986 m .28422 .56203 L .28305 .56051 L F
.613 .573 .786 r
.28543 .55912 m .28252 .55986 L .28192 .55766 L F
.419 .817 .984 r
.25 .53234 m .2523 .53189 L .25416 .5326 L F
.438 .826 .987 r
.2523 .53189 m .25646 .53212 L .25416 .5326 L F
.702 .821 .938 r
.33571 .64246 m .34005 .64333 L .33838 .64012 L F
.713 .67 .806 r
.35072 .65312 m .35323 .65702 L .35031 .65696 L F
.601 .179 0 r
.35201 .65513 m .35323 .65702 L .35152 .65436 L F
0 0 .474 r
.35234 .65351 m .35287 .65649 L .35201 .65513 L F
0 0 0 r
.35314 .65804 m .35176 .65941 L .35323 .65702 L F
.35314 .65804 m .35323 .65702 L .35201 .65513 L F
0 0 .474 r
.35287 .65649 m .35314 .65804 L .35201 .65513 L F
.601 .179 0 r
.35201 .65513 m .35152 .65436 L .35072 .65312 L F
.471 .047 .152 r
.3262 .621 m .32512 .61913 L .32346 .62121 L F
.3262 .621 m .32766 .61891 L .32512 .61913 L F
.246 .141 .531 r
.17135 .58192 m .17281 .58116 L .17271 .5785 L F
.338 .221 .569 r
.17135 .58192 m .17313 .58384 L .17281 .58116 L F
.17135 .58192 m .17142 .58456 L .17313 .58384 L F
.343 .172 .499 r
.38651 .56348 m .3861 .56637 L .3842 .56627 L F
.341 .284 .647 r
.3861 .56637 m .38666 .56832 L .3842 .56627 L F
.765 .399 .361 r
.34273 .61693 m .34537 .61815 L .34681 .61604 L F
.492 .152 .317 r
.34537 .61815 m .34905 .61524 L .34681 .61604 L F
.126 0 .12 r
.25702 .72384 m .2549 .72561 L .25354 .72774 L F
.494 .817 1 r
.23312 .76463 m .23717 .76503 L .23503 .76432 L F
.23312 .76463 m .23717 .76503 L .23503 .76432 L F
.689 .342 .381 r
.52937 .53509 m .53314 .53714 L .53294 .53532 L F
.687 .406 .492 r
.53314 .53714 m .5348 .53525 L .53294 .53532 L F
.66 .379 .483 r
.39745 .55399 m .39581 .55684 L .39454 .55646 L F
.225 .341 .773 r
.39648 .55114 m .39891 .55256 L .39745 .55399 L F
.261 0 .236 r
.3994 .5552 m .39745 .55399 L .39891 .55256 L F
.3994 .5552 m .39581 .55684 L .39745 .55399 L F
.171 0 .339 r
.2337 .63327 m .23567 .63179 L .23462 .63013 L F
0 0 0 r
.22898 .53655 m .22891 .53609 L .22668 .53707 L F
.731 .789 .898 r
.52104 .53556 m .51658 .53583 L .52031 .53571 L F
.788 .944 .598 r
.52334 .53203 m .52104 .53556 L .52146 .53421 L F
0 0 .255 r
.52031 .53571 m .52146 .53421 L .52104 .53556 L F
.328 .168 .506 r
.30583 .55945 m .30544 .56271 L .30656 .56196 L F
.067 .256 .747 r
.28982 .64231 m .28775 .64064 L .28894 .63988 L F
.702 .745 .238 r
.33969 .5613 m .33932 .56266 L .34039 .55917 L F
.658 .587 .764 r
.33932 .56266 m .34182 .56366 L .34039 .55917 L F
.695 .549 .684 r
.33932 .56266 m .34217 .56623 L .34182 .56366 L F
.098 .323 .798 r
.33969 .5613 m .34217 .56623 L .33932 .56266 L F
.512 .622 .897 r
.26892 .70891 m .26723 .70997 L .26685 .70786 L F
.578 .822 .991 r
.26491 .70851 m .26723 .70997 L .26892 .70891 L F
.736 .44 .48 r
.5348 .53525 m .53892 .53779 L .53737 .53525 L F
.722 .439 .496 r
.31559 .65337 m .3191 .65573 L .31938 .6534 L F
.661 .531 .695 r
.31938 .6534 m .32197 .65332 L .32176 .65039 L F
.633 .369 .501 r
.3191 .65573 m .32197 .65332 L .31938 .6534 L F
.468 .255 .506 r
.3118 .56008 m .31255 .5629 L .30965 .56317 L F
.808 .459 .396 r
.31563 .56304 m .3118 .56008 L .31446 .55985 L F
.31563 .56304 m .31255 .5629 L .3118 .56008 L F
.99 .822 .441 r
.34579 .55883 m .34617 .56222 L .34708 .55965 L F
.592 .169 .209 r
.35037 .55734 m .34579 .55883 L .34708 .55965 L F
.242 0 .298 r
.17487 .57464 m .17707 .57142 L .17528 .57231 L F
.835 .756 .776 r
.33371 .53385 m .33564 .53524 L .33408 .53167 L F
.918 .624 .472 r
.33371 .53385 m .33567 .53787 L .33564 .53524 L F
.382 .115 .38 r
.33564 .53524 m .33997 .53259 L .33408 .53167 L F
.33564 .53524 m .33771 .53486 L .33997 .53259 L F
.414 .204 .483 r
.33564 .53524 m .33567 .53787 L .33771 .53486 L F
.494 .622 .906 r
.522 .56181 m .52298 .56382 L .52424 .5615 L F
.505 .636 .912 r
.52298 .56382 m .52606 .56356 L .52424 .5615 L F
.631 .946 .739 r
.28219 .63104 m .28201 .63022 L .28448 .63109 L F
.568 .367 .569 r
.36728 .53204 m .36989 .52911 L .36854 .52747 L F
.36728 .53204 m .36993 .53179 L .36989 .52911 L F
.033 .189 .694 r
.36993 .53179 m .36854 .52747 L .36989 .52911 L F
.273 .047 .378 r
.37633 .54448 m .37822 .54378 L .37779 .54329 L F
.527 .597 .868 r
.30551 .57877 m .30696 .58192 L .30904 .58125 L F
.321 .039 .32 r
.20347 .57201 m .20079 .57479 L .20144 .57276 L F
.362 0 0 r
.25459 .5504 m .25178 .55126 L .25006 .55058 L F
0 0 0 r
.25649 .54674 m .25513 .5502 L .25459 .5504 L F
.25437 .55055 m .25459 .5504 L .25513 .5502 L F
.463 .258 .515 r
.25507 .55354 m .25791 .55032 L .25459 .5504 L F
.441 .084 .262 r
.3221 .54642 m .3208 .54977 L .31806 .54996 L F
.156 0 .266 r
.32412 .54424 m .32321 .54694 L .3221 .54642 L F
0 0 .061 r
.32231 .54873 m .3221 .54642 L .32321 .54694 L F
.696 .284 .261 r
.32602 .54881 m .32231 .54873 L .32321 .54694 L F
0 0 0 r
.32231 .54873 m .31927 .55141 L .3208 .54977 L F
.631 .069 0 r
.32578 .55029 m .32231 .54873 L .32602 .54881 L F
.32578 .55029 m .32441 .55053 L .32231 .54873 L F
.563 .901 .979 r
.32039 .54984 m .31927 .55141 L .32231 .54873 L F
.26 .241 .647 r
.32439 .54785 m .32441 .55053 L .32231 .54873 L F
.3242 .54795 m .32231 .54873 L .32039 .54984 L F
.32439 .54785 m .32231 .54873 L .3242 .54795 L F
0 0 .061 r
.32231 .54873 m .3208 .54977 L .32099 .54928 L F
.32231 .54873 m .32099 .54928 L .3221 .54642 L F
.387 .148 .426 r
.32251 .57893 m .32428 .58059 L .32494 .57848 L F
.32251 .57893 m .32212 .58136 L .32428 .58059 L F
.688 .246 .196 r
.33604 .66801 m .33862 .66889 L .33467 .66856 L F
.926 .727 .613 r
.33551 .66599 m .33604 .66801 L .33467 .66856 L F
0 0 0 r
.36417 .60873 m .36088 .61165 L .36066 .61024 L F
.832 .971 .888 r
.21308 .56184 m .21276 .56354 L .21568 .56156 L F
.344 .823 .846 r
.21529 .56115 m .21568 .56156 L .21749 .56028 L F
.255 0 .151 r
.21791 .56018 m .21768 .56039 L .21529 .56115 L F
.344 .823 .846 r
.21529 .56115 m .21313 .56183 L .21568 .56156 L F
.255 0 .151 r
.21768 .56039 m .21378 .56398 L .21529 .56115 L F
.344 .823 .846 r
.21529 .56115 m .21308 .56184 L .21313 .56183 L F
.628 .511 .7 r
.34845 .62577 m .35237 .62822 L .35161 .62542 L F
.34845 .62577 m .34962 .62867 L .35237 .62822 L F
0 0 .544 r
.34263 .63718 m .34435 .64018 L .34247 .63763 L F
.592 .268 .389 r
.33799 .54935 m .34053 .54972 L .33831 .54772 L F
.726 .686 .812 r
.3332 .54034 m .33695 .54151 L .33567 .53787 L F
.031 .556 .862 r
.33695 .54151 m .33579 .54087 L .3332 .54034 L F
.669 .555 .716 r
.33661 .54108 m .33918 .5433 L .33541 .54255 L F
.33778 .53964 m .33852 .54159 L .33661 .54108 L F
.33852 .54159 m .33918 .5433 L .33661 .54108 L F
.031 .556 .862 r
.33579 .54087 m .33566 .54079 L .33519 .54071 L F
.33579 .54087 m .33519 .54071 L .3332 .54034 L F
.324 .203 .557 r
.2871 .59722 m .28925 .59642 L .28933 .5936 L F
.402 .236 .538 r
.28724 .59984 m .28925 .59642 L .2871 .59722 L F
.11 0 .221 r
.27984 .63106 m .27923 .62936 L .27985 .62771 L F
.27984 .63106 m .27817 .63148 L .27923 .62936 L F
.435 0 .047 r
.34873 .58223 m .34484 .58399 L .34705 .58081 L F
.34873 .58223 m .34732 .58394 L .34484 .58399 L F
.681 .245 .208 r
.35117 .58408 m .34732 .58394 L .34873 .58223 L F
.16 .268 .727 r
.35329 .60294 m .35443 .60668 L .3556 .60491 L F
.214 .342 .778 r
.35443 .60668 m .35737 .60896 L .3556 .60491 L F
0 .549 .822 r
.24187 .6225 m .24123 .62279 L .2391 .62163 L F
.24187 .6225 m .24347 .62304 L .24123 .62279 L F
.599 .637 .86 r
.36272 .52787 m .3637 .53023 L .36605 .52912 L F
.389 0 .165 r
.29755 .54637 m .30106 .54391 L .29877 .54452 L F
.413 0 0 r
.28082 .64372 m .28474 .64452 L .28267 .64492 L F
.167 0 0 r
.28474 .64452 m .28532 .64522 L .28267 .64492 L F
.28474 .64452 m .28734 .64441 L .28532 .64522 L F
.399 .553 .892 r
.37516 .53811 m .37622 .5361 L .37347 .53696 L F
.37516 .53811 m .37713 .53815 L .37622 .5361 L F
.713 .67 .806 r
.35072 .65312 m .35031 .65696 L .34907 .6562 L F
0 0 .203 r
.29861 .57543 m .30043 .57429 L .3006 .57206 L F
.326 .053 .337 r
.29861 .57543 m .3006 .57728 L .30043 .57429 L F
.29861 .57543 m .29831 .57807 L .3006 .57728 L F
.565 .309 .488 r
.36069 .58381 m .35864 .5816 L .35851 .58473 L F
.36069 .58381 m .36128 .58137 L .35864 .5816 L F
.559 .422 .65 r
.28581 .54734 m .28356 .55059 L .28337 .54789 L F
.974 .695 .44 r
.31101 .60053 m .31089 .60292 L .30952 .60172 L F
.48 .368 .649 r
.30023 .56655 m .30289 .56853 L .30289 .56363 L F
.192 0 0 r
.34242 .56647 m .34104 .56811 L .33866 .56869 L F
.779 .997 .856 r
.34398 .5647 m .34242 .56647 L .34477 .56423 L F
.081 0 0 r
.34317 .56739 m .34242 .56647 L .34398 .5647 L F
.34317 .56739 m .34104 .56811 L .34242 .56647 L F
.243 .55 .93 r
.18439 .60161 m .18467 .59989 L .18314 .59988 L F
.18439 .60161 m .18771 .60277 L .18467 .59989 L F
.651 .282 .331 r
.52334 .53203 m .52146 .53421 L .52515 .53416 L F
.568 .367 .569 r
.36728 .53204 m .36854 .52747 L .36605 .52912 L F
0 0 0 r
.36684 .53429 m .36993 .53179 L .36728 .53204 L F
0 .438 .792 r
.27199 .64116 m .27422 .64209 L .27263 .64198 L F
.078 .554 .901 r
.27422 .64209 m .27529 .64162 L .27263 .64198 L F
.321 0 0 r
.27263 .64198 m .27529 .64162 L .2732 .6427 L F
.27263 .64198 m .2732 .6427 L .27172 .64346 L F
0 .438 .792 r
.27069 .64062 m .27199 .64116 L .27263 .64198 L F
.078 .554 .901 r
.27422 .64209 m .27699 .64269 L .27529 .64162 L F
.729 .655 .776 r
.20385 .58479 m .20193 .58553 L .20043 .58388 L F
.691 .535 .671 r
.20385 .58479 m .20147 .58802 L .20193 .58553 L F
.777 .731 .811 r
.20738 .79496 m .21067 .79269 L .20643 .79279 L F
.729 .655 .776 r
.20385 .58479 m .20043 .58388 L .20217 .58352 L F
.518 .699 .952 r
.20609 .58348 m .20385 .58479 L .20217 .58352 L F
.205 .73 .742 r
.25646 .53212 m .25883 .53156 L .26019 .53133 L F
.34 .819 .798 r
.26019 .53133 m .26106 .53076 L .26262 .53053 L F
.26019 .53133 m .25883 .53156 L .26106 .53076 L F
0 0 0 r
.28296 .61765 m .28321 .61679 L .28461 .61574 L F
.28296 .61765 m .28258 .61893 L .28321 .61679 L F
.679 .477 .606 r
.32176 .55725 m .32059 .56005 L .31812 .55947 L F
.581 .37 .559 r
.32329 .55951 m .32176 .55725 L .3227 .55656 L F
.32329 .55951 m .32059 .56005 L .32176 .55725 L F
.554 .856 .997 r
.24235 .63484 m .24421 .63572 L .24615 .63504 L F
.433 0 0 r
.3409 .6699 m .33862 .66889 L .34239 .66858 L F
.643 .257 .297 r
.34444 .66823 m .3409 .6699 L .34239 .66858 L F
.056 .556 .885 r
.32526 .57114 m .32528 .57082 L .32295 .57022 L F
.32706 .57186 m .32528 .57082 L .32526 .57114 L F
.65 .635 .822 r
.32464 .56888 m .32528 .57082 L .32753 .56844 L F
.524 .557 .831 r
.32295 .57022 m .32528 .57082 L .32464 .56888 L F
.44 .781 .998 r
.32361 .56968 m .32581 .56937 L .32528 .57082 L F
.4 .183 .464 r
.32581 .56937 m .32531 .57015 L .32528 .57082 L F
.295 0 .008 r
.32528 .57082 m .32128 .57342 L .32353 .56981 L F
.32528 .57082 m .32353 .56981 L .32361 .56968 L F
.32528 .57082 m .32324 .57343 L .32128 .57342 L F
.4 .183 .464 r
.32531 .57015 m .32324 .57343 L .32528 .57082 L F
.056 .556 .885 r
.32742 .572 m .32528 .57082 L .32706 .57186 L F
.532 .684 .936 r
.32742 .572 m .32753 .56844 L .32528 .57082 L F
.32742 .572 m .32975 .57161 L .32753 .56844 L F
.316 .211 .573 r
.32742 .572 m .32937 .57439 L .32975 .57161 L F
.32742 .572 m .32778 .5753 L .32937 .57439 L F
0 .084 .553 r
.52764 .53614 m .52653 .53525 L .52515 .53416 L F
.621 .279 .368 r
.52653 .53525 m .529 .53728 L .52937 .53509 L F
0 .084 .553 r
.52764 .53614 m .529 .53728 L .52653 .53525 L F
.43 .334 .645 r
.37269 .54613 m .37367 .55025 L .37528 .54935 L F
.204 .295 .736 r
.34039 .55917 m .34182 .56366 L .34228 .56193 L F
0 0 .512 r
.34182 .56366 m .34217 .56623 L .34228 .56193 L F
.522 .601 .874 r
.50926 .55961 m .50993 .55579 L .50745 .55651 L F
.50926 .55961 m .51157 .55923 L .50993 .55579 L F
0 0 0 r
.19995 .55143 m .19675 .55347 L .19869 .55237 L F
.138 0 0 r
.19869 .55237 m .20204 .55046 L .19995 .55143 L F
.161 .594 .935 r
.26307 .63857 m .26486 .63981 L .26672 .64004 L F
0 0 .27 r
.31796 .61417 m .31748 .61865 L .31655 .61652 L F
.322 .332 .715 r
.38666 .56832 m .38778 .57287 L .38573 .57252 L F
.334 .303 .674 r
.38778 .57287 m .38836 .57469 L .38573 .57252 L F
.418 0 0 r
.23515 .74971 m .23665 .74964 L .23252 .74909 L F
.464 .242 .49 r
.31255 .5629 m .31145 .56513 L .30965 .56317 L F
0 0 .198 r
.30748 .55711 m .30868 .55275 L .30615 .55313 L F
.30748 .55711 m .30847 .55554 L .30868 .55275 L F
0 0 .506 r
.30748 .55711 m .30905 .55777 L .30847 .55554 L F
.30748 .55711 m .30811 .55938 L .30905 .55777 L F
.429 .585 .905 r
.28734 .64441 m .29063 .64772 L .29094 .64673 L F
.612 .955 .893 r
.23269 .75397 m .23464 .75369 L .23644 .7525 L F
.478 .391 .679 r
.32176 .65039 m .32457 .65246 L .32377 .64992 L F
.32176 .65039 m .32197 .65332 L .32457 .65246 L F
.459 .357 .652 r
.35674 .58799 m .35882 .58753 L .35851 .58473 L F
.626 .571 .773 r
.35697 .59067 m .35882 .58753 L .35674 .58799 L F
.104 0 .316 r
.33415 .57793 m .33202 .58142 L .33196 .57886 L F
.281 .049 .373 r
.33244 .6153 m .33049 .6161 L .33006 .61844 L F
.566 .44 .667 r
.35298 .60049 m .35552 .60008 L .3553 .5973 L F
.561 .417 .643 r
.35298 .60049 m .35329 .60294 L .35552 .60008 L F
.35298 .60049 m .35329 .60294 L .35552 .60008 L F
.321 .682 .978 r
.25191 .63523 m .25516 .63689 L .25658 .63678 L F
.808 .594 .612 r
.24613 .74492 m .25023 .74285 L .24849 .74274 L F
.471 .811 .999 r
.32166 .53067 m .31836 .53023 L .31885 .53004 L F
.548 .705 .943 r
.32236 .52801 m .32166 .53067 L .31885 .53004 L F
.32236 .52801 m .32484 .53083 L .32166 .53067 L F
.515 .312 .542 r
.54235 .55028 m .53965 .55352 L .53951 .5507 L F
.041 0 .097 r
.28674 .61235 m .28792 .61028 L .28936 .60935 L F
.448 .851 .664 r
.2351 .55086 m .23528 .551 L .23745 .55006 L F
.2351 .55086 m .23317 .55217 L .23528 .551 L F
.36 0 0 r
.29452 .52773 m .29692 .52833 L .29853 .52818 L F
0 0 0 r
.29853 .52818 m .29692 .52833 L .3009 .52802 L F
.225 0 .108 r
.3917 .55863 m .38906 .5596 L .39216 .55731 L F
.571 .165 .234 r
.39216 .55731 m .39414 .5589 L .3917 .55863 L F
.447 .212 .463 r
.39454 .55646 m .39414 .5589 L .39216 .55731 L F
0 .488 .83 r
.18828 .60443 m .18846 .604 L .18771 .60277 L F
.18828 .60443 m .19166 .60548 L .18846 .604 L F
.617 .451 .634 r
.35315 .54444 m .3563 .54455 L .35505 .54136 L F
.645 .503 .674 r
.35505 .54136 m .3573 .54366 L .35898 .53887 L F
.631 .487 .669 r
.35898 .53887 m .3573 .54366 L .36073 .54251 L F
.351 0 .036 r
.35842 .54372 m .36073 .54251 L .3573 .54366 L F
.496 .387 .66 r
.35505 .54136 m .35842 .54372 L .3573 .54366 L F
.35505 .54136 m .3563 .54455 L .35842 .54372 L F
.35 .551 .908 r
.19937 .61158 m .20011 .61322 L .20101 .61141 L F
.233 .405 .828 r
.20011 .61322 m .2027 .61474 L .20101 .61141 L F
.689 .342 .381 r
.52937 .53509 m .529 .53728 L .53314 .53714 L F
.592 .169 .209 r
.35037 .55734 m .34835 .55959 L .34579 .55883 L F
.242 0 0 r
.35089 .55891 m .35037 .55734 L .35177 .55605 L F
.35089 .55891 m .34835 .55959 L .35037 .55734 L F
.258 .45 .859 r
.39447 .54543 m .3933 .54721 L .39129 .54407 L F
.39447 .54543 m .39453 .54695 L .3933 .54721 L F
.208 .179 .604 r
.39453 .54695 m .39517 .54961 L .3933 .54721 L F
.293 0 0 r
.24315 .55789 m .2451 .55821 L .24708 .55712 L F
.287 .734 .961 r
.2451 .55821 m .24941 .55905 L .24708 .55712 L F
.508 .354 .607 r
.33404 .64986 m .33168 .65305 L .33159 .65046 L F
0 .277 .765 r
.27931 .55608 m .28091 .55679 L .27917 .55512 L F
0 .294 .722 r
.28192 .55766 m .28115 .55695 L .27931 .55608 L F
.759 .68 .775 r
.27917 .55512 m .28184 .55768 L .283 .55591 L F
0 .294 .722 r
.28115 .55695 m .28105 .55686 L .28091 .55679 L F
.28115 .55695 m .28091 .55679 L .27931 .55608 L F
.759 .68 .775 r
.28091 .55679 m .28117 .5587 L .28115 .55702 L F
.985 .834 .446 r
.28115 .55695 m .28117 .5587 L .28105 .55686 L F
.28192 .55766 m .28117 .5587 L .28115 .55695 L F
.759 .68 .775 r
.28115 .55702 m .28117 .5587 L .28184 .55768 L F
.27917 .55512 m .27965 .55599 L .28091 .55679 L F
.27965 .55599 m .28117 .5587 L .28091 .55679 L F
0 .277 .765 r
.28091 .55679 m .28105 .55686 L .27917 .55512 L F
.541 .785 .989 r
.27917 .55512 m .27948 .55519 L .28135 .55455 L F
.27948 .55519 m .283 .55591 L .28135 .55455 L F
.952 .774 .625 r
.283 .55591 m .28426 .55721 L .28394 .5536 L F
.069 0 .212 r
.28546 .55223 m .283 .55591 L .28394 .5536 L F
.28546 .55223 m .283 .55591 L .28394 .5536 L F
.881 .85 .809 r
.28135 .55455 m .283 .55591 L .28546 .55223 L F
.28135 .55455 m .28546 .55223 L .28422 .55239 L F
.266 0 .203 r
.28422 .55239 m .28261 .55412 L .28135 .55455 L F
.628 .83 .426 r
.28192 .55766 m .28117 .5587 L .283 .55591 L F
.28192 .55766 m .283 .55591 L .28426 .55721 L F
.28192 .55766 m .28117 .5587 L .283 .55591 L F
0 0 0 r
.283 .55591 m .28117 .5587 L .28233 .55716 L F
.656 .639 .822 r
.28105 .55686 m .28117 .5587 L .27917 .55512 L F
.613 .573 .786 r
.28543 .55912 m .28192 .55766 L .28426 .55721 L F
.726 .292 .219 r
.28233 .55716 m .28501 .55818 L .283 .55591 L F
.667 .233 .21 r
.2836 .55664 m .2796 .55652 L .28135 .55455 L F
.2836 .55664 m .28135 .55455 L .28151 .5553 L F
.266 0 .203 r
.28261 .55412 m .28151 .5553 L .28135 .55455 L F
.491 .03 .086 r
.28135 .55455 m .27934 .55536 L .27917 .55512 L F
0 .277 .765 r
.27931 .55608 m .27917 .55512 L .27892 .55479 L F
.491 .03 .086 r
.27934 .55536 m .2773 .55617 L .27917 .55512 L F
0 .277 .765 r
.27892 .55479 m .27917 .55512 L .27827 .55259 L F
.148 .154 .608 r
.30922 .60998 m .31128 .6112 L .31115 .60834 L F
.30922 .60998 m .30988 .61251 L .31128 .6112 L F
.653 .814 .961 r
.23373 .73991 m .23777 .74029 L .2363 .73893 L F
.23373 .73991 m .23777 .74029 L .2363 .73893 L F
.294 .642 .967 r
.2363 .73893 m .23777 .74029 L .23829 .73903 L F
.23829 .73903 m .23777 .74029 L .2363 .73893 L F
.044 0 0 r
.31143 .54114 m .30908 .54236 L .31124 .53983 L F
.81 .714 .759 r
.32091 .66312 m .31817 .6654 L .31667 .66184 L F
.91 .705 .612 r
.33302 .66475 m .33551 .66599 L .33467 .66856 L F
.67 .873 .975 r
.30596 .5403 m .30431 .54152 L .30741 .54137 L F
.132 .003 .425 r
.30908 .54236 m .30727 .544 L .30741 .54137 L F
.889 .753 .706 r
.31414 .56584 m .31255 .5629 L .31563 .56304 L F
.393 .194 .488 r
.31812 .55947 m .31563 .56304 L .31446 .55985 L F
.31812 .55947 m .31764 .56271 L .31563 .56304 L F
.568 .539 .783 r
.31878 .5659 m .31563 .56304 L .31764 .56271 L F
.326 .774 .958 r
.33467 .66856 m .33862 .66889 L .33687 .6683 L F
.314 0 0 r
.33687 .6683 m .33862 .66889 L .3409 .6699 L F
.97 .718 .291 r
.32745 .54666 m .3265 .54365 L .33056 .54443 L F
.32745 .54666 m .3266 .54628 L .3265 .54365 L F
.308 .068 .377 r
.2524 .5574 m .25423 .55687 L .25507 .55354 L F
.463 .258 .515 r
.25507 .55354 m .25749 .5533 L .25791 .55032 L F
.591 .327 .485 r
.25507 .55354 m .25744 .55585 L .25749 .5533 L F
.25507 .55354 m .25423 .55687 L .25744 .55585 L F
.316 0 0 r
.24315 .55789 m .24113 .55965 L .2451 .55821 L F
.567 .726 .949 r
.51929 .56224 m .52082 .55972 L .51766 .56146 L F
.51929 .56224 m .522 .56181 L .52082 .55972 L F
0 0 0 r
.26889 .61853 m .27019 .61803 L .27115 .61505 L F
0 0 .032 r
.2737 .61214 m .27115 .61505 L .27283 .61462 L F
.12 0 .097 r
.27115 .61505 m .27213 .61694 L .27283 .61462 L F
.27115 .61505 m .27019 .61803 L .27213 .61694 L F
.941 .871 .453 r
.30147 .58299 m .30273 .58126 L .30203 .58055 L F
.30147 .58299 m .30184 .58482 L .30273 .58126 L F
.848 .998 .811 r
.30412 .57798 m .30273 .58126 L .30551 .57877 L F
.30412 .57798 m .30203 .58055 L .30273 .58126 L F
.27 0 0 r
.25022 .63489 m .25071 .6357 L .24899 .63542 L F
.25022 .63489 m .25191 .63523 L .25071 .6357 L F
.665 .369 .461 r
.36086 .53736 m .36377 .53754 L .3644 .53498 L F
0 0 .186 r
.3644 .53498 m .36555 .5357 L .36684 .53429 L F
.3644 .53498 m .36377 .53754 L .36555 .5357 L F
.56 .624 .873 r
.29642 .65349 m .29654 .64933 L .29557 .64958 L F
.29642 .65349 m .29868 .65356 L .29654 .64933 L F
.108 0 0 r
.29848 .65382 m .29868 .65356 L .29642 .65349 L F
.29642 .65349 m .29868 .65356 L .29848 .65382 L F
.355 0 .062 r
.29963 .5967 m .29999 .59739 L .29724 .59762 L F
0 0 .456 r
.30028 .59431 m .29963 .5967 L .29954 .59394 L F
0 0 .314 r
.30028 .59431 m .29999 .59739 L .29963 .5967 L F
.23 0 0 r
.35168 .61355 m .35247 .61337 L .35415 .61372 L F
.743 .698 .809 r
.34228 .56193 m .34217 .56623 L .33969 .5613 L F
.188 .711 .688 r
.23729 .53463 m .23504 .53524 L .23243 .53593 L F
0 0 .417 r
.37175 .52488 m .37161 .52631 L .37099 .52226 L F
0 .248 .686 r
.37175 .52488 m .37486 .52693 L .37161 .52631 L F
.681 .606 .765 r
.34952 .64945 m .34751 .6526 L .34778 .65021 L F
.633 .369 .501 r
.3191 .65573 m .32176 .65593 L .32197 .65332 L F
.547 .369 .592 r
.32176 .65593 m .32457 .65246 L .32197 .65332 L F
.123 0 .371 r
.30116 .5874 m .30073 .58999 L .29883 .59108 L F
0 0 0 r
.30073 .58999 m .29954 .59394 L .29883 .59108 L F
.614 .494 .693 r
.37943 .59079 m .37721 .59388 L .3767 .59117 L F
.57 .307 .478 r
.34962 .62867 m .35183 .63064 L .35237 .62822 L F
.715 .738 .869 r
.33466 .60624 m .33147 .60684 L .33402 .60601 L F
.466 .031 .128 r
.33402 .60601 m .33724 .60597 L .33466 .60624 L F
.722 .439 .496 r
.31559 .65337 m .31536 .6558 L .3191 .65573 L F
.43 .746 .993 r
.27634 .54291 m .2783 .5444 L .27588 .54454 L F
.27634 .54291 m .2783 .5444 L .27588 .54454 L F
.602 .25 .346 r
.26834 .55366 m .26695 .55613 L .26418 .556 L F
.498 .139 .287 r
.27101 .55506 m .26834 .55366 L .27087 .55413 L F
.27101 .55506 m .26695 .55613 L .26834 .55366 L F
.42 .337 .656 r
.32217 .63742 m .32443 .64068 L .32448 .63696 L F
.32217 .63742 m .32245 .64117 L .32443 .64068 L F
.778 .523 .55 r
.20131 .59066 m .20047 .58919 L .20147 .58802 L F
.304 .165 .521 r
.20277 .58951 m .20131 .59066 L .20147 .58802 L F
.386 .247 .566 r
.33619 .57436 m .33415 .57793 L .33394 .57536 L F
.497 .594 .881 r
.19448 .60711 m .19622 .61023 L .19792 .60799 L F
.45 .527 .845 r
.19622 .61023 m .19937 .61158 L .19792 .60799 L F
.632 .495 .677 r
.31986 .62469 m .32013 .62795 L .31672 .62842 L F
.568 .277 .434 r
.31672 .62842 m .31861 .6303 L .31658 .63083 L F
.31672 .62842 m .32013 .62795 L .31861 .6303 L F
.332 0 0 r
.24687 .56005 m .24517 .56198 L .24257 .5623 L F
.043 0 0 r
.24729 .56114 m .24687 .56005 L .24941 .55905 L F
.24729 .56114 m .24517 .56198 L .24687 .56005 L F
.515 .4 .661 r
.19767 .57747 m .19575 .58146 L .19569 .5786 L F
.526 .329 .556 r
.35274 .54612 m .35096 .5475 L .35315 .54444 L F
.581 .254 .38 r
.35315 .54444 m .35571 .54637 L .3563 .54455 L F
.35315 .54444 m .35571 .54637 L .3563 .54455 L F
.192 .235 .677 r
.17142 .58456 m .17208 .58794 L .17325 .58741 L F
.144 .116 .565 r
.17208 .58794 m .17369 .59009 L .17325 .58741 L F
.051 .091 .583 r
.17272 .59042 m .17369 .59009 L .17208 .58794 L F
0 0 0 r
.3423 .61001 m .34085 .61208 L .34003 .6126 L F
.846 .943 .58 r
.34299 .60818 m .34085 .61208 L .3423 .61001 L F
.974 .673 .297 r
.34143 .6076 m .34299 .60818 L .34278 .60564 L F
.943 .959 .732 r
.34141 .60742 m .34085 .61208 L .34299 .60818 L F
.273 .216 .609 r
.34221 .6112 m .34139 .60765 L .34141 .60764 L F
.974 .673 .297 r
.34141 .60764 m .34146 .6077 L .34143 .6076 L F
.34143 .60769 m .34146 .6077 L .34141 .60764 L F
.273 .216 .609 r
.3416 .60829 m .34141 .60764 L .34145 .60761 L F
.34221 .6112 m .34141 .60764 L .3416 .60829 L F
.974 .673 .297 r
.34138 .60768 m .34143 .60769 L .34141 .60764 L F
.34146 .6077 m .34299 .60818 L .34143 .6076 L F
0 0 0 r
.34145 .60761 m .34278 .60564 L .34484 .60438 L F
.34141 .60764 m .34143 .6076 L .34144 .60761 L F
.34141 .60764 m .34144 .60761 L .34142 .60763 L F
.943 .959 .732 r
.34141 .60742 m .34155 .60748 L .34142 .60763 L F
.34155 .60748 m .34299 .60818 L .34138 .60768 L F
0 0 0 r
.34142 .60763 m .34144 .60761 L .34145 .60761 L F
.34143 .6076 m .34145 .60761 L .34145 .60761 L F
.273 .216 .609 r
.34145 .60761 m .34142 .60763 L .34141 .60742 L F
.34142 .60763 m .34139 .60765 L .34141 .60742 L F
.943 .959 .732 r
.34141 .60742 m .34142 .60763 L .34138 .60768 L F
0 0 0 r
.34143 .6076 m .34278 .60564 L .34145 .60761 L F
.684 .275 .264 r
.34484 .60438 m .34838 .60658 L .34186 .60812 L F
0 0 0 r
.3415 .60779 m .34484 .60438 L .34186 .60812 L F
.34138 .60768 m .34145 .60761 L .3415 .60779 L F
.34145 .60761 m .34484 .60438 L .3415 .60779 L F
0 0 .314 r
.34319 .61346 m .34312 .61369 L .34275 .61234 L F
.34268 .61178 m .34275 .61234 L .34193 .60931 L F
.34319 .61346 m .34275 .61234 L .34268 .61178 L F
.34146 .60761 m .34145 .60761 L .34141 .60742 L F
0 0 0 r
.34138 .60768 m .34141 .60764 L .34145 .60761 L F
.589 .443 .651 r
.34186 .60812 m .34141 .60742 L .34138 .60768 L F
.34186 .60812 m .34271 .60769 L .34141 .60742 L F
0 0 .314 r
.34147 .60755 m .34141 .60742 L .34271 .60769 L F
.415 .132 .373 r
.34139 .60752 m .34271 .60769 L .34141 .60742 L F
.45 .068 .221 r
.34186 .60812 m .34371 .60782 L .34271 .60769 L F
0 0 .314 r
.34275 .60813 m .34147 .60755 L .34271 .60769 L F
.34301 .61125 m .34183 .60841 L .34275 .60813 L F
.34183 .60841 m .34147 .60755 L .34275 .60813 L F
.45 .068 .221 r
.34376 .60781 m .34838 .60658 L .34867 .60703 L F
0 0 .314 r
.34267 .61168 m .34141 .60742 L .34301 .61125 L F
.34208 .60968 m .34193 .60931 L .34141 .60742 L F
.34312 .61369 m .34299 .61411 L .34149 .60774 L F
.34312 .61369 m .34149 .60774 L .34141 .60742 L F
.34299 .61411 m .3416 .60829 L .34154 .60803 L F
.34158 .60812 m .34154 .60803 L .34145 .60761 L F
.34299 .61411 m .34154 .60803 L .34158 .60812 L F
.34299 .61411 m .34145 .60761 L .34146 .60761 L F
.34299 .61411 m .3429 .61444 L .3416 .60829 L F
.273 .216 .609 r
.34221 .6112 m .34085 .61208 L .34139 .60765 L F
.415 .132 .373 r
.34109 .60877 m .34271 .60769 L .34139 .60752 L F
.3403 .61213 m .34238 .6083 L .34109 .60877 L F
.34238 .6083 m .34271 .60769 L .34109 .60877 L F
.45 .068 .221 r
.34371 .60782 m .34572 .6072 L .34376 .60781 L F
.34275 .60797 m .34482 .60742 L .34371 .60782 L F
.34195 .6081 m .34272 .60792 L .34275 .60797 L F
.34272 .60792 m .34482 .60742 L .34275 .60797 L F
.34194 .6081 m .34482 .60742 L .34195 .6081 L F
.34482 .60742 m .34572 .6072 L .34371 .60782 L F
.34572 .6072 m .34838 .60658 L .34376 .60781 L F
.34371 .60782 m .34376 .60781 L .34271 .60769 L F
.34376 .60781 m .34867 .60703 L .34271 .60769 L F
.842 .739 .75 r
.34867 .60703 m .34403 .61247 L .34271 .60769 L F
.34403 .61247 m .34319 .61346 L .34271 .60769 L F
0 0 .44 r
.34271 .60769 m .34315 .60866 L .34295 .6065 L F
.34315 .60866 m .34359 .60963 L .34352 .60929 L F
.34315 .60866 m .34352 .60929 L .34295 .6065 L F
.415 .132 .373 r
.34193 .60913 m .34359 .60963 L .34315 .60866 L F
.34238 .6083 m .34315 .60866 L .34271 .60769 L F
.34193 .60913 m .34315 .60866 L .34238 .6083 L F
.45 .068 .221 r
.34186 .60812 m .34194 .6081 L .34195 .6081 L F
0 0 .314 r
.34319 .61346 m .34267 .61168 L .34301 .61125 L F
.415 .132 .373 r
.34242 .61052 m .34359 .60963 L .34193 .60913 L F
.439 .3 .594 r
.34295 .6065 m .34359 .60963 L .34468 .60726 L F
.937 .921 .77 r
.34468 .60726 m .34359 .60963 L .34256 .61087 L F
0 0 .314 r
.34319 .61346 m .34193 .60931 L .34208 .60968 L F
.308 0 .249 r
.34175 .61185 m .34256 .61087 L .3403 .61213 L F
.937 .921 .77 r
.34253 .61062 m .34256 .61087 L .34175 .61185 L F
.308 0 .249 r
.34256 .61087 m .34359 .60963 L .34242 .61052 L F
.937 .921 .77 r
.34468 .60726 m .34256 .61087 L .34253 .61062 L F
.308 0 .249 r
.34256 .61087 m .34242 .61052 L .3403 .61213 L F
.415 .132 .373 r
.3403 .61213 m .34242 .61052 L .34193 .60913 L F
.273 .216 .609 r
.3429 .61444 m .34085 .61208 L .34221 .6112 L F
0 0 0 r
.34003 .6126 m .34085 .61208 L .33978 .61289 L F
.298 .149 .503 r
.34137 .61473 m .33978 .61289 L .34085 .61208 L F
.34137 .61473 m .33964 .61507 L .33978 .61289 L F
.331 .325 .702 r
.35161 .62542 m .3529 .6216 L .35053 .62198 L F
.35161 .62542 m .35389 .62456 L .3529 .6216 L F
0 0 .432 r
.35161 .62542 m .35272 .62664 L .35389 .62456 L F
.35161 .62542 m .35237 .62822 L .35272 .62664 L F
.038 0 0 r
.34784 .55226 m .35085 .55011 L .34924 .55192 L F
.287 .055 .376 r
.19086 .55929 m .1932 .55622 L .19123 .55679 L F
.532 .81 .997 r
.22399 .6137 m .22336 .61549 L .22155 .61435 L F
.22399 .6137 m .22573 .61489 L .22336 .61549 L F
.602 .48 .686 r
.3917 .55863 m .38989 .56186 L .38906 .5596 L F
.154 .69 .693 r
.30005 .5513 m .29821 .5517 L .29553 .55228 L F
.672 .155 0 r
.30005 .5513 m .29998 .55242 L .29821 .5517 L F
.393 .814 .971 r
.29893 .55199 m .30045 .55185 L .29821 .5517 L F
.29893 .55199 m .29762 .55182 L .30045 .55185 L F
.298 .55174 m .29893 .55199 L .29821 .5517 L F
.29553 .55228 m .29876 .552 L .298 .55174 L F
.29876 .552 m .29893 .55199 L .298 .55174 L F
.29553 .55228 m .29945 .55143 L .29449 .5493 L F
.154 .69 .693 r
.29821 .5517 m .29762 .55182 L .29553 .55228 L F
.393 .814 .971 r
.29575 .55226 m .29762 .55182 L .29893 .55199 L F
.29553 .55228 m .29762 .55182 L .29575 .55226 L F
.52 0 0 r
.29998 .55242 m .30097 .55338 L .29762 .55182 L F
.30221 .55298 m .30191 .55308 L .29998 .55242 L F
.672 .155 0 r
.3 .55212 m .30221 .55298 L .29998 .55242 L F
.29821 .5517 m .29998 .55242 L .29762 .55182 L F
.393 .814 .971 r
.29821 .5517 m .30045 .55185 L .29945 .55143 L F
.715 .557 .672 r
.29449 .5493 m .30045 .55185 L .29755 .54637 L F
.668 .823 .958 r
.30045 .55185 m .29762 .55182 L .2992 .55053 L F
.477 .44 .738 r
.29762 .55182 m .30097 .55338 L .2997 .55133 L F
.29762 .55182 m .2997 .55133 L .2992 .55053 L F
.52 0 0 r
.30191 .55308 m .30097 .55338 L .29998 .55242 L F
.672 .155 0 r
.30005 .5513 m .30132 .55229 L .3 .55212 L F
.30132 .55229 m .30221 .55298 L .3 .55212 L F
.328 .097 .403 r
.3272 .63388 m .32492 .63464 L .32448 .63696 L F
.549 .401 .633 r
.3365 .64935 m .33338 .64642 L .33666 .64656 L F
.3365 .64935 m .33404 .64986 L .33338 .64642 L F
.657 .77 .932 r
.30479 .60157 m .30625 .59921 L .30415 .59922 L F
.30479 .60157 m .30698 .60111 L .30625 .59921 L F
.144 .332 .793 r
.34626 .64039 m .34793 .64404 L .34653 .64372 L F
.169 0 0 r
.1932 .55622 m .19526 .55558 L .19675 .55347 L F
.142 0 0 r
.19675 .55347 m .19732 .55487 L .19869 .55237 L F
.19675 .55347 m .19526 .55558 L .19732 .55487 L F
.577 .708 .932 r
.26308 .54585 m .26664 .54725 L .26528 .54601 L F
.493 .753 .987 r
.26528 .54601 m .26664 .54725 L .2676 .54564 L F
.681 .622 .783 r
.26653 .5496 m .2676 .54564 L .26664 .54725 L F
0 0 .279 r
.33563 .64181 m .33571 .64246 L .33621 .6404 L F
.702 .821 .938 r
.33571 .64246 m .33838 .64012 L .33621 .6404 L F
.015 .59 .718 r
.26721 .52952 m .27174 .52951 L .26944 .52992 L F
0 0 0 r
.29993 .62578 m .29731 .62829 L .29815 .62789 L F
.615 .217 .265 r
.29815 .62789 m .30172 .6268 L .29993 .62578 L F
.865 .671 .638 r
.30172 .6268 m .30253 .62528 L .29993 .62578 L F
0 0 .313 r
.3345 .60918 m .33294 .61283 L .33447 .61197 L F
.058 0 .285 r
.33447 .61197 m .33294 .61283 L .33244 .6153 L F
.702 .556 .685 r
.24973 .73669 m .2536 .73757 L .25376 .73539 L F
.384 .281 .613 r
.25376 .73539 m .2536 .73757 L .2552 .73656 L F
.501 .266 .49 r
.2552 .73656 m .25606 .73473 L .25376 .73539 L F
.384 .281 .613 r
.25376 .73539 m .2536 .73757 L .2552 .73656 L F
.307 0 0 r
.3566 .61954 m .35934 .61972 L .35915 .61942 L F
.3566 .61954 m .35542 .62106 L .35934 .61972 L F
.342 .471 .846 r
.35934 .61972 m .3566 .61954 L .35915 .61942 L F
.174 .024 .425 r
.3006 .57206 m .30265 .57119 L .30289 .56853 L F
0 0 0 r
.30043 .57429 m .30265 .57119 L .3006 .57206 L F
.517 .483 .758 r
.31806 .54996 m .31907 .55358 L .31671 .55357 L F
.687 .406 .492 r
.53314 .53714 m .53522 .53773 L .5348 .53525 L F
.736 .44 .48 r
.5348 .53525 m .53522 .53773 L .53892 .53779 L F
.132 0 .053 r
.29618 .59934 m .29424 .60016 L .29724 .59762 L F
.306 0 0 r
.29724 .59762 m .29802 .59871 L .29618 .59934 L F
.29769 .59758 m .29999 .59739 L .29802 .59871 L F
.947 .87 .729 r
.29802 .59871 m .29999 .59739 L .30028 .59431 L F
0 0 .123 r
.29891 .59727 m .29829 .59962 L .29802 .59871 L F
.29829 .59962 m .29787 .60122 L .29802 .59871 L F
.306 0 0 r
.29724 .59762 m .29769 .59758 L .29802 .59871 L F
.515 .508 .786 r
.51298 .56261 m .51419 .55851 L .51157 .55923 L F
.51298 .56261 m .51536 .56239 L .51419 .55851 L F
.126 0 .12 r
.25702 .72384 m .25354 .72774 L .25565 .72731 L F
.613 .77 .955 r
.25965 .72377 m .25702 .72384 L .25901 .72372 L F
.38 .062 .296 r
.25901 .72372 m .25702 .72384 L .25565 .72731 L F
.206 .268 .707 r
.21034 .56524 m .21011 .56943 L .21195 .56608 L F
.883 .908 .841 r
.21308 .56184 m .21195 .56608 L .21276 .56354 L F
.21308 .56184 m .21034 .56524 L .21195 .56608 L F
0 0 .049 r
.28716 .54292 m .28757 .53891 L .28562 .53951 L F
.28716 .54292 m .28751 .54154 L .28757 .53891 L F
.615 .951 .792 r
.28716 .54292 m .28482 .54332 L .28751 .54154 L F
.889 .753 .706 r
.31414 .56584 m .31145 .56513 L .31255 .5629 L F
.501 0 0 r
.31414 .56584 m .31428 .56669 L .31145 .56513 L F
.31414 .56584 m .3166 .56757 L .31428 .56669 L F
.508 .823 .507 r
.33707 .6621 m .33792 .66122 L .33976 .6594 L F
.681 .908 .57 r
.33976 .6594 m .33792 .66122 L .34035 .65813 L F
.626 .571 .773 r
.35697 .59067 m .36051 .59146 L .35882 .58753 L F
.646 .531 .709 r
.35697 .59067 m .35802 .59412 L .36051 .59146 L F
.439 .16 .392 r
.18557 .56284 m .18788 .56232 L .18849 .55995 L F
.119 0 .26 r
.18849 .55995 m .18952 .56113 L .19086 .55929 L F
.18849 .55995 m .18788 .56232 L .18952 .56113 L F
.198 .727 .818 r
.25004 .73792 m .2536 .73757 L .25271 .7397 L F
.716 .448 .52 r
.25271 .7397 m .24973 .73669 L .25004 .73792 L F
.25271 .7397 m .2536 .73757 L .24973 .73669 L F
.5 .62 .902 r
.37648 .52621 m .37486 .52693 L .37723 .52706 L F
.37648 .52621 m .37639 .52691 L .37486 .52693 L F
.454 .576 .887 r
.37639 .52691 m .37843 .52926 L .37608 .52935 L F
.728 .621 .739 r
.37984 .52545 m .37648 .52621 L .37723 .52706 L F
.643 .962 .914 r
.37723 .52706 m .37739 .52653 L .37984 .52545 L F
.728 .621 .739 r
.3794 .52555 m .37739 .52653 L .37648 .52621 L F
.37984 .52545 m .37727 .52659 L .3794 .52555 L F
.643 .962 .914 r
.37739 .52653 m .37775 .52529 L .37984 .52545 L F
.728 .621 .739 r
.37739 .52653 m .37727 .52659 L .37726 .52659 L F
.37739 .52653 m .37726 .52659 L .37648 .52621 L F
.37984 .52545 m .38064 .52825 L .37727 .52659 L F
.643 .962 .914 r
.37723 .52706 m .37684 .52689 L .37689 .52684 L F
.197 .727 .783 r
.37486 .52693 m .37686 .5269 L .37723 .52706 L F
.631 .661 .861 r
.38064 .52825 m .37843 .52926 L .37689 .52684 L F
.37727 .52659 m .37689 .52684 L .37648 .52621 L F
.643 .962 .914 r
.37723 .52706 m .37689 .52684 L .37705 .52673 L F
.37723 .52706 m .37703 .5267 L .37739 .52653 L F
.631 .661 .861 r
.38064 .52825 m .37689 .52684 L .37727 .52659 L F
.643 .962 .914 r
.37705 .52673 m .37689 .52684 L .37703 .5267 L F
.37739 .52653 m .37703 .5267 L .37745 .5263 L F
.37745 .5263 m .37606 .52654 L .37775 .52529 L F
.454 .576 .887 r
.37648 .52621 m .37689 .52684 L .37639 .52691 L F
.643 .962 .914 r
.37684 .52689 m .37606 .52654 L .37745 .5263 L F
.454 .576 .887 r
.37689 .52684 m .37692 .52689 L .37684 .52689 L F
.37689 .52684 m .37684 .52689 L .37639 .52691 L F
.197 .727 .783 r
.37639 .52691 m .37684 .52689 L .37686 .5269 L F
.454 .576 .887 r
.37692 .52689 m .37843 .52926 L .37639 .52691 L F
.197 .727 .783 r
.37486 .52693 m .37606 .52654 L .37684 .52689 L F
.37486 .52693 m .37684 .52689 L .37639 .52691 L F
.5 .62 .902 r
.37639 .52691 m .37608 .52935 L .37486 .52693 L F
0 0 .463 r
.20185 .59313 m .20261 .59656 L .20194 .59451 L F
.206 .268 .707 r
.21034 .56524 m .21103 .56868 L .21011 .56943 L F
.608 .235 .31 r
.21103 .56868 m .20786 .57041 L .21011 .56943 L F
0 0 0 r
.29443 .585 m .2921 .58816 L .29325 .58674 L F
.813 .884 .456 r
.29598 .58125 m .29443 .585 L .29477 .58311 L F
0 0 0 r
.29443 .585 m .29469 .58573 L .29477 .58311 L F
0 0 .265 r
.29469 .58573 m .29465 .58838 L .29558 .58647 L F
.29469 .58573 m .29558 .58647 L .29505 .58614 L F
0 0 0 r
.29427 .58524 m .29325 .58674 L .29469 .58573 L F
.285 0 .157 r
.29325 .58674 m .29465 .58838 L .29469 .58573 L F
0 0 .265 r
.29469 .58573 m .29505 .58614 L .29283 .58475 L F
0 0 0 r
.29443 .585 m .29427 .58524 L .29469 .58573 L F
.518 .229 .414 r
.22934 .55398 m .22892 .55622 L .22617 .55652 L F
0 0 .13 r
.22978 .55527 m .22934 .55398 L .23148 .5533 L F
.22978 .55527 m .22892 .55622 L .22934 .55398 L F
.866 .802 .785 r
.36773 .56601 m .36543 .56868 L .36697 .56806 L F
.715 .388 .423 r
.36543 .56868 m .36772 .57131 L .36697 .56806 L F
.389 .271 .596 r
.36697 .56806 m .36984 .56789 L .36773 .56601 L F
.373 .175 .479 r
.36697 .56806 m .36772 .57131 L .36984 .56789 L F
.507 .19 .365 r
.24208 .54611 m .23953 .54673 L .24015 .54439 L F
.483 .195 .399 r
.24261 .54393 m .24208 .54611 L .24015 .54439 L F
.197 0 0 r
.2775 .60668 m .27902 .60619 L .27653 .60707 L F
.345 .058 .326 r
.2775 .60668 m .27546 .61158 L .27778 .61094 L F
.766 .338 .234 r
.3547 .56731 m .35307 .56984 L .35203 .56788 L F
.647 .151 .057 r
.3547 .56731 m .35404 .56865 L .35404 .56865 L F
0 0 0 r
.3547 .56731 m .35404 .56865 L .35591 .56734 L F
.683 .796 .934 r
.35591 .56734 m .35404 .56865 L .35404 .56864 L F
.554 .301 .486 r
.35591 .56734 m .35404 .56865 L .3547 .56731 L F
.35373 .56926 m .35307 .56984 L .35379 .56872 L F
.35404 .56865 m .35379 .56872 L .3547 .56731 L F
.35373 .56926 m .35379 .56872 L .35404 .56865 L F
.647 .151 .057 r
.3547 .56731 m .35404 .56865 L .35203 .56788 L F
.197 .575 .94 r
.35171 .56668 m .35404 .56864 L .35203 .56788 L F
.35404 .56864 m .35404 .56865 L .35404 .56865 L F
.35404 .56864 m .35404 .56865 L .35203 .56788 L F
.532 .667 .923 r
.35632 .56492 m .35461 .56728 L .35758 .56658 L F
.683 .796 .934 r
.35591 .56734 m .35404 .56864 L .35171 .56668 L F
.554 .301 .486 r
.35591 .56734 m .35373 .56926 L .35404 .56865 L F
.369 .633 .956 r
.2027 .61474 m .20403 .61627 L .20468 .61474 L F
.522 .806 .998 r
.20403 .61627 m .2063 .61573 L .20468 .61474 L F
.557 .642 .89 r
.21081 .59714 m .21034 .60061 L .20865 .59865 L F
.21081 .59714 m .21244 .60004 L .21034 .60061 L F
.373 .484 .843 r
.21342 .6021 m .21034 .60061 L .21244 .60004 L F
.078 .637 .789 r
.33272 .66201 m .33548 .66194 L .33707 .6621 L F
.423 .862 .918 r
.33548 .66194 m .33792 .66122 L .33707 .6621 L F
.6 .143 .138 r
.29868 .65356 m .30278 .65357 L .3011 .65527 L F
.25 0 0 r
.30278 .65357 m .30338 .65478 L .3011 .65527 L F
.30278 .65357 m .3056 .65318 L .30338 .65478 L F
.331 0 .096 r
.3287 .62054 m .32766 .61891 L .3262 .621 L F
.3287 .62054 m .33006 .61844 L .32766 .61891 L F
0 0 0 r
.29084 .59004 m .29325 .58674 L .2921 .58816 L F
.719 .641 .769 r
.3581 .6124 m .3594 .61587 L .35589 .61544 L F
.574 .56 .801 r
.36136 .61539 m .3594 .61587 L .3581 .6124 L F
.461 .266 .528 r
.35826 .52188 m .3581 .52504 L .36056 .52106 L F
.115 0 .412 r
.32922 .65622 m .32922 .65929 L .32824 .65944 L F
.446 .248 .517 r
.33168 .65305 m .33151 .65583 L .32922 .65622 L F
.595 .35 .516 r
.33172 .65858 m .32922 .65622 L .33151 .65583 L F
.33172 .65858 m .32922 .65929 L .32922 .65622 L F
0 0 .103 r
.29339 .60237 m .29188 .60343 L .29424 .60016 L F
0 0 .232 r
.29339 .60237 m .29144 .60595 L .29188 .60343 L F
.186 .663 .932 r
.29731 .62829 m .29962 .62831 L .29815 .62789 L F
.56 .341 .539 r
.3203 .56203 m .31764 .56271 L .31812 .55947 L F
.678 .347 .407 r
.32059 .56005 m .3203 .56203 L .31812 .55947 L F
0 0 0 r
.31159 .60549 m .31319 .60526 L .31089 .60292 L F
.31159 .60549 m .31135 .60584 L .31319 .60526 L F
.582 .452 .668 r
.37943 .59079 m .38004 .59374 L .37721 .59388 L F
.574 .338 .521 r
.38004 .59374 m .37691 .59655 L .37721 .59388 L F
.149 .162 .618 r
.32922 .65929 m .32914 .66238 L .32824 .65944 L F
.525 .392 .642 r
.32824 .65944 m .32914 .66238 L .32749 .66272 L F
.456 .271 .541 r
.31658 .63083 m .31423 .63382 L .3142 .63138 L F
0 0 0 r
.34444 .66823 m .34768 .66635 L .34625 .66754 L F
.34768 .66635 m .34794 .66643 L .34625 .66754 L F
.34768 .66635 m .35004 .66584 L .34794 .66643 L F
.643 .275 .33 r
.32159 .56818 m .32464 .56888 L .32586 .56625 L F
.569 .281 .439 r
.32464 .56888 m .32776 .56541 L .32586 .56625 L F
0 .487 .795 r
.26039 .63791 m .26086 .63769 L .25858 .63708 L F
.26039 .63791 m .26307 .63857 L .26086 .63769 L F
.61 .52 .728 r
.37327 .60303 m .37272 .60387 L .37203 .60025 L F
.403 .316 .643 r
.37327 .60303 m .37317 .60646 L .37272 .60387 L F
.633 .472 .646 r
.30484 .63706 m .30742 .63391 L .30514 .63451 L F
.079 0 0 r
.2524 .5574 m .2536 .55773 L .25423 .55687 L F
.2524 .5574 m .25145 .55839 L .2536 .55773 L F
.141 0 .227 r
.2552 .73656 m .2536 .73757 L .25271 .7397 L F
.2552 .73656 m .2536 .73757 L .25271 .7397 L F
.465 .229 .47 r
.38654 .57818 m .38683 .58073 L .38405 .58139 L F
0 0 .189 r
.38836 .57469 m .3876 .57787 L .38654 .57818 L F
.687 .68 .837 r
.3876 .57787 m .38683 .58073 L .38654 .57818 L F
0 0 0 r
.21099 .54466 m .21111 .54532 L .2133 .54408 L F
.21099 .54466 m .20898 .54603 L .21111 .54532 L F
.823 .757 .79 r
.53351 .54641 m .53174 .54968 L .53544 .55009 L F
.632 .107 0 r
.53174 .54968 m .53452 .55185 L .53544 .55009 L F
.63 .667 .867 r
.53774 .54926 m .54043 .55003 L .53823 .54827 L F
.258 .711 .955 r
.53452 .54914 m .54105 .5503 L .53544 .55009 L F
.53438 .54899 m .53785 .54968 L .53452 .54914 L F
.53785 .54968 m .54105 .5503 L .53452 .54914 L F
.54105 .5503 m .54106 .55031 L .53544 .55009 L F
.63 .667 .867 r
.53774 .54927 m .54029 .55006 L .53774 .54926 L F
.421 .721 .987 r
.53599 .54782 m .53739 .54915 L .53438 .54899 L F
.53603 .54779 m .53692 .54867 L .53599 .54782 L F
.53692 .54867 m .53739 .54915 L .53599 .54782 L F
.258 .711 .955 r
.53438 .54899 m .53734 .54914 L .53753 .5492 L F
.53438 .54899 m .53753 .5492 L .53767 .54926 L F
.53438 .54899 m .5404 .55008 L .53785 .54968 L F
.889 .854 .802 r
.53512 .54922 m .53757 .54927 L .53654 .54879 L F
.258 .711 .955 r
.53767 .54926 m .53753 .5492 L .53774 .54927 L F
.889 .854 .802 r
.53757 .54927 m .53774 .54927 L .53744 .54915 L F
.53757 .54927 m .53744 .54915 L .53654 .54879 L F
.53654 .54879 m .53823 .54827 L .53564 .54841 L F
.53692 .54867 m .53774 .54927 L .53823 .54827 L F
.421 .721 .987 r
.53692 .54867 m .53744 .54915 L .53739 .54915 L F
.889 .854 .802 r
.53654 .54879 m .53744 .54915 L .53692 .54867 L F
.53744 .54915 m .53774 .54927 L .53692 .54867 L F
.421 .721 .987 r
.53603 .54779 m .53766 .54916 L .53744 .54915 L F
.53603 .54779 m .53744 .54915 L .53692 .54867 L F
.889 .854 .802 r
.53564 .54841 m .5366 .54836 L .53603 .54779 L F
.5366 .54836 m .53823 .54827 L .53603 .54779 L F
.53512 .54922 m .53654 .54879 L .53564 .54841 L F
.258 .711 .955 r
.53923 .54987 m .53774 .54927 L .54027 .55006 L F
.53438 .54899 m .53774 .54927 L .53923 .54987 L F
.889 .854 .802 r
.53512 .54922 m .53701 .55075 L .53774 .54927 L F
.258 .711 .955 r
.53785 .54968 m .5404 .55008 L .54106 .55031 L F
.63 .667 .867 r
.53701 .55075 m .54029 .55007 L .53774 .54927 L F
.54029 .55007 m .54029 .55006 L .53774 .54927 L F
.54029 .55006 m .54043 .55003 L .53774 .54926 L F
.258 .711 .955 r
.54027 .55006 m .53766 .54916 L .5404 .55008 L F
.53734 .54914 m .53766 .54916 L .54027 .55006 L F
.63 .667 .867 r
.53701 .55075 m .54085 .55173 L .54045 .55009 L F
.891 .771 .722 r
.54106 .55031 m .53823 .54827 L .54043 .55003 L F
.54063 .55 m .53766 .54916 L .53823 .54827 L F
.91 .63 .501 r
.54106 .55031 m .54043 .55003 L .54235 .55028 L F
.837 .42 .247 r
.54043 .55003 m .54044 .55005 L .54235 .55028 L F
.91 .63 .501 r
.54105 .55012 m .54235 .55028 L .54082 .54722 L F
.54106 .55031 m .54235 .55028 L .54105 .55012 L F
.837 .42 .247 r
.54044 .55005 m .54044 .55007 L .54235 .55028 L F
.891 .771 .722 r
.54106 .55031 m .5404 .55008 L .54044 .55007 L F
.54106 .55031 m .54044 .55007 L .54086 .55016 L F
.258 .711 .955 r
.54105 .5503 m .54106 .55031 L .54106 .55031 L F
.837 .42 .247 r
.54044 .55007 m .54085 .55173 L .54218 .55044 L F
.54044 .55007 m .54218 .55044 L .54235 .55028 L F
.891 .771 .722 r
.54086 .55016 m .54044 .55007 L .54063 .55 L F
.63 .667 .867 r
.54029 .55006 m .5404 .55008 L .54043 .55003 L F
.5404 .55008 m .54044 .55007 L .54043 .55003 L F
.891 .771 .722 r
.5404 .55008 m .53766 .54916 L .54063 .55 L F
.63 .667 .867 r
.5404 .55008 m .54045 .55009 L .54044 .55007 L F
.54044 .55009 m .54045 .55009 L .54045 .55009 L F
.53701 .55075 m .54045 .55009 L .54044 .55009 L F
.53701 .55075 m .54045 .55009 L .54029 .55006 L F
.95 .706 .246 r
.53544 .55009 m .53452 .55185 L .53438 .54899 L F
.53 .552 .822 r
.35883 .56934 m .35983 .5654 L .35758 .56658 L F
.35883 .56934 m .36169 .56884 L .35983 .5654 L F
.505 .386 .652 r
.35883 .56934 m .36136 .57125 L .36169 .56884 L F
.557 .761 .973 r
.30707 .529 m .30482 .52963 L .30326 .52813 L F
.142 0 0 r
.51484 .53671 m .52031 .53571 L .51658 .53583 L F
.27 0 0 r
.52031 .53571 m .51864 .53644 L .5213 .53637 L F
0 0 .255 r
.52031 .53571 m .5213 .53637 L .52146 .53421 L F
.52 .308 .532 r
.25791 .55032 m .25992 .55263 L .26048 .55024 L F
.25791 .55032 m .25749 .5533 L .25992 .55263 L F
.227 0 .169 r
.30899 .62217 m .30599 .62494 L .30834 .62442 L F
.26 0 .309 r
.31092 .62136 m .30899 .62217 L .30834 .62442 L F
.609 .676 .889 r
.20043 .58388 m .19575 .58146 L .19803 .58097 L F
.391 .513 .861 r
.20036 .58026 m .20043 .58388 L .19803 .58097 L F
.20036 .58026 m .20217 .58352 L .20043 .58388 L F
.501 .38 .646 r
.38155 .58751 m .37943 .59079 L .37917 .58809 L F
.545 .133 .211 r
.27827 .55259 m .2753 .55561 L .27279 .55534 L F
.887 .825 .781 r
.27916 .55075 m .27827 .55259 L .27822 .55096 L F
.628 .234 .278 r
.27917 .55512 m .2753 .55561 L .27827 .55259 L F
.674 .227 .182 r
.37497 .62822 m .37328 .62993 L .37102 .62788 L F
.592 .272 .396 r
.37411 .62822 m .37328 .62993 L .37102 .62788 L F
.562 .575 .824 r
.37328 .62993 m .37364 .62828 L .37411 .62822 L F
.14 0 0 r
.37102 .62788 m .37411 .62822 L .37447 .62818 L F
.562 .575 .824 r
.37364 .62828 m .37419 .6258 L .37411 .62822 L F
.14 0 0 r
.37447 .62818 m .37411 .62822 L .37497 .62822 L F
.128 .675 .72 r
.37411 .62822 m .37736 .62774 L .37497 .62822 L F
.182 0 0 r
.37736 .62774 m .37328 .62993 L .37497 .62822 L F
.343 .791 .641 r
.22467 .62768 m .22219 .62894 L .2244 .62779 L F
.22467 .62768 m .2244 .62779 L .22488 .62754 L F
.477 0 0 r
.22489 .62759 m .22467 .62768 L .22143 .6256 L F
.226 .62823 m .22467 .62768 L .22489 .62759 L F
.51 .162 .312 r
.226 .62823 m .22603 .62996 L .22467 .62768 L F
.192 .235 .677 r
.17142 .58456 m .17325 .58741 L .17313 .58384 L F
.63 .445 .614 r
.3553 .5973 m .35795 .59686 L .35802 .59412 L F
.379 .242 .565 r
.35802 .59412 m .35795 .59686 L .35979 .59605 L F
.651 .54 .714 r
.35802 .59412 m .36109 .59442 L .36051 .59146 L F
.619 .254 .329 r
.35802 .59412 m .35979 .59605 L .36109 .59442 L F
.379 .242 .565 r
.35802 .59412 m .35795 .59686 L .35979 .59605 L F
.741 .739 .849 r
.24472 .54322 m .24714 .54655 L .24928 .54479 L F
.644 .382 .508 r
.32749 .66272 m .32688 .66507 L .32445 .66489 L F
.506 .25 .46 r
.32871 .66417 m .32749 .66272 L .32914 .66238 L F
.32871 .66417 m .32688 .66507 L .32749 .66272 L F
.152 0 0 r
.2478 .55078 m .24593 .55059 L .24377 .55025 L F
.223 0 0 r
.25006 .55058 m .24593 .55059 L .2478 .55078 L F
.815 .364 .167 r
.25392 .62185 m .25605 .62488 L .25751 .62451 L F
.239 .754 .764 r
.25605 .62488 m .25963 .6241 L .25751 .62451 L F
0 0 .238 r
.25985 .72663 m .25897 .72769 L .25965 .72377 L F
.25985 .72663 m .25965 .72377 L .25901 .72372 L F
.485 .791 .999 r
.37678 .56256 m .37919 .5621 L .37517 .56112 L F
.616 .404 .572 r
.37619 .56547 m .37919 .5621 L .37678 .56256 L F
0 0 .282 r
.3203 .56203 m .31878 .5659 L .31764 .56271 L F
.3203 .56203 m .32013 .56456 L .31878 .5659 L F
0 0 0 r
.32013 .56456 m .31769 .56729 L .31878 .5659 L F
.417 .372 .701 r
.32245 .64117 m .32499 .64306 L .32443 .64068 L F
.32245 .64117 m .32312 .64349 L .32499 .64306 L F
.361 .814 .939 r
.2778 .52895 m .27557 .52944 L .2733 .52901 L F
0 0 0 r
.30073 .58999 m .30002 .59241 L .29954 .59394 L F
.923 .747 .261 r
.30002 .59241 m .30028 .59431 L .29954 .59394 L F
.694 .185 .024 r
.28817 .54681 m .29046 .5488 L .29265 .54811 L F
.45 .118 .31 r
.29265 .54811 m .29449 .5493 L .29535 .54741 L F
.273 .766 .703 r
.29265 .54811 m .29262 .548 L .29449 .5493 L F
.29265 .54811 m .29046 .5488 L .29262 .548 L F
.182 0 .07 r
.20079 .57479 m .19767 .57747 L .19877 .57522 L F
.61 .52 .728 r
.37327 .60303 m .37203 .60025 L .3751 .59824 L F
.361 .228 .561 r
.37691 .59655 m .3751 .59824 L .37548 .5976 L F
.37691 .59655 m .37701 .59909 L .3751 .59824 L F
.36 .196 .518 r
.37701 .59909 m .37327 .60303 L .3751 .59824 L F
.487 .627 .914 r
.20688 .59595 m .20671 .59895 L .20506 .59622 L F
.20688 .59595 m .20865 .59865 L .20671 .59895 L F
.323 .044 .326 r
.29618 .59934 m .29339 .60237 L .29424 .60016 L F
.571 .75 .962 r
.31379 .54149 m .31504 .53913 L .31269 .53955 L F
.31379 .54149 m .31679 .54081 L .31504 .53913 L F
.293 .273 .665 r
.31379 .54149 m .31458 .54411 L .31583 .54307 L F
.691 .199 .072 r
.34278 .60564 m .33968 .60555 L .34208 .60513 L F
.173 .137 .574 r
.32807 .52995 m .32807 .53002 L .32661 .53052 L F
.315 .747 .97 r
.32548 .5309 m .32661 .53052 L .32777 .53116 L F
.43 .812 .99 r
.32777 .53116 m .32661 .53052 L .33073 .53048 L F
.414 .816 .982 r
.32777 .53116 m .33073 .53048 L .33185 .53059 L F
.609 .208 .258 r
.32661 .53052 m .32832 .53261 L .33073 .53048 L F
.173 .137 .574 r
.32807 .53002 m .32832 .53261 L .32661 .53052 L F
.315 .747 .97 r
.32484 .53083 m .32661 .53052 L .32548 .5309 L F
.711 .594 .723 r
.36704 .52249 m .36376 .5255 L .36317 .52103 L F
0 .344 .699 r
.36376 .5255 m .3651 .52593 L .36257 .524 L F
.658 .146 .016 r
.36257 .524 m .3651 .52593 L .36404 .52569 L F
0 .034 .602 r
.36099 .52218 m .36227 .52557 L .36257 .524 L F
.281 .602 .952 r
.36257 .524 m .36227 .52557 L .36376 .5255 L F
.658 .146 .016 r
.36257 .524 m .36404 .52569 L .36184 .52518 L F
0 .034 .602 r
.36056 .52106 m .36099 .52218 L .36257 .524 L F
.639 .617 .812 r
.36272 .52787 m .36376 .5255 L .36227 .52557 L F
.383 .514 .866 r
.2339 .61538 m .23362 .61862 L .23173 .61587 L F
.2339 .61538 m .23546 .61852 L .23362 .61862 L F
.421 .624 .937 r
.219 .62458 m .2182 .62123 L .21657 .62111 L F
.219 .62458 m .22087 .62405 L .2182 .62123 L F
.486 .263 .5 r
.36763 .63821 m .36962 .63972 L .36988 .63719 L F
.032 0 0 r
.29767 .54231 m .29563 .54294 L .2932 .54325 L F
0 0 0 r
.30022 .54129 m .29563 .54294 L .29767 .54231 L F
0 .064 .627 r
.36054 .63299 m .36035 .63479 L .35873 .63086 L F
.968 .748 .552 r
.35808 .63325 m .36035 .63479 L .36054 .63299 L F
.35808 .63325 m .35958 .63683 L .36035 .63479 L F
.631 .487 .669 r
.35898 .53887 m .36073 .54251 L .36086 .53736 L F
.552 .419 .654 r
.28818 .54406 m .28581 .54734 L .28542 .54469 L F
.019 .335 .817 r
.39844 .55114 m .39648 .55114 L .39517 .54961 L F
.39844 .55114 m .39891 .55256 L .39648 .55114 L F
.778 .523 .55 r
.20131 .59066 m .19713 .59031 L .20047 .58919 L F
.216 0 .342 r
.28258 .61893 m .28174 .62127 L .28088 .62088 L F
.272 .127 .495 r
.28187 .62398 m .28088 .62088 L .28174 .62127 L F
.28187 .62398 m .2804 .62457 L .28088 .62088 L F
.42 .463 .798 r
.3892 .53636 m .3884 .54044 L .38729 .53837 L F
.3892 .53636 m .39038 .54028 L .3884 .54044 L F
.103 .629 .876 r
.24208 .54611 m .24624 .54695 L .2439 .54672 L F
.103 0 .231 r
.35552 .60008 m .35329 .60294 L .3546 .60291 L F
.12 .261 .736 r
.35329 .60294 m .3556 .60491 L .3546 .60291 L F
.138 0 0 r
.24981 .62371 m .2524 .62317 L .25392 .62185 L F
.801 .374 .231 r
.2524 .62317 m .25605 .62488 L .25392 .62185 L F
.168 0 .332 r
.32129 .60634 m .32083 .60872 L .31927 .60944 L F
.162 .02 .427 r
.3205 .6112 m .31927 .60944 L .32083 .60872 L F
.3205 .6112 m .31907 .61242 L .31927 .60944 L F
.493 .459 .748 r
.34273 .61693 m .34044 .61887 L .33964 .61507 L F
.503 .772 .992 r
.31695 .58922 m .31463 .58968 L .31228 .58821 L F
.787 .615 .668 r
.54082 .54722 m .54235 .55028 L .54382 .5467 L F
.112 .419 .865 r
.35057 .64544 m .35061 .6472 L .34793 .64404 L F
0 0 .061 r
.35057 .64544 m .34952 .64945 L .35061 .6472 L F
.335 .221 .571 r
.3215 .62555 m .31986 .62469 L .32141 .62278 L F
.647 .678 .865 r
.3215 .62555 m .32013 .62795 L .31986 .62469 L F
.751 .511 .569 r
.36525 .5589 m .36254 .56181 L .36465 .55867 L F
.527 .568 .84 r
.36012 .57565 m .36367 .57819 L .36237 .57526 L F
.769 .614 .686 r
.3317 .54152 m .33056 .54443 L .3265 .54365 L F
.641 .469 .635 r
.3332 .54034 m .33056 .54443 L .3317 .54152 L F
.701 .263 .206 r
.26672 .64004 m .27069 .64062 L .26857 .64236 L F
.592 .123 .11 r
.26857 .64236 m .27069 .64062 L .27263 .64198 L F
.568 .293 .459 r
.3266 .54628 m .32412 .54424 L .3265 .54365 L F
.3266 .54628 m .32321 .54694 L .32412 .54424 L F
.508 .354 .607 r
.33404 .64986 m .33406 .65254 L .33168 .65305 L F
.531 .318 .536 r
.33409 .65524 m .33168 .65305 L .33406 .65254 L F
.33409 .65524 m .33151 .65583 L .33168 .65305 L F
.754 .924 .946 r
.53041 .56089 m .53177 .56173 L .53497 .55967 L F
.837 .83 .84 r
.3581 .6124 m .35589 .61544 L .35415 .61372 L F
.191 .079 .487 r
.17281 .58116 m .17416 .57765 L .17271 .5785 L F
.788 .658 .719 r
.36323 .56605 m .36543 .56868 L .36773 .56601 L F
.36323 .56605 m .36773 .56601 L .36647 .56622 L F
0 .18 .715 r
.36773 .56601 m .3685 .56535 L .36647 .56622 L F
.36773 .56601 m .36984 .56789 L .3685 .56535 L F
.787 .482 .472 r
.34039 .55917 m .34228 .56193 L .33969 .5613 L F
.213 0 .245 r
.34039 .55917 m .34174 .56024 L .34254 .56021 L F
.34039 .55917 m .34003 .56028 L .34174 .56024 L F
.34003 .56028 m .33969 .5613 L .34174 .56024 L F
.743 .224 0 r
.33763 .55757 m .34174 .56024 L .33969 .5613 L F
.33763 .55757 m .33995 .56008 L .34174 .56024 L F
.039 .607 .766 r
.34174 .56024 m .33995 .56008 L .34309 .56022 L F
.983 .754 .513 r
.34405 .56026 m .34254 .56021 L .34174 .56024 L F
.039 .607 .766 r
.34174 .56024 m .34309 .56022 L .34405 .56026 L F
.146 0 0 r
.24613 .74492 m .24525 .74614 L .2437 .74562 L F
.684 .283 .282 r
.24525 .74614 m .24263 .7484 L .2437 .74562 L F
.24525 .74614 m .24744 .74837 L .24263 .7484 L F
.599 .303 .439 r
.24525 .74614 m .24794 .74616 L .24744 .74837 L F
.435 .797 .996 r
.29388 .5538 m .29213 .55277 L .28982 .5533 L F
.693 .898 .971 r
.29553 .55228 m .29213 .55277 L .29388 .5538 L F
.058 .081 .568 r
.34513 .56162 m .34477 .56423 L .34617 .56222 L F
.34513 .56162 m .34398 .5647 L .34477 .56423 L F
.525 .407 .661 r
.50471 .54136 m .50499 .54365 L .50752 .54105 L F
.403 .316 .643 r
.37327 .60303 m .37519 .60604 L .37317 .60646 L F
.36 .196 .518 r
.37701 .59909 m .37808 .60145 L .37327 .60303 L F
.407 .318 .642 r
.37767 .60386 m .37327 .60303 L .37808 .60145 L F
.37767 .60386 m .37519 .60604 L .37327 .60303 L F
.294 0 .219 r
.25769 .54905 m .25649 .54674 L .25865 .54566 L F
.25769 .54905 m .25513 .5502 L .25649 .54674 L F
.212 .453 .873 r
.21559 .62143 m .21463 .61811 L .21293 .61774 L F
.21559 .62143 m .21657 .62111 L .21463 .61811 L F
.284 .59 .946 r
.30402 .6268 m .30361 .62837 L .30533 .62826 L F
.494 .322 .577 r
.33567 .53787 m .33566 .54079 L .3332 .54034 L F
0 0 0 r
.28419 .52876 m .28662 .52851 L .2883 .5283 L F
.262 .765 .874 r
.28662 .52851 m .29057 .52826 L .2883 .5283 L F
.759 .692 .787 r
.31667 .66184 m .31817 .6654 L .31413 .66498 L F
.689 .179 .018 r
.31817 .6654 m .31802 .66691 L .31591 .6655 L F
.312 .413 .804 r
.31591 .6655 m .31802 .66691 L .31789 .66616 L F
.393 0 0 r
.31446 .66502 m .31591 .6655 L .31817 .6654 L F
.312 .413 .804 r
.31591 .6655 m .31789 .66616 L .31739 .6631 L F
.393 0 0 r
.31413 .66498 m .31591 .6655 L .31446 .66502 L F
.689 .179 .018 r
.31817 .6654 m .32026 .66749 L .31802 .66691 L F
.486 .242 .47 r
.32047 .66502 m .32026 .66749 L .31817 .6654 L F
.552 .271 .443 r
.21872 .56598 m .22077 .568 L .22154 .56573 L F
.21872 .56598 m .22077 .568 L .22154 .56573 L F
.766 .494 .522 r
.22617 .55652 m .22181 .55799 L .22368 .55874 L F
.529 .45 .711 r
.50496 .55703 m .50667 .55243 L .504 .55301 L F
.50496 .55703 m .50745 .55651 L .50667 .55243 L F
.572 .553 .795 r
.504 .55301 m .50576 .55022 L .50335 .55067 L F
.504 .55301 m .50667 .55243 L .50576 .55022 L F
.286 0 .206 r
.33202 .58142 m .33095 .58417 L .32922 .58387 L F
.104 0 .316 r
.33415 .57793 m .33389 .58041 L .33202 .58142 L F
.466 .242 .488 r
.33389 .58041 m .33095 .58417 L .33202 .58142 L F
0 0 0 r
.31009 .64347 m .31286 .64056 L .31238 .64313 L F
.04 0 .307 r
.31238 .64313 m .31286 .64056 L .31374 .64074 L F
.446 .046 .186 r
.5099 .54009 m .51256 .53943 L .51331 .53757 L F
.249 .762 .821 r
.29057 .52826 m .29292 .52777 L .29452 .52773 L F
.311 0 0 r
.29292 .52777 m .29692 .52833 L .29452 .52773 L F
.695 .8 .93 r
.20131 .59066 m .19893 .59135 L .19713 .59031 L F
0 .133 .67 r
.20185 .59313 m .19893 .59135 L .20131 .59066 L F
.304 .464 .854 r
.23743 .61831 m .23747 .62151 L .23546 .61852 L F
.23743 .61831 m .2391 .62163 L .23747 .62151 L F
.046 0 .281 r
.30487 .65006 m .30677 .64654 L .30659 .64946 L F
.283 .241 .634 r
.30688 .65196 m .30487 .65006 L .30659 .64946 L F
.30688 .65196 m .3056 .65318 L .30487 .65006 L F
.467 .227 .465 r
.33997 .53259 m .34056 .53365 L .34016 .53205 L F
.181 .065 .475 r
.27817 .63148 m .27979 .63229 L .27984 .63106 L F
0 0 .449 r
.28986 .6363 m .28878 .63426 L .29075 .63372 L F
.28986 .6363 m .28905 .63711 L .28878 .63426 L F
.348 0 .205 r
.32329 .55951 m .3203 .56203 L .32059 .56005 L F
.301 0 0 r
.3447 .55584 m .33997 .55678 L .34239 .55671 L F
.643 .497 .67 r
.3553 .5973 m .35552 .60008 L .35795 .59686 L F
.389 .148 .423 r
.36341 .58044 m .36128 .58137 L .36069 .58381 L F
.433 .52 .847 r
.28426 .55721 m .28732 .55874 L .28543 .55912 L F
0 0 .1 r
.28583 .56077 m .28543 .55912 L .28732 .55874 L F
.28583 .56077 m .28422 .56203 L .28543 .55912 L F
.26 .048 .39 r
.37367 .55025 m .37141 .55357 L .37314 .55224 L F
0 0 0 r
.37024 .55556 m .37314 .55224 L .37141 .55357 L F
.994 .788 .519 r
.34484 .65599 m .34299 .65476 L .34321 .65201 L F
0 0 0 r
.34484 .65599 m .34268 .65739 L .34299 .65476 L F
.23981 .53418 m .24195 .53355 L .24363 .53267 L F
.24363 .53267 m .24418 .53285 L .24597 .532 L F
.24363 .53267 m .24195 .53355 L .24418 .53285 L F
.741 .679 .79 r
.33069 .5625 m .33215 .56595 L .33174 .56535 L F
.816 .793 .83 r
.32753 .56844 m .32975 .57161 L .33204 .56856 L F
.32753 .56844 m .33204 .56856 L .33022 .56884 L F
.939 .693 .54 r
.33215 .56595 m .33022 .56884 L .33204 .56856 L F
.539 .636 .895 r
.20289 .59308 m .20261 .59656 L .20185 .59313 L F
.20289 .59308 m .20506 .59622 L .20261 .59656 L F
.759 .564 .632 r
.37317 .60646 m .37365 .6098 L .3712 .60899 L F
.422 .399 .728 r
.37519 .60604 m .376 .60882 L .37317 .60646 L F
.526 .4 .651 r
.376 .60882 m .37365 .6098 L .37317 .60646 L F
.51 .6 .879 r
.21599 .60827 m .21577 .61202 L .21448 .60828 L F
.21599 .60827 m .218 .61165 L .21577 .61202 L F
.451 .4 .71 r
.33631 .54635 m .33357 .54474 L .33541 .54255 L F
.33631 .54635 m .33424 .54716 L .33357 .54474 L F
.599 .388 .567 r
.34408 .54422 m .34381 .54675 L .34073 .54695 L F
.42 .643 .949 r
.34381 .54144 m .34408 .54422 L .34146 .5422 L F
.34381 .54144 m .34498 .54342 L .34408 .54422 L F
.29 .194 .569 r
.34498 .54342 m .34381 .54675 L .34408 .54422 L F
0 0 0 r
.26889 .61853 m .26688 .62 L .27019 .61803 L F
.394 .322 .657 r
.32372 .6463 m .32499 .64306 L .32312 .64349 L F
.99 .822 .441 r
.34579 .55883 m .34513 .56162 L .34617 .56222 L F
.338 .03 .287 r
.30677 .64654 m .31009 .64347 L .30922 .6458 L F
.329 0 .061 r
.31009 .64347 m .31094 .64518 L .30922 .6458 L F
.31009 .64347 m .31238 .64313 L .31094 .64518 L F
0 0 .222 r
.23252 .74909 m .23083 .75231 L .23189 .75224 L F
.001 .237 .746 r
.23083 .75231 m .23269 .75397 L .23189 .75224 L F
.393 .495 .844 r
.32476 .52677 m .32484 .53083 L .32236 .52801 L F
.32476 .52677 m .32661 .53052 L .32484 .53083 L F
.882 .968 .842 r
.35329 .63421 m .35239 .63541 L .35233 .63471 L F
.596 .47 .679 r
.35329 .63421 m .35347 .63734 L .35085 .63744 L F
.882 .968 .842 r
.35329 .63421 m .35034 .63573 L .35173 .63333 L F
.133 .427 .869 r
.35237 .62822 m .35526 .63004 L .35446 .62919 L F
.35526 .63004 m .35568 .63031 L .35528 .6299 L F
.35526 .63004 m .35528 .6299 L .35522 .62984 L F
.3546 .62933 m .35522 .62984 L .3526 .6272 L F
.35526 .63004 m .35522 .62984 L .3546 .62933 L F
.831 .924 .536 r
.35329 .63421 m .35507 .63036 L .35183 .63064 L F
.654 .387 .503 r
.35237 .62822 m .35183 .63064 L .35483 .63038 L F
.35237 .62822 m .35498 .63051 L .35526 .63004 L F
.831 .924 .536 r
.35507 .63036 m .35528 .6299 L .35183 .63064 L F
.654 .387 .503 r
.35483 .63038 m .35183 .63064 L .35498 .63051 L F
.35526 .63004 m .35498 .63051 L .35594 .63047 L F
.831 .924 .536 r
.35329 .63421 m .35319 .63413 L .35498 .63051 L F
.35506 .63038 m .35498 .63051 L .35525 .62996 L F
.35329 .63421 m .35498 .63051 L .35506 .63038 L F
.35528 .6299 m .35526 .62988 L .35183 .63064 L F
.686 .569 .719 r
.35528 .6299 m .35183 .63064 L .35526 .62988 L F
.35594 .63047 m .35498 .63051 L .35528 .6299 L F
.35498 .63051 m .35183 .63064 L .35528 .6299 L F
.04 .297 .788 r
.35243 .63201 m .35304 .63304 L .35225 .63374 L F
.831 .924 .536 r
.35525 .62996 m .35291 .63376 L .35528 .62989 L F
.35291 .63376 m .35291 .63376 L .35528 .62989 L F
.35319 .63413 m .35284 .63388 L .35525 .62996 L F
.35329 .63421 m .35528 .62989 L .35528 .6299 L F
.764 .51 .551 r
.35537 .62996 m .35292 .63376 L .35808 .63325 L F
.04 .297 .788 r
.35291 .63376 m .35433 .63537 L .35284 .6342 L F
.35291 .63376 m .353 .63386 L .35291 .63376 L F
.353 .63386 m .35433 .63537 L .35291 .63376 L F
.887 .804 .761 r
.35448 .63549 m .35496 .63362 L .353 .63386 L F
.35448 .63549 m .353 .63386 L .35284 .63388 L F
.764 .51 .551 r
.35292 .63376 m .353 .63386 L .35808 .63325 L F
.04 .297 .788 r
.35235 .63364 m .35284 .6342 L .35225 .63374 L F
.35304 .63304 m .35289 .63391 L .35235 .63364 L F
0 .25 .761 r
.35173 .63333 m .35289 .63391 L .35329 .63421 L F
.04 .297 .788 r
.35289 .63391 m .35284 .6342 L .35235 .63364 L F
0 .25 .761 r
.35173 .63333 m .35284 .63388 L .35289 .63391 L F
.831 .924 .536 r
.35291 .63376 m .35284 .63388 L .35291 .63376 L F
.764 .51 .551 r
.35528 .62989 m .35284 .63388 L .35537 .62996 L F
.04 .297 .788 r
.35304 .63304 m .35448 .63549 L .35433 .63537 L F
.35304 .63304 m .35433 .63537 L .35291 .63376 L F
.794 .341 .166 r
.357 .63993 m .35347 .63734 L .35721 .6376 L F
.357 .63993 m .35534 .63995 L .35347 .63734 L F
0 .25 .761 r
.35173 .63333 m .35448 .63549 L .35284 .63388 L F
0 .053 .616 r
.35243 .63201 m .35433 .63418 L .35448 .63549 L F
.433 .478 .807 r
.35433 .63418 m .35389 .63778 L .35448 .63549 L F
.613 .156 0 r
.35347 .63734 m .35534 .63995 L .35385 .63809 L F
.433 .478 .807 r
.35389 .63778 m .35385 .63809 L .35448 .63549 L F
.887 .804 .761 r
.35448 .63549 m .35808 .63325 L .35496 .63362 L F
.764 .51 .551 r
.35292 .63376 m .35284 .63388 L .353 .63386 L F
.831 .924 .536 r
.35528 .6299 m .35529 .62987 L .35526 .62988 L F
.35528 .6299 m .35528 .6299 L .35529 .62987 L F
.686 .569 .719 r
.35594 .63047 m .35528 .6299 L .35529 .62987 L F
.35528 .6299 m .35526 .62988 L .35529 .62987 L F
.831 .924 .536 r
.35528 .6299 m .35528 .62989 L .35529 .62987 L F
.764 .51 .551 r
.35529 .62987 m .35528 .62989 L .35537 .62996 L F
.133 .427 .869 r
.35253 .62752 m .35446 .62919 L .3526 .6272 L F
.35237 .62822 m .35446 .62919 L .35253 .62752 L F
.349 .502 .869 r
.35672 .62945 m .35594 .63047 L .35529 .62987 L F
.764 .51 .551 r
.35529 .62987 m .35537 .62996 L .35672 .62945 L F
.133 .427 .869 r
.35547 .63001 m .35594 .63047 L .35561 .63007 L F
.764 .51 .551 r
.35537 .62996 m .35808 .63325 L .35721 .63081 L F
.35537 .62996 m .35561 .63007 L .35672 .62945 L F
.396 .57 .907 r
.35272 .62664 m .35561 .63007 L .35672 .62945 L F
.35561 .63007 m .35594 .63047 L .35672 .62945 L F
.764 .51 .551 r
.35561 .63007 m .35721 .63081 L .35672 .62945 L F
.133 .427 .869 r
.3526 .6272 m .35547 .63001 L .35272 .62664 L F
.35547 .63001 m .35561 .63007 L .35272 .62664 L F
.35568 .63031 m .35594 .63047 L .3526 .6272 L F
.04 .297 .788 r
.35215 .63254 m .35225 .63374 L .35173 .63333 L F
.35243 .63201 m .35225 .63374 L .35215 .63254 L F
.882 .968 .842 r
.35239 .63541 m .35085 .63744 L .35233 .63471 L F
.3521 .63513 m .35085 .63744 L .35034 .63573 L F
.871 .462 .247 r
.35347 .63734 m .35034 .63573 L .35085 .63744 L F
.634 .571 .766 r
.35133 .63827 m .34865 .63631 L .35034 .63573 L F
.34865 .63631 m .34776 .63565 L .35034 .63573 L F
.882 .968 .842 r
.35233 .63471 m .3521 .63513 L .35034 .63573 L F
.414 .346 .672 r
.3427 .60013 m .34518 .60293 L .34505 .5996 L F
0 0 0 r
.36417 .60873 m .36223 .61109 L .36088 .61165 L F
.157 0 0 r
.36587 .6089 m .36417 .60873 L .36681 .60818 L F
.36587 .6089 m .36223 .61109 L .36417 .60873 L F
0 0 0 r
.18557 .56284 m .18296 .56589 L .1845 .56472 L F
.268 0 .158 r
.18557 .56284 m .18662 .56381 L .18788 .56232 L F
.18557 .56284 m .1845 .56472 L .18662 .56381 L F
.561 .401 .622 r
.34198 .63047 m .33952 .63456 L .33977 .63114 L F
.212 .258 .693 r
.30988 .61251 m .31201 .61457 L .31128 .6112 L F
.3 .272 .66 r
.30988 .61251 m .31083 .61504 L .31201 .61457 L F
.513 0 0 r
.27087 .55413 m .27279 .55534 L .27101 .55506 L F
.849 .683 .676 r
.34189 .64331 m .34367 .64656 L .34094 .64596 L F
.697 .517 .64 r
.34168 .64888 m .34094 .64596 L .34367 .64656 L F
.751 .453 .479 r
.34424 .64839 m .34168 .64888 L .34367 .64656 L F
.039 0 .03 r
.18013 .5687 m .18163 .56842 L .18296 .56589 L F
.256 0 .146 r
.18296 .56589 m .18383 .56769 L .1845 .56472 L F
.18296 .56589 m .18163 .56842 L .18383 .56769 L F
.145 0 0 r
.30289 .56363 m .30377 .564 L .30544 .56271 L F
.848 .973 .661 r
.30544 .56271 m .30562 .56091 L .30656 .56196 L F
.30544 .56271 m .30377 .564 L .30562 .56091 L F
.499 .274 .504 r
.38989 .56186 m .3861 .56637 L .38651 .56348 L F
0 0 0 r
.36856 .5563 m .36997 .55629 L .37024 .55556 L F
.36856 .5563 m .36707 .55774 L .36997 .55629 L F
.287 .734 .961 r
.2451 .55821 m .24726 .55808 L .24941 .55905 L F
.457 .825 .993 r
.25145 .55839 m .24726 .55808 L .24941 .55905 L F
.422 .84 .964 r
.25309 .55864 m .25145 .55839 L .24941 .55905 L F
0 0 0 r
.24934 .56026 m .24941 .55905 L .25145 .55839 L F
.24934 .56026 m .24729 .56114 L .24941 .55905 L F
.33005 .5521 m .33037 .55239 L .33105 .55158 L F
.89 .465 .109 r
.33005 .5521 m .32992 .55453 L .33037 .55239 L F
.209 0 .029 r
.22144 .53965 m .22033 .54033 L .21942 .54042 L F
.401 0 .127 r
.21746 .5423 m .22144 .53965 L .21942 .54042 L F
.702 .718 .861 r
.33771 .53486 m .34257 .53515 L .34056 .53365 L F
.76 .775 .866 r
.34056 .53365 m .34257 .53515 L .34414 .53433 L F
0 0 0 r
.30195 .58575 m .30184 .58482 L .30147 .58299 L F
.30195 .58575 m .30116 .5874 L .30184 .58482 L F
.465 .633 .927 r
.2303 .61394 m .22947 .61608 L .22781 .61481 L F
.2303 .61394 m .23173 .61587 L .22947 .61608 L F
.67 .884 .977 r
.37172 .53591 m .37135 .53812 L .37347 .53696 L F
.81 .948 .6 r
.29144 .60595 m .28936 .60935 L .29068 .60739 L F
.035 0 .074 r
.27546 .61158 m .2737 .61214 L .27283 .61462 L F
.359 0 0 r
.25309 .55864 m .25529 .55936 L .25145 .55839 L F
.588 .851 .994 r
.28419 .52876 m .28198 .52955 L .28014 .52858 L F
0 0 .204 r
.29598 .58125 m .29774 .58031 L .29831 .57807 L F
0 0 .193 r
.2971 .58255 m .29598 .58125 L .29477 .58311 L F
.2971 .58255 m .29774 .58031 L .29598 .58125 L F
.091 0 0 r
.30629 .62604 m .30599 .62494 L .30402 .6268 L F
.30629 .62604 m .30834 .62442 L .30599 .62494 L F
.47 .259 .509 r
.38405 .58139 m .38388 .58421 L .38143 .58467 L F
.541 .388 .622 r
.38388 .58421 m .38155 .58751 L .38143 .58467 L F
.529 .307 .522 r
.38654 .58357 m .38405 .58139 L .38683 .58073 L F
.38654 .58357 m .38388 .58421 L .38405 .58139 L F
0 0 0 r
.31261 .57454 m .3099 .57782 L .31149 .57566 L F
0 0 .403 r
.32683 .63102 m .32779 .63237 L .32884 .63051 L F
.32779 .63237 m .32827 .63233 L .32884 .63051 L F
.32683 .63102 m .3272 .63388 L .32812 .63282 L F
.32779 .63237 m .32812 .63282 L .32827 .63233 L F
.785 .416 .358 r
.32812 .63282 m .32884 .63051 L .32575 .63183 L F
.32593 .63204 m .32575 .63183 L .32556 .63191 L F
.32812 .63282 m .32575 .63183 L .32593 .63204 L F
.359 .272 .62 r
.32798 .63589 m .33027 .6379 L .32948 .6363 L F
.667 .226 .195 r
.33101 .63255 m .32884 .63051 L .32556 .63191 L F
0 0 .407 r
.32756 .63147 m .32556 .63191 L .32776 .63069 L F
.177 .685 .902 r
.32713 .6315 m .32726 .63154 L .32556 .63191 L F
.32726 .63154 m .3298 .63222 L .32556 .63191 L F
.3298 .63222 m .32884 .63229 L .32556 .63191 L F
0 0 .116 r
.32812 .63282 m .3272 .63388 L .32681 .63581 L F
.327 .6356 m .32681 .63581 L .32671 .63632 L F
.32812 .63282 m .32681 .63581 L .327 .6356 L F
0 0 .407 r
.32669 .63175 m .32556 .63191 L .32668 .63166 L F
.328 .097 .403 r
.3272 .63388 m .32448 .63696 L .32671 .63632 L F
0 0 .116 r
.32812 .63282 m .32671 .63632 L .32798 .63589 L F
.755 .636 .729 r
.32812 .63282 m .32798 .63589 L .32556 .63191 L F
.177 .685 .902 r
.32715 .63169 m .32556 .63191 L .32748 .63506 L F
0 0 .407 r
.32704 .63354 m .32556 .63191 L .32669 .63175 L F
.177 .685 .902 r
.32713 .6315 m .32556 .63191 L .32715 .63169 L F
.32776 .63475 m .32748 .63506 L .32798 .63589 L F
.32713 .6315 m .32748 .63506 L .32776 .63475 L F
.359 .272 .62 r
.32763 .63408 m .32948 .6363 L .32723 .63169 L F
.177 .685 .902 r
.3298 .63222 m .33101 .63255 L .32884 .63229 L F
.075 .278 .765 r
.32729 .63169 m .33102 .63617 L .32731 .6316 L F
.32731 .6316 m .33102 .63617 L .33084 .63341 L F
.563 .514 .759 r
.32884 .63051 m .32966 .62443 L .32723 .62547 L F
.32966 .62443 m .32966 .6244 L .32959 .62444 L F
.32966 .62443 m .3296 .62443 L .32723 .62547 L F
.32884 .63051 m .33125 .63003 L .32966 .6244 L F
.726 .613 .732 r
.33125 .63003 m .33386 .62683 L .32969 .62442 L F
.33125 .63003 m .32969 .62442 L .32967 .62442 L F
.32967 .62443 m .32967 .6244 L .32966 .62441 L F
.33125 .63003 m .32967 .62442 L .32967 .62443 L F
.32967 .62442 m .32967 .6244 L .32967 .62443 L F
.433 .165 .406 r
.3296 .62443 m .32748 .62428 L .32723 .62547 L F
.348 0 0 r
.327 .62478 m .3296 .62443 L .32963 .62444 L F
.433 .165 .406 r
.32985 .62445 m .32963 .62444 L .32941 .62462 L F
.32941 .62462 m .3296 .62443 L .32723 .62547 L F
.32963 .62444 m .3296 .62443 L .32941 .62462 L F
.563 .514 .759 r
.3296 .62443 m .32959 .62444 L .32723 .62547 L F
.726 .613 .732 r
.32966 .62441 m .32967 .6244 L .32966 .6244 L F
.348 0 0 r
.3274 .62384 m .32985 .62445 L .32819 .62278 L F
.764 .275 .065 r
.32969 .62442 m .33386 .62683 L .32969 .62443 L F
.32981 .62457 m .33386 .62683 L .33198 .62706 L F
.32969 .62443 m .33007 .62465 L .32981 .62457 L F
.726 .613 .732 r
.32967 .62442 m .32969 .62442 L .32967 .6244 L F
.764 .275 .065 r
.32966 .6244 m .32969 .62442 L .32969 .62443 L F
.32966 .6244 m .33198 .62706 L .32985 .62445 L F
.433 .165 .406 r
.32985 .62445 m .32723 .62547 L .32959 .62444 L F
.348 0 0 r
.327 .62478 m .32963 .62444 L .32936 .62451 L F
.975 .726 .495 r
.32723 .62547 m .32748 .62428 L .32567 .62616 L F
.047 0 .318 r
.32683 .62798 m .32525 .6303 L .32723 .62547 L F
.3266 .62941 m .32594 .62985 L .32683 .62798 L F
.32594 .62985 m .32525 .6303 L .32683 .62798 L F
.348 0 0 r
.32567 .62616 m .32653 .62527 L .32804 .6249 L F
.047 0 .318 r
.3266 .62941 m .32723 .62547 L .32567 .62616 L F
.348 0 0 r
.32567 .62616 m .32804 .6249 L .32985 .62445 L F
.32653 .62527 m .327 .62478 L .32936 .62451 L F
.32653 .62527 m .32936 .62451 L .32985 .62445 L F
.327 .62478 m .32748 .62428 L .3296 .62443 L F
.32567 .62616 m .32819 .62513 L .3274 .62384 L F
.32819 .62513 m .32967 .62453 L .32862 .62421 L F
.32819 .62513 m .32862 .62421 L .3274 .62384 L F
.32962 .62444 m .32963 .62444 L .32969 .62444 L F
.32969 .62444 m .32969 .62444 L .32985 .62445 L F
.32962 .62444 m .32969 .62444 L .32969 .62444 L F
.433 .165 .406 r
.32985 .62445 m .32959 .62444 L .32966 .6244 L F
.348 0 0 r
.32936 .62451 m .32962 .62444 L .32985 .62445 L F
.32967 .62453 m .32985 .62445 L .3274 .62384 L F
.764 .275 .065 r
.33007 .62465 m .33386 .62683 L .32981 .62457 L F
.496 .271 .503 r
.33101 .63255 m .33125 .63003 L .32884 .63051 L F
.528 .291 .499 r
.33349 .63216 m .33125 .63003 L .33101 .63255 L F
.09 0 0 r
.33084 .63341 m .33349 .63216 L .33101 .63255 L F
.984 .869 .641 r
.33187 .63093 m .33349 .63216 L .33112 .63328 L F
.33107 .63287 m .33112 .63328 L .33084 .63341 L F
.33187 .63093 m .33112 .63328 L .33107 .63287 L F
.703 .324 .328 r
.32851 .62791 m .33187 .63093 L .32776 .63069 L F
.09 0 0 r
.32946 .63269 m .33101 .63255 L .32726 .63154 L F
.33086 .63334 m .33101 .63255 L .32946 .63269 L F
.714 .491 .586 r
.32776 .63069 m .33187 .63093 L .33084 .63341 L F
.075 .278 .765 r
.32734 .63175 m .33027 .6379 L .33029 .63785 L F
.32734 .63175 m .32792 .63295 L .32844 .63307 L F
.32792 .63295 m .33029 .63785 L .32844 .63307 L F
.32732 .63176 m .33027 .6379 L .32734 .63175 L F
.32723 .63169 m .33027 .6379 L .32729 .63169 L F
.09 0 0 r
.33004 .633 m .32734 .63158 L .32738 .63163 L F
.33004 .63299 m .32726 .63154 L .33004 .633 L F
.359 .272 .62 r
.32763 .63408 m .32723 .63169 L .32717 .63169 L F
.714 .491 .586 r
.32776 .63069 m .33029 .63292 L .32704 .63354 L F
.76 .745 .839 r
.32749 .63178 m .32817 .63132 L .32751 .63166 L F
.32704 .63354 m .32775 .63214 L .32749 .63178 L F
.32775 .63214 m .32817 .63132 L .32749 .63178 L F
.09 0 0 r
.32738 .63163 m .32726 .63154 L .32731 .6316 L F
.32734 .63158 m .32726 .63154 L .32738 .63163 L F
.33084 .63341 m .33004 .63299 L .33004 .633 L F
.33084 .63341 m .33086 .63334 L .3297 .6328 L F
.32971 .63282 m .3297 .6328 L .32946 .63269 L F
.33084 .63341 m .3297 .6328 L .32971 .63282 L F
.714 .491 .586 r
.33029 .63292 m .33084 .63341 L .32881 .63348 L F
.233 0 0 r
.32996 .63342 m .32999 .6334 L .32876 .63315 L F
.371 .131 .414 r
.33084 .63341 m .33118 .6326 L .33236 .63304 L F
.33118 .6326 m .33132 .63257 L .33236 .63304 L F
.33121 .63252 m .33226 .63258 L .33236 .63304 L F
.026 0 0 r
.33237 .63236 m .33153 .63252 L .33149 .63254 L F
.233 0 0 r
.33149 .63254 m .33153 .63252 L .33144 .63254 L F
.984 .869 .641 r
.3321 .63192 m .33084 .63341 L .33234 .63292 L F
.76 .745 .839 r
.33144 .63254 m .33153 .63252 L .33148 .6325 L F
.984 .869 .641 r
.33107 .63287 m .33084 .63341 L .3321 .63192 L F
.026 0 0 r
.33298 .63239 m .33237 .63236 L .32999 .6334 L F
.984 .869 .641 r
.33187 .63093 m .33122 .63252 L .3321 .63192 L F
.33122 .63252 m .33107 .63287 L .3315 .63248 L F
.33122 .63252 m .3315 .63248 L .3321 .63192 L F
.436 .605 .918 r
.3315 .63248 m .33153 .63252 L .33237 .63236 L F
.371 .131 .414 r
.33121 .63252 m .33187 .63093 L .33226 .63258 L F
.595 .591 .817 r
.33823 .6312 m .33891 .62575 L .33649 .63008 L F
0 0 0 r
.33754 .6289 m .33649 .63008 L .33821 .627 L F
.33846 .62679 m .33821 .627 L .33891 .62575 L F
.33754 .6289 m .33821 .627 L .33846 .62679 L F
.811 .585 .595 r
.3384 .62597 m .34162 .62369 L .33769 .62314 L F
.595 .591 .817 r
.33823 .6312 m .34104 .631 L .33891 .62575 L F
.568 .383 .59 r
.34514 .62727 m .34198 .63047 L .34233 .62808 L F
.561 .401 .622 r
.34198 .63047 m .34228 .63501 L .33952 .63456 L F
.568 .383 .59 r
.34514 .62727 m .34495 .63003 L .34198 .63047 L F
.519 .37 .618 r
.34481 .63262 m .34198 .63047 L .34495 .63003 L F
.34481 .63262 m .34228 .63501 L .34198 .63047 L F
.544 .561 .823 r
.33891 .62575 m .34104 .631 L .34338 .63004 L F
.33891 .62575 m .34338 .63004 L .34137 .62639 L F
.921 .868 .435 r
.33754 .6289 m .33891 .62575 L .3384 .62597 L F
.811 .585 .595 r
.3384 .62597 m .34137 .62639 L .34162 .62369 L F
0 .12 .668 r
.33845 .62437 m .33897 .62554 L .3384 .62597 L F
.33897 .62554 m .33918 .62603 L .33847 .62598 L F
.33897 .62554 m .33847 .62598 L .3384 .62597 L F
.642 .377 .502 r
.34162 .62369 m .33926 .62144 L .33769 .62314 L F
0 0 0 r
.33897 .62554 m .34051 .62326 L .33845 .62437 L F
0 .12 .668 r
.33845 .62437 m .33935 .62605 L .33918 .62603 L F
.33935 .62605 m .3389 .62642 L .3384 .62597 L F
.921 .868 .435 r
.33754 .6289 m .3384 .62597 L .34016 .62756 L F
.351 .292 .651 r
.34051 .62326 m .34016 .62756 L .33904 .62548 L F
.34051 .62326 m .33904 .62548 L .33845 .62437 L F
0 0 0 r
.33828 .62662 m .33918 .62594 L .3397 .6249 L F
.33802 .62695 m .33814 .62685 L .33828 .62662 L F
.33814 .62685 m .33918 .62594 L .33828 .62662 L F
.33897 .62554 m .3397 .6249 L .34051 .62326 L F
.33802 .62695 m .3397 .6249 L .33897 .62554 L F
.33802 .62695 m .33897 .62554 L .33845 .62437 L F
0 .12 .668 r
.33935 .62605 m .34016 .62756 L .3389 .62642 L F
.566 .927 .764 r
.3353 .63021 m .33649 .63008 L .33754 .6289 L F
.436 .605 .918 r
.32924 .62922 m .3315 .63248 L .33308 .63221 L F
.32924 .62922 m .33308 .63221 L .33327 .63204 L F
.528 .291 .499 r
.33349 .63216 m .33379 .62962 L .33125 .63003 L F
.438 .214 .476 r
.33611 .62906 m .33379 .62962 L .33349 .63216 L F
.552 .369 .586 r
.33125 .63003 m .33379 .62962 L .33386 .62683 L F
.47 .302 .571 r
.33386 .62683 m .33379 .62962 L .33611 .62906 L F
.832 .791 .813 r
.33487 .62796 m .33349 .63216 L .33187 .63093 L F
.33487 .62796 m .33611 .62906 L .33349 .63216 L F
.703 .324 .328 r
.32851 .62791 m .33182 .62887 L .33187 .63093 L F
.832 .791 .813 r
.33487 .62796 m .33187 .63093 L .33182 .62887 L F
.436 .605 .918 r
.32924 .62922 m .33343 .63215 L .33367 .63188 L F
.33122 .63041 m .33354 .6318 L .33226 .6304 L F
.33354 .6318 m .33363 .63171 L .33071 .6287 L F
.566 .927 .764 r
.33501 .63037 m .33444 .63098 L .3353 .63021 L F
.436 .605 .918 r
.33122 .63041 m .33226 .6304 L .33071 .6287 L F
.33354 .6318 m .33367 .63188 L .33363 .63171 L F
.65 .962 .786 r
.33401 .63186 m .33649 .63008 L .33338 .63218 L F
.436 .605 .918 r
.33367 .63188 m .33396 .63205 L .33372 .63181 L F
.33367 .63188 m .33372 .63181 L .33363 .63171 L F
.33327 .63204 m .33308 .63221 L .33343 .63215 L F
.026 0 0 r
.33343 .63215 m .33237 .63236 L .33298 .63239 L F
.33221 .63278 m .32996 .63342 L .33068 .63341 L F
.432 .285 .581 r
.33264 .63282 m .33084 .63341 L .33308 .63244 L F
.771 .662 .742 r
.33245 .63297 m .33772 .63291 L .33649 .63008 L F
.33243 .63303 m .33772 .63291 L .33245 .63297 L F
.764 .55 .609 r
.33577 .63505 m .33772 .63291 L .33243 .63303 L F
.432 .285 .581 r
.33184 .63438 m .33084 .63341 L .3325 .63286 L F
.764 .55 .609 r
.33242 .63307 m .33243 .63303 L .33236 .63304 L F
.33577 .63505 m .33243 .63303 L .33242 .63307 L F
.33577 .63505 m .33242 .63307 L .33308 .63559 L F
.432 .285 .581 r
.3324 .63492 m .33241 .63382 L .33387 .6324 L F
.33184 .63438 m .3325 .63286 L .33387 .6324 L F
.764 .55 .609 r
.33242 .63307 m .33236 .63304 L .33308 .63559 L F
.432 .285 .581 r
.33308 .63559 m .3324 .63492 L .33275 .63432 L F
.33308 .63559 m .33275 .63432 L .33387 .6324 L F
.3324 .63492 m .33184 .63438 L .33241 .63382 L F
.771 .662 .742 r
.33236 .63304 m .33243 .63303 L .33245 .63297 L F
.984 .869 .641 r
.33234 .63292 m .33084 .63341 L .33236 .63304 L F
.371 .131 .414 r
.33084 .63341 m .33236 .63304 L .33308 .63244 L F
.65 .962 .786 r
.33245 .63296 m .33338 .63218 L .33246 .63265 L F
.33245 .63297 m .33308 .63244 L .33245 .63296 L F
.33308 .63244 m .33338 .63218 L .33245 .63296 L F
.432 .285 .581 r
.33264 .63282 m .33308 .63244 L .33396 .63205 L F
.371 .131 .414 r
.33308 .63244 m .33236 .63304 L .33396 .63205 L F
.65 .962 .786 r
.33245 .63297 m .33401 .63186 L .33338 .63218 L F
.33236 .63304 m .33245 .63297 L .33246 .63265 L F
.33236 .63304 m .33246 .63265 L .3324 .63268 L F
.33236 .63304 m .3324 .63268 L .33396 .63205 L F
.026 0 0 r
.33396 .63205 m .33296 .63239 L .3324 .63268 L F
.65 .962 .786 r
.33246 .63265 m .33354 .63205 L .3325 .63183 L F
.33338 .63218 m .33354 .63205 L .33246 .63265 L F
.436 .605 .918 r
.33367 .63188 m .33343 .63215 L .33396 .63205 L F
.65 .962 .786 r
.33338 .63218 m .33345 .63213 L .33349 .63209 L F
.026 0 0 r
.33396 .63205 m .33298 .63239 L .33296 .63239 L F
.33396 .63205 m .33343 .63215 L .33298 .63239 L F
.65 .962 .786 r
.3324 .63268 m .33246 .63265 L .3325 .63183 L F
.3324 .63268 m .3325 .63183 L .33396 .63205 L F
.026 0 0 r
.33396 .63205 m .3324 .63268 L .33221 .63278 L F
.33296 .63239 m .32996 .63342 L .33221 .63278 L F
.436 .605 .918 r
.3315 .63248 m .33237 .63236 L .33343 .63215 L F
.026 0 0 r
.33237 .63236 m .33149 .63254 L .32999 .6334 L F
.33296 .63239 m .32999 .6334 L .32999 .63341 L F
.33298 .63239 m .32999 .6334 L .33296 .63239 L F
.698 .983 .843 r
.3325 .63183 m .33396 .63205 L .33032 .63349 L F
.3325 .63183 m .33032 .63349 L .33256 .63197 L F
.821 .354 0 r
.33127 .62927 m .33372 .63181 L .3325 .63183 L F
.65 .962 .786 r
.33354 .63205 m .33433 .63103 L .3325 .63183 L F
.33354 .63205 m .33382 .63181 L .33372 .63181 L F
.821 .354 0 r
.33372 .63181 m .33396 .63205 L .3325 .63183 L F
.591 .948 .886 r
.33198 .62706 m .33386 .62683 L .33416 .62565 L F
.553 .084 0 r
.32985 .62445 m .33198 .62706 L .33044 .6252 L F
.7 .519 .64 r
.33198 .62706 m .32801 .62572 L .33044 .6252 L F
.33198 .62706 m .32851 .62791 L .32801 .62572 L F
.33198 .62706 m .33182 .62887 L .32851 .62791 L F
.642 .761 .935 r
.33044 .6252 m .33198 .62706 L .33416 .62565 L F
.33044 .6252 m .33416 .62565 L .33276 .62436 L F
.495 .619 .904 r
.33276 .62436 m .33198 .62706 L .33044 .6252 L F
0 .146 .689 r
.33386 .62683 m .33611 .62906 L .33416 .62565 L F
.495 .619 .904 r
.33276 .62436 m .33487 .62796 L .33198 .62706 L F
.655 .479 .635 r
.33198 .62706 m .33487 .62796 L .33182 .62887 L F
.399 .304 .632 r
.33071 .6287 m .33332 .63126 L .33255 .6261 L F
.33332 .63126 m .33344 .63137 L .33341 .63119 L F
.33332 .63126 m .33341 .63119 L .33255 .6261 L F
.909 .765 .689 r
.33416 .62565 m .33611 .62906 L .33487 .62796 L F
.608 .604 .822 r
.33416 .62565 m .33487 .62796 L .33688 .62513 L F
.577 .778 .975 r
.33457 .62488 m .33688 .62513 L .33416 .62565 L F
.682 .712 .871 r
.33688 .62513 m .33457 .62488 L .33276 .62436 L F
.33688 .62513 m .33276 .62436 L .33513 .62383 L F
.577 .778 .975 r
.33513 .62383 m .33688 .62513 L .33457 .62488 L F
.682 .712 .871 r
.33688 .62513 m .33663 .62548 L .33457 .62488 L F
.577 .778 .975 r
.33457 .62488 m .33416 .62565 L .33276 .62436 L F
.682 .712 .871 r
.33663 .62548 m .33487 .62796 L .33276 .62436 L F
.577 .778 .975 r
.33513 .62383 m .33457 .62488 L .33276 .62436 L F
.777 .677 .754 r
.33341 .63119 m .33444 .62661 L .33255 .6261 L F
.33344 .63137 m .33349 .63112 L .33341 .63119 L F
.33349 .63112 m .33444 .62661 L .33341 .63119 L F
.566 .927 .764 r
.33287 .63161 m .33433 .63103 L .33501 .63037 L F
.33284 .63163 m .33286 .63162 L .33287 .63161 L F
.33286 .63162 m .33433 .63103 L .33287 .63161 L F
.3325 .63183 m .3327 .63174 L .33284 .63163 L F
.3327 .63174 m .33433 .63103 L .33284 .63163 L F
.33433 .63103 m .33444 .63098 L .33501 .63037 L F
.31 0 .004 r
.3325 .63183 m .33501 .63037 L .33568 .63063 L F
.65 .962 .786 r
.33349 .63209 m .33649 .63008 L .33516 .63067 L F
.33345 .63213 m .33649 .63008 L .33349 .63209 L F
.432 .285 .581 r
.33387 .6324 m .33264 .63282 L .33396 .63205 L F
.698 .983 .843 r
.3325 .63183 m .33344 .63137 L .33315 .63195 L F
.075 .278 .765 r
.32874 .63344 m .33029 .63785 L .32893 .63366 L F
.32858 .63344 m .33029 .63785 L .32874 .63344 L F
.32893 .63366 m .33029 .63785 L .33095 .63633 L F
.32993 .63486 m .33095 .63633 L .33102 .63617 L F
.32893 .63366 m .33095 .63633 L .32993 .63486 L F
.359 .272 .62 r
.32798 .63589 m .32948 .6363 L .32763 .63408 L F
.695 .484 .597 r
.32897 .63348 m .32811 .63598 L .32704 .63354 L F
.33084 .63341 m .32968 .6345 L .32897 .63348 L F
.32968 .6345 m .32811 .63598 L .32897 .63348 L F
.026 0 0 r
.33396 .63205 m .32867 .63425 L .33084 .63329 L F
0 0 .3 r
.33293 .63239 m .33396 .63205 L .3325 .63183 L F
.745 .776 .878 r
.33293 .63239 m .33401 .63227 L .33344 .63137 L F
.33278 .63268 m .33309 .63257 L .33293 .63239 L F
0 0 .3 r
.33449 .63443 m .33308 .63559 L .33396 .63205 L F
.33439 .63399 m .33396 .63205 L .33309 .63234 L F
.33309 .63257 m .33309 .63234 L .33293 .63239 L F
.33439 .63399 m .33309 .63234 L .33309 .63257 L F
.695 .484 .597 r
.33084 .63341 m .33102 .63617 L .32811 .63598 L F
.432 .285 .581 r
.33308 .63559 m .33102 .63617 L .33084 .63341 L F
.33084 .63341 m .33308 .63559 L .33236 .63304 L F
.33084 .63341 m .33102 .63617 L .33308 .63559 L F
0 0 .34 r
.33032 .63349 m .33136 .63534 L .3331 .63332 L F
0 0 .3 r
.33449 .63443 m .33439 .63399 L .33293 .63239 L F
.745 .776 .878 r
.33309 .63257 m .33401 .63227 L .33293 .63239 L F
.698 .983 .843 r
.33291 .63237 m .33367 .63204 L .33381 .63246 L F
.33309 .63261 m .33381 .63246 L .33449 .63443 L F
0 0 .34 r
.33309 .63257 m .33309 .63261 L .33401 .63227 L F
.33309 .63261 m .33386 .63245 L .33401 .63227 L F
.698 .983 .843 r
.33291 .63237 m .33381 .63246 L .33309 .63261 L F
0 0 .34 r
.33309 .63261 m .3331 .63332 L .33386 .63245 L F
.33032 .63349 m .3331 .63332 L .33309 .63257 L F
.698 .983 .843 r
.3325 .63183 m .33367 .63204 L .33291 .63237 L F
.745 .776 .878 r
.33032 .63349 m .33278 .63268 L .33344 .63137 L F
.698 .983 .843 r
.33315 .63195 m .33344 .63137 L .33367 .63204 L F
.026 0 0 r
.33068 .63341 m .32996 .63342 L .32815 .63446 L F
.33084 .63329 m .32815 .63446 L .33032 .63349 L F
.32867 .63425 m .32815 .63446 L .33084 .63329 L F
.698 .983 .843 r
.3325 .63183 m .33256 .63197 L .33344 .63137 L F
.821 .354 0 r
.33071 .6287 m .33127 .62927 L .3325 .63183 L F
.65 .962 .786 r
.33372 .63181 m .33516 .63067 L .33433 .63103 L F
.33382 .63181 m .33516 .63067 L .33372 .63181 L F
.31 0 .004 r
.33501 .63037 m .33754 .6289 L .33597 .63036 L F
.566 .927 .764 r
.33444 .63098 m .33649 .63008 L .3353 .63021 L F
.31 0 .004 r
.33501 .63037 m .33597 .63036 L .33568 .63063 L F
.436 .605 .918 r
.32924 .62922 m .33122 .63041 L .33071 .6287 L F
.371 .131 .414 r
.33118 .6326 m .33121 .63252 L .33132 .63257 L F
.76 .745 .839 r
.32876 .63315 m .33144 .63254 L .32817 .63132 L F
.33144 .63254 m .33148 .6325 L .32817 .63132 L F
.233 0 0 r
.32999 .6334 m .33149 .63254 L .32976 .63292 L F
.33149 .63254 m .33144 .63254 L .32976 .63292 L F
.075 .278 .765 r
.32844 .63307 m .32858 .63344 L .32874 .63344 L F
.714 .491 .586 r
.33029 .63292 m .32881 .63348 L .32704 .63354 L F
.233 0 0 r
.32999 .6334 m .32976 .63292 L .32876 .63315 L F
.026 0 0 r
.32999 .63341 m .32999 .6334 L .32996 .63342 L F
.233 0 0 r
.32815 .63446 m .32996 .63342 L .32704 .63354 L F
.32996 .63342 m .32876 .63315 L .32704 .63354 L F
.76 .745 .839 r
.32817 .63132 m .331 .63233 L .32924 .62922 L F
.331 .63233 m .33153 .63252 L .33092 .63164 L F
.331 .63233 m .33092 .63164 L .32924 .62922 L F
.32704 .63354 m .32876 .63315 L .32817 .63132 L F
.075 .278 .765 r
.32729 .63169 m .32732 .63176 L .32734 .63175 L F
.76 .745 .839 r
.32751 .63166 m .32924 .62922 L .32776 .63069 L F
.32817 .63132 m .32924 .62922 L .32751 .63166 L F
0 0 .407 r
.32704 .63354 m .32669 .63175 L .3275 .63171 L F
.32669 .63175 m .32668 .63166 L .32723 .63169 L F
.32669 .63175 m .32723 .63169 L .3275 .63171 L F
.32728 .6317 m .32668 .63166 L .32734 .63152 L F
.075 .278 .765 r
.32713 .6315 m .32723 .63169 L .32729 .63169 L F
.657 .337 .42 r
.32234 .62991 m .32525 .6303 L .32439 .63241 L F
0 0 .053 r
.32439 .63241 m .3266 .62941 L .32556 .63191 L F
.37 .113 .388 r
.32385 .63483 m .32439 .63241 L .32556 .63191 L F
0 0 .122 r
.32851 .62791 m .32556 .63191 L .3266 .62941 L F
.37 .113 .388 r
.32385 .63483 m .32556 .63191 L .32615 .63394 L F
0 0 .122 r
.32851 .62791 m .32776 .63069 L .32556 .63191 L F
0 0 .407 r
.32704 .63354 m .32615 .63394 L .32556 .63191 L F
.759 .523 .575 r
.32704 .63354 m .32749 .63178 L .32366 .63068 L F
.09 0 0 r
.32731 .6316 m .32726 .63154 L .32713 .6315 L F
0 0 .407 r
.3275 .63171 m .32742 .63171 L .32756 .63147 L F
.32742 .63171 m .32728 .6317 L .32735 .63164 L F
.32742 .63171 m .32735 .63164 L .32756 .63147 L F
.32728 .6317 m .32734 .63152 L .32756 .63147 L F
.075 .278 .765 r
.32713 .6315 m .32729 .63169 L .32731 .6316 L F
.359 .272 .62 r
.32717 .63169 m .32723 .63169 L .32713 .6315 L F
.759 .523 .575 r
.32749 .63178 m .32776 .63069 L .32512 .63068 L F
.32749 .63178 m .32512 .63068 L .32366 .63068 L F
.979 .748 .518 r
.34073 .54695 m .33876 .54588 L .33918 .5433 L F
.557 .332 .529 r
.34332 .54914 m .34073 .54695 L .34381 .54675 L F
.34332 .54914 m .34053 .54972 L .34073 .54695 L F
.338 0 0 r
.27899 .64536 m .28082 .64372 L .28267 .64492 L F
0 0 0 r
.36684 .53429 m .36866 .53381 L .36993 .53179 L F
.033 .189 .694 r
.36993 .53179 m .37081 .53013 L .36854 .52747 L F
0 0 0 r
.36993 .53179 m .37033 .5321 L .37081 .53013 L F
.36993 .53179 m .36866 .53381 L .37033 .5321 L F
.624 .479 .664 r
.36097 .62479 m .36144 .62798 L .35856 .62808 L F
.508 .272 .491 r
.36144 .62798 m .35873 .63086 L .35856 .62808 L F
.643 .257 .297 r
.34444 .66823 m .34326 .67051 L .3409 .6699 L F
.452 .196 .434 r
.34625 .66754 m .34326 .67051 L .34444 .66823 L F
.04 .369 .838 r
.22143 .6256 m .22189 .6246 L .22087 .62405 L F
.22143 .6256 m .22467 .62768 L .22189 .6246 L F
.443 .427 .746 r
.17284 .59483 m .17369 .59009 L .17272 .59042 L F
.249 .696 .957 r
.23997 .63481 m .2404 .63345 L .23881 .63294 L F
.23997 .63481 m .24235 .63484 L .2404 .63345 L F
.2 .714 .886 r
.26308 .54585 m .26126 .5455 L .25865 .54566 L F
.278 .741 .949 r
.26528 .54601 m .26126 .5455 L .26308 .54585 L F
.311 .739 .972 r
.29847 .67712 m .30046 .67804 L .29798 .67805 L F
0 .321 .808 r
.29832 .67739 m .29798 .67805 L .29895 .67794 L F
.29743 .67661 m .29798 .67805 L .29832 .67739 L F
.29743 .67661 m .29832 .67739 L .29814 .67697 L F
.29832 .67739 m .29895 .67794 L .29814 .67697 L F
.311 .739 .972 r
.29814 .67697 m .29847 .67712 L .29832 .67739 L F
.29814 .67697 m .29832 .67739 L .29798 .67805 L F
.29814 .67697 m .29798 .67805 L .29743 .67661 L F
.066 .627 .78 r
.29798 .67805 m .30046 .67804 L .29895 .67794 L F
.552 .419 .654 r
.28818 .54406 m .28817 .54681 L .28581 .54734 L F
.242 .397 .819 r
.36237 .57526 m .36367 .57819 L .36497 .57692 L F
.118 0 .388 r
.36367 .57819 m .3655 .5787 L .36497 .57692 L F
.36367 .57819 m .36341 .58044 L .3655 .5787 L F
.309 .721 .976 r
.28982 .5533 m .28546 .55223 L .28733 .55319 L F
0 0 0 r
.17707 .57142 m .17873 .57074 L .18013 .5687 L F
.102 0 0 r
.18013 .5687 m .18067 .57002 L .18163 .56842 L F
.18013 .5687 m .17873 .57074 L .18067 .57002 L F
.826 .603 .6 r
.34056 .53365 m .34414 .53433 L .3424 .53176 L F
.679 .574 .73 r
.3424 .53176 m .34414 .53433 L .34678 .53145 L F
0 .227 .748 r
.34556 .55091 m .344 .55024 L .34332 .54914 L F
.178 0 .344 r
.34538 .54597 m .34332 .54914 L .34381 .54675 L F
.81 .962 .638 r
.34538 .54597 m .34363 .54747 L .34332 .54914 L F
0 .238 .753 r
.34363 .54747 m .34556 .55091 L .34332 .54914 L F
.541 .402 .64 r
.34511 .54736 m .34556 .55091 L .34363 .54747 L F
.34511 .54736 m .34344 .54988 L .34556 .55091 L F
.726 .219 .023 r
.34344 .54988 m .34668 .55139 L .34556 .55091 L F
.34668 .55139 m .34785 .55194 L .34556 .55091 L F
0 .227 .748 r
.34556 .55091 m .34619 .55379 L .344 .55024 L F
0 .015 .528 r
.34556 .55091 m .3447 .55584 L .34619 .55379 L F
.599 .475 .682 r
.29574 .6434 m .29857 .64007 L .29663 .64086 L F
0 .545 .75 r
.24573 .6232 m .24981 .62371 L .24798 .62385 L F
.764 .807 .887 r
.53823 .53962 m .53753 .5414 L .53999 .54039 L F
.501 .38 .646 r
.38155 .58751 m .38171 .59022 L .37943 .59079 L F
.492 .352 .617 r
.38171 .59022 m .38201 .59286 L .37943 .59079 L F
.438 .355 .666 r
.38201 .59286 m .38004 .59374 L .37943 .59079 L F
.144 .366 .822 r
.29654 .64933 m .29868 .65356 L .29913 .65125 L F
.737 .74 .222 r
.29913 .65125 m .29868 .65356 L .29848 .65382 L F
.414 .824 .975 r
.30078 .65549 m .30338 .65478 L .30246 .6561 L F
.29874 .65476 m .29996 .65476 L .30078 .65549 L F
.6 .143 .138 r
.29868 .65356 m .3011 .65527 L .29956 .65442 L F
.29865 .65361 m .29956 .65442 L .29855 .65386 L F
.29849 .65381 m .29855 .65386 L .29848 .65382 L F
.29865 .65361 m .29855 .65386 L .29849 .65381 L F
.29868 .65356 m .29956 .65442 L .29865 .65361 L F
.737 .74 .222 r
.29913 .65125 m .29848 .65382 L .3011 .65527 L F
.29913 .65125 m .3011 .65527 L .29874 .65476 L F
.048 0 .397 r
.29913 .65125 m .29881 .65408 L .30078 .65253 L F
.29881 .65408 m .29874 .65476 L .29912 .65434 L F
.29881 .65408 m .29912 .65434 L .30078 .65253 L F
.414 .824 .975 r
.29874 .65476 m .3011 .65527 L .30338 .65478 L F
.29996 .65476 m .30338 .65478 L .30078 .65549 L F
.137 .509 .911 r
.29277 .64721 m .29557 .64958 L .29654 .64933 L F
.872 .791 .767 r
.33013 .54925 m .33424 .54716 L .33258 .54861 L F
.438 .826 .987 r
.2523 .53189 m .25462 .53141 L .25646 .53212 L F
.368 .804 .961 r
.25462 .53141 m .25883 .53156 L .25646 .53212 L F
.647 .678 .865 r
.3215 .62555 m .32283 .62843 L .32013 .62795 L F
.681 .291 .301 r
.32013 .62795 m .32234 .62991 L .31861 .6303 L F
.32013 .62795 m .32283 .62843 L .32234 .62991 L F
.488 .328 .589 r
.50335 .55067 m .50576 .55022 L .50552 .5468 L F
0 .08 .633 r
.17498 .59654 m .17455 .59455 L .17284 .59483 L F
.17498 .59654 m .17535 .59621 L .17455 .59455 L F
.766 .494 .522 r
.22617 .55652 m .22546 .55875 L .22181 .55799 L F
.403 .131 .383 r
.22786 .55794 m .22546 .55875 L .22617 .55652 L F
.472 .115 .277 r
.22892 .55622 m .22786 .55794 L .22617 .55652 L F
.528 .57 .841 r
.26149 .7182 m .26533 .72128 L .26379 .71775 L F
.565 .28 .441 r
.26048 .55024 m .25992 .55263 L .26259 .5523 L F
.565 .28 .442 r
.26048 .55024 m .26259 .5523 L .26264 .55025 L F
.506 .826 1 r
.24597 .532 m .24819 .5314 L .25 .53234 L F
.431 .799 .995 r
.24819 .5314 m .2523 .53189 L .25 .53234 L F
.744 .847 .928 r
.37099 .52226 m .36704 .52249 L .36932 .5217 L F
.37099 .52226 m .36797 .52295 L .36704 .52249 L F
.087 .23 .717 r
.37169 .52126 m .37099 .52226 L .36932 .5217 L F
.37169 .52126 m .37175 .52488 L .37099 .52226 L F
.656 .751 .919 r
.32397 .62446 m .3215 .62555 L .32226 .6228 L F
.764 .824 .355 r
.32416 .62431 m .3215 .62555 L .32397 .62446 L F
.32416 .62431 m .32283 .62843 L .3215 .62555 L F
.629 .238 .284 r
.32283 .62843 m .32525 .6303 L .32234 .62991 L F
.345 .083 .365 r
.20474 .54727 m .20414 .54964 L .20678 .54669 L F
.635 .576 .771 r
.35882 .58753 m .36051 .59146 L .36277 .59069 L F
.44 .395 .711 r
.36051 .59146 m .363 .59337 L .36277 .59069 L F
.36051 .59146 m .36109 .59442 L .363 .59337 L F
0 0 0 r
.27902 .60619 m .28076 .60538 L .28168 .60335 L F
.28168 .60335 m .28227 .60437 L .28411 .60314 L F
.28168 .60335 m .28076 .60538 L .28227 .60437 L F
.493 .459 .748 r
.34273 .61693 m .33964 .61507 L .34137 .61473 L F
0 0 0 r
.32129 .60634 m .32363 .60299 L .32352 .60575 L F
.419 .169 .427 r
.32352 .60575 m .32083 .60872 L .32129 .60634 L F
.741 .679 .79 r
.33069 .5625 m .33174 .56535 L .32776 .56541 L F
0 0 0 r
.36109 .59442 m .35979 .59605 L .363 .59337 L F
.691 .577 .722 r
.35072 .65312 m .34907 .6562 L .34751 .6526 L F
.419 .194 .464 r
.31186 .54732 m .314 .54664 L .31458 .54411 L F
.465 .244 .493 r
.31186 .54732 m .31379 .5492 L .314 .54664 L F
.31186 .54732 m .31148 .55018 L .31379 .5492 L F
.678 .938 .965 r
.20152 .58897 m .20131 .59066 L .20277 .58951 L F
.732 .235 0 r
.20132 .59176 m .20131 .59066 L .20152 .58897 L F
.106 .096 .562 r
.20131 .59066 m .20289 .59308 L .20185 .59313 L F
.732 .235 0 r
.20132 .59176 m .20289 .59308 L .20131 .59066 L F
.423 .436 .769 r
.3892 .53636 m .38729 .53837 L .38618 .53458 L F
.598 .517 .734 r
.50499 .54365 m .50755 .54319 L .50752 .54105 L F
.526 .404 .656 r
.50552 .5468 m .50755 .54319 L .50499 .54365 L F
.443 .427 .746 r
.17284 .59483 m .17455 .59455 L .17369 .59009 L F
.492 .152 .317 r
.34537 .61815 m .34796 .61784 L .34905 .61524 L F
.103 0 .199 r
.27874 .6068 m .28076 .60538 L .27902 .60619 L F
0 0 .27 r
.31796 .61417 m .31812 .61716 L .31748 .61865 L F
.174 .445 .874 r
.31812 .61716 m .3215 .62059 L .31748 .61865 L F
.042 .322 .806 r
.32141 .62278 m .31748 .61865 L .3215 .62059 L F
.209 0 .029 r
.22144 .53965 m .22238 .53861 L .22033 .54033 L F
.114 0 0 r
.22446 .53767 m .22238 .53861 L .22144 .53965 L F
.733 .691 .81 r
.33272 .66201 m .32914 .66238 L .33172 .65858 L F
.718 .49 .58 r
.33272 .66201 m .32871 .66417 L .32914 .66238 L F
.33272 .66201 m .33302 .66475 L .32871 .66417 L F
.47 .516 .823 r
.33399 .65807 m .33272 .66201 L .33172 .65858 L F
.33399 .65807 m .33548 .66194 L .33272 .66201 L F
.456 .836 .605 r
.30431 .54152 m .30269 .54271 L .303 .54245 L F
.113 .414 .862 r
.303 .54245 m .30422 .54175 L .30396 .54165 L F
.303 .54245 m .30396 .54165 L .30166 .54075 L F
.456 .836 .605 r
.30269 .54271 m .30106 .54391 L .303 .54245 L F
.668 .861 .973 r
.30166 .54075 m .30431 .54152 L .30596 .5403 L F
.30166 .54075 m .30431 .54152 L .30596 .5403 L F
.554 .856 .997 r
.24235 .63484 m .24615 .63504 L .24446 .63452 L F
.242 0 .298 r
.17487 .57464 m .17664 .57397 L .17707 .57142 L F
.346 .166 .488 r
.17664 .57397 m .17873 .57074 L .17707 .57142 L F
.173 0 .301 r
.37314 .55224 m .37528 .54935 L .37367 .55025 L F
.291 .077 .407 r
.32778 .5753 m .32917 .57693 L .32937 .57439 L F
.32778 .5753 m .32729 .57783 L .32917 .57693 L F
.157 0 0 r
.24962 .54254 m .24921 .54265 L .24747 .54322 L F
.24921 .54265 m .24511 .54376 L .24747 .54322 L F
.741 .739 .849 r
.24472 .54322 m .24606 .54368 L .24747 .54322 L F
.24606 .54368 m .24928 .54479 L .24747 .54322 L F
.628 .817 .973 r
.24747 .54322 m .24928 .54479 L .25169 .54353 L F
.406 .111 .348 r
.32494 .57848 m .32659 .58001 L .32729 .57783 L F
.32494 .57848 m .32428 .58059 L .32659 .58001 L F
.485 .709 .969 r
.35053 .62198 m .35138 .62014 L .34901 .62099 L F
.35053 .62198 m .3529 .6216 L .35138 .62014 L F
.536 .564 .83 r
.26379 .71775 m .26533 .72128 L .26569 .71747 L F
.505 .283 .511 r
.2935 .63097 m .29075 .63372 L .29104 .63112 L F
.639 .617 .812 r
.36272 .52787 m .36605 .52912 L .36376 .5255 L F
.416 .685 .974 r
.31885 .53004 m .31836 .53023 L .31576 .52827 L F
.302 .233 .61 r
.32377 .64992 m .32553 .64563 L .32372 .6463 L F
.32377 .64992 m .326 .64882 L .32553 .64563 L F
.046 0 .442 r
.32457 .65246 m .326 .64882 L .32377 .64992 L F
.434 .159 .396 r
.35842 .54372 m .35571 .54637 L .3563 .54455 L F
.35842 .54372 m .35571 .54637 L .3563 .54455 L F
.733 .85 .936 r
.36512 .65908 m .36146 .659 L .36314 .65892 L F
.527 .377 .621 r
.36366 .66128 m .36146 .659 L .36512 .65908 L F
.764 .832 .904 r
.36512 .65908 m .36548 .65598 L .36632 .65724 L F
.36512 .65908 m .36314 .65892 L .36548 .65598 L F
0 0 0 r
.36649 .65846 m .36512 .65908 L .36632 .65724 L F
.36649 .65846 m .36366 .66128 L .36512 .65908 L F
.389 0 .165 r
.29755 .54637 m .29963 .54605 L .30106 .54391 L F
.463 .158 .363 r
.29963 .54605 m .303 .54245 L .30106 .54391 L F
.226 0 .319 r
.35795 .59686 m .35552 .60008 L .35741 .59906 L F
.384 .15 .431 r
.3546 .60291 m .35741 .59906 L .35552 .60008 L F
0 0 0 r
.21791 .56018 m .21749 .56028 L .21956 .55885 L F
.21791 .56018 m .21529 .56115 L .21749 .56028 L F
.548 .693 .935 r
.38404 .52894 m .38255 .53124 L .38064 .52825 L F
.38404 .52894 m .38498 .53081 L .38255 .53124 L F
0 0 .282 r
.36089 .6207 m .36136 .62347 L .36097 .62479 L F
.65 .092 0 r
.36097 .62479 m .36466 .62715 L .36144 .62798 L F
.38 .051 .278 r
.36466 .62715 m .36107 .63048 L .36144 .62798 L F
.36466 .62715 m .36352 .6299 L .36107 .63048 L F
.65 .092 0 r
.36097 .62479 m .36446 .6274 L .36466 .62715 L F
.76 .837 .379 r
.36466 .62715 m .36446 .6274 L .3647 .62644 L F
.178 .439 .87 r
.3647 .62644 m .36446 .6274 L .36404 .62687 L F
.3647 .62644 m .36404 .62687 L .36136 .62347 L F
.757 .62 .708 r
.36648 .62501 m .36581 .62572 L .3647 .62644 L F
.067 0 .426 r
.3647 .62644 m .36352 .6299 L .36466 .62715 L F
.3647 .62644 m .3647 .62672 L .36461 .62671 L F
.36461 .62671 m .36473 .62903 L .36352 .6299 L F
.3647 .62672 m .36473 .62903 L .36461 .62671 L F
.01 .335 .817 r
.36387 .62665 m .36446 .6274 L .3634 .62661 L F
.508 .272 .491 r
.36144 .62798 m .36107 .63048 L .35873 .63086 L F
.759 .506 .551 r
.36004 .6285 m .36473 .62903 L .3647 .62644 L F
.757 .62 .708 r
.36581 .62572 m .36412 .6275 L .3647 .62644 L F
.36412 .6275 m .36372 .62792 L .3647 .62644 L F
.01 .335 .817 r
.36136 .62347 m .36387 .62665 L .36097 .62479 L F
.36387 .62665 m .3634 .62661 L .36097 .62479 L F
.357 .208 .538 r
.35882 .58753 m .36069 .58381 L .35851 .58473 L F
.681 .606 .765 r
.34952 .64945 m .35072 .65312 L .34751 .6526 L F
.226 0 0 r
.28503 .63158 m .28448 .63109 L .28201 .63022 L F
.058 .081 .568 r
.34513 .56162 m .34546 .56435 L .34398 .5647 L F
.41 .189 .465 r
.34546 .56435 m .34317 .56739 L .34398 .5647 L F
.034 0 .29 r
.31458 .54411 m .314 .54664 L .31583 .54307 L F
.468 .338 .62 r
.25354 .72774 m .25384 .73033 L .25606 .72995 L F
.949 .957 .709 r
.28461 .61574 m .28237 .61714 L .28296 .61765 L F
0 0 0 r
.28562 .61468 m .28461 .61574 L .28674 .61235 L F
.507 .876 .659 r
.28386 .61601 m .28461 .61574 L .28562 .61468 L F
.28386 .61601 m .28237 .61714 L .28461 .61574 L F
.382 0 .049 r
.32922 .58387 m .32862 .58473 L .32386 .58654 L F
.276 0 0 r
.32922 .58387 m .33033 .58525 L .32862 .58473 L F
.32922 .58387 m .33095 .58417 L .33033 .58525 L F
.783 .657 .724 r
.36323 .56605 m .36169 .56884 L .36543 .56868 L F
.653 .521 .69 r
.36169 .56884 m .36388 .57061 L .36543 .56868 L F
.688 .391 .467 r
.36388 .57061 m .36772 .57131 L .36543 .56868 L F
0 0 .058 r
.33282 .55846 m .33069 .5625 L .33216 .56079 L F
.577 .699 .925 r
.33282 .55846 m .33374 .5553 L .33156 .55554 L F
.33282 .55846 m .33573 .55758 L .33374 .5553 L F
.456 .271 .541 r
.31658 .63083 m .31644 .63343 L .31423 .63382 L F
.451 .305 .591 r
.31656 .63618 m .31423 .63382 L .31644 .63343 L F
.31656 .63618 m .31444 .63721 L .31423 .63382 L F
.543 .68 .928 r
.2063 .61573 m .21123 .6177 L .208 .61549 L F
.331 .661 .973 r
.21123 .6177 m .21112 .61628 L .208 .61549 L F
.21123 .6177 m .21293 .61774 L .21112 .61628 L F
.14 0 0 r
.23243 .53593 m .2311 .53569 L .22898 .53655 L F
0 0 0 r
.29692 .52833 m .29919 .52817 L .3009 .52802 L F
.194 .719 .855 r
.29919 .52817 m .30326 .52813 L .3009 .52802 L F
.782 .39 .312 r
.53522 .53773 m .53823 .53962 L .53892 .53779 L F
.339 .158 .482 r
.30659 .64946 m .30677 .64654 L .30922 .6458 L F
.612 .955 .893 r
.23269 .75397 m .23644 .7525 L .23443 .7543 L F
.281 0 0 r
.23644 .7525 m .23663 .7539 L .23443 .7543 L F
.653 .256 .279 r
.31536 .6558 m .31756 .65789 L .3191 .65573 L F
.228 0 .018 r
.3191 .65573 m .31979 .65729 L .32176 .65593 L F
.3191 .65573 m .31756 .65789 L .31979 .65729 L F
.613 .4 .568 r
.33921 .64901 m .33666 .64656 L .33814 .6451 L F
.33921 .64901 m .3365 .64935 L .33666 .64656 L F
.837 .83 .84 r
.3581 .6124 m .35415 .61372 L .35667 .6115 L F
.988 .798 .56 r
.35737 .60896 m .3581 .6124 L .35667 .6115 L F
.574 .56 .801 r
.36136 .61539 m .3581 .6124 L .36088 .61165 L F
.531 .758 .98 r
.3116 .52993 m .30707 .529 L .30943 .52858 L F
.635 .779 .95 r
.31187 .5275 m .3116 .52993 L .30943 .52858 L F
.31187 .5275 m .31366 .52923 L .3116 .52993 L F
.508 .565 .848 r
.21999 .61116 m .21939 .61468 L .218 .61165 L F
.21999 .61116 m .22155 .61435 L .21939 .61468 L F
0 0 .151 r
.25715 .73344 m .25606 .73473 L .2552 .73656 L F
.641 .246 .279 r
.23423 .75153 m .23252 .74909 L .23189 .75224 L F
.23423 .75153 m .23515 .74971 L .23252 .74909 L F
.423 .167 .42 r
.20347 .57201 m .20298 .57434 L .20079 .57479 L F
.464 .204 .434 r
.20534 .57368 m .20298 .57434 L .20347 .57201 L F
.468 .204 .429 r
.2059 .5715 m .20534 .57368 L .20347 .57201 L F
.526 .404 .656 r
.50552 .5468 m .5081 .54618 L .50755 .54319 L F
.38 .196 .501 r
.50576 .55022 m .5081 .54618 L .50552 .5468 L F
.974 .736 .516 r
.33221 .53085 m .33371 .53385 L .33408 .53167 L F
.33221 .53085 m .33146 .53309 L .33371 .53385 L F
.889 .598 .488 r
.33038 .53573 m .33371 .53385 L .33146 .53309 L F
.33038 .53573 m .33377 .53753 L .33371 .53385 L F
.918 .624 .472 r
.33371 .53385 m .33377 .53753 L .33567 .53787 L F
.41 .207 .492 r
.33855 .57134 m .33619 .57436 L .33657 .57218 L F
.684 .634 .793 r
.36376 .5255 m .36605 .52912 L .36854 .52747 L F
0 0 0 r
.5343 .54586 m .5343 .54401 L .53642 .54305 L F
.5343 .54586 m .53351 .54641 L .5343 .54401 L F
.779 .57 .618 r
.39581 .55684 m .39414 .5589 L .39454 .55646 L F
.265 .015 .335 r
.35979 .59605 m .35795 .59686 L .35741 .59906 L F
.544 .383 .613 r
.3365 .64935 m .33406 .65254 L .33404 .64986 L F
.495 .333 .591 r
.32975 .57161 m .33216 .57127 L .33204 .56856 L F
.587 .397 .591 r
.32937 .57439 m .33216 .57127 L .32975 .57161 L F
.729 .782 .291 r
.28296 .61765 m .28174 .62127 L .28258 .61893 L F
.498 .589 .876 r
.522 .56181 m .52283 .55831 L .52082 .55972 L F
.522 .56181 m .52424 .5615 L .52283 .55831 L F
.138 0 0 r
.19869 .55237 m .20036 .55235 L .20204 .55046 L F
.098 0 0 r
.20204 .55046 m .20248 .55162 L .20414 .54964 L F
.20204 .55046 m .20036 .55235 L .20248 .55162 L F
.356 .405 .774 r
.35233 .6515 m .35072 .65312 L .34952 .64945 L F
.055 .207 .705 r
.35234 .65351 m .35072 .65312 L .35233 .6515 L F
.35234 .65351 m .35201 .65513 L .35072 .65312 L F
.394 .322 .657 r
.32372 .6463 m .32553 .64563 L .32499 .64306 L F
.749 .236 0 r
.283 .55591 m .28732 .55874 L .28426 .55721 L F
.286 .786 .794 r
.26262 .53053 m .26333 .5301 L .26487 .53031 L F
.26262 .53053 m .26106 .53076 L .26333 .5301 L F
.429 .585 .905 r
.28734 .64441 m .28809 .64489 L .28942 .64549 L F
.28809 .64489 m .29094 .64673 L .28942 .64549 L F
.056 .511 .893 r
.28942 .64549 m .29277 .64721 L .29186 .64644 L F
.353 0 0 r
.29107 .64624 m .28942 .64549 L .29186 .64644 L F
.056 .511 .893 r
.28942 .64549 m .29094 .64673 L .29277 .64721 L F
.353 0 0 r
.28727 .64523 m .28942 .64549 L .29107 .64624 L F
.524 0 0 r
.28532 .64522 m .28734 .64441 L .28942 .64549 L F
.459 0 0 r
.29384 .6427 m .29057 .64238 L .29181 .64255 L F
.105 .476 .895 r
.29206 .64134 m .29273 .64267 L .29181 .64255 L F
.827 .478 .395 r
.29512 .64572 m .29574 .6434 L .29181 .64255 L F
.105 .476 .895 r
.29273 .64267 m .29292 .64305 L .29181 .64255 L F
.459 0 0 r
.29057 .64238 m .28982 .64231 L .29181 .64255 L F
.507 0 0 r
.29181 .64255 m .29574 .6434 L .29384 .6427 L F
0 0 0 r
.32212 .58136 m .32053 .58454 L .32134 .58294 L F
0 0 .104 r
.32053 .58454 m .3204 .58699 L .32134 .58294 L F
.32053 .58454 m .32005 .58752 L .3204 .58699 L F
.869 .975 .851 r
.30656 .56196 m .30905 .55777 L .30811 .55938 L F
.909 .921 .814 r
.53591 .55557 m .53497 .55967 L .53696 .55638 L F
.894 .958 .832 r
.53814 .55274 m .53696 .55638 L .53965 .55352 L F
.53814 .55274 m .53591 .55557 L .53696 .55638 L F
.788 .666 .729 r
.33302 .66475 m .33467 .66856 L .33062 .66696 L F
.478 0 0 r
.33062 .66696 m .33467 .66856 L .33299 .66816 L F
.169 .706 .81 r
.33467 .66856 m .33548 .66824 L .33299 .66816 L F
.33467 .66856 m .33687 .6683 L .33548 .66824 L F
.752 .708 .811 r
.30908 .54236 m .30765 .54655 L .30727 .544 L F
.467 .227 .465 r
.33997 .53259 m .33771 .53486 L .34056 .53365 L F
.911 .532 .103 r
.32047 .596 m .32243 .59941 L .32169 .59712 L F
.697 .894 .526 r
.24794 .74616 m .25023 .74285 L .25035 .74575 L F
.52 .304 .526 r
.24794 .74616 m .2499 .74841 L .24744 .74837 L F
.24794 .74616 m .25035 .74575 L .2499 .74841 L F
.587 .561 .792 r
.30781 .57768 m .30904 .58125 L .31094 .57899 L F
.404 .184 .463 r
.31193 .57782 m .31188 .58061 L .30904 .58125 L F
.497 .3 .544 r
.31147 .5833 m .30904 .58125 L .31188 .58061 L F
.30904 .58125 m .31147 .5833 L .31094 .57899 L F
.30904 .58125 m .30896 .584 L .31147 .5833 L F
.31147 .5833 m .30896 .584 L .30904 .58125 L F
.182 0 .07 r
.20079 .57479 m .19955 .57682 L .19767 .57747 L F
.56 .264 .423 r
.20298 .57434 m .19955 .57682 L .20079 .57479 L F
.515 .4 .661 r
.19767 .57747 m .19803 .58097 L .19575 .58146 L F
.223 .167 .58 r
.31083 .61504 m .31041 .61878 L .31238 .61724 L F
.476 .355 .635 r
.31041 .61878 m .31311 .62093 L .31238 .61724 L F
.31041 .61878 m .31092 .62136 L .31311 .62093 L F
0 0 0 r
.28674 .61235 m .28922 .6095 L .28788 .61118 L F
.28922 .6095 m .28936 .60935 L .28788 .61118 L F
.757 .902 .512 r
.28788 .61118 m .28936 .60935 L .28988 .60774 L F
0 0 0 r
.28955 .60831 m .28788 .61118 L .28988 .60774 L F
.735 .89 .494 r
.28757 .61157 m .28788 .61118 L .28955 .60831 L F
0 0 0 r
.28562 .61468 m .28674 .61235 L .28788 .61118 L F
.735 .89 .494 r
.28675 .61291 m .28788 .61118 L .28757 .61157 L F
0 .124 .666 r
.31089 .60292 m .31109 .60232 L .30952 .60172 L F
.31089 .60292 m .31319 .60526 L .31109 .60232 L F
.749 .799 .893 r
.22775 .62999 m .23133 .63096 L .23259 .63061 L F
.496 .836 .998 r
.23237 .62912 m .23259 .63061 L .23462 .63013 L F
.23237 .62912 m .23033 .62969 L .23259 .63061 L F
0 0 .37 r
.36181 .61343 m .36136 .61539 L .36088 .61165 L F
0 0 .029 r
.36134 .61689 m .36136 .61539 L .36181 .61343 L F
.545 .329 .538 r
.3345 .60918 m .33716 .60869 L .33724 .60597 L F
.495 .289 .529 r
.33724 .60597 m .33944 .60796 L .33968 .60555 L F
.33724 .60597 m .33716 .60869 L .33944 .60796 L F
.335 0 .045 r
.32212 .58136 m .32319 .58257 L .32428 .58059 L F
.32212 .58136 m .32134 .58294 L .32319 .58257 L F
0 0 0 r
.33799 .54935 m .33816 .55018 L .34053 .54972 L F
.33799 .54935 m .3361 .55117 L .33816 .55018 L F
.321 .682 .978 r
.25191 .63523 m .25658 .63678 L .25567 .63554 L F
.304 .607 .953 r
.25658 .63678 m .25733 .63544 L .25567 .63554 L F
.25658 .63678 m .25858 .63708 L .25733 .63544 L F
.682 .618 .777 r
.33172 .65858 m .32914 .66238 L .32922 .65929 L F
0 0 .523 r
.32436 .60348 m .3258 .60551 L .32363 .60299 L F
.297 .758 .949 r
.3258 .60551 m .32352 .60575 L .32363 .60299 L F
.752 .708 .811 r
.30908 .54236 m .31118 .54718 L .30765 .54655 L F
.873 .731 .703 r
.31118 .54718 m .30788 .54917 L .30765 .54655 L F
.689 .678 .834 r
.31329 .54488 m .31118 .54718 L .30908 .54236 L F
0 0 0 r
.31095 .54771 m .31118 .54718 L .31329 .54488 L F
.616 .474 .666 r
.30868 .55275 m .30615 .55313 L .30591 .55067 L F
.904 .985 .749 r
.31079 .58879 m .31129 .58598 L .31228 .58821 L F
.31079 .58879 m .30916 .58936 L .31129 .58598 L F
.959 .732 .552 r
.24472 .54322 m .24208 .54611 L .24261 .54393 L F
.606 .657 .874 r
.51157 .55923 m .51252 .55518 L .50993 .55579 L F
.51157 .55923 m .51419 .55851 L .51252 .55518 L F
.742 .62 .723 r
.36799 .5399 m .36491 .54123 L .36377 .53754 L F
.331 0 .048 r
.36799 .5399 m .36753 .54078 L .36491 .54123 L F
0 0 0 r
.36967 .53961 m .36753 .54078 L .36799 .5399 L F
0 .52 .798 r
.1935 .60527 m .18846 .604 L .19166 .60548 L F
.762 .917 .543 r
.28988 .60774 m .28936 .60935 L .29144 .60595 L F
.498 .385 .656 r
.23979 .54915 m .23745 .55006 L .23953 .54673 L F
0 0 0 r
.23806 .55003 m .23745 .55006 L .23979 .54915 L F
.23806 .55003 m .2351 .55086 L .23745 .55006 L F
.69 .37 .429 r
.32047 .66502 m .32445 .66489 L .32289 .66758 L F
.725 .458 .522 r
.32688 .66507 m .32289 .66758 L .32445 .66489 L F
.754 .924 .946 r
.53041 .56089 m .53497 .55967 L .53369 .55876 L F
.909 .921 .814 r
.53591 .55557 m .53369 .55876 L .53497 .55967 L F
.927 .681 .547 r
.33377 .53753 m .33566 .54079 L .33567 .53787 L F
.013 .327 .812 r
.33706 .5378 m .33567 .53787 L .33377 .53753 L F
.33706 .5378 m .33778 .53964 L .33567 .53787 L F
.188 .711 .688 r
.23729 .53463 m .23243 .53593 L .23506 .53491 L F
.03 0 0 r
.23733 .53519 m .23729 .53463 L .23506 .53491 L F
.23733 .53519 m .23981 .53418 L .23729 .53463 L F
.434 .219 .487 r
.36988 .63719 m .37194 .63911 L .37237 .63673 L F
.36988 .63719 m .36962 .63972 L .37194 .63911 L F
.36988 .63719 m .37194 .63911 L .37237 .63673 L F
.36988 .63719 m .36962 .63972 L .37194 .63911 L F
.038 0 0 r
.34784 .55226 m .3495 .55181 L .35085 .55011 L F
.562 .602 .851 r
.35314 .65804 m .35231 .66189 L .35176 .65941 L F
.898 .848 .786 r
.29084 .59004 m .28933 .5936 L .2873 .59259 L F
.453 .308 .593 r
.28925 .59642 m .29155 .59575 L .28933 .5936 L F
.238 .222 .638 r
.28945 .59458 m .28933 .5936 L .29155 .59575 L F
.28945 .59458 m .2873 .59259 L .28933 .5936 L F
.816 .925 .907 r
.30594 .57639 m .30551 .57877 L .30781 .57768 L F
.30594 .57639 m .30412 .57798 L .30551 .57877 L F
.351 0 .036 r
.35842 .54372 m .36084 .54338 L .36073 .54251 L F
.417 .012 .161 r
.36084 .54338 m .36355 .54183 L .36073 .54251 L F
.715 .557 .672 r
.29449 .5493 m .29755 .54637 L .29535 .54741 L F
.638 .887 .549 r
.54085 .55173 m .53965 .55352 L .54235 .55028 L F
.595 .887 .991 r
.54085 .55173 m .53814 .55274 L .53965 .55352 L F
0 0 0 r
.25963 .6241 m .26164 .62338 L .26306 .62236 L F
.26306 .62236 m .26164 .62338 L .26497 .62111 L F
.015 .59 .718 r
.26721 .52952 m .26964 .5295 L .27174 .52951 L F
.012 0 0 r
.26964 .5295 m .2733 .52901 L .27174 .52951 L F
.274 .202 .591 r
.30289 .56363 m .30434 .56759 L .30377 .564 L F
.30289 .56363 m .30289 .56853 L .30434 .56759 L F
.479 .279 .53 r
.34088 .57072 m .33866 .56869 L .34104 .56811 L F
.34088 .57072 m .33855 .57134 L .33866 .56869 L F
.377 0 0 r
.37365 .6098 m .36972 .60874 L .3712 .60899 L F
.37365 .6098 m .36912 .61144 L .36972 .60874 L F
.37365 .6098 m .37197 .61181 L .36912 .61144 L F
0 0 0 r
.37394 .61014 m .37365 .6098 L .37528 .61013 L F
.37394 .61014 m .37197 .61181 L .37365 .6098 L F
.328 .012 .268 r
.376 .60882 m .37528 .61013 L .37365 .6098 L F
.466 .834 .992 r
.3274 .60607 m .32856 .60475 L .3258 .60551 L F
.32856 .60475 m .3274 .60607 L .3258 .60551 L F
.02 0 0 r
.32856 .60475 m .32766 .60525 L .3258 .60551 L F
.297 .758 .949 r
.3258 .60551 m .3274 .60607 L .32386 .60577 L F
.3258 .60551 m .3274 .60607 L .32352 .60575 L F
.02 0 0 r
.32766 .60525 m .32466 .60692 L .3258 .60551 L F
.297 .758 .949 r
.3258 .60551 m .32386 .60577 L .32352 .60575 L F
.466 .834 .992 r
.3274 .60607 m .32975 .60553 L .32856 .60475 L F
.32856 .60475 m .32975 .60553 L .3274 .60607 L F
.386 .247 .566 r
.33619 .57436 m .33633 .57747 L .33415 .57793 L F
.276 .046 .373 r
.33581 .57967 m .33415 .57793 L .33633 .57747 L F
.33581 .57967 m .33389 .58041 L .33415 .57793 L F
.499 .274 .504 r
.38989 .56186 m .38966 .56595 L .3861 .56637 L F
.602 .48 .686 r
.3917 .55863 m .39192 .5618 L .38989 .56186 L F
.554 .32 .514 r
.39155 .5646 m .38989 .56186 L .39192 .5618 L F
.39155 .5646 m .38966 .56595 L .38989 .56186 L F
0 0 0 r
.36684 .53429 m .36555 .5357 L .36866 .53381 L F
.478 .604 .899 r
.37622 .5361 m .37713 .53815 L .37851 .53585 L F
.268 .33 .742 r
.37713 .53815 m .37954 .53986 L .37851 .53585 L F
.334 .329 .704 r
.37792 .54038 m .37954 .53986 L .37713 .53815 L F
.574 .338 .521 r
.38004 .59374 m .37993 .59632 L .37691 .59655 L F
.258 .087 .448 r
.38161 .5953 m .38004 .59374 L .38201 .59286 L F
.38161 .5953 m .37993 .59632 L .38004 .59374 L F
.348 0 .205 r
.32329 .55951 m .32268 .56151 L .3203 .56203 L F
.34 .366 .743 r
.32512 .55822 m .32329 .55951 L .3227 .55656 L F
0 0 .044 r
.32512 .55822 m .32268 .56151 L .32329 .55951 L F
.454 .876 .763 r
.3545 .66401 m .3555 .66379 L .35864 .66216 L F
.766 .454 .457 r
.26892 .70891 m .26685 .70786 L .26491 .70851 L F
.054 .574 .873 r
.22399 .6137 m .22781 .61481 L .22573 .61489 L F
.357 .507 .871 r
.19937 .61158 m .19899 .60811 L .19792 .60799 L F
.19937 .61158 m .20101 .61141 L .19899 .60811 L F
.55 .886 .633 r
.30338 .65478 m .3056 .65318 L .30688 .65196 L F
.536 .362 .592 r
.33006 .61844 m .33252 .61804 L .33244 .6153 L F
.356 0 .095 r
.33105 .6202 m .33006 .61844 L .3287 .62054 L F
.33105 .6202 m .33252 .61804 L .33006 .61844 L F
.536 .362 .592 r
.33006 .61844 m .33252 .61804 L .33244 .6153 L F
.191 .079 .487 r
.17281 .58116 m .17415 .58121 L .17416 .57765 L F
.179 .251 .701 r
.17281 .58116 m .17491 .5832 L .17415 .58121 L F
.377 .281 .619 r
.17313 .58384 m .17491 .5832 L .17281 .58116 L F
.073 .598 .872 r
.208 .61549 m .20468 .61474 L .2063 .61573 L F
.357 .208 .538 r
.35882 .58753 m .3609 .58716 L .36069 .58381 L F
.41 .506 .846 r
.35882 .58753 m .36171 .5887 L .3609 .58716 L F
.635 .576 .771 r
.35882 .58753 m .36277 .59069 L .36171 .5887 L F
.486 .041 .119 r
.52901 .53851 m .53314 .53714 L .529 .53728 L F
.52901 .53851 m .53153 .53913 L .53314 .53714 L F
.71 .302 .272 r
.53153 .53913 m .53557 .53958 L .53314 .53714 L F
.68 .317 .35 r
.53314 .53714 m .53557 .53958 L .53522 .53773 L F
.396 0 0 r
.24377 .55025 m .24196 .5502 L .23979 .54915 L F
0 .574 .757 r
.24475 .55041 m .24196 .5502 L .24377 .55025 L F
.061 0 0 r
.2442 .55035 m .24077 .55011 L .24196 .5502 L F
.047 .612 .774 r
.24196 .5502 m .23806 .55003 L .23979 .54915 L F
.061 0 0 r
.24077 .55011 m .24009 .55006 L .24196 .5502 L F
0 .574 .757 r
.24593 .55059 m .24196 .5502 L .24475 .55041 L F
.733 .707 .827 r
.52424 .5615 m .52606 .56356 L .52804 .56197 L F
0 .357 .82 r
.18771 .60277 m .18726 .6014 L .18467 .59989 L F
0 0 .396 r
.18771 .60277 m .18846 .604 L .18726 .6014 L F
.779 .57 .618 r
.39581 .55684 m .39809 .55933 L .39414 .5589 L F
.315 .464 .85 r
.39957 .55788 m .39581 .55684 L .3994 .5552 L F
.39957 .55788 m .39809 .55933 L .39581 .55684 L F
0 0 .232 r
.29339 .60237 m .29304 .6051 L .29144 .60595 L F
.025 0 0 r
.29186 .60689 m .29144 .60595 L .29304 .6051 L F
.29186 .60689 m .28988 .60774 L .29144 .60595 L F
.379 .542 .891 r
.21366 .5981 m .21244 .60004 L .21081 .59714 L F
.088 .15 .633 r
.21366 .5981 m .21421 .60223 L .21244 .60004 L F
0 .094 .638 r
.21244 .60004 m .21421 .60223 L .21342 .6021 L F
.383 .292 .628 r
.36897 .59562 m .36727 .59669 L .36671 .59357 L F
.36671 .59357 m .36727 .59669 L .36897 .59562 L F
.36897 .59562 m .36727 .59669 L .36671 .59357 L F
.554 .019 0 r
.25178 .55126 m .25064 .55182 L .24828 .55098 L F
0 .483 .859 r
.24828 .55098 m .25064 .55182 L .24989 .55131 L F
.35 0 0 r
.25178 .55126 m .24828 .55098 L .25006 .55058 L F
0 .483 .859 r
.24828 .55098 m .24989 .55131 L .24862 .55043 L F
.223 0 0 r
.24635 .55059 m .24828 .55098 L .24593 .55059 L F
.25006 .55058 m .24828 .55098 L .24635 .55059 L F
.494 .284 .524 r
.31861 .6303 m .31644 .63343 L .31658 .63083 L F
.441 .693 .972 r
.23567 .63179 m .23631 .63024 L .23462 .63013 L F
0 0 0 r
.35004 .66584 m .35045 .66632 L .34794 .66643 L F
.35004 .66584 m .35258 .66525 L .35045 .66632 L F
.408 .396 .734 r
.38728 .53029 m .38618 .53458 L .38498 .53081 L F
.38728 .53029 m .38801 .53399 L .38618 .53458 L F
.42 .437 .771 r
.38801 .53399 m .3892 .53636 L .38618 .53458 L F
.797 .503 .492 r
.31094 .57899 m .31188 .58061 L .31193 .57782 L F
.622 .506 .7 r
.31138 .65575 m .3134 .65669 L .31536 .6558 L F
.31138 .65575 m .31281 .65969 L .3134 .65669 L F
.161 .594 .935 r
.26307 .63857 m .26672 .64004 L .2651 .6387 L F
.376 .7 .984 r
.2651 .6387 m .26672 .64004 L .26729 .63862 L F
0 .084 .634 r
.26729 .63862 m .26672 .64004 L .26857 .64236 L F
.197 0 .28 r
.22154 .56573 m .22077 .568 L .22326 .56484 L F
.22326 .56484 m .22077 .568 L .22154 .56573 L F
.141 .047 .479 r
.28159 .62655 m .2804 .62457 L .28187 .62398 L F
.28159 .62655 m .27985 .62771 L .2804 .62457 L F
0 0 0 r
.25606 .72995 m .25897 .72769 L .25832 .72884 L F
.25832 .72884 m .25897 .72769 L .25985 .72663 L F
.395 .225 .53 r
.31115 .60834 m .31319 .60526 L .31135 .60584 L F
.418 .313 .628 r
.35322 .54953 m .35346 .55232 L .35159 .55271 L F
.307 .207 .574 r
.35346 .55232 m .35177 .55605 L .35159 .55271 L F
.42 .303 .614 r
.32448 .63696 m .32684 .63903 L .32671 .63632 L F
.32448 .63696 m .32443 .64068 L .32684 .63903 L F
.337 .094 .39 r
.29075 .5436 m .28817 .54681 L .28818 .54406 L F
.338 .126 .438 r
.37528 .54935 m .37803 .54868 L .37822 .54378 L F
.525 .815 .999 r
.37822 .54378 m .38122 .54343 L .37779 .54329 L F
.623 .625 .832 r
.37779 .54329 m .38122 .54343 L .37954 .53986 L F
.135 .329 .793 r
.37954 .53986 m .38122 .54343 L .38209 .54174 L F
.217 .167 .584 r
.37987 .54329 m .38209 .54174 L .38122 .54343 L F
.37987 .54329 m .3825 .5442 L .38209 .54176 L F
.37987 .54329 m .38209 .54176 L .38209 .54174 L F
.525 .815 .999 r
.37934 .54365 m .37987 .54329 L .38122 .54343 L F
.37822 .54378 m .37987 .54329 L .37934 .54365 L F
.339 .127 .438 r
.37822 .54378 m .37981 .54762 L .37987 .54329 L F
.37822 .54378 m .37803 .54868 L .37981 .54762 L F
0 .153 .678 r
.31587 .66219 m .31739 .6631 L .31607 .6614 L F
.31587 .66219 m .3155 .66067 L .31667 .66184 L F
.31587 .66219 m .31607 .6614 L .3155 .66067 L F
.826 .995 .759 r
.31667 .66184 m .31562 .66313 L .31587 .66219 L F
.31562 .66313 m .31413 .66498 L .31587 .66219 L F
.455 .422 .732 r
.31413 .66498 m .31591 .6655 L .31587 .66219 L F
.369 .224 .549 r
.39615 .56065 m .39414 .5589 L .39809 .55933 L F
.543 .886 .642 r
.39957 .55788 m .39615 .56065 L .39809 .55933 L F
.309 .721 .976 r
.28982 .5533 m .28805 .55225 L .28546 .55223 L F
.486 .718 .973 r
.28982 .5533 m .2901 .55109 L .28805 .55225 L F
.28982 .5533 m .29213 .55277 L .2901 .55109 L F
.462 .247 .501 r
.33447 .61197 m .33716 .60869 L .3345 .60918 L F
.287 .055 .376 r
.19086 .55929 m .19269 .5586 L .1932 .55622 L F
.106 0 0 r
.19086 .55929 m .18952 .56113 L .19269 .5586 L F
.335 .758 .975 r
.36056 .52106 m .36129 .52017 L .36317 .52103 L F
0 .062 .617 r
.36056 .52106 m .36257 .524 L .36129 .52017 L F
0 0 .543 r
.31927 .55141 m .31806 .54996 L .3208 .54977 L F
.563 .901 .979 r
.32039 .54984 m .31977 .55016 L .31927 .55141 L F
.31977 .55016 m .31836 .55087 L .31927 .55141 L F
0 0 .543 r
.31927 .55141 m .31907 .55358 L .3188 .55259 L F
.31927 .55141 m .3188 .55259 L .31806 .54996 L F
.903 .49 .166 r
.31924 .55173 m .32121 .55306 L .31907 .55355 L F
.31927 .55141 m .31977 .55183 L .31924 .55173 L F
.31977 .55183 m .32121 .55306 L .31924 .55173 L F
.31927 .55141 m .31934 .55306 L .32121 .55306 L F
.598 .102 .045 r
.31934 .55306 m .32079 .55288 L .32121 .55306 L F
.32079 .55288 m .32338 .55255 L .32127 .55304 L F
.32079 .55288 m .32127 .55304 L .32121 .55306 L F
.32338 .55255 m .3239 .55249 L .32121 .55306 L F
.537 .561 .827 r
.32489 .55561 m .3227 .55656 L .32121 .55306 L F
.32489 .55561 m .32121 .55306 L .3239 .55249 L F
.598 .102 .045 r
.32073 .55291 m .32156 .55364 L .32366 .55261 L F
.31934 .55306 m .32156 .55364 L .32073 .55291 L F
.088 .167 .652 r
.32156 .55364 m .32351 .55553 L .32346 .5553 L F
.598 .102 .045 r
.31934 .55306 m .32366 .55261 L .32338 .55255 L F
.32338 .55255 m .32366 .55261 L .3239 .55249 L F
.828 .999 .789 r
.3239 .55249 m .32156 .55364 L .32441 .55053 L F
.698 .903 .969 r
.32379 .55121 m .32259 .55146 L .32441 .55053 L F
.32156 .55364 m .32259 .55146 L .32379 .55121 L F
.088 .167 .652 r
.32156 .55364 m .32346 .5553 L .32259 .55146 L F
.828 .999 .789 r
.3239 .55249 m .32441 .55053 L .32578 .55029 L F
.645 .596 .785 r
.32744 .55471 m .3239 .55249 L .32578 .55029 L F
.903 .49 .166 r
.31907 .55355 m .32121 .55306 L .31907 .55358 L F
.373 .8 .97 r
.31927 .55141 m .31836 .55087 L .31611 .55128 L F
.647 .352 .457 r
.3186 .55138 m .31934 .55306 L .31927 .55141 L F
.31611 .55128 m .31758 .55209 L .3186 .55138 L F
.31758 .55209 m .31934 .55306 L .3186 .55138 L F
.31611 .55128 m .31635 .55327 L .31934 .55306 L F
.828 .994 .748 r
.31699 .5525 m .31623 .55194 L .31836 .55087 L F
.31635 .55327 m .31632 .55297 L .31699 .5525 L F
.31632 .55297 m .31623 .55194 L .31699 .5525 L F
.92 .544 .127 r
.31836 .55087 m .31934 .55306 L .31927 .55141 L F
.554 .017 0 r
.31836 .55087 m .32156 .55364 L .31934 .55306 L F
.3206 .55281 m .3203 .55275 L .32156 .55364 L F
.31836 .55087 m .32024 .55268 L .3206 .55281 L F
.32024 .55268 m .3203 .55275 L .3206 .55281 L F
.698 .903 .969 r
.32156 .55364 m .3203 .55275 L .32259 .55146 L F
.088 .167 .652 r
.32156 .55364 m .32259 .55146 L .3203 .55275 L F
.888 .956 .614 r
.3203 .55275 m .32028 .55131 L .32259 .55146 L F
.466 .239 .485 r
.32028 .55131 m .3203 .55275 L .32259 .55146 L F
.645 .596 .785 r
.32744 .55471 m .32489 .55561 L .3239 .55249 L F
.185 .237 .684 r
.32421 .55248 m .32393 .55368 L .3246 .55272 L F
.32393 .55368 m .32351 .55553 L .32454 .55287 L F
.32393 .55368 m .32454 .55287 L .3246 .55272 L F
.297 0 0 r
.32474 .55262 m .32339 .55325 L .32448 .55255 L F
.691 .978 .805 r
.32466 .55252 m .32339 .55325 L .32474 .55262 L F
.297 0 0 r
.32527 .55237 m .32474 .55262 L .32448 .55255 L F
.691 .978 .805 r
.32485 .55247 m .32474 .55262 L .32527 .55237 L F
.32466 .55252 m .32474 .55262 L .32485 .55247 L F
.185 .237 .684 r
.32273 .55208 m .32351 .55553 L .32421 .55248 L F
.239 0 .255 r
.32466 .55252 m .32351 .55531 L .32339 .55325 L F
.418 .756 .995 r
.32351 .55531 m .32413 .55373 L .32339 .55325 L F
.297 0 0 r
.32527 .55237 m .32448 .55255 L .32424 .55222 L F
.185 .237 .684 r
.32259 .55146 m .32424 .55222 L .32527 .55237 L F
.297 0 0 r
.32527 .55237 m .32424 .55222 L .32418 .55214 L F
.185 .237 .684 r
.32424 .55222 m .32472 .55244 L .32527 .55237 L F
.32424 .55222 m .3246 .55272 L .32472 .55244 L F
.32259 .55146 m .3246 .55272 L .32424 .55222 L F
.32259 .55146 m .32273 .55208 L .32421 .55248 L F
.297 0 0 r
.32448 .55255 m .32079 .55337 L .32418 .55214 L F
.32527 .55237 m .32185 .55164 L .32259 .55146 L F
.32185 .55164 m .32178 .55163 L .32179 .55163 L F
.32185 .55164 m .32179 .55163 L .32259 .55146 L F
0 0 0 r
.33013 .54925 m .32921 .5501 L .32698 .55192 L F
.32921 .5501 m .32841 .55083 L .32738 .55161 L F
.32921 .5501 m .32738 .55161 L .32698 .55192 L F
.33013 .54925 m .32841 .55083 L .32698 .55192 L F
.717 .763 .889 r
.32684 .54721 m .33015 .54931 L .32959 .54666 L F
0 0 0 r
.33066 .54964 m .33077 .55024 L .33078 .55 L F
.33066 .54964 m .33084 .55017 L .3308 .54952 L F
.111 0 0 r
.32841 .55083 m .33077 .55024 L .33066 .54964 L F
.147 0 0 r
.3308 .54955 m .33077 .55024 L .32841 .55083 L F
.33258 .54861 m .33077 .55024 L .3308 .54955 L F
0 0 0 r
.33078 .55 m .33077 .55024 L .33084 .55017 L F
.147 0 0 r
.33258 .54861 m .33113 .54938 L .33079 .54934 L F
.33258 .54861 m .33079 .54934 L .33078 .54908 L F
0 0 0 r
.3308 .54952 m .33084 .55017 L .3336 .54713 L F
.147 0 0 r
.33078 .54908 m .33079 .54934 L .33013 .54925 L F
.717 .763 .889 r
.33058 .54959 m .33066 .54964 L .33063 .54957 L F
.111 0 0 r
.32841 .55083 m .33066 .54964 L .33058 .54959 L F
.147 0 0 r
.33058 .54959 m .32841 .55083 L .32921 .5501 L F
.33113 .54938 m .32921 .5501 L .33013 .54925 L F
.111 0 0 r
.32841 .55083 m .33058 .54959 L .32684 .54721 L F
.147 0 0 r
.33113 .54938 m .32841 .55083 L .33058 .54959 L F
.717 .763 .889 r
.33015 .54931 m .33058 .54959 L .33045 .54906 L F
.33058 .54959 m .33063 .54957 L .33045 .54906 L F
.33015 .54931 m .33045 .54906 L .32959 .54666 L F
.645 .596 .785 r
.32744 .55471 m .32578 .55029 L .32698 .55192 L F
.567 .574 .82 r
.32841 .55083 m .32744 .55471 L .32698 .55192 L F
.32841 .55083 m .32992 .55453 L .32744 .55471 L F
.756 .673 .77 r
.33353 .55219 m .33038 .55135 L .33077 .55024 L F
.33038 .55135 m .32841 .55083 L .33077 .55024 L F
.6 .695 .91 r
.32959 .54666 m .32968 .54691 L .33405 .54622 L F
.32968 .54691 m .33066 .54964 L .3331 .54718 L F
.32968 .54691 m .3331 .54718 L .33405 .54622 L F
.756 .673 .77 r
.33353 .55219 m .32992 .55453 L .32841 .55083 L F
.696 .284 .261 r
.32602 .54881 m .32321 .54694 L .3266 .54628 L F
.778 .677 .752 r
.32441 .55053 m .32841 .55083 L .32684 .54721 L F
.46 0 0 r
.3265 .54992 m .33077 .55024 L .32841 .55083 L F
.3265 .54992 m .3286 .55101 L .33077 .55024 L F
.625 .26 .331 r
.3286 .55101 m .33121 .54899 L .33077 .55024 L F
.33121 .54899 m .3336 .54713 L .33077 .55024 L F
.631 .299 .39 r
.33631 .54635 m .336 .54875 L .33258 .54861 L F
0 0 0 r
.33066 .54964 m .3336 .54713 L .33405 .54622 L F
.625 .26 .331 r
.3286 .55101 m .33145 .55129 L .33355 .54722 L F
.33349 .54721 m .33355 .54722 L .3336 .54713 L F
.3286 .55101 m .33355 .54722 L .33349 .54721 L F
.694 .358 .403 r
.32482 .55246 m .33145 .55129 L .3286 .55101 L F
0 0 0 r
.32472 .55244 m .32796 .55095 L .32527 .55237 L F
.691 .978 .805 r
.32466 .55252 m .32527 .55237 L .32796 .55095 L F
.694 .358 .403 r
.32466 .55252 m .3249 .55248 L .32482 .55246 L F
.3249 .55248 m .33145 .55129 L .32482 .55246 L F
.418 .756 .995 r
.32413 .55373 m .325 .55153 L .32339 .55325 L F
.297 0 0 r
.32285 .55291 m .32339 .55325 L .32079 .55337 L F
.32448 .55255 m .32339 .55325 L .32285 .55291 L F
.32418 .55214 m .32079 .55337 L .32028 .55131 L F
.32178 .55163 m .32028 .55131 L .32259 .55146 L F
.041 .157 .66 r
.3923 .54219 m .39129 .54407 L .39038 .54028 L F
.284 .476 .871 r
.3923 .54219 m .39447 .54543 L .39129 .54407 L F
.821 .683 .711 r
.29815 .62789 m .29962 .62831 L .30172 .6268 L F
.808 .594 .612 r
.24613 .74492 m .25035 .74575 L .25023 .74285 L F
.599 .475 .682 r
.29574 .6434 m .29909 .64293 L .29857 .64007 L F
.8 .648 .694 r
.29512 .64572 m .29909 .64293 L .29574 .6434 L F
.811 .637 .667 r
.34189 .64331 m .34094 .64596 L .33814 .6451 L F
.34189 .64331 m .33814 .6451 L .33998 .64449 L F
.223 .167 .58 r
.31083 .61504 m .31238 .61724 L .31201 .61457 L F
.623 .625 .832 r
.37779 .54329 m .37954 .53986 L .37792 .54038 L F
.613 .686 .895 r
.36171 .5887 m .36277 .59069 L .36523 .58995 L F
.1 0 .246 r
.363 .59337 m .36523 .58995 L .36277 .59069 L F
.078 0 0 r
.21111 .54532 m .21549 .54338 L .2133 .54408 L F
0 0 0 r
.36753 .54078 m .36379 .54249 L .36491 .54123 L F
0 0 .072 r
.3013 .58929 m .30116 .5874 L .30195 .58575 L F
.609 .373 .535 r
.30345 .58751 m .30169 .58904 L .3013 .58929 L F
0 0 .072 r
.3013 .58929 m .30073 .58999 L .30079 .58964 L F
.748 .76 .251 r
.30048 .59008 m .30073 .58999 L .3013 .58929 L F
.609 .373 .535 r
.30169 .58904 m .30048 .59008 L .3013 .58929 L F
0 0 .072 r
.3013 .58929 m .30079 .58964 L .30116 .5874 L F
.128 .675 .72 r
.37411 .62822 m .37648 .62784 L .37736 .62774 L F
.182 0 0 r
.37736 .62774 m .37566 .6294 L .37328 .62993 L F
.599 .949 .818 r
.37736 .62774 m .37648 .62784 L .37836 .62643 L F
.584 .864 .537 r
.37836 .62643 m .37566 .6294 L .37736 .62774 L F
.349 .183 .51 r
.17487 .57464 m .17647 .57662 L .17664 .57397 L F
.17487 .57464 m .17416 .57765 L .17647 .57662 L F
.515 .275 .489 r
.28411 .60314 m .28683 .60265 L .28724 .59984 L F
.402 .236 .538 r
.28724 .59984 m .28918 .5992 L .28925 .59642 L F
.357 .14 .441 r
.28724 .59984 m .28884 .60181 L .28918 .5992 L F
.28724 .59984 m .28683 .60265 L .28884 .60181 L F
.959 .732 .552 r
.24472 .54322 m .24624 .54695 L .24458 .545 L F
.719 .761 .886 r
.24458 .545 m .24624 .54695 L .24208 .54611 L F
.959 .732 .552 r
.24458 .545 m .24624 .54695 L .24472 .54322 L F
.58 .713 .934 r
.24849 .5462 m .24624 .54695 L .24458 .545 L F
.421 .222 .503 r
.25744 .55585 m .25992 .55263 L .25749 .5533 L F
.871 .462 .247 r
.35347 .63734 m .35133 .63827 L .35034 .63573 L F
.613 .156 0 r
.35347 .63734 m .35385 .63809 L .35133 .63827 L F
.247 0 .104 r
.19869 .55237 m .19949 .55416 L .20036 .55235 L F
.19869 .55237 m .19732 .55487 L .19949 .55416 L F
.908 .6 .45 r
.3085 .57148 m .30853 .57346 L .31035 .57236 L F
.569 .281 .439 r
.32464 .56888 m .32753 .56844 L .32776 .56541 L F
.066 0 .082 r
.32776 .56541 m .3297 .56542 L .33069 .5625 L F
0 0 .177 r
.32776 .56541 m .32861 .56643 L .3297 .56542 L F
.32776 .56541 m .32753 .56844 L .32861 .56643 L F
.777 .597 .656 r
.30052 .63952 m .30484 .63706 L .30083 .63662 L F
.30052 .63952 m .30475 .6398 L .30484 .63706 L F
.633 .472 .646 r
.30484 .63706 m .3077 .63679 L .30742 .63391 L F
.551 .356 .57 r
.30475 .6398 m .3077 .63679 L .30484 .63706 L F
.487 0 0 r
.33221 .53085 m .33408 .53167 L .33185 .53059 L F
.402 .394 .736 r
.30681 .63167 m .30742 .63391 L .30918 .63365 L F
.507 .378 .64 r
.30742 .63391 m .31023 .63619 L .30918 .63365 L F
.30742 .63391 m .3077 .63679 L .31023 .63619 L F
.243 .103 .482 r
.28171 .62938 m .27985 .62771 L .28159 .62655 L F
.28171 .62938 m .27984 .63106 L .27985 .62771 L F
.546 .041 .007 r
.30615 .55313 m .30493 .55411 L .30221 .55298 L F
.977 .735 .503 r
.30868 .55275 m .30493 .55411 L .30615 .55313 L F
.416 .685 .974 r
.31885 .53004 m .31576 .52827 L .31821 .52788 L F
.688 .832 .952 r
.32236 .52801 m .31885 .53004 L .31821 .52788 L F
.869 .975 .851 r
.30656 .56196 m .30562 .56091 L .30905 .55777 L F
.629 .629 .832 r
.51536 .56239 m .5165 .55812 L .51419 .55851 L F
.51536 .56239 m .51766 .56146 L .5165 .55812 L F
.557 .761 .973 r
.30707 .529 m .30326 .52813 L .30562 .52786 L F
.507 .772 .991 r
.3079 .52731 m .30707 .529 L .30562 .52786 L F
.3079 .52731 m .30943 .52858 L .30707 .529 L F
.984 .905 .599 r
.36972 .60874 m .36859 .609 L .36866 .60858 L F
.151 0 0 r
.37016 .6088 m .36972 .60874 L .36681 .60818 L F
.984 .905 .599 r
.36972 .60874 m .36881 .60768 L .36893 .6069 L F
.204 .64 .949 r
.36972 .60874 m .36896 .60785 L .36895 .60785 L F
.36972 .60874 m .36895 .60785 L .36681 .60818 L F
.984 .905 .599 r
.36972 .60874 m .36866 .60858 L .36881 .60768 L F
.151 0 0 r
.3712 .60899 m .36972 .60874 L .37016 .6088 L F
.767 .544 .596 r
.34448 .6584 m .34837 .66154 L .34846 .65882 L F
.34448 .6584 m .34448 .66149 L .34837 .66154 L F
.34448 .6584 m .34846 .65882 L .34712 .66078 L F
.994 .748 .432 r
.34837 .66154 m .34712 .66078 L .34846 .65882 L F
.058 0 .285 r
.33447 .61197 m .33244 .6153 L .33444 .61472 L F
.406 .262 .57 r
.33244 .6153 m .33447 .61719 L .33444 .61472 L F
.33244 .6153 m .33252 .61804 L .33447 .61719 L F
.272 0 .227 r
.25952 .54824 m .25865 .54566 L .26126 .5455 L F
.25952 .54824 m .25769 .54905 L .25865 .54566 L F
.594 .275 .398 r
.3134 .65669 m .31756 .65789 L .31536 .6558 L F
.29 .194 .569 r
.34498 .54342 m .34538 .54597 L .34381 .54675 L F
.62 .345 .48 r
.26259 .5523 m .26653 .5496 L .26264 .55025 L F
.661 .175 .086 r
.31979 .65729 m .3238 .65783 L .32176 .65593 L F
.547 .369 .592 r
.32176 .65593 m .32447 .65544 L .32457 .65246 L F
.5 .234 .442 r
.32176 .65593 m .3238 .65783 L .32447 .65544 L F
.239 .754 .764 r
.25605 .62488 m .25832 .6243 L .25963 .6241 L F
.201 0 0 r
.25832 .6243 m .26164 .62338 L .25963 .6241 L F
0 0 .279 r
.33563 .64181 m .33596 .64254 L .33571 .64246 L F
0 .005 .532 r
.33596 .64254 m .33814 .6451 L .33571 .64246 L F
.319 .199 .556 r
.33216 .57127 m .33407 .57077 L .33204 .56856 L F
.633 .095 0 r
.33204 .56856 m .33251 .56972 L .33022 .56884 L F
.33204 .56856 m .33407 .57077 L .33251 .56972 L F
.196 .701 .906 r
.35282 .51839 m .35607 .51844 L .35675 .51882 L F
.655 .183 .119 r
.35675 .51882 m .35501 .52027 L .35282 .51839 L F
.974 .714 .474 r
.3581 .52504 m .35825 .52773 L .35641 .5266 L F
.686 .972 .919 r
.35675 .51882 m .35607 .51844 L .35711 .51729 L F
.783 .958 .638 r
.35711 .51729 m .35501 .52027 L .35675 .51882 L F
.431 .289 .587 r
.36035 .527 m .35825 .52773 L .3581 .52504 L F
.67 .21 .151 r
.35641 .5266 m .36035 .527 L .3581 .52504 L F
.79 .687 .751 r
.35117 .58408 m .34862 .58721 L .34732 .58394 L F
.608 .421 .602 r
.35122 .58682 m .34862 .58721 L .35117 .58408 L F
.542 .356 .579 r
.35414 .5834 m .35122 .58682 L .35117 .58408 L F
.597 .503 .719 r
.36086 .53736 m .36355 .54183 L .36319 .53757 L F
.152 0 0 r
.36086 .53736 m .36319 .53757 L .36377 .53754 L F
.387 0 .154 r
.23671 .75103 m .23515 .74971 L .23423 .75153 L F
.524 .557 .831 r
.32295 .57022 m .32464 .56888 L .32159 .56818 L F
.156 .155 .605 r
.2151 .60441 m .21362 .6062 L .21342 .6021 L F
.27 .321 .731 r
.2151 .60441 m .21599 .60827 L .21362 .6062 L F
.279 .322 .728 r
.21362 .6062 m .21599 .60827 L .21448 .60828 L F
.464 .572 .879 r
.34532 .63796 m .34435 .64018 L .34263 .63718 L F
.34532 .63796 m .34646 .64003 L .34435 .64018 L F
.107 0 0 r
.34646 .64003 m .34313 .64147 L .34435 .64018 L F
.592 .437 .641 r
.38924 .56757 m .3861 .56637 L .38966 .56595 L F
.38924 .56757 m .38666 .56832 L .3861 .56637 L F
.48 .515 .817 r
.30533 .62826 m .30681 .63167 L .30843 .62961 L F
.402 .394 .736 r
.30681 .63167 m .30918 .63365 L .30843 .62961 L F
.086 .618 .865 r
.18187 .59938 m .18314 .59988 L .18467 .59989 L F
.194 0 .338 r
.1932 .55622 m .19432 .55767 L .19526 .55558 L F
.1932 .55622 m .19269 .5586 L .19432 .55767 L F
.389 .627 .948 r
.19448 .60711 m .19515 .6056 L .1935 .60527 L F
.19448 .60711 m .19792 .60799 L .19515 .6056 L F
.725 .458 .522 r
.32688 .66507 m .32662 .66758 L .32289 .66758 L F
.741 .546 .631 r
.32871 .66417 m .32662 .66758 L .32688 .66507 L F
.504 .334 .583 r
.25715 .73344 m .2552 .73656 L .2575 .73611 L F
0 0 0 r
.34716 .62241 m .34567 .62363 L .34429 .6245 L F
.018 .103 .611 r
.34429 .6245 m .34614 .62755 L .34514 .62727 L F
.678 .236 0 r
.34476 .62569 m .34614 .62755 L .34429 .6245 L F
.34476 .62569 m .34429 .6245 L .34567 .62363 L F
.69 .37 .429 r
.32047 .66502 m .32289 .66758 L .32026 .66749 L F
.898 .848 .786 r
.29084 .59004 m .2873 .59259 L .2904 .59022 L F
.483 .486 .784 r
.37831 .56268 m .37517 .56112 L .37919 .5621 L F
.616 .404 .572 r
.37619 .56547 m .37913 .56518 L .37919 .5621 L F
.461 .28 .548 r
.37919 .5621 m .38144 .56439 L .38134 .56162 L F
.37919 .5621 m .37913 .56518 L .38144 .56439 L F
.389 0 0 r
.38134 .56162 m .37831 .56268 L .37919 .5621 L F
.562 .602 .851 r
.35314 .65804 m .35468 .66139 L .35231 .66189 L F
.38 .062 .296 r
.25901 .72372 m .25565 .72731 L .25813 .72692 L F
.721 .424 .475 r
.25813 .72692 m .25985 .72663 L .25901 .72372 L F
.541 .388 .622 r
.38388 .58421 m .38391 .58678 L .38155 .58751 L F
.376 .284 .623 r
.38366 .58935 m .38155 .58751 L .38391 .58678 L F
.38366 .58935 m .38171 .59022 L .38155 .58751 L F
.698 .778 .914 r
.32346 .62121 m .32141 .62278 L .3215 .62059 L F
0 0 .338 r
.32226 .6228 m .32141 .62278 L .32346 .62121 L F
.32226 .6228 m .3215 .62555 L .32141 .62278 L F
.698 .778 .914 r
.32346 .62121 m .32141 .62278 L .3215 .62059 L F
.456 .214 .457 r
.37993 .59632 m .37701 .59909 L .37691 .59655 L F
.684 .634 .793 r
.36376 .5255 m .36854 .52747 L .36674 .52671 L F
.348 .77 .976 r
.36674 .52671 m .36854 .52747 L .36903 .52646 L F
0 .11 .663 r
.36854 .52747 m .37081 .53013 L .36903 .52646 L F
.561 .754 .968 r
.25145 .55839 m .25529 .55936 L .2536 .55773 L F
.918 .802 .717 r
.2536 .55773 m .25529 .55936 L .25513 .55692 L F
0 .064 .627 r
.36054 .63299 m .35873 .63086 L .36107 .63048 L F
.782 .39 .312 r
.53522 .53773 m .53557 .53958 L .53823 .53962 L F
.606 .831 .986 r
.21979 .55708 m .21956 .55885 L .22181 .55799 L F
.874 .962 .628 r
.21979 .55708 m .21791 .56018 L .21956 .55885 L F
.62 .493 .687 r
.39414 .5589 m .39192 .5618 L .3917 .55863 L F
.673 .815 .951 r
.20898 .5957 m .20865 .59865 L .20688 .59595 L F
.20898 .5957 m .21081 .59714 L .20865 .59865 L F
0 0 0 r
.36896 .60785 m .36587 .6089 L .36681 .60818 L F
.307 .207 .574 r
.35346 .55232 m .3539 .55515 L .35177 .55605 L F
.446 .213 .465 r
.3539 .55515 m .35089 .55891 L .35177 .55605 L F
0 0 .061 r
.35057 .64544 m .35024 .64805 L .34952 .64945 L F
.1 .361 .827 r
.35024 .64805 m .35233 .6515 L .34952 .64945 L F
.794 .574 .603 r
.34424 .64839 m .34321 .65201 L .34168 .64888 L F
.035 0 .368 r
.30289 .56853 m .30397 .56958 L .30434 .56759 L F
.30289 .56853 m .30265 .57119 L .30397 .56958 L F
.413 .23 .521 r
.33409 .65524 m .33172 .65858 L .33151 .65583 L F
.663 .882 .979 r
.37426 .53464 m .37347 .53696 L .37622 .5361 L F
.37426 .53464 m .37172 .53591 L .37347 .53696 L F
.285 0 .157 r
.29325 .58674 m .29239 .58911 L .29465 .58838 L F
0 0 0 r
.30022 .54129 m .29819 .54232 L .29563 .54294 L F
.7 .966 .731 r
.29985 .54048 m .30022 .54129 L .30166 .54075 L F
.29985 .54048 m .29819 .54232 L .30022 .54129 L F
.544 .383 .613 r
.3365 .64935 m .33651 .65219 L .33406 .65254 L F
.612 .411 .585 r
.33671 .65496 m .33406 .65254 L .33651 .65219 L F
.33671 .65496 m .33409 .65524 L .33406 .65254 L F
.361 .814 .939 r
.2778 .52895 m .2733 .52901 L .27595 .52806 L F
.387 .803 .976 r
.27834 .52778 m .2778 .52895 L .27595 .52806 L F
.27834 .52778 m .28014 .52858 L .2778 .52895 L F
.503 .772 .992 r
.31695 .58922 m .31228 .58821 L .31514 .58839 L F
.736 .917 .954 r
.32005 .58752 m .31695 .58922 L .31514 .58839 L F
.051 0 .409 r
.29004 .63889 m .28905 .63711 L .28986 .6363 L F
.29004 .63889 m .28894 .63988 L .28905 .63711 L F
.291 .69 .974 r
.27529 .64162 m .27699 .64269 L .27746 .64166 L F
.785 .661 .726 r
.35983 .5654 m .36323 .56605 L .36199 .56408 L F
.35983 .5654 m .36169 .56884 L .36323 .56605 L F
.568 .623 .866 r
.36323 .56605 m .36489 .56416 L .36199 .56408 L F
.36323 .56605 m .36647 .56622 L .36489 .56416 L F
.156 0 .283 r
.31679 .54081 m .31664 .53997 L .31504 .53913 L F
.31679 .54081 m .3179 .54193 L .31664 .53997 L F
.31679 .54081 m .31583 .54307 L .3179 .54193 L F
.667 .599 .769 r
.50755 .54319 m .5099 .54009 L .50752 .54105 L F
.50755 .54319 m .51107 .54264 L .5099 .54009 L F
.626 .405 .562 r
.51063 .54572 m .50755 .54319 L .5081 .54618 L F
.51063 .54572 m .51107 .54264 L .50755 .54319 L F
.389 .148 .423 r
.36341 .58044 m .36069 .58381 L .36301 .58339 L F
.285 .06 .387 r
.36341 .58044 m .36564 .58402 L .3655 .5787 L F
.36341 .58044 m .36301 .58339 L .36564 .58402 L F
0 0 .495 r
.39447 .54543 m .39517 .54961 L .39453 .54695 L F
.914 .864 .777 r
.29997 .67619 m .30046 .67804 L .29814 .67697 L F
.92 .866 .769 r
.29895 .67794 m .30046 .67804 L .29997 .67619 L F
.588 .851 .994 r
.28419 .52876 m .28014 .52858 L .28247 .52813 L F
.357 .789 .968 r
.28495 .52771 m .28419 .52876 L .28247 .52813 L F
.28495 .52771 m .28662 .52851 L .28419 .52876 L F
0 0 0 r
.37024 .55556 m .37215 .55462 L .37314 .55224 L F
.173 0 .301 r
.37314 .55224 m .37502 .55186 L .37528 .54935 L F
.521 .254 .45 r
.37215 .55462 m .37502 .55186 L .37314 .55224 L F
.358 .643 .963 r
.2027 .61474 m .20312 .61312 L .20101 .61141 L F
.2027 .61474 m .20468 .61474 L .20312 .61312 L F
.337 .094 .39 r
.29075 .5436 m .2902 .54631 L .28817 .54681 L F
.403 .151 .414 r
.29265 .54545 m .29075 .5436 L .2932 .54325 L F
.29265 .54545 m .2902 .54631 L .29075 .5436 L F
.046 0 .442 r
.32457 .65246 m .32559 .65217 L .326 .64882 L F
.104 .18 .659 r
.32457 .65246 m .32647 .65461 L .32559 .65217 L F
.39 .241 .556 r
.32447 .65544 m .32647 .65461 L .32457 .65246 L F
.416 .314 .631 r
.2902 .54631 m .29046 .5488 L .28817 .54681 L F
.508 .472 .751 r
.50667 .55243 m .50803 .54854 L .50576 .55022 L F
.50667 .55243 m .50895 .55185 L .50803 .54854 L F
.579 .514 .746 r
.50745 .55651 m .50895 .55185 L .50667 .55243 L F
0 0 0 r
.3205 .6112 m .31796 .61417 L .31907 .61242 L F
.509 .512 .795 r
.37487 .52252 m .37325 .5257 L .37169 .52126 L F
.37325 .5257 m .37322 .52578 L .37317 .52565 L F
.37325 .5257 m .37317 .52565 L .37169 .52126 L F
0 .248 .686 r
.37175 .52488 m .3738 .52604 L .37486 .52693 L F
.3738 .52604 m .37494 .5267 L .37492 .52675 L F
.3738 .52604 m .37492 .52675 L .37486 .52693 L F
.197 .727 .783 r
.37486 .52693 m .37494 .5267 L .37606 .52654 L F
.63 .778 .952 r
.31576 .52827 m .31366 .52923 L .31187 .5275 L F
.767 .622 .699 r
.34228 .63501 m .33921 .6358 L .33952 .63456 L F
.435 .329 .635 r
.31281 .65969 m .3155 .66067 L .3134 .65669 L F
0 0 .04 r
.33069 .5625 m .33118 .56387 L .33216 .56079 L F
.33069 .5625 m .3297 .56542 L .33118 .56387 L F
.156 .155 .605 r
.2151 .60441 m .21342 .6021 L .21421 .60223 L F
.04 0 .307 r
.31238 .64313 m .31374 .64074 L .31462 .64197 L F
0 0 0 r
.31094 .64518 m .31238 .64313 L .31462 .64197 L F
.166 0 .134 r
.18662 .56381 m .18952 .56113 L .18788 .56232 L F
.711 .983 .893 r
.36377 .53754 m .36319 .53757 L .36555 .5357 L F
.106 .64 .862 r
.25191 .63523 m .25284 .63487 L .25071 .6357 L F
.25191 .63523 m .25567 .63554 L .25284 .63487 L F
.669 .555 .716 r
.33778 .53964 m .33541 .54255 L .33566 .54079 L F
.503 .27 .493 r
.33918 .5433 m .33631 .54635 L .33541 .54255 L F
.664 .775 .932 r
.52424 .5615 m .52804 .56197 L .52715 .56026 L F
.663 .775 .932 r
.52715 .56026 m .52804 .56197 L .53041 .56089 L F
.985 .708 .35 r
.34862 .58721 m .34778 .58741 L .3482 .58692 L F
.973 .67 .296 r
.34732 .58394 m .34841 .58667 L .34742 .58639 L F
.34841 .58667 m .34862 .58721 L .3482 .58692 L F
.34841 .58667 m .3482 .58692 L .34742 .58639 L F
.985 .708 .35 r
.34862 .58721 m .3485 .58941 L .34742 .58639 L F
.873 .737 .709 r
.34742 .58639 m .3485 .58941 L .3465 .5886 L F
0 0 0 r
.34769 .58753 m .34819 .58744 L .35181 .58383 L F
.34763 .58759 m .34765 .58758 L .34769 .58753 L F
.985 .708 .35 r
.34862 .58721 m .3485 .58941 L .34778 .58741 L F
0 0 0 r
.34765 .58758 m .34819 .58744 L .34769 .58753 L F
.3465 .5886 m .34713 .58817 L .34763 .58759 L F
.34713 .58817 m .34819 .58744 L .34763 .58759 L F
.985 .708 .35 r
.3482 .58692 m .34778 .58741 L .34742 .58639 L F
.642 .395 .529 r
.35122 .58682 m .3485 .58941 L .34862 .58721 L F
0 0 0 r
.24597 .532 m .24628 .53188 L .24819 .5314 L F
.24597 .532 m .24418 .53285 L .24628 .53188 L F
.457 .353 .648 r
.32489 .55561 m .32512 .55822 L .3227 .55656 L F
.752 .64 .736 r
.24016 .56163 m .236 .56182 L .23853 .56052 L F
.048 .616 .721 r
.24016 .56163 m .23812 .56171 L .236 .56182 L F
.68 .96 .944 r
.24063 .56038 m .24016 .56163 L .24257 .5623 L F
.24063 .56038 m .23812 .56171 L .24016 .56163 L F
0 0 0 r
.23317 .55217 m .22978 .55527 L .23148 .5533 L F
.64 .889 .551 r
.35856 .64622 m .35722 .64742 L .35652 .64499 L F
.378 .724 .989 r
.35652 .64499 m .35937 .64502 L .35856 .64622 L F
.88 .475 .249 r
.35523 .64635 m .35722 .64742 L .35652 .64499 L F
.216 .633 .953 r
.35523 .64635 m .35722 .64742 L .35937 .64502 L F
.902 .686 .601 r
.35738 .64696 m .35722 .64742 L .35731 .64652 L F
.64 .889 .551 r
.35856 .64622 m .35697 .64812 L .35722 .64742 L F
.603 .432 .622 r
.35856 .64622 m .35874 .64911 L .35594 .64937 L F
.587 .363 .543 r
.35874 .64911 m .35874 .65178 L .35594 .64937 L F
.435 .304 .603 r
.36083 .64845 m .35874 .64911 L .35856 .64622 L F
.4 .217 .514 r
.36083 .64845 m .35874 .65178 L .35874 .64911 L F
.992 .776 .511 r
.35722 .64742 m .35874 .65178 L .36083 .64845 L F
.011 .219 .728 r
.35937 .64502 m .36083 .64845 L .35856 .64622 L F
.832 .703 .722 r
.35722 .64742 m .36083 .64845 L .35937 .64502 L F
.902 .686 .601 r
.35791 .65022 m .35722 .64742 L .35738 .64696 L F
.64 .889 .551 r
.35697 .64812 m .35594 .64937 L .35722 .64742 L F
.642 .892 .558 r
.35594 .64937 m .3542 .65108 L .35722 .64742 L F
.718 .283 .217 r
.35594 .64937 m .35874 .65178 L .3542 .65108 L F
.443 .217 .475 r
.31092 .62136 m .30834 .62442 L .31079 .62374 L F
.43 .207 .472 r
.31311 .62093 m .31092 .62136 L .31079 .62374 L F
.024 0 0 r
.31079 .62374 m .30834 .62442 L .30629 .62604 L F
.262 .765 .874 r
.28662 .52851 m .28906 .52811 L .29057 .52826 L F
.242 .753 .866 r
.29057 .52826 m .29095 .52767 L .29292 .52777 L F
.29057 .52826 m .28906 .52811 L .29095 .52767 L F
.454 .876 .763 r
.3545 .66401 m .35864 .66216 L .35707 .6608 L F
.843 .882 .869 r
.36146 .659 m .35864 .66216 L .35707 .6608 L F
.558 .403 .627 r
.36146 .659 m .36127 .66194 L .35864 .66216 L F
.411 0 0 r
.36127 .66194 m .35889 .66129 L .35864 .66216 L F
.527 .377 .621 r
.36366 .66128 m .36127 .66194 L .36146 .659 L F
.411 0 0 r
.35889 .66129 m .35707 .6608 L .35762 .66127 L F
.36127 .66194 m .35899 .66175 L .35707 .6608 L F
.221 0 0 r
.36366 .66128 m .35899 .66175 L .36127 .66194 L F
.36285 .66136 m .36163 .66184 L .35899 .66175 L F
.36366 .66128 m .36333 .66137 L .36285 .66136 L F
.36333 .66137 m .36163 .66184 L .36285 .66136 L F
.411 0 0 r
.35889 .66129 m .35762 .66127 L .35864 .66216 L F
.407 .212 .501 r
.22978 .55527 m .22786 .55794 L .22892 .55622 L F
.994 .754 .452 r
.36223 .61109 m .36181 .61343 L .36088 .61165 L F
.742 .843 .926 r
.36314 .65892 m .35968 .65782 L .36209 .65448 L F
.36314 .65892 m .36146 .659 L .35968 .65782 L F
.659 .659 .839 r
.36548 .65598 m .36314 .65892 L .36209 .65448 L F
.397 .486 .834 r
.29181 .64255 m .28982 .64231 L .28894 .63988 L F
.477 .438 .736 r
.36136 .57125 m .36237 .57526 L .36449 .57432 L F
.456 .386 .689 r
.36237 .57526 m .36497 .57692 L .36449 .57432 L F
.081 0 0 r
.2536 .55773 m .25744 .55585 L .25423 .55687 L F
.81 .716 .761 r
.35808 .63325 m .35704 .63675 L .35958 .63683 L F
.797 .76 .819 r
.35704 .63675 m .35721 .6376 L .35958 .63683 L F
.35704 .63675 m .35721 .6376 L .35958 .63683 L F
.429 0 0 r
.35704 .63675 m .35763 .63732 L .35958 .63683 L F
.791 .709 .773 r
.35958 .63683 m .357 .63993 L .35721 .6376 L F
.421 .374 .7 r
.36222 .63861 m .36023 .64079 L .35991 .63882 L F
.36222 .63861 m .35991 .63882 L .35958 .63683 L F
.543 0 0 r
.35763 .63732 m .36222 .63861 L .35958 .63683 L F
.35763 .63732 m .36008 .63857 L .36222 .63861 L F
.118 .668 .786 r
.36222 .63861 m .36008 .63857 L .36423 .63842 L F
.36222 .63861 m .36423 .63842 L .36424 .63842 L F
0 0 0 r
.28411 .60314 m .28422 .60345 L .28567 .60394 L F
.28411 .60314 m .28227 .60437 L .28422 .60345 L F
.34 0 .061 r
.28567 .60394 m .28683 .60265 L .28411 .60314 L F
.413 .605 .927 r
.20563 .5942 m .20506 .59622 L .20289 .59308 L F
.20563 .5942 m .20688 .59595 L .20506 .59622 L F
.669 .674 .846 r
.30781 .57768 m .30853 .57346 L .30594 .57639 L F
.30781 .57768 m .3099 .57782 L .30853 .57346 L F
.579 .514 .746 r
.50745 .55651 m .50993 .55579 L .50895 .55185 L F
.848 .445 .276 r
.357 .63993 m .35532 .64134 L .35534 .63995 L F
0 0 0 r
.35929 .64092 m .35532 .64134 L .357 .63993 L F
.452 0 0 r
.36023 .64079 m .35929 .64092 L .357 .63993 L F
.433 .259 .544 r
.28918 .5992 m .29155 .59575 L .28925 .59642 L F
.487 0 0 r
.33221 .53085 m .33185 .53059 L .33073 .53048 L F
0 0 .398 r
.36069 .58381 m .36214 .58458 L .36301 .58339 L F
.36069 .58381 m .3609 .58716 L .36214 .58458 L F
.401 0 .127 r
.21746 .5423 m .21996 .54206 L .22144 .53965 L F
.016 0 0 r
.22298 .53955 m .22446 .53767 L .22144 .53965 L F
0 0 0 r
.22144 .53965 m .22175 .54047 L .22298 .53955 L F
.22144 .53965 m .21996 .54206 L .22175 .54047 L F
.608 .235 .31 r
.21103 .56868 m .21011 .57095 L .20786 .57041 L F
.059 .157 .653 r
.21207 .56713 m .21103 .56868 L .21034 .56524 L F
.162 0 .116 r
.21256 .56961 m .21103 .56868 L .21207 .56713 L F
.21256 .56961 m .21011 .57095 L .21103 .56868 L F
.233 .646 .959 r
.26307 .63857 m .26328 .63748 L .26086 .63769 L F
.26307 .63857 m .2651 .6387 L .26328 .63748 L F
.323 .044 .326 r
.29618 .59934 m .29556 .60216 L .29339 .60237 L F
.264 0 .308 r
.29802 .59871 m .29556 .60216 L .29618 .59934 L F
.557 .431 .665 r
.20036 .58026 m .19767 .57747 L .19955 .57682 L F
.20036 .58026 m .19803 .58097 L .19767 .57747 L F
.593 .424 .622 r
.34484 .58399 m .34732 .58394 L .34705 .58081 L F
.579 .414 .622 r
.34705 .58081 m .34732 .58394 L .35132 .58288 L F
.549 .292 .479 r
.26418 .556 m .26635 .55811 L .26383 .55839 L F
.613 .284 .389 r
.26695 .55613 m .26635 .55811 L .26418 .556 L F
.717 .542 .651 r
.32871 .66417 m .33302 .66475 L .33062 .66696 L F
.308 .769 .947 r
.2676 .54564 m .26584 .54513 L .26355 .54538 L F
.249 0 .049 r
.26577 .54522 m .26355 .54538 L .26584 .54513 L F
.278 .741 .949 r
.26528 .54601 m .26355 .54538 L .2615 .54553 L F
.308 .769 .947 r
.2676 .54564 m .26355 .54538 L .26528 .54601 L F
.249 0 .049 r
.26426 .54708 m .26355 .54538 L .26577 .54522 L F
.278 .741 .949 r
.2615 .54553 m .26355 .54538 L .26126 .5455 L F
.61 .414 .592 r
.36222 .63861 m .35929 .64092 L .36023 .64079 L F
.479 .308 .57 r
.39414 .5589 m .39424 .56162 L .39192 .5618 L F
.459 .224 .47 r
.39424 .56162 m .39155 .5646 L .39192 .5618 L F
.237 0 0 r
.31394 .54029 m .31269 .53955 L .31504 .53913 L F
.31394 .54029 m .31143 .54114 L .31269 .53955 L F
.463 .158 .363 r
.29963 .54605 m .3026 .54542 L .303 .54245 L F
.257 0 .308 r
.303 .54245 m .30451 .54446 L .30422 .54175 L F
.303 .54245 m .3026 .54542 L .30451 .54446 L F
.653 .521 .69 r
.36169 .56884 m .36136 .57125 L .36388 .57061 L F
.577 .389 .59 r
.3134 .65669 m .3155 .66067 L .31756 .65789 L F
.71 .319 .305 r
.30422 .64156 m .30475 .6398 L .30052 .63952 L F
.551 .356 .57 r
.30475 .6398 m .30766 .63946 L .3077 .63679 L F
.692 .442 .54 r
.30422 .64156 m .30766 .63946 L .30475 .6398 L F
.713 .7 .836 r
.30853 .57346 m .3099 .57782 L .31261 .57454 L F
.397 .326 .66 r
.17313 .58384 m .17544 .58603 L .17491 .5832 L F
.17313 .58384 m .17325 .58741 L .17544 .58603 L F
.707 .776 .906 r
.29549 .5264 m .29692 .52833 L .29292 .52777 L F
.49 .679 .949 r
.29769 .52605 m .29692 .52833 L .29549 .5264 L F
.491 .681 .95 r
.29769 .52605 m .29919 .52817 L .29692 .52833 L F
.741 .546 .631 r
.32871 .66417 m .33062 .66696 L .32662 .66758 L F
.273 .216 .609 r
.3429 .61444 m .34137 .61473 L .34085 .61208 L F
.869 .603 .075 r
.53557 .53958 m .53642 .54305 L .53823 .53962 L F
.95 .673 .478 r
.34508 .62061 m .34567 .62363 L .34716 .62241 L F
.697 .778 .914 r
.34508 .62061 m .34716 .62241 L .34901 .62099 L F
.368 .804 .961 r
.25462 .53141 m .25688 .53097 L .25883 .53156 L F
.469 .856 .979 r
.25883 .53156 m .25922 .53036 L .26106 .53076 L F
.25883 .53156 m .25688 .53097 L .25922 .53036 L F
.477 .438 .736 r
.36136 .57125 m .36449 .57432 L .36388 .57061 L F
.365 .328 .684 r
.32443 .64068 m .32661 .64302 L .32684 .63903 L F
.32443 .64068 m .32499 .64306 L .32661 .64302 L F
.809 .848 .389 r
.28191 .61976 m .28174 .62127 L .28296 .61765 L F
.782 .6 .034 r
.28159 .62253 m .28174 .62127 L .28191 .61976 L F
.28159 .62253 m .28187 .62398 L .28174 .62127 L F
.203 0 0 r
.22668 .53707 m .22446 .53767 L .22298 .53955 L F
.755 .957 .651 r
.36579 .52408 m .36463 .52559 L .3651 .52593 L F
0 .344 .699 r
.36376 .5255 m .3655 .52621 L .3651 .52593 L F
.698 .221 .114 r
.3651 .52593 m .36337 .52724 L .36184 .52518 L F
.755 .957 .651 r
.36463 .52559 m .36337 .52724 L .3651 .52593 L F
0 .344 .699 r
.3655 .52621 m .36674 .52671 L .3651 .52593 L F
.713 .414 .469 r
.52146 .53421 m .52506 .5365 L .52515 .53416 L F
.539 .294 .493 r
.52506 .5365 m .52764 .53614 L .52515 .53416 L F
.487 .61 .899 r
.21801 .60828 m .218 .61165 L .21599 .60827 L F
.21801 .60828 m .21999 .61116 L .218 .61165 L F
.645 .546 .728 r
.38882 .5703 m .38778 .57287 L .38666 .56832 L F
0 .078 .599 r
.38917 .57314 m .38778 .57287 L .38882 .5703 L F
.38917 .57314 m .38836 .57469 L .38778 .57287 L F
.981 .758 .53 r
.52764 .53614 m .52901 .53851 L .529 .53728 L F
0 0 .505 r
.34053 .54972 m .34023 .54818 L .33876 .54588 L F
.748 .749 .853 r
.34023 .54818 m .33816 .55018 L .33727 .54757 L F
.801 .988 .886 r
.34053 .54972 m .33917 .54998 L .34023 .54818 L F
.33917 .54998 m .33888 .54948 L .34023 .54818 L F
.764 .358 .282 r
.33876 .54588 m .34023 .54818 L .33872 .54787 L F
.33775 .54702 m .33872 .54787 L .33727 .54757 L F
.33876 .54588 m .33872 .54787 L .33775 .54702 L F
.325 .41 .796 r
.33957 .55017 m .34089 .55014 L .34066 .54959 L F
.33956 .54862 m .34066 .54959 L .33954 .54693 L F
.33957 .55017 m .34066 .54959 L .33956 .54862 L F
.33957 .55017 m .33954 .54693 L .33727 .54757 L F
0 .091 .617 r
.33835 .54822 m .33957 .55017 L .33873 .54922 L F
.33804 .54804 m .33873 .54922 L .33727 .54757 L F
.33835 .54822 m .33873 .54922 L .33804 .54804 L F
.801 .988 .886 r
.33917 .54998 m .33816 .55018 L .33888 .54948 L F
.546 .414 .653 r
.31656 .63618 m .31374 .64074 L .31444 .63721 L F
.325 .122 .444 r
.35632 .56492 m .35591 .56734 L .35863 .5639 L F
.246 .027 .371 r
.35863 .5639 m .35591 .56734 L .35796 .56621 L F
.882 .757 .253 r
.35591 .56734 m .35539 .56651 L .35796 .56621 L F
.243 0 0 r
.35539 .56651 m .35758 .5663 L .35796 .56621 L F
.386 .826 .688 r
.35796 .56621 m .35758 .56658 L .35856 .56607 L F
.435 .294 .589 r
.36044 .56602 m .35848 .56937 L .35796 .56621 L F
.243 0 0 r
.35758 .5663 m .36044 .56602 L .35796 .56621 L F
.386 .826 .688 r
.35796 .56621 m .35856 .56607 L .35983 .5654 L F
.35796 .56621 m .35591 .56734 L .35758 .56658 L F
.482 .398 .685 r
.17369 .59009 m .17544 .58603 L .17325 .58741 L F
.38 .416 .773 r
.3488 .64121 m .34793 .64404 L .34626 .64039 L F
.3488 .64121 m .35057 .64544 L .34793 .64404 L F
.496 .231 .441 r
.36997 .55629 m .37215 .55462 L .37024 .55556 L F
.472 0 0 r
.37322 .52578 m .37494 .5267 L .37175 .52488 L F
.087 .23 .717 r
.37169 .52126 m .37322 .52578 L .37175 .52488 L F
.233 0 .313 r
.29831 .57807 m .29959 .57939 L .3006 .57728 L F
.29831 .57807 m .29774 .58031 L .29959 .57939 L F
.438 .536 .859 r
.31525 .57298 m .31368 .57265 L .313 .5712 L F
.31525 .57298 m .31599 .57473 L .31368 .57265 L F
.805 .404 .291 r
.31679 .57744 m .31417 .5734 L .31599 .57473 L F
.31417 .5734 m .31368 .57265 L .31435 .57325 L F
.31417 .5734 m .31435 .57325 L .31599 .57473 L F
.31679 .57744 m .31261 .57454 L .31368 .57265 L F
.014 .181 .693 r
.31333 .57411 m .3141 .57462 L .31525 .57298 L F
.31261 .57454 m .31281 .57455 L .31333 .57411 L F
.31281 .57455 m .3141 .57462 L .31333 .57411 L F
.622 .408 .571 r
.313 .5712 m .31261 .57454 L .31525 .57298 L F
.804 .656 .699 r
.34094 .64596 m .33921 .64901 L .33814 .6451 L F
.697 .517 .64 r
.34168 .64888 m .33921 .64901 L .34094 .64596 L F
.103 0 .199 r
.27874 .6068 m .28009 .60741 L .28076 .60538 L F
.156 0 .289 r
.27874 .6068 m .27942 .60999 L .28009 .60741 L F
.27874 .6068 m .27778 .61094 L .27942 .60999 L F
.62 .345 .48 r
.26259 .5523 m .26528 .55229 L .26653 .5496 L F
.681 .622 .783 r
.26653 .5496 m .26907 .54951 L .2676 .54564 L F
.471 .121 .29 r
.26528 .55229 m .26907 .54951 L .26653 .5496 L F
0 .17 .696 r
.3556 .60491 m .35737 .60896 L .3578 .60731 L F
0 0 .086 r
.35737 .60896 m .35801 .60975 L .3578 .60731 L F
.35737 .60896 m .35667 .6115 L .35801 .60975 L F
.532 .38 .621 r
.38631 .58623 m .38388 .58421 L .38654 .58357 L F
.38631 .58623 m .38391 .58678 L .38388 .58421 L F
.786 .494 .493 r
.2915 .6294 m .29542 .62755 L .2917 .62681 L F
0 0 .405 r
.20145 .58211 m .20217 .58352 L .20036 .58026 L F
.917 .752 .662 r
.20527 .58591 m .20609 .58348 L .20217 .58352 L F
.901 .509 .263 r
.20145 .58211 m .20527 .58591 L .20217 .58352 L F
.576 .403 .61 r
.31369 .56724 m .30886 .56834 L .31145 .56513 L F
.074 0 .42 r
.31052 .56951 m .30886 .56834 L .31369 .56724 L F
.31052 .56951 m .3085 .57148 L .30886 .56834 L F
.156 .109 .549 r
.38326 .59141 m .38171 .59022 L .38366 .58935 L F
.38326 .59141 m .38201 .59286 L .38171 .59022 L F
.983 .754 .513 r
.34405 .56026 m .34579 .55883 L .34254 .56021 L F
.34405 .56026 m .34513 .56162 L .34579 .55883 L F
.524 .497 .769 r
.34579 .55883 m .34727 .55524 L .3447 .55584 L F
.34579 .55883 m .34835 .55959 L .34727 .55524 L F
.534 .006 0 r
.34835 .55959 m .34757 .56015 L .34579 .55883 L F
.34835 .55959 m .34757 .56015 L .34579 .55883 L F
.786 .635 .694 r
.3447 .55584 m .34254 .56021 L .34579 .55883 L F
.431 .799 .995 r
.24819 .5314 m .25041 .53101 L .2523 .53189 L F
.336 .774 .965 r
.25041 .53101 m .25462 .53141 L .2523 .53189 L F
.784 .576 .619 r
.33216 .57127 m .33619 .57436 L .33407 .57077 L F
.33216 .57127 m .33182 .57414 L .33619 .57436 L F
.355 0 0 r
.33157 .5765 m .33619 .57436 L .33182 .57414 L F
.33157 .5765 m .33434 .57638 L .33619 .57436 L F
.5 .512 .8 r
.33619 .57436 m .3369 .56974 L .33407 .57077 L F
.41 .207 .492 r
.33855 .57134 m .33832 .57382 L .33619 .57436 L F
.5 .512 .8 r
.33619 .57436 m .33832 .57382 L .3369 .56974 L F
.378 .217 .533 r
.33832 .57382 m .33633 .57747 L .33619 .57436 L F
.98 .717 .457 r
.33619 .57436 m .33434 .57638 L .33633 .57747 L F
0 0 0 r
.33619 .57436 m .33597 .57479 L .33832 .57382 L F
.33619 .57436 m .33434 .57638 L .33597 .57479 L F
.558 .4 .623 r
.30766 .63946 m .31023 .63619 L .3077 .63679 L F
.525 .597 .869 r
.23696 .61606 m .23546 .61852 L .2339 .61538 L F
.422 .465 .799 r
.23696 .61606 m .23743 .61831 L .23546 .61852 L F
.687 .68 .837 r
.3876 .57787 m .38943 .58084 L .38683 .58073 L F
.596 .396 .581 r
.38902 .58297 m .38683 .58073 L .38943 .58084 L F
.541 .762 .979 r
.39092 .57886 m .38943 .58084 L .3876 .57787 L F
.39092 .57886 m .39195 .58027 L .38943 .58084 L F
.379 .113 .38 r
.39079 .58204 m .38943 .58084 L .39195 .58027 L F
.39079 .58204 m .38902 .58297 L .38943 .58084 L F
.568 .402 .617 r
.33908 .65173 m .3365 .64935 L .33921 .64901 L F
.33908 .65173 m .33651 .65219 L .3365 .64935 L F
.897 .876 .807 r
.31583 .54307 m .314 .54664 L .3146 .54466 L F
.166 .057 .476 r
.31379 .5492 m .3146 .54466 L .314 .54664 L F
.189 0 .31 r
.29478 .60408 m .29339 .60237 L .29556 .60216 L F
.29478 .60408 m .29304 .6051 L .29339 .60237 L F
.407 .245 .547 r
.53351 .54641 m .53438 .54899 L .53174 .54968 L F
.41 .253 .556 r
.53438 .54899 m .53452 .55185 L .53174 .54968 L F
.354 .205 .536 r
.17416 .57765 m .17654 .5794 L .17647 .57662 L F
.17416 .57765 m .17415 .58121 L .17654 .5794 L F
.886 .951 .844 r
.20527 .58591 m .20277 .58951 L .20601 .58721 L F
.20527 .58591 m .20152 .58897 L .20277 .58951 L F
.596 .396 .581 r
.38902 .58297 m .38654 .58357 L .38683 .58073 L F
.296 .399 .798 r
.39069 .53645 m .39038 .54028 L .3892 .53636 L F
.39069 .53645 m .392 .53948 L .39038 .54028 L F
.206 .183 .61 r
.392 .53948 m .3923 .54219 L .39038 .54028 L F
.457 .236 .489 r
.37502 .55186 m .37803 .54868 L .37528 .54935 L F
.794 .682 .741 r
.29449 .5493 m .29213 .55277 L .29553 .55228 L F
.711 .594 .723 r
.36704 .52249 m .36317 .52103 L .36562 .52036 L F
.615 .709 .912 r
.36932 .5217 m .36704 .52249 L .36562 .52036 L F
.918 .802 .717 r
.2536 .55773 m .25513 .55692 L .25595 .55711 L F
.081 0 0 r
.2536 .55773 m .25595 .55711 L .25744 .55585 L F
.421 .222 .503 r
.25744 .55585 m .25957 .5552 L .25992 .55263 L F
.118 0 0 r
.25744 .55691 m .25595 .55711 L .25513 .55692 L F
.283 0 0 r
.25595 .55711 m .25957 .5552 L .25744 .55585 L F
.394 .841 .926 r
.26487 .53031 m .26564 .52948 L .26721 .52952 L F
.26487 .53031 m .26333 .5301 L .26564 .52948 L F
.329 .059 .343 r
.32293 .60786 m .32083 .60872 L .32352 .60575 L F
.342 0 .105 r
.32352 .60575 m .32466 .60692 L .32293 .60786 L F
.32352 .60575 m .3258 .60551 L .32466 .60692 L F
.405 .348 .681 r
.34614 .62755 m .34495 .63003 L .34514 .62727 L F
.519 .761 .985 r
.38596 .52882 m .38498 .53081 L .38404 .52894 L F
.38596 .52882 m .38728 .53029 L .38498 .53081 L F
.494 .284 .524 r
.31861 .6303 m .31892 .63301 L .31644 .63343 L F
.405 .222 .517 r
.32076 .63249 m .31861 .6303 L .32234 .62991 L F
.32076 .63249 m .31892 .63301 L .31861 .6303 L F
.681 .948 .682 r
.29159 .63232 m .29075 .63372 L .2935 .63097 L F
0 0 .134 r
.29161 .63493 m .29075 .63372 L .29159 .63232 L F
.29161 .63493 m .28986 .6363 L .29075 .63372 L F
0 .204 .726 r
.23881 .63294 m .2404 .63345 L .23889 .63179 L F
.645 .546 .728 r
.38882 .5703 m .38666 .56832 L .38924 .56757 L F
.558 .301 .482 r
.51256 .53943 m .51509 .5392 L .51484 .53671 L F
.615 .402 .57 r
.51509 .5392 m .51864 .53644 L .51484 .53671 L F
.419 .252 .547 r
.36254 .56181 m .36466 .56166 L .36465 .55867 L F
.401 .17 .446 r
.36466 .56166 m .36199 .56408 L .36254 .56181 L F
.705 .231 .122 r
.24936 .74784 m .25035 .74575 L .24613 .74492 L F
.727 .203 0 r
.25056 .74649 m .25035 .74575 L .24936 .74784 L F
.4 .402 .746 r
.25035 .74575 m .25338 .74839 L .25255 .74688 L F
.25035 .74575 m .25255 .74688 L .25186 .74727 L F
.25035 .74575 m .25186 .74727 L .2499 .74841 L F
.727 .203 0 r
.25213 .74755 m .25219 .74759 L .25035 .74575 L F
.25219 .74759 m .25338 .74839 L .25151 .74676 L F
.25219 .74759 m .25151 .74676 L .25035 .74575 L F
.522 .292 .507 r
.2499 .74841 m .25149 .74749 L .25218 .75093 L F
.25149 .74749 m .25186 .74727 L .25188 .74751 L F
.25149 .74749 m .25188 .74751 L .25218 .75093 L F
.768 .486 .507 r
.25218 .75093 m .25338 .74839 L .25209 .74752 L F
.522 .292 .507 r
.25186 .74727 m .25209 .74752 L .25218 .75093 L F
.768 .486 .507 r
.25218 .75093 m .25209 .74752 L .25056 .74649 L F
.522 .292 .507 r
.25209 .74752 m .25245 .74791 L .25218 .75093 L F
.203 0 .208 r
.25511 .7477 m .25338 .74839 L .25218 .75093 L F
.536 .256 .437 r
.25245 .74791 m .25432 .75026 L .25218 .75093 L F
.447 .425 .741 r
.25255 .74688 m .25338 .74839 L .25511 .7477 L F
.492 .569 .861 r
.25511 .7477 m .25338 .74839 L .25219 .74759 L F
.25247 .74754 m .25219 .74759 L .25209 .74752 L F
.25511 .7477 m .25219 .74759 L .25247 .74754 L F
.536 .256 .437 r
.25249 .74754 m .25418 .75 L .25245 .74791 L F
.25255 .74688 m .25286 .74748 L .25249 .74754 L F
.25286 .74748 m .25418 .75 L .25249 .74754 L F
.25418 .75 m .25432 .75026 L .25245 .74791 L F
.727 .203 0 r
.25209 .74752 m .25213 .74755 L .25186 .74727 L F
.522 .292 .507 r
.25186 .74727 m .25255 .74688 L .25245 .74791 L F
.727 .203 0 r
.25056 .74649 m .25209 .74752 L .25035 .74575 L F
.25209 .74752 m .25186 .74727 L .25035 .74575 L F
.492 .569 .861 r
.25511 .7477 m .25209 .74752 L .25501 .74767 L F
.536 .256 .437 r
.25286 .74748 m .25511 .7477 L .25432 .75026 L F
.25255 .74688 m .25511 .7477 L .25286 .74748 L F
.492 .569 .861 r
.25501 .74767 m .25463 .74765 L .25056 .74649 L F
.25463 .74765 m .25209 .74752 L .25189 .74739 L F
.25463 .74765 m .25189 .74739 L .25056 .74649 L F
.496 .304 .549 r
.20786 .57041 m .20534 .57368 L .2059 .5715 L F
.434 .159 .396 r
.35842 .54372 m .35809 .54579 L .35571 .54637 L F
.35842 .54372 m .35809 .54579 L .35571 .54637 L F
.335 .077 .365 r
.3603 .54485 m .35842 .54372 L .36084 .54338 L F
.3603 .54485 m .35809 .54579 L .35842 .54372 L F
.3603 .54485 m .35842 .54372 L .36084 .54338 L F
.3603 .54485 m .35809 .54579 L .35842 .54372 L F
.621 .475 .663 r
.24208 .54611 m .23979 .54915 L .23953 .54673 L F
.194 .719 .855 r
.29919 .52817 m .30077 .52777 L .30326 .52813 L F
.582 .933 .943 r
.30326 .52813 m .3026 .52684 L .30562 .52786 L F
.30326 .52813 m .30077 .52777 L .3026 .52684 L F
.977 .735 .503 r
.30868 .55275 m .30683 .55434 L .30493 .55411 L F
.30868 .55275 m .30847 .55554 L .30683 .55434 L F
.75 .233 0 r
.24252 .63455 m .2408 .63424 L .23985 .63302 L F
.643 .088 0 r
.24427 .63455 m .2404 .63345 L .24235 .63484 L F
.24328 .63421 m .2404 .63345 L .24427 .63455 L F
.24446 .63452 m .24328 .63421 L .24427 .63455 L F
.24446 .63452 m .24252 .63455 L .2404 .63345 L F
.75 .233 0 r
.24252 .63455 m .23889 .63179 L .2404 .63345 L F
.24106 .63344 m .23985 .63302 L .23889 .63179 L F
.24252 .63455 m .23985 .63302 L .24106 .63344 L F
.519 .653 .919 r
.2325 .61346 m .23173 .61587 L .2303 .61394 L F
.2325 .61346 m .2339 .61538 L .23173 .61587 L F
.38 .196 .501 r
.50576 .55022 m .50803 .54854 L .5081 .54618 L F
.492 .221 .431 r
.37489 .6363 m .37194 .63911 L .37237 .63673 L F
.37489 .6363 m .37194 .63911 L .37237 .63673 L F
.295 .407 .806 r
.33919 .53756 m .33778 .53964 L .33706 .5378 L F
.33919 .53756 m .33974 .5394 L .33778 .53964 L F
.64 .539 .724 r
.34146 .5422 m .33778 .53964 L .33974 .5394 L F
.34146 .5422 m .33918 .5433 L .33778 .53964 L F
.332 0 .1 r
.236 .56182 m .23812 .56171 L .23853 .56052 L F
.238 0 .069 r
.23853 .56052 m .23812 .56171 L .24063 .56038 L F
.175 0 0 r
.23853 .56052 m .24063 .56038 L .24113 .55965 L F
.561 .411 .636 r
.29857 .64007 m .30052 .63952 L .30083 .63662 L F
.473 .388 .68 r
.29857 .64007 m .30121 .6426 L .30052 .63952 L F
.29857 .64007 m .29909 .64293 L .30121 .6426 L F
.395 .842 .927 r
.24052 .53328 m .23981 .53418 L .23733 .53519 L F
.24052 .53328 m .24195 .53355 L .23981 .53418 L F
.42 .177 .437 r
.3447 .55584 m .34727 .55524 L .34784 .55226 L F
.325 .095 .403 r
.34784 .55226 m .34928 .55443 L .3495 .55181 L F
.34784 .55226 m .34727 .55524 L .34928 .55443 L F
.222 0 .278 r
.32729 .57783 m .32659 .58001 L .32917 .57693 L F
.378 .685 .979 r
.21112 .61628 m .21293 .61774 L .21326 .61629 L F
.164 .454 .882 r
.21293 .61774 m .21463 .61811 L .21326 .61629 L F
.126 0 .214 r
.36897 .59562 m .36648 .59878 L .36727 .59669 L F
.36727 .59669 m .36648 .59878 L .36897 .59562 L F
.338 .598 .942 r
.36548 .65598 m .36799 .65588 L .36632 .65724 L F
0 0 .157 r
.36799 .65588 m .36649 .65846 L .36632 .65724 L F
.498 .367 .632 r
.2915 .6294 m .2935 .63097 L .29546 .62996 L F
.2915 .6294 m .29159 .63232 L .2935 .63097 L F
0 0 .474 r
.36319 .53757 m .36355 .54183 L .36449 .53808 L F
0 0 0 r
.36753 .54078 m .36581 .54176 L .36379 .54249 L F
.09 0 .1 r
.36355 .54183 m .36581 .54176 L .36449 .53808 L F
.36355 .54183 m .36338 .54311 L .36581 .54176 L F
.422 .284 .587 r
.22396 .56063 m .22181 .55799 L .22546 .55875 L F
.329 0 .088 r
.22786 .55794 m .22396 .56063 L .22546 .55875 L F
.286 .365 .77 r
.31428 .56669 m .31369 .56724 L .31145 .56513 L F
.569 .173 .252 r
.31148 .55018 m .31337 .55163 L .31379 .5492 L F
.31148 .55018 m .31081 .55196 L .31337 .55163 L F
.211 .278 .715 r
.28117 .5587 m .28305 .56051 L .28233 .55716 L F
.483 .486 .784 r
.37831 .56268 m .37619 .56547 L .37517 .56112 L F
.628 .695 .893 r
.37831 .56268 m .37913 .56518 L .37619 .56547 L F
.917 .752 .662 r
.20527 .58591 m .20601 .58721 L .20609 .58348 L F
.573 .725 .945 r
.20839 .58381 m .20609 .58348 L .20642 .58312 L F
0 0 .11 r
.20609 .58348 m .20839 .58381 L .20642 .58312 L F
.20609 .58348 m .20621 .58418 L .20839 .58381 L F
.20609 .58348 m .20601 .58721 L .20621 .58418 L F
.898 .926 .828 r
.32149 .58896 m .32046 .59275 L .32342 .59026 L F
.908 .834 .761 r
.32149 .58896 m .32342 .59026 L .32386 .58654 L F
.404 .399 .74 r
.17369 .59009 m .17455 .59455 L .1763 .59194 L F
.384 .38 .732 r
.17535 .59621 m .1763 .59194 L .17455 .59455 L F
.145 0 0 r
.24063 .56038 m .2451 .55821 L .24113 .55965 L F
.24063 .56038 m .24307 .55989 L .2451 .55821 L F
.673 .319 .366 r
.24307 .55989 m .24726 .55808 L .2451 .55821 L F
.827 .483 .405 r
.29815 .62789 m .29788 .62978 L .29962 .62831 L F
.355 0 0 r
.24187 .6225 m .24573 .6232 L .24347 .62304 L F
.503 .27 .493 r
.33918 .5433 m .33876 .54588 L .33631 .54635 L F
.745 .279 .143 r
.24517 .56198 m .24063 .56038 L .24257 .5623 L F
.042 .288 .78 r
.23968 .62009 m .2391 .62163 L .23743 .61831 L F
.224 .511 .91 r
.23968 .62009 m .24187 .6225 L .2391 .62163 L F
.365 .312 .665 r
.32499 .64306 m .32735 .64517 L .32661 .64302 L F
.38 .313 .656 r
.32499 .64306 m .32553 .64563 L .32735 .64517 L F
.818 .916 .904 r
.36317 .52103 m .3637 .51757 L .36562 .52036 L F
.36317 .52103 m .36129 .52017 L .3637 .51757 L F
.413 .23 .521 r
.33409 .65524 m .33399 .65807 L .33172 .65858 L F
.496 .721 .972 r
.37419 .6258 m .37648 .62784 L .37411 .62822 L F
.713 .414 .469 r
.52146 .53421 m .5213 .53637 L .52506 .5365 L F
.749 .236 0 r
.283 .55591 m .28501 .55818 L .28732 .55874 L F
.412 .823 .975 r
.28732 .55874 m .28501 .55818 L .28933 .55819 L F
.674 .463 .592 r
.28933 .55819 m .28583 .56077 L .28732 .55874 L F
0 .545 .75 r
.24573 .6232 m .24796 .62343 L .24981 .62371 L F
.542 .899 .973 r
.24981 .62371 m .25035 .62249 L .2524 .62317 L F
.24981 .62371 m .24796 .62343 L .25035 .62249 L F
.477 .816 .999 r
.28295 .68495 m .28493 .68653 L .28234 .68632 L F
.272 .745 .938 r
.28234 .68632 m .28493 .68653 L .28509 .68647 L F
.477 .816 .999 r
.28698 .68536 m .28493 .68653 L .28295 .68495 L F
0 0 0 r
.28509 .68647 m .28493 .68653 L .28698 .68536 L F
.137 0 .254 r
.32293 .60786 m .3205 .6112 L .32083 .60872 L F
.689 .678 .834 r
.31329 .54488 m .30908 .54236 L .31143 .54114 L F
.591 .623 .852 r
.31394 .54029 m .31329 .54488 L .31143 .54114 L F
.31394 .54029 m .3146 .54466 L .31329 .54488 L F
.205 0 0 r
.3146 .54466 m .31095 .54771 L .31329 .54488 L F
.213 .486 .895 r
.31589 .58464 m .31873 .58758 L .31765 .58786 L F
.558 .639 .887 r
.31519 .58446 m .31765 .58786 L .31514 .58839 L F
.213 .486 .895 r
.31583 .58453 m .31765 .58786 L .31519 .58446 L F
.109 .001 .438 r
.31554 .58472 m .31524 .58706 L .31694 .58577 L F
.31519 .58446 m .31519 .5848 L .31554 .58472 L F
.31519 .5848 m .31524 .58706 L .31554 .58472 L F
.213 .486 .895 r
.31583 .58453 m .31593 .58463 L .31589 .58464 L F
.31593 .58463 m .31873 .58758 L .31589 .58464 L F
.736 .917 .954 r
.32005 .58752 m .31658 .58814 L .31765 .58786 L F
.633 .071 0 r
.31933 .58822 m .32005 .58752 L .31765 .58786 L F
.213 .486 .895 r
.31873 .58758 m .31933 .58822 L .31765 .58786 L F
.736 .917 .954 r
.31658 .58814 m .31514 .58839 L .31765 .58786 L F
0 .119 .648 r
.32005 .58752 m .32149 .58896 L .3204 .58699 L F
.633 .071 0 r
.31933 .58822 m .32149 .58896 L .32005 .58752 L F
.643 .563 .749 r
.51107 .54264 m .51256 .53943 L .5099 .54009 L F
.51107 .54264 m .51383 .54326 L .51256 .53943 L F
.424 .085 .285 r
.51063 .54572 m .51383 .54326 L .51107 .54264 L F
.471 .121 .29 r
.26528 .55229 m .2675 .55219 L .26907 .54951 L F
.68 .621 .783 r
.2676 .54564 m .26907 .54951 L .27143 .54724 L F
.447 .096 .276 r
.26907 .54951 m .27081 .55089 L .27155 .54976 L F
.26907 .54951 m .2675 .55219 L .27081 .55089 L F
.609 .503 .709 r
.26907 .54951 m .27155 .54976 L .27143 .54724 L F
.507 .327 .571 r
.30896 .584 m .31129 .58598 L .31147 .5833 L F
.30896 .584 m .31129 .58598 L .31147 .5833 L F
.508 .528 .812 r
.51419 .55851 m .51513 .55448 L .51252 .55518 L F
.51419 .55851 m .5165 .55812 L .51513 .55448 L F
.833 .836 .849 r
.27854 .54211 m .28056 .54413 L .28299 .54026 L F
.176 0 0 r
.28056 .54413 m .27859 .54483 L .2825 .54439 L F
.859 .672 .649 r
.22603 .62996 m .22386 .63045 L .22467 .62768 L F
0 0 0 r
.20678 .54669 m .20414 .54964 L .20571 .54819 L F
.071 0 0 r
.20571 .54819 m .20898 .54603 L .20678 .54669 L F
.988 .734 .453 r
.31915 .59203 m .32047 .596 L .32046 .59275 L F
.898 .926 .828 r
.32149 .58896 m .31915 .59203 L .32046 .59275 L F
.016 .275 .774 r
.32282 .59785 m .32243 .59941 L .32047 .596 L F
0 0 .001 r
.32259 .60045 m .32243 .59941 L .32282 .59785 L F
.32259 .60045 m .3221 .60183 L .32243 .59941 L F
.301 0 0 r
.3447 .55584 m .34249 .55696 L .34036 .55671 L F
0 .015 .528 r
.34556 .55091 m .34606 .55451 L .3447 .55584 L F
.768 .625 .702 r
.34606 .55451 m .34249 .55696 L .3447 .55584 L F
.34606 .55451 m .34752 .55824 L .34249 .55696 L F
.283 0 0 r
.34752 .55824 m .34539 .55782 L .34249 .55696 L F
.32 .583 .937 r
.34249 .55696 m .34539 .55782 L .34492 .55725 L F
.34249 .55696 m .34492 .55725 L .34336 .55534 L F
.301 0 0 r
.34036 .55671 m .34249 .55696 L .33997 .55678 L F
.462 .248 .502 r
.32268 .56151 m .32013 .56456 L .3203 .56203 L F
.368 .547 .899 r
.21463 .61811 m .21657 .62111 L .21741 .61925 L F
.253 .407 .824 r
.21657 .62111 m .2182 .62123 L .21741 .61925 L F
.201 .577 .941 r
.34401 .61652 m .34273 .61693 L .34137 .61473 L F
.34401 .61652 m .34537 .61815 L .34273 .61693 L F
.76 .477 .503 r
.34273 .61693 m .34508 .62061 L .34537 .61815 L F
.34273 .61693 m .34508 .62061 L .34537 .61815 L F
.46 .831 .992 r
.20642 .58312 m .20954 .58264 L .20839 .58381 L F
.534 .25 .429 r
.20954 .58264 m .20642 .58312 L .20839 .58381 L F
0 0 0 r
.5343 .54586 m .53642 .54305 L .53602 .5427 L F
.869 .603 .075 r
.53557 .53958 m .53602 .5427 L .53642 .54305 L F
.772 .63 .703 r
.34508 .62061 m .34796 .61784 L .34537 .61815 L F
0 0 .031 r
.34548 .62018 m .34508 .62061 L .34532 .61857 L F
.34548 .62018 m .34532 .61857 L .34537 .61815 L F
.772 .63 .703 r
.34508 .62061 m .34901 .62099 L .34796 .61784 L F
.715 .18 0 r
.34554 .6207 m .34548 .62018 L .34209 .61858 L F
0 .136 .641 r
.34615 .62108 m .34508 .62061 L .34548 .62018 L F
.715 .18 0 r
.34615 .62108 m .34548 .62018 L .34554 .6207 L F
0 0 .031 r
.34548 .62018 m .34537 .61815 L .34401 .61652 L F
.489 .684 .953 r
.34614 .54111 m .34498 .54342 L .34381 .54144 L F
.307 .205 .572 r
.34719 .5448 m .34498 .54342 L .34614 .54111 L F
.34719 .5448 m .34538 .54597 L .34498 .54342 L F
.556 .359 .57 r
.50803 .54854 m .51063 .54572 L .5081 .54618 L F
.3 .563 .929 r
.2182 .62123 m .22087 .62405 L .22165 .62276 L F
.049 .223 .722 r
.22087 .62405 m .22189 .6246 L .22165 .62276 L F
.097 0 0 r
.33687 .6683 m .33756 .66872 L .33548 .66824 L F
.314 0 0 r
.33687 .6683 m .3409 .6699 L .33892 .66827 L F
.097 0 0 r
.33687 .6683 m .33892 .66827 L .33756 .66872 L F
.339 .158 .482 r
.30659 .64946 m .30922 .6458 L .3089 .64835 L F
.127 .096 .549 r
.30854 .65088 m .30659 .64946 L .3089 .64835 L F
.30854 .65088 m .30688 .65196 L .30659 .64946 L F
.462 .247 .501 r
.33447 .61197 m .33685 .61073 L .33716 .60869 L F
.217 .134 .543 r
.33447 .61197 m .33639 .61346 L .33685 .61073 L F
.33447 .61197 m .33444 .61472 L .33639 .61346 L F
0 0 0 r
.24934 .56026 m .25145 .55839 L .24726 .55808 L F
.8 .648 .694 r
.29512 .64572 m .29978 .64606 L .29909 .64293 L F
.303 0 0 r
.2986 .64629 m .29978 .64606 L .29512 .64572 L F
.377 .368 .723 r
.29909 .64293 m .29978 .64606 L .30102 .64524 L F
.498 .903 .801 r
.30102 .64524 m .29978 .64606 L .2986 .64629 L F
.843 .792 .802 r
.2437 .74562 m .23986 .74861 L .24263 .7484 L F
.434 .163 .402 r
.24613 .74492 m .2437 .74562 L .24263 .7484 L F
.369 .224 .549 r
.39615 .56065 m .39424 .56162 L .39414 .5589 L F
.481 .437 .731 r
.37805 .608 m .37519 .60604 L .37767 .60386 L F
.37805 .608 m .376 .60882 L .37519 .60604 L F
.577 .457 .679 r
.3204 .58699 m .32385 .5864 L .32319 .58257 L F
.353 .331 .695 r
.32673 .58517 m .32386 .58654 L .32862 .58473 L F
.32668 .58518 m .32649 .58527 L .32673 .58517 L F
.32649 .58527 m .32386 .58654 L .32673 .58517 L F
.908 .834 .761 r
.32149 .58896 m .32386 .58654 L .32625 .58599 L F
.565 .407 .626 r
.32385 .5864 m .32149 .58896 L .32625 .58599 L F
.3204 .58699 m .3208 .58771 L .32385 .5864 L F
.3208 .58771 m .32149 .58896 L .32385 .5864 L F
.353 .331 .695 r
.32604 .58546 m .32386 .58654 L .32668 .58518 L F
.32652 .58522 m .32604 .58546 L .32665 .5852 L F
.32652 .58522 m .32665 .5852 L .32668 .58518 L F
.32652 .58522 m .32625 .58599 L .32537 .58619 L F
.32495 .586 m .32481 .58632 L .32386 .58654 L F
.577 .457 .679 r
.32385 .5864 m .32625 .58599 L .32585 .58554 L F
.442 .427 .747 r
.32319 .58257 m .32625 .58599 L .32652 .58522 L F
.943 .959 .676 r
.32652 .58522 m .32458 .58687 L .32517 .58548 L F
.577 .457 .679 r
.32385 .5864 m .32585 .58554 L .32319 .58257 L F
.442 .427 .747 r
.32319 .58257 m .32652 .58522 L .32536 .58365 L F
0 .111 .663 r
.32536 .58365 m .32652 .58522 L .32627 .5829 L F
.943 .959 .676 r
.32652 .58522 m .32517 .58548 L .32627 .5829 L F
.257 0 0 r
.32652 .58522 m .32862 .58473 L .33033 .58525 L F
.791 .491 .481 r
.32832 .53261 m .33221 .53085 L .33073 .53048 L F
.271 .42 .828 r
.32807 .52995 m .32661 .53052 L .32476 .52677 L F
.576 .602 .841 r
.22399 .6137 m .22155 .61435 L .21999 .61116 L F
.623 .245 .306 r
.32662 .66758 m .33062 .66696 L .32889 .6696 L F
.67 .253 .245 r
.33062 .66696 m .33117 .67027 L .32889 .6696 L F
.33062 .66696 m .33299 .66816 L .33117 .67027 L F
.514 .37 .624 r
.36388 .57061 m .36603 .57315 L .36772 .57131 L F
.36388 .57061 m .36449 .57432 L .36603 .57315 L F
.442 .21 .466 r
.33685 .61073 m .33944 .60796 L .33716 .60869 L F
.642 .77 .941 r
.35138 .62014 m .3529 .6216 L .35542 .62106 L F
.547 .262 .434 r
.3529 .6216 m .35441 .62354 L .35542 .62106 L F
.02 .125 .634 r
.3529 .6216 m .35389 .62456 L .35441 .62354 L F
.547 .262 .434 r
.3529 .6216 m .35441 .62354 L .35542 .62106 L F
.122 0 0 r
.20414 .54964 m .20462 .55088 L .20571 .54819 L F
.20414 .54964 m .20248 .55162 L .20462 .55088 L F
.486 .322 .583 r
.319 .63569 m .31644 .63343 L .31892 .63301 L F
.319 .63569 m .31656 .63618 L .31644 .63343 L F
.234 0 .21 r
.37805 .608 m .37528 .61013 L .376 .60882 L F
.351 0 .076 r
.3495 .55181 m .35142 .55166 L .35322 .54953 L F
.676 .54 .692 r
.35571 .54637 m .35322 .54953 L .35607 .54918 L F
.488 .259 .492 r
.35346 .55232 m .35607 .54918 L .35322 .54953 L F
.728 .429 .472 r
.35142 .55166 m .35607 .54918 L .35322 .54953 L F
.676 .54 .692 r
.35571 .54637 m .35322 .54953 L .35607 .54918 L F
.232 .478 .887 r
.30625 .59921 m .30952 .60172 L .30749 .5986 L F
.779 .691 .767 r
.35808 .53027 m .35641 .5266 L .35825 .52773 L F
.389 .191 .487 r
.36035 .527 m .35808 .53027 L .35825 .52773 L F
.503 .3 .537 r
.34088 .57072 m .33832 .57382 L .33855 .57134 L F
.423 .288 .591 r
.39187 .56708 m .38882 .5703 L .38924 .56757 L F
.39187 .56708 m .39205 .57136 L .38882 .5703 L F
.39 .062 .284 r
.39205 .57136 m .38917 .57314 L .38882 .5703 L F
.843 .882 .869 r
.36146 .659 m .35707 .6608 L .35968 .65782 L F
.628 .817 .973 r
.24747 .54322 m .25169 .54353 L .24962 .54254 L F
.446 .153 .373 r
.24849 .5462 m .25086 .5457 L .25169 .54353 L F
.588 .843 .993 r
.25335 .54254 m .24962 .54254 L .25169 .54353 L F
.119 0 .208 r
.25169 .54353 m .25086 .5457 L .25335 .54254 L F
.384 .38 .732 r
.17535 .59621 m .17712 .59614 L .1763 .59194 L F
0 0 .161 r
.38918 .57524 m .38836 .57469 L .38917 .57314 L F
.38918 .57524 m .3876 .57787 L .38836 .57469 L F
.421 .721 .987 r
.53603 .54779 m .53351 .54641 L .5343 .54586 L F
.53603 .54779 m .53438 .54899 L .53351 .54641 L F
.791 .491 .481 r
.32832 .53261 m .33146 .53309 L .33221 .53085 L F
.673 .123 0 r
.30843 .62961 m .30402 .6268 L .30533 .62826 L F
.38 0 .179 r
.27101 .55506 m .26635 .55811 L .26695 .55613 L F
.071 0 0 r
.33447 .61719 m .33252 .61804 L .33105 .6202 L F
.293 .029 .33 r
.1845 .56472 m .18587 .56678 L .18662 .56381 L F
.1845 .56472 m .18383 .56769 L .18587 .56678 L F
0 .094 .647 r
.29755 .54637 m .29934 .54874 L .29963 .54605 L F
.29755 .54637 m .30045 .55185 L .29934 .54874 L F
.29755 .54637 m .30045 .55185 L .29934 .54874 L F
.706 .726 .866 r
.51766 .56146 m .51896 .55745 L .5165 .55812 L F
.51766 .56146 m .52082 .55972 L .51896 .55745 L F
.587 .397 .591 r
.32937 .57439 m .33182 .57414 L .33216 .57127 L F
.642 .395 .529 r
.35122 .58682 m .35121 .58934 L .3485 .58941 L F
.542 .356 .579 r
.35414 .5834 m .35431 .58636 L .35122 .58682 L F
.52 .294 .512 r
.35431 .58636 m .35121 .58934 L .35122 .58682 L F
0 0 .196 r
.33727 .54757 m .33631 .54635 L .33876 .54588 L F
.33727 .54757 m .336 .54875 L .33631 .54635 L F
.716 .64 .772 r
.37981 .54762 m .3825 .5442 L .37987 .54329 L F
.087 .503 .901 r
.25858 .63708 m .25879 .63601 L .25733 .63544 L F
.25858 .63708 m .26086 .63769 L .25879 .63601 L F
.534 .32 .535 r
.25992 .55263 m .26225 .5546 L .26259 .5523 L F
.25992 .55263 m .25957 .5552 L .26225 .5546 L F
.56 .264 .423 r
.20298 .57434 m .20175 .57694 L .19955 .57682 L F
0 0 0 r
.20534 .57368 m .20175 .57694 L .20298 .57434 L F
.447 .268 .544 r
.36958 .64249 m .37194 .63911 L .36962 .63972 L F
.36958 .64249 m .37194 .63911 L .36962 .63972 L F
0 0 0 r
.363 .59337 m .35979 .59605 L .36153 .59495 L F
.1 0 .246 r
.363 .59337 m .3658 .5933 L .36523 .58995 L F
.085 0 .054 r
.363 .59337 m .364 .59433 L .3658 .5933 L F
.434 .325 .632 r
.364 .59433 m .36424 .59385 L .3658 .5933 L F
.538 .534 .799 r
.36173 .59473 m .3658 .5933 L .363 .59337 L F
.3617 .59477 m .36424 .59385 L .36173 .59473 L F
.36424 .59385 m .3658 .5933 L .36173 .59473 L F
.434 .325 .632 r
.364 .59433 m .36607 .59374 L .36601 .59323 L F
0 0 .173 r
.36523 .58995 m .3658 .5933 L .36574 .59096 L F
.434 .325 .632 r
.36424 .59385 m .36574 .59096 L .3658 .5933 L F
.36424 .59385 m .36601 .59323 L .36574 .59096 L F
.538 .534 .799 r
.36546 .59343 m .364 .59433 L .3658 .5933 L F
.434 .325 .632 r
.364 .59433 m .36546 .59343 L .36424 .59385 L F
.538 .534 .799 r
.36153 .59495 m .364 .59433 L .36546 .59343 L F
.434 .325 .632 r
.364 .59433 m .36601 .59323 L .36546 .59343 L F
.538 .534 .799 r
.36153 .59495 m .3658 .5933 L .3617 .59477 L F
.26 .414 .827 r
.23189 .75224 m .23269 .75397 L .23443 .7543 L F
.507 .578 .861 r
.31782 .57299 m .31599 .57473 L .31525 .57298 L F
.27 .221 .617 r
.31796 .57624 m .31599 .57473 L .31782 .57299 L F
.31796 .57624 m .31679 .57744 L .31599 .57473 L F
.384 .15 .431 r
.3546 .60291 m .35716 .60248 L .35741 .59906 L F
.265 .015 .335 r
.35979 .59605 m .35741 .59906 L .35911 .59848 L F
.393 .157 .433 r
.35741 .59906 m .35824 .60117 L .35911 .59848 L F
.35741 .59906 m .35716 .60248 L .35824 .60117 L F
.64 .397 .534 r
.32319 .58257 m .32659 .58001 L .32428 .58059 L F
.613 .686 .895 r
.36171 .5887 m .36523 .58995 L .36409 .5883 L F
.329 .594 .942 r
.36409 .5883 m .36523 .58995 L .36607 .58836 L F
0 0 .173 r
.36523 .58995 m .36574 .59096 L .36607 .58836 L F
0 0 0 r
.35607 .54918 m .35809 .54579 L .35571 .54637 L F
.43 .31 .615 r
.35809 .54579 m .35607 .54918 L .35571 .54637 L F
0 0 .029 r
.21308 .56184 m .21175 .5645 L .21034 .56524 L F
.199 .187 .619 r
.21175 .5645 m .21207 .56713 L .21034 .56524 L F
.484 .224 .444 r
.32917 .57693 m .33182 .57414 L .32937 .57439 L F
0 0 0 r
.35664 .51663 m .35551 .51695 L .35364 .51671 L F
.325 .679 .978 r
.35156 .51729 m .35286 .51796 L .34941 .51748 L F
.35286 .51796 m .35269 .51834 L .34891 .51741 L F
.708 .77 .901 r
.35364 .51671 m .35286 .51796 L .34943 .51619 L F
.693 .889 .515 r
.35364 .51671 m .35299 .51766 L .35296 .5178 L F
.35364 .51671 m .35296 .5178 L .35282 .51839 L F
.159 .399 .844 r
.35282 .51839 m .35364 .51671 L .35607 .51844 L F
.35282 .51839 m .35442 .51877 L .35364 .51671 L F
.693 .889 .515 r
.35355 .51856 m .35282 .51839 L .35353 .519 L F
.35364 .51671 m .35282 .51839 L .35355 .51856 L F
0 .43 .697 r
.35269 .51834 m .35386 .51863 L .35282 .51839 L F
.35386 .51863 m .35442 .51877 L .35282 .51839 L F
.693 .889 .515 r
.35299 .51766 m .35269 .51834 L .35282 .51839 L F
.325 .679 .978 r
.35286 .51796 m .35395 .51853 L .35269 .51834 L F
.35395 .51853 m .35442 .51877 L .35386 .51863 L F
.35395 .51853 m .35386 .51863 L .35269 .51834 L F
.693 .889 .515 r
.35395 .51853 m .35353 .519 L .35412 .5195 L F
.35364 .51671 m .35353 .519 L .35395 .51853 L F
.708 .77 .901 r
.35364 .51671 m .35442 .51877 L .35395 .51853 L F
.693 .889 .515 r
.35364 .51671 m .35412 .5195 L .35501 .52027 L F
.708 .77 .901 r
.35364 .51671 m .35395 .51853 L .35286 .51796 L F
.607 .804 .976 r
.35711 .51729 m .35607 .51844 L .35364 .51671 L F
.769 .699 .786 r
.35364 .51671 m .35501 .52027 L .35711 .51729 L F
.693 .889 .515 r
.35299 .51766 m .35255 .5183 L .35269 .51834 L F
.765 .334 .228 r
.35282 .51839 m .35129 .52015 L .34891 .51741 L F
.693 .889 .515 r
.35255 .5183 m .35129 .52015 L .35282 .51839 L F
0 .43 .697 r
.34891 .51741 m .35269 .51834 L .35282 .51839 L F
.651 .189 .144 r
.35501 .52027 m .35129 .52015 L .35282 .51839 L F
.787 .708 .776 r
.35364 .51671 m .35129 .52015 L .35501 .52027 L F
.855 .985 .706 r
.35172 .51802 m .35129 .52015 L .35364 .51671 L F
0 0 0 r
.35551 .51695 m .35172 .51802 L .35297 .51717 L F
.35551 .51695 m .35297 .51717 L .35364 .51671 L F
.325 .679 .978 r
.34943 .51619 m .35156 .51729 L .34891 .51741 L F
.35156 .51729 m .34941 .51748 L .34891 .51741 L F
.395 .225 .53 r
.31115 .60834 m .3131 .60792 L .31319 .60526 L F
.237 .087 .466 r
.31128 .6112 m .3131 .60792 L .31115 .60834 L F
.649 .675 .861 r
.52283 .55831 m .52424 .5615 L .52715 .56026 L F
.377 .368 .723 r
.29909 .64293 m .30102 .64524 L .30121 .6426 L F
.456 .214 .457 r
.37993 .59632 m .37949 .59878 L .37701 .59909 L F
.242 .007 .344 r
.37949 .59878 m .37808 .60145 L .37701 .59909 L F
.599 .445 .644 r
.31094 .57899 m .31147 .5833 L .31188 .58061 L F
.476 .103 .253 r
.34167 .60693 m .33968 .60555 L .33944 .60796 L F
.34167 .60693 m .34208 .60513 L .33968 .60555 L F
.809 .848 .389 r
.28191 .61976 m .28296 .61765 L .28237 .61714 L F
0 .574 .757 r
.24593 .55059 m .2442 .55035 L .24196 .5502 L F
.455 .792 .999 r
.24828 .55098 m .2442 .55035 L .24593 .55059 L F
.302 .13 .475 r
.35911 .59848 m .36153 .59495 L .35979 .59605 L F
.722 .732 .859 r
.30989 .63908 m .31374 .64074 L .31163 .63585 L F
.613 .044 0 r
.31154 .64079 m .31374 .64074 L .30989 .63908 L F
.132 .358 .818 r
.31163 .63585 m .31374 .64074 L .31411 .63763 L F
.867 .996 .79 r
.31411 .63763 m .31374 .64074 L .31154 .64079 L F
.546 .414 .653 r
.31656 .63618 m .31681 .63967 L .31374 .64074 L F
.646 .516 .691 r
.31681 .63967 m .31462 .64197 L .31374 .64074 L F
.797 .302 0 r
.31154 .64079 m .31462 .64197 L .31374 .64074 L F
.389 .073 .304 r
.33216 .56079 m .33459 .56049 L .33573 .55758 L F
.384 .582 .92 r
.33573 .55758 m .33587 .55516 L .33374 .5553 L F
.33573 .55758 m .33763 .55757 L .33587 .55516 L F
.452 .152 .365 r
.33459 .56049 m .33763 .55757 L .33573 .55758 L F
0 0 0 r
.30043 .57429 m .3014 .57352 L .30265 .57119 L F
.046 0 .465 r
.30043 .57429 m .30161 .57623 L .3014 .57352 L F
.30043 .57429 m .3006 .57728 L .30161 .57623 L F
.474 .308 .575 r
.34712 .66078 m .34448 .66149 L .34448 .6584 L F
0 0 .495 r
.39447 .54543 m .39577 .54808 L .39517 .54961 L F
.182 .46 .884 r
.39577 .54808 m .39844 .55114 L .39517 .54961 L F
.099 0 0 r
.30048 .59008 m .30299 .5904 L .30043 .59008 L F
.764 .88 .93 r
.29808 .58978 m .29768 .59111 L .30048 .59008 L F
.824 .887 .461 r
.29913 .59258 m .30048 .59008 L .29808 .58978 L F
.099 0 0 r
.30048 .59008 m .30043 .59008 L .29808 .58978 L F
.748 .76 .251 r
.30048 .59008 m .30002 .59241 L .30071 .59008 L F
.30048 .59008 m .30071 .59008 L .30073 .58999 L F
.959 .732 .552 r
.24472 .54322 m .24458 .545 L .24208 .54611 L F
.24458 .545 m .24472 .54322 L .24747 .54322 L F
.076 .632 .807 r
.28234 .68632 m .28509 .68647 L .28459 .68631 L F
.465 .89 .87 r
.28459 .68631 m .28509 .68647 L .28698 .68536 L F
.329 .812 .799 r
.28637 .55164 m .28546 .55223 L .28805 .55225 L F
.28637 .55164 m .28422 .55239 L .28546 .55223 L F
.505 .344 .597 r
.34317 .56739 m .34088 .57072 L .34104 .56811 L F
0 0 0 r
.28562 .61468 m .28711 .61238 L .28675 .61291 L F
.28593 .61416 m .28675 .61291 L .28806 .61215 L F
.708 .958 .693 r
.28675 .61291 m .28386 .61601 L .28562 .61468 L F
0 0 0 r
.28511 .61494 m .28675 .61291 L .28593 .61416 L F
.28711 .61238 m .28788 .61118 L .28675 .61291 L F
.328 .082 .38 r
.35415 .61372 m .35629 .61449 L .35667 .6115 L F
.504 .322 .567 r
.35415 .61372 m .35716 .61627 L .35629 .61449 L F
.35415 .61372 m .3536 .61745 L .35716 .61627 L F
.277 0 0 r
.17606 .59747 m .17766 .598 L .17928 .59864 L F
.17766 .598 m .18187 .59938 L .17928 .59864 L F
.666 .118 0 r
.18187 .59938 m .18148 .60055 L .17928 .59864 L F
0 .229 .744 r
.17928 .59864 m .18148 .60055 L .18045 .5991 L F
.17928 .59864 m .18045 .5991 L .17836 .59615 L F
.277 0 0 r
.17606 .59747 m .17928 .59864 L .17712 .59614 L F
.636 .198 .192 r
.26857 .64236 m .27263 .64198 L .27093 .64395 L F
.316 0 0 r
.27093 .64395 m .27263 .64198 L .27172 .64346 L F
.387 .225 .536 r
.3146 .54466 m .3179 .54193 L .31583 .54307 L F
.476 .489 .792 r
.3535 .58193 m .35638 .58289 L .35414 .5834 L F
.338 .204 .547 r
.35611 .58561 m .35414 .5834 L .35638 .58289 L F
.35611 .58561 m .35431 .58636 L .35414 .5834 L F
.312 .413 .804 r
.31591 .6655 m .31739 .6631 L .31587 .66219 L F
.209 .003 .366 r
.38161 .5953 m .37949 .59878 L .37993 .59632 L F
.698 .957 .698 r
.36834 .53913 m .36753 .54078 L .36967 .53961 L F
.36834 .53913 m .36581 .54176 L .36753 .54078 L F
.923 .747 .261 r
.30002 .59241 m .29986 .59503 L .30028 .59431 L F
.947 .87 .729 r
.29802 .59871 m .30028 .59431 L .29986 .59503 L F
.228 0 .151 r
.21529 .56115 m .21175 .5645 L .21308 .56184 L F
0 0 0 r
.26497 .62111 m .26164 .62338 L .26308 .62296 L F
.26688 .62 m .26497 .62111 L .26308 .62296 L F
.428 0 0 r
.25419 .62416 m .25605 .62488 L .2524 .62317 L F
.425 .85 .952 r
.25645 .62402 m .25605 .62488 L .25419 .62416 L F
.25645 .62402 m .25832 .6243 L .25605 .62488 L F
.171 0 .009 r
.34484 .60438 m .34518 .60293 L .34208 .60513 L F
.368 .819 .939 r
.34484 .60438 m .34208 .60513 L .34518 .60293 L F
.656 .537 .707 r
.34505 .5996 m .34518 .60293 L .34743 .59904 L F
.644 .171 .115 r
.34684 .60487 m .34518 .60293 L .34484 .60438 L F
.34484 .60438 m .34518 .60293 L .34684 .60487 L F
.403 .144 .403 r
.32447 .65544 m .32613 .65721 L .32647 .65461 L F
.32447 .65544 m .3238 .65783 L .32613 .65721 L F
.448 .216 .469 r
.38631 .58623 m .38366 .58935 L .38391 .58678 L F
.981 .758 .53 r
.52764 .53614 m .52739 .53926 L .52901 .53851 L F
.575 .097 .082 r
.52739 .53926 m .53153 .53913 L .52901 .53851 L F
.753 .56 .635 r
.34168 .64888 m .33908 .65173 L .33921 .64901 L F
0 .327 .694 r
.29277 .64721 m .29372 .64749 L .29186 .64644 L F
.29277 .64721 m .29548 .64838 L .29372 .64749 L F
.137 .509 .911 r
.29277 .64721 m .29654 .64933 L .29548 .64838 L F
.488 .259 .492 r
.35346 .55232 m .35641 .55196 L .35607 .54918 L F
.728 .429 .472 r
.35142 .55166 m .35641 .55196 L .35607 .54918 L F
.43 .31 .615 r
.35809 .54579 m .35864 .549 L .35607 .54918 L F
0 0 .153 r
.35607 .54918 m .35636 .5503 L .35864 .549 L F
.135 .108 .56 r
.35944 .54685 m .35864 .549 L .35809 .54579 L F
.833 .808 .826 r
.35717 .54744 m .35636 .5503 L .35944 .54685 L F
.876 .935 .855 r
.35944 .54685 m .35636 .5503 L .35864 .549 L F
.655 .268 .299 r
.35944 .54685 m .35876 .54942 L .35717 .54744 L F
0 0 .462 r
.35717 .54744 m .35766 .54794 L .35732 .54732 L F
0 0 0 r
.35704 .54754 m .35717 .54744 L .35809 .54579 L F
.496 .018 .05 r
.35809 .54579 m .35717 .54744 L .35944 .54685 L F
.879 .993 .782 r
.35717 .54744 m .35651 .54581 L .35884 .54509 L F
0 0 .462 r
.35717 .54744 m .35732 .54732 L .35651 .54581 L F
0 0 0 r
.35607 .54918 m .35717 .54744 L .35704 .54754 L F
0 0 .153 r
.35607 .54918 m .35636 .5503 L .35717 .54744 L F
.35607 .54918 m .35641 .55196 L .35636 .5503 L F
.35607 .54918 m .35641 .55196 L .35636 .5503 L F
.125 .616 .911 r
.23462 .63013 m .23631 .63024 L .23237 .62912 L F
.657 .337 .42 r
.32234 .62991 m .32439 .63241 L .32076 .63249 L F
.474 .578 .879 r
.31337 .58522 m .31228 .58821 L .31129 .58598 L F
.31337 .58522 m .31514 .58839 L .31228 .58821 L F
.409 .73 .991 r
.37622 .5361 m .37694 .53446 L .37426 .53464 L F
.37622 .5361 m .37851 .53585 L .37694 .53446 L F
.753 .56 .635 r
.34168 .64888 m .34321 .65201 L .33908 .65173 L F
.475 .839 .992 r
.34837 .66154 m .34448 .66149 L .34712 .66078 L F
.667 .437 .562 r
.33664 .6576 m .33409 .65524 L .33671 .65496 L F
.33664 .6576 m .33399 .65807 L .33409 .65524 L F
.999 .842 .526 r
.36972 .60874 m .36912 .61144 L .36859 .609 L F
.985 .899 .584 r
.36893 .6069 m .36896 .60785 L .36972 .60874 L F
.463 .287 .556 r
.36465 .55867 m .36697 .56085 L .36707 .55774 L F
.36465 .55867 m .36466 .56166 L .36697 .56085 L F
.55 .311 .506 r
.35863 .5639 m .35983 .5654 L .36199 .56408 L F
.35863 .5639 m .35796 .56621 L .35983 .5654 L F
.374 0 .056 r
.35542 .62106 m .35827 .62092 L .35934 .61972 L F
.479 .409 .7 r
.51383 .54326 m .51509 .5392 L .51256 .53943 L F
.51383 .54326 m .51599 .54216 L .51509 .5392 L F
.56 .325 .517 r
.51327 .54541 m .51599 .54216 L .51383 .54326 L F
.424 .085 .285 r
.51063 .54572 m .51327 .54541 L .51383 .54326 L F
.3 .351 .748 r
.3429 .61444 m .34401 .61652 L .34137 .61473 L F
.696 .311 .314 r
.24263 .7484 m .24744 .74837 L .24556 .75081 L F
.622 .381 .531 r
.24744 .74837 m .24949 .75117 L .24556 .75081 L F
.24744 .74837 m .2499 .74841 L .24949 .75117 L F
.573 .709 .934 r
.28305 .56051 m .28422 .56203 L .28583 .56077 L F
.241 .126 .515 r
.28583 .56077 m .28434 .56451 L .28422 .56203 L F
.28583 .56077 m .28434 .56451 L .28422 .56203 L F
0 0 0 r
.36984 .56789 m .36772 .57131 L .36888 .56974 L F
.195 .006 .381 r
.36603 .57315 m .36888 .56974 L .36772 .57131 L F
0 0 .506 r
.4006 .55321 m .39891 .55256 L .39844 .55114 L F
.4006 .55321 m .3994 .5552 L .39891 .55256 L F
0 0 .474 r
.36319 .53757 m .36449 .53808 L .36555 .5357 L F
.37 .091 .354 r
.36352 .6299 m .36054 .63299 L .36107 .63048 L F
.369 .28 .623 r
.32553 .64563 m .32778 .64799 L .32735 .64517 L F
.32553 .64563 m .326 .64882 L .32778 .64799 L F
.597 .535 .756 r
.33664 .6576 m .33548 .66194 L .33399 .65807 L F
.33664 .6576 m .33792 .66122 L .33548 .66194 L F
.649 .828 .969 r
.31187 .5275 m .30943 .52858 L .3079 .52731 L F
.603 .333 .48 r
.34732 .58394 m .35181 .58383 L .35132 .58288 L F
.34732 .58394 m .34742 .58639 L .35181 .58383 L F
.648 .806 .367 r
.35389 .62456 m .35272 .62664 L .35441 .62354 L F
.389 .801 .979 r
.28726 .52733 m .28662 .52851 L .28495 .52771 L F
.28726 .52733 m .28906 .52811 L .28662 .52851 L F
.126 .371 .83 r
.19792 .60799 m .19873 .60679 L .19515 .6056 L F
.19792 .60799 m .19899 .60811 L .19873 .60679 L F
.449 .857 .688 r
.35045 .66632 m .35258 .66525 L .3545 .66401 L F
.286 .338 .741 r
.38199 .52582 m .38064 .52825 L .37984 .52545 L F
.504 .613 .894 r
.38199 .52582 m .38404 .52894 L .38064 .52825 L F
.523 0 0 r
.24458 .545 m .24649 .54615 L .24849 .5462 L F
.243 0 0 r
.24649 .54615 m .25086 .5457 L .24849 .5462 L F
.663 .775 .932 r
.52715 .56026 m .53041 .56089 L .52953 .55921 L F
.76 .889 .936 r
.52953 .55921 m .53041 .56089 L .53369 .55876 L F
.512 .6 .878 r
.36489 .56416 m .36647 .56622 L .3685 .56535 L F
.208 .491 .9 r
.1935 .60527 m .19515 .6056 L .19389 .60366 L F
.17 .448 .877 r
.19389 .60366 m .19473 .60544 L .1935 .60527 L F
0 .52 .798 r
.1935 .60527 m .19473 .60544 L .18846 .604 L F
.184 .299 .749 r
.3546 .60291 m .3569 .60483 L .35716 .60248 L F
.3546 .60291 m .3556 .60491 L .3569 .60483 L F
.078 0 0 r
.21111 .54532 m .2134 .54478 L .21549 .54338 L F
.169 0 0 r
.2134 .54478 m .21746 .5423 L .21549 .54338 L F
.332 .657 .971 r
.28295 .68495 m .28234 .68632 L .28459 .68631 L F
.698 .778 .914 r
.32346 .62121 m .3215 .62059 L .32171 .62123 L F
.798 .441 .381 r
.32226 .6228 m .32346 .62121 L .32171 .62123 L F
.346 0 0 r
.32429 .62243 m .32346 .62121 L .32226 .6228 L F
.32429 .62243 m .3262 .621 L .32346 .62121 L F
.484 .843 .993 r
.34252 .54068 m .34146 .5422 L .33974 .5394 L F
.34252 .54068 m .34381 .54144 L .34146 .5422 L F
.054 .574 .873 r
.22399 .6137 m .22602 .61399 L .22781 .61481 L F
.699 .905 .969 r
.22781 .61481 m .22831 .61273 L .2303 .61394 L F
.22781 .61481 m .22602 .61399 L .22831 .61273 L F
.532 .203 .356 r
.29526 .54498 m .29265 .54545 L .2932 .54325 L F
.507 .211 .398 r
.29563 .54294 m .29526 .54498 L .2932 .54325 L F
.205 0 0 r
.3146 .54466 m .31331 .54724 L .31095 .54771 L F
.166 .057 .476 r
.31379 .5492 m .31548 .5484 L .3146 .54466 L F
.387 .476 .829 r
.31598 .54052 m .3146 .54466 L .31394 .54029 L F
.387 .225 .536 r
.3146 .54466 m .31784 .54512 L .31786 .54446 L F
.31577 .54369 m .31786 .54446 L .3179 .54193 L F
.3146 .54466 m .31786 .54446 L .31577 .54369 L F
.547 .288 .474 r
.3146 .54466 m .31798 .54777 L .31784 .54512 L F
.3146 .54466 m .31548 .5484 L .31798 .54777 L F
.502 .351 .608 r
.31786 .54446 m .32076 .54104 L .3179 .54193 L F
.31784 .54512 m .31823 .54458 L .31786 .54446 L F
.31826 .54454 m .32023 .54451 L .32063 .54186 L F
.31826 .54454 m .32063 .54186 L .32058 .5413 L F
.31819 .54457 m .32076 .54104 L .31786 .54446 L F
.31826 .54454 m .32076 .54104 L .31819 .54457 L F
.528 .776 .988 r
.3179 .54193 m .32076 .54104 L .32027 .54097 L F
0 0 .147 r
.32066 .54173 m .32066 .54209 L .32061 .54164 L F
0 0 .182 r
.32076 .54104 m .32087 .54333 L .32066 .54173 L F
.32076 .54104 m .32063 .54186 L .32087 .54333 L F
.45 0 0 r
.3203 .54495 m .32028 .54466 L .32063 .54388 L F
.673 .526 .677 r
.32023 .54451 m .32027 .54453 L .32026 .54444 L F
.45 0 0 r
.32016 .54492 m .32037 .54395 L .32063 .54388 L F
0 0 .337 r
.32087 .54333 m .32102 .54487 L .32063 .54388 L F
.673 .526 .677 r
.32026 .54494 m .3204 .54675 L .32108 .54492 L F
.531 .418 .67 r
.31798 .54777 m .31996 .5449 L .31784 .54512 L F
.31996 .5449 m .3192 .54477 L .31784 .54512 L F
.45 0 0 r
.32011 .54495 m .31935 .5448 L .32011 .54493 L F
.31935 .5448 m .31819 .54457 L .31934 .54479 L F
.31935 .5448 m .31934 .54479 L .32011 .54493 L F
.531 .418 .67 r
.31996 .5449 m .32023 .54451 L .3193 .54475 L F
.31996 .5449 m .3193 .54475 L .31935 .5448 L F
.45 0 0 r
.31956 .54482 m .31819 .54457 L .31828 .54454 L F
.32011 .54493 m .31957 .54483 L .31956 .54482 L F
.31957 .54483 m .31819 .54457 L .31956 .54482 L F
.531 .418 .67 r
.31798 .54777 m .32044 .5472 L .3204 .54675 L F
.31974 .54522 m .3204 .54675 L .32026 .54494 L F
.31798 .54777 m .3204 .54675 L .31974 .54522 L F
.502 .351 .608 r
.31823 .54458 m .3193 .54475 L .31826 .54454 L F
.31784 .54512 m .3192 .54477 L .31823 .54458 L F
.45 0 0 r
.31935 .5448 m .3192 .54477 L .31819 .54457 L F
.3192 .54477 m .31823 .54458 L .31819 .54457 L F
.502 .351 .608 r
.3192 .54477 m .3193 .54475 L .31823 .54458 L F
.45 0 0 r
.3192 .54477 m .31843 .54464 L .31823 .54458 L F
.32019 .54533 m .31532 .54642 L .318 .54461 L F
.31841 .54467 m .318 .54461 L .31809 .54455 L F
.32019 .54533 m .318 .54461 L .31841 .54467 L F
.531 .418 .67 r
.31996 .5449 m .32026 .54494 L .32023 .54451 L F
.31974 .54522 m .32026 .54494 L .31996 .5449 L F
.31935 .5448 m .3193 .54475 L .3192 .54477 L F
.45 0 0 r
.32011 .54495 m .31945 .54497 L .31843 .54464 L F
.32011 .54495 m .31843 .54464 L .31935 .5448 L F
.32105 .54513 m .32042 .54527 L .31945 .54497 L F
.32105 .54513 m .31945 .54497 L .32011 .54495 L F
.673 .526 .677 r
.32108 .54492 m .3204 .54675 L .32358 .54612 L F
.32023 .54451 m .32026 .54494 L .32108 .54492 L F
.3204 .54675 m .32044 .5472 L .32047 .54718 L F
.3204 .54675 m .32047 .54718 L .32358 .54612 L F
.45 0 0 r
.32105 .54513 m .32011 .54495 L .32011 .54493 L F
0 0 .337 r
.32102 .54487 m .32105 .54513 L .32096 .54485 L F
.32102 .54487 m .32096 .54485 L .32063 .54388 L F
.45 0 0 r
.32104 .54509 m .3203 .54495 L .32041 .54459 L F
.32096 .54485 m .32041 .54459 L .32063 .54388 L F
.673 .526 .677 r
.32023 .54451 m .32083 .5448 L .32091 .54482 L F
.32023 .54451 m .32091 .54482 L .32027 .54453 L F
.45 0 0 r
.32104 .54509 m .32041 .54459 L .32096 .54485 L F
.673 .526 .677 r
.32027 .54453 m .32091 .54482 L .32135 .54494 L F
.32083 .5448 m .32358 .54612 L .32156 .54505 L F
.32102 .54487 m .32156 .54505 L .32135 .54494 L F
0 0 .337 r
.32102 .54487 m .32135 .54494 L .32105 .54513 L F
.32087 .54333 m .32135 .54494 L .32102 .54487 L F
.673 .526 .677 r
.32083 .5448 m .32102 .54487 L .32135 .54494 L F
.32026 .54444 m .32135 .54494 L .32087 .54333 L F
.32027 .54453 m .32135 .54494 L .32026 .54444 L F
.45 0 0 r
.3203 .54495 m .32016 .54492 L .32028 .54466 L F
.502 .351 .608 r
.3193 .54475 m .32023 .54451 L .31826 .54454 L F
.45 0 0 r
.32016 .54492 m .31828 .54454 L .32037 .54395 L F
0 0 .182 r
.32063 .54186 m .32023 .54451 L .32026 .54444 L F
.32049 .54336 m .32026 .54444 L .32042 .54416 L F
.32063 .54186 m .32037 .54394 L .32053 .54302 L F
.47 .336 .616 r
.32027 .54097 m .32053 .54302 L .31796 .54452 L F
.32053 .54302 m .32063 .54388 L .32037 .54394 L F
0 0 .182 r
.32063 .54186 m .32026 .54444 L .32037 .54394 L F
.47 .336 .616 r
.32053 .54302 m .32037 .54394 L .31796 .54452 L F
0 0 .182 r
.32053 .54302 m .32037 .54394 L .32049 .54336 L F
0 0 .147 r
.32061 .54206 m .32063 .54388 L .32053 .54302 L F
.32066 .54209 m .32063 .54388 L .32061 .54164 L F
.45 0 0 r
.31819 .54457 m .31876 .54433 L .32037 .54394 L F
.32037 .54395 m .32037 .54394 L .32063 .54388 L F
.31819 .54457 m .32037 .54394 L .32037 .54395 L F
0 0 .147 r
.32066 .54173 m .32087 .54333 L .32063 .54388 L F
0 0 .182 r
.32071 .54234 m .32042 .54416 L .32087 .54333 L F
.32063 .54186 m .32049 .54336 L .32071 .54234 L F
.32049 .54336 m .32042 .54416 L .32071 .54234 L F
0 0 .147 r
.32061 .54164 m .32061 .54206 L .32027 .54097 L F
.32061 .54206 m .32053 .54302 L .32027 .54097 L F
.74 .588 .686 r
.32076 .54104 m .32066 .54173 L .32061 .54164 L F
.502 .351 .608 r
.32058 .5413 m .32061 .54164 L .32076 .54104 L F
.74 .588 .686 r
.32076 .54104 m .32061 .54164 L .32027 .54097 L F
.502 .351 .608 r
.32061 .54164 m .32063 .54186 L .32076 .54104 L F
.45 0 0 r
.32105 .54513 m .31828 .54454 L .32104 .54509 L F
.31819 .54457 m .31796 .54452 L .31876 .54433 L F
.502 .351 .608 r
.31823 .54458 m .31826 .54454 L .31819 .54457 L F
.45 0 0 r
.31819 .54457 m .32019 .54533 L .31809 .54455 L F
.32042 .54527 m .32019 .54533 L .31819 .54457 L F
.31809 .54455 m .31532 .54642 L .31796 .54452 L F
.387 .476 .829 r
.31598 .54052 m .31796 .54452 L .3146 .54466 L F
.039 0 0 r
.31532 .54642 m .3146 .54466 L .31796 .54452 L F
.31532 .54642 m .31331 .54724 L .3146 .54466 L F
.482 .398 .685 r
.17369 .59009 m .17579 .5896 L .17544 .58603 L F
.481 .393 .679 r
.17369 .59009 m .1763 .59194 L .17579 .5896 L F
.322 .511 .886 r
.36984 .56789 m .37145 .56649 L .3685 .56535 L F
.485 .297 .55 r
.36888 .56974 m .37145 .56649 L .36984 .56789 L F
.837 .63 .623 r
.22181 .55799 m .21791 .56018 L .21979 .55708 L F
.22181 .55799 m .2217 .56167 L .21791 .56018 L F
.519 .806 .998 r
.21979 .55708 m .22181 .55799 L .22294 .55662 L F
.527 .249 .437 r
.21979 .55708 m .22294 .55662 L .22181 .55799 L F
.329 0 .088 r
.22417 .56048 m .22626 .56022 L .22396 .56063 L F
.22786 .55794 m .22626 .56022 L .22417 .56048 L F
.725 .347 .334 r
.2303 .56054 m .22626 .56022 L .22786 .55794 L F
.715 .228 .085 r
.22858 .55996 m .22853 .55994 L .22626 .56022 L F
.422 .284 .587 r
.22396 .56063 m .22171 .56132 L .22181 .55799 L F
.764 .669 .758 r
.22235 .55925 m .22626 .56022 L .22515 .5562 L F
.983 .759 .521 r
.22515 .5562 m .22626 .56022 L .22453 .55875 L F
.715 .228 .085 r
.22853 .55994 m .22453 .55875 L .22626 .56022 L F
.507 .769 .99 r
.22396 .56063 m .22626 .56022 L .22571 .56009 L F
.22396 .56063 m .22571 .56009 L .22235 .55925 L F
.422 .284 .587 r
.22396 .56063 m .2217 .56167 L .22171 .56132 L F
.576 .433 .65 r
.33908 .65173 m .33671 .65496 L .33651 .65219 L F
.963 .805 .639 r
.22467 .62768 m .22386 .63045 L .22219 .62894 L F
.155 .436 .871 r
.22189 .6246 m .22467 .62768 L .2246 .6258 L F
.343 .791 .641 r
.22467 .62768 m .22488 .62754 L .2246 .6258 L F
.965 .666 .411 r
.30749 .5986 m .30952 .60172 L .30765 .59927 L F
.096 .409 .86 r
.30765 .59927 m .30952 .60172 L .31109 .60232 L F
.787 .288 0 r
.35272 .5798 m .35638 .58289 L .3535 .58193 L F
.525 .569 .842 r
.3609 .58716 m .36171 .5887 L .36409 .5883 L F
.274 .278 .682 r
.38326 .59141 m .38423 .59503 L .38201 .59286 L F
.553 .298 .483 r
.38201 .59286 m .38423 .59503 L .38161 .5953 L F
.38201 .59286 m .38423 .59503 L .38161 .5953 L F
.397 .486 .834 r
.29181 .64255 m .28894 .63988 L .29004 .63889 L F
0 0 .399 r
.35203 .56788 m .35307 .56984 L .35171 .56668 L F
0 .17 .696 r
.3556 .60491 m .3578 .60731 L .3569 .60483 L F
.859 .786 .778 r
.2901 .55109 m .29449 .5493 L .29262 .548 L F
.2901 .55109 m .29213 .55277 L .29449 .5493 L F
.887 .804 .761 r
.35448 .63549 m .35704 .63675 L .35808 .63325 L F
0 0 0 r
.35385 .63809 m .35704 .63675 L .35448 .63549 L F
.35385 .63809 m .35763 .63732 L .35704 .63675 L F
.548 .594 .852 r
.35707 .6608 m .35468 .66139 L .35314 .65804 L F
0 .234 .625 r
.37831 .56268 m .38144 .56439 L .37913 .56518 L F
.243 .681 .959 r
.25567 .63554 m .2553 .6343 L .25284 .63487 L F
.25567 .63554 m .25733 .63544 L .2553 .6343 L F
0 0 .272 r
.33536 .63982 m .33596 .64254 L .33563 .64181 L F
.308 .191 .553 r
.32671 .63632 m .32851 .63844 L .32798 .63589 L F
.32671 .63632 m .32684 .63903 L .32851 .63844 L F
.206 .086 .487 r
.33444 .61472 m .33654 .61646 L .33639 .61346 L F
.33444 .61472 m .33447 .61719 L .33654 .61646 L F
.828 .839 .856 r
.29959 .57939 m .30203 .58055 L .30412 .57798 L F
.981 .788 .573 r
.29983 .58102 m .30203 .58055 L .29959 .57939 L F
.29983 .58102 m .30147 .58299 L .30203 .58055 L F
0 0 0 r
.3014 .57352 m .30397 .56958 L .30265 .57119 L F
0 .409 .841 r
.30166 .54075 m .3025 .54006 L .29985 .54048 L F
.30166 .54075 m .30422 .54175 L .3025 .54006 L F
0 0 .291 r
.31052 .56951 m .30853 .57346 L .3085 .57148 L F
.38 0 .179 r
.27101 .55506 m .26859 .5577 L .26635 .55811 L F
.593 .245 .35 r
.27264 .55678 m .27101 .55506 L .27279 .55534 L F
.27264 .55678 m .26859 .5577 L .27101 .55506 L F
.073 .598 .872 r
.208 .61549 m .20655 .61497 L .20468 .61474 L F
.208 0 0 r
.21112 .61628 m .20655 .61497 L .208 .61549 L F
.771 .725 .81 r
.39155 .5646 m .38924 .56757 L .38966 .56595 L F
.534 .384 .624 r
.39155 .5646 m .39187 .56708 L .38924 .56757 L F
.63 .778 .952 r
.31576 .52827 m .31187 .5275 L .31426 .52673 L F
.528 .64 .904 r
.31668 .52566 m .31576 .52827 L .31426 .52673 L F
.31668 .52566 m .31821 .52788 L .31576 .52827 L F
.901 .509 .263 r
.20145 .58211 m .2018 .58472 L .20527 .58591 L F
.896 .876 .809 r
.2018 .58472 m .20152 .58897 L .20527 .58591 L F
.71 .319 .305 r
.30422 .64156 m .30052 .63952 L .30121 .6426 L F
.433 .259 .544 r
.28918 .5992 m .2915 .59851 L .29155 .59575 L F
.343 .126 .433 r
.28918 .5992 m .29088 .60091 L .2915 .59851 L F
.28918 .5992 m .28884 .60181 L .29088 .60091 L F
.012 .111 .623 r
.31128 .6112 m .31201 .61457 L .31312 .61309 L F
.104 .134 .607 r
.31238 .61724 m .31312 .61309 L .31201 .61457 L F
.077 .349 .822 r
.29654 .64933 m .29795 .64896 L .29548 .64838 L F
.29654 .64933 m .29913 .65125 L .29795 .64896 L F
.289 .194 .57 r
.3555 .55414 m .35346 .55232 L .35641 .55196 L F
.3555 .55414 m .3539 .55515 L .35346 .55232 L F
.823 .857 .873 r
.35034 .63573 m .35044 .6333 L .35173 .63333 L F
.412 .822 .976 r
.28048 .52742 m .28014 .52858 L .27834 .52778 L F
.28048 .52742 m .28247 .52813 L .28014 .52858 L F
.668 .823 .958 r
.30045 .55185 m .2992 .55053 L .29934 .54874 L F
.436 .644 .945 r
.3409 .6699 m .34171 .66813 L .33892 .66827 L F
.3409 .6699 m .34326 .67051 L .34171 .66813 L F
.775 .653 .728 r
.35138 .62014 m .35542 .62106 L .3536 .61745 L F
0 0 0 r
.35441 .62354 m .35495 .6228 L .35542 .62106 L F
.733 .637 .752 r
.3536 .61745 m .35542 .62106 L .35782 .61789 L F
.013 0 0 r
.35542 .62106 m .35617 .62222 L .35827 .62092 L F
.35542 .62106 m .35495 .6228 L .35617 .62222 L F
.572 .524 .763 r
.50993 .55579 m .51126 .55129 L .50895 .55185 L F
.50993 .55579 m .51252 .55518 L .51126 .55129 L F
.55 .886 .633 r
.30338 .65478 m .30688 .65196 L .30573 .65445 L F
0 0 0 r
.30573 .65445 m .30688 .65196 L .30854 .65088 L F
.201 0 0 r
.25832 .6243 m .26062 .62409 L .26164 .62338 L F
0 0 0 r
.26164 .62338 m .26062 .62409 L .26308 .62296 L F
.405 .348 .681 r
.34614 .62755 m .34685 .62931 L .34495 .63003 L F
.388 .217 .525 r
.34676 .63165 m .34495 .63003 L .34685 .62931 L F
.34676 .63165 m .34481 .63262 L .34495 .63003 L F
.998 .803 .458 r
.30916 .59497 m .30841 .59199 L .30899 .59224 L F
.045 0 0 r
.28884 .60181 m .28683 .60265 L .28567 .60394 L F
.592 .53 .754 r
.34796 .61784 m .34901 .62099 L .35138 .62014 L F
.622 .534 .734 r
.25606 .72995 m .25813 .72692 L .25565 .72731 L F
.311 .167 .519 r
.28201 .63022 m .27984 .63106 L .28171 .62938 L F
.28201 .63022 m .27979 .63229 L .27984 .63106 L F
.514 .249 .451 r
.27081 .55089 m .27363 .54841 L .27155 .54976 L F
.446 .376 .684 r
.27143 .54724 m .27155 .54976 L .27363 .54841 L F
.501 .797 .998 r
.3395 .64336 m .33814 .6451 L .33596 .64254 L F
.3395 .64336 m .33998 .64449 L .33814 .6451 L F
.266 .454 .859 r
.19899 .60811 m .20101 .61141 L .20194 .60951 L F
.134 .287 .755 r
.20101 .61141 m .20312 .61312 L .20194 .60951 L F
0 0 .026 r
.28211 .62486 m .28187 .62398 L .28159 .62253 L F
.28211 .62486 m .28159 .62655 L .28187 .62398 L F
.578 .387 .586 r
.26757 .72355 m .26767 .72655 L .26496 .72666 L F
.26757 .72355 m .26767 .72655 L .26496 .72666 L F
.438 .797 .996 r
.26803 .72222 m .26994 .72321 L .26757 .72355 L F
.396 .247 .559 r
.26958 .72576 m .26757 .72355 L .26994 .72321 L F
.26757 .72355 m .26958 .72576 L .26803 .72222 L F
.26757 .72355 m .26767 .72655 L .26958 .72576 L F
.26958 .72576 m .26767 .72655 L .26757 .72355 L F
.031 0 0 r
.18952 .56113 m .19123 .56071 L .19269 .5586 L F
.114 0 0 r
.19269 .5586 m .19323 .55994 L .19432 .55767 L F
.19269 .5586 m .19123 .56071 L .19323 .55994 L F
.797 .309 .041 r
.33038 .53573 m .33163 .53766 L .33377 .53753 L F
.884 .988 .807 r
.33377 .53753 m .33326 .53454 L .33706 .5378 L F
.33377 .53753 m .33163 .53766 L .33326 .53454 L F
.677 .31 .344 r
.32289 .66758 m .32662 .66758 L .32639 .66914 L F
.612 .251 .333 r
.32662 .66758 m .32889 .6696 L .32639 .66914 L F
.29 0 .254 r
.19526 .55558 m .19432 .55767 L .19732 .55487 L F
.68 .621 .783 r
.2676 .54564 m .27143 .54724 L .26989 .54539 L F
.245 .416 .834 r
.27143 .54724 m .27236 .54567 L .26989 .54539 L F
.27143 .54724 m .27363 .54841 L .27236 .54567 L F
.312 0 .084 r
.26355 .54538 m .25952 .54824 L .26126 .5455 L F
.466 .242 .488 r
.33389 .58041 m .33367 .58323 L .33095 .58417 L F
.219 .044 .418 r
.33531 .58206 m .33389 .58041 L .33581 .57967 L F
.33531 .58206 m .33367 .58323 L .33389 .58041 L F
0 0 0 r
.22775 .62999 m .22672 .63013 L .22386 .63045 L F
.505 .811 1 r
.22775 .62999 m .23033 .62969 L .22852 .62867 L F
0 0 0 r
.29095 .52767 m .29549 .5264 L .29292 .52777 L F
.296 .498 .885 r
.31109 .60232 m .31319 .60526 L .31444 .6041 L F
0 0 .366 r
.31319 .60526 m .31455 .60618 L .31444 .6041 L F
.31319 .60526 m .3131 .60792 L .31455 .60618 L F
.767 .622 .699 r
.34228 .63501 m .34263 .63718 L .33921 .6358 L F
.751 .284 .138 r
.34263 .63718 m .34136 .63812 L .33921 .6358 L F
.489 .373 .647 r
.34481 .63262 m .34263 .63718 L .34228 .63501 L F
.34481 .63262 m .34525 .63657 L .34263 .63718 L F
.526 .539 .812 r
.34525 .63657 m .34532 .63796 L .34263 .63718 L F
.362 .112 .393 r
.38902 .58297 m .38631 .58623 L .38654 .58357 L F
.344 .059 .329 r
.34313 .64147 m .34426 .64364 L .3454 .64109 L F
.083 .061 .532 r
.34426 .64364 m .34478 .64189 L .3454 .64109 L F
.107 0 0 r
.34613 .64017 m .3454 .64109 L .34313 .64147 L F
.34646 .64003 m .3454 .64109 L .34313 .64147 L F
.453 .581 .892 r
.34313 .64147 m .3454 .64109 L .34317 .6382 L F
0 .211 .732 r
.3454 .64109 m .34535 .63993 L .34317 .6382 L F
.083 .061 .532 r
.34478 .64189 m .34535 .63993 L .3454 .64109 L F
.107 0 0 r
.34646 .64003 m .3454 .64109 L .34613 .64017 L F
.567 .627 .871 r
.34863 .63857 m .34646 .64003 L .34532 .63796 L F
.495 .475 .764 r
.34863 .63857 m .3488 .64121 L .34646 .64003 L F
.655 .324 .4 r
.34646 .64003 m .3488 .64121 L .34626 .64039 L F
.346 .166 .488 r
.17664 .57397 m .1785 .5733 L .17873 .57074 L F
.43 .28 .575 r
.17647 .57662 m .1785 .5733 L .17664 .57397 L F
.595 .327 .481 r
.26225 .5546 m .26487 .55466 L .26259 .5523 L F
.615 .326 .455 r
.26259 .5523 m .26487 .55466 L .26528 .55229 L F
.692 .442 .54 r
.30422 .64156 m .3074 .64243 L .30766 .63946 L F
.558 .4 .623 r
.30766 .63946 m .30989 .63908 L .31023 .63619 L F
.407 .2 .484 r
.30766 .63946 m .30952 .64156 L .30989 .63908 L F
.30766 .63946 m .3074 .64243 L .30952 .64156 L F
0 0 0 r
.24628 .53188 m .25041 .53101 L .24819 .5314 L F
.622 .534 .734 r
.25606 .72995 m .25832 .72884 L .25813 .72692 L F
.323 .551 .916 r
.21141 .59528 m .21081 .59714 L .20898 .5957 L F
.21141 .59528 m .21366 .5981 L .21081 .59714 L F
.145 .492 .904 r
.38067 .52411 m .37984 .52545 L .37775 .52529 L F
.38067 .52411 m .38199 .52582 L .37984 .52545 L F
.837 .55 .504 r
.31988 .66977 m .31802 .66691 L .32026 .66749 L F
.6 .336 .488 r
.32026 .66749 m .32254 .66981 L .31988 .66977 L F
.634 .332 .442 r
.32289 .66758 m .32254 .66981 L .32026 .66749 L F
.394 0 0 r
.26496 .72666 m .26767 .72655 L .26654 .72762 L F
.26654 .72762 m .26767 .72655 L .26496 .72666 L F
.26496 .72666 m .26767 .72655 L .26654 .72762 L F
.638 .145 .065 r
.32819 .62278 m .3262 .621 L .32429 .62243 L F
.491 .207 .41 r
.32819 .62278 m .3287 .62054 L .3262 .621 L F
.7 .504 .62 r
.34321 .65201 m .3393 .65466 L .33908 .65173 L F
.34321 .65201 m .34299 .65476 L .3393 .65466 L F
.688 .832 .952 r
.32236 .52801 m .31821 .52788 L .32072 .52715 L F
.72 .893 .959 r
.32476 .52677 m .32236 .52801 L .32072 .52715 L F
.306 .329 .721 r
.30843 .62961 m .30918 .63365 L .31066 .632 L F
.274 .282 .686 r
.30918 .63365 m .31163 .63585 L .31066 .632 L F
.22 .275 .707 r
.30918 .63365 m .31023 .63619 L .31163 .63585 L F
.041 .127 .628 r
.38728 .53029 m .38883 .53309 L .38801 .53399 L F
0 0 .337 r
.38883 .53309 m .3892 .53636 L .38801 .53399 L F
.248 0 .186 r
.34484 .60438 m .34208 .60513 L .34167 .60693 L F
.26 .414 .827 r
.23189 .75224 m .23443 .7543 L .23423 .75153 L F
.446 .057 .206 r
.3603 .54485 m .36338 .54311 L .36084 .54338 L F
.46 .086 .242 r
.36379 .54249 m .3603 .54485 L .36084 .54338 L F
.378 .217 .533 r
.33832 .57382 m .33831 .57677 L .33633 .57747 L F
.122 0 .26 r
.33746 .57865 m .33633 .57747 L .33831 .57677 L F
.33746 .57865 m .33581 .57967 L .33633 .57747 L F
.136 .366 .824 r
.29963 .52595 m .29919 .52817 L .29769 .52605 L F
.29963 .52595 m .30077 .52777 L .29919 .52817 L F
.615 .709 .912 r
.36932 .5217 m .36562 .52036 L .36763 .52014 L F
.441 .722 .985 r
.36986 .51974 m .36932 .5217 L .36763 .52014 L F
.36986 .51974 m .37169 .52126 L .36932 .5217 L F
0 0 .337 r
.38883 .53309 m .38941 .53486 L .3892 .53636 L F
.146 .493 .905 r
.38941 .53486 m .39069 .53645 L .3892 .53636 L F
.389 0 0 r
.38134 .56162 m .37953 .56334 L .37831 .56268 L F
.551 .847 .998 r
.38202 .55995 m .38134 .56162 L .38407 .56102 L F
.742 .932 .591 r
.38202 .55995 m .37953 .56334 L .38134 .56162 L F
.578 .388 .588 r
.38134 .56162 m .38144 .56439 L .38407 .56102 L F
0 0 .248 r
.31004 .64711 m .30922 .6458 L .31094 .64518 L F
.31004 .64711 m .3089 .64835 L .30922 .6458 L F
.53 .906 .953 r
.24511 .54376 m .24458 .545 L .24747 .54322 L F
.24511 .54376 m .24276 .54471 L .24458 .545 L F
0 .293 .791 r
.24458 .545 m .24511 .54376 L .24276 .54471 L F
.24458 .545 m .24649 .54615 L .24511 .54376 L F
.304 .767 .945 r
.26989 .54539 m .26584 .54513 L .2676 .54564 L F
.435 .852 .958 r
.26106 .53076 m .26159 .52978 L .26333 .5301 L F
.26106 .53076 m .25922 .53036 L .26159 .52978 L F
.027 .599 .732 r
.26721 .52952 m .26564 .52948 L .26964 .5295 L F
.355 0 0 r
.24187 .6225 m .24388 .62311 L .24573 .6232 L F
.106 0 0 r
.24573 .6232 m .24388 .62311 L .24796 .62343 L F
.279 .318 .724 r
.31379 .5492 m .31611 .55128 L .31548 .5484 L F
.569 .327 .509 r
.31337 .55163 m .31611 .55128 L .31379 .5492 L F
.915 .855 .769 r
.29814 .67697 m .29895 .67794 L .29997 .67619 L F
.237 .087 .466 r
.31128 .6112 m .31294 .61054 L .3131 .60792 L F
.012 .111 .623 r
.31128 .6112 m .31312 .61309 L .31294 .61054 L F
.606 .781 .964 r
.3536 .61745 m .35782 .61789 L .35716 .61627 L F
.024 0 0 r
.31079 .62374 m .30629 .62604 L .30871 .62568 L F
.356 0 0 r
.30962 .62496 m .31079 .62374 L .30871 .62568 L F
.30962 .62496 m .31328 .62392 L .31079 .62374 L F
.638 .481 .654 r
.31079 .62374 m .31328 .62392 L .31311 .62093 L F
.37 .091 .354 r
.36352 .6299 m .36274 .63238 L .36054 .63299 L F
.759 .664 .757 r
.35873 .63191 m .36274 .63238 L .36004 .6285 L F
0 0 0 r
.35965 .63033 m .35873 .63191 L .36004 .6285 L F
.77 .691 .776 r
.35965 .63033 m .35947 .63055 L .35873 .63191 L F
0 .13 .666 r
.35805 .63317 m .35873 .63191 L .35672 .62945 L F
.741 .292 .186 r
.35672 .62945 m .35873 .63191 L .35426 .63096 L F
.746 .303 .2 r
.35873 .63191 m .35712 .63344 L .35506 .63166 L F
.3551 .63114 m .35506 .63166 L .35426 .63096 L F
.35873 .63191 m .35506 .63166 L .3551 .63114 L F
.396 .57 .907 r
.35272 .62664 m .35672 .62945 L .35518 .62607 L F
.741 .292 .186 r
.35672 .62945 m .35426 .63096 L .35501 .628 L F
.307 .385 .779 r
.35426 .63096 m .35712 .63344 L .356 .62966 L F
0 0 .023 r
.356 .62966 m .35502 .63334 L .35493 .63345 L F
.35501 .63233 m .35493 .63345 L .35433 .63418 L F
.356 .62966 m .35493 .63345 L .35501 .63233 L F
.77 .691 .776 r
.35947 .63055 m .35712 .63344 L .35873 .63191 L F
0 .13 .666 r
.35808 .63325 m .35873 .63191 L .35805 .63317 L F
.447 .781 .998 r
.35808 .63325 m .36054 .63299 L .35873 .63191 L F
.592 .53 .754 r
.34796 .61784 m .35138 .62014 L .35241 .61834 L F
.524 .488 .759 r
.51126 .55129 m .50803 .54854 L .50895 .55185 L F
.006 .13 .644 r
.34727 .55524 m .34835 .55959 L .34844 .55538 L F
.34727 .55524 m .34844 .55538 L .34928 .55443 L F
.59 .534 .76 r
.34844 .55538 m .34752 .55824 L .34606 .55451 L F
.941 .933 .764 r
.34844 .55538 m .34622 .55972 L .34752 .55824 L F
.94 .929 .766 r
.34835 .55959 m .34622 .55972 L .34844 .55538 L F
.577 .226 .337 r
.35089 .55891 m .34757 .56015 L .34835 .55959 L F
.531 .576 .845 r
.33816 .55018 m .3361 .55117 L .336 .54875 L F
.674 .716 .88 r
.51896 .55745 m .52082 .55972 L .52283 .55831 L F
.203 0 0 r
.22668 .53707 m .22298 .53955 L .22509 .53867 L F
.02 0 0 r
.22698 .53764 m .22668 .53707 L .22509 .53867 L F
.22698 .53764 m .22898 .53655 L .22668 .53707 L F
.456 .695 .97 r
.20312 .61312 m .20468 .61474 L .20533 .61285 L F
.373 .603 .937 r
.20468 .61474 m .20655 .61497 L .20533 .61285 L F
.808 .616 .642 r
.23986 .74861 m .24066 .75086 L .23671 .75103 L F
.23986 .74861 m .23671 .75103 L .2392 .75065 L F
.549 .407 .641 r
.24084 .75053 m .24263 .7484 L .23986 .74861 L F
.094 .644 .821 r
.28532 .64522 m .28942 .64549 L .28727 .64523 L F
.271 .311 .72 r
.31238 .61724 m .31311 .62093 L .31442 .61897 L F
.319 .375 .763 r
.31311 .62093 m .31585 .62328 L .31442 .61897 L F
.519 .39 .644 r
.31328 .62392 m .31585 .62328 L .31311 .62093 L F
.13 0 .035 r
.18163 .56842 m .18263 .56915 L .18383 .56769 L F
.18163 .56842 m .18067 .57002 L .18263 .56915 L F
.522 .292 .507 r
.2499 .74841 m .25218 .75093 L .24949 .75117 L F
.484 .224 .444 r
.32917 .57693 m .33157 .5765 L .33182 .57414 L F
.03 .581 .828 r
.24446 .63452 m .2449 .63419 L .24252 .63455 L F
.24446 .63452 m .2471 .63476 L .2449 .63419 L F
0 .349 .781 r
.2471 .63476 m .24873 .6356 L .2473 .63439 L F
.2471 .63476 m .2473 .63439 L .24707 .63419 L F
0 .543 .801 r
.24446 .63452 m .24696 .63502 L .2471 .63476 L F
.24696 .63502 m .24899 .63542 L .2471 .63476 L F
.336 .774 .965 r
.25041 .53101 m .25273 .53077 L .25462 .53141 L F
.416 .801 .99 r
.2549 .53015 m .25462 .53141 L .25273 .53077 L F
.2549 .53015 m .25688 .53097 L .25462 .53141 L F
.114 .667 .761 r
.3766 .60994 m .37528 .61013 L .37805 .608 L F
.3766 .60994 m .37394 .61014 L .37528 .61013 L F
.412 .108 .337 r
.33118 .56387 m .33459 .56049 L .33216 .56079 L F
.342 .003 .237 r
.33095 .58417 m .33266 .5851 L .33033 .58525 L F
.33095 .58417 m .33367 .58323 L .33266 .5851 L F
.135 0 .199 r
.3205 .6112 m .31952 .6137 L .31796 .61417 L F
0 0 .214 r
.31858 .61558 m .31796 .61417 L .31952 .6137 L F
.8 .581 .605 r
.32043 .61508 m .31894 .6162 L .31858 .61558 L F
0 0 .214 r
.31858 .61558 m .31812 .61716 L .31798 .61455 L F
.774 .563 .614 r
.31442 .61897 m .31796 .62003 L .31812 .61716 L F
.31442 .61897 m .31812 .61716 L .31734 .6195 L F
.695 .743 .236 r
.31858 .61558 m .31734 .6195 L .31812 .61716 L F
.768 .678 .764 r
.31493 .61511 m .31734 .6195 L .31858 .61558 L F
.8 .581 .605 r
.31894 .6162 m .31735 .61741 L .31858 .61558 L F
0 0 .214 r
.31858 .61558 m .31798 .61455 L .31796 .61417 L F
.644 .525 .703 r
.3393 .65466 m .33671 .65496 L .33908 .65173 L F
.704 .561 .689 r
.3393 .65466 m .33664 .6576 L .33671 .65496 L F
.288 .717 .969 r
.31525 .57298 m .31578 .57178 L .31782 .57299 L F
.421 .335 .653 r
.3141 .57462 m .31578 .57178 L .31525 .57298 L F
.442 .21 .466 r
.33685 .61073 m .33944 .61005 L .33944 .60796 L F
.332 0 .209 r
.33801 .61271 m .33685 .61073 L .33639 .61346 L F
.33801 .61271 m .33944 .61005 L .33685 .61073 L F
.035 0 .074 r
.27546 .61158 m .27283 .61462 L .27487 .61395 L F
.34 .073 .356 r
.27546 .61158 m .27699 .61322 L .27778 .61094 L F
.27546 .61158 m .27487 .61395 L .27699 .61322 L F
.694 .192 .044 r
.26383 .55839 m .26232 .55925 L .25744 .55691 L F
.535 .059 .073 r
.26635 .55811 m .26232 .55925 L .26383 .55839 L F
.805 .404 .291 r
.31679 .57744 m .31517 .57809 L .31261 .57454 L F
.014 .181 .693 r
.31261 .57454 m .31517 .57809 L .3141 .57462 L F
.422 .387 .715 r
.20206 .5787 m .19955 .57682 L .20175 .57694 L F
.20206 .5787 m .20036 .58026 L .19955 .57682 L F
.005 .552 .83 r
.24899 .63542 m .25071 .6357 L .2471 .63476 L F
.288 0 0 r
.2753 .55561 m .27264 .55678 L .27279 .55534 L F
.022 0 0 r
.23317 .55217 m .23185 .55437 L .22978 .55527 L F
0 0 0 r
.23361 .5532 m .23317 .55217 L .2351 .55086 L F
.23361 .5532 m .23185 .55437 L .23317 .55217 L F
.525 .569 .842 r
.3609 .58716 m .36409 .5883 L .36214 .58458 L F
.697 .483 .594 r
.37395 .68455 m .37342 .68224 L .37531 .68299 L F
.209 0 .011 r
.34719 .5448 m .34363 .54747 L .34538 .54597 L F
.626 .851 .985 r
.37675 .68163 m .37531 .68299 L .37342 .68224 L F
.515 .261 .467 r
.37675 .68163 m .37395 .68455 L .37531 .68299 L F
.317 .241 .61 r
.31856 .63836 m .31656 .63618 L .319 .63569 L F
.31856 .63836 m .31681 .63967 L .31656 .63618 L F
.166 0 .134 r
.18662 .56381 m .18849 .56363 L .18952 .56113 L F
.21 0 .154 r
.18952 .56113 m .1905 .56282 L .19123 .56071 L F
.18952 .56113 m .18849 .56363 L .1905 .56282 L F
.404 .184 .463 r
.1715 .61136 m .17346 .61103 L .17398 .60821 L F
.1715 .61136 m .17346 .61103 L .17398 .60821 L F
0 .243 .754 r
.32259 .60045 m .32436 .60348 L .3221 .60183 L F
.745 .279 .143 r
.24517 .56198 m .24279 .56295 L .24063 .56038 L F
.842 .999 .794 r
.24512 .5606 m .24517 .56198 L .24729 .56114 L F
.24512 .5606 m .24279 .56295 L .24517 .56198 L F
0 0 .334 r
.32572 .55631 m .32489 .55561 L .32744 .55471 L F
.32572 .55631 m .32512 .55822 L .32489 .55561 L F
.188 .436 .866 r
.30847 .55554 m .30938 .55402 L .30683 .55434 L F
.30847 .55554 m .31134 .55739 L .30938 .55402 L F
.559 .443 .677 r
.30905 .55777 m .31134 .55739 L .30847 .55554 L F
.486 .212 .423 r
.35667 .6115 m .35844 .61323 L .35801 .60975 L F
.35667 .6115 m .35629 .61449 L .35844 .61323 L F
.491 .437 .724 r
.36273 .61901 m .36136 .62347 L .36089 .6207 L F
.452 .196 .434 r
.34625 .66754 m .34563 .67 L .34326 .67051 L F
.114 0 .287 r
.34794 .66643 m .34563 .67 L .34625 .66754 L F
.358 .096 .374 r
.39373 .56388 m .39155 .5646 L .39424 .56162 L F
0 0 .184 r
.39523 .56264 m .39424 .56162 L .39615 .56065 L F
.39523 .56264 m .39373 .56388 L .39424 .56162 L F
0 0 0 r
.20206 .5787 m .20145 .58211 L .20036 .58026 L F
.492 .221 .431 r
.37489 .6363 m .3743 .63878 L .37194 .63911 L F
.37489 .6363 m .3743 .63878 L .37194 .63911 L F
.408 .68 .972 r
.37632 .63465 m .37672 .63591 L .37489 .6363 L F
.553 .278 .452 r
.37733 .63827 m .37489 .6363 L .37672 .63591 L F
.37733 .63827 m .3743 .63878 L .37489 .6363 L F
0 0 .02 r
.37489 .6363 m .37533 .63732 L .37632 .63465 L F
.37489 .6363 m .3743 .63878 L .37533 .63732 L F
.525 .321 .546 r
.29934 .54874 m .3026 .54542 L .29963 .54605 L F
.833 .836 .849 r
.28018 .54143 m .28299 .54026 L .28006 .54105 L F
.601 .159 .172 r
.28562 .53951 m .28006 .54105 L .28299 .54026 L F
.28562 .53951 m .28342 .54148 L .28006 .54105 L F
.151 .659 .903 r
.28006 .54105 m .28342 .54148 L .27998 .54079 L F
.28006 .54105 m .27998 .54079 L .27966 .54073 L F
.833 .836 .849 r
.27854 .54211 m .28018 .54143 L .28006 .54105 L F
.709 .48 .575 r
.5213 .53637 m .52502 .53888 L .52506 .5365 L F
.618 .417 .588 r
.52502 .53888 m .52764 .53614 L .52506 .5365 L F
0 .077 .638 r
.29206 .64134 m .29181 .64255 L .29004 .63889 L F
.827 .478 .395 r
.29512 .64572 m .29181 .64255 L .29292 .64305 L F
.222 0 .25 r
.18662 .56381 m .18777 .56585 L .18849 .56363 L F
.18662 .56381 m .18587 .56678 L .18777 .56585 L F
.442 0 0 r
.35042 .5908 m .3465 .5886 L .3485 .58941 L F
.525 .089 .153 r
.35121 .58934 m .35042 .5908 L .3485 .58941 L F
.831 .873 .875 r
.2904 .59022 m .2873 .59259 L .28548 .59098 L F
.2904 .59022 m .28548 .59098 L .28758 .59141 L F
.552 .048 .011 r
.28758 .59141 m .29195 .5915 L .2904 .59022 L F
.34 .116 .421 r
.2904 .59022 m .29195 .5915 L .29239 .58911 L F
.238 .057 .422 r
.33944 .60796 m .34141 .60742 L .34167 .60693 L F
.33944 .60796 m .33944 .61005 L .34141 .60742 L F
.828 .839 .856 r
.29959 .57939 m .30412 .57798 L .30193 .57883 L F
.771 .997 .826 r
.30366 .57626 m .30412 .57798 L .30594 .57639 L F
.30366 .57626 m .30193 .57883 L .30412 .57798 L F
.7 .531 .655 r
.29007 .59473 m .28945 .59458 L .29155 .59575 L F
.994 .749 .431 r
.29155 .59575 m .2915 .59851 L .29007 .59473 L F
.29155 .59575 m .2915 .59851 L .29007 .59473 L F
.242 .161 .56 r
.17491 .5832 m .17654 .5794 L .17415 .58121 L F
.349 .712 .985 r
.26328 .63748 m .2651 .6387 L .26729 .63862 L F
.012 0 0 r
.26964 .5295 m .27198 .5293 L .2733 .52901 L F
0 0 0 r
.27198 .5293 m .27595 .52806 L .2733 .52901 L F
.137 0 .254 r
.32293 .60786 m .32306 .61069 L .3205 .6112 L F
.202 0 .291 r
.32306 .61069 m .31952 .6137 L .3205 .6112 L F
.597 .915 .667 r
.23663 .7539 m .24084 .75053 L .2392 .75065 L F
.549 .407 .641 r
.24084 .75053 m .2433 .75055 L .24263 .7484 L F
.548 .819 .462 r
.24084 .75053 m .24263 .7484 L .2433 .75055 L F
.396 .679 .974 r
.39255 .5786 m .39195 .58027 L .39092 .57886 L F
.04 0 .437 r
.39255 .5786 m .39079 .58204 L .39195 .58027 L F
.404 0 0 r
.33299 .66816 m .33493 .66901 L .33117 .67027 L F
.33299 .66816 m .33548 .66824 L .33493 .66901 L F
0 0 .52 r
.17468 .60874 m .17585 .61074 L .17398 .60821 L F
.271 .754 .925 r
.17585 .61074 m .17346 .61103 L .17398 .60821 L F
0 0 .52 r
.17468 .60874 m .17398 .60821 L .17346 .61103 L F
.466 .351 .639 r
.29262 .548 m .2902 .54631 L .29265 .54545 L F
.29262 .548 m .29046 .5488 L .2902 .54631 L F
.407 .212 .501 r
.22978 .55527 m .22921 .55811 L .22786 .55794 L F
.725 .347 .334 r
.2303 .56054 m .22786 .55794 L .22921 .55811 L F
.985 .741 .347 r
.27185 .70706 m .27294 .70786 L .27265 .70905 L F
.27185 .70706 m .27294 .70786 L .27265 .70905 L F
.552 .878 .991 r
.30562 .52786 m .30455 .52593 L .3079 .52731 L F
.30562 .52786 m .3026 .52684 L .30455 .52593 L F
.315 0 0 r
.27917 .55512 m .2773 .55617 L .2753 .55561 L F
.42 .232 .518 r
.39373 .56388 m .39337 .56671 L .39155 .5646 L F
.287 .208 .59 r
.39155 .5646 m .39337 .56671 L .39187 .56708 L F
.157 .204 .661 r
.30434 .56759 m .30585 .56625 L .30377 .564 L F
.247 .153 .546 r
.30397 .56958 m .30585 .56625 L .30434 .56759 L F
.556 .359 .57 r
.50803 .54854 m .51094 .54902 L .51063 .54572 L F
.524 .488 .759 r
.51126 .55129 m .51094 .54902 L .50803 .54854 L F
.464 .889 .892 r
.28943 .6306 m .28503 .63158 L .28701 .63207 L F
.247 .316 .737 r
.37851 .53585 m .37954 .53986 L .38123 .53814 L F
.266 .345 .759 r
.37954 .53986 m .38209 .54174 L .38123 .53814 L F
.231 .227 .648 r
.36449 .57432 m .36671 .57534 L .36603 .57315 L F
.36449 .57432 m .36497 .57692 L .36671 .57534 L F
.413 .249 .547 r
.31147 .5833 m .31129 .58598 L .31337 .58522 L F
.31147 .5833 m .31129 .58598 L .31337 .58522 L F
.358 .43 .799 r
.18467 .59989 m .18602 .59754 L .18361 .59809 L F
.18467 .59989 m .18726 .6014 L .18602 .59754 L F
.062 .339 .816 r
.3923 .54219 m .39498 .54408 L .39447 .54543 L F
0 0 .488 r
.39498 .54408 m .39577 .54808 L .39447 .54543 L F
.251 .15 .541 r
.326 .64882 m .3277 .65046 L .32778 .64799 L F
.326 .64882 m .32559 .65217 L .3277 .65046 L F
0 0 .56 r
.3207 .59464 m .32047 .596 L .31915 .59203 L F
0 .171 .677 r
.32245 .59706 m .32047 .596 L .3207 .59464 L F
.32245 .59706 m .32282 .59785 L .32047 .596 L F
.438 .522 .847 r
.35261 .64751 m .35233 .6515 L .35024 .64805 L F
.35261 .64751 m .3542 .65108 L .35233 .6515 L F
.418 .301 .613 r
.3542 .65108 m .35234 .65351 L .35233 .6515 L F
.441 .493 .817 r
.38918 .57524 m .39092 .57886 L .3876 .57787 L F
.637 .237 0 r
.38762 .53102 m .38728 .53029 L .38596 .52882 L F
.38762 .53102 m .38883 .53309 L .38728 .53029 L F
0 0 0 r
.20534 .57368 m .20375 .57585 L .20175 .57694 L F
.496 .304 .549 r
.20786 .57041 m .20762 .5733 L .20534 .57368 L F
0 0 0 r
.20563 .57493 m .20534 .57368 L .20762 .5733 L F
.20563 .57493 m .20375 .57585 L .20534 .57368 L F
.614 .457 .646 r
.51094 .54902 m .51327 .54541 L .51063 .54572 L F
.717 .263 .172 r
.31679 .57744 m .31464 .57865 L .31517 .57809 L F
.6 .267 .377 r
.31796 .57624 m .31464 .57865 L .31679 .57744 L F
.447 .268 .544 r
.36958 .64249 m .37185 .64194 L .37194 .63911 L F
.36958 .64249 m .37185 .64194 L .37194 .63911 L F
.517 .66 .925 r
.20816 .59389 m .20688 .59595 L .20563 .5942 L F
.451 .572 .885 r
.20816 .59389 m .20898 .5957 L .20688 .59595 L F
.722 .732 .859 r
.30989 .63908 m .31163 .63585 L .31023 .63619 L F
.786 .655 .718 r
.25832 .72884 m .25985 .72663 L .25813 .72692 L F
.677 .31 .344 r
.32289 .66758 m .32639 .66914 L .32254 .66981 L F
.76 .889 .936 r
.52953 .55921 m .53369 .55876 L .53172 .55742 L F
.86 .813 .802 r
.53172 .55742 m .53369 .55876 L .53591 .55557 L F
.118 0 0 r
.25744 .55691 m .25818 .55684 L .25595 .55711 L F
.283 0 0 r
.25595 .55711 m .25818 .55684 L .25957 .5552 L F
.481 .077 .196 r
.25818 .55684 m .26225 .5546 L .25957 .5552 L F
.84 .752 .766 r
.5341 .55381 m .53591 .55557 L .53452 .55185 L F
.86 .813 .802 r
.53172 .55742 m .53591 .55557 L .5341 .55381 L F
.802 .735 .79 r
.53452 .55185 m .53591 .55557 L .53814 .55274 L F
.65 .22 .214 r
.28751 .54154 m .28562 .53951 L .28757 .53891 L F
.28751 .54154 m .28342 .54148 L .28562 .53951 L F
.085 .013 .47 r
.29182 .63754 m .28986 .6363 L .29161 .63493 L F
.29182 .63754 m .29004 .63889 L .28986 .6363 L F
.264 0 .308 r
.29802 .59871 m .29787 .60122 L .29556 .60216 L F
.947 .87 .729 r
.29802 .59871 m .29986 .59503 L .29891 .59727 L F
.271 .754 .925 r
.17585 .61074 m .17783 .61128 L .17346 .61103 L F
.17346 .61103 m .17783 .61128 L .17585 .61074 L F
.631 .926 .973 r
.17585 .61074 m .17783 .61128 L .17822 .60975 L F
.17822 .60975 m .17783 .61128 L .17585 .61074 L F
.434 .163 .402 r
.24613 .74492 m .24263 .7484 L .24489 .74795 L F
.624 .298 .397 r
.24489 .74795 m .24936 .74784 L .24613 .74492 L F
.557 .678 .919 r
.34326 .67051 m .34388 .6681 L .34171 .66813 L F
.34326 .67051 m .34563 .67 L .34388 .6681 L F
.536 .914 .762 r
.36375 .60977 m .36223 .61109 L .36587 .6089 L F
.845 .643 .629 r
.36493 .60697 m .36878 .60781 L .36637 .6039 L F
.36878 .60781 m .36896 .60785 L .36881 .60762 L F
.36878 .60781 m .36881 .60762 L .36637 .6039 L F
.43 .503 .833 r
.36637 .6039 m .36896 .60785 L .36893 .6069 L F
.951 .947 .73 r
.36642 .60734 m .36587 .6089 L .36877 .60791 L F
.36611 .60742 m .36587 .6089 L .36642 .60734 L F
.36493 .60697 m .36517 .60746 L .36613 .60727 L F
.36517 .60746 m .36587 .6089 L .36613 .60727 L F
.36493 .60697 m .36431 .60844 L .36587 .6089 L F
.36431 .60844 m .36375 .60977 L .36391 .6097 L F
.36431 .60844 m .36391 .6097 L .36587 .6089 L F
.729 .684 .807 r
.36301 .60832 m .36462 .60747 L .36373 .60222 L F
.36462 .60747 m .36494 .60729 L .36483 .6068 L F
.36462 .60747 m .36483 .6068 L .36373 .60222 L F
.222 0 0 r
.36683 .60794 m .36375 .60977 L .36493 .60697 L F
.36863 .60885 m .36444 .60964 L .36683 .60794 L F
.36444 .60964 m .36375 .60977 L .36683 .60794 L F
.951 .947 .73 r
.36878 .60781 m .36877 .60791 L .36896 .60785 L F
.805 .447 .378 r
.37197 .61181 m .36859 .609 L .36912 .61144 L F
.761 .586 .661 r
.36973 .61245 m .36842 .61014 L .36859 .609 L F
.805 .447 .378 r
.37197 .61181 m .36973 .61245 L .36859 .609 L F
.216 .06 .444 r
.36893 .6069 m .36842 .61014 L .37121 .60876 L F
.222 0 0 r
.36886 .60897 m .36861 .60901 L .36863 .60885 L F
0 0 0 r
.36859 .609 m .36856 .60923 L .36865 .60864 L F
.222 0 0 r
.36861 .60901 m .36375 .60977 L .36863 .60885 L F
0 0 0 r
.36865 .60864 m .36844 .61 L .36885 .60742 L F
.36859 .609 m .36885 .60742 L .36882 .6076 L F
.951 .947 .73 r
.36493 .60697 m .36877 .60791 L .36878 .60781 L F
.36613 .60727 m .36611 .60742 L .36642 .60734 L F
.77 .548 .597 r
.36637 .6039 m .36751 .60622 L .36493 .60697 L F
0 0 0 r
.36844 .61 m .36847 .60982 L .36885 .60742 L F
.77 .548 .597 r
.36751 .60622 m .36886 .60897 L .36651 .60778 L F
.36751 .60622 m .36651 .60778 L .36493 .60697 L F
.43 .503 .833 r
.36637 .6039 m .36893 .6069 L .36785 .60555 L F
.79 .554 .58 r
.36785 .60555 m .36886 .60897 L .36637 .6039 L F
.222 0 0 r
.3644 .60967 m .36586 .60975 L .36375 .60977 L F
0 0 0 r
.36856 .60923 m .36842 .61014 L .36864 .60871 L F
.36864 .6087 m .36864 .60871 L .36865 .60864 L F
.36856 .60923 m .36864 .60871 L .36864 .6087 L F
.222 0 0 r
.36861 .60901 m .36646 .6096 L .3644 .60967 L F
.36886 .60897 m .3686 .60903 L .36861 .60901 L F
.3686 .60903 m .36646 .6096 L .36861 .60901 L F
.36646 .6096 m .36586 .60975 L .3644 .60967 L F
.548 .273 .451 r
.36785 .60555 m .36586 .60975 L .36646 .6096 L F
.36785 .60555 m .36646 .6096 L .36886 .60897 L F
.492 .238 .457 r
.37121 .60876 m .36942 .60949 L .36815 .60699 L F
.36942 .60949 m .36874 .60977 L .36869 .60952 L F
.36942 .60949 m .36869 .60952 L .36815 .60699 L F
.548 .273 .451 r
.36759 .60608 m .36813 .60688 L .36713 .60707 L F
.36785 .60555 m .36787 .60565 L .36759 .60608 L F
.36787 .60565 m .36813 .60688 L .36759 .60608 L F
.492 .238 .457 r
.36823 .60694 m .36815 .60699 L .36813 .60688 L F
.37121 .60876 m .36815 .60699 L .36823 .60694 L F
.36899 .60664 m .36813 .60688 L .36785 .60555 L F
0 0 0 r
.36882 .6076 m .36885 .60742 L .36893 .6069 L F
.354 .313 .673 r
.36893 .6069 m .37101 .60292 L .36785 .60555 L F
.36893 .6069 m .3714 .60629 L .37101 .60292 L F
.216 .06 .444 r
.36893 .6069 m .37121 .60876 L .3714 .60629 L F
.492 .238 .457 r
.37121 .60876 m .36813 .60688 L .36899 .60664 L F
.548 .273 .451 r
.36713 .60707 m .36874 .60977 L .36586 .60975 L F
.36813 .60688 m .36874 .60977 L .36713 .60707 L F
0 0 0 r
.36844 .61 m .36842 .61014 L .36847 .60982 L F
.194 0 .282 r
.27283 .61462 m .27393 .61597 L .27487 .61395 L F
.27283 .61462 m .27213 .61694 L .27393 .61597 L F
.577 .758 .964 r
.32856 .60475 m .3258 .60551 L .32436 .60348 L F
.602 .817 .983 r
.28548 .59098 m .2873 .59259 L .28327 .59212 L F
.608 .305 .431 r
.28481 .59413 m .28327 .59212 L .2873 .59259 L F
.903 .635 .522 r
.2873 .59259 m .28809 .59576 L .28567 .59455 L F
.28548 .59402 m .28567 .59455 L .28514 .59429 L F
.2873 .59259 m .28567 .59455 L .28548 .59402 L F
.901 .656 .559 r
.28481 .59413 m .28809 .59576 L .28677 .59791 L F
0 0 .474 r
.28569 .59416 m .28652 .59704 L .28642 .59509 L F
.28652 .59704 m .28677 .59791 L .28675 .59768 L F
.28652 .59704 m .28675 .59768 L .28642 .59509 L F
.903 .635 .522 r
.2873 .59259 m .28514 .59429 L .28507 .59397 L F
.437 .333 .639 r
.28456 .59145 m .28569 .59416 L .28548 .59098 L F
.28327 .59212 m .28499 .59357 L .28456 .59145 L F
.28499 .59357 m .28569 .59416 L .28456 .59145 L F
.903 .635 .522 r
.28507 .59397 m .28514 .59429 L .28481 .59413 L F
.238 .222 .638 r
.28945 .59458 m .28809 .59576 L .2873 .59259 L F
.659 .659 .839 r
.36548 .65598 m .36209 .65448 L .36438 .65417 L F
.37 .518 .875 r
.36678 .65376 m .36548 .65598 L .36438 .65417 L F
.36678 .65376 m .36799 .65588 L .36548 .65598 L F
.436 .643 .945 r
.22102 .60937 m .21999 .61116 L .21801 .60828 L F
.22102 .60937 m .22201 .61094 L .21999 .61116 L F
.576 .602 .841 r
.22399 .6137 m .21999 .61116 L .22201 .61094 L F
.052 .124 .62 r
.4006 .55321 m .40113 .55718 L .3994 .5552 L F
.274 .17 .55 r
.3994 .5552 m .40113 .55718 L .39957 .55788 L F
.594 .552 .777 r
.36489 .56416 m .36697 .56085 L .36466 .56166 L F
.36489 .56416 m .3685 .56535 L .36697 .56085 L F
.726 .344 .326 r
.53153 .53913 m .53375 .54141 L .53557 .53958 L F
.904 .621 .497 r
.53375 .54141 m .53602 .5427 L .53557 .53958 L F
.393 .213 .514 r
.1785 .5733 m .18067 .57002 L .17873 .57074 L F
0 0 0 r
.31094 .64518 m .31462 .64197 L .31327 .64479 L F
.646 .516 .691 r
.31681 .63967 m .31723 .64217 L .31462 .64197 L F
.603 .235 .317 r
.31462 .64197 m .31579 .64467 L .31327 .64479 L F
.31462 .64197 m .31723 .64217 L .31579 .64467 L F
.231 0 .309 r
.29959 .57939 m .29774 .58031 L .2971 .58255 L F
.709 .577 .705 r
.32013 .56456 m .31925 .56768 L .31769 .56729 L F
.583 .846 .496 r
.32268 .56151 m .32121 .56314 L .32013 .56456 L F
0 0 .079 r
.32066 .56551 m .32013 .56456 L .32121 .56314 L F
.32066 .56551 m .31925 .56768 L .32013 .56456 L F
0 .087 .636 r
.3369 .56974 m .33832 .57382 L .33855 .57121 L F
.3369 .56974 m .33832 .57382 L .33855 .57121 L F
.884 .992 .773 r
.33832 .57382 m .33597 .57479 L .33855 .57121 L F
.503 .3 .537 r
.34088 .57072 m .34084 .57332 L .33832 .57382 L F
.429 .221 .494 r
.34084 .57332 m .33831 .57677 L .33832 .57382 L F
.31 .556 .922 r
.22455 .61169 m .22399 .6137 L .22201 .61094 L F
.22455 .61169 m .22602 .61399 L .22399 .6137 L F
.823 .857 .873 r
.35034 .63573 m .34776 .63565 L .35044 .6333 L F
.485 .882 .956 r
.24052 .53328 m .24418 .53285 L .24195 .53355 L F
.098 0 .249 r
.32419 .60957 m .32293 .60786 L .32466 .60692 L F
.32419 .60957 m .32306 .61069 L .32293 .60786 L F
.071 0 0 r
.20571 .54819 m .2076 .54782 L .20898 .54603 L F
0 0 0 r
.2076 .54782 m .21111 .54532 L .20898 .54603 L F
.649 .675 .861 r
.52283 .55831 m .52715 .56026 L .52535 .55744 L F
.548 .639 .892 r
.52535 .55744 m .52715 .56026 L .52953 .55921 L F
.242 .161 .56 r
.17491 .5832 m .17623 .58291 L .17654 .5794 L F
.278 .308 .713 r
.17491 .5832 m .17721 .58528 L .17623 .58291 L F
.385 .32 .661 r
.17491 .5832 m .17544 .58603 L .17721 .58528 L F
.387 0 0 r
.25215 .6232 m .2524 .62317 L .25035 .62249 L F
.25215 .6232 m .25419 .62416 L .2524 .62317 L F
.831 .614 .609 r
.31796 .62003 m .3215 .62059 L .31812 .61716 L F
.828 .563 .539 r
.31796 .62003 m .32171 .62123 L .3215 .62059 L F
.831 .614 .609 r
.31796 .62003 m .3215 .62059 L .31812 .61716 L F
.499 .771 .992 r
.23065 .61211 m .2303 .61394 L .22831 .61273 L F
.23065 .61211 m .2325 .61346 L .2303 .61394 L F
.715 .734 .865 r
.23645 .61409 m .2339 .61538 L .2325 .61346 L F
.525 .597 .869 r
.23696 .61606 m .2339 .61538 L .23645 .61409 L F
.82 .487 .425 r
.31925 .56768 m .31581 .56918 L .31769 .56729 L F
.31925 .56768 m .32004 .57185 L .31581 .56918 L F
0 0 .417 r
.32121 .5684 m .31925 .56768 L .32066 .56551 L F
.32121 .5684 m .32004 .57185 L .31925 .56768 L F
.446 .149 .366 r
.26487 .55466 m .2675 .55219 L .26528 .55229 L F
.547 .579 .839 r
.22386 .63045 m .22488 .62754 L .22219 .62894 L F
.22386 .63045 m .22672 .63013 L .22488 .62754 L F
.562 .575 .824 r
.37328 .62993 m .37566 .6294 L .37419 .6258 L F
.803 .559 .569 r
.31428 .56669 m .3166 .56757 L .31769 .56729 L F
.755 .354 .292 r
.31769 .56729 m .31581 .56918 L .31428 .56669 L F
.362 .112 .393 r
.38902 .58297 m .38849 .58592 L .38631 .58623 L F
.176 0 .324 r
.39052 .58422 m .38902 .58297 L .39079 .58204 L F
.39052 .58422 m .38849 .58592 L .38902 .58297 L F
0 .349 .823 r
.31504 .53913 m .31664 .53997 L .31536 .53827 L F
.389 .373 .721 r
.31536 .53827 m .31394 .54029 L .31504 .53913 L F
.802 .735 .79 r
.53452 .55185 m .53814 .55274 L .53701 .55075 L F
.63 .667 .867 r
.53701 .55075 m .53814 .55274 L .54085 .55173 L F
.505 .344 .597 r
.34317 .56739 m .34323 .57029 L .34088 .57072 L F
.367 .193 .509 r
.34282 .57257 m .34088 .57072 L .34323 .57029 L F
.34282 .57257 m .34084 .57332 L .34088 .57072 L F
.228 .533 .922 r
.20335 .5915 m .20289 .59308 L .20132 .59176 L F
.20335 .5915 m .20563 .5942 L .20289 .59308 L F
.304 0 0 r
.36564 .58402 m .36301 .58339 L .36214 .58458 L F
.241 .126 .515 r
.28583 .56077 m .28572 .56403 L .28434 .56451 L F
.284 .241 .632 r
.28434 .56451 m .28636 .56663 L .28572 .56403 L F
.241 .126 .515 r
.28583 .56077 m .28572 .56403 L .28434 .56451 L F
.284 .241 .632 r
.28434 .56451 m .28636 .56663 L .28572 .56403 L F
.374 .203 .516 r
.20956 .5723 m .20786 .57041 L .21011 .57095 L F
.20956 .5723 m .20762 .5733 L .20786 .57041 L F
.577 .457 .679 r
.3204 .58699 m .32319 .58257 L .32134 .58294 L F
0 0 0 r
.31428 .56669 m .31052 .56951 L .31369 .56724 L F
.663 .781 .936 r
.37836 .62643 m .37648 .62784 L .37419 .6258 L F
0 .04 .587 r
.21663 .60647 m .21599 .60827 L .2151 .60441 L F
.379 .625 .949 r
.21663 .60647 m .21801 .60828 L .21599 .60827 L F
0 0 0 r
.3006 .57728 m .29959 .57939 L .30161 .57623 L F
.673 .319 .366 r
.24307 .55989 m .24512 .5606 L .24726 .55808 L F
.637 .274 .338 r
.24726 .55808 m .24512 .5606 L .24934 .56026 L F
.779 .691 .767 r
.35808 .53027 m .35401 .52971 L .35641 .5266 L F
.744 .487 .542 r
.35808 .53027 m .35237 .5319 L .35401 .52971 L F
.35409 .53141 m .35391 .53214 L .35381 .53213 L F
.35385 .53148 m .35381 .53213 L .35237 .5319 L F
.35409 .53141 m .35381 .53213 L .35385 .53148 L F
.742 .555 .641 r
.35237 .5319 m .35387 .5328 L .3539 .53219 L F
.233 0 0 r
.35774 .53273 m .3575 .53285 L .3539 .53219 L F
.35391 .53214 m .3539 .53219 L .35237 .5319 L F
.35774 .53273 m .3539 .53219 L .35391 .53214 L F
.742 .555 .641 r
.35237 .5319 m .3539 .53219 L .35401 .52971 L F
.987 .778 .538 r
.35401 .52971 m .3539 .53219 L .35211 .53108 L F
.3539 .53219 m .3539 .5322 L .3539 .5322 L F
.3539 .53219 m .3539 .5322 L .35211 .53108 L F
.786 .487 .482 r
.35237 .5319 m .35354 .53477 L .35387 .5328 L F
.233 0 0 r
.35381 .53217 m .35354 .53477 L .35237 .5319 L F
.783 .7 .772 r
.35354 .53477 m .35211 .53108 L .35375 .53268 L F
.35354 .53477 m .35375 .53268 L .35378 .5327 L F
.35372 .53371 m .35378 .5327 L .35387 .5328 L F
.35354 .53477 m .35378 .5327 L .35372 .53371 L F
.987 .778 .538 r
.3539 .5322 m .35387 .5328 L .35378 .5327 L F
.233 0 0 r
.3575 .53285 m .35354 .53477 L .35381 .53217 L F
.987 .778 .538 r
.3539 .5322 m .35378 .5327 L .35211 .53108 L F
.744 .487 .542 r
.35808 .53027 m .35774 .53273 L .35391 .53214 L F
.35808 .53027 m .35391 .53214 L .35409 .53141 L F
.786 .956 .631 r
.35878 .52809 m .35808 .53027 L .36035 .527 L F
0 0 .134 r
.35905 .53066 m .35808 .53027 L .35878 .52809 L F
.35905 .53066 m .35774 .53273 L .35808 .53027 L F
.702 .911 .968 r
.22235 .55925 m .21966 .56081 L .2217 .56167 L F
.216 0 0 r
.22146 .56119 m .22119 .56131 L .21966 .56081 L F
0 .369 .703 r
.2217 .56167 m .21966 .56081 L .21887 .56056 L F
.216 0 0 r
.22119 .56131 m .21851 .56258 L .21966 .56081 L F
0 .369 .703 r
.21887 .56056 m .21966 .56081 L .21791 .56018 L F
.702 .911 .968 r
.22235 .55925 m .2217 .56167 L .22396 .56063 L F
.899 .98 .801 r
.32221 .55908 m .32268 .56151 L .32512 .55822 L F
0 0 0 r
.32258 .56174 m .32268 .56151 L .32221 .55908 L F
.32258 .56174 m .32121 .56314 L .32268 .56151 L F
.615 .402 .57 r
.51509 .5392 m .51866 .53918 L .51864 .53644 L F
.68 .455 .573 r
.51864 .53644 m .52122 .53898 L .5213 .53637 L F
.51864 .53644 m .51866 .53918 L .52122 .53898 L F
.64 .596 .79 r
.35532 .64134 m .35385 .63809 L .35534 .63995 L F
.898 .898 .818 r
.35241 .61834 m .35138 .62014 L .3536 .61745 L F
.272 .144 .516 r
.32057 .6349 m .31892 .63301 L .32076 .63249 L F
.32057 .6349 m .319 .63569 L .31892 .63301 L F
.698 .591 .733 r
.34035 .65813 m .33792 .66122 L .33664 .6576 L F
.152 0 .39 r
.23149 .55673 m .22978 .55527 L .23185 .55437 L F
.23149 .55673 m .22921 .55811 L .22978 .55527 L F
.72 .893 .959 r
.32476 .52677 m .32072 .52715 L .32307 .52614 L F
.711 .939 .96 r
.32476 .52677 m .32536 .52477 L .32703 .52628 L F
.32476 .52677 m .32307 .52614 L .32536 .52477 L F
.271 .42 .828 r
.32807 .52995 m .32476 .52677 L .32703 .52628 L F
.234 .233 .653 r
.36497 .57692 m .36702 .57901 L .36671 .57534 L F
.303 .244 .624 r
.3655 .5787 m .36702 .57901 L .36497 .57692 L F
.615 .133 .086 r
.32996 .56967 m .32753 .56844 L .33022 .56884 L F
.44 0 .042 r
.33022 .56884 m .33251 .56972 L .32996 .56967 L F
.484 .695 .961 r
.18846 .604 m .18891 .60319 L .18726 .6014 L F
.18891 .60319 m .18945 .60222 L .18792 .60165 L F
0 0 0 r
.18945 .60222 m .18768 .60188 L .18726 .6014 L F
.926 .687 .558 r
.18555 .59795 m .18768 .60188 L .18372 .59949 L F
.18602 .59754 m .18711 .60039 L .18555 .59795 L F
0 .041 .604 r
.18726 .6014 m .18768 .60188 L .18602 .59754 L F
.926 .687 .558 r
.18711 .60039 m .18768 .60188 L .18555 .59795 L F
.484 .695 .961 r
.18891 .60319 m .18792 .60165 L .18726 .6014 L F
.18846 .604 m .19473 .60544 L .18945 .60222 L F
.673 .123 0 r
.30843 .62961 m .30655 .62908 L .30402 .6268 L F
.692 .932 .967 r
.30893 .62745 m .30655 .62908 L .30843 .62961 L F
.021 .238 .742 r
.30843 .62961 m .31066 .632 L .30893 .62745 L F
.692 .932 .967 r
.30893 .62745 m .30655 .62908 L .30843 .62961 L F
.345 .073 .349 r
.29819 .54232 m .29526 .54498 L .29563 .54294 L F
.64 .397 .534 r
.32319 .58257 m .32536 .58365 L .32659 .58001 L F
.276 .016 .327 r
.32917 .57693 m .32659 .58001 L .32862 .57901 L F
.027 0 .231 r
.32659 .58001 m .32758 .58172 L .32862 .57901 L F
.32659 .58001 m .32536 .58365 L .32758 .58172 L F
.108 .662 .761 r
.25868 .6241 m .25832 .6243 L .25645 .62402 L F
0 .514 .72 r
.25699 .62386 m .25848 .62406 L .25868 .6241 L F
.108 .662 .761 r
.25868 .6241 m .26062 .62409 L .25917 .62422 L F
.509 .911 .892 r
.26308 .62296 m .26062 .62409 L .25868 .6241 L F
.26308 .62296 m .25868 .6241 L .26106 .6244 L F
0 .514 .72 r
.25848 .62406 m .26106 .6244 L .25868 .6241 L F
.108 .662 .761 r
.25868 .6241 m .25917 .62422 L .25832 .6243 L F
.53 0 0 r
.2767 .54353 m .27859 .54483 L .27634 .54291 L F
.2767 .54353 m .27634 .54291 L .27854 .54211 L F
0 0 0 r
.30905 .55777 m .30562 .56091 L .30742 .55975 L F
.147 0 0 r
.30742 .55975 m .31134 .55739 L .30905 .55777 L F
.58 .842 .487 r
.24789 .74961 m .25056 .74649 L .24936 .74784 L F
.542 .37 .597 r
.24949 .75117 m .25056 .74649 L .24789 .74961 L F
.24949 .75117 m .25218 .75093 L .25056 .74649 L F
.616 .334 .467 r
.25432 .75026 m .25056 .74649 L .25218 .75093 L F
.25432 .75026 m .25511 .7477 L .25056 .74649 L F
.446 .057 .206 r
.3603 .54485 m .36284 .54462 L .36338 .54311 L F
.46 .086 .242 r
.36379 .54249 m .36284 .54462 L .3603 .54485 L F
.061 0 .054 r
.36581 .54176 m .36284 .54462 L .36379 .54249 L F
.396 .122 .376 r
.32917 .57693 m .33079 .57759 L .33157 .5765 L F
.32917 .57693 m .32862 .57901 L .33079 .57759 L F
.416 .321 .639 r
.32684 .63903 m .32914 .64131 L .32851 .63844 L F
.32684 .63903 m .32661 .64302 L .32914 .64131 L F
.899 .98 .801 r
.32221 .55908 m .32512 .55822 L .32366 .55786 L F
.728 .97 .932 r
.32572 .55631 m .32366 .55786 L .32512 .55822 L F
.52 .294 .512 r
.35431 .58636 m .3542 .58887 L .35121 .58934 L F
0 0 .192 r
.35482 .58733 m .35431 .58636 L .35611 .58561 L F
.35482 .58733 m .35426 .58735 L .35431 .58636 L F
.976 .922 .647 r
.35611 .58561 m .35411 .58691 L .35482 .58733 L F
.35611 .58561 m .35411 .58691 L .35482 .58733 L F
0 .325 .811 r
.35536 .58731 m .35482 .58733 L .35411 .58691 L F
.35701 .58784 m .35482 .58733 L .35536 .58731 L F
0 0 .192 r
.35482 .58733 m .3542 .58887 L .35426 .58735 L F
0 0 0 r
.27019 .61803 m .26688 .62 L .26886 .61897 L F
.27019 .61803 m .27009 .61842 L .27213 .61694 L F
.27019 .61803 m .26886 .61897 L .27009 .61842 L F
.147 .688 .715 r
.23126 .53612 m .23243 .53593 L .22898 .53655 L F
.275 .777 .771 r
.23342 .53547 m .23243 .53593 L .23126 .53612 L F
0 0 0 r
.23342 .53547 m .23126 .53612 L .22922 .537 L F
.23342 .53547 m .22922 .537 L .23134 .53583 L F
.049 0 0 r
.23257 .53571 m .23342 .53547 L .23134 .53583 L F
.289 .776 .704 r
.2341 .53528 m .23243 .53593 L .23342 .53547 L F
.049 0 0 r
.23496 .53548 m .23342 .53547 L .23257 .53571 L F
.289 .776 .704 r
.23506 .53491 m .2341 .53528 L .23342 .53547 L F
.588 .54 .768 r
.5165 .55812 m .51786 .55401 L .51513 .55448 L F
.5165 .55812 m .51896 .55745 L .51786 .55401 L F
.498 .903 .801 r
.30102 .64524 m .2986 .64629 L .30068 .6448 L F
.908 .786 .303 r
.30121 .6426 m .30102 .64524 L .30068 .6448 L F
.378 0 .048 r
.27529 .64162 m .27746 .64166 L .27172 .64346 L F
.634 .335 .447 r
.3542 .58887 m .35042 .5908 L .35121 .58934 L F
0 0 .048 r
.30853 .57346 m .30764 .57599 L .30594 .57639 L F
.806 .494 .461 r
.30764 .57599 m .30366 .57626 L .30594 .57639 L F
.264 .772 .804 r
.31425 .62336 m .31328 .62392 L .30962 .62496 L F
.31425 .62336 m .31585 .62328 L .31328 .62392 L F
.448 .216 .469 r
.38631 .58623 m .38555 .58998 L .38366 .58935 L F
.578 .334 .511 r
.38882 .58861 m .38631 .58623 L .38849 .58592 L F
.38882 .58861 m .38555 .58998 L .38631 .58623 L F
.107 .073 .533 r
.32647 .65461 m .3277 .65046 L .32559 .65217 L F
.13 .66 .867 r
.23237 .62912 m .22852 .62867 L .23033 .62969 L F
.433 .517 .845 r
.36626 .5169 m .36562 .52036 L .3637 .51757 L F
.36626 .5169 m .36763 .52014 L .36562 .52036 L F
.801 .997 .78 r
.32753 .56844 m .32581 .56937 L .32861 .56643 L F
.615 .133 .086 r
.32996 .56967 m .32581 .56937 L .32753 .56844 L F
0 0 0 r
.3465 .5886 m .35181 .58383 L .34742 .58639 L F
0 0 .26 r
.35181 .58383 m .3518 .58204 L .35132 .58288 L F
.35181 .58383 m .35229 .58462 L .3518 .58204 L F
0 0 0 r
.35181 .58383 m .35009 .58641 L .35229 .58462 L F
.35181 .58383 m .34819 .58744 L .35009 .58641 L F
.025 0 .161 r
.28076 .60538 m .28009 .60741 L .28227 .60437 L F
.709 .48 .575 r
.5213 .53637 m .52122 .53898 L .52502 .53888 L F
.275 0 .196 r
.36707 .55774 m .36802 .55899 L .36997 .55629 L F
.539 .578 .842 r
.36697 .56085 m .36802 .55899 L .36707 .55774 L F
.786 .435 .391 r
.31789 .62257 m .32171 .62123 L .31796 .62003 L F
.31789 .62257 m .32226 .6228 L .32171 .62123 L F
.172 .314 .768 r
.23825 .61645 m .23743 .61831 L .23696 .61606 L F
.23825 .61645 m .23968 .62009 L .23743 .61831 L F
0 0 0 r
.29095 .52767 m .29308 .52715 L .29549 .5264 L F
.29308 .52715 m .29769 .52605 L .29549 .5264 L F
.35929 .64092 m .35771 .64117 L .35532 .64134 L F
.588 .025 0 r
.35929 .64092 m .36171 .64212 L .35771 .64117 L F
.61 .414 .592 r
.36222 .63861 m .36171 .64212 L .35929 .64092 L F
.704 .561 .689 r
.3393 .65466 m .34035 .65813 L .33664 .6576 L F
.621 .512 .709 r
.34268 .65739 m .3393 .65466 L .34299 .65476 L F
.34268 .65739 m .34035 .65813 L .3393 .65466 L F
.072 0 0 r
.36555 .5357 m .36739 .53507 L .36866 .53381 L F
.364 .028 .255 r
.36449 .53808 m .36739 .53507 L .36555 .5357 L F
.649 .828 .969 r
.31187 .5275 m .3079 .52731 L .31038 .52698 L F
.515 .881 .979 r
.31426 .52673 m .31187 .5275 L .31038 .52698 L F
.058 0 0 r
.25769 .54905 m .25437 .55055 L .25513 .5502 L F
.46 .793 .999 r
.28583 .56077 m .28933 .55819 L .28501 .55818 L F
.28583 .56077 m .28928 .56083 L .28933 .55819 L F
.674 .463 .592 r
.28933 .55819 m .28928 .56083 L .28583 .56077 L F
.914 .642 .512 r
.29337 .58128 m .29477 .58311 L .29196 .58235 L F
.968 .715 .497 r
.29477 .58311 m .29283 .58475 L .29196 .58235 L F
.29477 .58311 m .29469 .58573 L .29283 .58475 L F
.566 .643 .885 r
.2953 .58021 m .29477 .58311 L .29337 .58128 L F
.2953 .58021 m .2971 .58255 L .29477 .58311 L F
.575 .739 .954 r
.34622 .55972 m .34513 .56162 L .34405 .56026 L F
.555 .45 .689 r
.34757 .56015 m .34513 .56162 L .34622 .55972 L F
.34757 .56015 m .34546 .56435 L .34513 .56162 L F
.528 .85 .998 r
.19426 .82878 m .19614 .82961 L .19833 .82894 L F
.19426 .82878 m .19614 .82961 L .19833 .82894 L F
.302 .13 .475 r
.35911 .59848 m .36138 .59739 L .36153 .59495 L F
.457 .303 .583 r
.35824 .60117 m .36138 .59739 L .35911 .59848 L F
.733 .528 .615 r
.36567 .64203 m .36222 .63861 L .36424 .63842 L F
.36567 .64203 m .36171 .64212 L .36222 .63861 L F
.216 .633 .953 r
.35523 .64635 m .35937 .64502 L .35652 .64499 L F
.104 .134 .607 r
.31238 .61724 m .31362 .61695 L .31312 .61309 L F
.139 .29 .756 r
.31238 .61724 m .31442 .61897 L .31362 .61695 L F
.994 .754 .452 r
.36223 .61109 m .36132 .61386 L .36181 .61343 L F
.504 .159 .315 r
.36359 .61349 m .36223 .61109 L .36375 .60977 L F
.935 .924 .774 r
.36132 .61386 m .36134 .61689 L .36181 .61343 L F
.504 .159 .315 r
.36359 .61349 m .36132 .61386 L .36223 .61109 L F
.532 .365 .6 r
.51599 .54216 m .51866 .53918 L .51509 .5392 L F
.078 0 .292 r
.30377 .564 m .30494 .56379 L .30562 .56091 L F
.147 .202 .663 r
.30377 .564 m .30585 .56625 L .30494 .56379 L F
.228 0 .151 r
.21529 .56115 m .21378 .56398 L .21175 .5645 L F
0 0 .315 r
.30213 .58361 m .30147 .58299 L .29983 .58102 L F
0 0 .348 r
.30147 .58299 m .30226 .58565 L .30195 .58575 L F
.187 0 0 r
.30244 .58371 m .30213 .58361 L .29923 .58295 L F
.505 .61 .89 r
.30342 .58394 m .30345 .58751 L .30213 .58361 L F
.187 0 0 r
.30342 .58394 m .30213 .58361 L .30244 .58371 L F
0 0 .315 r
.30213 .58361 m .30226 .58565 L .3016 .58342 L F
.30213 .58361 m .3016 .58342 L .30147 .58299 L F
0 .136 .641 r
.34615 .62108 m .34742 .62256 L .34508 .62061 L F
.418 .329 .648 r
.34742 .62256 m .34567 .62363 L .34508 .62061 L F
.37 .315 .665 r
.32661 .64302 m .32898 .64468 L .32914 .64131 L F
.32661 .64302 m .32735 .64517 L .32898 .64468 L F
.523 .498 .771 r
.35277 .64481 m .35057 .64544 L .3488 .64121 L F
.459 .23 .479 r
.35261 .64751 m .35057 .64544 L .35277 .64481 L F
.35261 .64751 m .35024 .64805 L .35057 .64544 L F
.367 .48 .842 r
.29638 .64364 m .29512 .64572 L .29292 .64305 L F
.303 0 0 r
.2986 .64629 m .29512 .64572 L .29548 .64838 L F
.757 .738 .835 r
.29638 .64364 m .29548 .64838 L .29512 .64572 L F
.699 .16 0 r
.38199 .52582 m .38596 .52882 L .38404 .52894 L F
.071 0 0 r
.33447 .61719 m .33105 .6202 L .3335 .61963 L F
.052 0 .073 r
.33654 .61646 m .33447 .61719 L .3335 .61963 L F
.526 .332 .56 r
.37194 .63911 m .37439 .64138 L .3743 .63878 L F
.37194 .63911 m .37185 .64194 L .37439 .64138 L F
.37194 .63911 m .37439 .64138 L .3743 .63878 L F
.37194 .63911 m .37185 .64194 L .37439 .64138 L F
.308 .418 .811 r
.22189 .6246 m .22311 .62217 L .22165 .62276 L F
.22189 .6246 m .2246 .6258 L .22311 .62217 L F
.545 .406 .642 r
.38555 .58998 m .38326 .59141 L .38366 .58935 L F
.504 .418 .691 r
.31942 .64155 m .31681 .63967 L .31856 .63836 L F
.31942 .64155 m .31723 .64217 L .31681 .63967 L F
.243 0 0 r
.24649 .54615 m .24841 .54653 L .25086 .5457 L F
.24841 .54653 m .24936 .54652 L .25086 .5457 L F
.755 .657 .753 r
.25335 .54254 m .25086 .5457 L .24962 .54254 L F
.882 .992 .787 r
.25086 .5457 m .25247 .54267 L .24962 .54254 L F
.25086 .5457 m .24996 .544 L .25247 .54267 L F
.371 0 0 r
.25086 .5457 m .2491 .54667 L .25117 .54673 L F
.25086 .5457 m .25117 .54673 L .24996 .544 L F
0 0 0 r
.25247 .54267 m .25264 .54279 L .25438 .54169 L F
.066 0 0 r
.25438 .54169 m .25296 .54288 L .25181 .54331 L F
0 0 0 r
.25264 .54279 m .25269 .54282 L .25438 .54169 L F
.066 0 0 r
.25264 .54279 m .25181 .54331 L .24996 .544 L F
0 0 0 r
.25264 .54279 m .24996 .544 L .25269 .54282 L F
.25247 .54267 m .24996 .544 L .25264 .54279 L F
.066 0 0 r
.25438 .54169 m .25264 .54279 L .24996 .544 L F
0 0 .149 r
.25107 .54651 m .25261 .54301 L .24996 .544 L F
.25125 .54651 m .25265 .54293 L .25107 .54651 L F
.25265 .54293 m .25269 .54282 L .25264 .54293 L F
.25265 .54293 m .25264 .54293 L .25107 .54651 L F
.309 0 0 r
.2557 .5424 m .25551 .54245 L .25438 .54169 L F
.629 .281 .362 r
.25117 .54673 m .25026 .54959 L .25311 .54902 L F
.669 .279 .297 r
.25117 .54673 m .25311 .54902 L .25114 .54819 L F
0 0 .149 r
.25117 .54673 m .25114 .54819 L .25258 .5432 L F
.25117 .54673 m .25266 .54294 L .25265 .54293 L F
.309 0 0 r
.25458 .54261 m .25294 .54291 L .25296 .54288 L F
.25551 .54245 m .25296 .54288 L .25438 .54169 L F
.467 .301 .572 r
.25269 .54282 m .25279 .54294 L .2557 .5424 L F
.25279 .54294 m .25552 .54648 L .2557 .5424 L F
0 0 0 r
.25404 .54356 m .2528 .54325 L .25383 .54295 L F
.25535 .54264 m .25383 .54295 L .2557 .5424 L F
.25404 .54356 m .25383 .54295 L .25535 .54264 L F
.467 .301 .572 r
.25314 .5434 m .25114 .54819 L .25552 .54648 L F
0 0 0 r
.25387 .54369 m .2528 .54325 L .25404 .54356 L F
.25379 .54374 m .25372 .54371 L .25387 .54369 L F
.25372 .54371 m .2528 .54325 L .25387 .54369 L F
.467 .301 .572 r
.25279 .54353 m .25114 .54819 L .25314 .5434 L F
.25293 .54313 m .25279 .54353 L .25314 .5434 L F
.25271 .54317 m .25114 .54819 L .25293 .54313 L F
.25266 .54294 m .25114 .54819 L .25279 .54294 L F
0 0 0 r
.25372 .54371 m .25235 .54338 L .2528 .54325 L F
.25379 .54374 m .25368 .54372 L .25372 .54371 L F
.25368 .54372 m .25235 .54338 L .25372 .54371 L F
.307 .126 .464 r
.25285 .54349 m .25282 .54384 L .25462 .54268 L F
0 0 .149 r
.25117 .54673 m .25258 .5432 L .25256 .54319 L F
.25117 .54673 m .25125 .54651 L .25107 .54651 L F
.493 .513 .806 r
.25269 .54476 m .25159 .548 L .25097 .54638 L F
.527 .479 .746 r
.25311 .54902 m .25552 .54648 L .25114 .54819 L F
.529 .552 .823 r
.25269 .54476 m .25395 .54767 L .25159 .548 L F
.527 .479 .746 r
.25311 .54902 m .25561 .54864 L .25552 .54648 L F
.443 .326 .626 r
.25561 .54864 m .2564 .54549 L .25552 .54648 L F
.729 .2 0 r
.25281 .54464 m .25595 .54699 L .25395 .54767 L F
.753 .271 .093 r
.25286 .54467 m .25437 .54729 L .2538 .54613 L F
0 0 0 r
.25275 .5447 m .25102 .54633 L .25287 .54456 L F
.25287 .54458 m .25287 .54456 L .25373 .54373 L F
.729 .2 0 r
.25286 .54459 m .25595 .54699 L .25281 .54464 L F
.25286 .54459 m .2538 .54613 L .25595 .54699 L F
0 0 0 r
.25373 .54373 m .25278 .54464 L .25235 .54338 L F
.25275 .5447 m .25286 .54457 L .25286 .54459 L F
.729 .2 0 r
.25277 .54452 m .25286 .54459 L .25281 .54464 L F
0 0 0 r
.25379 .54374 m .25102 .54633 L .25377 .54374 L F
.25377 .54374 m .25275 .5447 L .25373 .54373 L F
.487 .505 .801 r
.25281 .5446 m .25282 .54465 L .25286 .54462 L F
.753 .271 .093 r
.25279 .54456 m .25285 .54466 L .25286 .54467 L F
.25277 .54452 m .2528 .54457 L .25279 .54456 L F
.066 0 0 r
.25438 .54169 m .24996 .544 L .25247 .54267 L F
.311 0 .18 r
.25235 .54338 m .25001 .54417 L .24996 .544 L F
.179 0 0 r
.24711 .54645 m .2491 .54667 L .24649 .54615 L F
.24711 .54645 m .24649 .54615 L .24511 .54376 L F
.506 .325 .57 r
.24735 .5436 m .24711 .54645 L .24511 .54376 L F
.984 .766 .529 r
.24539 .54504 m .24711 .54645 L .24735 .5436 L F
.026 0 0 r
.25001 .54417 m .24539 .54504 L .24735 .5436 L F
.421 0 0 r
.24996 .544 m .25001 .54417 L .24735 .5436 L F
0 0 .304 r
.25001 .54417 m .25 .54386 L .24759 .54489 L F
.311 0 .18 r
.25235 .54338 m .25103 .5463 L .25001 .54417 L F
.25103 .5463 m .25101 .54631 L .25001 .54417 L F
.25102 .54633 m .251 .54634 L .25001 .54417 L F
0 0 .304 r
.25001 .54417 m .251 .54634 L .25 .54386 L F
.493 .513 .806 r
.25102 .54633 m .251 .54634 L .25 .54386 L F
0 0 .304 r
.251 .54634 m .25101 .54636 L .25 .54386 L F
.493 .513 .806 r
.251 .54634 m .25095 .54635 L .25 .54386 L F
.503 .609 .891 r
.25095 .54635 m .24759 .54489 L .25 .54386 L F
.243 0 0 r
.24841 .54653 m .2491 .54667 L .24936 .54652 L F
.764 .538 .591 r
.25117 .54673 m .2491 .54667 L .24711 .54645 L F
.873 .55 .436 r
.2478 .54784 m .25117 .54673 L .24711 .54645 L F
.24803 .54828 m .24849 .54805 L .2478 .54784 L F
.24849 .54805 m .25117 .54673 L .2478 .54784 L F
.24803 .54828 m .25026 .54959 L .25117 .54673 L F
.503 .609 .891 r
.25159 .548 m .25091 .54881 L .24759 .54489 L F
.25091 .54881 m .25026 .54959 L .24958 .54839 L F
.25091 .54881 m .24958 .54839 L .24759 .54489 L F
.25159 .548 m .25008 .54682 L .25095 .54635 L F
.25008 .54682 m .24759 .54489 L .25095 .54635 L F
.311 0 .18 r
.25103 .5463 m .25102 .54633 L .25101 .54631 L F
.493 .513 .806 r
.25102 .54633 m .25097 .54638 L .25095 .54635 L F
.311 0 .18 r
.25102 .54633 m .25101 .54636 L .251 .54634 L F
0 0 0 r
.25278 .54464 m .25102 .54633 L .25192 .54435 L F
.493 .513 .806 r
.25269 .54476 m .25102 .54633 L .25 .54386 L F
0 0 0 r
.25278 .54464 m .25192 .54435 L .25235 .54338 L F
.547 .109 .16 r
.25 .54386 m .25277 .54452 L .25285 .54349 L F
.493 .513 .806 r
.25277 .54452 m .25 .54386 L .25285 .54349 L F
.487 .505 .801 r
.25 .54386 m .25286 .54462 L .25188 .5438 L F
.753 .271 .093 r
.2528 .54457 m .25285 .54466 L .25279 .54456 L F
.529 .552 .823 r
.25277 .54452 m .25281 .54464 L .25269 .54476 L F
0 0 0 r
.25224 .54519 m .25101 .54636 L .25102 .54633 L F
.25379 .54374 m .25192 .5455 L .25224 .54519 L F
.25192 .5455 m .25101 .54636 L .25224 .54519 L F
.493 .513 .806 r
.25277 .54452 m .25269 .54476 L .25 .54386 L F
.487 .505 .801 r
.25246 .54455 m .25101 .54636 L .25282 .54465 L F
.25033 .54467 m .25101 .54636 L .25246 .54455 L F
.25 .54386 m .25282 .54465 L .25281 .5446 L F
.738 .72 .835 r
.24759 .54489 m .25026 .54959 L .24803 .54828 L F
.207 0 0 r
.24809 .54597 m .25013 .54676 L .25275 .54454 L F
.25272 .54454 m .25275 .54454 L .25277 .54452 L F
.24809 .54597 m .25275 .54454 L .25272 .54454 L F
.487 .505 .801 r
.25 .54386 m .25033 .54467 L .25246 .54455 L F
.729 .2 0 r
.25277 .54452 m .25279 .54456 L .25286 .54459 L F
.25279 .54456 m .25286 .54462 L .25286 .54459 L F
0 0 0 r
.25286 .54459 m .25287 .54456 L .25287 .54458 L F
.25286 .54457 m .25287 .54456 L .25286 .54459 L F
.307 .126 .464 r
.25282 .54384 m .25277 .54452 L .25357 .54373 L F
.25282 .54384 m .25277 .54452 L .25357 .54373 L F
.487 .505 .801 r
.25188 .5438 m .25286 .54462 L .25379 .54374 L F
.729 .2 0 r
.25279 .54456 m .25286 .54467 L .25286 .54462 L F
.25286 .54467 m .2538 .54613 L .25286 .54459 L F
.753 .271 .093 r
.25277 .54452 m .25013 .54676 L .25242 .54705 L F
.529 .552 .823 r
.25281 .54464 m .25395 .54767 L .25269 .54476 L F
.753 .271 .093 r
.25285 .54466 m .25242 .54705 L .25437 .54729 L F
.25277 .54452 m .25242 .54705 L .25285 .54466 L F
.25285 .54466 m .25437 .54729 L .25286 .54467 L F
.307 .126 .464 r
.25282 .54384 m .25357 .54373 L .2536 .5437 L F
.075 0 0 r
.25301 .54373 m .25387 .54369 L .2557 .5424 L F
.307 .126 .464 r
.25282 .54384 m .25357 .54373 L .25386 .54344 L F
.075 0 0 r
.25301 .54373 m .25516 .54267 L .25301 .54373 L F
.307 .126 .464 r
.25297 .54375 m .25302 .54373 L .25462 .54268 L F
.25282 .54384 m .25386 .54344 L .25297 .54375 L F
.25282 .54384 m .2536 .5437 L .25299 .54373 L F
.075 0 0 r
.253 .54374 m .25387 .54369 L .25301 .54373 L F
.253 .54374 m .25301 .54373 L .25301 .54373 L F
.527 .273 .473 r
.2557 .5424 m .2564 .54549 L .25801 .54151 L F
.2557 .5424 m .25552 .54648 L .2564 .54549 L F
.075 0 0 r
.25301 .54373 m .25516 .54267 L .25687 .54208 L F
.25516 .54267 m .2557 .5424 L .25648 .54219 L F
.25516 .54267 m .25648 .54219 L .25687 .54208 L F
.737 .657 .77 r
.25801 .54151 m .26222 .5425 L .2611 .53931 L F
.722 .508 .599 r
.25801 .54151 m .26173 .54494 L .26222 .5425 L F
.25801 .54151 m .2564 .54549 L .26173 .54494 L F
0 0 0 r
.25918 .54132 m .253 .54374 L .25687 .54208 L F
.597 .947 .91 r
.25462 .54268 m .25302 .54373 L .2535 .54354 L F
.25462 .54268 m .2535 .54354 L .25918 .54132 L F
.316 0 0 r
.2557 .5424 m .25269 .54282 L .25438 .54169 L F
0 0 0 r
.25801 .54151 m .25687 .54208 L .2557 .5424 L F
.597 .947 .91 r
.25462 .54268 m .25918 .54132 L .25707 .54234 L F
.551 .722 .953 r
.25462 .54268 m .25707 .54234 L .25642 .54131 L F
.25462 .54268 m .25642 .54131 L .25533 .53961 L F
.307 .126 .464 r
.25299 .54373 m .2536 .5437 L .25462 .54268 L F
.597 .947 .91 r
.25462 .54268 m .253 .54374 L .25302 .54373 L F
.307 .126 .464 r
.25302 .54373 m .25386 .54344 L .25462 .54268 L F
.075 0 0 r
.253 .54374 m .25379 .54374 L .25387 .54369 L F
.307 .126 .464 r
.25285 .54349 m .25282 .54384 L .25462 .54268 L F
.467 .301 .572 r
.25279 .54294 m .25271 .54317 L .25293 .54313 L F
.25269 .54282 m .25266 .54294 L .25279 .54294 L F
.309 0 0 r
.25551 .54245 m .25383 .54295 L .25294 .54291 L F
.25383 .54295 m .2528 .54325 L .25293 .54294 L F
.25383 .54295 m .25293 .54294 L .25294 .54291 L F
.25551 .54245 m .25294 .54291 L .25458 .54261 L F
.066 0 0 r
.25262 .543 m .25235 .54338 L .24996 .544 L F
.25296 .54288 m .25272 .54308 L .25262 .543 L F
0 0 .149 r
.25256 .54319 m .25258 .5432 L .25264 .54302 L F
.25256 .54319 m .25264 .54302 L .25263 .54301 L F
.066 0 0 r
.25272 .54308 m .25235 .54338 L .25262 .543 L F
0 0 .149 r
.25263 .54301 m .25264 .54302 L .25266 .54294 L F
.25265 .54293 m .25266 .54294 L .25269 .54282 L F
.309 0 0 r
.2528 .54325 m .25235 .54338 L .25272 .54308 L F
.2528 .54325 m .25272 .54308 L .25296 .54288 L F
0 0 .149 r
.25261 .54301 m .25269 .54282 L .24996 .544 L F
0 0 .431 r
.21469 .60043 m .21421 .60223 L .21366 .5981 L F
0 .077 .638 r
.21555 .60265 m .21421 .60223 L .21469 .60043 L F
.21555 .60265 m .21591 .6041 L .21421 .60223 L F
.01 .136 .649 r
.21591 .6041 m .2151 .60441 L .21421 .60223 L F
.502 .862 .988 r
.28879 .55095 m .28805 .55225 L .2901 .55109 L F
.28879 .55095 m .28637 .55164 L .28805 .55225 L F
.991 .795 .542 r
.35874 .65178 m .35471 .65328 L .3542 .65108 L F
.35874 .65178 m .35708 .65088 L .35471 .65328 L F
.35874 .65178 m .35806 .65415 L .35708 .65088 L F
.992 .776 .511 r
.35722 .64742 m .35708 .65088 L .35874 .65178 L F
.991 .795 .542 r
.35708 .65088 m .35806 .65415 L .35874 .65178 L F
.786 .956 .631 r
.35878 .52809 m .36035 .527 L .35641 .5266 L F
.39 .366 .712 r
.37968 .60686 m .37805 .608 L .37767 .60386 L F
0 0 0 r
.37968 .60686 m .3766 .60994 L .37805 .608 L F
.407 .179 .453 r
.31756 .65789 m .3155 .66067 L .31732 .6604 L F
.427 .195 .458 r
.31979 .65729 m .31756 .65789 L .31732 .6604 L F
.31979 .65729 m .31756 .65789 L .31732 .6604 L F
.247 0 .177 r
.20571 .54819 m .20674 .55009 L .2076 .54782 L F
.20571 .54819 m .20462 .55088 L .20674 .55009 L F
.696 .311 .314 r
.24263 .7484 m .24556 .75081 L .2433 .75055 L F
.491 .451 .74 r
.2433 .75055 m .24489 .74795 L .24263 .7484 L F
0 .483 .785 r
.22809 .78523 m .2286 .78556 L .22519 .78446 L F
.834 .481 .387 r
.22519 .78446 m .2286 .78556 L .22681 .7877 L F
.855 .507 0 r
.22822 .78685 m .2286 .78556 L .22809 .78523 L F
0 0 0 r
.22681 .7877 m .2286 .78556 L .22822 .78685 L F
0 0 .418 r
.35968 .65782 m .36044 .65363 L .36209 .65448 L F
.35 .767 .978 r
.36044 .65363 m .36438 .65417 L .36209 .65448 L F
.77 .719 .186 r
.1816 .59979 m .18148 .60055 L .18187 .59938 L F
.989 .771 .385 r
.29898 .59377 m .30002 .59241 L .30048 .59008 L F
.29898 .59377 m .29986 .59503 L .30002 .59241 L F
.325 .679 .978 r
.34943 .51619 m .34891 .51741 L .34722 .51704 L F
0 .169 .703 r
.34891 .51741 m .34943 .51619 L .34722 .51704 L F
.34891 .51741 m .35129 .52015 L .34943 .51619 L F
.498 .381 .651 r
.23423 .75153 m .23663 .7539 L .23671 .75103 L F
.23423 .75153 m .23443 .7543 L .23663 .7539 L F
.612 .463 .655 r
.34776 .63565 m .34481 .63262 L .34676 .63165 L F
.34776 .63565 m .34525 .63657 L .34481 .63262 L F
.837 .55 .504 r
.31988 .66977 m .31735 .67025 L .31802 .66691 L F
.782 .422 .375 r
.31988 .66977 m .31836 .672 L .31735 .67025 L F
.182 0 0 r
.32254 .66981 m .31836 .672 L .31988 .66977 L F
.744 .454 .491 r
.31735 .67025 m .3194 .67065 L .31802 .66691 L F
0 .044 .598 r
.31739 .6631 m .31802 .66691 L .3191 .66541 L F
.426 .289 .591 r
.31802 .66691 m .32171 .67005 L .3191 .66541 L F
.31802 .66691 m .3194 .67065 L .32171 .67005 L F
.595 .047 0 r
.30493 .55411 m .30284 .55434 L .30097 .55338 L F
.04 .609 .742 r
.30683 .55434 m .30284 .55434 L .30493 .55411 L F
.219 .568 .939 r
.29638 .64364 m .29292 .64305 L .29206 .64134 L F
.908 .786 .303 r
.30121 .6426 m .30323 .6423 L .30422 .64156 L F
.30121 .6426 m .30068 .6448 L .30323 .6423 L F
.551 .847 .998 r
.38202 .55995 m .38407 .56102 L .38307 .55883 L F
.42 .375 .702 r
.38407 .56102 m .38537 .5578 L .38307 .55883 L F
.488 .271 .51 r
.3841 .55968 m .38202 .55995 L .38406 .5593 L F
.786 .968 .667 r
.38144 .56439 m .38176 .5631 L .38407 .56102 L F
.38176 .5631 m .38223 .56242 L .38407 .56102 L F
.001 0 0 r
.38407 .56102 m .38186 .56269 L .38433 .56186 L F
.488 .271 .51 r
.38433 .56186 m .38323 .56095 L .3841 .55968 L F
.38323 .56095 m .38202 .55995 L .3841 .55968 L F
.786 .968 .667 r
.38176 .5631 m .38186 .56269 L .38223 .56242 L F
.42 .375 .702 r
.38407 .56102 m .38597 .56035 L .38537 .5578 L F
.001 0 0 r
.38407 .56102 m .38433 .56186 L .38597 .56035 L F
.154 0 0 r
.25437 .55055 m .25064 .55182 L .25178 .55126 L F
0 0 0 r
.27198 .5293 m .27434 .52876 L .27595 .52806 L F
.297 .769 .654 r
.27595 .52806 m .27652 .52778 L .27834 .52778 L F
.27595 .52806 m .27434 .52876 L .27652 .52778 L F
.166 0 .129 r
.20036 .55235 m .2015 .55315 L .20248 .55162 L F
.20036 .55235 m .19949 .55416 L .2015 .55315 L F
.947 .641 .199 r
.36129 .52017 m .36257 .524 L .36156 .52268 L F
.658 .146 .016 r
.36257 .524 m .36184 .52518 L .36156 .52268 L F
.318 .394 .783 r
.26729 .63862 m .26857 .64236 L .2701 .64046 L F
.292 .355 .757 r
.26857 .64236 m .27093 .64395 L .2701 .64046 L F
.613 .044 0 r
.31154 .64079 m .30989 .63908 L .30952 .64156 L F
.449 .857 .688 r
.35045 .66632 m .3545 .66401 L .35238 .66519 L F
.331 .1 .406 r
.35656 .66262 m .3545 .66401 L .35707 .6608 L F
.456 .854 .663 r
.35238 .66519 m .3545 .66401 L .35656 .66262 L F
.655 .302 .362 r
.30402 .6268 m .30655 .62908 L .30405 .62838 L F
.566 .232 .362 r
.30405 .62838 m .30342 .62858 L .30402 .6268 L F
.30342 .62858 m .30029 .62959 L .30402 .6268 L F
.57 .24 .37 r
.30342 .62858 m .30307 .62958 L .30029 .62959 L F
.30405 .62838 m .30307 .62958 L .30342 .62858 L F
.445 .205 .456 r
.30307 .62958 m .30309 .62955 L .30342 .62858 L F
.516 .103 .196 r
.30029 .62959 m .30307 .62958 L .30227 .63091 L F
.501 .119 .248 r
.30291 .62962 m .30282 .62979 L .30064 .62982 L F
.30282 .62979 m .30227 .63091 L .30189 .63066 L F
.30282 .62979 m .30189 .63066 L .30064 .62982 L F
.667 .212 .164 r
.30227 .63091 m .30043 .63259 L .30022 .6324 L F
.30142 .63084 m .30022 .6324 L .29827 .63058 L F
.30227 .63091 m .30022 .6324 L .30142 .63084 L F
.475 0 0 r
.30142 .63084 m .30109 .63127 L .29827 .63058 L F
.30227 .63091 m .30109 .63127 L .30142 .63084 L F
.621 .24 .3 r
.30043 .63259 m .30109 .63127 L .29827 .63058 L F
.525 .047 .064 r
.29938 .63349 m .30043 .63259 L .29694 .63298 L F
0 0 0 r
.29942 .63344 m .29955 .63328 L .29938 .63349 L F
.30195 .63016 m .29955 .63328 L .29942 .63344 L F
.512 0 0 r
.30062 .63373 m .30043 .63259 L .30182 .6337 L F
.30056 .6337 m .30043 .63259 L .30062 .63373 L F
0 0 0 r
.29959 .63323 m .29938 .63349 L .30078 .63381 L F
.512 0 0 r
.29937 .63332 m .30043 .63259 L .30056 .63373 L F
.4 0 0 r
.30004 .63264 m .30043 .63259 L .29968 .63311 L F
.583 .881 .584 r
.30301 .62961 m .30109 .63127 L .30195 .63016 L F
.30277 .62983 m .30109 .63127 L .30301 .62961 L F
.569 .161 .229 r
.3047 .6306 m .30043 .63259 L .30227 .63091 L F
.3047 .6306 m .30319 .63288 L .30043 .63259 L F
.496 0 .006 r
.30043 .63259 m .30319 .63288 L .30182 .6337 L F
.512 0 0 r
.29869 .63378 m .30062 .63373 L .30136 .63438 L F
.30062 .63373 m .30182 .6337 L .30156 .63409 L F
0 0 0 r
.29959 .63323 m .30078 .63381 L .30174 .63402 L F
.225 .503 .904 r
.30158 .63385 m .30174 .63402 L .29973 .63343 L F
.29953 .63336 m .29973 .63343 L .2993 .6333 L F
.30158 .63385 m .29973 .63343 L .29953 .63336 L F
.512 0 0 r
.30076 .6338 m .30156 .63409 L .30149 .6342 L F
.30062 .63373 m .30156 .63409 L .30076 .6338 L F
.30062 .63373 m .30149 .6342 L .30136 .63438 L F
0 0 0 r
.30195 .63016 m .29962 .63319 L .30174 .63402 L F
.29962 .63319 m .29959 .63323 L .29992 .63335 L F
.29962 .63319 m .29992 .63335 L .30174 .63402 L F
.512 0 0 r
.30056 .63373 m .30056 .6337 L .30062 .63373 L F
.225 .503 .904 r
.2993 .6333 m .29945 .63335 L .29938 .63349 L F
.29945 .63335 m .30078 .63381 L .29938 .63349 L F
.512 0 0 r
.29869 .63378 m .29937 .63332 L .30056 .63373 L F
.225 .503 .904 r
.29945 .63335 m .30174 .63402 L .30078 .63381 L F
.4 0 0 r
.29762 .6329 m .30004 .63264 L .29927 .63329 L F
0 0 0 r
.29967 .63311 m .29982 .63293 L .29955 .63328 L F
.4 0 0 r
.30004 .63264 m .29994 .63277 L .29869 .63378 L F
.29994 .63277 m .29968 .63311 L .29884 .63368 L F
.305 .625 .96 r
.29912 .6333 m .29938 .63349 L .29694 .63298 L F
.4 0 0 r
.29994 .63277 m .29884 .63368 L .29869 .63378 L F
.29694 .63298 m .29762 .6329 L .29924 .63331 L F
.29762 .6329 m .29927 .63329 L .29924 .63331 L F
.305 .625 .96 r
.29589 .63089 m .29912 .6333 L .29694 .63298 L F
.225 .503 .904 r
.29745 .6293 m .29846 .63149 L .29724 .63274 L F
.29846 .63149 m .2993 .6333 L .29725 .63274 L F
.29846 .63149 m .29725 .63274 L .29724 .63274 L F
.2993 .6333 m .29938 .63349 L .29916 .63341 L F
.2993 .6333 m .29916 .63341 L .29718 .63273 L F
0 0 0 r
.30048 .63207 m .30109 .63127 L .29982 .63293 L F
.30048 .63207 m .29982 .63293 L .29967 .63311 L F
.225 .503 .904 r
.29846 .63149 m .30158 .63385 L .2993 .6333 L F
.29745 .6293 m .3002 .63233 L .29846 .63149 L F
.3002 .63233 m .30158 .63385 L .29846 .63149 L F
.582 .808 .985 r
.29785 .63299 m .30136 .63438 L .30193 .63413 L F
.085 0 0 r
.30182 .6337 m .30319 .63288 L .30531 .63245 L F
0 0 .301 r
.30195 .63016 m .30174 .63402 L .30213 .63325 L F
0 0 0 r
.30182 .6337 m .30531 .63245 L .30335 .63351 L F
.30182 .6337 m .30335 .63351 L .30136 .63438 L F
.30195 .63016 m .30109 .63127 L .30048 .63207 L F
.65 .691 .875 r
.30213 .63325 m .30174 .63402 L .29745 .6293 L F
.582 .808 .985 r
.29785 .63299 m .30193 .63413 L .30335 .63351 L F
.29724 .63275 m .29785 .63299 L .30335 .63351 L F
.4 0 0 r
.29694 .63298 m .29924 .63331 L .29913 .63341 L F
0 .491 .76 r
.29718 .63273 m .29916 .63341 L .29694 .63298 L F
.29718 .63273 m .29724 .63275 L .29718 .63273 L F
.29724 .63275 m .29916 .63341 L .29718 .63273 L F
.29916 .63341 m .29938 .63349 L .29694 .63298 L F
.4 0 0 r
.29694 .63298 m .29913 .63341 L .29869 .63378 L F
.582 .808 .985 r
.29739 .63297 m .29985 .63385 L .29737 .63294 L F
.29985 .63385 m .30136 .63438 L .29737 .63294 L F
.29737 .63294 m .30136 .63438 L .29724 .63275 L F
.498 .367 .632 r
.2915 .6294 m .294 .63197 L .29159 .63232 L F
.72 .189 0 r
.29163 .6309 m .294 .63197 L .2915 .6294 L F
.564 .849 .997 r
.29593 .63111 m .294 .63197 L .29163 .6309 L F
.29593 .63111 m .294 .63197 L .29163 .6309 L F
.557 .621 .872 r
.29694 .63298 m .2922 .62945 L .29589 .63089 L F
0 .491 .76 r
.29591 .63092 m .29694 .63298 L .29589 .63089 L F
.29718 .63273 m .29718 .63273 L .29591 .63092 L F
.29718 .63273 m .29694 .63298 L .29591 .63092 L F
.582 .808 .985 r
.29649 .63265 m .29739 .63297 L .29724 .63275 L F
.29649 .63265 m .29718 .63274 L .29708 .63291 L F
.29718 .63274 m .29724 .63275 L .29721 .63278 L F
.29718 .63274 m .29721 .63278 L .29708 .63291 L F
.031 .558 .86 r
.29869 .63378 m .30136 .63438 L .29649 .63265 L F
.582 .808 .985 r
.29708 .63291 m .29858 .63306 L .3014 .63481 L F
.29858 .63306 m .30248 .63343 L .30213 .63388 L F
.29858 .63306 m .30213 .63388 L .3014 .63481 L F
.30248 .63343 m .30335 .63351 L .30306 .63371 L F
.30248 .63343 m .30306 .63371 L .3014 .63481 L F
.29724 .63275 m .30335 .63351 L .29708 .63291 L F
.225 .503 .904 r
.29719 .63266 m .29724 .63274 L .29718 .63273 L F
.29745 .6293 m .29724 .63274 L .29719 .63266 L F
.583 .881 .584 r
.30307 .62958 m .30277 .62983 L .30301 .62961 L F
.445 .205 .456 r
.30307 .62958 m .30342 .62858 L .30342 .62854 L F
.501 .119 .248 r
.30337 .62935 m .30227 .63091 L .30342 .62858 L F
.245 0 0 r
.30655 .62908 m .30615 .62925 L .30405 .62838 L F
.445 .205 .456 r
.30307 .62958 m .30356 .62955 L .3034 .62922 L F
.583 .881 .584 r
.30307 .62958 m .30319 .62959 L .30356 .62955 L F
.245 0 0 r
.30615 .62925 m .30331 .62958 L .30405 .62838 L F
.30331 .62958 m .30319 .62959 L .30337 .62935 L F
.30331 .62958 m .30337 .62935 L .30405 .62838 L F
.445 .205 .456 r
.30388 .6272 m .30629 .62604 L .30402 .6268 L F
.501 .119 .248 r
.30405 .62838 m .30337 .62935 L .30342 .62858 L F
.445 .205 .456 r
.30309 .62955 m .3034 .62922 L .30388 .6272 L F
.3034 .62922 m .30629 .62604 L .30388 .6272 L F
.3034 .62922 m .30525 .62945 L .30629 .62604 L F
.30356 .62955 m .30525 .62945 L .3034 .62922 L F
.245 0 0 r
.30356 .62955 m .30227 .63091 L .30319 .62959 L F
.30615 .62925 m .30388 .63022 L .30356 .62955 L F
.30388 .63022 m .30227 .63091 L .30356 .62955 L F
.583 .881 .584 r
.30307 .62958 m .30301 .62961 L .30319 .62959 L F
.30356 .62955 m .30319 .62959 L .30394 .62953 L F
.30394 .62953 m .30195 .63016 L .30525 .62945 L F
.30301 .62961 m .30195 .63016 L .30394 .62953 L F
.501 .119 .248 r
.30342 .62858 m .30291 .62962 L .30029 .62959 L F
.30291 .62962 m .30064 .62982 L .30029 .62959 L F
.445 .205 .456 r
.30342 .62854 m .30342 .62858 L .30402 .6268 L F
.242 .007 .344 r
.37949 .59878 m .37889 .60146 L .37808 .60145 L F
.192 0 .353 r
.38132 .59792 m .37949 .59878 L .38161 .5953 L F
.5 .233 .441 r
.38134 .60076 m .37949 .59878 L .38132 .59792 L F
.38134 .60076 m .37889 .60146 L .37949 .59878 L F
.633 .284 .361 r
.3538 .55995 m .35032 .56035 L .35089 .55891 L F
.3538 .55995 m .35089 .55891 L .35146 .55961 L F
.446 .213 .465 r
.3539 .55515 m .35146 .55961 L .35089 .55891 L F
.36 .12 .408 r
.35555 .55673 m .3539 .55515 L .3555 .55414 L F
.35555 .55673 m .35146 .55961 L .3539 .55515 L F
.636 .49 .666 r
.36739 .53507 m .37033 .5321 L .36866 .53381 L F
.41 .189 .465 r
.34546 .56435 m .34535 .56677 L .34317 .56739 L F
.604 .508 .718 r
.34757 .56015 m .34834 .56429 L .34546 .56435 L F
.391 .067 .291 r
.34834 .56429 m .34535 .56677 L .34546 .56435 L F
.418 .301 .613 r
.3542 .65108 m .35471 .65328 L .35234 .65351 L F
.594 .488 .703 r
.35563 .65728 m .35234 .65351 L .35471 .65328 L F
.35563 .65728 m .35314 .65804 L .35234 .65351 L F
.033 0 0 r
.33892 .66827 m .3399 .66843 L .33756 .66872 L F
.33892 .66827 m .34171 .66813 L .3399 .66843 L F
.355 .77 .979 r
.36674 .52671 m .36903 .52646 L .3651 .52593 L F
.418 .359 .684 r
.17579 .5896 m .17721 .58528 L .17544 .58603 L F
.43 .28 .575 r
.17647 .57662 m .17861 .57614 L .1785 .5733 L F
.287 .149 .513 r
.17647 .57662 m .17813 .57855 L .17861 .57614 L F
.17647 .57662 m .17654 .5794 L .17813 .57855 L F
.531 .556 .826 r
.27746 .64166 m .27899 .64536 L .28162 .64467 L F
.338 0 0 r
.28215 .64498 m .28267 .64492 L .28162 .64467 L F
.399 .793 .987 r
.28267 .64492 m .28532 .64522 L .28162 .64467 L F
.492 0 0 r
.28162 .64467 m .28532 .64522 L .2839 .64577 L F
0 .292 .686 r
.28037 .64392 m .28162 .64467 L .2839 .64577 L F
.531 .556 .826 r
.27746 .64166 m .27904 .6428 L .27992 .64369 L F
.27904 .6428 m .28162 .64467 L .27992 .64369 L F
0 .292 .686 r
.27992 .64369 m .28162 .64467 L .28037 .64392 L F
.338 0 0 r
.27899 .64536 m .28215 .64498 L .28162 .64467 L F
.275 0 0 r
.28532 .64522 m .2858 .64637 L .2839 .64577 L F
.077 .523 .902 r
.2839 .64577 m .2858 .64637 L .28565 .64621 L F
.28422 .64562 m .28565 .64621 L .28481 .64532 L F
.2839 .64577 m .28565 .64621 L .28422 .64562 L F
.2839 .64577 m .28422 .64562 L .28489 .64604 L F
.28422 .64562 m .28481 .64532 L .28489 .64604 L F
0 .292 .686 r
.28165 .6446 m .2839 .64577 L .28489 .64604 L F
.27992 .64369 m .28165 .6446 L .28489 .64604 L F
.547 0 0 r
.28015 .64393 m .28489 .64604 L .28133 .64512 L F
.27992 .64369 m .28236 .64484 L .28015 .64393 L F
.28236 .64484 m .28489 .64604 L .28015 .64393 L F
.27992 .64369 m .28133 .64512 L .28008 .64479 L F
0 0 0 r
.26688 .62 m .26308 .62296 L .26527 .62204 L F
.26886 .61897 m .26688 .62 L .26527 .62204 L F
.208 0 0 r
.21112 .61628 m .20897 .61568 L .20655 .61497 L F
.309 .704 .978 r
.21112 .61628 m .21138 .6151 L .20897 .61568 L F
.21112 .61628 m .21326 .61629 L .21138 .6151 L F
.387 .253 .574 r
.34524 .56944 m .34317 .56739 L .34535 .56677 L F
.34524 .56944 m .34323 .57029 L .34317 .56739 L F
.225 0 0 r
.32992 .55453 m .32572 .55631 L .32744 .55471 L F
.445 .311 .605 r
.3155 .66067 m .31739 .6631 L .31732 .6604 L F
.502 .349 .605 r
.36473 .62903 m .36274 .63238 L .36352 .6299 L F
.677 .605 .768 r
.28233 .55716 m .28305 .56051 L .28501 .55818 L F
.573 .709 .934 r
.28305 .56051 m .28583 .56077 L .28501 .55818 L F
.579 .132 .154 r
.37606 .52654 m .37322 .52578 L .37487 .52252 L F
.37606 .52654 m .37494 .5267 L .37322 .52578 L F
0 0 .325 r
.3495 .55181 m .35131 .55182 L .35142 .55166 L F
.3495 .55181 m .34928 .55443 L .35131 .55182 L F
.181 .043 .446 r
.3131 .60792 m .31437 .60956 L .31455 .60618 L F
.3131 .60792 m .31294 .61054 L .31437 .60956 L F
.701 .546 .674 r
.31979 .65729 m .32363 .65988 L .3238 .65783 L F
.406 .151 .411 r
.3238 .65783 m .32363 .65988 L .32613 .65721 L F
.3238 .65783 m .32363 .65988 L .32613 .65721 L F
.671 .655 .825 r
.34776 .63565 m .34532 .63796 L .34525 .63657 L F
.567 .627 .871 r
.34863 .63857 m .34532 .63796 L .34776 .63565 L F
.278 0 .135 r
.31579 .64467 m .31723 .64217 L .31942 .64155 L F
.682 .951 .693 r
.36515 .65956 m .36366 .66128 L .36649 .65846 L F
.455 .88 .786 r
.36463 .66044 m .36366 .66128 L .36515 .65956 L F
.36463 .66044 m .36163 .66184 L .36366 .66128 L F
.472 .527 .833 r
.21463 .61811 m .21613 .61575 L .21326 .61629 L F
.21463 .61811 m .21741 .61925 L .21613 .61575 L F
.452 .152 .365 r
.33459 .56049 m .33742 .56 L .33763 .55757 L F
.602 .69 .904 r
.33587 .55516 m .33763 .55757 L .33997 .55678 L F
.65 .317 .396 r
.33742 .56 m .33995 .56008 L .33763 .55757 L F
0 0 0 r
.26654 .72762 m .26767 .72655 L .26958 .72576 L F
.26958 .72576 m .26767 .72655 L .26654 .72762 L F
0 0 .517 r
.1763 .59194 m .17712 .59614 L .17765 .59432 L F
0 .166 .703 r
.17712 .59614 m .17836 .59615 L .17765 .59432 L F
.17712 .59614 m .17928 .59864 L .17836 .59615 L F
.321 .451 .836 r
.37002 .52694 m .37081 .53013 L .37213 .52798 L F
.36941 .52725 m .37081 .53013 L .37002 .52694 L F
.36903 .52646 m .37213 .52798 L .37058 .52664 L F
0 0 0 r
.37186 .52657 m .37058 .52664 L .37213 .52798 L F
.37186 .52657 m .3701 .52798 L .37057 .52667 L F
.37063 .52664 m .37057 .52667 L .37058 .52664 L F
.37186 .52657 m .37057 .52667 L .37063 .52664 L F
.321 .451 .836 r
.36903 .52646 m .36941 .52725 L .37002 .52694 L F
.597 .557 .78 r
.37033 .5321 m .37213 .52798 L .37081 .53013 L F
.079 0 .252 r
.31129 .58598 m .30916 .58936 L .31075 .58823 L F
.503 .206 .395 r
.30916 .58936 m .31101 .59125 L .31075 .58823 L F
.30916 .58936 m .30841 .59199 L .31101 .59125 L F
.691 .754 .9 r
.23484 .61237 m .23645 .61409 L .2325 .61346 L F
.53 .61 .877 r
.23725 .61075 m .23645 .61409 L .23484 .61237 L F
.23725 .61075 m .23848 .61349 L .23645 .61409 L F
.419 .231 .516 r
.23848 .61349 m .23825 .61645 L .23645 .61409 L F
.138 .156 .616 r
.23645 .61409 m .23825 .61645 L .23696 .61606 L F
0 0 .291 r
.31052 .56951 m .31004 .57234 L .30853 .57346 L F
.11 0 .103 r
.30962 .57496 m .30853 .57346 L .31004 .57234 L F
.30962 .57496 m .30764 .57599 L .30853 .57346 L F
.169 0 0 r
.2134 .54478 m .21565 .5442 L .21746 .5423 L F
0 0 0 r
.21746 .5423 m .21767 .54329 L .21996 .54206 L F
.21746 .5423 m .21565 .5442 L .21767 .54329 L F
.195 .006 .381 r
.36603 .57315 m .36841 .5723 L .36888 .56974 L F
.1 0 .337 r
.36671 .57534 m .36841 .5723 L .36603 .57315 L F
.392 .78 .989 r
.28305 .52686 m .28247 .52813 L .28048 .52742 L F
.28305 .52686 m .28495 .52771 L .28247 .52813 L F
.586 .358 .537 r
.32819 .62278 m .33105 .6202 L .3287 .62054 L F
0 .074 .623 r
.28211 .62486 m .2833 .62863 L .28159 .62655 L F
.26 .172 .562 r
.28159 .62655 m .2833 .62863 L .28171 .62938 L F
.648 .57 .753 r
.51252 .55518 m .51381 .55086 L .51126 .55129 L F
.51252 .55518 m .51513 .55448 L .51381 .55086 L F
.712 .484 .578 r
.53701 .55075 m .53452 .55185 L .53438 .54899 L F
.553 .084 0 r
.32985 .62445 m .33044 .6252 L .32819 .62278 L F
.314 .204 .566 r
.39382 .56921 m .39187 .56708 L .39337 .56671 L F
.39382 .56921 m .39205 .57136 L .39187 .56708 L F
0 .234 .625 r
.37831 .56268 m .37953 .56334 L .38144 .56439 L F
.015 .291 .787 r
.38186 .56269 m .38286 .5645 L .38144 .56439 L F
0 .211 .727 r
.38286 .56454 m .38144 .56439 L .37953 .56334 L F
.015 .292 .787 r
.38144 .56439 m .38388 .56642 L .38286 .5645 L F
0 .211 .727 r
.38286 .56454 m .38388 .56642 L .38144 .56439 L F
.945 .61 .19 r
.35672 .62945 m .35501 .628 L .35518 .62607 L F
.272 .738 .947 r
.28726 .52733 m .29095 .52767 L .28906 .52811 L F
.045 0 .105 r
.29628 .60295 m .29556 .60216 L .29787 .60122 L F
.29628 .60295 m .29478 .60408 L .29556 .60216 L F
.634 .585 .781 r
.35133 .63827 m .3488 .64121 L .34863 .63857 L F
.643 .598 .789 r
.35133 .63827 m .35268 .64208 L .3488 .64121 L F
.523 .498 .771 r
.35277 .64481 m .3488 .64121 L .35268 .64208 L F
.479 0 0 r
.30652 .64329 m .30422 .64156 L .30323 .6423 L F
.30652 .64329 m .30667 .64307 L .30422 .64156 L F
.594 .073 0 r
.30667 .64307 m .3074 .64243 L .30422 .64156 L F
.535 .059 .073 r
.26635 .55811 m .2641 .55997 L .26232 .55925 L F
.443 0 0 r
.26834 .55923 m .26635 .55811 L .26859 .5577 L F
.26834 .55923 m .2641 .55997 L .26635 .55811 L F
0 0 .26 r
.20375 .57585 m .20206 .5787 L .20175 .57694 L F
0 0 0 r
.35827 .62092 m .3585 .61875 L .36133 .61956 L F
.565 .698 .931 r
.27187 .72155 m .26994 .72321 L .26803 .72222 L F
.27187 .72155 m .27261 .72297 L .26994 .72321 L F
.54 .269 .453 r
.26994 .72321 m .27198 .72546 L .26958 .72576 L F
.26994 .72321 m .27261 .72297 L .27237 .72392 L F
.26994 .72321 m .27237 .72392 L .27117 .72457 L F
.548 .434 .676 r
.26946 .72549 m .27187 .72155 L .26803 .72222 L F
.26958 .72576 m .26983 .7253 L .26946 .72549 L F
.26983 .7253 m .27187 .72155 L .26946 .72549 L F
.54 .269 .453 r
.27117 .72457 m .27237 .72392 L .27198 .72546 L F
.288 0 0 r
.2753 .55561 m .27483 .5564 L .27264 .55678 L F
.331 0 0 r
.2753 .55561 m .2773 .55617 L .27483 .5564 L F
.418 .359 .684 r
.17579 .5896 m .17742 .58937 L .17721 .58528 L F
.201 .112 .525 r
.1763 .59194 m .17742 .58937 L .17579 .5896 L F
.862 .692 .669 r
.32791 .53498 m .33146 .53309 L .32832 .53261 L F
.32791 .53498 m .33038 .53573 L .33146 .53309 L F
.065 0 .058 r
.36338 .54311 m .36284 .54462 L .36581 .54176 L F
.69 .147 0 r
.23968 .62009 m .24388 .62311 L .24187 .6225 L F
.935 .924 .774 r
.36132 .61386 m .35951 .61638 L .36134 .61689 L F
.36 .217 .548 r
.34861 .62595 m .34614 .62755 L .34476 .62569 L F
.34861 .62595 m .34819 .62901 L .34614 .62755 L F
.213 .239 .672 r
.34614 .62755 m .34819 .62901 L .34685 .62931 L F
.934 .969 .725 r
.36953 .53693 m .36967 .53961 L .37172 .53591 L F
.569 .934 .923 r
.37426 .53464 m .37278 .5346 L .37172 .53591 L F
.636 .49 .666 r
.36739 .53507 m .37105 .53607 L .37033 .5321 L F
.421 .353 .675 r
.37033 .5321 m .37129 .53589 L .37278 .5346 L F
.598 .936 .747 r
.37205 .5355 m .3709 .53623 L .37172 .53591 L F
.37242 .53504 m .37105 .53607 L .37205 .5355 L F
.37278 .5346 m .3705 .53648 L .37242 .53504 L F
.421 .353 .675 r
.37129 .53589 m .37136 .53615 L .37278 .5346 L F
.598 .936 .747 r
.3709 .53623 m .3705 .53648 L .37073 .53637 L F
.3709 .53623 m .37073 .53637 L .37172 .53591 L F
.37105 .53607 m .3705 .53648 L .37205 .5355 L F
.586 .223 .319 r
.37105 .53607 m .36953 .53693 L .37136 .53615 L F
.36739 .53507 m .36953 .53693 L .37105 .53607 L F
.636 .49 .666 r
.37105 .53607 m .37136 .53615 L .37129 .53589 L F
.37105 .53607 m .37129 .53589 L .37033 .5321 L F
.598 .936 .747 r
.37278 .5346 m .36953 .53693 L .3705 .53648 L F
.468 .012 .085 r
.3395 .64336 m .34313 .64147 L .33998 .64449 L F
.3395 .64336 m .3409 .64387 L .34313 .64147 L F
.453 .581 .892 r
.34313 .64147 m .34317 .6382 L .34136 .63812 L F
.6 .162 .179 r
.34313 .64147 m .3409 .64387 L .34426 .64364 L F
.556 .417 .647 r
.35441 .62354 m .35272 .62664 L .35518 .62607 L F
.35441 .62354 m .35272 .62664 L .35518 .62607 L F
.107 .073 .533 r
.32647 .65461 m .32739 .65453 L .3277 .65046 L F
.123 .245 .719 r
.32647 .65461 m .32867 .65669 L .32739 .65453 L F
.512 .285 .506 r
.32647 .65461 m .32613 .65721 L .32867 .65669 L F
.32647 .65461 m .32613 .65721 L .32867 .65669 L F
0 .152 .667 r
.37851 .53585 m .37848 .53518 L .37694 .53446 L F
.37851 .53585 m .38123 .53814 L .37848 .53518 L F
.548 .594 .852 r
.35707 .6608 m .35314 .65804 L .35563 .65728 L F
.755 .663 .759 r
.35968 .65782 m .35707 .6608 L .35563 .65728 L F
.468 0 0 r
.35707 .6608 m .35776 .66246 L .35656 .66262 L F
.35707 .6608 m .35899 .66175 L .35776 .66246 L F
.322 .681 .978 r
.23771 .76552 m .23721 .76678 L .23556 .76646 L F
.23771 .76552 m .23992 .76707 L .23721 .76678 L F
.23721 .76678 m .23771 .76552 L .23556 .76646 L F
.23721 .76678 m .23992 .76707 L .23771 .76552 L F
.23771 .76552 m .23992 .76707 L .23721 .76678 L F
.584 .304 .458 r
.3839 .59748 m .38132 .59792 L .38161 .5953 L F
.556 .308 .495 r
.38423 .59503 m .3839 .59748 L .38161 .5953 L F
.617 .464 .651 r
.28945 .59458 m .28677 .59791 L .28809 .59576 L F
.394 .477 .827 r
.36409 .5883 m .36453 .58474 L .36214 .58458 L F
.36409 .5883 m .36607 .58836 L .36453 .58474 L F
.56 .325 .517 r
.51327 .54541 m .51599 .54515 L .51599 .54216 L F
.532 .365 .6 r
.51599 .54216 m .51868 .54177 L .51866 .53918 L F
.563 .328 .517 r
.51599 .54216 m .51867 .54463 L .51868 .54177 L F
.51599 .54216 m .51599 .54515 L .51867 .54463 L F
.681 .711 .87 r
.51896 .55745 m .52283 .55831 L .52177 .55635 L F
.635 .689 .883 r
.52177 .55635 m .52283 .55831 L .52535 .55744 L F
.312 0 .084 r
.26355 .54538 m .262 .54774 L .25952 .54824 L F
.249 0 .049 r
.26426 .54708 m .262 .54774 L .26355 .54538 L F
.558 .639 .887 r
.31519 .58446 m .31514 .58839 L .31337 .58522 L F
.879 .964 .847 r
.36953 .53693 m .36834 .53913 L .36967 .53961 L F
0 0 0 r
.20206 .5787 m .20157 .58214 L .20145 .58211 L F
0 0 .14 r
.20157 .58214 m .2018 .58472 L .20145 .58211 L F
.975 .694 .431 r
.23413 .62983 m .23291 .63084 L .23275 .62968 L F
.375 0 0 r
.23538 .62998 m .23413 .62983 L .23237 .62912 L F
.975 .694 .431 r
.23413 .62983 m .2325 .62789 L .23237 .62912 L F
0 .082 .643 r
.2325 .62789 m .2329 .62883 L .23237 .62912 L F
.13 .66 .867 r
.23237 .62912 m .2329 .62883 L .22852 .62867 L F
.467 .694 .966 r
.22852 .62867 m .2329 .62883 L .22997 .62679 L F
.74 .746 .857 r
.22997 .62679 m .2329 .62883 L .2325 .62789 L F
.975 .694 .431 r
.23413 .62983 m .23275 .62968 L .2325 .62789 L F
.375 0 0 r
.23631 .63024 m .23413 .62983 L .23538 .62998 L F
0 .256 .701 r
.23631 .63024 m .23747 .6306 L .23413 .62983 L F
.23631 .63024 m .23889 .63179 L .23747 .6306 L F
.275 0 0 r
.28532 .64522 m .28727 .64523 L .2858 .64637 L F
0 0 0 r
.30916 .59497 m .30749 .5986 L .30833 .597 L F
.096 .409 .86 r
.30765 .59927 m .31109 .60232 L .30945 .60092 L F
.191 .192 .629 r
.30749 .5986 m .30945 .60092 L .30833 .597 L F
.30749 .5986 m .30765 .59927 L .30945 .60092 L F
.693 .569 .711 r
.37987 .55797 m .38307 .55883 L .38229 .55476 L F
.269 .033 .359 r
.38187 .55704 m .37987 .55797 L .38229 .55476 L F
.551 .847 .998 r
.38202 .55995 m .38307 .55883 L .37987 .55797 L F
.389 .27 .594 r
.38187 .55704 m .38202 .55995 L .37987 .55797 L F
0 .04 .587 r
.21663 .60647 m .2151 .60441 L .21591 .6041 L F
.521 .254 .45 r
.37215 .55462 m .37476 .55418 L .37502 .55186 L F
.457 .236 .489 r
.37502 .55186 m .37736 .55125 L .37803 .54868 L F
.498 .262 .488 r
.37476 .55418 m .37736 .55125 L .37502 .55186 L F
.488 .561 .856 r
.2182 .62123 m .21947 .61886 L .21741 .61925 L F
.2182 .62123 m .22165 .62276 L .21947 .61886 L F
.577 .226 .337 r
.35089 .55891 m .35032 .56035 L .34757 .56015 L F
.622 .683 .886 r
.31668 .52566 m .32072 .52715 L .31821 .52788 L F
.425 .675 .966 r
.33374 .5553 m .33587 .55516 L .33456 .55353 L F
.787 .288 0 r
.35272 .5798 m .3542 .58211 L .35638 .58289 L F
.355 .781 .973 r
.3542 .58211 m .3568 .58204 L .35638 .58289 L F
.478 .567 .867 r
.3542 .58211 m .35638 .58289 L .3568 .58204 L F
.14 0 .414 r
.35753 .58444 m .35611 .58561 L .35638 .58289 L F
.478 .567 .867 r
.3542 .58211 m .35753 .58444 L .35638 .58289 L F
.794 .801 .858 r
.36921 .6473 m .3671 .64828 L .36935 .64581 L F
.595 .298 .434 r
.36921 .6473 m .36924 .65041 L .3671 .64828 L F
.381 .428 .785 r
.36935 .64581 m .37201 .64762 L .36921 .6473 L F
.419 .163 .417 r
.37201 .64762 m .36924 .65041 L .36921 .6473 L F
.755 .663 .759 r
.35968 .65782 m .35563 .65728 L .35797 .65805 L F
0 0 .418 r
.35968 .65782 m .36064 .65705 L .36044 .65363 L F
.043 0 0 r
.35797 .65805 m .36064 .65705 L .35968 .65782 L F
.508 .808 .999 r
.36054 .63299 m .36274 .63238 L .35873 .63191 L F
.557 .712 .944 r
.18945 .60222 m .19473 .60544 L .19389 .60366 L F
.01 0 .007 r
.29478 .60408 m .29186 .60689 L .29304 .6051 L F
.618 .417 .588 r
.52502 .53888 m .52739 .53926 L .52764 .53614 L F
.43 .193 .451 r
.31075 .58823 m .31337 .58522 L .31129 .58598 L F
.896 .876 .809 r
.2018 .58472 m .19974 .58806 L .20152 .58897 L F
0 .125 .67 r
.19974 .58806 m .20132 .59176 L .20152 .58897 L F
.639 .451 .613 r
.36564 .58402 m .36702 .57901 L .3655 .5787 L F
.554 .301 .486 r
.35307 .56984 m .35591 .56734 L .35171 .56668 L F
.35307 .56984 m .35557 .56975 L .35591 .56734 L F
.35591 .56734 m .35557 .56975 L .35307 .56984 L F
.882 .757 .253 r
.35591 .56734 m .3553 .56643 L .35539 .56651 L F
.35591 .56734 m .35557 .56975 L .35524 .5666 L F
.3553 .56643 m .35524 .5666 L .35521 .5663 L F
.35591 .56734 m .35524 .5666 L .3553 .56643 L F
.434 0 0 r
.35524 .5666 m .3557 .56677 L .35539 .56651 L F
.3549 .5668 m .35517 .56679 L .35524 .5666 L F
.35517 .56679 m .3557 .56677 L .35524 .5666 L F
.589 .331 .494 r
.35848 .56937 m .35591 .56734 L .35796 .56621 L F
.434 0 0 r
.3557 .56677 m .35857 .56667 L .35539 .56651 L F
.882 .757 .253 r
.3553 .56643 m .35521 .5663 L .35539 .56651 L F
.589 .331 .494 r
.35848 .56937 m .35557 .56975 L .35591 .56734 L F
.525 .321 .546 r
.29934 .54874 m .30217 .54824 L .3026 .54542 L F
.438 .21 .469 r
.2992 .55053 m .30217 .54824 L .29934 .54874 L F
.476 .851 .623 r
.28386 .61601 m .28346 .61618 L .28237 .61714 L F
.987 .828 .441 r
.28116 .61905 m .28191 .61976 L .28237 .61714 L F
.28116 .61905 m .28237 .61714 L .28346 .61618 L F
.257 .59 .948 r
.29991 .69142 m .29871 .69192 L .29727 .69051 L F
.29727 .69051 m .29871 .69192 L .29991 .69142 L F
.998 .803 .458 r
.30916 .59497 m .3088 .59573 L .30841 .59199 L F
.217 0 .011 r
.3088 .59573 m .30833 .597 L .31057 .59649 L F
0 0 0 r
.30916 .59497 m .30833 .597 L .3088 .59573 L F
.04 0 .437 r
.39255 .5786 m .39256 .58126 L .39079 .58204 L F
.373 .206 .522 r
.39256 .58126 m .39052 .58422 L .39079 .58204 L F
.975 .836 .642 r
.29337 .58128 m .29196 .58235 L .29132 .58126 L F
.497 .04 .097 r
.29132 .58126 m .2953 .58021 L .29337 .58128 L F
0 0 0 r
.24628 .53188 m .24866 .53149 L .25041 .53101 L F
.137 .68 .708 r
.24866 .53149 m .25273 .53077 L .25041 .53101 L F
.196 0 .305 r
.36799 .65588 m .36515 .65956 L .36649 .65846 L F
.143 .477 .897 r
.20655 .61497 m .20671 .61329 L .20533 .61285 L F
.20655 .61497 m .20897 .61568 L .20671 .61329 L F
.523 .492 .764 r
.37889 .60146 m .37767 .60386 L .37808 .60145 L F
.37889 .60146 m .37931 .60359 L .37767 .60386 L F
.39 .366 .712 r
.37968 .60686 m .37767 .60386 L .37931 .60359 L F
.823 .933 .903 r
.28702 .60084 m .28884 .60181 L .28567 .60394 L F
.556 .869 .995 r
.29088 .60091 m .28884 .60181 L .28702 .60084 L F
.329 .572 .928 r
.19515 .6056 m .19546 .60357 L .19389 .60366 L F
.19515 .6056 m .19873 .60679 L .19546 .60357 L F
.125 .466 .891 r
.31109 .60232 m .31452 .60254 L .30945 .60092 L F
.31109 .60232 m .31444 .6041 L .31452 .60254 L F
.563 .482 .721 r
.38229 .55476 m .38307 .55883 L .38537 .5578 L F
.474 .285 .543 r
.24063 .56038 m .24279 .56295 L .24307 .55989 L F
.309 .794 .895 r
.26159 .52978 m .26564 .52948 L .26333 .5301 L F
0 0 .238 r
.30562 .56091 m .30675 .56206 L .30742 .55975 L F
.30562 .56091 m .30494 .56379 L .30675 .56206 L F
.162 .402 .846 r
.19873 .60679 m .19899 .60811 L .19962 .60644 L F
.205 .454 .875 r
.19899 .60811 m .20194 .60951 L .19962 .60644 L F
.418 .774 .996 r
.26086 .63769 m .26162 .63642 L .25879 .63601 L F
.26086 .63769 m .26328 .63748 L .26162 .63642 L F
0 0 0 r
.19432 .55767 m .1961 .55692 L .19732 .55487 L F
.138 0 0 r
.1961 .55692 m .19949 .55416 L .19732 .55487 L F
.162 0 .052 r
.39883 .55929 m .39615 .56065 L .39957 .55788 L F
.487 .249 .479 r
.40113 .55718 m .39883 .55929 L .39957 .55788 L F
.339 .095 .39 r
.38487 .55165 m .38462 .55396 L .38229 .55476 L F
.563 .482 .721 r
.38229 .55476 m .38537 .5578 L .38462 .55396 L F
.435 .214 .478 r
.38462 .55396 m .38187 .55704 L .38229 .55476 L F
.339 .095 .39 r
.38229 .55476 m .38462 .55396 L .38487 .55165 L F
.38487 .55165 m .38462 .55396 L .38229 .55476 L F
.38487 .55165 m .38462 .55396 L .38229 .55476 L F
.372 .781 .981 r
.34252 .54068 m .34614 .54111 L .34381 .54144 L F
.49 0 0 r
.33326 .53454 m .33919 .53756 L .33706 .5378 L F
0 .558 .734 r
.24388 .62311 m .24605 .62322 L .24796 .62343 L F
.086 .62 .864 r
.24413 .62206 m .24723 .62244 L .24727 .62246 L F
.268 0 0 r
.2478 .62292 m .25035 .62249 L .24825 .62331 L F
.24843 .62281 m .24881 .623 L .25035 .62249 L F
.24605 .62322 m .2478 .62292 L .24796 .62343 L F
.24605 .62322 m .24881 .623 L .24843 .62281 L F
.58 .083 .039 r
.24881 .623 m .25079 .62439 L .25215 .6232 L F
0 .195 .694 r
.24904 .62251 m .25005 .6236 L .24881 .623 L F
.25005 .6236 m .25079 .62439 L .24881 .623 L F
.086 .62 .864 r
.24762 .62276 m .24727 .62246 L .24881 .623 L F
.24413 .62206 m .24727 .62246 L .24762 .62276 L F
.268 0 0 r
.2478 .62292 m .24825 .62331 L .24796 .62343 L F
.617 .168 .163 r
.36558 .64204 m .36085 .64335 L .36171 .64212 L F
.36554 .64207 m .36085 .64335 L .36558 .64204 L F
.36567 .64203 m .36354 .64402 L .36085 .64335 L F
.958 .788 .343 r
.36058 .64086 m .36354 .64402 L .36478 .64128 L F
.98 .914 .617 r
.36339 .64222 m .36352 .64383 L .36478 .64128 L F
.36352 .64383 m .36354 .64402 L .36368 .64369 L F
.36352 .64383 m .36368 .64369 L .36478 .64128 L F
.617 .168 .163 r
.36567 .64203 m .36554 .64207 L .36558 .64204 L F
.939 .617 .174 r
.36424 .63842 m .36478 .64128 L .36567 .64203 L F
.983 .908 .626 r
.36478 .64128 m .36354 .64402 L .36567 .64203 L F
.273 .24 .639 r
.33745 .64048 m .33596 .64254 L .33536 .63982 L F
.46 .793 .999 r
.28583 .56077 m .28746 .55972 L .28928 .56083 L F
.711 .538 .653 r
.28928 .56083 m .28572 .56403 L .28583 .56077 L F
0 0 .408 r
.28583 .56077 m .28726 .56235 L .28746 .55972 L F
.28583 .56077 m .28572 .56403 L .28726 .56235 L F
.509 .24 .442 r
.3518 .58204 m .3542 .58211 L .35272 .5798 L F
.894 .791 .739 r
.30938 .55402 m .31337 .55163 L .31081 .55196 L F
.30938 .55402 m .31158 .55513 L .31337 .55163 L F
.747 .59 .682 r
.31337 .55163 m .31158 .55513 L .31363 .55509 L F
.447 .363 .668 r
.31337 .55163 m .31635 .55327 L .31611 .55128 L F
.31337 .55163 m .31363 .55509 L .31635 .55327 L F
.448 .463 .782 r
.36697 .56085 m .3685 .56535 L .36994 .5626 L F
.453 .469 .785 r
.3685 .56535 m .37145 .56649 L .36994 .5626 L F
.547 0 0 r
.2471 .63476 m .25071 .6357 L .24873 .6356 L F
.496 .89 .952 r
.24873 .6356 m .25071 .6357 L .25284 .63487 L F
0 0 0 r
.22922 .537 m .22898 .53655 L .22698 .53764 L F
.22922 .537 m .23126 .53612 L .22898 .53655 L F
.559 .169 .26 r
.21011 .57095 m .21217 .57264 L .20956 .5723 L F
.406 .214 .504 r
.21256 .56961 m .21217 .57264 L .21011 .57095 L F
.237 .733 .912 r
.26989 .54539 m .26813 .54497 L .26584 .54513 L F
.221 0 0 r
.27236 .54567 m .26813 .54497 L .26989 .54539 L F
.735 .858 .938 r
.33251 .56972 m .33407 .57077 L .3369 .56974 L F
.575 .097 .082 r
.52739 .53926 m .5302 .54083 L .53153 .53913 L F
.757 .314 .201 r
.53153 .53913 m .5302 .54083 L .53375 .54141 L F
.584 .378 .567 r
.3585 .61875 m .36123 .61922 L .36273 .61901 L F
.3585 .61875 m .35854 .62144 L .36123 .61922 L F
.697 .562 .699 r
.36123 .61922 m .35855 .62014 L .35884 .61836 L F
0 0 0 r
.35842 .6212 m .35852 .62036 L .3585 .61875 L F
.35827 .62092 m .35617 .62222 L .35854 .62144 L F
.575 .646 .883 r
.35854 .62144 m .35617 .62222 L .35576 .62154 L F
.35701 .62052 m .35576 .62154 L .35402 .61874 L F
.35854 .62144 m .35576 .62154 L .35671 .62077 L F
.697 .562 .699 r
.35671 .62077 m .35854 .62144 L .35614 .62096 L F
0 0 0 r
.35827 .62092 m .35842 .6212 L .3585 .61875 L F
.35842 .6212 m .35854 .62144 L .35852 .62036 L F
.697 .562 .699 r
.36123 .61922 m .35854 .62144 L .35671 .62077 L F
.575 .646 .883 r
.35854 .62144 m .35671 .62077 L .35701 .62052 L F
.35854 .62144 m .35701 .62052 L .35614 .62096 L F
.35701 .62052 m .35402 .61874 L .35614 .62096 L F
.697 .562 .699 r
.35855 .62014 m .35671 .62077 L .35701 .62052 L F
.3586 .61973 m .35701 .62052 L .35867 .61918 L F
.35855 .62014 m .35701 .62052 L .3586 .61973 L F
.35867 .61918 m .35614 .62096 L .35876 .61843 L F
.35671 .62077 m .35614 .62096 L .35867 .61918 L F
.35855 .62014 m .35876 .61843 L .35884 .61836 L F
.327 .188 .535 r
.32898 .64468 m .32735 .64517 L .32919 .64715 L F
.218 .173 .591 r
.32735 .64517 m .32778 .64799 L .32919 .64715 L F
.562 .278 .443 r
.38487 .55165 m .38716 .55365 L .38462 .55396 L F
.38487 .55165 m .38716 .55365 L .38462 .55396 L F
.933 .784 .673 r
.29007 .59473 m .2915 .59851 L .28945 .59722 L F
.987 .775 .533 r
.2915 .59851 m .29088 .60091 L .29007 .59473 L F
0 0 0 r
.3014 .57352 m .30357 .5729 L .30397 .56958 L F
.024 0 .467 r
.3014 .57352 m .30358 .57417 L .30357 .5729 L F
.3014 .57352 m .30161 .57623 L .30358 .57417 L F
0 .48 .831 r
.2553 .6343 m .25733 .63544 L .25757 .63505 L F
0 .368 .788 r
.25733 .63544 m .25879 .63601 L .25757 .63505 L F
.651 .878 .518 r
.32001 .59059 m .31915 .59203 L .32149 .58896 L F
0 .078 .608 r
.32001 .59059 m .3207 .59464 L .31915 .59203 L F
.735 .858 .938 r
.33251 .56972 m .3369 .56974 L .33478 .56874 L F
.66 .893 .981 r
.33735 .5676 m .3369 .56974 L .33936 .5692 L F
.33735 .5676 m .33478 .56874 L .3369 .56974 L F
0 .087 .636 r
.3369 .56974 m .33855 .57121 L .33936 .5692 L F
0 .026 .562 r
.35441 .62354 m .35518 .62607 L .35495 .6228 L F
.432 .609 .922 r
.21437 .5962 m .21366 .5981 L .21141 .59528 L F
0 0 .452 r
.21437 .5962 m .21469 .60043 L .21366 .5981 L F
.643 .575 .763 r
.51126 .55129 m .51366 .54837 L .51094 .54902 L F
.647 .581 .767 r
.51381 .55086 m .51366 .54837 L .51126 .55129 L F
.246 .64 .961 r
.35131 .55182 m .3555 .55414 L .35641 .55196 L F
.35134 .55177 m .35641 .55196 L .35142 .55166 L F
.35231 .55185 m .35641 .55196 L .35134 .55177 L F
.97 .901 .542 r
.35636 .5503 m .3555 .55414 L .35641 .55196 L F
.35636 .5503 m .3555 .55414 L .35641 .55196 L F
.613 .539 .747 r
.35513 .55208 m .35682 .55282 L .35456 .553 L F
.35622 .55032 m .35667 .5522 L .35513 .55208 L F
.35667 .5522 m .35682 .55282 L .35513 .55208 L F
.246 .64 .961 r
.35131 .55182 m .35231 .55185 L .35134 .55177 L F
.481 .077 .196 r
.25818 .55684 m .2606 .55696 L .26225 .5546 L F
.174 0 .011 r
.26225 .5546 m .26284 .55608 L .26487 .55466 L F
.711 .564 .687 r
.34742 .62256 m .34476 .62569 L .34567 .62363 L F
.651 .878 .518 r
.32001 .59059 m .32149 .58896 L .31933 .58822 L F
.681 .799 .938 r
.28459 .68631 m .28698 .68536 L .28295 .68495 L F
.432 .834 .977 r
.26564 .52948 m .26791 .52896 L .26964 .5295 L F
.359 .787 .971 r
.26791 .52896 m .27198 .5293 L .26964 .5295 L F
.201 .112 .525 r
.1763 .59194 m .17757 .59147 L .17742 .58937 L F
.194 .096 .507 r
.1763 .59194 m .17765 .59432 L .17757 .59147 L F
.515 .336 .576 r
.37736 .55125 m .37981 .54762 L .37803 .54868 L F
.527 .249 .437 r
.22294 .55662 m .22235 .55925 L .21979 .55708 L F
.21979 .55708 m .22235 .55925 L .22294 .55662 L F
.608 .305 .431 r
.28481 .59413 m .28569 .59416 L .28327 .59212 L F
0 0 .243 r
.30854 .65088 m .3089 .64835 L .31004 .64711 L F
0 0 .01 r
.33266 .5851 m .33367 .58323 L .33531 .58206 L F
.488 .288 .535 r
.3026 .54542 m .30475 .54757 L .30451 .54446 L F
.3026 .54542 m .30217 .54824 L .30475 .54757 L F
0 0 0 r
.30952 .64156 m .3074 .64243 L .30667 .64307 L F
.28 .389 .796 r
.3932 .53802 m .392 .53948 L .39069 .53645 L F
.407 .417 .758 r
.3932 .53802 m .3923 .54219 L .392 .53948 L F
.879 .85 .811 r
.3671 .64828 m .36306 .65043 L .36529 .64698 L F
.3671 .64828 m .36444 .65117 L .36306 .65043 L F
.698 .522 .646 r
.3671 .64828 m .3676 .65147 L .36444 .65117 L F
.782 .777 .848 r
.36935 .64581 m .3671 .64828 L .36529 .64698 L F
.368 .292 .638 r
.36924 .65041 m .3676 .65147 L .3671 .64828 L F
.491 .451 .74 r
.2433 .75055 m .24556 .75081 L .24489 .74795 L F
.157 0 0 r
.24962 .54254 m .24735 .5436 L .24511 .54376 L F
.562 .072 .05 r
.25247 .54267 m .24735 .5436 L .24962 .54254 L F
.137 0 0 r
.30338 .65478 m .30373 .65564 L .30246 .6561 L F
.30338 .65478 m .30573 .65445 L .30373 .65564 L F
.64 .596 .79 r
.35532 .64134 m .35268 .64208 L .35133 .63827 L F
.327 .102 .411 r
.35532 .64134 m .35277 .64481 L .35268 .64208 L F
.348 0 0 r
.33493 .66901 m .33548 .66824 L .33756 .66872 L F
.327 .04 .315 r
.19323 .55994 m .1961 .55692 L .19432 .55767 L F
.71 .816 .931 r
.24556 .75081 m .24949 .75117 L .24789 .74961 L F
.757 .738 .835 r
.29638 .64364 m .2986 .64629 L .29548 .64838 L F
.363 0 0 r
.29548 .64838 m .29607 .64935 L .29372 .64749 L F
.29548 .64838 m .29795 .64896 L .29607 .64935 L F
0 .013 .582 r
.29795 .64896 m .29913 .65125 L .29865 .64992 L F
.048 0 .397 r
.29913 .65125 m .30078 .65253 L .29865 .64992 L F
.538 .335 .553 r
.29195 .5915 m .29465 .58838 L .29239 .58911 L F
.531 .576 .845 r
.33816 .55018 m .336 .54875 L .33727 .54757 L F
.613 .324 .455 r
.52118 .54163 m .52502 .53888 L .52122 .53898 L F
.52118 .54163 m .52479 .54148 L .52502 .53888 L F
.564 .255 .402 r
.52479 .54148 m .52739 .53926 L .52502 .53888 L F
.204 .224 .659 r
.29182 .63754 m .29206 .64134 L .29004 .63889 L F
.534 .25 .429 r
.20642 .58312 m .20858 .58481 L .20954 .58264 L F
.20954 .58264 m .20858 .58481 L .20642 .58312 L F
.054 0 0 r
.18383 .56769 m .18263 .56915 L .18587 .56678 L F
.393 .213 .514 r
.1785 .5733 m .18048 .57268 L .18067 .57002 L F
.295 .178 .545 r
.1785 .5733 m .18021 .57528 L .18048 .57268 L F
.1785 .5733 m .17861 .57614 L .18021 .57528 L F
.026 0 .13 r
.29072 .60938 m .28988 .60774 L .29186 .60689 L F
.29072 .60938 m .28955 .60831 L .28988 .60774 L F
.985 .733 .466 r
.31782 .57299 m .32004 .57185 L .32048 .5719 L F
.31782 .57299 m .31581 .56918 L .32004 .57185 L F
.31782 .57299 m .31578 .57178 L .31581 .56918 L F
.536 .756 .978 r
.32048 .5719 m .32128 .57342 L .31782 .57299 L F
0 0 0 r
.32128 .57342 m .31796 .57624 L .31782 .57299 L F
0 0 .537 r
.34449 .61604 m .3429 .61444 L .34319 .61346 L F
.34449 .61604 m .34401 .61652 L .3429 .61444 L F
.491 .03 .086 r
.28135 .55455 m .2796 .55652 L .2773 .55617 L F
.247 .153 .546 r
.30397 .56958 m .30609 .56887 L .30585 .56625 L F
.586 .099 .064 r
.30397 .56958 m .30564 .57203 L .30609 .56887 L F
.30397 .56958 m .30363 .5724 L .30564 .57203 L F
.30363 .5724 m .30389 .57276 L .30564 .57203 L F
.094 0 .333 r
.30609 .56887 m .30564 .57203 L .30705 .57016 L F
.866 .989 .833 r
.30357 .5729 m .30358 .57417 L .30564 .57203 L F
.749 .976 .72 r
.30358 .57417 m .30354 .57356 L .30564 .57203 L F
.391 .052 .267 r
.30354 .57356 m .30705 .57016 L .30564 .57203 L F
.30409 .57303 m .30629 .57296 L .30705 .57016 L F
.30354 .57356 m .30435 .57338 L .30409 .57303 L F
.30435 .57338 m .30629 .57296 L .30409 .57303 L F
.586 .099 .064 r
.30363 .5724 m .30357 .5729 L .30389 .57276 L F
.456 .575 .885 r
.33945 .53646 m .33974 .5394 L .33919 .53756 L F
.33945 .53646 m .34179 .5388 L .33974 .5394 L F
.412 .376 .709 r
.34179 .5388 m .34252 .54068 L .33974 .5394 L F
.514 .249 .451 r
.27081 .55089 m .27325 .55063 L .27363 .54841 L F
.513 .532 .813 r
.27363 .54841 m .27488 .54503 L .27236 .54567 L F
.27363 .54841 m .27584 .5477 L .27488 .54503 L F
.519 .319 .55 r
.27325 .55063 m .27584 .5477 L .27363 .54841 L F
.446 .149 .366 r
.26487 .55466 m .26721 .55418 L .2675 .55219 L F
.391 .051 .265 r
.26721 .55418 m .27081 .55089 L .2675 .55219 L F
0 0 0 r
.23149 .55673 m .2303 .56054 L .22921 .55811 L F
.293 .003 .288 r
.31134 .55739 m .31363 .55509 L .31158 .55513 L F
.31134 .55739 m .31331 .55705 L .31363 .55509 L F
.724 .375 .388 r
.31363 .55509 m .31706 .55725 L .31635 .55327 L F
.31363 .55509 m .31331 .55705 L .31706 .55725 L F
.573 .859 .996 r
.24934 .56026 m .24512 .5606 L .24729 .56114 L F
.874 .516 .366 r
.24512 .5606 m .24513 .56255 L .24729 .56114 L F
.043 .377 .843 r
.39577 .54808 m .39864 .54974 L .39844 .55114 L F
0 .171 .708 r
.39864 .54974 m .39931 .5516 L .39844 .55114 L F
0 0 .506 r
.4006 .55321 m .39844 .55114 L .39931 .5516 L F
.811 .863 .887 r
.53512 .54922 m .53452 .55185 L .53701 .55075 L F
.491 .437 .724 r
.36273 .61901 m .36354 .62296 L .36136 .62347 L F
.178 .439 .87 r
.3647 .62644 m .36136 .62347 L .36354 .62296 L F
0 0 0 r
.31428 .56669 m .31175 .56871 L .31052 .56951 L F
.733 .35 .325 r
.31428 .56669 m .31581 .56918 L .31175 .56871 L F
.823 .933 .903 r
.28702 .60084 m .28567 .60394 L .28422 .60345 L F
0 0 0 r
.32128 .57342 m .32018 .57521 L .31796 .57624 L F
.65 .318 .397 r
.32048 .5719 m .32361 .56968 L .32128 .57342 L F
0 0 0 r
.32111 .57413 m .32128 .57342 L .32324 .57343 L F
.32111 .57413 m .32018 .57521 L .32128 .57342 L F
.44 .289 .579 r
.34877 .63082 m .34685 .62931 L .34819 .62901 L F
.34877 .63082 m .34676 .63165 L .34685 .62931 L F
.891 .989 .776 r
.25829 .73832 m .25961 .73835 L .25715 .74152 L F
.54 .331 .545 r
.25961 .73835 m .25958 .74139 L .25715 .74152 L F
.592 .871 .994 r
.26036 .73642 m .25961 .73835 L .25829 .73832 L F
.26036 .73642 m .26251 .73735 L .25961 .73835 L F
.522 .333 .566 r
.26251 .73735 m .25993 .74065 L .25961 .73835 L F
.362 .134 .428 r
.26285 .73738 m .25993 .74065 L .26251 .73735 L F
.26422 .73748 m .26105 .73982 L .26285 .73738 L F
.26105 .73982 m .25993 .74065 L .26285 .73738 L F
.464 .292 .562 r
.262 .74087 m .25993 .74065 L .26422 .73748 L F
.464 .293 .563 r
.25961 .73835 m .25993 .74065 L .26025 .74068 L F
.25961 .73835 m .26025 .74068 L .262 .74087 L F
.25961 .73835 m .26103 .73985 L .25958 .74139 L F
.26103 .73985 m .262 .74087 L .25996 .74131 L F
.26103 .73985 m .25996 .74131 L .25958 .74139 L F
.81 .613 .636 r
.28701 .63207 m .29159 .63232 L .2915 .6294 L F
.72 .189 0 r
.29163 .6309 m .2915 .6294 L .29159 .63232 L F
0 0 0 r
.2075 .57412 m .20762 .5733 L .20956 .5723 L F
.2075 .57412 m .20563 .57493 L .20762 .5733 L F
.657 .607 .787 r
.51513 .55448 m .51738 .55152 L .51381 .55086 L F
.51513 .55448 m .51786 .55401 L .51738 .55152 L F
.426 .29 .592 r
.32988 .52606 m .32807 .52995 L .32703 .52628 L F
.39 .268 .592 r
.33155 .52277 m .32988 .52606 L .33034 .52614 L F
.947 .936 .75 r
.33155 .52277 m .33034 .52614 L .3303 .52584 L F
.39 .268 .592 r
.33155 .52277 m .33033 .52577 L .32988 .52606 L F
.947 .936 .75 r
.33155 .52277 m .3303 .52584 L .32997 .52307 L F
.39 .268 .592 r
.33155 .52277 m .33192 .52472 L .33033 .52577 L F
.629 .752 .935 r
.3303 .52584 m .33031 .52588 L .33024 .52589 L F
.39 .268 .592 r
.33192 .52472 m .33215 .52594 L .33 .52606 L F
.33192 .52472 m .33 .52606 L .32988 .52606 L F
.629 .752 .935 r
.32997 .52307 m .3303 .52584 L .32703 .52628 L F
.3303 .52584 m .33024 .52589 L .32703 .52628 L F
0 0 0 r
.33215 .52594 m .32966 .52944 L .32988 .52614 L F
.426 .29 .592 r
.32988 .52606 m .32985 .52616 L .32983 .52616 L F
.677 .561 .717 r
.32703 .52628 m .32985 .52616 L .32988 .52606 L F
.32985 .52616 m .33034 .52614 L .32988 .52606 L F
.426 .29 .592 r
.32988 .52606 m .32988 .52614 L .32985 .52616 L F
0 0 0 r
.33 .52606 m .32988 .52614 L .32988 .52606 L F
.629 .752 .935 r
.33031 .52588 m .33034 .52614 L .32985 .52616 L F
.33031 .52588 m .32985 .52616 L .32988 .52614 L F
0 0 0 r
.33215 .52594 m .32988 .52614 L .33 .52606 L F
.629 .752 .935 r
.32988 .52614 m .32985 .52616 L .32985 .52616 L F
.33031 .52588 m .32985 .52616 L .32703 .52628 L F
.426 .29 .592 r
.32983 .52616 m .32966 .52944 L .32807 .52995 L F
.32988 .52614 m .32966 .52944 L .32983 .52616 L F
.421 .315 .627 r
.32966 .52944 m .32832 .53261 L .32807 .52995 L F
.477 .009 .063 r
.32639 .66914 m .32503 .67008 L .32254 .66981 L F
.334 0 0 r
.32639 .66914 m .32645 .66999 L .32503 .67008 L F
.32639 .66914 m .32889 .6696 L .32645 .66999 L F
.147 0 0 r
.30742 .55975 m .3093 .55954 L .31134 .55739 L F
.902 .781 .719 r
.30938 .55402 m .31134 .55739 L .31158 .55513 L F
.359 0 .093 r
.3093 .55954 m .31331 .55705 L .31134 .55739 L F
.458 .301 .579 r
.3569 .60483 m .35824 .60117 L .35716 .60248 L F
.3569 .60483 m .35936 .60419 L .35824 .60117 L F
.457 .303 .583 r
.35824 .60117 m .3616 .60026 L .36138 .59739 L F
.463 .303 .578 r
.35824 .60117 m .36218 .60312 L .3616 .60026 L F
.35824 .60117 m .35936 .60419 L .36218 .60312 L F
.861 .659 .628 r
.53235 .54373 m .53602 .5427 L .53375 .54141 L F
.53235 .54373 m .5343 .54586 L .53602 .5427 L F
.139 .142 .599 r
.21371 .56553 m .21175 .5645 L .21378 .56398 L F
.21371 .56553 m .21207 .56713 L .21175 .5645 L F
.483 .276 .522 r
.32083 .63761 m .319 .63569 L .32057 .6349 L F
.32083 .63761 m .31856 .63836 L .319 .63569 L F
.348 .793 .957 r
.2549 .53015 m .25922 .53036 L .25688 .53097 L F
.711 .538 .653 r
.28928 .56083 m .28963 .56429 L .28572 .56403 L F
.557 .835 .997 r
.28928 .56083 m .28746 .55972 L .29188 .56018 L F
.624 .474 .658 r
.29081 .56274 m .28928 .56083 L .29188 .56018 L F
.29081 .56274 m .28963 .56429 L .28928 .56083 L F
.429 .221 .494 r
.34084 .57332 m .34055 .57614 L .33831 .57677 L F
.314 0 .224 r
.34055 .57614 m .33746 .57865 L .33831 .57677 L F
0 0 0 r
.23525 .55223 m .2351 .55086 L .23806 .55003 L F
.23525 .55223 m .23361 .5532 L .2351 .55086 L F
.251 .723 .941 r
.30455 .52593 m .31038 .52698 L .3079 .52731 L F
.528 .776 .988 r
.3179 .54193 m .32027 .54097 L .31664 .53997 L F
0 0 0 r
.34141 .60742 m .33944 .61005 L .33801 .61271 L F
.163 0 .33 r
.33746 .57865 m .33531 .58206 L .33581 .57967 L F
.359 .272 .62 r
.32798 .63589 m .32851 .63844 L .33027 .6379 L F
.418 .049 .229 r
.31004 .64711 m .31094 .64518 L .3126 .64666 L F
.41 .051 .241 r
.31094 .64518 m .31327 .64479 L .3126 .64666 L F
.688 .49 .613 r
.51866 .53918 m .51868 .54177 L .52122 .53898 L F
.545 .406 .642 r
.38555 .58998 m .38626 .5917 L .38326 .59141 L F
.516 .435 .704 r
.38656 .59441 m .38326 .59141 L .38626 .5917 L F
.38656 .59441 m .38423 .59503 L .38326 .59141 L F
.442 0 0 r
.35042 .5908 m .34926 .5903 L .3465 .5886 L F
.176 .323 .775 r
.3465 .5886 m .34926 .5903 L .34819 .58744 L F
.798 .739 .798 r
.34388 .6681 m .34563 .67 L .34794 .66643 L F
.716 .64 .772 r
.37981 .54762 m .38623 .55047 L .3825 .5442 L F
.158 0 0 r
.38014 .55109 m .38623 .55047 L .37981 .54762 L F
0 0 0 r
.38144 .55121 m .38118 .55195 L .38174 .55142 L F
.158 0 0 r
.38113 .55099 m .38144 .55121 L .38623 .55047 L F
.72 .963 .941 r
.38623 .55047 m .38144 .55121 L .38417 .54908 L F
0 0 0 r
.38144 .55121 m .38174 .55142 L .38417 .54908 L F
.158 0 0 r
.38014 .55109 m .38144 .55121 L .38113 .55099 L F
0 .188 .72 r
.3825 .5442 m .38623 .55047 L .38513 .54683 L F
.72 .963 .941 r
.38623 .55047 m .38417 .54908 L .38513 .54683 L F
.488 .493 .788 r
.17346 .61103 m .17585 .61074 L .17468 .60874 L F
.649 .576 .76 r
.51786 .55401 m .51896 .55745 L .52177 .55635 L F
.531 .325 .546 r
.29526 .54498 m .29262 .548 L .29265 .54545 L F
.787 .578 .617 r
.36129 .52017 m .35711 .51729 L .35992 .51687 L F
.36129 .52017 m .35745 .52028 L .35711 .51729 L F
.429 0 0 r
.36129 .52017 m .3601 .52118 L .35745 .52028 L F
.726 .717 .842 r
.3637 .51757 m .36129 .52017 L .35992 .51687 L F
.965 .638 .295 r
.36129 .52017 m .36156 .52268 L .3601 .52118 L F
.511 .327 .567 r
.36138 .59739 m .364 .59433 L .36153 .59495 L F
.541 .594 .856 r
.2833 .62863 m .28201 .63022 L .28171 .62938 L F
.411 .206 .488 r
.34273 .57535 m .34084 .57332 L .34282 .57257 L F
.34273 .57535 m .34055 .57614 L .34084 .57332 L F
0 0 0 r
.35385 .63809 m .3558 .63781 L .35763 .63732 L F
.57 .012 0 r
.3558 .63781 m .36008 .63857 L .35763 .63732 L F
.303 .167 .524 r
.30345 .58751 m .30195 .58575 L .30226 .58565 L F
.30345 .58751 m .3013 .58929 L .30195 .58575 L F
.525 .624 .892 r
.20586 .59058 m .20563 .5942 L .20335 .5915 L F
.20586 .59058 m .20816 .59389 L .20563 .5942 L F
.693 .41 .49 r
.32076 .63249 m .32439 .63241 L .32385 .63483 L F
.761 .679 .772 r
.37419 .6258 m .37566 .6294 L .37836 .62643 L F
.639 .42 .569 r
.51868 .54177 m .52118 .54163 L .52122 .53898 L F
.634 .571 .766 r
.35133 .63827 m .34863 .63857 L .34776 .63565 L F
.708 .922 .585 r
.35401 .52971 m .35474 .52822 L .35641 .5266 L F
.719 .955 .672 r
.35401 .52971 m .35211 .53108 L .35474 .52822 L F
.407 .417 .758 r
.3932 .53802 m .39427 .54169 L .3923 .54219 L F
.396 .374 .716 r
.39427 .54169 m .39498 .54408 L .3923 .54219 L F
.349 .712 .985 r
.26328 .63748 m .26729 .63862 L .26567 .63724 L F
.4 .709 .985 r
.26567 .63724 m .26729 .63862 L .26789 .63711 L F
.115 .373 .833 r
.26729 .63862 m .2701 .64046 L .26789 .63711 L F
.597 .915 .667 r
.23663 .7539 m .2392 .75065 L .2389 .75363 L F
.561 .338 .533 r
.2389 .75363 m .23671 .75103 L .23663 .7539 L F
.2389 .75363 m .2392 .75065 L .23671 .75103 L F
.59 .938 .938 r
.28006 .54105 m .27966 .54073 L .27854 .54211 L F
.594 .898 .62 r
.27966 .54073 m .2767 .54353 L .27854 .54211 L F
.438 .21 .469 r
.2992 .55053 m .30184 .55062 L .30217 .54824 L F
.457 .443 .754 r
.30097 .55338 m .30184 .55062 L .2992 .55053 L F
.098 0 0 r
.33079 .57759 m .33434 .57638 L .33157 .5765 L F
0 0 0 r
.30986 .55203 m .30973 .55254 L .3108 .55008 L F
.485 .882 .956 r
.24052 .53328 m .24228 .53272 L .24418 .53285 L F
.078 0 0 r
.24418 .53285 m .24396 .53289 L .24628 .53188 L F
.24418 .53285 m .24228 .53272 L .24396 .53289 L F
.468 .848 .625 r
.28511 .61494 m .28386 .61601 L .28675 .61291 L F
.28511 .61494 m .28346 .61618 L .28386 .61601 L F
0 0 0 r
.36085 .64335 m .35937 .64502 L .36171 .64212 L F
.697 .159 0 r
.36085 .64335 m .35771 .64117 L .36171 .64212 L F
.759 .506 .551 r
.36004 .6285 m .3647 .62644 L .36372 .62792 L F
.362 .45 .816 r
.36648 .62501 m .3647 .62644 L .36354 .62296 L F
.735 .89 .494 r
.28675 .61291 m .28955 .60831 L .28806 .61215 L F
.067 0 .085 r
.28806 .61215 m .28955 .60831 L .29072 .60938 L F
.124 0 .232 r
.27942 .60999 m .27778 .61094 L .27699 .61322 L F
.289 .052 .37 r
.34524 .56944 m .34282 .57257 L .34323 .57029 L F
.003 0 0 r
.25465 .62427 m .25419 .62416 L .25215 .6232 L F
.25465 .62427 m .25645 .62402 L .25419 .62416 L F
.53 .059 .081 r
.35641 .5266 m .35878 .52809 L .35906 .52627 L F
.35641 .5266 m .35474 .52822 L .35878 .52809 L F
.786 .956 .631 r
.35878 .52809 m .35641 .5266 L .35906 .52627 L F
.429 .106 .314 r
.39883 .55929 m .39523 .56264 L .39615 .56065 L F
.614 .457 .646 r
.51094 .54902 m .51366 .54837 L .51327 .54541 L F
.02 0 0 r
.32856 .60475 m .32638 .60685 L .32466 .60692 L F
.779 .387 .311 r
.32436 .60348 m .32638 .60685 L .32856 .60475 L F
.323 .323 .704 r
.3569 .60483 m .35914 .6067 L .35936 .60419 L F
.3569 .60483 m .3578 .60731 L .35914 .6067 L F
.515 .881 .979 r
.31426 .52673 m .31038 .52698 L .31282 .52622 L F
.62 .928 .97 r
.31668 .52566 m .31426 .52673 L .31509 .5252 L F
.603 .91 .981 r
.31509 .5252 m .31426 .52673 L .31282 .52622 L F
.33 .237 .597 r
.39523 .56264 m .39337 .56671 L .39373 .56388 L F
.117 .089 .548 r
.21333 .56825 m .21207 .56713 L .21371 .56553 L F
.21333 .56825 m .21256 .56961 L .21207 .56713 L F
.65 .318 .397 r
.32048 .5719 m .32284 .57248 L .32361 .56968 L F
.4 .183 .464 r
.32581 .56937 m .32508 .57309 L .32324 .57343 L F
.478 .531 .833 r
.32324 .57343 m .32635 .57355 L .32593 .57293 L F
.4 .183 .464 r
.32508 .57309 m .32507 .57317 L .32324 .57343 L F
.738 .495 .561 r
.32943 .57211 m .32516 .57315 L .32581 .56937 L F
.32516 .57315 m .32507 .57317 L .32508 .57309 L F
.32516 .57315 m .32508 .57309 L .32581 .56937 L F
.478 .531 .833 r
.32402 .57228 m .32593 .57293 L .32476 .57121 L F
.32324 .57343 m .32508 .57309 L .32402 .57228 L F
.32508 .57309 m .32593 .57293 L .32402 .57228 L F
.164 0 .219 r
.32361 .56968 m .32476 .57121 L .32581 .56937 L F
.32361 .56968 m .32284 .57248 L .32476 .57121 L F
0 0 0 r
.2076 .54782 m .20942 .54706 L .21111 .54532 L F
.024 0 0 r
.21111 .54532 m .21145 .54631 L .2134 .54478 L F
.21111 .54532 m .20942 .54706 L .21145 .54631 L F
.233 0 0 r
.35774 .53273 m .35668 .53435 L .35354 .53477 L F
.563 .416 .639 r
.35501 .52027 m .35745 .52028 L .35711 .51729 L F
.35501 .52027 m .35745 .52028 L .35711 .51729 L F
.602 .804 .39 r
.35905 .53066 m .35668 .53435 L .35774 .53273 L F
.496 .231 .441 r
.36997 .55629 m .37189 .55689 L .37215 .55462 L F
.569 .318 .496 r
.37189 .55689 m .37476 .55418 L .37215 .55462 L F
.19 .684 .92 r
.34622 .55972 m .35032 .56035 L .34757 .56015 L F
.34622 .55972 m .35032 .56035 L .34757 .56015 L F
.559 .477 .719 r
.35082 .56344 m .34757 .56015 L .35032 .56035 L F
.35082 .56344 m .34834 .56429 L .34757 .56015 L F
.653 .485 .644 r
.51327 .54541 m .51626 .54768 L .51599 .54515 L F
.51327 .54541 m .51366 .54837 L .51626 .54768 L F
.412 .108 .337 r
.33118 .56387 m .33401 .56373 L .33459 .56049 L F
.276 0 .295 r
.33459 .56049 m .33592 .56231 L .33742 .56 L F
.33459 .56049 m .33401 .56373 L .33592 .56231 L F
.391 .067 .291 r
.34834 .56429 m .34772 .5662 L .34535 .56677 L F
.779 .653 .724 r
.35082 .56344 m .34772 .5662 L .34834 .56429 L F
.703 .249 .17 r
.32218 .62393 m .32226 .6228 L .31789 .62257 L F
.22 0 .125 r
.32429 .62243 m .32226 .6228 L .32218 .62393 L F
.977 .905 .672 r
.5341 .55381 m .53367 .55151 L .53297 .55276 L F
.5341 .55381 m .53452 .55185 L .53367 .55151 L F
.858 .761 .755 r
.53017 .55575 m .5341 .55381 L .53297 .55276 L F
.53017 .55575 m .53172 .55742 L .5341 .55381 L F
.668 .715 .883 r
.30068 .6448 m .2986 .64629 L .29638 .64364 L F
.913 .68 .572 r
.37994 .63332 m .38135 .63577 L .38337 .63564 L F
.781 .956 .927 r
.38337 .63564 m .38135 .63577 L .38225 .6349 L F
.38337 .63564 m .38225 .6349 L .38344 .63374 L F
.77 .893 .931 r
.38103 .63409 m .38135 .63577 L .38089 .63411 L F
.418 0 0 r
.38337 .63564 m .38174 .63456 L .37994 .63332 L F
.77 .893 .931 r
.38344 .63374 m .38225 .6349 L .38103 .63409 L F
.518 0 0 r
.37994 .63332 m .38156 .63444 L .38089 .63411 L F
.77 .893 .931 r
.38225 .6349 m .38105 .63419 L .38156 .63444 L F
.518 0 0 r
.38156 .63444 m .38236 .635 L .38089 .63411 L F
.77 .893 .931 r
.38225 .6349 m .38135 .63577 L .38105 .63419 L F
.38156 .63444 m .38105 .63419 L .38103 .63409 L F
.418 0 0 r
.38225 .6349 m .38236 .635 L .38174 .63456 L F
.38337 .63564 m .38304 .63542 L .38225 .6349 L F
.38304 .63542 m .38236 .635 L .38225 .6349 L F
.897 .985 .722 r
.38344 .63374 m .38236 .635 L .38337 .63564 L F
.696 .837 .95 r
.23484 .61237 m .2325 .61346 L .23065 .61211 L F
0 0 0 r
.28496 .55245 m .28422 .55239 L .28637 .55164 L F
.28496 .55245 m .28151 .5553 L .28422 .55239 L F
.455 .792 .999 r
.24828 .55098 m .24646 .54998 L .2442 .55035 L F
0 .483 .859 r
.24828 .55098 m .24862 .55043 L .24646 .54998 L F
0 0 0 r
.22298 .53955 m .22175 .54047 L .22509 .53867 L F
.274 0 .217 r
.27699 .61322 m .27487 .61395 L .27393 .61597 L F
.589 .379 .564 r
.3743 .63878 m .37439 .64138 L .37733 .63827 L F
.37733 .63827 m .37439 .64138 L .3743 .63878 L F
.3743 .63878 m .37733 .63827 L .37541 .63935 L F
.3743 .63878 m .37541 .63935 L .37508 .63954 L F
0 0 .333 r
.3743 .63878 m .37439 .64138 L .37492 .6391 L F
.3743 .63878 m .37492 .6391 L .37533 .63732 L F
.589 .379 .564 r
.3743 .63878 m .37508 .63954 L .37533 .63732 L F
.604 .268 .374 r
.27264 .55678 m .27072 .55981 L .26859 .5577 L F
.475 .133 .306 r
.27483 .5564 m .27072 .55981 L .27264 .55678 L F
.594 .85 .496 r
.29262 .548 m .29095 .54989 L .2901 .55109 L F
.554 .928 .921 r
.29095 .54989 m .28879 .55095 L .2901 .55109 L F
.504 .186 .361 r
.36997 .55629 m .36802 .55899 L .37189 .55689 L F
.879 .495 .305 r
.34209 .61858 m .34548 .62018 L .34401 .61652 L F
.34209 .61858 m .34401 .61652 L .34449 .61604 L F
.518 .263 .468 r
.32923 .53802 m .33038 .53573 L .32791 .53498 L F
.32923 .53802 m .33163 .53766 L .33038 .53573 L F
.629 .752 .935 r
.32997 .52307 m .32703 .52628 L .32536 .52477 L F
.782 .777 .848 r
.36935 .64581 m .36529 .64698 L .36787 .64516 L F
.747 .576 .664 r
.36787 .64516 m .37201 .64762 L .36935 .64581 L F
.36787 .64516 m .37107 .64852 L .37201 .64762 L F
.885 .874 .82 r
.37201 .64762 m .37107 .64852 L .37182 .64615 L F
.489 .235 .456 r
.37185 .64194 m .37366 .64415 L .37439 .64138 L F
.37185 .64194 m .37375 .64426 L .37439 .64138 L F
.885 .874 .82 r
.37238 .64555 m .37182 .64615 L .37284 .64293 L F
.37201 .64762 m .37182 .64615 L .37238 .64555 L F
.489 .235 .456 r
.37366 .64415 m .37375 .64426 L .37382 .64398 L F
.37366 .64415 m .37382 .64398 L .37439 .64138 L F
.72 .638 .765 r
.3257 .53593 m .32333 .53894 L .32617 .53626 L F
.295 .046 .356 r
.32273 .54163 m .32617 .53626 L .32333 .53894 L F
.147 0 .266 r
.32512 .53791 m .32333 .53894 L .3257 .53593 L F
.354 .168 .485 r
.32512 .53791 m .32273 .54163 L .32333 .53894 L F
.74 .668 .78 r
.32182 .53528 m .32333 .53894 L .3257 .53593 L F
.891 .989 .776 r
.25829 .73832 m .25715 .74152 L .25732 .74049 L F
.331 .761 .972 r
.25715 .74152 m .25958 .74139 L .25732 .74049 L F
.394 0 .117 r
.33353 .55219 m .33064 .55572 L .32812 .556 L F
.186 0 0 r
.33456 .55353 m .33064 .55572 L .33353 .55219 L F
.483 .223 .444 r
.37629 .57339 m .37841 .57516 L .3789 .57287 L F
.37629 .57339 m .37841 .57516 L .3789 .57287 L F
.321 0 0 r
.18602 .59754 m .1816 .59979 L .18361 .59809 L F
.482 .524 .824 r
.33745 .64048 m .3395 .64336 L .33596 .64254 L F
.6 .267 .377 r
.31796 .57624 m .31711 .57866 L .31464 .57865 L F
.323 .005 .262 r
.31986 .57767 m .31796 .57624 L .32018 .57521 L F
.534 .371 .606 r
.31986 .57767 m .31688 .58044 L .31711 .57866 L F
0 0 0 r
.31716 .57974 m .31742 .57917 L .31839 .57673 L F
.31688 .58044 m .317 .58016 L .31716 .57974 L F
.317 .58016 m .31742 .57917 L .31716 .57974 L F
.323 .005 .262 r
.31841 .57658 m .31711 .57866 L .31796 .57624 L F
.31986 .57767 m .31767 .57845 L .31841 .57658 L F
.31767 .57845 m .31711 .57866 L .31841 .57658 L F
.596 .864 .993 r
.37217 .51981 m .37169 .52126 L .36986 .51974 L F
.37217 .51981 m .37344 .5203 L .37169 .52126 L F
.509 .512 .795 r
.37487 .52252 m .37169 .52126 L .37344 .5203 L F
.058 0 0 r
.25769 .54905 m .25652 .54994 L .25437 .55055 L F
0 0 0 r
.25952 .54824 m .25652 .54994 L .25769 .54905 L F
.86 .728 .716 r
.37342 .68224 m .37116 .68521 L .36943 .68205 L F
.37342 .68224 m .36943 .68205 L .37224 .68309 L F
.697 .483 .594 r
.37395 .68455 m .37116 .68521 L .37342 .68224 L F
.751 .971 .928 r
.37626 .67966 m .37342 .68224 L .37501 .6802 L F
.669 .931 .641 r
.37342 .68224 m .37224 .68309 L .37501 .6802 L F
.626 .851 .985 r
.37675 .68163 m .37342 .68224 L .37626 .67966 L F
.693 .41 .49 r
.32076 .63249 m .32385 .63483 L .32057 .6349 L F
.92 .824 .735 r
.53823 .54827 m .53766 .54916 L .53603 .54779 L F
.391 .051 .265 r
.26721 .55418 m .26954 .55367 L .27081 .55089 L F
.399 .039 .234 r
.26954 .55367 m .27325 .55063 L .27081 .55089 L F
.633 .612 .811 r
.22488 .62754 m .22672 .63013 L .22852 .62867 L F
.788 .71 .778 r
.29959 .57939 m .2971 .58255 L .2953 .58021 L F
.851 .875 .435 r
.29916 .595 m .29986 .59503 L .29898 .59377 L F
.29916 .595 m .29891 .59727 L .29986 .59503 L F
.629 .53 .723 r
.51381 .55086 m .51626 .54768 L .51366 .54837 L F
.51381 .55086 m .51738 .55152 L .51626 .54768 L F
.634 .335 .447 r
.3542 .58887 m .35317 .59116 L .35042 .5908 L F
.615 .501 .699 r
.35482 .58733 m .35317 .59116 L .3542 .58887 L F
.487 .601 .892 r
.20312 .61312 m .20307 .60967 L .20194 .60951 L F
.20312 .61312 m .20533 .61285 L .20307 .60967 L F
.888 .596 .487 r
.27089 .62618 m .26856 .62824 L .27044 .62817 L F
.564 .872 .579 r
.2717 .62516 m .27089 .62618 L .27327 .62568 L F
.2717 .62516 m .26856 .62824 L .27089 .62618 L F
.627 .412 .57 r
.27044 .62817 m .27327 .62568 L .27089 .62618 L F
0 0 .26 r
.20375 .57585 m .20221 .57897 L .20206 .5787 L F
0 0 .156 r
.20252 .58045 m .20206 .5787 L .20221 .57897 L F
.20252 .58045 m .20157 .58214 L .20206 .5787 L F
.165 .029 .438 r
.18067 .57002 m .18185 .57177 L .18263 .56915 L F
.18067 .57002 m .18048 .57268 L .18185 .57177 L F
.55 .311 .506 r
.35863 .5639 m .36044 .56602 L .35796 .56621 L F
.35863 .5639 m .36044 .56602 L .35796 .56621 L F
.411 .628 .943 r
.22297 .60919 m .22201 .61094 L .22102 .60937 L F
.278 .459 .859 r
.22297 .60919 m .22455 .61169 L .22201 .61094 L F
.546 .32 .524 r
.27859 .54483 m .28093 .54684 L .2825 .54439 L F
.108 0 0 r
.2825 .54439 m .28435 .54416 L .28482 .54332 L F
.436 .145 .371 r
.28093 .54684 m .28435 .54416 L .2825 .54439 L F
.68 .158 0 r
.36444 .65117 m .3652 .65263 L .36306 .65043 L F
.36444 .65117 m .36678 .65376 L .3652 .65263 L F
.682 .381 .458 r
.3676 .65147 m .36678 .65376 L .36444 .65117 L F
.412 0 0 r
.23342 .53547 m .23733 .53519 L .23506 .53491 L F
.456 .854 .663 r
.35238 .66519 m .35656 .66262 L .35439 .66477 L F
0 0 0 r
.35439 .66477 m .35656 .66262 L .35776 .66246 L F
.27393 .61597 m .27213 .61694 L .27009 .61842 L F
.225 0 0 r
.32992 .55453 m .32812 .556 L .32572 .55631 L F
.552 .529 .783 r
.32851 .62791 m .3266 .62941 L .32567 .62616 L F
.389 .373 .721 r
.31536 .53827 m .31598 .54052 L .31394 .54029 L F
.527 .382 .627 r
.35708 .65088 m .35597 .65487 L .35471 .65328 L F
0 0 .261 r
.35799 .65152 m .35597 .65487 L .35708 .65088 L F
0 0 .377 r
.35799 .65152 m .35705 .65589 L .35597 .65487 L F
0 .13 .678 r
.35597 .65487 m .35705 .65589 L .35471 .65328 L F
.127 .225 .697 r
.35705 .65589 m .35563 .65728 L .35471 .65328 L F
.314 .533 .906 r
.35705 .65589 m .35797 .65805 L .35563 .65728 L F
.433 .201 .462 r
.38656 .59441 m .3839 .59748 L .38423 .59503 L F
.747 .634 .735 r
.31442 .61897 m .31585 .62328 L .31796 .62003 L F
.308 .093 .416 r
.31796 .62003 m .31585 .62328 L .31789 .62257 L F
.745 .227 0 r
.31514 .62442 m .31585 .62328 L .31425 .62336 L F
.308 .093 .416 r
.31796 .62003 m .31585 .62328 L .31789 .62257 L F
0 0 0 r
.31789 .62257 m .31585 .62328 L .31514 .62442 L F
.693 .401 0 r
.37555 .63204 m .37672 .63591 L .37632 .63465 L F
.37555 .63204 m .37672 .63591 L .37632 .63465 L F
0 0 .484 r
.37795 .63672 m .37672 .63591 L .37632 .63465 L F
.37795 .63672 m .37733 .63827 L .37672 .63591 L F
.541 .712 .951 r
.20972 .59358 m .20898 .5957 L .20816 .59389 L F
.20972 .59358 m .21141 .59528 L .20898 .5957 L F
.432 .281 .574 r
.29504 .58127 m .29762 .58334 L .29781 .58078 L F
.29504 .58127 m .29492 .58409 L .29652 .58364 L F
.2969 .58277 m .29652 .58364 L .29762 .58334 L F
.29504 .58127 m .29652 .58364 L .2969 .58277 L F
.343 0 0 r
.29762 .58334 m .29983 .58102 L .29781 .58078 L F
.949 .635 .403 r
.29781 .58078 m .29762 .58334 L .29672 .58306 L F
.788 .71 .778 r
.29959 .57939 m .29841 .57962 L .29781 .58078 L F
.92 .569 .354 r
.29959 .57939 m .29781 .58078 L .29983 .58102 L F
.654 .57 .748 r
.29833 .57943 m .29794 .58153 L .29781 .58078 L F
.29794 .58153 m .29762 .58334 L .29781 .58078 L F
.788 .71 .778 r
.29841 .57962 m .29763 .57977 L .29781 .58078 L F
.29763 .57977 m .2953 .58021 L .29781 .58078 L F
.343 0 0 r
.29762 .58334 m .29923 .58295 L .29983 .58102 L F
0 0 .315 r
.30213 .58361 m .29983 .58102 L .29923 .58295 L F
.343 0 0 r
.29762 .58334 m .29956 .58334 L .29923 .58295 L F
.091 .23 .715 r
.30213 .58361 m .30345 .58751 L .30226 .58565 L F
.434 0 0 r
.29956 .58334 m .30342 .58394 L .29923 .58295 L F
.654 .57 .748 r
.29833 .57943 m .29956 .58334 L .29762 .58334 L F
.508 .352 .605 r
.29959 .57939 m .30193 .57883 L .30161 .57623 L F
.455 .38 .682 r
.3011 .57894 m .29956 .58334 L .29833 .57943 L F
0 0 0 r
.29802 .58119 m .29714 .582 L .29911 .58067 L F
.949 .635 .403 r
.29732 .58172 m .29672 .58306 L .29727 .58183 L F
.2974 .5816 m .29672 .58306 L .29732 .58172 L F
.29735 .58174 m .29672 .58306 L .29756 .58125 L F
.29756 .58125 m .2974 .5816 L .29732 .58172 L F
.29781 .58078 m .29735 .58174 L .29756 .58125 L F
.29781 .58078 m .29727 .58183 L .29833 .57943 L F
.392 0 .072 r
.2953 .58021 m .29504 .58127 L .29781 .58078 L F
.791 .646 .702 r
.29833 .57943 m .29672 .58306 L .29802 .58119 L F
.764 .935 .587 r
.29672 .58306 m .29598 .58306 L .29802 .58119 L F
0 0 0 r
.29714 .582 m .29598 .58306 L .29691 .58235 L F
.29714 .582 m .29691 .58235 L .29911 .58067 L F
.178 .537 .925 r
.21862 .60713 m .21801 .60828 L .21663 .60647 L F
.21862 .60713 m .22102 .60937 L .21801 .60828 L F
.538 .683 .932 r
.27484 .72229 m .27261 .72297 L .27187 .72155 L F
.365 .11 .388 r
.27198 .72546 m .27261 .72297 L .27484 .72229 L F
.539 .578 .842 r
.36697 .56085 m .36926 .56039 L .36802 .55899 L F
.448 .463 .782 r
.36697 .56085 m .36994 .5626 L .36926 .56039 L F
.264 0 0 r
.25652 .54994 m .25488 .5518 L .25318 .55135 L F
.045 .306 .794 r
.25318 .55135 m .25488 .5518 L .25474 .55158 L F
.154 0 0 r
.25437 .55055 m .25318 .55135 L .25236 .55124 L F
.264 0 0 r
.25652 .54994 m .25318 .55135 L .25437 .55055 L F
.045 .306 .794 r
.25318 .55135 m .25474 .55158 L .25311 .54902 L F
.154 0 0 r
.25236 .55124 m .25318 .55135 L .25064 .55182 L F
.381 .845 .826 r
.27172 .64346 m .27746 .64166 L .27326 .64258 L F
.565 .001 0 r
.27746 .64166 m .27811 .64277 L .27326 .64258 L F
.27746 .64166 m .27992 .64369 L .27811 .64277 L F
0 0 .437 r
.31294 .61054 m .31384 .61343 L .31437 .60956 L F
.31294 .61054 m .31312 .61309 L .31384 .61343 L F
.541 .594 .856 r
.2833 .62863 m .28503 .63158 L .28201 .63022 L F
.196 .065 .464 r
.32778 .64799 m .32921 .64984 L .32919 .64715 L F
.32778 .64799 m .3277 .65046 L .32921 .64984 L F
.324 0 .225 r
.32862 .57901 m .32989 .58101 L .33079 .57759 L F
.32862 .57901 m .32758 .58172 L .32989 .58101 L F
.421 .315 .627 r
.32966 .52944 m .33037 .53195 L .32832 .53261 L F
.473 .288 .548 r
.33037 .53195 m .32791 .53498 L .32832 .53261 L F
.743 .687 .797 r
.35722 .64742 m .3542 .65108 L .35261 .64751 L F
.648 .611 .799 r
.35555 .55673 m .3538 .55995 L .35146 .55961 L F
.448 .565 .881 r
.31664 .53997 m .31825 .53792 L .31536 .53827 L F
.31664 .53997 m .32027 .54097 L .31825 .53792 L F
.39 .062 .284 r
.39205 .57136 m .39137 .57272 L .38917 .57314 L F
.338 .102 .402 r
.39137 .57272 m .38918 .57524 L .38917 .57314 L F
.264 .525 .912 r
.22657 .61238 m .22602 .61399 L .22455 .61169 L F
.669 .944 .961 r
.22831 .61273 m .22602 .61399 L .22657 .61238 L F
.248 .166 .563 r
.17654 .5794 m .17818 .58113 L .17813 .57855 L F
.17654 .5794 m .17623 .58291 L .17818 .58113 L F
.773 .817 .888 r
.3159 .53538 m .3193 .53524 L .3181 .53424 L F
.453 .091 .26 r
.31536 .53827 m .3193 .53524 L .3159 .53538 L F
.31536 .53827 m .31825 .53792 L .3193 .53524 L F
.533 .67 .925 r
.3193 .53524 m .32042 .53357 L .3181 .53424 L F
0 0 0 r
.3193 .53524 m .31928 .53592 L .32182 .53528 L F
.664 .721 .891 r
.32042 .53357 m .32182 .53528 L .32449 .53415 L F
.533 .67 .925 r
.32002 .53525 m .32182 .53528 L .32153 .53492 L F
0 0 0 r
.31928 .53592 m .32449 .53415 L .32182 .53528 L F
.668 .749 .91 r
.32182 .53528 m .3257 .53593 L .32449 .53415 L F
.32182 .53528 m .3257 .53593 L .32449 .53415 L F
0 0 0 r
.32157 .53518 m .32322 .53499 L .32422 .53433 L F
.31928 .53592 m .32422 .53433 L .32348 .53449 L F
.2 .539 .926 r
.32333 .53404 m .32411 .53489 L .32322 .53499 L F
.981 .759 .528 r
.3257 .53593 m .32512 .53791 L .32449 .53415 L F
.295 .046 .356 r
.32273 .54163 m .32478 .54087 L .32617 .53626 L F
.582 .552 .786 r
.32617 .53626 m .32791 .53498 L .3257 .53593 L F
.32617 .53626 m .32923 .53802 L .32791 .53498 L F
.755 .493 .536 r
.32617 .53626 m .32908 .54091 L .32923 .53802 L F
.32617 .53626 m .32478 .54087 L .32908 .54091 L F
.407 .617 .936 r
.32449 .53415 m .3257 .53593 L .32653 .53409 L F
.54 .477 .734 r
.32759 .53677 m .32512 .53791 L .32469 .53532 L F
.32543 .53494 m .32469 .53532 L .32449 .53415 L F
.634 .877 .986 r
.32679 .53425 m .3257 .53593 L .32791 .53498 L F
.32636 .53447 m .3257 .53593 L .32679 .53425 L F
.54 .477 .734 r
.32759 .53677 m .32469 .53532 L .32543 .53494 L F
.634 .877 .986 r
.32653 .53409 m .32636 .53447 L .32679 .53425 L F
.54 .477 .734 r
.32759 .53677 m .32449 .53415 L .32653 .53409 L F
.746 .332 .264 r
.32322 .53499 m .32512 .53599 L .32653 .53409 L F
.2 .539 .926 r
.32411 .53489 m .32512 .53599 L .32322 .53499 L F
0 0 0 r
.31928 .53592 m .32322 .53499 L .32157 .53518 L F
.32348 .53449 m .32422 .53433 L .32449 .53415 L F
.533 .67 .925 r
.3193 .53524 m .32002 .53525 L .32042 .53357 L F
.32002 .53525 m .32153 .53492 L .32042 .53357 L F
0 0 0 r
.3193 .53524 m .31825 .53792 L .31928 .53592 L F
.635 .689 .883 r
.52177 .55635 m .52535 .55744 L .52381 .55573 L F
.586 .707 .926 r
.52381 .55573 m .52535 .55744 L .52787 .55681 L F
.548 .639 .892 r
.52535 .55744 m .52953 .55921 L .52787 .55681 L F
.209 0 .011 r
.34719 .5448 m .34511 .54736 L .34363 .54747 L F
.557 .532 .783 r
.34945 .54398 m .34719 .5448 L .34614 .54111 L F
.683 .42 .518 r
.34945 .54398 m .34511 .54736 L .34719 .5448 L F
.182 0 0 r
.32254 .66981 m .32071 .67151 L .31836 .672 L F
0 .561 .778 r
.32254 .66981 m .32251 .66961 L .32071 .67151 L F
.32254 .66981 m .32503 .67008 L .32251 .66961 L F
.487 .612 .901 r
.21741 .61925 m .21731 .61583 L .21613 .61575 L F
.21741 .61925 m .21947 .61886 L .21731 .61583 L F
0 0 0 r
.26886 .61897 m .26527 .62204 L .26759 .62159 L F
.27009 .61842 m .26886 .61897 L .26759 .62159 L F
.659 .252 .263 r
.26859 .5577 m .27072 .55981 L .26834 .55923 L F
.09 0 .19 r
.36924 .65041 m .36678 .65376 L .3676 .65147 L F
.255 0 .151 r
.21791 .56018 m .2161 .56329 L .21378 .56398 L F
.362 .003 .214 r
.21851 .56258 m .21791 .56018 L .21966 .56081 L F
.21851 .56258 m .2161 .56329 L .21791 .56018 L F
.234 0 0 r
.32867 .60571 m .32715 .60659 L .32638 .60685 L F
.32715 .60659 m .32526 .6077 L .32638 .60685 L F
.053 0 .19 r
.32638 .60685 m .32419 .60957 L .32457 .60745 L F
.32638 .60685 m .32457 .60745 L .32466 .60692 L F
.712 .976 .919 r
.21996 .54206 m .22041 .54043 L .22175 .54047 L F
.781 .991 .759 r
.21996 .54206 m .21767 .54329 L .22041 .54043 L F
.798 .739 .798 r
.34388 .6681 m .34794 .66643 L .34648 .66683 L F
.023 0 0 r
.34794 .66643 m .34922 .66648 L .34648 .66683 L F
0 0 0 r
.34958 .66475 m .34922 .66648 L .35136 .66577 L F
.34958 .66475 m .34921 .66662 L .34922 .66648 L F
.34921 .66662 m .34856 .66996 L .34922 .66648 L F
.023 0 0 r
.34794 .66643 m .34923 .66637 L .34922 .66648 L F
.34923 .66637 m .35045 .66632 L .34922 .66648 L F
.602 .69 .904 r
.33587 .55516 m .33997 .55678 L .33888 .55584 L F
.276 .682 .97 r
.33997 .55678 m .34249 .55696 L .33888 .55584 L F
0 0 0 r
.29308 .52715 m .29534 .52662 L .29769 .52605 L F
.302 .792 .755 r
.29769 .52605 m .29793 .52571 L .29963 .52595 L F
.29769 .52605 m .29534 .52662 L .29793 .52571 L F
.679 .714 .875 r
.31066 .632 m .31435 .63235 L .31242 .62917 L F
.718 .44 .505 r
.31396 .63497 m .31435 .63235 L .31066 .632 L F
.1 0 .322 r
.31452 .63323 m .31435 .63235 L .31396 .63497 L F
.876 .494 .021 r
.31242 .62917 m .31435 .63235 L .31452 .63323 L F
.684 .532 .673 r
.31732 .6604 m .3197 .66084 L .31979 .65729 L F
.701 .546 .674 r
.31979 .65729 m .3197 .66084 L .32363 .65988 L F
.635 .593 .789 r
.51738 .55152 m .51786 .55401 L .52 .55085 L F
.612 .56 .772 r
.51786 .55401 m .52124 .55493 L .52 .55085 L F
.649 .576 .76 r
.51786 .55401 m .52177 .55635 L .52124 .55493 L F
.985 .85 .624 r
.35495 .6228 m .35518 .62607 L .35389 .62495 L F
.855 .612 .571 r
.35501 .628 m .35389 .62495 L .35518 .62607 L F
.327 .102 .411 r
.35532 .64134 m .35489 .64433 L .35277 .64481 L F
.518 .299 .521 r
.35523 .64635 m .35277 .64481 L .35489 .64433 L F
.35523 .64635 m .35261 .64751 L .35277 .64481 L F
.487 .845 .993 r
.28943 .63142 m .29159 .63232 L .28701 .63207 L F
.474 .839 .992 r
.29163 .6309 m .29159 .63232 L .28943 .63142 L F
.152 .032 .451 r
.293 .63406 m .29159 .63232 L .294 .63197 L F
.293 .63406 m .29161 .63493 L .29159 .63232 L F
.917 .961 .796 r
.53367 .55151 m .53452 .55185 L .53512 .54922 L F
.489 .386 .664 r
.31611 .55128 m .31798 .54777 L .31548 .5484 L F
.31611 .55128 m .31836 .55087 L .31798 .54777 L F
.762 .249 0 r
.38941 .53486 m .3932 .53802 L .39069 .53645 L F
.69 .571 .716 r
.35044 .6333 m .34776 .63565 L .34676 .63165 L F
.532 .534 .802 r
.37775 .52529 m .37606 .52654 L .37487 .52252 L F
.15 0 .269 r
.37775 .52529 m .37534 .52878 L .37606 .52654 L F
.37775 .52529 m .37534 .52878 L .37606 .52654 L F
.718 .283 .217 r
.3578 .60731 m .35829 .60827 L .35914 .6067 L F
0 0 .438 r
.3578 .60731 m .35801 .60975 L .35903 .61024 L F
.502 .626 .906 r
.35844 .61323 m .35903 .61024 L .35801 .60975 L F
.718 .283 .217 r
.3578 .60731 m .35903 .61024 L .3557 .60908 L F
.3578 .60731 m .3557 .60908 L .35829 .60827 L F
.202 0 .291 r
.32306 .61069 m .32183 .61289 L .31952 .6137 L F
.18 0 .108 r
.32183 .61289 m .31858 .61558 L .31952 .6137 L F
.624 .682 .885 r
.31917 .52495 m .32072 .52715 L .31668 .52566 L F
.634 .686 .882 r
.32307 .52614 m .32072 .52715 L .31917 .52495 L F
.36 .454 .821 r
.22165 .62276 m .22157 .61854 L .21947 .61886 L F
.22165 .62276 m .22311 .62217 L .22157 .61854 L F
.491 .044 .117 r
.26284 .55608 m .26721 .55418 L .26487 .55466 L F
.515 .261 .467 r
.37675 .68163 m .37664 .68436 L .37395 .68455 L F
.432 .33 .639 r
.3788 .67851 m .37675 .68163 L .37626 .67966 L F
.3788 .67851 m .37918 .6815 L .37675 .68163 L F
.403 .171 .444 r
.37918 .6815 m .37664 .68436 L .37675 .68163 L F
0 0 .319 r
.35711 .51729 m .35794 .51781 L .35992 .51687 L F
.567 .923 .744 r
.35992 .51687 m .35794 .51781 L .36092 .51575 L F
0 .418 .856 r
.35794 .51781 m .35891 .51733 L .35859 .51744 L F
0 0 .319 r
.35711 .51729 m .35721 .51822 L .35794 .51781 L F
.792 .607 .651 r
.35794 .51781 m .35664 .51663 L .3568 .51419 L F
.452 0 0 r
.35794 .51781 m .35657 .51814 L .35411 .51747 L F
.743 .666 .775 r
.36092 .51575 m .35794 .51781 L .3568 .51419 L F
.36092 .51575 m .35794 .51781 L .3568 .51419 L F
0 .418 .856 r
.35794 .51781 m .35859 .51744 L .35657 .51814 L F
0 0 .319 r
.35721 .51822 m .35745 .52028 L .35794 .51781 L F
.635 .163 .114 r
.33995 .56008 m .34206 .56177 L .34405 .56026 L F
.502 .853 .593 r
.34405 .56026 m .34346 .56054 L .34622 .55972 L F
.34405 .56026 m .34206 .56177 L .34346 .56054 L F
.74 .565 .657 r
.34928 .55443 m .34556 .55091 L .34785 .55194 L F
.34928 .55443 m .34606 .55451 L .34556 .55091 L F
.437 .313 .613 r
.35716 .61627 m .35844 .61323 L .35629 .61449 L F
.35716 .61627 m .35951 .61638 L .35844 .61323 L F
.432 .217 .484 r
.35716 .61627 m .3585 .61875 L .35951 .61638 L F
.531 .325 .546 r
.29526 .54498 m .29508 .54757 L .29262 .548 L F
.777 .521 .548 r
.29845 .54008 m .2946 .54193 L .29576 .54314 L F
0 .044 .528 r
.29518 .5425 m .29576 .54314 L .2946 .54193 L F
.788 .998 .847 r
.29576 .54314 m .29645 .5439 L .29819 .54232 L F
0 .044 .528 r
.29665 .54393 m .29576 .54314 L .29518 .5425 L F
.788 .998 .847 r
.29576 .54314 m .29526 .54498 L .29645 .5439 L F
.455 .262 .528 r
.29721 .54694 m .29526 .54498 L .29576 .54314 L F
.29721 .54694 m .29508 .54757 L .29526 .54498 L F
.248 0 .186 r
.34484 .60438 m .34167 .60693 L .34295 .6065 L F
.48 .595 .89 r
.34141 .60742 m .34295 .6065 L .34167 .60693 L F
.523 .394 .646 r
.28872 .56601 m .28572 .56403 L .28963 .56429 L F
.606 .324 .463 r
.29081 .56274 m .28872 .56601 L .28963 .56429 L F
.69 .571 .716 r
.35044 .6333 m .34676 .63165 L .34877 .63082 L F
.785 .42 0 r
.38762 .53102 m .38941 .53486 L .38883 .53309 L F
.973 .716 .484 r
.37284 .53195 m .37426 .53464 L .37694 .53446 L F
.37284 .53195 m .37278 .5346 L .37426 .53464 L F
.521 .814 .999 r
.21326 .61629 m .21384 .61442 L .21138 .6151 L F
.21326 .61629 m .21613 .61575 L .21384 .61442 L F
.271 .151 .527 r
.3088 .59573 m .31101 .59125 L .30841 .59199 L F
.3088 .59573 m .31028 .59529 L .31101 .59125 L F
.217 0 .011 r
.3088 .59573 m .31057 .59649 L .31028 .59529 L F
0 0 0 r
.3297 .56542 m .33046 .56542 L .33118 .56387 L F
.3297 .56542 m .32861 .56643 L .33046 .56542 L F
.73 .426 .465 r
.39521 .57285 m .39205 .57136 L .39382 .56921 L F
.39521 .57285 m .39137 .57272 L .39205 .57136 L F
.047 .612 .774 r
.24196 .5502 m .24009 .55006 L .23806 .55003 L F
.64 .596 .79 r
.35532 .64134 m .35133 .63827 L .35385 .63809 L F
.514 .26 .468 r
.35742 .64367 m .35532 .64134 L .35771 .64117 L F
.35742 .64367 m .35489 .64433 L .35532 .64134 L F
.349 0 .18 r
.33033 .58525 m .32678 .5877 L .32652 .58522 L F
.33033 .58525 m .32907 .58776 L .32678 .5877 L F
0 0 0 r
.33073 .58606 m .33033 .58525 L .33266 .5851 L F
.33073 .58606 m .32907 .58776 L .33033 .58525 L F
.518 .423 .687 r
.38134 .60076 m .37931 .60359 L .37889 .60146 L F
.38134 .60076 m .38171 .60339 L .37931 .60359 L F
.448 .365 .671 r
.38175 .60609 m .37931 .60359 L .38171 .60339 L F
.38175 .60609 m .37968 .60686 L .37931 .60359 L F
.738 .495 .561 r
.32943 .57211 m .32581 .56937 L .32996 .56967 L F
.416 .094 .309 r
.33251 .56972 m .32943 .57211 L .32996 .56967 L F
.492 0 0 r
.2858 .64637 m .28727 .64523 L .28981 .64641 L F
.353 0 0 r
.28727 .64523 m .29186 .64644 L .28981 .64641 L F
.764 .7 .792 r
.36337 .68218 m .36486 .68532 L .36091 .68492 L F
.794 .602 .642 r
.36464 .68809 m .36091 .68492 L .36486 .68532 L F
.715 .679 .814 r
.36712 .68308 m .36486 .68532 L .36337 .68218 L F
.691 .638 .791 r
.36712 .68308 m .36846 .68549 L .36486 .68532 L F
.704 .541 .664 r
.36846 .68549 m .36464 .68809 L .36486 .68532 L F
.758 .69 .787 r
.52787 .55681 m .52953 .55921 L .53172 .55742 L F
.197 0 .062 r
.20248 .55162 m .20364 .55234 L .20462 .55088 L F
.20248 .55162 m .2015 .55315 L .20364 .55234 L F
.214 .204 .63 r
.17721 .58528 m .17818 .58113 L .17623 .58291 L F
.441 .016 .136 r
.29508 .54757 m .29095 .54989 L .29262 .548 L F
.523 .394 .646 r
.28572 .56403 m .28872 .56601 L .28726 .56235 L F
.28572 .56403 m .28636 .56663 L .28872 .56601 L F
.28872 .56601 m .28636 .56663 L .28572 .56403 L F
0 0 0 r
.28227 .60437 m .28009 .60741 L .28116 .6064 L F
.007 0 .259 r
.28009 .60741 m .28075 .60871 L .28116 .6064 L F
.28009 .60741 m .27942 .60999 L .28075 .60871 L F
.564 .255 .402 r
.52479 .54148 m .52742 .54128 L .52739 .53926 L F
.526 .226 .4 r
.52742 .54128 m .5302 .54083 L .52739 .53926 L F
.364 .028 .255 r
.36449 .53808 m .36678 .53771 L .36739 .53507 L F
.586 .223 .319 r
.36739 .53507 m .36678 .53771 L .36953 .53693 L F
.413 .287 .598 r
.31732 .6604 m .31739 .6631 L .31935 .6624 L F
.66 .268 .292 r
.31935 .6624 m .3197 .66084 L .31732 .6604 L F
.413 .287 .598 r
.31732 .6604 m .31739 .6631 L .31935 .6624 L F
.23 .677 .953 r
.30646 .5412 m .3025 .54006 L .30422 .54175 L F
.483 .357 .632 r
.30451 .54446 m .30646 .5412 L .30422 .54175 L F
.586 .358 .537 r
.32819 .62278 m .33123 .62426 L .33105 .6202 L F
.957 .663 .434 r
.33105 .6202 m .3311 .62139 L .32978 .62217 L F
.3311 .62139 m .33123 .62426 L .32978 .62217 L F
.766 .7 .79 r
.32978 .62217 m .33123 .62426 L .32921 .62241 L F
0 0 0 r
.32958 .62229 m .32978 .62217 L .32921 .62241 L F
.978 .701 .433 r
.33154 .62279 m .33259 .62196 L .32978 .62217 L F
.33259 .62196 m .33219 .62138 L .32978 .62217 L F
.603 .474 .677 r
.33154 .62279 m .33339 .62226 L .33267 .62207 L F
.33156 .6229 m .33339 .62226 L .33154 .62279 L F
.052 0 .26 r
.33216 .62291 m .33257 .62292 L .33281 .62273 L F
.33117 .62303 m .33281 .62273 L .33339 .62226 L F
.978 .701 .433 r
.33405 .62118 m .33411 .62076 L .33154 .62279 L F
.603 .474 .677 r
.33117 .62303 m .33267 .62207 L .33135 .62172 L F
.978 .701 .433 r
.3337 .62356 m .33267 .62207 L .33234 .62228 L F
.3337 .62356 m .33234 .62228 L .33219 .62238 L F
.52 .132 .247 r
.33281 .62273 m .3337 .62356 L .33339 .62226 L F
.33257 .62292 m .3337 .62356 L .33281 .62273 L F
.978 .701 .433 r
.3337 .62356 m .33185 .62291 L .33289 .62293 L F
.095 .453 .884 r
.32921 .62241 m .33123 .62426 L .32819 .62278 L F
0 .186 .701 r
.32819 .62278 m .33044 .6252 L .32921 .62241 L F
.91 .67 .564 r
.32921 .62241 m .33044 .6252 L .32854 .62395 L F
.52 .132 .247 r
.32997 .62502 m .3337 .62356 L .33257 .62292 L F
.052 0 .26 r
.32854 .62395 m .33281 .62273 L .33117 .62303 L F
.978 .701 .433 r
.33289 .62293 m .33251 .62289 L .33135 .62172 L F
.33251 .62289 m .33154 .62279 L .33145 .62229 L F
.33251 .62289 m .33145 .62229 L .33135 .62172 L F
.33185 .62291 m .33154 .62279 L .33289 .62293 L F
.052 0 .26 r
.32854 .62395 m .32997 .62502 L .33257 .62292 L F
.32854 .62395 m .33257 .62292 L .33216 .62291 L F
.978 .701 .433 r
.33308 .62267 m .33405 .62118 L .33267 .62207 L F
.608 .182 .207 r
.33267 .62207 m .33339 .62226 L .3337 .62356 L F
.978 .701 .433 r
.3337 .62356 m .33385 .62253 L .33308 .62267 L F
.33385 .62253 m .33405 .62118 L .33308 .62267 L F
.33154 .62279 m .32978 .62217 L .33135 .62172 L F
.603 .474 .677 r
.33117 .62303 m .33156 .6229 L .33154 .62279 L F
.608 .182 .207 r
.33135 .62172 m .33267 .62207 L .3337 .62356 L F
.978 .701 .433 r
.33259 .62196 m .33411 .62076 L .33219 .62138 L F
.603 .474 .677 r
.32854 .62395 m .33117 .62303 L .33135 .62172 L F
0 0 0 r
.33135 .62172 m .32978 .62217 L .32958 .62229 L F
.957 .663 .434 r
.33105 .6202 m .32978 .62217 L .3335 .61963 L F
0 .111 .663 r
.32536 .58365 m .32627 .5829 L .32758 .58172 L F
.164 .677 .894 r
.36903 .52646 m .36724 .52596 L .36624 .52608 L F
.605 .07 0 r
.37058 .52664 m .36724 .52596 L .36903 .52646 L F
.37058 .52664 m .3701 .52798 L .36724 .52596 L F
.231 .28 .707 r
.36724 .52596 m .3701 .52798 L .36938 .5257 L F
.36724 .52596 m .36938 .5257 L .36861 .52326 L F
.164 .677 .894 r
.36624 .52608 m .36724 .52596 L .3651 .52593 L F
.606 .324 .463 r
.29081 .56274 m .29177 .56591 L .28872 .56601 L F
.144 0 .308 r
.29381 .55963 m .29081 .56274 L .29188 .56018 L F
.29381 .55963 m .29314 .56232 L .29081 .56274 L F
.39 .202 .501 r
.294 .56494 m .29081 .56274 L .29314 .56232 L F
.294 .56494 m .29177 .56591 L .29081 .56274 L F
.615 .808 .974 r
.24196 .76609 m .23992 .76707 L .23771 .76552 L F
.23771 .76552 m .23992 .76707 L .24196 .76609 L F
.42 .497 .832 r
.39119 .5751 m .39092 .57886 L .38918 .57524 L F
.39119 .5751 m .39255 .5786 L .39092 .57886 L F
.278 0 .135 r
.31579 .64467 m .31942 .64155 L .31893 .64349 L F
.471 .457 .761 r
.32115 .64087 m .31942 .64155 L .31856 .63836 L F
.289 .038 .35 r
.31893 .64349 m .31942 .64155 L .32115 .64087 L F
.338 .691 .981 r
.34549 .60359 m .34484 .60438 L .34295 .6065 L F
.34549 .60359 m .34684 .60487 L .34484 .60438 L F
.684 .275 .264 r
.34484 .60438 m .34684 .60487 L .34838 .60658 L F
.857 .548 .021 r
.33835 .54822 m .33962 .5524 L .33957 .55017 L F
.259 0 .095 r
.33957 .55017 m .33962 .5524 L .34089 .55014 L F
.59 .534 .76 r
.34844 .55538 m .34606 .55451 L .34928 .55443 L F
.539 .632 .891 r
.35031 .54975 m .3516 .55066 L .34955 .55164 L F
.555 .665 .91 r
.35131 .55182 m .34928 .55443 L .34849 .55306 L F
.35131 .55182 m .34849 .55306 L .35004 .55186 L F
.599 .857 .507 r
.34928 .55443 m .34921 .55451 L .35131 .55182 L F
.34921 .55451 m .34844 .55538 L .35118 .55197 L F
.34921 .55451 m .35118 .55197 L .35131 .55182 L F
.539 .632 .891 r
.3516 .55066 m .35199 .55094 L .35019 .55175 L F
.599 .857 .507 r
.34928 .55443 m .34844 .55538 L .35131 .55182 L F
.246 .64 .961 r
.35131 .55182 m .35456 .553 L .3555 .55414 L F
.324 .666 .974 r
.35402 .55238 m .35131 .55182 L .34955 .55164 L F
.539 .632 .891 r
.35199 .55094 m .35402 .55238 L .35122 .55192 L F
.35199 .55094 m .35122 .55192 L .35019 .55175 L F
.3516 .55066 m .35019 .55175 L .34955 .55164 L F
.555 .665 .91 r
.35004 .55186 m .34849 .55306 L .34785 .55194 L F
.704 .541 .664 r
.36846 .68549 m .3685 .68829 L .36464 .68809 L F
.638 .649 .844 r
.36943 .68205 m .36846 .68549 L .36712 .68308 L F
.36943 .68205 m .37116 .68521 L .36846 .68549 L F
.62 .474 .661 r
.37114 .68796 m .36846 .68549 L .37116 .68521 L F
.37114 .68796 m .3685 .68829 L .36846 .68549 L F
.69 .147 0 r
.23968 .62009 m .24195 .62241 L .24388 .62311 L F
.129 .564 .923 r
.24413 .62206 m .24388 .62311 L .24195 .62241 L F
.24413 .62206 m .24605 .62322 L .24388 .62311 L F
.316 0 0 r
.27093 .64395 m .27172 .64346 L .27304 .64344 L F
.381 .845 .826 r
.27172 .64346 m .27326 .64258 L .27304 .64344 L F
.146 .054 .485 r
.33639 .61346 m .3378 .61539 L .33801 .61271 L F
.33639 .61346 m .33654 .61646 L .3378 .61539 L F
.457 .443 .754 r
.30097 .55338 m .30284 .55434 L .30184 .55062 L F
.819 .719 .755 r
.35229 .58462 m .35611 .58561 L .3542 .58211 L F
.781 .344 .212 r
.35229 .58462 m .35411 .58691 L .35611 .58561 L F
.478 .567 .867 r
.3542 .58211 m .35611 .58561 L .35753 .58444 L F
0 0 0 r
.35753 .58444 m .35482 .58733 L .35611 .58561 L F
.35753 .58444 m .35482 .58733 L .35611 .58561 L F
.49 0 0 r
.33326 .53454 m .33657 .53645 L .33919 .53756 L F
.534 .858 .996 r
.33919 .53756 m .33909 .53577 L .33945 .53646 L F
.33919 .53756 m .33657 .53645 L .33909 .53577 L F
.926 .689 .561 r
.27948 .62151 m .28159 .62253 L .28191 .61976 L F
.927 .972 .745 r
.28116 .61905 m .27948 .62151 L .28191 .61976 L F
.638 .415 .564 r
.22681 .7877 m .22809 .78523 L .22519 .78446 L F
.714 .748 .878 r
.52787 .55681 m .53172 .55742 L .53017 .55575 L F
.299 0 0 r
.32889 .6696 m .32946 .67019 L .32645 .66999 L F
.32889 .6696 m .33117 .67027 L .32946 .67019 L F
.475 .491 .794 r
.36891 .51693 m .36763 .52014 L .36626 .5169 L F
.36891 .51693 m .36986 .51974 L .36763 .52014 L F
.631 .649 .849 r
.30893 .62745 m .31066 .632 L .31242 .62917 L F
.718 .44 .505 r
.31396 .63497 m .31066 .632 L .31163 .63585 L F
0 0 0 r
.23084 .55882 m .23087 .5591 L .2303 .56054 L F
.23149 .55673 m .23087 .5591 L .23084 .55882 L F
.244 0 0 r
.23293 .55797 m .23089 .55935 L .23087 .5591 L F
.315 .769 .955 r
.2303 .56054 m .22858 .55996 L .22758 .56033 L F
.563 .889 .988 r
.23087 .5591 m .22858 .55996 L .2303 .56054 L F
.244 0 0 r
.23089 .55935 m .22894 .56066 L .23087 .5591 L F
.359 0 0 r
.23087 .5591 m .2296 .55958 L .22858 .55996 L F
.2296 .55958 m .22648 .56077 L .22858 .55996 L F
.315 .769 .955 r
.22758 .56033 m .22858 .55996 L .22626 .56022 L F
.717 .534 .641 r
.52736 .54361 m .52792 .54647 L .52869 .54376 L F
.522 .569 .844 r
.52869 .54376 m .5302 .54083 L .52736 .54361 L F
.52869 .54376 m .53219 .54388 L .5302 .54083 L F
.658 .451 .592 r
.52792 .54647 m .53219 .54388 L .52869 .54376 L F
.572 .403 .614 r
.34772 .5662 m .34524 .56944 L .34535 .56677 L F
.64 .662 .856 r
.35243 .63201 m .35044 .6333 L .34877 .63082 L F
.502 .593 .878 r
.24012 .6126 m .23848 .61349 L .23725 .61075 L F
.137 .003 .422 r
.23916 .6159 m .23848 .61349 L .24012 .6126 L F
.23916 .6159 m .23825 .61645 L .23848 .61349 L F
.487 .834 .997 r
.25692 .74695 m .25511 .7477 L .25544 .74607 L F
.729 .754 .246 r
.25544 .74607 m .25511 .7477 L .25432 .75026 L F
.217 0 .297 r
.25432 .75026 m .25511 .7477 L .25692 .74695 L F
.635 .461 .629 r
.32363 .65988 m .32618 .66035 L .32613 .65721 L F
.532 .371 .608 r
.32618 .66035 m .32867 .65669 L .32613 .65721 L F
.196 0 .305 r
.36799 .65588 m .36722 .65953 L .36515 .65956 L F
0 0 0 r
.36722 .65953 m .36463 .66044 L .36515 .65956 L F
.557 .525 .775 r
.52177 .55635 m .52377 .55412 L .52124 .55493 L F
.52177 .55635 m .52381 .55573 L .52377 .55412 L F
.562 .072 .05 r
.25247 .54267 m .24996 .544 L .24735 .5436 L F
.263 .306 .719 r
.38462 .55396 m .38537 .5578 L .38684 .55603 L F
.492 .51 .804 r
.38597 .56035 m .38684 .55603 L .38537 .5578 L F
.261 0 0 r
.26666 .54651 m .26584 .54513 L .26813 .54497 L F
.26666 .54651 m .26426 .54708 L .26584 .54513 L F
.465 .21 .443 r
.3538 .55995 m .35082 .56344 L .35032 .56035 L F
.3538 .55995 m .35339 .56294 L .35082 .56344 L F
.648 .611 .799 r
.35555 .55673 m .3567 .56035 L .3538 .55995 L F
.189 0 .354 r
.35513 .56187 m .3538 .55995 L .3567 .56035 L F
.35513 .56187 m .35339 .56294 L .3538 .55995 L F
.111 .069 .526 r
.30161 .57623 m .30366 .57626 L .30358 .57417 L F
.30161 .57623 m .30193 .57883 L .30366 .57626 L F
0 .349 .781 r
.2471 .63476 m .24707 .63419 L .2449 .63419 L F
.611 .401 .573 r
.51868 .54177 m .51867 .54463 L .52117 .54383 L F
.633 .395 .54 r
.51868 .54177 m .52117 .54383 L .52118 .54163 L F
.533 .027 0 r
.34849 .6066 m .34684 .60487 L .34549 .60359 L F
0 .045 .601 r
.34838 .60658 m .34684 .60487 L .34849 .6066 L F
.447 .323 .618 r
.36044 .65363 m .36305 .65598 L .36438 .65417 L F
.661 .851 .451 r
.36438 .65417 m .3652 .65263 L .36678 .65376 L F
.36438 .65417 m .36305 .65598 L .3652 .65263 L F
.463 .386 .684 r
.32851 .63844 m .33123 .64074 L .33027 .6379 L F
.32851 .63844 m .32914 .64131 L .33123 .64074 L F
.992 .75 .461 r
.31517 .57809 m .31464 .57865 L .3141 .57462 L F
0 0 .034 r
.28227 .60437 m .28339 .60491 L .28422 .60345 L F
.28227 .60437 m .28116 .6064 L .28339 .60491 L F
.717 .92 .574 r
.35557 .56975 m .35396 .57195 L .35427 .57094 L F
.52 .343 .581 r
.35319 .573 m .35556 .57258 L .35316 .57304 L F
.35557 .56975 m .35556 .57258 L .35319 .573 L F
.527 .298 .511 r
.35848 .56937 m .35821 .57221 L .35556 .57258 L F
.753 .296 .167 r
.35821 .57221 m .358 .57214 L .35556 .57258 L F
.527 .298 .511 r
.35848 .56937 m .35556 .57258 L .35557 .56975 L F
.753 .296 .167 r
.358 .57214 m .35427 .57094 L .35556 .57258 L F
.959 .912 .55 r
.35557 .56975 m .35557 .56975 L .35521 .5663 L F
.35557 .56975 m .35427 .57094 L .35521 .5663 L F
.931 .961 .767 r
.35521 .5663 m .3549 .5668 L .35524 .5666 L F
.35521 .5663 m .35524 .5666 L .35539 .56651 L F
.753 .296 .167 r
.35821 .57221 m .35622 .5736 L .35427 .57094 L F
.717 .92 .574 r
.35396 .57195 m .35316 .57304 L .35427 .57094 L F
.54 .76 .978 r
.35316 .57304 m .35556 .57258 L .35427 .57094 L F
.673 .182 0 r
.35427 .57094 m .35622 .5736 L .35515 .57273 L F
.35427 .57094 m .35515 .57273 L .35462 .56982 L F
.35427 .57094 m .35462 .56982 L .35459 .56968 L F
.548 .434 .676 r
.26958 .72576 m .27198 .72546 L .27187 .72155 L F
0 .125 .67 r
.19974 .58806 m .20168 .59017 L .20132 .59176 L F
.381 .694 .982 r
.20168 .59017 m .20335 .5915 L .20132 .59176 L F
.771 .386 .326 r
.36008 .63857 m .36478 .64128 L .36424 .63842 L F
.04 .609 .742 r
.30683 .55434 m .3054 .5543 L .30284 .55434 L F
.442 .876 .9 r
.30779 .55338 m .30683 .55434 L .30938 .55402 L F
.30779 .55338 m .3054 .5543 L .30683 .55434 L F
.403 .763 .994 r
.26328 .63748 m .26395 .63614 L .26162 .63642 L F
.26328 .63748 m .26567 .63724 L .26395 .63614 L F
.085 .45 .882 r
.38067 .52411 m .38245 .5247 L .38199 .52582 L F
.699 .16 0 r
.38199 .52582 m .3841 .52809 L .38596 .52882 L F
0 .126 .675 r
.38245 .5247 m .3841 .52809 L .38199 .52582 L F
.551 .18 .29 r
.31935 .6624 m .32363 .65988 L .3197 .66084 L F
.31935 .6624 m .32225 .66249 L .32363 .65988 L F
.187 0 .098 r
.32363 .65988 m .32429 .66165 L .32618 .66035 L F
.32363 .65988 m .32225 .66249 L .32429 .66165 L F
.498 .262 .488 r
.37476 .55418 m .37754 .55382 L .37736 .55125 L F
.515 .336 .576 r
.37736 .55125 m .38014 .55109 L .37981 .54762 L F
.245 .082 .451 r
.37736 .55125 m .37921 .55267 L .38014 .55109 L F
.37736 .55125 m .37754 .55382 L .37921 .55267 L F
.549 .468 .717 r
.39052 .58422 m .38882 .58861 L .38849 .58592 L F
.32 .281 .658 r
.17721 .58528 m .17742 .58937 L .17931 .58722 L F
.347 .27 .626 r
.17757 .59147 m .17931 .58722 L .17742 .58937 L F
.992 .755 .39 r
.38209 .54174 m .38104 .54068 L .38123 .53814 L F
.975 .771 .564 r
.3825 .5442 m .38104 .54068 L .38209 .54174 L F
.137 .68 .708 r
.24866 .53149 m .25101 .53106 L .25273 .53077 L F
.169 .7 .695 r
.25101 .53106 m .2549 .53015 L .25273 .53077 L F
.521 .307 .53 r
.30184 .55062 m .30475 .54757 L .30217 .54824 L F
.336 .155 .482 r
.17813 .57855 m .18021 .57528 L .17861 .57614 L F
.096 0 .188 r
.20954 .58264 m .20858 .58481 L .21107 .58164 L F
.20954 .58264 m .20858 .58481 L .21107 .58164 L F
.696 .837 .95 r
.23484 .61237 m .23065 .61211 L .23265 .61133 L F
.698 .887 .967 r
.23725 .61075 m .23484 .61237 L .23265 .61133 L F
.309 .794 .895 r
.26159 .52978 m .26387 .52932 L .26564 .52948 L F
.486 .889 .941 r
.26564 .52948 m .2664 .52844 L .26791 .52896 L F
.26564 .52948 m .26387 .52932 L .2664 .52844 L F
.785 .951 .927 r
.29845 .54008 m .29819 .54232 L .29985 .54048 L F
.863 .991 .829 r
.29845 .54008 m .29576 .54314 L .29819 .54232 L F
.378 .125 .398 r
.22515 .5562 m .22235 .55925 L .22294 .55662 L F
.764 .669 .758 r
.22235 .55925 m .22515 .5562 L .22294 .55662 L F
.436 .468 .795 r
.28571 .62811 m .28503 .63158 L .2833 .62863 L F
.28571 .62811 m .28701 .63207 L .28503 .63158 L F
0 0 0 r
.37968 .60686 m .37854 .6088 L .3766 .60994 L F
.491 .14 .299 r
.38175 .60609 m .37854 .6088 L .37968 .60686 L F
0 0 .502 r
.38597 .52814 m .38596 .52882 L .3841 .52809 L F
.38597 .52814 m .38762 .53102 L .38596 .52882 L F
.609 .438 .625 r
.38878 .59101 m .38555 .58998 L .38882 .58861 L F
.38878 .59101 m .38626 .5917 L .38555 .58998 L F
.52 .302 .524 r
.3518 .58204 m .35229 .58462 L .3542 .58211 L F
.779 .653 .724 r
.35082 .56344 m .35171 .56668 L .34772 .5662 L F
.243 .164 .564 r
.34931 .5678 m .34772 .5662 L .35171 .56668 L F
0 .039 .592 r
.35251 .56557 m .35171 .56668 L .35082 .56344 L F
.591 .936 .758 r
.35251 .56557 m .34931 .5678 L .35171 .56668 L F
.425 .67 .964 r
.22488 .62754 m .22754 .62743 L .2246 .6258 L F
.22488 .62754 m .22852 .62867 L .22754 .62743 L F
.492 .51 .804 r
.38597 .56035 m .38803 .55966 L .38684 .55603 L F
.323 0 .02 r
.38433 .56186 m .38803 .55966 L .38597 .56035 L F
.58 .083 .039 r
.24881 .623 m .25215 .6232 L .25035 .62249 L F
.603 .289 .411 r
.24123 .75309 m .2392 .75065 L .2389 .75363 L F
.24123 .75309 m .24193 .75061 L .2392 .75065 L F
.2392 .75065 m .24123 .75309 L .2389 .75363 L F
.2392 .75065 m .24193 .75061 L .24123 .75309 L F
.597 .557 .78 r
.37033 .5321 m .37284 .53195 L .37213 .52798 L F
.421 .353 .675 r
.37033 .5321 m .37278 .5346 L .37284 .53195 L F
.565 .907 .973 r
.31668 .52566 m .31727 .52421 L .31917 .52495 L F
.31668 .52566 m .31509 .5252 L .31727 .52421 L F
.306 .317 .708 r
.30078 .65253 m .29874 .65476 L .30246 .6561 L F
.511 .371 .627 r
.31163 .63585 m .31411 .63763 L .31396 .63497 L F
.732 .989 .878 r
.32312 .59631 m .32282 .59785 L .32245 .59706 L F
.66 .187 .118 r
.32087 .60166 m .32259 .60045 L .31858 .59999 L F
.485 0 0 r
.31858 .59999 m .32259 .60045 L .3205 .60053 L F
.888 .637 .553 r
.3205 .60053 m .32282 .59785 L .32312 .59631 L F
.3205 .60053 m .32259 .60045 L .32282 .59785 L F
.146 0 .359 r
.33297 .57761 m .33241 .58032 L .3339 .57931 L F
.33297 .57761 m .3339 .57931 L .33313 .57827 L F
.098 0 0 r
.33079 .57759 m .33297 .57761 L .3328 .57691 L F
.377 .046 .272 r
.33079 .57759 m .33241 .58032 L .33297 .57761 L F
.146 0 .359 r
.33297 .57761 m .33313 .57827 L .33181 .57651 L F
.098 0 0 r
.3328 .57691 m .33297 .57761 L .33434 .57638 L F
.377 .046 .272 r
.33079 .57759 m .32989 .58101 L .33241 .58032 L F
.625 .599 .804 r
.27488 .54503 m .27859 .54483 L .2767 .54353 L F
.27488 .54503 m .27841 .54735 L .27859 .54483 L F
.546 .32 .524 r
.27859 .54483 m .27841 .54735 L .28093 .54684 L F
0 0 0 r
.20375 .57585 m .20273 .57793 L .20221 .57897 L F
0 0 .138 r
.20273 .57793 m .20252 .58045 L .20221 .57897 L F
.214 .204 .63 r
.17721 .58528 m .1785 .58483 L .17818 .58113 L F
.237 .271 .694 r
.17721 .58528 m .17931 .58722 L .1785 .58483 L F
0 0 0 r
.29368 .60607 m .29186 .60689 L .29478 .60408 L F
.29072 .60938 m .29186 .60689 L .29368 .60607 L F
.389 .062 .286 r
.3766 .60994 m .37387 .61295 L .37394 .61014 L F
.3766 .60994 m .37559 .61336 L .37387 .61295 L F
.36 .037 .275 r
.37737 .61216 m .3766 .60994 L .37854 .6088 L F
.37737 .61216 m .37559 .61336 L .3766 .60994 L F
.138 0 0 r
.1961 .55692 m .19809 .55622 L .19949 .55416 L F
.151 0 0 r
.19949 .55416 m .2002 .55545 L .2015 .55315 L F
.19949 .55416 m .19809 .55622 L .2002 .55545 L F
.788 .697 .764 r
.32429 .62243 m .32567 .62616 L .32819 .62278 L F
.834 .999 .818 r
.30078 .64296 m .30323 .6423 L .30068 .6448 L F
.376 0 0 r
.30652 .64329 m .30323 .6423 L .30078 .64296 L F
.496 .89 .952 r
.24873 .6356 m .25284 .63487 L .25157 .63538 L F
0 0 0 r
.2553 .6343 m .25157 .63538 L .25284 .63487 L F
.739 .673 .787 r
.32218 .62393 m .32567 .62616 L .32429 .62243 L F
.85 .45 .284 r
.32218 .62393 m .32375 .62765 L .32567 .62616 L F
.552 .529 .783 r
.32851 .62791 m .32567 .62616 L .32801 .62572 L F
.069 0 0 r
.32567 .62616 m .32662 .62644 L .32801 .62572 L F
.32567 .62616 m .32375 .62765 L .32662 .62644 L F
.502 .349 .605 r
.36274 .63238 m .36473 .62903 L .36004 .6285 L F
.36274 .63238 m .36516 .63184 L .36473 .62903 L F
.36473 .62903 m .36516 .63184 L .36274 .63238 L F
.467 .54 .849 r
.31442 .61897 m .31493 .61511 L .31362 .61695 L F
.31442 .61897 m .31734 .6195 L .31493 .61511 L F
.1 .573 .909 r
.33587 .55516 m .3359 .55414 L .33456 .55353 L F
.33587 .55516 m .33888 .55584 L .3359 .55414 L F
0 0 0 r
.34141 .60742 m .33801 .61271 L .3403 .61213 L F
.48 .595 .89 r
.34141 .60742 m .34271 .60769 L .34295 .6065 L F
.585 .345 .519 r
.37795 .63672 m .37508 .63954 L .37733 .63827 L F
.607 .533 .746 r
.37588 .64842 m .37623 .65087 L .37328 .65083 L F
.149 0 .228 r
.37328 .65083 m .37533 .65017 L .37588 .64842 L F
.545 .18 .298 r
.37623 .65087 m .37414 .65222 L .37328 .65083 L F
.235 .083 .461 r
.37328 .65083 m .37414 .65222 L .37533 .65017 L F
.068 .031 .502 r
.37414 .65222 m .37357 .65375 L .37328 .65083 L F
.37414 .65222 m .37357 .65375 L .37328 .65083 L F
.794 .602 .642 r
.36464 .68809 m .36065 .68768 L .36091 .68492 L F
.829 .566 .541 r
.36464 .68809 m .36081 .69016 L .36065 .68768 L F
.36464 .68809 m .36462 .69099 L .36081 .69016 L F
.693 .452 .553 r
.36847 .69068 m .36464 .68809 L .3685 .68829 L F
.36847 .69068 m .36462 .69099 L .36464 .68809 L F
.502 .626 .906 r
.35844 .61323 m .36132 .61386 L .35903 .61024 L F
.631 .42 .578 r
.35844 .61323 m .35951 .61638 L .36132 .61386 L F
.656 .415 .543 r
.28746 .55972 m .28972 .56218 L .29188 .56018 L F
.671 .407 .513 r
.28972 .56218 m .29381 .55963 L .29188 .56018 L F
.454 .073 .225 r
.34136 .63812 m .34026 .64023 L .33745 .64048 L F
.296 0 .098 r
.34317 .6382 m .34026 .64023 L .34136 .63812 L F
0 .056 .619 r
.23996 .61872 m .23968 .62009 L .23825 .61645 L F
0 .132 .679 r
.24075 .62029 m .23968 .62009 L .23996 .61872 L F
.24075 .62029 m .24195 .62241 L .23968 .62009 L F
.975 .909 .677 r
.35456 .553 m .35313 .55558 L .3555 .55414 L F
.35456 .553 m .35313 .55558 L .3555 .55414 L F
0 0 .051 r
.35682 .55282 m .35555 .55673 L .3555 .55414 L F
.359 .787 .971 r
.26791 .52896 m .27022 .52865 L .27198 .5293 L F
.332 .789 .946 r
.27022 .52865 m .27434 .52876 L .27198 .5293 L F
.274 0 .278 r
.19123 .56071 m .19248 .56206 L .19323 .55994 L F
.19123 .56071 m .1905 .56282 L .19248 .56206 L F
.493 .6 .889 r
.25744 .55691 m .2606 .55696 L .25818 .55684 L F
.25744 .55691 m .26232 .55925 L .2606 .55696 L F
.779 .472 .468 r
.39511 .57545 m .39137 .57272 L .39521 .57285 L F
.15 .303 .765 r
.39382 .56921 m .39646 .57147 L .39521 .57285 L F
0 0 .13 r
.39572 .57367 m .39521 .57285 L .39646 .57147 L F
.39572 .57367 m .39511 .57545 L .39521 .57285 L F
.471 .457 .761 r
.32115 .64087 m .31856 .63836 L .32083 .63761 L F
.581 .528 .76 r
.28831 .58169 m .28688 .58502 L .28679 .58219 L F
.28688 .58502 m .28831 .58169 L .28679 .58219 L F
.655 .454 .6 r
.37114 .68796 m .36847 .69068 L .3685 .68829 L F
.348 .793 .957 r
.2549 .53015 m .25736 .5297 L .25922 .53036 L F
.082 0 0 r
.25736 .5297 m .26159 .52978 L .25922 .53036 L F
.526 0 0 r
.31331 .55705 m .31541 .55835 L .31706 .55725 L F
.698 .629 .776 r
.31635 .55327 m .31706 .55725 L .31934 .55306 L F
.918 .552 .317 r
.31706 .55725 m .31541 .55835 L .31694 .55855 L F
.656 .576 .753 r
.31934 .55306 m .31706 .55725 L .31989 .55686 L F
.677 .405 .502 r
.31694 .55855 m .31989 .55686 L .31706 .55725 L F
.43 .193 .451 r
.31075 .58823 m .31303 .58766 L .31337 .58522 L F
.14 0 .089 r
.31519 .58446 m .31337 .58522 L .31605 .58337 L F
.444 .251 .523 r
.31303 .58766 m .31519 .58446 L .31337 .58522 L F
.14 0 .089 r
.31519 .58446 m .31337 .58522 L .31605 .58337 L F
.678 .514 .656 r
.37435 .68741 m .37116 .68521 L .37395 .68455 L F
.469 .293 .558 r
.37664 .68436 m .37435 .68741 L .37395 .68455 L F
.475 .133 .306 r
.27483 .5564 m .27344 .55965 L .27072 .55981 L F
.334 0 .238 r
.27571 .55886 m .27483 .5564 L .2773 .55617 L F
.157 0 0 r
.2796 .55652 m .27802 .55825 L .27571 .55886 L F
.128 0 0 r
.27802 .55825 m .27794 .55827 L .27571 .55886 L F
.334 0 .238 r
.27571 .55886 m .27353 .55944 L .27483 .5564 L F
.128 0 0 r
.27794 .55827 m .27293 .55953 L .27571 .55886 L F
.334 0 .238 r
.27571 .55886 m .27344 .55965 L .27353 .55944 L F
.726 .717 .842 r
.3637 .51757 m .35992 .51687 L .36244 .51567 L F
.625 .709 .907 r
.36626 .5169 m .3637 .51757 L .36244 .51567 L F
.658 .443 .581 r
.24307 .55989 m .24279 .56295 L .24512 .5606 L F
.485 .297 .55 r
.36888 .56974 m .37103 .56917 L .37145 .56649 L F
.529 .322 .544 r
.36841 .5723 m .37103 .56917 L .36888 .56974 L F
.012 0 0 r
.34171 .66813 m .34235 .66817 L .3399 .66843 L F
.508 .912 .86 r
.34235 .66817 m .34325 .66788 L .34413 .66747 L F
.27 .509 .9 r
.34413 .66747 m .3459 .66666 L .34564 .66633 L F
0 0 0 r
.34502 .66694 m .34413 .66747 L .34564 .66633 L F
.508 .912 .86 r
.34368 .66774 m .34648 .66683 L .34413 .66747 L F
.012 0 0 r
.3424 .66812 m .34388 .6681 L .34235 .66817 L F
.508 .912 .86 r
.34235 .66817 m .34388 .6681 L .34648 .66683 L F
.709 .363 .389 r
.34922 .66648 m .34413 .66747 L .34648 .66683 L F
.34922 .66648 m .34856 .66996 L .34413 .66747 L F
.27 .509 .9 r
.34413 .66747 m .34856 .66996 L .3459 .66666 L F
0 0 0 r
.34318 .66876 m .34413 .66747 L .34502 .66694 L F
.508 .912 .86 r
.34325 .66788 m .34368 .66774 L .34413 .66747 L F
0 0 0 r
.34231 .6682 m .34235 .66817 L .34413 .66747 L F
.33967 .66926 m .34235 .66817 L .34231 .6682 L F
.012 0 0 r
.34171 .66813 m .3424 .66812 L .34235 .66817 L F
.857 .613 .567 r
.30737 .59043 m .30345 .58751 L .30553 .58707 L F
.30737 .59043 m .30299 .5904 L .30345 .58751 L F
.478 0 0 r
.30737 .59043 m .30456 .59123 L .30299 .5904 L F
0 .003 .569 r
.30655 .58817 m .30737 .59043 L .30553 .58707 L F
.915 .978 .764 r
.30655 .58817 m .30456 .59123 L .30737 .59043 L F
0 0 0 r
.33118 .56387 m .33229 .56405 L .33401 .56373 L F
.33118 .56387 m .33046 .56542 L .33229 .56405 L F
.937 .64 .179 r
.35555 .55673 m .35593 .55948 L .3567 .56035 L F
.991 .88 .559 r
.35593 .55948 m .35513 .56187 L .3567 .56035 L F
.5 .793 .998 r
.2855 .52618 m .28495 .52771 L .28305 .52686 L F
.2855 .52618 m .28726 .52733 L .28495 .52771 L F
.617 .513 .714 r
.51599 .54515 m .51626 .54768 L .51867 .54463 L F
.646 .555 .737 r
.51867 .54463 m .51626 .54768 L .51868 .54698 L F
.621 .525 .724 r
.51626 .54768 m .52 .55085 L .51868 .54698 L F
.51626 .54768 m .51738 .55152 L .52 .55085 L F
0 0 0 r
.30573 .65445 m .30854 .65088 L .30803 .6534 L F
0 0 .35 r
.30979 .6498 m .30854 .65088 L .31004 .64711 L F
0 0 .241 r
.30803 .6534 m .30854 .65088 L .30979 .6498 L F
.65 .185 .135 r
.37197 .61181 m .37387 .61295 L .36973 .61245 L F
.55 .361 .577 r
.37394 .61014 m .37387 .61295 L .37197 .61181 L F
.37394 .61014 m .37387 .61295 L .37197 .61181 L F
.081 .596 .884 r
.26422 .73748 m .26251 .73735 L .26036 .73642 L F
0 0 0 r
.30373 .65564 m .30573 .65445 L .30803 .6534 L F
.466 .396 .695 r
.37101 .60292 m .3714 .60629 L .36785 .60555 L F
.492 .238 .457 r
.37121 .60876 m .36785 .60555 L .3714 .60629 L F
.509 .159 .308 r
.31327 .64479 m .31523 .64648 L .3126 .64666 L F
.31327 .64479 m .31579 .64467 L .31523 .64648 L F
.569 .318 .496 r
.37189 .55689 m .37459 .5566 L .37476 .55418 L F
.353 .143 .449 r
.37476 .55418 m .37665 .55579 L .37754 .55382 L F
.37476 .55418 m .37459 .5566 L .37665 .55579 L F
.47 .336 .616 r
.32027 .54097 m .31796 .54452 L .31598 .54052 L F
.811 .808 .321 r
.21333 .56825 m .21217 .57264 L .21256 .56961 L F
.811 .682 .722 r
.28945 .59722 m .29088 .60091 L .28702 .60084 L F
.863 .702 .682 r
.29007 .59473 m .29088 .60091 L .28945 .59722 L F
.715 .548 .662 r
.28787 .57583 m .28545 .57588 L .2879 .57278 L F
0 0 0 r
.2879 .57278 m .28545 .57588 L .28793 .57307 L F
.512 .82 1 r
.2879 .57278 m .2884 .57118 L .29028 .57222 L F
0 0 .398 r
.28793 .57307 m .2884 .57118 L .2879 .57278 L F
.502 .374 .638 r
.29059 .5751 m .2879 .57278 L .29028 .57222 L F
.29059 .5751 m .28787 .57583 L .2879 .57278 L F
.475 .802 1 r
.31452 .60254 m .31444 .6041 L .31653 .60351 L F
0 0 .401 r
.31444 .6041 m .31563 .60574 L .31653 .60351 L F
.31444 .6041 m .31455 .60618 L .31563 .60574 L F
.486 .342 .611 r
.31075 .58823 m .31101 .59125 L .31303 .58766 L F
.346 .255 .608 r
.32914 .64131 m .33131 .64334 L .33123 .64074 L F
.32914 .64131 m .32898 .64468 L .33131 .64334 L F
.796 .999 .834 r
.18768 .60188 m .18352 .60032 L .18372 .59949 L F
.18768 .60188 m .18601 .60113 L .18352 .60032 L F
.18768 .60188 m .18545 .60288 L .18601 .60113 L F
0 0 0 r
.18945 .60222 m .18545 .60288 L .18768 .60188 L F
.538 .335 .553 r
.29195 .5915 m .29444 .59109 L .29465 .58838 L F
.255 .419 .833 r
.29558 .58647 m .29465 .58838 L .29571 .58757 L F
.592 .531 .755 r
.29444 .59109 m .29571 .58757 L .29465 .58838 L F
0 0 0 r
.30952 .64156 m .30667 .64307 L .3089 .64316 L F
.266 0 .26 r
.31154 .64079 m .30952 .64156 L .3089 .64316 L F
0 0 0 r
.33215 .52594 m .33104 .52798 L .32966 .52944 L F
.458 .476 .79 r
.33104 .52798 m .33037 .53195 L .32966 .52944 L F
.572 .539 .78 r
.36968 .65261 m .36799 .65588 L .36678 .65376 L F
.36968 .65261 m .37077 .65681 L .36799 .65588 L F
0 0 0 r
.37077 .65681 m .36722 .65953 L .36799 .65588 L F
.589 .063 0 r
.34252 .54068 m .34371 .542 L .34614 .54111 L F
.557 .532 .783 r
.34945 .54398 m .34614 .54111 L .34859 .54104 L F
0 0 0 r
.34371 .542 m .34859 .54104 L .34614 .54111 L F
.221 0 0 r
.27236 .54567 m .27049 .54558 L .26813 .54497 L F
.212 0 0 r
.27488 .54503 m .27051 .54558 L .27236 .54567 L F
.27051 .54558 m .27049 .54558 L .2705 .54558 L F
.27051 .54558 m .27257 .5456 L .27049 .54558 L F
.27488 .54503 m .27257 .5456 L .27051 .54558 L F
.53 .115 .199 r
.27398 .54489 m .27492 .54562 L .27257 .5456 L F
.27492 .54562 m .27507 .54575 L .27257 .5456 L F
.2767 .54353 m .27257 .5456 L .27488 .54503 L F
.2767 .54353 m .27599 .54449 L .27398 .54489 L F
.625 .599 .804 r
.27488 .54503 m .27584 .5477 L .27841 .54735 L F
.53 .115 .199 r
.27599 .54449 m .27507 .54575 L .27398 .54489 L F
.212 0 0 r
.27051 .54558 m .2705 .54558 L .27236 .54567 L F
.743 .687 .797 r
.35722 .64742 m .35261 .64751 L .35523 .64635 L F
.216 .633 .953 r
.35523 .64635 m .35731 .64652 L .35722 .64742 L F
.902 .686 .601 r
.35791 .65022 m .35708 .65088 L .35722 .64742 L F
.216 .633 .953 r
.35523 .64635 m .35731 .64652 L .35722 .64742 L F
.072 .043 .516 r
.3277 .65046 m .32739 .65453 L .32913 .65259 L F
0 0 .528 r
.32867 .65669 m .32913 .65259 L .32739 .65453 L F
.69 .495 .619 r
.52117 .54383 m .52479 .54148 L .52118 .54163 L F
.511 .327 .567 r
.36138 .59739 m .36407 .597 L .364 .59433 L F
.452 .265 .536 r
.3616 .60026 m .36407 .597 L .36138 .59739 L F
.211 .736 .822 r
.27652 .52778 m .28048 .52742 L .27834 .52778 L F
.39 .475 .827 r
.36453 .58474 m .36607 .58836 L .3672 .58661 L F
.429 .334 .646 r
.36574 .59096 m .3672 .58661 L .36607 .58836 L F
.38 .26 .589 r
.31175 .56871 m .31004 .57234 L .31052 .56951 L F
.573 .82 .992 r
.34557 .51575 m .34722 .51704 L .34943 .51619 L F
.34557 .51575 m .34722 .51704 L .34943 .51619 L F
.137 0 .318 r
.23361 .5532 m .23149 .55673 L .23185 .55437 L F
0 0 0 r
.29514 .60504 m .29478 .60408 L .29628 .60295 L F
.29514 .60504 m .29368 .60607 L .29478 .60408 L F
.047 .043 .529 r
.30585 .56625 m .30675 .56206 L .30494 .56379 L F
0 0 .261 r
.35799 .65152 m .35708 .65088 L .35791 .65022 L F
.109 .062 .517 r
.36001 .64623 m .35791 .65022 L .35731 .64652 L F
.36001 .64623 m .36043 .64838 L .35791 .65022 L F
.707 .6 .734 r
.36043 .64838 m .35799 .65152 L .35791 .65022 L F
.518 .311 .539 r
.32908 .54091 m .33163 .53766 L .32923 .53802 L F
.202 .424 .854 r
.28405 .55462 m .28151 .5553 L .28496 .55245 L F
.28405 .55462 m .2836 .55664 L .28151 .5553 L F
.422 0 0 r
.28758 .59141 m .28957 .59226 L .29195 .5915 L F
.518 .275 .486 r
.29195 .5915 m .29411 .59354 L .29444 .59109 L F
0 .138 .68 r
.29277 .59149 m .29411 .59354 L .29195 .5915 L F
.29277 .59149 m .29195 .5915 L .28957 .59226 L F
.094 .2 .684 r
.19873 .60679 m .19977 .60567 L .19546 .60357 L F
.19873 .60679 m .19962 .60644 L .19977 .60567 L F
.596 .375 .551 r
.37555 .63204 m .37918 .63655 L .37871 .63221 L F
.541 .365 .592 r
.37632 .63465 m .37918 .63655 L .37555 .63204 L F
.596 .375 .551 r
.37555 .63204 m .37918 .63655 L .37871 .63221 L F
.541 .365 .592 r
.37632 .63465 m .37918 .63655 L .37555 .63204 L F
.435 .214 .478 r
.38462 .55396 m .3843 .55646 L .38187 .55704 L F
.381 .219 .533 r
.3843 .55646 m .38202 .55995 L .38187 .55704 L F
.061 0 0 r
.2442 .55035 m .24233 .55023 L .24009 .55006 L F
.267 .768 .879 r
.24646 .54998 m .24233 .55023 L .2442 .55035 L F
.31 .031 .318 r
.18849 .56363 m .18981 .56505 L .1905 .56282 L F
.18849 .56363 m .18777 .56585 L .18981 .56505 L F
.711 .564 .687 r
.34742 .62256 m .34861 .62595 L .34476 .62569 L F
.591 .82 .987 r
.34993 .6219 m .34742 .62256 L .34615 .62108 L F
.677 .546 .698 r
.35112 .62561 m .34742 .62256 L .34993 .6219 L F
.35112 .62561 m .34861 .62595 L .34742 .62256 L F
.982 .751 .514 r
.36529 .64698 m .36337 .64853 L .36354 .64402 L F
0 .015 .573 r
.36306 .65043 m .36337 .64853 L .36529 .64698 L F
.698 .732 .876 r
.36787 .64516 m .36529 .64698 L .36354 .64402 L F
.33 .237 .597 r
.39523 .56264 m .39377 .56795 L .39337 .56671 L F
.248 .157 .552 r
.39713 .56445 m .39377 .56795 L .39523 .56264 L F
0 0 .478 r
.39491 .56664 m .39337 .56671 L .39377 .56795 L F
.39491 .56664 m .39382 .56921 L .39337 .56671 L F
.467 .694 .966 r
.22852 .62867 m .22997 .62679 L .22754 .62743 L F
.483 .357 .632 r
.30451 .54446 m .30678 .54389 L .30646 .5412 L F
.471 .325 .601 r
.30451 .54446 m .30703 .54679 L .30678 .54389 L F
.30451 .54446 m .30475 .54757 L .30703 .54679 L F
.042 0 0 r
.23496 .53548 m .23733 .53519 L .23342 .53547 L F
0 0 0 r
.23952 .53388 m .23967 .53379 L .23733 .53519 L F
.614 .953 .913 r
.23952 .53388 m .23733 .53519 L .23496 .53548 L F
0 0 0 r
.23902 .53419 m .23952 .53388 L .23796 .53463 L F
.24037 .53363 m .23952 .53388 L .23902 .53419 L F
.23952 .53388 m .24052 .53328 L .23967 .53379 L F
.676 .521 .667 r
.24789 .74961 m .24489 .74795 L .24556 .75081 L F
.257 .59 .948 r
.29991 .69142 m .29727 .69051 L .29975 .69011 L F
.29727 .69051 m .29991 .69142 L .29909 .69352 L F
.513 .26 .469 r
.29909 .69352 m .29975 .69011 L .29727 .69051 L F
.593 .534 .759 r
.52124 .55493 m .5226 .55019 L .52 .55085 L F
.52124 .55493 m .52377 .55412 L .5226 .55019 L F
.227 .423 .846 r
.35745 .52028 m .3601 .52118 L .35794 .51781 L F
.987 .806 .413 r
.38286 .56454 m .38298 .56835 L .38388 .56642 L F
.537 .496 .758 r
.38388 .56642 m .3856 .5636 L .38286 .5645 L F
.38388 .56642 m .38675 .56594 L .3856 .5636 L F
.519 .169 .314 r
.38298 .56835 m .38675 .56594 L .38388 .56642 L F
.438 .855 .957 r
.23065 .61211 m .22831 .61273 L .22657 .61238 L F
.764 .688 .778 r
.31303 .58766 m .31101 .59125 L .3144 .59141 L F
.718 .565 .681 r
.31101 .59125 m .31453 .59399 L .3144 .59141 L F
.514 .547 .827 r
.31303 .58766 m .3144 .59141 L .31664 .58921 L F
.327 .228 .587 r
.31453 .59399 m .31664 .58921 L .3144 .59141 L F
.514 .832 1 r
.27093 .64395 m .27074 .64201 L .2701 .64046 L F
.27093 .64395 m .27155 .64248 L .27074 .64201 L F
.27093 .64395 m .27304 .64344 L .27155 .64248 L F
.549 .468 .717 r
.39052 .58422 m .39114 .58815 L .38882 .58861 L F
.431 .226 .499 r
.39114 .58815 m .38878 .59101 L .38882 .58861 L F
.419 .16 .412 r
.2721 .65333 m .27291 .65107 L .26987 .65393 L F
.2721 .65333 m .27291 .65107 L .26987 .65393 L F
.33 .798 .926 r
.25465 .62427 m .25868 .6241 L .25645 .62402 L F
.929 .681 .543 r
.32241 .60318 m .32436 .60348 L .32259 .60045 L F
.32241 .60318 m .32436 .60348 L .32259 .60045 L F
.789 .317 0 r
.32465 .60515 m .32436 .60348 L .32241 .60318 L F
.043 .547 .878 r
.32417 .60551 m .32465 .60515 L .32235 .60576 L F
.789 .317 0 r
.32465 .60515 m .32638 .60685 L .32514 .60478 L F
.702 .774 .908 r
.32867 .60571 m .32638 .60685 L .32465 .60515 L F
.789 .317 0 r
.32465 .60515 m .32514 .60478 L .32436 .60348 L F
.702 .774 .908 r
.32867 .60571 m .32465 .60515 L .32716 .60198 L F
.69 .56 .703 r
.32465 .60515 m .32785 .60618 L .32716 .60198 L F
.043 .547 .878 r
.32681 .60516 m .32785 .60618 L .32465 .60515 L F
.32681 .60516 m .32465 .60515 L .32417 .60551 L F
0 .149 .685 r
.2246 .6258 m .22513 .62434 L .22311 .62217 L F
.17 .464 .888 r
.2246 .6258 m .22754 .62743 L .22513 .62434 L F
.763 .77 .265 r
.29819 .59931 m .29787 .60122 L .29891 .59727 L F
0 0 .21 r
.29819 .59931 m .29628 .60295 L .29787 .60122 L F
.678 .514 .656 r
.37435 .68741 m .37114 .68796 L .37116 .68521 L F
.373 .192 .502 r
.31935 .6624 m .31739 .6631 L .3191 .66541 L F
.737 .412 .431 r
.31836 .672 m .3194 .67065 L .31735 .67025 L F
.221 0 .069 r
.32171 .67005 m .3194 .67065 L .31836 .672 L F
.443 .226 .487 r
.3839 .59748 m .38134 .60076 L .38132 .59792 L F
.591 .355 .527 r
.37124 .59769 m .37356 .60014 L .37386 .59744 L F
.37386 .59744 m .37356 .60014 L .37124 .59769 L F
.37386 .59744 m .37356 .60014 L .37124 .59769 L F
0 .49 .734 r
.25318 .55135 m .24862 .55043 L .25064 .55182 L F
.668 .715 .883 r
.30068 .6448 m .29638 .64364 L .29855 .64335 L F
.834 .999 .818 r
.30078 .64296 m .30068 .6448 L .29855 .64335 L F
0 0 0 r
.26308 .62296 m .26303 .62331 L .26527 .62204 L F
.26308 .62296 m .26106 .6244 L .26303 .62331 L F
.077 .28 .766 r
.34943 .51619 m .35129 .52015 L .35172 .51802 L F
.247 0 .005 r
.25857 .54941 m .25652 .54994 L .25952 .54824 L F
.154 0 0 r
.26101 .54859 m .25952 .54824 L .262 .54774 L F
.26101 .54859 m .25857 .54941 L .25952 .54824 L F
.29 .701 .973 r
.35042 .5908 m .35155 .59014 L .34926 .5903 L F
.35107 .59088 m .35317 .59116 L .35155 .59014 L F
.662 .337 .413 r
.35364 .59261 m .35155 .59014 L .35317 .59116 L F
.38 0 0 r
.3539 .59245 m .35364 .59261 L .35334 .59169 L F
0 0 0 r
.35823 .59001 m .35389 .59247 L .35601 .59115 L F
.662 .337 .413 r
.35364 .59261 m .35419 .59277 L .35389 .59247 L F
0 0 0 r
.35389 .59247 m .35364 .59261 L .3539 .59245 L F
.662 .337 .413 r
.35364 .59261 m .35389 .59247 L .35155 .59014 L F
0 0 0 r
.35389 .59247 m .35364 .59261 L .35389 .59247 L F
.35389 .59247 m .3539 .59245 L .35601 .59115 L F
.592 .063 0 r
.35155 .59014 m .35389 .59247 L .35218 .59127 L F
.35389 .59247 m .35398 .59256 L .35388 .59249 L F
.35389 .59247 m .35388 .59249 L .35218 .59127 L F
.579 .576 .814 r
.35386 .59247 m .35419 .59277 L .35364 .59261 L F
.592 .063 0 r
.35398 .59256 m .35419 .59277 L .35403 .59262 L F
.579 .576 .814 r
.35614 .59098 m .35386 .59247 L .35823 .59001 L F
.35386 .59247 m .35364 .59261 L .35389 .59247 L F
.35386 .59247 m .35389 .59247 L .35823 .59001 L F
.592 .063 0 r
.35398 .59256 m .35407 .59268 L .35378 .59247 L F
.35385 .59247 m .35378 .59247 L .35218 .59127 L F
.35398 .59256 m .35378 .59247 L .35385 .59247 L F
.579 .576 .814 r
.35614 .59098 m .35419 .59277 L .35386 .59247 L F
.592 .063 0 r
.35403 .59262 m .35419 .59277 L .35407 .59268 L F
.38 0 0 r
.35601 .59115 m .3539 .59245 L .35317 .59116 L F
.3539 .59245 m .35334 .59169 L .35317 .59116 L F
.592 .063 0 r
.35155 .59014 m .35218 .59127 L .3523 .58898 L F
.35155 .59014 m .3523 .58898 L .35235 .58791 L F
.29 .701 .973 r
.35042 .5908 m .35107 .59088 L .35155 .59014 L F
.474 .825 .997 r
.25958 .74139 m .25988 .7399 L .25732 .74049 L F
.25958 .74139 m .262 .74087 L .25988 .7399 L F
.663 .134 0 r
.29186 .64644 m .29372 .64749 L .28981 .64641 L F
.991 .776 .513 r
.37439 .64138 m .37375 .64426 L .37284 .64293 L F
.833 .808 .827 r
.35944 .54685 m .35717 .54744 L .35884 .54509 L F
.284 .463 .86 r
.35884 .54509 m .36171 .54647 L .35944 .54685 L F
.318 0 .197 r
.36108 .54875 m .35944 .54685 L .36171 .54647 L F
.36108 .54875 m .35876 .54942 L .35944 .54685 L F
0 0 0 r
.18263 .56915 m .18413 .5685 L .18587 .56678 L F
.115 0 0 r
.18413 .5685 m .18777 .56585 L .18587 .56678 L F
.548 .381 .606 r
.3676 .63116 m .36516 .63184 L .36473 .62903 L F
.3676 .63116 m .36516 .63184 L .36473 .62903 L F
.485 .855 .987 r
.40271 .56336 m .40147 .56293 L .40413 .56203 L F
.40147 .56293 m .40191 .56263 L .40413 .56203 L F
.40271 .56336 m .40119 .56283 L .40413 .56203 L F
.537 .424 .672 r
.40413 .56203 m .40067 .56003 L .40269 .55956 L F
.40413 .56203 m .40119 .56283 L .40067 .56003 L F
.485 .855 .987 r
.40147 .56293 m .40119 .56283 L .40191 .56263 L F
.338 0 .051 r
.40255 .56301 m .40119 .56283 L .40413 .56203 L F
.153 .131 .578 r
.40353 .56155 m .40508 .56277 L .40255 .56301 L F
0 .162 .689 r
.40453 .56007 m .40413 .56203 L .40269 .55956 L F
.153 .131 .578 r
.40453 .56007 m .40255 .56301 L .40413 .56203 L F
.40453 .56007 m .40468 .56079 L .40353 .56155 L F
.40468 .56079 m .40508 .56277 L .40353 .56155 L F
.628 .57 .77 r
.28481 .59413 m .28677 .59791 L .28569 .59416 L F
.98 .697 .321 r
.28677 .59791 m .28596 .59953 L .28642 .59509 L F
.28677 .59791 m .28702 .60084 L .28596 .59953 L F
.617 .464 .651 r
.28945 .59458 m .28945 .59722 L .28677 .59791 L F
.811 .682 .722 r
.28945 .59722 m .28702 .60084 L .28677 .59791 L F
.366 .798 .622 r
.35136 .66577 m .35085 .66609 L .35238 .66519 L F
.073 0 0 r
.35439 .66477 m .35136 .66577 L .35238 .66519 L F
.5 .091 .197 r
.35439 .66477 m .35345 .66704 L .35136 .66577 L F
0 .259 .761 r
.35136 .66577 m .35345 .66704 L .35202 .66536 L F
.35136 .66577 m .35202 .66536 L .35139 .66463 L F
.366 .798 .622 r
.35136 .66577 m .35045 .66632 L .35085 .66609 L F
.333 .815 .796 r
.34922 .66648 m .35045 .66632 L .35136 .66577 L F
.399 .039 .234 r
.26954 .55367 m .27168 .55365 L .27325 .55063 L F
.519 .319 .55 r
.27325 .55063 m .27572 .55013 L .27584 .5477 L F
.476 .136 .309 r
.27168 .55365 m .27572 .55013 L .27325 .55063 L F
.947 .936 .75 r
.33155 .52277 m .32997 .52307 L .32999 .52414 L F
.33155 .52277 m .32999 .52414 L .33017 .5215 L F
.486 .797 .999 r
.33017 .5215 m .3346 .52225 L .33155 .52277 L F
.963 .644 .251 r
.33072 .52383 m .33215 .52594 L .33155 .52277 L F
.33072 .52383 m .33155 .52277 L .3346 .52225 L F
.715 .679 .814 r
.36712 .68308 m .36337 .68218 L .36576 .68143 L F
.617 .745 .937 r
.36943 .68205 m .36712 .68308 L .36576 .68143 L F
0 0 0 r
.28526 .54302 m .28556 .54288 L .28751 .54154 L F
.28482 .54332 m .28556 .54288 L .28526 .54302 L F
0 0 .077 r
.28556 .54288 m .28612 .54402 L .28595 .54269 L F
.559 .058 .02 r
.28751 .54154 m .28556 .54288 L .28342 .54148 L F
0 0 .077 r
.28556 .54288 m .28595 .54269 L .28577 .54138 L F
.304 0 0 r
.36564 .58402 m .36214 .58458 L .36453 .58474 L F
0 .039 .592 r
.35251 .56557 m .35082 .56344 L .35339 .56294 L F
.978 .784 .573 r
.32678 .5877 m .32458 .58687 L .32652 .58522 L F
.978 .788 .58 r
.32678 .5877 m .32428 .58982 L .32458 .58687 L F
.424 0 .014 r
.32799 .58915 m .32678 .5877 L .32907 .58776 L F
.32799 .58915 m .32428 .58982 L .32678 .5877 L F
.444 .273 .553 r
.32898 .64468 m .33122 .64682 L .33131 .64334 L F
.32898 .64468 m .32919 .64715 L .33122 .64682 L F
0 0 0 r
.24037 .53363 m .24052 .53328 L .23952 .53388 L F
.24037 .53363 m .24228 .53272 L .24052 .53328 L F
.23836 .55018 m .23806 .55003 L .24009 .55006 L F
.23836 .55018 m .23525 .55223 L .23806 .55003 L F
.111 0 0 r
.21002 .57341 m .20956 .5723 L .21217 .57264 L F
.21002 .57341 m .2075 .57412 L .20956 .5723 L F
.286 .365 .77 r
.36994 .5626 m .37145 .56649 L .3725 .56452 L F
.36994 .5626 m .3725 .56452 L .37233 .56418 L F
.404 .375 .713 r
.36994 .5626 m .37181 .56211 L .36926 .56039 L F
.286 .365 .77 r
.36994 .5626 m .37259 .56436 L .37181 .56211 L F
.35 0 .155 r
.37126 .56207 m .36808 .56508 L .3677 .5618 L F
.37181 .56211 m .37143 .56241 L .37126 .56207 L F
.37143 .56241 m .36808 .56508 L .37126 .56207 L F
.286 .365 .77 r
.37233 .56418 m .3725 .56452 L .37259 .56436 L F
.136 .176 .64 r
.37145 .56649 m .37316 .5684 L .37259 .56436 L F
.404 .225 .523 r
.37145 .56649 m .37103 .56917 L .37316 .5684 L F
.06 0 .079 r
.32581 .56937 m .3277 .56883 L .32861 .56643 L F
.228 0 .151 r
.32861 .56643 m .32965 .56802 L .33046 .56542 L F
.32861 .56643 m .3277 .56883 L .32965 .56802 L F
.26 0 .202 r
.32476 .57121 m .3277 .56883 L .32581 .56937 L F
.002 0 0 r
.2134 .54478 m .21362 .54559 L .21565 .5442 L F
.2134 .54478 m .21145 .54631 L .21362 .54559 L F
.914 .972 .787 r
.33297 .57761 m .33597 .57479 L .33434 .57638 L F
.785 .537 0 r
.39539 .54658 m .39577 .54808 L .39498 .54408 L F
.119 .391 .846 r
.3966 .54654 m .39577 .54808 L .39539 .54658 L F
.3966 .54654 m .39864 .54974 L .39577 .54808 L F
.573 .847 .507 r
.33531 .58206 m .33354 .58396 L .33266 .5851 L F
.587 .929 .733 r
.33354 .58396 m .33073 .58606 L .33266 .5851 L F
.676 .521 .667 r
.24789 .74961 m .24936 .74784 L .24489 .74795 L F
.06 0 .243 r
.33697 .58094 m .33531 .58206 L .33746 .57865 L F
.136 0 0 r
.3358 .58322 m .33531 .58206 L .33697 .58094 L F
.438 0 0 r
.3358 .58322 m .33862 .58335 L .33779 .58422 L F
.524 0 0 r
.33779 .58422 m .33674 .58369 L .3358 .58322 L F
.136 0 0 r
.3358 .58322 m .33472 .58269 L .33531 .58206 L F
.524 0 0 r
.33674 .58369 m .33377 .5822 L .3358 .58322 L F
.136 0 0 r
.3358 .58322 m .33354 .58396 L .33472 .58269 L F
.095 0 0 r
.34055 .57614 m .33935 .57791 L .33746 .57865 L F
.263 0 .125 r
.34273 .57535 m .33935 .57791 L .34055 .57614 L F
.148 0 .409 r
.18048 .57268 m .18156 .57445 L .18185 .57177 L F
.18048 .57268 m .18021 .57528 L .18156 .57445 L F
.566 .326 .512 r
.38684 .55603 m .38462 .55396 L .38716 .55365 L F
.38684 .55603 m .3843 .55646 L .38462 .55396 L F
.263 .306 .719 r
.38462 .55396 m .38684 .55603 L .38716 .55365 L F
.489 .329 .59 r
.31735 .67025 m .31612 .67266 L .31836 .672 L F
.31735 .67025 m .31612 .67266 L .31836 .672 L F
.557 .712 .944 r
.18945 .60222 m .19389 .60366 L .19326 .6024 L F
.282 .639 .965 r
.19389 .60366 m .19406 .60224 L .19326 .6024 L F
.19389 .60366 m .19546 .60357 L .19406 .60224 L F
.478 .394 .682 r
.36537 .61842 m .36354 .62296 L .36273 .61901 L F
.36537 .61842 m .36585 .62234 L .36354 .62296 L F
.494 .45 .738 r
.36585 .62234 m .36648 .62501 L .36354 .62296 L F
.639 .451 .613 r
.36564 .58402 m .36801 .58194 L .36702 .57901 L F
.351 .324 .688 r
.36671 .57534 m .36702 .57901 L .36858 .578 L F
.015 .083 .59 r
.36702 .57901 m .36914 .58006 L .36858 .578 L F
.36702 .57901 m .36801 .58194 L .36914 .58006 L F
.472 .23 .466 r
.35112 .62561 m .34819 .62901 L .34861 .62595 L F
.451 .146 .356 r
.24363 .75253 m .24193 .75061 L .24123 .75309 L F
.24123 .75309 m .24193 .75061 L .24363 .75253 L F
.313 .075 .383 r
.3789 .57287 m .37841 .57516 L .38091 .57199 L F
.38091 .57199 m .37841 .57516 L .3789 .57287 L F
.627 .412 .57 r
.27044 .62817 m .2731 .62854 L .27327 .62568 L F
.532 .701 .947 r
.27404 .62344 m .27327 .62568 L .27538 .62501 L F
.784 .96 .924 r
.27404 .62344 m .2717 .62516 L .27327 .62568 L F
.41 .232 .526 r
.27327 .62568 m .2731 .62854 L .27538 .62501 L F
.503 .741 .98 r
.33735 .5676 m .33936 .5692 L .34006 .56755 L F
.536 .489 .75 r
.33855 .57121 m .34006 .56755 L .33936 .5692 L F
.429 .106 .314 r
.39883 .55929 m .39737 .5624 L .39523 .56264 L F
.487 .249 .479 r
.40113 .55718 m .40067 .56003 L .39883 .55929 L F
.747 .565 .648 r
.40067 .56003 m .39737 .5624 L .39883 .55929 L F
.338 .102 .402 r
.39137 .57272 m .39119 .5751 L .38918 .57524 L F
.072 .043 .516 r
.3277 .65046 m .32913 .65259 L .32921 .64984 L F
.642 .489 .66 r
.28548 .59098 m .28569 .59416 L .28758 .59141 L F
.498 .829 .999 r
.3265 .54992 m .32841 .55083 L .32441 .55053 L F
.587 .376 .562 r
.27572 .55013 m .27841 .54735 L .27584 .5477 L F
.363 .468 .833 r
.20813 .59003 m .20816 .59389 L .20586 .59058 L F
.20813 .59003 m .20972 .59358 L .20816 .59389 L F
.175 .188 .633 r
.31312 .61309 m .31362 .61695 L .31493 .61511 L F
.497 .04 .097 r
.29132 .58126 m .29504 .58127 L .2953 .58021 L F
.797 .779 .275 r
.29916 .595 m .29819 .59931 L .29891 .59727 L F
.376 0 .11 r
.33756 .66872 m .33923 .67005 L .33605 .67034 L F
.33756 .66872 m .3399 .66843 L .33923 .67005 L F
.141 0 0 r
.3399 .66843 m .34235 .66817 L .33967 .66926 L F
0 0 .395 r
.34011 .67217 m .34072 .67025 L .34167 .67044 L F
.828 .994 .857 r
.34149 .67043 m .34011 .67217 L .34318 .66876 L F
.703 .616 .756 r
.34512 .66995 m .34657 .67281 L .34149 .67043 L F
.34512 .66995 m .34149 .67043 L .34318 .66876 L F
.656 .627 .809 r
.34398 .67506 m .34011 .67217 L .34149 .67043 L F
.667 .635 .808 r
.34657 .67281 m .34398 .67506 L .34149 .67043 L F
.656 .627 .809 r
.34398 .67506 m .34191 .67617 L .34011 .67217 L F
.205 0 .125 r
.34346 .67054 m .34045 .67286 L .3417 .67231 L F
.777 .939 .591 r
.34236 .67133 m .34346 .67054 L .3417 .67231 L F
.699 .174 0 r
.34346 .67054 m .34458 .66974 L .34277 .66903 L F
.34346 .67054 m .34277 .66903 L .34239 .66952 L F
0 0 0 r
.34295 .66879 m .34413 .66747 L .34318 .66876 L F
.33999 .66921 m .3439 .66757 L .34295 .66879 L F
.3439 .66757 m .34413 .66747 L .34295 .66879 L F
.33988 .66918 m .34413 .66747 L .33999 .66921 L F
.33967 .66926 m .33988 .66918 L .33999 .66921 L F
.094 .205 .689 r
.34129 .66845 m .33967 .66926 L .34318 .66876 L F
0 0 .395 r
.34167 .67044 m .34129 .66845 L .34318 .66876 L F
0 0 0 r
.34318 .66876 m .34564 .66633 L .34512 .66995 L F
.817 .61 .623 r
.34129 .66845 m .34512 .66995 L .34564 .66633 L F
.34129 .66845 m .34564 .66633 L .34504 .66991 L F
.249 .557 .933 r
.34129 .66845 m .34504 .66991 L .34212 .66722 L F
.699 .174 0 r
.34346 .67054 m .34201 .66914 L .34136 .6714 L F
.34201 .66914 m .34129 .66845 L .34131 .66939 L F
0 0 .395 r
.34123 .67036 m .34129 .66845 L .34167 .67044 L F
.094 .205 .689 r
.34129 .66845 m .34123 .67033 L .33967 .66926 L F
0 0 .395 r
.34072 .67025 m .34129 .66845 L .34123 .67036 L F
.094 .205 .689 r
.34129 .66845 m .34148 .6705 L .34123 .67033 L F
.753 .733 .833 r
.34086 .67013 m .34148 .6705 L .34129 .66845 L F
.452 0 0 r
.34067 .67022 m .34007 .66955 L .34128 .67037 L F
.33946 .66992 m .33996 .66962 L .34067 .67022 L F
.33996 .66962 m .34007 .66955 L .34067 .67022 L F
0 0 .395 r
.34086 .67037 m .34132 .66966 L .34117 .66961 L F
.34011 .67217 m .34094 .67044 L .34086 .67037 L F
.34094 .67044 m .34132 .66966 L .34086 .67037 L F
.34064 .6705 m .34117 .66961 L .34094 .66953 L F
.452 0 0 r
.33946 .66992 m .34067 .67022 L .34043 .6702 L F
.34067 .67022 m .34128 .67037 L .34072 .67025 L F
.34067 .67022 m .34072 .67025 L .34043 .6702 L F
0 0 .395 r
.34011 .67217 m .34086 .67037 L .34064 .6705 L F
.34086 .67037 m .34117 .66961 L .34076 .67029 L F
.34086 .67037 m .34076 .67029 L .34064 .6705 L F
.452 0 0 r
.33963 .66997 m .34076 .67029 L .34023 .66976 L F
.34076 .67029 m .34128 .67037 L .34148 .6705 L F
.34043 .6702 m .34072 .67025 L .34076 .67029 L F
.34072 .67025 m .34128 .67037 L .34076 .67029 L F
0 0 .395 r
.3406 .67115 m .34136 .6714 L .34134 .67079 L F
.452 0 0 r
.34076 .67029 m .34148 .6705 L .34086 .67013 L F
0 0 .395 r
.34094 .67044 m .34134 .67079 L .34132 .66966 L F
.3406 .67115 m .34134 .67079 L .34094 .67044 L F
.452 0 0 r
.34076 .67029 m .34086 .67013 L .34023 .66976 L F
.141 0 0 r
.3399 .66843 m .33967 .66926 L .33959 .6694 L F
.33972 .6689 m .33959 .6694 L .33937 .6698 L F
.3399 .66843 m .33959 .6694 L .33972 .6689 L F
.3399 .66843 m .33937 .6698 L .33926 .66998 L F
.364 .676 .976 r
.34007 .66955 m .33923 .67005 L .33967 .66926 L F
.416 .819 .981 r
.33605 .67034 m .34007 .66955 L .33942 .66955 L F
.141 0 0 r
.33926 .66998 m .33937 .6698 L .33923 .67005 L F
.416 .819 .981 r
.33605 .67034 m .33923 .67005 L .34007 .66955 L F
.364 .676 .976 r
.34007 .66955 m .33967 .66926 L .34148 .6705 L F
.753 .733 .833 r
.33725 .66799 m .34086 .67013 L .34129 .66845 L F
0 0 .395 r
.34011 .67217 m .34038 .672 L .3406 .67115 L F
.34038 .672 m .34136 .6714 L .3406 .67115 L F
.699 .174 0 r
.34201 .66914 m .34131 .66939 L .34136 .6714 L F
.232 0 0 r
.33117 .67027 m .33493 .66901 L .33369 .67045 L F
.358 0 0 r
.33493 .66901 m .33605 .67034 L .33337 .67083 L F
.33493 .66901 m .33756 .66872 L .33605 .67034 L F
.355 .789 .967 r
.33408 .66956 m .33952 .66955 L .33496 .66861 L F
.33952 .66955 m .33958 .66946 L .33496 .66861 L F
.416 .819 .981 r
.33558 .67015 m .33942 .66955 L .33408 .66956 L F
.33605 .67034 m .33942 .66955 L .33558 .67015 L F
.452 0 0 r
.33496 .66861 m .33958 .66946 L .33946 .66992 L F
.33496 .66861 m .33963 .66997 L .33725 .66799 L F
.355 .789 .967 r
.33952 .66955 m .34007 .66955 L .33958 .66946 L F
.452 0 0 r
.33958 .66946 m .34007 .66955 L .33946 .66992 L F
.33937 .66975 m .33971 .66945 L .33725 .66799 L F
.709 .285 .239 r
.33725 .66799 m .34129 .66845 L .33896 .6694 L F
.611 .954 .826 r
.33896 .6694 m .34043 .6688 L .34212 .66722 L F
.34043 .6688 m .34129 .66845 L .34203 .66736 L F
.34043 .6688 m .34203 .66736 L .34212 .66722 L F
.452 0 0 r
.33963 .66997 m .34023 .66976 L .33971 .66945 L F
.33963 .66997 m .33971 .66945 L .33937 .66975 L F
.205 0 .125 r
.34346 .67054 m .34136 .6714 L .34045 .67286 L F
.821 .568 .014 r
.34451 .66943 m .34423 .6668 L .34212 .66722 L F
.34504 .66991 m .34484 .66916 L .34451 .66943 L F
.34484 .66916 m .34423 .6668 L .34451 .66943 L F
.841 .722 .733 r
.34564 .66633 m .34856 .66996 L .34958 .66475 L F
.34564 .66633 m .34958 .66475 L .34757 .66549 L F
0 .259 .761 r
.35136 .66577 m .35139 .66463 L .34958 .66475 L F
.083 0 0 r
.34757 .66549 m .34958 .66475 L .35139 .66463 L F
.34757 .66549 m .35118 .66467 L .35013 .66493 L F
.35118 .66467 m .35139 .66463 L .35013 .66493 L F
.17 0 0 r
.34936 .66512 m .35013 .66493 L .35159 .66517 L F
.206 .732 .758 r
.34757 .66549 m .35013 .66493 L .34877 .66511 L F
.17 0 0 r
.34877 .66511 m .35013 .66493 L .34936 .66512 L F
.206 .732 .758 r
.34757 .66549 m .34877 .66511 L .34581 .66839 L F
.206 0 .242 r
.34504 .66991 m .34564 .66633 L .34757 .66549 L F
.821 .568 .014 r
.34434 .66723 m .34456 .66829 L .34423 .6668 L F
.206 0 .242 r
.34504 .66991 m .34757 .66549 L .3449 .66936 L F
.821 .568 .014 r
.34504 .66991 m .34483 .66952 L .34434 .66723 L F
.206 0 .242 r
.34504 .66991 m .3449 .66936 L .34485 .66955 L F
.644 .619 .81 r
.34666 .66972 m .34496 .67015 L .34483 .66952 L F
.34485 .66873 m .34483 .66952 L .34463 .6686 L F
.34492 .66925 m .34483 .66952 L .34485 .66873 L F
.828 .748 .775 r
.34423 .6668 m .34485 .66873 L .34459 .66667 L F
.206 .732 .758 r
.34757 .66549 m .34581 .66839 L .34528 .66881 L F
.828 .748 .775 r
.34459 .66667 m .34485 .66873 L .34877 .66511 L F
.34485 .66873 m .34494 .66936 L .34503 .66926 L F
.206 .732 .758 r
.34528 .66881 m .34581 .66839 L .34481 .66949 L F
.828 .748 .775 r
.34485 .66873 m .34503 .66926 L .34877 .66511 L F
.644 .619 .81 r
.34507 .66884 m .34485 .66873 L .3453 .66809 L F
.34485 .66873 m .34463 .6686 L .34478 .66849 L F
.34485 .66873 m .34478 .66849 L .3453 .66809 L F
.3453 .66809 m .34478 .66849 L .34423 .6668 L F
.34478 .66849 m .34463 .6686 L .34423 .6668 L F
.828 .748 .775 r
.34423 .6668 m .34494 .66936 L .34485 .66873 L F
.644 .619 .81 r
.34463 .6686 m .34212 .66722 L .34423 .6668 L F
.821 .568 .014 r
.34456 .66829 m .34481 .66949 L .34423 .6668 L F
.699 .174 0 r
.34346 .67054 m .34512 .66995 L .34458 .66974 L F
.644 .619 .81 r
.34496 .67015 m .34346 .67054 L .34463 .6686 L F
.821 .568 .014 r
.34483 .66952 m .34481 .66949 L .34434 .66723 L F
.828 .748 .775 r
.34423 .6668 m .34481 .66949 L .34494 .66936 L F
.644 .619 .81 r
.34507 .66884 m .34492 .66925 L .34485 .66873 L F
.206 0 .242 r
.34485 .66955 m .3449 .66936 L .34486 .66943 L F
.34485 .66955 m .34486 .66943 L .34483 .66952 L F
.644 .619 .81 r
.34666 .66972 m .34483 .66952 L .34507 .66884 L F
.206 0 .242 r
.34483 .66952 m .34486 .66943 L .34481 .66949 L F
.644 .619 .81 r
.34666 .66972 m .34507 .66884 L .3453 .66809 L F
.34463 .6686 m .34346 .67054 L .34212 .66722 L F
.035 .229 .732 r
.34212 .66722 m .34346 .67054 L .34409 .66872 L F
.777 .939 .591 r
.34409 .66872 m .34346 .67054 L .34236 .67133 L F
.699 .174 0 r
.34239 .66952 m .34277 .66903 L .34129 .66845 L F
0 0 .395 r
.34094 .66953 m .34132 .66966 L .34129 .66845 L F
.232 0 0 r
.33257 .67063 m .33369 .67045 L .33337 .67083 L F
.33117 .67027 m .33369 .67045 L .33257 .67063 L F
.291 0 .274 r
.30675 .56206 m .3093 .55954 L .30742 .55975 L F
0 0 0 r
.24614 .53225 m .24628 .53188 L .24396 .53289 L F
.24614 .53225 m .24866 .53149 L .24628 .53188 L F
.758 .658 .751 r
.5302 .54083 m .53235 .54373 L .53375 .54141 L F
.477 0 0 r
.32686 .66125 m .32618 .66035 L .32429 .66165 L F
.32686 .66125 m .32757 .66143 L .32618 .66035 L F
.532 .371 .608 r
.32618 .66035 m .32911 .65977 L .32867 .65669 L F
.346 0 .121 r
.32618 .66035 m .32757 .66143 L .32911 .65977 L F
.245 0 0 r
.30655 .62908 m .3047 .6306 L .30227 .63091 L F
.365 .169 .476 r
.30871 .62568 m .30655 .62908 L .30893 .62745 L F
0 0 0 r
.30683 .62981 m .30655 .62908 L .30893 .62745 L F
.30683 .62981 m .3047 .6306 L .30655 .62908 L F
.365 .169 .476 r
.30871 .62568 m .30655 .62908 L .30893 .62745 L F
0 .004 .547 r
.40201 .55558 m .40113 .55718 L .4006 .55321 L F
.509 .472 .752 r
.40201 .55558 m .40067 .56003 L .40113 .55718 L F
0 .097 .652 r
.31312 .61309 m .31493 .61511 L .31384 .61343 L F
.395 .234 .541 r
.36407 .597 m .36607 .59374 L .364 .59433 L F
.603 .123 0 r
.23889 .63179 m .23907 .63228 L .23747 .6306 L F
.435 .787 .997 r
.23907 .63228 m .24136 .63203 L .23738 .63052 L F
.103 .658 .767 r
.23747 .6306 m .23291 .63084 L .23413 .62983 L F
.382 .676 .975 r
.23607 .63057 m .23623 .63055 L .23436 .62949 L F
.23434 .62952 m .23436 .62949 L .23341 .62895 L F
.23607 .63057 m .23436 .62949 L .23434 .62952 L F
.2335 .63079 m .23357 .63078 L .23393 .62927 L F
.23357 .63078 m .23607 .63057 L .23438 .62954 L F
.23357 .63078 m .23438 .62954 L .23393 .62927 L F
.701 .161 0 r
.23747 .6306 m .23623 .63055 L .23595 .63038 L F
.382 .676 .975 r
.23595 .63038 m .23709 .63048 L .23381 .62912 L F
0 .552 .742 r
.23595 .63038 m .23709 .63048 L .23747 .6306 L F
.382 .676 .975 r
.23623 .63055 m .23709 .63048 L .23595 .63038 L F
0 .552 .742 r
.23562 .63033 m .23709 .63048 L .23595 .63038 L F
.382 .676 .975 r
.23623 .63055 m .23381 .62912 L .23341 .62895 L F
.725 .648 .771 r
.23436 .62955 m .23709 .63048 L .23562 .63033 L F
.144 .41 .855 r
.23427 .62956 m .23425 .62953 L .23393 .62927 L F
.382 .676 .975 r
.2335 .63079 m .23393 .62927 L .23341 .62895 L F
.144 .41 .855 r
.23426 .62971 m .23393 .62927 L .23341 .62895 L F
0 0 .061 r
.23411 .62972 m .2341 .62975 L .23341 .62895 L F
.2341 .62975 m .23401 .63032 L .23379 .62981 L F
.2341 .62975 m .23379 .62981 L .23341 .62895 L F
0 0 0 r
.23413 .62975 m .23425 .62973 L .23426 .62971 L F
.144 .41 .855 r
.23426 .62971 m .23427 .62956 L .23393 .62927 L F
0 0 0 r
.23434 .62959 m .23432 .62963 L .23426 .62971 L F
0 0 .061 r
.23432 .62963 m .23401 .63032 L .23406 .63 L F
0 0 0 r
.23413 .62975 m .23426 .62971 L .23341 .62895 L F
0 0 .061 r
.23432 .62962 m .23406 .63 L .23416 .62942 L F
.23436 .62955 m .23432 .62963 L .23416 .62942 L F
.725 .648 .771 r
.23416 .62942 m .23444 .62938 L .23436 .62955 L F
.144 .41 .855 r
.23426 .62971 m .23515 .62835 L .23434 .62779 L F
.603 .822 .427 r
.23426 .62971 m .23425 .62973 L .23432 .62962 L F
0 0 .061 r
.23432 .62963 m .23406 .63 L .23432 .62962 L F
.382 .676 .975 r
.23291 .63084 m .2335 .63079 L .23341 .62895 L F
.103 .658 .767 r
.23747 .6306 m .23623 .63055 L .23563 .6306 L F
.23487 .63074 m .23563 .6306 L .23291 .63084 L F
.23747 .6306 m .23563 .6306 L .23487 .63074 L F
.701 .161 0 r
.23595 .63038 m .23599 .63054 L .23562 .63033 L F
.23623 .63055 m .23599 .63054 L .23595 .63038 L F
.435 .787 .997 r
.23599 .63054 m .23671 .63027 L .23562 .63033 L F
.103 .658 .767 r
.23747 .6306 m .23709 .63048 L .23623 .63055 L F
.701 .161 0 r
.23747 .6306 m .23907 .63228 L .23599 .63054 L F
.435 .787 .997 r
.23907 .63228 m .23685 .63039 L .23599 .63054 L F
.23685 .63039 m .23671 .63027 L .23599 .63054 L F
.74 .746 .857 r
.22997 .62679 m .2325 .62789 L .2315 .62678 L F
.971 .689 .278 r
.2325 .62789 m .23291 .63084 L .2315 .62678 L F
0 .132 .671 r
.2315 .62678 m .23254 .62978 L .23341 .62895 L F
.23254 .62978 m .23291 .63084 L .23318 .62981 L F
.23254 .62978 m .23318 .62981 L .23341 .62895 L F
.784 .704 .775 r
.23476 .63204 m .23091 .63213 L .23252 .63008 L F
.23379 .62981 m .23252 .63008 L .23341 .62895 L F
.23476 .63204 m .23252 .63008 L .23379 .62981 L F
.76 .958 .653 r
.23341 .62895 m .23091 .63213 L .23146 .63057 L F
0 0 0 r
.23146 .63057 m .2338 .63024 L .23415 .62984 L F
.2339 .62983 m .23415 .62984 L .23425 .62973 L F
.23146 .63057 m .23415 .62984 L .2339 .62983 L F
0 .358 .83 r
.23115 .62558 m .23515 .62835 L .23153 .62454 L F
0 0 0 r
.23572 .62749 m .23523 .62841 L .23433 .62962 L F
0 .358 .83 r
.23515 .62835 m .23523 .62841 L .23516 .62833 L F
.23515 .62835 m .23516 .62833 L .23153 .62454 L F
.459 .606 .909 r
.23153 .62454 m .23516 .62833 L .23593 .62718 L F
.603 .822 .427 r
.23426 .62971 m .23555 .62772 L .23591 .62721 L F
.23572 .62749 m .23591 .62721 L .23593 .62718 L F
.23426 .62971 m .23591 .62721 L .23572 .62749 L F
0 0 0 r
.23593 .62718 m .23589 .62725 L .23572 .62749 L F
.23589 .62725 m .23523 .62841 L .23572 .62749 L F
.459 .606 .909 r
.23516 .62833 m .23523 .62841 L .23593 .62718 L F
.603 .822 .427 r
.23498 .6286 m .2338 .63024 L .2354 .62794 L F
.23432 .62962 m .23418 .62979 L .23498 .6286 L F
.23418 .62979 m .2338 .63024 L .23498 .6286 L F
.23515 .62835 m .2354 .62794 L .23555 .62772 L F
.23432 .62962 m .2354 .62794 L .23515 .62835 L F
.23425 .62973 m .2338 .63024 L .23432 .62962 L F
0 0 0 r
.23146 .63057 m .23425 .62973 L .23413 .62975 L F
.23146 .63057 m .23413 .62975 L .23341 .62895 L F
0 0 .061 r
.23416 .62942 m .23411 .62972 L .23341 .62895 L F
.144 .41 .855 r
.23427 .62956 m .23427 .62955 L .23425 .62953 L F
.725 .648 .771 r
.23396 .62918 m .23444 .62938 L .23416 .62942 L F
.144 .41 .855 r
.23427 .62955 m .23434 .62779 L .23396 .62918 L F
.23427 .62955 m .23396 .62918 L .23393 .62927 L F
.23393 .62927 m .23115 .62558 L .23341 .62895 L F
.725 .648 .771 r
.23341 .62895 m .23396 .62918 L .23416 .62942 L F
.23444 .62938 m .23709 .63048 L .23436 .62955 L F
0 0 .061 r
.23562 .63033 m .23401 .63032 L .23436 .62955 L F
0 0 0 r
.23433 .62962 m .23433 .62962 L .23432 .62963 L F
.23572 .62749 m .23433 .62962 L .23433 .62962 L F
.23572 .62749 m .23432 .62963 L .23434 .62959 L F
0 0 .061 r
.23562 .63033 m .23476 .63204 L .23401 .63032 L F
.144 .41 .855 r
.23426 .62971 m .23523 .62841 L .23515 .62835 L F
.23393 .62927 m .23434 .62779 L .23115 .62558 L F
.435 .787 .997 r
.23907 .63228 m .23738 .63052 L .23671 .63027 L F
.603 .123 0 r
.23889 .63179 m .2401 .63334 L .23907 .63228 L F
.2401 .63334 m .2408 .63424 L .23907 .63228 L F
.832 .463 0 r
.29196 .58235 m .29283 .58475 L .29132 .58126 L F
.836 .402 .201 r
.29795 .64896 m .29865 .64992 L .29607 .64935 L F
.116 .518 .911 r
.18352 .60032 m .18355 .60004 L .18372 .59949 L F
.321 0 0 r
.18402 .59856 m .18372 .59949 L .1816 .59979 L F
0 0 .53 r
.18372 .59949 m .18369 .59836 L .18211 .59622 L F
.116 .518 .911 r
.18355 .60004 m .18369 .59836 L .18372 .59949 L F
.321 0 0 r
.18602 .59754 m .18372 .59949 L .18402 .59856 L F
.708 .77 .901 r
.35364 .51671 m .34943 .51619 L .35191 .51547 L F
.293 .428 .827 r
.35378 .51351 m .35364 .51671 L .35191 .51547 L F
.35378 .51351 m .35664 .51663 L .35364 .51671 L F
.696 .606 .752 r
.36449 .53808 m .36581 .54176 L .36834 .53913 L F
.353 .297 .655 r
.38857 .59371 m .38626 .5917 L .38878 .59101 L F
.38857 .59371 m .38656 .59441 L .38626 .5917 L F
.251 .723 .941 r
.30455 .52593 m .30811 .52607 L .31038 .52698 L F
.181 .709 .852 r
.30811 .52607 m .31282 .52622 L .31038 .52698 L F
.439 .349 .658 r
.31798 .54777 m .32039 .54984 L .32044 .5472 L F
.31798 .54777 m .31836 .55087 L .32039 .54984 L F
.7 .531 .655 r
.29007 .59473 m .28945 .59722 L .28945 .59458 L F
.171 0 0 r
.28879 .55095 m .28496 .55245 L .28637 .55164 L F
.26 .631 .962 r
.25879 .63601 m .26027 .63524 L .25757 .63505 L F
.25879 .63601 m .26162 .63642 L .26027 .63524 L F
.647 .3 .37 r
.33742 .56 m .3407 .56189 L .33995 .56008 L F
.33742 .56 m .33592 .56231 L .3407 .56189 L F
.031 .592 .803 r
.32251 .66961 m .32503 .67008 L .32645 .66999 L F
.634 .686 .882 r
.32307 .52614 m .31917 .52495 L .32165 .52437 L F
.699 .724 .87 r
.32536 .52477 m .32307 .52614 L .32165 .52437 L F
0 0 .113 r
.22822 .78685 m .22809 .78523 L .22681 .7877 L F
.584 .374 .561 r
.28787 .57583 m .28527 .579 L .28545 .57588 L F
.28787 .57583 m .28789 .57874 L .28527 .579 L F
.612 .543 .752 r
.28527 .579 m .28675 .57885 L .28793 .57307 L F
.28675 .57885 m .28789 .57874 L .28789 .57818 L F
.419 .244 .535 r
.29047 .57667 m .28787 .57583 L .29059 .5751 L F
.28957 .5772 m .28787 .57583 L .29047 .57667 L F
.29038 .57786 m .28789 .57874 L .28787 .57583 L F
.612 .543 .752 r
.28675 .57885 m .28789 .57818 L .28793 .57307 L F
.419 .244 .535 r
.29038 .57786 m .28957 .5772 L .29047 .57667 L F
.677 .405 .502 r
.31694 .55855 m .31953 .55991 L .31989 .55686 L F
.678 .619 .782 r
.31989 .55686 m .32156 .55364 L .31934 .55306 L F
.31989 .55686 m .32366 .55786 L .32156 .55364 L F
.656 .386 .499 r
.31989 .55686 m .32221 .55908 L .32366 .55786 L F
.31989 .55686 m .31953 .55991 L .32221 .55908 L F
.059 .282 .772 r
.37512 .52044 m .37487 .52252 L .37344 .5203 L F
.146 .376 .829 r
.37611 .52258 m .37487 .52252 L .37512 .52044 L F
.532 .534 .802 r
.37775 .52529 m .37487 .52252 L .37611 .52258 L F
.975 .771 .564 r
.3825 .5442 m .38052 .54312 L .38104 .54068 L F
.569 .351 .544 r
.38297 .54536 m .38052 .54312 L .3825 .5442 L F
0 .188 .72 r
.3825 .5442 m .38513 .54683 L .38297 .54536 L F
.421 .864 .9 r
.22175 .54047 m .22264 .53966 L .22509 .53867 L F
0 0 0 r
.22509 .53867 m .22486 .53892 L .22698 .53764 L F
.22509 .53867 m .22264 .53966 L .22486 .53892 L F
.416 .094 .309 r
.33251 .56972 m .33172 .57161 L .32943 .57211 L F
.375 .067 .309 r
.33478 .56874 m .33172 .57161 L .33251 .56972 L F
.344 .536 .899 r
.34782 .55802 m .34622 .55972 L .34539 .55782 L F
.604 .952 .831 r
.34622 .55972 m .34346 .56054 L .34782 .55802 L F
.876 .494 .021 r
.31242 .62917 m .31452 .63323 L .31488 .62867 L F
.1 0 .322 r
.31452 .63323 m .31396 .63497 L .31609 .63426 L F
.434 .473 .802 r
.31488 .62867 m .31452 .63323 L .31728 .63033 L F
.236 .347 .774 r
.31452 .63323 m .31765 .63286 L .31728 .63033 L F
.31452 .63323 m .31609 .63426 L .31765 .63286 L F
0 0 .264 r
.21555 .60265 m .21663 .60647 L .21591 .6041 L F
0 0 0 r
.28482 .54332 m .28435 .54416 L .28556 .54288 L F
.347 .27 .626 r
.17757 .59147 m .17923 .59098 L .17931 .58722 L F
.374 .25 .581 r
.17765 .59432 m .17923 .59098 L .17757 .59147 L F
.886 .766 .723 r
.35959 .68159 m .36091 .68492 L .35897 .68364 L F
.785 .594 .642 r
.36091 .68492 m .35668 .68696 L .35897 .68364 L F
.36091 .68492 m .36065 .68768 L .35668 .68696 L F
.776 .722 .802 r
.36337 .68218 m .36091 .68492 L .35959 .68159 L F
.768 .614 .688 r
.32273 .54163 m .32066 .54173 L .32076 .54104 L F
.354 .168 .485 r
.32512 .53791 m .32478 .54087 L .32273 .54163 L F
.415 .313 .63 r
.32273 .54163 m .32514 .54337 L .32478 .54087 L F
.32273 .54163 m .32514 .54337 L .32478 .54087 L F
.149 0 .204 r
.2076 .54782 m .20857 .54902 L .20942 .54706 L F
.2076 .54782 m .20674 .55009 L .20857 .54902 L F
.761 .431 .426 r
.53204 .5473 m .5343 .54586 L .53235 .54373 L F
.53204 .5473 m .53603 .54779 L .5343 .54586 L F
0 .122 .671 r
.32263 .55578 m .32366 .55786 L .32351 .55553 L F
.746 .922 .949 r
.32351 .55553 m .32366 .55786 L .32572 .55631 L F
.763 .698 .791 r
.32517 .55882 m .32351 .55553 L .32572 .55631 L F
.32517 .55882 m .32171 .55873 L .32351 .55553 L F
.733 .882 .479 r
.32351 .55553 m .32171 .55873 L .32234 .5571 L F
0 0 0 r
.32351 .55553 m .32234 .5571 L .32463 .5552 L F
.32351 .55553 m .32463 .5552 L .32479 .55507 L F
0 .122 .671 r
.32156 .55364 m .32263 .55578 L .32351 .55553 L F
.623 .743 .933 r
.21366 .59437 m .21141 .59528 L .20972 .59358 L F
.432 .609 .922 r
.21437 .5962 m .21141 .59528 L .21366 .59437 L F
.818 .757 .795 r
.53127 .54944 m .53297 .55276 L .53367 .55151 L F
.53127 .54944 m .52888 .55257 L .53297 .55276 L F
.823 .739 .771 r
.52888 .55257 m .53017 .55575 L .53297 .55276 L F
.755 .957 .651 r
.36579 .52408 m .3651 .52593 L .36724 .52596 L F
.681 .703 .864 r
.35227 .61999 m .35495 .6228 L .34993 .6219 L F
.572 .531 .77 r
.35389 .62495 m .34993 .6219 L .35495 .6228 L F
.495 .643 .922 r
.35617 .62222 m .35495 .6228 L .35227 .61999 L F
.133 0 .188 r
.35617 .62222 m .35389 .62495 L .35495 .6228 L F
.985 .85 .624 r
.35495 .6228 m .35389 .62495 L .35617 .62222 L F
.454 .166 .384 r
.24279 .56295 m .24513 .56255 L .24512 .5606 L F
.586 .707 .926 r
.52381 .55573 m .52787 .55681 L .52635 .55353 L F
.703 .694 .839 r
.52635 .55353 m .52787 .55681 L .53017 .55575 L F
.61 .623 .839 r
.3026 .52684 m .30077 .52777 L .29963 .52595 L F
.148 .308 .77 r
.20194 .60951 m .20147 .60596 L .19962 .60644 L F
.20194 .60951 m .20307 .60967 L .20147 .60596 L F
.757 .993 .874 r
.37278 .5346 m .36953 .53693 L .37136 .53615 L F
.216 0 0 r
.22146 .56119 m .21966 .56081 L .22235 .55925 L F
.491 .044 .117 r
.26284 .55608 m .26542 .55621 L .26721 .55418 L F
.351 0 .024 r
.26721 .55418 m .26542 .55621 L .26897 .555 L F
.33 0 .128 r
.26721 .55418 m .26897 .555 L .26954 .55367 L F
.435 .294 .589 r
.36044 .56602 m .36053 .5688 L .35848 .56937 L F
.363 .162 .468 r
.36028 .57127 m .35848 .56937 L .36053 .5688 L F
.36028 .57127 m .35821 .57221 L .35848 .56937 L F
.7 .472 .575 r
.32057 .6349 m .32385 .63483 L .32323 .6375 L F
.452 .204 .447 r
.32385 .63483 m .32601 .63681 L .32323 .6375 L F
.32385 .63483 m .32615 .63394 L .32601 .63681 L F
.63 .517 .706 r
.51868 .54698 m .52117 .54383 L .51867 .54463 L F
.51868 .54698 m .52242 .54754 L .52117 .54383 L F
.613 .51 .713 r
.51868 .54698 m .5226 .55019 L .52242 .54754 L F
.51868 .54698 m .52 .55085 L .5226 .55019 L F
.16 .287 .746 r
.36184 .52518 m .3601 .52118 L .36156 .52268 L F
.612 .543 .752 r
.28527 .579 m .28793 .57307 L .28545 .57588 L F
.252 0 0 r
.34524 .56944 m .34109 .57148 L .34282 .57257 L F
.192 .062 .463 r
.34478 .57375 m .34282 .57257 L .34109 .57148 L F
.34478 .57375 m .34273 .57535 L .34282 .57257 L F
.472 .23 .466 r
.35112 .62561 m .35109 .62911 L .34819 .62901 L F
.572 .531 .77 r
.35389 .62495 m .35112 .62561 L .34993 .6219 L F
.532 .277 .474 r
.35345 .62789 m .35112 .62561 L .35389 .62495 L F
.35345 .62789 m .35109 .62911 L .35112 .62561 L F
.433 .478 .807 r
.35433 .63418 m .3558 .63781 L .35385 .63809 L F
.363 .037 .272 r
.30525 .62945 m .30871 .62568 L .30629 .62604 L F
.30525 .62945 m .30742 .62863 L .30871 .62568 L F
.493 .894 .757 r
.30962 .62496 m .30871 .62568 L .30996 .62461 L F
.62 .934 .963 r
.31179 .62317 m .31425 .62336 L .30962 .62496 L F
0 0 0 r
.30871 .62568 m .30742 .62863 L .30996 .62461 L F
.099 0 .038 r
.27551 .61536 m .27699 .61322 L .27393 .61597 L F
.095 0 .207 r
.27942 .60999 m .27699 .61322 L .27861 .61215 L F
0 0 0 r
.27861 .61215 m .27699 .61322 L .27551 .61536 L F
.441 .016 .136 r
.29508 .54757 m .29348 .54969 L .29095 .54989 L F
.529 .11 .192 r
.29644 .54905 m .29508 .54757 L .29721 .54694 L F
.29644 .54905 m .29348 .54969 L .29508 .54757 L F
.54 .477 .734 r
.32759 .53677 m .32653 .53409 L .32791 .53498 L F
.473 .288 .548 r
.33037 .53195 m .33039 .53435 L .32791 .53498 L F
.582 .345 .522 r
.33039 .53435 m .32759 .53677 L .32791 .53498 L F
.646 .562 .745 r
.17468 .60874 m .17585 .61074 L .17822 .60975 L F
.17468 .60874 m .17585 .61074 L .17822 .60975 L F
.699 .967 .936 r
.31637 .53394 m .3159 .53538 L .3181 .53424 L F
.965 .805 .632 r
.31365 .53685 m .3159 .53538 L .31637 .53394 L F
.31365 .53685 m .31536 .53827 L .3159 .53538 L F
0 0 .395 r
.39864 .54974 m .4006 .55321 L .39931 .5516 L F
.538 .683 .932 r
.27484 .72229 m .27187 .72155 L .27266 .7213 L F
0 0 .201 r
.27187 .72155 m .2724 .72398 L .27266 .7213 L F
.27187 .72155 m .27198 .72546 L .2724 .72398 L F
.059 .282 .772 r
.37512 .52044 m .37344 .5203 L .37217 .51981 L F
.934 .96 .759 r
.32121 .5684 m .32048 .5719 L .32004 .57185 L F
.015 .439 .867 r
.26232 .55925 m .26284 .55608 L .2606 .55696 L F
.26232 .55925 m .26261 .55844 L .26284 .55608 L F
.26232 .55925 m .2641 .55997 L .26261 .55844 L F
.1 0 .337 r
.36671 .57534 m .36803 .57477 L .36841 .5723 L F
.351 .324 .688 r
.36671 .57534 m .36858 .578 L .36803 .57477 L F
.386 .788 .984 r
.3407 .56189 m .34206 .56177 L .33995 .56008 L F
.779 .472 .468 r
.39511 .57545 m .39119 .5751 L .39137 .57272 L F
.683 .42 .518 r
.34945 .54398 m .34834 .54847 L .34511 .54736 L F
.877 .921 .528 r
.35069 .54016 m .34945 .54398 L .34859 .54104 L F
.35069 .54016 m .34904 .54251 L .34945 .54398 L F
.354 .112 .402 r
.3503 .54649 m .34945 .54398 L .34904 .54251 L F
.3503 .54649 m .34834 .54847 L .34945 .54398 L F
.677 .178 .054 r
.3558 .63781 m .3585 .63984 L .36008 .63857 L F
.875 .466 .244 r
.3585 .63984 m .36058 .64086 L .36008 .63857 L F
.771 .386 .326 r
.36008 .63857 m .36058 .64086 L .36478 .64128 L F
0 0 .21 r
.18263 .56915 m .18357 .57055 L .18413 .5685 L F
.18263 .56915 m .18185 .57177 L .18357 .57055 L F
.639 .95 .946 r
.31858 .53262 m .3181 .53424 L .32042 .53357 L F
.31858 .53262 m .31637 .53394 L .3181 .53424 L F
.7 .472 .575 r
.32057 .6349 m .32323 .6375 L .32083 .63761 L F
.043 0 0 r
.35797 .65805 m .35857 .65878 L .36064 .65705 L F
0 0 .2 r
.35858 .65818 m .35797 .65805 L .35705 .65589 L F
.35858 .65818 m .35857 .65878 L .35797 .65805 L F
.655 .454 .6 r
.37114 .68796 m .37109 .69084 L .36847 .69068 L F
.565 .322 .507 r
.37435 .68741 m .37109 .69084 L .37114 .68796 L F
.047 .043 .529 r
.30585 .56625 m .30686 .56561 L .30675 .56206 L F
.223 .188 .607 r
.30609 .56887 m .30686 .56561 L .30585 .56625 L F
.447 .323 .618 r
.36044 .65363 m .36064 .65705 L .36305 .65598 L F
.443 .226 .487 r
.3839 .59748 m .38377 .60027 L .38134 .60076 L F
.347 .095 .383 r
.38656 .59441 m .38615 .59692 L .3839 .59748 L F
.577 .334 .512 r
.38641 .59972 m .3839 .59748 L .38615 .59692 L F
.38641 .59972 m .38377 .60027 L .3839 .59748 L F
.438 .226 .492 r
.36926 .56039 m .37189 .55689 L .36802 .55899 L F
.36926 .56039 m .37087 .5605 L .37189 .55689 L F
.435 .371 .687 r
.36926 .56039 m .37181 .56211 L .37087 .5605 L F
.346 .276 .634 r
.38857 .59371 m .38877 .59642 L .38656 .59441 L F
.55 .269 .442 r
.38877 .59642 m .38615 .59692 L .38656 .59441 L F
.328 .036 .308 r
.37087 .5605 m .37459 .5566 L .37189 .55689 L F
.066 .512 .897 r
.21613 .61575 m .21583 .61458 L .21384 .61442 L F
.21613 .61575 m .21731 .61583 L .21583 .61458 L F
.176 .076 .494 r
.293 .63406 m .29182 .63754 L .29161 .63493 L F
0 0 0 r
.32111 .57413 m .32324 .57343 L .32284 .57248 L F
.478 .531 .833 r
.32324 .57343 m .32476 .57121 L .32284 .57248 L F
.459 .574 .883 r
.32507 .57317 m .32635 .57355 L .32324 .57343 L F
.661 .596 .772 r
.35914 .6067 m .36218 .60312 L .35936 .60419 L F
.549 .842 .998 r
.33799 .5459 m .33727 .54757 L .33954 .54693 L F
.614 .907 .984 r
.33799 .5459 m .33528 .54722 L .33727 .54757 L F
.33799 .5459 m .33528 .54722 L .33727 .54757 L F
0 .091 .617 r
.33835 .54822 m .33727 .54757 L .33799 .5459 L F
.558 .3 .481 r
.35771 .64117 m .36043 .64372 L .35742 .64367 L F
.697 .159 0 r
.36085 .64335 m .36043 .64372 L .35771 .64117 L F
.433 .152 .386 r
.33924 .58032 m .33746 .57865 L .33935 .57791 L F
.33924 .58032 m .33697 .58094 L .33746 .57865 L F
.592 .864 .994 r
.30667 .53928 m .30646 .5412 L .30896 .53822 L F
.554 .345 .551 r
.30646 .5412 m .30898 .54078 L .30896 .53822 L F
.424 .243 .53 r
.30896 .53822 m .30898 .54078 L .3113 .53745 L F
.516 .804 .998 r
.30667 .53928 m .3113 .53745 L .30896 .53822 L F
.474 .786 .998 r
.24252 .63455 m .2449 .63419 L .24301 .63313 L F
.643 .941 .961 r
.24301 .63313 m .2408 .63424 L .24252 .63455 L F
.406 0 0 r
.3073 .64399 m .30667 .64307 L .30652 .64329 L F
.3073 .64399 m .3089 .64316 L .30667 .64307 L F
.483 .389 .673 r
.38377 .60027 m .38171 .60339 L .38134 .60076 L F
.272 .738 .947 r
.28726 .52733 m .2895 .52719 L .29095 .52767 L F
.115 .665 .8 r
.2895 .52719 m .29308 .52715 L .29095 .52767 L F
.69 .495 .619 r
.52117 .54383 m .52508 .54427 L .52479 .54148 L F
.724 .52 .615 r
.52479 .54148 m .52736 .54361 L .52742 .54128 L F
.52479 .54148 m .52508 .54427 L .52736 .54361 L F
.579 .685 .914 r
.35108 .63016 m .35243 .63201 L .34877 .63082 L F
.543 .669 .919 r
.35426 .63096 m .35243 .63201 L .35108 .63016 L F
.356 .248 .591 r
.35426 .63096 m .35433 .63418 L .35243 .63201 L F
.232 0 .163 r
.20486 .57692 m .20375 .57585 L .20563 .57493 L F
.20486 .57692 m .20273 .57793 L .20375 .57585 L F
0 0 0 r
.2161 .56329 m .21371 .56553 L .21378 .56398 L F
.018 .138 .648 r
.30184 .55062 m .30284 .55434 L .30365 .5521 L F
.469 .663 .946 r
.30284 .55434 m .3054 .5543 L .30365 .5521 L F
.763 .67 .76 r
.37213 .52798 m .37284 .53195 L .37534 .52878 L F
.498 .301 .543 r
.37534 .52878 m .37284 .53195 L .37528 .53136 L F
.973 .716 .484 r
.37284 .53195 m .37694 .53446 L .37528 .53136 L F
.07 .362 .832 r
.20307 .60967 m .20533 .61285 L .20573 .6114 L F
.071 .364 .833 r
.20533 .61285 m .20671 .61329 L .20573 .6114 L F
.458 .576 .885 r
.34313 .53698 m .34179 .5388 L .33945 .53646 L F
.8 .771 .262 r
.34313 .53698 m .34252 .54068 L .34179 .5388 L F
.252 0 0 r
.34524 .56944 m .34321 .57164 L .34109 .57148 L F
.091 0 0 r
.34589 .57046 m .34524 .56944 L .34804 .56924 L F
.34589 .57046 m .34321 .57164 L .34524 .56944 L F
.572 .403 .614 r
.34772 .5662 m .34804 .56924 L .34524 .56944 L F
.421 .335 .653 r
.3141 .57462 m .31614 .57435 L .31578 .57178 L F
.645 .599 .788 r
.31464 .57865 m .31614 .57435 L .3141 .57462 L F
.594 .555 .78 r
.52381 .55573 m .52635 .55353 L .52377 .55412 L F
0 0 .094 r
.28075 .60871 m .27942 .60999 L .27861 .61215 L F
0 0 .528 r
.32867 .65669 m .32963 .65553 L .32913 .65259 L F
0 0 .001 r
.32956 .65846 m .32963 .65553 L .32867 .65669 L F
0 0 .375 r
.32867 .65669 m .32911 .65977 L .32956 .65846 L F
.748 .8 .895 r
.35932 .67843 m .35602 .67822 L .35782 .67751 L F
.764 .516 .558 r
.35932 .67843 m .35548 .68092 L .35602 .67822 L F
.35932 .67843 m .35959 .68159 L .35548 .68092 L F
.589 .603 .834 r
.36059 .67476 m .35932 .67843 L .35782 .67751 L F
.36059 .67476 m .36191 .67819 L .35932 .67843 L F
.567 .369 .572 r
.36191 .67819 m .35959 .68159 L .35932 .67843 L F
.801 .427 .348 r
.26884 .62884 m .27044 .62817 L .26856 .62824 L F
.26884 .62884 m .2731 .62854 L .27044 .62817 L F
.971 .727 .51 r
.39326 .56681 m .39334 .56803 L .39491 .56664 L F
.516 .314 .544 r
.39524 .56642 m .39491 .56664 L .39377 .56795 L F
.39571 .56593 m .39491 .56664 L .39524 .56642 L F
.971 .727 .51 r
.39334 .56803 m .39346 .56996 L .39491 .56664 L F
.217 .316 .752 r
.39491 .56664 m .39646 .57147 L .39382 .56921 L F
.477 .49 .793 r
.39858 .56976 m .39646 .57147 L .39491 .56664 L F
.39858 .56976 m .39491 .56664 L .39703 .56697 L F
.183 0 .153 r
.39491 .56664 m .39574 .56889 L .39703 .56697 L F
.39516 .56731 m .39346 .56996 L .39574 .56889 L F
.39491 .56664 m .3944 .56781 L .39516 .56731 L F
.3944 .56781 m .39346 .56996 L .39516 .56731 L F
.248 0 0 r
.39703 .56697 m .39456 .56686 L .39491 .56664 L F
.39456 .56686 m .39326 .56681 L .39491 .56664 L F
.714 .823 .933 r
.39588 .56532 m .39326 .56681 L .39576 .56692 L F
.516 .314 .544 r
.39713 .56445 m .39491 .56664 L .39571 .56593 L F
.39713 .56445 m .39703 .56697 L .39491 .56664 L F
.714 .823 .933 r
.3966 .56636 m .39576 .56692 L .39703 .56697 L F
.39588 .56532 m .39576 .56692 L .3966 .56636 L F
.231 .663 .957 r
.34249 .55696 m .34102 .55569 L .33888 .55584 L F
.32 .583 .937 r
.34249 .55696 m .34336 .55534 L .34102 .55569 L F
.799 .651 .699 r
.27948 .62151 m .28211 .62486 L .28159 .62253 L F
.359 0 .093 r
.3093 .55954 m .31175 .55917 L .31331 .55705 L F
.493 .076 .177 r
.31331 .55705 m .31175 .55917 L .31541 .55835 L F
.105 .197 .677 r
.32201 .59262 m .3207 .59464 L .32001 .59059 L F
.322 .26 .631 r
.32312 .59631 m .3207 .59464 L .32201 .59262 L F
.32312 .59631 m .32245 .59706 L .3207 .59464 L F
.585 .791 .978 r
.35879 .62366 m .35749 .62553 L .36052 .62499 L F
.633 .543 .735 r
.35879 .62366 m .35501 .628 L .35749 .62553 L F
.767 .674 .76 r
.35501 .628 m .36052 .62499 L .35749 .62553 L F
.352 .778 .973 r
.24873 .6356 m .24911 .63444 L .24707 .63419 L F
.24873 .6356 m .25157 .63538 L .24911 .63444 L F
.052 0 .073 r
.33654 .61646 m .3335 .61963 L .33557 .61897 L F
.097 0 0 r
.33557 .61897 m .3335 .61963 L .32978 .62217 L F
0 .435 .724 r
.35903 .61024 m .36157 .61097 L .35829 .60827 L F
.35903 .61024 m .36241 .61117 L .36157 .61097 L F
.482 .616 .907 r
.35903 .61024 m .36132 .61386 L .36241 .61117 L F
.401 0 .087 r
.36359 .61349 m .36374 .61455 L .36132 .61386 L F
.255 .352 .77 r
.36132 .61386 m .36374 .61455 L .36241 .61117 L F
.509 .854 .994 r
.31957 .52339 m .31917 .52495 L .31727 .52421 L F
.31957 .52339 m .32165 .52437 L .31917 .52495 L F
.581 .528 .76 r
.28831 .58169 m .28945 .58479 L .28688 .58502 L F
.346 .052 .315 r
.28945 .58479 m .28661 .58756 L .28688 .58502 L F
.581 .528 .76 r
.28688 .58502 m .28945 .58479 L .28831 .58169 L F
.346 .052 .315 r
.28661 .58756 m .28945 .58479 L .28688 .58502 L F
.28945 .58479 m .28879 .58689 L .28661 .58756 L F
.28661 .58756 m .28879 .58689 L .28945 .58479 L F
.51 .204 .383 r
.28945 .58479 m .28879 .58689 L .28688 .58502 L F
.548 .162 .262 r
.25857 .54941 m .25488 .5518 L .25652 .54994 L F
0 .196 .724 r
.37694 .53446 m .37749 .53336 L .37528 .53136 L F
.042 .37 .839 r
.37694 .53446 m .37848 .53518 L .37749 .53336 L F
.585 .699 .921 r
.20671 .61329 m .20897 .61568 L .21138 .6151 L F
.378 0 0 r
.21862 .60713 m .22297 .60919 L .22102 .60937 L F
.763 .67 .76 r
.37213 .52798 m .37534 .52878 L .37419 .52975 L F
.993 .749 .399 r
.37534 .52878 m .37528 .53136 L .37419 .52975 L F
.671 .793 .939 r
.37894 .52249 m .37775 .52529 L .37611 .52258 L F
.37894 .52249 m .38067 .52411 L .37775 .52529 L F
.551 .931 .847 r
.37683 .6794 m .37768 .67844 L .3788 .67851 L F
0 0 0 r
.37768 .67844 m .37601 .68074 L .37868 .67733 L F
.37768 .67844 m .37876 .67722 L .37928 .67695 L F
.37768 .67844 m .37868 .67733 L .37876 .67722 L F
.551 .931 .847 r
.37626 .67966 m .37768 .67844 L .37683 .6794 L F
.48 .81 1 r
.37928 .67695 m .38116 .678 L .3788 .67851 L F
.725 .989 .841 r
.3788 .67851 m .37768 .67844 L .37928 .67695 L F
.482 .366 .645 r
.3811 .68057 m .3788 .67851 L .38116 .678 L F
.3811 .68057 m .37918 .6815 L .3788 .67851 L F
.063 0 .242 r
.20131 .58697 m .19974 .58806 L .2018 .58472 L F
.292 .227 .61 r
.20131 .58697 m .20168 .59017 L .19974 .58806 L F
0 .015 .573 r
.36306 .65043 m .36372 .64904 L .36337 .64853 L F
.572 .051 0 r
.36306 .65043 m .3652 .65263 L .36408 .65174 L F
.36306 .65043 m .36408 .65174 L .36372 .64904 L F
.457 .424 .733 r
.37807 .64987 m .37623 .65087 L .37588 .64842 L F
0 0 0 r
.37807 .64987 m .37414 .65222 L .37623 .65087 L F
.567 .923 .744 r
.35992 .51687 m .36092 .51575 L .36244 .51567 L F
.552 .504 .755 r
.35108 .63016 m .34877 .63082 L .34819 .62901 L F
0 0 0 r
.18945 .60222 m .18785 .60256 L .18545 .60288 L F
.829 .998 .78 r
.18826 .60101 m .18945 .60222 L .19326 .6024 L F
.18826 .60101 m .18785 .60256 L .18945 .60222 L F
.565 .322 .507 r
.37435 .68741 m .37391 .69065 L .37109 .69084 L F
.469 .293 .558 r
.37664 .68436 m .3767 .6871 L .37435 .68741 L F
.435 .205 .465 r
.3767 .6871 m .37391 .69065 L .37435 .68741 L F
.795 .675 .731 r
.36191 .67819 m .36337 .68218 L .35959 .68159 L F
.591 .566 .795 r
.36576 .68143 m .36337 .68218 L .36191 .67819 L F
.365 .11 .388 r
.27198 .72546 m .27484 .72229 L .27426 .72495 L F
.954 .728 .558 r
.27426 .72495 m .27484 .72229 L .27266 .7213 L F
.559 .572 .824 r
.27827 .71742 m .27713 .71936 L .27516 .71814 L F
.27827 .71742 m .27951 .71898 L .27713 .71936 L F
.27827 .71742 m .27713 .71936 L .27516 .71814 L F
.27827 .71742 m .27951 .71898 L .27713 .71936 L F
.129 .445 .88 r
.37848 .53518 m .38123 .53814 L .38092 .53627 L F
.931 .745 .265 r
.38123 .53814 m .38039 .53792 L .38092 .53627 L F
.38123 .53814 m .38104 .54068 L .38039 .53792 L F
.418 .01 .155 r
.31579 .64467 m .31893 .64349 L .31755 .64592 L F
.289 .038 .35 r
.31893 .64349 m .32115 .64087 L .32067 .6432 L F
.24 0 .063 r
.31755 .64592 m .31893 .64349 L .32067 .6432 L F
.421 .864 .9 r
.22175 .54047 m .22041 .54043 L .22264 .53966 L F
.168 0 .028 r
.20462 .55088 m .20364 .55234 L .20674 .55009 L F
.592 .461 .671 r
.33557 .61897 m .3378 .61539 L .33654 .61646 L F
0 0 0 r
.28758 .59141 m .28569 .59416 L .28683 .5932 L F
.303 0 0 r
.28808 .59177 m .28758 .59141 L .28683 .5932 L F
.28808 .59177 m .28957 .59226 L .28758 .59141 L F
.582 .802 .983 r
.33954 .54693 m .34363 .54747 L .34427 .5466 L F
.541 .311 .516 r
.34089 .55014 m .34363 .54747 L .33954 .54693 L F
.34089 .55014 m .34344 .54988 L .34363 .54747 L F
.596 .071 0 r
.34405 .54661 m .33799 .5459 L .33954 .54693 L F
.34427 .5466 m .34408 .54658 L .34405 .54661 L F
.34408 .54658 m .33799 .5459 L .34405 .54661 L F
.34408 .54658 m .33937 .54682 L .33799 .5459 L F
.136 .298 .765 r
.34028 .54743 m .34049 .54789 L .33944 .54705 L F
.33919 .5467 m .3392 .54686 L .33799 .5459 L F
.92 .934 .799 r
.33914 .54483 m .33917 .54601 L .34271 .54146 L F
.873 .802 .776 r
.34271 .54146 m .33917 .54601 L .34409 .54658 L F
.34417 .54625 m .34409 .54658 L .34427 .5466 L F
.34271 .54146 m .34409 .54658 L .34417 .54625 L F
.34271 .54146 m .34427 .5466 L .34465 .54554 L F
.674 .936 .967 r
.34454 .54584 m .34423 .54633 L .34465 .54554 L F
.34427 .5466 m .34423 .54633 L .34454 .54584 L F
.596 .071 0 r
.34427 .5466 m .34409 .54661 L .34408 .54658 L F
.674 .936 .967 r
.34427 .5466 m .34363 .54747 L .34423 .54633 L F
.567 .558 .803 r
.34459 .54577 m .34423 .54633 L .34408 .54661 L F
.34407 .5467 m .34408 .54661 L .34363 .54747 L F
.34459 .54577 m .34408 .54661 L .34407 .5467 L F
.596 .071 0 r
.34409 .54661 m .33938 .54682 L .34408 .54658 L F
.389 .318 .655 r
.33799 .5459 m .34049 .54789 L .33835 .54822 L F
.62 .685 .889 r
.33392 .5439 m .33528 .54722 L .33799 .5459 L F
.427 .585 .906 r
.33569 .54746 m .33799 .5459 L .33528 .54722 L F
.33569 .54746 m .3362 .54503 L .33799 .5459 L F
.33569 .54746 m .33835 .54822 L .3362 .54503 L F
.272 0 0 r
.33383 .5507 m .33835 .54822 L .33569 .54746 L F
.33383 .5507 m .33653 .55027 L .33835 .54822 L F
.773 .921 .547 r
.33835 .54822 m .33653 .55027 L .33803 .54776 L F
0 .248 .761 r
.33835 .54822 m .33859 .54682 L .3362 .54503 L F
.773 .921 .547 r
.33851 .5473 m .33803 .54776 L .33859 .54682 L F
.33835 .54822 m .33803 .54776 L .33851 .5473 L F
.596 .071 0 r
.34409 .54661 m .33899 .54685 L .33938 .54682 L F
.33899 .54685 m .3385 .54687 L .33899 .54684 L F
.33899 .54685 m .33899 .54684 L .33938 .54682 L F
.873 .802 .776 r
.33917 .54601 m .33938 .54683 L .34427 .5466 L F
.136 .298 .765 r
.33914 .54483 m .34028 .54743 L .33799 .5459 L F
.33938 .54683 m .3392 .54686 L .33919 .5467 L F
.596 .071 0 r
.33937 .54682 m .3385 .54687 L .33799 .5459 L F
.92 .934 .799 r
.33914 .54483 m .3385 .54687 L .33917 .54601 L F
.136 .298 .765 r
.33938 .54683 m .33944 .54705 L .3392 .54686 L F
.34028 .54743 m .33944 .54705 L .33938 .54683 L F
.873 .802 .776 r
.33917 .54601 m .3385 .54687 L .33938 .54683 L F
.567 .558 .803 r
.34344 .54988 m .34422 .54709 L .34363 .54747 L F
.34422 .54709 m .34459 .54577 L .3441 .54665 L F
.34422 .54709 m .3441 .54665 L .34363 .54747 L F
.34459 .54577 m .34465 .54554 L .34423 .54633 L F
.243 .164 .564 r
.34931 .5678 m .34804 .56924 L .34772 .5662 L F
.615 .501 .699 r
.35482 .58733 m .35601 .59115 L .35317 .59116 L F
.695 .553 .689 r
.31934 .55306 m .31635 .55327 L .31836 .55087 L F
.217 .69 .939 r
.31623 .55194 m .3203 .55275 L .31836 .55087 L F
.816 .779 .275 r
.28642 .59509 m .28683 .5932 L .28569 .59416 L F
.462 .249 .504 r
.38186 .56269 m .37953 .56334 L .38202 .55995 L F
.381 .219 .533 r
.3843 .55646 m .38406 .5593 L .38202 .55995 L F
.488 .271 .51 r
.38433 .56186 m .38186 .56269 L .38202 .55995 L F
.475 .817 .999 r
.2724 .72398 m .27198 .72546 L .27426 .72495 L F
0 0 0 r
.27393 .61597 m .27009 .61842 L .27237 .61779 L F
.27551 .61536 m .27393 .61597 L .27237 .61779 L F
0 .07 .604 r
.31519 .58446 m .31844 .58218 L .31605 .58337 L F
.052 0 0 r
.31844 .58218 m .31519 .58446 L .31605 .58337 L F
.103 0 0 r
.35899 .66175 m .36011 .66195 L .35776 .66246 L F
.35899 .66175 m .36109 .66182 L .36011 .66195 L F
.532 .919 .806 r
.3587 .66214 m .36011 .66195 L .36128 .66081 L F
0 0 0 r
.35776 .66246 m .36011 .66195 L .35714 .66294 L F
.532 .919 .806 r
.35714 .66294 m .36011 .66195 L .3587 .66214 L F
.103 0 0 r
.36109 .66182 m .36163 .66184 L .36011 .66195 L F
.615 .808 .974 r
.24196 .76609 m .23771 .76552 L .2404 .76542 L F
.23771 .76552 m .24196 .76609 L .2404 .76542 L F
.483 .389 .673 r
.38377 .60027 m .38473 .60332 L .38171 .60339 L F
.152 0 .247 r
.38473 .60332 m .38175 .60609 L .38171 .60339 L F
.475 .582 .882 r
.21947 .61886 m .2201 .61558 L .21731 .61583 L F
.21947 .61886 m .22157 .61854 L .2201 .61558 L F
.608 .916 .657 r
.28702 .60084 m .28471 .60299 L .28521 .60212 L F
0 0 0 r
.28563 .60139 m .28521 .60212 L .28442 .60468 L F
.989 .838 .6 r
.28596 .59953 m .28702 .60084 L .28521 .60212 L F
0 0 0 r
.28597 .60047 m .28521 .60212 L .28563 .60139 L F
.608 .916 .657 r
.28471 .60299 m .28422 .60345 L .28521 .60212 L F
0 0 0 r
.28422 .60345 m .28442 .60468 L .28521 .60212 L F
.28422 .60345 m .28339 .60491 L .28442 .60468 L F
.338 .142 .46 r
.37386 .59744 m .37356 .60014 L .37602 .59659 L F
.37602 .59659 m .37356 .60014 L .37386 .59744 L F
.589 .128 0 r
.23883 .61732 m .23825 .61645 L .23916 .6159 L F
.23883 .61732 m .23996 .61872 L .23825 .61645 L F
.754 .653 .749 r
.37357 .65375 m .37077 .65681 L .36968 .65261 L F
.298 .027 .322 r
.37281 .65585 m .37077 .65681 L .37357 .65375 L F
0 0 0 r
.37414 .65222 m .37281 .65585 L .37357 .65375 L F
0 .026 .534 r
.37338 .65337 m .37422 .65524 L .37281 .65585 L F
.37365 .65219 m .37387 .65338 L .37338 .65337 L F
.37387 .65338 m .37422 .65524 L .37338 .65337 L F
0 .53 .828 r
.36968 .65261 m .37146 .65288 L .3726 .65335 L F
.37217 .65334 m .3726 .65335 L .37357 .65375 L F
.36968 .65261 m .3726 .65335 L .37217 .65334 L F
.625 .709 .907 r
.36626 .5169 m .36244 .51567 L .36447 .51575 L F
.399 .744 .993 r
.36723 .51566 m .36626 .5169 L .36447 .51575 L F
.36723 .51566 m .36891 .51693 L .36626 .5169 L F
0 0 0 r
.37077 .65681 m .36927 .65853 L .36722 .65953 L F
.95 .918 .554 r
.36884 .6574 m .37077 .65681 L .37281 .65585 L F
.36884 .6574 m .36927 .65853 L .37077 .65681 L F
.718 .565 .681 r
.31101 .59125 m .31028 .59529 L .31453 .59399 L F
.152 .243 .705 r
.39543 .54009 m .39427 .54169 L .3932 .53802 L F
.286 .355 .759 r
.39543 .54009 m .39498 .54408 L .39427 .54169 L F
.266 0 0 r
.31934 .55306 m .3178 .55367 L .31635 .55327 L F
0 .363 .831 r
.31635 .55327 m .3178 .55367 L .31623 .55194 L F
.219 .568 .939 r
.29638 .64364 m .29206 .64134 L .29484 .64277 L F
.365 .766 .985 r
.29855 .64335 m .29638 .64364 L .29484 .64277 L F
.696 .606 .752 r
.36449 .53808 m .36834 .53913 L .36678 .53771 L F
.771 .796 .873 r
.36678 .53771 m .36834 .53913 L .36953 .53693 L F
.592 .864 .994 r
.30667 .53928 m .30489 .5403 L .30646 .5412 L F
.644 .316 .402 r
.30667 .53928 m .30562 .53992 L .30489 .5403 L F
.23 .677 .953 r
.30646 .5412 m .30489 .5403 L .30433 .54059 L F
.644 .316 .402 r
.30562 .53992 m .30293 .54155 L .30489 .5403 L F
.23 .677 .953 r
.30433 .54059 m .30489 .5403 L .3025 .54006 L F
.323 .113 .432 r
.30678 .54389 m .30898 .54078 L .30646 .5412 L F
.645 .599 .788 r
.31464 .57865 m .31711 .57866 L .31614 .57435 L F
.637 .411 .559 r
.31464 .57865 m .31688 .58044 L .31711 .57866 L F
.31464 .57865 m .31449 .58126 L .31688 .58044 L F
.31464 .57865 m .31688 .58044 L .31711 .57866 L F
.31464 .57865 m .31449 .58126 L .31688 .58044 L F
.632 .484 .663 r
.36818 .61287 m .36375 .60977 L .36586 .60975 L F
.36818 .61287 m .36359 .61349 L .36375 .60977 L F
.497 .446 .731 r
.28793 .57307 m .28789 .57874 L .29038 .57786 L F
.412 .807 .986 r
.28527 .579 m .28896 .57805 L .28789 .57874 L F
.28527 .579 m .28896 .57805 L .28789 .57874 L F
.634 .852 .983 r
.23771 .76552 m .23556 .76646 L .23359 .76522 L F
.23771 .76552 m .23556 .76646 L .23359 .76522 L F
.579 .555 .792 r
.28571 .62811 m .2833 .62863 L .28211 .62486 L F
.194 0 0 r
.32946 .67019 m .33117 .67027 L .33337 .67083 L F
0 0 .218 r
.32258 .56174 m .32066 .56551 L .32121 .56314 L F
0 0 0 r
.20252 .58045 m .2018 .58472 L .20157 .58214 L F
.37125 .64922 m .36924 .65041 L .37201 .64762 L F
.885 .874 .82 r
.37201 .64762 m .37375 .64426 L .37415 .64698 L F
.37201 .64762 m .37284 .64293 L .37375 .64426 L F
0 0 0 r
.37415 .64698 m .37125 .64922 L .37201 .64762 L F
.662 .816 .957 r
.30207 .68954 m .29991 .69142 L .29975 .69011 L F
.30207 .68954 m .30337 .69096 L .29991 .69142 L F
.29991 .69142 m .30337 .69096 L .30207 .68954 L F
.29991 .69142 m .30207 .68954 L .29909 .69352 L F
.337 .32 .692 r
.34026 .64023 m .3395 .64336 L .33745 .64048 L F
.34026 .64023 m .3409 .64387 L .3395 .64336 L F
.552 .504 .755 r
.35108 .63016 m .34819 .62901 L .35109 .62911 L F
.693 .674 .826 r
.31825 .53792 m .32027 .54097 L .31598 .54052 L F
.276 .055 .387 r
.32759 .53677 m .32478 .54087 L .32512 .53791 L F
.593 .201 .268 r
.32943 .57211 m .32635 .57355 L .32507 .57317 L F
.32943 .57211 m .32821 .57427 L .32635 .57355 L F
.439 .068 .236 r
.33172 .57161 m .32821 .57427 L .32943 .57211 L F
.418 .01 .155 r
.31579 .64467 m .31755 .64592 L .31523 .64648 L F
.334 0 0 r
.27049 .54558 m .26666 .54651 L .26813 .54497 L F
.703 .249 .17 r
.32218 .62393 m .31789 .62257 L .31816 .6255 L F
.487 .155 .329 r
.31761 .62777 m .32218 .62393 L .31816 .6255 L F
.31761 .62777 m .32013 .6276 L .32218 .62393 L F
.693 .384 .448 r
.32218 .62393 m .32013 .6276 L .32375 .62765 L F
0 .03 .592 r
.29865 .64992 m .30078 .65253 L .29993 .65034 L F
.29865 .64992 m .29993 .65034 L .29607 .64935 L F
.297 0 0 r
.28981 .64641 m .29372 .64749 L .29195 .64711 L F
0 .212 .732 r
.29372 .64749 m .29516 .6479 L .29195 .64711 L F
.335 .589 .937 r
.29516 .6479 m .29607 .64935 L .29709 .64797 L F
.096 0 0 r
.29581 .64802 m .29516 .6479 L .29709 .64797 L F
0 .212 .732 r
.29395 .64767 m .29607 .64935 L .29516 .6479 L F
.096 0 0 r
.29264 .64813 m .29516 .6479 L .29581 .64802 L F
0 .212 .732 r
.29372 .64749 m .29395 .64767 L .29516 .6479 L F
.262 0 .072 r
.36874 .60977 m .37121 .60876 L .36842 .61014 L F
.761 .586 .661 r
.36973 .61245 m .36874 .60977 L .36842 .61014 L F
.703 .694 .839 r
.52635 .55353 m .53017 .55575 L .52888 .55257 L F
.601 .424 .615 r
.36968 .65261 m .36678 .65376 L .36924 .65041 L F
.325 .275 .647 r
.37125 .64922 m .36968 .65261 L .36924 .65041 L F
.597 .286 .413 r
.28207 .62443 m .28797 .62472 L .28838 .62231 L F
.28838 .62231 m .28797 .62472 L .28207 .62443 L F
.588 .278 .411 r
.28838 .62231 m .29054 .62442 L .28797 .62472 L F
.28838 .62231 m .29054 .62442 L .28797 .62472 L F
.32 .643 .967 r
.30403 .6896 m .30337 .69096 L .30207 .68954 L F
.30403 .6896 m .30337 .69096 L .30207 .68954 L F
.458 .476 .79 r
.33104 .52798 m .33257 .53185 L .33037 .53195 L F
.588 .378 .564 r
.33294 .53395 m .33037 .53195 L .33257 .53185 L F
.33294 .53395 m .33039 .53435 L .33037 .53195 L F
0 .211 .727 r
.38286 .56454 m .37953 .56334 L .38186 .56269 L F
.336 .155 .482 r
.17813 .57855 m .17997 .57788 L .18021 .57528 L F
.314 .184 .539 r
.17813 .57855 m .17987 .5805 L .17997 .57788 L F
.17813 .57855 m .17818 .58113 L .17987 .5805 L F
.312 .283 .665 r
.32333 .63998 m .32115 .64087 L .32083 .63761 L F
.173 0 .337 r
.32067 .6432 m .32115 .64087 L .32333 .63998 L F
0 0 0 r
.20252 .58045 m .20209 .58328 L .2018 .58472 L F
0 0 .505 r
.20209 .58328 m .20131 .58697 L .2018 .58472 L F
.758 .625 .713 r
.36452 .67496 m .36594 .67848 L .36191 .67819 L F
.591 .566 .795 r
.36576 .68143 m .36191 .67819 L .36594 .67848 L F
.658 .576 .752 r
.36852 .67822 m .36594 .67848 L .36452 .67496 L F
.737 .586 .687 r
.36852 .67822 m .36576 .68143 L .36594 .67848 L F
.762 .747 .838 r
.37824 .64729 m .37415 .64698 L .37568 .64413 L F
.767 .738 .827 r
.37824 .64729 m .37588 .64842 L .37415 .64698 L F
.457 .424 .733 r
.37807 .64987 m .37588 .64842 L .37824 .64729 L F
.835 .542 .494 r
.37568 .64413 m .38083 .647 L .37824 .64729 L F
.475 .212 .436 r
.38083 .647 m .37807 .64987 L .37824 .64729 L F
.082 0 0 r
.25736 .5297 m .25956 .52982 L .26159 .52978 L F
.037 0 0 r
.25956 .52982 m .26387 .52932 L .26159 .52978 L F
.468 .052 .168 r
.31057 .59649 m .31453 .59399 L .31028 .59529 L F
.31057 .59649 m .31318 .59586 L .31453 .59399 L F
.327 .228 .587 r
.31453 .59399 m .31652 .59316 L .31664 .58921 L F
.558 .304 .488 r
.31318 .59586 m .31652 .59316 L .31453 .59399 L F
0 .105 .66 r
.38089 .63411 m .38135 .63577 L .37994 .63332 L F
.431 .226 .499 r
.39114 .58815 m .39099 .59049 L .38878 .59101 L F
.583 .387 .581 r
.39099 .59049 m .38857 .59371 L .38878 .59101 L F
.974 .731 .507 r
.32087 .60166 m .32241 .60318 L .32259 .60045 L F
0 0 0 r
.3203 .55275 m .31934 .55306 L .32156 .55364 L F
.3203 .55275 m .3178 .55367 L .31934 .55306 L F
.551 .931 .847 r
.37626 .67966 m .37501 .6802 L .37768 .67844 L F
.312 .283 .665 r
.32333 .63998 m .32083 .63761 L .32323 .6375 L F
.8 .771 .262 r
.34313 .53698 m .34224 .54076 L .34252 .54068 L F
.744 .233 0 r
.34224 .54076 m .34371 .542 L .34252 .54068 L F
.118 0 0 r
.24396 .53289 m .24228 .53272 L .24037 .53363 L F
0 0 .051 r
.35682 .55282 m .35642 .55523 L .35555 .55673 L F
.913 .608 .452 r
.35368 .55885 m .35555 .55673 L .35313 .55558 L F
.35368 .55885 m .35593 .55948 L .35555 .55673 L F
.374 .266 .602 r
.31396 .63497 m .31555 .63682 L .31609 .63426 L F
.31396 .63497 m .31411 .63763 L .31555 .63682 L F
0 0 .471 r
.2701 .64046 m .27061 .63874 L .26789 .63711 L F
.2701 .64046 m .27074 .64201 L .27061 .63874 L F
.934 .96 .759 r
.32121 .5684 m .31919 .5709 L .32048 .5719 L F
.465 .35 .637 r
.31578 .57178 m .31815 .57395 L .31885 .57199 L F
.96 .946 .676 r
.31885 .57199 m .31815 .57395 L .31919 .5709 L F
.639 .233 .257 r
.31815 .57395 m .32048 .5719 L .31919 .5709 L F
.31815 .57395 m .32111 .57413 L .32048 .5719 L F
0 0 0 r
.32111 .57413 m .32284 .57248 L .32048 .5719 L F
.495 .27 .502 r
.3126 .64666 m .30979 .6498 L .31004 .64711 L F
.426 .779 .996 r
.26866 .52769 m .26791 .52896 L .2664 .52844 L F
.26866 .52769 m .27022 .52865 L .26791 .52896 L F
0 0 0 r
.34861 .62244 m .34846 .62195 L .3465 .62413 L F
.419 0 0 r
.34846 .62195 m .34993 .6219 L .34833 .62155 L F
.515 .915 .87 r
.3506 .62083 m .34993 .6219 L .34846 .62195 L F
0 0 0 r
.3506 .62083 m .34846 .62195 L .34861 .62244 L F
.419 0 0 r
.34846 .62195 m .34833 .62155 L .34615 .62108 L F
.582 .924 .72 r
.35227 .61999 m .34993 .6219 L .3506 .62083 L F
.137 0 0 r
.33962 .5524 m .34344 .54988 L .34089 .55014 L F
.808 .583 .597 r
.34454 .52242 m .34504 .52552 L .34244 .52501 L F
.785 .432 .388 r
.34504 .52552 m .34326 .52639 L .34244 .52501 L F
.557 .247 .397 r
.34244 .52501 m .34304 .52592 L .34454 .52242 L F
.378 .286 .624 r
.34677 .52438 m .34504 .52552 L .34454 .52242 L F
.576 .266 .406 r
.34454 .52242 m .34304 .52592 L .34677 .52438 L F
.286 .355 .759 r
.39543 .54009 m .39626 .54317 L .39498 .54408 L F
.063 .02 .491 r
.39626 .54317 m .39539 .54658 L .39498 .54408 L F
.521 .307 .53 r
.30184 .55062 m .30446 .5505 L .30475 .54757 L F
.018 .138 .648 r
.30184 .55062 m .30365 .5521 L .30446 .5505 L F
.347 .732 .985 r
.26395 .63614 m .26567 .63724 L .26789 .63711 L F
.684 .234 .179 r
.31581 .56918 m .31358 .57001 L .31175 .56871 L F
.426 .515 .846 r
.31578 .57178 m .31358 .57001 L .31581 .56918 L F
.373 .206 .522 r
.39256 .58126 m .39258 .58383 L .39052 .58422 L F
.854 .606 .563 r
.39256 .58126 m .3918 .58252 L .38963 .58085 L F
.861 .616 .567 r
.39205 .58124 m .3918 .58252 L .39256 .58126 L F
.867 .604 .538 r
.39256 .58126 m .39203 .58135 L .39205 .58124 L F
.738 .229 .009 r
.38954 .58179 m .3918 .58252 L .38963 .58085 L F
.867 .604 .538 r
.39248 .58125 m .39132 .5812 L .39126 .58108 L F
.39256 .58126 m .39247 .58126 L .39248 .58125 L F
.39247 .58126 m .38961 .58113 L .39248 .58125 L F
.861 .616 .567 r
.39255 .5786 m .39205 .58124 L .39256 .58126 L F
0 0 0 r
.39493 .57568 m .39365 .57797 L .39255 .5786 L F
0 0 .109 r
.39366 .57728 m .39255 .5786 L .39397 .57778 L F
.867 .604 .538 r
.39246 .58212 m .39258 .58383 L .39228 .58363 L F
.39257 .58205 m .39258 .58383 L .39246 .58212 L F
0 0 0 r
.39185 .58252 m .39175 .58258 L .3918 .58252 L F
.39185 .58252 m .3918 .58252 L .39182 .58244 L F
.738 .229 .009 r
.38954 .58179 m .39175 .58258 L .3918 .58252 L F
.867 .604 .538 r
.39144 .58146 m .39189 .58263 L .38954 .58179 L F
.39189 .58263 m .39228 .58363 L .38954 .58179 L F
.68 .137 0 r
.3911 .58331 m .39258 .58383 L .38954 .58179 L F
.738 .229 .009 r
.38954 .58179 m .3911 .58331 L .39175 .58258 L F
0 0 .109 r
.39203 .58135 m .3918 .58252 L .39205 .58124 L F
.867 .604 .538 r
.39246 .58128 m .39185 .58238 L .39203 .58135 L F
0 0 .109 r
.39192 .58219 m .39185 .58238 L .39203 .58135 L F
.39185 .58238 m .3918 .58252 L .39203 .58135 L F
.867 .604 .538 r
.39203 .58135 m .39182 .58244 L .39144 .58146 L F
.39185 .58238 m .39182 .58244 L .39203 .58135 L F
.859 .907 .497 r
.39182 .58244 m .3918 .58252 L .39185 .58238 L F
.867 .604 .538 r
.39256 .58126 m .39228 .58363 L .39182 .58244 L F
.39256 .58126 m .39182 .58244 L .39246 .58128 L F
.859 .907 .497 r
.39185 .58231 m .39182 .58244 L .39192 .58219 L F
.39182 .58244 m .39185 .58238 L .39192 .58219 L F
.509 .312 .548 r
.39501 .58079 m .39258 .58383 L .39256 .58126 L F
.39501 .58079 m .39258 .58383 L .39256 .58126 L F
0 0 0 r
.39323 .58232 m .3911 .58331 L .39175 .58258 L F
.39323 .58232 m .39175 .58258 L .39185 .58252 L F
.867 .604 .538 r
.39256 .58126 m .39257 .58205 L .39246 .58212 L F
0 0 0 r
.39194 .5825 m .39185 .58252 L .39185 .58231 L F
.39185 .58252 m .39182 .58244 L .39185 .58231 L F
0 0 .109 r
.39366 .57728 m .39192 .58219 L .39255 .5786 L F
.859 .907 .497 r
.3926 .5789 m .39226 .58045 L .39366 .57728 L F
.39226 .58045 m .39185 .58231 L .39298 .57915 L F
.39226 .58045 m .39298 .57915 L .39366 .57728 L F
0 0 0 r
.39511 .57545 m .39397 .57778 L .39374 .57781 L F
.39511 .57545 m .39365 .57797 L .39493 .57568 L F
.995 .847 .5 r
.39366 .57728 m .39397 .57778 L .39511 .57545 L F
0 .352 .817 r
.39366 .57728 m .39426 .57775 L .39397 .57778 L F
.39426 .57775 m .39741 .58022 L .39397 .57778 L F
0 0 0 r
.39374 .57781 m .39397 .57778 L .39365 .57797 L F
.859 .907 .497 r
.39185 .58231 m .39192 .58219 L .39366 .57728 L F
.562 .532 .78 r
.39397 .57778 m .39501 .58079 L .39256 .58126 L F
.39397 .57778 m .39501 .58079 L .39256 .58126 L F
0 0 0 r
.39323 .58232 m .39194 .5825 L .3926 .5789 L F
.39194 .5825 m .39185 .58231 L .3926 .5789 L F
.867 .604 .538 r
.39126 .58108 m .38961 .58113 L .38963 .58085 L F
.39132 .5812 m .38961 .58113 L .39126 .58108 L F
0 0 .109 r
.39192 .58219 m .39205 .58124 L .39255 .5786 L F
.867 .604 .538 r
.39205 .58124 m .38954 .58179 L .38961 .58113 L F
.39203 .58135 m .38954 .58179 L .39205 .58124 L F
0 0 0 r
.39511 .57545 m .39255 .5786 L .39119 .5751 L F
.34447 .54185 m .34681 .54153 L .34859 .54104 L F
.176 0 0 r
.34681 .54153 m .35069 .54016 L .34859 .54104 L F
.34716 .54141 m .34929 .54127 L .35069 .54016 L F
.34681 .54153 m .34929 .54127 L .34716 .54141 L F
.303 .117 .454 r
.35294 .53906 m .35069 .54016 L .35335 .53672 L F
.782 .408 .347 r
.35418 .54306 m .35069 .54016 L .35294 .53906 L F
.35418 .54306 m .34904 .54251 L .35069 .54016 L F
.651 .338 .429 r
.34929 .54127 m .35294 .53906 L .35069 .54016 L F
.303 .117 .454 r
.35294 .53906 m .35069 .54016 L .35335 .53672 L F
.651 .338 .429 r
.34929 .54127 m .35191 .54201 L .35294 .53906 L F
.426 .628 .938 r
.35106 .5405 m .35142 .54114 L .34929 .54126 L F
.537 .475 .735 r
.35578 .53812 m .35418 .54306 L .35294 .53906 L F
.347 .044 .301 r
.35294 .53906 m .35191 .54201 L .3542 .54124 L F
.577 .716 .937 r
.3542 .54124 m .35191 .54201 L .35089 .54019 L F
.35207 .53986 m .35089 .54019 L .3499 .53844 L F
.3542 .54124 m .35089 .54019 L .35207 .53986 L F
0 0 0 r
.35294 .53906 m .3552 .53706 L .35335 .53672 L F
.572 .354 .547 r
.35489 .53761 m .35294 .53906 L .35473 .53752 L F
.35578 .53812 m .35473 .53752 L .3552 .53706 L F
.35473 .53752 m .35335 .53672 L .3552 .53706 L F
0 0 0 r
.35473 .53752 m .35414 .53828 L .35501 .53728 L F
.35294 .53906 m .35358 .53864 L .35473 .53752 L F
.35294 .53906 m .35501 .53728 L .3552 .53706 L F
.572 .354 .547 r
.35473 .53752 m .35294 .53906 L .35335 .53672 L F
.35453 .53854 m .35294 .53906 L .35489 .53761 L F
.918 .542 .29 r
.35354 .53477 m .35335 .53672 L .35187 .53468 L F
.668 .456 .589 r
.35668 .53435 m .35335 .53672 L .35354 .53477 L F
.35668 .53435 m .3552 .53706 L .35335 .53672 L F
.287 .431 .832 r
.35335 .53672 m .35502 .53612 L .35187 .53468 L F
.344 .698 .983 r
.3552 .53706 m .35502 .53612 L .35335 .53672 L F
.863 .574 .496 r
.35414 .53828 m .35087 .53505 L .35502 .53612 L F
0 0 .201 r
.35426 .53853 m .35414 .53828 L .35308 .53706 L F
.537 .475 .735 r
.35578 .53812 m .35627 .54281 L .35418 .54306 L F
.279 .278 .679 r
.35801 .54136 m .35627 .54281 L .35591 .53941 L F
.35662 .53935 m .35591 .53941 L .35578 .53812 L F
.35801 .54136 m .35591 .53941 L .35662 .53935 L F
.35801 .54136 m .35578 .53812 L .35814 .53878 L F
.712 .474 .563 r
.36225 .54114 m .35801 .54136 L .35814 .53878 L F
.1 0 0 r
.35844 .5392 m .35641 .54033 L .35879 .53968 L F
.35814 .53878 m .35759 .53927 L .35844 .5392 L F
.35759 .53927 m .35641 .54033 L .35844 .5392 L F
.452 .288 .567 r
.35414 .53828 m .35419 .54107 L .35641 .54033 L F
.35419 .54107 m .3542 .54124 L .35641 .54033 L F
.35414 .53828 m .35641 .54033 L .35814 .53878 L F
.546 .817 .996 r
.35848 .53964 m .35641 .54033 L .35477 .53918 L F
.35879 .53968 m .35641 .54033 L .35848 .53964 L F
0 0 .201 r
.35477 .53918 m .3542 .54124 L .35414 .53828 L F
.35477 .53918 m .35414 .53828 L .35426 .53853 L F
0 0 0 r
.35408 .53816 m .35414 .53828 L .35473 .53752 L F
.35358 .53864 m .35414 .53828 L .35408 .53816 L F
.572 .354 .547 r
.35578 .53812 m .35453 .53854 L .35489 .53761 L F
.911 .899 .49 r
.35502 .53612 m .35414 .53828 L .35501 .53728 L F
.35517 .53687 m .35501 .53728 L .3552 .53706 L F
.35502 .53612 m .35501 .53728 L .35517 .53687 L F
.347 .044 .301 r
.35294 .53906 m .3542 .54124 L .35414 .53828 L F
.577 .716 .937 r
.35415 .53916 m .3499 .53844 L .35414 .53828 L F
.3542 .54124 m .35226 .53998 L .35415 .53916 L F
.35226 .53998 m .3499 .53844 L .35415 .53916 L F
0 0 0 r
.3489 .54143 m .35299 .53967 L .35259 .53984 L F
.34831 .54169 m .34873 .54151 L .3489 .54143 L F
.34873 .54151 m .35299 .53967 L .3489 .54143 L F
.378 0 0 r
.35038 .5408 m .35477 .53918 L .35406 .53929 L F
.35347 .53946 m .35406 .53929 L .35373 .53935 L F
.35038 .5408 m .35406 .53929 L .35347 .53946 L F
.35038 .5408 m .35302 .54068 L .35477 .53918 L F
0 0 0 r
.34923 .54129 m .35038 .5408 L .35299 .53967 L F
.34914 .54133 m .35038 .5408 L .34923 .54129 L F
.426 .628 .938 r
.3499 .53844 m .35106 .5405 L .34929 .54126 L F
.863 .574 .496 r
.35414 .53828 m .3499 .53844 L .35087 .53505 L F
.426 .628 .938 r
.3499 .53844 m .34929 .54127 L .34794 .54006 L F
.471 0 0 r
.34612 .53728 m .3499 .53844 L .34794 .54006 L F
.645 .339 .438 r
.35087 .53505 m .3499 .53844 L .35308 .53706 L F
.471 0 0 r
.34612 .53728 m .34885 .5385 L .3499 .53844 L F
.829 .631 .635 r
.34885 .5385 m .35308 .53706 L .3499 .53844 L F
.34885 .5385 m .35373 .53935 L .35308 .53706 L F
.488 .706 .967 r
.34794 .54006 m .34921 .5412 L .34681 .54153 L F
.34921 .5412 m .34929 .54127 L .34681 .54153 L F
0 0 0 r
.34831 .54169 m .35373 .53935 L .34885 .5385 L F
.622 .483 .671 r
.35269 .53798 m .35272 .53821 L .35038 .5408 L F
.35272 .53821 m .35302 .54068 L .35038 .5408 L F
0 0 0 r
.35201 .54006 m .35038 .5408 L .35205 .54008 L F
.35201 .54006 m .35195 .54013 L .35038 .5408 L F
.35205 .54008 m .35038 .5408 L .35302 .54068 L F
.426 .628 .938 r
.34929 .54126 m .35142 .54114 L .34929 .54127 L F
.35142 .54114 m .35191 .54201 L .34929 .54127 L F
.602 .404 .587 r
.35418 .54306 m .3503 .54649 L .34904 .54251 L F
.501 .503 .79 r
.34943 .54564 m .35038 .5408 L .34831 .54169 L F
.34943 .54564 m .35146 .54481 L .35038 .5408 L F
.461 .404 .707 r
.35146 .54481 m .35302 .54068 L .35038 .5408 L F
0 0 0 r
.35195 .54013 m .34961 .54268 L .35038 .5408 L F
.34831 .54169 m .35038 .5408 L .34914 .54133 L F
.35259 .53984 m .35299 .53967 L .35373 .53935 L F
.34371 .542 m .34681 .54153 L .34447 .54185 L F
.422 .708 .982 r
.28789 .52573 m .28726 .52733 L .2855 .52618 L F
.28789 .52573 m .2895 .52719 L .28726 .52733 L F
.783 .7 .772 r
.35354 .53477 m .34963 .5343 L .35211 .53108 L F
.458 0 0 r
.35187 .53468 m .35087 .53505 L .35103 .53476 L F
.918 .542 .29 r
.35234 .53463 m .35187 .53468 L .34963 .5343 L F
.523 .335 .568 r
.34963 .5343 m .35187 .53468 L .35211 .53108 L F
0 0 .139 r
.35211 .53108 m .35211 .53114 L .35268 .5318 L F
.35211 .53114 m .35187 .53468 L .35268 .5318 L F
.458 0 0 r
.35187 .53468 m .35103 .53476 L .35268 .5318 L F
.869 .949 .592 r
.35268 .5318 m .35087 .53505 L .35102 .53349 L F
.789 .515 .523 r
.35102 .53349 m .35293 .5321 L .35268 .5318 L F
.35293 .5321 m .35504 .53056 L .35268 .5318 L F
.918 .542 .29 r
.35354 .53477 m .35187 .53468 L .35234 .53463 L F
0 .233 .734 r
.28342 .54148 m .28391 .54082 L .28154 .54097 L F
.311 .797 .756 r
.28391 .54082 m .28321 .54104 L .28154 .54097 L F
.003 .562 .808 r
.28342 .54148 m .28154 .54097 L .28062 .54092 L F
.311 .797 .756 r
.28321 .54104 m .28033 .54198 L .28154 .54097 L F
.003 .562 .808 r
.28062 .54092 m .28154 .54097 L .27966 .54073 L F
0 .233 .734 r
.28342 .54148 m .28556 .54288 L .28391 .54082 L F
.137 0 0 r
.3025 .54006 m .29845 .54008 L .29985 .54048 L F
0 0 .395 r
.39864 .54974 m .40019 .5523 L .4006 .55321 L F
0 0 .386 r
.40019 .5523 m .40201 .55558 L .4006 .55321 L F
.464 .27 .533 r
.30446 .5505 m .30703 .54679 L .30475 .54757 L F
.518 .311 .539 r
.32908 .54091 m .33137 .54045 L .33163 .53766 L F
.847 .912 .879 r
.33326 .53454 m .33163 .53766 L .33041 .53664 L F
.494 .501 .793 r
.33137 .54045 m .33041 .53664 L .33163 .53766 L F
.995 .847 .5 r
.39366 .57728 m .39511 .57545 L .39572 .57367 L F
.767 .674 .76 r
.35501 .628 m .36004 .6285 L .36052 .62499 L F
0 0 0 r
.35965 .63033 m .36004 .6285 L .35501 .628 L F
.799 .486 .461 r
.36372 .62792 m .36052 .62499 L .36004 .6285 L F
.673 .172 .047 r
.31365 .53685 m .31825 .53792 L .31536 .53827 L F
.693 .674 .826 r
.31825 .53792 m .31598 .54052 L .31536 .53827 L F
.452 .265 .536 r
.3616 .60026 m .36395 .59977 L .36407 .597 L F
.421 .283 .586 r
.3616 .60026 m .36373 .60222 L .36395 .59977 L F
.3616 .60026 m .36218 .60312 L .36373 .60222 L F
.157 .146 .594 r
.31437 .60956 m .31563 .60574 L .31455 .60618 L F
.31437 .60956 m .31604 .60846 L .31563 .60574 L F
.092 0 .408 r
.31437 .60956 m .31597 .6111 L .31604 .60846 L F
.31437 .60956 m .31384 .61343 L .31597 .6111 L F
.9 .702 .626 r
.31514 .62442 m .31816 .6255 L .31789 .62257 L F
.421 .439 .773 r
.30833 .597 m .30945 .60092 L .31095 .59892 L F
.464 .5 .81 r
.30945 .60092 m .31452 .60254 L .31095 .59892 L F
.738 .562 .655 r
.52508 .54427 m .5251 .54706 L .52736 .54361 L F
.717 .534 .641 r
.52736 .54361 m .5251 .54706 L .52792 .54647 L F
.616 .527 .73 r
.52742 .54128 m .52736 .54361 L .5302 .54083 L F
.661 .596 .772 r
.35914 .6067 m .36301 .60832 L .36218 .60312 L F
.88 .678 .624 r
.35829 .60827 m .36301 .60832 L .35914 .6067 L F
.733 .5 .575 r
.36081 .69016 m .35668 .68696 L .36065 .68768 L F
.587 .376 .562 r
.27572 .55013 m .27825 .5501 L .27841 .54735 L F
.545 .335 .546 r
.27825 .5501 m .28093 .54684 L .27841 .54735 L F
.553 .542 .797 r
.28943 .63142 m .28701 .63207 L .28571 .62811 L F
.157 0 0 r
.2796 .55652 m .27571 .55886 L .2773 .55617 L F
.327 .04 .315 r
.19323 .55994 m .19536 .55925 L .1961 .55692 L F
.237 0 .275 r
.1961 .55692 m .19727 .55835 L .19809 .55622 L F
.1961 .55692 m .19536 .55925 L .19727 .55835 L F
.171 0 0 r
.28879 .55095 m .287 .55267 L .28496 .55245 L F
.18 0 .015 r
.287 .55267 m .28405 .55462 L .28496 .55245 L F
.678 .382 .465 r
.36847 .69068 m .36451 .69325 L .36462 .69099 L F
.36847 .69068 m .3667 .69356 L .36451 .69325 L F
.643 .34 .443 r
.37079 .69313 m .36847 .69068 L .37109 .69084 L F
.37079 .69313 m .3667 .69356 L .36847 .69068 L F
.592 .531 .755 r
.29444 .59109 m .29768 .59111 L .29571 .58757 L F
0 0 .029 r
.29444 .59109 m .29464 .59141 L .29768 .59111 L F
.666 .683 .856 r
.29464 .59141 m .29277 .59149 L .29492 .59053 L F
.29464 .59141 m .29492 .59053 L .29511 .59045 L F
0 0 .029 r
.29444 .59109 m .29422 .59275 L .29464 .59141 L F
.29422 .59275 m .29411 .59354 L .29464 .59141 L F
.133 .255 .725 r
.21764 .60464 m .21663 .60647 L .21555 .60265 L F
.257 .417 .831 r
.21764 .60464 m .21862 .60713 L .21663 .60647 L F
.529 .322 .544 r
.36841 .5723 m .37083 .57201 L .37103 .56917 L F
.51 .348 .597 r
.37083 .57201 m .37316 .5684 L .37103 .56917 L F
.066 .629 .771 r
.24233 .55023 m .23836 .55018 L .24009 .55006 L F
.549 .847 .998 r
.27155 .64248 m .27304 .64344 L .27326 .64258 L F
.698 .887 .967 r
.23725 .61075 m .23265 .61133 L .23572 .60995 L F
.74 .914 .952 r
.23725 .61075 m .23771 .60854 L .23943 .60965 L F
.23725 .61075 m .23572 .60995 L .23771 .60854 L F
.502 .593 .878 r
.24012 .6126 m .23725 .61075 L .23943 .60965 L F
.71 .925 .964 r
.30986 .55203 m .30779 .55338 L .30938 .55402 L F
.364 .129 .419 r
.30207 .68954 m .29975 .69011 L .29909 .69352 L F
.332 .789 .946 r
.27022 .52865 m .27274 .52828 L .27434 .52876 L F
.565 .904 .977 r
.27434 .52876 m .27499 .52734 L .27652 .52778 L F
.27434 .52876 m .27274 .52828 L .27499 .52734 L F
.983 .798 .393 r
.2903 .64091 m .29206 .64134 L .29182 .63754 L F
.34 0 0 r
.29319 .64198 m .29206 .64134 L .2903 .64091 L F
.29319 .64198 m .29484 .64277 L .29206 .64134 L F
.319 .179 .528 r
.37871 .63221 m .37918 .63655 L .38034 .63099 L F
.429 .213 .483 r
.37991 .63885 m .37795 .63672 L .37966 .63628 L F
.38034 .63717 m .37966 .63628 L .38064 .63603 L F
.37991 .63885 m .37966 .63628 L .38034 .63717 L F
.319 .179 .528 r
.38034 .63099 m .37933 .63585 L .37871 .63221 L F
.37933 .63585 m .37918 .63655 L .37907 .63551 L F
.37933 .63585 m .37907 .63551 L .37871 .63221 L F
.549 .746 .968 r
.32854 .62395 m .32801 .62572 L .32662 .62644 L F
.32854 .62395 m .33044 .6252 L .32801 .62572 L F
.578 .475 .701 r
.52377 .55412 m .52523 .54979 L .5226 .55019 L F
.52377 .55412 m .52635 .55353 L .52523 .54979 L F
.698 .732 .876 r
.36787 .64516 m .36354 .64402 L .36635 .64442 L F
.173 .41 .85 r
.36871 .64341 m .36787 .64516 L .36635 .64442 L F
.36871 .64341 m .37107 .64852 L .36787 .64516 L F
.652 .529 .701 r
.52117 .54383 m .5251 .54706 L .52508 .54427 L F
.52117 .54383 m .52242 .54754 L .5251 .54706 L F
.789 .713 .78 r
.53127 .54944 m .53367 .55151 L .53512 .54922 L F
.309 .451 .841 r
.39071 .53309 m .38941 .53486 L .38762 .53102 L F
.762 .249 0 r
.38941 .53486 m .39147 .53738 L .3932 .53802 L F
.145 .217 .681 r
.39071 .53309 m .39147 .53738 L .38941 .53486 L F
.237 .736 .907 r
.30019 .52532 m .29963 .52595 L .29793 .52571 L F
.30019 .52532 m .30169 .52567 L .29963 .52595 L F
.61 .623 .839 r
.3026 .52684 m .29963 .52595 L .30169 .52567 L F
.814 .792 .832 r
.37284 .64293 m .37107 .64852 L .36871 .64341 L F
.664 .721 .891 r
.32042 .53357 m .32449 .53415 L .32226 .53147 L F
.429 .571 .894 r
.32449 .53415 m .3249 .53111 L .32226 .53147 L F
.32449 .53415 m .32653 .53409 L .3249 .53111 L F
.746 .332 .264 r
.32322 .53499 m .32653 .53409 L .32449 .53415 L F
.821 .558 .54 r
.35766 .54794 m .36171 .54647 L .35651 .54581 L F
.571 .021 0 r
.35884 .54509 m .35651 .54581 L .36171 .54647 L F
.755 .713 .178 r
.35824 .54406 m .35766 .54794 L .35651 .54581 L F
.823 .382 0 r
.3575 .54765 m .35766 .54794 L .35777 .54654 L F
0 0 .462 r
.35717 .54744 m .35781 .54823 L .35766 .54794 L F
.755 .944 .943 r
.35622 .55032 m .35383 .55038 L .35766 .54794 L F
.823 .382 0 r
.35721 .54884 m .35766 .54794 L .3575 .54765 L F
0 0 .462 r
.35781 .54823 m .35876 .54942 L .35766 .54794 L F
.614 .953 .913 r
.23952 .53388 m .23496 .53548 L .23796 .53463 L F
.699 .724 .87 r
.32536 .52477 m .32165 .52437 L .32369 .52262 L F
.66 .823 .962 r
.32642 .52201 m .32536 .52477 L .32369 .52262 L F
.32642 .52201 m .32997 .52307 L .32536 .52477 L F
.211 .736 .822 r
.27652 .52778 m .27892 .5274 L .28048 .52742 L F
.358 .829 .877 r
.28048 .52742 m .28124 .52673 L .28305 .52686 L F
.28048 .52742 m .27892 .5274 L .28124 .52673 L F
.38 .26 .589 r
.31175 .56871 m .31219 .57195 L .31004 .57234 L F
0 0 .262 r
.31094 .5735 m .31004 .57234 L .31219 .57195 L F
.31094 .5735 m .30962 .57496 L .31004 .57234 L F
.232 .056 .426 r
.28075 .60871 m .28339 .60491 L .28116 .6064 L F
0 0 .258 r
.2419 .60931 m .24012 .6126 L .23943 .60965 L F
.2419 .60931 m .2417 .61157 L .24012 .6126 L F
0 0 .04 r
.24049 .61387 m .24012 .6126 L .2417 .61157 L F
.816 .98 .695 r
.24185 .60997 m .23932 .61349 L .24097 .61215 L F
.2418 .61053 m .24097 .61215 L .2417 .61157 L F
0 0 0 r
.24185 .60997 m .2417 .61157 L .2419 .60931 L F
.816 .98 .695 r
.24185 .60997 m .24097 .61215 L .2418 .61053 L F
0 0 .04 r
.24049 .61387 m .23916 .6159 L .23928 .61549 L F
.24035 .61339 m .23928 .61549 L .24012 .6126 L F
.24049 .61387 m .23928 .61549 L .24035 .61339 L F
0 0 .21 r
.29819 .59931 m .29771 .60189 L .29628 .60295 L F
0 0 0 r
.29771 .60189 m .29514 .60504 L .29628 .60295 L F
.069 0 0 r
.32514 .54337 m .32908 .54091 L .32478 .54087 L F
.27 0 0 r
.32908 .54091 m .33017 .54184 L .33137 .54045 L F
.704 .493 .599 r
.33005 .54145 m .32709 .5399 L .32929 .53901 L F
.33017 .54184 m .32973 .54156 L .33005 .54145 L F
.069 0 0 r
.32599 .54284 m .32828 .54205 L .32908 .54091 L F
.27 0 0 r
.32908 .54091 m .32787 .54264 L .33017 .54184 L F
.704 .493 .599 r
.32973 .54156 m .32709 .5399 L .33005 .54145 L F
.069 0 0 r
.32514 .54337 m .32779 .54266 L .32828 .54205 L F
.32514 .54337 m .32828 .54205 L .32599 .54284 L F
.704 .493 .599 r
.32973 .54156 m .32699 .54268 L .32709 .5399 L F
.33017 .54184 m .32844 .5423 L .32973 .54156 L F
.32844 .5423 m .32699 .54268 L .32973 .54156 L F
.069 0 0 r
.32779 .54266 m .32787 .54264 L .32789 .54261 L F
.32779 .54266 m .32789 .54261 L .32828 .54205 L F
.403 .171 .444 r
.37918 .6815 m .37858 .684 L .37664 .68436 L F
.387 .211 .517 r
.37858 .684 m .3767 .6871 L .37664 .68436 L F
.243 0 0 r
.35539 .56651 m .35857 .56667 L .36044 .56602 L F
.465 .274 .536 r
.36299 .56548 m .36053 .5688 L .36044 .56602 L F
.401 0 0 r
.35857 .56667 m .36299 .56548 L .36044 .56602 L F
.499 .246 .461 r
.3672 .58405 m .36564 .58402 L .36453 .58474 L F
.39 .475 .827 r
.36453 .58474 m .3672 .58661 L .3672 .58405 L F
.154 0 .051 r
.38014 .55109 m .38118 .55195 L .38144 .55121 L F
.38014 .55109 m .37921 .55267 L .38118 .55195 L F
.514 .273 .486 r
.36841 .5723 m .36803 .57477 L .37083 .57201 L F
.438 .855 .957 r
.23065 .61211 m .22657 .61238 L .22832 .61111 L F
.545 .883 .987 r
.23106 .61057 m .23065 .61211 L .22832 .61111 L F
.23106 .61057 m .23265 .61133 L .23065 .61211 L F
.811 .808 .321 r
.21333 .56825 m .21228 .57069 L .21217 .57264 L F
.818 .998 .782 r
.21228 .57069 m .21002 .57341 L .21217 .57264 L F
.88 .678 .624 r
.35829 .60827 m .36157 .61097 L .36301 .60832 L F
.729 .684 .807 r
.36301 .60832 m .36373 .60222 L .36218 .60312 L F
0 0 0 r
.36301 .60832 m .36436 .60682 L .36494 .60729 L F
.36301 .60832 m .36157 .61097 L .36436 .60682 L F
.188 0 .059 r
.2002 .55545 m .20364 .55234 L .2015 .55315 L F
.806 .494 .461 r
.30764 .57599 m .30661 .5777 L .30366 .57626 L F
.062 0 .02 r
.30962 .57496 m .30661 .5777 L .30764 .57599 L F
.221 .263 .694 r
.29087 .56788 m .29028 .57222 L .2884 .57118 L F
.29087 .56788 m .29164 .57157 L .29028 .57222 L F
.212 .241 .675 r
.29164 .57157 m .29237 .57426 L .29028 .57222 L F
.365 .262 .603 r
.29237 .57426 m .29059 .5751 L .29028 .57222 L F
0 0 0 r
.28405 .55462 m .28231 .55588 L .28198 .55628 L F
.279 .762 .923 r
.28174 .55658 m .28198 .55628 L .2796 .55652 L F
.04 0 0 r
.2802 .55741 m .2796 .55652 L .28198 .55628 L F
0 0 0 r
.28231 .55588 m .2802 .55741 L .28198 .55628 L F
.279 .762 .923 r
.2836 .55664 m .28198 .55628 L .28174 .55658 L F
.728 .945 .953 r
.28405 .55462 m .28198 .55628 L .2836 .55664 L F
.002 0 .319 r
.31208 .54866 m .31095 .54771 L .31331 .54724 L F
.31208 .54866 m .3108 .55008 L .31095 .54771 L F
.697 .697 .847 r
.38186 .56269 m .38286 .5645 L .3856 .5636 L F
.676 .284 .296 r
.34924 .6785 m .35137 .68059 L .34748 .68031 L F
.486 .31 .568 r
.35155 .67786 m .35137 .68059 L .34924 .6785 L F
.732 .99 .871 r
.34748 .68031 m .35155 .67786 L .34924 .6785 L F
.092 .233 .718 r
.37079 .5179 m .36986 .51974 L .36891 .51693 L F
.486 .73 .979 r
.37079 .5179 m .37217 .51981 L .36986 .51974 L F
.297 .646 .968 r
.34186 .53581 m .33945 .53646 L .33909 .53577 L F
.34186 .53581 m .34313 .53698 L .33945 .53646 L F
.409 .156 .416 r
.3107 .64245 m .31154 .64079 L .3089 .64316 L F
0 0 0 r
.3107 .64245 m .3089 .64316 L .3073 .64399 L F
.734 .421 .45 r
.36462 .69099 m .36048 .69302 L .36081 .69016 L F
.36462 .69099 m .36451 .69325 L .36048 .69302 L F
0 0 0 r
.2553 .6343 m .25382 .63491 L .25157 .63538 L F
.304 0 0 r
.2553 .6343 m .25556 .63464 L .25382 .63491 L F
.2553 .6343 m .25757 .63505 L .25556 .63464 L F
.904 .634 .518 r
.31514 .62442 m .31761 .62777 L .31816 .6255 L F
0 .03 .601 r
.22311 .62217 m .22332 .62082 L .22157 .61854 L F
0 .116 .668 r
.22311 .62217 m .22513 .62434 L .22332 .62082 L F
0 .325 .811 r
.35701 .58784 m .35823 .59001 L .35482 .58733 L F
.505 .434 .711 r
.35823 .59001 m .35601 .59115 L .35482 .58733 L F
.977 .724 .483 r
.37161 .58292 m .37336 .58422 L .37354 .5816 L F
.055 0 .377 r
.37354 .5816 m .37463 .58291 L .37603 .58106 L F
.37402 .58218 m .37336 .58422 L .37463 .58291 L F
.37354 .5816 m .37347 .5827 L .37402 .58218 L F
.37347 .5827 m .37336 .58422 L .37402 .58218 L F
.073 0 0 r
.37231 .58262 m .37354 .5816 L .37603 .58106 L F
.37161 .58292 m .3719 .58272 L .37231 .58262 L F
.3719 .58272 m .37354 .5816 L .37231 .58262 L F
.37454 .58168 m .37509 .58116 L .37366 .58131 L F
.569 .777 .977 r
.37366 .58131 m .37419 .58218 L .37684 .58131 L F
.37419 .58218 m .37463 .58291 L .37635 .58167 L F
.37419 .58218 m .37635 .58167 L .37684 .58131 L F
.073 0 0 r
.37161 .58292 m .37454 .58168 L .37366 .58131 L F
.37454 .58168 m .37603 .58106 L .37509 .58116 L F
.169 .7 .695 r
.25101 .53106 m .25336 .5305 L .2549 .53015 L F
.211 .73 .715 r
.2549 .53015 m .25561 .52989 L .25736 .5297 L F
.2549 .53015 m .25336 .5305 L .25561 .52989 L F
.3 .289 .679 r
.39317 .58636 m .39114 .58815 L .39052 .58422 L F
.16 .011 .416 r
.39292 .58872 m .39114 .58815 L .39317 .58636 L F
.39292 .58872 m .39099 .59049 L .39114 .58815 L F
0 0 .113 r
.22822 .78685 m .22681 .7877 L .22889 .78713 L F
0 0 0 r
.22681 .7877 m .22822 .78685 L .22889 .78713 L F
0 .49 .734 r
.25318 .55135 m .25119 .55086 L .24862 .55043 L F
.045 .306 .794 r
.25318 .55135 m .25311 .54902 L .25119 .55086 L F
.181 .709 .852 r
.30811 .52607 m .31021 .52592 L .31282 .52622 L F
.586 .926 .96 r
.31282 .52622 m .31188 .52485 L .31509 .5252 L F
.31282 .52622 m .31021 .52592 L .31188 .52485 L F
.742 .776 .88 r
.37533 .63732 m .37392 .63539 L .37632 .63465 L F
.719 .205 0 r
.37609 .63543 m .37632 .63465 L .37392 .63539 L F
.37609 .63543 m .37795 .63672 L .37632 .63465 L F
.618 .316 .436 r
.37632 .63465 m .37795 .63672 L .37918 .63655 L F
.729 .754 .246 r
.25544 .74607 m .25432 .75026 L .25462 .74878 L F
.286 0 0 r
.25432 .75026 m .2566 .74999 L .25497 .75175 L F
.217 0 .297 r
.25432 .75026 m .25692 .74695 L .2566 .74999 L F
.286 0 0 r
.25432 .75026 m .25497 .75175 L .25462 .74878 L F
.355 0 .038 r
.37387 .61295 m .36994 .61507 L .36973 .61245 L F
.37387 .61295 m .37273 .61464 L .36994 .61507 L F
.472 .064 .185 r
.37683 .61404 m .37273 .61464 L .37387 .61295 L F
.386 .103 .356 r
.37559 .61336 m .37683 .61404 L .37387 .61295 L F
.758 .658 .751 r
.5302 .54083 m .53219 .54388 L .53235 .54373 L F
.606 .408 .587 r
.53219 .54388 m .53204 .5473 L .53235 .54373 L F
.455 .288 .566 r
.35742 .64367 m .35523 .64635 L .35489 .64433 L F
.691 .863 .964 r
.36452 .67496 m .36059 .67476 L .36309 .67219 L F
.36452 .67496 m .36199 .67537 L .36059 .67476 L F
.758 .625 .713 r
.36452 .67496 m .36191 .67819 L .36199 .67537 L F
.71 .753 .886 r
.36669 .67256 m .36452 .67496 L .36309 .67219 L F
.635 .626 .825 r
.36669 .67256 m .36825 .67593 L .36452 .67496 L F
.658 .576 .752 r
.36852 .67822 m .36452 .67496 L .36825 .67593 L F
.3 .289 .679 r
.39317 .58636 m .39052 .58422 L .39258 .58383 L F
.658 .451 .592 r
.52792 .54647 m .53204 .5473 L .53219 .54388 L F
0 0 0 r
.30373 .65564 m .30803 .6534 L .30756 .65531 L F
0 0 .241 r
.30803 .6534 m .30979 .6498 L .30964 .65295 L F
.176 0 .301 r
.30756 .65531 m .30803 .6534 L .30964 .65295 L F
.356 0 0 r
.24646 .54998 m .2441 .55109 L .24233 .55023 L F
.55 .037 0 r
.24862 .55043 m .2441 .55109 L .24646 .54998 L F
.71 .175 0 r
.39147 .53738 m .39543 .54009 L .3932 .53802 L F
0 0 .059 r
.32313 .61168 m .32306 .61069 L .32419 .60957 L F
.32313 .61168 m .32183 .61289 L .32306 .61069 L F
.16 .287 .746 r
.36184 .52518 m .36172 .5213 L .3601 .52118 L F
.36184 .52518 m .36309 .52459 L .36172 .5213 L F
.084 .092 .569 r
.36184 .52518 m .36337 .52724 L .36309 .52459 L F
.129 0 0 r
.33137 .54045 m .33017 .54184 L .33241 .54121 L F
.528 .54 .811 r
.33241 .54121 m .33017 .54184 L .32929 .53901 L F
.639 .877 .524 r
.33049 .54118 m .33015 .5416 L .33017 .54184 L F
.652 .756 .926 r
.32787 .54264 m .32959 .54666 L .33156 .54435 L F
.32787 .54264 m .33156 .54435 L .33017 .54184 L F
.722 .673 .801 r
.32514 .54337 m .32768 .54524 L .32787 .54264 L F
.32768 .54524 m .32848 .54407 L .32787 .54264 L F
0 0 .479 r
.3283 .54388 m .32699 .54268 L .33017 .54184 L F
.393 0 .012 r
.33017 .54184 m .3283 .54388 L .32699 .54268 L F
.639 .877 .524 r
.33015 .5416 m .3283 .54388 L .32948 .5426 L F
.33015 .5416 m .32948 .5426 L .33017 .54184 L F
.722 .673 .801 r
.32768 .54524 m .32959 .54666 L .32848 .54407 L F
.32514 .54337 m .32684 .54721 L .32959 .54666 L F
.6 .695 .91 r
.32959 .54666 m .33405 .54622 L .33156 .54435 L F
.018 .146 .657 r
.31614 .57435 m .31711 .57866 L .31839 .57673 L F
0 0 0 r
.31688 .58044 m .31839 .57673 L .31711 .57866 L F
.499 .246 .461 r
.3672 .58405 m .36801 .58194 L .36564 .58402 L F
0 0 0 r
.36914 .58006 m .36801 .58194 L .3672 .58405 L F
.742 .529 .606 r
.36818 .61287 m .36374 .61455 L .36359 .61349 L F
.656 .415 .543 r
.28746 .55972 m .28726 .56235 L .28972 .56218 L F
.791 .673 .734 r
.53204 .5473 m .53512 .54922 L .53603 .54779 L F
.53204 .5473 m .53127 .54944 L .53512 .54922 L F
.755 .624 .715 r
.32358 .54612 m .32684 .54721 L .32514 .54337 L F
.32358 .54612 m .32439 .54785 L .32684 .54721 L F
.761 .651 .74 r
.32439 .54785 m .32441 .55053 L .32684 .54721 L F
.476 .136 .309 r
.27168 .55365 m .27398 .55426 L .27572 .55013 L F
.031 0 .091 r
.27572 .55013 m .27628 .55216 L .27825 .5501 L F
.27572 .55013 m .27398 .55426 L .27628 .55216 L F
.469 .296 .563 r
.32919 .64715 m .33145 .64911 L .33122 .64682 L F
.32919 .64715 m .32921 .64984 L .33145 .64911 L F
.491 .14 .299 r
.38175 .60609 m .38097 .60849 L .37854 .6088 L F
.152 0 .247 r
.38473 .60332 m .38382 .60552 L .38175 .60609 L F
.12 0 .15 r
.38382 .60552 m .38097 .60849 L .38175 .60609 L F
.609 .373 .535 r
.30345 .58751 m .30299 .5904 L .30048 .59008 L F
.505 .61 .89 r
.30342 .58394 m .30553 .58707 L .30345 .58751 L F
0 .097 .628 r
.34609 .55264 m .34663 .55566 L .34659 .55326 L F
.34583 .55265 m .34663 .55566 L .34609 .55264 L F
.739 .634 .743 r
.34336 .55534 m .34663 .55566 L .3457 .55215 L F
.718 .92 .573 r
.34427 .55356 m .34336 .55534 L .3451 .55297 L F
.34427 .55356 m .3451 .55297 L .3457 .55215 L F
.853 .937 .564 r
.34273 .5545 m .34336 .55534 L .34427 .55356 L F
.672 .295 .323 r
.34644 .55301 m .3433 .55427 L .34427 .55356 L F
.3433 .55427 m .34288 .55443 L .34427 .55356 L F
0 0 0 r
.34659 .55262 m .34644 .55301 L .34427 .55356 L F
.726 .219 .023 r
.34409 .55018 m .3457 .55215 L .34579 .55209 L F
.34468 .55046 m .34583 .55214 L .34785 .55194 L F
.34409 .55018 m .34583 .55214 L .34468 .55046 L F
.34344 .54988 m .3457 .55215 L .34409 .55018 L F
.694 .273 .242 r
.34344 .54988 m .3418 .55178 L .3457 .55215 L F
.659 .199 .149 r
.3418 .55178 m .34427 .55356 L .3457 .55215 L F
.884 .951 .6 r
.34553 .55101 m .3446 .55291 L .3457 .55215 L F
.3446 .55291 m .34427 .55356 L .3457 .55215 L F
.726 .219 .023 r
.34579 .55209 m .3457 .55215 L .34583 .55214 L F
0 0 0 r
.34793 .55208 m .34744 .55239 L .34659 .55262 L F
.34744 .55239 m .34671 .55262 L .34659 .55262 L F
.34708 .55261 m .34702 .55265 L .34659 .55262 L F
0 .134 .67 r
.34659 .55326 m .34699 .55264 L .34658 .55262 L F
0 0 0 r
.34702 .55265 m .34644 .55301 L .34659 .55262 L F
.34702 .55265 m .34659 .55262 L .34659 .55262 L F
0 .134 .67 r
.34659 .55326 m .34769 .55411 L .34699 .55264 L F
0 0 0 r
.34593 .55215 m .34427 .55356 L .3457 .55215 L F
0 .097 .628 r
.3457 .55215 m .34659 .55326 L .34658 .55262 L F
0 0 0 r
.34793 .55208 m .34659 .55262 L .34593 .55215 L F
.34659 .55262 m .34658 .55262 L .34593 .55215 L F
0 .097 .628 r
.3457 .55215 m .34658 .55262 L .34657 .55178 L F
0 0 0 r
.34659 .55262 m .34659 .55262 L .34658 .55262 L F
0 .134 .67 r
.34658 .55262 m .34659 .55262 L .34658 .55262 L F
0 .097 .628 r
.3457 .55215 m .34583 .55265 L .34609 .55264 L F
0 0 0 r
.34659 .55262 m .34427 .55356 L .34593 .55215 L F
0 .134 .67 r
.34658 .55262 m .34699 .55264 L .34657 .55178 L F
.34659 .55262 m .34699 .55264 L .34658 .55262 L F
.34663 .55566 m .34743 .55449 L .34659 .55326 L F
.34743 .55449 m .34769 .55411 L .34659 .55326 L F
.96 .706 .509 r
.34785 .55194 m .34857 .55059 L .34955 .55164 L F
.34785 .55194 m .34586 .54947 L .34857 .55059 L F
.34785 .55194 m .3457 .55215 L .34586 .54947 L F
.555 .665 .91 r
.35131 .55182 m .34785 .55194 L .34955 .55164 L F
.539 .632 .891 r
.35031 .54975 m .34955 .55164 L .34857 .55059 L F
.712 .576 .7 r
.34834 .54847 m .34586 .54947 L .34511 .54736 L F
.34834 .54847 m .34857 .55059 L .34586 .54947 L F
.869 .824 .349 r
.3457 .55215 m .34599 .55007 L .34586 .54947 L F
.34599 .55007 m .34631 .54787 L .34598 .54906 L F
.34599 .55007 m .34598 .54906 L .34586 .54947 L F
0 .097 .628 r
.3457 .55215 m .34657 .55178 L .34793 .55208 L F
.856 .431 .214 r
.34602 .55127 m .34744 .55239 L .34793 .55208 L F
.869 .824 .349 r
.3457 .55215 m .34553 .55101 L .34631 .54787 L F
.856 .431 .214 r
.34553 .55101 m .34591 .55118 L .3505 .55132 L F
.34591 .55118 m .34793 .55208 L .3505 .55132 L F
.34601 .55123 m .34602 .55127 L .34793 .55208 L F
.664 .646 .822 r
.34657 .55178 m .3505 .55132 L .34793 .55208 L F
.34665 .55177 m .34752 .55236 L .3505 .55132 L F
.34657 .55178 m .347 .55204 L .34665 .55177 L F
.347 .55204 m .34752 .55236 L .34665 .55177 L F
0 0 0 r
.34744 .55239 m .34725 .55251 L .34671 .55262 L F
.877 .569 .462 r
.34769 .55411 m .34752 .55236 L .34699 .55264 L F
0 0 0 r
.34725 .55251 m .34708 .55261 L .34705 .55261 L F
.34725 .55251 m .34705 .55261 L .34671 .55262 L F
.877 .569 .462 r
.34769 .55411 m .35053 .55421 L .34752 .55236 L F
.34699 .55264 m .34725 .55251 L .34657 .55178 L F
.856 .431 .214 r
.34602 .55127 m .34644 .55301 L .34725 .55251 L F
.347 .55204 m .34725 .55251 L .34744 .55239 L F
.877 .569 .462 r
.34725 .55251 m .347 .55204 L .34657 .55178 L F
.856 .431 .214 r
.34602 .55127 m .34725 .55251 L .347 .55204 L F
.877 .569 .462 r
.34725 .55251 m .34752 .55236 L .347 .55204 L F
.856 .431 .214 r
.34553 .55101 m .34602 .55209 L .34601 .55123 L F
.34602 .55209 m .34644 .55301 L .34601 .55123 L F
.664 .646 .822 r
.34752 .55236 m .35053 .55421 L .3505 .55141 L F
.34752 .55236 m .3505 .55141 L .3505 .55132 L F
.465 .392 .69 r
.32132 .58351 m .31933 .58822 L .31583 .58453 L F
.32132 .58351 m .32189 .58754 L .31933 .58822 L F
.234 .107 .494 r
.32189 .58754 m .32001 .59059 L .31933 .58822 L F
.609 .439 .627 r
.3811 .68057 m .37858 .684 L .37918 .6815 L F
0 0 0 r
.36064 .65705 m .35857 .65878 L .36305 .65598 L F
.323 .309 .689 r
.21518 .56484 m .21333 .56825 L .21371 .56553 L F
.21518 .56484 m .21587 .56844 L .21333 .56825 L F
.314 0 .029 r
.21487 .56984 m .21333 .56825 L .21587 .56844 L F
.21487 .56984 m .21228 .57069 L .21333 .56825 L F
.444 .251 .523 r
.31303 .58766 m .31524 .58706 L .31519 .58446 L F
.514 .547 .827 r
.31303 .58766 m .31664 .58921 L .31524 .58706 L F
0 0 0 r
.26744 .72833 m .26889 .72752 L .26998 .72717 L F
.26744 .72833 m .26889 .72752 L .26998 .72717 L F
.422 0 0 r
.22273 .61181 m .22455 .61169 L .22297 .60919 L F
.22273 .61181 m .22657 .61238 L .22455 .61169 L F
.741 .359 .329 r
.35009 .58641 m .35411 .58691 L .35229 .58462 L F
.794 .298 0 r
.25681 .74879 m .25692 .74695 L .25544 .74607 L F
.561 .36 .565 r
.25692 .74695 m .25908 .74985 L .2566 .74999 L F
.794 .298 0 r
.25681 .74879 m .25908 .74985 L .25692 .74695 L F
0 0 .206 r
.2152 .59293 m .21437 .5962 L .21366 .59437 L F
.2152 .59293 m .21498 .5963 L .21437 .5962 L F
0 0 .424 r
.21498 .5963 m .21558 .5988 L .21437 .5962 L F
0 0 .45 r
.21558 .5988 m .21469 .60043 L .21437 .5962 L F
.429 .334 .646 r
.36574 .59096 m .36784 .5904 L .3672 .58661 L F
.44 .372 .684 r
.36574 .59096 m .36838 .59324 L .36784 .5904 L F
.499 .373 .639 r
.36607 .59374 m .36838 .59324 L .36574 .59096 L F
.216 0 0 r
.26303 .62331 m .26759 .62159 L .26527 .62204 L F
.737 .586 .687 r
.36852 .67822 m .36943 .68205 L .36576 .68143 L F
.616 .532 .737 r
.37052 .67512 m .36852 .67822 L .36825 .67593 L F
.585 .492 .715 r
.37052 .67512 m .37144 .67786 L .36852 .67822 L F
.554 .47 .715 r
.37211 .68122 m .36852 .67822 L .37144 .67786 L F
.37211 .68122 m .36943 .68205 L .36852 .67822 L F
.606 .531 .743 r
.28748 .62519 m .28571 .62811 L .28449 .62688 L F
.553 .542 .797 r
.28943 .63142 m .28571 .62811 L .28748 .62519 L F
.555 .504 .753 r
.29106 .62633 m .28943 .63142 L .28748 .62519 L F
.627 .412 .571 r
.29054 .62442 m .29106 .62633 L .28748 .62519 L F
0 0 0 r
.28801 .62477 m .28632 .6267 L .28847 .62533 L F
.627 .412 .571 r
.29054 .62442 m .28748 .62519 L .28797 .62472 L F
0 0 0 r
.28797 .62472 m .28785 .62486 L .28801 .62477 L F
.28785 .62486 m .28632 .6267 L .28801 .62477 L F
.606 .531 .743 r
.28727 .62521 m .28449 .62688 L .28324 .62562 L F
.28748 .62519 m .28449 .62688 L .28727 .62521 L F
.28659 .62507 m .28324 .62562 L .28207 .62443 L F
.28748 .62519 m .28324 .62562 L .28659 .62507 L F
.28748 .62519 m .28207 .62443 L .28797 .62472 L F
.394 0 .115 r
.28439 .62664 m .28632 .6267 L .28785 .62486 L F
.28765 .62489 m .28785 .62486 L .28797 .62472 L F
.28439 .62664 m .28785 .62486 L .28765 .62489 L F
.28439 .62664 m .28394 .62632 L .28571 .62811 L F
.579 .555 .792 r
.28571 .62811 m .28211 .62486 L .28439 .62664 L F
.382 0 0 r
.28214 .62708 m .28468 .62685 L .28439 .62664 L F
.28468 .62685 m .28632 .6267 L .28439 .62664 L F
.394 0 .115 r
.28439 .62664 m .28207 .62443 L .28394 .62632 L F
.28439 .62664 m .28797 .62472 L .28207 .62443 L F
.323 0 .02 r
.38433 .56186 m .38685 .56143 L .38803 .55966 L F
0 0 0 r
.38803 .55966 m .39083 .55625 L .38684 .55603 L F
.38803 .55966 m .38951 .5583 L .39083 .55625 L F
.38803 .55966 m .38685 .56143 L .38951 .5583 L F
.022 0 .101 r
.37754 .55382 m .37665 .55579 L .37921 .55267 L F
.035 0 .16 r
.19323 .55994 m .19406 .56095 L .19536 .55925 L F
.19323 .55994 m .19248 .56206 L .19406 .56095 L F
.471 .216 .444 r
.32758 .55817 m .32572 .55631 L .32812 .556 L F
.32758 .55817 m .32517 .55882 L .32572 .55631 L F
.99 .822 .58 r
.32441 .55053 m .32325 .54935 L .3265 .54992 L F
.32441 .55053 m .32259 .55146 L .32325 .54935 L F
.408 .188 .465 r
.3378 .61539 m .3403 .61213 L .33801 .61271 L F
.154 0 0 r
.26834 .55923 m .26609 .55996 L .2641 .55997 L F
.232 0 0 r
.27072 .55981 m .26609 .55996 L .26834 .55923 L F
.009 .166 .68 r
.36373 .60222 m .36494 .60729 L .36591 .60452 L F
.797 .962 .645 r
.36591 .60452 m .36494 .60729 L .36436 .60682 L F
.822 .626 .638 r
.37501 .6802 m .37144 .67786 L .373 .67716 L F
.37501 .6802 m .37211 .68122 L .37144 .67786 L F
.857 .824 .814 r
.37501 .6802 m .37224 .68309 L .37211 .68122 L F
.755 .6 .685 r
.373 .67716 m .37768 .67844 L .37501 .6802 L F
.454 .884 .876 r
.36244 .51567 m .36299 .51484 L .36447 .51575 L F
.36244 .51567 m .36092 .51575 L .36299 .51484 L F
.211 .45 .871 r
.33027 .6379 m .33342 .63986 L .33102 .63617 L F
.519 .458 .728 r
.33027 .6379 m .33123 .64074 L .33342 .63986 L F
.659 .31 .37 r
.33431 .57422 m .32973 .5748 L .33172 .57161 L F
.596 .229 .316 r
.33431 .57422 m .33137 .57603 L .32973 .5748 L F
.33431 .57422 m .33181 .57651 L .33137 .57603 L F
.077 .358 .828 r
.33137 .57603 m .33193 .57619 L .33133 .57443 L F
.914 .972 .787 r
.332 .57669 m .33196 .57644 L .33597 .57479 L F
.569 .932 .785 r
.33597 .57479 m .33181 .57651 L .33684 .57364 L F
.396 0 .139 r
.33684 .57364 m .33181 .57651 L .33431 .57422 L F
.077 .358 .828 r
.33193 .57619 m .3326 .57638 L .33177 .57511 L F
.33193 .57619 m .33177 .57511 L .33133 .57443 L F
.914 .972 .787 r
.33297 .57761 m .332 .57669 L .33597 .57479 L F
.332 .57669 m .33181 .57651 L .33196 .57644 L F
0 0 0 r
.33597 .57479 m .33684 .57364 L .33855 .57121 L F
.44 .503 .828 r
.28726 .56235 m .28872 .56601 L .29029 .56423 L F
.58 .246 .367 r
.29177 .56591 m .29087 .56788 L .28872 .56601 L F
.282 .269 .667 r
.28872 .56601 m .29087 .56788 L .29029 .56423 L F
.651 .522 .694 r
.52242 .54754 m .5226 .55019 L .5251 .54706 L F
.4 .254 .566 r
.29283 .58475 m .29504 .58127 L .29132 .58126 L F
.29283 .58475 m .29492 .58409 L .29504 .58127 L F
.455 .409 .718 r
.29283 .58475 m .29558 .58647 L .29492 .58409 L F
0 .07 .604 r
.31519 .58446 m .31688 .58044 L .31844 .58218 L F
.052 0 0 r
.31844 .58218 m .31583 .58453 L .31519 .58446 L F
.444 .465 .787 r
.32001 .58 m .31844 .58218 L .31688 .58044 L F
.32001 .58 m .32132 .58351 L .31844 .58218 L F
.615 .305 .422 r
.32132 .58351 m .31583 .58453 L .31844 .58218 L F
.02 .534 .866 r
.31541 .55835 m .31953 .55991 L .31694 .55855 L F
.328 .036 .308 r
.37087 .5605 m .37272 .56017 L .37459 .5566 L F
.217 0 .24 r
.37459 .5566 m .37618 .55823 L .37665 .55579 L F
.37459 .5566 m .37272 .56017 L .37618 .55823 L F
0 0 .435 r
.2156 .6013 m .21469 .60043 L .21558 .5988 L F
.2156 .6013 m .21555 .60265 L .21469 .60043 L F
.674 .81 .948 r
.20586 .59058 m .20335 .5915 L .20168 .59017 L F
.395 .234 .541 r
.36407 .597 m .36614 .59633 L .36607 .59374 L F
.417 .237 .527 r
.36407 .597 m .36626 .59887 L .36614 .59633 L F
.36407 .597 m .36395 .59977 L .36626 .59887 L F
.464 .292 .562 r
.262 .74087 m .26422 .73748 L .26403 .74019 L F
.504 .838 .998 r
.25988 .7399 m .262 .74087 L .26403 .74019 L F
.411 .236 .531 r
.2639 .74295 m .262 .74087 L .26403 .74019 L F
.181 .03 .427 r
.18021 .57528 m .18129 .57711 L .18156 .57445 L F
.18021 .57528 m .17997 .57788 L .18129 .57711 L F
.51 .292 .519 r
.34943 .51619 m .35172 .51802 L .35191 .51547 L F
.801 .427 .348 r
.26884 .62884 m .27117 .63048 L .2731 .62854 L F
.142 0 .307 r
.27538 .62501 m .2731 .62854 L .27494 .62704 L F
.505 .188 .364 r
.27117 .63048 m .27494 .62704 L .2731 .62854 L F
.568 .767 .972 r
.30455 .52593 m .3026 .52684 L .30169 .52567 L F
.296 0 .098 r
.34317 .6382 m .3423 .63988 L .34026 .64023 L F
.618 .215 .256 r
.34317 .6382 m .34535 .63993 L .3423 .63988 L F
.55 .048 .016 r
.25215 .6232 m .25079 .62439 L .25465 .62427 L F
.725 .519 .612 r
.38684 .55603 m .39083 .55625 L .39026 .55405 L F
.067 0 0 r
.38908 .55526 m .38684 .55603 L .39026 .55405 L F
.585 .434 .643 r
.39026 .55405 m .39251 .55583 L .392 .55411 L F
.39026 .55405 m .39083 .55625 L .39251 .55583 L F
.119 0 0 r
.392 .55411 m .38908 .55526 L .39026 .55405 L F
.374 .25 .581 r
.17765 .59432 m .17956 .59381 L .17923 .59098 L F
.284 .221 .608 r
.17836 .59615 m .17956 .59381 L .17765 .59432 L F
.375 .067 .309 r
.33478 .56874 m .33425 .57132 L .33172 .57161 L F
.508 .181 .348 r
.33655 .57089 m .33478 .56874 L .33735 .5676 L F
.33655 .57089 m .33425 .57132 L .33478 .56874 L F
.979 .8 .591 r
.33072 .52383 m .33104 .52798 L .33215 .52594 L F
.923 .552 .294 r
.34849 .6066 m .34867 .60703 L .34838 .60658 L F
.263 .674 .967 r
.33888 .55584 m .33902 .5547 L .3359 .55414 L F
.896 .648 .554 r
.34102 .55569 m .33902 .5547 L .33888 .55584 L F
.631 .649 .849 r
.30893 .62745 m .31242 .62917 L .31097 .62853 L F
.449 .788 .998 r
.31242 .62917 m .31408 .62801 L .31097 .62853 L F
.31242 .62917 m .31488 .62867 L .31408 .62801 L F
0 .07 .604 r
.31519 .58446 m .31449 .58126 L .31688 .58044 L F
.31519 .58446 m .31609 .58368 L .31449 .58126 L F
.109 .001 .438 r
.31519 .58446 m .31694 .58577 L .31609 .58368 L F
.289 0 0 r
.32226 .53147 m .31858 .53262 L .32042 .53357 L F
.455 .288 .566 r
.35742 .64367 m .35731 .64652 L .35523 .64635 L F
.121 0 0 r
.26426 .54708 m .26101 .54859 L .262 .54774 L F
0 0 .224 r
.32601 .63681 m .32615 .63394 L .32704 .63354 L F
.605 .944 .936 r
.24614 .53225 m .25101 .53106 L .24866 .53149 L F
0 0 0 r
.21565 .5442 m .21558 .54441 L .21767 .54329 L F
.21565 .5442 m .21362 .54559 L .21558 .54441 L F
0 .131 .678 r
.30871 .54322 m .31063 .54512 L .31037 .54458 L F
.323 .113 .432 r
.30779 .54247 m .30871 .54322 L .30898 .54078 L F
.764 .675 .125 r
.30898 .54078 m .30871 .54322 L .30874 .54106 L F
0 .131 .678 r
.30871 .54322 m .31037 .54458 L .30874 .54106 L F
.323 .113 .432 r
.30678 .54389 m .30871 .54322 L .30779 .54247 L F
.377 .254 .584 r
.30678 .54389 m .30893 .54592 L .30871 .54322 L F
.30678 .54389 m .30703 .54679 L .30893 .54592 L F
.468 .639 .93 r
.22754 .62743 m .22697 .62407 L .22513 .62434 L F
.22754 .62743 m .22997 .62679 L .22697 .62407 L F
.824 .887 .461 r
.29913 .59258 m .29898 .59377 L .30048 .59008 L F
0 0 .117 r
.29913 .59258 m .29916 .595 L .29898 .59377 L F
.671 .407 .513 r
.28972 .56218 m .29314 .56232 L .29381 .55963 L F
.457 .035 .148 r
.31329 .64268 m .31154 .64079 L .3107 .64245 L F
.31329 .64268 m .31406 .64069 L .31154 .64079 L F
.867 .996 .79 r
.31411 .63763 m .31154 .64079 L .31406 .64069 L F
.221 0 .069 r
.32171 .67005 m .31836 .672 L .32071 .67151 L F
.591 .626 .854 r
.37211 .68122 m .37224 .68309 L .36943 .68205 L F
.223 .188 .607 r
.30609 .56887 m .30736 .56811 L .30686 .56561 L F
.081 0 .34 r
.30609 .56887 m .30705 .57016 L .30736 .56811 L F
.52 .224 .405 r
.37391 .69065 m .37079 .69313 L .37109 .69084 L F
.298 .03 .327 r
.1905 .56282 m .18981 .56505 L .19248 .56206 L F
.394 0 .063 r
.3336 .54713 m .33528 .54722 L .33405 .54622 L F
.3336 .54713 m .33569 .54746 L .33528 .54722 L F
.321 0 .135 r
.33145 .55129 m .33569 .54746 L .3336 .54713 L F
.378 .125 .398 r
.22515 .5562 m .22453 .55875 L .22235 .55925 L F
.681 .566 .719 r
.5251 .54706 m .5226 .55019 L .52523 .54979 L F
.413 .05 .236 r
.22392 .5607 m .22235 .55925 L .22453 .55875 L F
.22392 .5607 m .22146 .56119 L .22235 .55925 L F
.207 .097 .5 r
.33123 .64074 m .33279 .64268 L .33342 .63986 L F
.33123 .64074 m .33131 .64334 L .33279 .64268 L F
.851 .421 0 r
.37419 .52975 m .37186 .52657 L .37213 .52798 L F
.438 .159 .392 r
.35546 .5647 m .35339 .56294 L .35513 .56187 L F
.35546 .5647 m .35251 .56557 L .35339 .56294 L F
.958 .788 .343 r
.36058 .64086 m .36085 .64335 L .36354 .64402 L F
.36058 .64086 m .36043 .64372 L .36085 .64335 L F
.463 0 0 r
.36354 .64402 m .36043 .64372 L .36085 .64335 L F
.643 .63 .823 r
.37052 .67512 m .36825 .67593 L .36669 .67256 L F
.262 0 0 r
.29062 .55136 m .28879 .55095 L .29095 .54989 L F
.29062 .55136 m .287 .55267 L .28879 .55095 L F
.38 .127 .401 r
.38684 .55603 m .38406 .5593 L .3843 .55646 L F
.475 .802 1 r
.31452 .60254 m .31653 .60351 L .31531 .60111 L F
.558 .726 .953 r
.31531 .60111 m .31653 .60351 L .31843 .60261 L F
.178 0 .187 r
.31843 .60261 m .31653 .60351 L .31563 .60574 L F
.559 .44 .674 r
.31406 .64069 m .31555 .63682 L .31411 .63763 L F
.248 .157 .552 r
.39713 .56445 m .39523 .56264 L .39737 .5624 L F
.047 0 .125 r
.34295 .6065 m .34438 .60587 L .34549 .60359 L F
.439 .3 .594 r
.34295 .6065 m .34468 .60726 L .34438 .60587 L F
.698 .693 .841 r
.21211 .59257 m .21366 .59437 L .20972 .59358 L F
.656 .681 .862 r
.2152 .59293 m .21366 .59437 L .21211 .59257 L F
.399 .853 .883 r
.36256 .61896 m .36362 .61841 L .36537 .61842 L F
0 0 0 r
.36478 .6178 m .36362 .61841 L .36122 .61988 L F
.32 .402 .79 r
.36443 .61627 m .36719 .61825 L .36537 .61842 L F
.36443 .61627 m .36719 .61825 L .36537 .61842 L F
.562 .933 .913 r
.36537 .61842 m .36362 .61841 L .36578 .61722 L F
0 0 0 r
.36578 .61722 m .36362 .61841 L .36478 .6178 L F
.399 .853 .883 r
.36123 .61922 m .36362 .61841 L .36256 .61896 L F
.562 .933 .913 r
.36537 .61842 m .36578 .61722 L .36719 .61825 L F
.506 .476 .758 r
.36719 .61825 m .36585 .62234 L .36537 .61842 L F
.258 .054 .401 r
.32506 .63922 m .32323 .6375 L .32601 .63681 L F
.32506 .63922 m .32333 .63998 L .32323 .6375 L F
.925 .758 .656 r
.36199 .67537 m .36191 .67819 L .36059 .67476 L F
.962 .705 .499 r
.35879 .62366 m .36052 .62499 L .35854 .62144 L F
.955 .632 .369 r
.36052 .62499 m .36065 .6278 L .35879 .62366 L F
.799 .486 .461 r
.36372 .62792 m .36065 .6278 L .36052 .62499 L F
.65 .485 .646 r
.52523 .54979 m .52792 .54647 L .5251 .54706 L F
.52523 .54979 m .52921 .55032 L .52792 .54647 L F
.69 .506 .634 r
.52792 .54647 m .53127 .54944 L .53204 .5473 L F
.52792 .54647 m .52921 .55032 L .53127 .54944 L F
.662 .874 .978 r
.36004 .58091 m .3568 .58204 L .35738 .57936 L F
.651 .553 .731 r
.36004 .58091 m .35934 .58226 L .3568 .58204 L F
.826 .586 .577 r
.35934 .58226 m .35727 .58356 L .3568 .58204 L F
.846 .737 .217 r
.35727 .58356 m .35738 .57936 L .3568 .58204 L F
.842 .739 .75 r
.34867 .60703 m .3478 .61217 L .34319 .61346 L F
.732 .406 .429 r
.34319 .61346 m .3478 .61217 L .34665 .61461 L F
.112 .055 .506 r
.34915 .6116 m .3478 .61217 L .34867 .60703 L F
0 0 .02 r
.34665 .61461 m .3478 .61217 L .34915 .6116 L F
.697 .697 .847 r
.38186 .56269 m .3856 .5636 L .38433 .56186 L F
0 .279 .778 r
.3856 .5636 m .38685 .56143 L .38433 .56186 L F
.3856 .5636 m .38677 .56378 L .38685 .56143 L F
.3856 .5636 m .38794 .56519 L .38677 .56378 L F
.244 .337 .761 r
.38675 .56594 m .38794 .56519 L .3856 .5636 L F
.597 .949 .897 r
.36011 .66195 m .36463 .66044 L .36219 .65977 L F
.36011 .66195 m .36163 .66184 L .36463 .66044 L F
0 .478 .863 r
.36463 .66044 m .36496 .65974 L .36219 .65977 L F
.36463 .66044 m .36549 .66018 L .36496 .65974 L F
0 0 0 r
.36722 .65953 m .36549 .66018 L .36463 .66044 L F
.536 .489 .75 r
.33855 .57121 m .34109 .57148 L .34006 .56755 L F
.207 0 0 r
.33684 .57364 m .34109 .57148 L .33855 .57121 L F
.688 .917 .971 r
.32369 .52262 m .32165 .52437 L .31957 .52339 L F
.115 0 0 r
.18413 .5685 m .18631 .56781 L .18777 .56585 L F
0 0 0 r
.18777 .56585 m .18787 .56673 L .18981 .56505 L F
.18777 .56585 m .18631 .56781 L .18787 .56673 L F
.696 .599 .743 r
.32044 .5472 m .32439 .54785 L .32358 .54612 L F
.26 .241 .647 r
.32439 .54785 m .32039 .54984 L .32044 .5472 L F
.325 .275 .647 r
.37125 .64922 m .37146 .65288 L .36968 .65261 L F
0 0 0 r
.23263 .5552 m .23149 .55673 L .23361 .5532 L F
.166 .087 .515 r
.23263 .5552 m .23293 .55797 L .23149 .55673 L F
.318 .073 .376 r
.23293 .55797 m .23087 .5591 L .23149 .55673 L F
.263 0 .125 r
.34273 .57535 m .34146 .57733 L .33935 .57791 L F
.19 0 .081 r
.34418 .57636 m .34273 .57535 L .34478 .57375 L F
.34418 .57636 m .34146 .57733 L .34273 .57535 L F
.519 .169 .314 r
.38298 .56835 m .38559 .56805 L .38675 .56594 L F
.505 .154 .305 r
.38675 .56594 m .38821 .56768 L .38794 .56519 L F
.38675 .56594 m .38559 .56805 L .38821 .56768 L F
.512 .902 .754 r
.33046 .56542 m .33166 .56431 L .33229 .56405 L F
.533 .421 .672 r
.32965 .56802 m .33166 .56431 L .33046 .56542 L F
.231 .28 .707 r
.36724 .52596 m .36861 .52326 L .36579 .52408 L F
.432 .864 .927 r
.28789 .57874 m .28896 .57805 L .29038 .57786 L F
.29038 .57786 m .28896 .57805 L .28789 .57874 L F
.354 .273 .624 r
.32111 .57413 m .31986 .57767 L .32018 .57521 L F
.79 .547 .569 r
.33072 .52383 m .3346 .52225 L .33017 .5215 L F
.505 .539 .825 r
.34926 .5903 m .35009 .58641 L .34819 .58744 L F
.34926 .5903 m .35155 .59014 L .35009 .58641 L F
.414 .768 .995 r
.25619 .72119 m .25808 .72237 L .25358 .72152 L F
.25358 .72152 m .25808 .72237 L .25619 .72119 L F
.389 .205 .507 r
.31935 .6624 m .3191 .66541 L .32159 .66458 L F
.557 .196 .311 r
.32159 .66458 m .32225 .66249 L .31935 .6624 L F
.377 0 .148 r
.26954 .55367 m .26897 .555 L .27168 .55365 L F
.757 .62 .708 r
.36648 .62501 m .36654 .62864 L .36372 .62792 L F
.209 .043 .425 r
.36928 .6245 m .36654 .62864 L .36648 .62501 L F
0 .499 .778 r
.36654 .62864 m .36661 .62856 L .36372 .62792 L F
.209 .043 .425 r
.36928 .6245 m .36885 .62731 L .36654 .62864 L F
.341 .082 .367 r
.36885 .62731 m .36661 .62856 L .36654 .62864 L F
.141 .668 .874 r
.2888 .69334 m .29052 .69386 L .28646 .69339 L F
.28646 .69339 m .29052 .69386 L .2888 .69334 L F
.602 .925 .968 r
.29112 .69243 m .29052 .69386 L .2888 .69334 L F
.29112 .69243 m .29052 .69386 L .2888 .69334 L F
.169 .438 .871 r
.38178 .52297 m .38067 .52411 L .37894 .52249 L F
.38178 .52297 m .38245 .5247 L .38067 .52411 L F
.56 .504 .75 r
.3423 .63988 m .34356 .64305 L .3409 .64387 L F
.514 .867 .989 r
.34426 .64364 m .34101 .64386 L .34396 .64293 L F
.34101 .64386 m .3409 .64387 L .34356 .64305 L F
.34101 .64386 m .34356 .64305 L .34396 .64293 L F
.083 .061 .532 r
.34426 .64364 m .34588 .6426 L .34535 .63993 L F
.432 .811 .991 r
.34426 .64364 m .34396 .64293 L .34588 .6426 L F
.551 .5 .751 r
.34588 .6426 m .34396 .64293 L .34562 .6424 L F
.34562 .6424 m .34356 .64305 L .3423 .63988 L F
.432 .811 .991 r
.34396 .64293 m .34384 .64264 L .34588 .6426 L F
.551 .5 .751 r
.34588 .6426 m .34356 .64305 L .34396 .64293 L F
.34588 .6426 m .34405 .64427 L .34356 .64305 L F
.56 .504 .75 r
.34356 .64305 m .34405 .64427 L .3409 .64387 L F
.514 .867 .989 r
.34396 .64293 m .3409 .64387 L .34384 .64264 L F
.799 .651 .699 r
.27948 .62151 m .27769 .62436 L .28211 .62486 L F
.673 .199 .118 r
.27769 .62436 m .27998 .62627 L .28211 .62486 L F
.639 .155 .086 r
.27998 .62627 m .28439 .62664 L .28211 .62486 L F
.495 .643 .922 r
.35617 .62222 m .35227 .61999 L .35402 .61874 L F
.796 .961 .642 r
.32911 .65977 m .32757 .66143 L .32956 .65846 L F
.78 .677 .75 r
.34834 .56717 m .34804 .56924 L .34931 .5678 L F
.34834 .56717 m .34589 .57046 L .34804 .56924 L F
.792 .551 .572 r
.25988 .7399 m .26403 .74019 L .26422 .73748 L F
.25988 .7399 m .26422 .73748 L .26201 .73883 L F
.081 .596 .884 r
.26422 .73748 m .26036 .73642 L .26201 .73883 L F
.549 .512 .767 r
.36808 .62198 m .36648 .62501 L .36585 .62234 L F
.36808 .62198 m .36928 .6245 L .36648 .62501 L F
.232 0 0 r
.27072 .55981 m .27034 .56017 L .26609 .55996 L F
.131 0 0 r
.27344 .55965 m .27034 .56017 L .27072 .55981 L F
.421 .439 .773 r
.30833 .597 m .31095 .59892 L .31057 .59649 L F
.03 0 0 r
.30887 .62893 m .30893 .62745 L .31097 .62853 L F
.30887 .62893 m .30683 .62981 L .30893 .62745 L F
.672 .531 .684 r
.52523 .54979 m .52888 .55257 L .52921 .55032 L F
.52523 .54979 m .52635 .55353 L .52888 .55257 L F
.127 .285 .756 r
.29818 .54532 m .29721 .54694 L .2958 .54325 L F
.358 .299 .654 r
.29818 .54532 m .29644 .54905 L .29721 .54694 L F
.29818 .54532 m .29869 .54799 L .29644 .54905 L F
.421 .29 .596 r
.30055 .54481 m .29869 .54799 L .29818 .54532 L F
.30055 .54481 m .30077 .54731 L .29869 .54799 L F
.675 .258 .245 r
.29818 .54532 m .29632 .54746 L .30048 .54732 L F
.29818 .54532 m .30048 .54732 L .30077 .54731 L F
.127 .285 .756 r
.29818 .54532 m .2958 .54325 L .29576 .54314 L F
.516 .804 .998 r
.30667 .53928 m .30898 .54078 L .3113 .53745 L F
.30667 .53928 m .30947 .53893 L .30898 .54078 L F
.764 .675 .125 r
.30898 .54078 m .30874 .54106 L .30947 .53893 L F
.801 .966 .654 r
.30898 .54078 m .30947 .53893 L .3113 .53745 L F
.30898 .54078 m .30947 .53893 L .3113 .53745 L F
.758 .993 .873 r
.26036 .73642 m .25829 .73832 L .25709 .73671 L F
.941 .912 .531 r
.25709 .73671 m .25829 .73832 L .25732 .74049 L F
.621 .551 .754 r
.38091 .57199 m .38385 .5719 L .38298 .56835 L F
.248 .106 .484 r
.38336 .57072 m .38091 .57199 L .38298 .56835 L F
.577 .277 .422 r
.38091 .57199 m .3832 .57402 L .38385 .5719 L F
.338 .291 .658 r
.38336 .57072 m .3832 .57402 L .38091 .57199 L F
.547 0 0 r
.27992 .64369 m .28008 .64479 L .27811 .64277 L F
.469 .876 .726 r
.34677 .52438 m .34326 .52639 L .34504 .52552 L F
.186 0 0 r
.33456 .55353 m .333 .55519 L .33064 .55572 L F
.028 0 0 r
.33523 .55432 m .33456 .55353 L .3359 .55414 L F
.33523 .55432 m .333 .55519 L .33456 .55353 L F
.234 .107 .494 r
.32189 .58754 m .32199 .59 L .32001 .59059 L F
.275 .227 .622 r
.32199 .59 m .32201 .59262 L .32001 .59059 L F
.325 .289 .664 r
.17818 .58113 m .1785 .58483 L .18037 .58328 L F
.242 .228 .642 r
.17931 .58722 m .18037 .58328 L .1785 .58483 L F
.115 .665 .8 r
.2895 .52719 m .29167 .52705 L .29308 .52715 L F
.544 .918 .939 r
.29308 .52715 m .29392 .52603 L .29534 .52662 L F
.29308 .52715 m .29167 .52705 L .29392 .52603 L F
.718 .667 .799 r
.37533 .65017 m .37414 .65222 L .37807 .64987 L F
.855 .612 .571 r
.35501 .628 m .35345 .62789 L .35389 .62495 L F
.548 .162 .262 r
.25857 .54941 m .25735 .55204 L .25488 .5518 L F
.272 0 .133 r
.25959 .55131 m .25857 .54941 L .26101 .54859 L F
.401 .06 .269 r
.26354 .54801 m .26196 .55084 L .25959 .55131 L F
.098 .654 .739 r
.26196 .55084 m .26149 .55088 L .25959 .55131 L F
.272 0 .133 r
.25959 .55131 m .25746 .5518 L .25857 .54941 L F
.401 .06 .269 r
.26354 .54801 m .25959 .55131 L .26101 .54859 L F
.098 .654 .739 r
.26149 .55088 m .25782 .55117 L .25959 .55131 L F
.272 0 .133 r
.25959 .55131 m .25735 .55204 L .25746 .5518 L F
.56 .639 .886 r
.27538 .62501 m .27682 .62193 L .27404 .62344 L F
.27538 .62501 m .27769 .62436 L .27682 .62193 L F
.432 .174 .421 r
.27538 .62501 m .27739 .62632 L .27769 .62436 L F
.27538 .62501 m .27494 .62704 L .27739 .62632 L F
.839 .876 .437 r
.29176 .63627 m .29214 .63659 L .293 .63406 L F
.2 0 .038 r
.29176 .63627 m .293 .63406 L .29535 .63302 L F
.561 .928 .779 r
.2915 .63606 m .29176 .63627 L .29358 .63494 L F
.2 0 .038 r
.29176 .63627 m .29437 .6339 L .29358 .63494 L F
.29437 .6339 m .29535 .63302 L .29464 .63378 L F
.29437 .6339 m .29464 .63378 L .29358 .63494 L F
.625 .608 .814 r
.29535 .63302 m .293 .63406 L .29163 .6309 L F
.034 0 0 r
.29358 .63494 m .29464 .63378 L .29432 .6345 L F
.29464 .63378 m .29535 .63302 L .29482 .63379 L F
.29464 .63378 m .29482 .63379 L .29432 .6345 L F
.625 .608 .814 r
.29535 .63302 m .29163 .6309 L .29482 .63379 L F
.028 .307 .797 r
.29479 .63372 m .29483 .63379 L .29476 .63373 L F
.625 .608 .814 r
.29535 .63302 m .29482 .63379 L .29484 .63381 L F
.028 .307 .797 r
.29483 .63379 m .29484 .63381 L .29482 .63379 L F
.29483 .63379 m .29482 .63379 L .29476 .63373 L F
.035 0 0 r
.29694 .63298 m .29535 .63302 L .29484 .63381 L F
.557 .621 .872 r
.29694 .63298 m .29484 .63381 L .29483 .63379 L F
.034 0 0 r
.29481 .63379 m .29535 .63302 L .29694 .63298 L F
.557 .621 .872 r
.29694 .63298 m .29483 .63379 L .2922 .62945 L F
.034 0 0 r
.29432 .6345 m .29481 .63379 L .29694 .63298 L F
.397 0 0 r
.29684 .63398 m .29694 .63298 L .29869 .63378 L F
.028 .307 .797 r
.29479 .63372 m .29476 .63373 L .29163 .6309 L F
.29431 .63293 m .29479 .63372 L .29356 .63262 L F
.788 .952 .925 r
.29358 .63494 m .29694 .63298 L .2922 .63447 L F
.397 0 0 r
.2922 .63447 m .29551 .63343 L .29684 .63398 L F
.29551 .63343 m .29694 .63298 L .29684 .63398 L F
.028 .307 .797 r
.2922 .62945 m .29431 .63293 L .29163 .6309 L F
.29431 .63293 m .29356 .63262 L .29163 .6309 L F
.561 .928 .779 r
.28935 .63721 m .29329 .6351 L .29224 .63517 L F
.29329 .6351 m .29358 .63494 L .29224 .63517 L F
.994 .789 .517 r
.29189 .6352 m .29224 .63517 L .2922 .63447 L F
.561 .928 .779 r
.29026 .63672 m .29176 .63627 L .2915 .63606 L F
.28935 .63721 m .28991 .63699 L .29026 .63672 L F
.28991 .63699 m .29176 .63627 L .29026 .63672 L F
.12 0 0 r
.28935 .63721 m .29224 .63517 L .29124 .6367 L F
.994 .789 .517 r
.29124 .6367 m .29224 .63517 L .29189 .6352 L F
.29124 .6367 m .29171 .63561 L .29295 .63584 L F
.29171 .63561 m .2922 .63447 L .29249 .63501 L F
.29171 .63561 m .29249 .63501 L .29295 .63584 L F
.839 .876 .437 r
.29176 .63627 m .29182 .63754 L .29214 .63659 L F
.772 .418 .386 r
.28718 .64082 m .29002 .64146 L .28925 .63861 L F
.29002 .64146 m .2912 .64172 L .29042 .64047 L F
.829 .828 .353 r
.2903 .64091 m .29182 .63754 L .2918 .63705 L F
.2903 .64091 m .2918 .63705 L .2905 .64026 L F
.2903 .64091 m .29176 .63627 L .28925 .63861 L F
.697 .165 0 r
.2912 .64172 m .29319 .64198 L .2903 .64091 L F
.2912 .64172 m .2903 .64091 L .28925 .63861 L F
.772 .418 .386 r
.29002 .64146 m .29042 .64047 L .28925 .63861 L F
.829 .828 .353 r
.2905 .64026 m .2918 .63705 L .29176 .63627 L F
.436 .145 .371 r
.28093 .54684 m .28351 .54628 L .28435 .54416 L F
.07 0 .269 r
.28351 .54628 m .28556 .54288 L .28435 .54416 L F
.284 .221 .608 r
.17836 .59615 m .17989 .59631 L .17956 .59381 L F
.592 .517 .74 r
.17836 .59615 m .1816 .59979 L .17989 .59631 L F
.17836 .59615 m .18148 .60055 L .1816 .59979 L F
.436 .613 .924 r
.2449 .63419 m .24557 .63259 L .24301 .63313 L F
.2449 .63419 m .24707 .63419 L .24557 .63259 L F
.029 .252 .753 r
.36971 .51549 m .36891 .51693 L .36723 .51566 L F
.36971 .51549 m .37079 .5179 L .36891 .51693 L F
.325 .289 .664 r
.17818 .58113 m .18037 .58328 L .17987 .5805 L F
.726 .7 .825 r
.35362 .67525 m .35602 .67822 L .35155 .67786 L F
.752 .542 .611 r
.35602 .67822 m .35137 .68059 L .35155 .67786 L F
.35602 .67822 m .35548 .68092 L .35137 .68059 L F
.737 .702 .818 r
.35782 .67751 m .35602 .67822 L .35362 .67525 L F
.469 .382 .675 r
.37568 .64413 m .37375 .64426 L .37284 .64293 L F
.37568 .64413 m .37415 .64698 L .37375 .64426 L F
.236 .051 .414 r
.31609 .63426 m .31756 .63576 L .31765 .63286 L F
.31609 .63426 m .31555 .63682 L .31756 .63576 L F
0 .142 .679 r
.37528 .53136 m .37548 .53059 L .37419 .52975 L F
.37528 .53136 m .37749 .53336 L .37548 .53059 L F
.585 .699 .921 r
.20671 .61329 m .21138 .6151 L .21079 .61423 L F
.514 .805 .998 r
.21138 .6151 m .21244 .61347 L .21079 .61423 L F
.21138 .6151 m .21384 .61442 L .21244 .61347 L F
.506 .476 .758 r
.36719 .61825 m .36808 .62198 L .36585 .62234 L F
.711 .56 .681 r
.37592 .64768 m .37776 .64964 L .377 .64811 L F
.37776 .64964 m .37767 .64921 L .377 .64811 L F
.55 .052 .026 r
.377 .64811 m .37668 .64813 L .37664 .64796 L F
.711 .56 .681 r
.37541 .64791 m .37776 .64964 L .37592 .64768 L F
.37415 .64698 m .37533 .65017 L .37807 .64987 L F
.55 .052 .026 r
.37668 .64813 m .37249 .64844 L .37664 .64796 L F
.711 .56 .681 r
.37415 .64698 m .37541 .64791 L .37592 .64768 L F
.55 .052 .026 r
.37664 .64796 m .37249 .64844 L .37415 .64698 L F
.211 .498 .904 r
.37807 .64987 m .37852 .64904 L .377 .64811 L F
.37852 .64904 m .37883 .64847 L .37747 .6482 L F
.37852 .64904 m .37747 .6482 L .377 .64811 L F
.536 .528 .793 r
.3758 .65026 m .37249 .64844 L .377 .64811 L F
.255 .198 .598 r
.37699 .64793 m .3758 .65026 L .377 .64811 L F
.835 .542 .494 r
.3765 .64742 m .37676 .64845 L .37747 .6482 L F
.3765 .64742 m .37747 .6482 L .38083 .647 L F
.37568 .64413 m .3765 .64742 L .3773 .64735 L F
.37568 .64413 m .3773 .64735 L .37824 .64555 L F
.019 .035 .533 r
.37739 .64476 m .37697 .64721 L .37568 .64413 L F
.37697 .64721 m .3768 .64822 L .3765 .64742 L F
.255 .198 .598 r
.37698 .64769 m .37674 .6484 L .37699 .64793 L F
.837 .824 .835 r
.37805 .64461 m .37698 .64769 L .37739 .64476 L F
.37698 .64769 m .3768 .64822 L .3769 .64762 L F
.37698 .64769 m .3769 .64762 L .37739 .64476 L F
.11 .528 .913 r
.377 .64811 m .37764 .64823 L .37698 .64769 L F
.835 .542 .494 r
.37824 .64555 m .3773 .64735 L .38083 .647 L F
.837 .824 .835 r
.38179 .64374 m .37676 .64845 L .3768 .64822 L F
.255 .198 .598 r
.3768 .64822 m .37674 .6484 L .37698 .64769 L F
.837 .824 .835 r
.38179 .64374 m .3768 .64822 L .37805 .64461 L F
.86 .959 .869 r
.38083 .647 m .37747 .6482 L .38179 .64374 L F
.37747 .6482 m .37745 .6482 L .37746 .64819 L F
.37747 .6482 m .37746 .64819 L .38179 .64374 L F
.37745 .6482 m .37738 .64786 L .38179 .64374 L F
.11 .528 .913 r
.37764 .64823 m .37883 .64847 L .37717 .64777 L F
.37729 .64795 m .37717 .64777 L .37698 .64769 L F
.86 .959 .869 r
.37745 .6482 m .37676 .64845 L .37738 .64786 L F
.11 .528 .913 r
.37764 .64823 m .37717 .64777 L .37729 .64795 L F
.37698 .64769 m .37883 .64847 L .37694 .64691 L F
.255 .198 .598 r
.37698 .64761 m .3768 .64822 L .37698 .64769 L F
.019 .035 .533 r
.3768 .64822 m .37676 .64845 L .37674 .6484 L F
.3768 .64822 m .37674 .6484 L .3765 .64742 L F
.37697 .64721 m .3765 .64742 L .37568 .64413 L F
.255 .198 .598 r
.37694 .64691 m .37585 .65009 L .37674 .6484 L F
.37694 .64691 m .37674 .6484 L .37698 .64761 L F
.37585 .65009 m .3758 .65026 L .37699 .64793 L F
.711 .56 .681 r
.37776 .64964 m .37807 .64987 L .37767 .64921 L F
.475 .212 .436 r
.38083 .647 m .38053 .64945 L .37807 .64987 L F
.86 .959 .869 r
.38083 .647 m .38179 .64374 L .38307 .64349 L F
.514 .376 .631 r
.38307 .64349 m .38326 .64662 L .38083 .647 L F
.207 0 .355 r
.38237 .64794 m .38083 .647 L .38326 .64662 L F
.38237 .64794 m .38053 .64945 L .38083 .647 L F
.37 .82 .94 r
.25157 .63538 m .25165 .63443 L .24911 .63444 L F
.25157 .63538 m .25382 .63491 L .25165 .63443 L F
.82 .986 .714 r
.2816 .61812 m .28116 .61905 L .28346 .61618 L F
0 0 0 r
.28511 .61494 m .2816 .61812 L .28346 .61618 L F
.063 .02 .491 r
.39626 .54317 m .3966 .54654 L .39539 .54658 L F
.18 0 .108 r
.32183 .61289 m .32043 .61508 L .31858 .61558 L F
0 0 0 r
.32313 .61168 m .32043 .61508 L .32183 .61289 L F
.491 .438 .726 r
.37181 .56211 m .37272 .56017 L .37087 .5605 L F
.321 0 0 r
.23874 .76634 m .2404 .76542 L .23771 .76552 L F
.737 .702 .818 r
.35782 .67751 m .35362 .67525 L .35647 .67444 L F
.745 .754 .86 r
.36059 .67476 m .35782 .67751 L .35647 .67444 L F
.366 0 0 r
.32514 .54337 m .32135 .54494 L .32358 .54612 L F
.747 .565 .648 r
.40067 .56003 m .40119 .56283 L .39737 .5624 L F
.509 .472 .752 r
.40201 .55558 m .40269 .55956 L .40067 .56003 L F
.497 .872 .659 r
.22698 .53764 m .22663 .53754 L .22922 .537 L F
.22698 .53764 m .22486 .53892 L .22663 .53754 L F
0 .17 .706 r
.3191 .66541 m .32171 .67005 L .32139 .66777 L F
0 0 0 r
.32171 .67005 m .32251 .66961 L .32139 .66777 L F
.32171 .67005 m .32071 .67151 L .32251 .66961 L F
.402 .525 .867 r
.37336 .51709 m .37217 .51981 L .37079 .5179 L F
.37336 .51709 m .37512 .52044 L .37217 .51981 L F
.545 .335 .546 r
.27825 .5501 m .2807 .54994 L .28093 .54684 L F
.465 .268 .528 r
.28093 .54684 m .2831 .54928 L .28351 .54628 L F
.28093 .54684 m .2807 .54994 L .2831 .54928 L F
.533 .027 0 r
.34849 .6066 m .34549 .60359 L .34791 .60272 L F
.766 .635 .716 r
.34438 .60587 m .34791 .60272 L .34549 .60359 L F
.092 .502 .902 r
.19546 .60357 m .19564 .6025 L .19406 .60224 L F
.19546 .60357 m .19977 .60567 L .19564 .6025 L F
.582 .345 .522 r
.33039 .53435 m .33041 .53664 L .32759 .53677 L F
.575 .34 .522 r
.33294 .53395 m .33041 .53664 L .33039 .53435 L F
.715 .228 .085 r
.22858 .55996 m .22648 .56077 L .22453 .55875 L F
.763 .967 .677 r
.35886 .57034 m .35821 .57221 L .36028 .57127 L F
.35886 .57034 m .35622 .5736 L .35821 .57221 L F
.516 .557 .836 r
.27827 .71742 m .27951 .71898 L .28152 .71807 L F
.27827 .71742 m .27951 .71898 L .28152 .71807 L F
.761 .586 .661 r
.36973 .61245 m .36586 .60975 L .36874 .60977 L F
.36973 .61245 m .36818 .61287 L .36586 .60975 L F
.704 .485 .588 r
.36994 .61507 m .36818 .61287 L .36973 .61245 L F
.513 .51 .79 r
.31493 .61511 m .31659 .6161 L .31657 .61593 L F
.679 .221 .158 r
.31858 .61558 m .3179 .61659 L .31657 .61593 L F
.31605 .61525 m .31657 .61593 L .31493 .61511 L F
0 0 .412 r
.31662 .616 m .31689 .61559 L .31755 .61296 L F
.31659 .6161 m .31661 .61607 L .31662 .616 L F
.679 .221 .158 r
.31858 .61558 m .31664 .61592 L .31676 .61535 L F
0 0 .412 r
.31661 .61607 m .31689 .61559 L .31662 .616 L F
.679 .221 .158 r
.31676 .61535 m .31657 .61593 L .31605 .61525 L F
.31664 .61592 m .31657 .61593 L .31676 .61535 L F
0 .068 .597 r
.31597 .6111 m .31657 .61593 L .31755 .61296 L F
.31657 .61593 m .31659 .6161 L .31662 .616 L F
.31657 .61593 m .31662 .616 L .31755 .61296 L F
.513 .51 .79 r
.31493 .61511 m .31657 .61593 L .31597 .6111 L F
.696 .186 .018 r
.31493 .61511 m .31735 .61741 L .31659 .6161 L F
.679 .221 .158 r
.3179 .61659 m .31735 .61741 L .31651 .6159 L F
0 0 .412 r
.31661 .61607 m .31735 .61741 L .31689 .61559 L F
.31659 .6161 m .31735 .61741 L .31661 .61607 L F
.679 .221 .158 r
.31651 .6159 m .31735 .61741 L .31493 .61511 L F
.086 .62 .864 r
.24413 .62206 m .24881 .623 L .24605 .62322 L F
0 .195 .694 r
.24904 .62251 m .24881 .623 L .24723 .62244 L F
.232 0 .295 r
.23525 .55223 m .23263 .5552 L .23361 .5532 L F
.288 .153 .516 r
.36607 .59374 m .36768 .59555 L .36838 .59324 L F
.36607 .59374 m .36614 .59633 L .36768 .59555 L F
.37 .546 .897 r
.2641 .55997 m .26467 .55749 L .26261 .55844 L F
.2641 .55997 m .26609 .55996 L .26467 .55749 L F
.748 .802 .896 r
.35345 .62789 m .35108 .63016 L .35109 .62911 L F
.543 .669 .919 r
.35426 .63096 m .35108 .63016 L .35345 .62789 L F
.316 .128 .459 r
.29218 .57684 m .29059 .5751 L .29237 .57426 L F
.29218 .57684 m .29038 .57786 L .29059 .5751 L F
.465 .274 .536 r
.36299 .56548 m .36288 .56839 L .36053 .5688 L F
.445 .213 .467 r
.36288 .56839 m .36028 .57127 L .36053 .5688 L F
.706 .981 .897 r
.33401 .56373 m .33229 .56405 L .33592 .56231 L F
.526 .743 .975 r
.19962 .60644 m .2006 .60451 L .19977 .60567 L F
.19962 .60644 m .20147 .60596 L .2006 .60451 L F
.577 .286 .438 r
.31449 .58126 m .31609 .58368 L .31688 .58044 L F
.327 .618 .955 r
.31858 .59999 m .3205 .60053 L .31872 .59843 L F
.661 .749 .915 r
.31678 .60078 m .31858 .59999 L .31872 .59843 L F
.31678 .60078 m .32087 .60166 L .31858 .59999 L F
.426 .515 .846 r
.31578 .57178 m .31668 .56813 L .31358 .57001 L F
.31578 .57178 m .31885 .57199 L .31668 .56813 L F
.44 .348 .656 r
.31614 .57435 m .31815 .57395 L .31578 .57178 L F
.404 .409 .75 r
.34539 .55782 m .34663 .55566 L .34336 .55534 L F
.34539 .55782 m .34782 .55802 L .34663 .55566 L F
.439 .068 .236 r
.33172 .57161 m .32973 .5748 L .32821 .57427 L F
.659 .31 .37 r
.33431 .57422 m .33172 .57161 L .33425 .57132 L F
.983 .857 .638 r
.32627 .5829 m .32464 .58304 L .32758 .58172 L F
0 0 0 r
.32758 .58172 m .32778 .58209 L .32989 .58101 L F
.783 .694 .765 r
.32627 .5829 m .32458 .58687 L .32296 .58328 L F
.32627 .5829 m .32296 .58328 L .32624 .58501 L F
.32627 .5829 m .32624 .58501 L .32464 .58304 L F
.727 .624 .743 r
.32624 .58501 m .32778 .58209 L .32464 .58304 L F
0 .126 .675 r
.325 .58301 m .32618 .58367 L .32624 .58501 L F
0 0 0 r
.32758 .58172 m .32473 .583 L .32778 .58209 L F
.32473 .583 m .32478 .583 L .32778 .58209 L F
0 .126 .675 r
.32403 .58145 m .32531 .58277 L .325 .58301 L F
.32531 .58277 m .3254 .58301 L .325 .58301 L F
0 0 0 r
.32473 .583 m .32464 .58304 L .32478 .583 L F
.37 .41 .772 r
.32188 .57944 m .32296 .58328 L .32132 .58351 L F
.126 .237 .71 r
.32403 .58145 m .32296 .58328 L .32188 .57944 L F
.285 .45 .849 r
.32403 .58145 m .32624 .58501 L .32296 .58328 L F
0 .197 .724 r
.32534 .58347 m .32522 .5825 L .32195 .5813 L F
.118 .145 .613 r
.3248 .57742 m .32543 .58208 L .32403 .58145 L F
.32543 .58208 m .32545 .5822 L .32537 .58216 L F
.32543 .58208 m .32537 .58216 L .32403 .58145 L F
0 .197 .724 r
.32518 .58241 m .32503 .58103 L .3247 .58106 L F
0 .197 .713 r
.32545 .5822 m .32618 .58367 L .32403 .58145 L F
0 .197 .724 r
.32522 .5825 m .3252 .58238 L .32518 .58241 L F
.3252 .58238 m .32503 .58103 L .32518 .58241 L F
.091 .23 .716 r
.3231 .57851 m .32403 .58145 L .32188 .57944 L F
.118 .145 .613 r
.3248 .57742 m .32403 .58145 L .3231 .57851 L F
0 .197 .724 r
.32522 .5825 m .3247 .58106 L .32195 .5813 L F
0 .126 .675 r
.32531 .58277 m .32556 .58302 L .3254 .58301 L F
.32556 .58302 m .32618 .58367 L .325 .58301 L F
.139 0 0 r
.31761 .54607 m .31532 .54642 L .32105 .54513 L F
.338 0 0 r
.32135 .54494 m .31761 .54607 L .32105 .54513 L F
.957 .678 .237 r
.32171 .55873 m .32221 .55908 L .31953 .55991 L F
.32171 .55873 m .32258 .56174 L .32221 .55908 L F
.592 .721 .933 r
.30365 .5521 m .3054 .5543 L .30779 .55338 L F
.805 .597 .621 r
.35897 .68364 m .35548 .68092 L .35959 .68159 L F
0 0 0 r
.29226 .56625 m .29177 .56591 L .294 .56494 L F
.29226 .56625 m .29087 .56788 L .29177 .56591 L F
.539 .372 .603 r
.31358 .57001 m .31219 .57195 L .31175 .56871 L F
.137 0 0 r
.34067 .55171 m .3418 .55178 L .34344 .54988 L F
.116 .33 .799 r
.34217 .55073 m .34344 .55188 L .3418 .55178 L F
.3428 .55059 m .34344 .55188 L .34217 .55073 L F
.34344 .55188 m .34427 .55356 L .3418 .55178 L F
.377 .117 .388 r
.3418 .55178 m .33902 .5547 L .33962 .5524 L F
.3418 .55178 m .33902 .5547 L .33962 .5524 L F
.541 .402 .64 r
.34511 .54736 m .34586 .54947 L .34344 .54988 L F
.567 .558 .803 r
.34344 .54988 m .34586 .54947 L .34465 .54554 L F
0 .053 .61 r
.34465 .54554 m .34581 .5493 L .34631 .54787 L F
.34581 .5493 m .34586 .54947 L .34631 .54787 L F
0 .103 .624 r
.34465 .54554 m .34631 .54787 L .34563 .54404 L F
.846 .66 .651 r
.34631 .54787 m .34317 .55016 L .34387 .54917 L F
.34631 .54787 m .34347 .54938 L .34491 .54877 L F
.34387 .54917 m .34317 .55016 L .34247 .54991 L F
.34347 .54938 m .34247 .54991 L .34491 .54877 L F
.34631 .54787 m .34553 .55101 L .34317 .55016 L F
.224 .02 .379 r
.34491 .54877 m .34595 .55004 L .34646 .54812 L F
0 0 .537 r
.34563 .54404 m .34631 .54787 L .34702 .54601 L F
.754 .96 .662 r
.34631 .54787 m .34491 .54877 L .34689 .54618 L F
.34631 .54787 m .34689 .54618 L .34702 .54601 L F
.224 .02 .379 r
.34491 .54877 m .34646 .54812 L .34702 .54601 L F
.815 .719 .759 r
.34553 .55101 m .34427 .55356 L .3428 .55059 L F
.34317 .55016 m .3428 .55059 L .34247 .54991 L F
.34553 .55101 m .3428 .55059 L .34317 .55016 L F
0 0 0 r
.3423 .55119 m .34424 .55028 L .34299 .55055 L F
.137 0 0 r
.33962 .5524 m .3418 .55178 L .34067 .55171 L F
.523 .543 .818 r
.34049 .54789 m .3418 .55178 L .33962 .5524 L F
0 0 0 r
.34117 .55224 m .3417 .5519 L .3423 .55119 L F
.3417 .5519 m .34424 .55028 L .3423 .55119 L F
.34215 .55161 m .34375 .55137 L .34424 .55028 L F
.34117 .55224 m .34188 .552 L .34215 .55161 L F
.34188 .552 m .34375 .55137 L .34215 .55161 L F
.34299 .55055 m .34424 .55028 L .34491 .54877 L F
.116 .33 .799 r
.34247 .54991 m .3428 .55059 L .34217 .55073 L F
.799 .721 .778 r
.35668 .68696 m .35275 .6868 L .35533 .68361 L F
.814 .569 .569 r
.35668 .68696 m .35266 .68947 L .35275 .6868 L F
.35668 .68696 m .35659 .69019 L .35266 .68947 L F
.803 .722 .776 r
.35897 .68364 m .35668 .68696 L .35533 .68361 L F
.733 .5 .575 r
.36081 .69016 m .35659 .69019 L .35668 .68696 L F
.212 .052 .435 r
.18185 .57177 m .18365 .5733 L .18357 .57055 L F
.18185 .57177 m .18156 .57445 L .18365 .5733 L F
.464 .733 .985 r
.26162 .63642 m .26262 .63475 L .26027 .63524 L F
.26162 .63642 m .26395 .63614 L .26262 .63475 L F
.343 0 .088 r
.38951 .5583 m .39251 .55583 L .39083 .55625 L F
.642 .287 .355 r
.35474 .52822 m .35684 .53044 L .35878 .52809 L F
.85 .574 .521 r
.35878 .52809 m .35684 .53044 L .35905 .53066 L F
.826 .586 .577 r
.35934 .58226 m .36064 .58442 L .35727 .58356 L F
.329 .181 .524 r
.36208 .58009 m .35934 .58226 L .36004 .58091 L F
.547 .498 .752 r
.36293 .58371 m .35934 .58226 L .36208 .58009 L F
.36293 .58371 m .36064 .58442 L .35934 .58226 L F
.586 .828 .99 r
.2419 .60931 m .23771 .60854 L .23895 .60918 L F
.511 .823 1 r
.2419 .60931 m .23895 .60918 L .23935 .60902 L F
.586 .828 .99 r
.2419 .60931 m .23935 .60902 L .23771 .60854 L F
.512 .82 1 r
.24314 .60751 m .23935 .60902 L .23803 .60698 L F
.23935 .60902 m .23895 .60918 L .23885 .60894 L F
.23935 .60902 m .23885 .60894 L .23803 .60698 L F
.586 .828 .99 r
.23935 .60902 m .23895 .60898 L .23885 .60894 L F
.23935 .60902 m .23885 .60894 L .23771 .60854 L F
.483 .8 1 r
.23885 .60894 m .23895 .60918 L .23771 .60854 L F
.586 .828 .99 r
.23895 .60898 m .23828 .6089 L .23771 .60854 L F
.483 .8 1 r
.23803 .60698 m .23885 .60894 L .23771 .60854 L F
.511 .823 1 r
.2419 .60931 m .23935 .60902 L .24314 .60751 L F
.586 .828 .99 r
.2419 .60931 m .23943 .60965 L .23828 .6089 L F
.495 .27 .502 r
.3126 .64666 m .31227 .64923 L .30979 .6498 L F
.552 .232 .38 r
.3126 .64666 m .31467 .64837 L .31227 .64923 L F
.3126 .64666 m .31523 .64648 L .31467 .64837 L F
.242 .228 .642 r
.17931 .58722 m .1807 .58684 L .18037 .58328 L F
.319 .247 .617 r
.17931 .58722 m .18122 .58934 L .1807 .58684 L F
.17931 .58722 m .17923 .59098 L .18122 .58934 L F
.531 .137 .238 r
.2816 .61812 m .27948 .62151 L .28116 .61905 L F
.485 .717 .973 r
.3815 .67527 m .38116 .678 L .37928 .67695 L F
.3815 .67527 m .38331 .67755 L .38116 .678 L F
.585 .431 .639 r
.38364 .68012 m .38116 .678 L .38331 .67755 L F
.38364 .68012 m .3811 .68057 L .38116 .678 L F
.746 .962 .673 r
.32526 .6077 m .32419 .60957 L .32638 .60685 L F
.159 .016 .424 r
.32526 .6077 m .32313 .61168 L .32419 .60957 L F
.287 .313 .713 r
.36858 .578 m .37043 .57683 L .36803 .57477 L F
.444 .303 .594 r
.36914 .58006 m .37043 .57683 L .36858 .578 L F
.534 .371 .606 r
.31986 .57767 m .32001 .58 L .31688 .58044 L F
0 0 .191 r
.31688 .58044 m .31822 .58179 L .31742 .57917 L F
.31688 .58044 m .31609 .58368 L .31822 .58179 L F
.688 .651 .808 r
.21211 .59257 m .20972 .59358 L .20813 .59003 L F
.674 .81 .948 r
.20586 .59058 m .20168 .59017 L .20378 .58986 L F
.147 .684 .841 r
.20378 .58986 m .20813 .59003 L .20586 .59058 L F
.054 .243 .739 r
.32338 .60175 m .32241 .60318 L .32087 .60166 L F
.32338 .60175 m .32465 .60515 L .32241 .60318 L F
0 0 0 r
.27861 .61215 m .27551 .61536 L .27759 .61462 L F
0 0 .094 r
.28075 .60871 m .27861 .61215 L .28015 .61218 L F
0 0 0 r
.28015 .61218 m .27861 .61215 L .27759 .61462 L F
.923 .552 .294 r
.34849 .6066 m .34995 .60926 L .34867 .60703 L F
.481 .464 .762 r
.35116 .60489 m .34849 .6066 L .3481 .60396 L F
.35116 .60489 m .3481 .60396 L .34889 .60338 L F
.35116 .60489 m .34791 .60272 L .35025 .60213 L F
.35 .323 .687 r
.35288 .60422 m .35116 .60489 L .35025 .60213 L F
0 0 0 r
.35035 .6023 m .34917 .60459 L .35091 .60325 L F
.35025 .60213 m .35008 .6025 L .35035 .6023 L F
.35008 .6025 m .34917 .60459 L .35035 .6023 L F
.481 .464 .762 r
.34889 .60338 m .3481 .60396 L .34791 .60272 L F
.476 .439 .737 r
.35186 .60885 m .34849 .6066 L .35116 .60489 L F
.35186 .60885 m .34995 .60926 L .34849 .6066 L F
.954 .728 .558 r
.27426 .72495 m .27266 .7213 L .2724 .72398 L F
0 .171 .708 r
.2156 .6013 m .21764 .60464 L .21555 .60265 L F
0 0 0 r
.2161 .56329 m .21518 .56484 L .21371 .56553 L F
.805 .597 .621 r
.35897 .68364 m .35533 .68361 L .35548 .68092 L F
0 0 0 r
.24049 .61387 m .23883 .61732 L .23916 .6159 L F
.263 0 .231 r
.20942 .54706 m .20857 .54902 L .21145 .54631 L F
.137 0 0 r
.3025 .54006 m .3006 .54018 L .29845 .54008 L F
.216 0 0 r
.30489 .5403 m .3006 .54018 L .3025 .54006 L F
.614 .864 .99 r
.3062 .62748 m .30742 .62863 L .30525 .62945 L F
.752 .995 .842 r
.3062 .62748 m .30525 .62945 L .30195 .63016 L F
.571 .384 .589 r
.36043 .64372 m .35731 .64652 L .35742 .64367 L F
.334 .059 .339 r
.35474 .52822 m .35211 .53108 L .3544 .53027 L F
.605 .292 .413 r
.3544 .53027 m .35684 .53044 L .35474 .52822 L F
.557 .284 .458 r
.38641 .59972 m .38598 .60185 L .38377 .60027 L F
.204 0 0 r
.38838 .60084 m .38772 .60114 L .38598 .60185 L F
.387 .331 .673 r
.38598 .60185 m .38473 .60332 L .38446 .60246 L F
0 0 .063 r
.38598 .60185 m .38382 .60552 L .38473 .60332 L F
.931 .96 .768 r
.3829 .60328 m .38382 .60552 L .38598 .60185 L F
.565 .53 .775 r
.39065 .59794 m .39097 .60111 L .38838 .60084 L F
0 0 0 r
.38994 .60056 m .38838 .60084 L .39097 .60111 L F
.38994 .60056 m .38756 .60169 L .38838 .60084 L F
.619 .784 .96 r
.38944 .60047 m .38756 .60169 L .38994 .60056 L F
.557 .284 .458 r
.38641 .59972 m .38598 .60185 L .38377 .60027 L F
.419 .161 .414 r
.38876 .59909 m .38598 .60185 L .38641 .59972 L F
.343 .064 .338 r
.38838 .60084 m .38598 .60185 L .38876 .59909 L F
.565 .53 .775 r
.39065 .59794 m .38838 .60084 L .38876 .59909 L F
.204 0 0 r
.38838 .60084 m .38756 .60169 L .3829 .60328 L F
.619 .784 .96 r
.3854 .59976 m .38724 .6014 L .38944 .60047 L F
.38724 .6014 m .38756 .60169 L .38944 .60047 L F
.204 0 0 r
.38772 .60114 m .38536 .60218 L .38598 .60185 L F
.38536 .60218 m .3829 .60328 L .38426 .60264 L F
.38536 .60218 m .38426 .60264 L .38598 .60185 L F
.387 .331 .673 r
.38598 .60185 m .38446 .60246 L .38377 .60027 L F
0 0 0 r
.37415 .64698 m .37249 .64844 L .37125 .64922 L F
.158 0 0 r
.33411 .62076 m .33557 .61897 L .32978 .62217 L F
.728 .327 .29 r
.33411 .62076 m .33722 .62121 L .33557 .61897 L F
.592 .461 .671 r
.33557 .61897 m .33828 .61834 L .3378 .61539 L F
.826 .617 .62 r
.33722 .62121 m .33828 .61834 L .33557 .61897 L F
0 0 0 r
.3107 .64245 m .3073 .64399 L .30966 .64449 L F
.246 0 0 r
.31329 .64268 m .3107 .64245 L .30966 .64449 L F
.276 .055 .387 r
.32759 .53677 m .32709 .5399 L .32478 .54087 L F
.222 .101 .495 r
.32709 .5399 m .32514 .54337 L .32478 .54087 L F
.813 .602 .617 r
.38089 .63411 m .38236 .635 L .38344 .63374 L F
.312 .023 .303 r
.28283 .7061 m .28569 .70301 L .28475 .7057 L F
.28283 .7061 m .28569 .70301 L .28475 .7057 L F
.386 .091 .337 r
.28795 .70239 m .28569 .70301 L .28475 .7057 L F
.28475 .7057 m .28569 .70301 L .28795 .70239 L F
0 0 0 r
.27825 .5501 m .27918 .55022 L .2807 .54994 L F
.27825 .5501 m .27628 .55216 L .27918 .55022 L F
.232 .397 .822 r
.38509 .52617 m .3841 .52809 L .38245 .5247 L F
.314 .502 .882 r
.38509 .52617 m .38597 .52814 L .3841 .52809 L F
0 .026 .534 r
.37365 .65219 m .37281 .65585 L .37146 .65288 L F
.775 .972 .919 r
.36936 .65662 m .36933 .6572 L .36884 .6574 L F
.36933 .6572 m .36927 .65853 L .36884 .6574 L F
.83 .994 .853 r
.36933 .6572 m .36804 .65825 L .36927 .65853 L F
0 0 0 r
.36918 .65726 m .36936 .65662 L .36884 .6574 L F
.83 .994 .853 r
.36936 .65662 m .36918 .65726 L .36933 .6572 L F
0 0 0 r
.37422 .65524 m .36936 .65662 L .36918 .65726 L F
.83 .994 .853 r
.36936 .65662 m .36868 .65746 L .36918 .65726 L F
.36868 .65746 m .36804 .65825 L .36933 .6572 L F
.28 .764 .671 r
.37305 .65574 m .36884 .6574 L .37281 .65585 L F
.37378 .65543 m .36933 .6572 L .37305 .65574 L F
.36933 .6572 m .36884 .6574 L .37305 .65574 L F
.37422 .65524 m .36884 .6574 L .37378 .65543 L F
.944 .728 .58 r
.38104 .54068 m .3784 .5419 L .38039 .53792 L F
.38104 .54068 m .38052 .54312 L .3784 .5419 L F
.298 .15 .505 r
.31168 .65208 m .30979 .6498 L .31227 .64923 L F
.31168 .65208 m .30964 .65295 L .30979 .6498 L F
.618 .267 .353 r
.36372 .62792 m .35965 .63033 L .36065 .6278 L F
.36372 .62792 m .36234 .6305 L .35965 .63033 L F
.445 .013 .123 r
.36661 .62856 m .36234 .6305 L .36372 .62792 L F
.485 .875 .692 r
.35402 .61874 m .35227 .61999 L .3506 .62083 L F
.513 .51 .79 r
.31493 .61511 m .31597 .6111 L .31384 .61343 L F
0 0 0 r
.2075 .57412 m .20486 .57692 L .20563 .57493 L F
.502 .418 .694 r
.17956 .59381 m .18122 .58934 L .17923 .59098 L F
.573 .561 .802 r
.35834 .63703 m .3558 .63781 L .35433 .63418 L F
.505 .343 .595 r
.35834 .63703 m .3585 .63984 L .3558 .63781 L F
.741 .804 .902 r
.36354 .64402 m .36043 .64372 L .36339 .64222 L F
.744 .533 .608 r
.36354 .64402 m .36001 .64623 L .36043 .64372 L F
.36354 .64402 m .36337 .64853 L .36001 .64623 L F
.169 .333 .786 r
.36465 .64229 m .36354 .64402 L .36339 .64222 L F
.376 .615 .944 r
.36465 .64229 m .36635 .64442 L .36354 .64402 L F
.202 .661 .943 r
.25757 .63505 m .25811 .63425 L .25556 .63464 L F
.25757 .63505 m .26027 .63524 L .25811 .63425 L F
.101 0 .072 r
.27966 .54073 m .27834 .543 L .2767 .54353 L F
0 0 0 r
.28154 .54097 m .27834 .543 L .27966 .54073 L F
.494 .501 .793 r
.33137 .54045 m .33235 .5376 L .33041 .53664 L F
.33137 .54045 m .33349 .53987 L .33235 .5376 L F
.129 0 0 r
.33137 .54045 m .33241 .54121 L .33349 .53987 L F
.843 .944 .581 r
.38433 .56186 m .38286 .56454 L .38186 .56269 L F
.212 .362 .798 r
.29571 .58757 m .29661 .58678 L .29558 .58647 L F
.29571 .58757 m .29808 .58978 L .29661 .58678 L F
.3 .386 .784 r
.29571 .58757 m .29768 .59111 L .29808 .58978 L F
.773 .889 .928 r
.29808 .58978 m .29768 .59111 L .29464 .59141 L F
.722 .386 .409 r
.2858 .64637 m .28981 .64641 L .28802 .64921 L F
.563 .062 .023 r
.28981 .64641 m .29039 .64841 L .28802 .64921 L F
.28981 .64641 m .29195 .64711 L .29039 .64841 L F
.401 0 0 r
.35857 .56667 m .36096 .56684 L .36299 .56548 L F
.709 .957 .686 r
.36299 .56548 m .36375 .56391 L .36528 .56489 L F
.631 .154 .103 r
.36252 .56506 m .3584 .56587 L .36203 .5645 L F
.709 .957 .686 r
.36299 .56548 m .36096 .56684 L .36293 .56478 L F
.476 .282 .538 r
.36522 .56763 m .36288 .56839 L .36299 .56548 L F
.709 .957 .686 r
.36354 .56435 m .36293 .56478 L .36375 .56391 L F
.36299 .56548 m .36293 .56478 L .36354 .56435 L F
.476 .282 .538 r
.36522 .56763 m .36299 .56548 L .36528 .56489 L F
.332 .06 .342 r
.36096 .56684 m .36291 .56664 L .36375 .56391 L F
.315 .165 .512 r
.36713 .5665 m .36522 .56763 L .36528 .56489 L F
.459 .177 .397 r
.36375 .56391 m .36291 .56664 L .36563 .56584 L F
.631 .154 .103 r
.3633 .56596 m .36129 .56592 L .36252 .56506 L F
.36129 .56592 m .3584 .56587 L .36252 .56506 L F
.54 .186 .316 r
.3403 .63292 m .33823 .6312 L .33772 .63291 L F
.522 .193 .351 r
.3403 .63292 m .34104 .631 L .33823 .6312 L F
.15 .692 .749 r
.28124 .52673 m .2855 .52618 L .28305 .52686 L F
.298 .368 .766 r
.35426 .63096 m .35345 .62789 L .35501 .628 L F
.633 .543 .735 r
.35879 .62366 m .36065 .6278 L .35501 .628 L F
.618 .406 .572 r
.36065 .6278 m .35965 .63033 L .35501 .628 L F
.635 .092 0 r
.35727 .58356 m .36064 .58442 L .35786 .58462 L F
.354 .829 .857 r
.35786 .58462 m .36064 .58442 L .36293 .58371 L F
.019 0 0 r
.20364 .55234 m .20509 .55217 L .20674 .55009 L F
.223 0 .094 r
.20509 .55217 m .20857 .54902 L .20674 .55009 L F
.673 .172 .047 r
.31365 .53685 m .31534 .53948 L .31825 .53792 L F
.936 .965 .691 r
.31825 .53792 m .31807 .53551 L .31928 .53592 L F
.31825 .53792 m .31534 .53948 L .31807 .53551 L F
.04 0 0 r
.2802 .55741 m .27802 .55825 L .2796 .55652 L F
.037 0 0 r
.25956 .52982 m .26196 .52968 L .26387 .52932 L F
0 0 0 r
.26196 .52968 m .2664 .52844 L .26387 .52932 L F
.141 .303 .768 r
.20147 .60596 m .20307 .60967 L .20394 .6079 L F
.205 .386 .821 r
.20307 .60967 m .20573 .6114 L .20394 .6079 L F
.112 .055 .506 r
.34915 .6116 m .34867 .60703 L .34995 .60926 L F
.777 .895 .488 r
.32258 .56174 m .32103 .56385 L .32066 .56551 L F
.947 .635 .412 r
.31921 .56656 m .32066 .56551 L .32103 .56385 L F
.31921 .56656 m .32121 .5684 L .32066 .56551 L F
.429 .356 .673 r
.3672 .58405 m .3672 .58661 L .36917 .58495 L F
.502 .412 .686 r
.36784 .5904 m .36917 .58495 L .3672 .58661 L F
.493 .661 .936 r
.24277 .62026 m .24195 .62241 L .24075 .62029 L F
.24277 .62026 m .24413 .62206 L .24195 .62241 L F
.435 .205 .465 r
.3767 .6871 m .37612 .69017 L .37391 .69065 L F
.387 .211 .517 r
.37858 .684 m .37858 .68666 L .3767 .6871 L F
.547 .365 .586 r
.37858 .68666 m .37612 .69017 L .3767 .6871 L F
.471 .773 .996 r
.27106 .52713 m .27022 .52865 L .26866 .52769 L F
.27106 .52713 m .27274 .52828 L .27022 .52865 L F
.422 .03 .188 r
.21771 .5643 m .2161 .56329 L .21851 .56258 L F
.21771 .5643 m .21518 .56484 L .2161 .56329 L F
.066 .629 .771 r
.24233 .55023 m .24064 .55013 L .23836 .55018 L F
.404 0 0 r
.2441 .55109 m .24064 .55013 L .24233 .55023 L F
.327 .031 .301 r
.36803 .57477 m .37007 .5743 L .37083 .57201 L F
.376 .043 .268 r
.37007 .5743 m .37328 .5718 L .37083 .57201 L F
.51 .348 .597 r
.37083 .57201 m .37328 .5718 L .37316 .5684 L F
.403 .203 .491 r
.34146 .57733 m .33924 .58032 L .33935 .57791 L F
.452 .803 .998 r
.35738 .57936 m .36208 .58009 L .36004 .58091 L F
.24 0 .063 r
.31755 .64592 m .32067 .6432 L .31995 .64557 L F
.173 0 .337 r
.32067 .6432 m .32333 .63998 L .32309 .64236 L F
.705 .564 .693 r
.32309 .64236 m .31995 .64557 L .32067 .6432 L F
0 0 0 r
.35594 .56017 m .35513 .56187 L .35593 .55948 L F
.35594 .56017 m .35593 .55948 L .35368 .55885 L F
.643 .63 .823 r
.37052 .67512 m .36669 .67256 L .36909 .67169 L F
.506 .516 .801 r
.37172 .67106 m .37052 .67512 L .36909 .67169 L F
.37172 .67106 m .37303 .67443 L .37052 .67512 L F
.461 .349 .64 r
.37303 .67443 m .373 .67716 L .37052 .67512 L F
.346 .347 .718 r
.37052 .67512 m .373 .67716 L .37144 .67786 L F
.38 .127 .401 r
.38684 .55603 m .3867 .55879 L .38406 .5593 L F
.573 .281 .434 r
.38951 .5583 m .38684 .55603 L .38908 .55526 L F
.38951 .5583 m .3867 .55879 L .38684 .55603 L F
.02 .534 .866 r
.31541 .55835 m .31747 .55879 L .31953 .55991 L F
.429 .841 .969 r
.31747 .55879 m .32171 .55873 L .31953 .55991 L F
.742 .529 .606 r
.36818 .61287 m .36709 .6152 L .36374 .61455 L F
.704 .485 .588 r
.36994 .61507 m .36709 .6152 L .36818 .61287 L F
.365 .129 .417 r
.32929 .53901 m .32759 .53677 L .33041 .53664 L F
.32929 .53901 m .32709 .5399 L .32759 .53677 L F
.324 .666 .974 r
.35402 .55238 m .35456 .553 L .35131 .55182 L F
.865 .903 .858 r
.35622 .55032 m .35456 .553 L .35402 .55238 L F
.662 .267 .286 r
.27898 .54566 m .2767 .54353 L .27834 .543 L F
.27898 .54566 m .27507 .54575 L .2767 .54353 L F
.767 .992 .882 r
.32937 .58581 m .32907 .58776 L .33073 .58606 L F
.193 .183 .618 r
.32937 .58581 m .32799 .58915 L .32907 .58776 L F
.589 .299 .444 r
.33924 .58032 m .3358 .58322 L .33697 .58094 L F
0 0 .139 r
.35211 .53108 m .35268 .5318 L .3544 .53027 L F
0 0 .061 r
.33808 .56418 m .33735 .5676 L .34006 .56755 L F
.33808 .56418 m .33784 .56684 L .33735 .5676 L F
0 0 .064 r
.33763 .56954 m .33735 .5676 L .33784 .56684 L F
.33763 .56954 m .33655 .57089 L .33735 .5676 L F
.56 .504 .75 r
.3423 .63988 m .3409 .64387 L .34026 .64023 L F
.514 .591 .869 r
.3409 .64387 m .34405 .64427 L .34384 .64264 L F
.611 .22 .279 r
.33592 .56231 m .33808 .56418 L .3407 .56189 L F
.386 .788 .984 r
.3407 .56189 m .34059 .561 L .34206 .56177 L F
.813 .985 .713 r
.3407 .56189 m .33808 .56418 L .34059 .561 L F
.358 .422 .791 r
.37848 .53518 m .38003 .53265 L .37749 .53336 L F
.37848 .53518 m .38092 .53627 L .38003 .53265 L F
.853 .643 .619 r
.37327 .63544 m .37257 .63693 L .36929 .63167 L F
.743 .78 .883 r
.37392 .63539 m .37257 .63693 L .37327 .63544 L F
.74 .621 .727 r
.36929 .63167 m .37257 .63693 L .36758 .63375 L F
.708 .353 .373 r
.37257 .63693 m .36733 .63649 L .36758 .63375 L F
.37257 .63693 m .37134 .63695 L .36733 .63649 L F
.743 .78 .883 r
.37392 .63539 m .37134 .63695 L .37257 .63693 L F
.742 .776 .88 r
.37533 .63732 m .37134 .63695 L .37392 .63539 L F
.778 .301 .102 r
.37508 .63954 m .37134 .63695 L .37533 .63732 L F
.633 .314 .413 r
.40035 .5643 m .39737 .5624 L .40119 .56283 L F
.338 0 .051 r
.40255 .56301 m .40035 .5643 L .40119 .56283 L F
.378 0 0 r
.22051 .60803 m .22073 .60823 L .22297 .60919 L F
.227 .316 .747 r
.22093 .60671 m .22107 .60855 L .22073 .60823 L F
.954 .611 .305 r
.22073 .60823 m .22273 .61181 L .22297 .60919 L F
.22073 .60823 m .22127 .61119 L .22273 .61181 L F
.227 .316 .747 r
.22107 .60855 m .22127 .61119 L .22073 .60823 L F
.378 0 0 r
.21862 .60713 m .22073 .60823 L .22051 .60803 L F
.464 .805 .999 r
.38053 .64945 m .37883 .64847 L .37807 .64987 L F
.464 .27 .533 r
.30446 .5505 m .30689 .54992 L .30703 .54679 L F
.295 0 .152 r
.30365 .5521 m .30689 .54992 L .30446 .5505 L F
.691 .665 .82 r
.36858 .58427 m .37161 .58292 L .36841 .58238 L F
.976 .761 .549 r
.37229 .58573 m .37161 .58292 L .36858 .58427 L F
.676 .215 .15 r
.36841 .58238 m .36997 .58469 L .36845 .5845 L F
0 0 0 r
.3684 .58159 m .3672 .58405 L .36841 .58238 L F
.205 .279 .719 r
.36841 .58238 m .3672 .58405 L .36858 .58427 L F
.429 .356 .673 r
.3672 .58405 m .36917 .58495 L .36858 .58427 L F
.676 .215 .15 r
.36841 .58238 m .36845 .5845 L .36598 .5842 L F
0 0 0 r
.36914 .58006 m .3684 .58159 L .36841 .58238 L F
.348 .8 .948 r
.27499 .52734 m .27892 .5274 L .27652 .52778 L F
.298 .368 .766 r
.35345 .62789 m .356 .62966 L .35426 .63096 L F
.35426 .63096 m .356 .62966 L .35345 .62789 L F
0 0 .023 r
.356 .62966 m .35433 .63418 L .35426 .63096 L F
.608 .129 .091 r
.31188 .52485 m .31727 .52421 L .31509 .5252 L F
.362 .206 .531 r
.32921 .64984 m .33096 .65246 L .33145 .64911 L F
.32921 .64984 m .32913 .65259 L .33096 .65246 L F
.326 .405 .79 r
.27061 .63874 m .27074 .64201 L .2723 .63881 L F
.16 .202 .658 r
.2723 .63881 m .27074 .64201 L .27155 .64248 L F
.232 .056 .426 r
.28075 .60871 m .28312 .60865 L .28339 .60491 L F
.211 0 .241 r
.2821 .61053 m .28075 .60871 L .28015 .61218 L F
.2821 .61053 m .28312 .60865 L .28075 .60871 L F
.549 0 0 r
.29709 .64368 m .29855 .64335 L .29484 .64277 L F
0 0 0 r
.30078 .64296 m .29855 .64335 L .29709 .64368 L F
.734 .624 .736 r
.52921 .55032 m .52888 .55257 L .53127 .54944 L F
0 .228 .746 r
.22157 .61854 m .22193 .61708 L .2201 .61558 L F
0 .05 .614 r
.22157 .61854 m .22332 .62082 L .22193 .61708 L F
.621 .479 .668 r
.38877 .59642 m .38641 .59972 L .38615 .59692 L F
0 0 0 r
.2702 .62671 m .26856 .62824 L .2717 .62516 L F
0 0 .169 r
.2702 .62671 m .26884 .62884 L .26856 .62824 L F
0 0 0 r
.27551 .61536 m .27237 .61779 L .27457 .61721 L F
.27759 .61462 m .27551 .61536 L .27457 .61721 L F
.642 .921 .977 r
.23572 .60995 m .23265 .61133 L .23106 .61057 L F
.555 .504 .753 r
.29106 .62633 m .29163 .6309 L .28943 .63142 L F
.018 .146 .657 r
.31614 .57435 m .31839 .57673 L .31815 .57395 L F
0 0 0 r
.24185 .60997 m .2419 .60931 L .24314 .60751 L F
.517 .676 .937 r
.37715 .52025 m .37611 .52258 L .37512 .52044 L F
.37715 .52025 m .37894 .52249 L .37611 .52258 L F
.44 .665 .957 r
.29032 .52527 m .2895 .52719 L .28789 .52573 L F
.29032 .52527 m .29167 .52705 L .2895 .52719 L F
.537 .009 0 r
.36267 .5385 m .36678 .53771 L .36616 .53994 L F
.36267 .5385 m .36512 .53882 L .36678 .53771 L F
.72 .955 .672 r
.36678 .53771 m .36669 .53665 L .36871 .53635 L F
.36678 .53771 m .36512 .53882 L .36669 .53665 L F
.628 .39 .538 r
.36947 .53894 m .36678 .53771 L .36871 .53635 L F
.36947 .53894 m .36616 .53994 L .36678 .53771 L F
.583 .387 .581 r
.39099 .59049 m .39123 .59313 L .38857 .59371 L F
.623 .545 .745 r
.39292 .58872 m .39123 .59313 L .39099 .59049 L F
.473 .279 .535 r
.30703 .54679 m .30949 .54901 L .30893 .54592 L F
.30703 .54679 m .30689 .54992 L .30949 .54901 L F
.071 .358 .829 r
.3966 .54654 m .39898 .54812 L .39864 .54974 L F
.638 .211 0 r
.39914 .55075 m .39864 .54974 L .39898 .54812 L F
.39914 .55075 m .40019 .5523 L .39864 .54974 L F
.744 .99 .796 r
.35191 .51547 m .35267 .51374 L .35378 .51351 L F
0 0 0 r
.35329 .51757 m .35411 .51747 L .35172 .51802 L F
.35664 .51663 m .35411 .51747 L .35329 .51757 L F
.887 .503 .3 r
.35657 .51814 m .35534 .5173 L .35411 .51747 L F
.561 .564 .814 r
.352 .51675 m .35411 .51747 L .35267 .51374 L F
.35172 .51802 m .35411 .51747 L .352 .51675 L F
.792 .607 .651 r
.35794 .51781 m .35411 .51747 L .35664 .51663 L F
.561 .564 .814 r
.35179 .51712 m .35267 .51374 L .35191 .51547 L F
.352 .51675 m .35267 .51374 L .35179 .51712 L F
.975 .674 .3 r
.35267 .51374 m .35411 .51747 L .35221 .51518 L F
.887 .503 .3 r
.35534 .5173 m .35271 .51552 L .35411 .51747 L F
.35271 .51552 m .35221 .51518 L .35262 .51568 L F
.35271 .51552 m .35262 .51568 L .35411 .51747 L F
.561 .564 .814 r
.35172 .51802 m .352 .51675 L .35179 .51712 L F
.581 .481 .706 r
.37101 .60292 m .37413 .60473 L .3734 .60238 L F
.37101 .60292 m .3714 .60629 L .37413 .60473 L F
.551 .465 .71 r
.3734 .60238 m .3714 .60629 L .37101 .60292 L F
.745 .227 0 r
.31514 .62442 m .31425 .62336 L .31482 .62393 L F
.447 0 0 r
.31482 .62393 m .31425 .62336 L .31179 .62317 L F
.58 .644 .878 r
.1816 .59979 m .18211 .59622 L .17989 .59631 L F
.1816 .59979 m .18372 .59949 L .18211 .59622 L F
.291 0 .274 r
.30675 .56206 m .30877 .56147 L .3093 .55954 L F
.42 .088 .295 r
.30877 .56147 m .31175 .55917 L .3093 .55954 L F
.447 .025 .144 r
.31611 .64187 m .31406 .64069 L .31329 .64268 L F
.559 .44 .674 r
.31406 .64069 m .31708 .64041 L .31555 .63682 L F
.432 .044 .201 r
.31611 .64187 m .31708 .64041 L .31406 .64069 L F
.62 .934 .963 r
.31179 .62317 m .30962 .62496 L .30996 .62461 L F
.666 .683 .856 r
.29464 .59141 m .29411 .59354 L .29277 .59149 L F
.347 .732 .985 r
.26395 .63614 m .26789 .63711 L .26604 .63647 L F
0 .261 .705 r
.26789 .63711 m .26788 .63673 L .26604 .63647 L F
.26789 .63711 m .27061 .63874 L .26788 .63673 L F
.365 .772 .983 r
.2566 .74999 m .25681 .74879 L .25497 .75175 L F
.2566 .74999 m .25908 .74985 L .25681 .74879 L F
.551 .465 .71 r
.37379 .60531 m .37389 .60605 L .3714 .60629 L F
.473 .214 .44 r
.37374 .60772 m .3714 .60629 L .37389 .60605 L F
.289 .18 .552 r
.37413 .60473 m .3758 .60183 L .3734 .60238 L F
.37413 .60473 m .3759 .60478 L .3758 .60183 L F
.106 0 .273 r
.37404 .60539 m .3759 .60478 L .37413 .60473 L F
.378 .338 .687 r
.3759 .60478 m .37463 .60559 L .3745 .60524 L F
.37463 .60559 m .37389 .60605 L .37379 .60531 L F
.473 .214 .44 r
.37379 .60531 m .37404 .60539 L .37407 .60519 L F
.3714 .60629 m .37407 .60519 L .37413 .60473 L F
.378 .338 .687 r
.37463 .60559 m .37379 .60531 L .3734 .60238 L F
.106 0 .273 r
.37374 .60772 m .3759 .60478 L .37389 .60605 L F
.37374 .60772 m .3759 .60478 L .37404 .60539 L F
.378 .338 .687 r
.3759 .60478 m .3745 .60524 L .3734 .60238 L F
.473 .214 .44 r
.3714 .60629 m .37374 .60772 L .37404 .60539 L F
.3714 .60629 m .37404 .60539 L .37379 .60531 L F
.551 .465 .71 r
.3734 .60238 m .37379 .60531 L .3714 .60629 L F
.473 .214 .44 r
.37374 .60772 m .37121 .60876 L .3714 .60629 L F
.3714 .60629 m .37121 .60876 L .37374 .60772 L F
.185 .544 .928 r
.19326 .6024 m .19267 .60044 L .18826 .60101 L F
.19326 .6024 m .19406 .60224 L .19267 .60044 L F
.031 .276 .773 r
.31664 .58921 m .31782 .58956 L .31524 .58706 L F
.258 .172 .563 r
.31664 .58921 m .31834 .59207 L .31782 .58956 L F
.31664 .58921 m .31652 .59316 L .31834 .59207 L F
.732 .99 .871 r
.34748 .68031 m .35031 .67786 L .35155 .67786 L F
.642 .887 .546 r
.35362 .67525 m .35155 .67786 L .35236 .67652 L F
.62 .959 .884 r
.35155 .67786 m .35031 .67786 L .35236 .67652 L F
.572 .484 .716 r
.3867 .55879 m .38433 .56186 L .38406 .5593 L F
.52 .224 .405 r
.37391 .69065 m .37336 .69282 L .37079 .69313 L F
.229 0 .192 r
.37612 .69017 m .37336 .69282 L .37391 .69065 L F
.976 .761 .549 r
.37229 .58573 m .37336 .58422 L .37161 .58292 L F
0 0 0 r
.37463 .58291 m .37336 .58422 L .37229 .58573 L F
.119 0 0 r
.392 .55411 m .39123 .55517 L .38908 .55526 L F
.239 .272 .695 r
.392 .55411 m .39251 .55583 L .39434 .55411 L F
.121 0 0 r
.39434 .55411 m .39123 .55517 L .392 .55411 L F
.503 .678 .944 r
.21731 .61583 m .21822 .61368 L .21583 .61458 L F
.21731 .61583 m .2201 .61558 L .21822 .61368 L F
.188 0 .059 r
.2002 .55545 m .20224 .55476 L .20364 .55234 L F
.112 0 .018 r
.20364 .55234 m .20419 .55391 L .20509 .55217 L F
.20364 .55234 m .20224 .55476 L .20419 .55391 L F
0 0 .24 r
.38373 .64237 m .38307 .64349 L .38179 .64374 L F
.38373 .64237 m .38326 .64662 L .38307 .64349 L F
.427 .683 .97 r
.20671 .61329 m .20743 .61152 L .20573 .6114 L F
.20671 .61329 m .21079 .61423 L .20743 .61152 L F
.33 .798 .926 r
.25465 .62427 m .25699 .62386 L .25868 .6241 L F
.418 .478 .815 r
.32635 .57355 m .3268 .57068 L .32476 .57121 L F
.32635 .57355 m .32821 .57427 L .3268 .57068 L F
.609 .439 .627 r
.3811 .68057 m .38123 .68385 L .37858 .684 L F
.501 .319 .566 r
.38364 .68012 m .38123 .68385 L .3811 .68057 L F
.688 .651 .808 r
.21211 .59257 m .20813 .59003 L .21056 .58933 L F
.529 .635 .899 r
.21261 .589 m .21211 .59257 L .21056 .58933 L F
.21261 .589 m .21567 .59249 L .21211 .59257 L F
.656 .681 .862 r
.2152 .59293 m .21211 .59257 L .21567 .59249 L F
.456 .694 .969 r
.18545 .60288 m .18785 .60256 L .18601 .60113 L F
.366 .093 .361 r
.34915 .6116 m .34995 .60926 L .35186 .60885 L F
.613 .845 .987 r
.37181 .56211 m .3677 .5618 L .37043 .56086 L F
.35 0 .155 r
.37181 .56211 m .37042 .56467 L .36808 .56508 L F
.491 .438 .726 r
.37181 .56211 m .37402 .56157 L .37272 .56017 L F
.181 .063 .472 r
.37259 .56436 m .37402 .56157 L .37181 .56211 L F
.37259 .56436 m .37398 .56421 L .37402 .56157 L F
.625 .243 .299 r
.37398 .56421 m .37181 .56211 L .37402 .56157 L F
.37398 .56421 m .37042 .56467 L .37181 .56211 L F
.484 .784 .998 r
.37043 .56086 m .37402 .56157 L .37181 .56211 L F
.853 .643 .619 r
.37327 .63544 m .36929 .63167 L .37293 .63261 L F
.343 .51 .878 r
.37463 .63235 m .37327 .63544 L .37293 .63261 L F
.438 .556 .877 r
.37463 .63235 m .37392 .63539 L .37327 .63544 L F
.115 0 0 r
.30373 .65564 m .30756 .65531 L .30421 .65596 L F
.176 0 .301 r
.30756 .65531 m .30964 .65295 L .30896 .65466 L F
.455 .885 .843 r
.30421 .65596 m .30756 .65531 L .30896 .65466 L F
.435 .32 .624 r
.36803 .57477 m .37043 .57683 L .37007 .5743 L F
.238 0 .191 r
.32429 .66165 m .32225 .66249 L .32159 .66458 L F
.902 .814 .751 r
.27682 .62193 m .27948 .62151 L .27869 .62029 L F
.27682 .62193 m .27769 .62436 L .27948 .62151 L F
.531 .137 .238 r
.2816 .61812 m .27869 .62029 L .27948 .62151 L F
0 .13 .666 r
.33249 .52979 m .33257 .53185 L .33104 .52798 L F
0 0 .31 r
.33326 .53301 m .33257 .53185 L .33249 .52979 L F
.33326 .53301 m .33294 .53395 L .33257 .53185 L F
.365 .278 .624 r
.33131 .64334 m .33371 .64573 L .33279 .64268 L F
.33131 .64334 m .33122 .64682 L .33371 .64573 L F
.197 .066 .465 r
.17987 .5805 m .18129 .57711 L .17997 .57788 L F
.486 .332 .598 r
.36373 .60222 m .36626 .59887 L .36395 .59977 L F
.629 .555 .753 r
.38298 .56835 m .38385 .5719 L .38559 .56805 L F
.396 .4 .746 r
.38298 .56835 m .38385 .5719 L .38587 .57058 L F
.576 .444 .663 r
.3832 .57402 m .38587 .57058 L .38385 .5719 L F
.192 0 .212 r
.19809 .55622 m .19911 .55743 L .2002 .55545 L F
.19809 .55622 m .19727 .55835 L .19911 .55743 L F
.414 .334 .657 r
.30675 .56206 m .30922 .56424 L .30877 .56147 L F
.30675 .56206 m .30686 .56561 L .30922 .56424 L F
.336 .085 .377 r
.33017 .55701 m .32812 .556 L .33064 .55572 L F
.33017 .55701 m .32758 .55817 L .32812 .556 L F
.79 .547 .569 r
.33072 .52383 m .33017 .5215 L .32999 .52414 L F
.257 .481 .883 r
.32972 .52026 m .33111 .52297 L .32876 .52251 L F
.928 .578 .14 r
.32876 .52251 m .32997 .52307 L .32685 .52214 L F
.32876 .52251 m .32999 .52414 L .32997 .52307 L F
.844 .708 .713 r
.32999 .52414 m .33104 .52798 L .33072 .52383 L F
.257 .481 .883 r
.33111 .52297 m .33225 .5252 L .32876 .52251 L F
.928 .578 .14 r
.32876 .52251 m .32685 .52214 L .32642 .52201 L F
.53 .149 .264 r
.29095 .54989 m .293 .55142 L .29062 .55136 L F
.508 .162 .316 r
.29348 .54969 m .293 .55142 L .29095 .54989 L F
.343 0 .088 r
.38951 .5583 m .3916 .55798 L .39251 .55583 L F
.303 0 .072 r
.39251 .55583 m .39434 .55725 L .39434 .55411 L F
.39251 .55583 m .3916 .55798 L .39434 .55725 L F
.499 .245 .46 r
.38123 .68385 m .37858 .68666 L .37858 .684 L F
.44 .503 .828 r
.28726 .56235 m .29029 .56423 L .28972 .56218 L F
.73 .293 .214 r
.22273 .61181 m .22452 .61387 L .22657 .61238 L F
0 0 0 r
.22657 .61238 m .22684 .613 L .22832 .61111 L F
.22657 .61238 m .22452 .61387 L .22684 .613 L F
.376 .532 .884 r
.33405 .54622 m .33392 .5439 L .33156 .54435 L F
.33405 .54622 m .33528 .54722 L .33392 .5439 L F
0 0 .535 r
.21567 .59249 m .21628 .59214 L .2152 .59293 L F
.146 .001 .412 r
.21687 .59465 m .2152 .59293 L .21628 .59214 L F
.21687 .59465 m .21498 .5963 L .2152 .59293 L F
.216 0 0 r
.26303 .62331 m .26549 .62299 L .26759 .62159 L F
0 0 0 r
.26759 .62159 m .26866 .6209 L .27009 .61842 L F
.26782 .62239 m .26759 .62159 L .26549 .62299 L F
.26782 .62239 m .26866 .6209 L .26759 .62159 L F
.389 .367 .714 r
.37259 .56436 m .37316 .5684 L .37517 .56796 L F
.389 .369 .716 r
.37316 .5684 m .37581 .57121 L .37517 .56796 L F
.576 .399 .604 r
.37328 .5718 m .37581 .57121 L .37316 .5684 L F
.603 .474 .677 r
.32854 .62395 m .33135 .62172 L .32921 .62241 L F
.408 .188 .465 r
.3378 .61539 m .34001 .61512 L .3403 .61213 L F
.457 .431 .741 r
.3378 .61539 m .34035 .61728 L .34001 .61512 L F
.539 .424 .671 r
.3378 .61539 m .33828 .61834 L .34035 .61728 L F
0 0 .09 r
.20486 .57692 m .20252 .58045 L .20273 .57793 L F
0 0 .377 r
.35799 .65152 m .35738 .65644 L .35705 .65589 L F
.656 .192 0 r
.35738 .65644 m .35858 .65818 L .35705 .65589 L F
.325 .49 .869 r
.3601 .52118 m .36156 .51964 L .35794 .51781 L F
.3601 .52118 m .36172 .5213 L .36156 .51964 L F
0 0 .505 r
.20209 .58328 m .20243 .58592 L .20131 .58697 L F
.461 .472 .783 r
.20243 .58592 m .20168 .59017 L .20131 .58697 L F
.552 .356 .569 r
.34001 .61512 m .34175 .61185 L .3403 .61213 L F
.813 .99 .737 r
.29007 .54146 m .28948 .54322 L .29206 .54031 L F
.691 .516 .645 r
.28948 .54322 m .29206 .54355 L .29206 .54031 L F
.731 .548 .645 r
.29206 .54031 m .29206 .54355 L .29576 .54314 L F
.395 0 0 r
.29206 .54031 m .29263 .54073 L .29007 .54146 L F
.731 .548 .645 r
.29206 .54031 m .29576 .54314 L .2946 .54193 L F
.395 0 0 r
.29206 .54031 m .2946 .54193 L .29263 .54073 L F
.715 .18 0 r
.34615 .62108 m .34209 .61858 L .34163 .62124 L F
.667 .277 .297 r
.34383 .62459 m .34615 .62108 L .34163 .62124 L F
.58 .107 .096 r
.3465 .62413 m .34615 .62108 L .34383 .62459 L F
.3465 .62413 m .34846 .62195 L .34615 .62108 L F
0 0 .487 r
.34244 .52501 m .34326 .52639 L .34304 .52592 L F
.847 .912 .879 r
.33326 .53454 m .33041 .53664 L .33294 .53395 L F
.309 .563 .927 r
.33484 .53462 m .33326 .53454 L .33294 .53395 L F
.054 0 .058 r
.33104 .5381 m .33041 .53664 L .33235 .5376 L F
.204 0 .221 r
.33336 .53365 m .33104 .5381 L .33235 .5376 L F
.33339 .5335 m .33334 .53361 L .33336 .53365 L F
.049 .465 .883 r
.33307 .53358 m .33363 .5342 L .33294 .53395 L F
.33317 .53328 m .33334 .53361 L .33307 .53358 L F
.309 .563 .927 r
.33484 .53462 m .33657 .53645 L .33326 .53454 L F
.552 .53 .785 r
.33235 .5376 m .33538 .53895 L .33347 .53371 L F
.33336 .53365 m .33347 .53371 L .33339 .5335 L F
.049 .465 .883 r
.33336 .53365 m .33363 .5342 L .33326 .5336 L F
.552 .53 .785 r
.33235 .5376 m .33347 .53371 L .33336 .53365 L F
.049 .465 .883 r
.33326 .5336 m .33363 .5342 L .33307 .53358 L F
.33334 .53361 m .33336 .53365 L .33326 .5336 L F
.204 0 .221 r
.33334 .53361 m .33104 .5381 L .33336 .53365 L F
.33334 .53361 m .33311 .53735 L .33104 .5381 L F
.33339 .5335 m .33339 .53362 L .33334 .53361 L F
.33339 .53362 m .33311 .53735 L .33334 .53361 L F
.049 .465 .883 r
.33346 .53367 m .33484 .53462 L .33363 .5342 L F
.595 .315 .462 r
.33339 .5335 m .33348 .53367 L .33423 .534 L F
.229 .388 .815 r
.33441 .53399 m .33484 .53462 L .33423 .534 L F
.33514 .53396 m .33509 .53407 L .33441 .53399 L F
.33509 .53407 m .33484 .53462 L .33441 .53399 L F
.267 0 0 r
.33484 .53462 m .33909 .53577 L .33657 .53645 L F
.33484 .53462 m .33749 .53549 L .33909 .53577 L F
.229 .388 .815 r
.33593 .53223 m .33749 .53549 L .33484 .53462 L F
.595 .315 .462 r
.33583 .53469 m .33558 .538 L .33749 .53549 L F
.049 .465 .883 r
.33355 .5337 m .33484 .53462 L .33346 .53367 L F
.3342 .53397 m .33484 .53462 L .33346 .53364 L F
.595 .315 .462 r
.33348 .53367 m .33558 .538 L .33583 .53469 L F
.53 .155 .274 r
.33598 .53698 m .3337 .53391 L .33749 .53549 L F
.3337 .53391 m .33352 .53367 L .33416 .53396 L F
.3337 .53391 m .33416 .53396 L .33749 .53549 L F
.595 .315 .462 r
.33441 .53399 m .33423 .534 L .33583 .53469 L F
.33339 .5335 m .33423 .534 L .33441 .53399 L F
.229 .388 .815 r
.33593 .53223 m .33514 .53396 L .33326 .53301 L F
.53 .155 .274 r
.33352 .53367 m .33339 .5335 L .33441 .53399 L F
.229 .388 .815 r
.33441 .53399 m .33423 .534 L .3342 .53397 L F
.53 .155 .274 r
.3342 .53397 m .33441 .53399 L .33583 .53469 L F
.33352 .53367 m .33441 .53399 L .3342 .53397 L F
.229 .388 .815 r
.33514 .53396 m .33441 .53399 L .33326 .53301 L F
.33441 .53399 m .3342 .53397 L .33326 .53301 L F
0 0 .453 r
.33523 .53856 m .33558 .538 L .33538 .53895 L F
.33339 .5335 m .33558 .538 L .33523 .53856 L F
.552 .53 .785 r
.33235 .5376 m .33349 .53987 L .33538 .53895 L F
.333 0 .131 r
.33241 .54121 m .33465 .54072 L .33538 .53895 L F
.724 .785 .298 r
.33538 .53895 m .33465 .54072 L .33558 .538 L F
.551 .927 .919 r
.33465 .54072 m .33567 .53785 L .33558 .538 L F
.795 .949 .608 r
.33749 .53549 m .33558 .538 L .33598 .53698 L F
.551 .927 .919 r
.33567 .53785 m .33598 .53698 L .33558 .538 L F
.53 .155 .274 r
.33598 .53698 m .33311 .53735 L .33339 .53362 L F
.33352 .53367 m .33339 .53362 L .33339 .5335 L F
.049 .465 .883 r
.33346 .53364 m .33355 .5337 L .33346 .53367 L F
.33347 .53365 m .33355 .5337 L .33346 .53364 L F
.53 .155 .274 r
.33598 .53698 m .33339 .53362 L .33352 .53367 L F
.049 .465 .883 r
.33346 .53364 m .33347 .53365 L .33346 .53364 L F
.53 .155 .274 r
.33352 .53367 m .33583 .53469 L .33749 .53549 L F
.049 .465 .883 r
.33326 .53301 m .3342 .53397 L .33346 .53364 L F
.33326 .53301 m .33363 .5342 L .33317 .53328 L F
.766 .635 .716 r
.34438 .60587 m .34854 .60538 L .34791 .60272 L F
.387 0 0 r
.34686 .60675 m .34854 .60538 L .34438 .60587 L F
0 0 .42 r
.34791 .60272 m .34854 .60538 L .34917 .60459 L F
.53 .856 .571 r
.34917 .60459 m .34854 .60538 L .34686 .60675 L F
.826 .365 .118 r
.25709 .73671 m .26201 .73883 L .26036 .73642 L F
.46 .315 .597 r
.32364 .59885 m .3205 .60053 L .32312 .59631 L F
.638 .776 .947 r
.31872 .59843 m .3205 .60053 L .32364 .59885 L F
.37 .826 .724 r
.36927 .65853 m .36549 .66018 L .36722 .65953 L F
.481 .295 .551 r
.25358 .72152 m .25339 .72443 L .25619 .72119 L F
0 0 .398 r
.28793 .57307 m .28851 .57352 L .2884 .57118 L F
.497 .446 .731 r
.28793 .57307 m .29038 .57786 L .28851 .57352 L F
.605 .944 .936 r
.24614 .53225 m .24999 .53088 L .25101 .53106 L F
.426 .862 .924 r
.25101 .53106 m .25291 .53002 L .25336 .5305 L F
.25101 .53106 m .24999 .53088 L .25291 .53002 L F
.248 .458 .868 r
.3249 .53111 m .32653 .53409 L .32775 .53285 L F
0 0 0 r
.32653 .53409 m .32647 .53455 L .32775 .53285 L F
.32653 .53409 m .32512 .53599 L .32647 .53455 L F
.28 .191 .573 r
.36241 .61117 m .36436 .60682 L .36157 .61097 L F
.459 .066 .206 r
.30299 .5904 m .29913 .59258 L .29808 .58978 L F
.30299 .5904 m .30162 .59251 L .29913 .59258 L F
.007 0 0 r
.30456 .59123 m .30162 .59251 L .30299 .5904 L F
0 0 0 r
.33229 .56405 m .33407 .5637 L .33592 .56231 L F
.656 .177 .103 r
.33407 .5637 m .33808 .56418 L .33592 .56231 L F
.121 0 0 r
.26426 .54708 m .26354 .54801 L .26101 .54859 L F
.295 0 0 r
.26426 .54708 m .26595 .54772 L .26354 .54801 L F
.277 0 .011 r
.26666 .54651 m .26595 .54772 L .26426 .54708 L F
0 0 0 r
.27009 .61842 m .27057 .61963 L .27237 .61779 L F
.27009 .61842 m .26866 .6209 L .27057 .61963 L F
.327 .655 .971 r
.2888 .69334 m .28646 .69339 L .28708 .69203 L F
.28708 .69203 m .28646 .69339 L .2888 .69334 L F
.2888 .69334 m .28646 .69339 L .28708 .69203 L F
.475 .859 .65 r
.31532 .54642 m .31208 .54866 L .31331 .54724 L F
.971 .709 .477 r
.38808 .63716 m .38607 .63858 L .38653 .63569 L F
.485 .724 .977 r
.38945 .63545 m .38808 .63716 L .38653 .63569 L F
.561 .321 .509 r
.38945 .63545 m .38607 .63858 L .38808 .63716 L F
.504 .396 .665 r
.39105 .59551 m .38857 .59371 L .39123 .59313 L F
.39105 .59551 m .38877 .59642 L .38857 .59371 L F
.745 .707 .816 r
.32514 .54666 m .3265 .54992 L .32325 .54935 L F
.322 .46 .844 r
.32813 .54838 m .3265 .54992 L .32514 .54666 L F
.182 .228 .675 r
.32813 .54838 m .3286 .55101 L .3265 .54992 L F
.716 .567 .685 r
.35533 .68361 m .35137 .68059 L .35548 .68092 L F
.315 .363 .752 r
.31524 .58706 m .31782 .58956 L .31694 .58577 L F
.328 .227 .585 r
.30736 .56811 m .30922 .56424 L .30686 .56561 L F
.366 0 0 r
.32514 .54337 m .32359 .54501 L .32135 .54494 L F
.222 .101 .495 r
.32709 .5399 m .32699 .54268 L .32514 .54337 L F
.384 .807 .971 r
.32514 .54337 m .32787 .54264 L .32699 .54268 L F
.762 .601 .679 r
.32699 .54268 m .32359 .54501 L .32514 .54337 L F
.09 .34 .813 r
.38597 .52814 m .38831 .52959 L .38762 .53102 L F
.15 .418 .86 r
.38831 .52959 m .39071 .53309 L .38762 .53102 L F
.985 .73 .458 r
.2611 .53931 m .26222 .5425 L .26268 .54038 L F
.707 .895 .965 r
.2622 .53798 m .26268 .54038 L .26456 .53757 L F
.26216 .53803 m .26268 .54038 L .2622 .53798 L F
.26215 .53799 m .2611 .53931 L .26268 .54038 L F
.579 .935 .931 r
.26591 .53665 m .26215 .53799 L .26456 .53757 L F
0 0 0 r
.26591 .53665 m .26275 .5376 L .26215 .53799 L F
.157 0 0 r
.26149 .54063 m .26113 .53943 L .26275 .5376 L F
.26113 .53943 m .2611 .53931 L .26161 .53878 L F
.26113 .53943 m .26161 .53878 L .26275 .5376 L F
.707 .895 .965 r
.26215 .53799 m .26216 .53803 L .2622 .53798 L F
.597 .633 .858 r
.26268 .54038 m .26523 .54036 L .26456 .53757 L F
.513 .182 .342 r
.26222 .5425 m .26523 .54036 L .26268 .54038 L F
.471 .287 .55 r
.38876 .59909 m .38641 .59972 L .38877 .59642 L F
.71 .753 .886 r
.36669 .67256 m .36309 .67219 L .36544 .6713 L F
.653 .802 .955 r
.36544 .6713 m .36909 .67169 L .36669 .67256 L F
.549 .483 .734 r
.33145 .64911 m .33371 .64573 L .33122 .64682 L F
0 0 0 r
.31208 .54866 m .30986 .55203 L .3108 .55008 L F
.816 .779 .275 r
.28642 .59509 m .28616 .59526 L .28683 .5932 L F
0 0 0 r
.28683 .5932 m .28616 .59526 L .28808 .59177 L F
.799 .733 .791 r
.35553 .66491 m .35607 .66399 L .35575 .66492 L F
0 0 0 r
.35439 .66477 m .35643 .66337 L .35607 .66399 L F
.35607 .66399 m .35345 .66704 L .35439 .66477 L F
.799 .733 .791 r
.35139 .66463 m .35345 .66704 L .35607 .66399 L F
.35139 .66463 m .35607 .66399 L .35553 .66491 L F
0 0 0 r
.35643 .66337 m .35776 .66246 L .35607 .66399 L F
.35776 .66246 m .35714 .66294 L .35607 .66399 L F
.427 .677 .967 r
.19564 .6025 m .19977 .60567 L .2006 .60451 L F
.397 .089 .321 r
.31467 .64837 m .31523 .64648 L .31755 .64592 L F
.899 .637 .534 r
.31479 .62678 m .31761 .62777 L .31514 .62442 L F
.728 .906 .957 r
.31408 .62801 m .31761 .62777 L .31479 .62678 L F
.31408 .62801 m .31488 .62867 L .31761 .62777 L F
.671 .419 .531 r
.31488 .62867 m .31728 .63033 L .31761 .62777 L F
.533 .297 .503 r
.31761 .62777 m .31728 .63033 L .32013 .6276 L F
.492 .751 .987 r
.30179 .58274 m .30413 .58417 L .29956 .58334 L F
.582 .045 0 r
.29956 .58334 m .30445 .58437 L .30342 .58394 L F
.492 .751 .987 r
.30412 .58423 m .30445 .58437 L .3041 .5843 L F
0 .261 .665 r
.30457 .58445 m .30365 .58404 L .30445 .58437 L F
.30365 .58404 m .30342 .58394 L .30445 .58437 L F
.492 .751 .987 r
.30413 .58417 m .30445 .58437 L .30412 .58423 L F
.30413 .58417 m .3041 .5843 L .29956 .58334 L F
.18 .427 .861 r
.30623 .58546 m .30553 .58707 L .304 .58481 L F
.3041 .58431 m .304 .58481 L .30342 .58394 L F
.30623 .58546 m .304 .58481 L .3041 .58431 L F
.992 .847 .486 r
.30623 .58546 m .30655 .58817 L .30553 .58707 L F
.415 .216 .5 r
.26998 .72717 m .26744 .72833 L .26975 .73005 L F
.26998 .72717 m .26744 .72833 L .26975 .73005 L F
.777 .403 .347 r
.20255 .8276 m .20509 .82769 L .20313 .82995 L F
.6 .29 .416 r
.20313 .82995 m .20486 .82772 L .20255 .8276 L F
.67 .882 .513 r
.20472 .82775 m .20486 .82772 L .20313 .82995 L F
.20554 .82661 m .20486 .82772 L .20472 .82775 L F
.069 0 0 r
.20486 .82772 m .20509 .82769 L .20503 .82769 L F
.20486 .82772 m .20503 .82769 L .20255 .8276 L F
.377 .772 .987 r
.20554 .82661 m .20509 .82769 L .20486 .82772 L F
.20554 .82661 m .20745 .82749 L .20509 .82769 L F
.20509 .82769 m .20554 .82661 L .20313 .82995 L F
.20509 .82769 m .20745 .82749 L .20554 .82661 L F
.685 .632 .791 r
.32411 .56043 m .32258 .56174 L .32171 .55873 L F
.3 0 0 r
.32347 .56333 m .32258 .56174 L .32411 .56043 L F
.32347 .56333 m .32103 .56385 L .32258 .56174 L F
.727 .54 .637 r
.29029 .56423 m .29314 .56232 L .28972 .56218 L F
.633 .314 .413 r
.40035 .5643 m .39713 .56445 L .39737 .5624 L F
.194 0 0 r
.31097 .62853 m .31201 .62948 L .30887 .62893 L F
.31097 .62853 m .31408 .62801 L .31201 .62948 L F
.818 .604 .614 r
.36081 .69016 m .35674 .69237 L .35659 .69019 L F
.36081 .69016 m .36048 .69302 L .35674 .69237 L F
.051 0 0 r
.19536 .55925 m .19406 .56095 L .19727 .55835 L F
.491 .771 .994 r
.3585 .63984 m .36218 .64043 L .36058 .64086 L F
.497 .532 .823 r
.36218 .64043 m .36339 .64222 L .36058 .64086 L F
.389 .183 .475 r
.26284 .55608 m .26467 .55749 L .26542 .55621 L F
.26284 .55608 m .26261 .55844 L .26467 .55749 L F
.769 .591 .658 r
.32366 .63068 m .32662 .62644 L .32375 .62765 L F
.32366 .63068 m .32776 .63069 L .32662 .62644 L F
.111 0 .284 r
.32662 .62644 m .32799 .62695 L .32854 .62395 L F
.161 .203 .657 r
.32662 .62644 m .32924 .62922 L .32799 .62695 L F
.32662 .62644 m .32776 .63069 L .32924 .62922 L F
0 0 0 r
.30835 .57666 m .30661 .5777 L .30962 .57496 L F
.31094 .5735 m .30835 .57666 L .30962 .57496 L F
.545 .876 .991 r
.29534 .52662 m .29604 .52507 L .29793 .52571 L F
.29534 .52662 m .29392 .52603 L .29604 .52507 L F
.363 .299 .651 r
.31555 .63682 m .31817 .63934 L .31756 .63576 L F
.274 .286 .691 r
.31555 .63682 m .31708 .64041 L .31817 .63934 L F
.354 .273 .624 r
.32111 .57413 m .3216 .57695 L .31986 .57767 L F
.334 .222 .574 r
.3216 .57695 m .32001 .58 L .31986 .57767 L F
0 0 0 r
.22041 .54043 m .21767 .54329 L .21946 .54168 L F
.086 0 0 r
.22041 .54043 m .22164 .54062 L .22264 .53966 L F
.22041 .54043 m .21946 .54168 L .22164 .54062 L F
.023 0 0 r
.29206 .54355 m .2946 .54193 L .29576 .54314 L F
0 0 0 r
.29717 .54439 m .29665 .54393 L .29891 .5434 L F
0 .044 .528 r
.29665 .54393 m .29818 .54532 L .29612 .54347 L F
.977 .744 .519 r
.29665 .54393 m .29632 .54746 L .29818 .54532 L F
0 0 0 r
.29628 .5449 m .29665 .54393 L .29717 .54439 L F
0 .044 .528 r
.29665 .54393 m .29612 .54347 L .29576 .54314 L F
.982 .74 .493 r
.26403 .74019 m .2639 .74295 L .2623 .74272 L F
.484 .296 .549 r
.26619 .74249 m .2639 .74295 L .26403 .74019 L F
.69 .151 0 r
.26442 .74165 m .26403 .74019 L .2623 .74272 L F
.26442 .74165 m .26619 .74249 L .26403 .74019 L F
.729 .335 .302 r
.2623 .74272 m .26403 .74019 L .25988 .7399 L F
.685 .632 .791 r
.32411 .56043 m .32171 .55873 L .32517 .55882 L F
.277 0 .2 r
.32758 .55817 m .32411 .56043 L .32517 .55882 L F
.207 0 0 r
.33684 .57364 m .3389 .57345 L .34109 .57148 L F
.313 .306 .692 r
.34109 .57148 m .34206 .56707 L .34006 .56755 L F
.34109 .57148 m .34321 .57164 L .34206 .56707 L F
.192 .062 .463 r
.34478 .57375 m .34109 .57148 L .34321 .57164 L F
.269 0 0 r
.34109 .57148 m .34193 .57282 L .34321 .57164 L F
.34109 .57148 m .3389 .57345 L .34193 .57282 L F
0 0 .42 r
.34791 .60272 m .34917 .60459 L .35025 .60213 L F
.809 .956 .623 r
.35709 .53284 m .35668 .53435 L .35905 .53066 L F
.895 .98 .696 r
.35709 .53284 m .3552 .53706 L .35668 .53435 L F
.097 .464 .889 r
.29993 .65034 m .30078 .65253 L .30154 .65226 L F
.812 .714 .757 r
.30246 .6561 m .30154 .65226 L .30078 .65253 L F
.123 0 0 r
.34059 .561 m .34346 .56054 L .34206 .56177 L F
.388 .556 .898 r
.33102 .63617 m .33342 .63986 L .33513 .63944 L F
.251 .024 .361 r
.33513 .63944 m .33342 .63986 L .33279 .64268 L F
.55 .037 0 r
.24862 .55043 m .24682 .55147 L .2441 .55109 L F
0 0 0 r
.25119 .55086 m .24682 .55147 L .24862 .55043 L F
.27166 .6257 m .2717 .62516 L .27404 .62344 L F
.27166 .6257 m .2702 .62671 L .2717 .62516 L F
.21767 .54329 m .21777 .54368 L .21946 .54168 L F
.21767 .54329 m .21558 .54441 L .21777 .54368 L F
.897 .478 .156 r
.38513 .54683 m .38322 .54615 L .38297 .54536 L F
.431 .146 .379 r
.38513 .54683 m .38417 .54908 L .38661 .54841 L F
.38513 .54683 m .38661 .54841 L .38322 .54615 L F
.82 .592 .594 r
.38089 .63411 m .38064 .63603 L .38236 .635 L F
.26 0 .202 r
.32476 .57121 m .3268 .57068 L .3277 .56883 L F
0 0 0 r
.28797 .62472 m .28847 .62533 L .29054 .62442 L F
.049 0 0 r
.23496 .53548 m .23134 .53583 L .23373 .53532 L F
.307 .799 .808 r
.23598 .53487 m .23496 .53548 L .23373 .53532 L F
.23598 .53487 m .23796 .53463 L .23496 .53548 L F
.73 .222 .015 r
.30366 .57626 m .30661 .5777 L .30317 .57666 L F
.18 0 0 r
.30685 .5785 m .30443 .57883 L .30661 .5777 L F
.456 .313 .598 r
.30617 .58075 m .30549 .58025 L .30685 .5785 L F
.30549 .58025 m .30341 .57875 L .30437 .57868 L F
.30549 .58025 m .30437 .57868 L .30685 .5785 L F
.752 .261 .064 r
.30365 .57681 m .30437 .57868 L .30317 .57666 L F
.30437 .57868 m .30443 .57883 L .30421 .57846 L F
.30437 .57868 m .30421 .57846 L .30317 .57666 L F
.55 .135 .208 r
.30437 .57868 m .30443 .57883 L .30685 .5785 L F
.30341 .57875 m .30443 .57883 L .30437 .57868 L F
.752 .261 .064 r
.30661 .5777 m .30443 .57883 L .30365 .57681 L F
.18 0 0 r
.30685 .5785 m .30661 .5777 L .30835 .57666 L F
.429 .305 .608 r
.3191 .66541 m .32139 .66777 L .32159 .66458 L F
.389 .367 .714 r
.37259 .56436 m .37517 .56796 L .37398 .56421 L F
.28 .026 .339 r
.37921 .55267 m .37665 .55579 L .37889 .55471 L F
0 0 .128 r
.37665 .55579 m .37762 .55694 L .37889 .55471 L F
.37665 .55579 m .37618 .55823 L .37762 .55694 L F
.155 .439 .874 r
.35483 .61777 m .35614 .62096 L .35402 .61874 L F
.609 .761 .952 r
.35884 .61836 m .35614 .62096 L .35483 .61777 L F
.74 .761 .87 r
.36059 .67476 m .35647 .67444 L .35852 .67332 L F
.778 .758 .835 r
.36309 .67219 m .36059 .67476 L .35852 .67332 L F
.628 .642 .845 r
.38437 .56512 m .38298 .56835 L .38286 .56454 L F
.38437 .56512 m .38559 .56805 L .38298 .56835 L F
.396 .4 .746 r
.38298 .56835 m .38587 .57058 L .38559 .56805 L F
.649 .418 .555 r
.38559 .56805 m .38336 .57072 L .38298 .56835 L F
.724 .472 .545 r
.36442 .69534 m .36048 .69302 L .36451 .69325 L F
.676 .388 .477 r
.36451 .69325 m .36677 .69594 L .36442 .69534 L F
.679 .388 .473 r
.3667 .69356 m .36677 .69594 L .36451 .69325 L F
.056 .393 .852 r
.22001 .60669 m .21862 .60713 L .21764 .60464 L F
.22001 .60669 m .22073 .60823 L .21862 .60713 L F
.15 0 0 r
.25736 .5297 m .25561 .52989 L .25956 .52982 L F
.549 .847 .998 r
.27155 .64248 m .27326 .64258 L .27363 .64187 L F
.379 .75 .991 r
.27326 .64258 m .27811 .64277 L .27363 .64187 L F
.568 .767 .972 r
.30455 .52593 m .30169 .52567 L .3039 .52524 L F
.542 .719 .955 r
.30704 .52464 m .30455 .52593 L .3039 .52524 L F
.30704 .52464 m .30811 .52607 L .30455 .52593 L F
.383 .385 .738 r
.35842 .55172 m .35682 .55282 L .35622 .55032 L F
.125 0 .332 r
.35842 .55172 m .35642 .55523 L .35682 .55282 L F
.941 .912 .531 r
.25709 .73671 m .25732 .74049 L .25988 .7399 L F
.38 .749 .991 r
.36528 .51455 m .36447 .51575 L .36299 .51484 L F
.36528 .51455 m .36723 .51566 L .36447 .51575 L F
.363 .801 .961 r
.30266 .52487 m .30169 .52567 L .30019 .52532 L F
.30266 .52487 m .3039 .52524 L .30169 .52567 L F
.376 0 0 r
.30652 .64329 m .30078 .64296 L .30289 .64316 L F
.738 .385 .382 r
.30289 .64316 m .3073 .64399 L .30652 .64329 L F
.573 .008 0 r
.27111 .56037 m .27389 .56274 L .2717 .56148 L F
.131 0 0 r
.27344 .55965 m .27111 .56037 L .27049 .56014 L F
.373 .836 .781 r
.27571 .55886 m .27111 .56037 L .27344 .55965 L F
.27571 .55886 m .27293 .55953 L .27111 .56037 L F
.341 .254 .61 r
.27293 .55953 m .27389 .56274 L .27111 .56037 L F
.573 .008 0 r
.27111 .56037 m .2717 .56148 L .27216 .56075 L F
.27111 .56037 m .27216 .56075 L .27293 .55953 L F
.131 0 0 r
.27049 .56014 m .27111 .56037 L .27034 .56017 L F
0 0 0 r
.18981 .56505 m .19091 .5645 L .19248 .56206 L F
.23 0 .084 r
.19248 .56206 m .19329 .56361 L .19406 .56095 L F
.19248 .56206 m .19091 .5645 L .19329 .56361 L F
.842 .705 .711 r
.36305 .65598 m .35857 .65878 L .35858 .65818 L F
.36305 .65598 m .35858 .65818 L .36097 .65752 L F
.751 .917 .548 r
.3652 .65263 m .36305 .65598 L .36363 .65438 L F
.579 .408 .614 r
.36121 .6522 m .36237 .65609 L .35738 .65644 L F
.53 .331 .556 r
.3615 .65713 m .3622 .65629 L .36305 .65598 L F
.36228 .65622 m .3635 .65474 L .36335 .65514 L F
.36237 .65609 m .3635 .65474 L .36228 .65622 L F
.423 .315 .627 r
.36363 .65438 m .36242 .65628 L .36237 .65609 L F
.36363 .65438 m .36237 .65609 L .36121 .6522 L F
.53 .331 .556 r
.3622 .65629 m .36237 .65609 L .36228 .65622 L F
.3622 .65629 m .36335 .65514 L .36305 .65598 L F
.494 .32 .574 r
.36097 .65752 m .35738 .65644 L .3622 .65629 L F
.36097 .65752 m .3622 .65629 L .36242 .65628 L F
.579 .408 .614 r
.36237 .65609 m .36242 .65628 L .3622 .65629 L F
.36237 .65609 m .3622 .65629 L .35738 .65644 L F
.53 .331 .556 r
.36097 .65752 m .36363 .65438 L .3635 .65474 L F
.36097 .65752 m .3635 .65474 L .3615 .65713 L F
.442 .86 .951 r
.35433 .63418 m .35502 .63334 L .35712 .63344 L F
.573 .561 .802 r
.35834 .63703 m .35433 .63418 L .35712 .63344 L F
.398 .102 .343 r
.3268 .57068 m .32965 .56802 L .3277 .56883 L F
.421 .19 .456 r
.37889 .55471 m .38118 .55195 L .37921 .55267 L F
0 0 .119 r
.39105 .59551 m .38876 .59909 L .38877 .59642 L F
.37 .41 .772 r
.32188 .57944 m .32132 .58351 L .32001 .58 L F
.675 .541 .695 r
.32458 .58687 m .32132 .58351 L .32296 .58328 L F
.32458 .58687 m .32189 .58754 L .32132 .58351 L F
.319 0 .168 r
.18787 .56673 m .19091 .5645 L .18981 .56505 L F
.655 .139 0 r
.35903 .61024 m .35795 .61103 L .3557 .60908 L F
0 .435 .724 r
.35903 .61024 m .35829 .60827 L .35795 .61103 L F
.558 .304 .488 r
.31318 .59586 m .31598 .59512 L .31652 .59316 L F
.528 .426 .682 r
.31598 .59512 m .31834 .59207 L .31652 .59316 L F
.873 .763 .258 r
.28642 .59509 m .2857 .59786 L .28616 .59526 L F
.28642 .59509 m .28596 .59953 L .2857 .59786 L F
.125 0 .406 r
.36626 .59887 m .36768 .59555 L .36614 .59633 L F
.537 .833 .999 r
.3546 .60802 m .3557 .60908 L .35186 .60885 L F
.578 .068 .004 r
.35186 .60885 m .3557 .60908 L .35367 .61033 L F
.541 .835 .999 r
.35829 .60827 m .3557 .60908 L .3546 .60802 L F
.448 .244 .509 r
.3557 .60908 m .3546 .60802 L .35367 .61033 L F
.3557 .60908 m .35829 .60827 L .3546 .60802 L F
.3557 .60908 m .35795 .61103 L .35829 .60827 L F
.65 .158 .069 r
.3557 .60908 m .35795 .61103 L .35367 .61033 L F
.894 .928 .834 r
.30996 .62461 m .30742 .62863 L .3062 .62748 L F
.826 .617 .62 r
.33722 .62121 m .33926 .62144 L .33828 .61834 L F
.683 .595 .75 r
.33926 .62144 m .34035 .61728 L .33828 .61834 L F
.727 .54 .637 r
.29029 .56423 m .294 .56494 L .29314 .56232 L F
.359 0 0 r
.23087 .5591 m .22894 .56066 L .22648 .56077 L F
.214 .724 .89 r
.25165 .63443 m .25382 .63491 L .25556 .63464 L F
.502 .412 .686 r
.36784 .5904 m .37012 .58987 L .36917 .58495 L F
.499 .413 .689 r
.36784 .5904 m .37062 .59261 L .37012 .58987 L F
.36784 .5904 m .36838 .59324 L .37062 .59261 L F
.178 0 .192 r
.18357 .57055 m .18631 .56781 L .18413 .5685 L F
.887 .771 .729 r
.37507 .61106 m .37737 .61216 L .37761 .61146 L F
.37649 .61013 m .37761 .61146 L .37854 .6088 L F
.37507 .61106 m .37761 .61146 L .37649 .61013 L F
.37507 .61106 m .37854 .6088 L .37747 .61014 L F
.602 .511 .724 r
.37445 .60771 m .37747 .61014 L .37506 .60769 L F
.37374 .60772 m .37533 .60875 L .37445 .60771 L F
.37533 .60875 m .37747 .61014 L .37445 .60771 L F
.718 .38 .405 r
.38097 .60849 m .37747 .61014 L .37854 .6088 L F
.777 .521 .548 r
.29845 .54008 m .29735 .54317 L .2946 .54193 L F
.359 .027 .26 r
.3006 .54018 m .29735 .54317 L .29845 .54008 L F
0 .328 .813 r
.35701 .58784 m .35839 .58843 L .35823 .59001 L F
.797 .993 .758 r
.35839 .58843 m .35614 .59098 L .35823 .59001 L F
.669 .538 .696 r
.36001 .64623 m .35731 .64652 L .36043 .64372 L F
.066 .458 .883 r
.29558 .58647 m .29762 .58334 L .29492 .58409 L F
.77 .691 .776 r
.35965 .63033 m .36111 .63388 L .35712 .63344 L F
.585 .552 .783 r
.36066 .63642 m .35712 .63344 L .36111 .63388 L F
.101 .273 .753 r
.35009 .58641 m .35141 .58977 L .35235 .58791 L F
.575 .039 0 r
.35009 .58641 m .35235 .58791 L .35411 .58691 L F
.628 .914 .98 r
.35235 .58791 m .35069 .58753 L .35311 .58643 L F
.35235 .58791 m .35311 .58643 L .35328 .58635 L F
.101 .273 .753 r
.35141 .58977 m .35155 .59014 L .35235 .58791 L F
.009 .218 .729 r
.35965 .63033 m .36043 .63106 L .36111 .63388 L F
.36043 .63106 m .36169 .63282 L .36111 .63388 L F
.497 .493 .783 r
.36169 .63282 m .36066 .63642 L .36111 .63388 L F
.36189 .63244 m .36158 .63346 L .36169 .63282 L F
.36158 .63346 m .36066 .63642 L .36169 .63282 L F
.585 .552 .783 r
.36066 .63642 m .35834 .63703 L .35712 .63344 L F
.497 .493 .783 r
.36158 .63346 m .36318 .6359 L .36066 .63642 L F
.36268 .63456 m .36318 .6359 L .36232 .6346 L F
.71 .613 .747 r
.3656 .63557 m .36318 .6359 L .36268 .63456 L F
.592 .123 .11 r
.36297 .63452 m .36311 .63449 L .36306 .63449 L F
.766 .494 .523 r
.36218 .63405 m .36306 .63449 L .36189 .63244 L F
.497 .493 .783 r
.36218 .63405 m .36226 .63451 L .36158 .63346 L F
.766 .494 .523 r
.35825 .63211 m .36289 .6345 L .36278 .63435 L F
.36278 .63435 m .36289 .6345 L .36306 .63449 L F
0 0 .197 r
.36306 .63449 m .36391 .63291 L .36189 .63244 L F
.71 .613 .747 r
.36587 .63336 m .36189 .63244 L .36594 .63279 L F
0 0 .197 r
.36391 .63291 m .36392 .63289 L .36189 .63244 L F
.71 .613 .747 r
.3656 .63557 m .36352 .63381 L .36587 .63336 L F
.36352 .63381 m .36391 .63291 L .36587 .63336 L F
0 0 .197 r
.36391 .63291 m .36416 .63452 L .36392 .63289 L F
.71 .613 .747 r
.36273 .63456 m .36268 .63456 L .36267 .63453 L F
.497 .493 .783 r
.36268 .63456 m .36232 .6346 L .36226 .63451 L F
.279 0 0 r
.358 .63484 m .3593 .63556 L .36297 .63452 L F
.36263 .63452 m .36297 .63452 L .36306 .63449 L F
.71 .613 .747 r
.36277 .63452 m .36273 .63456 L .36271 .63452 L F
.497 .493 .783 r
.36267 .63453 m .36268 .63456 L .36226 .63451 L F
.279 0 0 r
.358 .63484 m .36297 .63452 L .36263 .63452 L F
.71 .613 .747 r
.36352 .63381 m .36277 .63452 L .36189 .63244 L F
.36277 .63452 m .36271 .63452 L .36189 .63244 L F
.36413 .63432 m .36311 .63449 L .36352 .63381 L F
0 0 .197 r
.36306 .63449 m .36311 .63449 L .36391 .63291 L F
.71 .613 .747 r
.36311 .63449 m .36273 .63456 L .36352 .63381 L F
0 0 .197 r
.36311 .63449 m .36322 .63449 L .36352 .63381 L F
.36311 .63449 m .36352 .63381 L .36391 .63291 L F
.36322 .63449 m .36416 .63452 L .36391 .63291 L F
.71 .613 .747 r
.36352 .63381 m .36189 .63244 L .36391 .63291 L F
.766 .494 .523 r
.36236 .63423 m .36265 .63452 L .36289 .6345 L F
.71 .613 .747 r
.36273 .63456 m .36267 .63453 L .36189 .63244 L F
.3656 .63557 m .36268 .63456 L .36413 .63432 L F
.592 .123 .11 r
.36288 .63454 m .36327 .6345 L .36311 .63449 L F
.36288 .63454 m .36311 .63449 L .36297 .63452 L F
.3593 .63556 m .36416 .63452 L .36327 .6345 L F
.3593 .63556 m .36327 .6345 L .36288 .63454 L F
.497 .493 .783 r
.36267 .63453 m .36226 .63451 L .36218 .63405 L F
.36189 .63244 m .36267 .63453 L .36158 .63346 L F
.009 .218 .729 r
.36043 .63106 m .36189 .63244 L .36169 .63282 L F
.766 .494 .523 r
.35825 .63211 m .36218 .63405 L .36189 .63244 L F
.36152 .6338 m .36138 .63461 L .36265 .63452 L F
.36152 .6338 m .36265 .63452 L .36236 .63423 L F
.35825 .63211 m .358 .63484 L .36138 .63461 L F
.35825 .63211 m .36138 .63461 L .36152 .6338 L F
.751 .917 .548 r
.3652 .65263 m .36363 .65438 L .36408 .65174 L F
.037 .356 .83 r
.28562 .64651 m .28481 .64532 L .2858 .64637 L F
.722 .386 .409 r
.2858 .64637 m .28802 .64921 L .28562 .64651 L F
.898 .876 .806 r
.36994 .61507 m .36578 .61722 L .36709 .6152 L F
.36994 .61507 m .36719 .61825 L .36578 .61722 L F
.676 .484 .618 r
.37005 .61766 m .36719 .61825 L .36994 .61507 L F
.545 .382 .611 r
.3732 .61692 m .36994 .61507 L .37273 .61464 L F
.3732 .61692 m .37005 .61766 L .36994 .61507 L F
0 0 .542 r
.39543 .54009 m .39681 .54267 L .39626 .54317 L F
.005 0 .471 r
.39791 .54439 m .39626 .54317 L .39681 .54267 L F
.39791 .54439 m .3966 .54654 L .39626 .54317 L F
.505 .188 .364 r
.27117 .63048 m .27408 .63015 L .27494 .62704 L F
.291 0 .283 r
.27494 .62704 m .2761 .62936 L .27739 .62632 L F
.27494 .62704 m .27408 .63015 L .2761 .62936 L F
.531 .137 .238 r
.2816 .61812 m .28108 .6204 L .27869 .62029 L F
0 0 0 r
.28511 .61494 m .28387 .61715 L .2816 .61812 L F
.016 0 .091 r
.28387 .61715 m .28108 .6204 L .2816 .61812 L F
0 0 0 r
.36122 .61988 m .36123 .61922 L .35884 .61836 L F
.36122 .61988 m .36362 .61841 L .36123 .61922 L F
.635 .222 .243 r
.28948 .54322 m .29151 .54491 L .29206 .54355 L F
.841 .69 .696 r
.29007 .54146 m .29151 .54491 L .28948 .54322 L F
.588 .281 .415 r
.22453 .55875 m .22648 .56077 L .22392 .5607 L F
.669 .942 .963 r
.39323 .58232 m .39258 .58383 L .3911 .58331 L F
0 0 .359 r
.39323 .58232 m .39317 .58636 L .39258 .58383 L F
.304 0 .1 r
.35459 .56968 m .35857 .56667 L .35511 .5668 L F
0 0 0 r
.35509 .56694 m .35427 .57094 L .35459 .56968 L F
.35521 .5663 m .35514 .56662 L .35514 .56666 L F
.35514 .56662 m .35489 .56789 L .3551 .56688 L F
.35514 .56662 m .3551 .56688 L .35514 .56666 L F
.35489 .56789 m .35427 .57094 L .35514 .56666 L F
.304 0 .1 r
.35459 .56968 m .35511 .5668 L .3549 .5668 L F
.318 0 .128 r
.3551 .56688 m .35459 .56968 L .3549 .5668 L F
.35719 .56776 m .35459 .56968 L .3551 .56688 L F
0 0 0 r
.35514 .56666 m .35509 .56694 L .35459 .56968 L F
.304 0 .1 r
.35459 .56968 m .35698 .56911 L .35806 .56745 L F
.35722 .56769 m .35806 .56745 L .35857 .56667 L F
.35459 .56968 m .35806 .56745 L .35722 .56769 L F
.88 .811 .777 r
.35698 .56911 m .36096 .56684 L .35857 .56667 L F
.218 .734 .709 r
.3633 .56596 m .35772 .56745 L .3584 .56587 L F
.532 .833 .999 r
.36528 .56489 m .36473 .56454 L .36584 .56308 L F
.36473 .56454 m .36375 .56391 L .36433 .56368 L F
.36473 .56454 m .36433 .56368 L .36584 .56308 L F
.631 .154 .103 r
.3633 .56596 m .36203 .5645 L .36353 .56401 L F
.61 .618 .834 r
.36423 .56378 m .36203 .5645 L .3582 .55958 L F
.532 .833 .999 r
.36528 .56489 m .36584 .56308 L .3677 .5618 L F
.621 .48 .668 r
.3677 .5618 m .36808 .56508 L .36528 .56489 L F
.315 .165 .512 r
.36713 .5665 m .36528 .56489 L .36808 .56508 L F
.459 .177 .397 r
.36375 .56391 m .36563 .56584 L .36584 .56308 L F
.61 .618 .834 r
.36423 .56378 m .3582 .55958 L .36303 .55757 L F
0 0 0 r
.36373 .56237 m .3633 .56596 L .36423 .56378 L F
.36343 .56152 m .36342 .56171 L .36373 .56237 L F
.36342 .56171 m .3633 .56596 L .36373 .56237 L F
.219 0 .011 r
.36337 .5647 m .36006 .56677 L .3633 .56596 L F
.36337 .5647 m .36261 .56603 L .36006 .56677 L F
.218 .734 .709 r
.36317 .56599 m .36006 .56677 L .36307 .56602 L F
.219 0 .011 r
.36261 .56603 m .36248 .56627 L .36006 .56677 L F
.218 .734 .709 r
.3578 .56742 m .36006 .56677 L .35772 .56745 L F
.36307 .56602 m .36006 .56677 L .3578 .56742 L F
.3633 .56596 m .36317 .56599 L .36307 .56602 L F
.426 .435 .766 r
.35616 .56336 m .35719 .56776 L .3551 .56688 L F
.35539 .56546 m .3551 .56688 L .3549 .5668 L F
.35616 .56336 m .3551 .56688 L .35539 .56546 L F
0 0 0 r
.3549 .5668 m .35427 .57094 L .35459 .56968 L F
.548 .455 .701 r
.35031 .54975 m .34834 .54847 L .3503 .54649 L F
.35031 .54975 m .34857 .55059 L .34834 .54847 L F
.687 .744 .895 r
.23907 .63228 m .2408 .63424 L .24301 .63313 L F
.576 .425 .639 r
.31095 .59892 m .31318 .59586 L .31057 .59649 L F
.31095 .59892 m .31302 .59877 L .31318 .59586 L F
.593 .527 .75 r
.31095 .59892 m .31531 .60111 L .31302 .59877 L F
.31095 .59892 m .31452 .60254 L .31531 .60111 L F
.818 .406 0 r
.23883 .61732 m .24075 .62029 L .23996 .61872 L F
.259 .507 .901 r
.32251 .66961 m .32358 .66785 L .32139 .66777 L F
.031 .592 .803 r
.32251 .66961 m .32645 .66999 L .3255 .67034 L F
.259 .507 .901 r
.32251 .66961 m .3255 .67034 L .32358 .66785 L F
.647 .313 .391 r
.29644 .54905 m .293 .55142 L .29348 .54969 L F
.29644 .54905 m .29554 .55183 L .293 .55142 L F
.568 .233 .362 r
.29889 .55119 m .29644 .54905 L .29869 .54799 L F
.29889 .55119 m .29554 .55183 L .29644 .54905 L F
.937 .921 .77 r
.34468 .60726 m .34175 .61185 L .34425 .61085 L F
.387 0 0 r
.34686 .60675 m .34438 .60587 L .34468 .60726 L F
.484 .315 .575 r
.34425 .61085 m .34686 .60675 L .34468 .60726 L F
.558 .726 .953 r
.31531 .60111 m .31843 .60261 L .31678 .60078 L F
.46 .21 .447 r
.31799 .60501 m .31843 .60261 L .31563 .60574 L F
.661 .749 .915 r
.31678 .60078 m .31843 .60261 L .32087 .60166 L F
.479 .226 .453 r
.32087 .60166 m .31843 .60261 L .31799 .60501 L F
.28 .349 .756 r
.33277 .52618 m .33104 .52798 L .32999 .52414 L F
.938 .85 .415 r
.33277 .52618 m .33249 .52979 L .33104 .52798 L F
.547 .287 .473 r
.27739 .62632 m .27998 .62627 L .27769 .62436 L F
.398 .091 .323 r
.37737 .61216 m .37683 .61404 L .37559 .61336 L F
.524 0 0 r
.35235 .58791 m .35701 .58784 L .35411 .58691 L F
.545 .034 0 r
.30489 .5403 m .30293 .54155 L .3006 .54018 L F
0 0 0 r
.22663 .53754 m .23134 .53583 L .22922 .537 L F
.31358 .57001 m .31094 .5735 L .31219 .57195 L F
.336 .219 .569 r
.30871 .54322 m .30893 .54592 L .31063 .54512 L F
.445 .013 .123 r
.36661 .62856 m .36564 .63018 L .36234 .6305 L F
.469 .036 .135 r
.36823 .62981 m .36564 .63018 L .36661 .62856 L F
.341 .082 .367 r
.36885 .62731 m .36823 .62981 L .36661 .62856 L F
.681 .39 .473 r
.37066 .69569 m .3667 .69356 L .37079 .69313 L F
.37066 .69569 m .36677 .69594 L .3667 .69356 L F
.964 .86 .455 r
.34221 .53869 m .34313 .53698 L .34186 .53581 L F
.34221 .53869 m .34224 .54076 L .34313 .53698 L F
.558 .53 .78 r
.39741 .58022 m .39501 .58079 L .39397 .57778 L F
.39741 .58022 m .39501 .58079 L .39397 .57778 L F
.716 .34 .336 r
.36709 .6152 m .36578 .61722 L .36374 .61455 L F
.232 0 .295 r
.23525 .55223 m .23484 .55534 L .23263 .5552 L F
.263 .156 .539 r
.23459 .55624 m .23263 .5552 L .23484 .55534 L F
.23459 .55624 m .23293 .55797 L .23263 .5552 L F
.066 .458 .883 r
.29558 .58647 m .29526 .58506 L .29762 .58334 L F
.29558 .58647 m .29661 .58678 L .29526 .58506 L F
.439 .545 .867 r
.34006 .56755 m .34032 .5634 L .33808 .56418 L F
.542 .706 .947 r
.34206 .56707 m .34349 .56598 L .34032 .5634 L F
.34349 .56598 m .34426 .5654 L .34246 .56448 L F
.34349 .56598 m .34246 .56448 L .34032 .5634 L F
.439 .545 .867 r
.34006 .56755 m .34206 .56707 L .34179 .5665 L F
.34006 .56755 m .34179 .5665 L .34013 .56648 L F
.413 .604 .925 r
.34426 .5654 m .34443 .56653 L .34391 .56533 L F
.781 .527 .553 r
.34386 .56536 m .34391 .56533 L .34443 .56653 L F
.542 .706 .947 r
.34398 .56561 m .34443 .56653 L .34428 .56554 L F
.34206 .56707 m .34443 .56653 L .34398 .56561 L F
.781 .527 .553 r
.34227 .56646 m .34386 .56536 L .34443 .56653 L F
.675 .542 .695 r
.34206 .56707 m .34589 .57046 L .34443 .56653 L F
.34206 .56707 m .34321 .57164 L .34589 .57046 L F
.799 .682 .736 r
.34386 .56652 m .34177 .56965 L .34012 .56645 L F
.34443 .56653 m .34412 .56689 L .34386 .56652 L F
.34412 .56689 m .34177 .56965 L .34386 .56652 L F
.34443 .56653 m .34367 .56651 L .34409 .56652 L F
.34367 .56651 m .34012 .56645 L .34409 .56652 L F
.793 .672 .731 r
.34443 .56653 m .34589 .57046 L .34177 .56965 L F
.781 .527 .553 r
.34227 .56646 m .34572 .56834 L .34396 .56541 L F
.34386 .56536 m .34396 .56541 L .34391 .56533 L F
.34227 .56646 m .34396 .56541 L .34386 .56536 L F
.542 .706 .947 r
.34414 .56548 m .34428 .56554 L .34426 .5654 L F
.34398 .56561 m .34428 .56554 L .34414 .56548 L F
.799 .682 .736 r
.34409 .56652 m .34012 .56645 L .34227 .56646 L F
.439 .545 .867 r
.34013 .56648 m .34179 .5665 L .34032 .5634 L F
0 .027 .599 r
.36941 .62288 m .36928 .6245 L .36808 .62198 L F
0 0 .562 r
.36941 .62288 m .37073 .62639 L .36928 .6245 L F
.305 .124 .463 r
.37073 .62639 m .36885 .62731 L .36928 .6245 L F
.263 0 .232 r
.34338 .63004 m .34104 .631 L .3403 .63292 L F
.846 .555 .496 r
.35684 .53044 m .35709 .53284 L .35879 .53063 L F
.35684 .53044 m .35709 .53284 L .35905 .53066 L F
.046 0 .453 r
.35832 .53124 m .35709 .53284 L .35684 .53044 L F
0 0 0 r
.35832 .53124 m .35618 .53403 L .35709 .53284 L F
.35618 .53403 m .35588 .53442 L .35709 .53284 L F
.846 .555 .496 r
.35879 .53063 m .35709 .53284 L .35905 .53066 L F
.212 .065 .453 r
.18156 .57445 m .18336 .5759 L .18365 .5733 L F
.18156 .57445 m .18129 .57711 L .18336 .5759 L F
.451 .74 .99 r
.21079 .61423 m .21051 .61144 L .20743 .61152 L F
.21079 .61423 m .21244 .61347 L .21051 .61144 L F
.054 0 .058 r
.33104 .5381 m .32929 .53901 L .33041 .53664 L F
.064 .142 .635 r
.40377 .55764 m .40269 .55956 L .40201 .55558 L F
0 .162 .689 r
.40453 .56007 m .40269 .55956 L .40377 .55764 L F
0 .263 .771 r
.20147 .60596 m .20183 .60463 L .2006 .60451 L F
.20147 .60596 m .20394 .6079 L .20183 .60463 L F
.585 .345 .519 r
.37795 .63672 m .37767 .63959 L .37508 .63954 L F
.606 .831 .986 r
.38064 .63603 m .37795 .63672 L .37609 .63543 L F
.429 .213 .483 r
.37991 .63885 m .37767 .63959 L .37795 .63672 L F
0 0 .24 r
.38373 .64237 m .38402 .64501 L .38326 .64662 L F
.846 .997 .826 r
.38402 .64501 m .38237 .64794 L .38326 .64662 L F
.502 .418 .694 r
.17956 .59381 m .18186 .59307 L .18122 .58934 L F
.486 .368 .644 r
.17989 .59631 m .18186 .59307 L .17956 .59381 L F
.865 .903 .858 r
.35622 .55032 m .35402 .55238 L .35383 .55038 L F
.755 .944 .943 r
.35622 .55032 m .35766 .54794 L .35876 .54942 L F
.582 .311 .471 r
.35876 .54942 m .35842 .55172 L .35622 .55032 L F
.15 .692 .749 r
.28124 .52673 m .28363 .52635 L .2855 .52618 L F
.462 .889 .87 r
.2855 .52618 m .28585 .52538 L .28789 .52573 L F
.2855 .52618 m .28363 .52635 L .28585 .52538 L F
0 0 0 r
.29072 .60938 m .29368 .60607 L .2926 .60814 L F
0 0 .068 r
.2926 .60814 m .29368 .60607 L .29514 .60504 L F
.677 .492 .629 r
.37336 .69282 m .37066 .69569 L .37079 .69313 L F
.469 .382 .675 r
.37568 .64413 m .37284 .64293 L .37483 .64352 L F
.019 .035 .533 r
.37739 .64476 m .37568 .64413 L .37483 .64352 L F
.07 0 .269 r
.28351 .54628 m .28499 .54563 L .28556 .54288 L F
.486 .27 .511 r
.28351 .54628 m .28562 .54848 L .28499 .54563 L F
.28351 .54628 m .2831 .54928 L .28562 .54848 L F
.028 0 .007 r
.28806 .61215 m .28552 .61506 L .28511 .61494 L F
0 0 0 r
.28562 .61611 m .28511 .61494 L .28552 .61506 L F
.28562 .61611 m .28387 .61715 L .28511 .61494 L F
.717 .473 .555 r
.32428 .58982 m .32189 .58754 L .32458 .58687 L F
.32428 .58982 m .32199 .59 L .32189 .58754 L F
.367 .581 .924 r
.24557 .63259 m .24707 .63419 L .24793 .63233 L F
.311 .513 .891 r
.24707 .63419 m .24911 .63444 L .24793 .63233 L F
.269 0 0 r
.27918 .55022 m .2831 .54928 L .2807 .54994 L F
.728 .622 .74 r
.38006 .54531 m .3784 .5419 L .38052 .54312 L F
.656 .353 .447 r
.38052 .54312 m .38263 .5455 L .38006 .54531 L F
.569 .351 .544 r
.38297 .54536 m .38263 .5455 L .38052 .54312 L F
.046 0 0 r
.26897 .555 m .26991 .55512 L .27168 .55365 L F
.474 .003 .054 r
.27168 .55365 m .26991 .55512 L .27379 .55455 L F
.47 .05 .159 r
.27168 .55365 m .27379 .55455 L .27398 .55426 L F
.432 .824 .985 r
.35086 .567 m .34931 .5678 L .35251 .56557 L F
.674 .257 .245 r
.3549 .5668 m .35086 .567 L .35251 .56557 L F
.559 .46 .698 r
.35546 .5647 m .3549 .5668 L .35251 .56557 L F
.461 .472 .783 r
.20243 .58592 m .20378 .58986 L .20168 .59017 L F
.289 0 0 r
.32226 .53147 m .32133 .53238 L .31858 .53262 L F
.562 .919 .956 r
.32331 .52978 m .3232 .5311 L .32545 .53027 L F
.447 .54 .859 r
.32331 .52978 m .32332 .53084 L .3232 .5311 L F
0 0 0 r
.3232 .5311 m .32309 .53136 L .3249 .53111 L F
.501 .904 .914 r
.32545 .53027 m .3232 .5311 L .3249 .53111 L F
.447 .54 .859 r
.32332 .53084 m .32333 .53404 L .3232 .5311 L F
0 0 0 r
.3232 .5311 m .32226 .53147 L .32309 .53136 L F
.3232 .5311 m .32133 .53238 L .32226 .53147 L F
.396 0 0 r
.29195 .64711 m .29264 .64813 L .29039 .64841 L F
.29195 .64711 m .29516 .6479 L .29264 .64813 L F
.683 .207 .115 r
.3203 .55275 m .31623 .55194 L .3178 .55367 L F
.582 .213 .306 r
.37683 .61404 m .37507 .61106 L .37737 .61216 L F
.277 0 .2 r
.32758 .55817 m .32653 .5608 L .32411 .56043 L F
.259 0 .136 r
.32653 .5608 m .32347 .56333 L .32411 .56043 L F
0 0 0 r
.27575 .6226 m .27404 .62344 L .27682 .62193 L F
.27452 .62317 m .27404 .62344 L .27575 .6226 L F
.27452 .62317 m .27166 .6257 L .27404 .62344 L F
.023 0 0 r
.29206 .54355 m .29151 .54491 L .2946 .54193 L F
.385 0 0 r
.29586 .64364 m .29484 .64277 L .29319 .64198 L F
.29586 .64364 m .29709 .64368 L .29484 .64277 L F
.236 .447 .863 r
.29709 .64797 m .29607 .64935 L .29993 .65034 L F
.432 .824 .985 r
.35086 .567 m .34834 .56717 L .34931 .5678 L F
.843 .944 .581 r
.38433 .56186 m .38276 .56354 L .38286 .56454 L F
.572 .484 .716 r
.3867 .55879 m .38685 .56143 L .38433 .56186 L F
.728 .298 .228 r
.38677 .56378 m .38433 .56186 L .38685 .56143 L F
.38677 .56378 m .38276 .56354 L .38433 .56186 L F
.564 .859 .544 r
.2896 .61049 m .28806 .61215 L .29072 .60938 L F
.018 0 0 r
.28877 .61339 m .28806 .61215 L .2896 .61049 L F
.28877 .61339 m .28552 .61506 L .28806 .61215 L F
.489 .464 .757 r
.37014 .62112 m .36808 .62198 L .36719 .61825 L F
0 .027 .599 r
.36941 .62288 m .36808 .62198 L .37014 .62112 L F
.814 .792 .832 r
.37284 .64293 m .36871 .64341 L .37108 .64267 L F
.054 .515 .892 r
.37257 .64211 m .37483 .64352 L .37284 .64293 L F
.524 .33 .559 r
.37353 .63954 m .37408 .64154 L .37257 .64211 L F
.054 .515 .892 r
.37328 .64232 m .37483 .64352 L .37257 .64211 L F
.37257 .64211 m .37284 .64293 L .37108 .64267 L F
.524 .33 .559 r
.37408 .64154 m .37421 .64203 L .37108 .64267 L F
.37421 .64203 m .37455 .64326 L .37177 .64279 L F
.37421 .64203 m .37177 .64279 L .37108 .64267 L F
.37353 .63954 m .37257 .64211 L .37172 .64185 L F
.233 .379 .806 r
.37595 .64115 m .37576 .64155 L .37512 .64157 L F
.37576 .64155 m .37483 .64352 L .37328 .64232 L F
.406 .26 .567 r
.37595 .64115 m .37455 .64326 L .37421 .64203 L F
.37595 .64115 m .37421 .64203 L .37353 .63954 L F
.233 .379 .806 r
.37595 .64115 m .37512 .64157 L .37242 .64165 L F
.37576 .64155 m .37328 .64232 L .37242 .64165 L F
.054 .515 .892 r
.37242 .64165 m .37328 .64232 L .37257 .64211 L F
.524 .33 .559 r
.37172 .64185 m .37257 .64211 L .37108 .64267 L F
.054 .515 .892 r
.37242 .64165 m .37257 .64211 L .37108 .64267 L F
.712 .503 .605 r
.38024 .57735 m .3832 .57402 L .38067 .57463 L F
.38024 .57735 m .38339 .57693 L .3832 .57402 L F
.039 0 .263 r
.38202 .57672 m .38067 .57463 L .3832 .57402 L F
.38166 .5768 m .38067 .57463 L .38202 .57672 L F
.3816 .57682 m .38024 .57735 L .38057 .57526 L F
.611 .154 0 r
.38121 .57633 m .38161 .57684 L .38183 .57716 L F
.039 0 .263 r
.38166 .5768 m .3816 .57682 L .38067 .57463 L F
.3816 .57682 m .38057 .57526 L .38067 .57463 L F
.38106 .57725 m .38024 .57735 L .38166 .5768 L F
.564 .81 .991 r
.38286 .57654 m .38207 .5774 L .38181 .57708 L F
.38202 .57672 m .38181 .57708 L .38159 .57681 L F
.38286 .57654 m .38181 .57708 L .38202 .57672 L F
.576 .444 .663 r
.3832 .57402 m .38599 .57362 L .38587 .57058 L F
.511 .229 .423 r
.3832 .57402 m .38539 .57586 L .38599 .57362 L F
.374 .248 .578 r
.3832 .57402 m .38339 .57693 L .38539 .57586 L F
0 0 0 r
.38439 .57213 m .38223 .57636 L .3832 .57402 L F
.38223 .57636 m .38183 .57716 L .38202 .57672 L F
.38223 .57636 m .38202 .57672 L .3832 .57402 L F
0 0 .351 r
.38439 .57213 m .3832 .57402 L .38336 .57072 L F
.711 .59 .719 r
.38004 .57193 m .38155 .57636 L .38439 .57213 L F
.564 .81 .991 r
.38286 .57654 m .38159 .57681 L .38123 .57636 L F
.38286 .57654 m .38123 .57636 L .38141 .57636 L F
.611 .154 0 r
.38161 .57684 m .38207 .5774 L .38183 .57716 L F
.039 0 .263 r
.38183 .57716 m .38166 .5768 L .38202 .57672 L F
.711 .59 .719 r
.38155 .57636 m .38183 .57716 L .38223 .57636 L F
.38155 .57636 m .38223 .57636 L .38439 .57213 L F
.564 .81 .991 r
.38141 .57636 m .38123 .57636 L .38121 .57633 L F
.748 .609 .704 r
.37893 .57331 m .38121 .57633 L .38004 .57193 L F
.38121 .57633 m .38155 .57636 L .38004 .57193 L F
.564 .81 .991 r
.38267 .57645 m .38121 .57633 L .38034 .57527 L F
.38286 .57654 m .38121 .57633 L .38267 .57645 L F
.748 .609 .704 r
.38121 .57633 m .38183 .57716 L .38155 .57636 L F
.37754 .57505 m .38183 .57716 L .37893 .57331 L F
.611 .154 0 r
.38034 .57527 m .38121 .57633 L .38183 .57716 L F
.039 0 .263 r
.38183 .57716 m .38106 .57725 L .38166 .5768 L F
.564 .81 .991 r
.38384 .57547 m .38286 .57654 L .38235 .57628 L F
.38346 .57545 m .38235 .57628 L .38034 .57527 L F
.38384 .57547 m .38235 .57628 L .38346 .57545 L F
0 .024 .553 r
.29064 .62419 m .29054 .62442 L .28847 .62533 L F
.29064 .62419 m .29176 .62558 L .29054 .62442 L F
.24 0 .099 r
.29176 .62558 m .29191 .62572 L .29224 .62561 L F
.363 .455 .82 r
.29264 .62578 m .29248 .6264 L .29191 .62572 L F
.24 0 .099 r
.29191 .62572 m .29198 .62578 L .29206 .62573 L F
.29191 .62572 m .29206 .62573 L .29224 .62561 L F
.795 .955 .625 r
.29224 .62561 m .29322 .62343 L .29064 .62419 L F
.29224 .62561 m .29222 .62547 L .29322 .62343 L F
.363 .455 .82 r
.29306 .62409 m .29223 .62546 L .29223 .62545 L F
.29289 .6241 m .29223 .62545 L .29064 .62419 L F
.29306 .62409 m .29223 .62545 L .29289 .6241 L F
.795 .955 .625 r
.29222 .62547 m .2921 .62477 L .29295 .62399 L F
.771 .973 .692 r
.29222 .62547 m .29198 .62578 L .29203 .62434 L F
.606 .768 .957 r
.29176 .62558 m .29224 .62561 L .29064 .62419 L F
.771 .973 .692 r
.29224 .62561 m .29206 .62573 L .29222 .62547 L F
.363 .455 .82 r
.29264 .62578 m .29191 .62572 L .29064 .62419 L F
.346 .242 .592 r
.29054 .62442 m .29248 .6264 L .29106 .62633 L F
.24 0 .099 r
.28847 .62533 m .28951 .62739 L .29198 .62578 L F
.771 .973 .692 r
.29198 .62578 m .28985 .62718 L .29056 .62613 L F
0 .024 .553 r
.29176 .62558 m .29206 .62595 L .29059 .62447 L F
.29206 .62595 m .29209 .626 L .29059 .62447 L F
.24 0 .099 r
.28847 .62533 m .29198 .62578 L .29176 .62558 L F
0 .024 .553 r
.29064 .62419 m .29248 .6264 L .29219 .6261 L F
.771 .973 .692 r
.29198 .62578 m .29055 .62613 L .29167 .62515 L F
0 0 0 r
.29056 .62613 m .28988 .62832 L .29157 .62554 L F
.29055 .62613 m .29055 .62614 L .29056 .62613 L F
.29055 .62614 m .28988 .62832 L .29056 .62613 L F
.771 .973 .692 r
.28985 .62718 m .28981 .6272 L .29048 .62625 L F
.28985 .62718 m .29048 .62625 L .29056 .62613 L F
.28981 .6272 m .28951 .62739 L .29054 .62615 L F
.28981 .6272 m .29054 .62615 L .29056 .62613 L F
.181 0 .254 r
.29055 .62614 m .28857 .62958 L .28988 .62832 L F
.29055 .62613 m .29054 .62615 L .29055 .62614 L F
.29054 .62615 m .28857 .62958 L .29055 .62614 L F
.29054 .62615 m .28951 .62739 L .28857 .62958 L F
.29055 .62613 m .28951 .62739 L .29054 .62615 L F
.771 .973 .692 r
.29056 .62613 m .28951 .62739 L .29055 .62613 L F
0 0 0 r
.29055 .62613 m .29056 .62613 L .29057 .62612 L F
0 .024 .553 r
.29176 .62558 m .29059 .62447 L .29054 .62442 L F
.606 .768 .957 r
.28847 .62533 m .29176 .62558 L .29064 .62419 L F
0 0 0 r
.29055 .62613 m .29057 .62612 L .29203 .62434 L F
.771 .973 .692 r
.29167 .62515 m .29057 .62612 L .29156 .62492 L F
.795 .955 .625 r
.2921 .62477 m .29203 .62434 L .29295 .62399 L F
.771 .973 .692 r
.29198 .62578 m .29156 .62492 L .29203 .62434 L F
.363 .455 .82 r
.29322 .62343 m .29394 .62571 L .29248 .6264 L F
.304 .413 .808 r
.29558 .62449 m .29394 .62571 L .29322 .62343 L F
.363 .455 .82 r
.29322 .62343 m .29306 .62409 L .29064 .62419 L F
.795 .955 .625 r
.29295 .62399 m .29203 .62434 L .29322 .62343 L F
.363 .455 .82 r
.29306 .62409 m .29264 .62578 L .29223 .62546 L F
.54 .01 0 r
.29322 .62343 m .29203 .62434 L .29558 .62449 L F
.638 .84 .978 r
.29558 .62449 m .29203 .62434 L .29407 .62328 L F
.29558 .62449 m .29203 .62434 L .29407 .62328 L F
0 0 0 r
.29057 .62612 m .29407 .62328 L .29203 .62434 L F
.771 .973 .692 r
.29156 .62492 m .29055 .62613 L .29156 .62492 L F
.29057 .62612 m .29055 .62613 L .29156 .62492 L F
0 0 0 r
.29057 .62612 m .29072 .62604 L .29109 .6257 L F
.29056 .62613 m .29072 .62604 L .29057 .62612 L F
.29109 .6257 m .29157 .62554 L .29407 .62328 L F
.29072 .62604 m .29157 .62554 L .29109 .6257 L F
.771 .973 .692 r
.29206 .62573 m .29198 .62578 L .29222 .62547 L F
0 .024 .553 r
.29206 .62595 m .29219 .6261 L .29209 .626 L F
.821 .558 .54 r
.35766 .54794 m .36108 .54875 L .36171 .54647 L F
.304 .132 .474 r
.3635 .54553 m .36171 .54647 L .36364 .5429 L F
.221 0 .323 r
.3635 .54553 m .36108 .54875 L .36171 .54647 L F
.3635 .54553 m .36108 .54875 L .36171 .54647 L F
.423 .252 .543 r
.39858 .56976 m .39572 .57367 L .39646 .57147 L F
.263 0 .204 r
.21978 .5636 m .21851 .56258 L .22146 .56119 L F
.21978 .5636 m .21771 .5643 L .21851 .56258 L F
0 0 0 r
.31358 .57001 m .31254 .57324 L .31094 .5735 L F
.021 0 0 r
.31668 .56813 m .31571 .56922 L .31358 .57001 L F
0 0 0 r
.31383 .57098 m .31358 .57001 L .31571 .56922 L F
.31383 .57098 m .31254 .57324 L .31358 .57001 L F
.26196 .52968 m .26434 .52921 L .2664 .52844 L F
.26434 .52921 m .26866 .52769 L .2664 .52844 L F
0 0 .407 r
.35616 .56336 m .35513 .56187 L .35594 .56017 L F
.35616 .56336 m .35546 .5647 L .35513 .56187 L F
.147 .684 .841 r
.20378 .58986 m .20646 .58979 L .20813 .59003 L F
.344 .819 .89 r
.20646 .58979 m .21056 .58933 L .20813 .59003 L F
0 0 0 r
.2896 .61049 m .29072 .60938 L .2926 .60814 L F
.871 .889 .845 r
.35108 .59795 m .35328 .5994 L .35025 .60213 L F
.677 .481 .614 r
.35328 .5994 m .35222 .60149 L .35025 .60213 L F
.853 .892 .865 r
.35462 .59628 m .35328 .5994 L .35108 .59795 L F
.541 .518 .779 r
.35462 .59628 m .35604 .59879 L .35328 .5994 L F
.447 .223 .479 r
.3557 .60159 m .35328 .5994 L .35604 .59879 L F
.3557 .60159 m .35222 .60149 L .35328 .5994 L F
.372 .054 .292 r
.31227 .64923 m .31363 .65137 L .31168 .65208 L F
.31227 .64923 m .31467 .64837 L .31363 .65137 L F
.394 .138 .403 r
.37062 .59261 m .36838 .59324 L .36768 .59555 L F
0 0 .09 r
.20486 .57692 m .20421 .57933 L .20252 .58045 L F
.018 0 .296 r
.20385 .58146 m .20252 .58045 L .20421 .57933 L F
.20385 .58146 m .20209 .58328 L .20252 .58045 L F
.778 .401 .342 r
.33769 .62314 m .33926 .62144 L .33722 .62121 L F
.683 .595 .75 r
.33926 .62144 m .34163 .62124 L .34035 .61728 L F
.642 .377 .502 r
.34162 .62369 m .34163 .62124 L .33926 .62144 L F
.718 .238 .107 r
.32778 .58209 m .332 .58352 L .32989 .58101 L F
.469 .241 .485 r
.32989 .58101 m .332 .58352 L .33241 .58032 L F
.738 .72 .835 r
.24759 .54489 m .24711 .54645 L .24539 .54504 L F
.24759 .54489 m .24803 .54828 L .24711 .54645 L F
.054 0 .32 r
.31096 .65416 m .30964 .65295 L .31168 .65208 L F
.31096 .65416 m .30896 .65466 L .30964 .65295 L F
0 .404 .849 r
.38276 .56354 m .38437 .56512 L .38286 .56454 L F
.499 .245 .46 r
.38123 .68385 m .38115 .68628 L .37858 .68666 L F
.501 .319 .566 r
.38364 .68012 m .38402 .68348 L .38123 .68385 L F
.421 .155 .403 r
.38402 .68348 m .38115 .68628 L .38123 .68385 L F
.486 .332 .598 r
.36373 .60222 m .36644 .60192 L .36626 .59887 L F
.009 .166 .68 r
.36373 .60222 m .36591 .60452 L .36644 .60192 L F
.768 .434 .42 r
.35659 .69019 m .3528 .692 L .35266 .68947 L F
.35659 .69019 m .35674 .69237 L .3528 .692 L F
.38 .413 .77 r
.32913 .65259 m .33202 .65521 L .33096 .65246 L F
.534 .432 .685 r
.32963 .65553 m .33202 .65521 L .32913 .65259 L F
.772 .572 .629 r
.35137 .68059 m .34894 .68313 L .34748 .68031 L F
.35137 .68059 m .351 .68362 L .34894 .68313 L F
.819 .617 .63 r
.35137 .68059 m .35258 .68397 L .351 .68362 L F
.716 .567 .685 r
.35533 .68361 m .35258 .68397 L .35137 .68059 L F
.121 0 0 r
.23836 .55018 m .23723 .55199 L .23525 .55223 L F
.564 .191 .293 r
.24064 .55013 m .23723 .55199 L .23836 .55018 L F
.642 .921 .977 r
.23572 .60995 m .23106 .61057 L .23331 .61086 L F
.598 .236 .326 r
.23331 .61086 m .23771 .60854 L .23572 .60995 L F
.538 .867 .994 r
.25465 .62427 m .25079 .62439 L .25294 .62359 L F
.484 .791 .999 r
.25523 .62274 m .25699 .62386 L .25465 .62427 L F
.576 .882 .992 r
.25465 .62427 m .25294 .62359 L .25523 .62274 L F
.758 .687 .783 r
.34304 .52592 m .34326 .52639 L .34677 .52438 L F
.605 .414 .596 r
.36108 .54875 m .35842 .55172 L .35876 .54942 L F
.305 0 0 r
.28808 .59177 m .29277 .59149 L .28957 .59226 L F
.321 0 .135 r
.33145 .55129 m .33383 .5507 L .33569 .54746 L F
.812 .714 .757 r
.30246 .6561 m .30373 .65564 L .30154 .65226 L F
0 .051 .608 r
.30154 .65226 m .30373 .65564 L .30329 .65459 L F
.945 .752 .285 r
.30329 .65459 m .30373 .65564 L .30357 .65825 L F
.115 0 0 r
.30373 .65564 m .30421 .65596 L .30357 .65825 L F
.856 .827 .818 r
.34209 .61858 m .34449 .61604 L .3425 .61492 L F
.732 .406 .429 r
.34319 .61346 m .34665 .61461 L .34449 .61604 L F
.758 .844 .917 r
.3425 .61492 m .34449 .61604 L .34665 .61461 L F
.53 .494 .761 r
.38572 .67735 m .38364 .68012 L .38331 .67755 L F
.38572 .67735 m .38664 .68007 L .38364 .68012 L F
.389 .169 .454 r
.38664 .68007 m .38402 .68348 L .38364 .68012 L F
.49 .623 .909 r
.35383 .55038 m .35402 .55238 L .35031 .54975 L F
.328 .227 .585 r
.30736 .56811 m .30904 .56732 L .30922 .56424 L F
.183 0 .355 r
.30705 .57016 m .30904 .56732 L .30736 .56811 L F
.685 .25 .211 r
.36337 .64853 m .36043 .64838 L .36001 .64623 L F
.521 .537 .813 r
.28851 .57352 m .29038 .57786 L .29218 .57684 L F
.455 .885 .843 r
.30421 .65596 m .30896 .65466 L .30824 .6572 L F
0 0 0 r
.30824 .6572 m .30896 .65466 L .31096 .65416 L F
.73 .222 .015 r
.30366 .57626 m .30317 .57666 L .30358 .57417 L F
.98 .722 .47 r
.35362 .67525 m .35236 .67652 L .35208 .67315 L F
.668 .744 .907 r
.35647 .67444 m .35362 .67525 L .35208 .67315 L F
.31 .662 .973 r
.21384 .61442 m .21422 .61321 L .21244 .61347 L F
.21384 .61442 m .21583 .61458 L .21422 .61321 L F
.127 .204 .674 r
.39275 .53511 m .39147 .53738 L .39071 .53309 L F
.71 .175 0 r
.39147 .53738 m .39363 .53954 L .39543 .54009 L F
.166 .255 .711 r
.39275 .53511 m .39363 .53954 L .39147 .53738 L F
.894 .915 .83 r
.36616 .53994 m .36225 .54114 L .36267 .5385 L F
.36616 .53994 m .36364 .5429 L .36225 .54114 L F
.571 .366 .565 r
.36616 .53994 m .36623 .54275 L .36364 .5429 L F
.496 .233 .445 r
.36947 .53894 m .36623 .54275 L .36616 .53994 L F
.589 .299 .444 r
.33924 .58032 m .33862 .58335 L .3358 .58322 L F
.403 .203 .491 r
.34146 .57733 m .34175 .57972 L .33924 .58032 L F
.511 .228 .421 r
.34184 .58214 m .33924 .58032 L .34175 .57972 L F
.34184 .58214 m .33862 .58335 L .33924 .58032 L F
.602 .404 .587 r
.35418 .54306 m .3543 .546 L .3503 .54649 L F
.549 .38 .605 r
.35627 .54281 m .3543 .546 L .35418 .54306 L F
.234 0 0 r
.32867 .60571 m .32732 .6075 L .32526 .6077 L F
.533 .524 .791 r
.32984 .60148 m .32867 .60571 L .32716 .60198 L F
.32984 .60148 m .33066 .6057 L .32867 .60571 L F
0 0 0 r
.32926 .60653 m .32867 .60571 L .33066 .6057 L F
.32926 .60653 m .32732 .6075 L .32867 .60571 L F
.881 .753 .717 r
.31921 .56656 m .31919 .5709 L .32121 .5684 L F
.592 .721 .933 r
.30365 .5521 m .30779 .55338 L .30575 .55186 L F
.709 .836 .943 r
.30575 .55186 m .30779 .55338 L .30986 .55203 L F
.53 .505 .773 r
.3568 .51419 m .35664 .51663 L .35378 .51351 L F
.3568 .51419 m .35664 .51663 L .35378 .51351 L F
.524 .823 .999 r
.35267 .51374 m .3568 .51419 L .35378 .51351 L F
.175 .609 .94 r
.26395 .63614 m .26437 .63527 L .26262 .63475 L F
.26395 .63614 m .26604 .63647 L .26437 .63527 L F
.465 0 0 r
.30552 .64448 m .3073 .64399 L .30289 .64316 L F
.259 0 0 r
.30966 .64449 m .3073 .64399 L .30552 .64448 L F
0 .371 .837 r
.3831 .52376 m .38245 .5247 L .38178 .52297 L F
.3831 .52376 m .38509 .52617 L .38245 .5247 L F
.684 .94 .654 r
.31475 .53515 m .31365 .53685 L .31637 .53394 L F
0 0 .482 r
.31475 .53515 m .31534 .53948 L .31365 .53685 L F
.37 .271 .611 r
.37402 .56157 m .37618 .55823 L .37272 .56017 L F
.882 .992 .775 r
.32956 .65846 m .32757 .66143 L .32686 .66125 L F
.932 .92 .778 r
.36096 .56684 m .36028 .57127 L .36288 .56839 L F
.36096 .56684 m .35886 .57034 L .36028 .57127 L F
0 0 0 r
.28154 .54097 m .28033 .54198 L .27834 .543 L F
.648 .504 .673 r
.31302 .59877 m .31598 .59512 L .31318 .59586 L F
.348 .091 .375 r
.32254 .61449 m .32043 .61508 L .32313 .61168 L F
.159 .016 .424 r
.32526 .6077 m .32512 .61065 L .32313 .61168 L F
.286 .038 .352 r
.32502 .61367 m .32313 .61168 L .32512 .61065 L F
.32502 .61367 m .32254 .61449 L .32313 .61168 L F
.819 .996 .856 r
.332 .58352 m .33073 .58606 L .33354 .58396 L F
.332 .58352 m .32937 .58581 L .33073 .58606 L F
0 0 .522 r
.36374 .61455 m .36407 .61096 L .36241 .61117 L F
.36374 .61455 m .36471 .61355 L .36407 .61096 L F
0 .146 .668 r
.36374 .61455 m .36578 .61722 L .36471 .61355 L F
.538 .5 .762 r
.29226 .56625 m .29164 .57157 L .29087 .56788 L F
.29226 .56625 m .29437 .5712 L .29164 .57157 L F
.582 .516 .746 r
.29437 .5712 m .29237 .57426 L .29164 .57157 L F
.606 .451 .646 r
.35449 .54869 m .3503 .54649 L .3543 .546 L F
.35449 .54869 m .35031 .54975 L .3503 .54649 L F
.386 .091 .337 r
.28475 .7057 m .28795 .70239 L .2877 .70565 L F
.28795 .70239 m .28475 .7057 L .28688 .7044 L F
.162 .03 .441 r
.28908 .7037 m .28795 .70239 L .28999 .70186 L F
.28908 .7037 m .2877 .70565 L .28795 .70239 L F
.208 0 .064 r
.28999 .70186 m .28795 .70239 L .28688 .7044 L F
.438 0 0 r
.36522 .56763 m .36096 .56684 L .36288 .56839 L F
.721 .597 .718 r
.35533 .68361 m .35275 .6868 L .35258 .68397 L F
0 0 .224 r
.32601 .63681 m .32704 .63354 L .32811 .63598 L F
.282 0 .27 r
.32506 .63922 m .32601 .63681 L .32811 .63598 L F
.95 .663 .461 r
.35275 .6868 m .351 .68362 L .35258 .68397 L F
.35275 .6868 m .35079 .68607 L .351 .68362 L F
.808 .681 .724 r
.35266 .68947 m .35079 .68607 L .35275 .6868 L F
0 0 .138 r
.23607 .55316 m .23525 .55223 L .23723 .55199 L F
.23607 .55316 m .23484 .55534 L .23525 .55223 L F
.354 .829 .857 r
.35786 .58462 m .36293 .58371 L .36093 .58425 L F
.732 .211 0 r
.36208 .58009 m .36532 .58315 L .36293 .58371 L F
.559 .93 .922 r
.36532 .58315 m .36093 .58425 L .36293 .58371 L F
.387 .291 .623 r
.35568 .55704 m .35368 .55885 L .35313 .55558 L F
.525 .189 .341 r
.35642 .55523 m .35568 .55704 L .35313 .55558 L F
.513 .182 .342 r
.26222 .5425 m .26475 .54227 L .26523 .54036 L F
.616 .646 .857 r
.26456 .53757 m .26523 .54036 L .2677 .53956 L F
.563 .296 .469 r
.26475 .54227 m .2677 .53956 L .26523 .54036 L F
.623 .545 .745 r
.39292 .58872 m .39369 .59333 L .39123 .59313 L F
.541 .344 .563 r
.39123 .59313 m .39358 .59532 L .39105 .59551 L F
.619 .335 .464 r
.39369 .59333 m .39358 .59532 L .39123 .59313 L F
.532 .364 .598 r
.36066 .63642 m .3585 .63984 L .35834 .63703 L F
.026 0 0 r
.25001 .54417 m .24759 .54489 L .24539 .54504 L F
.778 .758 .835 r
.36309 .67219 m .35852 .67332 L .36132 .67068 L F
.641 .793 .955 r
.36367 .66991 m .36309 .67219 L .36132 .67068 L F
.36367 .66991 m .36544 .6713 L .36309 .67219 L F
.222 0 .216 r
.31217 .55907 m .31403 .55839 L .31541 .55835 L F
.447 .209 .459 r
.31315 .56033 m .31521 .55796 L .31403 .55839 L F
.625 .957 .912 r
.31541 .55835 m .31403 .55839 L .31592 .55713 L F
.447 .209 .459 r
.31521 .55796 m .31592 .55713 L .31403 .55839 L F
.222 0 .216 r
.31175 .55917 m .31403 .55839 L .31217 .55907 L F
.222 .556 .934 r
.31592 .55713 m .31747 .55879 L .31541 .55835 L F
.262 0 .072 r
.37121 .60876 m .37089 .61008 L .36874 .60977 L F
.36874 .60977 m .37089 .61008 L .37121 .60876 L F
.894 .537 .062 r
.34304 .52592 m .3427 .52657 L .34326 .52639 L F
.443 .468 .791 r
.32482 .5953 m .32312 .59631 L .32201 .59262 L F
.853 .559 .026 r
.32268 .59696 m .32364 .59885 L .32312 .59631 L F
.32268 .59696 m .32312 .59631 L .32482 .5953 L F
0 0 0 r
.28596 .59953 m .28597 .60047 L .2857 .59786 L F
.28596 .59953 m .28521 .60212 L .28597 .60047 L F
.878 .96 .85 r
.32514 .54666 m .32325 .54935 L .32244 .54737 L F
.882 .856 .811 r
.32259 .55146 m .32244 .54737 L .32325 .54935 L F
0 0 .401 r
.2922 .62945 m .29163 .6309 L .29106 .62633 L F
.218 .047 .423 r
.31604 .60846 m .31799 .60501 L .31563 .60574 L F
.681 .885 .973 r
.31688 .53166 m .31637 .53394 L .31858 .53262 L F
.347 .171 .495 r
.31688 .53166 m .31475 .53515 L .31637 .53394 L F
.16 .202 .658 r
.2723 .63881 m .27155 .64248 L .27363 .64187 L F
.846 .737 .217 r
.35727 .58356 m .35697 .58232 L .35738 .57936 L F
0 0 .375 r
.35727 .58356 m .35812 .58397 L .35697 .58232 L F
.35727 .58356 m .35786 .58462 L .35812 .58397 L F
.403 .532 .873 r
.24095 .61703 m .24075 .62029 L .23883 .61732 L F
.24095 .61703 m .24277 .62026 L .24075 .62029 L F
.168 .681 .896 r
.25699 .62386 m .25907 .62387 L .26106 .6244 L F
.504 .032 .066 r
.25907 .62387 m .26303 .62331 L .26106 .6244 L F
.854 .985 .855 r
.23941 .76542 m .2404 .76542 L .23874 .76634 L F
.8 .748 .805 r
.30317 .57666 m .30354 .57356 L .30358 .57417 L F
.135 0 .023 r
.26542 .55621 m .26684 .55643 L .26897 .555 L F
.568 .22 .337 r
.26684 .55643 m .26991 .55512 L .26897 .555 L F
.759 .637 .725 r
.34035 .61728 m .34163 .62124 L .34209 .61858 L F
.667 .277 .297 r
.34383 .62459 m .34163 .62124 L .34162 .62369 L F
.305 0 0 r
.28808 .59177 m .29142 .5921 L .29277 .59149 L F
.763 .975 .705 r
.29277 .59149 m .29232 .59071 L .29511 .59045 L F
.29277 .59149 m .29142 .5921 L .29232 .59071 L F
.899 .637 .534 r
.31479 .62678 m .31514 .62442 L .31482 .62393 L F
.538 .614 .876 r
.33156 .54435 m .33241 .54121 L .33017 .54184 L F
.33156 .54435 m .33392 .5439 L .33241 .54121 L F
.669 .975 .878 r
.38128 .64797 m .38053 .64945 L .38237 .64794 L F
.493 .818 1 r
.38128 .64797 m .37883 .64847 L .38053 .64945 L F
.594 .303 .443 r
.37134 .63695 m .36763 .63965 L .36733 .63649 L F
.37134 .63695 m .37178 .63958 L .36763 .63965 L F
.661 .348 .432 r
.37134 .63695 m .37353 .63954 L .37178 .63958 L F
.778 .301 .102 r
.37508 .63954 m .37353 .63954 L .37134 .63695 L F
.748 .937 .948 r
.29808 .58978 m .29511 .59045 L .29751 .58894 L F
.29808 .58978 m .29464 .59141 L .29511 .59045 L F
.722 .344 0 r
.29808 .58978 m .29751 .58894 L .29661 .58678 L F
.429 .376 .697 r
.29029 .56423 m .29226 .56625 L .294 .56494 L F
0 .211 .736 r
.29392 .56305 m .29597 .56673 L .294 .56494 L F
0 0 .2 r
.29226 .56625 m .29392 .56305 L .294 .56494 L F
.654 .287 .336 r
.294 .56494 m .29597 .56673 L .29226 .56625 L F
.42 .088 .295 r
.30877 .56147 m .3112 .56096 L .31175 .55917 L F
.222 0 .216 r
.31175 .55917 m .3112 .56096 L .31403 .55839 L F
.458 0 0 r
.35187 .53468 m .35455 .5359 L .35087 .53505 L F
.35455 .5359 m .35444 .53597 L .35087 .53505 L F
.989 .865 .618 r
.3538 .53632 m .35588 .53442 L .35541 .53465 L F
.35308 .53706 m .35396 .53623 L .3538 .53632 L F
.35396 .53623 m .35588 .53442 L .3538 .53632 L F
.458 0 0 r
.35455 .5359 m .35502 .53612 L .35444 .53597 L F
.759 .697 .794 r
.36815 .67001 m .36909 .67169 L .36544 .6713 L F
.591 .626 .855 r
.37172 .67106 m .36909 .67169 L .36815 .67001 L F
.334 .222 .574 r
.3216 .57695 m .32188 .57944 L .32001 .58 L F
.264 .031 .361 r
.2884 .57118 m .29031 .57048 L .29087 .56788 L F
.431 .312 .617 r
.28851 .57352 m .29031 .57048 L .2884 .57118 L F
0 0 0 r
.21145 .54631 m .20857 .54902 L .21007 .54777 L F
.134 0 0 r
.21007 .54777 m .21362 .54559 L .21145 .54631 L F
.496 .233 .445 r
.36947 .53894 m .36897 .54241 L .36623 .54275 L F
.521 .481 .753 r
.37162 .53814 m .36947 .53894 L .36871 .53635 L F
.322 .087 .393 r
.37103 .54132 m .36947 .53894 L .37162 .53814 L F
.37103 .54132 m .36897 .54241 L .36947 .53894 L F
.533 .437 .692 r
.37365 .65219 m .37125 .64922 L .37249 .64844 L F
.37365 .65219 m .37146 .65288 L .37125 .64922 L F
.197 .066 .465 r
.17987 .5805 m .18129 .58015 L .18129 .57711 L F
.254 .273 .687 r
.17987 .5805 m .182 .58258 L .18129 .58015 L F
.348 .287 .646 r
.17987 .5805 m .18037 .58328 L .182 .58258 L F
.417 .71 .984 r
.38382 .6754 m .38331 .67755 L .3815 .67528 L F
.297 0 0 r
.38382 .6754 m .38267 .67561 L .38425 .67542 L F
.625 .81 .971 r
.38823 .67658 m .38539 .67582 L .38645 .67516 L F
.38539 .67582 m .38382 .6754 L .38645 .67516 L F
.38823 .67658 m .38572 .67735 L .38382 .6754 L F
.616 .83 .982 r
.38949 .67558 m .38823 .67658 L .38645 .67516 L F
.876 .882 .449 r
.38783 .67251 m .38768 .67335 L .38811 .6717 L F
.38768 .67335 m .38733 .67523 L .38782 .67301 L F
.38768 .67335 m .38782 .67301 L .38811 .6717 L F
.84 .902 .881 r
.39066 .67325 m .38733 .67523 L .38779 .67335 L F
.711 .98 .907 r
.38761 .67396 m .38806 .67226 L .38811 .6717 L F
.38733 .67523 m .38799 .67255 L .38761 .67396 L F
.38799 .67255 m .38806 .67226 L .38761 .67396 L F
.814 .91 .906 r
.39066 .67325 m .38799 .67255 L .39198 .67014 L F
.38799 .67255 m .38783 .67251 L .38803 .6724 L F
.38799 .67255 m .38803 .6724 L .39198 .67014 L F
.84 .902 .881 r
.38828 .67263 m .38768 .67335 L .38783 .67251 L F
.39066 .67325 m .38768 .67335 L .38828 .67263 L F
.736 .582 .683 r
.39198 .67014 m .38803 .6724 L .38811 .6717 L F
.38803 .6724 m .38783 .67251 L .38811 .6717 L F
.711 .98 .907 r
.38803 .67237 m .38791 .67387 L .38806 .67226 L F
.38733 .67523 m .38783 .67405 L .38803 .67237 L F
.38783 .67405 m .38791 .67387 L .38803 .67237 L F
.84 .902 .881 r
.38779 .67335 m .38733 .67523 L .38768 .67335 L F
.616 .83 .982 r
.38949 .67558 m .38733 .67523 L .39066 .67325 L F
.711 .98 .907 r
.38733 .67523 m .38645 .67516 L .38791 .67387 L F
.616 .83 .982 r
.38949 .67558 m .38645 .67516 L .38733 .67523 L F
.217 0 .124 r
.38709 .67477 m .38738 .67691 L .38783 .6743 L F
.38645 .67516 m .38672 .67566 L .38709 .67477 L F
.38672 .67566 m .38738 .67691 L .38709 .67477 L F
.38645 .67516 m .38783 .6743 L .38791 .67387 L F
.297 0 0 r
.38382 .6754 m .38425 .67542 L .38645 .67516 L F
.417 .71 .984 r
.38382 .6754 m .3815 .67528 L .3815 .67527 L F
.38382 .6754 m .38572 .67735 L .38331 .67755 L F
.348 .8 .948 r
.27499 .52734 m .27725 .52696 L .27892 .5274 L F
.353 .815 .925 r
.27725 .52696 m .28124 .52673 L .27892 .5274 L F
.29 .109 .454 r
.32485 .6418 m .32333 .63998 L .32506 .63922 L F
.32485 .6418 m .32309 .64236 L .32333 .63998 L F
.685 .25 .211 r
.36337 .64853 m .36372 .64904 L .36043 .64838 L F
.688 .917 .971 r
.32369 .52262 m .31957 .52339 L .3219 .52257 L F
.423 .847 .953 r
.32479 .52194 m .32369 .52262 L .3219 .52257 L F
.32479 .52194 m .32642 .52201 L .32369 .52262 L F
.034 0 0 r
.22392 .5607 m .21978 .5636 L .22146 .56119 L F
.744 .233 0 r
.34224 .54076 m .34271 .54146 L .34371 .542 L F
.399 .811 .977 r
.34271 .54146 m .34681 .54153 L .34371 .542 L F
.621 .831 .981 r
.27499 .52734 m .27274 .52828 L .27106 .52713 L F
.224 .672 .952 r
.22997 .62679 m .2296 .62579 L .22697 .62407 L F
.22997 .62679 m .2315 .62678 L .2296 .62579 L F
.71 .374 0 r
.3268 .57068 m .32821 .57427 L .32724 .57189 L F
0 .352 .822 r
.32821 .57427 m .32861 .57336 L .32724 .57189 L F
.193 .387 .826 r
.32973 .5748 m .33137 .57603 L .32821 .57427 L F
0 .352 .822 r
.32821 .57427 m .33137 .57603 L .32861 .57336 L F
0 0 .217 r
.29916 .59794 m .29819 .59931 L .29916 .595 L F
.042 0 .439 r
.29916 .59794 m .29771 .60189 L .29819 .59931 L F
.608 .129 .091 r
.31188 .52485 m .31547 .52572 L .31727 .52421 L F
0 0 0 r
.31727 .52421 m .31835 .52354 L .31957 .52339 L F
.31727 .52421 m .31547 .52572 L .31835 .52354 L F
.549 .483 .734 r
.33145 .64911 m .33352 .64879 L .33371 .64573 L F
.505 .294 .527 r
.33349 .6518 m .33145 .64911 L .33096 .65246 L F
.33349 .6518 m .33352 .64879 L .33145 .64911 L F
.485 .875 .692 r
.35402 .61874 m .3506 .62083 L .35263 .61793 L F
.155 .439 .874 r
.35483 .61777 m .35402 .61874 L .35263 .61793 L F
.429 .841 .969 r
.31747 .55879 m .31993 .55817 L .32171 .55873 L F
.643 .929 .972 r
.32171 .55873 m .31993 .55817 L .32234 .5571 L F
.856 .827 .818 r
.34209 .61858 m .3425 .61492 L .34035 .61728 L F
.216 .549 .931 r
.28556 .54288 m .28577 .54138 L .28391 .54082 L F
0 0 .077 r
.28556 .54288 m .28499 .54563 L .28612 .54402 L F
.28 0 .062 r
.30531 .63245 m .3047 .6306 L .30683 .62981 L F
.30531 .63245 m .30319 .63288 L .3047 .6306 L F
.31 .118 .45 r
.28339 .60491 m .28471 .6074 L .28442 .60468 L F
.28339 .60491 m .28312 .60865 L .28471 .6074 L F
.668 .708 .877 r
.34384 .64264 m .34405 .64427 L .34588 .6426 L F
.649 .418 .555 r
.38559 .56805 m .38587 .57058 L .38336 .57072 L F
.63 .643 .845 r
.38821 .56768 m .38559 .56805 L .38437 .56512 L F
.59 .375 .558 r
.38559 .56805 m .38587 .57058 L .38821 .56768 L F
.38559 .56805 m .38587 .57058 L .38821 .56768 L F
.466 .239 .485 r
.32028 .55131 m .31978 .55202 L .3203 .55275 L F
.217 .69 .939 r
.31623 .55194 m .31984 .55211 L .3203 .55275 L F
.683 .207 .115 r
.31773 .55224 m .31843 .55395 L .31623 .55194 L F
.3203 .55275 m .31843 .55395 L .31773 .55224 L F
.501 .331 .583 r
.32079 .55337 m .31854 .55608 L .31843 .55395 L F
.55 .369 .588 r
.31843 .55395 m .31854 .55608 L .31862 .55441 L F
.466 .239 .485 r
.31978 .55202 m .31843 .55395 L .31982 .55306 L F
.31984 .55211 m .31982 .55306 L .3203 .55275 L F
.31978 .55202 m .31982 .55306 L .31984 .55211 L F
.407 .69 .977 r
.31985 .55207 m .31993 .55212 L .31984 .55211 L F
.217 .69 .939 r
.31984 .55211 m .31993 .55212 L .3203 .55275 L F
.783 .744 .818 r
.32028 .55131 m .31993 .55212 L .31691 .55028 L F
.466 .239 .485 r
.31949 .55248 m .32079 .55337 L .31854 .55393 L F
.31985 .55192 m .32079 .55337 L .31949 .55248 L F
.583 .369 .556 r
.32339 .55325 m .32351 .55531 L .32079 .55337 L F
.982 .719 .454 r
.32253 .55456 m .32079 .55337 L .32351 .55531 L F
.466 .239 .485 r
.31985 .55192 m .31854 .55393 L .31853 .55381 L F
.888 .956 .614 r
.3203 .55275 m .31993 .55212 L .32028 .55131 L F
.466 .239 .485 r
.32028 .55131 m .32042 .55189 L .31985 .55192 L F
.32042 .55189 m .32079 .55337 L .31985 .55192 L F
.924 .536 .165 r
.31924 .55206 m .32079 .55337 L .32028 .55131 L F
.742 .278 .148 r
.31924 .55206 m .32028 .55131 L .32079 .55337 L F
.982 .719 .454 r
.31924 .55206 m .32079 .55337 L .32253 .55456 L F
.407 .69 .977 r
.31691 .55028 m .31962 .55193 L .31623 .55194 L F
.31962 .55193 m .31985 .55207 L .31798 .552 L F
.31962 .55193 m .31798 .552 L .31623 .55194 L F
.31985 .55207 m .31984 .55211 L .31623 .55194 L F
0 0 .206 r
.31859 .55498 m .31921 .55493 L .31875 .55151 L F
.31854 .55608 m .31864 .55591 L .31859 .55498 L F
.31864 .55591 m .31921 .55493 L .31859 .55498 L F
.466 .239 .485 r
.31853 .55381 m .31854 .55393 L .31843 .55395 L F
.55 .369 .588 r
.31843 .55395 m .31862 .55441 L .31875 .55151 L F
.521 .537 .813 r
.28851 .57352 m .29237 .57426 L .29055 .57329 L F
.28851 .57352 m .29218 .57684 L .29237 .57426 L F
.582 .516 .746 r
.29437 .5712 m .29493 .57381 L .29237 .57426 L F
0 .175 .709 r
.29237 .57426 m .29343 .57379 L .29055 .57329 L F
.517 .274 .486 r
.29493 .57381 m .29452 .57634 L .29237 .57426 L F
0 .175 .709 r
.29237 .57426 m .29452 .57634 L .29343 .57379 L F
0 0 .256 r
.36364 .5429 m .36428 .54386 L .36225 .54114 L F
.36364 .5429 m .3635 .54553 L .36448 .54362 L F
.36448 .54362 m .3635 .54553 L .36364 .5429 L F
.36364 .5429 m .36448 .54362 L .36428 .54386 L F
.36448 .54362 m .36364 .5429 L .36623 .54275 L F
.19 .615 .945 r
.38013 .52161 m .37894 .52249 L .37715 .52025 L F
.38013 .52161 m .38178 .52297 L .37894 .52249 L F
.915 .718 .621 r
.32146 .63026 m .32375 .62765 L .32013 .6276 L F
.32146 .63026 m .32366 .63068 L .32375 .62765 L F
.376 .043 .268 r
.37007 .5743 m .37324 .57386 L .37328 .5718 L F
.466 .11 .277 r
.37328 .5718 m .37324 .57386 L .37523 .57302 L F
.457 .118 .303 r
.37328 .5718 m .37523 .57302 L .37581 .57121 L F
.755 .6 .685 r
.373 .67716 m .37601 .68074 L .37768 .67844 L F
0 0 .001 r
.32956 .65846 m .32957 .65863 L .32963 .65553 L F
.394 .208 .506 r
.32963 .65553 m .33163 .65756 L .33202 .65521 L F
.32963 .65553 m .32957 .65863 L .33163 .65756 L F
.378 .338 .687 r
.3759 .60478 m .3734 .60238 L .3758 .60183 L F
.546 .486 .74 r
.39123 .55517 m .38951 .5583 L .38908 .55526 L F
.781 .706 .781 r
.3436 .67744 m .345 .68047 L .34142 .67977 L F
.823 .549 .524 r
.345 .68047 m .34158 .68252 L .34142 .67977 L F
.345 .68047 m .345 .68321 L .34158 .68252 L F
.694 .667 .819 r
.34748 .68031 m .345 .68047 L .3436 .67744 L F
.729 .469 .535 r
.34894 .68313 m .345 .68047 L .34748 .68031 L F
.34894 .68313 m .345 .68321 L .345 .68047 L F
.45 .605 .912 r
.22513 .62434 m .22614 .62215 L .22332 .62082 L F
.22513 .62434 m .22697 .62407 L .22614 .62215 L F
.372 0 .182 r
.333 .55519 m .33017 .55701 L .33064 .55572 L F
.429 .376 .697 r
.29029 .56423 m .29087 .56788 L .29226 .56625 L F
.492 .264 .496 r
.34382 .57915 m .34146 .57733 L .34418 .57636 L F
.34382 .57915 m .34175 .57972 L .34146 .57733 L F
.83 .534 .487 r
.36041 .69561 m .35674 .69237 L .36048 .69302 L F
.724 .472 .545 r
.36442 .69534 m .36041 .69561 L .36048 .69302 L F
.551 .5 .751 r
.34588 .6426 m .3423 .63988 L .34535 .63993 L F
.499 .882 .968 r
.332 .58352 m .33354 .58396 L .3358 .58322 L F
.052 0 .26 r
.32854 .62395 m .32799 .62695 L .32997 .62502 L F
.895 .98 .696 r
.35709 .53284 m .35502 .53612 L .3552 .53706 L F
.911 .899 .49 r
.35502 .53612 m .35414 .53828 L .3552 .53706 L F
.61 .241 .318 r
.3552 .53706 m .35814 .53878 L .35578 .53812 L F
.621 .114 .023 r
.35414 .53828 m .35814 .53878 L .3552 .53706 L F
.452 .704 .975 r
.24483 .62041 m .24413 .62206 L .24277 .62026 L F
.24483 .62041 m .24723 .62244 L .24413 .62206 L F
.489 .464 .757 r
.37014 .62112 m .36719 .61825 L .37005 .61766 L F
0 .259 .765 r
.40019 .5523 m .40245 .55385 L .40201 .55558 L F
0 .082 .636 r
.40245 .55385 m .40377 .55764 L .40201 .55558 L F
0 0 0 r
.2075 .57412 m .20652 .57632 L .20486 .57692 L F
.003 0 0 r
.20815 .57534 m .2075 .57412 L .21002 .57341 L F
.20815 .57534 m .20652 .57632 L .2075 .57412 L F
.486 .368 .644 r
.17989 .59631 m .18211 .59622 L .18186 .59307 L F
.223 0 .094 r
.20509 .55217 m .20715 .55152 L .20857 .54902 L F
.392 .105 .354 r
.20715 .55152 m .21007 .54777 L .20857 .54902 L F
.614 .679 .888 r
.26609 .55996 m .26684 .55643 L .26467 .55749 L F
.26609 .55996 m .27034 .56017 L .26684 .55643 L F
.135 0 .023 r
.26542 .55621 m .26467 .55749 L .26684 .55643 L F
.333 0 .131 r
.33241 .54121 m .33538 .53895 L .33349 .53987 L F
.117 0 0 r
.36669 .53665 m .37105 .53597 L .36871 .53635 L F
.521 .481 .753 r
.37162 .53814 m .36871 .53635 L .37105 .53597 L F
.63 .643 .845 r
.38821 .56768 m .38677 .56378 L .38794 .56519 L F
.715 .987 .851 r
.3673 .53034 m .36805 .52864 L .3701 .52798 L F
.648 .59 .776 r
.37046 .52961 m .3673 .53034 L .3701 .52798 L F
.563 .867 .996 r
.37046 .52961 m .36805 .52864 L .3673 .53034 L F
.728 .477 .548 r
.40255 .56301 m .39957 .56628 L .40035 .5643 L F
.40255 .56301 m .4038 .56667 L .39957 .56628 L F
.465 .488 .797 r
.40508 .56277 m .4038 .56667 L .40255 .56301 L F
.295 0 .152 r
.30365 .5521 m .30575 .55186 L .30689 .54992 L F
.328 0 .17 r
.30689 .54992 m .30818 .55096 L .30949 .54901 L F
.30689 .54992 m .30575 .55186 L .30818 .55096 L F
.694 .667 .819 r
.34748 .68031 m .3436 .67744 L .34591 .67641 L F
.686 .676 .835 r
.34591 .67641 m .35031 .67786 L .34748 .68031 L F
0 0 .108 r
.20544 .5785 m .20486 .57692 L .20652 .57632 L F
.20544 .5785 m .20421 .57933 L .20486 .57692 L F
.579 .408 .614 r
.36121 .6522 m .35738 .65644 L .35799 .65152 L F
.494 .32 .574 r
.36097 .65752 m .35858 .65818 L .35738 .65644 L F
.594 .601 .829 r
.36744 .64144 m .36635 .64442 L .36465 .64229 L F
.36744 .64144 m .36871 .64341 L .36635 .64442 L F
0 .418 .856 r
.35794 .51781 m .36156 .51964 L .35891 .51733 L F
.275 .086 .434 r
.29031 .57048 m .29226 .56625 L .29087 .56788 L F
.202 .063 .459 r
.3649 .63944 m .36339 .64222 L .36218 .64043 L F
.3649 .63944 m .36465 .64229 L .36339 .64222 L F
0 0 0 r
.31817 .63934 m .31708 .64041 L .31611 .64187 L F
.426 .517 .848 r
.37564 .51688 m .37512 .52044 L .37336 .51709 L F
.37564 .51688 m .37715 .52025 L .37512 .52044 L F
.8 .581 .605 r
.32043 .61508 m .32076 .61756 L .31735 .61741 L F
.385 .286 .619 r
.32257 .61646 m .32043 .61508 L .32254 .61449 L F
.32257 .61646 m .32076 .61756 L .32043 .61508 L F
.317 0 0 r
.39363 .53954 m .39443 .53991 L .39543 .54009 L F
0 0 .345 r
.39596 .54098 m .39543 .54009 L .39443 .53991 L F
.39596 .54098 m .39681 .54267 L .39543 .54009 L F
.646 .369 .485 r
.33962 .5524 m .33902 .5547 L .3359 .55414 L F
.523 .543 .818 r
.34049 .54789 m .33962 .5524 L .33835 .54822 L F
.576 .202 .296 r
.27049 .54558 m .26595 .54772 L .26666 .54651 L F
.623 .436 .609 r
.37339 .62042 m .37005 .61766 L .3732 .61692 L F
.37339 .62042 m .37014 .62112 L .37005 .61766 L F
.558 .613 .864 r
.30902 .52336 m .30811 .52607 L .30704 .52464 L F
.30902 .52336 m .31021 .52592 L .30811 .52607 L F
.552 .356 .569 r
.34001 .61512 m .3425 .61492 L .34175 .61185 L F
.608 .525 .736 r
.3425 .61492 m .34425 .61085 L .34175 .61185 L F
.589 .1 .061 r
.37767 .63959 m .37353 .63954 L .37508 .63954 L F
0 0 0 r
.30078 .64296 m .29709 .64368 L .30004 .64447 L F
.689 .216 .123 r
.30004 .64447 m .30306 .64482 L .30078 .64296 L F
.641 .284 .35 r
.30306 .64482 m .30289 .64316 L .30078 .64296 L F
.547 .365 .586 r
.37858 .68666 m .37871 .68976 L .37612 .69017 L F
.503 .331 .581 r
.38115 .68908 m .37858 .68666 L .38115 .68628 L F
.38115 .68908 m .37871 .68976 L .37858 .68666 L F
0 .134 .67 r
.34663 .55566 m .34782 .55802 L .34769 .55411 L F
.637 .669 .864 r
.36309 .52459 m .36383 .52123 L .36172 .5213 L F
.36309 .52459 m .36579 .52408 L .36383 .52123 L F
.618 .493 .688 r
.36309 .52459 m .36337 .52724 L .36579 .52408 L F
.35 .323 .687 r
.35288 .60422 m .35025 .60213 L .35222 .60149 L F
.443 .197 .444 r
.35288 .60422 m .35222 .60149 L .3557 .60159 L F
.637 .763 .939 r
.29392 .52603 m .29167 .52705 L .29032 .52527 L F
.687 .744 .895 r
.23907 .63228 m .24301 .63313 L .24136 .63203 L F
.644 .834 .974 r
.24136 .63203 m .24301 .63313 L .24557 .63259 L F
.718 .38 .405 r
.38097 .60849 m .3805 .61072 L .37747 .61014 L F
0 0 0 r
.38382 .60552 m .38269 .60719 L .38097 .60849 L F
.237 0 .267 r
.38138 .60997 m .38097 .60849 L .38269 .60719 L F
.38138 .60997 m .3805 .61072 L .38097 .60849 L F
.229 0 .192 r
.37612 .69017 m .37547 .69236 L .37336 .69282 L F
.517 .159 .298 r
.37808 .69186 m .37612 .69017 L .37871 .68976 L F
.37808 .69186 m .37547 .69236 L .37612 .69017 L F
0 0 0 r
.3544 .53027 m .35504 .53056 L .35684 .53044 L F
.3544 .53027 m .35268 .5318 L .35504 .53056 L F
.743 .666 .775 r
.36092 .51575 m .3568 .51419 L .35875 .51433 L F
.392 .789 .986 r
.35875 .51433 m .36299 .51484 L .36092 .51575 L F
.871 .889 .845 r
.35108 .59795 m .35025 .60213 L .34982 .60115 L F
0 0 0 r
.35025 .60213 m .35091 .60325 L .34982 .60115 L F
.894 .928 .834 r
.30996 .62461 m .3062 .62748 L .30822 .62644 L F
0 0 0 r
.30996 .62461 m .31015 .62553 L .31179 .62317 L F
.30996 .62461 m .30822 .62644 L .31015 .62553 L F
.483 .043 .125 r
.36584 .56308 m .37043 .56086 L .3677 .5618 L F
.441 .793 .997 r
.26027 .63524 m .26085 .63378 L .25811 .63425 L F
.26027 .63524 m .26262 .63475 L .26085 .63378 L F
.865 .944 .867 r
.31928 .53592 m .32133 .53238 L .32322 .53499 L F
.31928 .53592 m .31807 .53551 L .32133 .53238 L F
.602 .935 .953 r
.25336 .5305 m .25385 .52914 L .25561 .52989 L F
.25336 .5305 m .25291 .53002 L .25385 .52914 L F
.51 .8 .998 r
.28008 .64479 m .28489 .64604 L .28481 .64532 L F
0 0 0 r
.23838 .5346 m .23796 .53463 L .23598 .53487 L F
.23838 .5346 m .24037 .53363 L .23796 .53463 L F
.7 .962 .713 r
.32013 .6276 m .31728 .63033 L .31806 .62884 L F
.824 .405 .248 r
.31806 .62884 m .32146 .63026 L .32013 .6276 L F
.758 .844 .917 r
.3425 .61492 m .34665 .61461 L .3446 .61467 L F
.281 0 0 r
.34665 .61461 m .34727 .61589 L .3446 .61467 L F
.34665 .61461 m .34906 .61447 L .34727 .61589 L F
0 0 .02 r
.34665 .61461 m .34915 .6116 L .34906 .61447 L F
.606 .443 .635 r
.33684 .57364 m .33425 .57132 L .33655 .57089 L F
.33684 .57364 m .33431 .57422 L .33425 .57132 L F
.359 .027 .26 r
.3006 .54018 m .30056 .54255 L .29735 .54317 L F
.507 .138 .274 r
.30293 .54155 m .30056 .54255 L .3006 .54018 L F
.648 .504 .673 r
.31302 .59877 m .31677 .59891 L .31598 .59512 L F
.578 .448 .667 r
.31531 .60111 m .31677 .59891 L .31302 .59877 L F
.779 .487 .492 r
.31815 .57395 m .3216 .57695 L .32111 .57413 L F
.469 .239 .483 r
.25681 .74879 m .25544 .74607 L .25462 .74878 L F
.555 .225 .364 r
.32799 .58915 m .32428 .59209 L .32428 .58982 L F
.32799 .58915 m .32737 .59183 L .32428 .59209 L F
.193 .183 .618 r
.32937 .58581 m .32989 .58869 L .32799 .58915 L F
.053 0 .188 r
.32886 .59093 m .32799 .58915 L .32989 .58869 L F
.32886 .59093 m .32737 .59183 L .32799 .58915 L F
.238 0 .191 r
.32429 .66165 m .32159 .66458 L .32414 .66435 L F
.48 .276 .525 r
.32686 .66125 m .32429 .66165 L .32414 .66435 L F
.3 .011 .296 r
.34915 .6116 m .35186 .60885 L .35128 .61115 L F
.54 .491 .749 r
.3546 .60802 m .35186 .60885 L .35116 .60489 L F
.442 .135 .348 r
.35128 .61115 m .35186 .60885 L .35367 .61033 L F
.896 .648 .554 r
.34102 .55569 m .33906 .5575 L .33902 .5547 L F
.695 .387 .45 r
.34336 .55534 m .33906 .5575 L .34102 .55569 L F
.976 .761 .549 r
.37229 .58573 m .36858 .58427 L .36917 .58495 L F
.569 .458 .688 r
.36917 .58495 m .37254 .58907 L .37229 .58573 L F
.36917 .58495 m .37012 .58987 L .37254 .58907 L F
.447 .16 .383 r
.33017 .55701 m .32653 .5608 L .32758 .55817 L F
.315 .796 .901 r
.2623 .74272 m .2639 .74295 L .26619 .74249 L F
.218 .047 .423 r
.31604 .60846 m .31773 .60771 L .31799 .60501 L F
.275 .167 .546 r
.31604 .60846 m .31785 .6104 L .31773 .60771 L F
.325 .173 .516 r
.31604 .60846 m .31597 .6111 L .31785 .6104 L F
0 0 .056 r
.27018 .61992 m .27125 .62109 L .27144 .62059 L F
.168 0 0 r
.27457 .61721 m .27237 .61779 L .2706 .6196 L F
.27457 .61721 m .2706 .6196 L .2706 .61961 L F
.27457 .61721 m .2706 .61961 L .27272 .61739 L F
0 0 .056 r
.27057 .61957 m .2706 .61961 L .27084 .61932 L F
.27018 .61992 m .27144 .62059 L .27057 .61957 L F
.168 0 0 r
.2706 .61961 m .2706 .6196 L .27057 .61963 L F
.2706 .61961 m .27057 .61963 L .27069 .6195 L F
.2706 .61961 m .27069 .6195 L .27272 .61739 L F
0 0 .056 r
.27084 .61932 m .27144 .62059 L .2725 .61781 L F
.2706 .61961 m .27144 .62059 L .27084 .61932 L F
.842 .731 .741 r
.36733 .63649 m .36318 .6359 L .3656 .63557 L F
.36733 .63649 m .3649 .63944 L .36318 .6359 L F
.707 .518 .63 r
.36733 .63649 m .36763 .63965 L .3649 .63944 L F
.965 .783 .608 r
.36733 .63649 m .36594 .63279 L .36758 .63375 L F
.36733 .63649 m .3656 .63557 L .36594 .63279 L F
.274 0 0 r
.22832 .61111 m .22973 .6111 L .23106 .61057 L F
.22832 .61111 m .22684 .613 L .22973 .6111 L F
.307 .627 .961 r
.19406 .60224 m .19446 .60075 L .19267 .60044 L F
.191 .499 .906 r
.19406 .60224 m .19564 .6025 L .19446 .60075 L F
.479 .226 .453 r
.32087 .60166 m .31799 .60501 L .31984 .60406 L F
.649 .929 .656 r
.32364 .59885 m .32087 .60166 L .32139 .60056 L F
.834 .861 .865 r
.31984 .60406 m .32139 .60056 L .32087 .60166 L F
.472 .276 .532 r
.32364 .59885 m .32338 .60175 L .32087 .60166 L F
.779 .487 .492 r
.31815 .57395 m .31839 .57673 L .3216 .57695 L F
.49 .825 .999 r
.20963 .82693 m .20745 .82749 L .20554 .82661 L F
.20554 .82661 m .20745 .82749 L .20963 .82693 L F
.24 0 .165 r
.2002 .55545 m .19911 .55743 L .20224 .55476 L F
.082 .322 .8 r
.33225 .5252 m .32999 .52414 L .32876 .52251 L F
.33225 .5252 m .33277 .52618 L .32999 .52414 L F
.116 .518 .911 r
.18352 .60032 m .18409 .5994 L .18369 .59836 L F
.18352 .60032 m .18601 .60113 L .18409 .5994 L F
.78 .589 .641 r
.21822 .61368 m .22273 .61181 L .22127 .61119 L F
.21822 .61368 m .22257 .61457 L .22273 .61181 L F
.859 .83 .817 r
.36929 .63167 m .36594 .63279 L .36823 .62981 L F
.36929 .63167 m .36758 .63375 L .36594 .63279 L F
.466 .599 .9 r
.37071 .62921 m .36929 .63167 L .36823 .62981 L F
.37071 .62921 m .37293 .63261 L .36929 .63167 L F
.606 .831 .986 r
.38064 .63603 m .37609 .63543 L .37943 .63354 L F
0 0 .307 r
.38196 .6322 m .38064 .63603 L .37943 .63354 L F
.38196 .6322 m .38195 .63486 L .38064 .63603 L F
0 .098 .62 r
.38195 .63486 m .38248 .63795 L .38064 .63603 L F
.424 .145 .383 r
.38248 .63795 m .37991 .63885 L .38064 .63603 L F
.28 .191 .573 r
.36241 .61117 m .36407 .61096 L .36436 .60682 L F
.851 .421 0 r
.37419 .52975 m .37264 .52846 L .37186 .52657 L F
0 .224 .737 r
.37419 .52975 m .37427 .52862 L .37264 .52846 L F
.37419 .52975 m .37548 .53059 L .37427 .52862 L F
.571 .456 .683 r
.35128 .61115 m .34906 .61447 L .34915 .6116 L F
.695 .742 .888 r
.21822 .61368 m .2201 .61558 L .22257 .61457 L F
.518 .261 .465 r
.2201 .61558 m .22193 .61708 L .22257 .61457 L F
.882 .992 .775 r
.32956 .65846 m .32686 .66125 L .32957 .65863 L F
.732 .619 .732 r
.36066 .63642 m .36218 .64043 L .3585 .63984 L F
.648 .575 .759 r
.3649 .63944 m .36218 .64043 L .36066 .63642 L F
.445 0 .04 r
.33866 .63471 m .33772 .63291 L .33577 .63505 L F
.33866 .63471 m .3403 .63292 L .33772 .63291 L F
.31 .109 .437 r
.30162 .59251 m .29916 .595 L .29913 .59258 L F
.30162 .59251 m .30159 .59487 L .29916 .595 L F
.305 .072 .387 r
.30159 .59487 m .29916 .59794 L .29916 .595 L F
.49 .623 .909 r
.35383 .55038 m .35031 .54975 L .35449 .54869 L F
.357 .83 .86 r
.24266 .53293 m .24396 .53289 L .24037 .53363 L F
.364 .833 .876 r
.24499 .5322 m .24614 .53225 L .24396 .53289 L F
.368 .837 .864 r
.24499 .5322 m .24396 .53289 L .24266 .53293 L F
.573 .515 .751 r
.34001 .61512 m .34035 .61728 L .3425 .61492 L F
.305 .276 .661 r
.18037 .58328 m .1807 .58684 L .18245 .5852 L F
.491 .468 .759 r
.18122 .58934 m .18245 .5852 L .1807 .58684 L F
0 .568 .749 r
.32645 .66999 m .32779 .67002 L .3255 .67034 L F
.32719 .67004 m .32946 .67019 L .32779 .67002 L F
0 .557 .739 r
.32946 .67019 m .33174 .67037 L .32779 .67002 L F
.194 0 0 r
.32946 .67019 m .33337 .67083 L .33174 .67037 L F
.688 .252 .21 r
.33174 .67037 m .33001 .6722 L .32779 .67002 L F
0 .148 .691 r
.32779 .67002 m .33001 .6722 L .32868 .67 L F
.32779 .67002 m .32868 .67 L .32812 .66907 L F
0 .568 .749 r
.32645 .66999 m .32719 .67004 L .32779 .67002 L F
.465 0 0 r
.30552 .64448 m .30289 .64316 L .30306 .64482 L F
0 0 .359 r
.39323 .58232 m .39336 .58619 L .39317 .58636 L F
0 .025 .594 r
.39336 .58619 m .39476 .58849 L .39317 .58636 L F
.324 .191 .541 r
.39317 .58636 m .39476 .58849 L .39292 .58872 L F
.194 .714 .683 r
.36864 .56291 m .37308 .56166 L .37043 .56086 L F
.383 .84 .768 r
.37308 .56166 m .37099 .56225 L .37172 .56187 L F
.37308 .56166 m .37172 .56187 L .37279 .56133 L F
.349 0 0 r
.37386 .56154 m .37308 .56166 L .37402 .56157 L F
.37043 .56086 m .37308 .56166 L .37386 .56154 L F
.37 .271 .611 r
.37402 .56157 m .37649 .56058 L .37618 .55823 L F
.634 .962 .82 r
.37402 .56157 m .37492 .56021 L .37649 .56058 L F
.37402 .56157 m .37308 .56166 L .37492 .56021 L F
.668 .744 .907 r
.35647 .67444 m .35208 .67315 L .355 .67284 L F
.744 .779 .882 r
.35852 .67332 m .35647 .67444 L .355 .67284 L F
.576 .202 .296 r
.27049 .54558 m .2684 .54795 L .26595 .54772 L F
.558 .181 .283 r
.27257 .5456 m .2684 .54795 L .27049 .54558 L F
.68 .613 .774 r
.37565 .67406 m .37303 .67443 L .37172 .67106 L F
0 0 .39 r
.37405 .67547 m .37303 .67443 L .37565 .67406 L F
.37405 .67547 m .373 .67716 L .37303 .67443 L F
.853 .983 .858 r
.33909 .53577 m .34028 .53264 L .34186 .53581 L F
.33909 .53577 m .33749 .53549 L .34028 .53264 L F
.959 .879 .482 r
.3824 .60572 m .38382 .60552 L .3829 .60328 L F
.3824 .60572 m .38269 .60719 L .38382 .60552 L F
.397 .089 .321 r
.31467 .64837 m .31755 .64592 L .31626 .64833 L F
.778 .407 .353 r
.31755 .64592 m .31981 .64886 L .31626 .64833 L F
.792 .574 .606 r
.31995 .64557 m .31981 .64886 L .31755 .64592 L F
.438 .556 .877 r
.37463 .63235 m .37609 .63543 L .37392 .63539 L F
0 0 0 r
.36128 .66081 m .36011 .66195 L .36219 .65977 L F
.103 .086 .551 r
.30893 .54592 m .31051 .54768 L .31063 .54512 L F
.30893 .54592 m .30949 .54901 L .31051 .54768 L F
.787 .678 .745 r
.25311 .54902 m .25488 .5518 L .25119 .55086 L F
.699 .203 .062 r
.25488 .5518 m .25288 .55198 L .25119 .55086 L F
.178 0 0 r
.25735 .55204 m .25288 .55198 L .25488 .5518 L F
0 0 .333 r
.39419 .59297 m .39292 .58872 L .39476 .58849 L F
.833 .7 .717 r
.39751 .59182 m .39452 .59301 L .3945 .59113 L F
.795 .669 .726 r
.39417 .59322 m .39452 .59361 L .39399 .59209 L F
.39452 .59361 m .39451 .59295 L .39399 .59209 L F
.39452 .59361 m .39576 .59497 L .39452 .59301 L F
.826 .675 .696 r
.39452 .59301 m .39576 .59497 L .39417 .59315 L F
.39751 .59182 m .39576 .59497 L .39452 .59301 L F
.795 .669 .726 r
.39452 .59301 m .39576 .59497 L .39451 .59295 L F
.39431 .59262 m .39576 .59497 L .39465 .59161 L F
.39431 .59262 m .39465 .59161 L .3945 .59113 L F
.833 .7 .717 r
.39452 .59301 m .39417 .59315 L .3945 .59113 L F
.48 .595 .891 r
.39415 .5932 m .39576 .59497 L .39358 .59532 L F
.795 .669 .726 r
.39443 .59485 m .39576 .59497 L .39417 .59322 L F
.48 .595 .891 r
.39417 .59315 m .39576 .59497 L .39415 .5932 L F
0 0 .333 r
.39417 .59315 m .39415 .59309 L .39419 .59297 L F
.39415 .59309 m .39292 .58872 L .39419 .59297 L F
.795 .669 .726 r
.39399 .59209 m .39431 .59262 L .3945 .59113 L F
0 0 .333 r
.39415 .59309 m .39369 .59333 L .39292 .58872 L F
.39416 .59315 m .39369 .59333 L .39415 .59309 L F
.48 .595 .891 r
.39416 .59315 m .39358 .59532 L .39369 .59333 L F
.795 .669 .726 r
.39392 .5948 m .39443 .59485 L .39416 .59315 L F
.48 .595 .891 r
.39417 .59315 m .39415 .5932 L .39416 .59315 L F
.39415 .5932 m .39358 .59532 L .39416 .59315 L F
.795 .669 .726 r
.39263 .59468 m .39392 .5948 L .39399 .59209 L F
.39392 .5948 m .39416 .59315 L .39399 .59209 L F
0 0 .333 r
.39417 .59315 m .39416 .59315 L .39415 .59309 L F
.528 .426 .682 r
.31598 .59512 m .31903 .5959 L .31834 .59207 L F
.647 .588 .774 r
.31677 .59891 m .31903 .5959 L .31598 .59512 L F
.305 .276 .661 r
.18037 .58328 m .18245 .5852 L .182 .58258 L F
.742 .607 .708 r
.32428 .58982 m .32201 .59262 L .32199 .59 L F
.429 .188 .445 r
.32428 .59209 m .32201 .59262 L .32428 .58982 L F
.28 .449 .851 r
.37405 .67547 m .37601 .68074 L .373 .67716 L F
.631 .68 .878 r
.37876 .67722 m .37601 .68074 L .37405 .67547 L F
0 0 0 r
.34346 .56054 m .34512 .56042 L .34782 .55802 L F
.355 0 .059 r
.34782 .55802 m .34919 .55936 L .34769 .55411 L F
.34782 .55802 m .34512 .56042 L .34919 .55936 L F
.472 .064 .185 r
.37683 .61404 m .37563 .61484 L .37273 .61464 L F
0 0 0 r
.37563 .61484 m .3732 .61692 L .37273 .61464 L F
.673 .652 .821 r
.34589 .57046 m .34478 .57375 L .34321 .57164 L F
.34589 .57046 m .34741 .57411 L .34478 .57375 L F
0 0 0 r
.34741 .57411 m .34418 .57636 L .34478 .57375 L F
.157 .345 .801 r
.388 .52793 m .38597 .52814 L .38509 .52617 L F
.388 .52793 m .38831 .52959 L .38597 .52814 L F
.125 0 .406 r
.36626 .59887 m .36764 .59825 L .36768 .59555 L F
.293 .188 .559 r
.36626 .59887 m .36801 .60096 L .36764 .59825 L F
.36626 .59887 m .36644 .60192 L .36801 .60096 L F
.203 0 0 r
.22164 .54062 m .22486 .53892 L .22264 .53966 L F
0 0 .119 r
.39105 .59551 m .39065 .59794 L .38876 .59909 L F
.62 .685 .889 r
.33392 .5439 m .33799 .5459 L .3362 .54503 L F
0 0 .324 r
.33799 .5459 m .3385 .54687 L .33914 .54483 L F
.497 0 0 r
.35502 .63334 m .35568 .63402 L .35712 .63344 L F
.707 .6 .734 r
.36043 .64838 m .36121 .6522 L .35799 .65152 L F
.292 .375 .776 r
.356 .62966 m .35712 .63344 L .35825 .63211 L F
.772 .499 .523 r
.35568 .63402 m .35825 .63211 L .35712 .63344 L F
.555 .375 .592 r
.36372 .64904 m .36121 .6522 L .36043 .64838 L F
.36372 .64904 m .36408 .65174 L .36121 .6522 L F
.423 .315 .627 r
.36363 .65438 m .36121 .6522 L .36408 .65174 L F
.432 .318 .623 r
.37007 .5743 m .37242 .57622 L .37324 .57386 L F
.37007 .5743 m .37043 .57683 L .37242 .57622 L F
0 0 0 r
.33229 .56405 m .33166 .56431 L .33407 .5637 L F
.311 .366 .758 r
.31765 .63286 m .31806 .62884 L .31728 .63033 L F
.867 .485 .316 r
.32181 .6319 m .32366 .63068 L .32146 .63026 L F
.795 .366 .23 r
.32181 .6319 m .32476 .63271 L .32366 .63068 L F
.759 .523 .575 r
.32704 .63354 m .32366 .63068 L .32476 .63271 L F
.677 .492 .629 r
.37336 .69282 m .37364 .69576 L .37066 .69569 L F
.374 .323 .673 r
.37547 .69236 m .37582 .69506 L .37336 .69282 L F
.454 .328 .619 r
.37582 .69506 m .37364 .69576 L .37336 .69282 L F
.417 .821 .979 r
.29604 .52507 m .30019 .52532 L .29793 .52571 L F
.013 .257 .761 r
.21463 .58869 m .21567 .59249 L .21261 .589 L F
.21463 .58869 m .21628 .59214 L .21567 .59249 L F
0 0 0 r
.34741 .57411 m .34557 .57556 L .34418 .57636 L F
.551 .585 .842 r
.34938 .57318 m .34741 .57411 L .34589 .57046 L F
.127 0 0 r
.34784 .57512 m .34741 .57411 L .34938 .57318 L F
.34784 .57512 m .34557 .57556 L .34741 .57411 L F
.525 .451 .715 r
.21799 .56731 m .21518 .56484 L .21771 .5643 L F
.21799 .56731 m .21587 .56844 L .21518 .56484 L F
.969 .859 .46 r
.38039 .53792 m .37969 .5379 L .38092 .53627 L F
.785 .517 0 r
.38092 .53627 m .38059 .53555 L .38003 .53265 L F
.913 .891 .475 r
.38092 .53627 m .37969 .5379 L .38059 .53555 L F
.475 .859 .65 r
.31532 .54642 m .31304 .54782 L .31208 .54866 L F
.139 0 0 r
.31761 .54607 m .31304 .54782 L .31532 .54642 L F
.598 .085 .002 r
.27998 .62627 m .28214 .62708 L .28439 .62664 L F
.709 .427 .495 r
.351 .68362 m .34867 .68579 L .34894 .68313 L F
.351 .68362 m .35079 .68607 L .34867 .68579 L F
.582 .742 .953 r
.28475 .7057 m .2877 .70565 L .28688 .7044 L F
.979 .819 .615 r
.2417 .61157 m .23932 .61349 L .24049 .61387 L F
.644 .834 .974 r
.24136 .63203 m .24557 .63259 L .24253 .63107 L F
.3 .697 .976 r
.24557 .63259 m .24619 .63109 L .24253 .63107 L F
.24557 .63259 m .24793 .63233 L .24619 .63109 L F
.751 .827 .911 r
.25988 .7399 m .26201 .73883 L .25709 .73671 L F
.375 .211 .527 r
.30922 .56424 m .3112 .56096 L .30877 .56147 L F
.598 .236 .326 r
.23331 .61086 m .23532 .61128 L .23771 .60854 L F
.511 .132 .258 r
.23771 .60854 m .23938 .61057 L .23803 .60698 L F
.23771 .60854 m .23532 .61128 L .23938 .61057 L F
.713 .524 .633 r
.21799 .56731 m .21487 .56984 L .21587 .56844 L F
.302 .145 .495 r
.18129 .57711 m .18349 .57861 L .18336 .5759 L F
.18129 .57711 m .18129 .58015 L .18349 .57861 L F
0 0 .401 r
.2922 .62945 m .29106 .62633 L .29248 .6264 L F
.47 .7 .968 r
.18601 .60113 m .18785 .60256 L .18826 .60101 L F
0 .193 .724 r
.20862 .58736 m .2094 .5886 L .20883 .58921 L F
.344 .819 .89 r
.20851 .58956 m .20883 .58921 L .21056 .58933 L F
.563 .074 .054 r
.20883 .58921 m .21261 .589 L .21056 .58933 L F
.20883 .58921 m .21059 .59052 L .21261 .589 L F
0 .193 .724 r
.2094 .5886 m .21059 .59052 L .20883 .58921 L F
.344 .819 .89 r
.20646 .58979 m .20883 .58921 L .20851 .58956 L F
.138 .342 .803 r
.20394 .6079 m .20573 .6114 L .20651 .60972 L F
.283 .525 .908 r
.20573 .6114 m .20743 .61152 L .20651 .60972 L F
0 .148 .679 r
.36172 .5213 m .36271 .52036 L .36156 .51964 L F
.276 .682 .97 r
.36172 .5213 m .36383 .52123 L .36271 .52036 L F
.548 .881 .62 r
.37374 .60772 m .37089 .61008 L .37121 .60876 L F
.803 .609 .64 r
.37089 .61008 m .37374 .60772 L .37121 .60876 L F
.549 .8 .991 r
.33364 .51641 m .33503 .51772 L .33107 .5171 L F
.367 .154 .453 r
.33253 .51859 m .33107 .5171 L .33503 .51772 L F
.967 .841 .665 r
.33364 .51641 m .33253 .51859 L .33503 .51772 L F
.746 .38 .359 r
.33769 .62314 m .33722 .62121 L .33411 .62076 L F
.712 .888 .961 r
.33337 .67083 m .33605 .67034 L .33408 .66956 L F
.122 .302 .773 r
.34465 .54554 m .34563 .54404 L .34271 .54146 L F
0 0 .456 r
.27943 .5439 m .27834 .543 L .28033 .54198 L F
.27943 .5439 m .27898 .54566 L .27834 .543 L F
.672 .191 .102 r
.27363 .64187 m .27811 .64277 L .27534 .64257 L F
.548 0 0 r
.27534 .64257 m .27614 .64295 L .27363 .64187 L F
.319 .576 .933 r
.27363 .64187 m .2753 .64258 L .27484 .64076 L F
0 .015 .531 r
.27811 .64277 m .27866 .64325 L .27534 .64257 L F
.27866 .64325 m .27883 .64341 L .27634 .64281 L F
.27866 .64325 m .27634 .64281 L .27534 .64257 L F
.27669 .64291 m .27902 .64357 L .27585 .64271 L F
.27883 .64341 m .27888 .64345 L .27669 .64291 L F
.27888 .64345 m .27902 .64357 L .27669 .64291 L F
.296 .48 .87 r
.27534 .64257 m .27691 .64043 L .27619 .64279 L F
.27534 .64257 m .27619 .64279 L .27614 .64295 L F
.27534 .64257 m .27585 .64271 L .27691 .64043 L F
.319 .576 .933 r
.2753 .64258 m .27585 .64271 L .27484 .64076 L F
.27585 .64271 m .27603 .64275 L .27598 .64267 L F
.27585 .64271 m .27598 .64267 L .27484 .64076 L F
.296 .48 .87 r
.27585 .64271 m .27595 .64274 L .27598 .64267 L F
.27585 .64271 m .27598 .64267 L .27691 .64043 L F
.444 .655 .95 r
.27598 .64267 m .27603 .64275 L .27691 .64043 L F
.27603 .64275 m .27619 .64279 L .27691 .64043 L F
0 .015 .531 r
.27883 .64341 m .27585 .64271 L .27534 .64257 L F
.296 .48 .87 r
.27595 .64274 m .27902 .64357 L .27691 .64043 L F
.444 .655 .95 r
.27566 .64214 m .27598 .64267 L .27691 .64043 L F
.27484 .64076 m .27566 .64214 L .27691 .64043 L F
.27603 .64275 m .27614 .64295 L .27619 .64279 L F
.319 .576 .933 r
.2753 .64258 m .27614 .64295 L .27603 .64275 L F
0 .015 .531 r
.27811 .64277 m .28008 .64479 L .27902 .64357 L F
.729 .658 .779 r
.31668 .56813 m .31885 .57199 L .31919 .5709 L F
.398 .102 .343 r
.3268 .57068 m .32911 .57011 L .32965 .56802 L F
.533 .421 .672 r
.32965 .56802 m .33238 .56738 L .33166 .56431 L F
.447 .158 .379 r
.32911 .57011 m .33238 .56738 L .32965 .56802 L F
.695 .387 .45 r
.34336 .55534 m .3417 .55782 L .33906 .5575 L F
.853 .937 .564 r
.34273 .5545 m .3417 .55782 L .34336 .55534 L F
.197 .721 .855 r
.25561 .52989 m .25796 .52967 L .25956 .52982 L F
.326 .789 .939 r
.25796 .52967 m .26196 .52968 L .25956 .52982 L F
.713 .98 .908 r
.32479 .55507 m .32234 .5571 L .32351 .55531 L F
.589 .056 0 r
.32351 .55531 m .3251 .55562 L .32479 .55507 L F
.3251 .55562 m .32696 .55598 L .32479 .55507 L F
0 0 0 r
.32414 .55391 m .32479 .55507 L .32472 .55244 L F
.32351 .55553 m .32479 .55507 L .32414 .55391 L F
.452 .803 .998 r
.35738 .57936 m .35984 .57903 L .36208 .58009 L F
.438 .797 .996 r
.35984 .57903 m .36239 .57886 L .36208 .58009 L F
.732 .211 0 r
.36208 .58009 m .36439 .58293 L .36532 .58315 L F
0 .09 .647 r
.36239 .57886 m .36439 .58293 L .36208 .58009 L F
.158 .111 .551 r
.21687 .59465 m .21558 .5988 L .21498 .5963 L F
.578 .448 .667 r
.31531 .60111 m .31678 .60078 L .31677 .59891 L F
.192 .488 .9 r
.39114 .53138 m .39071 .53309 L .38831 .52959 L F
.39114 .53138 m .39189 .53274 L .39071 .53309 L F
.127 .204 .674 r
.39275 .53511 m .39071 .53309 L .39189 .53274 L F
.065 .254 .746 r
.21732 .60127 m .21764 .60464 L .2156 .6013 L F
.21732 .60127 m .21873 .60469 L .21764 .60464 L F
.056 .393 .852 r
.22001 .60669 m .21764 .60464 L .21873 .60469 L F
.787 .91 .925 r
.36496 .65974 m .36927 .65853 L .36804 .65825 L F
.36496 .65974 m .36549 .66018 L .36927 .65853 L F
.99 .727 .383 r
.29661 .58678 m .29528 .58772 L .29526 .58506 L F
.844 .393 .137 r
.29661 .58678 m .29751 .58894 L .29528 .58772 L F
.215 .588 .946 r
.26788 .63673 m .27061 .63874 L .2723 .63881 L F
.878 .96 .85 r
.32514 .54666 m .32244 .54737 L .32359 .54501 L F
.593 .744 .949 r
.32713 .54593 m .32514 .54666 L .32359 .54501 L F
.322 .46 .844 r
.32813 .54838 m .32514 .54666 L .32713 .54593 L F
.125 .637 .895 r
.36528 .51455 m .36971 .51549 L .36723 .51566 L F
.579 .935 .931 r
.26591 .53665 m .26456 .53757 L .26741 .53641 L F
.616 .646 .857 r
.26456 .53757 m .2677 .53956 L .26741 .53641 L F
.594 .476 .688 r
.26741 .53641 m .27032 .53808 L .26931 .53624 L F
.26741 .53641 m .2677 .53956 L .27032 .53808 L F
.396 .839 .937 r
.26931 .53624 m .26591 .53665 L .26741 .53641 L F
.78 .677 .75 r
.34834 .56717 m .3496 .57222 L .34589 .57046 L F
.551 .585 .842 r
.34938 .57318 m .34589 .57046 L .3496 .57222 L F
.18 .273 .724 r
.35074 .57027 m .3496 .57222 L .34834 .56717 L F
.811 .934 .564 r
.35074 .57027 m .34938 .57318 L .3496 .57222 L F
0 0 0 r
.38118 .55195 m .38322 .55064 L .38417 .54908 L F
.484 .266 .506 r
.38417 .54908 m .38641 .55093 L .38661 .54841 L F
0 .554 .768 r
.38661 .54841 m .38417 .54807 L .38263 .5455 L F
.38417 .54807 m .38254 .54784 L .38261 .54617 L F
.38417 .54807 m .38261 .54617 L .38263 .5455 L F
0 0 0 r
.38417 .54908 m .38456 .54855 L .38641 .55093 L F
0 .554 .768 r
.38661 .54841 m .3849 .54808 L .38254 .54784 L F
0 0 0 r
.38456 .54855 m .3849 .54808 L .38623 .55058 L F
.38456 .54855 m .38623 .55058 L .38641 .55093 L F
.38417 .54908 m .38322 .55064 L .3849 .54808 L F
.78 .816 .881 r
.36815 .67001 m .36367 .66991 L .36598 .66871 L F
.36815 .67001 m .36544 .6713 L .36367 .66991 L F
.657 .851 .974 r
.37037 .66834 m .36815 .67001 L .36598 .66871 L F
.591 .626 .855 r
.37172 .67106 m .36815 .67001 L .37037 .66834 L F
0 0 0 r
.35521 .5663 m .35459 .56968 L .3549 .5668 L F
.228 0 .32 r
.37073 .62639 m .36823 .62981 L .36885 .62731 L F
.709 .456 .54 r
.35459 .56968 m .35086 .567 L .3549 .5668 L F
.426 .435 .766 r
.35616 .56336 m .3549 .5668 L .35546 .5647 L F
.766 .433 .423 r
.35965 .63033 m .35825 .63211 L .356 .62966 L F
.292 .375 .776 r
.356 .62966 m .35825 .63211 L .35965 .63033 L F
.635 .265 .326 r
.35825 .63211 m .36189 .63244 L .35965 .63033 L F
.567 .027 0 r
.35965 .63033 m .3602 .63109 L .35825 .63211 L F
.35965 .63033 m .36189 .63244 L .3602 .63109 L F
.619 .271 .358 r
.36234 .6305 m .36189 .63244 L .35965 .63033 L F
.041 0 0 r
.19406 .56095 m .19597 .56029 L .19727 .55835 L F
.149 0 .039 r
.19597 .56029 m .19911 .55743 L .19727 .55835 L F
0 0 0 r
.37463 .58291 m .37229 .58573 L .37461 .58523 L F
.5 .392 .664 r
.37461 .58523 m .37684 .58131 L .37463 .58291 L F
.611 .663 .876 r
.37548 .53059 m .37749 .53336 L .38003 .53265 L F
.244 0 0 r
.23293 .55797 m .2313 .56012 L .22894 .56066 L F
0 0 0 r
.23329 .55911 m .23293 .55797 L .23459 .55624 L F
.23329 .55911 m .2313 .56012 L .23293 .55797 L F
.443 .468 .791 r
.32482 .5953 m .32201 .59262 L .32428 .59209 L F
.68 .613 .774 r
.37565 .67406 m .37172 .67106 L .37563 .67216 L F
.402 .395 .737 r
.37729 .67285 m .37565 .67406 L .37563 .67216 L F
.365 0 .196 r
.37729 .67285 m .37405 .67547 L .37565 .67406 L F
.144 0 0 r
.36974 .56547 m .36808 .56508 L .37042 .56467 L F
.36974 .56547 m .36713 .5665 L .36808 .56508 L F
.322 .389 .776 r
.39791 .54439 m .39898 .54812 L .3966 .54654 L F
.63 .643 .845 r
.38821 .56768 m .38437 .56512 L .38677 .56378 L F
.655 .549 .722 r
.38951 .5583 m .38685 .56143 L .3867 .55879 L F
.744 .779 .882 r
.35852 .67332 m .355 .67284 L .35752 .67033 L F
.711 .682 .82 r
.36132 .67068 m .35852 .67332 L .35752 .67033 L F
0 0 0 r
.35594 .56017 m .35368 .55885 L .35568 .55704 L F
.319 0 .133 r
.2761 .62936 m .27998 .62627 L .27739 .62632 L F
0 0 .026 r
.39164 .59645 m .39105 .59551 L .39358 .59532 L F
.39164 .59645 m .39065 .59794 L .39105 .59551 L F
.441 .282 .568 r
.37254 .58907 m .37461 .58523 L .37229 .58573 L F
.709 .836 .943 r
.30575 .55186 m .30986 .55203 L .30818 .55096 L F
.74 .915 .548 r
.31085 .55052 m .31048 .55042 L .30986 .55203 L F
.506 .809 .999 r
.30986 .55203 m .31048 .55042 L .30818 .55096 L F
0 0 0 r
.30949 .54901 m .30818 .55096 L .31051 .54768 L F
.491 .321 .578 r
.30818 .55096 m .31048 .55042 L .31051 .54768 L F
.84 .567 .525 r
.30925 .54914 m .31037 .55147 L .31063 .551 L F
.668 .484 .626 r
.31062 .5507 m .31012 .55031 L .31048 .55042 L F
.311 .5515 m .31063 .551 L .31062 .5507 L F
.31063 .551 m .31012 .55031 L .31062 .5507 L F
.031 .221 .726 r
.31208 .54866 m .31304 .54782 L .31281 .54696 L F
.561 .853 .997 r
.31281 .54696 m .31051 .54768 L .31208 .54866 L F
.853 .789 .788 r
.31281 .54696 m .31304 .54782 L .31761 .54607 L F
.31281 .54696 m .31761 .54607 L .31574 .54721 L F
.668 .484 .626 r
.3111 .55172 m .31048 .55042 L .31362 .5507 L F
.74 .915 .548 r
.31208 .54866 m .31048 .55042 L .31085 .55052 L F
.598 .447 .647 r
.31281 .54696 m .31048 .55042 L .31208 .54866 L F
.31281 .54696 m .31362 .5507 L .31048 .55042 L F
.427 .334 .647 r
.31518 .54898 m .31281 .54696 L .31574 .54721 L F
.31518 .54898 m .31362 .5507 L .31281 .54696 L F
0 0 0 r
.31281 .54696 m .31063 .551 L .3138 .54572 L F
.31063 .551 m .31037 .55147 L .31063 .55104 L F
.31063 .551 m .31063 .55104 L .3138 .54572 L F
.668 .484 .626 r
.31008 .5503 m .30925 .54914 L .31048 .55042 L F
.558 .455 .694 r
.31043 .55078 m .31037 .55147 L .30925 .54914 L F
.668 .484 .626 r
.31008 .5503 m .30925 .54914 L .31008 .5503 L F
.84 .567 .525 r
.30925 .54914 m .31051 .54768 L .31048 .55042 L F
.30925 .54914 m .31063 .551 L .31281 .54696 L F
.482 .268 .512 r
.31063 .54512 m .31281 .54696 L .31108 .54314 L F
.31063 .54512 m .31051 .54768 L .31281 .54696 L F
.84 .567 .525 r
.30925 .54914 m .31281 .54696 L .31051 .54768 L F
.558 .455 .694 r
.31091 .5451 m .31043 .55078 L .30925 .54914 L F
0 .14 .66 r
.31245 .54618 m .31284 .54293 L .31108 .54314 L F
.31281 .54696 m .31281 .54603 L .31245 .54618 L F
.31281 .54603 m .31284 .54293 L .31245 .54618 L F
.31281 .54603 m .3138 .54572 L .31284 .54293 L F
.31281 .54696 m .3138 .54572 L .31281 .54603 L F
.753 .627 .721 r
.3138 .54572 m .31063 .55104 L .3108 .5474 L F
.78 .558 .598 r
.31175 .53782 m .31067 .54074 L .31525 .54096 L F
.087 0 0 r
.31108 .54314 m .31525 .54096 L .31067 .54074 L F
.31108 .54314 m .31284 .54293 L .31525 .54096 L F
.316 .338 .726 r
.31172 .53867 m .31284 .54293 L .31108 .54314 L F
.753 .627 .721 r
.3138 .54572 m .31083 .54674 L .31161 .54525 L F
.3138 .54572 m .31091 .5451 L .31138 .54554 L F
.291 .001 .288 r
.31284 .54293 m .31138 .54554 L .31091 .5451 L F
0 .031 .58 r
.31303 .54244 m .31284 .54293 L .31172 .53867 L F
.722 .854 .425 r
.31303 .54244 m .31138 .54554 L .31271 .54315 L F
.31286 .54288 m .31271 .54315 L .31284 .54293 L F
.31303 .54244 m .31271 .54315 L .31286 .54288 L F
.753 .627 .721 r
.3138 .54572 m .3108 .5474 L .31083 .54674 L F
.31161 .54525 m .31083 .54674 L .31091 .5451 L F
.693 .398 .47 r
.31187 .54708 m .31459 .54547 L .3138 .54572 L F
.31459 .54547 m .31568 .54483 L .3138 .54572 L F
.31568 .54483 m .31584 .54474 L .31542 .54494 L F
.31568 .54483 m .31542 .54494 L .3138 .54572 L F
.753 .627 .721 r
.31063 .55104 m .31037 .55147 L .31043 .55078 L F
.31063 .55104 m .31043 .55078 L .31091 .5451 L F
.668 .484 .626 r
.31064 .55106 m .31008 .5503 L .31012 .55031 L F
.3111 .55172 m .31042 .55077 L .31064 .55106 L F
.31042 .55077 m .31008 .5503 L .31064 .55106 L F
.3111 .55172 m .31012 .55031 L .311 .5515 L F
.58 .741 .953 r
.25294 .62359 m .25079 .62439 L .24904 .62251 L F
.491 .468 .759 r
.18122 .58934 m .18331 .58873 L .18245 .5852 L F
.533 .44 .696 r
.18122 .58934 m .1838 .59248 L .18331 .58873 L F
.18122 .58934 m .18186 .59307 L .1838 .59248 L F
.54 .491 .749 r
.3546 .60802 m .35116 .60489 L .35288 .60422 L F
.066 0 .284 r
.35814 .55392 m .35642 .55523 L .35842 .55172 L F
.551 .4 .629 r
.35814 .55392 m .35568 .55704 L .35642 .55523 L F
0 .03 .573 r
.34221 .53869 m .34271 .54146 L .34224 .54076 L F
.108 .065 .522 r
.31694 .58577 m .31822 .58179 L .31609 .58368 L F
.682 .348 .402 r
.36442 .69534 m .36268 .69807 L .36041 .69561 L F
.684 .355 .412 r
.36677 .69594 m .36268 .69807 L .36442 .69534 L F
.511 .804 .998 r
.39778 .5794 m .39789 .57941 L .39741 .58022 L F
.39789 .57941 m .40021 .57973 L .39765 .58018 L F
.39789 .57941 m .39765 .58018 L .39741 .58022 L F
.39818 .5785 m .40001 .57961 L .39778 .5794 L F
0 .06 .613 r
.39818 .5785 m .39815 .58008 L .39789 .57941 L F
.749 .598 .688 r
.39789 .57941 m .39803 .57976 L .39778 .5794 L F
.39803 .57976 m .39815 .58008 L .39778 .5794 L F
.04 .233 .734 r
.39778 .5794 m .39815 .57994 L .39818 .5785 L F
.511 .804 .998 r
.40001 .57961 m .40021 .57973 L .39778 .5794 L F
.505 .257 .472 r
.40021 .57973 m .39964 .58215 L .39741 .58022 L F
.04 .233 .734 r
.39815 .57994 m .39964 .58215 L .39818 .5785 L F
.39893 .58153 m .39964 .58215 L .39778 .5794 L F
0 .06 .613 r
.39818 .5785 m .39841 .58077 L .39815 .58008 L F
.963 .738 .55 r
.39818 .5785 m .39964 .58215 L .40021 .57973 L F
.533 .172 .3 r
.40095 .58036 m .39993 .58052 L .39818 .5785 L F
0 .06 .613 r
.39818 .5785 m .39789 .57941 L .39706 .57721 L F
.04 .233 .734 r
.39741 .58022 m .39893 .58153 L .39778 .5794 L F
.749 .598 .688 r
.39778 .5794 m .39841 .58077 L .3926 .5789 L F
.39815 .58008 m .39841 .58077 L .39778 .5794 L F
.3926 .5789 m .39841 .58077 L .3926 .5789 L F
.39615 .57478 m .39789 .57941 L .3926 .5789 L F
0 0 0 r
.39841 .58077 m .39323 .58232 L .3926 .5789 L F
.39433 .58199 m .39547 .5818 L .39323 .58232 L F
.39841 .58077 m .39547 .5818 L .39433 .58199 L F
.39818 .5785 m .39547 .5818 L .39841 .58077 L F
.192 .423 .856 r
.39647 .58106 m .39672 .58136 L .39547 .5818 L F
.39672 .58136 m .39689 .58156 L .39547 .5818 L F
.39689 .58156 m .3983 .58328 L .39547 .5818 L F
.533 .172 .3 r
.39993 .58052 m .39647 .58106 L .39818 .5785 L F
0 .06 .613 r
.39818 .5785 m .39706 .57721 L .39615 .57478 L F
0 .261 .665 r
.30457 .58445 m .30623 .58546 L .30342 .58394 L F
.79 .522 .532 r
.31735 .61741 m .32076 .61756 L .31999 .61951 L F
.142 0 .223 r
.31999 .61951 m .32076 .61756 L .32257 .61646 L F
.112 0 .175 r
.31363 .65137 m .31467 .64837 L .31626 .64833 L F
.042 0 0 r
.28764 .61521 m .28552 .61506 L .28877 .61339 L F
.28764 .61521 m .28562 .61611 L .28552 .61506 L F
.328 .799 .922 r
.28585 .52538 m .29032 .52527 L .28789 .52573 L F
.491 .228 .443 r
.26222 .5425 m .26418 .54442 L .26475 .54227 L F
.26222 .5425 m .26173 .54494 L .26418 .54442 L F
.123 0 0 r
.34059 .561 m .34296 .56084 L .34272 .56066 L F
.564 .412 .633 r
.34059 .561 m .34426 .5654 L .34296 .56084 L F
0 .175 .669 r
.34354 .56127 m .34296 .56084 L .34108 .56057 L F
.516 .267 .476 r
.34296 .56084 m .34566 .56286 L .34512 .56042 L F
0 .175 .669 r
.34426 .56147 m .34566 .56286 L .34493 .56231 L F
.34426 .56147 m .34493 .56231 L .34296 .56084 L F
.34426 .56147 m .34296 .56084 L .34354 .56127 L F
.123 0 0 r
.34272 .56066 m .34296 .56084 L .34346 .56054 L F
0 0 0 r
.34346 .56054 m .34296 .56084 L .34512 .56042 L F
.162 .694 .854 r
.33894 .56067 m .34296 .56084 L .34059 .561 L F
.33894 .56067 m .34108 .56057 L .34296 .56084 L F
.615 .067 0 r
.34035 .56059 m .34426 .56147 L .34108 .56057 L F
0 .319 .804 r
.34255 .56199 m .34265 .56207 L .34265 .56205 L F
.34035 .56059 m .34256 .562 L .34255 .56199 L F
.34256 .562 m .34265 .56207 L .34255 .56199 L F
.615 .067 0 r
.34035 .56059 m .3425 .56196 L .34426 .56147 L F
.689 .36 .413 r
.3417 .55782 m .34108 .56057 L .33906 .5575 L F
.035 .138 .642 r
.33906 .5575 m .34108 .56057 L .33998 .55553 L F
0 0 0 r
.34273 .5545 m .34108 .56057 L .3417 .55782 L F
.71 .614 .748 r
.33998 .55553 m .34108 .56057 L .34273 .5545 L F
.506 .069 .143 r
.34025 .55914 m .34445 .55713 L .34246 .56188 L F
0 .319 .804 r
.34035 .56059 m .3425 .56196 L .34025 .55914 L F
.964 .937 .692 r
.34426 .56147 m .3425 .56196 L .34319 .56014 L F
0 .319 .804 r
.3425 .56196 m .34265 .56205 L .3424 .56176 L F
.3425 .56196 m .3424 .56176 L .34025 .55914 L F
.353 .122 .418 r
.34059 .561 m .33808 .56418 L .34032 .5634 L F
.709 .426 .494 r
.34399 .56521 m .34402 .56523 L .34059 .561 L F
.34402 .56523 m .34422 .56536 L .34407 .56518 L F
.34402 .56523 m .34407 .56518 L .34059 .561 L F
.34032 .5634 m .3439 .56521 L .34059 .561 L F
.3439 .56521 m .34426 .5654 L .3435 .56449 L F
.3439 .56521 m .3435 .56449 L .34059 .561 L F
.556 .883 .616 r
.34399 .56521 m .34759 .56188 L .34566 .56286 L F
.34402 .56523 m .34759 .56188 L .34399 .56521 L F
.709 .426 .494 r
.34041 .56267 m .34399 .56521 L .34059 .561 L F
.34032 .5634 m .34426 .5654 L .34041 .56267 L F
.556 .883 .616 r
.34391 .56533 m .34402 .56523 L .34399 .56521 L F
0 0 .377 r
.34147 .56483 m .34032 .5634 L .34398 .56526 L F
.413 .604 .925 r
.34402 .56523 m .34391 .56533 L .34399 .56521 L F
.556 .883 .616 r
.34399 .56525 m .34399 .56525 L .34402 .56523 L F
.34399 .56525 m .34402 .56523 L .34402 .56523 L F
.413 .604 .925 r
.34426 .5654 m .34391 .56533 L .34402 .56523 L F
.556 .883 .616 r
.34399 .56525 m .34398 .56526 L .34402 .56523 L F
.34391 .56533 m .34394 .56529 L .34398 .56526 L F
.34391 .56533 m .34398 .56526 L .34399 .56525 L F
.097 .25 .733 r
.34572 .56834 m .34557 .56682 L .34394 .56529 L F
0 0 .377 r
.34404 .56535 m .34398 .56526 L .34426 .5654 L F
.34396 .56527 m .34398 .56526 L .34404 .56535 L F
.556 .883 .616 r
.34402 .56523 m .34402 .56523 L .34473 .56456 L F
.34402 .56523 m .34473 .56456 L .34473 .56456 L F
.709 .426 .494 r
.34399 .56521 m .34426 .5654 L .34422 .56536 L F
.413 .604 .925 r
.34426 .5654 m .34402 .56523 L .34471 .56457 L F
.34402 .56523 m .34399 .56521 L .34471 .56457 L F
.073 0 0 r
.34471 .56457 m .34404 .56517 L .34426 .5654 L F
.097 .25 .733 r
.34404 .56535 m .34404 .5652 L .34396 .56527 L F
0 0 .377 r
.34387 .56532 m .34396 .56527 L .34404 .56535 L F
.073 0 0 r
.34404 .56517 m .34387 .56532 L .34404 .56535 L F
.34404 .56517 m .34404 .56535 L .34426 .5654 L F
.097 .25 .733 r
.34557 .56682 m .3453 .564 L .34404 .5652 L F
.34557 .56682 m .34404 .5652 L .34404 .56535 L F
.34557 .56682 m .34396 .56527 L .34394 .56529 L F
0 0 .377 r
.34147 .56483 m .34398 .56526 L .34387 .56532 L F
.073 0 0 r
.34566 .56286 m .34147 .56483 L .34387 .56532 L F
.413 .604 .925 r
.34471 .56457 m .34399 .56521 L .34566 .56286 L F
.073 0 0 r
.34403 .5651 m .34404 .56517 L .34471 .56457 L F
.556 .883 .616 r
.34402 .56523 m .34479 .56428 L .34756 .56189 L F
.34479 .56428 m .34527 .56369 L .34612 .56303 L F
.34479 .56428 m .34612 .56303 L .34756 .56189 L F
.395 .192 .483 r
.34512 .56042 m .34759 .56188 L .34919 .55936 L F
.556 .281 .453 r
.34839 .56089 m .34651 .56112 L .34834 .56023 L F
.556 .883 .616 r
.34402 .56523 m .34756 .56189 L .34759 .56188 L F
.111 0 0 r
.34759 .56188 m .35178 .55981 L .34919 .55936 L F
.34759 .56188 m .34997 .5613 L .35178 .55981 L F
.556 .883 .616 r
.34473 .56456 m .34473 .56456 L .34759 .56188 L F
.505 .108 .222 r
.34612 .56303 m .34997 .5613 L .34759 .56188 L F
.34527 .56369 m .34674 .56295 L .34612 .56303 L F
.34674 .56295 m .34997 .5613 L .34612 .56303 L F
.34563 .56351 m .34948 .56382 L .34997 .5613 L F
.34527 .56369 m .34599 .56372 L .34563 .56351 L F
.34599 .56372 m .34948 .56382 L .34563 .56351 L F
.395 .192 .483 r
.34512 .56042 m .34566 .56286 L .34759 .56188 L F
.556 .281 .453 r
.34855 .56304 m .34582 .56342 L .34651 .56112 L F
.48 .44 .736 r
.34903 .56564 m .34893 .5666 L .34912 .56565 L F
.34527 .56369 m .34879 .5665 L .34923 .56381 L F
.34879 .5665 m .34893 .5666 L .34923 .56381 L F
.18 .273 .724 r
.35074 .57027 m .34834 .56717 L .35086 .567 L F
.709 .456 .54 r
.35459 .56968 m .35074 .57027 L .35086 .567 L F
.605 .458 .656 r
.34948 .56382 m .34893 .5666 L .35017 .56578 L F
.972 .735 .521 r
.34321 .57164 m .34177 .56965 L .34589 .57046 L F
.34321 .57164 m .34193 .57282 L .34177 .56965 L F
.448 .121 .317 r
.34245 .57106 m .34515 .57162 L .34572 .56834 L F
.097 .25 .733 r
.34572 .56834 m .34822 .56864 L .34527 .56369 L F
.131 0 .2 r
.34515 .57162 m .34822 .56864 L .34572 .56834 L F
.48 .44 .736 r
.34612 .56437 m .34822 .56864 L .34893 .5666 L F
.34527 .56369 m .3455 .56407 L .34612 .56437 L F
.3455 .56407 m .34822 .56864 L .34612 .56437 L F
.771 .614 .685 r
.34829 .56579 m .34866 .56729 L .3465 .56824 L F
.34829 .56579 m .3465 .56824 L .34556 .56865 L F
.547 .25 .415 r
.34822 .56864 m .34916 .5693 L .34893 .5666 L F
.771 .614 .685 r
.34866 .56729 m .34916 .5693 L .34836 .56915 L F
.131 0 .2 r
.34515 .57162 m .34727 .57092 L .34822 .56865 L F
.34822 .56865 m .34822 .56865 L .34822 .56864 L F
.34515 .57162 m .34822 .56865 L .34822 .56865 L F
.547 .25 .415 r
.34822 .56864 m .34727 .57092 L .34916 .5693 L F
.622 .106 0 r
.34842 .56916 m .34826 .57012 L .34556 .56865 L F
.34916 .5693 m .34865 .56976 L .34842 .56916 L F
.34865 .56976 m .34826 .57012 L .34842 .56916 L F
.771 .614 .685 r
.34866 .56729 m .34836 .56915 L .34556 .56865 L F
.174 .062 .477 r
.34916 .5693 m .35017 .56578 L .34893 .5666 L F
.34916 .5693 m .35066 .56858 L .35023 .56614 L F
.34998 .56643 m .35023 .56614 L .35017 .56578 L F
.34916 .5693 m .35023 .56614 L .34998 .56643 L F
.225 .258 .686 r
.3502 .56584 m .34985 .56578 L .35017 .56578 L F
.48 .44 .736 r
.34923 .56381 m .34903 .56564 L .34948 .56382 L F
.34903 .56564 m .34912 .56565 L .34948 .56382 L F
.651 .24 .253 r
.34997 .5613 m .34948 .56382 L .35223 .56333 L F
.59 .43 .633 r
.3508 .56223 m .34855 .56304 L .34834 .56023 L F
.605 .458 .656 r
.34948 .56382 m .35017 .56578 L .35223 .56333 L F
.728 .464 .528 r
.35223 .56333 m .35017 .56578 L .35541 .56587 L F
.661 .505 .662 r
.3508 .56223 m .34829 .56579 L .34855 .56304 L F
.724 .363 .366 r
.35017 .56578 m .35119 .56646 L .35541 .56587 L F
.35119 .56646 m .35448 .56865 L .35478 .56775 L F
.35119 .56646 m .35478 .56775 L .35541 .56587 L F
.661 .505 .662 r
.3508 .56223 m .35017 .56578 L .34829 .56579 L F
.651 .24 .253 r
.34997 .5613 m .35223 .56333 L .35236 .56072 L F
.728 .655 .777 r
.35223 .56333 m .35483 .55925 L .35236 .56072 L F
.35223 .56333 m .35498 .56345 L .35483 .55925 L F
.728 .464 .528 r
.35223 .56333 m .35541 .56587 L .35498 .56345 L F
.314 .115 .443 r
.35334 .56208 m .35017 .56578 L .3508 .56223 L F
.35334 .56208 m .35318 .56483 L .35124 .56544 L F
.35066 .56521 m .35124 .56544 L .35017 .56578 L F
.35334 .56208 m .35124 .56544 L .35066 .56521 L F
.271 .018 .335 r
.35124 .5655 m .35027 .566 L .35017 .56578 L F
.561 .614 .863 r
.35048 .56585 m .35056 .56585 L .35111 .56511 L F
.35056 .56585 m .35153 .56588 L .3513 .56546 L F
.271 .018 .335 r
.35124 .56544 m .35124 .5655 L .35017 .56578 L F
.561 .614 .863 r
.35056 .56585 m .3513 .56546 L .35111 .56511 L F
.724 .363 .366 r
.35017 .56578 m .35055 .56698 L .35448 .56865 L F
.582 .359 .544 r
.35052 .56652 m .35055 .56698 L .3509 .56664 L F
.35055 .56698 m .35056 .56706 L .35059 .56702 L F
.35055 .56698 m .35059 .56702 L .3509 .56664 L F
.724 .363 .366 r
.35055 .56698 m .35101 .56841 L .35178 .56846 L F
.35055 .56698 m .35178 .56846 L .35448 .56865 L F
.582 .359 .544 r
.35036 .5662 m .3509 .56664 L .35114 .56635 L F
.34968 .56606 m .35028 .56635 L .35036 .5662 L F
.35028 .56635 m .3509 .56664 L .35036 .5662 L F
.271 .018 .335 r
.35056 .56585 m .35036 .5662 L .35027 .566 L F
.174 .062 .477 r
.35066 .56858 m .35055 .56698 L .35017 .56578 L F
.225 .258 .686 r
.35007 .56614 m .34829 .56579 L .34985 .56578 L F
.582 .359 .544 r
.34829 .56579 m .3509 .56664 L .34968 .56606 L F
.225 .258 .686 r
.35108 .56774 m .34985 .56578 L .3502 .56584 L F
.582 .359 .544 r
.34829 .56579 m .35114 .56635 L .35153 .56588 L F
.401 .227 .527 r
.35056 .56585 m .35108 .56774 L .35153 .56588 L F
.271 .018 .335 r
.3506 .566 m .35108 .56774 L .35036 .5662 L F
.582 .359 .544 r
.34829 .56579 m .34988 .56788 L .35056 .56706 L F
.34829 .56579 m .35056 .56706 L .35052 .56652 L F
.174 .062 .477 r
.35066 .56858 m .35101 .56841 L .35055 .56698 L F
.225 .258 .686 r
.35108 .56774 m .34829 .56579 L .35007 .56614 L F
.401 .227 .527 r
.34829 .56579 m .35108 .56774 L .35056 .56585 L F
.271 .018 .335 r
.35124 .5655 m .35108 .56774 L .3506 .566 L F
.35124 .5655 m .35036 .5662 L .35056 .56585 L F
.35318 .56483 m .35155 .56554 L .35124 .56544 L F
.018 0 .121 r
.35155 .56554 m .35318 .56483 L .35167 .56318 L F
.35153 .56588 m .35318 .56483 L .35155 .56554 L F
.35153 .56588 m .35108 .56774 L .35318 .56483 L F
.271 .018 .335 r
.35318 .56483 m .35247 .56581 L .35155 .56554 L F
.062 .312 .796 r
.3513 .56546 m .35131 .56547 L .35131 .56546 L F
.35131 .56547 m .35153 .56588 L .35155 .56556 L F
.271 .018 .335 r
.35247 .56581 m .35108 .56774 L .35124 .56544 L F
.062 .312 .796 r
.34896 .5612 m .3513 .56546 L .35167 .56318 L F
.3513 .56546 m .35131 .56546 L .35167 .56318 L F
.35131 .56547 m .35155 .56556 L .35167 .56318 L F
.561 .614 .863 r
.34834 .56543 m .35048 .56585 L .34896 .5612 L F
.34829 .56579 m .3494 .56582 L .34834 .56543 L F
.3494 .56582 m .35048 .56585 L .34834 .56543 L F
.35048 .56585 m .35111 .56511 L .34896 .5612 L F
.225 .258 .686 r
.35108 .56774 m .35027 .56839 L .34829 .56579 L F
.35027 .56839 m .34916 .5693 L .34829 .56579 L F
.582 .359 .544 r
.34829 .56579 m .34857 .56949 L .34988 .56788 L F
.598 .413 .602 r
.34855 .56304 m .34829 .56579 L .34582 .56342 L F
.096 .311 .788 r
.34582 .56342 m .34631 .56389 L .34657 .56178 L F
.34631 .56389 m .34829 .56579 L .34784 .56474 L F
.34631 .56389 m .34784 .56474 L .34657 .56178 L F
.556 .281 .453 r
.34853 .56271 m .34733 .56189 L .34839 .56089 L F
.34855 .56304 m .34824 .56275 L .34853 .56271 L F
.34824 .56275 m .34733 .56189 L .34853 .56271 L F
.34733 .56189 m .34651 .56112 L .34839 .56089 L F
.097 .25 .733 r
.3453 .564 m .34406 .56515 L .34404 .56517 L F
.073 0 0 r
.34566 .56286 m .34403 .5651 L .34471 .56457 L F
.556 .883 .616 r
.34394 .56529 m .34527 .56369 L .34402 .56523 L F
.097 .25 .733 r
.34404 .5652 m .34404 .56517 L .34394 .56529 L F
.3453 .564 m .34404 .56517 L .34404 .5652 L F
.073 0 0 r
.34403 .5651 m .34387 .56532 L .34404 .56517 L F
.097 .25 .733 r
.3453 .564 m .34527 .56369 L .34406 .56515 L F
.34448 .56627 m .34394 .56529 L .34391 .56533 L F
.34572 .56834 m .34394 .56529 L .34448 .56627 L F
.413 .533 .869 r
.34147 .56483 m .34265 .56207 L .34035 .56059 L F
.615 .067 0 r
.34035 .56059 m .34242 .56198 L .3425 .56196 L F
.964 .937 .692 r
.3425 .56196 m .34242 .56198 L .34246 .56188 L F
.3425 .56196 m .34246 .56188 L .34319 .56014 L F
.506 .069 .143 r
.34025 .55914 m .34246 .56188 L .34242 .56198 L F
.964 .937 .692 r
.34426 .56147 m .34319 .56014 L .34445 .55713 L F
0 .076 .632 r
.27034 .56017 m .26963 .55656 L .26684 .55643 L F
.27034 .56017 m .27111 .56037 L .26963 .55656 L F
.226 0 0 r
.29062 .55136 m .28928 .55229 L .287 .55267 L F
.03 0 0 r
.293 .55142 m .28928 .55229 L .29062 .55136 L F
.53 .64 .902 r
.33096 .60179 m .33066 .6057 L .32984 .60148 L F
.33096 .60179 m .33436 .60529 L .33066 .6057 L F
.471 0 0 r
.32926 .60653 m .33066 .6057 L .33317 .60681 L F
.463 .164 .372 r
.33066 .6057 m .33436 .60529 L .33317 .60681 L F
.431 .312 .617 r
.28851 .57352 m .29055 .57329 L .29031 .57048 L F
.183 0 .355 r
.30705 .57016 m .309 .57005 L .30904 .56732 L F
0 0 .058 r
.30705 .57016 m .30769 .57139 L .309 .57005 L F
.30705 .57016 m .30629 .57296 L .30769 .57139 L F
.064 0 0 r
.21946 .54168 m .21976 .54289 L .22164 .54062 L F
.21946 .54168 m .21777 .54368 L .21976 .54289 L F
.281 0 0 r
.29731 .6442 m .29709 .64368 L .29586 .64364 L F
.29731 .6442 m .30004 .64447 L .29709 .64368 L F
0 0 0 r
.26434 .52921 m .26673 .52865 L .26866 .52769 L F
.26866 .52769 m .2689 .52783 L .27106 .52713 L F
.26866 .52769 m .26673 .52865 L .2689 .52783 L F
.437 .314 .614 r
.3427 .52657 m .34251 .52902 L .34015 .52707 L F
.3427 .52657 m .34251 .52902 L .34015 .52707 L F
0 0 0 r
.2896 .61049 m .2926 .60814 L .29149 .61066 L F
0 0 .065 r
.29008 .61229 m .2896 .61049 L .29149 .61066 L F
.29008 .61229 m .28877 .61339 L .2896 .61049 L F
.903 .843 .775 r
.31755 .61942 m .31515 .62101 L .31735 .61741 L F
.414 0 .124 r
.31755 .61942 m .31604 .62172 L .31515 .62101 L F
.79 .522 .532 r
.31735 .61741 m .31999 .61951 L .31755 .61942 L F
.187 0 0 r
.31999 .61951 m .31604 .62172 L .31755 .61942 L F
.522 .462 .73 r
.37517 .56796 m .37581 .57121 L .37693 .56754 L F
.532 .473 .735 r
.37693 .56754 m .37581 .57121 L .37853 .56997 L F
.621 .426 .597 r
.37523 .57302 m .37853 .56997 L .37581 .57121 L F
.793 .707 .77 r
.31984 .60406 m .32465 .60515 L .32338 .60175 L F
.732 .268 .147 r
.32235 .60576 m .32465 .60515 L .31984 .60406 L F
.412 .35 .678 r
.37012 .58987 m .37267 .59162 L .37254 .58907 L F
.37012 .58987 m .37062 .59261 L .37267 .59162 L F
0 0 0 r
.22663 .53754 m .2286 .53697 L .23134 .53583 L F
.339 .8 .686 r
.23134 .53583 m .23203 .53541 L .23373 .53532 L F
.23134 .53583 m .2286 .53697 L .23203 .53541 L F
0 .112 .663 r
.35797 .53016 m .35684 .53044 L .35504 .53056 L F
.35797 .53016 m .35832 .53124 L .35684 .53044 L F
.729 .658 .779 r
.31668 .56813 m .31919 .5709 L .31921 .56656 L F
.421 .825 .621 r
.287 .55267 m .28561 .55352 L .28405 .55462 L F
.207 .186 .613 r
.28566 .5501 m .287 .55267 L .28928 .55229 L F
.28566 .5501 m .28561 .55352 L .287 .55267 L F
0 0 0 r
.31094 .5735 m .31008 .57594 L .30835 .57666 L F
.31008 .57594 m .30685 .5785 L .30835 .57666 L F
.978 .731 .319 r
.38373 .64237 m .38248 .63795 L .38439 .63898 L F
.239 .016 .361 r
.38653 .63569 m .38607 .63858 L .38439 .63898 L F
.34 .748 .981 r
.38248 .63795 m .38607 .63858 L .38439 .63898 L F
.472 .367 .654 r
.38607 .63858 m .38373 .64237 L .38439 .63898 L F
.501 .904 .914 r
.32545 .53027 m .3249 .53111 L .32738 .52981 L F
.248 .458 .868 r
.3249 .53111 m .32775 .53285 L .32738 .52981 L F
.648 .575 .759 r
.3649 .63944 m .36066 .63642 L .36318 .6359 L F
.177 .262 .714 r
.31694 .58577 m .31782 .58956 L .31905 .58773 L F
.313 .328 .717 r
.31834 .59207 m .31905 .58773 L .31782 .58956 L F
.559 .837 .997 r
.30542 .52382 m .3039 .52524 L .30266 .52487 L F
.30542 .52382 m .30704 .52464 L .3039 .52524 L F
.549 .38 .605 r
.35627 .54281 m .35651 .54581 L .3543 .546 L F
.602 .44 .634 r
.35766 .54794 m .3543 .546 L .35651 .54581 L F
.35766 .54794 m .35449 .54869 L .3543 .546 L F
0 0 0 r
.3111 .57456 m .31094 .5735 L .31254 .57324 L F
.3111 .57456 m .31008 .57594 L .31094 .5735 L F
.39 .413 .764 r
.37046 .52961 m .37264 .52846 L .3701 .52798 L F
.515 .848 .997 r
.37264 .52846 m .36805 .52864 L .37046 .52961 L F
.563 .296 .469 r
.26475 .54227 m .26733 .54222 L .2677 .53956 L F
.463 .219 .458 r
.26733 .54222 m .27032 .53808 L .2677 .53956 L F
.742 .755 .863 r
.34391 .51444 m .3399 .51431 L .3426 .51191 L F
.117 0 0 r
.34391 .51444 m .3427 .51451 L .3399 .51431 L F
.571 .628 .869 r
.34506 .51129 m .34391 .51444 L .3426 .51191 L F
.34506 .51129 m .34629 .51383 L .34391 .51444 L F
0 0 0 r
.34629 .51383 m .3427 .51451 L .34391 .51444 L F
0 0 .169 r
.2702 .62671 m .26958 .62904 L .26884 .62884 L F
0 .265 .723 r
.26958 .62904 m .27117 .63048 L .26884 .62884 L F
.238 .593 .949 r
.24904 .62251 m .24723 .62244 L .24483 .62041 L F
.882 .856 .811 r
.32259 .55146 m .32028 .55131 L .32244 .54737 L F
.441 .436 .758 r
.33763 .56954 m .33684 .57364 L .33655 .57089 L F
.158 .092 .527 r
.35824 .54406 m .35627 .54281 L .35801 .54136 L F
.35824 .54406 m .35651 .54581 L .35627 .54281 L F
.852 .453 .286 r
.32577 .63513 m .32704 .63354 L .32476 .63271 L F
.233 0 0 r
.32815 .63446 m .32704 .63354 L .32577 .63513 L F
.649 .929 .656 r
.32364 .59885 m .32139 .60056 L .31872 .59843 L F
0 0 0 r
.32369 .60037 m .32364 .59885 L .32268 .59696 L F
.004 0 0 r
.32369 .60037 m .32621 .59941 L .32404 .60089 L F
.32369 .60037 m .32404 .60089 L .3238 .60048 L F
.395 .297 .625 r
.32127 .59775 m .32369 .60037 L .32268 .59696 L F
.87 .514 .016 r
.32268 .59696 m .32369 .60037 L .32278 .59868 L F
.004 0 0 r
.32369 .60037 m .3238 .60048 L .32278 .59868 L F
0 0 0 r
.32369 .60037 m .32338 .60175 L .32352 .60021 L F
.32369 .60037 m .32352 .60021 L .32364 .59885 L F
.947 .783 .325 r
.38653 .63569 m .38607 .63858 L .38595 .63557 L F
.91 .921 .534 r
.38653 .63569 m .38707 .6323 L .38945 .63545 L F
.38653 .63569 m .38595 .63557 L .38707 .6323 L F
.697 .514 .637 r
.34867 .68579 m .345 .68321 L .34894 .68313 L F
.333 0 0 r
.33902 .5547 m .33523 .55432 L .3359 .55414 L F
.558 .181 .283 r
.27257 .5456 m .27081 .54814 L .2684 .54795 L F
.555 .177 .28 r
.27427 .54733 m .27257 .5456 L .27507 .54575 L F
.27427 .54733 m .27081 .54814 L .27257 .5456 L F
0 0 .351 r
.38439 .57213 m .38336 .57072 L .38587 .57058 L F
.666 .936 .967 r
.3815 .67527 m .37928 .67695 L .38049 .67473 L F
.704 .92 .583 r
.37928 .67695 m .37876 .67722 L .38049 .67473 L F
.502 .324 .572 r
.33279 .64268 m .33515 .64212 L .33513 .63944 L F
.469 .236 .477 r
.33461 .64462 m .33515 .64212 L .33279 .64268 L F
.165 .193 .644 r
.33279 .64268 m .33371 .64573 L .33461 .64462 L F
.651 .424 .563 r
.39957 .56628 m .39713 .56445 L .40035 .5643 L F
.39957 .56628 m .39703 .56697 L .39713 .56445 L F
.711 .696 .835 r
.36383 .52123 m .36579 .52408 L .36861 .52326 L F
.308 .277 .66 r
.31623 .55194 m .31875 .55151 L .31691 .55028 L F
.31623 .55194 m .31843 .55395 L .31875 .55151 L F
.826 .581 .029 r
.32716 .60198 m .32785 .60618 L .32774 .60614 L F
.32716 .60198 m .32774 .60614 L .32984 .60148 L F
.543 .688 .933 r
.22452 .61387 m .22257 .61457 L .22178 .61219 L F
0 0 .204 r
.22193 .61708 m .22178 .61219 L .22257 .61457 L F
.178 0 .192 r
.18357 .57055 m .18533 .5699 L .18631 .56781 L F
.174 .025 .425 r
.18365 .5733 m .18533 .5699 L .18357 .57055 L F
.452 .237 .496 r
.31799 .60501 m .31997 .60748 L .31984 .60406 L F
.31799 .60501 m .31773 .60771 L .31997 .60748 L F
.65 .642 .829 r
.37336 .51709 m .37079 .5179 L .36971 .51549 L F
.269 0 0 r
.27918 .55022 m .28155 .55017 L .2831 .54928 L F
.377 .789 .979 r
.28155 .55017 m .28566 .5501 L .2831 .54928 L F
.348 0 .22 r
.2831 .54928 m .28566 .5501 L .28562 .54848 L F
.529 .494 .761 r
.37517 .56796 m .37637 .56363 L .37398 .56421 L F
.37517 .56796 m .37693 .56754 L .37637 .56363 L F
.168 .681 .896 r
.25743 .62335 m .25699 .62386 L .25523 .62274 L F
.25743 .62335 m .25907 .62387 L .25699 .62386 L F
.639 .817 .968 r
.21422 .61321 m .21583 .61458 L .21822 .61368 L F
.901 .986 .746 r
.31201 .62948 m .31408 .62801 L .31479 .62678 L F
.69 .735 .885 r
.34949 .51058 m .34879 .51186 L .34666 .51098 L F
.769 .6 .669 r
.35006 .51353 m .34666 .51098 L .34879 .51186 L F
.322 .278 .653 r
.35101 .51027 m .34879 .51186 L .34949 .51058 L F
.543 .584 .845 r
.35101 .51027 m .35006 .51353 L .34879 .51186 L F
.159 0 .38 r
.33241 .58032 m .332 .58352 L .3339 .57931 L F
.233 .379 .806 r
.37595 .64115 m .37739 .64476 L .37483 .64352 L F
.632 .254 .309 r
.36897 .54241 m .36448 .54362 L .36623 .54275 L F
.421 .19 .456 r
.37889 .55471 m .3808 .55446 L .38118 .55195 L F
.176 .023 .421 r
.3808 .55446 m .38322 .55064 L .38118 .55195 L F
.722 .435 .491 r
.37066 .69569 m .36666 .69811 L .36677 .69594 L F
.37066 .69569 m .37061 .69837 L .36666 .69811 L F
.689 .407 .491 r
.37322 .69838 m .37066 .69569 L .37364 .69576 L F
.37322 .69838 m .37061 .69837 L .37066 .69569 L F
.228 .024 .383 r
.39615 .57478 m .39366 .57728 L .39572 .57367 L F
.749 .598 .688 r
.39615 .57478 m .3926 .5789 L .39366 .57728 L F
.399 .811 .977 r
.34271 .54146 m .34513 .54104 L .34681 .54153 L F
.488 .706 .967 r
.34794 .54006 m .34681 .54153 L .34513 .54104 L F
.231 .573 .941 r
.32698 .52102 m .32642 .52201 L .32479 .52194 L F
.32698 .52102 m .32876 .52251 L .32642 .52201 L F
.647 .588 .774 r
.31677 .59891 m .31872 .59843 L .31903 .5959 L F
.623 .484 .673 r
.31677 .59891 m .31678 .60078 L .31872 .59843 L F
.444 .303 .594 r
.36914 .58006 m .37067 .57997 L .37043 .57683 L F
.702 .647 .791 r
.36841 .58238 m .37067 .57997 L .36914 .58006 L F
.477 .897 .863 r
.24724 .53129 m .24999 .53088 L .24614 .53225 L F
.403 .776 .993 r
.25606 .52858 m .25561 .52989 L .25385 .52914 L F
.016 0 0 r
.25606 .52858 m .25385 .52914 L .25292 .52975 L F
.603 .952 .891 r
.25385 .52914 m .25291 .53002 L .24956 .53069 L F
.016 0 0 r
.25435 .52933 m .25292 .52975 L .25193 .53039 L F
.25606 .52858 m .25292 .52975 L .25435 .52933 L F
.301 .796 .8 r
.25291 .53002 m .24999 .53088 L .24807 .53116 L F
.24898 .5309 m .24807 .53116 L .24724 .53129 L F
.25291 .53002 m .24807 .53116 L .24898 .5309 L F
.564 .191 .293 r
.24064 .55013 m .24128 .55267 L .23723 .55199 L F
.45 .123 .318 r
.24258 .55093 m .24128 .55267 L .24064 .55013 L F
.404 0 0 r
.2441 .55109 m .24258 .55093 L .24064 .55013 L F
.248 0 .096 r
.37889 .55471 m .3799 .55624 L .3808 .55446 L F
.37889 .55471 m .37762 .55694 L .3799 .55624 L F
.71 .374 0 r
.3268 .57068 m .32724 .57189 L .32911 .57011 L F
.447 0 0 r
.31482 .62393 m .31515 .62101 L .31501 .62357 L F
.31482 .62393 m .31179 .62317 L .31515 .62101 L F
.969 .9 .698 r
.31501 .62357 m .31479 .62678 L .31482 .62393 L F
.034 0 0 r
.22392 .5607 m .22187 .56285 L .21978 .5636 L F
.125 0 0 r
.22648 .56077 m .22187 .56285 L .22392 .5607 L F
.149 0 .075 r
.27943 .5439 m .27723 .54582 L .27735 .54576 L F
.229 0 .118 r
.2763 .54663 m .27507 .54575 L .27735 .54576 L F
.149 0 .075 r
.27723 .54582 m .2763 .54663 L .27735 .54576 L F
.048 0 0 r
.27748 .54569 m .27735 .54576 L .27507 .54575 L F
.27898 .54566 m .27735 .54576 L .27748 .54569 L F
.736 .979 .917 r
.27943 .5439 m .27735 .54576 L .27898 .54566 L F
.945 .752 .285 r
.30329 .65459 m .30357 .65825 L .30421 .65596 L F
.282 .032 .346 r
.2926 .60814 m .29514 .60504 L .29454 .60739 L F
.156 0 .088 r
.29149 .61066 m .2926 .60814 L .29454 .60739 L F
.786 .706 .776 r
.3216 .57695 m .31839 .57673 L .32029 .57367 L F
.442 .516 .839 r
.32304 .57599 m .3216 .57695 L .32029 .57367 L F
0 0 .261 r
.32304 .57599 m .32188 .57944 L .3216 .57695 L F
.338 0 0 r
.32135 .54494 m .31944 .54677 L .31761 .54607 L F
.777 .356 .25 r
.32244 .54737 m .32135 .54494 L .32359 .54501 L F
.31 .313 .701 r
.32028 .55131 m .32132 .5515 L .32186 .5486 L F
.32028 .55131 m .31944 .54677 L .32244 .54737 L F
.3216 .5483 m .32186 .5486 L .32214 .54709 L F
.32028 .55131 m .32186 .5486 L .3216 .5483 L F
.777 .356 .25 r
.32244 .54737 m .32048 .54698 L .32135 .54494 L F
.32048 .54698 m .31944 .54677 L .31992 .54631 L F
.32048 .54698 m .31992 .54631 L .32135 .54494 L F
0 0 0 r
.28405 .55462 m .28255 .55629 L .2809 .5569 L F
.194 0 0 r
.28466 .55598 m .28215 .55673 L .28405 .55462 L F
.598 .48 .689 r
.28195 .55278 m .28435 .55562 L .28362 .55256 L F
.28435 .55562 m .28466 .55598 L .28453 .55555 L F
.194 0 0 r
.28466 .55598 m .28405 .55462 L .28561 .55352 L F
.598 .48 .689 r
.28435 .55562 m .28453 .55555 L .28362 .55256 L F
0 0 0 r
.2809 .5569 m .28215 .55673 L .2802 .55741 L F
.28255 .55629 m .28215 .55673 L .2809 .5569 L F
.493 .374 .645 r
.18186 .59307 m .18364 .59484 L .1838 .59248 L F
.18186 .59307 m .18211 .59622 L .18364 .59484 L F
.031 .603 .735 r
.36219 .65977 m .36345 .6597 L .36128 .66081 L F
.36219 .65977 m .36496 .65974 L .36345 .6597 L F
.025 0 .031 r
.36768 .59555 m .36937 .59481 L .37062 .59261 L F
.345 .151 .468 r
.36768 .59555 m .36958 .59783 L .36937 .59481 L F
.36768 .59555 m .36764 .59825 L .36958 .59783 L F
0 .135 .621 r
.32681 .60516 m .32774 .60614 L .32785 .60618 L F
.423 .252 .543 r
.39858 .56976 m .39871 .57271 L .39572 .57367 L F
.512 .32 .558 r
.39871 .57271 m .39615 .57478 L .39572 .57367 L F
.799 .694 .153 r
.33371 .64573 m .33352 .64879 L .33344 .64794 L F
.756 .613 .046 r
.33344 .64794 m .33352 .64879 L .33349 .6518 L F
.978 .701 .433 r
.3337 .62356 m .33513 .62383 L .33411 .62076 L F
.746 .38 .359 r
.33769 .62314 m .33411 .62076 L .33513 .62383 L F
.4 .844 .931 r
.33769 .62314 m .33513 .62383 L .3337 .62356 L F
.438 0 0 r
.36522 .56763 m .36466 .56789 L .36096 .56684 L F
.797 .952 .616 r
.36563 .56584 m .36522 .56763 L .36713 .5665 L F
.36563 .56584 m .36466 .56789 L .36522 .56763 L F
.273 .089 .44 r
.36713 .5665 m .36648 .56946 L .36522 .56763 L F
.695 .791 .924 r
.28708 .69203 m .29112 .69243 L .2888 .69334 L F
.2888 .69334 m .29112 .69243 L .28708 .69203 L F
.038 .379 .843 r
.22001 .60669 m .22093 .60671 L .22073 .60823 L F
.441 .794 .997 r
.31858 .53262 m .32133 .53238 L .31688 .53166 L F
.605 .414 .596 r
.36108 .54875 m .36103 .55152 L .35842 .55172 L F
.869 .43 .14 r
.35766 .54794 m .36103 .55152 L .36108 .54875 L F
.758 .54 .601 r
.36486 .55179 m .36108 .54875 L .36281 .54863 L F
.36486 .55179 m .36103 .55152 L .36108 .54875 L F
0 0 .091 r
.36103 .55152 m .36281 .54863 L .36108 .54875 L F
.329 0 0 r
.27262 .63129 m .27408 .63015 L .27117 .63048 L F
0 .204 .673 r
.27262 .63129 m .27117 .63048 L .26958 .62904 L F
.158 .111 .551 r
.21687 .59465 m .21735 .59776 L .21558 .5988 L F
.34 .283 .647 r
.21735 .59776 m .2156 .6013 L .21558 .5988 L F
.348 .1 .39 r
.19329 .56361 m .19597 .56029 L .19406 .56095 L F
.589 .1 .061 r
.37767 .63959 m .37595 .64115 L .37353 .63954 L F
.418 0 0 r
.37849 .64081 m .37767 .63959 L .37991 .63885 L F
.37849 .64081 m .37595 .64115 L .37767 .63959 L F
.121 0 .367 r
.2969 .57034 m .29493 .57381 L .29437 .5712 L F
.2969 .57034 m .29641 .57293 L .29493 .57381 L F
.521 .396 .65 r
.29641 .57293 m .29452 .57634 L .29493 .57381 L F
.246 .083 .453 r
.32677 .60988 m .32526 .6077 L .32732 .6075 L F
.32677 .60988 m .32512 .61065 L .32526 .6077 L F
.748 .816 .906 r
.28688 .7044 m .2877 .70565 L .28908 .7037 L F
.684 .469 .588 r
.36744 .64144 m .3649 .63944 L .36763 .63965 L F
.36744 .64144 m .36465 .64229 L .3649 .63944 L F
.721 .985 .895 r
.36532 .58315 m .36439 .58293 L .3655 .58179 L F
.36532 .58315 m .36439 .58293 L .3655 .58179 L F
.273 .175 .557 r
.3655 .58179 m .36557 .58214 L .36439 .58293 L F
.559 .93 .922 r
.36532 .58315 m .36439 .58293 L .36329 .58366 L F
.273 .175 .557 r
.36557 .58214 m .36598 .5842 L .36439 .58293 L F
.559 .93 .922 r
.36329 .58366 m .36439 .58293 L .36093 .58425 L F
.8 .786 .84 r
.38677 .56378 m .38437 .56512 L .38276 .56354 L F
0 0 0 r
.27679 .62242 m .27682 .62193 L .27869 .62029 L F
.27679 .62242 m .27575 .6226 L .27682 .62193 L F
.705 .564 .693 r
.32309 .64236 m .32347 .64599 L .31995 .64557 L F
.507 .418 .689 r
.32551 .64532 m .32309 .64236 L .32485 .6418 L F
.32551 .64532 m .32347 .64599 L .32309 .64236 L F
.695 .566 .705 r
.37178 .63958 m .36744 .64144 L .36763 .63965 L F
.509 .585 .867 r
.31188 .52485 m .31021 .52592 L .30902 .52336 L F
.343 .103 .399 r
.29714 .60426 m .29514 .60504 L .29771 .60189 L F
.326 .07 .364 r
.29454 .60739 m .29514 .60504 L .29714 .60426 L F
.007 0 0 r
.30456 .59123 m .30449 .5917 L .30162 .59251 L F
.715 .646 .089 r
.30466 .5901 m .30456 .59123 L .30655 .58817 L F
.30466 .5901 m .30449 .5917 L .30456 .59123 L F
.001 0 .092 r
.18631 .56781 m .18533 .5699 L .18787 .56673 L F
.644 .316 .402 r
.30667 .53928 m .30542 .54191 L .30293 .54155 L F
.539 .204 .349 r
.30874 .54106 m .30667 .53928 L .30947 .53893 L F
.30874 .54106 m .30542 .54191 L .30667 .53928 L F
.794 .833 .882 r
.23941 .76542 m .23874 .76634 L .23573 .76747 L F
.185 0 0 r
.23573 .76747 m .23874 .76634 L .23794 .76726 L F
.625 .855 .484 r
.23941 .76542 m .23874 .76634 L .23794 .76726 L F
.744 .719 .829 r
.37436 .6683 m .37172 .67106 L .37037 .66834 L F
.676 .603 .766 r
.37436 .6683 m .37563 .67216 L .37172 .67106 L F
.499 .882 .968 r
.332 .58352 m .3358 .58322 L .33377 .5822 L F
.263 0 .232 r
.34338 .63004 m .3403 .63292 L .343 .6329 L F
.949 .598 .222 r
.34137 .62639 m .34338 .63004 L .34183 .62888 L F
.995 .784 .505 r
.34183 .62888 m .34338 .63004 L .343 .6329 L F
.471 .22 .452 r
.36937 .59481 m .37267 .59162 L .37062 .59261 L F
.992 .847 .486 r
.30623 .58546 m .30565 .58801 L .30655 .58817 L F
.715 .646 .089 r
.30466 .5901 m .30655 .58817 L .30565 .58801 L F
.741 .391 .388 r
.36594 .63279 m .36234 .6305 L .36564 .63018 L F
.36445 .63184 m .36362 .63259 L .36234 .6305 L F
.36594 .63279 m .36406 .63263 L .36445 .63184 L F
.36406 .63263 m .36362 .63259 L .36445 .63184 L F
.263 .479 .88 r
.36291 .62964 m .36389 .63277 L .3654 .63056 L F
.36389 .63277 m .36396 .63282 L .3654 .63056 L F
.741 .391 .388 r
.36362 .63259 m .36189 .63244 L .3621 .63156 L F
.36362 .63259 m .3621 .63156 L .36234 .6305 L F
.655 .757 .924 r
.36189 .63244 m .36392 .63289 L .36291 .62964 L F
0 0 .146 r
.36396 .63282 m .3647 .63204 L .36522 .63085 L F
.36392 .63289 m .36394 .63286 L .36396 .63282 L F
.36394 .63286 m .3647 .63204 L .36396 .63282 L F
.263 .479 .88 r
.36389 .63277 m .36392 .63289 L .36396 .63282 L F
0 0 .146 r
.36392 .63289 m .36416 .63452 L .3647 .63204 L F
.592 .123 .11 r
.3593 .63556 m .36242 .63621 L .36416 .63452 L F
.763 .702 .794 r
.3647 .63204 m .36242 .63621 L .36084 .63285 L F
.557 .062 .036 r
.3647 .63204 m .36339 .6326 L .36448 .63256 L F
.67 .545 .703 r
.36823 .62981 m .36594 .63279 L .36564 .63018 L F
.557 .062 .036 r
.3647 .63204 m .36448 .63256 L .36745 .63247 L F
0 0 .146 r
.36522 .63085 m .3647 .63204 L .3654 .63056 L F
.808 .681 .724 r
.35266 .68947 m .34869 .68892 L .35079 .68607 L F
.751 .46 .49 r
.35266 .68947 m .34866 .69161 L .34869 .68892 L F
.35266 .68947 m .3528 .692 L .34866 .69161 L F
.621 .831 .981 r
.27499 .52734 m .27106 .52713 L .27328 .52622 L F
.491 .77 .994 r
.27547 .52563 m .27499 .52734 L .27328 .52622 L F
.27547 .52563 m .27725 .52696 L .27499 .52734 L F
.375 .211 .527 r
.30922 .56424 m .3112 .56366 L .3112 .56096 L F
.089 .028 .487 r
.30922 .56424 m .31059 .56603 L .3112 .56366 L F
.30922 .56424 m .30904 .56732 L .31059 .56603 L F
.711 .696 .835 r
.36383 .52123 m .36861 .52326 L .36395 .52102 L F
.41 0 0 r
.37078 .52272 m .36395 .52102 L .36861 .52326 L F
.626 .528 .723 r
.36861 .52326 m .37186 .52657 L .37078 .52272 L F
.36861 .52326 m .3701 .52798 L .37186 .52657 L F
.042 0 .439 r
.29916 .59794 m .29864 .60124 L .29771 .60189 L F
0 0 .186 r
.29868 .60326 m .29771 .60189 L .29864 .60124 L F
.29868 .60326 m .29714 .60426 L .29771 .60189 L F
.388 .556 .898 r
.33102 .63617 m .33513 .63944 L .33308 .63559 L F
.515 .589 .866 r
.33308 .63559 m .33513 .63944 L .33724 .63882 L F
.434 .27 .559 r
.33513 .63944 m .33724 .64134 L .33724 .63882 L F
.33513 .63944 m .33515 .64212 L .33724 .64134 L F
.414 .268 .573 r
.37043 .57683 m .37261 .57886 L .37242 .57622 L F
.397 .268 .586 r
.37043 .57683 m .37067 .57997 L .37261 .57886 L F
.524 .823 .999 r
.35267 .51374 m .35505 .51313 L .3568 .51419 L F
.22 .628 .954 r
.35748 .51316 m .3568 .51419 L .35505 .51313 L F
.35748 .51316 m .35875 .51433 L .3568 .51419 L F
.14 .581 .928 r
.26604 .63647 m .26729 .63602 L .26437 .63527 L F
.26604 .63647 m .26788 .63673 L .26729 .63602 L F
.536 .528 .793 r
.3758 .65026 m .37365 .65219 L .37249 .64844 L F
.391 .294 .624 r
.3758 .65026 m .37565 .65372 L .37365 .65219 L F
.383 .295 .631 r
.37565 .65372 m .37422 .65524 L .37365 .65219 L F
.712 .888 .961 r
.33337 .67083 m .33408 .66956 L .33174 .67037 L F
.444 0 .041 r
.32204 .66641 m .32159 .66458 L .32141 .66739 L F
.32204 .66641 m .32414 .66435 L .32159 .66458 L F
.321 .726 .979 r
.32271 .66538 m .32204 .66641 L .32029 .66582 L F
.32318 .66529 m .32204 .66641 L .32271 .66538 L F
.444 0 .041 r
.32204 .66641 m .32141 .66739 L .32139 .66777 L F
.353 .815 .925 r
.27725 .52696 m .27958 .52648 L .28124 .52673 L F
.244 .752 .876 r
.27958 .52648 m .28363 .52635 L .28124 .52673 L F
.639 .877 .524 r
.33049 .54118 m .33017 .54184 L .33241 .54121 L F
.539 .614 .876 r
.33017 .54184 m .33392 .5439 L .33241 .54121 L F
.684 .355 .412 r
.36677 .69594 m .36666 .69811 L .36268 .69807 L F
.335 0 0 r
.3701 .52798 m .36805 .52864 L .37264 .52846 L F
.447 .239 .503 r
.3701 .52798 m .37264 .52846 L .37186 .52657 L F
.792 .574 .606 r
.31995 .64557 m .32153 .64826 L .31981 .64886 L F
.707 .551 .674 r
.32347 .64599 m .32153 .64826 L .31995 .64557 L F
.998 .777 .449 r
.38587 .57058 m .38599 .57362 L .38439 .57213 L F
.747 .53 .601 r
.37339 .62042 m .36941 .62288 L .37014 .62112 L F
.938 .85 .415 r
.33277 .52618 m .33211 .52861 L .3326 .52841 L F
.216 .024 .391 r
.33498 .52501 m .33377 .52785 L .33211 .52861 L F
.935 .63 .438 r
.33163 .52881 m .33211 .52861 L .33377 .52785 L F
.33069 .52923 m .33211 .52861 L .33163 .52881 L F
.938 .85 .415 r
.3326 .52841 m .33211 .52861 L .33249 .52979 L F
.762 .475 0 r
.3325 .53047 m .33249 .52979 L .33211 .52861 L F
.935 .63 .438 r
.33069 .52923 m .3325 .53047 L .33211 .52861 L F
.661 .109 0 r
.33069 .52923 m .33233 .53018 L .3325 .53047 L F
.762 .475 0 r
.3325 .53047 m .33277 .53096 L .33249 .52979 L F
.661 .109 0 r
.33233 .53018 m .33423 .53128 L .3325 .53047 L F
.762 .475 0 r
.3325 .53047 m .33326 .53301 L .33277 .53096 L F
.097 .073 .539 r
.21926 .56611 m .21771 .5643 L .21978 .5636 L F
.21926 .56611 m .21799 .56731 L .21771 .5643 L F
.969 .9 .698 r
.31501 .62357 m .31347 .62608 L .31479 .62678 L F
.901 .986 .746 r
.31201 .62948 m .31479 .62678 L .31347 .62608 L F
.727 .235 .071 r
.29735 .54317 m .29665 .54393 L .2946 .54193 L F
.024 0 0 r
.30056 .54255 m .29665 .54393 L .29735 .54317 L F
.727 .235 .071 r
.29735 .54317 m .29665 .54393 L .2946 .54193 L F
.234 0 0 r
.34231 .63327 m .3403 .63292 L .33866 .63471 L F
.34231 .63327 m .343 .6329 L .3403 .63292 L F
.62 .322 .443 r
.35842 .55172 m .36078 .55394 L .35814 .55392 L F
.583 .328 .496 r
.36103 .55152 m .36078 .55394 L .35842 .55172 L F
.502 .048 .106 r
.31835 .52354 m .3219 .52257 L .31957 .52339 L F
0 0 0 r
.24266 .53293 m .24037 .53363 L .23838 .5346 L F
.372 0 0 r
.30457 .58445 m .30445 .58437 L .30179 .58274 L F
.497 .301 .544 r
.37582 .69506 m .37322 .69838 L .37364 .69576 L F
.358 .427 .796 r
.35732 .59779 m .35604 .59879 L .35462 .59628 L F
0 0 .149 r
.35618 .60048 m .35604 .59879 L .35732 .59779 L F
.35618 .60048 m .3557 .60159 L .35604 .59879 L F
.421 .155 .403 r
.38402 .68348 m .38359 .68579 L .38115 .68628 L F
.389 .169 .454 r
.38664 .68007 m .38626 .68292 L .38402 .68348 L F
.22 0 .332 r
.3854 .68491 m .38402 .68348 L .38626 .68292 L F
.3854 .68491 m .38359 .68579 L .38402 .68348 L F
.684 .607 .764 r
.37796 .67055 m .37563 .67216 L .37436 .6683 L F
.402 .395 .737 r
.37729 .67285 m .37563 .67216 L .37796 .67055 L F
.058 .203 .7 r
.20447 .588 m .20378 .58986 L .20243 .58592 L F
.514 .734 .974 r
.20447 .588 m .20646 .58979 L .20378 .58986 L F
.872 .864 .829 r
.34142 .67977 m .34191 .67617 L .3436 .67744 L F
.34142 .67977 m .33945 .67928 L .34191 .67617 L F
.824 .528 .488 r
.34142 .67977 m .33924 .68209 L .33945 .67928 L F
.34142 .67977 m .34158 .68252 L .33924 .68209 L F
.536 .596 .861 r
.34198 .5306 m .34186 .53581 L .34028 .53264 L F
.34198 .5306 m .34423 .53541 L .34186 .53581 L F
.319 .141 .476 r
.34423 .53541 m .34221 .53869 L .34186 .53581 L F
.707 .551 .674 r
.32347 .64599 m .32414 .64868 L .32153 .64826 L F
.393 .35 .691 r
.32583 .64784 m .32347 .64599 L .32551 .64532 L F
.32583 .64784 m .32414 .64868 L .32347 .64599 L F
.582 .213 .306 r
.37683 .61404 m .37747 .61014 L .37507 .61106 L F
.37683 .61404 m .37819 .61416 L .37747 .61014 L F
.37683 .61404 m .37563 .61484 L .37819 .61416 L F
.769 .6 .669 r
.35006 .51353 m .34629 .51383 L .34666 .51098 L F
.676 .306 .338 r
.35006 .51353 m .34878 .51623 L .34629 .51383 L F
.543 .584 .845 r
.35101 .51027 m .35267 .51374 L .35006 .51353 L F
.175 0 .096 r
.35093 .51523 m .35006 .51353 L .35267 .51374 L F
.887 .503 .3 r
.35657 .51814 m .354 .51862 L .35226 .51527 L F
.35234 .51527 m .35226 .51527 L .35221 .51518 L F
.35657 .51814 m .35226 .51527 L .35234 .51527 L F
.561 .036 0 r
.3527 .51555 m .35173 .51547 L .35114 .51529 L F
.35125 .51529 m .35114 .51529 L .35093 .51523 L F
.3527 .51555 m .35114 .51529 L .35125 .51529 L F
.175 0 .096 r
.35093 .51523 m .34878 .51623 L .34945 .5148 L F
.651 .103 0 r
.34629 .51383 m .34878 .51623 L .34667 .51509 L F
.113 0 0 r
.35093 .51523 m .34667 .51509 L .34878 .51623 L F
.561 .036 0 r
.35173 .51547 m .34921 .51526 L .35093 .51523 L F
.175 0 .096 r
.35093 .51523 m .34945 .5148 L .35006 .51353 L F
.561 .171 .259 r
.36486 .55179 m .36078 .55394 L .36103 .55152 L F
.36486 .55179 m .36403 .55379 L .36078 .55394 L F
.313 .516 .894 r
.36591 .55024 m .36486 .55179 L .36281 .54863 L F
.593 .478 .692 r
.36591 .55024 m .36403 .55379 L .36486 .55179 L F
.482 .327 .594 r
.3758 .60183 m .37819 .60416 L .3759 .60478 L F
.3758 .60183 m .37819 .60416 L .3759 .60478 L F
.702 .647 .791 r
.36841 .58238 m .37161 .58292 L .37067 .57997 L F
.36841 .58238 m .37161 .58292 L .37067 .57997 L F
.659 .211 .178 r
.36841 .58238 m .37161 .58292 L .36997 .58469 L F
.491 .863 .64 r
.37333 .58146 m .37161 .58292 L .37366 .58131 L F
0 0 0 r
.36997 .58469 m .37161 .58292 L .37333 .58146 L F
.134 0 0 r
.21007 .54777 m .21209 .5475 L .21362 .54559 L F
0 0 0 r
.21362 .54559 m .21393 .54654 L .21558 .54441 L F
.21362 .54559 m .21209 .5475 L .21393 .54654 L F
.156 .303 .763 r
.22193 .61708 m .22332 .62082 L .22432 .61905 L F
.277 .463 .863 r
.22332 .62082 m .22614 .62215 L .22432 .61905 L F
.595 .539 .762 r
.33096 .65246 m .33202 .65521 L .33349 .6518 L F
.534 .47 .73 r
.33202 .65521 m .33493 .65496 L .33349 .6518 L F
.269 .037 .365 r
.33202 .65521 m .33308 .65668 L .33493 .65496 L F
.33202 .65521 m .33163 .65756 L .33308 .65668 L F
.863 .479 .316 r
.3362 .54503 m .33241 .54121 L .33392 .5439 L F
.627 .548 .745 r
.2969 .57034 m .29437 .5712 L .29226 .56625 L F
.282 0 .27 r
.32506 .63922 m .32811 .63598 L .32748 .63881 L F
.58 .121 .13 r
.32811 .63598 m .32954 .63783 L .32748 .63881 L F
.32811 .63598 m .33102 .63617 L .32954 .63783 L F
.8 .748 .805 r
.30317 .57666 m .30097 .57626 L .30354 .57356 L F
.573 .199 .295 r
.30317 .57666 m .3011 .57894 L .30097 .57626 L F
.30317 .57666 m .30341 .57875 L .3011 .57894 L F
.30317 .57666 m .30443 .57883 L .30341 .57875 L F
.69 .832 .951 r
.34591 .67641 m .3436 .67744 L .34191 .67617 L F
.728 .622 .74 r
.38006 .54531 m .37575 .5456 L .3784 .5419 L F
.653 .347 .441 r
.38006 .54531 m .37612 .54775 L .37575 .5456 L F
.38006 .54531 m .37868 .54812 L .37612 .54775 L F
.704 .428 .504 r
.38263 .5455 m .37868 .54812 L .38006 .54531 L F
.485 .403 .688 r
.31765 .63286 m .31756 .63576 L .32 .63479 L F
.685 .611 .768 r
.31817 .63934 m .32 .63479 L .31756 .63576 L F
.837 .824 .835 r
.38179 .64374 m .37739 .64476 L .38002 .64473 L F
.814 .994 .754 r
.38179 .64374 m .3826 .64149 L .38373 .64237 L F
.38179 .64374 m .38002 .64473 L .3826 .64149 L F
0 .026 .584 r
.2315 .62678 m .23115 .62558 L .2296 .62579 L F
.2315 .62678 m .23341 .62895 L .23115 .62558 L F
.539 .283 .475 r
.38115 .68908 m .37808 .69186 L .37871 .68976 L F
.615 .951 .923 r
.29751 .58894 m .29511 .59045 L .29232 .59071 L F
.097 .464 .889 r
.29993 .65034 m .30154 .65226 L .30069 .65062 L F
0 0 .434 r
.30154 .65226 m .30109 .65126 L .30095 .65111 L F
.30154 .65226 m .30237 .65332 L .30109 .65126 L F
.30095 .65111 m .30109 .65126 L .30069 .65062 L F
.813 .358 .151 r
.2987 .65039 m .30069 .65062 L .30237 .65332 L F
.2987 .65039 m .30046 .6518 L .30156 .65171 L F
.30046 .6518 m .30237 .65332 L .30156 .65171 L F
.116 .639 .881 r
.30278 .65162 m .30156 .65171 L .3035 .65176 L F
.379 0 0 r
.3015 .65169 m .30156 .65171 L .30151 .6517 L F
.3015 .65169 m .30151 .6517 L .29924 .65097 L F
.116 .639 .881 r
.29924 .65097 m .30156 .65171 L .30278 .65162 L F
.379 0 0 r
.2987 .65039 m .3015 .65169 L .29924 .65097 L F
0 0 .434 r
.30154 .65226 m .30329 .65459 L .30237 .65332 L F
.846 .997 .826 r
.38402 .64501 m .38128 .64797 L .38237 .64794 L F
.3 .245 .627 r
.20385 .58146 m .20243 .58592 L .20209 .58328 L F
.546 .486 .74 r
.39123 .55517 m .3916 .55798 L .38951 .5583 L F
.397 .335 .671 r
.37353 .53572 m .37162 .53814 L .37105 .53597 L F
.37353 .53572 m .37382 .53887 L .37162 .53814 L F
.294 .044 .355 r
.37304 .54045 m .37162 .53814 L .37382 .53887 L F
.37304 .54045 m .37103 .54132 L .37162 .53814 L F
.483 .043 .125 r
.36584 .56308 m .36864 .56291 L .37043 .56086 L F
.853 .892 .865 r
.35462 .59628 m .35108 .59795 L .35349 .59573 L F
0 .361 .818 r
.35659 .59682 m .35462 .59628 L .35349 .59573 L F
.35659 .59682 m .35732 .59779 L .35493 .59645 L F
.634 .422 .577 r
.35368 .60122 m .35606 .60007 L .35659 .59682 L F
.825 .875 .436 r
.35606 .60007 m .35618 .60048 L .35732 .59779 L F
.442 .747 .993 r
.35838 .59635 m .35732 .59779 L .35659 .59682 L F
.549 .406 .639 r
.35838 .59635 m .35606 .60007 L .35732 .59779 L F
.35838 .59635 m .35909 .59951 L .35606 .60007 L F
0 .01 .585 r
.35982 .59718 m .36011 .59854 L .35838 .59635 L F
.149 .143 .594 r
.36011 .59854 m .35909 .59951 L .35838 .59635 L F
0 .01 .585 r
.35982 .59718 m .35838 .59635 L .35629 .59832 L F
.35624 .59859 m .35629 .59832 L .35584 .59875 L F
.733 .687 .144 r
.35657 .59696 m .35626 .59882 L .35629 .59832 L F
.35626 .59882 m .35606 .60007 L .35629 .59832 L F
.35659 .59682 m .35584 .59875 L .35629 .59832 L F
.35659 .59682 m .35657 .59696 L .35629 .59832 L F
.157 0 0 r
.35641 .59821 m .35659 .59682 L .35584 .59875 L F
.35838 .59635 m .357 .59671 L .35641 .59821 L F
.357 .59671 m .35659 .59682 L .35641 .59821 L F
.542 0 0 r
.35606 .60007 m .35555 .60059 L .35574 .59992 L F
.733 .687 .144 r
.35659 .59682 m .35624 .5986 L .35632 .59778 L F
.711 .954 .673 r
.35629 .59832 m .35584 .59875 L .35632 .59778 L F
.538 .849 .998 r
.35624 .59859 m .35584 .59875 L .35632 .59778 L F
.733 .687 .144 r
.35624 .5986 m .35622 .59869 L .35632 .59778 L F
.35659 .59682 m .35629 .59832 L .35764 .59705 L F
.711 .954 .673 r
.35838 .59635 m .35629 .59832 L .35632 .59778 L F
0 .01 .585 r
.35982 .59718 m .35629 .59832 L .35624 .59859 L F
.538 .849 .998 r
.35982 .59718 m .35624 .59859 L .35632 .59778 L F
.542 0 0 r
.35622 .59869 m .35574 .59992 L .35632 .59778 L F
.35606 .60007 m .35574 .59992 L .35622 .59869 L F
.733 .687 .144 r
.35629 .59832 m .35606 .60007 L .35622 .59869 L F
.35659 .59682 m .35764 .59705 L .35838 .59635 L F
0 .361 .818 r
.35659 .59682 m .35493 .59645 L .35462 .59628 L F
.637 .763 .939 r
.29392 .52603 m .29032 .52527 L .29241 .52511 L F
.323 0 0 r
.29241 .52511 m .29604 .52507 L .29392 .52603 L F
0 .068 .597 r
.31597 .6111 m .31755 .61296 L .31785 .6104 L F
.398 .301 .628 r
.38823 .67658 m .38664 .68007 L .38572 .67735 L F
.38823 .67658 m .38857 .6794 L .38664 .68007 L F
.337 .125 .437 r
.38826 .68202 m .38664 .68007 L .38857 .6794 L F
.38826 .68202 m .38626 .68292 L .38664 .68007 L F
.372 0 .182 r
.333 .55519 m .33189 .55668 L .33017 .55701 L F
.489 .867 .654 r
.33523 .55432 m .33189 .55668 L .333 .55519 L F
.83 .534 .487 r
.36041 .69561 m .35696 .69503 L .35674 .69237 L F
.744 .404 .406 r
.36041 .69561 m .35676 .69761 L .35696 .69503 L F
.36041 .69561 m .35859 .69778 L .35676 .69761 L F
.699 .344 .371 r
.36041 .69561 m .36268 .69807 L .35859 .69778 L F
.547 .817 .459 r
.25026 .54959 m .25159 .548 L .25311 .54902 L F
.426 .788 .996 r
.25395 .54767 m .25311 .54902 L .25159 .548 L F
.25395 .54767 m .25561 .54864 L .25311 .54902 L F
.748 .61 .704 r
.25026 .54959 m .25119 .55086 L .25311 .54902 L F
.178 0 0 r
.25735 .55204 m .25493 .55229 L .25554 .55202 L F
.477 .897 .873 r
.25782 .55117 m .25493 .55229 L .25735 .55204 L F
0 0 0 r
.2572 .55159 m .25457 .55245 L .25493 .55229 L F
.25457 .55245 m .25361 .55276 L .25493 .55229 L F
.178 0 0 r
.25554 .55202 m .25493 .55229 L .25288 .55198 L F
.477 .897 .873 r
.25782 .55117 m .25735 .55204 L .25959 .55131 L F
.643 .621 .813 r
.37108 .64267 m .36871 .64341 L .36744 .64144 L F
.693 .672 .825 r
.34868 .67562 m .35031 .67786 L .34591 .67641 L F
.642 .654 .847 r
.35236 .67652 m .35031 .67786 L .34868 .67562 L F
.446 .257 .53 r
.38359 .68579 m .38115 .68908 L .38115 .68628 L F
.032 .262 .761 r
.40095 .55066 m .40019 .5523 L .39914 .55075 L F
.40095 .55066 m .40245 .55385 L .40019 .5523 L F
.925 .872 .766 r
.29762 .58334 m .29526 .58506 L .29672 .58306 L F
.294 .756 .948 r
.29672 .58306 m .29956 .58334 L .29762 .58334 L F
.106 0 0 r
.32954 .63783 m .33102 .63617 L .33308 .63559 L F
.548 .881 .62 r
.37374 .60772 m .37156 .60929 L .37089 .61008 L F
.803 .609 .64 r
.37089 .61008 m .37507 .61106 L .37374 .60772 L F
.106 0 .273 r
.37374 .60772 m .37506 .60769 L .3759 .60478 L F
.37374 .60772 m .37506 .60769 L .3759 .60478 L F
.657 .93 .649 r
.37349 .60726 m .37374 .60772 L .37506 .60769 L F
.37349 .60726 m .37156 .60929 L .37374 .60772 L F
.602 .511 .724 r
.37374 .60772 m .37507 .61106 L .37747 .61014 L F
.306 0 .125 r
.26595 .54772 m .26196 .55084 L .26354 .54801 L F
.52 .517 .792 r
.3062 .62748 m .30683 .62981 L .30887 .62893 L F
.491 .894 .937 r
.30502 .6291 m .30683 .62981 L .30887 .62893 L F
.463 .081 .228 r
.30806 .63167 m .30683 .62981 L .30887 .62893 L F
.30806 .63167 m .30531 .63245 L .30683 .62981 L F
.555 .648 .896 r
.31854 .55608 m .31747 .55879 L .31592 .55713 L F
.31854 .55608 m .31993 .55817 L .31747 .55879 L F
0 0 .302 r
.34162 .62369 m .34257 .62556 L .34312 .62495 L F
.34162 .62369 m .34137 .62639 L .34257 .62556 L F
.465 0 0 r
.34383 .62459 m .34162 .62369 L .34312 .62495 L F
.675 .258 .245 r
.29818 .54532 m .30077 .54731 L .30055 .54481 L F
.448 .231 .49 r
.36644 .60192 m .36832 .60357 L .36801 .60096 L F
.36644 .60192 m .36591 .60452 L .36832 .60357 L F
.962 .698 .486 r
.25462 .74878 m .25497 .75175 L .25266 .75088 L F
.806 .957 .625 r
.25516 .75034 m .25462 .74878 L .25266 .75088 L F
.25516 .75034 m .25681 .74879 L .25462 .74878 L F
0 .183 .717 r
.32738 .52981 m .3296 .53179 L .32843 .53018 L F
.39 .283 .612 r
.32738 .52981 m .32775 .53285 L .3296 .53179 L F
0 .183 .717 r
.32738 .52981 m .32843 .53018 L .32545 .53027 L F
.311 .366 .758 r
.31765 .63286 m .31948 .63282 L .31806 .62884 L F
.485 .403 .688 r
.31765 .63286 m .32 .63479 L .31948 .63282 L F
.214 .724 .89 r
.25165 .63443 m .25556 .63464 L .25383 .63409 L F
.323 .796 .921 r
.25556 .63464 m .25615 .63387 L .25383 .63409 L F
.25556 .63464 m .25811 .63425 L .25615 .63387 L F
0 0 0 r
.27457 .61721 m .27581 .61635 L .27759 .61462 L F
.068 0 0 r
.27457 .61721 m .27476 .61745 L .27581 .61635 L F
.27457 .61721 m .27272 .61739 L .27476 .61745 L F
.522 .526 .801 r
.39547 .5818 m .39336 .58619 L .39323 .58232 L F
.39547 .5818 m .39685 .58533 L .39336 .58619 L F
.45 .305 .592 r
.39685 .58533 m .39476 .58849 L .39336 .58619 L F
.73 .593 .703 r
.38009 .57898 m .38339 .57693 L .38024 .57735 L F
.64 .965 .834 r
.38207 .5774 m .38339 .57693 L .38009 .57898 L F
.423 .86 .761 r
.38539 .57586 m .38339 .57693 L .38207 .5774 L F
.698 .92 .968 r
.36841 .58238 m .36849 .58003 L .37067 .57997 L F
.36841 .58238 m .3655 .58179 L .36849 .58003 L F
.351 0 .036 r
.36997 .58469 m .36587 .58704 L .36598 .5842 L F
.564 .534 .78 r
.36587 .58704 m .36608 .58634 L .36598 .5842 L F
.676 .215 .15 r
.36841 .58238 m .36598 .5842 L .36587 .58186 L F
.564 .534 .78 r
.36608 .58634 m .36729 .58251 L .36598 .5842 L F
.676 .215 .15 r
.36587 .58186 m .36598 .5842 L .3655 .58179 L F
.501 .294 .531 r
.33166 .56431 m .33389 .56629 L .33407 .5637 L F
.34 .295 .661 r
.33166 .56431 m .33238 .56738 L .33389 .56629 L F
.037 .356 .83 r
.28562 .64651 m .28802 .64921 L .28553 .64594 L F
.112 .404 .856 r
.28553 .64594 m .28802 .64921 L .28823 .64731 L F
.548 .834 .998 r
.28823 .64731 m .28802 .64921 L .29039 .64841 L F
.388 .351 .696 r
.31903 .5959 m .31872 .59843 L .32127 .59775 L F
.366 .274 .618 r
.32127 .59775 m .31872 .59843 L .32139 .60056 L F
.319 .576 .933 r
.27363 .64187 m .27484 .64076 L .2723 .63881 L F
.515 .589 .866 r
.33308 .63559 m .33724 .63882 L .33577 .63505 L F
.437 .354 .664 r
.33577 .63505 m .33929 .6379 L .33866 .63471 L F
.33577 .63505 m .33724 .63882 L .33929 .6379 L F
.208 0 .064 r
.28999 .70186 m .28688 .7044 L .28908 .7037 L F
.376 .719 .988 r
.24911 .63444 m .25031 .63331 L .24793 .63233 L F
.24911 .63444 m .25165 .63443 L .25031 .63331 L F
.757 .861 .926 r
.31777 .56488 m .31497 .56615 L .31921 .56656 L F
.89 .988 .74 r
.31563 .56744 m .31921 .56656 L .31497 .56615 L F
.31563 .56744 m .31668 .56813 L .31921 .56656 L F
.461 0 .066 r
.32103 .56385 m .31777 .56488 L .31921 .56656 L F
.978 .731 .319 r
.38373 .64237 m .3826 .64149 L .38248 .63795 L F
.472 .367 .654 r
.38607 .63858 m .38672 .64181 L .38373 .64237 L F
.412 .171 .436 r
.38672 .64181 m .38402 .64501 L .38373 .64237 L F
.662 .24 .234 r
.37398 .56421 m .36974 .56547 L .37042 .56467 L F
.37398 .56421 m .37286 .56581 L .36974 .56547 L F
.15 .206 .667 r
.37657 .56501 m .37693 .56754 L .37703 .56544 L F
.614 .186 .205 r
.37703 .56544 m .37286 .56581 L .37398 .56421 L F
.37716 .56549 m .37709 .5655 L .37703 .56544 L F
.37709 .5655 m .37286 .56581 L .37703 .56544 L F
.338 0 .144 r
.37716 .56549 m .37713 .56554 L .37711 .56553 L F
.614 .186 .205 r
.37716 .56549 m .37703 .56544 L .37637 .56363 L F
.338 0 .144 r
.37709 .5655 m .37286 .56888 L .37286 .56581 L F
.37716 .56549 m .37711 .56553 L .37709 .5655 L F
.37711 .56553 m .37286 .56888 L .37709 .5655 L F
.15 .206 .667 r
.37637 .56363 m .37678 .56475 L .37761 .56656 L F
.37709 .5655 m .3775 .56672 L .37756 .56662 L F
.37703 .56542 m .3775 .56672 L .37709 .5655 L F
.37678 .56475 m .37756 .56662 L .37761 .56656 L F
.37706 .56551 m .37693 .56754 L .3775 .56672 L F
.37703 .5655 m .37693 .56754 L .37706 .56551 L F
0 .108 .662 r
.37693 .56754 m .37856 .56827 L .37844 .56535 L F
.37693 .56754 m .37853 .56997 L .37856 .56827 L F
.653 .276 .317 r
.37856 .56827 m .37541 .56853 L .37713 .56554 L F
.37725 .56568 m .37713 .56554 L .37716 .56549 L F
.663 .316 0 r
.37714 .56544 m .37716 .56549 L .37637 .56363 L F
0 .059 .608 r
.37714 .56524 m .37716 .56549 L .37637 .56363 L F
.15 .206 .667 r
.37734 .56565 m .37761 .56656 L .3777 .56641 L F
.653 .276 .317 r
.37856 .56827 m .37725 .56568 L .37844 .56535 L F
.37725 .56568 m .37716 .56549 L .37844 .56535 L F
.15 .206 .667 r
.37637 .56363 m .37724 .56568 L .37734 .56565 L F
.37724 .56568 m .37761 .56656 L .37734 .56565 L F
.37637 .56363 m .3777 .56641 L .37844 .56535 L F
.588 .402 .597 r
.37637 .56363 m .37932 .5605 L .37649 .56058 L F
.37637 .56363 m .37868 .56355 L .37932 .5605 L F
.522 .169 .31 r
.37637 .56363 m .37844 .56535 L .37868 .56355 L F
.653 .276 .317 r
.37856 .56827 m .37713 .56554 L .37725 .56568 L F
.15 .206 .667 r
.37678 .56475 m .37703 .56542 L .37709 .5655 L F
.663 .316 0 r
.37672 .5645 m .37714 .56544 L .37637 .56363 L F
.338 0 .144 r
.37711 .56553 m .37541 .56853 L .37286 .56888 L F
.37713 .56554 m .37541 .56853 L .37711 .56553 L F
.15 .206 .667 r
.37703 .56544 m .37703 .5655 L .37706 .56551 L F
.37637 .56363 m .37657 .56501 L .37703 .56544 L F
.614 .186 .205 r
.37703 .56544 m .37398 .56421 L .37637 .56363 L F
.767 .375 .312 r
.37672 .5645 m .37716 .56753 L .37822 .56571 L F
.3778 .56503 m .37822 .56571 L .37844 .56535 L F
.37672 .5645 m .37822 .56571 L .3778 .56503 L F
0 .059 .608 r
.37654 .563 m .37714 .56524 L .37637 .56363 L F
.3769 .56166 m .37704 .56381 L .37654 .563 L F
.37704 .56381 m .37714 .56524 L .37654 .563 L F
.275 .086 .434 r
.29031 .57048 m .2924 .56964 L .29226 .56625 L F
.627 .548 .745 r
.2969 .57034 m .29226 .56625 L .29597 .56673 L F
0 0 .2 r
.29226 .56625 m .29266 .56636 L .29392 .56305 L F
.343 .135 .447 r
.29226 .56625 m .2944 .56862 L .29266 .56636 L F
.29226 .56625 m .2924 .56964 L .2944 .56862 L F
.893 .911 .51 r
.29151 .54491 m .29263 .54073 L .2946 .54193 L F
.369 .728 .989 r
.2946 .54193 m .29486 .54062 L .29263 .54073 L F
.2946 .54193 m .29486 .54062 L .29263 .54073 L F
0 .188 .72 r
.2946 .54193 m .29665 .54393 L .29486 .54062 L F
.895 .578 .44 r
.34479 .68597 m .34158 .68252 L .345 .68321 L F
.697 .514 .637 r
.34867 .68579 m .34479 .68597 L .345 .68321 L F
.608 .493 .697 r
.21228 .57069 m .2125 .57325 L .21002 .57341 L F
.621 .197 .217 r
.21139 .57496 m .21002 .57341 L .2125 .57325 L F
.21139 .57496 m .20815 .57534 L .21002 .57341 L F
0 0 0 r
.25918 .54132 m .25801 .54151 L .2611 .53931 L F
.25918 .54132 m .25687 .54208 L .25801 .54151 L F
.741 .443 .476 r
.35674 .69237 m .35254 .69454 L .3528 .692 L F
.35674 .69237 m .35449 .69472 L .35254 .69454 L F
.772 .488 .505 r
.35674 .69237 m .35696 .69503 L .35449 .69472 L F
.395 0 .092 r
.34906 .61447 m .3504 .61598 L .34727 .61589 L F
.34906 .61447 m .3519 .61419 L .3504 .61598 L F
.571 .456 .683 r
.35128 .61115 m .3519 .61419 L .34906 .61447 L F
.417 .821 .979 r
.29604 .52507 m .29884 .52461 L .30019 .52532 L F
.341 0 0 r
.29884 .52461 m .30266 .52487 L .30019 .52532 L F
.983 .736 .48 r
.3308 .51938 m .32925 .51857 L .33107 .5171 L F
.523 .832 1 r
.33107 .5171 m .33174 .51547 L .33364 .51641 L F
.367 .154 .453 r
.33107 .5171 m .33253 .51859 L .33174 .51547 L F
.33107 .5171 m .3308 .51938 L .33253 .51859 L F
.33253 .51859 m .3308 .51938 L .33107 .5171 L F
.201 0 .359 r
.30904 .56732 m .31072 .56883 L .31059 .56603 L F
.30904 .56732 m .309 .57005 L .31072 .56883 L F
.403 .776 .993 r
.25606 .52858 m .25796 .52967 L .25561 .52989 L F
.602 .44 .634 r
.35766 .54794 m .35383 .55038 L .35449 .54869 L F
.949 .936 .6 r
.35383 .55038 m .35301 .55008 L .35449 .54869 L F
.578 .166 .224 r
.31981 .64886 m .32153 .64826 L .31985 .65005 L F
.711 .461 .546 r
.32153 .64826 m .32392 .65128 L .31985 .65005 L F
.32153 .64826 m .32414 .64868 L .32392 .65128 L F
0 0 0 r
.37563 .61484 m .37394 .61676 L .3732 .61692 L F
.559 .61 .86 r
.37666 .61697 m .3732 .61692 L .37394 .61676 L F
.37666 .61697 m .37339 .62042 L .3732 .61692 L F
.298 0 .101 r
.23794 .76726 m .23941 .76542 L .23573 .76747 L F
.592 .836 .465 r
.24052 .76392 m .23941 .76542 L .23794 .76726 L F
.117 0 0 r
.36669 .53665 m .36783 .53662 L .37105 .53597 L F
.32 .807 .797 r
.37105 .53597 m .37228 .5353 L .37353 .53572 L F
.37105 .53597 m .36783 .53662 L .37228 .5353 L F
.746 .756 .861 r
.35162 .62939 m .356 .62966 L .35431 .6269 L F
.826 .644 .657 r
.35479 .6303 m .356 .62966 L .35453 .62957 L F
.709 .683 .822 r
.35443 .63019 m .35446 .6309 L .35162 .62939 L F
.826 .644 .657 r
.3515 .63204 m .35394 .63075 L .35162 .62939 L F
.627 .062 0 r
.35162 .62939 m .35446 .6309 L .35449 .63103 L F
.826 .644 .657 r
.3515 .63204 m .3555 .63154 L .35394 .63075 L F
.627 .062 0 r
.35394 .63075 m .35449 .63103 L .3545 .63108 L F
.35162 .62939 m .35449 .63103 L .35394 .63075 L F
.826 .644 .657 r
.3515 .63204 m .35502 .63334 L .3555 .63154 L F
.35449 .63103 m .3555 .63154 L .35452 .63045 L F
.723 .651 .777 r
.35451 .6306 m .3545 .63108 L .35449 .63103 L F
.35451 .63062 m .35449 .63103 L .35446 .6309 L F
.35451 .6306 m .35449 .63103 L .35451 .63062 L F
.826 .644 .657 r
.35452 .63045 m .3555 .63154 L .356 .62966 L F
0 0 .389 r
.35449 .63046 m .35446 .6309 L .35443 .63019 L F
.826 .644 .657 r
.35449 .63046 m .35451 .63062 L .35452 .63045 L F
0 0 .389 r
.35451 .6306 m .35451 .63062 L .35449 .63046 L F
.35451 .63062 m .35446 .6309 L .35449 .63046 L F
.826 .644 .657 r
.35394 .63075 m .35449 .63103 L .35451 .63062 L F
.35394 .63075 m .35451 .63062 L .35449 .63046 L F
.35394 .63075 m .35479 .6303 L .35162 .62939 L F
.627 .062 0 r
.35162 .62939 m .3545 .63108 L .35475 .63204 L F
.438 .434 .758 r
.356 .62966 m .35675 .62548 L .35431 .6269 L F
.723 .651 .777 r
.35512 .62731 m .35475 .63204 L .3545 .63108 L F
.35512 .62731 m .3545 .63108 L .35451 .6306 L F
.826 .644 .657 r
.35453 .6299 m .35453 .62957 L .3543 .62956 L F
.35479 .6303 m .35453 .62957 L .35453 .6299 L F
.35443 .63019 m .3543 .62956 L .35162 .62939 L F
.35479 .6303 m .3543 .62956 L .35443 .63019 L F
0 0 .389 r
.35512 .62731 m .35434 .62752 L .35431 .6269 L F
.35451 .6306 m .35443 .63019 L .35431 .6269 L F
.709 .683 .822 r
.35431 .6269 m .35443 .63019 L .35162 .62939 L F
0 0 .389 r
.35512 .62731 m .35431 .6269 L .35675 .62548 L F
.35512 .62731 m .35675 .62548 L .3527 .62429 L F
.799 .407 .311 r
.3505 .62714 m .35512 .62731 L .3527 .62429 L F
.3503 .6274 m .35055 .62739 L .3505 .62714 L F
.35055 .62739 m .35512 .62731 L .3505 .62714 L F
.107 .661 .775 r
.35569 .62716 m .35512 .62731 L .3503 .6274 L F
.627 .062 0 r
.35162 .62939 m .35475 .63204 L .3515 .63204 L F
.438 .434 .758 r
.356 .62966 m .35741 .63106 L .35675 .62548 L F
.487 .325 .587 r
.35675 .62548 m .35899 .62526 L .35939 .62264 L F
.458 .285 .558 r
.35735 .62521 m .35675 .62548 L .35939 .62264 L F
.62 .809 .972 r
.3527 .62429 m .35675 .62548 L .35735 .62521 L F
.3527 .62429 m .35735 .62521 L .35504 .62182 L F
.107 .661 .775 r
.35659 .62712 m .3503 .6274 L .35559 .62321 L F
.352 .137 .44 r
.35061 .62768 m .35145 .63095 L .35231 .62719 L F
.35004 .62784 m .35112 .63022 L .35061 .62768 L F
.35112 .63022 m .35145 .63095 L .35061 .62768 L F
.107 .661 .775 r
.35659 .62712 m .35512 .62731 L .35569 .62716 L F
0 0 .389 r
.35512 .62731 m .35451 .6306 L .35434 .62752 L F
.719 .446 .512 r
.356 .62966 m .35825 .63211 L .35741 .63106 L F
.162 .68 .889 r
.33558 .56388 m .33639 .5637 L .33808 .56418 L F
.97 .726 .51 r
.33639 .5637 m .33784 .56684 L .33808 .56418 L F
.463 .287 .557 r
.34032 .5634 m .33784 .56684 L .33639 .5637 L F
.762 .674 .765 r
.34032 .5634 m .33639 .5637 L .33894 .56067 L F
.729 .64 .759 r
.33644 .56497 m .33732 .5635 L .33639 .5637 L F
.33732 .5635 m .33842 .56167 L .33639 .5637 L F
.162 .68 .889 r
.33407 .5637 m .33639 .5637 L .33558 .56388 L F
.388 .564 .905 r
.22614 .62215 m .22697 .62407 L .22806 .62215 L F
.242 .375 .798 r
.22697 .62407 m .2296 .62579 L .22806 .62215 L F
.762 .601 .679 r
.32699 .54268 m .32713 .54593 L .32359 .54501 L F
0 0 .479 r
.3283 .54388 m .32713 .54593 L .32701 .54319 L F
.275 .392 .801 r
.3283 .54388 m .32971 .54727 L .32713 .54593 L F
.579 .609 .847 r
.33056 .54358 m .32971 .54727 L .3283 .54388 L F
0 0 0 r
.32681 .54544 m .32911 .5443 L .3283 .54388 L F
.32911 .5443 m .33056 .54358 L .3283 .54388 L F
0 0 .479 r
.3283 .54388 m .32701 .54319 L .32699 .54268 L F
.427 .677 .967 r
.19564 .6025 m .2006 .60451 L .19938 .60323 L F
.187 .421 .855 r
.2006 .60451 m .20144 .60311 L .19938 .60323 L F
.2006 .60451 m .20183 .60463 L .20144 .60311 L F
.255 0 .313 r
.32596 .66351 m .32686 .66125 L .32414 .66435 L F
0 0 0 r
.32596 .66351 m .32414 .66435 L .32204 .66641 L F
.265 .088 .444 r
.32392 .65128 m .32414 .64868 L .32583 .64784 L F
0 0 0 r
.32957 .65863 m .32686 .66125 L .32935 .65938 L F
.33163 .65756 m .32957 .65863 L .32935 .65938 L F
.797 .807 .86 r
.37681 .66725 m .37278 .66708 L .37535 .66476 L F
.795 .809 .863 r
.37681 .66725 m .37436 .6683 L .37278 .66708 L F
.684 .607 .764 r
.37796 .67055 m .37436 .6683 L .37681 .66725 L F
.59 .688 .91 r
.37743 .66358 m .37681 .66725 L .37535 .66476 L F
.37743 .66358 m .37965 .66677 L .37681 .66725 L F
.667 .592 .762 r
.37965 .66677 m .37796 .67055 L .37681 .66725 L F
.802 .637 .677 r
.3527 .62429 m .35504 .62182 L .35136 .62077 L F
.752 .642 .739 r
.34818 .62503 m .34987 .62214 L .34823 .62308 L F
.34987 .62214 m .35012 .62171 L .34985 .62191 L F
.34987 .62214 m .34985 .62191 L .34823 .62308 L F
0 0 0 r
.3506 .62083 m .3468 .6239 L .3481 .62316 L F
.3506 .62083 m .348 .62325 L .34871 .62274 L F
.922 .717 .226 r
.34978 .62091 m .3506 .62083 L .34985 .62191 L F
0 0 0 r
.3506 .62083 m .34849 .62296 L .34983 .62193 L F
.9 .978 .805 r
.35263 .61793 m .3506 .62083 L .34962 .61868 L F
.34963 .61866 m .34962 .61868 L .34961 .61866 L F
.35263 .61793 m .34962 .61868 L .34963 .61866 L F
.469 .166 .37 r
.35492 .61944 m .35263 .61793 L .34963 .61866 L F
.34966 .61867 m .34963 .61866 L .34961 .61866 L F
.35492 .61944 m .34963 .61866 L .34966 .61867 L F
.79 .667 .727 r
.34831 .61991 m .3497 .61981 L .34962 .61875 L F
.922 .717 .226 r
.34962 .61875 m .34965 .61875 L .34974 .62032 L F
.79 .667 .727 r
.34831 .61991 m .34974 .62032 L .3497 .61981 L F
.34831 .61991 m .34962 .61875 L .34935 .61891 L F
.802 .637 .677 r
.3498 .6214 m .34974 .62032 L .34831 .61991 L F
.922 .717 .226 r
.34961 .61891 m .34985 .62191 L .34961 .61917 L F
.34961 .61883 m .34966 .61926 L .34961 .61891 L F
.34962 .61875 m .34966 .61926 L .34961 .61883 L F
.34966 .61926 m .34985 .62191 L .34961 .61891 L F
.752 .642 .739 r
.34823 .62308 m .35012 .62171 L .34831 .61991 L F
.922 .717 .226 r
.34961 .61883 m .34961 .61917 L .34935 .61891 L F
.34961 .61917 m .34957 .62231 L .34938 .6193 L F
.34961 .61917 m .34938 .6193 L .34935 .61891 L F
.538 .199 .341 r
.34939 .62072 m .34981 .61887 L .34961 .61887 L F
.34939 .62069 m .34961 .61887 L .34941 .61888 L F
.34939 .62072 m .34961 .61887 L .34939 .62069 L F
.578 .348 .53 r
.3504 .61598 m .34993 .61826 L .3475 .61888 L F
.79 .667 .727 r
.34951 .61876 m .34962 .61875 L .34961 .61866 L F
.34944 .61884 m .34962 .61875 L .34951 .61876 L F
.34941 .61888 m .34962 .61875 L .3494 .61886 L F
.922 .717 .226 r
.34961 .61866 m .34962 .61875 L .34961 .61883 L F
.34961 .61866 m .34961 .61883 L .34946 .61887 L F
.578 .348 .53 r
.34951 .61876 m .34946 .61887 L .34941 .61888 L F
.34993 .61826 m .34941 .61888 L .3475 .61888 L F
.79 .667 .727 r
.3494 .61886 m .34944 .61884 L .34951 .61876 L F
.538 .199 .341 r
.34798 .61934 m .34946 .61887 L .3475 .61888 L F
.34822 .61958 m .34941 .61888 L .3475 .61888 L F
.79 .667 .727 r
.34935 .61891 m .34941 .61888 L .3494 .61886 L F
.922 .717 .226 r
.34951 .61876 m .34946 .61887 L .3494 .61886 L F
.34961 .61866 m .34946 .61887 L .34951 .61876 L F
.578 .348 .53 r
.3504 .61598 m .3475 .61888 L .34727 .61589 L F
.583 .577 .812 r
.3494 .61886 m .34961 .61887 L .34803 .61657 L F
.34941 .61888 m .34946 .61887 L .3494 .61886 L F
.922 .717 .226 r
.34961 .61866 m .34963 .61869 L .34962 .61875 L F
.34963 .61869 m .34965 .61875 L .34962 .61875 L F
.578 .348 .53 r
.34993 .61826 m .34981 .61887 L .34946 .61887 L F
.583 .577 .812 r
.34946 .61887 m .34961 .61887 L .3494 .61886 L F
.922 .717 .226 r
.34935 .61891 m .34957 .62231 L .34831 .61991 L F
.538 .199 .341 r
.34939 .62072 m .34941 .61888 L .34822 .61958 L F
.922 .717 .226 r
.3494 .61886 m .34946 .61887 L .34935 .61891 L F
.578 .348 .53 r
.34993 .61826 m .34946 .61887 L .34951 .61876 L F
.583 .577 .812 r
.34803 .61657 m .34961 .61887 L .34857 .61424 L F
.3475 .61888 m .34941 .61888 L .34803 .61657 L F
.34961 .61887 m .34981 .61887 L .34941 .61739 L F
.34961 .61887 m .34941 .61739 L .34857 .61424 L F
.538 .199 .341 r
.34939 .62072 m .34961 .61887 L .34946 .61887 L F
.34939 .62072 m .34946 .61887 L .34798 .61934 L F
.34939 .62072 m .34981 .61887 L .34961 .61887 L F
.34939 .62072 m .34961 .61887 L .34939 .62072 L F
.922 .717 .226 r
.3497 .61981 m .34974 .62032 L .34976 .6206 L F
.34961 .61866 m .34974 .62032 L .3497 .61981 L F
.34965 .61875 m .3506 .62083 L .34978 .62091 L F
.79 .667 .727 r
.3497 .61981 m .35504 .62182 L .35492 .61944 L F
.34974 .62032 m .35504 .62182 L .3497 .61981 L F
.3497 .61981 m .35492 .61944 L .34961 .61866 L F
.922 .717 .226 r
.34961 .61866 m .34976 .6206 L .34978 .62091 L F
.497 .273 .505 r
.35286 .61815 m .34997 .61884 L .34992 .6183 L F
.34997 .61884 m .34981 .61887 L .34983 .61876 L F
.34997 .61884 m .34983 .61876 L .34992 .6183 L F
.35121 .6167 m .34992 .6183 L .3504 .61598 L F
.35286 .61815 m .34992 .6183 L .35121 .6167 L F
.802 .637 .677 r
.35012 .62171 m .35136 .62077 L .34974 .62032 L F
.35012 .62171 m .34974 .62032 L .3498 .6214 L F
.922 .717 .226 r
.34961 .61917 m .34985 .62191 L .34957 .62231 L F
.752 .642 .739 r
.34818 .62503 m .34823 .62308 L .34957 .62231 L F
0 0 0 r
.34871 .62274 m .348 .62325 L .34849 .62296 L F
.34983 .62193 m .34849 .62296 L .34957 .62231 L F
.752 .642 .739 r
.34823 .62308 m .34831 .61991 L .34957 .62231 L F
0 0 0 r
.3481 .62316 m .3465 .62413 L .348 .62325 L F
.3468 .6239 m .3465 .62413 L .3481 .62316 L F
.752 .642 .739 r
.34818 .62503 m .3527 .62429 L .35012 .62171 L F
.802 .637 .677 r
.3527 .62429 m .35136 .62077 L .35012 .62171 L F
.519 .883 .979 r
.23348 .78634 m .2362 .78552 L .23397 .78514 L F
.23397 .78514 m .2362 .78552 L .23348 .78634 L F
.631 .687 .884 r
.2362 .78552 m .23514 .78635 L .23348 .78634 L F
.23348 .78634 m .23514 .78635 L .2362 .78552 L F
.519 .883 .979 r
.23348 .78634 m .2362 .78552 L .23397 .78514 L F
0 0 .002 r
.20509 .55217 m .20603 .55257 L .20715 .55152 L F
.20509 .55217 m .20419 .55391 L .20603 .55257 L F
.607 .487 .69 r
.27379 .55455 m .27628 .55216 L .27398 .55426 L F
.322 .118 .44 r
.3036 .59407 m .30162 .59251 L .30449 .5917 L F
.3036 .59407 m .30159 .59487 L .30162 .59251 L F
.376 .198 .509 r
.18211 .59622 m .18369 .59836 L .18364 .59484 L F
.441 .436 .758 r
.33763 .56954 m .3389 .57345 L .33684 .57364 L F
.477 .897 .863 r
.24724 .53129 m .24614 .53225 L .24499 .5322 L F
.704 .428 .504 r
.38263 .5455 m .38254 .54784 L .37868 .54812 L F
.525 .263 .461 r
.38297 .54536 m .38322 .54615 L .38263 .5455 L F
0 .554 .768 r
.38661 .54841 m .38263 .5455 L .38322 .54615 L F
.756 .661 .758 r
.37612 .54775 m .37463 .54417 L .37575 .5456 L F
.891 .903 .829 r
.3784 .5419 m .37575 .5456 L .37463 .54417 L F
.504 .032 .066 r
.25907 .62387 m .26125 .62491 L .26303 .62331 L F
.129 0 0 r
.26303 .62331 m .26359 .62431 L .26549 .62299 L F
.26303 .62331 m .26125 .62491 L .26359 .62431 L F
.799 .694 .153 r
.33371 .64573 m .33344 .64794 L .33461 .64462 L F
0 0 .444 r
.3784 .5419 m .37969 .5379 L .38039 .53792 L F
.751 .323 .235 r
.37089 .61008 m .37402 .61275 L .37507 .61106 L F
.059 0 0 r
.37402 .61275 m .37747 .61014 L .37507 .61106 L F
.976 .72 .478 r
.35208 .67315 m .35236 .67652 L .35084 .67304 L F
.464 .837 .99 r
.35314 .67208 m .35208 .67315 L .35084 .67304 L F
.35314 .67208 m .355 .67284 L .35208 .67315 L F
.39 .532 .878 r
.24246 .61682 m .24277 .62026 L .24095 .61703 L F
.24246 .61682 m .24483 .62041 L .24277 .62026 L F
.552 .268 .437 r
.38539 .57586 m .38828 .57554 L .38599 .57362 L F
.571 .008 0 r
.38599 .57362 m .38641 .57459 L .38439 .57213 L F
.38658 .57412 m .38828 .57554 L .38641 .57459 L F
.669 .889 .978 r
.38641 .57459 m .38828 .57554 L .3881 .57332 L F
0 0 0 r
.38631 .57486 m .38641 .57459 L .3881 .57332 L F
.423 .86 .761 r
.38539 .57586 m .38207 .5774 L .38384 .57547 L F
.747 .258 .075 r
.38453 .57724 m .38539 .57586 L .38384 .57547 L F
.38453 .57724 m .3883 .57856 L .38539 .57586 L F
.587 .379 .566 r
.38539 .57586 m .3883 .57856 L .38828 .57554 L F
.683 .517 .655 r
.38641 .57459 m .38453 .57724 L .38384 .57547 L F
.773 .942 .6 r
.3847 .57624 m .38453 .57724 L .38641 .57459 L F
0 0 0 r
.3847 .57624 m .38641 .57459 L .38631 .57486 L F
.571 .008 0 r
.38599 .57362 m .38658 .57412 L .38641 .57459 L F
.841 .69 .696 r
.29007 .54146 m .28875 .54444 L .29151 .54491 L F
.809 .438 .353 r
.28875 .54444 m .28984 .54698 L .29151 .54491 L F
.893 .911 .51 r
.29151 .54491 m .29107 .54463 L .29263 .54073 L F
.874 .937 .564 r
.29151 .54491 m .28984 .54698 L .29107 .54463 L F
.315 .796 .901 r
.2623 .74272 m .26619 .74249 L .26442 .74165 L F
.03 0 0 r
.293 .55142 m .2913 .55213 L .28928 .55229 L F
.088 .618 .869 r
.29519 .55282 m .2913 .55213 L .293 .55142 L F
.559 .068 .047 r
.29554 .55183 m .29519 .55282 L .293 .55142 L F
.489 .525 .821 r
.23932 .61349 m .23883 .61732 L .24049 .61387 L F
.23932 .61349 m .24095 .61703 L .23883 .61732 L F
.92 .934 .799 r
.33914 .54483 m .34271 .54146 L .34113 .54394 L F
.55 .551 .808 r
.3441 .53785 m .34271 .54146 L .34221 .53869 L F
.3441 .53785 m .34513 .54104 L .34271 .54146 L F
.696 .298 .29 r
.34563 .54404 m .34113 .54394 L .34271 .54146 L F
.514 .354 .602 r
.34513 .54104 m .34563 .54404 L .34271 .54146 L F
.524 0 0 r
.35235 .58791 m .35604 .58831 L .35701 .58784 L F
.411 0 0 r
.35604 .58831 m .35839 .58843 L .35701 .58784 L F
0 .178 .696 r
.34247 .54991 m .3418 .55178 L .34049 .54789 L F
.431 .417 .743 r
.32749 .5942 m .32482 .5953 L .32428 .59209 L F
0 0 0 r
.32268 .59696 m .32482 .5953 L .32749 .5942 L F
0 0 .183 r
.26275 .5376 m .2611 .53931 L .26215 .53799 L F
.157 0 0 r
.26149 .54063 m .25918 .54132 L .2611 .53931 L F
.957 .702 .51 r
.33902 .5547 m .33733 .55449 L .33523 .55432 L F
.33902 .5547 m .33906 .5575 L .33733 .55449 L F
.392 .789 .986 r
.35875 .51433 m .36188 .51399 L .36299 .51484 L F
.749 .95 .943 r
.36299 .51484 m .3638 .51253 L .36528 .51455 L F
.36299 .51484 m .36188 .51399 L .3638 .51253 L F
.437 0 .064 r
.37819 .61416 m .37703 .61599 L .37563 .61484 L F
.479 .33 .6 r
.3805 .61072 m .37819 .61416 L .37747 .61014 L F
.3805 .61072 m .38048 .61403 L .37819 .61416 L F
.874 .797 .771 r
.38048 .61403 m .37703 .61599 L .37819 .61416 L F
.414 0 .014 r
.22973 .6111 m .23331 .61086 L .23106 .61057 L F
0 0 0 r
.25119 .55086 m .24892 .55119 L .24682 .55147 L F
.431 0 0 r
.25288 .55198 m .24892 .55119 L .25119 .55086 L F
.871 .611 .543 r
.25119 .55086 m .24892 .55119 L .25026 .54959 L F
.427 .224 .5 r
.34382 .57915 m .34184 .58214 L .34175 .57972 L F
.248 .296 .716 r
.3505 .55132 m .35383 .55038 L .35301 .55008 L F
.3505 .55132 m .35267 .55185 L .35383 .55038 L F
.66 .285 .323 r
.35267 .55185 m .35301 .55008 L .35383 .55038 L F
.508 .29 .519 r
.32506 .63922 m .32748 .63881 L .32485 .6418 L F
.292 .621 .959 r
.32204 .66641 m .32139 .66777 L .32358 .66785 L F
.41 .723 .988 r
.21244 .61347 m .21252 .61157 L .21051 .61144 L F
.21244 .61347 m .21422 .61321 L .21252 .61157 L F
.313 .328 .717 r
.31834 .59207 m .31981 .5915 L .31905 .58773 L F
.245 .151 .545 r
.31834 .59207 m .31995 .59429 L .31981 .5915 L F
.066 .099 .586 r
.31834 .59207 m .31903 .5959 L .31995 .59429 L F
.356 .068 .331 r
.26475 .54227 m .26624 .54378 L .26733 .54222 L F
.26475 .54227 m .26418 .54442 L .26624 .54378 L F
.337 .386 .765 r
.37345 .62868 m .37293 .63261 L .37071 .62921 L F
.37345 .62868 m .37463 .63235 L .37293 .63261 L F
.711 .682 .821 r
.35972 .6671 m .36132 .67068 L .35752 .67033 L F
.621 .636 .845 r
.36367 .66991 m .36132 .67068 L .35972 .6671 L F
.468 .053 .169 r
.22684 .613 m .22913 .61324 L .22973 .6111 L F
.414 0 .014 r
.22973 .6111 m .23147 .61271 L .23331 .61086 L F
.338 0 .13 r
.22973 .6111 m .22913 .61324 L .23147 .61271 L F
.634 .208 0 r
.30237 .65332 m .30329 .65459 L .30413 .65603 L F
.945 .752 .285 r
.30329 .65459 m .30421 .65596 L .30413 .65603 L F
.64 .965 .834 r
.38207 .5774 m .38024 .57735 L .38183 .57716 L F
.38207 .5774 m .38009 .57898 L .38024 .57735 L F
.618 .471 .661 r
.31179 .62317 m .31501 .62357 L .31515 .62101 L F
.803 .594 .62 r
.31015 .62553 m .31501 .62357 L .31179 .62317 L F
.241 0 .236 r
.3112 .56096 m .31315 .56033 L .31403 .55839 L F
.506 .313 .553 r
.3112 .56096 m .3135 .56297 L .31315 .56033 L F
.3112 .56096 m .3112 .56366 L .3135 .56297 L F
.108 .065 .522 r
.31694 .58577 m .31775 .58593 L .31822 .58179 L F
.043 .233 .733 r
.31694 .58577 m .31905 .58773 L .31775 .58593 L F
.265 0 0 r
.28108 .6204 m .27679 .62242 L .27869 .62029 L F
.65 .642 .829 r
.37336 .51709 m .36971 .51549 L .37147 .51468 L F
.313 .556 .922 r
.3742 .51532 m .37336 .51709 L .37147 .51468 L F
.431 .697 .976 r
.3742 .51532 m .37564 .51688 L .37336 .51709 L F
.125 0 0 r
.22648 .56077 m .22429 .56236 L .22187 .56285 L F
.148 0 0 r
.22665 .56132 m .22648 .56077 L .22894 .56066 L F
.22665 .56132 m .22429 .56236 L .22648 .56077 L F
0 0 0 r
.27452 .62317 m .27575 .6226 L .27679 .62242 L F
.741 .879 .944 r
.30902 .52336 m .30704 .52464 L .30542 .52382 L F
.455 .38 .682 r
.3011 .57894 m .30179 .58274 L .29956 .58334 L F
.229 0 .118 r
.2763 .54663 m .27427 .54733 L .27507 .54575 L F
.938 .767 .642 r
.34666 .51098 m .34749 .51017 L .34949 .51058 L F
.34666 .51098 m .34506 .51129 L .34749 .51017 L F
.34666 .51098 m .34629 .51383 L .34506 .51129 L F
0 .209 .683 r
.38166 .52242 m .38178 .52297 L .38013 .52161 L F
.38166 .52242 m .3831 .52376 L .38178 .52297 L F
.667 .592 .762 r
.37965 .66677 m .38091 .67063 L .37796 .67055 L F
0 0 0 r
.38091 .67063 m .37729 .67285 L .37796 .67055 L F
.608 .525 .736 r
.3425 .61492 m .3446 .61467 L .34425 .61085 L F
.727 .879 .952 r
.35218 .59127 m .35419 .59277 L .35614 .59098 L F
.463 .219 .458 r
.26733 .54222 m .26984 .54176 L .27032 .53808 L F
.562 .602 .851 r
.26931 .53624 m .27032 .53808 L .27242 .53678 L F
.369 .14 .431 r
.27032 .53808 m .27197 .54083 L .27242 .53678 L F
.27032 .53808 m .26984 .54176 L .27197 .54083 L F
.326 .789 .939 r
.25796 .52967 m .26033 .52935 L .26196 .52968 L F
.398 .826 .961 r
.26033 .52935 m .26434 .52921 L .26196 .52968 L F
.611 .663 .876 r
.37548 .53059 m .37847 .53195 L .37854 .53139 L F
.409 .496 .837 r
.37548 .53059 m .37854 .53139 L .37687 .52793 L F
.688 .913 .972 r
.37575 .53476 m .37353 .53572 L .37433 .53375 L F
.37591 .53487 m .37563 .53497 L .37575 .53476 L F
.37563 .53497 m .37353 .53572 L .37575 .53476 L F
.602 .238 .323 r
.37433 .53375 m .37854 .53139 L .37591 .53487 L F
.676 .546 .699 r
.37865 .53576 m .37353 .53572 L .37591 .53487 L F
.37865 .53576 m .37382 .53887 L .37353 .53572 L F
.573 .284 .439 r
.37394 .53588 m .37401 .53588 L .37433 .53375 L F
.37401 .53588 m .37688 .53576 L .3753 .53451 L F
.37401 .53588 m .3753 .53451 L .37433 .53375 L F
.602 .238 .323 r
.37433 .53375 m .37531 .53448 L .37854 .53139 L F
.249 .314 .735 r
.37531 .53448 m .37688 .53576 L .37685 .53562 L F
.37433 .53375 m .3753 .53451 L .37531 .53448 L F
.3753 .53451 m .37688 .53576 L .37531 .53448 L F
.729 .952 .655 r
.37689 .53283 m .37538 .53437 L .37742 .53191 L F
.602 .238 .323 r
.37433 .53375 m .37463 .53514 L .37531 .53448 L F
.729 .952 .655 r
.37538 .53437 m .37559 .53403 L .37742 .53191 L F
.37669 .53316 m .37542 .53438 L .37689 .53283 L F
.249 .314 .735 r
.37433 .53375 m .37531 .53448 L .37609 .53183 L F
.729 .952 .655 r
.37542 .53438 m .37531 .53448 L .37689 .53283 L F
.37531 .53448 m .37538 .53437 L .37689 .53283 L F
.611 .663 .876 r
.37847 .53195 m .38003 .53265 L .37854 .53139 L F
.704 .636 .778 r
.37854 .53139 m .38059 .53555 L .37591 .53487 L F
.778 .554 .596 r
.38059 .53555 m .37865 .53576 L .37591 .53487 L F
0 .227 .739 r
.37854 .53139 m .37914 .52993 L .37687 .52793 L F
.893 .957 .834 r
.37914 .52993 m .37559 .53403 L .37609 .53183 L F
.37559 .53403 m .37463 .53514 L .37609 .53183 L F
.249 .314 .735 r
.37559 .53403 m .37685 .53562 L .3763 .53286 L F
.37531 .53448 m .37546 .53459 L .37559 .53403 L F
.37546 .53459 m .37685 .53562 L .37559 .53403 L F
.37531 .53448 m .3763 .53286 L .37609 .53183 L F
.729 .952 .655 r
.37531 .53448 m .37463 .53514 L .37538 .53437 L F
.37538 .53437 m .37463 .53514 L .37559 .53403 L F
.37854 .53139 m .37669 .53316 L .37864 .5305 L F
.37669 .53316 m .37742 .53191 L .37864 .5305 L F
.37854 .53139 m .37864 .5305 L .37914 .52993 L F
.963 .631 .282 r
.38003 .53265 m .38059 .53555 L .37854 .53139 L F
0 0 0 r
.32502 .61367 m .32257 .61646 L .32254 .61449 L F
.51 .8 .998 r
.28008 .64479 m .28481 .64532 L .28243 .64423 L F
.534 0 0 r
.28243 .64423 m .28481 .64532 L .28553 .64594 L F
.037 .356 .83 r
.28562 .64651 m .28553 .64594 L .28481 .64532 L F
.203 0 0 r
.22164 .54062 m .22317 .54107 L .22486 .53892 L F
.657 .948 .955 r
.22486 .53892 m .22542 .53733 L .22663 .53754 L F
0 0 0 r
.22486 .53892 m .22506 .53967 L .22542 .53733 L F
.22486 .53892 m .22317 .54107 L .22506 .53967 L F
.468 .407 .705 r
.40264 .56928 m .39957 .56628 L .4038 .56667 L F
.465 .488 .797 r
.40508 .56277 m .40597 .56625 L .4038 .56667 L F
.315 0 .249 r
.40597 .56625 m .40264 .56928 L .4038 .56667 L F
.392 .105 .354 r
.20715 .55152 m .20958 .55088 L .21007 .54777 L F
.2 0 .294 r
.21007 .54777 m .2114 .54971 L .21209 .5475 L F
.21007 .54777 m .20958 .55088 L .2114 .54971 L F
.008 0 .494 r
.29031 .57048 m .29125 .56973 L .2924 .56964 L F
.29031 .57048 m .29055 .57329 L .29125 .56973 L F
.257 .349 .767 r
.37078 .52272 m .37186 .52657 L .37334 .52427 L F
.398 .393 .737 r
.37264 .52846 m .37334 .52427 L .37186 .52657 L F
.867 .605 .54 r
.25026 .54959 m .24892 .55119 L .24803 .54828 L F
.24803 .54828 m .24892 .55119 L .25026 .54959 L F
.547 .817 .459 r
.25159 .548 m .24892 .55119 L .25026 .54959 L F
.25026 .54959 m .24892 .55119 L .25159 .548 L F
.89 .988 .74 r
.31563 .56744 m .31571 .56922 L .31668 .56813 L F
.183 0 .273 r
.32935 .65938 m .32686 .66125 L .32596 .66351 L F
.319 0 .133 r
.2761 .62936 m .27846 .62883 L .27998 .62627 L F
0 0 0 r
.27846 .62883 m .28214 .62708 L .27998 .62627 L F
.395 .362 .704 r
.32971 .54727 m .32813 .54838 L .32713 .54593 L F
.51 .609 .887 r
.29541 .56221 m .29597 .56673 L .29392 .56305 L F
.29541 .56221 m .29815 .5661 L .29597 .56673 L F
.506 .449 .727 r
.29815 .5661 m .2969 .57034 L .29597 .56673 L F
0 0 0 r
.33293 .67007 m .33174 .67037 L .33408 .66956 L F
.33293 .67007 m .33001 .6722 L .33174 .67037 L F
.891 .903 .829 r
.3784 .5419 m .37463 .54417 L .37682 .54278 L F
0 0 .444 r
.3784 .5419 m .37981 .54084 L .37969 .5379 L F
.446 .845 .649 r
.3784 .5419 m .37682 .54278 L .37981 .54084 L F
.245 0 .253 r
.31096 .65416 m .31168 .65208 L .31363 .65137 L F
.786 .869 .91 r
.3426 .51191 m .3399 .51431 L .33821 .51287 L F
.279 .693 .97 r
.3399 .51431 m .34037 .51307 L .33821 .51287 L F
.3399 .51431 m .3427 .51451 L .34037 .51307 L F
.471 .064 .185 r
.31427 .64428 m .31611 .64187 L .31329 .64268 L F
.603 .436 .628 r
.31611 .64187 m .31871 .64193 L .31817 .63934 L F
.799 .587 .614 r
.31427 .64428 m .31871 .64193 L .31611 .64187 L F
.603 .436 .628 r
.31611 .64187 m .31871 .64193 L .31817 .63934 L F
.747 .53 .601 r
.37339 .62042 m .37315 .62316 L .36941 .62288 L F
.559 .61 .86 r
.37666 .61697 m .3749 .62083 L .37339 .62042 L F
.565 .371 .577 r
.37574 .62271 m .37339 .62042 L .3749 .62083 L F
.37574 .62271 m .37315 .62316 L .37339 .62042 L F
.608 .493 .698 r
.39957 .56628 m .39858 .56976 L .39703 .56697 L F
.39957 .56628 m .40063 .57008 L .39858 .56976 L F
.658 .452 .593 r
.40063 .57008 m .39871 .57271 L .39858 .56976 L F
.944 .611 .366 r
.39858 .56976 m .39574 .56889 L .39703 .56697 L F
.685 .611 .768 r
.31817 .63934 m .31938 .63989 L .32 .63479 L F
.763 .507 .547 r
.31895 .64317 m .31817 .63934 L .31871 .64193 L F
.364 .256 .596 r
.31894 .64264 m .31892 .64514 L .31962 .6447 L F
.31905 .64228 m .31962 .6447 L .32074 .644 L F
.31871 .64193 m .31962 .6447 L .31905 .64228 L F
0 0 .281 r
.31908 .6423 m .31906 .64233 L .31895 .64317 L F
.763 .507 .547 r
.31895 .64317 m .31906 .64233 L .31905 .64228 L F
.489 .265 .501 r
.31895 .64317 m .31905 .64228 L .31908 .6423 L F
.31895 .64317 m .31908 .6423 L .32074 .644 L F
0 0 .281 r
.32057 .63863 m .31908 .6423 L .31895 .64317 L F
.32177 .63734 m .32057 .63863 L .31895 .64317 L F
.32057 .63863 m .31938 .63989 L .31906 .64233 L F
.364 .256 .596 r
.31871 .64193 m .31878 .64303 L .31894 .64264 L F
.31878 .64303 m .31892 .64514 L .31894 .64264 L F
.763 .507 .547 r
.31905 .64228 m .31938 .63989 L .31932 .63986 L F
.31906 .64233 m .31938 .63989 L .31905 .64228 L F
.489 .265 .501 r
.31895 .64317 m .31871 .64193 L .31905 .64228 L F
.763 .507 .547 r
.31895 .64317 m .31932 .63986 L .31817 .63934 L F
.132 .109 .563 r
.32 .63479 m .31938 .63989 L .32177 .63734 L F
.66 .947 .957 r
.38735 .54667 m .3849 .54808 L .38661 .54841 L F
.974 .718 .482 r
.38661 .54841 m .3849 .54808 L .38735 .54667 L F
.38661 .54841 m .38641 .55093 L .3849 .54808 L F
.128 0 0 r
.27802 .55825 m .27545 .55937 L .27293 .55953 L F
0 0 0 r
.27802 .55866 m .27802 .55825 L .2802 .55741 L F
.27802 .55866 m .27545 .55937 L .27802 .55825 L F
.713 .524 .633 r
.21799 .56731 m .21771 .57014 L .21487 .56984 L F
0 0 .28 r
.21926 .56611 m .21771 .57014 L .21799 .56731 L F
0 0 .3 r
.3542 .6071 m .3546 .60802 L .35288 .60422 L F
.891 .885 .457 r
.35367 .61033 m .3546 .60802 L .3542 .6071 L F
0 0 0 r
.19911 .55743 m .2008 .55647 L .20224 .55476 L F
.218 0 .028 r
.2008 .55647 m .20419 .55391 L .20224 .55476 L F
.441 .282 .568 r
.37254 .58907 m .37488 .5887 L .37461 .58523 L F
.586 .457 .672 r
.37267 .59162 m .37488 .5887 L .37254 .58907 L F
0 .444 .792 r
.26262 .63475 m .2626 .63436 L .26085 .63378 L F
.26262 .63475 m .26437 .63527 L .2626 .63436 L F
.777 .688 .766 r
.28751 .54757 m .28612 .54402 L .28499 .54563 L F
.457 .391 .695 r
.28499 .54563 m .28562 .54848 L .28751 .54757 L F
.511 .418 .686 r
.30077 .54731 m .29889 .55119 L .29869 .54799 L F
.347 .669 .975 r
.34954 .50884 m .35101 .51027 L .34949 .51058 L F
.682 .942 .963 r
.34949 .51058 m .34749 .51017 L .34954 .50884 L F
.347 .669 .975 r
.34954 .50884 m .35101 .51027 L .34949 .51058 L F
0 0 .026 r
.39164 .59645 m .39358 .59532 L .39263 .59468 L F
.335 .777 .962 r
.39358 .59532 m .39576 .59497 L .39263 .59468 L F
.311 .453 .842 r
.20394 .6079 m .20528 .60619 L .20183 .60463 L F
.20394 .6079 m .20527 .60761 L .20528 .60619 L F
.296 .357 .756 r
.20394 .6079 m .20651 .60972 L .20527 .60761 L F
.382 0 0 r
.28214 .62708 m .28434 .62793 L .28632 .6267 L F
.597 .199 .258 r
.28434 .62793 m .28847 .62533 L .28632 .6267 L F
.469 .166 .37 r
.35492 .61944 m .35483 .61777 L .35263 .61793 L F
.246 0 0 r
.31329 .64268 m .30966 .64449 L .31194 .64487 L F
.471 .064 .185 r
.31427 .64428 m .31329 .64268 L .31194 .64487 L F
0 0 .261 r
.32304 .57599 m .3231 .57851 L .32188 .57944 L F
.174 0 .209 r
.32724 .57189 m .3283 .57284 L .32911 .57011 L F
0 .014 .565 r
.32724 .57189 m .32861 .57336 L .3283 .57284 L F
.811 .934 .564 r
.35074 .57027 m .34946 .57208 L .34938 .57318 L F
.811 .915 .522 r
.34946 .57208 m .34784 .57512 L .34938 .57318 L F
.341 0 0 r
.31944 .54677 m .31574 .54721 L .31761 .54607 L F
.085 .293 .775 r
.37787 .5186 m .37715 .52025 L .37564 .51688 L F
.183 .417 .853 r
.37787 .5186 m .38013 .52161 L .37715 .52025 L F
.3 .245 .627 r
.20385 .58146 m .20397 .58521 L .20243 .58592 L F
.304 .254 .635 r
.20397 .58521 m .20447 .588 L .20243 .58592 L F
.323 .577 .933 r
.38592 .52447 m .38509 .52617 L .3831 .52376 L F
.177 .394 .836 r
.38592 .52447 m .388 .52793 L .38509 .52617 L F
0 0 0 r
.27759 .61462 m .27773 .61536 L .27893 .61312 L F
.27759 .61462 m .27581 .61635 L .27773 .61536 L F
.28015 .61218 m .27759 .61462 L .27893 .61312 L F
.125 .637 .895 r
.36528 .51455 m .3678 .5147 L .36971 .51549 L F
.382 .821 .953 r
.3678 .5147 m .37147 .51468 L .36971 .51549 L F
.695 .566 .705 r
.37178 .63958 m .37108 .64267 L .36744 .64144 L F
.639 .817 .968 r
.21422 .61321 m .21822 .61368 L .21648 .61272 L F
.793 .909 .92 r
.21648 .61272 m .21822 .61368 L .22127 .61119 L F
.744 .719 .829 r
.37436 .6683 m .37037 .66834 L .37278 .66708 L F
0 0 .077 r
.32984 .60148 m .33045 .60263 L .33096 .60179 L F
.262 .025 .354 r
.32677 .60988 m .32732 .6075 L .32926 .60653 L F
0 0 0 r
.32796 .60863 m .32677 .60988 L .32926 .60653 L F
.32796 .60863 m .32798 .6086 L .32758 .60569 L F
.32798 .6086 m .32926 .60653 L .32856 .60618 L F
.32798 .6086 m .32856 .60618 L .32758 .60569 L F
0 0 .077 r
.32984 .60148 m .32949 .60225 L .33045 .60263 L F
.32949 .60225 m .32774 .60614 L .32893 .6046 L F
.32949 .60225 m .32893 .6046 L .33045 .60263 L F
.869 .43 .14 r
.35766 .54794 m .35899 .55068 L .36103 .55152 L F
0 0 .091 r
.36103 .55152 m .36257 .55048 L .36281 .54863 L F
.459 .032 .142 r
.35899 .55068 m .36257 .55048 L .36103 .55152 L F
.861 .923 .868 r
.35752 .67033 m .355 .67284 L .35314 .67208 L F
.634 .786 .955 r
.18409 .5994 m .18601 .60113 L .18854 .60017 L F
.47 .7 .968 r
.18601 .60113 m .18826 .60101 L .18854 .60017 L F
.186 .718 .758 r
.23439 .53506 m .23373 .53532 L .23203 .53541 L F
.23439 .53506 m .23598 .53487 L .23373 .53532 L F
.831 .95 .601 r
.31735 .61741 m .31515 .62101 L .31567 .6194 L F
.31735 .61741 m .31567 .6194 L .31602 .61869 L F
.966 .921 .587 r
.31735 .61741 m .31585 .61885 L .31689 .61559 L F
.187 0 0 r
.31999 .61951 m .31756 .62171 L .31604 .62172 L F
.211 .575 .941 r
.31604 .62172 m .31739 .62108 L .31628 .61947 L F
.31589 .61945 m .31628 .61947 L .31585 .61885 L F
.31604 .62172 m .31628 .61947 L .31589 .61945 L F
.04 0 .392 r
.31735 .61597 m .31644 .61948 L .3187 .6171 L F
.31644 .61948 m .31627 .62012 L .31677 .6195 L F
.31644 .61948 m .31677 .6195 L .3187 .6171 L F
.31689 .61559 m .31664 .61742 L .31735 .61597 L F
.449 .248 .514 r
.31739 .62108 m .31627 .62012 L .31585 .61885 L F
.04 0 .392 r
.31664 .61742 m .31627 .62012 L .31735 .61597 L F
.831 .95 .601 r
.31602 .61869 m .31567 .6194 L .31585 .61885 L F
.702 .701 .846 r
.37943 .63354 m .37609 .63543 L .37463 .63235 L F
.576 .71 .934 r
.3255 .67034 m .32657 .66739 L .32358 .66785 L F
.3255 .67034 m .32779 .67002 L .32657 .66739 L F
.34 .283 .647 r
.21735 .59776 m .21732 .60127 L .2156 .6013 L F
.752 .995 .842 r
.3062 .62748 m .30195 .63016 L .30502 .6291 L F
.52 .517 .792 r
.3062 .62748 m .30887 .62893 L .30822 .62644 L F
0 0 0 r
.26782 .62239 m .26785 .62324 L .27018 .61992 L F
.27057 .61963 m .26782 .62239 L .27018 .61992 L F
.27057 .61963 m .26866 .6209 L .26782 .62239 L F
.706 .824 .938 r
.34398 .67506 m .34591 .67641 L .34191 .67617 L F
.684 .82 .948 r
.34868 .67562 m .34591 .67641 L .34398 .67506 L F
.667 .344 .416 r
.26963 .55656 m .27379 .55455 L .26991 .55512 L F
.26963 .55656 m .27311 .55696 L .27379 .55455 L F
.473 .158 .35 r
.27379 .55455 m .27311 .55696 L .27577 .55613 L F
.607 .487 .69 r
.27379 .55455 m .27624 .55447 L .27628 .55216 L F
.517 .14 .265 r
.27379 .55455 m .27577 .55613 L .27624 .55447 L F
.174 .025 .425 r
.18365 .5733 m .18508 .57253 L .18533 .5699 L F
.368 .24 .573 r
.18336 .5759 m .18508 .57253 L .18365 .5733 L F
.181 0 0 r
.24908 .77989 m .25114 .78015 L .24713 .77951 L F
.24713 .77951 m .25114 .78015 L .24908 .77989 L F
.6 .922 .97 r
.24908 .77989 m .25114 .78015 L .25175 .77867 L F
.25175 .77867 m .25114 .78015 L .24908 .77989 L F
.795 .999 .807 r
.28925 .63861 m .29176 .63627 L .28935 .63721 L F
.531 .154 .272 r
.34184 .58214 m .33779 .58422 L .33862 .58335 L F
.404 .164 .433 r
.30874 .54106 m .31175 .53782 L .30947 .53893 L F
.30874 .54106 m .31175 .53782 L .30947 .53893 L F
.447 .16 .383 r
.33017 .55701 m .32893 .56034 L .32653 .5608 L F
.448 .159 .38 r
.33189 .55668 m .32893 .56034 L .33017 .55701 L F
0 0 0 r
.37422 .65524 m .37047 .65649 L .36936 .65662 L F
.477 .891 .784 r
.37543 .65419 m .37422 .65524 L .37565 .65372 L F
.37543 .65419 m .37047 .65649 L .37422 .65524 L F
.332 .273 .639 r
.182 .58258 m .18349 .57861 L .18129 .58015 L F
.939 .965 .73 r
.32971 .54727 m .3286 .55101 L .32813 .54838 L F
.32971 .54727 m .32796 .55095 L .3286 .55101 L F
.694 .358 .403 r
.32466 .55252 m .3286 .55101 L .32796 .55095 L F
.447 .158 .379 r
.32911 .57011 m .33156 .56962 L .33238 .56738 L F
.017 0 .162 r
.33238 .56738 m .33156 .56962 L .33389 .56629 L F
.551 0 0 r
.29586 .64364 m .29319 .64198 L .2912 .64172 L F
.202 0 0 r
.22164 .54062 m .21976 .54289 L .22317 .54107 L F
.861 .923 .868 r
.35752 .67033 m .35314 .67208 L .35553 .67085 L F
0 0 0 r
.35972 .6671 m .35752 .67033 L .35848 .66947 L F
.444 .875 .79 r
.35848 .66947 m .35752 .67033 L .35553 .67085 L F
.365 0 .199 r
.37703 .61599 m .37394 .61676 L .37563 .61484 L F
0 0 .122 r
.31839 .57673 m .32001 .57557 L .32029 .57367 L F
.016 0 .194 r
.31839 .57673 m .31914 .57727 L .32001 .57557 L F
.31839 .57673 m .31742 .57917 L .31914 .57727 L F
0 0 0 r
.28597 .60047 m .28442 .60468 L .28584 .60313 L F
.043 .004 .482 r
.28442 .60468 m .28617 .60627 L .28584 .60313 L F
.28442 .60468 m .28471 .6074 L .28617 .60627 L F
0 0 .511 r
.39411 .53759 m .39363 .53954 L .39275 .53511 L F
.037 .327 .811 r
.39538 .53932 m .39363 .53954 L .39411 .53759 L F
.39538 .53932 m .39443 .53991 L .39363 .53954 L F
.333 .619 .955 r
.39703 .56697 m .39786 .56539 L .39588 .56532 L F
.653 .831 .415 r
.39703 .56697 m .39574 .56889 L .39786 .56539 L F
.094 0 .164 r
.28471 .6074 m .28312 .60865 L .2821 .61053 L F
.988 .762 .508 r
.31807 .53551 m .31688 .53166 L .32133 .53238 L F
.391 .251 .568 r
.3232 .5311 m .32333 .53404 L .32133 .53238 L F
.2 .539 .926 r
.32333 .53404 m .32322 .53499 L .32133 .53238 L F
.506 .449 .727 r
.29815 .5661 m .29846 .57022 L .2969 .57034 L F
.633 .466 .639 r
.29846 .57022 m .29641 .57293 L .2969 .57034 L F
.53 .331 .556 r
.36363 .65438 m .36097 .65752 L .36242 .65628 L F
.528 .54 .811 r
.33241 .54121 m .32929 .53901 L .33104 .5381 L F
0 0 0 r
.28808 .59177 m .28616 .59526 L .2866 .59482 L F
.337 .098 .397 r
.28808 .59177 m .2866 .59482 L .28934 .5937 L F
.546 .158 .257 r
.28808 .59177 m .28934 .5937 L .29142 .5921 L F
.393 .842 .75 r
.27106 .52713 m .27101 .5268 L .27328 .52622 L F
.27106 .52713 m .2689 .52783 L .27101 .5268 L F
.548 .489 .741 r
.34557 .57556 m .34382 .57915 L .34418 .57636 L F
.337 .667 .975 r
.19564 .6025 m .19635 .60113 L .19446 .60075 L F
.19564 .6025 m .19938 .60323 L .19635 .60113 L F
.398 .365 .706 r
.18331 .58873 m .1838 .59248 L .186 .59109 L F
.283 .171 .545 r
.18364 .59484 m .186 .59109 L .1838 .59248 L F
.194 .016 .398 r
.28616 .59526 m .28717 .59704 L .2866 .59482 L F
.28616 .59526 m .2857 .59786 L .28717 .59704 L F
0 0 0 r
.38091 .67063 m .37874 .67236 L .37729 .67285 L F
.045 .186 .688 r
.38186 .66965 m .38091 .67063 L .37965 .66677 L F
.135 0 0 r
.38122 .67167 m .38091 .67063 L .38186 .66965 L F
.38122 .67167 m .37874 .67236 L .38091 .67063 L F
.142 0 .223 r
.31999 .61951 m .32257 .61646 L .32176 .61912 L F
0 0 0 r
.32176 .61912 m .31756 .62171 L .31999 .61951 L F
.658 .302 .356 r
.29889 .55119 m .29519 .55282 L .29554 .55183 L F
.579 .41 .617 r
.30097 .57626 m .29833 .57943 L .3011 .57894 L F
0 0 0 r
.29802 .58119 m .3011 .57894 L .29833 .57943 L F
.579 .41 .617 r
.3011 .57894 m .29833 .57943 L .30097 .57626 L F
.524 .33 .559 r
.37353 .63954 m .37108 .64267 L .37178 .63958 L F
.401 .567 .902 r
.37108 .64267 m .37455 .64326 L .37242 .64165 L F
.74 .654 .764 r
.3582 .55958 m .36203 .5645 L .35616 .56336 L F
.053 .165 .663 r
.3584 .56587 m .35616 .56336 L .36203 .5645 L F
.58 .741 .953 r
.25294 .62359 m .24904 .62251 L .25117 .62238 L F
.611 .829 .984 r
.25523 .62274 m .25294 .62359 L .25117 .62238 L F
.895 .578 .44 r
.34479 .68597 m .34281 .68581 L .34158 .68252 L F
.856 .47 .314 r
.34479 .68597 m .34308 .68762 L .34281 .68581 L F
.431 .417 .743 r
.32749 .5942 m .32428 .59209 L .32737 .59183 L F
.854 .466 .312 r
.34479 .68597 m .34552 .68852 L .34308 .68762 L F
.798 .432 .364 r
.34869 .68892 m .34479 .68597 L .34867 .68579 L F
.34869 .68892 m .34552 .68852 L .34479 .68597 L F
.834 .861 .865 r
.31984 .60406 m .32338 .60175 L .32139 .60056 L F
.302 .699 .977 r
.32139 .60056 m .32338 .60175 L .32369 .60037 L F
.468 .407 .705 r
.40264 .56928 m .40063 .57008 L .39957 .56628 L F
.826 .954 .612 r
.35588 .53442 m .35502 .53612 L .35709 .53284 L F
.32 .286 .663 r
.34733 .53073 m .34682 .53352 L .34655 .53465 L F
.502 .772 .992 r
.34655 .53465 m .34806 .53609 L .34628 .53577 L F
0 0 0 r
.34806 .53609 m .3441 .53785 L .34423 .53541 L F
.34806 .53609 m .34612 .53728 L .3441 .53785 L F
.987 .787 .55 r
.34655 .53465 m .34612 .53728 L .34806 .53609 L F
.32 .286 .663 r
.34682 .53352 m .34612 .53728 L .34655 .53465 L F
.502 .772 .992 r
.34655 .53465 m .34628 .53577 L .34423 .53541 L F
.319 .141 .476 r
.34423 .53541 m .3441 .53785 L .34221 .53869 L F
.152 0 .392 r
.29435 .62793 m .29248 .6264 L .29394 .62571 L F
.29435 .62793 m .2922 .62945 L .29248 .6264 L F
.176 0 0 r
.2441 .55109 m .24682 .55147 L .24258 .55093 L F
.797 .962 .645 r
.36591 .60452 m .36436 .60682 L .36538 .60726 L F
.427 .316 .624 r
.36436 .60682 m .36583 .60935 L .36538 .60726 L F
.36436 .60682 m .36407 .61096 L .36583 .60935 L F
.007 .241 .749 r
.30874 .54106 m .31063 .54512 L .31108 .54314 L F
.197 0 .208 r
.28562 .54848 m .28566 .5501 L .28751 .54757 L F
.715 .544 .657 r
.35079 .68607 m .34869 .68892 L .34867 .68579 L F
.319 0 .168 r
.18787 .56673 m .19012 .56615 L .19091 .5645 L F
.469 .162 .362 r
.19012 .56615 m .19329 .56361 L .19091 .5645 L F
0 0 0 r
.34629 .51383 m .34465 .51417 L .3427 .51451 L F
.651 .103 0 r
.34629 .51383 m .34667 .51509 L .34465 .51417 L F
.388 .351 .696 r
.31903 .5959 m .32127 .59775 L .31995 .59429 L F
.328 .799 .922 r
.28585 .52538 m .28823 .52494 L .29032 .52527 L F
.529 .9 .964 r
.29032 .52527 m .29077 .52399 L .29241 .52511 L F
.29032 .52527 m .28823 .52494 L .29077 .52399 L F
.701 .507 .623 r
.37618 .55823 m .37932 .5605 L .37762 .55694 L F
.37618 .55823 m .37649 .56058 L .37932 .5605 L F
.38 .789 .981 r
.24253 .63107 m .23671 .63027 L .24136 .63203 L F
0 0 0 r
.2761 .62936 m .27408 .63015 L .27262 .63129 L F
.36578 .61722 m .36122 .61988 L .36453 .61635 L F
.993 .743 .422 r
.36471 .61355 m .36578 .61722 L .36453 .61635 L F
.612 .674 .884 r
.3782 .61975 m .3749 .62083 L .37666 .61697 L F
.489 .276 .516 r
.3782 .61975 m .37574 .62271 L .3749 .62083 L F
.381 .157 .444 r
.33724 .64134 m .33515 .64212 L .33461 .64462 L F
.321 .275 .65 r
.21453 .57204 m .21228 .57069 L .21487 .56984 L F
.21453 .57204 m .2125 .57325 L .21228 .57069 L F
.546 .801 .992 r
.20646 .58772 m .20646 .58979 L .20447 .588 L F
.20646 .58772 m .20883 .58921 L .20646 .58979 L F
.207 .186 .613 r
.28566 .5501 m .28928 .55229 L .28801 .55055 L F
.307 .504 .886 r
.28928 .55229 m .28967 .54957 L .28801 .55055 L F
.28928 .55229 m .2913 .55213 L .28967 .54957 L F
.149 0 .039 r
.19597 .56029 m .19783 .55966 L .19911 .55743 L F
.428 .174 .425 r
.19783 .55966 m .2008 .55647 L .19911 .55743 L F
.775 .558 .605 r
.31807 .53551 m .31534 .53948 L .31475 .53515 L F
.265 .737 .942 r
.31475 .53515 m .31655 .5349 L .31807 .53551 L F
.988 .762 .508 r
.31807 .53551 m .31655 .5349 L .31688 .53166 L F
.372 0 0 r
.36849 .58003 m .37261 .57886 L .37067 .57997 L F
0 .062 .577 r
.3926 .55603 m .39123 .55517 L .39434 .55411 L F
.965 .697 .477 r
.39434 .55411 m .39434 .55725 L .3926 .55603 L F
0 0 0 r
.29802 .58119 m .29911 .58067 L .3011 .57894 L F
.965 .73 .534 r
.25266 .75088 m .25497 .75175 L .25423 .75295 L F
.806 .957 .625 r
.25516 .75034 m .25497 .75175 L .25681 .74879 L F
.803 .893 .477 r
.25423 .75295 m .25497 .75175 L .25516 .75034 L F
.407 0 0 r
.29768 .67579 m .29997 .67716 L .29808 .67596 L F
.29768 .67579 m .29997 .67716 L .29808 .67596 L F
.5 .392 .664 r
.37461 .58523 m .37707 .5851 L .37684 .58131 L F
.502 .327 .576 r
.37461 .58523 m .37712 .58783 L .37707 .5851 L F
.37461 .58523 m .37488 .5887 L .37712 .58783 L F
.409 .496 .837 r
.37548 .53059 m .37687 .52793 L .37427 .52862 L F
.52 0 0 r
.30078 .64545 m .30306 .64482 L .30004 .64447 L F
0 0 0 r
.30552 .64448 m .30306 .64482 L .30078 .64545 L F
.655 .166 0 r
.35825 .63211 m .35728 .63137 L .35741 .63106 L F
.248 .287 .706 r
.35675 .62548 m .35741 .63106 L .35917 .62824 L F
.604 .663 .881 r
.35825 .63211 m .35917 .62824 L .35741 .63106 L F
0 0 .444 r
.39596 .54098 m .39791 .54439 L .39681 .54267 L F
0 .15 .683 r
.36156 .51964 m .36208 .51825 L .35891 .51733 L F
.36156 .51964 m .36271 .52036 L .36208 .51825 L F
.122 0 .301 r
.27166 .6257 m .26958 .62904 L .2702 .62671 L F
.332 .273 .639 r
.182 .58258 m .18359 .58199 L .18349 .57861 L F
.353 .293 .65 r
.18245 .5852 m .18359 .58199 L .182 .58258 L F
.318 0 .128 r
.35719 .56776 m .35698 .56911 L .35459 .56968 L F
.053 .165 .663 r
.3584 .56587 m .35719 .56776 L .35616 .56336 L F
0 0 0 r
.35772 .56745 m .35719 .56776 L .3584 .56587 L F
.35772 .56745 m .35698 .56911 L .35719 .56776 L F
.984 .901 .643 r
.35622 .5736 m .35362 .57531 L .35515 .57273 L F
.885 .964 .841 r
.35515 .57273 m .35622 .5736 L .35886 .57034 L F
.984 .901 .643 r
.35622 .5736 m .35362 .57531 L .35515 .57273 L F
.306 0 .125 r
.26595 .54772 m .26428 .55027 L .26196 .55084 L F
.355 0 .036 r
.2684 .54795 m .26428 .55027 L .26595 .54772 L F
.301 .796 .8 r
.25291 .53002 m .24724 .53129 L .24956 .53069 L F
.286 0 0 r
.32161 .52244 m .32479 .52194 L .3219 .52257 L F
.32161 .52244 m .32272 .5227 L .32479 .52194 L F
.851 .996 .761 r
.32479 .52194 m .32568 .51868 L .32698 .52102 L F
.32479 .52194 m .32272 .5227 L .32568 .51868 L F
0 .135 .621 r
.32681 .60516 m .32758 .60569 L .32774 .60614 L F
.509 .489 .77 r
.32926 .60653 m .33045 .60263 L .32774 .60614 L F
.075 0 0 r
.36093 .58425 m .35812 .58397 L .35786 .58462 L F
.542 .756 .976 r
.36276 .53709 m .36512 .53882 L .36267 .5385 L F
.684 .795 .933 r
.36669 .53665 m .36512 .53882 L .36276 .53709 L F
.542 .756 .976 r
.36276 .53709 m .36267 .5385 L .36052 .53818 L F
.868 .654 .611 r
.36267 .5385 m .36225 .54114 L .36052 .53818 L F
.489 .251 .48 r
.35738 .57936 m .35951 .58145 L .35984 .57903 L F
.35738 .57936 m .35697 .58232 L .35951 .58145 L F
.659 .126 0 r
.25743 .62335 m .26125 .62491 L .25907 .62387 L F
0 0 0 r
.32775 .53285 m .32647 .53455 L .3296 .53179 L F
.733 .296 .212 r
.31626 .64833 m .31981 .64886 L .31985 .65005 L F
.177 .614 .941 r
.25672 .75388 m .25852 .75514 L .25614 .75438 L F
.25614 .75438 m .25852 .75514 L .25672 .75388 L F
.079 0 .122 r
.21453 .57204 m .21139 .57496 L .2125 .57325 L F
.292 .303 .7 r
.18331 .58873 m .18412 .58461 L .18245 .5852 L F
.18331 .58873 m .18473 .58836 L .18412 .58461 L F
.304 .353 .748 r
.18331 .58873 m .186 .59109 L .18473 .58836 L F
.442 .516 .839 r
.32304 .57599 m .32029 .57367 L .32281 .57246 L F
0 0 .133 r
.32029 .57367 m .32153 .57411 L .32281 .57246 L F
.32029 .57367 m .32001 .57557 L .32153 .57411 L F
.108 0 0 r
.24682 .55147 m .24255 .55348 L .24258 .55093 L F
.24682 .55147 m .24487 .55296 L .24255 .55348 L F
.132 0 0 r
.24892 .55119 m .24487 .55296 L .24682 .55147 L F
.632 .254 .309 r
.36897 .54241 m .36809 .54461 L .36448 .54362 L F
.454 .077 .234 r
.37059 .54347 m .36897 .54241 L .37103 .54132 L F
.37059 .54347 m .36809 .54461 L .36897 .54241 L F
.665 .698 .871 r
.36354 .65709 m .36496 .65974 L .36804 .65825 L F
.568 .22 .337 r
.26684 .55643 m .26963 .55656 L .26991 .55512 L F
.529 .869 .608 r
.21261 .589 m .21359 .58792 L .21463 .58869 L F
.21261 .589 m .21059 .59052 L .21359 .58792 L F
.306 .276 .66 r
.35308 .61271 m .35128 .61115 L .35367 .61033 L F
.35308 .61271 m .3519 .61419 L .35128 .61115 L F
.405 .357 .691 r
.32799 .62695 m .33071 .6287 L .32997 .62502 L F
.321 .367 .754 r
.32799 .62695 m .32924 .62922 L .33071 .6287 L F
.772 .418 .386 r
.28718 .64082 m .28925 .63861 L .28935 .63721 L F
.579 .41 .617 r
.30097 .57626 m .3011 .57894 L .29922 .57417 L F
.807 .762 .812 r
.30354 .57356 m .30097 .57626 L .29922 .57417 L F
0 0 .293 r
.71821 .33545 m .71908 .33469 L .72136 .33471 L F
.69 .559 .702 r
.72136 .33471 m .71832 .33807 L .71821 .33545 L F
0 0 .293 r
.71821 .33545 m .71832 .33807 L .71908 .33469 L F
.29 .669 .972 r
.20743 .61152 m .20789 .61034 L .20651 .60972 L F
.20743 .61152 m .21051 .61144 L .20789 .61034 L F
.995 .784 .505 r
.34183 .62888 m .343 .6329 L .34202 .63118 L F
.999 .835 .507 r
.34202 .63118 m .343 .6329 L .34231 .63327 L F
.88 .811 .777 r
.35698 .56911 m .35886 .57034 L .36096 .56684 L F
.361 .65 .966 r
.36096 .56684 m .36466 .56789 L .36291 .56664 L F
.54 .813 .996 r
.26088 .75443 m .25852 .75514 L .25672 .75388 L F
.25672 .75388 m .25852 .75514 L .26088 .75443 L F
.333 .625 .958 r
.24539 .54504 m .24759 .54489 L .24597 .54323 L F
.24539 .54504 m .24759 .54489 L .24597 .54323 L F
.607 .493 .698 r
.31785 .6104 m .31997 .60748 L .31773 .60771 L F
0 0 0 r
.32911 .57011 m .32963 .57103 L .33156 .56962 L F
.992 .801 .425 r
.32911 .57011 m .32884 .57185 L .3283 .57284 L F
.32884 .57185 m .32861 .57336 L .3283 .57284 L F
.381 .513 .866 r
.32861 .57336 m .32963 .57103 L .3283 .57284 L F
.188 0 0 r
.32976 .57247 m .32769 .57397 L .3283 .57284 L F
.32769 .57397 m .32723 .5743 L .3283 .57284 L F
0 0 0 r
.32911 .57011 m .3283 .57284 L .32963 .57103 L F
.671 .775 .928 r
.32647 .53455 m .32512 .53599 L .32333 .53404 L F
.956 .736 .564 r
.37694 .64691 m .37883 .64847 L .37739 .64476 L F
0 .13 .67 r
.37883 .64847 m .37948 .64726 L .37739 .64476 L F
.46 .829 .992 r
.38128 .64797 m .37948 .64726 L .37883 .64847 L F
.07 .007 .47 r
.3821 .61213 m .3805 .61072 L .38138 .60997 L F
.3821 .61213 m .38048 .61403 L .3805 .61072 L F
.313 .545 .914 r
.35101 .51027 m .35505 .51313 L .35267 .51374 L F
.781 .353 .235 r
.35221 .51518 m .35093 .51523 L .35267 .51374 L F
.712 .474 .563 r
.36225 .54114 m .35814 .53878 L .36052 .53818 L F
.1 0 0 r
.35814 .53878 m .35879 .53968 L .36052 .53818 L F
.781 .353 .235 r
.35221 .51518 m .35093 .51523 L .35267 .51374 L F
0 .077 .595 r
.31515 .62101 m .31604 .62172 L .31585 .61885 L F
.122 .057 .504 r
.31515 .62101 m .31501 .62357 L .31604 .62172 L F
.31515 .62101 m .31501 .62357 L .31604 .62172 L F
.74 .66 .771 r
.36538 .60726 m .37078 .60857 L .36832 .60357 L F
.603 .18 .211 r
.36583 .60935 m .37078 .60857 L .36538 .60726 L F
.36583 .60935 m .37095 .60989 L .37078 .60857 L F
.482 .512 .812 r
.37078 .60857 m .37056 .60266 L .36832 .60357 L F
.37078 .60857 m .37279 .60771 L .37056 .60266 L F
0 0 .211 r
.37078 .60857 m .37156 .60929 L .37279 .60771 L F
.37078 .60857 m .37095 .60989 L .37156 .60929 L F
.703 .984 .872 r
.35735 .51639 m .35657 .51814 L .35891 .51733 L F
.35735 .51639 m .354 .51862 L .35657 .51814 L F
.684 .82 .948 r
.34868 .67562 m .34398 .67506 L .34657 .67281 L F
.758 .792 .881 r
.35084 .67304 m .34868 .67562 L .34657 .67281 L F
.642 .654 .847 r
.35236 .67652 m .34868 .67562 L .35084 .67304 L F
.485 .286 .534 r
.37071 .62921 m .36823 .62981 L .37073 .62639 L F
.503 .334 .584 r
.37315 .62316 m .37073 .62639 L .36941 .62288 L F
.37315 .62316 m .37314 .62594 L .37073 .62639 L F
.49 .29 .535 r
.37314 .62594 m .37071 .62921 L .37073 .62639 L F
.658 .302 .356 r
.29889 .55119 m .29762 .55356 L .29519 .55282 L F
.511 .418 .686 r
.30077 .54731 m .30131 .55085 L .29889 .55119 L F
.698 .473 .577 r
.30131 .55085 m .29762 .55356 L .29889 .55119 L F
.989 .865 .618 r
.35308 .53706 m .35502 .53612 L .35588 .53442 L F
.35308 .53706 m .35414 .53828 L .35502 .53612 L F
.741 .879 .944 r
.30902 .52336 m .30542 .52382 L .3078 .52298 L F
.593 .924 .965 r
.30902 .52336 m .31001 .52185 L .31143 .52288 L F
.30902 .52336 m .3078 .52298 L .31001 .52185 L F
.509 .585 .867 r
.31188 .52485 m .30902 .52336 L .31143 .52288 L F
.755 .713 .178 r
.35821 .54426 m .35777 .54654 L .35766 .54794 L F
.823 .382 0 r
.35721 .54884 m .35899 .55068 L .35766 .54794 L F
.249 .023 .362 r
.35965 .54752 m .35733 .54877 L .35777 .54654 L F
.35733 .54877 m .35721 .54884 L .35777 .54654 L F
.755 .713 .178 r
.35824 .54406 m .35777 .54654 L .35821 .54426 L F
.561 .321 .509 r
.38945 .63545 m .38881 .63833 L .38607 .63858 L F
0 .305 .799 r
.38707 .6323 m .38975 .63419 L .38945 .63545 L F
1 .816 .514 r
.38822 .63369 m .38945 .63545 L .38975 .63419 L F
.38822 .63369 m .38881 .63833 L .38945 .63545 L F
.427 .066 .248 r
.25776 .5484 m .26173 .54494 L .2564 .54549 L F
.25776 .5484 m .25994 .54801 L .26173 .54494 L F
.426 .07 .256 r
.25994 .54801 m .26418 .54442 L .26173 .54494 L F
.789 .428 .372 r
.32551 .63518 m .32476 .63271 L .32181 .6319 L F
.32551 .63518 m .32577 .63513 L .32476 .63271 L F
.543 .688 .933 r
.22452 .61387 m .22178 .61219 L .22157 .61212 L F
.609 .773 .959 r
.22684 .613 m .22452 .61387 L .22188 .61231 L F
.22189 .61218 m .22188 .61231 L .22157 .61212 L F
.22684 .613 m .22188 .61231 L .22189 .61218 L F
0 0 .204 r
.22193 .61708 m .22223 .61583 L .22185 .61274 L F
.22181 .61319 m .22185 .61274 L .22178 .61219 L F
.22193 .61708 m .22185 .61274 L .22181 .61319 L F
0 .251 .763 r
.22193 .61708 m .22432 .61905 L .22223 .61583 L F
.176 .023 .421 r
.3808 .55446 m .38274 .55342 L .38322 .55064 L F
.401 .125 .377 r
.3799 .55624 m .38274 .55342 L .3808 .55446 L F
.905 .966 .651 r
.31563 .56744 m .31383 .57098 L .31571 .56922 L F
0 0 0 r
.32502 .61367 m .32378 .61555 L .32257 .61646 L F
.32378 .61555 m .32176 .61912 L .32257 .61646 L F
.283 .171 .545 r
.18364 .59484 m .18527 .59474 L .186 .59109 L F
.205 .07 .465 r
.18364 .59484 m .18592 .59568 L .18527 .59474 L F
.18364 .59484 m .18369 .59836 L .18592 .59568 L F
.569 .904 .667 r
.2821 .61053 m .28015 .61218 L .27893 .61312 L F
.807 .762 .812 r
.30354 .57356 m .29922 .57417 L .30177 .57514 L F
.168 0 0 r
.30177 .57514 m .30629 .57296 L .30354 .57356 L F
.498 .808 1 r
.27759 .52532 m .27725 .52696 L .27547 .52563 L F
.27759 .52532 m .27958 .52648 L .27725 .52696 L F
.4 .844 .931 r
.33769 .62314 m .3337 .62356 L .33603 .62272 L F
.55 .897 .978 r
.33834 .62206 m .33769 .62314 L .33603 .62272 L F
0 0 .332 r
.33845 .62437 m .33769 .62314 L .33834 .62206 L F
.33845 .62437 m .3384 .62597 L .33769 .62314 L F
0 0 .431 r
.34257 .62556 m .34137 .62639 L .34183 .62888 L F
.203 0 .356 r
.29007 .54146 m .28952 .54437 L .28875 .54444 L F
.683 .513 .65 r
.29263 .54073 m .28952 .54437 L .29007 .54146 L F
.691 .475 .59 r
.38248 .63795 m .37849 .64081 L .37991 .63885 L F
0 .062 .577 r
.3926 .55603 m .3916 .55798 L .39123 .55517 L F
.582 .809 .986 r
.39434 .55725 m .3916 .55798 L .3926 .55603 L F
.172 .189 .637 r
.34425 .61085 m .3446 .61467 L .34622 .61235 L F
.3 .363 .761 r
.3446 .61467 m .34727 .61589 L .34622 .61235 L F
.471 0 0 r
.35375 .63416 m .35502 .63334 L .3515 .63204 L F
.35375 .63416 m .35568 .63402 L .35502 .63334 L F
.551 .4 .629 r
.35814 .55392 m .35816 .55705 L .35568 .55704 L F
.581 .462 .682 r
.3582 .55958 m .35568 .55704 L .35816 .55705 L F
.3582 .55958 m .35594 .56017 L .35568 .55704 L F
.392 .51 .859 r
.21786 .59034 m .21628 .59214 L .21463 .58869 L F
.267 .322 .734 r
.21786 .59034 m .2187 .5941 L .21628 .59214 L F
.39 .328 .667 r
.21628 .59214 m .2187 .5941 L .21687 .59465 L F
.666 .873 .497 r
.36383 .52123 m .36479 .51957 L .36271 .52036 L F
.36383 .52123 m .36395 .52102 L .36479 .51957 L F
.188 .12 .543 r
.23607 .55316 m .23459 .55624 L .23484 .55534 L F
.23607 .55316 m .23633 .55676 L .23459 .55624 L F
.272 0 .177 r
.23633 .55676 m .23329 .55911 L .23459 .55624 L F
.059 0 0 r
.37402 .61275 m .37535 .61236 L .37747 .61014 L F
0 .335 .811 r
.37747 .61014 m .37747 .6091 L .37506 .60769 L F
.806 .953 .614 r
.37747 .61014 m .37535 .61236 L .37747 .6091 L F
.513 .488 .767 r
.29055 .57329 m .29343 .57379 L .29125 .56973 L F
.244 .752 .876 r
.27958 .52648 m .28206 .52615 L .28363 .52635 L F
.457 .875 .937 r
.28363 .52635 m .28439 .52537 L .28585 .52538 L F
.28363 .52635 m .28206 .52615 L .28439 .52537 L F
.309 .784 .924 r
.25811 .63425 m .25863 .63344 L .25615 .63387 L F
.25811 .63425 m .26085 .63378 L .25863 .63344 L F
.583 .43 .639 r
.32479 .55507 m .32466 .55252 L .32472 .55244 L F
.694 .358 .403 r
.32466 .55252 m .33094 .55323 L .33145 .55129 L F
.565 .232 .364 r
.33094 .55323 m .33357 .55319 L .33145 .55129 L F
.475 .248 .49 r
.33145 .55129 m .33357 .55319 L .33383 .5507 L F
.272 .178 .561 r
.38949 .67558 m .39007 .67861 L .38823 .67658 L F
.216 .168 .586 r
.38823 .67658 m .39007 .67861 L .38857 .6794 L F
.266 .23 .631 r
.36407 .61096 m .3663 .61271 L .36583 .60935 L F
.36407 .61096 m .36471 .61355 L .3663 .61271 L F
.687 .592 .743 r
.31806 .62884 m .32181 .6319 L .32146 .63026 L F
.564 .604 .852 r
.29452 .57634 m .29526 .57218 L .29343 .57379 L F
.521 .396 .65 r
.29641 .57293 m .29686 .57578 L .29452 .57634 L F
.564 .604 .852 r
.29452 .57634 m .29686 .57578 L .29526 .57218 L F
.396 .839 .937 r
.26931 .53624 m .26827 .536 L .26591 .53665 L F
.434 .825 .985 r
.27169 .53595 m .26827 .536 L .26931 .53624 L F
.562 .602 .851 r
.26931 .53624 m .27242 .53678 L .27169 .53595 L F
.487 .782 .997 r
.27902 .64357 m .28008 .64479 L .28243 .64423 L F
.621 .426 .597 r
.37523 .57302 m .37838 .57318 L .37853 .56997 L F
0 0 .571 r
.37853 .56997 m .38004 .57193 L .37856 .56827 L F
.281 .148 .516 r
.37853 .56997 m .37838 .57318 L .38004 .57193 L F
.658 .452 .593 r
.40063 .57008 m .40079 .57271 L .39871 .57271 L F
.458 .32 .604 r
.40264 .56928 m .40079 .57271 L .40063 .57008 L F
.597 .199 .258 r
.28434 .62793 m .28722 .62809 L .28847 .62533 L F
.24 0 .099 r
.28847 .62533 m .28722 .62809 L .28951 .62739 L F
0 0 0 r
.24266 .53293 m .23838 .5346 L .24045 .53351 L F
.318 .806 .807 r
.24259 .53253 m .24266 .53293 L .24045 .53351 L F
.24259 .53253 m .24499 .5322 L .24266 .53293 L F
.215 .588 .946 r
.26788 .63673 m .2723 .63881 L .27084 .63737 L F
0 .177 .669 r
.2723 .63881 m .27353 .63933 L .27084 .63737 L F
.2723 .63881 m .27484 .64076 L .27353 .63933 L F
.484 0 0 r
.30802 .64499 m .30966 .64449 L .30552 .64448 L F
.348 0 0 r
.30996 .64558 m .30966 .64449 L .30802 .64499 L F
.30996 .64558 m .31194 .64487 L .30966 .64449 L F
0 0 .523 r
.39791 .54439 m .39943 .54699 L .39898 .54812 L F
0 0 .437 r
.40072 .54884 m .39898 .54812 L .39943 .54699 L F
.40072 .54884 m .39914 .55075 L .39898 .54812 L F
.431 0 0 r
.25288 .55198 m .25115 .55224 L .24892 .55119 L F
.493 0 0 r
.25493 .55229 m .25115 .55224 L .25288 .55198 L F
.885 .964 .841 r
.35515 .57273 m .35886 .57034 L .35698 .56911 L F
.249 .282 .7 r
.32716 .64394 m .32551 .64532 L .32485 .6418 L F
.195 .141 .565 r
.32782 .64697 m .32551 .64532 L .32716 .64394 L F
.32782 .64697 m .32583 .64784 L .32551 .64532 L F
.814 .91 .906 r
.39066 .67325 m .39198 .67014 L .39314 .67283 L F
.361 .033 .268 r
.39314 .67283 m .38949 .67558 L .39066 .67325 L F
.684 .343 .391 r
.21771 .57014 m .21701 .57219 L .21487 .56984 L F
0 0 .28 r
.21926 .56611 m .21903 .56895 L .21771 .57014 L F
.085 .164 .65 r
.21903 .56895 m .21973 .57177 L .21771 .57014 L F
.457 .119 .304 r
.21771 .57014 m .21973 .57177 L .21701 .57219 L F
.512 .32 .558 r
.39871 .57271 m .39848 .57673 L .39615 .57478 L F
0 .06 .613 r
.39818 .5785 m .39615 .57478 L .39848 .57673 L F
.232 0 0 r
.23476 .63204 m .23335 .63236 L .23091 .63213 L F
0 0 .061 r
.23562 .63033 m .23584 .63142 L .23476 .63204 L F
.331 .81 .763 r
.23584 .63142 m .23335 .63236 L .23476 .63204 L F
.326 .07 .364 r
.29454 .60739 m .29714 .60426 L .29633 .60671 L F
0 0 0 r
.29774 .60517 m .29714 .60426 L .29868 .60326 L F
.29774 .60517 m .29633 .60671 L .29714 .60426 L F
.265 0 0 r
.28108 .6204 m .27919 .62214 L .27679 .62242 L F
0 0 0 r
.28279 .61902 m .28108 .6204 L .28387 .61715 L F
.28147 .62119 m .28108 .6204 L .28279 .61902 L F
.28147 .62119 m .27919 .62214 L .28108 .6204 L F
.687 .343 .386 r
.21487 .56984 m .21701 .57219 L .21453 .57204 L F
.756 .613 .046 r
.33344 .64794 m .33349 .6518 L .33332 .6505 L F
.484 .682 .953 r
.33631 .65374 m .33912 .65365 L .33728 .65218 L F
.33631 .65374 m .33912 .65365 L .33728 .65218 L F
0 0 .092 r
.33689 .65299 m .33631 .65374 L .33728 .65218 L F
.186 .39 .83 r
.3368 .65296 m .33631 .65374 L .33689 .65299 L F
0 0 0 r
.3365 .65343 m .33631 .65374 L .3368 .65296 L F
.186 .39 .83 r
.33349 .6518 m .33631 .65374 L .3368 .65296 L F
0 0 0 r
.3368 .65296 m .33631 .65374 L .33703 .65262 L F
.159 .689 .86 r
.33631 .65374 m .33912 .65365 L .33965 .65392 L F
.33631 .65374 m .33912 .65365 L .33965 .65392 L F
.794 .663 .112 r
.33344 .64794 m .33332 .6505 L .33315 .64919 L F
0 .334 .813 r
.33332 .6505 m .33682 .65294 L .33315 .64919 L F
.33682 .65294 m .33689 .65299 L .33683 .65293 L F
.33682 .65294 m .33683 .65293 L .33315 .64919 L F
0 0 0 r
.33728 .65218 m .3365 .65343 L .33703 .65262 L F
.574 .644 .881 r
.33315 .64919 m .33683 .65293 L .33728 .65218 L F
.33683 .65293 m .33689 .65299 L .33728 .65218 L F
0 0 0 r
.33694 .65276 m .3367 .65313 L .33521 .65577 L F
.3367 .65313 m .33631 .65374 L .33607 .65417 L F
.3367 .65313 m .33607 .65417 L .33521 .65577 L F
.33703 .65262 m .33684 .65291 L .33694 .65276 L F
.33684 .65291 m .33631 .65374 L .33694 .65276 L F
.186 .39 .83 r
.33349 .6518 m .3368 .65296 L .33332 .6505 L F
.3368 .65296 m .33689 .65299 L .33682 .65294 L F
.3368 .65296 m .33682 .65294 L .33332 .6505 L F
.416 .407 .741 r
.33349 .6518 m .33493 .65496 L .33631 .65374 L F
.205 0 0 r
.23845 .55249 m .23723 .55199 L .24128 .55267 L F
.23845 .55249 m .23607 .55316 L .23723 .55199 L F
.502 .048 .106 r
.31835 .52354 m .32019 .52454 L .3219 .52257 L F
.033 0 0 r
.3219 .52257 m .32272 .5227 L .32161 .52244 L F
.3219 .52257 m .3222 .52328 L .32272 .5227 L F
.3219 .52257 m .32019 .52454 L .3222 .52328 L F
.131 .005 .428 r
.32631 .61233 m .32512 .61065 L .32677 .60988 L F
.32631 .61233 m .32502 .61367 L .32512 .61065 L F
.365 0 .196 r
.37729 .67285 m .37624 .67519 L .37405 .67547 L F
.612 .239 .311 r
.38049 .67473 m .37729 .67285 L .37874 .67236 L F
.38049 .67473 m .37624 .67519 L .37729 .67285 L F
.47 0 0 r
.28577 .54138 m .28237 .54121 L .28391 .54082 L F
.754 .762 .86 r
.28441 .53964 m .28237 .54121 L .28577 .54138 L F
.28441 .53964 m .28237 .54121 L .28577 .54138 L F
0 0 .39 r
.28417 .54052 m .28237 .54121 L .28441 .53964 L F
.311 .797 .756 r
.28391 .54082 m .28237 .54121 L .28043 .54195 L F
0 0 .39 r
.28362 .5425 m .28237 .54121 L .28417 .54052 L F
.311 .797 .756 r
.28043 .54195 m .28237 .54121 L .28033 .54198 L F
.539 .283 .475 r
.38115 .68908 m .38075 .69161 L .37808 .69186 L F
.446 .257 .53 r
.38359 .68579 m .38347 .68852 L .38115 .68908 L F
.358 .127 .421 r
.38286 .69085 m .38115 .68908 L .38347 .68852 L F
.38286 .69085 m .38075 .69161 L .38115 .68908 L F
.764 .935 .587 r
.29672 .58306 m .29526 .58506 L .29598 .58306 L F
0 0 .341 r
.3577 .66306 m .35607 .66399 L .35714 .66294 L F
0 0 0 r
.35575 .66492 m .35607 .66399 L .3577 .66306 L F
.74 .66 .771 r
.36538 .60726 m .36832 .60357 L .36591 .60452 L F
.427 .224 .5 r
.34382 .57915 m .34337 .58209 L .34184 .58214 L F
.548 .489 .741 r
.34557 .57556 m .34639 .57885 L .34382 .57915 L F
.552 .334 .537 r
.34609 .58143 m .34382 .57915 L .34639 .57885 L F
.34609 .58143 m .34337 .58209 L .34382 .57915 L F
.353 0 0 r
.26359 .62431 m .26782 .62239 L .26549 .62299 L F
.349 .17 .491 r
.33407 .5637 m .33644 .56497 L .33639 .5637 L F
.33407 .5637 m .33389 .56629 L .33644 .56497 L F
.341 0 0 r
.29884 .52461 m .30086 .52508 L .30266 .52487 L F
.559 .935 .88 r
.30266 .52487 m .30331 .52375 L .30542 .52382 L F
.30266 .52487 m .30086 .52508 L .30331 .52375 L F
.12 .154 .623 r
.3824 .60572 m .38138 .60997 L .38269 .60719 L F
.3824 .60572 m .38265 .60978 L .38138 .60997 L F
.073 0 .32 r
.38265 .60978 m .3821 .61213 L .38138 .60997 L F
.411 .664 .964 r
.32698 .52102 m .32876 .52251 L .32972 .52026 L F
.471 .361 .647 r
.36764 .59825 m .37021 .60036 L .36958 .59783 L F
.36764 .59825 m .36801 .60096 L .37021 .60036 L F
.024 0 0 r
.26624 .54378 m .26984 .54176 L .26733 .54222 L F
.692 .26 .219 r
.23147 .61271 m .2353 .61307 L .23331 .61086 L F
.604 .274 .383 r
.23331 .61086 m .2353 .61307 L .23532 .61128 L F
.531 .154 .272 r
.34184 .58214 m .34037 .58436 L .33779 .58422 L F
.646 .365 .479 r
.34337 .58209 m .34037 .58436 L .34184 .58214 L F
.486 .538 .835 r
.34449 .53054 m .34423 .53541 L .34198 .5306 L F
.34449 .53054 m .34655 .53465 L .34423 .53541 L F
.347 .089 .374 r
.37242 .57622 m .37523 .57302 L .37324 .57386 L F
.657 .851 .974 r
.37037 .66834 m .36598 .66871 L .36882 .66754 L F
.68 .919 .973 r
.37128 .66647 m .37037 .66834 L .36882 .66754 L F
.37128 .66647 m .37278 .66708 L .37037 .66834 L F
.184 .035 .432 r
.20544 .5785 m .20385 .58146 L .20421 .57933 L F
.681 .319 .353 r
.35848 .66947 m .3621 .66913 L .35972 .6671 L F
.818 .943 .907 r
.36065 .66844 m .3621 .66913 L .3606 .66846 L F
.621 .636 .845 r
.36356 .66983 m .35972 .6671 L .3621 .66913 L F
.818 .943 .907 r
.36434 .66682 m .3621 .66913 L .36065 .66844 L F
.621 .636 .845 r
.36367 .66991 m .36356 .66983 L .3621 .66913 L F
.719 .843 .941 r
.36434 .66682 m .36367 .66991 L .3621 .66913 L F
.36434 .66682 m .36598 .66871 L .36367 .66991 L F
0 0 0 r
.27846 .62883 m .28075 .62814 L .28214 .62708 L F
.381 0 0 r
.28075 .62814 m .28434 .62793 L .28214 .62708 L F
.493 .358 .625 r
.38228 .59188 m .38258 .58748 L .38185 .58868 L F
.601 .421 .61 r
.38457 .58537 m .3854 .58837 L .38287 .58859 L F
.459 .26 .522 r
.38296 .58858 m .38228 .59188 L .38287 .58859 L F
.3854 .58837 m .38305 .59102 L .38296 .58858 L F
.38305 .59102 m .38228 .59188 L .38296 .58858 L F
.601 .421 .61 r
.38457 .58537 m .38287 .58859 L .38261 .58774 L F
.192 .169 .602 r
.38678 .58768 m .3854 .58837 L .38457 .58537 L F
.459 .26 .522 r
.3854 .58837 m .3846 .5913 L .38228 .59188 L F
.541 .456 .709 r
.38678 .58768 m .3846 .5913 L .3854 .58837 L F
.3846 .5913 m .38678 .58768 L .38292 .5875 L F
.38295 .58817 m .38292 .5875 L .38258 .58748 L F
.3846 .5913 m .38292 .5875 L .38295 .58817 L F
.493 .358 .625 r
.38228 .59188 m .38309 .59168 L .38278 .5891 L F
.38228 .59188 m .38278 .5891 L .38261 .58774 L F
.38228 .59188 m .38261 .58774 L .38257 .58761 L F
.623 .452 .629 r
.38457 .58537 m .38261 .58774 L .38258 .58748 L F
.493 .358 .625 r
.38309 .59168 m .3846 .5913 L .38258 .58748 L F
.459 .26 .522 r
.38287 .58859 m .38228 .59188 L .38185 .58868 L F
.601 .421 .61 r
.38261 .58774 m .38287 .58859 L .38185 .58868 L F
.493 .358 .625 r
.38257 .58761 m .38261 .58774 L .38258 .58748 L F
.623 .452 .629 r
.38261 .58774 m .38185 .58868 L .38258 .58748 L F
.435 .195 .449 r
.38258 .58748 m .38678 .58768 L .38457 .58537 L F
.288 .455 .852 r
.33733 .55449 m .33906 .5575 L .33998 .55553 L F
.655 .528 .696 r
.37808 .69186 m .37582 .69506 L .37547 .69236 L F
.156 0 .088 r
.29149 .61066 m .29454 .60739 L .29334 .60974 L F
0 0 0 r
.29334 .60974 m .29454 .60739 L .29633 .60671 L F
.803 .594 .62 r
.31015 .62553 m .31347 .62608 L .31501 .62357 L F
.668 .839 .421 r
.31501 .62357 m .31347 .62608 L .31604 .62172 L F
.31501 .62357 m .31347 .62608 L .31604 .62172 L F
.244 .522 .914 r
.32861 .57336 m .33137 .57603 L .33133 .57443 L F
.26 .441 .85 r
.33181 .57651 m .3326 .57638 L .33137 .57603 L F
.843 .61 .586 r
.34869 .68892 m .34528 .69067 L .34552 .68852 L F
.34869 .68892 m .34866 .69161 L .34528 .69067 L F
.347 .089 .374 r
.37242 .57622 m .37517 .57647 L .37523 .57302 L F
.527 .226 .4 r
.37523 .57302 m .37517 .57647 L .37754 .57505 L F
.574 .213 .318 r
.37523 .57302 m .37754 .57505 L .37838 .57318 L F
.609 .761 .952 r
.35884 .61836 m .35483 .61777 L .35753 .61889 L F
.584 .036 0 r
.36122 .61988 m .35884 .61836 L .35753 .61889 L F
.799 .587 .614 r
.31427 .64428 m .31892 .64514 L .31871 .64193 L F
.888 .735 .686 r
.33104 .5381 m .33049 .54118 L .33241 .54121 L F
.318 .803 .882 r
.33241 .54121 m .33342 .54055 L .33465 .54072 L F
.833 .47 .368 r
.33241 .54121 m .33388 .54456 L .33056 .54358 L F
.863 .479 .316 r
.3362 .54503 m .33388 .54456 L .33241 .54121 L F
.833 .47 .368 r
.33241 .54121 m .33056 .54358 L .33342 .54055 L F
.432 .801 .995 r
.25813 .52818 m .26033 .52935 L .25796 .52967 L F
.482 .819 .999 r
.26087 .52744 m .26033 .52935 L .25868 .52847 L F
.26087 .52744 m .25868 .52847 L .25813 .52818 L F
.432 .801 .995 r
.25813 .52818 m .25796 .52967 L .2562 .52867 L F
0 0 0 r
.26087 .52744 m .25647 .52881 L .25882 .52828 L F
.326 .793 .684 r
.26191 .52695 m .26087 .52744 L .25882 .52828 L F
.26235 .52676 m .26087 .52744 L .26191 .52695 L F
0 0 0 r
.26009 .52768 m .25813 .52818 L .25647 .52881 L F
.26087 .52744 m .25813 .52818 L .26009 .52768 L F
.432 .801 .995 r
.25813 .52818 m .2562 .52867 L .25606 .52858 L F
.461 .529 .841 r
.3799 .66261 m .37965 .66677 L .37743 .66358 L F
.3799 .66261 m .38152 .6662 L .37965 .66677 L F
.045 .186 .688 r
.38186 .66965 m .37965 .66677 L .38152 .6662 L F
0 .13 .67 r
.388 .52793 m .38879 .52819 L .38831 .52959 L F
0 .335 .809 r
.39008 .52986 m .38831 .52959 L .38879 .52819 L F
.39008 .52986 m .39114 .53138 L .38831 .52959 L F
.653 .524 .694 r
.27628 .55216 m .27863 .55383 L .27918 .55022 L F
.27628 .55216 m .27624 .55447 L .27863 .55383 L F
.539 .254 .43 r
.37322 .69838 m .37016 .70089 L .37061 .69837 L F
.37322 .69838 m .37272 .70066 L .37016 .70089 L F
.421 .148 .391 r
.37503 .70013 m .37322 .69838 L .3757 .6979 L F
.37503 .70013 m .37272 .70066 L .37322 .69838 L F
.497 .301 .544 r
.37582 .69506 m .3757 .6979 L .37322 .69838 L F
.751 .635 .732 r
.32778 .58209 m .32937 .58581 L .332 .58352 L F
.28 .11 .463 r
.3339 .57931 m .332 .58352 L .33377 .5822 L F
.647 .449 .6 r
.31997 .60748 m .32235 .60576 L .31984 .60406 L F
.145 0 0 r
.2313 .56012 m .22665 .56132 L .22894 .56066 L F
.564 .825 .463 r
.3504 .61598 m .3519 .61419 L .35308 .61271 L F
.74 .654 .764 r
.3582 .55958 m .35616 .56336 L .35594 .56017 L F
.489 .867 .654 r
.33523 .55432 m .33341 .55539 L .33189 .55668 L F
0 0 0 r
.33733 .55449 m .33341 .55539 L .33523 .55432 L F
.443 .197 .444 r
.35288 .60422 m .3557 .60159 L .35284 .6041 L F
0 0 .415 r
.35255 .60426 m .35259 .60426 L .35091 .60325 L F
.35259 .60426 m .35288 .60422 L .35203 .6038 L F
.35259 .60426 m .35203 .6038 L .35091 .60325 L F
.854 .993 .741 r
.35281 .60409 m .3557 .60159 L .35618 .60048 L F
.062 0 0 r
.35288 .60422 m .35284 .6041 L .35276 .60407 L F
.35203 .6038 m .35276 .60407 L .35091 .60325 L F
.35288 .60422 m .35276 .60407 L .35203 .6038 L F
.854 .993 .741 r
.35262 .60429 m .35284 .6041 L .35281 .60409 L F
0 0 .415 r
.35262 .60429 m .35288 .60422 L .35255 .60426 L F
.443 .197 .444 r
.35288 .60422 m .35284 .6041 L .35262 .60429 L F
.35288 .60422 m .35262 .60429 L .35262 .60429 L F
.062 0 0 r
.35288 .60422 m .3536 .60437 L .35282 .60405 L F
.35288 .60422 m .35262 .60429 L .3536 .60437 L F
.114 0 .038 r
.3536 .60437 m .35263 .60429 L .35282 .60409 L F
.854 .993 .741 r
.35284 .6041 m .3557 .60159 L .35281 .60409 L F
.35262 .60429 m .3557 .60159 L .35262 .60429 L F
.447 .58 .894 r
.35529 .60285 m .35602 .60491 L .35369 .60497 L F
0 .023 .595 r
.3562 .60732 m .35369 .60497 L .35602 .60491 L F
.35557 .60693 m .35369 .60497 L .3562 .60732 L F
.114 0 .038 r
.35363 .60432 m .35282 .60409 L .35618 .60048 L F
.35263 .60429 m .35262 .60429 L .35618 .60048 L F
.3536 .60437 m .35618 .60048 L .35606 .60007 L F
.712 .984 .889 r
.35529 .60285 m .35369 .60497 L .3542 .60331 L F
.421 .563 .891 r
.35529 .60285 m .35785 .60431 L .35602 .60491 L F
.807 .767 .816 r
.35785 .60431 m .3563 .60875 L .35617 .60696 L F
.35625 .60484 m .35617 .60696 L .35602 .60491 L F
.35785 .60431 m .35617 .60696 L .35625 .60484 L F
0 .023 .595 r
.3563 .60875 m .35612 .60849 L .35622 .6076 L F
.6 .609 .833 r
.35609 .60912 m .35616 .60731 L .35597 .60797 L F
.18 .379 .823 r
.35557 .60693 m .35597 .60797 L .35616 .6073 L F
.766 .505 .539 r
.35369 .60497 m .35597 .60797 L .35557 .60693 L F
.891 .885 .457 r
.35367 .61033 m .35548 .60845 L .3563 .60979 L F
.35367 .61033 m .3542 .6071 L .35548 .60845 L F
.248 0 0 r
.35367 .61033 m .3563 .60979 L .35454 .61162 L F
.322 .436 .822 r
.35369 .60497 m .35548 .60845 L .3542 .6071 L F
.766 .505 .539 r
.35369 .60497 m .35586 .60839 L .35597 .60797 L F
0 .023 .595 r
.35592 .6085 m .35548 .60845 L .35425 .60605 L F
.356 .60864 m .35548 .60845 L .35592 .6085 L F
.35544 .60773 m .35425 .60605 L .35369 .60497 L F
.35602 .60865 m .35425 .60605 L .35544 .60773 L F
.766 .505 .539 r
.35369 .60497 m .35543 .61006 L .35586 .60839 L F
.752 .929 .576 r
.35571 .60972 m .3563 .60896 L .35574 .60967 L F
.9 .648 .547 r
.35588 .60842 m .35587 .60847 L .3557 .6081 L F
.766 .505 .539 r
.35543 .61006 m .35559 .60986 L .35562 .6093 L F
.35584 .60844 m .35587 .60847 L .35597 .60797 L F
.9 .648 .547 r
.35587 .60847 m .35559 .60986 L .35569 .60825 L F
.35587 .60847 m .35569 .60825 L .3557 .6081 L F
0 .111 .65 r
.356 .60864 m .3563 .60979 L .35548 .60845 L F
.35612 .60868 m .35614 .60882 L .356 .60864 L F
.35614 .60882 m .3563 .60979 L .356 .60864 L F
.3563 .60875 m .3563 .60887 L .35612 .60868 L F
.3563 .60887 m .3563 .60979 L .35612 .60868 L F
.9 .648 .547 r
.35603 .60859 m .35585 .60861 L .35605 .6088 L F
.35597 .60797 m .35588 .60842 L .3557 .6081 L F
.35597 .60797 m .3557 .6081 L .35603 .60856 L F
0 .023 .595 r
.3563 .60875 m .35602 .60865 L .35598 .60859 L F
.35612 .60849 m .35598 .60859 L .35369 .60497 L F
.3563 .60875 m .35598 .60859 L .35612 .60849 L F
.6 .609 .833 r
.35617 .60846 m .35678 .60513 L .35616 .6073 L F
.752 .929 .576 r
.35609 .60909 m .3563 .60896 L .3563 .60875 L F
.35454 .61162 m .3563 .60979 L .3563 .60896 L F
.649 .443 .592 r
.35047 .60852 m .35532 .61021 L .35449 .60731 L F
.35532 .61021 m .35551 .61027 L .35543 .61006 L F
.35532 .61021 m .35543 .61006 L .35449 .60731 L F
.9 .648 .547 r
.35559 .60986 m .35554 .60992 L .3557 .6081 L F
.752 .929 .576 r
.35538 .61026 m .35611 .60924 L .35571 .60972 L F
.35574 .60967 m .356 .60933 L .35609 .60911 L F
.35574 .60967 m .35609 .60911 L .35607 .60913 L F
.35454 .61162 m .35542 .61029 L .35538 .61026 L F
.35542 .61029 m .35611 .60924 L .35538 .61026 L F
.35611 .60924 m .3563 .60896 L .35571 .60972 L F
.06 0 .349 r
.35618 .61005 m .35454 .61162 L .3555 .61005 L F
.248 0 0 r
.35367 .61033 m .35454 .61162 L .35308 .61271 L F
.564 .825 .463 r
.3504 .61598 m .35308 .61271 L .35289 .61497 L F
.736 .534 .62 r
.35618 .61005 m .35585 .61037 L .35454 .61162 L F
0 0 .073 r
.35316 .61294 m .35308 .61271 L .35454 .61162 L F
.35361 .61422 m .35289 .61497 L .35305 .61305 L F
.35316 .61294 m .35305 .61305 L .35308 .61271 L F
.35361 .61422 m .35305 .61305 L .35316 .61294 L F
.736 .534 .62 r
.35585 .61037 m .35442 .61172 L .35454 .61162 L F
.35442 .61172 m .35279 .61327 L .354 .61213 L F
.35442 .61172 m .354 .61213 L .35454 .61162 L F
0 0 .073 r
.35361 .61422 m .35316 .61294 L .35454 .61162 L F
.986 .757 .504 r
.35279 .61327 m .35361 .61422 L .35454 .61162 L F
.736 .534 .62 r
.35618 .61005 m .35647 .61357 L .35279 .61327 L F
.567 .408 .625 r
.35792 .61261 m .35618 .61005 L .35815 .60949 L F
.35792 .61261 m .35647 .61357 L .35618 .61005 L F
.428 0 0 r
.35356 .61183 m .35706 .61005 L .35618 .61005 L F
.35706 .61005 m .35815 .60949 L .35618 .61005 L F
.06 0 .349 r
.35618 .61005 m .3555 .61005 L .35607 .60913 L F
.9 .648 .547 r
.35609 .60911 m .35607 .60913 L .35618 .61005 L F
.35605 .6088 m .35539 .60987 L .35609 .60911 L F
.752 .929 .576 r
.35607 .60913 m .35609 .60911 L .35609 .60909 L F
.356 .60933 m .3563 .60896 L .35609 .60909 L F
.06 0 .349 r
.35618 .61005 m .35609 .60909 L .3563 .60875 L F
.6 .609 .833 r
.35618 .61005 m .35617 .60887 L .35609 .6091 L F
.35618 .61005 m .35609 .6091 L .35609 .60912 L F
.06 0 .349 r
.35618 .61005 m .35607 .60913 L .35609 .60909 L F
.9 .648 .547 r
.35607 .60913 m .35539 .60987 L .35618 .61005 L F
.766 .505 .539 r
.35543 .61006 m .35551 .61027 L .35554 .60992 L F
.35554 .60992 m .35551 .61027 L .35559 .60986 L F
.9 .648 .547 r
.3557 .6081 m .35551 .61027 L .35319 .60936 L F
.35605 .6088 m .35319 .60936 L .35539 .60987 L F
.6 .609 .833 r
.35617 .60887 m .35616 .60731 L .35609 .6091 L F
.35617 .60887 m .35609 .6091 L .35609 .60912 L F
.35618 .61005 m .3564 .60831 L .35617 .60846 L F
.3564 .60831 m .35678 .60513 L .35617 .60846 L F
.9 .648 .547 r
.35603 .60856 m .356 .60856 L .35603 .60859 L F
0 .023 .595 r
.35602 .60865 m .356 .60864 L .35592 .6085 L F
.9 .648 .547 r
.356 .60856 m .35585 .60861 L .35603 .60859 L F
0 0 .415 r
.35369 .60497 m .3542 .6071 L .35288 .60422 L F
.649 .443 .592 r
.35293 .60581 m .35449 .60731 L .35369 .60497 L F
.35047 .60852 m .35449 .60731 L .35293 .60581 L F
.9 .648 .547 r
.35585 .60861 m .35319 .60936 L .35605 .6088 L F
.366 .185 .498 r
.35047 .60852 m .35319 .60936 L .3553 .61019 L F
.35532 .61021 m .3553 .61019 L .35551 .61027 L F
.35047 .60852 m .3553 .61019 L .35532 .61021 L F
.9 .648 .547 r
.35559 .60986 m .35551 .61027 L .35554 .60992 L F
.3557 .6081 m .35319 .60936 L .35603 .60856 L F
0 .023 .595 r
.35612 .60849 m .35369 .60497 L .35615 .60753 L F
.35612 .60849 m .35615 .60753 L .35622 .6076 L F
.6 .609 .833 r
.35616 .60737 m .35616 .6073 L .35616 .60731 L F
.35618 .61005 m .35616 .6073 L .35616 .60737 L F
.18 .379 .823 r
.3542 .60331 m .35557 .60693 L .35678 .60513 L F
.35557 .60693 m .35616 .6073 L .35678 .60513 L F
0 .023 .595 r
.35622 .6076 m .35557 .60693 L .3562 .60732 L F
.766 .505 .539 r
.35369 .60497 m .35557 .60693 L .35466 .60451 L F
.35388 .60436 m .35466 .60451 L .3542 .60331 L F
.35369 .60497 m .35466 .60451 L .35388 .60436 L F
.114 0 .038 r
.3536 .60437 m .35324 .60424 L .35363 .60432 L F
.35324 .60424 m .35282 .60409 L .35363 .60432 L F
.062 0 0 r
.35284 .6041 m .35282 .60405 L .35258 .60394 L F
.35284 .6041 m .35258 .60394 L .35091 .60325 L F
.854 .993 .741 r
.35262 .60429 m .35262 .60429 L .35262 .60429 L F
.114 0 .038 r
.35263 .60429 m .35262 .60429 L .35262 .60429 L F
0 0 .415 r
.3526 .6043 m .35262 .60429 L .35255 .60426 L F
.35369 .60497 m .35288 .60422 L .3526 .6043 L F
.877 .569 .462 r
.34769 .55411 m .35108 .55728 L .35053 .55421 L F
.248 .296 .716 r
.3505 .55132 m .35053 .55421 L .3526 .55192 L F
.3505 .55132 m .3526 .55192 L .35252 .55182 L F
.856 .431 .214 r
.34553 .55101 m .3505 .55132 L .34915 .54963 L F
.699 .739 .882 r
.34939 .54966 m .3505 .55132 L .35301 .55008 L F
.34915 .54963 m .34923 .54974 L .34939 .54966 L F
.34923 .54974 m .3505 .55132 L .34939 .54966 L F
.774 .418 .383 r
.35099 .54979 m .3511 .55188 L .35031 .55025 L F
.35008 .54966 m .35031 .55025 L .35002 .54965 L F
.18 .687 .903 r
.34915 .54963 m .34998 .54972 L .35002 .54965 L F
.34998 .54972 m .35301 .55008 L .35002 .54965 L F
0 0 0 r
.35055 .5486 m .35034 .54908 L .35002 .54965 L F
.51 .288 .513 r
.34984 .55007 m .34553 .55101 L .34915 .54963 L F
.35027 .55034 m .34969 .55042 L .34984 .55007 L F
.34969 .55042 m .34553 .55101 L .34984 .55007 L F
.35054 .55084 m .34949 .55087 L .35027 .55034 L F
.34949 .55087 m .34553 .55101 L .34969 .55042 L F
.34949 .55087 m .34969 .55042 L .35027 .55034 L F
.774 .418 .383 r
.3511 .55188 m .35111 .55203 L .3507 .55113 L F
.3511 .55188 m .3507 .55113 L .3504 .55049 L F
.35031 .55025 m .3504 .55049 L .35002 .54965 L F
.3511 .55188 m .3504 .55049 L .35031 .55025 L F
.51 .288 .513 r
.35054 .55084 m .34575 .5515 L .34681 .55097 L F
.497 .299 .542 r
.35002 .54965 m .3504 .55049 L .35102 .55082 L F
.3504 .55049 m .35111 .55203 L .35102 .55082 L F
.51 .288 .513 r
.35102 .55082 m .35056 .55088 L .35054 .55084 L F
.35056 .55088 m .34575 .5515 L .35054 .55084 L F
.497 .299 .542 r
.35002 .54965 m .35102 .55082 L .34915 .54963 L F
0 0 0 r
.35055 .5486 m .34969 .55061 L .35001 .54968 L F
.35004 .54962 m .35001 .54968 L .35002 .54965 L F
.35055 .5486 m .35001 .54968 L .35004 .54962 L F
.35034 .54908 m .34969 .55061 L .35001 .54968 L F
.35003 .54963 m .35001 .54968 L .35002 .54965 L F
.35034 .54908 m .35001 .54968 L .35003 .54963 L F
.774 .418 .383 r
.35099 .54979 m .35031 .55025 L .35008 .54966 L F
.51 .288 .513 r
.35056 .55088 m .34644 .55301 L .34575 .5515 L F
.35102 .55082 m .35061 .55102 L .35056 .55088 L F
.35061 .55102 m .34644 .55301 L .35056 .55088 L F
.34681 .55097 m .34575 .5515 L .34553 .55101 L F
.35102 .55082 m .35054 .55084 L .35027 .55034 L F
.774 .418 .383 r
.35301 .55008 m .352 .55112 L .35099 .54979 L F
.352 .55112 m .35111 .55203 L .35099 .54979 L F
.248 .296 .716 r
.35252 .55182 m .3526 .55192 L .35267 .55185 L F
.514 .324 .561 r
.35053 .55421 m .35352 .55617 L .35267 .55185 L F
.35053 .55421 m .35108 .55728 L .35352 .55617 L F
.099 0 .182 r
.18787 .56673 m .18533 .5699 L .18704 .56891 L F
.113 0 .343 r
.18508 .57253 m .18704 .56891 L .18533 .5699 L F
.836 .69 .7 r
.3945 .59113 m .39576 .59497 L .39751 .59182 L F
.323 .189 .539 r
.33724 .63882 m .33927 .64085 L .33929 .6379 L F
.33724 .63882 m .33724 .64134 L .33927 .64085 L F
.012 .202 .713 r
.40396 .55636 m .40377 .55764 L .40245 .55385 L F
0 0 .161 r
.40396 .55636 m .40453 .56007 L .40377 .55764 L F
.26 .441 .85 r
.33181 .57651 m .3339 .57931 L .3326 .57638 L F
0 0 .049 r
.3339 .57931 m .33512 .57563 L .3326 .57638 L F
.3339 .57931 m .33461 .57929 L .33512 .57563 L F
.435 .608 .921 r
.33377 .5822 m .33461 .57929 L .3339 .57931 L F
.363 .247 .585 r
.30055 .54481 m .30261 .54679 L .30077 .54731 L F
.30055 .54481 m .30261 .54679 L .30077 .54731 L F
.415 .515 .852 r
.33417 .52453 m .33277 .52618 L .33225 .5252 L F
.33417 .52453 m .33498 .52501 L .33277 .52618 L F
.216 .024 .391 r
.33498 .52501 m .33211 .52861 L .33277 .52618 L F
.574 .388 .591 r
.37242 .57622 m .37539 .57808 L .37517 .57647 L F
.37242 .57622 m .37261 .57886 L .37539 .57808 L F
.438 .226 .493 r
.22187 .56285 m .21926 .56611 L .21978 .5636 L F
.935 .723 .592 r
.30492 .58653 m .30623 .58546 L .30457 .58445 L F
.30492 .58653 m .30565 .58801 L .30623 .58546 L F
.772 .499 .523 r
.35568 .63402 m .358 .63484 L .35825 .63211 L F
.604 .663 .881 r
.35825 .63211 m .3602 .63109 L .35917 .62824 L F
0 0 .178 r
.3769 .56166 m .37641 .56278 L .37649 .56058 L F
.3769 .56166 m .37649 .56058 L .37492 .56021 L F
.857 .985 .706 r
.37492 .56021 m .37934 .56064 L .3769 .56166 L F
.335 .79 .947 r
.37868 .56355 m .3823 .56307 L .37932 .5605 L F
.857 .985 .706 r
.37492 .56021 m .37521 .55824 L .37856 .56018 L F
.37831 .56054 m .37856 .56018 L .37934 .56064 L F
.37492 .56021 m .37856 .56018 L .37831 .56054 L F
0 .209 .726 r
.37762 .55694 m .37932 .5605 L .3798 .55859 L F
.627 .809 .97 r
.3798 .55859 m .37934 .56064 L .37521 .55824 L F
.656 .926 .639 r
.37932 .5591 m .37763 .56029 L .3769 .56166 L F
.3798 .55859 m .37952 .55881 L .37932 .5591 L F
.37952 .55881 m .37763 .56029 L .37932 .5591 L F
.485 .384 .665 r
.37763 .56029 m .37746 .56036 L .3769 .56166 L F
.37746 .56036 m .37537 .5612 L .3769 .56166 L F
0 0 .178 r
.3769 .56166 m .37637 .56363 L .37641 .56278 L F
.663 .316 0 r
.37672 .5645 m .37637 .56363 L .3769 .56166 L F
.353 .293 .65 r
.18245 .5852 m .18412 .58461 L .18359 .58199 L F
.76 .531 .586 r
.37016 .70089 m .36666 .69811 L .37061 .69837 L F
.338 .317 .689 r
.32281 .57246 m .32524 .5751 L .32304 .57599 L F
.181 0 .35 r
.3248 .57742 m .32304 .57599 L .32524 .5751 L F
.3248 .57742 m .3231 .57851 L .32304 .57599 L F
.793 .909 .92 r
.21648 .61272 m .22127 .61119 L .22178 .61219 L F
.227 .316 .747 r
.22093 .60671 m .22223 .61165 L .22127 .61119 L F
.783 .357 0 r
.22157 .61212 m .22178 .61219 L .22127 .61119 L F
.492 .055 .137 r
.22127 .61119 m .22223 .61165 L .22157 .61212 L F
.656 .353 .448 r
.27577 .55613 m .27863 .55383 L .27624 .55447 L F
.778 .528 .558 r
.3528 .692 m .34887 .69414 L .34866 .69161 L F
.3528 .692 m .35254 .69454 L .34887 .69414 L F
.411 .664 .964 r
.32698 .52102 m .3308 .51938 L .32925 .51857 L F
.32698 .52102 m .32972 .52026 L .3308 .51938 L F
.755 .358 .3 r
.32925 .51857 m .32972 .52026 L .3308 .51938 L F
.786 .869 .91 r
.3426 .51191 m .33821 .51287 L .3407 .50985 L F
.636 .771 .945 r
.34506 .51129 m .3426 .51191 L .3407 .50985 L F
.511 .892 .712 r
.33293 .67007 m .33408 .66956 L .33496 .66861 L F
0 0 0 r
.21558 .54441 m .21581 .5455 L .21777 .54368 L F
.21558 .54441 m .21393 .54654 L .21581 .5455 L F
.463 .287 .557 r
.34032 .5634 m .34012 .56645 L .33784 .56684 L F
.722 .519 .616 r
.34177 .56965 m .33784 .56684 L .34012 .56645 L F
.34177 .56965 m .33763 .56954 L .33784 .56684 L F
.653 .676 .86 r
.33546 .60393 m .33436 .60529 L .33096 .60179 L F
0 0 0 r
.33317 .60681 m .33436 .60529 L .33546 .60393 L F
.122 0 .194 r
.18787 .56673 m .18899 .56768 L .19012 .56615 L F
.18787 .56673 m .18704 .56891 L .18899 .56768 L F
.041 .282 .776 r
.37932 .5605 m .3823 .56307 L .3798 .55859 L F
.238 .593 .949 r
.24904 .62251 m .24483 .62041 L .24682 .62044 L F
0 .315 .673 r
.24682 .62044 m .25117 .62238 L .24904 .62251 L F
.484 .315 .575 r
.34425 .61085 m .34657 .61041 L .34686 .60675 L F
.172 .189 .637 r
.34425 .61085 m .34622 .61235 L .34657 .61041 L F
.537 .36 .59 r
.37562 .6254 m .37315 .62316 L .37574 .62271 L F
.37562 .6254 m .37314 .62594 L .37315 .62316 L F
.812 .364 .175 r
.3362 .54503 m .33457 .54627 L .33388 .54456 L F
.643 .134 .021 r
.3362 .54503 m .33859 .54682 L .33457 .54627 L F
.276 .058 .392 r
.37808 .69186 m .37769 .6944 L .37582 .69506 L F
.324 .162 .501 r
.37754 .69705 m .37582 .69506 L .37769 .6944 L F
.37754 .69705 m .3757 .6979 L .37582 .69506 L F
.567 .878 .993 r
.36974 .56547 m .36713 .5665 L .36799 .56499 L F
.36974 .56547 m .36713 .5665 L .36799 .56499 L F
.691 .582 .729 r
.36974 .56547 m .36648 .56946 L .36713 .5665 L F
.61 .593 .809 r
.31397 .52197 m .31188 .52485 L .31143 .52288 L F
.31397 .52197 m .31547 .52572 L .31188 .52485 L F
.342 0 .171 r
.28496 .61837 m .28387 .61715 L .28562 .61611 L F
.28496 .61837 m .28279 .61902 L .28387 .61715 L F
.53 .331 .556 r
.36363 .65438 m .36354 .65709 L .36097 .65752 L F
.36097 .65752 m .36354 .65709 L .36363 .65438 L F
.36354 .65709 m .36345 .6597 L .36097 .65752 L F
.41 .538 .875 r
.26788 .63673 m .26899 .63428 L .26729 .63602 L F
.26788 .63673 m .27084 .63737 L .26899 .63428 L F
.639 .488 .662 r
.34501 .52584 m .34251 .52902 L .3427 .52657 L F
.34501 .52584 m .34251 .52902 L .3427 .52657 L F
.297 .411 .81 r
.2199 .60275 m .21873 .60469 L .21732 .60127 L F
.055 .171 .67 r
.2199 .60275 m .22001 .60669 L .21873 .60469 L F
.396 .706 .984 r
.25595 .54699 m .25561 .54864 L .25395 .54767 L F
.443 .326 .626 r
.25561 .54864 m .25776 .5484 L .2564 .54549 L F
.396 .706 .984 r
.25595 .54699 m .25776 .5484 L .25561 .54864 L F
.373 .789 .977 r
.25165 .63443 m .25242 .63341 L .25031 .63331 L F
.25165 .63443 m .25383 .63409 L .25242 .63341 L F
.702 .701 .846 r
.37943 .63354 m .37463 .63235 L .37716 .63207 L F
.733 .716 .836 r
.38196 .6322 m .37943 .63354 L .37716 .63207 L F
.514 .731 .972 r
.35981 .51216 m .35875 .51433 L .35748 .51316 L F
.35981 .51216 m .36188 .51399 L .35875 .51433 L F
.669 .195 .116 r
.38248 .63795 m .38382 .6389 L .38607 .63858 L F
.6 .568 .79 r
.38607 .63858 m .38822 .63369 L .38595 .63557 L F
.38607 .63858 m .38881 .63833 L .38822 .63369 L F
.22 .488 .896 r
.38382 .6389 m .38672 .64181 L .38607 .63858 L F
.21 .074 .467 r
.32886 .59093 m .32749 .5942 L .32737 .59183 L F
.213 0 .245 r
.32485 .6418 m .32748 .63881 L .32664 .64125 L F
.212 0 .245 r
.32664 .64125 m .32748 .63881 L .32954 .63783 L F
.518 .813 .999 r
.33423 .53128 m .33323 .5329 L .3325 .53047 L F
.654 .591 .773 r
.32843 .53018 m .3296 .53179 L .3325 .53047 L F
.32843 .53018 m .3325 .53047 L .33069 .52923 L F
.86 .986 .846 r
.3296 .53179 m .33069 .52923 L .3325 .53047 L F
.661 .109 0 r
.33069 .52923 m .33178 .53103 L .33423 .53128 L F
.346 .57 .923 r
.33534 .52951 m .33423 .53128 L .33178 .53103 L F
.33562 .52938 m .33423 .53128 L .33534 .52951 L F
.518 .813 .999 r
.33423 .53128 m .33326 .53301 L .33323 .5329 L F
.33423 .53128 m .33593 .53223 L .33326 .53301 L F
.349 .195 .526 r
.35108 .59795 m .34982 .60115 L .35125 .60306 L F
.559 .241 .386 r
.34982 .60115 m .35091 .60325 L .35125 .60306 L F
.711 .443 .519 r
.3112 .56366 m .31497 .56615 L .3135 .56297 L F
.3112 .56366 m .31059 .56603 L .31497 .56615 L F
.431 0 0 r
.29264 .64813 m .29709 .64797 L .2949 .64902 L F
.331 .788 .65 r
.2949 .64902 m .29709 .64797 L .29804 .64748 L F
.584 .014 0 r
.29993 .65034 m .29804 .64748 L .29709 .64797 L F
.806 .566 .575 r
.31985 .65005 m .32392 .65128 L .32354 .6539 L F
.265 .088 .444 r
.32392 .65128 m .32583 .64784 L .32542 .6506 L F
.103 .133 .607 r
.32617 .65419 m .32395 .65133 L .32542 .6506 L F
.416 .212 .493 r
.32354 .6539 m .32392 .65128 L .32617 .65419 L F
.73 .722 .844 r
.32424 .65245 m .32617 .65419 L .32542 .6506 L F
0 0 0 r
.32625 .6502 m .32542 .6506 L .32424 .65245 L F
.32697 .64939 m .32542 .6506 L .32625 .6502 L F
.103 .133 .607 r
.32395 .65133 m .32392 .65128 L .32542 .6506 L F
.686 .704 .861 r
.32234 .5571 m .31993 .55817 L .31854 .55608 L F
.448 .159 .38 r
.33189 .55668 m .33143 .55985 L .32893 .56034 L F
.454 .165 .382 r
.3339 .55923 m .33189 .55668 L .33341 .55539 L F
.3339 .55923 m .33143 .55985 L .33189 .55668 L F
0 0 0 r
.26591 .53665 m .26446 .53724 L .26275 .5376 L F
.387 .829 .697 r
.26611 .53633 m .26591 .53665 L .26827 .536 L F
.26611 .53633 m .26446 .53724 L .26591 .53665 L F
0 .151 .693 r
.32657 .66739 m .32779 .67002 L .32812 .66907 L F
0 0 0 r
.33631 .65374 m .33493 .65496 L .33308 .65668 L F
.706 .191 0 r
.33944 .54908 m .34049 .54789 L .33859 .54682 L F
.33944 .54908 m .34247 .54991 L .34049 .54789 L F
.194 .714 .683 r
.36985 .56257 m .37099 .56225 L .37308 .56166 L F
.61 .473 .67 r
.37035 .56434 m .37236 .56186 L .37099 .56225 L F
.37236 .56186 m .37279 .56133 L .37099 .56225 L F
.194 .714 .683 r
.36864 .56291 m .37099 .56225 L .36985 .56257 L F
.383 .84 .768 r
.37308 .56166 m .37279 .56133 L .37492 .56021 L F
.727 .624 .743 r
.32624 .58501 m .32937 .58581 L .32778 .58209 L F
.734 .346 .317 r
.32624 .58501 m .32728 .58763 L .32937 .58581 L F
.931 .681 .537 r
.32937 .58581 m .32728 .58763 L .32989 .58869 L F
.265 .579 .942 r
.36395 .52102 m .36739 .52065 L .36479 .51957 L F
.41 0 0 r
.36979 .52247 m .3688 .52257 L .36395 .52102 L F
.37078 .52272 m .3688 .52257 L .36979 .52247 L F
.996 .775 .485 r
.3688 .52257 m .3675 .52368 L .36746 .5227 L F
.265 .579 .942 r
.36395 .52102 m .3688 .52257 L .36739 .52065 L F
.996 .775 .485 r
.3688 .52257 m .36746 .5227 L .36739 .52065 L F
.947 .798 .664 r
.33174 .51547 m .33253 .51859 L .33364 .51641 L F
0 0 0 r
.35278 .59707 m .35349 .59573 L .35108 .59795 L F
.46 .279 .548 r
.35108 .59795 m .35368 .60122 L .35278 .59707 L F
.35108 .59795 m .35125 .60306 L .35368 .60122 L F
.929 .781 .676 r
.30502 .6291 m .30822 .62843 L .30822 .62644 L F
0 0 .116 r
.30822 .62644 m .30822 .62843 L .30823 .62839 L F
.491 .894 .937 r
.30502 .6291 m .30799 .62846 L .30822 .62644 L F
.30799 .62846 m .30823 .62839 L .30822 .62644 L F
.30823 .62841 m .3087 .62831 L .30822 .62644 L F
0 0 .116 r
.30822 .62644 m .30822 .62682 L .30855 .62748 L F
.30822 .62682 m .30823 .62839 L .30855 .62748 L F
.501 .908 .844 r
.30855 .62748 m .30823 .62839 L .30629 .62867 L F
.519 .052 .086 r
.30646 .62857 m .30873 .62784 L .30855 .62748 L F
.30873 .62784 m .31107 .62709 L .30855 .62748 L F
.501 .908 .844 r
.30823 .62839 m .30822 .62843 L .30799 .62846 L F
.30823 .62839 m .30799 .62846 L .30629 .62867 L F
.491 .894 .937 r
.30799 .62846 m .30823 .62841 L .30823 .62839 L F
.335 .816 .803 r
.30629 .62867 m .30799 .62846 L .30502 .6291 L F
.30799 .62846 m .30822 .62843 L .30502 .6291 L F
.491 .894 .937 r
.30502 .6291 m .30887 .62893 L .3087 .62831 L F
.577 .12 .132 r
.30887 .62893 m .31127 .63019 L .30806 .63167 L F
.30887 .62893 m .31201 .62948 L .31127 .63019 L F
.75 .616 .71 r
.38049 .67473 m .38382 .6754 L .3815 .67527 L F
.801 .54 .544 r
.34158 .68252 m .33901 .68481 L .33924 .68209 L F
.34158 .68252 m .34281 .68581 L .33901 .68481 L F
.615 .951 .923 r
.29751 .58894 m .29232 .59071 L .29528 .58772 L F
.545 .822 .997 r
.30241 .67642 m .29997 .67716 L .29768 .67579 L F
.29768 .67579 m .29997 .67716 L .30241 .67642 L F
.045 .325 .808 r
.37156 .60929 m .37402 .61275 L .37089 .61008 L F
.714 .282 .221 r
.32211 .56677 m .32108 .56614 L .32102 .56909 L F
0 0 0 r
.32121 .57159 m .32211 .56677 L .32102 .56909 L F
.157 .127 .571 r
.32211 .56677 m .32102 .56909 L .32108 .56614 L F
.733 .634 .748 r
.32211 .56677 m .32121 .57159 L .32102 .56909 L F
.32211 .56677 m .32557 .57395 L .32479 .57353 L F
.32179 .56847 m .32479 .57353 L .32121 .57159 L F
.32211 .56677 m .32479 .57353 L .32179 .56847 L F
0 0 0 r
.32145 .57036 m .32157 .57007 L .32193 .56788 L F
.32121 .57159 m .32193 .56788 L .32179 .56847 L F
.212 .735 .84 r
.31778 .57036 m .32165 .56988 L .32157 .57007 L F
.732 .633 .749 r
.3283 .57284 m .32557 .57395 L .32211 .56677 L F
.714 .282 .221 r
.32211 .56677 m .32275 .56838 L .32227 .56794 L F
.141 0 .268 r
.32211 .56677 m .32193 .56788 L .32224 .56771 L F
.732 .633 .749 r
.3283 .57284 m .32211 .56677 L .3264 .56742 L F
.744 .582 .675 r
.32605 .56534 m .3264 .56742 L .32211 .56677 L F
.145 .007 .421 r
.32395 .56681 m .32275 .56838 L .32211 .56677 L F
.141 0 .268 r
.32193 .56788 m .32253 .56799 L .32395 .56681 L F
.57 .572 .816 r
.32253 .56799 m .32275 .56838 L .32395 .56681 L F
.141 0 .268 r
.32253 .56799 m .32302 .56808 L .32395 .56681 L F
0 0 0 r
.32179 .56847 m .32193 .56788 L .32211 .56677 L F
.714 .282 .221 r
.32211 .56677 m .32227 .56794 L .3195 .56542 L F
.141 0 .268 r
.32211 .56677 m .32224 .56771 L .32395 .56681 L F
.461 0 .066 r
.32103 .56385 m .3195 .56542 L .31822 .56474 L F
.744 .802 .899 r
.32398 .56578 m .3195 .56542 L .32103 .56385 L F
.32398 .56578 m .32108 .56614 L .3195 .56542 L F
.157 .127 .571 r
.32211 .56677 m .32108 .56614 L .32398 .56578 L F
.744 .582 .675 r
.32605 .56534 m .32211 .56677 L .32398 .56578 L F
.714 .282 .221 r
.32211 .56677 m .3195 .56542 L .32108 .56614 L F
.57 .572 .816 r
.32014 .56391 m .32253 .56799 L .32395 .56681 L F
.026 .266 .766 r
.32233 .56795 m .32275 .56838 L .32253 .56799 L F
.141 0 .268 r
.32193 .56788 m .32157 .57007 L .32302 .56808 L F
.026 .266 .766 r
.32199 .5676 m .32233 .56795 L .32208 .56722 L F
.32233 .56795 m .32253 .56799 L .32208 .56722 L F
.505 .332 .58 r
.32157 .57007 m .32394 .56951 L .32395 .56681 L F
.075 .348 .821 r
.32157 .57007 m .32185 .56853 L .32394 .56951 L F
.32157 .57007 m .32249 .56977 L .32185 .56853 L F
.212 .735 .84 r
.32165 .56988 m .32249 .56977 L .32157 .57007 L F
0 0 0 r
.32121 .57159 m .32157 .57007 L .32145 .57036 L F
.026 .266 .766 r
.32021 .5658 m .32199 .5676 L .32172 .56661 L F
.32199 .5676 m .32208 .56722 L .32172 .56661 L F
.3195 .56542 m .32055 .56638 L .32021 .5658 L F
.32055 .56638 m .32275 .56838 L .32021 .5658 L F
.3195 .56542 m .32172 .56661 L .32014 .56391 L F
.461 0 .066 r
.31822 .56474 m .3195 .56542 L .31777 .56488 L F
.744 .802 .899 r
.32398 .56578 m .32103 .56385 L .32347 .56333 L F
.305 .072 .387 r
.30159 .59487 m .30108 .59731 L .29916 .59794 L F
.171 .084 .508 r
.30072 .59981 m .29916 .59794 L .30108 .59731 L F
.30072 .59981 m .29864 .60124 L .29916 .59794 L F
.512 .82 1 r
.24314 .60751 m .23803 .60698 L .24094 .60632 L F
.498 .192 .377 r
.24185 .60997 m .24314 .60751 L .24094 .60632 L F
.24185 .60997 m .24436 .60944 L .24314 .60751 L F
.24314 .60751 m .24436 .60944 L .24185 .60997 L F
0 0 0 r
.33163 .65756 m .32935 .65938 L .32966 .65904 L F
.33308 .65668 m .33163 .65756 L .32966 .65904 L F
.979 .728 .485 r
.32974 .65639 m .33109 .65723 L .32966 .65904 L F
.75 .516 .576 r
.32974 .65639 m .32966 .65904 L .32538 .65853 L F
.979 .728 .485 r
.33109 .65723 m .33163 .65756 L .32966 .65904 L F
0 0 0 r
.33308 .65668 m .32966 .65904 L .33207 .65859 L F
.544 .344 .56 r
.32974 .65639 m .33207 .65859 L .32966 .65904 L F
.183 0 .273 r
.32935 .65938 m .32596 .66351 L .32811 .66418 L F
.701 .311 .305 r
.32538 .65853 m .32966 .65904 L .3281 .66106 L F
.397 .829 .957 r
.32966 .65904 m .33008 .65807 L .32827 .66081 L F
.32966 .65904 m .32827 .66081 L .3281 .66106 L F
.048 .035 .518 r
.21826 .59665 m .21687 .59465 L .2187 .5941 L F
.21826 .59665 m .21735 .59776 L .21687 .59465 L F
.331 .165 .5 r
.38535 .68769 m .38359 .68579 L .3854 .68491 L F
.38535 .68769 m .38347 .68852 L .38359 .68579 L F
0 .465 .815 r
.37334 .52427 m .3688 .52257 L .37078 .52272 L F
.655 .615 .797 r
.34794 .54006 m .34513 .54104 L .3441 .53785 L F
.139 0 0 r
.29039 .64841 m .29072 .64925 L .28823 .64731 L F
.29039 .64841 m .29264 .64813 L .29072 .64925 L F
.361 .296 .648 r
.32664 .64125 m .32716 .64394 L .32485 .6418 L F
.106 0 0 r
.32954 .63783 m .33308 .63559 L .33292 .63594 L F
.32954 .63783 m .3299 .63763 L .33006 .63781 L F
.33007 .63753 m .33047 .63731 L .33015 .63774 L F
.33047 .63731 m .33292 .63594 L .33022 .6377 L F
.33047 .63731 m .33022 .6377 L .33015 .63774 L F
0 0 .34 r
.33032 .63349 m .33015 .63774 L .33136 .63534 L F
.33015 .63774 m .33015 .63782 L .33017 .63778 L F
.33015 .63774 m .33017 .63778 L .33136 .63534 L F
.106 0 0 r
.3299 .63763 m .33007 .63753 L .33007 .6378 L F
.33007 .63753 m .33015 .63774 L .33007 .6378 L F
.3299 .63763 m .33007 .6378 L .33006 .63781 L F
.212 0 .245 r
.32664 .64125 m .32954 .63783 L .32779 .64013 L F
.527 .206 .367 r
.32954 .63783 m .32993 .63816 L .32779 .64013 L F
.32993 .63816 m .33186 .63976 L .32877 .64004 L F
.32993 .63816 m .32877 .64004 L .32779 .64013 L F
0 0 .382 r
.32804 .63715 m .32924 .6389 L .32991 .63778 L F
.527 .206 .367 r
.32993 .63816 m .33208 .63771 L .33186 .63976 L F
0 0 .382 r
.33007 .6378 m .33008 .6378 L .33015 .63782 L F
.527 .206 .367 r
.33008 .6378 m .33013 .63785 L .32993 .63816 L F
0 0 .382 r
.33008 .6378 m .33012 .63785 L .33013 .63785 L F
.33008 .6378 m .33013 .63785 L .33015 .63782 L F
.527 .206 .367 r
.32954 .63783 m .33008 .6378 L .32993 .63816 L F
.33008 .6378 m .33016 .6378 L .33013 .63785 L F
.88 .828 .792 r
.33007 .6378 m .33015 .63782 L .33015 .63774 L F
.662 .835 .417 r
.33017 .63778 m .33015 .63782 L .33013 .63785 L F
.33017 .63778 m .33013 .63785 L .33016 .6378 L F
.527 .206 .367 r
.33016 .6378 m .33208 .63771 L .32993 .63816 L F
.662 .835 .417 r
.33016 .6378 m .33013 .63785 L .33012 .63785 L F
0 0 .382 r
.33011 .63784 m .32924 .6389 L .33012 .63785 L F
.32804 .63715 m .33012 .63785 L .33007 .6378 L F
.88 .828 .792 r
.32804 .63715 m .33007 .6378 L .33032 .63349 L F
.33007 .6378 m .33015 .63774 L .33032 .63349 L F
.662 .835 .417 r
.33136 .63534 m .33018 .63776 L .32924 .6389 L F
.106 0 0 r
.33006 .63781 m .33292 .63594 L .33208 .63771 L F
.662 .835 .417 r
.33018 .63776 m .33017 .63778 L .33015 .6378 L F
.33018 .63776 m .33015 .6378 L .32924 .6389 L F
.33017 .63778 m .33012 .63785 L .32924 .6389 L F
0 0 0 r
.33208 .63771 m .33308 .63559 L .33449 .63443 L F
0 .388 .787 r
.24793 .63233 m .24776 .63178 L .24619 .63109 L F
.24793 .63233 m .25031 .63331 L .24776 .63178 L F
.347 .171 .495 r
.31688 .53166 m .31655 .5349 L .31475 .53515 L F
.335 .79 .947 r
.37868 .56355 m .38276 .56354 L .3823 .56307 L F
.349 0 0 r
.37844 .56535 m .38276 .56354 L .37868 .56355 L F
.147 0 .207 r
.38112 .56512 m .38231 .56621 L .3823 .56618 L F
.349 0 0 r
.38044 .56451 m .38112 .56512 L .38276 .56354 L F
.803 1 .816 r
.3823 .56307 m .38276 .56354 L .38336 .56136 L F
.812 .949 .601 r
.38276 .56354 m .38112 .56512 L .38336 .56136 L F
.504 .559 .845 r
.3798 .55859 m .3823 .56307 L .38336 .56136 L F
.889 .985 .716 r
.38336 .56136 m .38112 .56512 L .3811 .56283 L F
.147 0 .207 r
.38112 .56512 m .3823 .56618 L .3811 .56283 L F
.349 0 0 r
.37844 .56535 m .38112 .56512 L .38044 .56451 L F
.956 .945 .717 r
.39164 .59645 m .39097 .60111 L .39065 .59794 L F
.39164 .59645 m .38994 .60056 L .39097 .60111 L F
.208 0 .198 r
.38826 .68202 m .3854 .68491 L .38626 .68292 L F
.213 0 .19 r
.28237 .54121 m .27943 .5439 L .28033 .54198 L F
0 0 .188 r
.30072 .59981 m .29868 .60326 L .29864 .60124 L F
.45 .305 .592 r
.39685 .58533 m .39695 .58787 L .39476 .58849 L F
.414 .211 .494 r
.39695 .58787 m .3945 .59113 L .39476 .58849 L F
.223 .014 .37 r
.3947 .59313 m .39436 .59338 L .3945 .59113 L F
0 0 .101 r
.3945 .59113 m .39417 .59315 L .39457 .58998 L F
.223 .014 .37 r
.39436 .59338 m .39263 .59468 L .3945 .59113 L F
0 0 .101 r
.3945 .59113 m .39457 .58998 L .39476 .58849 L F
.65 .479 .639 r
.36078 .55394 m .35816 .55705 L .35814 .55392 L F
.69 .559 .702 r
.72136 .33471 m .72103 .33786 L .71832 .33807 L F
0 0 0 r
.72103 .33786 m .72398 .33644 L .72173 .33747 L F
.43 .328 .638 r
.72105 .33771 m .72398 .33644 L .72103 .33786 L F
.687 .679 .836 r
.72125 .33755 m .72103 .33786 L .72173 .33747 L F
.43 .328 .638 r
.72136 .33471 m .72267 .33558 L .72127 .33741 L F
.72107 .33748 m .72127 .33741 L .72105 .33771 L F
.72136 .33471 m .72127 .33741 L .72107 .33748 L F
.72267 .33558 m .72329 .33599 L .72125 .33755 L F
.72267 .33558 m .72125 .33755 L .72105 .33771 L F
.752 .293 .159 r
.72398 .33644 m .72157 .3373 L .72173 .33747 L F
.664 .789 .941 r
.72157 .3373 m .72125 .33755 L .72173 .33747 L F
.43 .328 .638 r
.72329 .33599 m .72398 .33644 L .72105 .33771 L F
.752 .293 .159 r
.72398 .33644 m .71908 .33469 L .72157 .3373 L F
.687 .679 .836 r
.71832 .33807 m .72103 .33786 L .72125 .33755 L F
.664 .789 .941 r
.71908 .33469 m .71832 .33807 L .72125 .33755 L F
.71908 .33469 m .72125 .33755 L .72157 .3373 L F
.398 .826 .961 r
.26033 .52935 m .26281 .52884 L .26434 .52921 L F
.387 .826 .951 r
.26281 .52884 m .26673 .52865 L .26434 .52921 L F
.355 0 .036 r
.2684 .54795 m .26675 .54993 L .26428 .55027 L F
.324 0 0 r
.27018 .54889 m .26675 .54993 L .2684 .54795 L F
.433 0 0 r
.27081 .54814 m .27018 .54889 L .2684 .54795 L F
.522 .394 .647 r
.27918 .55022 m .28195 .55278 L .28155 .55017 L F
.27918 .55022 m .27863 .55383 L .28195 .55278 L F
.622 .543 .744 r
.32 .63479 m .32181 .6319 L .31948 .63282 L F
.32 .63479 m .32551 .63518 L .32181 .6319 L F
.132 .109 .563 r
.32 .63479 m .32177 .63734 L .32551 .63518 L F
0 0 .225 r
.31875 .55151 m .31921 .55493 L .31924 .55206 L F
.501 0 0 r
.31875 .55151 m .31924 .55206 L .31691 .55028 L F
.924 .536 .165 r
.31924 .55206 m .32028 .55131 L .31691 .55028 L F
.31 .313 .701 r
.32028 .55131 m .32214 .54709 L .31944 .54677 L F
.742 .278 .148 r
.31924 .55206 m .32132 .5515 L .32028 .55131 L F
.135 .668 .861 r
.19267 .60044 m .18854 .60017 L .18826 .60101 L F
.19267 .60044 m .18933 .59967 L .18854 .60017 L F
.246 .629 .959 r
.19267 .60044 m .19318 .59951 L .18933 .59967 L F
.19267 .60044 m .19446 .60075 L .19318 .59951 L F
0 0 0 r
.28053 .61263 m .2821 .61053 L .27893 .61312 L F
.27893 .61312 m .27773 .61536 L .28053 .61263 L F
.653 .299 .36 r
.30293 .54155 m .29891 .5434 L .30056 .54255 L F
.30293 .54155 m .30204 .54372 L .29891 .5434 L F
.573 .216 .325 r
.30497 .54343 m .30204 .54372 L .30293 .54155 L F
.611 .203 .244 r
.30542 .54191 m .30497 .54343 L .30293 .54155 L F
.39 .586 .921 r
.36601 .51219 m .36528 .51455 L .3638 .51253 L F
.36601 .51219 m .3678 .5147 L .36528 .51455 L F
.846 .494 0 r
.39114 .53138 m .39275 .53511 L .39189 .53274 L F
.471 .22 .452 r
.36937 .59481 m .37253 .59426 L .37267 .59162 L F
.586 .457 .672 r
.37267 .59162 m .37508 .5913 L .37488 .5887 L F
.607 .331 .473 r
.37267 .59162 m .37482 .59383 L .37508 .5913 L F
.37267 .59162 m .37253 .59426 L .37482 .59383 L F
.259 0 .136 r
.32653 .5608 m .32563 .56271 L .32347 .56333 L F
0 0 0 r
.32893 .56034 m .32563 .56271 L .32653 .5608 L F
.416 .195 .468 r
.2866 .59482 m .28919 .59601 L .28934 .5937 L F
.2866 .59482 m .28717 .59704 L .28919 .59601 L F
.255 .198 .598 r
.37694 .64691 m .3777 .65048 L .3758 .65026 L F
0 0 0 r
.3777 .65048 m .37565 .65372 L .3758 .65026 L F
.633 .466 .639 r
.29846 .57022 m .29976 .57268 L .29641 .57293 L F
.398 .365 .706 r
.30113 .56899 m .29846 .57022 L .29815 .5661 L F
.806 .879 .448 r
.30113 .56899 m .29976 .57268 L .29846 .57022 L F
.293 .151 .511 r
.27111 .56037 m .27311 .55696 L .26963 .55656 L F
.27111 .56037 m .27293 .55953 L .27311 .55696 L F
.368 .24 .573 r
.18336 .5759 m .1852 .57523 L .18508 .57253 L F
.281 .141 .506 r
.18349 .57861 m .1852 .57523 L .18336 .5759 L F
.234 .168 .574 r
.28952 .54437 m .28984 .54698 L .28875 .54444 L F
.137 .666 .87 r
.28612 .54402 m .28952 .54437 L .28875 .54444 L F
.144 0 0 r
.20715 .55152 m .20603 .55257 L .20958 .55088 L F
.756 .661 .758 r
.37612 .54775 m .37214 .54749 L .37463 .54417 L F
.694 .463 .569 r
.37582 .54989 m .37214 .54749 L .37612 .54775 L F
.616 .304 .419 r
.37612 .54775 m .37842 .54991 L .37582 .54989 L F
.642 .296 .37 r
.37868 .54812 m .37842 .54991 L .37612 .54775 L F
.778 .522 .55 r
.35696 .69503 m .35676 .69761 L .35449 .69472 L F
0 0 0 r
.28471 .6074 m .2821 .61053 L .28363 .60954 L F
.28363 .60954 m .2821 .61053 L .28053 .61263 L F
.622 .251 .318 r
.38254 .54784 m .37842 .54991 L .37868 .54812 L F
.38254 .54784 m .38135 .55011 L .37842 .54991 L F
.91 .613 .469 r
.38322 .55064 m .38254 .54784 L .3849 .54808 L F
.38322 .55064 m .38135 .55011 L .38254 .54784 L F
.667 .644 .818 r
.37366 .58131 m .37261 .57886 L .37333 .58146 L F
.37442 .58131 m .37684 .58131 L .37591 .57924 L F
.37505 .57922 m .37591 .57924 L .37539 .57808 L F
.37442 .58131 m .37591 .57924 L .37505 .57922 L F
.674 .457 .584 r
.37505 .57922 m .37478 .57922 L .37261 .57886 L F
.667 .644 .818 r
.37366 .58131 m .37478 .57922 L .37261 .57886 L F
.674 .457 .584 r
.37478 .57922 m .3727 .57917 L .37261 .57886 L F
.37505 .57922 m .37261 .57886 L .37539 .57808 L F
.667 .644 .818 r
.37478 .57922 m .37539 .57808 L .37261 .57886 L F
.37366 .58131 m .37442 .58131 L .37539 .57808 L F
.426 .51 .841 r
.37853 .58093 m .37684 .58131 L .37897 .58133 L F
.674 .457 .584 r
.37693 .5795 m .3766 .57969 L .37623 .57945 L F
.426 .51 .841 r
.3763 .57951 m .37647 .58008 L .3766 .57969 L F
.37647 .58008 m .37684 .58131 L .37663 .57987 L F
.37647 .58008 m .37663 .57987 L .3766 .57969 L F
.37611 .57969 m .37684 .58131 L .3763 .57949 L F
.626 .879 .538 r
.3766 .57969 m .37295 .58413 L .37333 .58146 L F
.37671 .57975 m .37295 .58413 L .3766 .57969 L F
.37671 .57975 m .37438 .58225 L .37295 .58413 L F
.426 .51 .841 r
.3766 .57969 m .37684 .58131 L .37853 .58093 L F
.37539 .57808 m .37591 .57924 L .37606 .57934 L F
.626 .879 .538 r
.37693 .5795 m .37671 .57975 L .3766 .57969 L F
.37693 .5795 m .37678 .57966 L .37671 .57975 L F
.674 .457 .584 r
.37613 .57938 m .3727 .57917 L .37505 .57922 L F
.37693 .5795 m .37623 .57945 L .37613 .57938 L F
.37623 .57945 m .3727 .57917 L .37613 .57938 L F
.37693 .5795 m .37505 .57922 L .37521 .57869 L F
.261 0 .006 r
.37635 .57923 m .37693 .5795 L .37636 .57915 L F
.426 .51 .841 r
.37539 .57808 m .37606 .57934 L .3761 .57933 L F
.674 .457 .584 r
.37655 .57915 m .37593 .57903 L .37539 .57808 L F
.442 .534 .855 r
.37755 .57765 m .37636 .57915 L .37693 .5795 L F
.674 .457 .584 r
.37693 .5795 m .37639 .57925 L .37655 .57915 L F
.37639 .57925 m .37641 .57921 L .37655 .57915 L F
.265 0 .092 r
.37649 .57928 m .37641 .57921 L .37662 .57914 L F
.37641 .57921 m .37636 .57915 L .37644 .57915 L F
.37641 .57921 m .37635 .57923 L .37636 .57915 L F
.674 .457 .584 r
.37635 .57923 m .37593 .57903 L .37655 .57915 L F
.265 0 .092 r
.37641 .57921 m .37644 .57915 L .37662 .57914 L F
.674 .457 .584 r
.37639 .57925 m .37635 .57923 L .37641 .57921 L F
.261 0 .006 r
.37635 .5793 m .37693 .5795 L .37635 .57923 L F
.265 0 .092 r
.37649 .57928 m .37635 .5793 L .37635 .57923 L F
.37649 .57928 m .37635 .57923 L .37641 .57921 L F
.426 .51 .841 r
.37539 .57808 m .3761 .57933 L .37668 .57926 L F
.674 .457 .584 r
.37593 .57903 m .37521 .57869 L .37539 .57808 L F
.426 .51 .841 r
.3777 .58018 m .3767 .57967 L .37853 .58093 L F
.3767 .57967 m .37606 .57934 L .37659 .57968 L F
.3767 .57967 m .37659 .57968 L .37853 .58093 L F
.626 .879 .538 r
.37678 .57966 m .37362 .58308 L .37671 .57975 L F
.37438 .58225 m .37362 .58308 L .37355 .58318 L F
.261 0 .006 r
.3761 .58237 m .37362 .58308 L .37678 .57966 L F
.37689 .57965 m .37678 .57966 L .37693 .5795 L F
.3761 .58237 m .37678 .57966 L .37689 .57965 L F
.426 .51 .841 r
.37635 .5793 m .37606 .57934 L .3777 .58018 L F
.3763 .57949 m .3763 .57951 L .3766 .57969 L F
.674 .457 .584 r
.3766 .57969 m .37333 .58146 L .37623 .57945 L F
.261 0 .006 r
.3761 .58237 m .37689 .57965 L .37635 .5793 L F
.37689 .57965 m .37693 .5795 L .37635 .5793 L F
.426 .51 .841 r
.37668 .57926 m .37635 .5793 L .3777 .58018 L F
.265 0 .092 r
.37679 .57958 m .37628 .58015 L .37635 .5793 L F
.37679 .57958 m .37635 .5793 L .37649 .57928 L F
.457 .359 .656 r
.37684 .58131 m .37929 .58327 L .37897 .58133 L F
.37684 .58131 m .37707 .5851 L .37929 .58327 L F
.265 0 .092 r
.37885 .5816 m .3761 .58237 L .37628 .58015 L F
.37885 .5816 m .37628 .58015 L .37679 .57958 L F
.626 .879 .538 r
.37438 .58225 m .37355 .58318 L .37295 .58413 L F
.426 .51 .841 r
.37591 .57924 m .37611 .57969 L .3763 .57949 L F
0 0 0 r
.37708 .57894 m .37642 .57915 L .37636 .57915 L F
.37708 .57894 m .37636 .57915 L .37755 .57765 L F
.442 .534 .855 r
.37755 .57765 m .37689 .57947 L .37633 .57895 L F
.37699 .57776 m .37633 .57895 L .37539 .57808 L F
.37755 .57765 m .37633 .57895 L .37699 .57776 L F
.436 .299 .595 r
.37539 .57808 m .37755 .57765 L .37754 .57505 L F
.611 .154 0 r
.38034 .57527 m .38183 .57716 L .37754 .57505 L F
0 0 .258 r
.37754 .57505 m .3788 .57397 L .38034 .57527 L F
.37754 .57505 m .3773 .57721 L .3788 .57397 L F
.436 .299 .595 r
.37539 .57808 m .37754 .57505 L .37517 .57647 L F
.845 .542 .476 r
.37289 .57717 m .37721 .57761 L .37539 .57808 L F
.37721 .57761 m .37755 .57765 L .37699 .57776 L F
.37721 .57761 m .37699 .57776 L .37539 .57808 L F
0 0 .258 r
.3773 .57721 m .37726 .57758 L .37814 .5757 L F
.426 .51 .841 r
.37539 .57808 m .37657 .57915 L .37755 .57765 L F
.442 .534 .855 r
.37708 .57894 m .37693 .5795 L .37689 .57947 L F
.37712 .57893 m .37693 .5795 L .37708 .57894 L F
.426 .51 .841 r
.37662 .57914 m .37897 .58133 L .37796 .57871 L F
.37659 .57917 m .37897 .58133 L .37662 .57914 L F
.388 .464 .817 r
.37849 .57856 m .37897 .58133 L .38098 .581 L F
.442 .534 .855 r
.37755 .57765 m .37712 .57893 L .37708 .57894 L F
0 0 0 r
.38011 .57804 m .37708 .57894 L .37755 .57765 L F
.388 .464 .817 r
.37755 .57765 m .37796 .57871 L .37849 .57856 L F
.37796 .57871 m .37897 .58133 L .37849 .57856 L F
0 0 0 r
.38011 .57804 m .37662 .57914 L .37882 .57843 L F
.388 .464 .817 r
.37755 .57765 m .37849 .57856 L .38011 .57804 L F
.37849 .57856 m .38098 .581 L .38011 .57804 L F
0 0 0 r
.37823 .57863 m .37824 .57864 L .37662 .57914 L F
.37824 .57864 m .37912 .57901 L .3767 .57914 L F
.37824 .57864 m .3767 .57914 L .37662 .57914 L F
.38011 .57804 m .38 .57815 L .37823 .57863 L F
.38 .57815 m .37912 .57901 L .37865 .57852 L F
.38011 .57804 m .37642 .57915 L .37708 .57894 L F
.923 .921 .541 r
.37898 .57788 m .37912 .57901 L .38011 .57804 L F
0 0 .294 r
.37946 .57936 m .37912 .57901 L .37898 .57788 L F
.37985 .58056 m .37912 .57901 L .37946 .57936 L F
0 0 0 r
.37865 .57852 m .37912 .57901 L .37823 .57863 L F
.265 0 .092 r
.37885 .5816 m .3765 .57929 L .37912 .57901 L F
.3765 .57929 m .37649 .57928 L .37651 .57928 L F
.3765 .57929 m .37651 .57928 L .37912 .57901 L F
.426 .51 .841 r
.37657 .57915 m .37659 .57917 L .37662 .57914 L F
0 0 0 r
.37882 .57843 m .37662 .57914 L .37642 .57915 L F
.426 .51 .841 r
.37657 .57915 m .37796 .57871 L .37755 .57765 L F
.845 .542 .476 r
.37289 .57717 m .37719 .57819 L .37755 .57765 L F
0 0 .258 r
.37726 .57758 m .37719 .57819 L .37748 .57743 L F
.37726 .57758 m .37748 .57743 L .37814 .5757 L F
.3773 .57721 m .37814 .5757 L .3788 .57397 L F
.265 0 .092 r
.37649 .57928 m .37662 .57914 L .37912 .57901 L F
.674 .457 .584 r
.37623 .57945 m .37333 .58146 L .3727 .57917 L F
.823 .571 .017 r
.36343 .56152 m .36423 .56378 L .36303 .55757 L F
0 0 .146 r
.29266 .56636 m .29337 .5659 L .29392 .56305 L F
0 .114 .647 r
.29266 .56636 m .2944 .56862 L .29337 .5659 L F
0 0 0 r
.32596 .66351 m .32204 .66641 L .32506 .66634 L F
.903 .562 .084 r
.328 .66534 m .32596 .66351 L .32506 .66634 L F
.328 .66534 m .32811 .66418 L .32596 .66351 L F
0 0 .048 r
.3011 .57894 m .30177 .57514 L .29922 .57417 L F
.3011 .57894 m .30153 .57806 L .30177 .57514 L F
.631 .9 .587 r
.3011 .57894 m .29911 .58067 L .30153 .57806 L F
.406 .277 .59 r
.30341 .57875 m .30179 .58274 L .3011 .57894 L F
.323 0 0 r
.29241 .52511 m .29486 .52546 L .29604 .52507 L F
.434 .864 .75 r
.29604 .52507 m .29697 .52432 L .29884 .52461 L F
.29604 .52507 m .29486 .52546 L .29697 .52432 L F
0 .291 .784 r
.72288 .33468 m .72136 .33471 L .71908 .33469 L F
.72288 .33468 m .72398 .33644 L .72136 .33471 L F
.43 .188 .444 r
.37987 .69379 m .37808 .69186 L .38075 .69161 L F
.37987 .69379 m .37769 .6944 L .37808 .69186 L F
.529 .211 .372 r
.35492 .61944 m .35753 .61889 L .35483 .61777 L F
.374 .164 .461 r
.39031 .6813 m .38857 .6794 L .39007 .67861 L F
.39031 .6813 m .38826 .68202 L .38857 .6794 L F
.634 .786 .955 r
.18409 .5994 m .18854 .60017 L .18685 .59909 L F
0 .354 .806 r
.18854 .60017 m .18864 .59936 L .18685 .59909 L F
.18854 .60017 m .18933 .59967 L .18864 .59936 L F
.349 .175 .498 r
.19015 .60286 m .18839 .60389 L .18854 .60017 L F
.19015 .60286 m .18839 .60389 L .18854 .60017 L F
.114 0 .174 r
.20815 .57534 m .20544 .5785 L .20652 .57632 L F
.623 .735 .928 r
.36291 .56664 m .36466 .56789 L .36563 .56584 L F
.568 .118 .142 r
.35278 .59707 m .35659 .59682 L .35349 .59573 L F
.236 0 0 r
.33897 .53158 m .34045 .53138 L .34072 .53148 L F
.733 .89 .496 r
.34251 .52902 m .34094 .53157 L .34072 .53148 L F
0 0 .005 r
.34198 .5306 m .34028 .53264 L .34251 .52902 L F
.515 .151 .287 r
.34251 .52902 m .34449 .53054 L .34198 .5306 L F
.536 .139 .235 r
.34072 .53148 m .34449 .53054 L .34251 .52902 L F
0 0 0 r
.34383 .53091 m .34449 .53054 L .34189 .53119 L F
.34383 .53091 m .34189 .53119 L .34072 .53148 L F
.457 .522 .836 r
.34733 .53073 m .34655 .53465 L .34449 .53054 L F
.102 0 0 r
.34383 .53091 m .34682 .53089 L .34653 .53051 L F
.549 .881 .989 r
.34708 .52981 m .34449 .53054 L .34549 .52916 L F
.627 .918 .644 r
.34549 .52916 m .34449 .53054 L .34383 .53091 L F
.457 .522 .836 r
.34733 .53073 m .34449 .53054 L .34708 .52981 L F
.102 0 0 r
.34383 .53091 m .34653 .53051 L .34549 .52916 L F
.236 0 0 r
.34045 .53138 m .34383 .53091 L .34072 .53148 L F
.733 .89 .496 r
.34094 .53157 m .34028 .53264 L .34072 .53148 L F
.505 .773 .992 r
.21252 .61157 m .21422 .61321 L .21648 .61272 L F
.53 .856 .571 r
.34917 .60459 m .34686 .60675 L .34815 .60698 L F
.498 .427 .707 r
.34657 .61041 m .34815 .60698 L .34686 .60675 L F
0 0 0 r
.28617 .60627 m .28471 .6074 L .28363 .60954 L F
.355 .615 .949 r
.22614 .62215 m .22733 .62089 L .22432 .61905 L F
.22614 .62215 m .22806 .62215 L .22733 .62089 L F
.23 .369 .798 r
.24194 .61504 m .24095 .61703 L .23932 .61349 L F
.361 .533 .89 r
.24194 .61504 m .24246 .61682 L .24095 .61703 L F
.655 .757 .924 r
.36189 .63244 m .36291 .62964 L .3602 .63109 L F
.543 .86 .996 r
.29763 .57155 m .29641 .57293 L .29976 .57268 L F
.29763 .57155 m .29526 .57218 L .29641 .57293 L F
.874 .797 .771 r
.38048 .61403 m .37908 .61699 L .37703 .61599 L F
.494 .528 .821 r
.38031 .61897 m .37703 .61599 L .37908 .61699 L F
.553 .403 .631 r
.38048 .61403 m .38172 .61705 L .37908 .61699 L F
.528 .238 .418 r
.38172 .61705 m .38031 .61897 L .37908 .61699 L F
.586 .83 .991 r
.38196 .6322 m .37716 .63207 L .37676 .63046 L F
.446 .783 .998 r
.38019 .63085 m .38196 .6322 L .37676 .63046 L F
.38019 .63085 m .38345 .63162 L .38196 .6322 L F
.258 .109 .479 r
.38345 .63162 m .38195 .63486 L .38196 .6322 L F
.25 .025 .365 r
.30288 .59645 m .30159 .59487 L .3036 .59407 L F
.30288 .59645 m .30108 .59731 L .30159 .59487 L F
.799 .997 .783 r
.39094 .56782 m .39052 .56971 L .39326 .56681 L F
.546 .059 .05 r
.38884 .57127 m .39052 .56971 L .39094 .56782 L F
.38884 .57127 m .39205 .57092 L .39052 .56971 L F
.618 .453 .636 r
.39052 .56971 m .39346 .56996 L .39326 .56681 L F
.525 .075 .125 r
.39205 .57092 m .39346 .56996 L .39052 .56971 L F
.32 0 .133 r
.36225 .54114 m .35824 .54406 L .35801 .54136 L F
.36225 .54114 m .3604 .54375 L .35824 .54406 L F
.747 .411 .415 r
.36428 .54386 m .3604 .54375 L .36225 .54114 L F
.656 .353 .448 r
.27577 .55613 m .27841 .55637 L .27863 .55383 L F
.712 .569 .691 r
.27841 .55637 m .28195 .55278 L .27863 .55383 L F
.752 .464 .495 r
.36656 .70074 m .36268 .69807 L .36666 .69811 L F
.76 .531 .586 r
.37016 .70089 m .36656 .70074 L .36666 .69811 L F
.23 .584 .945 r
.24767 .77832 m .24908 .77989 L .24713 .77951 L F
.24713 .77951 m .24908 .77989 L .24767 .77832 L F
.476 .355 .635 r
.36832 .60357 m .37021 .60036 L .36801 .60096 L F
.778 .554 .596 r
.38059 .53555 m .37969 .5379 L .37865 .53576 L F
.557 .358 .567 r
.40091 .57511 m .39871 .57271 L .40079 .57271 L F
.40091 .57511 m .39848 .57673 L .39871 .57271 L F
.713 .248 .145 r
.24255 .55348 m .24128 .55267 L .24258 .55093 L F
.555 .353 .561 r
.32557 .57395 m .32524 .5751 L .32281 .57246 L F
.078 .075 .551 r
.32153 .57411 m .32121 .57159 L .32281 .57246 L F
.501 .321 .569 r
.36937 .59481 m .37216 .59644 L .37253 .59426 L F
.36937 .59481 m .36958 .59783 L .37216 .59644 L F
.99 .726 .386 r
.29528 .58772 m .29399 .58686 L .29526 .58506 L F
.735 .866 .445 r
.29526 .58506 m .29399 .58686 L .29598 .58306 L F
.272 .637 .964 r
.3427 .51451 m .34276 .51307 L .34037 .51307 L F
.3427 .51451 m .34465 .51417 L .34276 .51307 L F
.948 .749 .286 r
.36471 .61355 m .36453 .61635 L .36418 .616 L F
.36471 .61355 m .36418 .616 L .3663 .61271 L F
.288 0 0 r
.32967 .52223 m .33225 .5252 L .32972 .52026 L F
.677 .222 .165 r
.32568 .51868 m .32925 .51857 L .32698 .52102 L F
.32568 .51868 m .32743 .52011 L .32925 .51857 L F
.755 .358 .3 r
.32925 .51857 m .3345 .52237 L .32972 .52026 L F
.288 0 0 r
.32963 .5238 m .33059 .52431 L .32967 .52223 L F
.33059 .52431 m .33225 .5252 L .32967 .52223 L F
.32963 .5238 m .32972 .52026 L .3345 .52237 L F
.726 .209 0 r
.33021 .52084 m .32925 .51857 L .32743 .52011 L F
.515 .609 .884 r
.32741 .51608 m .33021 .52084 L .32891 .5205 L F
.32741 .51708 m .32891 .5205 L .32743 .52011 L F
.32741 .51608 m .32891 .5205 L .32741 .51708 L F
.288 0 0 r
.32977 .52388 m .33417 .52453 L .33225 .5252 L F
.32995 .52385 m .33417 .52453 L .32977 .52388 L F
.32963 .5238 m .32995 .52385 L .32977 .52388 L F
.32963 .5238 m .3312 .52427 L .33417 .52453 L F
.398 0 .081 r
.3312 .52427 m .33579 .52168 L .33417 .52453 L F
.3312 .52427 m .33387 .52364 L .33426 .52324 L F
.3326 .52348 m .33426 .52324 L .33579 .52168 L F
.3312 .52427 m .33426 .52324 L .3326 .52348 L F
.469 .779 .998 r
.2802 .55741 m .28215 .55673 L .27841 .55637 L F
.234 .242 .664 r
.3821 .61213 m .38227 .61581 L .38048 .61403 L F
.261 .247 .654 r
.38227 .61581 m .38172 .61705 L .38048 .61403 L F
.793 .546 .564 r
.35235 .58791 m .35614 .59098 L .35604 .58831 L F
.66 .535 .701 r
.35604 .58831 m .35614 .59098 L .35839 .58843 L F
.513 .777 .992 r
.35328 .58635 m .35604 .58831 L .35235 .58791 L F
.933 .596 .371 r
.35459 .56968 m .35331 .57228 L .35074 .57027 L F
.35459 .56968 m .35515 .57273 L .35331 .57228 L F
.405 .297 .617 r
.31742 .57917 m .31973 .58115 L .31914 .57727 L F
.307 .294 .681 r
.31822 .58179 m .31973 .58115 L .31742 .57917 L F
.607 .493 .698 r
.31785 .6104 m .32043 .60997 L .31997 .60748 L F
.169 .021 .424 r
.31785 .6104 m .31941 .61217 L .32043 .60997 L F
.31785 .6104 m .31755 .61296 L .31941 .61217 L F
.385 .795 .98 r
.25117 .62238 m .25345 .62203 L .25523 .62274 L F
.034 .517 .881 r
.2553 .622 m .25523 .62274 L .25345 .62203 L F
.2553 .622 m .25743 .62335 L .25523 .62274 L F
0 0 .108 r
.36281 .54863 m .36381 .54908 L .36591 .55024 L F
.36281 .54863 m .36257 .55048 L .36381 .54908 L F
.735 .36 0 r
.32631 .58592 m .32624 .58501 L .32618 .58367 L F
.32624 .58509 m .32728 .58763 L .32624 .58501 L F
.32659 .58642 m .32728 .58763 L .32624 .58509 L F
.411 .297 .612 r
.32848 .58656 m .32728 .58763 L .32682 .58683 L F
.32738 .58648 m .32682 .58683 L .32659 .58642 L F
.32848 .58656 m .32682 .58683 L .32738 .58648 L F
.32941 .58684 m .32728 .58763 L .32848 .58656 L F
.32795 .58626 m .32659 .58642 L .32771 .58621 L F
.32987 .58666 m .32782 .58651 L .32795 .58626 L F
.32782 .58651 m .32659 .58642 L .32795 .58626 L F
.721 .571 .685 r
.33233 .58364 m .32987 .58666 L .32835 .58295 L F
.807 .745 .795 r
.32795 .58596 m .32631 .58592 L .32835 .58295 L F
.741 .646 .754 r
.32835 .58295 m .32863 .58364 L .32751 .58473 L F
.32835 .58295 m .32751 .58473 L .32734 .58442 L F
.32863 .58364 m .32987 .58666 L .32795 .58626 L F
.068 .283 .771 r
.32795 .58596 m .32808 .58578 L .32757 .58485 L F
0 0 0 r
.32795 .58596 m .32802 .58602 L .32808 .58578 L F
.741 .646 .754 r
.32863 .58364 m .32802 .58602 L .32631 .58592 L F
.32802 .58602 m .32795 .58626 L .32779 .58623 L F
0 0 0 r
.32795 .58596 m .32787 .58615 L .32802 .58602 L F
.246 0 0 r
.32746 .58626 m .32795 .58596 L .32631 .58592 L F
.32746 .58626 m .32771 .58621 L .32795 .58596 L F
.741 .646 .754 r
.32787 .58615 m .32779 .58623 L .32771 .58621 L F
.246 0 0 r
.32771 .58621 m .32786 .58619 L .32787 .58615 L F
.32771 .58621 m .32787 .58615 L .32795 .58596 L F
.741 .646 .754 r
.32802 .58602 m .32787 .58615 L .32631 .58592 L F
.32787 .58615 m .32771 .58621 L .32631 .58592 L F
0 0 0 r
.32802 .58602 m .32786 .58619 L .32806 .58606 L F
.32787 .58615 m .32786 .58619 L .32802 .58602 L F
.3 .09 .418 r
.32835 .58295 m .32734 .58442 L .32618 .58367 L F
.735 .36 0 r
.32631 .58592 m .32659 .58642 L .32624 .58509 L F
.3 .09 .418 r
.32734 .58442 m .32631 .58592 L .3262 .58395 L F
.32734 .58442 m .3262 .58395 L .32618 .58367 L F
.068 .283 .771 r
.32744 .58446 m .3292 .58415 L .32664 .58213 L F
.32757 .58485 m .32798 .58467 L .32744 .58446 L F
.32798 .58467 m .3292 .58415 L .32744 .58446 L F
.32808 .58578 m .3292 .58415 L .32757 .58485 L F
.741 .646 .754 r
.32734 .58442 m .32751 .58473 L .32631 .58592 L F
0 0 0 r
.32808 .58578 m .32806 .58606 L .32867 .58492 L F
.32802 .58602 m .32806 .58606 L .32808 .58578 L F
.32867 .58492 m .32881 .58679 L .3292 .58415 L F
.32806 .58606 m .32881 .58679 L .32867 .58492 L F
.926 .729 .617 r
.32728 .58763 m .32886 .59093 L .32989 .58869 L F
.083 .293 .776 r
.32966 .58938 m .32886 .59093 L .32728 .58763 L F
0 0 0 r
.32806 .58606 m .32713 .58795 L .32881 .58679 L F
.32786 .58619 m .32713 .58795 L .32806 .58606 L F
.411 .297 .612 r
.32771 .58621 m .32659 .58642 L .32631 .58592 L F
.246 0 0 r
.32452 .58807 m .32746 .58626 L .32631 .58592 L F
.411 .297 .612 r
.32987 .58666 m .32941 .58684 L .32848 .58656 L F
.246 0 0 r
.32668 .58674 m .32713 .58795 L .32786 .58619 L F
.32668 .58674 m .32786 .58619 L .32746 .58626 L F
.32452 .58807 m .32699 .58796 L .32668 .58674 L F
.32699 .58796 m .32713 .58795 L .32668 .58674 L F
.358 .677 .977 r
.19635 .60113 m .19938 .60323 L .20144 .60311 L F
.055 .171 .67 r
.2199 .60275 m .22093 .60671 L .22001 .60669 L F
0 0 0 r
.27272 .61739 m .27057 .61963 L .2725 .61781 L F
0 0 .056 r
.27018 .61992 m .2725 .61781 L .27057 .61963 L F
.095 0 0 r
.27018 .61992 m .26785 .62324 L .27125 .62109 L F
0 0 .377 r
.34147 .56483 m .34012 .56645 L .34032 .5634 L F
0 0 .448 r
.2857 .59786 m .28655 .59995 L .28717 .59704 L F
.2857 .59786 m .28597 .60047 L .28655 .59995 L F
.183 .413 .85 r
.24542 .61861 m .24483 .62041 L .24246 .61682 L F
.376 .633 .955 r
.24542 .61861 m .24682 .62044 L .24483 .62041 L F
.203 .434 .861 r
.20144 .60311 m .20183 .60463 L .20252 .60293 L F
.261 .505 .899 r
.20183 .60463 m .20528 .60619 L .20252 .60293 L F
.293 .229 .611 r
.31822 .58179 m .31775 .58593 L .32003 .58385 L F
.414 .408 .743 r
.31905 .58773 m .32003 .58385 L .31775 .58593 L F
.534 0 0 r
.28243 .64423 m .28553 .64594 L .28478 .64494 L F
.002 .388 .846 r
.28553 .64594 m .287 .64551 L .28478 .64494 L F
.28553 .64594 m .28823 .64731 L .287 .64551 L F
.635 .811 .968 r
.36882 .66754 m .36598 .66871 L .36434 .66682 L F
.737 .96 .941 r
.37353 .53572 m .37228 .5353 L .37433 .53375 L F
.853 .714 .709 r
.33804 .67586 m .33945 .67928 L .33606 .67973 L F
.806 .607 .632 r
.33945 .67928 m .33516 .68154 L .33606 .67973 L F
.33945 .67928 m .33924 .68209 L .33516 .68154 L F
.773 .681 .763 r
.34191 .67617 m .33945 .67928 L .33804 .67586 L F
.075 0 0 r
.36093 .58425 m .35934 .5841 L .35812 .58397 L F
.337 .814 .891 r
.36186 .58351 m .36093 .58425 L .36439 .58293 L F
.36186 .58351 m .35934 .5841 L .36093 .58425 L F
.055 0 .226 r
.32542 .6506 m .32583 .64784 L .32782 .64697 L F
.793 .546 .564 r
.35235 .58791 m .35218 .59127 L .35614 .59098 L F
.565 .398 .614 r
.35614 .59098 m .35871 .59138 L .35839 .58843 L F
.35614 .59098 m .35871 .59138 L .35839 .58843 L F
.447 .209 .459 r
.31315 .56033 m .31518 .56046 L .31592 .55713 L F
.55 .369 .588 r
.31843 .55395 m .31592 .55713 L .31854 .55608 L F
0 0 .212 r
.31592 .55713 m .317 .5579 L .31854 .55608 L F
.31592 .55713 m .31518 .56046 L .317 .5579 L F
.55 .369 .588 r
.31854 .55608 m .31592 .55713 L .31843 .55395 L F
0 0 0 r
.3777 .65048 m .37658 .65265 L .37565 .65372 L F
.37658 .65265 m .37543 .65419 L .37565 .65372 L F
.714 .895 .962 r
.39377 .56404 m .39326 .56681 L .39588 .56532 L F
.873 .994 .769 r
.39377 .56404 m .39094 .56782 L .39326 .56681 L F
0 0 .272 r
.33461 .64462 m .33344 .64794 L .33456 .647 L F
.794 .663 .112 r
.33344 .64794 m .33315 .64919 L .33456 .647 L F
.133 .233 .703 r
.33994 .57136 m .3389 .57345 L .33763 .56954 L F
.516 .352 .597 r
.33994 .57136 m .33751 .57453 L .3389 .57345 L F
.07 0 0 r
.33751 .57453 m .34193 .57282 L .3389 .57345 L F
.451 0 0 r
.37634 .5175 m .37564 .51688 L .3742 .51532 L F
.37634 .5175 m .37787 .5186 L .37564 .51688 L F
0 0 .029 r
.23756 .62917 m .23562 .63033 L .23671 .63027 L F
.23756 .62917 m .23584 .63142 L .23562 .63033 L F
.385 .094 .342 r
.3846 .5913 m .38174 .59406 L .38228 .59188 L F
.3846 .5913 m .38174 .59406 L .38228 .59188 L F
0 0 .562 r
.39114 .53138 m .3929 .53389 L .39275 .53511 L F
0 0 .519 r
.39415 .53552 m .39275 .53511 L .3929 .53389 L F
.39415 .53552 m .39411 .53759 L .39275 .53511 L F
0 0 0 r
.35832 .53124 m .35738 .53356 L .35588 .53442 L F
.355 .795 .634 r
.35738 .53356 m .35541 .53465 L .35588 .53442 L F
.729 .801 .909 r
.71994 .31442 m .72292 .31367 L .72331 .31587 L F
.71994 .31442 m .72292 .31367 L .72331 .31587 L F
.651 .748 .921 r
.72362 .31281 m .72292 .31367 L .72331 .31587 L F
.72362 .31281 m .72292 .31367 L .72331 .31587 L F
.252 .531 .918 r
.30421 .65596 m .30824 .6572 L .30643 .65592 L F
.30421 .65596 m .30643 .65592 L .30413 .65603 L F
.56 .283 .452 r
.35951 .58145 m .36239 .57886 L .35984 .57903 L F
.773 .681 .762 r
.34011 .67217 m .34191 .67617 L .33804 .67586 L F
.951 .696 .515 r
.35235 .58791 m .35218 .59127 L .35069 .58753 L F
.35235 .58791 m .35218 .59127 L .35069 .58753 L F
.133 .233 .703 r
.33994 .57136 m .33763 .56954 L .34177 .56965 L F
.969 .733 .525 r
.34177 .56965 m .34193 .57282 L .33994 .57136 L F
.348 .1 .39 r
.19329 .56361 m .19545 .56284 L .19597 .56029 L F
.262 .027 .357 r
.19597 .56029 m .1973 .56193 L .19783 .55966 L F
.19597 .56029 m .19545 .56284 L .1973 .56193 L F
.786 .993 .768 r
.29142 .5921 m .28934 .5937 L .29232 .59071 L F
.498 .905 .815 r
.27328 .52622 m .27324 .52556 L .27547 .52563 L F
.27328 .52622 m .27101 .5268 L .27324 .52556 L F
.749 .528 0 r
.22178 .61219 m .22197 .61443 L .21865 .61327 L F
.184 .515 .915 r
.21865 .61327 m .22197 .61443 L .22183 .6143 L F
.519 .033 .042 r
.22178 .61219 m .21865 .61327 L .21683 .61269 L F
.184 .515 .915 r
.21865 .61327 m .22183 .6143 L .21935 .61196 L F
.519 .033 .042 r
.21683 .61269 m .21865 .61327 L .21648 .61272 L F
.749 .528 0 r
.22178 .61219 m .22223 .61583 L .22197 .61443 L F
.129 .678 .765 r
.23677 .53466 m .23598 .53487 L .23439 .53506 L F
.23677 .53466 m .23838 .5346 L .23598 .53487 L F
.675 .964 .753 r
.30058 .54318 m .29891 .5434 L .30111 .5436 L F
.024 0 0 r
.30056 .54255 m .29891 .5434 L .2977 .54356 L F
.675 .964 .753 r
.29937 .54221 m .29891 .5434 L .30058 .54318 L F
.024 0 0 r
.2977 .54356 m .29891 .5434 L .29665 .54393 L F
.983 .781 .556 r
.29224 .63517 m .29358 .63494 L .2922 .63447 L F
0 .193 .724 r
.20862 .58736 m .20883 .58921 L .20646 .58772 L F
.025 0 .015 r
.3752 .53888 m .37382 .53887 L .37865 .53576 L F
.3752 .53888 m .37304 .54045 L .37382 .53887 L F
.631 .68 .878 r
.37876 .67722 m .37405 .67547 L .37624 .67519 L F
.713 .76 .89 r
.38049 .67473 m .37876 .67722 L .37624 .67519 L F
.959 .662 .429 r
.36221 .58115 m .36439 .58293 L .36239 .57886 L F
.665 .799 .947 r
.3655 .58179 m .36439 .58293 L .36221 .58115 L F
.586 .04 0 r
.36439 .58293 m .36598 .5842 L .36186 .58351 L F
.784 .635 .695 r
.2353 .61307 m .23938 .61057 L .23532 .61128 L F
.542 0 0 r
.30078 .64545 m .30004 .64447 L .29731 .6442 L F
.547 .759 .975 r
.27242 .53678 m .27381 .53543 L .27169 .53595 L F
.27242 .53678 m .27564 .53715 L .27381 .53543 L F
.316 .124 .454 r
.27242 .53678 m .27387 .53969 L .27564 .53715 L F
.27242 .53678 m .27197 .54083 L .27387 .53969 L F
.218 0 .028 r
.2008 .55647 m .20281 .55602 L .20419 .55391 L F
.086 0 0 r
.20419 .55391 m .20483 .55516 L .20603 .55257 L F
.20419 .55391 m .20281 .55602 L .20483 .55516 L F
.616 .552 .76 r
.37849 .64081 m .37739 .64476 L .37595 .64115 L F
.37849 .64081 m .38002 .64473 L .37739 .64476 L F
.587 .308 .46 r
.38002 .64473 m .37948 .64726 L .37739 .64476 L F
.535 .302 .508 r
.37739 .64476 m .37948 .64726 L .37694 .64691 L F
.587 .308 .46 r
.38002 .64473 m .37948 .64726 L .37739 .64476 L F
.398 .393 .737 r
.37264 .52846 m .37427 .52862 L .37334 .52427 L F
.381 .157 .444 r
.33724 .64134 m .33461 .64462 L .33421 .64084 L F
.645 .63 .82 r
.33456 .647 m .33421 .64084 L .33461 .64462 L F
.643 .469 .633 r
.36081 .55629 m .35816 .55705 L .36078 .55394 L F
.642 .468 .632 r
.36487 .55481 m .36078 .55394 L .36403 .55379 L F
.36487 .55481 m .36081 .55629 L .36078 .55394 L F
.426 .07 .256 r
.25994 .54801 m .26243 .54765 L .26418 .54442 L F
.432 .076 .259 r
.26418 .54442 m .26542 .54694 L .26624 .54378 L F
.26418 .54442 m .26243 .54765 L .26542 .54694 L F
.74 .437 .469 r
.37016 .70089 m .36871 .70382 L .36656 .70074 L F
.568 .244 .38 r
.37221 .70293 m .37016 .70089 L .37272 .70066 L F
.37221 .70293 m .36871 .70382 L .37016 .70089 L F
.975 .744 .527 r
.3149 .53353 m .31688 .53166 L .31663 .53174 L F
.3149 .53353 m .31655 .5349 L .31688 .53166 L F
.755 .885 .476 r
.31663 .53174 m .31688 .53166 L .31731 .53027 L F
0 0 .226 r
.31688 .53166 m .31749 .53348 L .31731 .53027 L F
.31688 .53166 m .31655 .5349 L .31749 .53348 L F
0 .295 .793 r
.27564 .53715 m .27525 .53502 L .27381 .53543 L F
.27564 .53715 m .27699 .53735 L .27525 .53502 L F
0 0 0 r
.27564 .53715 m .27596 .53854 L .27699 .53735 L F
.27564 .53715 m .27387 .53969 L .27596 .53854 L F
.584 .014 0 r
.29993 .65034 m .30069 .65062 L .2987 .65039 L F
.697 .416 .495 r
.36268 .69807 m .35855 .70051 L .35859 .69778 L F
.36268 .69807 m .36258 .70051 L .35855 .70051 L F
.752 .464 .495 r
.36656 .70074 m .36258 .70051 L .36268 .69807 L F
.437 .435 .759 r
.31315 .56033 m .31618 .56221 L .31518 .56046 L F
.538 .411 .656 r
.31315 .56033 m .3135 .56297 L .31618 .56221 L F
.469 .162 .362 r
.19012 .56615 m .19256 .56576 L .19329 .56361 L F
.22 0 .251 r
.19329 .56361 m .19448 .56486 L .19545 .56284 L F
.19329 .56361 m .19256 .56576 L .19448 .56486 L F
.458 .32 .604 r
.40264 .56928 m .40318 .57267 L .40079 .57271 L F
.443 .214 .47 r
.40318 .57267 m .40091 .57511 L .40079 .57271 L F
.40318 .57267 m .40091 .57511 L .40079 .57271 L F
0 0 .116 r
.30822 .62644 m .30855 .62748 L .31015 .62553 L F
.665 .698 .871 r
.36642 .65783 m .36804 .65825 L .36544 .65898 L F
0 0 0 r
.36936 .65662 m .36544 .65898 L .36804 .65825 L F
.815 .644 .67 r
.3679 .65768 m .36413 .66051 L .36544 .65898 L F
.36413 .66051 m .36392 .66067 L .36544 .65898 L F
.665 .698 .871 r
.36354 .65709 m .36642 .65783 L .36544 .65898 L F
.082 0 0 r
.25115 .55224 m .24947 .5525 L .24715 .55254 L F
.414 .801 .989 r
.24947 .5525 m .24867 .55242 L .24715 .55254 L F
.132 0 0 r
.24892 .55119 m .24715 .55254 L .24551 .55268 L F
.476 0 0 r
.25115 .55224 m .24715 .55254 L .24892 .55119 L F
.414 .801 .989 r
.24867 .55242 m .24552 .55208 L .24715 .55254 L F
.132 0 0 r
.24551 .55268 m .24715 .55254 L .24487 .55296 L F
.76 .681 .775 r
.34028 .53264 m .33749 .53549 L .33593 .53223 L F
.406 .277 .59 r
.30341 .57875 m .30372 .58206 L .30179 .58274 L F
.372 0 0 r
.30457 .58445 m .30179 .58274 L .30372 .58206 L F
.887 .981 .821 r
.17864 .68542 m .17903 .68623 L .18012 .68422 L F
.18012 .68422 m .17903 .68623 L .17864 .68542 L F
.705 .702 .845 r
.17903 .68623 m .18036 .68587 L .18012 .68422 L F
.17903 .68623 m .18036 .68587 L .18012 .68422 L F
.615 .216 0 r
.39707 .54292 m .39737 .54346 L .39596 .54098 L F
.688 .321 0 r
.39538 .53932 m .39707 .54292 L .39596 .54098 L F
.39538 .53932 m .39654 .54201 L .39707 .54292 L F
.39654 .54201 m .39669 .54236 L .39707 .54292 L F
.615 .216 0 r
.39707 .54292 m .39791 .54439 L .39737 .54346 L F
0 0 .365 r
.39854 .54542 m .39791 .54439 L .39707 .54292 L F
.645 .129 0 r
.39885 .5459 m .39854 .54542 L .39823 .5436 L F
0 0 .365 r
.39854 .54542 m .39943 .54699 L .39828 .54503 L F
0 .014 .577 r
.39854 .54542 m .40059 .54784 L .40072 .54884 L F
.645 .129 0 r
.39905 .54662 m .40059 .54784 L .39854 .54542 L F
.39905 .54662 m .39854 .54542 L .39885 .5459 L F
0 0 .365 r
.39854 .54542 m .39828 .54503 L .39791 .54439 L F
.735 .658 .774 r
.31835 .52354 m .31547 .52572 L .31397 .52197 L F
.642 .234 .254 r
.30868 .54354 m .30542 .54191 L .30874 .54106 L F
.30868 .54354 m .30497 .54343 L .30542 .54191 L F
.751 .701 .804 r
.30023 .56307 m .29815 .5661 L .29541 .56221 L F
.552 .428 .666 r
.30023 .56307 m .30097 .56562 L .29815 .5661 L F
.398 .365 .706 r
.30113 .56899 m .29815 .5661 L .30097 .56562 L F
.794 .502 .495 r
.31814 .6472 m .31892 .64514 L .31427 .64428 L F
.658 .511 .672 r
.31814 .6472 m .32074 .644 L .31892 .64514 L F
.636 .771 .945 r
.34506 .51129 m .3407 .50985 L .34332 .50896 L F
.642 .716 .901 r
.34749 .51017 m .34506 .51129 L .34332 .50896 L F
.204 0 0 r
.26437 .63527 m .26481 .63547 L .2626 .63436 L F
.26437 .63527 m .26729 .63602 L .26481 .63547 L F
0 0 0 r
.32472 .55244 m .32466 .55252 L .32796 .55095 L F
0 0 .127 r
.32916 .54958 m .32796 .55095 L .32971 .54727 L F
0 0 0 r
.32916 .54958 m .32466 .55252 L .32796 .55095 L F
.716 .473 .556 r
.32466 .55252 m .33094 .55323 L .32796 .55095 L F
.743 .806 .903 r
.39225 .58407 m .38917 .5868 L .39552 .58751 L F
.184 0 0 r
.38927 .58994 m .39552 .58751 L .38917 .5868 L F
.38927 .58994 m .39173 .58963 L .39552 .58751 L F
.194 .452 .876 r
.39552 .58751 m .394 .58335 L .39225 .58407 L F
.474 .286 .545 r
.39695 .58787 m .39637 .5922 L .3945 .59113 L F
.391 .214 .518 r
.39873 .5909 m .39637 .5922 L .39695 .58787 L F
.194 .452 .876 r
.39552 .58751 m .39697 .58803 L .394 .58335 L F
.062 0 0 r
.39552 .58751 m .39419 .58892 L .39697 .58803 L F
.39552 .58751 m .39173 .58963 L .39419 .58892 L F
0 0 .07 r
.27166 .6257 m .27072 .6284 L .26958 .62904 L F
0 .204 .673 r
.27262 .63129 m .26958 .62904 L .26917 .63163 L F
.27262 .63129 m .26917 .63163 L .27133 .63148 L F
.404 .182 .459 r
.27133 .63148 m .26958 .62904 L .27072 .6284 L F
.27133 .63148 m .26917 .63163 L .26958 .62904 L F
.152 0 .163 r
.31096 .65416 m .31363 .65137 L .31243 .65386 L F
.549 .826 .476 r
.31461 .65021 m .31363 .65137 L .31626 .64833 L F
0 0 0 r
.31243 .65386 m .31363 .65137 L .31461 .65021 L F
.998 .783 .456 r
.29521 .54644 m .29639 .54674 L .29665 .54393 L F
0 0 0 r
.29628 .5449 m .29521 .54644 L .29665 .54393 L F
.429 0 .01 r
.29628 .5449 m .29389 .54609 L .29521 .54644 L F
0 0 0 r
.29521 .54644 m .28973 .54721 L .29137 .54726 L F
.29259 .54681 m .29236 .54685 L .28973 .54721 L F
.29521 .54644 m .29236 .54685 L .29259 .54681 L F
.429 0 .01 r
.29389 .54609 m .29236 .54685 L .29521 .54644 L F
.505 .554 .84 r
.29137 .54726 m .29279 .54971 L .29462 .54898 L F
.29137 .54726 m .29462 .54898 L .29521 .54644 L F
.429 0 .01 r
.29628 .5449 m .29498 .54667 L .29236 .54685 L F
.154 0 0 r
.29592 .54601 m .29735 .54613 L .29498 .54667 L F
.29592 .54601 m .29498 .54667 L .29628 .5449 L F
.716 .267 .184 r
.29735 .54613 m .29466 .54598 L .29498 .54667 L F
.509 .409 .677 r
.29338 .54501 m .29371 .54621 L .29371 .54621 L F
.29271 .54255 m .29338 .545 L .29338 .54501 L F
.29338 .545 m .29371 .54621 L .29338 .54501 L F
.29271 .54255 m .29371 .54621 L .29567 .54573 L F
.407 .345 .675 r
.29258 .54649 m .29371 .54621 L .29341 .54513 L F
.665 .873 .497 r
.2925 .54651 m .29227 .54687 L .29236 .54685 L F
.407 .345 .675 r
.29182 .54772 m .29341 .54513 L .29186 .54747 L F
.716 .267 .184 r
.29466 .54598 m .29278 .54587 L .29371 .54621 L F
.29466 .54598 m .29371 .54621 L .29498 .54667 L F
.998 .783 .456 r
.29521 .54644 m .29632 .54746 L .29639 .54674 L F
.716 .267 .184 r
.29735 .54613 m .29645 .54687 L .29466 .54598 L F
.29645 .54687 m .29615 .54711 L .29549 .54661 L F
.29645 .54687 m .29549 .54661 L .29466 .54598 L F
.509 .409 .677 r
.29578 .54585 m .2953 .5462 L .29622 .54632 L F
.29495 .54646 m .29397 .54719 L .29549 .54661 L F
.29371 .54621 m .29397 .54719 L .29578 .54585 L F
.665 .873 .497 r
.29371 .54621 m .29236 .54685 L .29498 .54667 L F
.29371 .54621 m .29371 .54621 L .29371 .54621 L F
.407 .345 .675 r
.29182 .54772 m .29397 .54719 L .29371 .54621 L F
.665 .873 .497 r
.29371 .54621 m .29236 .54685 L .29371 .54621 L F
.2925 .54651 m .29236 .54685 L .29371 .54621 L F
.407 .345 .675 r
.29182 .54772 m .29371 .54621 L .29258 .54649 L F
.683 .513 .65 r
.29263 .54073 m .29107 .54463 L .28952 .54437 L F
.686 .491 .618 r
.29107 .54463 m .28984 .54698 L .28952 .54437 L F
.54 .512 .773 r
.28973 .54721 m .29236 .54685 L .29128 .5438 L F
.745 .549 .629 r
.28566 .5501 m .28801 .55055 L .28751 .54757 L F
.347 .275 .632 r
.28751 .54757 m .28801 .55055 L .28967 .54957 L F
.677 .217 .153 r
.28751 .54757 m .28967 .54957 L .28562 .54908 L F
.465 .452 .759 r
.28686 .54503 m .28784 .54851 L .28973 .54721 L F
.615 .43 .608 r
.28686 .54503 m .28975 .54568 L .28978 .54211 L F
.126 .043 .483 r
.28978 .54211 m .28975 .54568 L .29128 .5438 L F
.465 .452 .759 r
.28686 .54503 m .28973 .54721 L .28975 .54568 L F
.54 .512 .773 r
.28973 .54721 m .2903 .54596 L .28975 .54568 L F
.2903 .54596 m .29128 .5438 L .29001 .54536 L F
.2903 .54596 m .29001 .54536 L .28975 .54568 L F
.631 .865 .986 r
.28973 .54721 m .28967 .54957 L .29137 .54726 L F
.28973 .54721 m .28784 .54851 L .28967 .54957 L F
.646 .62 .809 r
.28967 .54957 m .29279 .54971 L .29137 .54726 L F
.688 .542 .683 r
.28871 .54672 m .29172 .54769 L .29177 .54731 L F
.29172 .54769 m .2918 .54757 L .29177 .54731 L F
.668 .278 .298 r
.29236 .54685 m .29189 .54743 L .29187 .54741 L F
.29119 .54681 m .29187 .54741 L .29115 .54681 L F
.29236 .54685 m .29187 .54741 L .29119 .54681 L F
.74 .624 .729 r
.29236 .54685 m .29119 .54681 L .29128 .5438 L F
.29119 .54681 m .28871 .54672 L .29128 .5438 L F
.407 .345 .675 r
.29177 .54731 m .29271 .54255 L .29128 .5438 L F
.2918 .54757 m .29187 .54741 L .29177 .54731 L F
.29186 .54747 m .29187 .54741 L .2918 .54757 L F
.29186 .54747 m .29189 .54743 L .29187 .54741 L F
.693 .267 .233 r
.28871 .54672 m .29077 .54884 L .29182 .54772 L F
.668 .278 .298 r
.29189 .54743 m .29134 .54812 L .29115 .54681 L F
.665 .873 .497 r
.29208 .5469 m .29077 .54884 L .29189 .54743 L F
.29196 .54732 m .29189 .54743 L .29196 .54735 L F
.407 .345 .675 r
.29187 .54741 m .29341 .54513 L .29271 .54255 L F
.665 .873 .497 r
.29208 .5469 m .29189 .54743 L .29196 .54732 L F
.407 .345 .675 r
.29182 .54772 m .29186 .54747 L .2918 .54757 L F
.29187 .54741 m .29271 .54255 L .29177 .54731 L F
.29189 .54743 m .29341 .54513 L .29187 .54741 L F
.668 .278 .298 r
.29115 .54681 m .29134 .54812 L .2907 .54679 L F
.665 .873 .497 r
.2923 .54686 m .29196 .54735 L .29236 .54685 L F
.29208 .5469 m .29196 .54735 L .2923 .54686 L F
.688 .542 .683 r
.29172 .54769 m .29182 .54772 L .2918 .54757 L F
.668 .278 .298 r
.2907 .54679 m .29071 .54711 L .28871 .54672 L F
.29134 .54812 m .29077 .54884 L .2907 .54679 L F
.688 .542 .683 r
.28871 .54672 m .29177 .54731 L .29128 .5438 L F
.668 .278 .298 r
.29071 .54711 m .29077 .54884 L .28871 .54672 L F
.693 .365 .416 r
.29278 .54587 m .29549 .54661 L .29397 .54719 L F
.716 .267 .184 r
.29466 .54598 m .29548 .54765 L .29278 .54587 L F
.29615 .54711 m .29548 .54765 L .29466 .54598 L F
.693 .365 .416 r
.29278 .54587 m .29622 .54632 L .29549 .54661 L F
.509 .409 .677 r
.29567 .54573 m .29371 .54621 L .29578 .54585 L F
.665 .873 .497 r
.29278 .54587 m .2925 .54651 L .29371 .54621 L F
.29278 .54587 m .29208 .5469 L .29227 .54687 L F
.29278 .54587 m .29227 .54687 L .2925 .54651 L F
.474 0 0 r
.33154 .60676 m .33378 .60835 L .33209 .60745 L F
.33154 .60676 m .33209 .60745 L .33209 .60697 L F
.117 0 0 r
.33317 .60681 m .33154 .60676 L .33132 .60668 L F
.457 .259 .522 r
.33546 .60393 m .33537 .6065 L .33317 .60681 L F
.605 .16 .168 r
.33537 .6065 m .33154 .60676 L .33317 .60681 L F
.33537 .6065 m .33378 .60835 L .33154 .60676 L F
.474 0 0 r
.33154 .60676 m .33209 .60697 L .3321 .60457 L F
.117 0 0 r
.33132 .60668 m .33154 .60676 L .32926 .60653 L F
.123 0 0 r
.22542 .53733 m .2286 .53697 L .22663 .53754 L F
.46 0 0 r
.29632 .54746 m .29823 .54869 L .30077 .54731 L F
.444 .37 .679 r
.30368 .54972 m .30077 .54731 L .30261 .54679 L F
.30368 .54972 m .30131 .55085 L .30077 .54731 L F
.297 0 0 r
.30077 .54731 m .30079 .5485 L .30261 .54679 L F
.30077 .54731 m .29823 .54869 L .30079 .5485 L F
.646 .809 .961 r
.36622 .57894 m .36239 .57886 L .36483 .57849 L F
.809 .594 .612 r
.36221 .58115 m .36622 .57894 L .36239 .57886 L F
.36221 .58115 m .3655 .58179 L .36622 .57894 L F
.452 .24 .5 r
.36849 .58003 m .3655 .58179 L .36622 .57894 L F
.36849 .58003 m .36622 .57894 L .36483 .57849 L F
0 0 0 r
.317 .5579 m .32069 .55666 L .31854 .55608 L F
.64 .957 .776 r
.32069 .55666 m .31897 .55731 L .32002 .55648 L F
.686 .704 .861 r
.32112 .55677 m .31854 .55608 L .32069 .55666 L F
.457 .275 .544 r
.32079 .55337 m .32069 .55666 L .31854 .55608 L F
.64 .957 .776 r
.32069 .55666 m .32002 .55648 L .32177 .55511 L F
.686 .704 .861 r
.32234 .5571 m .32112 .55677 L .32069 .55666 L F
.681 .94 .964 r
.32234 .5571 m .32069 .55666 L .32351 .55531 L F
.827 .954 .899 r
.37535 .66476 m .37278 .66708 L .3731 .66481 L F
.799 .934 .921 r
.3731 .66481 m .37278 .66708 L .37128 .66647 L F
.448 .162 .384 r
.40597 .56625 m .40491 .56905 L .40264 .56928 L F
0 0 .519 r
.40508 .56277 m .40636 .56477 L .40597 .56625 L F
0 0 .056 r
.40674 .56732 m .40597 .56625 L .40636 .56477 L F
.40674 .56732 m .40491 .56905 L .40597 .56625 L F
.574 .661 .896 r
.36128 .53005 m .36053 .52682 L .36169 .52855 L F
.278 0 0 r
.36053 .52682 m .36423 .52636 L .36169 .52855 L F
.597 .585 .81 r
.36476 .52796 m .36169 .52855 L .36423 .52636 L F
0 0 .343 r
.36244 .52703 m .36169 .52855 L .36476 .52796 L F
.36224 .52745 m .36128 .53005 L .36169 .52855 L F
.36203 .5281 m .36128 .53005 L .36224 .52745 L F
.574 .661 .896 r
.36128 .53005 m .35797 .53016 L .36053 .52682 L F
0 0 .343 r
.36244 .52703 m .36227 .52978 L .36128 .53005 L F
.646 .302 .375 r
.36053 .52682 m .35853 .53013 L .36148 .52985 L F
.36177 .52893 m .36148 .52985 L .36227 .52978 L F
.36053 .52682 m .36148 .52985 L .36177 .52893 L F
0 0 .343 r
.36244 .52703 m .36203 .5281 L .36224 .52745 L F
0 0 0 r
.32966 .65904 m .32935 .65938 L .32811 .66418 L F
.52 .132 .247 r
.32997 .62502 m .33324 .62546 L .3337 .62356 L F
.491 .107 .239 r
.3337 .62356 m .33781 .62332 L .33603 .62272 L F
.3337 .62356 m .33324 .62546 L .33781 .62332 L F
0 0 .011 r
.37838 .57318 m .37754 .57505 L .38004 .57193 L F
.584 .014 0 r
.29993 .65034 m .2987 .65039 L .29804 .64748 L F
.694 .945 .661 r
.38212 .64643 m .38128 .64797 L .38402 .64501 L F
.551 .867 .995 r
.38212 .64643 m .37948 .64726 L .38128 .64797 L F
.248 .287 .706 r
.35675 .62548 m .35917 .62824 L .35899 .62526 L F
.699 .921 .589 r
.30824 .6572 m .31096 .65416 L .30927 .65568 L F
.296 .333 .731 r
.31243 .65386 m .31304 .65629 L .31096 .65416 L F
.913 .554 .341 r
.30927 .65568 m .31096 .65416 L .31105 .65652 L F
.699 .363 .403 r
.31096 .65416 m .31304 .65629 L .31105 .65652 L F
0 0 .281 r
.32177 .63734 m .31895 .64317 L .32165 .63993 L F
.363 .362 .724 r
.32165 .63993 m .31895 .64317 L .32074 .644 L F
.382 .821 .953 r
.3678 .5147 m .37003 .51423 L .37147 .51468 L F
.334 .549 .911 r
.37252 .51284 m .37147 .51468 L .37003 .51423 L F
.37252 .51284 m .3742 .51532 L .37147 .51468 L F
.61 .464 .658 r
.37819 .60416 m .38057 .60414 L .3806 .60074 L F
.52 .126 .234 r
.38057 .60414 m .38059 .6055 L .37819 .60416 L F
.61 .464 .658 r
.3806 .60074 m .38057 .60414 L .37819 .60416 L F
.52 .126 .234 r
.38057 .60414 m .38059 .6055 L .37819 .60416 L F
.289 0 0 r
.27427 .54733 m .27018 .54889 L .27081 .54814 L F
.27427 .54733 m .27281 .54857 L .27018 .54889 L F
.121 0 0 r
.2763 .54663 m .27281 .54857 L .27427 .54733 L F
.482 .237 .467 r
.37703 .61599 m .37666 .61697 L .37394 .61676 L F
.803 .893 .477 r
.25423 .75295 m .25516 .75034 L .25266 .75088 L F
0 0 0 r
.27381 .63078 m .2761 .62936 L .27262 .63129 L F
.064 0 0 r
.27615 .63028 m .2761 .62936 L .27381 .63078 L F
.27615 .63028 m .27846 .62883 L .2761 .62936 L F
.692 .571 .715 r
.36303 .55757 m .3582 .55958 L .35816 .55705 L F
.72 .944 .637 r
.38518 .64341 m .38402 .64501 L .38672 .64181 L F
.22 .488 .896 r
.38382 .6389 m .38734 .64012 L .38672 .64181 L F
0 0 0 r
.38734 .64012 m .38518 .64341 L .38672 .64181 L F
.384 .181 .477 r
.33389 .56629 m .33156 .56962 L .33365 .56888 L F
.687 .22 .138 r
.33156 .56962 m .33041 .57046 L .33377 .5716 L F
.33041 .57046 m .33165 .57131 L .33377 .5716 L F
.436 .302 .6 r
.33156 .56962 m .33377 .5716 L .33365 .56888 L F
.33156 .56962 m .33377 .5716 L .33365 .56888 L F
.217 .733 .87 r
.33086 .57239 m .32993 .57246 L .32963 .57103 L F
.381 .513 .866 r
.32861 .57336 m .33026 .57401 L .32993 .57246 L F
.32893 .57262 m .32993 .57246 L .32963 .57103 L F
.32861 .57336 m .32993 .57246 L .32893 .57262 L F
.775 .718 .799 r
.33164 .57131 m .33086 .57239 L .33377 .5716 L F
.33086 .57239 m .332 .57365 L .3331 .57237 L F
.33086 .57239 m .3331 .57237 L .33377 .5716 L F
.32963 .57103 m .33054 .57204 L .33164 .57131 L F
.33054 .57204 m .33086 .57239 L .33164 .57131 L F
.217 .733 .87 r
.33258 .57226 m .33086 .57239 L .32963 .57103 L F
.33258 .57226 m .33223 .57208 L .33031 .57239 L F
.33086 .57239 m .33031 .57239 L .32993 .57246 L F
.33258 .57226 m .33031 .57239 L .33086 .57239 L F
.775 .718 .799 r
.33086 .57239 m .33133 .57443 L .332 .57365 L F
.33031 .57239 m .33133 .57443 L .33086 .57239 L F
.381 .513 .866 r
.33026 .57401 m .33133 .57443 L .33024 .57225 L F
.32992 .57238 m .33024 .57225 L .32963 .57103 L F
.33026 .57401 m .33024 .57225 L .32992 .57238 L F
.217 .733 .87 r
.33223 .57208 m .33185 .57187 L .32993 .57246 L F
.687 .22 .138 r
.33041 .57046 m .32963 .57103 L .33165 .57131 L F
.658 .664 .844 r
.33053 .56677 m .33258 .57226 L .32963 .57103 L F
.762 .554 .616 r
.33185 .57187 m .32774 .57491 L .32958 .57268 L F
.217 .733 .87 r
.32993 .57246 m .33013 .57239 L .32976 .57247 L F
.33013 .57239 m .33001 .5724 L .32976 .57247 L F
.762 .554 .616 r
.33001 .5724 m .32958 .57268 L .32976 .57247 L F
.775 .718 .799 r
.32963 .57103 m .33031 .57239 L .33086 .57239 L F
.217 .733 .87 r
.33013 .57239 m .33185 .57187 L .33001 .5724 L F
.762 .554 .616 r
.33185 .57187 m .32958 .57268 L .33001 .5724 L F
.217 .733 .87 r
.32993 .57246 m .32976 .57247 L .32963 .57103 L F
.246 .4 .819 r
.33355 .56924 m .33053 .56677 L .33293 .5662 L F
.488 .33 .592 r
.33365 .56888 m .33644 .56497 L .33389 .56629 L F
.33365 .56888 m .33593 .56871 L .33644 .56497 L F
.45 .374 .68 r
.33558 .5684 m .33293 .5662 L .33434 .56573 L F
.33558 .5684 m .33355 .56924 L .33293 .5662 L F
.345 0 .076 r
.33229 .5667 m .33434 .56573 L .33293 .5662 L F
.246 .4 .819 r
.33355 .56924 m .33266 .57201 L .33071 .56723 L F
.33355 .56924 m .33071 .56723 L .33098 .56714 L F
.345 0 .076 r
.33101 .5677 m .33324 .56638 L .33229 .5667 L F
.33324 .56638 m .33434 .56573 L .33229 .5667 L F
.246 .4 .819 r
.33098 .56714 m .33071 .56723 L .33053 .56677 L F
.33266 .57201 m .33258 .57226 L .33242 .57184 L F
.33266 .57201 m .33242 .57184 L .33053 .56677 L F
.525 .571 .844 r
.18012 .68422 m .18036 .68587 L .18246 .68472 L F
.18246 .68472 m .18036 .68587 L .18012 .68422 L F
.487 .722 .975 r
.32204 .66641 m .32358 .66785 L .32657 .66739 L F
.691 .475 .59 r
.38248 .63795 m .3826 .64149 L .37849 .64081 L F
.186 .359 .804 r
.38375 .63655 m .38248 .63795 L .38195 .63486 L F
.38375 .63655 m .38382 .6389 L .38248 .63795 L F
.525 .346 .581 r
.38382 .6389 m .3826 .64149 L .38248 .63795 L F
.84 .538 .479 r
.34866 .69161 m .34641 .69366 L .34528 .69067 L F
.854 .563 .495 r
.34887 .69414 m .34641 .69366 L .34866 .69161 L F
.295 .78 .908 r
.33927 .64085 m .33724 .64134 L .33421 .64084 L F
.899 .877 .444 r
.30466 .5901 m .3036 .59407 L .30449 .5917 L F
.241 0 .277 r
.34113 .54394 m .33859 .54682 L .33914 .54483 L F
.3 .14 .489 r
.37508 .5913 m .37712 .58783 L .37488 .5887 L F
.365 .493 .855 r
.40072 .54884 m .40095 .55066 L .39914 .55075 L F
.313 .545 .914 r
.35101 .51027 m .35646 .51264 L .35505 .51313 L F
.124 .51 .91 r
.35162 .50924 m .35645 .51262 L .35101 .51027 L F
.335 .687 .98 r
.35677 .51254 m .35748 .51316 L .35505 .51313 L F
.124 .51 .91 r
.35645 .51262 m .35654 .51268 L .35646 .51264 L F
.35645 .51262 m .35646 .51264 L .35101 .51027 L F
.988 .893 .614 r
.35576 .51021 m .35649 .51254 L .35162 .50924 L F
.35649 .51254 m .35652 .51262 L .35648 .51259 L F
.35576 .51021 m .35597 .51183 L .35654 .51268 L F
.699 .904 .969 r
.35722 .51 m .35597 .51183 L .35656 .50971 L F
.35844 .51055 m .35682 .51139 L .35722 .51 L F
.35682 .51139 m .35597 .51183 L .35722 .51 L F
.988 .893 .614 r
.35649 .51254 m .35648 .51259 L .35162 .50924 L F
.35652 .51262 m .35654 .51268 L .35645 .51262 L F
.35652 .51262 m .35645 .51262 L .35162 .50924 L F
.335 .687 .98 r
.35597 .51183 m .35625 .51208 L .3557 .51255 L F
.35547 .51253 m .3557 .51255 L .35505 .51313 L F
.35597 .51183 m .3557 .51255 L .35547 .51253 L F
.35625 .51208 m .35677 .51254 L .35646 .51264 L F
.35625 .51208 m .35646 .51264 L .35505 .51313 L F
.313 .545 .914 r
.35646 .51264 m .35654 .51268 L .35505 .51313 L F
.326 .676 .977 r
.35654 .51268 m .35597 .51183 L .35505 .51313 L F
0 0 .36 r
.36052 .53818 m .36134 .53391 L .36276 .53709 L F
.36052 .53818 m .36169 .5381 L .36134 .53391 L F
0 0 0 r
.36052 .53818 m .35879 .53968 L .36169 .5381 L F
.458 .432 .741 r
.31905 .58773 m .31981 .5915 L .32112 .59024 L F
.189 .109 .529 r
.31981 .5915 m .32189 .59276 L .32112 .59024 L F
.31981 .5915 m .31995 .59429 L .32189 .59276 L F
.758 .792 .881 r
.35084 .67304 m .34657 .67281 L .34917 .67244 L F
.596 .898 .987 r
.35314 .67208 m .35084 .67304 L .34917 .67244 L F
.76 .681 .775 r
.34028 .53264 m .33593 .53223 L .33752 .53189 L F
.547 .85 .998 r
.34072 .53148 m .34028 .53264 L .33752 .53189 L F
.609 .773 .959 r
.22684 .613 m .22157 .61212 L .22514 .61197 L F
.295 .702 .975 r
.22727 .61195 m .22684 .613 L .22514 .61197 L F
.251 .654 .964 r
.22727 .61195 m .22913 .61324 L .22684 .613 L F
0 0 0 r
.31207 .64556 m .31194 .64487 L .30996 .64558 L F
.31207 .64556 m .31427 .64428 L .31194 .64487 L F
.401 .791 .989 r
.27987 .52518 m .27958 .52648 L .27759 .52532 L F
.27987 .52518 m .28206 .52615 L .27958 .52648 L F
.687 .592 .743 r
.31806 .62884 m .31948 .63282 L .32181 .6319 L F
.692 .571 .715 r
.36303 .55757 m .35816 .55705 L .36081 .55629 L F
.777 .688 .766 r
.28751 .54757 m .28389 .5471 L .28612 .54402 L F
.689 .233 .163 r
.28751 .54757 m .28562 .54908 L .28389 .5471 L F
.277 .766 .909 r
.31898 .69165 m .31915 .69111 L .32139 .69135 L F
.31898 .69165 m .31915 .69111 L .32139 .69135 L F
0 0 .161 r
.40396 .55636 m .40442 .55861 L .40453 .56007 L F
0 0 .136 r
.40442 .55861 m .40508 .56277 L .40453 .56007 L F
.733 .296 .212 r
.31626 .64833 m .31985 .65005 L .31814 .6472 L F
0 0 0 r
.31461 .65021 m .31626 .64833 L .31814 .6472 L F
.45 .876 .921 r
.30542 .52382 m .30546 .52299 L .3078 .52298 L F
.30542 .52382 m .30331 .52375 L .30546 .52299 L F
.293 .229 .611 r
.31822 .58179 m .32003 .58385 L .31973 .58115 L F
.184 .035 .432 r
.20544 .5785 m .20523 .58119 L .20385 .58146 L F
.275 .225 .618 r
.20587 .58374 m .20385 .58146 L .20523 .58119 L F
.20587 .58374 m .20397 .58521 L .20385 .58146 L F
.351 .65 .967 r
.23091 .63213 m .23335 .63236 L .23146 .63057 L F
.769 .522 .562 r
.35449 .69472 m .35268 .6972 L .35254 .69454 L F
.35449 .69472 m .35676 .69761 L .35268 .6972 L F
0 0 0 r
.30552 .64448 m .30078 .64545 L .30345 .64607 L F
.428 0 0 r
.30604 .64572 m .30552 .64448 L .30345 .64607 L F
.30604 .64572 m .30802 .64499 L .30552 .64448 L F
.124 .51 .91 r
.35162 .50924 m .35101 .51027 L .34954 .50884 L F
.42 .511 .845 r
.2296 .62579 m .22942 .62214 L .22806 .62215 L F
.2296 .62579 m .23115 .62558 L .22942 .62214 L F
.612 .674 .884 r
.3782 .61975 m .37666 .61697 L .37703 .61599 L F
.656 .501 .661 r
.3782 .61975 m .3791 .62262 L .37574 .62271 L F
.494 .528 .821 r
.38031 .61897 m .3782 .61975 L .37703 .61599 L F
.41 .288 .602 r
.38031 .61897 m .38053 .62177 L .3782 .61975 L F
.298 .284 .676 r
.38053 .62177 m .3791 .62262 L .3782 .61975 L F
.655 .615 .797 r
.34794 .54006 m .3441 .53785 L .34612 .53728 L F
.335 .123 .436 r
.37304 .54045 m .37059 .54347 L .37103 .54132 L F
0 .143 .664 r
.20528 .60619 m .20527 .60761 L .20608 .6061 L F
.089 .247 .733 r
.20527 .60761 m .20743 .60827 L .20608 .6061 L F
.20527 .60761 m .20651 .60972 L .20743 .60827 L F
.961 .942 .651 r
.38707 .6323 m .38595 .63557 L .3855 .63394 L F
.733 .906 .955 r
.3855 .63394 m .38595 .63557 L .38822 .63369 L F
.943 .757 .622 r
.28441 .53964 m .28577 .54138 L .2846 .53762 L F
.396 .453 .801 r
.28566 .53849 m .28577 .54138 L .28725 .53979 L F
.285 .53892 m .28577 .54138 L .28566 .53849 L F
0 0 0 r
.28568 .53848 m .28621 .53883 L .28441 .53964 L F
.396 .453 .801 r
.2846 .53762 m .28725 .53979 L .28712 .53717 L F
0 0 0 r
.28712 .53717 m .2868 .53775 L .28568 .53848 L F
.2868 .53775 m .28621 .53883 L .28568 .53848 L F
.396 .453 .801 r
.2846 .53762 m .285 .53892 L .28566 .53849 L F
.128 .071 .518 r
.28577 .54138 m .28725 .54272 L .28725 .53979 L F
.28577 .54138 m .28612 .54402 L .28725 .54272 L F
.735 .658 .774 r
.31835 .52354 m .31397 .52197 L .31647 .52115 L F
.444 .145 .362 r
.32161 .52244 m .31835 .52354 L .31647 .52115 L F
.32161 .52244 m .32019 .52454 L .31835 .52354 L F
.596 .486 .698 r
.31997 .60748 m .32198 .60702 L .32235 .60576 L F
.269 .008 .32 r
.32235 .60576 m .32378 .608 L .32681 .60516 L F
.32235 .60576 m .32198 .60702 L .32378 .608 L F
.277 .729 .957 r
.32333 .53404 m .32543 .53387 L .32647 .53455 L F
.797 .966 .914 r
.32647 .53455 m .32803 .53206 L .3296 .53179 L F
.32647 .53455 m .32543 .53387 L .32803 .53206 L F
0 0 0 r
.38418 .64559 m .38402 .64501 L .38518 .64341 L F
.38418 .64559 m .38212 .64643 L .38402 .64501 L F
.31127 .63019 m .31201 .62948 L .31406 .62865 L F
.901 .986 .746 r
.31201 .62948 m .31347 .62608 L .31406 .62865 L F
.63 .471 .648 r
.37345 .62868 m .37071 .62921 L .37314 .62594 L F
.529 .338 .565 r
.37562 .6254 m .37558 .62808 L .37314 .62594 L F
.451 .341 .637 r
.37314 .62594 m .37558 .62808 L .37345 .62868 L F
.641 .234 .258 r
.21139 .57496 m .21006 .57728 L .20815 .57534 L F
.079 0 .122 r
.21453 .57204 m .21321 .57476 L .21139 .57496 L F
.051 0 0 r
.21321 .57476 m .21006 .57728 L .21139 .57496 L F
.554 .844 .998 r
.37716 .63207 m .37463 .63235 L .37534 .63073 L F
0 .123 .652 r
.37534 .63073 m .37463 .63235 L .37345 .62868 L F
.322 .805 .884 r
.28439 .52537 m .28823 .52494 L .28585 .52538 L F
.384 .172 .465 r
.33383 .5507 m .33534 .55176 L .33653 .55027 L F
.33383 .5507 m .33357 .55319 L .33534 .55176 L F
.736 .304 .225 r
.34822 .62644 m .34818 .62503 L .34515 .62473 L F
.542 .908 .959 r
.34257 .62556 m .34626 .62432 L .34312 .62495 L F
0 0 0 r
.34607 .62436 m .34383 .62459 L .34312 .62495 L F
.34626 .62432 m .34613 .62433 L .34607 .62436 L F
.34613 .62433 m .34383 .62459 L .34607 .62436 L F
.542 .908 .959 r
.34257 .62556 m .34347 .62456 L .34626 .62432 L F
.736 .304 .225 r
.34453 .62498 m .34515 .62473 L .34347 .62456 L F
.34822 .62644 m .34515 .62473 L .34453 .62498 L F
0 0 0 r
.34626 .62432 m .3465 .62413 L .34383 .62459 L F
.416 .865 .842 r
.24724 .53129 m .24499 .5322 L .24259 .53253 L F
.592 .384 .568 r
.37784 .62511 m .37574 .62271 L .3791 .62262 L F
.37784 .62511 m .37562 .6254 L .37574 .62271 L F
0 0 0 r
.3707 .58018 m .36906 .58194 L .3694 .58159 L F
.3707 .58018 m .3694 .58159 L .37185 .57899 L F
.372 0 0 r
.37167 .57912 m .3707 .58018 L .37261 .57886 L F
.36849 .58003 m .3707 .58018 L .37167 .57912 L F
.757 .972 .697 r
.37261 .57886 m .3707 .58018 L .37289 .57717 L F
.516 .883 .977 r
.37261 .57886 m .37289 .57717 L .37539 .57808 L F
.361 .033 .268 r
.39314 .67283 m .39217 .67519 L .38949 .67558 L F
.417 .53 .864 r
.39452 .6719 m .39314 .67283 L .39198 .67014 L F
.388 .058 .28 r
.3947 .6745 m .39314 .67283 L .39452 .6719 L F
.3947 .6745 m .39217 .67519 L .39314 .67283 L F
.653 .676 .86 r
.33546 .60393 m .33096 .60179 L .33368 .60154 L F
.471 .642 .931 r
.33678 .60234 m .33546 .60393 L .33368 .60154 L F
.501 .439 .719 r
.33678 .60234 m .33537 .6065 L .33546 .60393 L F
.521 .526 .801 r
.39865 .5845 m .39685 .58533 L .39547 .5818 L F
.327 .211 .565 r
.39849 .58706 m .39685 .58533 L .39865 .5845 L F
.39849 .58706 m .39695 .58787 L .39685 .58533 L F
.037 .327 .811 r
.39538 .53932 m .39596 .54098 L .39443 .53991 L F
.519 .19 .349 r
.3663 .61271 m .37095 .60989 L .36583 .60935 L F
0 .209 .726 r
.37762 .55694 m .3798 .55859 L .3799 .55624 L F
.54 .813 .996 r
.26088 .75443 m .25672 .75388 L .25903 .75345 L F
.25672 .75388 m .26088 .75443 L .25903 .75345 L F
.977 .908 .669 r
.35074 .57027 m .34946 .57208 L .34869 .57095 L F
.601 .06 0 r
.35074 .57027 m .35331 .57228 L .34869 .57095 L F
.277 .127 .49 r
.37712 .58783 m .37929 .58327 L .37707 .5851 L F
.392 .412 .762 r
.29435 .62793 m .29589 .63089 L .2922 .62945 L F
.259 .752 .674 r
.34288 .55443 m .34273 .5545 L .34427 .55356 L F
.411 .243 .54 r
.34553 .55101 m .34644 .55301 L .34427 .55356 L F
.404 .164 .433 r
.30874 .54106 m .31067 .54074 L .31175 .53782 L F
.546 .299 .493 r
.31108 .54314 m .30874 .54106 L .31067 .54074 L F
.31108 .54314 m .30868 .54354 L .30874 .54106 L F
.404 .164 .433 r
.30874 .54106 m .31067 .54074 L .31175 .53782 L F
.007 .241 .749 r
.30874 .54106 m .31108 .54314 L .31067 .54074 L F
.345 0 .128 r
.37807 .53761 m .37865 .53576 L .37969 .5379 L F
.37807 .53761 m .3752 .53888 L .37865 .53576 L F
.482 .819 .999 r
.26087 .52744 m .26281 .52884 L .26033 .52935 L F
.38 .789 .981 r
.24253 .63107 m .24212 .6301 L .23671 .63027 L F
0 .447 .712 r
.24619 .63109 m .24212 .6301 L .24253 .63107 L F
.789 .515 .523 r
.35102 .53349 m .35541 .53465 L .35504 .53056 L F
.421 .245 .535 r
.35504 .53056 m .35738 .53356 L .35797 .53016 L F
.35504 .53056 m .35541 .53465 L .35738 .53356 L F
.736 .66 .774 r
.37214 .54749 m .36809 .54461 L .37059 .54347 L F
.37214 .54749 m .36835 .54738 L .36809 .54461 L F
.722 .487 .569 r
.37214 .54749 m .36826 .54997 L .36835 .54738 L F
.37214 .54749 m .37206 .55011 L .36826 .54997 L F
.75 .653 .753 r
.37463 .54417 m .37214 .54749 L .37059 .54347 L F
.694 .463 .569 r
.37582 .54989 m .37206 .55011 L .37214 .54749 L F
.435 .346 .657 r
.32563 .56271 m .32398 .56578 L .32347 .56333 L F
.116 .625 .896 r
.36809 .54461 m .36428 .54386 L .36448 .54362 L F
.202 0 0 r
.27476 .61745 m .27272 .61739 L .2725 .61781 L F
.053 0 .153 r
.34917 .60459 m .35002 .60481 L .35091 .60325 L F
.34917 .60459 m .34815 .60698 L .35002 .60481 L F
.444 .409 .724 r
.20587 .58374 m .20447 .588 L .20397 .58521 L F
.648 .495 .662 r
.3806 .60074 m .38157 .60181 L .38313 .60104 L F
.38157 .60181 m .3829 .60328 L .38313 .60104 L F
.771 .821 .892 r
.3829 .60328 m .3854 .59976 L .38313 .60104 L F
0 0 0 r
.3854 .59976 m .38426 .60048 L .38313 .60104 L F
.38426 .60048 m .38223 .60175 L .38313 .60104 L F
0 0 .467 r
.38223 .60175 m .3806 .60074 L .38313 .60104 L F
.648 .495 .662 r
.3806 .60074 m .38057 .60414 L .3829 .60328 L F
0 0 .467 r
.38223 .60175 m .38057 .60414 L .3806 .60074 L F
.551 .927 .919 r
.33465 .54072 m .33557 .53946 L .33598 .53698 L F
.33465 .54072 m .33342 .54055 L .33557 .53946 L F
.132 0 0 r
.35714 .66294 m .36128 .66081 L .36 .66224 L F
0 0 0 r
.36 .66224 m .36128 .66081 L .36345 .6597 L F
.476 .355 .635 r
.36832 .60357 m .37056 .60266 L .37021 .60036 L F
.353 0 0 r
.26359 .62431 m .26599 .6242 L .26782 .62239 L F
0 0 0 r
.26782 .62239 m .26682 .62338 L .26785 .62324 L F
.02 0 0 r
.26785 .62324 m .26956 .62306 L .27125 .62109 L F
.044 0 0 r
.26514 .62322 m .26904 .62308 L .26785 .62324 L F
.26904 .62308 m .26956 .62306 L .26785 .62324 L F
0 0 0 r
.26682 .62338 m .26599 .6242 L .26785 .62324 L F
.698 .473 .577 r
.30131 .55085 m .30129 .55362 L .29762 .55356 L F
.631 .418 .574 r
.30398 .55306 m .30131 .55085 L .30368 .54972 L F
.30398 .55306 m .30129 .55362 L .30131 .55085 L F
0 0 0 r
.309 .57005 m .30769 .57139 L .31072 .56883 L F
.911 .764 .275 r
.30492 .58653 m .30466 .5901 L .30565 .58801 L F
.589 .421 .621 r
.32263 .67904 m .32557 .67932 L .32513 .67587 L F
.32263 .67904 m .32557 .67932 L .32513 .67587 L F
.958 .859 .445 r
.32991 .53961 m .33049 .54118 L .33104 .5381 L F
.808 .612 .637 r
.33311 .53735 m .32991 .53961 L .33104 .5381 L F
.168 0 0 r
.30177 .57514 m .30495 .57438 L .30629 .57296 L F
0 0 0 r
.30495 .57438 m .30769 .57139 L .30629 .57296 L F
.806 .879 .448 r
.30113 .56899 m .30002 .57105 L .29976 .57268 L F
.488 .8 .999 r
.29976 .57268 m .30002 .57105 L .29763 .57155 L F
.596 .486 .698 r
.31997 .60748 m .32043 .60997 L .32198 .60702 L F
0 0 .519 r
.36563 .56584 m .36648 .56946 L .36646 .56808 L F
.691 .582 .729 r
.36974 .56547 m .37044 .56964 L .36648 .56946 L F
.553 .258 .42 r
.37044 .56964 m .3671 .57227 L .36648 .56946 L F
0 0 .471 r
.36648 .56946 m .368 .57056 L .36646 .56808 L F
.553 .258 .42 r
.37044 .56964 m .36977 .57204 L .3671 .57227 L F
.51 .25 .456 r
.37286 .56888 m .36977 .57204 L .37044 .56964 L F
.37286 .56888 m .37259 .5715 L .36977 .57204 L F
.488 .197 .398 r
.37259 .5715 m .37193 .57359 L .36977 .57204 L F
0 .316 .672 r
.37131 .57196 m .36875 .57083 L .368 .57056 L F
0 0 .471 r
.36648 .56946 m .36662 .57007 L .368 .57056 L F
.968 .759 .567 r
.368 .57056 m .36713 .56736 L .36646 .56808 L F
.368 .57056 m .36626 .56972 L .36713 .56736 L F
0 .316 .672 r
.36875 .57083 m .36626 .56972 L .368 .57056 L F
0 0 .471 r
.36662 .57007 m .3671 .57227 L .368 .57056 L F
.593 .478 .692 r
.36591 .55024 m .36662 .55419 L .36403 .55379 L F
.629 .477 .658 r
.36662 .55419 m .36487 .55481 L .36403 .55379 L F
.646 .365 .479 r
.34337 .58209 m .3436 .58446 L .34037 .58436 L F
.13 0 .141 r
.34609 .58143 m .3436 .58446 L .34337 .58209 L F
.239 .049 .409 r
.36487 .55481 m .36303 .55757 L .36081 .55629 L F
.458 .337 .627 r
.36902 .55394 m .36659 .55548 L .36662 .55419 L F
.303 0 0 r
.36631 .55492 m .36762 .55434 L .36715 .5545 L F
.239 .049 .409 r
.36438 .55554 m .36366 .56111 L .36303 .55757 L F
.36475 .55542 m .36366 .56111 L .36438 .55554 L F
.629 .477 .658 r
.36662 .55419 m .36659 .55548 L .36487 .55481 L F
.495 .273 .506 r
.36616 .55855 m .36487 .55481 L .36659 .55548 L F
.36616 .55855 m .36366 .56111 L .36487 .55481 L F
.303 0 0 r
.36303 .55654 m .36663 .55481 L .36631 .55492 L F
.36663 .55481 m .36762 .55434 L .36631 .55492 L F
.239 .049 .409 r
.36487 .55481 m .36475 .55542 L .36438 .55554 L F
.823 .571 .017 r
.36343 .56152 m .36303 .55757 L .36366 .56111 L F
.258 .338 .755 r
.22336 .60872 m .22223 .61165 L .22093 .60671 L F
.579 .614 .851 r
.22336 .60872 m .22157 .61212 L .22223 .61165 L F
0 0 0 r
.27452 .62317 m .27329 .62506 L .27166 .6257 L F
.187 0 .311 r
.27329 .62506 m .27072 .6284 L .27166 .6257 L F
.919 .588 .122 r
.3128 .62592 m .31347 .62608 L .31254 .62592 L F
0 0 0 r
.31306 .62592 m .3128 .62592 L .31107 .62709 L F
.919 .588 .122 r
.3128 .62592 m .31406 .62865 L .31347 .62608 L F
.544 .625 .883 r
.31486 .62486 m .31482 .62503 L .3128 .62592 L F
.31482 .62503 m .31406 .62865 L .313 .62635 L F
.31482 .62503 m .313 .62635 L .3128 .62592 L F
.31486 .62486 m .31706 .62877 L .31406 .62865 L F
.61 .658 .872 r
.31884 .62746 m .31706 .62877 L .31486 .62486 L F
.31884 .62746 m .31486 .62486 L .31747 .62327 L F
0 0 0 r
.31747 .62327 m .31486 .62486 L .31311 .62603 L F
.31639 .6239 m .31311 .62603 L .31482 .62482 L F
.31747 .62327 m .3158 .62433 L .31639 .6239 L F
.3158 .62433 m .31311 .62603 L .31639 .6239 L F
.31486 .62486 m .3128 .62592 L .31306 .62592 L F
.919 .588 .122 r
.3128 .62592 m .31254 .62592 L .31015 .62553 L F
0 0 0 r
.33733 .55449 m .33537 .55498 L .33341 .55539 L F
.072 0 .269 r
.33757 .55563 m .33731 .55716 L .33596 .55797 L F
.448 0 0 r
.33998 .55553 m .33704 .55518 L .33733 .55449 L F
.33704 .55518 m .33537 .55498 L .33648 .5547 L F
.33704 .55518 m .33648 .5547 L .33733 .55449 L F
.604 .509 .719 r
.33826 .55463 m .33537 .55498 L .33998 .55553 L F
.072 0 .269 r
.33826 .55463 m .33781 .55583 L .33757 .55563 L F
.33781 .55583 m .33731 .55716 L .33757 .55563 L F
.86 .986 .846 r
.3296 .53179 m .32803 .53206 L .33069 .52923 L F
.47 .292 .556 r
.35475 .63204 m .35375 .63416 L .3515 .63204 L F
.656 .926 .639 r
.3798 .55859 m .3769 .56166 L .37934 .56064 L F
.162 .625 .932 r
.29276 .5243 m .29241 .52511 L .29077 .52399 L F
.29276 .5243 m .29486 .52546 L .29241 .52511 L F
.441 .262 .54 r
.29337 .5659 m .29541 .56221 L .29392 .56305 L F
.098 .654 .739 r
.26196 .55084 m .25979 .55094 L .25782 .55117 L F
.586 .09 .043 r
.26428 .55027 m .25979 .55094 L .26196 .55084 L F
0 .337 .813 r
.37506 .60769 m .3768 .60781 L .37349 .60726 L F
.37598 .60823 m .37747 .6091 L .3768 .60781 L F
.861 .808 .797 r
.37747 .6091 m .37535 .61236 L .37376 .60998 L F
.37747 .6091 m .37376 .60998 L .3768 .60781 L F
.082 0 .317 r
.37557 .61027 m .37745 .60748 L .3768 .60781 L F
.37745 .60748 m .37774 .60706 L .3768 .60781 L F
0 .337 .813 r
.37506 .60769 m .37598 .60823 L .3768 .60781 L F
.113 0 .343 r
.18508 .57253 m .18652 .57188 L .18704 .56891 L F
.212 .158 .576 r
.18508 .57253 m .18679 .57454 L .18652 .57188 L F
.275 .17 .55 r
.1852 .57523 m .18679 .57454 L .18508 .57253 L F
.744 .699 .808 r
.36122 .61988 m .35939 .62264 L .36289 .62255 L F
.716 .535 .644 r
.35939 .62264 m .36238 .62484 L .36289 .62255 L F
.566 .736 .956 r
.36289 .62255 m .36377 .61966 L .36122 .61988 L F
.36289 .62255 m .36588 .62279 L .36377 .61966 L F
.28 0 .065 r
.36238 .62484 m .36588 .62279 L .36289 .62255 L F
.703 .622 .764 r
.35504 .62182 m .35735 .62521 L .35939 .62264 L F
0 0 .276 r
.21794 .5995 m .21732 .60127 L .21735 .59776 L F
.186 .408 .845 r
.21794 .5995 m .2199 .60275 L .21732 .60127 L F
0 0 .444 r
.37676 .63046 m .37716 .63207 L .37558 .62808 L F
.583 .512 .74 r
.34937 .57783 m .34639 .57885 L .34557 .57556 L F
.002 0 .063 r
.34937 .57783 m .34609 .58143 L .34639 .57885 L F
.742 .49 .548 r
.35859 .69778 m .35662 .70029 L .35676 .69761 L F
.35859 .69778 m .35855 .70051 L .35662 .70029 L F
.665 .859 .974 r
.31397 .52197 m .31143 .52288 L .31001 .52185 L F
.3 .14 .489 r
.37508 .5913 m .37713 .59033 L .37712 .58783 L F
0 0 0 r
.37482 .59383 m .37713 .59033 L .37508 .5913 L F
.663 .904 .979 r
.37608 .66291 m .37535 .66476 L .3731 .66481 L F
.37608 .66291 m .37743 .66358 L .37535 .66476 L F
.574 .494 .727 r
.29125 .56973 m .2944 .56862 L .2924 .56964 L F
.43 .282 .577 r
.39205 .6777 m .38949 .67558 L .39217 .67519 L F
.39205 .6777 m .39007 .67861 L .38949 .67558 L F
.203 .063 .456 r
.35812 .58397 m .35951 .58145 L .35697 .58232 L F
.78 .558 .598 r
.31175 .53782 m .31525 .54096 L .31413 .53817 L F
0 0 0 r
.31172 .53867 m .31175 .53782 L .31413 .53817 L F
.722 .989 .86 r
.31477 .53643 m .31172 .53867 L .31413 .53817 L F
.483 .853 .987 r
.31405 .5379 m .31172 .53867 L .31477 .53643 L F
.31405 .5379 m .31217 .53792 L .31172 .53867 L F
.31217 .53792 m .31084 .53793 L .31172 .53867 L F
0 0 0 r
.31172 .53867 m .31067 .54074 L .31097 .53993 L F
.31172 .53867 m .31097 .53993 L .31175 .53782 L F
.574 .494 .727 r
.29125 .56973 m .29526 .57218 L .2944 .56862 L F
.542 .502 .761 r
.29125 .56973 m .29343 .57379 L .29526 .57218 L F
.431 .307 .611 r
.32513 .67587 m .32557 .67932 L .32736 .67815 L F
.32736 .67815 m .32557 .67932 L .32513 .67587 L F
.699 .57 .706 r
.3135 .56297 m .31777 .56488 L .31618 .56221 L F
.3135 .56297 m .31497 .56615 L .31777 .56488 L F
.281 .141 .506 r
.18349 .57861 m .1851 .57784 L .1852 .57523 L F
.303 .249 .63 r
.18349 .57861 m .18552 .58067 L .1851 .57784 L F
.18349 .57861 m .18359 .58199 L .18552 .58067 L F
.762 .529 .581 r
.33924 .68209 m .33488 .68427 L .33516 .68154 L F
.33924 .68209 m .33901 .68481 L .33488 .68427 L F
.784 .635 .695 r
.2353 .61307 m .23932 .61349 L .23938 .61057 L F
.633 .558 .752 r
.23803 .60698 m .23938 .61057 L .24185 .60997 L F
.619 .497 .692 r
.23938 .61057 m .23932 .61349 L .24185 .60997 L F
.456 .313 .598 r
.30617 .58075 m .30372 .58206 L .30341 .57875 L F
0 .268 .733 r
.19318 .59951 m .19446 .60075 L .19423 .60001 L F
.017 .526 .866 r
.19423 .60001 m .19446 .60075 L .19635 .60113 L F
.562 .564 .813 r
.31413 .53817 m .31525 .54096 L .31758 .54021 L F
.655 .3 .359 r
.31284 .54293 m .31758 .54021 L .31525 .54096 L F
.123 .568 .921 r
.3843 .52321 m .3831 .52376 L .38166 .52242 L F
.3843 .52321 m .38592 .52447 L .3831 .52376 L F
.377 .789 .979 r
.28155 .55017 m .28361 .5498 L .28566 .5501 L F
.427 .284 .583 r
.28195 .55278 m .28361 .5498 L .28155 .55017 L F
.583 .651 .882 r
.35917 .62824 m .3602 .63109 L .36291 .62964 L F
0 0 0 r
.33894 .56067 m .33639 .5637 L .33842 .56167 L F
.251 .71 .951 r
.37059 .54347 m .37301 .54341 L .37463 .54417 L F
.58 .944 .871 r
.37682 .54278 m .37463 .54417 L .37639 .54278 L F
.634 .347 .465 r
.37301 .54341 m .37639 .54278 L .37463 .54417 L F
.247 0 .049 r
.27679 .62242 m .27329 .62506 L .27452 .62317 L F
.401 .227 .528 r
.36544 .65898 m .36345 .6597 L .36354 .65709 L F
.603 .952 .891 r
.25385 .52914 m .24956 .53069 L .25193 .53039 L F
.633 .558 .752 r
.23803 .60698 m .24185 .60997 L .24094 .60632 L F
.491 .823 .999 r
.32545 .53027 m .32547 .52842 L .32331 .52978 L F
.32545 .53027 m .32843 .53018 L .32547 .52842 L F
.645 .339 .438 r
.35087 .53505 m .35308 .53706 L .35102 .53349 L F
0 0 0 r
.33521 .65577 m .33631 .65374 L .3363 .65375 L F
.33521 .65577 m .3363 .65375 L .33308 .65668 L F
.33521 .65577 m .33308 .65668 L .33355 .65667 L F
.701 .903 .968 r
.33272 .6547 m .33521 .65577 L .33355 .65667 L F
.43 .162 .404 r
.33438 .65814 m .33521 .65577 L .33207 .65859 L F
.965 .763 .581 r
.33438 .65814 m .33521 .65577 L .33272 .6547 L F
.91 .866 .428 r
.33451 .65707 m .33521 .65577 L .33438 .65814 L F
.3349 .6538 m .33521 .65577 L .33451 .65707 L F
0 .552 .731 r
.33355 .65667 m .33308 .65668 L .32974 .65639 L F
0 0 0 r
.33308 .65668 m .33207 .65859 L .32974 .65639 L F
.725 .273 .178 r
.32974 .65639 m .33308 .65668 L .33207 .65859 L F
.857 .985 .706 r
.37492 .56021 m .37279 .56133 L .37521 .55824 L F
.414 .408 .743 r
.31905 .58773 m .32099 .58748 L .32003 .58385 L F
.458 .432 .741 r
.31905 .58773 m .32112 .59024 L .32099 .58748 L F
.621 .193 .208 r
.31059 .56603 m .31267 .56782 L .31497 .56615 L F
.057 0 0 r
.31267 .56782 m .31563 .56744 L .31497 .56615 L F
.782 .522 .544 r
.35254 .69454 m .34888 .69678 L .34887 .69414 L F
.35254 .69454 m .35268 .6972 L .34888 .69678 L F
.747 .48 .527 r
.34308 .68762 m .33901 .68481 L .34281 .68581 L F
.579 .609 .847 r
.33056 .54358 m .33226 .54724 L .32971 .54727 L F
.262 0 .113 r
.33226 .54724 m .32916 .54958 L .32971 .54727 L F
.07 0 0 r
.33751 .57453 m .34002 .57399 L .34193 .57282 L F
.505 .295 .528 r
.36584 .56308 m .36799 .56499 L .36864 .56291 L F
.36584 .56308 m .36563 .56584 L .36799 .56499 L F
.624 .079 0 r
.38322 .55064 m .38066 .5518 L .38135 .55011 L F
.38322 .55064 m .38315 .55137 L .38066 .5518 L F
.386 .204 .509 r
.38322 .55064 m .38274 .55342 L .38487 .55235 L F
.624 .079 0 r
.38322 .55064 m .38487 .55235 L .38315 .55137 L F
.343 .061 .333 r
.37717 .69947 m .3757 .6979 L .37754 .69705 L F
.37717 .69947 m .37503 .70013 L .3757 .6979 L F
0 0 0 r
.39574 .56889 m .39346 .56996 L .39205 .57092 L F
.32631 .61233 m .32378 .61555 L .32502 .61367 L F
0 0 .276 r
.21794 .5995 m .21735 .59776 L .21826 .59665 L F
.648 .368 .48 r
.34163 .63684 m .34231 .63327 L .33866 .63471 L F
.999 .835 .507 r
.34202 .63118 m .34231 .63327 L .34496 .63466 L F
.763 .62 .701 r
.34163 .63684 m .34496 .63466 L .34231 .63327 L F
0 0 0 r
.32198 .60702 m .32043 .60997 L .31941 .61217 L F
.024 0 0 r
.26624 .54378 m .26844 .54303 L .26984 .54176 L F
.006 0 0 r
.26984 .54176 m .27078 .54205 L .27197 .54083 L F
.26984 .54176 m .26844 .54303 L .27078 .54205 L F
.593 .546 .771 r
.31995 .59429 m .32127 .59775 L .32268 .59696 L F
.395 .297 .625 r
.32127 .59775 m .32139 .60056 L .32369 .60037 L F
.486 0 0 r
.38822 .63369 m .38975 .63419 L .3855 .63394 L F
.647 .241 .26 r
.3855 .63394 m .38975 .63419 L .38707 .6323 L F
.535 .372 .607 r
.40547 .57164 m .40264 .56928 L .40491 .56905 L F
.40547 .57164 m .40318 .57267 L .40264 .56928 L F
0 0 .431 r
.34257 .62556 m .34183 .62888 L .34016 .62756 L F
.723 .541 0 r
.34183 .62888 m .34187 .62978 L .34016 .62756 L F
.34183 .62888 m .34202 .63118 L .34187 .62978 L F
.329 .298 .671 r
.18359 .58199 m .18583 .58408 L .18552 .58067 L F
.365 .302 .652 r
.18412 .58461 m .18583 .58408 L .18359 .58199 L F
.286 0 0 r
.2353 .61307 m .23788 .61376 L .23932 .61349 L F
.386 0 0 r
.24002 .61401 m .23932 .61349 L .23788 .61376 L F
.24002 .61401 m .24194 .61504 L .23932 .61349 L F
0 .562 .72 r
.31706 .62877 m .31806 .62884 L .31406 .62865 L F
.502 0 0 r
.31406 .62865 m .31806 .62884 L .31613 .62965 L F
.643 .966 .893 r
.31884 .62746 m .31806 .62884 L .31706 .62877 L F
.674 .969 .779 r
.31613 .62965 m .31806 .62884 L .31884 .62746 L F
.693 .651 .804 r
.32236 .65142 m .3231 .64614 L .32153 .64703 L F
.32248 .65206 m .32254 .65144 L .32236 .65142 L F
.32254 .65144 m .3231 .64614 L .32236 .65142 L F
.32254 .65144 m .32542 .6506 L .3231 .64614 L F
.806 .566 .575 r
.32282 .65188 m .32335 .65267 L .32284 .6519 L F
.32202 .65139 m .32251 .65187 L .32282 .65188 L F
.32251 .65187 m .32335 .65267 L .32282 .65188 L F
0 .182 .704 r
.32327 .65216 m .32354 .6539 L .32424 .65245 L F
.332 0 .193 r
.32424 .65245 m .32248 .65206 L .32327 .65216 L F
.32424 .65245 m .32454 .65198 L .32248 .65206 L F
.32454 .65198 m .32542 .6506 L .32283 .65188 L F
.32454 .65198 m .32283 .65188 L .32248 .65206 L F
.806 .566 .575 r
.32104 .65129 m .32354 .6539 L .32202 .65139 L F
.61 .436 .622 r
.31985 .65005 m .32327 .65216 L .32248 .65206 L F
.693 .651 .804 r
.32248 .65206 m .32283 .65188 L .32254 .65144 L F
.32283 .65188 m .32542 .6506 L .32254 .65144 L F
.806 .566 .575 r
.32202 .65139 m .32354 .6539 L .32335 .65267 L F
.32284 .6519 m .32335 .65267 L .32327 .65216 L F
.31985 .65005 m .32104 .65129 L .32202 .65139 L F
.269 .563 .934 r
.32424 .65245 m .32354 .6539 L .32617 .65419 L F
.771 .821 .892 r
.3829 .60328 m .38756 .60169 L .3854 .59976 L F
.501 .45 .731 r
.31985 .65005 m .32153 .64703 L .31814 .6472 L F
.31985 .65005 m .32248 .65206 L .32153 .64703 L F
0 0 0 r
.21777 .54368 m .21894 .54347 L .21976 .54289 L F
.21777 .54368 m .21581 .5455 L .21894 .54347 L F
.567 .496 .735 r
.37286 .56888 m .37044 .56964 L .36974 .56547 L F
.56 .283 .452 r
.35951 .58145 m .36221 .58115 L .36239 .57886 L F
.165 0 .058 r
.36221 .58115 m .36483 .57849 L .36239 .57886 L F
.145 0 0 r
.2313 .56012 m .2291 .56139 L .22665 .56132 L F
.138 0 0 r
.23329 .55911 m .2291 .56139 L .2313 .56012 L F
.706 .941 .96 r
.21463 .58869 m .21565 .58652 L .21639 .58813 L F
.21463 .58869 m .21359 .58792 L .21565 .58652 L F
.392 .51 .859 r
.21786 .59034 m .21463 .58869 L .21639 .58813 L F
0 0 .515 r
.34563 .54404 m .34598 .54307 L .34374 .54398 L F
.139 0 0 r
.3451 .54399 m .34374 .54398 L .34598 .54307 L F
0 .574 .716 r
.34563 .54404 m .34374 .54398 L .343 .54398 L F
.139 0 0 r
.34433 .54479 m .34374 .54398 L .3451 .54399 L F
0 .574 .716 r
.343 .54398 m .34374 .54398 L .34113 .54394 L F
0 0 .515 r
.34563 .54404 m .34702 .54601 L .34598 .54307 L F
0 0 .382 r
.38828 .57554 m .38954 .57613 L .3881 .57332 L F
.38828 .57554 m .3883 .57856 L .38954 .57613 L F
.435 .346 .657 r
.32563 .56271 m .32605 .56534 L .32398 .56578 L F
.105 .269 .748 r
.20651 .60972 m .20789 .61034 L .20743 .60827 L F
.235 .443 .86 r
.31777 .56488 m .31757 .56225 L .31618 .56221 L F
.31777 .56488 m .3195 .56542 L .31757 .56225 L F
.196 0 0 r
.18899 .56768 m .19256 .56576 L .19012 .56615 L F
.508 .831 .999 r
.32547 .52842 m .32843 .53018 L .33069 .52923 L F
.567 .496 .735 r
.37286 .56888 m .36974 .56547 L .37286 .56581 L F
.434 .825 .985 r
.27169 .53595 m .27042 .53559 L .26827 .536 L F
.043 .612 .715 r
.27381 .53543 m .27042 .53559 L .27169 .53595 L F
.203 .063 .456 r
.35812 .58397 m .35934 .5841 L .35951 .58145 L F
.583 .512 .74 r
.34937 .57783 m .34557 .57556 L .34784 .57512 L F
.143 0 0 r
.35013 .66493 m .35139 .66463 L .35575 .66492 L F
.487 .782 .997 r
.27902 .64357 m .28243 .64423 L .28018 .64384 L F
.46 0 0 r
.28243 .64423 m .28045 .64623 L .28018 .64384 L F
.466 0 0 r
.28248 .64536 m .28365 .64679 L .28282 .64608 L F
.46 0 0 r
.2821 .64457 m .28248 .64536 L .28045 .64623 L F
.289 .476 .87 r
.27691 .64043 m .27902 .64357 L .28018 .64384 L F
.951 .616 .346 r
.27836 .643 m .28018 .64384 L .28045 .64623 L F
.525 .573 .846 r
.27836 .643 m .28045 .64623 L .28248 .64536 L F
.466 0 0 r
.28248 .64536 m .28282 .64608 L .28112 .64461 L F
.46 0 0 r
.28243 .64423 m .28248 .64536 L .2821 .64457 L F
.28243 .64423 m .28478 .64494 L .28248 .64536 L F
.459 .351 .644 r
.29558 .62449 m .29435 .62793 L .29394 .62571 L F
.524 0 0 r
.33779 .58422 m .33653 .58391 L .33378 .5822 L F
.093 .637 .841 r
.33779 .58422 m .34037 .58436 L .33653 .58391 L F
.648 .16 .078 r
.34037 .58436 m .33864 .58521 L .33653 .58391 L F
.33864 .58521 m .3382 .58543 L .33653 .58391 L F
.524 0 0 r
.33378 .5822 m .33653 .58391 L .33377 .5822 L F
0 0 0 r
.33894 .56067 m .34035 .56059 L .34108 .56057 L F
.33894 .56067 m .33842 .56167 L .34035 .56059 L F
.435 0 0 r
.29072 .64925 m .29264 .64813 L .2949 .64902 L F
.245 0 .326 r
.38535 .68769 m .38286 .69085 L .38347 .68852 L F
0 .194 .725 r
.38821 .52657 m .388 .52793 L .38592 .52447 L F
.38821 .52657 m .38879 .52819 L .388 .52793 L F
0 0 0 r
.29008 .61229 m .29149 .61066 L .29334 .60974 L F
.022 .22 .727 r
.37056 .60266 m .37279 .60771 L .37349 .60726 L F
0 0 0 r
.37279 .60771 m .37156 .60929 L .37349 .60726 L F
.471 .247 .491 r
.27293 .55953 m .27577 .55613 L .27311 .55696 L F
.27293 .55953 m .27545 .55937 L .27577 .55613 L F
.27293 .55953 m .27545 .55937 L .27577 .55613 L F
.485 .31 .568 r
.27293 .55953 m .27545 .55937 L .27311 .55696 L F
0 0 .52 r
.40095 .55066 m .40318 .55408 L .40245 .55385 L F
.914 .704 .205 r
.40318 .55408 m .40396 .55636 L .40245 .55385 L F
.789 .965 .655 r
.32882 .54217 m .33049 .54118 L .32991 .53961 L F
.32882 .54217 m .3283 .54388 L .33049 .54118 L F
.275 0 .251 r
.38286 .69085 m .37987 .69379 L .38075 .69161 L F
.631 .884 .546 r
.32079 .55337 m .31921 .55493 L .31854 .55608 L F
.673 .583 .746 r
.3826 .64149 m .38002 .64473 L .37849 .64081 L F
.032 0 0 r
.3088 .57753 m .30685 .5785 L .31008 .57594 L F
.185 0 .194 r
.3088 .57753 m .30617 .58075 L .30685 .5785 L F
.211 .575 .941 r
.31604 .62172 m .31756 .62171 L .31739 .62108 L F
.728 .479 .55 r
.36625 .70302 m .36258 .70051 L .36656 .70074 L F
.731 .436 .48 r
.36656 .70074 m .36871 .70382 L .36625 .70302 L F
.23 .659 .957 r
.39588 .56532 m .39632 .56436 L .39377 .56404 L F
.39588 .56532 m .39786 .56539 L .39632 .56436 L F
0 0 0 r
.32268 .59696 m .32749 .5942 L .32724 .59724 L F
0 0 .113 r
.32826 .59346 m .32749 .5942 L .32886 .59093 L F
0 0 .369 r
.32832 .59598 m .32749 .5942 L .32826 .59346 L F
0 0 .356 r
.32832 .59598 m .32724 .59724 L .32749 .5942 L F
0 0 .301 r
.30195 .63016 m .30213 .63325 L .30502 .6291 L F
0 0 0 r
.29008 .61229 m .28764 .61521 L .28877 .61339 L F
.207 .186 .613 r
.28566 .5501 m .28688 .55273 L .28561 .55352 L F
0 0 .109 r
.28688 .55273 m .28466 .55598 L .28561 .55352 L F
.498 .427 .707 r
.34657 .61041 m .34921 .60967 L .34815 .60698 L F
.234 0 .218 r
.34622 .61235 m .34921 .60967 L .34657 .61041 L F
.485 .453 .747 r
.18409 .5994 m .18592 .59568 L .18369 .59836 L F
.18409 .5994 m .18685 .59909 L .18592 .59568 L F
.26 .279 .691 r
.18412 .58461 m .18473 .58836 L .18633 .58671 L F
.246 .298 .719 r
.186 .59109 m .18633 .58671 L .18473 .58836 L F
.378 .596 .931 r
.35891 .51733 m .35954 .51531 L .35735 .51639 L F
.35891 .51733 m .36208 .51825 L .35954 .51531 L F
.742 .278 .148 r
.31924 .55206 m .32339 .55325 L .32132 .5515 L F
.403 .404 .746 r
.32214 .54709 m .32132 .5515 L .32436 .54882 L F
.01 .011 .508 r
.32339 .55325 m .32436 .54882 L .32132 .5515 L F
.28 0 .065 r
.36238 .62484 m .36385 .62455 L .36588 .62279 L F
.297 .577 .938 r
.36377 .61966 m .36588 .62279 L .36621 .62091 L F
0 0 0 r
.36588 .62279 m .36609 .62356 L .36621 .62091 L F
.36588 .62279 m .36385 .62455 L .36609 .62356 L F
.788 .426 .37 r
.32437 .63703 m .32577 .63513 L .32551 .63518 L F
.716 .482 .57 r
.32437 .63703 m .32815 .63446 L .32577 .63513 L F
.757 .69 .787 r
.29896 .55992 m .30023 .56307 L .29541 .56221 L F
.279 .408 .814 r
.30148 .56047 m .30023 .56307 L .29896 .55992 L F
.17 .231 .685 r
.30148 .56047 m .30097 .56562 L .30023 .56307 L F
.387 .826 .951 r
.26281 .52884 m .26531 .5283 L .26673 .52865 L F
.369 .831 .908 r
.26531 .5283 m .2689 .52783 L .26673 .52865 L F
.435 .608 .921 r
.33377 .5822 m .33495 .58185 L .33461 .57929 L F
.393 .399 .747 r
.33377 .5822 m .33653 .58391 L .33495 .58185 L F
.867 .625 .57 r
.34552 .68852 m .34286 .69048 L .34308 .68762 L F
.34552 .68852 m .34528 .69067 L .34286 .69048 L F
.279 .777 .876 r
.3821 .53731 m .37807 .53761 L .37969 .5379 L F
.525 .37 .613 r
.37981 .54084 m .3821 .53731 L .37969 .5379 L F
0 0 0 r
.27381 .63078 m .27262 .63129 L .27133 .63148 L F
.49 .899 .914 r
.3563 .60875 m .3563 .60979 L .35841 .60889 L F
.331 .765 .969 r
.25383 .63409 m .25615 .63387 L .25242 .63341 L F
.061 0 .417 r
.28597 .60047 m .28691 .60275 L .28655 .59995 L F
.28597 .60047 m .28584 .60313 L .28691 .60275 L F
.674 .6 .765 r
.37242 .64165 m .37455 .64326 L .37595 .64115 L F
.546 .236 .394 r
.39637 .5922 m .3947 .59313 L .3945 .59113 L F
0 0 0 r
.36936 .65662 m .36767 .65775 L .36692 .65809 L F
.432 .824 .6 r
.37067 .65562 m .36767 .65775 L .36936 .65662 L F
0 0 0 r
.36799 .65761 m .36767 .65775 L .37067 .65562 L F
.3679 .65768 m .36767 .65775 L .36799 .65761 L F
.36692 .65809 m .36767 .65775 L .36544 .65898 L F
0 0 .438 r
.36936 .65662 m .37047 .65649 L .37067 .65562 L F
.732 .674 .793 r
.38053 .62177 m .37784 .62511 L .3791 .62262 L F
.302 0 0 r
.26085 .63378 m .26063 .63403 L .25863 .63344 L F
.26085 .63378 m .2626 .63436 L .26063 .63403 L F
.007 0 .307 r
.31755 .61296 m .31884 .6144 L .31941 .61217 L F
.31755 .61296 m .31689 .61559 L .31884 .6144 L F
.169 0 .247 r
.21209 .5475 m .2114 .54971 L .21393 .54654 L F
.151 0 .223 r
.3111 .57456 m .3088 .57753 L .31008 .57594 L F
.985 .823 .602 r
.36809 .54461 m .36835 .54738 L .36598 .54492 L F
.868 .875 .841 r
.36591 .55024 m .36598 .54492 L .36835 .54738 L F
.581 .383 .578 r
.36835 .54738 m .36826 .54997 L .36591 .55024 L F
.165 0 .058 r
.36221 .58115 m .36417 .58049 L .36483 .57849 L F
.524 .1 .178 r
.36417 .58049 m .36796 .58109 L .36483 .57849 L F
.452 .24 .5 r
.36849 .58003 m .36483 .57849 L .36796 .58109 L F
0 .123 .652 r
.37534 .63073 m .37345 .62868 L .37558 .62808 L F
.061 .202 .698 r
.32887 .56315 m .3279 .56495 L .32706 .56215 L F
0 0 0 r
.32893 .56034 m .32733 .56187 L .32617 .56244 L F
.32893 .56034 m .32617 .56244 L .32585 .56255 L F
.32585 .56255 m .32617 .56244 L .32563 .56271 L F
.46 .684 .962 r
.32563 .56271 m .32733 .56187 L .32674 .56109 L F
.061 .202 .698 r
.32764 .56195 m .32706 .56215 L .32674 .56109 L F
.32887 .56315 m .32706 .56215 L .32764 .56195 L F
.17 0 0 r
.33064 .56078 m .32893 .56034 L .33143 .55985 L F
.33064 .56078 m .32733 .56187 L .32893 .56034 L F
.695 .56 .698 r
.34919 .55936 m .35108 .55728 L .34769 .55411 L F
.34919 .55936 m .35178 .55981 L .35108 .55728 L F
.574 .661 .896 r
.36128 .53005 m .35832 .53124 L .35797 .53016 L F
.728 .357 .347 r
.36134 .53391 m .35832 .53124 L .36128 .53005 L F
.36134 .53391 m .35738 .53356 L .35832 .53124 L F
.352 .44 .812 r
.34147 .56483 m .34227 .56646 L .34012 .56645 L F
.744 .736 .844 r
.33916 .52183 m .341 .52534 L .33699 .52483 L F
.04 .599 .809 r
.33699 .52483 m .33995 .52506 L .341 .52534 L F
.67 .561 .723 r
.34161 .52098 m .33916 .52183 L .33799 .51795 L F
.34161 .52098 m .33799 .51795 L .34118 .52037 L F
.871 .992 .743 r
.34118 .52037 m .34051 .52124 L .34161 .52098 L F
.617 .418 .589 r
.34161 .52098 m .34179 .52365 L .33916 .52183 L F
.871 .992 .743 r
.34051 .52124 m .33965 .52235 L .34043 .5218 L F
.34051 .52124 m .34043 .5218 L .34161 .52098 L F
.193 .421 .854 r
.34179 .52365 m .341 .52534 L .34016 .52374 L F
.34032 .52263 m .34016 .52374 L .33916 .52183 L F
.34179 .52365 m .34016 .52374 L .34032 .52263 L F
.683 .968 .928 r
.34179 .52365 m .33995 .52506 L .341 .52534 L F
.088 .618 .869 r
.29519 .55282 m .29366 .55232 L .2913 .55213 L F
0 .401 .699 r
.29519 .55282 m .29762 .55356 L .29366 .55232 L F
.787 .546 .573 r
.38059 .6055 m .3829 .60328 L .38057 .60414 L F
.473 .412 .708 r
.38223 .60175 m .38059 .6055 L .38057 .60414 L F
.008 0 .306 r
.35178 .55981 m .35352 .55617 L .35108 .55728 L F
.403 .249 .555 r
.31059 .56603 m .31072 .56883 L .31267 .56782 L F
.31059 .56603 m .31072 .56883 L .31267 .56782 L F
.22 0 0 r
.29697 .52432 m .30086 .52508 L .29884 .52461 L F
.438 .226 .493 r
.22187 .56285 m .22165 .56552 L .21926 .56611 L F
.529 .302 .514 r
.22165 .5682 m .21926 .56611 L .22165 .56552 L F
.22165 .5682 m .21903 .56895 L .21926 .56611 L F
.758 .974 .705 r
.3407 .50985 m .33821 .51287 L .33915 .51093 L F
.325 .512 .886 r
.33821 .51287 m .34037 .51307 L .33915 .51093 L F
.824 .6 .598 r
.22665 .56132 m .2243 .56512 L .22429 .56236 L F
.722 .464 .535 r
.22665 .56132 m .22762 .56531 L .2243 .56512 L F
.12 .03 .469 r
.2291 .56139 m .22762 .56531 L .22665 .56132 L F
.42 .845 .697 r
.2286 .53697 m .22994 .53606 L .23203 .53541 L F
.563 .932 .8 r
.23203 .53541 m .23189 .53473 L .23439 .53506 L F
.23203 .53541 m .22994 .53606 L .23189 .53473 L F
.475 .878 .724 r
.30153 .67554 m .3043 .6752 L .30194 .67499 L F
.545 .822 .997 r
.30126 .67557 m .29768 .67579 L .30107 .67543 L F
.30241 .67642 m .29842 .67589 L .30126 .67557 L F
.29842 .67589 m .29768 .67579 L .30126 .67557 L F
.30241 .67642 m .30107 .67543 L .30132 .67549 L F
.29768 .67579 m .30241 .67642 L .3001 .67746 L F
.649 .936 .967 r
.3043 .6752 m .30344 .67575 L .30123 .67541 L F
.30344 .67575 m .30241 .67642 L .30123 .67541 L F
.921 .893 .785 r
.3001 .67746 m .30159 .67546 L .30123 .67541 L F
.30159 .67546 m .30194 .67499 L .30123 .67541 L F
.475 .878 .724 r
.3001 .67746 m .30298 .67591 L .30153 .67554 L F
.3001 .67746 m .30241 .67642 L .3043 .6752 L F
.458 .208 .446 r
.30245 .67697 m .30206 .67548 L .3001 .67746 L F
.649 .936 .967 r
.3043 .6752 m .30177 .67537 L .30194 .67499 L F
.458 .208 .446 r
.30171 .67552 m .30194 .67499 L .30153 .67554 L F
.649 .936 .967 r
.30177 .67537 m .30123 .67541 L .30194 .67499 L F
.458 .208 .446 r
.30206 .67548 m .30194 .67499 L .30171 .67552 L F
.30206 .67548 m .30153 .67554 L .3001 .67746 L F
.475 .878 .724 r
.30298 .67591 m .3043 .6752 L .30153 .67554 L F
.545 .822 .997 r
.30132 .67549 m .30107 .67543 L .30123 .67541 L F
.713 .248 .145 r
.24255 .55348 m .23845 .55249 L .24128 .55267 L F
.53 .182 .322 r
.32696 .55598 m .33094 .55323 L .32466 .55252 L F
.32696 .55598 m .32827 .55653 L .33094 .55323 L F
.637 .311 .403 r
.33094 .55323 m .33341 .55539 L .33357 .55319 L F
.33094 .55323 m .32829 .55651 L .33341 .55539 L F
.32829 .55651 m .32832 .55652 L .33341 .55539 L F
.583 .43 .639 r
.32479 .55507 m .32696 .55598 L .32466 .55252 L F
0 0 .319 r
.33081 .55597 m .32918 .55642 L .33341 .55539 L F
.32832 .55652 m .32884 .55646 L .33081 .55597 L F
.21 .729 .714 r
.33341 .55539 m .32944 .55636 L .33294 .55541 L F
0 0 .43 r
.32912 .5564 m .32982 .5563 L .32909 .55657 L F
.21 .729 .714 r
.32944 .55636 m .32916 .55642 L .32957 .55631 L F
.32944 .55636 m .32957 .55631 L .33294 .55541 L F
0 0 0 r
.32997 .55624 m .33294 .55541 L .32957 .55631 L F
0 0 .319 r
.329 .55642 m .32937 .55636 L .33081 .55597 L F
0 0 .43 r
.32983 .55236 m .32982 .5563 L .32912 .5564 L F
0 0 0 r
.32997 .55624 m .32957 .55631 L .32916 .55642 L F
0 0 .43 r
.32982 .55627 m .32997 .55624 L .32982 .5563 L F
.32982 .55623 m .32997 .55624 L .32982 .55627 L F
.32983 .55236 m .32997 .55618 L .32982 .55623 L F
.32997 .55618 m .32997 .55624 L .32982 .55623 L F
0 0 .319 r
.32884 .55646 m .32918 .55642 L .32937 .55636 L F
.202 .153 .576 r
.32909 .55657 m .32872 .55647 L .32884 .55646 L F
.673 .175 .055 r
.32882 .55646 m .32909 .55657 L .32884 .55646 L F
.202 .153 .576 r
.32909 .55657 m .32855 .55796 L .32866 .55646 L F
0 0 .319 r
.32866 .55648 m .32898 .55688 L .32882 .55646 L F
.32827 .55653 m .32864 .55671 L .32866 .55648 L F
.32864 .55671 m .32898 .55688 L .32866 .55648 L F
.11 0 .28 r
.32909 .55657 m .32983 .55886 L .32997 .55624 L F
0 0 0 r
.32884 .55722 m .32855 .55796 L .32909 .55657 L F
.865 .944 .581 r
.32909 .55657 m .3288 .55711 L .32855 .55796 L F
0 0 .319 r
.32827 .55653 m .32855 .55796 L .32879 .55715 L F
.32827 .55653 m .3288 .55716 L .32865 .55671 L F
.3288 .55716 m .32884 .55722 L .3288 .55711 L F
.3288 .55716 m .3288 .55711 L .32865 .55671 L F
.202 .153 .576 r
.32858 .55753 m .32855 .55796 L .32843 .55782 L F
.52 .216 .391 r
.32696 .55598 m .32855 .55796 L .32827 .55653 L F
.202 .153 .576 r
.32858 .55753 m .32843 .55782 L .32696 .55598 L F
0 0 .319 r
.32868 .55648 m .32884 .55646 L .32885 .55646 L F
.32827 .55653 m .32866 .55648 L .32868 .55648 L F
.32866 .55648 m .32884 .55646 L .32868 .55648 L F
.202 .153 .576 r
.32866 .55646 m .32866 .55648 L .32696 .55598 L F
.32866 .55648 m .32858 .55753 L .32767 .55666 L F
0 0 .319 r
.32827 .55653 m .32918 .55642 L .32832 .55652 L F
.637 .311 .403 r
.32829 .55651 m .32827 .55653 L .32832 .55652 L F
.202 .153 .576 r
.32866 .55648 m .32767 .55666 L .32696 .55598 L F
.855 .746 .742 r
.3288 .55711 m .3252 .56027 L .32697 .56057 L F
.32909 .55657 m .32883 .55682 L .3288 .55711 L F
.32883 .55682 m .3252 .56027 L .3288 .55711 L F
.865 .944 .581 r
.3288 .55711 m .32697 .56057 L .32855 .55796 L F
0 0 .319 r
.32879 .55715 m .32855 .55796 L .32884 .55722 L F
.11 0 .28 r
.32909 .55657 m .3288 .55711 L .32884 .55722 L F
.32909 .55657 m .32776 .56009 L .32983 .55886 L F
0 0 0 r
.3289 .55707 m .32884 .55722 L .32909 .55657 L F
0 0 .319 r
.32865 .55671 m .3289 .55707 L .32883 .5568 L F
.11 0 .28 r
.32884 .55722 m .32697 .56057 L .32776 .56009 L F
.3288 .55711 m .32697 .56057 L .32884 .55722 L F
.427 .102 .309 r
.32848 .55821 m .3252 .56027 L .32883 .55682 L F
.3289 .55707 m .32883 .55682 L .32909 .55657 L F
0 0 .319 r
.32865 .55671 m .32884 .55722 L .3289 .55707 L F
.427 .102 .309 r
.32848 .55821 m .32883 .55682 L .3289 .55707 L F
0 0 .319 r
.32883 .5568 m .3289 .55707 L .32898 .55688 L F
.198 .055 .449 r
.32997 .55624 m .32851 .55819 L .32909 .55657 L F
0 0 0 r
.32916 .55642 m .3289 .55707 L .32909 .55657 L F
.427 .102 .309 r
.32851 .55819 m .32848 .55821 L .32909 .55657 L F
.673 .175 .055 r
.32876 .55648 m .32883 .5565 L .32882 .55646 L F
.32883 .5565 m .32909 .55657 L .32882 .55646 L F
0 0 .43 r
.32912 .5564 m .32909 .55657 L .32883 .5565 L F
0 0 .319 r
.32882 .55646 m .32883 .5565 L .32884 .55646 L F
0 0 .43 r
.32884 .55646 m .32883 .5565 L .32876 .55648 L F
.32912 .5564 m .32883 .5565 L .32884 .55646 L F
0 0 .319 r
.32884 .55646 m .32898 .55688 L .32916 .55642 L F
.32883 .5565 m .32898 .55688 L .32884 .55646 L F
.32884 .55646 m .32937 .55636 L .329 .55642 L F
.202 .153 .576 r
.32884 .55646 m .32737 .5561 L .32571 .55502 L F
.32603 .55512 m .32571 .55502 L .32537 .5548 L F
.32884 .55646 m .32571 .55502 L .32603 .55512 L F
.289 .108 .453 r
.32983 .55236 m .32698 .5554 L .32788 .5513 L F
.202 .153 .576 r
.32872 .55647 m .32737 .5561 L .32884 .55646 L F
.32737 .5561 m .32696 .55598 L .32673 .55581 L F
.32737 .5561 m .32673 .55581 L .32537 .5548 L F
.673 .175 .055 r
.32658 .55584 m .32876 .55648 L .32537 .5548 L F
.289 .108 .453 r
.32698 .5554 m .32658 .55584 L .32672 .55533 L F
.32698 .5554 m .32672 .55533 L .32788 .5513 L F
.673 .175 .055 r
.32876 .55648 m .32884 .55646 L .32537 .5548 L F
0 0 .43 r
.32983 .55236 m .32912 .5564 L .32658 .55584 L F
.32912 .5564 m .32876 .55648 L .32658 .55584 L F
0 0 .319 r
.32885 .55646 m .32916 .55642 L .32918 .55642 L F
.32884 .55646 m .32916 .55642 L .32885 .55646 L F
.729 .797 .906 r
.3638 .51253 m .36188 .51399 L .35981 .51216 L F
.526 .371 .613 r
.23845 .55249 m .23871 .55545 L .23607 .55316 L F
.525 .371 .615 r
.23871 .55545 m .23633 .55676 L .23607 .55316 L F
.959 .946 .682 r
.33804 .67586 m .33606 .67973 L .33595 .6773 L F
.187 0 0 r
.33632 .67517 m .33891 .67372 L .33866 .67438 L F
.695 .85 .43 r
.34011 .67217 m .33824 .67549 L .33866 .67438 L F
0 0 0 r
.34136 .6714 m .33866 .67438 L .34045 .67286 L F
.187 0 0 r
.33891 .67372 m .34045 .67286 L .33866 .67438 L F
.695 .85 .43 r
.33824 .67549 m .33804 .67586 L .33866 .67438 L F
.726 .964 .697 r
.33866 .67438 m .33804 .67586 L .33595 .6773 L F
.684 .795 .933 r
.36669 .53665 m .36276 .53709 L .36576 .53591 L F
0 .489 .789 r
.36576 .53591 m .36783 .53662 L .36669 .53665 L F
.479 .408 .699 r
.32997 .62502 m .33255 .6261 L .33324 .62546 L F
.32997 .62502 m .33071 .6287 L .33255 .6261 L F
0 .479 .81 r
.35568 .63402 m .35655 .63406 L .358 .63484 L F
0 0 .555 r
.35865 .63312 m .358 .63484 L .35655 .63406 L F
.35865 .63312 m .3593 .63556 L .358 .63484 L F
.778 .537 .571 r
.35676 .69761 m .35281 .69982 L .35268 .6972 L F
.35676 .69761 m .35662 .70029 L .35281 .69982 L F
.408 .128 .373 r
.37503 .70013 m .37221 .70293 L .37272 .70066 L F
0 .315 .673 r
.24682 .62044 m .24941 .62155 L .25117 .62238 L F
.407 .793 .99 r
.24941 .62155 m .25345 .62203 L .25117 .62238 L F
.24941 .62155 m .25345 .62203 L .25117 .62238 L F
.63 .102 0 r
.29242 .64334 m .2912 .64172 L .28718 .64082 L F
.552 .082 .092 r
.29361 .64303 m .2912 .64172 L .29242 .64334 L F
.551 0 0 r
.29586 .64364 m .2912 .64172 L .29361 .64303 L F
.997 .806 .527 r
.30457 .58445 m .30296 .58687 L .30492 .58653 L F
.965 .649 .364 r
.30388 .58671 m .30425 .58947 L .30492 .58653 L F
.30398 .58893 m .30425 .58947 L .30388 .58671 L F
.911 .764 .275 r
.30492 .58653 m .30425 .58947 L .30466 .5901 L F
.871 .678 .639 r
.30391 .58958 m .30425 .58947 L .30296 .58687 L F
0 0 .333 r
.30493 .5864 m .30536 .5886 L .30401 .58951 L F
.304 .58931 m .30401 .58951 L .30391 .58958 L F
.30493 .5864 m .30401 .58951 L .304 .58931 L F
.965 .649 .364 r
.30296 .58687 m .30398 .58893 L .30388 .58671 L F
.444 .409 .724 r
.20587 .58374 m .20646 .58772 L .20447 .588 L F
.591 .627 .856 r
.36208 .51825 m .36271 .52036 L .36479 .51957 L F
.503 .399 .669 r
.38373 .66298 m .38152 .6662 L .3799 .66261 L F
.38373 .66298 m .38383 .66572 L .38152 .6662 L F
.558 .424 .655 r
.38435 .66893 m .38152 .6662 L .38383 .66572 L F
.38435 .66893 m .38186 .66965 L .38152 .6662 L F
.519 .19 .349 r
.3663 .61271 m .36893 .61254 L .37095 .60989 L F
.546 .32 .523 r
.36893 .61254 m .37156 .60929 L .37095 .60989 L F
.246 .298 .719 r
.186 .59109 m .18715 .59029 L .18633 .58671 L F
.287 .174 .546 r
.186 .59109 m .18765 .59322 L .18715 .59029 L F
.186 .59109 m .18527 .59474 L .18765 .59322 L F
.008 0 .306 r
.35178 .55981 m .35302 .55898 L .35352 .55617 L F
.305 0 .107 r
.34997 .5613 m .35302 .55898 L .35178 .55981 L F
0 0 .163 r
.28652 .61748 m .28562 .61611 L .28764 .61521 L F
.28652 .61748 m .28496 .61837 L .28562 .61611 L F
.648 .368 .48 r
.34163 .63684 m .33866 .63471 L .33929 .6379 L F
.42 .237 .525 r
.33929 .6379 m .34213 .63901 L .34163 .63684 L F
.33929 .6379 m .33927 .64085 L .34213 .63901 L F
.095 0 0 r
.27042 .53559 m .26611 .53633 L .26827 .536 L F
.837 .961 .628 r
.38227 .61581 m .38031 .61897 L .38172 .61705 L F
.788 .426 .37 r
.32437 .63703 m .32551 .63518 L .32177 .63734 L F
.703 .622 .764 r
.35504 .62182 m .35939 .62264 L .35753 .61889 L F
.697 .631 .779 r
.35753 .61889 m .35939 .62264 L .36122 .61988 L F
.716 .535 .644 r
.35939 .62264 m .35899 .62526 L .36238 .62484 L F
.713 .248 .145 r
.24255 .55348 m .2402 .55413 L .23845 .55249 L F
.768 .335 .224 r
.24255 .55348 m .24046 .55492 L .2402 .55413 L F
.483 .852 .618 r
.24322 .55282 m .24255 .55348 L .24487 .55296 L F
.24322 .55282 m .24046 .55492 L .24255 .55348 L F
0 0 .162 r
.32631 .61233 m .32677 .60988 L .32796 .60863 L F
.223 .39 .819 r
.38019 .63085 m .38195 .63486 L .38345 .63162 L F
.38019 .63085 m .38461 .63385 L .38195 .63486 L F
.606 .043 0 r
.3817 .6356 m .38375 .63655 L .38195 .63486 L F
.3817 .6356 m .38195 .63486 L .38461 .63385 L F
.868 .981 .845 r
.29528 .58772 m .29226 .58954 L .29399 .58686 L F
.29528 .58772 m .29232 .59071 L .29226 .58954 L F
.132 0 0 r
.35714 .66294 m .36 .66224 L .3577 .66306 L F
.392 .352 .694 r
.36958 .59783 m .3715 .59839 L .37216 .59644 L F
.36958 .59783 m .37021 .60036 L .3715 .59839 L F
.454 .579 .889 r
.30237 .65332 m .30413 .65603 L .30643 .65592 L F
.575 .341 .524 r
.2243 .56512 m .22187 .56285 L .22429 .56236 L F
.2243 .56512 m .22165 .56552 L .22187 .56285 L F
0 0 0 r
.36343 .56152 m .36337 .5647 L .3633 .56596 L F
.679 .165 .009 r
.36134 .53391 m .36576 .53591 L .36276 .53709 L F
.868 .875 .841 r
.36591 .55024 m .36381 .54908 L .36598 .54492 L F
.539 .441 .692 r
.36932 .55311 m .36591 .55024 L .36826 .54997 L F
.36932 .55311 m .36662 .55419 L .36591 .55024 L F
.531 .38 .621 r
.37948 .64726 m .3777 .65048 L .37694 .64691 L F
.594 .653 .878 r
.33133 .57443 m .3326 .57638 L .33512 .57563 L F
.447 .54 .859 r
.32331 .52978 m .32543 .53387 L .32333 .53404 L F
.341 .371 .747 r
.31995 .59429 m .32295 .59635 L .32189 .59276 L F
.593 .546 .771 r
.31995 .59429 m .32268 .59696 L .32295 .59635 L F
.741 .642 .749 r
.35721 .54884 m .35888 .55187 L .35899 .55068 L F
.459 .034 .145 r
.35888 .55187 m .36152 .55159 L .35899 .55068 L F
.459 .032 .142 r
.35899 .55068 m .36152 .55159 L .36257 .55048 L F
0 0 .094 r
.18592 .59568 m .18765 .59322 L .18527 .59474 L F
.607 .283 .394 r
.18012 .68422 m .18246 .68472 L .17864 .68542 L F
.17864 .68542 m .18246 .68472 L .18012 .68422 L F
.291 .084 .417 r
.18704 .56891 m .18889 .57045 L .18899 .56768 L F
.18704 .56891 m .18652 .57188 L .18889 .57045 L F
.748 .62 .717 r
.34016 .62756 m .33568 .63063 L .33754 .6289 L F
.239 0 .255 r
.32466 .55252 m .32537 .5548 L .32351 .55531 L F
0 0 0 r
.32916 .54958 m .32788 .5513 L .32466 .55252 L F
.15 0 .269 r
.32788 .5513 m .32537 .5548 L .32466 .55252 L F
.505 .773 .992 r
.21252 .61157 m .21648 .61272 L .2149 .61166 L F
0 .424 .778 r
.21865 .61327 m .2149 .61166 L .21648 .61272 L F
.903 .953 .609 r
.3553 .57071 m .35515 .57273 L .35696 .56913 L F
.957 .793 .638 r
.35331 .57228 m .35515 .57273 L .3553 .57071 L F
.648 .18 .128 r
.35742 .57253 m .35367 .57225 L .3553 .57071 L F
.35367 .57225 m .35348 .57224 L .3553 .57071 L F
.903 .953 .609 r
.3553 .57071 m .35696 .56913 L .35698 .56911 L F
.728 .928 .588 r
.35772 .56745 m .3553 .57071 L .35698 .56911 L F
.366 .087 .352 r
.38762 .68426 m .3854 .68491 L .38826 .68202 L F
.367 .106 .38 r
.39031 .6813 m .38762 .68426 L .38826 .68202 L F
.357 0 0 r
.30335 .63351 m .30531 .63245 L .30739 .63314 L F
.369 0 .067 r
.30739 .63314 m .30531 .63245 L .30806 .63167 L F
.05 0 0 r
.20603 .55257 m .20763 .55245 L .20958 .55088 L F
0 0 0 r
.20958 .55088 m .20985 .5516 L .2114 .54971 L F
.20958 .55088 m .20763 .55245 L .20985 .5516 L F
.391 .214 .518 r
.39873 .5909 m .39695 .58787 L .39849 .58706 L F
0 0 0 r
.39818 .5785 m .39647 .58106 L .39547 .5818 L F
.521 .526 .801 r
.39865 .5845 m .39547 .5818 L .3983 .58328 L F
.617 .59 .801 r
.31914 .57727 m .32153 .57411 L .32001 .57557 L F
.31914 .57727 m .3231 .57851 L .32153 .57411 L F
.486 .19 .389 r
.31973 .58115 m .3231 .57851 L .31914 .57727 L F
.486 .275 .518 r
.20815 .57534 m .20786 .5779 L .20544 .5785 L F
.363 .128 .417 r
.20786 .5779 m .20523 .58119 L .20544 .5785 L F
.275 0 0 r
.30996 .64558 m .30802 .64499 L .30604 .64572 L F
0 .164 .699 r
.38013 .52057 m .38013 .52161 L .37787 .5186 L F
0 .347 .818 r
.38013 .52057 m .38166 .52242 L .38013 .52161 L F
.592 .835 .991 r
.35641 .54033 m .3542 .54124 L .35477 .53918 L F
.658 .815 .959 r
.24767 .77832 m .24908 .77989 L .25175 .77867 L F
.24767 .77832 m .24908 .77989 L .25175 .77867 L F
.427 .194 .457 r
.3604 .54375 m .35777 .54654 L .35824 .54406 L F
.751 .323 .235 r
.25595 .54699 m .25994 .54801 L .25776 .5484 L F
.41 .727 .99 r
.27353 .63933 m .27484 .64076 L .27691 .64043 L F
.485 .395 .679 r
.4006 .57777 m .39818 .5785 L .39848 .57673 L F
.533 .172 .3 r
.40095 .58036 m .39818 .5785 L .4006 .57777 L F
.579 .614 .851 r
.22336 .60872 m .22514 .61197 L .22157 .61212 L F
0 0 .136 r
.40442 .55861 m .40484 .56108 L .40508 .56277 L F
.666 .2 0 r
.40529 .5636 m .40508 .56277 L .40484 .56108 L F
.40529 .5636 m .40636 .56477 L .40508 .56277 L F
0 0 .044 r
.39164 .59645 m .39263 .59468 L .3947 .59313 L F
.214 0 0 r
.33258 .60224 m .33096 .60179 L .33045 .60263 L F
.33258 .60224 m .33368 .60154 L .33096 .60179 L F
.695 .414 .493 r
.28362 .55256 m .28566 .5501 L .28361 .5498 L F
.28362 .55256 m .28688 .55273 L .28566 .5501 L F
.728 .831 .928 r
.31397 .52197 m .31001 .52185 L .31216 .52057 L F
.656 .815 .96 r
.31647 .52115 m .31397 .52197 L .31216 .52057 L F
.839 .833 .84 r
.24385 .54196 m .24776 .54377 L .24605 .54122 L F
.24385 .54196 m .24597 .54323 L .24776 .54377 L F
.527 .799 .996 r
.24776 .54377 m .24848 .54046 L .24605 .54122 L F
.24776 .54377 m .25234 .54309 L .24848 .54046 L F
.53 .802 .996 r
.25 .54386 m .25234 .54309 L .24776 .54377 L F
.392 .786 .987 r
.24776 .54377 m .24597 .54323 L .25 .54386 L F
.726 .792 .904 r
.24597 .54323 m .24759 .54489 L .25 .54386 L F
.24597 .54323 m .24759 .54489 L .25 .54386 L F
.75 .616 .71 r
.38049 .67473 m .38267 .67561 L .38382 .6754 L F
.509 .489 .77 r
.32926 .60653 m .33154 .60676 L .33045 .60263 L F
.26 .279 .691 r
.18412 .58461 m .18633 .58671 L .18583 .58408 L F
0 0 0 r
.32198 .60702 m .31941 .61217 L .32166 .61192 L F
.245 .025 .368 r
.32378 .608 m .32198 .60702 L .32166 .61192 L F
.65 .558 .738 r
.35492 .61944 m .35504 .62182 L .35753 .61889 L F
.758 .464 .486 r
.21655 .57494 m .21453 .57204 L .21701 .57219 L F
.47 .234 .474 r
.21915 .57415 m .21701 .57219 L .21973 .57177 L F
.21915 .57415 m .21655 .57494 L .21701 .57219 L F
.544 .925 .912 r
.24045 .53351 m .23838 .5346 L .23677 .53466 L F
.302 0 .261 r
.36799 .56499 m .37099 .56225 L .36864 .56291 L F
.455 .249 .51 r
.21006 .57728 m .20786 .5779 L .20815 .57534 L F
0 0 .406 r
.39183 .53235 m .39114 .53138 L .39008 .52986 L F
.39183 .53235 m .3929 .53389 L .39114 .53138 L F
.821 .354 0 r
.33071 .6287 m .3325 .63183 L .33344 .63137 L F
0 0 0 r
.34011 .67217 m .33866 .67438 L .34136 .6714 L F
.135 0 0 r
.33423 .53128 m .33752 .53189 L .33593 .53223 L F
0 0 .224 r
.35728 .63137 m .35568 .63402 L .35375 .63416 L F
.35728 .63137 m .35655 .63406 L .35568 .63402 L F
.656 .1 0 r
.34304 .61872 m .34509 .61955 L .34297 .61849 L F
.34304 .61872 m .34509 .61955 L .34297 .61849 L F
.733 .533 .622 r
.34304 .61872 m .34727 .61589 L .34509 .61955 L F
.713 .423 .484 r
.347 .62117 m .34304 .61872 L .34509 .61955 L F
.527 .379 .623 r
.34727 .61589 m .3475 .61888 L .34509 .61955 L F
.441 .17 .405 r
.34509 .61955 m .3475 .61888 L .347 .62117 L F
.322 .06 .353 r
.26369 .53963 m .26275 .5376 L .26446 .53724 L F
.26369 .53963 m .26149 .54063 L .26275 .5376 L F
.149 0 .075 r
.27943 .5439 m .27824 .54642 L .2763 .54663 L F
.694 .561 .701 r
.28237 .54121 m .28208 .5464 L .27943 .5439 L F
.299 0 .146 r
.28062 .54573 m .28046 .54487 L .28208 .5464 L F
0 0 .39 r
.28362 .5425 m .28208 .5464 L .28237 .54121 L F
.489 .89 .944 r
.28263 .54484 m .28062 .54573 L .28208 .5464 L F
0 0 0 r
.28263 .54484 m .28067 .54604 L .28062 .54573 L F
.28067 .54604 m .27934 .54685 L .28062 .54573 L F
.299 0 .146 r
.28062 .54573 m .27943 .5439 L .28046 .54487 L F
.28062 .54573 m .27824 .54642 L .27943 .5439 L F
.787 .546 .573 r
.38059 .6055 m .3824 .60572 L .3829 .60328 L F
.963 .789 .618 r
.33944 .54908 m .34117 .55224 L .34247 .54991 L F
.33944 .54908 m .33838 .55163 L .34117 .55224 L F
.996 .766 .461 r
.33838 .55163 m .34288 .55443 L .34117 .55224 L F
0 0 0 r
.34117 .55224 m .34491 .54877 L .34247 .54991 L F
.512 .515 .796 r
.34288 .55443 m .34375 .55137 L .34117 .55224 L F
.635 .811 .968 r
.36882 .66754 m .36434 .66682 L .36702 .66615 L F
.643 .836 .975 r
.3694 .66522 m .36882 .66754 L .36702 .66615 L F
.3694 .66522 m .37128 .66647 L .36882 .66754 L F
0 .139 .683 r
.22432 .61905 m .22435 .61782 L .22223 .61583 L F
0 .379 .84 r
.22432 .61905 m .22733 .62089 L .22435 .61782 L F
.474 .472 .776 r
.2913 .55213 m .29279 .54971 L .28967 .54957 L F
.2913 .55213 m .29366 .55232 L .29279 .54971 L F
.273 .069 .41 r
.30288 .59645 m .30072 .59981 L .30108 .59731 L F
0 .281 .778 r
.27072 .63692 m .27232 .6371 L .27064 .63655 L F
0 0 .429 r
.26899 .63428 m .27082 .63734 L .27072 .63692 L F
.793 .3 0 r
.26899 .63428 m .27072 .63692 L .26902 .63603 L F
0 .281 .778 r
.27072 .63692 m .27064 .63655 L .26902 .63603 L F
0 0 .429 r
.27082 .63734 m .27084 .63737 L .27072 .63692 L F
0 .178 .658 r
.27084 .63737 m .27353 .63933 L .27072 .63692 L F
.376 .168 .466 r
.37987 .69379 m .37754 .69705 L .37769 .6944 L F
.642 .716 .901 r
.34749 .51017 m .34332 .50896 L .34579 .50815 L F
.671 .763 .919 r
.34954 .50884 m .34749 .51017 L .34579 .50815 L F
.982 .719 .454 r
.31924 .55206 m .31921 .55493 L .32079 .55337 L F
.26 .767 .757 r
.30546 .52299 m .31001 .52185 L .3078 .52298 L F
.256 .482 .884 r
.38565 .6374 m .38382 .6389 L .38375 .63655 L F
.38565 .6374 m .38734 .64012 L .38382 .6389 L F
.593 .941 .93 r
.27547 .52563 m .27574 .52441 L .27759 .52532 L F
.27547 .52563 m .27324 .52556 L .27574 .52441 L F
.336 0 0 r
.29361 .64303 m .29731 .6442 L .29586 .64364 L F
.66 .285 .323 r
.35267 .55185 m .35487 .55219 L .35301 .55008 L F
.573 .57 .811 r
.35267 .55185 m .35352 .55617 L .35612 .55545 L F
.35267 .55185 m .35612 .55545 L .35487 .55219 L F
.671 .587 .753 r
.35267 .55185 m .35612 .55545 L .35487 .55219 L F
.674 .282 .297 r
.35487 .55219 m .35111 .55203 L .35301 .55008 L F
.277 .127 .49 r
.37712 .58783 m .3808 .58649 L .37929 .58327 L F
.157 .032 .447 r
.37712 .58783 m .38016 .58595 L .3808 .58649 L F
.843 .58 .541 r
.38016 .58595 m .3808 .58726 L .38081 .58607 L F
.157 .032 .447 r
.3808 .58649 m .38016 .58595 L .38098 .58642 L F
.744 .303 .204 r
.37929 .58327 m .38081 .5861 L .38109 .58612 L F
.843 .58 .541 r
.38081 .5861 m .38095 .58661 L .38109 .58612 L F
.744 .303 .204 r
.38081 .5861 m .38098 .58642 L .38109 .58612 L F
.843 .58 .541 r
.38081 .58607 m .38081 .5861 L .38109 .58612 L F
.38095 .58661 m .38149 .58865 L .3812 .58681 L F
.38095 .58661 m .3812 .58681 L .38109 .58612 L F
.3808 .58726 m .38149 .58865 L .38081 .58607 L F
.277 .127 .49 r
.3808 .58649 m .38098 .58642 L .38081 .5861 L F
.3808 .58649 m .38081 .5861 L .37929 .58327 L F
.157 .032 .447 r
.37712 .58783 m .37713 .59033 L .38016 .58595 L F
.914 .704 .205 r
.40318 .55408 m .40318 .55544 L .40396 .55636 L F
0 0 .23 r
.40468 .55727 m .40396 .55636 L .40318 .55544 L F
.40468 .55727 m .40442 .55861 L .40396 .55636 L F
0 0 0 r
.32826 .59346 m .32886 .59093 L .32966 .58938 L F
.483 .298 .552 r
.38771 .68714 m .3854 .68491 L .38762 .68426 L F
.38771 .68714 m .38535 .68769 L .3854 .68491 L F
.311 .249 .624 r
.37021 .60036 m .37241 .60271 L .3715 .59839 L F
.33 .252 .615 r
.37056 .60266 m .37241 .60271 L .37021 .60036 L F
.365 .222 .55 r
.28934 .5937 m .29226 .58954 L .29232 .59071 L F
.712 .913 .559 r
.28612 .54402 m .28389 .5471 L .28499 .54526 L F
.187 .186 .625 r
.28389 .5471 m .28562 .54908 L .28499 .54526 L F
.462 .648 .939 r
.37376 .60998 m .37402 .61275 L .37224 .61024 L F
.014 0 0 r
.37403 .60993 m .37376 .60998 L .37349 .61034 L F
.3768 .60781 m .37376 .60998 L .37403 .60993 L F
.462 .648 .939 r
.37376 .60998 m .37224 .61024 L .37156 .60929 L F
.37376 .60998 m .37535 .61236 L .37402 .61275 L F
.22 .287 .721 r
.22004 .5927 m .2187 .5941 L .21786 .59034 L F
.135 .027 .455 r
.22004 .5927 m .21826 .59665 L .2187 .5941 L F
.385 .094 .342 r
.3846 .5913 m .38404 .59337 L .38174 .59406 L F
.3846 .5913 m .38404 .59337 L .38174 .59406 L F
.541 .456 .709 r
.38678 .58768 m .38695 .59074 L .3846 .5913 L F
.425 .132 .361 r
.38695 .59074 m .38404 .59337 L .3846 .5913 L F
.541 .456 .709 r
.3846 .5913 m .38695 .59074 L .38678 .58768 L F
.425 .132 .361 r
.38695 .59074 m .38404 .59337 L .3846 .5913 L F
.659 .126 0 r
.25743 .62335 m .25982 .62519 L .26125 .62491 L F
0 0 0 r
.25982 .62519 m .26359 .62431 L .26125 .62491 L F
.764 .943 .939 r
.26481 .63547 m .26729 .63602 L .26899 .63428 L F
.858 .82 .809 r
.36173 .61804 m .36323 .61774 L .36122 .61988 L F
.36254 .61513 m .36122 .61988 L .36119 .61811 L F
.375 .416 .775 r
.36119 .61811 m .36122 .61988 L .36377 .61966 L F
.3612 .61815 m .36377 .61966 L .36183 .62055 L F
.36119 .61811 m .36125 .61814 L .3612 .61815 L F
.36125 .61814 m .36377 .61966 L .3612 .61815 L F
.858 .82 .809 r
.36254 .61513 m .36453 .61635 L .36323 .61774 L F
.36254 .61513 m .36323 .61774 L .36173 .61804 L F
.735 .214 0 r
.36436 .61794 m .36644 .61835 L .36453 .61635 L F
.512 .017 0 r
.36453 .61635 m .36644 .61835 L .36418 .616 L F
.735 .214 0 r
.36436 .61794 m .36453 .61635 L .36254 .61513 L F
.786 .864 .907 r
.36809 .54461 m .36538 .54367 L .37059 .54347 L F
.36809 .54461 m .36538 .54367 L .37059 .54347 L F
.473 .298 .562 r
.37304 .54045 m .37301 .54341 L .37059 .54347 L F
.79 .495 .488 r
.38049 .67473 m .38312 .67828 L .38267 .67561 L F
.24 0 .135 r
.38312 .67828 m .38645 .67516 L .38267 .67561 L F
.596 .898 .987 r
.35314 .67208 m .34917 .67244 L .35171 .67194 L F
.635 .947 .949 r
.35386 .67058 m .35553 .67085 L .35314 .67208 L F
.658 .965 .921 r
.35386 .67058 m .35314 .67208 L .35171 .67194 L F
.485 .395 .679 r
.4006 .57777 m .39848 .57673 L .40091 .57511 L F
.758 .464 .486 r
.21655 .57494 m .21321 .57476 L .21453 .57204 L F
.219 .447 .867 r
.24739 .61845 m .24682 .62044 L .24542 .61861 L F
.24739 .61845 m .24941 .62155 L .24682 .62044 L F
.643 .359 .473 r
.32268 .59696 m .32621 .59941 L .32369 .60037 L F
.32268 .59696 m .32724 .59724 L .32621 .59941 L F
.87 .514 .016 r
.32268 .59696 m .32278 .59868 L .32295 .59635 L F
.722 .989 .86 r
.31477 .53643 m .31413 .53817 L .31635 .53771 L F
.562 .564 .813 r
.31413 .53817 m .31758 .54021 L .31635 .53771 L F
.351 0 .036 r
.36997 .58469 m .36855 .58672 L .36587 .58704 L F
.056 0 0 r
.37073 .58575 m .36997 .58469 L .37295 .58413 L F
.37073 .58575 m .36855 .58672 L .36997 .58469 L F
0 0 0 r
.36997 .58469 m .37333 .58146 L .37295 .58413 L F
.424 .312 .621 r
.1851 .57784 m .18679 .57454 L .1852 .57523 L F
.944 .754 .616 r
.36423 .52636 m .36244 .52703 L .36476 .52796 L F
.76 .677 .771 r
.36423 .52636 m .36476 .52796 L .36662 .52498 L F
.428 .174 .425 r
.19783 .55966 m .20007 .55916 L .2008 .55647 L F
.245 .011 .346 r
.2008 .55647 m .20202 .55814 L .20281 .55602 L F
.2008 .55647 m .20007 .55916 L .20202 .55814 L F
.13 0 .141 r
.34609 .58143 m .34562 .58361 L .3436 .58446 L F
.002 0 .063 r
.34937 .57783 m .34777 .58081 L .34609 .58143 L F
.017 0 .106 r
.34777 .58081 m .34562 .58361 L .34609 .58143 L F
.595 .423 .619 r
.35899 .62526 m .36185 .6274 L .36238 .62484 L F
.629 .409 .564 r
.36185 .6274 m .36385 .62455 L .36238 .62484 L F
.287 .53 .91 r
.22806 .62215 m .2291 .62062 L .22733 .62089 L F
.22806 .62215 m .22942 .62214 L .2291 .62062 L F
.345 .043 .301 r
.26624 .54378 m .26783 .54576 L .26844 .54303 L F
.26624 .54378 m .26542 .54694 L .26783 .54576 L F
.607 .302 .426 r
.3149 .53353 m .31749 .53348 L .31655 .5349 L F
.016 .141 .652 r
.35221 .51518 m .354 .51862 L .35351 .51675 L F
.35221 .51518 m .3527 .51555 L .35093 .51523 L F
.728 .626 .744 r
.35351 .51675 m .35521 .51545 L .3527 .51555 L F
0 0 0 r
.35401 .51543 m .35339 .51596 L .3527 .51555 L F
.016 .141 .652 r
.35233 .51533 m .35351 .51675 L .3527 .51555 L F
0 0 0 r
.35339 .51596 m .35197 .51716 L .3527 .51555 L F
.016 .141 .652 r
.35221 .51518 m .35233 .51533 L .3527 .51555 L F
.331 .788 .65 r
.2949 .64902 m .29804 .64748 L .2987 .65039 L F
.489 .89 .944 r
.28263 .54484 m .28208 .5464 L .28316 .54365 L F
.235 0 .133 r
.28457 .54353 m .2823 .54559 L .28263 .54484 L F
.2823 .54559 m .28207 .54579 L .28263 .54484 L F
.489 .89 .944 r
.28263 .54484 m .28316 .54365 L .28362 .5425 L F
.255 0 .022 r
.30739 .63314 m .30806 .63167 L .31127 .63019 L F
.768 .583 .648 r
.31973 .58115 m .32534 .58347 L .32195 .5813 L F
.31973 .58115 m .32003 .58385 L .32534 .58347 L F
.501 .465 .749 r
.32003 .58385 m .32342 .58666 L .32534 .58347 L F
0 .197 .724 r
.32534 .58347 m .32618 .58367 L .32503 .58103 L F
.424 .082 .279 r
.32534 .58347 m .32631 .58592 L .32618 .58367 L F
.32534 .58347 m .32342 .58666 L .32631 .58592 L F
0 .117 .583 r
.25782 .62354 m .25743 .62335 L .2553 .622 L F
.25782 .62354 m .25982 .62519 L .25743 .62335 L F
.82 .722 .756 r
.33388 .54456 m .33226 .54724 L .33056 .54358 L F
.343 .131 .441 r
.33457 .54627 m .33226 .54724 L .33388 .54456 L F
.358 .428 .797 r
.39901 .58393 m .39849 .58706 L .39865 .5845 L F
.357 .427 .797 r
.39984 .58284 m .39957 .58451 L .39888 .58539 L F
.39957 .58451 m .39923 .58663 L .39906 .58602 L F
.39957 .58451 m .39906 .58602 L .39888 .58539 L F
.39986 .58323 m .40054 .58585 L .39923 .58663 L F
.557 .72 .95 r
.40054 .58585 m .39995 .58357 L .39995 .58357 L F
.40054 .58585 m .39995 .58357 L .40294 .58272 L F
.39988 .58358 m .39977 .58176 L .40294 .58272 L F
.357 .427 .797 r
.40003 .58232 m .40054 .58585 L .39986 .58323 L F
.557 .72 .95 r
.40054 .58585 m .40294 .58272 L .40003 .58232 L F
.509 .327 .569 r
.40294 .58272 m .40054 .58585 L .40003 .58232 L F
.557 .72 .95 r
.40054 .58585 m .40181 .58349 L .4003 .58236 L F
.39984 .58284 m .39932 .58162 L .39977 .58176 L F
.357 .427 .797 r
.39986 .58323 m .39923 .58663 L .39984 .58284 L F
.358 .428 .797 r
.3998 .58302 m .40054 .58585 L .39922 .58662 L F
.39883 .586 m .39922 .58662 L .39849 .58706 L F
.535 .652 .91 r
.3988 .58636 m .39923 .58663 L .39888 .58539 L F
.358 .428 .797 r
.3998 .58302 m .39922 .58662 L .39883 .586 L F
.39883 .586 m .39849 .58706 L .39901 .58393 L F
.535 .652 .91 r
.394 .58335 m .3988 .58636 L .39871 .58581 L F
.39713 .5833 m .39871 .58581 L .3983 .58328 L F
.394 .58335 m .39871 .58581 L .39713 .5833 L F
.557 .72 .95 r
.39988 .58358 m .39977 .5832 L .39984 .58284 L F
.358 .428 .797 r
.39989 .58254 m .39888 .58539 L .39901 .58393 L F
.216 .473 .887 r
.3983 .58328 m .39928 .58273 L .39865 .5845 L F
.39928 .58273 m .39981 .58244 L .3993 .58335 L F
.39928 .58273 m .3993 .58335 L .39865 .5845 L F
.39981 .58244 m .39989 .58254 L .39865 .5845 L F
.357 .427 .797 r
.39981 .58244 m .39888 .58539 L .3983 .58328 L F
.535 .652 .91 r
.3988 .58636 m .39888 .58539 L .3983 .58328 L F
.394 .58335 m .39697 .58803 L .39923 .58663 L F
.802 .639 .68 r
.39647 .58106 m .394 .58335 L .3983 .58328 L F
.786 .668 .733 r
.3962 .58292 m .39751 .58594 L .3929 .58538 L F
.922 .97 .68 r
.39932 .58162 m .39751 .58594 L .3962 .58292 L F
.39925 .58177 m .39658 .58397 L .39751 .58594 L F
.39932 .58162 m .39925 .58168 L .39925 .58177 L F
.39925 .58168 m .39658 .58397 L .39925 .58177 L F
.216 .473 .887 r
.39981 .58244 m .40003 .58232 L .39989 .58254 L F
.557 .72 .95 r
.39977 .5832 m .39941 .58195 L .39984 .58284 L F
.39941 .58195 m .39932 .58162 L .3995 .58207 L F
.39941 .58195 m .3995 .58207 L .39984 .58284 L F
.358 .428 .797 r
.40003 .58232 m .39984 .58284 L .39989 .58254 L F
.357 .427 .797 r
.40003 .58232 m .39984 .58284 L .39981 .58244 L F
.358 .428 .797 r
.39984 .58284 m .39888 .58539 L .39989 .58254 L F
.357 .427 .797 r
.39984 .58284 m .39888 .58539 L .39981 .58244 L F
.40003 .58232 m .39986 .58323 L .39984 .58284 L F
.358 .428 .797 r
.40003 .58232 m .39954 .58382 L .39888 .58539 L F
.39954 .58382 m .39883 .586 L .39886 .58569 L F
.39954 .58382 m .39886 .58569 L .39888 .58539 L F
.557 .72 .95 r
.39988 .58358 m .4003 .58236 L .40012 .58223 L F
.39977 .5832 m .40012 .58223 L .39932 .58162 L F
.358 .428 .797 r
.40003 .58232 m .40054 .58585 L .3998 .58302 L F
.557 .72 .95 r
.39988 .58358 m .40012 .58223 L .39977 .5832 L F
.40054 .58585 m .39988 .58358 L .39995 .58357 L F
.40054 .58585 m .4003 .58236 L .39988 .58358 L F
.409 .307 .628 r
.39922 .58666 m .40054 .58585 L .39923 .58663 L F
.301 .177 .538 r
.4009 .5888 m .39853 .58709 L .3992 .58668 L F
.454 0 0 r
.39919 .58665 m .39922 .58666 L .39923 .58663 L F
.301 .177 .538 r
.40069 .58706 m .39918 .58665 L .40054 .58585 L F
.4009 .5888 m .39918 .58665 L .40069 .58706 L F
.4009 .5888 m .39873 .5909 L .39849 .58706 L F
.409 .307 .628 r
.39886 .58907 m .40054 .58585 L .39922 .58666 L F
.301 .177 .538 r
.3992 .58668 m .39849 .58706 L .39918 .58665 L F
.39853 .58709 m .39849 .58706 L .3992 .58668 L F
.454 0 0 r
.39697 .58803 m .39886 .58907 L .39922 .58666 L F
.39697 .58803 m .39922 .58666 L .39919 .58665 L F
.39697 .58803 m .39419 .58892 L .39886 .58907 L F
.248 0 .269 r
.28499 .54526 m .28725 .54272 L .28612 .54402 L F
.171 .052 .465 r
.33781 .62332 m .33834 .62206 L .33603 .62272 L F
.631 .439 .604 r
.37784 .62511 m .37558 .62808 L .37562 .6254 L F
.829 .799 .823 r
.36375 .55149 m .36141 .55484 L .36698 .55451 L F
.36706 .55443 m .36698 .55451 L .36715 .5545 L F
.36375 .55149 m .36698 .55451 L .36706 .55443 L F
.458 .337 .627 r
.36741 .5541 m .3674 .55409 L .36932 .55311 L F
.36736 .55411 m .36768 .55376 L .36932 .55311 L F
0 .046 .608 r
.3676 .5543 m .36776 .55279 L .36622 .55125 L F
.36762 .55434 m .36762 .55432 L .3676 .5543 L F
.36762 .55432 m .36776 .55279 L .3676 .5543 L F
.458 .337 .627 r
.36902 .55394 m .36741 .5541 L .36932 .55311 L F
.36741 .5541 m .36736 .55411 L .3674 .55409 L F
.36736 .55411 m .36662 .55419 L .36768 .55376 L F
0 .338 .805 r
.24389 .61696 m .24246 .61682 L .24194 .61504 L F
.24389 .61696 m .24542 .61861 L .24246 .61682 L F
.17 .231 .685 r
.30148 .56047 m .30212 .56512 L .30097 .56562 L F
.136 .145 .604 r
.30212 .56512 m .30268 .56782 L .30097 .56562 L F
.284 .184 .562 r
.30268 .56782 m .30113 .56899 L .30097 .56562 L F
.894 .983 .802 r
.31383 .57098 m .3111 .57456 L .31254 .57324 L F
0 0 0 r
.28712 .53717 m .28441 .53964 L .2846 .53762 L F
.38734 .64012 m .38626 .64235 L .38518 .64341 L F
.38626 .64235 m .38418 .64559 L .38518 .64341 L F
.566 .327 .513 r
.27577 .55613 m .27802 .55866 L .27841 .55637 L F
.27577 .55613 m .27545 .55937 L .27802 .55866 L F
0 .036 .549 r
.32831 .64297 m .32664 .64125 L .32779 .64013 L F
.32831 .64297 m .32716 .64394 L .32664 .64125 L F
0 0 0 r
.27773 .61536 m .27581 .61635 L .27476 .61745 L F
.568 .725 .948 r
.31948 .5216 m .32161 .52244 L .31647 .52115 L F
.224 .322 .754 r
.32116 .51773 m .32161 .52244 L .31948 .5216 L F
.32116 .51773 m .32272 .5227 L .32161 .52244 L F
.759 .984 .906 r
.32272 .5227 m .32019 .52454 L .32161 .52244 L F
.084 0 0 r
.22699 .53798 m .22797 .53734 L .22793 .53724 L F
.42 .845 .697 r
.2286 .53697 m .22793 .53724 L .22994 .53606 L F
.084 0 0 r
.22797 .53734 m .22994 .53606 L .22793 .53724 L F
.123 0 0 r
.22787 .53705 m .22793 .53724 L .2286 .53697 L F
.22542 .53733 m .22793 .53724 L .22787 .53705 L F
.511 .779 .993 r
.36909 .51286 m .3678 .5147 L .36601 .51219 L F
.36909 .51286 m .37003 .51423 L .3678 .5147 L F
.463 .25 .504 r
.37432 .55195 m .37206 .55011 L .37582 .54989 L F
.587 .196 .27 r
.37842 .54991 m .37432 .55195 L .37582 .54989 L F
.5 .241 .454 r
.37216 .59644 m .37482 .59383 L .37253 .59426 L F
.476 .212 .433 r
.25951 .54178 m .25907 .54409 L .25707 .54234 L F
.25951 .54178 m .25907 .54409 L .25707 .54234 L F
.56 .574 .825 r
.25907 .54409 m .25942 .54214 L .25951 .54178 L F
0 0 0 r
.25951 .54178 m .25918 .54132 L .25967 .54118 L F
.456 .734 .987 r
.25956 .53647 m .26227 .53643 L .26028 .53467 L F
.25956 .53647 m .26227 .53643 L .26028 .53467 L F
.587 .416 .618 r
.2577 .5378 m .25939 .53944 L .26028 .53467 L F
0 .056 .568 r
.2577 .5378 m .25983 .5398 L .25939 .53944 L F
0 .194 .719 r
.2577 .5378 m .25951 .54178 L .25983 .5398 L F
.56 .574 .825 r
.25942 .54214 m .25983 .5398 L .25951 .54178 L F
0 0 0 r
.25951 .54178 m .25967 .54118 L .26149 .54063 L F
.25951 .54178 m .25707 .54234 L .25918 .54132 L F
.455 .007 .095 r
.24572 .54585 m .25 .54386 L .24597 .54323 L F
.24572 .54585 m .24809 .54597 L .25 .54386 L F
.53 .802 .996 r
.25 .54386 m .25285 .54349 L .25234 .54309 L F
.547 .109 .16 r
.25 .54386 m .24809 .54597 L .25277 .54452 L F
.19 .074 .481 r
.25285 .54349 m .25379 .54374 L .253 .54374 L F
.487 .505 .801 r
.25 .54386 m .25379 .54374 L .25285 .54349 L F
.416 .865 .842 r
.24724 .53129 m .24259 .53253 L .24492 .53185 L F
.238 .753 .766 r
.24712 .53107 m .24724 .53129 L .24492 .53185 L F
.24712 .53107 m .24956 .53069 L .24724 .53129 L F
.661 .572 .744 r
.37334 .52427 m .37427 .52862 L .37687 .52793 L F
.586 .856 .995 r
.36264 .54283 m .3604 .54375 L .36428 .54386 L F
0 .094 .624 r
.36428 .54386 m .36505 .54191 L .36264 .54283 L F
.116 .625 .896 r
.36809 .54461 m .36573 .54379 L .36428 .54386 L F
.36573 .54379 m .36538 .54367 L .36508 .54372 L F
.36573 .54379 m .36508 .54372 L .36428 .54386 L F
.985 .823 .602 r
.36809 .54461 m .36428 .54386 L .36538 .54367 L F
.36809 .54461 m .36598 .54492 L .36428 .54386 L F
.515 .187 .349 r
.36598 .54492 m .36853 .54463 L .36868 .54411 L F
.3673 .54396 m .36868 .54411 L .36907 .54267 L F
.36598 .54492 m .36868 .54411 L .3673 .54396 L F
0 .094 .624 r
.36428 .54386 m .36598 .54492 L .36505 .54191 L F
.732 .674 .793 r
.38053 .62177 m .38208 .62535 L .37784 .62511 L F
.526 .34 .571 r
.38096 .62763 m .37784 .62511 L .38208 .62535 L F
.076 .275 .762 r
.38053 .62177 m .38296 .62385 L .38208 .62535 L F
0 0 0 r
.38279 .62646 m .38208 .62535 L .38296 .62385 L F
.38279 .62646 m .38096 .62763 L .38208 .62535 L F
.28328 .62018 m .28279 .61902 L .28496 .61837 L F
.28328 .62018 m .28147 .62119 L .28279 .61902 L F
.408 .384 .721 r
.3465 .62413 m .34818 .62503 L .34957 .62231 L F
.665 .696 .869 r
.34626 .62432 m .34957 .62231 L .3465 .62413 L F
0 0 0 r
.30392 .59105 m .30265 .59207 L .30355 .59144 L F
.841 .834 .362 r
.30392 .59105 m .3036 .59407 L .30459 .59037 L F
.30392 .59105 m .30459 .59037 L .30466 .5901 L F
.30392 .59105 m .30466 .5901 L .30425 .58947 L F
.695 .373 .428 r
.30425 .58947 m .30586 .59214 L .30392 .59105 L F
.30425 .58947 m .30586 .59214 L .30392 .59105 L F
0 .415 .852 r
.30392 .59105 m .30586 .59214 L .30459 .59071 L F
0 0 0 r
.30392 .59105 m .30355 .59144 L .30459 .59071 L F
0 0 .089 r
.30539 .5935 m .3036 .59407 L .30392 .59105 L F
.30539 .5935 m .30288 .59645 L .3036 .59407 L F
0 0 .018 r
.20603 .55257 m .20653 .55412 L .20763 .55245 L F
.20603 .55257 m .20483 .55516 L .20653 .55412 L F
.11 0 0 r
.27862 .63018 m .27817 .62901 L .27615 .63028 L F
.105 .658 .796 r
.27681 .63001 m .27862 .63018 L .27615 .63028 L F
.575 0 0 r
.27891 .63095 m .27862 .63018 L .27681 .63001 L F
.683 .456 .572 r
.28004 .63315 m .28295 .63037 L .28019 .63021 L F
0 0 .123 r
.28046 .63165 m .28004 .63315 L .28019 .63021 L F
.575 0 0 r
.28046 .63165 m .27862 .63018 L .27891 .63095 L F
.11 0 0 r
.27862 .63018 m .27846 .62883 L .27817 .62901 L F
.27862 .63018 m .28075 .62814 L .27846 .62883 L F
.712 .569 .691 r
.27841 .55637 m .28215 .55673 L .28195 .55278 L F
.427 .284 .583 r
.28195 .55278 m .28362 .55256 L .28361 .5498 L F
.598 .48 .689 r
.28195 .55278 m .28215 .55673 L .28466 .55598 L F
.282 0 0 r
.25242 .63341 m .24776 .63178 L .25031 .63331 L F
.365 0 0 r
.31484 .64523 m .31427 .64428 L .31207 .64556 L F
.794 .502 .495 r
.31814 .6472 m .31427 .64428 L .31664 .64489 L F
.365 0 0 r
.31484 .64523 m .31664 .64489 L .31427 .64428 L F
.118 .172 .643 r
.32112 .59024 m .32283 .5894 L .32099 .58748 L F
.101 .021 .47 r
.32112 .59024 m .32307 .59211 L .32283 .5894 L F
.32112 .59024 m .32189 .59276 L .32307 .59211 L F
.262 0 .113 r
.33226 .54724 m .33136 .54904 L .32916 .54958 L F
.667 .285 .311 r
.33226 .54724 m .33446 .54929 L .33136 .54904 L F
.429 .316 .623 r
.33457 .54627 m .33446 .54929 L .33226 .54724 L F
.33457 .54627 m .33446 .54929 L .33226 .54724 L F
.358 .677 .977 r
.19635 .60113 m .20144 .60311 L .19838 .60065 L F
.206 .485 .896 r
.20144 .60311 m .2021 .60069 L .19838 .60065 L F
.20144 .60311 m .20252 .60293 L .2021 .60069 L F
.802 .591 .616 r
.34888 .69678 m .34641 .69366 L .34887 .69414 L F
.957 .793 .638 r
.35515 .57273 m .35362 .57531 L .35331 .57228 L F
.35331 .57228 m .35362 .57531 L .35515 .57273 L F
.68 .486 .616 r
.37193 .55263 m .36826 .54997 L .37206 .55011 L F
.463 .25 .504 r
.37432 .55195 m .37193 .55263 L .37206 .55011 L F
.401 .125 .377 r
.3799 .55624 m .38221 .55563 L .38274 .55342 L F
.285 .025 .333 r
.38274 .55342 m .38221 .55563 L .38487 .55235 L F
.431 .043 .201 r
.33255 .6261 m .33781 .62332 L .33324 .62546 L F
.33255 .6261 m .33444 .62661 L .33781 .62332 L F
.171 .052 .465 r
.33781 .62332 m .33845 .62437 L .33834 .62206 L F
.85 .797 .799 r
.33444 .62661 m .33845 .62437 L .33781 .62332 L F
.511 .312 .547 r
.35951 .58145 m .36186 .58351 L .36221 .58115 L F
.35951 .58145 m .35934 .5841 L .36186 .58351 L F
0 0 0 r
.31461 .65021 m .31814 .6472 L .31716 .64817 L F
.173 0 0 r
.31461 .65021 m .31716 .64817 L .31686 .64978 L F
0 0 0 r
.31871 .64845 m .31716 .64817 L .31814 .6472 L F
.31686 .64978 m .31716 .64817 L .31871 .64845 L F
0 .489 .789 r
.36576 .53591 m .3677 .5364 L .36783 .53662 L F
0 0 0 r
.3677 .5364 m .37228 .5353 L .36783 .53662 L F
.87 .834 .808 r
.33859 .54682 m .33653 .55027 L .33446 .54929 L F
.917 .787 .703 r
.33653 .55027 m .33534 .55176 L .33446 .54929 L F
.259 0 0 r
.28248 .64536 m .28478 .64494 L .287 .64551 L F
.104 0 .263 r
.19783 .55966 m .19888 .56093 L .20007 .55916 L F
.19783 .55966 m .1973 .56193 L .19888 .56093 L F
.276 0 .256 r
.31748 .54796 m .31574 .54721 L .31944 .54677 L F
.156 .695 .718 r
.32214 .54709 m .31748 .54796 L .31944 .54677 L F
0 .497 .8 r
.29762 .55356 m .29619 .55292 L .29366 .55232 L F
.15 .413 .856 r
.29762 .55356 m .29806 .55144 L .29619 .55292 L F
.434 0 0 r
.30129 .55362 m .29983 .55434 L .29762 .55356 L F
.15 .413 .856 r
.29762 .55356 m .29983 .55434 L .29806 .55144 L F
.336 .142 .463 r
.32723 .5743 m .32557 .57395 L .3283 .57284 L F
.377 .423 .782 r
.32963 .57103 m .3283 .57284 L .3264 .56742 L F
.188 0 0 r
.32976 .57247 m .3283 .57284 L .32963 .57103 L F
.727 .318 .273 r
.27293 .55953 m .27558 .56182 L .27545 .55937 L F
.576 .393 .597 r
.27558 .56182 m .27389 .56274 L .27293 .55953 L F
.727 .318 .273 r
.27293 .55953 m .2717 .56148 L .27558 .56182 L F
.576 .393 .597 r
.27558 .56182 m .27293 .55953 L .27545 .55937 L F
.434 0 0 r
.29632 .54746 m .29462 .54898 L .29823 .54869 L F
.501 .439 .719 r
.33678 .60234 m .33752 .60598 L .33537 .6065 L F
.766 .531 .578 r
.33752 .60598 m .33378 .60835 L .33537 .6065 L F
0 0 0 r
.30245 .5536 m .30129 .55362 L .30398 .55306 L F
.30245 .5536 m .29983 .55434 L .30129 .55362 L F
.41 0 0 r
.31107 .62709 m .31015 .62553 L .30855 .62748 L F
.31107 .62709 m .3128 .62592 L .31015 .62553 L F
.121 0 0 r
.2763 .54663 m .27508 .54797 L .27281 .54857 L F
.179 0 0 r
.27824 .54642 m .27508 .54797 L .2763 .54663 L F
.299 .132 .48 r
.28717 .59704 m .28935 .59844 L .28919 .59601 L F
.28717 .59704 m .28655 .59995 L .28935 .59844 L F
.595 .423 .619 r
.35899 .62526 m .35917 .62824 L .36185 .6274 L F
.559 .86 .997 r
.28439 .52537 m .28206 .52615 L .27987 .52518 L F
.255 .315 .733 r
.30579 .58421 m .30457 .58445 L .30372 .58206 L F
.263 0 .05 r
.30493 .5864 m .30457 .58445 L .30579 .58421 L F
.30493 .5864 m .30296 .58687 L .30457 .58445 L F
.782 .934 .575 r
.3283 .54388 m .32681 .54544 L .32882 .54217 L F
.449 .734 .988 r
.32882 .54217 m .33056 .54358 L .3283 .54388 L F
.461 .238 .487 r
.36902 .55394 m .36616 .55855 L .36659 .55548 L F
.533 .214 .373 r
.38386 .67133 m .38186 .66965 L .38435 .66893 L F
.38386 .67133 m .38122 .67167 L .38186 .66965 L F
0 .137 .684 r
.34187 .62978 m .34202 .63118 L .34295 .63183 L F
.999 .835 .507 r
.34202 .63118 m .34496 .63466 L .34295 .63183 L F
.148 0 .149 r
.19545 .56284 m .19448 .56486 L .1973 .56193 L F
.733 .533 .622 r
.34304 .61872 m .3475 .61888 L .34727 .61589 L F
.194 .289 .735 r
.34622 .61235 m .34727 .61589 L .34857 .61424 L F
.583 .577 .812 r
.3475 .61888 m .34857 .61424 L .34727 .61589 L F
.322 .805 .884 r
.28439 .52537 m .2867 .52484 L .28823 .52494 L F
.161 .696 .707 r
.2867 .52484 m .29077 .52399 L .28823 .52494 L F
0 .465 .815 r
.37334 .52427 m .37164 .52335 L .3688 .52257 L F
.426 0 0 r
.37164 .52335 m .3675 .52368 L .3688 .52257 L F
.357 .759 .984 r
.22727 .61195 m .23147 .61271 L .22913 .61324 L F
.634 .422 .577 r
.35368 .60122 m .35659 .59682 L .35278 .59707 L F
.733 .687 .144 r
.35659 .59682 m .35632 .59778 L .35584 .59875 L F
.337 .187 .524 r
.31585 .61885 m .31627 .62012 L .31689 .61559 L F
.04 0 .392 r
.31689 .61559 m .3187 .6171 L .31884 .6144 L F
.365 .222 .55 r
.28934 .5937 m .29191 .59321 L .29226 .58954 L F
.063 0 .184 r
.28919 .59601 m .29191 .59321 L .28934 .5937 L F
.473 .412 .708 r
.38223 .60175 m .38266 .60286 L .38059 .6055 L F
.492 .299 .547 r
.38318 .60775 m .38454 .60772 L .38553 .60513 L F
.347 .112 .409 r
.38335 .60756 m .38353 .60756 L .38318 .60775 L F
.718 .542 .651 r
.38553 .60513 m .38454 .60772 L .38434 .6072 L F
.347 .112 .409 r
.38553 .60513 m .38523 .60688 L .38434 .6072 L F
.38553 .60513 m .38434 .6072 L .38335 .60756 L F
.718 .542 .651 r
.38553 .60513 m .38434 .6072 L .38223 .60175 L F
0 0 .427 r
.38313 .60762 m .38265 .60978 L .3824 .60572 L F
.38318 .60775 m .3824 .60572 L .38059 .6055 L F
.503 .4 .671 r
.38059 .6055 m .3839 .60736 L .38318 .60775 L F
.3839 .60736 m .38454 .60772 L .38318 .60775 L F
.347 .112 .409 r
.38353 .60756 m .38511 .60762 L .38318 .60775 L F
.473 .412 .708 r
.38434 .6072 m .38454 .60772 L .3839 .60736 L F
.347 .112 .409 r
.38523 .60688 m .38511 .60762 L .38335 .60756 L F
.473 .412 .708 r
.38266 .60286 m .38434 .6072 L .38306 .60689 L F
.38434 .6072 m .3839 .60736 L .38306 .60689 L F
.38266 .60286 m .38306 .60689 L .38059 .6055 L F
0 0 .427 r
.38318 .60775 m .38315 .60786 L .38313 .60762 L F
.38315 .60786 m .38265 .60978 L .38313 .60762 L F
.761 .743 .222 r
.38266 .60906 m .38265 .60978 L .38318 .60775 L F
.38266 .60906 m .3821 .61213 L .38265 .60978 L F
.724 .518 .611 r
.32378 .608 m .32758 .60569 L .32681 .60516 L F
.255 0 .022 r
.30739 .63314 m .31127 .63019 L .3097 .63329 L F
0 0 0 r
.31127 .63019 m .31406 .62865 L .31249 .63106 L F
.309 0 .096 r
.31127 .63019 m .31204 .6324 L .3097 .63329 L F
.31127 .63019 m .31249 .63106 L .31204 .6324 L F
.714 .599 .727 r
.40318 .57267 m .40363 .57562 L .40091 .57511 L F
.719 .397 .432 r
.40363 .57562 m .4031 .57752 L .40091 .57511 L F
.513 .457 .731 r
.40651 .57466 m .40363 .57562 L .40318 .57267 L F
.368 .064 .311 r
.40582 .57658 m .40363 .57562 L .40651 .57466 L F
.40582 .57658 m .4031 .57752 L .40363 .57562 L F
.255 .315 .733 r
.30579 .58421 m .30372 .58206 L .30617 .58075 L F
.703 .465 .561 r
.36247 .70314 m .35855 .70051 L .36258 .70051 L F
.728 .479 .55 r
.36625 .70302 m .36247 .70314 L .36258 .70051 L F
.336 .142 .463 r
.32723 .5743 m .32524 .5751 L .32557 .57395 L F
.517 .782 .993 r
.3671 .57227 m .36977 .57204 L .368 .57056 L F
.493 0 0 r
.25493 .55229 m .25361 .55276 L .25115 .55224 L F
0 0 0 r
.2572 .55159 m .25493 .55229 L .25782 .55117 L F
.231 .233 .654 r
.31618 .56221 m .317 .5579 L .31518 .56046 L F
.499 .111 .235 r
.31613 .62965 m .31249 .63106 L .31406 .62865 L F
.309 .083 .399 r
.33341 .55539 m .33534 .55176 L .33357 .55319 L F
.24 0 .135 r
.38312 .67828 m .38518 .67779 L .38645 .67516 L F
.217 0 .124 r
.38645 .67516 m .38518 .67779 L .38738 .67691 L F
0 0 0 r
.36 .66224 m .36345 .6597 L .36197 .6617 L F
.085 0 0 r
.36197 .6617 m .36345 .6597 L .36544 .65898 L F
.503 .4 .67 r
.37897 .58133 m .38183 .58278 L .38098 .581 L F
.37897 .58133 m .37929 .58327 L .38183 .58278 L F
0 .214 .737 r
.37874 .67236 m .3811 .67434 L .38049 .67473 L F
0 .123 .673 r
.3811 .67434 m .38312 .67828 L .38049 .67473 L F
.501 .805 .999 r
.26235 .52676 m .26281 .52884 L .26087 .52744 L F
.26235 .52676 m .26531 .5283 L .26281 .52884 L F
.489 .331 .592 r
.38404 .59337 m .38407 .59715 L .38174 .59406 L F
.38174 .59406 m .38407 .59715 L .38404 .59337 L F
.38404 .59337 m .38407 .59715 L .38174 .59406 L F
.81 .535 .523 r
.33901 .68481 m .3348 .68645 L .33488 .68427 L F
.33901 .68481 m .33891 .68755 L .3348 .68645 L F
.747 .48 .527 r
.34308 .68762 m .33891 .68755 L .33901 .68481 L F
.675 .964 .753 r
.29937 .54221 m .29628 .5449 L .29891 .5434 L F
0 .544 .739 r
.30204 .54372 m .30111 .5436 L .29891 .5434 L F
.009 .317 .805 r
.20528 .60619 m .20542 .60457 L .20252 .60293 L F
.20528 .60619 m .20608 .6061 L .20542 .60457 L F
.649 .902 .982 r
.37838 .66181 m .37743 .66358 L .37608 .66291 L F
.37838 .66181 m .3799 .66261 L .37743 .66358 L F
.591 .925 .964 r
.27814 .65001 m .27966 .65035 L .28033 .64895 L F
.27814 .65001 m .27966 .65035 L .28033 .64895 L F
.615 .77 .955 r
.23146 .63057 m .23335 .63236 L .23584 .63142 L F
0 0 0 r
.35797 .53016 m .35853 .53013 L .36053 .52682 L F
0 0 .052 r
.35797 .53016 m .35835 .53055 L .35853 .53013 L F
.35797 .53016 m .35738 .53356 L .35835 .53055 L F
.247 0 .049 r
.27679 .62242 m .27576 .62455 L .27329 .62506 L F
0 0 0 r
.27691 .62313 m .27716 .62238 L .27919 .62214 L F
.569 .937 .823 r
.27988 .62142 m .27811 .62187 L .27691 .62313 L F
.169 .025 .429 r
.27811 .62187 m .2768 .62345 L .27691 .62313 L F
.2768 .62345 m .27497 .62565 L .27691 .62313 L F
0 0 0 r
.27691 .62313 m .27679 .62242 L .27716 .62238 L F
.27691 .62313 m .27576 .62455 L .27679 .62242 L F
.789 .624 .676 r
.31304 .65629 m .31437 .65955 L .3109 .65901 L F
.674 .195 .106 r
.3109 .65901 m .31437 .65955 L .31261 .66005 L F
.625 .64 .846 r
.3153 .65574 m .31437 .65955 L .31304 .65629 L F
.3153 .65574 m .31719 .65905 L .31437 .65955 L F
.217 0 0 r
.31437 .65955 m .31544 .66048 L .31261 .66005 L F
.31437 .65955 m .31719 .65905 L .31544 .66048 L F
.276 0 .256 r
.31748 .54796 m .31518 .54898 L .31574 .54721 L F
.5 .241 .454 r
.37216 .59644 m .37446 .59604 L .37482 .59383 L F
0 0 0 r
.37482 .59383 m .37605 .59243 L .37713 .59033 L F
.502 .475 .759 r
.37446 .59604 m .37605 .59243 L .37482 .59383 L F
0 .092 .65 r
.23115 .62558 m .23153 .62454 L .22942 .62214 L F
.589 .193 .26 r
.3436 .58446 m .34244 .58573 L .34037 .58436 L F
.047 0 0 r
.3412 .58475 m .34037 .58436 L .34244 .58573 L F
.3412 .58475 m .3382 .58543 L .34037 .58436 L F
.31 .71 .978 r
.21051 .61144 m .2108 .61043 L .20789 .61034 L F
.21051 .61144 m .21252 .61157 L .2108 .61043 L F
.644 .834 .973 r
.23027 .78497 m .23397 .78514 L .23234 .7837 L F
.23027 .78497 m .23397 .78514 L .23234 .7837 L F
.288 .657 .97 r
.23234 .7837 m .23397 .78514 L .23449 .78396 L F
.23234 .7837 m .23397 .78514 L .23449 .78396 L F
.486 .19 .389 r
.31973 .58115 m .32195 .5813 L .3231 .57851 L F
.469 .501 .809 r
.32153 .57411 m .3231 .57851 L .3248 .57742 L F
.564 .374 .583 r
.32195 .5813 m .3248 .57742 L .3231 .57851 L F
.048 0 0 r
.37639 .54278 m .37981 .54084 L .37682 .54278 L F
.37639 .54278 m .37804 .54229 L .37981 .54084 L F
.446 .03 .156 r
.37804 .54229 m .38225 .54029 L .37981 .54084 L F
.525 .37 .613 r
.37981 .54084 m .38225 .54029 L .3821 .53731 L F
.654 .228 0 r
.31854 .64818 m .31814 .6472 L .31664 .64489 L F
0 0 0 r
.31871 .64845 m .31814 .6472 L .31854 .64818 L F
.658 .511 .672 r
.31814 .6472 m .32153 .64703 L .32074 .644 L F
.736 .582 .683 r
.39198 .67014 m .38811 .6717 L .3906 .67141 L F
.417 .53 .864 r
.39452 .6719 m .39198 .67014 L .39419 .66893 L F
0 0 0 r
.3906 .67141 m .39419 .66893 L .39198 .67014 L F
.711 .59 .719 r
.38004 .57193 m .38439 .57213 L .38214 .57185 L F
.64 .41 .554 r
.38439 .57213 m .38384 .57547 L .38214 .57185 L F
.38439 .57213 m .38641 .57459 L .38384 .57547 L F
.649 .557 .737 r
.33377 .5716 m .33593 .56871 L .33365 .56888 L F
.615 .403 .57 r
.40091 .57511 m .4031 .57752 L .4006 .57777 L F
.015 0 .08 r
.28534 .54134 m .28441 .53964 L .28621 .53883 L F
.28534 .54134 m .28362 .5425 L .28441 .53964 L F
.949 .681 .495 r
.3407 .50985 m .33915 .51093 L .33855 .5085 L F
.722 .836 .935 r
.34332 .50896 m .3407 .50985 L .33855 .5085 L F
.056 .255 .749 r
.34739 .67143 m .34657 .67281 L .34512 .66995 L F
.49 .818 1 r
.34739 .67143 m .34917 .67244 L .34657 .67281 L F
.729 .797 .906 r
.3638 .51253 m .35981 .51216 L .36227 .51111 L F
.158 .632 .927 r
.36227 .51111 m .36601 .51219 L .3638 .51253 L F
0 .571 .759 r
.23147 .61271 m .23314 .61281 L .2353 .61307 L F
0 .534 .797 r
.23314 .61281 m .23788 .61376 L .2353 .61307 L F
.567 .887 .99 r
.3606 .66846 m .3621 .66913 L .35848 .66947 L F
.26 .319 .735 r
.22247 .60503 m .22093 .60671 L .2199 .60275 L F
.273 .34 .75 r
.22247 .60503 m .22336 .60872 L .22093 .60671 L F
.363 .362 .724 r
.32165 .63993 m .32074 .644 L .32236 .64308 L F
.244 .296 .718 r
.32074 .644 m .3231 .64614 L .32236 .64308 L F
.342 .31 .677 r
.32074 .644 m .32153 .64703 L .3231 .64614 L F
.843 .554 .499 r
.34641 .69366 m .34286 .69048 L .34528 .69067 L F
0 0 0 r
.21976 .54289 m .22119 .54265 L .22317 .54107 L F
.245 0 .036 r
.22119 .54265 m .22506 .53967 L .22317 .54107 L F
.586 .09 .043 r
.26428 .55027 m .26218 .5516 L .25979 .55094 L F
.329 0 0 r
.26584 .55096 m .26428 .55027 L .26675 .54993 L F
.26584 .55096 m .26218 .5516 L .26428 .55027 L F
.432 .196 .454 r
.3799 .55624 m .3798 .55859 L .38221 .55563 L F
.935 .932 .774 r
.33516 .68154 m .33595 .6773 L .33606 .67973 L F
.584 .036 0 r
.36122 .61988 m .35753 .61889 L .36119 .61811 L F
.697 .631 .779 r
.35753 .61889 m .36122 .61988 L .36119 .61811 L F
.456 .249 .509 r
.35091 .60325 m .35368 .60122 L .35125 .60306 L F
.196 0 0 r
.18899 .56768 m .191 .56754 L .19256 .56576 L F
0 0 0 r
.19256 .56576 m .19261 .56659 L .19448 .56486 L F
.19256 .56576 m .191 .56754 L .19261 .56659 L F
.048 .24 .738 r
.37856 .56827 m .38004 .57193 L .3808 .57028 L F
.711 .59 .719 r
.38004 .57193 m .38214 .57185 L .38384 .57547 L F
.838 .727 .742 r
.38051 .57232 m .3808 .57028 L .38004 .57193 L F
.3834 .57472 m .38233 .5729 L .38051 .57232 L F
.38233 .5729 m .3808 .57028 L .38051 .57232 L F
.38351 .57481 m .3808 .57028 L .3834 .57472 L F
.711 .59 .719 r
.38004 .57193 m .38384 .57547 L .38351 .57481 L F
.373 .21 .527 r
.3816 .57366 m .38233 .5729 L .3808 .57028 L F
.886 .799 .758 r
.3808 .57028 m .3788 .57397 L .3816 .57366 L F
.838 .727 .742 r
.38054 .57346 m .3788 .57397 L .37928 .57308 L F
0 .433 .716 r
.38122 .57365 m .38198 .57388 L .3816 .57366 L F
.373 .21 .527 r
.3816 .57366 m .38198 .57388 L .38211 .57357 L F
.838 .727 .742 r
.38212 .57354 m .3788 .57397 L .38237 .57291 L F
.664 .905 .574 r
.3788 .57397 m .38122 .57365 L .3816 .57366 L F
.838 .727 .742 r
.38174 .5745 m .3788 .57397 L .38212 .57354 L F
.664 .905 .574 r
.3788 .57397 m .37855 .57362 L .38122 .57365 L F
.699 .844 .952 r
.38351 .57481 m .38034 .57527 L .3788 .57397 L F
.564 .81 .991 r
.38384 .57547 m .38034 .57527 L .38351 .57481 L F
.75 .994 .86 r
.38301 .57499 m .37898 .57788 L .38222 .57677 L F
.38305 .5749 m .38293 .57499 L .38301 .57499 L F
.38293 .57499 m .37898 .57788 L .38301 .57499 L F
0 .433 .716 r
.37855 .57362 m .38335 .575 L .38198 .57388 L F
.38335 .575 m .38456 .57535 L .38399 .57502 L F
.838 .727 .742 r
.38351 .57481 m .38174 .5745 L .38237 .57291 L F
0 .433 .716 r
.38335 .575 m .38399 .57502 L .38198 .57388 L F
.37855 .57362 m .38198 .57388 L .38122 .57365 L F
.838 .727 .742 r
.38237 .57291 m .38054 .57346 L .3808 .57028 L F
.38054 .57346 m .37928 .57308 L .3808 .57028 L F
.373 .21 .527 r
.38211 .57357 m .38456 .57535 L .38361 .57331 L F
.38198 .57388 m .38456 .57535 L .38211 .57357 L F
.38233 .5729 m .38361 .57331 L .38306 .57215 L F
.3816 .57366 m .38361 .57331 L .38233 .5729 L F
.38233 .5729 m .38306 .57215 L .3808 .57028 L F
0 0 0 r
.34937 .57237 m .34946 .57208 L .34869 .57095 L F
.34937 .57237 m .34784 .57512 L .34946 .57208 L F
.398 .147 .414 r
.30153 .57806 m .30495 .57438 L .30177 .57514 L F
.619 .828 .981 r
.35981 .51216 m .35748 .51316 L .35597 .51183 L F
.789 .624 .676 r
.31304 .65629 m .3109 .65901 L .31105 .65652 L F
.413 .414 .752 r
.3153 .65574 m .31304 .65629 L .31243 .65386 L F
.316 .338 .726 r
.31172 .53867 m .31108 .54314 L .31067 .54074 L F
.652 .67 .855 r
.35023 .57498 m .34937 .57783 L .34784 .57512 L F
.35023 .57498 m .35191 .57823 L .34937 .57783 L F
.678 .38 .461 r
.35165 .58058 m .34937 .57783 L .35191 .57823 L F
.35165 .58058 m .34777 .58081 L .34937 .57783 L F
.69 .421 .511 r
.33699 .52483 m .33417 .52453 L .33579 .52168 L F
.33699 .52483 m .33498 .52501 L .33417 .52453 L F
.252 .041 .386 r
.37445 .5704 m .37286 .56888 L .37541 .56853 L F
.37445 .5704 m .37259 .5715 L .37286 .56888 L F
.565 .354 .552 r
.25266 .75088 m .25496 .75308 L .25516 .75034 L F
.68 .486 .616 r
.37193 .55263 m .36932 .55311 L .36826 .54997 L F
.585 .859 .523 r
.33983 .54526 m .33859 .54682 L .34113 .54394 L F
.041 0 0 r
.34374 .54398 m .33983 .54526 L .34113 .54394 L F
.278 0 0 r
.36053 .52682 m .36244 .52703 L .36423 .52636 L F
0 0 .235 r
.35352 .55617 m .35467 .55716 L .35612 .55545 L F
.35352 .55617 m .35302 .55898 L .35467 .55716 L F
.513 .457 .731 r
.40651 .57466 m .40318 .57267 L .40547 .57164 L F
.656 .815 .96 r
.31647 .52115 m .31216 .52057 L .31458 .51895 L F
.582 .718 .936 r
.31717 .5179 m .31647 .52115 L .31458 .51895 L F
.31717 .5179 m .31948 .5216 L .31647 .52115 L F
.13 .165 .63 r
.28584 .60313 m .28768 .60531 L .28691 .60275 L F
.283 .201 .584 r
.28584 .60313 m .28617 .60627 L .28768 .60531 L F
.726 .209 0 r
.33021 .52084 m .3345 .52237 L .32925 .51857 L F
.87 .834 .808 r
.33859 .54682 m .33446 .54929 L .33457 .54627 L F
.758 .684 .137 r
.33983 .54526 m .33944 .54908 L .33859 .54682 L F
.456 .249 .509 r
.35091 .60325 m .3536 .60437 L .35368 .60122 L F
.619 .369 .518 r
.35002 .60481 m .35369 .60497 L .35091 .60325 L F
.045 .047 .535 r
.33983 .54526 m .33944 .54908 L .33859 .54682 L F
.903 .562 .084 r
.328 .66534 m .32883 .66601 L .32811 .66418 L F
.62 .383 .536 r
.32812 .66907 m .32883 .66601 L .32657 .66739 L F
.997 .814 .539 r
.32706 .66754 m .32883 .66601 L .32812 .66907 L F
.752 .983 .909 r
.328 .66534 m .32883 .66601 L .32657 .66739 L F
0 .033 .6 r
.32811 .66418 m .32883 .66601 L .32895 .66395 L F
.885 .964 .635 r
.32895 .66395 m .32883 .66601 L .32706 .66754 L F
.569 .054 0 r
.36141 .55484 m .36303 .55654 L .36715 .5545 L F
.528 .734 .969 r
.36715 .5545 m .36622 .55125 L .36375 .55149 L F
.36715 .5545 m .36762 .55434 L .36622 .55125 L F
.779 .532 .562 r
.35281 .69982 m .34888 .69678 L .35268 .6972 L F
.231 .233 .654 r
.31618 .56221 m .31757 .56225 L .317 .5579 L F
.744 .501 .563 r
.35855 .70051 m .35833 .70332 L .35662 .70029 L F
.703 .465 .561 r
.36247 .70314 m .35833 .70332 L .35855 .70051 L F
.767 .698 .785 r
.32812 .66907 m .33001 .6722 L .33293 .67007 L F
.585 .487 .71 r
.3339 .67098 m .33349 .67551 L .33072 .67079 L F
0 .065 .628 r
.33072 .67079 m .33349 .67551 L .3322 .67229 L F
.767 .698 .785 r
.32926 .66931 m .33293 .67007 L .33072 .67079 L F
.575 .937 .801 r
.33072 .67079 m .33293 .67007 L .33496 .66861 L F
.33072 .67079 m .33496 .66861 L .3339 .67098 L F
0 .065 .628 r
.33072 .67079 m .3322 .67229 L .3312 .66979 L F
.767 .698 .785 r
.32812 .66907 m .32926 .66931 L .33072 .67079 L F
.676 .462 .587 r
.37639 .54278 m .37304 .54045 L .3752 .53888 L F
.37639 .54278 m .37301 .54341 L .37304 .54045 L F
.022 .22 .727 r
.37056 .60266 m .37349 .60726 L .37241 .60271 L F
.575 .542 .781 r
.33834 .62206 m .34156 .62181 L .34099 .6199 L F
.543 .327 .536 r
.33834 .62206 m .34051 .62326 L .34156 .62181 L F
.33834 .62206 m .33845 .62437 L .34051 .62326 L F
.575 .542 .781 r
.33834 .62206 m .34156 .62181 L .34099 .6199 L F
.543 .327 .536 r
.33834 .62206 m .34051 .62326 L .34156 .62181 L F
.33834 .62206 m .33845 .62437 L .34051 .62326 L F
.654 .859 .978 r
.29697 .52432 m .29486 .52546 L .29276 .5243 L F
.722 .836 .935 r
.34332 .50896 m .33855 .5085 L .3417 .50671 L F
.587 .704 .924 r
.34579 .50815 m .34332 .50896 L .3417 .50671 L F
.698 .691 .84 r
.35362 .57531 m .35191 .57823 L .35023 .57498 L F
.63 .603 .804 r
.35362 .57531 m .35484 .57763 L .35191 .57823 L F
.728 .529 .621 r
.35484 .57763 m .35165 .58058 L .35191 .57823 L F
.655 .3 .359 r
.31284 .54293 m .31671 .54402 L .31758 .54021 L F
.365 .474 .838 r
.31635 .53771 m .31758 .54021 L .31909 .53861 L F
.35 .028 .271 r
.31758 .54021 m .31883 .54229 L .31909 .53861 L F
.31758 .54021 m .31671 .54402 L .31883 .54229 L F
0 0 0 r
.36646 .56808 m .36799 .56499 L .36563 .56584 L F
.497 .273 .505 r
.35286 .61815 m .3504 .61598 L .35289 .61497 L F
.327 .727 .981 r
.35002 .54965 m .35055 .5486 L .34915 .54963 L F
.434 .463 .791 r
.32674 .56109 m .32605 .56534 L .32563 .56271 L F
0 0 .042 r
.2725 .61781 m .27289 .61943 L .27476 .61745 L F
.2725 .61781 m .27125 .62109 L .27289 .61943 L F
0 .117 .635 r
.30261 .54679 m .30433 .54892 L .30368 .54972 L F
.68 .249 .217 r
.30079 .5485 m .30433 .54892 L .30261 .54679 L F
.565 .599 .846 r
.30433 .54892 m .30398 .55306 L .30368 .54972 L F
.30433 .54892 m .30633 .55248 L .30398 .55306 L F
.417 0 0 r
.30633 .55248 m .30245 .5536 L .30398 .55306 L F
.587 .196 .27 r
.37842 .54991 m .37707 .55235 L .37432 .55195 L F
.609 .221 .282 r
.38066 .5518 m .37707 .55235 L .37842 .54991 L F
.611 .22 .278 r
.38135 .55011 m .38066 .5518 L .37842 .54991 L F
.106 0 0 r
.30497 .54343 m .30111 .5436 L .30204 .54372 L F
.04 .549 .875 r
.37334 .52427 m .37522 .52469 L .37164 .52335 L F
.661 .572 .744 r
.37334 .52427 m .37687 .52793 L .37522 .52469 L F
.666 .479 .622 r
.3073 .54808 m .3044 .54616 L .3077 .54598 L F
.3073 .54808 m .3044 .54616 L .3077 .54598 L F
0 0 .531 r
.3073 .54808 m .30737 .54764 L .3077 .54598 L F
.673 .415 .523 r
.3077 .54598 m .30497 .54343 L .30819 .54353 L F
.30649 .54433 m .3077 .54598 L .30673 .54448 L F
.30497 .54343 m .30743 .54572 L .30649 .54433 L F
.30743 .54572 m .3077 .54598 L .30649 .54433 L F
.106 0 0 r
.30205 .54355 m .30356 .54362 L .30111 .5436 L F
.30497 .54343 m .30356 .54362 L .30205 .54355 L F
.673 .415 .523 r
.30497 .54343 m .3044 .54616 L .3077 .54598 L F
.3077 .54598 m .3044 .54616 L .30497 .54343 L F
.30497 .54343 m .30673 .54448 L .30356 .54362 L F
.35 .542 .901 r
.30356 .54362 m .3061 .54376 L .30604 .54372 L F
.30356 .54362 m .30604 .54372 L .3017 .54156 L F
.077 0 .434 r
.30673 .54448 m .30793 .54424 L .30789 .54118 L F
.30673 .54448 m .30789 .54118 L .30722 .54382 L F
.35 .542 .901 r
.3061 .54376 m .30722 .54382 L .30573 .54321 L F
.3061 .54376 m .30573 .54321 L .3017 .54156 L F
0 0 .531 r
.30737 .54764 m .30793 .54424 L .3077 .54598 L F
.673 .415 .523 r
.3077 .54598 m .30819 .54353 L .30868 .54354 L F
.433 .126 .342 r
.31091 .5451 m .30868 .54354 L .31108 .54314 L F
.31091 .5451 m .3077 .54598 L .30868 .54354 L F
.729 .64 .759 r
.33644 .56497 m .34056 .56567 L .33842 .56167 L F
.38 0 .185 r
.33593 .56871 m .34056 .56567 L .33644 .56497 L F
.33593 .56871 m .33853 .56832 L .34056 .56567 L F
.375 .467 .827 r
.33842 .56167 m .34056 .56567 L .34147 .56483 L F
.271 0 .111 r
.34056 .56567 m .34108 .56733 L .34147 .56483 L F
.34056 .56567 m .33853 .56832 L .34108 .56733 L F
.333 .238 .596 r
.39212 .68048 m .39007 .67861 L .39205 .6777 L F
.39212 .68048 m .39031 .6813 L .39007 .67861 L F
.744 .303 .204 r
.37929 .58327 m .38109 .58612 L .38183 .58278 L F
.594 .507 .726 r
.2944 .56862 m .29526 .57218 L .29763 .57155 L F
.801 .377 .239 r
.38612 .57969 m .3883 .57856 L .38453 .57724 L F
.831 .996 .762 r
.38954 .57613 m .3883 .57856 L .38612 .57969 L F
0 0 0 r
.23532 .55783 m .23329 .55911 L .23633 .55676 L F
.461 .125 .31 r
.23871 .55545 m .23532 .55783 L .23633 .55676 L F
.243 .051 .409 r
.33626 .52651 m .33498 .52501 L .33699 .52483 L F
.764 .767 .855 r
.33916 .52183 m .33699 .52483 L .33579 .52168 L F
.662 .765 .285 r
.33677 .52528 m .33699 .52483 L .33995 .52506 L F
.33677 .52528 m .33626 .52651 L .33699 .52483 L F
.657 .871 .979 r
.35328 .58635 m .35069 .58753 L .34906 .58651 L F
.406 0 0 r
.35328 .58635 m .34906 .58651 L .35069 .58753 L F
.444 .249 .52 r
.38227 .61581 m .38286 .61829 L .38031 .61897 L F
.059 .099 .589 r
.3821 .61213 m .38373 .61439 L .38227 .61581 L F
.62 .358 .499 r
.38553 .61801 m .38227 .61581 L .38373 .61439 L F
.38553 .61801 m .38286 .61829 L .38267 .61608 L F
0 0 0 r
.38449 .61751 m .38286 .61829 L .38553 .61801 L F
.38449 .61751 m .38303 .62021 L .38286 .61829 L F
.38303 .62021 m .38251 .62117 L .38286 .61829 L F
.62 .358 .499 r
.38267 .61608 m .38286 .61829 L .38227 .61581 L F
0 0 .293 r
.32791 .64526 m .32716 .64394 L .32831 .64297 L F
.398 .126 .381 r
.32791 .64526 m .32831 .64297 L .33032 .64276 L F
.762 .851 .406 r
.3281 .64415 m .32791 .64526 L .32832 .64367 L F
0 0 .293 r
.32791 .64526 m .32771 .64648 L .32716 .64394 L F
.055 0 .226 r
.32542 .6506 m .32782 .64697 L .32697 .64939 L F
.572 .593 .835 r
.32697 .64939 m .32791 .64526 L .32467 .64677 L F
.163 0 0 r
.32467 .64677 m .32791 .64526 L .32656 .64762 L F
.762 .851 .406 r
.32656 .64762 m .32791 .64526 L .3281 .64415 L F
0 0 .293 r
.32791 .64526 m .32782 .64697 L .32771 .64648 L F
.337 .463 .84 r
.37522 .52469 m .37687 .52793 L .37782 .52515 L F
.161 .262 .721 r
.37687 .52793 m .37914 .52993 L .37782 .52515 L F
0 .24 .755 r
.37252 .51284 m .37387 .51379 L .3742 .51532 L F
.941 .581 .291 r
.37387 .51379 m .37634 .5175 L .3742 .51532 L F
.321 .726 .979 r
.32318 .66529 m .32506 .66634 L .32204 .66641 L F
.32318 .66529 m .32204 .66641 L .32029 .66582 L F
.32318 .66529 m .32506 .66634 L .32204 .66641 L F
.487 .722 .975 r
.32204 .66641 m .32657 .66739 L .32506 .66634 L F
.791 .976 .909 r
.31739 .62108 m .31756 .62171 L .32176 .61912 L F
.31771 .62105 m .32176 .61912 L .32002 .62083 L F
.31769 .62094 m .32176 .61912 L .31771 .62105 L F
.641 .487 .658 r
.32002 .62083 m .31747 .62327 L .31739 .62108 L F
0 0 .117 r
.31783 .6218 m .31815 .6226 L .31841 .61949 L F
.31747 .62327 m .31799 .62276 L .31783 .6218 L F
.31799 .62276 m .31815 .6226 L .31783 .6218 L F
.791 .976 .909 r
.31739 .62108 m .31769 .62094 L .31771 .62105 L F
.098 0 .294 r
.32332 .61774 m .32176 .61912 L .32378 .61555 L F
.495 .185 .37 r
.32332 .61774 m .32002 .62083 L .32176 .61912 L F
.602 .59 .812 r
.2944 .56862 m .29563 .56553 L .29337 .5659 L F
.2944 .56862 m .2973 .5681 L .29563 .56553 L F
.595 .524 .745 r
.2944 .56862 m .29703 .56892 L .2973 .5681 L F
.594 .507 .726 r
.2944 .56862 m .29763 .57155 L .29703 .56892 L F
.651 .48 .639 r
.36418 .616 m .36893 .61254 L .3663 .61271 L F
0 0 0 r
.21976 .54289 m .21894 .54347 L .22119 .54265 L F
.297 .111 .452 r
.28901 .64057 m .28718 .64082 L .28935 .63721 L F
.621 .066 0 r
.29414 .6442 m .29383 .64351 L .29116 .64294 L F
.29383 .64351 m .29361 .64303 L .29248 .64299 L F
.351 .527 .889 r
.29154 .64262 m .29242 .64334 L .28846 .64144 L F
.28901 .64057 m .29154 .64262 L .28758 .64099 L F
.28901 .64057 m .28758 .64099 L .28718 .64082 L F
.753 .236 0 r
.29086 .64003 m .28901 .64057 L .29076 .63901 L F
.29116 .64294 m .29242 .64334 L .29109 .64226 L F
.351 .527 .889 r
.29154 .64262 m .28846 .64144 L .28718 .64082 L F
.753 .236 0 r
.29116 .64294 m .28901 .64057 L .29086 .64003 L F
.552 .082 .092 r
.29361 .64303 m .29242 .64334 L .29116 .64294 L F
.621 .066 0 r
.29383 .64351 m .29248 .64299 L .29116 .64294 L F
.882 .702 .653 r
.33516 .68154 m .3316 .68406 L .33382 .68096 L F
.33516 .68154 m .33488 .68427 L .3316 .68406 L F
.935 .932 .774 r
.33516 .68154 m .33382 .68096 L .33595 .6773 L F
.299 .066 .384 r
.32723 .5743 m .3248 .57742 L .32524 .5751 L F
.785 .805 .868 r
.32116 .51773 m .31948 .5216 L .31717 .5179 L F
.353 .15 .46 r
.22542 .53733 m .22699 .53798 L .22793 .53724 L F
.22542 .53733 m .22506 .53967 L .22699 .53798 L F
.439 .842 .649 r
.29541 .56221 m .29713 .56097 L .29896 .55992 L F
.279 .408 .814 r
.30148 .56047 m .29896 .55992 L .30048 .55961 L F
.156 0 0 r
.29896 .55992 m .30082 .56035 L .30048 .55961 L F
.29896 .55992 m .29713 .56097 L .30082 .56035 L F
.016 0 0 r
.25606 .52858 m .25211 .53032 L .25421 .52958 L F
.01 0 0 r
.25813 .52818 m .25421 .52958 L .25647 .52881 L F
.423 .864 .906 r
.25633 .52883 m .25421 .52958 L .25263 .52952 L F
.25647 .52881 m .25421 .52958 L .25633 .52883 L F
.016 0 0 r
.25211 .53032 m .25193 .53039 L .25421 .52958 L F
.01 0 0 r
.25813 .52818 m .25606 .52858 L .25421 .52958 L F
.441 .262 .54 r
.29337 .5659 m .29563 .56553 L .29541 .56221 L F
.179 .159 .597 r
.40742 .57005 m .40491 .56905 L .40674 .56732 L F
.40742 .57005 m .40547 .57164 L .40491 .56905 L F
.425 .275 .573 r
.38286 .61829 m .38053 .62177 L .38031 .61897 L F
.733 .781 .892 r
.72088 .31171 m .72292 .31367 L .71994 .31442 L F
.72088 .31171 m .71994 .31442 L .71822 .3137 L F
.133 0 0 r
.72292 .31367 m .71822 .3137 L .71994 .31442 L F
.72292 .31367 m .71849 .31665 L .71822 .3137 L F
.72292 .31367 m .72123 .31572 L .71849 .31665 L F
.661 .764 .926 r
.72362 .31281 m .72292 .31367 L .72088 .31171 L F
.86 .929 .545 r
.72264 .31307 m .72292 .31367 L .72362 .31281 L F
.72264 .31307 m .72123 .31572 L .72292 .31367 L F
.362 .064 .318 r
.31072 .56883 m .30769 .57139 L .31224 .5699 L F
.945 .7 .536 r
.31224 .5699 m .31267 .56782 L .31072 .56883 L F
.201 .213 .648 r
.30575 .57551 m .30614 .57416 L .30632 .57349 L F
0 0 0 r
.30656 .57262 m .30632 .57349 L .30769 .57139 L F
.30769 .57139 m .30632 .57349 L .30825 .57236 L F
.633 .927 .973 r
.30825 .57236 m .30632 .57349 L .30681 .57188 L F
.201 .213 .648 r
.30614 .57416 m .30681 .57188 L .30632 .57349 L F
0 0 0 r
.30495 .57438 m .30632 .57349 L .30656 .57262 L F
.30769 .57139 m .30825 .57236 L .31224 .5699 L F
.174 .068 .484 r
.29541 .56221 m .29736 .56325 L .29713 .56097 L F
.29541 .56221 m .29563 .56553 L .29736 .56325 L F
.862 .987 .713 r
.31731 .53027 m .3149 .53353 L .31663 .53174 L F
.631 .439 .604 r
.37784 .62511 m .37676 .63046 L .37558 .62808 L F
.526 .34 .571 r
.38096 .62763 m .37676 .63046 L .37784 .62511 L F
.339 0 .207 r
.27078 .54205 m .27387 .53969 L .27197 .54083 L F
.751 .323 .235 r
.25595 .54699 m .25822 .5492 L .25994 .54801 L F
.351 0 0 r
.25994 .54801 m .25822 .5492 L .26179 .54874 L F
.338 0 .046 r
.25994 .54801 m .26179 .54874 L .26243 .54765 L F
.458 .261 .524 r
.36104 .60603 m .35841 .60889 L .36109 .60936 L F
.568 .354 .55 r
.36272 .60812 m .36104 .60603 L .36109 .60936 L F
.43 .224 .497 r
.36104 .60603 m .35841 .60889 L .36168 .60764 L F
.455 .278 .551 r
.36168 .60764 m .35841 .60889 L .36109 .60936 L F
.455 .625 .925 r
.33461 .57929 m .33495 .58185 L .33732 .58021 L F
0 0 0 r
.33495 .58185 m .3347 .58265 L .33732 .58021 L F
0 0 .497 r
.40179 .55134 m .40095 .55066 L .40072 .54884 L F
.40179 .55134 m .40318 .55408 L .40095 .55066 L F
0 .146 .69 r
.21639 .58813 m .21852 .59042 L .21786 .59034 L F
.22 .287 .721 r
.22004 .5927 m .21786 .59034 L .21852 .59042 L F
.073 0 0 r
.34566 .56286 m .3436 .56444 L .34147 .56483 L F
.44 .673 .962 r
.34651 .56112 m .34566 .56286 L .34426 .56147 L F
0 0 0 r
.34582 .56342 m .34566 .56286 L .34651 .56112 L F
.34582 .56342 m .3436 .56444 L .34566 .56286 L F
.957 .7 .506 r
.34426 .56147 m .3436 .56444 L .34566 .56286 L F
.752 .983 .909 r
.328 .66534 m .32657 .66739 L .32506 .66634 L F
.034 0 0 r
.25979 .55094 m .2572 .55159 L .25782 .55117 L F
.838 .954 .607 r
.36416 .63452 m .36242 .63621 L .3647 .63204 L F
.095 0 0 r
.27042 .53559 m .26866 .53611 L .26611 .53633 L F
0 0 0 r
.27182 .53551 m .26866 .53611 L .27042 .53559 L F
.043 .612 .715 r
.27381 .53543 m .27182 .53551 L .27042 .53559 L F
.672 .295 .323 r
.34644 .55301 m .34695 .55465 L .34288 .55443 L F
.528 .323 .545 r
.35102 .55082 m .34863 .55481 L .34644 .55301 L F
.643 .278 .337 r
.34644 .55301 m .34863 .55481 L .34695 .55465 L F
.752 .293 .159 r
.72398 .33644 m .72288 .33808 L .71908 .33469 L F
0 0 0 r
.72529 .33687 m .72398 .33644 L .72288 .33468 L F
.72529 .33687 m .72288 .33808 L .72398 .33644 L F
0 .188 .721 r
.37839 .51755 m .37787 .5186 L .37634 .5175 L F
.37839 .51755 m .38013 .52057 L .37787 .5186 L F
.716 .183 0 r
.21579 .5886 m .21639 .58813 L .21565 .58652 L F
.21579 .5886 m .21852 .59042 L .21639 .58813 L F
0 0 0 r
.32621 .59941 m .32724 .59724 L .32832 .59598 L F
.46 .322 .606 r
.2402 .55413 m .23871 .55545 L .23845 .55249 L F
.656 .559 .734 r
.28944 .53384 m .28712 .53717 L .28982 .53642 L F
0 0 0 r
.28944 .53384 m .28817 .53568 L .28712 .53717 L F
.347 .115 .413 r
.28725 .53979 m .28982 .53642 L .28712 .53717 L F
.363 .157 .461 r
.28817 .53568 m .28621 .53883 L .28712 .53717 L F
.531 .79 .992 r
.29931 .52375 m .30086 .52508 L .29697 .52432 L F
.672 .918 .975 r
.30331 .52375 m .30086 .52508 L .30167 .52308 L F
.562 .804 .989 r
.30167 .52308 m .30086 .52508 L .29931 .52375 L F
.438 .666 .958 r
.36208 .51825 m .36278 .51592 L .35954 .51531 L F
.36208 .51825 m .36359 .51756 L .36278 .51592 L F
.591 .627 .856 r
.36208 .51825 m .36479 .51957 L .36359 .51756 L F
.279 .777 .876 r
.3821 .53731 m .38054 .53717 L .37807 .53761 L F
.234 .753 .809 r
.38491 .53655 m .38054 .53717 L .3821 .53731 L F
.66 .473 .621 r
.3821 .53731 m .38507 .53978 L .38491 .53655 L F
.3821 .53731 m .38225 .54029 L .38507 .53978 L F
.763 .447 .451 r
.35662 .70029 m .35427 .70255 L .35281 .69982 L F
.808 .516 .495 r
.35662 .70029 m .35833 .70332 L .35427 .70255 L F
.484 .31 .569 r
.34815 .60698 m .35047 .60852 L .35002 .60481 L F
.347 .341 .711 r
.34815 .60698 m .34921 .60967 L .35047 .60852 L F
.25 0 0 r
.31435 .55129 m .31362 .5507 L .31518 .54898 L F
.31435 .55129 m .3111 .55172 L .31362 .5507 L F
.935 .63 .438 r
.33439 .5272 m .33377 .52785 L .3345 .52714 L F
.243 .051 .409 r
.33436 .52714 m .33406 .52716 L .33498 .52501 L F
.33439 .5272 m .33377 .52785 L .33436 .52715 L F
.33446 .52711 m .33436 .52715 L .33557 .5257 L F
.33439 .5272 m .33436 .52715 L .33446 .52711 L F
.33557 .5257 m .33436 .52714 L .33498 .52501 L F
.33569 .52584 m .33439 .5272 L .33557 .5257 L F
.738 .942 .95 r
.3345 .5271 m .3345 .52714 L .33626 .52651 L F
.774 .779 .857 r
.33444 .52713 m .3345 .52714 L .33446 .52713 L F
.33444 .52713 m .33439 .5272 L .3345 .52714 L F
.183 0 .3 r
.3345 .52714 m .33377 .52785 L .33626 .52651 L F
.243 .051 .409 r
.33626 .52651 m .33377 .52785 L .33569 .52584 L F
.738 .942 .95 r
.33462 .52442 m .3345 .5271 L .33626 .52651 L F
.33462 .52442 m .33109 .52634 L .3345 .52714 L F
.09 0 0 r
.33194 .52626 m .33109 .52634 L .33462 .52442 L F
.774 .779 .857 r
.3295 .52649 m .33444 .52713 L .33109 .52634 L F
.33444 .52713 m .33446 .52713 L .33109 .52634 L F
.3288 .52639 m .33069 .52923 L .33439 .5272 L F
.3288 .52639 m .33439 .5272 L .33444 .52713 L F
.752 .316 .216 r
.3345 .52237 m .32841 .52278 L .32963 .5238 L F
.32841 .52278 m .32736 .52285 L .32858 .52336 L F
.32841 .52278 m .32858 .52336 L .32963 .5238 L F
.3345 .52237 m .32743 .52011 L .32736 .52285 L F
.32819 .52036 m .3291 .52298 L .32743 .52011 L F
.3345 .52237 m .33021 .52286 L .32819 .52036 L F
.33021 .52286 m .3291 .52298 L .32819 .52036 L F
.463 .294 .566 r
.32963 .5238 m .33109 .52634 L .3312 .52427 L F
.64 .442 .599 r
.3312 .52427 m .33109 .52634 L .33387 .52364 L F
.779 .669 .742 r
.33387 .52364 m .33109 .52634 L .33014 .52474 L F
.551 .333 .537 r
.32982 .52342 m .33033 .52423 L .33046 .52391 L F
.779 .669 .742 r
.33387 .52364 m .33014 .52474 L .33033 .52423 L F
.33119 .52327 m .33033 .52423 L .33072 .52321 L F
.33387 .52364 m .33033 .52423 L .33119 .52327 L F
.09 0 0 r
.33088 .52699 m .33109 .52634 L .33194 .52626 L F
.32994 .52764 m .33035 .52717 L .33088 .52699 L F
.33035 .52717 m .33109 .52634 L .33088 .52699 L F
.774 .779 .857 r
.3288 .52639 m .3295 .52649 L .33109 .52634 L F
.277 0 0 r
.3288 .52639 m .33109 .52634 L .32994 .52764 L F
.605 .356 .514 r
.32736 .52285 m .32982 .52342 L .3291 .52298 L F
.32736 .52285 m .32977 .52345 L .32982 .52342 L F
.635 .225 0 r
.3291 .52298 m .32933 .52334 L .32736 .52285 L F
.32933 .52334 m .32963 .5238 L .32736 .52285 L F
.32934 .52336 m .3295 .52364 L .32951 .52362 L F
.508 .831 .999 r
.32547 .52842 m .33069 .52923 L .3288 .52639 L F
.227 0 .058 r
.3288 .52639 m .32735 .52869 L .32547 .52842 L F
.277 0 0 r
.3288 .52639 m .32982 .5275 L .32735 .52869 L F
.32982 .5275 m .32994 .52764 L .32939 .52786 L F
.32982 .5275 m .32939 .52786 L .32735 .52869 L F
.632 .102 0 r
.32547 .52842 m .33069 .52923 L .32803 .53206 L F
.32547 .52842 m .32863 .53043 L .33069 .52923 L F
.122 .37 .83 r
.32735 .52869 m .32863 .53043 L .32547 .52842 L F
.933 .612 .41 r
.32735 .52869 m .32719 .53085 L .32863 .53043 L F
.777 .64 .71 r
.32976 .52771 m .32719 .53085 L .32735 .52869 L F
.243 .051 .409 r
.33436 .52714 m .33377 .52785 L .33406 .52716 L F
.935 .63 .438 r
.33069 .52923 m .33377 .52785 L .33439 .5272 L F
.668 .575 .741 r
.33329 .53014 m .32996 .52765 L .33199 .52686 L F
.277 0 .064 r
.32943 .52779 m .32993 .52766 L .33199 .52686 L F
.668 .575 .741 r
.32996 .52765 m .32995 .52765 L .33199 .52686 L F
.648 .577 .762 r
.33199 .52686 m .33329 .53014 L .32995 .52765 L F
.3304 .52746 m .32995 .52765 L .32994 .52764 L F
.33199 .52686 m .32995 .52765 L .3304 .52746 L F
.394 0 0 r
.32863 .53043 m .33178 .53103 L .33069 .52923 L F
.32863 .53043 m .33085 .53116 L .33178 .53103 L F
.484 0 0 r
.32719 .53085 m .33085 .53116 L .32863 .53043 L F
.777 .64 .71 r
.3299 .52768 m .33085 .53116 L .32719 .53085 L F
.32994 .52764 m .32994 .52765 L .3299 .52768 L F
.32994 .52765 m .33085 .53116 L .3299 .52768 L F
.668 .575 .741 r
.33329 .53014 m .33085 .53116 L .32994 .52764 L F
.016 0 0 r
.32825 .53145 m .33096 .5275 L .32987 .52771 L F
.777 .64 .71 r
.3299 .52768 m .32719 .53085 L .32976 .52771 L F
.016 0 0 r
.32973 .52781 m .32987 .52771 L .32976 .52773 L F
.32825 .53145 m .32987 .52771 L .32973 .52781 L F
.3294 .52788 m .32976 .52773 L .32943 .52779 L F
.32825 .53145 m .32976 .52773 L .3294 .52788 L F
.277 0 .064 r
.32993 .52766 m .33105 .52736 L .33199 .52686 L F
.016 0 0 r
.33096 .5275 m .33105 .52736 L .32993 .52766 L F
.32984 .52769 m .32993 .52766 L .32969 .52772 L F
.33096 .5275 m .32993 .52766 L .32984 .52769 L F
.668 .575 .741 r
.32995 .52765 m .32994 .52764 L .3304 .52746 L F
.32995 .52765 m .3304 .52746 L .33199 .52686 L F
.777 .64 .71 r
.32994 .52764 m .3299 .52768 L .32976 .52771 L F
.016 0 0 r
.33096 .5275 m .32969 .52772 L .32943 .52779 L F
.845 .716 .72 r
.32595 .52615 m .32694 .5299 L .32943 .52779 L F
.32694 .5299 m .32719 .53085 L .32936 .52789 L F
.32694 .5299 m .32936 .52789 L .32943 .52779 L F
.848 .571 .519 r
.32595 .52615 m .32994 .52764 L .32985 .52424 L F
.635 .225 0 r
.32982 .5242 m .32985 .52424 L .32934 .52336 L F
.33 .52451 m .33004 .52456 L .32933 .52334 L F
.848 .571 .519 r
.3295 .52365 m .32985 .52424 L .32982 .52342 L F
.32595 .52615 m .32985 .52424 L .3295 .52365 L F
.635 .225 0 r
.32933 .52334 m .32982 .5242 L .32934 .52336 L F
.3295 .52364 m .33109 .52634 L .32951 .52362 L F
.551 .333 .537 r
.32982 .52342 m .32986 .52476 L .33033 .52423 L F
.635 .225 0 r
.32982 .5242 m .33004 .52456 L .32985 .52424 L F
.605 .356 .514 r
.32736 .52285 m .3295 .52364 L .32933 .52334 L F
.635 .225 0 r
.3291 .52298 m .33 .52451 L .32933 .52334 L F
.605 .356 .514 r
.32736 .52285 m .32714 .52528 L .3295 .52364 L F
.32933 .52334 m .3295 .52364 L .32977 .52345 L F
.848 .571 .519 r
.32595 .52615 m .3295 .52365 L .32714 .52528 L F
.3295 .52365 m .32982 .52342 L .3295 .52364 L F
.3295 .52365 m .3295 .52364 L .32714 .52528 L F
.635 .225 0 r
.32951 .52362 m .33109 .52634 L .32963 .5238 L F
.33004 .52456 m .33109 .52634 L .32934 .52336 L F
.277 0 .064 r
.32943 .52779 m .33199 .52686 L .32994 .52764 L F
.09 0 0 r
.32994 .52764 m .33462 .52442 L .33199 .52686 L F
.551 .333 .537 r
.33033 .52423 m .33025 .52494 L .33199 .52686 L F
.33025 .52494 m .32994 .52764 L .33147 .52705 L F
.33025 .52494 m .33147 .52705 L .33199 .52686 L F
.32986 .52476 m .32994 .52764 L .33033 .52423 L F
.32982 .52342 m .33206 .52515 L .33048 .5232 L F
.779 .669 .742 r
.33072 .52321 m .33014 .52474 L .3291 .52298 L F
.551 .333 .537 r
.33046 .52391 m .33186 .52665 L .33206 .52515 L F
.33033 .52423 m .33186 .52665 L .33046 .52391 L F
.62 .801 .969 r
.33284 .51968 m .3345 .52237 L .33092 .52109 L F
.33284 .51968 m .33092 .52109 L .33021 .52084 L F
.115 0 .264 r
.33455 .51828 m .33441 .51852 L .33284 .51968 L F
.528 .254 .442 r
.33284 .51968 m .3291 .52298 L .33059 .52282 L F
.33284 .51968 m .33059 .52282 L .3345 .52237 L F
.968 .74 .541 r
.3323 .52162 m .33387 .52364 L .33284 .51968 L F
.33207 .52243 m .33229 .52258 L .3323 .52162 L F
.33229 .52258 m .33387 .52364 L .3323 .52162 L F
0 0 0 r
.33579 .52168 m .33387 .52364 L .33607 .52199 L F
.528 .796 .995 r
.32982 .52342 m .33207 .52243 L .3291 .52298 L F
.779 .669 .742 r
.3323 .52259 m .3291 .52298 L .33207 .52243 L F
.33387 .52364 m .33072 .52321 L .3323 .52259 L F
.551 .333 .537 r
.33048 .5232 m .33055 .52327 L .33219 .52264 L F
.528 .796 .995 r
.32982 .52342 m .33219 .52264 L .33207 .52243 L F
.779 .669 .742 r
.33219 .52264 m .33217 .52261 L .3323 .52259 L F
.528 .796 .995 r
.33219 .52264 m .3324 .52256 L .33207 .52243 L F
.779 .669 .742 r
.33072 .52321 m .3291 .52298 L .33217 .52261 L F
.33072 .52321 m .33217 .52261 L .33219 .52264 L F
.551 .333 .537 r
.33219 .52264 m .33206 .52515 L .3324 .52256 L F
.33055 .52327 m .33206 .52515 L .33219 .52264 L F
.837 .776 .793 r
.33462 .52442 m .33607 .52199 L .33387 .52364 L F
0 .132 .678 r
.33469 .52393 m .33387 .52364 L .33229 .52258 L F
.33278 .52284 m .33229 .52258 L .33207 .52243 L F
.33469 .52393 m .33229 .52258 L .33278 .52284 L F
.487 .456 .749 r
.3324 .52256 m .33525 .52225 L .33207 .52243 L F
.3324 .52256 m .33359 .52278 L .33525 .52225 L F
0 .132 .678 r
.33511 .52267 m .33417 .52259 L .33525 .52225 L F
.33469 .52393 m .33278 .52284 L .33511 .52267 L F
.487 .456 .749 r
.33359 .52278 m .33528 .52307 L .33525 .52225 L F
0 .132 .678 r
.33417 .52259 m .33207 .52243 L .33525 .52225 L F
.777 .989 .753 r
.33239 .52263 m .33341 .52279 L .3324 .52256 L F
.33341 .52279 m .33359 .52278 L .3324 .52256 L F
0 .132 .678 r
.33278 .52284 m .33207 .52243 L .33511 .52267 L F
.777 .989 .753 r
.33341 .52279 m .33528 .52307 L .33359 .52278 L F
.33229 .5237 m .33382 .52338 L .33239 .52263 L F
0 .042 .557 r
.33528 .52307 m .33598 .52231 L .33525 .52225 L F
.837 .776 .793 r
.33462 .52442 m .33677 .52528 L .33798 .52351 L F
.33462 .52442 m .33798 .52351 L .33607 .52199 L F
.662 .765 .285 r
.33677 .52528 m .33995 .52506 L .33798 .52351 L F
.591 .42 .618 r
.3383 .52598 m .33643 .52492 L .33598 .52231 L F
.83 .995 .759 r
.33528 .52307 m .33543 .52324 L .33598 .52231 L F
.591 .42 .618 r
.33643 .52492 m .33543 .52324 L .33598 .52231 L F
.83 .995 .759 r
.33543 .52324 m .33702 .52502 L .33598 .52231 L F
.591 .42 .618 r
.33543 .52324 m .33535 .5231 L .33598 .52231 L F
.83 .995 .759 r
.33528 .52307 m .33537 .52313 L .33543 .52324 L F
.591 .42 .618 r
.33643 .52492 m .33469 .52393 L .33535 .5231 L F
.83 .995 .759 r
.33528 .52307 m .33527 .52303 L .33537 .52313 L F
.33543 .52324 m .33537 .52313 L .33702 .52502 L F
0 .01 .518 r
.33598 .52231 m .33535 .5231 L .33525 .52225 L F
.33535 .5231 m .33523 .52298 L .33525 .52225 L F
.83 .995 .759 r
.33527 .52303 m .335 .52172 L .33665 .52442 L F
.33527 .52303 m .33665 .52442 L .33702 .52502 L F
0 .01 .518 r
.33535 .5231 m .33523 .52325 L .33523 .52298 L F
.33521 .52316 m .33469 .52393 L .33511 .52267 L F
0 .132 .678 r
.33469 .52393 m .33462 .52442 L .33387 .52364 L F
.777 .989 .753 r
.33228 .52652 m .33528 .52307 L .33229 .5237 L F
.33199 .52686 m .33524 .5231 L .33521 .52316 L F
.33199 .52686 m .33228 .52652 L .33229 .5237 L F
.551 .333 .537 r
.33186 .52665 m .33201 .5266 L .3324 .52256 L F
.641 .447 .605 r
.33469 .52393 m .33199 .52686 L .33462 .52442 L F
.628 .567 .767 r
.33577 .5272 m .33329 .53014 L .33199 .52686 L F
.699 .821 .94 r
.33462 .52442 m .33626 .52651 L .33677 .52528 L F
.641 .447 .605 r
.33469 .52393 m .33577 .5272 L .33199 .52686 L F
.777 .989 .753 r
.33199 .52686 m .33239 .52486 L .33315 .52552 L F
0 0 0 r
.33199 .52686 m .33217 .52732 L .33239 .52486 L F
0 .07 .622 r
.33217 .52732 m .33178 .52433 L .33239 .52486 L F
.33178 .52433 m .33164 .5232 L .33239 .52486 L F
.777 .989 .753 r
.33315 .52552 m .33239 .52486 L .33524 .5231 L F
.33521 .52316 m .33524 .5231 L .33528 .52307 L F
0 .01 .518 r
.33523 .52325 m .33503 .5235 L .33521 .52316 L F
.33503 .5235 m .33469 .52393 L .33521 .52316 L F
.777 .989 .753 r
.3352 .52309 m .33528 .52307 L .33519 .52306 L F
0 .01 .518 r
.33523 .52313 m .33511 .52267 L .33525 .52225 L F
.33521 .52317 m .33511 .52267 L .33523 .52313 L F
.777 .989 .753 r
.33382 .52338 m .3352 .52309 L .33239 .52263 L F
.3352 .52309 m .33519 .52306 L .33239 .52263 L F
.83 .995 .759 r
.33527 .52303 m .33239 .52486 L .335 .52172 L F
.33528 .52307 m .33524 .5231 L .33527 .52303 L F
.33524 .5231 m .33239 .52486 L .33527 .52303 L F
0 .01 .518 r
.33523 .52325 m .33521 .52317 L .33523 .52313 L F
.115 0 .264 r
.33441 .51852 m .33207 .52243 L .33284 .51968 L F
.642 .285 .35 r
.32743 .52011 m .3291 .52298 L .33021 .52084 L F
0 0 .53 r
.32763 .52 m .3291 .52298 L .3283 .51963 L F
.32743 .52011 m .32788 .52089 L .32763 .52 L F
.32788 .52089 m .3291 .52298 L .32763 .52 L F
.551 .333 .537 r
.33186 .52665 m .33199 .52686 L .33201 .5266 L F
.507 .481 .762 r
.34937 .57237 m .35023 .57498 L .34784 .57512 L F
.138 0 0 r
.23329 .55911 m .2314 .56082 L .2291 .56139 L F
.556 .224 .362 r
.23532 .55783 m .2314 .56082 L .23329 .55911 L F
.645 .63 .82 r
.33456 .647 m .33718 .64679 L .33421 .64084 L F
.546 .183 .304 r
.33663 .64948 m .33456 .647 L .33315 .64919 L F
.33663 .64948 m .33718 .64679 L .33456 .647 L F
.203 .46 .88 r
.36479 .51957 m .36473 .51709 L .36359 .51756 L F
.36479 .51957 m .36739 .52065 L .36473 .51709 L F
.449 .195 .436 r
.3715 .59839 m .37446 .59604 L .37216 .59644 L F
.77 .695 .78 r
.37136 .61196 m .36885 .61511 L .3747 .61496 L F
.393 .214 .517 r
.36885 .61511 m .3708 .61724 L .3747 .61496 L F
0 .045 .528 r
.37257 .61304 m .3747 .61496 L .37309 .61351 L F
.941 .928 .764 r
.37309 .61351 m .3747 .61496 L .3708 .61724 L F
0 0 .121 r
.37309 .61351 m .37394 .61497 L .37394 .61427 L F
.37309 .61351 m .37394 .61427 L .37394 .61186 L F
0 .045 .528 r
.37136 .61196 m .37257 .61304 L .37309 .61351 L F
.594 .263 .378 r
.33186 .63976 m .33208 .63771 L .33435 .63977 L F
0 0 0 r
.33208 .63771 m .33449 .63443 L .33519 .63751 L F
.558 .271 .436 r
.33208 .63771 m .33519 .63751 L .33435 .63977 L F
.173 0 0 r
.31461 .65021 m .31686 .64978 L .31413 .65206 L F
.748 .994 .843 r
.31413 .65206 m .31686 .64978 L .31438 .65025 L F
0 0 .527 r
.31507 .65233 m .31413 .65206 L .31438 .65025 L F
.31601 .65518 m .31413 .65206 L .31507 .65233 L F
0 0 0 r
.31243 .65386 m .31359 .65191 L .31413 .65206 L F
.31359 .65191 m .31461 .65021 L .31413 .65206 L F
.413 .414 .752 r
.3153 .65574 m .31243 .65386 L .31413 .65206 L F
0 .251 .763 r
.28823 .64731 m .28959 .6475 L .287 .64551 L F
.28823 .64731 m .29072 .64925 L .28959 .6475 L F
.614 .47 .662 r
.33133 .57443 m .33397 .57421 L .33377 .5716 L F
.594 .653 .878 r
.33133 .57443 m .33512 .57563 L .33397 .57421 L F
.982 .719 .454 r
.31924 .55206 m .32351 .55531 L .32339 .55325 L F
.01 .011 .508 r
.32339 .55325 m .325 .55153 L .32436 .54882 L F
.64 .949 .948 r
.35848 .66947 m .35553 .67085 L .35386 .67058 L F
.716 .482 .57 r
.32437 .63703 m .32804 .63715 L .32815 .63446 L F
.88 .828 .792 r
.32804 .63715 m .33032 .63349 L .32815 .63446 L F
.73 .717 .839 r
.3854 .59976 m .38994 .60056 L .38855 .5986 L F
.823 .739 .771 r
.38855 .5986 m .38994 .60056 L .39164 .59645 L F
0 0 0 r
.3677 .5364 m .369 .53618 L .37228 .5353 L F
.335 0 0 r
.37228 .5353 m .37394 .53588 L .37433 .53375 L F
.37228 .5353 m .369 .53618 L .37394 .53588 L F
0 0 0 r
.34562 .58361 m .34244 .58573 L .3436 .58446 L F
.32966 .65904 m .32811 .66418 L .33027 .66223 L F
0 .033 .6 r
.32811 .66418 m .32895 .66395 L .33027 .66223 L F
0 .104 .632 r
.3859 .52384 m .38592 .52447 L .3843 .52321 L F
.3859 .52384 m .38821 .52657 L .38592 .52447 L F
.646 .307 .384 r
.3339 .55923 m .33064 .56078 L .33143 .55985 L F
.32 .286 .663 r
.34733 .53073 m .34775 .53688 L .34612 .53728 L F
.339 .363 .74 r
.34775 .53688 m .34885 .5385 L .34612 .53728 L F
.434 .848 .964 r
.23189 .53473 m .23677 .53466 L .23439 .53506 L F
.429 0 0 r
.34966 .62625 m .3527 .62429 L .34818 .62503 L F
.35002 .62654 m .3511 .62563 L .34966 .62625 L F
.3511 .62563 m .3527 .62429 L .34966 .62625 L F
.736 .304 .225 r
.34822 .62644 m .34347 .62456 L .34527 .62749 L F
.286 0 .224 r
.35002 .62665 m .34818 .62503 L .34822 .62644 L F
.35018 .62667 m .3501 .6266 L .35002 .62665 L F
.3501 .6266 m .34818 .62503 L .35002 .62665 L F
.596 .446 .647 r
.34736 .62952 m .35004 .62784 L .34996 .62669 L F
.34895 .62735 m .34996 .62669 L .34991 .62604 L F
.34736 .62952 m .34996 .62669 L .34895 .62735 L F
.286 0 .224 r
.35018 .62667 m .34822 .62644 L .34991 .62604 L F
.596 .446 .647 r
.34736 .62952 m .34991 .62604 L .34822 .62644 L F
.442 .414 .732 r
.3493 .6264 m .34799 .62717 L .34754 .62606 L F
.34799 .62717 m .34789 .62723 L .34787 .62715 L F
.43 .226 .501 r
.34686 .62692 m .34787 .62715 L .34822 .62644 L F
.788 .431 .38 r
.34347 .62456 m .34818 .62503 L .34626 .62432 L F
.665 .696 .869 r
.34626 .62432 m .34818 .62503 L .34957 .62231 L F
.649 .856 .979 r
.34347 .62456 m .34818 .62503 L .34687 .62382 L F
.901 .689 .607 r
.34306 .6271 m .34527 .62749 L .34347 .62456 L F
.619 .381 .535 r
.34187 .62978 m .34451 .628 L .34345 .62773 L F
.34451 .628 m .3442 .62763 L .34345 .62773 L F
.901 .689 .607 r
.34345 .62773 m .34527 .62749 L .34306 .6271 L F
.619 .381 .535 r
.34187 .62978 m .34516 .62963 L .34527 .62749 L F
.638 .624 .82 r
.34438 .629 m .34516 .62963 L .34463 .62965 L F
.34335 .62628 m .34472 .62881 L .34438 .629 L F
.34472 .62881 m .34516 .62963 L .34438 .629 L F
.449 .873 .758 r
.34854 .62674 m .34784 .62726 L .3493 .6264 L F
.714 .275 .205 r
.34385 .62721 m .34406 .62875 L .34516 .62963 L F
.638 .624 .82 r
.34335 .62628 m .34463 .62965 L .34303 .62704 L F
.772 .611 .679 r
.34687 .62382 m .34787 .62715 L .34335 .62628 L F
.34787 .62715 m .34781 .62721 L .34335 .62628 L F
.442 .414 .732 r
.34799 .62717 m .34787 .62715 L .34754 .62606 L F
.772 .611 .679 r
.34787 .62715 m .34789 .62723 L .34781 .62721 L F
.449 .873 .758 r
.34784 .62726 m .34789 .62723 L .34799 .62717 L F
.43 .226 .501 r
.34527 .62749 m .34736 .62952 L .34794 .62742 L F
.714 .275 .205 r
.34781 .62721 m .34789 .62723 L .34784 .62726 L F
.43 .226 .501 r
.3478 .6272 m .34794 .62742 L .34801 .62718 L F
.34527 .62749 m .34794 .62742 L .3478 .6272 L F
.714 .275 .205 r
.34335 .62628 m .34349 .62678 L .34385 .62721 L F
.34349 .62678 m .34406 .62875 L .34385 .62721 L F
.619 .381 .535 r
.34451 .628 m .34527 .62749 L .3442 .62763 L F
.43 .226 .501 r
.34527 .62749 m .34801 .62718 L .34686 .62692 L F
.34601 .6282 m .34516 .62963 L .34736 .62952 L F
.34527 .62749 m .34521 .62864 L .34601 .6282 L F
.34521 .62864 m .34516 .62963 L .34601 .6282 L F
.714 .275 .205 r
.34335 .62628 m .34781 .62721 L .34406 .62875 L F
.449 .873 .758 r
.34406 .62875 m .34918 .62645 L .3471 .62734 L F
.34918 .62645 m .3493 .6264 L .3492 .62644 L F
.43 .226 .501 r
.34799 .62717 m .34802 .62716 L .34822 .62644 L F
.449 .873 .758 r
.34918 .62645 m .3492 .62644 L .3471 .62734 L F
.714 .275 .205 r
.34781 .62721 m .34784 .62726 L .34406 .62875 L F
.449 .873 .758 r
.34406 .62875 m .34694 .62761 L .34854 .62674 L F
.43 .226 .501 r
.34787 .62715 m .34799 .62717 L .34807 .62692 L F
.449 .873 .758 r
.34694 .62761 m .34784 .62726 L .34854 .62674 L F
.638 .624 .82 r
.34281 .62756 m .34322 .62803 L .34187 .62978 L F
.34325 .62739 m .34463 .62965 L .34281 .62756 L F
.619 .381 .535 r
.34187 .62978 m .34345 .62773 L .34295 .6278 L F
.638 .624 .82 r
.34322 .62803 m .34463 .62965 L .34187 .62978 L F
.34303 .62704 m .34325 .62739 L .34281 .62756 L F
0 0 .431 r
.34257 .62556 m .34016 .62756 L .34234 .62774 L F
.34291 .62753 m .34234 .62774 L .34295 .6278 L F
.34257 .62556 m .34234 .62774 L .34291 .62753 L F
.901 .689 .607 r
.34295 .6278 m .34345 .62773 L .34306 .6271 L F
.43 .226 .501 r
.34787 .62715 m .34807 .62692 L .34822 .62644 L F
.34799 .62717 m .34801 .62718 L .34802 .62716 L F
.449 .873 .758 r
.34784 .62726 m .34799 .62717 L .3493 .6264 L F
.442 .414 .732 r
.34991 .62604 m .3493 .6264 L .34687 .62382 L F
.3493 .6264 m .34754 .62606 L .34687 .62382 L F
.449 .873 .758 r
.3471 .62734 m .3493 .6264 L .34991 .62604 L F
.429 0 0 r
.35018 .62667 m .35027 .62659 L .35002 .62654 L F
.35027 .62659 m .3527 .62429 L .35002 .62654 L F
.741 .569 .66 r
.35157 .62337 m .35039 .62618 L .34925 .62328 L F
.636 .707 .897 r
.35004 .62784 m .35022 .62757 L .34991 .62604 L F
.741 .569 .66 r
.35039 .62618 m .35003 .62603 L .35001 .62588 L F
.35039 .62618 m .3502 .62663 L .35003 .62603 L F
.799 .407 .311 r
.3503 .6274 m .35031 .62739 L .35018 .62667 L F
.35031 .62739 m .35078 .62677 L .35019 .62666 L F
.35078 .62677 m .3527 .62429 L .35045 .62642 L F
.35078 .62677 m .35045 .62642 L .35019 .62666 L F
.741 .569 .66 r
.35016 .6256 m .34998 .62586 L .34925 .62328 L F
.35001 .62588 m .35003 .62603 L .34998 .62586 L F
.249 .224 .634 r
.35008 .62602 m .34991 .62604 L .34972 .62384 L F
.741 .569 .66 r
.35039 .62618 m .34998 .62586 L .35016 .6256 L F
.249 .224 .634 r
.34957 .62366 m .34991 .62604 L .34925 .62328 L F
.707 .532 .65 r
.35157 .62337 m .35559 .62321 L .35129 .62662 L F
.35065 .62632 m .35129 .62662 L .35032 .62738 L F
.35157 .62337 m .35129 .62662 L .35065 .62632 L F
.249 .224 .634 r
.35005 .62603 m .34991 .62604 L .34957 .62366 L F
.25 .579 .943 r
.3499 .62598 m .35003 .62603 L .35005 .62603 L F
.707 .532 .65 r
.35064 .62631 m .35032 .62738 L .35031 .62736 L F
.35157 .62337 m .35065 .62632 L .35064 .62631 L F
.35065 .62632 m .35032 .62738 L .35064 .62631 L F
.799 .407 .311 r
.35031 .62739 m .35019 .62666 L .35018 .62667 L F
.741 .569 .66 r
.3502 .62663 m .3503 .6274 L .35018 .62667 L F
.35157 .62337 m .35064 .62631 L .35039 .62618 L F
.249 .224 .634 r
.3514 .62587 m .35008 .62602 L .34972 .62384 L F
.25 .579 .943 r
.3514 .62587 m .3501 .62602 L .34961 .62423 L F
.3501 .62602 m .35005 .62603 L .35004 .62599 L F
.3501 .62602 m .35004 .62599 L .34961 .62423 L F
.741 .569 .66 r
.35039 .62618 m .35031 .62736 L .3502 .62663 L F
.35064 .62631 m .35031 .62736 L .35039 .62618 L F
.35031 .62736 m .3503 .6274 L .3502 .62663 L F
.249 .224 .634 r
.34975 .62387 m .3497 .6243 L .34957 .62366 L F
.3514 .62587 m .34984 .62443 L .34975 .62387 L F
.34984 .62443 m .3497 .6243 L .34975 .62387 L F
.25 .579 .943 r
.35005 .62603 m .34991 .62604 L .34989 .62596 L F
.741 .569 .66 r
.3502 .62663 m .35018 .62667 L .35 .62602 L F
.249 .224 .634 r
.34986 .62542 m .34991 .62604 L .34925 .62328 L F
.741 .569 .66 r
.35003 .62603 m .35 .62602 L .34925 .62328 L F
.3502 .62663 m .35 .62602 L .35003 .62603 L F
.249 .224 .634 r
.34972 .62384 m .34986 .62542 L .34925 .62328 L F
.25 .579 .943 r
.35005 .62603 m .34989 .62596 L .34961 .62423 L F
.34993 .62597 m .35005 .62603 L .3514 .62587 L F
.3499 .62598 m .35005 .62603 L .34993 .62597 L F
.707 .532 .65 r
.35031 .62736 m .35032 .62738 L .3503 .6274 L F
.25 .579 .943 r
.34961 .62423 m .34987 .62579 L .3514 .62587 L F
.34987 .62579 m .3499 .62598 L .35003 .62597 L F
.34987 .62579 m .35003 .62597 L .3514 .62587 L F
.636 .707 .897 r
.35022 .62757 m .3514 .62587 L .35003 .62603 L F
.35022 .62757 m .35003 .62603 L .34991 .62604 L F
.442 .414 .732 r
.34991 .62604 m .34687 .62382 L .34925 .62328 L F
.449 .873 .758 r
.34406 .62875 m .34991 .62604 L .34736 .62762 L F
.906 .983 .729 r
.34736 .62762 m .34981 .6261 L .34961 .62423 L F
.34981 .6261 m .34991 .62604 L .3499 .62598 L F
.34981 .6261 m .3499 .62598 L .34961 .62423 L F
.25 .579 .943 r
.3499 .62598 m .34991 .62604 L .35003 .62603 L F
0 0 0 r
.3251 .61427 m .32378 .61555 L .32631 .61233 L F
.041 0 .268 r
.32509 .61702 m .32378 .61555 L .3251 .61427 L F
.32509 .61702 m .32332 .61774 L .32378 .61555 L F
.542 0 0 r
.25615 .63387 m .25436 .6342 L .25242 .63341 L F
.076 0 0 r
.25863 .63344 m .25436 .6342 L .25615 .63387 L F
.855 .867 .848 r
.37537 .5612 m .37672 .5645 L .3769 .56166 L F
.37537 .5612 m .37304 .564 L .37672 .5645 L F
.922 .534 .158 r
.37601 .56685 m .37672 .5645 L .37304 .564 L F
.33 0 .085 r
.37306 .56593 m .37423 .56757 L .37601 .56685 L F
.37297 .5659 m .37423 .56757 L .37306 .56593 L F
0 0 .421 r
.37423 .56757 m .37453 .56815 L .37453 .56799 L F
.648 .377 .495 r
.37297 .5659 m .37601 .56685 L .37304 .564 L F
.922 .534 .158 r
.37601 .56685 m .37703 .56667 L .37672 .5645 L F
0 0 .421 r
.37423 .56757 m .37446 .56607 L .37671 .56553 L F
.37423 .56757 m .37453 .56799 L .37446 .56607 L F
.663 .963 .768 r
.37601 .56685 m .37423 .56757 L .37484 .56706 L F
.37601 .56685 m .37484 .56706 L .37671 .56553 L F
.922 .534 .158 r
.37601 .56685 m .37716 .56753 L .37703 .56667 L F
.397 0 0 r
.2922 .63447 m .29869 .63378 L .29681 .63354 L F
.225 0 0 r
.29295 .63584 m .2922 .63447 L .29681 .63354 L F
.388 .808 .619 r
.3881 .57332 m .39205 .57092 L .38884 .57127 L F
.3881 .57332 m .38844 .57308 L .39205 .57092 L F
.732 .962 .941 r
.39349 .56851 m .39574 .56889 L .39205 .57092 L F
.39425 .56808 m .39574 .56889 L .39349 .56851 L F
.828 .954 .61 r
.39786 .56539 m .39574 .56889 L .3962 .56694 L F
.738 .963 .938 r
.3962 .56694 m .39574 .56889 L .39388 .56788 L F
.3962 .56694 m .39388 .56788 L .39618 .57086 L F
.598 .34 .498 r
.39618 .57086 m .39862 .56637 L .3962 .56694 L F
.142 0 0 r
.39619 .56696 m .39695 .56792 L .39505 .56899 L F
.3962 .56694 m .3962 .56695 L .39619 .56696 L F
.3962 .56695 m .39695 .56792 L .39619 .56696 L F
.732 .962 .941 r
.39388 .56788 m .39425 .56808 L .39349 .56851 L F
.682 .497 .629 r
.38844 .57308 m .39388 .56788 L .39205 .57092 L F
.369 .831 .908 r
.26531 .5283 m .26762 .5277 L .2689 .52783 L F
.418 .858 .92 r
.2689 .52783 m .27008 .527 L .27101 .5268 L F
.2689 .52783 m .26762 .5277 L .27008 .527 L F
.85 .797 .799 r
.33444 .62661 m .33802 .62695 L .33845 .62437 L F
.322 .393 .78 r
.33444 .62661 m .33686 .62778 L .33802 .62695 L F
.353 .147 .455 r
.33686 .62778 m .33918 .62594 L .33802 .62695 L F
.695 .659 .81 r
.38269 .6599 m .38373 .66298 L .3799 .66261 L F
.514 .612 .888 r
.38387 .65948 m .38373 .66298 L .38269 .6599 L F
.38387 .65948 m .3857 .66255 L .38373 .66298 L F
.543 .458 .709 r
.3857 .66255 m .38383 .66572 L .38373 .66298 L F
0 .447 .712 r
.24619 .63109 m .24416 .63058 L .24212 .6301 L F
0 .381 .788 r
.24619 .63109 m .24616 .63062 L .24416 .63058 L F
.24619 .63109 m .24776 .63178 L .24616 .63062 L F
.756 .476 .51 r
.37716 .56753 m .38112 .56512 L .37844 .56535 L F
.684 .162 0 r
.2958 .64512 m .29731 .6442 L .29361 .64303 L F
.512 0 0 r
.29781 .64576 m .29651 .64469 L .2958 .64512 L F
0 .416 .729 r
.29558 .64493 m .29781 .64576 L .2958 .64512 L F
.539 0 0 r
.29941 .64707 m .29781 .64576 L .29558 .64493 L F
.30005 .64743 m .29781 .64576 L .29941 .64707 L F
.512 0 0 r
.29781 .64576 m .29731 .6442 L .29651 .64469 L F
.542 0 0 r
.30078 .64545 m .29731 .6442 L .30116 .64556 L F
.512 0 0 r
.29781 .64576 m .30116 .64556 L .29731 .6442 L F
.151 0 .223 r
.3111 .57456 m .31075 .57715 L .3088 .57753 L F
0 0 .038 r
.31344 .57152 m .3111 .57456 L .31383 .57098 L F
.475 .321 .592 r
.31281 .57336 m .31075 .57715 L .3111 .57456 L F
.31281 .57336 m .31294 .57652 L .31075 .57715 L F
.719 .206 0 r
.31204 .57367 m .31286 .5742 L .31281 .57336 L F
.436 .291 .585 r
.31507 .57562 m .31294 .57652 L .31281 .57336 L F
.719 .206 0 r
.31286 .5742 m .31507 .57562 L .31281 .57336 L F
0 0 .038 r
.31276 .5724 m .31281 .57336 L .3111 .57456 L F
.31344 .57152 m .31281 .57336 L .31276 .5724 L F
.646 .302 .375 r
.36053 .52682 m .36227 .52978 L .36244 .52703 L F
.547 0 0 r
.34739 .67143 m .34512 .66995 L .34346 .67054 L F
.461 .238 .487 r
.36902 .55394 m .36834 .55805 L .36616 .55855 L F
.453 .218 .467 r
.36834 .55805 m .36587 .56094 L .36616 .55855 L F
.36834 .55805 m .36807 .56045 L .36587 .56094 L F
.467 0 0 r
.36616 .55904 m .36768 .5603 L .36609 .55755 L F
.36568 .55729 m .36609 .55755 L .36545 .55642 L F
.36616 .55904 m .36609 .55755 L .36568 .55729 L F
.303 0 0 r
.36386 .55614 m .36549 .55665 L .36762 .55434 L F
.36303 .55654 m .36461 .55661 L .36386 .55614 L F
.36461 .55661 m .36549 .55665 L .36386 .55614 L F
.753 .893 .493 r
.36762 .55434 m .36549 .55665 L .36776 .55279 L F
.855 .793 .79 r
.32425 .63983 m .32779 .64013 L .32804 .63715 L F
.404 0 0 r
.32586 .64095 m .32779 .64013 L .32425 .63983 L F
0 0 .382 r
.32804 .63715 m .32779 .64013 L .32924 .6389 L F
.453 .856 .677 r
.32924 .6389 m .32779 .64013 L .32586 .64095 L F
.478 .152 .334 r
.32779 .64013 m .33032 .64276 L .32831 .64297 L F
.32779 .64013 m .33186 .63976 L .33032 .64276 L F
.994 .754 .448 r
.38407 .59715 m .38489 .5968 L .38404 .59337 L F
.426 .443 .774 r
.38404 .59337 m .38489 .5968 L .38707 .59579 L F
.729 .709 .832 r
.38407 .59718 m .38489 .5968 L .38407 .59715 L F
.38407 .59718 m .38707 .59579 L .38489 .5968 L F
.61 .3 .419 r
.33136 .54904 m .32788 .5513 L .32916 .54958 L F
.562 .038 0 r
.33258 .60224 m .33678 .60234 L .33368 .60154 L F
.169 0 .293 r
.38791 .67387 m .3906 .67141 L .38811 .6717 L F
.331 .788 .65 r
.2949 .64902 m .2987 .65039 L .2969 .64972 L F
.379 0 0 r
.2987 .65039 m .29924 .65097 L .2969 .64972 L F
0 0 .162 r
.32631 .61233 m .32781 .60897 L .32729 .61097 L F
.101 0 0 r
.32711 .61358 m .32631 .61233 L .32729 .61097 L F
0 0 .162 r
.32781 .60897 m .32796 .60863 L .32729 .61097 L F
.702 .428 .506 r
.32411 .61138 m .32729 .61097 L .32796 .60863 L F
.989 .744 .467 r
.32589 .61069 m .32729 .61097 L .32456 .61132 L F
.32589 .61069 m .32456 .61132 L .32411 .61138 L F
.32589 .61069 m .3268 .61285 L .32729 .61097 L F
.3268 .61285 m .32711 .61358 L .32729 .61097 L F
.254 .005 .33 r
.3298 .60778 m .32729 .61097 L .32796 .60863 L F
.3298 .60778 m .32729 .61097 L .32796 .60863 L F
.576 .586 .825 r
.32803 .60939 m .32711 .61358 L .32589 .61069 L F
0 0 0 r
.32688 .61023 m .32589 .61069 L .32417 .61222 L F
.32803 .60939 m .32589 .61069 L .32688 .61023 L F
.101 0 0 r
.32711 .61358 m .3251 .61427 L .32631 .61233 L F
.395 .711 .986 r
.39736 .66681 m .39937 .66796 L .39651 .66825 L F
.45 .335 .63 r
.39847 .66805 m .39776 .67075 L .39651 .66825 L F
.39937 .66796 m .39776 .67075 L .39847 .66805 L F
0 0 .334 r
.39776 .67075 m .39697 .67391 L .39699 .67364 L F
0 .065 .606 r
.39731 .66689 m .39776 .67075 L .39736 .66681 L F
.39651 .66825 m .39776 .67075 L .39731 .66689 L F
0 0 .334 r
.39776 .67075 m .39699 .67364 L .39728 .67072 L F
.883 .487 .276 r
.39673 .66941 m .39776 .67075 L .39651 .66839 L F
.313 .314 .7 r
.39648 .66924 m .39419 .66893 L .39651 .66825 L F
.883 .487 .276 r
.39651 .66849 m .39651 .66839 L .39646 .6683 L F
.39673 .66941 m .39651 .66839 L .39651 .66849 L F
.39646 .6683 m .39776 .67075 L .39651 .66825 L F
.313 .314 .7 r
.39741 .66937 m .39648 .66924 L .39651 .66825 L F
0 0 .334 r
.39776 .67075 m .39728 .67072 L .39741 .66937 L F
.528 .484 .751 r
.39693 .67027 m .39697 .67391 L .3947 .6745 L F
.883 .487 .276 r
.39722 .67053 m .39776 .67075 L .39612 .66862 L F
.528 .484 .751 r
.39741 .66937 m .39728 .67072 L .39693 .67027 L F
.39684 .66987 m .3947 .6745 L .39452 .6719 L F
.39684 .66987 m .39684 .66987 L .39684 .66987 L F
.39684 .66987 m .3947 .6745 L .39684 .66987 L F
.39694 .67027 m .3947 .6745 L .39684 .66987 L F
.313 .314 .7 r
.39648 .66924 m .39452 .6719 L .39419 .66893 L F
.39684 .66987 m .39452 .6719 L .39648 .66924 L F
.883 .487 .276 r
.39587 .66884 m .39722 .67053 L .39612 .66862 L F
.528 .484 .751 r
.3971 .67048 m .39697 .67391 L .39693 .67027 L F
.883 .487 .276 r
.39499 .66964 m .3971 .67048 L .39587 .66884 L F
.3971 .67048 m .39722 .67053 L .39587 .66884 L F
.528 .484 .751 r
.39728 .67072 m .39728 .67072 L .3971 .67048 L F
.39728 .67072 m .39697 .67391 L .3971 .67048 L F
0 .072 .607 r
.39698 .67043 m .39709 .67071 L .39728 .67072 L F
.3971 .67048 m .39728 .67072 L .39776 .67075 L F
.39698 .67043 m .39728 .67072 L .3971 .67048 L F
0 0 .334 r
.39776 .67075 m .39811 .67319 L .39697 .67391 L F
0 .072 .607 r
.39709 .67071 m .39811 .67319 L .39776 .67075 L F
.39499 .66964 m .39747 .67246 L .39698 .67043 L F
.39747 .67246 m .39811 .67319 L .39698 .67043 L F
.528 .484 .751 r
.39741 .66937 m .39694 .67027 L .39684 .66987 L F
.883 .487 .276 r
.39612 .66862 m .39673 .66941 L .39646 .6683 L F
0 0 .517 r
.39651 .66825 m .39776 .67075 L .39741 .66937 L F
.313 .314 .7 r
.39741 .66937 m .39684 .66987 L .39648 .66924 L F
.554 .841 .508 r
.36257 .55048 m .36152 .55159 L .36381 .54908 L F
0 0 .072 r
.37898 .64881 m .3777 .65048 L .37948 .64726 L F
0 0 0 r
.37745 .65113 m .3777 .65048 L .37898 .64881 L F
.37745 .65113 m .37658 .65265 L .3777 .65048 L F
.901 .689 .607 r
.34295 .6278 m .34347 .62456 L .34257 .62556 L F
.275 0 .251 r
.38286 .69085 m .382 .69317 L .37987 .69379 L F
.372 .03 .25 r
.38534 .69048 m .382 .69317 L .38286 .69085 L F
.52 .332 .566 r
.38535 .68769 m .38534 .69048 L .38286 .69085 L F
0 .424 .778 r
.21865 .61327 m .21678 .61226 L .2149 .61166 L F
.184 .515 .915 r
.21865 .61327 m .21935 .61196 L .21678 .61226 L F
.629 .409 .564 r
.36185 .6274 m .36505 .62923 L .36385 .62455 L F
.022 .033 .529 r
.36385 .62455 m .36597 .62622 L .36609 .62356 L F
.785 .54 .565 r
.36548 .62345 m .36195 .62581 L .36256 .62291 L F
.36609 .62356 m .36551 .62388 L .36548 .62345 L F
.022 .033 .529 r
.36385 .62455 m .36505 .62923 L .3657 .62711 L F
.36385 .62455 m .3657 .62711 L .36563 .62595 L F
.785 .54 .565 r
.36551 .62388 m .36195 .62581 L .36548 .62345 L F
.022 .033 .529 r
.36563 .62595 m .3657 .62711 L .36597 .62622 L F
.495 .774 .994 r
.39351 .55431 m .3926 .55603 L .39106 .55475 L F
.39351 .55431 m .3926 .55603 L .39106 .55475 L F
.007 0 0 r
.3155 .57079 m .31383 .57098 L .31563 .56744 L F
.3155 .57079 m .31344 .57152 L .31383 .57098 L F
.408 .128 .373 r
.37503 .70013 m .3745 .70235 L .37221 .70293 L F
.379 .113 .378 r
.37717 .69947 m .3745 .70235 L .37503 .70013 L F
.809 .93 .913 r
.38269 .6599 m .3799 .66261 L .37838 .66181 L F
.801 .686 .739 r
.32814 .65327 m .32974 .65639 L .32659 .65638 L F
.75 .516 .576 r
.32974 .65639 m .32538 .65853 L .32659 .65638 L F
.55 .596 .852 r
.33054 .65295 m .32974 .65639 L .32814 .65327 L F
.33054 .65295 m .33355 .65667 L .32974 .65639 L F
.703 .667 .811 r
.33397 .57421 m .33512 .57563 L .33751 .57453 L F
.714 .422 .48 r
.33512 .57563 m .33786 .5768 L .33751 .57453 L F
.33512 .57563 m .33461 .57929 L .33786 .5768 L F
.424 .312 .621 r
.1851 .57784 m .1871 .57723 L .18679 .57454 L F
.309 .189 .55 r
.18552 .58067 m .1871 .57723 L .1851 .57784 L F
.642 .808 .963 r
.25174 .6206 m .25345 .62203 L .24941 .62155 L F
.406 .709 .985 r
.25402 .62045 m .25345 .62203 L .25174 .6206 L F
.36 .659 .97 r
.25402 .62045 m .2553 .622 L .25345 .62203 L F
.234 0 .218 r
.34622 .61235 m .34818 .61172 L .34921 .60967 L F
.194 .289 .735 r
.34622 .61235 m .34857 .61424 L .34818 .61172 L F
.968 .778 .592 r
.31105 .65652 m .30907 .65801 L .30927 .65568 L F
.31105 .65652 m .3109 .65901 L .30907 .65801 L F
0 0 0 r
.29334 .60974 m .29633 .60671 L .29515 .60843 L F
.29515 .60843 m .29633 .60671 L .29774 .60517 L F
.092 .351 .821 r
.31757 .56225 m .3195 .56542 L .32014 .56391 L F
.022 0 .095 r
.29008 .61229 m .28933 .61494 L .28764 .61521 L F
0 0 0 r
.28764 .61521 m .28933 .61494 L .28652 .61748 L F
.429 .403 .728 r
.22155 .5709 m .21973 .57177 L .21903 .56895 L F
.226 0 .326 r
.22155 .5709 m .21915 .57415 L .21973 .57177 L F
.376 .168 .466 r
.37987 .69379 m .37964 .69644 L .37754 .69705 L F
.451 .244 .507 r
.37964 .69644 m .37717 .69947 L .37754 .69705 L F
.319 .808 .841 r
.27402 .53495 m .27381 .53543 L .27525 .53502 L F
.457 .816 .545 r
.27536 .53382 m .27455 .53449 L .27402 .53495 L F
.319 .808 .841 r
.27402 .53495 m .27182 .53551 L .27344 .53545 L F
0 0 .011 r
.27232 .53636 m .27182 .53551 L .27402 .53495 L F
.457 .816 .545 r
.27455 .53449 m .27232 .53636 L .27402 .53495 L F
.319 .808 .841 r
.27402 .53495 m .27344 .53545 L .27381 .53543 L F
.433 .368 .685 r
.36221 .58115 m .36399 .5826 L .36417 .58049 L F
.61 .341 .485 r
.36221 .58115 m .36186 .58351 L .36399 .5826 L F
.363 .128 .417 r
.20786 .5779 m .20726 .58084 L .20523 .58119 L F
.432 .382 .702 r
.20726 .58084 m .20786 .58312 L .20523 .58119 L F
.478 .377 .662 r
.20523 .58119 m .20786 .58312 L .20587 .58374 L F
.323 .175 .519 r
.28655 .59995 m .2884 .60097 L .28935 .59844 L F
.28655 .59995 m .28691 .60275 L .2884 .60097 L F
.383 .131 .403 r
.21006 .57728 m .20726 .58084 L .20786 .5779 L F
0 0 0 r
.30268 .56782 m .30002 .57105 L .30113 .56899 L F
.763 .62 .701 r
.34163 .63684 m .34489 .63744 L .34496 .63466 L F
.711 .749 .882 r
.34496 .63466 m .34542 .63118 L .34295 .63183 L F
.34496 .63466 m .34772 .63401 L .34542 .63118 L F
.691 .56 .701 r
.34489 .63744 m .34772 .63401 L .34496 .63466 L F
.983 .806 .588 r
.34322 .63628 m .34489 .63744 L .34496 .63466 L F
0 0 0 r
.36646 .56808 m .36713 .56736 L .36799 .56499 L F
.854 .625 .591 r
.34308 .68762 m .33947 .68972 L .33891 .68755 L F
.34308 .68762 m .34286 .69048 L .33947 .68972 L F
.434 .463 .791 r
.32674 .56109 m .3279 .56495 L .32605 .56534 L F
.464 .418 .721 r
.3279 .56495 m .3264 .56742 L .32605 .56534 L F
.782 .859 .907 r
.3731 .66481 m .37128 .66647 L .3694 .66522 L F
.122 0 0 r
.72753 .33961 m .72948 .33939 L .73046 .33872 L F
.057 0 0 r
.72753 .33961 m .72855 .34002 L .72948 .33939 L F
0 0 0 r
.73046 .33872 m .72855 .34002 L .72948 .33939 L F
.033 0 0 r
.73046 .33872 m .72855 .34002 L .72753 .33961 L F
.423 .86 .924 r
.24552 .55208 m .24487 .55296 L .24715 .55254 L F
.24552 .55208 m .24322 .55282 L .24487 .55296 L F
.318 .755 .967 r
.19838 .60065 m .19423 .60001 L .19635 .60113 L F
.185 0 .194 r
.3088 .57753 m .3082 .57993 L .30617 .58075 L F
.002 0 .126 r
.30964 .57906 m .3088 .57753 L .31075 .57715 L F
.30964 .57906 m .3082 .57993 L .3088 .57753 L F
.295 .78 .908 r
.33927 .64085 m .33421 .64084 L .33947 .64384 L F
.596 .469 .678 r
.33947 .64384 m .34213 .63901 L .33927 .64085 L F
.501 .465 .749 r
.32003 .58385 m .32099 .58748 L .32342 .58666 L F
.404 .211 .501 r
.32099 .58748 m .32283 .5894 L .32342 .58666 L F
.513 .21 .389 r
.32019 .52454 m .32218 .52626 L .3222 .52328 L F
.342 .258 .615 r
.3222 .52328 m .32477 .52323 L .32272 .5227 L F
.316 .062 .361 r
.3222 .52328 m .32218 .52626 L .32477 .52323 L F
.049 0 .358 r
.29076 .63901 m .28935 .63721 L .29124 .6367 L F
.29076 .63901 m .28901 .64057 L .28935 .63721 L F
.713 .423 .484 r
.347 .62117 m .3475 .61888 L .34304 .61872 L F
.538 .199 .341 r
.34939 .62072 m .3475 .61888 L .347 .62117 L F
.34939 .62072 m .3475 .61888 L .347 .62117 L F
.462 .678 .958 r
.36399 .5826 m .36598 .5842 L .36729 .58251 L F
.766 .744 .833 r
.36186 .58351 m .36598 .5842 L .36399 .5826 L F
.538 .805 .995 r
.25234 .54309 m .25285 .54349 L .25462 .54268 L F
.19 .074 .481 r
.25285 .54349 m .253 .54374 L .25462 .54268 L F
.429 .403 .728 r
.22155 .5709 m .21903 .56895 L .22165 .5682 L F
.045 0 0 r
.29334 .60974 m .29221 .61193 L .29008 .61229 L F
.027 0 .098 r
.29108 .61361 m .29008 .61229 L .29221 .61193 L F
.29108 .61361 m .28933 .61494 L .29008 .61229 L F
0 0 .524 r
.32121 .57159 m .32262 .57398 L .32157 .57007 L F
.078 .075 .551 r
.32153 .57411 m .32262 .57398 L .32121 .57159 L F
.828 .954 .61 r
.39786 .56539 m .3962 .56694 L .39632 .56436 L F
.546 .32 .523 r
.36893 .61254 m .37136 .61196 L .37156 .60929 L F
.316 .132 .465 r
.37156 .60929 m .37349 .61034 L .37376 .60998 L F
.37156 .60929 m .37136 .61196 L .37349 .61034 L F
0 0 0 r
.28652 .61748 m .28328 .62018 L .28496 .61837 L F
.695 .246 .183 r
.34388 .63905 m .34489 .63744 L .34163 .63684 L F
.326 0 0 r
.3452 .63863 m .34489 .63744 L .34388 .63905 L F
.3452 .63863 m .34774 .63775 L .34489 .63744 L F
.572 .393 .6 r
.34489 .63744 m .34774 .63775 L .34772 .63401 L F
.147 .383 .834 r
.22046 .60105 m .2199 .60275 L .21794 .5995 L F
.057 .274 .766 r
.22046 .60105 m .22247 .60503 L .2199 .60275 L F
.379 .76 .99 r
.34579 .50815 m .34784 .50782 L .34954 .50884 L F
.34579 .50815 m .34784 .50782 L .34954 .50884 L F
.18 .543 .927 r
.35024 .50768 m .34954 .50884 L .34784 .50782 L F
.35024 .50768 m .35162 .50924 L .34954 .50884 L F
.836 .48 .381 r
.3316 .68406 m .33488 .68427 L .3348 .68645 L F
.697 .374 .426 r
.36625 .70302 m .36478 .70576 L .36247 .70314 L F
.646 .316 .399 r
.36843 .70538 m .36625 .70302 L .36871 .70382 L F
.36843 .70538 m .36478 .70576 L .36625 .70302 L F
.754 .667 .766 r
.35102 .53349 m .35308 .53706 L .35541 .53465 L F
.064 .149 .642 r
.35373 .53935 m .35477 .53918 L .35308 .53706 L F
.543 .458 .709 r
.3857 .66255 m .38628 .66527 L .38383 .66572 L F
.54 .442 .693 r
.38628 .66527 m .38435 .66893 L .38383 .66572 L F
.309 .083 .399 r
.33341 .55539 m .33537 .55498 L .33534 .55176 L F
.421 .523 .856 r
.33534 .55176 m .33739 .54963 L .33446 .54929 L F
.33534 .55176 m .33838 .55163 L .33739 .54963 L F
.581 .386 .583 r
.33537 .55498 m .33838 .55163 L .33534 .55176 L F
.583 .651 .882 r
.35917 .62824 m .36291 .62964 L .36185 .6274 L F
.495 .325 .579 r
.29768 .67579 m .3001 .67746 L .30123 .67541 L F
.37 .214 .536 r
.38728 .68956 m .38535 .68769 L .38771 .68714 L F
.38728 .68956 m .38534 .69048 L .38535 .68769 L F
.324 0 0 r
.27018 .54889 m .26917 .54973 L .26675 .54993 L F
.353 0 0 r
.27281 .54857 m .26917 .54973 L .27018 .54889 L F
.424 .865 .796 r
.36796 .58109 m .3707 .58018 L .36849 .58003 L F
.705 .405 .466 r
.28295 .63037 m .28434 .62793 L .28075 .62814 L F
.671 .365 .447 r
.28295 .63037 m .28663 .63043 L .28434 .62793 L F
.65 .367 .477 r
.28663 .63043 m .28722 .62809 L .28434 .62793 L F
.335 .572 .927 r
.30156 .65171 m .30237 .65332 L .3035 .65176 L F
0 0 .545 r
.30237 .65332 m .30374 .65423 L .3035 .65176 L F
.454 .579 .889 r
.30237 .65332 m .30643 .65592 L .30339 .65547 L F
0 0 .545 r
.30237 .65332 m .30339 .65547 L .30374 .65423 L F
.596 .41 .6 r
.2243 .56512 m .22165 .5682 L .22165 .56552 L F
0 .051 .598 r
.33045 .60263 m .33154 .60676 L .3321 .60457 L F
.832 .839 .852 r
.37067 .65562 m .37543 .65419 L .37272 .65448 L F
.37067 .65562 m .37047 .65649 L .37543 .65419 L F
.364 .835 .85 r
.37492 .65384 m .37543 .65419 L .37658 .65265 L F
.37492 .65384 m .37272 .65448 L .37543 .65419 L F
.458 0 0 r
.26063 .63403 m .2626 .63436 L .26481 .63547 L F
.529 .339 .568 r
.31618 .56754 m .3155 .57079 L .31563 .56744 L F
.057 0 0 r
.31267 .56782 m .31618 .56754 L .31563 .56744 L F
0 0 0 r
.29387 .61064 m .29334 .60974 L .29515 .60843 L F
.29387 .61064 m .29221 .61193 L .29334 .60974 L F
.808 .612 .637 r
.33311 .53735 m .33342 .54055 L .32991 .53961 L F
.504 .387 .654 r
.33557 .53946 m .33311 .53735 L .33598 .53698 L F
.33557 .53946 m .33342 .54055 L .33311 .53735 L F
0 0 0 r
.28363 .60954 m .28053 .61263 L .28276 .61193 L F
.28617 .60627 m .28363 .60954 L .28552 .60877 L F
.091 0 .038 r
.28433 .6104 m .28363 .60954 L .28276 .61193 L F
.28433 .6104 m .28552 .60877 L .28363 .60954 L F
.735 .704 .822 r
.21359 .58792 m .21059 .59052 L .20862 .58736 L F
0 0 0 r
.35967 .54529 m .35777 .54654 L .3604 .54375 L F
.249 .023 .362 r
.35965 .54752 m .35777 .54654 L .35967 .54529 L F
.84 .854 .854 r
.38096 .62763 m .38019 .63085 L .37676 .63046 L F
.51 .292 .52 r
.37787 .63021 m .37534 .63073 L .37558 .62808 L F
.37787 .63021 m .37534 .63073 L .37558 .62808 L F
.649 .557 .737 r
.33377 .5716 m .3364 .57138 L .33593 .56871 L F
.72 .607 .73 r
.33397 .57421 m .3364 .57138 L .33377 .5716 L F
0 .236 .754 r
.36977 .57204 m .37131 .57196 L .368 .57056 L F
.36977 .57204 m .37193 .57359 L .37131 .57196 L F
.031 .558 .86 r
.29869 .63378 m .29649 .63265 L .29681 .63354 L F
.348 .688 .981 r
.22554 .61059 m .22514 .61197 L .22336 .60872 L F
.22554 .61059 m .22727 .61195 L .22514 .61197 L F
.822 .426 0 r
.7205 .29679 m .72185 .29878 L .7213 .29874 L F
.597 .662 .884 r
.72279 .29499 m .72185 .29878 L .7205 .29679 L F
.72279 .29499 m .72451 .29801 L .72185 .29878 L F
.031 0 0 r
.72185 .29878 m .72342 .29898 L .7213 .29874 L F
.72185 .29878 m .72451 .29801 L .72342 .29898 L F
.55 .069 .066 r
.34921 .51526 m .34878 .51738 L .3483 .51538 L F
.113 0 0 r
.34969 .51519 m .34921 .51526 L .34667 .51509 L F
.48 .672 .949 r
.34667 .51509 m .34921 .51526 L .3477 .51288 L F
.55 .069 .066 r
.34921 .51526 m .3483 .51538 L .3477 .51288 L F
.113 0 0 r
.35093 .51523 m .34921 .51526 L .34969 .51519 L F
.31 0 .004 r
.3325 .63183 m .33568 .63063 L .33344 .63137 L F
.495 .306 .553 r
.33401 .63227 m .33568 .63063 L .33344 .63137 L F
.33401 .63227 m .33425 .63232 L .33568 .63063 L F
.571 .502 .739 r
.33418 .6324 m .33449 .63443 L .3339 .63273 L F
.33568 .63063 m .33516 .6323 L .33418 .6324 L F
.33516 .6323 m .33449 .63443 L .33418 .6324 L F
.33568 .63063 m .33694 .63389 L .33449 .63443 L F
.14 0 0 r
.33449 .63443 m .33575 .63509 L .33616 .63643 L F
.33449 .63443 m .33694 .63389 L .33575 .63509 L F
.184 .183 .623 r
.33616 .63643 m .33519 .63751 L .33449 .63443 L F
.503 .183 .358 r
.33575 .63509 m .33409 .63241 L .33136 .63534 L F
.33409 .63241 m .33401 .63227 L .33387 .63243 L F
.33409 .63241 m .33387 .63243 L .33136 .63534 L F
.454 .073 .226 r
.33568 .63063 m .33767 .6324 L .33694 .63389 L F
.495 .306 .553 r
.33425 .63232 m .337 .63291 L .33568 .63063 L F
.503 .183 .358 r
.33575 .63509 m .337 .63291 L .33425 .63232 L F
.33409 .63241 m .33425 .63232 L .33401 .63227 L F
.33575 .63509 m .33425 .63232 L .33409 .63241 L F
.571 .502 .739 r
.33568 .63063 m .33425 .63232 L .33344 .63137 L F
.33425 .63232 m .3339 .63273 L .33385 .63255 L F
.33425 .63232 m .33385 .63255 L .33344 .63137 L F
.411 .297 .612 r
.32987 .58666 m .32966 .58938 L .32728 .58763 L F
.796 .442 .387 r
.35672 .66469 m .36061 .66554 L .35867 .66818 L F
0 0 .482 r
.35672 .66469 m .35867 .66818 L .35806 .66674 L F
.807 .66 .7 r
.36 .66224 m .35672 .66469 L .3577 .66306 L F
.36 .66224 m .36061 .66554 L .35672 .66469 L F
0 0 .482 r
.35672 .66469 m .35806 .66674 L .35689 .66398 L F
0 0 0 r
.35575 .66492 m .35644 .66427 L .35672 .66469 L F
.35644 .66427 m .3577 .66306 L .35672 .66469 L F
.306 .563 .928 r
.34542 .63118 m .34772 .63401 L .34842 .63218 L F
.053 .256 .751 r
.34772 .63401 m .35003 .63617 L .34842 .63218 L F
.491 .329 .588 r
.34772 .63401 m .34774 .63775 L .35003 .63617 L F
0 0 0 r
.29934 .60229 m .29868 .60326 L .30072 .59981 L F
.29774 .60517 m .29868 .60326 L .29934 .60229 L F
.621 .21 0 r
.39669 .54236 m .39854 .54542 L .39707 .54292 L F
.32 .092 .403 r
.3947 .6745 m .39205 .6777 L .39217 .67519 L F
.495 .105 .23 r
.37221 .70293 m .36843 .70538 L .36871 .70382 L F
0 0 0 r
.38212 .64643 m .37898 .64881 L .37948 .64726 L F
.346 .722 .985 r
.21252 .61157 m .21319 .61052 L .2108 .61043 L F
.21252 .61157 m .2149 .61166 L .21319 .61052 L F
.403 .429 .773 r
.36291 .62964 m .36505 .62923 L .36185 .6274 L F
.36291 .62964 m .3654 .63056 L .36505 .62923 L F
.648 .62 .807 r
.13696 .73359 m .1374 .73527 L .13419 .7347 L F
.542 .014 0 r
.13419 .7347 m .1374 .73527 L .13519 .73595 L F
.167 0 0 r
.13497 .73549 m .13696 .73359 L .13419 .7347 L F
0 0 .483 r
.13497 .73549 m .13419 .7347 L .13519 .73595 L F
.135 0 0 r
.33423 .53128 m .33898 .53217 L .33752 .53189 L F
0 .064 .604 r
.33752 .53189 m .33897 .53158 L .34072 .53148 L F
.33752 .53189 m .33898 .53217 L .33897 .53158 L F
.699 .425 .505 r
.39419 .59569 m .39199 .59989 L .39024 .59854 L F
.39199 .59989 m .39143 .60096 L .39065 .59938 L F
.39199 .59989 m .39065 .59938 L .39024 .59854 L F
.28 .239 .633 r
.39024 .59854 m .39065 .59938 L .39104 .59896 L F
.823 .739 .771 r
.38855 .5986 m .38855 .5986 L .39024 .59854 L F
.38855 .5986 m .39164 .59645 L .39024 .59854 L F
0 0 0 r
.3854 .59976 m .38348 .60141 L .38223 .60175 L F
.729 .709 .832 r
.38407 .59718 m .3854 .59976 L .38855 .5986 L F
.977 .742 .515 r
.38407 .59718 m .38348 .60141 L .3854 .59976 L F
.729 .709 .832 r
.38407 .59718 m .38855 .5986 L .38707 .59579 L F
.282 .323 .727 r
.38855 .5986 m .38916 .59464 L .38707 .59579 L F
.38855 .5986 m .39024 .59854 L .38916 .59464 L F
.292 0 .014 r
.39106 .59899 m .38597 .60226 L .38407 .59718 L F
.39147 .59909 m .39123 .59923 L .39106 .59899 L F
.51 .612 .89 r
.39124 .59882 m .39147 .59909 L .39106 .59899 L F
.28 .239 .633 r
.39065 .59938 m .39093 .59995 L .3913 .59928 L F
.292 0 .014 r
.39123 .59923 m .39039 .60017 L .38941 .60028 L F
.39133 .59924 m .38947 .6012 L .39123 .59923 L F
.28 .239 .633 r
.39065 .59938 m .39146 .59926 L .3909 .59918 L F
.39086 .59918 m .3909 .59918 L .39087 .59917 L F
.39065 .59938 m .3909 .59918 L .39086 .59918 L F
.292 0 .014 r
.39147 .59909 m .39133 .59924 L .39123 .59923 L F
.78 .949 .614 r
.3914 .59911 m .39133 .59924 L .39147 .59909 L F
.292 0 .014 r
.39123 .59923 m .39117 .59926 L .3912 .59918 L F
.39117 .59926 m .38597 .60226 L .3912 .59918 L F
.3912 .59918 m .38597 .60226 L .39106 .59899 L F
.78 .949 .614 r
.39072 .59933 m .39133 .59924 L .3914 .59911 L F
0 0 .044 r
.39164 .59645 m .3947 .59313 L .39419 .59569 L F
.699 .425 .505 r
.39419 .59569 m .39024 .59854 L .39164 .59645 L F
.1 0 .152 r
.39508 .59744 m .39143 .60096 L .39419 .59569 L F
.63 .53 .722 r
.39152 .59447 m .39146 .59898 L .39508 .59744 L F
.39146 .59898 m .39154 .59907 L .39508 .59744 L F
.39146 .59911 m .39143 .60096 L .39373 .59874 L F
.78 .949 .614 r
.3914 .59911 m .39147 .59909 L .3916 .59909 L F
.63 .53 .722 r
.39146 .59911 m .39373 .59874 L .39508 .59744 L F
.28 .239 .633 r
.3912 .59878 m .39146 .5986 L .39147 .5985 L F
.39065 .59938 m .39124 .59882 L .3912 .59878 L F
.39124 .59882 m .39146 .5986 L .3912 .59878 L F
.39036 .59814 m .39147 .5985 L .39152 .59447 L F
.39024 .59854 m .39086 .59852 L .39036 .59814 L F
.39086 .59852 m .39147 .5985 L .39036 .59814 L F
.503 .422 .698 r
.38916 .59464 m .38707 .59579 L .38645 .59281 L F
.626 .914 .98 r
.38718 .59387 m .38707 .59579 L .38916 .59464 L F
.28 .239 .633 r
.39024 .59854 m .39152 .59447 L .38916 .59464 L F
0 .185 .708 r
.3915 .59901 m .39092 .59842 L .38718 .59387 L F
.39156 .59909 m .39146 .59898 L .3915 .59901 L F
.39156 .59909 m .39147 .59909 L .39124 .59882 L F
.28 .239 .633 r
.39087 .59917 m .39146 .59926 L .39146 .59898 L F
.39124 .59882 m .39146 .59898 L .39146 .5986 L F
0 .185 .708 r
.39156 .59909 m .39124 .59882 L .39146 .59898 L F
.28 .239 .633 r
.39087 .59917 m .39146 .59898 L .39124 .59882 L F
.39074 .59852 m .39104 .59896 L .39147 .5985 L F
0 .185 .708 r
.39146 .59898 m .39124 .59882 L .39092 .59842 L F
.39146 .59898 m .39092 .59842 L .3915 .59901 L F
.499 .414 .691 r
.3922 .5952 m .39122 .59792 L .3924 .59907 L F
0 .185 .708 r
.3924 .59907 m .3916 .59909 L .38836 .59526 L F
.39122 .59792 m .38836 .59526 L .38771 .5945 L F
.3924 .59907 m .38836 .59526 L .39122 .59792 L F
.499 .414 .691 r
.3922 .5952 m .39335 .59913 L .39259 .59919 L F
0 .185 .708 r
.3916 .59909 m .39156 .59909 L .3915 .59901 L F
.3916 .59909 m .3915 .59901 L .38718 .59387 L F
.63 .53 .722 r
.39146 .59898 m .39146 .59911 L .39154 .59907 L F
.78 .949 .614 r
.39072 .59933 m .39138 .59912 L .3924 .59907 L F
.39138 .59912 m .3914 .59911 L .39142 .59911 L F
.39138 .59912 m .39142 .59911 L .3924 .59907 L F
.3914 .59911 m .3916 .59909 L .3924 .59907 L F
.28 .239 .633 r
.39024 .59854 m .39104 .59896 L .39074 .59852 L F
.621 .435 .609 r
.38707 .59579 m .38404 .59337 L .38645 .59281 L F
.38707 .59579 m .38407 .59715 L .38404 .59337 L F
.426 .443 .774 r
.38404 .59337 m .38707 .59579 L .38645 .59281 L F
0 0 0 r
.38407 .59718 m .38407 .59715 L .38707 .59579 L F
0 0 .307 r
.38718 .59387 m .38707 .59579 L .38695 .59521 L F
.38718 .59387 m .38695 .59521 L .38645 .59281 L F
.503 .422 .698 r
.38916 .59464 m .38645 .59281 L .38901 .59228 L F
0 0 .307 r
.38718 .59387 m .38645 .59281 L .38901 .59228 L F
.483 .594 .888 r
.38916 .59464 m .3898 .59242 L .38901 .59228 L F
.217 0 0 r
.38952 .59358 m .38718 .59387 L .38901 .59228 L F
.373 .778 .984 r
.38727 .59332 m .38718 .59387 L .38952 .59358 L F
.38566 .59314 m .38718 .59387 L .38727 .59332 L F
.51 .612 .89 r
.38718 .59387 m .38407 .59718 L .38707 .59579 L F
.38718 .59387 m .39124 .59882 L .38645 .59779 L F
.39124 .59882 m .39106 .59899 L .38645 .59779 L F
.499 .414 .691 r
.39122 .59792 m .39072 .59933 L .3924 .59907 L F
.39122 .59792 m .39259 .59919 L .39072 .59933 L F
.749 .41 .41 r
.39192 .59816 m .3922 .5952 L .3924 .59907 L F
.499 .414 .691 r
.3922 .5952 m .39247 .59799 L .39194 .59796 L F
.3922 .5952 m .39194 .59796 L .39122 .59792 L F
.483 .594 .888 r
.38916 .59464 m .39152 .59447 L .3898 .59242 L F
.749 .41 .41 r
.38952 .59358 m .3922 .5952 L .39192 .59816 L F
0 .185 .708 r
.39192 .59816 m .38718 .59387 L .38952 .59358 L F
.3924 .59907 m .39159 .59826 L .39192 .59816 L F
.499 .414 .691 r
.39247 .59799 m .39159 .59826 L .39122 .59792 L F
0 .185 .708 r
.39159 .59826 m .38718 .59387 L .39192 .59816 L F
.499 .414 .691 r
.39247 .59799 m .39259 .59919 L .39159 .59826 L F
0 .185 .708 r
.3924 .59907 m .38771 .5945 L .38718 .59387 L F
.78 .949 .614 r
.39072 .59933 m .38947 .6012 L .39133 .59924 L F
.428 .71 .982 r
.39335 .59913 m .39297 .5999 L .39072 .59933 L F
.39297 .5999 m .39249 .60088 L .39154 .60005 L F
.28 .239 .633 r
.3913 .59928 m .39143 .60096 L .39146 .59926 L F
.428 .71 .982 r
.39297 .5999 m .39154 .60005 L .39072 .59933 L F
.292 0 .014 r
.38941 .60028 m .38952 .60114 L .38597 .60226 L F
.39039 .60017 m .38952 .60114 L .38941 .60028 L F
.38952 .60114 m .38947 .6012 L .38934 .60124 L F
.38952 .60114 m .38934 .60124 L .38597 .60226 L F
.665 .369 .462 r
.39249 .60088 m .38853 .60282 L .38961 .6011 L F
.28 .239 .633 r
.39093 .59995 m .39143 .60096 L .3913 .59928 L F
.665 .369 .462 r
.39154 .60005 m .38961 .6011 L .39072 .59933 L F
.39249 .60088 m .38961 .6011 L .39154 .60005 L F
.51 .612 .89 r
.38427 .59697 m .38645 .59779 L .38407 .59718 L F
.38718 .59387 m .38645 .59779 L .38427 .59697 L F
.364 .141 .437 r
.21556 .58433 m .21359 .58792 L .21565 .58652 L F
.21565 .58415 m .21359 .58792 L .21565 .58652 L F
.735 .704 .822 r
.21359 .58792 m .20862 .58736 L .21159 .589 L F
0 0 0 r
.21159 .589 m .21565 .58652 L .21359 .58792 L F
.21159 .589 m .21335 .58842 L .21475 .58727 L F
.21419 .58741 m .21475 .58727 L .21565 .58652 L F
.21159 .589 m .21475 .58727 L .21419 .58741 L F
.267 .423 .832 r
.21573 .58837 m .21579 .5886 L .21565 .58652 L F
.21538 .58711 m .21713 .58929 L .21579 .5886 L F
.928 .972 .708 r
.21565 .58652 m .21475 .58727 L .21511 .58608 L F
.21475 .58727 m .21335 .58842 L .21482 .58647 L F
.21475 .58727 m .21482 .58647 L .21511 .58608 L F
.267 .423 .832 r
.21538 .58711 m .21573 .58837 L .21567 .58704 L F
.21538 .58711 m .21567 .58704 L .21565 .58652 L F
.21482 .58509 m .21538 .58711 L .21565 .58652 L F
.21492 .58544 m .21586 .58699 L .21538 .58711 L F
.974 .906 .564 r
.21603 .58248 m .21511 .58608 L .21482 .58509 L F
.21603 .58248 m .21511 .58608 L .21482 .58509 L F
.267 .423 .832 r
.21482 .58509 m .21494 .58529 L .21492 .58544 L F
.364 .141 .437 r
.21565 .58415 m .21556 .58433 L .21565 .58652 L F
.973 .906 .56 r
.21565 .58652 m .21511 .58608 L .21603 .58248 L F
.267 .423 .832 r
.21494 .58529 m .21586 .58699 L .21492 .58544 L F
.21586 .58699 m .21713 .58929 L .21538 .58711 L F
.419 .226 .51 r
.382 .69317 m .37964 .69644 L .37987 .69379 L F
.46 .833 .591 r
.37324 .58378 m .37295 .58413 L .37362 .58308 L F
.37324 .58378 m .37073 .58575 L .37295 .58413 L F
.996 .766 .461 r
.33838 .55163 m .33998 .55553 L .34288 .55443 L F
.33838 .55163 m .33826 .55463 L .33998 .55553 L F
.259 .752 .674 r
.34288 .55443 m .33998 .55553 L .34273 .5545 L F
.464 .418 .721 r
.3279 .56495 m .32868 .56704 L .3264 .56742 L F
.377 .423 .782 r
.32963 .57103 m .3264 .56742 L .32868 .56704 L F
.632 .252 .305 r
.37713 .59033 m .3789 .59235 L .38016 .58595 L F
.37713 .59033 m .37605 .59243 L .3789 .59235 L F
.351 .492 .86 r
.34465 .51417 m .34597 .51278 L .34276 .51307 L F
.34465 .51417 m .34667 .51509 L .34597 .51278 L F
.499 .556 .845 r
.3231 .64614 m .32542 .6506 L .32697 .64939 L F
.73 .722 .844 r
.32424 .65245 m .32542 .6506 L .32697 .64939 L F
0 0 0 r
.34921 .60967 m .34818 .61172 L .35047 .60852 L F
.425 .132 .361 r
.38695 .59074 m .38645 .59281 L .38404 .59337 L F
.38695 .59074 m .38645 .59281 L .38404 .59337 L F
.474 .304 .57 r
.38917 .5868 m .38695 .59074 L .38927 .58994 L F
.461 .164 .374 r
.38901 .59228 m .38695 .59074 L .38927 .58994 L F
.38901 .59228 m .38645 .59281 L .38695 .59074 L F
.474 .304 .57 r
.38917 .5868 m .38695 .59074 L .38927 .58994 L F
.461 .164 .374 r
.38901 .59228 m .38695 .59074 L .38927 .58994 L F
.38901 .59228 m .38645 .59281 L .38695 .59074 L F
0 .177 .711 r
.22197 .61443 m .22223 .61583 L .22241 .61412 L F
0 .117 .659 r
.22223 .61583 m .22325 .61601 L .22241 .61412 L F
.22223 .61583 m .22435 .61782 L .22325 .61601 L F
.649 .443 .592 r
.35047 .60852 m .35369 .60497 L .35002 .60481 L F
.568 .354 .55 r
.36104 .60603 m .36272 .60812 L .36168 .60764 L F
.36104 .60603 m .36358 .60572 L .36272 .60812 L F
.36272 .60812 m .36358 .60572 L .36104 .60603 L F
.714 .364 .383 r
.36168 .60764 m .36272 .60812 L .36104 .60603 L F
.36168 .60764 m .36272 .60812 L .36104 .60603 L F
.289 .476 .87 r
.27691 .64043 m .28018 .64384 L .27836 .643 L F
.709 .6 .732 r
.28362 .55256 m .28466 .55598 L .28688 .55273 L F
.544 .925 .912 r
.24045 .53351 m .23677 .53466 L .23783 .53385 L F
.455 .886 .861 r
.24259 .53253 m .24045 .53351 L .23876 .53373 L F
.24259 .53253 m .23876 .53373 L .2389 .53355 L F
.24259 .53253 m .23783 .53385 L .24138 .5331 L F
0 0 0 r
.24369 .53248 m .24259 .53253 L .24138 .5331 L F
.39 .84 .922 r
.24369 .53248 m .24138 .5331 L .2394 .53292 L F
.23948 .53282 m .2394 .53292 L .23892 .53287 L F
.24369 .53248 m .2394 .53292 L .23948 .53282 L F
.455 .886 .861 r
.2389 .53355 m .23876 .53373 L .23783 .53385 L F
0 0 0 r
.21393 .54654 m .2114 .54971 L .21291 .54816 L F
.113 0 0 r
.2114 .54971 m .21205 .55082 L .21291 .54816 L F
.2114 .54971 m .20985 .5516 L .21205 .55082 L F
0 .248 .76 r
.31832 .65901 m .31719 .65905 L .3153 .65574 L F
0 0 0 r
.31544 .66048 m .31719 .65905 L .31832 .65901 L F
.135 .027 .455 r
.22004 .5927 m .21918 .59627 L .21826 .59665 L F
.449 .307 .596 r
.21918 .59627 m .21794 .5995 L .21826 .59665 L F
.347 .115 .413 r
.28725 .53979 m .28967 .53912 L .28982 .53642 L F
.387 .254 .576 r
.28725 .54272 m .28967 .53912 L .28725 .53979 L F
.695 .154 0 r
.38013 .52057 m .3843 .52321 L .38166 .52242 L F
.26 .767 .757 r
.30546 .52299 m .30588 .52272 L .31001 .52185 L F
.603 .952 .886 r
.31001 .52185 m .31073 .52059 L .31216 .52057 L F
.31001 .52185 m .30588 .52272 L .31073 .52059 L F
.975 .718 .482 r
.31842 .52566 m .3195 .52668 L .32019 .52454 L F
.759 .984 .906 r
.32272 .5227 m .32039 .52284 L .32019 .52454 L F
.842 .985 .705 r
.32039 .52284 m .31842 .52566 L .32019 .52454 L F
.532 .205 .358 r
.32019 .52454 m .3195 .52668 L .32218 .52626 L F
.699 .921 .589 r
.30824 .6572 m .30927 .65568 L .30643 .65592 L F
.541 .308 .511 r
.38122 .67167 m .3811 .67434 L .37874 .67236 L F
.063 0 .184 r
.28919 .59601 m .29121 .59528 L .29191 .59321 L F
.302 .143 .493 r
.28935 .59844 m .29121 .59528 L .28919 .59601 L F
0 0 0 r
.317 .5579 m .31897 .55731 L .32069 .55666 L F
.64 .957 .776 r
.32069 .55666 m .32177 .55511 L .32351 .55531 L F
.451 .341 .637 r
.28982 .53642 m .29201 .53322 L .28944 .53384 L F
.28982 .53642 m .29249 .53657 L .29201 .53322 L F
.145 0 .118 r
.28967 .53912 m .29249 .53657 L .28982 .53642 L F
.187 0 .311 r
.27329 .62506 m .27288 .62734 L .27072 .6284 L F
0 0 .469 r
.27201 .62995 m .27072 .6284 L .27288 .62734 L F
.27201 .62995 m .27133 .63148 L .27072 .6284 L F
.369 .353 .71 r
.20813 .5848 m .20646 .58772 L .20587 .58374 L F
.497 .513 .803 r
.20813 .5848 m .20862 .58736 L .20646 .58772 L F
.546 .236 .394 r
.39637 .5922 m .39696 .593 L .3947 .59313 L F
.61 .507 .712 r
.39873 .5909 m .39696 .593 L .39637 .5922 L F
0 0 .177 r
.26551 .53789 m .26446 .53724 L .26611 .53633 L F
.26546 .53786 m .26369 .53963 L .26446 .53724 L F
.26545 .53795 m .26369 .53963 L .26546 .53786 L F
.053 0 0 r
.26527 .53834 m .26369 .53963 L .26545 .53795 L F
.712 .363 .384 r
.26227 .53643 m .26528 .53833 L .2648 .53648 L F
.122 0 0 r
.26822 .53843 m .2676 .53878 L .26658 .53835 L F
.26733 .53826 m .26658 .53835 L .26551 .53789 L F
.26822 .53843 m .26658 .53835 L .26733 .53826 L F
.2676 .53878 m .26644 .53854 L .26551 .53789 L F
.26714 .53904 m .26533 .53829 L .26534 .53827 L F
.2669 .53887 m .26534 .53827 L .26551 .53789 L F
.26714 .53904 m .26534 .53827 L .2669 .53887 L F
.628 .256 .319 r
.26611 .53633 m .26797 .53818 L .26551 .53789 L F
.26797 .53818 m .26822 .53843 L .26733 .53826 L F
.26797 .53818 m .26733 .53826 L .26551 .53789 L F
.559 .267 .428 r
.26866 .53611 m .26822 .53843 L .26611 .53633 L F
.474 .153 .342 r
.27182 .53551 m .26822 .53843 L .26866 .53611 L F
.544 .485 .739 r
.26558 .53837 m .26884 .53795 L .26713 .53508 L F
.26552 .53848 m .26578 .53844 L .26558 .53837 L F
.26578 .53844 m .26884 .53795 L .26558 .53837 L F
.26547 .53834 m .26552 .53826 L .26545 .53827 L F
.26552 .53826 m .26713 .53508 L .26545 .53827 L F
0 0 .177 r
.26551 .53789 m .26545 .53795 L .26546 .53786 L F
.079 0 0 r
.26611 .53633 m .2648 .53648 L .26227 .53643 L F
.26611 .53633 m .2648 .53648 L .26227 .53643 L F
.57 .94 .857 r
.26713 .53508 m .2648 .53648 L .26611 .53633 L F
.26713 .53508 m .2648 .53648 L .26611 .53633 L F
.544 .485 .739 r
.26545 .53827 m .26713 .53508 L .2648 .53648 L F
.26552 .53848 m .26558 .53837 L .26547 .53834 L F
.26558 .53837 m .26713 .53508 L .26547 .53834 L F
.793 .533 .543 r
.26537 .53849 m .26578 .53844 L .26552 .53848 L F
.712 .363 .384 r
.26528 .53833 m .26552 .53848 L .26547 .53834 L F
.26528 .53833 m .26547 .53834 L .26533 .53829 L F
.26524 .53844 m .2652 .53853 L .26535 .53851 L F
.26537 .53839 m .26535 .53851 L .26552 .53848 L F
.122 0 0 r
.26482 .54034 m .26489 .53926 L .26533 .53829 L F
.053 0 0 r
.26426 .54065 m .26378 .53979 L .26492 .53868 L F
.26519 .53854 m .26492 .53868 L .26527 .53834 L F
.26426 .54065 m .26492 .53868 L .26519 .53854 L F
.26426 .54065 m .26519 .53854 L .26489 .53926 L F
.26519 .53854 m .26545 .53795 L .2652 .53853 L F
.26519 .53854 m .2652 .53853 L .26489 .53926 L F
.712 .363 .384 r
.26227 .53643 m .25939 .53944 L .2652 .53853 L F
0 0 .409 r
.25939 .53944 m .26524 .53851 L .26494 .53858 L F
.122 0 0 r
.26568 .53843 m .26528 .53851 L .26533 .53829 L F
0 0 .409 r
.26524 .53851 m .26537 .53849 L .26523 .53852 L F
.26524 .53851 m .26523 .53852 L .26494 .53858 L F
.712 .363 .384 r
.26227 .53643 m .2652 .53853 L .26524 .53844 L F
.289 .263 .655 r
.25927 .53718 m .2597 .53917 L .2577 .5378 L F
0 0 .409 r
.25939 .53944 m .25993 .53907 L .26527 .5385 L F
.25939 .53944 m .26527 .5385 L .26524 .53851 L F
.25939 .53944 m .25983 .5398 L .26041 .53875 L F
.289 .263 .655 r
.2597 .53917 m .25983 .5398 L .25932 .53933 L F
.2597 .53917 m .25932 .53933 L .2577 .5378 L F
0 0 .409 r
.25993 .53907 m .26041 .53875 L .26074 .53873 L F
.25993 .53907 m .26074 .53873 L .26527 .5385 L F
.26524 .53851 m .26527 .5385 L .26537 .53849 L F
.26494 .53858 m .26537 .53849 L .26552 .53848 L F
.122 0 0 r
.26714 .53904 m .26482 .54034 L .26528 .53851 L F
.26714 .53904 m .26528 .53851 L .26568 .53843 L F
.26482 .54034 m .26426 .54065 L .26489 .53926 L F
.712 .363 .384 r
.26497 .53813 m .26535 .53851 L .26537 .53839 L F
.26227 .53643 m .26496 .53825 L .26497 .53813 L F
.26496 .53825 m .26535 .53851 L .26497 .53813 L F
.26533 .53829 m .26547 .53834 L .26542 .5382 L F
.26528 .53833 m .26542 .5382 L .2648 .53648 L F
.053 0 0 r
.26378 .53979 m .26369 .53963 L .26527 .53834 L F
.26523 .53851 m .26545 .53795 L .26551 .53789 L F
.26489 .53926 m .26521 .53852 L .26523 .53851 L F
.26521 .53852 m .26545 .53795 L .26523 .53851 L F
.793 .533 .543 r
.26542 .53845 m .26884 .53795 L .26591 .53842 L F
.26041 .53875 m .26624 .53819 L .26542 .53845 L F
.26624 .53819 m .26884 .53795 L .26542 .53845 L F
.26568 .53845 m .26591 .53842 L .26578 .53844 L F
.26041 .53875 m .26591 .53842 L .26568 .53845 L F
.26041 .53875 m .26578 .53844 L .26537 .53849 L F
.122 0 0 r
.2676 .53878 m .26714 .53904 L .26644 .53854 L F
.509 .499 .781 r
.25673 .74647 m .25782 .75043 L .25516 .75034 L F
.25673 .74647 m .25516 .75034 L .25604 .74965 L F
.213 .688 .937 r
.25604 .74965 m .25782 .75043 L .25516 .75034 L F
.093 0 .062 r
.21291 .54816 m .21581 .5455 L .21393 .54654 L F
.367 .106 .38 r
.39031 .6813 m .38973 .68364 L .38762 .68426 L F
.321 .104 .421 r
.39212 .68048 m .38973 .68364 L .39031 .6813 L F
.64 .949 .948 r
.35848 .66947 m .35386 .67058 L .35668 .66896 L F
.548 .902 .972 r
.3606 .66846 m .35848 .66947 L .35668 .66896 L F
0 0 .153 r
.36254 .61513 m .36119 .61811 L .36215 .61757 L F
0 0 .295 r
.36215 .61757 m .36119 .61811 L .36183 .62055 L F
0 .006 .578 r
.38378 .61329 m .3821 .61213 L .38266 .60906 L F
.38378 .61329 m .38373 .61439 L .3821 .61213 L F
.656 .564 .739 r
.33718 .64679 m .33947 .64384 L .33421 .64084 L F
.33718 .64679 m .34008 .64675 L .33947 .64384 L F
.574 .644 .881 r
.33315 .64919 m .33378 .64965 L .3353 .6513 L F
.33378 .64965 m .33728 .65218 L .3353 .6513 L F
.947 .904 .748 r
.3353 .6513 m .33728 .65218 L .33521 .65577 L F
.3353 .6513 m .33521 .65577 L .3349 .6538 L F
.375 .148 .437 r
.33619 .65227 m .3353 .6513 L .3349 .6538 L F
.33759 .6506 m .3353 .6513 L .33619 .65227 L F
0 0 0 r
.33592 .65054 m .33663 .64948 L .3353 .6513 L F
.632 .372 .506 r
.33951 .64933 m .33789 .64757 L .33663 .64948 L F
.704 .882 .964 r
.3379 .64809 m .33951 .64933 L .33663 .64948 L F
0 0 0 r
.3379 .64809 m .33663 .64948 L .33592 .65054 L F
.632 .372 .506 r
.33789 .64757 m .33718 .64679 L .33663 .64948 L F
.33951 .64933 m .34008 .64675 L .33718 .64679 L F
.468 .157 .355 r
.36264 .54283 m .35967 .54529 L .3604 .54375 L F
.419 .754 .995 r
.32537 .5548 m .32696 .55598 L .32351 .55531 L F
.078 0 .247 r
.3023 .5988 m .30072 .59981 L .30288 .59645 L F
0 0 0 r
.30208 .60059 m .30072 .59981 L .3023 .5988 L F
.30208 .60059 m .29934 .60229 L .30072 .59981 L F
0 .091 .648 r
.38821 .52657 m .39008 .52986 L .38879 .52819 L F
.797 .58 .607 r
.35934 .5841 m .35947 .58689 L .35545 .58636 L F
.35934 .5841 m .35545 .58636 L .35814 .58544 L F
.532 .373 .611 r
.35934 .5841 m .35947 .58689 L .36186 .58351 L F
.869 .868 .835 r
.35814 .58544 m .36186 .58351 L .35934 .5841 L F
.088 .237 .723 r
.39415 .53552 m .39538 .53932 L .39411 .53759 L F
.376 .279 .616 r
.18652 .57188 m .18845 .57374 L .18889 .57045 L F
.18652 .57188 m .18679 .57454 L .18845 .57374 L F
0 0 0 r
.3906 .67141 m .3925 .6706 L .39419 .66893 L F
.39419 .66893 m .39499 .66964 L .39651 .66825 L F
.39419 .66893 m .3925 .6706 L .39499 .66964 L F
.4 0 0 r
.26705 .63513 m .26902 .63603 L .26711 .63536 L F
.764 .943 .939 r
.26481 .63547 m .26697 .63485 L .26705 .63513 L F
.41 .78 .994 r
.26339 .63457 m .26481 .63547 L .26705 .63513 L F
.4 0 0 r
.26705 .63513 m .26711 .63536 L .26538 .63475 L F
.764 .943 .939 r
.26697 .63485 m .26899 .63428 L .26705 .63513 L F
.793 .3 0 r
.26899 .63428 m .26902 .63603 L .26705 .63513 L F
.495 .105 .23 r
.37221 .70293 m .37101 .70526 L .36843 .70538 L F
.505 .172 .336 r
.3745 .70235 m .37101 .70526 L .37221 .70293 L F
.409 .823 .973 r
.35007 .67132 m .34917 .67244 L .34739 .67143 L F
.35007 .67132 m .35171 .67194 L .34917 .67244 L F
.841 .956 .613 r
.38472 .66702 m .38435 .66893 L .38628 .66527 L F
0 .084 .633 r
.38472 .66702 m .3861 .67053 L .38435 .66893 L F
.316 .085 .395 r
.3861 .67053 m .38386 .67133 L .38435 .66893 L F
.382 .555 .9 r
.20789 .61034 m .20854 .60804 L .20743 .60827 L F
.20789 .61034 m .2108 .61043 L .20854 .60804 L F
.623 .937 .96 r
.2304 .78361 m .23027 .78497 L .23234 .7837 L F
.23234 .7837 m .23027 .78497 L .2304 .78361 L F
.952 .743 .583 r
.33397 .58613 m .33257 .58688 L .33233 .58364 L F
.576 .38 .579 r
.33653 .58391 m .33397 .58613 L .33233 .58364 L F
.33653 .58391 m .3364 .58692 L .33397 .58613 L F
.518 .001 0 r
.3364 .58692 m .33257 .58688 L .33397 .58613 L F
.598 .929 .718 r
.32896 .57297 m .32723 .5743 L .32976 .57247 L F
.782 .709 .784 r
.32545 .57418 m .32427 .57658 L .32723 .5743 L F
.32262 .57398 m .32323 .57494 L .32545 .57418 L F
.32323 .57494 m .32427 .57658 L .32545 .57418 L F
.32262 .57398 m .32723 .5743 L .32573 .57498 L F
.598 .929 .718 r
.32573 .57498 m .32723 .5743 L .32896 .57297 L F
.782 .709 .784 r
.32427 .57658 m .3248 .57742 L .32723 .5743 L F
.756 .523 .579 r
.32774 .57491 m .33096 .57482 L .3278 .57906 L F
0 0 .173 r
.32774 .57491 m .3278 .57906 L .32826 .57629 L F
.32774 .57491 m .32826 .57629 L .32818 .57613 L F
.32774 .57491 m .32818 .57613 L .32702 .57395 L F
.598 .929 .718 r
.32573 .57498 m .3274 .57394 L .32774 .57491 L F
.3274 .57394 m .32896 .57297 L .32774 .57491 L F
.32896 .57297 m .32976 .57247 L .3295 .57278 L F
.32896 .57297 m .3295 .57278 L .32774 .57491 L F
.72 .607 .73 r
.33397 .57421 m .33751 .57453 L .3364 .57138 L F
.516 .352 .597 r
.33751 .57453 m .33994 .57136 L .3364 .57138 L F
.33751 .57453 m .34002 .57399 L .33994 .57136 L F
.33994 .57136 m .34002 .57399 L .33751 .57453 L F
.5 .394 .666 r
.33786 .5768 m .34002 .57399 L .33751 .57453 L F
0 0 .435 r
.38957 .58729 m .38901 .59228 L .38927 .58994 L F
.38974 .58579 m .38955 .58749 L .38957 .58729 L F
.38955 .58749 m .38901 .59228 L .38957 .58729 L F
.693 .407 .484 r
.3898 .59242 m .39419 .58892 L .39173 .58963 L F
.3898 .59242 m .39455 .59171 L .39419 .58892 L F
.622 .58 .786 r
.39277 .59037 m .39043 .58683 L .39419 .58892 L F
0 0 0 r
.38979 .5864 m .39058 .58601 L .38965 .58653 L F
.39221 .58411 m .39058 .58601 L .38979 .5864 L F
.317 0 .124 r
.3929 .58538 m .39058 .58601 L .39225 .58407 L F
.923 .77 .673 r
.3929 .58538 m .39147 .58557 L .39058 .58601 L F
0 0 0 r
.39225 .58407 m .38965 .58653 L .38967 .58636 L F
.923 .77 .673 r
.39147 .58557 m .38974 .58579 L .39058 .58601 L F
.622 .58 .786 r
.39043 .58683 m .38974 .58579 L .39067 .58645 L F
.39043 .58683 m .39067 .58645 L .39419 .58892 L F
0 0 0 r
.39225 .58407 m .39219 .58414 L .39221 .58411 L F
.39219 .58414 m .39058 .58601 L .39221 .58411 L F
.38967 .58636 m .38965 .58653 L .38917 .5868 L F
0 0 .129 r
.38974 .58579 m .38917 .5868 L .39058 .58601 L F
.38974 .58579 m .38927 .58994 L .38917 .5868 L F
.818 .943 .907 r
.36434 .66682 m .3606 .66846 L .36228 .66708 L F
.619 .695 .899 r
.3658 .66436 m .36434 .66682 L .36228 .66708 L F
.3658 .66436 m .36702 .66615 L .36434 .66682 L F
.424 0 0 r
.3109 .65901 m .31093 .65937 L .30907 .65801 L F
.3109 .65901 m .31261 .66005 L .31093 .65937 L F
.489 .811 1 r
.28967 .54957 m .28784 .54851 L .28562 .54908 L F
.699 .801 .928 r
.21491 .57345 m .21321 .57476 L .21655 .57494 L F
.16 0 0 r
.21915 .57415 m .21491 .57345 L .21655 .57494 L F
.302 0 .261 r
.36799 .56499 m .37035 .56434 L .37099 .56225 L F
.509 .66 .928 r
.26142 .62222 m .26421 .6243 L .26204 .62474 L F
0 0 0 r
.26204 .62474 m .26599 .6242 L .26359 .62431 L F
.26204 .62474 m .26437 .62443 L .26599 .6242 L F
.509 .66 .928 r
.26421 .6243 m .26437 .62443 L .26204 .62474 L F
0 0 0 r
.26029 .62508 m .26204 .62474 L .26359 .62431 L F
.25982 .62519 m .26204 .62474 L .26029 .62508 L F
.599 .087 .003 r
.30339 .65547 m .30643 .65592 L .30562 .657 L F
.532 .302 .512 r
.30643 .65592 m .30684 .65796 L .30562 .657 L F
.30643 .65592 m .30907 .65801 L .30684 .65796 L F
.30643 .65592 m .30927 .65568 L .30907 .65801 L F
.168 0 .064 r
.27674 .61662 m .27773 .61536 L .27476 .61745 L F
.269 0 .013 r
.27289 .61943 m .27674 .61662 L .27476 .61745 L F
0 .491 .744 r
.24212 .6301 m .23756 .62917 L .23671 .63027 L F
0 0 .143 r
.28617 .60627 m .2867 .60723 L .28768 .60531 L F
.28617 .60627 m .28552 .60877 L .2867 .60723 L F
.787 .556 .586 r
.63972 .40106 m .63598 .40403 L .63847 .40077 L F
.568 .406 .622 r
.64251 .40102 m .63972 .40448 L .63972 .40106 L F
0 0 .135 r
.63972 .40448 m .63976 .40454 L .63972 .40106 L F
.787 .556 .586 r
.63972 .40106 m .63976 .40454 L .63598 .40403 L F
.572 .925 .95 r
.63972 .40106 m .64125 .39956 L .64251 .40102 L F
.63972 .40106 m .63847 .40077 L .64125 .39956 L F
.761 .695 .789 r
.32803 .53206 m .32543 .53387 L .32331 .52978 L F
.432 .517 .845 r
.18685 .59909 m .18675 .59558 L .18592 .59568 L F
.18685 .59909 m .18864 .59936 L .18675 .59558 L F
.761 .695 .789 r
.32803 .53206 m .32331 .52978 L .32547 .52842 L F
.348 .482 .853 r
.31635 .53771 m .31718 .53548 L .31477 .53643 L F
.31635 .53771 m .31909 .53861 L .31718 .53548 L F
.37 0 0 r
.36909 .51286 m .37252 .51284 L .37003 .51423 L F
.391 .247 .563 r
.38962 .68609 m .38762 .68426 L .38973 .68364 L F
.38962 .68609 m .38771 .68714 L .38762 .68426 L F
.357 .759 .984 r
.22727 .61195 m .22963 .61174 L .23147 .61271 L F
.322 .634 .963 r
.23179 .61101 m .23147 .61271 L .22963 .61174 L F
.23179 .61101 m .23314 .61281 L .23147 .61271 L F
.291 .001 .288 r
.31284 .54293 m .31091 .5451 L .31108 .54314 L F
.228 0 .231 r
.31284 .54293 m .31091 .5451 L .31108 .54314 L F
.455 .625 .925 r
.33461 .57929 m .33732 .58021 L .33786 .5768 L F
.5 .394 .666 r
.33786 .5768 m .33965 .57634 L .34002 .57399 L F
.49 .203 .405 r
.33786 .5768 m .33984 .57968 L .33965 .57634 L F
.33786 .5768 m .33732 .58021 L .33984 .57968 L F
.728 .529 .621 r
.35484 .57763 m .35503 .58044 L .35165 .58058 L F
.432 .502 .83 r
.3566 .57695 m .35484 .57763 L .35362 .57531 L F
.396 .278 .599 r
.35689 .57964 m .35484 .57763 L .3566 .57695 L F
.35689 .57964 m .35503 .58044 L .35484 .57763 L F
.227 .742 .866 r
.25027 .53022 m .24956 .53069 L .24712 .53107 L F
.25027 .53022 m .25193 .53039 L .24956 .53069 L F
.955 .667 .45 r
.36134 .53391 m .35958 .53556 L .35738 .53356 L F
.36134 .53391 m .36169 .5381 L .35958 .53556 L F
.497 .512 .802 r
.36227 .52978 m .36134 .53391 L .36128 .53005 L F
.36227 .52978 m .36361 .53335 L .36134 .53391 L F
.679 .165 .009 r
.36134 .53391 m .3639 .53623 L .36576 .53591 L F
.431 .267 .556 r
.36361 .53335 m .3639 .53623 L .36134 .53391 L F
.36361 .53335 m .3639 .53623 L .36134 .53391 L F
0 0 .202 r
.40742 .57005 m .40699 .57331 L .40547 .57164 L F
.022 .112 .619 r
.40699 .57331 m .40651 .57466 L .40547 .57164 L F
.669 .443 .569 r
.4031 .57752 m .40095 .58036 L .4006 .57777 L F
.559 .86 .997 r
.28439 .52537 m .27987 .52518 L .2824 .52483 L F
.32 .804 .882 r
.28473 .52469 m .28439 .52537 L .2824 .52483 L F
.28473 .52469 m .2867 .52484 L .28439 .52537 L F
.361 0 .03 r
.26369 .53963 m .25951 .54178 L .26149 .54063 L F
.723 .651 .777 r
.35512 .62731 m .35728 .63137 L .35475 .63204 L F
.701 .553 .683 r
.35475 .63204 m .35728 .63137 L .35375 .63416 L F
.131 .329 .794 r
.35771 .63076 m .35728 .63137 L .35512 .62731 L F
.346 .143 .455 r
.35865 .63312 m .35728 .63137 L .35771 .63076 L F
.35865 .63312 m .35655 .63406 L .35728 .63137 L F
.249 0 0 r
.26808 .55048 m .26584 .55096 L .26675 .54993 L F
.266 0 0 r
.26917 .54973 m .26808 .55048 L .26675 .54993 L F
.425 .275 .573 r
.38286 .61829 m .38251 .62117 L .38053 .62177 L F
.442 .32 .618 r
.38251 .62117 m .38296 .62385 L .38053 .62177 L F
.273 .253 .653 r
.3187 .6171 m .31627 .62012 L .31739 .62108 L F
.044 0 0 r
.29201 .53322 m .28817 .53568 L .28944 .53384 L F
.609 .372 .533 r
.35368 .60122 m .3536 .60437 L .35606 .60007 L F
.469 0 0 r
.18864 .59936 m .19318 .59951 L .19102 .59844 L F
.18864 .59936 m .18933 .59967 L .19318 .59951 L F
0 .271 .642 r
.19318 .59951 m .19423 .60001 L .19102 .59844 L F
0 0 0 r
.32826 .59346 m .32966 .58938 L .32949 .59203 L F
.07 .046 .521 r
.32949 .59203 m .32832 .59598 L .32826 .59346 L F
.072 0 .222 r
.18889 .57045 m .191 .56754 L .18899 .56768 L F
.153 .685 .857 r
.25361 .55276 m .24947 .5525 L .25115 .55224 L F
.607 .397 .571 r
.32165 .63993 m .32437 .63703 L .32177 .63734 L F
.449 .195 .436 r
.3715 .59839 m .37371 .60041 L .37446 .59604 L F
.506 .379 .641 r
.3715 .59839 m .37478 .60213 L .37371 .60041 L F
.3715 .59839 m .37241 .60271 L .37478 .60213 L F
.349 .747 .984 r
.27574 .52441 m .27987 .52518 L .27759 .52532 L F
.161 .696 .707 r
.2867 .52484 m .28903 .52434 L .29077 .52399 L F
0 .543 .82 r
.29146 .52378 m .29077 .52399 L .28903 .52434 L F
.29146 .52378 m .29276 .5243 L .29077 .52399 L F
.84 .854 .854 r
.38096 .62763 m .37787 .63021 L .38019 .63085 L F
.625 .064 0 r
.38013 .63221 m .38019 .63085 L .37787 .63021 L F
.777 .718 .797 r
.38013 .63221 m .3817 .6356 L .38461 .63385 L F
.503 .353 .609 r
.38353 .63356 m .38403 .63555 L .3817 .6356 L F
.625 .064 0 r
.3832 .63333 m .38461 .63385 L .38017 .63121 L F
.503 .353 .609 r
.38383 .63322 m .38388 .63381 L .38353 .63356 L F
.38388 .63381 m .38403 .63555 L .38353 .63356 L F
.625 .064 0 r
.38017 .63121 m .38461 .63385 L .38019 .63085 L F
.38013 .63221 m .3832 .63333 L .38017 .63121 L F
.765 .979 .718 r
.29366 .55232 m .29462 .54898 L .29279 .54971 L F
.29366 .55232 m .29447 .55041 L .29462 .54898 L F
.29366 .55232 m .29283 .55238 L .29447 .55041 L F
.29447 .55041 m .29366 .55232 L .29619 .55292 L F
.29447 .55041 m .29283 .55238 L .29366 .55232 L F
.345 .414 .79 r
.13865 .7338 m .1374 .73527 L .13696 .73359 L F
.69 .981 .865 r
.13519 .73595 m .1374 .73527 L .13865 .7338 L F
.63 .366 .499 r
.37193 .55263 m .36902 .55394 L .36932 .55311 L F
0 0 0 r
.28053 .61263 m .27773 .61536 L .27901 .61421 L F
.403 .822 .639 r
.27901 .61421 m .28276 .61193 L .28053 .61263 L F
.643 .887 .985 r
.25979 .74947 m .26154 .75027 L .25782 .75043 L F
.724 .464 .533 r
.35794 .60322 m .35785 .60431 L .35673 .60319 L F
.374 0 0 r
.35651 .60319 m .35617 .60318 L .35591 .60312 L F
.724 .464 .533 r
.35808 .60161 m .35645 .60352 L .35633 .60337 L F
.374 0 0 r
.35651 .60319 m .35591 .60312 L .35808 .60161 L F
.861 .793 .783 r
.35808 .60161 m .35591 .60312 L .35588 .6029 L F
.724 .464 .533 r
.35808 .60161 m .35592 .60288 L .35573 .60266 L F
.861 .793 .783 r
.35808 .60161 m .35588 .6029 L .35555 .60059 L F
.724 .464 .533 r
.35808 .60161 m .35633 .60337 L .35592 .60288 L F
.35808 .60161 m .35794 .60322 L .35673 .60319 L F
.374 0 0 r
.3605 .60367 m .35808 .60161 L .35785 .60431 L F
.549 .313 .509 r
.3605 .60367 m .35785 .60431 L .35808 .60161 L F
.3605 .60367 m .35785 .60431 L .35808 .60161 L F
.374 0 0 r
.3605 .60367 m .35651 .60319 L .35808 .60161 L F
.3605 .60367 m .35841 .60375 L .35617 .60318 L F
.3605 .60367 m .35617 .60318 L .35651 .60319 L F
.724 .464 .533 r
.35673 .60319 m .35785 .60431 L .35645 .60352 L F
.385 .399 .752 r
.35591 .60312 m .35617 .60318 L .35608 .60307 L F
.724 .464 .533 r
.35573 .60266 m .35645 .60352 L .35529 .60285 L F
.385 .399 .752 r
.35608 .60307 m .35841 .60375 L .35854 .60245 L F
.35617 .60318 m .35841 .60375 L .35608 .60307 L F
.542 0 0 r
.35606 .60007 m .35808 .60161 L .35593 .60075 L F
.46 .155 .36 r
.35909 .59951 m .35808 .60161 L .35606 .60007 L F
.575 .435 .653 r
.36011 .59854 m .35808 .60161 L .35909 .59951 L F
.36011 .59854 m .36093 .60118 L .35808 .60161 L F
.549 .313 .509 r
.3605 .60367 m .35808 .60161 L .36093 .60118 L F
.385 .399 .752 r
.35732 .60165 m .35854 .60245 L .35879 .60013 L F
.35591 .60312 m .35854 .60245 L .35732 .60165 L F
.542 0 0 r
.35561 .60054 m .35593 .60075 L .35555 .60059 L F
.35606 .60007 m .35593 .60075 L .35561 .60054 L F
.169 0 .293 r
.38791 .67387 m .39005 .67365 L .3906 .67141 L F
.555 .367 .581 r
.38738 .67691 m .39005 .67365 L .38791 .67387 L F
.785 .74 .811 r
.33653 .58391 m .33233 .58364 L .3347 .58265 L F
.388 .226 .538 r
.3382 .58543 m .3364 .58692 L .33653 .58391 L F
.3382 .58543 m .3364 .58692 L .33653 .58391 L F
.41 .727 .99 r
.27353 .63933 m .27691 .64043 L .27498 .63957 L F
.837 .367 .05 r
.27498 .63957 m .27691 .64043 L .27836 .643 L F
.37 .107 .378 r
.28951 .62739 m .28722 .62809 L .28663 .63043 L F
.535 .319 .534 r
.39696 .593 m .39419 .59569 L .3947 .59313 L F
.563 .405 .625 r
.32736 .67815 m .33007 .67828 L .32988 .676 L F
.32736 .67815 m .33007 .67828 L .32988 .676 L F
.224 .14 .545 r
.2973 .5681 m .29703 .56892 L .29874 .5673 L F
.543 .534 .795 r
.29763 .57155 m .29874 .5673 L .29703 .56892 L F
.459 0 0 r
.30184 .64631 m .30345 .64607 L .30078 .64545 L F
.30184 .64631 m .30078 .64545 L .30116 .64556 L F
.113 0 .1 r
.36799 .56499 m .36895 .56646 L .37035 .56434 L F
.36799 .56499 m .36713 .56736 L .36895 .56646 L F
.661 .764 .926 r
.72362 .31281 m .72088 .31171 L .72264 .31307 L F
.375 .467 .827 r
.33842 .56167 m .34147 .56483 L .34035 .56059 L F
.543 .534 .795 r
.29763 .57155 m .30002 .57105 L .29874 .5673 L F
.63 .366 .499 r
.37193 .55263 m .37149 .55454 L .36902 .55394 L F
.43 .179 .43 r
.37432 .55195 m .37149 .55454 L .37193 .55263 L F
.781 .527 .553 r
.34227 .56646 m .34317 .5683 L .34572 .56834 L F
.448 .121 .317 r
.34245 .57106 m .34572 .56834 L .34317 .5683 L F
.651 .48 .639 r
.36418 .616 m .36885 .61511 L .36893 .61254 L F
.665 .533 .694 r
.36418 .616 m .36644 .61835 L .36885 .61511 L F
0 0 .491 r
.39854 .54542 m .40072 .54884 L .39943 .54699 L F
.478 .192 .401 r
.38003 .68103 m .38257 .68069 L .38312 .67828 L F
.38003 .68103 m .38257 .68069 L .38312 .67828 L F
.449 .448 .765 r
.38371 .67356 m .38312 .67828 L .3811 .67434 L F
.38371 .67356 m .38518 .67779 L .38312 .67828 L F
.321 .055 .345 r
.38518 .67779 m .38257 .68069 L .38312 .67828 L F
.38518 .67779 m .38257 .68069 L .38312 .67828 L F
.52 .513 .789 r
.37241 .60271 m .37349 .60726 L .37554 .60672 L F
.499 .425 .704 r
.37349 .60726 m .3768 .60781 L .37554 .60672 L F
.469 .501 .809 r
.32153 .57411 m .3248 .57742 L .32262 .57398 L F
.82 .607 .614 r
.22415 .57084 m .22165 .5682 L .22456 .56812 L F
.22415 .57084 m .22155 .5709 L .22165 .5682 L F
.667 .21 .158 r
.22415 .57084 m .22359 .57289 L .22155 .5709 L F
.162 0 .254 r
.22745 .56713 m .22415 .57084 L .22456 .56812 L F
.22745 .56713 m .22665 .5701 L .22415 .57084 L F
.604 .375 .541 r
.22665 .5701 m .22359 .57289 L .22415 .57084 L F
.716 .638 .769 r
.32568 .51868 m .32272 .5227 L .32116 .51773 L F
.769 .985 .903 r
.32379 .5201 m .32272 .5227 L .32477 .52323 L F
.32379 .5201 m .32039 .52284 L .32272 .5227 L F
.728 .626 .744 r
.35351 .51675 m .354 .51862 L .35735 .51639 L F
0 0 .302 r
.35351 .51675 m .35467 .52085 L .354 .51862 L F
.35351 .51675 m .35467 .52085 L .354 .51862 L F
.572 .329 .51 r
.33598 .53698 m .33557 .53946 L .33797 .53883 L F
.33598 .53698 m .33557 .53946 L .33797 .53883 L F
.802 .591 .616 r
.34888 .69678 m .34624 .69657 L .34641 .69366 L F
.817 .564 .556 r
.34888 .69678 m .3462 .69911 L .34624 .69657 L F
.34888 .69678 m .34892 .69983 L .3462 .69911 L F
.779 .532 .562 r
.35281 .69982 m .34892 .69983 L .34888 .69678 L F
.329 .658 .972 r
.22733 .62089 m .22789 .61917 L .22435 .61782 L F
.22733 .62089 m .2291 .62062 L .22789 .61917 L F
.466 .875 .729 r
.27988 .62142 m .27919 .62214 L .28147 .62119 L F
.27988 .62142 m .27691 .62313 L .27919 .62214 L F
0 .038 .599 r
.22942 .62214 m .23064 .62283 L .2291 .62062 L F
.22942 .62214 m .23153 .62454 L .23064 .62283 L F
0 0 .114 r
.3023 .5988 m .30288 .59645 L .30539 .5935 L F
.748 .62 .717 r
.34016 .62756 m .34064 .62835 L .33568 .63063 L F
.454 .073 .226 r
.33568 .63063 m .34064 .62835 L .33767 .6324 L F
0 .071 .633 r
.34016 .62756 m .34187 .62978 L .34064 .62835 L F
.751 .263 .078 r
.34064 .62835 m .33964 .63083 L .33767 .6324 L F
.34064 .62835 m .34187 .62978 L .33964 .63083 L F
.012 0 0 r
.20007 .55916 m .19888 .56093 L .20202 .55814 L F
.369 .353 .71 r
.20813 .5848 m .20587 .58374 L .20786 .58312 L F
0 0 0 r
.36209 .66401 m .36141 .66417 L .3633 .66293 L F
.631 .84 .446 r
.35867 .66818 m .36061 .66554 L .36141 .66417 L F
.711 .9 .529 r
.35867 .66818 m .35968 .66616 L .35689 .66398 L F
.515 .393 .652 r
.35689 .66398 m .35968 .66616 L .35921 .66337 L F
.711 .9 .529 r
.35929 .66728 m .36119 .66449 L .35968 .66616 L F
0 0 .521 r
.36141 .66417 m .36061 .66554 L .3604 .66441 L F
.711 .9 .529 r
.36119 .66449 m .36114 .66449 L .35968 .66616 L F
.36119 .66449 m .36141 .66417 L .36114 .66449 L F
0 0 0 r
.35968 .66616 m .36141 .66417 L .36209 .66401 L F
0 0 .521 r
.36141 .66417 m .3604 .66441 L .36 .66224 L F
0 0 0 r
.35968 .66616 m .3633 .66293 L .36205 .66536 L F
.534 .406 .652 r
.35921 .66337 m .35968 .66616 L .36205 .66536 L F
.504 .884 .969 r
.3599 .66555 m .35968 .66616 L .35833 .66568 L F
.36205 .66536 m .35968 .66616 L .3599 .66555 L F
.711 .9 .529 r
.35867 .66818 m .35929 .66728 L .35968 .66616 L F
.534 .406 .652 r
.35921 .66337 m .36079 .66448 L .36043 .66443 L F
.36079 .66448 m .36205 .66536 L .36049 .66447 L F
.36079 .66448 m .36049 .66447 L .36043 .66443 L F
.642 .541 .724 r
.22745 .56713 m .2243 .56512 L .22762 .56531 L F
.12 .03 .469 r
.2291 .56139 m .23008 .56475 L .22762 .56531 L F
.23008 .56475 m .23019 .56512 L .22977 .56515 L F
.23008 .56475 m .22977 .56515 L .22762 .56531 L F
.598 .299 .432 r
.23157 .56387 m .2291 .56139 L .2314 .56082 L F
.305 .167 .523 r
.23326 .56207 m .23157 .56387 L .2314 .56082 L F
.509 .165 .319 r
.23326 .56207 m .23117 .56331 L .23157 .56387 L F
.914 .936 .809 r
.23019 .56512 m .22955 .5667 L .23157 .56387 L F
.598 .299 .432 r
.23157 .56387 m .23023 .56526 L .23019 .56512 L F
.23157 .56387 m .23019 .56512 L .2291 .56139 L F
.914 .936 .809 r
.23064 .56402 m .23019 .56512 L .23157 .56387 L F
.509 .165 .319 r
.23117 .56331 m .22975 .56416 L .23064 .56402 L F
.23117 .56331 m .23064 .56402 L .23157 .56387 L F
.12 .03 .469 r
.23019 .56512 m .23013 .56526 L .22762 .56531 L F
.899 .987 .765 r
.23157 .56387 m .22944 .56685 L .23023 .56526 L F
.42 .188 .454 r
.23064 .56852 m .22944 .56685 L .22947 .56664 L F
.16 .057 .48 r
.23013 .56526 m .22875 .56623 L .22762 .56531 L F
.23008 .56536 m .22745 .56713 L .23013 .56526 L F
.914 .936 .809 r
.22956 .56659 m .22944 .56685 L .22955 .5667 L F
.16 .057 .48 r
.23008 .56536 m .22944 .56685 L .22745 .56713 L F
.914 .936 .809 r
.22957 .56643 m .22944 .56685 L .22956 .56659 L F
.16 .057 .48 r
.23023 .56526 m .22944 .56685 L .23008 .56536 L F
.914 .936 .809 r
.22975 .56416 m .22947 .56664 L .22957 .56643 L F
.22947 .56664 m .22944 .56685 L .22957 .56643 L F
.22975 .56416 m .22955 .5667 L .23064 .56402 L F
.42 .188 .454 r
.23036 .56716 m .22947 .56664 L .22975 .56416 L F
.23064 .56852 m .22947 .56664 L .23036 .56716 L F
.16 .057 .48 r
.22875 .56623 m .22745 .56713 L .22759 .56556 L F
.22875 .56623 m .22759 .56556 L .22762 .56531 L F
.23023 .56526 m .23008 .56536 L .23013 .56526 L F
.12 .03 .469 r
.23019 .56512 m .23023 .56526 L .23013 .56526 L F
.167 .172 .619 r
.18552 .58067 m .18583 .58408 L .18732 .58261 L F
.211 .242 .676 r
.18583 .58408 m .18789 .5861 L .18732 .58261 L F
.311 .257 .635 r
.18633 .58671 m .18789 .5861 L .18583 .58408 L F
.446 .03 .156 r
.37804 .54229 m .3815 .54193 L .38225 .54029 L F
.606 .189 .226 r
.3815 .54193 m .38431 .54208 L .38225 .54029 L F
.557 .211 .337 r
.38225 .54029 m .38431 .54208 L .38507 .53978 L F
.728 .626 .744 r
.35351 .51675 m .35735 .51639 L .35521 .51545 L F
.629 .867 .987 r
.35735 .51639 m .35815 .5142 L .35521 .51545 L F
.35735 .51639 m .35954 .51531 L .35815 .5142 L F
.781 .288 .041 r
.31854 .64818 m .31664 .64489 L .31484 .64523 L F
0 0 .094 r
.18592 .59568 m .18675 .59558 L .18765 .59322 L F
.089 0 .178 r
.20281 .55602 m .20374 .55698 L .20483 .55516 L F
.20281 .55602 m .20202 .55814 L .20374 .55698 L F
.583 .423 .63 r
.36893 .61254 m .36885 .61511 L .37136 .61196 L F
.712 .436 .507 r
.36247 .70314 m .35828 .70565 L .35833 .70332 L F
.36247 .70314 m .36231 .70538 L .35828 .70565 L F
.643 .377 .5 r
.36247 .70314 m .36478 .70576 L .36231 .70538 L F
.564 .692 .927 r
.34037 .51307 m .3412 .51042 L .33915 .51093 L F
.34037 .51307 m .34276 .51307 L .3412 .51042 L F
.41 .031 .205 r
.34375 .55137 m .34595 .55004 L .34491 .54877 L F
0 .059 .624 r
.32951 .64899 m .32782 .64697 L .32791 .64526 L F
.497 .239 .454 r
.32697 .64939 m .32782 .64697 L .32951 .64899 L F
.461 .125 .31 r
.23871 .55545 m .23772 .55761 L .23532 .55783 L F
.285 .07 .4 r
.2402 .55413 m .24046 .55492 L .23871 .55545 L F
.417 .146 .393 r
.24046 .55492 m .23772 .55761 L .23871 .55545 L F
.792 .415 .343 r
.28019 .63021 m .28075 .62814 L .27862 .63018 L F
.705 .405 .466 r
.28295 .63037 m .28075 .62814 L .28019 .63021 L F
.615 .77 .955 r
.23146 .63057 m .23584 .63142 L .2338 .63024 L F
.838 .859 .86 r
.2338 .63024 m .23584 .63142 L .23756 .62917 L F
.994 .804 .543 r
.37601 .56685 m .37599 .56689 L .37716 .56753 L F
.005 0 .046 r
.37716 .56753 m .37541 .56853 L .37851 .56827 L F
.994 .804 .543 r
.37599 .56689 m .37469 .56949 L .37716 .56753 L F
.005 0 .046 r
.37716 .56753 m .37851 .56827 L .37856 .56827 L F
.269 .28 .687 r
.37856 .56827 m .37997 .56784 L .37716 .56753 L F
.37856 .56827 m .3808 .57028 L .37997 .56784 L F
.274 .318 .726 r
.18633 .58671 m .18715 .59029 L .1889 .58907 L F
.192 .163 .595 r
.1889 .58907 m .18715 .59029 L .1888 .59199 L F
.193 .163 .594 r
.18715 .59029 m .18765 .59322 L .1888 .59199 L F
0 .085 .628 r
.2419 .6142 m .24194 .61504 L .24002 .61401 L F
.2419 .6142 m .24389 .61696 L .24194 .61504 L F
.851 .838 .832 r
.33342 .54055 m .32882 .54217 L .32991 .53961 L F
.33342 .54055 m .33056 .54358 L .32882 .54217 L F
.679 .673 .838 r
.3364 .57138 m .33853 .56832 L .33593 .56871 L F
.3364 .57138 m .33994 .57136 L .33853 .56832 L F
.843 .554 .499 r
.34641 .69366 m .34299 .6931 L .34286 .69048 L F
.853 .636 .609 r
.34641 .69366 m .34264 .69584 L .34299 .6931 L F
.34641 .69366 m .34624 .69657 L .34264 .69584 L F
.634 .347 .465 r
.37301 .54341 m .37575 .54559 L .37639 .54278 L F
.451 0 0 r
.37337 .54375 m .37301 .54341 L .37639 .54278 L F
.37337 .54375 m .37575 .54559 L .37301 .54341 L F
.877 .746 .715 r
.2717 .56148 m .27307 .565 L .27389 .56274 L F
.591 .423 .623 r
.27558 .56182 m .27307 .565 L .27389 .56274 L F
.817 .607 .619 r
.24242 .54472 m .24597 .54323 L .24385 .54196 L F
.24242 .54472 m .24572 .54585 L .24597 .54323 L F
0 0 0 r
.27674 .61662 m .27901 .61421 L .27773 .61536 L F
.269 .024 .345 r
.33258 .60224 m .33435 .60391 L .33678 .60234 L F
.575 .479 .708 r
.33898 .59926 m .33931 .60203 L .33678 .60234 L F
.086 0 0 r
.33628 .60321 m .33678 .60234 L .33435 .60391 L F
.418 .382 .712 r
.33948 .60542 m .33678 .60234 L .33931 .60203 L F
.33948 .60542 m .33752 .60598 L .33716 .60423 L F
.33778 .60349 m .33716 .60423 L .33678 .60234 L F
.33948 .60542 m .33716 .60423 L .33778 .60349 L F
.086 0 0 r
.33628 .60321 m .33931 .60203 L .33678 .60234 L F
.575 .479 .708 r
.33898 .59926 m .33931 .60203 L .33678 .60234 L F
.553 .404 .632 r
.34152 .59872 m .33931 .60203 L .33898 .59926 L F
0 0 .262 r
.33898 .59926 m .33931 .60203 L .33964 .60034 L F
.745 .991 .802 r
.33964 .60034 m .33941 .60153 L .33628 .60321 L F
.33941 .60153 m .33931 .60203 L .33884 .60221 L F
.33941 .60153 m .33884 .60221 L .33628 .60321 L F
.766 .531 .578 r
.33752 .60598 m .33751 .60851 L .33378 .60835 L F
0 0 0 r
.33948 .60542 m .33751 .60851 L .33752 .60598 L F
.51 .594 .874 r
.37641 .53836 m .37639 .54278 L .3752 .53888 L F
.37641 .53836 m .37804 .54229 L .37639 .54278 L F
.213 0 0 r
.37804 .54229 m .37337 .54375 L .37639 .54278 L F
.437 .19 .441 r
.37575 .54559 m .37804 .54229 L .37639 .54278 L F
.832 .986 .872 r
.32264 .54488 m .31971 .54751 L .32214 .54709 L F
0 0 0 r
.32036 .54724 m .32025 .54734 L .31971 .54751 L F
.32025 .54734 m .31791 .54953 L .31971 .54751 L F
.156 .695 .718 r
.31945 .54759 m .31971 .54751 L .31748 .54796 L F
.32214 .54709 m .31971 .54751 L .31945 .54759 L F
.832 .986 .872 r
.32264 .54488 m .32214 .54709 L .32461 .54617 L F
.403 .404 .746 r
.32214 .54709 m .32436 .54882 L .32461 .54617 L F
.259 0 .304 r
.26844 .54303 m .2698 .54471 L .27078 .54205 L F
.26844 .54303 m .26783 .54576 L .2698 .54471 L F
.638 .624 .82 r
.34335 .62628 m .34187 .62978 L .34295 .6278 L F
.351 .292 .651 r
.34051 .62326 m .34295 .6278 L .34016 .62756 L F
.459 .351 .644 r
.29558 .62449 m .29621 .62733 L .29435 .62793 L F
0 0 .477 r
.29718 .63273 m .29435 .62793 L .29621 .62733 L F
.65 .691 .875 r
.30213 .63325 m .29745 .6293 L .30132 .62921 L F
.439 .307 .604 r
.29745 .6293 m .29718 .63273 L .29621 .62733 L F
0 0 .29 r
.29745 .6293 m .29672 .63185 L .29815 .62959 L F
.29672 .63185 m .29649 .63265 L .29684 .63199 L F
.29672 .63185 m .29684 .63199 L .29815 .62959 L F
0 0 .477 r
.29718 .63273 m .29589 .63089 L .29588 .63088 L F
.29654 .63164 m .29588 .63088 L .29435 .62793 L F
.29718 .63273 m .29588 .63088 L .29654 .63164 L F
.309 .189 .55 r
.18552 .58067 m .18717 .57994 L .1871 .57723 L F
.167 .172 .619 r
.18552 .58067 m .18732 .58261 L .18717 .57994 L F
.657 .871 .979 r
.35328 .58635 m .34906 .58651 L .35156 .58333 L F
.406 0 0 r
.35328 .58635 m .35107 .58698 L .34906 .58651 L F
.455 .395 .701 r
.35473 .58317 m .35328 .58635 L .35156 .58333 L F
.35473 .58317 m .35545 .58636 L .35328 .58635 L F
.762 .256 0 r
.35328 .58635 m .35364 .5882 L .35107 .58698 L F
.35328 .58635 m .35453 .58809 L .35364 .5882 L F
.45 .275 .551 r
.35545 .58636 m .35527 .58913 L .35328 .58635 L F
.506 0 0 r
.35107 .58698 m .35364 .5882 L .34968 .58754 L F
.678 .203 .116 r
.34968 .58754 m .35364 .5882 L .35216 .58961 L F
.345 .524 .889 r
.34906 .58651 m .35107 .58698 L .35095 .58543 L F
.506 0 0 r
.35107 .58698 m .35222 .58427 L .35095 .58543 L F
.35107 .58698 m .34968 .58754 L .35222 .58427 L F
.573 .408 .62 r
.34968 .58754 m .35337 .58744 L .35222 .58427 L F
.446 .534 .853 r
.35364 .5882 m .35396 .58639 L .35298 .58829 L F
.595 .419 .614 r
.35222 .58427 m .35345 .58728 L .35422 .58569 L F
.446 .534 .853 r
.35396 .58639 m .35401 .58611 L .35337 .58744 L F
.35401 .58611 m .35345 .58728 L .35337 .58744 L F
.595 .419 .614 r
.35345 .58728 m .35351 .58744 L .35422 .58569 L F
.446 .534 .853 r
.35401 .58611 m .35402 .58606 L .35345 .58728 L F
.35396 .58639 m .35337 .58744 L .35298 .58829 L F
.489 .306 .558 r
.34968 .58754 m .35216 .58961 L .35337 .58744 L F
.446 .534 .853 r
.35298 .58829 m .35402 .58606 L .35284 .58831 L F
.489 .306 .558 r
.35337 .58744 m .35216 .58961 L .35351 .58744 L F
.573 .408 .62 r
.35337 .58744 m .35351 .58744 L .35345 .58728 L F
.35337 .58744 m .35345 .58728 L .35222 .58427 L F
.446 .534 .853 r
.35364 .5882 m .35422 .58569 L .35402 .58606 L F
.35364 .5882 m .35284 .58831 L .35216 .58961 L F
.762 .256 0 r
.35453 .58809 m .35527 .58913 L .35364 .5882 L F
.517 .833 1 r
.26518 .52636 m .26531 .5283 L .26235 .52676 L F
.26518 .52636 m .26762 .5277 L .26531 .5283 L F
.791 .697 .761 r
.38487 .55235 m .38066 .5518 L .38315 .55137 L F
.38487 .55235 m .38221 .55563 L .38066 .5518 L F
.695 .246 .183 r
.34388 .63905 m .34163 .63684 L .34213 .63901 L F
.725 .432 .483 r
.35281 .69982 m .34816 .70186 L .34892 .69983 L F
.35281 .69982 m .3504 .70275 L .34816 .70186 L F
.727 .436 .485 r
.35281 .69982 m .35427 .70255 L .3504 .70275 L F
.756 .476 .51 r
.37716 .56753 m .37997 .56784 L .38112 .56512 L F
.147 0 .207 r
.38112 .56512 m .37997 .56784 L .38231 .56621 L F
.732 .608 .719 r
.22456 .56812 m .22165 .5682 L .2243 .56512 L F
.642 .541 .724 r
.22745 .56713 m .22456 .56812 L .2243 .56512 L F
.782 .859 .907 r
.3731 .66481 m .3694 .66522 L .37173 .6639 L F
.741 .949 .946 r
.37336 .66272 m .3731 .66481 L .37173 .6639 L F
.37336 .66272 m .37608 .66291 L .3731 .66481 L F
0 0 0 r
.32681 .54544 m .32888 .54474 L .33056 .54358 L F
.968 .692 .455 r
.33056 .54358 m .32888 .54474 L .32882 .54217 L F
.73 .722 .844 r
.32424 .65245 m .32814 .65327 L .32617 .65419 L F
.32424 .65245 m .32814 .65327 L .32617 .65419 L F
.655 .506 .669 r
.32814 .65327 m .32659 .65638 L .32617 .65419 L F
.344 .393 .768 r
.2973 .5681 m .29736 .56325 L .29563 .56553 L F
.2973 .5681 m .29874 .5673 L .29736 .56325 L F
0 0 .345 r
.37609 .53183 m .37463 .53514 L .37433 .53375 L F
.335 .816 .803 r
.30629 .62867 m .30502 .6291 L .30213 .63325 L F
.619 .828 .981 r
.35981 .51216 m .35597 .51183 L .35844 .51055 L F
.402 .655 .961 r
.36051 .51051 m .35981 .51216 L .35844 .51055 L F
.631 .904 .984 r
.36227 .51111 m .35981 .51216 L .36051 .51051 L F
.36227 .51111 m .35981 .51216 L .36051 .51051 L F
0 0 0 r
.37807 .53761 m .37641 .53836 L .3752 .53888 L F
0 .051 .598 r
.33045 .60263 m .3321 .60457 L .33258 .60224 L F
.654 .859 .978 r
.29697 .52432 m .29276 .5243 L .29546 .52403 L F
.522 .88 .982 r
.29546 .52403 m .29931 .52375 L .29697 .52432 L F
.316 0 0 r
.37522 .52469 m .37368 .52419 L .37164 .52335 L F
.072 .593 .876 r
.37782 .52515 m .37368 .52419 L .37522 .52469 L F
.911 .547 .332 r
.34108 .56733 m .34227 .56646 L .34147 .56483 L F
.34108 .56733 m .34317 .5683 L .34227 .56646 L F
0 0 .011 r
.33435 .63977 m .33519 .63751 L .33616 .63643 L F
.418 .756 .995 r
.32351 .55531 m .32341 .55369 L .325 .55153 L F
.32351 .55531 m .32537 .5548 L .32341 .55369 L F
.764 .988 .897 r
.32351 .55531 m .32341 .55369 L .32537 .5548 L F
.32351 .55531 m .32177 .55511 L .32341 .55369 L F
.741 .642 .749 r
.35721 .54884 m .35487 .55219 L .35888 .55187 L F
.496 .291 .531 r
.35612 .55545 m .35888 .55187 L .35487 .55219 L F
.35612 .55545 m .35855 .55492 L .35888 .55187 L F
.652 .452 .6 r
.35855 .55492 m .36152 .55159 L .35888 .55187 L F
.245 0 .036 r
.22119 .54265 m .22352 .54202 L .22506 .53967 L F
.104 0 0 r
.22506 .53967 m .22562 .54109 L .22699 .53798 L F
.22506 .53967 m .22352 .54202 L .22562 .54109 L F
.21 .729 .714 r
.33341 .55539 m .33294 .55541 L .33537 .55498 L F
.431 .369 .687 r
.33596 .55797 m .33341 .55539 L .33537 .55498 L F
.33596 .55797 m .3339 .55923 L .33341 .55539 L F
.529 .479 .744 r
.33947 .64384 m .34008 .64675 L .34227 .64603 L F
.595 .407 .597 r
.33951 .64933 m .34227 .64603 L .34008 .64675 L F
.802 .965 .649 r
.31544 .5317 m .3149 .53353 L .31731 .53027 L F
.604 .794 .368 r
.31835 .52857 m .31731 .53027 L .3195 .52668 L F
.664 .926 .631 r
.31835 .52857 m .31544 .5317 L .31731 .53027 L F
.659 .613 .792 r
.31731 .53027 m .3211 .53004 L .3195 .52668 L F
.613 .434 .616 r
.31731 .53027 m .321 .5323 L .3211 .53004 L F
.31731 .53027 m .31749 .53348 L .321 .5323 L F
.424 .612 .928 r
.12733 .72149 m .12857 .72151 L .12767 .72193 L F
.33 .799 .704 r
.12767 .72193 m .12857 .72151 L .12727 .72208 L F
.502 .475 .759 r
.37446 .59604 m .37687 .59561 L .37605 .59243 L F
.396 .15 .419 r
.37446 .59604 m .37543 .59668 L .37687 .59561 L F
.37446 .59604 m .37371 .60041 L .37543 .59668 L F
.57 .642 .883 r
.27525 .53502 m .27699 .53735 L .27931 .53658 L F
.309 0 .098 r
.27596 .53854 m .27931 .53658 L .27699 .53735 L F
.618 .634 .845 r
.33994 .57136 m .34108 .56733 L .33853 .56832 L F
.33994 .57136 m .34245 .57106 L .34108 .56733 L F
.596 .414 .606 r
.33994 .57136 m .34002 .57399 L .34245 .57106 L F
0 .267 .774 r
.30339 .65547 m .30562 .657 L .30374 .65423 L F
.451 .698 .972 r
.30111 .5436 m .3017 .54156 L .29937 .54221 L F
.30111 .5436 m .30356 .54362 L .3017 .54156 L F
.691 .853 .96 r
.24848 .54046 m .25234 .54309 L .25417 .54122 L F
.538 .805 .995 r
.25234 .54309 m .25462 .54268 L .25417 .54122 L F
.305 0 .107 r
.34997 .5613 m .35236 .56072 L .35302 .55898 L F
.031 0 .004 r
.35302 .55898 m .35483 .55925 L .35467 .55716 L F
.35302 .55898 m .35236 .56072 L .35483 .55925 L F
.815 .644 .67 r
.3679 .65768 m .36791 .66135 L .36392 .66067 L F
0 .52 .828 r
.36441 .66061 m .36392 .66067 L .36535 .66089 L F
.085 0 0 r
.36318 .66075 m .36544 .65898 L .36392 .66067 L F
0 .52 .828 r
.36229 .65999 m .36392 .66067 L .36441 .66061 L F
.085 0 0 r
.36197 .6617 m .36318 .66075 L .36392 .66067 L F
0 0 0 r
.36544 .65898 m .36767 .65775 L .3679 .65768 L F
.803 .488 .458 r
.35427 .70255 m .35833 .70332 L .35828 .70565 L F
.796 .631 .677 r
.33799 .51795 m .33916 .52183 L .33579 .52168 L F
.75 .238 0 r
.25437 .54729 m .25595 .54699 L .2538 .54613 L F
.25437 .54729 m .25822 .5492 L .25595 .54699 L F
.782 .693 .766 r
.38221 .55563 m .37849 .55534 L .38066 .5518 L F
.785 .681 .75 r
.38221 .55563 m .3798 .55859 L .37849 .55534 L F
.234 .753 .809 r
.38491 .53655 m .38319 .53666 L .38054 .53717 L F
.251 .218 .626 r
.38507 .53978 m .38689 .53869 L .38491 .53655 L F
.755 .3 .171 r
.38689 .53869 m .38319 .53666 L .38491 .53655 L F
0 0 .521 r
.36141 .66417 m .36 .66224 L .36197 .6617 L F
.557 .88 .991 r
.30331 .52375 m .30401 .52223 L .30546 .52299 L F
.30331 .52375 m .30167 .52308 L .30401 .52223 L F
.251 .16 .553 r
.30808 .58256 m .30617 .58075 L .3082 .57993 L F
.30808 .58256 m .30579 .58421 L .30617 .58075 L F
.478 .069 .185 r
.35467 .55716 m .35855 .55492 L .35612 .55545 L F
.629 .499 .685 r
.27802 .55866 m .27558 .56182 L .27545 .55937 L F
.27802 .55866 m .27558 .56182 L .27545 .55937 L F
.578 .005 0 r
.30048 .55961 m .30082 .56035 L .30148 .56047 L F
.697 .871 .963 r
.33798 .52351 m .33995 .52506 L .34179 .52365 L F
.621 .377 .526 r
.37149 .55454 m .36834 .55805 L .36902 .55394 L F
.044 0 .254 r
.27425 .6263 m .27329 .62506 L .27576 .62455 L F
.27425 .6263 m .27288 .62734 L .27329 .62506 L F
0 0 .089 r
.38507 .53978 m .38431 .54208 L .38689 .53869 L F
0 0 0 r
.1973 .56193 m .19448 .56486 L .19618 .56365 L F
.237 0 .23 r
.19618 .56365 m .19888 .56093 L .1973 .56193 L F
.417 0 0 r
.30633 .55248 m .30448 .55401 L .30245 .5536 L F
.442 .396 .712 r
.3073 .54808 m .30633 .55248 L .30433 .54892 L F
.3073 .54808 m .30853 .55185 L .30633 .55248 L F
.451 0 0 r
.30817 .55376 m .30633 .55248 L .30853 .55185 L F
.30817 .55376 m .30448 .55401 L .30633 .55248 L F
.776 .374 .291 r
.33891 .68755 m .33701 .68936 L .3348 .68645 L F
.811 .424 .323 r
.33947 .68972 m .33701 .68936 L .33891 .68755 L F
.105 0 .303 r
.29226 .58954 m .29358 .58942 L .29399 .58686 L F
.381 .235 .555 r
.29226 .58954 m .29401 .59217 L .29358 .58942 L F
.29226 .58954 m .29191 .59321 L .29401 .59217 L F
.975 .742 .523 r
.71588 .33547 m .71499 .33189 L .7161 .33272 L F
.46 .465 .776 r
.71742 .3284 m .7161 .33272 L .71499 .33189 L F
.71742 .3284 m .71821 .33241 L .7161 .33272 L F
.729 .555 .655 r
.71908 .33469 m .7161 .33272 L .71821 .33241 L F
.71908 .33469 m .71588 .33547 L .7161 .33272 L F
0 0 0 r
.27281 .54857 m .26808 .55048 L .26917 .54973 L F
.27281 .54857 m .27065 .5498 L .26808 .55048 L F
.384 0 0 r
.27508 .54797 m .27065 .5498 L .27281 .54857 L F
0 0 .414 r
.34857 .61424 m .34981 .61887 L .34964 .61622 L F
.848 .76 .248 r
.34964 .61622 m .34981 .61887 L .34939 .62072 L F
.417 .093 .305 r
.34939 .62072 m .34981 .61887 L .35286 .61815 L F
.346 .57 .923 r
.33562 .52938 m .33898 .53217 L .33423 .53128 L F
.98 .775 .556 r
.32273 .54204 m .32461 .54617 L .32681 .54544 L F
.32273 .54204 m .32264 .54488 L .32461 .54617 L F
.472 .288 .55 r
.32436 .54882 m .32681 .54544 L .32461 .54617 L F
.261 0 .078 r
.3339 .67098 m .33496 .66861 L .33725 .66799 L F
.776 .519 .547 r
.71822 .3137 m .71469 .31607 L .71702 .31209 L F
.71822 .3137 m .71849 .31665 L .71469 .31607 L F
.763 .852 .917 r
.72088 .31171 m .71822 .3137 L .71702 .31209 L F
0 0 .113 r
.33799 .51795 m .33579 .52168 L .33712 .52028 L F
.486 0 0 r
.33919 .5191 m .33799 .51795 L .33712 .52028 L F
.33919 .5191 m .34058 .51992 L .33799 .51795 L F
.738 .629 .739 r
.33722 .51505 m .33879 .51828 L .33455 .51828 L F
.33879 .51828 m .33919 .5191 L .33827 .51894 L F
.33879 .51828 m .33827 .51894 L .33455 .51828 L F
.634 .072 0 r
.33751 .51993 m .33455 .51828 L .33919 .5191 L F
0 0 0 r
.33848 .51869 m .33751 .51993 L .33919 .5191 L F
.766 .361 .285 r
.33712 .52028 m .33965 .52235 L .33751 .51993 L F
.33712 .52028 m .33607 .52199 L .33965 .52235 L F
0 .193 .714 r
.33951 .51738 m .33919 .5191 L .33722 .51505 L F
0 0 0 r
.33951 .51738 m .33714 .52045 L .3375 .51995 L F
.33755 .51987 m .3375 .51995 L .33751 .51993 L F
.33951 .51738 m .3375 .51995 L .33755 .51987 L F
.33951 .51738 m .33848 .51869 L .33919 .5191 L F
.486 0 0 r
.33919 .5191 m .34118 .52037 L .34058 .51992 L F
.266 0 .011 r
.26243 .54765 m .26444 .54796 L .26542 .54694 L F
.26243 .54765 m .26179 .54874 L .26444 .54796 L F
.424 .848 .953 r
.34549 .52916 m .34972 .52883 L .34708 .52981 L F
.717 .641 .771 r
.34972 .52883 m .34733 .53073 L .34708 .52981 L F
.441 0 0 r
.36576 .53591 m .3639 .53623 L .3677 .5364 L F
.513 0 0 r
.25242 .63341 m .25286 .63477 L .25058 .63284 L F
0 .129 .641 r
.25058 .63284 m .25286 .63477 L .25141 .63323 L F
.282 0 0 r
.25242 .63341 m .25058 .63284 L .25001 .63257 L F
0 .129 .641 r
.25058 .63284 m .25141 .63323 L .25044 .6322 L F
.282 0 0 r
.25001 .63257 m .25058 .63284 L .24776 .63178 L F
.513 0 0 r
.25242 .63341 m .25436 .6342 L .25286 .63477 L F
.646 .307 .384 r
.3339 .55923 m .33319 .56111 L .33064 .56078 L F
.284 0 .227 r
.33544 .56028 m .3339 .55923 L .33596 .55797 L F
.33544 .56028 m .33319 .56111 L .3339 .55923 L F
.248 0 .269 r
.28499 .54526 m .28686 .54503 L .28725 .54272 L F
.387 .254 .576 r
.28725 .54272 m .28978 .54211 L .28967 .53912 L F
.615 .43 .608 r
.28686 .54503 m .28978 .54211 L .28725 .54272 L F
.392 .424 .775 r
.34114 .6204 m .34156 .62181 L .34298 .62072 L F
.8 .999 .815 r
.34051 .62326 m .34298 .62072 L .34156 .62181 L F
.392 .424 .775 r
.34298 .62072 m .34156 .62181 L .34099 .6199 L F
.536 .463 .72 r
.34298 .62072 m .34051 .62326 L .34156 .62181 L F
.8 .999 .815 r
.34051 .62326 m .34096 .62143 L .34298 .62072 L F
.536 .463 .72 r
.34298 .62072 m .34347 .62456 L .34051 .62326 L F
.688 .573 .721 r
.34687 .62382 m .34347 .62456 L .34298 .62072 L F
.34687 .62382 m .34298 .62072 L .34528 .62094 L F
.413 0 0 r
.34096 .62143 m .34467 .62101 L .34298 .62072 L F
.34467 .62101 m .34528 .62094 L .34298 .62072 L F
.392 .424 .775 r
.34099 .6199 m .34114 .6204 L .34298 .62072 L F
.526 .91 .763 r
.31216 .52057 m .31322 .5194 L .31458 .51895 L F
.496 .906 .87 r
.31216 .52057 m .31073 .52059 L .31322 .5194 L F
.094 0 .203 r
.38884 .57127 m .38641 .57459 L .3881 .57332 L F
.38884 .57127 m .38641 .57459 L .3881 .57332 L F
.587 .704 .924 r
.34579 .50815 m .3417 .50671 L .34383 .50583 L F
.461 .595 .9 r
.34624 .5053 m .34579 .50815 L .34383 .50583 L F
.34624 .5053 m .34784 .50782 L .34579 .50815 L F
.14 .031 .457 r
.1871 .57723 m .18845 .57374 L .18679 .57454 L F
.133 0 0 r
.37909 .53801 m .37807 .53761 L .38054 .53717 L F
.37909 .53801 m .37641 .53836 L .37807 .53761 L F
.789 .711 .778 r
.2717 .56148 m .27307 .565 L .27558 .56182 L F
0 0 .059 r
.39048 .57012 m .38884 .57127 L .39094 .56782 L F
0 0 0 r
.39048 .57012 m .3881 .57332 L .38884 .57127 L F
.758 .684 .137 r
.33983 .54526 m .33945 .54806 L .33944 .54908 L F
0 0 .246 r
.34095 .5454 m .33945 .54806 L .33983 .54526 L F
.843 .976 .674 r
.34095 .5454 m .33973 .54618 L .33967 .54613 L F
.041 0 0 r
.34306 .54421 m .34095 .5454 L .33983 .54526 L F
.843 .976 .674 r
.34095 .5454 m .33967 .54613 L .33777 .54454 L F
.041 0 0 r
.34374 .54398 m .34095 .5454 L .34306 .54421 L F
.139 0 0 r
.34433 .54479 m .34095 .5454 L .34374 .54398 L F
.947 .688 .512 r
.36621 .62091 m .36644 .61835 L .36436 .61794 L F
.464 .271 .533 r
.36644 .61835 m .36877 .61774 L .36885 .61511 L F
.595 .423 .619 r
.36621 .62091 m .36877 .61774 L .36644 .61835 L F
.576 .864 .996 r
.27201 .62995 m .27381 .63078 L .27133 .63148 L F
.669 .803 .351 r
.32814 .65327 m .32659 .65638 L .3272 .65501 L F
.317 0 .071 r
.33054 .65295 m .32814 .65327 L .3272 .65501 L F
.438 0 0 r
.32812 .66907 m .32906 .66987 L .32706 .66754 L F
.32812 .66907 m .33072 .67079 L .32906 .66987 L F
.547 .151 .242 r
.71908 .33469 m .71883 .33724 L .71588 .33547 L F
.457 .748 .992 r
.7216 .33333 m .71908 .33469 L .71821 .33241 L F
.7216 .33333 m .72288 .33468 L .71908 .33469 L F
.743 .327 .261 r
.71908 .33469 m .72288 .33808 L .71883 .33724 L F
.855 .793 .79 r
.32425 .63983 m .32804 .63715 L .32437 .63703 L F
.318 .755 .967 r
.19838 .60065 m .19642 .59987 L .19423 .60001 L F
.197 .654 .943 r
.19838 .60065 m .19773 .59948 L .19642 .59987 L F
.19838 .60065 m .2021 .60069 L .19773 .59948 L F
.158 .632 .927 r
.36227 .51111 m .36449 .51133 L .36601 .51219 L F
.209 .59 .945 r
.36729 .51149 m .36601 .51219 L .36449 .51133 L F
.36729 .51149 m .36909 .51286 L .36601 .51219 L F
.32 .092 .403 r
.3947 .6745 m .39397 .67752 L .39205 .6777 L F
.206 .032 .41 r
.39397 .67752 m .39212 .68048 L .39205 .6777 L F
0 0 0 r
.31748 .54796 m .31435 .55129 L .31518 .54898 L F
.669 .443 .569 r
.4031 .57752 m .403 .58015 L .40095 .58036 L F
.67 .444 .569 r
.40556 .57938 m .4031 .57752 L .40582 .57658 L F
.40556 .57938 m .403 .58015 L .4031 .57752 L F
.65 .341 .435 r
.36215 .61757 m .36436 .61794 L .36254 .61513 L F
.698 .691 .84 r
.35362 .57531 m .35023 .57498 L .35271 .57464 L F
.659 .104 0 r
.35271 .57464 m .3566 .57695 L .35362 .57531 L F
.471 .126 .3 r
.19261 .56659 m .19618 .56365 L .19448 .56486 L F
.596 .469 .678 r
.33947 .64384 m .34174 .64327 L .34213 .63901 L F
.529 .479 .744 r
.33947 .64384 m .34227 .64603 L .34174 .64327 L F
.627 .809 .97 r
.3798 .55859 m .37521 .55824 L .37849 .55534 L F
.721 .279 .201 r
.38213 .56073 m .37763 .56029 L .3798 .55859 L F
.504 .559 .845 r
.3798 .55859 m .38336 .56136 L .38213 .56073 L F
.618 .371 .522 r
.38371 .67356 m .38122 .67167 L .38386 .67133 L F
.38371 .67356 m .3811 .67434 L .38122 .67167 L F
.629 .665 .866 r
.25174 .6206 m .24941 .62155 L .24739 .61845 L F
.809 .93 .913 r
.38269 .6599 m .37838 .66181 L .38092 .65942 L F
.33 .772 .964 r
.38387 .65948 m .38269 .6599 L .38092 .65942 L F
.053 .464 .883 r
.24776 .63178 m .24914 .63133 L .24616 .63062 L F
.24776 .63178 m .25058 .63284 L .24914 .63133 L F
.836 .548 .502 r
.34286 .69048 m .34067 .69258 L .33947 .68972 L F
.34286 .69048 m .34299 .6931 L .34067 .69258 L F
.31 0 0 r
.29072 .64925 m .2949 .64902 L .29319 .64948 L F
.464 0 0 r
.2949 .64902 m .29525 .65038 L .29319 .64948 L F
.2949 .64902 m .2969 .64972 L .29525 .65038 L F
.494 .725 .975 r
.2021 .60069 m .20252 .60293 L .20348 .60105 L F
.249 .422 .838 r
.20252 .60293 m .20542 .60457 L .20348 .60105 L F
.36 0 .07 r
.13865 .7338 m .13696 .73359 L .13497 .73549 L F
.403 .023 .2 r
.30804 .58518 m .30579 .58421 L .30808 .58256 L F
.30804 .58518 m .30493 .5864 L .30579 .58421 L F
.557 .618 .868 r
.34187 .62978 m .34295 .63183 L .34542 .63118 L F
.571 .242 .373 r
.2572 .55159 m .25583 .55458 L .25361 .55276 L F
.455 .14 .341 r
.25979 .55094 m .25583 .55458 L .2572 .55159 L F
.516 .484 .76 r
.28562 .54908 m .28686 .54503 L .28499 .54526 L F
.467 .699 .969 r
.24613 .6167 m .24542 .61861 L .24389 .61696 L F
.408 .633 .946 r
.24613 .6167 m .24739 .61845 L .24561 .61811 L F
0 .504 .762 r
.24638 .618 m .24739 .61845 L .24613 .6167 L F
.656 .898 .981 r
.25261 .6176 m .25073 .61911 L .24706 .61818 L F
.24769 .61792 m .24706 .61818 L .24638 .618 L F
.25261 .6176 m .24706 .61818 L .24769 .61792 L F
.53 0 0 r
.2419 .6142 m .24613 .6167 L .24389 .61696 L F
.73 .338 .307 r
.24427 .61589 m .24638 .618 L .24613 .6167 L F
.24427 .61589 m .24757 .61769 L .24638 .618 L F
.656 .898 .981 r
.25261 .6176 m .24638 .618 L .25158 .61664 L F
.73 .338 .307 r
.24757 .61769 m .24822 .61804 L .24638 .618 L F
0 .504 .762 r
.24651 .61806 m .25029 .619 L .24739 .61845 L F
.24676 .6181 m .25029 .619 L .24651 .61806 L F
.73 .338 .307 r
.24757 .61769 m .24594 .61863 L .24822 .61804 L F
.24427 .61589 m .24496 .61703 L .24757 .61769 L F
.24496 .61703 m .24712 .6177 L .24757 .61769 L F
.656 .898 .981 r
.25158 .61664 m .24757 .61769 L .25102 .61611 L F
.24757 .61769 m .24712 .6177 L .25102 .61611 L F
.451 .156 .372 r
.24822 .61804 m .25102 .61611 L .24712 .6177 L F
.656 .898 .981 r
.24757 .61769 m .24638 .618 L .24712 .6177 L F
.451 .156 .372 r
.24822 .61804 m .24712 .6177 L .24638 .618 L F
.73 .338 .307 r
.24496 .61703 m .2454 .61775 L .24712 .6177 L F
0 .504 .762 r
.24638 .618 m .24676 .6181 L .24651 .61806 L F
.408 .633 .946 r
.24561 .61811 m .24739 .61845 L .24542 .61861 L F
.73 .338 .307 r
.2454 .61775 m .24594 .61863 L .24757 .61769 L F
.451 .156 .372 r
.24822 .61804 m .2501 .6182 L .25079 .61665 L F
.24944 .6172 m .25079 .61665 L .25102 .61611 L F
.24822 .61804 m .25079 .61665 L .24944 .6172 L F
.561 .14 .2 r
.24753 .61822 m .2501 .6182 L .24822 .61804 L F
.24594 .61863 m .24846 .61837 L .24753 .61822 L F
.24846 .61837 m .2501 .6182 L .24753 .61822 L F
0 .504 .762 r
.25029 .619 m .25073 .61911 L .24739 .61845 L F
.397 .829 .957 r
.32966 .65904 m .33207 .65859 L .33008 .65807 L F
.562 .422 .649 r
.33027 .66223 m .33207 .65859 L .32966 .65904 L F
.691 .839 .41 r
.3272 .65501 m .32659 .65638 L .32538 .65853 L F
0 0 .068 r
.37384 .57791 m .3746 .5792 L .37484 .57894 L F
.125 0 .086 r
.37318 .57724 m .37384 .57791 L .37719 .57819 L F
.789 .981 .904 r
.37719 .57819 m .37384 .57791 L .37705 .57573 L F
0 0 .068 r
.37384 .57791 m .37484 .57894 L .37667 .577 L F
.125 0 .086 r
.37289 .57717 m .37384 .57791 L .37318 .57724 L F
.897 .968 .651 r
.3788 .57397 m .37719 .57819 L .37705 .57573 L F
.945 .7 .536 r
.31224 .5699 m .31344 .57152 L .31267 .56782 L F
.451 .387 .695 r
.31267 .56782 m .3155 .57079 L .31618 .56754 L F
.31267 .56782 m .31344 .57152 L .3155 .57079 L F
.167 0 0 r
.35947 .58689 m .35527 .58913 L .35545 .58636 L F
.35947 .58689 m .35821 .58845 L .35703 .58819 L F
.984 .703 .379 r
.35814 .58544 m .35821 .58845 L .35947 .58689 L F
0 .205 .721 r
.35872 .58707 m .35947 .58874 L .35821 .58845 L F
.35947 .58874 m .36017 .5903 L .35821 .58845 L F
.167 0 0 r
.35703 .58819 m .35821 .58845 L .35527 .58913 L F
.869 .868 .835 r
.35814 .58544 m .35947 .58689 L .36186 .58351 L F
.413 .533 .869 r
.34147 .56483 m .3436 .56444 L .34265 .56207 L F
.298 .029 .326 r
.34147 .56483 m .34108 .56733 L .3436 .56444 L F
.911 .547 .332 r
.34108 .56733 m .34147 .56483 L .3436 .56444 L F
.224 .225 .649 r
.32683 .57945 m .32545 .5822 L .3248 .57742 L F
.367 .209 .531 r
.32683 .57945 m .32503 .58103 L .32545 .5822 L F
.528 .322 .545 r
.35111 .55203 m .34863 .55481 L .35102 .55082 L F
.336 0 0 r
.1271 .72168 m .12857 .72151 L .12733 .72149 L F
.964 .937 .692 r
.34426 .56147 m .34445 .55713 L .34651 .56112 L F
.564 .374 .583 r
.32195 .5813 m .32503 .58103 L .3248 .57742 L F
.392 .246 .561 r
.3248 .57742 m .32503 .58103 L .32683 .57945 L F
.675 .976 .83 r
.33418 .56986 m .33258 .57226 L .33355 .56924 L F
.33418 .56986 m .33185 .57187 L .33258 .57226 L F
.621 .597 .805 r
.33007 .67828 m .3318 .67561 L .32988 .676 L F
0 0 .216 r
.33037 .67614 m .32988 .676 L .3318 .67561 L F
.33037 .67614 m .33007 .67828 L .32988 .676 L F
.32988 .676 m .33007 .67828 L .33037 .67614 L F
.621 .066 0 r
.29414 .6442 m .2958 .64512 L .29361 .64303 L F
.208 0 .293 r
.31941 .61217 m .32065 .61359 L .32166 .61192 L F
.31941 .61217 m .31884 .6144 L .32065 .61359 L F
0 0 0 r
.30153 .57806 m .30204 .57756 L .30428 .57724 L F
.336 0 .233 r
.3007 .57932 m .30224 .58135 L .30205 .57764 L F
.30198 .57764 m .30205 .57764 L .30204 .57756 L F
.3007 .57932 m .30205 .57764 L .30198 .57764 L F
.135 0 .155 r
.30204 .57756 m .30217 .57749 L .30428 .57724 L F
.398 .147 .414 r
.30205 .5775 m .30217 .57749 L .30495 .57438 L F
.30217 .57749 m .30428 .57724 L .30488 .57466 L F
.30217 .57749 m .30488 .57466 L .30495 .57438 L F
.029 0 .254 r
.30495 .57438 m .30428 .57724 L .30575 .57551 L F
.135 0 .155 r
.30217 .57749 m .30575 .57551 L .30428 .57724 L F
.30204 .57756 m .3021 .57757 L .30217 .57749 L F
.398 .147 .414 r
.30192 .57764 m .30428 .57724 L .30205 .5775 L F
.30291 .57765 m .30428 .57724 L .30192 .57764 L F
.135 0 .155 r
.30217 .57749 m .30503 .57799 L .30575 .57551 L F
.3021 .57757 m .30503 .57799 L .30217 .57749 L F
.398 .147 .414 r
.30215 .57788 m .30291 .57765 L .30211 .57764 L F
.337 0 .211 r
.3021 .57757 m .30482 .58058 L .30503 .57799 L F
.30204 .57756 m .30211 .57763 L .3021 .57757 L F
.30211 .57763 m .30482 .58058 L .3021 .57757 L F
.398 .147 .414 r
.30153 .57806 m .30215 .57788 L .30192 .57764 L F
.337 0 .211 r
.30211 .57763 m .30224 .58135 L .30482 .58058 L F
.30204 .57756 m .30205 .57764 L .30211 .57763 L F
.398 .147 .414 r
.30215 .57788 m .30211 .57764 L .30205 .57764 L F
.337 0 .211 r
.30205 .57764 m .30224 .58135 L .30211 .57763 L F
0 0 0 r
.30153 .57806 m .3007 .57932 L .30198 .57764 L F
.30153 .57806 m .30198 .57764 L .30204 .57756 L F
.398 .147 .414 r
.30194 .57766 m .30197 .57765 L .30192 .57764 L F
.30197 .57765 m .30205 .57764 L .30198 .57764 L F
.30197 .57765 m .30198 .57764 L .30192 .57764 L F
.30215 .57788 m .30205 .57764 L .30194 .57766 L F
.029 0 .254 r
.30495 .57438 m .30575 .57551 L .30632 .57349 L F
.393 .214 .517 r
.36885 .61511 m .36877 .61774 L .3708 .61724 L F
0 .127 .676 r
.39031 .52869 m .39008 .52986 L .38821 .52657 L F
0 0 .572 r
.39031 .52869 m .39183 .53235 L .39008 .52986 L F
0 .032 .588 r
.32189 .59276 m .32295 .59635 L .32354 .59496 L F
.73 .636 .074 r
.32295 .59635 m .32281 .59734 L .32354 .59496 L F
.32295 .59635 m .32278 .59868 L .32281 .59734 L F
0 0 .335 r
.40059 .54784 m .40179 .55134 L .40072 .54884 L F
.724 .518 .611 r
.32378 .608 m .32796 .60863 L .32758 .60569 L F
0 0 0 r
.32748 .59831 m .32621 .59941 L .32832 .59598 L F
.469 .845 .616 r
.32404 .60089 m .32621 .59941 L .32748 .59831 L F
.396 .285 .608 r
.32758 .60569 m .32796 .60863 L .3298 .60778 L F
.32758 .60569 m .32796 .60863 L .3298 .60778 L F
.607 .397 .571 r
.32165 .63993 m .32425 .63983 L .32437 .63703 L F
.8 .999 .815 r
.34051 .62326 m .33951 .62273 L .34096 .62143 L F
.523 .376 .622 r
.33918 .62594 m .33951 .62273 L .34051 .62326 L F
.432 .329 .637 r
.34335 .62628 m .34051 .62326 L .34347 .62456 L F
.34335 .62628 m .34295 .6278 L .34051 .62326 L F
.274 .318 .726 r
.18633 .58671 m .1889 .58907 L .18789 .5861 L F
0 0 0 r
.30153 .57806 m .29911 .58067 L .3007 .57932 L F
.921 .654 .516 r
.33965 .52235 m .34179 .52365 L .34161 .52098 L F
.668 .74 .241 r
.40699 .57331 m .40582 .57658 L .40651 .57466 L F
.655 .446 .59 r
.35503 .58044 m .35156 .58333 L .35165 .58058 L F
.35503 .58044 m .35473 .58317 L .35156 .58333 L F
.435 .256 .538 r
.35717 .58234 m .35503 .58044 L .35689 .57964 L F
.35717 .58234 m .35473 .58317 L .35503 .58044 L F
.076 0 0 r
.25863 .63344 m .25722 .63389 L .25436 .6342 L F
0 .409 .712 r
.25863 .63344 m .2588 .6334 L .25722 .63389 L F
.25863 .63344 m .26063 .63403 L .2588 .6334 L F
.434 .848 .964 r
.23189 .53473 m .23439 .53405 L .23677 .53466 L F
.433 .847 .964 r
.23677 .53466 m .23675 .53348 L .23783 .53385 L F
.23677 .53466 m .23439 .53405 L .23675 .53348 L F
.382 .44 .797 r
.38098 .581 m .38183 .58278 L .38372 .58287 L F
.601 .441 .637 r
.38109 .58612 m .38372 .58287 L .38183 .58278 L F
.372 .03 .25 r
.38534 .69048 m .38457 .69272 L .382 .69317 L F
.427 .081 .273 r
.3871 .69218 m .38534 .69048 L .38728 .68956 L F
.3871 .69218 m .38457 .69272 L .38534 .69048 L F
.339 0 .207 r
.27078 .54205 m .27306 .54154 L .27387 .53969 L F
.554 .318 .512 r
.27306 .54154 m .27596 .53854 L .27387 .53969 L F
.005 0 .046 r
.37716 .56753 m .37445 .5704 L .37541 .56853 L F
.838 .859 .86 r
.2338 .63024 m .23756 .62917 L .23593 .62718 L F
.248 .532 .919 r
.23756 .62917 m .23786 .62743 L .23593 .62718 L F
.23756 .62917 m .24147 .62986 L .23786 .62743 L F
0 .491 .744 r
.24212 .6301 m .24147 .62986 L .23756 .62917 L F
0 0 0 r
.27101 .5268 m .27215 .52617 L .27324 .52556 L F
.343 .819 .773 r
.27101 .5268 m .27008 .527 L .27215 .52617 L F
0 0 0 r
.21222 .57559 m .21006 .57728 L .21321 .57476 L F
.21372 .57448 m .21321 .57476 L .21491 .57345 L F
.21372 .57448 m .21222 .57559 L .21321 .57476 L F
.564 .534 .78 r
.36587 .58704 m .36855 .58672 L .36729 .58251 L F
.717 .641 .771 r
.34972 .52883 m .35102 .53349 L .34733 .53073 L F
.839 .831 .358 r
.35102 .53349 m .3519 .5292 L .34972 .52883 L F
.35181 .52965 m .35104 .53145 L .3519 .5292 L F
.35102 .53349 m .35104 .53145 L .35181 .52965 L F
.146 .149 .604 r
.34951 .53476 m .34733 .53073 L .35102 .53349 L F
.447 .008 .11 r
.35001 .53328 m .35032 .53312 L .35104 .53145 L F
.525 .454 .719 r
.35104 .53172 m .35269 .53798 L .35204 .53808 L F
.35104 .53172 m .35204 .53808 L .35132 .53714 L F
.86 .967 .642 r
.35104 .53172 m .35102 .53349 L .35104 .53166 L F
.146 .149 .604 r
.34926 .53498 m .34863 .5336 L .34951 .53476 L F
.34863 .5336 m .34733 .53073 L .34951 .53476 L F
.86 .967 .642 r
.35104 .53172 m .34926 .53498 L .35102 .53349 L F
.525 .454 .719 r
.35104 .53172 m .35132 .53714 L .35055 .53613 L F
.86 .967 .642 r
.35104 .53172 m .35104 .53166 L .35104 .53145 L F
.525 .454 .719 r
.35104 .53172 m .3503 .53836 L .34926 .53498 L F
.456 .063 .205 r
.35413 .53116 m .35104 .53172 L .35104 .53145 L F
.35413 .53116 m .3525 .53288 L .35104 .53172 L F
.594 .498 .715 r
.35516 .53715 m .35104 .53172 L .3525 .53288 L F
.35516 .53715 m .35269 .53798 L .35104 .53172 L F
.447 .008 .11 r
.35032 .53312 m .35413 .53116 L .35104 .53145 L F
.525 .454 .719 r
.35055 .53613 m .35204 .53808 L .3503 .53836 L F
0 .464 .841 r
.2149 .61166 m .21484 .61102 L .21319 .61052 L F
0 .45 .835 r
.2149 .61166 m .21678 .61226 L .21484 .61102 L F
.535 .319 .534 r
.39696 .593 m .39674 .59828 L .39419 .59569 L F
.1 0 .152 r
.39508 .59744 m .39419 .59569 L .39674 .59828 L F
.495 .185 .37 r
.32332 .61774 m .3231 .62057 L .32002 .62083 L F
.06 0 .264 r
.32455 .61949 m .32332 .61774 L .32509 .61702 L F
.32455 .61949 m .3231 .62057 L .32332 .61774 L F
0 0 0 r
.64219 .40362 m .63972 .40448 L .64251 .40102 L F
.64219 .40362 m .63976 .40454 L .63972 .40448 L F
.777 .677 .754 r
.33344 .63137 m .33568 .63063 L .33444 .62661 L F
.322 .393 .78 r
.33444 .62661 m .33568 .63063 L .33686 .62778 L F
.003 .101 .615 r
.33568 .63063 m .33767 .6324 L .33686 .62778 L F
.33568 .63063 m .337 .63291 L .33767 .6324 L F
.455 .451 .765 r
.30383 .56433 m .30212 .56512 L .30148 .56047 L F
.777 .823 .35 r
.30383 .56433 m .30268 .56782 L .30212 .56512 L F
0 0 .569 r
.3847 .57624 m .38612 .57969 L .38453 .57724 L F
.563 .393 .609 r
.35393 .5544 m .35111 .55203 L .35487 .55219 L F
.148 0 .279 r
.35661 .55116 m .35487 .55219 L .35721 .54884 L F
.558 .331 .527 r
.35661 .55116 m .35393 .5544 L .35487 .55219 L F
.621 .665 .871 r
.38786 .66181 m .3857 .66255 L .38387 .65948 L F
.157 .19 .646 r
.38776 .66387 m .3857 .66255 L .38786 .66181 L F
.38776 .66387 m .38628 .66527 L .3857 .66255 L F
0 0 .488 r
.39415 .53552 m .39556 .53802 L .39538 .53932 L F
0 0 .326 r
.39601 .54042 m .39538 .53932 L .39556 .53802 L F
.39601 .54042 m .39669 .54236 L .39538 .53932 L F
.153 .685 .857 r
.25361 .55276 m .25182 .55232 L .24947 .5525 L F
0 .12 .62 r
.25361 .55276 m .25409 .55278 L .25182 .55232 L F
.455 .14 .341 r
.25916 .55152 m .25826 .55419 L .25583 .55458 L F
.25979 .55094 m .25826 .55419 L .25916 .55152 L F
.727 .412 .446 r
.25826 .55419 m .25776 .55612 L .25764 .55602 L F
0 .12 .62 r
.25361 .55276 m .25583 .55458 L .25488 .55359 L F
.25394 .55277 m .25488 .55359 L .25409 .55278 L F
.823 .848 .867 r
.25409 .55278 m .25583 .55458 L .25457 .55367 L F
.727 .412 .446 r
.25826 .55419 m .25457 .55367 L .25583 .55458 L F
.25826 .55419 m .25764 .55602 L .25504 .55374 L F
.25504 .55374 m .25774 .55619 L .25457 .55367 L F
.25776 .55612 m .25774 .55619 L .25504 .55374 L F
0 .12 .62 r
.25361 .55276 m .25488 .55359 L .25394 .55277 L F
.934 .74 .616 r
.33739 .54963 m .33944 .54908 L .33945 .54806 L F
.33739 .54963 m .33838 .55163 L .33944 .54908 L F
.833 .803 .823 r
.30629 .62867 m .30213 .63325 L .30132 .62921 L F
.673 .125 0 r
.31416 .5342 m .3149 .53353 L .31544 .5317 L F
.31469 .53372 m .31718 .53548 L .3149 .53353 L F
.3151 .5346 m .31718 .53548 L .31469 .53372 L F
.607 .302 .426 r
.3149 .53353 m .31718 .53548 L .31749 .53348 L F
0 0 .024 r
.31616 .53656 m .31477 .53643 L .31718 .53548 L F
.31582 .53593 m .31718 .53548 L .3151 .5346 L F
.31583 .53595 m .31584 .53594 L .31582 .53593 L F
.31584 .53594 m .31718 .53548 L .31582 .53593 L F
.31537 .53563 m .3151 .5346 L .31416 .5342 L F
.673 .125 0 r
.31416 .5342 m .3151 .5346 L .31469 .53372 L F
.558 .399 .622 r
.31544 .5317 m .31531 .53541 L .31416 .5342 L F
.31531 .53541 m .31529 .53612 L .31416 .5342 L F
0 0 .024 r
.31616 .53656 m .3151 .5346 L .31537 .53563 L F
0 0 .28 r
.31644 .53304 m .31552 .53551 L .31551 .53491 L F
.31644 .53304 m .31551 .53491 L .31544 .5317 L F
.158 0 .246 r
.31831 .53167 m .31644 .53304 L .31716 .53064 L F
.187 .714 .714 r
.31831 .53167 m .31697 .53197 L .31644 .53304 L F
0 0 .28 r
.31552 .53551 m .31533 .53509 L .31544 .5317 L F
.31644 .53304 m .31544 .5317 L .31716 .53064 L F
.187 .714 .714 r
.31697 .53197 m .31439 .53256 L .31644 .53304 L F
0 0 .28 r
.31537 .53563 m .31529 .53612 L .31531 .53541 L F
.32 .301 .681 r
.31416 .5342 m .31537 .53563 L .31529 .53612 L F
.31537 .53563 m .31616 .53656 L .31529 .53612 L F
0 0 .28 r
.31542 .53578 m .31529 .53612 L .31537 .53563 L F
.642 .804 .961 r
.31427 .53425 m .31503 .53564 L .31644 .53304 L F
.31503 .53564 m .31529 .53612 L .31542 .53578 L F
0 0 .28 r
.31552 .53551 m .31542 .53578 L .31533 .53509 L F
.31542 .53578 m .31531 .53541 L .31533 .53509 L F
.642 .804 .961 r
.31503 .53564 m .31542 .53578 L .31644 .53304 L F
0 0 .024 r
.31616 .53656 m .31629 .53642 L .31583 .53595 L F
.31629 .53642 m .31718 .53548 L .31583 .53595 L F
.851 .725 .724 r
.63598 .40403 m .6376 .40809 L .63403 .40728 L F
.755 .636 .729 r
.63703 .40976 m .63403 .40728 L .6376 .40809 L F
.538 .567 .832 r
.63962 .407 m .6376 .40809 L .63598 .40403 L F
.197 0 .231 r
.63962 .407 m .63703 .40976 L .6376 .40809 L F
.615 .391 .554 r
.39696 .593 m .40014 .59332 L .39862 .59221 L F
.457 .118 .302 r
.39862 .59221 m .39873 .59257 L .39696 .593 L F
.342 .418 .796 r
.39862 .59221 m .40014 .59332 L .39925 .59221 L F
.61 .507 .712 r
.39941 .59241 m .40014 .59332 L .39796 .5931 L F
.39958 .59237 m .40014 .59332 L .39941 .59241 L F
.317 .373 .762 r
.40157 .59223 m .40014 .59332 L .39873 .5909 L F
.342 .418 .796 r
.39925 .59221 m .40014 .59332 L .40157 .59223 L F
.329 .049 .328 r
.40157 .59223 m .39934 .5946 L .39873 .59257 L F
.39925 .59221 m .39873 .59257 L .39862 .59221 L F
.40157 .59223 m .39873 .59257 L .39925 .59221 L F
.61 .507 .712 r
.39873 .59257 m .39796 .5931 L .39696 .593 L F
.39941 .59241 m .39796 .5931 L .39873 .59257 L F
.457 .118 .302 r
.39873 .59257 m .39934 .5946 L .39696 .593 L F
.61 .507 .712 r
.39873 .5909 m .39958 .59237 L .39696 .593 L F
0 0 .186 r
.39755 .59461 m .39696 .593 L .39934 .5946 L F
.39755 .59461 m .39674 .59828 L .39696 .593 L F
.566 .517 .759 r
.34937 .57237 m .35271 .57464 L .35023 .57498 L F
.175 0 .258 r
.37445 .5704 m .37193 .57359 L .37259 .5715 L F
.692 .897 .535 r
.33575 .63509 m .33694 .63389 L .33767 .6324 L F
0 0 .444 r
.29549 .62421 m .29558 .62449 L .29407 .62328 L F
.29549 .62421 m .29726 .62674 L .29558 .62449 L F
.158 .151 .599 r
.29726 .62674 m .29621 .62733 L .29558 .62449 L F
.889 .985 .716 r
.38336 .56136 m .3811 .56283 L .38213 .56073 L F
.392 .779 .99 r
.38336 .56136 m .38438 .56038 L .38213 .56073 L F
.127 0 .223 r
.29708 .60745 m .29515 .60843 L .29774 .60517 L F
0 0 0 r
.29387 .61064 m .29515 .60843 L .29708 .60745 L F
.368 .227 .555 r
.35476 .61703 m .35289 .61497 L .35361 .61422 L F
.35476 .61703 m .35286 .61815 L .35289 .61497 L F
.383 .131 .403 r
.21006 .57728 m .20853 .58054 L .20726 .58084 L F
0 0 .153 r
.21095 .57861 m .21006 .57728 L .21222 .57559 L F
.21095 .57861 m .20853 .58054 L .21006 .57728 L F
.404 .775 .993 r
.34276 .51307 m .34401 .5117 L .3412 .51042 L F
.34276 .51307 m .34597 .51278 L .34401 .5117 L F
.833 .803 .823 r
.30629 .62867 m .30132 .62921 L .30275 .62881 L F
.57 .934 .922 r
.30855 .62748 m .30629 .62867 L .30275 .62881 L F
.424 .865 .796 r
.36796 .58109 m .36994 .58024 L .3707 .58018 L F
.967 .909 .555 r
.36906 .58194 m .36994 .58024 L .3707 .58018 L F
0 0 0 r
.3707 .58018 m .37185 .57899 L .37289 .57717 L F
.726 .618 .737 r
.32342 .5177 m .32568 .51868 L .32116 .51773 L F
.465 .674 .955 r
.32568 .51667 m .32568 .51868 L .32342 .5177 L F
.053 .282 .773 r
.32568 .51667 m .32743 .52011 L .32568 .51868 L F
.4 .149 .415 r
.2905 .58487 m .29258 .58274 L .28997 .58365 L F
.742 .645 .752 r
.29258 .58274 m .2905 .58487 L .28997 .58365 L F
.3 .455 .848 r
.34597 .51278 m .34667 .51509 L .3477 .51288 L F
.574 .935 .79 r
.35003 .63617 m .34774 .63775 L .3452 .63863 L F
.557 .754 .97 r
.26023 .62289 m .25982 .62519 L .25782 .62354 L F
.26023 .62289 m .26204 .62474 L .25982 .62519 L F
.687 .949 .681 r
.37745 .65113 m .37492 .65384 L .37658 .65265 L F
.906 .773 .703 r
.34108 .56733 m .34245 .57106 L .34317 .5683 L F
0 0 0 r
.38212 .64643 m .38037 .64808 L .37898 .64881 L F
.38037 .64808 m .37745 .65113 L .37898 .64881 L F
.625 .315 .425 r
.3335 .55087 m .33136 .54904 L .33446 .54929 L F
.446 .88 .881 r
.33739 .54963 m .3335 .55087 L .33446 .54929 L F
0 .522 .777 r
.31093 .65937 m .31261 .66005 L .31544 .66048 L F
.491 .295 .541 r
.38776 .66387 m .38472 .66702 L .38628 .66527 L F
.647 .718 .9 r
.36772 .66331 m .36702 .66615 L .3658 .66436 L F
.36772 .66331 m .3694 .66522 L .36702 .66615 L F
0 0 .028 r
.18765 .59322 m .18675 .59558 L .1888 .59199 L F
.975 .742 .523 r
.71588 .33547 m .71416 .33417 L .71499 .33189 L F
.922 .53 .181 r
.71588 .33547 m .71551 .33731 L .71416 .33417 L F
.567 .1 .107 r
.71883 .33724 m .71551 .33731 L .71588 .33547 L F
.286 0 .165 r
.39647 .58106 m .3962 .58292 L .394 .58335 L F
.355 0 .18 r
.39932 .58162 m .3962 .58292 L .39647 .58106 L F
.327 0 0 r
.40095 .58036 m .39932 .58162 L .39647 .58106 L F
.609 .59 .806 r
.12727 .72208 m .12857 .72151 L .1271 .72168 L F
.306 .261 .643 r
.35738 .53356 m .35958 .53556 L .35835 .53055 L F
.201 .524 .919 r
.27072 .63692 m .27353 .63933 L .27498 .63957 L F
.178 0 .261 r
.22845 .5692 m .22745 .56713 L .22944 .56685 L F
.22845 .5692 m .22665 .5701 L .22745 .56713 L F
.779 .449 .429 r
.30825 .57236 m .31344 .57152 L .31224 .5699 L F
.30825 .57236 m .31281 .57336 L .31344 .57152 L F
.247 0 .222 r
.31344 .57152 m .31281 .57336 L .3155 .57079 L F
.31344 .57152 m .31281 .57336 L .3155 .57079 L F
0 .376 .838 r
.38403 .63555 m .38375 .63655 L .3817 .6356 L F
.38403 .63555 m .38565 .6374 L .38375 .63655 L F
.614 .574 .785 r
.3211 .53004 m .32218 .52626 L .3195 .52668 L F
.3211 .53004 m .32331 .52978 L .32218 .52626 L F
.601 .393 .571 r
.321 .5323 m .32331 .52978 L .3211 .53004 L F
.546 .468 .718 r
.36417 .58049 m .36399 .5826 L .36796 .58109 L F
.462 .678 .958 r
.36399 .5826 m .36729 .58251 L .36796 .58109 L F
.05 .296 .785 r
.20608 .6061 m .20668 .6046 L .20542 .60457 L F
.20608 .6061 m .20854 .60804 L .20668 .6046 L F
.174 .321 .774 r
.20608 .6061 m .20743 .60827 L .20854 .60804 L F
0 0 0 r
.38222 .64693 m .38212 .64643 L .38418 .64559 L F
.38222 .64693 m .38037 .64808 L .38212 .64643 L F
.227 0 .267 r
.39697 .67391 m .39397 .67752 L .3947 .6745 L F
.556 .224 .362 r
.23532 .55783 m .23341 .56166 L .2314 .56082 L F
.433 .098 .297 r
.23605 .56092 m .23532 .55783 L .23772 .55761 L F
.23605 .56092 m .23341 .56166 L .23532 .55783 L F
.338 .767 .972 r
.35477 .53918 m .35693 .53897 L .35879 .53968 L F
.67 .129 0 r
.35968 .54156 m .35879 .53968 L .35693 .53897 L F
0 0 0 r
.35636 .54285 m .35968 .54156 L .35581 .5401 L F
.76 .992 .786 r
.35968 .54156 m .35798 .54227 L .3588 .54147 L F
.67 .129 0 r
.35968 .54156 m .36073 .54166 L .35879 .53968 L F
.672 .13 0 r
.35879 .53968 m .36264 .54283 L .36138 .53906 L F
.35879 .53968 m .36148 .54243 L .36264 .54283 L F
.664 .227 .203 r
.35581 .5401 m .35968 .54156 L .35693 .53897 L F
.76 .992 .786 r
.35968 .54156 m .3588 .54147 L .3603 .54001 L F
.67 .129 0 r
.35968 .54156 m .36148 .54243 L .36073 .54166 L F
.635 .545 .736 r
.36169 .5381 m .35879 .53968 L .36138 .53906 L F
.205 .341 .781 r
.25633 .61988 m .2553 .622 L .25402 .62045 L F
.25633 .61988 m .25782 .62354 L .2553 .622 L F
.612 .577 .79 r
.38011 .57804 m .38098 .581 L .3835 .58017 L F
.563 .42 .645 r
.38098 .581 m .38372 .58287 L .3835 .58017 L F
.435 .575 .895 r
.72617 .29563 m .72451 .29801 L .72279 .29499 L F
.55 .388 .615 r
.72617 .29563 m .72342 .29898 L .72451 .29801 L F
.534 .495 .759 r
.34702 .54601 m .34831 .54169 L .34598 .54307 L F
.34702 .54601 m .34943 .54564 L .34831 .54169 L F
.617 .386 .544 r
.34702 .54601 m .35055 .5486 L .34943 .54564 L F
.34702 .54601 m .34595 .55004 L .35055 .5486 L F
.397 .259 .574 r
.37349 .61034 m .37136 .61196 L .37309 .61351 L F
.76 .296 .148 r
.24242 .54472 m .2431 .54701 L .24572 .54585 L F
0 0 0 r
.2431 .54701 m .24809 .54597 L .24572 .54585 L F
.453 .22 .47 r
.36152 .55159 m .36375 .55149 L .36381 .54908 L F
.888 .908 .835 r
.36598 .54492 m .36381 .54908 L .36232 .54765 L F
0 0 .343 r
.36381 .54908 m .36542 .54986 L .36232 .54765 L F
.36381 .54908 m .36375 .55149 L .36542 .54986 L F
.081 0 .319 r
.38916 .68832 m .38771 .68714 L .38962 .68609 L F
.38916 .68832 m .38728 .68956 L .38771 .68714 L F
.516 .484 .76 r
.28562 .54908 m .28784 .54851 L .28686 .54503 L F
.652 .452 .6 r
.35855 .55492 m .36141 .55484 L .36152 .55159 L F
.469 .301 .57 r
.36152 .55159 m .36141 .55484 L .36375 .55149 L F
.61 .928 .967 r
.37838 .66181 m .37608 .66291 L .37336 .66272 L F
.408 .197 .479 r
.39361 .56713 m .39094 .56782 L .39377 .56404 L F
.297 0 .204 r
.39048 .57012 m .39094 .56782 L .39361 .56713 L F
.781 .908 .928 r
.3412 .58475 m .34244 .58573 L .34562 .58361 L F
.666 .479 .622 r
.3073 .54808 m .30433 .54892 L .3044 .54616 L F
.3073 .54808 m .30433 .54892 L .3044 .54616 L F
.701 .903 .968 r
.33272 .6547 m .33355 .65667 L .33054 .65295 L F
0 .217 .739 r
.39183 .53235 m .39415 .53552 L .3929 .53389 L F
.66 .773 .933 r
.32531 .66378 m .32506 .66634 L .32318 .66529 L F
.32531 .66378 m .328 .66534 L .32506 .66634 L F
.32506 .66634 m .32531 .66378 L .32318 .66529 L F
.32506 .66634 m .328 .66534 L .32531 .66378 L F
.37 0 0 r
.36909 .51286 m .37071 .51336 L .37252 .51284 L F
.596 .049 0 r
.37252 .51284 m .37071 .51336 L .37387 .51379 L F
.379 .113 .378 r
.37717 .69947 m .37648 .70287 L .3745 .70235 L F
.451 .244 .507 r
.37964 .69644 m .37962 .699 L .37717 .69947 L F
.462 .184 .406 r
.37887 .70269 m .37717 .69947 L .37962 .699 L F
.37887 .70269 m .37648 .70287 L .37717 .69947 L F
.273 .036 .361 r
.35965 .54752 m .35661 .55116 L .35721 .54884 L F
.233 0 0 r
.24416 .63058 m .24147 .62986 L .24212 .6301 L F
.742 .645 .752 r
.29258 .58274 m .29399 .58686 L .2905 .58487 L F
.35 0 0 r
.2905 .58487 m .29399 .58686 L .29201 .58574 L F
.974 .708 .466 r
.29201 .58574 m .29358 .58942 L .29399 .58686 L F
.752 .65 .748 r
.29598 .58306 m .29399 .58686 L .29258 .58274 L F
.278 .744 .947 r
.29258 .58274 m .29466 .58252 L .29598 .58306 L F
.301 .325 .72 r
.29399 .58686 m .29466 .58252 L .29598 .58306 L F
.29399 .58686 m .29548 .58606 L .29466 .58252 L F
.12 .252 .727 r
.29422 .5849 m .29399 .58686 L .29258 .58274 L F
.808 .901 .907 r
.29201 .58574 m .29399 .58686 L .29422 .5849 L F
.089 0 .296 r
.29399 .58686 m .29358 .58942 L .29548 .58606 L F
.659 .898 .981 r
.71231 .34773 m .71321 .34541 L .71533 .34556 L F
.71231 .34773 m .71122 .3466 L .71321 .34541 L F
.234 .422 .843 r
.71231 .34773 m .71321 .34541 L .71122 .3466 L F
.637 .592 .787 r
.71533 .34556 m .71588 .34831 L .71231 .34773 L F
.196 0 0 r
.71588 .34831 m .71541 .34839 L .71231 .34773 L F
.234 .422 .843 r
.71231 .34773 m .71541 .34839 L .71321 .34541 L F
.65 .969 .873 r
.3417 .50671 m .33855 .5085 L .34198 .50621 L F
0 0 0 r
.34198 .50621 m .34383 .50583 L .3417 .50671 L F
.658 .664 .844 r
.33053 .56677 m .32963 .57103 L .32868 .56704 L F
.61 .3 .419 r
.33136 .54904 m .33035 .55161 L .32788 .5513 L F
.625 .315 .425 r
.3335 .55087 m .33035 .55161 L .33136 .54904 L F
.69 .476 .593 r
.35331 .57228 m .34937 .57237 L .34869 .57095 L F
.35331 .57228 m .35271 .57464 L .34937 .57237 L F
0 .115 .64 r
.22409 .6071 m .22336 .60872 L .22247 .60503 L F
.086 .264 .749 r
.22409 .6071 m .22554 .61059 L .22336 .60872 L F
.844 .567 .519 r
.34624 .69657 m .34263 .6985 L .34264 .69584 L F
.34624 .69657 m .3462 .69911 L .34263 .6985 L F
0 0 0 r
.21894 .54347 m .21581 .5455 L .21774 .54428 L F
.013 0 0 r
.21774 .54428 m .22119 .54265 L .21894 .54347 L F
.172 .531 .922 r
.3077 .54598 m .30793 .54424 L .30673 .54448 L F
.558 .455 .694 r
.31091 .5451 m .3073 .54808 L .3077 .54598 L F
0 .032 .588 r
.32189 .59276 m .32354 .59496 L .32307 .59211 L F
.511 .031 .053 r
.35165 .58058 m .35017 .58185 L .34777 .58081 L F
.989 .804 .566 r
.35165 .58058 m .35156 .58333 L .35017 .58185 L F
0 0 0 r
.29774 .60517 m .29934 .60229 L .29994 .60467 L F
.357 .062 .321 r
.29708 .60745 m .29774 .60517 L .29994 .60467 L F
.143 0 0 r
.35013 .66493 m .35575 .66492 L .35159 .66517 L F
.43 .321 .629 r
.33965 .57634 m .34212 .57346 L .34002 .57399 L F
.33965 .57634 m .34239 .57636 L .34212 .57346 L F
.41 .175 .445 r
.33965 .57634 m .3421 .57873 L .34239 .57636 L F
.33965 .57634 m .33984 .57968 L .3421 .57873 L F
.386 .348 .694 r
.317 .5579 m .31757 .56225 L .31992 .56068 L F
.389 .355 .699 r
.31757 .56225 m .32014 .56391 L .31992 .56068 L F
0 0 0 r
.38901 .59228 m .39173 .58963 L .38927 .58994 L F
.367 .122 .404 r
.34002 .57399 m .34212 .57346 L .34245 .57106 L F
0 0 .507 r
.34314 .57164 m .34245 .57106 L .34212 .57346 L F
.449 .135 .339 r
.34245 .57106 m .34449 .57328 L .34515 .57162 L F
0 0 .507 r
.34314 .57164 m .34449 .57328 L .34245 .57106 L F
0 0 .396 r
.40764 .56574 m .40636 .56477 L .40529 .5636 L F
.40764 .56574 m .40674 .56732 L .40636 .56477 L F
.563 .934 .909 r
.26437 .62443 m .26785 .62324 L .26599 .6242 L F
.512 .515 .796 r
.34288 .55443 m .34463 .55558 L .34457 .55527 L F
.686 .334 .371 r
.34695 .55465 m .34574 .55586 L .34457 .55527 L F
.34391 .55449 m .34457 .55527 L .34288 .55443 L F
.34695 .55465 m .34457 .55527 L .34391 .55449 L F
.107 .216 .695 r
.34375 .55137 m .34457 .55527 L .34586 .55318 L F
.34457 .55527 m .34463 .55558 L .3447 .55543 L F
.747 .35 .299 r
.34288 .55443 m .34445 .55713 L .34463 .55558 L F
.686 .334 .371 r
.3444 .55519 m .34445 .55713 L .34288 .55443 L F
.34574 .55586 m .34551 .55608 L .34486 .55557 L F
.34574 .55586 m .34486 .55557 L .3449 .55544 L F
.186 0 .203 r
.34463 .55558 m .34445 .55713 L .34486 .55557 L F
.34463 .55558 m .34486 .55557 L .3447 .55543 L F
.686 .334 .371 r
.34551 .55608 m .34445 .55713 L .3444 .55519 L F
0 0 0 r
.3471 .55547 m .34445 .55713 L .34695 .55465 L F
.186 0 .203 r
.34486 .55557 m .34445 .55713 L .3471 .55547 L F
.686 .334 .371 r
.3449 .55544 m .34486 .55557 L .3444 .55519 L F
.186 0 .203 r
.3447 .55543 m .3471 .55547 L .34586 .55318 L F
.34486 .55557 m .3471 .55547 L .3447 .55543 L F
.107 .216 .695 r
.34457 .55527 m .3447 .55543 L .34586 .55318 L F
.512 .515 .796 r
.34288 .55443 m .34457 .55527 L .34375 .55137 L F
0 0 0 r
.3471 .55547 m .34695 .55465 L .34863 .55481 L F
.556 .832 .997 r
.32342 .5177 m .32116 .51773 L .32197 .516 L F
.226 .056 .43 r
.32605 .51383 m .32568 .51667 L .32342 .5177 L F
.32605 .51383 m .32568 .51667 L .32342 .5177 L F
.48 .791 .999 r
.32197 .516 m .32568 .51667 L .32342 .5177 L F
0 0 0 r
.35348 .57224 m .35331 .57228 L .3553 .57071 L F
.35348 .57224 m .35271 .57464 L .35331 .57228 L F
.798 .386 .269 r
.30198 .64809 m .30345 .64607 L .30184 .64631 L F
.437 .074 .248 r
.30506 .64799 m .30345 .64607 L .30198 .64809 L F
.30506 .64799 m .30604 .64572 L .30345 .64607 L F
.41 .339 .667 r
.32165 .63993 m .32433 .6426 L .32425 .63983 L F
.32165 .63993 m .32236 .64308 L .32433 .6426 L F
.433 .716 .984 r
.64125 .39956 m .64373 .39939 L .64251 .40102 L F
.377 .15 .437 r
.64456 .40263 m .64251 .40102 L .64373 .39939 L F
.64456 .40263 m .64219 .40362 L .64251 .40102 L F
.044 0 0 r
.29201 .53322 m .2901 .53503 L .28817 .53568 L F
.395 .301 .63 r
.29201 .53322 m .29249 .53657 L .29449 .53523 L F
.648 .215 .207 r
.29449 .53523 m .2901 .53503 L .29201 .53322 L F
.603 .677 .893 r
.29806 .55144 m .29983 .55434 L .30245 .5536 L F
.518 .001 0 r
.3364 .58692 m .33446 .58818 L .33257 .58688 L F
.327 0 0 r
.3382 .58774 m .3364 .58692 L .3382 .58543 L F
.3382 .58774 m .33446 .58818 L .3364 .58692 L F
.432 .01 .137 r
.31204 .6324 m .31613 .62965 L .31473 .63255 L F
.31204 .6324 m .31249 .63106 L .31613 .62965 L F
.404 .129 .379 r
.31824 .62936 m .31613 .62965 L .31884 .62746 L F
.437 .089 .275 r
.31824 .62936 m .31473 .63255 L .31613 .62965 L F
.16 0 0 r
.21915 .57415 m .2168 .57381 L .21491 .57345 L F
.083 0 .2 r
.22155 .5709 m .22097 .57335 L .21915 .57415 L F
.776 .592 .65 r
.22097 .57335 m .2168 .57381 L .21915 .57415 L F
0 .031 .568 r
.28691 .60275 m .28864 .60395 L .2884 .60097 L F
.28691 .60275 m .28768 .60531 L .28864 .60395 L F
.449 .307 .596 r
.21918 .59627 m .21972 .60002 L .21794 .5995 L F
.403 .38 .72 r
.21972 .60002 m .22046 .60105 L .21794 .5995 L F
.14 .031 .457 r
.1871 .57723 m .18834 .5767 L .18845 .57374 L F
.193 .159 .589 r
.1871 .57723 m .18879 .57922 L .18834 .5767 L F
.297 .18 .547 r
.1871 .57723 m .18717 .57994 L .18879 .57922 L F
.466 .231 .473 r
.36616 .55855 m .36343 .56152 L .36366 .56111 L F
.07 .046 .521 r
.32949 .59203 m .33002 .5953 L .32832 .59598 L F
0 0 0 r
.33002 .5953 m .32748 .59831 L .32832 .59598 L F
.572 .594 .836 r
.18675 .59558 m .18864 .59936 L .19102 .59844 L F
0 0 0 r
.24369 .53248 m .24492 .53185 L .24259 .53253 L F
.408 .305 .625 r
.34213 .63901 m .34381 .64307 L .34388 .63905 L F
.34213 .63901 m .34174 .64327 L .34381 .64307 L F
.654 .418 .55 r
.39632 .56436 m .39361 .56713 L .39377 .56404 L F
.783 .731 .804 r
.3347 .58265 m .33102 .58058 L .33344 .57916 L F
.3347 .58265 m .33233 .58364 L .33102 .58058 L F
.676 .692 .857 r
.33732 .58021 m .3347 .58265 L .33344 .57916 L F
.387 .76 .992 r
.38769 .60432 m .3897 .6055 L .38659 .60492 L F
.777 .541 .579 r
.3897 .6055 m .38921 .60849 L .38659 .60492 L F
0 .246 .666 r
.38965 .60523 m .3897 .6055 L .38769 .60432 L F
.38965 .60523 m .39091 .60606 L .3897 .6055 L F
.762 .527 .578 r
.39308 .60847 m .3897 .6055 L .39091 .60606 L F
.39308 .60847 m .38921 .60849 L .3897 .6055 L F
.63 .252 .307 r
.29466 .58252 m .29911 .58067 L .29598 .58306 L F
.29466 .58252 m .29762 .58291 L .29911 .58067 L F
.211 0 .054 r
.29911 .58067 m .29978 .58223 L .3007 .57932 L F
.29911 .58067 m .29762 .58291 L .29978 .58223 L F
.139 .294 .761 r
.3571 .6288 m .35512 .62731 L .35659 .62712 L F
.131 .329 .794 r
.35771 .63076 m .35512 .62731 L .3571 .6288 L F
.561 .036 0 r
.3527 .51555 m .35197 .51716 L .34921 .51526 L F
0 0 0 r
.35401 .51543 m .3527 .51555 L .35521 .51545 L F
.471 .692 .963 r
.22772 .61004 m .22727 .61195 L .22554 .61059 L F
.22772 .61004 m .22963 .61174 L .22727 .61195 L F
.155 .417 .858 r
.38791 .63852 m .38734 .64012 L .38565 .6374 L F
0 0 0 r
.38791 .63852 m .38626 .64235 L .38734 .64012 L F
.193 0 0 r
.30335 .63351 m .30739 .63314 L .30574 .63354 L F
.302 0 0 r
.30739 .63314 m .30785 .63423 L .30574 .63354 L F
.30739 .63314 m .3097 .63329 L .30785 .63423 L F
.705 .94 .961 r
.35386 .67058 m .35171 .67194 L .35007 .67132 L F
.386 .348 .694 r
.317 .5579 m .31992 .56068 L .31897 .55731 L F
.419 .226 .51 r
.382 .69317 m .38195 .69605 L .37964 .69644 L F
.505 .287 .516 r
.38198 .69843 m .37964 .69644 L .38195 .69605 L F
.38198 .69843 m .37962 .699 L .37964 .69644 L F
.538 .567 .832 r
.63962 .407 m .63598 .40403 L .63976 .40454 L F
0 0 0 r
.64219 .40362 m .63962 .407 L .63976 .40454 L F
.931 .706 .577 r
.16959 .65211 m .17066 .64943 L .16799 .64838 L F
.16959 .65211 m .17066 .64943 L .16799 .64838 L F
.807 .767 .816 r
.35785 .60431 m .36168 .60764 L .3563 .60875 L F
.523 .055 .085 r
.3563 .60875 m .36168 .60764 L .35815 .60949 L F
0 .3 .763 r
.36187 .60728 m .36168 .60764 L .35785 .60431 L F
.478 .877 .714 r
.35815 .60949 m .36168 .60764 L .36187 .60728 L F
.666 .497 .646 r
.36109 .60936 m .36272 .60812 L .36168 .60764 L F
0 .433 .825 r
.36187 .60728 m .36272 .60812 L .36168 .60764 L F
.505 .172 .336 r
.3745 .70235 m .37363 .70502 L .37101 .70526 L F
.33 .011 .265 r
.37586 .70441 m .3745 .70235 L .37648 .70287 L F
.37586 .70441 m .37363 .70502 L .3745 .70235 L F
.468 .157 .355 r
.36264 .54283 m .36158 .54509 L .35967 .54529 L F
.589 .536 .764 r
.36138 .53906 m .36264 .54283 L .36505 .54191 L F
.995 .852 .581 r
.36148 .54243 m .36158 .54509 L .36264 .54283 L F
.401 .243 .55 r
.33915 .51093 m .34198 .50621 L .33855 .5085 L F
.466 .231 .473 r
.36616 .55855 m .36587 .56094 L .36343 .56152 L F
1 .804 .481 r
.3243 .65719 m .32538 .65853 L .32436 .66093 L F
.691 .839 .41 r
.3272 .65501 m .32538 .65853 L .3243 .65719 L F
.701 .311 .305 r
.32538 .65853 m .3281 .66106 L .32436 .66093 L F
.52 .513 .789 r
.37241 .60271 m .37554 .60672 L .37478 .60213 L F
.272 .499 .892 r
.23386 .61051 m .23314 .61281 L .23179 .61101 L F
.23386 .61051 m .23583 .61318 L .23314 .61281 L F
0 .534 .797 r
.23314 .61281 m .23583 .61318 L .23788 .61376 L F
.258 0 0 r
.33751 .60851 m .33675 .60876 L .33378 .60835 L F
.71 .333 .332 r
.34056 .60822 m .33896 .60811 L .33876 .60743 L F
.33896 .60811 m .33751 .60801 L .33876 .60743 L F
0 0 0 r
.33858 .60683 m .33876 .60743 L .33751 .60851 L F
.33948 .60542 m .33876 .60743 L .33858 .60683 L F
.494 .887 .721 r
.33876 .60743 m .33675 .60876 L .33751 .60851 L F
0 0 .535 r
.31601 .65518 m .3153 .65574 L .31413 .65206 L F
.043 .521 .886 r
.31712 .656 m .3153 .65574 L .31601 .65518 L F
0 .248 .76 r
.31832 .65901 m .3153 .65574 L .31712 .656 L F
.621 .377 .526 r
.37149 .55454 m .37373 .55828 L .36834 .55805 L F
.43 .179 .43 r
.37432 .55195 m .37355 .55514 L .37149 .55454 L F
.496 .334 .591 r
.37411 .55725 m .37149 .55454 L .37355 .55514 L F
.37411 .55725 m .37373 .55828 L .37149 .55454 L F
.364 .744 .988 r
.36051 .51051 m .36449 .51133 L .36227 .51111 L F
0 0 .262 r
.33898 .59926 m .33964 .60034 L .34152 .59872 L F
.693 .762 .905 r
.32273 .54204 m .32721 .54343 L .32601 .54144 L F
.98 .775 .556 r
.32273 .54204 m .32681 .54544 L .32721 .54343 L F
.71 .937 .961 r
.3271 .54176 m .32721 .54343 L .32882 .54217 L F
.31 .126 .462 r
.32721 .54343 m .32681 .54544 L .32882 .54217 L F
.571 .603 .846 r
.3271 .54176 m .33082 .54365 L .32978 .5408 L F
.573 .174 .248 r
.32978 .5408 m .32806 .54152 L .3271 .54176 L F
.054 .372 .839 r
.32632 .54196 m .32721 .54343 L .3271 .54176 L F
.571 .603 .846 r
.3271 .54176 m .32888 .54474 L .33082 .54365 L F
.573 .174 .248 r
.32806 .54152 m .32556 .54256 L .3271 .54176 L F
.054 .372 .839 r
.32601 .54144 m .32632 .54196 L .3271 .54176 L F
.551 .722 .953 r
.25462 .54268 m .25533 .53961 L .25417 .54122 L F
0 .286 .786 r
.36278 .51592 m .36359 .51756 L .36372 .51632 L F
.328 .705 .982 r
.36359 .51756 m .36473 .51709 L .36372 .51632 L F
.675 .408 .51 r
.364 .53926 m .3677 .5364 L .3639 .53623 L F
.364 .53926 m .36756 .53889 L .3677 .5364 L F
.614 .788 .965 r
.36505 .54191 m .36907 .54267 L .36722 .54117 L F
.515 .187 .349 r
.36598 .54492 m .36907 .54267 L .36505 .54191 L F
.627 .367 .506 r
.3677 .5364 m .3721 .53661 L .369 .53618 L F
.3677 .5364 m .36756 .53889 L .3721 .53661 L F
.067 0 .326 r
.36907 .54267 m .36756 .53889 L .36722 .54117 L F
.36907 .54267 m .3721 .53661 L .36756 .53889 L F
.36907 .54267 m .37039 .54184 L .3721 .53661 L F
.511 .338 .583 r
.36853 .54463 m .37039 .54184 L .36907 .54267 L F
.95 .611 .21 r
.38381 .61454 m .38449 .61751 L .38553 .61801 L F
0 0 0 r
.38449 .61751 m .3833 .62016 L .38251 .62117 L F
.95 .611 .21 r
.38387 .61495 m .38449 .61751 L .38381 .61454 L F
.38373 .61439 m .38387 .61495 L .38381 .61454 L F
.262 .199 .595 r
.38409 .6152 m .38449 .61751 L .38373 .61439 L F
.439 .228 .495 r
.38409 .6152 m .3833 .62016 L .38449 .61751 L F
.38409 .6152 m .38546 .61981 L .38462 .61995 L F
.38399 .61579 m .38462 .61995 L .3833 .62016 L F
.38409 .6152 m .38462 .61995 L .38399 .61579 L F
.977 .774 .563 r
.19382 .60854 m .19122 .60943 L .19229 .6071 L F
.19382 .60854 m .19122 .60943 L .19229 .6071 L F
.474 .506 .81 r
.22226 .59205 m .22004 .5927 L .21852 .59042 L F
.259 .142 .524 r
.22193 .5946 m .22004 .5927 L .22226 .59205 L F
.22193 .5946 m .21918 .59627 L .22004 .5927 L F
.179 .359 .806 r
.32887 .56315 m .33053 .56677 L .3279 .56495 L F
.377 .367 .721 r
.3279 .56495 m .33053 .56677 L .32868 .56704 L F
.269 0 .013 r
.27289 .61943 m .27606 .6179 L .27674 .61662 L F
0 0 0 r
.27674 .61662 m .27781 .61617 L .27901 .61421 L F
.27674 .61662 m .27606 .6179 L .27781 .61617 L F
.785 .805 .868 r
.32116 .51773 m .31717 .5179 L .31959 .51697 L F
.606 .886 .99 r
.32116 .51773 m .31959 .51697 L .32197 .516 L F
.084 0 0 r
.22699 .53798 m .22866 .53811 L .22994 .53606 L F
.268 0 .144 r
.22699 .53798 m .22786 .54035 L .22866 .53811 L F
.22699 .53798 m .22562 .54109 L .22786 .54035 L F
.579 .19 .269 r
.35126 .55527 m .35102 .55693 L .34863 .55481 L F
0 .098 .623 r
.34863 .55481 m .35102 .55693 L .34966 .55523 L F
.34863 .55481 m .34966 .55523 L .3471 .55547 L F
.602 .423 .612 r
.35111 .55203 m .35126 .55527 L .34863 .55481 L F
.553 .404 .632 r
.34152 .59872 m .34183 .60179 L .33931 .60203 L F
.361 .173 .486 r
.34183 .60179 m .33948 .60542 L .33931 .60203 L F
.563 .393 .609 r
.35305 .55366 m .35126 .55527 L .35111 .55203 L F
.758 .725 .822 r
.34969 .55061 m .35349 .55335 L .35169 .54798 L F
.686 .149 0 r
.34969 .55061 m .35181 .55289 L .35349 .55335 L F
.405 .507 .85 r
.35169 .54798 m .35349 .55335 L .35473 .54951 L F
.547 .342 .554 r
.35181 .55289 m .35473 .54951 L .35362 .55295 L F
.35333 .5533 m .35362 .55295 L .35349 .55335 L F
.35181 .55289 m .35362 .55295 L .35333 .5533 L F
.563 .393 .609 r
.35393 .5544 m .35192 .55506 L .35305 .55366 L F
.35192 .55506 m .35126 .55527 L .35305 .55366 L F
.272 .184 .569 r
.22196 .59664 m .21918 .59627 L .22193 .5946 L F
.22196 .59664 m .21972 .60002 L .21918 .59627 L F
.763 .852 .917 r
.72088 .31171 m .71702 .31209 L .71988 .31007 L F
.267 .512 .903 r
.71988 .31007 m .72264 .31307 L .72088 .31171 L F
.574 .243 .371 r
.22359 .57289 m .22097 .57335 L .22155 .5709 L F
.439 .242 .515 r
.34818 .61172 m .35041 .61112 L .35047 .60852 L F
.444 .256 .529 r
.34818 .61172 m .35033 .6137 L .35041 .61112 L F
.338 .254 .613 r
.34857 .61424 m .35033 .6137 L .34818 .61172 L F
0 0 0 r
.34906 .58651 m .35095 .58543 L .35156 .58333 L F
.344 .673 .977 r
.35017 .58185 m .35156 .58333 L .35234 .58175 L F
0 0 0 r
.35156 .58333 m .35222 .58427 L .35234 .58175 L F
.35156 .58333 m .35095 .58543 L .35222 .58427 L F
.564 .29 .459 r
.31718 .53548 m .321 .5323 L .31749 .53348 L F
0 0 0 r
.28473 .52469 m .28903 .52434 L .2867 .52484 L F
.69 .793 .929 r
.32674 .56109 m .32733 .56187 L .33064 .56078 L F
.321 .254 .625 r
.20853 .58054 m .20786 .58312 L .20726 .58084 L F
.529 0 0 r
.33007 .67828 m .32991 .67867 L .33037 .67614 L F
.33007 .67828 m .33197 .67983 L .32991 .67867 L F
.621 .597 .805 r
.33007 .67828 m .33281 .67782 L .3318 .67561 L F
.495 .16 .328 r
.33281 .67782 m .33197 .67983 L .33007 .67828 L F
.88 .992 .765 r
.34582 .58138 m .34562 .58361 L .34777 .58081 L F
.427 .808 .991 r
.35017 .58185 m .34582 .58138 L .34777 .58081 L F
0 0 .423 r
.32236 .64308 m .3231 .64614 L .32341 .64485 L F
.069 .422 .868 r
.32341 .64485 m .3231 .64614 L .32467 .64677 L F
.499 .556 .845 r
.3231 .64614 m .32697 .64939 L .32467 .64677 L F
.444 .875 .911 r
.25263 .52952 m .25193 .53039 L .25027 .53022 L F
.25263 .52952 m .25421 .52958 L .25193 .53039 L F
.512 .316 .552 r
.36597 .56391 m .36343 .56152 L .36587 .56094 L F
.36597 .56391 m .36337 .5647 L .36343 .56152 L F
.783 .974 .69 r
.30064 .56928 m .30002 .57105 L .30268 .56782 L F
.777 .823 .35 r
.30383 .56433 m .30298 .56601 L .30268 .56782 L F
0 .16 .699 r
.30298 .56601 m .30472 .56977 L .30268 .56782 L F
.67 .201 .131 r
.30268 .56782 m .30472 .56977 L .30064 .56928 L F
0 .16 .699 r
.30298 .56601 m .30472 .56977 L .30268 .56782 L F
.186 .018 .406 r
.32342 .58666 m .32452 .58807 L .32631 .58592 L F
.32342 .58666 m .32283 .5894 L .32452 .58807 L F
.562 .422 .649 r
.33027 .66223 m .33262 .66217 L .33207 .65859 L F
.473 .09 .232 r
.33153 .66374 m .33027 .66223 L .32895 .66395 L F
.33153 .66374 m .33262 .66217 L .33027 .66223 L F
.554 .439 .677 r
.3861 .67053 m .38371 .67356 L .38386 .67133 L F
.605 .297 .422 r
.33186 .63976 m .33347 .64186 L .33032 .64276 L F
.33186 .63976 m .33435 .63977 L .33347 .64186 L F
.454 .23 .484 r
.29121 .59528 m .29401 .59217 L .29191 .59321 L F
.296 .495 .882 r
.20935 .58555 m .20862 .58736 L .20813 .5848 L F
.20935 .58555 m .21159 .589 L .20862 .58736 L F
.841 .776 .789 r
.3675 .52368 m .36623 .51981 L .36739 .52065 L F
.861 .436 0 r
.36739 .52065 m .36623 .51981 L .36473 .51709 L F
.588 .557 .787 r
.34227 .64603 m .34381 .64307 L .34174 .64327 L F
.407 .83 .964 r
.27422 .62987 m .27381 .63078 L .27201 .62995 L F
.27422 .62987 m .27615 .63028 L .27381 .63078 L F
.146 .149 .604 r
.34926 .53498 m .34775 .53688 L .34733 .53073 L F
.288 .347 .75 r
.34926 .53498 m .34885 .5385 L .34775 .53688 L F
.611 .45 .639 r
.29805 .71211 m .29799 .71548 L .29553 .71529 L F
.46 .253 .511 r
.29805 .71211 m .29819 .71396 L .29935 .71338 L F
.231 0 .14 r
.29935 .71338 m .29819 .71396 L .299 .71545 L F
0 0 .303 r
.29841 .71442 m .29825 .71483 L .29819 .71396 L F
.29825 .71483 m .29799 .71548 L .29805 .71211 L F
0 0 .33 r
.299 .71545 m .29799 .71548 L .29841 .71442 L F
.299 .71545 m .29841 .71442 L .29853 .71412 L F
.231 0 .14 r
.29841 .71442 m .29553 .71529 L .29892 .71544 L F
.29819 .71396 m .29816 .71398 L .29841 .71442 L F
.29816 .71398 m .29553 .71529 L .29841 .71442 L F
.29819 .71396 m .29892 .71544 L .299 .71545 L F
0 0 .303 r
.29853 .71412 m .29841 .71442 L .29805 .71211 L F
.29841 .71442 m .29819 .71396 L .29805 .71211 L F
.46 .253 .511 r
.29805 .71211 m .29553 .71529 L .29819 .71396 L F
0 .564 .75 r
.29553 .71529 m .29799 .71548 L .299 .71545 L F
.875 .845 .383 r
.71499 .33189 m .71411 .3326 L .71399 .33031 L F
.71499 .33189 m .71416 .33417 L .71411 .3326 L F
.567 .841 .996 r
.71499 .33189 m .71633 .32932 L .71742 .3284 L F
.71499 .33189 m .71399 .33031 L .71633 .32932 L F
.273 .253 .653 r
.3187 .6171 m .31739 .62108 L .31841 .61949 L F
0 0 .117 r
.31747 .62327 m .31841 .61949 L .31739 .62108 L F
.549 .479 .729 r
.32114 .62439 m .31884 .62746 L .31747 .62327 L F
.32114 .62439 m .32126 .6271 L .31884 .62746 L F
0 0 .034 r
.31945 .62849 m .31884 .62746 L .32126 .6271 L F
.31945 .62849 m .31824 .62936 L .31884 .62746 L F
.317 0 .124 r
.3929 .58538 m .39225 .58407 L .394 .58335 L F
.101 .267 .748 r
.35656 .50971 m .35597 .51183 L .35576 .51021 L F
.699 .904 .969 r
.35844 .51055 m .35597 .51183 L .35656 .50971 L F
.296 0 .241 r
.27078 .54205 m .27196 .54399 L .27306 .54154 L F
.27078 .54205 m .2698 .54471 L .27196 .54399 L F
0 0 0 r
.20763 .55245 m .20841 .55289 L .20985 .5516 L F
.20763 .55245 m .20653 .55412 L .20841 .55289 L F
.093 0 .062 r
.21291 .54816 m .21475 .54781 L .21581 .5455 L F
.252 0 .213 r
.21291 .54816 m .21409 .5501 L .21475 .54781 L F
.21291 .54816 m .21205 .55082 L .21409 .5501 L F
.143 0 .086 r
.21581 .5455 m .21666 .547 L .21774 .54428 L F
.21581 .5455 m .21475 .54781 L .21666 .547 L F
.588 .551 .78 r
.25979 .74947 m .25782 .75043 L .25673 .74647 L F
.64 .893 .985 r
.25604 .74965 m .25782 .75043 L .25979 .74947 L F
.144 0 0 r
.2304 .78361 m .23449 .78396 L .23234 .7837 L F
.23234 .7837 m .23449 .78396 L .2304 .78361 L F
.23234 .7837 m .23449 .78396 L .2304 .78361 L F
0 0 .086 r
.37499 .55293 m .37432 .55195 L .37707 .55235 L F
.37499 .55293 m .37355 .55514 L .37432 .55195 L F
.178 0 .127 r
.21372 .57448 m .21095 .57861 L .21222 .57559 L F
0 .324 .754 r
.21713 .58929 m .21852 .59042 L .21579 .5886 L F
.507 .723 .97 r
.21971 .58835 m .21852 .59042 L .21713 .58929 L F
.21971 .58835 m .22099 .58956 L .21852 .59042 L F
.474 .506 .81 r
.22226 .59205 m .21852 .59042 L .22099 .58956 L F
.317 .373 .762 r
.40157 .59223 m .39873 .5909 L .4009 .5888 L F
.572 .331 .512 r
.33797 .53883 m .33787 .54157 L .33557 .53946 L F
.33797 .53883 m .33787 .54157 L .33557 .53946 L F
.321 .104 .421 r
.39212 .68048 m .39217 .68375 L .38973 .68364 L F
.21 .003 .366 r
.39217 .68375 m .38962 .68609 L .38973 .68364 L F
0 .143 .67 r
.29874 .5673 m .30002 .57105 L .30064 .56928 L F
.366 .185 .498 r
.35047 .60852 m .35041 .61112 L .35319 .60936 L F
.302 .342 .738 r
.37478 .60213 m .37554 .60672 L .3772 .60399 L F
0 0 .496 r
.3768 .60781 m .3772 .60399 L .37554 .60672 L F
.299 .609 .954 r
.35954 .51531 m .35999 .51358 L .35815 .5142 L F
.35954 .51531 m .36278 .51592 L .35999 .51358 L F
.361 0 .03 r
.26369 .53963 m .26221 .54147 L .25951 .54178 L F
.053 0 0 r
.26426 .54065 m .26221 .54147 L .26369 .53963 L F
.628 .232 .274 r
.29853 .71412 m .29805 .71211 L .29935 .71338 L F
.816 .594 .601 r
.34892 .69983 m .34816 .70186 L .3462 .69911 L F
.628 .576 .776 r
.37279 .56133 m .37356 .55895 L .37521 .55824 L F
.37279 .56133 m .37537 .5612 L .3745 .55847 L F
.37356 .55895 m .37503 .55809 L .37521 .55824 L F
.157 0 .063 r
.37427 .55859 m .3741 .55867 L .37435 .55853 L F
.628 .576 .776 r
.37356 .55895 m .37411 .55725 L .37503 .55809 L F
.887 .823 .778 r
.37435 .55853 m .37411 .55844 L .37411 .55725 L F
.628 .576 .776 r
.37356 .55895 m .37411 .55867 L .37411 .55725 L F
.887 .823 .778 r
.37411 .55844 m .37373 .55828 L .37411 .55725 L F
.628 .576 .776 r
.37411 .55867 m .3745 .55847 L .37411 .55725 L F
.37279 .56133 m .3745 .55847 L .37356 .55895 L F
.157 0 .063 r
.37297 .55951 m .37055 .56071 L .3741 .55867 L F
.37297 .55951 m .3741 .55867 L .37427 .55859 L F
.37055 .56071 m .37014 .56092 L .37202 .55985 L F
.37055 .56071 m .37202 .55985 L .37435 .55853 L F
.28 0 0 r
.37411 .55725 m .37849 .55534 L .37521 .55824 L F
.563 .851 .997 r
.27008 .527 m .26762 .5277 L .26518 .52636 L F
.572 .593 .835 r
.32697 .64939 m .32951 .64899 L .32791 .64526 L F
.444 .108 .3 r
.32697 .64939 m .32951 .64899 L .3299 .65269 L F
.32697 .64939 m .32951 .64899 L .3299 .65269 L F
.528 .205 .365 r
.26444 .54796 m .26783 .54576 L .26542 .54694 L F
.548 .902 .972 r
.35852 .66872 m .35668 .66896 L .35867 .66818 L F
.629 .822 .974 r
.35867 .66818 m .35668 .66896 L .35389 .66713 L F
.046 0 0 r
.35575 .66492 m .3544 .66552 L .35159 .66517 L F
.3544 .66552 m .35409 .66565 L .35351 .66554 L F
.3544 .66552 m .35351 .66554 L .35159 .66517 L F
.345 .232 .579 r
.35159 .66517 m .35376 .66704 L .35191 .66748 L F
.35376 .66704 m .35371 .66708 L .35191 .66748 L F
.735 .843 .931 r
.35371 .66708 m .35386 .67058 L .35191 .66748 L F
.416 .359 .686 r
.35379 .66704 m .35378 .66707 L .35373 .66707 L F
.046 0 0 r
.35575 .66492 m .35672 .66469 L .35409 .66565 L F
.539 .923 .809 r
.35409 .66565 m .35672 .66469 L .35689 .66398 L F
.826 .748 .778 r
.354 .66685 m .35661 .66718 L .35689 .66398 L F
.35379 .66705 m .35404 .66706 L .354 .66685 L F
.35404 .66706 m .35661 .66718 L .354 .66685 L F
.457 .545 .859 r
.35159 .66517 m .35409 .66565 L .35327 .66321 L F
0 0 .203 r
.3537 .66439 m .35407 .66714 L .35391 .66636 L F
.35339 .66356 m .35391 .66636 L .35327 .66321 L F
.3537 .66439 m .35391 .66636 L .35339 .66356 L F
.416 .359 .686 r
.35402 .6669 m .35379 .66706 L .35379 .66704 L F
.35379 .66706 m .35378 .66707 L .35379 .66704 L F
.826 .748 .778 r
.35378 .66706 m .35379 .66706 L .35379 .66705 L F
.35379 .66706 m .35661 .66718 L .35379 .66705 L F
.735 .843 .931 r
.35378 .66706 m .35378 .66707 L .35371 .66708 L F
.35378 .66707 m .35386 .67058 L .35371 .66708 L F
.416 .359 .686 r
.35373 .66707 m .35361 .66719 L .35353 .6672 L F
.35378 .66707 m .35361 .66719 L .35373 .66707 L F
.345 .232 .579 r
.35159 .66517 m .35376 .66704 L .35191 .66748 L F
.35376 .66704 m .35371 .66708 L .35191 .66748 L F
.416 .359 .686 r
.35395 .66691 m .35353 .6672 L .352 .66736 L F
.35402 .6669 m .35353 .6672 L .35395 .66691 L F
.345 .232 .579 r
.35376 .66704 m .35378 .66706 L .35371 .66708 L F
.35376 .66704 m .35378 .66706 L .35371 .66708 L F
.416 .359 .686 r
.35327 .66321 m .35401 .66687 L .352 .66736 L F
.35401 .66687 m .35402 .6669 L .35395 .66691 L F
.35401 .66687 m .35395 .66691 L .352 .66736 L F
.775 .661 .737 r
.34999 .66563 m .352 .66736 L .34686 .66692 L F
.35179 .66488 m .35185 .66558 L .34999 .66563 L F
.35185 .66558 m .352 .66736 L .34999 .66563 L F
.629 .822 .974 r
.354 .66711 m .35389 .66713 L .35379 .66706 L F
.354 .66711 m .35379 .66706 L .35379 .66706 L F
.35867 .66818 m .35379 .66706 L .35661 .66718 L F
.35379 .66706 m .35378 .66706 L .35379 .66706 L F
.35379 .66706 m .35379 .66706 L .35661 .66718 L F
.35379 .66706 m .35379 .66706 L .35378 .66706 L F
.35867 .66818 m .35389 .66713 L .354 .66711 L F
.735 .843 .931 r
.35378 .66706 m .35668 .66896 L .35522 .6698 L F
.35382 .66885 m .35522 .6698 L .35386 .67058 L F
.35378 .66706 m .35522 .6698 L .35382 .66885 L F
.978 .702 .432 r
.35191 .66748 m .35386 .67058 L .35234 .67017 L F
.527 .399 .65 r
.35191 .66748 m .35234 .67017 L .35472 .66955 L F
.835 .649 .651 r
.35382 .66716 m .35411 .66707 L .35378 .66706 L F
.527 .399 .65 r
.35236 .66786 m .35351 .66868 L .35294 .66834 L F
.35191 .66748 m .3531 .66835 L .35236 .66786 L F
.35191 .66748 m .35294 .66834 L .35369 .66723 L F
.35294 .66834 m .35306 .66843 L .35338 .66783 L F
.35294 .66834 m .35338 .66783 L .35369 .66723 L F
0 0 0 r
.35191 .66775 m .35196 .66753 L .35356 .66723 L F
.3536 .66723 m .35356 .66723 L .35364 .66722 L F
.35191 .66775 m .35356 .66723 L .3536 .66723 L F
.416 .359 .686 r
.35379 .66706 m .3538 .66717 L .35361 .66719 L F
.527 .399 .65 r
.35296 .66724 m .35369 .66723 L .35378 .66706 L F
.35191 .66748 m .35369 .66723 L .35296 .66724 L F
0 0 0 r
.35191 .66775 m .35364 .66722 L .35407 .66714 L F
.416 .359 .686 r
.35402 .6669 m .3538 .66717 L .35379 .66706 L F
0 0 0 r
.35196 .66753 m .352 .66736 L .35361 .66719 L F
.35196 .66753 m .35361 .66719 L .35407 .66714 L F
.941 .961 .678 r
.3537 .66439 m .35203 .66779 L .35394 .66718 L F
.835 .649 .651 r
.35472 .66955 m .35411 .66707 L .35382 .66716 L F
.416 .359 .686 r
.35402 .6669 m .35407 .66714 L .3538 .66717 L F
.941 .961 .678 r
.35405 .66704 m .35394 .66718 L .35407 .66714 L F
.3537 .66439 m .35394 .66718 L .35405 .66704 L F
.527 .399 .65 r
.3531 .66835 m .35472 .66955 L .35236 .66786 L F
0 0 0 r
.35178 .6683 m .3518 .66821 L .35407 .66714 L F
.3518 .66821 m .35191 .66775 L .35363 .66726 L F
.3518 .66821 m .35363 .66726 L .35407 .66714 L F
.527 .399 .65 r
.35294 .66834 m .35472 .66955 L .35306 .66843 L F
.35351 .66868 m .35472 .66955 L .35294 .66834 L F
.835 .649 .651 r
.35472 .66955 m .35382 .66716 L .35306 .66843 L F
.35382 .66716 m .35378 .66706 L .35369 .66723 L F
.35382 .66716 m .35369 .66723 L .35306 .66843 L F
.941 .961 .678 r
.35203 .66779 m .35178 .6683 L .35238 .668 L F
.35203 .66779 m .35238 .668 L .35407 .66714 L F
.835 .649 .651 r
.35472 .66955 m .35661 .66718 L .35411 .66707 L F
.629 .822 .974 r
.35867 .66818 m .35472 .66955 L .35719 .66912 L F
.35867 .66818 m .35661 .66718 L .35472 .66955 L F
.518 .76 .984 r
.35904 .66692 m .35867 .66818 L .35719 .66912 L F
.35968 .66616 m .35867 .66818 L .35904 .66692 L F
.548 .902 .972 r
.3606 .66846 m .35852 .66872 L .35867 .66818 L F
.712 .942 .958 r
.36228 .66708 m .3606 .66846 L .35867 .66818 L F
.781 .908 .928 r
.3412 .58475 m .34562 .58361 L .34348 .58385 L F
.838 .987 .865 r
.34348 .58385 m .34562 .58361 L .34582 .58138 L F
0 0 0 r
.33579 .52168 m .33607 .52199 L .33712 .52028 L F
.213 0 0 r
.37804 .54229 m .37618 .5435 L .37337 .54375 L F
.437 .19 .441 r
.37575 .54559 m .37805 .54504 L .37804 .54229 L F
0 0 .42 r
.37909 .53801 m .37804 .54229 L .37641 .53836 L F
.37909 .53801 m .37935 .54109 L .37804 .54229 L F
.58 .301 .457 r
.37804 .54229 m .383 .54364 L .3815 .54193 L F
.383 .54364 m .38384 .54387 L .38321 .54335 L F
.383 .54364 m .38321 .54335 L .3815 .54193 L F
.988 .728 .433 r
.38384 .54387 m .38431 .54208 L .3815 .54193 L F
.738 .929 .584 r
.38448 .54167 m .38276 .54348 L .38512 .54021 L F
.38431 .54208 m .38389 .54245 L .38448 .54167 L F
.38389 .54245 m .38276 .54348 L .38448 .54167 L F
0 0 0 r
.37907 .54252 m .37804 .54229 L .37935 .54109 L F
.58 .301 .457 r
.37804 .54229 m .37805 .54504 L .38384 .54387 L F
0 0 0 r
.37907 .54252 m .37618 .5435 L .37804 .54229 L F
.813 .78 .822 r
.29778 .53792 m .29955 .53943 L .30204 .53622 L F
.644 .52 .697 r
.29955 .53943 m .30212 .53964 L .30204 .53622 L F
0 .074 .616 r
.30015 .53932 m .29955 .53943 L .29778 .53792 L F
.609 .255 .344 r
.29955 .53943 m .3017 .54156 L .30212 .53964 L F
0 .074 .616 r
.30015 .53932 m .3017 .54156 L .29955 .53943 L F
.021 0 0 r
.37164 .52335 m .36758 .52603 L .3675 .52368 L F
.37164 .52335 m .36966 .52529 L .36758 .52603 L F
.415 0 0 r
.37368 .52419 m .36966 .52529 L .37164 .52335 L F
0 0 .444 r
.38382 .62225 m .38251 .62117 L .3833 .62016 L F
.38382 .62225 m .38296 .62385 L .38251 .62117 L F
.401 .243 .55 r
.33915 .51093 m .3412 .51042 L .34198 .50621 L F
.28 0 0 r
.37411 .55725 m .37646 .55725 L .37849 .55534 L F
.715 .883 .488 r
.38066 .5518 m .37849 .55534 L .37967 .55302 L F
0 0 0 r
.37849 .55534 m .37893 .55609 L .37967 .55302 L F
.37849 .55534 m .37646 .55725 L .37893 .55609 L F
.233 0 0 r
.24416 .63058 m .24224 .63007 L .24147 .62986 L F
.082 .625 .845 r
.24616 .63062 m .24224 .63007 L .24416 .63058 L F
.321 .254 .625 r
.20853 .58054 m .20942 .58269 L .20786 .58312 L F
.19 .066 .471 r
.20942 .58269 m .20813 .5848 L .20786 .58312 L F
.454 .254 .517 r
.384 .6948 m .382 .69317 L .38457 .69272 L F
.384 .6948 m .38195 .69605 L .382 .69317 L F
.453 .648 .942 r
.35249 .50708 m .35162 .50924 L .35024 .50768 L F
.35249 .50708 m .35576 .51021 L .35162 .50924 L F
.756 .719 .817 r
.33102 .58058 m .33233 .58364 L .32835 .58295 L F
.721 .571 .685 r
.33233 .58364 m .33257 .58688 L .32987 .58666 L F
0 0 .339 r
.3571 .6288 m .35865 .63312 L .35771 .63076 L F
.179 0 0 r
.27824 .54642 m .27728 .54746 L .27508 .54797 L F
.27934 .54685 m .27824 .54642 L .28062 .54573 L F
.27934 .54685 m .27728 .54746 L .27824 .54642 L F
.35 .542 .901 r
.30356 .54362 m .30673 .54448 L .30722 .54382 L F
.485 .901 .86 r
.27988 .62142 m .28147 .62119 L .28328 .62018 L F
0 0 .136 r
.30611 .52125 m .30546 .52299 L .30401 .52223 L F
.30611 .52125 m .30588 .52272 L .30546 .52299 L F
.274 .623 .96 r
.27525 .53502 m .276 .53376 L .27402 .53495 L F
.27525 .53502 m .27931 .53658 L .276 .53376 L F
.624 .221 .259 r
.35828 .70565 m .36231 .70538 L .36057 .70763 L F
.623 .226 .271 r
.36478 .70576 m .36057 .70763 L .36231 .70538 L F
.585 .322 .485 r
.40556 .57938 m .40294 .58272 L .403 .58015 L F
.40556 .57938 m .40612 .58255 L .40294 .58272 L F
.417 .355 .681 r
.40582 .57658 m .40868 .57926 L .40556 .57938 L F
.296 .134 .484 r
.40807 .58163 m .40556 .57938 L .40868 .57926 L F
.40807 .58163 m .40612 .58255 L .40556 .57938 L F
.272 0 0 r
.39168 .60847 m .39034 .60934 L .38921 .60849 L F
0 0 .374 r
.38921 .60849 m .39034 .60934 L .38965 .60523 L F
.958 .665 .234 r
.38965 .60523 m .39019 .60944 L .39034 .60934 L F
.39019 .60944 m .3903 .61027 L .39034 .60934 L F
.272 0 0 r
.39308 .60847 m .39034 .60934 L .39168 .60847 L F
.33 .649 .968 r
.3934 .60677 m .39308 .60847 L .39091 .60606 L F
.793 .993 .765 r
.3934 .60677 m .39034 .60934 L .39308 .60847 L F
.018 0 .172 r
.29295 .63584 m .29076 .63901 L .29124 .6367 L F
0 0 .158 r
.3654 .63056 m .36597 .62622 L .36505 .62923 L F
.627 .805 .968 r
.3665 .62831 m .36637 .62868 L .36782 .62909 L F
.36637 .62868 m .36568 .63075 L .36595 .63054 L F
.36637 .62868 m .36595 .63054 L .36782 .62909 L F
0 0 .158 r
.3654 .63056 m .36593 .63063 L .36597 .62622 L F
.519 .707 .956 r
.36595 .63054 m .36887 .63057 L .36782 .62909 L F
0 0 .158 r
.36593 .63063 m .36594 .63063 L .36595 .63054 L F
.519 .707 .956 r
.36568 .63075 m .36592 .63074 L .36594 .63063 L F
0 .038 .533 r
.36594 .63063 m .36568 .63075 L .36594 .63063 L F
.3654 .63056 m .36568 .63075 L .36594 .63063 L F
.519 .707 .956 r
.36568 .63075 m .36594 .63063 L .36595 .63054 L F
.36592 .63074 m .36887 .63057 L .36595 .63054 L F
0 0 .158 r
.36595 .63054 m .36594 .63063 L .36596 .6305 L F
.36594 .63063 m .36594 .63063 L .36595 .63054 L F
.36594 .63063 m .36596 .63055 L .36596 .6305 L F
.526 .697 .947 r
.36637 .62868 m .36594 .63063 L .36568 .63075 L F
.36594 .63063 m .36592 .63074 L .36568 .63075 L F
0 .038 .533 r
.36594 .63063 m .36568 .63075 L .36596 .63064 L F
.526 .697 .947 r
.3665 .62831 m .36887 .63057 L .36592 .63074 L F
.3665 .62831 m .36592 .63074 L .36637 .62868 L F
0 0 .158 r
.36594 .63063 m .36596 .63064 L .36596 .63055 L F
.36593 .63063 m .36596 .6305 L .36597 .62622 L F
0 .038 .533 r
.3654 .63056 m .36745 .63247 L .36568 .63075 L F
.624 .216 .25 r
.3647 .63204 m .36745 .63247 L .3654 .63056 L F
0 0 0 r
.2867 .60723 m .28552 .60877 L .28433 .6104 L F
.403 .822 .639 r
.27901 .61421 m .28056 .61318 L .28276 .61193 L F
0 0 0 r
.28276 .61193 m .28251 .61246 L .28433 .6104 L F
.28276 .61193 m .28056 .61318 L .28251 .61246 L F
.37 .107 .378 r
.28951 .62739 m .28663 .63043 L .28857 .62958 L F
0 0 0 r
.29203 .62434 m .28951 .62739 L .29055 .62613 L F
.702 .428 .506 r
.32411 .61138 m .32796 .60863 L .32378 .608 L F
.361 .809 .949 r
.33008 .65807 m .33207 .65859 L .33438 .65814 L F
.422 .324 .639 r
.33207 .65859 m .33465 .66147 L .33438 .65814 L F
.33207 .65859 m .33262 .66217 L .33465 .66147 L F
.831 .996 .762 r
.38954 .57613 m .38612 .57969 L .38855 .57926 L F
0 .045 .614 r
.3881 .57332 m .38954 .57613 L .38994 .57638 L F
.3881 .57332 m .38994 .57638 L .38939 .57492 L F
.873 .814 .789 r
.38847 .57245 m .3886 .57281 L .38891 .57223 L F
.243 .151 .546 r
.38535 .57355 m .38617 .57405 L .38606 .57355 L F
.38617 .57405 m .38617 .57372 L .38487 .56837 L F
0 0 0 r
.39048 .57012 m .38891 .57223 L .3881 .57332 L F
.873 .814 .789 r
.38636 .57346 m .3886 .57281 L .38847 .57245 L F
.38617 .57355 m .38631 .5736 L .38636 .57346 L F
0 0 0 r
.3847 .57624 m .3881 .57332 L .38712 .57558 L F
0 .045 .614 r
.3881 .57332 m .38939 .57492 L .38844 .57308 L F
0 0 0 r
.38829 .57307 m .38712 .57558 L .3881 .57332 L F
.38891 .57223 m .38712 .57558 L .38829 .57307 L F
.873 .814 .789 r
.38617 .57365 m .38712 .57558 L .3885 .57301 L F
.38843 .57287 m .3885 .57301 L .3886 .57281 L F
.38617 .57365 m .3885 .57301 L .38843 .57287 L F
0 .045 .614 r
.38939 .57492 m .39124 .57721 L .38871 .57347 L F
.38939 .57492 m .38871 .57347 L .38844 .57308 L F
.873 .814 .789 r
.38673 .57357 m .38617 .57355 L .38677 .57356 L F
.38617 .57365 m .38631 .5736 L .38617 .57355 L F
.38631 .5736 m .3886 .57281 L .38636 .57346 L F
.38617 .57355 m .38891 .57223 L .38729 .57324 L F
.38641 .57356 m .38729 .57324 L .38677 .57356 L F
.38617 .57355 m .38729 .57324 L .38641 .57356 L F
.098 .169 .65 r
.38616 .57245 m .38621 .57234 L .38612 .56954 L F
.38617 .57372 m .38621 .57234 L .38616 .57245 L F
.38617 .57372 m .38627 .57411 L .38621 .57234 L F
.873 .814 .789 r
.38617 .57355 m .38617 .57355 L .38673 .57357 L F
.098 .169 .65 r
.38612 .56954 m .38625 .57356 L .38709 .57046 L F
.38625 .57356 m .38639 .57356 L .38709 .57046 L F
.38487 .56837 m .38617 .57372 L .38612 .56954 L F
.873 .814 .789 r
.38548 .57389 m .38617 .57365 L .38617 .57355 L F
.243 .151 .546 r
.38306 .57215 m .38456 .57535 L .38612 .57421 L F
.38306 .57215 m .38612 .57421 L .38617 .57405 L F
.38535 .57355 m .38606 .57355 L .38487 .56837 L F
.557 .608 .859 r
.38586 .57375 m .38709 .57046 L .38639 .57356 L F
.38564 .57354 m .38709 .57046 L .38586 .57375 L F
.243 .151 .546 r
.38306 .57215 m .38535 .57355 L .38487 .56837 L F
.734 .683 .802 r
.3808 .57028 m .38306 .57215 L .38231 .56621 L F
.187 .265 .713 r
.38231 .56621 m .38306 .57215 L .38487 .56837 L F
.557 .608 .859 r
.38548 .57389 m .38564 .57354 L .38586 .57375 L F
.098 .169 .65 r
.38625 .57356 m .38627 .57411 L .38639 .57356 L F
.873 .814 .789 r
.38618 .5746 m .38712 .57558 L .38617 .57365 L F
.243 .151 .546 r
.38617 .57405 m .38627 .57411 L .38617 .57372 L F
.636 .895 .986 r
.38456 .57535 m .38548 .57389 L .38612 .57421 L F
.873 .814 .789 r
.38548 .57389 m .38618 .5746 L .38617 .57424 L F
.38548 .57389 m .38617 .57424 L .38617 .57365 L F
.243 .151 .546 r
.38617 .57405 m .38612 .57421 L .38627 .57411 L F
.636 .895 .986 r
.38612 .57421 m .38548 .57389 L .38627 .57411 L F
.557 .608 .859 r
.38548 .57389 m .38639 .57356 L .38627 .57411 L F
.873 .814 .789 r
.38548 .57389 m .38617 .57355 L .38673 .57357 L F
.38677 .57356 m .38891 .57223 L .38842 .57314 L F
.557 .608 .859 r
.38548 .57389 m .38842 .57314 L .38709 .57046 L F
.706 .685 .828 r
.3861 .57373 m .3824 .57054 L .38443 .57201 L F
.3824 .57054 m .38182 .57004 L .38204 .5702 L F
.3824 .57054 m .38204 .5702 L .38443 .57201 L F
0 .045 .614 r
.38939 .57492 m .38994 .57638 L .39124 .57721 L F
.089 0 .222 r
.39124 .57721 m .38954 .57613 L .38855 .57926 L F
.824 .558 .536 r
.403 .58015 m .39932 .58162 L .40095 .58036 L F
.272 .116 .478 r
.39419 .58892 m .39629 .59067 L .39886 .58907 L F
.409 .307 .628 r
.39886 .58907 m .4009 .5888 L .40054 .58585 L F
.324 0 0 r
.39629 .59067 m .4009 .5888 L .39886 .58907 L F
.683 .456 .572 r
.28004 .63315 m .28268 .63331 L .28295 .63037 L F
.468 .272 .53 r
.28295 .63037 m .28528 .63278 L .28663 .63043 L F
.28295 .63037 m .28268 .63331 L .28528 .63278 L F
.439 .307 .604 r
.29745 .6293 m .29621 .62733 L .29726 .62674 L F
.693 .629 .78 r
.71873 .34779 m .71588 .34831 L .71533 .34556 L F
.761 .359 .29 r
.71873 .34779 m .71541 .34839 L .71588 .34831 L F
.755 .643 .737 r
.31917 .66151 m .32029 .66582 L .31655 .66467 L F
.37 .713 .987 r
.31655 .66467 m .32029 .66582 L .31886 .66457 L F
.512 .491 .77 r
.32318 .66529 m .32029 .66582 L .31917 .66151 L F
.468 .766 .995 r
.31886 .66457 m .32029 .66582 L .32318 .66529 L F
.64 .727 .911 r
.29447 .55041 m .29619 .55292 L .29806 .55144 L F
.342 .244 .597 r
.30147 .60402 m .29934 .60229 L .30208 .60059 L F
.30147 .60402 m .29994 .60467 L .29934 .60229 L F
.039 0 0 r
.25436 .6342 m .2548 .63456 L .25286 .63477 L F
.25436 .6342 m .25722 .63389 L .2548 .63456 L F
.344 0 0 r
.34187 .62978 m .34244 .63134 L .33964 .63083 L F
.557 .618 .868 r
.34187 .62978 m .34542 .63118 L .34516 .62963 L F
.344 0 0 r
.34187 .62978 m .34516 .62963 L .34244 .63134 L F
.759 .38 .337 r
.36377 .61966 m .36621 .62091 L .36183 .62055 L F
.629 .665 .866 r
.25174 .6206 m .24739 .61845 L .25073 .61911 L F
.477 .597 .894 r
.25261 .6176 m .25174 .6206 L .25073 .61911 L F
.25261 .6176 m .25402 .62045 L .25174 .6206 L F
.811 .739 .784 r
.36169 .5381 m .36138 .53906 L .35958 .53556 L F
.704 .697 .841 r
.35958 .53556 m .36138 .53906 L .3639 .53623 L F
.554 .464 .707 r
.36138 .53906 m .364 .53926 L .3639 .53623 L F
.589 .536 .764 r
.36138 .53906 m .36505 .54191 L .364 .53926 L F
.522 .88 .982 r
.29546 .52403 m .29775 .52321 L .29931 .52375 L F
.725 .945 .953 r
.29931 .52375 m .29996 .52171 L .30167 .52308 L F
.29931 .52375 m .29775 .52321 L .29996 .52171 L F
.241 0 .103 r
.28663 .63043 m .28793 .63179 L .28857 .62958 L F
.28663 .63043 m .28528 .63278 L .28793 .63179 L F
.349 .747 .984 r
.27574 .52441 m .27828 .52417 L .27987 .52518 L F
.385 .773 .989 r
.27828 .52417 m .2824 .52483 L .27987 .52518 L F
.432 .786 .997 r
.29332 .52293 m .29276 .5243 L .29146 .52378 L F
.29332 .52293 m .29546 .52403 L .29276 .5243 L F
.478 .069 .185 r
.35467 .55716 m .35727 .55695 L .35855 .55492 L F
.676 .286 .301 r
.35855 .55492 m .36097 .55675 L .36141 .55484 L F
.35855 .55492 m .35727 .55695 L .36097 .55675 L F
.76 .662 .754 r
.33595 .6773 m .3318 .67561 L .33478 .67547 L F
.33595 .6773 m .33281 .67782 L .3318 .67561 L F
.896 .842 .783 r
.33595 .6773 m .33197 .67983 L .33281 .67782 L F
.33595 .6773 m .33382 .68096 L .33197 .67983 L F
.832 .817 .835 r
.33866 .67438 m .33595 .6773 L .33478 .67547 L F
.601 .393 .571 r
.321 .5323 m .32321 .53202 L .32331 .52978 L F
.175 .286 .74 r
.32218 .52626 m .32331 .52978 L .32462 .52847 L F
.244 .212 .623 r
.32321 .53202 m .32462 .52847 L .32331 .52978 L F
.608 .577 .793 r
.36593 .53252 m .36361 .53335 L .36227 .52978 L F
.979 .684 .327 r
.36276 .5351 m .3639 .53623 L .36361 .53335 L F
.36276 .5351 m .36361 .53335 L .36426 .53312 L F
.36276 .5351 m .36426 .53312 L .36447 .53371 L F
.36276 .5351 m .36593 .53252 L .36593 .53521 L F
.699 .179 0 r
.36593 .53521 m .3607 .53058 L .36276 .5351 L F
.36593 .53521 m .36477 .53453 L .36458 .53402 L F
.979 .684 .327 r
.36447 .53371 m .36426 .53312 L .36593 .53252 L F
.699 .179 0 r
.36458 .53402 m .36329 .53364 L .3607 .53058 L F
.36329 .53364 m .36217 .53238 L .3607 .53058 L F
.36477 .53453 m .36316 .5336 L .36458 .53402 L F
.729 .932 .956 r
.36527 .53249 m .36316 .5336 L .36593 .53521 L F
.549 .398 .628 r
.36527 .53249 m .36553 .536 L .36539 .53598 L F
.36388 .5343 m .36539 .53598 L .36287 .53562 L F
.36527 .53249 m .36539 .53598 L .36388 .5343 L F
.699 .179 0 r
.36329 .53364 m .36316 .5336 L .36217 .53238 L F
.764 .348 0 r
.28959 .6475 m .29072 .64925 L .28954 .6478 L F
.182 0 0 r
.29072 .64925 m .29319 .64948 L .29156 .64973 L F
.29072 .64925 m .29156 .64973 L .28954 .6478 L F
.139 .101 .549 r
.34336 .60074 m .34152 .59872 L .34389 .59817 L F
.34336 .60074 m .34183 .60179 L .34152 .59872 L F
.048 0 0 r
.34389 .59817 m .34152 .59872 L .33964 .60034 L F
.558 .455 .694 r
.31091 .5451 m .30925 .54914 L .3073 .54808 L F
.762 .581 .651 r
.30925 .54914 m .30853 .55185 L .3073 .54808 L F
.668 .484 .626 r
.3111 .55172 m .30853 .55185 L .30925 .54914 L F
.275 0 0 r
.30996 .64558 m .30604 .64572 L .30839 .64613 L F
.168 0 0 r
.31207 .64556 m .30996 .64558 L .30839 .64613 L F
0 0 .4 r
.40468 .55727 m .40484 .56108 L .40442 .55861 L F
.893 .957 .834 r
.37914 .52993 m .37609 .53183 L .37632 .53162 L F
0 0 .38 r
.37609 .53183 m .37695 .53403 L .37655 .53141 L F
0 .003 .569 r
.37782 .52515 m .37914 .52993 L .37916 .52771 L F
.891 .985 .716 r
.37711 .53043 m .37632 .5315 L .3764 .53038 L F
0 0 .38 r
.37609 .53183 m .37631 .53163 L .3764 .53038 L F
.891 .985 .716 r
.37632 .5315 m .37614 .53173 L .3764 .53038 L F
0 0 .38 r
.37631 .53163 m .37655 .53141 L .3764 .53038 L F
.928 .969 .755 r
.37914 .52993 m .37614 .53173 L .37916 .52771 L F
0 0 0 r
.3764 .53038 m .37614 .53173 L .37609 .53183 L F
.347 .644 .965 r
.37695 .53403 m .37823 .53265 L .3764 .53038 L F
.573 .561 .803 r
.37823 .53265 m .37554 .53032 L .3764 .53038 L F
.37554 .53032 m .37423 .52919 L .3764 .53038 L F
.891 .985 .716 r
.37916 .52771 m .37711 .53043 L .3764 .53038 L F
.893 .957 .834 r
.37632 .53162 m .37609 .53183 L .37614 .53173 L F
.956 .947 .71 r
.3566 .57695 m .35742 .57253 L .35932 .57385 L F
.579 .382 .578 r
.35924 .57654 m .3566 .57695 L .35932 .57385 L F
.53 .79 .992 r
.35972 .57171 m .35932 .57385 L .35742 .57253 L F
.35972 .57171 m .36158 .5732 L .35932 .57385 L F
.569 .425 .646 r
.36158 .5732 m .35924 .57654 L .35932 .57385 L F
.923 .921 .541 r
.37898 .57788 m .38011 .57804 L .38222 .57677 L F
.612 .577 .79 r
.38011 .57804 m .3835 .58017 L .38222 .57677 L F
.824 .558 .536 r
.403 .58015 m .40294 .58272 L .39932 .58162 L F
.595 .407 .597 r
.33951 .64933 m .34222 .64919 L .34227 .64603 L F
.588 .557 .787 r
.34227 .64603 m .34508 .64545 L .34381 .64307 L F
.567 .397 .61 r
.34222 .64919 m .34508 .64545 L .34227 .64603 L F
0 0 0 r
.3679 .65768 m .37067 .65562 L .36881 .65719 L F
.406 .841 .705 r
.37202 .65473 m .37067 .65562 L .37272 .65448 L F
0 0 0 r
.37103 .65643 m .37067 .65562 L .37202 .65473 L F
.37103 .65643 m .36881 .65719 L .37067 .65562 L F
.718 .542 .651 r
.38553 .60513 m .38223 .60175 L .38348 .60141 L F
0 0 .556 r
.22197 .61443 m .22191 .61165 L .21935 .61196 L F
.22197 .61443 m .22241 .61412 L .22191 .61165 L F
.6 .492 .702 r
.35814 .58544 m .35473 .58317 L .35717 .58234 L F
.35814 .58544 m .35545 .58636 L .35473 .58317 L F
.472 .288 .55 r
.32436 .54882 m .32679 .54828 L .32681 .54544 L F
.748 .472 .514 r
.32436 .54882 m .32788 .5513 L .32679 .54828 L F
.32436 .54882 m .325 .55153 L .32788 .5513 L F
.941 .581 .291 r
.37387 .51379 m .37462 .51655 L .37634 .5175 L F
.085 .596 .888 r
.37462 .51655 m .37839 .51755 L .37634 .5175 L F
.529 .339 .568 r
.31618 .56754 m .31778 .57036 L .3155 .57079 L F
.699 .269 0 r
.31665 .56889 m .31618 .56754 L .3155 .57079 L F
.33 0 .066 r
.31778 .57036 m .31722 .57181 L .3155 .57079 L F
0 .089 .61 r
.3155 .57079 m .31722 .57181 L .31665 .56889 L F
.88 .721 .68 r
.31665 .56889 m .31722 .57181 L .31552 .57094 L F
0 0 0 r
.31552 .57094 m .3166 .56905 L .31665 .56889 L F
.699 .269 0 r
.31665 .56889 m .31778 .57036 L .31676 .56856 L F
.662 .884 .523 r
.3186 .56618 m .31665 .56889 L .31753 .56742 L F
0 0 0 r
.3166 .56905 m .31753 .56742 L .31665 .56889 L F
.699 .269 0 r
.31665 .56889 m .31676 .56856 L .31618 .56754 L F
.447 0 0 r
.38066 .5518 m .37967 .55302 L .37707 .55235 L F
.855 .527 .431 r
.30391 .58958 m .30392 .59105 L .30425 .58947 L F
0 0 .423 r
.32236 .64308 m .32341 .64485 L .32433 .6426 L F
.269 .024 .345 r
.33258 .60224 m .3321 .60457 L .33435 .60391 L F
0 0 0 r
.20483 .55516 m .20374 .55698 L .20653 .55412 L F
.22994 .53606 m .23041 .53719 L .23189 .53473 L F
.22994 .53606 m .22866 .53811 L .23041 .53719 L F
.621 .665 .871 r
.38786 .66181 m .38387 .65948 L .38717 .65888 L F
.33 .227 .584 r
.38984 .65782 m .38786 .66181 L .38717 .65888 L F
.38984 .65782 m .38995 .6612 L .38786 .66181 L F
.173 0 .246 r
.38995 .6612 m .38776 .66387 L .38786 .66181 L F
.072 0 .222 r
.18889 .57045 m .19027 .56977 L .191 .56754 L F
.32 .206 .564 r
.18889 .57045 m .19062 .57257 L .19027 .56977 L F
.18889 .57045 m .18845 .57374 L .19062 .57257 L F
.245 .025 .368 r
.32378 .608 m .32166 .61192 L .32411 .61138 L F
.22 .415 .841 r
.37371 .60041 m .37567 .60041 L .37543 .59668 L F
.392 .117 .372 r
.37925 .59512 m .37543 .59668 L .37823 .59715 L F
.37925 .59512 m .37687 .59561 L .37543 .59668 L F
.249 0 .319 r
.37823 .59715 m .37543 .59668 L .37567 .60041 L F
.836 .48 .381 r
.3316 .68406 m .3348 .68645 L .33137 .68572 L F
.732 .296 .216 r
.3348 .68645 m .33334 .6883 L .33137 .68572 L F
.788 .37 .256 r
.3348 .68645 m .33701 .68936 L .33334 .6883 L F
.697 .871 .963 r
.33798 .52351 m .34179 .52365 L .33965 .52235 L F
.163 0 0 r
.72855 .34002 m .72921 .33996 L .72948 .33939 L F
.41 .216 .504 r
.30079 .5485 m .30291 .55019 L .30433 .54892 L F
.243 0 0 r
.30291 .55019 m .3073 .54808 L .30433 .54892 L F
0 0 0 r
.27901 .61421 m .27781 .61617 L .28056 .61318 L F
.527 .1 .174 r
.38319 .53666 m .37909 .53801 L .38054 .53717 L F
.309 0 .098 r
.27596 .53854 m .27834 .53803 L .27931 .53658 L F
.599 .776 .965 r
.276 .53376 m .27931 .53658 L .28139 .53556 L F
.061 0 0 r
.27931 .53658 m .27834 .53803 L .28139 .53556 L F
.445 .325 .623 r
.33188 .58855 m .32987 .58666 L .33257 .58688 L F
.449 .073 .232 r
.33257 .58688 m .33446 .58818 L .33188 .58855 L F
.841 .776 .789 r
.3675 .52368 m .36394 .52276 L .36623 .51981 L F
.778 .475 .473 r
.3675 .52368 m .36306 .52532 L .36394 .52276 L F
.3675 .52368 m .36758 .52603 L .36306 .52532 L F
.253 .004 .329 r
.3906 .67141 m .39005 .67365 L .3925 .6706 L F
0 0 0 r
.28768 .60531 m .28764 .60611 L .28864 .60395 L F
.28768 .60531 m .2867 .60723 L .28764 .60611 L F
.861 .798 .787 r
.33382 .68096 m .32946 .68295 L .33197 .67983 L F
.33382 .68096 m .3316 .68406 L .32946 .68295 L F
.458 0 0 r
.26063 .63403 m .26481 .63547 L .26339 .63457 L F
.4 .149 .415 r
.2905 .58487 m .29201 .58574 L .29258 .58274 L F
.975 .716 .477 r
.31842 .52566 m .31835 .52857 L .3195 .52668 L F
.509 .251 .459 r
.2168 .57381 m .21372 .57448 L .21491 .57345 L F
0 0 .326 r
.39529 .68131 m .39488 .68177 L .3954 .67863 L F
.39488 .68177 m .39431 .68241 L .39485 .68052 L F
.449 .328 .623 r
.39529 .67964 m .39431 .68241 L .39217 .68375 L F
.39529 .67964 m .39217 .68375 L .39212 .68048 L F
0 0 .47 r
.3954 .67863 m .39529 .67964 L .39397 .67752 L F
.801 .71 .765 r
.3954 .67863 m .39431 .68241 L .39529 .67964 L F
0 0 .326 r
.39488 .68177 m .39485 .68052 L .3954 .67863 L F
.206 .032 .41 r
.39397 .67752 m .39482 .6789 L .39212 .68048 L F
.39482 .6789 m .39529 .67964 L .39484 .67976 L F
.39482 .6789 m .39484 .67976 L .39212 .68048 L F
.314 .691 .979 r
.23823 .6128 m .23788 .61376 L .23583 .61318 L F
.23823 .6128 m .24002 .61401 L .23788 .61376 L F
.695 .154 0 r
.38013 .52057 m .38228 .52272 L .3843 .52321 L F
.25 0 0 r
.38228 .52272 m .3859 .52384 L .3843 .52321 L F
.145 0 .118 r
.28967 .53912 m .29147 .53844 L .29249 .53657 L F
.42 .305 .616 r
.28978 .54211 m .29147 .53844 L .28967 .53912 L F
.574 .644 .881 r
.33315 .64919 m .3353 .6513 L .33663 .64948 L F
.485 .261 .499 r
.38407 .59718 m .38597 .60226 L .38348 .60141 L F
.447 .789 .998 r
.71849 .31665 m .71791 .31552 L .71469 .31607 L F
.801 .974 .905 r
.71973 .31401 m .71849 .31665 L .72123 .31572 L F
.71973 .31401 m .71791 .31552 L .71849 .31665 L F
.832 .817 .835 r
.33866 .67438 m .33478 .67547 L .33632 .67517 L F
0 0 .114 r
.3023 .5988 m .30539 .5935 L .30439 .59803 L F
.137 0 0 r
.30208 .60059 m .3023 .5988 L .30439 .59803 L F
.384 0 0 r
.27508 .54797 m .27315 .54975 L .27065 .5498 L F
.046 0 0 r
.2755 .54892 m .27508 .54797 L .27728 .54746 L F
.2755 .54892 m .27315 .54975 L .27508 .54797 L F
.457 .219 .464 r
.37774 .60706 m .38068 .61052 L .37978 .60597 L F
.816 .494 .444 r
.37978 .60597 m .38068 .61052 L .37942 .60866 L F
0 .332 .816 r
.37942 .60866 m .38092 .60983 L .38025 .60776 L F
.894 .904 .494 r
.38096 .61022 m .38266 .60906 L .38318 .60775 L F
.38096 .61031 m .38266 .60906 L .38096 .61022 L F
.38068 .61052 m .38096 .61031 L .38096 .61022 L F
.937 .57 .186 r
.38068 .61052 m .38378 .61329 L .38266 .60906 L F
.939 .698 .548 r
.38511 .60762 m .38068 .61052 L .38318 .60775 L F
.38511 .60762 m .38347 .60973 L .38068 .61052 L F
0 .041 .6 r
.38372 .61137 m .38068 .61052 L .38347 .60973 L F
0 .332 .816 r
.38092 .60983 m .38249 .61104 L .38079 .60856 L F
.38092 .60983 m .38079 .60856 L .38025 .60776 L F
0 .23 .742 r
.72473 .33482 m .72288 .33468 L .7216 .33333 L F
.72473 .33482 m .72529 .33687 L .72288 .33468 L F
.693 .629 .78 r
.71873 .34779 m .71533 .34556 L .71756 .34412 L F
.761 .359 .29 r
.71873 .34779 m .71777 .34969 L .71541 .34839 L F
.595 .582 .808 r
.72143 .34709 m .71873 .34779 L .71756 .34412 L F
.607 .184 .214 r
.72156 .34942 m .71873 .34779 L .72143 .34709 L F
.72156 .34942 m .71777 .34969 L .71873 .34779 L F
.52 .16 .297 r
.34192 .65082 m .34222 .64919 L .33951 .64933 L F
0 .212 .655 r
.34192 .65082 m .33951 .64933 L .3379 .64809 L F
.659 .104 0 r
.35271 .57464 m .35555 .57692 L .3566 .57695 L F
.809 .561 .563 r
.36183 .62055 m .36621 .62091 L .36609 .62356 L F
.956 .947 .71 r
.3566 .57695 m .35555 .57692 L .35742 .57253 L F
.478 .298 .557 r
.35924 .57654 m .35689 .57964 L .3566 .57695 L F
.925 .547 .15 r
.36473 .61964 m .36621 .62091 L .36436 .61794 L F
.586 .036 0 r
.36688 .62205 m .36621 .62091 L .36473 .61964 L F
.36688 .62205 m .36854 .62305 L .36621 .62091 L F
.595 .423 .619 r
.36621 .62091 m .36899 .62066 L .36877 .61774 L F
.561 .294 .468 r
.36621 .62091 m .36854 .62305 L .36899 .62066 L F
.387 .76 .992 r
.38769 .60432 m .38659 .60492 L .38553 .60513 L F
.8 .542 .547 r
.38659 .60492 m .38511 .60762 L .38553 .60513 L F
.38659 .60492 m .38921 .60849 L .38511 .60762 L F
.261 0 .078 r
.3339 .67098 m .33722 .66802 L .33602 .669 L F
.512 .423 .692 r
.33602 .669 m .33349 .67551 L .3339 .67098 L F
.796 .745 .805 r
.3312 .66979 m .33349 .67551 L .33602 .669 L F
.079 0 0 r
.33602 .669 m .3369 .66933 L .33506 .66978 L F
.33602 .669 m .33506 .66978 L .33414 .67001 L F
.261 0 .078 r
.33722 .66802 m .33725 .66799 L .33602 .669 L F
.572 .014 0 r
.33725 .66799 m .33762 .66881 L .33602 .669 L F
.33725 .66799 m .33801 .66861 L .33762 .66881 L F
.524 .855 .576 r
.33729 .66897 m .33762 .66881 L .33856 .66778 L F
.079 0 0 r
.33602 .669 m .33762 .66881 L .3369 .66933 L F
.524 .855 .576 r
.3369 .66933 m .33762 .66881 L .33729 .66897 L F
.572 .014 0 r
.33801 .66861 m .33896 .6694 L .33762 .66881 L F
.078 0 .006 r
.19888 .56093 m .2009 .56022 L .20202 .55814 L F
.039 0 0 r
.20202 .55814 m .20266 .55932 L .20374 .55698 L F
.20202 .55814 m .2009 .56022 L .20266 .55932 L F
.404 0 0 r
.32586 .64095 m .32425 .63983 L .32433 .6426 L F
.469 .007 .072 r
.31322 .5194 m .31717 .5179 L .31458 .51895 L F
.707 .428 .5 r
.29258 .58274 m .29422 .5849 L .29466 .58252 L F
.29258 .58274 m .29201 .58574 L .29422 .5849 L F
.12 .252 .727 r
.29422 .5849 m .29258 .58274 L .29466 .58252 L F
.297 .116 .459 r
.33589 .63898 m .33435 .63977 L .33616 .63643 L F
.153 0 .195 r
.33347 .64186 m .33435 .63977 L .33589 .63898 L F
.431 .226 .498 r
.35772 .56745 m .35716 .57204 L .3553 .57071 L F
.253 .258 .671 r
.35716 .57204 m .35742 .57253 L .3553 .57071 L F
.445 .325 .623 r
.33188 .58855 m .32966 .58938 L .32987 .58666 L F
.683 .729 .885 r
.36772 .66331 m .37173 .6639 L .3694 .66522 L F
.849 .596 .556 r
.35427 .70255 m .3507 .70438 L .3504 .70275 L F
.35427 .70255 m .35414 .70528 L .3507 .70438 L F
.803 .488 .458 r
.35427 .70255 m .35828 .70565 L .35414 .70528 L F
.804 .325 .074 r
.32278 .59868 m .32331 .60028 L .32281 .59734 L F
.32278 .59868 m .32404 .60089 L .32331 .60028 L F
.52 .207 .376 r
.26157 .55303 m .25979 .55094 L .26218 .5516 L F
.26157 .55303 m .25826 .55419 L .25979 .55094 L F
.243 0 0 r
.30291 .55019 m .30538 .54989 L .3073 .54808 L F
0 0 .531 r
.3073 .54808 m .30839 .54705 L .30793 .54424 L F
.187 0 0 r
.3073 .54808 m .30795 .54935 L .30839 .54705 L F
.3073 .54808 m .30538 .54989 L .30795 .54935 L F
.53 .497 .764 r
.38738 .67691 m .38518 .67779 L .38371 .67356 L F
.417 .093 .305 r
.34939 .62072 m .35286 .61815 L .35209 .62042 L F
.579 .425 .636 r
.35476 .61703 m .35209 .62042 L .35286 .61815 L F
.259 0 0 r
.28248 .64536 m .287 .64551 L .28508 .64602 L F
.735 .224 0 r
.287 .64551 m .28721 .64747 L .28508 .64602 L F
.287 .64551 m .28959 .6475 L .28721 .64747 L F
.821 .639 .656 r
.33677 .52528 m .33958 .53152 L .33562 .52938 L F
.645 .454 .61 r
.34386 .52819 m .33858 .52697 L .34217 .52435 L F
.33858 .52697 m .33858 .52694 L .34217 .52435 L F
.5 .488 .775 r
.3419 .52923 m .33854 .52781 L .3387 .52705 L F
.645 .454 .61 r
.33858 .52697 m .3419 .52923 L .33854 .52696 L F
.34386 .52819 m .3419 .52923 L .33858 .52697 L F
.5 .488 .775 r
.3419 .52923 m .3387 .52705 L .33875 .5268 L F
.33854 .52781 m .33785 .52752 L .33858 .52694 L F
.33854 .52781 m .33858 .52694 L .33875 .5268 L F
.645 .454 .61 r
.33858 .52697 m .33854 .52696 L .33858 .52694 L F
.5 .488 .775 r
.3419 .52923 m .33875 .5268 L .33854 .52696 L F
.33875 .5268 m .33785 .52752 L .33677 .52528 L F
.33875 .5268 m .33677 .52528 L .33854 .52696 L F
.221 0 0 r
.33875 .5268 m .34217 .52435 L .33858 .52694 L F
.34145 .52465 m .34154 .52461 L .33875 .5268 L F
.34154 .52461 m .34217 .52435 L .33875 .5268 L F
.3383 .52598 m .34145 .52465 L .33854 .52696 L F
.34145 .52465 m .33858 .52694 L .33854 .52696 L F
.5 .488 .775 r
.3419 .52923 m .33971 .53139 L .33785 .52752 L F
.33971 .53139 m .33958 .53152 L .33952 .53138 L F
.33971 .53139 m .33952 .53138 L .33677 .52528 L F
.236 0 0 r
.33897 .53158 m .34135 .53161 L .34177 .53149 L F
.34019 .53141 m .34177 .53149 L .34383 .53091 L F
.33897 .53158 m .34177 .53149 L .34019 .53141 L F
.102 0 0 r
.34383 .53091 m .34135 .53161 L .34682 .53089 L F
.127 .375 .832 r
.37978 .5189 m .38013 .52057 L .37839 .51755 L F
0 .135 .682 r
.38168 .52107 m .38013 .52057 L .37978 .5189 L F
.38168 .52107 m .38228 .52272 L .38013 .52057 L F
0 .217 .739 r
.39183 .53235 m .39421 .53429 L .39415 .53552 L F
0 0 .469 r
.39421 .53429 m .39556 .53802 L .39415 .53552 L F
.424 .848 .953 r
.34549 .52916 m .34804 .52849 L .34972 .52883 L F
0 .484 .718 r
.34804 .52849 m .3519 .5292 L .34972 .52883 L F
.424 .309 .618 r
.36877 .61774 m .37114 .61997 L .3708 .61724 L F
.444 .31 .604 r
.36899 .62066 m .37114 .61997 L .36877 .61774 L F
.574 .935 .79 r
.35003 .63617 m .3452 .63863 L .34773 .63798 L F
0 0 .498 r
.34842 .63218 m .35003 .63617 L .35008 .63482 L F
.789 .967 .662 r
.35008 .63482 m .35003 .63617 L .34773 .63798 L F
.775 .568 .619 r
.29447 .55041 m .29823 .54869 L .29462 .54898 L F
.371 0 .048 r
.3721 .53661 m .37394 .53588 L .369 .53618 L F
.3721 .53661 m .37239 .5378 L .37394 .53588 L F
.087 0 0 r
.37394 .53588 m .37641 .53836 L .37688 .53576 L F
.37394 .53588 m .3749 .53665 L .37641 .53836 L F
.37394 .53588 m .37239 .5378 L .3749 .53665 L F
.683 .575 .728 r
.3252 .56027 m .32531 .56036 L .32697 .56057 L F
.69 .793 .929 r
.32674 .56109 m .32945 .56088 L .32697 .56057 L F
.061 .202 .698 r
.32887 .56315 m .32674 .56109 L .32697 .56057 L F
.683 .575 .728 r
.32531 .56036 m .32887 .56315 L .32697 .56057 L F
.69 .793 .929 r
.32945 .56088 m .33064 .56078 L .32697 .56057 L F
.251 0 0 r
.33319 .56111 m .32697 .56057 L .33064 .56078 L F
.61 .473 .67 r
.37035 .56434 m .37304 .564 L .37279 .56133 L F
.62 .232 .287 r
.37035 .56434 m .37297 .5659 L .37304 .564 L F
.37035 .56434 m .36895 .56646 L .37297 .5659 L F
.654 .418 .55 r
.39632 .56436 m .3962 .56694 L .39361 .56713 L F
.455 .451 .765 r
.30383 .56433 m .30287 .56276 L .30305 .56142 L F
.30287 .56276 m .30148 .56047 L .30305 .56142 L F
.582 .03 0 r
.30129 .56096 m .30305 .56142 L .30148 .56047 L F
.548 .478 .728 r
.30315 .56068 m .30305 .56142 L .30129 .56096 L F
.30536 .56036 m .30305 .56142 L .30315 .56068 L F
.188 0 .108 r
.38096 .62763 m .38004 .62949 L .37787 .63021 L F
.491 .119 .261 r
.38267 .62915 m .38096 .62763 L .38279 .62646 L F
.38267 .62915 m .38004 .62949 L .38096 .62763 L F
.55 .069 .066 r
.34921 .51526 m .35197 .51716 L .34878 .51738 L F
.09 .402 .856 r
.31909 .53861 m .32011 .53546 L .31718 .53548 L F
.31909 .53861 m .31949 .53717 L .32011 .53546 L F
.31909 .53861 m .32062 .5392 L .31949 .53717 L F
.701 .503 .618 r
.31909 .53861 m .32273 .54204 L .32062 .5392 L F
.31909 .53861 m .31883 .54229 L .32273 .54204 L F
.288 .347 .75 r
.34926 .53498 m .3503 .53836 L .34885 .5385 L F
.308 .167 .52 r
.3503 .53836 m .34831 .54169 L .34885 .5385 L F
.521 0 0 r
.29525 .65038 m .2969 .64972 L .29924 .65097 L F
.702 .384 .436 r
.29249 .53657 m .29557 .53811 L .29449 .53523 L F
.29249 .53657 m .29147 .53844 L .29557 .53811 L F
.944 .718 .565 r
.2901 .53503 m .29147 .53844 L .29249 .53657 L F
.652 .097 0 r
.19423 .60001 m .1925 .59987 L .19102 .59844 L F
.398 .752 .993 r
.19423 .60001 m .19391 .59759 L .1925 .59987 L F
.19423 .60001 m .19642 .59987 L .19391 .59759 L F
.739 .852 .933 r
.29967 .53494 m .29925 .53639 L .30204 .53622 L F
.813 .78 .822 r
.29778 .53792 m .30204 .53622 L .29925 .53639 L F
.563 .823 .994 r
.30343 .53518 m .30204 .53622 L .30501 .53607 L F
.586 .474 .692 r
.30204 .53622 m .30417 .53887 L .30501 .53607 L F
.30204 .53622 m .30212 .53964 L .30417 .53887 L F
.627 .842 .983 r
.30288 .53487 m .30501 .53607 L .30709 .53485 L F
.686 .493 .62 r
.30501 .53607 m .3083 .53874 L .30709 .53485 L F
.30501 .53607 m .30417 .53887 L .3083 .53874 L F
.616 .244 .315 r
.30661 .53506 m .30454 .53862 L .30183 .5372 L F
.30709 .53485 m .30695 .53505 L .30661 .53506 L F
.30695 .53505 m .30454 .53862 L .30661 .53506 L F
.563 .823 .994 r
.30288 .53487 m .30267 .53521 L .30343 .53518 L F
.30267 .53521 m .30204 .53622 L .30343 .53518 L F
.556 .814 .994 r
.29967 .53494 m .30204 .53622 L .30288 .53487 L F
0 .237 .746 r
.38724 .52496 m .38821 .52657 L .3859 .52384 L F
0 .107 .659 r
.38941 .52684 m .38821 .52657 L .38724 .52496 L F
.38941 .52684 m .39031 .52869 L .38821 .52657 L F
0 .076 .59 r
.22268 .60071 m .22247 .60503 L .22046 .60105 L F
.22268 .60071 m .22339 .60465 L .22247 .60503 L F
.016 .129 .64 r
.22339 .60465 m .22409 .6071 L .22247 .60503 L F
0 0 0 r
.27324 .52556 m .27488 .52546 L .27574 .52441 L F
.27324 .52556 m .27215 .52617 L .27488 .52546 L F
.786 .668 .733 r
.3962 .58292 m .3929 .58538 L .394 .58335 L F
.417 .146 .393 r
.24046 .55492 m .23988 .55716 L .23772 .55761 L F
0 0 0 r
.24193 .55393 m .24046 .55492 L .24322 .55282 L F
.174 0 .293 r
.24165 .55605 m .24046 .55492 L .24193 .55393 L F
.24165 .55605 m .23988 .55716 L .24046 .55492 L F
.753 .627 .721 r
.3138 .54572 m .31138 .54554 L .31187 .54708 L F
.503 .476 .76 r
.31284 .54293 m .3138 .54572 L .31584 .54474 L F
.869 .672 .634 r
.31284 .54293 m .31138 .54554 L .3138 .54572 L F
.457 .852 .653 r
.31747 .62327 m .31482 .62482 L .31815 .6226 L F
.641 .487 .658 r
.32002 .62083 m .32114 .62439 L .31747 .62327 L F
.655 .338 .423 r
.36843 .70538 m .36701 .70821 L .36478 .70576 L F
.59 .286 .421 r
.37101 .70526 m .36701 .70821 L .36843 .70538 L F
.855 .527 .431 r
.30391 .58958 m .30265 .59207 L .30392 .59105 L F
0 0 .333 r
.30493 .5864 m .30391 .58958 L .30296 .58687 L F
.034 0 .015 r
.30459 .59071 m .30391 .58958 L .30536 .5886 L F
.30459 .59071 m .30265 .59207 L .30391 .58958 L F
.711 .278 .219 r
.29781 .64576 m .30184 .64631 L .30116 .64556 L F
.69 .738 .887 r
.33982 .5366 m .33797 .53883 L .34087 .53782 L F
0 0 0 r
.33982 .5366 m .33936 .53733 L .33797 .53883 L F
.55 .307 .5 r
.33787 .54157 m .34087 .53782 L .33797 .53883 L F
.091 .053 .517 r
.33936 .53733 m .33787 .54157 L .33797 .53883 L F
.625 .441 .613 r
.36158 .54509 m .35965 .54752 L .35967 .54529 L F
.509 .66 .928 r
.26142 .62222 m .26204 .62474 L .26023 .62289 L F
.628 .615 .818 r
.3835 .58017 m .3847 .57624 L .38222 .57677 L F
.3835 .58017 m .38612 .57969 L .3847 .57624 L F
.398 .297 .622 r
.3835 .58017 m .38589 .58197 L .38612 .57969 L F
.3835 .58017 m .38372 .58287 L .38589 .58197 L F
.188 .024 .413 r
.35966 .56876 m .35772 .56745 L .36006 .56677 L F
.35966 .56876 m .35716 .57204 L .35772 .56745 L F
.207 .352 .79 r
.35348 .57224 m .35555 .57692 L .35271 .57464 L F
.564 .29 .459 r
.31718 .53548 m .32011 .53546 L .321 .5323 L F
.397 .134 .394 r
.321 .5323 m .32255 .53463 L .32321 .53202 L F
.321 .5323 m .32011 .53546 L .32255 .53463 L F
.503 .475 .759 r
.37605 .59243 m .37687 .59561 L .37925 .59512 L F
0 0 .414 r
.34857 .61424 m .34964 .61622 L .35033 .6137 L F
.312 .164 .513 r
.32681 .54544 m .32857 .54721 L .32888 .54474 L F
.32681 .54544 m .32679 .54828 L .32857 .54721 L F
0 0 .18 r
.40722 .57506 m .40582 .57658 L .40699 .57331 L F
.182 .311 .761 r
.40722 .57506 m .40868 .57926 L .40582 .57658 L F
.225 0 0 r
.29295 .63584 m .29681 .63354 L .29529 .6325 L F
.686 .885 .972 r
.29529 .6325 m .29681 .63354 L .29649 .63265 L F
.025 .546 .864 r
.26063 .63403 m .26158 .63364 L .2588 .6334 L F
.26063 .63403 m .26339 .63457 L .26158 .63364 L F
.924 .694 .571 r
.3316 .68406 m .33137 .68572 L .32946 .68295 L F
.61 .928 .967 r
.37838 .66181 m .37336 .66272 L .37667 .66061 L F
.833 .905 .888 r
.37896 .65877 m .37838 .66181 L .37667 .66061 L F
.37896 .65877 m .38092 .65942 L .37838 .66181 L F
0 0 0 r
.31748 .54796 m .31661 .55014 L .31435 .55129 L F
.227 0 0 r
.31791 .54953 m .31748 .54796 L .31971 .54751 L F
.31791 .54953 m .31661 .55014 L .31748 .54796 L F
.916 .694 .197 r
.72218 .29459 m .72279 .29499 L .7205 .29679 L F
.125 0 0 r
.7213 .29874 m .72218 .29459 L .7205 .29679 L F
.546 .523 .781 r
.36729 .58251 m .36855 .58672 L .37073 .58575 L F
.71 .474 .567 r
.3017 .54156 m .30417 .53887 L .30212 .53964 L F
.604 .223 .294 r
.26584 .55096 m .26433 .55348 L .26218 .5516 L F
.525 .172 .311 r
.26808 .55048 m .26433 .55348 L .26584 .55096 L F
.502 .296 .532 r
.31921 .55493 m .31897 .55731 L .32177 .55511 L F
.253 .137 .521 r
.18732 .58261 m .18879 .57922 L .18717 .57994 L F
.361 .173 .486 r
.34183 .60179 m .34177 .60487 L .33948 .60542 L F
.205 0 .124 r
.34091 .60649 m .33948 .60542 L .34177 .60487 L F
.34091 .60649 m .33876 .60743 L .33948 .60542 L F
0 0 0 r
.24552 .55208 m .24193 .55393 L .24322 .55282 L F
.332 0 0 r
.35477 .53918 m .35581 .5401 L .35693 .53897 L F
.35477 .53918 m .35302 .54068 L .35581 .5401 L F
.35477 .53918 m .35302 .54068 L .35581 .5401 L F
0 .575 .715 r
.30335 .63351 m .30346 .6335 L .3014 .63481 L F
.30335 .63351 m .30574 .63354 L .30346 .6335 L F
.277 .139 .505 r
.18845 .57374 m .19054 .57534 L .19062 .57257 L F
.18845 .57374 m .18834 .5767 L .19054 .57534 L F
.178 0 .127 r
.21372 .57448 m .21285 .57792 L .21095 .57861 L F
.509 .251 .459 r
.2168 .57381 m .21776 .57515 L .21372 .57448 L F
.217 0 0 r
.21776 .57515 m .21285 .57792 L .21372 .57448 L F
.491 .506 .801 r
.34542 .63118 m .34736 .62952 L .34516 .62963 L F
.34542 .63118 m .34842 .63218 L .34736 .62952 L F
.317 0 .071 r
.33054 .65295 m .3272 .65501 L .32862 .65428 L F
.33054 .65295 m .32862 .65428 L .3299 .65269 L F
.674 .944 .677 r
.3299 .65269 m .33054 .65295 L .32862 .65428 L F
.476 0 0 r
.33272 .6547 m .33054 .65295 L .3299 .65269 L F
.867 .649 .604 r
.34299 .6931 m .34036 .69568 L .34067 .69258 L F
.34299 .6931 m .34264 .69584 L .34036 .69568 L F
.312 .053 .35 r
.36097 .55675 m .36303 .55654 L .36141 .55484 L F
.831 .942 .897 r
.23072 .5502 m .23043 .55242 L .23305 .55072 L F
.74 .574 .669 r
.23043 .55242 m .23242 .55337 L .23305 .55072 L F
.664 .933 .969 r
.23297 .54902 m .23305 .55072 L .23532 .55041 L F
.23297 .54902 m .23072 .5502 L .23305 .55072 L F
.491 .331 .591 r
.23305 .55072 m .23242 .55337 L .23532 .55041 L F
.386 0 0 r
.25464 .54863 m .2573 .54897 L .25625 .54832 L F
.385 0 0 r
.25549 .54785 m .25625 .54832 L .25822 .5492 L F
.357 0 0 r
.25822 .5492 m .26063 .54959 L .26179 .54874 L F
.271 0 0 r
.25625 .54832 m .26063 .54959 L .25822 .5492 L F
.386 0 0 r
.2573 .54897 m .25871 .54915 L .25625 .54832 L F
.385 0 0 r
.25437 .54729 m .25625 .54832 L .25549 .54785 L F
.297 .116 .459 r
.33589 .63898 m .33616 .63643 L .33575 .63509 L F
.219 .649 .954 r
.33378 .60835 m .33424 .60734 L .33209 .60745 L F
.33378 .60835 m .33675 .60876 L .33424 .60734 L F
.367 .209 .531 r
.32503 .58103 m .32664 .58213 L .32683 .57945 L F
.32683 .57945 m .32664 .58213 L .32503 .58103 L F
.357 .317 .676 r
.32279 .62245 m .32002 .62083 L .3231 .62057 L F
.32279 .62245 m .32114 .62439 L .32002 .62083 L F
.506 .85 .995 r
.16894 .73005 m .17086 .73078 L .1712 .72942 L F
.16894 .73005 m .17086 .73078 L .1712 .72942 L F
.335 .374 .753 r
.71742 .3284 m .72013 .32995 L .71821 .33241 L F
.429 .508 .838 r
.72013 .32995 m .7216 .33333 L .71821 .33241 L F
.8 .968 .911 r
.24209 .54271 m .24242 .54472 L .24385 .54196 L F
.24209 .54271 m .24036 .54464 L .24242 .54472 L F
.656 .516 .681 r
.24036 .54464 m .2431 .54701 L .24242 .54472 L F
.579 .612 .85 r
.36084 .63285 m .3593 .63556 L .35865 .63312 L F
.36084 .63285 m .36242 .63621 L .3593 .63556 L F
.705 .94 .961 r
.35386 .67058 m .35007 .67132 L .35234 .67017 L F
.73 .363 .356 r
.35414 .70528 m .35828 .70565 L .35685 .70828 L F
.611 .228 .293 r
.35828 .70565 m .36057 .70763 L .35685 .70828 L F
0 0 0 r
.2431 .54701 m .24553 .54652 L .24809 .54597 L F
.257 0 0 r
.24828 .54612 m .24809 .54597 L .24553 .54652 L F
.24828 .54612 m .25013 .54676 L .24809 .54597 L F
.29 .136 .492 r
.2884 .60097 m .29118 .5979 L .28935 .59844 L F
.2884 .60097 m .29104 .60077 L .29118 .5979 L F
0 0 .301 r
.2884 .60097 m .28984 .60252 L .29104 .60077 L F
.2884 .60097 m .28864 .60395 L .28984 .60252 L F
.57 .934 .922 r
.30855 .62748 m .30275 .62881 L .30646 .62857 L F
.006 0 .194 r
.27425 .6263 m .27201 .62995 L .27288 .62734 L F
.503 .476 .76 r
.31284 .54293 m .31584 .54474 L .31671 .54402 L F
.403 .563 .899 r
.34883 .50537 m .34784 .50782 L .34624 .5053 L F
.473 .645 .932 r
.34883 .50537 m .35024 .50768 L .34784 .50782 L F
.382 .237 .557 r
.38004 .62949 m .38013 .63221 L .37787 .63021 L F
.244 .087 .46 r
.33117 .59135 m .32966 .58938 L .33188 .58855 L F
.33117 .59135 m .32949 .59203 L .32966 .58938 L F
.623 .226 .271 r
.36478 .70576 m .36306 .70784 L .36057 .70763 L F
.705 .328 .332 r
.36478 .70576 m .36701 .70821 L .36306 .70784 L F
.436 .11 .312 r
.23988 .55716 m .23605 .56092 L .23772 .55761 L F
.244 .705 .95 r
.35656 .50971 m .36051 .51051 L .35844 .51055 L F
.772 .611 .679 r
.34687 .62382 m .34335 .62628 L .34347 .62456 L F
.513 .592 .871 r
.38769 .60432 m .38553 .60513 L .38348 .60141 L F
.336 0 .233 r
.3007 .57932 m .29978 .58223 L .30224 .58135 L F
.543 .866 .995 r
.13005 .73564 m .13008 .73698 L .12912 .73677 L F
.13005 .73564 m .1326 .73645 L .13008 .73698 L F
.13008 .73698 m .12781 .73644 L .12912 .73677 L F
.13005 .73564 m .12912 .73677 L .12785 .73611 L F
.13008 .73698 m .13005 .73564 L .12781 .73644 L F
.13008 .73698 m .1326 .73645 L .13005 .73564 L F
.588 .551 .78 r
.25979 .74947 m .25673 .74647 L .25604 .74965 L F
.014 0 0 r
.3768 .60781 m .37349 .61034 L .37557 .61027 L F
0 0 .496 r
.3768 .60781 m .37774 .60706 L .3772 .60399 L F
.089 .491 .898 r
.2291 .62062 m .22885 .61927 L .22789 .61917 L F
0 0 .513 r
.2291 .62062 m .23064 .62283 L .22885 .61927 L F
0 .063 .623 r
.39823 .5436 m .39854 .54542 L .39669 .54236 L F
.988 .736 .362 r
.40226 .55372 m .40318 .55408 L .40179 .55134 L F
.40226 .55372 m .40318 .55544 L .40318 .55408 L F
.581 .386 .583 r
.33537 .55498 m .33826 .55463 L .33838 .55163 L F
0 0 0 r
.3658 .66436 m .36228 .66708 L .36391 .66679 L F
.3658 .66436 m .36391 .66679 L .3633 .66293 L F
.817 .348 .097 r
.36772 .66331 m .36791 .66135 L .3658 .66436 L F
.451 .291 .572 r
.36772 .66331 m .3658 .66436 L .36791 .66135 L F
.817 .348 .097 r
.36772 .66331 m .36392 .66067 L .36791 .66135 L F
.36772 .66331 m .3658 .66436 L .36468 .66372 L F
.36772 .66331 m .36468 .66372 L .36512 .66309 L F
.36512 .66309 m .36468 .66372 L .3633 .66293 L F
.685 .201 .096 r
.36572 .66479 m .36772 .66331 L .3633 .66293 L F
.817 .348 .097 r
.36772 .66331 m .36667 .66397 L .36392 .66067 L F
.263 .328 .743 r
.36392 .66067 m .36549 .66255 L .36535 .66089 L F
.36549 .66255 m .36667 .66397 L .36585 .66204 L F
.36549 .66255 m .36585 .66204 L .36535 .66089 L F
.302 .143 .493 r
.28935 .59844 m .29118 .5979 L .29121 .59528 L F
0 0 0 r
.33677 .52528 m .33562 .52938 L .33626 .52651 L F
.734 .683 .802 r
.3808 .57028 m .38231 .56621 L .37997 .56784 L F
.473 .283 .541 r
.32788 .5513 m .32658 .55584 L .32537 .5548 L F
.981 .742 .501 r
.37337 .54375 m .37506 .54755 L .37575 .54559 L F
.38 .063 .298 r
.37575 .54559 m .37506 .54755 L .37805 .54504 L F
.121 0 .247 r
.191 .56754 m .19027 .56977 L .19261 .56659 L F
.19 .066 .471 r
.20942 .58269 m .20935 .58555 L .20813 .5848 L F
.503 .475 .759 r
.37605 .59243 m .37925 .59512 L .3789 .59235 L F
.42 .324 .641 r
.38016 .58595 m .3789 .59235 L .38164 .59082 L F
.372 .222 .544 r
.3789 .59235 m .38224 .59458 L .38164 .59082 L F
.3789 .59235 m .37925 .59512 L .38224 .59458 L F
.189 .183 .621 r
.21109 .58126 m .20853 .58054 L .21095 .57861 L F
.21109 .58126 m .20942 .58269 L .20853 .58054 L F
.267 .512 .903 r
.71988 .31007 m .72183 .31033 L .72264 .31307 L F
.923 .796 .702 r
.71973 .31401 m .72264 .31307 L .72183 .31033 L F
.71973 .31401 m .72123 .31572 L .72264 .31307 L F
0 .287 .783 r
.34025 .55914 m .34242 .56198 L .34035 .56059 L F
.661 .286 .324 r
.63304 .40627 m .63598 .40403 L .63403 .40728 L F
.63304 .40627 m .63412 .40777 L .63598 .40403 L F
.658 .787 .327 r
.63617 .40362 m .63412 .40777 L .63705 .4017 L F
.63598 .40403 m .63572 .40455 L .63617 .40362 L F
.63572 .40455 m .63412 .40777 L .63617 .40362 L F
.755 .636 .729 r
.63703 .40976 m .63363 .41016 L .63387 .40839 L F
.6343 .40751 m .63387 .40839 L .63403 .40728 L F
.63703 .40976 m .63387 .40839 L .6343 .40751 L F
0 0 .171 r
.63416 .40972 m .63363 .41016 L .63703 .40976 L F
.631 .904 .601 r
.63962 .407 m .63828 .40807 L .63703 .40976 L F
.646 .956 .937 r
.63828 .40807 m .63416 .40972 L .63703 .40976 L F
0 0 .319 r
.4075 .56829 m .40674 .56732 L .40764 .56574 L F
.4075 .56829 m .40742 .57005 L .40674 .56732 L F
.414 .801 .989 r
.24947 .5525 m .24768 .55161 L .24552 .55208 L F
.362 .597 .936 r
.24947 .5525 m .24984 .54995 L .24768 .55161 L F
.24947 .5525 m .25182 .55232 L .24984 .54995 L F
0 0 0 r
.31486 .62486 m .31107 .62709 L .31311 .62603 L F
.554 .439 .677 r
.3861 .67053 m .38651 .67282 L .38371 .67356 L F
.53 .497 .764 r
.38738 .67691 m .38371 .67356 L .38651 .67282 L F
.775 .962 .655 r
.63847 .40077 m .63598 .40403 L .63705 .4017 L F
.581 .844 .493 r
.27691 .62313 m .27425 .6263 L .27576 .62455 L F
.18 0 .324 r
.36141 .66417 m .36197 .6617 L .36392 .66067 L F
.338 0 .149 r
.32293 .61293 m .32166 .61192 L .32065 .61359 L F
.32293 .61293 m .32411 .61138 L .32166 .61192 L F
0 0 0 r
.34652 .54364 m .34598 .54307 L .34831 .54169 L F
.34652 .54364 m .34433 .54479 L .34598 .54307 L F
.237 0 .23 r
.19618 .56365 m .19791 .56368 L .19888 .56093 L F
.305 0 .26 r
.19888 .56093 m .20016 .56281 L .2009 .56022 L F
.19888 .56093 m .19791 .56368 L .20016 .56281 L F
0 0 .041 r
.3721 .53661 m .37202 .53805 L .37239 .5378 L F
.37202 .53805 m .37039 .54184 L .37192 .5396 L F
.3721 .53661 m .3713 .53907 L .37202 .53805 L F
.3713 .53907 m .37039 .54184 L .37202 .53805 L F
.631 .913 .981 r
.37396 .53675 m .37239 .5378 L .37224 .53772 L F
.37284 .53688 m .37224 .53772 L .37099 .53708 L F
.37396 .53675 m .37224 .53772 L .37284 .53688 L F
.3749 .53665 m .37239 .5378 L .37396 .53675 L F
0 0 .041 r
.37202 .53805 m .37192 .5396 L .37239 .5378 L F
.514 .909 .793 r
.37745 .5515 m .37707 .55235 L .37967 .55302 L F
.37745 .5515 m .37499 .55293 L .37707 .55235 L F
.696 .297 .287 r
.35467 .55716 m .35126 .55527 L .35393 .5544 L F
.35467 .55716 m .35102 .55693 L .35126 .55527 L F
.012 0 0 r
.3412 .58475 m .3382 .58774 L .3382 .58543 L F
.882 .887 .831 r
.31743 .66044 m .31917 .66151 L .31655 .66467 L F
.573 .527 .766 r
.32179 .65854 m .31917 .66151 L .31832 .65901 L F
.32179 .65854 m .32162 .66109 L .31917 .66151 L F
.512 .491 .77 r
.32318 .66529 m .31917 .66151 L .32162 .66109 L F
.879 .632 .561 r
.35835 .53055 m .35411 .52829 L .35649 .5276 L F
.35835 .53055 m .35413 .53116 L .35411 .52829 L F
.745 .361 .326 r
.35835 .53055 m .3525 .53288 L .35413 .53116 L F
.35835 .53055 m .35749 .53407 L .3525 .53288 L F
.148 .328 .789 r
.35886 .52701 m .35835 .53055 L .35649 .5276 L F
.063 0 0 r
.35835 .53055 m .36227 .52978 L .35853 .53013 L F
.35835 .53055 m .3607 .53058 L .36227 .52978 L F
.148 .328 .789 r
.35886 .52701 m .3607 .53058 L .35835 .53055 L F
.557 .562 .814 r
.35958 .53556 m .3607 .53058 L .35835 .53055 L F
.334 0 .211 r
.35996 .53335 m .35835 .53055 L .3607 .53058 L F
.35996 .53335 m .35749 .53407 L .35835 .53055 L F
.29 .247 .636 r
.29874 .5673 m .30001 .5626 L .29736 .56325 L F
.29874 .5673 m .30046 .56655 L .30001 .5626 L F
.271 .202 .593 r
.29874 .5673 m .30064 .56928 L .30046 .56655 L F
.173 .039 .446 r
.30949 .5817 m .3082 .57993 L .30964 .57906 L F
.30949 .5817 m .30808 .58256 L .3082 .57993 L F
.554 .318 .512 r
.27306 .54154 m .2756 .54131 L .27596 .53854 L F
.392 .18 .467 r
.27596 .53854 m .27774 .54053 L .27834 .53803 L F
.27596 .53854 m .2756 .54131 L .27774 .54053 L F
.888 .908 .835 r
.36598 .54492 m .36232 .54765 L .36483 .54737 L F
.258 0 .053 r
.36483 .54737 m .36853 .54463 L .36598 .54492 L F
.489 0 0 r
.30733 .64724 m .30604 .64572 L .30506 .64799 L F
.30733 .64724 m .30839 .64613 L .30604 .64572 L F
.085 .043 .508 r
.32283 .5894 m .32464 .59047 L .32452 .58807 L F
.32283 .5894 m .32307 .59211 L .32464 .59047 L F
.57 .231 .354 r
.3111 .55172 m .30817 .55376 L .30853 .55185 L F
.808 .785 .831 r
.13519 .73595 m .13865 .7338 L .13497 .73549 L F
.076 0 0 r
.33319 .56111 m .32887 .56315 L .32697 .56057 L F
.33319 .56111 m .33129 .56253 L .32887 .56315 L F
.012 0 0 r
.33544 .56028 m .33129 .56253 L .33319 .56111 L F
.775 .568 .619 r
.29447 .55041 m .29806 .55144 L .29823 .54869 L F
.619 .433 .608 r
.29823 .54869 m .30077 .55103 L .30079 .5485 L F
.29823 .54869 m .29806 .55144 L .30077 .55103 L F
.397 .145 .411 r
.33772 .55959 m .33596 .55797 L .33731 .55716 L F
.33772 .55959 m .33544 .56028 L .33596 .55797 L F
.604 .509 .719 r
.33826 .55463 m .33596 .55797 L .33537 .55498 L F
.182 0 0 r
.26063 .54959 m .26444 .54796 L .26179 .54874 L F
.24 .754 .757 r
.33537 .55498 m .33642 .55456 L .33826 .55463 L F
.33537 .55498 m .33294 .55541 L .33642 .55456 L F
.86 .949 .871 r
.71533 .34556 m .71651 .34237 L .71756 .34412 L F
.71533 .34556 m .71321 .34541 L .71651 .34237 L F
.444 .731 .988 r
.2108 .61043 m .21219 .60923 L .20854 .60804 L F
.2108 .61043 m .21319 .61052 L .21219 .60923 L F
.837 .367 .05 r
.27498 .63957 m .27836 .643 L .27842 .64158 L F
0 0 .442 r
.27842 .64158 m .27836 .643 L .27877 .64161 L F
.525 .573 .846 r
.27836 .643 m .28248 .64536 L .28112 .64461 L F
.009 .34 .82 r
.27836 .643 m .28112 .64461 L .27877 .64161 L F
.473 .193 .407 r
.36505 .54191 m .36148 .54243 L .36373 .54046 L F
.36505 .54191 m .36158 .54509 L .36148 .54243 L F
.36505 .54191 m .3642 .54509 L .36158 .54509 L F
.594 .568 .794 r
.364 .53926 m .36505 .54191 L .36722 .54117 L F
.245 .704 .95 r
.36722 .54117 m .36373 .54046 L .36505 .54191 L F
.178 0 .285 r
.36654 .54341 m .36505 .54191 L .36722 .54117 L F
.36654 .54341 m .3642 .54509 L .36505 .54191 L F
.843 .58 .541 r
.38016 .58595 m .38109 .58612 L .38098 .58642 L F
.601 .441 .637 r
.38109 .58612 m .3843 .58644 L .38372 .58287 L F
.302 0 .249 r
.38149 .58865 m .3843 .58644 L .38109 .58612 L F
.732 .903 .526 r
.38626 .64235 m .38477 .64409 L .38418 .64559 L F
.747 .97 .698 r
.38477 .64409 m .38222 .64693 L .38418 .64559 L F
.909 .98 .711 r
.34244 .63134 m .34516 .62963 L .34406 .62875 L F
.478 .298 .557 r
.35924 .57654 m .3593 .57923 L .35689 .57964 L F
.412 .275 .584 r
.3592 .58186 m .35689 .57964 L .3593 .57923 L F
.35858 .58126 m .35717 .58234 L .35689 .57964 L F
.742 .501 .566 r
.35488 .5813 m .35881 .57946 L .35481 .57849 L F
.35881 .57946 m .3593 .57923 L .35885 .57916 L F
.35881 .57946 m .35885 .57916 L .35481 .57849 L F
.412 .275 .584 r
.3592 .58186 m .35847 .58203 L .35858 .58126 L F
.35847 .58203 m .35717 .58234 L .35858 .58126 L F
0 0 0 r
.34198 .50621 m .34182 .50633 L .34383 .50583 L F
.397 .437 .785 r
.3412 .51042 m .34182 .50633 L .34198 .50621 L F
.885 .988 .805 r
.34825 .62036 m .34939 .62072 L .34687 .62382 L F
.479 .262 .506 r
.34687 .62382 m .34939 .62072 L .34925 .62328 L F
.848 .76 .248 r
.34964 .61622 m .34939 .62072 L .34891 .62033 L F
.202 .719 .88 r
.34891 .62033 m .34939 .62072 L .34825 .62036 L F
.66 .456 .597 r
.35209 .62042 m .34925 .62328 L .34939 .62072 L F
.431 .825 .606 r
.63847 .40077 m .64002 .39962 L .64125 .39956 L F
.63847 .40077 m .63705 .4017 L .64002 .39962 L F
.351 .594 .937 r
.22325 .61601 m .22435 .61782 L .22512 .61607 L F
.279 .508 .897 r
.22435 .61782 m .22789 .61917 L .22512 .61607 L F
.227 0 .267 r
.39697 .67391 m .3964 .67657 L .39397 .67752 L F
.356 .056 .312 r
.39863 .6758 m .39697 .67391 L .39811 .67319 L F
.39863 .6758 m .3964 .67657 L .39697 .67391 L F
.603 .677 .893 r
.29806 .55144 m .30245 .5536 L .30077 .55103 L F
.714 .573 .695 r
.29962 .55778 m .30195 .5578 L .30245 .5536 L F
0 0 0 r
.30245 .5536 m .29962 .55778 L .30181 .55522 L F
.386 .465 .819 r
.30245 .5536 m .30291 .55019 L .30077 .55103 L F
.30245 .5536 m .30448 .55401 L .30291 .55019 L F
.568 .485 .721 r
.30195 .5578 m .30448 .55401 L .30245 .5536 L F
.115 0 0 r
.30181 .55522 m .30448 .55401 L .30245 .5536 L F
.582 .738 .95 r
.25533 .53961 m .25707 .54234 L .25951 .54178 L F
.93 .968 .755 r
.34383 .50583 m .34182 .50633 L .34209 .50466 L F
.3 .754 .955 r
.34271 .50475 m .34883 .50537 L .34624 .5053 L F
.34209 .50466 m .34262 .50471 L .34271 .50475 L F
.34262 .50471 m .34883 .50537 L .34271 .50475 L F
.34262 .50471 m .34705 .50475 L .34883 .50537 L F
.34209 .50466 m .3426 .50467 L .34262 .50471 L F
.3426 .50467 m .34705 .50475 L .34262 .50471 L F
.545 .764 .979 r
.34558 .50323 m .34209 .50466 L .34299 .50361 L F
.34558 .50323 m .34705 .50475 L .34348 .50468 L F
.34309 .50425 m .34348 .50468 L .34209 .50466 L F
.34558 .50323 m .34348 .50468 L .34309 .50425 L F
.167 0 0 r
.34182 .50633 m .33815 .50828 L .33847 .50615 L F
.482 0 0 r
.33847 .50615 m .34113 .50675 L .34182 .50633 L F
.167 0 0 r
.33927 .50769 m .3403 .50779 L .33815 .50828 L F
.34182 .50633 m .3403 .50779 L .33927 .50769 L F
.397 .437 .785 r
.3412 .51042 m .34301 .50996 L .34182 .50633 L F
0 0 .572 r
.34301 .50996 m .34325 .50886 L .34182 .50633 L F
.82 .427 .308 r
.34182 .50633 m .34325 .50886 L .3403 .50779 L F
.817 .367 0 r
.34325 .50886 m .34277 .50941 L .3403 .50779 L F
.134 .306 .773 r
.3403 .50779 m .34277 .50941 L .34216 .50797 L F
.711 .379 .414 r
.33857 .50471 m .34259 .50371 L .34113 .50675 L F
.839 .985 .707 r
.34182 .50633 m .34299 .50361 L .34209 .50466 L F
.711 .379 .414 r
.34275 .50388 m .3428 .50393 L .34199 .5053 L F
.34275 .50388 m .34199 .5053 L .34113 .50675 L F
.34259 .50371 m .34275 .50388 L .34113 .50675 L F
.839 .985 .707 r
.34182 .50633 m .34113 .50675 L .34239 .50461 L F
.992 .791 .532 r
.34182 .50633 m .3403 .50779 L .34113 .50675 L F
.202 .605 .947 r
.33857 .50471 m .34113 .50675 L .33847 .50615 L F
.134 .306 .773 r
.3403 .50779 m .34216 .50797 L .34125 .50579 L F
.711 .379 .414 r
.34259 .50371 m .34299 .50361 L .3428 .50393 L F
.839 .985 .707 r
.34256 .5046 m .34255 .50434 L .34261 .50449 L F
.34182 .50633 m .3425 .50448 L .34256 .5046 L F
.3425 .50448 m .34255 .50434 L .34256 .5046 L F
.34245 .50464 m .34239 .50461 L .34255 .50434 L F
.34182 .50633 m .34239 .50461 L .34245 .50464 L F
.34261 .50449 m .34255 .50434 L .34299 .50361 L F
.93 .968 .755 r
.34383 .50583 m .34288 .5052 L .34624 .5053 L F
.34288 .5052 m .34209 .50466 L .34271 .50475 L F
.34288 .5052 m .34271 .50475 L .34624 .5053 L F
.095 .27 .752 r
.38382 .62225 m .38619 .62691 L .38296 .62385 L F
.56 .336 .532 r
.38296 .62385 m .38619 .62691 L .38279 .62646 L F
.38296 .62385 m .38619 .62691 L .38279 .62646 L F
.013 0 0 r
.21774 .54428 m .21944 .54407 L .22119 .54265 L F
0 0 0 r
.22119 .54265 m .22137 .54327 L .22352 .54202 L F
.22119 .54265 m .21944 .54407 L .22137 .54327 L F
.201 .524 .919 r
.27072 .63692 m .27498 .63957 L .27324 .63858 L F
0 .281 .778 r
.27072 .63692 m .27324 .63858 L .27232 .6371 L F
.191 .283 .729 r
.32157 .57007 m .32262 .57398 L .32362 .5724 L F
.32157 .57007 m .32362 .5724 L .32341 .57161 L F
.32157 .57007 m .32387 .572 L .32394 .56951 L F
0 0 0 r
.3216 .57059 m .32157 .57007 L .32394 .56951 L F
.575 .682 .913 r
.3186 .56618 m .32196 .56928 L .31778 .57036 L F
.32196 .56928 m .32249 .56977 L .32204 .56983 L F
.32196 .56928 m .32204 .56983 L .31778 .57036 L F
.618 .194 .215 r
.32157 .57007 m .31722 .57181 L .31778 .57036 L F
.32157 .57007 m .32047 .57225 L .31722 .57181 L F
.602 .69 .904 r
.32185 .56853 m .32249 .56977 L .3186 .56618 L F
.57 .572 .816 r
.32014 .56391 m .32395 .56681 L .32257 .56328 L F
.602 .69 .904 r
.32185 .56853 m .3186 .56618 L .32104 .5645 L F
.968 .828 .408 r
.32066 .5675 m .3216 .57059 L .32185 .56857 L F
.32184 .56851 m .32185 .56857 L .32185 .56853 L F
.32066 .5675 m .32185 .56857 L .32184 .56851 L F
0 0 0 r
.3216 .57059 m .32296 .56996 L .32185 .56853 L F
.32296 .56996 m .32394 .56951 L .32268 .56892 L F
.32296 .56996 m .32268 .56892 L .32185 .56853 L F
.191 .283 .729 r
.32341 .57161 m .32362 .5724 L .32387 .572 L F
.354 .502 .867 r
.32262 .57398 m .32573 .57498 L .32387 .572 L F
0 0 .383 r
.34943 .54564 m .35023 .54646 L .35146 .54481 L F
.34943 .54564 m .35055 .5486 L .35023 .54646 L F
0 0 0 r
.30785 .63423 m .3097 .63329 L .31204 .6324 L F
.28473 .52469 m .28696 .52454 L .28903 .52434 L F
.391 .85 .838 r
.28903 .52434 m .28925 .52368 L .29146 .52378 L F
.28903 .52434 m .28696 .52454 L .28925 .52368 L F
.439 .307 .604 r
.38916 .68832 m .3871 .69218 L .38728 .68956 L F
.89 .919 .837 r
.37131 .57196 m .37193 .57359 L .37445 .5704 L F
.625 .484 .67 r
.37279 .56133 m .37304 .564 L .37537 .5612 L F
.488 .521 .817 r
.30609 .56251 m .30383 .56433 L .30305 .56142 L F
.486 .013 .058 r
.30471 .56592 m .30383 .56433 L .30609 .56251 L F
.30471 .56592 m .30298 .56601 L .30383 .56433 L F
.41 .216 .504 r
.30079 .5485 m .30077 .55103 L .30291 .55019 L F
.485 .844 .993 r
.25335 .5396 m .25096 .54018 L .25417 .54122 L F
.266 .755 .67 r
.25335 .5396 m .25298 .53974 L .25096 .54018 L F
.691 .853 .96 r
.24921 .54056 m .25417 .54122 L .25096 .54018 L F
.266 .755 .67 r
.25298 .53974 m .24854 .54144 L .25096 .54018 L F
.691 .853 .96 r
.24848 .54046 m .24921 .54056 L .25096 .54018 L F
.485 .844 .993 r
.25335 .5396 m .25417 .54122 L .25533 .53961 L F
.766 .361 .285 r
.33712 .52028 m .33751 .51993 L .33919 .5191 L F
.297 .128 .475 r
.31884 .6144 m .3187 .6171 L .32065 .61359 L F
.471 .126 .3 r
.19261 .56659 m .19517 .56635 L .19618 .56365 L F
.009 0 .091 r
.19618 .56365 m .19684 .56515 L .19791 .56368 L F
.19618 .56365 m .19517 .56635 L .19684 .56515 L F
.134 .165 .628 r
.34322 .63628 m .34388 .63905 L .3452 .63863 L F
.022 0 0 r
.325 .55153 m .32629 .5516 L .32788 .5513 L F
.977 .683 .307 r
.32788 .5513 m .32629 .5516 L .32679 .54828 L F
.289 .108 .453 r
.32983 .55236 m .32788 .5513 L .33035 .55161 L F
.882 .887 .831 r
.31743 .66044 m .31655 .66467 L .31886 .66457 L F
0 0 0 r
.24603 .53166 m .24712 .53107 L .24492 .53185 L F
.24603 .53166 m .24492 .53185 L .24369 .53248 L F
.64219 .40362 m .64133 .40526 L .63962 .407 L F
.536 .862 .58 r
.64133 .40526 m .63828 .40807 L .63962 .407 L F
.151 0 .029 r
.33465 .66147 m .33262 .66217 L .33153 .66374 L F
0 0 0 r
.27125 .62109 m .27152 .62213 L .27289 .61943 L F
.27125 .62109 m .27002 .62252 L .27152 .62213 L F
.345 0 .206 r
.27152 .62213 m .27485 .61882 L .27289 .61943 L F
.27152 .62213 m .27379 .62166 L .27485 .61882 L F
.444 0 0 r
.26986 .62223 m .27271 .62182 L .27152 .62213 L F
.27271 .62182 m .27379 .62166 L .27152 .62213 L F
0 0 0 r
.27002 .62252 m .26956 .62306 L .27152 .62213 L F
.074 0 0 r
.31294 .57652 m .30964 .57906 L .31075 .57715 L F
.555 .333 .533 r
.22752 .55772 m .23012 .55739 L .23034 .55471 L F
.23034 .55471 m .23012 .55739 L .22752 .55772 L F
.418 .104 .323 r
.23034 .55471 m .23242 .55337 L .23043 .55242 L F
.565 .601 .848 r
.23072 .5502 m .23034 .55471 L .23043 .55242 L F
.418 .104 .323 r
.23034 .55471 m .23275 .5542 L .23242 .55337 L F
.565 .601 .848 r
.23072 .5502 m .23275 .5542 L .23034 .55471 L F
.387 .149 .427 r
.23012 .55739 m .23275 .5542 L .23034 .55471 L F
.23012 .55739 m .23275 .5542 L .23034 .55471 L F
.695 .695 .161 r
.31405 .5379 m .31172 .53867 L .31084 .53793 L F
.31405 .5379 m .31303 .54244 L .31172 .53867 L F
0 0 0 r
.38901 .59228 m .3898 .59242 L .39173 .58963 L F
.617 .45 .633 r
.32477 .52323 m .32218 .52626 L .32365 .52491 L F
.528 .317 .537 r
.32218 .52626 m .32462 .52847 L .32365 .52491 L F
.542 .406 .645 r
.29713 .56097 m .30001 .5626 L .30082 .56035 L F
.29713 .56097 m .29736 .56325 L .30001 .5626 L F
.534 .656 .914 r
.38187 .65692 m .38092 .65942 L .37896 .65877 L F
.38187 .65692 m .38334 .65919 L .38092 .65942 L F
.33 .772 .964 r
.38387 .65948 m .38092 .65942 L .38334 .65919 L F
.885 .988 .805 r
.34825 .62036 m .34687 .62382 L .34528 .62094 L F
.547 0 0 r
.34739 .67143 m .34346 .67054 L .34666 .66972 L F
.257 .731 .939 r
.34825 .6707 m .34739 .67143 L .34666 .66972 L F
.34825 .6707 m .35007 .67132 L .34739 .67143 L F
0 0 0 r
.24605 .54122 m .24209 .54271 L .24385 .54196 L F
.809 .593 .611 r
.3462 .69911 m .34816 .70186 L .34492 .70147 L F
.781 .442 .412 r
.34492 .70147 m .34816 .70186 L .34625 .70432 L F
.683 .313 .339 r
.34816 .70186 m .3507 .70438 L .34625 .70432 L F
.715 .294 .247 r
.34816 .70186 m .3504 .70275 L .3507 .70438 L F
0 0 0 r
.38791 .63852 m .38722 .64082 L .38626 .64235 L F
.63 .861 .493 r
.38722 .64082 m .38477 .64409 L .38626 .64235 L F
.883 .698 .647 r
.3462 .69911 m .34242 .70117 L .34263 .6985 L F
.3462 .69911 m .34492 .70147 L .34242 .70117 L F
.554 .142 .215 r
.31435 .55129 m .31338 .55337 L .3111 .55172 L F
0 0 0 r
.31661 .55014 m .31338 .55337 L .31435 .55129 L F
0 .375 .837 r
.27498 .63957 m .27799 .64029 L .27324 .63858 L F
.27498 .63957 m .27842 .64158 L .27799 .64029 L F
0 0 .109 r
.40485 .55946 m .40484 .56108 L .40468 .55727 L F
0 0 .19 r
.40525 .56213 m .40484 .56108 L .40485 .55946 L F
.40525 .56213 m .40529 .5636 L .40484 .56108 L F
.305 .13 .472 r
.34378 .60365 m .34183 .60179 L .34336 .60074 L F
.34378 .60365 m .34177 .60487 L .34183 .60179 L F
.438 0 0 r
.30684 .65796 m .30907 .65801 L .31093 .65937 L F
.552 .363 .578 r
.32477 .52323 m .32617 .5203 L .32379 .5201 L F
.32477 .52323 m .32743 .52011 L .32617 .5203 L F
.32477 .52323 m .32736 .52285 L .32743 .52011 L F
.493 .262 .491 r
.32365 .52491 m .32736 .52285 L .32477 .52323 L F
.879 .582 .481 r
.33947 .68972 m .33729 .69175 L .33701 .68936 L F
.33947 .68972 m .34067 .69258 L .33729 .69175 L F
.89 .919 .837 r
.37131 .57196 m .37445 .5704 L .37224 .57252 L F
.646 .918 .625 r
.37716 .56753 m .37469 .56949 L .37452 .57012 L F
.37716 .56753 m .37452 .57012 L .37446 .57039 L F
.51 .16 .308 r
.37834 .56808 m .37469 .56949 L .37601 .56685 L F
.604 .428 .617 r
.37834 .56808 m .37514 .57139 L .37469 .56949 L F
0 0 .316 r
.37478 .56907 m .37514 .57139 L .37496 .56957 L F
.606 .206 .258 r
.36895 .56646 m .37124 .56829 L .37297 .5659 L F
.33 0 .085 r
.37297 .5659 m .37124 .56829 L .37423 .56757 L F
.734 .24 .061 r
.36959 .56521 m .37423 .56757 L .37124 .56829 L F
.646 .918 .625 r
.37446 .57039 m .37452 .57012 L .37445 .5704 L F
.089 0 0 r
.37514 .57139 m .37445 .5704 L .37469 .56949 L F
.37514 .57139 m .37224 .57252 L .37445 .5704 L F
.767 .681 .768 r
.37095 .57092 m .37514 .57139 L .37423 .56757 L F
0 0 .316 r
.37423 .56757 m .37468 .56946 L .37468 .56945 L F
.37447 .56823 m .37468 .56945 L .37478 .56907 L F
.37423 .56757 m .37468 .56945 L .37447 .56823 L F
.37468 .56946 m .37514 .57139 L .37478 .56907 L F
.706 .307 .289 r
.37496 .56957 m .37212 .56993 L .37423 .56757 L F
.543 .928 .868 r
.37273 .56947 m .37212 .56993 L .37428 .56933 L F
0 0 0 r
.37357 .56824 m .37212 .56993 L .37135 .57051 L F
.543 .928 .868 r
.37039 .56967 m .37212 .56993 L .37273 .56947 L F
0 0 0 r
.37135 .57051 m .37212 .56993 L .37095 .57092 L F
.37423 .56757 m .37389 .56795 L .37357 .56824 L F
.37389 .56795 m .37212 .56993 L .37357 .56824 L F
.734 .24 .061 r
.36959 .56521 m .37453 .56815 L .37423 .56757 L F
.4 .564 .901 r
.36997 .5621 m .37418 .56768 L .36959 .56521 L F
.37418 .56768 m .37443 .56802 L .37405 .5678 L F
.37418 .56768 m .37405 .5678 L .36959 .56521 L F
.37443 .56802 m .37453 .56815 L .37445 .5681 L F
.37443 .56802 m .37445 .5681 L .36959 .56521 L F
.164 .428 .865 r
.36953 .51227 m .36909 .51286 L .36729 .51149 L F
.36953 .51227 m .37071 .51336 L .36909 .51286 L F
.563 .934 .909 r
.26437 .62443 m .26514 .62322 L .26785 .62324 L F
.167 .628 .934 r
.3477 .51288 m .34401 .5117 L .34597 .51278 L F
.74 .969 .7 r
.36227 .52978 m .36315 .52792 L .36463 .52932 L F
.36227 .52978 m .3607 .53058 L .36315 .52792 L F
.608 .577 .793 r
.36593 .53252 m .36227 .52978 L .36463 .52932 L F
.466 .092 .245 r
.37373 .55828 m .36807 .56045 L .36834 .55805 L F
.21 .003 .366 r
.39217 .68375 m .39152 .68602 L .38962 .68609 L F
.211 0 .23 r
.39152 .68602 m .38916 .68832 L .38962 .68609 L F
0 0 0 r
.29937 .54221 m .29592 .54601 L .29628 .5449 L F
.342 .117 .42 r
.23275 .5542 m .23532 .55041 L .23242 .55337 L F
.443 .623 .928 r
.26227 .53643 m .26265 .53372 L .26028 .53467 L F
.26227 .53643 m .2648 .53648 L .26265 .53372 L F
.461 .799 .999 r
.21678 .61226 m .21738 .61093 L .21484 .61102 L F
.21678 .61226 m .21935 .61196 L .21738 .61093 L F
0 0 .374 r
.38921 .60849 m .38965 .60523 L .38743 .60731 L F
.569 .375 .579 r
.38965 .60523 m .38901 .60692 L .38743 .60731 L F
.404 .767 .994 r
.38565 .60774 m .38921 .60849 L .38743 .60731 L F
.569 .375 .579 r
.38901 .60692 m .3883 .60877 L .38743 .60731 L F
.404 .767 .994 r
.38511 .60762 m .38565 .60774 L .38743 .60731 L F
.125 .139 .603 r
.36881 .65719 m .36791 .66135 L .3679 .65768 L F
.344 .165 .489 r
.18675 .59558 m .18866 .59587 L .1888 .59199 L F
.29 .357 .76 r
.18675 .59558 m .18912 .5971 L .18866 .59587 L F
.572 .594 .836 r
.18675 .59558 m .19102 .59844 L .18912 .5971 L F
0 0 0 r
.27574 .52441 m .27673 .52459 L .27828 .52417 L F
.27574 .52441 m .27488 .52546 L .27673 .52459 L F
.528 .205 .365 r
.26444 .54796 m .26699 .54765 L .26783 .54576 L F
.343 .024 .272 r
.26783 .54576 m .26923 .54696 L .2698 .54471 L F
.26783 .54576 m .26699 .54765 L .26923 .54696 L F
.164 .058 .478 r
.37349 .61034 m .37394 .61186 L .37557 .61027 L F
.37349 .61034 m .37309 .61351 L .37394 .61186 L F
.513 .845 .997 r
.386 .65833 m .38387 .65948 L .38334 .65919 L F
.386 .65833 m .38717 .65888 L .38387 .65948 L F
.563 .851 .997 r
.27008 .527 m .26518 .52636 L .26751 .52571 L F
.551 .857 .997 r
.27215 .52617 m .27008 .527 L .26751 .52571 L F
.525 .389 .637 r
.38372 .58287 m .38649 .58475 L .38589 .58197 L F
.38372 .58287 m .3843 .58644 L .38649 .58475 L F
.515 .609 .884 r
.32741 .51608 m .32743 .52011 L .32568 .51667 L F
0 0 .53 r
.32743 .52011 m .3283 .51963 L .32617 .5203 L F
.311 .17 .522 r
.32736 .52285 m .3291 .52298 L .32743 .52011 L F
.493 .262 .491 r
.32365 .52491 m .32714 .52528 L .32736 .52285 L F
0 0 .49 r
.32365 .52491 m .32595 .52615 L .32714 .52528 L F
.32365 .52491 m .32462 .52847 L .32595 .52615 L F
.812 .503 .467 r
.34445 .55713 m .34834 .56023 L .34651 .56112 L F
.608 .954 .845 r
.31438 .65025 m .31686 .64978 L .31871 .64845 L F
.747 .536 .61 r
.30195 .5578 m .30082 .56035 L .29962 .55778 L F
.30195 .5578 m .30129 .56096 L .30082 .56035 L F
.568 .485 .721 r
.30195 .5578 m .30497 .55749 L .30448 .55401 L F
.595 .389 .572 r
.30536 .56036 m .30195 .5578 L .30497 .55749 L F
.30536 .56036 m .30129 .56096 L .30195 .5578 L F
.747 .536 .61 r
.30082 .56035 m .30129 .56096 L .30195 .5578 L F
.57 .231 .354 r
.3111 .55172 m .31072 .55365 L .30817 .55376 L F
.508 .175 .337 r
.3111 .55172 m .31338 .55337 L .31072 .55365 L F
.55 .307 .5 r
.33787 .54157 m .34067 .5413 L .34087 .53782 L F
.598 .209 .276 r
.34256 .53675 m .33982 .5366 L .34087 .53782 L F
.432 .245 .525 r
.34067 .5413 m .34294 .54079 L .34256 .53675 L F
.598 .209 .276 r
.34256 .53675 m .34332 .53717 L .34295 .53711 L F
.425 .24 .524 r
.34256 .53675 m .34519 .53991 L .3452 .53912 L F
.34256 .53675 m .34294 .54079 L .34519 .53991 L F
.598 .209 .276 r
.34256 .53675 m .34295 .53711 L .33982 .5366 L F
.416 .376 .706 r
.34256 .53675 m .34524 .53703 L .34332 .53717 L F
.425 .24 .524 r
.34256 .53675 m .34295 .53711 L .34325 .5371 L F
.414 .495 .834 r
.34332 .53717 m .34335 .53698 L .34325 .5371 L F
.425 .24 .524 r
.34347 .53685 m .34335 .53698 L .34524 .53703 L F
.414 .495 .834 r
.34335 .53698 m .34524 .53703 L .34396 .53349 L F
.34332 .53717 m .34524 .53703 L .34335 .53698 L F
.425 .24 .524 r
.34335 .53698 m .34325 .5371 L .34524 .53703 L F
.34256 .53675 m .34325 .5371 L .34347 .53685 L F
.414 .495 .834 r
.34325 .5371 m .34396 .53349 L .34083 .53472 L F
.34335 .53698 m .34396 .53349 L .34325 .5371 L F
.631 .804 .373 r
.34315 .53701 m .34273 .53707 L .34295 .53711 L F
.34325 .5371 m .34295 .53711 L .34332 .53717 L F
.34315 .53701 m .34295 .53711 L .34325 .5371 L F
.425 .24 .524 r
.34295 .53711 m .3452 .53912 L .34524 .53705 L F
.34295 .53711 m .34524 .53705 L .34524 .53703 L F
.631 .804 .373 r
.34083 .53472 m .33982 .5366 L .34273 .53707 L F
.34083 .53472 m .34273 .53707 L .34315 .53701 L F
.432 .245 .525 r
.34067 .5413 m .3424 .53712 L .34087 .53782 L F
.3424 .53712 m .34256 .53675 L .34184 .53721 L F
.3424 .53712 m .34184 .53721 L .34087 .53782 L F
.244 .212 .623 r
.32321 .53202 m .32536 .53151 L .32462 .52847 L F
.114 0 .173 r
.32321 .53202 m .32433 .53366 L .32536 .53151 L F
.32321 .53202 m .32255 .53463 L .32433 .53366 L F
.629 .209 .227 r
.26218 .5516 m .26433 .55348 L .26157 .55303 L F
1 .801 .487 r
.36622 .55125 m .36542 .54986 L .36375 .55149 L F
0 0 .202 r
.40742 .57005 m .40737 .57265 L .40699 .57331 L F
0 0 .18 r
.40722 .57506 m .40699 .57331 L .40737 .57265 L F
.65 .343 .438 r
.36473 .61964 m .36215 .61757 L .36183 .62055 L F
.36473 .61964 m .36436 .61794 L .36215 .61757 L F
.247 .039 .388 r
.31084 .53793 m .31229 .53832 L .31401 .53807 L F
.695 .695 .161 r
.31404 .53796 m .31393 .53844 L .31303 .54244 L F
.31403 .53797 m .31393 .53844 L .31404 .53796 L F
.31393 .53844 m .31333 .54106 L .31316 .54181 L F
.31393 .53844 m .31316 .54181 L .31303 .54244 L F
.308 .041 .336 r
.31556 .53998 m .31333 .54106 L .31403 .53797 L F
.695 .695 .161 r
.31405 .5379 m .31403 .53797 L .31404 .53796 L F
.308 .041 .336 r
.31411 .53799 m .31403 .53797 L .31405 .5379 L F
.31556 .53998 m .31403 .53797 L .31411 .53799 L F
.247 .039 .388 r
.31402 .53802 m .31401 .53807 L .31427 .53803 L F
.31425 .53803 m .31427 .53803 L .31431 .53803 L F
.567 .659 .898 r
.31426 .53797 m .31431 .53803 L .31616 .53656 L F
.308 .041 .336 r
.31605 .53722 m .31461 .53771 L .31606 .53663 L F
.31612 .53678 m .31606 .53663 L .31616 .53656 L F
.31605 .53722 m .31606 .53663 L .31612 .53678 L F
.31461 .53771 m .31405 .5379 L .31616 .53656 L F
.31426 .53797 m .31405 .5379 L .31605 .53722 L F
0 0 .024 r
.31538 .53649 m .31405 .5379 L .31477 .53643 L F
.31616 .53656 m .31436 .53771 L .31538 .53649 L F
.31436 .53771 m .31405 .5379 L .31538 .53649 L F
.567 .659 .898 r
.31139 .53412 m .31426 .53797 L .31616 .53656 L F
.473 .895 .86 r
.31431 .53803 m .31449 .53739 L .31616 .53656 L F
.674 .233 .195 r
.31449 .53739 m .31626 .53697 L .31616 .53656 L F
.31626 .53697 m .31653 .53691 L .31616 .53656 L F
.367 .158 .458 r
.31626 .53697 m .31556 .53998 L .31612 .53678 L F
.3176 .53895 m .31679 .53936 L .31626 .53697 L F
.31679 .53936 m .31556 .53998 L .31626 .53697 L F
.674 .233 .195 r
.31626 .53697 m .3176 .53895 L .31653 .53691 L F
.367 .158 .458 r
.3176 .53895 m .31612 .53678 L .31616 .53656 L F
.674 .233 .195 r
.31621 .53698 m .3176 .53895 L .31626 .53697 L F
.308 .041 .336 r
.31582 .5385 m .31426 .53797 L .31605 .53722 L F
.674 .233 .195 r
.31449 .53739 m .31693 .53861 L .31621 .53698 L F
.31693 .53861 m .3176 .53895 L .31621 .53698 L F
.757 .614 .701 r
.30933 .53421 m .31424 .53798 L .31139 .53412 L F
.31424 .53798 m .31431 .53803 L .31426 .53797 L F
.31424 .53798 m .31426 .53797 L .31139 .53412 L F
.308 .041 .336 r
.31556 .53998 m .31411 .53799 L .31582 .5385 L F
.247 .039 .388 r
.31422 .53803 m .31427 .53803 L .31425 .53803 L F
.31424 .53803 m .31427 .53803 L .31422 .53803 L F
.308 .041 .336 r
.31411 .53799 m .31425 .53797 L .31422 .53803 L F
.757 .614 .701 r
.31418 .53793 m .3141 .53802 L .31422 .53803 L F
.31424 .53798 m .31422 .53803 L .31431 .53803 L F
.31418 .53793 m .31422 .53803 L .31424 .53798 L F
.308 .041 .336 r
.31411 .53799 m .31405 .5379 L .31425 .53797 L F
.31422 .53803 m .31425 .53797 L .31582 .5385 L F
.247 .039 .388 r
.31402 .53802 m .31424 .53803 L .31422 .53803 L F
.31084 .53793 m .31401 .53807 L .31402 .53802 L F
.757 .614 .701 r
.30933 .53421 m .31084 .53793 L .31402 .53802 L F
.31403 .53797 m .31402 .53802 L .3141 .53802 L F
.30933 .53421 m .31402 .53802 L .31403 .53797 L F
.30933 .53421 m .3141 .53802 L .31418 .53793 L F
.394 .714 .987 r
.19102 .59844 m .19138 .59703 L .18912 .5971 L F
0 .131 .675 r
.19102 .59844 m .1925 .59987 L .19138 .59703 L F
.729 .553 .653 r
.3811 .56283 m .37763 .56029 L .38213 .56073 L F
.326 0 .21 r
.38346 .56217 m .38213 .56073 L .38438 .56038 L F
.38346 .56217 m .3811 .56283 L .38213 .56073 L F
.38346 .56217 m .38213 .56073 L .38438 .56038 L F
.38346 .56217 m .3811 .56283 L .38213 .56073 L F
0 0 .47 r
.3954 .67863 m .39397 .67752 L .3964 .67657 L F
.528 .488 .756 r
.30082 .56035 m .30181 .55522 L .29962 .55778 L F
0 0 0 r
.33767 .6324 m .337 .63291 L .33575 .63509 L F
.105 .658 .796 r
.27681 .63001 m .27615 .63028 L .27422 .62987 L F
.813 .489 0 r
.37376 .51451 m .37387 .51379 L .37071 .51336 L F
.37376 .51451 m .37462 .51655 L .37387 .51379 L F
.44 .174 .412 r
.38198 .69843 m .37887 .70269 L .37962 .699 L F
.484 .9 .873 r
.35815 .5142 m .35401 .51543 L .35521 .51545 L F
.798 .779 .836 r
.39736 .66681 m .39776 .67075 L .39937 .66796 L F
.467 .473 .781 r
.36084 .63285 m .35865 .63312 L .3571 .6288 L F
.22 .415 .841 r
.37371 .60041 m .37478 .60213 L .37567 .60041 L F
.15 .323 .784 r
.37478 .60213 m .3772 .60399 L .37567 .60041 L F
.51 .787 .995 r
.24099 .61242 m .24002 .61401 L .23823 .6128 L F
.309 .527 .903 r
.24099 .61242 m .2419 .6142 L .24002 .61401 L F
.341 .312 .681 r
.32286 .62553 m .32126 .6271 L .32114 .62439 L F
.479 .837 .577 r
.32123 .627 m .32126 .6271 L .32286 .62553 L F
.32123 .627 m .31945 .62849 L .32126 .6271 L F
.558 .331 .527 r
.35661 .55116 m .35686 .55435 L .35393 .5544 L F
.273 .036 .361 r
.35965 .54752 m .35877 .5505 L .35661 .55116 L F
.163 .048 .465 r
.35838 .55279 m .35661 .55116 L .35877 .5505 L F
.35838 .55279 m .35686 .55435 L .35661 .55116 L F
.583 .734 .947 r
.23179 .61101 m .22963 .61174 L .22772 .61004 L F
.396 .238 .547 r
.36807 .56295 m .36587 .56094 L .36807 .56045 L F
.36807 .56295 m .36597 .56391 L .36587 .56094 L F
.236 .233 .652 r
.18789 .5861 m .18885 .5819 L .18732 .58261 L F
.18789 .5861 m .18916 .58572 L .18885 .5819 L F
.245 .264 .683 r
.18789 .5861 m .19002 .58817 L .18916 .58572 L F
.232 .262 .687 r
.18789 .5861 m .1889 .58907 L .19002 .58817 L F
0 0 .435 r
.38974 .58579 m .3898 .59242 L .38901 .59228 L F
.217 0 0 r
.38952 .59358 m .38901 .59228 L .3898 .59242 L F
.162 .335 .791 r
.36463 .52932 m .36693 .53089 L .36593 .53252 L F
0 0 .247 r
.36693 .53089 m .36593 .53521 L .36593 .53252 L F
.597 .452 .655 r
.36803 .5915 m .36555 .59516 L .36566 .59233 L F
.36803 .5915 m .36896 .59482 L .36555 .59516 L F
.082 0 .389 r
.36566 .59233 m .36741 .59446 L .36803 .5915 L F
.36566 .59233 m .36555 .59516 L .36741 .59446 L F
.28 .133 .496 r
.32682 .61595 m .3251 .61427 L .32711 .61358 L F
.32682 .61595 m .32509 .61702 L .3251 .61427 L F
.843 .515 .433 r
.27986 .63441 m .28268 .63331 L .28004 .63315 L F
.27986 .63441 m .28238 .63557 L .28268 .63331 L F
.831 .441 .313 r
.28084 .6376 m .28238 .63557 L .27986 .63441 L F
.974 .697 .442 r
.28084 .6376 m .28238 .63557 L .28003 .6339 L F
0 0 0 r
.27986 .63441 m .28004 .63315 L .28044 .63171 L F
.28042 .63184 m .28044 .63171 L .28046 .63165 L F
.27986 .63441 m .28044 .63171 L .28042 .63184 L F
.27986 .63441 m .28046 .63165 L .27937 .63441 L F
.974 .697 .442 r
.27991 .63451 m .28003 .6339 L .27965 .63363 L F
.28084 .6376 m .28003 .6339 L .27991 .63451 L F
.395 .525 .87 r
.21237 .58643 m .21159 .589 L .20935 .58555 L F
.21237 .58643 m .21335 .58842 L .21159 .589 L F
.437 .089 .275 r
.31824 .62936 m .31747 .63226 L .31473 .63255 L F
0 0 .089 r
.3188 .6311 m .31824 .62936 L .31945 .62849 L F
.3188 .6311 m .31747 .63226 L .31824 .62936 L F
.184 .443 .871 r
.35475 .50703 m .35576 .51021 L .35249 .50708 L F
.35475 .50703 m .35656 .50971 L .35576 .51021 L F
0 0 .186 r
.32965 .64962 m .32951 .64899 L .3299 .65269 L F
.32965 .64962 m .32951 .64899 L .3299 .65269 L F
.19 .367 .81 r
.20542 .60457 m .20618 .60253 L .20348 .60105 L F
.20542 .60457 m .20668 .6046 L .20618 .60253 L F
.749 .359 .314 r
.32329 .66537 m .32782 .66585 L .32567 .66635 L F
.224 .409 .835 r
.32574 .66632 m .32782 .66585 L .32567 .66635 L F
.733 .321 .266 r
.32455 .66659 m .32782 .66585 L .32566 .66766 L F
.32564 .66627 m .32782 .66585 L .32576 .66632 L F
.32329 .66537 m .32405 .66545 L .32564 .66627 L F
.32405 .66545 m .32782 .66585 L .32564 .66627 L F
.677 .822 .383 r
.32895 .66395 m .32741 .66688 L .32782 .66585 L F
.436 .062 .229 r
.32949 .66697 m .32895 .66395 L .32782 .66585 L F
.32949 .66697 m .33153 .66374 L .32895 .66395 L F
.782 .805 .871 r
.32128 .66388 m .32318 .66529 L .32162 .66109 L F
.32128 .66388 m .32531 .66378 L .32318 .66529 L F
.32318 .66529 m .32531 .66378 L .32128 .66388 L F
.581 .56 .796 r
.32922 .66445 m .32574 .66632 L .32405 .66181 L F
.32574 .66632 m .32567 .66635 L .32564 .66627 L F
.32574 .66632 m .32564 .66627 L .32405 .66181 L F
.667 .609 .781 r
.32405 .66181 m .32564 .66627 L .32329 .66537 L F
.32564 .66627 m .32567 .66635 L .32329 .66537 L F
.733 .321 .266 r
.32329 .66537 m .32576 .66632 L .32455 .66659 L F
.224 .409 .835 r
.32814 .66503 m .32782 .66585 L .32574 .66632 L F
.32922 .66445 m .32782 .66585 L .32814 .66503 L F
.677 .822 .383 r
.32741 .66688 m .32706 .66754 L .32782 .66585 L F
0 .15 .676 r
.32782 .66585 m .32706 .66754 L .32906 .66987 L F
0 .072 .63 r
.38378 .61329 m .38447 .6135 L .38373 .61439 L F
.262 .199 .595 r
.38409 .6152 m .38373 .61439 L .38447 .6135 L F
.037 0 0 r
.20985 .5516 m .20841 .55289 L .21205 .55082 L F
.357 .062 .321 r
.29708 .60745 m .29994 .60467 L .29895 .60761 L F
.039 0 .118 r
.3008 .60612 m .29994 .60467 L .30147 .60402 L F
.3008 .60612 m .29895 .60761 L .29994 .60467 L F
.525 .487 .756 r
.22196 .59664 m .22046 .60105 L .21972 .60002 L F
.072 .593 .876 r
.37782 .52515 m .37617 .52443 L .37368 .52419 L F
.898 .576 .431 r
.37916 .52771 m .37617 .52443 L .37782 .52515 L F
.388 0 .092 r
.36494 .56576 m .36337 .5647 L .36597 .56391 L F
.36494 .56576 m .36248 .56627 L .36337 .5647 L F
.803 .829 .871 r
.33102 .58058 m .32835 .58295 L .32664 .58213 L F
.569 .425 .646 r
.36158 .5732 m .36178 .57628 L .35924 .57654 L F
.437 .266 .55 r
.36151 .57856 m .35924 .57654 L .36178 .57628 L F
.36151 .57856 m .3593 .57923 L .35924 .57654 L F
.161 0 .195 r
.28457 .54353 m .28362 .5425 L .28534 .54134 L F
.28457 .54353 m .28263 .54484 L .28362 .5425 L F
.444 .732 .988 r
.14197 .70701 m .14592 .70852 L .14468 .70715 L F
.14197 .70701 m .14592 .70852 L .14468 .70715 L F
.583 .843 .994 r
.71469 .31607 m .71172 .31537 L .71354 .31342 L F
.71 .305 .276 r
.71469 .31607 m .71039 .31673 L .71172 .31537 L F
.71469 .31607 m .71415 .31774 L .71039 .31673 L F
.958 .947 .68 r
.71469 .31607 m .71591 .31066 L .71702 .31209 L F
.71469 .31607 m .71354 .31342 L .71591 .31066 L F
.18 .054 .462 r
.71661 .31365 m .71469 .31607 L .71791 .31552 L F
.71661 .31365 m .71415 .31774 L .71469 .31607 L F
.828 .703 .727 r
.32946 .68295 m .33137 .68572 L .32778 .68598 L F
.707 .303 .279 r
.32778 .68598 m .33137 .68572 L .32943 .68813 L F
.704 .299 .276 r
.33137 .68572 m .33334 .6883 L .32943 .68813 L F
.9 .873 .802 r
.26078 .76123 m .26226 .76213 L .25993 .76498 L F
.72 .552 .662 r
.26226 .76213 m .26307 .76541 L .25993 .76498 L F
.408 .354 .686 r
.26483 .76457 m .26307 .76541 L .26226 .76213 L F
.673 .127 0 r
.26353 .76424 m .26226 .76213 L .26078 .76123 L F
.26353 .76424 m .26483 .76457 L .26226 .76213 L F
.534 .269 .459 r
.22752 .55772 m .22961 .55975 L .23012 .55739 L F
.23012 .55739 m .22961 .55975 L .22752 .55772 L F
.676 .692 .857 r
.33732 .58021 m .33344 .57916 L .33561 .5788 L F
.711 .344 .351 r
.3356 .58118 m .33732 .58021 L .33561 .5788 L F
.33619 .58085 m .33984 .57968 L .33732 .58021 L F
.3367 .58079 m .33984 .57968 L .33619 .58085 L F
.3356 .58118 m .33839 .5817 L .33984 .57968 L F
.352 .533 .894 r
.33926 .57951 m .33885 .58055 L .3365 .57764 L F
.33885 .58055 m .33839 .5817 L .33791 .58066 L F
.33885 .58055 m .33791 .58066 L .3365 .57764 L F
.711 .344 .351 r
.3356 .58118 m .3367 .58079 L .33619 .58085 L F
.759 .887 .936 r
.71988 .31007 m .71702 .31209 L .71591 .31066 L F
.557 0 0 r
.21335 .58842 m .21713 .58929 L .21579 .5886 L F
.567 .397 .61 r
.34222 .64919 m .34533 .64838 L .34508 .64545 L F
.532 .303 .514 r
.34453 .65144 m .34222 .64919 L .34192 .65082 L F
.34453 .65144 m .34533 .64838 L .34222 .64919 L F
.288 .746 .953 r
.13005 .73564 m .1326 .73645 L .13422 .73615 L F
.13005 .73564 m .1326 .73645 L .13422 .73615 L F
.41 .031 .205 r
.34375 .55137 m .34618 .55141 L .34595 .55004 L F
.541 .117 .186 r
.34595 .55004 m .34969 .55061 L .35055 .5486 L F
.34595 .55004 m .34618 .55141 L .34969 .55061 L F
0 0 0 r
.64359 .40387 m .64219 .40362 L .64456 .40263 L F
.64359 .40387 m .64133 .40526 L .64219 .40362 L F
.459 .606 .909 r
.23153 .62454 m .23593 .62718 L .23453 .62579 L F
.32 .543 .911 r
.23593 .62718 m .23675 .62541 L .23453 .62579 L F
.23593 .62718 m .23786 .62743 L .23675 .62541 L F
.364 .12 .406 r
.36899 .62066 m .36854 .62305 L .37114 .61997 L F
.308 .167 .52 r
.3503 .53836 m .35038 .5408 L .34831 .54169 L F
.156 0 0 r
.34961 .54268 m .34831 .54169 L .35038 .5408 L F
.34961 .54268 m .34652 .54364 L .34831 .54169 L F
.42 .305 .616 r
.28978 .54211 m .29187 .54137 L .29147 .53844 L F
.126 .043 .483 r
.28978 .54211 m .29128 .5438 L .29187 .54137 L F
.545 0 0 r
.30977 .57269 m .31157 .57343 L .31281 .57336 L F
.719 .206 0 r
.31204 .57367 m .31281 .57336 L .31056 .57349 L F
.495 .535 .827 r
.31688 .57447 m .31224 .57371 L .31552 .57094 L F
.31224 .57371 m .31204 .57367 L .31208 .57364 L F
.31224 .57371 m .31208 .57364 L .31552 .57094 L F
.545 0 0 r
.30825 .57236 m .31056 .57349 L .31157 .57343 L F
.30825 .57236 m .31157 .57343 L .30977 .57269 L F
.75 .937 .947 r
.37727 .56534 m .37716 .56753 L .37601 .56685 L F
.151 .223 .684 r
.3452 .63863 m .34388 .63905 L .34613 .64124 L F
.343 .251 .605 r
.34388 .63905 m .34381 .64307 L .34613 .64124 L F
.543 .405 .643 r
.35033 .6137 m .35319 .60936 L .35041 .61112 L F
.21 0 0 r
.33037 .67614 m .33478 .67547 L .3318 .67561 L F
.75 .994 .86 r
.38305 .5749 m .38222 .57677 L .3847 .57624 L F
.509 .327 .569 r
.40294 .58272 m .40319 .5853 L .40054 .58585 L F
.557 .72 .95 r
.40054 .58585 m .40319 .5853 L .40181 .58349 L F
.902 .65 .142 r
.40054 .58585 m .4009 .5888 L .39993 .58734 L F
.431 .274 .566 r
.40319 .5853 m .4009 .5888 L .40054 .58585 L F
.902 .65 .142 r
.40054 .58585 m .39993 .58734 L .40319 .5853 L F
.545 .268 .447 r
.38589 .58197 m .38958 .58141 L .38612 .57969 L F
.522 .298 .515 r
.38612 .57969 m .38958 .58141 L .38855 .57926 L F
.606 .652 .87 r
.34265 .56207 m .3436 .56444 L .34582 .56342 L F
.712 .942 .958 r
.36228 .66708 m .35867 .66818 L .36182 .66791 L F
0 0 0 r
.36391 .66679 m .36228 .66708 L .36182 .66791 L F
.733 .33 .286 r
.30198 .64809 m .30184 .64631 L .29781 .64576 L F
.988 .728 .433 r
.38384 .54387 m .38276 .54348 L .38431 .54208 L F
.744 .945 .625 r
.38689 .53869 m .38431 .54208 L .38512 .54021 L F
.386 0 .178 r
.27196 .54399 m .2756 .54131 L .27306 .54154 L F
0 0 .123 r
.28046 .63165 m .28019 .63021 L .27862 .63018 L F
.274 .737 .949 r
.63278 .40937 m .63363 .41016 L .62981 .40961 L F
.63315 .40934 m .63318 .40939 L .63278 .40937 L F
.63318 .40939 m .63363 .41016 L .63278 .40937 L F
.968 .651 .346 r
.63363 .41016 m .62922 .41033 L .62981 .40961 L F
.63363 .41016 m .63222 .41044 L .62922 .41033 L F
.633 .139 .059 r
.62547 .40899 m .62981 .40961 L .62922 .41033 L F
.62547 .40899 m .62922 .41033 L .62886 .41001 L F
.438 0 0 r
.62878 .41001 m .62882 .40999 L .62547 .40899 L F
.62882 .40999 m .62981 .40961 L .62547 .40899 L F
.483 .487 .786 r
.62709 .40408 m .62876 .40994 L .62547 .40899 L F
.633 .139 .059 r
.62547 .40899 m .62886 .41001 L .62883 .40998 L F
.046 0 0 r
.63298 .40938 m .62981 .40961 L .62885 .40998 L F
.62918 .40994 m .62885 .40998 L .6288 .41 L F
.63298 .40938 m .62885 .40998 L .62918 .40994 L F
.508 .794 .997 r
.62922 .41033 m .63222 .41044 L .63179 .40964 L F
.046 0 0 r
.63324 .40916 m .62954 .40853 L .63251 .40815 L F
.63324 .40916 m .63069 .40563 L .63129 .40524 L F
.858 .781 .281 r
.63403 .40728 m .63363 .41016 L .63336 .40944 L F
.63403 .40728 m .63336 .40944 L .63336 .40937 L F
.63403 .40728 m .63335 .4094 L .63338 .40915 L F
.832 .952 .896 r
.63335 .40833 m .63336 .40932 L .63485 .40784 L F
.947 .652 .447 r
.63304 .40627 m .63318 .40782 L .63105 .40474 L F
.63318 .40782 m .63331 .40917 L .63276 .4081 L F
.63318 .40782 m .63276 .4081 L .63105 .40474 L F
.63331 .40917 m .63324 .40916 L .63105 .40474 L F
.832 .952 .896 r
.63193 .40878 m .63279 .4091 L .63335 .40833 L F
.63279 .4091 m .63336 .40918 L .63335 .40833 L F
.858 .781 .281 r
.63403 .40728 m .63332 .40932 L .63304 .40627 L F
.832 .952 .896 r
.63144 .40895 m .63484 .40785 L .63385 .40915 L F
.046 0 0 r
.63324 .40916 m .62896 .40997 L .62954 .40853 L F
.832 .952 .896 r
.63143 .40894 m .63328 .4094 L .63193 .40878 L F
.63143 .40894 m .63147 .40893 L .63144 .40895 L F
.63147 .40893 m .63484 .40785 L .63144 .40895 L F
.508 .794 .997 r
.62922 .41033 m .62999 .40985 L .62885 .40999 L F
.046 0 0 r
.62902 .40997 m .6288 .41 L .62878 .41001 L F
.63298 .40938 m .6288 .41 L .62902 .40997 L F
.63315 .40934 m .62981 .40961 L .63298 .40938 L F
.63298 .40938 m .62878 .41001 L .63324 .40916 L F
.832 .952 .896 r
.63279 .4091 m .63336 .40932 L .63336 .40918 L F
.947 .652 .447 r
.63331 .40917 m .63332 .40932 L .63324 .40916 L F
.832 .952 .896 r
.63484 .40785 m .63485 .40784 L .63485 .40785 L F
.858 .781 .281 r
.63336 .40937 m .63336 .40944 L .63335 .4094 L F
.709 .734 .871 r
.63328 .4094 m .63426 .40946 L .63485 .40784 L F
.832 .952 .896 r
.63484 .40785 m .63485 .40785 L .63385 .40915 L F
.046 0 0 r
.63251 .40815 m .62954 .40853 L .63069 .40563 L F
.63129 .40524 m .63069 .40563 L .63105 .40474 L F
.756 .244 0 r
.63123 .40521 m .63304 .40627 L .63105 .40474 L F
.769 .616 .689 r
.63684 .4016 m .63123 .40521 L .63659 .40148 L F
.63705 .4017 m .63245 .40447 L .63684 .4016 L F
.63245 .40447 m .63123 .40521 L .63684 .4016 L F
.508 .794 .997 r
.62999 .40985 m .63179 .40964 L .63143 .40894 L F
.62922 .41033 m .63179 .40964 L .62999 .40985 L F
.62999 .40985 m .63143 .40894 L .62885 .40999 L F
.046 0 0 r
.62896 .40997 m .62887 .40999 L .62888 .40997 L F
.62896 .40997 m .62888 .40997 L .63105 .40474 L F
.508 .794 .997 r
.62885 .40999 m .6289 .40997 L .62883 .40997 L F
.046 0 0 r
.62887 .40999 m .6288 .40996 L .63105 .40474 L F
.765 .661 .748 r
.63105 .40474 m .6288 .40996 L .62709 .40408 L F
.6288 .40996 m .62876 .40994 L .62709 .40408 L F
.508 .794 .997 r
.62883 .40997 m .63143 .40894 L .62849 .40967 L F
.6289 .40997 m .63143 .40894 L .62883 .40997 L F
.046 0 0 r
.63332 .40932 m .63315 .40934 L .63298 .40938 L F
.832 .952 .896 r
.63309 .40935 m .63222 .41044 L .63328 .4094 L F
.63143 .40894 m .63179 .40964 L .63309 .40935 L F
.63179 .40964 m .63222 .41044 L .63309 .40935 L F
.633 .139 .059 r
.6288 .40996 m .62883 .40998 L .62883 .40997 L F
.046 0 0 r
.62887 .40999 m .62878 .41001 L .6288 .40996 L F
.633 .139 .059 r
.62876 .40994 m .6288 .40996 L .62881 .40996 L F
.6288 .40996 m .62883 .40997 L .62881 .40996 L F
.62547 .40899 m .62883 .40998 L .62876 .40994 L F
.765 .661 .748 r
.6288 .40996 m .62878 .41001 L .62876 .40994 L F
.483 .487 .786 r
.62876 .40994 m .62878 .41001 L .62547 .40899 L F
.633 .139 .059 r
.62547 .40899 m .62881 .40996 L .62849 .40967 L F
.832 .952 .896 r
.63315 .40924 m .63328 .4094 L .63336 .40932 L F
.63307 .4093 m .63328 .4094 L .63315 .40924 L F
.046 0 0 r
.63332 .40932 m .63298 .40938 L .63324 .40916 L F
.832 .952 .896 r
.63193 .40878 m .63307 .4093 L .63315 .40924 L F
.858 .781 .281 r
.63338 .40915 m .63335 .4094 L .63332 .40932 L F
.709 .734 .871 r
.63328 .40993 m .63416 .40972 L .63426 .40946 L F
.63222 .41044 m .63327 .41006 L .63328 .40993 L F
.63327 .41006 m .63416 .40972 L .63328 .40993 L F
.274 .737 .949 r
.63336 .40944 m .63363 .41016 L .63315 .40934 L F
.709 .734 .871 r
.63222 .41044 m .63426 .40946 L .63328 .4094 L F
.274 .737 .949 r
.63332 .40932 m .63336 .40944 L .63315 .40934 L F
.968 .651 .346 r
.63363 .41016 m .63367 .41242 L .63222 .41044 L F
0 0 .171 r
.63416 .40972 m .63367 .41242 L .63363 .41016 L F
.347 .644 .965 r
.37695 .53403 m .37823 .53265 L .37718 .53326 L F
0 0 .361 r
.37609 .53183 m .37669 .53485 L .37695 .53403 L F
.347 .644 .965 r
.37695 .53403 m .37718 .53326 L .37589 .53402 L F
0 0 .361 r
.37669 .53485 m .37688 .53576 L .37695 .53403 L F
.983 .787 .564 r
.37688 .53576 m .3749 .53665 L .37695 .53403 L F
.37688 .53576 m .37641 .53836 L .3749 .53665 L F
.415 0 0 r
.37368 .52419 m .37254 .52529 L .36966 .52529 L F
.303 0 0 r
.37617 .52443 m .37254 .52529 L .37368 .52419 L F
.298 .486 .875 r
.23153 .62454 m .23251 .62248 L .23064 .62283 L F
.23153 .62454 m .23453 .62579 L .23251 .62248 L F
.587 .777 .97 r
.37001 .66268 m .37173 .6639 L .36772 .66331 L F
.658 .796 .948 r
.37336 .66272 m .37173 .6639 L .37001 .66268 L F
.594 .568 .794 r
.364 .53926 m .36722 .54117 L .36756 .53889 L F
.996 .825 .556 r
.36756 .53889 m .36591 .54039 L .36722 .54117 L F
0 .065 .628 r
.33072 .67079 m .3312 .66979 L .32906 .66987 L F
.346 .332 .701 r
.1888 .59199 m .19002 .58817 L .1889 .58907 L F
.1888 .59199 m .19013 .59166 L .19002 .58817 L F
.49 .326 .585 r
.18866 .59587 m .19013 .59166 L .1888 .59199 L F
.407 .071 .279 r
.30128 .54349 m .29937 .54221 L .3017 .54156 L F
.30128 .54349 m .29592 .54601 L .29937 .54221 L F
0 0 0 r
.31544 .66048 m .31832 .65901 L .31743 .66044 L F
.597 .593 .818 r
.3193 .6557 m .31832 .65901 L .31712 .656 L F
.3193 .6557 m .32179 .65854 L .31832 .65901 L F
.32 .188 .54 r
.36796 .58109 m .36729 .58251 L .36906 .58194 L F
.546 .523 .781 r
.36729 .58251 m .37073 .58575 L .36906 .58194 L F
.71 .474 .567 r
.3017 .54156 m .30722 .54382 L .30417 .53887 L F
.61 .445 .633 r
.30417 .53887 m .30789 .54118 L .3083 .53874 L F
.30417 .53887 m .30722 .54382 L .30789 .54118 L F
.527 .1 .174 r
.38319 .53666 m .38374 .53793 L .37909 .53801 L F
.76 .248 0 r
.38319 .53666 m .3848 .53854 L .38374 .53793 L F
.755 .3 .171 r
.38689 .53869 m .3848 .53854 L .38319 .53666 L F
.198 .339 .782 r
.34212 .57346 m .34494 .57586 L .34314 .57164 L F
.5 .373 .639 r
.34239 .57636 m .34494 .57586 L .34212 .57346 L F
.42 .324 .641 r
.38016 .58595 m .38164 .59082 L .38149 .58865 L F
.305 .167 .523 r
.23326 .56207 m .2314 .56082 L .23341 .56166 L F
.59 .286 .421 r
.37101 .70526 m .37066 .70767 L .36701 .70821 L F
.6 .331 .481 r
.37363 .70502 m .37066 .70767 L .37101 .70526 L F
0 .226 .729 r
.25044 .6322 m .25294 .63407 L .25158 .63233 L F
.25044 .6322 m .25158 .63233 L .25119 .63231 L F
0 .19 .682 r
.25058 .63284 m .25044 .6322 L .24989 .63211 L F
0 .226 .729 r
.25044 .6322 m .25119 .63231 L .24935 .63221 L F
0 .19 .682 r
.24989 .63211 m .25044 .6322 L .24914 .63133 L F
0 .102 .652 r
.40226 .55372 m .40468 .55727 L .40318 .55544 L F
.293 .215 .594 r
.29147 .53844 m .29345 .54022 L .29557 .53811 L F
.597 .802 .978 r
.29557 .53811 m .29615 .53638 L .29449 .53523 L F
.29557 .53811 m .29778 .53792 L .29615 .53638 L F
.124 0 0 r
.29557 .53811 m .29602 .53935 L .29778 .53792 L F
.29557 .53811 m .29345 .54022 L .29602 .53935 L F
.125 .139 .603 r
.36881 .65719 m .36927 .66143 L .36791 .66135 L F
.084 .37 .836 r
.36927 .66143 m .37001 .66268 L .36791 .66135 L F
.587 .777 .97 r
.37001 .66268 m .36772 .66331 L .36791 .66135 L F
.916 .694 .197 r
.72218 .29459 m .7223 .29272 L .72279 .29499 L F
.307 .621 .958 r
.72505 .29406 m .72279 .29499 L .7223 .29272 L F
.72505 .29406 m .72617 .29563 L .72279 .29499 L F
.469 .007 .072 r
.31322 .5194 m .313 .51976 L .31717 .5179 L F
.693 .981 .877 r
.31717 .5179 m .31786 .51633 L .31959 .51697 L F
.31717 .5179 m .313 .51976 L .31786 .51633 L F
.478 .212 .431 r
.28238 .63557 m .28528 .63278 L .28268 .63331 L F
.665 .529 .689 r
.29358 .58942 m .29401 .59217 L .29615 .58908 L F
.668 .551 .712 r
.29548 .58606 m .29358 .58942 L .29615 .58908 L F
.665 .529 .689 r
.29358 .58942 m .29401 .59217 L .29615 .58908 L F
.364 .744 .988 r
.36051 .51051 m .36261 .5103 L .36449 .51133 L F
.146 .637 .916 r
.36261 .5103 m .36729 .51149 L .36449 .51133 L F
.222 .735 .699 r
.2548 .63456 m .25722 .63389 L .2588 .6334 L F
.372 0 0 r
.29156 .64973 m .29319 .64948 L .29525 .65038 L F
.167 .156 .6 r
.3592 .58186 m .35814 .58544 L .35717 .58234 L F
.3592 .58186 m .35933 .58483 L .35814 .58544 L F
0 0 .187 r
.35904 .5859 m .35814 .58544 L .35933 .58483 L F
.267 0 .155 r
.36096 .58636 m .35872 .58707 L .3596 .58545 L F
.291 0 .203 r
.36096 .58636 m .35872 .58707 L .35904 .5859 L F
0 0 .187 r
.35859 .58671 m .35814 .58544 L .35904 .5859 L F
.35861 .58676 m .35821 .58845 L .35814 .58544 L F
.35872 .58707 m .35861 .58736 L .35861 .58676 L F
.35861 .58736 m .35821 .58845 L .35861 .58676 L F
.738 .402 .412 r
.35422 .58569 m .35861 .58549 L .35466 .58431 L F
.35861 .58549 m .35942 .58546 L .35861 .58526 L F
.35861 .58549 m .35861 .58526 L .35466 .58431 L F
.35942 .58546 m .3596 .58545 L .35945 .58541 L F
.35942 .58546 m .35945 .58541 L .35466 .58431 L F
.35942 .58546 m .35872 .58707 L .3596 .58545 L F
.291 0 .203 r
.35944 .58542 m .35904 .5859 L .35959 .58507 L F
.35945 .58541 m .35904 .5859 L .35967 .58514 L F
0 0 .187 r
.35872 .58707 m .35859 .58671 L .35904 .5859 L F
.738 .402 .412 r
.35422 .58569 m .35872 .58707 L .35942 .58546 L F
.291 0 .203 r
.35959 .58507 m .35904 .5859 L .35933 .58483 L F
.35967 .58514 m .35944 .58542 L .35959 .58507 L F
.35968 .58516 m .35958 .58527 L .35967 .58514 L F
.35958 .58527 m .35956 .58527 L .35967 .58514 L F
.352 .259 .609 r
.36132 .58115 m .35933 .58483 L .3592 .58186 L F
.36132 .58115 m .36166 .58433 L .35933 .58483 L F
.446 .326 .622 r
.35975 .58523 m .36022 .58511 L .36166 .58433 L F
.267 0 .155 r
.36096 .58636 m .3596 .58545 L .36166 .58433 L F
.291 0 .203 r
.36096 .58636 m .35975 .58523 L .36166 .58433 L F
.35975 .58523 m .35933 .58483 L .36166 .58433 L F
.446 .326 .622 r
.35958 .58527 m .35975 .58523 L .36166 .58433 L F
.3592 .58186 m .35958 .58527 L .36166 .58433 L F
.35958 .58527 m .3596 .58545 L .36022 .58511 L F
.291 0 .203 r
.35958 .58527 m .35945 .58541 L .35956 .58527 L F
.782 .57 .613 r
.35945 .58541 m .3596 .58545 L .35958 .58527 L F
.291 0 .203 r
.36096 .58636 m .35904 .5859 L .35968 .58516 L F
.782 .57 .613 r
.35932 .58538 m .35945 .58541 L .35955 .58498 L F
.35945 .58541 m .35958 .58527 L .35955 .58498 L F
.35466 .58431 m .35932 .58538 L .3592 .58186 L F
.35932 .58538 m .35955 .58498 L .3592 .58186 L F
.923 .77 .673 r
.3929 .58538 m .39419 .58892 L .38974 .58579 L F
0 0 .511 r
.39421 .58694 m .39419 .58892 L .3929 .58538 L F
.716 .678 .812 r
.39421 .58694 m .39277 .59037 L .39419 .58892 L F
.272 .116 .478 r
.39419 .58892 m .39455 .59171 L .39629 .59067 L F
.514 .882 .977 r
.29583 .5225 m .29546 .52403 L .29332 .52293 L F
.29583 .5225 m .29775 .52321 L .29546 .52403 L F
0 0 .047 r
.28857 .62958 m .28933 .63101 L .28988 .62832 L F
.28857 .62958 m .28793 .63179 L .28933 .63101 L F
.362 .036 .271 r
.28652 .61748 m .28541 .61963 L .28328 .62018 L F
0 0 0 r
.28697 .61708 m .28933 .61494 L .28764 .6165 L F
.28764 .6165 m .28933 .61494 L .29108 .61361 L F
.28764 .6165 m .29108 .61361 L .28891 .61521 L F
.115 0 .238 r
.28892 .61539 m .28764 .6165 L .28891 .61521 L F
.28901 .61789 m .28764 .6165 L .28892 .61539 L F
0 0 0 r
.28652 .61748 m .28697 .61708 L .28764 .6165 L F
.062 0 .098 r
.28737 .61904 m .28652 .61748 L .28764 .6165 L F
.28737 .61904 m .28541 .61963 L .28652 .61748 L F
.163 0 0 r
.32467 .64677 m .32656 .64762 L .32341 .64485 L F
.216 0 .169 r
.21774 .54428 m .21869 .5462 L .21944 .54407 L F
.21774 .54428 m .21666 .547 L .21869 .5462 L F
.237 0 .035 r
.23189 .53473 m .23264 .53656 L .23439 .53405 L F
.23189 .53473 m .23041 .53719 L .23264 .53656 L F
.604 .807 .978 r
.30401 .52223 m .30167 .52308 L .29996 .52171 L F
0 .174 .708 r
.30374 .65423 m .30562 .657 L .30684 .65796 L F
0 0 0 r
.28433 .6104 m .28531 .60932 L .2867 .60723 L F
.28433 .6104 m .28251 .61246 L .28531 .60932 L F
.341 .312 .681 r
.32286 .62553 m .32114 .62439 L .32279 .62245 L F
.312 .413 .804 r
.34381 .64307 m .34508 .64545 L .34653 .64489 L F
.276 .182 .564 r
.34508 .64545 m .34688 .64746 L .34653 .64489 L F
.34508 .64545 m .34533 .64838 L .34688 .64746 L F
0 .204 .73 r
.35527 .58913 m .35629 .58846 L .35364 .5882 L F
.516 .368 .619 r
.35821 .58845 m .358 .59199 L .35527 .58913 L F
0 .204 .73 r
.35527 .58913 m .358 .59199 L .35629 .58846 L F
.125 0 .086 r
.37289 .57717 m .37185 .57899 L .37384 .57791 L F
.869 .861 .83 r
.29615 .53638 m .29925 .53639 L .29967 .53494 L F
.29615 .53638 m .29778 .53792 L .29925 .53639 L F
.14 0 0 r
.3335 .55087 m .33245 .5517 L .33035 .55161 L F
.446 .88 .881 r
.33739 .54963 m .33501 .54986 L .3335 .55087 L F
0 0 0 r
.33501 .54986 m .33245 .5517 L .3335 .55087 L F
.843 .623 .604 r
.26577 .75076 m .26702 .75099 L .26488 .75242 L F
.26577 .75076 m .26488 .75242 L .26475 .75238 L F
.905 .787 .72 r
.26461 .75259 m .26702 .75099 L .26584 .75302 L F
.363 .113 .395 r
.26584 .75302 m .26702 .75099 L .26848 .75182 L F
.976 .908 .674 r
.26425 .75132 m .26577 .75076 L .26461 .75259 L F
.622 .812 .973 r
.26425 .75132 m .2654 .75256 L .26848 .75182 L F
.2654 .75256 m .26584 .75302 L .26633 .7528 L F
.2654 .75256 m .26633 .7528 L .26848 .75182 L F
.843 .623 .604 r
.26475 .75238 m .26488 .75242 L .26461 .75259 L F
.46 0 0 r
.26848 .75182 m .26702 .75099 L .26577 .75076 L F
.332 .097 .399 r
.26115 .5977 m .25863 .60089 L .25883 .59861 L F
.26115 .5977 m .25863 .60089 L .25883 .59861 L F
.413 .08 .289 r
.31883 .54229 m .32134 .54216 L .32273 .54204 L F
.36 0 0 r
.32601 .54144 m .32062 .5392 L .32273 .54204 L F
0 0 .015 r
.32282 .5426 m .32273 .54204 L .32134 .54216 L F
.32282 .5426 m .32264 .54488 L .32273 .54204 L F
.625 .441 .613 r
.36158 .54509 m .36232 .54765 L .35965 .54752 L F
.6 .498 .71 r
.3642 .54509 m .36232 .54765 L .36158 .54509 L F
.297 0 .204 r
.39048 .57012 m .39361 .56713 L .39207 .56845 L F
.682 .497 .629 r
.38844 .57308 m .39518 .57419 L .39388 .56788 L F
.463 .353 .643 r
.39388 .56788 m .39649 .5723 L .39618 .57086 L F
.39649 .5723 m .39651 .57233 L .39649 .57223 L F
.39649 .5723 m .39649 .57223 L .39618 .57086 L F
.598 .34 .498 r
.39618 .57086 m .39884 .56934 L .39862 .56637 L F
.827 .775 .803 r
.39884 .56934 m .39633 .57035 L .39695 .56792 L F
.463 .353 .643 r
.39388 .56788 m .39518 .57419 L .39651 .57233 L F
.827 .775 .803 r
.39633 .57035 m .39443 .57112 L .3962 .56887 L F
.39633 .57035 m .3962 .56887 L .39695 .56792 L F
.446 0 .005 r
.39361 .56713 m .39505 .56899 L .39207 .56845 L F
.39361 .56713 m .3962 .56694 L .39505 .56899 L F
.454 .23 .484 r
.29121 .59528 m .29355 .59482 L .29401 .59217 L F
.468 .272 .531 r
.29121 .59528 m .29118 .5979 L .29355 .59482 L F
.525 .172 .311 r
.26808 .55048 m .26716 .55349 L .26433 .55348 L F
.21 0 .128 r
.27065 .5498 m .26716 .55349 L .26808 .55048 L F
.653 .775 .938 r
.72031 .34312 m .71756 .34412 L .71651 .34237 L F
.595 .582 .808 r
.72143 .34709 m .71756 .34412 L .72031 .34312 L F
.728 .446 .5 r
.3761 .58237 m .37324 .58378 L .37362 .58308 L F
.363 .157 .461 r
.28817 .53568 m .2879 .53861 L .28621 .53883 L F
.757 .494 .535 r
.29147 .53844 m .28817 .53568 L .2901 .53503 L F
.29147 .53844 m .2879 .53861 L .28817 .53568 L F
.253 .137 .521 r
.18732 .58261 m .18885 .5819 L .18879 .57922 L F
.466 0 0 r
.28248 .64536 m .28508 .64602 L .28365 .64679 L F
.082 .625 .845 r
.24616 .63062 m .24471 .63021 L .24224 .63007 L F
.1 .607 .894 r
.24914 .63133 m .24471 .63021 L .24616 .63062 L F
.474 .153 .342 r
.27182 .53551 m .27062 .53827 L .26822 .53843 L F
.378 .821 .949 r
.27403 .53558 m .27232 .53636 L .27536 .53382 L F
.27403 .53558 m .27369 .53561 L .27232 .53636 L F
0 0 .011 r
.27232 .53636 m .27117 .537 L .27182 .53551 L F
.378 .821 .949 r
.27369 .53561 m .27108 .53587 L .27232 .53636 L F
0 0 .011 r
.27232 .53636 m .27062 .53827 L .27117 .537 L F
.471 .306 .575 r
.384 .6948 m .38198 .69843 L .38195 .69605 L F
.407 0 0 r
.28721 .64747 m .28959 .6475 L .28954 .6478 L F
.664 .905 .574 r
.3788 .57397 m .37705 .57573 L .37855 .57362 L F
.75 .23 0 r
.34402 .52554 m .34804 .52849 L .34549 .52916 L F
.34402 .52554 m .34549 .52916 L .34637 .52776 L F
.487 .846 .992 r
.34549 .52916 m .34804 .52849 L .34637 .52776 L F
.76 .574 .645 r
.34682 .53089 m .34637 .52776 L .34549 .52916 L F
.37 .04 .269 r
.31584 .54474 m .31883 .54229 L .31671 .54402 L F
.31584 .54474 m .31807 .54421 L .31883 .54229 L F
.413 .08 .289 r
.31883 .54229 m .31807 .54421 L .32134 .54216 L F
.34 .082 .369 r
.2879 .53861 m .28534 .54134 L .28621 .53883 L F
.288 .41 .812 r
.38647 .63496 m .38565 .6374 L .38403 .63555 L F
.642 .625 .818 r
.38824 .63706 m .38791 .63852 L .38647 .63496 L F
0 0 .199 r
.38824 .63706 m .38722 .64082 L .38791 .63852 L F
.38804 .6378 m .38859 .63964 L .38722 .64082 L F
.38824 .63706 m .3883 .63748 L .38804 .6378 L F
.3883 .63748 m .38859 .63964 L .38804 .6378 L F
.288 .41 .812 r
.38647 .63496 m .38775 .63814 L .38565 .6374 L F
.38775 .63814 m .38791 .63852 L .38758 .63836 L F
.38775 .63814 m .38758 .63836 L .38565 .6374 L F
.557 .562 .814 r
.36103 .53527 m .36276 .5351 L .36269 .53494 L F
.35958 .53556 m .36269 .53494 L .3607 .53058 L F
.46 .765 .996 r
.36041 .53506 m .36103 .53527 L .36276 .5351 L F
.36103 .53527 m .3639 .53623 L .36276 .5351 L F
.704 .697 .841 r
.35958 .53556 m .3639 .53623 L .36103 .53527 L F
.557 .562 .814 r
.35958 .53556 m .36276 .5351 L .36103 .53527 L F
.704 .697 .841 r
.35958 .53556 m .36103 .53527 L .36041 .53506 L F
.477 .468 .768 r
.3083 .53874 m .30933 .53421 L .30709 .53485 L F
.3083 .53874 m .31084 .53793 L .30933 .53421 L F
.413 .203 .483 r
.30789 .54118 m .31084 .53793 L .3083 .53874 L F
.361 .809 .949 r
.33008 .65807 m .33438 .65814 L .33259 .65989 L F
.91 .866 .428 r
.3349 .6538 m .33438 .65814 L .33272 .6547 L F
.432 .292 .59 r
.33438 .65814 m .33465 .66147 L .33664 .66036 L F
.614 .071 0 r
.33438 .65814 m .33521 .65951 L .33259 .65989 L F
.417 .808 .574 r
.33276 .66283 m .33465 .66147 L .33153 .66374 L F
0 0 0 r
.33664 .66036 m .33465 .66147 L .33276 .66283 L F
.33664 .66036 m .33276 .66283 L .33521 .65951 L F
0 0 .086 r
.33521 .65951 m .33276 .66283 L .33435 .66157 L F
.679 .772 .29 r
.33507 .65976 m .33521 .65951 L .33435 .66157 L F
0 0 .523 r
.33444 .65685 m .33521 .65951 L .3358 .65793 L F
.679 .772 .29 r
.3358 .65793 m .33521 .65951 L .33507 .65976 L F
.614 .071 0 r
.33438 .65814 m .33541 .65916 L .33521 .65951 L F
.33541 .65916 m .33664 .66036 L .33521 .65951 L F
.28 .163 .535 r
.40512 .58344 m .40294 .58272 L .40612 .58255 L F
.119 0 0 r
.40622 .58359 m .40603 .58357 L .40512 .58344 L F
.28 .163 .535 r
.40512 .58344 m .40319 .5853 L .40298 .58312 L F
.65 .762 .931 r
.40181 .58349 m .40512 .58344 L .40371 .5833 L F
.119 0 0 r
.40603 .58357 m .40371 .5833 L .40512 .58344 L F
.28 .163 .535 r
.40512 .58344 m .40298 .58312 L .40294 .58272 L F
0 0 0 r
.29387 .61064 m .29708 .60745 L .29574 .60962 L F
.218 0 0 r
.29708 .60745 m .29789 .60877 L .29574 .60962 L F
.29708 .60745 m .29895 .60761 L .29789 .60877 L F
0 0 .511 r
.39421 .58694 m .3929 .58538 L .39751 .58594 L F
.498 .337 .593 r
.39658 .58397 m .39421 .58694 L .39751 .58594 L F
.204 0 .265 r
.36713 .56736 m .36626 .56972 L .36895 .56646 L F
.551 .57 .826 r
.72266 .34273 m .72143 .34709 L .72031 .34312 L F
.72266 .34273 m .72431 .34635 L .72143 .34709 L F
.469 .275 .534 r
.72431 .34635 m .72156 .34942 L .72143 .34709 L F
.906 .63 .508 r
.34264 .69584 m .34044 .69786 L .34036 .69568 L F
.34264 .69584 m .34263 .6985 L .34044 .69786 L F
.605 .065 0 r
.72288 .33808 m .72038 .33954 L .71883 .33724 L F
.775 .421 .385 r
.72529 .33687 m .72038 .33954 L .72288 .33808 L F
.534 .518 .784 r
.37508 .55809 m .37678 .56063 L .37763 .56029 L F
.37411 .55725 m .37487 .55822 L .37508 .55809 L F
.37487 .55822 m .37678 .56063 L .37508 .55809 L F
.37411 .55725 m .37499 .55802 L .37646 .55725 L F
.37499 .55802 m .37763 .56029 L .37646 .55725 L F
.83 .421 .27 r
.37499 .55293 m .37893 .55609 L .37646 .55725 L F
.414 0 0 r
.37893 .55609 m .37768 .5566 L .37646 .55725 L F
.437 .448 .773 r
.37499 .55293 m .37646 .55725 L .37411 .55725 L F
.414 0 0 r
.37768 .5566 m .37469 .55783 L .37646 .55725 L F
.449 .873 .758 r
.37646 .55725 m .37487 .55822 L .37411 .55725 L F
.37487 .55822 m .37435 .55853 L .37411 .55725 L F
.37487 .55822 m .37436 .5585 L .37435 .55853 L F
.534 .518 .784 r
.37478 .5581 m .37537 .5612 L .37678 .56063 L F
.37411 .55725 m .37447 .5584 L .37478 .5581 L F
.37447 .5584 m .37537 .5612 L .37478 .5581 L F
.887 .823 .778 r
.37435 .55853 m .37014 .56092 L .37373 .55828 L F
.559 .88 .604 r
.37469 .55783 m .37297 .55951 L .37429 .55857 L F
.37436 .5585 m .37429 .55857 L .37435 .55853 L F
.37469 .55783 m .37429 .55857 L .37436 .5585 L F
.449 .873 .758 r
.37646 .55725 m .37469 .55783 L .37436 .5585 L F
.37646 .55725 m .37436 .5585 L .37487 .55822 L F
.485 .384 .665 r
.37537 .5612 m .37806 .56295 L .37763 .56029 L F
.37763 .56029 m .37806 .56295 L .37537 .5612 L F
.809 .561 .563 r
.36183 .62055 m .36609 .62356 L .36256 .62291 L F
.785 .54 .565 r
.36609 .62356 m .36597 .62622 L .36195 .62581 L F
.523 .055 .085 r
.3563 .60875 m .35815 .60949 L .35618 .61005 L F
.744 .945 .625 r
.38689 .53869 m .38512 .54021 L .3848 .53854 L F
.033 0 .176 r
.37309 .61351 m .3708 .61724 L .37288 .61603 L F
0 0 .121 r
.37309 .61351 m .37288 .61603 L .37394 .61497 L F
.225 0 0 r
.29815 .62959 m .30132 .62921 L .29745 .6293 L F
.439 .307 .604 r
.29745 .6293 m .29726 .62674 L .29815 .62959 L F
.478 .896 .89 r
.33744 .5488 m .33739 .54963 L .33945 .54806 L F
.33744 .5488 m .33501 .54986 L .33739 .54963 L F
.845 .982 .693 r
.29615 .58908 m .29401 .59217 L .29415 .59041 L F
0 0 .57 r
.29401 .59217 m .29542 .59382 L .29415 .59041 L F
.28 .081 .421 r
.29401 .59217 m .29355 .59482 L .29542 .59382 L F
0 0 0 r
.29157 .62554 m .29549 .62421 L .29407 .62328 L F
.361 .091 .362 r
.31897 .55731 m .32042 .55764 L .32177 .55511 L F
.303 .275 .661 r
.31897 .55731 m .32126 .5596 L .32042 .55764 L F
.279 .271 .671 r
.31897 .55731 m .31992 .56068 L .32126 .5596 L F
.66 .456 .597 r
.35209 .62042 m .35157 .62337 L .34925 .62328 L F
.579 .425 .636 r
.35476 .61703 m .35523 .61959 L .35209 .62042 L F
.712 .593 .721 r
.35523 .61959 m .35157 .62337 L .35209 .62042 L F
.308 0 0 r
.29602 .53935 m .30015 .53932 L .29778 .53792 L F
.476 .15 .333 r
.36906 .58194 m .36994 .58024 L .36796 .58109 L F
.36796 .58109 m .36994 .58024 L .36906 .58194 L F
.868 .576 .493 r
.35414 .70528 m .35221 .70788 L .3507 .70438 L F
.35414 .70528 m .35416 .70782 L .35221 .70788 L F
.73 .363 .356 r
.35414 .70528 m .35685 .70828 L .35416 .70782 L F
.536 .288 .487 r
.71742 .3284 m .72013 .32995 L .72044 .32773 L F
.592 .053 0 r
.71633 .32932 m .72013 .32995 L .71742 .3284 L F
.536 .288 .487 r
.71742 .3284 m .72013 .32995 L .72044 .32773 L F
.748 .488 .538 r
.30586 .59214 m .30539 .5935 L .30392 .59105 L F
.553 .138 .208 r
.29853 .71412 m .29935 .71338 L .299 .71545 L F
.254 .29 .706 r
.19327 .59667 m .19425 .59754 L .19484 .59484 L F
.357 .727 .987 r
.19554 .5984 m .19642 .59987 L .19773 .59948 L F
.19399 .59763 m .19519 .59874 L .19554 .5984 L F
.19519 .59874 m .19642 .59987 L .19554 .5984 L F
.19391 .59759 m .19773 .59948 L .1955 .59861 L F
0 0 0 r
.19807 .59543 m .1955 .59861 L .19778 .59771 L F
.1961 .59787 m .19558 .59871 L .1955 .59861 L F
.19807 .59543 m .19654 .59745 L .1961 .59787 L F
.19654 .59745 m .19558 .59871 L .1961 .59787 L F
.482 0 0 r
.1955 .59861 m .19327 .59667 L .19391 .59759 L F
.1955 .59861 m .19558 .59871 L .19327 .59667 L F
.254 .29 .706 r
.19425 .59754 m .19558 .59871 L .19528 .59716 L F
.19425 .59754 m .19528 .59716 L .19484 .59484 L F
.357 .727 .987 r
.19391 .59759 m .19397 .59764 L .19399 .59763 L F
.19397 .59764 m .19642 .59987 L .19399 .59763 L F
.593 .607 .835 r
.32282 .5426 m .32329 .54062 L .32408 .5408 L F
.36 0 0 r
.32492 .54099 m .32408 .5408 L .32062 .5392 L F
.379 .441 .799 r
.32062 .5392 m .32408 .5408 L .32231 .53675 L F
0 0 .464 r
.32231 .53675 m .32408 .5408 L .32368 .53895 L F
.593 .607 .835 r
.32329 .54062 m .32368 .53895 L .32408 .5408 L F
.36 0 0 r
.32601 .54144 m .32408 .5408 L .32492 .54099 L F
0 .395 .695 r
.32601 .54144 m .3271 .54176 L .32408 .5408 L F
.248 .76 .768 r
.33245 .5517 m .32983 .55236 L .33035 .55161 L F
.125 0 0 r
.7213 .29874 m .71996 .2987 L .72218 .29459 L F
.7213 .29874 m .72342 .29898 L .71996 .2987 L F
.717 .968 .936 r
.33762 .66881 m .33896 .6694 L .34212 .66722 L F
.542 .633 .891 r
.33897 .53158 m .33562 .52938 L .33958 .53152 L F
.581 .485 .71 r
.3419 .52923 m .33897 .53158 L .33958 .53152 L F
.187 0 0 r
.33632 .67517 m .34001 .67377 L .34045 .67286 L F
0 0 0 r
.34045 .67286 m .34001 .67377 L .3417 .67231 L F
.803 .829 .871 r
.33102 .58058 m .32664 .58213 L .32683 .57945 L F
.33102 .58058 m .32683 .57945 L .32884 .58075 L F
.728 .974 .927 r
.33344 .57916 m .33102 .58058 L .32884 .58075 L F
.455 .866 .713 r
.37387 .65356 m .37272 .65448 L .37492 .65384 L F
.37387 .65356 m .37202 .65473 L .37272 .65448 L F
.096 .486 .898 r
.21319 .61052 m .21326 .60936 L .21219 .60923 L F
.21319 .61052 m .21484 .61102 L .21326 .60936 L F
.525 .487 .756 r
.22196 .59664 m .22268 .60071 L .22046 .60105 L F
.95 .913 .744 r
.31035 .54334 m .31303 .54244 L .31333 .54106 L F
.31035 .54334 m .31138 .54554 L .31303 .54244 L F
.258 0 .053 r
.36501 .54724 m .3671 .54681 L .36853 .54463 L F
.511 .338 .583 r
.36853 .54463 m .37097 .54443 L .37039 .54184 L F
.636 .239 .274 r
.36853 .54463 m .37066 .5466 L .37097 .54443 L F
.36853 .54463 m .3671 .54681 L .37066 .5466 L F
.49 .45 .74 r
.3685 .5426 m .36979 .54625 L .3671 .54681 L F
.36979 .54625 m .3698 .54628 L .3671 .54681 L F
.258 0 .053 r
.36483 .54737 m .3671 .54681 L .36501 .54724 L F
.18 .337 .786 r
.22258 .59106 m .22226 .59205 L .22099 .58956 L F
0 0 .031 r
.22258 .59106 m .22193 .5946 L .22226 .59205 L F
.238 .253 .674 r
.36233 .56901 m .36158 .5732 L .35972 .57171 L F
.36233 .56901 m .36319 .57265 L .36158 .5732 L F
.262 .329 .744 r
.36319 .57265 m .36413 .57544 L .36158 .5732 L F
.468 .348 .633 r
.36413 .57544 m .36178 .57628 L .36158 .5732 L F
.508 .287 .513 r
.3871 .69218 m .384 .6948 L .38457 .69272 L F
.603 .348 .503 r
.36238 .55001 m .35965 .54752 L .36232 .54765 L F
.36238 .55001 m .35877 .5505 L .35965 .54752 L F
.21 .171 .593 r
.18834 .5767 m .19047 .57798 L .19054 .57534 L F
.18834 .5767 m .18879 .57922 L .19047 .57798 L F
0 0 0 r
.2867 .60723 m .28531 .60932 L .28764 .60611 L F
.402 .396 .738 r
.29466 .58252 m .29548 .58606 L .29762 .58471 L F
.044 .121 .62 r
.29548 .58606 m .29739 .58739 L .29762 .58471 L F
.29548 .58606 m .29615 .58908 L .29739 .58739 L F
.412 .713 .985 r
.35055 .5486 m .35169 .54798 L .35023 .54646 L F
0 0 .131 r
.35055 .5486 m .34969 .55061 L .35169 .54798 L F
.685 .308 .328 r
.25993 .76498 m .26307 .76541 L .26068 .76664 L F
0 0 0 r
.26068 .76664 m .26307 .76541 L .26483 .76457 L F
.007 .018 .518 r
.32307 .59211 m .32444 .59415 L .32464 .59047 L F
.32307 .59211 m .32354 .59496 L .32444 .59415 L F
0 0 .005 r
.29108 .61361 m .29221 .61193 L .29387 .61064 L F
.385 .773 .989 r
.27828 .52417 m .28063 .52393 L .2824 .52483 L F
.389 .764 .992 r
.28063 .52393 m .28473 .52469 L .2824 .52483 L F
.292 .453 .849 r
.20668 .6046 m .20854 .60804 L .2095 .60606 L F
.353 .528 .889 r
.20854 .60804 m .21219 .60923 L .2095 .60606 L F
0 0 0 r
.32341 .55369 m .32629 .5516 L .325 .55153 L F
.562 .59 .839 r
.25468 .61631 m .25402 .62045 L .25261 .6176 L F
.25468 .61631 m .25633 .61988 L .25402 .62045 L F
.792 .812 .868 r
.31721 .52329 m .31443 .52572 L .31842 .52566 L F
.822 .57 .557 r
.31421 .5275 m .31842 .52566 L .31443 .52572 L F
.31421 .5275 m .31835 .52857 L .31842 .52566 L F
.856 .833 .823 r
.31721 .52329 m .31842 .52566 L .32039 .52284 L F
.142 0 0 r
.3962 .56694 m .39862 .56637 L .39695 .56792 L F
.753 .236 0 r
.29116 .64294 m .29076 .63901 L .29042 .64102 L F
.027 .452 .874 r
.29267 .6427 m .29116 .64294 L .29042 .64102 L F
.29267 .6427 m .29414 .6442 L .29116 .64294 L F
.182 0 0 r
.29615 .58908 m .29686 .5899 L .29739 .58739 L F
.29615 .58908 m .29415 .59041 L .29686 .5899 L F
.116 .639 .881 r
.29924 .65097 m .3035 .65176 L .30166 .65081 L F
.262 .701 .962 r
.30166 .65081 m .3035 .65176 L .30462 .65115 L F
0 0 .112 r
.3035 .65176 m .30377 .65281 L .30462 .65115 L F
.3035 .65176 m .30374 .65423 L .30377 .65281 L F
.89 .649 .568 r
.34067 .69258 m .33721 .69443 L .33729 .69175 L F
.34067 .69258 m .34036 .69568 L .33721 .69443 L F
.122 0 .199 r
.32679 .54828 m .32629 .5516 L .32857 .54721 L F
0 0 0 r
.3216 .57059 m .32047 .57225 L .32157 .57007 L F
.86 .792 .783 r
.33751 .51993 m .34118 .52037 L .33919 .5191 L F
.33751 .51993 m .33965 .52235 L .34118 .52037 L F
.621 .519 .717 r
.35686 .55435 m .35467 .55716 L .35393 .5544 L F
.788 .677 .742 r
.34903 .5192 m .35081 .52293 L .34649 .52239 L F
.399 .415 .761 r
.34953 .52509 m .34649 .52239 L .35081 .52293 L F
0 0 .364 r
.35194 .51877 m .35081 .52293 L .34903 .5192 L F
.35194 .51877 m .35195 .52188 L .35081 .52293 L F
0 0 0 r
.35102 .52348 m .35081 .52293 L .35195 .52188 L F
.35102 .52348 m .34953 .52509 L .35081 .52293 L F
.397 .438 .786 r
.3412 .51042 m .34401 .5117 L .34301 .50996 L F
.312 .413 .804 r
.34381 .64307 m .34653 .64489 L .34613 .64124 L F
.728 .974 .927 r
.33344 .57916 m .32884 .58075 L .33138 .58014 L F
.013 0 0 r
.33138 .58014 m .33561 .5788 L .33344 .57916 L F
.248 .511 .906 r
.38447 .6135 m .38773 .61506 L .38409 .6152 L F
.262 .128 .503 r
.38776 .61762 m .38409 .6152 L .38773 .61506 L F
.38776 .61762 m .38546 .61981 L .38409 .6152 L F
.248 .511 .906 r
.38447 .6135 m .38773 .61506 L .38409 .6152 L F
.678 .19 .083 r
.31057 .64856 m .30839 .64613 L .30733 .64724 L F
.558 .205 .325 r
.31057 .64856 m .31207 .64556 L .30839 .64613 L F
.012 0 0 r
.3412 .58475 m .34 .58767 L .3382 .58774 L F
0 0 0 r
.34085 .58601 m .3412 .58475 L .34348 .58385 L F
.34085 .58601 m .34 .58767 L .3412 .58475 L F
.619 .626 .836 r
.35933 .62656 m .3571 .6288 L .35659 .62712 L F
.548 .511 .767 r
.35933 .62656 m .35952 .62888 L .3571 .6288 L F
.467 .473 .781 r
.36084 .63285 m .3571 .6288 L .35952 .62888 L F
.66 .484 .635 r
.34804 .52849 m .35104 .53145 L .3519 .5292 L F
.594 .249 .355 r
.3519 .5292 m .35413 .53116 L .35411 .52829 L F
.3519 .5292 m .35104 .53145 L .35413 .53116 L F
.3519 .5292 m .35413 .53116 L .35411 .52829 L F
.3519 .5292 m .35104 .53145 L .35413 .53116 L F
0 0 0 r
.38768 .667 m .3861 .67053 L .38472 .66702 L F
.38768 .667 m .38683 .66916 L .3861 .67053 L F
.242 .553 .931 r
.38683 .66916 m .38753 .67039 L .3861 .67053 L F
.654 .688 .87 r
.38753 .67039 m .38651 .67282 L .3861 .67053 L F
.41 .78 .994 r
.26339 .63457 m .26696 .63512 L .26538 .63475 L F
.029 .582 .825 r
.26339 .63457 m .26538 .63475 L .26344 .63422 L F
.514 0 0 r
.26378 .63439 m .26538 .63475 L .26762 .63626 L F
.26344 .63422 m .26538 .63475 L .26378 .63439 L F
.41 .78 .994 r
.26696 .63512 m .26705 .63513 L .26538 .63475 L F
.745 .913 .95 r
.38984 .65782 m .386 .65833 L .38793 .65666 L F
.38984 .65782 m .38717 .65888 L .386 .65833 L F
.519 .697 .95 r
.39064 .65559 m .38984 .65782 L .38793 .65666 L F
.39064 .65559 m .3922 .65738 L .38984 .65782 L F
.531 .4 .647 r
.3922 .65738 m .38995 .6612 L .38984 .65782 L F
.478 .885 .942 r
.23892 .53287 m .24138 .5331 L .23783 .53385 L F
.293 0 0 r
.30346 .6335 m .30574 .63354 L .30785 .63423 L F
0 0 0 r
.32916 .55642 m .32909 .55657 L .32997 .55624 L F
.9 .873 .802 r
.26078 .76123 m .25993 .76498 L .25958 .7639 L F
0 0 .343 r
.25958 .7639 m .25993 .76498 L .26068 .76664 L F
.066 .033 .505 r
.26068 .76664 m .25986 .76799 L .25993 .76498 L F
.691 .839 .41 r
.3272 .65501 m .3243 .65719 L .32647 .65711 L F
.61 .575 .79 r
.32647 .65711 m .32862 .65428 L .3272 .65501 L F
.107 .216 .695 r
.34375 .55137 m .34586 .55318 L .34618 .55141 L F
.17 0 0 r
.34877 .66511 m .35159 .66517 L .35179 .66488 L F
.574 .858 .531 r
.35179 .66488 m .35159 .66517 L .35327 .66321 L F
.776 .592 .65 r
.22097 .57335 m .21776 .57515 L .2168 .57381 L F
.599 .776 .965 r
.276 .53376 m .28139 .53556 L .27998 .5332 L F
.357 .031 .268 r
.27834 .53803 m .28038 .53756 L .28139 .53556 L F
.198 .428 .858 r
.28139 .53556 m .28275 .53358 L .27998 .5332 L F
0 0 .306 r
.28038 .53756 m .28275 .53358 L .28139 .53556 L F
.302 0 .249 r
.38149 .58865 m .38342 .58821 L .3843 .58644 L F
.382 .196 .5 r
.38164 .59082 m .38342 .58821 L .38149 .58865 L F
0 0 .444 r
.39031 .52869 m .39164 .53085 L .39183 .53235 L F
.454 0 0 r
.3927 .53309 m .39183 .53235 L .39164 .53085 L F
.3927 .53309 m .39421 .53429 L .39183 .53235 L F
.964 .821 .654 r
.33642 .55456 m .33731 .55716 L .33826 .55463 L F
.735 .364 0 r
.71416 .33417 m .71412 .33472 L .71411 .3326 L F
.71416 .33417 m .71551 .33731 L .71412 .33472 L F
.512 .339 .583 r
.37039 .54184 m .37337 .54375 L .37192 .5396 L F
.37039 .54184 m .37097 .54443 L .37337 .54375 L F
.153 0 .195 r
.33347 .64186 m .33589 .63898 L .33453 .64211 L F
.994 .748 .414 r
.33768 .63675 m .33679 .63771 L .33813 .63623 L F
0 0 .449 r
.33679 .63771 m .33589 .63898 L .33588 .63868 L F
0 0 0 r
.33453 .64211 m .33589 .63898 L .33679 .63771 L F
.33453 .64211 m .33679 .63771 L .3367 .64031 L F
.994 .748 .414 r
.33548 .63926 m .3367 .64031 L .33679 .63771 L F
.33548 .63926 m .33679 .63771 L .33768 .63675 L F
0 0 .449 r
.33679 .63771 m .33588 .63868 L .33575 .63509 L F
.764 .608 .685 r
.36248 .56627 m .35966 .56876 L .36006 .56677 L F
0 0 .146 r
.32683 .57945 m .32739 .58047 L .32884 .58075 L F
.32683 .57945 m .32664 .58213 L .32739 .58047 L F
.586 .573 .806 r
.22647 .60622 m .22554 .61059 L .22409 .6071 L F
.22647 .60622 m .22772 .61004 L .22554 .61059 L F
.665 .903 .569 r
.39005 .67365 m .38738 .67691 L .38651 .67282 L F
.39005 .67365 m .38821 .67546 L .38738 .67691 L F
.555 .367 .581 r
.38738 .67691 m .39 .67693 L .39005 .67365 L F
.407 .726 .989 r
.38821 .67546 m .39 .67693 L .38738 .67691 L F
.223 0 0 r
.27934 .54685 m .2755 .54892 L .27728 .54746 L F
.245 .704 .95 r
.36722 .54117 m .36591 .54039 L .36373 .54046 L F
.173 0 .108 r
.3685 .5426 m .36654 .54341 L .36722 .54117 L F
.3685 .5426 m .36722 .54117 L .36591 .54039 L F
.182 0 0 r
.26063 .54959 m .26283 .54936 L .26157 .54918 L F
.013 .587 .749 r
.25871 .54915 m .26283 .54936 L .26063 .54959 L F
.105 0 0 r
.26283 .54936 m .26105 .54922 L .26383 .54949 L F
.26283 .54936 m .26383 .54949 L .2652 .54963 L F
.182 0 0 r
.26157 .54918 m .26283 .54936 L .26444 .54796 L F
.452 0 .063 r
.26283 .54936 m .26699 .54765 L .26444 .54796 L F
0 0 .201 r
.40813 .57109 m .40742 .57005 L .4075 .56829 L F
.40813 .57109 m .40737 .57265 L .40742 .57005 L F
.437 .448 .773 r
.37499 .55293 m .37411 .55725 L .37355 .55514 L F
0 0 .314 r
.31992 .56068 m .32014 .56391 L .32055 .56225 L F
.926 .607 .418 r
.32257 .56328 m .32055 .56225 L .32014 .56391 L F
.599 .65 .872 r
.33284 .51968 m .33021 .52084 L .32741 .51608 L F
.767 .448 0 r
.35942 .59759 m .36011 .59854 L .35982 .59718 L F
.441 .451 .773 r
.35879 .60013 m .35841 .60375 L .35901 .6001 L F
.355 .052 .305 r
.35636 .60039 m .35879 .60013 L .35966 .59762 L F
.35619 .60053 m .35966 .59762 L .3596 .59738 L F
.3596 .59738 m .35966 .59762 L .35982 .59718 L F
.782 .798 .307 r
.35982 .59718 m .35879 .60013 L .35942 .59759 L F
.441 .451 .773 r
.35879 .60013 m .35901 .6001 L .35942 .59759 L F
.355 .052 .305 r
.35619 .60053 m .35879 .60013 L .35636 .60039 L F
.767 .448 0 r
.35977 .59807 m .36093 .60118 L .36011 .59854 L F
.35942 .59759 m .35996 .59887 L .35977 .59807 L F
.35996 .59887 m .36093 .60118 L .35977 .59807 L F
.654 .688 .87 r
.38753 .67039 m .39005 .67365 L .38651 .67282 L F
.793 .725 .788 r
.3925 .6706 m .39005 .67365 L .38753 .67039 L F
.514 .333 .574 r
.39005 .67365 m .39 .67693 L .39276 .67643 L F
.726 .296 .227 r
.39005 .67365 m .39276 .67643 L .38821 .67546 L F
.604 .375 .541 r
.22665 .5701 m .22615 .57285 L .22359 .57289 L F
.265 .074 .424 r
.22845 .5692 m .22615 .57285 L .22665 .5701 L F
.003 .202 .715 r
.40182 .54959 m .40179 .55134 L .40059 .54784 L F
0 0 .165 r
.40204 .55225 m .40179 .55134 L .40182 .54959 L F
.40204 .55225 m .40226 .55372 L .40179 .55134 L F
0 0 0 r
.36889 .66286 m .36772 .66331 L .36572 .66479 L F
.36772 .66331 m .36667 .66397 L .36889 .66286 L F
.518 .463 .734 r
.21109 .58126 m .20935 .58555 L .20942 .58269 L F
0 .309 .779 r
.36278 .51592 m .36256 .51493 L .35999 .51358 L F
.36278 .51592 m .36372 .51632 L .36256 .51493 L F
.485 .901 .86 r
.27988 .62142 m .28328 .62018 L .28306 .62122 L F
.301 0 0 r
.28541 .61963 m .28306 .62122 L .28328 .62018 L F
.724 .31 0 r
.36473 .51709 m .36511 .51816 L .36372 .51632 L F
.36473 .51709 m .36623 .51981 L .36511 .51816 L F
.828 .748 .775 r
.34423 .6668 m .34877 .66511 L .34686 .66692 L F
.775 .661 .737 r
.35179 .66488 m .34686 .66692 L .34877 .66511 L F
.293 .199 .574 r
.33117 .59135 m .33141 .59364 L .32949 .59203 L F
.33141 .59364 m .33002 .5953 L .32949 .59203 L F
.861 .864 .84 r
.39508 .59744 m .39674 .59828 L .39755 .59461 L F
.775 .486 .497 r
.36694 .52818 m .36306 .52532 L .36758 .52603 L F
.294 .011 .302 r
.36966 .52529 m .36694 .52818 L .36758 .52603 L F
0 0 .506 r
.26484 .62193 m .26437 .62443 L .26142 .62222 L F
.26484 .62193 m .26514 .62322 L .26437 .62443 L F
0 0 0 r
.21603 .58248 m .21741 .58265 L .21842 .58199 L F
.101 0 .177 r
.21749 .58254 m .21741 .58265 L .21603 .58248 L F
.21764 .58268 m .21482 .58509 L .21603 .58248 L F
0 0 0 r
.21603 .58248 m .21622 .58343 L .21741 .58265 L F
.101 0 .177 r
.21779 .58255 m .21749 .58254 L .21842 .58199 L F
.21749 .58254 m .21603 .58248 L .21842 .58199 L F
.881 .989 .731 r
.21856 .58108 m .21654 .58311 L .21868 .58037 L F
.21654 .58311 m .21622 .58343 L .21642 .58318 L F
.21654 .58311 m .21642 .58318 L .21868 .58037 L F
.21842 .58199 m .21741 .58265 L .21856 .58108 L F
.21741 .58265 m .21622 .58343 L .21856 .58108 L F
.101 0 .177 r
.21779 .58255 m .21764 .58268 L .21741 .58265 L F
.21779 .58255 m .21741 .58265 L .21749 .58254 L F
0 0 0 r
.21603 .58248 m .21482 .58509 L .21622 .58343 L F
.338 .808 .917 r
.64002 .39962 m .64373 .39939 L .64125 .39956 L F
.436 .266 .552 r
.3321 .60457 m .33424 .60734 L .33435 .60391 L F
.3321 .60457 m .33209 .60745 L .33424 .60734 L F
.137 0 0 r
.30208 .60059 m .30439 .59803 L .30389 .60058 L F
.166 .115 .551 r
.30606 .59713 m .30439 .59803 L .30539 .5935 L F
0 0 .158 r
.30389 .60058 m .30439 .59803 L .30606 .59713 L F
.503 .353 .609 r
.38383 .63322 m .3817 .6356 L .38013 .63221 L F
.494 .178 .36 r
.30751 .58754 m .30536 .5886 L .30493 .5864 L F
.495 .174 .351 r
.30804 .58518 m .30751 .58754 L .30493 .5864 L F
.783 .71 .783 r
.3243 .65719 m .32162 .66109 L .32179 .65854 L F
1 .804 .481 r
.3243 .65719 m .32436 .66093 L .32162 .66109 L F
.782 .805 .871 r
.32128 .66388 m .32162 .66109 L .32436 .66093 L F
.303 .001 .275 r
.32157 .54678 m .31971 .54751 L .32264 .54488 L F
0 0 0 r
.32036 .54724 m .31971 .54751 L .32157 .54678 L F
.576 .587 .827 r
.36906 .58194 m .37073 .58575 L .37324 .58378 L F
0 0 0 r
.24552 .55208 m .2429 .55372 L .24193 .55393 L F
.104 0 0 r
.24549 .55316 m .24552 .55208 L .24768 .55161 L F
.24549 .55316 m .2429 .55372 L .24552 .55208 L F
.444 .199 .448 r
.34239 .57636 m .3421 .57873 L .34494 .57586 L F
.548 .478 .728 r
.30536 .56036 m .30609 .56251 L .30305 .56142 L F
.622 .713 .911 r
.30536 .56036 m .30305 .56142 L .30129 .56096 L F
.25 0 0 r
.38228 .52272 m .38527 .52371 L .3859 .52384 L F
.142 .587 .928 r
.38527 .52371 m .38724 .52496 L .3859 .52384 L F
.775 .7 .78 r
.32645 .56629 m .33053 .56677 L .32887 .56315 L F
.665 .19 .114 r
.32645 .56629 m .32858 .56823 L .33053 .56677 L F
.127 0 0 r
.32858 .56823 m .33293 .5662 L .33053 .56677 L F
.814 .775 .816 r
.38052 .66655 m .38472 .66702 L .38307 .6634 L F
.186 .702 .888 r
.38286 .66636 m .38472 .66702 L .38052 .66655 L F
.105 .346 .815 r
.38307 .6634 m .38472 .66702 L .38515 .66449 L F
.787 .987 .894 r
.38515 .66449 m .38472 .66702 L .38286 .66636 L F
.491 .295 .541 r
.38776 .66387 m .38768 .667 L .38472 .66702 L F
.384 0 0 r
.30028 .62974 m .30132 .62921 L .29815 .62959 L F
.162 .072 .497 r
.30275 .62881 m .30132 .62921 L .30298 .62907 L F
0 0 0 r
.30298 .62907 m .30132 .62921 L .30028 .62974 L F
.716 .678 .812 r
.39421 .58694 m .39629 .59067 L .39277 .59037 L F
.637 .65 .846 r
.3898 .59242 m .39467 .59336 L .39455 .59171 L F
.254 .097 .465 r
.39455 .59171 m .3962 .5936 L .39629 .59067 L F
.39455 .59171 m .39467 .59336 L .3962 .5936 L F
.15 .377 .829 r
.3962 .5936 m .39277 .59037 L .39629 .59067 L F
.253 .535 .92 r
.39699 .58904 m .39629 .59067 L .39421 .58694 L F
.733 .726 .844 r
.39553 .59193 m .39699 .58904 L .39538 .59156 L F
.97 .741 .31 r
.39538 .59156 m .3962 .5936 L .39629 .59067 L F
.733 .726 .844 r
.3962 .5936 m .39657 .59147 L .39553 .59193 L F
.324 0 0 r
.39629 .59067 m .3979 .59088 L .4009 .5888 L F
.3979 .59088 m .39886 .59101 L .39972 .59008 L F
.3979 .59088 m .39972 .59008 L .4009 .5888 L F
.253 .535 .92 r
.39699 .58904 m .39886 .59101 L .39629 .59067 L F
.6 .366 .533 r
.39621 .59335 m .39865 .59257 L .39629 .59067 L F
.3962 .5936 m .39725 .59316 L .39621 .59335 L F
.39725 .59316 m .39865 .59257 L .39621 .59335 L F
.7 .551 .681 r
.40157 .59223 m .40171 .59488 L .39934 .5946 L F
.40157 .59223 m .40171 .59488 L .39934 .5946 L F
.34 0 0 r
.39934 .5946 m .40171 .59488 L .39755 .59461 L F
.594 .838 .991 r
.39755 .59461 m .40171 .59488 L .39778 .59306 L F
.39746 .59312 m .39778 .59306 L .39745 .5929 L F
.39755 .59461 m .39778 .59306 L .39746 .59312 L F
.733 .726 .844 r
.39657 .59147 m .39699 .58904 L .39553 .59193 L F
.964 .891 .511 r
.4009 .5888 m .39886 .59101 L .39993 .58734 L F
.431 .274 .566 r
.40319 .5853 m .40322 .58807 L .4009 .5888 L F
.627 .481 .664 r
.40415 .59142 m .4009 .5888 L .40322 .58807 L F
.40415 .59142 m .40157 .59223 L .4009 .5888 L F
.856 .833 .823 r
.31721 .52329 m .32039 .52284 L .31931 .52181 L F
.669 .898 .978 r
.32361 .5198 m .32039 .52284 L .32379 .5201 L F
.32361 .5198 m .31931 .52181 L .32039 .52284 L F
0 0 .271 r
.32282 .5426 m .32157 .54678 L .32264 .54488 L F
.616 .594 .805 r
.26023 .62289 m .25782 .62354 L .25633 .61988 L F
0 0 0 r
.20374 .55698 m .2052 .55611 L .20653 .55412 L F
.407 .175 .446 r
.20266 .55932 m .2052 .55611 L .20374 .55698 L F
.332 .001 .245 r
.2052 .55611 m .20841 .55289 L .20653 .55412 L F
0 .109 .658 r
.40226 .55372 m .40423 .55563 L .40468 .55727 L F
.918 .721 .228 r
.40423 .55563 m .40485 .55946 L .40468 .55727 L F
.802 .782 .834 r
.33607 .52199 m .33798 .52351 L .33965 .52235 L F
0 .416 .729 r
.29558 .64493 m .2958 .64512 L .29414 .6442 L F
.326 0 0 r
.3333 .67632 m .33478 .67547 L .33037 .67614 L F
.263 .743 .932 r
.33632 .67517 m .33478 .67547 L .33511 .67474 L F
.583 .914 .684 r
.33511 .67474 m .33478 .67547 L .3333 .67632 L F
.905 .763 .694 r
.21511 .58608 m .21452 .5853 L .21482 .58509 L F
.21511 .58608 m .21237 .58643 L .21452 .5853 L F
.21511 .58608 m .21335 .58842 L .21237 .58643 L F
.582 .738 .95 r
.25533 .53961 m .25951 .54178 L .2577 .5378 L F
.386 .07 .302 r
.26221 .54147 m .25907 .54409 L .25951 .54178 L F
.419 .452 .788 r
.35653 .61636 m .35476 .61703 L .35361 .61422 L F
.318 .247 .618 r
.35697 .61872 m .35476 .61703 L .35653 .61636 L F
.35697 .61872 m .35523 .61959 L .35476 .61703 L F
.665 .818 .957 r
.29179 .55421 m .28785 .55388 L .28991 .55228 L F
.656 .553 .726 r
.29036 .55628 m .28785 .55388 L .29179 .55421 L F
.262 .613 .956 r
.28991 .55228 m .29176 .5528 L .29179 .55421 L F
.656 .553 .726 r
.29036 .55628 m .28896 .55643 L .28785 .55388 L F
.686 .351 .402 r
.28991 .55228 m .28833 .55515 L .29008 .5551 L F
.051 0 .467 r
.29177 .55291 m .29036 .55628 L .29179 .55421 L F
.29167 .55303 m .29036 .55628 L .29177 .55291 L F
.29176 .5528 m .29167 .55303 L .29177 .55291 L F
.29176 .5528 m .29226 .55503 L .29036 .55628 L F
.686 .351 .402 r
.29114 .55372 m .29008 .5551 L .29226 .55503 L F
.28991 .55228 m .29008 .5551 L .29114 .55372 L F
.6 .289 .413 r
.3843 .58644 m .38693 .58763 L .38649 .58475 L F
.3843 .58644 m .38342 .58821 L .38693 .58763 L F
.402 .396 .738 r
.29466 .58252 m .29762 .58471 L .29762 .58291 L F
.369 .31 .66 r
.30949 .5817 m .30804 .58518 L .30808 .58256 L F
.639 .212 .215 r
.35727 .55695 m .35927 .55878 L .36097 .55675 L F
.733 .514 .595 r
.35927 .55878 m .36303 .55654 L .36097 .55675 L F
0 .058 .623 r
.39788 .54262 m .39669 .54236 L .39601 .54042 L F
.39788 .54262 m .39823 .5436 L .39669 .54236 L F
.468 .766 .995 r
.31886 .66457 m .32318 .66529 L .32128 .66388 L F
.403 .615 .937 r
.29862 .6251 m .29726 .62674 L .29549 .62421 L F
.117 .099 .56 r
.29945 .62774 m .29726 .62674 L .29862 .6251 L F
.29945 .62774 m .29815 .62959 L .29726 .62674 L F
.342 .117 .42 r
.23275 .5542 m .23476 .55352 L .23532 .55041 L F
.254 .474 .878 r
.23532 .55041 m .23593 .54832 L .23297 .54902 L F
.23532 .55041 m .23689 .55006 L .23593 .54832 L F
.133 0 .337 r
.23532 .55041 m .23476 .55352 L .23689 .55006 L F
.275 .775 .873 r
.19122 .60943 m .19002 .60651 L .19229 .6071 L F
0 0 .372 r
.19288 .60553 m .19229 .6071 L .19002 .60651 L F
.19288 .60553 m .19278 .60739 L .19229 .6071 L F
.351 .414 .787 r
.19418 .60483 m .19278 .60739 L .19288 .60553 L F
.785 .979 .705 r
.1928 .60666 m .19278 .60739 L .19418 .60483 L F
0 0 .525 r
.19278 .60739 m .19277 .60783 L .19229 .6071 L F
.785 .979 .705 r
.1917 .60812 m .19278 .60739 L .1928 .60666 L F
0 0 .525 r
.19278 .60739 m .19398 .60969 L .19277 .60783 L F
.793 .725 .788 r
.3925 .6706 m .38753 .67039 L .3913 .67058 L F
.516 .887 .972 r
.3925 .6706 m .39317 .66938 L .39499 .66964 L F
.608 .954 .879 r
.3925 .6706 m .3913 .67058 L .39317 .66938 L F
.528 .488 .756 r
.30082 .56035 m .30129 .56096 L .30181 .55522 L F
.856 .4 .06 r
.30082 .56035 m .30149 .56251 L .30129 .56096 L F
.209 .006 .371 r
.30001 .5626 m .30149 .56251 L .30082 .56035 L F
.693 .398 .47 r
.31187 .54708 m .31547 .54721 L .31584 .54474 L F
.5 .254 .474 r
.31547 .54721 m .31807 .54421 L .31584 .54474 L F
.759 .726 .822 r
.62071 .4129 m .62122 .41551 L .61824 .41566 L F
.682 .314 .342 r
.61824 .41566 m .62122 .41551 L .6217 .41798 L F
.403 .475 .82 r
.62406 .4146 m .62122 .41551 L .62071 .4129 L F
.252 .042 .388 r
.6217 .41798 m .62122 .41551 L .62406 .4146 L F
.442 .002 .105 r
.33032 .64276 m .33347 .64186 L .33239 .64378 L F
.531 0 0 r
.33672 .64556 m .33523 .64426 L .33698 .64574 L F
.342 .051 .318 r
.33314 .64245 m .33523 .64426 L .33239 .64378 L F
.199 .638 .947 r
.33239 .64378 m .33523 .64426 L .33274 .64278 L F
.531 0 0 r
.33274 .64278 m .33523 .64426 L .33672 .64556 L F
.342 .051 .318 r
.33347 .64186 m .33523 .64426 L .33314 .64245 L F
.33347 .64186 m .33453 .64211 L .33523 .64426 L F
.519 .052 .086 r
.30646 .62857 m .3095 .62937 L .31107 .62709 L F
0 0 0 r
.31107 .62709 m .31115 .62765 L .31311 .62603 L F
.31107 .62709 m .3095 .62937 L .31115 .62765 L F
.844 .824 .347 r
.33677 .52528 m .33562 .52938 L .33577 .5272 L F
.085 0 0 r
.33677 .52528 m .3383 .52598 L .33854 .52696 L F
.33677 .52528 m .33577 .5272 L .3383 .52598 L F
.436 .11 .312 r
.23988 .55716 m .23924 .56034 L .23605 .56092 L F
.2 0 .238 r
.24125 .55879 m .23988 .55716 L .24165 .55605 L F
.24125 .55879 m .23924 .56034 L .23988 .55716 L F
0 .522 .777 r
.31093 .65937 m .31544 .66048 L .31325 .66031 L F
.081 .638 .794 r
.31544 .66048 m .31743 .66044 L .31325 .66031 L F
.07 0 .281 r
.32455 .61949 m .32279 .62245 L .3231 .62057 L F
0 0 0 r
.32586 .64095 m .32433 .6426 L .32341 .64485 L F
.42 .801 .991 r
.21935 .61196 m .22022 .61055 L .21738 .61093 L F
.21935 .61196 m .22191 .61165 L .22022 .61055 L F
.626 .071 0 r
.4057 .5648 m .40764 .56574 L .40529 .5636 L F
.4057 .5648 m .40529 .5636 L .40525 .56213 L F
.561 0 0 r
.28365 .64679 m .28508 .64602 L .28721 .64747 L F
.797 .867 .9 r
.26461 .75259 m .26584 .75302 L .26425 .75132 L F
.587 .592 .824 r
.32257 .56328 m .32395 .56681 L .32645 .56629 L F
.535 .356 .585 r
.32395 .56681 m .32394 .56951 L .32645 .56629 L F
.01 .194 .706 r
.34736 .62952 m .34842 .63218 L .34946 .63152 L F
0 .044 .577 r
.34946 .63152 m .34842 .63218 L .35008 .63482 L F
.734 .606 .714 r
.30793 .54424 m .31138 .54554 L .31035 .54334 L F
.30793 .54424 m .31187 .54708 L .31138 .54554 L F
.511 .75 .982 r
.36041 .53506 m .36276 .5351 L .35958 .53556 L F
.422 .062 .247 r
.37887 .70269 m .37586 .70441 L .37648 .70287 L F
.734 .615 .726 r
.32436 .66093 m .3281 .66106 L .32647 .65711 L F
.623 .559 .762 r
.32647 .65711 m .3281 .66106 L .33008 .65807 L F
.224 0 .23 r
.34515 .57162 m .34643 .57177 L .34727 .57092 L F
.34515 .57162 m .34449 .57328 L .34643 .57177 L F
.514 .293 .516 r
.33787 .54157 m .33777 .54454 L .33529 .54465 L F
.33787 .54157 m .33777 .54454 L .33529 .54465 L F
.091 .053 .517 r
.33936 .53733 m .33969 .54018 L .33787 .54157 L F
.484 .269 .51 r
.33792 .54157 m .34059 .54352 L .34067 .5413 L F
.33787 .54157 m .33791 .5416 L .33792 .54157 L F
.33791 .5416 m .34059 .54352 L .33792 .54157 L F
.34059 .54352 m .33787 .54157 L .33969 .54018 L F
.34059 .54352 m .33777 .54454 L .33787 .54157 L F
.33787 .54157 m .33777 .54454 L .34059 .54352 L F
.843 .976 .674 r
.34095 .5454 m .33777 .54454 L .34059 .54352 L F
.455 .207 .448 r
.34059 .54352 m .33973 .54618 L .33777 .54454 L F
0 0 .328 r
.33827 .54498 m .33987 .54107 L .33752 .54428 L F
.33751 .54435 m .33752 .54428 L .33749 .54433 L F
.33827 .54498 m .33752 .54428 L .33751 .54435 L F
.543 0 0 r
.26425 .75132 m .26848 .75182 L .26577 .75076 L F
.631 .804 .373 r
.34083 .53472 m .33936 .53733 L .33982 .5366 L F
.326 .793 .684 r
.26235 .52676 m .25882 .52828 L .26087 .5272 L F
.305 .782 .922 r
.26322 .52597 m .26235 .52676 L .26087 .5272 L F
.26322 .52597 m .26518 .52636 L .26235 .52676 L F
.029 0 0 r
.27485 .61882 m .27606 .6179 L .27289 .61943 L F
.442 .186 .429 r
.27485 .61882 m .27781 .61617 L .27606 .6179 L F
.989 .744 .467 r
.32589 .61069 m .32411 .61138 L .32293 .61293 L F
.302 .221 .596 r
.3708 .61724 m .37277 .61922 L .37288 .61603 L F
.3708 .61724 m .37114 .61997 L .37277 .61922 L F
.085 .596 .888 r
.37462 .51655 m .37734 .51698 L .37839 .51755 L F
0 .284 .785 r
.37968 .51742 m .37839 .51755 L .37734 .51698 L F
.37968 .51742 m .37978 .5189 L .37839 .51755 L F
.815 .803 .84 r
.31073 .52059 m .30588 .52272 L .30611 .52125 L F
.31073 .52059 m .30611 .52125 L .30874 .52125 L F
.83 1 .813 r
.31073 .52059 m .31151 .51819 L .31322 .5194 L F
.31073 .52059 m .30874 .52125 L .31151 .51819 L F
.802 .723 .777 r
.37805 .54504 m .37337 .54375 L .37618 .5435 L F
.37805 .54504 m .37506 .54755 L .37337 .54375 L F
0 0 .302 r
.37907 .54252 m .37805 .54504 L .37618 .5435 L F
.46 .057 .189 r
.37805 .54504 m .37913 .54818 L .38384 .54387 L F
0 0 .302 r
.37907 .54252 m .37913 .54818 L .37805 .54504 L F
.474 .171 .371 r
.36417 .62224 m .36183 .62055 L .36256 .62291 L F
.36417 .62224 m .36473 .61964 L .36183 .62055 L F
.612 .401 .571 r
.22316 .58849 m .22099 .58956 L .21971 .58835 L F
.22316 .58849 m .22258 .59106 L .22099 .58956 L F
.379 .441 .799 r
.32062 .5392 m .32231 .53675 L .31949 .53717 L F
.453 0 .054 r
.3132 .64726 m .31207 .64556 L .31057 .64856 L F
.3132 .64726 m .31484 .64523 L .31207 .64556 L F
.542 .633 .891 r
.33897 .53158 m .33898 .53217 L .33562 .52938 L F
.703 .845 .95 r
.33424 .60734 m .33675 .60876 L .33876 .60743 L F
.243 0 .123 r
.38224 .59458 m .37925 .59512 L .37823 .59715 L F
0 0 .385 r
.30181 .55522 m .30129 .56096 L .30269 .55818 L F
0 0 .175 r
.30129 .56096 m .30309 .56082 L .30269 .55818 L F
.30129 .56096 m .30149 .56251 L .30309 .56082 L F
.478 .885 .942 r
.23892 .53287 m .23783 .53385 L .23675 .53348 L F
.325 .121 .442 r
.32857 .54721 m .33082 .54365 L .32888 .54474 L F
0 0 0 r
.24828 .53079 m .24712 .53107 L .24603 .53166 L F
.24828 .53079 m .25027 .53022 L .24712 .53107 L F
.65 .869 .981 r
.28974 .53738 m .2879 .53861 L .29147 .53844 L F
.324 .75 .973 r
.29615 .53638 m .29215 .53566 L .29449 .53523 L F
.29615 .53638 m .29454 .53543 L .29215 .53566 L F
.534 .187 .327 r
.29454 .53543 m .29377 .536 L .29215 .53566 L F
.761 .892 .937 r
.29215 .53566 m .29147 .53844 L .29018 .53524 L F
.29215 .53566 m .28974 .53738 L .29147 .53844 L F
.534 .187 .327 r
.29377 .536 m .29034 .53856 L .29215 .53566 L F
.761 .892 .937 r
.29215 .53566 m .29018 .53524 L .2901 .53503 L F
.293 .215 .594 r
.29147 .53844 m .29187 .54137 L .29345 .54022 L F
.512 .913 .845 r
.276 .53376 m .27536 .53382 L .27402 .53495 L F
.878 .467 .233 r
.34492 .70147 m .3444 .70396 L .34242 .70117 L F
.34492 .70147 m .34625 .70432 L .3444 .70396 L F
.134 0 .154 r
.27774 .54053 m .28038 .53756 L .27834 .53803 L F
.203 .684 .932 r
.35656 .50971 m .35907 .50979 L .36051 .51051 L F
.39 .733 .991 r
.3611 .50911 m .36051 .51051 L .35907 .50979 L F
.3611 .50911 m .36261 .5103 L .36051 .51051 L F
.759 .887 .936 r
.71988 .31007 m .71591 .31066 L .71855 .30789 L F
.137 .569 .926 r
.72091 .30936 m .71988 .31007 L .71855 .30789 L F
.72091 .30936 m .72183 .31033 L .71988 .31007 L F
.343 .315 .682 r
.22241 .61412 m .22371 .61023 L .22191 .61165 L F
.22241 .61412 m .22426 .61365 L .22371 .61023 L F
.426 .409 .737 r
.22325 .61601 m .22426 .61365 L .22241 .61412 L F
.813 .842 .871 r
.29815 .62959 m .29529 .6325 L .29649 .63265 L F
.399 .319 .65 r
.29815 .62959 m .29649 .63265 L .29843 .63162 L F
.172 .524 .92 r
.29649 .63265 m .29994 .6332 L .29843 .63162 L F
.29649 .63265 m .3014 .63481 L .30024 .63353 L F
.29649 .63265 m .30024 .63353 L .29906 .63306 L F
.608 .364 .522 r
.29742 .63241 m .29737 .63459 L .29487 .63441 L F
.29843 .63162 m .29806 .63267 L .29742 .63241 L F
.29806 .63267 m .29737 .63459 L .29742 .63241 L F
.172 .524 .92 r
.29906 .63306 m .30024 .63353 L .29994 .6332 L F
.583 .68 .907 r
.386 .65833 m .38334 .65919 L .38187 .65692 L F
.491 .298 .546 r
.38279 .62646 m .38506 .62864 L .38267 .62915 L F
.558 .294 .472 r
.38619 .62691 m .38506 .62864 L .38279 .62646 L F
.776 .592 .65 r
.22097 .57335 m .22055 .57486 L .21776 .57515 L F
.504 .214 .407 r
.22359 .57289 m .22055 .57486 L .22097 .57335 L F
1 .801 .487 r
.36622 .55125 m .36483 .55275 L .36542 .54986 L F
.587 .106 .078 r
.36776 .55279 m .36483 .55275 L .36622 .55125 L F
0 0 .314 r
.31992 .56068 m .32055 .56225 L .32126 .5596 L F
.546 .775 .983 r
.35099 .50569 m .35024 .50768 L .34883 .50537 L F
.35099 .50569 m .35249 .50708 L .35024 .50768 L F
.387 .149 .427 r
.23012 .55739 m .23235 .55674 L .23275 .5542 L F
.23012 .55739 m .23235 .55674 L .23275 .5542 L F
.838 .463 0 r
.23163 .55263 m .23275 .5542 L .23072 .5502 L F
.339 .109 .412 r
.23476 .55352 m .23275 .5542 L .23163 .55263 L F
.23476 .55352 m .23235 .55674 L .23275 .5542 L F
.23275 .5542 m .23235 .55674 L .23476 .55352 L F
.124 0 0 r
.37745 .65113 m .37387 .65356 L .37492 .65384 L F
.048 0 0 r
.34389 .59817 m .33964 .60034 L .34336 .60074 L F
.44 .174 .412 r
.38198 .69843 m .38196 .70174 L .37887 .70269 L F
.471 .306 .575 r
.384 .6948 m .38427 .69776 L .38198 .69843 L F
.271 .049 .381 r
.38363 .70035 m .38198 .69843 L .38427 .69776 L F
.38363 .70035 m .38196 .70174 L .38198 .69843 L F
.235 .006 .348 r
.19027 .56977 m .19196 .5692 L .19261 .56659 L F
.369 .29 .634 r
.19062 .57257 m .19196 .5692 L .19027 .56977 L F
.821 .943 .583 r
.32065 .61359 m .3187 .6171 L .31844 .61602 L F
.813 .708 .172 r
.31844 .61602 m .3187 .6171 L .31841 .61949 L F
.413 0 0 r
.34096 .62143 m .34291 .62262 L .34528 .62094 L F
0 0 0 r
.34528 .62094 m .34601 .62129 L .34825 .62036 L F
.34528 .62094 m .34291 .62262 L .34601 .62129 L F
.32177 .55511 m .32223 .55515 L .32341 .55369 L F
.32177 .55511 m .32042 .55764 L .32223 .55515 L F
.187 .72 .804 r
.31854 .65557 m .31712 .656 L .31601 .65518 L F
.31854 .65557 m .3193 .6557 L .31712 .656 L F
.616 .244 .315 r
.30709 .53485 m .30183 .5372 L .30288 .53487 L F
.462 .239 .489 r
.31213 .53474 m .30943 .53768 L .30899 .53535 L F
0 0 0 r
.30797 .53563 m .30709 .53485 L .30933 .53421 L F
.992 .873 .543 r
.30866 .53361 m .30933 .53421 L .31139 .53412 L F
0 0 0 r
.30683 .53682 m .30687 .53592 L .30797 .53563 L F
.799 .502 .488 r
.30765 .53702 m .30645 .53694 L .30712 .53855 L F
.30698 .53677 m .30645 .53694 L .30765 .53702 L F
0 0 0 r
.30665 .537 m .30668 .53687 L .30683 .53682 L F
.30668 .53687 m .30687 .53592 L .30683 .53682 L F
.424 .273 .57 r
.30566 .53859 m .30454 .53862 L .30556 .53784 L F
0 0 0 r
.30682 .53618 m .30454 .53862 L .30709 .53485 L F
.30668 .53686 m .30567 .53769 L .30682 .53618 L F
.30567 .53769 m .30454 .53862 L .30682 .53618 L F
.424 .273 .57 r
.30712 .53855 m .30508 .54021 L .30454 .53862 L F
.596 .596 .822 r
.30183 .5372 m .3017 .54156 L .30015 .53932 L F
.30183 .5372 m .30722 .54382 L .3017 .54156 L F
.081 .547 .903 r
.30183 .5372 m .29852 .53573 L .29967 .53494 L F
0 .166 .698 r
.3052 .54041 m .30722 .54382 L .30362 .5394 L F
.663 .843 .969 r
.30471 .54189 m .30722 .54382 L .30508 .54021 L F
.236 0 .251 r
.30591 .54234 m .30471 .54189 L .30644 .54121 L F
.30648 .54124 m .30644 .54121 L .3065 .54119 L F
.30591 .54234 m .30644 .54121 L .30648 .54124 L F
0 .166 .698 r
.30508 .54021 m .3052 .54041 L .3031 .53876 L F
.3052 .54041 m .30362 .5394 L .3031 .53876 L F
.30508 .54021 m .3031 .53876 L .30183 .5372 L F
.18 .161 .599 r
.30508 .54021 m .3065 .54119 L .30644 .54121 L F
.30508 .54021 m .30644 .54121 L .30471 .54189 L F
.081 .547 .903 r
.30183 .5372 m .30062 .53614 L .29852 .53573 L F
.308 0 0 r
.29602 .53935 m .29829 .53964 L .30015 .53932 L F
.511 .332 .574 r
.29829 .53964 m .30183 .5372 L .30015 .53932 L F
.29829 .53964 m .30062 .53614 L .30183 .5372 L F
.547 .021 0 r
.30508 .54021 m .30062 .53614 L .3007 .53918 L F
.30508 .54021 m .30454 .53979 L .30062 .53614 L F
.968 .907 .701 r
.30526 .53823 m .30454 .53979 L .30508 .54021 L F
.3054 .53676 m .30481 .53882 L .30526 .53823 L F
.30481 .53882 m .30454 .53979 L .30526 .53823 L F
.30558 .53484 m .30531 .53612 L .3054 .53676 L F
0 0 0 r
.30663 .53691 m .30567 .5377 L .30668 .53686 L F
.30567 .5377 m .30454 .53862 L .30567 .53769 L F
.30567 .5377 m .30567 .53769 L .30668 .53686 L F
.30597 .53753 m .30528 .53806 L .30668 .53687 L F
.30528 .53806 m .30454 .53862 L .30533 .53797 L F
.30528 .53806 m .30533 .53797 L .30668 .53687 L F
0 .166 .698 r
.30508 .54021 m .30183 .5372 L .30454 .53862 L F
.947 .904 .521 r
.30404 .53705 m .30446 .53935 L .30558 .53484 L F
.30446 .53935 m .30454 .53979 L .30471 .53895 L F
.30446 .53935 m .30471 .53895 L .30558 .53484 L F
.968 .907 .701 r
.30531 .53612 m .30471 .53895 L .3054 .53676 L F
.30471 .53895 m .30454 .53979 L .30481 .53882 L F
.30471 .53895 m .30481 .53882 L .3054 .53676 L F
.424 .273 .57 r
.30712 .53855 m .30566 .53859 L .30607 .53745 L F
.30566 .53859 m .30556 .53784 L .30607 .53745 L F
.968 .907 .701 r
.30649 .53704 m .30623 .53762 L .30712 .53855 L F
.30526 .53823 m .30508 .54021 L .30649 .53704 L F
.424 .273 .57 r
.30712 .53855 m .30607 .53745 L .30665 .537 L F
.968 .907 .701 r
.30623 .53762 m .30508 .54021 L .30712 .53855 L F
.30558 .53484 m .30526 .53823 L .30649 .53704 L F
0 0 0 r
.30668 .53687 m .30663 .53691 L .30668 .53686 L F
.30665 .537 m .30597 .53753 L .30668 .53687 L F
.799 .502 .488 r
.30668 .53687 m .30558 .53484 L .30645 .53694 L F
.30683 .53682 m .30679 .53676 L .30668 .53687 L F
.30679 .53676 m .30558 .53484 L .30668 .53687 L F
.992 .873 .543 r
.30683 .53671 m .30683 .53682 L .30691 .53674 L F
0 0 0 r
.30687 .53592 m .30709 .53485 L .30797 .53563 L F
.594 .668 .891 r
.30943 .53768 m .30683 .53671 L .30866 .53361 L F
.799 .502 .488 r
.30783 .5365 m .3068 .53574 L .30683 .53682 L F
.3068 .53574 m .30558 .53484 L .30683 .53682 L F
.992 .873 .543 r
.30683 .53671 m .30665 .537 L .30683 .53682 L F
.30866 .53361 m .30887 .53469 L .30933 .53421 L F
.799 .502 .488 r
.30783 .5365 m .30698 .53677 L .30765 .53702 L F
.30943 .53768 m .30783 .5365 L .30712 .53855 L F
.594 .668 .891 r
.30943 .53768 m .30665 .537 L .30683 .53671 L F
.462 .239 .489 r
.31172 .53461 m .30899 .53535 L .30866 .53361 L F
.31213 .53474 m .30899 .53535 L .31172 .53461 L F
.579 .578 .815 r
.32887 .56315 m .32983 .55886 L .32697 .56057 L F
.575 .682 .913 r
.3186 .56618 m .31778 .57036 L .31665 .56889 L F
.377 .129 .405 r
.23012 .55739 m .22961 .55975 L .23235 .55674 L F
.23012 .55739 m .22961 .55975 L .23235 .55674 L F
.731 .491 .565 r
.35483 .55925 m .35102 .55693 L .35467 .55716 L F
.621 .519 .717 r
.35686 .55435 m .35727 .55695 L .35467 .55716 L F
.67 .459 .591 r
.35727 .55695 m .35483 .55925 L .35467 .55716 L F
.35727 .55695 m .35483 .55925 L .35467 .55716 L F
.581 .904 .982 r
.32197 .516 m .31959 .51697 L .31786 .51633 L F
.763 .702 .794 r
.3647 .63204 m .36084 .63285 L .36339 .6326 L F
.601 .212 .278 r
.33984 .57968 m .33839 .5817 L .34202 .58138 L F
.457 .27 .538 r
.33984 .57968 m .34202 .58138 L .3421 .57873 L F
.427 .808 .991 r
.35017 .58185 m .34826 .58103 L .34582 .58138 L F
.387 .624 .947 r
.35017 .58185 m .35057 .5801 L .34826 .58103 L F
.35017 .58185 m .35234 .58175 L .35057 .5801 L F
.761 .892 .937 r
.29215 .53566 m .2901 .53503 L .29449 .53523 L F
.81 .927 .912 r
.36373 .54046 m .36148 .54243 L .35968 .54156 L F
.191 0 0 r
.22137 .54327 m .22562 .54109 L .22352 .54202 L F
.369 .31 .66 r
.30949 .5817 m .31016 .58533 L .30804 .58518 L F
.088 0 .014 r
.31016 .58533 m .30751 .58754 L .30804 .58518 L F
.519 .354 .597 r
.27425 .6263 m .27422 .62987 L .27201 .62995 L F
.597 .603 .829 r
.21971 .58835 m .21713 .58929 L .21482 .58509 L F
.386 0 .178 r
.27196 .54399 m .2743 .54364 L .2756 .54131 L F
.489 .173 .357 r
.2743 .54364 m .27774 .54053 L .2756 .54131 L F
.802 .698 .749 r
.22316 .58849 m .21971 .58835 L .22245 .58489 L F
.157 .242 .701 r
.22245 .58489 m .22478 .5875 L .22316 .58849 L F
0 0 .058 r
.22373 .58937 m .22316 .58849 L .22478 .5875 L F
.22373 .58937 m .22258 .59106 L .22316 .58849 L F
.455 .053 .187 r
.3883 .60877 m .38511 .60762 L .38743 .60731 L F
.3883 .60877 m .38347 .60973 L .38511 .60762 L F
.486 .272 .514 r
.36413 .57544 m .36151 .57856 L .36178 .57628 L F
.074 0 0 r
.31294 .57652 m .31162 .57829 L .30964 .57906 L F
.104 0 0 r
.31507 .57562 m .31162 .57829 L .31294 .57652 L F
.012 0 0 r
.33544 .56028 m .33313 .56212 L .33129 .56253 L F
.532 .037 .027 r
.33746 .56203 m .33544 .56028 L .33772 .55959 L F
.33746 .56203 m .33313 .56212 L .33544 .56028 L F
.79 .943 .925 r
.32213 .65707 m .3243 .65719 L .32179 .65854 L F
.32213 .65707 m .3243 .65719 L .32179 .65854 L F
.734 .615 .726 r
.32436 .66093 m .3243 .65719 L .32415 .66054 L F
.32436 .66093 m .32647 .65711 L .3243 .65719 L F
0 0 .101 r
.32461 .65905 m .32415 .66054 L .3243 .65719 L F
.32461 .65905 m .3243 .65719 L .32213 .65707 L F
.56 .831 .996 r
.31644 .64776 m .31871 .64845 L .31854 .64818 L F
.608 .954 .845 r
.31438 .65025 m .31871 .64845 L .31644 .64776 L F
.518 .76 .984 r
.35968 .66616 m .36182 .66791 L .35867 .66818 L F
.157 0 0 r
.24747 .54809 m .24749 .54809 L .24828 .54612 L F
0 0 0 r
.24984 .54995 m .25437 .54729 L .25029 .54678 L F
.24984 .54995 m .25029 .54678 L .25012 .54687 L F
.371 .322 .673 r
.25063 .54725 m .24984 .54995 L .25013 .54676 L F
.157 0 0 r
.24842 .54765 m .25063 .54725 L .24997 .54693 L F
.24868 .54777 m .25063 .54725 L .24842 .54765 L F
0 0 0 r
.24984 .54995 m .25197 .54916 L .25284 .54849 L F
.25185 .54877 m .25284 .54849 L .25437 .54729 L F
.24984 .54995 m .25284 .54849 L .25185 .54877 L F
.306 0 0 r
.25437 .54729 m .25197 .54916 L .25464 .54863 L F
.68 .41 .507 r
.25421 .54809 m .25063 .54725 L .25331 .54695 L F
.25464 .54863 m .25359 .54827 L .25421 .54809 L F
.25359 .54827 m .25063 .54725 L .25421 .54809 L F
.371 .322 .673 r
.25011 .54901 m .25197 .54916 L .24984 .54995 L F
.25063 .54725 m .2514 .54835 L .25011 .54901 L F
.2514 .54835 m .25197 .54916 L .25011 .54901 L F
.651 .838 .429 r
.25251 .54704 m .25124 .54594 L .25331 .54695 L F
.25063 .54725 m .25124 .54594 L .25251 .54704 L F
.951 .599 .238 r
.24983 .5434 m .25124 .54594 L .25023 .5451 L F
0 .12 .586 r
.25023 .5451 m .25058 .54538 L .25124 .54594 L F
.75 .715 .82 r
.25067 .54703 m .25234 .54787 L .25331 .54695 L F
.24986 .54706 m .25053 .54728 L .25067 .54703 L F
.926 .97 .761 r
.24985 .5477 m .24985 .54827 L .25046 .54766 L F
.24985 .5477 m .24762 .55118 L .24984 .54995 L F
.157 0 0 r
.24868 .54777 m .25029 .54767 L .25063 .54725 L F
.926 .97 .761 r
.24986 .54706 m .2494 .5479 L .24985 .5477 L F
.2494 .5479 m .24762 .55118 L .24985 .5477 L F
.157 0 0 r
.24972 .54776 m .24994 .54811 L .25029 .54767 L F
.561 .433 .663 r
.24747 .54809 m .24762 .55118 L .2494 .5479 L F
.157 0 0 r
.24747 .54809 m .2494 .5479 L .24972 .54776 L F
.24747 .54809 m .25029 .54767 L .24868 .54777 L F
.24749 .54809 m .24868 .54777 L .24842 .54765 L F
.561 .433 .663 r
.24747 .54809 m .2494 .5479 L .24986 .54706 L F
.157 0 0 r
.24747 .54809 m .24894 .5481 L .2494 .5479 L F
.24894 .5481 m .24994 .54811 L .24972 .54776 L F
.926 .97 .761 r
.25046 .54766 m .24985 .54827 L .25197 .54916 L F
.24986 .54706 m .24985 .5477 L .25046 .54766 L F
.651 .838 .429 r
.25063 .54725 m .25035 .54761 L .25053 .54728 L F
.2509 .54668 m .25053 .54728 L .25106 .54634 L F
.25063 .54725 m .25053 .54728 L .2509 .54668 L F
.68 .41 .507 r
.25464 .54863 m .25197 .54916 L .25063 .54725 L F
.75 .715 .82 r
.25053 .54728 m .25197 .54916 L .25464 .54863 L F
.24986 .54706 m .25036 .54756 L .25053 .54728 L F
.25036 .54756 m .25197 .54916 L .25053 .54728 L F
.25053 .54728 m .25234 .54787 L .25067 .54703 L F
.715 .503 .6 r
.24828 .54612 m .25063 .54725 L .25013 .54676 L F
.85 .393 .092 r
.25067 .54703 m .24994 .54811 L .24986 .54706 L F
.651 .838 .429 r
.25035 .54761 m .24994 .54811 L .25067 .54703 L F
.85 .393 .092 r
.25331 .54695 m .24994 .54811 L .25067 .54703 L F
.651 .838 .429 r
.25067 .54703 m .24994 .54811 L .25106 .54634 L F
.25106 .54634 m .24994 .54811 L .25124 .54594 L F
.85 .393 .092 r
.25331 .54695 m .25124 .54594 L .24994 .54811 L F
.25331 .54695 m .25098 .54693 L .25124 .54594 L F
.926 .97 .761 r
.24985 .54827 m .24984 .54995 L .25194 .54917 L F
.827 .586 .574 r
.25272 .54866 m .2499 .54855 L .25092 .54687 L F
.561 .433 .663 r
.24747 .54809 m .24986 .54706 L .24994 .54811 L F
0 0 0 r
.25124 .54594 m .24868 .54982 L .25018 .54784 L F
.25091 .54675 m .25018 .54784 L .25079 .54703 L F
.25124 .54594 m .25018 .54784 L .25091 .54675 L F
.509 0 0 r
.25124 .54594 m .25258 .54696 L .25331 .54695 L F
0 .12 .586 r
.25058 .54538 m .25258 .54696 L .25124 .54594 L F
0 0 0 r
.25124 .54594 m .2508 .547 L .2509 .54685 L F
.2508 .547 m .25079 .54703 L .25083 .54695 L F
.2508 .547 m .25083 .54695 L .2509 .54685 L F
.85 .393 .092 r
.25098 .54693 m .2509 .54685 L .25124 .54594 L F
.157 0 0 r
.24749 .54809 m .24997 .54693 L .24828 .54612 L F
0 0 0 r
.25012 .54687 m .25029 .54678 L .25013 .54676 L F
.771 .964 .927 r
.24868 .54982 m .25065 .54707 L .25072 .54705 L F
.24868 .54982 m .25075 .547 L .25074 .54709 L F
.827 .586 .574 r
.2499 .54855 m .24927 .54853 L .25075 .54704 L F
.25079 .54703 m .25075 .54704 L .25083 .54695 L F
.2499 .54855 m .25075 .54704 L .25079 .54703 L F
.856 .664 .129 r
.24742 .54888 m .24762 .55118 L .2475 .5486 L F
.24742 .54888 m .2475 .5486 L .24747 .54809 L F
.413 0 0 r
.24742 .54888 m .24502 .55027 L .24714 .55001 L F
0 .019 .551 r
.24742 .54888 m .24868 .54982 L .24762 .55118 L F
.413 0 0 r
.24742 .54888 m .24714 .55001 L .24868 .54982 L F
.771 .964 .927 r
.24868 .54982 m .24688 .54952 L .25065 .54707 L F
.25072 .54705 m .25065 .54707 L .25075 .547 L F
.25074 .54709 m .25075 .547 L .25087 .54693 L F
.871 .989 .727 r
.25082 .54641 m .24927 .54853 L .24961 .5464 L F
.92 .531 .143 r
.25124 .54594 m .25089 .54688 L .25023 .5451 L F
.871 .989 .727 r
.25083 .54695 m .24927 .54853 L .2512 .54641 L F
.92 .531 .143 r
.25089 .54688 m .25087 .54693 L .25085 .54688 L F
.25089 .54688 m .25085 .54688 L .25023 .5451 L F
.85 .393 .092 r
.25098 .54693 m .25087 .54693 L .2509 .54685 L F
.827 .586 .574 r
.25169 .54694 m .25092 .54687 L .25137 .54641 L F
.25272 .54866 m .25098 .54693 L .25169 .54694 L F
.25098 .54693 m .25092 .54687 L .25169 .54694 L F
.028 0 0 r
.25264 .54696 m .25183 .54694 L .25331 .54695 L F
.25183 .54694 m .25098 .54693 L .25126 .54693 L F
.25183 .54694 m .25126 .54693 L .25331 .54695 L F
.791 .489 .477 r
.25167 .54624 m .25144 .5464 L .25258 .54696 L F
.25114 .54581 m .25142 .54637 L .25167 .54624 L F
.25142 .54637 m .25144 .5464 L .25167 .54624 L F
.611 .491 .691 r
.25558 .54555 m .25137 .54641 L .25209 .54254 L F
.458 .346 .639 r
.25376 .54428 m .2514 .54638 L .25209 .54254 L F
.2514 .54638 m .25137 .54641 L .25139 .54635 L F
.2514 .54638 m .25139 .54635 L .25209 .54254 L F
.791 .489 .477 r
.25023 .5451 m .25139 .54635 L .25114 .54581 L F
.25139 .54635 m .25144 .5464 L .25114 .54581 L F
.622 .501 .694 r
.25023 .5451 m .25124 .54625 L .25125 .5462 L F
.791 .489 .477 r
.25023 .5451 m .25085 .54688 L .2514 .54636 L F
.622 .501 .694 r
.25023 .5451 m .25125 .5462 L .25209 .54254 L F
.25124 .54625 m .25137 .54641 L .25147 .54591 L F
.25124 .54625 m .25147 .54591 L .25209 .54254 L F
.25023 .5451 m .25137 .54641 L .25209 .54254 L F
.253 0 0 r
.24961 .5464 m .25376 .54428 L .2514 .54638 L F
.25135 .54641 m .2514 .54638 L .25137 .54641 L F
.24961 .5464 m .2514 .54638 L .25135 .54641 L F
.791 .489 .477 r
.25144 .5464 m .2522 .54695 L .25258 .54696 L F
.827 .586 .574 r
.25331 .54868 m .25272 .54866 L .25169 .54694 L F
.25183 .54694 m .25169 .54694 L .25137 .54641 L F
.25331 .54868 m .25169 .54694 L .25183 .54694 L F
.028 0 0 r
.25258 .54696 m .25098 .54693 L .25264 .54696 L F
.627 .573 .774 r
.25452 .54701 m .25183 .54694 L .25137 .54641 L F
.791 .489 .477 r
.25144 .5464 m .25195 .54695 L .2522 .54695 L F
.627 .573 .774 r
.25558 .54555 m .25452 .54701 L .25148 .54643 L F
.25143 .5464 m .25148 .54643 L .25137 .54641 L F
.25558 .54555 m .25148 .54643 L .25143 .5464 L F
.75 .715 .82 r
.25234 .54787 m .25464 .54863 L .25355 .54725 L F
.25234 .54787 m .25355 .54725 L .25331 .54695 L F
.627 .573 .774 r
.25452 .54701 m .25331 .54868 L .25183 .54694 L F
.028 0 0 r
.25258 .54696 m .25087 .54693 L .25098 .54693 L F
.791 .489 .477 r
.2514 .54636 m .25087 .54693 L .25195 .54695 L F
.871 .989 .727 r
.25137 .54641 m .25083 .54695 L .25095 .54679 L F
.25137 .54641 m .25095 .54679 L .25135 .54641 L F
.791 .489 .477 r
.25085 .54688 m .25087 .54693 L .2514 .54636 L F
.871 .989 .727 r
.25135 .54641 m .25095 .54679 L .2512 .54641 L F
.2512 .54641 m .25077 .54688 L .25082 .54641 L F
.25077 .54688 m .25077 .54688 L .25077 .54688 L F
.25077 .54688 m .25077 .54688 L .25082 .54641 L F
.25077 .54688 m .24927 .54853 L .25082 .54641 L F
.827 .586 .574 r
.2499 .54855 m .25083 .54695 L .25092 .54687 L F
0 0 0 r
.2509 .54685 m .25079 .54703 L .25087 .54693 L F
.926 .97 .761 r
.24985 .54827 m .25194 .54917 L .25197 .54916 L F
.306 0 0 r
.25437 .54729 m .25464 .54863 L .25625 .54832 L F
.376 .444 .804 r
.35555 .60059 m .35591 .60312 L .35619 .60053 L F
.385 .399 .752 r
.35591 .60312 m .35879 .60013 L .35619 .60053 L F
.82 .426 .305 r
.3132 .64726 m .31644 .64776 L .31484 .64523 L F
.56 .831 .996 r
.31644 .64776 m .31854 .64818 L .31484 .64523 L F
.299 .067 .384 r
.33327 .59018 m .33188 .58855 L .33446 .58818 L F
.33327 .59018 m .33117 .59135 L .33188 .58855 L F
.6 .331 .481 r
.37363 .70502 m .3732 .7074 L .37066 .70767 L F
.45 .219 .471 r
.37586 .70441 m .3732 .7074 L .37363 .70502 L F
.976 .687 .405 r
.33111 .51038 m .32965 .5119 L .32901 .50908 L F
.545 .788 .988 r
.33166 .50827 m .33337 .50971 L .33111 .51038 L F
.33166 .50827 m .33337 .50971 L .33111 .51038 L F
.39 .146 .419 r
.27497 .62565 m .27425 .6263 L .27691 .62313 L F
.592 .789 .974 r
.21947 .55669 m .22342 .55723 L .22189 .55607 L F
.554 .222 .361 r
.2196 .55983 m .22342 .55723 L .21947 .55669 L F
.2196 .55983 m .22404 .5596 L .22342 .55723 L F
.439 .727 .987 r
.22189 .55607 m .22342 .55723 L .22395 .55554 L F
.531 .209 .366 r
.22342 .55723 m .22536 .55908 L .22395 .55554 L F
.22342 .55723 m .22404 .5596 L .22536 .55908 L F
.201 .213 .648 r
.30575 .57551 m .30772 .57457 L .30681 .57188 L F
.387 .185 .48 r
.30503 .57799 m .30772 .57457 L .30575 .57551 L F
0 0 .179 r
.35319 .60936 m .35356 .61183 L .35618 .61005 L F
.6 .609 .833 r
.35618 .61005 m .35815 .60949 L .35678 .60513 L F
.539 .797 .993 r
.32423 .51538 m .32568 .51667 L .32197 .516 L F
.414 .683 .973 r
.32644 .51492 m .32568 .51667 L .32423 .51538 L F
.32644 .51492 m .32741 .51608 L .32568 .51667 L F
.382 .842 .891 r
.25025 .52949 m .25027 .53022 L .24828 .53079 L F
.25025 .52949 m .25263 .52952 L .25027 .53022 L F
0 0 0 r
.24605 .54122 m .24414 .54205 L .24209 .54271 L F
.272 0 0 r
.24848 .54046 m .24414 .54205 L .24605 .54122 L F
.193 0 .336 r
.3633 .66293 m .36141 .66417 L .36392 .66067 L F
.089 0 .222 r
.39124 .57721 m .38855 .57926 L .39006 .58013 L F
.199 .311 .754 r
.39006 .58013 m .38855 .57926 L .38941 .5765 L F
.627 .132 .055 r
.38855 .57926 m .38716 .58087 L .38941 .5765 L F
.234 0 .194 r
.39234 .58011 m .38958 .58141 L .39074 .58107 L F
.375 .232 .556 r
.38855 .57926 m .38958 .58141 L .39074 .58107 L F
.627 .132 .055 r
.38855 .57926 m .39074 .58107 L .38716 .58087 L F
.466 .092 .245 r
.37373 .55828 m .37014 .56092 L .36807 .56045 L F
.784 .99 .754 r
.32791 .64526 m .33032 .64276 L .32832 .64367 L F
.451 0 0 r
.32832 .64367 m .33032 .64276 L .33239 .64378 L F
.748 .488 .538 r
.30586 .59214 m .30642 .5945 L .30539 .5935 L F
.108 .085 .547 r
.30749 .59326 m .30586 .59214 L .30459 .59071 L F
.30749 .59326 m .30642 .5945 L .30586 .59214 L F
.751 .735 .838 r
.35481 .57849 m .3593 .57923 L .35736 .57593 L F
.742 .501 .566 r
.35488 .5813 m .3592 .58186 L .3593 .57923 L F
.54 .64 .898 r
.35736 .57593 m .3593 .57923 L .36151 .57856 L F
.4 .219 .517 r
.36132 .58115 m .3593 .57923 L .36151 .57856 L F
.36132 .58115 m .3592 .58186 L .3593 .57923 L F
.36132 .58115 m .3593 .57923 L .36151 .57856 L F
.36132 .58115 m .3592 .58186 L .3593 .57923 L F
.773 .643 .718 r
.34649 .52239 m .34837 .52857 L .34402 .52554 L F
.75 .23 0 r
.34402 .52554 m .34837 .52857 L .34804 .52849 L F
.399 .415 .761 r
.34953 .52509 m .34837 .52857 L .34649 .52239 L F
.888 .949 .842 r
.34804 .52849 m .34837 .52857 L .34953 .52509 L F
.573 .439 .661 r
.34453 .65144 m .34688 .64746 L .34533 .64838 L F
.423 .864 .906 r
.25647 .52881 m .25263 .52952 L .25496 .52886 L F
.357 .819 .922 r
.25719 .52804 m .25647 .52881 L .25496 .52886 L F
.25719 .52804 m .25882 .52828 L .25647 .52881 L F
.622 .483 .671 r
.35269 .53798 m .35038 .5408 L .3503 .53836 L F
.779 .676 .75 r
.36807 .56295 m .36494 .56576 L .36597 .56391 L F
.6 .498 .71 r
.3642 .54509 m .36483 .54737 L .36232 .54765 L F
.676 .397 .49 r
.36542 .54986 m .36238 .55001 L .36232 .54765 L F
.508 .287 .513 r
.3871 .69218 m .38676 .6949 L .384 .6948 L F
.375 .156 .449 r
.38676 .6949 m .38427 .69776 L .384 .6948 L F
.048 0 .044 r
.37557 .61027 m .37394 .61186 L .37658 .6115 L F
.072 0 .189 r
.37658 .6115 m .37394 .61186 L .37394 .61497 L F
.217 .133 .54 r
.18885 .5819 m .19047 .57798 L .18879 .57922 L F
.595 .439 .641 r
.35647 .61357 m .35361 .61422 L .35279 .61327 L F
.35647 .61357 m .35653 .61636 L .35361 .61422 L F
.504 .214 .407 r
.22359 .57289 m .22296 .57477 L .22055 .57486 L F
.444 .084 .259 r
.22615 .57285 m .22296 .57477 L .22359 .57289 L F
.705 .781 .911 r
.30064 .56928 m .30472 .56977 L .30351 .56832 L F
.971 .757 .557 r
.30351 .56832 m .30472 .56977 L .30298 .56601 L F
.30351 .56832 m .30472 .56977 L .30298 .56601 L F
.496 .288 .527 r
.30817 .55376 m .30497 .55749 L .30448 .55401 L F
.30817 .55376 m .30788 .55689 L .30497 .55749 L F
.545 .393 .626 r
.30784 .55954 m .30497 .55749 L .30788 .55689 L F
.30784 .55954 m .30536 .56036 L .30497 .55749 L F
.497 .489 .779 r
.38231 .56621 m .38346 .56217 L .3811 .56283 L F
.38231 .56621 m .38471 .56598 L .38346 .56217 L F
.187 .265 .713 r
.38231 .56621 m .38487 .56837 L .38471 .56598 L F
.185 0 .338 r
.32455 .61949 m .32509 .61702 L .32682 .61595 L F
.683 .686 .847 r
.22996 .60808 m .23179 .61101 L .22772 .61004 L F
.493 .554 .846 r
.2333 .60878 m .23179 .61101 L .22996 .60808 L F
.2333 .60878 m .23386 .61051 L .23179 .61101 L F
.374 .013 .217 r
.40807 .58163 m .40512 .58344 L .40612 .58255 L F
.782 .805 .871 r
.32128 .66388 m .32436 .66093 L .32415 .66054 L F
.843 .976 .674 r
.34095 .5454 m .33945 .54806 L .33973 .54618 L F
.826 .998 .784 r
.33973 .54618 m .33744 .5488 L .33945 .54806 L F
.353 .147 .455 r
.33686 .62778 m .33902 .62841 L .33918 .62594 L F
.411 .343 .67 r
.33686 .62778 m .33964 .63083 L .33902 .62841 L F
.33686 .62778 m .33767 .6324 L .33964 .63083 L F
.467 .221 .457 r
.27608 .73974 m .27869 .7391 L .27832 .7419 L F
.27608 .73974 m .27869 .7391 L .27832 .7419 L F
.25 .078 .441 r
.36981 .56194 m .36807 .56045 L .37014 .56092 L F
.36981 .56194 m .36807 .56295 L .36807 .56045 L F
.36 .099 .377 r
.2698 .54471 m .26923 .54696 L .27196 .54399 L F
.951 .948 .728 r
.32946 .68295 m .32653 .68549 L .32814 .6822 L F
.32946 .68295 m .32778 .68598 L .32653 .68549 L F
.891 .942 .839 r
.33197 .67983 m .32946 .68295 L .32814 .6822 L F
.553 .54 .794 r
.31743 .66044 m .31886 .66457 L .32128 .66388 L F
0 0 0 r
.30785 .63423 m .31204 .6324 L .31014 .63493 L F
.572 .186 .272 r
.31014 .63493 m .31204 .6324 L .31397 .63414 L F
.578 .185 .261 r
.31204 .6324 m .31473 .63255 L .31397 .63414 L F
.867 .726 .704 r
.34512 .59114 m .34561 .59451 L .34372 .59444 L F
.777 .365 .271 r
.34372 .59444 m .34561 .59451 L .34451 .59656 L F
.259 .289 .703 r
.34777 .59416 m .34561 .59451 L .34524 .59198 L F
.34777 .59416 m .34524 .59198 L .34564 .59174 L F
.744 .825 .362 r
.34512 .59114 m .34372 .59444 L .34409 .59311 L F
.259 .289 .703 r
.34777 .59416 m .34512 .59114 L .34725 .59069 L F
.777 .365 .271 r
.34372 .59444 m .34561 .59451 L .34451 .59656 L F
0 0 .404 r
.34409 .59311 m .34372 .59444 L .34451 .59656 L F
.09 0 0 r
.34451 .59656 m .34561 .59451 L .34777 .59416 L F
.34451 .59656 m .34777 .59416 L .3464 .59636 L F
.184 .223 .669 r
.34409 .59311 m .34451 .59656 L .3464 .59636 L F
.34409 .59311 m .3464 .59636 L .34539 .59234 L F
.215 0 0 r
.34685 .59104 m .34409 .59311 L .34539 .59234 L F
.3466 .59119 m .34409 .59311 L .34686 .59104 L F
.259 .289 .703 r
.34564 .59174 m .34524 .59198 L .34512 .59114 L F
.215 0 0 r
.34725 .59069 m .34512 .59114 L .34409 .59311 L F
.776 .403 .35 r
.34565 .59362 m .34539 .59234 L .34131 .59165 L F
.73 .288 .201 r
.34469 .59297 m .34539 .59234 L .34489 .59305 L F
.619 .649 .857 r
.34542 .59325 m .34565 .59362 L .34424 .59298 L F
.34489 .59305 m .34424 .59298 L .34131 .59165 L F
.34542 .59325 m .34424 .59298 L .34489 .59305 L F
.47 .35 .635 r
.34982 .59314 m .34725 .59069 L .34964 .59019 L F
.34982 .59314 m .34777 .59416 L .34725 .59069 L F
.764 .881 .93 r
.3464 .59636 m .34746 .59404 L .34645 .59322 L F
.34625 .5958 m .34645 .59322 L .34539 .59234 L F
.3464 .59636 m .34645 .59322 L .34625 .5958 L F
.446 .186 .425 r
.34645 .59322 m .34539 .59234 L .34565 .59362 L F
.34917 .59186 m .34539 .59234 L .34645 .59322 L F
.764 .881 .93 r
.34746 .59404 m .34752 .59391 L .34539 .59234 L F
.553 .084 .094 r
.34492 .593 m .34539 .59234 L .3463 .59301 L F
.34565 .59306 m .3463 .59301 L .34646 .59313 L F
.34492 .593 m .3463 .59301 L .34565 .59306 L F
.73 .288 .201 r
.34131 .59165 m .34539 .59234 L .34457 .59307 L F
.34228 .59257 m .34457 .59307 L .34366 .59388 L F
.34131 .59165 m .34457 .59307 L .34228 .59257 L F
.215 0 0 r
.34686 .59104 m .34685 .59104 L .34539 .59234 L F
.197 0 0 r
.34754 .59207 m .34725 .59069 L .34539 .59234 L F
.34917 .59186 m .34881 .59164 L .34754 .59207 L F
.34881 .59164 m .34725 .59069 L .34754 .59207 L F
.759 .702 .798 r
.34565 .59306 m .34565 .59362 L .34531 .59309 L F
.446 .186 .425 r
.34645 .59322 m .34565 .59362 L .3458 .59307 L F
.34646 .59313 m .3458 .59307 L .3467 .58993 L F
.34645 .59322 m .3458 .59307 L .34646 .59313 L F
.619 .649 .857 r
.34214 .58799 m .34531 .59309 L .34131 .59165 L F
.34531 .59309 m .34542 .59325 L .34489 .59305 L F
.553 .084 .094 r
.34489 .59305 m .34492 .593 L .34511 .59307 L F
.619 .649 .857 r
.34531 .59309 m .34489 .59305 L .34131 .59165 L F
.553 .084 .094 r
.34404 .59424 m .34489 .59305 L .34752 .59391 L F
.34489 .59305 m .34511 .59307 L .34752 .59391 L F
.34492 .593 m .34539 .59234 L .34646 .59313 L F
.446 .186 .425 r
.3458 .59307 m .34565 .59362 L .34565 .59306 L F
.553 .084 .094 r
.34492 .593 m .34646 .59313 L .34752 .59391 L F
.759 .702 .798 r
.3457 .58916 m .34566 .5927 L .34214 .58799 L F
.34566 .5927 m .34565 .59306 L .34545 .59277 L F
.34566 .5927 m .34545 .59277 L .34214 .58799 L F
.34565 .59306 m .34531 .59309 L .34214 .58799 L F
.553 .084 .094 r
.34489 .59305 m .34492 .593 L .34657 .59321 L F
.34492 .593 m .34646 .59313 L .34657 .59321 L F
.446 .186 .425 r
.3467 .58993 m .3458 .59307 L .3457 .58916 L F
.3458 .59307 m .34565 .59306 L .3457 .58916 L F
.215 0 0 r
.34725 .59069 m .3466 .59119 L .34686 .59104 L F
.197 0 0 r
.34917 .59186 m .34964 .59019 L .34725 .59069 L F
.446 .186 .425 r
.34917 .59186 m .34645 .59322 L .3467 .58993 L F
.553 .084 .094 r
.34404 .59424 m .34489 .59305 L .34752 .59391 L F
.34489 .59305 m .34657 .59321 L .34752 .59391 L F
.73 .288 .201 r
.34366 .59388 m .34469 .59297 L .34404 .59424 L F
.34469 .59297 m .34489 .59305 L .34404 .59424 L F
.033 0 .447 r
.27585 .62795 m .27425 .6263 L .27497 .62565 L F
.27585 .62795 m .27422 .62987 L .27425 .6263 L F
.849 .744 .747 r
.72905 .34276 m .72708 .34334 L .72921 .33996 L F
.425 .218 .492 r
.72905 .34276 m .72688 .34656 L .72708 .34334 L F
.72905 .34276 m .73032 .34518 L .72688 .34656 L F
.391 .228 .538 r
.73229 .33921 m .72905 .34276 L .72921 .33996 L F
.73229 .33921 m .73247 .34192 L .72905 .34276 L F
.095 .081 .55 r
.73133 .34353 m .72905 .34276 L .73247 .34192 L F
.73133 .34353 m .73032 .34518 L .72905 .34276 L F
.733 .33 .286 r
.30198 .64809 m .29781 .64576 L .30005 .64743 L F
.096 0 .325 r
.29762 .58291 m .29909 .58368 L .29978 .58223 L F
.29762 .58291 m .29762 .58471 L .29909 .58368 L F
.543 .405 .643 r
.35033 .6137 m .35279 .61327 L .35319 .60936 L F
.155 0 0 r
.35059 .6147 m .35033 .6137 L .34964 .61622 L F
.35059 .6147 m .35279 .61327 L .35033 .6137 L F
0 .064 .628 r
.37968 .51742 m .38168 .52107 L .37978 .5189 L F
.769 .388 .335 r
.38307 .6634 m .38776 .66387 L .38516 .66442 L F
.512 .632 .906 r
.38307 .6634 m .38516 .66442 L .38518 .66399 L F
.517 0 0 r
.38422 .664 m .38509 .66397 L .38307 .6634 L F
.38509 .66397 m .38546 .66395 L .38307 .6634 L F
.38546 .66395 m .38684 .66378 L .38307 .6634 L F
.903 .94 .824 r
.38525 .6618 m .38518 .66399 L .38848 .65926 L F
.38518 .66399 m .38516 .66442 L .38546 .66395 L F
.38518 .66399 m .38546 .66395 L .38848 .65926 L F
.517 0 0 r
.38546 .66395 m .38776 .66387 L .38684 .66378 L F
.512 .632 .906 r
.38307 .6634 m .38518 .66399 L .38525 .6618 L F
.37 .402 .763 r
.38776 .66387 m .38848 .65926 L .38546 .66395 L F
.38776 .66387 m .38546 .66395 L .38516 .66442 L F
.517 0 0 r
.38515 .66449 m .38776 .66387 L .38422 .664 L F
.173 0 .246 r
.38995 .6612 m .38946 .66328 L .38776 .66387 L F
.37 .402 .763 r
.38776 .66387 m .38946 .66328 L .38848 .65926 L F
.261 .114 .484 r
.38936 .66597 m .38768 .667 L .38776 .66387 L F
0 0 0 r
.38782 .66483 m .38776 .66387 L .38515 .66449 L F
.261 .114 .484 r
.38936 .66597 m .38776 .66387 L .38946 .66328 L F
0 0 0 r
.38782 .66483 m .38946 .66328 L .38776 .66387 L F
.079 .431 .873 r
.30894 .57139 m .30825 .57236 L .30681 .57188 L F
.30894 .57139 m .31056 .57349 L .30825 .57236 L F
.702 .806 .93 r
.24147 .62986 m .24224 .63007 L .24121 .62835 L F
.129 .452 .883 r
.24121 .62835 m .24224 .63007 L .24232 .6283 L F
.349 .672 .976 r
.24224 .63007 m .24471 .63021 L .24232 .6283 L F
.653 .775 .938 r
.72031 .34312 m .71651 .34237 L .71907 .34142 L F
.464 .6 .902 r
.72199 .34074 m .72031 .34312 L .71907 .34142 L F
.72199 .34074 m .72266 .34273 L .72031 .34312 L F
.831 .493 .415 r
.33729 .69175 m .33334 .6883 L .33701 .68936 L F
.628 .266 .336 r
.3299 .65269 m .33191 .65074 L .32965 .64962 L F
.32965 .64962 m .33191 .65074 L .3299 .65269 L F
.3299 .65269 m .33191 .65074 L .32965 .64962 L F
.636 .895 .986 r
.38456 .57535 m .38305 .5749 L .38548 .57389 L F
.561 .802 .989 r
.3847 .57624 m .38712 .57558 L .38305 .5749 L F
.513 .592 .871 r
.38769 .60432 m .38348 .60141 L .38578 .60284 L F
.529 .738 .971 r
.38853 .60282 m .38769 .60432 L .38578 .60284 L F
.182 .293 .743 r
.38965 .60523 m .38769 .60432 L .38853 .60282 L F
.745 .413 .421 r
.3542 .60331 m .35785 .60431 L .35529 .60285 L F
.461 .404 .707 r
.35146 .54481 m .35359 .54467 L .35302 .54068 L F
.17 0 0 r
.35146 .54481 m .35213 .54576 L .35359 .54467 L F
.35146 .54481 m .35023 .54646 L .35213 .54576 L F
.082 0 .317 r
.37557 .61027 m .37726 .60967 L .37774 .60706 L F
.048 0 .044 r
.37557 .61027 m .37658 .6115 L .37726 .60967 L F
.632 .945 .951 r
.35098 .66982 m .35007 .67132 L .34825 .6707 L F
.35098 .66982 m .35234 .67017 L .35007 .67132 L F
.61 .575 .79 r
.32647 .65711 m .33008 .65807 L .32862 .65428 L F
.382 .397 .751 r
.38597 .60226 m .38578 .60284 L .38348 .60141 L F
.605 .688 .901 r
.23645 .60998 m .23583 .61318 L .23386 .61051 L F
.23645 .60998 m .23823 .6128 L .23583 .61318 L F
0 0 0 r
.29152 .63835 m .29076 .63901 L .29295 .63584 L F
.294 .082 .411 r
.29171 .64158 m .29076 .63901 L .29152 .63835 L F
.29171 .64158 m .29042 .64102 L .29076 .63901 L F
.214 .236 .668 r
.35483 .55925 m .35498 .56345 L .35699 .56117 L F
.464 .447 .754 r
.35541 .56587 m .35699 .56117 L .35498 .56345 L F
.649 .472 .63 r
.21947 .55669 m .21681 .55993 L .218 .55743 L F
.21947 .55669 m .21681 .55993 L .218 .55743 L F
.077 0 .275 r
.19261 .56659 m .19391 .56752 L .19517 .56635 L F
.19261 .56659 m .19196 .5692 L .19391 .56752 L F
.483 .309 .568 r
.36694 .52818 m .36463 .52932 L .36315 .52792 L F
.36694 .52818 m .36693 .53089 L .36463 .52932 L F
.576 .356 .545 r
.3104 .55622 m .30817 .55376 L .31072 .55365 L F
.3104 .55622 m .30788 .55689 L .30817 .55376 L F
0 0 0 r
.39207 .56845 m .38891 .57223 L .39048 .57012 L F
.551 .857 .997 r
.27215 .52617 m .26751 .52571 L .26944 .52566 L F
.509 .861 .991 r
.27488 .52546 m .27215 .52617 L .26944 .52566 L F
.616 .588 .799 r
.35747 .62291 m .35659 .62712 L .35559 .62321 L F
.35747 .62291 m .35933 .62656 L .35659 .62712 L F
.115 0 0 r
.30181 .55522 m .30201 .55575 L .30448 .55401 L F
0 0 .499 r
.30448 .55401 m .30538 .54989 L .30291 .55019 L F
.30448 .55401 m .30571 .55319 L .30538 .54989 L F
0 0 0 r
.30448 .55401 m .30485 .55469 L .30571 .55319 L F
.30448 .55401 m .30201 .55575 L .30485 .55469 L F
.36394 .52276 m .36506 .52148 L .36623 .51981 L F
.874 .881 .447 r
.36623 .51981 m .36554 .51897 L .36511 .51816 L F
.36623 .51981 m .36506 .52148 L .36554 .51897 L F
.343 .815 .904 r
.28306 .62122 m .27811 .62187 L .27988 .62142 L F
.728 .446 .5 r
.3761 .58237 m .37548 .58507 L .37324 .58378 L F
.304 .055 .361 r
.37776 .58386 m .3761 .58237 L .37885 .5816 L F
.37776 .58386 m .37548 .58507 L .3761 .58237 L F
.712 .593 .721 r
.35523 .61959 m .35559 .62321 L .35157 .62337 L F
.412 .368 .699 r
.35747 .62291 m .35559 .62321 L .35523 .61959 L F
.401 .805 .59 r
.35401 .51543 m .35737 .51314 L .3523 .51274 L F
.35401 .51543 m .35614 .51397 L .35737 .51314 L F
.484 .9 .873 r
.35815 .5142 m .35614 .51397 L .35401 .51543 L F
.179 .713 .812 r
.35862 .51379 m .35815 .5142 L .35999 .51358 L F
.35862 .51379 m .35614 .51397 L .35815 .5142 L F
.562 .719 .946 r
.2021 .60069 m .20348 .60105 L .20049 .59844 L F
.369 .639 .959 r
.20049 .59844 m .20348 .60105 L .20417 .59944 L F
.174 .403 .844 r
.20348 .60105 m .20618 .60253 L .20417 .59944 L F
.53 0 0 r
.2419 .6142 m .24427 .61589 L .24613 .6167 L F
.696 .346 .378 r
.22055 .57486 m .21912 .57776 L .21776 .57515 L F
.593 .232 .326 r
.22194 .57716 m .22055 .57486 L .22296 .57477 L F
.22194 .57716 m .21912 .57776 L .22055 .57486 L F
.545 .292 .483 r
.31949 .53717 m .32255 .53463 L .32011 .53546 L F
.648 .091 0 r
.34436 .56173 m .34025 .55914 L .34265 .56207 L F
.34436 .56173 m .34254 .56116 L .34025 .55914 L F
.506 .069 .143 r
.34025 .55914 m .34423 .55994 L .34445 .55713 L F
.34423 .55994 m .34453 .55983 L .34445 .55713 L F
.451 .512 .83 r
.34164 .55608 m .34434 .55974 L .34025 .55914 L F
.79 .95 .924 r
.34303 .5604 m .34254 .56116 L .34427 .56003 L F
.34429 .55992 m .34427 .56003 L .34462 .5598 L F
.34303 .5604 m .34427 .56003 L .34429 .55992 L F
.812 .503 .467 r
.34661 .55886 m .34536 .56017 L .34834 .56023 L F
.34445 .55713 m .34536 .56017 L .34661 .55886 L F
0 0 .047 r
.34445 .55713 m .34493 .55743 L .34481 .55835 L F
.606 .652 .87 r
.34265 .56207 m .34582 .56342 L .34436 .56173 L F
.351 .627 .956 r
.34436 .56173 m .34582 .56342 L .34657 .56178 L F
.34436 .56173 m .34834 .56023 L .34536 .56017 L F
.34436 .56173 m .34657 .56178 L .34834 .56023 L F
.599 .128 .108 r
.34455 .56284 m .34322 .56173 L .34474 .56065 L F
.79 .95 .924 r
.34413 .56012 m .34254 .56116 L .34341 .56143 L F
.599 .128 .108 r
.34322 .56173 m .34254 .56116 L .34387 .56085 L F
.79 .95 .924 r
.34413 .56012 m .34341 .56143 L .34436 .56173 L F
.599 .128 .108 r
.34322 .56173 m .34387 .56085 L .34474 .56065 L F
.79 .95 .924 r
.34519 .55909 m .34444 .56112 L .34536 .56017 L F
.34493 .55743 m .34461 .55986 L .34519 .55909 L F
.34461 .55986 m .34444 .56112 L .34519 .55909 L F
.34444 .56112 m .34436 .56173 L .34536 .56017 L F
0 0 .047 r
.34492 .55742 m .34453 .55983 L .34493 .55743 L F
.34445 .55713 m .34451 .55903 L .34492 .55742 L F
.34451 .55903 m .34453 .55983 L .34492 .55742 L F
.273 .429 .835 r
.34493 .55743 m .34434 .55974 L .34336 .55841 L F
.34478 .55737 m .34336 .55841 L .34164 .55608 L F
.34493 .55743 m .34336 .55841 L .34478 .55737 L F
.34493 .55743 m .34164 .55608 L .34339 .55772 L F
.469 .828 .995 r
.34428 .55599 m .34514 .55654 L .34339 .55772 L F
.34514 .55654 m .34588 .557 L .34495 .55727 L F
.34514 .55654 m .34495 .55727 L .34339 .55772 L F
.451 .512 .83 r
.34434 .55974 m .34423 .55994 L .34025 .55914 L F
.522 .614 .885 r
.34339 .55772 m .34405 .55915 L .34493 .55743 L F
.79 .95 .924 r
.34493 .55743 m .34349 .56022 L .34453 .55983 L F
.34493 .55743 m .34453 .55983 L .34462 .5598 L F
0 0 .047 r
.34453 .55983 m .34454 .56001 L .34493 .55743 L F
.273 .429 .835 r
.34493 .55743 m .34454 .56001 L .34434 .55974 L F
.79 .95 .924 r
.34462 .5598 m .34413 .56012 L .34436 .56173 L F
.506 .069 .143 r
.34423 .55994 m .34454 .56001 L .34453 .55983 L F
.522 .614 .885 r
.34405 .55915 m .34474 .56065 L .34493 .55743 L F
.34493 .55743 m .34474 .56065 L .34339 .55772 L F
.79 .95 .924 r
.34493 .55743 m .34303 .5604 L .34349 .56022 L F
.451 .512 .83 r
.34434 .55974 m .34454 .56001 L .34423 .55994 L F
.835 .595 .577 r
.62625 .43757 m .62244 .43954 L .62474 .43658 L F
.62625 .43757 m .62623 .44038 L .62244 .43954 L F
.468 .295 .563 r
.62883 .43947 m .62623 .44038 L .62625 .43757 L F
.448 0 0 r
.62883 .43947 m .62625 .43757 L .62474 .43658 L F
.531 .4 .647 r
.3922 .65738 m .39275 .66093 L .38995 .6612 L F
.396 .06 .274 r
.39275 .66093 m .38946 .66328 L .38995 .6612 L F
.658 .796 .948 r
.37336 .66272 m .37001 .66268 L .37268 .66116 L F
.731 .982 .91 r
.37539 .66035 m .37336 .66272 L .37268 .66116 L F
.37539 .66035 m .37667 .66061 L .37336 .66272 L F
.891 .942 .839 r
.33197 .67983 m .32814 .6822 L .32991 .67867 L F
0 0 .153 r
.2429 .55372 m .24165 .55605 L .24193 .55393 L F
.599 .404 .589 r
.38267 .62915 m .38013 .63221 L .38004 .62949 L F
.205 .63 .95 r
.37531 .51559 m .37462 .51655 L .37376 .51451 L F
.37531 .51559 m .37734 .51698 L .37462 .51655 L F
.122 0 0 r
.26822 .53843 m .26647 .54011 L .26426 .54065 L F
.085 0 0 r
.26877 .5394 m .26822 .53843 L .27062 .53827 L F
.26877 .5394 m .26647 .54011 L .26822 .53843 L F
.785 .779 .847 r
.35942 .59759 m .3605 .60367 L .36093 .60118 L F
.475 .376 .663 r
.404 .59344 m .40157 .59223 L .40415 .59142 L F
.404 .59344 m .40171 .59488 L .40157 .59223 L F
.169 .025 .429 r
.27811 .62187 m .27796 .62454 L .27497 .62565 L F
.213 0 .287 r
.27774 .62698 m .27497 .62565 L .27796 .62454 L F
.27774 .62698 m .27585 .62795 L .27497 .62565 L F
.669 .722 .889 r
.26265 .53372 m .2648 .53648 L .26713 .53508 L F
.679 .413 .513 r
.32354 .59496 m .32448 .59703 L .32444 .59415 L F
.32354 .59496 m .32281 .59734 L .32448 .59703 L F
.01 .194 .706 r
.34736 .62952 m .34946 .63152 L .35004 .62784 L F
.124 0 .376 r
.32452 .58807 m .32606 .58995 L .32713 .58795 L F
.32452 .58807 m .32464 .59047 L .32606 .58995 L F
.452 0 .063 r
.26283 .54936 m .2652 .54963 L .26699 .54765 L F
.093 0 0 r
.26699 .54765 m .26747 .5488 L .26923 .54696 L F
.26699 .54765 m .2652 .54963 L .26747 .5488 L F
.734 .645 .76 r
.61436 .41502 m .61564 .41868 L .61175 .41859 L F
.695 .362 .409 r
.61175 .41859 m .61564 .41868 L .61588 .42086 L F
.755 .655 .751 r
.61824 .41566 m .61564 .41868 L .61436 .41502 L F
.685 .355 .41 r
.61564 .41868 m .61867 .42101 L .61588 .42086 L F
.673 .529 .681 r
.61824 .41566 m .61876 .4188 L .61564 .41868 L F
.654 .377 .488 r
.61564 .41868 m .61876 .4188 L .61867 .42101 L F
.029 .582 .825 r
.26339 .63457 m .26344 .63422 L .26158 .63364 L F
.581 .485 .71 r
.3419 .52923 m .34135 .53161 L .33897 .53158 L F
.562 .719 .946 r
.2021 .60069 m .20049 .59844 L .19773 .59948 L F
.007 0 0 r
.34091 .60649 m .34177 .60487 L .34378 .60365 L F
.604 .807 .978 r
.30401 .52223 m .29996 .52171 L .30229 .52081 L F
.602 .781 .966 r
.30611 .52125 m .30401 .52223 L .30229 .52081 L F
.464 .882 .927 r
.29146 .52378 m .29162 .52283 L .29332 .52293 L F
.29146 .52378 m .28925 .52368 L .29162 .52283 L F
.59 .43 .633 r
.3508 .56223 m .34834 .56023 L .35099 .55972 L F
.105 0 0 r
.34657 .56178 m .35099 .55972 L .34834 .56023 L F
.334 .495 .869 r
.32213 .65707 m .32179 .65854 L .3193 .6557 L F
.293 .006 .294 r
.30332 .54274 m .30264 .54194 L .30722 .54382 L F
.663 .843 .969 r
.30471 .54189 m .30332 .54274 L .30722 .54382 L F
.388 .06 .283 r
.30471 .54189 m .30366 .54313 L .30332 .54274 L F
.30366 .54313 m .30207 .545 L .30332 .54274 L F
.293 .006 .294 r
.30332 .54274 m .3017 .54156 L .30264 .54194 L F
.30332 .54274 m .30128 .54349 L .3017 .54156 L F
.312 0 .233 r
.71807 .33689 m .71551 .33731 L .71883 .33724 L F
0 0 .408 r
.71883 .33724 m .72014 .33651 L .71807 .33689 L F
.278 .472 .87 r
.72292 .33166 m .72473 .33482 L .7216 .33333 L F
.524 .353 .591 r
.72002 .33653 m .72433 .33539 L .72292 .33166 L F
.71997 .33662 m .72003 .3366 L .72002 .33653 L F
.72003 .3366 m .72433 .33539 L .72002 .33653 L F
.461 .165 .375 r
.72014 .33651 m .72433 .33539 L .72003 .3366 L F
0 0 .408 r
.72003 .33658 m .72003 .3366 L .72014 .33651 L F
.461 .165 .375 r
.72014 .33651 m .72003 .3366 L .71997 .33662 L F
0 0 .408 r
.72003 .3366 m .72038 .33954 L .72014 .33651 L F
.71883 .33724 m .72027 .33937 L .72003 .33658 L F
.72027 .33937 m .72038 .33954 L .72003 .33658 L F
.774 .672 .75 r
.35742 .57253 m .35555 .57692 L .35348 .57224 L F
.082 0 0 r
.38683 .55957 m .38346 .56217 L .38438 .56038 L F
.758 .596 .677 r
.38683 .55957 m .38346 .56217 L .38438 .56038 L F
.146 .637 .916 r
.36261 .5103 m .36556 .51055 L .36729 .51149 L F
.178 .638 .937 r
.36556 .51055 m .36953 .51227 L .36729 .51149 L F
0 0 .219 r
.34686 .66692 m .34666 .66972 L .34423 .6668 L F
.34683 .66734 m .34718 .66873 L .34666 .66972 L F
.741 .244 .051 r
.34661 .66859 m .34733 .6693 L .34718 .66873 L F
0 0 0 r
.34893 .6709 m .35098 .66982 L .34825 .6707 L F
.34893 .6709 m .34825 .6707 L .34718 .66873 L F
.741 .244 .051 r
.34733 .6693 m .34893 .6709 L .34718 .66873 L F
0 0 .219 r
.34686 .66692 m .34718 .66873 L .34683 .66734 L F
0 .239 .756 r
.34718 .66873 m .34825 .6707 L .34666 .66972 L F
.751 .666 .768 r
.61683 .41188 m .61824 .41566 L .61436 .41502 L F
.713 .647 .782 r
.62071 .4129 m .61824 .41566 L .61683 .41188 L F
.682 .314 .342 r
.61824 .41566 m .6217 .41798 L .61876 .4188 L F
.65 .762 .931 r
.40181 .58349 m .40319 .5853 L .40512 .58344 L F
0 .121 .66 r
.40371 .5833 m .40319 .5853 L .39993 .58734 L F
.40371 .5833 m .40508 .5873 L .40319 .5853 L F
.336 .201 .544 r
.40508 .5873 m .40322 .58807 L .40319 .5853 L F
.40508 .5873 m .40322 .58807 L .40319 .5853 L F
.495 .369 .638 r
.35972 .57171 m .35716 .57204 L .35966 .56876 L F
.35972 .57171 m .35742 .57253 L .35716 .57204 L F
.768 .65 .731 r
.38267 .62915 m .38383 .63322 L .38013 .63221 L F
.576 .535 .772 r
.38633 .63252 m .38383 .63322 L .38267 .62915 L F
.517 .357 .603 r
.38633 .63252 m .38403 .63555 L .38383 .63322 L F
.753 .776 .872 r
.36745 .63247 m .36339 .6326 L .36568 .63075 L F
.519 .707 .956 r
.36568 .63075 m .36745 .63247 L .36887 .63057 L F
.36568 .63075 m .36745 .63247 L .36887 .63057 L F
0 0 0 r
.33276 .66283 m .33153 .66374 L .32949 .66697 L F
.664 .314 .369 r
.32949 .66697 m .33153 .66374 L .32782 .66585 L F
.566 .542 .787 r
.30046 .56655 m .30149 .56251 L .30001 .5626 L F
0 0 0 r
.36394 .52276 m .36377 .52337 L .36506 .52148 L F
.36394 .52276 m .36306 .52532 L .36377 .52337 L F
.19 0 .287 r
.21475 .54781 m .21586 .54919 L .21666 .547 L F
.21475 .54781 m .21409 .5501 L .21586 .54919 L F
.165 .678 .895 r
.14215 .70654 m .14197 .70701 L .13985 .70726 L F
.14215 .70654 m .14468 .70715 L .14197 .70701 L F
.14197 .70701 m .14215 .70654 L .13985 .70726 L F
.14197 .70701 m .14468 .70715 L .14215 .70654 L F
.178 .638 .937 r
.36556 .51055 m .36771 .51075 L .36953 .51227 L F
.587 .887 .991 r
.36953 .51227 m .36771 .51075 L .36982 .51117 L F
.134 .415 .86 r
.36982 .51117 m .37071 .51336 L .36953 .51227 L F
.419 .864 .803 r
.33178 .53103 m .33329 .53014 L .33562 .52938 L F
.33178 .53103 m .33085 .53116 L .33329 .53014 L F
.293 .45 .846 r
.33642 .55456 m .33876 .55567 L .33731 .55716 L F
.556 .561 .814 r
.33876 .55567 m .33772 .55959 L .33731 .55716 L F
.721 .953 .95 r
.29996 .52171 m .29775 .52321 L .29583 .5225 L F
.412 .368 .699 r
.35747 .62291 m .35523 .61959 L .35697 .61872 L F
.683 .46 .577 r
.72342 .29898 m .7211 .30205 L .71996 .2987 L F
.72342 .29898 m .72378 .30162 L .7211 .30205 L F
.55 .388 .615 r
.72617 .29563 m .72697 .2986 L .72342 .29898 L F
.474 .146 .329 r
.72342 .29898 m .72551 .30149 L .72378 .30162 L F
.72551 .30149 m .72547 .30174 L .72378 .30162 L F
.72342 .29898 m .72697 .2986 L .72637 .30014 L F
.748 .751 .855 r
.72888 .29989 m .72572 .30297 L .72897 .29991 L F
.474 .146 .329 r
.72555 .30143 m .72637 .30014 L .72594 .30125 L F
.72342 .29898 m .72637 .30014 L .72551 .30149 L F
.161 0 .182 r
.72639 .30086 m .72697 .2986 L .72885 .29747 L F
.748 .751 .855 r
.72555 .30143 m .72572 .30297 L .7288 .29997 L F
.161 0 .182 r
.72639 .30086 m .72885 .29747 L .72897 .29991 L F
.748 .751 .855 r
.72834 .30014 m .7288 .29997 L .72888 .29989 L F
.72555 .30143 m .7288 .29997 L .72834 .30014 L F
.161 0 .182 r
.72574 .30176 m .72639 .30086 L .72897 .29991 L F
.72574 .30176 m .72594 .30125 L .72639 .30086 L F
.72594 .30125 m .72697 .2986 L .72639 .30086 L F
.748 .751 .855 r
.7253 .29925 m .72555 .30143 L .72594 .30125 L F
.72774 .29968 m .72594 .30125 L .72888 .29989 L F
.7253 .29925 m .72594 .30125 L .72774 .29968 L F
.474 .146 .329 r
.72551 .30149 m .72555 .30143 L .72574 .30176 L F
.72555 .30143 m .72594 .30125 L .72574 .30176 L F
.941 .964 .704 r
.72547 .30174 m .72507 .30342 L .72378 .30162 L F
.72507 .30342 m .72474 .30444 L .72378 .30162 L F
.49 .277 .517 r
.72378 .30162 m .72479 .30458 L .72113 .3048 L F
.39 .309 .644 r
.72358 .30608 m .72113 .3048 L .72479 .30458 L F
.931 .926 .781 r
.72358 .30608 m .72477 .30435 L .72454 .30184 L F
.72477 .30435 m .72572 .30297 L .72533 .3026 L F
.72477 .30435 m .72533 .3026 L .72454 .30184 L F
.941 .964 .704 r
.72507 .30342 m .72479 .30458 L .72474 .30444 L F
.983 .882 .648 r
.72547 .30174 m .72572 .30297 L .72554 .30135 L F
.72533 .3026 m .72572 .30297 L .72547 .30174 L F
.941 .964 .704 r
.72574 .30176 m .72521 .30333 L .72547 .30174 L F
.949 .917 .746 r
.72479 .30458 m .72572 .30297 L .72533 .3026 L F
.941 .964 .704 r
.72533 .3026 m .72479 .30458 L .72547 .30174 L F
.638 .447 .609 r
.72479 .30458 m .72572 .30297 L .72358 .30608 L F
.949 .917 .746 r
.72479 .30458 m .72533 .3026 L .72454 .30184 L F
.941 .964 .704 r
.72521 .30333 m .72479 .30458 L .72533 .3026 L F
.983 .882 .648 r
.72533 .3026 m .72533 .3026 L .72547 .30174 L F
.72454 .30184 m .72501 .30229 L .7253 .29925 L F
.72501 .30229 m .72533 .3026 L .72532 .30179 L F
.72501 .30229 m .72532 .30179 L .7253 .29925 L F
.72533 .3026 m .72554 .30135 L .7253 .29925 L F
.474 .146 .329 r
.72551 .30149 m .72574 .30176 L .72547 .30174 L F
.176 0 0 r
.21205 .55082 m .20841 .55289 L .21056 .55225 L F
.011 0 0 r
.21056 .55225 m .21409 .5501 L .21205 .55082 L F
.415 0 .11 r
.31844 .61602 m .32293 .61293 L .32065 .61359 L F
.768 .985 .904 r
.37728 .65868 m .37896 .65877 L .37667 .66061 L F
.774 .988 .894 r
.37728 .65868 m .37667 .66061 L .37539 .66035 L F
.204 .364 .802 r
.72013 .32995 m .72292 .33166 L .7216 .33333 L F
0 0 0 r
.29355 .59482 m .29118 .5979 L .29227 .59711 L F
.006 0 .496 r
.29227 .59711 m .29118 .5979 L .29237 .59957 L F
.162 .036 .449 r
.29118 .5979 m .29104 .60077 L .29237 .59957 L F
.439 .307 .604 r
.38916 .68832 m .38974 .69148 L .3871 .69218 L F
.456 .269 .537 r
.38974 .69148 m .38676 .6949 L .3871 .69218 L F
0 .3 .763 r
.36187 .60728 m .35785 .60431 L .3605 .60367 L F
.478 .877 .714 r
.35815 .60949 m .36187 .60728 L .36071 .60893 L F
.104 .247 .728 r
.36193 .60356 m .36187 .60728 L .3605 .60367 L F
.36193 .60356 m .36327 .60623 L .36187 .60728 L F
.514 .817 .489 r
.36327 .60623 m .36071 .60893 L .36187 .60728 L F
.52 .193 .353 r
.36555 .59516 m .36896 .59482 L .3678 .59677 L F
.196 .266 .709 r
.36741 .59446 m .36555 .59516 L .3678 .59677 L F
.103 0 .241 r
.29487 .63441 m .29295 .63584 L .29529 .6325 L F
.004 0 .093 r
.29152 .63835 m .29295 .63584 L .29487 .63441 L F
0 .168 .653 r
.36982 .51117 m .37376 .51451 L .37071 .51336 L F
.691 .529 .662 r
.38374 .53793 m .37935 .54109 L .37909 .53801 L F
.056 .28 .771 r
.32664 .58213 m .3292 .58415 L .32739 .58047 L F
.281 0 0 r
.72156 .34942 m .72089 .35026 L .71777 .34969 L F
.468 0 0 r
.7244 .35068 m .72089 .35026 L .72156 .34942 L F
.616 .478 .671 r
.72431 .34635 m .72441 .3493 L .72156 .34942 L F
.507 .109 .221 r
.72441 .3493 m .7244 .35068 L .72156 .34942 L F
.25 .11 .487 r
.36597 .62622 m .36507 .62994 L .36195 .62581 L F
.36597 .62622 m .36596 .63064 L .36507 .62994 L F
.501 .3 .539 r
.36597 .62622 m .36838 .62573 L .36854 .62305 L F
.36597 .62622 m .36838 .62573 L .36854 .62305 L F
.404 .244 .548 r
.31162 .57829 m .30949 .5817 L .30964 .57906 L F
.729 .932 .956 r
.36527 .53249 m .36593 .53521 L .36693 .53089 L F
.884 .639 .563 r
.61026 .40927 m .60761 .41063 L .60889 .40796 L F
.61026 .40927 m .61041 .41198 L .60761 .41063 L F
.823 .758 .791 r
.61204 .40619 m .61026 .40927 L .60889 .40796 L F
.649 .525 .699 r
.61204 .40619 m .6131 .40874 L .61026 .40927 L F
.745 .609 .707 r
.6131 .40874 m .61041 .41198 L .61026 .40927 L F
.119 0 .135 r
.29285 .6127 m .29108 .61361 L .29387 .61064 L F
0 0 0 r
.29574 .60962 m .29285 .6127 L .29387 .61064 L F
.997 .771 .428 r
.32331 .60028 m .32264 .6036 L .32166 .60103 L F
.803 .498 .473 r
.32331 .60028 m .32356 .60337 L .32264 .6036 L F
.32331 .60028 m .32404 .60089 L .32356 .60337 L F
0 0 .535 r
.32281 .59734 m .32331 .60028 L .32442 .59898 L F
.528 .896 .696 r
.32442 .59898 m .32331 .60028 L .32166 .60103 L F
.231 0 0 r
.33314 .63549 m .33575 .63509 L .33136 .63534 L F
.763 .353 .275 r
.33679 .63771 m .33575 .63509 L .33314 .63549 L F
.142 .587 .928 r
.38527 .52371 m .38721 .52399 L .38724 .52496 L F
0 .172 .7 r
.38721 .52399 m .38941 .52684 L .38724 .52496 L F
.86 .804 .794 r
.34903 .5192 m .34484 .52094 L .34701 .51803 L F
.34903 .5192 m .34649 .52239 L .34484 .52094 L F
.719 .848 .943 r
.35197 .51716 m .34903 .5192 L .34701 .51803 L F
.606 .553 .769 r
.35197 .51716 m .35194 .51877 L .34903 .5192 L F
0 .353 .749 r
.3603 .54001 m .36147 .54061 L .36161 .54093 L F
.81 .927 .912 r
.36373 .54046 m .36165 .54102 L .36161 .54093 L F
.09 0 0 r
.36373 .54046 m .36161 .54093 L .36591 .54039 L F
.456 0 .005 r
.36161 .54093 m .36418 .54201 L .36591 .54039 L F
0 .353 .749 r
.36147 .54061 m .36418 .54201 L .36161 .54093 L F
.81 .927 .912 r
.36165 .54102 m .35968 .54156 L .36161 .54093 L F
.426 .409 .737 r
.22325 .61601 m .22512 .61607 L .22426 .61365 L F
0 0 .39 r
.30262 .60289 m .30147 .60402 L .30208 .60059 L F
0 0 0 r
.3008 .60612 m .30147 .60402 L .30262 .60289 L F
.42 .188 .454 r
.23064 .56852 m .22845 .5692 L .22944 .56685 L F
.876 .891 .84 r
.37114 .61997 m .36854 .62305 L .36688 .62205 L F
.987 .744 .477 r
.36665 .62455 m .36838 .62573 L .36854 .62305 L F
.572 .671 .906 r
.36838 .62573 m .36886 .62326 L .36854 .62305 L F
.987 .744 .477 r
.36665 .62455 m .36854 .62305 L .36886 .62326 L F
.573 .502 .737 r
.22647 .60622 m .22409 .6071 L .22339 .60465 L F
.61 .954 .828 r
.27828 .52417 m .27865 .52321 L .28063 .52393 L F
.27828 .52417 m .27673 .52459 L .27865 .52321 L F
.717 .968 .936 r
.33762 .66881 m .34212 .66722 L .34296 .66885 L F
.551 0 0 r
.34212 .66722 m .34263 .66829 L .34296 .66885 L F
.34212 .66722 m .34409 .66872 L .34263 .66829 L F
.675 .134 0 r
.32617 .5203 m .32361 .5198 L .32379 .5201 L F
.733 .726 .844 r
.39688 .59332 m .39865 .59257 L .39623 .5934 L F
.72 .286 .218 r
.39897 .59303 m .39745 .5929 L .39801 .59316 L F
.39897 .59303 m .39801 .59316 L .40171 .59488 L F
.69 .907 .972 r
.3962 .5936 m .39745 .5929 L .39865 .59257 L F
.72 .286 .218 r
.39897 .59303 m .4024 .59617 L .39745 .5929 L F
.404 .59344 m .39897 .59303 L .40171 .59488 L F
.404 .59344 m .40372 .59392 L .39897 .59303 L F
.40372 .59392 m .4024 .59617 L .39897 .59303 L F
.733 .726 .844 r
.39638 .59254 m .39865 .59257 L .39699 .58904 L F
.39623 .5934 m .39791 .59283 L .39638 .59254 L F
.39791 .59283 m .39865 .59257 L .39638 .59254 L F
.3962 .5936 m .39688 .59332 L .39623 .5934 L F
.555 .663 .909 r
.647 .4007 m .64456 .40263 L .64373 .39939 L F
.647 .4007 m .647 .40204 L .64456 .40263 L F
.095 0 0 r
.647 .40204 m .64359 .40387 L .64456 .40263 L F
0 .174 .708 r
.30374 .65423 m .30684 .65796 L .30525 .65683 L F
0 0 .479 r
.30377 .65281 m .30374 .65423 L .30525 .65683 L F
.576 .367 .56 r
.36507 .62994 m .36084 .63285 L .35952 .62888 L F
.36507 .62994 m .36339 .6326 L .36084 .63285 L F
.479 .301 .561 r
.39431 .68241 m .39152 .68602 L .39217 .68375 L F
.876 .891 .84 r
.37114 .61997 m .36688 .62205 L .36864 .62269 L F
.335 .297 .667 r
.37114 .61997 m .37354 .622 L .37277 .61922 L F
.061 .261 .753 r
.37249 .61907 m .37354 .622 L .37114 .61997 L F
.37249 .61907 m .37114 .61997 L .36864 .62269 L F
.121 0 .274 r
.32356 .60337 m .32404 .60089 L .32528 .60045 L F
.469 .845 .616 r
.32404 .60089 m .32748 .59831 L .32528 .60045 L F
0 0 0 r
.12771 .73617 m .13005 .73564 L .12785 .73611 L F
.658 .378 .485 r
.25775 .55133 m .26031 .54969 L .25871 .54915 L F
.013 .587 .749 r
.25871 .54915 m .26105 .54922 L .26283 .54936 L F
.658 .378 .485 r
.26031 .54969 m .26105 .54922 L .25871 .54915 L F
.271 0 0 r
.25629 .54833 m .25871 .54915 L .26063 .54959 L F
.25625 .54832 m .25871 .54915 L .25629 .54833 L F
.641 .607 .799 r
.22996 .60808 m .22772 .61004 L .22647 .60622 L F
.369 .29 .634 r
.19062 .57257 m .19241 .57191 L .19196 .5692 L F
.287 .14 .5 r
.19062 .57257 m .19222 .57454 L .19241 .57191 L F
.19062 .57257 m .19054 .57534 L .19222 .57454 L F
.26 .045 .386 r
.34618 .55141 m .34772 .55228 L .34969 .55061 L F
.717 .943 .638 r
.35046 .54911 m .34772 .55228 L .34969 .55061 L F
.056 .218 .716 r
.35046 .54911 m .35181 .55289 L .34969 .55061 L F
.702 .806 .93 r
.24147 .62986 m .24121 .62835 L .23786 .62743 L F
.785 .997 .803 r
.34096 .62143 m .33951 .62273 L .33955 .6214 L F
0 .17 .707 r
.34194 .62086 m .34096 .62143 L .33955 .6214 L F
.34194 .62086 m .34291 .62262 L .34096 .62143 L F
.699 .278 .242 r
.40181 .58349 m .39658 .58397 L .39932 .58162 L F
0 0 0 r
.32341 .55369 m .32495 .55258 L .32629 .5516 L F
.471 .24 .482 r
.32223 .55515 m .32495 .55258 L .32341 .55369 L F
.514 .857 .994 r
.71797 .34063 m .72004 .34005 L .72199 .34074 L F
.72004 .34005 m .72148 .33965 L .72171 .34014 L F
.72004 .34005 m .72171 .34014 L .72199 .34074 L F
.775 .421 .385 r
.72277 .34019 m .72204 .34015 L .72117 .33983 L F
.72091 .33968 m .72117 .33983 L .72038 .33954 L F
.72277 .34019 m .72117 .33983 L .72091 .33968 L F
0 .444 .863 r
.72148 .33965 m .72268 .3406 L .72256 .34062 L F
.72171 .34014 m .72256 .34062 L .72199 .34074 L F
.72148 .33965 m .72256 .34062 L .72171 .34014 L F
0 .177 .61 r
.71523 .33884 m .71907 .34142 L .71651 .34237 L F
.718 .3407 m .71797 .34063 L .71907 .34142 L F
.71523 .33884 m .71797 .34063 L .718 .3407 L F
.792 .715 .779 r
.71651 .34237 m .71262 .34203 L .71523 .33884 L F
.098 .652 .705 r
.71379 .34119 m .71797 .34063 L .71666 .34034 L F
.069 .559 .894 r
.71742 .3407 m .71794 .34057 L .71797 .34063 L F
.71794 .34057 m .72004 .34005 L .71797 .34063 L F
.51 .29 .515 r
.71666 .34034 m .71797 .34063 L .71523 .33884 L F
.775 .421 .385 r
.72529 .33687 m .72353 .33919 L .72038 .33954 L F
.72353 .33919 m .72277 .34019 L .72121 .33976 L F
.72353 .33919 m .72121 .33976 L .72038 .33954 L F
.72277 .34019 m .72263 .34037 L .72204 .34015 L F
.7 .653 .8 r
.72038 .33954 m .72263 .34037 L .72317 .33659 L F
.069 .559 .894 r
.71728 .34072 m .72148 .33965 L .72004 .34005 L F
.71728 .34072 m .72004 .34005 L .71742 .3407 L F
.404 .561 .896 r
.72664 .33464 m .72529 .33687 L .72473 .33482 L F
.655 .86 .474 r
.72664 .33464 m .72263 .34037 L .72529 .33687 L F
.741 .651 .76 r
.72688 .34656 m .72431 .34635 L .72708 .34334 L F
.548 .298 .489 r
.72688 .34656 m .72441 .3493 L .72431 .34635 L F
.72688 .34656 m .72737 .34879 L .72441 .3493 L F
.406 .196 .479 r
.73032 .34518 m .72737 .34879 L .72688 .34656 L F
.49 .326 .585 r
.18866 .59587 m .19038 .5956 L .19013 .59166 L F
.297 .292 .685 r
.19002 .58817 m .19013 .59166 L .19227 .59029 L F
.057 .005 .476 r
.19013 .59166 m .19197 .59284 L .19227 .59029 L F
.19013 .59166 m .19038 .5956 L .19197 .59284 L F
0 0 0 r
.28891 .61521 m .29108 .61361 L .29285 .6127 L F
.616 .594 .805 r
.26023 .62289 m .25633 .61988 L .25829 .62003 L F
.7 .727 .871 r
.26319 .62101 m .26023 .62289 L .25829 .62003 L F
.699 .962 .943 r
.26142 .62222 m .26023 .62289 L .26319 .62101 L F
.223 0 0 r
.27934 .54685 m .27792 .54854 L .2755 .54892 L F
.042 0 0 r
.28207 .54579 m .27934 .54685 L .28263 .54484 L F
.556 .22 .355 r
.28207 .54579 m .27792 .54854 L .27934 .54685 L F
.576 .586 .825 r
.32803 .60939 m .32961 .61314 L .32711 .61358 L F
.478 .197 .408 r
.32711 .61358 m .32904 .61514 L .32682 .61595 L F
.32711 .61358 m .32961 .61314 L .32904 .61514 L F
.727 .211 0 r
.32653 .68549 m .32778 .68598 L .32943 .68813 L F
.328 .32 .697 r
.22493 .60273 m .22339 .60465 L .22268 .60071 L F
.573 .502 .737 r
.22647 .60622 m .22339 .60465 L .22493 .60273 L F
.949 .711 .543 r
.34263 .6985 m .3405 .7005 L .34044 .69786 L F
.34263 .6985 m .34242 .70117 L .3405 .7005 L F
.461 .072 .214 r
.23605 .56092 m .23326 .56207 L .23341 .56166 L F
.169 .302 .757 r
.4091 .5779 m .40868 .57926 L .40722 .57506 L F
0 0 0 r
.4091 .5779 m .40807 .58163 L .40868 .57926 L F
.762 .554 .616 r
.33185 .57187 m .33096 .57482 L .32774 .57491 L F
.115 0 .278 r
.33418 .56986 m .33096 .57482 L .33185 .57187 L F
.374 .148 .437 r
.3379 .64809 m .3353 .6513 L .33759 .6506 L F
.704 .326 .329 r
.36306 .70784 m .36701 .70821 L .36684 .70992 L F
.624 .304 .409 r
.37066 .70767 m .36684 .70992 L .36701 .70821 L F
.76 .574 .645 r
.34682 .53089 m .34804 .52849 L .34637 .52776 L F
.34682 .53089 m .34772 .53174 L .34804 .52849 L F
.888 .949 .842 r
.34804 .52849 m .34833 .52653 L .34637 .52776 L F
.34804 .52849 m .34953 .52509 L .34833 .52653 L F
.66 .484 .635 r
.34804 .52849 m .34772 .53174 L .35104 .53145 L F
.775 .396 .337 r
.29525 .65038 m .29924 .65097 L .29741 .65321 L F
.065 0 0 r
.29924 .65097 m .3018 .65086 L .29741 .65321 L F
.29924 .65097 m .30166 .65081 L .3018 .65086 L F
.117 0 .069 r
.29355 .59482 m .29469 .59505 L .29542 .59382 L F
.29355 .59482 m .29227 .59711 L .29469 .59505 L F
.674 .61 .775 r
.36195 .62581 m .35952 .62888 L .35933 .62656 L F
.36195 .62581 m .36507 .62994 L .35952 .62888 L F
.08 0 0 r
.23439 .53405 m .23466 .53569 L .23675 .53348 L F
.23439 .53405 m .23264 .53656 L .23466 .53569 L F
0 0 0 r
.31835 .52857 m .31716 .53064 L .31544 .5317 L F
.928 .708 .586 r
.24189 .61135 m .2419 .6142 L .24099 .61242 L F
.24189 .61135 m .24427 .61589 L .2419 .6142 L F
.951 .736 .577 r
.3633 .66293 m .36392 .66067 L .36229 .65999 L F
.376 .584 .924 r
.23786 .62743 m .23831 .62519 L .23675 .62541 L F
.23786 .62743 m .24121 .62835 L .23831 .62519 L F
.167 .628 .934 r
.3477 .51288 m .34601 .51186 L .34401 .5117 L F
0 0 .261 r
.3477 .51288 m .34786 .51212 L .34601 .51186 L F
.3477 .51288 m .34878 .51738 L .34786 .51212 L F
.061 .135 .628 r
.38589 .58197 m .38649 .58475 L .38855 .58301 L F
.405 .309 .633 r
.38649 .58475 m .38974 .58579 L .38855 .58301 L F
.38649 .58475 m .38693 .58763 L .38974 .58579 L F
.898 .576 .431 r
.37916 .52771 m .37611 .52748 L .37617 .52443 L F
.891 .985 .716 r
.37916 .52771 m .3764 .53038 L .37611 .52748 L F
0 0 .294 r
.37985 .58056 m .37885 .5816 L .37912 .57901 L F
0 0 0 r
.26157 .55303 m .25774 .55619 L .25826 .55419 L F
.18 .379 .823 r
.3542 .60331 m .35678 .60513 L .35785 .60431 L F
.292 0 0 r
.35678 .60513 m .3605 .60367 L .35785 .60431 L F
.149 0 0 r
.29852 .53573 m .30062 .53614 L .2991 .53586 L F
.869 .861 .83 r
.29615 .53638 m .29803 .53561 L .29852 .53573 L F
.08 .635 .811 r
.29852 .53573 m .29677 .53544 L .29454 .53543 L F
.149 0 0 r
.29852 .53573 m .2991 .53586 L .29677 .53544 L F
.869 .861 .83 r
.29803 .53561 m .29967 .53494 L .29852 .53573 L F
.081 .547 .903 r
.30183 .5372 m .29967 .53494 L .30288 .53487 L F
.189 .523 .919 r
.38276 .52136 m .38228 .52272 L .38168 .52107 L F
.38276 .52136 m .38527 .52371 L .38228 .52272 L F
.649 .708 .89 r
.36927 .66143 m .37268 .66116 L .37001 .66268 L F
.67 .459 .591 r
.35727 .55695 m .35711 .55979 L .35483 .55925 L F
.35727 .55695 m .35711 .55979 L .35483 .55925 L F
.299 .272 .66 r
.35838 .55279 m .35727 .55695 L .35686 .55435 L F
.35838 .55279 m .35911 .55631 L .35727 .55695 L F
.291 .251 .639 r
.35911 .55631 m .35927 .55878 L .35727 .55695 L F
.33 .679 .978 r
.32573 .57498 m .32702 .57395 L .32387 .572 L F
.32573 .57498 m .32774 .57491 L .32702 .57395 L F
.478 .212 .431 r
.28238 .63557 m .28494 .63514 L .28528 .63278 L F
.335 .091 .389 r
.28528 .63278 m .28699 .63434 L .28793 .63179 L F
.28528 .63278 m .28494 .63514 L .28699 .63434 L F
.627 .818 .402 r
.72882 .34057 m .72708 .34334 L .7284 .34114 L F
.756 .977 .919 r
.72708 .34334 m .72611 .34284 L .7284 .34114 L F
.824 .346 .039 r
.72268 .34098 m .72611 .34284 L .72266 .34273 L F
.72365 .34123 m .72611 .34284 L .72268 .34098 L F
.72268 .3406 m .72365 .34123 L .72345 .34118 L F
.72268 .3406 m .72345 .34118 L .72268 .34098 L F
.807 .581 .595 r
.72148 .33965 m .72158 .33975 L .72268 .3406 L F
.824 .346 .039 r
.72268 .3406 m .72266 .34273 L .72199 .34074 L F
.807 .581 .595 r
.72158 .33975 m .72459 .34278 L .72268 .3406 L F
.824 .346 .039 r
.72268 .3406 m .72459 .34278 L .72611 .34284 L F
.704 .347 .368 r
.72459 .34278 m .72755 .34151 L .72611 .34284 L F
.72755 .34151 m .7284 .34114 L .72729 .34197 L F
.72755 .34151 m .72729 .34197 L .72611 .34284 L F
.72651 .34196 m .728 .34233 L .7284 .34114 L F
0 0 .372 r
.72784 .34278 m .72809 .34156 L .7284 .34114 L F
.627 .818 .402 r
.72921 .33996 m .72882 .34057 L .7284 .34114 L F
.583 .821 .99 r
.72921 .33996 m .73076 .33784 L .73229 .33921 L F
0 0 0 r
.72921 .33996 m .7284 .34114 L .73076 .33784 L F
.873 .992 .75 r
.73076 .33784 m .7284 .34114 L .72866 .33875 L F
0 0 .372 r
.72784 .34278 m .7286 .34177 L .72865 .33954 L F
.72809 .34156 m .72866 .33875 L .7284 .34114 L F
.72842 .33994 m .72865 .33954 L .72866 .33875 L F
.72784 .34278 m .72865 .33954 L .72842 .33994 L F
.704 .347 .368 r
.72459 .34278 m .72784 .34278 L .728 .34233 L F
.72459 .34278 m .728 .34233 L .72651 .34196 L F
.473 .895 .86 r
.31431 .53803 m .31229 .53832 L .31449 .53739 L F
0 0 0 r
.2865 .54023 m .28534 .54134 L .2879 .53861 L F
0 0 .129 r
.2865 .54023 m .28457 .54353 L .28534 .54134 L F
.645 .327 .419 r
.36417 .62224 m .36688 .62205 L .36473 .61964 L F
.149 .212 .674 r
.25678 .61562 m .25633 .61988 L .25468 .61631 L F
.25678 .61562 m .25811 .61957 L .25633 .61988 L F
.352 .341 .708 r
.25924 .61778 m .25811 .61957 L .25678 .61562 L F
.937 .651 .473 r
.25541 .61685 m .25811 .61957 L .25678 .61562 L F
.352 .341 .708 r
.25924 .61778 m .25811 .61957 L .25678 .61562 L F
.726 .728 .852 r
.25276 .61792 m .25811 .61957 L .25541 .61685 L F
.712 .42 .482 r
.25424 .62043 m .25811 .61957 L .25276 .61792 L F
.186 .606 .943 r
.25811 .61957 m .25793 .62 L .25633 .61988 L F
.712 .42 .482 r
.25424 .62043 m .25674 .62137 L .25811 .61957 L F
.671 .877 .5 r
.25811 .61957 m .25674 .62137 L .25828 .61917 L F
.25811 .61957 m .25828 .61917 L .25924 .61778 L F
.186 .606 .943 r
.25811 .61957 m .25829 .62003 L .25793 .62 L F
.061 .135 .628 r
.38589 .58197 m .38855 .58301 L .38958 .58141 L F
.531 .212 .372 r
.72218 .29459 m .72505 .29406 L .7223 .29272 L F
.08 0 .264 r
.29187 .54137 m .29128 .5438 L .29345 .54022 L F
.413 .203 .483 r
.30789 .54118 m .3096 .5411 L .31084 .53793 L F
.54 .334 .549 r
.30789 .54118 m .31035 .54334 L .3096 .5411 L F
.30789 .54118 m .30793 .54424 L .31035 .54334 L F
.387 .093 .339 r
.61876 .4188 m .62093 .42004 L .61867 .42101 L F
.61876 .4188 m .6217 .41798 L .62093 .42004 L F
.511 .325 .565 r
.32394 .56951 m .3264 .56902 L .32645 .56629 L F
.502 .298 .536 r
.32394 .56951 m .32387 .572 L .3264 .56902 L F
.599 .462 .666 r
.29843 .63162 m .29529 .6325 L .29815 .62959 L F
.608 .364 .522 r
.29843 .63162 m .29487 .63441 L .29529 .6325 L F
.823 .815 .843 r
.7073 .31733 m .70816 .32029 L .70471 .32017 L F
.633 .365 .494 r
.70816 .32029 m .70562 .32283 L .70471 .32017 L F
.70816 .32029 m .70854 .32308 L .70562 .32283 L F
.841 .824 .831 r
.71039 .31673 m .70816 .32029 L .7073 .31733 L F
.649 .551 .73 r
.71039 .31673 m .71199 .32071 L .70816 .32029 L F
.686 .434 .536 r
.71199 .32071 m .70854 .32308 L .70816 .32029 L F
.568 .546 .79 r
.12781 .73644 m .13005 .73564 L .12771 .73617 L F
.515 .584 .862 r
.22298 .59686 m .22268 .60071 L .22196 .59664 L F
.22298 .59686 m .2249 .60031 L .22268 .60071 L F
.328 .32 .697 r
.22493 .60273 m .22268 .60071 L .2249 .60031 L F
.625 .36 .498 r
.39862 .56637 m .39884 .56934 L .40056 .56834 L F
.749 .309 .207 r
.39862 .56637 m .40056 .56834 L .39695 .56792 L F
0 0 .127 r
.40791 .57335 m .40737 .57265 L .40813 .57109 L F
.40791 .57335 m .40722 .57506 L .40737 .57265 L F
.222 .735 .699 r
.2548 .63456 m .2588 .6334 L .25697 .63347 L F
.111 0 0 r
.25697 .63347 m .2588 .6334 L .26158 .63364 L F
.649 .472 .63 r
.21947 .55669 m .2196 .55983 L .21681 .55993 L F
.21947 .55669 m .2196 .55983 L .21681 .55993 L F
.92 .975 .764 r
.22189 .55607 m .2196 .55983 L .21947 .55669 L F
.124 0 0 r
.37745 .65113 m .37488 .6535 L .37387 .65356 L F
.663 .929 .642 r
.38037 .64808 m .37828 .64974 L .37745 .65113 L F
.659 .917 .609 r
.37828 .64974 m .37488 .6535 L .37745 .65113 L F
.709 .734 .871 r
.63222 .41044 m .63367 .41242 L .63416 .40972 L F
.064 .189 .684 r
.35099 .55972 m .34966 .55523 L .35102 .55693 L F
.731 .491 .565 r
.35483 .55925 m .35099 .55972 L .35102 .55693 L F
.521 .02 .007 r
.352 .66736 m .34718 .66873 L .34686 .66692 L F
.352 .66736 m .35022 .6696 L .34718 .66873 L F
.416 .359 .686 r
.35327 .66321 m .352 .66736 L .35179 .66488 L F
0 0 0 r
.35178 .6683 m .35064 .66907 L .352 .66736 L F
.35178 .6683 m .35022 .6696 L .35064 .66907 L F
.581 .572 .808 r
.34729 .66467 m .35022 .6696 L .35062 .66927 L F
.35093 .66761 m .35062 .66927 L .35178 .6683 L F
.34729 .66467 m .35062 .66927 L .35093 .66761 L F
.843 .741 .75 r
.35159 .6641 m .3537 .66439 L .35224 .66325 L F
.581 .572 .808 r
.34729 .66467 m .35178 .6683 L .34947 .6669 L F
.843 .741 .75 r
.34947 .6669 m .35127 .66583 L .35159 .6641 L F
.35127 .66583 m .3537 .66439 L .35159 .6641 L F
.34947 .6669 m .35178 .6683 L .3537 .66439 L F
.375 .688 .98 r
.35248 .66783 m .35178 .6683 L .34947 .6669 L F
.997 .847 .567 r
.35407 .66714 m .35178 .6683 L .35306 .66843 L F
.375 .688 .98 r
.35371 .66821 m .35178 .6683 L .35248 .66783 L F
.798 .423 .345 r
.31421 .5275 m .31716 .53064 L .31835 .52857 L F
.399 .271 .587 r
.36017 .5903 m .358 .59199 L .35821 .58845 L F
.351 .477 .847 r
.37967 .55302 m .38038 .54921 L .37745 .5515 L F
.37967 .55302 m .38087 .55237 L .38038 .54921 L F
.058 0 .268 r
.37967 .55302 m .37893 .55609 L .38087 .55237 L F
.434 .081 .265 r
.31473 .63255 m .31643 .63407 L .31397 .63414 L F
.31473 .63255 m .31747 .63226 L .31643 .63407 L F
.757 .692 .79 r
.71523 .33884 m .71412 .33472 L .71551 .33731 L F
.312 0 .233 r
.71807 .33689 m .71523 .33884 L .71551 .33731 L F
.884 .55 .412 r
.33721 .69443 m .34036 .69568 L .34044 .69786 L F
.848 .718 .72 r
.61173 .41579 m .61175 .41859 L .60834 .41774 L F
.86 .578 .509 r
.60834 .41774 m .61175 .41859 L .61178 .42104 L F
.706 .604 .74 r
.61436 .41502 m .61175 .41859 L .61173 .41579 L F
.695 .362 .409 r
.61175 .41859 m .61588 .42086 L .61178 .42104 L F
.787 .748 .228 r
.22205 .59281 m .22193 .5946 L .22258 .59106 L F
0 0 .413 r
.22205 .59281 m .22298 .59686 L .22193 .5946 L F
.033 0 .463 r
.22298 .59686 m .22196 .59664 L .22193 .5946 L F
.21 0 .128 r
.27065 .5498 m .26893 .55301 L .26716 .55349 L F
.347 0 .203 r
.27136 .55235 m .27065 .5498 L .27315 .54975 L F
.27136 .55235 m .26893 .55301 L .27065 .5498 L F
.382 .196 .5 r
.38164 .59082 m .38335 .5908 L .38342 .58821 L F
.247 .143 .533 r
.38164 .59082 m .38317 .5934 L .38335 .5908 L F
.38164 .59082 m .38224 .59458 L .38317 .5934 L F
.533 .869 .992 r
.31144 .57195 m .31204 .57367 L .31056 .57349 L F
.682 .954 .952 r
.31552 .57094 m .31204 .57367 L .31144 .57195 L F
.495 .535 .827 r
.31688 .57447 m .31507 .57562 L .31204 .57367 L F
.851 .997 .821 r
.37066 .5466 m .37337 .54375 L .37097 .54443 L F
.536 .557 .824 r
.61106 .40277 m .61204 .40619 L .61257 .4045 L F
.808 .597 .617 r
.61106 .40277 m .61257 .4045 L .61222 .40449 L F
.382 .453 .809 r
.61208 .40331 m .61207 .40427 L .61106 .40277 L F
.61207 .40427 m .61204 .40619 L .61106 .40277 L F
.61226 .40479 m .61204 .40619 L .61208 .40331 L F
.808 .597 .617 r
.61106 .40277 m .61222 .40449 L .60781 .40446 L F
.795 .764 .825 r
.60781 .40446 m .61222 .40449 L .60889 .40796 L F
.61222 .40449 m .61257 .4045 L .61226 .40479 L F
.61222 .40449 m .61226 .40479 L .60889 .40796 L F
.382 .453 .809 r
.61246 .40351 m .61226 .40479 L .61208 .40331 L F
.823 .758 .791 r
.61204 .40619 m .61226 .40479 L .61257 .4045 L F
.382 .453 .809 r
.61408 .40436 m .61204 .40619 L .61246 .40351 L F
.823 .758 .791 r
.61204 .40619 m .60889 .40796 L .61226 .40479 L F
.392 .471 .821 r
.61408 .40436 m .61551 .40809 L .61204 .40619 L F
.503 .448 .729 r
.61551 .40809 m .6131 .40874 L .61204 .40619 L F
.347 .18 .507 r
.35555 .60059 m .35619 .60053 L .35632 .59778 L F
.355 .052 .305 r
.35619 .60053 m .35982 .59718 L .35632 .59778 L F
.652 .386 .504 r
.33759 .6506 m .34013 .65073 L .3379 .64809 L F
0 .212 .655 r
.34192 .65082 m .3379 .64809 L .34013 .65073 L F
.566 .542 .787 r
.30046 .56655 m .30298 .56601 L .30149 .56251 L F
.647 .488 .654 r
.30046 .56655 m .30351 .56832 L .30298 .56601 L F
.30046 .56655 m .30064 .56928 L .30351 .56832 L F
.608 .61 .827 r
.37646 .55725 m .37763 .56029 L .37961 .55859 L F
.729 .553 .653 r
.3811 .56283 m .37806 .56295 L .37763 .56029 L F
0 0 .435 r
.37763 .56029 m .37877 .56138 L .37961 .55859 L F
.502 .193 .375 r
.37877 .56138 m .3821 .55831 L .37961 .55859 L F
.527 .659 .919 r
.37961 .55859 m .3821 .55831 L .38052 .55658 L F
0 0 .173 r
.37992 .55763 m .37979 .5599 L .37877 .56138 L F
.49 .241 .464 r
.37979 .5599 m .37948 .56001 L .37877 .56138 L F
0 0 .435 r
.37763 .56029 m .37803 .56281 L .37877 .56138 L F
.981 .709 .433 r
.37877 .56138 m .37723 .5608 L .37725 .55774 L F
.608 .61 .827 r
.37646 .55725 m .37961 .55859 L .37893 .55609 L F
.527 .659 .919 r
.37961 .55859 m .38052 .55658 L .37893 .55609 L F
0 0 .173 r
.37992 .55763 m .37877 .56138 L .37725 .55774 L F
.49 .241 .464 r
.37948 .56001 m .37723 .5608 L .37877 .56138 L F
0 0 .435 r
.37803 .56281 m .37806 .56295 L .37877 .56138 L F
.513 .777 .992 r
.39276 .67643 m .39 .67693 L .38821 .67546 L F
.139 .163 .624 r
.3695 .59346 m .36896 .59482 L .36803 .5915 L F
.626 .284 .37 r
.36803 .5915 m .36741 .59446 L .3695 .59346 L F
.518 .463 .734 r
.21109 .58126 m .21203 .58629 L .20935 .58555 L F
0 .5 .832 r
.21203 .58629 m .21237 .58643 L .20935 .58555 L F
.118 .407 .857 r
.38923 .5259 m .39031 .52869 L .38941 .52684 L F
.922 .545 .137 r
.38923 .5259 m .39164 .53085 L .39031 .52869 L F
.954 .92 .737 r
.38384 .54387 m .37913 .54818 L .38276 .54348 L F
.533 .289 .491 r
.31279 .55577 m .31072 .55365 L .31338 .55337 L F
.31279 .55577 m .3104 .55622 L .31072 .55365 L F
.117 .455 .886 r
.22789 .61917 m .22816 .61786 L .22512 .61607 L F
.22789 .61917 m .22885 .61927 L .22816 .61786 L F
.39 .84 .922 r
.24369 .53248 m .23892 .53287 L .24156 .53123 L F
.555 .855 .997 r
.24603 .53166 m .24369 .53248 L .24156 .53123 L F
0 0 0 r
.38222 .64693 m .3817 .6473 L .38037 .64808 L F
.3817 .6473 m .37828 .64974 L .38037 .64808 L F
.367 .11 .387 r
.2009 .56022 m .20236 .56204 L .20266 .55932 L F
.2009 .56022 m .20016 .56281 L .20236 .56204 L F
0 .268 .774 r
.71541 .34839 m .71617 .34787 L .71321 .34541 L F
.09 .489 .898 r
.71541 .34839 m .71777 .34969 L .71617 .34787 L F
.443 .26 .537 r
.26319 .62101 m .26484 .62193 L .26142 .62222 L F
.705 .576 .708 r
.28896 .55643 m .2851 .55689 L .28785 .55388 L F
0 0 0 r
.2851 .55689 m .28631 .55645 L .28785 .55388 L F
.612 .269 .365 r
.28896 .55643 m .28724 .55898 L .2851 .55689 L F
.914 .633 .496 r
.28724 .55898 m .28631 .55645 L .28515 .55694 L F
.28724 .55898 m .28511 .5587 L .28631 .55645 L F
.396 .006 .178 r
.29036 .55628 m .28724 .55898 L .28896 .55643 L F
.48 .284 .537 r
.29272 .55758 m .2915 .56105 L .28984 .56012 L F
0 .313 .776 r
.28984 .56012 m .2915 .56105 L .29042 .5602 L F
.396 .006 .178 r
.29036 .55628 m .28972 .55988 L .28952 .55978 L F
.29033 .5563 m .28951 .5598 L .28724 .55898 L F
.29036 .55628 m .28951 .5598 L .29033 .5563 L F
.237 0 .141 r
.29272 .55758 m .28972 .55988 L .29036 .55628 L F
0 .313 .776 r
.28984 .56012 m .29042 .5602 L .28972 .55988 L F
.28984 .56012 m .28972 .55988 L .28952 .55978 L F
.48 .284 .537 r
.28972 .55988 m .28984 .56012 L .28972 .55988 L F
.29272 .55758 m .28984 .56012 L .28972 .55988 L F
.237 0 .141 r
.28972 .55988 m .28972 .55988 L .28972 .55988 L F
.28972 .55988 m .28972 .55988 L .29036 .55628 L F
0 .313 .776 r
.28952 .55978 m .28972 .55988 L .2884 .55862 L F
.28972 .55988 m .29042 .5602 L .29027 .56008 L F
.28972 .55988 m .29027 .56008 L .2884 .55862 L F
.396 .006 .178 r
.28952 .55978 m .28972 .55988 L .28951 .5598 L F
.28972 .55988 m .28972 .55988 L .28952 .55978 L F
0 .313 .776 r
.28951 .5598 m .2884 .55862 L .28841 .55873 L F
0 .387 .82 r
.28724 .55898 m .28951 .5598 L .28984 .56012 L F
0 .313 .776 r
.28984 .56012 m .28952 .55978 L .28951 .5598 L F
0 .387 .82 r
.28951 .5598 m .28972 .55988 L .28984 .56012 L F
0 .313 .776 r
.28984 .56012 m .28951 .5598 L .28951 .5598 L F
.28952 .55978 m .2884 .55862 L .28951 .5598 L F
0 .387 .82 r
.28724 .55898 m .28841 .55873 L .28673 .55787 L F
0 0 0 r
.28631 .55645 m .28557 .55784 L .28768 .55588 L F
.28557 .55784 m .28589 .55785 L .28768 .55588 L F
.28631 .55645 m .28768 .55588 L .28833 .55515 L F
.765 .979 .72 r
.28833 .55515 m .28589 .55785 L .28608 .55674 L F
.686 .923 .971 r
.28575 .55736 m .28511 .5587 L .28576 .55738 L F
0 .387 .82 r
.28576 .55738 m .28576 .55737 L .28575 .55736 L F
0 0 0 r
.28557 .55784 m .28511 .5587 L .28589 .55785 L F
.307 .555 .923 r
.28575 .55736 m .28613 .55644 L .28511 .5587 L F
.765 .979 .72 r
.28589 .55785 m .28511 .5587 L .28574 .5573 L F
.686 .923 .971 r
.28576 .55738 m .28511 .5587 L .28724 .55898 L F
.914 .633 .496 r
.28515 .55694 m .28631 .55645 L .2851 .55689 L F
.765 .979 .72 r
.28626 .55636 m .28608 .55674 L .28613 .55644 L F
.28833 .55515 m .28608 .55674 L .28626 .55636 L F
.307 .555 .923 r
.28575 .55736 m .28576 .55737 L .28613 .55644 L F
.765 .979 .72 r
.28589 .55785 m .28576 .55737 L .28613 .55644 L F
.307 .555 .923 r
.28576 .55737 m .28841 .55873 L .28613 .55644 L F
.765 .979 .72 r
.28576 .55737 m .28574 .5573 L .28613 .55644 L F
0 .387 .82 r
.2862 .55786 m .28673 .55787 L .28576 .55737 L F
.2862 .55786 m .28576 .55737 L .28576 .55738 L F
.28724 .55898 m .28673 .55787 L .2862 .55786 L F
.835 .981 .876 r
.33562 .52938 m .33329 .53014 L .33577 .5272 L F
.396 .587 .92 r
.25182 .55232 m .25197 .54916 L .24984 .54995 L F
.25182 .55232 m .25409 .55278 L .25197 .54916 L F
.349 .321 .687 r
.18885 .5819 m .18916 .58572 L .19116 .58387 L F
.194 .168 .599 r
.19002 .58817 m .19116 .58387 L .18916 .58572 L F
.364 .283 .631 r
.38512 .54021 m .38374 .53793 L .3848 .53854 L F
0 0 0 r
.28974 .53738 m .2865 .54023 L .2879 .53861 L F
.666 .784 .937 r
.38305 .5749 m .38712 .57558 L .38548 .57389 L F
.21 0 0 r
.38627 .57519 m .38559 .57547 L .38548 .57389 L F
.38559 .57547 m .38363 .57631 L .38447 .57521 L F
.38559 .57547 m .38447 .57521 L .38548 .57389 L F
0 .433 .716 r
.38246 .57474 m .38305 .5749 L .38456 .57535 L F
.37855 .57362 m .38274 .57481 L .38246 .57474 L F
.38274 .57481 m .38305 .5749 L .38246 .57474 L F
.83 .736 .76 r
.34649 .52239 m .34217 .52435 L .34484 .52094 L F
.34649 .52239 m .34402 .52554 L .34217 .52435 L F
0 0 0 r
.28785 .55388 m .28833 .55515 L .28991 .55228 L F
.28785 .55388 m .28631 .55645 L .28833 .55515 L F
.832 .475 .379 r
.35221 .70788 m .35416 .70782 L .35242 .70988 L F
.574 .143 .185 r
.35242 .70988 m .35416 .70782 L .35659 .70971 L F
.577 .14 .174 r
.35416 .70782 m .35685 .70828 L .35659 .70971 L F
.386 .07 .302 r
.26221 .54147 m .2614 .5435 L .25907 .54409 L F
0 0 .098 r
.26305 .54212 m .26221 .54147 L .26426 .54065 L F
.26305 .54212 m .2614 .5435 L .26221 .54147 L F
.444 .084 .259 r
.22615 .57285 m .2254 .5746 L .22296 .57477 L F
0 0 .076 r
.22758 .57169 m .22615 .57285 L .22845 .5692 L F
.301 0 .192 r
.22758 .57394 m .22615 .57285 L .22758 .57169 L F
.22758 .57394 m .2254 .5746 L .22615 .57285 L F
.522 .47 .739 r
.36654 .54341 m .36483 .54737 L .3642 .54509 L F
.39 0 0 r
.31854 .65557 m .32213 .65707 L .3193 .6557 L F
.531 .367 .604 r
.36826 .57057 m .36873 .57402 L .36768 .5705 L F
.37095 .57092 m .36947 .57109 L .36826 .57057 L F
0 .206 .71 r
.36947 .57109 m .37095 .57092 L .36882 .57079 L F
.37131 .57196 m .37095 .57092 L .36947 .57109 L F
.531 .367 .604 r
.37095 .57092 m .3705 .57154 L .36947 .57109 L F
0 .316 .672 r
.37131 .57196 m .36947 .57109 L .36759 .57031 L F
.36947 .57109 m .36826 .57057 L .36759 .57031 L F
.531 .367 .604 r
.3705 .57154 m .36873 .57402 L .36826 .57057 L F
0 .316 .672 r
.36947 .57109 m .36882 .57079 L .36826 .57057 L F
.207 0 0 r
.36826 .57057 m .36882 .57079 L .37095 .57092 L F
.36768 .5705 m .36882 .57079 L .36826 .57057 L F
0 .316 .672 r
.36759 .57031 m .36882 .57079 L .36626 .56972 L F
0 .206 .71 r
.37131 .57196 m .37224 .57252 L .37095 .57092 L F
0 .066 .63 r
.33951 .62273 m .34181 .62583 L .33955 .6214 L F
.523 .376 .622 r
.33918 .62594 m .34181 .62583 L .33951 .62273 L F
.373 .511 .867 r
.20618 .60253 m .20668 .6046 L .20795 .60257 L F
.328 .451 .833 r
.20668 .6046 m .2095 .60606 L .20795 .60257 L F
.389 .764 .992 r
.28063 .52393 m .28304 .52367 L .28473 .52469 L F
.105 .624 .885 r
.28304 .52367 m .28696 .52454 L .28473 .52469 L F
.406 .552 .888 r
.71354 .31342 m .71172 .31537 L .71232 .31287 L F
.878 .993 .787 r
.71119 .31513 m .71172 .31537 L .71039 .31673 L F
.71232 .31287 m .71039 .31673 L .70975 .31576 L F
.615 .449 .634 r
.71415 .31774 m .71199 .32071 L .71039 .31673 L F
.608 .046 0 r
.71014 .31673 m .7125 .318 L .71135 .31707 L F
.71014 .31673 m .71135 .31707 L .70975 .31576 L F
.576 .376 .573 r
.70975 .31576 m .7125 .318 L .71211 .31551 L F
.608 .046 0 r
.71014 .31673 m .7098 .31587 L .71211 .31551 L F
.7098 .31587 m .70975 .31576 L .71006 .31573 L F
.7098 .31587 m .71006 .31573 L .71211 .31551 L F
.841 .824 .831 r
.71039 .31673 m .7073 .31733 L .70975 .31576 L F
.721 .778 .898 r
.70975 .31576 m .7073 .31733 L .70595 .31543 L F
.762 .718 .811 r
.7088 .3124 m .70975 .31576 L .70595 .31543 L F
.799 .738 .796 r
.7088 .3124 m .71232 .31287 L .70975 .31576 L F
.976 .921 .659 r
.7094 .31653 m .71014 .31673 L .70975 .31443 L F
.70889 .3196 m .71014 .31673 L .7094 .31653 L F
.878 .993 .787 r
.71232 .31287 m .71186 .31477 L .71119 .31513 L F
.71186 .31477 m .71172 .31537 L .71119 .31513 L F
0 .041 .6 r
.38372 .61137 m .38378 .61329 L .38068 .61052 L F
.38372 .61137 m .38447 .6135 L .38378 .61329 L F
.511 .482 .76 r
.18912 .5971 m .19038 .5956 L .18866 .59587 L F
.18912 .5971 m .19138 .59703 L .19038 .5956 L F
.393 .141 .409 r
.34067 .5413 m .34059 .54352 L .34294 .54079 L F
.626 .633 .837 r
.40508 .5873 m .40415 .59142 L .40322 .58807 L F
.40508 .5873 m .40721 .59124 L .40415 .59142 L F
.617 .371 .523 r
.40721 .59124 m .404 .59344 L .40415 .59142 L F
0 .001 .576 r
.39421 .53429 m .39597 .53667 L .39556 .53802 L F
0 .123 .648 r
.39597 .53667 m .39601 .54042 L .39556 .53802 L F
.301 0 0 r
.28541 .61963 m .28397 .62132 L .28306 .62122 L F
.038 0 0 r
.28599 .62048 m .28541 .61963 L .28737 .61904 L F
.28599 .62048 m .28397 .62132 L .28541 .61963 L F
0 0 .271 r
.32282 .5426 m .32263 .54689 L .32157 .54678 L F
0 0 0 r
.32157 .54678 m .32263 .54689 L .32036 .54724 L F
.317 .742 .973 r
.21484 .61102 m .21496 .61006 L .21326 .60936 L F
.21484 .61102 m .21738 .61093 L .21496 .61006 L F
.763 .73 .822 r
.34582 .58138 m .34348 .58385 L .34202 .58138 L F
0 .242 .754 r
.34202 .58138 m .34433 .58377 L .34348 .58385 L F
0 0 0 r
.3446 .5842 m .34348 .58385 L .34433 .58377 L F
.3446 .5842 m .34085 .58601 L .34348 .58385 L F
.749 .671 .775 r
.36494 .56576 m .36626 .56972 L .36233 .56901 L F
.593 .491 .707 r
.36569 .5721 m .36233 .56901 L .36626 .56972 L F
.775 .685 .764 r
.36895 .56646 m .36626 .56972 L .36494 .56576 L F
.421 .13 .363 r
.36768 .5705 m .36626 .56972 L .36882 .57079 L F
.36768 .5705 m .36569 .5721 L .36626 .56972 L F
.745 .609 .707 r
.6131 .40874 m .61412 .41242 L .61041 .41198 L F
.688 .537 .676 r
.61412 .41242 m .61173 .41579 L .61041 .41198 L F
.61412 .41242 m .61436 .41502 L .61173 .41579 L F
.657 .623 .804 r
.61551 .40809 m .61412 .41242 L .6131 .40874 L F
.61551 .40809 m .61683 .41188 L .61412 .41242 L F
.636 .498 .678 r
.61683 .41188 m .61436 .41502 L .61412 .41242 L F
.721 .832 .383 r
.27808 .53136 m .27759 .53241 L .2775 .53299 L F
.367 .836 .818 r
.2775 .53299 m .276 .53376 L .27741 .53356 L F
.2775 .53299 m .27536 .53382 L .276 .53376 L F
.082 0 0 r
.27655 .53464 m .27536 .53382 L .2775 .53299 L F
.721 .832 .383 r
.27759 .53241 m .27655 .53464 L .2775 .53299 L F
.367 .836 .818 r
.2775 .53299 m .27741 .53356 L .27998 .5332 L F
.04 .533 .881 r
.27998 .5332 m .27998 .53233 L .2775 .53299 L F
.27998 .5332 m .28275 .53358 L .27998 .53233 L F
.771 .995 .795 r
.36306 .52532 m .36278 .52481 L .36377 .52337 L F
.845 .636 .093 r
.36306 .52532 m .36315 .52792 L .36278 .52481 L F
.775 .486 .497 r
.36694 .52818 m .36315 .52792 L .36306 .52532 L F
.631 .101 0 r
.72514 .29672 m .72617 .29563 L .72505 .29406 L F
.441 .321 .62 r
.72885 .29747 m .72697 .2986 L .72617 .29563 L F
.631 .101 0 r
.72514 .29672 m .72885 .29747 L .72617 .29563 L F
.166 .115 .551 r
.30606 .59713 m .30539 .5935 L .30642 .5945 L F
.779 .676 .75 r
.36807 .56295 m .36895 .56646 L .36494 .56576 L F
.983 .766 .532 r
.36734 .56518 m .36895 .56646 L .36807 .56295 L F
0 .238 .752 r
.36959 .56521 m .36895 .56646 L .36734 .56518 L F
.36959 .56521 m .37124 .56829 L .36895 .56646 L F
.707 .197 .017 r
.34427 .65325 m .34192 .65082 L .34013 .65073 L F
.646 .245 .269 r
.34427 .65325 m .34453 .65144 L .34192 .65082 L F
.76 .73 .825 r
.22025 .58173 m .22245 .58489 L .21779 .58255 L F
.806 .703 .752 r
.22245 .58489 m .21971 .58835 L .21779 .58255 L F
.26 .383 .799 r
.22346 .58304 m .22245 .58489 L .22025 .58173 L F
.22346 .58304 m .22408 .58483 L .22245 .58489 L F
.264 .271 .68 r
.22408 .58483 m .22478 .5875 L .22245 .58489 L F
.04 .056 .548 r
.32279 .62245 m .32423 .6248 L .32286 .62553 L F
0 0 0 r
.32423 .6248 m .32123 .627 L .32286 .62553 L F
.082 .552 .903 r
.30525 .65683 m .30684 .65796 L .30966 .65851 L F
.438 0 0 r
.30684 .65796 m .31093 .65937 L .30966 .65851 L F
.736 .932 .954 r
.22022 .61055 m .22191 .61165 L .22371 .61023 L F
.587 .592 .824 r
.32257 .56328 m .32645 .56629 L .32633 .56368 L F
.679 .556 .709 r
.32633 .56368 m .32645 .56629 L .32887 .56315 L F
.429 .26 .548 r
.32645 .56629 m .3264 .56902 L .32858 .56823 L F
.686 .689 .847 r
.35327 .66321 m .35409 .66565 L .35689 .66398 L F
.803 .863 .893 r
.71661 .31365 m .71791 .31552 L .71973 .31401 L F
.713 .592 .719 r
.32257 .56328 m .32633 .56368 L .3252 .56027 L F
.683 .575 .728 r
.32555 .56055 m .32633 .56368 L .32887 .56315 L F
0 0 0 r
.32753 .55976 m .32616 .56054 L .32825 .55846 L F
.32844 .55831 m .32825 .55846 L .32851 .55819 L F
.32753 .55976 m .32825 .55846 L .32844 .55831 L F
.683 .575 .728 r
.3252 .56027 m .32535 .56071 L .32555 .56055 L F
0 0 0 r
.32568 .56102 m .3252 .56027 L .32851 .55819 L F
.198 .055 .449 r
.32997 .55624 m .32983 .55886 L .32851 .55819 L F
0 0 0 r
.32753 .55976 m .32851 .55819 L .32983 .55886 L F
.85 .998 .786 r
.33017 .55694 m .32753 .55976 L .32983 .55886 L F
.152 .13 .577 r
.32908 .55561 m .32753 .55976 L .33017 .55694 L F
.32908 .55561 m .32927 .55876 L .32753 .55976 L F
.32927 .55876 m .32928 .55898 L .32753 .55976 L F
0 0 0 r
.32753 .55976 m .32568 .56102 L .32616 .56054 L F
.683 .575 .728 r
.32535 .56071 m .32633 .56368 L .32555 .56055 L F
.636 .493 .671 r
.33424 .60734 m .33658 .60768 L .33658 .60765 L F
.703 .845 .95 r
.33658 .60765 m .33876 .60743 L .33792 .60782 L F
.33424 .60734 m .33592 .60738 L .33658 .60765 L F
.33592 .60738 m .33876 .60743 L .33658 .60765 L F
.151 .122 .569 r
.33628 .60321 m .33658 .60765 L .33827 .60521 L F
.33658 .60765 m .33658 .60768 L .3366 .60765 L F
.33658 .60765 m .3366 .60765 L .33827 .60521 L F
.636 .493 .671 r
.33424 .60734 m .33658 .60765 L .33628 .60321 L F
.315 0 0 r
.33751 .60801 m .33658 .60768 L .33424 .60734 L F
.703 .845 .95 r
.33658 .60765 m .33792 .60782 L .33751 .60801 L F
.448 .433 .749 r
.33751 .60801 m .33827 .60521 L .3366 .60765 L F
.33751 .60801 m .3366 .60765 L .33658 .60768 L F
.703 .845 .95 r
.33424 .60734 m .33658 .60765 L .33751 .60801 L F
.71 .333 .332 r
.34056 .60822 m .33876 .60743 L .34091 .60649 L F
.637 .65 .846 r
.3898 .59242 m .39152 .59447 L .39467 .59336 L F
.63 .53 .722 r
.39152 .59447 m .39508 .59744 L .39467 .59336 L F
.241 0 .257 r
.37185 .57899 m .36906 .58194 L .37119 .58103 L F
.288 .01 .306 r
.37119 .58103 m .37384 .57791 L .37185 .57899 L F
0 0 .179 r
.35319 .60936 m .35279 .61327 L .35356 .61183 L F
.392 .154 .429 r
.36568 .63075 m .36507 .62994 L .36596 .63064 L F
.36568 .63075 m .36339 .6326 L .36507 .62994 L F
0 0 0 r
.22373 .58937 m .22205 .59281 L .22258 .59106 L F
.806 .985 .715 r
.32864 .59657 m .32748 .59831 L .33002 .5953 L F
.194 0 .225 r
.33141 .59364 m .32864 .59657 L .33002 .5953 L F
.895 .475 .12 r
.40204 .55225 m .40423 .55563 L .40226 .55372 L F
.428 0 0 r
.35356 .61183 m .35644 .61192 L .35815 .60949 L F
.329 .434 .817 r
.35815 .60949 m .3587 .60532 L .35678 .60513 L F
.669 .889 .531 r
.36071 .60893 m .35792 .61261 L .35815 .60949 L F
.36069 .60895 m .35997 .60974 L .35937 .6107 L F
.36071 .60893 m .36048 .60918 L .36069 .60895 L F
.36048 .60918 m .35997 .60974 L .36069 .60895 L F
.546 .14 .223 r
.35771 .61012 m .35974 .60998 L .35815 .60949 L F
.35974 .60998 m .36126 .60987 L .35999 .60972 L F
.35974 .60998 m .35999 .60972 L .35815 .60949 L F
.35644 .61192 m .35829 .61114 L .35771 .61012 L F
.669 .889 .531 r
.35997 .60974 m .35843 .61144 L .35937 .6107 L F
.329 .434 .817 r
.35999 .60972 m .35999 .60972 L .36062 .60872 L F
.35999 .60972 m .36126 .60987 L .36073 .60893 L F
0 0 0 r
.36122 .6084 m .36 .60971 L .36071 .60893 L F
.521 .535 .81 r
.36073 .60893 m .36126 .60987 L .36173 .60785 L F
0 0 0 r
.36131 .60831 m .36073 .60893 L .36122 .6084 L F
.36073 .60893 m .36 .60971 L .36122 .6084 L F
.36173 .60785 m .36131 .60831 L .36071 .60893 L F
.521 .535 .81 r
.3587 .60532 m .36073 .60893 L .36173 .60785 L F
.329 .434 .817 r
.35999 .60972 m .36073 .60893 L .36062 .60872 L F
.546 .14 .223 r
.35897 .61085 m .35843 .61144 L .36126 .60987 L F
.35644 .61192 m .35843 .61144 L .35897 .61085 L F
.35897 .61085 m .36126 .60987 L .35976 .60998 L F
0 0 0 r
.36131 .60831 m .35864 .61122 L .35898 .61084 L F
.36023 .60946 m .35898 .61084 L .36 .60971 L F
.36131 .60831 m .35898 .61084 L .36023 .60946 L F
.35864 .61122 m .35843 .61144 L .36048 .60918 L F
.35864 .61122 m .36048 .60918 L .36071 .60893 L F
.546 .14 .223 r
.35829 .61114 m .35897 .61085 L .35771 .61012 L F
.35897 .61085 m .35976 .60998 L .35771 .61012 L F
0 0 .346 r
.35834 .61078 m .35847 .61119 L .35844 .6114 L F
.35842 .61137 m .35844 .6114 L .35843 .61144 L F
.35834 .61078 m .35844 .6114 L .35842 .61137 L F
.669 .889 .531 r
.35937 .6107 m .35843 .61144 L .35833 .61207 L F
.892 .905 .829 r
.36173 .60785 m .35843 .61144 L .36126 .60987 L F
0 0 .346 r
.35847 .61119 m .3595 .61431 L .35843 .61144 L F
.669 .889 .531 r
.35833 .61207 m .35843 .61144 L .35792 .61261 L F
.329 .434 .817 r
.35815 .60949 m .35999 .60972 L .3587 .60532 L F
.35999 .60972 m .36062 .60872 L .3587 .60532 L F
.127 0 0 r
.32858 .56823 m .33101 .5677 L .33293 .5662 L F
.881 .989 .731 r
.21842 .58199 m .21868 .58037 L .22025 .58173 L F
.76 .73 .825 r
.22025 .58173 m .21779 .58255 L .21842 .58199 L F
.415 .257 .557 r
.35411 .52829 m .35627 .53024 L .35649 .5276 L F
.35411 .52829 m .35413 .53116 L .35627 .53024 L F
.413 .013 .167 r
.3811 .56283 m .37727 .56534 L .37806 .56295 L F
.3811 .56283 m .38065 .56518 L .37727 .56534 L F
.811 .709 .173 r
.38072 .56408 m .3811 .56283 L .38346 .56217 L F
.38072 .56408 m .38065 .56518 L .3811 .56283 L F
0 .073 .626 r
.27799 .64029 m .27842 .64158 L .27877 .64161 L F
.918 .721 .228 r
.40423 .55563 m .40411 .55858 L .40485 .55946 L F
.777 .52 0 r
.40487 .56083 m .40485 .55946 L .40411 .55858 L F
.40487 .56083 m .40525 .56213 L .40485 .55946 L F
.576 .587 .827 r
.36906 .58194 m .37324 .58378 L .37119 .58103 L F
.523 .526 .8 r
.32862 .65428 m .33008 .65807 L .33231 .65725 L F
.474 .379 .667 r
.33008 .65807 m .33259 .65989 L .33231 .65725 L F
.752 .669 .77 r
.72708 .34334 m .72431 .34635 L .72266 .34273 L F
.237 0 0 r
.3271 .54176 m .32282 .5426 L .32408 .5408 L F
.3271 .54176 m .32556 .54256 L .32282 .5426 L F
.208 .054 .441 r
.30784 .55954 m .30609 .56251 L .30536 .56036 L F
.217 .321 .757 r
.39353 .65548 m .3922 .65738 L .39064 .65559 L F
.39353 .65548 m .3935 .65709 L .3922 .65738 L F
.214 .304 .741 r
.3935 .65709 m .39485 .65973 L .3922 .65738 L F
.429 .328 .639 r
.3922 .65738 m .39485 .65973 L .39275 .66093 L F
.429 .608 .923 r
.23064 .62283 m .23277 .62141 L .22885 .61927 L F
.23064 .62283 m .23251 .62248 L .23277 .62141 L F
.636 .707 .897 r
.35004 .62784 m .35231 .62719 L .3514 .62587 L F
.352 .137 .44 r
.35004 .62784 m .34946 .63152 L .35145 .63095 L F
.471 .595 .895 r
.35825 .50763 m .35656 .50971 L .35475 .50703 L F
.35825 .50763 m .35907 .50979 L .35656 .50971 L F
.513 .632 .905 r
.23453 .62579 m .23463 .62237 L .23251 .62248 L F
.23453 .62579 m .23675 .62541 L .23463 .62237 L F
.522 .47 .739 r
.36654 .54341 m .3671 .54681 L .36483 .54737 L F
.201 .359 .799 r
.37567 .60041 m .3772 .60399 L .3788 .60381 L F
.201 .346 .787 r
.3772 .60399 m .37978 .60597 L .3788 .60381 L F
.455 .359 .657 r
.3772 .60399 m .37774 .60706 L .37978 .60597 L F
.407 .843 .942 r
.35472 .66955 m .35234 .67017 L .35098 .66982 L F
.462 .863 .685 r
.31807 .54421 m .31947 .54316 L .32134 .54216 L F
.26 0 0 r
.32134 .54216 m .31947 .54316 L .32282 .5426 L F
.582 .22 .32 r
.33446 .58818 m .3367 .59018 L .33327 .59018 L F
.588 .218 .308 r
.3382 .58774 m .3367 .59018 L .33446 .58818 L F
.926 .607 .418 r
.32257 .56328 m .32104 .5645 L .32055 .56225 L F
0 0 0 r
.32478 .56075 m .32392 .56213 L .32257 .56328 L F
.342 .044 .306 r
.32392 .56213 m .32104 .5645 L .32257 .56328 L F
.643 .584 .773 r
.32126 .5596 m .32521 .56022 L .32223 .55515 L F
.538 .208 .356 r
.32055 .56225 m .32521 .56022 L .32126 .5596 L F
0 0 0 r
.3252 .56027 m .32392 .56213 L .32478 .56075 L F
.538 .208 .356 r
.32055 .56225 m .32392 .56213 L .32521 .56022 L F
.342 .044 .306 r
.32392 .56213 m .32104 .5645 L .32055 .56225 L F
.32392 .56213 m .32312 .56418 L .32104 .5645 L F
.32392 .56213 m .32312 .56418 L .32104 .5645 L F
.97 .694 .453 r
.32393 .55962 m .32331 .56311 L .32392 .56213 L F
.32331 .56311 m .32312 .56418 L .32392 .56213 L F
.621 .472 .659 r
.35792 .61261 m .35653 .61636 L .35647 .61357 L F
.63 .265 .333 r
.35685 .70828 m .36057 .70763 L .35887 .71018 L F
.718 .372 .39 r
.36057 .70763 m .3628 .71044 L .35887 .71018 L F
.667 .371 .461 r
.36057 .70763 m .36306 .70784 L .3628 .71044 L F
.217 0 0 r
.21776 .57515 m .215 .57746 L .21285 .57792 L F
.723 .355 .352 r
.21776 .57515 m .21912 .57776 L .215 .57746 L F
0 0 0 r
.26157 .55303 m .25924 .55533 L .25774 .55619 L F
.705 .291 .259 r
.26392 .55572 m .26157 .55303 L .26433 .55348 L F
.26392 .55572 m .25924 .55533 L .26157 .55303 L F
.207 0 .012 r
.19791 .56368 m .19911 .56443 L .20016 .56281 L F
.19791 .56368 m .19684 .56515 L .19911 .56443 L F
.576 .535 .772 r
.38633 .63252 m .38267 .62915 L .38506 .62864 L F
.564 .272 .43 r
.36238 .55001 m .35838 .55279 L .35877 .5505 L F
.334 .45 .83 r
.19138 .59703 m .1925 .59987 L .19391 .59759 L F
.154 .4 .846 r
.25457 .55367 m .25585 .55311 L .25409 .55278 L F
.25457 .55367 m .25774 .55619 L .25585 .55311 L F
.607 .373 .536 r
.2196 .55983 m .21663 .56264 L .21681 .55993 L F
.21663 .56264 m .2196 .55983 L .21681 .55993 L F
.2196 .55983 m .2193 .56266 L .21663 .56264 L F
.21663 .56264 m .2193 .56266 L .2196 .55983 L F
.611 .396 .566 r
.21681 .55993 m .2193 .56266 L .21663 .56264 L F
.119 0 .342 r
.26078 .76123 m .25958 .7639 L .26032 .76403 L F
.564 .317 .5 r
.26032 .76403 m .26353 .76424 L .26078 .76123 L F
.585 .621 .854 r
.23891 .60896 m .23823 .6128 L .23645 .60998 L F
.23891 .60896 m .24099 .61242 L .23823 .6128 L F
.115 0 .238 r
.28901 .61789 m .28737 .61904 L .28764 .6165 L F
.788 .669 .733 r
.39124 .57721 m .39518 .57419 L .38844 .57308 L F
.713 .647 .782 r
.62071 .4129 m .61683 .41188 L .62048 .41094 L F
.604 .771 .96 r
.6219 .41045 m .62071 .4129 L .62048 .41094 L F
.6219 .41045 m .62319 .41198 L .62071 .4129 L F
.403 .475 .82 r
.62406 .4146 m .62071 .4129 L .62319 .41198 L F
.208 .054 .441 r
.30784 .55954 m .30769 .56193 L .30609 .56251 L F
.159 0 .315 r
.30769 .56193 m .30471 .56592 L .30609 .56251 L F
0 0 0 r
.33978 .58837 m .33929 .58899 L .34085 .58601 L F
.33929 .58899 m .3388 .58963 L .33983 .58781 L F
.506 .34 .591 r
.34 .58767 m .33983 .5878 L .33989 .58768 L F
.34 .58767 m .3388 .58963 L .3367 .59018 L F
.595 .448 .652 r
.34085 .58601 m .3388 .58963 L .34 .58767 L F
0 0 0 r
.33929 .58899 m .33983 .58781 L .34085 .58601 L F
.506 .34 .591 r
.33989 .58768 m .3367 .59018 L .3382 .58774 L F
.33983 .5878 m .3367 .59018 L .33989 .58768 L F
.013 0 0 r
.33138 .58014 m .33424 .57953 L .33561 .5788 L F
.189 .285 .733 r
.32462 .52847 m .32719 .53085 L .32595 .52615 L F
.404 .317 .643 r
.32462 .52847 m .32536 .53151 L .32719 .53085 L F
.645 .71 .894 r
.3365 .57764 m .33561 .5788 L .33424 .57953 L F
.3365 .57764 m .3356 .58118 L .33561 .5788 L F
.71 .976 .918 r
.38187 .65692 m .37896 .65877 L .37728 .65868 L F
.541 0 0 r
.26538 .63475 m .26902 .63603 L .26762 .63626 L F
.36 0 0 r
.26902 .63603 m .26984 .63684 L .26762 .63626 L F
.26902 .63603 m .27232 .6371 L .26984 .63684 L F
0 .496 .776 r
.71777 .34969 m .71879 .34969 L .71617 .34787 L F
.917 .863 .772 r
.71879 .34969 m .71545 .35097 L .71657 .34898 L F
.71879 .34969 m .71657 .34898 L .7166 .34893 L F
0 .496 .776 r
.71777 .34969 m .7202 .35014 L .71879 .34969 L F
.7202 .35014 m .72089 .35026 L .71879 .34969 L F
.5 .254 .474 r
.31547 .54721 m .31746 .54695 L .31807 .54421 L F
0 0 .162 r
.31807 .54421 m .31894 .54529 L .31947 .54316 L F
.31807 .54421 m .31746 .54695 L .31894 .54529 L F
.378 .18 .481 r
.71399 .33031 m .71411 .3326 L .71633 .32932 L F
.048 .614 .768 r
.31325 .66031 m .31743 .66044 L .31585 .66031 L F
.356 .731 .987 r
.31743 .66044 m .31811 .6592 L .31585 .66031 L F
.31743 .66044 m .3197 .66033 L .31811 .6592 L F
.553 .54 .794 r
.31743 .66044 m .32128 .66388 L .3197 .66033 L F
.581 .904 .982 r
.32197 .516 m .31786 .51633 L .32117 .51696 L F
.443 0 .044 r
.32117 .51696 m .32423 .51538 L .32197 .516 L F
0 0 0 r
.32568 .56102 m .32392 .56213 L .3252 .56027 L F
.157 0 .236 r
.22866 .53811 m .22786 .54035 L .23041 .53719 L F
.819 .652 .676 r
.61041 .41198 m .61173 .41579 L .61035 .41449 L F
.848 .718 .72 r
.61173 .41579 m .60834 .41774 L .61035 .41449 L F
.621 .801 .372 r
.31527 .51587 m .31322 .5194 L .31151 .51819 L F
.31527 .51587 m .313 .51976 L .31322 .5194 L F
.262 .701 .962 r
.30166 .65081 m .30506 .64799 L .30198 .64809 L F
.30166 .65081 m .30462 .65115 L .30506 .64799 L F
.534 .345 .571 r
.30462 .65115 m .30733 .64724 L .30506 .64799 L F
.237 0 .141 r
.29272 .55758 m .29036 .55628 L .29226 .55503 L F
.624 .304 .409 r
.37066 .70767 m .36941 .71042 L .36684 .70992 L F
.489 .138 .298 r
.3732 .7074 m .36941 .71042 L .37066 .70767 L F
0 .172 .697 r
.27232 .6371 m .27324 .63858 L .27334 .63772 L F
.725 .615 .734 r
.27799 .63952 m .2811 .6406 L .28084 .6376 L F
0 0 0 r
.27799 .63952 m .28084 .6376 L .27969 .63882 L F
.27799 .63952 m .27969 .63882 L .27703 .63915 L F
.54 .69 .937 r
.27334 .63772 m .27799 .64029 L .27799 .63952 L F
.014 .482 .873 r
.2771 .63997 m .27709 .6398 L .27334 .63772 L F
.54 .69 .937 r
.27334 .63772 m .27353 .6378 L .27594 .63929 L F
.014 .482 .873 r
.27324 .63858 m .2771 .63997 L .27334 .63772 L F
.619 .252 .325 r
.27594 .63929 m .2785 .64086 L .27821 .64136 L F
0 .069 .581 r
.27735 .64052 m .27594 .63929 L .27821 .64136 L F
.54 .69 .937 r
.2748 .63829 m .27799 .63952 L .27594 .63929 L F
0 0 0 r
.27706 .63942 m .27703 .63915 L .27594 .63929 L F
.27799 .63952 m .27703 .63915 L .27706 .63942 L F
.014 .482 .873 r
.2771 .63997 m .27799 .64029 L .27709 .6398 L F
0 .073 .626 r
.27799 .64029 m .27877 .64161 L .27799 .63952 L F
.463 .373 .668 r
.27877 .64161 m .2811 .6406 L .27799 .63952 L F
.619 .252 .325 r
.27594 .63929 m .27969 .63882 L .2785 .64086 L F
0 .069 .581 r
.27469 .63788 m .27594 .63929 L .27735 .64052 L F
.54 .69 .937 r
.27353 .6378 m .2748 .63829 L .27594 .63929 L F
.236 .093 .474 r
.36256 .62291 m .36398 .62393 L .36417 .62224 L F
.36256 .62291 m .36195 .62581 L .36398 .62393 L F
.643 .584 .773 r
.32126 .5596 m .32223 .55515 L .32042 .55764 L F
.658 .177 0 r
.35647 .59312 m .35918 .59661 L .35693 .59398 L F
.614 .477 .67 r
.358 .59199 m .35824 .59508 L .35647 .59312 L F
.769 .473 .485 r
.35824 .59508 m .35918 .59661 L .35647 .59312 L F
.107 0 .041 r
.35647 .59312 m .35693 .59398 L .358 .59199 L F
.995 .865 .577 r
.24036 .54464 m .23885 .54674 L .23992 .54741 L F
.646 .922 .637 r
.24126 .54336 m .24036 .54464 L .24209 .54271 L F
.656 .516 .681 r
.24036 .54464 m .23992 .54741 L .2431 .54701 L F
0 0 0 r
.24023 .54532 m .24036 .54464 L .24126 .54336 L F
.24023 .54532 m .23885 .54674 L .24036 .54464 L F
.68 .969 .925 r
.26068 .76664 m .26483 .76457 L .26353 .76424 L F
.827 .991 .865 r
.26486 .7628 m .26483 .76457 L .26353 .76424 L F
.26486 .7628 m .26483 .76457 L .26353 .76424 L F
.203 0 0 r
.28292 .63687 m .28238 .63557 L .28084 .6376 L F
.255 0 0 r
.28292 .63687 m .28494 .63514 L .28238 .63557 L F
.559 .067 0 r
.39905 .54662 m .40182 .54959 L .40059 .54784 L F
.332 .001 .245 r
.2052 .55611 m .20737 .55568 L .20841 .55289 L F
.115 0 .146 r
.20841 .55289 m .20928 .55468 L .21056 .55225 L F
.20841 .55289 m .20737 .55568 L .20928 .55468 L F
.517 .357 .603 r
.38633 .63252 m .38647 .63496 L .38403 .63555 L F
.699 .356 .392 r
.34625 .70432 m .3507 .70438 L .34846 .70682 L F
.822 .532 .499 r
.3507 .70438 m .35221 .70788 L .34846 .70682 L F
.887 .97 .834 r
.32862 .51752 m .32645 .51946 L .3283 .51963 L F
.599 .65 .872 r
.33047 .51811 m .32741 .51608 L .32949 .5178 L F
0 .183 .688 r
.32875 .51669 m .33041 .51856 L .32741 .51608 L F
.887 .97 .834 r
.32875 .51669 m .32817 .51738 L .32862 .51752 L F
.32817 .51738 m .32645 .51946 L .32862 .51752 L F
.599 .65 .872 r
.33284 .51968 m .33047 .51811 L .33041 .51856 L F
.33047 .51811 m .32949 .5178 L .33041 .51856 L F
.528 .254 .442 r
.33284 .51968 m .33207 .52243 L .3291 .52298 L F
.217 .739 .836 r
.33041 .51856 m .33455 .51828 L .33284 .51968 L F
.217 .133 .54 r
.18885 .5819 m .19018 .58135 L .19047 .57798 L F
.289 .316 .716 r
.18885 .5819 m .19116 .58387 L .19018 .58135 L F
.32 .291 .67 r
.39698 .67528 m .3964 .67657 L .39863 .6758 L F
.39698 .67528 m .3954 .67863 L .3964 .67657 L F
.422 .228 .51 r
.38342 .58821 m .38566 .59014 L .38693 .58763 L F
.38342 .58821 m .38335 .5908 L .38566 .59014 L F
.047 0 .351 r
.33523 .64426 m .33453 .64211 L .3367 .64031 L F
0 0 .343 r
.25958 .7639 m .26068 .76664 L .26032 .76403 L F
.271 0 .294 r
.32857 .54721 m .32629 .5516 L .32819 .55004 L F
.325 .121 .442 r
.32857 .54721 m .33066 .54655 L .33082 .54365 L F
.207 0 .275 r
.32857 .54721 m .33046 .54667 L .33066 .54655 L F
.32857 .54721 m .32819 .55004 L .33046 .54667 L F
.722 .197 0 r
.28954 .6478 m .28953 .64929 L .28721 .64747 L F
.28954 .6478 m .29156 .64973 L .28953 .64929 L F
.476 0 0 r
.33272 .6547 m .3299 .65269 L .33191 .65074 L F
.973 .711 .295 r
.3321 .65438 m .33272 .6547 L .33191 .65074 L F
.468 .239 .482 r
.33444 .65685 m .33272 .6547 L .33231 .65725 L F
.33444 .65685 m .3349 .6538 L .33272 .6547 L F
.595 .825 .987 r
.19773 .59948 m .19778 .59771 L .1955 .59861 L F
.19773 .59948 m .20049 .59844 L .19778 .59771 L F
.714 .879 .48 r
.32337 .62095 m .32279 .62245 L .32455 .61949 L F
0 0 .535 r
.32337 .62095 m .32423 .6248 L .32279 .62245 L F
.579 .578 .815 r
.32887 .56315 m .33129 .56253 L .32983 .55886 L F
.338 .808 .917 r
.64002 .39962 m .64262 .3991 L .64373 .39939 L F
.087 .482 .895 r
.64546 .39897 m .64373 .39939 L .64262 .3991 L F
.64546 .39897 m .647 .4007 L .64373 .39939 L F
.723 .729 .855 r
.34314 .57164 m .34449 .57328 L .34643 .57177 L F
.776 .767 .845 r
.62454 .40502 m .62547 .40899 L .62196 .40792 L F
.833 .467 .361 r
.62196 .40792 m .62547 .40899 L .62593 .4112 L F
.483 .487 .786 r
.62709 .40408 m .62547 .40899 L .62454 .40502 L F
.633 .139 .059 r
.62547 .40899 m .62849 .40967 L .62593 .4112 L F
0 0 .551 r
.71321 .34541 m .71262 .34203 L .71651 .34237 L F
0 .014 .583 r
.36372 .51632 m .3648 .51673 L .36256 .51493 L F
.36372 .51632 m .36511 .51816 L .3648 .51673 L F
.752 .669 .77 r
.72708 .34334 m .72266 .34273 L .72611 .34284 L F
.134 0 .154 r
.27774 .54053 m .28038 .53987 L .28038 .53756 L F
0 0 .306 r
.28038 .53756 m .2819 .53654 L .28275 .53358 L F
0 0 .039 r
.28038 .53756 m .28057 .53883 L .2819 .53654 L F
.28038 .53756 m .28038 .53987 L .28057 .53883 L F
.108 .297 .773 r
.35992 .62488 m .35933 .62656 L .35747 .62291 L F
.628 .879 .988 r
.35992 .62488 m .36195 .62581 L .35933 .62656 L F
.663 .963 .768 r
.37601 .56685 m .37671 .56553 L .37727 .56534 L F
.51 .16 .308 r
.37834 .56808 m .37601 .56685 L .37727 .56534 L F
.756 .715 .814 r
.31062 .52527 m .31443 .52572 L .31239 .52338 L F
.653 .384 .5 r
.31101 .52639 m .31443 .52572 L .31062 .52527 L F
.31101 .52639 m .31421 .5275 L .31443 .52572 L F
.75 .714 .818 r
.31239 .52338 m .31443 .52572 L .31721 .52329 L F
0 0 .32 r
.30732 .59562 m .30642 .5945 L .30749 .59326 L F
.30732 .59562 m .30606 .59713 L .30642 .5945 L F
0 0 0 r
.32771 .59901 m .32748 .59831 L .32864 .59657 L F
.32771 .59901 m .32528 .60045 L .32748 .59831 L F
0 0 .335 r
.37727 .56534 m .37877 .56138 L .37806 .56295 L F
.1 .607 .894 r
.24914 .63133 m .24721 .63042 L .2467 .63071 L F
.445 0 0 r
.24914 .63133 m .25044 .6322 L .24721 .63042 L F
.625 .061 0 r
.24721 .63042 m .25044 .6322 L .24935 .63221 L F
0 .21 .735 r
.24721 .63042 m .24935 .63221 L .24787 .63005 L F
.24721 .63042 m .24787 .63005 L .24748 .62948 L F
.1 .607 .894 r
.2467 .63071 m .24721 .63042 L .24471 .63021 L F
0 0 0 r
.34494 .57586 m .3421 .57873 L .34358 .57803 L F
0 0 .156 r
.3421 .57873 m .34269 .57954 L .34358 .57803 L F
.3421 .57873 m .34202 .58138 L .34269 .57954 L F
.632 .32 .425 r
.31115 .62765 m .31482 .62482 L .31311 .62603 L F
.637 .804 .963 r
.36391 .66679 m .36182 .66791 L .35968 .66616 L F
.485 .518 .816 r
.34314 .57164 m .34494 .57586 L .34657 .57454 L F
.364 .104 .38 r
.34358 .57803 m .34657 .57454 L .34494 .57586 L F
.387 .696 .982 r
.35326 .50561 m .35249 .50708 L .35099 .50569 L F
.35326 .50561 m .35475 .50703 L .35249 .50708 L F
.842 .828 .833 r
.71911 .31097 m .71661 .31365 L .71973 .31401 L F
.914 .935 .809 r
.71973 .31401 m .72091 .30936 L .71911 .31097 L F
.71973 .31401 m .72183 .31033 L .72091 .30936 L F
.427 .852 .95 r
.26564 .52537 m .26518 .52636 L .26322 .52597 L F
.26564 .52537 m .26751 .52571 L .26518 .52636 L F
.925 .728 .617 r
.30005 .64743 m .30166 .65081 L .30198 .64809 L F
.394 .499 .848 r
.27681 .63001 m .27422 .62987 L .27585 .62795 L F
.704 .326 .329 r
.36306 .70784 m .36684 .70992 L .3628 .71044 L F
.445 .401 .716 r
.33082 .54365 m .33242 .53958 L .32978 .5408 L F
.33082 .54365 m .33344 .54362 L .33242 .53958 L F
.49 .286 .529 r
.33066 .54655 m .33344 .54362 L .33082 .54365 L F
.422 .062 .247 r
.37887 .70269 m .37835 .70401 L .37586 .70441 L F
.517 .241 .436 r
.38196 .70174 m .37835 .70401 L .37887 .70269 L F
.074 .382 .844 r
.27877 .64161 m .28112 .64461 L .28163 .6433 L F
0 .207 .731 r
.28163 .6433 m .28112 .64461 L .28365 .64679 L F
.639 .698 .889 r
.23593 .54832 m .23992 .54741 L .23885 .54674 L F
.23593 .54832 m .23957 .54976 L .23992 .54741 L F
.589 .307 .456 r
.23957 .54976 m .2431 .54701 L .23992 .54741 L F
.176 0 .132 r
.29941 .5451 m .29592 .54601 L .30128 .54349 L F
.29941 .5451 m .29735 .54613 L .29592 .54601 L F
.65 .917 .618 r
.36966 .52529 m .36792 .52669 L .36694 .52818 L F
.905 .547 .35 r
.36966 .52529 m .36792 .52669 L .36942 .52714 L F
.705 .425 .498 r
.37254 .52529 m .36942 .52714 L .36966 .52529 L F
.866 .873 .432 r
.36144 .60761 m .3614 .6082 L .36173 .60785 L F
.514 .817 .489 r
.36226 .6073 m .36173 .60785 L .36071 .60893 L F
.866 .873 .432 r
.3614 .6082 m .36126 .60987 L .36173 .60785 L F
.514 .817 .489 r
.36327 .60623 m .36173 .60785 L .36226 .6073 L F
.26 .045 .386 r
.34618 .55141 m .34586 .55318 L .34772 .55228 L F
.497 .361 .626 r
.34402 .52554 m .34386 .52819 L .34217 .52435 L F
.34402 .52554 m .34637 .52776 L .34386 .52819 L F
.211 0 .23 r
.39152 .68602 m .39088 .68805 L .38916 .68832 L F
.359 .253 .596 r
.3912 .69083 m .38916 .68832 L .39088 .68805 L F
.3912 .69083 m .38974 .69148 L .38916 .68832 L F
.782 .57 .613 r
.35466 .58431 m .3592 .58186 L .35488 .5813 L F
.446 .326 .622 r
.3592 .58186 m .36166 .58433 L .36132 .58115 L F
.194 .168 .599 r
.19002 .58817 m .19119 .58778 L .19116 .58387 L F
.229 .281 .709 r
.19002 .58817 m .19227 .59029 L .19119 .58778 L F
.597 .603 .829 r
.21971 .58835 m .21482 .58509 L .21779 .58255 L F
.81 .81 .85 r
.31062 .52527 m .30887 .52769 L .31101 .52639 L F
.531 .232 .405 r
.30887 .52769 m .30996 .53014 L .31101 .52639 L F
0 0 .053 r
.31101 .52639 m .31125 .5288 L .31421 .5275 L F
.31101 .52639 m .30996 .53014 L .31125 .5288 L F
.465 .86 .973 r
.25223 .52833 m .25263 .52952 L .25025 .52949 L F
.25223 .52833 m .25496 .52886 L .25263 .52952 L F
.249 .266 .682 r
.34613 .64124 m .34653 .64489 L .34843 .64346 L F
.47 .369 .658 r
.34688 .64746 m .34972 .65007 L .34825 .64765 L F
.137 0 0 r
.34743 .6479 m .34688 .64746 L .34825 .64765 L F
0 0 .219 r
.34653 .64489 m .34743 .6479 L .34843 .64346 L F
.34653 .64489 m .34688 .64746 L .34743 .6479 L F
.726 .854 .942 r
.25468 .61631 m .25261 .6176 L .25102 .61611 L F
.56 .574 .825 r
.25907 .54409 m .2614 .5435 L .25983 .5398 L F
.077 0 0 r
.2577 .5378 m .25335 .5396 L .25533 .53961 L F
.589 .04 0 r
.25597 .53892 m .25807 .53871 L .25575 .53906 L F
.2577 .5378 m .25807 .53871 L .25597 .53892 L F
.2577 .5378 m .25894 .53897 L .25807 .53871 L F
.25894 .53897 m .25983 .5398 L .25807 .53871 L F
.289 .263 .655 r
.25927 .53718 m .25983 .5398 L .2577 .5378 L F
.026 .08 .582 r
.26041 .53875 m .25983 .5398 L .25927 .53718 L F
.141 .684 .819 r
.25985 .53853 m .25757 .53855 L .25807 .53871 L F
.25757 .53855 m .25608 .53857 L .25807 .53871 L F
.026 .08 .582 r
.26041 .53875 m .25927 .53718 L .26123 .53558 L F
0 0 .007 r
.26123 .53558 m .26067 .53852 L .26041 .53875 L F
.141 .684 .819 r
.26067 .53852 m .25985 .53853 L .25807 .53871 L F
.367 .794 .97 r
.25807 .53871 m .25779 .53868 L .25575 .53906 L F
.077 0 0 r
.2577 .5378 m .25575 .53906 L .25378 .53942 L F
.367 .794 .97 r
.25779 .53868 m .25414 .53841 L .25575 .53906 L F
.077 0 0 r
.25378 .53942 m .25575 .53906 L .25335 .5396 L F
.092 0 .17 r
.26028 .53467 m .25927 .53718 L .2577 .5378 L F
.601 .909 .645 r
.24762 .55118 m .24768 .55161 L .24984 .54995 L F
.24762 .55118 m .24549 .55316 L .24768 .55161 L F
.68 .969 .925 r
.26068 .76664 m .26353 .76424 L .26032 .76403 L F
.433 .119 .332 r
.35483 .55925 m .3508 .56223 L .35099 .55972 L F
.35483 .55925 m .35334 .56208 L .3508 .56223 L F
.537 .228 .391 r
.35699 .56117 m .35483 .55925 L .35711 .55979 L F
.35699 .56117 m .35334 .56208 L .35483 .55925 L F
.214 .236 .668 r
.35483 .55925 m .35699 .56117 L .35711 .55979 L F
.604 .29 .412 r
.72737 .34879 m .7244 .35068 L .72441 .3493 L F
.56 .179 .277 r
.37239 .5378 m .37192 .5396 L .37099 .53708 L F
.37239 .5378 m .37447 .5396 L .37192 .5396 L F
.37192 .5396 m .37447 .5396 L .37239 .5378 L F
.247 .039 .388 r
.31084 .53793 m .3096 .5411 L .31229 .53832 L F
0 0 .01 r
.34386 .52819 m .34135 .53161 L .3419 .52923 L F
.34386 .52819 m .34298 .53061 L .34135 .53161 L F
.586 .219 .312 r
.34135 .53161 m .3437 .53331 L .34682 .53089 L F
.3437 .53331 m .34396 .53349 L .34441 .53308 L F
.3437 .53331 m .34441 .53308 L .34682 .53089 L F
.392 0 .146 r
.34793 .53285 m .35104 .53145 L .34772 .53174 L F
.595 .892 .6 r
.34682 .53089 m .34396 .53349 L .34651 .53092 L F
.307 .386 .78 r
.34851 .52934 m .34808 .53193 L .34651 .53092 L F
.595 .892 .6 r
.34682 .53089 m .34793 .53285 L .34772 .53174 L F
.307 .386 .78 r
.34808 .53193 m .34793 .53285 L .34741 .53214 L F
.595 .892 .6 r
.34682 .53089 m .34651 .53092 L .34793 .53285 L F
.307 .386 .78 r
.34808 .53193 m .34741 .53214 L .34651 .53092 L F
.218 .305 .74 r
.34298 .53061 m .34396 .53349 L .34135 .53161 L F
.817 .634 .654 r
.33594 .54115 m .33775 .54195 L .33632 .54071 L F
.33242 .53958 m .33344 .54362 L .33775 .54195 L F
.443 .08 .251 r
.33257 .54631 m .33674 .54281 L .33344 .54362 L F
.33674 .54281 m .33775 .54195 L .33655 .54242 L F
.33674 .54281 m .33655 .54242 L .33344 .54362 L F
.33674 .54281 m .33741 .54308 L .33775 .54195 L F
.935 .8 .338 r
.33775 .54195 m .33749 .54433 L .33741 .54308 L F
.443 .08 .251 r
.33741 .54308 m .33749 .54311 L .33775 .54195 L F
.935 .8 .338 r
.33775 .54195 m .33713 .53838 L .33456 .53919 L F
.33775 .54195 m .33741 .54308 L .33713 .53838 L F
.213 .328 .765 r
.33721 .53972 m .33742 .5431 L .3378 .53905 L F
.33742 .5431 m .33749 .54433 L .33756 .54313 L F
.33742 .5431 m .33756 .54313 L .3378 .53905 L F
.34 0 .221 r
.33775 .54195 m .33797 .54323 L .33749 .54433 L F
.33797 .54323 m .33827 .54498 L .33749 .54433 L F
.33775 .54195 m .33749 .54311 L .33797 .54323 L F
.213 .328 .765 r
.3378 .53905 m .33756 .54314 L .33829 .54248 L F
.33919 .54041 m .33829 .54248 L .33987 .54107 L F
.3378 .53905 m .33829 .54248 L .33919 .54041 L F
.34 0 .221 r
.33797 .54323 m .33688 .54575 L .33827 .54498 L F
.213 .328 .765 r
.33756 .54314 m .33749 .54433 L .33817 .54339 L F
.34 0 .221 r
.33749 .54311 m .33688 .54575 L .33797 .54323 L F
.443 .08 .251 r
.33257 .54631 m .33688 .54575 L .33749 .54311 L F
.33257 .54631 m .33749 .54311 L .33674 .54281 L F
.213 .328 .765 r
.33756 .54314 m .33817 .54339 L .33987 .54107 L F
.33713 .53838 m .33721 .53972 L .3378 .53905 L F
.817 .634 .654 r
.33242 .53958 m .33594 .54115 L .33456 .53919 L F
.33594 .54115 m .33632 .54071 L .33456 .53919 L F
.691 .529 .662 r
.38374 .53793 m .38404 .54152 L .37935 .54109 L F
.364 .283 .631 r
.38512 .54021 m .38404 .54152 L .38374 .53793 L F
.675 .134 0 r
.32617 .5203 m .32358 .52044 L .32361 .5198 L F
.439 .877 .873 r
.32645 .51946 m .32617 .5203 L .3283 .51963 L F
.32645 .51946 m .32358 .52044 L .32617 .5203 L F
.369 0 0 r
.35323 .54878 m .35169 .54798 L .35473 .54951 L F
.35323 .54878 m .35046 .54911 L .35169 .54798 L F
.622 .099 0 r
.39622 .67142 m .39499 .66964 L .39317 .66938 L F
0 .072 .607 r
.39719 .67215 m .39798 .67276 L .39811 .67319 L F
.39499 .66964 m .39798 .67276 L .39719 .67215 L F
.155 0 .257 r
.39959 .67169 m .39852 .67317 L .39798 .67276 L F
.974 .803 .609 r
.39798 .67276 m .39863 .6758 L .39811 .67319 L F
.39798 .67276 m .39698 .67528 L .39863 .6758 L F
.155 0 .257 r
.39852 .67317 m .39698 .67528 L .39798 .67276 L F
.622 .099 0 r
.39622 .67142 m .39798 .67276 L .39592 .67061 L F
.636 .86 .984 r
.39959 .67169 m .39798 .67276 L .39622 .67142 L F
.891 .884 .819 r
.39541 .67422 m .39959 .67169 L .39622 .67142 L F
0 0 0 r
.3965 .67219 m .39622 .67142 L .39621 .66986 L F
.3965 .67222 m .39622 .67142 L .3965 .67219 L F
.622 .099 0 r
.39622 .67142 m .39592 .67061 L .39499 .66964 L F
.676 .156 0 r
.34433 .54479 m .34059 .54352 L .34095 .5454 L F
.76 .315 .196 r
.62244 .43954 m .62623 .44038 L .62638 .44195 L F
.632 .209 .222 r
.62623 .44038 m .62895 .44224 L .62638 .44195 L F
.481 .325 .592 r
.62883 .43947 m .62895 .44224 L .62623 .44038 L F
.016 .277 .776 r
.29171 .64158 m .29267 .6427 L .29042 .64102 L F
.453 .856 .677 r
.32924 .6389 m .32586 .64095 L .32805 .64243 L F
.662 .835 .417 r
.33136 .63534 m .32924 .6389 L .33088 .63774 L F
.083 0 .219 r
.33088 .63774 m .32924 .6389 L .32805 .64243 L F
.375 .156 .449 r
.38676 .6949 m .38675 .69789 L .38427 .69776 L F
.356 .052 .305 r
.38675 .69789 m .38363 .70035 L .38427 .69776 L F
.191 0 0 r
.22137 .54327 m .22374 .54282 L .22562 .54109 L F
0 0 0 r
.22562 .54109 m .22586 .542 L .22786 .54035 L F
.22562 .54109 m .22378 .54278 L .22586 .542 L F
.012 0 0 r
.22786 .54035 m .22586 .542 L .2281 .54123 L F
.335 .817 .859 r
.22394 .54197 m .22778 .54129 L .22586 .542 L F
.22778 .54129 m .2281 .54123 L .22586 .542 L F
0 0 0 r
.22378 .54278 m .22374 .54282 L .22586 .542 L F
.39 .246 .562 r
.33558 .5684 m .33418 .56986 L .33355 .56924 L F
0 0 .551 r
.71321 .34541 m .7138 .34337 L .71262 .34203 L F
0 .156 .663 r
.71321 .34541 m .71512 .34656 L .7138 .34337 L F
.71321 .34541 m .71617 .34787 L .71512 .34656 L F
.639 .286 .356 r
.38693 .58763 m .3881 .58996 L .38974 .58579 L F
.38693 .58763 m .38566 .59014 L .3881 .58996 L F
.721 .953 .95 r
.29996 .52171 m .29583 .5225 L .29862 .5218 L F
.445 .88 .875 r
.29996 .52171 m .30089 .52078 L .30229 .52081 L F
.455 .886 .855 r
.29996 .52171 m .29862 .5218 L .30089 .52078 L F
.574 .859 .533 r
.21482 .58509 m .21452 .5853 L .21622 .58343 L F
.227 .236 .661 r
.36792 .52669 m .36693 .53089 L .36694 .52818 L F
.615 .449 .634 r
.71415 .31774 m .71485 .32031 L .71199 .32071 L F
.18 .054 .462 r
.71661 .31365 m .71563 .31724 L .71415 .31774 L F
.652 .823 .965 r
.71617 .31764 m .71415 .31774 L .71563 .31724 L F
.71617 .31764 m .71485 .32031 L .71415 .31774 L F
.665 .369 .462 r
.39249 .60088 m .39407 .60443 L .38853 .60282 L F
.578 .535 .771 r
.39335 .59913 m .39407 .60443 L .39249 .60088 L F
.689 .957 .707 r
.35356 .61183 m .35279 .61327 L .35059 .6147 L F
.558 .703 .937 r
.29945 .62774 m .30028 .62974 L .29815 .62959 L F
.645 .495 .664 r
.30028 .62974 m .29843 .63162 L .29815 .62959 L F
.30028 .62974 m .29843 .63162 L .29815 .62959 L F
.285 .641 .966 r
.39242 .60569 m .39091 .60606 L .38965 .60523 L F
.39242 .60569 m .3934 .60677 L .39091 .60606 L F
.277 0 .243 r
.23064 .56852 m .22758 .57169 L .22845 .5692 L F
.285 .644 .967 r
.36418 .50929 m .36261 .5103 L .3611 .50911 L F
.36418 .50929 m .36556 .51055 L .36261 .5103 L F
.926 .744 .636 r
.61041 .41198 m .60839 .41333 L .60761 .41063 L F
.61041 .41198 m .61035 .41449 L .60839 .41333 L F
.078 0 0 r
.19391 .56752 m .19684 .56515 L .19517 .56635 L F
.858 .404 .049 r
.34601 .51186 m .34301 .50996 L .34401 .5117 L F
.34601 .51186 m .34325 .50886 L .34301 .50996 L F
.32 .121 .446 r
.33918 .62594 m .34101 .62769 L .34181 .62583 L F
.33918 .62594 m .33902 .62841 L .34101 .62769 L F
.587 .928 .957 r
.26087 .5272 m .25882 .52828 L .25719 .52804 L F
.628 .272 .348 r
.26658 .55558 m .26392 .55572 L .26433 .55348 L F
.56 .288 .46 r
.26716 .55349 m .26658 .55558 L .26433 .55348 L F
0 0 0 r
.37387 .65356 m .37103 .65643 L .37202 .65473 L F
.704 .767 .901 r
.34214 .59918 m .34336 .60074 L .33964 .60034 L F
.538 .699 .943 r
.34472 .59892 m .34336 .60074 L .34214 .59918 L F
.257 .3 .716 r
.34472 .59892 m .34569 .60271 L .34336 .60074 L F
.41 .309 .628 r
.34569 .60271 m .34378 .60365 L .34336 .60074 L F
.509 .861 .991 r
.27488 .52546 m .26944 .52566 L .27217 .52517 L F
.491 .889 .95 r
.27673 .52459 m .27488 .52546 L .27217 .52517 L F
.686 .434 .536 r
.71199 .32071 m .71219 .32306 L .70854 .32308 L F
.64 .433 .587 r
.71485 .32031 m .71219 .32306 L .71199 .32071 L F
.686 .798 .935 r
.61792 .40701 m .61947 .40866 L .61551 .40809 L F
.783 .69 .762 r
.61551 .40809 m .61947 .40866 L .61683 .41188 L F
.66 .505 .663 r
.61947 .40866 m .62048 .41094 L .61683 .41188 L F
.555 .748 .967 r
.62196 .40792 m .61947 .40866 L .61792 .40701 L F
.204 .262 .702 r
.6219 .41045 m .61947 .40866 L .62196 .40792 L F
.6219 .41045 m .62048 .41094 L .61947 .40866 L F
.583 .68 .907 r
.386 .65833 m .38187 .65692 L .38421 .65637 L F
.743 .747 .855 r
.38793 .65666 m .386 .65833 L .38421 .65637 L F
0 0 .153 r
.2429 .55372 m .24262 .55511 L .24165 .55605 L F
.061 0 .236 r
.2427 .5578 m .24165 .55605 L .24262 .55511 L F
.2427 .5578 m .24125 .55879 L .24165 .55605 L F
.55 .872 .591 r
.34616 .58083 m .34582 .58138 L .34826 .58103 L F
.883 .483 .262 r
.34269 .57954 m .3452 .58172 L .34616 .58083 L F
.55 .872 .591 r
.34599 .58111 m .34487 .58203 L .34582 .58138 L F
.34616 .58083 m .3452 .58172 L .34599 .58111 L F
.3452 .58172 m .34487 .58203 L .34599 .58111 L F
.883 .483 .262 r
.34269 .57954 m .34344 .58197 L .34465 .58215 L F
.778 .982 .72 r
.34433 .58377 m .34616 .58083 L .34591 .58233 L F
.34433 .58377 m .34438 .58237 L .34443 .58232 L F
.883 .483 .262 r
.34269 .57954 m .34465 .58215 L .3452 .58172 L F
.55 .872 .591 r
.34514 .58178 m .34438 .58237 L .34487 .58203 L F
.34616 .58083 m .34448 .58228 L .34514 .58178 L F
.34448 .58228 m .34438 .58237 L .34514 .58178 L F
.778 .982 .72 r
.34433 .58377 m .34443 .58232 L .34474 .58216 L F
.34558 .58176 m .34474 .58216 L .34562 .58169 L F
.34433 .58377 m .34474 .58216 L .34558 .58176 L F
0 0 0 r
.34591 .58233 m .3446 .5842 L .34433 .58377 L F
.15 0 0 r
.34571 .58493 m .3446 .5842 L .34591 .58233 L F
.34571 .58493 m .34591 .58233 L .34474 .58216 L F
.34467 .58219 m .34474 .58216 L .34465 .58215 L F
.34571 .58493 m .34474 .58216 L .34467 .58219 L F
0 .242 .754 r
.34202 .58138 m .34438 .58237 L .34433 .58377 L F
.15 0 0 r
.34398 .58266 m .34465 .58215 L .34344 .58197 L F
.34571 .58493 m .34465 .58215 L .34398 .58266 L F
.883 .483 .262 r
.3452 .58172 m .34465 .58215 L .34474 .58216 L F
.3452 .58172 m .34474 .58216 L .34534 .58184 L F
.3452 .58172 m .34534 .58184 L .34616 .58083 L F
.778 .982 .72 r
.34562 .58169 m .34534 .58184 L .34616 .58083 L F
.883 .483 .262 r
.34534 .58184 m .34591 .58233 L .34616 .58083 L F
.778 .982 .72 r
.34534 .58184 m .34443 .58232 L .34616 .58083 L F
.883 .483 .262 r
.34534 .58184 m .34474 .58216 L .34591 .58233 L F
.645 .352 .459 r
.37617 .52443 m .37212 .52766 L .37254 .52529 L F
.37617 .52443 m .37611 .52748 L .37212 .52766 L F
0 0 .062 r
.26123 .53558 m .26028 .53467 L .26265 .53372 L F
.26123 .53558 m .25927 .53718 L .26028 .53467 L F
.332 0 0 r
.33092 .67734 m .33037 .67614 L .32997 .67836 L F
.33092 .67734 m .3333 .67632 L .33037 .67614 L F
.919 .907 .795 r
.33281 .67304 m .33355 .67387 L .33092 .67734 L F
.669 .97 .796 r
.33511 .67474 m .33092 .67734 L .33355 .67387 L F
.919 .907 .795 r
.33281 .67304 m .33092 .67734 L .33229 .67611 L F
.517 .865 .611 r
.33147 .67676 m .33092 .67734 L .3289 .67881 L F
.33229 .67611 m .33092 .67734 L .33147 .67676 L F
.332 0 0 r
.33092 .67734 m .32997 .67836 L .32991 .67867 L F
.621 .472 .659 r
.35792 .61261 m .35719 .61679 L .35653 .61636 L F
0 0 .35 r
.3595 .61431 m .35792 .61261 L .35843 .61144 L F
.3595 .61431 m .35719 .61679 L .35792 .61261 L F
.756 .244 0 r
.63123 .40521 m .63412 .40777 L .63304 .40627 L F
.813 .708 .172 r
.31844 .61602 m .31841 .61949 L .31876 .61801 L F
0 0 .222 r
.31841 .61949 m .31912 .62117 L .31876 .61801 L F
.31841 .61949 m .31815 .6226 L .31912 .62117 L F
.451 .497 .815 r
.32782 .66585 m .32906 .66987 L .3312 .66979 L F
.415 0 .11 r
.31844 .61602 m .32206 .61526 L .32293 .61293 L F
0 0 0 r
.32417 .61222 m .32589 .61069 L .32293 .61293 L F
.32293 .61293 m .32326 .61398 L .32417 .61222 L F
.32293 .61293 m .32206 .61526 L .32326 .61398 L F
.032 0 .287 r
.21285 .57792 m .21109 .58126 L .21095 .57861 L F
.573 .439 .661 r
.34453 .65144 m .34749 .65082 L .34688 .64746 L F
.759 .556 .623 r
.34427 .65325 m .34749 .65082 L .34453 .65144 L F
.41 .538 .874 r
.35629 .58846 m .358 .59199 L .35871 .58893 L F
.548 .427 .666 r
.36074 .59397 m .358 .59199 L .36017 .5903 L F
0 0 0 r
.358 .59199 m .3594 .59172 L .35871 .58893 L F
.548 .427 .666 r
.36074 .59397 m .35824 .59508 L .358 .59199 L F
0 0 0 r
.358 .59199 m .35693 .59398 L .3594 .59172 L F
.442 .186 .429 r
.27485 .61882 m .27721 .62034 L .27781 .61617 L F
.116 0 .109 r
.27485 .61882 m .27579 .62023 L .27721 .62034 L F
.27485 .61882 m .27379 .62166 L .27579 .62023 L F
.669 .722 .889 r
.26265 .53372 m .26713 .53508 L .26527 .53307 L F
.624 .766 .947 r
.26527 .53307 m .26713 .53508 L .26895 .53391 L F
0 .098 .654 r
.26713 .53508 m .26865 .53631 L .26895 .53391 L F
.26713 .53508 m .26884 .53795 L .26865 .53631 L F
.874 .538 .032 r
.41628 .54402 m .41565 .5434 L .41482 .54033 L F
.964 .924 .59 r
.41565 .5434 m .41465 .54554 L .41628 .54402 L F
.874 .538 .032 r
.41482 .54033 m .41565 .5434 L .41628 .54402 L F
.964 .924 .59 r
.41628 .54402 m .41465 .54554 L .41565 .5434 L F
.231 0 0 r
.33314 .63549 m .33136 .63534 L .33088 .63774 L F
.889 .925 .839 r
.32128 .66388 m .32415 .66054 L .32223 .66022 L F
.643 .935 .967 r
.32223 .66022 m .32415 .66054 L .32461 .65905 L F
.464 .447 .754 r
.35541 .56587 m .35763 .56565 L .35699 .56117 L F
.513 .243 .443 r
.35448 .56865 m .35763 .56565 L .35541 .56587 L F
.826 .736 .765 r
.35057 .5801 m .35481 .57849 L .35367 .57695 L F
.35057 .5801 m .35234 .58175 L .35481 .57849 L F
.705 .551 .676 r
.35481 .57849 m .35234 .58175 L .35488 .5813 L F
.409 0 0 r
.35736 .57593 m .35367 .57695 L .35481 .57849 L F
0 .28 .686 r
.2942 .64404 m .29414 .6442 L .29267 .6427 L F
.2942 .64404 m .29558 .64493 L .29414 .6442 L F
.57 .798 .985 r
.33585 .50906 m .33337 .50971 L .33166 .50827 L F
.33166 .50827 m .33337 .50971 L .33585 .50906 L F
.714 .269 .192 r
.34601 .62129 m .34891 .62033 L .34825 .62036 L F
.531 .255 .441 r
.2254 .5746 m .22194 .57716 L .22296 .57477 L F
.758 .596 .677 r
.38683 .55957 m .38751 .5626 L .38346 .56217 L F
.082 0 0 r
.38683 .55957 m .38594 .56152 L .38346 .56217 L F
.366 .22 .547 r
.38751 .5626 m .38971 .55904 L .38683 .55957 L F
0 0 0 r
.38731 .56012 m .38683 .55957 L .38971 .55904 L F
.38731 .56012 m .38594 .56152 L .38683 .55957 L F
.556 .561 .814 r
.33876 .55567 m .34025 .55914 L .33772 .55959 L F
.601 .272 .385 r
.33999 .5617 m .33772 .55959 L .34025 .55914 L F
.33999 .5617 m .33746 .56203 L .33772 .55959 L F
.264 .745 .929 r
.25286 .63477 m .25294 .63407 L .25044 .6322 L F
.25286 .63477 m .2548 .63456 L .25294 .63407 L F
.369 .138 .428 r
.27832 .7419 m .27869 .7391 L .28073 .73852 L F
.28073 .73852 m .27869 .7391 L .27832 .7419 L F
.764 .608 .685 r
.36248 .56627 m .36233 .56901 L .35966 .56876 L F
.749 .671 .775 r
.36494 .56576 m .36233 .56901 L .36248 .56627 L F
0 0 0 r
.32586 .64095 m .32341 .64485 L .32472 .64351 L F
.295 .338 .736 r
.32341 .64485 m .32656 .64762 L .32472 .64351 L F
.489 .173 .357 r
.2743 .54364 m .27697 .54338 L .27774 .54053 L F
.286 0 .281 r
.27774 .54053 m .2792 .54241 L .28038 .53987 L F
.27774 .54053 m .27697 .54338 L .2792 .54241 L F
.292 0 0 r
.35678 .60513 m .3587 .60532 L .3605 .60367 L F
.785 .779 .847 r
.35942 .59759 m .35841 .60375 L .3605 .60367 L F
.762 .582 .654 r
.3587 .60532 m .36193 .60356 L .3605 .60367 L F
0 0 .214 r
.34964 .61622 m .35052 .61778 L .35059 .6147 L F
.34964 .61622 m .34891 .62033 L .35052 .61778 L F
.677 .335 .388 r
.71591 .31066 m .71232 .31287 L .71473 .30941 L F
.71591 .31066 m .71354 .31342 L .71232 .31287 L F
.759 .701 .796 r
.71761 .30614 m .71591 .31066 L .71473 .30941 L F
.71761 .30614 m .71855 .30789 L .71591 .31066 L F
0 0 .362 r
.35359 .53867 m .35269 .53798 L .35516 .53715 L F
.35359 .53867 m .35302 .54068 L .35269 .53798 L F
.864 .995 .805 r
.31062 .52527 m .30823 .52637 L .30887 .52769 L F
.659 .299 0 r
.30823 .52637 m .30996 .53014 L .30887 .52769 L F
.179 0 .037 r
.31409 .57711 m .31162 .57829 L .31507 .57562 L F
.29 0 .102 r
.31626 .57655 m .31507 .57562 L .31688 .57447 L F
.31626 .57655 m .31409 .57711 L .31507 .57562 L F
.92 .975 .764 r
.22189 .55607 m .21876 .55796 L .2196 .55983 L F
.872 .738 .224 r
.21888 .56079 m .2196 .55983 L .21876 .55796 L F
.21888 .56079 m .2193 .56266 L .2196 .55983 L F
.626 .413 .573 r
.2193 .56266 m .22404 .5596 L .2196 .55983 L F
0 0 0 r
.27781 .61617 m .27931 .61532 L .28056 .61318 L F
.224 0 .1 r
.27931 .61532 m .28251 .61246 L .28056 .61318 L F
.505 .73 .974 r
.38683 .66916 m .3913 .67058 L .38753 .67039 L F
.713 .584 .709 r
.72378 .30162 m .72113 .3048 L .7211 .30205 L F
.461 .072 .214 r
.23605 .56092 m .23568 .56202 L .23326 .56207 L F
.437 .081 .263 r
.23924 .56034 m .23568 .56202 L .23605 .56092 L F
0 0 0 r
.23297 .54902 m .23227 .54943 L .23072 .5502 L F
0 0 .179 r
.23227 .54943 m .23163 .55263 L .23072 .5502 L F
0 0 .217 r
.27781 .61617 m .27873 .61785 L .27931 .61532 L F
.27781 .61617 m .27721 .62034 L .27873 .61785 L F
0 0 0 r
.28864 .60395 m .28764 .60611 L .28984 .60252 L F
.02 0 0 r
.27111 .53882 m .27062 .53827 L .27232 .53636 L F
.27111 .53882 m .26877 .5394 L .27062 .53827 L F
.479 .301 .561 r
.39431 .68241 m .39415 .68535 L .39152 .68602 L F
.408 .103 .334 r
.39415 .68535 m .39088 .68805 L .39152 .68602 L F
.298 .316 .711 r
.3452 .63863 m .34742 .64084 L .34773 .63798 L F
.3452 .63863 m .34613 .64124 L .34742 .64084 L F
.339 .109 .412 r
.23476 .55352 m .23163 .55263 L .23244 .55342 L F
.311 .143 .484 r
.23689 .55006 m .23509 .55299 L .23664 .55219 L F
.715 .377 .405 r
.23466 .55318 m .23861 .55118 L .23664 .55219 L F
.447 .258 .529 r
.23689 .55006 m .23664 .55219 L .23925 .55085 L F
.715 .377 .405 r
.23861 .55118 m .23925 .55085 L .23664 .55219 L F
.311 .143 .484 r
.23509 .55299 m .23476 .55352 L .23664 .55219 L F
0 0 0 r
.23244 .55342 m .23664 .55219 L .23476 .55352 L F
.437 .411 .732 r
.35381 .51799 m .35194 .51877 L .35197 .51716 L F
.365 .219 .547 r
.35387 .52084 m .35194 .51877 L .35381 .51799 L F
.35387 .52084 m .35195 .52188 L .35194 .51877 L F
0 0 .219 r
.30181 .55522 m .30269 .55818 L .30201 .55575 L F
.889 .925 .839 r
.32128 .66388 m .32223 .66022 L .3197 .66033 L F
.817 .979 .69 r
.32955 .65265 m .33191 .65074 L .3299 .65269 L F
.32955 .65265 m .3299 .65269 L .32862 .65428 L F
.928 .653 .498 r
.32955 .65265 m .3321 .65438 L .33191 .65074 L F
.68 .43 .536 r
.38404 .54152 m .37907 .54252 L .37935 .54109 L F
.666 .608 .78 r
.37103 .65643 m .36927 .66143 L .36881 .65719 L F
.806 .658 .7 r
.7211 .30205 m .72113 .3048 L .71729 .30401 L F
.795 .691 .75 r
.72113 .3048 m .71855 .30789 L .71729 .30401 L F
.72 .574 .689 r
.72113 .3048 m .72122 .30926 L .71855 .30789 L F
.39 .309 .644 r
.72358 .30608 m .72122 .30926 L .72113 .3048 L F
.45 .219 .471 r
.37586 .70441 m .37551 .70688 L .3732 .7074 L F
.421 .194 .462 r
.37783 .70623 m .37586 .70441 L .37835 .70401 L F
.37783 .70623 m .37551 .70688 L .37586 .70441 L F
.71 .976 .918 r
.38187 .65692 m .37728 .65868 L .38007 .65638 L F
.41 .832 .965 r
.38007 .65638 m .38421 .65637 L .38187 .65692 L F
.688 .483 .603 r
.35719 .61679 m .35697 .61872 L .35653 .61636 L F
.904 .779 .712 r
.60839 .41333 m .61035 .41449 L .60834 .41774 L F
.192 .445 .872 r
.2095 .60606 m .21219 .60923 L .21326 .60936 L F
.457 .219 .464 r
.37774 .60706 m .37726 .60967 L .38068 .61052 L F
.579 .117 .121 r
.31187 .54708 m .31427 .54851 L .31547 .54721 L F
.665 .137 0 r
.31427 .54851 m .31746 .54695 L .31547 .54721 L F
.617 .562 .77 r
.38767 .62547 m .38619 .62691 L .38382 .62225 L F
0 0 .044 r
.38767 .62547 m .38506 .62864 L .38619 .62691 L F
.666 .608 .78 r
.37103 .65643 m .37268 .66116 L .36927 .66143 L F
.489 .138 .298 r
.3732 .7074 m .37209 .71024 L .36941 .71042 L F
.358 .015 .24 r
.37551 .70688 m .37209 .71024 L .3732 .7074 L F
.789 .664 .726 r
.71996 .2987 m .7211 .30205 L .71803 .30153 L F
.806 .658 .7 r
.7211 .30205 m .71729 .30401 L .71803 .30153 L F
.745 .642 .746 r
.38936 .66597 m .38683 .66916 L .38768 .667 L F
.272 0 0 r
.24848 .54046 m .2464 .54192 L .24414 .54205 L F
0 0 0 r
.25096 .54018 m .2464 .54192 L .24848 .54046 L F
.563 .539 .786 r
.38874 .63176 m .38633 .63252 L .38506 .62864 L F
.5 .344 .601 r
.38874 .63176 m .38647 .63496 L .38633 .63252 L F
.776 .888 .474 r
.3678 .59677 m .36896 .59482 L .3695 .59346 L F
.796 .745 .805 r
.3312 .66979 m .33602 .669 L .33414 .67001 L F
0 0 .535 r
.32281 .59734 m .32442 .59898 L .32448 .59703 L F
0 0 .391 r
.32448 .59703 m .32657 .59277 L .32444 .59415 L F
.32448 .59703 m .32661 .59553 L .32657 .59277 L F
0 0 .004 r
.32448 .59703 m .32581 .5979 L .32661 .59553 L F
.32448 .59703 m .32442 .59898 L .32581 .5979 L F
.057 0 .128 r
.39207 .56845 m .3909 .57144 L .38891 .57223 L F
.567 .259 .406 r
.3909 .57144 m .38842 .57314 L .38891 .57223 L F
.734 .625 .738 r
.39467 .59336 m .39508 .59744 L .39755 .59461 L F
.981 .696 .4 r
.36244 .57417 m .36413 .57544 L .36319 .57265 L F
.486 .272 .514 r
.36413 .57544 m .36381 .57809 L .36151 .57856 L F
.503 .483 .768 r
.36468 .57364 m .36413 .57544 L .36349 .57353 L F
.36468 .57364 m .36349 .57353 L .3638 .57319 L F
.36468 .57364 m .36329 .57293 L .36347 .57284 L F
.593 .491 .707 r
.36508 .57154 m .36459 .57183 L .36233 .56901 L F
.36459 .57183 m .36319 .57265 L .36262 .57024 L F
.36459 .57183 m .36262 .57024 L .36233 .56901 L F
.36494 .57171 m .36319 .57265 L .36508 .57154 L F
0 .142 .623 r
.36479 .572 m .3648 .572 L .36474 .57195 L F
.895 .722 .66 r
.36467 .57203 m .36479 .572 L .36474 .57195 L F
0 0 0 r
.36479 .572 m .36475 .57206 L .3648 .572 L F
0 0 .112 r
.36468 .5721 m .36475 .57206 L .36479 .572 L F
.593 .491 .707 r
.36475 .57206 m .36319 .57265 L .36514 .5716 L F
.36449 .57237 m .36409 .57246 L .36468 .5721 L F
.36409 .57246 m .36319 .57265 L .36475 .57206 L F
.895 .722 .66 r
.3643 .57212 m .36437 .57239 L .36468 .5721 L F
.36467 .57203 m .36468 .5721 L .36479 .572 L F
.3643 .57212 m .36468 .5721 L .36467 .57203 L F
.593 .491 .707 r
.36468 .57215 m .36468 .5721 L .36475 .57206 L F
.36449 .57237 m .36468 .5721 L .36468 .57215 L F
0 0 .112 r
.36437 .57239 m .36463 .57226 L .36475 .57206 L F
.36437 .57239 m .36475 .57206 L .36468 .5721 L F
0 .142 .623 r
.36474 .57195 m .36541 .57206 L .36281 .57005 L F
.593 .491 .707 r
.36569 .5721 m .36449 .57237 L .36514 .5716 L F
0 .142 .623 r
.3648 .572 m .36541 .57206 L .36474 .57195 L F
.895 .722 .66 r
.36023 .57314 m .36467 .57203 L .36281 .57005 L F
.36467 .57203 m .36474 .57195 L .36281 .57005 L F
.593 .491 .707 r
.36514 .5716 m .36494 .57171 L .36508 .57154 L F
0 0 0 r
.3648 .572 m .36463 .57226 L .36486 .57201 L F
.36475 .57206 m .36463 .57226 L .3648 .572 L F
.503 .483 .768 r
.36625 .57469 m .36319 .57265 L .36569 .5721 L F
0 0 0 r
.36486 .57201 m .36284 .5752 L .36541 .57206 L F
.36463 .57226 m .36284 .5752 L .36486 .57201 L F
.503 .483 .768 r
.3638 .57319 m .36349 .57353 L .36329 .57293 L F
.36347 .57284 m .36329 .57293 L .36319 .57265 L F
0 0 .112 r
.36244 .57417 m .36284 .5752 L .36463 .57226 L F
.36244 .57417 m .36463 .57226 L .36437 .57239 L F
.895 .722 .66 r
.36023 .57314 m .36244 .57417 L .36437 .57239 L F
.36023 .57314 m .36437 .57239 L .3643 .57212 L F
.503 .483 .768 r
.36625 .57469 m .36504 .57512 L .36468 .57364 L F
.36504 .57512 m .36413 .57544 L .36468 .57364 L F
.571 .416 .632 r
.36625 .57469 m .36381 .57809 L .36413 .57544 L F
.446 .534 .853 r
.35364 .5882 m .35629 .58846 L .35422 .58569 L F
0 0 0 r
.32582 .61875 m .32455 .61949 L .32682 .61595 L F
.32337 .62095 m .32455 .61949 L .32582 .61875 L F
.54 .64 .898 r
.35736 .57593 m .36151 .57856 L .35963 .57506 L F
.2 .416 .848 r
.35963 .57506 m .36151 .57856 L .36241 .57666 L F
.427 .227 .504 r
.36355 .5805 m .36151 .57856 L .36381 .57809 L F
.36151 .57856 m .36355 .5805 L .36241 .57666 L F
.36151 .57856 m .36132 .58115 L .36355 .5805 L F
.36355 .5805 m .36132 .58115 L .36151 .57856 L F
.174 .5 .908 r
.37324 .58378 m .3743 .58319 L .37119 .58103 L F
.37324 .58378 m .37548 .58507 L .3743 .58319 L F
.617 .371 .523 r
.40721 .59124 m .40668 .59392 L .404 .59344 L F
.414 .521 .858 r
.40854 .59039 m .40721 .59124 L .40508 .5873 L F
.394 .169 .451 r
.40894 .59307 m .40721 .59124 L .40854 .59039 L F
.40894 .59307 m .40668 .59392 L .40721 .59124 L F
.404 .244 .548 r
.31162 .57829 m .31136 .58107 L .30949 .5817 L F
.454 .375 .678 r
.31136 .58107 m .31227 .58382 L .30949 .5817 L F
.462 .375 .671 r
.31227 .58382 m .31016 .58533 L .30949 .5817 L F
.469 .344 .627 r
.33327 .59018 m .33141 .59364 L .33117 .59135 L F
.414 .178 .445 r
.38471 .56598 m .38751 .5626 L .38346 .56217 L F
.38471 .56598 m .38738 .56523 L .38751 .5626 L F
.366 .22 .547 r
.38751 .5626 m .38976 .56211 L .38971 .55904 L F
.212 .022 .392 r
.38751 .5626 m .38904 .56433 L .38976 .56211 L F
.38751 .5626 m .38738 .56523 L .38904 .56433 L F
.093 0 .121 r
.27196 .54399 m .26923 .54696 L .27111 .54578 L F
.212 0 .045 r
.27111 .54578 m .2743 .54364 L .27196 .54399 L F
.893 .809 .758 r
.60781 .40446 m .60889 .40796 L .60625 .40723 L F
.919 .732 .633 r
.60625 .40723 m .60889 .40796 L .60761 .41063 L F
.701 .896 .967 r
.36398 .62393 m .36195 .62581 L .35992 .62488 L F
.5 .373 .638 r
.31019 .55894 m .30788 .55689 L .3104 .55622 L F
.31019 .55894 m .30784 .55954 L .30788 .55689 L F
.115 0 .278 r
.33418 .56986 m .3327 .5746 L .33096 .57482 L F
.077 0 .066 r
.33096 .57482 m .3327 .5746 L .3278 .57906 L F
0 0 0 r
.29237 .59957 m .29104 .60077 L .28984 .60252 L F
.71 .45 .53 r
.36542 .54986 m .36122 .55262 L .36238 .55001 L F
.36542 .54986 m .36483 .55275 L .36122 .55262 L F
.63 .265 .333 r
.35685 .70828 m .35887 .71018 L .35659 .70971 L F
.7 .727 .871 r
.26319 .62101 m .25829 .62003 L .26089 .61981 L F
0 .263 .699 r
.26189 .61996 m .26319 .62101 L .26089 .61981 L F
.26189 .61996 m .26484 .62193 L .26319 .62101 L F
.442 0 .078 r
.26093 .61982 m .26338 .62019 L .26385 .62005 L F
.26089 .61981 m .26097 .61982 L .26093 .61982 L F
.26097 .61982 m .26338 .62019 L .26093 .61982 L F
.136 .532 .919 r
.26258 .62039 m .26304 .62041 L .26484 .62193 L F
.26286 .62026 m .26301 .6203 L .26484 .62193 L F
.263 .6203 m .26514 .62091 L .26484 .62193 L F
0 .263 .699 r
.26214 .6201 m .26484 .62193 L .26189 .61996 L F
.2 0 0 r
.2638 .62045 m .26135 .62291 L .26358 .62225 L F
.26385 .62005 m .26351 .62043 L .2638 .62045 L F
.26351 .62043 m .26135 .62291 L .2638 .62045 L F
.136 .532 .919 r
.26214 .6201 m .26286 .62026 L .26304 .62041 L F
.26214 .6201 m .26304 .62041 L .26258 .62039 L F
.26286 .62026 m .263 .6203 L .26301 .6203 L F
.497 .078 .174 r
.25881 .62274 m .26135 .62291 L .26351 .62043 L F
.26325 .62037 m .26351 .62043 L .26385 .62005 L F
.25881 .62274 m .26351 .62043 L .26325 .62037 L F
.25881 .62274 m .26325 .62037 L .25934 .62137 L F
.26325 .62037 m .26385 .62005 L .263 .6203 L F
.26325 .62037 m .263 .6203 L .25934 .62137 L F
.136 .532 .919 r
.263 .6203 m .26517 .6208 L .26514 .62091 L F
.2 0 0 r
.26385 .62005 m .2638 .62045 L .26518 .62078 L F
.136 .532 .919 r
.26489 .62071 m .26518 .62078 L .26517 .6208 L F
.2 0 0 r
.2638 .62045 m .26358 .62225 L .26518 .62078 L F
.136 .532 .919 r
.26156 .6197 m .26518 .62078 L .26489 .62071 L F
.442 0 .078 r
.26189 .61996 m .26269 .62039 L .26338 .62019 L F
.136 .532 .919 r
.26156 .6197 m .26517 .6208 L .26214 .6201 L F
0 .263 .699 r
.26156 .6197 m .26214 .6201 L .26189 .61996 L F
.442 0 .078 r
.26089 .61981 m .25934 .62137 L .26269 .62039 L F
.26089 .61981 m .26269 .62039 L .26189 .61996 L F
.26089 .61981 m .26385 .62005 L .26156 .6197 L F
0 .263 .699 r
.26156 .6197 m .26189 .61996 L .26089 .61981 L F
.685 .603 .758 r
.30298 .56601 m .30351 .56832 L .30471 .56592 L F
.30298 .56601 m .30351 .56832 L .30471 .56592 L F
.608 .954 .845 r
.31438 .65025 m .31644 .64776 L .31577 .65065 L F
.871 .604 .53 r
.31577 .65065 m .31644 .64776 L .3132 .64726 L F
.652 .324 .405 r
.39443 .57112 m .39207 .56845 L .39505 .56899 L F
.39443 .57112 m .3909 .57144 L .39207 .56845 L F
.574 .282 .435 r
.29909 .58368 m .30224 .58135 L .29978 .58223 L F
.551 .927 .918 r
.33753 .67392 m .33632 .67517 L .33511 .67474 L F
.33753 .67392 m .34001 .67377 L .33632 .67517 L F
.695 .466 .573 r
.34637 .52776 m .34298 .53061 L .34386 .52819 L F
.989 .786 .395 r
.39539 .59284 m .3962 .5936 L .39538 .59156 L F
.734 .625 .738 r
.39467 .59336 m .39704 .59439 L .3962 .5936 L F
.15 .377 .829 r
.3962 .5936 m .39467 .59336 L .39277 .59037 L F
.255 0 0 r
.3922 .5952 m .39467 .59336 L .3962 .5936 L F
.3922 .5952 m .39328 .59477 L .39542 .59521 L F
.39328 .59477 m .3962 .5936 L .39542 .59521 L F
.989 .786 .395 r
.39542 .59521 m .3962 .5936 L .39539 .59284 L F
.642 .526 .707 r
.39664 .59546 m .39542 .59521 L .39555 .59327 L F
.39792 .59803 m .39542 .59521 L .39664 .59546 L F
.734 .625 .738 r
.39704 .59439 m .39755 .59461 L .3962 .5936 L F
.69 .907 .972 r
.3962 .5936 m .39755 .59461 L .39745 .5929 L F
.595 .605 .832 r
.22734 .60209 m .22647 .60622 L .22493 .60273 L F
.22734 .60209 m .22883 .60556 L .22647 .60622 L F
.641 .607 .799 r
.22996 .60808 m .22647 .60622 L .22883 .60556 L F
.762 .473 .496 r
.33334 .6883 m .32961 .69099 L .32943 .68813 L F
.33334 .6883 m .33319 .69085 L .32961 .69099 L F
.765 .476 .496 r
.33334 .6883 m .33501 .69151 L .33319 .69085 L F
.831 .493 .415 r
.33729 .69175 m .33501 .69151 L .33334 .6883 L F
.801 .672 .721 r
.71764 .31982 m .71875 .32366 L .71493 .32276 L F
.228 .693 .946 r
.71493 .32276 m .71875 .32366 L .71795 .32298 L F
.21 .295 .733 r
.72032 .32155 m .71875 .32366 L .71764 .31982 L F
.668 .946 .959 r
.71795 .32298 m .71875 .32366 L .72032 .32155 L F
.754 .393 .371 r
.71633 .32932 m .7213 .33125 L .72013 .32995 L F
.395 .345 .684 r
.7213 .33125 m .72292 .33166 L .72013 .32995 L F
.545 .292 .483 r
.31949 .53717 m .32231 .53675 L .32255 .53463 L F
.239 .04 .396 r
.32255 .53463 m .32231 .53675 L .32433 .53366 L F
.631 .527 .717 r
.35302 .54068 m .35636 .54285 L .35581 .5401 L F
.275 .775 .873 r
.19122 .60943 m .18759 .60977 L .19002 .60651 L F
.19122 .60943 m .18989 .60935 L .18759 .60977 L F
.096 0 0 r
.19122 .60943 m .19398 .60969 L .18989 .60935 L F
.195 .611 .946 r
.24471 .63021 m .24531 .62911 L .24232 .6283 L F
.24471 .63021 m .24721 .63042 L .24531 .62911 L F
.789 .353 .214 r
.34242 .70117 m .34072 .70291 L .3405 .7005 L F
.34242 .70117 m .3444 .70396 L .34072 .70291 L F
.213 0 0 r
.26923 .54696 m .2699 .54823 L .27111 .54578 L F
.26923 .54696 m .26747 .5488 L .2699 .54823 L F
.761 .637 .724 r
.36233 .56901 m .35972 .57171 L .35966 .56876 L F
.504 .258 .475 r
.29843 .63162 m .29994 .6332 L .29737 .63459 L F
0 0 .527 r
.31601 .65518 m .31438 .65025 L .31386 .65243 L F
.247 .538 .923 r
.31854 .65557 m .31601 .65518 L .31386 .65243 L F
.57 .603 .847 r
.23103 .60473 m .22996 .60808 L .22883 .60556 L F
.23103 .60473 m .2333 .60878 L .22996 .60808 L F
.734 .606 .714 r
.30793 .54424 m .30839 .54705 L .31187 .54708 L F
.328 0 .025 r
.30795 .54935 m .31187 .54708 L .30839 .54705 L F
.30795 .54935 m .31031 .549 L .31187 .54708 L F
.574 .142 .183 r
.31187 .54708 m .31031 .549 L .31427 .54851 L F
.75 .714 .818 r
.31239 .52338 m .31721 .52329 L .3152 .52217 L F
.77 .861 .918 r
.3152 .52217 m .31721 .52329 L .31931 .52181 L F
.564 .272 .43 r
.36238 .55001 m .36122 .55262 L .35838 .55279 L F
.821 .998 .783 r
.35845 .55885 m .35711 .55979 L .35927 .55878 L F
.746 .299 .188 r
.35711 .55979 m .35821 .56095 L .35927 .55878 L F
.35711 .55979 m .35699 .56117 L .35821 .56095 L F
.821 .998 .783 r
.35845 .55885 m .35699 .56117 L .35711 .55979 L F
.644 .932 .67 r
.31497 .55148 m .31338 .55337 L .31661 .55014 L F
.253 .021 .356 r
.31479 .55489 m .31338 .55337 L .31497 .55148 L F
.31479 .55489 m .31279 .55577 L .31338 .55337 L F
0 .123 .648 r
.39597 .53667 m .39692 .53884 L .39601 .54042 L F
0 .117 .644 r
.39692 .53884 m .39788 .54262 L .39601 .54042 L F
.983 .766 .532 r
.36734 .56518 m .36807 .56295 L .36981 .56194 L F
.482 .433 .727 r
.36782 .62909 m .36899 .62678 L .36656 .62754 L F
.624 .092 0 r
.36954 .62722 m .36838 .62573 L .36884 .62664 L F
.36899 .62678 m .36884 .62664 L .36886 .62668 L F
.36954 .62722 m .36884 .62664 L .36899 .62678 L F
.482 .433 .727 r
.36782 .62909 m .37016 .63051 L .36938 .62717 L F
.457 .013 .103 r
.36989 .62767 m .37099 .62566 L .36838 .62573 L F
.482 .433 .727 r
.36899 .62678 m .36938 .62717 L .3692 .62636 L F
.36782 .62909 m .36938 .62717 L .36899 .62678 L F
.36899 .62678 m .3692 .62636 L .36886 .62668 L F
.624 .092 0 r
.36989 .62767 m .36954 .62722 L .36916 .62692 L F
.3695 .6273 m .36916 .62692 L .36886 .62668 L F
.36989 .62767 m .36916 .62692 L .3695 .6273 L F
.086 0 0 r
.37335 .62466 m .37099 .62566 L .36989 .62767 L F
.37335 .62466 m .36989 .62767 L .37167 .62661 L F
.567 .455 .685 r
.3692 .62636 m .37002 .62645 L .36989 .62767 L F
.572 .671 .906 r
.36838 .62573 m .37099 .62566 L .36886 .62326 L F
.564 .668 .908 r
.36886 .62326 m .37099 .62566 L .37335 .62466 L F
.325 .315 .694 r
.36864 .62269 m .36688 .62205 L .36907 .6179 L F
.36916 .61862 m .36907 .6179 L .36932 .61742 L F
.36864 .62269 m .36907 .6179 L .36916 .61862 L F
.564 .668 .908 r
.36886 .62326 m .37335 .62466 L .37354 .622 L F
.811 .564 .565 r
.37191 .62244 m .37058 .62386 L .36886 .62326 L F
.37354 .622 m .37058 .62386 L .37191 .62244 L F
.949 .756 .607 r
.36996 .62454 m .37058 .62386 L .37001 .62614 L F
.987 .744 .477 r
.36665 .62455 m .36886 .62326 L .37058 .62386 L F
.835 .801 .819 r
.3702 .61732 m .37249 .61907 L .37157 .61993 L F
.36983 .6186 m .37157 .61993 L .36864 .62269 L F
.3702 .61732 m .37157 .61993 L .36983 .6186 L F
.3702 .61732 m .36864 .62269 L .36932 .61742 L F
.673 .618 .785 r
.36665 .62455 m .37058 .62386 L .36932 .61742 L F
.912 .764 .684 r
.36911 .61804 m .37058 .62386 L .36841 .62018 L F
.36932 .61742 m .3695 .61834 L .36911 .61804 L F
.3695 .61834 m .37058 .62386 L .36911 .61804 L F
.949 .756 .607 r
.3699 .6227 m .37058 .62386 L .36996 .62454 L F
.567 .455 .685 r
.37011 .62646 m .37167 .62661 L .37039 .62737 L F
.046 .128 .627 r
.37002 .62645 m .37022 .62678 L .37167 .62661 L F
.697 .721 .868 r
.37167 .62661 m .36995 .62681 L .36981 .62694 L F
.046 .128 .627 r
.37022 .62678 m .37024 .62683 L .37167 .62661 L F
.949 .756 .607 r
.36978 .6268 m .3698 .62677 L .36981 .62694 L F
.809 .591 .608 r
.36988 .62665 m .37019 .6267 L .36981 .62694 L F
.567 .455 .685 r
.37002 .62645 m .37011 .62646 L .37004 .62686 L F
.809 .591 .608 r
.37011 .62646 m .37019 .6267 L .36988 .62665 L F
.578 .53 .765 r
.36978 .6268 m .36981 .62694 L .36995 .62681 L F
.567 .455 .685 r
.37002 .62645 m .37004 .62686 L .36989 .62767 L F
.37011 .62646 m .37039 .62737 L .36989 .62767 L F
.046 .128 .627 r
.3697 .62692 m .37145 .6289 L .37024 .62683 L F
.3698 .6268 m .37024 .62683 L .37006 .6265 L F
.3697 .62692 m .37024 .62683 L .3698 .6268 L F
.36988 .62665 m .37006 .6265 L .37002 .62645 L F
.3697 .62692 m .37006 .6265 L .36988 .62665 L F
.809 .591 .608 r
.37001 .62614 m .37011 .62646 L .36988 .62665 L F
.37058 .62386 m .37335 .62466 L .37019 .6267 L F
.37058 .62386 m .37019 .6267 L .37001 .62614 L F
.811 .564 .565 r
.37354 .622 m .37335 .62466 L .37058 .62386 L F
.697 .721 .868 r
.37167 .62661 m .37385 .62325 L .36995 .62681 L F
.949 .756 .607 r
.36841 .62018 m .36966 .6223 L .3698 .62677 L F
.36841 .62018 m .3698 .62677 L .36978 .6268 L F
.36966 .6223 m .3699 .6227 L .36987 .62387 L F
.36966 .6223 m .36987 .62387 L .36981 .62694 L F
.3699 .6227 m .37001 .62614 L .36981 .62694 L F
.578 .53 .765 r
.36841 .62018 m .36978 .6268 L .37385 .62325 L F
.36978 .6268 m .36995 .62681 L .37385 .62325 L F
.046 .128 .627 r
.37024 .62683 m .37145 .6289 L .37165 .6269 L F
.37024 .62683 m .37165 .6269 L .37167 .62661 L F
.3692 .62636 m .3697 .62692 L .37002 .62645 L F
.3692 .62636 m .36938 .62717 L .37145 .6289 L F
.36938 .62717 m .37016 .63051 L .37121 .6292 L F
.36938 .62717 m .37121 .6292 L .37145 .6289 L F
.624 .092 0 r
.36989 .62767 m .36886 .62668 L .3692 .62636 L F
.36886 .62668 m .36838 .62573 L .36665 .62455 L F
.36886 .62668 m .36665 .62455 L .3692 .62636 L F
.482 .433 .727 r
.36886 .62668 m .3692 .62636 L .36872 .62657 L F
.36899 .62678 m .36872 .62657 L .36656 .62754 L F
.714 .269 .192 r
.34601 .62129 m .35 .62226 L .34891 .62033 L F
.446 .174 .406 r
.34891 .62033 m .35231 .62134 L .35052 .61778 L F
.34891 .62033 m .35 .62226 L .35231 .62134 L F
.328 .191 .538 r
.19047 .57798 m .19222 .57454 L .19054 .57534 L F
.641 .398 .536 r
.35222 .58427 m .35488 .5813 L .35234 .58175 L F
.35222 .58427 m .35466 .58431 L .35488 .5813 L F
.56 .546 .796 r
.23486 .60604 m .23386 .61051 L .2333 .60878 L F
.23486 .60604 m .23645 .60998 L .23386 .61051 L F
.589 .307 .456 r
.23957 .54976 m .24207 .54982 L .2431 .54701 L F
.546 .263 .437 r
.2431 .54701 m .24522 .54903 L .24553 .54652 L F
.2431 .54701 m .24207 .54982 L .24522 .54903 L F
.461 .854 .655 r
.22196 .55581 m .22189 .55607 L .22395 .55554 L F
.22196 .55581 m .21876 .55796 L .22189 .55607 L F
.487 .307 .562 r
.38487 .56837 m .38738 .56523 L .38471 .56598 L F
.392 0 .146 r
.34793 .53285 m .35001 .53328 L .35104 .53145 L F
.622 .58 .786 r
.39277 .59037 m .3898 .59242 L .38974 .58579 L F
.808 .687 .731 r
.39277 .59037 m .38952 .59358 L .3898 .59242 L F
.572 .518 .756 r
.38546 .61981 m .38382 .62225 L .3833 .62016 L F
.764 .82 .897 r
.31786 .51633 m .313 .51976 L .31527 .51587 L F
.703 .794 .921 r
.29994 .6332 m .3014 .63481 L .30346 .6335 L F
.788 .753 .821 r
.32629 .5516 m .32983 .55236 L .32819 .55004 L F
.32629 .5516 m .32495 .55258 L .32983 .55236 L F
0 0 0 r
.32512 .55478 m .32983 .55236 L .32495 .55258 L F
.32512 .55478 m .32688 .55421 L .32983 .55236 L F
0 0 .429 r
.32983 .55236 m .33046 .54667 L .32819 .55004 L F
.32983 .55236 m .33083 .55197 L .33046 .54667 L F
.248 .76 .768 r
.33245 .5517 m .33083 .55197 L .32983 .55236 L F
.562 .575 .824 r
.33083 .55197 m .32997 .55624 L .32983 .55236 L F
0 0 0 r
.32983 .55236 m .32895 .55333 L .33083 .55197 L F
.32983 .55236 m .32688 .55421 L .32895 .55333 L F
.298 .767 .939 r
.29388 .52208 m .29332 .52293 L .29162 .52283 L F
.29388 .52208 m .29583 .5225 L .29332 .52293 L F
.451 .718 .982 r
.32862 .65428 m .3321 .65438 L .32955 .65265 L F
.523 .526 .8 r
.32862 .65428 m .33231 .65725 L .3321 .65438 L F
.08 .635 .811 r
.29852 .53573 m .29454 .53543 L .29615 .53638 L F
.548 .634 .889 r
.35231 .62719 m .35367 .62523 L .3514 .62587 L F
.35231 .62719 m .35478 .6268 L .35367 .62523 L F
.426 .099 .305 r
.35363 .6301 m .35231 .62719 L .35145 .63095 L F
.35363 .6301 m .35478 .6268 L .35231 .62719 L F
.384 .471 .826 r
.33084 .61195 m .32961 .61314 L .32803 .60939 L F
0 0 .127 r
.32904 .61514 m .32961 .61314 L .33084 .61195 L F
.777 .299 .101 r
.34625 .70432 m .3455 .7061 L .3444 .70396 L F
.34625 .70432 m .34846 .70682 L .3455 .7061 L F
0 0 0 r
.23675 .53348 m .23783 .53352 L .23892 .53287 L F
.23675 .53348 m .23466 .53569 L .23783 .53352 L F
.641 .356 .47 r
.39373 .57877 m .39124 .57721 L .39006 .58013 L F
.788 .669 .733 r
.39124 .57721 m .39396 .57586 L .39518 .57419 L F
0 0 .017 r
.39518 .57419 m .39396 .57586 L .39489 .57535 L F
.39544 .57461 m .39489 .57535 L .39564 .57495 L F
.39518 .57419 m .39489 .57535 L .39544 .57461 L F
.572 .595 .838 r
.39475 .57555 m .38941 .5765 L .39479 .57538 L F
.641 .356 .47 r
.39385 .57864 m .39396 .57586 L .39124 .57721 L F
.747 .991 .796 r
.39373 .57877 m .39359 .57894 L .39551 .57713 L F
.641 .356 .47 r
.39394 .57869 m .39394 .57857 L .39385 .57864 L F
.39394 .57857 m .39396 .57586 L .39385 .57864 L F
.056 0 .355 r
.39564 .57495 m .3947 .57545 L .39528 .57571 L F
.643 .481 .648 r
.39532 .57572 m .39479 .57538 L .39512 .57427 L F
.799 .746 .804 r
.39564 .57495 m .39529 .57571 L .39551 .57713 L F
.643 .481 .648 r
.39551 .57713 m .39485 .57552 L .39529 .57571 L F
.799 .746 .804 r
.39529 .57571 m .39499 .57637 L .39551 .57713 L F
.056 0 .355 r
.39478 .57576 m .39396 .57586 L .39403 .57838 L F
.643 .481 .648 r
.39485 .57552 m .39394 .57869 L .39479 .57538 L F
.747 .991 .796 r
.39399 .57851 m .39373 .57877 L .39446 .5781 L F
.3939 .57859 m .39388 .57861 L .39399 .57851 L F
.39388 .57861 m .39373 .57877 L .39399 .57851 L F
.3939 .57859 m .39446 .5781 L .39551 .57713 L F
0 0 0 r
.39551 .57713 m .39234 .58011 L .39273 .57975 L F
.643 .481 .648 r
.39551 .57713 m .39394 .57869 L .39397 .57858 L F
.39551 .57713 m .39399 .5785 L .39485 .57552 L F
.056 0 .355 r
.39436 .57777 m .39394 .57857 L .39407 .57841 L F
.39564 .57495 m .39432 .57777 L .39436 .57777 L F
.39432 .57777 m .39394 .57857 L .39436 .57777 L F
.747 .991 .796 r
.39475 .57786 m .39551 .57713 L .39494 .5779 L F
0 0 0 r
.39551 .57713 m .39493 .57768 L .39493 .57768 L F
.799 .746 .804 r
.394 .57855 m .39394 .57869 L .39551 .57713 L F
0 0 0 r
.39551 .57713 m .39493 .57768 L .39505 .57757 L F
.643 .481 .648 r
.39551 .57713 m .39397 .57858 L .39399 .5785 L F
.747 .991 .796 r
.39402 .57845 m .3939 .57859 L .39551 .57713 L F
.799 .746 .804 r
.39407 .57841 m .394 .57855 L .39551 .57713 L F
.39499 .57637 m .39493 .57764 L .39551 .57713 L F
.39499 .57637 m .39407 .57841 L .39493 .57764 L F
.747 .991 .796 r
.39473 .57768 m .39402 .57845 L .39551 .57713 L F
.39454 .57781 m .39551 .57713 L .39475 .57786 L F
0 0 0 r
.39551 .57713 m .39505 .57757 L .39517 .57747 L F
.39517 .57747 m .39476 .57786 L .39493 .57772 L F
.056 0 .355 r
.39407 .57841 m .39394 .57857 L .39394 .57861 L F
.394 .57855 m .39394 .57861 L .39394 .57869 L F
.39407 .57841 m .39394 .57861 L .394 .57855 L F
.572 .595 .838 r
.39397 .57859 m .39384 .57864 L .39399 .57851 L F
.39394 .57869 m .39388 .57866 L .39397 .57859 L F
.39388 .57866 m .39384 .57864 L .39397 .57859 L F
0 0 0 r
.39475 .57786 m .39295 .57955 L .39436 .57824 L F
.39295 .57955 m .39273 .57975 L .39286 .57963 L F
.39295 .57955 m .39286 .57963 L .39436 .57824 L F
.39476 .57786 m .39475 .57786 L .39475 .57786 L F
.39475 .57786 m .39273 .57975 L .39475 .57786 L F
.747 .991 .796 r
.39454 .57781 m .3944 .57799 L .39473 .57768 L F
.39454 .57781 m .39494 .5779 L .39477 .57814 L F
.667 .489 .634 r
.39234 .58011 m .39502 .57807 L .39436 .57824 L F
.747 .991 .796 r
.3944 .57823 m .39477 .57814 L .39413 .57901 L F
.39454 .57781 m .39477 .57814 L .3944 .57823 L F
.667 .489 .634 r
.39234 .58011 m .39658 .58397 L .39502 .57807 L F
.39436 .57824 m .39502 .57807 L .39493 .57772 L F
0 0 0 r
.39476 .57786 m .39436 .57824 L .39493 .57772 L F
.056 0 .355 r
.39403 .57838 m .39396 .57586 L .39394 .57857 L F
.39528 .57571 m .39478 .57576 L .39403 .57838 L F
.572 .595 .838 r
.39399 .57851 m .39389 .57847 L .39403 .57834 L F
.39389 .57847 m .39292 .57804 L .39403 .57834 L F
.39403 .57834 m .39292 .57804 L .39475 .57555 L F
.641 .356 .47 r
.39385 .57864 m .39124 .57721 L .39373 .57877 L F
.572 .595 .838 r
.39384 .57864 m .38941 .5765 L .39399 .57851 L F
.39384 .57864 m .39006 .58013 L .38941 .5765 L F
.39373 .57877 m .39006 .58013 L .39384 .57864 L F
.747 .991 .796 r
.39181 .57975 m .39312 .5792 L .3944 .57799 L F
.39181 .57975 m .3944 .57799 L .39454 .57781 L F
.39181 .57975 m .39454 .57781 L .39441 .5782 L F
.3933 .57927 m .39441 .5782 L .39413 .57901 L F
0 0 0 r
.39493 .57768 m .39273 .57975 L .39517 .57747 L F
.747 .991 .796 r
.39312 .5792 m .39347 .57905 L .39385 .57864 L F
.39312 .5792 m .39385 .57864 L .39473 .57768 L F
.39373 .57877 m .39347 .57905 L .39359 .57894 L F
.641 .356 .47 r
.39394 .57869 m .39385 .57864 L .39373 .57877 L F
.572 .595 .838 r
.39394 .57869 m .39373 .57877 L .39384 .57864 L F
.747 .991 .796 r
.39181 .57975 m .39441 .5782 L .3933 .57927 L F
0 0 .298 r
.39512 .57427 m .39509 .57438 L .39534 .57733 L F
0 0 0 r
.39523 .57753 m .39551 .57713 L .39493 .57772 L F
.432 .45 .778 r
.39503 .57779 m .39658 .58397 L .39892 .58046 L F
.39493 .57772 m .39497 .57787 L .39503 .57779 L F
.39497 .57787 m .39658 .58397 L .39503 .57779 L F
0 0 0 r
.39413 .57901 m .39477 .57813 L .39512 .57769 L F
.721 .545 .651 r
.40088 .57626 m .39698 .57644 L .39779 .57589 L F
0 0 0 r
.39753 .57607 m .39751 .57608 L .39686 .57652 L F
.39751 .57608 m .39551 .57713 L .39685 .57652 L F
.39751 .57608 m .39685 .57652 L .39686 .57652 L F
.721 .545 .651 r
.40088 .57626 m .39785 .57794 L .39698 .57644 L F
.626 .909 .616 r
.39551 .57713 m .39833 .57423 L .39657 .57574 L F
0 0 0 r
.39751 .57608 m .39833 .57423 L .39551 .57713 L F
.721 .545 .651 r
.39779 .57589 m .39751 .57608 L .39768 .57587 L F
.62 .195 .215 r
.39768 .57587 m .39833 .57423 L .40088 .57626 L F
.39657 .57574 m .39833 .57423 L .39768 .57587 L F
0 0 0 r
.39788 .57589 m .39798 .57552 L .39768 .57587 L F
.39762 .57602 m .39768 .57587 L .39751 .57608 L F
.39788 .57589 m .39768 .57587 L .39762 .57602 L F
.39798 .57552 m .39833 .57423 L .39751 .57608 L F
.721 .545 .651 r
.39768 .57587 m .39698 .57644 L .39657 .57574 L F
.39751 .57608 m .39698 .57644 L .39768 .57587 L F
.40088 .57626 m .40047 .57887 L .39799 .57865 L F
0 0 0 r
.39824 .57848 m .39794 .57839 L .3983 .57892 L F
.39794 .57839 m .39523 .57753 L .39802 .57879 L F
.39523 .57753 m .39505 .57776 L .3983 .57892 L F
.432 .45 .778 r
.39493 .57772 m .39892 .58046 L .3983 .57892 L F
.848 .635 .614 r
.39799 .57865 m .39661 .58086 L .39679 .57854 L F
.721 .545 .651 r
.40088 .57626 m .39799 .57865 L .39785 .57794 L F
.738 .561 .653 r
.39828 .57881 m .40088 .57626 L .39788 .57589 L F
.3983 .57892 m .3984 .57881 L .39828 .57881 L F
.3984 .57881 m .40088 .57626 L .39828 .57881 L F
.764 .554 .614 r
.39892 .58046 m .40047 .57887 L .3983 .57892 L F
.848 .635 .614 r
.40047 .57887 m .39938 .57943 L .39828 .57881 L F
.40016 .57885 m .3984 .57881 L .39799 .57865 L F
.40047 .57887 m .39828 .57881 L .40016 .57885 L F
.738 .561 .653 r
.3984 .57881 m .40047 .57887 L .40088 .57626 L F
.3983 .57892 m .40047 .57887 L .3984 .57881 L F
.848 .635 .614 r
.3984 .57881 m .39828 .57881 L .39828 .57881 L F
.3984 .57881 m .39828 .57881 L .39799 .57865 L F
0 0 0 r
.39819 .57876 m .39802 .57879 L .3983 .57892 L F
.39799 .57865 m .39802 .57879 L .39819 .57876 L F
.848 .635 .614 r
.39938 .57943 m .39661 .58086 L .39799 .57865 L F
0 0 0 r
.39794 .57839 m .39799 .57865 L .39819 .57876 L F
.721 .545 .651 r
.39785 .57794 m .39799 .57865 L .39679 .57854 L F
0 0 0 r
.39685 .57653 m .39523 .57753 L .39824 .57848 L F
.721 .545 .651 r
.39785 .57794 m .39679 .57854 L .39661 .57619 L F
.39785 .57794 m .39661 .57619 L .39657 .57574 L F
0 0 0 r
.39788 .57589 m .39685 .57653 L .39824 .57848 L F
.39477 .57813 m .39551 .57713 L .39523 .57753 L F
.39523 .57753 m .39493 .57772 L .39505 .57776 L F
.39503 .57779 m .39523 .57753 L .3952 .57756 L F
.39477 .57813 m .39523 .57753 L .39503 .57779 L F
.39477 .57813 m .3952 .57756 L .39512 .57769 L F
.39413 .57901 m .39512 .57769 L .39679 .57854 L F
.39686 .57652 m .39551 .57713 L .39523 .57753 L F
.39512 .57769 m .39657 .57574 L .39664 .57666 L F
.39512 .57769 m .39664 .57666 L .39679 .57854 L F
.39788 .57589 m .39753 .57607 L .39686 .57652 L F
.39512 .57769 m .39551 .57713 L .39657 .57574 L F
0 0 .298 r
.39534 .57733 m .39534 .57733 L .39534 .57741 L F
.39512 .57427 m .39534 .57733 L .39534 .57733 L F
.643 .481 .648 r
.39485 .57552 m .39479 .57538 L .39532 .57572 L F
0 0 .298 r
.39509 .57438 m .39479 .57538 L .395 .57616 L F
.39509 .57438 m .395 .57616 L .39534 .57741 L F
.643 .481 .648 r
.39551 .57713 m .39529 .57571 L .39532 .57572 L F
.056 0 .355 r
.3947 .57545 m .39396 .57586 L .39528 .57571 L F
.572 .595 .838 r
.39292 .57804 m .38941 .5765 L .39475 .57555 L F
.747 .991 .796 r
.39181 .57975 m .39234 .58011 L .39347 .57905 L F
.642 .625 .818 r
.38824 .63706 m .38647 .63496 L .38946 .63416 L F
.071 0 .448 r
.38946 .63416 m .39055 .63621 L .38824 .63706 L F
0 0 .213 r
.39055 .63621 m .38859 .63964 L .38824 .63706 L F
.125 .047 .489 r
.19241 .57191 m .19391 .56752 L .19196 .5692 L F
.396 .06 .274 r
.39275 .66093 m .39188 .66278 L .38946 .66328 L F
.361 .093 .366 r
.39485 .65973 m .39188 .66278 L .39275 .66093 L F
.456 .269 .537 r
.38974 .69148 m .38947 .69475 L .38676 .6949 L F
.439 .205 .46 r
.38863 .69727 m .38676 .6949 L .38947 .69475 L F
.38863 .69727 m .38675 .69789 L .38676 .6949 L F
.721 .976 .922 r
.3417 .67231 m .34001 .67377 L .33753 .67392 L F
0 .161 .684 r
.40791 .57335 m .40928 .57717 L .40722 .57506 L F
.169 .302 .757 r
.4091 .5779 m .40722 .57506 L .40928 .57717 L F
.636 .081 0 r
.37531 .51559 m .37968 .51742 L .37734 .51698 L F
.602 .781 .966 r
.30611 .52125 m .30229 .52081 L .30452 .51921 L F
.533 .61 .875 r
.30726 .51813 m .30611 .52125 L .30452 .51921 L F
.30726 .51813 m .30874 .52125 L .30611 .52125 L F
.117 0 .397 r
.29739 .58739 m .29909 .58368 L .29762 .58471 L F
.004 0 .093 r
.29152 .63835 m .29487 .63441 L .29269 .63731 L F
0 0 .414 r
.29319 .63946 m .29152 .63835 L .29269 .63731 L F
.29319 .63946 m .29171 .64158 L .29152 .63835 L F
0 0 0 r
.27344 .55031 m .27315 .54975 L .2755 .54892 L F
.27344 .55031 m .27136 .55235 L .27315 .54975 L F
.424 0 0 r
.30032 .63001 m .30028 .62974 L .29945 .62774 L F
.30032 .63001 m .30223 .63099 L .30028 .62974 L F
0 0 0 r
.30298 .62907 m .30028 .62974 L .30223 .63099 L F
.485 .518 .816 r
.34314 .57164 m .34657 .57454 L .34643 .57177 L F
0 0 0 r
.34916 .5693 m .34643 .57177 L .34826 .57012 L F
.421 .257 .551 r
.34643 .57177 m .34891 .57354 L .34826 .57012 L F
.34643 .57177 m .34657 .57454 L .34891 .57354 L F
.607 .915 .656 r
.34727 .57092 m .34643 .57177 L .34916 .5693 L F
.249 .266 .682 r
.34613 .64124 m .34843 .64346 L .34742 .64084 L F
.793 .533 .543 r
.26041 .53875 m .26647 .54011 L .26884 .53795 L F
.217 0 .013 r
.26884 .53795 m .26647 .54011 L .26877 .5394 L F
.26884 .53795 m .26877 .5394 L .26865 .53631 L F
.688 .483 .603 r
.35719 .61679 m .35707 .61906 L .35697 .61872 L F
.058 0 .427 r
.35985 .61696 m .35719 .61679 L .3595 .61431 L F
0 0 .354 r
.35795 .62056 m .35826 .62134 L .35697 .61872 L F
.35826 .62134 m .35849 .62193 L .35727 .61937 L F
.35826 .62134 m .35727 .61937 L .35697 .61872 L F
.058 0 .427 r
.35985 .61696 m .35711 .61903 L .35719 .61679 L F
.35711 .61903 m .35707 .61906 L .35707 .61897 L F
.35711 .61903 m .35707 .61897 L .35719 .61679 L F
0 0 .017 r
.39518 .57419 m .39564 .57495 L .39651 .57233 L F
0 0 .469 r
.734 .33589 m .73229 .33921 L .73076 .33784 L F
.734 .33589 m .73351 .33792 L .73229 .33921 L F
0 0 .278 r
.73326 .33937 m .73229 .33921 L .73351 .33792 L F
.616 .629 .841 r
.73076 .33784 m .73351 .33792 L .734 .33589 L F
.748 .359 .317 r
.72866 .33875 m .73351 .33792 L .73076 .33784 L F
.72866 .33875 m .7324 .33982 L .73351 .33792 L F
.55 .562 .819 r
.73612 .33635 m .73351 .33792 L .734 .33589 L F
0 0 .493 r
.734 .33589 m .73496 .33428 L .73612 .33635 L F
.734 .33589 m .73351 .33792 L .73496 .33428 L F
.747 .853 .415 r
.73351 .33792 m .7331 .33863 L .73496 .33428 L F
.7331 .33863 m .7324 .33982 L .73353 .33738 L F
.7331 .33863 m .73353 .33738 L .73496 .33428 L F
0 0 .278 r
.73326 .33937 m .73247 .34192 L .73239 .3407 L F
.73287 .33931 m .73239 .3407 L .73229 .33921 L F
.73326 .33937 m .73239 .3407 L .73287 .33931 L F
.78 .419 .372 r
.70202 .32299 m .70266 .32313 L .70253 .32505 L F
.697 .638 .786 r
.70471 .32017 m .70266 .32313 L .70202 .32299 L F
.70471 .32017 m .70562 .32283 L .70266 .32313 L F
.646 .323 .41 r
.70562 .32283 m .70253 .32505 L .70266 .32313 L F
0 0 0 r
.36074 .59397 m .35918 .59661 L .35824 .59508 L F
.631 .527 .717 r
.35302 .54068 m .35359 .54467 L .35636 .54285 L F
0 0 0 r
.35359 .54467 m .35518 .54405 L .35636 .54285 L F
.35359 .54467 m .35213 .54576 L .35518 .54405 L F
.835 .508 .434 r
.33729 .69175 m .33511 .69367 L .33501 .69151 L F
.924 .673 .54 r
.33729 .69175 m .33721 .69443 L .33511 .69367 L F
.482 0 0 r
.72091 .30936 m .72122 .30926 L .71855 .30789 L F
.674 .907 .571 r
.72091 .30936 m .72122 .30926 L .72358 .30608 L F
.509 .165 .319 r
.23326 .56207 m .23243 .564 L .22975 .56416 L F
.458 .114 .295 r
.2353 .56288 m .23326 .56207 L .23568 .56202 L F
.2353 .56288 m .23243 .564 L .23326 .56207 L F
.525 0 0 r
.35999 .51358 m .36256 .51493 L .35862 .51379 L F
.663 .17 .068 r
.38958 .58141 m .39156 .5828 L .39074 .58107 L F
.154 0 .284 r
.38974 .58579 m .39012 .58607 L .39156 .5828 L F
0 .386 .819 r
.39246 .58493 m .39082 .58482 L .39156 .5828 L F
.735 .459 .511 r
.39156 .5828 m .39115 .58424 L .39171 .58469 L F
.498 .337 .593 r
.39514 .58578 m .39246 .58493 L .39083 .58482 L F
.39421 .58694 m .39514 .58578 L .39082 .58482 L F
.735 .459 .511 r
.39156 .5828 m .39171 .58469 L .39246 .58493 L F
.498 .337 .593 r
.39565 .58514 m .39658 .58397 L .39171 .58469 L F
.39246 .58493 m .39171 .58469 L .39082 .58482 L F
.39565 .58514 m .39171 .58469 L .39246 .58493 L F
0 .386 .819 r
.39291 .58599 m .39082 .58482 L .39246 .58493 L F
.39291 .58599 m .39421 .58694 L .39082 .58482 L F
.154 0 .284 r
.39012 .58607 m .39056 .58637 L .39098 .58486 L F
.667 .489 .634 r
.39104 .58415 m .39082 .58482 L .39171 .58469 L F
.154 0 .284 r
.39087 .58483 m .39098 .58486 L .39108 .58449 L F
.39012 .58607 m .39098 .58486 L .39087 .58483 L F
.735 .459 .511 r
.39171 .58469 m .39056 .58637 L .3927 .5855 L F
.39115 .58424 m .39108 .58449 L .39171 .58469 L F
.39108 .58449 m .39056 .58637 L .39171 .58469 L F
.154 0 .284 r
.39083 .58482 m .39108 .58449 L .39115 .58424 L F
.39012 .58607 m .39108 .58449 L .39083 .58482 L F
.735 .459 .511 r
.39246 .58493 m .39171 .58469 L .3927 .5855 L F
.498 .337 .593 r
.39514 .58578 m .39565 .58514 L .39246 .58493 L F
.667 .489 .634 r
.39138 .58308 m .39104 .58415 L .39435 .5843 L F
.39104 .58415 m .39171 .58469 L .39435 .5843 L F
.735 .459 .511 r
.3927 .5855 m .39056 .58637 L .39291 .58599 L F
.154 0 .284 r
.39012 .58607 m .39115 .58424 L .39156 .5828 L F
.663 .17 .068 r
.38958 .58141 m .3891 .58215 L .39156 .5828 L F
.3891 .58215 m .39082 .58285 L .39156 .5828 L F
.418 .36 .686 r
.38958 .58141 m .39156 .5828 L .39074 .58107 L F
.845 .849 .388 r
.39156 .5828 m .39234 .58011 L .39074 .58107 L F
.154 0 .284 r
.38974 .58579 m .39156 .5828 L .38855 .58301 L F
.845 .849 .388 r
.39156 .5828 m .39082 .58482 L .39234 .58011 L F
.667 .489 .634 r
.39234 .58011 m .39138 .58308 L .39177 .58315 L F
.3931 .5808 m .39177 .58315 L .39658 .58397 L F
.39234 .58011 m .39177 .58315 L .3931 .5808 L F
.39138 .58308 m .39435 .5843 L .39658 .58397 L F
.663 .17 .068 r
.3891 .58215 m .38855 .58301 L .39082 .58285 L F
.936 .578 .307 r
.35102 .52348 m .35212 .52664 L .35288 .52476 L F
.799 .569 .589 r
.38965 .60523 m .3934 .60677 L .39242 .60569 L F
.38965 .60523 m .39034 .60934 L .3934 .60677 L F
.533 .869 .992 r
.31144 .57195 m .31056 .57349 L .30894 .57139 L F
.686 .689 .847 r
.35327 .66321 m .35689 .66398 L .3558 .66269 L F
.567 .65 .891 r
.3558 .66269 m .35689 .66398 L .35921 .66337 L F
.68 .43 .536 r
.38404 .54152 m .38276 .54348 L .37907 .54252 L F
0 0 0 r
.38512 .54021 m .38276 .54348 L .38404 .54152 L F
.559 .067 0 r
.39905 .54662 m .4008 .54862 L .40134 .54908 L F
0 0 .56 r
.40007 .54728 m .4008 .54862 L .39905 .54662 L F
.774 .414 0 r
.40007 .54728 m .40059 .54845 L .4008 .54862 L F
.40059 .54845 m .40169 .55092 L .4008 .54862 L F
.559 .067 0 r
.40134 .54908 m .4008 .54862 L .40182 .54959 L F
0 0 .316 r
.4008 .54862 m .40204 .55225 L .40182 .54959 L F
.622 .389 .544 r
.34556 .56865 m .34857 .56949 L .34829 .56579 L F
.561 .614 .863 r
.34829 .56579 m .34896 .5612 L .34657 .56178 L F
.401 .227 .527 r
.34829 .56579 m .34857 .56949 L .35108 .56774 L F
.951 .736 .577 r
.3633 .66293 m .3625 .66059 L .36368 .66293 L F
.685 .201 .096 r
.36572 .66479 m .3633 .66293 L .36391 .66679 L F
.71 .893 .963 r
.3643 .66404 m .3633 .66293 L .36368 .66293 L F
.3643 .66404 m .36205 .66536 L .3633 .66293 L F
.821 .367 .149 r
.36422 .66398 m .36368 .66293 L .36072 .6616 L F
.3643 .66404 m .36368 .66293 L .36422 .66398 L F
.951 .736 .577 r
.3625 .66059 m .36229 .65999 L .36368 .66293 L F
.725 .47 .542 r
.3671 .54681 m .36953 .5488 L .37066 .5466 L F
.851 .997 .821 r
.37066 .5466 m .37202 .54363 L .37337 .54375 L F
.37066 .5466 m .3698 .54628 L .37202 .54363 L F
.977 .919 .619 r
.37066 .5466 m .36953 .5488 L .3698 .54628 L F
.433 .744 .993 r
.28148 .52242 m .28063 .52393 L .27865 .52321 L F
.28148 .52242 m .28304 .52367 L .28063 .52393 L F
.895 .736 .678 r
.71729 .30401 m .71855 .30789 L .71761 .30614 L F
.713 .219 .067 r
.34826 .57012 m .35212 .57209 L .34916 .5693 L F
0 0 0 r
.34967 .56938 m .34916 .5693 L .35108 .56774 L F
.275 .291 .696 r
.34916 .5693 m .35212 .57209 L .35101 .56841 L F
0 0 0 r
.34967 .56938 m .34826 .57012 L .34916 .5693 L F
.738 .972 .929 r
.35359 .53867 m .35201 .54006 L .35302 .54068 L F
.368 .148 .443 r
.38307 .6634 m .38286 .66636 L .38052 .66655 L F
.24 0 .296 r
.32387 .572 m .32571 .57167 L .3264 .56902 L F
.348 .399 .773 r
.32387 .572 m .32702 .57395 L .32571 .57167 L F
.733 .514 .595 r
.35927 .55878 m .36338 .5591 L .36303 .55654 L F
.638 .544 .732 r
.36338 .5591 m .36549 .55665 L .36303 .55654 L F
.705 .425 .498 r
.37254 .52529 m .37212 .52766 L .36942 .52714 L F
.282 0 .184 r
.32582 .61875 m .32682 .61595 L .32904 .61514 L F
0 .058 .623 r
.30178 .64945 m .30166 .65081 L .30005 .64743 L F
0 0 .472 r
.3018 .65086 m .30166 .65081 L .30178 .64945 L F
.636 .493 .671 r
.33424 .60734 m .33628 .60321 L .33435 .60391 L F
.253 0 .268 r
.21944 .54407 m .21869 .5462 L .22137 .54327 L F
.619 .544 .747 r
.38947 .6012 m .38578 .60284 L .38597 .60226 L F
.38947 .6012 m .38853 .60282 L .38578 .60284 L F
.752 .502 .554 r
.63776 .43366 m .63376 .43552 L .63622 .43219 L F
.63776 .43366 m .63792 .43627 L .63376 .43552 L F
.764 .843 .912 r
.63951 .42977 m .63776 .43366 L .63622 .43219 L F
.63951 .42977 m .64046 .43083 L .63776 .43366 L F
.596 .544 .767 r
.64046 .43083 m .64076 .43357 L .63776 .43366 L F
.583 .373 .561 r
.64076 .43357 m .63792 .43627 L .63776 .43366 L F
0 0 0 r
.37985 .58056 m .37776 .58386 L .37885 .5816 L F
.227 0 .231 r
.32536 .53151 m .32433 .53366 L .32719 .53085 L F
.157 0 .063 r
.37297 .55951 m .36981 .56194 L .37014 .56092 L F
.62 .607 .817 r
.3291 .52298 m .33041 .51856 L .3283 .51963 L F
.3291 .52298 m .33207 .52243 L .33041 .51856 L F
.449 .25 .517 r
.35503 .68824 m .3526 .68891 L .35527 .6852 L F
.35503 .68824 m .3526 .68891 L .35527 .6852 L F
.616 .646 .858 r
.3471 .55547 m .34772 .55228 L .34586 .55318 L F
.3471 .55547 m .34966 .55523 L .34772 .55228 L F
.044 0 0 r
.26514 .62322 m .26754 .62319 L .26956 .62306 L F
.264 .671 .967 r
.26518 .62078 m .26905 .62265 L .26484 .62193 L F
.505 .906 .916 r
.26878 .62311 m .26895 .62282 L .27152 .62213 L F
.26895 .62282 m .26895 .62282 L .26901 .6228 L F
.26895 .62282 m .26901 .6228 L .27152 .62213 L F
.205 0 0 r
.26895 .62282 m .26514 .62322 L .26484 .62193 L F
.505 .906 .916 r
.26878 .62311 m .26754 .62319 L .26895 .62282 L F
.205 0 0 r
.26978 .623 m .26821 .62308 L .26895 .62282 L F
.26821 .62308 m .26514 .62322 L .26895 .62282 L F
.505 .906 .916 r
.26956 .62306 m .26878 .62311 L .27152 .62213 L F
.698 .982 .884 r
.26978 .623 m .27152 .62213 L .26895 .62282 L F
.264 .671 .967 r
.26895 .62282 m .26978 .623 L .26895 .62282 L F
.698 .982 .884 r
.26978 .623 m .26895 .62282 L .26754 .62319 L F
.264 .671 .967 r
.26905 .62265 m .26978 .623 L .26895 .62282 L F
.26905 .62265 m .26895 .62282 L .26484 .62193 L F
.676 .156 0 r
.34433 .54479 m .34242 .54568 L .34059 .54352 L F
0 0 0 r
.34487 .54497 m .34433 .54479 L .34652 .54364 L F
.34487 .54497 m .34242 .54568 L .34433 .54479 L F
.769 .713 .8 r
.34878 .51738 m .35197 .51716 L .35401 .51543 L F
.34878 .51738 m .35401 .51543 L .3523 .51274 L F
0 0 .406 r
.35026 .51559 m .35041 .51706 L .35003 .51732 L F
.719 .848 .943 r
.35197 .51716 m .34966 .51757 L .35003 .51732 L F
.515 0 0 r
.35003 .51732 m .35381 .51799 L .35197 .51716 L F
.8 .484 .455 r
.35003 .51732 m .35063 .51923 L .35381 .51799 L F
0 0 .406 r
.35041 .51706 m .35063 .51923 L .35003 .51732 L F
.719 .848 .943 r
.34966 .51757 m .34701 .51803 L .35003 .51732 L F
.541 .323 .533 r
.35401 .51543 m .35381 .51799 L .35197 .51716 L F
.736 .932 .954 r
.22022 .61055 m .22371 .61023 L .22221 .61017 L F
.065 .11 .599 r
.22371 .61023 m .22426 .61365 L .22525 .61208 L F
0 0 .478 r
.22371 .61023 m .22428 .61077 L .22221 .61017 L F
.22371 .61023 m .22525 .61208 L .22428 .61077 L F
.47 .369 .658 r
.34688 .64746 m .34749 .65082 L .34972 .65007 L F
.908 .572 .395 r
.1917 .60812 m .19398 .60969 L .19278 .60739 L F
.646 .323 .41 r
.70562 .32283 m .70475 .32518 L .70253 .32505 L F
.707 .445 .526 r
.70854 .32308 m .70475 .32518 L .70562 .32283 L F
.64 .634 .829 r
.37337 .54375 m .37447 .5396 L .37192 .5396 L F
.37337 .54375 m .37618 .5435 L .37447 .5396 L F
.526 .918 .907 r
.37337 .54375 m .37441 .5426 L .37618 .5435 L F
.37337 .54375 m .37202 .54363 L .37441 .5426 L F
.763 .661 .75 r
.30639 .59063 m .30459 .59071 L .30751 .58754 L F
.108 .085 .547 r
.30749 .59326 m .30459 .59071 L .30639 .59063 L F
.403 .273 .588 r
.30751 .58754 m .3096 .58964 L .30639 .59063 L F
.456 .361 .659 r
.3096 .58964 m .30749 .59326 L .30639 .59063 L F
.39 .105 .356 r
.3264 .56902 m .32808 .57067 L .32858 .56823 L F
.3264 .56902 m .32571 .57167 L .32808 .57067 L F
.019 .565 .835 r
.34705 .50475 m .35099 .50569 L .34883 .50537 L F
.708 .795 .919 r
.63676 .4071 m .63485 .40784 L .63828 .40807 L F
.77 .699 .784 r
.63485 .40784 m .63416 .40972 L .63828 .40807 L F
.802 .79 .842 r
.63676 .4071 m .63828 .40807 L .64133 .40526 L F
.372 .826 .93 r
.32739 .58047 m .33138 .58014 L .32884 .58075 L F
.105 0 0 r
.34657 .56178 m .34896 .5612 L .35099 .55972 L F
.064 .189 .684 r
.35099 .55972 m .35198 .55834 L .34966 .55523 L F
0 0 0 r
.35099 .55972 m .35094 .5601 L .35198 .55834 L F
.35099 .55972 m .34896 .5612 L .35094 .5601 L F
.501 .403 .676 r
.35985 .61696 m .35841 .61968 L .35707 .61906 L F
.35841 .61968 m .35795 .62056 L .35709 .61911 L F
.35841 .61968 m .35709 .61911 L .35707 .61906 L F
0 0 .5 r
.35849 .62193 m .35747 .62291 L .35701 .61907 L F
0 0 .354 r
.35709 .61911 m .35697 .61872 L .35707 .61906 L F
0 0 .5 r
.35716 .61914 m .35709 .61911 L .35697 .61872 L F
0 0 .354 r
.35795 .62056 m .35697 .61872 L .35709 .61911 L F
0 0 .5 r
.35709 .61911 m .35701 .61907 L .35697 .61872 L F
.35849 .62193 m .35701 .61907 L .35716 .61914 L F
.032 .28 .776 r
.35849 .62193 m .35992 .62488 L .35747 .62291 L F
.624 .146 0 r
.39484 .53543 m .39421 .53429 L .3927 .53309 L F
.765 .308 0 r
.39498 .53593 m .39484 .53543 L .39498 .53355 L F
.39498 .53674 m .3961 .53784 L .39484 .53543 L F
.39498 .53674 m .39484 .53543 L .39498 .53593 L F
.624 .146 0 r
.39484 .53543 m .39597 .53667 L .39471 .53496 L F
.39484 .53543 m .39471 .53496 L .39421 .53429 L F
.095 0 0 r
.647 .40204 m .64648 .40291 L .64359 .40387 L F
.136 .285 .753 r
.647 .4007 m .6479 .40101 L .647 .40204 L F
0 0 0 r
.6479 .40101 m .64648 .40291 L .647 .40204 L F
.29789 .60877 m .29895 .60761 L .3008 .60612 L F
.579 .601 .839 r
.35754 .53649 m .35516 .53715 L .35258 .53301 L F
.35263 .53298 m .35258 .53301 L .3525 .53288 L F
.35754 .53649 m .35258 .53301 L .35263 .53298 L F
.35754 .53649 m .3525 .53288 L .35749 .53407 L F
0 0 0 r
.35457 .53164 m .35281 .53324 L .35481 .5319 L F
.35413 .53116 m .35325 .53255 L .35457 .53164 L F
.35325 .53255 m .35281 .53324 L .35457 .53164 L F
.447 .008 .11 r
.35001 .53328 m .35281 .53324 L .35413 .53116 L F
0 0 0 r
.35413 .53116 m .35481 .5319 L .35627 .53024 L F
.011 0 0 r
.21056 .55225 m .2123 .55203 L .21409 .5501 L F
0 0 0 r
.21409 .5501 m .21422 .55101 L .21586 .54919 L F
.21409 .5501 m .2123 .55203 L .21422 .55101 L F
.637 .822 .972 r
.38642 .65536 m .38793 .65666 L .38421 .65637 L F
.936 .626 .428 r
.38624 .65873 m .38848 .65926 L .38793 .65666 L F
.672 .871 .974 r
.38848 .65437 m .38793 .65666 L .38642 .65536 L F
.38848 .65437 m .39064 .65559 L .38793 .65666 L F
.229 .172 .583 r
.38793 .65666 m .38848 .65437 L .38624 .65873 L F
.38793 .65666 m .39004 .65965 L .38848 .65437 L F
.38793 .65666 m .38848 .65926 L .39004 .65965 L F
.755 .434 .442 r
.31616 .53656 m .31653 .53691 L .31949 .53717 L F
.819 .798 .831 r
.70114 .31962 m .70202 .32299 L .69871 .32252 L F
.816 .443 .348 r
.69871 .32252 m .70202 .32299 L .70253 .32505 L F
.77 .753 .838 r
.70334 .31825 m .70202 .32299 L .70114 .31962 L F
.70334 .31825 m .70471 .32017 L .70202 .32299 L F
.536 .109 .178 r
.30298 .62907 m .30646 .62857 L .30275 .62881 L F
0 .064 .611 r
.22426 .61365 m .22574 .61438 L .22525 .61208 L F
.22426 .61365 m .22512 .61607 L .22574 .61438 L F
.501 .844 .571 r
.38332 .64586 m .38222 .64693 L .38477 .64409 L F
.38332 .64586 m .3817 .6473 L .38222 .64693 L F
.504 .314 .556 r
.31019 .55894 m .30769 .56193 L .30784 .55954 L F
.457 .487 .802 r
.19138 .59703 m .19197 .59284 L .19038 .5956 L F
.092 .083 .554 r
.39529 .68131 m .39576 .68425 L .39431 .68241 L F
.254 .118 .495 r
.39576 .68425 m .39415 .68535 L .39431 .68241 L F
.685 .604 .759 r
.30149 .56251 m .30298 .56601 L .30471 .56592 L F
.034 .602 .764 r
.25102 .61611 m .25333 .6162 L .25468 .61631 L F
.882 .917 .845 r
.25468 .61631 m .2551 .61255 L .25678 .61562 L F
.25468 .61631 m .25333 .6162 L .2551 .61255 L F
.504 .295 .529 r
.34524 .53703 m .34778 .53676 L .34793 .53285 L F
.34524 .53703 m .34778 .53676 L .34793 .53285 L F
.307 .386 .78 r
.34851 .52934 m .35001 .53328 L .34793 .53285 L F
.393 .206 .504 r
.34988 .53588 m .34778 .53676 L .34793 .53285 L F
.34988 .53588 m .34778 .53676 L .34793 .53285 L F
.386 .204 .507 r
.35001 .53328 m .34988 .53588 L .34793 .53285 L F
.195 0 .037 r
.37384 .57791 m .37667 .577 L .37705 .57573 L F
.825 .754 .785 r
.37667 .577 m .37855 .57362 L .37705 .57573 L F
.572 .518 .756 r
.38546 .61981 m .38651 .62166 L .38382 .62225 L F
.617 .562 .77 r
.38767 .62547 m .38382 .62225 L .38651 .62166 L F
0 0 0 r
.29157 .62554 m .29428 .62471 L .29549 .62421 L F
.09 .565 .906 r
.29683 .62395 m .29549 .62421 L .29428 .62471 L F
.29683 .62395 m .29862 .6251 L .29549 .62421 L F
.272 0 .277 r
.21666 .547 m .21586 .54919 L .21869 .5462 L F
.595 .781 .969 r
.21452 .5853 m .21237 .58643 L .21203 .58629 L F
.831 .441 .313 r
.28084 .6376 m .27986 .63441 L .27937 .63441 L F
.298 .346 .744 r
.25409 .55278 m .25464 .54863 L .25197 .54916 L F
.25409 .55278 m .25585 .55311 L .25464 .54863 L F
.993 .851 .499 r
.35259 .64966 m .3534 .64771 L .35248 .64603 L F
.53 .55 .82 r
.3534 .64771 m .35428 .64373 L .35248 .64603 L F
.3534 .64771 m .35569 .64707 L .35428 .64373 L F
.325 0 .247 r
.35259 .64966 m .35569 .64707 L .3534 .64771 L F
0 0 0 r
.38668 .64155 m .38585 .6427 L .38477 .64409 L F
.887 .849 .392 r
.38546 .64255 m .385 .64388 L .38585 .6427 L F
.562 .82 .452 r
.38585 .6427 m .38332 .64586 L .38477 .64409 L F
0 0 0 r
.38585 .6427 m .38427 .64597 L .38332 .64586 L F
.887 .849 .392 r
.385 .64388 m .38427 .64597 L .38585 .6427 L F
0 0 0 r
.38722 .64082 m .38585 .6427 L .38668 .64155 L F
.808 .597 .617 r
.61106 .40277 m .60781 .40446 L .61032 .4009 L F
.576 .667 .9 r
.61302 .40027 m .61106 .40277 L .61032 .4009 L F
.423 .445 .778 r
.61302 .40027 m .61408 .40436 L .61106 .40277 L F
.375 .148 .437 r
.33759 .6506 m .3349 .6538 L .3373 .65287 L F
.355 .141 .445 r
.3373 .65287 m .3349 .6538 L .33444 .65685 L F
.235 0 .133 r
.28457 .54353 m .28364 .54594 L .28207 .54579 L F
0 0 .129 r
.2865 .54023 m .28621 .5428 L .28457 .54353 L F
0 0 0 r
.28463 .54441 m .28457 .54353 L .28621 .5428 L F
.28463 .54441 m .28364 .54594 L .28457 .54353 L F
.926 .954 .627 r
.32991 .67867 m .32814 .6822 L .328 .68028 L F
.585 .883 .586 r
.33092 .67734 m .32991 .67867 L .328 .68028 L F
.634 .072 0 r
.33751 .51993 m .33714 .52045 L .33455 .51828 L F
.625 .785 .958 r
.3743 .58319 m .37548 .58507 L .37776 .58386 L F
.605 .573 .791 r
.37539 .66035 m .37268 .66116 L .37103 .65643 L F
.808 .687 .731 r
.39277 .59037 m .39467 .59336 L .38952 .59358 L F
.749 .41 .41 r
.38952 .59358 m .39467 .59336 L .3922 .5952 L F
.232 .744 .722 r
.33235 .55566 m .33642 .55456 L .33294 .55541 L F
.33235 .55566 m .33478 .55494 L .33642 .55456 L F
.534 0 0 r
.33478 .55494 m .33876 .55567 L .33642 .55456 L F
.39 .246 .562 r
.33558 .5684 m .33531 .5718 L .33418 .56986 L F
.344 .1 .392 r
.33482 .57351 m .33418 .56986 L .33531 .5718 L F
.33482 .57351 m .3327 .5746 L .33418 .56986 L F
.86 .578 .509 r
.60834 .41774 m .61178 .42104 L .6078 .42074 L F
.779 .477 .477 r
.6078 .42074 m .61178 .42104 L .61186 .42331 L F
.669 .4 .505 r
.61588 .42086 m .61186 .42331 L .61178 .42104 L F
.055 .561 .882 r
.31093 .65937 m .31325 .66031 L .31153 .65936 L F
.266 .713 .959 r
.31325 .66031 m .31464 .65944 L .31153 .65936 L F
.31325 .66031 m .31585 .66031 L .31464 .65944 L F
.374 .013 .217 r
.40807 .58163 m .40622 .58359 L .40512 .58344 L F
0 0 .189 r
.40933 .57989 m .40807 .58163 L .4091 .5779 L F
.134 0 .325 r
.40933 .57989 m .40622 .58359 L .40807 .58163 L F
.007 0 0 r
.34091 .60649 m .34378 .60365 L .34275 .6055 L F
.113 0 .081 r
.34275 .6055 m .34378 .60365 L .34569 .60271 L F
.162 .4 .844 r
.22512 .61607 m .22816 .61786 L .22574 .61438 L F
0 0 0 r
.40668 .59392 m .4024 .59617 L .404 .59344 L F
.982 .706 .416 r
.64283 .4272 m .64106 .4279 L .64231 .42657 L F
.64283 .4272 m .64298 .42982 L .64106 .4279 L F
.828 1 .809 r
.64283 .4272 m .64394 .42459 L .64583 .42643 L F
.64283 .4272 m .64231 .42657 L .64394 .42459 L F
.479 .242 .477 r
.64583 .42643 m .64298 .42982 L .64283 .4272 L F
.769 .616 .689 r
.63705 .4017 m .63412 .40777 L .63123 .40521 L F
.71 .986 .867 r
.64002 .39962 m .63705 .4017 L .63846 .3996 L F
.706 .976 .769 r
.63705 .4017 m .63659 .40148 L .63846 .3996 L F
0 0 .39 r
.30262 .60289 m .30208 .60059 L .30389 .60058 L F
0 0 0 r
.28974 .53738 m .28842 .53938 L .2865 .54023 L F
0 0 .114 r
.28755 .54122 m .2865 .54023 L .28842 .53938 L F
.28755 .54122 m .28621 .5428 L .2865 .54023 L F
.756 .639 .078 r
.40746 .56683 m .40764 .56574 L .4057 .5648 L F
.40746 .56683 m .4075 .56829 L .40764 .56574 L F
.64 .433 .587 r
.71485 .32031 m .71493 .32276 L .71219 .32306 L F
.652 .823 .965 r
.71617 .31764 m .71764 .31982 L .71485 .32031 L F
.801 .672 .721 r
.71764 .31982 m .71493 .32276 L .71485 .32031 L F
.648 .46 .616 r
.3096 .5411 m .31333 .54106 L .31229 .53832 L F
.3096 .5411 m .31035 .54334 L .31333 .54106 L F
.555 .855 .997 r
.24603 .53166 m .24156 .53123 L .24377 .53085 L F
.568 .87 .995 r
.24828 .53079 m .24603 .53166 L .24377 .53085 L F
.026 0 .17 r
.28933 .63101 m .28793 .63179 L .28699 .63434 L F
.47 .093 .24 r
.30332 .54274 m .29941 .5451 L .30128 .54349 L F
0 0 0 r
.29574 .60962 m .29461 .61203 L .29285 .6127 L F
.151 0 .078 r
.29662 .61118 m .29574 .60962 L .29789 .60877 L F
.29662 .61118 m .29461 .61203 L .29574 .60962 L F
.587 .506 .731 r
.21888 .56079 m .21968 .5623 L .2193 .56266 L F
.115 .66 .831 r
.2193 .56266 m .21968 .5623 L .21663 .56264 L F
.21663 .56264 m .21968 .5623 L .2193 .56266 L F
0 .183 .688 r
.32875 .51669 m .32741 .51608 L .32644 .51492 L F
.685 .604 .759 r
.30149 .56251 m .30471 .56592 L .30417 .56415 L F
.875 .951 .856 r
.30417 .56415 m .30471 .56592 L .30769 .56193 L F
.338 .298 .666 r
.38515 .66449 m .38307 .6634 L .38525 .6618 L F
.458 .221 .465 r
.38515 .66449 m .38286 .66636 L .38307 .6634 L F
.088 0 .014 r
.31016 .58533 m .30904 .58714 L .30751 .58754 L F
0 0 0 r
.31227 .58382 m .30904 .58714 L .31016 .58533 L F
.562 .643 .888 r
.38946 .66328 m .39004 .65965 L .38848 .65926 L F
.38946 .66328 m .39188 .66278 L .39004 .65965 L F
.551 .342 .551 r
.39161 .66513 m .38936 .66597 L .38946 .66328 L F
.203 0 0 r
.3902 .66454 m .38946 .66328 L .38782 .66483 L F
.551 .342 .551 r
.39161 .66513 m .38946 .66328 L .39188 .66278 L F
.203 0 0 r
.3902 .66454 m .39188 .66278 L .38946 .66328 L F
0 0 0 r
.31643 .63407 m .31747 .63226 L .3188 .6311 L F
.688 .542 .682 r
.30751 .58754 m .30459 .59071 L .30536 .5886 L F
0 0 0 r
.32997 .55624 m .33235 .55566 L .33294 .55541 L F
.838 .895 .88 r
.30955 .52367 m .31062 .52527 L .31239 .52338 L F
.965 .886 .704 r
.30955 .52367 m .30823 .52637 L .31062 .52527 L F
0 .251 .761 r
.22529 .5988 m .2249 .60031 L .22298 .59686 L F
.043 .331 .813 r
.22529 .5988 m .22734 .60209 L .2249 .60031 L F
.52 .364 .61 r
.2249 .60031 m .22734 .60209 L .22493 .60273 L F
.48 .283 .535 r
.18759 .60977 m .18989 .60935 L .19002 .60651 L F
.351 .499 .866 r
.24189 .61135 m .24099 .61242 L .23891 .60896 L F
.705 .433 .51 r
.61588 .42086 m .61867 .42101 L .61868 .42337 L F
.359 .162 .472 r
.61868 .42337 m .61867 .42101 L .62093 .42004 L F
.791 .946 .603 r
.71958 .29815 m .71996 .2987 L .71803 .30153 L F
.658 .812 .374 r
.72218 .29459 m .71996 .2987 L .72125 .29616 L F
.785 .856 .903 r
.71958 .29815 m .71546 .29934 L .71811 .29791 L F
.379 0 0 r
.71811 .29791 m .71931 .2982 L .71958 .29815 L F
.77 .957 .642 r
.72031 .298 m .71996 .2987 L .71958 .29815 L F
.917 .774 .688 r
.71803 .30153 m .71672 .30251 L .71958 .29815 L F
.785 .856 .903 r
.71958 .29815 m .71672 .30251 L .71546 .29934 L F
.379 0 0 r
.71931 .2982 m .72125 .29867 L .71958 .29815 L F
.77 .957 .642 r
.72125 .29616 m .72031 .298 L .71958 .29815 L F
.194 0 .225 r
.33141 .59364 m .33029 .59643 L .32864 .59657 L F
.444 .16 .387 r
.33029 .59643 m .32771 .59901 L .32864 .59657 L F
.384 .11 .369 r
.33815 .50828 m .33585 .50906 L .33847 .50615 L F
.33815 .50828 m .33585 .50906 L .33847 .50615 L F
.202 .605 .947 r
.33857 .50471 m .33847 .50615 L .33657 .50444 L F
.564 .635 .88 r
.33815 .50828 m .33657 .50444 L .33847 .50615 L F
.77 .861 .918 r
.3152 .52217 m .31931 .52181 L .31838 .52175 L F
.618 .935 .962 r
.32361 .5198 m .31944 .52018 L .31931 .52181 L F
.216 .332 .768 r
.31944 .52018 m .31838 .52175 L .31931 .52181 L F
.681 .423 .525 r
.38276 .54348 m .37913 .54818 L .37907 .54252 L F
.409 0 0 r
.35736 .57593 m .35577 .57728 L .35367 .57695 L F
0 0 0 r
.3579 .57604 m .35736 .57593 L .35963 .57506 L F
.3579 .57604 m .35577 .57728 L .35736 .57593 L F
.372 0 0 r
.29156 .64973 m .29525 .65038 L .29306 .65067 L F
.819 .355 .118 r
.29525 .65038 m .29509 .65275 L .29306 .65067 L F
.29525 .65038 m .29741 .65321 L .29509 .65275 L F
0 0 0 r
.28891 .61521 m .29285 .6127 L .29134 .61446 L F
.168 0 0 r
.29354 .61389 m .29285 .6127 L .29461 .61203 L F
.29354 .61389 m .29134 .61446 L .29285 .6127 L F
.355 .347 .712 r
.21348 .58293 m .21203 .58629 L .21109 .58126 L F
.595 .781 .969 r
.21452 .5853 m .21203 .58629 L .21348 .58293 L F
.29 .259 .651 r
.30904 .58714 m .3096 .58964 L .30751 .58754 L F
.368 .767 .985 r
.21496 .61006 m .21738 .61093 L .22022 .61055 L F
.428 .222 .497 r
.35649 .5276 m .35841 .52959 L .35886 .52701 L F
.35649 .5276 m .35627 .53024 L .35841 .52959 L F
.119 .512 .91 r
.24121 .62835 m .24117 .62701 L .23831 .62519 L F
.24121 .62835 m .24232 .6283 L .24117 .62701 L F
0 0 .203 r
.3537 .66439 m .35327 .66321 L .3558 .66269 L F
0 .168 .653 r
.36982 .51117 m .37252 .51318 L .37347 .51427 L F
.521 0 0 r
.36937 .51126 m .37252 .51318 L .36982 .51117 L F
0 .231 .717 r
.37168 .51221 m .37252 .51318 L .36937 .51126 L F
.37227 .51246 m .37252 .51318 L .37192 .51249 L F
.37227 .51246 m .37361 .51393 L .37252 .51318 L F
.141 .43 .869 r
.37636 .51427 m .37361 .51393 L .37227 .51246 L F
0 .446 .85 r
.37379 .51226 m .37636 .51427 L .37227 .51246 L F
.37365 .51232 m .37227 .51246 L .37067 .51368 L F
.37379 .51226 m .37227 .51246 L .37365 .51232 L F
0 .231 .717 r
.37227 .51246 m .37192 .51249 L .37168 .51221 L F
0 .168 .653 r
.37347 .51427 m .37252 .51318 L .37376 .51451 L F
0 .21 .686 r
.37252 .51318 m .37361 .51393 L .37376 .51451 L F
0 .174 .663 r
.37361 .51393 m .37531 .51559 L .37376 .51451 L F
.457 .487 .802 r
.19138 .59703 m .19327 .59667 L .19197 .59284 L F
.334 .45 .83 r
.19138 .59703 m .19391 .59759 L .19327 .59667 L F
.016 0 0 r
.3386 .60216 m .33964 .60034 L .33628 .60321 L F
.247 0 .067 r
.34105 .60151 m .33964 .60034 L .3386 .60216 L F
.34105 .60151 m .34214 .59918 L .33964 .60034 L F
.562 .575 .824 r
.33083 .55197 m .33235 .55566 L .32997 .55624 L F
.407 .843 .942 r
.35472 .66955 m .35098 .66982 L .35306 .66843 L F
.387 .811 .969 r
.35576 .66853 m .35472 .66955 L .35306 .66843 L F
.35576 .66853 m .35719 .66912 L .35472 .66955 L F
.105 .624 .885 r
.28304 .52367 m .28532 .52389 L .28696 .52454 L F
.544 .89 .982 r
.28696 .52454 m .28764 .52315 L .28925 .52368 L F
.517 .865 .991 r
.28696 .52454 m .28532 .52389 L .28764 .52315 L F
.438 .825 .987 r
.64088 .39828 m .64002 .39962 L .63846 .3996 L F
.64088 .39828 m .64262 .3991 L .64002 .39962 L F
.802 .79 .842 r
.63676 .4071 m .64133 .40526 L .64015 .40446 L F
.654 .952 .948 r
.64266 .40336 m .64133 .40526 L .64359 .40387 L F
.615 .905 .985 r
.64015 .40446 m .64133 .40526 L .64266 .40336 L F
.566 .014 0 r
.36653 .5414 m .36591 .54039 L .36418 .54201 L F
.58 .464 .685 r
.36405 .54455 m .36653 .5414 L .36418 .54201 L F
.762 .938 .594 r
.36653 .5414 m .36487 .54298 L .36592 .54137 L F
.566 .014 0 r
.36653 .5414 m .36713 .54143 L .36591 .54039 L F
.762 .938 .594 r
.36653 .5414 m .36592 .54137 L .36654 .54042 L F
.566 .014 0 r
.36653 .5414 m .3685 .5426 L .36713 .54143 L F
.604 .29 .412 r
.72737 .34879 m .7272 .35079 L .7244 .35068 L F
.406 .196 .479 r
.73032 .34518 m .73012 .34769 L .72737 .34879 L F
.33 .069 .358 r
.72957 .34966 m .72737 .34879 L .73012 .34769 L F
.72957 .34966 m .7272 .35079 L .72737 .34879 L F
.046 0 .193 r
.31409 .57711 m .31136 .58107 L .31162 .57829 L F
.634 .862 .985 r
.19051 .6045 m .19288 .60553 L .19002 .60651 L F
0 0 .067 r
.19002 .60651 m .19028 .60777 L .19051 .6045 L F
.19002 .60651 m .18989 .60935 L .19028 .60777 L F
0 .286 .784 r
.22885 .61927 m .22892 .61801 L .22816 .61786 L F
.04 .427 .868 r
.22885 .61927 m .23277 .62141 L .22892 .61801 L F
.466 .271 .531 r
.31235 .55827 m .3104 .55622 L .31279 .55577 L F
.31235 .55827 m .31019 .55894 L .3104 .55622 L F
.633 .963 .887 r
.30229 .52081 m .30279 .51944 L .30452 .51921 L F
.30229 .52081 m .30089 .52078 L .30279 .51944 L F
.639 .698 .889 r
.23593 .54832 m .23689 .55006 L .23957 .54976 L F
.447 .258 .529 r
.23689 .55006 m .23925 .55085 L .23957 .54976 L F
.249 0 .319 r
.37823 .59715 m .37567 .60041 L .37812 .59979 L F
.243 0 .123 r
.38224 .59458 m .37823 .59715 L .38132 .59687 L F
.524 .274 .478 r
.38044 .59924 m .37823 .59715 L .37812 .59979 L F
.38044 .59924 m .38132 .59687 L .37823 .59715 L F
.755 .955 .939 r
.33932 .53524 m .33936 .53733 L .34083 .53472 L F
.671 .181 .077 r
.33713 .53838 m .33936 .53733 L .33932 .53524 L F
.146 .092 .534 r
.33936 .53733 m .34096 .53937 L .33969 .54018 L F
.671 .181 .077 r
.33713 .53838 m .34096 .53937 L .33936 .53733 L F
.201 .359 .799 r
.37567 .60041 m .3788 .60381 L .37812 .59979 L F
.498 .337 .593 r
.39421 .58694 m .39839 .58686 L .39658 .58397 L F
.888 .716 .663 r
.39993 .58734 m .39832 .58678 L .39909 .58643 L F
.498 .337 .593 r
.39839 .58686 m .39861 .58686 L .3985 .5867 L F
.39839 .58686 m .3985 .5867 L .39658 .58397 L F
.888 .716 .663 r
.39993 .58734 m .39699 .58904 L .39739 .58836 L F
.498 .337 .593 r
.39658 .58397 m .39861 .58686 L .39421 .58694 L F
.888 .716 .663 r
.39842 .58682 m .39739 .58836 L .39832 .58678 L F
.39993 .58734 m .39739 .58836 L .39842 .58682 L F
.987 .888 .633 r
.39896 .58649 m .3985 .5867 L .39658 .58397 L F
.888 .716 .663 r
.39896 .58649 m .3985 .5867 L .39875 .58605 L F
.329 .283 .654 r
.39658 .58397 m .3985 .5867 L .39875 .58605 L F
.888 .716 .663 r
.3985 .5867 m .39832 .58678 L .39875 .58605 L F
.329 .283 .654 r
.3985 .5867 m .39861 .58686 L .39875 .58605 L F
.987 .888 .633 r
.39896 .58649 m .39861 .58686 L .3985 .5867 L F
.39896 .58649 m .39875 .58605 L .39861 .58686 L F
.40181 .58349 m .39896 .58649 L .39658 .58397 L F
.40181 .58349 m .39875 .58605 L .39896 .58649 L F
.888 .716 .663 r
.39909 .58643 m .39896 .58649 L .39875 .58605 L F
.987 .888 .633 r
.40181 .58349 m .39993 .58734 L .39875 .58605 L F
.275 0 .299 r
.40371 .5833 m .39993 .58734 L .40181 .58349 L F
.182 0 .244 r
.34056 .60822 m .34091 .60649 L .34275 .6055 L F
.407 .175 .446 r
.20266 .55932 m .20491 .55871 L .2052 .55611 L F
.297 .085 .413 r
.2052 .55611 m .20678 .5579 L .20737 .55568 L F
.2052 .55611 m .20491 .55871 L .20678 .5579 L F
.688 .447 .551 r
.30506 .63289 m .30646 .62857 L .30298 .62907 L F
.441 .199 .45 r
.30864 .63009 m .30646 .62857 L .30506 .63289 L F
.539 .136 .226 r
.30864 .63009 m .3095 .62937 L .30646 .62857 L F
0 0 0 r
.38859 .63964 m .38585 .6427 L .38722 .64082 L F
.235 0 .025 r
.26647 .54011 m .26305 .54212 L .26426 .54065 L F
.669 .4 .505 r
.61588 .42086 m .616 .42323 L .61186 .42331 L F
.705 .433 .51 r
.61588 .42086 m .61868 .42337 L .616 .42323 L F
.238 .167 .57 r
.29542 .59382 m .29686 .5899 L .29415 .59041 L F
.29542 .59382 m .29737 .59278 L .29686 .5899 L F
.263 .061 .407 r
.29469 .59505 m .29737 .59278 L .29542 .59382 L F
0 .003 .522 r
.31499 .52811 m .31716 .53064 L .31421 .5275 L F
.31499 .52811 m .31421 .5275 L .31125 .5288 L F
.081 0 .265 r
.29345 .54022 m .29128 .5438 L .29271 .54255 L F
.532 .817 .471 r
.2437 .54138 m .24311 .54205 L .24289 .54231 L F
0 0 .038 r
.24289 .54231 m .24023 .54532 L .24126 .54336 L F
.532 .817 .471 r
.24311 .54205 m .24136 .54403 L .24289 .54231 L F
0 0 0 r
.24289 .54231 m .24209 .54271 L .24272 .54251 L F
.24289 .54231 m .24272 .54251 L .24414 .54205 L F
.24289 .54231 m .24126 .54336 L .24209 .54271 L F
.288 .01 .306 r
.37119 .58103 m .37316 .58026 L .37384 .57791 L F
0 0 .068 r
.37384 .57791 m .37316 .58026 L .3746 .5792 L F
.549 .144 .227 r
.29487 .63441 m .29591 .63697 L .29269 .63731 L F
.29487 .63441 m .29737 .63459 L .29591 .63697 L F
.627 .29 .38 r
.33964 .65258 m .33759 .6506 L .3373 .65287 L F
.33964 .65258 m .34013 .65073 L .33759 .6506 L F
.574 .325 .502 r
.38594 .56152 m .38072 .56408 L .38346 .56217 L F
.075 0 0 r
.29034 .53856 m .28974 .53738 L .29215 .53566 L F
.29034 .53856 m .28842 .53938 L .28974 .53738 L F
.347 .313 .678 r
.33129 .56253 m .33253 .55822 L .32983 .55886 L F
.33129 .56253 m .33313 .56212 L .33253 .55822 L F
.378 .485 .842 r
.33129 .56253 m .33537 .56538 L .33313 .56212 L F
.33129 .56253 m .33537 .56538 L .33313 .56212 L F
0 0 0 r
.21056 .55225 m .21094 .55345 L .2123 .55203 L F
.21056 .55225 m .20928 .55468 L .21094 .55345 L F
.859 .576 .508 r
.32223 .66022 m .32213 .65707 L .31854 .65557 L F
.538 0 0 r
.32283 .65809 m .32213 .65707 L .32223 .66022 L F
.32283 .65809 m .32461 .65905 L .32213 .65707 L F
.413 .182 .452 r
.38767 .62547 m .38737 .62823 L .38506 .62864 L F
.538 .613 .876 r
.38834 .62178 m .38767 .62547 L .38651 .62166 L F
.38834 .62178 m .38998 .62482 L .38767 .62547 L F
.521 .273 .48 r
.38995 .62757 m .38767 .62547 L .38998 .62482 L F
.38995 .62757 m .38737 .62823 L .38767 .62547 L F
.273 .198 .587 r
.32464 .59047 m .32657 .59277 L .32606 .58995 L F
.32464 .59047 m .32444 .59415 L .32657 .59277 L F
.563 .539 .786 r
.38874 .63176 m .38506 .62864 L .38737 .62823 L F
.648 .821 .966 r
.72036 .31867 m .71764 .31982 L .71617 .31764 L F
.21 .295 .733 r
.72032 .32155 m .71764 .31982 L .72036 .31867 L F
.631 .913 .981 r
.3749 .53665 m .37099 .53708 L .37297 .53367 L F
.796 .748 .808 r
.37695 .53403 m .3749 .53665 L .37297 .53367 L F
.121 0 .274 r
.32356 .60337 m .32528 .60045 L .32593 .60269 L F
.158 .055 .478 r
.32771 .59901 m .32593 .60269 L .32528 .60045 L F
.725 .717 .843 r
.39161 .66513 m .39614 .66722 L .39401 .66239 L F
.502 .163 .324 r
.39614 .66722 m .39317 .66938 L .39161 .66513 L F
.39614 .66722 m .39536 .67004 L .39317 .66938 L F
.147 .287 .751 r
.39593 .6621 m .39614 .66722 L .39401 .66239 L F
.39593 .6621 m .39743 .66463 L .39614 .66722 L F
.036 0 .396 r
.39743 .66463 m .39536 .67004 L .39614 .66722 L F
.611 .488 .688 r
.38946 .63416 m .38647 .63496 L .38874 .63176 L F
.227 .236 .661 r
.36792 .52669 m .36883 .53136 L .36693 .53089 L F
.77 .61 .68 r
.36883 .53136 m .36527 .53249 L .36693 .53089 L F
.389 .196 .493 r
.33839 .5817 m .34088 .5834 L .34202 .58138 L F
.717 .83 .382 r
.34202 .58138 m .34088 .5834 L .34269 .57954 L F
0 0 0 r
.28699 .63434 m .28494 .63514 L .28292 .63687 L F
.346 .581 .93 r
.25774 .55619 m .25883 .55407 L .25585 .55311 L F
.25774 .55619 m .25924 .55533 L .25883 .55407 L F
0 0 0 r
.30505 .59943 m .30389 .60058 L .30606 .59713 L F
.30262 .60289 m .30389 .60058 L .30505 .59943 L F
.814 .782 .823 r
.40056 .56834 m .39884 .56934 L .39695 .56792 L F
.469 .344 .627 r
.33327 .59018 m .33383 .59339 L .33141 .59364 L F
.615 .31 .43 r
.33381 .59585 m .33141 .59364 L .33383 .59339 L F
.33381 .59585 m .33029 .59643 L .33141 .59364 L F
.125 .047 .489 r
.19241 .57191 m .19368 .57109 L .19391 .56752 L F
.134 .064 .505 r
.19241 .57191 m .19381 .57377 L .19368 .57109 L F
.238 .087 .464 r
.19222 .57454 m .19381 .57377 L .19241 .57191 L F
.365 .663 .971 r
.72596 .33317 m .72473 .33482 L .72292 .33166 L F
.72596 .33317 m .72664 .33464 L .72473 .33482 L F
.49 .45 .74 r
.3685 .5426 m .3671 .54681 L .36654 .54341 L F
.497 .498 .787 r
.3698 .54628 m .36953 .5488 L .3671 .54681 L F
.978 .732 .496 r
.41907 .55929 m .417 .56096 L .41752 .55823 L F
.41907 .55929 m .41942 .56271 L .417 .56096 L F
.734 .557 .653 r
.42012 .56199 m .41942 .56271 L .41907 .55929 L F
.652 .893 .983 r
.41907 .55929 m .42036 .5569 L .4219 .55867 L F
.41907 .55929 m .41752 .55823 L .42036 .5569 L F
.714 .65 .784 r
.4219 .55867 m .42012 .56199 L .41907 .55929 L F
.957 .615 .256 r
.62243 .41326 m .62319 .41198 L .6219 .41045 L F
.62243 .41326 m .62406 .4146 L .62319 .41198 L F
.628 .487 .671 r
.62593 .4112 m .62406 .4146 L .62319 .41198 L F
.443 0 .044 r
.32117 .51696 m .32269 .51723 L .32423 .51538 L F
0 0 0 r
.32423 .51538 m .32477 .51606 L .32644 .51492 L F
.32423 .51538 m .32269 .51723 L .32477 .51606 L F
.748 .752 .856 r
.18989 .60935 m .19398 .60969 L .1917 .60812 L F
.76 .417 .404 r
.35221 .70788 m .34833 .70939 L .34846 .70682 L F
.35221 .70788 m .35242 .70988 L .34833 .70939 L F
.369 .162 .462 r
.20266 .55932 m .20442 .5612 L .20491 .55871 L F
.20266 .55932 m .20236 .56204 L .20442 .5612 L F
0 0 0 r
.26264 .53422 m .26265 .53372 L .26527 .53307 L F
.26264 .53422 m .26123 .53558 L .26265 .53372 L F
.725 .919 .568 r
.23356 .5475 m .23297 .54902 L .23593 .54832 L F
.23356 .5475 m .23227 .54943 L .23297 .54902 L F
0 0 0 r
.30505 .59943 m .30606 .59713 L .30732 .59562 L F
.14 0 .019 r
.20016 .56281 m .20121 .56352 L .20236 .56204 L F
.20016 .56281 m .19911 .56443 L .20121 .56352 L F
.339 0 0 r
.33501 .54986 m .33083 .55197 L .33245 .5517 L F
.454 .311 .596 r
.38335 .5908 m .38566 .59314 L .38566 .59014 L F
.533 .315 .529 r
.38317 .5934 m .38566 .59314 L .38335 .5908 L F
.38317 .5934 m .38566 .59314 L .38335 .5908 L F
0 0 0 r
.25096 .54018 m .24854 .54144 L .2464 .54192 L F
.566 .786 .982 r
.138 .70594 m .13985 .70726 L .14215 .70654 L F
.14215 .70654 m .13985 .70726 L .138 .70594 L F
.345 .565 .92 r
.20618 .60253 m .20533 .59959 L .20417 .59944 L F
.20618 .60253 m .20795 .60257 L .20533 .59959 L F
.252 .042 .388 r
.6217 .41798 m .62359 .41527 L .6228 .41669 L F
0 0 .112 r
.6228 .41669 m .6217 .41798 L .62093 .42004 L F
.864 .732 .715 r
.62093 .42002 m .6228 .41669 L .61959 .41623 L F
.62093 .42004 m .6228 .41669 L .62093 .42002 L F
.252 .042 .388 r
.62359 .41527 m .62406 .4146 L .6228 .41669 L F
.362 .583 .927 r
.23675 .62541 m .23852 .62406 L .23463 .62237 L F
.23675 .62541 m .23831 .62519 L .23852 .62406 L F
.109 0 0 r
.35754 .53649 m .35359 .53867 L .35516 .53715 L F
.721 .665 .794 r
.61868 .42337 m .61964 .42693 L .61593 .42705 L F
.693 .414 .496 r
.61593 .42705 m .61964 .42693 L .61963 .42948 L F
.447 .487 .808 r
.61997 .42408 m .61964 .42693 L .61868 .42337 L F
.487 .665 .941 r
.62456 .42527 m .62253 .42626 L .61997 .42408 L F
.827 .974 .669 r
.61892 .42168 m .61868 .42337 L .6189 .42304 L F
.61892 .42168 m .6189 .42304 L .62093 .42004 L F
.782 .587 .019 r
.61892 .42168 m .61881 .41942 L .61857 .41922 L F
0 0 .271 r
.61893 .42094 m .61892 .42168 L .61869 .41973 L F
.447 .487 .808 r
.61997 .42408 m .61868 .42337 L .62107 .42489 L F
.5 0 0 r
.62107 .42489 m .62456 .42527 L .61997 .42408 L F
0 .286 .785 r
.62107 .42489 m .61937 .42381 L .61892 .42168 L F
.827 .974 .669 r
.61892 .42168 m .62093 .42004 L .61881 .41942 L F
0 .286 .785 r
.62107 .42489 m .61892 .42168 L .61954 .42403 L F
0 0 .271 r
.61954 .42403 m .61892 .42168 L .61893 .42094 L F
0 .286 .785 r
.61937 .42381 m .61868 .42337 L .61877 .42269 L F
.61937 .42381 m .61877 .42269 L .61892 .42168 L F
.697 .719 .866 r
.61997 .42408 m .62253 .42626 L .62087 .42665 L F
.61989 .42479 m .62087 .42665 L .61964 .42693 L F
.61997 .42408 m .62087 .42665 L .61989 .42479 L F
.579 .278 .422 r
.61964 .42693 m .62261 .42894 L .61963 .42948 L F
.61964 .42693 m .62253 .42626 L .62261 .42894 L F
.534 .345 .571 r
.30462 .65115 m .30712 .6503 L .30733 .64724 L F
.744 .584 .677 r
.30712 .6503 m .31057 .64856 L .30733 .64724 L F
.884 .55 .412 r
.33721 .69443 m .34044 .69786 L .3371 .69718 L F
.847 .563 .507 r
.3371 .69718 m .34044 .69786 L .3405 .7005 L F
.339 0 0 r
.33501 .54986 m .33357 .55165 L .33083 .55197 L F
0 0 0 r
.3356 .55047 m .33501 .54986 L .33744 .5488 L F
.3356 .55047 m .33357 .55165 L .33501 .54986 L F
.982 .695 .35 r
.37095 .57092 m .37224 .57252 L .37121 .57344 L F
0 0 0 r
.37121 .57344 m .37224 .57252 L .37514 .57139 L F
.652 .803 .955 r
.37095 .57092 m .37224 .57252 L .37514 .57139 L F
.407 .228 .524 r
.39134 .69352 m .38974 .69148 L .3912 .69083 L F
.39134 .69352 m .38947 .69475 L .38974 .69148 L F
.492 .705 .964 r
.36229 .65999 m .36535 .66089 L .36611 .65919 L F
.298 .473 .864 r
.36611 .65919 m .36535 .66089 L .36675 .65953 L F
.54 .487 .745 r
.36535 .66089 m .36889 .66286 L .36675 .65953 L F
.36535 .66089 m .36667 .66397 L .36889 .66286 L F
.745 .642 .746 r
.38936 .66597 m .3913 .67058 L .38683 .66916 L F
.603 .571 .79 r
.39317 .66938 m .3913 .67058 L .38936 .66597 L F
.221 0 0 r
.3383 .52598 m .3404 .52584 L .34217 .52435 L F
0 0 0 r
.34217 .52435 m .34351 .52307 L .34484 .52094 L F
.495 .835 .553 r
.34217 .52435 m .3404 .52584 L .34351 .52307 L F
.305 .481 .869 r
.35968 .50733 m .35907 .50979 L .35825 .50763 L F
.577 .765 .968 r
.3611 .50911 m .35907 .50979 L .35968 .50733 L F
.685 .952 .954 r
.37582 .55103 m .37499 .55293 L .37745 .5515 L F
.414 0 0 r
.37893 .55609 m .37725 .55774 L .37469 .55783 L F
.83 .421 .27 r
.37499 .55293 m .37794 .55656 L .37893 .55609 L F
.094 .272 .755 r
.37582 .55103 m .37794 .55656 L .37499 .55293 L F
.301 .049 .355 r
.26893 .55301 m .26658 .55558 L .26716 .55349 L F
.293 0 0 r
.30346 .6335 m .30785 .63423 L .30656 .63388 L F
.025 .529 .872 r
.30785 .63423 m .30821 .6337 L .30656 .63388 L F
.30785 .63423 m .31014 .63493 L .30821 .6337 L F
.688 .447 .551 r
.30506 .63289 m .30298 .62907 L .30223 .63099 L F
.766 .655 .739 r
.34181 .54015 m .33969 .54018 L .34071 .53953 L F
.34294 .54079 m .34148 .54052 L .34181 .54015 L F
.34148 .54052 m .33969 .54018 L .34181 .54015 L F
.8 .657 .705 r
.34519 .53991 m .34308 .536 L .34524 .53703 L F
.34519 .53991 m .34096 .53937 L .34308 .536 L F
.696 .58 .721 r
.3428 .53904 m .34452 .53694 L .34326 .53821 L F
.766 .655 .739 r
.34294 .54079 m .34071 .53953 L .34107 .53944 L F
.575 .829 .993 r
.34519 .53991 m .34294 .54079 L .34096 .53937 L F
.696 .58 .721 r
.34192 .54063 m .34396 .53774 L .3428 .53904 L F
.34396 .53774 m .34452 .53694 L .3428 .53904 L F
.766 .655 .739 r
.34294 .54079 m .34059 .54352 L .33969 .54018 L F
.193 0 0 r
.33987 .54107 m .34192 .54063 L .3428 .53904 L F
.34207 .53921 m .3428 .53904 L .34326 .53821 L F
.33987 .54107 m .3428 .53904 L .34207 .53921 L F
.766 .655 .739 r
.34107 .53944 m .34071 .53953 L .34096 .53937 L F
0 0 .266 r
.36554 .51897 m .3648 .51673 L .36511 .51816 L F
0 0 .189 r
.40933 .57989 m .4091 .5779 L .40928 .57717 L F
.574 .535 .773 r
.31915 .57385 m .31552 .57094 L .31722 .57181 L F
.661 .328 .399 r
.32047 .57225 m .31915 .57385 L .31722 .57181 L F
.357 .793 .965 r
.26782 .52471 m .26751 .52571 L .26564 .52537 L F
.26782 .52471 m .26944 .52566 L .26751 .52571 L F
0 0 .385 r
.37288 .61603 m .37279 .61867 L .37383 .61744 L F
.37288 .61603 m .37383 .61744 L .37394 .61497 L F
.341 .149 .469 r
.37681 .61309 m .37394 .61497 L .37383 .61744 L F
.502 .296 .533 r
.36936 .6154 m .37226 .61249 L .37021 .61731 L F
.3702 .61731 m .37021 .61731 L .3702 .61732 L F
.36936 .6154 m .37021 .61731 L .3702 .61731 L F
.341 .149 .469 r
.37681 .61309 m .37383 .61744 L .37616 .61688 L F
.462 .824 .995 r
.37438 .61679 m .37383 .61744 L .37182 .61699 L F
.625 .411 .572 r
.36876 .61193 m .37074 .61203 L .36936 .6154 L F
.454 .23 .484 r
.36936 .6154 m .37074 .61203 L .37226 .61249 L F
.966 .87 .692 r
.3702 .61732 m .37226 .61249 L .36983 .61381 L F
.862 .428 .008 r
.36922 .61661 m .3702 .61732 L .36936 .6154 L F
.36919 .6169 m .36948 .61702 L .36922 .61661 L F
.36948 .61702 m .3702 .61732 L .36922 .61661 L F
.835 .801 .819 r
.3702 .61732 m .36932 .61742 L .37014 .61993 L F
.579 .529 .764 r
.36841 .62018 m .37042 .62079 L .36965 .62 L F
.912 .764 .684 r
.36932 .61742 m .36841 .62018 L .37014 .61993 L F
.579 .529 .764 r
.37042 .62079 m .37021 .61997 L .36884 .61916 L F
.912 .764 .684 r
.37014 .61993 m .36841 .62018 L .37021 .62015 L F
.579 .529 .764 r
.36841 .62018 m .36965 .62 L .36884 .61916 L F
.966 .87 .692 r
.3702 .61732 m .37013 .6166 L .37003 .61725 L F
.37013 .6166 m .36983 .61381 L .37003 .61725 L F
.37003 .61725 m .36983 .61381 L .36919 .6169 L F
.686 .796 .933 r
.37383 .61744 m .37249 .61907 L .3702 .61732 L F
.37383 .61744 m .3702 .61732 L .37021 .61997 L F
.579 .529 .764 r
.3704 .62072 m .37033 .62004 L .37021 .61997 L F
.686 .796 .933 r
.37033 .62006 m .37021 .61997 L .37021 .62015 L F
.37383 .61744 m .37021 .61997 L .37033 .62006 L F
.37383 .61744 m .37033 .62006 L .36996 .61656 L F
.985 .717 .343 r
.36958 .61745 m .3702 .61732 L .36948 .61702 L F
.835 .801 .819 r
.3702 .61732 m .37014 .61993 L .37021 .61997 L F
.985 .717 .343 r
.37021 .61997 m .3702 .61732 L .36958 .61745 L F
.579 .529 .764 r
.36892 .619 m .37017 .6198 L .36958 .61745 L F
.37021 .61997 m .37286 .62153 L .36892 .619 L F
.36884 .61916 m .37021 .61997 L .36892 .619 L F
.36841 .62018 m .36958 .61745 L .37021 .62015 L F
.985 .717 .343 r
.37021 .62015 m .36958 .61745 L .36919 .6169 L F
.36958 .61745 m .36948 .61702 L .36947 .61702 L F
.36958 .61745 m .36947 .61702 L .36919 .6169 L F
.579 .529 .764 r
.36958 .61745 m .37286 .62153 L .36996 .61656 L F
.37017 .6198 m .37286 .62153 L .36958 .61745 L F
.686 .796 .933 r
.37033 .62006 m .37021 .62015 L .36996 .61656 L F
.579 .529 .764 r
.37042 .62079 m .37286 .62153 L .37033 .62004 L F
.37042 .62079 m .37033 .62004 L .3704 .62072 L F
.835 .801 .819 r
.37021 .61997 m .37014 .61993 L .37021 .62015 L F
.985 .717 .343 r
.37021 .62015 m .37021 .61997 L .36958 .61745 L F
.579 .529 .764 r
.36841 .62018 m .37385 .62325 L .37286 .62153 L F
.36958 .61745 m .36965 .61729 L .37021 .62015 L F
.36965 .61729 m .36996 .61656 L .37006 .61794 L F
.36965 .61729 m .37006 .61794 L .37021 .62015 L F
.462 .824 .995 r
.37314 .61672 m .37182 .61699 L .36996 .61656 L F
.37438 .61679 m .37182 .61699 L .37314 .61672 L F
.37616 .61688 m .37383 .61744 L .37438 .61679 L F
0 0 .385 r
.37279 .61867 m .37277 .61922 L .37383 .61744 L F
.703 .963 .713 r
.37383 .61744 m .37277 .61922 L .37249 .61907 L F
.837 .521 0 r
.37277 .61922 m .37354 .622 L .37249 .61907 L F
.849 .719 .718 r
.34266 .66859 m .34451 .66758 L .34263 .66829 L F
.315 .735 .975 r
.33762 .66881 m .34296 .66885 L .34179 .66857 L F
0 0 0 r
.34409 .66872 m .3417 .67231 L .34289 .67176 L F
.659 .802 .951 r
.33856 .66778 m .34296 .66885 L .34263 .66829 L F
0 0 0 r
.34409 .66872 m .34289 .67176 L .34263 .66829 L F
.849 .719 .718 r
.34289 .67176 m .34411 .66862 L .34266 .66859 L F
.34411 .66862 m .34451 .66758 L .34266 .66859 L F
.315 .735 .975 r
.33791 .66848 m .34179 .66857 L .33856 .66778 L F
.33762 .66881 m .34179 .66857 L .33791 .66848 L F
.236 0 .198 r
.29319 .63946 m .29269 .63731 L .29591 .63697 L F
.54 .355 .579 r
.57548 .40496 m .57397 .40688 L .57244 .40615 L F
.57548 .40496 m .57568 .40794 L .57295 .40817 L F
.57548 .40496 m .57244 .40615 L .5716 .40401 L F
.936 .608 .389 r
.5716 .40401 m .57244 .40615 L .57039 .40527 L F
0 .516 .83 r
.57106 .40549 m .57244 .40615 L .57433 .40656 L F
.57039 .40527 m .57244 .40615 L .57106 .40549 L F
.54 .355 .579 r
.57397 .40688 m .57295 .40817 L .57244 .40615 L F
.458 .761 .995 r
.57295 .40817 m .57433 .40656 L .57244 .40615 L F
.57295 .40817 m .57568 .40794 L .57433 .40656 L F
.467 .505 .814 r
.32223 .55515 m .32521 .56022 L .32614 .55949 L F
.923 .953 .62 r
.32521 .56022 m .32393 .55962 L .32614 .55949 L F
.32521 .56022 m .32392 .56213 L .32393 .55962 L F
.359 .732 .988 r
.3197 .66033 m .32223 .66022 L .31811 .6592 L F
.753 .668 .768 r
.36278 .52481 m .36315 .52792 L .35886 .52701 L F
.759 .655 .748 r
.36315 .52792 m .3607 .53058 L .35886 .52701 L F
.151 .122 .569 r
.33628 .60321 m .33827 .60521 L .3386 .60216 L F
.559 .458 .695 r
.33259 .65989 m .33444 .65685 L .33231 .65725 L F
.032 0 .287 r
.21285 .57792 m .21233 .58042 L .21109 .58126 L F
.355 .347 .712 r
.21348 .58293 m .21109 .58126 L .21233 .58042 L F
.645 .71 .894 r
.3365 .57764 m .33839 .5817 L .3356 .58118 L F
0 0 0 r
.33839 .5817 m .33533 .58405 L .3356 .58118 L F
.637 .38 .513 r
.33533 .58405 m .33854 .58438 L .33839 .5817 L F
0 0 0 r
.33839 .5817 m .33622 .58362 L .33533 .58405 L F
.637 .38 .513 r
.33533 .58405 m .33839 .5817 L .3356 .58118 L F
.389 .196 .493 r
.33839 .5817 m .33854 .58438 L .34088 .5834 L F
0 0 0 r
.33885 .58253 m .33839 .5817 L .33926 .57951 L F
.33885 .58253 m .33622 .58362 L .33839 .5817 L F
.92 .535 .14 r
.3241 .60632 m .32264 .6036 L .32356 .60337 L F
.81 .976 .899 r
.32455 .60401 m .32356 .60337 L .32593 .60269 L F
.32455 .60401 m .3241 .60632 L .32356 .60337 L F
.683 .499 .632 r
.32472 .64351 m .32805 .64243 L .32586 .64095 L F
.515 .881 .979 r
.25719 .52804 m .25496 .52886 L .25223 .52833 L F
.562 .393 .61 r
.34773 .63798 m .35024 .63756 L .35008 .63482 L F
.523 .318 .543 r
.34742 .64084 m .35024 .63756 L .34773 .63798 L F
.514 .857 .994 r
.71797 .34063 m .72199 .34074 L .71907 .34142 L F
.344 .14 .453 r
.71411 .3326 m .71678 .3312 L .71633 .32932 L F
.327 .111 .425 r
.71411 .3326 m .71412 .33472 L .71678 .3312 L F
.71411 .3326 m .71412 .33472 L .71678 .3312 L F
.793 .732 .796 r
.37855 .57362 m .37898 .57788 L .38305 .5749 L F
0 0 .333 r
.35918 .59661 m .3594 .59172 L .35693 .59398 L F
.35918 .59661 m .35968 .59581 L .3594 .59172 L F
0 0 0 r
.36074 .59397 m .35968 .59581 L .35918 .59661 L F
.32 .291 .67 r
.39698 .67528 m .39785 .67818 L .3954 .67863 L F
0 0 .127 r
.39785 .67818 m .39529 .68131 L .3954 .67863 L F
.163 .7 .735 r
.35057 .5801 m .34616 .58083 L .34826 .58103 L F
.686 .351 .402 r
.28991 .55228 m .29226 .55503 L .29176 .5528 L F
.534 .406 .652 r
.35921 .66337 m .36043 .66443 L .3607 .66177 L F
.432 .726 .988 r
.35969 .66273 m .35992 .66273 L .35978 .66264 L F
.567 .65 .891 r
.3558 .66269 m .35921 .66337 L .35992 .66273 L F
.492 .75 .986 r
.35635 .66054 m .35992 .66273 L .36032 .66217 L F
.35977 .66137 m .36032 .66217 L .36072 .6616 L F
.867 .894 .852 r
.35809 .65879 m .35881 .66012 L .36138 .65752 L F
.492 .75 .986 r
.35635 .66054 m .36032 .66217 L .3598 .66141 L F
.35635 .66054 m .3598 .66141 L .35977 .66137 L F
.35635 .66054 m .35977 .66137 L .35967 .66172 L F
.867 .894 .852 r
.35977 .66137 m .35967 .66172 L .3598 .66141 L F
.35881 .66012 m .3598 .66141 L .36138 .65752 L F
.492 .75 .986 r
.35977 .66137 m .3598 .66141 L .35977 .66137 L F
.679 .527 .672 r
.35967 .66172 m .35987 .66151 L .3598 .66141 L F
.35967 .66172 m .36072 .6616 L .36286 .65825 L F
.492 .75 .986 r
.35977 .66137 m .36072 .6616 L .35967 .66172 L F
.867 .894 .852 r
.35881 .66012 m .35967 .66172 L .35977 .66137 L F
.679 .527 .672 r
.3598 .66141 m .36286 .65825 L .36138 .65752 L F
.35987 .66151 m .36286 .65825 L .3598 .66141 L F
.611 .906 .984 r
.35992 .66273 m .35921 .66337 L .36072 .6616 L F
.534 .406 .652 r
.36005 .66239 m .3607 .66177 L .36072 .6616 L F
.35921 .66337 m .3607 .66177 L .36005 .66239 L F
.432 .726 .988 r
.3558 .66269 m .35969 .66273 L .35635 .66054 L F
.35969 .66273 m .35978 .66264 L .35635 .66054 L F
.799 .959 .635 r
.35635 .66054 m .3537 .66439 L .3558 .66269 L F
.591 .36 .534 r
.72514 .29672 m .72218 .29459 L .72125 .29616 L F
.72514 .29672 m .72505 .29406 L .72218 .29459 L F
.917 .774 .688 r
.71803 .30153 m .71729 .30401 L .71672 .30251 L F
.466 .762 .994 r
.36286 .65825 m .36229 .65999 L .36611 .65919 L F
.851 .439 .251 r
.36072 .6616 m .36229 .65999 L .36286 .65825 L F
.36072 .6616 m .36368 .66293 L .36229 .65999 L F
.67 .649 .821 r
.23486 .60604 m .2333 .60878 L .23103 .60473 L F
.703 .21 .069 r
.28365 .64679 m .28721 .64747 L .28543 .64856 L F
.641 .129 .011 r
.28543 .64856 m .28721 .64747 L .28953 .64929 L F
.72 .981 .774 r
.37893 .55609 m .37975 .55443 L .38087 .55237 L F
.116 .282 .757 r
.38087 .55237 m .38228 .55122 L .38038 .54921 L F
.53 .342 .571 r
.37975 .55443 m .38228 .55122 L .38087 .55237 L F
.765 .671 .759 r
.71523 .33884 m .71262 .34203 L .71148 .33833 L F
0 0 .236 r
.71148 .33833 m .71262 .34203 L .71219 .34051 L F
.968 .845 .434 r
.71262 .34203 m .71174 .34343 L .71219 .34051 L F
.534 .061 .078 r
.71262 .34203 m .7138 .34337 L .71174 .34343 L F
.505 .299 .534 r
.34524 .53703 m .34519 .53991 L .34778 .53676 L F
.34524 .53703 m .34519 .53991 L .34778 .53676 L F
.922 .765 .669 r
.34396 .53349 m .34524 .53703 L .34308 .536 L F
.637 .804 .963 r
.36391 .66679 m .35968 .66616 L .36205 .66536 L F
.758 .85 .92 r
.36572 .66479 m .36391 .66679 L .36205 .66536 L F
.632 .32 .425 r
.31115 .62765 m .31332 .6284 L .31482 .62482 L F
.507 .888 .703 r
.31815 .6226 m .31482 .62482 L .3182 .62237 L F
.519 .203 .372 r
.31482 .62482 m .31728 .62731 L .3182 .62237 L F
.31482 .62482 m .31332 .6284 L .31728 .62731 L F
.463 .193 .417 r
.30636 .65302 m .30462 .65115 L .30377 .65281 L F
.30636 .65302 m .30712 .6503 L .30462 .65115 L F
0 0 0 r
.35102 .52348 m .34833 .52653 L .34953 .52509 L F
.665 .137 0 r
.31427 .54851 m .31791 .54953 L .31746 .54695 L F
.519 .424 .687 r
.31746 .54695 m .32036 .54724 L .31894 .54529 L F
.31746 .54695 m .31791 .54953 L .32036 .54724 L F
.567 .297 .467 r
.3607 .53058 m .36316 .5336 L .35996 .53335 L F
.532 .559 .827 r
.25983 .5398 m .2614 .5435 L .26305 .54212 L F
.504 .233 .437 r
.3883 .60877 m .38372 .61137 L .38347 .60973 L F
.582 .592 .829 r
.33964 .63083 m .34101 .62769 L .33902 .62841 L F
.33964 .63083 m .34244 .63134 L .34101 .62769 L F
.285 .353 .757 r
.30149 .56251 m .30417 .56415 L .30309 .56082 L F
.715 .6 .727 r
.29271 .54255 m .29602 .53935 L .29345 .54022 L F
0 0 0 r
.35636 .54285 m .35518 .54405 L .35798 .54227 L F
.35472 .54395 m .35798 .54227 L .35518 .54405 L F
.35472 .54395 m .35594 .5436 L .35798 .54227 L F
.866 .987 .714 r
.35798 .54227 m .35594 .5436 L .35672 .5428 L F
0 0 0 r
.35636 .54285 m .35798 .54227 L .35928 .54171 L F
.866 .987 .714 r
.35798 .54227 m .35672 .5428 L .35889 .54061 L F
0 0 0 r
.35928 .54171 m .35798 .54227 L .35968 .54156 L F
.72 .981 .774 r
.37893 .55609 m .37794 .55656 L .37975 .55443 L F
.426 0 .03 r
.38052 .55658 m .37725 .55774 L .37893 .55609 L F
.398 .791 .988 r
.38566 .59314 m .38718 .59387 L .38317 .5934 L F
.38566 .59314 m .38718 .59387 L .38317 .5934 L F
.096 .294 .774 r
.37447 .5396 m .37618 .5435 L .37699 .54181 L F
.59 .887 .991 r
.37618 .5435 m .37441 .5426 L .37699 .54181 L F
.373 .778 .984 r
.38952 .59358 m .38718 .59387 L .38566 .59314 L F
.567 .659 .898 r
.31139 .53412 m .31616 .53656 L .31427 .53425 L F
.367 .158 .458 r
.3176 .53895 m .31616 .53656 L .31653 .53691 L F
.714 .65 .784 r
.4219 .55867 m .42297 .56223 L .42012 .56199 L F
.823 .551 .528 r
.42263 .565 m .42012 .56199 L .42297 .56223 L F
0 0 .38 r
.4219 .55867 m .42338 .56233 L .42297 .56223 L F
.841 .376 .006 r
.42338 .56233 m .42548 .56435 L .42297 .56223 L F
.459 .317 .601 r
.42297 .56223 m .42548 .56435 L .42263 .565 L F
.679 .767 .282 r
.27965 .63363 m .27937 .63441 L .28046 .63165 L F
0 0 .504 r
.27965 .63363 m .28084 .6376 L .27937 .63441 L F
.838 .895 .88 r
.30955 .52367 m .31239 .52338 L .31054 .52222 L F
.639 .832 .975 r
.31239 .52338 m .31365 .52081 L .31054 .52222 L F
.31239 .52338 m .3152 .52217 L .31365 .52081 L F
.754 .653 .75 r
.39618 .57086 m .39651 .57233 L .39884 .56934 L F
.827 .775 .803 r
.39884 .56934 m .39651 .57233 L .39443 .57112 L F
.916 .634 .494 r
.39443 .57112 m .39651 .57233 L .39564 .57495 L F
0 0 0 r
.34484 .52094 m .34637 .52032 L .34701 .51803 L F
.34484 .52094 m .3449 .52164 L .34637 .52032 L F
.34484 .52094 m .34351 .52307 L .3449 .52164 L F
.759 .556 .623 r
.34427 .65325 m .3473 .65317 L .34749 .65082 L F
.097 0 .441 r
.34749 .65082 m .34902 .65162 L .34972 .65007 L F
.34749 .65082 m .3473 .65317 L .34902 .65162 L F
.707 .445 .526 r
.70854 .32308 m .70869 .32551 L .70475 .32518 L F
.407 .22 .513 r
.71131 .32578 m .70854 .32308 L .71219 .32306 L F
.71131 .32578 m .70869 .32551 L .70854 .32308 L F
.425 .195 .46 r
.30681 .57188 m .30868 .57374 L .30894 .57139 L F
.13 .169 .634 r
.30772 .57457 m .30868 .57374 L .30681 .57188 L F
.469 .302 .571 r
.57807 .40684 m .57548 .40496 L .5753 .40322 L F
0 .04 .61 r
.5753 .40322 m .57548 .40496 L .57537 .40381 L F
.548 .813 .995 r
.57537 .40381 m .57548 .40496 L .5716 .40401 L F
.469 .302 .571 r
.57807 .40684 m .57568 .40794 L .57548 .40496 L F
.757 .692 .79 r
.71523 .33884 m .71148 .33833 L .71412 .33472 L F
.989 .744 .368 r
.71412 .33472 m .71523 .33884 L .71807 .33689 L F
.71412 .33472 m .71416 .33746 L .71523 .33884 L F
.51 .29 .515 r
.71666 .34034 m .71523 .33884 L .71416 .33746 L F
0 0 .179 r
.23227 .54943 m .23222 .5513 L .23163 .55263 L F
0 .133 .672 r
.23222 .5513 m .23244 .55342 L .23163 .55263 L F
.76 .992 .786 r
.35968 .54156 m .3603 .54001 L .36161 .54093 L F
.548 .442 .686 r
.3615 .55507 m .35838 .55279 L .36122 .55262 L F
.3615 .55507 m .35911 .55631 L .35838 .55279 L F
.952 .604 .287 r
.41372 .54215 m .41482 .54033 L .41351 .53912 L F
.41372 .54215 m .41565 .5434 L .41482 .54033 L F
.41482 .54033 m .41372 .54215 L .41351 .53912 L F
.41482 .54033 m .41565 .5434 L .41372 .54215 L F
.717 .41 .459 r
.41657 .55334 m .41435 .5534 L .41594 .55446 L F
.815 .949 .602 r
.41673 .55305 m .41594 .55446 L .41669 .55306 L F
.41757 .55292 m .41594 .55446 L .41673 .55305 L F
.717 .41 .459 r
.4169 .55333 m .41657 .55334 L .41594 .55446 L F
.919 .594 .126 r
.41757 .55292 m .41673 .55305 L .41617 .54939 L F
.41673 .55305 m .41668 .55298 L .41617 .54939 L F
.109 .286 .762 r
.4186 .55134 m .41757 .55292 L .41617 .54939 L F
.86 .506 .379 r
.41617 .54939 m .41668 .55298 L .41499 .55194 L F
.41668 .55298 m .41657 .55298 L .41378 .5512 L F
.717 .41 .459 r
.41667 .55296 m .41435 .5534 L .4169 .55333 L F
.856 .892 .862 r
.41657 .55298 m .41435 .5534 L .41378 .5512 L F
.717 .41 .459 r
.41634 .55243 m .41435 .5534 L .41667 .55296 L F
.856 .892 .862 r
.41669 .55306 m .41435 .5534 L .41657 .55298 L F
.86 .506 .379 r
.41668 .55298 m .41669 .55306 L .41657 .55298 L F
.717 .41 .459 r
.4172 .55298 m .41668 .55298 L .4169 .55333 L F
.4186 .55134 m .41668 .55298 L .4172 .55298 L F
.919 .594 .126 r
.41673 .55305 m .41669 .55306 L .41668 .55298 L F
.644 .896 .567 r
.4186 .55134 m .41594 .55446 L .41757 .55292 L F
.856 .892 .862 r
.41669 .55306 m .41594 .55446 L .41435 .5534 L F
.717 .41 .459 r
.4186 .55134 m .41739 .55396 L .41535 .55358 L F
.41522 .55298 m .41535 .55358 L .41435 .5534 L F
.4186 .55134 m .41634 .55243 L .41668 .55298 L F
.4186 .55134 m .41535 .55358 L .41522 .55298 L F
.86 .506 .379 r
.41468 .55052 m .41499 .55194 L .41378 .5512 L F
.41617 .54939 m .41499 .55194 L .41468 .55052 L F
0 0 .395 r
.38971 .55904 m .38987 .5585 L .38731 .56012 L F
.38971 .55904 m .39061 .5607 L .38987 .5585 L F
.015 0 .433 r
.38971 .55904 m .38976 .56211 L .39061 .5607 L F
.515 .386 .643 r
.30538 .54989 m .3082 .55229 L .30795 .54935 L F
.30538 .54989 m .30571 .55319 L .3082 .55229 L F
0 0 0 r
.32058 .62796 m .31945 .62849 L .32123 .627 L F
0 0 .197 r
.31927 .63027 m .31966 .62839 L .32058 .62796 L F
.3188 .6311 m .31966 .62839 L .31927 .63027 L F
.3188 .6311 m .32058 .62796 L .31967 .62875 L F
0 0 .069 r
.31866 .63323 m .31967 .62875 L .31897 .63203 L F
.31861 .63342 m .31872 .63294 L .31866 .63323 L F
.31872 .63294 m .31967 .62875 L .31866 .63323 L F
0 0 .197 r
.3188 .6311 m .31945 .62849 L .31966 .62839 L F
.63 .84 .981 r
.57568 .40794 m .57943 .4082 L .57807 .40684 L F
.57807 .40684 m .57943 .4082 L .57568 .40794 L F
.516 .763 .986 r
.57943 .4082 m .58065 .40617 L .57807 .40684 L F
.57943 .4082 m .58241 .40776 L .58065 .40617 L F
.57943 .4082 m .58065 .40617 L .57807 .40684 L F
.57943 .4082 m .58241 .40776 L .58065 .40617 L F
.465 0 .002 r
.3628 .71044 m .36684 .70992 L .3653 .71183 L F
.55 .063 .053 r
.36684 .70992 m .36759 .71201 L .3653 .71183 L F
.36684 .70992 m .36941 .71042 L .36759 .71201 L F
.48 .031 .106 r
.25674 .62137 m .26089 .61981 L .25829 .62003 L F
.814 .996 .857 r
.25924 .61778 m .25829 .62003 L .25811 .61957 L F
0 0 .27 r
.73133 .34353 m .73012 .34769 L .73032 .34518 L F
.541 .179 .303 r
.29741 .65321 m .3018 .65086 L .30053 .65361 L F
0 0 .472 r
.3018 .65086 m .30178 .64945 L .30204 .65203 L F
0 0 0 r
.30053 .65361 m .3018 .65086 L .30204 .65203 L F
.669 .118 0 r
.30204 .65203 m .3018 .65086 L .30377 .65281 L F
.187 0 .15 r
.33297 .63695 m .33314 .63549 L .33088 .63774 L F
.763 .353 .275 r
.33679 .63771 m .33314 .63549 L .33671 .63701 L F
0 .313 .663 r
.33408 .63585 m .33314 .63549 L .33297 .63695 L F
.33408 .63585 m .33671 .63701 L .33314 .63549 L F
.162 .587 .935 r
.38571 .52273 m .38527 .52371 L .38276 .52136 L F
.38571 .52273 m .38721 .52399 L .38527 .52371 L F
.682 .754 .906 r
.61692 .40407 m .61551 .40809 L .61408 .40436 L F
.61692 .40407 m .61792 .40701 L .61551 .40809 L F
.751 .438 .454 r
.71493 .32276 m .71131 .32578 L .71219 .32306 L F
.217 .739 .836 r
.33041 .51856 m .33267 .51826 L .33455 .51828 L F
.806 .696 .744 r
.33041 .51856 m .33455 .51828 L .33267 .51826 L F
.33041 .51856 m .33207 .52243 L .33455 .51828 L F
.909 .911 .809 r
.33455 .51828 m .33542 .51395 L .33722 .51505 L F
.33455 .51828 m .33267 .51826 L .33542 .51395 L F
.501 0 0 r
.33455 .51828 m .33527 .51909 L .33267 .51826 L F
.725 .957 .947 r
.33588 .51725 m .33418 .51835 L .33527 .51909 L F
.33418 .51835 m .33381 .51859 L .33527 .51909 L F
.501 0 0 r
.33455 .51828 m .33644 .51987 L .33527 .51909 L F
.33644 .51987 m .33714 .52045 L .33527 .51909 L F
.625 .275 .358 r
.34556 .56865 m .34826 .57012 L .34857 .56949 L F
.489 .306 .558 r
.34968 .58754 m .34964 .59019 L .35216 .58961 L F
.678 .203 .116 r
.34968 .58754 m .35216 .58961 L .34964 .59019 L F
.32 .77 .958 r
.27217 .52517 m .26944 .52566 L .26782 .52471 L F
.477 .425 .721 r
.37119 .58103 m .3743 .58319 L .37316 .58026 L F
.882 .992 .757 r
.62385 .43632 m .62474 .43658 L .62244 .43954 L F
.448 0 0 r
.62883 .43947 m .62474 .43658 L .62574 .43851 L F
0 0 .561 r
.62652 .43725 m .62574 .43851 L .62474 .43658 L F
.62652 .43725 m .62474 .43658 L .6245 .43651 L F
.62445 .43653 m .6245 .43651 L .62385 .43632 L F
.62652 .43725 m .6245 .43651 L .62445 .43653 L F
.374 .269 .605 r
.62652 .43725 m .62385 .43632 L .62618 .43411 L F
.542 .532 .794 r
.62618 .43411 m .62385 .43632 L .62224 .43146 L F
.62618 .43411 m .62224 .43146 L .62433 .43133 L F
.033 .276 .772 r
.62391 .43168 m .62485 .43607 L .62624 .43438 L F
.55 .827 .478 r
.62624 .43438 m .62485 .43607 L .62437 .43657 L F
.882 .992 .757 r
.62385 .43632 m .62244 .43954 L .62132 .43773 L F
.657 .74 .911 r
.62385 .43632 m .62132 .43773 L .62163 .43732 L F
.615 .576 .787 r
.62224 .43146 m .62163 .43732 L .62032 .43178 L F
.62224 .43146 m .62385 .43632 L .62163 .43732 L F
.537 0 0 r
.62394 .43701 m .62485 .43607 L .62118 .43518 L F
.55 .827 .478 r
.62431 .4366 m .62437 .43657 L .62394 .43701 L F
.62624 .43438 m .62437 .43657 L .62431 .4366 L F
.969 .777 .589 r
.71672 .30251 m .71761 .30614 L .71356 .30579 L F
.71672 .30251 m .71729 .30401 L .71761 .30614 L F
.857 .734 .727 r
.71761 .30614 m .71473 .30941 L .71356 .30579 L F
.705 .647 .789 r
.616 .42323 m .61593 .42705 L .61362 .42578 L F
.817 .512 .473 r
.61593 .42705 m .61593 .4292 L .61362 .42578 L F
.721 .665 .794 r
.61868 .42337 m .61593 .42705 L .616 .42323 L F
.693 .414 .496 r
.61593 .42705 m .61963 .42948 L .61593 .4292 L F
.714 .915 .563 r
.29182 .54772 m .29278 .54587 L .29397 .54719 L F
.29182 .54772 m .29077 .54884 L .29278 .54587 L F
.389 .144 .418 r
.34059 .54352 m .34242 .54568 L .33973 .54618 L F
.754 .393 .371 r
.71633 .32932 m .71678 .3312 L .7213 .33125 L F
.476 .288 .546 r
.71807 .33689 m .7213 .33125 L .71678 .3312 L F
.71807 .33689 m .71997 .33662 L .7213 .33125 L F
.524 .353 .591 r
.71997 .33662 m .72292 .33166 L .7213 .33125 L F
.703 .794 .921 r
.29994 .6332 m .30346 .6335 L .30223 .63099 L F
.454 .606 .912 r
.30346 .6335 m .30506 .63289 L .30223 .63099 L F
.30346 .6335 m .30656 .63388 L .30506 .63289 L F
.114 0 .117 r
.35387 .52084 m .35102 .52348 L .35195 .52188 L F
.796 .748 .808 r
.37695 .53403 m .37297 .53367 L .37589 .53402 L F
.347 .644 .965 r
.37695 .53403 m .37873 .53398 L .37823 .53265 L F
.37695 .53403 m .37873 .53398 L .37823 .53265 L F
.752 .371 .331 r
.34966 .55523 m .34623 .55731 L .34768 .55491 L F
0 0 0 r
.34768 .55491 m .34623 .55731 L .34687 .55646 L F
.957 .682 .473 r
.34966 .55523 m .34768 .55491 L .34846 .55341 L F
0 0 0 r
.34768 .55491 m .34687 .55646 L .34853 .55424 L F
.957 .682 .473 r
.34846 .55341 m .34768 .55491 L .34772 .55228 L F
.752 .371 .331 r
.34966 .55523 m .35198 .55834 L .34623 .55731 L F
.756 .716 .815 r
.34786 .51212 m .34878 .51738 L .3523 .51274 L F
.707 .197 .017 r
.34427 .65325 m .34013 .65073 L .33964 .65258 L F
.575 0 0 r
.28046 .63165 m .27681 .63001 L .27942 .62973 L F
.243 .415 .834 r
.28084 .62835 m .28046 .63165 L .27942 .62973 L F
.28084 .62835 m .28188 .63131 L .28046 .63165 L F
.501 .286 .519 r
.28188 .63131 m .27965 .63363 L .28046 .63165 L F
.9 .976 .806 r
.39072 .59933 m .38853 .60282 L .38947 .6012 L F
.598 .45 .651 r
.39407 .60443 m .38965 .60523 L .38853 .60282 L F
.334 .661 .973 r
.35371 .50554 m .35475 .50703 L .35326 .50561 L F
.35371 .50554 m .35825 .50763 L .35475 .50703 L F
.034 .547 .871 r
.20049 .59844 m .20202 .59835 L .19778 .59771 L F
.20049 .59844 m .20417 .59944 L .20202 .59835 L F
.547 .342 .554 r
.35181 .55289 m .35437 .55247 L .35473 .54951 L F
.203 .049 .438 r
.35507 .54959 m .35473 .54951 L .35719 .55117 L F
.35507 .54959 m .35323 .54878 L .35473 .54951 L F
.514 .314 .546 r
.35473 .54951 m .35437 .55247 L .35719 .55117 L F
.762 .668 .759 r
.36711 .54939 m .36483 .55275 L .36776 .55279 L F
.514 .298 .524 r
.36776 .55279 m .36549 .55665 L .36778 .55516 L F
.179 .252 .702 r
.36776 .55279 m .36934 .55126 L .36711 .54939 L F
0 0 .279 r
.36776 .55279 m .36897 .55297 L .36934 .55126 L F
.36776 .55279 m .36778 .55516 L .36897 .55297 L F
.845 .716 .72 r
.32595 .52615 m .32943 .52779 L .32994 .52764 L F
0 0 .013 r
.32719 .53085 m .32825 .53145 L .32943 .52779 L F
.369 .477 .839 r
.20795 .60257 m .2095 .60606 L .21119 .60594 L F
.192 .445 .872 r
.2095 .60606 m .21326 .60936 L .21119 .60594 L F
0 .074 .574 r
.38721 .52399 m .38923 .5259 L .38941 .52684 L F
0 0 .108 r
.38317 .5934 m .38224 .59458 L .38132 .59687 L F
.569 .375 .579 r
.38965 .60523 m .3903 .61027 L .3883 .60877 L F
.598 .45 .651 r
.39407 .60443 m .39242 .60569 L .38965 .60523 L F
0 0 .324 r
.39067 .60755 m .38965 .60523 L .39242 .60569 L F
.39067 .60755 m .3903 .61027 L .38965 .60523 L F
.473 .809 .999 r
.34851 .51663 m .35003 .51732 L .34701 .51803 L F
0 0 0 r
.34701 .51803 m .34785 .51885 L .34851 .51663 L F
.34701 .51803 m .34637 .52032 L .34785 .51885 L F
.487 .446 .737 r
.34946 .63152 m .35008 .63482 L .35216 .63391 L F
.314 .206 .568 r
.35008 .63482 m .35222 .63739 L .35216 .63391 L F
.35008 .63482 m .35024 .63756 L .35222 .63739 L F
0 0 0 r
.23041 .53719 m .22786 .54035 L .22946 .53897 L F
.012 0 0 r
.22786 .54035 m .2281 .54123 L .22946 .53897 L F
0 0 .335 r
.37727 .56534 m .37866 .56418 L .37877 .56138 L F
.486 .877 .695 r
.37727 .56534 m .37671 .56553 L .37866 .56418 L F
.041 0 .194 r
.38065 .56518 m .37834 .56808 L .37727 .56534 L F
.431 .711 .982 r
.39163 .65317 m .39064 .65559 L .38851 .65439 L F
.39163 .65317 m .38851 .65439 L .38849 .65436 L F
.01 0 0 r
.38995 .65435 m .39163 .65317 L .39029 .65369 L F
.38995 .65435 m .39029 .65369 L .38848 .65437 L F
.02 .457 .873 r
.38836 .65272 m .38995 .65435 L .38771 .6533 L F
.431 .711 .982 r
.39163 .65317 m .39353 .65548 L .39064 .65559 L F
.523 .526 .8 r
.39004 .65965 m .3917 .65581 L .38848 .65437 L F
.01 0 0 r
.38995 .65435 m .38848 .65437 L .38718 .65305 L F
.431 .711 .982 r
.38849 .65436 m .38851 .65439 L .38848 .65437 L F
.025 .433 .867 r
.38848 .65437 m .38976 .65494 L .38995 .65435 L F
.38976 .65494 m .3917 .65581 L .38995 .65435 L F
.411 .719 .987 r
.39063 .65253 m .38995 .65435 L .38983 .65423 L F
.39063 .65253 m .38983 .65423 L .38836 .65272 L F
.724 .74 .864 r
.39259 .65108 m .39063 .65253 L .38907 .64974 L F
.218 .473 .886 r
.39063 .65253 m .39144 .65081 L .3914 .65087 L F
.467 .643 .934 r
.39063 .65253 m .38836 .65272 L .38673 .65039 L F
.39063 .65253 m .38673 .65039 L .38907 .64974 L F
.218 .473 .886 r
.39063 .65253 m .3914 .65087 L .38884 .65435 L F
.863 .815 .333 r
.3903 .6533 m .38995 .65435 L .39063 .65253 L F
.025 .433 .867 r
.38848 .65437 m .38995 .65435 L .38908 .65715 L F
.863 .815 .333 r
.38924 .65578 m .38995 .65435 L .3903 .6533 L F
.38903 .65629 m .38995 .65435 L .38924 .65578 L F
.02 .457 .873 r
.38747 .65297 m .38771 .6533 L .38718 .65305 L F
.38836 .65272 m .38771 .6533 L .38747 .65297 L F
.624 .873 .526 r
.31912 .62117 m .31815 .6226 L .3182 .62237 L F
.394 .365 .708 r
.23259 .56754 m .22975 .56416 L .23243 .564 L F
.23259 .56754 m .23064 .56852 L .22975 .56416 L F
.795 .759 .82 r
.7073 .31733 m .70471 .32017 L .70334 .31825 L F
.277 0 .243 r
.23064 .56852 m .22983 .57103 L .22758 .57169 L F
.428 .099 .305 r
.23243 .57021 m .23064 .56852 L .23259 .56754 L F
.23243 .57021 m .22983 .57103 L .23064 .56852 L F
.573 .174 .248 r
.32978 .5408 m .32818 .54275 L .32556 .54256 L F
0 0 .295 r
.33083 .53719 m .32978 .5408 L .33242 .53958 L F
.481 .669 .946 r
.33242 .53958 m .33244 .53771 L .33083 .53719 L F
.33244 .53771 m .33245 .53709 L .33174 .53713 L F
.33244 .53771 m .33174 .53713 L .33083 .53719 L F
.33242 .53958 m .33456 .53919 L .33245 .53709 L F
.267 0 .065 r
.33428 .53922 m .3307 .54223 L .33087 .53962 L F
.33456 .53919 m .3344 .53932 L .33428 .53922 L F
.3344 .53932 m .3307 .54223 L .33428 .53922 L F
0 0 .295 r
.33049 .53837 m .33087 .53962 L .32978 .5408 L F
.33083 .53719 m .33084 .53797 L .33049 .53837 L F
.33084 .53797 m .33087 .53962 L .33049 .53837 L F
.748 .49 .542 r
.32649 .53865 m .33087 .53962 L .33083 .53719 L F
.879 .828 .793 r
.33165 .53707 m .32895 .53825 L .33118 .53706 L F
.33245 .53709 m .33129 .53748 L .33165 .53707 L F
.33129 .53748 m .32895 .53825 L .33165 .53707 L F
.503 .381 .646 r
.33087 .53962 m .32818 .54275 L .32978 .5408 L F
.712 .618 .052 r
.38193 .51699 m .38168 .52107 L .37968 .51742 L F
.987 .742 .475 r
.38027 .51836 m .38175 .51969 L .38179 .51908 L F
.38027 .51836 m .38179 .51908 L .38193 .51699 L F
.373 0 0 r
.37845 .51754 m .38027 .51836 L .37752 .51697 L F
.357 0 0 r
.37845 .51754 m .37886 .51769 L .38027 .51836 L F
.712 .618 .052 r
.38193 .51699 m .38175 .51969 L .3817 .52061 L F
.636 .081 0 r
.37531 .51559 m .37798 .51737 L .37968 .51742 L F
.496 .899 .928 r
.37798 .51737 m .37752 .51697 L .37968 .51742 L F
.732 .273 .161 r
.37807 .51708 m .38193 .51699 L .37968 .51742 L F
.37752 .51697 m .37819 .51697 L .37807 .51708 L F
.37819 .51697 m .38193 .51699 L .37807 .51708 L F
.37819 .51697 m .38027 .51836 L .38193 .51699 L F
.37752 .51697 m .37978 .51811 L .37819 .51697 L F
.37978 .51811 m .38027 .51836 L .37819 .51697 L F
0 .331 .81 r
.37603 .51541 m .37789 .51724 L .37531 .51559 L F
.37651 .51529 m .37719 .51625 L .37603 .51541 L F
.37719 .51625 m .37789 .51724 L .37603 .51541 L F
.37789 .51724 m .37798 .51737 L .37785 .51728 L F
.37789 .51724 m .37785 .51728 L .37531 .51559 L F
.357 0 0 r
.37886 .51769 m .38247 .51897 L .38027 .51836 L F
.071 .513 .898 r
.3818 .51878 m .38175 .51969 L .38027 .51836 L F
.38247 .51897 m .38175 .51969 L .3818 .51878 L F
.712 .618 .052 r
.3817 .52061 m .38175 .51969 L .38168 .52107 L F
.001 .363 .833 r
.38175 .51969 m .38276 .52136 L .38168 .52107 L F
.328 .191 .538 r
.19047 .57798 m .19226 .57721 L .19222 .57454 L F
.242 .154 .551 r
.19047 .57798 m .19213 .57991 L .19226 .57721 L F
.19047 .57798 m .19018 .58135 L .19213 .57991 L F
.587 .928 .957 r
.26087 .5272 m .25719 .52804 L .25971 .52741 L F
.436 .868 .77 r
.26322 .52597 m .26087 .5272 L .26188 .52639 L F
.429 .869 .805 r
.26188 .52639 m .26087 .5272 L .25971 .52741 L F
0 0 .246 r
.23251 .62248 m .23308 .62113 L .23277 .62141 L F
.368 .687 .98 r
.23251 .62248 m .23463 .62237 L .23308 .62113 L F
.928 .708 .586 r
.24189 .61135 m .24226 .61574 L .24427 .61589 L F
.722 .215 .023 r
.24226 .61574 m .24247 .61652 L .24427 .61589 L F
.808 .345 .129 r
.24247 .61652 m .24594 .61863 L .24427 .61589 L F
.843 .836 .839 r
.32901 .50908 m .3271 .51195 L .32506 .51084 L F
.431 .747 .993 r
.3271 .51195 m .3274 .51042 L .32506 .51084 L F
.575 .455 .678 r
.32901 .50908 m .32965 .5119 L .3271 .51195 L F
.431 .747 .993 r
.3271 .51195 m .32965 .5119 L .3274 .51042 L F
.207 .007 .374 r
.62261 .42894 m .62253 .42626 L .62456 .42527 L F
0 .152 .695 r
.33776 .51397 m .33722 .51505 L .33542 .51395 L F
.33776 .51397 m .33951 .51738 L .33722 .51505 L F
.946 .947 .631 r
.32626 .68409 m .32814 .6822 L .32653 .68549 L F
.926 .956 .632 r
.328 .68028 m .32814 .6822 L .32626 .68409 L F
.413 .088 .303 r
.38086 .70377 m .37783 .70623 L .37835 .70401 L F
.517 .241 .436 r
.38196 .70174 m .38086 .70377 L .37835 .70401 L F
.535 .334 .555 r
.38363 .70035 m .38086 .70377 L .38196 .70174 L F
.626 .413 .573 r
.22254 .56057 m .22269 .56252 L .22337 .56003 L F
.2193 .56266 m .22234 .56254 L .22254 .56057 L F
.22234 .56254 m .22269 .56252 L .22254 .56057 L F
.954 .776 .623 r
.21959 .56239 m .22269 .56252 L .2193 .56266 L F
.21968 .5623 m .22007 .56233 L .21959 .56239 L F
.22007 .56233 m .22269 .56252 L .21959 .56239 L F
.31 .475 .862 r
.2198 .55844 m .22206 .56209 L .21888 .56079 L F
.22206 .56209 m .22269 .5631 L .22119 .56219 L F
.22206 .56209 m .22119 .56219 L .21888 .56079 L F
.968 .741 .54 r
.21968 .5623 m .22001 .56504 L .22207 .56513 L F
.22213 .56457 m .22207 .56513 L .22277 .56516 L F
.21968 .5623 m .22207 .56513 L .22213 .56457 L F
.954 .776 .623 r
.21974 .56231 m .22213 .56457 L .22269 .56252 L F
.22213 .56457 m .22277 .56516 L .22269 .56252 L F
.338 .672 .976 r
.22269 .5631 m .22061 .56302 L .21964 .56177 L F
.21953 .56118 m .21964 .56177 L .21888 .56079 L F
.22269 .5631 m .21964 .56177 L .21953 .56118 L F
.954 .776 .623 r
.21968 .5623 m .21975 .56237 L .21974 .56231 L F
.21975 .56237 m .22213 .56457 L .21974 .56231 L F
.626 .413 .573 r
.22337 .56003 m .22269 .56252 L .22404 .5596 L F
.551 .33 .532 r
.22404 .5596 m .22413 .56204 L .22536 .55908 L F
.22404 .5596 m .22269 .56252 L .22413 .56204 L F
.904 .779 .712 r
.60839 .41333 m .60834 .41774 L .60666 .41641 L F
.998 .845 .558 r
.60834 .41774 m .60681 .41886 L .60666 .41641 L F
.60834 .41774 m .6078 .42074 L .60681 .41886 L F
.648 .581 .766 r
.35699 .56117 m .3607 .56498 L .35821 .56095 L F
.657 .446 .586 r
.35821 .56095 m .36338 .5591 L .35927 .55878 L F
.35821 .56095 m .36299 .56201 L .36338 .5591 L F
.627 .461 .639 r
.3607 .56498 m .36299 .56201 L .35821 .56095 L F
.57 .565 .809 r
.3514 .62587 m .35231 .62134 L .34961 .62423 L F
.3514 .62587 m .35367 .62523 L .35231 .62134 L F
0 0 .018 r
.32713 .58795 m .32606 .58995 L .32881 .58679 L F
.638 .544 .732 r
.36338 .5591 m .36616 .55904 L .36549 .55665 L F
.756 .988 .767 r
.36299 .56201 m .36616 .55904 L .36338 .5591 L F
.566 .589 .836 r
.23103 .60473 m .22883 .60556 L .22734 .60209 L F
.503 0 0 r
.29782 .64682 m .29558 .64493 L .2942 .64404 L F
.539 0 0 r
.29739 .64595 m .29558 .64493 L .29782 .64682 L F
.503 0 0 r
.29782 .64682 m .2942 .64404 L .29687 .64525 L F
.655 .102 0 r
.29882 .64886 m .29782 .64682 L .29707 .64557 L F
.29882 .64886 m .29707 .64557 L .29715 .64577 L F
.539 0 0 r
.30005 .64743 m .29739 .64595 L .29782 .64682 L F
.801 .308 0 r
.299 .64919 m .29687 .64525 L .2949 .64426 L F
.721 .19 0 r
.30178 .64945 m .30005 .64743 L .29782 .64682 L F
.30178 .64945 m .29782 .64682 L .30084 .64973 L F
.655 .102 0 r
.299 .64919 m .30084 .64973 L .29782 .64682 L F
.72 .317 .283 r
.29719 .64648 m .30127 .64692 L .29929 .64899 L F
.358 0 0 r
.29941 .64685 m .30127 .64692 L .29898 .64667 L F
.819 .455 .368 r
.29929 .64899 m .30127 .64692 L .29941 .64685 L F
.059 .276 .767 r
.30192 .64788 m .29941 .64685 L .30024 .64451 L F
.30212 .64829 m .29941 .64685 L .30192 .64788 L F
.358 0 0 r
.29941 .64685 m .29898 .64667 L .29748 .64651 L F
.29748 .64653 m .29748 .64651 L .29719 .64648 L F
.29941 .64685 m .29748 .64651 L .29748 .64653 L F
.655 .102 0 r
.29715 .64577 m .29707 .64557 L .29687 .64525 L F
.299 .64919 m .29782 .64682 L .29882 .64886 L F
.528 .365 .604 r
.36768 .5705 m .36625 .57469 L .36569 .5721 L F
.36768 .5705 m .36873 .57402 L .36625 .57469 L F
.577 .679 .91 r
.22536 .55908 m .22533 .55598 L .22395 .55554 L F
.22536 .55908 m .22781 .55868 L .22533 .55598 L F
0 0 .159 r
.22536 .55908 m .22615 .56036 L .22781 .55868 L F
.22536 .55908 m .22413 .56204 L .22615 .56036 L F
.531 .255 .441 r
.2254 .5746 m .22468 .5775 L .22194 .57716 L F
.3 .047 .354 r
.22691 .5766 m .2254 .5746 L .22758 .57394 L F
.22691 .5766 m .22468 .5775 L .2254 .5746 L F
.287 0 .229 r
.42012 .56199 m .41876 .56458 L .41942 .56271 L F
.823 .551 .528 r
.42263 .565 m .41876 .56458 L .42012 .56199 L F
.048 0 0 r
.22946 .53897 m .23264 .53656 L .23041 .53719 L F
.562 .568 .817 r
.31229 .53832 m .31333 .54106 L .31556 .53998 L F
.224 .409 .835 r
.32922 .66445 m .32949 .66697 L .32782 .66585 L F
.451 .497 .815 r
.32782 .66585 m .3312 .66979 L .32949 .66697 L F
0 0 .456 r
.32949 .66697 m .3312 .66979 L .32998 .6676 L F
.32949 .66697 m .3312 .66979 L .32998 .6676 L F
.614 .046 0 r
.32782 .66585 m .32998 .6676 L .32566 .66766 L F
.32782 .66585 m .32949 .66697 L .32998 .6676 L F
.669 .97 .796 r
.33511 .67474 m .3333 .67632 L .33092 .67734 L F
0 0 .56 r
.32259 .56666 m .32185 .56853 L .32104 .5645 L F
.968 .828 .408 r
.32066 .5675 m .32185 .56853 L .32259 .56666 L F
.463 .373 .668 r
.27877 .64161 m .28163 .6433 L .2811 .6406 L F
.451 .512 .83 r
.34164 .55608 m .34025 .55914 L .33876 .55567 L F
.531 .315 .532 r
.34254 .56116 m .33999 .5617 L .34025 .55914 L F
.659 .566 .739 r
.35213 .54576 m .35023 .54646 L .34992 .54457 L F
.35135 .5448 m .34992 .54457 L .34961 .54268 L F
.35213 .54576 m .34992 .54457 L .35135 .5448 L F
.35213 .54576 m .34961 .54268 L .35278 .54478 L F
.545 .485 .74 r
.34961 .54268 m .34992 .54457 L .35223 .54535 L F
.34992 .54457 m .35023 .54646 L .35223 .54535 L F
.603 .148 .145 r
.34613 .54396 m .35223 .54535 L .34487 .54497 L F
.34652 .54364 m .34927 .54446 L .34613 .54396 L F
.34927 .54446 m .35223 .54535 L .34613 .54396 L F
.545 .485 .74 r
.34961 .54268 m .35223 .54535 L .34652 .54364 L F
0 0 .366 r
.35323 .54878 m .35181 .55289 L .35046 .54911 L F
.35323 .54878 m .35334 .5518 L .35181 .55289 L F
.514 .246 .447 r
.35181 .55289 m .35402 .5548 L .35437 .55247 L F
.152 .245 .707 r
.35334 .5518 m .35402 .5548 L .35181 .55289 L F
.559 .458 .695 r
.33259 .65989 m .33521 .65951 L .33444 .65685 L F
.556 .22 .355 r
.28207 .54579 m .28048 .5487 L .27792 .54854 L F
.275 0 .194 r
.28268 .54791 m .28207 .54579 L .28364 .54594 L F
.28268 .54791 m .28048 .5487 L .28207 .54579 L F
.727 .211 0 r
.32653 .68549 m .32943 .68813 L .32727 .68771 L F
.977 .674 .342 r
.32943 .68813 m .32844 .69001 L .32727 .68771 L F
.32943 .68813 m .32961 .69099 L .32844 .69001 L F
.606 .187 .221 r
.23925 .55085 m .24157 .5516 L .23957 .54976 L F
.559 .203 .322 r
.23957 .54976 m .24157 .5516 L .24207 .54982 L F
.665 .137 0 r
.31427 .54851 m .31593 .54959 L .31791 .54953 L F
.238 .131 .524 r
.31593 .54959 m .31661 .55014 L .31791 .54953 L F
.606 .25 .34 r
.31014 .63493 m .31397 .63414 L .3124 .63691 L F
.525 .229 .407 r
.31397 .63414 m .31614 .63621 L .3124 .63691 L F
.31397 .63414 m .31643 .63407 L .31614 .63621 L F
.212 0 .045 r
.27111 .54578 m .27349 .54519 L .2743 .54364 L F
.362 0 .116 r
.2743 .54364 m .27573 .54472 L .27697 .54338 L F
.2743 .54364 m .27349 .54519 L .27573 .54472 L F
.479 .242 .477 r
.64583 .42643 m .64564 .42922 L .64298 .42982 L F
.496 .522 .814 r
.6465 .42202 m .64583 .42643 L .64394 .42459 L F
.6465 .42202 m .6482 .4259 L .64583 .42643 L F
.403 .181 .459 r
.6482 .4259 m .64564 .42922 L .64583 .42643 L F
.571 .416 .632 r
.36625 .57469 m .36629 .57779 L .36381 .57809 L F
.443 .162 .39 r
.36629 .57779 m .36355 .5805 L .36381 .57809 L F
.798 .594 .625 r
.34361 .56951 m .33773 .56755 L .34003 .56698 L F
.34361 .56951 m .33809 .57126 L .33773 .56755 L F
.296 0 .246 r
.33962 .57238 m .33809 .57126 L .34361 .56951 L F
.898 .686 .175 r
.34271 .56654 m .34361 .56951 L .34003 .56698 L F
.34271 .56654 m .34292 .56988 L .34361 .56951 L F
.516 .214 .393 r
.34292 .56988 m .33962 .57238 L .34361 .56951 L F
.575 .601 .842 r
.33955 .6214 m .34181 .62583 L .34362 .62431 L F
.814 .721 .763 r
.34101 .62769 m .34362 .62431 L .34181 .62583 L F
.574 .282 .435 r
.29909 .58368 m .30175 .58366 L .30224 .58135 L F
.359 .092 .366 r
.30224 .58135 m .30395 .58292 L .30482 .58058 L F
.30224 .58135 m .30175 .58366 L .30395 .58292 L F
.573 .758 .965 r
.72036 .31867 m .72411 .31956 L .72317 .31773 L F
.72317 .31773 m .72411 .31956 L .72036 .31867 L F
.458 .687 .965 r
.72317 .31773 m .72411 .31956 L .72551 .31754 L F
.72551 .31754 m .72411 .31956 L .72317 .31773 L F
.72317 .31773 m .72411 .31956 L .72551 .31754 L F
.702 .318 .316 r
.31427 .54851 m .31247 .55102 L .31393 .55104 L F
.238 .131 .524 r
.31597 .54962 m .31497 .55148 L .31661 .55014 L F
.31587 .54969 m .31497 .55148 L .31597 .54962 L F
.31593 .54959 m .31587 .54969 L .31597 .54962 L F
.31593 .54959 m .31658 .55107 L .31497 .55148 L F
.702 .318 .316 r
.31554 .54992 m .31393 .55104 L .31658 .55107 L F
.31427 .54851 m .31393 .55104 L .31554 .54992 L F
.619 .062 0 r
.62574 .43851 m .62813 .44017 L .62883 .43947 L F
.546 .839 .998 r
.6301 .43777 m .63165 .43905 L .62883 .43947 L F
.594 .852 .5 r
.62883 .43947 m .62813 .44017 L .6301 .43777 L F
.667 .495 .642 r
.63165 .43905 m .62895 .44224 L .62883 .43947 L F
.764 .82 .897 r
.31786 .51633 m .31527 .51587 L .31639 .51481 L F
.447 .537 .856 r
.3183 .51403 m .31786 .51633 L .31639 .51481 L F
.3183 .51403 m .32117 .51696 L .31786 .51633 L F
.441 .216 .475 r
.24553 .54652 m .24747 .54809 L .24828 .54612 L F
.24553 .54652 m .24522 .54903 L .24747 .54809 L F
.375 .276 .613 r
.36355 .58319 m .36132 .58115 L .36355 .5805 L F
.36355 .58319 m .36166 .58433 L .36132 .58115 L F
.36355 .58319 m .36132 .58115 L .36355 .5805 L F
.36355 .58319 m .36166 .58433 L .36132 .58115 L F
.538 .699 .943 r
.34472 .59892 m .34214 .59918 L .34451 .59656 L F
0 0 0 r
.34451 .59656 m .34214 .59918 L .34349 .59844 L F
.34349 .59844 m .34214 .59918 L .34105 .60151 L F
.516 .486 .762 r
.38629 .61145 m .38447 .6135 L .38372 .61137 L F
.38629 .61145 m .38773 .61506 L .38447 .6135 L F
.641 .397 .535 r
.35222 .58427 m .35422 .58569 L .35466 .58431 L F
.74 .925 .574 r
.3216 .57059 m .31915 .57385 L .32047 .57225 L F
.054 0 0 r
.63385 .40915 m .63485 .40784 L .63676 .4071 L F
.624 .766 .947 r
.26527 .53307 m .26895 .53391 L .26725 .5327 L F
.552 .596 .851 r
.26865 .53631 m .26725 .5327 L .26895 .53391 L F
.825 .754 .785 r
.37667 .577 m .37898 .57788 L .37855 .57362 L F
.724 .407 0 r
.37902 .57821 m .37898 .57788 L .37667 .577 L F
.37902 .57821 m .37985 .58056 L .37898 .57788 L F
.682 .229 .17 r
.39074 .58107 m .38902 .58261 L .38716 .58087 L F
.59 .948 .874 r
.39181 .57975 m .39074 .58107 L .39234 .58011 L F
.577 .873 .567 r
.39181 .57975 m .38902 .58261 L .39074 .58107 L F
.783 .653 .718 r
.21912 .57776 m .22025 .58173 L .21868 .58037 L F
.591 .538 .764 r
.22266 .58081 m .22025 .58173 L .21912 .57776 L F
.588 .528 .755 r
.22266 .58081 m .22346 .58304 L .22025 .58173 L F
.927 .886 .773 r
.6228 .41669 m .62406 .4146 L .62243 .41326 L F
.387 .185 .48 r
.30503 .57799 m .30715 .57734 L .30772 .57457 L F
.346 .14 .45 r
.30482 .58058 m .30715 .57734 L .30503 .57799 L F
.524 .549 .823 r
.39109 .63131 m .38874 .63176 L .38737 .62823 L F
.192 .056 .455 r
.39109 .63131 m .38946 .63416 L .38874 .63176 L F
.315 0 0 r
.25697 .63347 m .25294 .63407 L .2548 .63456 L F
0 0 0 r
.28251 .61246 m .28425 .61157 L .28531 .60932 L F
.28531 .60932 m .28698 .60821 L .28764 .60611 L F
.409 .194 .473 r
.28425 .61157 m .28698 .60821 L .28531 .60932 L F
.744 .584 .677 r
.30712 .6503 m .31053 .6506 L .31057 .64856 L F
.691 .833 .951 r
.31127 .64607 m .3121 .6478 L .31057 .64856 L F
.576 .445 .665 r
.31057 .64856 m .3132 .64726 L .31127 .64607 L F
.31057 .64856 m .31053 .6506 L .3132 .64726 L F
.707 .352 0 r
.31047 .64441 m .31127 .64607 L .3121 .64817 L F
.31042 .64429 m .31127 .64607 L .31047 .64441 L F
.691 .833 .951 r
.31127 .64607 m .3132 .64726 L .3121 .6478 L F
.871 .608 .537 r
.33721 .69443 m .33488 .69647 L .33511 .69367 L F
.33721 .69443 m .3371 .69718 L .33488 .69647 L F
.92 .535 .14 r
.3241 .60632 m .32302 .60579 L .32264 .6036 L F
.81 .976 .899 r
.32455 .60401 m .32302 .60579 L .3241 .60632 L F
.752 .671 .771 r
.71412 .33472 m .71807 .33689 L .71678 .3312 L F
.372 .785 .98 r
.71807 .33689 m .72014 .33651 L .71997 .33662 L F
.833 .724 .743 r
.36741 .59446 m .3678 .59677 L .3695 .59346 L F
.02 0 0 r
.27111 .53882 m .27232 .53636 L .27108 .53587 L F
.511 .275 .493 r
.37387 .65356 m .37339 .65638 L .37103 .65643 L F
.683 .64 .801 r
.37728 .65868 m .37339 .65638 L .37608 .65698 L F
.182 0 0 r
.3751 .65685 m .37527 .65688 L .37339 .65638 L F
.37527 .65688 m .37608 .65698 L .37528 .6568 L F
.37527 .65688 m .37528 .6568 L .37339 .65638 L F
.605 .573 .791 r
.37539 .66035 m .37103 .65643 L .37339 .65638 L F
.683 .64 .801 r
.37728 .65868 m .37539 .66035 L .37339 .65638 L F
0 0 0 r
.37526 .65696 m .37431 .65805 L .37285 .65989 L F
.63 .805 .967 r
.37758 .65452 m .37608 .65698 L .3751 .65685 L F
0 0 0 r
.37571 .6564 m .37526 .65693 L .37526 .65696 L F
.37526 .65693 m .37431 .65805 L .37526 .65696 L F
0 0 .269 r
.3751 .65685 m .37387 .65356 L .37488 .6535 L F
.3751 .65685 m .37339 .65638 L .37387 .65356 L F
.555 .748 .967 r
.62196 .40792 m .61792 .40701 L .62111 .40493 L F
.766 .749 .838 r
.62454 .40502 m .62196 .40792 L .62111 .40493 L F
.833 .467 .361 r
.62196 .40792 m .62341 .40912 L .6245 .40953 L F
.62341 .40912 m .62593 .4112 L .6245 .40953 L F
.731 .81 .913 r
.6245 .40953 m .62593 .4112 L .62849 .40967 L F
.6245 .40953 m .62849 .40967 L .62717 .40876 L F
.271 0 .088 r
.62569 .40998 m .6245 .40953 L .62717 .40876 L F
.62358 .41173 m .6245 .40953 L .62569 .40998 L F
.547 .318 .519 r
.62196 .40792 m .6245 .40953 L .6219 .41045 L F
.358 .015 .24 r
.37551 .70688 m .37447 .70972 L .37209 .71024 L F
.364 .033 .263 r
.37783 .70623 m .37447 .70972 L .37551 .70688 L F
.887 .97 .834 r
.32875 .51669 m .3283 .51963 L .33041 .51856 L F
.668 .392 .495 r
.36665 .62455 m .36417 .62224 L .36398 .62393 L F
.36665 .62455 m .36688 .62205 L .36417 .62224 L F
.58 .004 0 r
.29156 .64973 m .29306 .65067 L .28953 .64929 L F
.224 0 .1 r
.27931 .61532 m .28131 .6149 L .28251 .61246 L F
.295 0 .135 r
.28251 .61246 m .28369 .61416 L .28425 .61157 L F
.28251 .61246 m .28131 .6149 L .28369 .61416 L F
.343 .815 .904 r
.28306 .62122 m .2801 .62133 L .27811 .62187 L F
.151 0 0 r
.28397 .62132 m .2801 .62133 L .28306 .62122 L F
.244 .75 .885 r
.38273 .65607 m .38421 .65637 L .38007 .65638 L F
.626 .873 .988 r
.38491 .65442 m .38421 .65637 L .38273 .65607 L F
.38491 .65442 m .38642 .65536 L .38421 .65637 L F
.117 0 .397 r
.29739 .58739 m .29872 .58679 L .29909 .58368 L F
.535 .452 .709 r
.29686 .5899 m .29872 .58679 L .29739 .58739 L F
.673 .618 .785 r
.36665 .62455 m .36932 .61742 L .36688 .62205 L F
.977 .722 .477 r
.41942 .56271 m .41876 .56458 L .417 .56096 L F
.533 .526 .794 r
.33773 .56755 m .33558 .5684 L .33448 .56603 L F
.33773 .56755 m .33448 .56603 L .33466 .56591 L F
.101 .334 .806 r
.33313 .56212 m .33537 .56538 L .33552 .56365 L F
.33552 .56365 m .33537 .56538 L .33313 .56212 L F
.226 0 .021 r
.33434 .56573 m .33537 .56538 L .33552 .56365 L F
0 0 0 r
.33537 .56538 m .33537 .56551 L .33552 .56365 L F
.226 0 .021 r
.33538 .56534 m .33552 .56365 L .33628 .56499 L F
.33466 .56591 m .3351 .56565 L .33773 .56755 L F
.3351 .56565 m .33628 .56499 L .33656 .5655 L F
.3351 .56565 m .33656 .5655 L .33773 .56755 L F
.533 .526 .794 r
.33466 .56591 m .33448 .56603 L .33434 .56573 L F
.226 0 .021 r
.33434 .56573 m .33352 .56725 L .3351 .56565 L F
.33434 .56573 m .3351 .56565 L .33537 .56538 L F
0 0 0 r
.33537 .56541 m .33516 .56562 L .33537 .56551 L F
.33537 .56538 m .33528 .56548 L .33537 .56541 L F
.226 0 .021 r
.33434 .56573 m .33628 .56499 L .33466 .56591 L F
0 0 0 r
.33537 .56551 m .33535 .56605 L .33552 .56365 L F
.226 0 .021 r
.33434 .56573 m .33552 .56365 L .33538 .56534 L F
0 0 0 r
.33537 .56551 m .33352 .56725 L .33535 .56605 L F
.33516 .56562 m .33352 .56725 L .33537 .56551 L F
.33528 .56548 m .33352 .56725 L .33537 .56541 L F
.537 .402 .644 r
.33773 .56755 m .33531 .5718 L .33558 .5684 L F
0 0 0 r
.63991 .43489 m .63792 .43627 L .64076 .43357 L F
.205 0 .059 r
.6432 .43255 m .63991 .43489 L .64076 .43357 L F
.537 .5 .762 r
.6432 .43255 m .64076 .43357 L .64046 .43083 L F
.184 .204 .647 r
.36017 .5903 m .36203 .59286 L .36074 .59397 L F
.787 .698 .766 r
.36203 .59286 m .35968 .59581 L .36074 .59397 L F
.521 0 0 r
.36937 .51126 m .36982 .51117 L .36771 .51075 L F
.778 .707 .785 r
.34736 .62762 m .34946 .63152 L .34489 .63072 L F
.633 .807 .966 r
.34489 .63072 m .34946 .63152 L .3484 .62986 L F
0 .183 .717 r
.34962 .62975 m .34946 .63152 L .34736 .62762 L F
.213 .544 .929 r
.3484 .62986 m .34946 .63152 L .34962 .62975 L F
.487 .446 .737 r
.34946 .63152 m .35216 .63391 L .35145 .63095 L F
.451 0 0 r
.32832 .64367 m .33239 .64378 L .33098 .64267 L F
.199 .638 .947 r
.33239 .64378 m .33274 .64278 L .33098 .64267 L F
.206 .415 .845 r
.21119 .60594 m .21326 .60936 L .21417 .60772 L F
.215 .426 .852 r
.21326 .60936 m .21496 .61006 L .21417 .60772 L F
.466 .3 .571 r
.35996 .53335 m .35754 .53649 L .35749 .53407 L F
.042 0 .226 r
.32231 .53675 m .32355 .53624 L .32433 .53366 L F
.15 .075 .509 r
.32231 .53675 m .32368 .53895 L .32355 .53624 L F
.868 .771 .752 r
.71272 .35767 m .70998 .35708 L .71184 .3545 L F
.861 .505 .376 r
.71272 .35767 m .71168 .35939 L .70998 .35708 L F
.668 .659 .832 r
.71565 .35715 m .71272 .35767 L .71184 .3545 L F
.503 .079 .169 r
.71446 .35843 m .71272 .35767 L .71565 .35715 L F
.71446 .35843 m .71168 .35939 L .71272 .35767 L F
0 0 0 r
.23892 .53287 m .23996 .53253 L .24156 .53123 L F
.23892 .53287 m .23783 .53352 L .23996 .53253 L F
.1 .073 .536 r
.29227 .59711 m .29402 .59867 L .29469 .59505 L F
.29227 .59711 m .29237 .59957 L .29402 .59867 L F
.337 0 .092 r
.23811 .56169 m .2353 .56288 L .23568 .56202 L F
.437 .081 .263 r
.23924 .56034 m .23811 .56169 L .23568 .56202 L F
.111 0 0 r
.25697 .63347 m .26158 .63364 L .25946 .63282 L F
.056 .493 .891 r
.26158 .63364 m .26186 .6328 L .25946 .63282 L F
.26158 .63364 m .26344 .63422 L .26186 .6328 L F
.364 .104 .38 r
.34358 .57803 m .34586 .57767 L .34657 .57454 L F
.274 .027 .345 r
.34657 .57454 m .34832 .57646 L .34891 .57354 L F
.34657 .57454 m .34586 .57767 L .34832 .57646 L F
.347 .346 .716 r
.19116 .58387 m .19213 .57991 L .19018 .58135 L F
.721 .976 .922 r
.3417 .67231 m .33753 .67392 L .33982 .67303 L F
.295 .774 .679 r
.34289 .67176 m .3417 .67231 L .33982 .67303 L F
.482 .55 .849 r
.32739 .58047 m .3292 .58415 L .33121 .58295 L F
.194 .01 .389 r
.3292 .58415 m .33071 .58571 L .33121 .58295 L F
.3292 .58415 m .32881 .58679 L .33071 .58571 L F
.078 0 0 r
.19391 .56752 m .19565 .56699 L .19684 .56515 L F
.055 0 0 r
.19565 .56699 m .19911 .56443 L .19684 .56515 L F
0 0 0 r
.32803 .60939 m .32417 .61222 L .32626 .6115 L F
.384 .471 .826 r
.33084 .61195 m .32803 .60939 L .33131 .61183 L F
.687 .273 .255 r
.32626 .6115 m .33131 .61183 L .32803 .60939 L F
.903 .94 .824 r
.38525 .6618 m .38848 .65926 L .38624 .65873 L F
.392 .169 .452 r
.33053 .64042 m .33088 .63774 L .32805 .64243 L F
.318 .107 .428 r
.33297 .63695 m .33088 .63774 L .33053 .64042 L F
0 0 0 r
.40668 .59392 m .40482 .59502 L .4024 .59617 L F
.273 0 0 r
.40894 .59307 m .40482 .59502 L .40668 .59392 L F
.504 .233 .437 r
.3883 .60877 m .38629 .61145 L .38372 .61137 L F
0 0 0 r
.27597 .54933 m .2755 .54892 L .27792 .54854 L F
.45 0 0 r
.27853 .5494 m .27627 .54943 L .27597 .54933 L F
0 0 0 r
.27597 .54933 m .27344 .55031 L .27524 .5491 L F
.592 .612 .841 r
.27224 .54771 m .273 .54935 L .27597 .54933 L F
.273 .54935 m .27344 .55031 L .2746 .54986 L F
.273 .54935 m .2746 .54986 L .27597 .54933 L F
.689 .292 .29 r
.27076 .54864 m .26977 .55051 L .27344 .54992 L F
.2699 .54823 m .26989 .54837 L .27076 .54864 L F
.26989 .54837 m .26977 .55051 L .27076 .54864 L F
.45 0 0 r
.27627 .54943 m .27434 .54945 L .27597 .54933 L F
0 0 0 r
.27597 .54933 m .27524 .5491 L .2755 .54892 L F
.487 .307 .562 r
.38487 .56837 m .38758 .568 L .38738 .56523 L F
.098 .169 .65 r
.38671 .57009 m .38709 .57046 L .38703 .56808 L F
.528 .831 .999 r
.3861 .57373 m .38647 .57166 L .38698 .57084 L F
.3861 .57373 m .38626 .57293 L .38635 .57234 L F
.557 .117 .158 r
.38842 .57314 m .39047 .57379 L .3861 .57373 L F
.82 .727 .762 r
.38842 .57314 m .3861 .57373 L .38709 .57046 L F
.38842 .57314 m .3861 .57373 L .38709 .57046 L F
.528 .831 .999 r
.38647 .57166 m .38723 .56742 L .38698 .57084 L F
.34 0 0 r
.38728 .56697 m .38566 .56745 L .38731 .56672 L F
.177 .082 .5 r
.38738 .56523 m .38758 .568 L .38891 .56688 L F
.34 0 0 r
.38731 .56733 m .38566 .56745 L .38777 .56683 L F
.38699 .56768 m .38681 .56765 L .38731 .56733 L F
.38681 .56765 m .38566 .56745 L .38731 .56733 L F
.098 .169 .65 r
.38703 .56808 m .38709 .57046 L .38758 .568 L F
.004 0 .244 r
.38758 .568 m .38709 .57046 L .38891 .56688 L F
.886 .958 .618 r
.38891 .56688 m .38709 .57046 L .38731 .56733 L F
.34 0 0 r
.38777 .56683 m .38728 .56697 L .38769 .56654 L F
.38728 .56697 m .38731 .56672 L .38769 .56654 L F
.886 .958 .618 r
.38815 .5668 m .38731 .56733 L .38735 .56672 L F
.38891 .56688 m .38757 .56725 L .38815 .5668 L F
.38757 .56725 m .38781 .56701 L .38815 .5668 L F
.177 .082 .5 r
.38738 .56523 m .38891 .56688 L .38904 .56433 L F
.716 .183 0 r
.38891 .56688 m .38503 .56384 L .38904 .56433 L F
.38891 .56688 m .38769 .56654 L .38503 .56384 L F
.528 .831 .999 r
.38698 .57084 m .38723 .56742 L .38709 .57046 L F
.38723 .56742 m .38731 .56733 L .38709 .57046 L F
.722 .439 .497 r
.38677 .57027 m .39034 .56773 L .38856 .56713 L F
.34 0 0 r
.38802 .56749 m .38781 .56701 L .3881 .56683 L F
.38795 .56754 m .38781 .56701 L .38802 .56749 L F
.38799 .56773 m .3881 .56683 L .38854 .56715 L F
.886 .958 .618 r
.38757 .56725 m .38731 .56733 L .38781 .56701 L F
.528 .831 .999 r
.38723 .56742 m .38735 .56672 L .38731 .56733 L F
.722 .439 .497 r
.38713 .56809 m .38795 .56754 L .3872 .56763 L F
.34 0 0 r
.38803 .56786 m .38699 .56768 L .38701 .56766 L F
.38795 .56754 m .38701 .56766 L .38777 .56683 L F
.38803 .56786 m .38701 .56766 L .38795 .56754 L F
.722 .439 .497 r
.3872 .56763 m .38856 .56713 L .38735 .56672 L F
.38795 .56754 m .38856 .56713 L .3872 .56763 L F
.528 .831 .999 r
.38723 .56742 m .3872 .56763 L .38735 .56672 L F
.574 .325 .502 r
.38594 .56152 m .38503 .56384 L .38072 .56408 L F
.797 .435 .37 r
.38503 .56384 m .38136 .56101 L .38072 .56408 L F
.848 .771 .776 r
.37866 .56418 m .38065 .56518 L .38072 .56408 L F
.37866 .56418 m .38072 .56408 L .38136 .56101 L F
.686 .379 .45 r
.38503 .56384 m .38132 .56608 L .38013 .56336 L F
.38503 .56384 m .38485 .56615 L .38132 .56608 L F
.658 .355 .448 r
.38503 .56384 m .38769 .56654 L .38485 .56615 L F
0 0 0 r
.38769 .56654 m .38382 .568 L .38485 .56615 L F
.38401 .56793 m .38566 .56745 L .38382 .568 L F
.38769 .56654 m .38566 .56745 L .38401 .56793 L F
.406 .48 .824 r
.38675 .56714 m .38566 .56745 L .38719 .56772 L F
.38417 .56375 m .38566 .56745 L .38675 .56714 L F
.38417 .56375 m .38719 .56772 L .3873 .56709 L F
.38555 .56529 m .38803 .56786 L .38578 .56591 L F
.3853 .56495 m .38803 .56786 L .3845 .56419 L F
.07 0 .059 r
.38727 .56688 m .38636 .56749 L .38578 .56591 L F
.313 .312 .698 r
.38382 .568 m .38132 .56608 L .38485 .56615 L F
.459 .513 .827 r
.38382 .568 m .38566 .56745 L .38417 .56375 L F
.098 .169 .65 r
.38487 .56837 m .38671 .57009 L .38703 .56808 L F
.281 .213 .6 r
.38578 .56591 m .38535 .56907 L .38417 .56375 L F
.029 .114 .619 r
.38573 .56925 m .38443 .57201 L .38382 .568 L F
.339 .352 .727 r
.38382 .568 m .38443 .57201 L .38182 .57004 L F
.403 0 .077 r
.38382 .568 m .38228 .57025 L .38573 .56925 L F
.041 0 .194 r
.38065 .56518 m .37932 .56781 L .37834 .56808 L F
.883 .734 .692 r
.37866 .56418 m .37932 .56781 L .38065 .56518 L F
.342 .363 .738 r
.38132 .56608 m .37932 .56781 L .37866 .56418 L F
.28 .306 .71 r
.38182 .57004 m .37932 .56781 L .38132 .56608 L F
.342 .363 .738 r
.38132 .56608 m .37866 .56418 L .38013 .56336 L F
.313 .312 .698 r
.38382 .568 m .38182 .57004 L .38132 .56608 L F
.124 0 0 r
.38158 .56916 m .38382 .568 L .3791 .56731 L F
.38158 .56916 m .38228 .57025 L .38382 .568 L F
.489 .792 .998 r
.3791 .56731 m .38382 .568 L .3806 .56601 L F
.459 .513 .827 r
.38382 .568 m .38417 .56375 L .3806 .56601 L F
.501 .869 .645 r
.3806 .56601 m .38003 .56637 L .3791 .56731 L F
.765 .524 .569 r
.38417 .56375 m .38535 .56907 L .38438 .56857 L F
.38333 .56428 m .38438 .56857 L .38003 .56637 L F
.38417 .56375 m .38438 .56857 L .38333 .56428 L F
.528 .831 .999 r
.38635 .57234 m .38656 .57131 L .3872 .56763 L F
.38635 .57234 m .3872 .56763 L .38723 .56742 L F
.38626 .57293 m .38677 .57027 L .38635 .57234 L F
.3861 .57373 m .38443 .57201 L .38677 .57027 L F
0 .127 .673 r
.38589 .56986 m .38443 .57201 L .38573 .56925 L F
.718 .257 .154 r
.38443 .57201 m .38727 .5735 L .38677 .57027 L F
0 .127 .673 r
.38647 .57204 m .38443 .57201 L .38589 .56986 L F
.752 .329 .245 r
.38548 .57389 m .38363 .57631 L .38145 .57348 L F
.66 .157 .042 r
.38548 .57389 m .38375 .5744 L .38145 .57348 L F
.546 .6 .858 r
.38182 .57004 m .38375 .5744 L .38145 .57348 L F
0 0 0 r
.3861 .57373 m .38375 .5744 L .38548 .57389 L F
.706 .685 .828 r
.3861 .57373 m .38375 .5744 L .38182 .57004 L F
.617 .56 .768 r
.3803 .57009 m .38145 .57348 L .37855 .57362 L F
.539 .178 .303 r
.38145 .57348 m .37734 .57607 L .37855 .57362 L F
.38145 .57348 m .37954 .57552 L .37734 .57607 L F
.546 .6 .858 r
.38182 .57004 m .38145 .57348 L .3803 .57009 L F
.661 .332 .406 r
.38145 .57348 m .38363 .57631 L .37954 .57552 L F
0 0 0 r
.37939 .57468 m .38292 .57352 L .38486 .57137 L F
.24 0 .301 r
.38292 .57352 m .38376 .57259 L .38486 .57137 L F
0 0 .422 r
.38486 .57137 m .38502 .57119 L .38492 .57078 L F
.885 .514 .334 r
.38407 .56884 m .38546 .5707 L .38573 .56925 L F
.38546 .5707 m .38579 .57113 L .38576 .57037 L F
.38546 .5707 m .38576 .57037 L .38573 .56925 L F
.38579 .57113 m .38647 .57204 L .38632 .57148 L F
.38579 .57113 m .38632 .57148 L .38573 .56925 L F
.722 .439 .497 r
.38677 .57027 m .38822 .56773 L .38713 .56809 L F
.528 .831 .999 r
.38656 .57131 m .38677 .57027 L .38698 .56902 L F
.38706 .56848 m .38698 .56902 L .38714 .56803 L F
.38656 .57131 m .38698 .56902 L .38706 .56848 L F
.259 .158 .544 r
.38727 .5735 m .38983 .57023 L .38677 .57027 L F
.771 .407 .366 r
.38983 .57023 m .38773 .57213 L .38672 .57068 L F
.3869 .56953 m .38672 .57068 L .38573 .56925 L F
.722 .439 .497 r
.38677 .57027 m .38983 .57023 L .39034 .56773 L F
.771 .407 .366 r
.38983 .57023 m .38672 .57068 L .3869 .56953 L F
.528 .831 .999 r
.38656 .57131 m .38714 .56803 L .3872 .56763 L F
.762 .671 .762 r
.38803 .56786 m .38983 .57023 L .38573 .56925 L F
0 .543 .793 r
.38444 .56893 m .38611 .56917 L .38573 .56925 L F
.38407 .56884 m .38455 .56892 L .38444 .56893 L F
.629 .065 0 r
.38407 .56884 m .38003 .56637 L .38535 .56907 L F
0 0 0 r
.38578 .56591 m .38407 .56884 L .38535 .56907 L F
0 .543 .793 r
.38455 .56892 m .38611 .56917 L .38468 .56897 L F
.38449 .56893 m .38468 .56897 L .38444 .56893 L F
.38455 .56892 m .38468 .56897 L .38449 .56893 L F
0 .004 .579 r
.38573 .56925 m .38773 .57213 L .38611 .56917 L F
.715 .615 .744 r
.38611 .56917 m .38647 .57204 L .38465 .56961 L F
.38455 .56892 m .38465 .56961 L .38407 .56884 L F
.38611 .56917 m .38465 .56961 L .38455 .56892 L F
0 0 .422 r
.38492 .57078 m .38573 .57041 L .38533 .56882 L F
.177 .64 .936 r
.38519 .56829 m .38611 .56917 L .38407 .56884 L F
0 0 .422 r
.38513 .56885 m .38533 .56882 L .38519 .56829 L F
.38492 .57078 m .38533 .56882 L .38513 .56885 L F
.24 0 .301 r
.38376 .57259 m .38573 .57041 L .38511 .57109 L F
.38376 .57259 m .38511 .57109 L .38486 .57137 L F
.629 .065 0 r
.38407 .56884 m .38234 .5684 L .38003 .56637 L F
0 0 0 r
.38578 .56591 m .38519 .56829 L .38407 .56884 L F
0 0 .422 r
.38319 .56941 m .38519 .56829 L .38234 .5684 L F
.004 0 .076 r
.38228 .57025 m .38187 .57106 L .38407 .56884 L F
.38187 .57106 m .38131 .57218 L .38265 .57056 L F
.38187 .57106 m .38265 .57056 L .38407 .56884 L F
.737 .622 .73 r
.38407 .56884 m .38131 .57218 L .38486 .57137 L F
.38407 .56884 m .38486 .57137 L .38234 .5684 L F
0 0 .422 r
.38486 .57137 m .38495 .57057 L .38382 .56982 L F
.38364 .56993 m .38382 .56982 L .38319 .56941 L F
.38486 .57137 m .38382 .56982 L .38364 .56993 L F
.38495 .57057 m .38519 .56829 L .38319 .56941 L F
.38502 .57119 m .38573 .57041 L .38492 .57078 L F
.07 0 .059 r
.38636 .56749 m .38519 .56829 L .38578 .56591 L F
.406 .48 .824 r
.3845 .56419 m .38555 .56529 L .38578 .56591 L F
.38417 .56375 m .3853 .56495 L .3845 .56419 L F
.722 .439 .497 r
.38822 .56773 m .38856 .56713 L .38799 .56751 L F
.38822 .56773 m .38799 .56751 L .38713 .56809 L F
.34 0 0 r
.38799 .56773 m .38795 .56754 L .38802 .56749 L F
.38854 .56715 m .3881 .56683 L .38988 .56571 L F
.886 .958 .618 r
.38891 .56688 m .38803 .56679 L .38769 .56654 L F
.38803 .56679 m .38735 .56672 L .38769 .56654 L F
.34 0 0 r
.38781 .56701 m .38769 .56654 L .38862 .56619 L F
.38781 .56701 m .38862 .56619 L .38988 .56571 L F
.819 .426 .307 r
.38735 .56672 m .38856 .56713 L .38988 .56571 L F
.38856 .56713 m .39034 .56773 L .38988 .56571 L F
.34 0 0 r
.38803 .56786 m .38799 .56773 L .38988 .56571 L F
.406 .48 .824 r
.3873 .56709 m .38719 .56772 L .38803 .56786 L F
0 0 .208 r
.38727 .5735 m .3861 .57373 L .39047 .57379 L F
.38727 .5735 m .38627 .57519 L .3861 .57373 L F
.928 .849 .744 r
.38941 .5765 m .38716 .58087 L .38542 .58002 L F
.38941 .5765 m .3865 .57907 L .38787 .5782 L F
.3865 .57907 m .38542 .58002 L .38787 .5782 L F
.365 0 0 r
.39004 .5784 m .38941 .5765 L .38787 .5782 L F
.454 .548 .862 r
.38727 .5735 m .38938 .57723 L .38787 .5782 L F
.38938 .57723 m .39004 .5784 L .38787 .5782 L F
.38727 .5735 m .38787 .5782 L .38627 .57519 L F
.636 .178 .147 r
.38727 .5735 m .38713 .57502 L .38642 .57517 L F
.159 0 0 r
.38671 .5746 m .38678 .57463 L .38727 .5735 L F
.718 .257 .154 r
.38551 .57322 m .38713 .57502 L .38581 .57274 L F
0 .127 .673 r
.38706 .57473 m .38713 .57502 L .38678 .57463 L F
.718 .257 .154 r
.38683 .5745 m .38713 .57502 L .38727 .5735 L F
.567 .259 .406 r
.3909 .57144 m .39047 .57379 L .38842 .57314 L F
.821 .491 .43 r
.39314 .57401 m .38727 .5735 L .39047 .57379 L F
.365 0 0 r
.39004 .5784 m .39333 .57631 L .38941 .5765 L F
.39333 .57631 m .39479 .57538 L .39166 .57603 L F
.39333 .57631 m .39166 .57603 L .38941 .5765 L F
.657 .246 .252 r
.39534 .57741 m .39479 .57538 L .39004 .5784 L F
.756 .504 .551 r
.39443 .57112 m .39512 .57427 L .39047 .57379 L F
0 .561 .755 r
.39193 .57394 m .39314 .57401 L .39047 .57379 L F
.303 .464 .854 r
.39314 .57401 m .39454 .5741 L .39452 .57388 L F
.265 .08 .433 r
.39452 .57388 m .39441 .57408 L .39314 .57401 L F
0 .561 .755 r
.39512 .57427 m .39314 .57401 L .39214 .57396 L F
.919 .677 .557 r
.39512 .57427 m .39534 .57741 L .39314 .57401 L F
.303 .464 .854 r
.39314 .57401 m .39479 .57655 L .39454 .5741 L F
.265 .08 .433 r
.39441 .57408 m .39329 .57607 L .39314 .57401 L F
0 .561 .755 r
.39214 .57396 m .39314 .57401 L .39193 .57394 L F
.303 .464 .854 r
.39479 .57655 m .39534 .57741 L .39516 .57662 L F
.39479 .57655 m .39516 .57662 L .39452 .57388 L F
.821 .491 .43 r
.39314 .57401 m .39329 .57607 L .38727 .5735 L F
.743 .683 .793 r
.39329 .57607 m .39004 .5784 L .38727 .5735 L F
.159 0 0 r
.38658 .57508 m .38981 .57336 L .38905 .5734 L F
.38659 .57505 m .38905 .5734 L .38727 .5735 L F
.38658 .57508 m .38905 .5734 L .38659 .57505 L F
.858 .878 .852 r
.38642 .57517 m .38713 .57502 L .38706 .57473 L F
.718 .257 .154 r
.38581 .57274 m .38683 .5745 L .38727 .5735 L F
.38443 .57201 m .38551 .57322 L .38581 .57274 L F
0 .127 .673 r
.38647 .57204 m .3869 .57399 L .38443 .57201 L F
.3869 .57399 m .38706 .57473 L .38668 .57434 L F
.3869 .57399 m .38668 .57434 L .38443 .57201 L F
.21 0 0 r
.38627 .57519 m .38548 .57389 L .3861 .57373 L F
0 .127 .673 r
.38706 .57473 m .38678 .57463 L .38443 .57201 L F
.159 0 0 r
.38642 .57517 m .38658 .57508 L .38678 .57463 L F
.38642 .57517 m .38678 .57463 L .38671 .5746 L F
.858 .878 .852 r
.38642 .57517 m .38706 .57473 L .38647 .57204 L F
.684 .659 .819 r
.38787 .5782 m .38363 .57631 L .38627 .57519 L F
.259 .158 .544 r
.38727 .5735 m .38981 .57336 L .38983 .57023 L F
.765 .847 .913 r
.38773 .57213 m .38981 .57336 L .38642 .57517 L F
.38716 .57358 m .38642 .57517 L .38634 .57565 L F
.38773 .57213 m .38699 .57385 L .38716 .57358 L F
.38699 .57385 m .38642 .57517 L .38716 .57358 L F
.781 .733 .808 r
.31151 .51819 m .30874 .52125 L .30726 .51813 L F
.923 .835 .741 r
.42263 .565 m .41883 .56699 L .41876 .56458 L F
.42263 .565 m .42039 .56809 L .41883 .56699 L F
.802 .623 .66 r
.42367 .5683 m .42039 .56809 L .42263 .565 L F
.461 .409 .713 r
.42548 .56435 m .42367 .5683 L .42263 .565 L F
.464 .112 .283 r
.38068 .61052 m .37726 .60967 L .37658 .6115 L F
.866 .663 .625 r
.62244 .43954 m .61921 .44107 L .62132 .43773 L F
.62244 .43954 m .62246 .44237 L .61921 .44107 L F
.76 .315 .196 r
.62244 .43954 m .62638 .44195 L .62246 .44237 L F
.743 .338 .282 r
.3594 .59172 m .36017 .5903 L .35871 .58893 L F
.3594 .59172 m .36203 .59286 L .36017 .5903 L F
.974 .693 .431 r
.35871 .58893 m .36017 .5903 L .35872 .58707 L F
.163 .7 .735 r
.35057 .5801 m .3482 .58043 L .34664 .58075 L F
.047 0 0 r
.35577 .57728 m .35136 .58072 L .35089 .58047 L F
.457 0 0 r
.35089 .58047 m .35149 .58104 L .3482 .58043 L F
.374 0 0 r
.351 .5808 m .35149 .58104 L .35089 .58047 L F
.696 .159 0 r
.35149 .58104 m .35107 .58079 L .351 .5808 L F
.35149 .58104 m .351 .5808 L .35065 .58089 L F
.35065 .58089 m .3499 .58009 L .3482 .58043 L F
.35149 .58104 m .3497 .58077 L .34941 .5805 L F
.374 0 0 r
.35104 .58093 m .35149 .58104 L .351 .5808 L F
.696 .159 0 r
.35107 .58079 m .3499 .58009 L .35065 .58089 L F
.618 .271 .361 r
.35367 .57695 m .3482 .58043 L .35057 .5801 L F
.35367 .57695 m .35089 .58047 L .3482 .58043 L F
.696 .159 0 r
.3499 .58009 m .34742 .57859 L .3482 .58043 L F
.35149 .58104 m .34941 .5805 L .34742 .57859 L F
.374 0 0 r
.35105 .58096 m .35149 .58104 L .35104 .58093 L F
.047 0 0 r
.35136 .58072 m .35105 .58096 L .351 .5808 L F
.35136 .58072 m .351 .5808 L .35089 .58047 L F
.163 .7 .735 r
.34664 .58075 m .3482 .58043 L .34616 .58083 L F
.49 .286 .529 r
.33066 .54655 m .33257 .54631 L .33344 .54362 L F
.57 .432 .653 r
.33046 .54667 m .33257 .54631 L .33066 .54655 L F
.795 .759 .82 r
.7073 .31733 m .70334 .31825 L .70595 .31543 L F
.478 .224 .451 r
.24125 .55879 m .23811 .56169 L .23924 .56034 L F
0 0 0 r
.3615 .55507 m .35927 .55878 L .35911 .55631 L F
.751 .438 .454 r
.71493 .32276 m .71421 .32481 L .71131 .32578 L F
0 .546 .724 r
.71493 .32276 m .71795 .32298 L .71694 .32287 L F
.71493 .32276 m .71694 .32287 L .71421 .32481 L F
.799 .65 .697 r
.61186 .42331 m .61362 .42578 L .6098 .42618 L F
.75 .452 .479 r
.6098 .42618 m .61362 .42578 L .61174 .42864 L F
.693 .627 .778 r
.616 .42323 m .61362 .42578 L .61186 .42331 L F
.795 .511 .508 r
.61362 .42578 m .61593 .4292 L .61174 .42864 L F
.267 .715 .959 r
.3312 .66979 m .33193 .66896 L .32998 .6676 L F
.3312 .66979 m .33414 .67001 L .33193 .66896 L F
.408 .103 .334 r
.39415 .68535 m .39321 .68758 L .39088 .68805 L F
.028 0 .133 r
.39576 .68425 m .39321 .68758 L .39415 .68535 L F
0 0 0 r
.28764 .60611 m .28864 .60475 L .28984 .60252 L F
.28764 .60611 m .28824 .60732 L .28864 .60475 L F
.28764 .60611 m .28698 .60821 L .28824 .60732 L F
.858 .404 .049 r
.34601 .51186 m .3443 .51092 L .34453 .51026 L F
.188 .533 .924 r
.34601 .51186 m .34656 .51044 L .3443 .51092 L F
.449 .056 .201 r
.34656 .51044 m .34402 .5117 L .3443 .51092 L F
.34402 .5117 m .34281 .51231 L .3443 .51092 L F
.858 .404 .049 r
.34453 .51026 m .3443 .51092 L .34325 .50886 L F
.188 .533 .924 r
.34601 .51186 m .34786 .51212 L .34656 .51044 L F
.082 0 0 r
.27655 .53464 m .27403 .53558 L .27536 .53382 L F
.228 0 .078 r
.29737 .63459 m .29843 .63622 L .29591 .63697 L F
.29737 .63459 m .29994 .6332 L .29843 .63622 L F
.919 .732 .633 r
.60625 .40723 m .60761 .41063 L .60643 .40962 L F
.971 .66 .351 r
.60761 .41063 m .60664 .4125 L .60643 .40962 L F
.60761 .41063 m .60839 .41333 L .60664 .4125 L F
.666 .603 .775 r
.23891 .60896 m .23645 .60998 L .23486 .60604 L F
.019 .501 .875 r
.35478 .6268 m .35655 .62694 L .35367 .62523 L F
.35628 .62738 m .35781 .62798 L .35655 .62694 L F
.67 .218 .169 r
.35667 .62971 m .35781 .62798 L .35478 .6268 L F
.991 .735 .414 r
.35655 .62694 m .35781 .62798 L .35667 .62971 L F
.019 0 .459 r
.35655 .62694 m .35722 .62981 L .35688 .6264 L F
.35655 .62694 m .35688 .6264 L .3568 .62561 L F
.019 .501 .875 r
.35478 .6268 m .35628 .62738 L .35655 .62694 L F
.67 .218 .169 r
.35667 .62971 m .35478 .6268 L .35363 .6301 L F
.046 0 .193 r
.31409 .57711 m .31334 .5801 L .31136 .58107 L F
.068 .137 .628 r
.31316 .582 m .31136 .58107 L .31334 .5801 L F
.31316 .582 m .31227 .58382 L .31136 .58107 L F
0 0 0 r
.23261 .55337 m .23466 .55318 L .23664 .55219 L F
.715 .377 .405 r
.23466 .55318 m .23735 .55395 L .23925 .55085 L F
.385 0 0 r
.23372 .55253 m .23524 .55312 L .23466 .55318 L F
.23524 .55312 m .23735 .55395 L .23466 .55318 L F
0 0 0 r
.23244 .55342 m .23466 .55318 L .23261 .55337 L F
.591 .42 .618 r
.3383 .52598 m .33577 .5272 L .33469 .52393 L F
.841 .528 0 r
.32264 .6036 m .32302 .60579 L .32166 .60103 L F
.447 .497 .818 r
.3788 .60381 m .37978 .60597 L .38145 .6053 L F
.816 .494 .444 r
.37978 .60597 m .37942 .60866 L .38145 .6053 L F
.722 .546 .652 r
.42354 .57121 m .42039 .56809 L .42367 .5683 L F
.461 .409 .713 r
.42548 .56435 m .42548 .56775 L .42367 .5683 L F
.433 .229 .501 r
.42592 .5697 m .42367 .5683 L .42548 .56775 L F
.42592 .5697 m .42354 .57121 L .42367 .5683 L F
0 0 0 r
.73326 .33937 m .73133 .34353 L .73247 .34192 L F
.482 .793 .999 r
.29922 .62353 m .29862 .6251 L .29683 .62395 L F
0 0 .543 r
.29999 .6274 m .29862 .6251 L .29922 .62353 L F
0 .005 .553 r
.29999 .6274 m .29945 .62774 L .29862 .6251 L F
0 0 0 r
.3615 .55507 m .36036 .55723 L .35927 .55878 L F
.635 .957 .784 r
.36036 .55723 m .35845 .55885 L .35927 .55878 L F
.346 0 0 r
.31427 .53425 m .30866 .53361 L .31139 .53412 L F
.693 .315 .327 r
.31021 .65226 m .31053 .6506 L .30712 .6503 L F
.697 .618 .764 r
.31053 .6506 m .31438 .65025 L .3132 .64726 L F
.665 .421 .542 r
.31386 .65243 m .31053 .6506 L .31021 .65226 L F
.31386 .65243 m .31438 .65025 L .31053 .6506 L F
.482 .393 .679 r
.63686 .43789 m .63376 .43552 L .63792 .43627 L F
.484 .194 .398 r
.63991 .43489 m .63686 .43789 L .63792 .43627 L F
.444 .209 .462 r
.21554 .57917 m .21285 .57792 L .215 .57746 L F
.21554 .57917 m .21233 .58042 L .21285 .57792 L F
0 0 .172 r
.39377 .65599 m .39353 .65577 L .39353 .65548 L F
.64 .181 0 r
.39377 .65599 m .39353 .65548 L .39163 .65317 L F
.39377 .65599 m .39163 .65317 L .39388 .65609 L F
0 .171 .69 r
.39562 .6581 m .3935 .65709 L .39377 .65599 L F
.797 .309 0 r
.39394 .65663 m .39562 .6581 L .39377 .65599 L F
0 0 .172 r
.39377 .65599 m .3935 .65709 L .39353 .65577 L F
.217 .544 .928 r
.3917 .65581 m .39478 .65751 L .38995 .65435 L F
.797 .309 0 r
.39502 .65781 m .39562 .6581 L .39394 .65663 L F
.217 .544 .928 r
.39478 .65751 m .39511 .65769 L .39463 .65738 L F
.39478 .65751 m .39463 .65738 L .38995 .65435 L F
.797 .309 0 r
.39414 .65737 m .39502 .65781 L .39474 .6575 L F
.39414 .65737 m .39511 .65769 L .39478 .65751 L F
0 .171 .69 r
.39562 .6581 m .39485 .65973 L .3935 .65709 L F
.523 .526 .8 r
.39004 .65965 m .39249 .65893 L .3917 .65581 L F
.797 .309 0 r
.39414 .65737 m .3917 .65581 L .39249 .65893 L F
.76 .972 .695 r
.39324 .65738 m .39414 .65737 L .39203 .65887 L F
.797 .309 0 r
.39414 .65737 m .39452 .65736 L .3917 .65581 L F
.797 .572 .596 r
.38995 .65435 m .39463 .65738 L .39394 .65663 L F
.39079 .65376 m .39394 .65663 L .39111 .65354 L F
.38995 .65435 m .39394 .65663 L .39079 .65376 L F
.797 .309 0 r
.394 .65683 m .39463 .65738 L .39394 .65663 L F
.39414 .65737 m .39478 .65751 L .39452 .65736 L F
.39414 .65737 m .39474 .6575 L .39463 .65738 L F
.39414 .65737 m .39463 .65738 L .394 .65683 L F
.39414 .65737 m .39394 .65663 L .39511 .65769 L F
.39394 .65663 m .39377 .65599 L .39511 .65769 L F
.64 .181 0 r
.39377 .65599 m .39388 .65609 L .39511 .65769 L F
.797 .572 .596 r
.39111 .65354 m .39511 .65769 L .39163 .65317 L F
.39463 .65738 m .39511 .65769 L .39111 .65354 L F
.763 .571 .637 r
.39414 .65198 m .39511 .65769 L .39163 .65317 L F
.648 .613 .8 r
.39473 .65453 m .39677 .65692 L .39414 .65737 L F
0 0 0 r
.39473 .65453 m .39414 .65737 L .39446 .65588 L F
.76 .972 .695 r
.39446 .65588 m .39414 .65737 L .39324 .65738 L F
.465 .522 .831 r
.22548 .58262 m .22408 .58483 L .22346 .58304 L F
.296 .292 .686 r
.22599 .58636 m .22408 .58483 L .22548 .58262 L F
.22599 .58636 m .22478 .5875 L .22408 .58483 L F
.814 .721 .763 r
.34101 .62769 m .34406 .62875 L .34362 .62431 L F
.909 .98 .711 r
.34244 .63134 m .34406 .62875 L .34489 .63072 L F
.588 .596 .828 r
.34101 .62769 m .34489 .63072 L .34406 .62875 L F
.584 .552 .785 r
.34362 .62431 m .34406 .62875 L .34736 .62762 L F
.498 .311 .558 r
.34736 .62762 m .34489 .63072 L .34406 .62875 L F
.584 .422 .628 r
.33641 .5928 m .33327 .59018 L .3367 .59018 L F
.33641 .5928 m .33383 .59339 L .33327 .59018 L F
.816 .823 .855 r
.61959 .41623 m .6228 .41669 L .62243 .41326 L F
.513 .243 .443 r
.35448 .56865 m .35674 .56904 L .35763 .56565 L F
.648 .581 .766 r
.35699 .56117 m .35763 .56565 L .3607 .56498 L F
.576 .303 .465 r
.35763 .56565 m .36011 .56765 L .3607 .56498 L F
.35763 .56565 m .35674 .56904 L .36011 .56765 L F
.263 .061 .407 r
.29469 .59505 m .29693 .59571 L .29737 .59278 L F
.085 0 .231 r
.29469 .59505 m .29568 .59766 L .29693 .59571 L F
.29469 .59505 m .29402 .59867 L .29568 .59766 L F
.379 .182 .482 r
.31479 .55489 m .31235 .55827 L .31279 .55577 L F
.643 .524 .703 r
.36873 .57402 m .36629 .57779 L .36625 .57469 L F
.481 .813 1 r
.19418 .60483 m .19288 .60553 L .19051 .6045 L F
.714 .914 .963 r
.36698 .59416 m .3668 .59621 L .36487 .59481 L F
.871 .995 .789 r
.36698 .59416 m .3659 .59545 L .3668 .59621 L F
.343 .791 .955 r
.36374 .59668 m .36747 .59676 L .3668 .59621 L F
.36374 .59668 m .3678 .59677 L .3668 .59621 L F
.421 .788 .995 r
.36487 .59481 m .3668 .59621 L .36374 .59668 L F
0 0 0 r
.36437 .59725 m .36374 .59668 L .3668 .59621 L F
.871 .995 .789 r
.3659 .59545 m .36437 .59725 L .3668 .59621 L F
.343 .791 .955 r
.36747 .59676 m .3678 .59677 L .3668 .59621 L F
.996 .781 .422 r
.3668 .59621 m .3678 .59677 L .36741 .59446 L F
.591 .538 .764 r
.22266 .58081 m .21912 .57776 L .22194 .57716 L F
.46 .322 .605 r
.22468 .5775 m .22266 .58081 L .22194 .57716 L F
.471 .24 .482 r
.32223 .55515 m .32512 .55478 L .32495 .55258 L F
.467 .505 .814 r
.32223 .55515 m .32614 .55949 L .32512 .55478 L F
.491 .889 .95 r
.27673 .52459 m .27217 .52517 L .27459 .52458 L F
.685 .971 .92 r
.27865 .52321 m .27673 .52459 L .27459 .52458 L F
.282 0 .184 r
.32582 .61875 m .32904 .61514 L .32759 .61741 L F
0 0 .127 r
.32904 .61514 m .33084 .61195 L .33033 .61447 L F
0 0 0 r
.32759 .61741 m .32904 .61514 L .33033 .61447 L F
.291 .247 .635 r
.19116 .58387 m .19119 .58778 L .19326 .58608 L F
.265 .264 .671 r
.19227 .59029 m .19326 .58608 L .19119 .58778 L F
0 0 .316 r
.4008 .54862 m .40169 .55092 L .40204 .55225 L F
.858 .467 0 r
.40169 .55355 m .40204 .55225 L .40169 .55092 L F
.40169 .55355 m .40281 .55484 L .40204 .55225 L F
.895 .475 .12 r
.40204 .55225 m .40281 .55484 L .40423 .55563 L F
.875 .951 .856 r
.30417 .56415 m .30769 .56193 L .3065 .56424 L F
.504 .314 .556 r
.31019 .55894 m .31001 .5615 L .30769 .56193 L F
.477 .108 .259 r
.3091 .56355 m .30769 .56193 L .31001 .5615 L F
.3091 .56355 m .3065 .56424 L .30769 .56193 L F
0 0 0 r
.3216 .57059 m .32044 .57266 L .31915 .57385 L F
.959 .805 .367 r
.32066 .5675 m .32044 .57266 L .3216 .57059 L F
.598 .108 .063 r
.35887 .71018 m .3628 .71044 L .3612 .71194 L F
.468 0 0 r
.3612 .71194 m .3628 .71044 L .3653 .71183 L F
.374 .026 .242 r
.2699 .54823 m .27349 .54519 L .27111 .54578 L F
.802 .699 .751 r
.40622 .58359 m .40508 .5873 L .40371 .5833 L F
.589 .471 .687 r
.40795 .58642 m .40508 .5873 L .40622 .58359 L F
.414 .521 .858 r
.40854 .59039 m .40508 .5873 L .40795 .58642 L F
.695 .466 .573 r
.34637 .52776 m .34651 .53092 L .34298 .53061 L F
.484 .348 .619 r
.34833 .52653 m .34851 .52934 L .34637 .52776 L F
.527 .337 .567 r
.34851 .52934 m .34651 .53092 L .34637 .52776 L F
.928 .729 .613 r
.28988 .62832 m .28933 .63101 L .28767 .62755 L F
.865 .842 .82 r
.29157 .62554 m .28988 .62832 L .28767 .62755 L F
.928 .729 .613 r
.28988 .62832 m .28933 .63101 L .28767 .62755 L F
.782 .847 .901 r
.64298 .42982 m .63951 .42977 L .64106 .4279 L F
.64298 .42982 m .64046 .43083 L .63951 .42977 L F
.537 .5 .762 r
.6432 .43255 m .64046 .43083 L .64298 .42982 L F
.506 .314 .555 r
.64564 .42922 m .6432 .43255 L .64298 .42982 L F
.054 0 0 r
.63385 .40915 m .63676 .4071 L .63688 .40679 L F
.503 .869 .644 r
.63892 .40518 m .63676 .4071 L .64015 .40446 L F
.502 .869 .643 r
.63688 .40679 m .63676 .4071 L .63892 .40518 L F
.426 0 0 r
.26984 .63684 m .27232 .6371 L .27334 .63772 L F
.727 .445 .5 r
.33511 .69367 m .33319 .69085 L .33501 .69151 L F
.599 .038 0 r
.31014 .63493 m .31028 .63602 L .30821 .6337 L F
.31014 .63493 m .3124 .63691 L .31028 .63602 L F
.192 .056 .455 r
.39109 .63131 m .39089 .63368 L .38946 .63416 L F
.182 .03 .427 r
.39089 .63368 m .39055 .63621 L .38946 .63416 L F
0 0 .479 r
.30377 .65281 m .30525 .65683 L .30389 .6556 L F
.632 .444 .609 r
.30664 .65594 m .30843 .65444 L .30589 .65589 L F
.055 .505 .892 r
.30431 .6558 m .30801 .65759 L .30575 .65589 L F
.30535 .65582 m .30671 .65603 L .3067 .65601 L F
.632 .444 .609 r
.30664 .65594 m .30589 .65589 L .30518 .6563 L F
.055 .505 .892 r
.30575 .65589 m .30801 .65759 L .30671 .65603 L F
.30394 .65562 m .30431 .6558 L .30575 .65589 L F
.30394 .65562 m .30671 .65603 L .30535 .65582 L F
.425 .159 .404 r
.30518 .6563 m .30535 .65582 L .30389 .6556 L F
.30535 .65582 m .30636 .65302 L .30389 .6556 L F
.411 .145 .397 r
.30843 .65444 m .30531 .65594 L .30566 .65602 L F
.055 .505 .892 r
.30389 .6556 m .30394 .65562 L .30664 .65594 L F
.30394 .65562 m .3067 .65601 L .30664 .65594 L F
.411 .145 .397 r
.30843 .65444 m .30636 .65302 L .30535 .65582 L F
.30551 .65584 m .30535 .65582 L .30531 .65594 L F
.30843 .65444 m .30535 .65582 L .30551 .65584 L F
.30566 .65602 m .30531 .65594 L .30518 .6563 L F
.055 .505 .892 r
.30394 .65562 m .30525 .65683 L .30801 .65759 L F
.30389 .6556 m .30391 .65561 L .30394 .65562 L F
.30391 .65561 m .30525 .65683 L .30394 .65562 L F
.082 .552 .903 r
.30525 .65683 m .30966 .65851 L .30801 .65759 L F
.456 .361 .659 r
.3096 .58964 m .30986 .59286 L .30749 .59326 L F
.349 .17 .492 r
.30965 .59541 m .30749 .59326 L .30986 .59286 L F
.30965 .59541 m .30732 .59562 L .30749 .59326 L F
.312 .291 .674 r
.38776 .61762 m .38651 .62166 L .38546 .61981 L F
.094 .312 .789 r
.64791 .39906 m .647 .4007 L .64546 .39897 L F
.64791 .39906 m .6479 .40101 L .647 .4007 L F
.006 .241 .748 r
.35519 .51732 m .35381 .51799 L .35063 .51923 L F
.35519 .51732 m .35622 .52015 L .35381 .51799 L F
.475 .309 .576 r
.35381 .51799 m .35622 .52015 L .35387 .52084 L F
.047 0 0 r
.3464 .59636 m .34777 .59416 L .34982 .59314 L F
.722 .471 .547 r
.34411 .65599 m .3473 .65317 L .34427 .65325 L F
.34411 .65599 m .34809 .65612 L .3473 .65317 L F
.71 .651 .789 r
.34809 .65612 m .34902 .65162 L .3473 .65317 L F
.767 .595 .664 r
.34269 .57954 m .34586 .57767 L .34358 .57803 L F
0 .387 .82 r
.288 .55931 m .28984 .56012 L .28838 .55874 L F
.28838 .55874 m .28841 .55874 L .28841 .55873 L F
.581 .296 .448 r
.29124 .56194 m .28742 .56527 L .28798 .56255 L F
.872 .895 .846 r
.28742 .56527 m .28786 .56328 L .28798 .56255 L F
.81 .502 .468 r
.29124 .56194 m .28798 .56255 L .28855 .5589 L F
.872 .895 .846 r
.28786 .56328 m .28835 .56109 L .28798 .56255 L F
.81 .502 .468 r
.28855 .5589 m .28798 .56255 L .28839 .55872 L F
.28861 .55886 m .28839 .55872 L .2884 .55862 L F
0 .387 .82 r
.28838 .55874 m .28984 .56012 L .28841 .55874 L F
.81 .502 .468 r
.29124 .56194 m .28839 .55872 L .28861 .55886 L F
0 .387 .82 r
.28841 .55873 m .28841 .55874 L .28841 .55873 L F
0 0 .003 r
.28817 .5608 m .28798 .56255 L .28835 .56109 L F
.28839 .55872 m .28798 .56255 L .2884 .55871 L F
.872 .895 .846 r
.28742 .56527 m .28524 .56482 L .28835 .56109 L F
.238 0 .132 r
.287 .56258 m .28847 .56129 L .28835 .56109 L F
.81 .502 .468 r
.29124 .56194 m .2884 .55862 L .2915 .56105 L F
.238 0 .132 r
.28847 .56129 m .29051 .5595 L .28835 .56109 L F
0 0 .003 r
.2884 .55871 m .28817 .5608 L .28835 .56109 L F
.2884 .55862 m .28839 .55872 L .28839 .55872 L F
.928 .599 .395 r
.28613 .55644 m .28839 .55872 L .2884 .55862 L F
.28839 .55872 m .28841 .55873 L .2884 .55862 L F
0 0 .003 r
.2884 .55862 m .28839 .55872 L .2884 .55871 L F
0 .387 .82 r
.28724 .55898 m .288 .55931 L .28838 .55874 L F
.001 0 0 r
.35886 .52701 m .36104 .52622 L .36278 .52481 L F
.376 .092 .348 r
.36104 .52622 m .36377 .52337 L .36278 .52481 L F
.532 .865 .994 r
.33813 .63623 m .33679 .63771 L .33671 .63701 L F
.398 .031 .221 r
.36483 .55275 m .3615 .55507 L .36122 .55262 L F
.36483 .55275 m .36326 .55496 L .3615 .55507 L F
.098 0 .241 r
.36673 .55146 m .36483 .55275 L .36711 .54939 L F
.465 .223 .462 r
.36673 .55146 m .36326 .55496 L .36483 .55275 L F
.871 .604 .53 r
.31577 .65065 m .3132 .64726 L .31438 .65025 L F
.681 .345 .399 r
.31438 .65025 m .31691 .65267 L .31386 .65243 L F
.31438 .65025 m .31577 .65065 L .31691 .65267 L F
.31438 .65025 m .31691 .65267 L .31386 .65243 L F
.31438 .65025 m .31577 .65065 L .31691 .65267 L F
.75 .379 .35 r
.33046 .54667 m .32446 .54766 L .326 .54632 L F
.33046 .54667 m .3249 .54797 L .32446 .54766 L F
0 0 .518 r
.33017 .54398 m .33046 .54667 L .326 .54632 L F
.327 .109 .422 r
.33017 .54398 m .326 .54632 L .32818 .54275 L F
0 0 .518 r
.33017 .54398 m .33063 .54515 L .33046 .54667 L F
.57 .432 .653 r
.33046 .54667 m .33336 .54877 L .33257 .54631 L F
.558 .38 .595 r
.33083 .55197 m .33336 .54877 L .33046 .54667 L F
0 0 .514 r
.33046 .54667 m .33164 .54776 L .33102 .54484 L F
.33077 .54455 m .33102 .54484 L .33085 .54402 L F
.33046 .54667 m .33102 .54484 L .33077 .54455 L F
0 0 .518 r
.33063 .54515 m .33164 .54776 L .33046 .54667 L F
0 0 .514 r
.33069 .54457 m .33085 .54402 L .33075 .54406 L F
0 0 .526 r
.33085 .54402 m .33164 .54776 L .33153 .5454 L F
0 0 .547 r
.33153 .5454 m .33164 .54776 L .33063 .54515 L F
.33073 .54456 m .33063 .54515 L .33017 .54398 L F
.33153 .5454 m .33063 .54515 L .33073 .54456 L F
0 0 .514 r
.33046 .54667 m .33077 .54455 L .33073 .54456 L F
.33063 .54515 m .33073 .54456 L .33069 .54457 L F
.33046 .54667 m .33073 .54456 L .33063 .54515 L F
.33077 .54455 m .33085 .54402 L .33069 .54457 L F
.46 0 .008 r
.32938 .54486 m .33072 .54456 L .33017 .54398 L F
.327 .109 .422 r
.33017 .54398 m .32818 .54275 L .3307 .54223 L F
.46 0 .008 r
.32962 .5443 m .33017 .54398 L .331 .54228 L F
0 0 .514 r
.33069 .54457 m .32821 .54512 L .32663 .54578 L F
.3264 .54589 m .32663 .54578 L .32638 .54589 L F
.351 .008 .236 r
.3295 .54458 m .32638 .54597 L .32638 .54589 L F
.46 0 .008 r
.33072 .54456 m .33073 .54456 L .33017 .54398 L F
0 0 .514 r
.33069 .54457 m .33075 .54406 L .32821 .54512 L F
.351 .008 .236 r
.33085 .54402 m .32947 .54462 L .3295 .54458 L F
.32947 .54462 m .32638 .54597 L .3295 .54458 L F
0 0 .514 r
.32877 .54627 m .32933 .54497 L .32663 .54578 L F
.351 .008 .236 r
.32947 .54462 m .3288 .5455 L .32638 .54597 L F
.46 0 .008 r
.3288 .5455 m .32912 .54514 L .32929 .54485 L F
.32912 .54514 m .32938 .54486 L .3295 .54458 L F
.351 .008 .236 r
.33085 .54402 m .3288 .5455 L .32947 .54462 L F
.46 0 .008 r
.3288 .5455 m .32929 .54485 L .32962 .5443 L F
.32912 .54514 m .3295 .54458 L .32962 .5443 L F
.32938 .54486 m .33017 .54398 L .32962 .5443 L F
0 0 .514 r
.33046 .54667 m .33069 .54457 L .32933 .54497 L F
.33046 .54667 m .32933 .54497 L .32877 .54627 L F
.46 0 .008 r
.33151 .5454 m .33133 .54519 L .33073 .54456 L F
.33151 .5454 m .33073 .54456 L .33072 .54456 L F
.3288 .5455 m .33151 .5454 L .33072 .54456 L F
.3288 .5455 m .33072 .54456 L .32938 .54486 L F
.33151 .5454 m .33153 .5454 L .33133 .54519 L F
0 0 .514 r
.33046 .54667 m .32663 .54578 L .3264 .54589 L F
.448 .245 .511 r
.32638 .54597 m .3288 .5455 L .32907 .54461 L F
.32667 .54576 m .32907 .54461 L .3293 .54387 L F
.32638 .54597 m .32907 .54461 L .32667 .54576 L F
.32832 .54456 m .3293 .54387 L .32932 .54383 L F
.32638 .54597 m .3293 .54387 L .32832 .54456 L F
.719 .965 .939 r
.3264 .54589 m .3249 .54797 L .33046 .54667 L F
.32638 .54589 m .32635 .54592 L .3264 .54589 L F
.32635 .54592 m .3249 .54797 L .3264 .54589 L F
.574 .535 .773 r
.31915 .57385 m .31688 .57447 L .31552 .57094 L F
.318 .016 .285 r
.31915 .57385 m .31626 .57655 L .31688 .57447 L F
.312 .291 .674 r
.38776 .61762 m .38834 .62178 L .38651 .62166 L F
.347 .346 .716 r
.19116 .58387 m .19276 .58337 L .19213 .57991 L F
.291 .247 .635 r
.19116 .58387 m .19326 .58608 L .19276 .58337 L F
0 .375 .788 r
.30966 .65851 m .31004 .65823 L .30801 .65759 L F
.3098 .65857 m .31153 .65936 L .31004 .65823 L F
.055 .561 .882 r
.31093 .65937 m .31153 .65936 L .30966 .65851 L F
.396 0 .045 r
.31153 .65936 m .30983 .65938 L .31004 .65823 L F
0 0 0 r
.31023 .65794 m .31004 .65823 L .30983 .65938 L F
.31057 .65675 m .31004 .65823 L .31023 .65794 L F
0 .375 .788 r
.30966 .65851 m .3098 .65857 L .31004 .65823 L F
.778 .482 0 r
.39788 .54262 m .39905 .54662 L .39823 .5436 L F
.539 .24 .408 r
.30485 .55469 m .3082 .55229 L .30571 .55319 L F
.278 0 0 r
.38038 .54921 m .37582 .55103 L .37745 .5515 L F
.388 .238 .554 r
.22942 .57292 m .22758 .57169 L .22983 .57103 L F
.22942 .57292 m .22758 .57394 L .22758 .57169 L F
.011 0 .059 r
.28984 .60252 m .29162 .60197 L .29237 .59957 L F
.024 0 .064 r
.29237 .59957 m .29333 .6009 L .29402 .59867 L F
.29237 .59957 m .29162 .60197 L .29333 .6009 L F
.736 .716 .833 r
.62961 .40174 m .63105 .40474 L .62709 .40408 L F
.06 .1 .589 r
.63203 .40083 m .63105 .40474 L .62961 .40174 L F
.63203 .40083 m .63123 .40521 L .63105 .40474 L F
.224 .684 .947 r
.34705 .50475 m .34934 .50483 L .35099 .50569 L F
.408 .765 .995 r
.34934 .50483 m .35326 .50561 L .35099 .50569 L F
.965 .712 .503 r
.34244 .63134 m .34237 .63418 L .34072 .632 L F
.588 .596 .828 r
.34101 .62769 m .34244 .63134 L .34489 .63072 L F
.481 .294 .549 r
.34472 .63354 m .34244 .63134 L .34489 .63072 L F
.34472 .63354 m .34237 .63418 L .34244 .63134 L F
0 0 0 r
.34489 .63072 m .34244 .63134 L .34072 .632 L F
.843 .836 .839 r
.32901 .50908 m .32506 .51084 L .32677 .50775 L F
.668 .838 .965 r
.33166 .50827 m .32901 .50908 L .32677 .50775 L F
0 0 .415 r
.3298 .50964 m .32901 .50908 L .33166 .50827 L F
.3298 .50964 m .32965 .5119 L .32901 .50908 L F
.025 .282 .778 r
.29379 .64209 m .29171 .64158 L .29319 .63946 L F
.29379 .64209 m .29267 .6427 L .29171 .64158 L F
.234 0 .197 r
.31626 .57655 m .31334 .5801 L .31409 .57711 L F
.653 .532 .703 r
.37185 .53016 m .36942 .52714 L .37212 .52766 L F
.37185 .53016 m .36792 .52669 L .36942 .52714 L F
.698 .982 .884 r
.26978 .623 m .26986 .62223 L .27152 .62213 L F
.25 .658 .963 r
.28351 .52264 m .28304 .52367 L .28148 .52242 L F
.28351 .52264 m .28532 .52389 L .28304 .52367 L F
.595 .287 .416 r
.33319 .69085 m .32886 .69375 L .32961 .69099 L F
.33319 .69085 m .33141 .6937 L .32886 .69375 L F
.727 .445 .5 r
.33511 .69367 m .33141 .6937 L .33319 .69085 L F
.345 0 .076 r
.33101 .5677 m .33352 .56725 L .33434 .56573 L F
.751 .368 .328 r
.7244 .35068 m .72333 .35274 L .72089 .35026 L F
.549 .144 .226 r
.72611 .35203 m .7244 .35068 L .7272 .35079 L F
.72611 .35203 m .72333 .35274 L .7244 .35068 L F
.393 .201 .498 r
.2801 .62133 m .27796 .62454 L .27811 .62187 L F
.523 .3 .518 r
.35629 .58846 m .35872 .58707 L .35422 .58569 L F
.35629 .58846 m .35871 .58893 L .35872 .58707 L F
.432 .13 .352 r
.35699 .56117 m .35318 .56483 L .35334 .56208 L F
.487 .293 .542 r
.36981 .56194 m .36959 .56521 L .36734 .56518 L F
.603 .571 .79 r
.39317 .66938 m .38936 .66597 L .39161 .66513 L F
0 0 0 r
.22373 .58937 m .22478 .5875 L .22599 .58636 L F
.803 .537 .535 r
.7253 .29925 m .72885 .29747 L .72514 .29672 L F
.7253 .29925 m .72897 .29991 L .72885 .29747 L F
.756 .988 .767 r
.36299 .56201 m .363 .56076 L .36616 .55904 L F
0 0 .204 r
.36549 .55665 m .36616 .55904 L .36545 .55642 L F
.467 0 0 r
.36616 .55904 m .363 .56076 L .36768 .5603 L F
.851 .549 .016 r
.40724 .5695 m .4075 .56829 L .40746 .56683 L F
.40724 .5695 m .40813 .57109 L .4075 .56829 L F
.125 0 .364 r
.30772 .57457 m .3086 .57631 L .30868 .57374 L F
.30772 .57457 m .30715 .57734 L .3086 .57631 L F
.148 0 .1 r
.29789 .60877 m .3008 .60612 L .29997 .60801 L F
.46 .336 .624 r
.30287 .60535 m .3008 .60612 L .30262 .60289 L F
.226 0 .136 r
.29997 .60801 m .3008 .60612 L .30287 .60535 L F
.541 .43 .677 r
.39321 .68758 m .3912 .69083 L .39088 .68805 L F
.158 .055 .478 r
.32771 .59901 m .32768 .60237 L .32593 .60269 L F
0 0 0 r
.32593 .60269 m .32657 .60288 L .32455 .60401 L F
.32593 .60269 m .32768 .60237 L .32657 .60288 L F
.891 .76 .71 r
.21912 .57776 m .21868 .58037 L .21554 .57917 L F
.854 .729 .724 r
.21868 .58037 m .21449 .58169 L .21554 .57917 L F
.21868 .58037 m .21622 .58343 L .21449 .58169 L F
0 0 .47 r
.6078 .42074 m .6078 .4207 L .60681 .41886 L F
.779 .477 .477 r
.6078 .42074 m .61186 .42331 L .6099 .42321 L F
0 0 .47 r
.6078 .42074 m .6099 .42321 L .6078 .4207 L F
.781 .733 .808 r
.31151 .51819 m .30726 .51813 L .30955 .5169 L F
.75 .834 .916 r
.31527 .51587 m .31151 .51819 L .30955 .5169 L F
.677 .776 .925 r
.56686 .39922 m .5677 .40126 L .56381 .40061 L F
.771 .449 .442 r
.56381 .40061 m .5677 .40126 L .5665 .40526 L F
.612 .836 .986 r
.56849 .39938 m .5677 .40126 L .56686 .39922 L F
.56849 .39938 m .57075 .40027 L .5677 .40126 L F
.782 .669 .739 r
.56828 .40328 m .5665 .40526 L .5677 .40126 L F
.835 .663 .67 r
.57075 .40027 m .56926 .40208 L .5677 .40126 L F
.57075 .40027 m .5716 .40401 L .56828 .40328 L F
.466 .822 .996 r
.5745 .40264 m .5716 .40401 L .57075 .40027 L F
.336 .422 .802 r
.56849 .39938 m .56963 .40215 L .57148 .40188 L F
.768 .268 .022 r
.57039 .40527 m .57062 .40455 L .56828 .40328 L F
.776 .348 .232 r
.56828 .40328 m .57003 .40366 L .57039 .40527 L F
.782 .669 .739 r
.56828 .40328 m .57062 .40455 L .57038 .40397 L F
.776 .348 .232 r
.57003 .40366 m .5716 .40401 L .57134 .40429 L F
.835 .663 .67 r
.56926 .40208 m .56828 .40328 L .56786 .40182 L F
.56926 .40208 m .56786 .40182 L .5677 .40126 L F
.782 .669 .739 r
.56828 .40328 m .57038 .40397 L .56849 .39938 L F
.776 .348 .232 r
.57003 .40366 m .57134 .40429 L .57038 .40397 L F
.675 .729 .22 r
.57071 .40427 m .57062 .40455 L .57039 .40527 L F
.336 .422 .802 r
.57038 .40397 m .57062 .40455 L .57071 .40427 L F
.776 .348 .232 r
.57003 .40366 m .57106 .40457 L .57039 .40527 L F
.57038 .40397 m .57077 .4041 L .57071 .40427 L F
.336 .422 .802 r
.57038 .40397 m .57071 .40427 L .57129 .40246 L F
.675 .729 .22 r
.57148 .40188 m .57071 .40427 L .57039 .40527 L F
.776 .348 .232 r
.57071 .40427 m .57134 .40429 L .57106 .40457 L F
.57077 .4041 m .57134 .40429 L .57071 .40427 L F
.336 .422 .802 r
.56963 .40215 m .57038 .40397 L .57129 .40246 L F
.56963 .40215 m .57129 .40246 L .57148 .40188 L F
.667 .495 .642 r
.63165 .43905 m .63102 .44052 L .62895 .44224 L F
.915 .916 .803 r
.63376 .43552 m .63165 .43905 L .6301 .43777 L F
.658 .529 .696 r
.63376 .43552 m .63392 .43821 L .63165 .43905 L F
.558 .299 .479 r
.63165 .43905 m .6344 .44087 L .63102 .44052 L F
.63165 .43905 m .63392 .43821 L .6344 .44087 L F
.891 .76 .71 r
.21912 .57776 m .21554 .57917 L .215 .57746 L F
.412 0 0 r
.36759 .71201 m .36941 .71042 L .37048 .71148 L F
.376 0 .005 r
.36941 .71042 m .37209 .71024 L .37048 .71148 L F
.322 .106 .422 r
.31235 .55827 m .31001 .5615 L .31019 .55894 L F
.09 0 .092 r
.32433 .53366 m .32576 .53304 L .32719 .53085 L F
.513 .324 .562 r
.32355 .53624 m .32576 .53304 L .32433 .53366 L F
.855 .996 .764 r
.33017 .55694 m .32983 .55886 L .33235 .55566 L F
.584 .413 .616 r
.33235 .55566 m .32983 .55886 L .33253 .55822 L F
.569 .137 .181 r
.33533 .58405 m .33744 .58545 L .33854 .58438 L F
0 .274 .779 r
.33587 .5838 m .33744 .58545 L .33533 .58405 L F
.33672 .58436 m .33744 .58545 L .33587 .5838 L F
.674 .505 .649 r
.33744 .58545 m .34043 .58367 L .33854 .58438 L F
.34043 .58367 m .34088 .5834 L .34059 .58352 L F
.34043 .58367 m .34059 .58352 L .33854 .58438 L F
.483 .103 .242 r
.33453 .58386 m .33559 .58694 L .33763 .58619 L F
.674 .505 .649 r
.33744 .58545 m .34014 .58674 L .34088 .5834 L F
0 .309 .687 r
.33909 .58614 m .34014 .58674 L .33744 .58545 L F
.483 .103 .242 r
.33835 .58554 m .33763 .58619 L .33882 .58575 L F
0 .309 .687 r
.33835 .5855 m .33672 .58436 L .33622 .58362 L F
0 .274 .779 r
.33622 .58362 m .33672 .58436 L .33587 .5838 L F
.44 .41 .729 r
.33453 .58386 m .33786 .58515 L .33622 .58362 L F
.33786 .58515 m .33911 .58564 L .33622 .58362 L F
0 .309 .687 r
.33821 .58548 m .33744 .58545 L .33672 .58436 L F
.33909 .58614 m .33877 .58601 L .33821 .58548 L F
.33877 .58601 m .33744 .58545 L .33821 .58548 L F
.33909 .58614 m .33672 .58436 L .33835 .5855 L F
.593 .374 .552 r
.33911 .58564 m .33909 .58614 L .33835 .5855 L F
.483 .103 .242 r
.33844 .58551 m .33847 .58552 L .33799 .58521 L F
.33799 .58521 m .33852 .58555 L .33911 .58564 L F
.432 0 0 r
.33896 .5857 m .33909 .58614 L .33911 .58564 L F
.523 .38 .629 r
.33896 .5857 m .33909 .58614 L .33906 .58573 L F
.33835 .5855 m .33909 .58614 L .33896 .5857 L F
.432 0 0 r
.33559 .58694 m .33909 .58614 L .33896 .5857 L F
.483 .103 .242 r
.33852 .58555 m .33882 .58575 L .33896 .5857 L F
.33852 .58555 m .33896 .5857 L .33911 .58564 L F
.593 .374 .552 r
.33911 .58564 m .33835 .5855 L .33622 .58362 L F
.53 .396 .643 r
.33885 .58253 m .33911 .58564 L .33622 .58362 L F
.523 .38 .629 r
.33622 .58362 m .33835 .5855 L .33885 .58253 L F
.483 .103 .242 r
.33854 .58563 m .33882 .58575 L .33786 .58515 L F
.523 .38 .629 r
.33835 .5855 m .33906 .58573 L .33885 .58253 L F
.483 .103 .242 r
.33786 .58515 m .33844 .58551 L .33799 .58521 L F
.33844 .58551 m .33882 .58575 L .33847 .58552 L F
.33453 .58386 m .33854 .58563 L .33786 .58515 L F
.33453 .58386 m .33763 .58619 L .33835 .58554 L F
.645 .71 .895 r
.27774 .62698 m .27681 .63001 L .27585 .62795 L F
.27774 .62698 m .27942 .62973 L .27681 .63001 L F
.205 0 0 r
.26978 .623 m .26754 .62319 L .26514 .62322 L F
.704 .767 .901 r
.62111 .40493 m .61792 .40701 L .61692 .40407 L F
.47 .303 .572 r
.39536 .67004 m .39622 .67142 L .39317 .66938 L F
.664 .956 .946 r
.64519 .40188 m .64359 .40387 L .64648 .40291 L F
.64519 .40188 m .64266 .40336 L .64359 .40387 L F
.979 .743 .332 r
.4034 .55684 m .40423 .55563 L .40281 .55484 L F
.4034 .55684 m .40411 .55858 L .40423 .55563 L F
.361 .093 .366 r
.39485 .65973 m .39401 .66239 L .39192 .66274 L F
.978 .859 .473 r
.3934 .66195 m .39401 .66239 L .39485 .65973 L F
.302 .772 .937 r
.39578 .66209 m .39401 .66239 L .3934 .66195 L F
.39593 .6621 m .39401 .66239 L .39578 .66209 L F
.361 .093 .366 r
.39192 .66274 m .39401 .66239 L .39188 .66278 L F
.978 .859 .473 r
.3934 .66195 m .39485 .65973 L .39562 .6581 L F
.715 .6 .727 r
.29271 .54255 m .29682 .54536 L .29602 .53935 L F
.509 .409 .677 r
.29271 .54255 m .29622 .54632 L .29682 .54536 L F
0 0 .499 r
.29602 .53935 m .29682 .54536 L .29738 .54103 L F
.207 0 0 r
.29941 .5451 m .29734 .54645 L .29735 .54613 L F
.29734 .54645 m .29548 .54765 L .29634 .54696 L F
.29734 .54645 m .29634 .54696 L .29735 .54613 L F
.29941 .5451 m .29784 .54706 L .29548 .54765 L F
.554 .509 .76 r
.29869 .54557 m .29921 .54549 L .29945 .54025 L F
.47 .093 .24 r
.30332 .54274 m .30207 .545 L .29941 .5451 L F
.554 .509 .76 r
.29921 .54549 m .302 .54508 L .30158 .54428 L F
.29921 .54549 m .30158 .54428 L .29945 .54025 L F
.129 0 0 r
.29682 .54536 m .29869 .54557 L .29738 .54103 L F
.29682 .54536 m .29622 .54632 L .29869 .54557 L F
.305 .629 .962 r
.36637 .50923 m .36556 .51055 L .36418 .50929 L F
.36637 .50923 m .36771 .51075 L .36556 .51055 L F
.298 .067 .385 r
.35841 .52959 m .36104 .52622 L .35886 .52701 L F
0 .056 .585 r
.40953 .58871 m .40854 .59039 L .40795 .58642 L F
.704 .49 0 r
.40864 .59118 m .40854 .59039 L .40953 .58871 L F
.40864 .59118 m .40894 .59307 L .40854 .59039 L F
0 0 .204 r
.36549 .55665 m .36545 .55642 L .36778 .55516 L F
.595 .873 .55 r
.21869 .5462 m .21982 .54474 L .22137 .54327 L F
0 0 0 r
.22137 .54327 m .22128 .54376 L .22374 .54282 L F
.22137 .54327 m .21982 .54474 L .22128 .54376 L F
.461 .175 .392 r
.37423 .52919 m .37185 .53016 L .37212 .52766 L F
.547 .12 .182 r
.37611 .52748 m .37423 .52919 L .37212 .52766 L F
.568 .87 .995 r
.24828 .53079 m .24377 .53085 L .24661 .53045 L F
.663 .948 .956 r
.25025 .52949 m .24828 .53079 L .24661 .53045 L F
.414 .136 .38 r
.32808 .57067 m .33101 .5677 L .32858 .56823 L F
.877 .821 .789 r
.60852 .39941 m .61032 .4009 L .60781 .40446 L F
.576 .635 .872 r
.61142 .39705 m .61032 .4009 L .60852 .39941 L F
.61142 .39705 m .61302 .40027 L .61032 .4009 L F
.941 .964 .704 r
.72574 .30176 m .72572 .30297 L .72479 .30458 L F
.807 .907 .91 r
.72897 .29991 m .72572 .30297 L .72574 .30176 L F
.548 .233 .386 r
.36711 .54939 m .36934 .55126 L .36673 .55146 L F
.488 .416 .702 r
.37812 .59979 m .38133 .60188 L .38044 .59924 L F
.37812 .59979 m .3788 .60381 L .38133 .60188 L F
.316 .781 .939 r
.39188 .66278 m .3934 .66195 L .39004 .65965 L F
.39188 .66278 m .39401 .66239 L .3934 .66195 L F
.3934 .66195 m .39401 .66239 L .39188 .66278 L F
.725 .717 .843 r
.39161 .66513 m .39401 .66239 L .39188 .66278 L F
.316 .781 .939 r
.3934 .66195 m .39188 .66278 L .3902 .66454 L F
.482 .55 .849 r
.32739 .58047 m .33121 .58295 L .33138 .58014 L F
.63 .374 .512 r
.33138 .58014 m .33448 .58221 L .33424 .57953 L F
.33138 .58014 m .33121 .58295 L .33448 .58221 L F
.587 .907 .981 r
.28925 .52368 m .28998 .52213 L .29162 .52283 L F
.28925 .52368 m .28764 .52315 L .28998 .52213 L F
.134 0 .325 r
.40933 .57989 m .40876 .58242 L .40622 .58359 L F
0 0 .514 r
.40876 .58242 m .40795 .58642 L .40622 .58359 L F
.669 .52 .674 r
.3903 .61027 m .38629 .61145 L .3883 .60877 L F
.966 .88 .698 r
.60664 .4125 m .60839 .41333 L .60666 .41641 L F
.668 .659 .832 r
.71565 .35715 m .71184 .3545 L .71426 .35314 L F
.348 .331 .699 r
.71695 .35252 m .71565 .35715 L .71426 .35314 L F
.71695 .35252 m .71787 .35649 L .71565 .35715 L F
0 0 0 r
.71565 .35715 m .71695 .35733 L .71446 .35843 L F
.71565 .35715 m .71787 .35649 L .71695 .35733 L F
.165 .426 .863 r
.36782 .62909 m .36887 .63057 L .37016 .63051 L F
.15 .506 .911 r
.37016 .63051 m .36887 .63057 L .3665 .62831 L F
.787 .657 .719 r
.71211 .31551 m .71661 .31365 L .71499 .31211 L F
.71211 .31551 m .71563 .31724 L .71661 .31365 L F
.832 .804 .824 r
.71499 .31211 m .71661 .31365 L .71911 .31097 L F
.092 0 0 r
.28984 .60252 m .29071 .60381 L .29162 .60197 L F
.28984 .60252 m .28864 .60475 L .29071 .60381 L F
.502 .193 .375 r
.37877 .56138 m .38136 .56101 L .3821 .55831 L F
0 .352 .825 r
.3821 .55831 m .38234 .55765 L .38052 .55658 L F
0 0 0 r
.3821 .55831 m .38136 .56101 L .38234 .55765 L F
.33199 .52686 m .33105 .52736 L .33217 .52732 L F
.693 .83 .949 r
.37098 .55802 m .37297 .55951 L .37469 .55783 L F
.577 .867 .995 r
.37292 .5571 m .37098 .55802 L .37469 .55783 L F
.536 .206 .357 r
.37098 .55802 m .37212 .55896 L .37292 .5571 L F
.37212 .55896 m .37304 .55972 L .37297 .55815 L F
.37212 .55896 m .37297 .55815 L .37292 .5571 L F
.733 .991 .846 r
.37297 .55951 m .37109 .55994 L .36981 .56194 L F
.37109 .55994 m .37041 .56009 L .37018 .5608 L F
.37109 .55994 m .37018 .5608 L .36981 .56194 L F
0 0 0 r
.36997 .5621 m .36981 .56194 L .37041 .56009 L F
.36997 .5621 m .36959 .56521 L .36981 .56194 L F
.639 .698 .889 r
.23593 .54832 m .23885 .54674 L .23735 .5479 L F
.564 .871 .995 r
.23621 .54668 m .23593 .54832 L .23735 .5479 L F
.23621 .54668 m .23356 .5475 L .23593 .54832 L F
.217 .091 .486 r
.19226 .57721 m .19381 .57377 L .19222 .57454 L F
.173 .397 .839 r
.25735 .614 m .25678 .61562 L .2551 .61255 L F
.78 .958 .64 r
.25735 .614 m .25541 .61685 L .25678 .61562 L F
.468 .3 .569 r
.71412 .33472 m .71148 .33833 L .71416 .33746 L F
.462 .284 .553 r
.71148 .33833 m .71219 .34051 L .71416 .33746 L F
.832 .804 .824 r
.71499 .31211 m .71911 .31097 L .71792 .30964 L F
.808 .954 .912 r
.71911 .31097 m .72023 .30815 L .71792 .30964 L F
.71911 .31097 m .72091 .30936 L .72023 .30815 L F
.693 .315 .327 r
.31021 .65226 m .30712 .6503 L .30636 .65302 L F
.016 0 0 r
.32825 .53145 m .3299 .53076 L .33105 .52736 L F
0 0 0 r
.33105 .52736 m .3299 .53076 L .33217 .52732 L F
.528 .733 .968 r
.33288 .55358 m .33235 .55566 L .33083 .55197 L F
.33288 .55358 m .33478 .55494 L .33235 .55566 L F
.441 .295 .586 r
.33235 .55566 m .33288 .55358 L .33017 .55694 L F
.33235 .55566 m .33478 .55494 L .33288 .55358 L F
.33235 .55566 m .33464 .55768 L .33478 .55494 L F
.427 .295 .598 r
.33253 .55822 m .33464 .55768 L .33235 .55566 L F
.441 .295 .586 r
.33235 .55566 m .33464 .55768 L .33478 .55494 L F
.523 .318 .543 r
.34742 .64084 m .35011 .64023 L .35024 .63756 L F
.663 .616 .791 r
.35011 .64023 m .35222 .63739 L .35024 .63756 L F
.72 .981 .907 r
.19028 .60777 m .18989 .60935 L .1917 .60812 L F
.648 .821 .966 r
.72036 .31867 m .71661 .31774 L .71896 .31731 L F
.539 .848 .998 r
.72171 .31674 m .72036 .31867 L .71896 .31731 L F
.651 .395 .519 r
.71847 .31959 m .7216 .31683 L .71896 .31731 L F
.7216 .31683 m .72171 .31674 L .71896 .31731 L F
.648 .821 .966 r
.71661 .31774 m .71617 .31764 L .71896 .31731 L F
.539 .848 .998 r
.72171 .31674 m .72317 .31773 L .72036 .31867 L F
.573 .758 .965 r
.72317 .31773 m .72036 .31867 L .72032 .32155 L F
.346 0 0 r
.31427 .53425 m .31213 .53474 L .31165 .53395 L F
.765 .996 .836 r
.31439 .53256 m .31213 .53474 L .31427 .53425 L F
.712 .978 .769 r
.3131 .53307 m .31213 .53474 L .31439 .53256 L F
.41 .384 .719 r
.3131 .53307 m .31241 .5352 L .31213 .53474 L F
.31241 .5352 m .31175 .53722 L .31213 .53474 L F
.346 0 0 r
.31165 .53395 m .31213 .53474 L .30866 .53361 L F
.901 .983 .786 r
.63622 .43219 m .6329 .43452 L .6352 .43178 L F
.63622 .43219 m .63376 .43552 L .6329 .43452 L F
.439 .868 .928 r
.63622 .43219 m .63771 .43102 L .63951 .42977 L F
.63622 .43219 m .6352 .43178 L .63771 .43102 L F
0 0 .467 r
.32512 .55479 m .32614 .55949 L .32629 .55665 L F
.874 .992 .81 r
.32614 .55949 m .32393 .55962 L .32629 .55665 L F
0 0 0 r
.32546 .55959 m .32704 .55785 L .32629 .55665 L F
.32704 .55785 m .32908 .55561 L .32629 .55665 L F
0 0 .467 r
.32512 .55478 m .32512 .55479 L .32629 .55665 L F
.621 .275 .362 r
.35481 .5319 m .35841 .52959 L .35627 .53024 L F
.191 .217 .658 r
.34742 .64084 m .34984 .64296 L .35011 .64023 L F
.34742 .64084 m .34843 .64346 L .34984 .64296 L F
.638 .215 0 r
.39891 .54553 m .39854 .54472 L .39801 .54407 L F
0 0 .56 r
.40007 .54728 m .39905 .54662 L .39854 .54472 L F
.638 .215 0 r
.39909 .54581 m .39854 .54472 L .39891 .54553 L F
0 0 .247 r
.39854 .54472 m .39905 .54662 L .39841 .54444 L F
.39854 .54472 m .39841 .54444 L .39788 .54262 L F
.914 .547 .32 r
.32653 .68549 m .32515 .68606 L .32626 .68409 L F
.32653 .68549 m .32727 .68771 L .32515 .68606 L F
.863 .505 .372 r
.61921 .44107 m .62246 .44237 L .6226 .44438 L F
.723 .47 .543 r
.62638 .44195 m .6226 .44438 L .62246 .44237 L F
.404 0 0 r
.71617 .31764 m .71563 .31724 L .71211 .31551 L F
.827 .698 .722 r
.35428 .64373 m .35569 .64707 L .35248 .64603 L F
.801 .734 .789 r
.35248 .64603 m .35569 .64707 L .35259 .64966 L F
0 .159 .691 r
.35524 .64601 m .35569 .64707 L .35642 .64591 L F
.35428 .64373 m .35569 .64707 L .35642 .64591 L F
0 0 0 r
.35718 .64585 m .35589 .64625 L .35621 .64629 L F
.463 .283 .55 r
.35666 .64019 m .35428 .64373 L .35659 .64293 L F
0 .159 .691 r
.35428 .64373 m .35642 .64591 L .35659 .64293 L F
.514 .347 .592 r
.35659 .64293 m .35894 .63962 L .35666 .64019 L F
.35659 .64293 m .35919 .64229 L .35894 .63962 L F
.468 .227 .465 r
.35861 .6452 m .35659 .64293 L .35642 .64591 L F
.35861 .6452 m .35919 .64229 L .35659 .64293 L F
.955 .718 .54 r
.35663 .64112 m .35861 .6452 L .35539 .64474 L F
0 0 0 r
.35718 .64585 m .35642 .64591 L .35589 .64625 L F
.35861 .6452 m .35642 .64591 L .35718 .64585 L F
0 .159 .691 r
.35428 .64373 m .35524 .64601 L .35642 .64591 L F
.888 .81 .766 r
.35248 .64603 m .35428 .64373 L .35291 .64394 L F
.35248 .64603 m .35291 .64394 L .35165 .64503 L F
.827 .977 .681 r
.35214 .64518 m .35428 .64373 L .35248 .64603 L F
.69 .205 .092 r
.35642 .64591 m .35428 .64373 L .35214 .64518 L F
.35642 .64591 m .35214 .64518 L .35539 .64474 L F
0 0 0 r
.35861 .6452 m .35479 .64694 L .35687 .64675 L F
.35861 .6452 m .35687 .64675 L .35539 .64474 L F
.847 .887 .458 r
.35663 .64112 m .35539 .64474 L .35543 .64305 L F
0 0 .539 r
.35543 .64305 m .35539 .64474 L .35657 .64635 L F
.35672 .64637 m .35657 .64635 L .35687 .64675 L F
.35543 .64305 m .35657 .64635 L .35672 .64637 L F
0 0 0 r
.35621 .64629 m .35589 .64625 L .35479 .64694 L F
.807 .658 .698 r
.37192 .5396 m .36882 .54016 L .37099 .53708 L F
.616 .541 .747 r
.37068 .54179 m .36882 .54016 L .37192 .5396 L F
.679 .441 .554 r
.37447 .5396 m .37068 .54179 L .37192 .5396 L F
0 0 .013 r
.32719 .53085 m .32576 .53304 L .32825 .53145 L F
0 0 0 r
.37121 .57344 m .37514 .57139 L .37095 .57092 L F
.723 .567 .677 r
.37759 .57163 m .3754 .57362 L .37514 .57139 L F
.995 .866 .58 r
.3754 .57362 m .37496 .56957 L .37514 .57139 L F
.604 .428 .617 r
.37834 .56808 m .37759 .57163 L .37514 .57139 L F
.865 .842 .82 r
.29157 .62554 m .28767 .62755 L .28974 .6238 L F
.587 .78 .972 r
.29422 .62307 m .29157 .62554 L .28974 .6238 L F
.29422 .62307 m .29428 .62471 L .29157 .62554 L F
.527 .44 .7 r
.22269 .56252 m .22277 .56516 L .22511 .56455 L F
.338 .672 .976 r
.22269 .5631 m .224 .56447 L .22061 .56302 L F
.224 .56447 m .22439 .56488 L .22377 .56458 L F
.224 .56447 m .22377 .56458 L .22061 .56302 L F
.708 .296 .263 r
.22246 .56514 m .22511 .56455 L .22277 .56516 L F
.22001 .56504 m .22345 .56471 L .22246 .56514 L F
.22345 .56471 m .22511 .56455 L .22246 .56514 L F
.333 .001 .244 r
.24207 .54982 m .24386 .55084 L .24522 .54903 L F
.24207 .54982 m .24157 .5516 L .24386 .55084 L F
.754 .78 .875 r
.63659 .40148 m .63123 .40521 L .63203 .40083 L F
.883 .964 .842 r
.35833 .66568 m .35719 .66912 L .35576 .66853 L F
.35833 .66568 m .35968 .66616 L .35719 .66912 L F
0 0 0 r
.21586 .54919 m .21755 .54801 L .21869 .5462 L F
.21869 .5462 m .21909 .54715 L .21982 .54474 L F
.21869 .5462 m .21755 .54801 L .21909 .54715 L F
.45 .14 .347 r
.29997 .60801 m .29662 .61118 L .29789 .60877 L F
.265 .264 .671 r
.19227 .59029 m .1936 .58961 L .19326 .58608 L F
.339 .205 .548 r
.19197 .59284 m .1936 .58961 L .19227 .59029 L F
.601 .947 .798 r
.25414 .53841 m .25035 .54073 L .25335 .5396 L F
.076 0 .133 r
.25234 .5398 m .2517 .5402 L .25035 .54073 L F
.266 .755 .67 r
.25335 .5396 m .25035 .54073 L .24889 .54131 L F
.076 0 .133 r
.2517 .5402 m .25058 .54088 L .25035 .54073 L F
.266 .755 .67 r
.24889 .54131 m .25035 .54073 L .24854 .54144 L F
.455 .841 .984 r
.25575 .53906 m .25414 .53841 L .25335 .5396 L F
.467 .864 .682 r
.35306 .66843 m .35098 .66982 L .34893 .6709 L F
.86 .992 .739 r
.36023 .57314 m .35963 .57506 L .36244 .57417 L F
.36023 .57314 m .3579 .57604 L .35963 .57506 L F
.2 .416 .848 r
.35963 .57506 m .36241 .57666 L .36244 .57417 L F
.769 .42 .395 r
.37776 .58386 m .37638 .58588 L .3743 .58319 L F
.32 .133 .463 r
.37985 .58056 m .38006 .5831 L .37776 .58386 L F
.586 .349 .524 r
.38006 .5831 m .37638 .58588 L .37776 .58386 L F
.48 .031 .106 r
.25674 .62137 m .25934 .62137 L .26089 .61981 L F
.384 .688 .979 r
.64382 .39757 m .64262 .3991 L .64088 .39828 L F
.64382 .39757 m .64546 .39897 L .64262 .3991 L F
.786 .532 0 r
.40487 .56083 m .4057 .5648 L .40525 .56213 L F
.818 .418 0 r
.42194 .56038 m .4219 .55867 L .42036 .5569 L F
.42194 .56038 m .42338 .56233 L .4219 .55867 L F
.712 .664 .801 r
.25145 .61155 m .25333 .6162 L .25102 .61611 L F
.677 .646 .812 r
.2551 .61255 m .25333 .6162 L .25145 .61155 L F
.562 .568 .817 r
.31229 .53832 m .31556 .53998 L .31449 .53739 L F
.7 .971 .754 r
.29961 .63257 m .29994 .6332 L .30223 .63099 L F
.845 .861 .409 r
.29843 .63622 m .29994 .6332 L .29961 .63257 L F
.101 .656 .722 r
.2464 .54192 m .24289 .54231 L .24414 .54205 L F
.447 .497 .818 r
.3788 .60381 m .38145 .6053 L .38133 .60188 L F
.61 .905 .984 r
.31464 .65944 m .31585 .66031 L .31811 .6592 L F
.866 .759 .742 r
.6099 .42321 m .61186 .42331 L .6098 .42618 L F
.57 .659 .897 r
.3464 .59636 m .34472 .59892 L .34451 .59656 L F
.069 0 0 r
.3464 .59636 m .34451 .59656 L .34349 .59844 L F
.641 .194 .175 r
.36256 .51493 m .35828 .51618 L .35862 .51379 L F
.36256 .51493 m .36117 .51666 L .35828 .51618 L F
.629 .18 .167 r
.3648 .51673 m .36117 .51666 L .36256 .51493 L F
.915 .916 .803 r
.63376 .43552 m .6301 .43777 L .6329 .43452 L F
.482 .393 .679 r
.63686 .43789 m .63392 .43821 L .63376 .43552 L F
.666 .603 .775 r
.23891 .60896 m .23486 .60604 L .23724 .60543 L F
.627 .634 .838 r
.23966 .60466 m .23891 .60896 L .23724 .60543 L F
.23966 .60466 m .24126 .60883 L .23891 .60896 L F
.351 .499 .866 r
.24189 .61135 m .23891 .60896 L .24126 .60883 L F
.602 .346 .501 r
.63102 .44052 m .6289 .44438 L .62895 .44224 L F
.63102 .44052 m .63164 .44398 L .6289 .44438 L F
.568 .361 .56 r
.6344 .44087 m .63164 .44398 L .63102 .44052 L F
.527 .44 .7 r
.22269 .56252 m .22511 .56455 L .22413 .56204 L F
.528 .333 .56 r
.36355 .58319 m .36096 .58636 L .36166 .58433 L F
.36355 .58319 m .36096 .58636 L .36166 .58433 L F
.701 .896 .967 r
.36398 .62393 m .35992 .62488 L .36587 .62605 L F
.957 .712 .525 r
.36418 .62524 m .36398 .62393 L .36587 .62605 L F
.491 .682 .951 r
.36014 .62458 m .36587 .62605 L .35992 .62488 L F
.36418 .62524 m .36587 .62605 L .36014 .62458 L F
.957 .712 .525 r
.36418 .62524 m .36485 .62505 L .36398 .62393 L F
.36575 .62549 m .36665 .62455 L .36418 .62524 L F
.491 .682 .951 r
.36131 .62304 m .36587 .62605 L .36086 .62363 L F
.957 .712 .525 r
.36446 .62686 m .36418 .62524 L .36587 .62605 L F
.36442 .62688 m .36442 .62683 L .36446 .62686 L F
.36442 .62683 m .36418 .62524 L .36446 .62686 L F
.865 .456 .252 r
.36442 .62688 m .36587 .62605 L .36478 .62533 L F
.491 .682 .951 r
.36086 .62363 m .36418 .62524 L .36014 .62458 L F
.865 .456 .252 r
.36442 .62688 m .36478 .62533 L .36131 .62304 L F
.957 .712 .525 r
.36442 .62688 m .36575 .62549 L .36418 .62524 L F
.36442 .62688 m .36656 .62754 L .36665 .62455 L F
.647 .439 .587 r
.36656 .62754 m .3692 .62636 L .36665 .62455 L F
.988 .887 .559 r
.36556 .62829 m .3665 .62831 L .36656 .62754 L F
.921 .556 .315 r
.36556 .62829 m .36656 .62754 L .36442 .62688 L F
.406 .513 .854 r
.36758 .6282 m .36637 .62826 L .36391 .62502 L F
.36637 .62826 m .36556 .62829 L .36506 .6273 L F
.36637 .62826 m .36506 .6273 L .36391 .62502 L F
.957 .712 .525 r
.36485 .62505 m .36665 .62455 L .36505 .62418 L F
.36485 .62505 m .36505 .62418 L .36398 .62393 L F
.414 .278 .586 r
.30795 .54935 m .31015 .55145 L .31031 .549 L F
.30795 .54935 m .3082 .55229 L .31015 .55145 L F
.109 0 0 r
.35754 .53649 m .35588 .53809 L .35359 .53867 L F
.466 .3 .571 r
.35996 .53335 m .36016 .53597 L .35754 .53649 L F
.285 0 0 r
.36016 .53597 m .35588 .53809 L .35754 .53649 L F
0 .22 .732 r
.2942 .64404 m .29267 .6427 L .29379 .64209 L F
.206 .276 .715 r
.22416 .59474 m .22298 .59686 L .22205 .59281 L F
.228 .303 .734 r
.22416 .59474 m .22529 .5988 L .22298 .59686 L F
.723 .47 .543 r
.62638 .44195 m .6262 .44409 L .6226 .44438 L F
.686 .373 .44 r
.62638 .44195 m .6289 .44438 L .6262 .44409 L F
.62638 .44195 m .62895 .44224 L .6289 .44438 L F
.03 0 .243 r
.38317 .5934 m .38132 .59687 L .3826 .5958 L F
.471 .134 .314 r
.38493 .59542 m .38317 .5934 L .3826 .5958 L F
.38493 .59542 m .38566 .59314 L .38317 .5934 L F
0 0 .196 r
.3826 .5958 m .38132 .59687 L .38044 .59924 L F
.355 .677 .977 r
.36189 .50755 m .3611 .50911 L .35968 .50733 L F
.36189 .50755 m .36418 .50929 L .3611 .50911 L F
.177 .246 .697 r
.37932 .56781 m .3803 .57009 L .37834 .56808 L F
.46 .292 .566 r
.3803 .57009 m .37759 .57163 L .37834 .56808 L F
.613 .596 .809 r
.36913 .60816 m .36876 .61193 L .36609 .61242 L F
.36913 .60816 m .37074 .61203 L .36876 .61193 L F
0 0 .333 r
.36876 .61193 m .36936 .6154 L .36983 .61381 L F
.36876 .61193 m .36983 .61381 L .36609 .61242 L F
.838 .878 .872 r
.71546 .29934 m .71672 .30251 L .71276 .30207 L F
.891 .806 .758 r
.71276 .30207 m .71672 .30251 L .71356 .30579 L F
.355 .141 .445 r
.3373 .65287 m .33444 .65685 L .33687 .65519 L F
0 0 .523 r
.33444 .65685 m .3358 .65793 L .33687 .65519 L F
.683 .499 .632 r
.32472 .64351 m .32832 .64367 L .32805 .64243 L F
.541 .407 .647 r
.32805 .64243 m .33098 .64267 L .33053 .64042 L F
.32805 .64243 m .32832 .64367 L .33098 .64267 L F
.181 0 0 r
.22533 .55598 m .22196 .55581 L .22395 .55554 L F
.467 .321 .598 r
.35222 .59231 m .34964 .59019 L .35216 .58961 L F
.35222 .59231 m .34982 .59314 L .34964 .59019 L F
.578 .381 .578 r
.35222 .59231 m .34929 .59545 L .34982 .59314 L F
.861 .546 .454 r
.35011 .59438 m .34989 .59157 L .3497 .59154 L F
.181 0 0 r
.3507 .5907 m .34964 .59019 L .34917 .59186 L F
.35216 .58961 m .34917 .59186 L .34989 .59157 L F
.874 .719 .687 r
.34665 .59106 m .34917 .59186 L .34746 .59052 L F
.34665 .59106 m .34746 .59052 L .3457 .58916 L F
0 .028 .574 r
.3472 .5893 m .34665 .59106 L .3457 .58916 L F
.106 0 .366 r
.3472 .5893 m .34568 .59171 L .34665 .59106 L F
.34568 .59171 m .34479 .59313 L .34665 .59106 L F
.874 .719 .687 r
.34665 .59106 m .34989 .59157 L .34917 .59186 L F
.861 .546 .454 r
.34833 .59267 m .3497 .59154 L .34665 .59106 L F
.047 0 0 r
.3464 .59636 m .34982 .59314 L .34929 .59545 L F
.861 .546 .454 r
.35011 .59438 m .3497 .59154 L .34833 .59267 L F
.181 0 0 r
.35216 .58961 m .35197 .58965 L .3507 .5907 L F
.35197 .58965 m .34964 .59019 L .3507 .5907 L F
.953 .753 .596 r
.37611 .52748 m .3764 .53038 L .37423 .52919 L F
.181 0 0 r
.32358 .52044 m .32232 .52189 L .32021 .52226 L F
.437 .415 .737 r
.32021 .52226 m .32232 .52189 L .32206 .52103 L F
.52 0 0 r
.32358 .52044 m .31999 .52022 L .32361 .5198 L F
.31999 .52022 m .31981 .52015 L .32361 .5198 L F
.181 0 0 r
.32358 .52044 m .32021 .52226 L .31944 .52018 L F
.437 .415 .737 r
.32098 .52061 m .32206 .52103 L .32156 .51936 L F
.32021 .52226 m .32206 .52103 L .32098 .52061 L F
.52 0 0 r
.31999 .52022 m .31944 .52018 L .31981 .52015 L F
0 .176 .679 r
.32754 .51525 m .32875 .51669 L .32649 .51497 L F
.32754 .51525 m .32649 .51497 L .32644 .51492 L F
.32754 .51525 m .32644 .51492 L .32477 .51606 L F
.354 0 0 r
.32536 .51461 m .32754 .51525 L .32591 .51572 L F
.32536 .51461 m .32591 .51572 L .32477 .51606 L F
0 .071 .623 r
.32325 .51106 m .32448 .51286 L .32536 .51461 L F
.32448 .51286 m .32593 .51495 L .32536 .51461 L F
.555 .504 .753 r
.32593 .51495 m .3281 .51539 L .32754 .51525 L F
0 .245 .756 r
.32988 .51576 m .32875 .51669 L .32754 .51525 L F
.555 .504 .753 r
.3281 .51539 m .32988 .51576 L .32754 .51525 L F
.549 .35 .563 r
.2353 .56288 m .23259 .56754 L .23243 .564 L F
.455 .454 .767 r
.25464 .54863 m .25775 .55133 L .25871 .54915 L F
.452 .799 .998 r
.20202 .59835 m .20417 .59944 L .20432 .59797 L F
.035 .378 .843 r
.20417 .59944 m .20533 .59959 L .20432 .59797 L F
.535 .334 .555 r
.38363 .70035 m .38359 .70366 L .38086 .70377 L F
.356 .052 .305 r
.38675 .69789 m .38583 .69988 L .38363 .70035 L F
.441 .261 .54 r
.38583 .69988 m .38359 .70366 L .38363 .70035 L F
0 0 0 r
.39514 .60365 m .39242 .60569 L .39407 .60443 L F
.96 .674 .448 r
.39242 .60569 m .39262 .60947 L .39067 .60755 L F
.652 .596 .779 r
.39514 .60365 m .39567 .60593 L .39242 .60569 L F
.558 .351 .556 r
.39535 .60847 m .39242 .60569 L .39567 .60593 L F
.39535 .60847 m .39262 .60947 L .39242 .60569 L F
.682 .954 .952 r
.31552 .57094 m .31144 .57195 L .31449 .57121 L F
0 0 0 r
.31552 .57094 m .31663 .57008 L .31753 .56742 L F
.433 .863 .75 r
.31552 .57094 m .31449 .57121 L .31663 .57008 L F
.321 0 .078 r
.31894 .54529 m .32282 .5426 L .31947 .54316 L F
.31894 .54529 m .321 .54512 L .32282 .5426 L F
.593 .607 .835 r
.32282 .5426 m .32556 .54256 L .32368 .53895 L F
0 0 0 r
.32282 .5426 m .32416 .54209 L .32556 .54256 L F
.486 .263 .5 r
.32556 .54256 m .32263 .54689 L .32282 .5426 L F
0 0 0 r
.32282 .5426 m .321 .54512 L .32416 .54209 L F
.694 .206 .085 r
.33478 .55494 m .33682 .55687 L .33876 .55567 L F
.071 0 0 r
.33876 .55567 m .33939 .55631 L .34164 .55608 L F
.33876 .55567 m .33682 .55687 L .33939 .55631 L F
0 0 0 r
.21586 .54919 m .21422 .55101 L .21755 .54801 L F
.757 .52 .574 r
.34764 .60217 m .34765 .60475 L .34427 .60416 L F
0 .313 .772 r
.34427 .60416 m .3458 .60435 L .34466 .6039 L F
.34427 .60416 m .34466 .6039 L .34354 .60345 L F
0 0 0 r
.34427 .60416 m .34275 .6055 L .34392 .60439 L F
.34427 .60416 m .34392 .60439 L .34569 .60271 L F
.375 .314 .661 r
.34701 .59844 m .34569 .60271 L .34472 .59892 L F
.34701 .59844 m .34764 .60217 L .34569 .60271 L F
.757 .52 .574 r
.34764 .60217 m .34427 .60416 L .34569 .60271 L F
.684 .542 .686 r
.32472 .64351 m .32656 .64762 L .32832 .64367 L F
.525 .82 .999 r
.62849 .40967 m .63001 .40781 L .62717 .40876 L F
.62849 .40967 m .63143 .40894 L .63001 .40781 L F
.471 .269 .523 r
.39134 .69352 m .38863 .69727 L .38947 .69475 L F
.517 0 0 r
.31499 .52811 m .31908 .52968 L .31716 .53064 L F
.158 0 .246 r
.31831 .53167 m .31716 .53064 L .31908 .52968 L F
.65 .537 .713 r
.35213 .54576 m .35046 .54911 L .35023 .54646 L F
.35213 .54576 m .35046 .54911 L .35023 .54646 L F
.754 .675 .774 r
.35046 .54911 m .35223 .54535 L .35023 .54646 L F
.35046 .54911 m .34628 .54812 L .35223 .54535 L F
.35046 .54911 m .34778 .55066 L .34628 .54812 L F
.693 .533 .666 r
.35046 .54911 m .34772 .55228 L .34778 .55066 L F
.14 0 .119 r
.29872 .58679 m .30175 .58366 L .29909 .58368 L F
.347 .054 .318 r
.31098 .58656 m .30904 .58714 L .31227 .58382 L F
.117 0 .184 r
.3136 .58498 m .31227 .58382 L .31316 .582 L F
.3136 .58498 m .31098 .58656 L .31227 .58382 L F
.581 .834 .993 r
.33753 .67392 m .33511 .67474 L .33355 .67387 L F
.712 .664 .801 r
.25145 .61155 m .25102 .61611 L .25113 .61465 L F
.591 .3 .444 r
.25102 .61611 m .25276 .61792 L .25113 .61465 L F
.25102 .61611 m .2501 .6182 L .25276 .61792 L F
.29 .765 .651 r
.266 .53274 m .26527 .53307 L .26725 .5327 L F
.266 .53274 m .26264 .53422 L .26527 .53307 L F
.47 .393 .688 r
.3881 .58996 m .39056 .58637 L .38974 .58579 L F
.373 .129 .41 r
.31861 .63342 m .31643 .63407 L .3188 .6311 L F
0 0 .069 r
.31861 .63342 m .3188 .6311 L .31967 .62875 L F
.702 .662 .808 r
.21622 .58343 m .21452 .5853 L .21348 .58293 L F
.446 .226 .485 r
.6344 .44087 m .63392 .43821 L .63686 .43789 L F
.766 .749 .838 r
.62454 .40502 m .62111 .40493 L .62319 .40341 L F
.699 .758 .898 r
.62319 .40341 m .62709 .40408 L .62454 .40502 L F
.192 .715 .865 r
.26041 .53875 m .25807 .53871 L .25983 .5398 L F
.532 .559 .827 r
.25983 .5398 m .26305 .54212 L .26041 .53875 L F
.566 .786 .982 r
.138 .70594 m .14215 .70654 L .14073 .70521 L F
.14215 .70654 m .138 .70594 L .14073 .70521 L F
.181 .572 .937 r
.14073 .70521 m .14215 .70654 L .14242 .70544 L F
.14242 .70544 m .14215 .70654 L .14073 .70521 L F
.068 0 .072 r
.34857 .56949 m .34967 .56938 L .35108 .56774 L F
.34857 .56949 m .34826 .57012 L .34967 .56938 L F
.791 .758 .823 r
.60614 .40283 m .60781 .40446 L .60518 .40239 L F
.851 .743 .744 r
.60518 .40239 m .60781 .40446 L .60625 .40723 L F
.877 .821 .789 r
.60852 .39941 m .60781 .40446 L .60614 .40283 L F
0 0 0 r
.38976 .56211 m .38904 .56433 L .39061 .5607 L F
.661 .831 .965 r
.3274 .51042 m .32965 .5119 L .3298 .50964 L F
.768 .675 .76 r
.26041 .53875 m .26305 .54212 L .26647 .54011 L F
0 0 .061 r
.33084 .61195 m .33131 .61183 L .33033 .61447 L F
.447 .246 .514 r
.33868 .59197 m .3367 .59018 L .3388 .58963 L F
.33868 .59197 m .33641 .5928 L .3367 .59018 L F
0 0 0 r
.28599 .62048 m .28737 .61904 L .28901 .61789 L F
.423 0 0 r
.34021 .54873 m .3356 .55047 L .33744 .5488 L F
.647 .508 .679 r
.33973 .54618 m .34021 .54873 L .33744 .5488 L F
.708 .2 0 r
.23275 .55138 m .23244 .55342 L .23222 .5513 L F
.23275 .55138 m .23466 .55318 L .23244 .55342 L F
.692 .367 .421 r
.26444 .55753 m .26392 .55572 L .26658 .55558 L F
0 0 0 r
.26829 .55415 m .26658 .55558 L .26893 .55301 L F
.22 0 .182 r
.26829 .55415 m .26444 .55753 L .26658 .55558 L F
.816 .443 .348 r
.69871 .32252 m .70253 .32505 L .69827 .32528 L F
.7 .386 .442 r
.69827 .32528 m .70253 .32505 L .70099 .32609 L F
.72 .477 .558 r
.70475 .32518 m .70099 .32609 L .70253 .32505 L F
.629 .845 .982 r
.57433 .40656 m .57568 .40794 L .57807 .40684 L F
.471 .451 .754 r
.3065 .56424 m .3082 .56797 L .30538 .56814 L F
.3065 .56424 m .30538 .56814 L .30593 .56663 L F
.38 .699 .983 r
.30538 .56814 m .3082 .56797 L .30593 .56663 L F
.94 .659 .479 r
.34846 .70682 m .34634 .70899 L .3455 .7061 L F
.34846 .70682 m .34833 .70939 L .34634 .70899 L F
.627 .461 .639 r
.3607 .56498 m .36352 .56478 L .36299 .56201 L F
0 0 .191 r
.36299 .56201 m .36328 .5627 L .363 .56076 L F
.36299 .56201 m .36352 .56478 L .36328 .5627 L F
.413 .088 .303 r
.38086 .70377 m .38023 .70579 L .37783 .70623 L F
.42 .095 .306 r
.38086 .70377 m .38261 .70523 L .38023 .70579 L F
.459 .085 .241 r
.38359 .70366 m .38261 .70523 L .38086 .70377 L F
.331 0 .149 r
.26392 .55572 m .25993 .55836 L .25924 .55533 L F
.429 0 0 r
.26444 .55753 m .26419 .55874 L .26211 .5579 L F
.661 .113 0 r
.26419 .55874 m .26387 .55849 L .26211 .5579 L F
.331 0 .149 r
.26392 .55572 m .26211 .5579 L .26113 .55757 L F
.692 .367 .421 r
.26444 .55753 m .26211 .5579 L .26392 .55572 L F
.331 0 .149 r
.26113 .55757 m .26211 .5579 L .25993 .55836 L F
.55 .585 .842 r
.25993 .55836 m .26211 .5579 L .26037 .55397 L F
.92 .581 .122 r
.26037 .55397 m .26211 .5579 L .2609 .55623 L F
.661 .113 0 r
.26387 .55849 m .2609 .55623 L .26211 .5579 L F
.332 .406 .788 r
.19197 .59284 m .19327 .59667 L .19484 .59484 L F
.537 .402 .644 r
.33773 .56755 m .33809 .57126 L .33531 .5718 L F
.473 .14 .321 r
.33809 .57126 m .33482 .57351 L .33531 .5718 L F
.449 .413 .727 r
.22482 .58024 m .22346 .58304 L .22266 .58081 L F
.22482 .58024 m .22548 .58262 L .22346 .58304 L F
.443 .162 .39 r
.36629 .57779 m .36597 .57997 L .36355 .5805 L F
.643 .524 .703 r
.36873 .57402 m .3693 .57678 L .36629 .57779 L F
.548 .293 .48 r
.36629 .57779 m .36851 .57982 L .36597 .57997 L F
.36629 .57779 m .3693 .57678 L .36851 .57982 L F
.101 .334 .806 r
.33552 .56365 m .33313 .56212 L .33746 .56203 L F
.78 .501 .514 r
.33999 .5617 m .33552 .56365 L .33746 .56203 L F
.942 .717 .57 r
.34772 .55228 m .34628 .54812 L .34778 .55066 L F
0 .216 .721 r
.22781 .55868 m .22749 .55752 L .22533 .55598 L F
.199 0 0 r
.22781 .55868 m .2287 .55963 L .22749 .55752 L F
.22781 .55868 m .22615 .56036 L .2287 .55963 L F
.628 .511 .702 r
.35101 .56841 m .35418 .57056 L .35448 .56865 L F
.403 .125 .373 r
.35448 .56865 m .35655 .56982 L .35674 .56904 L F
.35448 .56865 m .35418 .57056 L .35655 .56982 L F
.459 .204 .439 r
.35402 .5548 m .35719 .55117 L .35437 .55247 L F
.668 .838 .965 r
.33166 .50827 m .32677 .50775 L .33014 .50454 L F
.023 .223 .729 r
.33239 .50658 m .33166 .50827 L .33014 .50454 L F
.74 .965 .687 r
.33239 .50658 m .3298 .50964 L .33166 .50827 L F
.451 .17 .394 r
.38863 .69727 m .38583 .69988 L .38675 .69789 L F
.485 .83 .997 r
.33193 .66896 m .33414 .67001 L .3369 .66933 L F
.097 0 0 r
.20236 .56204 m .20121 .56352 L .20442 .5612 L F
.444 .124 .328 r
.36011 .56765 m .36352 .56478 L .3607 .56498 L F
.829 .358 .071 r
.71879 .34969 m .71512 .34656 L .71617 .34787 L F
.424 0 0 r
.30032 .63001 m .29945 .62774 L .29999 .6274 L F
0 0 0 r
.33099 .66515 m .33276 .66283 L .32949 .66697 L F
.33099 .66515 m .32949 .66697 L .32922 .66445 L F
0 0 .469 r
.32922 .66445 m .32949 .66697 L .32998 .6676 L F
.801 .966 .911 r
.37803 .65656 m .37728 .65868 L .37608 .65698 L F
.37803 .65656 m .38007 .65638 L .37728 .65868 L F
.637 .443 .603 r
.35102 .52348 m .35212 .52664 L .34833 .52653 L F
0 0 0 r
.35387 .52084 m .35283 .52222 L .35102 .52348 L F
.146 .105 .55 r
.35283 .52222 m .35311 .52578 L .35102 .52348 L F
.017 .085 .592 r
.35102 .52348 m .35311 .52578 L .35212 .52664 L F
.71 .893 .963 r
.3643 .66404 m .36572 .66479 L .36205 .66536 L F
.707 .981 .901 r
.36738 .66266 m .36572 .66479 L .3643 .66404 L F
.36738 .66266 m .36889 .66286 L .36572 .66479 L F
.577 .805 .986 r
.31447 .64563 m .3132 .64726 L .31127 .64607 L F
.756 .716 .815 r
.34786 .51212 m .3523 .51274 L .34922 .51157 L F
0 .539 .72 r
.3523 .51274 m .35316 .51277 L .34922 .51157 L F
.3523 .51274 m .35385 .51286 L .35316 .51277 L F
.774 .965 .663 r
.35316 .51277 m .35143 .51409 L .35252 .51268 L F
0 .505 .846 r
.34922 .51157 m .35223 .51248 L .35273 .51226 L F
.35223 .51248 m .35316 .51277 L .35273 .51226 L F
.772 .997 .825 r
.35273 .51226 m .35316 .51277 L .35397 .5108 L F
0 0 0 r
.35397 .5108 m .3529 .51219 L .35273 .51226 L F
.3529 .51219 m .35143 .51409 L .35273 .51226 L F
.774 .965 .663 r
.35316 .51277 m .35252 .51268 L .35397 .5108 L F
0 .539 .72 r
.35385 .51286 m .35737 .51314 L .35316 .51277 L F
.615 .926 .682 r
.24023 .54532 m .23735 .5479 L .23885 .54674 L F
.047 0 0 r
.35577 .57728 m .35089 .58047 L .35367 .57695 L F
.636 .668 .864 r
.23305 .60291 m .23486 .60604 L .23103 .60473 L F
.588 .645 .875 r
.23724 .60543 m .23486 .60604 L .23305 .60291 L F
.993 .851 .499 r
.35259 .64966 m .34825 .64765 L .34972 .65007 L F
.35259 .64966 m .35248 .64603 L .34825 .64765 L F
0 0 0 r
.35216 .64981 m .35259 .64966 L .34972 .65007 L F
.801 .734 .789 r
.35248 .64603 m .35259 .64966 L .35216 .64981 L F
.535 .452 .709 r
.29686 .5899 m .2997 .58976 L .29872 .58679 L F
.088 0 .21 r
.29737 .59278 m .2997 .58976 L .29686 .5899 L F
.86 .991 .834 r
.1927 .60595 m .19185 .60791 L .19418 .60483 L F
.481 .813 1 r
.19418 .60483 m .19051 .6045 L .19338 .60374 L F
.86 .991 .834 r
.19028 .60777 m .19185 .60791 L .1927 .60595 L F
.19028 .60777 m .19418 .60483 L .19275 .60753 L F
0 0 .12 r
.19348 .60414 m .19275 .60753 L .19388 .60577 L F
.19338 .60374 m .19321 .60475 L .19348 .60414 L F
.19321 .60475 m .19275 .60753 L .19348 .60414 L F
.86 .991 .834 r
.19028 .60777 m .1917 .60812 L .19185 .60791 L F
.704 .17 0 r
.38834 .62178 m .39273 .62407 L .38998 .62482 L F
.725 .577 .688 r
.39273 .62407 m .38995 .62757 L .38998 .62482 L F
.86 .506 .379 r
.41617 .54939 m .41378 .5512 L .41532 .54828 L F
.679 .904 .975 r
.41617 .54939 m .41715 .54721 L .4186 .54849 L F
.41617 .54939 m .41532 .54828 L .41715 .54721 L F
.109 .286 .762 r
.4186 .55134 m .41617 .54939 L .4186 .54849 L F
.373 .778 .984 r
.38566 .59314 m .3881 .58996 L .38566 .59014 L F
.38566 .59314 m .38952 .59358 L .3881 .58996 L F
.47 .393 .688 r
.3881 .58996 m .3907 .58949 L .39056 .58637 L F
.003 .151 .667 r
.3881 .58996 m .39029 .59138 L .3907 .58949 L F
.3881 .58996 m .38952 .59358 L .39029 .59138 L F
0 0 0 r
.3186 .56618 m .31917 .56637 L .32104 .5645 L F
0 0 .56 r
.32259 .56666 m .32104 .5645 L .32312 .56418 L F
.734 .475 .538 r
.31917 .56637 m .32312 .56418 L .32104 .5645 L F
.509 .278 .499 r
.37721 .5366 m .37698 .53913 L .37447 .5396 L F
.37721 .5366 m .37698 .53913 L .37447 .5396 L F
.443 .286 .572 r
.37721 .5366 m .37966 .53601 L .37873 .53398 L F
.41 .196 .475 r
.37721 .5366 m .37698 .53913 L .37966 .53601 L F
.443 .286 .572 r
.37721 .5366 m .37966 .53601 L .37873 .53398 L F
.41 .196 .475 r
.37721 .5366 m .37698 .53913 L .37966 .53601 L F
.509 .278 .499 r
.37447 .5396 m .37698 .53913 L .37721 .5366 L F
.541 .43 .677 r
.39321 .68758 m .39347 .69031 L .3912 .69083 L F
.458 .276 .545 r
.39347 .69031 m .39134 .69352 L .3912 .69083 L F
.188 0 .278 r
.20737 .55568 m .20678 .5579 L .20928 .55468 L F
0 0 0 r
.28509 .63597 m .28635 .63473 L .28292 .63687 L F
.28509 .63597 m .28292 .63687 L .28381 .63571 L F
.782 .692 .765 r
.28185 .6386 m .28654 .63957 L .28509 .63597 L F
.203 0 0 r
.28292 .63687 m .28084 .6376 L .28381 .63571 L F
0 0 .467 r
.28084 .6376 m .28185 .6386 L .28381 .63571 L F
0 0 0 r
.28509 .63597 m .28699 .63434 L .28635 .63473 L F
.28887 .63339 m .28699 .63434 L .28509 .63597 L F
.28887 .63339 m .28509 .63597 L .28874 .6356 L F
.71 .452 .534 r
.28509 .63597 m .28874 .6356 L .28381 .63571 L F
.782 .692 .765 r
.28185 .6386 m .28509 .63597 L .28381 .63571 L F
.786 .522 .538 r
.28356 .6334 m .28509 .63597 L .28104 .63573 L F
0 0 .552 r
.28479 .63429 m .28509 .63597 L .28393 .63403 L F
.28479 .63429 m .28393 .63403 L .28356 .6334 L F
0 0 0 r
.2855 .63452 m .28479 .63429 L .28641 .63304 L F
.69 .253 .208 r
.28104 .63573 m .28509 .63597 L .28358 .63784 L F
.923 .922 .543 r
.28378 .63724 m .28509 .63597 L .28479 .63429 L F
.28358 .63784 m .28509 .63597 L .28479 .63429 L F
0 0 0 r
.28441 .63628 m .28479 .63429 L .2855 .63452 L F
.923 .922 .543 r
.28358 .63784 m .28509 .63597 L .28378 .63724 L F
.026 0 .17 r
.28933 .63101 m .28699 .63434 L .28887 .63339 L F
.729 .399 .421 r
.35659 .70971 m .35887 .71018 L .35866 .71232 L F
.598 .108 .063 r
.35887 .71018 m .3612 .71194 L .35866 .71232 L F
0 0 .499 r
.29602 .53935 m .29738 .54103 L .29829 .53964 L F
.707 .197 .017 r
.34427 .65325 m .33964 .65258 L .34084 .65288 L F
.594 .878 .993 r
.34606 .65221 m .34427 .65325 L .34084 .65288 L F
0 0 .248 r
.34568 .65354 m .34427 .65325 L .34606 .65221 L F
.34563 .65371 m .3455 .65366 L .34568 .65354 L F
.3455 .65366 m .34427 .65325 L .34568 .65354 L F
.71 .651 .789 r
.34809 .65612 m .35034 .65603 L .34902 .65162 L F
.068 .217 .711 r
.34902 .65162 m .35002 .65495 L .35133 .65447 L F
.35002 .65495 m .35034 .65603 L .35133 .65447 L F
.689 .35 .396 r
.34618 .65834 m .34809 .65612 L .34411 .65599 L F
.203 0 0 r
.34739 .65661 m .34809 .65612 L .34691 .65749 L F
.34739 .65661 m .34691 .65749 L .34618 .65834 L F
.106 0 0 r
.34799 .65553 m .34739 .65661 L .34646 .65416 L F
.203 0 0 r
.34739 .65661 m .34864 .6561 L .34809 .65612 L F
.34739 .65661 m .35034 .65603 L .34864 .6561 L F
.654 .967 .906 r
.35133 .65447 m .35034 .65603 L .34739 .65661 L F
.106 0 0 r
.34948 .65685 m .35133 .65447 L .35097 .65467 L F
.34948 .65685 m .35097 .65467 L .34739 .65661 L F
.735 .748 .862 r
.34739 .65661 m .34618 .65834 L .34556 .65446 L F
.34739 .65661 m .34587 .6546 L .34646 .65416 L F
.8 .328 .108 r
.34602 .65449 m .34646 .65416 L .34533 .65395 L F
.34663 .65497 m .34533 .65395 L .34543 .6544 L F
.735 .748 .862 r
.34587 .6546 m .34551 .65413 L .34646 .65416 L F
.8 .328 .108 r
.34663 .65497 m .34646 .65416 L .34602 .65449 L F
0 0 .248 r
.34532 .654 m .34411 .65599 L .34427 .65325 L F
.34535 .65402 m .34529 .65411 L .34532 .654 L F
.34529 .65411 m .34411 .65599 L .34532 .654 L F
.34532 .654 m .34427 .65325 L .34563 .65371 L F
.594 .878 .993 r
.34606 .65221 m .34084 .65288 L .34491 .64913 L F
.875 .873 .831 r
.3433 .65356 m .34533 .65395 L .34562 .6509 L F
.34533 .65395 m .34537 .65396 L .34538 .65377 L F
.34533 .65395 m .34538 .65377 L .34562 .6509 L F
.8 .328 .108 r
.34543 .6544 m .34533 .65395 L .34395 .65369 L F
0 0 .248 r
.34551 .65413 m .3454 .65427 L .34535 .65402 L F
.3454 .65427 m .34411 .65599 L .34535 .65402 L F
.735 .748 .862 r
.34587 .6546 m .34556 .65446 L .34551 .65413 L F
.34739 .65661 m .34556 .65446 L .34587 .6546 L F
.952 .761 .608 r
.34257 .65504 m .34379 .65883 L .34411 .65599 L F
.689 .35 .396 r
.34618 .65834 m .34411 .65599 L .34379 .65883 L F
.543 .554 .816 r
.34618 .65834 m .34257 .65504 L .34525 .65421 L F
.34556 .65446 m .34525 .65421 L .34551 .65413 L F
.34618 .65834 m .34525 .65421 L .34556 .65446 L F
.8 .328 .108 r
.34689 .65616 m .34673 .6554 L .3433 .65356 L F
.34673 .6554 m .34663 .65497 L .34571 .65458 L F
.34673 .6554 m .34571 .65458 L .3433 .65356 L F
.34663 .65497 m .34395 .65369 L .3433 .65356 L F
.562 .127 .171 r
.34837 .65872 m .34948 .65685 L .34689 .65616 L F
.928 .901 .778 r
.34839 .65844 m .34948 .65685 L .34837 .65872 L F
.106 0 0 r
.34948 .65685 m .34739 .65661 L .34799 .65553 L F
.34948 .65685 m .34646 .65416 L .34689 .65616 L F
.928 .901 .778 r
.34862 .65494 m .34948 .65685 L .34839 .65844 L F
0 .128 .675 r
.34902 .65162 m .35133 .65447 L .35 .65131 L F
.511 .589 .87 r
.35 .65131 m .35133 .65447 L .35301 .6534 L F
.916 .923 .804 r
.34909 .65362 m .35224 .65419 L .34862 .65494 L F
0 0 0 r
.35301 .6534 m .34948 .65685 L .35246 .65422 L F
.916 .923 .804 r
.35224 .65419 m .35246 .65422 L .35214 .65428 L F
.35224 .65419 m .35214 .65428 L .34862 .65494 L F
.193 0 0 r
.35388 .65463 m .35246 .65422 L .35224 .65419 L F
0 0 0 r
.35222 .65418 m .35133 .65447 L .34966 .65662 L F
.35226 .65414 m .34966 .65662 L .35121 .65516 L F
.35301 .6534 m .35133 .65447 L .35226 .65414 L F
.35121 .65516 m .34966 .65662 L .34948 .65685 L F
.928 .901 .778 r
.34862 .65494 m .35246 .65422 L .34948 .65685 L F
.193 0 0 r
.35281 .6544 m .35224 .65419 L .34909 .65362 L F
.35388 .65463 m .35224 .65419 L .35281 .6544 L F
0 0 0 r
.35226 .65414 m .35218 .65416 L .35222 .65418 L F
.35218 .65416 m .35133 .65447 L .35222 .65418 L F
.671 .592 .758 r
.34734 .64896 m .34902 .65162 L .34606 .65221 L F
.541 .207 .351 r
.34606 .65221 m .34902 .65162 L .34646 .65416 L F
0 0 0 r
.35216 .64981 m .34972 .65007 L .34902 .65162 L F
.35 .65131 m .35216 .64981 L .34902 .65162 L F
.35 .65131 m .34902 .65162 L .34734 .64896 L F
0 .128 .675 r
.34902 .65162 m .35 .65131 L .34646 .65416 L F
.703 .78 .912 r
.34894 .65121 m .34646 .65416 L .35 .65131 L F
.671 .592 .758 r
.34734 .64896 m .34606 .65221 L .34491 .64913 L F
.703 .78 .912 r
.34562 .6509 m .3462 .65316 L .34894 .65121 L F
.3462 .65316 m .34646 .65416 L .34894 .65121 L F
.875 .873 .831 r
.34537 .65396 m .34646 .65416 L .34563 .65371 L F
.541 .207 .351 r
.34563 .65371 m .34646 .65416 L .34551 .65413 L F
.34606 .65221 m .34646 .65416 L .34563 .65371 L F
.875 .873 .831 r
.34563 .65371 m .34646 .65416 L .3462 .65316 L F
.34537 .65396 m .3462 .65316 L .34562 .6509 L F
0 0 .248 r
.34551 .65413 m .34532 .654 L .34563 .65371 L F
.38 .569 .911 r
.28084 .62835 m .27942 .62973 L .27774 .62698 L F
.515 .881 .979 r
.25719 .52804 m .25223 .52833 L .25529 .5271 L F
.519 .837 .999 r
.25756 .52641 m .25719 .52804 L .25529 .5271 L F
.25756 .52641 m .25971 .52741 L .25719 .52804 L F
.285 .179 .553 r
.19391 .56752 m .19569 .5697 L .19565 .56699 L F
.19391 .56752 m .19368 .57109 L .19569 .5697 L F
.502 .326 .574 r
.36096 .58636 m .35871 .58893 L .35872 .58707 L F
.36096 .58636 m .35871 .58893 L .35872 .58707 L F
.116 .378 .837 r
.36675 .65953 m .36889 .66286 L .36941 .66122 L F
.715 .983 .9 r
.36941 .66122 m .36889 .66286 L .36738 .66266 L F
.847 .563 .507 r
.3371 .69718 m .3405 .7005 L .33682 .69976 L F
.806 .468 .417 r
.33682 .69976 m .3405 .7005 L .34072 .70291 L F
.762 .582 .654 r
.3587 .60532 m .36327 .60623 L .36193 .60356 L F
.817 .367 0 r
.34325 .50886 m .3443 .51092 L .34277 .50941 L F
.663 .866 .483 r
.37099 .53708 m .36882 .54016 L .3696 .53879 L F
.868 .834 .812 r
.37297 .53367 m .37099 .53708 L .3693 .53546 L F
0 0 0 r
.37099 .53708 m .37148 .5376 L .3693 .53546 L F
.37099 .53708 m .3696 .53879 L .37148 .5376 L F
.595 .08 0 r
.26105 .54922 m .26316 .5507 L .2652 .54963 L F
.075 0 0 r
.2652 .54963 m .26645 .54934 L .26747 .5488 L F
.2652 .54963 m .26316 .5507 L .26645 .54934 L F
.35 0 0 r
.33862 .65412 m .3373 .65287 L .33687 .65519 L F
.33862 .65412 m .33964 .65258 L .3373 .65287 L F
.353 .085 .362 r
.31614 .63621 m .31643 .63407 L .31861 .63342 L F
.286 .064 .391 r
.20491 .55871 m .20442 .5612 L .20678 .5579 L F
.743 .677 .787 r
.71356 .30579 m .71473 .30941 L .711 .30876 L F
.756 .645 .737 r
.71473 .30941 m .71232 .31287 L .711 .30876 L F
.155 .255 .716 r
.61546 .40234 m .61408 .40436 L .61302 .40027 L F
.441 .651 .948 r
.61692 .40407 m .61408 .40436 L .61546 .40234 L F
.715 .611 .74 r
.33827 .60521 m .3422 .60571 L .34105 .60151 L F
.476 .826 .55 r
.34061 .60731 m .34158 .60649 L .34214 .606 L F
.182 0 .244 r
.34056 .60822 m .34275 .6055 L .34158 .60649 L F
.432 .421 .747 r
.34245 .60574 m .34061 .60731 L .34274 .60578 L F
.33827 .60521 m .34061 .60731 L .34245 .60574 L F
.516 .504 .781 r
.34105 .60151 m .34266 .60556 L .34427 .60416 L F
.476 .826 .55 r
.34266 .60556 m .34275 .6055 L .34366 .6047 L F
.516 .504 .781 r
.34266 .60556 m .34274 .60578 L .34427 .60416 L F
.476 .826 .55 r
.34158 .60649 m .34194 .60619 L .34266 .60556 L F
.34194 .60619 m .34275 .6055 L .34266 .60556 L F
.34061 .60731 m .34214 .606 L .34427 .60416 L F
.34158 .60649 m .34366 .6047 L .34427 .60416 L F
.715 .611 .74 r
.3422 .60571 m .34245 .60574 L .34254 .60527 L F
.34245 .60574 m .34274 .60578 L .34266 .60556 L F
.34245 .60574 m .34266 .60556 L .34254 .60527 L F
.3422 .60571 m .34254 .60527 L .34105 .60151 L F
.182 0 .244 r
.34059 .60776 m .34158 .60649 L .34061 .60731 L F
.34056 .60822 m .34158 .60649 L .34059 .60776 L F
.609 .903 .986 r
.29862 .5218 m .29583 .5225 L .29388 .52208 L F
0 0 0 r
.32058 .62796 m .32123 .627 L .32423 .6248 L F
.361 .417 .784 r
.35367 .62523 m .35456 .62147 L .35231 .62134 L F
.35367 .62523 m .35571 .62604 L .35456 .62147 L F
.452 .355 .655 r
.35367 .62523 m .35655 .62694 L .35571 .62604 L F
.886 .74 .694 r
.61881 .41942 m .62093 .42004 L .61959 .41623 L F
.966 .822 .651 r
.41565 .5434 m .41465 .54554 L .41372 .54215 L F
.41565 .5434 m .41465 .54554 L .41372 .54215 L F
.68 .798 .938 r
.3152 .52217 m .31838 .52175 L .31584 .51942 L F
.216 .332 .768 r
.31838 .52175 m .31944 .52018 L .31584 .51942 L F
.31838 .52175 m .32021 .52226 L .31944 .52018 L F
.31944 .52018 m .32021 .52226 L .31838 .52175 L F
.819 .676 .706 r
.711 .30876 m .71232 .31287 L .7088 .3124 L F
.745 .683 .791 r
.36545 .55642 m .36897 .55297 L .36778 .55516 L F
.226 .37 .8 r
.36778 .55516 m .37098 .55802 L .36897 .55297 L F
0 0 0 r
.33435 .66157 m .33276 .66283 L .33099 .66515 L F
.68 .798 .938 r
.3152 .52217 m .31584 .51942 L .31365 .52081 L F
.946 .85 .715 r
.35351 .58744 m .35216 .58961 L .35422 .58569 L F
.746 .541 .617 r
.70869 .32551 m .70473 .32758 L .70475 .32518 L F
.70869 .32551 m .70878 .32822 L .70473 .32758 L F
.535 .472 .732 r
.71131 .32578 m .70878 .32822 L .70869 .32551 L F
.564 .635 .88 r
.33815 .50828 m .33857 .50471 L .33657 .50444 L F
.33815 .50828 m .3403 .50779 L .33857 .50471 L F
.787 .698 .766 r
.36203 .59286 m .36374 .59668 L .35968 .59581 L F
.043 0 0 r
.36374 .59668 m .35963 .59848 L .35968 .59581 L F
.36374 .59668 m .36155 .59813 L .35963 .59848 L F
.421 .788 .995 r
.36487 .59481 m .36374 .59668 L .36226 .59336 L F
.36487 .59481 m .36226 .59336 L .36254 .59321 L F
.218 .194 .616 r
.36418 .59169 m .36487 .59481 L .36236 .59309 L F
.36418 .59169 m .36236 .59309 L .36203 .59286 L F
.766 .702 .791 r
.36487 .59481 m .36565 .59205 L .36418 .59169 L F
.36565 .59205 m .36641 .58936 L .36619 .58959 L F
.36565 .59205 m .36619 .58959 L .36418 .59169 L F
.778 .665 .74 r
.36295 .59369 m .36437 .59725 L .36456 .59703 L F
.766 .702 .791 r
.36487 .59481 m .36295 .59369 L .36641 .58936 L F
.36487 .59481 m .36698 .59416 L .36295 .59369 L F
.778 .665 .74 r
.36523 .59396 m .36456 .59703 L .36698 .59416 L F
.36295 .59369 m .36456 .59703 L .36523 .59396 L F
0 0 0 r
.36514 .59096 m .36418 .59169 L .36295 .59369 L F
.36641 .58936 m .36418 .59169 L .36514 .59096 L F
.218 .194 .616 r
.36358 .59266 m .36119 .5953 L .36295 .59369 L F
.36418 .59169 m .36321 .59286 L .36358 .59266 L F
.36321 .59286 m .36119 .5953 L .36358 .59266 L F
.421 .788 .995 r
.36254 .59321 m .36226 .59336 L .36203 .59286 L F
0 0 0 r
.36437 .59725 m .36155 .59813 L .36374 .59668 L F
.671 .877 .5 r
.25811 .61957 m .25674 .62137 L .25924 .61778 L F
.625 .468 .65 r
.39695 .56792 m .39443 .57112 L .39505 .56899 L F
.191 .609 .945 r
.24721 .63042 m .24748 .62948 L .24531 .62911 L F
.46 .322 .605 r
.22468 .5775 m .22482 .58024 L .22266 .58081 L F
.891 .914 .833 r
.72091 .30936 m .72358 .30608 L .72255 .30464 L F
.756 .597 .68 r
.72373 .30284 m .7253 .29925 L .72125 .29867 L F
.847 .809 .812 r
.71985 .30401 m .72316 .30328 L .72136 .30158 L F
.931 .926 .781 r
.7245 .302 m .72414 .30239 L .72255 .30464 L F
.847 .809 .812 r
.72316 .30328 m .7239 .30311 L .72363 .30295 L F
.72316 .30328 m .72363 .30295 L .72136 .30158 L F
.931 .926 .781 r
.72358 .30608 m .72441 .30241 L .72255 .30464 L F
.72441 .30241 m .7245 .302 L .72398 .30271 L F
.72441 .30241 m .72398 .30271 L .72255 .30464 L F
.7245 .302 m .72454 .30184 L .72414 .30239 L F
.778 .603 .663 r
.72136 .30158 m .72363 .30295 L .72125 .29867 L F
.604 .416 .6 r
.7239 .30311 m .72255 .30464 L .72454 .30184 L F
.778 .603 .663 r
.72363 .30295 m .7239 .30311 L .72373 .30284 L F
.72363 .30295 m .72373 .30284 L .72125 .29867 L F
.756 .597 .68 r
.7239 .30311 m .72422 .30223 L .72373 .30284 L F
.72422 .30223 m .7253 .29925 L .72373 .30284 L F
.829 .817 .838 r
.70114 .31962 m .69871 .32252 L .69702 .32121 L F
.933 .761 .645 r
.69871 .32252 m .69827 .32528 L .69702 .32121 L F
.78 .501 .514 r
.33999 .5617 m .33945 .56481 L .33552 .56365 L F
0 0 .149 r
.34075 .56284 m .33999 .5617 L .34254 .56116 L F
.34075 .56284 m .33945 .56481 L .33999 .5617 L F
.71 .333 .332 r
.34056 .60822 m .33894 .60908 L .33751 .60801 L F
.696 .981 .818 r
.34061 .60731 m .33894 .60908 L .34056 .60822 L F
.609 .903 .986 r
.29862 .5218 m .29388 .52208 L .29674 .52057 L F
.62 .856 .988 r
.30089 .52078 m .29862 .5218 L .29674 .52057 L F
.824 .871 .88 r
.3278 .57906 m .33057 .57304 L .32826 .57629 L F
.3278 .57906 m .3327 .5746 L .33057 .57304 L F
.603 .131 .107 r
.28397 .62132 m .2822 .62324 L .2801 .62133 L F
.387 0 0 r
.28468 .62291 m .28397 .62132 L .28599 .62048 L F
.28468 .62291 m .2822 .62324 L .28397 .62132 L F
.432 .13 .352 r
.35699 .56117 m .3556 .56437 L .35318 .56483 L F
.821 .998 .783 r
.35845 .55885 m .35674 .56066 L .35699 .56117 L F
.914 .892 .476 r
.35674 .56066 m .3556 .56437 L .35699 .56117 L F
.478 .224 .451 r
.24125 .55879 m .24052 .56126 L .23811 .56169 L F
.351 .106 .396 r
.24265 .5604 m .24125 .55879 L .2427 .5578 L F
.24265 .5604 m .24052 .56126 L .24125 .55879 L F
0 0 0 r
.38864 .59317 m .38814 .59329 L .38719 .59473 L F
.722 .95 .951 r
.39029 .59138 m .38952 .59358 L .38814 .59329 L F
0 0 0 r
.39029 .59138 m .38814 .59329 L .38864 .59317 L F
.373 .778 .984 r
.38952 .59358 m .38778 .59338 L .38814 .59329 L F
.38778 .59338 m .38566 .59314 L .38814 .59329 L F
.822 .886 .89 r
.3421 .533 m .34083 .53472 L .34396 .53349 L F
.689 .599 .75 r
.34651 .53092 m .34396 .53349 L .34298 .53061 L F
.954 .812 .664 r
.34396 .53349 m .34308 .536 L .3421 .533 L F
.96 .713 .519 r
.34396 .53349 m .3421 .533 L .34298 .53061 L F
.526 .804 .997 r
.59635 .42101 m .59771 .42234 L .59511 .42294 L F
.45 .182 .414 r
.59511 .42294 m .59771 .42234 L .59773 .42442 L F
.151 .3 .762 r
.59635 .42101 m .59511 .42294 L .59773 .42442 L F
0 0 .235 r
.30894 .57139 m .3103 .57164 L .31144 .57195 L F
.30894 .57139 m .30868 .57374 L .3103 .57164 L F
.484 .549 .847 r
.38117 .57728 m .37985 .58056 L .37902 .57821 L F
.38117 .57728 m .38464 .58196 L .37985 .58056 L F
.409 0 .087 r
.38464 .58196 m .38006 .5831 L .37985 .58056 L F
.474 .453 .755 r
.34242 .54568 m .34231 .54792 L .33973 .54618 L F
.549 .441 .684 r
.34231 .54792 m .34021 .54873 L .33973 .54618 L F
.859 .576 .508 r
.32223 .66022 m .31854 .65557 L .31811 .6592 L F
.643 .935 .967 r
.32223 .66022 m .32461 .65905 L .32405 .66181 L F
.146 .319 .781 r
.32223 .66022 m .32405 .66181 L .32283 .65809 L F
.007 0 .388 r
.73137 .34599 m .73012 .34769 L .73133 .34353 L F
.061 0 .324 r
.73137 .34599 m .72957 .34966 L .73012 .34769 L F
.135 0 0 r
.72957 .34966 m .72611 .35203 L .7272 .35079 L F
0 0 0 r
.32058 .62796 m .32423 .6248 L .32326 .62724 L F
.63 .196 .199 r
.32314 .62487 m .32417 .625 L .32405 .62435 L F
.719 .463 0 r
.32405 .62435 m .32423 .6248 L .32353 .62164 L F
.642 .282 .345 r
.32423 .6248 m .32647 .627 L .32326 .62724 L F
0 .032 .547 r
.32405 .62435 m .32647 .627 L .32423 .6248 L F
.558 .719 .948 r
.32886 .6264 m .32647 .627 L .32405 .62435 L F
.32886 .6264 m .32405 .62435 L .32713 .62537 L F
.63 .196 .199 r
.32417 .625 m .32713 .62537 L .32405 .62435 L F
.719 .463 0 r
.32405 .62435 m .32353 .62164 L .32337 .62095 L F
.022 .314 .803 r
.62652 .43725 m .62813 .44017 L .62574 .43851 L F
0 0 .127 r
.39785 .67818 m .39706 .68038 L .39529 .68131 L F
.504 .5 .786 r
.39706 .68038 m .39576 .68425 L .39529 .68131 L F
.524 .549 .823 r
.39109 .63131 m .38737 .62823 L .38995 .62757 L F
0 0 .29 r
.32702 .57395 m .32808 .57067 L .32571 .57167 L F
.142 0 0 r
.27573 .54472 m .2792 .54241 L .27697 .54338 L F
.642 .291 .361 r
.35659 .70971 m .35461 .71223 L .35242 .70988 L F
.729 .399 .421 r
.35659 .70971 m .35866 .71232 L .35461 .71223 L F
.891 .914 .833 r
.72091 .30936 m .72255 .30464 L .72023 .30815 L F
.003 .521 .857 r
.28953 .64929 m .29306 .65067 L .29156 .64978 L F
.617 .075 0 r
.29156 .64978 m .29306 .65067 L .29509 .65275 L F
.799 .881 .905 r
.3933 .61041 m .38972 .61176 L .39262 .60947 L F
.453 .131 .328 r
.3933 .61041 m .38962 .61441 L .38972 .61176 L F
.3933 .61041 m .39216 .61393 L .38962 .61441 L F
.972 .871 .678 r
.39262 .60947 m .39215 .61208 L .3933 .61041 L F
.477 .153 .338 r
.39215 .61208 m .39216 .61393 L .3933 .61041 L F
.809 .406 .286 r
.34072 .70291 m .3444 .70396 L .3427 .70555 L F
.78 .363 .259 r
.3427 .70555 m .3444 .70396 L .3455 .7061 L F
.72 .477 .558 r
.70475 .32518 m .70473 .32758 L .70099 .32609 L F
.513 .392 .652 r
.22413 .56204 m .22738 .56391 L .22615 .56036 L F
.22413 .56204 m .22511 .56455 L .22738 .56391 L F
.107 0 .186 r
.32568 .56102 m .32312 .56418 L .32392 .56213 L F
.942 .717 .57 r
.34772 .55228 m .3448 .55206 L .34628 .54812 L F
.836 .404 .207 r
.34772 .55228 m .34559 .55312 L .3448 .55206 L F
.365 .683 .979 r
.34768 .55491 m .34559 .55312 L .34772 .55228 L F
.21 .492 .9 r
.20533 .59959 m .20795 .60257 L .20843 .60101 L F
.117 .382 .84 r
.20795 .60257 m .21033 .60377 L .20843 .60101 L F
.369 .477 .839 r
.20795 .60257 m .21119 .60594 L .21033 .60377 L F
.57 .659 .897 r
.3464 .59636 m .34701 .59844 L .34472 .59892 L F
.776 .318 0 r
.22774 .60015 m .22737 .6009 L .22802 .59932 L F
.383 .794 .98 r
.22737 .6009 m .22734 .60209 L .22703 .60158 L F
.22737 .6009 m .22951 .60169 L .22734 .60209 L F
.375 .79 .978 r
.22737 .6009 m .23235 .60137 L .22951 .60169 L F
.566 .589 .836 r
.23103 .60473 m .22734 .60209 L .22951 .60169 L F
.626 .65 .854 r
.23305 .60291 m .23103 .60473 L .22951 .60169 L F
.23305 .60291 m .22951 .60169 L .23235 .60137 L F
.814 .489 .439 r
.22785 .60202 m .23235 .60137 L .22737 .6009 L F
.776 .318 0 r
.22713 .60198 m .22785 .60202 L .22737 .6009 L F
.22713 .60198 m .22737 .6009 L .22774 .60015 L F
.383 .794 .98 r
.22737 .6009 m .22703 .60158 L .22529 .5988 L F
.309 .551 .919 r
.35898 .50544 m .35825 .50763 L .35371 .50554 L F
.35898 .50544 m .35968 .50733 L .35825 .50763 L F
0 0 0 r
.30262 .60289 m .30505 .59943 L .30481 .60218 L F
.30505 .59943 m .30732 .59562 L .30716 .59838 L F
.295 .129 .478 r
.30716 .59838 m .30481 .60218 L .30505 .59943 L F
.243 .624 .958 r
.26828 .62067 m .26715 .62173 L .26518 .62078 L F
.448 0 .076 r
.26358 .62225 m .2661 .62235 L .26828 .62067 L F
.269 0 .043 r
.2661 .62235 m .26863 .62034 L .26828 .62067 L F
.26863 .62034 m .27009 .61918 L .26828 .62067 L F
.243 .624 .958 r
.26828 .62067 m .26978 .623 L .26715 .62173 L F
.26828 .62067 m .26986 .62223 L .26978 .623 L F
.455 .454 .767 r
.25464 .54863 m .25585 .55311 L .25775 .55133 L F
.402 .369 .707 r
.25585 .55311 m .25883 .55407 L .25775 .55133 L F
.549 .35 .563 r
.2353 .56288 m .23508 .56724 L .23259 .56754 L F
.337 0 .092 r
.23811 .56169 m .2368 .5632 L .2353 .56288 L F
.455 .307 .591 r
.2368 .5632 m .23508 .56724 L .2353 .56288 L F
.247 .538 .923 r
.31854 .65557 m .31386 .65243 L .31691 .65267 L F
.935 .724 .593 r
.31669 .65559 m .31854 .65557 L .31691 .65267 L F
.937 .739 .61 r
.31669 .65559 m .31811 .6592 L .31854 .65557 L F
.922 .545 .137 r
.38923 .5259 m .39085 .53026 L .39164 .53085 L F
.908 .517 .101 r
.39085 .53026 m .3927 .53309 L .39164 .53085 L F
.521 .535 .81 r
.3587 .60532 m .36173 .60785 L .36327 .60623 L F
.762 .961 .659 r
.36327 .60623 m .36144 .60761 L .36173 .60785 L F
.863 .8 .787 r
.39564 .57495 m .39551 .57713 L .39512 .57427 L F
.578 .535 .771 r
.39335 .59913 m .39514 .60365 L .39407 .60443 L F
.8 .793 .846 r
.385 .54732 m .38287 .54872 L .38639 .54911 L F
.566 .17 .251 r
.38228 .55122 m .38639 .54911 L .38287 .54872 L F
.38228 .55122 m .38561 .55123 L .38639 .54911 L F
.524 .692 .944 r
.385 .54732 m .38639 .54911 L .38785 .54699 L F
.048 0 .048 r
.38639 .54911 m .38739 .55028 L .38785 .54699 L F
.38639 .54911 m .38561 .55123 L .38739 .55028 L F
.693 .26 .218 r
.26316 .5507 m .26534 .5529 L .26645 .54934 L F
.316 0 .249 r
.26645 .54934 m .2699 .54823 L .26747 .5488 L F
.26645 .54934 m .26977 .55051 L .2699 .54823 L F
.395 .007 .181 r
.26534 .5529 m .26977 .55051 L .26645 .54934 L F
.334 .098 .399 r
.33641 .5928 m .33381 .59585 L .33383 .59339 L F
.245 0 .271 r
.2289 .57568 m .22758 .57394 L .22942 .57292 L F
.2289 .57568 m .22691 .5766 L .22758 .57394 L F
.754 .576 .655 r
.61963 .42948 m .61595 .43175 L .61593 .4292 L F
.61963 .42948 m .62032 .43178 L .61595 .43175 L F
.55 .303 .494 r
.61963 .42948 m .62261 .42894 L .62224 .43146 L F
.353 .334 .699 r
.62224 .43146 m .62032 .43178 L .61963 .42948 L F
0 0 0 r
.35201 .54006 m .35018 .54241 L .34961 .54268 L F
.027 .391 .85 r
.35018 .54241 m .35278 .54478 L .34961 .54268 L F
.187 0 .082 r
.27039 .55336 m .26893 .55301 L .27136 .55235 L F
.27039 .55336 m .26829 .55415 L .26893 .55301 L F
.369 .094 .359 r
.58865 .42505 m .58862 .42306 L .58582 .42585 L F
.58865 .42505 m .58862 .42306 L .58582 .42585 L F
.594 .263 .379 r
.58865 .42505 m .59123 .42496 L .58862 .42306 L F
.58862 .42306 m .59123 .42496 L .58865 .42505 L F
.58865 .42505 m .59123 .42496 L .58862 .42306 L F
.851 .743 .744 r
.60518 .40239 m .60625 .40723 L .60477 .40596 L F
.968 .694 .272 r
.60625 .40723 m .60525 .40842 L .60477 .40596 L F
.60625 .40723 m .60643 .40962 L .60525 .40842 L F
.258 .768 .793 r
.26412 .52553 m .26322 .52597 L .26188 .52639 L F
.26412 .52553 m .26564 .52537 L .26322 .52597 L F
0 .014 .588 r
.28767 .62755 m .28933 .63101 L .28926 .6294 L F
0 0 .02 r
.28933 .63101 m .28955 .63255 L .28926 .6294 L F
.28933 .63101 m .28887 .63339 L .28955 .63255 L F
.048 0 0 r
.22946 .53897 m .23127 .53871 L .23264 .53656 L F
0 0 0 r
.23264 .53656 m .2331 .5376 L .23466 .53569 L F
.23264 .53656 m .23127 .53871 L .2331 .5376 L F
.278 .766 .688 r
.34825 .64765 m .35248 .64603 L .34743 .6479 L F
.892 .914 .514 r
.34734 .64896 m .34825 .64765 L .34743 .6479 L F
.747 .888 .943 r
.62163 .43732 m .62132 .43773 L .61746 .43767 L F
.856 .694 .681 r
.61746 .43767 m .62132 .43773 L .61921 .44107 L F
.291 0 .059 r
.31015 .55145 m .31427 .54851 L .31031 .549 L F
.31015 .55145 m .31247 .55102 L .31427 .54851 L F
.702 .318 .316 r
.31427 .54851 m .31658 .55107 L .31593 .54959 L F
.679 .441 .554 r
.37447 .5396 m .37441 .5426 L .37068 .54179 L F
.562 .346 .543 r
.37699 .54181 m .37447 .5396 L .37698 .53913 L F
.37699 .54181 m .37441 .5426 L .37447 .5396 L F
.096 .294 .774 r
.37447 .5396 m .37699 .54181 L .37698 .53913 L F
.603 .865 .992 r
.38848 .65437 m .38642 .65536 L .38491 .65442 L F
.361 0 .123 r
.24052 .56126 m .2368 .5632 L .23811 .56169 L F
.831 .589 .572 r
.61593 .4292 m .61184 .43107 L .61174 .42864 L F
.61593 .4292 m .61595 .43175 L .61184 .43107 L F
.815 .745 .787 r
.70207 .31478 m .70334 .31825 L .69957 .318 L F
.801 .777 .831 r
.69957 .318 m .70334 .31825 L .70114 .31962 L F
.745 .711 .82 r
.70595 .31543 m .70334 .31825 L .70207 .31478 L F
.472 0 .023 r
.29741 .65321 m .29875 .65534 L .29509 .65275 L F
.29741 .65321 m .30053 .65361 L .29875 .65534 L F
0 0 0 r
.33336 .54877 m .33688 .54575 L .33257 .54631 L F
.677 .872 .972 r
.35518 .54405 m .35213 .54576 L .35278 .54478 L F
.714 .291 .242 r
.34833 .70939 m .35242 .70988 L .35061 .71188 L F
.701 .274 .232 r
.35242 .70988 m .35461 .71223 L .35061 .71188 L F
.936 .635 .446 r
.23971 .62579 m .23822 .62385 L .23828 .62416 L F
.264 .536 .919 r
.23463 .62237 m .23852 .62406 L .23507 .62079 L F
.83 .443 0 r
.23852 .62406 m .23828 .62416 L .23716 .62247 L F
.936 .635 .446 r
.23822 .62385 m .23716 .62247 L .23828 .62416 L F
.816 .859 .408 r
.23839 .62476 m .23828 .62416 L .23852 .62406 L F
.23831 .62519 m .23828 .62416 L .23839 .62476 L F
0 .236 .688 r
.23831 .62519 m .23971 .62579 L .23828 .62416 L F
.23831 .62519 m .24117 .62701 L .23971 .62579 L F
.564 .757 .968 r
.33194 .5164 m .33003 .51813 L .32875 .51669 L F
.33194 .5164 m .33041 .51856 L .32875 .51669 L F
.979 .799 .592 r
.33194 .5164 m .32988 .51576 L .33182 .51416 L F
.564 .757 .968 r
.33194 .5164 m .33041 .51856 L .33003 .51813 L F
.33194 .5164 m .33267 .51826 L .33041 .51856 L F
.33194 .5164 m .33267 .51826 L .33041 .51856 L F
.979 .799 .592 r
.33194 .5164 m .33141 .51925 L .32988 .51576 L F
.93 .934 .576 r
.33182 .51416 m .33143 .51664 L .33194 .5164 L F
.912 .92 .808 r
.33237 .51601 m .33194 .5164 L .33143 .51664 L F
.33542 .51395 m .33194 .5164 L .33237 .51601 L F
0 0 0 r
.3186 .56618 m .31753 .56742 L .31917 .56637 L F
.483 .331 .599 r
.72292 .33166 m .72433 .33539 L .72596 .33317 L F
.461 .165 .375 r
.72014 .33651 m .72317 .33659 L .72433 .33539 L F
.86 .997 .786 r
.72433 .33539 m .72317 .33659 L .72596 .33317 L F
.904 .843 .774 r
.72317 .33659 m .72664 .33464 L .72596 .33317 L F
.72317 .33659 m .72263 .34037 L .72664 .33464 L F
0 0 .185 r
.3743 .58319 m .3746 .5792 L .37316 .58026 L F
.935 .968 .719 r
.36554 .51897 m .36506 .52148 L .36377 .52337 L F
0 .074 .574 r
.38721 .52399 m .38939 .52592 L .38923 .5259 L F
0 0 .32 r
.39009 .52777 m .38923 .5259 L .38939 .52592 L F
.681 .165 0 r
.38873 .52658 m .39039 .52822 L .39009 .52777 L F
0 .221 .743 r
.39208 .5299 m .39085 .53026 L .39009 .52777 L F
.681 .165 0 r
.39039 .52822 m .39208 .5299 L .39009 .52777 L F
0 0 .32 r
.39009 .52777 m .39085 .53026 L .3897 .52717 L F
.39009 .52777 m .3897 .52717 L .38923 .5259 L F
.346 .14 .45 r
.30482 .58058 m .30685 .57987 L .30715 .57734 L F
.264 0 .266 r
.30482 .58058 m .30395 .58292 L .30685 .57987 L F
.303 .025 .316 r
.27931 .61532 m .27873 .61785 L .28131 .6149 L F
.756 .504 .551 r
.39443 .57112 m .39047 .57379 L .3909 .57144 L F
.961 .627 .269 r
.39443 .57112 m .39564 .57495 L .39512 .57427 L F
.535 .564 .831 r
.37975 .55443 m .37794 .55656 L .37582 .55103 L F
.088 0 .346 r
.37088 .60497 m .37047 .60735 L .36913 .60816 L F
.809 .908 .506 r
.371 .60554 m .36976 .60796 L .37047 .60735 L F
0 0 .497 r
.37061 .6106 m .37074 .61203 L .36971 .60955 L F
.36972 .60914 m .36971 .60955 L .36913 .60816 L F
.37061 .6106 m .36971 .60955 L .36972 .60914 L F
.756 .938 .599 r
.36913 .60816 m .36609 .61242 L .36721 .61001 L F
.758 .336 .248 r
.36721 .61001 m .37061 .6106 L .36913 .60816 L F
.36721 .61001 m .37047 .60735 L .36902 .60941 L F
.809 .908 .506 r
.36976 .60796 m .36902 .60941 L .36974 .60838 L F
.36976 .60796 m .36974 .60838 L .37047 .60735 L F
.119 .482 .899 r
.37226 .61249 m .37074 .61203 L .37061 .6106 L F
.755 .6 .685 r
.34567 .62373 m .35 .62226 L .34601 .62129 L F
.34567 .62373 m .34961 .62423 L .35 .62226 L F
.563 .415 .638 r
.35 .62226 m .34961 .62423 L .35231 .62134 L F
.992 .754 .469 r
.24061 .614 m .24226 .61574 L .24189 .61135 L F
.513 .456 .73 r
.24392 .60992 m .24189 .61135 L .24126 .60883 L F
.134 0 .055 r
.24344 .61161 m .24189 .61135 L .24392 .60992 L F
.24344 .61161 m .24061 .614 L .24189 .61135 L F
.36 .272 .62 r
.39727 .60223 m .39567 .60593 L .39514 .60365 L F
.39727 .60223 m .39758 .60561 L .39567 .60593 L F
.295 .046 .355 r
.39758 .60561 m .39535 .60847 L .39567 .60593 L F
.812 .601 .617 r
.58582 .42585 m .58603 .42919 L .58223 .42822 L F
.58582 .42585 m .58223 .42822 L .58592 .42869 L F
.347 .048 .308 r
.58865 .42505 m .58582 .42585 L .58745 .42664 L F
.225 .154 .563 r
.58964 .4272 m .5876 .42648 L .58865 .42505 L F
.5876 .42648 m .58582 .42585 L .58865 .42505 L F
.58956 .42754 m .58751 .42661 L .58964 .4272 L F
.58751 .42661 m .58582 .42585 L .5876 .42648 L F
.58751 .42661 m .5876 .42648 L .58964 .4272 L F
.347 .048 .308 r
.58865 .42505 m .58745 .42664 L .58751 .42661 L F
.58865 .42505 m .58751 .42661 L .58847 .426 L F
.225 .154 .563 r
.58956 .42754 m .58961 .4277 L .58745 .42664 L F
.58986 .42767 m .58745 .42664 L .58751 .42661 L F
.58969 .42774 m .58603 .42919 L .58582 .42585 L F
.347 .048 .308 r
.58847 .426 m .58622 .42837 L .58831 .42689 L F
.58622 .42837 m .58592 .42869 L .58607 .42857 L F
.58622 .42837 m .58607 .42857 L .58831 .42689 L F
.584 .237 .347 r
.59043 .42677 m .58865 .42505 L .59006 .42679 L F
.59079 .42641 m .58865 .42505 L .59043 .42677 L F
.59079 .42641 m .59123 .42496 L .58865 .42505 L F
.989 .734 .44 r
.59123 .42496 m .59151 .42572 L .59079 .42641 L F
.584 .237 .347 r
.59127 .42672 m .59123 .42496 L .59079 .42641 L F
.989 .734 .44 r
.59123 .42496 m .59079 .42641 L .59061 .42659 L F
.59123 .42496 m .59021 .42698 L .58865 .42505 L F
.59021 .42698 m .58986 .42767 L .58865 .42505 L F
.584 .237 .347 r
.59006 .42679 m .58865 .42505 L .58831 .42689 L F
.989 .734 .44 r
.59151 .42572 m .59157 .42591 L .59061 .42659 L F
.59157 .42591 m .59258 .42872 L .59091 .42693 L F
.59157 .42591 m .59091 .42693 L .59061 .42659 L F
.59061 .42659 m .59258 .42872 L .59015 .42778 L F
.916 .947 .805 r
.58993 .42823 m .59258 .42872 L .59032 .43135 L F
.793 .461 .428 r
.58993 .4279 m .59043 .42677 L .58974 .42681 L F
.916 .947 .805 r
.58989 .42793 m .59031 .42785 L .58993 .42823 L F
.59015 .42778 m .59031 .42785 L .58989 .42793 L F
.793 .461 .428 r
.59001 .42832 m .59015 .42778 L .58993 .4279 L F
.59015 .42778 m .59043 .42677 L .58993 .4279 L F
.916 .947 .805 r
.58986 .42767 m .59015 .42778 L .58989 .42793 L F
.59031 .42785 m .59258 .42872 L .58993 .42823 L F
.552 .567 .823 r
.59475 .42651 m .59258 .42872 L .59123 .42496 L F
.616 .262 .347 r
.59127 .42672 m .59374 .42701 L .59123 .42496 L F
.232 .69 .95 r
.59271 .42622 m .59374 .42701 L .59127 .42672 L F
.59271 .42622 m .59152 .42663 L .59001 .42832 L F
.59152 .42663 m .59127 .42672 L .59064 .42752 L F
.59152 .42663 m .59064 .42752 L .59001 .42832 L F
.697 .828 .945 r
.58965 .4279 m .59032 .43135 L .58645 .43134 L F
.793 .461 .428 r
.58988 .42848 m .58974 .42681 L .58956 .42754 L F
.697 .828 .945 r
.58986 .42767 m .58989 .42793 L .58965 .4279 L F
.58989 .42793 m .59032 .43135 L .58965 .4279 L F
.793 .461 .428 r
.58988 .42848 m .59001 .42832 L .58994 .42793 L F
.58983 .42792 m .58994 .42793 L .58974 .42681 L F
.58988 .42848 m .58994 .42793 L .58983 .42792 L F
.232 .69 .95 r
.58948 .42913 m .59001 .42832 L .58908 .42949 L F
.59271 .42622 m .59001 .42832 L .58948 .42913 L F
.584 .237 .347 r
.59127 .42672 m .59079 .42641 L .59043 .42677 L F
.989 .734 .44 r
.59055 .4263 m .59015 .42778 L .58986 .42767 L F
.59123 .42496 m .59015 .42778 L .59055 .4263 L F
.793 .461 .428 r
.59001 .42832 m .59127 .42672 L .59043 .42677 L F
.58956 .42754 m .58974 .42681 L .58931 .42683 L F
.225 .154 .563 r
.58986 .42767 m .58956 .42754 L .58964 .4272 L F
.58986 .42767 m .58969 .42774 L .58961 .4277 L F
.58986 .42767 m .58961 .4277 L .58956 .42754 L F
.697 .828 .945 r
.58963 .42776 m .58775 .42987 L .58663 .42895 L F
.58965 .4279 m .58645 .43134 L .58963 .42776 L F
.705 .466 .561 r
.59032 .43135 m .58586 .43342 L .58645 .43134 L F
.59032 .43135 m .59014 .43425 L .58586 .43342 L F
.339 .322 .694 r
.58749 .42951 m .58997 .43173 L .58908 .42949 L F
.58749 .42951 m .58997 .43173 L .58908 .42949 L F
0 .082 .585 r
.58823 .4301 m .5896 .43138 L .58749 .42951 L F
.5896 .43138 m .58997 .43173 L .58943 .43124 L F
.5896 .43138 m .58943 .43124 L .58749 .42951 L F
.697 .828 .945 r
.58663 .42895 m .58645 .43134 L .58603 .42919 L F
.58775 .42987 m .58645 .43134 L .58663 .42895 L F
.58986 .42767 m .58965 .4279 L .58963 .42776 L F
.793 .461 .428 r
.58908 .42949 m .58973 .42867 L .58831 .42689 L F
.58973 .42867 m .58988 .42848 L .58969 .42829 L F
.58973 .42867 m .58969 .42829 L .58831 .42689 L F
.58988 .42848 m .58931 .42683 L .58831 .42689 L F
.347 .048 .308 r
.58745 .42664 m .58592 .42869 L .58847 .426 L F
.225 .154 .563 r
.58751 .42661 m .58745 .42664 L .58582 .42585 L F
.347 .048 .308 r
.58745 .42664 m .58582 .42585 L .58592 .42869 L F
.685 .971 .92 r
.27865 .52321 m .27517 .52438 L .27675 .52388 L F
.308 .799 .863 r
.2776 .5233 m .27845 .52333 L .27675 .52388 L F
0 0 0 r
.28148 .52242 m .27675 .52388 L .27904 .52335 L F
.308 .799 .863 r
.27845 .52333 m .27904 .52335 L .27675 .52388 L F
.685 .971 .92 r
.27517 .52438 m .27459 .52458 L .27675 .52388 L F
0 0 0 r
.28148 .52242 m .27865 .52321 L .27675 .52388 L F
.606 .952 .898 r
.71694 .32287 m .71795 .32298 L .72032 .32155 L F
.536 .281 .476 r
.38716 .58087 m .38747 .58215 L .38542 .58002 L F
.38716 .58087 m .38902 .58261 L .38747 .58215 L F
.083 .6 .882 r
.19778 .59771 m .19814 .59728 L .19807 .59543 L F
.19778 .59771 m .20202 .59835 L .19814 .59728 L F
.623 .836 .982 r
.37823 .53265 m .37873 .53398 L .38056 .53169 L F
.37823 .53265 m .37873 .53398 L .38056 .53169 L F
0 0 .335 r
.37873 .53398 m .37966 .53601 L .37823 .53265 L F
.653 .447 .593 r
.30864 .63009 m .31115 .62765 L .3095 .62937 L F
.765 .996 .836 r
.31439 .53256 m .31427 .53425 L .31644 .53304 L F
.586 .075 .005 r
.30897 .52857 m .30908 .52992 L .30917 .52989 L F
.666 .315 .369 r
.30897 .52857 m .30996 .53014 L .30883 .52769 L F
.30897 .52857 m .31125 .5288 L .30996 .53014 L F
.586 .075 .005 r
.30897 .52857 m .30917 .52989 L .31109 .52914 L F
.666 .315 .369 r
.30897 .52857 m .30883 .52769 L .30823 .52637 L F
.597 .616 .841 r
.24207 .60397 m .24126 .60883 L .23966 .60466 L F
.24207 .60397 m .24397 .6086 L .24126 .60883 L F
.513 .456 .73 r
.24392 .60992 m .24126 .60883 L .24397 .6086 L F
.296 .215 .593 r
.30408 .60453 m .30262 .60289 L .30481 .60218 L F
.30408 .60453 m .30287 .60535 L .30262 .60289 L F
.058 0 0 r
.24156 .53123 m .24222 .53182 L .24377 .53085 L F
.24156 .53123 m .23996 .53253 L .24222 .53182 L F
.076 0 .277 r
.30269 .55818 m .30485 .55469 L .30201 .55575 L F
.744 .491 .548 r
.36326 .55496 m .36036 .55723 L .3615 .55507 L F
.43 .327 .637 r
.31098 .58656 m .3096 .58964 L .30904 .58714 L F
0 0 .29 r
.32702 .57395 m .32795 .57351 L .32808 .57067 L F
0 0 .513 r
.32702 .57395 m .32826 .57629 L .32795 .57351 L F
.67 .792 .939 r
.65041 .40465 m .65293 .40364 L .64909 .40305 L F
.65041 .40465 m .65293 .40364 L .64909 .40305 L F
.27 .771 .875 r
.35729 .54924 m .35613 .54929 L .35507 .54959 L F
.35613 .54929 m .35328 .54943 L .35507 .54959 L F
.203 .049 .438 r
.35507 .54959 m .35334 .5518 L .35328 .55008 L F
.35507 .54959 m .35328 .55008 L .35323 .54878 L F
.996 .825 .469 r
.42039 .56809 m .4201 .5712 L .41928 .56947 L F
.963 .649 .377 r
.42039 .56809 m .41928 .56947 L .41883 .56699 L F
.722 .546 .652 r
.42354 .57121 m .4201 .5712 L .42039 .56809 L F
.047 0 .351 r
.33523 .64426 m .3367 .64031 L .33647 .64293 L F
.231 .205 .622 r
.33698 .64574 m .33523 .64426 L .33647 .64293 L F
.947 .849 .713 r
.36882 .54016 m .3685 .5426 L .36653 .5414 L F
.616 .541 .747 r
.37068 .54179 m .3685 .5426 L .36882 .54016 L F
.654 .544 .718 r
.37202 .54363 m .3685 .5426 L .37068 .54179 L F
.37202 .54363 m .3698 .54628 L .3685 .5426 L F
.528 .487 .754 r
.31449 .53739 m .31556 .53998 L .3176 .53895 L F
0 0 .514 r
.40876 .58242 m .40874 .5863 L .40795 .58642 L F
0 .065 .585 r
.40874 .5863 m .40953 .58871 L .40795 .58642 L F
.682 .273 0 r
.28163 .6433 m .28365 .64679 L .28307 .64606 L F
0 .021 .535 r
.28307 .64606 m .28365 .64679 L .28543 .64856 L F
.041 .505 .886 r
.23277 .62141 m .23148 .61987 L .22892 .61801 L F
.23277 .62141 m .23308 .62113 L .23148 .61987 L F
.368 .767 .985 r
.21496 .61006 m .22022 .61055 L .2178 .61044 L F
.27 .776 .831 r
.22022 .61055 m .21991 .61023 L .2178 .61044 L F
.22022 .61055 m .22221 .61017 L .21991 .61023 L F
.737 .723 .838 r
.62606 .40092 m .62709 .40408 L .62319 .40341 L F
.739 .724 .837 r
.62961 .40174 m .62709 .40408 L .62606 .40092 L F
.142 .554 .925 r
.24232 .6283 m .24309 .62752 L .24117 .62701 L F
.24232 .6283 m .24531 .62911 L .24309 .62752 L F
.572 .55 .791 r
.35138 .52907 m .35001 .53328 L .34851 .52934 L F
.35138 .52907 m .35281 .53324 L .35001 .53328 L F
.871 .628 .568 r
.3371 .69718 m .33682 .69976 L .33488 .69647 L F
.278 .556 .928 r
.30506 .63289 m .30656 .63388 L .30821 .6337 L F
.272 0 .038 r
.24522 .54903 m .24742 .54888 L .24747 .54809 L F
.24522 .54903 m .24386 .55084 L .24742 .54888 L F
.749 .652 .753 r
.71416 .33746 m .71219 .34051 L .71666 .34034 L F
.505 0 0 r
.71219 .34051 m .71379 .34119 L .71666 .34034 L F
.552 .725 .955 r
.32036 .54724 m .321 .54512 L .31894 .54529 L F
.32036 .54724 m .32263 .54689 L .321 .54512 L F
.75 .834 .916 r
.31527 .51587 m .30955 .5169 L .31242 .51466 L F
.912 .852 .77 r
.31527 .51587 m .31448 .51308 L .31639 .51481 L F
.31527 .51587 m .31242 .51466 L .31448 .51308 L F
.23 0 0 r
.35622 .52015 m .35283 .52222 L .35387 .52084 L F
.37 .509 .867 r
.36131 .62304 m .35992 .62488 L .35849 .62193 L F
.627 .805 .968 r
.3665 .62831 m .36782 .62909 L .36656 .62754 L F
.434 .427 .752 r
.35145 .63095 m .35216 .63391 L .35398 .63342 L F
.383 .216 .528 r
.35216 .63391 m .35459 .63604 L .35398 .63342 L F
.35216 .63391 m .35222 .63739 L .35459 .63604 L F
.526 .284 .49 r
.35212 .52664 m .34851 .52934 L .34833 .52653 L F
.636 .172 .134 r
.40088 .57626 m .39833 .57423 L .39788 .57589 L F
.472 .404 .699 r
.33253 .55822 m .33515 .56125 L .33464 .55768 L F
.33253 .55822 m .33313 .56212 L .33515 .56125 L F
.344 .097 .389 r
.30921 .59794 m .30732 .59562 L .30965 .59541 L F
.30921 .59794 m .30716 .59838 L .30732 .59562 L F
.233 .751 .779 r
.30452 .51921 m .30737 .51853 L .30726 .51813 L F
.30452 .51921 m .30279 .51944 L .30737 .51853 L F
.315 0 0 r
.25697 .63347 m .25408 .63447 L .25294 .63407 L F
.293 .791 .824 r
.25946 .63282 m .25787 .63294 L .25697 .63347 L F
.332 .805 .728 r
.25787 .63294 m .25408 .63447 L .25697 .63347 L F
.189 .504 .909 r
.37734 .57607 m .37902 .57821 L .37667 .577 L F
.362 0 .039 r
.37667 .577 m .3746 .5792 L .37722 .57871 L F
.658 .504 .664 r
.3718 .57579 m .37205 .57954 L .36851 .57982 L F
.587 .552 .782 r
.37331 .57559 m .37205 .57954 L .3718 .57579 L F
.37331 .57559 m .3746 .5792 L .37205 .57954 L F
.362 0 .039 r
.37667 .577 m .37697 .57793 L .37731 .57668 L F
.37697 .57793 m .37722 .57871 L .37726 .57776 L F
.37697 .57793 m .37726 .57776 L .37731 .57668 L F
.632 .578 .775 r
.37722 .57871 m .37331 .57559 L .37652 .57598 L F
.362 0 .039 r
.37729 .57614 m .37731 .57668 L .37734 .57607 L F
.37667 .577 m .37731 .57668 L .37729 .57614 L F
.632 .578 .775 r
.37726 .57776 m .37652 .57598 L .37734 .57607 L F
.37722 .57871 m .37652 .57598 L .37726 .57776 L F
0 0 .544 r
.37668 .5763 m .37735 .57771 L .37804 .57709 L F
.37735 .57771 m .37801 .5791 L .37804 .57729 L F
.37735 .57771 m .37804 .57729 L .37804 .57709 L F
.632 .578 .775 r
.37722 .57871 m .3746 .5792 L .37331 .57559 L F
.603 .435 .628 r
.37722 .57871 m .37471 .58193 L .3746 .5792 L F
.3746 .5792 m .37471 .58193 L .37722 .57871 L F
.847 .497 .39 r
.37173 .57687 m .37739 .57888 L .37668 .5763 L F
.37739 .57888 m .37801 .5791 L .37735 .57771 L F
.37739 .57888 m .37735 .57771 L .37668 .5763 L F
.741 .681 .793 r
.37185 .53016 m .37297 .53367 L .36944 .53292 L F
.868 .834 .812 r
.37297 .53367 m .3693 .53546 L .36944 .53292 L F
.613 .585 .799 r
.37423 .52919 m .37297 .53367 L .37185 .53016 L F
.37423 .52919 m .37589 .53402 L .37297 .53367 L F
.045 0 .08 r
.37798 .65174 m .37488 .6535 L .37828 .64974 L F
.045 0 0 r
.3817 .6473 m .3807 .64963 L .37828 .64974 L F
.039 0 .056 r
.3807 .64963 m .37798 .65174 L .37828 .64974 L F
.673 .455 .58 r
.36287 .53562 m .35996 .53335 L .36316 .5336 L F
.36287 .53562 m .36016 .53597 L .35996 .53335 L F
0 0 0 r
.22946 .53897 m .2298 .53992 L .23127 .53871 L F
.22946 .53897 m .2281 .54123 L .2298 .53992 L F
0 0 .112 r
.36244 .57417 m .36241 .57666 L .36284 .5752 L F
.322 0 .109 r
.6219 .41045 m .62358 .41173 L .62243 .41326 L F
.6219 .41045 m .6245 .40953 L .62358 .41173 L F
.982 .695 .35 r
.37095 .57092 m .37121 .57344 L .36873 .57402 L F
.502 .429 .707 r
.3718 .57579 m .36873 .57402 L .37121 .57344 L F
.3718 .57579 m .3693 .57678 L .36873 .57402 L F
.423 0 0 r
.34021 .54873 m .33808 .55062 L .3356 .55047 L F
.384 0 0 r
.34082 .55035 m .34021 .54873 L .34231 .54792 L F
.34082 .55035 m .33808 .55062 L .34021 .54873 L F
0 .118 .643 r
.38834 .52445 m .38721 .52399 L .38571 .52273 L F
.38834 .52445 m .38939 .52592 L .38721 .52399 L F
.43 .295 .595 r
.31699 .55395 m .31497 .55148 L .31658 .55107 L F
.31699 .55395 m .31479 .55489 L .31497 .55148 L F
.663 .566 .735 r
.38972 .61176 m .38773 .61506 L .38629 .61145 L F
.332 .165 .499 r
.38972 .61176 m .38962 .61441 L .38773 .61506 L F
.253 .087 .452 r
.38962 .61441 m .38776 .61762 L .38773 .61506 L F
.325 .648 .968 r
.34558 .50323 m .34772 .50329 L .34705 .50475 L F
.35 .676 .977 r
.34772 .50329 m .34934 .50483 L .34705 .50475 L F
.829 .817 .838 r
.70114 .31962 m .69702 .32121 L .69957 .318 L F
.866 .759 .742 r
.6099 .42321 m .6098 .42618 L .60845 .42523 L F
.803 .442 .374 r
.6098 .42618 m .60803 .42781 L .60845 .42523 L F
.6098 .42618 m .61174 .42864 L .60803 .42781 L F
.854 .457 .289 r
.36597 .57997 m .36241 .57666 L .36355 .5805 L F
.597 .276 .396 r
.36597 .57997 m .36828 .58206 L .36543 .58216 L F
.244 0 0 r
.36828 .58206 m .36628 .58199 L .36543 .58216 L F
.423 .117 .34 r
.36597 .57997 m .36543 .58216 L .36355 .5805 L F
.261 .132 .509 r
.36543 .58216 m .36355 .58253 L .36355 .5805 L F
.924 .564 .326 r
.36543 .58216 m .36417 .58192 L .36373 .5797 L F
.244 0 0 r
.36628 .58199 m .36417 .58192 L .36543 .58216 L F
.261 .132 .509 r
.36543 .58216 m .36355 .58319 L .36355 .58253 L F
.36543 .58216 m .36355 .58319 L .36355 .5805 L F
.264 .536 .919 r
.23463 .62237 m .23507 .62079 L .23308 .62113 L F
.66 .227 .21 r
.31291 .65324 m .31386 .65243 L .31021 .65226 L F
.5 .031 .074 r
.3152 .65431 m .31386 .65243 L .31291 .65324 L F
.3152 .65431 m .31691 .65267 L .31386 .65243 L F
.755 .595 .679 r
.61595 .43175 m .62032 .43178 L .61733 .43509 L F
.761 .605 .684 r
.62032 .43178 m .62163 .43732 L .61733 .43509 L F
.439 .504 .829 r
.34718 .66873 m .3455 .66526 L .34451 .66758 L F
.34718 .66873 m .34729 .66467 L .3455 .66526 L F
.34718 .66873 m .35022 .6696 L .34729 .66467 L F
.741 .244 .051 r
.34661 .66859 m .34718 .66873 L .34451 .66758 L F
0 .216 .738 r
.22816 .61786 m .22719 .61469 L .22574 .61438 L F
.22816 .61786 m .22892 .61801 L .22719 .61469 L F
.888 .716 .663 r
.39993 .58734 m .39886 .59101 L .39699 .58904 L F
.266 .459 .863 r
.34843 .64346 m .35165 .64503 L .34984 .64296 L F
.86 .859 .838 r
.34743 .6479 m .35165 .64503 L .34843 .64346 L F
.575 .601 .842 r
.33955 .6214 m .34362 .62431 L .34194 .62086 L F
.718 .752 .879 r
.34601 .62129 m .34291 .62262 L .34194 .62086 L F
.754 .693 .793 r
.34194 .62086 m .34362 .62431 L .34601 .62129 L F
.599 .465 .671 r
.34362 .62431 m .34567 .62373 L .34601 .62129 L F
.584 .552 .785 r
.34362 .62431 m .34736 .62762 L .34567 .62373 L F
.055 0 0 r
.19565 .56699 m .19743 .56643 L .19911 .56443 L F
.189 0 0 r
.19743 .56643 m .20121 .56352 L .19911 .56443 L F
.278 .556 .928 r
.30506 .63289 m .30821 .6337 L .30864 .63009 L F
.447 .193 .435 r
.37798 .65174 m .3751 .65685 L .37488 .6535 L F
.753 .617 .708 r
.34567 .62373 m .34736 .62762 L .34961 .62423 L F
.565 .434 .66 r
.39286 .62794 m .39109 .63131 L .38995 .62757 L F
.39286 .62794 m .39296 .63072 L .39109 .63131 L F
0 0 .048 r
.39296 .63072 m .39089 .63368 L .39109 .63131 L F
.64 .355 .471 r
.3907 .58949 m .39421 .58694 L .39291 .58599 L F
.3907 .58949 m .39428 .58922 L .39421 .58694 L F
.595 .32 .47 r
.39428 .58922 m .39699 .58904 L .39421 .58694 L F
.7 .971 .754 r
.29961 .63257 m .30223 .63099 L .30032 .63001 L F
0 .22 .742 r
.39085 .53026 m .3931 .53192 L .3927 .53309 L F
0 .113 .666 r
.3931 .53192 m .39484 .53543 L .3927 .53309 L F
.318 .016 .285 r
.31915 .57385 m .31879 .57665 L .31626 .57655 L F
0 0 .126 r
.31987 .57514 m .31915 .57385 L .32044 .57266 L F
.31987 .57514 m .31879 .57665 L .31915 .57385 L F
.38 .125 .397 r
.32881 .58679 m .32606 .58995 L .32813 .58923 L F
.183 0 .308 r
.32881 .58679 m .32926 .58836 L .33071 .58571 L F
.32881 .58679 m .32813 .58923 L .32926 .58836 L F
.804 .916 .915 r
.27721 .62034 m .27579 .62023 L .27873 .61785 L F
.322 .106 .422 r
.31235 .55827 m .31215 .56063 L .31001 .5615 L F
.31215 .56063 m .31214 .56081 L .31204 .56084 L F
.31215 .56063 m .31204 .56084 L .31001 .5615 L F
.31214 .56081 m .31208 .56087 L .31165 .561 L F
.3116 .56098 m .31165 .561 L .31001 .5615 L F
.31214 .56081 m .31165 .561 L .3116 .56098 L F
.538 .33 .546 r
.31165 .561 m .3091 .56355 L .31001 .5615 L F
.31213 .56086 m .3119 .56107 L .31165 .561 L F
.073 .28 .767 r
.31186 .56106 m .31188 .56111 L .3119 .56107 L F
.538 .33 .546 r
.31186 .56106 m .3091 .56355 L .31165 .561 L F
.846 .739 .745 r
.30711 .5597 m .31183 .5611 L .30994 .55649 L F
.31183 .5611 m .31188 .56112 L .31186 .56107 L F
.31183 .5611 m .31186 .56107 L .30994 .55649 L F
.522 .298 .516 r
.31184 .56117 m .31188 .56112 L .31183 .5611 L F
.31178 .56115 m .31183 .5611 L .30711 .5597 L F
.31184 .56117 m .31183 .5611 L .31178 .56115 L F
.538 .33 .546 r
.3119 .56107 m .31173 .56122 L .31183 .5611 L F
.31187 .56106 m .31183 .5611 L .31186 .56106 L F
.846 .739 .745 r
.31188 .56112 m .31188 .56111 L .30994 .55649 L F
.538 .33 .546 r
.3119 .56107 m .31183 .5611 L .31187 .56106 L F
.522 .298 .516 r
.3091 .56355 m .31184 .56117 L .31178 .56115 L F
.538 .33 .546 r
.31183 .5611 m .3091 .56355 L .31186 .56106 L F
.522 .298 .516 r
.3091 .56355 m .31178 .56115 L .30711 .5597 L F
.538 .33 .546 r
.31173 .56122 m .3091 .56355 L .31183 .5611 L F
.54 .357 .582 r
.31447 .55776 m .31213 .56086 L .31235 .55827 L F
.073 .28 .767 r
.30994 .55649 m .31186 .56106 L .3126 .55876 L F
.31186 .56106 m .3119 .56107 L .3126 .55876 L F
.31188 .56111 m .31189 .56112 L .31189 .56111 L F
.31188 .56111 m .31189 .56111 L .3126 .55876 L F
.846 .739 .745 r
.31188 .56112 m .31189 .56112 L .31188 .56111 L F
.522 .298 .516 r
.31184 .56117 m .31189 .56112 L .31188 .56112 L F
.322 .106 .422 r
.31214 .56081 m .31213 .56086 L .31208 .56087 L F
.494 .593 .882 r
.38612 .66153 m .38515 .66449 L .38525 .6618 L F
.38612 .66153 m .38782 .66483 L .38515 .66449 L F
.299 .772 .933 r
.38167 .65559 m .38007 .65638 L .37803 .65656 L F
.38167 .65559 m .38273 .65607 L .38007 .65638 L F
.822 .928 .547 r
.22215 .59141 m .22205 .59281 L .22373 .58937 L F
0 .186 .719 r
.22215 .59141 m .22416 .59474 L .22205 .59281 L F
.101 .334 .806 r
.33313 .56212 m .33552 .56365 L .33515 .56125 L F
.675 .854 .968 r
.56538 .39768 m .56381 .40061 L .56237 .39931 L F
.56538 .39768 m .56686 .39922 L .56381 .40061 L F
.165 .215 .669 r
.56381 .40061 m .56538 .39768 L .56237 .39931 L F
.56381 .40061 m .5665 .40526 L .56538 .39768 L F
.667 .609 .781 r
.32405 .66181 m .32329 .66537 L .32167 .66507 L F
.749 .294 .17 r
.32329 .66537 m .32211 .66646 L .32167 .66507 L F
.32329 .66537 m .32566 .66766 L .32211 .66646 L F
.414 .849 .94 r
.13825 .70504 m .14073 .70521 L .138 .70594 L F
.138 .70594 m .14073 .70521 L .13825 .70504 L F
.884 .742 .234 r
.40745 .57203 m .40813 .57109 L .40724 .5695 L F
.40745 .57203 m .40791 .57335 L .40813 .57109 L F
.522 .233 .416 r
.34891 .57354 m .35212 .57209 L .34826 .57012 L F
.723 .567 .677 r
.37759 .57163 m .37855 .57362 L .3754 .57362 L F
.617 .56 .768 r
.3803 .57009 m .37855 .57362 L .37759 .57163 L F
.536 .494 .757 r
.33945 .56481 m .33773 .56755 L .33552 .56365 L F
.33945 .56481 m .34003 .56698 L .33773 .56755 L F
.988 .725 .424 r
.69324 .3315 m .69194 .33253 L .69191 .32992 L F
.545 .53 .79 r
.69454 .32687 m .69324 .3315 L .69191 .32992 L F
.69454 .32687 m .69632 .33081 L .69324 .3315 L F
.745 .511 .576 r
.69632 .33081 m .69194 .33253 L .69324 .3315 L F
.552 .596 .851 r
.26865 .53631 m .26933 .53293 L .26725 .5327 L F
.26865 .53631 m .27108 .53587 L .26933 .53293 L F
.53 .388 .632 r
.26865 .53631 m .27111 .53882 L .27108 .53587 L F
.26865 .53631 m .26877 .5394 L .27111 .53882 L F
.364 .033 .263 r
.37783 .70623 m .37686 .709 L .37447 .70972 L F
.336 0 .217 r
.38023 .70579 m .37686 .709 L .37783 .70623 L F
.202 0 0 r
.28048 .5487 m .27597 .54933 L .27792 .54854 L F
.654 .714 .892 r
.21449 .58169 m .21622 .58343 L .21348 .58293 L F
.915 .866 .777 r
.71184 .3545 m .70922 .356 L .71079 .35394 L F
.71184 .3545 m .70998 .35708 L .70922 .356 L F
.616 .943 .947 r
.71079 .35394 m .71426 .35314 L .71184 .3545 L F
.183 .417 .852 r
.21033 .60377 m .21119 .60594 L .21191 .6043 L F
.179 .411 .849 r
.21119 .60594 m .21417 .60772 L .21191 .6043 L F
.54 .422 .667 r
.21554 .57917 m .21449 .58169 L .21233 .58042 L F
.654 .714 .892 r
.21449 .58169 m .21348 .58293 L .21233 .58042 L F
.658 .504 .664 r
.3718 .57579 m .36851 .57982 L .3693 .57678 L F
.476 .759 .992 r
.36944 .58831 m .37181 .58997 L .36883 .58991 L F
.668 .197 .125 r
.36883 .58991 m .36733 .59149 L .36944 .58831 L F
.36883 .58991 m .37111 .5919 L .36733 .59149 L F
.588 .255 .372 r
.37181 .58997 m .37111 .5919 L .36883 .58991 L F
.787 .727 .797 r
.41091 .52549 m .40643 .52601 L .40934 .52345 L F
.41091 .52549 m .40853 .5272 L .40643 .52601 L F
.649 .452 .603 r
.41091 .52549 m .4099 .52931 L .40853 .5272 L F
.482 .534 .834 r
.41166 .52195 m .41091 .52549 L .40934 .52345 L F
.41166 .52195 m .41355 .52568 L .41091 .52549 L F
.148 0 .38 r
.41144 .52796 m .41091 .52549 L .41355 .52568 L F
.41144 .52796 m .4099 .52931 L .41091 .52549 L F
.853 .73 .727 r
.69702 .32121 m .69827 .32528 L .69506 .32439 L F
.857 .513 .402 r
.69506 .32439 m .69827 .32528 L .69865 .32764 L F
.7 .386 .442 r
.69827 .32528 m .70099 .32609 L .69865 .32764 L F
0 .331 .81 r
.37651 .51529 m .37531 .51559 L .37361 .51393 L F
0 0 0 r
.38194 .64785 m .3817 .6473 L .38332 .64586 L F
.38194 .64785 m .3807 .64963 L .3817 .6473 L F
.34489 .63072 m .34072 .632 L .34317 .6318 L F
.615 .467 .657 r
.34736 .62762 m .3484 .62986 L .34489 .63072 L F
.576 .354 .541 r
.34472 .63354 m .34489 .63072 L .34317 .6318 L F
.34472 .63354 m .3484 .62986 L .34489 .63072 L F
.633 .807 .966 r
.34489 .63072 m .3484 .62986 L .34472 .63354 L F
.576 .783 .977 r
.6055 .43322 m .6043 .43543 L .60299 .43396 L F
.6055 .43322 m .60691 .43474 L .6043 .43543 L F
.6055 .43322 m .6043 .43543 L .60299 .43396 L F
.6055 .43322 m .60691 .43474 L .6043 .43543 L F
.335 0 .016 r
.23735 .55395 m .24157 .5516 L .23925 .55085 L F
.796 .481 .456 r
.33862 .65412 m .34084 .65288 L .33964 .65258 L F
.346 .525 .889 r
.21417 .60772 m .21496 .61006 L .2178 .61044 L F
.992 .739 .4 r
.33647 .64293 m .3367 .64031 L .33548 .63926 L F
.743 .726 .836 r
.27998 .53233 m .28275 .53358 L .28329 .53242 L F
0 0 0 r
.2819 .53654 m .28329 .53242 L .28275 .53358 L F
.273 0 0 r
.40894 .59307 m .40783 .59464 L .40482 .59502 L F
.927 .882 .463 r
.40864 .59118 m .40783 .59464 L .40894 .59307 L F
0 0 0 r
.33424 .57953 m .33541 .57903 L .3365 .57764 L F
.337 .348 .724 r
.33448 .58221 m .33541 .57903 L .33424 .57953 L F
.466 .822 .996 r
.5745 .40264 m .57537 .40381 L .5716 .40401 L F
.747 .888 .943 r
.62163 .43732 m .61746 .43767 L .61733 .43509 L F
0 0 .248 r
.39692 .53884 m .39769 .54152 L .39788 .54262 L F
.831 .554 .007 r
.39769 .54152 m .39854 .54472 L .39788 .54262 L F
.7 .653 .8 r
.72038 .33954 m .72317 .33659 L .72014 .33651 L F
.217 .091 .486 r
.19226 .57721 m .19374 .57648 L .19381 .57377 L F
.357 .241 .582 r
.19213 .57991 m .19374 .57648 L .19226 .57721 L F
.753 .761 .252 r
.32961 .69099 m .32896 .69277 L .32844 .69001 L F
.32961 .69099 m .32886 .69375 L .32896 .69277 L F
.969 .693 .453 r
.34072 .632 m .34237 .63418 L .34033 .63599 L F
.092 0 0 r
.34033 .63599 m .34237 .63418 L .34472 .63354 L F
.723 .721 .848 r
.39699 .58904 m .39865 .59257 L .40043 .58986 L F
.575 .519 .755 r
.39865 .59257 m .40207 .59279 L .40043 .58986 L F
.63 .433 .597 r
.39745 .5929 m .40207 .59279 L .39865 .59257 L F
.13 0 .372 r
.30715 .57734 m .30685 .57987 L .3086 .57631 L F
.293 .183 .553 r
.19368 .57109 m .19536 .57289 L .19569 .5697 L F
.19368 .57109 m .19381 .57377 L .19536 .57289 L F
.205 0 .059 r
.6432 .43255 m .64245 .43407 L .63991 .43489 L F
0 0 0 r
.64555 .42994 m .6432 .43255 L .64564 .42922 L F
.419 .226 .511 r
.64555 .42994 m .64245 .43407 L .6432 .43255 L F
.215 .448 .868 r
.38494 .52076 m .38276 .52136 L .38175 .51969 L F
.38494 .52076 m .38571 .52273 L .38276 .52136 L F
.669 .52 .674 r
.3903 .61027 m .38972 .61176 L .38629 .61145 L F
.467 .864 .682 r
.35306 .66843 m .34893 .6709 L .35178 .6683 L F
.057 .615 .806 r
.35371 .66821 m .35306 .66843 L .35178 .6683 L F
.35371 .66821 m .35576 .66853 L .35306 .66843 L F
0 .408 .828 r
.26344 .63422 m .26391 .6337 L .26186 .6328 L F
.211 .564 .937 r
.26391 .6337 m .26772 .63579 L .26685 .63461 L F
.72 .234 .089 r
.26772 .63579 m .26771 .63591 L .26685 .63461 L F
0 .408 .828 r
.26344 .63422 m .26826 .63652 L .26522 .63455 L F
.26382 .6338 m .26522 .63455 L .26391 .6337 L F
.26344 .63422 m .26522 .63455 L .26382 .6338 L F
.009 .531 .857 r
.26762 .63626 m .26984 .63684 L .26772 .63579 L F
.26762 .63626 m .26772 .63579 L .26881 .63678 L F
0 .408 .828 r
.26826 .63652 m .26881 .63678 L .26809 .63633 L F
.26826 .63652 m .26809 .63633 L .26391 .6337 L F
.514 0 0 r
.26344 .63422 m .26762 .63626 L .26881 .63678 L F
.211 .564 .937 r
.26391 .6337 m .26881 .63678 L .26772 .63579 L F
.72 .234 .089 r
.26771 .63591 m .2703 .6381 L .2676 .63745 L F
.26772 .63579 m .26806 .63609 L .26771 .63591 L F
.26806 .63609 m .2703 .6381 L .26771 .63591 L F
.26771 .63591 m .2676 .63745 L .26697 .63506 L F
.26771 .63591 m .26697 .63506 L .26685 .63461 L F
0 0 .185 r
.3743 .58319 m .37471 .58193 L .3746 .5792 L F
.798 .412 .324 r
.3743 .58319 m .37208 .58494 L .37471 .58193 L F
.3743 .58319 m .37638 .58588 L .37208 .58494 L F
.717 .387 .42 r
.72089 .35026 m .71973 .35219 L .71879 .34969 L F
.72089 .35026 m .72333 .35274 L .71973 .35219 L F
.444 .124 .328 r
.36011 .56765 m .36184 .5674 L .36352 .56478 L F
0 0 0 r
.36352 .56478 m .36361 .56539 L .36328 .5627 L F
.36352 .56478 m .36184 .5674 L .36361 .56539 L F
.444 .16 .387 r
.33029 .59643 m .33024 .59847 L .32771 .59901 L F
.319 .067 .365 r
.33228 .59783 m .33029 .59643 L .33381 .59585 L F
.33228 .59783 m .33024 .59847 L .33029 .59643 L F
.89 .751 .702 r
.35291 .64394 m .35428 .64373 L .3541 .6409 L F
.739 .639 .749 r
.3541 .6409 m .35428 .64373 L .35666 .64019 L F
0 0 .467 r
.28084 .6376 m .2811 .6406 L .28185 .6386 L F
.451 .102 .282 r
.27969 .63882 m .28118 .64087 L .27821 .64136 L F
.831 .563 .015 r
.2811 .6406 m .28163 .6433 L .28081 .642 L F
.753 .336 .257 r
.2814 .64155 m .28185 .6386 L .28102 .64132 L F
.316 .413 .802 r
.28242 .64217 m .2823 .64315 L .28159 .64166 L F
.434 .426 .751 r
.2823 .64315 m .28131 .6421 L .28081 .642 L F
.649 .255 0 r
.28127 .64282 m .28163 .6433 L .28307 .64606 L F
.28081 .642 m .28099 .64228 L .28127 .64282 L F
.28099 .64228 m .28163 .6433 L .28127 .64282 L F
.657 .296 .348 r
.28075 .64442 m .2817 .64364 L .27995 .64596 L F
.649 .255 0 r
.28081 .642 m .28127 .64282 L .2823 .64315 L F
.28127 .64282 m .28307 .64606 L .2823 .64315 L F
.657 .296 .348 r
.2817 .64364 m .2823 .64315 L .28177 .64378 L F
.2817 .64364 m .28177 .64378 L .27995 .64596 L F
.886 .673 .608 r
.28131 .6421 m .2823 .64315 L .28102 .64256 L F
.28159 .64166 m .2823 .64315 L .28131 .6421 L F
.753 .336 .257 r
.28427 .64271 m .28266 .63996 L .28157 .64169 L F
.28284 .64241 m .28157 .64169 L .28131 .6421 L F
.28427 .64271 m .28157 .64169 L .28284 .64241 L F
.316 .413 .802 r
.28261 .64049 m .28325 .64186 L .28284 .64241 L F
.28242 .64217 m .28284 .64241 L .2823 .64315 L F
.28261 .64049 m .28284 .64241 L .28242 .64217 L F
.434 .426 .751 r
.2823 .64315 m .28427 .64271 L .28284 .64241 L F
.2823 .64315 m .28473 .64506 L .28427 .64271 L F
.316 .413 .802 r
.28325 .64186 m .28473 .64506 L .2823 .64315 L F
.434 .426 .751 r
.2823 .64315 m .28284 .64241 L .28131 .6421 L F
.753 .336 .257 r
.28266 .63996 m .28185 .6386 L .28131 .6421 L F
.316 .413 .802 r
.28261 .64049 m .28242 .64217 L .28126 .64098 L F
.28242 .64217 m .28159 .64166 L .28126 .64098 L F
.753 .336 .257 r
.28131 .6421 m .2814 .64155 L .28081 .642 L F
.2814 .64155 m .28102 .64132 L .28081 .642 L F
.886 .673 .608 r
.28102 .64256 m .2823 .64315 L .28075 .64442 L F
.28126 .64098 m .28159 .64166 L .28102 .64256 L F
.451 .102 .282 r
.28118 .64087 m .28126 .64098 L .28114 .64099 L F
.28118 .64087 m .28114 .64099 L .27821 .64136 L F
.831 .563 .015 r
.2811 .6406 m .28081 .642 L .28161 .63939 L F
.2818 .63872 m .28161 .63939 L .28185 .6386 L F
.2811 .6406 m .28161 .63939 L .2818 .63872 L F
.508 .214 .401 r
.28329 .53242 m .2826 .53561 L .28557 .53432 L F
.743 .726 .836 r
.27998 .53233 m .28329 .53242 L .2833 .5327 L F
.619 .767 .951 r
.27998 .53233 m .28325 .53269 L .28128 .53003 L F
.28325 .53269 m .2833 .5327 L .28327 .53265 L F
.28325 .53269 m .28327 .53265 L .28128 .53003 L F
0 0 0 r
.2819 .53654 m .2826 .53561 L .28322 .53276 L F
.28308 .53303 m .28322 .53276 L .28329 .53242 L F
.2819 .53654 m .28322 .53276 L .28308 .53303 L F
.28057 .53883 m .2826 .53561 L .2819 .53654 L F
.173 0 0 r
.37209 .71024 m .37447 .70972 L .37048 .71148 L F
.325 .296 .672 r
.42548 .56435 m .42791 .5664 L .42548 .56775 L F
.183 .066 .476 r
.42791 .5664 m .42592 .5697 L .42548 .56775 L F
.704 .17 0 r
.38834 .62178 m .39167 .62413 L .39273 .62407 L F
.725 .577 .688 r
.39273 .62407 m .39286 .62794 L .38995 .62757 L F
.819 .997 .848 r
.39273 .62407 m .3937 .62173 L .3951 .62336 L F
.39273 .62407 m .39167 .62413 L .3937 .62173 L F
.578 .461 .684 r
.39545 .62638 m .39273 .62407 L .3951 .62336 L F
.39545 .62638 m .39286 .62794 L .39273 .62407 L F
.899 .916 .824 r
.64519 .40188 m .6479 .40101 L .64791 .39906 L F
.64519 .40188 m .64648 .40291 L .6479 .40101 L F
.234 0 .197 r
.31626 .57655 m .31542 .57928 L .31334 .5801 L F
.653 .895 .558 r
.31987 .57514 m .31743 .57813 L .31879 .57665 L F
.717 .939 .625 r
.31813 .57655 m .31743 .57813 L .31987 .57514 L F
.576 .567 .807 r
.31813 .57655 m .3175 .57935 L .31743 .57813 L F
.3175 .57935 m .31713 .58101 L .31743 .57813 L F
.165 0 .169 r
.31743 .57813 m .31626 .57655 L .31734 .57659 L F
.31743 .57813 m .31734 .57659 L .31879 .57665 L F
.31743 .57813 m .31542 .57928 L .31626 .57655 L F
0 0 0 r
.64757 .42743 m .64564 .42922 L .6482 .4259 L F
.64757 .42743 m .64555 .42994 L .64564 .42922 L F
.828 .501 0 r
.40863 .57638 m .40928 .57717 L .40791 .57335 L F
0 0 .099 r
.40957 .5782 m .40928 .57717 L .40863 .57638 L F
.40957 .5782 m .40933 .57989 L .40928 .57717 L F
.661 .303 .356 r
.37855 .57362 m .37734 .57607 L .3754 .57362 L F
.318 .107 .428 r
.33297 .63695 m .33053 .64042 L .33294 .63979 L F
.343 .263 .62 r
.33053 .64042 m .33274 .64278 L .33294 .63979 L F
.33053 .64042 m .33098 .64267 L .33274 .64278 L F
.769 .664 .747 r
.27303 .75345 m .27205 .75719 L .27055 .75626 L F
0 0 .371 r
.27371 .75444 m .27224 .75687 L .27303 .75345 L F
.27224 .75687 m .27205 .75719 L .27214 .75685 L F
.27224 .75687 m .27214 .75685 L .27303 .75345 L F
.239 .209 .622 r
.27332 .75717 m .27205 .75719 L .27371 .75444 L F
0 .415 .745 r
.27055 .75626 m .27272 .75697 L .27115 .75624 L F
.27272 .75697 m .27332 .75717 L .273 .75704 L F
.27272 .75697 m .273 .75704 L .27115 .75624 L F
.174 .552 .93 r
.27055 .75626 m .27205 .75719 L .27332 .75717 L F
.457 .39 .694 r
.39542 .59521 m .39335 .59913 L .3922 .5952 L F
.653 .447 .593 r
.30864 .63009 m .31114 .63033 L .31115 .62765 L F
.485 .232 .455 r
.31114 .63033 m .31332 .6284 L .31115 .62765 L F
.422 .212 .487 r
.32606 .58995 m .32781 .59185 L .32813 .58923 L F
.205 .181 .608 r
.32606 .58995 m .32657 .59277 L .32781 .59185 L F
.388 .06 .283 r
.30471 .54189 m .30446 .54465 L .30207 .545 L F
.236 0 .251 r
.30591 .54234 m .30446 .54465 L .30471 .54189 L F
.516 .323 .558 r
.6465 .42202 m .6484 .42453 L .6482 .4259 L F
.768 .778 .277 r
.6484 .42453 m .64757 .42743 L .6482 .4259 L F
.566 .834 .996 r
.27808 .53136 m .2775 .53299 L .27998 .53233 L F
.14 0 .119 r
.29872 .58679 m .30069 .5861 L .30175 .58366 L F
.359 .008 .225 r
.30175 .58366 m .30304 .58499 L .30395 .58292 L F
.30175 .58366 m .30069 .5861 L .30304 .58499 L F
.628 .511 .702 r
.35101 .56841 m .35212 .57209 L .35418 .57056 L F
.294 0 0 r
.22221 .61017 m .22428 .61077 L .21991 .61023 L F
.396 0 .045 r
.31153 .65936 m .31257 .66101 L .30983 .65938 L F
.31153 .65936 m .31464 .65944 L .31257 .66101 L F
.926 .601 .141 r
.22525 .61208 m .22574 .61438 L .22428 .61077 L F
.448 .433 .749 r
.33751 .60801 m .33894 .60908 L .33827 .60521 L F
.839 .691 .699 r
.40853 .5272 m .40819 .52987 L .40643 .52601 L F
.543 .419 .661 r
.4099 .52931 m .40819 .52987 L .40853 .5272 L F
.44 .185 .429 r
.35359 .53867 m .35018 .54241 L .35201 .54006 L F
.946 .68 .501 r
.42354 .57121 m .42219 .57294 L .4201 .5712 L F
.42354 .57121 m .42406 .57386 L .42219 .57294 L F
.506 .193 .37 r
.42592 .5697 m .42406 .57386 L .42354 .57121 L F
.522 .233 .416 r
.34891 .57354 m .35149 .5731 L .35212 .57209 L F
0 0 .083 r
.34891 .57354 m .34938 .57483 L .35149 .5731 L F
.34891 .57354 m .34832 .57646 L .34938 .57483 L F
.336 .422 .802 r
.56849 .39938 m .5745 .40264 L .57075 .40027 L F
.486 .263 .5 r
.32556 .54256 m .32446 .54766 L .32263 .54689 L F
.973 .672 .382 r
.32556 .54256 m .32416 .54209 L .32368 .53895 L F
.863 .633 .589 r
.326 .54632 m .32556 .54256 L .32818 .54275 L F
.326 .54632 m .32446 .54766 L .32556 .54256 L F
.426 0 .03 r
.38052 .55658 m .37992 .55763 L .37725 .55774 L F
.617 .15 .121 r
.38234 .55765 m .37992 .55763 L .38052 .55658 L F
.757 .505 .552 r
.72125 .29867 m .72514 .29672 L .72125 .29616 L F
.72125 .29867 m .7253 .29925 L .72514 .29672 L F
.978 .69 .398 r
.36955 .57236 m .37121 .57344 L .37095 .57092 L F
.36955 .57236 m .37095 .57092 L .37212 .56993 L F
.639 .839 .977 r
.33057 .57304 m .3327 .5746 L .33482 .57351 L F
.764 .784 .87 r
.7106 .30512 m .711 .30876 L .70722 .30834 L F
.814 .669 .703 r
.711 .30876 m .7088 .3124 L .70722 .30834 L F
.824 .825 .849 r
.71356 .30579 m .711 .30876 L .7106 .30512 L F
.434 .427 .752 r
.35145 .63095 m .35398 .63342 L .35363 .6301 L F
.379 .182 .482 r
.31479 .55489 m .31447 .55776 L .31235 .55827 L F
.6 .855 .992 r
.35026 .51559 m .35003 .51732 L .34851 .51663 L F
.35026 .51559 m .35003 .51732 L .34851 .51663 L F
.801 .747 .803 r
.68805 .33765 m .68825 .34116 L .68455 .3405 L F
.876 .585 .065 r
.68825 .34116 m .68763 .34111 L .68455 .3405 L F
.68825 .34116 m .68843 .34297 L .68763 .34111 L F
.717 .683 .817 r
.69182 .34039 m .68825 .34116 L .68805 .33765 L F
.337 0 .122 r
.69182 .34039 m .68843 .34297 L .68825 .34116 L F
.539 .24 .408 r
.30485 .55469 m .30745 .55447 L .3082 .55229 L F
.351 .087 .367 r
.30745 .55447 m .31015 .55145 L .3082 .55229 L F
.55 .585 .842 r
.25993 .55836 m .26037 .55397 L .25924 .55533 L F
.581 .406 .61 r
.24549 .55316 m .24262 .55511 L .2429 .55372 L F
.334 .098 .399 r
.33641 .5928 m .33586 .59508 L .33381 .59585 L F
.033 0 0 r
.33437 .59691 m .33381 .59585 L .33586 .59508 L F
.33437 .59691 m .33228 .59783 L .33381 .59585 L F
.026 0 .068 r
.33714 .52045 m .33598 .52231 L .33525 .52225 L F
.33714 .52045 m .33598 .52231 L .33525 .52225 L F
.007 0 .388 r
.73137 .34599 m .73133 .34353 L .73173 .34306 L F
0 0 0 r
.73326 .33937 m .73173 .34306 L .73133 .34353 L F
.815 .779 .819 r
.30689 .52259 m .30955 .52367 L .31054 .52222 L F
.868 .721 .696 r
.30689 .52259 m .30823 .52637 L .30955 .52367 L F
.194 0 .334 r
.27971 .62363 m .27796 .62454 L .2801 .62133 L F
.504 .368 .629 r
.27971 .62363 m .27774 .62698 L .27796 .62454 L F
.04 .001 .48 r
.29047 .61668 m .28891 .61521 L .29134 .61446 L F
.29047 .61668 m .28901 .61789 L .28891 .61521 L F
.151 .691 .822 r
.28998 .52213 m .29388 .52208 L .29162 .52283 L F
.43 .327 .637 r
.31098 .58656 m .31165 .58913 L .3096 .58964 L F
.39 .294 .625 r
.31165 .58913 m .30986 .59286 L .3096 .58964 L F
.608 .046 0 r
.71014 .31673 m .71211 .31551 L .71175 .3142 L F
.843 .991 .852 r
.71454 .31139 m .71211 .31551 L .71499 .31211 L F
.71454 .31139 m .71175 .3142 L .71211 .31551 L F
.404 0 0 r
.71617 .31764 m .71211 .31551 L .7125 .318 L F
.414 .136 .38 r
.32808 .57067 m .33039 .57022 L .33101 .5677 L F
.634 .408 .557 r
.33039 .57022 m .33352 .56725 L .33101 .5677 L F
.276 .045 .372 r
.37658 .6115 m .37394 .61497 L .37681 .61309 L F
.629 .563 .761 r
.39727 .60223 m .39514 .60365 L .39335 .59913 L F
.947 .849 .713 r
.36882 .54016 m .36653 .5414 L .3696 .53879 L F
.244 .091 .465 r
.22691 .5766 m .22482 .58024 L .22468 .5775 L F
.778 .669 .743 r
.40643 .52601 m .40819 .52987 L .404 .52944 L F
.855 .593 .542 r
.40819 .52987 m .40447 .53137 L .404 .52944 L F
.40819 .52987 m .40811 .53279 L .40447 .53137 L F
.29 .13 .483 r
.40975 .53165 m .40819 .52987 L .4099 .52931 L F
.40975 .53165 m .40811 .53279 L .40819 .52987 L F
.717 .683 .817 r
.69182 .34039 m .68805 .33765 L .69087 .33724 L F
.337 0 .122 r
.69182 .34039 m .69106 .34239 L .68843 .34297 L F
.595 .513 .732 r
.69296 .33691 m .69182 .34039 L .69087 .33724 L F
.69296 .33691 m .69468 .3402 L .69182 .34039 L F
.704 .29 .26 r
.69483 .34274 m .69182 .34039 L .69468 .3402 L F
.69483 .34274 m .69106 .34239 L .69182 .34039 L F
.754 .78 .875 r
.63659 .40148 m .63203 .40083 L .63523 .40022 L F
.789 .92 .925 r
.63846 .3996 m .63659 .40148 L .63523 .40022 L F
.558 .38 .595 r
.33083 .55197 m .33357 .55165 L .33336 .54877 L F
.662 .177 .088 r
.33083 .55197 m .32895 .55333 L .33288 .55358 L F
.226 .267 .696 r
.34736 .62762 m .3484 .62986 L .34962 .62975 L F
.689 .561 .704 r
.35011 .64023 m .3541 .6409 L .35388 .64101 L F
.663 .616 .791 r
.35011 .64023 m .35388 .64101 L .35386 .64095 L F
.89 .751 .702 r
.35395 .64097 m .3541 .6409 L .35011 .64023 L F
.694 .898 .97 r
.3541 .6409 m .3539 .64099 L .35388 .64101 L F
.89 .751 .702 r
.35407 .64099 m .3541 .6409 L .35395 .64097 L F
.694 .898 .97 r
.3541 .6409 m .3556 .63887 L .3539 .64099 L F
.434 .492 .82 r
.35222 .63739 m .35386 .64095 L .3556 .63887 L F
.35386 .64095 m .35388 .64101 L .3539 .64099 L F
.35386 .64095 m .3539 .64099 L .3556 .63887 L F
.89 .751 .702 r
.35291 .64394 m .35402 .6411 L .35011 .64023 L F
.35402 .6411 m .35407 .64099 L .35386 .64095 L F
.35402 .6411 m .35386 .64095 L .35011 .64023 L F
.663 .616 .791 r
.35011 .64023 m .35386 .64095 L .35222 .63739 L F
.83 .522 .468 r
.34984 .64296 m .35291 .64394 L .35011 .64023 L F
.628 .503 .691 r
.70864 .33038 m .70473 .32758 L .70878 .32822 L F
.535 .472 .732 r
.71131 .32578 m .71196 .32794 L .70878 .32822 L F
.486 .228 .447 r
.71196 .32794 m .70864 .33038 L .70878 .32822 L F
.663 .948 .956 r
.25025 .52949 m .24661 .53045 L .24896 .52941 L F
.62 .95 .933 r
.25223 .52833 m .25025 .52949 L .25098 .52808 L F
.638 .962 .908 r
.25098 .52808 m .25025 .52949 L .24896 .52941 L F
.748 .648 .75 r
.34487 .54497 m .34628 .54812 L .34231 .54792 L F
.996 .861 .536 r
.34628 .54812 m .34449 .55006 L .34231 .54792 L F
.34628 .54812 m .3448 .55206 L .34449 .55006 L F
.72 .635 .763 r
.35223 .54535 m .34628 .54812 L .34487 .54497 L F
0 0 .119 r
.30726 .51813 m .30804 .51672 L .30955 .5169 L F
.30726 .51813 m .30737 .51853 L .30804 .51672 L F
.75 .588 .675 r
.34308 .536 m .34096 .53937 L .34326 .53821 L F
0 0 .353 r
.34308 .536 m .34283 .53475 L .3421 .533 L F
0 .115 .65 r
.34326 .53821 m .34283 .53475 L .34308 .536 L F
.716 .301 .259 r
.3754 .57362 m .37331 .57559 L .37423 .57312 L F
.751 .649 .748 r
.37331 .57559 m .37357 .57504 L .37423 .57312 L F
.995 .866 .58 r
.3754 .57362 m .37423 .57312 L .37507 .57063 L F
.751 .649 .748 r
.37357 .57504 m .37493 .57217 L .37423 .57312 L F
.995 .866 .58 r
.37507 .57063 m .37423 .57312 L .37496 .56957 L F
.716 .301 .259 r
.3754 .57362 m .37734 .57607 L .37628 .57595 L F
0 0 0 r
.37664 .5762 m .37904 .57242 L .37493 .57217 L F
.37668 .5763 m .37672 .57625 L .37664 .5762 L F
.37672 .57625 m .37904 .57242 L .37664 .5762 L F
.716 .301 .259 r
.37436 .5746 m .37628 .57595 L .37331 .57559 L F
.3754 .57362 m .37628 .57595 L .37436 .5746 L F
.567 .819 .993 r
.28764 .52315 m .28532 .52389 L .28351 .52264 L F
.849 .719 .718 r
.34289 .67176 m .34661 .66859 L .34451 .66758 L F
.186 0 .028 r
.34505 .67109 m .34661 .66859 L .34289 .67176 L F
.679 .137 0 r
.34737 .67025 m .34661 .66859 L .34505 .67109 L F
.094 0 0 r
.34737 .67025 m .3438 .67271 L .34565 .67213 L F
.3438 .67271 m .34342 .67297 L .34565 .67213 L F
.655 .884 .529 r
.347 .67049 m .34737 .67025 L .34565 .67213 L F
.091 0 0 r
.34505 .67109 m .34168 .67294 L .34342 .67297 L F
.094 0 0 r
.34737 .67025 m .34505 .67109 L .34342 .67297 L F
.679 .137 0 r
.34737 .67025 m .34791 .66989 L .34661 .66859 L F
.34737 .67025 m .34893 .6709 L .34791 .66989 L F
.835 .94 .894 r
.35178 .6683 m .34737 .67025 L .34947 .6669 L F
0 0 0 r
.34887 .66823 m .34947 .6669 L .34737 .67025 L F
.655 .884 .529 r
.34887 .66823 m .34737 .67025 L .347 .67049 L F
.835 .94 .894 r
.35178 .6683 m .34893 .6709 L .34737 .67025 L F
.655 .884 .529 r
.34887 .66823 m .34565 .67213 L .34803 .67152 L F
.396 .839 .938 r
.34744 .67158 m .34565 .67213 L .34366 .67191 L F
.34803 .67152 m .34565 .67213 L .34744 .67158 L F
.738 .672 .786 r
.3238 .52304 m .32595 .52615 L .32123 .52608 L F
.421 .19 .455 r
.32392 .52587 m .32123 .52608 L .32595 .52615 L F
.946 .651 .445 r
.3238 .52304 m .32392 .52587 L .32595 .52615 L F
.577 .356 .543 r
.235 .5698 m .23259 .56754 L .23508 .56724 L F
.235 .5698 m .23243 .57021 L .23259 .56754 L F
.704 .767 .901 r
.62111 .40493 m .61692 .40407 L .61934 .40291 L F
.739 .734 .847 r
.61934 .40291 m .62319 .40341 L .62111 .40493 L F
.966 .88 .698 r
.60664 .4125 m .60666 .41641 L .60655 .41494 L F
0 0 .264 r
.60666 .41641 m .60753 .41705 L .60655 .41494 L F
.60666 .41641 m .60681 .41886 L .60753 .41705 L F
.911 .535 .298 r
.32515 .68606 m .32727 .68771 L .3258 .68919 L F
.846 .425 .231 r
.32727 .68771 m .32844 .69001 L .3258 .68919 L F
.792 .647 .701 r
.38145 .6053 m .37942 .60866 L .3779 .60508 L F
.461 0 0 r
.38055 .60586 m .38145 .6053 L .3779 .60508 L F
.235 .246 .667 r
.38133 .60188 m .38145 .6053 L .38335 .6046 L F
0 0 0 r
.38335 .6046 m .38145 .6053 L .38055 .60586 L F
.39 .169 .454 r
.39576 .68425 m .3955 .68756 L .39321 .68758 L F
.402 .323 .653 r
.3955 .68756 m .39347 .69031 L .39321 .68758 L F
.444 0 0 r
.26986 .62223 m .27172 .62293 L .27379 .62166 L F
.732 .926 .956 r
.27579 .62023 m .27379 .62166 L .27405 .61947 L F
.881 .986 .717 r
.27379 .62166 m .27172 .62293 L .27405 .61947 L F
.616 .943 .947 r
.71079 .35394 m .7135 .35256 L .71426 .35314 L F
.571 .792 .982 r
.71545 .35097 m .71695 .35252 L .71426 .35314 L F
.738 .984 .904 r
.71426 .35314 m .7135 .35256 L .71545 .35097 L F
.425 .19 .452 r
.35894 .63962 m .35933 .63714 L .35666 .64019 L F
.975 .729 .5 r
.35894 .63962 m .35933 .63714 L .35744 .63598 L F
.519 .82 1 r
.35744 .63598 m .35933 .63714 L .36147 .63642 L F
.372 .145 .435 r
.36147 .63642 m .35933 .63714 L .35894 .63962 L F
0 0 .438 r
.39414 .62871 m .39286 .62794 L .39545 .62638 L F
.39414 .62871 m .39296 .63072 L .39286 .62794 L F
.267 0 .065 r
.33456 .53919 m .33087 .53962 L .33245 .53709 L F
.33456 .53919 m .33333 .54157 L .3307 .54223 L F
.06 0 0 r
.33539 .54042 m .33456 .53919 L .33713 .53838 L F
.33539 .54042 m .33333 .54157 L .33456 .53919 L F
.694 .898 .97 r
.3541 .6409 m .35666 .64019 L .3556 .63887 L F
.502 .803 .999 r
.35894 .63962 m .35666 .64019 L .3556 .63887 L F
.3556 .63887 m .35666 .64019 L .35894 .63962 L F
.534 .187 .327 r
.29454 .53543 m .29281 .53843 L .29034 .53856 L F
.562 .219 .344 r
.29815 .53692 m .29281 .53843 L .29454 .53543 L F
.744 .33 .264 r
.30062 .53614 m .29902 .53785 L .29815 .53692 L F
.562 .219 .344 r
.29829 .53698 m .29818 .53701 L .29815 .53692 L F
.29818 .53701 m .29281 .53843 L .29815 .53692 L F
.744 .33 .264 r
.29778 .53562 m .29815 .53692 L .29677 .53544 L F
.30062 .53614 m .29815 .53692 L .29778 .53562 L F
.562 .219 .344 r
.29815 .53692 m .29454 .53543 L .29677 .53544 L F
.453 .061 .205 r
.29818 .53701 m .29239 .54037 L .29281 .53843 L F
.116 0 0 r
.29829 .53964 m .29945 .54025 L .3007 .53918 L F
.29829 .53964 m .29738 .54103 L .29945 .54025 L F
.511 .332 .574 r
.29829 .53964 m .3007 .53918 L .30062 .53614 L F
.809 .54 .532 r
.29945 .54025 m .29482 .54031 L .29818 .53709 L F
.744 .33 .264 r
.29832 .5371 m .2982 .53709 L .29816 .53693 L F
.809 .54 .532 r
.29834 .5371 m .29818 .53709 L .29829 .53698 L F
.29945 .54025 m .29818 .53709 L .29834 .5371 L F
.744 .33 .264 r
.29835 .53713 m .29825 .53727 L .2982 .53709 L F
.29835 .53713 m .2982 .53709 L .29832 .5371 L F
.29902 .53785 m .29856 .5375 L .29835 .53713 L F
.29856 .5375 m .29825 .53727 L .29835 .53713 L F
.809 .54 .532 r
.29945 .54025 m .29834 .5371 L .29885 .53802 L F
.29834 .5371 m .29829 .53698 L .29885 .53802 L F
.453 .061 .205 r
.29829 .53698 m .29819 .53704 L .29818 .53701 L F
.29819 .53704 m .29239 .54037 L .29818 .53701 L F
.744 .33 .264 r
.29902 .53785 m .29885 .53802 L .29825 .53727 L F
.453 .061 .205 r
.29819 .53704 m .29482 .54031 L .29239 .54037 L F
.29829 .53698 m .29818 .53709 L .29819 .53704 L F
.29818 .53709 m .29482 .54031 L .29819 .53704 L F
.744 .33 .264 r
.29816 .53693 m .29819 .53704 L .29677 .53544 L F
.29819 .53704 m .29825 .53727 L .29816 .53716 L F
.29819 .53704 m .29816 .53716 L .29677 .53544 L F
.562 .219 .344 r
.29829 .53698 m .29815 .53692 L .29677 .53544 L F
.808 .368 0 r
.24061 .614 m .24247 .61652 L .24226 .61574 L F
.903 .94 .824 r
.38525 .6618 m .38624 .65873 L .38612 .66153 L F
.748 .482 .528 r
.6262 .44409 m .62282 .44664 L .6226 .44438 L F
.6262 .44409 m .62498 .44696 L .62282 .44664 L F
.687 .449 .557 r
.6289 .44438 m .62498 .44696 L .6262 .44409 L F
.361 0 .155 r
.71446 .35843 m .71183 .36118 L .71168 .35939 L F
.71446 .35843 m .7145 .36059 L .71183 .36118 L F
.019 0 .132 r
.71695 .35733 m .7145 .36059 L .71446 .35843 L F
0 0 .274 r
.40551 .56331 m .4057 .5648 L .40487 .56083 L F
.654 .137 0 r
.4061 .56586 m .4057 .5648 L .40551 .56331 L F
.4061 .56586 m .40746 .56683 L .4057 .5648 L F
.339 .205 .548 r
.19197 .59284 m .19375 .59247 L .1936 .58961 L F
.332 .406 .788 r
.19197 .59284 m .19484 .59484 L .19375 .59247 L F
.453 .203 .443 r
.31876 .61801 m .32206 .61526 L .31844 .61602 L F
.911 .883 .793 r
.32123 .51322 m .32117 .51696 L .3183 .51403 L F
.32123 .51322 m .31894 .51677 L .32117 .51696 L F
.53 .493 .759 r
.31894 .51677 m .32269 .51723 L .32117 .51696 L F
.455 0 .079 r
.38719 .59473 m .38566 .59314 L .38493 .59542 L F
.38719 .59473 m .38814 .59329 L .38566 .59314 L F
.376 .092 .348 r
.36104 .52622 m .36355 .52551 L .36377 .52337 L F
0 0 .087 r
.36377 .52337 m .36584 .51987 L .36554 .51897 L F
.36377 .52337 m .36492 .52245 L .36584 .51987 L F
.118 0 .277 r
.36377 .52337 m .36567 .52306 L .36492 .52245 L F
.36377 .52337 m .36355 .52551 L .36567 .52306 L F
.64 .583 .776 r
.37441 .5426 m .37202 .54363 L .37068 .54179 L F
.895 .498 .256 r
.42219 .57294 m .41928 .56947 L .4201 .5712 L F
.848 .771 .776 r
.37866 .56418 m .38136 .56101 L .37877 .56138 L F
.076 0 .277 r
.30269 .55818 m .30423 .55743 L .30485 .55469 L F
.214 .165 .583 r
.30269 .55818 m .30452 .56031 L .30423 .55743 L F
.218 .165 .581 r
.30309 .56082 m .30452 .56031 L .30269 .55818 L F
.718 .533 .639 r
.70099 .32609 m .69811 .33023 L .69865 .32764 L F
.70099 .32609 m .7023 .33066 L .69811 .33023 L F
.701 .523 .644 r
.70099 .32609 m .70473 .32758 L .7023 .33066 L F
.521 .534 .811 r
.32506 .51084 m .32595 .5066 L .32677 .50775 L F
.32506 .51084 m .3274 .51042 L .32595 .5066 L F
0 0 .47 r
.28104 .63573 m .28084 .6376 L .27965 .63363 L F
.849 .958 .616 r
.27969 .63882 m .28084 .6376 L .28104 .63573 L F
0 0 .196 r
.3826 .5958 m .38044 .59924 L .38268 .5986 L F
.394 .319 .653 r
.38044 .59924 m .38285 .60134 L .38268 .5986 L F
.359 .317 .676 r
.38044 .59924 m .38133 .60188 L .38285 .60134 L F
.226 0 .136 r
.29997 .60801 m .30287 .60535 L .30203 .60737 L F
.205 0 .207 r
.30428 .60685 m .30287 .60535 L .30408 .60453 L F
.30428 .60685 m .30203 .60737 L .30287 .60535 L F
.823 .454 0 r
.417 .56096 m .41876 .56458 L .41793 .56348 L F
.972 .791 .601 r
.41883 .56699 m .41793 .56348 L .41876 .56458 L F
.474 .577 .878 r
.61544 .39958 m .61302 .40027 L .61142 .39705 L F
.744 .733 .842 r
.61543 .4019 m .61934 .40291 L .61692 .40407 L F
.395 .267 .587 r
.61525 .40216 m .61302 .40027 L .61545 .40186 L F
.744 .733 .842 r
.61535 .40179 m .61545 .40186 L .61543 .4019 L F
.395 .267 .587 r
.61546 .40234 m .61525 .40216 L .61545 .40186 L F
.744 .733 .842 r
.61535 .40179 m .61692 .40407 L .61546 .40234 L F
.632 .446 .612 r
.61545 .40186 m .61535 .40179 L .61546 .40234 L F
.395 .267 .587 r
.61545 .40186 m .61302 .40027 L .61544 .39958 L F
.632 .446 .612 r
.61544 .39958 m .61535 .40179 L .61545 .40186 L F
.744 .733 .842 r
.61535 .40179 m .61548 .40182 L .61545 .40186 L F
.61548 .40182 m .61934 .40291 L .61543 .4019 L F
.406 .266 .577 r
.33336 .54877 m .3356 .55047 L .33485 .54767 L F
.33336 .54877 m .33357 .55165 L .3356 .55047 L F
.941 .781 .655 r
.3356 .55047 m .33379 .54959 L .33485 .54767 L F
0 0 0 r
.33485 .54767 m .33379 .54959 L .33528 .54736 L F
.33364 .54853 m .33485 .54767 L .33688 .54575 L F
.675 .926 .622 r
.33688 .54575 m .33485 .54767 L .33625 .5459 L F
0 0 0 r
.33485 .54767 m .33528 .54736 L .33625 .5459 L F
.33336 .54877 m .33485 .54767 L .33364 .54853 L F
.504 .5 .786 r
.39706 .68038 m .39803 .6837 L .39576 .68425 L F
.491 .281 .521 r
.39803 .6837 m .3955 .68756 L .39576 .68425 L F
.471 .269 .523 r
.39134 .69352 m .39132 .69703 L .38863 .69727 L F
.458 .276 .545 r
.39347 .69031 m .39377 .69323 L .39134 .69352 L F
.385 .202 .506 r
.39348 .69613 m .39134 .69352 L .39377 .69323 L F
.39348 .69613 m .39132 .69703 L .39134 .69352 L F
.607 .948 .794 r
.22374 .54282 m .22394 .54197 L .22586 .542 L F
.22374 .54282 m .22128 .54376 L .22394 .54197 L F
.63 .433 .597 r
.39745 .5929 m .4024 .59617 L .40207 .59279 L F
.645 .897 .568 r
.64394 .42459 m .64231 .42657 L .64106 .4279 L F
.591 .58 .809 r
.33294 .63979 m .33408 .63585 L .33297 .63695 L F
.591 .161 .193 r
.71131 .32578 m .71421 .32481 L .7137 .32623 L F
.002 0 0 r
.7137 .32623 m .71421 .32481 L .71694 .32287 L F
.459 .204 .439 r
.35402 .5548 m .35648 .55423 L .35719 .55117 L F
.841 .79 .803 r
.35729 .54924 m .35904 .54835 L .35939 .5464 L F
0 0 0 r
.35875 .5478 m .35857 .54809 L .35729 .54924 L F
.328 .606 .949 r
.35719 .55117 m .35729 .54924 L .35606 .55033 L F
.35719 .55117 m .35895 .55104 L .35729 .54924 L F
.841 .79 .803 r
.35729 .54924 m .35895 .55104 L .35904 .54835 L F
0 0 0 r
.35857 .54809 m .35597 .55242 L .35729 .54924 L F
.328 .606 .949 r
.35606 .55033 m .35729 .54924 L .35507 .54959 L F
.32 .081 .385 r
.35719 .55117 m .35648 .55423 L .35895 .55104 L F
.408 .765 .995 r
.34934 .50483 m .35164 .50453 L .35326 .50561 L F
.418 .765 .996 r
.35164 .50453 m .35371 .50554 L .35326 .50561 L F
0 0 0 r
.24377 .53085 m .24447 .53103 L .24661 .53045 L F
.24377 .53085 m .24222 .53182 L .24447 .53103 L F
.812 .61 .629 r
.33511 .69367 m .33123 .69616 L .33141 .6937 L F
.33511 .69367 m .33488 .69647 L .33123 .69616 L F
.559 .087 .092 r
.28833 .55515 m .29026 .55668 L .29226 .55503 L F
0 0 .363 r
.29322 .556 m .29272 .55758 L .29226 .55503 L F
.29322 .556 m .29226 .55503 L .29026 .55668 L F
.185 .043 .442 r
.32552 .66214 m .32405 .66181 L .32461 .65905 L F
.08 .269 .756 r
.32283 .65809 m .32552 .66214 L .32461 .65905 L F
.484 .194 .398 r
.63991 .43489 m .63982 .43752 L .63686 .43789 L F
.399 .13 .385 r
.64251 .43683 m .63991 .43489 L .64245 .43407 L F
.64251 .43683 m .63982 .43752 L .63991 .43489 L F
.653 .532 .703 r
.37185 .53016 m .36883 .53136 L .36792 .52669 L F
.891 .884 .819 r
.39541 .67422 m .39698 .67528 L .39959 .67169 L F
.451 .17 .394 r
.38863 .69727 m .38824 .69945 L .38583 .69988 L F
.394 .097 .338 r
.39132 .69703 m .38824 .69945 L .38863 .69727 L F
0 0 0 r
.63892 .40518 m .64015 .40446 L .64266 .40336 L F
.869 .984 .84 r
.5753 .40322 m .57537 .40381 L .5745 .40264 L F
0 .28 .781 r
.39802 .6746 m .39698 .67528 L .39541 .67422 L F
.39802 .6746 m .3994 .67708 L .39698 .67528 L F
.36 .316 .674 r
.3994 .67708 m .39785 .67818 L .39698 .67528 L F
.602 .448 .644 r
.39262 .60947 m .3903 .61027 L .39067 .60755 L F
.39262 .60947 m .38972 .61176 L .3903 .61027 L F
.614 .352 .498 r
.33141 .6937 m .33123 .69616 L .32886 .69375 L F
.519 .017 0 r
.32886 .69375 m .3299 .69486 L .32896 .69277 L F
.32886 .69375 m .33123 .69616 L .3299 .69486 L F
.553 .567 .823 r
.33978 .58837 m .33868 .59197 L .3388 .58963 L F
.467 .216 .45 r
.35149 .5731 m .35418 .57056 L .35212 .57209 L F
0 0 .467 r
.32512 .55478 m .32629 .55665 L .32688 .55421 L F
.501 .286 .519 r
.28188 .63131 m .2824 .6335 L .27965 .63363 L F
0 0 .47 r
.28104 .63573 m .27965 .63363 L .2824 .6335 L F
.764 .674 .763 r
.70466 .31159 m .70595 .31543 L .70207 .31478 L F
.726 .654 .778 r
.7088 .3124 m .70595 .31543 L .70466 .31159 L F
.815 .779 .819 r
.30689 .52259 m .31054 .52222 L .30917 .52128 L F
.638 .89 .986 r
.30917 .52128 m .31054 .52222 L .31365 .52081 L F
.881 .899 .838 r
.27106 .75267 m .27303 .75345 L .27055 .75626 L F
.657 .104 0 r
.27371 .75444 m .27303 .75345 L .27106 .75267 L F
.502 .326 .574 r
.36096 .58636 m .36091 .58921 L .35871 .58893 L F
.36096 .58636 m .36091 .58921 L .35871 .58893 L F
.278 0 0 r
.38038 .54921 m .37826 .55073 L .37582 .55103 L F
.743 .367 .341 r
.38038 .54921 m .38228 .55122 L .37826 .55073 L F
.101 .656 .722 r
.2464 .54192 m .24509 .54204 L .24289 .54231 L F
.218 .741 .781 r
.24854 .54144 m .24509 .54204 L .2464 .54192 L F
.708 .296 .263 r
.22001 .56504 m .22306 .56647 L .22511 .56455 L F
.408 0 .123 r
.22306 .56647 m .22738 .56391 L .22511 .56455 L F
.424 .28 .58 r
.71219 .34051 m .71174 .34343 L .71379 .34119 L F
.436 .175 .417 r
.2801 .62133 m .2822 .62324 L .27971 .62363 L F
.715 .611 .74 r
.33827 .60521 m .34105 .60151 L .3386 .60216 L F
.591 .42 .618 r
.3383 .52598 m .33598 .52231 L .33702 .52502 L F
.315 .731 .976 r
.33702 .52502 m .3404 .52584 L .3383 .52598 L F
.504 .884 .969 r
.36205 .66536 m .35833 .66568 L .36043 .66443 L F
.193 0 0 r
.33987 .54107 m .34326 .53821 L .34096 .53937 L F
0 .115 .65 r
.34326 .53821 m .34452 .53694 L .34283 .53475 L F
.189 0 .18 r
.35273 .614 m .35356 .61183 L .35059 .6147 L F
.304 .121 .46 r
.35273 .614 m .35059 .6147 L .35052 .61778 L F
0 0 .078 r
.33705 .59371 m .33641 .5928 L .33868 .59197 L F
.33705 .59371 m .33586 .59508 L .33641 .5928 L F
.621 .275 .362 r
.35481 .5319 m .35762 .53231 L .35841 .52959 L F
.298 .067 .385 r
.35841 .52959 m .36066 .52905 L .36104 .52622 L F
.426 .092 .294 r
.35841 .52959 m .3599 .53093 L .36066 .52905 L F
.35841 .52959 m .35762 .53231 L .3599 .53093 L F
.912 .92 .808 r
.33542 .51395 m .33267 .51826 L .33194 .5164 L F
.424 0 0 r
.33527 .51909 m .33141 .51925 L .33267 .51826 L F
.928 .787 .684 r
.6078 .4207 m .6099 .42321 L .60845 .42523 L F
.1 0 0 r
.24023 .54532 m .23621 .54668 L .23735 .5479 L F
.3 0 .241 r
.24477 .55443 m .24262 .55511 L .24549 .55316 L F
.447 .298 .585 r
.24477 .55443 m .2427 .5578 L .24262 .55511 L F
.658 .378 .485 r
.25775 .55133 m .26072 .55125 L .26105 .54922 L F
.473 .213 .438 r
.26105 .54922 m .26072 .55125 L .26316 .5507 L F
.375 .656 .967 r
.19545 .60357 m .19418 .60483 L .19338 .60374 L F
.768 .664 .749 r
.19545 .60357 m .19275 .60753 L .19418 .60483 L F
.528 .896 .696 r
.32442 .59898 m .32166 .60103 L .3237 .60103 L F
.511 .438 .71 r
.32166 .60103 m .32455 .60401 L .3237 .60103 L F
.32166 .60103 m .32302 .60579 L .32455 .60401 L F
.074 0 0 r
.37446 .56607 m .37866 .56418 L .37671 .56553 L F
.938 .739 .607 r
.31605 .65662 m .31811 .6592 L .31669 .65559 L F
.31593 .65733 m .31811 .6592 L .31605 .65662 L F
.31607 .65811 m .31811 .6592 L .31572 .65715 L F
.61 .905 .984 r
.31464 .65944 m .31811 .6592 L .31616 .65815 L F
.31464 .65944 m .31616 .65815 L .31549 .65839 L F
.31464 .65944 m .31582 .65797 L .31475 .6592 L F
.883 .992 .766 r
.31257 .66101 m .31464 .65944 L .31502 .65855 L F
.31257 .66101 m .31442 .65875 L .31457 .659 L F
.31442 .65875 m .31532 .65766 L .31544 .6584 L F
.31442 .65875 m .31544 .6584 L .31593 .66136 L F
.31257 .66101 m .31502 .65855 L .31536 .65773 L F
.31257 .66101 m .31457 .659 L .31593 .66136 L F
.61 .905 .984 r
.31549 .65839 m .31616 .65815 L .31582 .65797 L F
.297 .131 .48 r
.31544 .6584 m .31532 .65766 L .31582 .65797 L F
.61 .905 .984 r
.31475 .6592 m .31582 .65797 L .31536 .65773 L F
.297 .131 .48 r
.31582 .65797 m .31532 .65766 L .31588 .65759 L F
.31559 .65929 m .31544 .6584 L .31582 .65797 L F
.31593 .66136 m .31559 .65929 L .31833 .65726 L F
.31559 .65929 m .31588 .65759 L .31833 .65726 L F
.938 .739 .607 r
.31572 .65715 m .31593 .65733 L .31605 .65662 L F
.984 .777 .544 r
.3152 .65431 m .31669 .65559 L .31691 .65267 L F
.924 .864 .762 r
.31532 .65766 m .31573 .65716 L .31588 .65759 L F
0 0 0 r
.31536 .65773 m .31572 .65715 L .31532 .65766 L F
.31572 .65715 m .31669 .65559 L .31532 .65766 L F
.924 .864 .762 r
.31573 .65716 m .31572 .65715 L .31723 .65531 L F
.31532 .65766 m .31669 .65559 L .3152 .65431 L F
.31572 .65715 m .3152 .65431 L .31719 .65529 L F
.31572 .65715 m .31719 .65529 L .31723 .65531 L F
.31532 .65766 m .31525 .65563 L .31573 .65716 L F
.31525 .65563 m .3152 .65431 L .31573 .65716 L F
.31588 .65759 m .31723 .65531 L .31833 .65726 L F
.31573 .65716 m .31723 .65531 L .31588 .65759 L F
.938 .739 .607 r
.31536 .65773 m .31607 .65811 L .31572 .65715 L F
.239 .474 .882 r
.29497 .62321 m .29428 .62471 L .29422 .62307 L F
.602 .892 .989 r
.29497 .62321 m .29683 .62395 L .29428 .62471 L F
.29497 .62321 m .29683 .62395 L .29428 .62471 L F
.448 .519 .839 r
.28329 .53242 m .28592 .532 L .28552 .53172 L F
.508 .214 .401 r
.28329 .53242 m .28557 .53432 L .28592 .532 L F
.448 .519 .839 r
.28329 .53242 m .28552 .53172 L .2833 .5327 L F
.464 .015 .098 r
.35503 .61336 m .35356 .61183 L .35273 .614 L F
.35503 .61336 m .35644 .61192 L .35356 .61183 L F
.659 .793 .946 r
.31718 .51096 m .3183 .51403 L .31448 .51308 L F
.769 .735 .821 r
.3183 .51403 m .31639 .51481 L .31448 .51308 L F
.501 .533 .822 r
.31938 .50923 m .3183 .51403 L .31718 .51096 L F
.31938 .50923 m .32123 .51322 L .3183 .51403 L F
.714 .526 .633 r
.37681 .61309 m .37922 .61133 L .37658 .6115 L F
.464 .112 .283 r
.38068 .61052 m .37658 .6115 L .37922 .61133 L F
0 .376 .83 r
.36637 .50923 m .36781 .50989 L .36771 .51075 L F
.726 .231 0 r
.36781 .50989 m .36937 .51126 L .36771 .51075 L F
.452 0 0 r
.26385 .62005 m .26518 .62078 L .26156 .6197 L F
.792 .423 .358 r
.58223 .42822 m .58603 .42919 L .58645 .43134 L F
.936 .944 .608 r
.28038 .53987 m .2792 .54241 L .28057 .53883 L F
.938 .966 .717 r
.62206 .42765 m .62456 .42527 L .62107 .42489 L F
.62206 .42765 m .62261 .42894 L .62456 .42527 L F
.526 .284 .49 r
.35212 .52664 m .35138 .52907 L .34851 .52934 L F
.134 0 .154 r
.73612 .33635 m .73326 .33937 L .73351 .33792 L F
.088 0 .21 r
.29737 .59278 m .2989 .59202 L .2997 .58976 L F
.084 0 .335 r
.29737 .59278 m .29836 .59444 L .2989 .59202 L F
.29737 .59278 m .29693 .59571 L .29836 .59444 L F
.182 .042 .443 r
.3182 .62237 m .31728 .62731 L .32028 .62567 L F
.3182 .62237 m .32028 .62567 L .31829 .62341 L F
.624 .873 .526 r
.31912 .62117 m .3182 .62237 L .31829 .62341 L F
.524 .609 .879 r
.28401 .62959 m .28188 .63131 L .28084 .62835 L F
.624 .54 .74 r
.28401 .62959 m .2824 .6335 L .28188 .63131 L F
.573 .561 .803 r
.37823 .53265 m .37589 .53402 L .37423 .52919 L F
.329 .283 .654 r
.39658 .58397 m .39875 .58605 L .39892 .58046 L F
.513 .324 .562 r
.32355 .53624 m .32633 .5357 L .32576 .53304 L F
.566 .481 .719 r
.32633 .5357 m .32825 .53145 L .32576 .53304 L F
.581 .834 .993 r
.33753 .67392 m .33355 .67387 L .33687 .67294 L F
.558 .869 .995 r
.33982 .67303 m .33753 .67392 L .33687 .67294 L F
.829 .519 .466 r
.70998 .35708 m .70799 .35835 L .70922 .356 L F
.70998 .35708 m .71168 .35939 L .70799 .35835 L F
.725 .237 .085 r
.3556 .56437 m .35167 .56318 L .35318 .56483 L F
.599 .128 .108 r
.34455 .56284 m .34075 .56284 L .34254 .56116 L F
.739 .724 .837 r
.62961 .40174 m .62606 .40092 L .6284 .39954 L F
.581 .669 .899 r
.63203 .40083 m .62961 .40174 L .6284 .39954 L F
.841 .376 .006 r
.42338 .56233 m .42368 .56329 L .42548 .56435 L F
.512 .825 1 r
.42548 .56435 m .42368 .56329 L .42613 .56276 L F
.028 .252 .754 r
.42613 .56276 m .42791 .5664 L .42548 .56435 L F
.454 .119 .308 r
.63771 .43102 m .64106 .4279 L .63951 .42977 L F
.588 .645 .875 r
.23724 .60543 m .23305 .60291 L .23524 .60343 L F
.616 .794 .967 r
.23966 .60466 m .23724 .60543 L .23524 .60343 L F
.959 .715 .527 r
.41372 .54215 m .41226 .53783 L .41351 .53912 L F
0 0 .377 r
.41486 .54017 m .41351 .53912 L .41226 .53783 L F
.41486 .54017 m .41372 .54215 L .41351 .53912 L F
.777 .659 .733 r
.25276 .61792 m .25062 .62034 L .25424 .62043 L F
.659 .222 .2 r
.25062 .62034 m .25253 .62202 L .25424 .62043 L F
.589 .097 .053 r
.25253 .62202 m .25674 .62137 L .25424 .62043 L F
.402 .323 .653 r
.3955 .68756 m .39699 .69126 L .39347 .69031 L F
.391 .188 .48 r
.39699 .69126 m .39377 .69323 L .39347 .69031 L F
.587 .443 .653 r
.32368 .53895 m .32633 .5357 L .32355 .53624 L F
.876 .873 .83 r
.33014 .50454 m .32677 .50775 L .32595 .5066 L F
.33014 .50454 m .32595 .5066 L .32829 .50618 L F
.672 .204 .131 r
.33014 .50454 m .33239 .50658 L .332 .50386 L F
.33014 .50454 m .32829 .50618 L .33239 .50658 L F
.023 .223 .729 r
.33239 .50658 m .33014 .50454 L .332 .50386 L F
.43 .224 .497 r
.3168 .55698 m .31479 .55489 L .31699 .55395 L F
.3168 .55698 m .31447 .55776 L .31479 .55489 L F
.686 .27 0 r
.39484 .53543 m .39692 .53884 L .39597 .53667 L F
.798 .405 .309 r
.30062 .53614 m .30454 .53979 L .29885 .53802 L F
.586 .633 .865 r
.30417 .56415 m .30452 .56031 L .30309 .56082 L F
.30417 .56415 m .3065 .56424 L .30452 .56031 L F
.593 .299 .439 r
.30417 .56415 m .30593 .56663 L .3065 .56424 L F
.471 .451 .754 r
.3065 .56424 m .30593 .56663 L .30417 .56415 L F
.77 .61 .68 r
.36883 .53136 m .36944 .53292 L .36527 .53249 L F
.747 .547 .624 r
.3693 .53546 m .36527 .53249 L .36944 .53292 L F
.662 .556 .725 r
.37185 .53016 m .36944 .53292 L .36883 .53136 L F
.39 .294 .625 r
.31165 .58913 m .31215 .59197 L .30986 .59286 L F
.308 .097 .42 r
.31174 .59459 m .30986 .59286 L .31215 .59197 L F
.31174 .59459 m .30965 .59541 L .30986 .59286 L F
.881 .899 .838 r
.27106 .75267 m .27055 .75626 L .27022 .7535 L F
0 .415 .745 r
.27055 .75626 m .27115 .75624 L .27022 .7535 L F
.945 .787 .328 r
.62224 .43146 m .62261 .42894 L .62206 .42765 L F
.24 .348 .773 r
.41715 .54721 m .4186 .55134 L .4186 .54849 L F
0 0 0 r
.33978 .58837 m .34085 .58601 L .34014 .58674 L F
.114 0 0 r
.3446 .5842 m .34014 .58674 L .34085 .58601 L F
.162 .368 .819 r
.35052 .61778 m .35231 .62134 L .35317 .6197 L F
.33 .584 .936 r
.35231 .62134 m .35456 .62147 L .35317 .6197 L F
.477 .292 .55 r
.33024 .59847 m .32768 .60237 L .32771 .59901 L F
.371 .333 .687 r
.29872 .58679 m .301 .5886 L .30069 .5861 L F
.339 .333 .706 r
.29872 .58679 m .2997 .58976 L .301 .5886 L F
.623 .275 .359 r
.31038 .63244 m .30864 .63009 L .30821 .6337 L F
.31038 .63244 m .31114 .63033 L .30864 .63009 L F
.757 .428 0 r
.4034 .55684 m .40487 .56083 L .40411 .55858 L F
.711 .379 .414 r
.33857 .50471 m .34064 .50613 L .34299 .50361 L F
.072 .354 .826 r
.33882 .50252 m .34003 .50519 L .33857 .50471 L F
.794 .816 .869 r
.34095 .50576 m .34003 .50519 L .33882 .50252 L F
0 .397 .794 r
.34003 .50519 m .34098 .50569 L .34053 .50535 L F
.33857 .50471 m .34055 .50551 L .34003 .50519 L F
.34055 .50551 m .34098 .50569 L .34003 .50519 L F
.589 .861 .525 r
.34092 .50583 m .34064 .50613 L .34094 .50578 L F
.249 .453 .863 r
.34055 .50551 m .34098 .50636 L .34125 .50579 L F
.33857 .50471 m .34077 .50622 L .34055 .50551 L F
.34077 .50622 m .34098 .50636 L .34055 .50551 L F
.794 .816 .869 r
.34386 .5024 m .34095 .50576 L .34033 .50481 L F
.3396 .5025 m .34033 .50481 L .33882 .50252 L F
.34386 .5024 m .34033 .50481 L .3396 .5025 L F
.34095 .50576 m .34051 .50626 L .34003 .50519 L F
.249 .453 .863 r
.33857 .50471 m .33991 .50708 L .34064 .50613 L F
.711 .379 .414 r
.33857 .50471 m .34051 .50626 L .34064 .50613 L F
.072 .354 .826 r
.34003 .50519 m .34051 .50626 L .33857 .50471 L F
0 .397 .794 r
.33857 .50471 m .34053 .50535 L .33956 .50463 L F
.34098 .50569 m .34125 .50579 L .34101 .50563 L F
.34098 .50569 m .34101 .50563 L .33956 .50463 L F
.249 .453 .863 r
.34064 .50613 m .3403 .50779 L .34098 .50636 L F
.776 .66 .735 r
.34103 .50805 m .34029 .50634 L .34125 .50579 L F
.34029 .50634 m .33956 .50463 L .34101 .50563 L F
.589 .861 .525 r
.34064 .50613 m .34051 .50626 L .34071 .50603 L F
.776 .66 .735 r
.34029 .50634 m .34101 .50563 L .34125 .50579 L F
.589 .861 .525 r
.34299 .50361 m .34262 .50401 L .34386 .5024 L F
.34262 .50401 m .34092 .50583 L .34163 .505 L F
.34262 .50401 m .34163 .505 L .34386 .5024 L F
.34092 .50583 m .34094 .50578 L .34386 .5024 L F
.34064 .50613 m .34071 .50603 L .34386 .5024 L F
.249 .453 .863 r
.33991 .50708 m .3403 .50779 L .34064 .50613 L F
.589 .861 .525 r
.34299 .50361 m .34386 .5024 L .34558 .50323 L F
.134 0 0 r
.30207 .545 m .29784 .54706 L .29941 .5451 L F
.405 .554 .89 r
.34786 .51212 m .34886 .50963 L .34656 .51044 L F
.34786 .51212 m .34922 .51157 L .34886 .50963 L F
.498 .692 .955 r
.25883 .55407 m .25924 .55533 L .26037 .55397 L F
.742 .888 .946 r
.69087 .33724 m .68725 .33726 L .68968 .33582 L F
.69087 .33724 m .68805 .33765 L .68725 .33726 L F
.923 .925 .794 r
.69087 .33724 m .69194 .33253 L .69296 .33691 L F
.69087 .33724 m .68968 .33582 L .69194 .33253 L F
.929 .709 .583 r
.30204 .65203 m .30389 .6556 L .30377 .65281 L F
.30204 .65203 m .30389 .6556 L .30377 .65281 L F
.684 .515 .652 r
.30389 .6556 m .30636 .65302 L .30377 .65281 L F
.30389 .6556 m .30636 .65302 L .30377 .65281 L F
.358 .52 .881 r
.32113 .61747 m .32339 .61984 L .32335 .61961 L F
.832 .857 .864 r
.3212 .62037 m .32357 .62078 L .32339 .61984 L F
.3212 .62037 m .32339 .61984 L .32113 .61747 L F
.3212 .62037 m .32339 .61984 L .32335 .61961 L F
.3212 .62037 m .32344 .61989 L .32339 .61984 L F
.3212 .62037 m .32335 .61961 L .32344 .61989 L F
.32335 .61961 m .32357 .62078 L .32582 .61875 L F
.32335 .61961 m .32582 .61875 L .32344 .61989 L F
.358 .52 .881 r
.32229 .61641 m .32335 .61961 L .32269 .61604 L F
.32113 .61747 m .32335 .61961 L .32229 .61641 L F
.32269 .61604 m .32344 .61989 L .32285 .6159 L F
.32339 .61984 m .32344 .61989 L .32269 .61604 L F
.832 .857 .864 r
.3212 .62037 m .32337 .62095 L .32357 .62078 L F
.731 .33 .29 r
.32086 .62288 m .32337 .62095 L .3212 .62037 L F
.32086 .62288 m .32405 .62435 L .32337 .62095 L F
.453 .203 .443 r
.31876 .61801 m .32113 .61747 L .32206 .61526 L F
.507 .37 .629 r
.31876 .61801 m .3212 .62037 L .32113 .61747 L F
.31876 .61801 m .31912 .62117 L .3212 .62037 L F
.507 .083 .169 r
.30843 .65444 m .31021 .65226 L .30636 .65302 L F
.663 .242 .234 r
.31099 .65485 m .31021 .65226 L .30843 .65444 L F
.31099 .65485 m .31291 .65324 L .31021 .65226 L F
.597 .41 .598 r
.32795 .57351 m .33039 .57022 L .32808 .57067 L F
.832 .629 .629 r
.61184 .43107 m .61595 .43175 L .61407 .4345 L F
.83 .626 .627 r
.61595 .43175 m .61733 .43509 L .61407 .4345 L F
.904 .648 .539 r
.34989 .59157 m .35222 .59231 L .35216 .58961 L F
.291 0 .23 r
.32417 .61222 m .32326 .61398 L .32626 .6115 L F
.956 .696 .5 r
.42406 .57386 m .42215 .57549 L .42219 .57294 L F
.506 .193 .37 r
.42592 .5697 m .42219 .57294 L .42406 .57386 L F
.956 .696 .5 r
.42406 .57386 m .42401 .5758 L .42325 .57455 L F
.019 0 .181 r
.42607 .57501 m .42399 .57649 L .42406 .57386 L F
.42607 .57501 m .42406 .57386 L .42219 .57294 L F
.506 .193 .37 r
.42592 .5697 m .42471 .57358 L .42219 .57294 L F
.346 .498 .867 r
.42527 .57372 m .42607 .57501 L .42386 .5738 L F
.42471 .57358 m .42386 .5738 L .42234 .57298 L F
.42527 .57372 m .42386 .5738 L .42471 .57358 L F
.397 .432 .78 r
.4264 .57257 m .42775 .57425 L .42607 .57501 L F
.164 0 .226 r
.42789 .56968 m .42526 .57301 L .42592 .5697 L F
.42526 .57301 m .42483 .57355 L .42495 .57313 L F
.42526 .57301 m .42495 .57313 L .42592 .5697 L F
.42483 .57355 m .42465 .57378 L .42471 .57358 L F
.42483 .57355 m .42471 .57358 L .42592 .5697 L F
.506 .193 .37 r
.42471 .57358 m .42465 .57378 L .42219 .57294 L F
.346 .498 .867 r
.42356 .57101 m .42487 .57362 L .42234 .57298 L F
.823 .743 .776 r
.42356 .57101 m .42465 .57378 L .42483 .57355 L F
.42356 .57101 m .42483 .57355 L .42789 .56968 L F
.346 .498 .867 r
.42356 .57101 m .42527 .57372 L .42487 .57362 L F
.397 .432 .78 r
.42663 .5708 m .42712 .57229 L .4264 .57257 L F
.42712 .57229 m .42775 .57425 L .4264 .57257 L F
.346 .498 .867 r
.42234 .57298 m .42607 .57501 L .42232 .57301 L F
.42224 .57288 m .42232 .57301 L .42219 .57294 L F
.42356 .57101 m .42232 .57301 L .42224 .57288 L F
.956 .696 .5 r
.42325 .57455 m .42399 .57649 L .42215 .57549 L F
.42401 .5758 m .42399 .57649 L .42325 .57455 L F
.177 .409 .848 r
.34966 .5595 m .34623 .55731 L .35198 .55834 L F
.077 0 .062 r
.35198 .55834 m .35094 .5601 L .3538 .55737 L F
.35198 .55834 m .35094 .5601 L .3538 .55737 L F
.203 .09 .494 r
.35311 .52578 m .35138 .52907 L .35212 .52664 L F
.374 .026 .242 r
.2699 .54823 m .27224 .54771 L .27349 .54519 L F
.469 .13 .307 r
.27224 .54771 m .27573 .54472 L .27349 .54519 L F
.469 .302 .571 r
.57807 .40684 m .5753 .40322 L .57677 .405 L F
.629 .845 .982 r
.57433 .40656 m .57807 .40684 L .57677 .405 L F
.575 .729 .948 r
.57677 .405 m .57807 .40684 L .58065 .40617 L F
.32 .77 .958 r
.27217 .52517 m .26782 .52471 L .2705 .52412 L F
.495 .822 1 r
.27459 .52458 m .27217 .52517 L .2705 .52412 L F
.86 .859 .838 r
.34743 .6479 m .35248 .64603 L .35165 .64503 L F
0 0 .271 r
.35248 .64603 m .35321 .64769 L .35214 .64518 L F
.35248 .64603 m .35216 .64981 L .35321 .64769 L F
.626 .874 .988 r
.26188 .52639 m .25971 .52741 L .25756 .52641 L F
.712 .46 .543 r
.33121 .58295 m .33453 .58386 L .33448 .58221 L F
.33121 .58295 m .33071 .58571 L .33453 .58386 L F
.765 .991 .777 r
.33542 .51395 m .33143 .51664 L .33624 .51206 L F
.378 .609 .94 r
.33624 .51206 m .33776 .51397 L .33542 .51395 L F
.283 0 .295 r
.23243 .57021 m .22942 .57292 L .22983 .57103 L F
.528 .699 .948 r
.38117 .57728 m .37902 .57821 L .37734 .57607 L F
.166 0 .105 r
.29662 .61118 m .29354 .61389 L .29461 .61203 L F
0 0 0 r
.28463 .54441 m .28268 .54791 L .28364 .54594 L F
.987 .794 .557 r
.36767 .60298 m .36856 .60697 L .36618 .60435 L F
.955 .618 .323 r
.36856 .60697 m .36561 .60576 L .36558 .60368 L F
.756 .684 .782 r
.36856 .60565 m .36856 .60697 L .36767 .60298 L F
.649 .624 .812 r
.37088 .60497 m .36856 .60565 L .36767 .60298 L F
.37088 .60497 m .36767 .60298 L .36982 .60189 L F
.263 .001 .315 r
.36575 .60562 m .36793 .60499 L .36828 .60309 L F
.36561 .60576 m .36572 .60573 L .36575 .60562 L F
.36572 .60573 m .36793 .60499 L .36575 .60562 L F
.987 .794 .557 r
.36651 .60337 m .36618 .60435 L .36558 .60368 L F
.36767 .60298 m .36618 .60435 L .36651 .60337 L F
.955 .618 .323 r
.36856 .60697 m .36733 .60735 L .36561 .60576 L F
.941 .58 .289 r
.36913 .60816 m .36856 .60697 L .36856 .60565 L F
.36913 .60816 m .36733 .60735 L .36856 .60697 L F
.908 .814 .743 r
.71276 .30207 m .71356 .30579 L .71294 .30345 L F
.824 .825 .849 r
.71356 .30579 m .7106 .30512 L .71294 .30345 L F
0 0 .048 r
.39296 .63072 m .3927 .63277 L .39089 .63368 L F
0 0 0 r
.39414 .62871 m .3927 .63277 L .39296 .63072 L F
0 0 .051 r
.33862 .65412 m .33687 .65519 L .3358 .65793 L F
.374 .779 .983 r
.37469 .55783 m .37725 .55774 L .37292 .5571 L F
.784 .639 .701 r
.39056 .58637 m .3907 .58949 L .39291 .58599 L F
.441 .261 .54 r
.38583 .69988 m .38578 .70283 L .38359 .70366 L F
.218 0 .098 r
.38578 .70283 m .38261 .70523 L .38359 .70366 L F
.739 .618 .724 r
.24165 .60699 m .24488 .60488 L .24397 .6086 L F
.436 .472 .799 r
.24488 .60488 m .24638 .6079 L .24397 .6086 L F
0 0 .054 r
.24638 .6079 m .24392 .60992 L .24397 .6086 L F
0 0 0 r
.22373 .58937 m .22599 .58636 L .22604 .58872 L F
.159 .193 .648 r
.22743 .58456 m .22599 .58636 L .22548 .58262 L F
.556 .513 .763 r
.22743 .58456 m .22604 .58872 L .22599 .58636 L F
.641 .129 .011 r
.28543 .64856 m .28925 .64924 L .28758 .64887 L F
.944 .626 .401 r
.28543 .64839 m .28758 .64887 L .28585 .65029 L F
.138 .623 .917 r
.28543 .64856 m .28758 .64887 L .2853 .64779 L F
.944 .626 .401 r
.2853 .64779 m .28758 .64887 L .28543 .64839 L F
.641 .129 .011 r
.28925 .64924 m .28953 .64929 L .28758 .64887 L F
.23 0 0 r
.28953 .64929 m .28924 .64951 L .28758 .64887 L F
.28953 .64929 m .29156 .64978 L .28924 .64951 L F
.818 .741 .779 r
.60521 .39923 m .60614 .40283 L .60518 .40239 L F
.788 .724 .793 r
.60852 .39941 m .60614 .40283 L .60521 .39923 L F
.72 .55 .659 r
.70473 .32758 m .70605 .33106 L .7023 .33066 L F
.628 .503 .691 r
.70864 .33038 m .70605 .33106 L .70473 .32758 L F
.561 .14 .2 r
.24594 .61863 m .24859 .6199 L .2501 .6182 L F
.899 .603 .477 r
.2501 .6182 m .25062 .62034 L .25276 .61792 L F
.2501 .6182 m .24859 .6199 L .25062 .62034 L F
.806 .542 .538 r
.61733 .43509 m .61363 .43677 L .61407 .4345 L F
.61733 .43509 m .61746 .43767 L .61363 .43677 L F
.677 .646 .812 r
.2551 .61255 m .25145 .61155 L .2532 .61077 L F
.8 .735 .791 r
.25586 .61054 m .2551 .61255 L .2532 .61077 L F
.25586 .61054 m .25735 .614 L .2551 .61255 L F
.595 .804 .98 r
.37413 .58926 m .37181 .58997 L .36944 .58831 L F
.6 .349 .508 r
.37413 .58926 m .37111 .5919 L .37181 .58997 L F
.098 .652 .705 r
.71379 .34119 m .71728 .34072 L .71797 .34063 L F
.767 .595 .664 r
.34269 .57954 m .34616 .58083 L .34586 .57767 L F
.011 .028 .528 r
.34586 .57767 m .34742 .57859 L .34832 .57646 L F
.34586 .57767 m .34616 .58083 L .34742 .57859 L F
.632 .963 .873 r
.32344 .61989 m .32582 .61875 L .32759 .61741 L F
.696 .686 .837 r
.69624 .33337 m .69756 .33749 L .69296 .33691 L F
.732 .569 .671 r
.69756 .33749 m .69468 .3402 L .69296 .33691 L F
.543 .285 .475 r
.69722 .33959 m .69468 .3402 L .69756 .33749 L F
.613 .637 .85 r
.69942 .33642 m .69756 .33749 L .69624 .33337 L F
.711 .439 .511 r
.70101 .33962 m .69756 .33749 L .69942 .33642 L F
.70101 .33962 m .69722 .33959 L .69756 .33749 L F
.104 .004 .445 r
.32657 .59277 m .32661 .59553 L .32781 .59185 L F
.191 .163 .595 r
.19276 .58337 m .19396 .57918 L .19213 .57991 L F
.19276 .58337 m .19381 .58305 L .19396 .57918 L F
.058 .072 .559 r
.19276 .58337 m .19424 .58546 L .19381 .58305 L F
.19276 .58337 m .19326 .58608 L .19424 .58546 L F
.534 .829 .999 r
.33813 .63623 m .33671 .63701 L .33408 .63585 L F
.473 .14 .321 r
.33809 .57126 m .33746 .57308 L .33482 .57351 L F
.296 0 .246 r
.33962 .57238 m .33746 .57308 L .33809 .57126 L F
.733 .672 .791 r
.70733 .33721 m .70367 .33718 L .70629 .33372 L F
0 0 0 r
.70733 .33721 m .70381 .33936 L .70367 .33718 L F
.70733 .33721 m .70623 .33841 L .70381 .33936 L F
.653 .624 .809 r
.70823 .33534 m .70733 .33721 L .70629 .33372 L F
0 0 0 r
.70944 .33564 m .70733 .33721 L .70823 .33534 L F
.70944 .33564 m .70623 .33841 L .70733 .33721 L F
.457 .39 .694 r
.39542 .59521 m .39594 .59959 L .39335 .59913 L F
.642 .526 .707 r
.39792 .59803 m .39594 .59959 L .39542 .59521 L F
.663 .969 .801 r
.39792 .59803 m .39651 .59888 L .39594 .59959 L F
.629 .563 .761 r
.39516 .60056 m .3944 .59996 L .39594 .59959 L F
.3944 .59996 m .39335 .59913 L .39594 .59959 L F
.39727 .60223 m .39516 .60056 L .39594 .59959 L F
.654 .719 .896 r
.39638 .59938 m .39727 .60223 L .39594 .59959 L F
.39872 .59829 m .39861 .5986 L .39638 .59938 L F
.39861 .5986 m .39727 .60223 L .39638 .59938 L F
.39872 .59829 m .39981 .6017 L .39727 .60223 L F
.851 .825 .822 r
.40233 .59859 m .39981 .6017 L .39921 .59983 L F
.39984 .59838 m .39921 .59983 L .39872 .59829 L F
.40233 .59859 m .39921 .59983 L .39984 .59838 L F
.901 .932 .826 r
.40108 .59537 m .39872 .59829 L .4002 .59765 L F
.858 .813 .805 r
.40112 .59548 m .39872 .59829 L .40108 .59537 L F
.722 .825 .37 r
.4002 .59765 m .40009 .59782 L .40029 .59737 L F
.858 .813 .805 r
.40233 .59859 m .39984 .59838 L .40112 .59548 L F
.39984 .59838 m .39916 .59833 L .40009 .59782 L F
.028 0 0 r
.39912 .59842 m .39989 .59815 L .40009 .59782 L F
.39952 .59813 m .40009 .59782 L .4002 .59765 L F
.39912 .59842 m .40009 .59782 L .39952 .59813 L F
.705 .79 .313 r
.40108 .59537 m .4002 .59765 L .40029 .59737 L F
.858 .813 .805 r
.40009 .59782 m .39872 .59829 L .40096 .59567 L F
.40009 .59782 m .40096 .59567 L .40029 .59737 L F
.705 .79 .313 r
.40108 .59537 m .40029 .59737 L .40093 .59542 L F
.858 .813 .805 r
.40029 .59737 m .40096 .59567 L .40112 .59548 L F
.39916 .59833 m .39872 .59829 L .39952 .59813 L F
.028 0 0 r
.39833 .59898 m .39952 .59813 L .39872 .59829 L F
.39952 .59813 m .4002 .59765 L .39872 .59829 L F
.858 .813 .805 r
.39952 .59813 m .39872 .59829 L .40009 .59782 L F
.722 .825 .37 r
.40029 .59737 m .40009 .59783 L .4003 .59733 L F
.40009 .59782 m .40009 .59783 L .40029 .59737 L F
.028 0 0 r
.39833 .59898 m .39923 .59919 L .39989 .59815 L F
.39833 .59898 m .39989 .59815 L .39912 .59842 L F
.722 .825 .37 r
.4003 .59733 m .39923 .59919 L .40093 .59542 L F
.40009 .59783 m .39923 .59919 L .4003 .59733 L F
0 0 0 r
.39594 .59959 m .39415 .60028 L .39807 .59906 L F
.39594 .59959 m .39807 .59906 L .39833 .59898 L F
.663 .969 .801 r
.39651 .59888 m .39415 .60028 L .39594 .59959 L F
.924 .671 .183 r
.60643 .40962 m .6058 .41089 L .60525 .40842 L F
.60643 .40962 m .60664 .4125 L .6058 .41089 L F
.581 .482 .707 r
.34929 .59545 m .34701 .59844 L .3464 .59636 L F
.34929 .59545 m .35 .59839 L .34701 .59844 L F
.437 .283 .573 r
.35 .59839 m .34764 .60217 L .34701 .59844 L F
.474 .895 .867 r
.26794 .53183 m .26725 .5327 L .26933 .53293 L F
.26794 .53183 m .266 .53274 L .26725 .5327 L F
.489 .226 .441 r
.36104 .52622 m .36304 .52819 L .36355 .52551 L F
.36104 .52622 m .36066 .52905 L .36304 .52819 L F
.369 .085 .344 r
.28901 .61789 m .28825 .62126 L .28599 .62048 L F
.747 .653 .756 r
.28825 .62126 m .28468 .62291 L .28599 .62048 L F
.409 0 .087 r
.38464 .58196 m .383 .58273 L .38006 .5831 L F
.703 .626 .767 r
.38542 .58002 m .38464 .58196 L .38117 .57728 L F
.842 .791 .802 r
.38542 .58002 m .383 .58273 L .38464 .58196 L F
.802 .715 .768 r
.38747 .58215 m .383 .58273 L .38542 .58002 L F
.652 .244 .26 r
.38747 .58215 m .38471 .58455 L .383 .58273 L F
.329 0 0 r
.38902 .58261 m .38471 .58455 L .38747 .58215 L F
.193 .121 .541 r
.39399 .61049 m .39215 .61208 L .39262 .60947 L F
.392 .247 .562 r
.39399 .61049 m .39216 .61393 L .39215 .61208 L F
.193 .121 .541 r
.39399 .61049 m .39215 .61208 L .39262 .60947 L F
.977 .771 .559 r
.41752 .55823 m .417 .56096 L .41582 .55741 L F
.611 .885 .99 r
.41752 .55823 m .41831 .55649 L .42036 .5569 L F
.41752 .55823 m .41582 .55741 L .41831 .55649 L F
.977 .771 .559 r
.41752 .55823 m .417 .56096 L .41582 .55741 L F
.785 .772 .265 r
.61857 .41922 m .61959 .41623 L .61864 .41558 L F
.61857 .41922 m .61881 .41942 L .61959 .41623 L F
.774 .993 .779 r
.62064 .41396 m .61959 .41623 L .62243 .41326 L F
.725 .964 .94 r
.61864 .41558 m .61959 .41623 L .62064 .41396 L F
.262 .415 .827 r
.36609 .61242 m .36983 .61381 L .36721 .61001 L F
.732 .743 .86 r
.62218 .40032 m .62319 .40341 L .61934 .40291 L F
.751 .753 .854 r
.62606 .40092 m .62319 .40341 L .62218 .40032 L F
.514 .817 1 r
.18582 .64578 m .18367 .64643 L .18158 .64528 L F
.18582 .64578 m .18367 .64643 L .18158 .64528 L F
.729 .665 .787 r
.34623 .55731 m .34896 .5612 L .34474 .56065 L F
.603 .102 .034 r
.34896 .5612 m .34709 .56252 L .34474 .56065 L F
.467 .432 .736 r
.33342 .50469 m .33239 .50658 L .33425 .50516 L F
.313 .784 .931 r
.33291 .50462 m .33857 .50471 L .33657 .50444 L F
.33287 .50462 m .33293 .50462 L .33291 .50462 L F
.33293 .50462 m .33857 .50471 L .33291 .50462 L F
.33308 .50464 m .33857 .50471 L .33287 .50462 L F
0 0 0 r
.33857 .50471 m .33308 .50464 L .33657 .50444 L F
.467 .432 .736 r
.33425 .50516 m .3321 .50452 L .33308 .50464 L F
0 0 0 r
.33857 .50471 m .33425 .50516 L .33308 .50464 L F
.467 .432 .736 r
.33425 .50516 m .33308 .50464 L .33342 .50469 L F
.3321 .50452 m .33239 .50658 L .33342 .50469 L F
0 0 0 r
.33308 .50464 m .33425 .50516 L .33247 .50464 L F
.33308 .50464 m .33247 .50464 L .33287 .50462 L F
.33308 .50464 m .33287 .50462 L .33657 .50444 L F
.467 .432 .736 r
.33425 .50516 m .33239 .50658 L .3321 .50452 L F
.313 .784 .931 r
.33308 .50464 m .3332 .50462 L .33312 .50464 L F
.467 .432 .736 r
.33342 .50469 m .3321 .50452 L .332 .50386 L F
.313 .784 .931 r
.33247 .50464 m .33308 .50464 L .33287 .50462 L F
.571 .569 .812 r
.33539 .50061 m .33368 .50296 L .33362 .50255 L F
.467 .432 .736 r
.332 .50386 m .33329 .50461 L .33362 .50255 L F
.313 .784 .931 r
.33247 .50464 m .33329 .50461 L .33308 .50464 L F
.33312 .50464 m .3345 .50443 L .33857 .50471 L F
.467 .432 .736 r
.33329 .50461 m .33308 .50464 L .33342 .50469 L F
.33425 .50516 m .33329 .50461 L .33247 .50464 L F
.332 .50386 m .3321 .50452 L .33308 .50464 L F
.332 .50386 m .33308 .50464 L .33329 .50461 L F
.33329 .50461 m .332 .50386 L .33247 .50464 L F
.33342 .50469 m .33415 .50478 L .33407 .50442 L F
.571 .569 .812 r
.33539 .50061 m .33633 .50414 L .33399 .50444 L F
.467 .432 .736 r
.33343 .50457 m .33399 .50444 L .33362 .50255 L F
.33399 .50444 m .33385 .50351 L .33362 .50255 L F
.33329 .50461 m .33343 .50457 L .33362 .50255 L F
.571 .569 .812 r
.33368 .50296 m .33399 .50444 L .33247 .50464 L F
.33385 .50351 m .33399 .50444 L .33368 .50296 L F
.33539 .50061 m .33399 .50444 L .33375 .50287 L F
.467 .432 .736 r
.33399 .50444 m .33407 .50442 L .33385 .50351 L F
.571 .569 .812 r
.33368 .50296 m .33247 .50464 L .33362 .50255 L F
.784 .695 .766 r
.33407 .50442 m .33229 .50441 L .33358 .50261 L F
.33385 .50351 m .33358 .50261 L .33362 .50255 L F
.33407 .50442 m .33358 .50261 L .33385 .50351 L F
.571 .569 .812 r
.33375 .50287 m .33385 .50351 L .33368 .50296 L F
.313 .784 .931 r
.33399 .50444 m .33456 .50437 L .33329 .50461 L F
.3332 .50462 m .33633 .50414 L .33312 .50464 L F
.467 .432 .736 r
.33342 .50469 m .33407 .50442 L .33343 .50457 L F
.313 .784 .931 r
.33247 .50464 m .33399 .50444 L .33329 .50461 L F
.784 .695 .766 r
.33402 .50508 m .33177 .50512 L .33229 .50441 L F
.33425 .50516 m .33403 .50516 L .33402 .50508 L F
.33403 .50516 m .33177 .50512 L .33402 .50508 L F
.467 .432 .736 r
.33329 .50461 m .33342 .50469 L .33343 .50457 L F
.33342 .50469 m .33425 .50516 L .33415 .50478 L F
.784 .695 .766 r
.33425 .50516 m .33229 .50441 L .33407 .50442 L F
.313 .784 .931 r
.3345 .50443 m .33633 .50414 L .33758 .50446 L F
.3345 .50443 m .33758 .50446 L .33857 .50471 L F
.33456 .50437 m .33633 .50414 L .33308 .50464 L F
.616 .904 .985 r
.34966 .5595 m .34896 .5612 L .35094 .5601 L F
.177 .409 .848 r
.34966 .5595 m .34896 .5612 L .34623 .55731 L F
.616 .904 .985 r
.34966 .5595 m .34896 .5612 L .35094 .5601 L F
.752 .963 .673 r
.34966 .5595 m .34709 .56252 L .34896 .5612 L F
.062 .312 .796 r
.34896 .5612 m .35167 .56318 L .35094 .5601 L F
.036 0 .396 r
.39743 .66463 m .39737 .66755 L .39536 .67004 L F
.875 .91 .504 r
.39737 .66755 m .39622 .67142 L .39536 .67004 L F
.789 .983 .9 r
.71624 .30949 m .71499 .31211 L .71792 .30964 L F
.806 .999 .84 r
.71454 .31139 m .71499 .31211 L .71624 .30949 L F
.229 .651 .957 r
.63143 .40894 m .63263 .40807 L .63001 .40781 L F
.63143 .40894 m .63385 .40915 L .63263 .40807 L F
.503 .381 .646 r
.33087 .53962 m .3307 .54223 L .32818 .54275 L F
.632 .484 .663 r
.38268 .5986 m .38493 .59542 L .3826 .5958 L F
0 0 0 r
.72032 .32155 m .72317 .31773 L .72198 .31934 L F
.353 .751 .985 r
.72551 .31754 m .72317 .31773 L .72171 .31674 L F
.254 0 0 r
.72198 .31934 m .72317 .31773 L .72551 .31754 L F
.775 .673 .751 r
.38731 .56012 m .38503 .56384 L .38594 .56152 L F
0 0 .04 r
.39119 .63443 m .39089 .63368 L .3927 .63277 L F
.39119 .63443 m .39055 .63621 L .39089 .63368 L F
.276 .237 .633 r
.3594 .59172 m .36119 .5953 L .36203 .59286 L F
.3594 .59172 m .35968 .59581 L .36119 .5953 L F
.725 .546 .647 r
.59258 .42872 m .59287 .43165 L .59032 .43135 L F
.62 .681 .886 r
.59475 .42651 m .59696 .4292 L .59258 .42872 L F
.73 .619 .734 r
.59696 .4292 m .59287 .43165 L .59258 .42872 L F
.418 .765 .996 r
.35164 .50453 m .35431 .50417 L .35371 .50554 L F
.43 .695 .975 r
.35615 .50356 m .35371 .50554 L .35431 .50417 L F
.35615 .50356 m .35898 .50544 L .35371 .50554 L F
.62 .856 .988 r
.30089 .52078 m .29674 .52057 L .29906 .51955 L F
.691 .853 .96 r
.30279 .51944 m .30089 .52078 L .29906 .51955 L F
.862 .428 .008 r
.36919 .6169 m .36936 .6154 L .36983 .61381 L F
.775 .673 .751 r
.38731 .56012 m .38904 .56433 L .38503 .56384 L F
.794 .682 .74 r
.39061 .5607 m .38904 .56433 L .38731 .56012 L F
.39061 .5607 m .38731 .56012 L .39034 .56059 L F
.312 .479 .864 r
.38987 .5585 m .39061 .5607 L .39157 .5577 L F
.775 .87 .438 r
.39061 .5607 m .39034 .56059 L .39157 .5577 L F
.377 0 .082 r
.22536 .59035 m .22373 .58937 L .22604 .58872 L F
.22536 .59035 m .22215 .59141 L .22373 .58937 L F
.56 .81 .433 r
.33951 .51738 m .33812 .51918 L .33761 .51985 L F
0 0 0 r
.33992 .5179 m .33812 .51918 L .33951 .51738 L F
.511 .897 .735 r
.33992 .5179 m .3384 .51882 L .33812 .51918 L F
.3384 .51882 m .33738 .51943 L .33812 .51918 L F
.56 .81 .433 r
.33761 .51985 m .33812 .51918 L .33714 .52045 L F
.678 .678 .843 r
.34101 .5156 m .33951 .51738 L .33776 .51397 L F
0 0 0 r
.33992 .5179 m .33951 .51738 L .34101 .5156 L F
.412 .729 .99 r
.33714 .52045 m .33812 .51918 L .33527 .51909 L F
.33714 .52045 m .33812 .51918 L .33527 .51909 L F
.423 .28 .581 r
.33478 .55494 m .33464 .55768 L .33682 .55687 L F
.426 .249 .537 r
.38795 .70199 m .38583 .69988 L .38824 .69945 L F
.38795 .70199 m .38578 .70283 L .38583 .69988 L F
.658 .152 .03 r
.3007 .53918 m .30372 .54112 L .30508 .54021 L F
.519 0 0 r
.30508 .54021 m .30372 .54112 L .3065 .54119 L F
.756 .938 .599 r
.36913 .60816 m .36721 .61001 L .36733 .60735 L F
.088 0 .346 r
.37088 .60497 m .36913 .60816 L .36856 .60565 L F
.758 .336 .248 r
.36721 .61001 m .36913 .60816 L .37047 .60735 L F
.219 .468 .882 r
.36611 .65919 m .36594 .65784 L .36286 .65825 L F
.36611 .65919 m .36675 .65953 L .36594 .65784 L F
.305 .799 .813 r
.26782 .52471 m .26564 .52537 L .26412 .52553 L F
.337 .348 .724 r
.33448 .58221 m .33622 .58362 L .33541 .57903 L F
.44 .41 .729 r
.33453 .58386 m .33622 .58362 L .33448 .58221 L F
.107 .428 .871 r
.32263 .54689 m .32394 .54626 L .321 .54512 L F
.137 .431 .87 r
.32446 .54766 m .3249 .54797 L .32263 .54689 L F
.107 .428 .871 r
.32263 .54689 m .3249 .54797 L .32394 .54626 L F
.185 .653 .936 r
.26984 .63684 m .27334 .63772 L .27166 .63687 L F
0 .32 .786 r
.27334 .63772 m .27469 .63788 L .27166 .63687 L F
.27334 .63772 m .27594 .63929 L .27469 .63788 L F
.575 .068 0 r
.34833 .70939 m .34916 .71054 L .34634 .70899 L F
.34833 .70939 m .35061 .71188 L .34916 .71054 L F
.852 .723 .719 r
.24941 .60822 m .25145 .61155 L .24767 .61033 L F
.896 .629 .526 r
.25145 .61155 m .24923 .61247 L .24767 .61033 L F
.25145 .61155 m .25113 .61465 L .24923 .61247 L F
.719 .469 .546 r
.24941 .60822 m .2532 .61077 L .25145 .61155 L F
.748 .49 .542 r
.32649 .53865 m .33083 .53719 L .32868 .53611 L F
.356 0 0 r
.33245 .53709 m .32868 .53611 L .33083 .53719 L F
.807 .559 .564 r
.7138 .34337 m .71168 .34573 L .71174 .34343 L F
.7138 .34337 m .71512 .34656 L .71168 .34573 L F
.465 .223 .462 r
.36673 .55146 m .3664 .55441 L .36326 .55496 L F
.488 .242 .468 r
.36897 .55297 m .36673 .55146 L .36934 .55126 L F
.36897 .55297 m .3664 .55441 L .36673 .55146 L F
.88 .958 .849 r
.34263 .66829 m .3455 .66526 L .34393 .6647 L F
.547 .33 .537 r
.34263 .66829 m .34451 .66758 L .3455 .66526 L F
.408 .831 .963 r
.34393 .6647 m .3455 .66526 L .34729 .66467 L F
.34393 .6647 m .3455 .66526 L .34729 .66467 L F
.559 .739 .96 r
.28128 .53003 m .2833 .5327 L .28552 .53172 L F
.764 .993 .876 r
.27344 .54992 m .27136 .55235 L .27344 .55031 L F
.286 .045 .362 r
.27344 .54992 m .27039 .55336 L .27136 .55235 L F
.494 .127 .272 r
.35655 .56982 m .36011 .56765 L .35674 .56904 L F
0 .338 .809 r
.25294 .63407 m .2526 .63328 L .25158 .63233 L F
.25294 .63407 m .25408 .63447 L .2526 .63328 L F
.863 .505 .372 r
.61921 .44107 m .6226 .44438 L .62188 .44443 L F
.78 .47 .464 r
.62282 .44664 m .62188 .44443 L .6226 .44438 L F
.22 0 .182 r
.26829 .55415 m .26722 .55695 L .26444 .55753 L F
.308 0 .122 r
.26722 .55695 m .26419 .55874 L .26444 .55753 L F
.797 .732 .791 r
.34487 .54497 m .34231 .54792 L .34242 .54568 L F
.575 .158 .214 r
.34449 .55006 m .34082 .55035 L .34231 .54792 L F
.492 .409 .69 r
.39004 .65965 m .3934 .66195 L .39249 .65893 L F
.216 0 .101 r
.32926 .58836 m .33453 .58386 L .33071 .58571 L F
.32926 .58836 m .33245 .58769 L .33453 .58386 L F
.483 .103 .242 r
.33453 .58386 m .33245 .58769 L .33559 .58694 L F
.312 .103 .426 r
.32103 .52876 m .31908 .52968 L .32123 .52608 L F
.32103 .52876 m .31908 .52968 L .32123 .52608 L F
.589 .855 .51 r
.32123 .52608 m .32223 .52472 L .3238 .52304 L F
.421 .19 .455 r
.32123 .52608 m .32392 .52587 L .32223 .52472 L F
.32123 .52608 m .32103 .52876 L .32392 .52587 L F
.32392 .52587 m .32103 .52876 L .32123 .52608 L F
.846 .988 .718 r
.28833 .55515 m .28872 .553 L .29026 .55668 L F
.28833 .55515 m .28613 .55644 L .28872 .553 L F
.99 .728 .396 r
.59669 .42029 m .59771 .42234 L .59635 .42101 L F
.648 .704 .888 r
.59669 .42029 m .60092 .42131 L .59771 .42234 L F
0 .488 .76 r
.6021 .42149 m .60092 .42131 L .59669 .42029 L F
.614 .511 .713 r
.60049 .42118 m .6021 .42149 L .60054 .42115 L F
0 .486 .737 r
.60006 .42105 m .60046 .42117 L .6021 .42149 L F
.60046 .42117 m .60092 .42131 L .6021 .42149 L F
.614 .511 .713 r
.59865 .42237 m .6021 .42149 L .60049 .42118 L F
.43 .87 .897 r
.59859 .42186 m .60092 .42131 L .60046 .42117 L F
.59859 .42186 m .60046 .42117 L .59899 .42164 L F
.59771 .42234 m .59942 .42179 L .59859 .42186 L F
.59942 .42179 m .60092 .42131 L .59859 .42186 L F
.614 .511 .713 r
.59865 .42237 m .60054 .42115 L .5982 .42189 L F
.59899 .42164 m .60054 .42115 L .59935 .42088 L F
.43 .87 .897 r
.59899 .42164 m .60046 .42117 L .60006 .42105 L F
.615 .813 .976 r
.60006 .42105 m .6021 .42149 L .59865 .42237 L F
.43 .87 .897 r
.59773 .42425 m .60006 .42105 L .59773 .42442 L F
.59771 .42234 m .59859 .42186 L .59773 .42425 L F
.99 .728 .396 r
.5982 .42189 m .59788 .42192 L .59864 .42236 L F
.59864 .42236 m .59864 .42236 L .59865 .42237 L F
.43 .87 .897 r
.59859 .42186 m .59864 .42236 L .59773 .42425 L F
.99 .728 .396 r
.5982 .42189 m .59864 .42236 L .59864 .42236 L F
.43 .87 .897 r
.59859 .42186 m .59899 .42164 L .59864 .42236 L F
.59899 .42164 m .60006 .42105 L .59773 .42425 L F
.614 .511 .713 r
.5982 .42189 m .59899 .42164 L .59669 .42029 L F
.59899 .42164 m .59935 .42088 L .59669 .42029 L F
.99 .728 .396 r
.59669 .42029 m .59635 .42101 L .59788 .42192 L F
.59669 .42029 m .59788 .42192 L .5982 .42189 L F
.528 .333 .56 r
.36355 .58319 m .36354 .58586 L .36096 .58636 L F
.48 .309 .57 r
.36335 .58846 m .36096 .58636 L .36354 .58586 L F
.36335 .58846 m .36091 .58921 L .36096 .58636 L F
.528 .333 .56 r
.36355 .58319 m .36354 .58586 L .36096 .58636 L F
.48 .309 .57 r
.36335 .58846 m .36096 .58636 L .36354 .58586 L F
.36335 .58846 m .36091 .58921 L .36096 .58636 L F
.178 0 .272 r
.29072 .61933 m .28901 .61789 L .29047 .61668 L F
.29072 .61933 m .28825 .62126 L .28901 .61789 L F
.606 .952 .898 r
.71694 .32287 m .72032 .32155 L .71901 .32208 L F
.666 .958 .736 r
.71901 .32208 m .72032 .32155 L .72198 .31934 L F
.308 0 .026 r
.35729 .57811 m .35577 .57728 L .3579 .57604 L F
.35729 .57811 m .35105 .58096 L .35577 .57728 L F
.361 0 .123 r
.24052 .56126 m .23907 .56325 L .2368 .5632 L F
.335 0 .107 r
.24184 .56243 m .24052 .56126 L .24265 .5604 L F
.24184 .56243 m .23907 .56325 L .24052 .56126 L F
0 .341 .762 r
.2444 .61746 m .24594 .61863 L .24247 .61652 L F
0 .299 .686 r
.24681 .61889 m .24594 .61863 L .2444 .61746 L F
.24681 .61889 m .24859 .6199 L .24594 .61863 L F
.668 .824 .391 r
.28974 .6238 m .28767 .62755 L .28844 .62593 L F
0 .07 .61 r
.28844 .62593 m .28767 .62755 L .28926 .6294 L F
.744 .491 .548 r
.36326 .55496 m .36388 .55743 L .36036 .55723 L F
.49 .335 .598 r
.36545 .55642 m .36326 .55496 L .3664 .55441 L F
.36545 .55642 m .36388 .55743 L .36326 .55496 L F
.028 0 0 r
.20121 .56352 m .20267 .56345 L .20442 .5612 L F
0 0 0 r
.20678 .5579 m .20442 .5612 L .20568 .55996 L F
.072 0 0 r
.20442 .5612 m .20484 .56248 L .20568 .55996 L F
.20442 .5612 m .20267 .56345 L .20484 .56248 L F
.218 .194 .616 r
.36418 .59169 m .36203 .59286 L .36119 .5953 L F
.285 0 0 r
.36016 .53597 m .35854 .53782 L .35588 .53809 L F
.278 0 0 r
.361 .53719 m .36016 .53597 L .36287 .53562 L F
.361 .53719 m .35854 .53782 L .36016 .53597 L F
0 0 .349 r
.32918 .61163 m .32917 .61167 L .32843 .61164 L F
0 .544 .712 r
.32843 .61164 m .33131 .61183 L .32822 .61163 L F
.881 .667 .609 r
.33033 .61447 m .33131 .61183 L .32843 .61164 L F
.33033 .61447 m .32843 .61164 L .32906 .61333 L F
0 0 .349 r
.32917 .61167 m .32906 .61333 L .32843 .61164 L F
0 .544 .712 r
.32843 .61164 m .32822 .61163 L .32626 .6115 L F
.739 .624 .731 r
.3779 .60508 m .37942 .60866 L .37522 .6084 L F
.155 .682 .869 r
.37522 .6084 m .37942 .60866 L .37748 .60827 L F
0 .332 .816 r
.37942 .60866 m .38025 .60776 L .37748 .60827 L F
.672 .476 .611 r
.37942 .60866 m .38068 .61052 L .37922 .61133 L F
.625 .435 .605 r
.37922 .61133 m .38249 .61104 L .37942 .60866 L F
.589 .097 .053 r
.25253 .62202 m .25475 .62282 L .25674 .62137 L F
.549 .049 .02 r
.25674 .62137 m .25475 .62282 L .25881 .62274 L F
.516 .107 .203 r
.25674 .62137 m .25881 .62274 L .25934 .62137 L F
0 0 .154 r
.32206 .61526 m .32113 .61747 L .32326 .61398 L F
.967 .873 .69 r
.34623 .55731 m .34493 .55743 L .34768 .55491 L F
.34623 .55731 m .34493 .55743 L .34768 .55491 L F
.365 .683 .979 r
.34768 .55491 m .34794 .55315 L .34559 .55312 L F
0 0 0 r
.34768 .55491 m .34853 .55424 L .34794 .55315 L F
.122 0 .398 r
.19374 .57648 m .19536 .57289 L .19381 .57377 L F
.761 .608 .688 r
.33488 .69647 m .33682 .69976 L .33262 .69957 L F
.712 .358 .374 r
.33682 .69976 m .33478 .70227 L .33262 .69957 L F
.832 .523 .468 r
.33693 .70224 m .33478 .70227 L .33682 .69976 L F
.806 .468 .417 r
.33682 .69976 m .34072 .70291 L .33693 .70224 L F
0 0 .284 r
.71174 .34343 m .71345 .34395 L .71379 .34119 L F
.71174 .34343 m .71168 .34573 L .71345 .34395 L F
.213 .328 .765 r
.33713 .53838 m .33987 .54107 L .34096 .53937 L F
.738 .346 .309 r
.33713 .53838 m .33987 .54107 L .34096 .53937 L F
0 0 .119 r
.2997 .58976 m .2989 .59202 L .301 .5886 L F
.948 .743 .594 r
.30689 .52259 m .30634 .52555 L .30823 .52637 L F
.934 .598 .372 r
.30634 .52555 m .30663 .5279 L .30823 .52637 L F
.874 .488 .304 r
.30823 .52637 m .30663 .5279 L .30897 .52857 L F
.255 .12 .497 r
.36543 .58216 m .36354 .58586 L .36355 .58319 L F
.36543 .58216 m .36354 .58586 L .36355 .58319 L F
.524 .521 .794 r
.35481 .5319 m .35281 .53324 L .35138 .52907 L F
.062 0 .43 r
.30868 .57374 m .3116 .57509 L .3103 .57164 L F
.30868 .57374 m .3086 .57631 L .3116 .57509 L F
.398 .286 .608 r
.35963 .59848 m .36119 .5953 L .35968 .59581 L F
.5 .237 .448 r
.30485 .55469 m .30719 .55677 L .30745 .55447 L F
.30485 .55469 m .30423 .55743 L .30719 .55677 L F
.432 .421 .747 r
.33827 .60521 m .33894 .60908 L .34061 .60731 L F
.213 0 .173 r
.29034 .53856 m .28755 .54122 L .28842 .53938 L F
.467 .216 .45 r
.35149 .5731 m .35377 .57218 L .35418 .57056 L F
0 0 0 r
.35377 .57218 m .35655 .56982 L .35418 .57056 L F
.192 .715 .865 r
.26041 .53875 m .26067 .53852 L .25807 .53871 L F
.485 .83 .997 r
.33193 .66896 m .3369 .66933 L .33433 .66866 L F
.748 .91 .948 r
.33433 .66866 m .3369 .66933 L .33856 .66778 L F
.589 .118 .104 r
.32566 .66766 m .32998 .6676 L .32845 .66846 L F
0 .156 .6 r
.32998 .6676 m .3303 .66777 L .32845 .66846 L F
.32998 .6676 m .33193 .66896 L .3303 .66777 L F
.37 .029 .25 r
.26958 .55636 m .26829 .55415 L .27039 .55336 L F
.26958 .55636 m .26722 .55695 L .26829 .55415 L F
.202 0 0 r
.28048 .5487 m .27853 .5494 L .27597 .54933 L F
.692 .321 .341 r
.28268 .54791 m .27853 .5494 L .28048 .5487 L F
.731 .795 .903 r
.35737 .51314 m .35862 .51379 L .35734 .51301 L F
.35737 .51314 m .35614 .51397 L .35862 .51379 L F
.934 .672 .516 r
.35862 .51379 m .35693 .51557 L .35734 .51301 L F
.35862 .51379 m .35828 .51618 L .35693 .51557 L F
.402 .805 .587 r
.23466 .53569 m .23582 .53489 L .23783 .53352 L F
0 0 0 r
.23783 .53352 m .2379 .53396 L .23996 .53253 L F
.23783 .53352 m .23582 .53489 L .2379 .53396 L F
.28 .306 .71 r
.38182 .57004 m .3803 .57009 L .37932 .56781 L F
.323 .688 .979 r
.3648 .50791 m .36418 .50929 L .36189 .50755 L F
.3648 .50791 m .36637 .50923 L .36418 .50929 L F
.494 .127 .272 r
.35655 .56982 m .3587 .57002 L .36011 .56765 L F
.718 .378 .402 r
.36011 .56765 m .36281 .57005 L .36184 .5674 L F
.36011 .56765 m .3587 .57002 L .36281 .57005 L F
.856 .694 .681 r
.61746 .43767 m .61921 .44107 L .61733 .44029 L F
.886 .516 .335 r
.61921 .44107 m .61776 .44269 L .61733 .44029 L F
.61921 .44107 m .62188 .44443 L .61776 .44269 L F
.829 .358 .071 r
.71879 .34969 m .7166 .34893 L .71512 .34656 L F
.917 .863 .772 r
.71879 .34969 m .71695 .35252 L .71545 .35097 L F
.634 .444 .608 r
.71973 .35219 m .71695 .35252 L .71879 .34969 L F
.645 .897 .568 r
.64394 .42459 m .64106 .4279 L .64327 .42664 L F
.637 .919 .636 r
.64688 .42133 m .64394 .42459 L .64407 .42434 L F
.64688 .42133 m .6465 .42202 L .64394 .42459 L F
0 0 0 r
.64394 .42459 m .64327 .42664 L .64407 .42434 L F
.976 .777 .57 r
.35238 .55372 m .35402 .5548 L .35334 .5518 L F
.62 .112 .019 r
.35238 .55372 m .35648 .55423 L .35402 .5548 L F
.668 .824 .391 r
.28974 .6238 m .28844 .62593 L .28866 .62322 L F
.579 .687 .915 r
.29057 .62044 m .28974 .6238 L .28866 .62322 L F
.29057 .62044 m .29422 .62307 L .28974 .6238 L F
.736 .633 .745 r
.70722 .30834 m .7088 .3124 L .70466 .31159 L F
.217 .406 .834 r
.29687 .64525 m .2942 .64404 L .29379 .64209 L F
.517 0 0 r
.31605 .52852 m .31688 .52905 L .31908 .52968 L F
.968 .748 .552 r
.31688 .52905 m .31831 .53167 L .31908 .52968 L F
.213 0 .241 r
.32103 .52876 m .31831 .53167 L .31908 .52968 L F
.32103 .52876 m .31831 .53167 L .31908 .52968 L F
.118 .336 .804 r
.31759 .52739 m .31932 .53061 L .31688 .52905 L F
.31932 .53061 m .31947 .53091 L .31688 .52905 L F
.517 0 0 r
.31499 .52811 m .31688 .52905 L .31605 .52852 L F
.679 .576 .733 r
.36527 .53249 m .36287 .53562 L .36316 .5336 L F
0 0 0 r
.36553 .536 m .361 .53719 L .36287 .53562 L F
.659 .636 .816 r
.35472 .54395 m .35278 .54478 L .35018 .54241 L F
.677 .872 .972 r
.35518 .54405 m .35278 .54478 L .35472 .54395 L F
.686 .27 0 r
.39484 .53543 m .3961 .53784 L .39692 .53884 L F
.873 .549 .037 r
.3961 .53784 m .39769 .54152 L .39692 .53884 L F
0 0 0 r
.32304 .66449 m .32405 .66181 L .32167 .66507 L F
.08 .269 .756 r
.32283 .65809 m .32405 .66181 L .32552 .66214 L F
.581 .56 .796 r
.32922 .66445 m .32405 .66181 L .32552 .66214 L F
.684 .463 .579 r
.32304 .66449 m .32552 .66214 L .32405 .66181 L F
0 0 0 r
.35149 .5731 m .3529 .57309 L .35377 .57218 L F
.35149 .5731 m .34938 .57483 L .3529 .57309 L F
.244 .091 .465 r
.22691 .5766 m .22655 .57945 L .22482 .58024 L F
.117 .094 .553 r
.22655 .57945 m .22548 .58262 L .22482 .58024 L F
0 .21 .71 r
.31122 .51573 m .31066 .51608 L .30884 .51526 L F
.279 0 .061 r
.31242 .51466 m .31066 .51608 L .31315 .51531 L F
0 .21 .71 r
.31131 .51575 m .31066 .51608 L .31122 .51573 L F
0 0 0 r
.31037 .51627 m .31066 .51608 L .31242 .51466 L F
.30955 .5169 m .31066 .51608 L .31037 .51627 L F
.393 .844 .917 r
.30955 .5169 m .30804 .51672 L .31066 .51608 L F
.261 .046 .387 r
.28887 .63339 m .29027 .63481 L .28955 .63255 L F
.28887 .63339 m .28874 .6356 L .29027 .63481 L F
.656 .352 .445 r
.57703 .41578 m .58007 .41622 L .5795 .41813 L F
.5795 .41813 m .58007 .41622 L .57703 .41578 L F
.235 .246 .667 r
.38133 .60188 m .38335 .6046 L .38285 .60134 L F
0 0 0 r
.2123 .55203 m .21094 .55345 L .21422 .55101 L F
.253 .087 .452 r
.38962 .61441 m .38947 .61714 L .38776 .61762 L F
.564 .541 .787 r
.38947 .61714 m .38834 .62178 L .38776 .61762 L F
.485 .232 .455 r
.31114 .63033 m .31324 .63046 L .31332 .6284 L F
.674 .467 .598 r
.31324 .63046 m .31728 .62731 L .31332 .6284 L F
.353 .085 .362 r
.31614 .63621 m .31861 .63342 L .31866 .63443 L F
0 0 .096 r
.31866 .63443 m .31861 .63342 L .31897 .63203 L F
.564 .541 .787 r
.38947 .61714 m .39116 .62222 L .38834 .62178 L F
.58 .502 .731 r
.39116 .62222 m .39167 .62413 L .38834 .62178 L F
.702 .164 0 r
.36861 .631 m .3665 .62831 L .36556 .62829 L F
.15 .506 .911 r
.37016 .63051 m .3665 .62831 L .36861 .631 L F
.135 0 0 r
.72957 .34966 m .72918 .35124 L .72611 .35203 L F
.061 0 .324 r
.73137 .34599 m .7319 .34815 L .72957 .34966 L F
0 0 0 r
.73065 .34959 m .72957 .34966 L .7319 .34815 L F
.73065 .34959 m .72918 .35124 L .72957 .34966 L F
.72 .91 .961 r
.33894 .57676 m .33482 .57351 L .33746 .57308 L F
.33894 .57676 m .33689 .57557 L .33482 .57351 L F
.33894 .57676 m .3365 .57764 L .33689 .57557 L F
.352 .533 .894 r
.33926 .57951 m .3365 .57764 L .33894 .57676 L F
.593 .631 .858 r
.33962 .57238 m .33894 .57676 L .33746 .57308 L F
.33962 .57238 m .34225 .57631 L .33894 .57676 L F
.696 .618 .766 r
.34225 .57631 m .33926 .57951 L .33894 .57676 L F
.417 .813 .985 r
.29497 .62321 m .29922 .62353 L .29683 .62395 L F
.408 .065 .269 r
.39535 .60847 m .39399 .61049 L .39262 .60947 L F
.982 .772 .545 r
.3443 .51092 m .34281 .51231 L .34277 .50941 L F
.357 .241 .582 r
.19213 .57991 m .19396 .57918 L .19374 .57648 L F
.464 .202 .431 r
.24762 .55118 m .24477 .55443 L .24549 .55316 L F
.687 .449 .557 r
.6289 .44438 m .62904 .44692 L .62498 .44696 L F
.676 .441 .557 r
.63221 .44659 m .6289 .44438 L .63164 .44398 L F
.63221 .44659 m .62904 .44692 L .6289 .44438 L F
.117 .094 .553 r
.22655 .57945 m .22673 .58245 L .22548 .58262 L F
.132 .189 .656 r
.22673 .58245 m .22743 .58456 L .22548 .58262 L F
.73 .619 .734 r
.59696 .4292 m .59649 .43179 L .59287 .43165 L F
.591 .125 .117 r
.59287 .43165 m .59649 .43179 L .59645 .43321 L F
.729 .618 .734 r
.59903 .42858 m .59649 .43179 L .59696 .4292 L F
.2 0 .28 r
.59841 .43112 m .59649 .43179 L .59903 .42858 L F
.119 0 .089 r
.59645 .43321 m .59649 .43179 L .59841 .43112 L F
.032 0 .167 r
.3994 .67708 m .39706 .68038 L .39785 .67818 L F
.659 .802 .951 r
.33856 .66778 m .34263 .66829 L .34072 .66714 L F
.88 .958 .849 r
.34263 .66829 m .34393 .6647 L .34072 .66714 L F
.829 .997 .841 r
.64889 .41875 m .64951 .41889 L .6465 .42202 L F
.64889 .41875 m .6465 .42202 L .64827 .41966 L F
.637 .918 .635 r
.64827 .41966 m .6465 .42202 L .64688 .42133 L F
.518 .33 .565 r
.64951 .41889 m .64988 .42139 L .6465 .42202 L F
.516 .323 .558 r
.6465 .42202 m .64988 .42139 L .6484 .42453 L F
.283 0 .295 r
.23243 .57021 m .23142 .57292 L .22942 .57292 L F
.261 0 .281 r
.23142 .57292 m .2289 .57568 L .22942 .57292 L F
.142 0 0 r
.27573 .54472 m .27769 .54413 L .2792 .54241 L F
0 0 .286 r
.28057 .53883 m .2792 .54241 L .28035 .54096 L F
0 0 .037 r
.27769 .54413 m .28035 .54096 L .2792 .54241 L F
.428 .326 .637 r
.31329 .58835 m .31098 .58656 L .3136 .58498 L F
.31329 .58835 m .31165 .58913 L .31098 .58656 L F
.818 .497 0 r
.40778 .57465 m .40791 .57335 L .40745 .57203 L F
.40778 .57465 m .40863 .57638 L .40791 .57335 L F
.535 .362 .593 r
.39981 .6017 m .39758 .60561 L .39727 .60223 L F
.692 .68 .833 r
.69624 .33337 m .69296 .33691 L .69194 .33253 L F
.495 .905 .888 r
.26004 .63194 m .25946 .63282 L .26186 .6328 L F
.26004 .63194 m .25787 .63294 L .25946 .63282 L F
.1 0 0 r
.24023 .54532 m .2382 .54647 L .23621 .54668 L F
.804 1 .812 r
.24184 .542 m .24136 .54403 L .2437 .54138 L F
0 .065 .618 r
.24184 .542 m .24216 .54311 L .24136 .54403 L F
.533 .817 .471 r
.24289 .54231 m .24136 .54403 L .24064 .54486 L F
0 .065 .618 r
.24216 .54311 m .24288 .5456 L .24136 .54403 L F
.533 .817 .471 r
.24064 .54486 m .24136 .54403 L .24023 .54532 L F
.472 .183 .394 r
.24136 .54403 m .2382 .54647 L .24023 .54532 L F
.603 .865 .992 r
.38848 .65437 m .38491 .65442 L .38718 .65305 L F
0 0 .195 r
.38822 .65734 m .38624 .65873 L .38848 .65437 L F
.025 .433 .867 r
.38848 .65437 m .38908 .65715 L .38822 .65734 L F
.603 .881 .563 r
.28755 .54122 m .28463 .54441 L .28621 .5428 L F
.502 .658 .93 r
.34616 .58083 m .3482 .58043 L .34742 .57859 L F
.958 .709 .26 r
.40901 .52876 m .40975 .53165 L .4099 .52931 L F
.567 .931 .932 r
.41131 .52761 m .4099 .52931 L .41144 .52796 L F
.41131 .52761 m .40901 .52876 L .4099 .52931 L F
.842 .707 .715 r
.56538 .39768 m .56849 .39938 L .56756 .398 L F
.274 .657 .968 r
.56715 .39871 m .56686 .39922 L .56538 .39768 L F
.56715 .39871 m .56849 .39938 L .56686 .39922 L F
.842 .707 .715 r
.56538 .39768 m .56846 .39946 L .56849 .39938 L F
.274 .657 .968 r
.56756 .398 m .56849 .39938 L .56715 .39871 L F
.842 .707 .715 r
.56715 .39871 m .5665 .40526 L .56846 .39946 L F
.56538 .39768 m .5654 .39782 L .56715 .39871 L F
.782 .669 .739 r
.56828 .40328 m .56849 .39938 L .5665 .40526 L F
.759 .681 .776 r
.56652 .40498 m .56774 .40882 L .56393 .40831 L F
.393 .186 .476 r
.56667 .40736 m .56401 .40828 L .56652 .40498 L F
.56401 .40828 m .56393 .40831 L .56411 .40808 L F
.56401 .40828 m .56411 .40808 L .56652 .40498 L F
.842 .707 .715 r
.5654 .39782 m .56626 .40364 L .56715 .39871 L F
.56626 .40364 m .5665 .40526 L .56676 .40259 L F
.56626 .40364 m .56676 .40259 L .56715 .39871 L F
.274 .657 .968 r
.56756 .398 m .56715 .39871 L .56538 .39768 L F
.335 0 .016 r
.23735 .55395 m .23987 .55367 L .24157 .5516 L F
.015 0 0 r
.24157 .5516 m .24199 .5527 L .24386 .55084 L F
.24157 .5516 m .23987 .55367 L .24199 .5527 L F
.445 .061 .216 r
.31307 .63203 m .31114 .63033 L .31038 .63244 L F
.31307 .63203 m .31324 .63046 L .31114 .63033 L F
.425 .865 .906 r
.27904 .52335 m .28351 .52264 L .28148 .52242 L F
.275 .497 .89 r
.37446 .56607 m .37453 .56815 L .36997 .5621 L F
.041 .088 .585 r
.19326 .58608 m .1936 .58961 L .19482 .5881 L F
.427 .271 .566 r
.1936 .58961 m .19599 .59169 L .19482 .5881 L F
.1936 .58961 m .19375 .59247 L .19599 .59169 L F
.822 .531 .498 r
.60803 .42781 m .61174 .42864 L .61184 .43107 L F
.784 .768 .259 r
.40957 .5782 m .40887 .58086 L .40876 .58242 L F
.861 .679 .148 r
.40887 .58086 m .40938 .58497 L .40876 .58242 L F
.40891 .58119 m .40889 .58359 L .40938 .58497 L F
.40887 .58086 m .40888 .58132 L .40891 .58119 L F
.40888 .58132 m .40889 .58359 L .40891 .58119 L F
.784 .768 .259 r
.40935 .57971 m .40876 .58242 L .40933 .57989 L F
.40957 .5782 m .40915 .5804 L .40935 .57971 L F
.40915 .5804 m .40876 .58242 L .40935 .57971 L F
.77 .957 .642 r
.72125 .29616 m .71958 .29815 L .72125 .29867 L F
.793 .386 0 r
.36241 .57666 m .36373 .5797 L .36241 .57786 L F
.854 .457 .289 r
.36597 .57997 m .36373 .5797 L .36241 .57666 L F
.793 .386 0 r
.36241 .57666 m .36241 .57786 L .36284 .5752 L F
.829 .609 .605 r
.35165 .64503 m .35291 .64394 L .34984 .64296 L F
0 0 0 r
.35214 .64518 m .35291 .64394 L .35165 .64503 L F
.79 .718 .784 r
.60789 .39583 m .60852 .39941 L .60521 .39923 L F
.684 .648 .807 r
.61142 .39705 m .60852 .39941 L .60789 .39583 L F
.877 .5 .324 r
.71168 .35939 m .70888 .35945 L .70799 .35835 L F
.71168 .35939 m .71183 .36118 L .70888 .35945 L F
.92 .893 .786 r
.33488 .69647 m .33094 .69901 L .33123 .69616 L F
.33488 .69647 m .33262 .69957 L .33094 .69901 L F
0 0 0 r
.20678 .5579 m .20804 .55674 L .20928 .55468 L F
.171 0 .35 r
.20568 .55996 m .20804 .55674 L .20678 .5579 L F
.796 .677 .733 r
.23386 .60075 m .23305 .60291 L .23235 .60137 L F
.23386 .60075 m .23524 .60343 L .23305 .60291 L F
.153 .265 .727 r
.35456 .62147 m .35571 .62604 L .35694 .62319 L F
0 .171 .709 r
.35571 .62604 m .3568 .62561 L .35694 .62319 L F
.35571 .62604 m .35655 .62694 L .3568 .62561 L F
.119 .482 .899 r
.37226 .61249 m .37061 .6106 L .36983 .61381 L F
.395 .184 .472 r
.30518 .6563 m .30389 .6556 L .30664 .65594 L F
.532 .798 .994 r
.33687 .67294 m .33355 .67387 L .33281 .67304 L F
.689 .393 .468 r
.32326 .62724 m .31967 .62875 L .32058 .62796 L F
.069 0 .293 r
.23356 .5475 m .23275 .55138 L .23227 .54943 L F
0 0 .275 r
.23227 .54943 m .23275 .55138 L .23222 .5513 L F
.45 .14 .347 r
.29997 .60801 m .29907 .61085 L .29662 .61118 L F
.256 0 .265 r
.30113 .60987 m .29997 .60801 L .30203 .60737 L F
.30113 .60987 m .29907 .61085 L .29997 .60801 L F
.745 .633 .736 r
.70236 .33334 m .70367 .33718 L .69942 .33642 L F
.549 .29 .475 r
.70367 .33718 m .70101 .33962 L .69942 .33642 L F
.70367 .33718 m .70381 .33936 L .70101 .33962 L F
.685 .601 .756 r
.70629 .33372 m .70367 .33718 L .70236 .33334 L F
.045 0 0 r
.3365 .57764 m .33704 .57828 L .33689 .57557 L F
.3365 .57764 m .33541 .57903 L .33704 .57828 L F
.924 .564 .326 r
.36543 .58216 m .36373 .5797 L .36597 .57997 L F
.585 .279 .417 r
.36851 .57982 m .36828 .58206 L .36597 .57997 L F
.742 .683 .794 r
.59773 .42442 m .59903 .42858 L .59696 .4292 L F
0 .095 .642 r
.60007 .42742 m .59903 .42858 L .59773 .42442 L F
0 0 0 r
.59841 .43112 m .59903 .42858 L .60007 .42742 L F
.237 .223 .64 r
.37331 .57559 m .3718 .57579 L .37121 .57344 L F
.728 .202 0 r
.36955 .57236 m .37331 .57559 L .37121 .57344 L F
.215 .528 .921 r
.30801 .65759 m .309 .65659 L .30664 .65594 L F
.30801 .65759 m .31004 .65823 L .309 .65659 L F
.532 .817 .471 r
.2437 .54138 m .24289 .54231 L .24509 .54204 L F
.543 .554 .816 r
.34618 .65834 m .34379 .65883 L .34257 .65504 L F
.734 .475 .538 r
.31917 .56637 m .32259 .56666 L .32312 .56418 L F
.97 .694 .453 r
.32393 .55962 m .32568 .56102 L .32312 .56418 L F
.966 .684 .264 r
.30084 .64973 m .30204 .65203 L .30178 .64945 L F
.711 .949 .658 r
.25901 .60197 m .25628 .60505 L .25751 .60308 L F
.35 .102 .39 r
.25901 .60197 m .25919 .60476 L .25628 .60505 L F
.393 .294 .623 r
.25919 .60476 m .25863 .60727 L .25628 .60505 L F
.194 .267 .711 r
.25628 .60505 m .25863 .60727 L .25751 .60308 L F
.181 0 0 r
.22533 .55598 m .22451 .55619 L .22196 .55581 L F
.564 0 0 r
.22533 .55598 m .22749 .55752 L .22451 .55619 L F
.865 .899 .856 r
.34321 .64826 m .34491 .64913 L .34084 .65288 L F
.62 .646 .854 r
.34581 .64514 m .34491 .64913 L .34321 .64826 L F
.34581 .64514 m .34734 .64896 L .34491 .64913 L F
.619 .767 .951 r
.27998 .53233 m .28128 .53003 L .27808 .53136 L F
0 0 .054 r
.24638 .6079 m .2447 .61036 L .24392 .60992 L F
0 0 .108 r
.2447 .61036 m .24344 .61161 L .24392 .60992 L F
0 0 0 r
.23466 .53569 m .2331 .5376 L .23582 .53489 L F
.543 .845 .529 r
.29875 .65534 m .30053 .65361 L .30204 .65203 L F
.642 .305 .385 r
.71575 .31995 m .71617 .31764 L .7125 .318 L F
.448 .104 .288 r
.71575 .31995 m .71896 .31731 L .71617 .31764 L F
.527 .546 .818 r
.38885 .6609 m .38782 .66483 L .38612 .66153 L F
.38885 .6609 m .3902 .66454 L .38782 .66483 L F
.695 .502 .622 r
.70605 .33106 m .70236 .33334 L .7023 .33066 L F
.70605 .33106 m .70629 .33372 L .70236 .33334 L F
.608 .437 .625 r
.70864 .33038 m .70629 .33372 L .70605 .33106 L F
0 0 0 r
.32645 .51946 m .32232 .52189 L .32358 .52044 L F
.627 .95 .76 r
.37145 .6289 m .37016 .63051 L .36861 .631 L F
.295 .129 .478 r
.30716 .59838 m .3072 .60131 L .30481 .60218 L F
.038 0 .303 r
.30612 .6034 m .30481 .60218 L .3072 .60131 L F
.30612 .6034 m .30408 .60453 L .30481 .60218 L F
.822 .886 .89 r
.3421 .533 m .33932 .53524 L .34083 .53472 L F
.716 .677 .811 r
.25113 .61465 m .25276 .61792 L .25541 .61685 L F
.19 .39 .83 r
.36675 .65953 m .36787 .658 L .36594 .65784 L F
.36675 .65953 m .36941 .66122 L .36787 .658 L F
.428 .615 .929 r
.64687 .39712 m .64546 .39897 L .64382 .39757 L F
.64687 .39712 m .64791 .39906 L .64546 .39897 L F
.898 .618 .505 r
.62188 .44443 m .61769 .44526 L .61776 .44269 L F
.62188 .44443 m .62104 .44654 L .61769 .44526 L F
.78 .47 .464 r
.62282 .44664 m .62104 .44654 L .62188 .44443 L F
.837 .871 .868 r
.3603 .54001 m .35798 .54227 L .35889 .54061 L F
.9 .535 .072 r
.40169 .55355 m .4034 .55684 L .40281 .55484 L F
0 .189 .71 r
.22428 .61077 m .22574 .61438 L .22631 .61281 L F
.123 .382 .838 r
.22574 .61438 m .22719 .61469 L .22631 .61281 L F
.831 .554 .007 r
.39769 .54152 m .39801 .54407 L .39854 .54472 L F
.638 .215 0 r
.39909 .54581 m .40007 .54728 L .39854 .54472 L F
.566 .196 .299 r
.3124 .63691 m .31614 .63621 L .31463 .63871 L F
.044 0 0 r
.31463 .63871 m .31614 .63621 L .31866 .63443 L F
.97 .694 .453 r
.32393 .55962 m .32377 .56275 L .32568 .56102 L F
.506 .834 .536 r
.32546 .56113 m .32568 .56102 L .32753 .55976 L F
.32546 .56113 m .32377 .56275 L .32568 .56102 L F
.23 0 0 r
.35622 .52015 m .35493 .52205 L .35283 .52222 L F
.697 .715 .863 r
.35827 .51859 m .35622 .52015 L .35519 .51732 L F
0 0 0 r
.35661 .52066 m .35622 .52015 L .35827 .51859 L F
.35661 .52066 m .35493 .52205 L .35622 .52015 L F
.448 0 .062 r
.72611 .35203 m .72604 .35368 L .72333 .35274 L F
.478 .187 .392 r
.72918 .35124 m .72604 .35368 L .72611 .35203 L F
.647 .586 .772 r
.38822 .65734 m .38612 .66153 L .38624 .65873 L F
0 .221 .743 r
.39208 .5299 m .3931 .53192 L .39085 .53026 L F
.224 0 .189 r
.20804 .55674 m .21094 .55345 L .20928 .55468 L F
.183 .066 .476 r
.42791 .5664 m .42789 .56968 L .42592 .5697 L F
.686 .973 .78 r
.62064 .41396 m .62243 .41326 L .62358 .41173 L F
0 0 0 r
.33435 .66157 m .33099 .66515 L .33345 .66421 L F
.679 .772 .29 r
.3358 .65793 m .33435 .66157 L .33602 .66094 L F
0 0 .05 r
.33602 .66094 m .33435 .66157 L .33345 .66421 L F
.44 .185 .429 r
.35359 .53867 m .35318 .54173 L .35018 .54241 L F
.498 .234 .445 r
.35595 .54094 m .35359 .53867 L .35588 .53809 L F
.35595 .54094 m .35318 .54173 L .35359 .53867 L F
.55 .771 .98 r
.60946 .43411 m .60691 .43474 L .6055 .43322 L F
.6055 .43322 m .60691 .43474 L .60946 .43411 L F
0 0 0 r
.29354 .61389 m .29047 .61668 L .29134 .61446 L F
.497 .432 .714 r
.38427 .64597 m .38194 .64785 L .38332 .64586 L F
.742 .683 .794 r
.59773 .42442 m .59696 .4292 L .59475 .42651 L F
.817 .726 .764 r
.40511 .52232 m .40643 .52601 L .40458 .52553 L F
.40504 .52239 m .40458 .52553 L .40233 .52494 L F
.40511 .52232 m .40458 .52553 L .40504 .52239 L F
.685 .659 .818 r
.40934 .52345 m .40643 .52601 L .40592 .52459 L F
.40881 .52331 m .40592 .52459 L .40511 .52232 L F
.40934 .52345 m .40592 .52459 L .40881 .52331 L F
.038 0 0 r
.40761 .52451 m .40985 .52377 L .41149 .52212 L F
.41115 .52228 m .41149 .52212 L .41166 .52195 L F
.40761 .52451 m .41166 .52195 L .40934 .52345 L F
.40761 .52451 m .41149 .52212 L .41115 .52228 L F
.647 .86 .48 r
.40643 .52601 m .40635 .52563 L .40233 .52494 L F
.40643 .52601 m .404 .52944 L .40635 .52563 L F
.903 .975 .804 r
.40447 .53137 m .40635 .52563 L .40402 .52941 L F
.40401 .52947 m .40402 .52941 L .404 .52944 L F
.40447 .53137 m .40402 .52941 L .40401 .52947 L F
0 .353 .749 r
.3603 .54001 m .36244 .54089 L .36418 .54201 L F
.991 .735 .425 r
.36244 .54089 m .36405 .54455 L .36418 .54201 L F
.437 .283 .573 r
.35 .59839 m .34957 .60172 L .34764 .60217 L F
.516 .362 .611 r
.34957 .60172 m .34765 .60475 L .34764 .60217 L F
.823 .93 .903 r
.27579 .62023 m .27663 .61715 L .27873 .61785 L F
.27579 .62023 m .27405 .61947 L .27663 .61715 L F
.244 .312 .735 r
.30198 .6266 m .29999 .6274 L .29922 .62353 L F
0 0 .297 r
.30074 .62765 m .29999 .6274 L .30198 .6266 L F
.30074 .62765 m .30032 .63001 L .29999 .6274 L F
.69 .684 .84 r
.30452 .56031 m .3065 .56424 L .3091 .56355 L F
.333 .374 .755 r
.30958 .56703 m .3065 .56424 L .3091 .56355 L F
.30958 .56703 m .3082 .56797 L .3065 .56424 L F
.66 .407 .526 r
.30593 .56663 m .3091 .56355 L .3065 .56424 L F
.818 .741 .779 r
.60521 .39923 m .60518 .40239 L .60279 .4023 L F
.996 .825 .558 r
.60518 .40239 m .60362 .40441 L .60279 .4023 L F
.60518 .40239 m .60477 .40596 L .60362 .40441 L F
.635 .783 .952 r
.3112 .56978 m .31144 .57195 L .31077 .57177 L F
.3112 .56978 m .31077 .57177 L .31096 .57029 L F
.3112 .56978 m .31449 .57121 L .31144 .57195 L F
.69 .271 .245 r
.31251 .57156 m .31449 .57121 L .3112 .56978 L F
.31251 .57156 m .31663 .57008 L .31449 .57121 L F
.31251 .57156 m .3142 .57263 L .31663 .57008 L F
.703 .52 .637 r
.3112 .56978 m .3103 .57164 L .30985 .56963 L F
.3112 .56978 m .3103 .57164 L .30985 .56963 L F
.933 .831 .721 r
.3112 .56978 m .3103 .57164 L .31094 .56975 L F
.322 .193 .544 r
.31101 .56983 m .31408 .57292 L .31251 .57156 L F
.724 .204 0 r
.31094 .56975 m .31251 .57156 L .3112 .56978 L F
.322 .193 .544 r
.31094 .56975 m .31101 .56982 L .31101 .56983 L F
.31101 .56982 m .31408 .57292 L .31101 .56983 L F
.635 .783 .952 r
.31096 .57029 m .31077 .57177 L .3103 .57164 L F
.538 .311 .518 r
.19028 .60777 m .19338 .60374 L .19051 .6045 L F
.978 .691 .405 r
.31028 .63602 m .3124 .63691 L .31227 .63744 L F
.556 .202 .323 r
.31227 .63744 m .3124 .63691 L .31463 .63871 L F
0 0 .151 r
.25928 .60429 m .25919 .60476 L .25901 .60197 L F
.769 .33 .207 r
.25751 .60308 m .25928 .60429 L .25901 .60197 L F
.336 0 .217 r
.38023 .70579 m .37916 .70843 L .37686 .709 L F
.323 0 .178 r
.38261 .70523 m .37916 .70843 L .38023 .70579 L F
0 0 .268 r
.40433 .55926 m .40487 .56083 L .4034 .55684 L F
.93 .585 .146 r
.40428 .56245 m .40487 .56083 L .40433 .55926 L F
.40428 .56245 m .40551 .56331 L .40487 .56083 L F
0 0 0 r
.28057 .53883 m .28167 .53743 L .2826 .53561 L F
.316 .365 .755 r
.28035 .54096 m .28167 .53743 L .28057 .53883 L F
.639 .426 .578 r
.69758 .34227 m .69468 .3402 L .69722 .33959 L F
.69758 .34227 m .69483 .34274 L .69468 .3402 L F
.697 .659 .809 r
.26933 .53293 m .27108 .53587 L .27403 .53558 L F
.519 .286 .502 r
.27403 .53558 m .27111 .53882 L .27108 .53587 L F
0 0 .163 r
.27108 .53587 m .27153 .53688 L .27403 .53558 L F
.27108 .53587 m .27111 .53882 L .27153 .53688 L F
.112 .138 .609 r
.3951 .62336 m .39689 .62561 L .39545 .62638 L F
0 0 0 r
.39689 .62561 m .39414 .62871 L .39545 .62638 L F
.568 .361 .56 r
.6344 .44087 m .63479 .44365 L .63164 .44398 L F
.446 .226 .485 r
.6344 .44087 m .63686 .43789 L .63713 .4404 L F
.402 .247 .553 r
.63706 .4428 m .6344 .44087 L .63713 .4404 L F
.63706 .4428 m .63479 .44365 L .6344 .44087 L F
.742 .536 .615 r
.70236 .33334 m .69811 .33023 L .7023 .33066 L F
.898 .803 .746 r
.69553 .31952 m .69702 .32121 L .69506 .32439 L F
.836 .794 .811 r
.69801 .31634 m .69702 .32121 L .69553 .31952 L F
.69801 .31634 m .69957 .318 L .69702 .32121 L F
.789 .92 .925 r
.63846 .3996 m .63523 .40022 L .63734 .39868 L F
.702 .914 .968 r
.64088 .39828 m .63846 .3996 L .63734 .39868 L F
.552 .591 .847 r
.34075 .56284 m .34003 .56698 L .33945 .56481 L F
.34075 .56284 m .34271 .56654 L .34003 .56698 L F
.464 .202 .431 r
.24762 .55118 m .24719 .55389 L .24477 .55443 L F
.285 .052 .374 r
.24888 .55301 m .24762 .55118 L .24868 .54982 L F
.24888 .55301 m .24719 .55389 L .24762 .55118 L F
.189 0 0 r
.19743 .56643 m .19958 .5658 L .20121 .56352 L F
0 0 0 r
.20121 .56352 m .20117 .56475 L .20267 .56345 L F
.20121 .56352 m .19958 .5658 L .20117 .56475 L F
.434 .138 .361 r
.22426 .55653 m .21876 .55796 L .22196 .55581 L F
0 0 .274 r
.2198 .55844 m .21876 .55796 L .22426 .55653 L F
.2198 .55844 m .21888 .56079 L .21876 .55796 L F
.409 .194 .473 r
.28425 .61157 m .28652 .61096 L .28698 .60821 L F
.311 .084 .399 r
.28425 .61157 m .28577 .61326 L .28652 .61096 L F
.28425 .61157 m .28369 .61416 L .28577 .61326 L F
.98 .691 .388 r
.38136 .56101 m .37992 .55763 L .38234 .55765 L F
.38136 .56101 m .37979 .5599 L .37992 .55763 L F
.991 .757 .479 r
.38136 .56101 m .37945 .56235 L .38192 .55899 L F
.38136 .56101 m .38013 .56336 L .37945 .56235 L F
.797 .435 .37 r
.38503 .56384 m .38013 .56336 L .38136 .56101 L F
.65 .675 .86 r
.35519 .51732 m .35063 .51923 L .35026 .51559 L F
.477 .138 .313 r
.39287 .59111 m .3907 .58949 L .39029 .59138 L F
.531 .105 .177 r
.39287 .59111 m .39428 .58922 L .3907 .58949 L F
.785 .973 .914 r
.38321 .54693 m .38287 .54872 L .385 .54732 L F
.561 .042 0 r
.38785 .54699 m .38321 .54693 L .385 .54732 L F
.489 .209 .415 r
.63686 .43789 m .6397 .43966 L .63713 .4404 L F
.63686 .43789 m .63982 .43752 L .6397 .43966 L F
.653 .221 .209 r
.35461 .71223 m .35866 .71232 L .35687 .71434 L F
.723 .309 .261 r
.35866 .71232 m .36102 .71482 L .35687 .71434 L F
.542 .334 .548 r
.3612 .71194 m .36102 .71482 L .35866 .71232 L F
.581 .775 .971 r
.39699 .58904 m .40043 .58986 L .40028 .58838 L F
0 .27 .688 r
.40043 .58986 m .40181 .5904 L .40028 .58838 L F
.40043 .58986 m .40366 .59163 L .40181 .5904 L F
.371 .42 .782 r
.40043 .58986 m .40207 .59279 L .40366 .59163 L F
.453 .732 .987 r
.34996 .50298 m .34934 .50483 L .34772 .50329 L F
.34996 .50298 m .35164 .50453 L .34934 .50483 L F
.634 .408 .557 r
.33039 .57022 m .33334 .56991 L .33352 .56725 L F
.174 .032 .435 r
.33352 .56725 m .33494 .56911 L .33535 .56605 L F
.33352 .56725 m .33334 .56991 L .33494 .56911 L F
.595 .926 .964 r
.25308 .52678 m .25223 .52833 L .25098 .52808 L F
.25308 .52678 m .25529 .5271 L .25223 .52833 L F
.71 .207 .038 r
.33939 .55631 m .34339 .55772 L .34164 .55608 L F
.483 .183 .38 r
.34474 .56065 m .34709 .56252 L .34455 .56284 L F
.729 .665 .787 r
.34623 .55731 m .34474 .56065 L .34493 .55743 L F
.756 .597 .68 r
.7239 .30311 m .72454 .30184 L .7253 .29925 L F
.35 .217 .554 r
.19569 .5697 m .19743 .56643 L .19565 .56699 L F
.455 .307 .591 r
.2368 .5632 m .23706 .56671 L .23508 .56724 L F
.466 .288 .555 r
.23702 .56924 m .23508 .56724 L .23706 .56671 L F
.23702 .56924 m .235 .5698 L .23508 .56724 L F
.832 .999 .793 r
.35845 .55885 m .35656 .55997 L .35674 .56066 L F
.673 .438 .558 r
.36036 .55723 m .35656 .55997 L .35845 .55885 L F
.187 .653 .938 r
.26772 .63579 m .26984 .63684 L .27166 .63687 L F
.132 0 0 r
.13825 .70504 m .14073 .70521 L .14242 .70544 L F
.14242 .70544 m .14073 .70521 L .13825 .70504 L F
.586 .349 .524 r
.38006 .5831 m .38001 .58548 L .37638 .58588 L F
.606 .366 .526 r
.38238 .58519 m .38006 .5831 L .383 .58273 L F
.38238 .58519 m .38001 .58548 L .38006 .5831 L F
.821 .367 .149 r
.3643 .66404 m .36072 .6616 L .36283 .66403 L F
.469 .893 .856 r
.36521 .66306 m .3643 .66404 L .36283 .66403 L F
.36521 .66306 m .36738 .66266 L .3643 .66404 L F
.893 .84 .785 r
.34269 .57954 m .34088 .5834 L .33885 .58253 L F
.935 .779 .664 r
.34088 .5834 m .34014 .58674 L .33885 .58253 L F
.092 0 0 r
.34033 .63599 m .34472 .63354 L .34292 .63525 L F
.974 .714 .476 r
.34292 .63525 m .34472 .63354 L .34317 .6318 L F
.447 .298 .585 r
.24477 .55443 m .24486 .55722 L .2427 .5578 L F
.517 .365 .614 r
.24486 .55722 m .24265 .5604 L .2427 .5578 L F
.765 .852 .916 r
.38491 .65442 m .38273 .65607 L .38339 .65305 L F
.909 .976 .79 r
.38339 .65305 m .38273 .65607 L .38167 .65559 L F
.722 .47 .545 r
.59287 .43165 m .59331 .4339 L .59032 .43135 L F
.591 .125 .117 r
.59287 .43165 m .59645 .43321 L .59331 .4339 L F
.114 0 0 r
.3446 .5842 m .34263 .58591 L .34014 .58674 L F
.15 0 0 r
.34571 .58493 m .34263 .58591 L .3446 .5842 L F
.786 .46 .437 r
.34072 .70291 m .3385 .70507 L .33693 .70224 L F
.757 .418 .41 r
.34072 .70291 m .3427 .70555 L .3385 .70507 L F
.682 .966 .75 r
.34427 .60416 m .34274 .60578 L .34061 .60731 L F
.811 .519 .494 r
.70889 .3196 m .7125 .318 L .71014 .31673 L F
.70889 .3196 m .7127 .3204 L .7125 .318 L F
.642 .305 .385 r
.71575 .31995 m .7125 .318 L .7127 .3204 L F
.596 .535 .757 r
.39209 .61628 m .39379 .62178 L .39354 .62182 L F
.39126 .62157 m .39354 .62182 L .39116 .62222 L F
.39209 .61628 m .39354 .62182 L .39126 .62157 L F
.553 .497 .747 r
.39421 .61604 m .39379 .62178 L .39209 .61628 L F
.39421 .61604 m .39682 .6213 L .39379 .62178 L F
.145 .206 .668 r
.3966 .6216 m .39617 .6221 L .3937 .62173 L F
.39617 .6221 m .3951 .62336 L .3938 .62185 L F
.39617 .6221 m .3938 .62185 L .3937 .62173 L F
.3966 .6216 m .39597 .62337 L .3951 .62336 L F
.147 .148 .601 r
.39597 .62337 m .39689 .62561 L .3951 .62336 L F
.461 .477 .789 r
.36002 .6202 m .35849 .62193 L .35795 .62056 L F
.36002 .6202 m .36131 .62304 L .35849 .62193 L F
.792 .947 .605 r
.38766 .63919 m .38585 .6427 L .38859 .63964 L F
.38766 .63919 m .38546 .64255 L .38585 .6427 L F
.638 .478 .65 r
.31663 .57008 m .31917 .56637 L .31753 .56742 L F
.829 .991 .736 r
.3779 .60508 m .37522 .6084 L .37728 .60528 L F
.362 0 0 r
.3794 .60607 m .3779 .60508 L .37728 .60528 L F
.3794 .60607 m .38055 .60586 L .3779 .60508 L F
.842 .84 .843 r
.4024 .59617 m .40366 .59163 L .40207 .59279 L F
.632 .859 .985 r
.33379 .54959 m .33357 .55165 L .3356 .55047 L F
0 0 .346 r
.35834 .61078 m .35843 .61144 L .35644 .61192 L F
.842 .794 .805 r
.70207 .31478 m .69957 .318 L .69801 .31634 L F
.84 .796 .808 r
.70207 .31478 m .69908 .31445 L .70143 .31134 L F
.842 .794 .805 r
.70207 .31478 m .69801 .31634 L .69908 .31445 L F
.832 .791 .813 r
.70466 .31159 m .70207 .31478 L .70143 .31134 L F
.498 .039 .092 r
.3152 .65431 m .31291 .65324 L .31099 .65485 L F
.434 .492 .82 r
.35222 .63739 m .3556 .63887 L .35459 .63604 L F
.77 .669 .751 r
.69811 .33023 m .69632 .33081 L .69865 .32764 L F
.755 .539 .604 r
.69811 .33023 m .69624 .33337 L .69632 .33081 L F
.69811 .33023 m .70049 .33396 L .69624 .33337 L F
.742 .536 .615 r
.70236 .33334 m .70049 .33396 L .69811 .33023 L F
.683 .501 .634 r
.30958 .56703 m .30593 .56663 L .3082 .56797 L F
0 0 .213 r
.38363 .54964 m .38287 .54872 L .38321 .54693 L F
.38363 .54964 m .38228 .55122 L .38287 .54872 L F
.031 0 .042 r
.30685 .57987 m .30395 .58292 L .30568 .58197 L F
0 0 0 r
.3086 .57631 m .30685 .57987 L .30789 .57843 L F
0 0 .185 r
.30568 .58197 m .30789 .57843 L .30685 .57987 L F
.408 .303 .622 r
.37728 .60528 m .37522 .6084 L .37748 .60827 L F
.256 .07 .426 r
.32781 .59185 m .32926 .58836 L .32813 .58923 L F
.069 .095 .58 r
.19424 .58546 m .19326 .58608 L .19482 .5881 L F
.745 .683 .791 r
.36545 .55642 m .37098 .55802 L .36897 .55297 L F
.512 .185 .349 r
.36768 .5603 m .37098 .55802 L .36545 .55642 L F
.36768 .5603 m .37041 .56009 L .37098 .55802 L F
.534 .568 .835 r
.36897 .55297 m .37098 .55802 L .37292 .5571 L F
.536 .206 .357 r
.37098 .55802 m .37041 .56009 L .37304 .55972 L F
.37098 .55802 m .37304 .55972 L .37292 .5571 L F
.37098 .55802 m .37041 .56009 L .37304 .55972 L F
.644 .632 .823 r
.31226 .64187 m .31127 .64607 L .31042 .64429 L F
.31226 .64187 m .31447 .64563 L .31127 .64607 L F
.827 .691 .713 r
.31447 .64563 m .3121 .64817 L .31127 .64607 L F
.697 .659 .809 r
.26933 .53293 m .27403 .53558 L .27216 .53288 L F
.519 .286 .502 r
.27403 .53558 m .27362 .53855 L .27111 .53882 L F
.542 .695 .939 r
.27216 .53288 m .27403 .53558 L .27655 .53464 L F
.512 .338 .581 r
.27655 .53464 m .27362 .53855 L .27403 .53558 L F
0 0 0 r
.27403 .53558 m .27383 .53608 L .27655 .53464 L F
.27403 .53558 m .27153 .53688 L .27383 .53608 L F
0 .363 .76 r
.20533 .59959 m .20643 .59974 L .20432 .59797 L F
.20533 .59959 m .20843 .60101 L .20643 .59974 L F
.724 .948 .952 r
.71792 .30964 m .71955 .30717 L .71624 .30949 L F
.71792 .30964 m .72023 .30815 L .71955 .30717 L F
.837 .871 .868 r
.3603 .54001 m .35889 .54061 L .35854 .53782 L F
.216 .35 .785 r
.361 .53719 m .3603 .54001 L .35854 .53782 L F
.361 .53719 m .36244 .54089 L .3603 .54001 L F
.53 .493 .759 r
.31894 .51677 m .32156 .51936 L .32269 .51723 L F
.227 0 .138 r
.32269 .51723 m .32368 .51852 L .32477 .51606 L F
.32269 .51723 m .32156 .51936 L .32368 .51852 L F
0 0 0 r
.33729 .53954 m .33713 .53838 L .33935 .53812 L F
.33729 .53954 m .33539 .54042 L .33713 .53838 L F
.439 .258 .537 r
.33932 .53524 m .33935 .53812 L .33713 .53838 L F
0 .018 .571 r
.60753 .41705 m .60681 .41886 L .6078 .4207 L F
.716 .677 .811 r
.25113 .61465 m .25541 .61685 L .25353 .6138 L F
.787 .768 .836 r
.25353 .6138 m .25541 .61685 L .25735 .614 L F
.678 .55 .702 r
.72083 .35563 m .71695 .35252 L .71973 .35219 L F
.72083 .35563 m .71787 .35649 L .71695 .35252 L F
.326 .008 .264 r
.3212 .62037 m .31912 .62117 L .31829 .62341 L F
.957 .661 .432 r
.32223 .52472 m .32392 .52587 L .3238 .52304 L F
.639 .839 .977 r
.33057 .57304 m .33482 .57351 L .33278 .57406 L F
0 .12 .671 r
.33482 .57351 m .33521 .57205 L .33278 .57406 L F
.33482 .57351 m .33689 .57557 L .33521 .57205 L F
.79 .527 .54 r
.37725 .55774 m .37304 .55972 L .37292 .5571 L F
.37725 .55774 m .37723 .5608 L .37304 .55972 L F
.587 .443 .653 r
.32368 .53895 m .32649 .53865 L .32633 .5357 L F
.578 .399 .604 r
.32368 .53895 m .32416 .54209 L .32649 .53865 L F
.32368 .53895 m .32416 .54209 L .32649 .53865 L F
.319 .367 .755 r
.22702 .59738 m .22529 .5988 L .22416 .59474 L F
.253 .253 .666 r
.22702 .59738 m .22737 .6009 L .22529 .5988 L F
.37 .822 .936 r
.3013 .51861 m .30737 .51853 L .30279 .51944 L F
.3013 .51861 m .30379 .51806 L .30737 .51853 L F
.804 .946 .916 r
.30737 .51853 m .30528 .51586 L .30804 .51672 L F
.30737 .51853 m .30379 .51806 L .30528 .51586 L F
.743 .621 .723 r
.70864 .33038 m .70967 .33401 L .70629 .33372 L F
.653 .624 .809 r
.70823 .33534 m .70629 .33372 L .70967 .33401 L F
.365 .383 .746 r
.71162 .33223 m .70967 .33401 L .70864 .33038 L F
.068 0 .202 r
.71162 .33223 m .70823 .33534 L .70967 .33401 L F
.718 .599 .723 r
.40233 .59859 m .40346 .60197 L .39981 .6017 L F
.724 .524 .619 r
.40376 .60473 m .39981 .6017 L .40346 .60197 L F
.605 .535 .75 r
.40588 .60142 m .40346 .60197 L .40233 .59859 L F
0 0 0 r
.40588 .60142 m .40376 .60473 L .40346 .60197 L F
.38 .569 .911 r
.28084 .62835 m .27774 .62698 L .27953 .62917 L F
.543 .241 .405 r
.27843 .62783 m .28076 .62803 L .27953 .62917 L F
.792 .993 .762 r
.28146 .62738 m .28191 .62667 L .28206 .62729 L F
.419 .32 .636 r
.28228 .62608 m .28129 .62807 L .28113 .62761 L F
.28228 .62608 m .28113 .62761 L .27971 .62363 L F
.792 .993 .762 r
.28084 .62835 m .28033 .62867 L .28146 .62738 L F
.28033 .62867 m .28016 .62877 L .28062 .62828 L F
.28033 .62867 m .28062 .62828 L .28146 .62738 L F
.28016 .62877 m .27953 .62917 L .28086 .62794 L F
.28016 .62877 m .28086 .62794 L .28146 .62738 L F
.504 .368 .629 r
.28095 .62711 m .28113 .62761 L .27983 .62762 L F
.28113 .62761 m .28129 .62807 L .28086 .62794 L F
.28113 .62761 m .28086 .62794 L .27983 .62762 L F
.543 .241 .405 r
.27983 .62762 m .28129 .62807 L .27843 .62783 L F
.792 .993 .762 r
.28146 .62738 m .27953 .62917 L .28228 .62608 L F
.543 .241 .405 r
.28076 .62803 m .28129 .62807 L .27953 .62917 L F
.27774 .62698 m .27983 .62762 L .27843 .62783 L F
.792 .993 .762 r
.28084 .62835 m .28146 .62738 L .28219 .62785 L F
.28146 .62738 m .28206 .62729 L .28219 .62785 L F
.28191 .62667 m .28228 .62608 L .28226 .62651 L F
.28191 .62667 m .28226 .62651 L .28219 .62785 L F
.504 .368 .629 r
.27971 .62363 m .28095 .62711 L .27774 .62698 L F
.28095 .62711 m .27983 .62762 L .27774 .62698 L F
.714 .474 .561 r
.59032 .43135 m .59331 .4339 L .59014 .43425 L F
.066 .109 .597 r
.33464 .55768 m .33515 .56125 L .33632 .56009 L F
.167 .125 .563 r
.33515 .56125 m .33698 .56118 L .33753 .56205 L F
.296 .294 .687 r
.33699 .56124 m .33753 .56205 L .33698 .56118 L F
.167 .125 .563 r
.33515 .56125 m .33753 .56205 L .33702 .56128 L F
.296 .294 .687 r
.33733 .56476 m .33753 .56205 L .33699 .56124 L F
.167 .125 .563 r
.33702 .56128 m .33753 .56205 L .33705 .56128 L F
.33696 .56122 m .33705 .56128 L .33702 .56122 L F
.33515 .56125 m .33705 .56128 L .33696 .56122 L F
.388 .219 .527 r
.33552 .56365 m .33733 .56476 L .33699 .56124 L F
.33696 .56122 m .33699 .56124 L .33698 .56118 L F
.33552 .56365 m .33699 .56124 L .33696 .56122 L F
.167 .125 .563 r
.33515 .56125 m .33552 .56365 L .33696 .56122 L F
.33515 .56125 m .33696 .56122 L .33698 .56118 L F
.33515 .56125 m .33702 .56122 L .33632 .56009 L F
.869 .984 .84 r
.5753 .40322 m .5745 .40264 L .57478 .40298 L F
.785 .284 0 r
.57545 .40478 m .5753 .40322 L .57478 .40298 L F
.57545 .40478 m .57677 .405 L .5753 .40322 L F
.547 .441 .685 r
.35398 .63342 m .35667 .62971 L .35363 .6301 L F
.35398 .63342 m .35668 .6333 L .35667 .62971 L F
.723 .576 .689 r
.35459 .63604 m .35668 .6333 L .35398 .63342 L F
.591 .58 .809 r
.33294 .63979 m .33548 .63926 L .33408 .63585 L F
.513 .278 .496 r
.33499 .64162 m .33294 .63979 L .33274 .64278 L F
.33499 .64162 m .33548 .63926 L .33294 .63979 L F
.969 .655 .278 r
.64827 .41966 m .64951 .41889 L .64889 .41875 L F
.64827 .41966 m .64988 .42139 L .64951 .41889 L F
0 .059 .541 r
.25051 .62022 m .25062 .62034 L .24859 .6199 L F
.25051 .62022 m .25253 .62202 L .25062 .62034 L F
.747 .547 .624 r
.3693 .53546 m .36553 .536 L .36527 .53249 L F
.392 .21 .511 r
.33464 .55768 m .33632 .56009 L .33682 .55687 L F
.346 .316 .682 r
.22451 .55619 m .22426 .55653 L .22196 .55581 L F
0 .018 .587 r
.32285 .6159 m .32344 .61989 L .32389 .61704 L F
.632 .963 .873 r
.32344 .61989 m .32759 .61741 L .32389 .61704 L F
0 0 0 r
.35632 .56271 m .35674 .56066 L .35656 .55997 L F
.35632 .56271 m .3556 .56437 L .35674 .56066 L F
.872 .993 .804 r
.38837 .63759 m .38859 .63964 L .39055 .63621 L F
.38837 .63759 m .38766 .63919 L .38859 .63964 L F
.83 .443 0 r
.23833 .62388 m .23716 .62247 L .23507 .62079 L F
0 .185 .702 r
.23507 .62079 m .23716 .62247 L .23635 .62117 L F
.933 .639 .17 r
.23716 .62247 m .23757 .6252 L .2365 .62168 L F
.23716 .62247 m .2365 .62168 L .23635 .62117 L F
.83 .443 0 r
.23852 .62406 m .23716 .62247 L .23833 .62388 L F
.348 0 .065 r
.37048 .71148 m .37447 .70972 L .37294 .71175 L F
.291 0 .118 r
.37447 .70972 m .37577 .7108 L .37294 .71175 L F
.37447 .70972 m .37686 .709 L .37577 .7108 L F
.044 .006 .484 r
.32304 .66449 m .32167 .66507 L .32211 .66646 L F
.832 .791 .813 r
.70466 .31159 m .70143 .31134 L .7033 .30971 L F
.884 .911 .84 r
.7061 .30696 m .70466 .31159 L .7033 .30971 L F
.7061 .30696 m .70722 .30834 L .70466 .31159 L F
.163 0 .247 r
.58204 .41492 m .58007 .41622 L .5795 .41813 L F
.5795 .41813 m .58007 .41622 L .58204 .41492 L F
.469 .13 .307 r
.27224 .54771 m .27502 .54729 L .27573 .54472 L F
.076 0 .159 r
.27573 .54472 m .27675 .54619 L .27769 .54413 L F
.27573 .54472 m .27502 .54729 L .27675 .54619 L F
.693 .365 .416 r
.29278 .54587 m .29548 .54765 L .29622 .54632 L F
.369 .244 .576 r
.23926 .56542 m .2368 .5632 L .23907 .56325 L F
.23926 .56542 m .23706 .56671 L .2368 .5632 L F
.408 .194 .474 r
.63479 .44365 m .63221 .44659 L .63164 .44398 L F
.463 .332 .617 r
.31542 .57928 m .31316 .582 L .31334 .5801 L F
.315 .784 .934 r
.72459 .34278 m .7281 .34244 L .72784 .34278 L F
.567 .814 .435 r
.72784 .34278 m .7281 .34244 L .7286 .34177 L F
0 0 0 r
.63892 .40518 m .64266 .40336 L .64157 .40245 L F
.667 .955 .948 r
.64397 .40142 m .64266 .40336 L .64519 .40188 L F
.619 .896 .987 r
.64157 .40245 m .64266 .40336 L .64397 .40142 L F
.675 .926 .622 r
.33688 .54575 m .33625 .5459 L .33827 .54498 L F
.389 .051 .266 r
.235 .5698 m .23142 .57292 L .23243 .57021 L F
.344 0 .203 r
.29548 .54765 m .29869 .54557 L .29622 .54632 L F
.146 0 .37 r
.28698 .60821 m .28802 .60992 L .28824 .60732 L F
.28698 .60821 m .28652 .61096 L .28802 .60992 L F
.696 .618 .766 r
.34225 .57631 m .34269 .57954 L .33926 .57951 L F
.893 .84 .785 r
.34269 .57954 m .33885 .58253 L .33926 .57951 L F
0 0 .134 r
.32442 .59898 m .3237 .60103 L .32581 .5979 L F
.827 .691 .713 r
.31447 .64563 m .31527 .64922 L .3121 .64817 L F
.506 0 0 r
.3121 .64817 m .31527 .64922 L .31421 .64924 L F
0 0 0 r
.31612 .64731 m .31552 .64754 L .31719 .64672 L F
0 0 .447 r
.31552 .64754 m .31527 .64922 L .31495 .64775 L F
.31552 .64754 m .31495 .64775 L .31447 .64563 L F
.707 .352 0 r
.31042 .64429 m .3121 .64817 L .31119 .64745 L F
.353 0 0 r
.3121 .64817 m .31421 .64924 L .31156 .64802 L F
.808 .883 .9 r
.31156 .64802 m .31421 .64924 L .31552 .64754 L F
0 0 0 r
.31419 .64837 m .31552 .64754 L .31612 .64731 L F
.816 1 .803 r
.31421 .64924 m .31527 .64922 L .31552 .64754 L F
.127 .407 .856 r
.35898 .50544 m .36036 .50595 L .35968 .50733 L F
.288 .611 .955 r
.36036 .50595 m .36189 .50755 L .35968 .50733 L F
.567 .819 .993 r
.28764 .52315 m .28351 .52264 L .28588 .52202 L F
.614 .882 .99 r
.28998 .52213 m .28764 .52315 L .28823 .52131 L F
.558 .828 .996 r
.28823 .52131 m .28764 .52315 L .28588 .52202 L F
.769 .974 .697 r
.27873 .61785 m .27888 .61658 L .28131 .6149 L F
.435 0 0 r
.28131 .6149 m .27888 .61658 L .28303 .61596 L F
.343 0 .226 r
.28131 .6149 m .28303 .61596 L .28369 .61416 L F
.616 .794 .967 r
.23966 .60466 m .23524 .60343 L .23762 .6037 L F
.607 .705 .914 r
.239 .60101 m .23966 .60466 L .23762 .6037 L F
.239 .60101 m .24207 .60397 L .23966 .60466 L F
.751 .753 .854 r
.62606 .40092 m .62218 .40032 L .62452 .39902 L F
.736 .778 .887 r
.62452 .39902 m .6284 .39954 L .62606 .40092 L F
.796 .481 .456 r
.33862 .65412 m .34257 .65504 L .34084 .65288 L F
0 0 .52 r
.34254 .65196 m .34183 .65159 L .3433 .65356 L F
.865 .899 .856 r
.34321 .64826 m .34158 .65145 L .34183 .65159 L F
.895 .934 .56 r
.34321 .64826 m .34183 .65159 L .34165 .65011 L F
0 0 .52 r
.34165 .65011 m .34183 .65159 L .34254 .65196 L F
.865 .899 .856 r
.34158 .65145 m .34084 .65288 L .34183 .65159 L F
0 .232 .745 r
.34084 .65288 m .3433 .65356 L .34183 .65159 L F
.34084 .65288 m .34257 .65504 L .3433 .65356 L F
.068 0 .202 r
.71162 .33223 m .70944 .33564 L .70823 .33534 L F
.274 0 .292 r
.36023 .57314 m .3602 .57517 L .3579 .57604 L F
.75 .732 .835 r
.3587 .57002 m .36023 .57314 L .36281 .57005 L F
.051 .307 .794 r
.3587 .57002 m .36131 .57165 L .36023 .57314 L F
.588 .616 .847 r
.36131 .57165 m .3602 .57517 L .36023 .57314 L F
0 0 .461 r
.41411 .52159 m .41355 .52568 L .41166 .52195 L F
.41411 .52163 m .41443 .52365 L .41355 .52568 L F
.41443 .52365 m .41459 .52463 L .41447 .52475 L F
.41443 .52365 m .41447 .52475 L .41355 .52568 L F
.41412 .52164 m .41459 .52463 L .41411 .52163 L F
.269 .201 .593 r
.41633 .52353 m .41459 .52463 L .41411 .52159 L F
.239 0 0 r
.41166 .52195 m .40985 .52377 L .41437 .5218 L F
.41166 .52195 m .41437 .5218 L .41422 .52171 L F
0 0 .461 r
.41411 .52159 m .41412 .52164 L .41411 .52163 L F
.239 0 0 r
.41166 .52195 m .41433 .5217 L .41411 .52159 L F
.41433 .5217 m .4147 .52166 L .41411 .52159 L F
.013 .181 .693 r
.41515 .51981 m .41411 .52159 L .4147 .52166 L F
.41432 .52124 m .41444 .52159 L .41411 .52159 L F
.816 .685 .72 r
.41446 .52154 m .40841 .51998 L .41115 .51984 L F
.4147 .52166 m .41444 .52159 L .41446 .52154 L F
.41444 .52159 m .40841 .51998 L .41446 .52154 L F
.013 .181 .693 r
.41444 .52159 m .4145 .52175 L .41441 .52171 L F
.41444 .52159 m .41441 .52171 L .41411 .52159 L F
.4145 .52175 m .41451 .52179 L .41433 .5217 L F
.4145 .52175 m .41433 .5217 L .41411 .52159 L F
.41602 .52255 m .41633 .52353 L .41411 .52159 L F
.239 0 0 r
.41422 .52171 m .41437 .5218 L .4145 .52175 L F
.41433 .5217 m .4145 .52175 L .4147 .52166 L F
.41422 .52171 m .4145 .52175 L .41433 .5217 L F
.816 .685 .72 r
.41444 .52159 m .41437 .5218 L .41436 .52157 L F
.4147 .52166 m .4145 .52175 L .41444 .52159 L F
.4145 .52175 m .41437 .5218 L .41444 .52159 L F
.523 .787 .993 r
.41515 .51981 m .4147 .52166 L .41446 .52154 L F
.013 .181 .693 r
.41515 .51981 m .41444 .52158 L .41432 .52124 L F
.523 .787 .993 r
.41515 .51981 m .41446 .52154 L .41115 .51984 L F
.013 .181 .693 r
.41515 .51981 m .41451 .52179 L .41444 .52158 L F
.41515 .51981 m .41602 .52255 L .41451 .52179 L F
.816 .685 .72 r
.41436 .52157 m .40985 .52377 L .40841 .51998 L F
.41437 .5218 m .40985 .52377 L .41436 .52157 L F
.385 .847 .864 r
.41401 .52679 m .41355 .52568 L .41459 .52463 L F
.41401 .52679 m .41144 .52796 L .41355 .52568 L F
.877 .832 .799 r
.39287 .59111 m .39699 .58904 L .39428 .58922 L F
.659 .636 .816 r
.35472 .54395 m .35018 .54241 L .35318 .54173 L F
0 0 .438 r
.35595 .54094 m .35472 .54395 L .35318 .54173 L F
.35595 .54094 m .35594 .5436 L .35472 .54395 L F
0 0 0 r
.30304 .58499 m .30568 .58197 L .30395 .58292 L F
.719 .599 .721 r
.40482 .59502 m .40482 .5987 L .40233 .59859 L F
.605 .535 .75 r
.40588 .60142 m .40233 .59859 L .40482 .5987 L F
.326 .181 .526 r
.40783 .59464 m .40482 .5987 L .40482 .59502 L F
.40783 .59464 m .40781 .59758 L .40482 .5987 L F
.024 .124 .632 r
.4071 .59998 m .40482 .5987 L .40781 .59758 L F
.4071 .59998 m .40588 .60142 L .40482 .5987 L F
.454 .119 .308 r
.63771 .43102 m .64095 .43067 L .64106 .4279 L F
.437 .247 .523 r
.64095 .43067 m .64327 .42664 L .64106 .4279 L F
.123 0 0 r
.71695 .35733 m .71787 .35649 L .72083 .35563 L F
.036 .02 .507 r
.73173 .34306 m .73214 .34539 L .73137 .34599 L F
0 0 .318 r
.73214 .34539 m .7319 .34815 L .73137 .34599 L F
.151 .691 .822 r
.28998 .52213 m .29233 .52195 L .29388 .52208 L F
.638 .953 .939 r
.29388 .52208 m .29447 .52055 L .29674 .52057 L F
.29388 .52208 m .29233 .52195 L .29447 .52055 L F
.535 .362 .593 r
.39981 .6017 m .39958 .60522 L .39758 .60561 L F
.724 .524 .619 r
.40376 .60473 m .39958 .60522 L .39981 .6017 L F
.951 .955 .69 r
.328 .68028 m .32588 .68174 L .32694 .6798 L F
.328 .68028 m .32626 .68409 L .32588 .68174 L F
.649 .928 .651 r
.3289 .67881 m .328 .68028 L .32694 .6798 L F
.3289 .67881 m .33092 .67734 L .328 .68028 L F
.09 .504 .902 r
.22213 .56523 m .22061 .56302 L .22439 .56488 L F
.582 .803 .984 r
.22401 .56189 m .22439 .56488 L .22269 .5631 L F
.925 .974 .741 r
.22401 .56189 m .22213 .56523 L .22439 .56488 L F
.69 .684 .84 r
.30452 .56031 m .3091 .56355 L .30711 .5597 L F
.165 0 .24 r
.3114 .56355 m .30958 .56703 L .3091 .56355 L F
.31223 .56355 m .31107 .56507 L .3114 .56355 L F
.31107 .56507 m .30958 .56703 L .3114 .56355 L F
.538 .33 .546 r
.31213 .56086 m .31223 .56355 L .3114 .56355 L F
0 0 0 r
.31189 .56112 m .31162 .56246 L .3119 .56112 L F
.538 .33 .546 r
.31162 .56246 m .3114 .56355 L .3091 .56355 L F
.522 .298 .516 r
.3091 .56355 m .3113 .56407 L .31162 .56246 L F
.3091 .56355 m .31162 .56246 L .31189 .56112 L F
.538 .33 .546 r
.31192 .56105 m .31162 .56246 L .3091 .56355 L F
.31213 .56086 m .3114 .56355 L .31192 .56105 L F
0 0 0 r
.3119 .56112 m .31156 .56276 L .31191 .56112 L F
.31162 .56246 m .31156 .56276 L .3119 .56112 L F
.615 .389 .551 r
.31461 .56298 m .31213 .56086 L .31436 .56051 L F
.31461 .56298 m .31223 .56355 L .31213 .56086 L F
0 0 0 r
.31191 .56112 m .3113 .56407 L .31251 .56091 L F
.31156 .56276 m .3113 .56407 L .31191 .56112 L F
.683 .501 .634 r
.30958 .56703 m .31021 .57036 L .30593 .56663 L F
.165 0 .24 r
.31223 .56355 m .31146 .56618 L .30977 .56695 L F
.30999 .56649 m .30977 .56695 L .30958 .56703 L F
.31223 .56355 m .30977 .56695 L .30999 .56649 L F
.66 .407 .526 r
.30593 .56663 m .30958 .56736 L .3091 .56355 L F
0 0 .337 r
.30964 .56712 m .31021 .57036 L .30958 .56703 L F
.66 .407 .526 r
.30966 .56719 m .30974 .56739 L .30969 .56711 L F
.3097 .56738 m .30974 .56739 L .30966 .56719 L F
0 0 .294 r
.30974 .56739 m .31021 .57036 L .30991 .56754 L F
0 0 .337 r
.30991 .56754 m .31005 .56883 L .30964 .56712 L F
.31005 .56883 m .31021 .57036 L .30964 .56712 L F
.66 .407 .526 r
.30958 .56736 m .3097 .56738 L .30966 .56719 L F
.30958 .56736 m .30969 .56711 L .3091 .56355 L F
.324 .181 .527 r
.3091 .56355 m .31146 .56618 L .3113 .56407 L F
.30968 .56706 m .30974 .56739 L .31146 .56618 L F
0 0 .294 r
.30974 .56739 m .30991 .56754 L .31146 .56618 L F
0 0 .337 r
.30991 .56754 m .30962 .56709 L .31146 .56618 L F
.30962 .56709 m .30958 .56703 L .31146 .56618 L F
.324 .181 .527 r
.3091 .56355 m .30968 .56706 L .31146 .56618 L F
.415 .746 .994 r
.23308 .62113 m .23335 .61957 L .23148 .61987 L F
.23308 .62113 m .23507 .62079 L .23335 .61957 L F
.862 .512 .005 r
.3455 .7061 m .34535 .70744 L .3427 .70555 L F
.3455 .7061 m .34634 .70899 L .34535 .70744 L F
.922 .883 .778 r
.32626 .68409 m .32312 .68548 L .32291 .68538 L F
.32626 .68409 m .32515 .68606 L .32312 .68548 L F
.721 .658 .104 r
.32312 .68518 m .32312 .68541 L .32264 .68931 L F
.32312 .68541 m .32312 .68548 L .32307 .68587 L F
.32312 .68541 m .32307 .68587 L .32264 .68931 L F
.905 .965 .813 r
.32588 .68174 m .32626 .68409 L .32313 .6853 L F
.32315 .68508 m .32313 .6853 L .32291 .68538 L F
.32588 .68174 m .32313 .6853 L .32315 .68508 L F
.344 .589 .935 r
.24531 .62911 m .24584 .62751 L .24309 .62752 L F
.24531 .62911 m .24748 .62948 L .24584 .62751 L F
.657 .751 .919 r
.36903 .52208 m .37288 .5228 L .37088 .52037 L F
.279 .064 .397 r
.36903 .52208 m .37061 .52362 L .37288 .5228 L F
.522 .751 .98 r
.37288 .5228 m .3739 .52036 L .37088 .52037 L F
.37288 .5228 m .37527 .52227 L .3739 .52036 L F
0 0 0 r
.37288 .5228 m .37352 .52274 L .37527 .52227 L F
.37288 .5228 m .37061 .52362 L .37352 .52274 L F
.811 .716 .76 r
.37638 .58588 m .37413 .58926 L .37208 .58494 L F
.836 .755 .774 r
.37486 .58726 m .37413 .58926 L .37638 .58588 L F
.606 .382 .55 r
.38001 .58548 m .37486 .58726 L .37638 .58588 L F
.289 .787 .786 r
.37237 .55202 m .36897 .55297 L .36934 .55126 L F
.672 .7 .868 r
.36897 .55297 m .37237 .55202 L .36934 .55126 L F
0 0 0 r
.32645 .51946 m .32413 .52119 L .32232 .52189 L F
.509 .015 .018 r
.32818 .52078 m .32645 .51946 L .32894 .5198 L F
.32818 .52078 m .32413 .52119 L .32645 .51946 L F
.585 .411 .612 r
.32875 .51669 m .32894 .5198 L .32645 .51946 L F
.497 .017 .047 r
.3693 .53546 m .3674 .53712 L .36553 .536 L F
.687 .247 .202 r
.3693 .53546 m .37148 .5376 L .3674 .53712 L F
.852 .525 .432 r
.40811 .53279 m .4061 .53443 L .40447 .53137 L F
.697 .456 .555 r
.40975 .53165 m .4061 .53443 L .40811 .53279 L F
.773 .376 .302 r
.71512 .34656 m .71221 .34802 L .71168 .34573 L F
.71512 .34656 m .7166 .34893 L .71221 .34802 L F
.801 .747 .803 r
.68805 .33765 m .68455 .3405 L .68725 .33726 L F
.394 .396 .743 r
.34262 .5761 m .34269 .57954 L .34225 .57631 L F
.849 .463 .315 r
.34111 .58072 m .34269 .57954 L .34262 .5761 L F
.394 .396 .743 r
.34262 .5761 m .34225 .57631 L .3427 .576 L F
.849 .463 .315 r
.3409 .58137 m .34103 .58123 L .34111 .58072 L F
.3409 .58137 m .34344 .58197 L .34269 .57954 L F
.3409 .58137 m .34111 .58072 L .34352 .57992 L F
.34111 .58072 m .34262 .5761 L .34305 .57794 L F
.34103 .58123 m .34269 .57954 L .34111 .58072 L F
.34111 .58072 m .34305 .57794 L .34352 .57992 L F
.696 .337 .361 r
.34593 .58 m .34352 .57992 L .34262 .5761 L F
.762 .601 .679 r
.34176 .57652 m .34357 .57718 L .3427 .576 L F
.696 .337 .361 r
.34598 .57995 m .34262 .5761 L .34742 .57859 L F
.34593 .58 m .34587 .57992 L .34598 .57995 L F
.34587 .57992 m .34262 .5761 L .34598 .57995 L F
.58 .472 .696 r
.33996 .57753 m .34169 .57869 L .34442 .57749 L F
.34169 .57869 m .34352 .57992 L .34375 .5793 L F
.34169 .57869 m .34375 .5793 L .34442 .57749 L F
.762 .601 .679 r
.34357 .57718 m .34442 .57749 L .34376 .57692 L F
.34357 .57718 m .34376 .57692 L .3427 .576 L F
.33996 .57753 m .3416 .57751 L .34176 .57652 L F
.3416 .57751 m .34442 .57749 L .34176 .57652 L F
.074 0 0 r
.37446 .56607 m .37688 .56549 L .37866 .56418 L F
.748 .958 .659 r
.37866 .56418 m .37945 .56235 L .38013 .56336 L F
.37866 .56418 m .37688 .56549 L .37945 .56235 L F
.372 .141 .429 r
.33813 .63623 m .34072 .632 L .34033 .63599 L F
.969 .693 .453 r
.34072 .632 m .34033 .63599 L .33813 .63623 L F
.465 .217 .453 r
.34317 .6318 m .34072 .632 L .34033 .63599 L F
.497 .904 .813 r
.24661 .53045 m .24652 .52986 L .24896 .52941 L F
.24661 .53045 m .24447 .53103 L .24652 .52986 L F
.116 0 .355 r
.26218 .53695 m .26123 .53558 L .26264 .53422 L F
.26218 .53695 m .26067 .53852 L .26123 .53558 L F
.524 .316 .541 r
.25883 .55407 m .26072 .55125 L .25775 .55133 L F
.578 .381 .578 r
.35222 .59231 m .35198 .595 L .34929 .59545 L F
.67 .244 .226 r
.35011 .59438 m .35222 .59231 L .34989 .59157 L F
.456 .277 .549 r
.35441 .59445 m .35198 .595 L .35222 .59231 L F
.67 .244 .226 r
.35011 .59438 m .35441 .59445 L .35222 .59231 L F
.066 0 0 r
.25807 .53871 m .25608 .53857 L .25414 .53841 L F
.63 .805 .967 r
.37758 .65452 m .37803 .65656 L .37608 .65698 L F
.576 .29 .445 r
.70101 .33962 m .69758 .34227 L .69722 .33959 L F
.70101 .33962 m .70098 .34176 L .69758 .34227 L F
.533 .252 .434 r
.70381 .33936 m .70098 .34176 L .70101 .33962 L F
.807 .902 .908 r
.7106 .30512 m .70722 .30834 L .7061 .30696 L F
.575 .346 .531 r
.39209 .61628 m .38962 .61441 L .39216 .61393 L F
.39209 .61628 m .38947 .61714 L .38962 .61441 L F
.842 .84 .843 r
.4024 .59617 m .40252 .59493 L .40366 .59163 L F
.40252 .59493 m .40262 .59386 L .40286 .59333 L F
.40252 .59493 m .40286 .59333 L .40366 .59163 L F
.857 .813 .805 r
.40482 .59502 m .40233 .59859 L .40194 .59758 L F
.40245 .59524 m .40194 .59758 L .40108 .59537 L F
.40482 .59502 m .40194 .59758 L .40245 .59524 L F
.842 .84 .843 r
.4024 .59617 m .40482 .59502 L .40262 .59386 L F
.351 .087 .367 r
.30745 .55447 m .3096 .55378 L .31015 .55145 L F
.424 .151 .394 r
.31015 .55145 m .3096 .55378 L .31247 .55102 L F
.602 .294 .419 r
.37205 .57954 m .36828 .58206 L .36851 .57982 L F
.992 .739 .4 r
.33647 .64293 m .33787 .63897 L .33892 .64259 L F
.33647 .64293 m .33548 .63926 L .33787 .63897 L F
.506 .395 .662 r
.33929 .64521 m .33647 .64293 L .33892 .64259 L F
.33929 .64521 m .33698 .64574 L .33647 .64293 L F
0 0 0 r
.35834 .61078 m .35644 .61192 L .35503 .61336 L F
.823 .976 .891 r
.35328 .54943 m .35334 .5518 L .35507 .54959 L F
.259 .273 .685 r
.35328 .54943 m .35238 .55372 L .35334 .5518 L F
.217 .336 .771 r
.37228 .6036 m .37088 .60497 L .36982 .60189 L F
0 0 0 r
.371 .60554 m .37088 .60497 L .37228 .6036 L F
.371 .60554 m .37047 .60735 L .37088 .60497 L F
.928 .787 .684 r
.6078 .4207 m .60845 .42523 L .60833 .42328 L F
1 .821 .517 r
.60845 .42523 m .60693 .42662 L .60833 .42328 L F
.60845 .42523 m .60803 .42781 L .60693 .42662 L F
.794 .718 .781 r
.70236 .33334 m .69942 .33642 L .70049 .33396 L F
.857 .513 .402 r
.69506 .32439 m .69865 .32764 L .69454 .32687 L F
.742 .627 .732 r
.69865 .32764 m .69632 .33081 L .69454 .32687 L F
.415 0 0 r
.3648 .51673 m .36295 .51758 L .36117 .51666 L F
0 0 .266 r
.36554 .51897 m .36584 .51987 L .3648 .51673 L F
0 .207 .651 r
.3648 .51673 m .36757 .51851 L .36562 .51707 L F
.418 .38 .709 r
.3648 .51673 m .36584 .51987 L .36757 .51851 L F
0 .207 .651 r
.3648 .51673 m .36562 .51707 L .36295 .51758 L F
.376 .159 .452 r
.6301 .43777 m .62813 .44017 L .63024 .44062 L F
0 0 .052 r
.62947 .44009 m .62813 .44017 L .6301 .43777 L F
.809 .773 .819 r
.6301 .43777 m .62813 .44017 L .62652 .43725 L F
.017 .503 .873 r
.63024 .44062 m .62813 .44017 L .62947 .44009 L F
.791 .98 .707 r
.35321 .64769 m .35216 .64981 L .35 .65131 L F
.517 .889 .971 r
.3567 .66744 m .35576 .66853 L .35371 .66821 L F
.3567 .66744 m .35371 .66821 L .35441 .6681 L F
.289 .783 .749 r
.35676 .66735 m .3567 .66744 L .35441 .6681 L F
.542 .829 .49 r
.35833 .66568 m .35658 .66763 L .3567 .66744 L F
.069 0 0 r
.35833 .66568 m .3567 .66744 L .35886 .66668 L F
.289 .783 .749 r
.35886 .66668 m .3567 .66744 L .35676 .66735 L F
.542 .829 .49 r
.35658 .66763 m .35576 .66853 L .3567 .66744 L F
.745 .511 .576 r
.69632 .33081 m .69624 .33337 L .69194 .33253 L F
.714 .526 .633 r
.37681 .61309 m .37917 .61421 L .37922 .61133 L F
.603 .352 .509 r
.38181 .61365 m .37922 .61133 L .37917 .61421 L F
.38181 .61365 m .38249 .61104 L .37922 .61133 L F
.803 .977 .69 r
.39598 .60657 m .39535 .60847 L .39758 .60561 L F
.384 0 0 r
.39758 .60561 m .39807 .606 L .39598 .60657 L F
.39758 .60561 m .39985 .60699 L .39807 .606 L F
.429 .093 .293 r
.39958 .60522 m .39985 .60699 L .39758 .60561 L F
.806 .401 0 r
.42194 .56038 m .42368 .56329 L .42338 .56233 L F
.626 .137 0 r
.33262 .69957 m .33336 .70086 L .33094 .69901 L F
.33262 .69957 m .33478 .70227 L .33336 .70086 L F
.764 .642 .726 r
.57347 .43402 m .57459 .43739 L .57067 .43735 L F
.711 .364 .387 r
.57067 .43735 m .57459 .43739 L .57354 .43995 L F
.716 .616 .745 r
.57347 .43402 m .57717 .43462 L .57459 .43739 L F
.674 .324 .372 r
.57459 .43739 m .5772 .43978 L .57354 .43995 L F
.655 .521 .688 r
.57717 .43462 m .57726 .43768 L .57459 .43739 L F
.644 .336 .435 r
.57459 .43739 m .57726 .43768 L .5772 .43978 L F
0 .216 .738 r
.22892 .61801 m .2292 .61642 L .22719 .61469 L F
0 .294 .792 r
.22892 .61801 m .23063 .61818 L .2292 .61642 L F
.22892 .61801 m .23148 .61987 L .23063 .61818 L F
0 .245 .756 r
.32988 .51576 m .33141 .51925 L .32875 .51669 L F
.53 .37 .608 r
.32875 .51669 m .33141 .51925 L .32894 .5198 L F
.55 .574 .831 r
.37582 .55103 m .37689 .54703 L .37427 .54982 L F
.37582 .55103 m .37826 .55073 L .37689 .54703 L F
.43 0 0 r
.37427 .54982 m .37826 .55073 L .37582 .55103 L F
.535 .564 .831 r
.37975 .55443 m .37582 .55103 L .37826 .55073 L F
.674 .467 .598 r
.31324 .63046 m .31755 .63012 L .31728 .62731 L F
.518 .353 .596 r
.31728 .62731 m .31967 .62875 L .32028 .62567 L F
.31728 .62731 m .31755 .63012 L .31967 .62875 L F
.725 .593 .708 r
.72333 .35274 m .72083 .35563 L .71973 .35219 L F
.537 .816 .464 r
.72333 .35274 m .72233 .35389 L .72259 .35359 L F
.429 0 0 r
.72604 .35368 m .72233 .35389 L .72333 .35274 L F
.115 .667 .773 r
.72468 .35376 m .72519 .35366 L .72233 .35389 L F
.72604 .35368 m .72519 .35366 L .72468 .35376 L F
.478 .187 .392 r
.72918 .35124 m .7285 .3533 L .72604 .35368 L F
.445 .879 .883 r
.72885 .35223 m .72519 .35366 L .72604 .35368 L F
0 0 0 r
.72885 .35223 m .72625 .35347 L .72519 .35366 L F
.72625 .35347 m .72439 .35436 L .72519 .35366 L F
.269 0 0 r
.72519 .35366 m .72208 .35417 L .72233 .35389 L F
0 0 0 r
.72233 .35389 m .71863 .35531 L .72165 .35427 L F
.269 0 0 r
.72208 .35417 m .72132 .3543 L .72233 .35389 L F
.537 .816 .464 r
.72259 .35359 m .72233 .35389 L .72083 .35563 L F
.918 .541 .284 r
.32312 .68548 m .32515 .68606 L .3258 .68919 L F
.74 .631 .739 r
.19484 .59484 m .19558 .59871 L .19807 .59543 L F
.664 .198 .135 r
.29945 .54025 m .30372 .54112 L .3007 .53918 L F
.444 .608 .917 r
.24935 .63221 m .24912 .62944 L .24748 .62948 L F
.24935 .63221 m .25158 .63233 L .24912 .62944 L F
.785 .686 .755 r
.61806 .3989 m .61934 .40291 L .61535 .40179 L F
.67 .623 .793 r
.62218 .40032 m .61934 .40291 L .61806 .3989 L F
.408 0 .123 r
.22306 .56647 m .22594 .56609 L .22738 .56391 L F
.596 .55 .773 r
.22615 .56036 m .22738 .56391 L .23055 .56229 L F
.033 0 0 r
.22594 .56609 m .23055 .56229 L .22738 .56391 L F
.078 .504 .899 r
.24117 .62701 m .24166 .62612 L .23971 .62579 L F
.24117 .62701 m .24309 .62752 L .24166 .62612 L F
.698 .337 .361 r
.29677 .53544 m .29885 .53802 L .29829 .53698 L F
.764 .881 .93 r
.3464 .59636 m .34929 .59545 L .34752 .59391 L F
.34752 .59391 m .34929 .59545 L .3464 .59636 L F
0 0 .328 r
.33827 .54498 m .33951 .5443 L .33987 .54107 L F
.394 .829 .685 r
.33827 .54498 m .33959 .54411 L .33951 .5443 L F
.065 0 .389 r
.33975 .54211 m .33952 .54419 L .34096 .54236 L F
.33952 .54419 m .33965 .54411 L .34096 .54236 L F
.33952 .54419 m .33951 .5443 L .33965 .54411 L F
.649 .892 .553 r
.33951 .5443 m .33959 .54411 L .34096 .54236 L F
.86 .959 .869 r
.33625 .5459 m .33829 .54245 L .33959 .54411 L F
.749 .791 .887 r
.34096 .54236 m .33959 .54411 L .33829 .54245 L F
.782 .593 .643 r
.33865 .54403 m .3422 .54262 L .34096 .54236 L F
.3422 .54262 m .3432 .54221 L .34096 .54236 L F
.065 0 .389 r
.33987 .54107 m .33975 .54211 L .34096 .54236 L F
.394 .829 .685 r
.33891 .54456 m .33625 .5459 L .33959 .54411 L F
.33827 .54498 m .33806 .54508 L .33891 .54456 L F
.33806 .54508 m .33625 .5459 L .33891 .54456 L F
.452 .397 .706 r
.35213 .59765 m .34929 .59545 L .35198 .595 L F
.35213 .59765 m .35 .59839 L .34929 .59545 L F
.953 .676 .474 r
.35894 .63962 m .35663 .64112 L .3556 .63887 L F
.35894 .63962 m .35919 .64229 L .35663 .64112 L F
.772 .685 .767 r
.35744 .63598 m .36147 .63642 L .35894 .63962 L F
.379 .786 .982 r
.35899 .63519 m .35944 .63541 L .35744 .63598 L F
.35944 .63541 m .36147 .63642 L .35871 .63612 L F
.35944 .63541 m .35871 .63612 L .35744 .63598 L F
.893 .937 .836 r
.35894 .63962 m .36147 .63642 L .3596 .63475 L F
.652 .506 .672 r
.35894 .63962 m .36207 .63951 L .36147 .63642 L F
.538 .129 .214 r
.36044 .64179 m .36207 .63951 L .35894 .63962 L F
.039 .004 .484 r
.36044 .64179 m .35894 .63962 L .35952 .63533 L F
.35966 .6352 m .35952 .63533 L .3596 .63475 L F
.36044 .64179 m .35952 .63533 L .35966 .6352 L F
.36044 .64179 m .35919 .64229 L .35894 .63962 L F
.538 .129 .214 r
.36044 .64179 m .35894 .63962 L .35919 .64229 L F
.857 .813 .805 r
.40482 .59502 m .40108 .59537 L .40262 .59386 L F
.737 .316 0 r
.37651 .51529 m .37752 .51697 L .37798 .51737 L F
.54 .357 .582 r
.31447 .55776 m .31436 .56051 L .31213 .56086 L F
0 0 0 r
.31189 .56112 m .31251 .56091 L .3126 .55876 L F
.595 .804 .98 r
.37413 .58926 m .36944 .58831 L .37208 .58494 L F
.6 .349 .508 r
.37413 .58926 m .37366 .59207 L .37111 .5919 L F
.578 .384 .582 r
.37486 .58726 m .37366 .59207 L .37413 .58926 L F
.781 .981 .715 r
.39119 .63443 m .38837 .63759 L .39055 .63621 L F
.165 0 .298 r
.3059 .60611 m .30408 .60453 L .30612 .6034 L F
.3059 .60611 m .30428 .60685 L .30408 .60453 L F
0 0 0 r
.39544 .60912 m .39535 .60847 L .39598 .60657 L F
.39544 .60912 m .39399 .61049 L .39535 .60847 L F
.33705 .59371 m .33437 .59691 L .33586 .59508 L F
.325 0 0 r
.27362 .53855 m .27269 .53959 L .27111 .53882 L F
0 .17 .7 r
.27111 .53882 m .27269 .53959 L .27153 .53688 L F
.553 .567 .823 r
.33978 .58837 m .34131 .59165 L .33868 .59197 L F
.428 0 .083 r
.34131 .59165 m .33705 .59371 L .33868 .59197 L F
.613 .637 .85 r
.69942 .33642 m .69624 .33337 L .70049 .33396 L F
.014 .24 .746 r
.3482 .64727 m .34734 .64896 L .34581 .64514 L F
0 .188 .709 r
.35 .65131 m .34734 .64896 L .3482 .64727 L F
.979 .71 .446 r
.3377 .53413 m .33935 .53812 L .33932 .53524 L F
.823 .894 .892 r
.3377 .53413 m .33932 .53524 L .3421 .533 L F
.53 .342 .571 r
.38228 .55122 m .37975 .55443 L .37826 .55073 L F
.38228 .55122 m .38223 .554 L .37975 .55443 L F
.37975 .55443 m .38223 .554 L .38228 .55122 L F
.329 0 0 r
.38902 .58261 m .38734 .58433 L .38471 .58455 L F
0 0 0 r
.39181 .57975 m .39033 .58156 L .38902 .58261 L F
.39033 .58156 m .38734 .58433 L .38902 .58261 L F
.059 .077 .563 r
.40938 .58497 m .40874 .5863 L .40876 .58242 L F
0 0 .374 r
.40941 .58681 m .40874 .5863 L .40938 .58497 L F
.40941 .58681 m .40953 .58871 L .40874 .5863 L F
.782 .982 .905 r
.71004 .32783 m .70864 .33038 L .71196 .32794 L F
.868 .701 .673 r
.71004 .32783 m .71162 .33223 L .70864 .33038 L F
.972 .791 .601 r
.41883 .56699 m .41722 .56597 L .41793 .56348 L F
.971 .654 .322 r
.41883 .56699 m .41769 .56812 L .41722 .56597 L F
.41883 .56699 m .41928 .56947 L .41769 .56812 L F
.74 .631 .739 r
.19513 .59489 m .19807 .59543 L .19597 .59465 L F
.971 .656 .322 r
.19807 .59543 m .19684 .59607 L .19597 .59465 L F
.614 .196 0 r
.19597 .59465 m .19684 .59607 L .19643 .59547 L F
.19597 .59465 m .19643 .59547 L .19764 .59419 L F
.19597 .59465 m .19764 .59419 L .19834 .59345 L F
.74 .631 .739 r
.19484 .59484 m .19513 .59489 L .19597 .59465 L F
.971 .656 .322 r
.19807 .59543 m .19814 .59728 L .19684 .59607 L F
.134 0 0 r
.30207 .545 m .30024 .54652 L .29784 .54706 L F
.071 0 0 r
.30257 .54588 m .30207 .545 L .30446 .54465 L F
.30257 .54588 m .30024 .54652 L .30207 .545 L F
.678 .678 .843 r
.34101 .5156 m .33776 .51397 L .34024 .51289 L F
.177 .079 .498 r
.34281 .51231 m .34101 .5156 L .34024 .51289 L F
.34236 .51312 m .34305 .51565 L .34101 .5156 L F
.34286 .51305 m .34305 .51565 L .34236 .51312 L F
.317 .181 .532 r
.34506 .51424 m .34281 .51231 L .34556 .51223 L F
.34445 .51371 m .34305 .51565 L .34281 .51231 L F
.34506 .51424 m .34453 .51461 L .34445 .51371 L F
.34453 .51461 m .34305 .51565 L .34445 .51371 L F
.177 .079 .498 r
.34281 .51231 m .34286 .51305 L .34236 .51312 L F
.449 .056 .201 r
.34656 .51044 m .34556 .51223 L .34281 .51231 L F
.68 .525 .668 r
.34281 .51231 m .34024 .51289 L .34277 .50941 L F
0 0 0 r
.34127 .51406 m .34435 .51274 L .34146 .5112 L F
.34435 .51274 m .34556 .51223 L .34428 .51191 L F
.34435 .51274 m .34428 .51191 L .34146 .5112 L F
.34127 .51406 m .34371 .51356 L .34479 .51279 L F
.344 .5129 m .34479 .51279 L .34556 .51223 L F
.34127 .51406 m .34479 .51279 L .344 .5129 L F
.143 0 0 r
.34205 .51711 m .34101 .5156 L .34305 .51565 L F
.34205 .51711 m .33992 .5179 L .34101 .5156 L F
.991 .735 .425 r
.36244 .54089 m .36245 .54381 L .36405 .54455 L F
.794 .992 .881 r
.36245 .54381 m .36162 .54551 L .36405 .54455 L F
.613 .59 .804 r
.36162 .54551 m .36466 .54731 L .36405 .54455 L F
.58 .464 .685 r
.36405 .54455 m .36752 .54432 L .36653 .5414 L F
.316 .057 .354 r
.36466 .54731 m .36752 .54432 L .36405 .54455 L F
.437 .415 .737 r
.32021 .52226 m .32156 .51936 L .31944 .52018 L F
.203 .09 .494 r
.35311 .52578 m .35302 .5284 L .35138 .52907 L F
.524 .521 .794 r
.35481 .5319 m .35138 .52907 L .35302 .5284 L F
.464 .67 .953 r
.58286 .42555 m .58592 .42869 L .58223 .42822 L F
.634 .135 .048 r
.58223 .42822 m .58089 .42949 L .58286 .42555 L F
.792 .423 .358 r
.58451 .42991 m .58636 .43128 L .58538 .43017 L F
.58636 .43128 m .58645 .43134 L .58636 .43124 L F
.58636 .43128 m .58636 .43124 L .58523 .42999 L F
.664 .521 .68 r
.58645 .43134 m .58364 .43463 L .58232 .43094 L F
.58645 .43134 m .58586 .43342 L .58364 .43463 L F
.58645 .43134 m .58232 .43094 L .58523 .42999 L F
.235 0 .084 r
.58742 .43077 m .58472 .43065 L .58361 .43395 L F
.58823 .4301 m .58622 .43041 L .58742 .43077 L F
.58622 .43041 m .58472 .43065 L .58742 .43077 L F
.792 .423 .358 r
.58223 .42822 m .58451 .42991 L .58523 .42999 L F
.58451 .42991 m .58538 .43017 L .58523 .42999 L F
.634 .135 .048 r
.58223 .42822 m .58523 .42999 L .58089 .42949 L F
.746 .75 .856 r
.58089 .42949 m .58523 .42999 L .58232 .43094 L F
.331 .741 .979 r
.58426 .42963 m .58472 .43065 L .58622 .43041 L F
.58613 .42985 m .58622 .43041 L .58823 .4301 L F
.58426 .42963 m .58622 .43041 L .58613 .42985 L F
.477 .292 .55 r
.33024 .59847 m .33042 .60163 L .32768 .60237 L F
.151 0 0 r
.32768 .60237 m .32916 .60265 L .32657 .60288 L F
.32768 .60237 m .33042 .60163 L .32916 .60265 L F
.689 .292 .29 r
.2699 .54823 m .27344 .54992 L .27224 .54771 L F
.019 0 .459 r
.35655 .62694 m .35667 .62971 L .35722 .62981 L F
0 0 0 r
.24386 .55084 m .24502 .55027 L .24742 .54888 L F
.642 .322 .415 r
.30745 .55447 m .30719 .55677 L .30994 .55649 L F
.468 .365 .655 r
.30745 .55447 m .30994 .55649 L .3096 .55378 L F
.30745 .55447 m .30994 .55649 L .3096 .55378 L F
.45 .83 .989 r
.27663 .61715 m .27888 .61658 L .27873 .61785 L F
.911 .695 .597 r
.42326 .57866 m .42215 .57549 L .42399 .57649 L F
.019 0 .181 r
.42607 .57501 m .42418 .57694 L .42399 .57649 L F
.608 .367 .526 r
.42418 .57694 m .42326 .57866 L .42399 .57649 L F
.215 .428 .853 r
.24246 .61424 m .24247 .61652 L .24061 .614 L F
.24246 .61424 m .2444 .61746 L .24247 .61652 L F
.596 .03 0 r
.32211 .66646 m .32566 .66766 L .32398 .66762 L F
.278 0 0 r
.32625 .66799 m .32845 .66846 L .32668 .66823 L F
.32566 .66766 m .32667 .66795 L .32625 .66799 L F
.32667 .66795 m .32845 .66846 L .32625 .66799 L F
.167 .568 .933 r
.32552 .66214 m .32816 .66316 L .32919 .66321 L F
.197 .573 .939 r
.32581 .66222 m .32593 .6623 L .32552 .66214 L F
.32593 .6623 m .32922 .66445 L .32552 .66214 L F
.684 .463 .579 r
.32811 .66317 m .32816 .66316 L .32552 .66214 L F
.197 .573 .939 r
.3292 .66362 m .32922 .66445 L .32725 .66316 L F
.32814 .66318 m .32725 .66316 L .32581 .66222 L F
.3292 .66362 m .32725 .66316 L .32814 .66318 L F
.291 .062 .384 r
.32919 .66321 m .32816 .66316 L .32814 .66318 L F
.692 .484 .6 r
.32814 .66318 m .32816 .66316 L .32811 .66317 L F
.197 .573 .939 r
.32919 .66321 m .3292 .66362 L .32581 .66222 L F
.291 .062 .384 r
.32919 .66321 m .32814 .66318 L .32607 .66799 L F
.684 .463 .579 r
.32304 .66449 m .32811 .66317 L .32552 .66214 L F
.692 .484 .6 r
.32607 .66799 m .32814 .66318 L .32304 .66449 L F
.32814 .66318 m .32811 .66317 L .32304 .66449 L F
.32607 .66799 m .32304 .66449 L .32225 .66622 L F
0 .336 .704 r
.32596 .6679 m .32607 .66799 L .32225 .66622 L F
.352 0 0 r
.32489 .66907 m .32599 .66806 L .32668 .66823 L F
.278 0 0 r
.32599 .66806 m .32668 .66823 L .32597 .66807 L F
.32625 .66799 m .32668 .66823 L .32599 .66806 L F
.352 0 0 r
.32599 .66806 m .32607 .66799 L .32668 .66823 L F
0 .336 .704 r
.32668 .66823 m .32607 .66799 L .32596 .6679 L F
.278 0 0 r
.32625 .66799 m .32599 .66806 L .32398 .66762 L F
.765 .293 .122 r
.32489 .66907 m .32599 .66806 L .32383 .66793 L F
.278 0 0 r
.32599 .66806 m .32597 .66807 L .32591 .66806 L F
.32599 .66806 m .32591 .66806 L .32398 .66762 L F
.32566 .66766 m .32625 .66799 L .32398 .66762 L F
0 .248 .698 r
.32211 .66646 m .32398 .66762 L .32225 .66622 L F
0 .336 .704 r
.32591 .66806 m .32225 .66622 L .32398 .66762 L F
.765 .293 .122 r
.32577 .66798 m .32607 .66799 L .32225 .66622 L F
.32599 .66806 m .32607 .66799 L .32383 .66793 L F
.807 .936 .57 r
.32606 .66799 m .32607 .66799 L .32605 .66801 L F
.32716 .66516 m .32607 .66799 L .32606 .66799 L F
.32601 .66801 m .32605 .66801 L .32599 .66806 L F
.32716 .66516 m .32605 .66801 L .32601 .66801 L F
.32716 .66516 m .32599 .66806 L .32597 .66807 L F
0 .336 .704 r
.32596 .6679 m .32225 .66622 L .32597 .66807 L F
.807 .936 .57 r
.32592 .66728 m .32597 .66807 L .32537 .66824 L F
.32716 .66516 m .32597 .66807 L .32592 .66728 L F
0 .336 .704 r
.32597 .66807 m .32225 .66622 L .32591 .66806 L F
.32668 .66823 m .32596 .6679 L .32597 .66807 L F
.765 .293 .122 r
.32383 .66793 m .32577 .66798 L .32225 .66622 L F
.807 .936 .57 r
.32537 .66824 m .32599 .66806 L .32489 .66907 L F
.725 .237 .085 r
.3556 .56437 m .35308 .566 L .35167 .56318 L F
0 0 0 r
.35614 .56456 m .3556 .56437 L .35632 .56271 L F
.35614 .56456 m .35308 .566 L .3556 .56437 L F
.638 .89 .986 r
.30917 .52128 m .31365 .52081 L .31226 .5198 L F
.748 .903 .946 r
.31226 .5198 m .31365 .52081 L .31584 .51942 L F
.903 .547 .08 r
.60362 .40441 m .60477 .40596 L .60525 .40842 L F
.594 .845 .992 r
.31028 .63602 m .31227 .63744 L .31277 .63524 L F
.556 .202 .323 r
.31227 .63744 m .31463 .63871 L .31277 .63524 L F
.658 .613 .793 r
.32595 .5066 m .3274 .51042 L .3298 .50964 L F
.24 .348 .773 r
.41715 .54721 m .42146 .54977 L .4186 .55134 L F
.7 .976 .773 r
.42146 .54977 m .41739 .55396 L .4186 .55134 L F
.215 .721 .898 r
.35316 .51277 m .35737 .51314 L .35734 .51301 L F
.524 .316 .541 r
.25883 .55407 m .26037 .55397 L .26072 .55125 L F
0 0 0 r
.26037 .55397 m .26316 .5507 L .26072 .55125 L F
.221 0 0 r
.2382 .54647 m .23484 .54826 L .23621 .54668 L F
0 0 .07 r
.23638 .54619 m .23484 .54826 L .2382 .54647 L F
.23638 .54619 m .235 .54856 L .23484 .54826 L F
.235 .54856 m .23458 .54927 L .23484 .54826 L F
.183 0 0 r
.23434 .54726 m .23484 .54826 L .23356 .5475 L F
.23621 .54668 m .23484 .54826 L .23434 .54726 L F
0 0 .217 r
.23458 .54927 m .23356 .5475 L .23484 .54826 L F
.23458 .54927 m .23275 .55138 L .23356 .5475 L F
.861 .785 .776 r
.36162 .54551 m .35904 .54835 L .36168 .54784 L F
.615 .417 .59 r
.35895 .55104 m .36168 .54784 L .35904 .54835 L F
.35895 .55104 m .36183 .55127 L .36168 .54784 L F
.613 .59 .804 r
.36162 .54551 m .36168 .54784 L .36466 .54731 L F
.385 .156 .44 r
.36183 .55127 m .36466 .54731 L .36168 .54784 L F
.513 .413 .678 r
.36147 .63642 m .36207 .63951 L .3644 .63871 L F
.546 0 0 r
.36147 .63642 m .36205 .63738 L .3596 .63475 L F
.36147 .63642 m .3644 .63871 L .36205 .63738 L F
.185 0 .145 r
.29319 .63946 m .29591 .63697 L .29508 .63921 L F
.293 0 .191 r
.29508 .63921 m .29591 .63697 L .29711 .63823 L F
.308 0 .175 r
.29711 .63823 m .29591 .63697 L .29843 .63622 L F
.494 .124 .267 r
.36328 .5627 m .36768 .5603 L .363 .56076 L F
.36515 .56168 m .3663 .5628 L .36768 .5603 L F
.36328 .5627 m .36465 .56274 L .36515 .56168 L F
.36465 .56274 m .3663 .5628 L .36515 .56168 L F
.795 .31 .062 r
.36361 .56539 m .36008 .56261 L .36328 .5627 L F
0 .035 .581 r
.36184 .5674 m .36365 .56741 L .36361 .56539 L F
.795 .31 .062 r
.36361 .56539 m .36317 .56608 L .36008 .56261 L F
.765 .384 .333 r
.36008 .56261 m .36301 .5659 L .36005 .56457 L F
.36301 .5659 m .36317 .56608 L .36293 .56596 L F
.36301 .5659 m .36293 .56596 L .36005 .56457 L F
.778 .836 .372 r
.36319 .56604 m .36317 .56608 L .36361 .56539 L F
0 .035 .581 r
.36365 .56741 m .36411 .56741 L .36393 .56669 L F
.36365 .56741 m .36393 .56669 L .36361 .56539 L F
.673 .307 .344 r
.36255 .56629 m .36005 .56457 L .36317 .56608 L F
0 0 0 r
.36319 .56606 m .36255 .56629 L .36317 .56608 L F
.777 .282 .035 r
.36361 .56539 m .36288 .56652 L .36255 .56629 L F
.778 .836 .372 r
.36338 .56559 m .36319 .56604 L .36361 .56539 L F
.756 .56 .631 r
.36304 .56587 m .36344 .56554 L .36361 .56539 L F
.778 .836 .372 r
.36349 .56522 m .36317 .56608 L .36405 .56403 L F
.393 .706 .985 r
.3649 .5614 m .3663 .5628 L .36328 .5627 L F
.778 .836 .372 r
.3649 .5614 m .36361 .56539 L .36518 .56411 L F
.617 .496 .693 r
.36513 .56365 m .36394 .56513 L .3649 .5614 L F
.777 .282 .035 r
.36361 .56539 m .36372 .56587 L .36319 .56606 L F
.617 .496 .693 r
.36319 .56606 m .36317 .56608 L .36318 .56605 L F
.777 .282 .035 r
.36318 .56605 m .36319 .56606 L .36317 .56607 L F
.36361 .56539 m .36319 .56606 L .36318 .56605 L F
.617 .496 .693 r
.36394 .56513 m .36319 .56606 L .36334 .56563 L F
.36319 .56606 m .36318 .56605 L .36334 .56563 L F
.778 .836 .372 r
.36405 .56403 m .36338 .56559 L .36361 .56539 L F
.3649 .5614 m .36349 .56522 L .36405 .56403 L F
.617 .496 .693 r
.36394 .56513 m .36334 .56563 L .3649 .5614 L F
.756 .56 .631 r
.36334 .56563 m .36518 .56411 L .36361 .56539 L F
.36319 .56576 m .36518 .56411 L .36334 .56563 L F
0 0 0 r
.36518 .56411 m .36255 .56629 L .36319 .56606 L F
.777 .282 .035 r
.36317 .56607 m .36411 .56741 L .36288 .56652 L F
.36372 .56587 m .36411 .56741 L .36317 .56607 L F
.756 .56 .631 r
.36255 .56629 m .36319 .56576 L .36344 .56554 L F
.36255 .56629 m .36344 .56554 L .36304 .56587 L F
.617 .496 .693 r
.36518 .56411 m .36481 .56448 L .36513 .56365 L F
.36481 .56448 m .36317 .56608 L .36513 .56365 L F
0 .035 .581 r
.36184 .5674 m .36281 .57005 L .36411 .56741 L F
.143 .428 .868 r
.21033 .60377 m .2095 .60109 L .20843 .60101 L F
.21033 .60377 m .21191 .6043 L .2095 .60109 L F
.875 .91 .504 r
.39737 .66755 m .39621 .66986 L .39622 .67142 L F
0 0 0 r
.3965 .67222 m .39541 .67422 L .39622 .67142 L F
.123 0 0 r
.71695 .35733 m .72083 .35563 L .72165 .35427 L F
0 0 .101 r
.72083 .35563 m .72233 .35389 L .72165 .35427 L F
.626 .874 .988 r
.26188 .52639 m .25756 .52641 L .26013 .52603 L F
.511 .89 .965 r
.26412 .52553 m .26188 .52639 L .26013 .52603 L F
.795 .991 .749 r
.68717 .33736 m .68455 .3405 L .68558 .33839 L F
.68717 .33736 m .68558 .33839 L .68597 .33757 L F
.359 .485 .851 r
.68597 .33757 m .68455 .3405 L .68763 .34111 L F
.868 .541 .431 r
.68518 .34019 m .68255 .34204 L .68274 .34023 L F
.6838 .33954 m .68274 .34023 L .68286 .33909 L F
.68518 .34019 m .68274 .34023 L .6838 .33954 L F
.795 .991 .749 r
.68725 .33726 m .68717 .33736 L .68597 .33757 L F
0 0 0 r
.35377 .57218 m .35505 .57195 L .35655 .56982 L F
.35377 .57218 m .3529 .57309 L .35505 .57195 L F
.233 .352 .78 r
.27009 .61918 m .26986 .62223 L .26828 .62067 L F
.27009 .61918 m .27172 .62293 L .26986 .62223 L F
.753 .336 .257 r
.28427 .64271 m .28654 .63957 L .28185 .6386 L F
.359 .454 .822 r
.28509 .63597 m .28654 .63957 L .28816 .63766 L F
0 0 0 r
.28816 .63766 m .28654 .63957 L .28427 .64271 L F
.657 .246 .252 r
.39534 .57741 m .39004 .5784 L .39329 .57607 L F
.889 .856 .803 r
.39452 .57388 m .39534 .57741 L .39329 .57607 L F
.138 .623 .917 r
.28543 .64856 m .2853 .64779 L .28307 .64606 L F
.067 0 .182 r
.3086 .57631 m .31014 .57763 L .3116 .57509 L F
.3086 .57631 m .30789 .57843 L .31014 .57763 L F
.35 .166 .486 r
.31329 .58835 m .31339 .59089 L .31165 .58913 L F
.186 .153 .586 r
.31339 .59089 m .31215 .59197 L .31165 .58913 L F
.736 .73 .845 r
.57965 .43221 m .58025 .43386 L .57717 .43462 L F
.724 .583 .698 r
.58025 .43386 m .57726 .43768 L .57717 .43462 L F
.58025 .43386 m .58102 .43718 L .57726 .43768 L F
.607 .627 .845 r
.58232 .43094 m .58025 .43386 L .57965 .43221 L F
.58232 .43094 m .58286 .43245 L .58025 .43386 L F
.794 .996 .862 r
.58187 .43169 m .58411 .43087 L .58426 .42963 L F
.58411 .43087 m .58472 .43065 L .58456 .4303 L F
.58411 .43087 m .58456 .4303 L .58426 .42963 L F
.607 .627 .845 r
.58286 .43245 m .58364 .43463 L .5815 .43415 L F
.58286 .43245 m .5815 .43415 L .58025 .43386 L F
.662 .545 .711 r
.58025 .43386 m .58364 .43463 L .58102 .43718 L F
0 0 0 r
.34785 .51885 m .35026 .51559 L .34851 .51663 L F
.34349 .59844 m .34105 .60151 L .34266 .60084 L F
.516 .504 .781 r
.34105 .60151 m .34427 .60416 L .34266 .60084 L F
.972 .669 .287 r
.33909 .58614 m .33866 .58688 L .34014 .58674 L F
.979 .696 .316 r
.33866 .58688 m .33978 .58837 L .34014 .58674 L F
.23 .355 .784 r
.33885 .58253 m .34014 .58674 L .34137 .58381 L F
.395 .075 .3 r
.34263 .58591 m .33978 .58837 L .34014 .58674 L F
.34263 .58591 m .34214 .58799 L .33978 .58837 L F
.515 .478 .754 r
.33978 .58837 m .34214 .58799 L .34137 .58381 L F
.33978 .58837 m .34028 .58693 L .34014 .58674 L F
.656 .126 0 r
.33866 .58688 m .34214 .58799 L .33978 .58837 L F
.34023 .58738 m .34034 .58874 L .34214 .58799 L F
.33866 .58688 m .34009 .58847 L .34023 .58738 L F
.34009 .58847 m .34034 .58874 L .34023 .58738 L F
.515 .478 .754 r
.34028 .58693 m .34137 .58381 L .34037 .58619 L F
.34028 .58693 m .34037 .58619 L .34014 .58674 L F
.492 .207 .409 r
.38223 .554 m .38561 .55123 L .38228 .55122 L F
0 0 .406 r
.38364 .55188 m .38228 .55122 L .38363 .54964 L F
.38364 .55188 m .38223 .554 L .38228 .55122 L F
.847 .809 .812 r
.71985 .30401 m .72255 .30464 L .7239 .30311 L F
.636 .462 .63 r
.36335 .58846 m .36143 .59093 L .36091 .58921 L F
.36335 .58846 m .36143 .59093 L .36091 .58921 L F
.555 .803 .991 r
.36286 .65825 m .36459 .65649 L .36138 .65752 L F
.36286 .65825 m .36594 .65784 L .36459 .65649 L F
.145 .048 .477 r
.33155 .60018 m .33024 .59847 L .33228 .59783 L F
.33155 .60018 m .33042 .60163 L .33024 .59847 L F
0 0 .248 r
.41582 .55741 m .417 .56096 L .41655 .55952 L F
.915 .529 .121 r
.417 .56096 m .41652 .56232 L .41655 .55952 L F
.417 .56096 m .41793 .56348 L .41652 .56232 L F
0 0 0 r
.32326 .61398 m .32113 .61747 L .32285 .6159 L F
.069 0 0 r
.35833 .66568 m .35886 .66668 L .36043 .66443 L F
.503 .241 .45 r
.25058 .54088 m .24983 .5434 L .24778 .54192 L F
.014 .272 .772 r
.24778 .54192 m .24983 .5434 L .24928 .54233 L F
.12 0 .06 r
.25035 .54073 m .25058 .54088 L .24854 .54144 L F
.503 .241 .45 r
.25058 .54088 m .24778 .54192 L .24854 .54144 L F
.014 .272 .772 r
.24778 .54192 m .24928 .54233 L .24785 .53957 L F
.245 0 0 r
.24701 .54171 m .24778 .54192 L .24509 .54204 L F
.24854 .54144 m .24778 .54192 L .24701 .54171 L F
.931 .856 .745 r
.27115 .75624 m .27332 .75717 L .27371 .75444 L F
0 0 0 r
.39253 .5802 m .39181 .57975 L .39413 .57901 L F
.39253 .5802 m .39033 .58156 L .39181 .57975 L F
.932 .696 .557 r
.61746 .43767 m .61546 .43964 L .61363 .43677 L F
.61746 .43767 m .61733 .44029 L .61546 .43964 L F
0 .516 .83 r
.57039 .40527 m .57433 .40656 L .57273 .40532 L F
.685 .973 .916 r
.57433 .40656 m .57545 .40478 L .57273 .40532 L F
.57433 .40656 m .57677 .405 L .57545 .40478 L F
.428 .266 .557 r
.31662 .55976 m .31447 .55776 L .3168 .55698 L F
.31662 .55976 m .31436 .56051 L .31447 .55776 L F
.53 .596 .865 r
.56938 .43233 m .57054 .43454 L .56762 .4325 L F
.768 .575 .638 r
.57054 .43454 m .5668 .43685 L .56762 .4325 L F
.57054 .43454 m .57067 .43735 L .5668 .43685 L F
.687 .736 .888 r
.57222 .43105 m .57054 .43454 L .56938 .43233 L F
.57222 .43105 m .57347 .43402 L .57054 .43454 L F
.764 .642 .726 r
.57347 .43402 m .57067 .43735 L .57054 .43454 L F
.429 .276 .57 r
.35203 .60057 m .35 .59839 L .35213 .59765 L F
.35203 .60057 m .34957 .60172 L .35 .59839 L F
.695 .976 .912 r
.38987 .5585 m .38973 .55851 L .38731 .56012 L F
.38973 .55851 m .38761 .55918 L .38731 .56012 L F
.29 .593 .947 r
.38761 .55918 m .39034 .56059 L .38731 .56012 L F
.636 .198 .191 r
.38544 .55972 m .3872 .55931 L .38853 .55849 L F
.38356 .56047 m .3859 .55973 L .38544 .55972 L F
.3859 .55973 m .3872 .55931 L .38544 .55972 L F
.695 .976 .912 r
.38973 .55851 m .3878 .5586 L .38761 .55918 L F
.662 .968 .914 r
.39099 .55672 m .38987 .5585 L .39157 .5577 L F
.6 .894 .989 r
.38516 .55786 m .38192 .55899 L .38853 .55849 L F
.038 .596 .812 r
.38704 .55821 m .38681 .55791 L .38516 .55786 L F
.38853 .55849 m .38765 .55819 L .38704 .55821 L F
.38765 .55819 m .38681 .55791 L .38704 .55821 L F
.636 .198 .191 r
.38192 .55899 m .38356 .56047 L .38717 .55903 L F
.38612 .55867 m .38717 .55903 L .38853 .55849 L F
.38192 .55899 m .38717 .55903 L .38612 .55867 L F
.38356 .56047 m .38427 .56112 L .3872 .55931 L F
.869 .995 .784 r
.38853 .55849 m .38427 .56112 L .38681 .55791 L F
.938 .593 .17 r
.38853 .55849 m .38681 .55791 L .3878 .5586 L F
.38853 .55849 m .38681 .55791 L .3878 .5586 L F
.662 .968 .914 r
.39099 .55672 m .3878 .5586 L .38987 .5585 L F
.474 .037 .127 r
.3878 .5586 m .39157 .5577 L .3907 .55975 L F
.38926 .55974 m .3907 .55975 L .39034 .56059 L F
.3878 .5586 m .3907 .55975 L .38926 .55974 L F
.3878 .5586 m .39063 .56043 L .39157 .5577 L F
.523 .876 .986 r
.3892 .55709 m .3878 .5586 L .39099 .55672 L F
.087 .198 .685 r
.38819 .55818 m .39063 .56043 L .3878 .5586 L F
.3892 .55709 m .38965 .55814 L .38819 .55818 L F
.38965 .55814 m .39063 .56043 L .38819 .55818 L F
.29 .593 .947 r
.3878 .5586 m .38926 .55974 L .38761 .55918 L F
.38926 .55974 m .39034 .56059 L .38761 .55918 L F
.501 .403 .676 r
.35985 .61696 m .36002 .6202 L .35795 .62056 L F
.667 .145 0 r
.19814 .59728 m .20202 .59835 L .19999 .59843 L F
0 0 0 r
.20202 .59835 m .20207 .59867 L .19999 .59843 L F
.20202 .59835 m .20432 .59797 L .20207 .59867 L F
.719 .331 0 r
.42084 .55845 m .42036 .5569 L .41831 .55649 L F
.42084 .55845 m .42194 .56038 L .42036 .5569 L F
.628 .284 .368 r
.57726 .43768 m .58102 .43718 L .57996 .43954 L F
.616 .234 .296 r
.58102 .43718 m .58379 .43939 L .57996 .43954 L F
.58102 .43718 m .58331 .43776 L .58379 .43939 L F
.607 .458 .654 r
.58364 .43463 m .58331 .43776 L .58102 .43718 L F
.463 .332 .617 r
.31542 .57928 m .31595 .58212 L .31316 .582 L F
.078 0 .193 r
.31595 .58212 m .3136 .58498 L .31316 .582 L F
.882 .878 .826 r
.71079 .35394 m .70922 .356 L .70775 .35448 L F
.95 .856 .713 r
.70775 .35448 m .70922 .356 L .70799 .35835 L F
.751 .489 .535 r
.32661 .59553 m .32678 .59552 L .32716 .59455 L F
.32661 .59553 m .32581 .5979 L .32678 .59552 L F
.081 0 .276 r
.32581 .5979 m .32707 .59938 L .32678 .59552 L F
.078 .084 .561 r
.32678 .59552 m .32912 .59312 L .32716 .59455 L F
.32678 .59552 m .32963 .59621 L .32912 .59312 L F
.408 .187 .463 r
.32707 .59938 m .32963 .59621 L .32678 .59552 L F
.379 0 0 r
.71811 .29791 m .72125 .29867 L .71958 .29815 L F
.863 .574 .498 r
.35889 .54061 m .35588 .53809 L .35854 .53782 L F
.35889 .54061 m .35595 .54094 L .35588 .53809 L F
.892 .692 .626 r
.35889 .54061 m .35594 .5436 L .35595 .54094 L F
.156 .318 .776 r
.29322 .556 m .2948 .55921 L .29272 .55758 L F
.519 .324 .556 r
.2948 .55921 m .2915 .56105 L .29272 .55758 L F
.566 .481 .719 r
.32633 .5357 m .32868 .53611 L .32825 .53145 L F
.578 .436 .652 r
.32633 .5357 m .32649 .53865 L .32868 .53611 L F
.729 .26 .137 r
.33857 .52713 m .3404 .52584 L .33702 .52502 L F
0 0 0 r
.34351 .52307 m .3404 .52584 L .34172 .52496 L F
.262 0 .079 r
.33857 .52713 m .34172 .52496 L .3404 .52584 L F
.823 .894 .892 r
.3377 .53413 m .3421 .533 L .34011 .53333 L F
.294 .693 .975 r
.34283 .53475 m .34011 .53333 L .3421 .533 L F
.122 0 .398 r
.19374 .57648 m .19497 .57586 L .19536 .57289 L F
.141 .07 .508 r
.19396 .57918 m .19497 .57586 L .19374 .57648 L F
.491 .281 .521 r
.39803 .6837 m .39751 .68694 L .3955 .68756 L F
.471 .479 .784 r
.39876 .6823 m .39803 .6837 L .39706 .68038 L F
.221 .048 .422 r
.39963 .68565 m .39803 .6837 L .39876 .6823 L F
.39963 .68565 m .39751 .68694 L .39803 .6837 L F
.558 .869 .995 r
.33982 .67303 m .33687 .67294 L .33824 .67372 L F
.233 0 0 r
.34168 .67294 m .33982 .67303 L .33824 .67372 L F
.34168 .67294 m .34289 .67176 L .33982 .67303 L F
.06 .088 .576 r
.62224 .42698 m .62206 .42765 L .62107 .42489 L F
.62224 .42698 m .62107 .42489 L .61954 .42403 L F
.413 .228 .517 r
.30821 .6337 m .31028 .63602 L .31038 .63244 L F
0 0 .153 r
.36793 .60499 m .36837 .60332 L .36828 .60309 L F
0 0 0 r
.36814 .60274 m .36828 .60309 L .36982 .60189 L F
.642 .146 .057 r
.36828 .60309 m .37228 .6036 L .36982 .60189 L F
.572 .046 0 r
.36828 .60309 m .371 .60554 L .37228 .6036 L F
.36861 .60339 m .37057 .60541 L .371 .60554 L F
.36828 .60309 m .37057 .60541 L .36861 .60339 L F
0 0 .081 r
.37065 .60835 m .36902 .60941 L .36964 .6082 L F
.37065 .60835 m .36964 .6082 L .371 .60554 L F
.31 .309 .696 r
.37309 .60945 m .37065 .60835 L .37217 .60767 L F
0 .34 .76 r
.37136 .60845 m .37065 .60835 L .37309 .60945 L F
0 0 .081 r
.37065 .60835 m .371 .60554 L .37057 .60541 L F
.243 .151 .547 r
.37217 .60767 m .37065 .60835 L .37057 .60541 L F
0 .34 .76 r
.37028 .60783 m .37065 .60835 L .37136 .60845 L F
.36885 .60701 m .37065 .60835 L .37028 .60783 L F
.243 .151 .547 r
.37233 .60721 m .37057 .60541 L .37315 .60476 L F
.37217 .60767 m .37057 .60541 L .37233 .60721 L F
0 .183 .705 r
.36888 .60141 m .37057 .60541 L .36828 .60309 L F
0 0 .153 r
.36837 .60332 m .36888 .60141 L .36828 .60309 L F
0 0 0 r
.36767 .60298 m .36828 .60309 L .36814 .60274 L F
.36767 .60298 m .36558 .60368 L .36828 .60309 L F
.591 .161 .193 r
.71131 .32578 m .7137 .32623 L .71196 .32794 L F
.279 0 .061 r
.31242 .51466 m .31315 .51531 L .31448 .51308 L F
.672 .967 .924 r
.31448 .51308 m .31509 .51136 L .31718 .51096 L F
.605 .183 .214 r
.31448 .51308 m .31672 .51513 L .31509 .51136 L F
.31448 .51308 m .31315 .51531 L .31672 .51513 L F
.861 .79 .779 r
.72023 .30815 m .72255 .30464 L .71985 .30401 L F
.481 .324 .591 r
.24698 .55657 m .24477 .55443 L .24719 .55389 L F
.24698 .55657 m .24486 .55722 L .24477 .55443 L F
.973 .875 .677 r
.41532 .54828 m .41378 .5512 L .41292 .54967 L F
.684 .862 .967 r
.41715 .54721 m .41532 .54828 L .41363 .54707 L F
.968 .796 .616 r
.41532 .54828 m .41292 .54967 L .41363 .54707 L F
.274 .179 .561 r
.29495 .64161 m .29319 .63946 L .29508 .63921 L F
.159 .152 .6 r
.29495 .64161 m .29379 .64209 L .29319 .63946 L F
.815 .763 .805 r
.62876 .43395 m .6301 .43777 L .62652 .43725 L F
.791 .752 .817 r
.6329 .43452 m .6301 .43777 L .62876 .43395 L F
.513 .259 .467 r
.63288 .43962 m .6301 .43777 L .63024 .44062 L F
.589 .192 .258 r
.62947 .44009 m .6301 .43777 L .63288 .43962 L F
.791 .4 .314 r
.62652 .43725 m .6301 .43777 L .62947 .44009 L F
.882 .878 .826 r
.71079 .35394 m .70775 .35448 L .70948 .35165 L F
.665 .691 .865 r
.7122 .35015 m .71079 .35394 L .70948 .35165 L F
.7122 .35015 m .7135 .35256 L .71079 .35394 L F
.498 .527 .817 r
.3237 .60103 m .32455 .60401 L .32657 .60288 L F
.453 0 0 r
.32326 .62724 m .32647 .627 L .3247 .62856 L F
.1 0 0 r
.3247 .62856 m .32647 .627 L .32886 .6264 L F
.898 .803 .746 r
.69553 .31952 m .69506 .32439 L .69321 .323 L F
.885 .731 .686 r
.69506 .32439 m .69454 .32687 L .69321 .323 L F
.538 .311 .518 r
.19028 .60777 m .19275 .60753 L .19338 .60374 L F
0 0 .12 r
.19338 .60374 m .19388 .60577 L .19545 .60357 L F
.801 .583 .607 r
.30277 .52471 m .30689 .52259 L .30511 .52324 L F
.30277 .52471 m .30634 .52555 L .30689 .52259 L F
.48 .889 .766 r
.30917 .52128 m .30818 .52151 L .30689 .52259 L F
.479 .888 .759 r
.30818 .52151 m .30511 .52324 L .30689 .52259 L F
.863 .67 .64 r
.72136 .30158 m .72125 .29867 L .71811 .29791 L F
.75 .692 .795 r
.56622 .43186 m .56762 .4325 L .56453 .43392 L F
.664 .466 .606 r
.56762 .4325 m .5668 .43685 L .56453 .43392 L F
.53 .596 .865 r
.56938 .43233 m .56762 .4325 L .56622 .43186 L F
.601 .742 .943 r
.57562 .43308 m .57717 .43462 L .57347 .43402 L F
.762 .784 .871 r
.57965 .43221 m .57717 .43462 L .57562 .43308 L F
.146 .521 .917 r
.32919 .66321 m .33099 .66515 L .32922 .66445 L F
0 0 .149 r
.32781 .59185 m .32661 .59553 L .32716 .59455 L F
.808 .982 .894 r
.71004 .32783 m .71196 .32794 L .7137 .32623 L F
.271 0 .088 r
.62358 .41173 m .62717 .40876 L .62679 .41112 L F
.182 0 0 r
.62717 .40876 m .62879 .40975 L .62679 .41112 L F
.62717 .40876 m .63001 .40781 L .62879 .40975 L F
.75 .509 .568 r
.36388 .55743 m .36019 .55986 L .36036 .55723 L F
.36388 .55743 m .363 .56076 L .36019 .55986 L F
.009 0 .259 r
.36502 .55877 m .36388 .55743 L .36545 .55642 L F
.36502 .55877 m .363 .56076 L .36388 .55743 L F
.938 .683 .21 r
.68843 .34297 m .68828 .34452 L .68763 .34111 L F
.581 .205 .293 r
.68843 .34297 m .69107 .34459 L .68828 .34452 L F
.938 .683 .21 r
.68843 .34297 m .68828 .34452 L .68763 .34111 L F
.5 .282 .514 r
.69106 .34239 m .69107 .34459 L .68843 .34297 L F
.578 .384 .582 r
.37486 .58726 m .37571 .59255 L .37366 .59207 L F
.606 .382 .55 r
.38001 .58548 m .37907 .58734 L .37486 .58726 L F
.463 .231 .476 r
.37907 .58734 m .37571 .59255 L .37486 .58726 L F
.686 .833 .954 r
.38718 .65305 m .38491 .65442 L .38339 .65305 L F
.127 .379 .835 r
.21417 .60772 m .21515 .60659 L .21191 .6043 L F
.084 .312 .792 r
.21417 .60772 m .21712 .60948 L .21515 .60659 L F
.346 .525 .889 r
.21417 .60772 m .2178 .61044 L .21712 .60948 L F
.455 .27 .54 r
.22936 .57831 m .22691 .5766 L .2289 .57568 L F
.22936 .57831 m .22655 .57945 L .22691 .5766 L F
.624 .54 .74 r
.28401 .62959 m .28356 .6334 L .2824 .6335 L F
.786 .522 .538 r
.28356 .6334 m .28104 .63573 L .2824 .6335 L F
.069 0 .203 r
.29568 .59766 m .29402 .59867 L .29333 .6009 L F
.468 .827 .563 r
.32626 .6115 m .32326 .61398 L .32451 .61289 L F
0 0 0 r
.32626 .6115 m .32709 .61144 L .32843 .61164 L F
.32626 .6115 m .32451 .61289 L .32709 .61144 L F
.237 0 .072 r
.71345 .34395 m .71728 .34072 L .71379 .34119 L F
.506 .726 .972 r
.35635 .66054 m .35967 .66172 L .35809 .65879 L F
.647 .089 0 r
.62083 .42969 m .62168 .42961 L .61982 .42903 L F
.945 .787 .328 r
.62224 .43146 m .62215 .42957 L .62168 .42961 L F
.408 .613 .933 r
.62433 .43133 m .62224 .43146 L .62168 .42961 L F
.647 .089 0 r
.62391 .43168 m .62168 .42961 L .62083 .42969 L F
.945 .787 .328 r
.62215 .42957 m .62206 .42765 L .62168 .42961 L F
.839 .772 .787 r
.71276 .30207 m .71294 .30345 L .70866 .30374 L F
.842 .752 .763 r
.70866 .30374 m .71294 .30345 L .7106 .30512 L F
.091 0 0 r
.34505 .67109 m .34289 .67176 L .34168 .67294 L F
.594 .668 .891 r
.30943 .53768 m .30712 .53855 L .30665 .537 L F
.419 .747 .994 r
.30005 .53839 m .30454 .53979 L .30158 .538 L F
.142 0 0 r
.30115 .53811 m .30188 .5399 L .30085 .53822 L F
.579 .814 .988 r
.30185 .538 m .30454 .53979 L .30404 .53705 L F
.142 0 0 r
.30404 .53705 m .30085 .53822 L .30185 .538 L F
.30404 .53705 m .30375 .53744 L .30115 .53811 L F
.419 .747 .994 r
.30158 .538 m .30454 .53979 L .30185 .538 L F
.142 0 0 r
.30375 .53744 m .30188 .5399 L .30115 .53811 L F
.419 .747 .994 r
.29885 .53802 m .30005 .53839 L .30158 .538 L F
.581 .669 .899 r
.63203 .40083 m .6284 .39954 L .63147 .39856 L F
.587 .787 .975 r
.63375 .39873 m .63203 .40083 L .63147 .39856 L F
.63375 .39873 m .63523 .40022 L .63203 .40083 L F
.181 .665 .927 r
.34386 .5024 m .34772 .50329 L .34558 .50323 L F
.703 .626 .767 r
.38542 .58002 m .38117 .57728 L .38363 .57631 L F
.684 .659 .819 r
.38787 .5782 m .38542 .58002 L .38363 .57631 L F
.877 .8 .77 r
.69104 .32631 m .69191 .32992 L .68922 .32991 L F
.798 .549 .561 r
.69191 .32992 m .6882 .33196 L .68922 .32991 L F
.69191 .32992 m .69194 .33253 L .6882 .33196 L F
.806 .763 .812 r
.69454 .32687 m .69191 .32992 L .69104 .32631 L F
.691 .853 .96 r
.30279 .51944 m .29906 .51955 L .3013 .51861 L F
.884 .53 .371 r
.3258 .68919 m .32844 .69001 L .32896 .69277 L F
.336 .422 .802 r
.56849 .39938 m .57148 .40188 L .5745 .40264 L F
.495 .822 1 r
.27459 .52458 m .2705 .52412 L .27302 .52383 L F
.484 .842 .994 r
.27675 .52388 m .27459 .52458 L .27302 .52383 L F
.02 0 .058 r
.29162 .60197 m .29071 .60381 L .29333 .6009 L F
.391 .188 .48 r
.39699 .69126 m .39596 .69277 L .39377 .69323 L F
.383 .164 .453 r
.39596 .69277 m .39348 .69613 L .39377 .69323 L F
.879 .828 .793 r
.33245 .53709 m .33087 .53962 L .32895 .53825 L F
.141 0 0 r
.32966 .53874 m .33183 .53748 L .33118 .53706 L F
.33183 .53748 m .33357 .53646 L .33118 .53706 L F
.356 0 0 r
.33036 .53655 m .33118 .53706 L .32868 .53611 L F
.33245 .53709 m .33118 .53706 L .33036 .53655 L F
.436 .236 .509 r
.3656 .58784 m .36335 .58846 L .36354 .58586 L F
.3656 .58784 m .36335 .58846 L .36354 .58586 L F
0 0 0 r
.32326 .61398 m .32285 .6159 L .32451 .61289 L F
.573 .497 .731 r
.3937 .62173 m .39116 .62222 L .39379 .62178 L F
.3937 .62173 m .39167 .62413 L .39116 .62222 L F
.398 .286 .608 r
.35963 .59848 m .36155 .59813 L .36119 .5953 L F
.22 0 .1 r
.38578 .70283 m .38477 .70513 L .38261 .70523 L F
.067 0 0 r
.38795 .70199 m .38477 .70513 L .38578 .70283 L F
.141 .43 .869 r
.37636 .51427 m .37651 .51529 L .37361 .51393 L F
.595 .377 .555 r
.30428 .60685 m .30113 .60987 L .30203 .60737 L F
.556 .513 .763 r
.22743 .58456 m .22842 .58822 L .22604 .58872 L F
.338 0 .177 r
.22842 .58822 m .22536 .59035 L .22604 .58872 L F
.43 .83 .98 r
.31247 .55102 m .31448 .55049 L .31658 .55107 L F
0 .171 .708 r
.31804 .55149 m .31658 .55107 L .31448 .55049 L F
.49 .65 .929 r
.31922 .55097 m .31871 .55302 L .31804 .55149 L F
0 0 0 r
.31804 .55149 m .31836 .55314 L .31893 .55169 L F
.31804 .55149 m .31893 .55169 L .31922 .55097 L F
0 .171 .708 r
.31804 .55149 m .31871 .55302 L .31671 .5512 L F
.31804 .55149 m .31671 .5512 L .31658 .55107 L F
.283 .261 .658 r
.31658 .55107 m .31871 .55302 L .31699 .55395 L F
.807 .73 .78 r
.71267 .32296 m .71694 .32287 L .71575 .31995 L F
.81 .71 .755 r
.71267 .32296 m .7137 .32623 L .71694 .32287 L F
.446 .463 .783 r
.71694 .32287 m .71847 .31959 L .71575 .31995 L F
.71694 .32287 m .71901 .32208 L .71847 .31959 L F
.552 .567 .823 r
.59475 .42651 m .59123 .42496 L .59374 .42701 L F
.828 .65 .661 r
.56277 .43124 m .56453 .43392 L .56282 .43418 L F
.772 .461 .461 r
.56282 .43418 m .56453 .43392 L .56287 .43629 L F
.706 .623 .761 r
.56622 .43186 m .56453 .43392 L .56277 .43124 L F
.779 .471 .466 r
.56453 .43392 m .5668 .43685 L .56287 .43629 L F
.419 .32 .636 r
.28228 .62608 m .27971 .62363 L .2822 .62324 L F
.412 0 0 r
.36759 .71201 m .37048 .71148 L .37032 .7123 L F
.348 0 .065 r
.37048 .71148 m .37294 .71175 L .37032 .7123 L F
.435 .74 .991 r
.32895 .53825 m .33087 .53962 L .32766 .53891 L F
.204 0 0 r
.32728 .53925 m .32997 .53774 L .32895 .53825 L F
.32997 .53774 m .33118 .53706 L .32895 .53825 L F
.435 .74 .991 r
.32895 .53825 m .32766 .53891 L .32649 .53865 L F
.478 .228 .457 r
.3602 .57517 m .35729 .57811 L .3579 .57604 L F
.73 .783 .895 r
.6271 .39763 m .6284 .39954 L .62452 .39902 L F
.74 .786 .89 r
.63037 .39798 m .6284 .39954 L .6271 .39763 L F
.597 .494 .708 r
.63037 .39798 m .63147 .39856 L .6284 .39954 L F
.597 .41 .598 r
.32795 .57351 m .33057 .57304 L .33039 .57022 L F
.406 .134 .385 r
.33057 .57304 m .33334 .56991 L .33039 .57022 L F
.596 .535 .757 r
.39209 .61628 m .39116 .62222 L .38947 .61714 L F
0 0 .379 r
.30815 .6001 m .30716 .59838 L .30921 .59794 L F
.30815 .6001 m .3072 .60131 L .30716 .59838 L F
.702 .914 .968 r
.64088 .39828 m .63734 .39868 L .64028 .39596 L F
.618 .755 .944 r
.64237 .39532 m .64088 .39828 L .64028 .39596 L F
.64237 .39532 m .64382 .39757 L .64088 .39828 L F
.746 .527 .598 r
.36584 .51987 m .36903 .52208 L .36757 .51851 L F
.36584 .51987 m .36492 .52245 L .36903 .52208 L F
.978 .859 .473 r
.3934 .66195 m .39562 .6581 L .39593 .6621 L F
.262 .268 .677 r
.39783 .66031 m .39593 .6621 L .39562 .6581 L F
0 0 .43 r
.39783 .66031 m .39743 .66463 L .39593 .6621 L F
.697 .715 .863 r
.35827 .51859 m .35519 .51732 L .35693 .51557 L F
.151 0 .025 r
.36117 .51666 m .35693 .51557 L .35828 .51618 L F
.36117 .51666 m .35827 .51859 L .35693 .51557 L F
.36117 .51666 m .36121 .51752 L .35827 .51859 L F
0 0 0 r
.36121 .51752 m .35661 .52066 L .35827 .51859 L F
.538 .858 .566 r
.34637 .52032 m .3449 .52164 L .34785 .51885 L F
.507 .338 .587 r
.36043 .66443 m .36283 .66403 L .36072 .6616 L F
0 0 .063 r
.60664 .4125 m .60686 .41307 L .6058 .41089 L F
.60664 .4125 m .60655 .41494 L .60686 .41307 L F
.394 .097 .338 r
.39132 .69703 m .39059 .69891 L .38824 .69945 L F
.447 .221 .478 r
.39059 .69891 m .38795 .70199 L .38824 .69945 L F
.684 .648 .807 r
.61142 .39705 m .60789 .39583 L .61044 .3954 L F
.568 .698 .929 r
.61393 .39277 m .61142 .39705 L .61044 .3954 L F
.61393 .39277 m .61392 .39659 L .61142 .39705 L F
.474 .577 .878 r
.61544 .39958 m .61142 .39705 L .61392 .39659 L F
.883 .992 .766 r
.31257 .66101 m .31536 .65773 L .31532 .65766 L F
.577 .632 .869 r
.37893 .6517 m .37803 .65656 L .37758 .65452 L F
0 0 .238 r
.37893 .6517 m .37758 .65452 L .37798 .65174 L F
.923 .96 .643 r
.37893 .6517 m .37752 .65342 L .3791 .65164 L F
.577 .632 .869 r
.37893 .6517 m .38167 .65559 L .37803 .65656 L F
.791 .993 .766 r
.32759 .61741 m .33033 .61447 L .32801 .61569 L F
.694 .961 .944 r
.32389 .61704 m .32759 .61741 L .32801 .61569 L F
.446 .864 .949 r
.25756 .52641 m .25529 .5271 L .25308 .52678 L F
.448 .104 .288 r
.71575 .31995 m .71847 .31959 L .71896 .31731 L F
.617 .075 0 r
.29156 .64978 m .29509 .65275 L .29395 .65119 L F
.521 0 0 r
.28924 .64951 m .29156 .64978 L .29395 .65119 L F
.748 .91 .948 r
.33433 .66866 m .33856 .66778 L .3368 .66964 L F
.451 .158 .375 r
.33856 .66778 m .3409 .67176 L .3368 .66964 L F
.33856 .66778 m .34072 .66714 L .3409 .67176 L F
.682 .841 .959 r
.34559 .55312 m .3436 .55452 L .3419 .55332 L F
.832 .629 .629 r
.61184 .43107 m .61407 .4345 L .61226 .43346 L F
.955 .736 .569 r
.61226 .43346 m .61407 .4345 L .61363 .43677 L F
.269 0 .276 r
.39348 .69613 m .39059 .69891 L .39132 .69703 L F
.37 .495 .855 r
.31588 .645 m .31447 .64563 L .31226 .64187 L F
0 0 .447 r
.31552 .64754 m .31447 .64563 L .31588 .645 L F
.393 .351 .692 r
.22536 .59035 m .22416 .59474 L .22215 .59141 L F
.22536 .59035 m .22602 .59455 L .22416 .59474 L F
.319 .367 .755 r
.22702 .59738 m .22416 .59474 L .22602 .59455 L F
.071 .513 .898 r
.38247 .51897 m .38494 .52076 L .38175 .51969 L F
0 0 0 r
.29836 .59444 m .29693 .59571 L .29568 .59766 L F
.692 .275 .251 r
.62498 .44696 m .62514 .44865 L .62282 .44664 L F
.405 0 .012 r
.62904 .44692 m .62514 .44865 L .62498 .44696 L F
.522 .614 .885 r
.34493 .55743 m .34588 .557 L .34623 .55731 L F
.743 .972 .711 r
.34623 .55731 m .34588 .557 L .34853 .55424 L F
.227 .032 .394 r
.28864 .60475 m .29015 .60632 L .29071 .60381 L F
.28864 .60475 m .28824 .60732 L .29015 .60632 L F
.749 .321 .234 r
.40076 .60687 m .39958 .60522 L .40376 .60473 L F
0 0 0 r
.40588 .60142 m .40516 .60341 L .40376 .60473 L F
.218 0 .236 r
.40516 .60341 m .40076 .60687 L .40376 .60473 L F
.722 .942 .629 r
.63408 .43243 m .6352 .43178 L .6329 .43452 L F
.216 0 0 r
.63652 .43204 m .6352 .43178 L .63408 .43243 L F
.255 0 .014 r
.63771 .43102 m .6352 .43178 L .63652 .43204 L F
.877 .832 .799 r
.39287 .59111 m .39538 .59156 L .39699 .58904 L F
.989 .786 .395 r
.39542 .59521 m .39538 .59156 L .39555 .59327 L F
.8 .343 .153 r
.39555 .59327 m .39538 .59156 L .39287 .59111 L F
.44 .336 .64 r
.31871 .55302 m .3168 .55698 L .31699 .55395 L F
.628 .284 .368 r
.57726 .43768 m .57996 .43954 L .5772 .43978 L F
.878 .9 .843 r
.62118 .43518 m .62485 .43607 L .62391 .43168 L F
.455 .34 .634 r
.19375 .59247 m .19597 .59465 L .19599 .59169 L F
.188 .291 .739 r
.19484 .59484 m .19597 .59465 L .19375 .59247 L F
.363 0 0 r
.35286 .71239 m .35359 .71341 L .35325 .71317 L F
.338 0 0 r
.35061 .71188 m .3527 .71206 L .35286 .71239 L F
.363 0 0 r
.35286 .71239 m .35325 .71317 L .35078 .71137 L F
.338 0 0 r
.3527 .71206 m .35461 .71223 L .35286 .71239 L F
.686 .162 0 r
.35286 .71239 m .35461 .71223 L .35687 .71434 L F
.591 .682 .904 r
.57562 .43308 m .57347 .43402 L .57222 .43105 L F
.858 .94 .874 r
.35094 .5601 m .34966 .5595 L .3538 .55737 L F
0 0 .278 r
.35094 .5601 m .35307 .55904 L .34966 .5595 L F
.35094 .5601 m .35162 .56131 L .35307 .55904 L F
.35094 .5601 m .35167 .56318 L .35162 .56131 L F
.419 .226 .511 r
.64555 .42994 m .64527 .43363 L .64245 .43407 L F
.366 .072 .328 r
.64245 .43407 m .64476 .43562 L .64251 .43683 L F
.64245 .43407 m .64527 .43363 L .64476 .43562 L F
.861 .79 .779 r
.72023 .30815 m .71985 .30401 L .71955 .30717 L F
.586 .481 .7 r
.39875 .58605 m .39699 .58904 L .40028 .58838 L F
.483 .824 .536 r
.21755 .54801 m .21422 .55101 L .21567 .54969 L F
0 0 0 r
.21567 .54969 m .21909 .54715 L .21755 .54801 L F
.602 .294 .419 r
.37205 .57954 m .37089 .58177 L .36828 .58206 L F
.704 .514 .629 r
.3746 .5792 m .37089 .58177 L .37205 .57954 L F
.807 .581 .595 r
.72148 .33965 m .72087 .34211 L .72459 .34278 L F
.697 .789 .922 r
.72459 .34278 m .72087 .34211 L .72441 .34135 L F
.308 .685 .977 r
.72441 .34135 m .7281 .34244 L .72459 .34278 L F
.305 .799 .813 r
.26782 .52471 m .26412 .52553 L .26656 .52511 L F
.38 .832 .929 r
.2687 .52391 m .26782 .52471 L .26656 .52511 L F
.2687 .52391 m .2705 .52412 L .26782 .52471 L F
.331 .411 .793 r
.35983 .61188 m .3595 .61431 L .35834 .61078 L F
.36178 .61333 m .35834 .61078 L .36063 .61028 L F
.03 0 0 r
.36012 .61049 m .35834 .61078 L .35696 .61178 L F
.36063 .61028 m .36025 .61036 L .36012 .61049 L F
.36025 .61036 m .35834 .61078 L .36012 .61049 L F
.36 .61035 m .35696 .61178 L .35983 .61037 L F
.35997 .61054 m .35696 .61178 L .36 .61035 L F
0 0 0 r
.35834 .61078 m .35659 .61214 L .35696 .61178 L F
.35659 .61214 m .35503 .61336 L .35696 .61178 L F
.66 .972 .881 r
.35726 .61049 m .35983 .61037 L .35696 .61178 L F
0 0 .453 r
.35696 .61178 m .35834 .61349 L .35752 .61122 L F
.35696 .61178 m .35752 .61122 L .35726 .61049 L F
.851 .398 .116 r
.35904 .61147 m .35983 .61037 L .35726 .61049 L F
.35954 .61175 m .35973 .61084 L .35904 .61147 L F
.35973 .61084 m .35983 .61037 L .35904 .61147 L F
.03 0 0 r
.36063 .61028 m .35997 .61054 L .36 .61035 L F
.331 .411 .793 r
.36178 .61333 m .35956 .61428 L .35983 .61188 L F
.35956 .61428 m .3595 .61431 L .35983 .61188 L F
0 0 .367 r
.3606 .61549 m .3595 .61431 L .36178 .61333 L F
.3606 .61549 m .35985 .61696 L .3595 .61431 L F
.726 .26 .142 r
.37776 .61569 m .37681 .61309 L .37616 .61688 L F
.37776 .61569 m .37917 .61421 L .37681 .61309 L F
.942 .658 .197 r
.32895 .55333 m .33017 .55694 L .33288 .55358 L F
.32895 .55333 m .32908 .55561 L .33017 .55694 L F
.291 .062 .384 r
.30921 .59794 m .30965 .59541 L .31174 .59459 L F
0 .172 .709 r
.38494 .52076 m .38594 .52135 L .38571 .52273 L F
.931 .654 .493 r
.38594 .52135 m .38834 .52445 L .38571 .52273 L F
.979 .766 .352 r
.40645 .56829 m .40746 .56683 L .4061 .56586 L F
.40645 .56829 m .40724 .5695 L .40746 .56683 L F
.388 .219 .527 r
.33552 .56365 m .33535 .56605 L .33733 .56476 L F
.812 .836 .868 r
.60543 .3953 m .60521 .39923 L .60192 .39845 L F
.862 .785 .773 r
.60192 .39845 m .60521 .39923 L .60279 .4023 L F
.876 .885 .837 r
.60789 .39583 m .60521 .39923 L .60543 .3953 L F
.531 0 0 r
.33274 .64278 m .33698 .64574 L .3336 .64472 L F
.639 .089 0 r
.33627 .6464 m .33698 .64574 L .33778 .64734 L F
.3336 .64472 m .33459 .64502 L .33627 .6464 L F
.33459 .64502 m .33698 .64574 L .33627 .6464 L F
0 .354 .821 r
.3336 .64472 m .33778 .64734 L .33366 .64382 L F
0 .184 .669 r
.33366 .64382 m .33778 .64734 L .33747 .64696 L F
.908 .735 .656 r
.33747 .64696 m .34048 .64884 L .3391 .65059 L F
.497 .23 .44 r
.33776 .64762 m .33981 .64912 L .33747 .64696 L F
.3391 .65059 m .33975 .64924 L .33776 .64762 L F
.33975 .64924 m .33981 .64912 L .33776 .64762 L F
.626 .075 0 r
.33698 .64574 m .33747 .64696 L .33778 .64734 L F
.756 .534 .594 r
.34282 .64795 m .34223 .64817 L .33929 .64521 L F
.34223 .64817 m .34048 .64884 L .33992 .64713 L F
.34223 .64817 m .33992 .64713 L .33929 .64521 L F
.706 .423 .494 r
.3391 .65059 m .34048 .64884 L .34223 .64817 L F
.34233 .64826 m .34223 .64817 L .34282 .64795 L F
.864 .755 .741 r
.34082 .64826 m .34233 .64826 L .34282 .64795 L F
.34233 .64826 m .34321 .64826 L .34282 .64795 L F
.706 .423 .494 r
.34235 .64828 m .34233 .64826 L .34282 .64795 L F
.3391 .65059 m .34223 .64817 L .34235 .64828 L F
.506 .394 .661 r
.33929 .64521 m .34048 .64884 L .33698 .64574 L F
.863 .729 .713 r
.34235 .64828 m .34082 .64826 L .3391 .65059 L F
.764 .35 .266 r
.34246 .64828 m .34242 .64826 L .34082 .64826 L F
.863 .729 .713 r
.34282 .64795 m .34082 .64826 L .34235 .64828 L F
.764 .35 .266 r
.34299 .64852 m .34246 .64828 L .34082 .64826 L F
.34165 .65011 m .34285 .64869 L .34082 .64826 L F
.34285 .64869 m .34299 .64852 L .34259 .64847 L F
.34285 .64869 m .34259 .64847 L .34082 .64826 L F
.34299 .64852 m .34321 .64826 L .34242 .64826 L F
.497 .23 .44 r
.34163 .65012 m .34082 .64826 L .34165 .65011 L F
.3391 .65059 m .34037 .64886 L .34163 .65012 L F
.34037 .64886 m .34082 .64826 L .34163 .65012 L F
.626 .075 0 r
.33698 .64574 m .33928 .64777 L .33747 .64696 L F
.33928 .64777 m .34048 .64884 L .34012 .64861 L F
.33928 .64777 m .34012 .64861 L .33747 .64696 L F
.142 0 0 r
.35505 .57195 m .3587 .57002 L .35655 .56982 L F
.405 0 .012 r
.62904 .44692 m .62782 .44856 L .62514 .44865 L F
.453 0 .029 r
.63221 .44659 m .62782 .44856 L .62904 .44692 L F
0 0 0 r
.73326 .33937 m .73289 .34133 L .73173 .34306 L F
.84 .816 .333 r
.73289 .34133 m .73214 .34539 L .73173 .34306 L F
.979 .894 .668 r
.32801 .61569 m .33033 .61447 L .32906 .61333 L F
.726 .231 0 r
.36781 .50989 m .36912 .51178 L .36937 .51126 L F
.425 0 0 r
.36937 .51126 m .36912 .51178 L .37227 .51246 L F
.62 .112 .019 r
.35238 .55372 m .35441 .55535 L .35648 .55423 L F
.193 0 .306 r
.3587 .55624 m .36088 .55304 L .36054 .55552 L F
.3587 .55624 m .35911 .55632 L .35934 .5559 L F
.3587 .55624 m .35934 .5559 L .3597 .55523 L F
.561 .79 .985 r
.35993 .55541 m .36054 .55552 L .35975 .55527 L F
.305 .061 .369 r
.35993 .55541 m .35985 .55562 L .36007 .55549 L F
.561 .79 .985 r
.36006 .55551 m .36011 .55551 L .35993 .55541 L F
.36011 .55551 m .36054 .55552 L .35993 .55541 L F
.447 .232 .494 r
.35975 .55527 m .36054 .55552 L .36019 .55454 L F
.193 0 .306 r
.35949 .55508 m .3597 .55523 L .36088 .55304 L F
.35911 .55632 m .36046 .5541 L .36088 .55304 L F
.491 .256 .485 r
.35895 .55104 m .36019 .55454 L .36088 .55304 L F
.36019 .55454 m .36054 .55552 L .36088 .55304 L F
.561 .79 .985 r
.36011 .55551 m .3587 .55624 L .36054 .55552 L F
.193 0 .306 r
.36019 .55454 m .35954 .5564 L .36046 .5541 L F
.561 .79 .985 r
.35985 .55562 m .3587 .55624 L .36011 .55551 L F
.193 0 .306 r
.35911 .55632 m .35935 .55636 L .36019 .55454 L F
.35935 .55636 m .35954 .5564 L .36019 .55454 L F
.305 .061 .369 r
.36088 .55304 m .35993 .55541 L .36338 .5535 L F
.35993 .55541 m .36007 .55549 L .36338 .5535 L F
.35985 .55562 m .35954 .5564 L .36149 .55493 L F
.35985 .55562 m .36149 .55493 L .36338 .5535 L F
.561 .79 .985 r
.36006 .55551 m .35985 .55562 L .36011 .55551 L F
.193 0 .306 r
.3587 .55624 m .3597 .55523 L .35949 .55508 L F
.561 .79 .985 r
.35441 .55535 m .3587 .55624 L .36006 .55551 L F
.35441 .55535 m .36006 .55551 L .35648 .55423 L F
.36006 .55551 m .35975 .55527 L .35648 .55423 L F
.447 .232 .494 r
.35648 .55423 m .35975 .55527 L .35895 .55104 L F
.35975 .55527 m .36019 .55454 L .35895 .55104 L F
.459 .252 .511 r
.38471 .58455 m .38238 .58519 L .383 .58273 L F
.304 .121 .46 r
.35273 .614 m .35052 .61778 L .35266 .61704 L F
.469 .388 .683 r
.35052 .61778 m .35317 .6197 L .35266 .61704 L F
.689 .393 .468 r
.32326 .62724 m .3226 .62951 L .31967 .62875 L F
.453 0 0 r
.32326 .62724 m .3247 .62856 L .3226 .62951 L F
.588 .254 .371 r
.35895 .55104 m .36088 .55304 L .36183 .55127 L F
.07 0 .006 r
.29525 .61316 m .29354 .61389 L .29662 .61118 L F
.098 0 0 r
.29907 .61085 m .29525 .61316 L .29662 .61118 L F
.182 .711 .716 r
.29447 .52055 m .29906 .51955 L .29674 .52057 L F
.596 .55 .773 r
.22615 .56036 m .23055 .56229 L .2287 .55963 L F
.672 .7 .868 r
.36897 .55297 m .37118 .55467 L .37237 .55202 L F
.534 .568 .835 r
.36897 .55297 m .37292 .5571 L .37118 .55467 L F
0 0 .52 r
.37292 .5571 m .37237 .55202 L .37118 .55467 L F
.8 .735 .791 r
.25586 .61054 m .25353 .6138 L .25735 .614 L F
.502 .609 .891 r
.25735 .614 m .26041 .61459 L .25791 .61222 L F
.25735 .614 m .26041 .61459 L .25791 .61222 L F
.699 .235 0 r
.30019 .6539 m .30041 .65367 L .29936 .65261 L F
.76 .673 .766 r
.30041 .65367 m .3016 .65643 L .298 .65645 L F
.699 .235 0 r
.30111 .65532 m .30041 .65367 L .30019 .6539 L F
.543 .845 .529 r
.29875 .65534 m .30056 .65352 L .30041 .65367 L F
.30056 .65352 m .30204 .65203 L .30041 .65367 L F
.923 .607 .137 r
.30103 .65115 m .30204 .65203 L .30084 .64973 L F
.982 .899 .567 r
.30041 .65367 m .30204 .65203 L .30103 .65115 L F
0 .342 .739 r
.26186 .6328 m .26201 .63254 L .26004 .63194 L F
.26186 .6328 m .26391 .6337 L .26201 .63254 L F
.35 .217 .554 r
.19569 .5697 m .19751 .56916 L .19743 .56643 L F
.206 .067 .46 r
.19536 .57289 m .19751 .56916 L .19569 .5697 L F
.453 0 .029 r
.63221 .44659 m .63028 .44872 L .62782 .44856 L F
.291 0 0 r
.63479 .44601 m .63028 .44872 L .63221 .44659 L F
.408 .194 .474 r
.63479 .44365 m .63479 .44601 L .63221 .44659 L F
.83 .708 .73 r
.69321 .323 m .69454 .32687 L .69104 .32631 L F
.254 0 0 r
.72198 .31934 m .72551 .31754 L .72171 .31674 L F
.075 0 0 r
.2379 .53396 m .24222 .53182 L .23996 .53253 L F
0 0 0 r
.3449 .52164 m .34351 .52307 L .34172 .52496 L F
.772 .761 .844 r
.60158 .43067 m .60299 .43396 L .5992 .43364 L F
.639 .144 .06 r
.5992 .43364 m .60299 .43396 L .60173 .43546 L F
.592 .608 .837 r
.60424 .42975 m .60299 .43396 L .60158 .43067 L F
.60424 .42975 m .6055 .43322 L .60299 .43396 L F
.247 0 .017 r
.60299 .43396 m .6041 .43523 L .60173 .43546 L F
.60299 .43396 m .6055 .43322 L .6041 .43523 L F
.976 .807 .608 r
.29961 .63257 m .30032 .63001 L .29817 .63136 L F
.88 .991 .747 r
.29817 .63136 m .30032 .63001 L .30074 .62765 L F
0 .505 .846 r
.34922 .51157 m .35273 .51226 L .34886 .50963 L F
.256 .07 .426 r
.32781 .59185 m .33007 .59128 L .32926 .58836 L F
.377 .137 .418 r
.32926 .58836 m .33237 .59 L .33245 .58769 L F
.32926 .58836 m .33007 .59128 L .33237 .59 L F
0 0 .007 r
.33102 .54299 m .3307 .54223 L .33333 .54157 L F
.33102 .54299 m .33017 .54398 L .3307 .54223 L F
.187 0 .001 r
.3644 .63871 m .36207 .63951 L .36044 .64179 L F
.389 .051 .266 r
.235 .5698 m .23379 .57237 L .23142 .57292 L F
.364 .033 .265 r
.23702 .56924 m .23379 .57237 L .235 .5698 L F
.683 .236 .182 r
.29729 .62526 m .29922 .62353 L .29497 .62321 L F
.244 .312 .735 r
.30198 .6266 m .29922 .62353 L .30005 .62373 L F
.205 0 0 r
.30005 .62373 m .29922 .62353 L .29729 .62526 L F
.133 .618 .916 r
.33946 .57501 m .34225 .57631 L .33962 .57238 L F
.33946 .57501 m .3427 .576 L .34225 .57631 L F
.705 .618 .758 r
.31584 .51942 m .31944 .52018 L .31894 .51677 L F
.53 .493 .759 r
.31894 .51677 m .31944 .52018 L .32156 .51936 L F
.893 .49 .067 r
.38873 .52658 m .38939 .52592 L .38834 .52445 L F
.38873 .52658 m .39009 .52777 L .38939 .52592 L F
.98 .721 .321 r
.72141 .28763 m .72245 .28921 L .72152 .29015 L F
.6 .819 .984 r
.72283 .28296 m .72433 .2846 L .72179 .28482 L F
.574 .538 .777 r
.72433 .2846 m .72141 .28763 L .72179 .28482 L F
.5 .346 .604 r
.72179 .28482 m .72275 .28569 L .72283 .28296 L F
.574 .538 .777 r
.72433 .2846 m .72259 .28887 L .72272 .28627 L F
.72433 .2846 m .7254 .28846 L .72245 .28921 L F
.5 .346 .604 r
.72275 .28569 m .72419 .287 L .72288 .2831 L F
.72275 .28569 m .72288 .2831 L .72283 .28296 L F
.574 .538 .777 r
.72272 .28627 m .72245 .28921 L .72141 .28763 L F
.72259 .28887 m .72245 .28921 L .72272 .28627 L F
.558 .804 .991 r
.72245 .28921 m .72419 .287 L .72152 .29015 L F
.72245 .28921 m .7254 .28846 L .72419 .287 L F
.579 .522 .755 r
.33541 .57903 m .33622 .58362 L .33885 .58253 L F
.069 0 0 r
.3464 .59636 m .34349 .59844 L .34448 .59822 L F
.764 .881 .93 r
.34752 .59391 m .3464 .59636 L .34448 .59822 L F
.652 .172 .1 r
.34765 .60475 m .34714 .60587 L .34427 .60416 L F
.516 .362 .611 r
.34957 .60172 m .35015 .60434 L .34765 .60475 L F
.271 0 0 r
.34887 .6059 m .34765 .60475 L .35015 .60434 L F
.545 .416 .655 r
.35264 .60436 m .35041 .60707 L .35015 .60434 L F
.564 .442 .672 r
.35264 .60436 m .35317 .60694 L .35041 .60707 L F
0 .448 .808 r
.35139 .60648 m .34887 .6059 L .35254 .6069 L F
.34714 .60492 m .34887 .6059 L .35139 .60648 L F
.271 0 0 r
.34887 .6059 m .34714 .60587 L .34729 .60554 L F
.34887 .6059 m .34729 .60554 L .34765 .60475 L F
0 0 0 r
.24386 .55084 m .24377 .55118 L .24502 .55027 L F
.24386 .55084 m .24199 .5527 L .24377 .55118 L F
.238 .049 .409 r
.36304 .52819 m .36567 .52306 L .36355 .52551 L F
.697 .721 .868 r
.37167 .62661 m .37457 .6258 L .37385 .62325 L F
.287 0 0 r
.37438 .62662 m .37167 .62661 L .37145 .6289 L F
.37438 .62662 m .37457 .6258 L .37167 .62661 L F
.781 .676 .748 r
.33548 .63926 m .33813 .63623 L .33408 .63585 L F
.673 .141 0 r
.29509 .65275 m .29875 .65534 L .29716 .65558 L F
.29509 .65275 m .29716 .65558 L .29395 .65119 L F
0 0 .362 r
.28455 .63168 m .28356 .6334 L .28401 .62959 L F
0 0 .552 r
.28479 .63429 m .28356 .6334 L .28455 .63168 L F
.899 .667 .577 r
.30372 .54112 m .30591 .54234 L .3065 .54119 L F
.30372 .54112 m .3027 .54331 L .30591 .54234 L F
.925 .797 .701 r
.3027 .54331 m .30446 .54465 L .30591 .54234 L F
.73 .453 .508 r
.36567 .52306 m .36903 .52208 L .36492 .52245 L F
.36567 .52306 m .36866 .52491 L .36903 .52208 L F
.579 .605 .843 r
.36757 .51851 m .36903 .52208 L .37088 .52037 L F
.279 .064 .397 r
.36903 .52208 m .36866 .52491 L .37061 .52362 L F
0 0 0 r
.4071 .59998 m .40516 .60341 L .40588 .60142 L F
.745 .452 .485 r
.69483 .34274 m .69107 .34459 L .69106 .34239 L F
.69483 .34274 m .69493 .34509 L .69107 .34459 L F
.697 .467 .571 r
.69758 .34227 m .69493 .34509 L .69483 .34274 L F
.971 .715 .491 r
.40154 .55591 m .4034 .55684 L .40169 .55355 L F
.805 .331 0 r
.40154 .55591 m .40433 .55926 L .4034 .55684 L F
.649 .291 .351 r
.36768 .5603 m .36997 .5621 L .37041 .56009 L F
.36768 .5603 m .3663 .5628 L .36997 .5621 L F
.863 .67 .64 r
.72136 .30158 m .71811 .29791 L .71753 .30042 L F
.854 .626 .593 r
.71985 .30401 m .72136 .30158 L .71753 .30042 L F
0 0 .028 r
.28474 .54588 m .28268 .54791 L .28463 .54441 L F
0 0 0 r
.28673 .54249 m .28463 .54441 L .28755 .54122 L F
0 0 .029 r
.28673 .54249 m .28474 .54588 L .28463 .54441 L F
.692 .321 .341 r
.28268 .54791 m .27998 .55048 L .27853 .5494 L F
.442 .014 .129 r
.2833 .54939 m .28268 .54791 L .28474 .54588 L F
.2833 .54939 m .27998 .55048 L .28268 .54791 L F
.619 .494 .688 r
.32795 .57351 m .32826 .57629 L .33057 .57304 L F
.754 .334 .252 r
.34036 .65663 m .34257 .65504 L .33862 .65412 L F
.683 .948 .68 r
.3433 .65356 m .34257 .65504 L .34036 .65663 L F
.584 .324 .489 r
.2532 .61077 m .25586 .61054 L .2563 .60782 L F
.2532 .61077 m .25586 .61054 L .2563 .60782 L F
.53 .276 .475 r
.2563 .60782 m .25586 .61054 L .25843 .60993 L F
.25843 .60993 m .25586 .61054 L .2563 .60782 L F
.517 .365 .614 r
.24486 .55722 m .24502 .55987 L .24265 .5604 L F
.27 0 .147 r
.24502 .55987 m .24184 .56243 L .24265 .5604 L F
.326 .021 .285 r
.28988 .54041 m .28755 .54122 L .29034 .53856 L F
.521 .193 .352 r
.29034 .53856 m .29239 .54037 L .28988 .54041 L F
.534 .189 .329 r
.29281 .53843 m .29239 .54037 L .29034 .53856 L F
.044 0 0 r
.31463 .63871 m .31866 .63443 L .31708 .63821 L F
0 0 .096 r
.31866 .63443 m .31897 .63203 L .31827 .63514 L F
.716 .794 .316 r
.31708 .63821 m .31866 .63443 L .31827 .63514 L F
.914 .517 .137 r
.40464 .56481 m .40551 .56331 L .40428 .56245 L F
.40464 .56481 m .4061 .56586 L .40551 .56331 L F
0 0 0 r
.36553 .536 m .36341 .53659 L .361 .53719 L F
.502 0 0 r
.3674 .53712 m .36341 .53659 L .36553 .536 L F
.323 0 .178 r
.38261 .70523 m .38151 .70783 L .37916 .70843 L F
.41 .103 .33 r
.38477 .70513 m .38151 .70783 L .38261 .70523 L F
.132 .64 .9 r
.21991 .61023 m .21712 .60948 L .2178 .61044 L F
.312 .084 .398 r
.32688 .55421 m .32629 .55665 L .32895 .55333 L F
.715 .577 .699 r
.58586 .43342 m .58331 .43776 L .58364 .43463 L F
.492 .159 .329 r
.3653 .71183 m .36102 .71482 L .3612 .71194 L F
.849 .958 .616 r
.27969 .63882 m .28104 .63573 L .28185 .6386 L F
.451 .102 .282 r
.27969 .63882 m .28185 .6386 L .28126 .64098 L F
.432 .698 .977 r
.26933 .53293 m .27028 .53136 L .26794 .53183 L F
.26933 .53293 m .27216 .53288 L .27028 .53136 L F
.773 .375 .3 r
.41372 .54215 m .41152 .54339 L .41224 .54339 L F
.959 .715 .527 r
.41372 .54215 m .41225 .54287 L .41226 .53783 L F
.852 .62 .586 r
.41226 .53783 m .41225 .54287 L .40881 .53972 L F
.41225 .54287 m .41224 .54339 L .41195 .54308 L F
.41225 .54287 m .41195 .54308 L .40881 .53972 L F
.751 .614 .707 r
.41187 .54305 m .41182 .5431 L .41372 .54215 L F
.41182 .5431 m .41212 .54305 L .41372 .54215 L F
.41406 .54156 m .41225 .54287 L .41372 .54215 L F
.959 .715 .527 r
.41372 .54215 m .41224 .54339 L .41225 .54287 L F
.751 .614 .707 r
.41486 .54017 m .41509 .54438 L .41227 .5436 L F
.41182 .5431 m .41152 .54339 L .41212 .54305 L F
.41182 .5431 m .41194 .54324 L .41152 .54339 L F
.762 .894 .936 r
.41194 .54324 m .41152 .54339 L .40998 .54225 L F
.41224 .54339 m .41152 .54339 L .41194 .54324 L F
.751 .614 .707 r
.41194 .54324 m .41227 .5436 L .41152 .54339 L F
.762 .894 .936 r
.41195 .54308 m .41171 .54297 L .40892 .53984 L F
.41224 .54339 m .4117 .54312 L .41195 .54308 L F
.751 .614 .707 r
.41486 .54017 m .41187 .54305 L .41225 .54287 L F
.41486 .54017 m .41225 .54287 L .41406 .54156 L F
.41486 .54017 m .41227 .5436 L .41182 .5431 L F
.762 .894 .936 r
.40892 .53984 m .40998 .54225 L .40881 .53972 L F
.41171 .54297 m .40998 .54225 L .40892 .53984 L F
.4117 .54312 m .40998 .54225 L .41195 .54308 L F
0 0 0 r
.33857 .50471 m .33705 .50494 L .33425 .50516 L F
.072 .354 .826 r
.33882 .50252 m .33857 .50471 L .33633 .50414 L F
0 .397 .794 r
.33857 .50471 m .33956 .50463 L .33705 .50494 L F
.674 .45 .573 r
.24767 .61033 m .25076 .61119 L .24941 .60822 L F
.719 .469 .546 r
.24941 .60822 m .25076 .61119 L .2532 .61077 L F
.559 .415 .642 r
.39751 .68694 m .39699 .69126 L .3955 .68756 L F
.876 .885 .837 r
.60789 .39583 m .60543 .3953 L .60636 .39476 L F
.427 .79 .996 r
.61044 .3954 m .60789 .39583 L .60636 .39476 L F
.524 .609 .879 r
.28401 .62959 m .28084 .62835 L .28219 .62785 L F
.493 .813 1 r
.3801 .61262 m .37917 .61421 L .37776 .61569 L F
.3801 .61262 m .38181 .61365 L .37917 .61421 L F
.393 0 .017 r
.36117 .51666 m .36295 .51758 L .36121 .51752 L F
.685 .659 .818 r
.40934 .52345 m .40511 .52232 L .40761 .52451 L F
.136 .44 .876 r
.38025 .60776 m .38249 .61104 L .38254 .60898 L F
.822 .789 .289 r
.38254 .60898 m .38249 .61104 L .38181 .61365 L F
.069 .559 .894 r
.71728 .34072 m .72087 .34211 L .72148 .33965 L F
.309 .263 .643 r
.19396 .57918 m .19381 .58305 L .19604 .58119 L F
.208 .129 .542 r
.19381 .58305 m .1961 .58401 L .19604 .58119 L F
.19381 .58305 m .19424 .58546 L .1961 .58401 L F
.658 .613 .793 r
.32595 .5066 m .3298 .50964 L .32829 .50618 L F
.772 .742 .825 r
.32829 .50618 m .3298 .50964 L .33239 .50658 L F
.791 .752 .817 r
.6329 .43452 m .62876 .43395 L .63148 .433 L F
.722 .942 .629 r
.63408 .43243 m .6329 .43452 L .63148 .433 L F
.736 .569 .666 r
.59014 .43425 m .59331 .4339 L .5901 .43701 L F
.613 .381 .542 r
.59331 .4339 m .59334 .43713 L .5901 .43701 L F
.611 .423 .602 r
.59645 .43321 m .59334 .43713 L .59331 .4339 L F
.748 .903 .946 r
.31226 .5198 m .31584 .51942 L .31406 .51818 L F
.81 .862 .887 r
.31406 .51818 m .31584 .51942 L .31894 .51677 L F
0 0 .43 r
.39783 .66031 m .39782 .66395 L .39743 .66463 L F
0 0 .261 r
.39825 .66582 m .39743 .66463 L .39782 .66395 L F
.39825 .66582 m .39737 .66755 L .39743 .66463 L F
.825 .951 .901 r
.63385 .40915 m .63688 .40679 L .63445 .40628 L F
.718 .949 .953 r
.63445 .40628 m .63688 .40679 L .63892 .40518 L F
.825 .951 .901 r
.63385 .40915 m .63445 .40628 L .63263 .40807 L F
.082 0 .247 r
.21982 .54474 m .21909 .54715 L .22128 .54376 L F
.422 .787 .995 r
.33193 .66896 m .33214 .6678 L .3303 .66777 L F
.33193 .66896 m .33433 .66866 L .33214 .6678 L F
.492 .159 .329 r
.3653 .71183 m .36364 .71472 L .36102 .71482 L F
.604 .171 .191 r
.3653 .71183 m .36606 .71426 L .36364 .71472 L F
.3653 .71183 m .36759 .71201 L .36606 .71426 L F
.711 .288 .242 r
.62282 .44664 m .62142 .44832 L .62104 .44654 L F
.696 .269 .231 r
.62282 .44664 m .62514 .44865 L .62142 .44832 L F
.706 .623 .761 r
.56622 .43186 m .56277 .43124 L .56535 .43058 L F
.546 .69 .934 r
.56808 .4299 m .56622 .43186 L .56535 .43058 L F
.56808 .4299 m .56938 .43233 L .56622 .43186 L F
.492 .207 .409 r
.38223 .554 m .38495 .55361 L .38561 .55123 L F
0 0 .073 r
.38561 .55123 m .38619 .55189 L .38739 .55028 L F
.38561 .55123 m .38495 .55361 L .38619 .55189 L F
.75 .959 .939 r
.24554 .53989 m .24509 .54204 L .24778 .54192 L F
.24554 .53989 m .2437 .54138 L .24509 .54204 L F
.68 .797 .937 r
.56538 .39768 m .56237 .39931 L .56107 .39759 L F
.56538 .39768 m .56237 .39931 L .56107 .39759 L F
.593 .184 .237 r
.31562 .63215 m .31324 .63046 L .31307 .63203 L F
.58 .199 .285 r
.31562 .63215 m .31755 .63012 L .31324 .63046 L F
.465 .262 .519 r
.32416 .54209 m .32553 .54177 L .32649 .53865 L F
0 0 .09 r
.32649 .53865 m .32728 .53925 L .32895 .53825 L F
.32649 .53865 m .32553 .54177 L .32728 .53925 L F
.873 .549 .037 r
.3961 .53784 m .39663 .54003 L .39769 .54152 L F
.85 .56 .025 r
.39731 .54223 m .39769 .54152 L .39663 .54003 L F
.39731 .54223 m .39801 .54407 L .39769 .54152 L F
0 0 .423 r
.40102 .54906 m .40169 .55092 L .40007 .54728 L F
0 0 .25 r
.40102 .54906 m .40169 .55355 L .40169 .55092 L F
0 0 0 r
.29354 .61389 m .29215 .61597 L .29047 .61668 L F
.174 0 0 r
.29436 .61528 m .29354 .61389 L .29525 .61316 L F
.29436 .61528 m .29215 .61597 L .29354 .61389 L F
.286 .045 .362 r
.27344 .54992 m .27263 .55325 L .27039 .55336 L F
.268 0 .28 r
.27175 .55544 m .27039 .55336 L .27263 .55325 L F
.27175 .55544 m .26958 .55636 L .27039 .55336 L F
.688 .734 .886 r
.61715 .39552 m .61544 .39958 L .61392 .39659 L F
.61715 .39552 m .61806 .3989 L .61544 .39958 L F
.632 .446 .612 r
.61544 .39958 m .61806 .3989 L .61535 .40179 L F
.632 .484 .663 r
.38268 .5986 m .38524 .5982 L .38493 .59542 L F
.636 .506 .687 r
.38268 .5986 m .38285 .60134 L .38524 .5982 L F
.482 .254 .492 r
.73612 .33635 m .73593 .3385 L .73326 .33937 L F
.145 .093 .536 r
.73774 .33146 m .73612 .33635 L .73496 .33428 L F
.73774 .33146 m .73827 .33447 L .73612 .33635 L F
0 0 .118 r
.73827 .33447 m .73593 .3385 L .73612 .33635 L F
0 0 .023 r
.73456 .33914 m .73326 .33937 L .73593 .3385 L F
.73456 .33914 m .73289 .34133 L .73326 .33937 L F
0 0 .353 r
.37496 .56957 m .37428 .56933 L .37212 .56993 L F
.37496 .56957 m .37423 .57312 L .37493 .57217 L F
.37496 .56957 m .37493 .57217 L .37428 .56933 L F
.653 .834 .421 r
.301 .5886 m .2989 .59202 L .29995 .59015 L F
.131 0 .311 r
.2989 .59202 m .29981 .59347 L .29995 .59015 L F
.2989 .59202 m .29836 .59444 L .29981 .59347 L F
.814 .489 .439 r
.22785 .60202 m .23154 .60344 L .23235 .60137 L F
.122 0 .137 r
.23235 .60137 m .23154 .60344 L .23386 .60075 L F
.187 .714 .714 r
.31831 .53167 m .317 .53193 L .31439 .53256 L F
.06 .324 .806 r
.31688 .52905 m .31947 .53091 L .31831 .53167 L F
.38 .84 .778 r
.31947 .53091 m .317 .53193 L .31831 .53167 L F
.822 .531 .498 r
.60803 .42781 m .61184 .43107 L .60807 .43032 L F
.786 .688 .755 r
.60807 .43032 m .61184 .43107 L .60946 .43411 L F
.462 .241 .492 r
.60946 .43411 m .61184 .43107 L .61226 .43346 L F
.215 .265 .699 r
.35456 .62147 m .35552 .61906 L .35317 .6197 L F
.35456 .62147 m .35694 .62319 L .35552 .61906 L F
.731 .436 .48 r
.64791 .39906 m .64397 .40142 L .64519 .40188 L F
.756 .458 .48 r
.5668 .43685 m .57067 .43735 L .57074 .43961 L F
.711 .364 .387 r
.57067 .43735 m .57354 .43995 L .57074 .43961 L F
.663 .187 .113 r
.36733 .59149 m .37111 .5919 L .36923 .59367 L F
.4 0 0 r
.37111 .5919 m .37193 .5932 L .36923 .59367 L F
.37111 .5919 m .37366 .59207 L .37193 .5932 L F
.502 0 0 r
.21991 .61023 m .22428 .61077 L .22224 .611 L F
0 .125 .673 r
.22428 .61077 m .22631 .61281 L .22595 .61159 L F
.22428 .61077 m .22595 .61159 L .22224 .611 L F
.58 .183 .255 r
.31258 .65636 m .31099 .65485 L .31057 .65675 L F
.238 .545 .927 r
.30942 .65725 m .31004 .65823 L .31057 .65675 L F
0 0 0 r
.31057 .65675 m .30983 .65938 L .30882 .65977 L F
.684 .845 .425 r
.31057 .65675 m .30882 .65977 L .30903 .65913 L F
.395 .842 .925 r
.31218 .65593 m .31258 .65636 L .31057 .65675 L F
0 0 0 r
.31196 .65615 m .31057 .65675 L .30903 .65913 L F
.31218 .65593 m .31057 .65675 L .31196 .65615 L F
.238 .545 .927 r
.309 .65659 m .30942 .65725 L .31057 .65675 L F
0 0 0 r
.33123 .69616 m .3312 .69639 L .33128 .69746 L F
.3312 .69639 m .33094 .69901 L .33128 .69746 L F
0 .263 .77 r
.33128 .69746 m .33094 .69901 L .33336 .70086 L F
.759 .341 0 r
.33128 .69746 m .33195 .69856 L .33248 .69981 L F
.33195 .69856 m .33336 .70086 L .33248 .69981 L F
.783 .347 0 r
.33336 .70086 m .3335 .70228 L .33248 .69981 L F
0 0 .331 r
.33335 .70182 m .33248 .69981 L .3335 .70228 L F
.33231 .69866 m .33248 .69981 L .33335 .70182 L F
0 0 .445 r
.33128 .69746 m .33248 .69981 L .33231 .69866 L F
.33128 .69746 m .33231 .69866 L .33133 .69828 L F
.33128 .69746 m .33133 .69828 L .33045 .69794 L F
0 0 0 r
.33123 .69616 m .33128 .69746 L .3299 .69486 L F
.56 .416 .642 r
.35615 .52492 m .35283 .52222 L .35493 .52205 L F
.35615 .52492 m .35311 .52578 L .35283 .52222 L F
.053 .289 .779 r
.39498 .53355 m .39484 .53543 L .3931 .53192 L F
.637 .477 .65 r
.31917 .56637 m .32066 .5675 L .32259 .56666 L F
.936 .602 .164 r
.39249 .65893 m .39302 .66069 L .39168 .66006 L F
.39302 .66069 m .3934 .66195 L .39272 .6612 L F
.39302 .66069 m .39272 .6612 L .39168 .66006 L F
.675 .971 .79 r
.39089 .6631 m .3934 .66195 L .3902 .66454 L F
0 .166 .691 r
.39089 .6631 m .3915 .663 L .39182 .66271 L F
.966 .903 .707 r
.39168 .66006 m .3934 .66195 L .39089 .6631 L F
.936 .602 .164 r
.39249 .65893 m .39168 .66006 L .39414 .65737 L F
.842 .985 .705 r
.39203 .65887 m .39414 .65737 L .39168 .66006 L F
.554 .552 .806 r
.39348 .66259 m .3949 .65854 L .39203 .65887 L F
.39348 .66259 m .39614 .6623 L .3949 .65854 L F
.39348 .66259 m .39301 .66137 L .39438 .66143 L F
0 .166 .691 r
.39353 .66112 m .39361 .66108 L .39375 .66095 L F
.478 .402 .692 r
.39343 .6609 m .39375 .66095 L .39203 .65887 L F
.554 .552 .806 r
.39299 .66027 m .39203 .65887 L .39299 .65991 L F
.39301 .66137 m .39203 .65887 L .39299 .66027 L F
.39301 .66137 m .39299 .65991 L .39353 .66112 L F
.781 .693 .767 r
.39168 .66006 m .39089 .6631 L .39011 .6604 L F
.842 .985 .705 r
.39203 .65887 m .39168 .66006 L .39011 .6604 L F
.478 .402 .692 r
.39011 .6604 m .39343 .6609 L .39203 .65887 L F
.443 .483 .806 r
.39011 .6604 m .39089 .6631 L .39353 .66112 L F
.39343 .6609 m .39353 .66112 L .39375 .66095 L F
.39011 .6604 m .39353 .66112 L .39343 .6609 L F
0 .071 .626 r
.39375 .66095 m .39438 .66143 L .39203 .65887 L F
.554 .552 .806 r
.39353 .66112 m .39299 .65991 L .39392 .66093 L F
.457 0 0 r
.39368 .66101 m .39438 .66143 L .39375 .66095 L F
.554 .552 .806 r
.39301 .66137 m .39371 .66103 L .39438 .66143 L F
.457 0 0 r
.39291 .66172 m .39438 .66143 L .39368 .66101 L F
.554 .552 .806 r
.39371 .66103 m .39392 .66093 L .39438 .66143 L F
0 .166 .691 r
.39214 .66216 m .39182 .66271 L .39361 .66108 L F
.39214 .66216 m .39361 .66108 L .39353 .66112 L F
.39089 .6631 m .39182 .66271 L .39214 .66216 L F
.406 .134 .385 r
.33057 .57304 m .33279 .57242 L .33334 .56991 L F
.415 .143 .389 r
.33334 .56991 m .33521 .57205 L .33494 .56911 L F
.33334 .56991 m .33279 .57242 L .33521 .57205 L F
.157 .158 .608 r
.34448 .59822 m .34349 .59844 L .34518 .60049 L F
.479 .224 .448 r
.34518 .60049 m .34349 .59844 L .34266 .60084 L F
.718 .298 .248 r
.33624 .51206 m .34024 .51289 L .33776 .51397 L F
.616 .063 0 r
.30663 .5279 m .30908 .52992 L .30897 .52857 L F
.666 .315 .369 r
.30897 .52857 m .31109 .52914 L .31125 .5288 L F
.596 .622 .848 r
.24923 .61247 m .25113 .61465 L .25353 .6138 L F
.673 .438 .558 r
.36036 .55723 m .36019 .55986 L .35656 .55997 L F
.756 .798 .311 r
.40878 .59037 m .40864 .59118 L .40953 .58871 L F
.868 .81 .326 r
.40941 .58681 m .40878 .59037 L .40953 .58871 L F
.871 .465 .256 r
.33693 .70224 m .3363 .70432 L .33478 .70227 L F
.33693 .70224 m .3385 .70507 L .3363 .70432 L F
.773 .666 .745 r
.2641 .61404 m .26041 .61459 L .26276 .61052 L F
.58 .9 .984 r
.26213 .61339 m .26041 .61459 L .2641 .61404 L F
.551 .538 .793 r
.26541 .61012 m .2641 .61404 L .26276 .61052 L F
.26541 .61012 m .26643 .6135 L .2641 .61404 L F
.546 .887 .985 r
.26459 .61259 m .2641 .61404 L .26643 .6135 L F
.26459 .61259 m .26213 .61339 L .2641 .61404 L F
0 0 .501 r
.35571 .52775 m .35481 .5319 L .35302 .5284 L F
.35571 .52775 m .35603 .53131 L .35481 .5319 L F
.448 0 0 r
.35481 .5319 m .35679 .53264 L .35762 .53231 L F
.159 .418 .858 r
.35603 .53131 m .35679 .53264 L .35481 .5319 L F
.474 .031 .115 r
.36606 .71426 m .36759 .71201 L .36972 .71334 L F
.492 .003 .022 r
.36759 .71201 m .37032 .7123 L .36972 .71334 L F
.002 0 0 r
.21094 .55345 m .21277 .55301 L .21422 .55101 L F
0 0 0 r
.21422 .55101 m .21459 .55212 L .21567 .54969 L F
.21422 .55101 m .21277 .55301 L .21459 .55212 L F
.474 .157 .347 r
.33794 .64079 m .33548 .63926 L .33499 .64162 L F
.33794 .64079 m .33787 .63897 L .33548 .63926 L F
.326 .008 .264 r
.3212 .62037 m .31829 .62341 L .32086 .62288 L F
.675 .971 .79 r
.38938 .66147 m .38918 .66179 L .38885 .6609 L F
0 .141 .667 r
.39011 .6604 m .38885 .6609 L .39089 .6631 L F
.39089 .6631 m .38885 .6609 L .39011 .6604 L F
.622 .953 .791 r
.38782 .66128 m .38711 .66269 L .38994 .66053 L F
.38999 .66044 m .38994 .66053 L .39011 .6604 L F
.38782 .66128 m .38994 .66053 L .38999 .66044 L F
.675 .971 .79 r
.39089 .6631 m .3902 .66454 L .38918 .66179 L F
.39089 .6631 m .38918 .66179 L .38938 .66147 L F
.807 .633 .666 r
.56277 .43124 m .55885 .43309 L .5615 .42955 L F
.56277 .43124 m .56282 .43418 L .55885 .43309 L F
.573 .743 .957 r
.56535 .43058 m .56277 .43124 L .5615 .42955 L F
.715 .577 .699 r
.58586 .43342 m .58735 .43667 L .58331 .43776 L F
.65 .498 .664 r
.59014 .43425 m .58735 .43667 L .58586 .43342 L F
.755 .78 .874 r
.36541 .57206 m .36411 .56741 L .36281 .57005 L F
.401 .315 .643 r
.38493 .59542 m .38722 .59763 L .38719 .59473 L F
.38493 .59542 m .38524 .5982 L .38722 .59763 L F
.505 .267 .487 r
.321 .54512 m .32291 .54575 L .32416 .54209 L F
.413 .177 .444 r
.32416 .54209 m .32625 .54424 L .32553 .54177 L F
.32416 .54209 m .32291 .54575 L .32625 .54424 L F
.999 .796 .485 r
.3249 .54797 m .32346 .54932 L .32394 .54626 L F
.56 .733 .956 r
.32394 .54626 m .3249 .54797 L .32638 .54589 L F
.793 .536 .55 r
.60803 .42781 m .60424 .42975 L .60693 .42662 L F
.60803 .42781 m .60807 .43032 L .60424 .42975 L F
.528 .699 .948 r
.38117 .57728 m .37734 .57607 L .37954 .57552 L F
.626 .592 .795 r
.38363 .57631 m .38117 .57728 L .37954 .57552 L F
.344 0 .203 r
.29548 .54765 m .29784 .54706 L .29869 .54557 L F
.554 .509 .76 r
.29869 .54557 m .29945 .54025 L .29738 .54103 L F
.314 0 .101 r
.29784 .54706 m .302 .54508 L .29869 .54557 L F
.316 .185 .539 r
.35392 .59701 m .35198 .595 L .35441 .59445 L F
.35392 .59701 m .35213 .59765 L .35198 .595 L F
.749 .321 .234 r
.40076 .60687 m .39985 .60699 L .39958 .60522 L F
.45 .276 .553 r
.34578 .61146 m .34826 .61313 L .34819 .61021 L F
.34578 .61146 m .34826 .61313 L .34819 .61021 L F
.874 .846 .813 r
.35224 .66325 m .3537 .66439 L .35635 .66054 L F
.706 .763 .896 r
.68968 .33582 m .68725 .33726 L .6858 .33517 L F
.514 .343 .587 r
.35266 .61704 m .35503 .61336 L .35273 .614 L F
.257 .766 .767 r
.31109 .52914 m .31499 .52811 L .31125 .5288 L F
.744 .819 .91 r
.34393 .6647 m .34729 .66467 L .34596 .66348 L F
.365 .672 .975 r
.34596 .66348 m .34729 .66467 L .34885 .66403 L F
.263 .324 .739 r
.34729 .66467 m .34947 .6669 L .34885 .66403 L F
.623 .333 .457 r
.58331 .43776 m .58735 .43667 L .58622 .43996 L F
.65 .498 .664 r
.59014 .43425 m .5901 .43701 L .58735 .43667 L F
.632 .293 .378 r
.58735 .43667 m .58992 .43882 L .58622 .43996 L F
.58735 .43667 m .5901 .43701 L .58992 .43882 L F
.839 .772 .787 r
.71276 .30207 m .70866 .30374 L .7111 .30039 L F
.783 .749 .822 r
.71375 .29734 m .71276 .30207 L .7111 .30039 L F
.71375 .29734 m .71546 .29934 L .71276 .30207 L F
.439 .121 .327 r
.38238 .58519 m .37907 .58734 L .38001 .58548 L F
0 0 0 r
.39843 .67894 m .39706 .68038 L .3994 .67708 L F
.429 .426 .754 r
.39843 .67894 m .39969 .68184 L .39706 .68038 L F
.471 .479 .784 r
.39876 .6823 m .39706 .68038 L .39969 .68184 L F
.55 .771 .98 r
.60946 .43411 m .6055 .43322 L .60807 .43032 L F
.6055 .43322 m .60946 .43411 L .60958 .43654 L F
.476 .277 .531 r
.60958 .43654 m .60946 .43411 L .61226 .43346 L F
.60958 .43654 m .60946 .43411 L .61226 .43346 L F
.206 .067 .46 r
.19536 .57289 m .19738 .57174 L .19751 .56916 L F
.285 .114 .465 r
.19536 .57289 m .19741 .57451 L .19738 .57174 L F
.19536 .57289 m .19497 .57586 L .19741 .57451 L F
0 0 0 r
.34832 .57646 m .34742 .57859 L .34938 .57483 L F
.36761 .66283 m .36738 .66266 L .36521 .66306 L F
.36761 .66283 m .36941 .66122 L .36738 .66266 L F
.359 .454 .822 r
.28509 .63597 m .28816 .63766 L .28874 .6356 L F
.137 0 .164 r
.29027 .63481 m .28874 .6356 L .28816 .63766 L F
.895 .498 .256 r
.42219 .57294 m .4202 .5721 L .41928 .56947 L F
.962 .686 .467 r
.42219 .57294 m .42036 .57447 L .4202 .5721 L F
.42219 .57294 m .42215 .57549 L .42036 .57447 L F
.308 .445 .836 r
.42219 .57294 m .42465 .57378 L .42356 .57101 L F
.609 .696 .905 r
.24024 .60165 m .24207 .60397 L .239 .60101 L F
.24227 .60269 m .24214 .60347 L .24024 .60165 L F
.24214 .60347 m .24207 .60397 L .24024 .60165 L F
.704 .7 .843 r
.239 .60101 m .2405 .60228 L .24024 .60165 L F
.239 .60101 m .24024 .60165 L .2391 .59892 L F
0 0 .519 r
.23867 .59708 m .239 .60101 L .2391 .59892 L F
.564 .503 .746 r
.23947 .60091 m .2391 .59892 L .24024 .60165 L F
.625 .632 .837 r
.23947 .60091 m .239 .60101 L .2391 .59892 L F
.564 .503 .746 r
.23871 .60018 m .2391 .59892 L .23947 .60091 L F
.625 .632 .837 r
.24265 .60019 m .23947 .60091 L .2391 .59892 L F
.609 .696 .905 r
.24265 .60019 m .24227 .60269 L .239 .60101 L F
.607 .705 .914 r
.239 .60101 m .23762 .6037 L .2405 .60228 L F
.564 .503 .746 r
.23762 .6037 m .23871 .60018 L .2405 .60228 L F
.23871 .60018 m .24024 .60165 L .2405 .60228 L F
.609 .696 .905 r
.24265 .60019 m .24487 .60319 L .24207 .60397 L F
.593 .559 .785 r
.24487 .60319 m .24488 .60488 L .24207 .60397 L F
.528 .343 .574 r
.24207 .60397 m .24487 .60319 L .24488 .60488 L F
.24207 .60397 m .24165 .60699 L .24487 .60319 L F
.559 .739 .96 r
.28128 .53003 m .28552 .53172 L .28286 .52923 L F
.709 .788 .913 r
.28286 .52923 m .28552 .53172 L .28696 .5293 L F
.593 .518 .739 r
.28552 .53172 m .28746 .53109 L .28696 .5293 L F
.28552 .53172 m .28592 .532 L .28746 .53109 L F
.95 .856 .713 r
.70775 .35448 m .70799 .35835 L .70684 .357 L F
0 0 .556 r
.70799 .35835 m .70933 .35918 L .70684 .357 L F
.70799 .35835 m .70888 .35945 L .70933 .35918 L F
.966 .766 .584 r
.71227 .32416 m .7137 .32623 L .71267 .32296 L F
.808 .982 .894 r
.71004 .32783 m .7137 .32623 L .71227 .32416 L F
.465 .068 .202 r
.33141 .51925 m .32818 .52078 L .32894 .5198 L F
0 0 .436 r
.60686 .41307 m .60655 .41494 L .60753 .41705 L F
.273 0 .14 r
.59612 .4272 m .59773 .42442 L .59475 .42651 L F
.593 .576 .804 r
.59635 .42101 m .60006 .42105 L .59865 .42237 L F
.59635 .42101 m .59773 .42442 L .60006 .42105 L F
.654 .298 .357 r
.60007 .42742 m .59773 .42442 L .59612 .4272 L F
.191 .032 .423 r
.63649 .44477 m .63479 .44365 L .63706 .4428 L F
.63649 .44477 m .63479 .44601 L .63479 .44365 L F
.495 .332 .589 r
.30452 .56031 m .30719 .55677 L .30423 .55743 L F
.032 0 0 r
.28988 .54041 m .28673 .54249 L .28755 .54122 L F
.546 .429 .671 r
.35203 .60057 m .35015 .60434 L .34957 .60172 L F
0 .345 .768 r
.36627 .50869 m .36637 .50923 L .3648 .50791 L F
.36627 .50869 m .36781 .50989 L .36637 .50923 L F
0 0 0 r
.39594 .59959 m .39833 .59898 L .39872 .59829 L F
0 0 .527 r
.30069 .5861 m .301 .5886 L .30192 .58803 L F
.263 0 .296 r
.29995 .59015 m .30192 .58803 L .301 .5886 L F
.767 .756 .242 r
.36653 .5414 m .3674 .53712 L .3696 .53879 L F
.36653 .5414 m .36654 .54042 L .3674 .53712 L F
.222 .248 .677 r
.36653 .5414 m .36752 .54432 L .36868 .54335 L F
.66 .194 .135 r
.36868 .54335 m .36487 .54298 L .36653 .5414 L F
.532 .798 .994 r
.33687 .67294 m .33281 .67304 L .33472 .67314 L F
.26 .094 .456 r
.33281 .67304 m .3347 .67595 L .33472 .67314 L F
.33281 .67304 m .33229 .67611 L .3347 .67595 L F
.592 .445 .651 r
.38285 .60134 m .38641 .60146 L .38524 .5982 L F
.426 .339 .655 r
.38285 .60134 m .38542 .6039 L .38641 .60146 L F
.38285 .60134 m .38335 .6046 L .38542 .6039 L F
0 0 .297 r
.31339 .59089 m .31174 .59459 L .31215 .59197 L F
0 0 .037 r
.27769 .54413 m .2796 .54326 L .28035 .54096 L F
.316 .365 .755 r
.28035 .54096 m .28263 .54047 L .28167 .53743 L F
.169 0 .101 r
.28035 .54096 m .28169 .54229 L .28263 .54047 L F
.28035 .54096 m .2796 .54326 L .28169 .54229 L F
.697 .467 .571 r
.69758 .34227 m .69809 .34493 L .69493 .34509 L F
.697 .528 .655 r
.70098 .34176 m .69809 .34493 L .69758 .34227 L F
.425 .865 .906 r
.27904 .52335 m .28366 .52231 L .28351 .52264 L F
.626 .903 .601 r
.28351 .52264 m .28424 .5215 L .28588 .52202 L F
.28351 .52264 m .28366 .52231 L .28424 .5215 L F
0 0 0 r
.36897 .55297 m .36545 .55642 L .3664 .55441 L F
.657 .104 0 r
.27371 .75444 m .27106 .75267 L .27248 .75329 L F
.931 .856 .745 r
.27115 .75624 m .27371 .75444 L .27248 .75329 L F
.258 .104 .472 r
.23926 .56542 m .23702 .56924 L .23706 .56671 L F
.721 .828 .377 r
.6484 .42453 m .64988 .42139 L .64899 .4228 L F
.954 .62 .225 r
.64899 .4228 m .64988 .42139 L .64827 .41966 L F
.496 .852 .992 r
.39677 .65692 m .39562 .6581 L .39414 .65737 L F
.105 .234 .714 r
.39677 .65692 m .39783 .66031 L .39562 .6581 L F
.496 .852 .992 r
.39677 .65692 m .39562 .6581 L .39414 .65737 L F
.533 .252 .434 r
.70381 .33936 m .70334 .34149 L .70098 .34176 L F
0 0 .14 r
.70508 .33956 m .70381 .33936 L .70584 .33856 L F
.70508 .33956 m .70334 .34149 L .70381 .33936 L F
.894 .831 .364 r
.70488 .33848 m .70434 .34053 L .70508 .33956 L F
0 0 0 r
.70427 .34078 m .70268 .34272 L .70508 .33956 L F
.894 .831 .364 r
.70434 .34053 m .70427 .34078 L .70508 .33956 L F
0 0 .14 r
.70508 .33956 m .70584 .33856 L .70623 .33841 L F
.72 .317 .284 r
.56393 .40831 m .56774 .40882 L .56704 .4102 L F
.954 .666 .226 r
.56667 .40736 m .56774 .40882 L .56652 .40498 L F
.997 .798 .442 r
.56704 .4102 m .56774 .40882 L .56667 .40736 L F
.862 .789 .778 r
.31672 .51513 m .32123 .51322 L .31949 .51261 L F
.31672 .51513 m .31894 .51677 L .32123 .51322 L F
0 0 .433 r
.32015 .51018 m .32123 .51322 L .31938 .50923 L F
.875 .933 .856 r
.32015 .51018 m .31949 .51261 L .32123 .51322 L F
0 0 .527 r
.30069 .5861 m .30192 .58803 L .30304 .58499 L F
0 0 0 r
.64757 .42743 m .64627 .42972 L .64555 .42994 L F
.298 .129 .475 r
.64725 .43243 m .64555 .42994 L .64627 .42972 L F
.64725 .43243 m .64527 .43363 L .64555 .42994 L F
0 0 0 r
.32716 .59455 m .33007 .59128 L .32781 .59185 L F
.142 .495 .906 r
.321 .54512 m .32394 .54626 L .32291 .54575 L F
.157 .338 .794 r
.37385 .62325 m .37457 .6258 L .37631 .62528 L F
0 0 0 r
.37631 .62528 m .37457 .6258 L .37438 .62662 L F
.825 .406 .244 r
.35693 .51557 m .35316 .51277 L .35734 .51301 L F
.507 .533 .817 r
.34592 .57495 m .34262 .5761 L .3427 .576 L F
.34592 .57495 m .34742 .57859 L .34262 .5761 L F
.044 .006 .484 r
.32304 .66449 m .32211 .66646 L .32225 .66622 L F
.217 .406 .834 r
.29687 .64525 m .29379 .64209 L .29495 .64161 L F
0 0 .43 r
.33274 .64278 m .33366 .64382 L .33499 .64162 L F
.33274 .64278 m .3336 .64472 L .33366 .64382 L F
.219 0 .198 r
.3599 .53093 m .36304 .52819 L .36066 .52905 L F
.788 .622 .675 r
.31562 .63215 m .31967 .62875 L .31755 .63012 L F
.905 .914 .816 r
.35939 .5464 m .35904 .54835 L .36162 .54551 L F
.794 .992 .881 r
.36245 .54381 m .35939 .5464 L .36162 .54551 L F
.717 .73 .86 r
.40351 .51912 m .40511 .52232 L .40106 .52172 L F
.765 .627 .707 r
.40511 .52232 m .40233 .52494 L .40106 .52172 L F
.386 .546 .892 r
.40662 .52079 m .40511 .52232 L .40351 .51912 L F
.553 .004 0 r
.40571 .5233 m .40761 .52451 L .40511 .52232 L F
.40571 .5233 m .40511 .52232 L .40662 .52079 L F
.89 .47 .178 r
.71168 .34573 m .71221 .34802 L .7107 .34659 L F
0 0 0 r
.71168 .34573 m .71293 .3456 L .71345 .34395 L F
.71168 .34573 m .7107 .34659 L .71293 .3456 L F
.296 0 .129 r
.37686 .709 m .3781 .7102 L .37577 .7108 L F
.37686 .709 m .37916 .70843 L .3781 .7102 L F
.955 .718 .54 r
.35663 .64112 m .35919 .64229 L .35861 .6452 L F
0 0 .253 r
.36044 .64179 m .35919 .64229 L .35861 .6452 L F
.35861 .6452 m .35919 .64229 L .36044 .64179 L F
.1 0 .353 r
.34455 .56284 m .34271 .56654 L .34075 .56284 L F
.34455 .56284 m .34412 .56628 L .34271 .56654 L F
.173 .292 .746 r
.34412 .56628 m .34492 .56912 L .34271 .56654 L F
.513 .392 .652 r
.34492 .56912 m .34292 .56988 L .34271 .56654 L F
0 .159 .685 r
.35722 .62981 m .35667 .62971 L .35864 .63171 L F
.275 .22 .613 r
.35667 .62971 m .35668 .6333 L .35864 .63171 L F
.405 .143 .399 r
.6397 .43966 m .63982 .43752 L .64251 .43683 L F
.623 .801 .968 r
.32209 .50828 m .32342 .50981 L .31938 .50923 L F
0 0 .433 r
.32015 .51018 m .31938 .50923 L .32342 .50981 L F
.874 .846 .813 r
.35224 .66325 m .35635 .66054 L .35461 .66009 L F
.965 .834 .663 r
.32209 .50828 m .32015 .51018 L .32342 .50981 L F
.506 .726 .972 r
.35635 .66054 m .35809 .65879 L .35461 .66009 L F
.41 .588 .915 r
.3965 .67222 m .39802 .6746 L .39541 .67422 L F
.366 .033 .262 r
.32477 .51606 m .32593 .51495 L .32536 .51461 L F
.32477 .51606 m .32624 .5178 L .32593 .51495 L F
.32477 .51606 m .32368 .51852 L .32624 .5178 L F
0 0 0 r
.30421 .65699 m .30518 .6563 L .30664 .65594 L F
.385 .847 .864 r
.41401 .52679 m .41131 .52761 L .41144 .52796 L F
.492 .317 .572 r
.28557 .53432 m .28746 .53109 L .28592 .532 L F
.207 .562 .936 r
.36594 .65784 m .36629 .65651 L .36459 .65649 L F
.36594 .65784 m .36787 .658 L .36629 .65651 L F
.649 .795 .952 r
.37148 .5376 m .3696 .53879 L .3674 .53712 L F
.342 .76 .977 r
.28823 .52131 m .29233 .52195 L .28998 .52213 L F
0 0 0 r
.36897 .55297 m .36751 .55561 L .36545 .55642 L F
.653 .52 .688 r
.36751 .55561 m .36502 .55877 L .36545 .55642 L F
.623 .333 .457 r
.58331 .43776 m .58622 .43996 L .58379 .43939 L F
.171 0 .35 r
.20568 .55996 m .20764 .55929 L .20804 .55674 L F
.273 0 .2 r
.20568 .55996 m .20704 .56171 L .20764 .55929 L F
.20568 .55996 m .20484 .56248 L .20704 .56171 L F
.862 .785 .773 r
.60192 .39845 m .60279 .4023 L .60177 .40065 L F
0 0 .437 r
.60279 .4023 m .60384 .40309 L .60177 .40065 L F
.60279 .4023 m .60362 .40441 L .60384 .40309 L F
.224 0 .189 r
.20804 .55674 m .21016 .55599 L .21094 .55345 L F
.104 0 .142 r
.21094 .55345 m .21191 .5551 L .21277 .55301 L F
.21094 .55345 m .21016 .55599 L .21191 .5551 L F
.718 .497 .589 r
.71134 .32255 m .7127 .3204 L .70889 .3196 L F
.71134 .32255 m .71267 .32296 L .7127 .3204 L F
.807 .73 .78 r
.71267 .32296 m .71575 .31995 L .7127 .3204 L F
.186 0 .159 r
.28369 .61416 m .28303 .61596 L .28577 .61326 L F
.471 .017 .089 r
.2915 .56105 m .2936 .5619 L .29124 .56194 L F
.43 .171 .417 r
.2948 .55921 m .2936 .5619 L .2915 .56105 L F
.094 .353 .822 r
.39802 .6746 m .40011 .67563 L .3994 .67708 L F
0 0 .376 r
.40011 .67563 m .39843 .67894 L .3994 .67708 L F
.587 .506 .731 r
.21888 .56079 m .22061 .56302 L .21968 .5623 L F
.561 .042 0 r
.38785 .54699 m .38544 .54752 L .38321 .54693 L F
.641 .155 .082 r
.38785 .54699 m .38596 .54837 L .38544 .54752 L F
.398 .201 .493 r
.38785 .54699 m .38739 .55028 L .38959 .54946 L F
.38785 .54699 m .38959 .54946 L .38596 .54837 L F
.731 .436 .48 r
.64791 .39906 m .6487 .40159 L .64397 .40142 L F
.498 .658 .932 r
.64939 .39687 m .64791 .39906 L .64687 .39712 L F
.284 .365 .771 r
.64939 .39687 m .65142 .40201 L .64791 .39906 L F
.61 .368 .525 r
.64791 .39906 m .65142 .40201 L .6487 .40159 L F
.64791 .39906 m .65142 .40201 L .6487 .40159 L F
.392 .247 .562 r
.39399 .61049 m .39447 .61373 L .39216 .61393 L F
.597 .534 .754 r
.39447 .61373 m .39209 .61628 L .39216 .61393 L F
.591 .774 .967 r
.33345 .66421 m .33099 .66515 L .32919 .66321 L F
.675 .729 .22 r
.57148 .40188 m .57039 .40527 L .57273 .40532 L F
.671 .586 .752 r
.2526 .63328 m .25408 .63447 L .25787 .63294 L F
.601 .952 .877 r
.24896 .52941 m .24842 .52856 L .25098 .52808 L F
.24896 .52941 m .24652 .52986 L .24842 .52856 L F
.141 .07 .508 r
.19396 .57918 m .19516 .57849 L .19497 .57586 L F
.229 .251 .677 r
.19396 .57918 m .19604 .58119 L .19516 .57849 L F
.771 .688 .771 r
.572 .41447 m .57304 .41824 L .56948 .4182 L F
.613 .85 .989 r
.56948 .4182 m .57304 .41824 L .5718 .41703 L F
.995 .755 .433 r
.5718 .41703 m .57304 .41824 L .572 .41447 L F
.842 .469 0 r
.34266 .60084 m .34427 .60416 L .34354 .60345 L F
0 .313 .772 r
.34427 .60416 m .34714 .60587 L .3458 .60435 L F
.995 .807 .543 r
.35479 .64694 m .35642 .64591 L .35539 .64474 L F
.873 .475 .014 r
.41928 .56947 m .41886 .57071 L .41769 .56812 L F
.41928 .56947 m .4202 .5721 L .41886 .57071 L F
.3 0 .147 r
.34886 .50963 m .34556 .51223 L .34656 .51044 L F
.74 .786 .89 r
.63037 .39798 m .6271 .39763 L .63035 .39658 L F
.291 .523 .905 r
.63216 .39669 m .63037 .39798 L .63035 .39658 L F
.63216 .39669 m .63147 .39856 L .63037 .39798 L F
.451 .741 .99 r
.35232 .50274 m .35164 .50453 L .34996 .50298 L F
.35232 .50274 m .35431 .50417 L .35164 .50453 L F
.248 .504 .901 r
.25158 .63233 m .2526 .63328 L .2521 .63075 L F
.448 .669 .957 r
.2526 .63328 m .2561 .6324 L .2521 .63075 L F
.671 .586 .752 r
.2526 .63328 m .25787 .63294 L .2561 .6324 L F
.723 .576 .689 r
.35459 .63604 m .35744 .63598 L .35668 .6333 L F
.169 .222 .675 r
.35668 .6333 m .35899 .63519 L .35864 .63171 L F
.35668 .6333 m .35744 .63598 L .35899 .63519 L F
.625 .369 .51 r
.32928 .55898 m .32546 .56113 L .32753 .55976 L F
.174 0 0 r
.35886 .66668 m .36283 .66403 L .36043 .66443 L F
.807 .902 .908 r
.7106 .30512 m .7061 .30696 L .70866 .30374 L F
.615 .053 0 r
.71183 .36118 m .7108 .3609 L .70888 .35945 L F
.248 .762 .806 r
.71183 .36118 m .7133 .36039 L .7108 .3609 L F
.71183 .36118 m .7145 .36059 L .7133 .36039 L F
.658 .632 .812 r
.62069 .39812 m .62218 .40032 L .61806 .3989 L F
.677 .619 .783 r
.6233 .39509 m .62218 .40032 L .62069 .39812 L F
.6233 .39509 m .62452 .39902 L .62218 .40032 L F
.437 .305 .602 r
.24707 .55889 m .24486 .55722 L .24698 .55657 L F
.24707 .55889 m .24502 .55987 L .24486 .55722 L F
.482 .359 .636 r
.37728 .60528 m .38025 .60776 L .3794 .60607 L F
.37728 .60528 m .37748 .60827 L .38025 .60776 L F
.885 .485 .262 r
.61546 .43964 m .61733 .44029 L .61604 .44163 L F
.942 .593 .327 r
.61604 .44163 m .61733 .44029 L .61776 .44269 L F
.403 .29 .61 r
.31678 .56218 m .31436 .56051 L .31662 .55976 L F
.31678 .56218 m .31461 .56298 L .31436 .56051 L F
.664 .671 .847 r
.61918 .39434 m .61806 .3989 L .61715 .39552 L F
.61918 .39434 m .62069 .39812 L .61806 .3989 L F
.273 0 .14 r
.59612 .4272 m .59475 .42651 L .59374 .42701 L F
.33 0 0 r
.38257 .60657 m .38055 .60586 L .3794 .60607 L F
0 0 0 r
.38335 .6046 m .38055 .60586 L .38257 .60657 L F
.391 .847 .896 r
.32668 .66823 m .32845 .66846 L .3303 .66777 L F
.211 .492 .9 r
.29282 .62015 m .29422 .62307 L .29057 .62044 L F
.29282 .62015 m .29497 .62321 L .29422 .62307 L F
.385 .156 .44 r
.36183 .55127 m .36432 .55052 L .36466 .54731 L F
.316 .057 .354 r
.36466 .54731 m .36671 .54679 L .36752 .54432 L F
.093 0 .342 r
.36466 .54731 m .36592 .54874 L .36671 .54679 L F
.36466 .54731 m .36432 .55052 L .36592 .54874 L F
.338 .017 .266 r
.63713 .4404 m .63915 .44147 L .63706 .4428 L F
.63713 .4404 m .6397 .43966 L .63915 .44147 L F
.81 .494 .454 r
.55885 .43309 m .56282 .43418 L .56287 .43629 L F
.952 .667 .462 r
.3356 .55047 m .3338 .55233 L .33379 .54959 L F
0 0 0 r
.33808 .55062 m .3338 .55233 L .3356 .55047 L F
0 0 .52 r
.37292 .5571 m .37367 .55608 L .37237 .55202 L F
.37367 .55608 m .37364 .55528 L .37237 .55202 L F
.289 .787 .786 r
.37237 .55202 m .36978 .55254 L .36897 .55297 L F
.233 0 .255 r
.37237 .55202 m .37379 .55245 L .37427 .54982 L F
.905 .876 .798 r
.37263 .54848 m .37237 .55202 L .37427 .54982 L F
.37263 .54848 m .36978 .55254 L .37237 .55202 L F
0 0 .52 r
.37367 .55608 m .37385 .55583 L .37364 .55528 L F
.764 .439 .436 r
.37237 .55202 m .37385 .55583 L .37017 .55498 L F
.37237 .55202 m .3724 .55439 L .37379 .55245 L F
.37237 .55202 m .37017 .55498 L .36978 .55254 L F
.37237 .55202 m .36978 .55254 L .3724 .55439 L F
.606 .606 .825 r
.37101 .54805 m .36978 .55254 L .37263 .54848 L F
.37101 .54805 m .37355 .55243 L .36978 .55254 L F
.37355 .55243 m .37375 .55277 L .37356 .55276 L F
.37355 .55243 m .37356 .55276 L .36978 .55254 L F
.232 .116 .509 r
.37292 .5571 m .37447 .55863 L .37385 .55583 L F
.37292 .5571 m .37304 .55972 L .37447 .55863 L F
.638 .478 .65 r
.31663 .57008 m .31957 .56979 L .31917 .56637 L F
.637 .477 .65 r
.31917 .56637 m .31957 .56979 L .32066 .5675 L F
.764 .554 .614 r
.39892 .58046 m .40009 .5817 L .40047 .57887 L F
0 0 .489 r
.39892 .58046 m .39951 .58336 L .40009 .5817 L F
.848 .635 .614 r
.40047 .57887 m .40009 .5817 L .39918 .58148 L F
0 0 .489 r
.39904 .58119 m .39875 .58605 L .39941 .58369 L F
.39892 .58046 m .39891 .58094 L .39904 .58119 L F
.39891 .58094 m .39875 .58605 L .39904 .58119 L F
.39892 .58046 m .39941 .58369 L .39923 .58199 L F
.999 .833 .534 r
.39918 .58148 m .39829 .58308 L .39661 .58086 L F
.40009 .5817 m .3995 .58215 L .39918 .58148 L F
.3995 .58215 m .39829 .58308 L .39918 .58148 L F
.848 .635 .614 r
.39898 .57964 m .39918 .58148 L .39661 .58086 L F
.40047 .57887 m .39918 .58148 L .39898 .57964 L F
0 0 .489 r
.39923 .58199 m .39941 .58369 L .39951 .58336 L F
.893 .481 .207 r
.39875 .58605 m .39804 .58745 L .39951 .58336 L F
.39875 .58605 m .40028 .58838 L .39804 .58745 L F
.045 0 .203 r
.28652 .61096 m .28577 .61326 L .28802 .60992 L F
0 0 0 r
.23127 .53871 m .2298 .53992 L .2331 .5376 L F
.762 .784 .871 r
.57965 .43221 m .57562 .43308 L .5789 .43115 L F
.663 .846 .97 r
.58232 .43094 m .57965 .43221 L .5789 .43115 L F
.768 .664 .749 r
.19545 .60357 m .1967 .60759 L .19275 .60753 L F
.527 .005 0 r
.19275 .60753 m .1967 .60759 L .19418 .60882 L F
.302 .796 .857 r
.19761 .60699 m .1967 .60759 L .19545 .60357 L F
.19761 .60699 m .19899 .60704 L .1967 .60759 L F
.1967 .60759 m .19761 .60699 L .19418 .60882 L F
.1967 .60759 m .19899 .60704 L .19761 .60699 L F
.076 0 .133 r
.25234 .5398 m .25035 .54073 L .25264 .53933 L F
.518 .599 .875 r
.25023 .53903 m .25205 .54028 L .25234 .5398 L F
.387 .132 .401 r
.25209 .54254 m .25058 .54088 L .25234 .5398 L F
.365 .189 .505 r
.25414 .54172 m .25209 .54254 L .25234 .5398 L F
.518 .599 .875 r
.25205 .54028 m .25414 .54172 L .25234 .5398 L F
.076 0 .133 r
.25234 .5398 m .25264 .53933 L .25414 .53841 L F
.782 .969 .674 r
.2544 .53696 m .25414 .53841 L .25608 .53857 L F
.2544 .53696 m .25234 .5398 L .25414 .53841 L F
.81 .862 .887 r
.31406 .51818 m .31894 .51677 L .31672 .51513 L F
.057 .224 .721 r
.3448 .55206 m .34559 .55312 L .34449 .55006 L F
.78 .646 .714 r
.23906 .61047 m .24344 .61161 L .24165 .60699 L F
.769 .671 .755 r
.23906 .61047 m .24061 .614 L .24344 .61161 L F
.538 .519 .782 r
.24165 .60699 m .24344 .61161 L .2447 .61036 L F
.684 .862 .967 r
.41715 .54721 m .41363 .54707 L .41509 .54438 L F
.472 .711 .974 r
.41808 .54546 m .41715 .54721 L .41509 .54438 L F
.41808 .54546 m .41946 .54696 L .41715 .54721 L F
.85 .515 .419 r
.41808 .54546 m .41715 .54721 L .41946 .54696 L F
.41808 .54546 m .42146 .54977 L .41715 .54721 L F
.625 .502 .692 r
.22061 .56302 m .22001 .56504 L .21968 .5623 L F
.241 .314 .739 r
.39804 .62166 m .39597 .62337 L .3966 .6216 L F
0 0 .474 r
.39708 .62382 m .39597 .62337 L .39804 .62166 L F
.39708 .62382 m .39689 .62561 L .39597 .62337 L F
.608 .367 .526 r
.42418 .57694 m .42568 .57895 L .42326 .57866 L F
.239 .07 .44 r
.42775 .57425 m .42418 .57694 L .42607 .57501 L F
.383 .31 .65 r
.42853 .5789 m .42418 .57694 L .42775 .57425 L F
.42853 .5789 m .42568 .57895 L .42418 .57694 L F
.076 .387 .848 r
.28438 .62821 m .28401 .62959 L .28219 .62785 L F
0 0 .291 r
.28455 .63168 m .28401 .62959 L .28438 .62821 L F
.579 .522 .755 r
.33541 .57903 m .33885 .58253 L .33704 .57828 L F
.565 .68 .917 r
.38364 .55188 m .38495 .55361 L .38223 .554 L F
.448 0 .076 r
.26358 .62225 m .26828 .62067 L .26518 .62078 L F
.141 .684 .82 r
.35576 .63585 m .35744 .63598 L .35459 .63604 L F
.383 .837 .917 r
.35899 .63519 m .35744 .63598 L .35576 .63585 L F
0 0 0 r
.36322 .61945 m .36131 .62304 L .36002 .6202 L F
0 0 .085 r
.36044 .62481 m .36194 .62072 L .35925 .62512 L F
.36188 .62208 m .36199 .62183 L .36194 .62072 L F
.045 .323 .807 r
.36187 .62208 m .36391 .62502 L .36138 .62309 L F
.865 .456 .252 r
.36442 .62688 m .36131 .62304 L .36391 .62502 L F
0 0 .085 r
.36177 .62446 m .36199 .62183 L .36188 .62208 L F
.045 .323 .807 r
.36186 .62207 m .36187 .62208 L .36131 .62304 L F
.36187 .62208 m .36138 .62309 L .36131 .62304 L F
0 0 .085 r
.36188 .62208 m .36188 .62204 L .36186 .62207 L F
.045 .323 .807 r
.36199 .62183 m .36229 .62233 L .36186 .62207 L F
.36229 .62233 m .36391 .62502 L .36186 .62207 L F
0 0 .085 r
.36177 .62446 m .36188 .62208 L .36044 .62481 L F
.36188 .62208 m .36186 .62207 L .36044 .62481 L F
.36188 .62204 m .36194 .62072 L .36044 .62481 L F
0 0 0 r
.36322 .61945 m .36316 .61957 L .36131 .62304 L F
.36316 .61957 m .36199 .62183 L .36186 .62207 L F
.36316 .61957 m .36186 .62207 L .36131 .62304 L F
.367 .495 .856 r
.62752 .43261 m .62618 .43411 L .62433 .43133 L F
.548 .396 .626 r
.62876 .43395 m .62618 .43411 L .62752 .43261 L F
.62876 .43395 m .62652 .43725 L .62618 .43411 L F
0 0 0 r
.26037 .55397 m .26121 .5532 L .26316 .5507 L F
.772 .7 .16 r
.2609 .55623 m .26121 .5532 L .26037 .55397 L F
0 .018 .571 r
.60753 .41705 m .6078 .4207 L .60821 .41949 L F
0 0 .29 r
.60821 .41949 m .6078 .4207 L .60833 .42328 L F
.627 .734 .925 r
.57222 .43105 m .56938 .43233 L .56808 .4299 L F
.21 .209 .639 r
.32825 .53145 m .32868 .53611 L .33047 .53333 L F
.344 .384 .759 r
.32868 .53611 m .33118 .53706 L .33047 .53333 L F
.763 .627 .71 r
.24661 .60616 m .24638 .6079 L .24488 .60488 L F
.24661 .60616 m .24638 .6079 L .24488 .60488 L F
.739 .618 .724 r
.24165 .60699 m .24638 .6079 L .24488 .60488 L F
.538 .519 .782 r
.24165 .60699 m .2447 .61036 L .24638 .6079 L F
.576 .545 .783 r
.24487 .60319 m .24638 .6079 L .24488 .60488 L F
.881 .739 .701 r
.24638 .6079 m .2447 .61036 L .24661 .60616 L F
.24638 .6079 m .2447 .61036 L .24661 .60616 L F
.541 .388 .622 r
.36119 .5953 m .36437 .59725 L .36295 .59369 L F
.36119 .5953 m .36155 .59813 L .36437 .59725 L F
.512 .338 .581 r
.27655 .53464 m .27618 .53801 L .27362 .53855 L F
.36 0 .074 r
.27618 .53801 m .27269 .53959 L .27362 .53855 L F
.7 .974 .763 r
.30957 .52001 m .30917 .52128 L .31226 .5198 L F
.30957 .52001 m .30818 .52151 L .30917 .52128 L F
.804 .7 .75 r
.40987 .53448 m .41226 .53783 L .40825 .53686 L F
.852 .62 .586 r
.41226 .53783 m .40881 .53972 L .40825 .53686 L F
.182 .334 .783 r
.41335 .53618 m .41226 .53783 L .40987 .53448 L F
.41335 .53618 m .4134 .53792 L .41226 .53783 L F
0 0 .377 r
.41486 .54017 m .41226 .53783 L .4134 .53792 L F
.452 .83 .592 r
.34072 .66714 m .34393 .6647 L .34191 .66615 L F
0 0 .221 r
.3409 .67176 m .34072 .66714 L .34191 .66615 L F
.75 .394 .379 r
.3385 .70507 m .3427 .70555 L .3423 .70773 L F
.577 .23 .345 r
.3423 .70773 m .3427 .70555 L .34535 .70744 L F
.065 .597 .862 r
.65142 .40201 m .65171 .40236 L .6487 .40159 L F
.666 .135 0 r
.65171 .40236 m .6502 .40314 L .6487 .40159 L F
.716 .981 .778 r
.65142 .40201 m .65298 .40031 L .65171 .40236 L F
.558 .544 .795 r
.65193 .39641 m .65158 .4003 L .64939 .39687 L F
.65158 .4003 m .65142 .40201 L .65069 .40016 L F
.65158 .4003 m .65069 .40016 L .64939 .39687 L F
.65193 .39641 m .65298 .40031 L .65142 .40201 L F
.704 .957 .69 r
.65298 .40031 m .6502 .40314 L .65171 .40236 L F
.558 .346 .548 r
.65281 .40049 m .65386 .40499 L .65341 .40476 L F
.65123 .40209 m .65341 .40476 L .6502 .40314 L F
.65281 .40049 m .65341 .40476 L .65123 .40209 L F
.65386 .40499 m .65372 .4051 L .6502 .40314 L F
0 .366 .823 r
.6502 .40314 m .65391 .4052 L .65238 .40355 L F
0 0 .345 r
.6537 .40512 m .65422 .4058 L .65238 .40355 L F
.65391 .40537 m .65394 .40542 L .6537 .40512 L F
.96 .865 .458 r
.65464 .40504 m .65414 .40888 L .65391 .40537 L F
0 0 .345 r
.65391 .40537 m .65413 .40577 L .65422 .4058 L F
.65394 .40542 m .65422 .4058 L .6537 .40512 L F
.83 .863 .87 r
.65546 .40361 m .65391 .40537 L .65377 .40521 L F
.65387 .40498 m .65377 .40521 L .6537 .40512 L F
.65546 .40361 m .65377 .40521 L .65387 .40498 L F
.106 .051 .506 r
.65477 .40098 m .65405 .40451 L .65298 .40031 L F
.65405 .40451 m .65387 .40498 L .65298 .40031 L F
.558 .346 .548 r
.65301 .40052 m .65387 .40498 L .65281 .40049 L F
.65387 .40498 m .65391 .4052 L .65386 .40499 L F
.65387 .40498 m .65386 .40499 L .65281 .40049 L F
.83 .863 .87 r
.65546 .40361 m .6537 .40512 L .65353 .40491 L F
.65546 .40361 m .65353 .40491 L .65523 .40361 L F
.65598 .40303 m .65391 .4052 L .65405 .40451 L F
.65598 .40303 m .65405 .40451 L .65477 .40098 L F
.65523 .40361 m .65353 .40491 L .65238 .40355 L F
.106 .051 .506 r
.65405 .40451 m .65391 .4052 L .65387 .40498 L F
.83 .863 .87 r
.65598 .40303 m .65546 .40361 L .65238 .40355 L F
.558 .346 .548 r
.65386 .40499 m .65391 .4052 L .65372 .4051 L F
.65298 .40031 m .65301 .40052 L .65281 .40049 L F
.728 .657 .779 r
.57875 .42202 m .58093 .4244 L .57722 .42403 L F
.58032 .42234 m .58093 .4244 L .57875 .42202 L F
.856 .671 .651 r
.57685 .4213 m .57722 .42403 L .57288 .42273 L F
.728 .657 .779 r
.57981 .42063 m .57722 .42403 L .57685 .4213 L F
.573 .344 .53 r
.58035 .42325 m .57779 .42182 L .57576 .42243 L F
.57779 .42182 m .57685 .4213 L .57659 .42158 L F
.57779 .42182 m .57659 .42158 L .57576 .42243 L F
.728 .657 .779 r
.57981 .42063 m .58032 .42234 L .57875 .42202 L F
.6 .112 .066 r
.57722 .42403 m .58093 .4244 L .57965 .42593 L F
.476 0 0 r
.58031 .42585 m .58093 .4244 L .58286 .42555 L F
.57965 .42593 m .57979 .42576 L .58031 .42585 L F
.57979 .42576 m .58093 .4244 L .58031 .42585 L F
.509 .512 .795 r
.58089 .42949 m .58426 .42963 L .58272 .42628 L F
.766 .695 .783 r
.58286 .42555 m .58089 .42949 L .57965 .42593 L F
.509 .512 .795 r
.58184 .42612 m .58272 .42628 L .58215 .42503 L F
.58089 .42949 m .58272 .42628 L .58184 .42612 L F
.464 .258 .514 r
.58081 .42551 m .58035 .42325 L .57965 .42593 L F
.825 .527 0 r
.58035 .42325 m .58093 .4244 L .57986 .42081 L F
0 .23 .735 r
.58286 .42555 m .58093 .4244 L .58035 .42325 L F
.58286 .42555 m .58035 .42325 L .58215 .42503 L F
.459 .777 .998 r
.58484 .42457 m .58215 .42503 L .58078 .42386 L F
.58498 .42459 m .58215 .42503 L .58484 .42457 L F
.464 .258 .514 r
.58215 .42503 m .58035 .42325 L .58076 .42527 L F
.58215 .42503 m .58076 .42527 L .58081 .42551 L F
.825 .527 0 r
.58035 .42325 m .57986 .42081 L .57981 .42063 L F
.43 0 0 r
.37427 .54982 m .37712 .55099 L .37826 .55073 L F
.129 .295 .764 r
.37689 .54703 m .37826 .55073 L .37905 .5486 L F
.801 .988 .731 r
.37826 .55073 m .37712 .55099 L .37905 .5486 L F
.71 .296 .261 r
.3142 .57263 m .31856 .57246 L .31663 .57008 L F
.76 .267 .054 r
.31663 .57008 m .32044 .57266 L .31957 .56979 L F
.31663 .57008 m .31856 .57246 L .32044 .57266 L F
.257 .766 .767 r
.31109 .52914 m .31345 .52848 L .31499 .52811 L F
0 0 0 r
.31109 .52914 m .30908 .52992 L .31345 .52848 L F
.275 .497 .89 r
.37446 .56607 m .36997 .5621 L .37227 .56187 L F
.328 .159 .494 r
.37076 .56402 m .37112 .56362 L .37227 .56187 L F
.806 .539 .536 r
.37723 .5608 m .37227 .56187 L .37359 .55987 L F
.37723 .5608 m .37772 .564 L .37227 .56187 L F
.419 .125 .357 r
.37772 .564 m .37446 .56607 L .37227 .56187 L F
.328 .159 .494 r
.37112 .56362 m .37378 .56072 L .37227 .56187 L F
.806 .539 .536 r
.37359 .55987 m .37227 .56187 L .37304 .55972 L F
.412 .269 .574 r
.37945 .56235 m .37772 .564 L .37723 .5608 L F
.49 .241 .464 r
.37979 .5599 m .37945 .56235 L .37723 .5608 L F
0 0 0 r
.26355 .5359 m .261 .53812 L .26218 .53695 L F
.768 .353 .263 r
.26218 .53695 m .25822 .53795 L .26067 .53852 L F
.782 .491 .494 r
.25892 .53767 m .25709 .53839 L .25687 .5359 L F
.768 .353 .263 r
.25822 .53795 m .25747 .53814 L .25768 .53816 L F
.25822 .53795 m .25768 .53816 L .26067 .53852 L F
.782 .491 .494 r
.26022 .53879 m .25713 .53888 L .25709 .53839 L F
0 0 .427 r
.25608 .53857 m .25687 .5359 L .2544 .53696 L F
.25608 .53857 m .25747 .53814 L .25687 .5359 L F
.941 .622 .403 r
.25687 .5359 m .25707 .53816 L .25503 .53726 L F
.141 .684 .819 r
.25765 .53816 m .25739 .53816 L .25608 .53857 L F
.941 .622 .403 r
.25707 .53816 m .25713 .53888 L .2561 .53808 L F
.25707 .53816 m .2561 .53808 L .25503 .53726 L F
.141 .684 .819 r
.26031 .53852 m .25843 .53827 L .25608 .53857 L F
.25843 .53827 m .25765 .53816 L .25752 .5382 L F
.25843 .53827 m .25752 .5382 L .25608 .53857 L F
.25765 .53816 m .25747 .53814 L .25739 .53816 L F
.782 .491 .494 r
.26022 .53879 m .25709 .53839 L .25768 .53816 L F
.25872 .53816 m .25768 .53816 L .25822 .53795 L F
.141 .684 .819 r
.26038 .53848 m .25747 .53814 L .26031 .53852 L F
.782 .491 .494 r
.26022 .53879 m .25768 .53816 L .25949 .53816 L F
.768 .353 .263 r
.25822 .53795 m .26022 .53879 L .25747 .53814 L F
.141 .684 .819 r
.26067 .53852 m .26038 .53848 L .26031 .53852 L F
.768 .353 .263 r
.26218 .53695 m .26022 .53879 L .25822 .53795 L F
.782 .491 .494 r
.25949 .53816 m .25872 .53816 L .25892 .53767 L F
.25872 .53816 m .25822 .53795 L .25892 .53767 L F
0 0 0 r
.261 .53812 m .26022 .53879 L .26085 .53821 L F
.261 .53812 m .26085 .53821 L .26218 .53695 L F
0 .407 .853 r
.71593 .29855 m .71546 .29934 L .71375 .29734 L F
.71593 .29855 m .71753 .30042 L .71546 .29934 L F
0 0 .349 r
.32918 .61163 m .32843 .61164 L .32709 .61144 L F
.63 .284 .366 r
.26316 .5507 m .26121 .5532 L .26534 .5529 L F
.374 0 0 r
.28585 .65029 m .28758 .64887 L .28924 .64951 L F
.076 .387 .848 r
.28438 .62821 m .28219 .62785 L .28228 .62608 L F
.077 .063 .537 r
.22817 .58092 m .22655 .57945 L .22936 .57831 L F
.22759 .58039 m .22709 .5816 L .22655 .57945 L F
.22709 .5816 m .22673 .58245 L .2266 .58027 L F
.22709 .5816 m .2266 .58027 L .22655 .57945 L F
.22736 .58179 m .22673 .58245 L .22759 .58039 L F
.156 .631 .927 r
.22764 .58374 m .22711 .58299 L .22817 .58092 L F
.708 .432 .504 r
.22729 .58216 m .2273 .58218 L .22732 .58216 L F
.725 .678 .805 r
.22729 .58216 m .22732 .58216 L .2273 .58213 L F
.077 .063 .537 r
.22817 .58092 m .22736 .58179 L .22759 .58039 L F
.441 .567 .886 r
.22399 .57764 m .22732 .58216 L .22817 .58092 L F
.458 .221 .466 r
.22718 .5823 m .22817 .58092 L .22732 .58216 L F
.156 .631 .927 r
.22718 .5823 m .22673 .58245 L .22721 .58194 L F
.2269 .58268 m .22673 .58245 L .22718 .5823 L F
.22711 .58299 m .22743 .58456 L .22686 .58285 L F
.2269 .58268 m .22686 .58285 L .22673 .58245 L F
.22711 .58299 m .22686 .58285 L .2269 .58268 L F
.708 .432 .504 r
.22719 .58217 m .22718 .5823 L .2273 .58218 L F
.156 .631 .927 r
.22711 .58299 m .22721 .58194 L .22817 .58092 L F
.458 .221 .466 r
.22693 .58253 m .22817 .58092 L .22718 .5823 L F
.708 .432 .504 r
.22164 .58158 m .22539 .58396 L .22693 .58253 L F
.22164 .58158 m .22693 .58253 L .22682 .58225 L F
.22164 .58158 m .22718 .5823 L .22719 .58217 L F
.458 .221 .466 r
.22539 .58396 m .22699 .58221 L .22693 .58253 L F
.708 .432 .504 r
.22682 .58225 m .22693 .58253 L .22718 .5823 L F
.22164 .58158 m .2273 .58218 L .22729 .58216 L F
.725 .678 .805 r
.22164 .58158 m .22729 .58216 L .22399 .57764 L F
.22729 .58216 m .2273 .58213 L .22399 .57764 L F
.458 .221 .466 r
.22699 .58221 m .22817 .58092 L .22693 .58253 L F
.156 .631 .927 r
.22764 .58374 m .22755 .5841 L .22711 .58299 L F
.22755 .5841 m .22743 .58456 L .22711 .58299 L F
.22711 .58299 m .2269 .58268 L .22718 .5823 L F
.647 .586 .772 r
.38822 .65734 m .38885 .6609 L .38612 .66153 L F
.325 .521 .893 r
.24748 .62948 m .24841 .62747 L .24584 .62751 L F
.24748 .62948 m .24912 .62944 L .24841 .62747 L F
.697 .705 .854 r
.71545 .35097 m .7135 .35256 L .7122 .35015 L F
.212 .001 .36 r
.3237 .60103 m .32435 .60138 L .32581 .5979 L F
.498 .527 .817 r
.3237 .60103 m .32657 .60288 L .32552 .60335 L F
0 .128 .644 r
.3237 .60103 m .32552 .60335 L .32435 .60138 L F
.187 .653 .938 r
.26772 .63579 m .27166 .63687 L .2703 .6381 L F
.534 .031 .006 r
.27166 .63687 m .27469 .63788 L .2703 .6381 L F
0 0 .391 r
.35106 .51472 m .34956 .51355 L .35143 .51409 L F
.65 .675 .86 r
.35519 .51732 m .35026 .51559 L .35153 .515 L F
0 0 0 r
.34785 .51885 m .34945 .51743 L .35026 .51559 L F
.605 .904 .625 r
.35026 .51559 m .35143 .51409 L .35316 .51277 L F
0 0 0 r
.35316 .51277 m .35198 .51479 L .35026 .51559 L F
.35026 .51559 m .34945 .51743 L .35143 .51409 L F
0 0 .391 r
.34945 .51743 m .34955 .51384 L .35106 .51472 L F
.34955 .51384 m .34956 .51355 L .35106 .51472 L F
.65 .675 .86 r
.35424 .51657 m .35153 .515 L .35198 .51479 L F
.35519 .51732 m .35153 .515 L .35424 .51657 L F
.804 .88 .901 r
.35693 .51557 m .35519 .51732 L .35198 .51479 L F
.782 .587 .019 r
.61892 .42168 m .61857 .41922 L .61869 .41973 L F
.388 0 .094 r
.2826 .53561 m .28439 .53662 L .28557 .53432 L F
.2826 .53561 m .28167 .53743 L .28439 .53662 L F
.42 .376 .703 r
.38524 .5982 m .38802 .60025 L .38722 .59763 L F
.462 .372 .669 r
.38524 .5982 m .38641 .60146 L .38802 .60025 L F
.406 .831 .962 r
.33527 .51909 m .33381 .51859 L .33141 .51925 L F
.19 0 0 r
.33812 .51918 m .33738 .51943 L .33527 .51909 L F
.164 .359 .811 r
.33527 .51909 m .33738 .51943 L .33588 .51725 L F
0 .24 .75 r
.2823 .64315 m .28307 .64606 L .2853 .64779 L F
.462 .824 .995 r
.37616 .61688 m .36996 .61656 L .37629 .62001 L F
.682 .615 .774 r
.37629 .62001 m .37776 .61569 L .37616 .61688 L F
.649 .506 .675 r
.30593 .56663 m .31021 .57036 L .30974 .56739 L F
.349 0 .144 r
.26977 .55051 m .27015 .55205 L .27344 .54992 L F
.051 .241 .738 r
.27344 .54992 m .27434 .54945 L .27224 .54771 L F
.625 .163 .136 r
.27344 .54992 m .27417 .55215 L .27434 .54945 L F
.104 0 .282 r
.27417 .55215 m .27263 .55325 L .27344 .54992 L F
.625 .163 .136 r
.27344 .54992 m .27015 .55205 L .27417 .55215 L F
.051 .241 .738 r
.27344 .54992 m .27434 .54945 L .27224 .54771 L F
.104 0 .282 r
.27417 .55215 m .27344 .54992 L .27434 .54945 L F
.412 .613 .932 r
.39969 .68184 m .40202 .68176 L .39876 .6823 L F
.368 .194 .509 r
.40202 .68176 m .39963 .68565 L .39876 .6823 L F
.353 0 0 r
.3121 .64817 m .31156 .64802 L .31119 .64745 L F
.514 .41 .673 r
.33057 .57304 m .33278 .57406 L .33279 .57242 L F
.234 .524 .916 r
.3606 .61549 m .36232 .61745 L .35985 .61696 L F
.626 .501 .69 r
.36322 .61945 m .36077 .61764 L .36232 .61745 L F
.36322 .61945 m .36002 .6202 L .35985 .61696 L F
.77 .844 .907 r
.36487 .6165 m .36322 .61945 L .36232 .61745 L F
.33 0 .076 r
.3612 .61841 m .36325 .61734 L .36232 .61745 L F
.36325 .61734 m .36487 .6165 L .36232 .61745 L F
.626 .501 .69 r
.36077 .61764 m .35985 .61696 L .36232 .61745 L F
.766 .466 .478 r
.3025 .52741 m .30634 .52555 L .30277 .52471 L F
.3025 .52741 m .30663 .5279 L .30634 .52555 L F
.708 .2 0 r
.23275 .55138 m .23372 .55253 L .23466 .55318 L F
.656 .968 .814 r
.71863 .35531 m .71695 .35733 L .72165 .35427 L F
.461 .13 .318 r
.39682 .6213 m .3937 .62173 L .39379 .62178 L F
.888 .894 .828 r
.69801 .31634 m .69427 .31795 L .69672 .31473 L F
.69801 .31634 m .69553 .31952 L .69427 .31795 L F
.901 .89 .811 r
.69908 .31445 m .69801 .31634 L .69672 .31473 L F
.77 .909 .935 r
.6362 .39748 m .63523 .40022 L .63375 .39873 L F
.6362 .39748 m .63734 .39868 L .63523 .40022 L F
.252 .509 .904 r
.24912 .62944 m .25158 .63233 L .2521 .63075 L F
.78 .341 .207 r
.62104 .44654 m .61794 .44729 L .61769 .44526 L F
.62104 .44654 m .62142 .44832 L .61794 .44729 L F
.878 .511 .027 r
.4266 .56448 m .42791 .5664 L .42613 .56276 L F
0 .094 .649 r
.42851 .56589 m .42791 .5664 L .4266 .56448 L F
.42851 .56589 m .42951 .56779 L .42791 .5664 L F
.234 .106 .493 r
.42951 .56779 m .42789 .56968 L .42791 .5664 L F
.891 .839 .787 r
.69553 .31952 m .69184 .3213 L .69427 .31795 L F
.69553 .31952 m .69321 .323 L .69184 .3213 L F
.915 .885 .789 r
.37527 .52227 m .37352 .52274 L .3739 .52036 L F
.1 0 .21 r
.313 .56499 m .31223 .56355 L .31251 .56348 L F
.313 .56499 m .31251 .56348 L .31461 .56298 L F
.488 .169 .352 r
.31638 .56427 m .31301 .5674 L .313 .56499 L F
.6 .609 .832 r
.31301 .5674 m .31332 .56599 L .313 .56499 L F
.461 .023 .119 r
.31638 .56427 m .313 .56499 L .31461 .56298 L F
.6 .609 .832 r
.31332 .56599 m .31396 .56309 L .313 .56499 L F
.1 0 .21 r
.313 .56499 m .31146 .56618 L .31223 .56355 L F
.189 0 .334 r
.3113 .56407 m .313 .56499 L .31251 .56091 L F
.3113 .56407 m .31146 .56618 L .313 .56499 L F
.997 .848 .565 r
.41793 .56348 m .41624 .56457 L .41652 .56232 L F
.41793 .56348 m .41722 .56597 L .41624 .56457 L F
0 0 0 r
.33729 .53954 m .33935 .53812 L .33801 .53708 L F
.981 .688 .367 r
.3377 .53413 m .33801 .53708 L .33935 .53812 L F
.332 .121 .436 r
.31743 .57813 m .31713 .58101 L .31542 .57928 L F
.133 .109 .562 r
.31713 .58101 m .31595 .58212 L .31542 .57928 L F
.592 .612 .841 r
.27224 .54771 m .27597 .54933 L .27502 .54729 L F
.517 .245 .441 r
.27224 .54771 m .27434 .54945 L .27502 .54729 L F
.343 .794 .951 r
.30372 .54112 m .30497 .54077 L .3065 .54119 L F
.933 .887 .764 r
.3065 .54119 m .30856 .53872 L .30764 .54011 L F
.3065 .54119 m .30664 .53804 L .30943 .53768 L F
.3065 .54119 m .30497 .54077 L .30664 .53804 L F
.569 .32 .5 r
.30764 .54011 m .30497 .54077 L .3065 .54119 L F
.343 .794 .951 r
.3065 .54119 m .30497 .54077 L .30372 .54112 L F
.569 .32 .5 r
.30497 .54077 m .30705 .54218 L .30764 .54011 L F
.30764 .54011 m .30705 .54218 L .30497 .54077 L F
0 .088 .643 r
.30705 .54218 m .3069 .54123 L .30764 .54011 L F
.87 .767 .747 r
.30664 .53804 m .30497 .54077 L .30404 .53705 L F
.661 .646 .824 r
.30404 .53705 m .30497 .54077 L .30764 .54011 L F
.891 .547 .388 r
.30558 .53484 m .30664 .53804 L .30404 .53705 L F
.799 .502 .488 r
.30943 .53768 m .30664 .53804 L .30558 .53484 L F
.661 .646 .824 r
.30404 .53705 m .30764 .54011 L .30587 .53598 L F
.573 .185 .269 r
.30664 .53809 m .30188 .5399 L .30404 .53705 L F
.782 .438 0 r
.30764 .54011 m .30701 .53909 L .30644 .5373 L F
.453 .013 .111 r
.30673 .53842 m .30182 .5407 L .30672 .53837 L F
.573 .185 .269 r
.30672 .53837 m .30188 .5399 L .30664 .53809 L F
.453 .013 .111 r
.30609 .53872 m .30452 .54059 L .30182 .5407 L F
.30707 .53826 m .30635 .53892 L .30609 .53872 L F
.30635 .53892 m .30452 .54059 L .30609 .53872 L F
.782 .438 0 r
.30701 .53909 m .30672 .53837 L .30665 .5381 L F
.30701 .53909 m .30664 .53809 L .30644 .5373 L F
.573 .185 .269 r
.30664 .53809 m .30404 .53705 L .30587 .53598 L F
.782 .438 0 r
.30658 .53786 m .30643 .53816 L .30644 .5373 L F
.30683 .5388 m .30681 .53877 L .30658 .53786 L F
.30681 .53877 m .30643 .53816 L .30658 .53786 L F
.589 .175 .225 r
.30708 .53828 m .30676 .53857 L .30707 .53826 L F
.30676 .53857 m .30452 .54059 L .30676 .53855 L F
.30676 .53857 m .30676 .53855 L .30707 .53826 L F
0 .088 .643 r
.3069 .54123 m .30659 .53918 L .30764 .54011 L F
.30659 .53918 m .30681 .53877 L .30764 .54011 L F
.782 .438 0 r
.30701 .53909 m .30683 .5388 L .30672 .53837 L F
.589 .175 .225 r
.30772 .54038 m .30659 .53918 L .30708 .53828 L F
0 .088 .643 r
.30674 .53934 m .3076 .54017 L .30737 .53977 L F
.3066 .53924 m .307 .53961 L .30674 .53934 L F
.307 .53961 m .3076 .54017 L .30674 .53934 L F
.30705 .54218 m .30771 .5404 L .3066 .53924 L F
.30771 .5404 m .30772 .54038 L .3066 .53924 L F
.589 .175 .225 r
.30772 .54038 m .30587 .5405 L .30659 .53918 L F
.30587 .5405 m .30452 .54059 L .30657 .53921 L F
0 0 0 r
.30603 .53958 m .30452 .54059 L .30772 .54038 L F
.30603 .53958 m .30336 .54137 L .30452 .54059 L F
.479 .473 .773 r
.29945 .54025 m .3027 .54331 L .30372 .54112 L F
0 0 0 r
.30336 .54137 m .30314 .54151 L .30452 .54059 L F
.589 .175 .225 r
.30657 .53921 m .30452 .54059 L .30708 .53828 L F
0 .088 .643 r
.30659 .53918 m .30643 .53816 L .30681 .53877 L F
.3066 .53924 m .30772 .54038 L .3076 .54017 L F
.30658 .53912 m .30737 .53977 L .30643 .53816 L F
.3066 .53924 m .30737 .53977 L .30658 .53912 L F
.453 .013 .111 r
.30599 .5386 m .30182 .5407 L .30188 .5399 L F
.30672 .53837 m .30606 .53868 L .30599 .5386 L F
.30606 .53868 m .30182 .5407 L .30599 .5386 L F
.30707 .53826 m .30673 .53842 L .30672 .53837 L F
.782 .438 0 r
.30665 .5381 m .30672 .53837 L .30664 .53809 L F
.573 .185 .269 r
.30707 .53826 m .30664 .53809 L .30587 .53598 L F
.30707 .53826 m .30672 .53837 L .30664 .53809 L F
.782 .438 0 r
.30644 .5373 m .30643 .53816 L .30587 .53598 L F
.933 .887 .764 r
.30856 .53872 m .30943 .53768 L .30764 .54011 L F
.581 .719 .938 r
.58831 .42689 m .58592 .42869 L .58286 .42555 L F
.09 .504 .902 r
.22213 .56523 m .22001 .56504 L .22061 .56302 L F
.22213 .56523 m .22306 .56647 L .22001 .56504 L F
.616 .904 .613 r
.26954 .75383 m .27106 .75267 L .27022 .7535 L F
.558 .018 0 r
.27007 .75362 m .27106 .75267 L .26954 .75383 L F
.859 .514 .398 r
.27022 .7535 m .26909 .75649 L .26767 .75559 L F
.26909 .75649 m .26878 .75732 L .26845 .75681 L F
.26909 .75649 m .26845 .75681 L .26767 .75559 L F
.27022 .7535 m .27115 .75624 L .26878 .75732 L F
.924 .794 .698 r
.27089 .75561 m .27248 .75329 L .27007 .75362 L F
.27115 .75624 m .27159 .75527 L .27089 .75561 L F
.27159 .75527 m .27248 .75329 L .27089 .75561 L F
.558 .018 0 r
.27007 .75362 m .27248 .75329 L .27106 .75267 L F
.141 .684 .82 r
.35576 .63585 m .35459 .63604 L .3556 .63887 L F
.894 .725 .666 r
.39265 .59663 m .39792 .59803 L .39555 .59327 L F
.882 .764 .727 r
.39265 .59663 m .39415 .60028 L .39792 .59803 L F
.697 .456 .555 r
.40975 .53165 m .40987 .53448 L .4061 .53443 L F
.487 .534 .831 r
.41205 .53039 m .40975 .53165 L .40901 .52876 L F
.189 .074 .482 r
.41201 .53272 m .40975 .53165 L .41205 .53039 L F
.41201 .53272 m .40987 .53448 L .40975 .53165 L F
.188 0 .369 r
.19751 .56916 m .19958 .5658 L .19743 .56643 L F
.294 .693 .975 r
.34283 .53475 m .34249 .53348 L .34011 .53333 L F
0 0 .547 r
.34283 .53475 m .34452 .53694 L .34249 .53348 L F
0 0 0 r
.27769 .54413 m .27675 .54619 L .2796 .54326 L F
.547 .711 .947 r
.64475 .39468 m .64382 .39757 L .64237 .39532 L F
.64475 .39468 m .64687 .39712 L .64382 .39757 L F
.428 0 .083 r
.34131 .59165 m .33955 .59366 L .33705 .59371 L F
.619 .649 .857 r
.34214 .58799 m .34131 .59165 L .33978 .58837 L F
.711 .31 .286 r
.34131 .59165 m .34404 .59424 L .33955 .59366 L F
.182 .711 .716 r
.29447 .52055 m .29664 .52004 L .29906 .51955 L F
.55 .931 .855 r
.29906 .51955 m .29994 .5184 L .3013 .51861 L F
.29906 .51955 m .29664 .52004 L .29994 .5184 L F
.447 .193 .435 r
.37798 .65174 m .37758 .65452 L .3751 .65685 L F
.039 0 .056 r
.3807 .64963 m .3791 .65164 L .37798 .65174 L F
0 0 .238 r
.37893 .6517 m .37798 .65174 L .3791 .65164 L F
.096 .585 .903 r
.34203 .55679 m .34339 .55772 L .3408 .55681 L F
.469 .828 .995 r
.34428 .55599 m .34339 .55772 L .34203 .55679 L F
.685 .463 .578 r
.33816 .55778 m .34249 .55859 L .34203 .55679 L F
.754 .463 0 r
.34203 .55679 m .34249 .55859 L .34221 .55786 L F
.34203 .55679 m .34221 .55786 L .34341 .55677 L F
.34203 .55679 m .34341 .55677 L .34428 .55599 L F
.096 .585 .903 r
.34203 .55679 m .3408 .55681 L .33939 .55631 L F
.522 .614 .885 r
.34493 .55743 m .34339 .55772 L .34588 .557 L F
.439 .121 .327 r
.38238 .58519 m .38173 .58731 L .37907 .58734 L F
.499 .224 .429 r
.38471 .58455 m .38173 .58731 L .38238 .58519 L F
0 0 .399 r
.23989 .61213 m .24061 .614 L .23962 .61175 L F
.583 .082 0 r
.23929 .61174 m .24035 .61276 L .23989 .61213 L F
.123 .58 .92 r
.2408 .61319 m .24061 .614 L .23989 .61213 L F
.583 .082 0 r
.24035 .61276 m .2408 .61319 L .23989 .61213 L F
0 0 .399 r
.23989 .61213 m .23962 .61175 L .23906 .61047 L F
.123 .58 .92 r
.2408 .61319 m .24246 .61424 L .24061 .614 L F
.145 0 .41 r
.33682 .55687 m .33816 .55778 L .33939 .55631 L F
.33682 .55687 m .33632 .56009 L .33816 .55778 L F
.335 .817 .859 r
.22394 .54197 m .22639 .5413 L .2281 .54123 L F
.479 .895 .903 r
.2281 .54123 m .22897 .54025 L .2298 .53992 L F
.2281 .54123 m .22639 .5413 L .22897 .54025 L F
.658 .848 .973 r
.33177 .50512 m .33239 .50658 L .33425 .50516 L F
.584 .636 .868 r
.42613 .56276 m .42368 .56329 L .42194 .56038 L F
.277 0 .195 r
.36183 .55127 m .36088 .55304 L .36432 .55052 L F
.256 .046 .391 r
.33494 .56911 m .33733 .56476 L .33535 .56605 L F
.317 .704 .98 r
.20843 .60101 m .20846 .59968 L .20643 .59974 L F
0 .376 .839 r
.20843 .60101 m .2095 .60109 L .20846 .59968 L F
.341 .047 .311 r
.3096 .55378 m .31157 .55355 L .31247 .55102 L F
.454 .187 .418 r
.31157 .55355 m .31448 .55049 L .31247 .55102 L F
.751 .715 .819 r
.36787 .658 m .36941 .66122 L .37238 .65818 L F
.26 .768 .852 r
.37036 .66069 m .36941 .66122 L .36761 .66283 L F
.5 .323 .572 r
.36941 .66122 m .37185 .66076 L .37238 .65818 L F
.26 .768 .852 r
.37036 .66069 m .37185 .66076 L .36941 .66122 L F
.538 .926 .875 r
.266 .53274 m .26348 .53315 L .26264 .53422 L F
0 0 .39 r
.26348 .53315 m .26218 .53695 L .26264 .53422 L F
.636 .549 .739 r
.24767 .61033 m .24923 .61247 L .25076 .61119 L F
.21 .209 .639 r
.32825 .53145 m .33047 .53333 L .3299 .53076 L F
.119 0 .089 r
.59645 .43321 m .59765 .43192 L .59786 .43206 L F
0 0 0 r
.59808 .4322 m .59786 .43206 L .59627 .43258 L F
.492 .727 .976 r
.6004 .43172 m .5992 .43364 L .59786 .43206 L F
0 0 0 r
.6004 .43172 m .59786 .43206 L .59808 .4322 L F
.119 0 .089 r
.59765 .43192 m .59841 .43112 L .59786 .43206 L F
0 0 0 r
.59841 .43112 m .60007 .42742 L .60158 .43067 L F
.676 .915 .59 r
.6004 .43172 m .59841 .43112 L .59786 .43206 L F
.6004 .43172 m .60158 .43067 L .59841 .43112 L F
.751 .674 .776 r
.61226 .43346 m .61363 .43677 L .60958 .43654 L F
.667 .246 .234 r
.60958 .43654 m .61363 .43677 L .61213 .43863 L F
.823 .451 .349 r
.61363 .43677 m .61546 .43964 L .61213 .43863 L F
.79 .673 .735 r
.69194 .33253 m .68968 .33582 L .6882 .33196 L F
.585 .07 0 r
.33824 .67372 m .33687 .67294 L .33472 .67314 L F
0 .2 .728 r
.335 .52172 m .33725 .52371 L .3363 .52385 L F
.866 .995 .804 r
.33239 .52486 m .33164 .5232 L .335 .52172 L F
.52 .441 .707 r
.3342 .52344 m .33499 .52403 L .33725 .52371 L F
.33164 .5232 m .33499 .52403 L .3342 .52344 L F
.58 .089 .053 r
.33499 .52403 m .33796 .52361 L .33725 .52371 L F
.672 .198 .116 r
.33164 .5232 m .33725 .52371 L .335 .52172 L F
.58 .089 .053 r
.33796 .52361 m .33908 .52345 L .33725 .52371 L F
0 .2 .728 r
.3363 .52385 m .33725 .52371 L .33702 .52502 L F
0 .006 .581 r
.33725 .52371 m .33857 .52713 L .33702 .52502 L F
.525 .583 .856 r
.33908 .52345 m .33857 .52713 L .33725 .52371 L F
.58 .089 .053 r
.33499 .52403 m .33827 .52437 L .33908 .52345 L F
.717 .575 .694 r
.33499 .52403 m .33609 .52875 L .33827 .52437 L F
.525 .451 .715 r
.33499 .52403 m .33839 .52801 L .33827 .52437 L F
.314 0 .157 r
.33611 .52486 m .33499 .52403 L .33618 .52342 L F
.525 .451 .715 r
.33499 .52403 m .33609 .52875 L .33839 .52801 L F
.314 0 .157 r
.33605 .52607 m .33499 .52403 L .33611 .52486 L F
.141 .684 .82 r
.35576 .63585 m .3556 .63887 L .35376 .63734 L F
.826 .358 0 r
.35376 .63734 m .3556 .63887 L .35663 .64112 L F
.465 .217 .453 r
.34317 .6318 m .34033 .63599 L .34292 .63525 L F
0 .2 .62 r
.19814 .59728 m .19795 .59711 L .19684 .59607 L F
.19814 .59728 m .19999 .59843 L .19795 .59711 L F
.478 0 0 r
.34634 .70899 m .34711 .71004 L .34535 .70744 L F
.34634 .70899 m .34916 .71054 L .34711 .71004 L F
.301 .151 .504 r
.24918 .55536 m .24719 .55389 L .24888 .55301 L F
.24918 .55536 m .24698 .55657 L .24719 .55389 L F
.514 .192 .36 r
.58992 .43882 m .5901 .43701 L .59274 .43858 L F
.546 .148 .238 r
.5901 .43701 m .59334 .43713 L .59274 .43858 L F
0 0 0 r
.64841 .4255 m .6484 .42453 L .64899 .4228 L F
.64841 .4255 m .64757 .42743 L .6484 .42453 L F
.319 .556 .92 r
.63375 .39873 m .63147 .39856 L .63216 .39669 L F
.511 .89 .965 r
.26412 .52553 m .26013 .52603 L .26246 .52525 L F
.344 .803 .938 r
.26493 .5247 m .26412 .52553 L .26246 .52525 L F
.26493 .5247 m .26656 .52511 L .26412 .52553 L F
0 0 0 r
.35762 .53231 m .36015 .53178 L .3599 .53093 L F
.219 0 .198 r
.3599 .53093 m .36231 .53062 L .36304 .52819 L F
.222 0 .209 r
.3599 .53093 m .36015 .53178 L .36231 .53062 L F
.616 .754 .944 r
.65848 .40687 m .65956 .40856 L .65574 .40772 L F
.293 0 0 r
.65956 .40856 m .6558 .41017 L .65574 .40772 L F
.65956 .40856 m .65845 .41 L .6558 .41017 L F
.529 .709 .954 r
.65848 .40687 m .66127 .40623 L .65956 .40856 L F
.499 .301 .542 r
.66127 .40623 m .65845 .41 L .65956 .40856 L F
.686 .833 .954 r
.38718 .65305 m .38339 .65305 L .38605 .65248 L F
.02 .457 .873 r
.38836 .65272 m .38718 .65305 L .38605 .65248 L F
.028 0 .209 r
.36752 .54432 m .36821 .5458 L .36868 .54335 L F
.36752 .54432 m .36671 .54679 L .36821 .5458 L F
.644 .088 0 r
.20432 .59797 m .20477 .59952 L .20207 .59867 L F
.20432 .59797 m .20643 .59974 L .20477 .59952 L F
0 0 .395 r
.35167 .56318 m .35308 .566 L .35162 .56131 L F
.593 .872 .993 r
.35162 .56131 m .34971 .56233 L .35167 .56318 L F
.129 .584 .923 r
.24884 .61906 m .24859 .6199 L .24681 .61889 L F
.24884 .61906 m .25051 .62022 L .24859 .6199 L F
.461 .13 .318 r
.39682 .6213 m .3966 .6216 L .3937 .62173 L F
0 .185 .702 r
.23507 .62079 m .23635 .62117 L .23335 .61957 L F
.33 .264 .63 r
.3157 .58709 m .31329 .58835 L .3136 .58498 L F
.322 .146 .48 r
.31523 .58973 m .31329 .58835 L .3157 .58709 L F
.31523 .58973 m .31339 .59089 L .31329 .58835 L F
0 0 0 r
.30304 .58499 m .30442 .58393 L .30568 .58197 L F
.425 .13 .358 r
.30304 .58499 m .30508 .58642 L .30442 .58393 L F
.30304 .58499 m .30192 .58803 L .30508 .58642 L F
0 0 0 r
.32716 .59455 m .32912 .59312 L .33007 .59128 L F
.876 .836 .803 r
.70248 .3064 m .7033 .30971 L .70021 .30983 L F
.854 .875 .854 r
.70021 .30983 m .7033 .30971 L .70143 .31134 L F
.765 .777 .863 r
.7061 .30696 m .7033 .30971 L .70248 .3064 L F
.333 0 0 r
.6397 .43139 m .63771 .43102 L .63652 .43204 L F
.6397 .43139 m .64095 .43067 L .63771 .43102 L F
.211 0 .151 r
.38542 .6039 m .38335 .6046 L .38257 .60657 L F
.751 .649 .748 r
.37331 .57559 m .37668 .5763 L .37493 .57217 L F
.847 .497 .39 r
.37173 .57687 m .37668 .5763 L .37331 .57559 L F
0 0 0 r
.37668 .5763 m .377 .57605 L .37904 .57242 L F
0 0 .544 r
.37668 .5763 m .37804 .57709 L .377 .57605 L F
.385 0 0 r
.23372 .55253 m .23536 .55331 L .23735 .55395 L F
.337 0 0 r
.23536 .55331 m .23987 .55367 L .23735 .55395 L F
.522 .326 .556 r
.31028 .63602 m .31307 .63203 L .31038 .63244 L F
.585 .308 .463 r
.36144 .60761 m .36329 .60994 L .36063 .61028 L F
.36144 .60761 m .36329 .60994 L .36063 .61028 L F
.704 .514 .629 r
.3746 .5792 m .37471 .58193 L .37089 .58177 L F
.823 .624 .633 r
.36721 .61001 m .36983 .61381 L .37061 .6106 L F
.516 .214 .393 r
.34292 .56988 m .34222 .57215 L .33962 .57238 L F
.645 .435 .585 r
.34492 .56912 m .34222 .57215 L .34292 .56988 L F
.683 .523 .663 r
.24923 .61247 m .2532 .61077 L .25076 .61119 L F
.24923 .61247 m .25353 .6138 L .2532 .61077 L F
.495 .332 .589 r
.30452 .56031 m .30711 .5597 L .30719 .55677 L F
.845 .861 .409 r
.29843 .63622 m .29961 .63257 L .29933 .63487 L F
.984 .72 .44 r
.29933 .63487 m .29961 .63257 L .29817 .63136 L F
0 0 0 r
.35762 .53231 m .35679 .53264 L .36015 .53178 L F
.033 0 0 r
.22594 .56609 m .22771 .56537 L .23055 .56229 L F
.273 .282 .687 r
.23055 .56229 m .2309 .55877 L .2287 .55963 L F
.23055 .56229 m .23238 .56213 L .2309 .55877 L F
.599 .234 .321 r
.23055 .56229 m .23166 .56432 L .23238 .56213 L F
.23055 .56229 m .22771 .56537 L .23166 .56432 L F
.463 .231 .476 r
.37907 .58734 m .37872 .59119 L .37571 .59255 L F
.586 .384 .575 r
.38173 .58731 m .37872 .59119 L .37907 .58734 L F
.164 0 .279 r
.33862 .65412 m .3358 .65793 L .33817 .65674 L F
0 0 .254 r
.3358 .65793 m .33654 .65934 L .33817 .65674 L F
.3358 .65793 m .33602 .66094 L .33654 .65934 L F
.753 .753 .852 r
.35552 .61906 m .36002 .6202 L .3579 .6161 L F
.73 .571 .675 r
.35552 .61906 m .36194 .62072 L .36002 .6202 L F
.309 .507 .887 r
.3579 .6161 m .36002 .6202 L .3612 .61841 L F
.832 .556 .008 r
.36194 .62072 m .3612 .61841 L .36002 .6202 L F
.799 .661 .109 r
.35293 .52707 m .35302 .5284 L .35305 .52737 L F
.35293 .52707 m .35305 .52737 L .35311 .52578 L F
.35293 .52707 m .35311 .52578 L .35615 .52492 L F
.9 .811 .336 r
.35266 .5264 m .35293 .52707 L .35359 .52605 L F
.35191 .52668 m .35293 .52707 L .35266 .5264 L F
.616 .904 .613 r
.26954 .75383 m .27022 .7535 L .26767 .75559 L F
.84 .816 .333 r
.73289 .34133 m .73229 .34304 L .73214 .34539 L F
0 0 .013 r
.73241 .34546 m .73214 .34539 L .73229 .34304 L F
.73241 .34546 m .7319 .34815 L .73214 .34539 L F
0 0 0 r
.29711 .63823 m .29843 .63622 L .29933 .63487 L F
.921 .683 .561 r
.40233 .52494 m .40071 .52518 L .40106 .52172 L F
.348 0 0 r
.40233 .52494 m .40203 .5264 L .40071 .52518 L F
.40233 .52494 m .40635 .52563 L .40203 .5264 L F
.792 .547 .567 r
.5668 .43685 m .56278 .439 L .56287 .43629 L F
.5668 .43685 m .56678 .43967 L .56278 .439 L F
.756 .458 .48 r
.5668 .43685 m .57074 .43961 L .56678 .43967 L F
.019 .237 .742 r
.22719 .61469 m .22775 .61306 L .22631 .61281 L F
.22719 .61469 m .2292 .61642 L .22775 .61306 L F
.616 .72 .92 r
.73054 .33634 m .7324 .33982 L .72866 .33875 L F
.869 .821 .799 r
.73496 .33428 m .7324 .33982 L .73054 .33634 L F
.298 .633 .964 r
.36345 .5064 m .36189 .50755 L .36036 .50595 L F
.36345 .5064 m .3648 .50791 L .36189 .50755 L F
.636 .462 .63 r
.36335 .58846 m .36418 .59169 L .36143 .59093 L F
.36335 .58846 m .36418 .59169 L .36143 .59093 L F
.461 .353 .645 r
.36641 .58936 m .36335 .58846 L .3656 .58784 L F
.36641 .58936 m .36418 .59169 L .36335 .58846 L F
.36641 .58936 m .36335 .58846 L .3656 .58784 L F
.36641 .58936 m .36418 .59169 L .36335 .58846 L F
.747 .653 .756 r
.28825 .62126 m .28866 .62322 L .28468 .62291 L F
.698 .461 .562 r
.28866 .62322 m .28458 .62611 L .28468 .62291 L F
.28866 .62322 m .28844 .62593 L .28458 .62611 L F
.634 .579 .775 r
.29057 .62044 m .28866 .62322 L .28825 .62126 L F
.308 .685 .977 r
.72441 .34135 m .72641 .34099 L .7281 .34244 L F
.762 .888 .934 r
.7281 .34244 m .72747 .34025 L .7286 .34177 L F
.7281 .34244 m .72641 .34099 L .72747 .34025 L F
.974 .671 .302 r
.41435 .5534 m .41582 .55741 L .41457 .5555 L F
.619 .576 .784 r
.41831 .55649 m .41582 .55741 L .41435 .5534 L F
.823 .474 0 r
.41582 .55741 m .41558 .55795 L .41457 .5555 L F
.41582 .55741 m .41655 .55952 L .41558 .55795 L F
.927 .567 .319 r
.36373 .5797 m .36189 .58067 L .36241 .57786 L F
.36373 .5797 m .36417 .58192 L .36189 .58067 L F
0 0 0 r
.36978 .55254 m .36751 .55561 L .36897 .55297 L F
.559 .69 .928 r
.61715 .39552 m .61392 .39659 L .61393 .39277 L F
.929 .926 .784 r
.71014 .31673 m .71175 .3142 L .70975 .31443 L F
.859 .925 .871 r
.71235 .31104 m .71175 .3142 L .71454 .31139 L F
.897 .956 .828 r
.70975 .31443 m .71175 .3142 L .71235 .31104 L F
.642 .133 .023 r
.39413 .57901 m .39661 .58086 L .39253 .5802 L F
.585 .235 .342 r
.39679 .57854 m .39661 .58086 L .39413 .57901 L F
.856 .671 .651 r
.57685 .4213 m .57288 .42273 L .57306 .42076 L F
.57685 .4213 m .57306 .42076 L .57576 .42243 L F
.573 .344 .53 r
.58035 .42325 m .57981 .42063 L .57685 .4213 L F
.338 0 .177 r
.22842 .58822 m .22575 .59086 L .22536 .59035 L F
.546 .559 .819 r
.22961 .58472 m .22842 .58822 L .22743 .58456 L F
.22961 .58472 m .23087 .5878 L .22842 .58822 L F
.629 .398 .548 r
.23087 .5878 m .22575 .59086 L .22842 .58822 L F
.1 .619 .884 r
.63001 .40781 m .63263 .40807 L .63154 .40749 L F
.63001 .40781 m .63154 .40749 L .62879 .40975 L F
.62 .478 .666 r
.2532 .61077 m .25353 .6138 L .25586 .61054 L F
.887 .559 .061 r
.41378 .5512 m .41435 .5534 L .41292 .54967 L F
.889 .901 .83 r
.70143 .31134 m .69908 .31445 L .69795 .31308 L F
.901 .89 .811 r
.69908 .31445 m .69672 .31473 L .69795 .31308 L F
.547 .54 .798 r
.22749 .55752 m .2287 .55963 L .2309 .55877 L F
.577 .942 .883 r
.26571 .5318 m .266 .53274 L .26794 .53183 L F
.26571 .5318 m .26348 .53315 L .266 .53274 L F
0 0 0 r
.39029 .59138 m .38719 .59473 L .38968 .59431 L F
.444 .065 .224 r
.39229 .59316 m .39029 .59138 L .38968 .59431 L F
.39229 .59316 m .39287 .59111 L .39029 .59138 L F
.575 .808 .418 r
.34277 .50941 m .34024 .51289 L .34146 .5112 L F
.547 .712 .948 r
.34277 .50941 m .34418 .50717 L .34125 .50579 L F
.34277 .50941 m .34512 .50889 L .34418 .50717 L F
.764 .588 .659 r
.34146 .5112 m .34512 .50889 L .34277 .50941 L F
.381 .791 .981 r
.27108 .52312 m .2705 .52412 L .2687 .52391 L F
.27108 .52312 m .27302 .52383 L .2705 .52412 L F
.526 .155 .278 r
.31146 .5397 m .30943 .53768 L .31175 .53722 L F
.31146 .5397 m .30764 .54011 L .30943 .53768 L F
.462 .239 .489 r
.31213 .53474 m .31175 .53722 L .30943 .53768 L F
.841 .744 .757 r
.27429 .53183 m .27808 .53136 L .27668 .53076 L F
.27429 .53183 m .27655 .53464 L .27808 .53136 L F
.508 .876 .98 r
.27895 .53005 m .27808 .53136 L .28128 .53003 L F
.27895 .53005 m .27668 .53076 L .27808 .53136 L F
.1 0 0 r
.3247 .62856 m .32886 .6264 L .32713 .62537 L F
.477 0 0 r
.37366 .59207 m .37459 .59311 L .37193 .5932 L F
.37366 .59207 m .37585 .59352 L .37459 .59311 L F
.54 .067 .081 r
.37571 .59255 m .37585 .59352 L .37366 .59207 L F
.328 .337 .717 r
.24652 .60323 m .24488 .60488 L .24487 .60319 L F
.24652 .60323 m .24488 .60488 L .24487 .60319 L F
0 0 .185 r
.30568 .58197 m .30637 .58167 L .30789 .57843 L F
.249 0 .008 r
.30568 .58197 m .30833 .58297 L .30637 .58167 L F
.30568 .58197 m .30442 .58393 L .30833 .58297 L F
0 0 .217 r
.34541 .56431 m .34455 .56284 L .34709 .56252 L F
.34541 .56431 m .34412 .56628 L .34455 .56284 L F
.325 .133 .459 r
.61857 .41922 m .61864 .41558 L .62064 .41396 L F
.559 .415 .642 r
.39751 .68694 m .39861 .68965 L .39699 .69126 L F
0 .089 .611 r
.39942 .6879 m .39751 .68694 L .39963 .68565 L F
.39942 .6879 m .39861 .68965 L .39751 .68694 L F
.022 .542 .862 r
.35061 .71188 m .35078 .71137 L .34916 .71054 L F
.35061 .71188 m .35286 .71239 L .35078 .71137 L F
.356 .513 .876 r
.2455 .61531 m .2444 .61746 L .24246 .61424 L F
.231 .356 .785 r
.2455 .61531 m .24681 .61889 L .2444 .61746 L F
.542 .695 .939 r
.27216 .53288 m .27655 .53464 L .27429 .53183 L F
.727 .211 0 r
.27621 .53555 m .27655 .53464 L .27383 .53608 L F
.492 .321 .576 r
.27871 .53728 m .27618 .53801 L .27655 .53464 L F
.727 .211 0 r
.27651 .53473 m .27871 .53728 L .27655 .53464 L F
.27621 .53555 m .27758 .53651 L .27651 .53473 L F
.27758 .53651 m .27871 .53728 L .27651 .53473 L F
.618 .807 .972 r
.2803 .53612 m .27871 .53728 L .27621 .53555 L F
.591 .732 .942 r
.2803 .53612 m .28167 .53743 L .27871 .53728 L F
.2803 .53612 m .28167 .53743 L .27871 .53728 L F
0 0 0 r
.27871 .53728 m .27775 .5389 L .2803 .53612 L F
.2803 .53612 m .27775 .5389 L .27871 .53728 L F
.2803 .53612 m .27775 .5389 L .27871 .53728 L F
.45 .098 .275 r
.27871 .53728 m .27528 .53921 L .27618 .53801 L F
.27871 .53728 m .27775 .5389 L .27528 .53921 L F
.618 .807 .972 r
.2803 .53612 m .278 .5358 L .27853 .53513 L F
.278 .5358 m .27621 .53555 L .27853 .53513 L F
.334 0 .034 r
.27459 .53736 m .27695 .53704 L .27853 .53513 L F
.684 .566 .716 r
.27695 .53704 m .27945 .53396 L .27853 .53513 L F
.313 0 0 r
.28286 .52923 m .27895 .53005 L .28128 .53003 L F
.28286 .52923 m .28188 .53002 L .27895 .53005 L F
.169 .694 .871 r
.28188 .53002 m .28019 .52962 L .27895 .53005 L F
.672 .602 .769 r
.28159 .53492 m .27853 .53513 L .28019 .52962 L F
0 0 .276 r
.28019 .52962 m .27853 .53513 L .27992 .53338 L F
.684 .566 .716 r
.27945 .53396 m .27992 .53338 L .27853 .53513 L F
0 0 .459 r
.27853 .53513 m .27775 .5389 L .2803 .53612 L F
.27853 .53513 m .27891 .53847 L .27879 .53851 L F
.27808 .53732 m .27879 .53851 L .27775 .5389 L F
.27853 .53513 m .27879 .53851 L .27808 .53732 L F
.945 .707 .548 r
.27429 .53183 m .27383 .53608 L .27655 .53464 L F
.425 .408 .736 r
.3096 .55378 m .31255 .55594 L .31157 .55355 L F
.516 .399 .659 r
.30994 .55649 m .31255 .55594 L .3096 .55378 L F
.339 .773 .968 r
.35238 .55372 m .34983 .55273 L .34794 .55315 L F
.512 .016 .016 r
.34853 .55424 m .35238 .55372 L .34794 .55315 L F
.34853 .55424 m .35062 .55526 L .35238 .55372 L F
.259 .273 .685 r
.35328 .54943 m .35401 .55313 L .35238 .55372 L F
.967 .692 .459 r
.35238 .55372 m .35062 .55526 L .34983 .55273 L F
.245 .234 .648 r
.35401 .55313 m .35441 .55535 L .35238 .55372 L F
.88 .653 .129 r
.40889 .58359 m .40941 .58681 L .40938 .58497 L F
.071 0 0 r
.30257 .54588 m .30446 .54465 L .3027 .54331 L F
.697 .528 .655 r
.70098 .34176 m .70124 .34521 L .69809 .34493 L F
.025 .021 .513 r
.70268 .34272 m .70098 .34176 L .70334 .34149 L F
.70268 .34272 m .70124 .34521 L .70098 .34176 L F
.446 .864 .949 r
.25756 .52641 m .25308 .52678 L .25557 .52566 L F
.463 .808 .998 r
.25807 .52497 m .25756 .52641 L .25557 .52566 L F
.25807 .52497 m .26013 .52603 L .25756 .52641 L F
.763 .652 .739 r
.26276 .61052 m .26041 .61459 L .25791 .61222 L F
.479 .601 .896 r
.25791 .61222 m .26041 .61459 L .26213 .61339 L F
.765 .762 .85 r
.36829 .58502 m .36944 .58831 L .3656 .58784 L F
.899 .853 .788 r
.36944 .58831 m .36641 .58936 L .3656 .58784 L F
.36944 .58831 m .36733 .59149 L .36641 .58936 L F
.832 .794 .815 r
.37208 .58494 m .36944 .58831 L .36829 .58502 L F
.429 .125 .346 r
.36997 .5621 m .37304 .55972 L .37041 .56009 L F
.36997 .5621 m .37304 .55972 L .37041 .56009 L F
.796 .677 .733 r
.23386 .60075 m .23154 .60344 L .23524 .60343 L F
.87 .429 .049 r
.23154 .60344 m .23475 .60761 L .23524 .60343 L F
.573 .42 .635 r
.23524 .60343 m .23475 .60761 L .23762 .6037 L F
.903 .975 .804 r
.40447 .53137 m .40366 .52994 L .40635 .52563 L F
.964 .735 .542 r
.4061 .53443 m .40366 .52994 L .40447 .53137 L F
.693 .949 .675 r
.32916 .60265 m .33042 .60163 L .33155 .60018 L F
.44 .336 .64 r
.31871 .55302 m .31916 .55633 L .3168 .55698 L F
.257 .11 .482 r
.3187 .55821 m .3168 .55698 L .31916 .55633 L F
.3187 .55821 m .31662 .55976 L .3168 .55698 L F
.763 .652 .739 r
.26276 .61052 m .25791 .61222 L .26213 .61339 L F
.547 .716 .951 r
.26383 .6087 m .26541 .61012 L .26276 .61052 L F
.454 .173 .396 r
.26276 .61052 m .26459 .61259 L .26383 .6087 L F
.26276 .61052 m .26213 .61339 L .26459 .61259 L F
.558 .361 .57 r
.39695 .61281 m .39399 .61049 L .39544 .60912 L F
.39695 .61281 m .39447 .61373 L .39399 .61049 L F
.217 .406 .834 r
.29687 .64525 m .29495 .64161 L .2949 .64426 L F
.492 .317 .572 r
.28557 .53432 m .28803 .53383 L .28746 .53109 L F
.218 0 .101 r
.28557 .53432 m .28651 .5359 L .28803 .53383 L F
.28557 .53432 m .28439 .53662 L .28651 .5359 L F
.879 .497 .311 r
.31856 .57246 m .31915 .5746 L .32044 .57266 L F
.987 .839 .459 r
.32044 .57266 m .31915 .5746 L .31987 .57514 L F
.757 .621 .709 r
.31957 .56979 m .32044 .57266 L .32066 .5675 L F
.987 .839 .459 r
.32044 .57266 m .31915 .5746 L .31987 .57514 L F
.55 .244 .403 r
.32553 .54177 m .32932 .54383 L .32728 .53925 L F
.32553 .54177 m .32625 .54424 L .32932 .54383 L F
.72 .736 .864 r
.62558 .3942 m .62452 .39902 L .6233 .39509 L F
.62558 .3942 m .6271 .39763 L .62452 .39902 L F
.826 .741 .77 r
.57288 .42273 m .57722 .42403 L .57444 .42717 L F
.606 .399 .574 r
.57722 .42403 m .57778 .42718 L .57444 .42717 L F
.6 .112 .066 r
.57722 .42403 m .57965 .42593 L .57778 .42718 L F
.16 0 .26 r
.32393 .55962 m .32546 .55959 L .32629 .55665 L F
.26 .079 .436 r
.32393 .55962 m .32546 .56113 L .32546 .55959 L F
.177 0 0 r
.32546 .56113 m .32865 .56151 L .32636 .56131 L F
.32546 .56113 m .32636 .56131 L .32442 .56114 L F
.26 .079 .436 r
.32393 .55962 m .32387 .56082 L .32546 .56113 L F
.32387 .56082 m .32377 .56275 L .32546 .56113 L F
.889 .901 .83 r
.70143 .31134 m .69795 .31308 L .70021 .30983 L F
.849 .738 .74 r
.69321 .323 m .68924 .32493 L .69184 .3213 L F
.69321 .323 m .69104 .32631 L .68924 .32493 L F
.22 0 .241 r
.24184 .56243 m .23926 .56542 L .23907 .56325 L F
.932 .78 .67 r
.5893 .40827 m .59105 .41159 L .5892 .41105 L F
.631 .068 0 r
.5892 .41105 m .59105 .41159 L .59001 .41187 L F
.476 .599 .896 r
.59296 .41112 m .59105 .41159 L .5893 .40827 L F
.833 .583 .562 r
.59296 .41112 m .59001 .41187 L .59105 .41159 L F
.081 0 .276 r
.32581 .5979 m .32435 .60138 L .32707 .59938 L F
.651 .395 .519 r
.71847 .31959 m .72198 .31934 L .72171 .31674 L F
0 0 0 r
.3449 .52164 m .34172 .52496 L .34429 .52421 L F
.252 0 .247 r
.3449 .52164 m .34704 .52091 L .34785 .51885 L F
.358 .055 .307 r
.3449 .52164 m .34645 .52341 L .34704 .52091 L F
.3449 .52164 m .34429 .52421 L .34645 .52341 L F
0 0 .538 r
.33947 .64201 m .33892 .64259 L .33787 .63897 L F
0 0 .486 r
.34021 .6437 m .33892 .64259 L .33947 .64201 L F
.34021 .6437 m .33929 .64521 L .33892 .64259 L F
.69 .253 .208 r
.28104 .63573 m .28358 .63784 L .28185 .6386 L F
0 0 .108 r
.28126 .64098 m .28185 .6386 L .28358 .63784 L F
.506 .596 .878 r
.28746 .53109 m .29 .53043 L .28696 .5293 L F
.496 .32 .572 r
.28746 .53109 m .29033 .53317 L .29 .53043 L F
.28746 .53109 m .28803 .53383 L .29033 .53317 L F
0 0 .118 r
.4088 .5932 m .40783 .59464 L .40864 .59118 L F
0 0 .153 r
.40836 .59585 m .40783 .59464 L .4088 .5932 L F
.40836 .59585 m .40781 .59758 L .40783 .59464 L F
.463 .185 .404 r
.34571 .58493 m .34214 .58799 L .34263 .58591 L F
.238 .162 .564 r
.33362 .50255 m .33247 .50464 L .332 .50386 L F
.825 .937 .902 r
.71235 .31104 m .71454 .31139 L .71624 .30949 L F
.065 0 .389 r
.33987 .54107 m .34096 .54236 L .34192 .54063 L F
0 0 .039 r
.31114 .64437 m .31226 .64187 L .31042 .64429 L F
.6 .838 .463 r
.31463 .63871 m .31226 .64187 L .31314 .64057 L F
.586 .451 .664 r
.31463 .63871 m .31501 .64127 L .31226 .64187 L F
.37 .495 .855 r
.31588 .645 m .31226 .64187 L .31501 .64127 L F
0 0 0 r
.31314 .64057 m .31226 .64187 L .31114 .64437 L F
.653 .342 .433 r
.36295 .59369 m .36418 .59169 L .36143 .59093 L F
.218 .194 .616 r
.36418 .59169 m .36295 .59369 L .36143 .59093 L F
.966 .77 .587 r
.61982 .42903 m .62206 .42765 L .62224 .42698 L F
.61982 .42903 m .62168 .42961 L .62206 .42765 L F
.814 .881 .894 r
.27002 .53918 m .26664 .54062 L .26978 .5384 L F
.688 .858 .451 r
.26843 .54052 m .26712 .54232 L .26738 .5419 L F
.177 0 0 r
.26919 .53953 m .26843 .54052 L .26664 .54062 L F
.282 0 .177 r
.26664 .54062 m .26843 .54052 L .26978 .5384 L F
.688 .858 .451 r
.26843 .54052 m .26738 .5419 L .26957 .53832 L F
.177 0 0 r
.27002 .53918 m .26843 .54052 L .26919 .53953 L F
.484 .528 .827 r
.27153 .53688 m .27002 .53918 L .26978 .5384 L F
.27153 .53688 m .27269 .53959 L .27002 .53918 L F
.217 0 0 r
.27269 .53959 m .26843 .54052 L .27002 .53918 L F
.426 .076 .267 r
.37032 .7123 m .37226 .71361 L .36972 .71334 L F
.37032 .7123 m .37294 .71175 L .37226 .71361 L F
.611 .253 .339 r
.40028 .58838 m .39906 .5904 L .39804 .58745 L F
.40028 .58838 m .40181 .5904 L .39906 .5904 L F
.759 .515 .565 r
.36733 .60735 m .36329 .60994 L .36561 .60576 L F
.36733 .60735 m .36721 .61001 L .36329 .60994 L F
.776 .666 .742 r
.6882 .33196 m .68968 .33582 L .6858 .33517 L F
.596 .909 .981 r
.2561 .6324 m .25787 .63294 L .26004 .63194 L F
.142 0 0 r
.35505 .57195 m .35768 .57134 L .3587 .57002 L F
.578 .061 0 r
.35768 .57134 m .36131 .57165 L .3587 .57002 L F
.078 0 .193 r
.31595 .58212 m .31505 .58431 L .3136 .58498 L F
.33 .264 .63 r
.3157 .58709 m .3136 .58498 L .31505 .58431 L F
.238 .049 .409 r
.36361 .52709 m .36539 .52606 L .36567 .52306 L F
.78 .675 .125 r
.36567 .52306 m .36526 .52746 L .36523 .52538 L F
.36567 .52306 m .36523 .52538 L .36866 .52491 L F
.5 .908 .862 r
.36866 .52491 m .36697 .52514 L .36996 .52373 L F
.36697 .52514 m .36523 .52538 L .36856 .52422 L F
.36697 .52514 m .36856 .52422 L .36996 .52373 L F
.238 .049 .409 r
.36304 .52819 m .36526 .52746 L .36539 .52606 L F
.36304 .52819 m .36539 .52606 L .36361 .52709 L F
0 0 .049 r
.36304 .52819 m .36378 .52909 L .36526 .52746 L F
.36304 .52819 m .36231 .53062 L .36378 .52909 L F
.393 .849 .796 r
.71943 .34125 m .71826 .34133 L .71996 .34065 L F
.71943 .34125 m .71996 .34065 L .72117 .34017 L F
.069 .559 .894 r
.71923 .34147 m .71943 .34125 L .72087 .34211 L F
.71728 .34072 m .71943 .34125 L .71923 .34147 L F
.094 0 0 r
.71943 .34125 m .72441 .34135 L .72087 .34211 L F
.771 .707 .792 r
.60807 .43032 m .6055 .43322 L .60424 .42975 L F
.722 .328 .301 r
.6055 .43322 m .60776 .43578 L .6041 .43523 L F
.55 .771 .98 r
.6055 .43322 m .60958 .43654 L .60776 .43578 L F
.753 .973 .706 r
.64456 .42338 m .64688 .42133 L .64407 .42434 L F
.639 .921 .641 r
.64827 .41966 m .64688 .42133 L .64456 .42338 L F
.545 .27 .448 r
.32058 .62539 m .32086 .62288 L .31829 .62341 L F
.375 .285 .624 r
.32028 .62567 m .32058 .62539 L .31829 .62341 L F
.545 .27 .448 r
.32058 .62539 m .32086 .62288 L .31829 .62341 L F
.261 0 .281 r
.23142 .57292 m .23079 .57504 L .2289 .57568 L F
.501 .226 .428 r
.23379 .57237 m .23079 .57504 L .23142 .57292 L F
.765 .67 .758 r
.34559 .55312 m .3419 .55332 L .34449 .55006 L F
.626 .202 .216 r
.34559 .55312 m .34428 .55599 L .3419 .55332 L F
.644 .22 .224 r
.34853 .55424 m .34559 .55312 L .34794 .55315 L F
.34853 .55424 m .34428 .55599 L .34559 .55312 L F
.488 .699 .962 r
.24309 .62752 m .24391 .62531 L .24166 .62612 L F
.24309 .62752 m .24584 .62751 L .24391 .62531 L F
0 0 .344 r
.40778 .57465 m .40957 .5782 L .40863 .57638 L F
.067 0 0 r
.38795 .70199 m .38678 .70419 L .38477 .70513 L F
.31 .052 .352 r
.39059 .69891 m .38995 .70111 L .38795 .70199 L F
0 0 0 r
.38995 .70111 m .38678 .70419 L .38795 .70199 L F
.348 .55 .908 r
.2095 .60109 m .21191 .6043 L .21278 .60242 L F
.227 .4 .827 r
.21191 .6043 m .21515 .60659 L .21278 .60242 L F
.461 .023 .119 r
.31638 .56427 m .31461 .56298 L .31678 .56218 L F
.746 .714 .821 r
.6233 .39509 m .62069 .39812 L .61918 .39434 L F
.788 .622 .675 r
.31562 .63215 m .31897 .63203 L .31967 .62875 L F
.205 .23 .666 r
.31967 .62875 m .32058 .62539 L .32028 .62567 L F
.31967 .62875 m .32067 .62829 L .32058 .62539 L F
.684 .341 .387 r
.31967 .62875 m .3226 .62951 L .32174 .63144 L F
.205 .23 .666 r
.31967 .62875 m .32174 .63144 L .32067 .62829 L F
.364 .033 .265 r
.23702 .56924 m .23624 .57182 L .23379 .57237 L F
.258 .104 .472 r
.23926 .56542 m .23885 .56856 L .23702 .56924 L F
.277 0 .232 r
.23807 .57112 m .23702 .56924 L .23885 .56856 L F
.23807 .57112 m .23624 .57182 L .23702 .56924 L F
.809 .634 .665 r
.56393 .40831 m .56493 .41131 L .56334 .41094 L F
.83 .613 .608 r
.56493 .41131 m .56167 .41377 L .56334 .41094 L F
.56493 .41131 m .56472 .41416 L .56167 .41377 L F
.72 .317 .284 r
.56393 .40831 m .56704 .4102 L .56493 .41131 L F
0 0 .291 r
.5657 .41295 m .56493 .41131 L .56704 .4102 L F
.5657 .41295 m .56472 .41416 L .56493 .41131 L F
.1 0 .101 r
.39249 .69806 m .39059 .69891 L .39348 .69613 L F
.183 0 .286 r
.39249 .69806 m .38995 .70111 L .39059 .69891 L F
.278 .11 .466 r
.28824 .60732 m .28981 .60907 L .29015 .60632 L F
.28824 .60732 m .28802 .60992 L .28981 .60907 L F
.365 .134 .425 r
.34609 .64701 m .34581 .64514 L .34321 .64826 L F
.008 0 0 r
.34609 .64701 m .34321 .64826 L .34165 .65011 L F
.718 .298 .248 r
.33624 .51206 m .33869 .51428 L .34024 .51289 L F
.55 .321 .521 r
.33869 .51428 m .34146 .5112 L .34024 .51289 L F
.396 .829 .956 r
.30528 .51586 m .31066 .51608 L .30804 .51672 L F
.098 0 0 r
.29907 .61085 m .29752 .61264 L .29525 .61316 L F
.287 0 .095 r
.30113 .60987 m .29752 .61264 L .29907 .61085 L F
0 .445 .809 r
.25285 .62173 m .25253 .62202 L .25051 .62022 L F
.25285 .62173 m .25475 .62282 L .25253 .62202 L F
.652 .668 .852 r
.35307 .55904 m .35656 .55997 L .35441 .55535 L F
.837 .555 .511 r
.35162 .56131 m .35656 .55997 L .35307 .55904 L F
.35162 .56131 m .35632 .56271 L .35656 .55997 L F
0 .091 .649 r
.35441 .55535 m .35656 .55997 L .35624 .55715 L F
.72 .447 .512 r
.36008 .56261 m .35656 .55997 L .36019 .55986 L F
.706 .434 .511 r
.35656 .55997 m .35982 .56227 L .35624 .55715 L F
.72 .447 .512 r
.36008 .56261 m .35632 .56271 L .35656 .55997 L F
.706 .434 .511 r
.35656 .55997 m .35632 .56271 L .35982 .56227 L F
0 .091 .649 r
.35441 .55535 m .35656 .55997 L .35624 .55715 L F
.757 .629 .718 r
.23762 .6037 m .24165 .60699 L .24006 .60334 L F
.23762 .6037 m .23921 .60751 L .24165 .60699 L F
.752 .604 .693 r
.23921 .60751 m .23906 .61047 L .24165 .60699 L F
.796 .742 .803 r
.24006 .60334 m .24165 .60699 L .24487 .60319 L F
.591 .682 .904 r
.57562 .43308 m .57222 .43105 L .57446 .42961 L F
.424 .845 .685 r
.57718 .43198 m .57562 .43308 L .57446 .42961 L F
0 .266 .773 r
.57773 .43155 m .57718 .43198 L .576 .42954 L F
.424 .845 .685 r
.57718 .43198 m .5789 .43115 L .5763 .43268 L F
.636 .951 .751 r
.58089 .42949 m .5789 .43115 L .57718 .43198 L F
.663 .846 .97 r
.58232 .43094 m .5789 .43115 L .58089 .42949 L F
.636 .951 .751 r
.58089 .42949 m .57718 .43198 L .58187 .43169 L F
.604 .192 .234 r
.57966 .43379 m .58187 .43169 L .57718 .43198 L F
0 .266 .773 r
.57966 .43379 m .57718 .43198 L .57773 .43155 L F
.424 .845 .685 r
.57718 .43198 m .5763 .43268 L .57562 .43308 L F
.99 .765 .502 r
.40106 .52172 m .39917 .52361 L .39938 .52067 L F
.40106 .52172 m .40071 .52518 L .39917 .52361 L F
.83 .902 .889 r
.40106 .52172 m .40192 .51797 L .40351 .51912 L F
.40106 .52172 m .39938 .52067 L .40192 .51797 L F
.404 0 0 r
.22749 .55752 m .22695 .55746 L .22451 .55619 L F
0 .461 .77 r
.2309 .55877 m .22695 .55746 L .22749 .55752 L F
.64 .322 .417 r
.33817 .65674 m .34036 .65663 L .33862 .65412 L F
0 0 .291 r
.23079 .57504 m .22936 .57831 L .2289 .57568 L F
.812 .506 .471 r
.37208 .58494 m .36828 .58206 L .37089 .58177 L F
.37208 .58494 m .36829 .58502 L .36828 .58206 L F
.703 .6 .739 r
.37471 .58193 m .37208 .58494 L .37089 .58177 L F
.195 .034 .422 r
.34704 .52091 m .34945 .51743 L .34785 .51885 L F
.014 .272 .772 r
.24778 .54192 m .24785 .53957 L .24554 .53989 L F
.504 .569 .854 r
.36391 .62502 m .36556 .62829 L .36442 .62688 L F
.702 .164 0 r
.36861 .631 m .36556 .62829 L .36758 .6282 L F
.389 .356 .701 r
.19482 .5881 m .1961 .58401 L .19424 .58546 L F
.075 0 0 r
.2379 .53396 m .24032 .53333 L .24222 .53182 L F
.665 .926 .63 r
.24222 .53182 m .24167 .5317 L .24447 .53103 L F
.24222 .53182 m .24032 .53333 L .24167 .5317 L F
.894 .727 .666 r
.56393 .40831 m .56101 .41117 L .56304 .40815 L F
.56393 .40831 m .56334 .41094 L .56101 .41117 L F
.699 .59 .731 r
.56652 .40498 m .56393 .40831 L .56385 .40585 L F
.999 .815 .476 r
.56385 .40585 m .56393 .40831 L .56304 .40815 L F
.395 .85 .89 r
.56667 .40736 m .56393 .40831 L .56304 .40815 L F
.472 .485 .79 r
.33704 .57828 m .33885 .58253 L .3409 .58137 L F
.23 .355 .784 r
.33885 .58253 m .34137 .58381 L .3409 .58137 L F
.636 .154 .089 r
.57478 .40298 m .5745 .40264 L .57148 .40188 L F
.554 .355 .566 r
.57273 .40532 m .57478 .40298 L .57148 .40188 L F
.798 .573 .596 r
.36328 .5627 m .36019 .55986 L .363 .56076 L F
.36328 .5627 m .36008 .56261 L .36019 .55986 L F
.393 .706 .985 r
.3649 .5614 m .36328 .5627 L .363 .56076 L F
.723 .591 .708 r
.363 .56076 m .36328 .5627 L .36019 .55986 L F
0 0 .053 r
.30789 .57843 m .30837 .57986 L .31014 .57763 L F
.30789 .57843 m .30637 .58167 L .30837 .57986 L F
.244 0 0 r
.36828 .58206 m .3672 .58231 L .36417 .58192 L F
0 0 .103 r
.36828 .58206 m .36829 .58434 L .36844 .58402 L F
0 .12 .661 r
.36863 .5835 m .3686 .58373 L .36852 .58365 L F
.36863 .5835 m .36852 .58365 L .3672 .58231 L F
0 0 .103 r
.36851 .58366 m .36846 .58426 L .36852 .58374 L F
.36828 .58206 m .36842 .58378 L .36851 .58366 L F
.36842 .58378 m .36846 .58426 L .36851 .58366 L F
.36849 .5829 m .36852 .58374 L .36858 .58326 L F
.36828 .58206 m .36852 .58374 L .36849 .5829 L F
.722 .343 .331 r
.3672 .58231 m .36852 .58365 L .36266 .58309 L F
.36852 .58365 m .3686 .58373 L .36852 .58372 L F
.36852 .58365 m .36852 .58372 L .36266 .58309 L F
0 0 0 r
.36829 .58502 m .3656 .58784 L .36678 .58671 L F
.795 .819 .871 r
.36852 .58375 m .36678 .58671 L .36098 .5853 L F
.3685 .58388 m .36678 .58671 L .36852 .58375 L F
.64 .826 .412 r
.36755 .58521 m .36678 .58671 L .3685 .58388 L F
.795 .819 .871 r
.3686 .58373 m .3685 .58388 L .36852 .58375 L F
.64 .826 .412 r
.36854 .58382 m .3685 .58388 L .3686 .58373 L F
.36755 .58521 m .3685 .58388 L .36854 .58382 L F
0 0 .103 r
.36844 .58402 m .36829 .58502 L .36846 .58426 L F
.36829 .58434 m .36829 .58502 L .36844 .58402 L F
.795 .819 .871 r
.3686 .58373 m .36098 .5853 L .36266 .58309 L F
.64 .826 .412 r
.36755 .58521 m .36854 .58382 L .36863 .5835 L F
.36854 .58382 m .3686 .58373 L .36863 .5835 L F
0 0 .103 r
.36858 .58326 m .3685 .58395 L .36863 .5835 L F
.3685 .58395 m .36846 .58426 L .36863 .5835 L F
.36828 .58206 m .36863 .5835 L .3672 .58231 L F
.697 .705 .854 r
.71545 .35097 m .71221 .34802 L .7166 .34893 L F
.777 .864 .426 r
.40366 .59163 m .40247 .59351 L .40181 .5904 L F
.40366 .59163 m .40262 .59386 L .40247 .59351 L F
.27 0 .147 r
.24502 .55987 m .24408 .562 L .24184 .56243 L F
.168 0 .1 r
.24597 .56125 m .24502 .55987 L .24707 .55889 L F
.24597 .56125 m .24408 .562 L .24502 .55987 L F
.185 0 .316 r
.33398 .59927 m .33228 .59783 L .33437 .59691 L F
.33398 .59927 m .33155 .60018 L .33228 .59783 L F
.597 .534 .754 r
.39447 .61373 m .39421 .61604 L .39209 .61628 L F
.393 .706 .985 r
.3649 .5614 m .363 .56076 L .36502 .55877 L F
.801 .488 .46 r
.33929 .64521 m .34082 .64826 L .34282 .64795 L F
0 .103 .629 r
.34021 .6437 m .34082 .64826 L .33929 .64521 L F
.205 .423 .852 r
.34352 .57992 m .34344 .58197 L .3409 .58137 L F
.34352 .57992 m .34509 .58309 L .34344 .58197 L F
.15 0 0 r
.34571 .58493 m .34344 .58197 L .34509 .58309 L F
.651 .454 .604 r
.28468 .62291 m .28228 .62608 L .2822 .62324 L F
.12 0 0 r
.35687 .71434 m .36102 .71482 L .35922 .71466 L F
.391 .751 .993 r
.36102 .71482 m .36173 .71347 L .35922 .71466 L F
.36102 .71482 m .36364 .71472 L .36173 .71347 L F
.911 .695 .597 r
.42326 .57866 m .42187 .57822 L .42215 .57549 L F
.906 .701 .614 r
.42326 .57866 m .42139 .58121 L .42187 .57822 L F
.42326 .57866 m .42373 .58206 L .42139 .58121 L F
.573 .47 .699 r
.42691 .58114 m .42326 .57866 L .42568 .57895 L F
.42691 .58114 m .42373 .58206 L .42326 .57866 L F
0 0 .118 r
.4088 .5932 m .40864 .59118 L .40878 .59037 L F
.768 .572 .633 r
.5992 .43364 m .59645 .43321 L .59786 .43206 L F
.5992 .43364 m .59691 .43557 L .59645 .43321 L F
.5992 .43364 m .59912 .43657 L .59691 .43557 L F
.676 .915 .59 r
.6004 .43172 m .5992 .43364 L .60158 .43067 L F
.444 .303 .595 r
.60173 .43546 m .59912 .43657 L .5992 .43364 L F
.676 .915 .59 r
.60158 .43067 m .5992 .43364 L .6004 .43172 L F
.60158 .43067 m .5992 .43364 L .6004 .43172 L F
.349 .279 .636 r
.32232 .52189 m .32368 .51852 L .32156 .51936 L F
.32232 .52189 m .32413 .52119 L .32368 .51852 L F
.207 .069 .463 r
.32232 .52189 m .32392 .52357 L .32413 .52119 L F
.32232 .52189 m .32223 .52472 L .32392 .52357 L F
.32232 .52189 m .32392 .52357 L .32413 .52119 L F
.32232 .52189 m .32223 .52472 L .32392 .52357 L F
.928 .599 .395 r
.28613 .55644 m .2884 .55862 L .28816 .5561 L F
.281 .455 .855 r
.2884 .55862 m .29112 .55739 L .28816 .5561 L F
0 0 .053 r
.2884 .55862 m .28835 .56109 L .29112 .55739 L F
.094 0 0 r
.71943 .34125 m .7222 .34143 L .72441 .34135 L F
.321 .651 .97 r
.72501 .33955 m .72441 .34135 L .7222 .34143 L F
.72501 .33955 m .72641 .34099 L .72441 .34135 L F
.585 .531 .761 r
.25751 .60308 m .25863 .60727 L .25928 .60429 L F
.728 .723 .197 r
.25928 .60429 m .25863 .60727 L .25919 .60476 L F
.342 0 0 r
.25475 .62282 m .25706 .62314 L .25787 .62276 L F
.689 .167 0 r
.2529 .62176 m .25706 .62314 L .25475 .62282 L F
.25285 .62173 m .25299 .62178 L .2529 .62176 L F
.25299 .62178 m .25706 .62314 L .2529 .62176 L F
.446 .659 .952 r
.25591 .61956 m .25929 .62258 L .2587 .62282 L F
.342 0 0 r
.25787 .62276 m .25706 .62314 L .25881 .62274 L F
.387 .847 .882 r
.25699 .62354 m .25935 .62291 L .25706 .62314 L F
.446 .659 .952 r
.25669 .62246 m .2587 .62282 L .25699 .62354 L F
.25591 .61956 m .2587 .62282 L .25669 .62246 L F
.689 .167 0 r
.25285 .62173 m .25659 .62337 L .25706 .62314 L F
.25659 .62337 m .25699 .62354 L .25706 .62314 L F
.13 .678 .784 r
.25706 .62314 m .26135 .62291 L .25881 .62274 L F
.434 .472 .8 r
.36698 .59416 m .36641 .58936 L .36733 .59149 L F
.663 .187 .113 r
.36733 .59149 m .36923 .59367 L .36698 .59416 L F
.762 .626 .709 r
.70684 .32233 m .71134 .32255 L .70889 .3196 L F
.752 .493 .541 r
.70906 .3251 m .71134 .32255 L .70684 .32233 L F
.723 .466 .537 r
.71227 .32416 m .71134 .32255 L .70906 .3251 L F
.71227 .32416 m .71267 .32296 L .71134 .32255 L F
.317 .559 .923 r
.29614 .62171 m .29497 .62321 L .29282 .62015 L F
.9 .773 .712 r
.2985 .62282 m .29676 .62345 L .29806 .6221 L F
.123 .274 .747 r
.29614 .62171 m .29672 .62352 L .29497 .62321 L F
.29672 .62352 m .29622 .62432 L .29497 .62321 L F
.29672 .62352 m .29729 .62526 L .29622 .62432 L F
.914 .758 .675 r
.29531 .62399 m .29729 .62526 L .29614 .62171 L F
.9 .773 .712 r
.29676 .62345 m .29531 .62399 L .29728 .62264 L F
.29676 .62345 m .29728 .62264 L .29806 .6221 L F
.902 .648 .14 r
.40685 .57076 m .40724 .5695 L .40645 .56829 L F
.40685 .57076 m .40745 .57203 L .40724 .5695 L F
.763 .384 .336 r
.33787 .63897 m .33947 .64201 L .33794 .64079 L F
.484 .842 .994 r
.27675 .52388 m .27302 .52383 L .27524 .52397 L F
.308 .799 .863 r
.2776 .5233 m .27675 .52388 L .27524 .52397 L F
.767 .736 .824 r
.35245 .55684 m .34966 .5595 L .35307 .55904 L F
.652 .668 .852 r
.35307 .55904 m .35441 .55535 L .35245 .55684 L F
.798 .731 .789 r
.56761 .41476 m .56948 .4182 L .56581 .41666 L F
.024 .534 .868 r
.56581 .41666 m .56948 .4182 L .56836 .41733 L F
.8 .731 .788 r
.572 .41447 m .56948 .4182 L .56761 .41476 L F
.588 .906 .982 r
.56836 .41733 m .56948 .4182 L .5718 .41703 L F
.546 .429 .671 r
.35203 .60057 m .35264 .60436 L .35015 .60434 L F
.906 .86 .784 r
.70974 .29836 m .7111 .30039 L .70866 .30374 L F
.819 .849 .871 r
.71375 .29734 m .7111 .30039 L .70974 .29836 L F
0 .057 .591 r
.38887 .6584 m .38865 .65977 L .38822 .65734 L F
.39011 .6604 m .38822 .65734 L .38908 .65715 L F
.899 .931 .553 r
.38785 .65867 m .38907 .65715 L .38903 .65629 L F
.38907 .65715 m .38908 .65715 L .38908 .65713 L F
.38907 .65715 m .38908 .65713 L .38903 .65629 L F
0 .057 .591 r
.39011 .6604 m .38885 .6609 L .38865 .65977 L F
.39011 .6604 m .38865 .65977 L .38887 .6584 L F
0 0 .118 r
.73827 .33447 m .73771 .3366 L .73593 .3385 L F
.599 .928 .712 r
.73771 .3366 m .73456 .33914 L .73593 .3385 L F
.187 0 .001 r
.3644 .63871 m .36044 .64179 L .36431 .6416 L F
.321 .729 .979 r
.36205 .63738 m .3644 .63871 L .36633 .6384 L F
.326 .141 .47 r
.36633 .6384 m .3644 .63871 L .36431 .6416 L F
.825 .406 .244 r
.35693 .51557 m .35198 .51479 L .35316 .51277 L F
.386 0 0 r
.34386 .5024 m .34584 .50308 L .34772 .50329 L F
.416 0 0 r
.34584 .50308 m .34996 .50298 L .34772 .50329 L F
0 0 0 r
.30815 .6001 m .30612 .6034 L .3072 .60131 L F
.809 .917 .911 r
.64028 .39596 m .63734 .39868 L .6362 .39748 L F
.634 .579 .775 r
.29057 .62044 m .28825 .62126 L .29072 .61933 L F
.517 .431 .697 r
.35392 .59701 m .35203 .60057 L .35213 .59765 L F
.383 .17 .462 r
.32895 .55333 m .32629 .55665 L .32908 .55561 L F
.299 .354 .752 r
.28844 .62593 m .28926 .6294 L .29088 .62799 L F
.054 .02 .497 r
.28926 .6294 m .29065 .63052 L .29088 .62799 L F
.28926 .6294 m .28955 .63255 L .29065 .63052 L F
.266 0 0 r
.33433 .66866 m .33367 .66842 L .33214 .6678 L F
.33433 .66866 m .3368 .66964 L .33367 .66842 L F
.815 .406 0 r
.39909 .54581 m .40102 .54906 L .40007 .54728 L F
.611 .423 .602 r
.59645 .43321 m .59691 .43557 L .59334 .43713 L F
.464 .234 .479 r
.29071 .60381 m .29305 .60338 L .29333 .6009 L F
.476 .294 .554 r
.29333 .6009 m .29561 .60031 L .29568 .59766 L F
.465 .242 .49 r
.29305 .60338 m .29561 .60031 L .29333 .6009 L F
.981 .706 .323 r
.72419 .287 m .7254 .28846 L .72433 .2846 L F
.408 .613 .933 r
.62433 .43133 m .62168 .42961 L .62391 .43168 L F
.425 0 0 r
.62391 .43168 m .62752 .43261 L .62433 .43133 L F
.59 .284 .418 r
.34609 .64701 m .3482 .64727 L .34581 .64514 L F
0 0 .386 r
.31114 .64437 m .31042 .64429 L .31119 .64745 L F
.54 .221 .376 r
.33366 .64382 m .33794 .64079 L .33499 .64162 L F
.517 .865 .611 r
.33229 .67611 m .3289 .67881 L .33141 .67828 L F
.192 0 .073 r
.3347 .67595 m .33229 .67611 L .33141 .67828 L F
.684 .969 .926 r
.34393 .6647 m .34596 .66348 L .34443 .66334 L F
.756 .969 .69 r
.34191 .66615 m .34393 .6647 L .34443 .66334 L F
.243 0 0 r
.31509 .51136 m .31938 .50923 L .31718 .51096 L F
.31509 .51136 m .31762 .51108 L .31938 .50923 L F
.616 .824 .98 r
.32209 .50828 m .31938 .50923 L .32017 .50695 L F
.8 .934 .569 r
.31938 .50923 m .31762 .51108 L .32017 .50695 L F
0 0 0 r
.39485 .69476 m .39348 .69613 L .39596 .69277 L F
.369 .14 .431 r
.39485 .69476 m .39249 .69806 L .39348 .69613 L F
0 0 .25 r
.40102 .54906 m .40173 .55217 L .40169 .55355 L F
0 0 .296 r
.40173 .55217 m .40154 .55591 L .40169 .55355 L F
.156 .631 .927 r
.22764 .58374 m .22961 .58472 L .22743 .58456 L F
.467 .192 .412 r
.29071 .60381 m .29265 .6056 L .29305 .60338 L F
.29071 .60381 m .29015 .60632 L .29265 .6056 L F
.132 .64 .9 r
.21991 .61023 m .21797 .60952 L .21712 .60948 L F
0 .446 .788 r
.21991 .61023 m .22016 .60998 L .21797 .60952 L F
.21991 .61023 m .22224 .611 L .22016 .60998 L F
.692 .79 .925 r
.56251 .40445 m .56385 .40585 L .5598 .40509 L F
.5598 .40509 m .56385 .40585 L .56251 .40445 L F
.725 .799 .91 r
.56251 .40445 m .56652 .40498 L .56385 .40585 L F
0 .056 .577 r
.19275 .60753 m .19418 .60882 L .19388 .60577 L F
.718 .949 .953 r
.63445 .40628 m .63892 .40518 L .63826 .4047 L F
.804 1 .812 r
.63978 .40288 m .63958 .40449 L .64157 .40245 L F
0 0 0 r
.64157 .40245 m .64285 .40248 L .63978 .40288 L F
.497 .802 .999 r
.63978 .40288 m .64285 .40248 L .63989 .40197 L F
.63978 .40288 m .63989 .40197 L .63896 .40181 L F
.804 1 .812 r
.63978 .40288 m .63892 .40518 L .63958 .40449 L F
.8 .999 .833 r
.63826 .4047 m .63892 .40518 L .63978 .40288 L F
.999 .809 .514 r
.72866 .33875 m .72747 .34025 L .72836 .33756 L F
.72866 .33875 m .7286 .34177 L .72747 .34025 L F
.616 .72 .92 r
.73054 .33634 m .72866 .33875 L .72836 .33756 L F
.66 .623 .801 r
.29322 .556 m .29026 .55668 L .28872 .553 L F
.842 .469 0 r
.34266 .60084 m .34354 .60345 L .34518 .60049 L F
.871 .593 .514 r
.42373 .5843 m .42139 .58121 L .42373 .58206 L F
.637 .441 .6 r
.42691 .58114 m .42373 .5843 L .42373 .58206 L F
.527 .351 .586 r
.36155 .59813 m .36427 .59998 L .36437 .59725 L F
.36155 .59813 m .36427 .59998 L .36437 .59725 L F
.818 .336 0 r
.19531 .60575 m .19545 .60357 L .19388 .60577 L F
.19531 .60575 m .19761 .60699 L .19545 .60357 L F
0 .409 .825 r
.35885 .50466 m .35898 .50544 L .35615 .50356 L F
.35885 .50466 m .36036 .50595 L .35898 .50544 L F
.699 .501 .616 r
.30719 .55677 m .30711 .5597 L .30994 .55649 L F
.073 .28 .767 r
.30994 .55649 m .3126 .55876 L .31255 .55594 L F
.485 .019 .07 r
.32916 .60265 m .32552 .60335 L .32657 .60288 L F
0 0 0 r
.39734 .69142 m .39596 .69277 L .39861 .68965 L F
.218 .021 .386 r
.39734 .69142 m .39485 .69476 L .39596 .69277 L F
.444 .25 .522 r
.39861 .68965 m .39596 .69277 L .39699 .69126 L F
.567 .523 .766 r
.19482 .5881 m .19599 .59169 L .19823 .59073 L F
.119 0 .344 r
.19597 .59465 m .19823 .59073 L .19599 .59169 L F
.632 .444 .609 r
.30664 .65594 m .309 .65659 L .30843 .65444 L F
.374 .284 .625 r
.30843 .65444 m .309 .65659 L .31057 .65675 L F
.65 .301 .367 r
.31057 .65675 m .31099 .65485 L .30843 .65444 L F
.822 .789 .289 r
.38254 .60898 m .38181 .61365 L .3801 .61262 L F
.68 .797 .937 r
.56538 .39768 m .56107 .39759 L .56401 .39681 L F
.56538 .39768 m .56107 .39759 L .56401 .39681 L F
.124 .608 .914 r
.56538 .39768 m .56756 .398 L .56401 .39681 L F
.56538 .39768 m .56756 .398 L .56401 .39681 L F
.828 .993 .858 r
.36871 .57046 m .36955 .57236 L .37212 .56993 L F
.36871 .57046 m .36868 .57179 L .36955 .57236 L F
.716 .298 .251 r
.36773 .57422 m .36955 .57236 L .36868 .57179 L F
.36773 .57422 m .37152 .5747 L .36955 .57236 L F
.728 .202 0 r
.36955 .57236 m .37152 .5747 L .37331 .57559 L F
.405 .412 .754 r
.36341 .53659 m .36244 .54089 L .361 .53719 L F
.36341 .53659 m .36487 .54022 L .36244 .54089 L F
.376 .307 .651 r
.36487 .54022 m .36487 .54298 L .36244 .54089 L F
.486 .304 .559 r
.36487 .54298 m .36245 .54381 L .36244 .54089 L F
.29 .069 .395 r
.20804 .55674 m .20959 .55844 L .21016 .55599 L F
.20804 .55674 m .20764 .55929 L .20959 .55844 L F
.853 .798 .305 r
.29519 .55557 m .2948 .55921 L .29322 .556 L F
.29519 .55557 m .29458 .55811 L .2948 .55921 L F
.872 .899 .481 r
.29458 .55811 m .2936 .5619 L .2948 .55921 L F
.719 .556 .668 r
.69809 .34493 m .69507 .34788 L .69493 .34509 L F
.69809 .34493 m .69903 .3479 L .69507 .34788 L F
.696 .544 .676 r
.70124 .34521 m .69903 .3479 L .69809 .34493 L F
.327 0 0 r
.34099 .67368 m .34168 .67294 L .33824 .67372 L F
.083 0 0 r
.34342 .67297 m .34168 .67294 L .34099 .67368 L F
.828 .857 .869 r
.37263 .54848 m .37427 .54982 L .37689 .54703 L F
0 0 .054 r
.37427 .54982 m .37481 .55103 L .37712 .55099 L F
.37427 .54982 m .37379 .55245 L .37481 .55103 L F
.514 .343 .587 r
.35266 .61704 m .35534 .61647 L .35503 .61336 L F
.596 .509 .727 r
.35317 .6197 m .35534 .61647 L .35266 .61704 L F
.306 .191 .554 r
.19497 .57586 m .19739 .5772 L .19741 .57451 L F
.19497 .57586 m .19516 .57849 L .19739 .5772 L F
.308 0 .122 r
.26722 .55695 m .2664 .55845 L .26419 .55874 L F
.366 0 .186 r
.26958 .55636 m .2664 .55845 L .26722 .55695 L F
.165 0 .245 r
.31074 .59679 m .30815 .6001 L .30921 .59794 L F
.291 .062 .384 r
.30921 .59794 m .31174 .59459 L .31074 .59679 L F
.307 .339 .731 r
.36757 .51851 m .36825 .51436 L .36562 .51707 L F
.36757 .51851 m .36895 .51873 L .36825 .51436 L F
.579 .605 .843 r
.36757 .51851 m .3698 .51976 L .36988 .5204 L F
.3698 .51976 m .37088 .52037 L .36988 .5204 L F
.977 .737 .32 r
.37061 .52362 m .36996 .52373 L .36988 .5204 L F
0 0 .06 r
.36988 .5204 m .37005 .52198 L .37001 .52152 L F
.36988 .5204 m .37001 .52152 L .36975 .51907 L F
.34 .237 .59 r
.36757 .51851 m .36988 .5204 L .36895 .51873 L F
.465 .068 .202 r
.33141 .51925 m .33047 .52073 L .32818 .52078 L F
.281 0 .139 r
.33381 .51859 m .33047 .52073 L .33141 .51925 L F
.686 .973 .78 r
.62064 .41396 m .62358 .41173 L .62323 .41292 L F
.423 .069 .258 r
.62358 .41173 m .62601 .41278 L .62323 .41292 L F
.62358 .41173 m .62679 .41112 L .62601 .41278 L F
.781 .323 .157 r
.22099 .56751 m .22306 .56647 L .22213 .56523 L F
.22099 .56751 m .22305 .56871 L .22306 .56647 L F
.425 .019 .162 r
.22306 .56647 m .22305 .56871 L .22594 .56609 L F
.842 .748 .759 r
.57288 .42273 m .57444 .42717 L .57091 .42664 L F
.85 .567 .509 r
.57091 .42664 m .57444 .42717 L .57446 .42961 L F
.512 .097 .191 r
.57444 .42717 m .57605 .42859 L .57446 .42961 L F
.57444 .42717 m .57778 .42718 L .57605 .42859 L F
.156 .27 .731 r
.26623 .60966 m .26643 .6135 L .26541 .61012 L F
.92 .879 .778 r
.26623 .60966 m .26459 .61259 L .26643 .6135 L F
.958 .848 .691 r
.65574 .40772 m .65414 .40888 L .65464 .40504 L F
.76 .245 0 r
.6558 .41017 m .65414 .40888 L .65574 .40772 L F
.617 .713 .914 r
.65848 .40687 m .65574 .40772 L .65464 .40504 L F
.944 .788 .657 r
.7165 .29651 m .71753 .30042 L .71811 .29791 L F
.7165 .29651 m .71753 .30042 L .71811 .29791 L F
.793 .756 .819 r
.24006 .60334 m .24487 .60319 L .24265 .60019 L F
.258 .04 .381 r
.64407 .42434 m .64527 .42579 L .64456 .42338 L F
.64407 .42434 m .64327 .42664 L .64527 .42579 L F
.847 .497 .39 r
.37173 .57687 m .37331 .57559 L .37152 .5747 L F
0 0 0 r
.33539 .54042 m .33102 .54299 L .33333 .54157 L F
.751 .715 .819 r
.36787 .658 m .37238 .65818 L .37031 .65702 L F
.603 .636 .857 r
.37238 .65818 m .37269 .65469 L .37031 .65702 L F
.37238 .65818 m .37431 .65805 L .37269 .65469 L F
.598 .415 .605 r
.37185 .66076 m .37431 .65805 L .37238 .65818 L F
0 0 .403 r
.22802 .59932 m .22737 .6009 L .22702 .59738 L F
.821 .811 .841 r
.27953 .62917 m .28129 .62807 L .28228 .62608 L F
.318 .201 .559 r
.39825 .66582 m .39621 .66986 L .39737 .66755 L F
.697 .705 .854 r
.71545 .35097 m .7122 .35015 L .71221 .34802 L F
.368 .384 .746 r
.22575 .59086 m .22602 .59455 L .22536 .59035 L F
.056 0 .342 r
.29215 .61597 m .29072 .61933 L .29047 .61668 L F
.543 .928 .868 r
.37039 .56967 m .36871 .57046 L .37212 .56993 L F
.181 .698 .886 r
.27063 .61922 m .27246 .61905 L .27405 .61947 L F
.76 .646 .736 r
.27405 .61947 m .27172 .62293 L .27009 .61918 L F
.181 .698 .886 r
.27009 .61918 m .27246 .61905 L .27405 .61947 L F
.467 .867 .964 r
.27405 .61947 m .27246 .61905 L .27491 .61833 L F
.178 0 0 r
.27246 .61905 m .27298 .62047 L .27442 .61887 L F
.27246 .61905 m .27442 .61887 L .27491 .61833 L F
.181 .698 .886 r
.27009 .61918 m .27246 .61905 L .27063 .61922 L F
.584 .904 .648 r
.27405 .61947 m .27491 .61833 L .27663 .61715 L F
.243 0 .319 r
.57306 .42076 m .57051 .42397 L .57288 .42273 L F
.329 .144 .471 r
.57288 .42273 m .57051 .42397 L .57091 .42664 L F
.243 0 .319 r
.57288 .42273 m .57051 .42397 L .57306 .42076 L F
.842 .748 .759 r
.57288 .42273 m .57091 .42664 L .57051 .42397 L F
.71 .542 .66 r
.69493 .34509 m .69252 .34772 L .69107 .34459 L F
.69493 .34509 m .69507 .34788 L .69252 .34772 L F
0 0 0 r
.22213 .55765 m .22426 .55653 L .22451 .55619 L F
.22213 .55765 m .2198 .55844 L .22426 .55653 L F
.925 .592 .389 r
.60776 .43578 m .60958 .43654 L .60821 .43822 L F
.676 .232 .19 r
.60958 .43654 m .61213 .43863 L .60821 .43822 L F
.573 .743 .957 r
.56535 .43058 m .5615 .42955 L .56423 .42873 L F
.581 .696 .921 r
.56682 .42792 m .56535 .43058 L .56423 .42873 L F
.56682 .42792 m .56808 .4299 L .56535 .43058 L F
.205 0 0 r
.30005 .62373 m .29729 .62526 L .2985 .62282 L F
0 .274 .661 r
.30048 .62384 m .30005 .62373 L .2985 .62282 L F
.30048 .62384 m .30404 .62574 L .30005 .62373 L F
.468 .448 .752 r
.30404 .62574 m .30198 .6266 L .30005 .62373 L F
.478 .228 .457 r
.3602 .57517 m .36089 .5778 L .35729 .57811 L F
.588 .616 .847 r
.36131 .57165 m .36284 .5752 L .3602 .57517 L F
.74 .387 .383 r
.36241 .57786 m .3602 .57517 L .36284 .5752 L F
.36241 .57786 m .36089 .5778 L .3602 .57517 L F
.699 .39 .449 r
.57354 .43995 m .5772 .43978 L .5774 .44217 L F
.732 .493 .567 r
.57996 .43954 m .5774 .44217 L .5772 .43978 L F
.695 .513 .637 r
.28468 .62291 m .28458 .62611 L .28228 .62608 L F
0 0 0 r
.21567 .54969 m .21738 .54908 L .21909 .54715 L F
.21909 .54715 m .22027 .54602 L .22128 .54376 L F
.21909 .54715 m .21887 .54771 L .22027 .54602 L F
.21909 .54715 m .21738 .54908 L .21887 .54771 L F
.072 .261 .751 r
.64841 .4255 m .64978 .42935 L .64757 .42743 L F
.59 .279 .41 r
.64757 .42743 m .64978 .42935 L .64627 .42972 L F
.415 .177 .443 r
.38192 .55899 m .37945 .56235 L .37979 .5599 L F
.758 .342 .262 r
.58361 .43395 m .58472 .43065 L .58187 .43169 L F
.653 .169 0 r
.33336 .70086 m .33478 .70227 L .3363 .70432 L F
.202 0 .255 r
.29836 .59444 m .29568 .59766 L .29755 .5969 L F
.231 0 .268 r
.29836 .59444 m .29918 .59595 L .29981 .59347 L F
.29836 .59444 m .29755 .5969 L .29918 .59595 L F
.676 .97 .919 r
.33102 .54299 m .331 .54228 L .33017 .54398 L F
.983 .698 .371 r
.41655 .55952 m .41515 .56116 L .41558 .55795 L F
.41655 .55952 m .41652 .56232 L .41515 .56116 L F
.571 .94 .867 r
.25308 .52678 m .25098 .52808 L .24842 .52856 L F
.746 .634 .736 r
.68763 .34111 m .68828 .34452 L .68463 .34471 L F
.607 .183 .211 r
.68463 .34471 m .68828 .34452 L .68741 .34645 L F
.885 .755 .714 r
.69107 .34459 m .68741 .34645 L .68828 .34452 L F
.625 .696 .896 r
.62829 .3936 m .6271 .39763 L .62558 .3942 L F
.62829 .3936 m .63035 .39658 L .6271 .39763 L F
.134 0 .12 r
.32174 .63144 m .3226 .62951 L .3247 .62856 L F
.749 .856 .42 r
.70807 .3341 m .70623 .33841 L .70944 .33564 L F
.70807 .3341 m .70634 .33774 L .70623 .33841 L F
.748 .91 .534 r
.70623 .33841 m .70634 .33774 L .70508 .33956 L F
.629 .772 .949 r
.27028 .53136 m .27216 .53288 L .27429 .53183 L F
.448 .64 .938 r
.23148 .61987 m .23272 .61751 L .23063 .61818 L F
.23148 .61987 m .23335 .61957 L .23272 .61751 L F
.368 .384 .746 r
.22575 .59086 m .22795 .59444 L .22602 .59455 L F
.419 .417 .751 r
.22795 .59444 m .22702 .59738 L .22602 .59455 L F
.675 .513 .658 r
.70124 .34521 m .70237 .34864 L .69903 .3479 L F
0 .488 .863 r
.70345 .34528 m .70124 .34521 L .70268 .34272 L F
0 0 .322 r
.70325 .3431 m .70345 .34528 L .70268 .34272 L F
.924 .636 .156 r
.70311 .34454 m .70345 .34528 L .70325 .3431 L F
0 .488 .863 r
.70345 .34528 m .70376 .34597 L .70124 .34521 L F
.674 .513 .658 r
.70505 .34762 m .70124 .34521 L .70521 .3464 L F
.924 .636 .156 r
.70294 .34622 m .70345 .34528 L .70311 .34454 L F
0 .488 .863 r
.70345 .34528 m .70521 .3464 L .70376 .34597 L F
.674 .513 .658 r
.70505 .34762 m .70237 .34864 L .70124 .34521 L F
.58 .183 .255 r
.31258 .65636 m .3152 .65431 L .31099 .65485 L F
0 .273 .655 r
.31545 .65437 m .3152 .65431 L .31258 .65636 L F
.31545 .65437 m .31723 .65531 L .3152 .65431 L F
.435 .845 .968 r
.28424 .5215 m .28823 .52131 L .28588 .52202 L F
.765 .572 .637 r
.3739 .52036 m .36988 .5204 L .37088 .52037 L F
.854 .818 .813 r
.36945 .58025 m .37309 .58249 L .37173 .57687 L F
.896 .705 .636 r
.36945 .58025 m .37093 .58078 L .37309 .58249 L F
.297 .442 .838 r
.37173 .57687 m .37309 .58249 L .37478 .57957 L F
.452 .266 .537 r
.37093 .58078 m .37478 .57957 L .37309 .58249 L F
.947 .732 .58 r
.42215 .57549 m .4199 .57716 L .42036 .57447 L F
.42215 .57549 m .42187 .57822 L .4199 .57716 L F
.8 .731 .788 r
.572 .41447 m .56761 .41476 L .57036 .4157 L F
.988 .739 .462 r
.5718 .41703 m .572 .41447 L .57036 .4157 L F
.71 .607 .74 r
.23762 .6037 m .23475 .60761 L .23921 .60751 L F
.754 .606 .693 r
.23601 .60862 m .23921 .60751 L .23475 .60761 L F
.23601 .60862 m .23906 .61047 L .23921 .60751 L F
.419 .125 .357 r
.37772 .564 m .37688 .56549 L .37446 .56607 L F
.06 .088 .576 r
.62224 .42698 m .61954 .42403 L .62193 .42351 L F
.966 .77 .587 r
.61982 .42903 m .62224 .42698 L .62223 .42821 L F
.148 .251 .715 r
.6235 .4246 m .62224 .42698 L .62193 .42351 L F
0 0 0 r
.62223 .42821 m .62224 .42698 L .6235 .4246 L F
.616 .466 .656 r
.38542 .6039 m .38802 .60025 L .38641 .60146 L F
.133 .618 .916 r
.33946 .57501 m .33962 .57238 L .34222 .57215 L F
0 0 0 r
.33808 .55062 m .33529 .552 L .3338 .55233 L F
.653 .162 .071 r
.34022 .55252 m .33529 .552 L .33808 .55062 L F
.591 .028 0 r
.3419 .55332 m .33808 .55062 L .34082 .55035 L F
.3419 .55332 m .34022 .55252 L .33808 .55062 L F
.55 .235 .387 r
.57576 .42243 m .57306 .42076 L .57288 .42273 L F
.094 .343 .814 r
.31277 .63524 m .31463 .63871 L .31532 .63722 L F
.695 .883 .5 r
.31532 .63722 m .31463 .63871 L .31314 .64057 L F
.465 .366 .658 r
.31719 .64081 m .31463 .63871 L .31708 .63821 L F
.31575 .63963 m .31491 .64058 L .31463 .63871 L F
0 0 .065 r
.31799 .637 m .31708 .63821 L .31827 .63514 L F
.971 .714 .487 r
.31509 .63984 m .31685 .6384 L .31799 .637 L F
.31685 .6384 m .31708 .63821 L .31743 .63775 L F
.31685 .6384 m .31743 .63775 L .31799 .637 L F
.465 .366 .658 r
.31719 .64081 m .31501 .64127 L .31491 .64058 L F
.31719 .64081 m .31491 .64058 L .31575 .63963 L F
.349 .764 .979 r
.60919 .39456 m .61044 .3954 L .60636 .39476 L F
.667 .92 .975 r
.61152 .39332 m .61044 .3954 L .60919 .39456 L F
.655 .908 .98 r
.61393 .39277 m .61044 .3954 L .61152 .39332 L F
.366 .206 .528 r
.29568 .59766 m .29753 .59937 L .29755 .5969 L F
.29568 .59766 m .29561 .60031 L .29753 .59937 L F
.807 .622 .652 r
.71581 .30329 m .71985 .30401 L .71753 .30042 L F
.801 .502 .483 r
.71754 .30582 m .71985 .30401 L .71581 .30329 L F
.9 .692 .612 r
.71754 .30582 m .71955 .30717 L .71985 .30401 L F
.429 .125 .346 r
.36997 .5621 m .37227 .56187 L .37304 .55972 L F
.36997 .5621 m .37227 .56187 L .37304 .55972 L F
0 0 0 r
.37227 .56187 m .37447 .55863 L .37304 .55972 L F
.59 .513 .737 r
.35534 .61647 m .35696 .61178 L .35503 .61336 L F
.859 .774 .766 r
.69104 .32631 m .68714 .32812 L .68924 .32493 L F
.69104 .32631 m .68922 .32991 L .68714 .32812 L F
.748 .524 .59 r
.31345 .52848 m .31688 .52905 L .31499 .52811 L F
.354 0 0 r
.32536 .51461 m .32593 .51495 L .32754 .51525 L F
.87 .429 .049 r
.23154 .60344 m .23315 .60663 L .23475 .60761 L F
.545 0 0 r
.23315 .60663 m .23601 .60862 L .23475 .60761 L F
.903 .547 .08 r
.60362 .40441 m .60525 .40842 L .60531 .40685 L F
0 0 .321 r
.60525 .40842 m .6058 .41089 L .60531 .40685 L F
.619 .576 .784 r
.41831 .55649 m .41435 .5534 L .41739 .55396 L F
.874 .791 .765 r
.41799 .55107 m .41826 .55214 L .42146 .54977 L F
0 .042 .603 r
.41799 .55107 m .41831 .55202 L .41826 .55214 L F
.7 .976 .773 r
.42146 .54977 m .41826 .55214 L .4176 .55374 L F
0 .042 .603 r
.41831 .55202 m .41928 .55499 L .41826 .55214 L F
.7 .976 .773 r
.4176 .55374 m .41826 .55214 L .41739 .55396 L F
0 .143 .668 r
.41826 .55214 m .41831 .55649 L .41739 .55396 L F
.684 .625 .784 r
.71901 .32208 m .72198 .31934 L .71847 .31959 L F
.784 .701 .772 r
.38339 .65305 m .38167 .65559 L .37893 .6517 L F
.779 .559 .6 r
.31827 .63514 m .31897 .63203 L .31562 .63215 L F
.445 .766 .996 r
.3151 .52785 m .31688 .52905 L .31345 .52848 L F
.118 .336 .804 r
.31759 .52739 m .31688 .52905 L .3151 .52785 L F
.558 .483 .727 r
.35597 .55242 m .35328 .54943 L .35729 .54924 L F
0 0 0 r
.35875 .5478 m .35729 .54924 L .35939 .5464 L F
.884 .53 .371 r
.3258 .68919 m .32896 .69277 L .32567 .69185 L F
.894 .501 .27 r
.32896 .69277 m .32774 .69429 L .32567 .69185 L F
.32896 .69277 m .3299 .69486 L .32774 .69429 L F
.705 .79 .313 r
.40108 .59537 m .40093 .59542 L .40262 .59386 L F
.722 .922 .576 r
.40247 .59351 m .40262 .59386 L .40093 .59542 L F
.354 .393 .763 r
.3568 .62561 m .35722 .62981 L .35944 .62758 L F
0 .114 .663 r
.35722 .62981 m .35901 .63004 L .35944 .62758 L F
.35722 .62981 m .35864 .63171 L .35901 .63004 L F
.692 .149 0 r
.34782 .51184 m .34956 .51355 L .34844 .513 L F
.3 0 .147 r
.3473 .51086 m .34782 .51184 L .34556 .51223 L F
.351 .037 .286 r
.34782 .51184 m .34506 .51424 L .34556 .51223 L F
.779 .998 .821 r
.34599 .51178 m .34506 .51424 L .34782 .51184 L F
.692 .149 0 r
.34782 .51184 m .34844 .513 L .34599 .51178 L F
.3 0 .147 r
.34886 .50963 m .34782 .51184 L .3473 .51086 L F
.686 .31 .329 r
.34886 .50963 m .35273 .51226 L .34782 .51184 L F
.585 .131 .142 r
.56678 .43967 m .57074 .43961 L .5694 .4413 L F
.65 .207 .185 r
.57074 .43961 m .57337 .44164 L .5694 .4413 L F
.628 .238 .285 r
.57074 .43961 m .57354 .43995 L .57337 .44164 L F
.137 0 .164 r
.29027 .63481 m .28816 .63766 L .28959 .63761 L F
.258 .362 .779 r
.28955 .63255 m .29027 .63481 L .29219 .63445 L F
.135 0 .205 r
.29219 .63445 m .29027 .63481 L .28959 .63761 L F
.879 .766 .733 r
.68922 .32991 m .6882 .33196 L .68714 .32812 L F
0 .177 .713 r
.38527 .51955 m .38494 .52076 L .38247 .51897 L F
.38527 .51955 m .38594 .52135 L .38494 .52076 L F
.491 .36 .629 r
.31713 .58101 m .31505 .58431 L .31595 .58212 L F
0 0 .092 r
.7164 .35895 m .7145 .36059 L .71695 .35733 L F
.618 .951 .783 r
.7133 .36039 m .7145 .36059 L .71534 .35987 L F
.279 0 0 r
.7133 .36039 m .71538 .36051 L .7131 .36044 L F
.202 .558 .935 r
.70933 .35918 m .7108 .3609 L .71247 .36056 L F
.71185 .35995 m .71247 .36056 L .7133 .36039 L F
.70933 .35918 m .71247 .36056 L .71185 .35995 L F
0 .267 .753 r
.70888 .35945 m .7108 .3609 L .70933 .35918 L F
.202 .558 .935 r
.71148 .35999 m .7133 .36039 L .71265 .36042 L F
.70933 .35918 m .71185 .35995 L .71148 .35999 L F
.71185 .35995 m .7133 .36039 L .71148 .35999 L F
.506 .226 .423 r
.70933 .35918 m .71148 .35999 L .71172 .3595 L F
.71148 .35999 m .71265 .36042 L .71172 .3595 L F
.946 .773 .636 r
.70913 .35976 m .71142 .35953 L .71093 .36004 L F
.70908 .36021 m .71093 .36004 L .70885 .36219 L F
.70913 .35976 m .71093 .36004 L .70908 .36021 L F
.71142 .35953 m .71172 .3595 L .71155 .35966 L F
.71142 .35953 m .71155 .35966 L .70885 .36219 L F
.279 0 0 r
.7133 .36039 m .7131 .36044 L .71265 .36042 L F
.618 .951 .783 r
.7133 .36039 m .71534 .35987 L .7164 .35895 L F
.77 .844 .907 r
.36487 .6165 m .36615 .61786 L .36322 .61945 L F
.418 .067 .26 r
.36615 .61786 m .36199 .62183 L .36322 .61945 L F
.75 .866 .439 r
.32544 .68218 m .32694 .6798 L .32588 .68174 L F
.011 0 0 r
.3289 .67881 m .32694 .6798 L .32544 .68218 L F
.772 .7 .16 r
.2609 .55623 m .2609 .55488 L .26121 .5532 L F
.661 .113 0 r
.26419 .55874 m .26282 .55821 L .2609 .55623 L F
0 .097 .652 r
.2609 .55623 m .26282 .55821 L .2609 .55488 L F
.972 .693 .442 r
.62906 .44182 m .63024 .44062 L .62947 .44009 L F
.392 0 .091 r
.62906 .44182 m .63288 .43962 L .63024 .44062 L F
.188 0 .369 r
.19751 .56916 m .19914 .56834 L .19958 .5658 L F
.213 .064 .451 r
.19738 .57174 m .19914 .56834 L .19751 .56916 L F
.64 .517 .698 r
.30085 .53822 m .29885 .53802 L .30185 .538 L F
.30085 .53822 m .29945 .54025 L .29885 .53802 L F
.273 .308 .716 r
.31758 .64401 m .31588 .645 L .31501 .64127 L F
.057 0 .366 r
.31719 .64672 m .31588 .645 L .31758 .64401 L F
.31719 .64672 m .31552 .64754 L .31588 .645 L F
.916 .593 .12 r
.41292 .54967 m .41435 .5534 L .41342 .55215 L F
.933 .653 .18 r
.41435 .5534 m .41381 .55444 L .41342 .55215 L F
.41435 .5534 m .41457 .5555 L .41381 .55444 L F
.693 .452 .555 r
.59691 .43557 m .59274 .43858 L .59334 .43713 L F
.999 .833 .534 r
.40009 .5817 m .39951 .58336 L .39829 .58308 L F
0 0 .097 r
.31279 .59291 m .31174 .59459 L .31339 .59089 L F
0 0 .096 r
.31258 .59575 m .31174 .59459 L .31279 .59291 L F
.31258 .59575 m .31074 .59679 L .31174 .59459 L F
.857 .981 .688 r
.38585 .64063 m .38546 .64255 L .38766 .63919 L F
.946 .707 .546 r
.38279 .64385 m .38546 .64255 L .38585 .64063 L F
.38279 .64385 m .38427 .64597 L .38546 .64255 L F
.867 .894 .852 r
.35809 .65879 m .36138 .65752 L .35989 .65717 L F
.469 .884 .929 r
.36138 .65752 m .36459 .65649 L .36242 .65646 L F
.315 .775 .636 r
.36362 .65587 m .36242 .65646 L .36461 .65538 L F
.447 .861 .955 r
.35989 .65717 m .36064 .65735 L .36242 .65646 L F
0 0 0 r
.35989 .65717 m .36242 .65646 L .35967 .65782 L F
.315 .775 .636 r
.35967 .65782 m .36242 .65646 L .36362 .65587 L F
.447 .861 .955 r
.36064 .65735 m .36138 .65752 L .36242 .65646 L F
.211 .7 .925 r
.28823 .52131 m .29049 .52132 L .29233 .52195 L F
.489 .85 .991 r
.29233 .52195 m .29325 .52062 L .29447 .52055 L F
.29233 .52195 m .29049 .52132 L .29325 .52062 L F
.933 .766 .651 r
.23458 .54927 m .23372 .55253 L .23275 .55138 L F
.885 .454 .129 r
.39208 .5299 m .39498 .53355 L .3931 .53192 L F
.142 .171 .631 r
.39972 .66258 m .39782 .66395 L .39783 .66031 L F
.373 .288 .63 r
.39972 .66258 m .39825 .66582 L .39782 .66395 L F
.289 .757 .942 r
.2664 .55845 m .26282 .55821 L .26419 .55874 L F
.891 .694 .63 r
.56101 .41117 m .56334 .41094 L .56167 .41377 L F
.936 .635 .446 r
.23971 .62579 m .23757 .6252 L .23716 .62247 L F
.087 .562 .904 r
.23971 .62579 m .23988 .62499 L .23757 .6252 L F
.23971 .62579 m .24166 .62612 L .23988 .62499 L F
.314 0 .101 r
.29784 .54706 m .30024 .54652 L .302 .54508 L F
.869 .821 .799 r
.73496 .33428 m .73054 .33634 L .73398 .3337 L F
.974 .918 .597 r
.73496 .33428 m .73482 .33037 L .73774 .33146 L F
.73496 .33428 m .73398 .3337 L .73482 .33037 L F
.754 .639 .733 r
.37347 .54294 m .37653 .54425 L .37587 .54191 L F
.884 .574 .457 r
.37347 .54294 m .37689 .54703 L .37653 .54425 L F
.543 .544 .806 r
.37653 .54425 m .3778 .54031 L .37587 .54191 L F
.37653 .54425 m .37883 .54426 L .3778 .54031 L F
.552 .444 .685 r
.37653 .54425 m .37689 .54703 L .37883 .54426 L F
.875 .655 .602 r
.35239 .52906 m .35302 .5284 L .35293 .52707 L F
.35239 .52906 m .35571 .52775 L .35302 .5284 L F
.58 .454 .673 r
.38722 .59763 m .38968 .59431 L .38719 .59473 L F
.771 .279 .052 r
.23601 .60862 m .23734 .611 L .23906 .61047 L F
.878 .457 .202 r
.23734 .611 m .23989 .61213 L .23906 .61047 L F
.357 .228 .565 r
.24918 .55536 m .24707 .55889 L .24698 .55657 L F
.906 .571 .4 r
.3363 .70432 m .3385 .70507 L .3388 .70745 L F
.75 .394 .379 r
.3385 .70507 m .3423 .70773 L .3388 .70745 L F
.392 .408 .757 r
.37493 .57217 m .37682 .56866 L .37428 .56933 L F
.37493 .57217 m .37904 .57242 L .37682 .56866 L F
.777 .677 .754 r
.31593 .66136 m .31723 .66343 L .31433 .66371 L F
.572 .114 .126 r
.31433 .66371 m .31723 .66343 L .31774 .66509 L F
.585 .608 .841 r
.31834 .66229 m .31723 .66343 L .31593 .66136 L F
.058 0 .25 r
.31774 .66509 m .31723 .66343 L .31834 .66229 L F
0 0 0 r
.64157 .40245 m .64397 .40142 L .64285 .40248 L F
.39414 .62871 m .39359 .63142 L .3927 .63277 L F
.39508 .62678 m .39414 .62871 L .39689 .62561 L F
.39508 .62678 m .39398 .62922 L .39414 .62871 L F
.797 .72 .187 r
.39398 .62922 m .39359 .63142 L .39414 .62871 L F
.252 0 .03 r
.37916 .70843 m .38027 .70998 L .3781 .7102 L F
.37916 .70843 m .38151 .70783 L .38027 .70998 L F
.5 .908 .862 r
.36866 .52491 m .36996 .52373 L .37061 .52362 L F
0 0 0 r
.21567 .54969 m .21459 .55212 L .21738 .54908 L F
.033 0 .341 r
.30386 .52615 m .30277 .52471 L .30511 .52324 L F
.957 .615 .258 r
.30609 .52623 m .30461 .52636 L .30386 .52615 L F
.033 0 .341 r
.30386 .52615 m .3025 .52741 L .30266 .52581 L F
.417 .861 .79 r
.30386 .52615 m .30066 .52733 L .3025 .52741 L F
.957 .615 .258 r
.30461 .52636 m .30226 .52658 L .30386 .52615 L F
.033 0 .341 r
.30386 .52615 m .30266 .52581 L .30277 .52471 L F
.596 .509 .727 r
.35317 .6197 m .35552 .61906 L .35534 .61647 L F
.048 .616 .727 r
.35041 .60707 m .35254 .6069 L .34887 .6059 L F
.35041 .60707 m .35317 .60694 L .35254 .6069 L F
.857 .514 0 r
.41769 .56812 m .41624 .56457 L .41722 .56597 L F
.732 .235 0 r
.36627 .50869 m .36912 .51178 L .36781 .50989 L F
0 0 .029 r
.28673 .54249 m .2855 .54544 L .28474 .54588 L F
.037 0 .11 r
.28733 .54401 m .2855 .54544 L .28673 .54249 L F
.563 .568 .817 r
.28436 .54251 m .28662 .54365 L .28694 .54172 L F
.28662 .54365 m .28733 .54401 L .28723 .5434 L F
.032 0 0 r
.28988 .54041 m .28833 .54272 L .28673 .54249 L F
.037 0 .11 r
.28733 .54401 m .28673 .54249 L .28782 .54303 L F
.777 .728 .807 r
.28779 .54309 m .28733 .54401 L .28938 .54222 L F
.186 0 0 r
.29049 .54169 m .28833 .54272 L .28988 .54041 L F
.032 0 0 r
.28833 .54272 m .28795 .54295 L .28673 .54249 L F
0 0 0 r
.29049 .54169 m .28733 .54401 L .28723 .5434 L F
.032 0 0 r
.28795 .54295 m .28782 .54303 L .28673 .54249 L F
.563 .568 .817 r
.28662 .54365 m .28723 .5434 L .28694 .54172 L F
.28436 .54251 m .2855 .54544 L .28733 .54401 L F
.28436 .54251 m .2855 .54544 L .28733 .54401 L F
.28436 .54251 m .28733 .54401 L .28694 .54172 L F
.613 .266 .359 r
.28713 .54311 m .2836 .54499 L .28759 .54321 L F
.28436 .54251 m .2839 .54402 L .28713 .54311 L F
.2839 .54402 m .2836 .54499 L .28713 .54311 L F
0 0 0 r
.28998 .5417 m .28818 .54281 L .28694 .54172 L F
.28818 .54281 m .28723 .5434 L .28717 .5431 L F
.28818 .54281 m .28717 .5431 L .28694 .54172 L F
.29049 .54169 m .28723 .5434 L .28998 .5417 L F
.032 0 0 r
.28813 .54302 m .28795 .5431 L .28782 .54303 L F
.28813 .54302 m .28782 .54303 L .28795 .54295 L F
.037 0 .11 r
.28733 .54401 m .28782 .54303 L .28805 .54314 L F
.777 .728 .807 r
.28723 .5434 m .28733 .54401 L .28779 .54309 L F
.28833 .54272 m .28938 .54222 L .28998 .5417 L F
.28723 .5434 m .28938 .54222 L .28833 .54272 L F
.28998 .5417 m .28733 .54401 L .29049 .54169 L F
.28694 .54172 m .28723 .5434 L .28998 .5417 L F
.186 0 0 r
.29049 .54169 m .28988 .54041 L .29239 .54037 L F
.286 0 0 r
.29482 .54031 m .29049 .54169 L .29239 .54037 L F
.29482 .54031 m .29277 .54168 L .29049 .54169 L F
.223 0 0 r
.29277 .54168 m .28904 .54364 L .29049 .54169 L F
.43 .389 .711 r
.28988 .54194 m .29077 .542 L .2903 .53829 L F
.29077 .542 m .29209 .54209 L .29182 .54151 L F
.29077 .542 m .29182 .54151 L .2903 .53829 L F
0 0 0 r
.28929 .54269 m .28904 .54364 L .28783 .5439 L F
.29049 .54169 m .28999 .54237 L .28929 .54269 L F
.28999 .54237 m .28904 .54364 L .28929 .54269 L F
.28937 .54252 m .28783 .5439 L .28733 .54401 L F
.29049 .54169 m .28783 .5439 L .28937 .54252 L F
0 0 .25 r
.2855 .54544 m .2833 .54939 L .28474 .54588 L F
.2855 .54544 m .28505 .54812 L .2833 .54939 L F
.465 .534 .844 r
.2836 .54499 m .28532 .54617 L .28759 .54321 L F
0 0 .2 r
.28733 .54401 m .28505 .54812 L .2855 .54544 L F
0 0 0 r
.28505 .54812 m .28282 .55125 L .2833 .54939 L F
.524 .361 .602 r
.28505 .54812 m .28525 .55081 L .28282 .55125 L F
.28505 .54812 m .28525 .55081 L .28282 .55125 L F
.014 0 .473 r
.28556 .54833 m .28525 .55081 L .28505 .54812 L F
.053 0 .301 r
.28564 .54817 m .28559 .5485 L .28652 .54872 L F
.014 0 .473 r
.28652 .54872 m .28582 .54987 L .28559 .5485 L F
.28582 .54987 m .28525 .55081 L .28556 .54833 L F
.053 0 .301 r
.28559 .5485 m .28524 .55086 L .28652 .54872 L F
.014 0 .473 r
.28652 .54872 m .28559 .5485 L .28556 .54833 L F
.407 0 .114 r
.2833 .54939 m .28042 .55155 L .27998 .55048 L F
.2833 .54939 m .28282 .55125 L .28042 .55155 L F
.768 .486 .508 r
.27976 .54977 m .28524 .55086 L .28559 .5485 L F
.28557 .54819 m .28559 .5485 L .28564 .54817 L F
.053 0 .301 r
.28564 .54817 m .28652 .54872 L .2867 .5471 L F
.014 0 .473 r
.28652 .54872 m .28556 .54833 L .2867 .5471 L F
.28558 .54816 m .28505 .54812 L .28561 .54778 L F
.28556 .54833 m .28551 .54831 L .28558 .54816 L F
.28551 .54831 m .28505 .54812 L .28558 .54816 L F
.76 .651 .74 r
.28551 .54815 m .28558 .54816 L .28556 .54805 L F
.28558 .54816 m .28564 .54817 L .2856 .54811 L F
.014 0 .473 r
.28556 .54833 m .28561 .54778 L .28557 .54819 L F
.76 .651 .74 r
.28558 .54816 m .2856 .54811 L .28556 .54805 L F
.768 .486 .508 r
.28549 .54821 m .28557 .54819 L .28551 .54815 L F
.28557 .54819 m .28564 .54817 L .28558 .54816 L F
.28557 .54819 m .28558 .54816 L .28551 .54815 L F
.014 0 .473 r
.28558 .54812 m .28561 .54778 L .28561 .54778 L F
.28558 .54812 m .28561 .54778 L .28558 .54812 L F
.465 .534 .844 r
.2856 .54811 m .28564 .54817 L .2867 .5471 L F
.014 0 .473 r
.28556 .54833 m .28561 .54778 L .2867 .5471 L F
0 0 .2 r
.28733 .54401 m .28703 .54548 L .28578 .54715 L F
.28597 .54647 m .28578 .54715 L .28505 .54812 L F
.28733 .54401 m .28578 .54715 L .28597 .54647 L F
.28703 .54548 m .2867 .5471 L .28578 .54767 L F
.28703 .54548 m .28578 .54767 L .28505 .54812 L F
.465 .534 .844 r
.2836 .54499 m .2856 .54811 L .2867 .5471 L F
.014 0 .473 r
.28557 .54819 m .28558 .54812 L .28558 .54812 L F
.768 .486 .508 r
.28554 .5482 m .28556 .54833 L .28557 .54819 L F
.28556 .54833 m .28559 .5485 L .28557 .54819 L F
.27976 .54977 m .28559 .5485 L .28554 .5482 L F
.27976 .54977 m .28549 .54821 L .28013 .54731 L F
.28549 .54821 m .28551 .54815 L .28013 .54731 L F
.76 .651 .74 r
.28013 .54731 m .28551 .54815 L .2836 .54499 L F
.28551 .54815 m .28556 .54805 L .2836 .54499 L F
.465 .534 .844 r
.28532 .54617 m .2867 .5471 L .28733 .54436 L F
.28532 .54617 m .28733 .54436 L .28759 .54321 L F
.718 .988 .849 r
.29049 .54169 m .28733 .54401 L .28799 .54321 L F
.262 0 .302 r
.28865 .54625 m .28733 .54401 L .28904 .54364 L F
.28865 .54625 m .2867 .5471 L .28733 .54401 L F
.315 .09 .405 r
.28768 .54348 m .2867 .5471 L .28865 .54625 L F
.28759 .54321 m .28749 .54365 L .28768 .54348 L F
.28749 .54365 m .2867 .5471 L .28768 .54348 L F
.718 .988 .849 r
.288 .5432 m .28799 .54321 L .288 .54321 L F
.29049 .54169 m .28799 .54321 L .288 .5432 L F
.269 0 .138 r
.28759 .54321 m .28787 .54329 L .28813 .54311 L F
.718 .988 .849 r
.28826 .54302 m .288 .54321 L .28805 .54314 L F
.29049 .54169 m .288 .54321 L .28826 .54302 L F
.269 0 .138 r
.28813 .54311 m .28904 .54364 L .28942 .54288 L F
.28787 .54329 m .28904 .54364 L .28813 .54311 L F
.186 0 0 r
.29049 .54169 m .28826 .54302 L .28833 .54272 L F
.28826 .54302 m .28812 .54303 L .28833 .54272 L F
.269 0 .138 r
.28785 .54307 m .28942 .54288 L .28988 .54194 L F
.032 0 0 r
.28813 .54302 m .28812 .54303 L .28795 .5431 L F
.269 0 .138 r
.28791 .54315 m .28942 .54288 L .28812 .54303 L F
.032 0 0 r
.28812 .54303 m .28805 .54314 L .28798 .54311 L F
.28812 .54303 m .28798 .54311 L .28795 .5431 L F
.269 0 .138 r
.28759 .54321 m .28791 .54315 L .28785 .54307 L F
.28791 .54315 m .28812 .54303 L .28785 .54307 L F
.186 0 0 r
.28826 .54302 m .28805 .54314 L .28812 .54303 L F
.032 0 0 r
.28833 .54272 m .28813 .54302 L .28795 .54295 L F
.373 0 0 r
.37845 .51754 m .37752 .51697 L .37651 .51529 L F
.117 0 .417 r
.71863 .35531 m .7164 .35895 L .71695 .35733 L F
.8 .724 .78 r
.70498 .3031 m .7061 .30696 L .70248 .3064 L F
.792 .719 .784 r
.70866 .30374 m .7061 .30696 L .70498 .3031 L F
.868 .701 .673 r
.71004 .32783 m .70891 .33168 L .71162 .33223 L F
.902 .852 .784 r
.70807 .3341 m .71162 .33223 L .70891 .33168 L F
.70807 .3341 m .70944 .33564 L .71162 .33223 L F
.819 .426 .307 r
.38735 .56672 m .38988 .56571 L .38769 .56654 L F
.395 0 0 r
.35149 .58104 m .35269 .58153 L .3497 .58077 L F
.374 0 0 r
.35105 .58096 m .35269 .58153 L .35149 .58104 L F
.72 .986 .812 r
.35729 .57811 m .35269 .58153 L .35105 .58096 L F
.35729 .57811 m .35249 .58077 L .35269 .58153 L F
.389 0 0 r
.35876 .57959 m .35729 .57811 L .36089 .5778 L F
.35852 .57966 m .35729 .57811 L .35876 .57959 L F
.35858 .57974 m .35249 .58077 L .35729 .57811 L F
.846 .598 .563 r
.36241 .57786 m .35858 .57974 L .36089 .5778 L F
.36241 .57786 m .36189 .58067 L .35858 .57974 L F
.736 .743 .857 r
.35696 .57841 m .36117 .57887 L .35973 .5765 L F
.36117 .57887 m .36168 .57893 L .36155 .57876 L F
.36117 .57887 m .36155 .57876 L .35973 .5765 L F
.389 0 0 r
.35858 .57974 m .35852 .57966 L .35876 .57959 L F
.682 .428 .531 r
.69903 .3479 m .69511 .35037 L .69507 .34788 L F
.69903 .3479 m .69893 .35028 L .69511 .35037 L F
.654 .404 .529 r
.69903 .3479 m .70173 .35025 L .69893 .35028 L F
.684 .393 .476 r
.70237 .34864 m .70173 .35025 L .69903 .3479 L F
.61 .517 .724 r
.33689 .57557 m .33704 .57828 L .33996 .57753 L F
.472 .485 .79 r
.33704 .57828 m .3409 .58137 L .33996 .57753 L F
.291 0 0 r
.63479 .44601 m .63373 .44824 L .63028 .44872 L F
.131 0 .059 r
.63649 .44477 m .63373 .44824 L .63479 .44601 L F
.594 .693 .911 r
.38619 .55189 m .38495 .55361 L .38364 .55188 L F
.788 .959 .639 r
.38194 .64785 m .3791 .65164 L .3807 .64963 L F
.555 .345 .55 r
.38183 .65053 m .3791 .65164 L .38194 .64785 L F
.553 .275 .448 r
.38183 .65053 m .37893 .6517 L .3791 .65164 L F
.731 .747 .865 r
.38183 .65053 m .37893 .6517 L .3791 .65164 L F
.38183 .65053 m .38339 .65305 L .37893 .6517 L F
.541 .661 .914 r
.38605 .65248 m .38339 .65305 L .38183 .65053 L F
.733 .635 .751 r
.55753 .42717 m .55926 .43075 L .55511 .42984 L F
.842 .7 .706 r
.55926 .43075 m .55528 .43264 L .55511 .42984 L F
.55926 .43075 m .55885 .43309 L .55528 .43264 L F
.734 .766 .878 r
.55973 .42682 m .55926 .43075 L .55753 .42717 L F
.55973 .42682 m .5615 .42955 L .55926 .43075 L F
.641 .505 .682 r
.5615 .42955 m .55885 .43309 L .55926 .43075 L F
.419 0 0 r
.32058 .62539 m .32405 .62435 L .32086 .62288 L F
.174 0 0 r
.35886 .66668 m .3613 .66596 L .36283 .66403 L F
0 0 0 r
.36283 .66403 m .36245 .66451 L .36521 .66306 L F
.36283 .66403 m .3613 .66596 L .36245 .66451 L F
.176 0 0 r
.19999 .59843 m .20207 .59867 L .20196 .59921 L F
.19999 .59843 m .20196 .59921 L .19795 .59711 L F
.438 .835 .629 r
.22394 .54197 m .22128 .54376 L .22321 .54241 L F
.027 0 .024 r
.22128 .54376 m .22211 .545 L .22321 .54241 L F
.22128 .54376 m .22027 .54602 L .22211 .545 L F
.918 .541 .284 r
.32312 .68548 m .3258 .68919 L .32264 .68931 L F
.906 .651 .542 r
.3258 .68919 m .32324 .6917 L .32264 .68931 L F
.3258 .68919 m .32567 .69185 L .32324 .6917 L F
.419 .417 .751 r
.22795 .59444 m .229 .59713 L .22702 .59738 L F
0 0 .403 r
.22802 .59932 m .22702 .59738 L .229 .59713 L F
.685 .463 .578 r
.33816 .55778 m .34203 .55679 L .33939 .55631 L F
.519 .237 .426 r
.29752 .61264 m .29436 .61528 L .29525 .61316 L F
.367 .519 .877 r
.25944 .603 m .25928 .60429 L .25751 .60308 L F
.25944 .603 m .25928 .60429 L .25751 .60308 L F
.902 .873 .799 r
.70684 .32233 m .70889 .3196 L .70758 .31814 L F
.976 .921 .659 r
.70889 .3196 m .70975 .31443 L .70758 .31814 L F
0 0 0 r
.63027 .43401 m .63148 .433 L .62876 .43395 L F
.63027 .43401 m .62876 .43395 L .62752 .43261 L F
.119 0 .344 r
.19597 .59465 m .19834 .59345 L .19823 .59073 L F
.143 0 .268 r
.27502 .54729 m .27434 .54945 L .27675 .54619 L F
.353 .732 .987 r
.19946 .60577 m .19899 .60704 L .19761 .60699 L F
.19946 .60577 m .20139 .60707 L .19899 .60704 L F
.19946 .60577 m .19899 .60704 L .19761 .60699 L F
.19946 .60577 m .20139 .60707 L .19899 .60704 L F
.826 .953 .9 r
.31263 .51734 m .31226 .5198 L .31406 .51818 L F
.31263 .51734 m .30957 .52001 L .31226 .5198 L F
0 0 .132 r
.34011 .53333 m .33801 .53708 L .3377 .53413 L F
.066 .589 .873 r
.34596 .66348 m .34678 .66309 L .34443 .66334 L F
.34596 .66348 m .34885 .66403 L .34678 .66309 L F
.581 .524 .756 r
.32394 .54626 m .32625 .54424 L .32291 .54575 L F
0 0 0 r
.35322 .59418 m .35271 .59429 L .35167 .59512 L F
.107 .658 .806 r
.35271 .59429 m .35441 .59445 L .35217 .59441 L F
.456 .527 .842 r
.35604 .5966 m .35271 .59429 L .35493 .59315 L F
0 0 0 r
.35493 .59315 m .35271 .59429 L .35322 .59418 L F
.107 .658 .806 r
.35271 .59429 m .35217 .59441 L .35011 .59438 L F
.141 .529 .919 r
.26391 .6337 m .26616 .63345 L .26201 .63254 L F
.26391 .6337 m .26685 .63461 L .26616 .63345 L F
0 .038 .606 r
.60362 .40441 m .60531 .40685 L .60384 .40309 L F
.16 0 .018 r
.38739 .55028 m .38619 .55189 L .38959 .54946 L F
0 .143 .668 r
.41826 .55214 m .41928 .55499 L .41831 .55649 L F
.079 .297 .78 r
.41928 .55499 m .42084 .55845 L .41831 .55649 L F
.389 .356 .701 r
.19482 .5881 m .19664 .5878 L .1961 .58401 L F
.567 .523 .766 r
.19482 .5881 m .19823 .59073 L .19664 .5878 L F
0 0 0 r
.70508 .33956 m .70268 .34272 L .70334 .34149 L F
.91 .982 .749 r
.3927 .63277 m .39044 .63403 L .39119 .63443 L F
.467 .862 .674 r
.3919 .63298 m .3927 .63277 L .39359 .63142 L F
.3919 .63298 m .39044 .63403 L .3927 .63277 L F
.289 .78 .898 r
.22695 .55746 m .22213 .55765 L .22451 .55619 L F
.857 .982 .694 r
.39708 .62382 m .39508 .62678 L .39689 .62561 L F
.418 .067 .26 r
.36615 .61786 m .3645 .62142 L .36199 .62183 L F
0 .275 .752 r
.36743 .61826 m .36615 .61786 L .36487 .6165 L F
.287 0 .194 r
.36689 .62072 m .36634 .61861 L .36743 .61826 L F
.36689 .62072 m .3645 .62142 L .36615 .61786 L F
.638 .192 .174 r
.36743 .61826 m .36919 .6169 L .37096 .61853 L F
.205 0 .299 r
.36931 .61751 m .36743 .61826 L .37096 .61853 L F
.36931 .61751 m .36689 .62072 L .36743 .61826 L F
.894 .915 .83 r
.36536 .61983 m .36872 .61785 L .36743 .61826 L F
.36872 .61785 m .36931 .61751 L .36743 .61826 L F
.287 0 .194 r
.36634 .61861 m .36615 .61786 L .36743 .61826 L F
.866 .913 .86 r
.33624 .51206 m .33182 .51416 L .33446 .51097 L F
.33624 .51206 m .33143 .51664 L .33182 .51416 L F
.502 .814 1 r
.33688 .51044 m .33624 .51206 L .33446 .51097 L F
.531 0 0 r
.33666 .51271 m .33869 .51428 L .33624 .51206 L F
.33666 .51271 m .33624 .51206 L .33688 .51044 L F
.393 .237 .548 r
.3103 .57164 m .31192 .57425 L .31094 .56975 L F
.322 .193 .544 r
.31094 .56975 m .31192 .57425 L .31408 .57292 L F
.791 .619 .667 r
.40076 .60687 m .39939 .60927 L .39985 .60699 L F
.40076 .60687 m .40044 .60926 L .39939 .60927 L F
.218 0 .236 r
.40516 .60341 m .40396 .60569 L .40076 .60687 L F
.222 .038 .406 r
.40396 .60569 m .40044 .60926 L .40076 .60687 L F
.721 .602 .724 r
.34449 .55006 m .3419 .55332 L .34082 .55035 L F
0 .087 .637 r
.3419 .55332 m .34284 .55252 L .34022 .55252 L F
.3419 .55332 m .34428 .55599 L .34284 .55252 L F
.764 .669 .757 r
.34938 .57483 m .34742 .57859 L .34592 .57495 L F
.653 .263 .294 r
.34742 .57859 m .3497 .58077 L .34593 .58 L F
.375 .688 .98 r
.35371 .66821 m .34947 .6669 L .35185 .66837 L F
.102 .656 .726 r
.35441 .6681 m .35371 .66821 L .35185 .66837 L F
.216 0 0 r
.63652 .43204 m .63408 .43243 L .63674 .43193 L F
.362 .821 .927 r
.63922 .43094 m .63652 .43204 L .63674 .43193 L F
.63922 .43094 m .6397 .43139 L .63652 .43204 L F
.667 .328 .39 r
.3663 .5628 m .36854 .565 L .36997 .5621 L F
.469 .119 .289 r
.36997 .5621 m .37076 .56402 L .37227 .56187 L F
.36997 .5621 m .36854 .565 L .37076 .56402 L F
.825 .937 .902 r
.71235 .31104 m .71624 .30949 L .71551 .30885 L F
.422 .178 .437 r
.71754 .30582 m .71624 .30949 L .71955 .30717 L F
.71754 .30582 m .71551 .30885 L .71624 .30949 L F
.251 0 0 r
.29945 .54025 m .29721 .54079 L .29482 .54031 L F
.357 0 0 r
.30085 .53822 m .29721 .54079 L .29945 .54025 L F
.479 .473 .773 r
.29945 .54025 m .302 .54508 L .3027 .54331 L F
.836 .726 .742 r
.55528 .43264 m .55885 .43309 L .55652 .43548 L F
.713 .516 .621 r
.55885 .43309 m .55942 .43653 L .55652 .43548 L F
.81 .494 .454 r
.55885 .43309 m .56287 .43629 L .55942 .43653 L F
.842 .995 .755 r
.31426 .53101 m .31439 .53256 L .317 .53193 L F
.31426 .53101 m .3131 .53307 L .31439 .53256 L F
.5 .346 .604 r
.72179 .28482 m .72141 .28763 L .72419 .287 L F
.598 .533 .752 r
.34592 .57495 m .34442 .57749 L .3427 .576 L F
.34592 .57495 m .34479 .5776 L .34442 .57749 L F
.712 .382 .418 r
.34442 .57749 m .34593 .58 L .34479 .5776 L F
.34442 .57749 m .34352 .57992 L .34593 .58 L F
.227 .196 .614 r
.33753 .56205 m .33816 .55778 L .33632 .56009 L F
.205 .337 .777 r
.39879 .67205 m .39802 .6746 L .3965 .67222 L F
.39879 .67205 m .40011 .67563 L .39802 .6746 L F
0 0 .376 r
.40011 .67563 m .40003 .67831 L .39843 .67894 L F
.436 .555 .877 r
.40003 .67831 m .39969 .68184 L .39843 .67894 L F
.584 .636 .868 r
.42613 .56276 m .42194 .56038 L .42465 .56137 L F
.658 .84 .97 r
.42682 .56057 m .42613 .56276 L .42465 .56137 L F
.497 .672 .942 r
.42682 .56057 m .42914 .56277 L .42613 .56276 L F
.878 .511 .027 r
.4266 .56448 m .42613 .56276 L .42914 .56277 L F
.257 .037 .377 r
.34752 .59391 m .34448 .59822 L .34689 .59689 L F
.408 .311 .633 r
.34448 .59822 m .347 .59957 L .34689 .59689 L F
.34448 .59822 m .34518 .60049 L .347 .59957 L F
.775 .747 .827 r
.70791 .30035 m .70866 .30374 L .70498 .3031 L F
.906 .86 .784 r
.70974 .29836 m .70866 .30374 L .70791 .30035 L F
.108 0 0 r
.20267 .56345 m .2036 .56397 L .20484 .56248 L F
.20267 .56345 m .20117 .56475 L .2036 .56397 L F
.791 .98 .707 r
.35321 .64769 m .35 .65131 L .35319 .651 L F
.511 .589 .87 r
.35 .65131 m .35301 .6534 L .35319 .651 L F
.515 .436 .705 r
.35321 .64769 m .35319 .651 L .3555 .65027 L F
.446 .251 .521 r
.3555 .65027 m .35319 .651 L .35301 .6534 L F
.247 0 .039 r
.302 .54508 m .30257 .54588 L .3027 .54331 L F
.302 .54508 m .30024 .54652 L .30257 .54588 L F
.184 0 0 r
.33171 .665 m .33278 .66423 L .33137 .66379 L F
.591 .774 .967 r
.33345 .66421 m .33048 .66351 L .33137 .66379 L F
.799 .95 .919 r
.33485 .66242 m .33345 .66421 L .33137 .66379 L F
.184 0 0 r
.33278 .66423 m .33429 .66314 L .33137 .66379 L F
.591 .774 .967 r
.33048 .66351 m .32919 .66321 L .33137 .66379 L F
.563 .817 .445 r
.33602 .66094 m .33345 .66421 L .33485 .66242 L F
.22 0 .241 r
.24184 .56243 m .24096 .56483 L .23926 .56542 L F
.471 .217 .446 r
.24408 .562 m .24096 .56483 L .24184 .56243 L F
.804 .497 .469 r
.30983 .65938 m .31257 .66101 L .312 .66322 L F
.827 .755 .783 r
.31593 .66136 m .312 .66322 L .31257 .66101 L F
.36 0 .074 r
.27618 .53801 m .27528 .53921 L .27269 .53959 L F
.549 .322 .522 r
.35842 .52725 m .35571 .52775 L .35871 .52424 L F
.72 .558 .67 r
.35871 .52424 m .35571 .52775 L .35615 .52492 L F
.583 .432 .641 r
.35842 .52725 m .35615 .52492 L .35871 .52424 L F
.35615 .52492 m .35842 .52725 L .35871 .52424 L F
.36 .145 .446 r
.36089 .52377 m .35842 .52725 L .35871 .52424 L F
.35842 .52725 m .36089 .52377 L .35871 .52424 L F
.732 .493 .567 r
.57996 .43954 m .58099 .44186 L .5774 .44217 L F
.665 .474 .617 r
.58379 .43939 m .58099 .44186 L .57996 .43954 L F
.488 .849 .991 r
.57545 .40478 m .57931 .4048 L .57807 .4041 L F
.57807 .4041 m .57931 .4048 L .57545 .40478 L F
.484 .847 .991 r
.57807 .4041 m .57931 .4048 L .58078 .40345 L F
.57807 .4041 m .57931 .4048 L .58078 .40345 L F
.251 0 .116 r
.37832 .5928 m .37571 .59255 L .37872 .59119 L F
.37832 .5928 m .37585 .59352 L .37571 .59255 L F
0 0 0 r
.27981 .52328 m .28366 .52231 L .27904 .52335 L F
.639 .966 .873 r
.28424 .5215 m .28366 .52231 L .27981 .52328 L F
.751 .875 .456 r
.38825 .63748 m .38766 .63919 L .38837 .63759 L F
.793 .973 .679 r
.38825 .63748 m .38585 .64063 L .38766 .63919 L F
.589 .568 .798 r
.32552 .60335 m .32707 .59938 L .32435 .60138 L F
.696 .973 .768 r
.73065 .34959 m .73067 .34903 L .72918 .35124 L F
.695 .743 .236 r
.72928 .35069 m .72918 .35124 L .73067 .34903 L F
.72928 .35069 m .7285 .3533 L .72918 .35124 L F
.319 .176 .525 r
.39942 .6879 m .39734 .69142 L .39861 .68965 L F
.642 .787 .951 r
.4222 .54608 m .41946 .54696 L .41808 .54546 L F
.969 .696 .462 r
.4222 .54608 m .41808 .54546 L .41946 .54696 L F
.61 .637 .853 r
.33521 .57205 m .33689 .57557 L .33946 .57501 L F
.61 .517 .724 r
.33689 .57557 m .33996 .57753 L .33946 .57501 L F
.939 .836 .715 r
.71581 .30329 m .71753 .30042 L .71593 .29855 L F
.554 .355 .566 r
.57273 .40532 m .57545 .40478 L .57478 .40298 L F
.694 .463 .569 r
.69507 .34788 m .69281 .35083 L .69252 .34772 L F
.69507 .34788 m .69511 .35037 L .69281 .35083 L F
.789 .414 .346 r
.59691 .43557 m .59912 .43657 L .59915 .4383 L F
.312 .043 .334 r
.59915 .4383 m .59912 .43657 L .60173 .43546 L F
.795 .624 .669 r
.69252 .34772 m .68919 .3478 L .69107 .34459 L F
.703 .477 .578 r
.69252 .34772 m .68864 .3503 L .68919 .3478 L F
.69252 .34772 m .69281 .35083 L .68864 .3503 L F
.655 .319 .391 r
.3103 .57164 m .3116 .57509 L .31192 .57425 L F
0 0 .253 r
.36044 .64179 m .35861 .6452 L .36101 .64454 L F
.35861 .6452 m .36044 .64179 L .36101 .64454 L F
.689 .63 .785 r
.37689 .54703 m .38014 .54759 L .37883 .54426 L F
.627 .154 .112 r
.37689 .54703 m .37905 .5486 L .38014 .54759 L F
.715 .644 .776 r
.37883 .54426 m .38014 .54759 L .38321 .54693 L F
.291 0 0 r
.37905 .5486 m .38321 .54693 L .38014 .54759 L F
.645 .435 .585 r
.34492 .56912 m .34563 .57262 L .34222 .57215 L F
.58 .574 .811 r
.34676 .56586 m .34492 .56912 L .34412 .56628 L F
.658 .674 .854 r
.34676 .56586 m .35002 .56954 L .34492 .56912 L F
.549 .241 .398 r
.35002 .56954 m .34563 .57262 L .34492 .56912 L F
.517 .431 .697 r
.35392 .59701 m .35492 .60043 L .35203 .60057 L F
.061 0 .311 r
.35492 .60043 m .35264 .60436 L .35203 .60057 L F
.436 .555 .877 r
.40003 .67831 m .40202 .68176 L .39969 .68184 L F
0 0 0 r
.22321 .54241 m .22639 .5413 L .22394 .54197 L F
.884 .574 .457 r
.37347 .54294 m .37461 .54652 L .37689 .54703 L F
.828 .857 .869 r
.37263 .54848 m .37689 .54703 L .37461 .54652 L F
.817 .735 .774 r
.6882 .33196 m .68476 .33138 L .68714 .32812 L F
.818 .734 .772 r
.6882 .33196 m .6858 .33517 L .68476 .33138 L F
.472 .183 .394 r
.24136 .54403 m .24054 .54627 L .2382 .54647 L F
.398 .113 .359 r
.24288 .5456 m .24054 .54627 L .24136 .54403 L F
.387 .132 .401 r
.25209 .54254 m .24983 .5434 L .25058 .54088 L F
.237 0 .072 r
.71345 .34395 m .71619 .343 L .71728 .34072 L F
0 0 0 r
.71728 .34072 m .71826 .34133 L .71943 .34125 L F
.71728 .34072 m .71619 .343 L .71826 .34133 L F
.486 .387 .668 r
.33279 .57242 m .33278 .57406 L .33521 .57205 L F
.036 0 .378 r
.34592 .57495 m .34479 .5776 L .34737 .57596 L F
0 0 0 r
.34593 .58 m .34737 .57596 L .34479 .5776 L F
.539 .331 .547 r
.34966 .5595 m .34971 .56233 L .34709 .56252 L F
.63 .961 .9 r
.35121 .557 m .35245 .55684 L .35441 .55535 L F
.35121 .557 m .35094 .55681 L .35245 .55684 L F
.348 .271 .627 r
.35121 .557 m .35122 .55711 L .35094 .55681 L F
.81 .996 .861 r
.35122 .55711 m .34966 .5595 L .35167 .55759 L F
.35094 .55681 m .35006 .55866 L .35122 .55711 L F
.35006 .55866 m .34966 .5595 L .35122 .55711 L F
.348 .271 .627 r
.35122 .55711 m .35353 .5609 L .35162 .56131 L F
.35121 .557 m .35125 .55707 L .35122 .55711 L F
.35125 .55707 m .35353 .5609 L .35122 .55711 L F
.35122 .55711 m .35162 .56131 L .35094 .55681 L F
.81 .996 .861 r
.35154 .55683 m .35167 .55759 L .35245 .55684 L F
0 .091 .649 r
.35441 .55535 m .35624 .55715 L .3587 .55624 L F
.543 .287 .477 r
.35645 .55495 m .35624 .55715 L .35132 .557 L F
.35143 .55691 m .35132 .557 L .35121 .557 L F
.35645 .55495 m .35132 .557 L .35143 .55691 L F
.81 .996 .861 r
.35094 .55681 m .35121 .5571 L .35154 .55683 L F
.35132 .557 m .35167 .55759 L .35154 .55683 L F
.35121 .5571 m .35167 .55759 L .35132 .557 L F
.466 .242 .489 r
.35624 .55715 m .35353 .5609 L .35125 .55707 L F
.35132 .557 m .35125 .55707 L .35121 .557 L F
.35624 .55715 m .35125 .55707 L .35132 .557 L F
.81 .996 .861 r
.35121 .5571 m .35121 .5571 L .35132 .557 L F
.35 .186 .513 r
.35162 .56131 m .34966 .5595 L .35094 .55681 L F
.35162 .56131 m .34971 .56233 L .34966 .5595 L F
.765 .672 .76 r
.34885 .66403 m .34947 .6669 L .35224 .66325 L F
.471 .12 .288 r
.35185 .66837 m .34947 .6669 L .34887 .66823 L F
.378 .641 .959 r
.3775 .51368 m .37651 .51529 L .37636 .51427 L F
0 0 .477 r
.37718 .51599 m .37651 .51529 L .3775 .51368 L F
.37718 .51599 m .37845 .51754 L .37651 .51529 L F
.157 0 .245 r
.64476 .43562 m .64527 .43363 L .64725 .43243 L F
.84 .733 .745 r
.68597 .33757 m .68763 .34111 L .68518 .34019 L F
.839 .996 .761 r
.68763 .34111 m .68526 .3426 L .68518 .34019 L F
.68763 .34111 m .68463 .34471 L .68526 .3426 L F
.726 .738 .861 r
.622 .3917 m .6233 .39509 L .61918 .39434 L F
.512 .613 .89 r
.62558 .3942 m .6233 .39509 L .622 .3917 L F
.667 .616 .788 r
.39695 .61281 m .39421 .61604 L .39447 .61373 L F
.39695 .61281 m .39812 .61644 L .39421 .61604 L F
.574 .507 .742 r
.3983 .6191 m .39421 .61604 L .39812 .61644 L F
.3983 .6191 m .39682 .6213 L .39421 .61604 L F
.979 .718 .462 r
.40734 .52727 m .40901 .52876 L .40761 .52451 L F
.585 .545 .776 r
.40761 .52451 m .40901 .52876 L .41131 .52761 L F
.656 .824 .964 r
.41131 .52761 m .40901 .52876 L .40734 .52727 L F
.487 .534 .831 r
.41205 .53039 m .40901 .52876 L .41131 .52761 L F
.76 .303 .163 r
.36912 .51178 m .37067 .51368 L .37227 .51246 L F
.715 .644 .776 r
.37883 .54426 m .38321 .54693 L .38172 .54538 L F
.291 0 0 r
.37905 .5486 m .38151 .54846 L .38321 .54693 L F
.993 .775 .504 r
.38321 .54693 m .38151 .54846 L .38172 .54538 L F
.38 .284 .62 r
.38564 .54852 m .38321 .54693 L .38544 .54752 L F
.38564 .54852 m .38363 .54964 L .38321 .54693 L F
.863 .815 .333 r
.38903 .65629 m .38908 .65715 L .38995 .65435 L F
.924 .663 .524 r
.61776 .44269 m .61575 .44429 L .61604 .44163 L F
.61776 .44269 m .61769 .44526 L .61575 .44429 L F
0 0 0 r
.36121 .51752 m .35984 .51854 L .35661 .52066 L F
.449 .826 .583 r
.36165 .51713 m .36121 .51752 L .36295 .51758 L F
.36165 .51713 m .35984 .51854 L .36121 .51752 L F
.759 .702 .798 r
.34402 .5886 m .34214 .58799 L .34443 .5876 L F
.463 .185 .404 r
.34571 .58493 m .34443 .5876 L .34214 .58799 L F
.925 .736 .628 r
.34272 .58399 m .34443 .5876 L .34571 .58493 L F
.559 .591 .843 r
.34214 .58799 m .34443 .5876 L .34272 .58399 L F
.344 0 0 r
.34034 .58874 m .34443 .5876 L .34214 .58799 L F
.34034 .58874 m .34284 .58873 L .34443 .5876 L F
.775 .965 .665 r
.34443 .5876 m .34284 .58873 L .34524 .58564 L F
.34443 .5876 m .34524 .58564 L .34538 .58547 L F
.759 .702 .798 r
.3457 .58916 m .34402 .5886 L .34443 .5876 L F
0 .028 .574 r
.3472 .5893 m .3457 .58916 L .34443 .5876 L F
.874 .836 .806 r
.41509 .54438 m .41363 .54707 L .41164 .54589 L F
.989 .834 .595 r
.41363 .54707 m .41164 .54848 L .41164 .54589 L F
.41363 .54707 m .41292 .54967 L .41164 .54848 L F
.396 .829 .956 r
.30528 .51586 m .30884 .51526 L .31066 .51608 L F
.415 .098 .318 r
.31066 .51608 m .31263 .51734 L .31315 .51531 L F
0 .21 .71 r
.31131 .51575 m .31263 .51734 L .31066 .51608 L F
.726 .314 .266 r
.64742 .4032 m .64397 .40142 L .6487 .40159 L F
.538 .177 .303 r
.6487 .40159 m .6502 .40314 L .64742 .4032 L F
.11 0 0 r
.27491 .61833 m .27888 .61658 L .27663 .61715 L F
0 0 0 r
.23466 .53604 m .2331 .5376 L .23466 .53607 L F
.552 .889 .64 r
.2331 .5376 m .23264 .53758 L .23466 .53607 L F
0 0 0 r
.23466 .53607 m .23264 .53758 L .23464 .53614 L F
.23466 .53607 m .23464 .53614 L .23587 .53525 L F
.23582 .53489 m .23466 .53604 L .23466 .53607 L F
.399 .81 .608 r
.23466 .53607 m .2379 .53396 L .23582 .53489 L F
.8 .662 .711 r
.70906 .3251 m .71004 .32783 L .71227 .32416 L F
.695 .6 .746 r
.37385 .62325 m .37629 .62001 L .36996 .61656 L F
.37385 .62325 m .37651 .6227 L .37629 .62001 L F
.157 .338 .794 r
.37385 .62325 m .37631 .62528 L .37651 .6227 L F
.678 .846 .43 r
.26978 .5384 m .26957 .53832 L .27153 .53688 L F
.26978 .5384 m .26843 .54052 L .26957 .53832 L F
0 0 .071 r
.37945 .56235 m .37688 .56549 L .37772 .564 L F
.594 .939 .937 r
.3013 .51861 m .30206 .5172 L .30379 .51806 L F
.3013 .51861 m .29994 .5184 L .30206 .5172 L F
.616 .063 0 r
.30663 .5279 m .30878 .52991 L .30908 .52992 L F
.212 0 0 r
.30878 .52991 m .31345 .52848 L .30908 .52992 L F
.30878 .52991 m .31105 .5299 L .31345 .52848 L F
0 0 0 r
.31345 .52848 m .31341 .52902 L .3151 .52785 L F
.31345 .52848 m .31105 .5299 L .31341 .52902 L F
.654 .261 .288 r
.39229 .59316 m .39521 .59325 L .39287 .59111 L F
.8 .343 .153 r
.39555 .59327 m .39287 .59111 L .39521 .59325 L F
.699 .39 .449 r
.57354 .43995 m .5774 .44217 L .57337 .44164 L F
.413 .676 .97 r
.29197 .61904 m .29057 .62044 L .29072 .61933 L F
.29197 .61904 m .29282 .62015 L .29057 .62044 L F
.564 .503 .746 r
.23762 .6037 m .24006 .60334 L .2391 .59892 L F
.405 .143 .399 r
.6397 .43966 m .64251 .43683 L .6417 .43846 L F
.099 0 .053 r
.6417 .43846 m .64251 .43683 L .64476 .43562 L F
.567 .804 .988 r
.72665 .28362 m .72433 .2846 L .72283 .28296 L F
.981 .706 .323 r
.72419 .287 m .72433 .2846 L .72665 .28362 L F
.821 .734 .769 r
.70948 .35165 m .70565 .35068 L .70809 .34934 L F
.70948 .35165 m .70534 .35327 L .70565 .35068 L F
.70948 .35165 m .70775 .35448 L .70534 .35327 L F
.746 .688 .795 r
.7122 .35015 m .70948 .35165 L .70809 .34934 L F
.6 .05 0 r
.68463 .34471 m .6837 .34578 L .68526 .3426 L F
.68463 .34471 m .68741 .34645 L .6837 .34578 L F
.737 .481 .542 r
.56472 .41416 m .56133 .41647 L .56167 .41377 L F
.56472 .41416 m .56581 .41666 L .56133 .41647 L F
0 .078 .606 r
.56648 .41513 m .56472 .41416 L .5657 .41295 L F
.56648 .41513 m .56581 .41666 L .56472 .41416 L F
.343 .235 .585 r
.2968 .64093 m .29508 .63921 L .29711 .63823 L F
.2968 .64093 m .29495 .64161 L .29508 .63921 L F
.66 .623 .801 r
.29322 .556 m .28872 .553 L .29119 .5523 L F
.401 .358 .696 r
.29425 .55292 m .29322 .556 L .29119 .5523 L F
.29425 .55292 m .29519 .55557 L .29322 .556 L F
.836 .585 .56 r
.56287 .43629 m .55904 .43799 L .55942 .43653 L F
.56287 .43629 m .56278 .439 L .55904 .43799 L F
.858 .695 .679 r
.70775 .35448 m .70684 .357 L .70534 .35327 L F
.543 0 0 r
.33603 .67477 m .33824 .67372 L .33472 .67314 L F
.016 0 0 r
.33853 .67381 m .33824 .67372 L .33603 .67477 L F
.33853 .67381 m .34099 .67368 L .33824 .67372 L F
.432 0 0 r
.33559 .58694 m .33866 .58688 L .33909 .58614 L F
.823 .743 .776 r
.42356 .57101 m .42789 .56968 L .42663 .5708 L F
.406 .099 .329 r
.42951 .56779 m .42663 .5708 L .42789 .56968 L F
.995 .807 .543 r
.35479 .64694 m .35214 .64518 L .35321 .64769 L F
.35479 .64694 m .35539 .64474 L .35214 .64518 L F
.357 .826 .896 r
.27028 .53136 m .26571 .5318 L .26794 .53183 L F
.273 .308 .716 r
.31758 .64401 m .31501 .64127 L .31719 .64081 L F
.397 .432 .78 r
.42663 .5708 m .42607 .57501 L .42356 .57101 L F
0 .109 .653 r
.42733 .57908 m .42568 .57895 L .42853 .5789 L F
.42733 .57908 m .42691 .58114 L .42568 .57895 L F
.561 .936 .877 r
.37587 .54191 m .37367 .54222 L .37347 .54294 L F
.807 .684 .728 r
.3778 .54031 m .37367 .54222 L .37587 .54191 L F
.067 0 .16 r
.63915 .44147 m .63649 .44477 L .63706 .4428 L F
.256 .046 .391 r
.33494 .56911 m .33721 .56816 L .33733 .56476 L F
.296 .294 .687 r
.33733 .56476 m .33875 .56297 L .33753 .56205 L F
.33733 .56476 m .33965 .56461 L .33875 .56297 L F
.275 .06 .396 r
.33733 .56476 m .33912 .56723 L .33965 .56461 L F
.33733 .56476 m .33721 .56816 L .33912 .56723 L F
.411 .808 .584 r
.2298 .53992 m .231 .53906 L .2331 .5376 L F
.552 .889 .64 r
.2331 .5376 m .231 .53906 L .23264 .53758 L F
.515 .831 .52 r
.28303 .61596 m .28383 .61512 L .28577 .61326 L F
.172 0 .313 r
.28802 .60992 m .28577 .61326 L .2874 .6124 L F
.29 0 .109 r
.28785 .61316 m .29144 .61128 L .28934 .61235 L F
.14 0 0 r
.28577 .61326 m .28383 .61512 L .28626 .61446 L F
.799 .963 .914 r
.28626 .61446 m .28934 .61235 L .2874 .6124 L F
.651 .952 .948 r
.28383 .61512 m .28446 .61354 L .28585 .61425 L F
.28433 .61498 m .28585 .61425 L .28626 .61446 L F
.28383 .61512 m .28585 .61425 L .28433 .61498 L F
.14 0 0 r
.28608 .614 m .28626 .61446 L .28667 .61372 L F
.799 .963 .914 r
.28626 .61446 m .28558 .61441 L .28609 .61413 L F
.28626 .61446 m .28609 .61413 L .28934 .61235 L F
.14 0 0 r
.28577 .61326 m .28608 .614 L .2874 .6124 L F
.56 .851 .997 r
.28626 .61446 m .28558 .61318 L .28682 .61277 L F
.28626 .61446 m .28575 .6142 L .28607 .6141 L F
.679 .954 .951 r
.28642 .61399 m .28558 .61441 L .28626 .61446 L F
.29 0 .109 r
.28558 .61441 m .28642 .61399 L .28627 .61404 L F
.28558 .61441 m .28621 .61407 L .28606 .61415 L F
.679 .954 .951 r
.28682 .61277 m .28558 .61441 L .28642 .61399 L F
.29 0 .109 r
.28558 .61441 m .29017 .61284 L .28642 .61399 L F
.2858 .61433 m .2891 .61415 L .29017 .61284 L F
.28627 .61404 m .29017 .61284 L .29144 .61128 L F
.28606 .61415 m .28844 .61288 L .28785 .61316 L F
.28621 .61407 m .28844 .61288 L .28606 .61415 L F
.28844 .61288 m .29144 .61128 L .28785 .61316 L F
.14 0 0 r
.28608 .614 m .28667 .61372 L .2874 .6124 L F
.165 0 .291 r
.2874 .6124 m .28934 .61235 L .28981 .60907 L F
.401 .307 .633 r
.28558 .61441 m .28943 .6129 L .28682 .61277 L F
.29 0 .109 r
.28558 .61441 m .28609 .61437 L .2858 .61433 L F
.28609 .61437 m .2891 .61415 L .2858 .61433 L F
.401 .307 .633 r
.28558 .61441 m .2891 .61415 L .28943 .6129 L F
.056 0 .342 r
.29215 .61597 m .29197 .61904 L .29072 .61933 L F
.953 .661 .445 r
.29215 .61597 m .29197 .61904 L .29017 .61755 L F
.719 .266 .176 r
.29419 .618 m .29017 .61755 L .29215 .61597 L F
.461 .315 .595 r
.29436 .61528 m .29419 .618 L .29215 .61597 L F
.439 .224 .488 r
.2972 .61488 m .29419 .618 L .29436 .61528 L F
.765 .802 .883 r
.29419 .618 m .29197 .61904 L .29017 .61755 L F
.439 .224 .488 r
.2972 .61488 m .29664 .61745 L .29419 .618 L F
.612 .604 .818 r
.29532 .61753 m .29299 .6185 L .29142 .6174 L F
.117 .159 .63 r
.29089 .6163 m .29147 .61662 L .28992 .61619 L F
.29149 .61637 m .29148 .61651 L .29089 .6163 L F
.29148 .61651 m .29147 .61662 L .29089 .6163 L F
.612 .604 .818 r
.29267 .61683 m .29142 .6174 L .29148 .61651 L F
.29532 .61753 m .29353 .61747 L .29267 .61683 L F
.29353 .61747 m .29142 .6174 L .29267 .61683 L F
0 0 0 r
.29144 .61128 m .28934 .61386 L .29083 .6127 L F
.28934 .61386 m .28954 .61378 L .29083 .6127 L F
.29139 .61213 m .29083 .6127 L .29139 .61224 L F
.29144 .61128 m .29083 .6127 L .29139 .61213 L F
.28934 .61386 m .2891 .61415 L .28954 .61378 L F
.667 .572 .74 r
.29083 .6127 m .2891 .61415 L .28943 .6129 L F
.117 .159 .63 r
.28952 .61355 m .28989 .61365 L .28956 .61378 L F
.611 .345 .49 r
.28943 .6129 m .28989 .61365 L .28795 .6131 L F
.28943 .6129 m .28795 .6131 L .28682 .61277 L F
.667 .572 .74 r
.29139 .61224 m .29083 .6127 L .28943 .6129 L F
.313 .046 .338 r
.28981 .60907 m .28934 .61235 L .29144 .61128 L F
.667 .572 .74 r
.29139 .61224 m .28943 .6129 L .29189 .61252 L F
.457 .293 .57 r
.28943 .6129 m .29166 .61658 L .29189 .61252 L F
.29166 .61658 m .29173 .61669 L .29174 .6166 L F
.29166 .61658 m .29174 .6166 L .29189 .61252 L F
.117 .159 .63 r
.28956 .61378 m .29149 .61637 L .28992 .61619 L F
.612 .604 .818 r
.29532 .61753 m .29148 .61651 L .29176 .61661 L F
.117 .159 .63 r
.28989 .61365 m .29173 .61669 L .28956 .61378 L F
.611 .345 .49 r
.28989 .61365 m .29166 .61658 L .28902 .61453 L F
.117 .159 .63 r
.29149 .61637 m .29173 .61669 L .29147 .61662 L F
.611 .345 .49 r
.29166 .61658 m .29173 .61669 L .29155 .61655 L F
.29166 .61658 m .29155 .61655 L .28902 .61453 L F
.612 .604 .818 r
.29209 .6167 m .29176 .61661 L .29187 .61664 L F
.29532 .61753 m .29176 .61661 L .29209 .6167 L F
.29435 .6174 m .29187 .61664 L .29404 .61736 L F
.29532 .61753 m .29187 .61664 L .29435 .6174 L F
.78 .563 .606 r
.29189 .61252 m .29175 .61615 L .28825 .61135 L F
.29175 .61615 m .29173 .61669 L .29102 .6156 L F
.611 .345 .49 r
.28989 .61365 m .28902 .61453 L .28682 .61277 L F
.78 .563 .606 r
.29175 .61615 m .29102 .6156 L .28825 .61135 L F
.612 .604 .818 r
.29148 .61651 m .29147 .61662 L .28938 .61596 L F
.135 .13 .587 r
.29147 .61662 m .29116 .6172 L .28992 .61619 L F
.522 .362 .605 r
.29056 .61831 m .29299 .6185 L .28992 .61619 L F
.135 .13 .587 r
.29116 .6172 m .29056 .61831 L .28992 .61619 L F
.595 .772 .964 r
.28693 .61719 m .28883 .61778 L .29086 .61702 L F
.486 0 0 r
.29122 .61726 m .29129 .6173 L .28992 .61619 L F
.28938 .61596 m .29122 .61726 L .28992 .61619 L F
.28938 .61596 m .28992 .61619 L .29173 .61669 L F
.612 .604 .818 r
.29147 .61662 m .29134 .61723 L .28938 .61596 L F
.486 0 0 r
.29132 .61733 m .29299 .6185 L .29212 .61785 L F
.29129 .6173 m .29212 .61785 L .28992 .61619 L F
.29132 .61733 m .29212 .61785 L .29129 .6173 L F
.135 .13 .587 r
.29134 .61723 m .29056 .61831 L .29118 .61716 L F
.29144 .6168 m .29136 .61683 L .29147 .61662 L F
.612 .604 .818 r
.29147 .61662 m .29144 .61721 L .29134 .61723 L F
.135 .13 .587 r
.29173 .61669 m .29134 .61723 L .29147 .61662 L F
.595 .772 .964 r
.29086 .61702 m .29134 .61723 L .29173 .61669 L F
.28883 .61778 m .29122 .61726 L .29086 .61702 L F
.612 .604 .818 r
.29134 .61723 m .29122 .61726 L .28938 .61596 L F
.595 .772 .964 r
.29122 .61726 m .29134 .61723 L .29086 .61702 L F
.28883 .61778 m .29056 .61831 L .29134 .61723 L F
.486 0 0 r
.29122 .61726 m .29132 .61733 L .29129 .6173 L F
.612 .604 .818 r
.29134 .61723 m .29132 .61733 L .29122 .61726 L F
.595 .772 .964 r
.29055 .61681 m .29086 .61702 L .29173 .61669 L F
.28693 .61719 m .29086 .61702 L .29055 .61681 L F
.612 .604 .818 r
.29134 .61723 m .29142 .6174 L .29132 .61733 L F
.29144 .61721 m .29142 .6174 L .29134 .61723 L F
.29148 .61651 m .28938 .61596 L .2913 .6165 L F
.29177 .61662 m .2913 .6165 L .29198 .61669 L F
.29148 .61651 m .2913 .6165 L .29177 .61662 L F
.627 .717 .911 r
.28486 .61527 m .29173 .61669 L .2913 .6165 L F
.244 .357 .781 r
.28825 .61135 m .29058 .61492 L .28682 .61277 L F
.29058 .61492 m .28932 .61477 L .28682 .61277 L F
.063 .544 .894 r
.28745 .61478 m .28938 .61596 L .28952 .6142 L F
.28745 .61478 m .28952 .6142 L .28953 .61397 L F
.627 .717 .911 r
.28572 .61511 m .28602 .61518 L .28745 .61478 L F
.252 .503 .899 r
.28952 .6142 m .2924 .615 L .28953 .61397 L F
.28938 .61596 m .29035 .61565 L .28952 .6142 L F
.244 .357 .781 r
.29058 .61492 m .29173 .61669 L .28932 .61477 L F
.252 .503 .899 r
.29035 .61565 m .2924 .615 L .28952 .6142 L F
.29035 .61565 m .29359 .61672 L .2924 .615 L F
.28938 .61596 m .29056 .61617 L .29035 .61565 L F
.29056 .61617 m .29359 .61672 L .29035 .61565 L F
.063 .544 .894 r
.28745 .61478 m .29056 .61617 L .28938 .61596 L F
.2913 .6165 m .29173 .61669 L .28938 .61596 L F
.612 .604 .818 r
.29198 .61669 m .28938 .61596 L .29281 .61699 L F
.627 .717 .911 r
.29063 .61633 m .29076 .61637 L .29061 .61629 L F
.063 .544 .894 r
.29056 .61617 m .2913 .6165 L .28938 .61596 L F
.627 .717 .911 r
.29076 .61637 m .2913 .6165 L .29068 .61622 L F
.252 .503 .899 r
.29056 .61617 m .29404 .61736 L .29359 .61672 L F
.28938 .61596 m .29063 .61633 L .29056 .61617 L F
.627 .717 .911 r
.29076 .61637 m .29068 .61622 L .29056 .61617 L F
.29076 .61637 m .29056 .61617 L .29061 .61629 L F
.612 .604 .818 r
.29148 .61651 m .29281 .61699 L .29404 .61736 L F
.252 .503 .899 r
.29063 .61633 m .29404 .61736 L .29056 .61617 L F
.627 .717 .911 r
.29061 .61629 m .29056 .61617 L .28745 .61478 L F
.28602 .61518 m .29063 .61633 L .28745 .61478 L F
.29063 .61633 m .29061 .61629 L .28745 .61478 L F
.28486 .61527 m .2913 .6165 L .28572 .61511 L F
.56 .851 .997 r
.28607 .6141 m .28446 .61354 L .28558 .61318 L F
.28575 .6142 m .28446 .61354 L .28607 .6141 L F
.42 0 0 r
.62514 .44865 m .62401 .44937 L .62142 .44832 L F
.405 0 0 r
.62782 .44856 m .62401 .44937 L .62514 .44865 L F
.178 .708 .844 r
.32291 .68538 m .32312 .68548 L .32312 .68518 L F
.848 .538 .463 r
.40825 .53686 m .4061 .53443 L .40987 .53448 L F
.431 .479 .808 r
.41201 .53272 m .41335 .53618 L .40987 .53448 L F
.762 .601 .679 r
.33996 .57753 m .3427 .576 L .33946 .57501 L F
.776 .938 .588 r
.33654 .65934 m .33602 .66094 L .33485 .66242 L F
.745 .69 .799 r
.7107 .34659 m .7122 .35015 L .70809 .34934 L F
.748 .691 .797 r
.71221 .34802 m .7122 .35015 L .7107 .34659 L F
.727 .301 .237 r
.56278 .439 m .56678 .43967 L .56676 .44142 L F
.585 .131 .142 r
.56678 .43967 m .5694 .4413 L .56676 .44142 L F
.964 .735 .542 r
.4061 .53443 m .40386 .53343 L .40366 .52994 L F
.986 .712 .357 r
.4061 .53443 m .40465 .53537 L .40386 .53343 L F
.4061 .53443 m .40596 .53687 L .40465 .53537 L F
.848 .538 .463 r
.40825 .53686 m .40596 .53687 L .4061 .53443 L F
.499 .224 .429 r
.38471 .58455 m .38465 .58672 L .38173 .58731 L F
.632 .396 .543 r
.38734 .58433 m .38465 .58672 L .38471 .58455 L F
0 0 0 r
.37285 .65989 m .37431 .65805 L .37185 .66076 L F
.278 .443 .846 r
.37269 .65469 m .37429 .65801 L .37571 .6564 L F
.881 .961 .846 r
.37331 .65616 m .37093 .65845 L .37332 .65525 L F
.865 .903 .857 r
.37332 .65525 m .37093 .65845 L .37388 .65552 L F
.787 .792 .857 r
.3689 .65871 m .36761 .66283 L .36775 .66015 L F
.3689 .65871 m .37036 .66069 L .36761 .66283 L F
.608 .827 .984 r
.37093 .65845 m .37036 .66069 L .3689 .65871 L F
.873 .863 .826 r
.37331 .65616 m .37285 .65989 L .37093 .65845 L F
.789 .949 .61 r
.3689 .65871 m .36775 .66015 L .36692 .66059 L F
.397 0 0 r
.37269 .65469 m .37515 .65608 L .37377 .65547 L F
.37515 .65608 m .3757 .6564 L .37388 .65552 L F
.3757 .6564 m .37571 .6564 L .37332 .65525 L F
.214 0 .334 r
.37752 .65342 m .37571 .6564 L .37746 .65541 L F
.37752 .65342 m .37571 .6564 L .37746 .65541 L F
.75 .232 0 r
.3742 .6553 m .37432 .65509 L .37411 .65534 L F
.692 .303 .306 r
.37449 .65532 m .3742 .6553 L .37432 .65509 L F
.75 .232 0 r
.37433 .65525 m .37432 .65509 L .3742 .6553 L F
.397 0 0 r
.37336 .65518 m .37377 .65547 L .37373 .65545 L F
.865 .903 .857 r
.37332 .65525 m .37388 .65552 L .37432 .65509 L F
.692 .303 .306 r
.3742 .6553 m .37332 .65525 L .37432 .65509 L F
.397 0 0 r
.37269 .65469 m .37373 .65545 L .37305 .65501 L F
.586 .87 .994 r
.37332 .65525 m .37378 .65547 L .37384 .65545 L F
.86 .98 .855 r
.37432 .65509 m .37388 .65552 L .37383 .65542 L F
.37432 .65509 m .37388 .65552 L .37388 .65552 L F
.397 0 0 r
.37515 .65608 m .37388 .65552 L .37373 .65545 L F
.586 .87 .994 r
.37378 .65547 m .37571 .6564 L .37424 .65529 L F
.86 .98 .855 r
.37383 .65542 m .37388 .65552 L .37376 .65547 L F
.37389 .6554 m .37376 .65547 L .37378 .65548 L F
.37432 .65509 m .37383 .65542 L .37389 .6554 L F
.586 .87 .994 r
.37332 .65525 m .37384 .65545 L .37375 .65527 L F
.86 .98 .855 r
.37383 .65542 m .37376 .65547 L .37389 .6554 L F
.586 .87 .994 r
.37383 .65542 m .37384 .65545 L .37411 .65534 L F
.86 .98 .855 r
.37432 .65509 m .37378 .65548 L .3741 .65536 L F
.586 .87 .994 r
.37375 .65527 m .37383 .65542 L .37424 .65529 L F
.37383 .65542 m .37411 .65534 L .37424 .65529 L F
.37426 .6553 m .37571 .6564 L .37624 .65611 L F
.37449 .65532 m .37624 .65611 L .37733 .65549 L F
.37426 .6553 m .37624 .65611 L .37449 .65532 L F
.577 .901 .983 r
.37571 .6564 m .37331 .65616 L .37643 .6556 L F
.714 .851 .948 r
.37494 .65556 m .37331 .65616 L .37331 .65566 L F
.37746 .65541 m .37536 .65579 L .37494 .65556 L F
.37536 .65579 m .37331 .65616 L .37494 .65556 L F
.278 .443 .846 r
.37429 .65801 m .37431 .65805 L .37571 .6564 L F
0 0 0 r
.37571 .6564 m .37285 .65989 L .37331 .65616 L F
.692 .303 .306 r
.37588 .65726 m .37395 .65575 L .3742 .65554 L F
.37588 .65726 m .3742 .65554 L .37464 .65554 L F
.586 .87 .994 r
.37424 .65529 m .37426 .6553 L .37746 .65541 L F
.37426 .6553 m .37733 .65549 L .37746 .65541 L F
.714 .851 .948 r
.37746 .65541 m .37661 .65546 L .37428 .65529 L F
.37494 .65556 m .37331 .65566 L .37449 .65533 L F
.692 .303 .306 r
.37464 .65554 m .3742 .65554 L .37448 .65532 L F
.37449 .65533 m .37448 .65532 L .37449 .65532 L F
.75 .232 0 r
.37448 .65548 m .37449 .65532 L .37433 .65529 L F
.37449 .65532 m .37449 .65532 L .37443 .65529 L F
.692 .303 .306 r
.37464 .65554 m .37448 .65532 L .37449 .65533 L F
.75 .232 0 r
.37449 .65532 m .37449 .65533 L .37449 .65532 L F
.714 .851 .948 r
.37449 .65533 m .37374 .65554 L .37423 .65531 L F
.86 .98 .855 r
.37388 .65552 m .37362 .65578 L .37376 .65547 L F
.37362 .65578 m .37093 .65845 L .37368 .65555 L F
.37362 .65578 m .37368 .65555 L .37376 .65547 L F
.714 .851 .948 r
.37374 .65554 m .37368 .65556 L .3741 .65536 L F
.37368 .65556 m .37331 .65566 L .37369 .65551 L F
.37368 .65556 m .37369 .65551 L .3741 .65536 L F
.37374 .65554 m .3741 .65536 L .37423 .65531 L F
.75 .232 0 r
.37433 .65525 m .37424 .65529 L .37392 .65557 L F
.37424 .65529 m .37411 .65534 L .3741 .65536 L F
.37424 .65529 m .3741 .65536 L .37392 .65557 L F
.692 .303 .306 r
.37588 .65726 m .37434 .6553 L .37433 .6553 L F
.37395 .65575 m .3742 .6553 L .37449 .65532 L F
.75 .232 0 r
.37419 .65547 m .37433 .65525 L .37415 .65539 L F
.37433 .65529 m .37433 .65525 L .37419 .65547 L F
.37401 .65563 m .37415 .65539 L .37392 .65557 L F
.692 .303 .306 r
.3742 .65531 m .37332 .65525 L .3742 .6553 L F
.714 .851 .948 r
.37423 .65531 m .37331 .65566 L .37332 .65525 L F
.86 .98 .855 r
.3741 .65536 m .37378 .65548 L .37392 .65557 L F
.692 .303 .306 r
.37395 .65575 m .37332 .65525 L .3742 .65531 L F
.714 .851 .948 r
.37428 .65529 m .37423 .65531 L .37332 .65525 L F
.692 .303 .306 r
.37395 .65575 m .37433 .6553 L .37332 .65525 L F
.37588 .65726 m .37433 .6553 L .37395 .65575 L F
.75 .232 0 r
.37437 .65588 m .37433 .65529 L .37419 .65547 L F
.37442 .65682 m .37588 .65726 L .37542 .65662 L F
.37442 .65682 m .37542 .65662 L .37449 .65533 L F
.37442 .65682 m .37437 .65588 L .37217 .65765 L F
.466 .88 .751 r
.37345 .65702 m .37442 .65682 L .37197 .65771 L F
.692 .303 .306 r
.37588 .65726 m .37458 .65531 L .37434 .6553 L F
.75 .232 0 r
.37442 .65682 m .37448 .65548 L .37433 .65529 L F
.37442 .65682 m .37449 .65533 L .37449 .65532 L F
.714 .851 .948 r
.37661 .65546 m .37494 .65556 L .37449 .65533 L F
.37661 .65546 m .37423 .65531 L .37428 .65529 L F
.577 .901 .983 r
.37571 .6564 m .37643 .6556 L .37746 .65541 L F
.088 .123 .603 r
.37659 .65303 m .37458 .65531 L .37588 .65726 L F
.37659 .65303 m .37619 .65542 L .37646 .65562 L F
.37619 .65542 m .37588 .65726 L .37646 .65562 L F
.645 .941 .962 r
.37646 .65562 m .37588 .65726 L .37442 .65682 L F
0 0 0 r
.37683 .65589 m .37646 .65562 L .37481 .65752 L F
.728 .387 .401 r
.37893 .6517 m .37752 .65342 L .37746 .65541 L F
.972 .808 .619 r
.37802 .65016 m .37752 .65342 L .37893 .6517 L F
.985 .853 .479 r
.37688 .65186 m .37752 .65342 L .37802 .65016 L F
.914 .679 .18 r
.37746 .65541 m .37752 .65342 L .37688 .65186 L F
.451 0 0 r
.37706 .65274 m .37893 .6517 L .37746 .65541 L F
0 0 .372 r
.37706 .65274 m .37746 .65541 L .37688 .65186 L F
0 0 0 r
.37823 .65477 m .37646 .65562 L .37683 .65589 L F
.466 .88 .751 r
.37646 .65562 m .37442 .65682 L .37345 .65702 L F
.75 .232 0 r
.37433 .65529 m .37449 .65532 L .37433 .65525 L F
.37449 .65532 m .37443 .65529 L .37433 .65525 L F
.37433 .65525 m .37449 .65532 L .37432 .65509 L F
.37437 .65588 m .37415 .65539 L .37401 .65563 L F
.37437 .65588 m .37392 .65557 L .37217 .65765 L F
.397 0 0 r
.37269 .65469 m .37377 .65547 L .37336 .65518 L F
.007 0 0 r
.36787 .65943 m .37093 .65845 L .3689 .65871 L F
.86 .98 .855 r
.37376 .65547 m .37093 .65845 L .36787 .65943 L F
.37392 .65557 m .36787 .65943 L .37217 .65765 L F
.37376 .65547 m .36787 .65943 L .37392 .65557 L F
.397 0 0 r
.37305 .65501 m .37373 .65545 L .37332 .65525 L F
.581 .296 .448 r
.29124 .56194 m .2907 .5653 L .28742 .56527 L F
.058 0 .276 r
.29217 .56401 m .29124 .56194 L .2936 .5619 L F
.29217 .56401 m .2907 .5653 L .29124 .56194 L F
.626 .934 .965 r
.2687 .52391 m .26656 .52511 L .26493 .5247 L F
.486 .32 .581 r
.31927 .56148 m .31662 .55976 L .3187 .55821 L F
.31927 .56148 m .31678 .56218 L .31662 .55976 L F
.051 0 0 r
.63408 .43243 m .63148 .433 L .63027 .43401 L F
.885 .755 .714 r
.69107 .34459 m .68919 .3478 L .68741 .34645 L F
.521 0 0 r
.28924 .64951 m .29395 .65119 L .29204 .65067 L F
.714 .227 0 r
.29395 .65119 m .29429 .65255 L .29204 .65067 L F
.501 0 0 r
.29613 .65583 m .30001 .65774 L .29847 .65797 L F
.068 .22 .714 r
.29842 .65778 m .29613 .65583 L .29847 .65797 L F
.714 .227 0 r
.29395 .65119 m .29716 .65558 L .29548 .65381 L F
.981 .855 .641 r
.29716 .65558 m .29875 .65534 L .298 .65645 L F
.76 .673 .766 r
.30041 .65367 m .298 .65645 L .29875 .65534 L F
.595 .125 .11 r
.298 .65645 m .3016 .65643 L .30001 .65774 L F
.981 .855 .641 r
.29716 .65558 m .298 .65645 L .29613 .65583 L F
.501 0 0 r
.29613 .65583 m .298 .65645 L .30001 .65774 L F
.888 .732 .683 r
.29429 .65255 m .29716 .65558 L .29613 .65583 L F
.068 .22 .714 r
.29758 .65398 m .29657 .65527 L .29842 .65778 L F
.29657 .65527 m .29613 .65583 L .29842 .65778 L F
.714 .227 0 r
.29416 .65202 m .29548 .65381 L .29429 .65255 L F
.29395 .65119 m .29548 .65381 L .29416 .65202 L F
.228 .226 .649 r
.24868 .54982 m .25071 .55186 L .24888 .55301 L F
.428 .338 .652 r
.25071 .55186 m .24918 .55536 L .24888 .55301 L F
0 0 0 r
.30404 .62574 m .30074 .62765 L .30198 .6266 L F
.439 0 .034 r
.34885 .66403 m .35224 .66325 L .35126 .66455 L F
.569 .81 .427 r
.35126 .66455 m .35224 .66325 L .35461 .66009 L F
0 0 .331 r
.34571 .58427 m .34509 .58309 L .34352 .57992 L F
.34571 .58427 m .34571 .58493 L .34509 .58309 L F
.425 .866 .902 r
.37285 .65989 m .37185 .66076 L .37036 .66069 L F
.799 .661 .109 r
.35293 .52707 m .35615 .52492 L .35505 .52467 L F
.956 .891 .725 r
.35661 .52066 m .35615 .52492 L .35493 .52205 L F
.35661 .52066 m .35505 .52467 L .35615 .52492 L F
.583 .432 .641 r
.35842 .52725 m .35571 .52775 L .35615 .52492 L F
.35615 .52492 m .35571 .52775 L .35842 .52725 L F
.111 0 .173 r
.63915 .44147 m .6397 .43966 L .6417 .43846 L F
.819 .849 .871 r
.71375 .29734 m .70974 .29836 L .71258 .29539 L F
.545 .429 .672 r
.71626 .29386 m .71375 .29734 L .71258 .29539 L F
.71626 .29386 m .7165 .29651 L .71375 .29734 L F
.468 .232 .473 r
.71375 .29734 m .7165 .29651 L .71593 .29855 L F
.564 .85 .997 r
.26246 .52525 m .26013 .52603 L .25807 .52497 L F
.732 .667 .786 r
.57091 .42664 m .57222 .43105 L .56808 .4299 L F
.85 .567 .509 r
.57091 .42664 m .57446 .42961 L .57222 .43105 L F
.747 .464 .502 r
.34971 .56233 m .34541 .56431 L .34709 .56252 L F
.357 0 0 r
.30085 .53822 m .29926 .54084 L .29721 .54079 L F
.481 .102 .244 r
.30188 .5399 m .29926 .54084 L .30085 .53822 L F
.871 .5 .34 r
.30983 .65938 m .30819 .66134 L .30882 .65977 L F
.30983 .65938 m .312 .66322 L .30819 .66134 L F
.515 .436 .705 r
.35321 .64769 m .3555 .65027 L .35479 .64694 L F
0 0 0 r
.34418 .50717 m .34103 .50805 L .34125 .50579 L F
.714 .66 .795 r
.28458 .62611 m .28844 .62593 L .2869 .62241 L F
.389 .435 .788 r
.28844 .62593 m .28917 .62215 L .2869 .62241 L F
.28844 .62593 m .29064 .62605 L .28917 .62215 L F
.404 .366 .702 r
.28844 .62593 m .29088 .62799 L .29064 .62605 L F
.859 .755 .746 r
.6858 .33517 m .68315 .33478 L .68476 .33138 L F
.767 .483 .503 r
.6858 .33517 m .68206 .33701 L .68315 .33478 L F
.6858 .33517 m .68597 .33757 L .68206 .33701 L F
.337 0 0 r
.23536 .55331 m .23764 .55402 L .23987 .55367 L F
.643 .224 .235 r
.23764 .55402 m .24199 .5527 L .23987 .55367 L F
.882 .766 .73 r
.55972 .3943 m .56107 .39759 L .55827 .39711 L F
.865 .518 .393 r
.55827 .39711 m .56107 .39759 L .55863 .39796 L F
.55 .605 .861 r
.56401 .39681 m .56107 .39759 L .55972 .3943 L F
.265 .773 .793 r
.55863 .39796 m .56107 .39759 L .56401 .39681 L F
.392 0 .151 r
.37294 .71175 m .37462 .71302 L .37226 .71361 L F
.37294 .71175 m .37577 .7108 L .37462 .71302 L F
.756 .725 .824 r
.34938 .57483 m .34592 .57495 L .34847 .5718 L F
.3529 .57309 m .34938 .57483 L .34847 .5718 L F
.902 .873 .799 r
.70684 .32233 m .70758 .31814 L .70654 .32039 L F
.904 .581 .424 r
.70519 .32387 m .70684 .32233 L .70654 .32039 L F
.70519 .32387 m .707 .32482 L .70684 .32233 L F
.752 .493 .541 r
.70906 .3251 m .70684 .32233 L .707 .32482 L F
.349 .661 .972 r
.27355 .52241 m .27302 .52383 L .27108 .52312 L F
.27355 .52241 m .27524 .52397 L .27302 .52383 L F
.445 .549 .868 r
.22401 .56189 m .22269 .5631 L .2198 .55844 L F
.756 .725 .824 r
.3529 .57309 m .34847 .5718 L .35133 .57123 L F
.622 .684 .887 r
.35505 .57195 m .3529 .57309 L .35133 .57123 L F
.505 0 0 r
.23315 .60663 m .23511 .60824 L .23601 .60862 L F
.939 .644 .456 r
.23511 .60824 m .23734 .611 L .23601 .60862 L F
.371 .524 .879 r
.31922 .55097 m .32097 .55282 L .31871 .55302 L F
.481 .417 .708 r
.32097 .55282 m .31916 .55633 L .31871 .55302 L F
0 .469 .72 r
.35232 .50274 m .35615 .50356 L .35431 .50417 L F
.383 .844 .878 r
.56299 .42861 m .5615 .42955 L .55973 .42682 L F
.771 .497 .521 r
.56121 .42651 m .56338 .42819 L .56299 .42861 L F
.383 .844 .878 r
.56299 .42861 m .56423 .42873 L .56235 .42929 L F
.366 .834 .874 r
.56603 .42776 m .56423 .42873 L .56299 .42861 L F
.365 .835 .858 r
.56603 .42776 m .56682 .42792 L .56423 .42873 L F
.366 .834 .874 r
.56603 .42776 m .56299 .42861 L .56531 .42969 L F
.771 .497 .521 r
.56338 .42819 m .56531 .42969 L .56299 .42861 L F
.383 .844 .878 r
.56299 .42861 m .56235 .42929 L .5615 .42955 L F
.071 .281 .768 r
.59516 .42617 m .59374 .42701 L .59271 .42622 L F
.561 .378 .591 r
.59374 .42701 m .59706 .43024 L .59612 .4272 L F
.583 .131 .143 r
.59907 .42885 m .60007 .42742 L .59612 .4272 L F
.6 .607 .83 r
.59907 .42885 m .59648 .42708 L .59784 .42764 L F
.59648 .42708 m .59516 .42617 L .59784 .42764 L F
.699 .669 .817 r
.60281 .42609 m .60158 .43067 L .60007 .42742 L F
.718 .829 .934 r
.60041 .42498 m .60007 .42742 L .59907 .42885 L F
.963 .896 .711 r
.60041 .42498 m .59907 .42885 L .59784 .42764 L F
0 .311 .76 r
.59784 .42764 m .60084 .42962 L .601 .42821 L F
.329 0 0 r
.59784 .42764 m .601 .42821 L .59919 .4282 L F
.682 .826 .952 r
.59729 .42781 m .59907 .42885 L .59784 .42764 L F
.583 .131 .143 r
.59907 .42885 m .59612 .4272 L .59706 .43024 L F
.6 .607 .83 r
.59907 .42885 m .59706 .43024 L .59516 .42617 L F
0 .311 .76 r
.59784 .42764 m .59907 .42885 L .60084 .42962 L F
.329 0 0 r
.59784 .42764 m .59919 .4282 L .59653 .42817 L F
.071 .281 .768 r
.59516 .42617 m .59672 .42951 L .59374 .42701 L F
.682 .826 .952 r
.59537 .4284 m .59703 .4286 L .59729 .42781 L F
.59703 .4286 m .59907 .42885 L .59729 .42781 L F
.071 .281 .768 r
.59672 .42951 m .59706 .43024 L .59662 .42981 L F
.59672 .42951 m .59662 .42981 L .59374 .42701 L F
0 0 .39 r
.26348 .53315 m .26355 .5359 L .26218 .53695 L F
.076 .387 .848 r
.28438 .62821 m .28228 .62608 L .28458 .62611 L F
.699 .669 .817 r
.60281 .42609 m .60424 .42975 L .60158 .43067 L F
.486 .683 .953 r
.64939 .39687 m .64687 .39712 L .64475 .39468 L F
0 0 .38 r
.30833 .58297 m .30837 .57986 L .30637 .58167 L F
.157 0 .356 r
.19958 .5658 m .20069 .56729 L .20117 .56475 L F
.19958 .5658 m .19914 .56834 L .20069 .56729 L F
.262 .472 .875 r
.42294 .55813 m .42194 .56038 L .42084 .55845 L F
.42294 .55813 m .42465 .56137 L .42194 .56038 L F
.843 .813 .328 r
.40714 .59802 m .40781 .59758 L .40836 .59585 L F
.40714 .59802 m .4071 .59998 L .40781 .59758 L F
.977 .762 .548 r
.35679 .53264 m .35581 .53301 L .35603 .53131 L F
.288 0 0 r
.35581 .53301 m .36015 .53178 L .35679 .53264 L F
0 0 0 r
.31255 .55594 m .31435 .55505 L .31245 .5557 L F
.547 .264 .438 r
.31423 .55498 m .31552 .55563 L .31804 .55149 L F
0 0 0 r
.31435 .55505 m .31549 .55448 L .31423 .55498 L F
.31435 .55505 m .31423 .55498 L .31245 .5557 L F
.547 .264 .438 r
.31392 .55527 m .31503 .55643 L .31552 .55563 L F
0 0 0 r
.31435 .55505 m .31392 .55527 L .31549 .55448 L F
.31255 .55594 m .31392 .55527 L .31435 .55505 L F
.547 .264 .438 r
.31392 .55527 m .31552 .55563 L .31435 .55505 L F
.31392 .55527 m .31435 .55505 L .31423 .55498 L F
.31392 .55527 m .31423 .55498 L .31549 .55448 L F
.31423 .55498 m .31804 .55149 L .31549 .55448 L F
0 0 0 r
.31245 .5557 m .31549 .55448 L .31157 .55355 L F
.454 .187 .418 r
.31157 .55355 m .31549 .55448 L .31448 .55049 L F
.62 .287 .385 r
.31448 .55049 m .31549 .55448 L .31804 .55149 L F
.31448 .55049 m .31549 .55448 L .31804 .55149 L F
.679 .588 .746 r
.37629 .62001 m .37651 .6227 L .37879 .61958 L F
.556 .421 .652 r
.37651 .6227 m .37945 .62265 L .37879 .61958 L F
.739 .77 .878 r
.37686 .62297 m .37441 .62318 L .37701 .62259 L F
.37686 .62297 m .37701 .62259 L .37779 .62241 L F
.113 0 0 r
.37686 .62297 m .37651 .6227 L .3764 .62411 L F
.37686 .62297 m .3764 .62411 L .37631 .62528 L F
.37686 .62297 m .37945 .62265 L .37651 .6227 L F
.786 .362 .243 r
.22993 .60475 m .23154 .60344 L .22785 .60202 L F
.881 .449 .136 r
.23125 .60562 m .23154 .60344 L .22993 .60475 L F
.23125 .60562 m .23315 .60663 L .23154 .60344 L F
.789 .626 .679 r
.34299 .54637 m .3471 .54749 L .34601 .54334 L F
.709 .225 .096 r
.34299 .54637 m .34539 .54853 L .3471 .54749 L F
.193 .242 .685 r
.34653 .54401 m .3471 .54749 L .3482 .54615 L F
.34631 .54409 m .3471 .54749 L .34653 .54401 L F
.34607 .54358 m .3471 .54749 L .3462 .54358 L F
.34601 .54334 m .3482 .54615 L .34783 .54496 L F
.34601 .54334 m .34861 .54565 L .34847 .54325 L F
0 0 0 r
.34832 .54344 m .34548 .54455 L .34772 .54358 L F
.34841 .54333 m .34772 .54358 L .34847 .54325 L F
.34832 .54344 m .34772 .54358 L .34841 .54333 L F
.193 .242 .685 r
.3462 .54358 m .34631 .54409 L .34653 .54401 L F
.34601 .54334 m .34607 .54358 L .3462 .54358 L F
.789 .626 .679 r
.34299 .54637 m .34601 .54334 L .34378 .54386 L F
.4 .316 .645 r
.34367 .54472 m .34593 .54678 L .34548 .54455 L F
.883 .596 .081 r
.34548 .54455 m .34593 .54678 L .34533 .54477 L F
.069 0 0 r
.34584 .54405 m .34548 .54455 L .34367 .54472 L F
.75 .659 .76 r
.34543 .54083 m .34378 .54386 L .34601 .54334 L F
.523 .411 .668 r
.34601 .54334 m .34804 .53996 L .34543 .54083 L F
.34601 .54334 m .34847 .54325 L .34804 .53996 L F
.918 .977 .717 r
.34543 .54083 m .3432 .54221 L .34378 .54386 L F
0 0 0 r
.34367 .54472 m .34378 .54386 L .3432 .54221 L F
.069 0 0 r
.34723 .54301 m .34367 .54472 L .3432 .54221 L F
.3474 .54358 m .34367 .54472 L .34723 .54301 L F
.696 .58 .721 r
.34192 .54063 m .34543 .54083 L .34452 .53694 L F
.241 0 .183 r
.34192 .54063 m .3445 .53975 L .34543 .54083 L F
.984 .71 .343 r
.34452 .53694 m .34543 .54083 L .3445 .53975 L F
.852 .601 .559 r
.34847 .54325 m .3432 .54221 L .3445 .53975 L F
.407 .388 .726 r
.34367 .54472 m .34548 .54455 L .34503 .54049 L F
.883 .596 .081 r
.34548 .54455 m .34533 .54477 L .34479 .54297 L F
.069 0 0 r
.3474 .54358 m .34548 .54455 L .34584 .54405 L F
.34847 .54325 m .34772 .54358 L .3474 .54358 L F
.34772 .54358 m .34548 .54455 L .3474 .54358 L F
.34847 .54325 m .3474 .54358 L .34723 .54301 L F
.193 .242 .685 r
.34783 .54496 m .3482 .54615 L .34861 .54565 L F
.639 .936 .688 r
.3471 .54749 m .34539 .54853 L .34861 .54565 L F
.776 .879 .455 r
.73241 .34546 m .73065 .34959 L .7319 .34815 L F
.79 .647 .704 r
.39939 .60927 m .40043 .61314 L .39695 .61281 L F
.597 .574 .798 r
.40034 .61561 m .39695 .61281 L .40043 .61314 L F
.227 .185 .6 r
.40044 .60926 m .40043 .61314 L .39939 .60927 L F
.40044 .60926 m .40273 .61198 L .40043 .61314 L F
0 0 .136 r
.40273 .61198 m .40034 .61561 L .40043 .61314 L F
.779 .57 .617 r
.3025 .52741 m .30632 .53079 L .30663 .5279 L F
.454 .282 .557 r
.30663 .5279 m .30632 .53079 L .30878 .52991 L F
.979 .725 .479 r
.37956 .66961 m .38106 .67326 L .37941 .67229 L F
.559 .574 .825 r
.37956 .66961 m .38106 .67326 L .38351 .67273 L F
.487 .817 1 r
.37941 .67229 m .38106 .67326 L .38351 .67273 L F
.549 .241 .398 r
.35002 .56954 m .34847 .5718 L .34563 .57262 L F
.711 .686 .825 r
.35175 .5689 m .35002 .56954 L .34676 .56586 L F
.51 .197 .371 r
.35175 .5689 m .34847 .5718 L .35002 .56954 L F
.076 .212 .703 r
.62091 .42194 m .61869 .41973 L .61888 .41929 L F
.325 .133 .459 r
.61859 .41919 m .62064 .41396 L .62063 .41626 L F
.118 .265 .74 r
.61962 .41753 m .61857 .41922 L .61871 .41902 L F
.61962 .41753 m .61871 .41902 L .62063 .41626 L F
.137 0 0 r
.62063 .41626 m .62208 .41693 L .61962 .41753 L F
.507 .816 1 r
.62013 .4167 m .61962 .41753 L .62208 .41693 L F
.325 .133 .459 r
.61859 .41919 m .62064 .41396 L .61859 .41919 L F
.507 .816 1 r
.61845 .4165 m .61962 .41753 L .62013 .4167 L F
.076 .212 .703 r
.62027 .41974 m .61888 .41929 L .61962 .41753 L F
.62091 .42194 m .61888 .41929 L .62027 .41974 L F
.325 .133 .459 r
.61857 .41922 m .61859 .41919 L .61859 .41919 L F
.359 .13 .423 r
.62063 .41626 m .62064 .41396 L .62323 .41292 L F
.56 .733 .956 r
.32394 .54626 m .32638 .54589 L .32638 .54597 L F
.581 .524 .756 r
.32394 .54626 m .32638 .54597 L .32625 .54424 L F
.693 .452 .555 r
.59691 .43557 m .59523 .43851 L .59274 .43858 L F
.789 .414 .346 r
.59691 .43557 m .59915 .4383 L .59523 .43851 L F
.433 .253 .535 r
.24112 .56785 m .23926 .56542 L .24096 .56483 L F
.24112 .56785 m .23885 .56856 L .23926 .56542 L F
.222 .038 .406 r
.40396 .60569 m .40362 .6082 L .40044 .60926 L F
.285 .198 .578 r
.40362 .6082 m .40273 .61198 L .40044 .60926 L F
.339 .795 .945 r
.24054 .54627 m .23638 .54619 L .2382 .54647 L F
.254 .079 .44 r
.3983 .6191 m .3966 .6216 L .39682 .6213 L F
.419 0 0 r
.32058 .62539 m .32314 .62487 L .32405 .62435 L F
.809 .917 .911 r
.64028 .39596 m .6362 .39748 L .63893 .39443 L F
.606 .731 .933 r
.64139 .39345 m .64028 .39596 L .63893 .39443 L F
.64139 .39345 m .64237 .39532 L .64028 .39596 L F
.721 .514 .61 r
.70505 .34762 m .70173 .35025 L .70237 .34864 L F
.543 0 0 r
.33603 .67477 m .33472 .67314 L .3347 .67595 L F
.595 .377 .555 r
.30428 .60685 m .30393 .60979 L .30113 .60987 L F
.479 .345 .621 r
.3059 .60611 m .30393 .60979 L .30428 .60685 L F
.775 .977 .914 r
.29874 .64989 m .30084 .64973 L .299 .64919 L F
.891 .541 .375 r
.29874 .64989 m .30103 .65115 L .30084 .64973 L F
0 0 .291 r
.23079 .57504 m .23044 .57755 L .22936 .57831 L F
0 0 .025 r
.23044 .57755 m .22817 .58092 L .22936 .57831 L F
0 .125 .637 r
.40881 .53972 m .40596 .53687 L .40825 .53686 L F
.709 .788 .913 r
.28286 .52923 m .28696 .5293 L .28562 .52808 L F
.405 .609 .932 r
.28696 .5293 m .28777 .52721 L .28562 .52808 L F
.28696 .5293 m .29 .53043 L .28777 .52721 L F
.884 .939 .846 r
.34853 .55424 m .34588 .557 L .34428 .55599 L F
.276 .312 .719 r
.34853 .55424 m .34983 .55273 L .34794 .55315 L F
.34853 .55424 m .35062 .55526 L .34983 .55273 L F
.974 .917 .596 r
.31915 .5746 m .31813 .57655 L .31987 .57514 L F
0 0 0 r
.35875 .5478 m .35939 .5464 L .35822 .54562 L F
.042 0 0 r
.36245 .54381 m .35822 .54562 L .35939 .5464 L F
.885 .991 .778 r
.28395 .62425 m .28458 .62611 L .2869 .62241 L F
.298 .033 .332 r
.28438 .62821 m .28395 .62425 L .28243 .62691 L F
.771 .647 .725 r
.28392 .62308 m .28243 .62691 L .28395 .62425 L F
.28392 .62308 m .2806 .62585 L .28243 .62691 L F
.978 .735 .498 r
.28243 .62691 m .2806 .62585 L .28381 .6265 L F
.298 .033 .332 r
.28433 .62777 m .28458 .62611 L .28395 .62425 L F
.978 .735 .498 r
.28392 .62676 m .28381 .6265 L .28473 .62668 L F
.28243 .62691 m .28381 .6265 L .28392 .62676 L F
.298 .033 .332 r
.28438 .62821 m .28441 .62795 L .28433 .62777 L F
.28441 .62795 m .28458 .62611 L .28433 .62777 L F
.28438 .62821 m .28624 .62797 L .28458 .62611 L F
.28458 .62611 m .28624 .62797 L .28438 .62821 L F
.525 .708 .955 r
.26721 .60929 m .26541 .61012 L .26383 .6087 L F
.156 .27 .731 r
.26623 .60966 m .26541 .61012 L .26721 .60929 L F
.686 .162 0 r
.35286 .71239 m .35687 .71434 L .35576 .71316 L F
.363 0 0 r
.35286 .71239 m .35576 .71316 L .35359 .71341 L F
.931 .654 .493 r
.38594 .52135 m .38638 .52444 L .38834 .52445 L F
0 .142 .634 r
.38638 .52444 m .38873 .52658 L .38834 .52445 L F
.629 .398 .548 r
.23087 .5878 m .2305 .59045 L .22575 .59086 L F
.627 .605 .808 r
.23183 .58324 m .23087 .5878 L .22961 .58472 L F
.23183 .58324 m .23348 .58763 L .23087 .5878 L F
.479 .203 .417 r
.23348 .58763 m .2305 .59045 L .23087 .5878 L F
.391 .847 .896 r
.32668 .66823 m .3303 .66777 L .32871 .66892 L F
.307 0 0 r
.33214 .6678 m .32871 .66892 L .3303 .66777 L F
.764 .588 .659 r
.34146 .5112 m .34556 .51223 L .34512 .50889 L F
.196 .482 .896 r
.34512 .50889 m .34539 .50747 L .34418 .50717 L F
.537 .826 .999 r
.34754 .50823 m .34539 .50747 L .34512 .50889 L F
0 0 .109 r
.34512 .50889 m .34529 .50973 L .34539 .50747 L F
.34512 .50889 m .34556 .51223 L .34529 .50973 L F
.675 .266 .264 r
.36329 .60994 m .36721 .61001 L .36586 .61361 L F
.238 0 .099 r
.36586 .61361 m .36721 .61001 L .36902 .60941 L F
.771 .703 .788 r
.34665 .59106 m .34404 .59424 L .34752 .59391 L F
.861 .546 .454 r
.35011 .59438 m .34665 .59106 L .34752 .59391 L F
.624 .273 .354 r
.34956 .59599 m .34752 .59391 L .34689 .59689 L F
.34956 .59599 m .35011 .59438 L .34752 .59391 L F
.172 .233 .686 r
.62091 .42194 m .61954 .42403 L .61869 .41973 L F
.56 .758 .971 r
.62091 .42194 m .62193 .42351 L .61954 .42403 L F
.596 .909 .981 r
.2561 .6324 m .26004 .63194 L .25846 .63158 L F
0 .456 .825 r
.26004 .63194 m .26034 .6315 L .25846 .63158 L F
.26004 .63194 m .26201 .63254 L .26034 .6315 L F
.262 0 0 r
.32818 .52078 m .32392 .52357 L .32413 .52119 L F
.32818 .52078 m .32584 .52347 L .32392 .52357 L F
.424 .435 .768 r
.32661 .52507 m .32954 .5254 L .32849 .52363 L F
.21 0 0 r
.33047 .52073 m .32617 .52327 L .32818 .52078 L F
.424 .435 .768 r
.32725 .52344 m .32816 .52308 L .32735 .52316 L F
.32661 .52507 m .32735 .52316 L .32584 .52347 L F
.21 0 0 r
.32617 .52327 m .32711 .52321 L .32584 .52347 L F
.33047 .52073 m .32855 .52305 L .32816 .52308 L F
.32714 .5227 m .32816 .52308 L .32617 .52327 L F
.33047 .52073 m .32816 .52308 L .32714 .5227 L F
.73 .284 .192 r
.33164 .5232 m .32849 .52312 L .33047 .52073 L F
0 .151 .69 r
.32769 .52229 m .32816 .52308 L .32963 .52344 L F
.424 .435 .768 r
.32725 .52344 m .32849 .52363 L .32816 .52308 L F
.32661 .52507 m .32849 .52363 L .32725 .52344 L F
.416 .453 .79 r
.32832 .52314 m .32661 .52507 L .32584 .52347 L F
.32849 .52312 m .32837 .52325 L .32832 .52314 L F
.32837 .52325 m .32661 .52507 L .32832 .52314 L F
0 .07 .622 r
.33217 .52732 m .33278 .52569 L .33164 .5232 L F
.806 .643 .681 r
.33206 .52412 m .32849 .52312 L .33164 .5232 L F
.33278 .52569 m .3309 .52457 L .33206 .52412 L F
.3309 .52457 m .32849 .52312 L .33206 .52412 L F
.33278 .52569 m .32954 .5254 L .32849 .52312 L F
0 .151 .69 r
.32832 .52314 m .32954 .5254 L .32962 .52363 L F
.416 .453 .79 r
.32849 .52312 m .32954 .5254 L .32837 .52325 L F
0 .151 .69 r
.32837 .52325 m .32954 .5254 L .32832 .52314 L F
.32863 .52386 m .32954 .5254 L .32837 .52325 L F
.32816 .52308 m .32863 .52386 L .32832 .52314 L F
.416 .453 .79 r
.32837 .52325 m .32954 .5254 L .32661 .52507 L F
.947 .84 .705 r
.32956 .5251 m .32719 .52584 L .32963 .52344 L F
.32954 .5254 m .32809 .52567 L .32956 .5251 L F
.32809 .52567 m .32719 .52584 L .32956 .5251 L F
0 .151 .69 r
.32816 .52308 m .32962 .52363 L .32963 .52344 L F
.424 .435 .768 r
.32735 .52316 m .32769 .52229 L .32584 .52347 L F
.21 0 0 r
.32711 .52321 m .32849 .52312 L .32584 .52347 L F
.32855 .52305 m .32849 .52312 L .32617 .52327 L F
.424 .435 .768 r
.32735 .52316 m .32816 .52308 L .32769 .52229 L F
.21 0 0 r
.32617 .52327 m .32584 .52347 L .32603 .52325 L F
.32617 .52327 m .32603 .52325 L .32818 .52078 L F
0 .289 .788 r
.251 .6193 m .25051 .62022 L .24884 .61906 L F
.251 .6193 m .25285 .62173 L .25051 .62022 L F
.269 0 .043 r
.2661 .62235 m .26845 .62179 L .27009 .61918 L F
.248 0 .032 r
.27009 .61918 m .27091 .62111 L .27246 .61905 L F
.27009 .61918 m .26845 .62179 L .27091 .62111 L F
.297 .442 .838 r
.37173 .57687 m .37478 .57957 L .37801 .5791 L F
.693 .454 .557 r
.37478 .57957 m .37804 .57709 L .37801 .5791 L F
.779 .551 .591 r
.31881 .53721 m .31422 .53962 L .31643 .53667 L F
.31881 .53721 m .31833 .54029 L .31422 .53962 L F
.687 .172 0 r
.31858 .5379 m .31881 .53721 L .31643 .53667 L F
.458 .257 .519 r
.32066 .53954 m .31833 .54029 L .31881 .53721 L F
.687 .172 0 r
.31858 .5379 m .32066 .53954 L .31881 .53721 L F
.797 .795 .85 r
.60257 .39428 m .60192 .39845 L .60081 .39707 L F
.60257 .39428 m .60543 .3953 L .60192 .39845 L F
1 .82 .495 r
.60192 .39845 m .60081 .39923 L .60081 .39707 L F
.60192 .39845 m .60177 .40065 L .60081 .39923 L F
.73 .571 .675 r
.35552 .61906 m .35694 .62319 L .36194 .62072 L F
.44 .325 .626 r
.35694 .62319 m .35925 .62512 L .36194 .62072 L F
.832 .556 .008 r
.36194 .62072 m .36199 .62183 L .3612 .61841 L F
.74 .656 .767 r
.31315 .51531 m .31406 .51818 L .31672 .51513 L F
.329 .691 .98 r
.24584 .62751 m .24685 .62617 L .24391 .62531 L F
.24584 .62751 m .24841 .62747 L .24685 .62617 L F
.958 .641 .381 r
.4202 .5721 m .4186 .57345 L .41886 .57071 L F
.4202 .5721 m .42036 .57447 L .4186 .57345 L F
.445 .879 .883 r
.72885 .35223 m .72604 .35368 L .7285 .3533 L F
.872 .956 .858 r
.5546 .42817 m .55511 .42984 L .5541 .42908 L F
.5546 .42817 m .55753 .42717 L .55511 .42984 L F
.977 .695 .302 r
.5541 .42908 m .55511 .42984 L .55528 .43264 L F
0 0 .055 r
.36671 .54679 m .36592 .54874 L .36821 .5458 L F
.41 .384 .719 r
.3131 .53307 m .31385 .53678 L .31175 .53722 L F
.685 .546 .69 r
.31385 .53678 m .31146 .5397 L .31175 .53722 L F
.313 .452 .841 r
.41335 .53618 m .41623 .53733 L .4134 .53792 L F
.31 .426 .818 r
.41623 .53733 m .41634 .53952 L .4134 .53792 L F
.339 .423 .801 r
.4134 .53792 m .41634 .53952 L .41486 .54017 L F
0 .461 .77 r
.2309 .55877 m .22864 .55787 L .22695 .55746 L F
0 .526 .82 r
.2309 .55877 m .23159 .55865 L .22864 .55787 L F
.297 .295 .688 r
.2309 .55877 m .2334 .56101 L .23159 .55865 L F
.2309 .55877 m .23238 .56213 L .2334 .56101 L F
.501 .226 .428 r
.23379 .57237 m .23326 .57468 L .23079 .57504 L F
.297 .045 .353 r
.23536 .57379 m .23379 .57237 L .23624 .57182 L F
.23536 .57379 m .23326 .57468 L .23379 .57237 L F
.874 .836 .806 r
.41509 .54438 m .41164 .54589 L .41152 .54339 L F
.085 .091 .567 r
.41652 .54215 m .41509 .54438 L .41486 .54017 L F
.414 .527 .864 r
.41652 .54215 m .41808 .54546 L .41509 .54438 L F
.794 .816 .869 r
.34386 .5024 m .33882 .50252 L .34209 .50142 L F
.103 .522 .91 r
.34444 .50145 m .34386 .5024 L .34209 .50142 L F
.34444 .50145 m .34584 .50308 L .34386 .5024 L F
.597 .574 .798 r
.40034 .61561 m .39812 .61644 L .39695 .61281 L F
0 0 0 r
.40034 .61561 m .3983 .6191 L .39812 .61644 L F
.157 0 .288 r
.31523 .58973 m .31279 .59291 L .31339 .59089 L F
.422 .848 .704 r
.2298 .53992 m .22897 .54025 L .231 .53906 L F
.67 .253 .245 r
.36005 .56457 m .35632 .56271 L .36008 .56261 L F
.36005 .56457 m .35614 .56456 L .35632 .56271 L F
.749 .991 .801 r
.35614 .56456 m .35982 .56227 L .35632 .56271 L F
.35614 .56456 m .35654 .56322 L .35982 .56227 L F
.942 .858 .431 r
.35982 .56227 m .36016 .55725 L .35624 .55715 L F
.35982 .56227 m .35878 .5597 L .36016 .55725 L F
0 0 0 r
.35982 .56227 m .35677 .56316 L .35906 .56262 L F
.35677 .56316 m .35654 .56322 L .35906 .56262 L F
.35982 .56227 m .35906 .56262 L .35878 .5597 L F
.544 .289 .479 r
.35906 .56262 m .36224 .55966 L .35878 .5597 L F
.35906 .56262 m .36203 .56229 L .36224 .55966 L F
.968 .723 .513 r
.35977 .56072 m .36164 .56202 L .35906 .56262 L F
.36164 .56202 m .36203 .56229 L .35906 .56262 L F
.165 0 .291 r
.2874 .6124 m .28981 .60907 L .28802 .60992 L F
.592 .502 .722 r
.33521 .57205 m .33721 .56816 L .33494 .56911 L F
.141 0 .037 r
.36432 .55052 m .36088 .55304 L .36499 .55128 L F
.305 .061 .369 r
.36088 .55304 m .36338 .5535 L .36499 .55128 L F
.437 .247 .523 r
.64095 .43067 m .64331 .42959 L .64327 .42664 L F
.369 .277 .619 r
.64527 .42579 m .64327 .42664 L .64574 .42843 L F
.452 .259 .526 r
.64327 .42664 m .64331 .42959 L .64574 .42843 L F
.822 .445 .342 r
.61213 .43863 m .61546 .43964 L .61604 .44163 L F
.805 .331 0 r
.40154 .55591 m .40307 .55856 L .40433 .55926 L F
.906 .72 .218 r
.4038 .56082 m .40433 .55926 L .40307 .55856 L F
.4038 .56082 m .40428 .56245 L .40433 .55926 L F
.765 .875 .927 r
.73774 .33146 m .73482 .33037 L .73651 .32994 L F
.415 .781 .995 r
.73651 .32994 m .73883 .33035 L .73774 .33146 L F
.15 .097 .538 r
.73883 .33035 m .73827 .33447 L .73774 .33146 L F
.721 .514 .61 r
.70505 .34762 m .70565 .35068 L .70173 .35025 L F
.579 .027 0 r
.70353 .34535 m .70521 .3464 L .70345 .34528 L F
.656 .472 .623 r
.70697 .34752 m .70505 .34762 L .70521 .3464 L F
.70801 .34746 m .70565 .35068 L .70505 .34762 L F
.579 .027 0 r
.70698 .34801 m .70521 .3464 L .70353 .34535 L F
.656 .472 .623 r
.70801 .34746 m .70697 .34752 L .70521 .3464 L F
.522 .326 .556 r
.31028 .63602 m .31277 .63524 L .31307 .63203 L F
.64 .315 .405 r
.31522 .63444 m .31307 .63203 L .31277 .63524 L F
.31522 .63444 m .31562 .63215 L .31307 .63203 L F
.226 .626 .956 r
.3458 .60435 m .34714 .60587 L .34887 .6059 L F
0 0 0 r
.28139 .61628 m .28142 .61646 L .2815 .61633 L F
.28139 .61628 m .28234 .61482 L .28383 .61512 L F
.28139 .61628 m .2815 .61633 L .28234 .61482 L F
.28303 .61596 m .28128 .61622 L .28139 .61628 L F
.28128 .61622 m .27888 .61658 L .28139 .61628 L F
.492 .901 .804 r
.28303 .61596 m .28139 .61628 L .28383 .61512 L F
.834 .925 .893 r
.37262 .62524 m .37438 .62662 L .37145 .6289 L F
.669 .891 .978 r
.37631 .62528 m .37438 .62662 L .37262 .62524 L F
0 0 .374 r
.37367 .54222 m .37461 .54652 L .37347 .54294 L F
0 0 0 r
.27981 .52328 m .27904 .52335 L .2776 .5233 L F
.395 .007 .181 r
.26534 .5529 m .26775 .55259 L .26977 .55051 L F
.349 0 .144 r
.26977 .55051 m .26775 .55259 L .27015 .55205 L F
0 0 .291 r
.5657 .41295 m .56704 .4102 L .56658 .41011 L F
.997 .798 .442 r
.56704 .4102 m .56667 .40736 L .56658 .41011 L F
.085 .091 .567 r
.41652 .54215 m .41486 .54017 L .41634 .53952 L F
.336 .366 .744 r
.28955 .63255 m .29219 .63445 L .29065 .63052 L F
.512 0 0 r
.3587 .55624 m .36016 .55725 L .35954 .5564 L F
.3587 .55624 m .35624 .55715 L .36016 .55725 L F
.791 .718 .783 r
.36541 .57206 m .36284 .5752 L .36131 .57165 L F
.266 .241 .643 r
.3656 .58784 m .36787 .59018 L .36678 .58671 L F
.3656 .58784 m .36641 .58936 L .36787 .59018 L F
.434 .472 .8 r
.36698 .59416 m .36787 .59018 L .36641 .58936 L F
.36698 .59416 m .36923 .59367 L .36787 .59018 L F
.401 .317 .646 r
.36698 .59416 m .36941 .5963 L .36923 .59367 L F
.36923 .59367 m .36941 .5963 L .36698 .59416 L F
.776 .673 .749 r
.36295 .59369 m .36698 .59416 L .36641 .58936 L F
0 0 .208 r
.29564 .64278 m .29495 .64161 L .2968 .64093 L F
.29564 .64278 m .2949 .64426 L .29495 .64161 L F
.977 .737 .32 r
.37061 .52362 m .37209 .52148 L .37352 .52274 L F
.856 .831 .821 r
.3739 .52036 m .37352 .52274 L .37209 .52148 L F
.288 0 0 r
.35581 .53301 m .35836 .53285 L .36015 .53178 L F
.432 .039 .192 r
.35836 .53285 m .36231 .53062 L .36015 .53178 L F
.804 .554 .56 r
.72141 .28763 m .71772 .28941 L .72028 .28618 L F
.72141 .28763 m .72152 .29015 L .71772 .28941 L F
.798 .77 .828 r
.72006 .28819 m .72141 .28763 L .72028 .28618 L F
.72006 .28819 m .72419 .287 L .72141 .28763 L F
.96 .638 .241 r
.40524 .56703 m .4061 .56586 L .40464 .56481 L F
.40524 .56703 m .40645 .56829 L .4061 .56586 L F
.387 .847 .882 r
.25699 .62354 m .25853 .6229 L .25935 .62291 L F
.25853 .6229 m .25929 .62258 L .25935 .62291 L F
.13 .678 .784 r
.26073 .62294 m .25935 .62291 L .26135 .62291 L F
.25706 .62314 m .25935 .62291 L .26073 .62294 L F
.44 0 0 r
.25935 .62291 m .26358 .62225 L .26135 .62291 L F
.933 .766 .651 r
.23458 .54927 m .23536 .55331 L .23372 .55253 L F
.565 .883 .991 r
.63167 .43897 m .62947 .44009 L .63288 .43962 L F
.392 0 .091 r
.62906 .44182 m .63209 .44148 L .63288 .43962 L F
0 0 .426 r
.19604 .58119 m .19739 .5772 L .19516 .57849 L F
.711 .686 .825 r
.35175 .5689 m .34906 .56505 L .35096 .5668 L F
.35175 .5689 m .34676 .56586 L .34906 .56505 L F
.719 .498 .589 r
.35133 .57123 m .34847 .5718 L .35175 .5689 L F
.587 .586 .819 r
.35411 .56782 m .35175 .5689 L .35096 .5668 L F
.694 .588 .732 r
.35411 .56782 m .35133 .57123 L .35175 .5689 L F
.031 .293 .786 r
.24841 .62747 m .24912 .62944 L .24959 .62819 L F
.201 .504 .908 r
.24912 .62944 m .2521 .63075 L .24959 .62819 L F
.703 .305 .29 r
.33425 .50516 m .33297 .50732 L .33177 .50512 L F
.157 0 0 r
.33607 .50562 m .33425 .50516 L .33705 .50494 L F
.33607 .50562 m .33297 .50732 L .33425 .50516 L F
.986 .796 .565 r
.62051 .38753 m .62181 .38925 L .62052 .39009 L F
.67 .832 .961 r
.62328 .38657 m .62181 .38925 L .62051 .38753 L F
.62328 .38657 m .62446 .38819 L .62181 .38925 L F
.639 .158 .094 r
.62181 .38925 m .62425 .39064 L .62052 .39009 L F
.552 .364 .579 r
.62446 .38819 m .62425 .39064 L .62181 .38925 L F
.918 .538 .277 r
.36417 .58192 m .36266 .58309 L .36189 .58067 L F
.722 .343 .331 r
.3672 .58231 m .36266 .58309 L .36417 .58192 L F
.105 0 0 r
.28651 .5359 m .29033 .53317 L .28803 .53383 L F
.475 .267 .517 r
.55972 .3943 m .55719 .39496 L .55827 .39711 L F
.882 .766 .73 r
.55972 .3943 m .55827 .39711 L .55719 .39496 L F
.951 .754 .602 r
.42187 .57822 m .41922 .57986 L .4199 .57716 L F
.42187 .57822 m .42139 .58121 L .41922 .57986 L F
.827 .755 .783 r
.31593 .66136 m .31433 .66371 L .312 .66322 L F
.417 0 0 r
.31433 .66371 m .31452 .6643 L .312 .66322 L F
.31433 .66371 m .31774 .66509 L .31452 .6643 L F
0 0 0 r
.24502 .55027 m .24688 .54952 L .24868 .54982 L F
0 .146 .688 r
.24927 .54853 m .24868 .54982 L .24688 .54952 L F
.24927 .54853 m .25071 .55186 L .24868 .54982 L F
.297 .131 .48 r
.31593 .66136 m .31833 .65726 L .31774 .66087 L F
.585 .608 .841 r
.31834 .66229 m .31593 .66136 L .31774 .66087 L F
0 .08 .639 r
.22595 .61159 m .22631 .61281 L .22639 .61167 L F
.072 .481 .892 r
.22631 .61281 m .22775 .61306 L .22639 .61167 L F
.254 .079 .44 r
.3983 .6191 m .39804 .62166 L .3966 .6216 L F
.665 .474 .617 r
.58379 .43939 m .58362 .442 L .58099 .44186 L F
.562 .386 .601 r
.58379 .43939 m .58628 .44154 L .58362 .442 L F
.699 .339 .361 r
.58379 .43939 m .58622 .43996 L .58628 .44154 L F
.673 .307 .343 r
.28042 .55155 m .27642 .55154 L .27649 .54973 L F
0 0 0 r
.27642 .55154 m .27689 .55054 L .27649 .54973 L F
.45 0 0 r
.27853 .5494 m .27649 .54973 L .27634 .54943 L F
.673 .307 .343 r
.28042 .55155 m .27649 .54973 L .27853 .5494 L F
0 0 0 r
.27689 .55054 m .27809 .54801 L .27649 .54973 L F
.45 0 0 r
.27634 .54943 m .27649 .54973 L .27434 .54945 L F
.705 .2 .032 r
.27998 .55048 m .28042 .55155 L .27853 .5494 L F
0 0 0 r
.6397 .43139 m .64331 .42959 L .64095 .43067 L F
.585 .766 .965 r
.36953 .62732 m .37145 .6289 L .36758 .6282 L F
.744 .624 .726 r
.36758 .6282 m .37145 .6289 L .36861 .631 L F
.834 .925 .893 r
.37262 .62524 m .37145 .6289 L .36953 .62732 L F
.348 .117 .416 r
.29897 .63782 m .29711 .63823 L .29933 .63487 L F
0 0 .5 r
.29936 .63396 m .29933 .63487 L .29862 .63273 L F
.758 .677 .127 r
.29897 .63782 m .29933 .63487 L .29936 .63396 L F
.29897 .63782 m .29936 .63396 L .301 .63648 L F
.787 .287 0 r
.30074 .63627 m .29936 .63396 L .29655 .63289 L F
.301 .63648 m .29936 .63396 L .30074 .63627 L F
0 0 .5 r
.29936 .63396 m .29862 .63273 L .29817 .63136 L F
0 0 0 r
.57605 .42859 m .57778 .42718 L .57965 .42593 L F
.672 .781 .931 r
.36629 .65651 m .36787 .658 L .37031 .65702 L F
.275 .63 .962 r
.22224 .611 m .22492 .60991 L .22016 .60998 L F
.22224 .611 m .22595 .61159 L .22492 .60991 L F
.924 .794 .698 r
.27115 .75624 m .27007 .75362 L .26878 .75732 L F
.58 .454 .673 r
.38722 .59763 m .39001 .5971 L .38968 .59431 L F
.585 .477 .697 r
.38722 .59763 m .38802 .60025 L .39001 .5971 L F
.755 .78 .874 r
.36541 .57206 m .36131 .57165 L .36411 .56741 L F
.232 0 .239 r
.32916 .60265 m .33155 .60018 L .33108 .60259 L F
.14 0 .209 r
.33108 .60259 m .33155 .60018 L .33398 .59927 L F
.875 .655 .602 r
.35239 .52906 m .35603 .53131 L .35571 .52775 L F
.469 .301 .57 r
.35842 .52725 m .35603 .53131 L .35571 .52775 L F
0 0 .127 r
.35571 .52775 m .35592 .52816 L .35842 .52725 L F
.35571 .52775 m .35603 .53131 L .35592 .52816 L F
.897 .86 .797 r
.37802 .65016 m .38194 .64785 L .38076 .64658 L F
.37802 .65016 m .3791 .65164 L .38194 .64785 L F
.497 .432 .714 r
.38427 .64597 m .38486 .64784 L .38194 .64785 L F
.104 .593 .906 r
.38486 .64784 m .38076 .64658 L .38194 .64785 L F
0 0 0 r
.34367 .54472 m .34299 .54637 L .34378 .54386 L F
.474 .792 .999 r
.36364 .71472 m .3641 .71305 L .36173 .71347 L F
.36364 .71472 m .36606 .71426 L .3641 .71305 L F
0 0 0 r
.55973 .42682 m .55753 .42717 L .5546 .42817 L F
.716 .844 .943 r
.40614 .5181 m .40351 .51912 L .40192 .51797 L F
.386 .546 .892 r
.40662 .52079 m .40351 .51912 L .40614 .5181 L F
.48 .267 .513 r
.28613 .55644 m .28816 .5561 L .28872 .553 L F
.113 0 .365 r
.28872 .553 m .29052 .55363 L .29119 .5523 L F
.28872 .553 m .28816 .5561 L .29052 .55363 L F
.035 0 .424 r
.37904 .57242 m .377 .57605 L .37964 .57345 L F
.031 0 .418 r
.37964 .57345 m .377 .57605 L .37804 .57709 L F
0 0 0 r
.22594 .56609 m .22305 .56871 L .22771 .56537 L F
.344 0 .215 r
.37577 .7108 m .37718 .71273 L .37462 .71302 L F
.37577 .7108 m .3781 .7102 L .37718 .71273 L F
.894 .725 .666 r
.39265 .59663 m .39555 .59327 L .39521 .59325 L F
.227 .196 .614 r
.33753 .56205 m .33875 .56297 L .33816 .55778 L F
.161 .631 .93 r
.35687 .71434 m .35743 .71366 L .35576 .71316 L F
.35687 .71434 m .35922 .71466 L .35743 .71366 L F
.567 .223 .345 r
.32552 .60335 m .32839 .60352 L .32776 .6053 L F
.32552 .60335 m .32839 .60352 L .32776 .6053 L F
.69 .749 .248 r
.32798 .60462 m .32839 .60352 L .32776 .6053 L F
.485 .019 .07 r
.32867 .60275 m .32839 .60352 L .32552 .60335 L F
0 .147 .671 r
.32707 .59938 m .32839 .60352 L .32909 .60127 L F
.69 .749 .248 r
.32909 .60127 m .32839 .60352 L .32798 .60462 L F
.485 .019 .07 r
.32916 .60265 m .32839 .60352 L .32867 .60275 L F
.232 0 .239 r
.32916 .60265 m .33108 .60259 L .32839 .60352 L F
.975 .785 .586 r
.36759 .61546 m .36919 .6169 L .36743 .61826 L F
.303 .235 .612 r
.37096 .61853 m .36919 .6169 L .37021 .61585 L F
.671 .832 .961 r
.37021 .61585 m .36919 .6169 L .36759 .61546 L F
.37021 .61585 m .36919 .6169 L .36759 .61546 L F
0 0 .296 r
.40173 .55217 m .40209 .55451 L .40154 .55591 L F
.71 .266 0 r
.40199 .55731 m .40307 .55856 L .40171 .5562 L F
.40199 .55731 m .40171 .5562 L .40154 .55591 L F
.876 .503 .022 r
.40199 .55731 m .4038 .56082 L .40307 .55856 L F
0 .209 .732 r
.40345 .55876 m .4038 .56082 L .40199 .55731 L F
.4039 .55921 m .40388 .55962 L .40345 .55876 L F
.40388 .55962 m .4038 .56082 L .40345 .55876 L F
.657 .114 0 r
.40225 .55834 m .4039 .55921 L .40199 .55731 L F
.40225 .5583 m .40199 .55731 L .40216 .55522 L F
.40225 .55834 m .40199 .55731 L .40225 .5583 L F
.967 .648 .275 r
.40087 .55717 m .40225 .55834 L .40219 .55619 L F
0 0 .022 r
.40216 .55522 m .40199 .55731 L .40209 .55451 L F
.967 .648 .275 r
.4019 .55561 m .40219 .55619 L .40216 .55522 L F
.71 .266 0 r
.40199 .55731 m .40154 .55591 L .40209 .55451 L F
.967 .648 .275 r
.40087 .55717 m .40219 .55619 L .4019 .55561 L F
.472 .23 .466 r
.36499 .55128 m .36592 .54874 L .36432 .55052 L F
.28 .526 .909 r
.24347 .61296 m .24246 .61424 L .2408 .61319 L F
.24347 .61296 m .2455 .61531 L .24246 .61424 L F
.478 .47 .77 r
.32111 .52759 m .32112 .52797 L .31918 .52903 L F
.371 .248 .58 r
.32112 .52797 m .31947 .53091 L .31918 .52903 L F
.718 .672 .804 r
.32112 .52797 m .31947 .53091 L .31897 .52997 L F
.033 0 .133 r
.32113 .52758 m .3208 .52782 L .32105 .52767 L F
.3208 .52782 m .31918 .52903 L .32081 .52784 L F
.3208 .52782 m .32081 .52784 L .32105 .52767 L F
.32223 .52472 m .31918 .52903 L .32111 .52759 L F
.18 0 .237 r
.32112 .52797 m .32156 .52746 L .32111 .52759 L F
.414 .095 .313 r
.32208 .52736 m .3212 .52752 L .32223 .52472 L F
.18 0 .237 r
.32156 .52746 m .32226 .52662 L .3212 .52752 L F
.32156 .52746 m .3212 .52752 L .32111 .52759 L F
.414 .095 .313 r
.32414 .52688 m .32208 .52736 L .32209 .5272 L F
.32414 .52688 m .32209 .5272 L .32253 .52506 L F
.18 0 .237 r
.32112 .52797 m .32368 .52631 L .32226 .52662 L F
.305 0 .219 r
.32205 .52737 m .32112 .52797 L .32118 .52757 L F
.32414 .52688 m .32112 .52797 L .32205 .52737 L F
.18 0 .237 r
.32205 .52737 m .32205 .52737 L .32368 .52631 L F
.305 0 .219 r
.32414 .52688 m .32191 .52988 L .32112 .52797 L F
.32191 .52988 m .3217 .53017 L .32165 .53 L F
.32191 .52988 m .32165 .53 L .32112 .52797 L F
.18 0 .237 r
.32205 .52737 m .3217 .53017 L .32368 .52632 L F
.414 .095 .313 r
.32414 .52688 m .32223 .52472 L .32392 .52357 L F
.648 .393 .52 r
.32392 .52357 m .32414 .52688 L .32661 .52507 L F
.539 .23 .391 r
.32661 .52507 m .3217 .53017 L .32414 .52688 L F
.721 .477 .557 r
.32368 .52631 m .3217 .53017 L .32661 .52507 L F
.696 .639 .788 r
.32516 .52838 m .3233 .52834 L .32472 .52745 L F
.32351 .52914 m .32222 .52832 L .32516 .52838 L F
.32637 .53098 m .32382 .53178 L .32222 .52832 L F
.805 .722 .774 r
.32849 .52783 m .32637 .53098 L .32472 .52745 L F
.742 .811 .907 r
.32849 .52783 m .32472 .52745 L .32719 .52584 L F
.44 .047 .196 r
.32299 .52895 m .32668 .52622 L .32472 .52745 L F
.32668 .52622 m .32719 .52584 L .32472 .52745 L F
.696 .639 .788 r
.3233 .52834 m .32222 .52832 L .32472 .52745 L F
.32637 .53098 m .32351 .52914 L .32516 .52838 L F
.18 0 .237 r
.32205 .52737 m .32368 .52632 L .32368 .52631 L F
.32112 .52797 m .32157 .5297 L .32205 .52737 L F
.32157 .5297 m .3217 .53017 L .32205 .52737 L F
.414 .095 .313 r
.32253 .52506 m .32209 .5272 L .32223 .52472 L F
.32208 .52736 m .32118 .52757 L .3212 .52752 L F
.033 0 .133 r
.3212 .52752 m .32111 .52759 L .32119 .52753 L F
.32223 .52472 m .32111 .52759 L .3212 .52752 L F
.18 0 .237 r
.32111 .52759 m .32226 .52662 L .3211 .52688 L F
.478 .47 .77 r
.3211 .52688 m .32111 .52759 L .31918 .52903 L F
0 0 0 r
.32223 .52472 m .32067 .52692 L .3211 .52688 L F
.32067 .52692 m .31918 .52903 L .32042 .52764 L F
.32067 .52692 m .32042 .52764 L .3211 .52688 L F
.502 .527 .815 r
.31918 .52903 m .32112 .52797 L .32118 .52757 L F
.718 .672 .804 r
.32082 .52792 m .31897 .52997 L .31759 .52739 L F
.32082 .52792 m .32035 .52784 L .32085 .52811 L F
.32035 .52784 m .31759 .52739 L .3203 .52799 L F
.32035 .52784 m .3203 .52799 L .32085 .52811 L F
.32112 .52797 m .31897 .52997 L .32082 .52792 L F
.32085 .52811 m .31759 .52739 L .31947 .52879 L F
.32112 .52797 m .32082 .52792 L .32085 .52811 L F
.033 0 .133 r
.32119 .52753 m .32113 .52758 L .32118 .52757 L F
.32113 .52758 m .32105 .52767 L .32118 .52757 L F
.438 .177 .419 r
.3211 .52688 m .32392 .52357 L .32223 .52472 L F
.447 .573 .888 r
.36603 .62475 m .36391 .62502 L .36199 .62183 L F
.406 .513 .854 r
.36758 .6282 m .36391 .62502 L .36603 .62475 L F
.956 .706 .519 r
.2161 .59021 m .21789 .59393 L .21803 .59094 L F
.463 .274 .539 r
.21803 .59094 m .21795 .59263 L .21802 .59259 L F
.319 .26 .633 r
.21803 .59094 m .21839 .59305 L .21802 .59259 L F
.668 .708 .878 r
.21802 .59259 m .21839 .59305 L .21837 .59238 L F
.319 .26 .633 r
.21803 .59094 m .22014 .59307 L .21839 .59305 L F
.316 .32 .705 r
.2191 .59212 m .22119 .59174 L .2215 .58897 L F
.21839 .59305 m .21937 .59259 L .2191 .59212 L F
.463 .274 .539 r
.21917 .59209 m .21913 .59216 L .22014 .59307 L F
.316 .32 .705 r
.21937 .59259 m .22119 .59174 L .2191 .59212 L F
.21937 .59259 m .22014 .59307 L .22119 .59174 L F
.21839 .59305 m .22014 .59307 L .21937 .59259 L F
.463 .274 .539 r
.21937 .59259 m .21801 .59388 L .21972 .59323 L F
.21913 .59216 m .219 .59236 L .21937 .59259 L F
.219 .59236 m .21801 .59388 L .21937 .59259 L F
.21913 .59216 m .21972 .59323 L .22014 .59307 L F
.21803 .59094 m .21802 .59251 L .21917 .59209 L F
.586 .642 .873 r
.21837 .59238 m .21839 .59305 L .2191 .59212 L F
.463 .274 .539 r
.21802 .59251 m .21801 .59388 L .21917 .59209 L F
.667 .706 .877 r
.21819 .58746 m .21987 .59015 L .21834 .59017 L F
.586 .642 .873 r
.21834 .59017 m .21837 .59238 L .21845 .59229 L F
.21819 .58746 m .21829 .59017 L .21834 .59017 L F
.21829 .59017 m .21837 .59238 L .21834 .59017 L F
.319 .26 .633 r
.21803 .59094 m .21802 .59259 L .2161 .59021 L F
.668 .708 .878 r
.2161 .59021 m .21802 .59259 L .21819 .58746 L F
.21802 .59259 m .21837 .59238 L .21819 .58746 L F
.626 .276 .356 r
.21834 .59017 m .2183 .59258 L .2161 .59021 L F
.21987 .59015 m .21973 .59036 L .21834 .59017 L F
0 .035 .594 r
.21974 .58985 m .21987 .59015 L .21819 .58746 L F
.586 .642 .873 r
.21819 .58746 m .21845 .59229 L .21951 .59114 L F
.2197 .59046 m .21951 .59114 L .21986 .59076 L F
.21819 .58746 m .21951 .59114 L .2197 .59046 L F
.21819 .58746 m .21986 .59076 L .21974 .58985 L F
.626 .276 .356 r
.21973 .59036 m .2183 .59258 L .21834 .59017 L F
.869 .927 .541 r
.21834 .59092 m .2183 .59258 L .21973 .59036 L F
.21978 .59019 m .21973 .59036 L .21987 .59015 L F
.21834 .59092 m .21973 .59036 L .21978 .59019 L F
.586 .642 .873 r
.21819 .58746 m .22013 .59046 L .2215 .58897 L F
0 .035 .594 r
.21878 .58766 m .21974 .58985 L .21819 .58746 L F
.586 .642 .873 r
.21952 .58668 m .2215 .58897 L .22065 .58602 L F
.21819 .58746 m .21951 .58806 L .21952 .58668 L F
.21951 .58806 m .2215 .58897 L .21952 .58668 L F
.869 .927 .541 r
.21834 .59092 m .2195 .59034 L .21878 .58766 L F
.2195 .59034 m .21978 .59019 L .2195 .58948 L F
.2195 .59034 m .2195 .58948 L .21878 .58766 L F
.21978 .59019 m .21987 .59015 L .21974 .58985 L F
.21978 .59019 m .21974 .58985 L .21878 .58766 L F
.586 .642 .873 r
.21974 .58985 m .21986 .59076 L .22013 .59046 L F
.667 .706 .877 r
.21819 .58746 m .21834 .59017 L .2161 .59021 L F
.586 .642 .873 r
.21837 .59238 m .2191 .59212 L .2215 .58897 L F
.463 .274 .539 r
.21802 .59259 m .21789 .59393 L .21801 .59388 L F
.21795 .59263 m .21789 .59393 L .21802 .59259 L F
.865 .884 .848 r
.60542 .42527 m .60424 .42975 L .60281 .42609 L F
.60542 .42527 m .60693 .42662 L .60424 .42975 L F
.56 .298 .475 r
.35109 .53736 m .35072 .53973 L .34804 .53996 L F
.35109 .53736 m .35072 .53973 L .34804 .53996 L F
.569 .58 .825 r
.3534 .53667 m .35109 .53736 L .35048 .53546 L F
.3534 .53667 m .35152 .53589 L .35324 .53428 L F
.3534 .53667 m .35324 .53428 L .35344 .53422 L F
.499 .311 .557 r
.3534 .53667 m .35581 .53301 L .35344 .53409 L F
.3534 .53667 m .35513 .53719 L .35581 .53301 L F
.262 0 0 r
.35448 .5339 m .35457 .53512 L .35186 .53563 L F
.35581 .53301 m .35547 .53359 L .35448 .5339 L F
.35547 .53359 m .35457 .53512 L .35448 .5339 L F
.569 .58 .825 r
.35344 .53422 m .35324 .53428 L .35344 .53409 L F
.35152 .53589 m .35048 .53546 L .35178 .53486 L F
.35152 .53589 m .35178 .53486 L .35344 .53409 L F
.453 .212 .457 r
.35072 .53973 m .3534 .53667 L .35109 .53736 L F
0 0 .254 r
.35186 .53563 m .35072 .53973 L .35098 .53803 L F
.35123 .53704 m .35098 .53803 L .35109 .53736 L F
.35186 .53563 m .35098 .53803 L .35123 .53704 L F
.06 .228 .723 r
.35186 .53563 m .35109 .53736 L .35048 .53546 L F
.061 0 .311 r
.35492 .60043 m .35434 .60267 L .35264 .60436 L F
.732 .661 .108 r
.35434 .60267 m .35406 .60517 L .35264 .60436 L F
.188 .186 .624 r
.35406 .60517 m .35317 .60694 L .35264 .60436 L F
.678 .977 .88 r
.24447 .53103 m .24501 .52958 L .24652 .52986 L F
.24447 .53103 m .24167 .5317 L .24501 .52958 L F
.682 .615 .774 r
.37629 .62001 m .37879 .61958 L .37776 .61569 L F
.827 .704 .729 r
.39985 .60699 m .39939 .60927 L .39544 .60912 L F
.828 .704 .728 r
.39939 .60927 m .39695 .61281 L .39544 .60912 L F
.217 0 0 r
.27269 .53959 m .27038 .54075 L .26843 .54052 L F
.23 .738 .688 r
.27528 .53921 m .27038 .54075 L .27269 .53959 L F
.426 .747 .994 r
.32271 .50676 m .32209 .50828 L .32017 .50695 L F
.957 .802 .647 r
.31988 .50904 m .32209 .50828 L .32271 .50676 L F
.31988 .50904 m .32015 .51018 L .32209 .50828 L F
.559 .232 .37 r
.58622 .43996 m .58844 .44138 L .58628 .44154 L F
.58622 .43996 m .58992 .43882 L .58844 .44138 L F
.071 .634 .737 r
.2703 .6381 m .27469 .63788 L .27263 .63795 L F
.543 0 0 r
.27469 .63788 m .2748 .63867 L .27263 .63795 L F
0 .069 .581 r
.27469 .63788 m .27821 .64136 L .27802 .64019 L F
.543 0 0 r
.27469 .63788 m .27802 .64019 L .2748 .63867 L F
0 0 0 r
.38995 .70111 m .38861 .70317 L .38678 .70419 L F
.183 0 .286 r
.39249 .69806 m .39196 .70107 L .38995 .70111 L F
.13 0 0 r
.39105 .70222 m .38995 .70111 L .39196 .70107 L F
.39105 .70222 m .38861 .70317 L .38995 .70111 L F
.262 0 .079 r
.33857 .52713 m .34137 .52646 L .34172 .52496 L F
.775 .537 .574 r
.34137 .52646 m .34429 .52421 L .34172 .52496 L F
.815 .406 0 r
.39909 .54581 m .39999 .54816 L .40102 .54906 L F
.98 .69 .38 r
.39999 .54816 m .40173 .55217 L .40102 .54906 L F
0 0 0 r
.28816 .63766 m .28427 .64271 L .28751 .64172 L F
.256 .044 .387 r
.28959 .63761 m .28816 .63766 L .28751 .64172 L F
.841 .411 .211 r
.35954 .61175 m .36063 .61028 L .35983 .61037 L F
0 .015 .578 r
.36184 .61246 m .36178 .61333 L .36063 .61028 L F
.841 .411 .211 r
.35954 .61175 m .36184 .61246 L .36063 .61028 L F
.6 .35 .511 r
.36063 .61028 m .36329 .60994 L .36184 .61246 L F
0 0 .105 r
.33379 .54959 m .33469 .54523 L .33625 .5459 L F
.609 .367 .524 r
.33469 .54523 m .33794 .54803 L .33455 .54769 L F
.33469 .54523 m .33794 .54803 L .33455 .54769 L F
.799 .663 .713 r
.33794 .54803 m .33718 .54781 L .33762 .54668 L F
.33794 .54803 m .33865 .54403 L .33721 .54481 L F
.33794 .54803 m .33762 .54668 L .33865 .54403 L F
.699 .547 .678 r
.33865 .54403 m .33762 .54668 L .34333 .54712 L F
.33762 .54668 m .33713 .54793 L .33778 .54784 L F
.893 .88 .814 r
.33787 .54774 m .33778 .54784 L .33794 .54803 L F
.721 .455 0 r
.3372 .54492 m .33794 .54803 L .33721 .54481 L F
.33762 .54668 m .33794 .54803 L .3372 .54492 L F
.33719 .54511 m .33787 .54774 L .3372 .54495 L F
.33787 .54774 m .33794 .54803 L .33761 .54667 L F
.33787 .54774 m .33761 .54667 L .3372 .54495 L F
0 0 .03 r
.34045 .5505 m .34333 .54712 L .33789 .54783 L F
.33792 .54799 m .33789 .54783 L .33778 .54784 L F
.34045 .5505 m .33789 .54783 L .33792 .54799 L F
0 0 0 r
.33541 .54731 m .33455 .54769 L .33794 .54803 L F
.799 .663 .713 r
.33794 .54803 m .33713 .54793 L .33718 .54781 L F
.502 .492 .778 r
.33455 .54769 m .33764 .55052 L .33794 .54803 L F
.619 .559 .765 r
.33764 .55052 m .33713 .54793 L .33794 .54803 L F
0 0 .03 r
.3375 .54821 m .33778 .54784 L .33713 .54793 L F
.893 .88 .814 r
.33778 .54784 m .33773 .54791 L .33794 .54803 L F
0 0 .03 r
.34045 .5505 m .33778 .54784 L .3375 .54821 L F
.893 .88 .814 r
.33778 .54784 m .33773 .54791 L .33773 .54791 L F
.33719 .54511 m .33613 .54699 L .33773 .54791 L F
.699 .547 .678 r
.33762 .54668 m .33778 .54784 L .33787 .54774 L F
.893 .88 .814 r
.33719 .54511 m .33773 .54791 L .33787 .54774 L F
.699 .547 .678 r
.33787 .54774 m .33778 .54784 L .33789 .54783 L F
.33762 .54668 m .33789 .54783 L .34333 .54712 L F
.721 .455 0 r
.3372 .54495 m .33762 .54668 L .3372 .54492 L F
0 0 0 r
.33613 .54699 m .33541 .54731 L .33794 .54803 L F
.33613 .54699 m .33494 .54764 L .33455 .54769 L F
0 0 .105 r
.33379 .54959 m .33455 .54769 L .33418 .54774 L F
.294 .337 .737 r
.3338 .55233 m .33455 .54769 L .33379 .54959 L F
.3338 .55233 m .33529 .552 L .33455 .54769 L F
.502 .492 .778 r
.33455 .54769 m .33529 .552 L .33764 .55052 L F
0 0 0 r
.33488 .54764 m .33209 .54918 L .33455 .54769 L F
.33417 .54805 m .33209 .54918 L .33488 .54764 L F
.745 .702 .163 r
.3288 .5455 m .32831 .5481 L .32852 .5463 L F
.703 .396 .455 r
.33179 .54815 m .32831 .5481 L .3288 .5455 L F
.075 .288 .774 r
.33067 .55024 m .32999 .55191 L .32831 .5481 L F
.33067 .55024 m .32831 .5481 L .33179 .54815 L F
.009 0 .012 r
.33209 .54918 m .33179 .54815 L .33455 .54769 L F
.33209 .54918 m .33067 .55024 L .33179 .54815 L F
.565 .605 .851 r
.32831 .5481 m .32735 .55242 L .32583 .54871 L F
.32831 .5481 m .32999 .55191 L .32735 .55242 L F
.716 .303 .265 r
.32831 .5481 m .32641 .54979 L .33067 .55024 L F
.32831 .5481 m .33067 .55024 L .32889 .54914 L F
0 0 0 r
.33613 .54699 m .33485 .54801 L .33209 .54918 L F
.722 .467 .54 r
.32852 .5463 m .32889 .54914 L .33245 .54904 L F
.739 .5 .567 r
.33336 .55414 m .33209 .54918 L .33485 .54801 L F
.722 .467 .54 r
.33248 .54903 m .33245 .54904 L .3325 .54904 L F
.32852 .5463 m .33245 .54904 L .33248 .54903 L F
0 0 0 r
.33494 .54764 m .33417 .54805 L .33488 .54764 L F
0 0 .105 r
.33418 .54774 m .33455 .54769 L .33469 .54523 L F
.557 .324 .518 r
.58992 .43882 m .59276 .44101 L .58844 .44138 L F
.58992 .43882 m .59274 .43858 L .59276 .44101 L F
.882 .615 .095 r
.40685 .57076 m .40778 .57465 L .40745 .57203 L F
.678 .299 0 r
.40876 .57668 m .40957 .5782 L .40778 .57465 L F
.758 .752 .238 r
.40911 .57933 m .40957 .5782 L .40876 .57668 L F
.40911 .57933 m .40887 .58086 L .40957 .5782 L F
.211 0 .151 r
.38542 .6039 m .38257 .60657 L .3856 .60632 L F
.616 .466 .656 r
.38542 .6039 m .38811 .60289 L .38802 .60025 L F
.64 .4 .539 r
.3856 .60632 m .38811 .60289 L .38542 .6039 L F
.287 0 .095 r
.30113 .60987 m .29948 .61232 L .29752 .61264 L F
.574 .187 .27 r
.30315 .61169 m .29948 .61232 L .30113 .60987 L F
.542 .196 .331 r
.30393 .60979 m .30315 .61169 L .30113 .60987 L F
.822 .721 .753 r
.55528 .43264 m .55652 .43548 L .55342 .43532 L F
.758 .369 .316 r
.55342 .43532 m .55652 .43548 L .55508 .43755 L F
.714 .313 .287 r
.55652 .43548 m .55904 .43799 L .55508 .43755 L F
.718 .311 .275 r
.55652 .43548 m .55942 .43653 L .55904 .43799 L F
.596 .084 0 r
.40203 .5264 m .39917 .52361 L .40071 .52518 L F
.042 0 0 r
.36245 .54381 m .36063 .54503 L .35822 .54562 L F
.441 0 0 r
.36418 .54485 m .36245 .54381 L .36487 .54298 L F
.36418 .54485 m .36063 .54503 L .36245 .54381 L F
.631 .93 .676 r
.63447 .40599 m .63263 .40807 L .63445 .40628 L F
.698 .956 .95 r
.63154 .40749 m .63263 .40807 L .63447 .40599 L F
.576 .311 .479 r
.3674 .53712 m .36487 .54022 L .36341 .53659 L F
.3674 .53712 m .36654 .54042 L .36487 .54022 L F
0 0 .517 r
.60081 .39923 m .60177 .40065 L .60384 .40309 L F
.732 .661 .78 r
.31509 .51136 m .31672 .51513 L .31949 .51261 L F
.827 .704 .729 r
.39985 .60699 m .39598 .60657 L .39807 .606 L F
.39985 .60699 m .39544 .60912 L .39598 .60657 L F
0 .071 .623 r
.32325 .51106 m .32536 .51461 L .32196 .51303 L F
0 .289 .661 r
.32593 .51495 m .32196 .51303 L .32536 .51461 L F
.49 .373 .647 r
.34496 .63478 m .34513 .63788 L .34292 .63525 L F
.088 .589 .895 r
.30111 .65532 m .3016 .65643 L .30041 .65367 L F
.30111 .65532 m .30421 .65699 L .3016 .65643 L F
.509 0 0 r
.3016 .65643 m .30183 .65939 L .30001 .65774 L F
.3016 .65643 m .30399 .65795 L .30183 .65939 L F
.3016 .65643 m .30421 .65699 L .30399 .65795 L F
.26 .009 .33 r
.33615 .59621 m .33437 .59691 L .33705 .59371 L F
.207 0 .219 r
.33398 .59927 m .33437 .59691 L .33615 .59621 L F
.35 .475 .845 r
.19823 .59073 m .19989 .58978 L .19664 .5878 L F
.452 .172 .397 r
.19823 .59073 m .199 .59309 L .19989 .58978 L F
.19823 .59073 m .19834 .59345 L .199 .59309 L F
.724 .263 .156 r
.38596 .54837 m .38564 .54852 L .38544 .54752 L F
.813 .485 .433 r
.31522 .63444 m .31796 .63601 L .31562 .63215 L F
.779 .559 .6 r
.31827 .63514 m .31562 .63215 L .31796 .63601 L F
.188 0 .047 r
.30818 .52151 m .30686 .52333 L .30511 .52324 L F
.478 .239 .474 r
.30686 .52333 m .30386 .52615 L .30511 .52324 L F
.881 .922 .847 r
.33946 .57501 m .34222 .57215 L .33968 .57182 L F
0 .215 .639 r
.34222 .57215 m .34213 .57194 L .33968 .57182 L F
.588 .165 .205 r
.34222 .57215 m .34563 .57262 L .3444 .57347 L F
0 .215 .639 r
.34222 .57215 m .3444 .57347 L .34213 .57194 L F
.452 .311 .598 r
.32413 .52119 m .32624 .5178 L .32368 .51852 L F
.588 .503 .726 r
.35534 .61647 m .35552 .61906 L .3579 .6161 L F
.476 .599 .896 r
.59296 .41112 m .5893 .40827 L .59326 .40944 L F
.833 .583 .562 r
.59296 .41112 m .5936 .41381 L .59001 .41187 L F
.411 .32 .642 r
.5957 .41281 m .59296 .41112 L .59326 .40944 L F
.5957 .41281 m .5936 .41381 L .59296 .41112 L F
.868 .641 .593 r
.707 .32482 m .71004 .32783 L .70906 .3251 L F
.707 .32482 m .70695 .32748 L .71004 .32783 L F
.897 .737 .674 r
.70668 .3301 m .71004 .32783 L .70695 .32748 L F
.70668 .3301 m .70891 .33168 L .71004 .32783 L F
.401 .172 .448 r
.36427 .59998 m .36686 .59681 L .36437 .59725 L F
.36427 .59998 m .36686 .59681 L .36437 .59725 L F
.959 .713 .521 r
.70534 .35327 m .70684 .357 L .7052 .35638 L F
.729 .2 0 r
.7052 .35638 m .70684 .357 L .70615 .35764 L F
.663 .109 0 r
.70684 .357 m .70933 .35918 L .70615 .35764 L F
.498 .241 .455 r
.38516 .55786 m .38427 .56112 L .38192 .55899 L F
.357 .228 .565 r
.24918 .55536 m .24887 .55816 L .24707 .55889 L F
.461 .173 .389 r
.24887 .55816 m .24597 .56125 L .24707 .55889 L F
.984 .725 .455 r
.40571 .5233 m .40734 .52727 L .40761 .52451 L F
.585 .545 .776 r
.40761 .52451 m .40969 .52573 L .40985 .52377 L F
.40761 .52451 m .41131 .52761 L .40969 .52573 L F
.617 .713 .914 r
.65848 .40687 m .65464 .40504 L .65675 .40383 L F
.515 .753 .982 r
.66049 .40466 m .65848 .40687 L .65675 .40383 L F
.66049 .40466 m .66127 .40623 L .65848 .40687 L F
.465 .242 .49 r
.29305 .60338 m .29524 .60274 L .29561 .60031 L F
.199 0 .34 r
.29524 .60274 m .29753 .59937 L .29561 .60031 L F
.431 .285 .581 r
.41633 .52353 m .41401 .52679 L .41459 .52463 L F
.241 0 .183 r
.34192 .54063 m .34096 .54236 L .3445 .53975 L F
.586 .384 .575 r
.38173 .58731 m .38164 .59061 L .37872 .59119 L F
.021 0 .41 r
.38355 .58836 m .38173 .58731 L .38465 .58672 L F
.38355 .58836 m .38164 .59061 L .38173 .58731 L F
.926 .938 .583 r
.34556 .51223 m .34371 .51356 L .34529 .50973 L F
.34556 .51223 m .34371 .51356 L .34529 .50973 L F
0 .507 .817 r
.34678 .66309 m .34885 .66403 L .35126 .66455 L F
.722 .297 .237 r
.36518 .56411 m .36854 .565 L .3663 .5628 L F
.99 .761 .494 r
.3649 .5614 m .36518 .56411 L .3663 .5628 L F
.808 .883 .9 r
.31156 .64802 m .31552 .64754 L .31419 .64837 L F
0 0 0 r
.31146 .56618 m .30991 .56754 L .313 .56499 L F
.31146 .56618 m .30991 .56754 L .313 .56499 L F
0 .178 .701 r
.22796 .59183 m .22575 .59086 L .22869 .59061 L F
.519 .447 .714 r
.22796 .59183 m .2297 .58811 L .22782 .59207 L F
0 .178 .701 r
.22796 .59183 m .22795 .59444 L .22575 .59086 L F
.706 .447 .53 r
.22796 .59183 m .2274 .59295 L .22466 .59212 L F
.595 .632 .858 r
.22466 .59212 m .2274 .59295 L .22726 .59256 L F
.637 .267 .326 r
.22466 .59212 m .22726 .59256 L .22796 .59183 L F
.815 .75 .791 r
.22726 .59256 m .2274 .59295 L .22764 .59245 L F
.637 .267 .326 r
.22726 .59256 m .22756 .59261 L .22764 .59245 L F
.22726 .59256 m .22764 .59245 L .22796 .59183 L F
.815 .75 .791 r
.2255 .58778 m .22726 .59256 L .2297 .58811 L F
.22726 .59256 m .22764 .59245 L .2297 .58811 L F
.595 .632 .858 r
.22466 .59212 m .22726 .59256 L .2255 .58778 L F
.637 .267 .326 r
.22466 .59212 m .2267 .59425 L .22756 .59261 L F
.519 .447 .714 r
.22796 .59183 m .22764 .59245 L .2274 .59295 L F
.637 .267 .326 r
.2267 .59425 m .22681 .59436 L .22796 .59183 L F
.519 .447 .714 r
.22796 .59183 m .22782 .59207 L .22764 .59245 L F
0 .178 .701 r
.22796 .59183 m .22869 .59061 L .2305 .59045 L F
0 0 .512 r
.34151 .64583 m .34082 .64826 L .34021 .6437 L F
0 0 .465 r
.34165 .65011 m .34082 .64826 L .34151 .64583 L F
.366 0 .186 r
.26958 .55636 m .26874 .55806 L .2664 .55845 L F
.163 0 .085 r
.27175 .55544 m .26874 .55806 L .26958 .55636 L F
.41 .103 .33 r
.38477 .70513 m .38391 .70732 L .38151 .70783 L F
.367 .107 .381 r
.38678 .70419 m .38391 .70732 L .38477 .70513 L F
.872 .899 .481 r
.29458 .55811 m .29346 .56067 L .2936 .5619 L F
.873 .905 .493 r
.29346 .56067 m .29217 .56401 L .2936 .5619 L F
0 0 .527 r
.39731 .54223 m .39909 .54581 L .39801 .54407 L F
.683 .979 .842 r
.62643 .44208 m .62947 .44009 L .62778 .44017 L F
.487 .169 .353 r
.62906 .44182 m .62947 .44009 L .62643 .44208 L F
.55 .827 .478 r
.62624 .43438 m .62394 .43701 L .62788 .44021 L F
.559 .474 .715 r
.62624 .43438 m .62788 .44021 L .63101 .43769 L F
.504 0 0 r
.62778 .44017 m .62788 .44021 L .62394 .43701 L F
.453 .884 .839 r
.62778 .44017 m .62947 .44009 L .63167 .43897 L F
.632 .592 .791 r
.38564 .54852 m .38364 .55188 L .38363 .54964 L F
.888 .719 .667 r
.5598 .40509 m .55994 .4076 L .55856 .40385 L F
.692 .79 .925 r
.5598 .40509 m .56251 .40445 L .55994 .4076 L F
.701 .727 .87 r
.55856 .40385 m .56251 .40445 L .5598 .40509 L F
.745 .657 .764 r
.55856 .40385 m .55994 .4076 L .56251 .40445 L F
.635 .479 .654 r
.55994 .4076 m .56101 .41117 L .56304 .40815 L F
.58 .472 .696 r
.33996 .57753 m .3409 .58137 L .34352 .57992 L F
.771 .855 .913 r
.6051 .39321 m .60543 .3953 L .60257 .39428 L F
.6051 .39321 m .60636 .39476 L .60543 .3953 L F
.058 0 .25 r
.31774 .66509 m .31834 .66229 L .31904 .66614 L F
.19 .365 .808 r
.32044 .66296 m .31834 .66229 L .31774 .66087 L F
.359 .177 .493 r
.31904 .66614 m .31834 .66229 L .32044 .66296 L F
0 0 .028 r
.60833 .42328 m .60693 .42662 L .60846 .42456 L F
.592 .821 .987 r
.60846 .42456 m .60693 .42662 L .60542 .42527 L F
.16 0 .169 r
.29265 .6056 m .29524 .60274 L .29305 .60338 L F
0 .327 .787 r
.36481 .50717 m .3648 .50791 L .36345 .5064 L F
.36481 .50717 m .36627 .50869 L .3648 .50791 L F
.125 .248 .721 r
.399 .6589 m .39783 .66031 L .39677 .65692 L F
.06 .149 .643 r
.39972 .66258 m .39783 .66031 L .399 .6589 L F
0 0 .105 r
.34518 .60049 m .34354 .60345 L .34434 .60324 L F
.194 0 .241 r
.347 .59957 m .34518 .60049 L .34434 .60324 L F
.656 .472 .623 r
.70801 .34746 m .70521 .3464 L .70698 .34801 L F
.713 .548 .665 r
.70809 .34934 m .70565 .35068 L .70801 .34746 L F
.745 .69 .799 r
.7107 .34659 m .70809 .34934 L .70801 .34746 L F
.449 0 0 r
.70698 .34801 m .7107 .34659 L .70801 .34746 L F
.72 .388 .416 r
.33539 .54042 m .331 .54228 L .33102 .54299 L F
.63 .421 .58 r
.33482 .54255 m .33153 .5454 L .331 .54228 L F
.663 .47 .613 r
.33085 .54402 m .33153 .5454 L .3288 .5455 L F
.672 .568 .729 r
.331 .54228 m .33153 .5454 L .3288 .5455 L F
.72 .388 .416 r
.33199 .54186 m .33164 .54233 L .331 .54228 L F
.769 .916 .538 r
.32999 .54507 m .33208 .54082 L .331 .54228 L F
.33075 .54354 m .33062 .54294 L .33208 .54082 L F
.32999 .54507 m .33024 .54422 L .33075 .54354 L F
.33024 .54422 m .33062 .54294 L .33075 .54354 L F
.72 .388 .416 r
.33539 .54042 m .33482 .54255 L .33164 .54233 L F
.33539 .54042 m .33164 .54233 L .33199 .54186 L F
.643 .311 .394 r
.33829 .54245 m .33482 .54255 L .33539 .54042 L F
.428 .393 .717 r
.33729 .53954 m .33829 .54245 L .33539 .54042 L F
.33729 .53954 m .33829 .54245 L .33539 .54042 L F
.114 .163 .635 r
.60821 .41949 m .60833 .42328 L .61003 .4211 L F
0 0 .028 r
.61003 .4211 m .60833 .42328 L .60846 .42456 L F
.637 .441 .6 r
.42691 .58114 m .4269 .58417 L .42373 .5843 L F
0 .075 .627 r
.42733 .57908 m .42869 .58327 L .42691 .58114 L F
.317 .186 .539 r
.42869 .58327 m .4269 .58417 L .42691 .58114 L F
.015 0 .14 r
.27301 .55298 m .27219 .55484 L .27263 .55325 L F
.27417 .55215 m .27297 .55378 L .27301 .55298 L F
.27297 .55378 m .27219 .55484 L .27301 .55298 L F
.27219 .55484 m .27188 .55511 L .27263 .55325 L F
.673 .243 .217 r
.27295 .55418 m .27295 .5542 L .27303 .5542 L F
0 0 0 r
.27269 .55451 m .27175 .55544 L .27219 .55484 L F
.27283 .55414 m .27219 .55484 L .27297 .55378 L F
.27269 .55451 m .27219 .55484 L .27283 .55414 L F
.673 .243 .217 r
.26775 .55259 m .27283 .55414 L .27015 .55205 L F
.27283 .55414 m .27295 .55418 L .27286 .55411 L F
.27283 .55414 m .27286 .55411 L .27015 .55205 L F
.26775 .55259 m .27295 .5542 L .27295 .55418 L F
.27295 .55418 m .27303 .5542 L .27297 .55416 L F
.393 0 0 r
.26589 .55433 m .26786 .55516 L .27281 .55424 L F
.27281 .55421 m .27281 .55424 L .27303 .5542 L F
.26589 .55433 m .27281 .55424 L .27281 .55421 L F
.673 .243 .217 r
.26775 .55259 m .26589 .55433 L .27281 .55421 L F
.26775 .55259 m .27281 .55421 L .27282 .55416 L F
.27295 .55418 m .27297 .55416 L .27015 .55205 L F
0 .233 .696 r
.27288 .55409 m .2728 .55348 L .27015 .55205 L F
.27303 .5542 m .273 .55411 L .27288 .55409 L F
.273 .55411 m .2728 .55348 L .27288 .55409 L F
0 0 0 r
.27283 .55438 m .27282 .5543 L .27295 .5541 L F
.27299 .55411 m .27295 .5541 L .27417 .55215 L F
.246 0 0 r
.27281 .55424 m .273 .55411 L .27303 .5542 L F
0 0 0 r
.27283 .55438 m .27295 .5541 L .27299 .55411 L F
.246 0 0 r
.26786 .55516 m .2728 .55348 L .273 .55411 L F
.673 .243 .217 r
.27282 .55416 m .27281 .55421 L .27295 .5542 L F
.246 0 0 r
.26786 .55516 m .273 .55411 L .27281 .55424 L F
0 0 0 r
.27348 .55374 m .27333 .55389 L .27417 .55215 L F
.27333 .55389 m .27283 .55438 L .27298 .55413 L F
.27333 .55389 m .27298 .55413 L .27417 .55215 L F
.27283 .55438 m .27269 .55451 L .27282 .5543 L F
.27269 .55451 m .27297 .55378 L .27417 .55215 L F
.015 0 .14 r
.27219 .55484 m .27175 .55544 L .27188 .55511 L F
.359 .146 .449 r
.2968 .64093 m .29711 .63823 L .29897 .63782 L F
.589 .844 .486 r
.32544 .68218 m .32588 .68174 L .32291 .68538 L F
0 0 0 r
.32934 .61447 m .32801 .61569 L .32906 .61333 L F
.23 0 0 r
.32801 .61569 m .32391 .61667 L .32389 .61704 L F
.32801 .61569 m .32603 .61668 L .32391 .61667 L F
.515 .893 .709 r
.32934 .61447 m .32603 .61668 L .32801 .61569 L F
.266 .772 .854 r
.3271 .61667 m .32603 .61668 L .32934 .61447 L F
0 0 .359 r
.33042 .61331 m .32934 .61447 L .32918 .61163 L F
0 0 0 r
.33042 .61331 m .3271 .61667 L .32934 .61447 L F
.32946 .61428 m .32867 .61545 L .3271 .61667 L F
.33042 .61331 m .32957 .61434 L .32946 .61428 L F
.32957 .61434 m .32867 .61545 L .32946 .61428 L F
.32933 .6142 m .32906 .61333 L .32918 .61163 L F
.32934 .61447 m .32927 .61416 L .32933 .6142 L F
.32927 .61416 m .32906 .61333 L .32933 .6142 L F
.962 .632 .321 r
.41558 .55795 m .41381 .55444 L .41457 .5555 L F
.583 .082 0 r
.23929 .61174 m .23989 .61213 L .23734 .611 L F
.569 .81 .427 r
.35126 .66455 m .35461 .66009 L .35681 .66261 L F
.392 .036 .236 r
.35461 .66009 m .357 .66222 L .35681 .66261 L F
.35461 .66009 m .35809 .65879 L .357 .66222 L F
0 0 .102 r
.3299 .53076 m .33167 .52975 L .33217 .52732 L F
0 0 0 r
.33167 .52975 m .33069 .53129 L .33272 .52866 L F
.33167 .52975 m .33272 .52866 L .33291 .52841 L F
.824 .885 .456 r
.33005 .53142 m .33167 .52975 L .3299 .53076 L F
.33047 .53333 m .33167 .52975 L .33005 .53142 L F
.468 .198 .421 r
.35571 .63813 m .35576 .63585 L .35376 .63734 L F
.826 .358 0 r
.35376 .63734 m .35663 .64112 L .35571 .63813 L F
.213 .064 .451 r
.19738 .57174 m .19891 .57105 L .19914 .56834 L F
.296 .184 .553 r
.19741 .57451 m .19891 .57105 L .19738 .57174 L F
0 0 .368 r
.60639 .41017 m .60588 .40934 L .60714 .4115 L F
0 0 .322 r
.60531 .40685 m .60555 .4088 L .60588 .40934 L F
.85 .539 .009 r
.60531 .40685 m .60588 .40934 L .6051 .40791 L F
0 0 .368 r
.6051 .40791 m .60588 .40934 L .60639 .41017 L F
0 0 .322 r
.60555 .4088 m .6058 .41089 L .60588 .40934 L F
0 0 .529 r
.6058 .41089 m .60714 .4115 L .60588 .40934 L F
.6058 .41089 m .60686 .41307 L .60714 .4115 L F
.816 .342 .081 r
.32774 .69429 m .3299 .69486 L .33128 .69746 L F
.009 0 0 r
.36242 .65646 m .36459 .65649 L .36629 .65651 L F
.69 .613 .766 r
.38802 .60025 m .39157 .60014 L .39001 .5971 L F
.42 .295 .604 r
.38811 .60289 m .389 .6049 L .38978 .6042 L F
.614 .464 .655 r
.38826 .60024 m .39116 .60218 L .39157 .60014 L F
.38834 .60044 m .39116 .60218 L .38826 .60024 L F
.38802 .60025 m .38811 .60289 L .39116 .60218 L F
.513 .003 0 r
.39297 .60209 m .39149 .6005 L .39174 .60215 L F
.204 .567 .938 r
.39362 .60206 m .39116 .60218 L .39247 .60177 L F
.549 .439 .682 r
.39247 .60177 m .39107 .60832 L .39294 .60713 L F
0 0 .334 r
.39247 .60177 m .39201 .60393 L .39237 .60443 L F
.39201 .60393 m .39107 .60832 L .39218 .60501 L F
.39201 .60393 m .39218 .60501 L .39237 .60443 L F
.513 .003 0 r
.39297 .60209 m .39157 .60014 L .39149 .6005 L F
.39174 .60215 m .39149 .6005 L .39116 .60218 L F
.39362 .60206 m .39319 .60166 L .39297 .60209 L F
.39319 .60166 m .39157 .60014 L .39297 .60209 L F
.792 .679 .74 r
.38718 .60917 m .38954 .60866 L .39247 .60177 L F
.38954 .60866 m .39107 .60832 L .39201 .60393 L F
.38954 .60866 m .39201 .60393 L .39247 .60177 L F
.42 .295 .604 r
.38811 .60289 m .39247 .60177 L .39116 .60218 L F
.38917 .60261 m .38978 .6042 L .39247 .60177 L F
.38811 .60289 m .38978 .6042 L .38917 .60261 L F
.614 .464 .655 r
.38802 .60025 m .38834 .60044 L .38826 .60024 L F
.416 0 0 r
.34584 .50308 m .34841 .50391 L .34996 .50298 L F
.477 .858 .645 r
.34996 .50298 m .35142 .50165 L .35232 .50274 L F
.34996 .50298 m .34841 .50391 L .35142 .50165 L F
.736 .241 .058 r
.64397 .40142 m .64662 .40371 L .64285 .40248 L F
.726 .314 .266 r
.64742 .4032 m .64662 .40371 L .64397 .40142 L F
.894 .564 .072 r
.39575 .53863 m .3961 .53784 L .39498 .53674 L F
.39575 .53863 m .39663 .54003 L .3961 .53784 L F
.673 .519 .668 r
.58018 .44459 m .5774 .44217 L .58099 .44186 L F
.574 .293 .453 r
.58362 .442 m .58018 .44459 L .58099 .44186 L F
.971 .714 .487 r
.31509 .63984 m .31719 .64081 L .31708 .63821 L F
.627 .909 .983 r
.57582 .42765 m .57446 .42961 L .57605 .42859 L F
0 .241 .757 r
.576 .42954 m .57446 .42961 L .57582 .42765 L F
.576 .42954 m .57718 .43198 L .57446 .42961 L F
0 0 0 r
.34506 .51424 m .34205 .51711 L .34305 .51565 L F
.435 .845 .968 r
.28424 .5215 m .28636 .52102 L .28823 .52131 L F
.347 .777 .97 r
.28636 .52102 m .29049 .52132 L .28823 .52131 L F
.59 .513 .737 r
.35534 .61647 m .3579 .6161 L .35696 .61178 L F
0 .093 .617 r
.60686 .41307 m .60753 .41705 L .6085 .41519 L F
0 0 .52 r
.60753 .41705 m .60931 .41757 L .6085 .41519 L F
.60753 .41705 m .60821 .41949 L .60931 .41757 L F
.989 .84 .601 r
.34826 .61313 m .34737 .61532 L .34612 .61479 L F
.34826 .61313 m .34737 .61532 L .34612 .61479 L F
.866 .824 .805 r
.41358 .51108 m .41386 .51487 L .41164 .51443 L F
.634 .298 .384 r
.41386 .51487 m .41089 .51708 L .41164 .51443 L F
.41386 .51487 m .41415 .51714 L .41089 .51708 L F
.402 .469 .814 r
.41639 .51382 m .41386 .51487 L .41358 .51108 L F
.293 .068 .391 r
.41511 .51613 m .41386 .51487 L .41639 .51382 L F
.41511 .51613 m .41415 .51714 L .41386 .51487 L F
0 .037 .548 r
.19684 .59607 m .19795 .59711 L .19643 .59547 L F
.571 .94 .867 r
.25308 .52678 m .24842 .52856 L .25184 .52727 L F
0 0 0 r
.25417 .52644 m .25557 .52566 L .25308 .52678 L F
.25417 .52644 m .25308 .52678 L .25184 .52727 L F
.925 .736 .628 r
.34272 .58399 m .34571 .58493 L .34571 .58427 L F
.746 .985 .902 r
.32442 .56114 m .32377 .56275 L .32546 .56113 L F
0 0 .216 r
.37776 .61569 m .37879 .61958 L .37845 .61818 L F
.687 .558 .703 r
.3805 .6203 m .37845 .61818 L .37879 .61958 L F
.337 .275 .639 r
.37879 .61958 m .37895 .62034 L .3805 .6203 L F
.37895 .62034 m .38018 .62102 L .3805 .6203 L F
.37895 .62034 m .37945 .62265 L .38018 .62102 L F
.848 .881 .864 r
.3805 .6203 m .38018 .62102 L .38014 .62057 L F
.687 .558 .703 r
.3805 .6203 m .38072 .62151 L .38014 .62066 L F
.3805 .6203 m .38014 .62066 L .37845 .61818 L F
.848 .881 .864 r
.38014 .62057 m .38009 .62072 L .37686 .62297 L F
.38009 .62072 m .37945 .62265 L .37795 .62284 L F
.38009 .62072 m .37795 .62284 L .37686 .62297 L F
.38018 .62102 m .37945 .62265 L .38014 .62057 L F
.377 .029 .243 r
.3793 .6236 m .38037 .62066 L .37686 .62297 L F
.38037 .62066 m .3805 .6203 L .38014 .62057 L F
.139 .322 .786 r
.38007 .62055 m .38014 .62066 L .38013 .62057 L F
.377 .029 .243 r
.38037 .62066 m .38014 .62057 L .37686 .62297 L F
.139 .322 .786 r
.37845 .61818 m .38007 .62055 L .37959 .61783 L F
.38007 .62055 m .38013 .62057 L .37959 .61783 L F
.38014 .62066 m .38051 .6212 L .38 .61933 L F
.38014 .62066 m .38 .61933 L .37959 .61783 L F
.38051 .6212 m .38072 .62151 L .38065 .62128 L F
.98 .759 .532 r
.38105 .6203 m .38072 .62151 L .3805 .6203 L F
.734 .73 .847 r
.38184 .61745 m .38105 .6203 L .38268 .61731 L F
.38105 .6203 m .38072 .62151 L .38139 .62008 L F
.38105 .6203 m .38139 .62008 L .38268 .61731 L F
.276 0 .2 r
.38054 .62063 m .3805 .6203 L .38037 .62066 L F
.98 .759 .532 r
.38272 .62028 m .38268 .61731 L .38072 .62151 L F
.38272 .62028 m .38072 .62151 L .38105 .6203 L F
.276 0 .2 r
.38105 .6203 m .3805 .6203 L .38054 .62063 L F
.734 .73 .847 r
.37959 .61783 m .38047 .62068 L .38184 .61745 L F
.38047 .62068 m .38072 .62151 L .38105 .6203 L F
.38047 .62068 m .38105 .6203 L .38184 .61745 L F
.139 .322 .786 r
.38051 .6212 m .38065 .62128 L .38047 .62068 L F
.38051 .6212 m .38047 .62068 L .38037 .62066 L F
.276 0 .2 r
.38197 .621 m .38047 .62068 L .3793 .6236 L F
.38047 .62068 m .38037 .62066 L .38034 .62077 L F
.38047 .62068 m .38034 .62077 L .3793 .6236 L F
.38272 .62028 m .38105 .6203 L .38054 .62063 L F
.38272 .62028 m .38037 .62066 L .38197 .621 L F
.139 .322 .786 r
.38037 .62066 m .38047 .62068 L .37959 .61783 L F
.716 .844 .943 r
.40614 .5181 m .40192 .51797 L .40412 .5173 L F
0 .205 .729 r
.40692 .5176 m .40614 .5181 L .40412 .5173 L F
.40692 .5176 m .40841 .51998 L .40614 .5181 L F
.382 .307 .648 r
.40614 .5181 m .40841 .51998 L .40662 .52079 L F
.425 .594 .914 r
.39157 .5577 m .39245 .55629 L .39099 .55672 L F
.39157 .5577 m .39478 .55761 L .39245 .55629 L F
.769 .531 .574 r
.39063 .56043 m .3945 .55781 L .39157 .5577 L F
.3945 .55781 m .3944 .55762 L .39157 .5577 L F
.39063 .56043 m .39326 .56066 L .39464 .55791 L F
.3945 .55781 m .39464 .55791 L .39478 .55761 L F
.39063 .56043 m .39464 .55791 L .3945 .55781 L F
.769 .53 .573 r
.39478 .55761 m .39326 .56066 L .39719 .56094 L F
.687 .142 0 r
.39239 .55632 m .39467 .55814 L .39172 .55664 L F
.39245 .55629 m .39294 .55671 L .39239 .55632 L F
.39294 .55671 m .39467 .55814 L .39239 .55632 L F
.39467 .55814 m .39506 .55847 L .39474 .5583 L F
.39467 .55814 m .39474 .5583 L .39172 .55664 L F
.769 .531 .574 r
.3945 .55781 m .39478 .55761 L .3944 .55762 L F
.544 .763 .979 r
.60765 .39265 m .60636 .39476 L .6051 .39321 L F
.496 .701 .961 r
.60765 .39265 m .60919 .39456 L .60636 .39476 L F
.86 .959 .869 r
.33625 .5459 m .33469 .54523 L .33829 .54245 L F
0 0 .177 r
.30811 .60207 m .30612 .6034 L .30815 .6001 L F
.253 .135 .519 r
.30811 .60207 m .3059 .60611 L .30612 .6034 L F
.742 .804 .901 r
.22654 .57445 m .23079 .57504 L .22876 .57354 L F
.748 .486 .535 r
.2263 .57714 m .23079 .57504 L .22654 .57445 L F
.2263 .57714 m .23044 .57755 L .23079 .57504 L F
.57 .685 .918 r
.23079 .57504 m .23101 .57172 L .22876 .57354 L F
.23079 .57504 m .23326 .57468 L .23101 .57172 L F
.427 .157 .4 r
.23326 .57468 m .23044 .57755 L .23079 .57504 L F
.23326 .57468 m .23044 .57755 L .23079 .57504 L F
.807 .684 .728 r
.3778 .54031 m .37901 .54369 L .37895 .54367 L F
.397 .445 .793 r
.37871 .54378 m .37883 .54426 L .37891 .54373 L F
.3778 .54031 m .37903 .5441 L .37895 .54367 L F
.991 .844 .6 r
.37905 .5486 m .37768 .54829 L .37814 .54531 L F
.812 .654 .687 r
.37814 .54531 m .37768 .54829 L .37854 .54778 L F
.37814 .54531 m .37854 .54778 L .37811 .54596 L F
.37814 .54531 m .37811 .54596 L .3779 .54506 L F
.397 .445 .793 r
.37891 .54373 m .37883 .54426 L .37903 .5441 L F
.37897 .54372 m .37903 .5441 L .37908 .54405 L F
.37896 .54373 m .37903 .5441 L .37897 .54372 L F
.416 .478 .816 r
.37883 .54426 m .38172 .54538 L .38082 .54261 L F
0 0 0 r
.38082 .54261 m .37814 .54531 L .379 .54371 L F
.38082 .54261 m .379 .54371 L .37901 .54369 L F
.096 0 0 r
.37901 .54369 m .37896 .54372 L .37895 .54367 L F
.397 .445 .793 r
.37895 .54367 m .37896 .54373 L .37897 .54372 L F
.991 .844 .6 r
.37905 .5486 m .37814 .54531 L .38172 .54538 L F
.844 .73 .738 r
.38172 .54538 m .37814 .54531 L .38082 .54261 L F
.116 .352 .817 r
.37811 .54596 m .38006 .54535 L .3779 .54506 L F
.37854 .54778 m .37967 .54597 L .37811 .54596 L F
.37967 .54597 m .38006 .54535 L .37811 .54596 L F
.096 0 0 r
.37818 .54422 m .37814 .54531 L .37627 .54595 L F
.37549 .54595 m .37627 .54595 L .37461 .54652 L F
.37818 .54422 m .37627 .54595 L .37549 .54595 L F
.37896 .54372 m .37814 .54531 L .37818 .54422 L F
.37901 .54369 m .379 .54371 L .37896 .54372 L F
.379 .54371 m .37814 .54531 L .37896 .54372 L F
.397 .445 .793 r
.3778 .54031 m .37871 .54378 L .37891 .54373 L F
.096 0 0 r
.37895 .54367 m .37461 .54652 L .37367 .54222 L F
.37896 .54372 m .37461 .54652 L .37895 .54367 L F
.807 .684 .728 r
.3778 .54031 m .37895 .54367 L .37367 .54222 L F
.703 .611 .751 r
.38144 .53969 m .37877 .54015 L .38068 .53873 L F
.37877 .54015 m .3778 .54031 L .37872 .5398 L F
.37877 .54015 m .37872 .5398 L .38068 .53873 L F
.703 .73 .871 r
.37883 .53995 m .3778 .54031 L .37877 .54015 L F
.397 .445 .793 r
.37872 .5398 m .3807 .53929 L .38068 .53873 L F
.3778 .54031 m .37883 .53995 L .37872 .5398 L F
.37883 .53995 m .3807 .53929 L .37872 .5398 L F
.346 .35 .721 r
.37934 .54062 m .38082 .54261 L .37925 .54354 L F
.703 .73 .871 r
.37941 .53807 m .37877 .54015 L .37935 .54005 L F
.856 .619 .579 r
.38068 .53873 m .3807 .53929 L .38144 .53969 L F
.703 .73 .871 r
.3796 .53869 m .37999 .53994 L .38144 .53969 L F
.856 .619 .579 r
.3807 .53929 m .38082 .54261 L .38144 .53969 L F
.703 .73 .871 r
.37941 .53807 m .3796 .53869 L .38144 .53969 L F
.397 .445 .793 r
.37883 .53995 m .37923 .54049 L .3807 .53929 L F
.703 .73 .871 r
.37941 .53807 m .3778 .54031 L .37883 .53995 L F
.346 .35 .721 r
.37941 .53807 m .37923 .54049 L .3778 .54031 L F
.37923 .54049 m .37901 .54369 L .3778 .54031 L F
.397 .445 .793 r
.37923 .54049 m .38082 .54261 L .38075 .54068 L F
.37923 .54049 m .38075 .54068 L .3807 .53929 L F
.346 .35 .721 r
.37923 .54049 m .37925 .54354 L .3791 .54243 L F
.37934 .54062 m .37925 .54354 L .37923 .54049 L F
.397 .445 .793 r
.3778 .54031 m .38082 .54261 L .37883 .53995 L F
.346 .35 .721 r
.37941 .53807 m .37934 .54062 L .37923 .54049 L F
.37941 .53807 m .38082 .54261 L .37934 .54062 L F
.3791 .54243 m .37925 .54354 L .37901 .54369 L F
.397 .445 .793 r
.3778 .54031 m .37908 .54405 L .38082 .54261 L F
.955 .624 .351 r
.32067 .62829 m .32174 .63144 L .31985 .63087 L F
.134 0 .12 r
.32174 .63144 m .3247 .62856 L .32407 .63088 L F
.646 .365 .478 r
.32067 .62829 m .32407 .63088 L .32174 .63144 L F
.493 .795 .999 r
.32174 .63144 m .32268 .62988 L .32067 .62829 L F
.376 0 .17 r
.32268 .62988 m .32067 .62829 L .31985 .63087 L F
.659 .536 .703 r
.32067 .62829 m .32314 .62487 L .32058 .62539 L F
.32067 .62829 m .3247 .62856 L .32314 .62487 L F
.646 .365 .478 r
.32067 .62829 m .3247 .62856 L .32407 .63088 L F
.475 0 0 r
.32268 .62988 m .3247 .62856 L .32067 .62829 L F
0 0 .426 r
.19604 .58119 m .19707 .58071 L .19739 .5772 L F
.038 .045 .536 r
.19604 .58119 m .19749 .58328 L .19707 .58071 L F
.172 .083 .505 r
.1961 .58401 m .19749 .58328 L .19604 .58119 L F
.878 .725 .688 r
.39951 .58336 m .3964 .5862 L .39829 .58308 L F
.39951 .58336 m .39804 .58745 L .3964 .5862 L F
.204 0 0 r
.32728 .53925 m .32966 .53874 L .33118 .53706 L F
.569 .649 .89 r
.33118 .53706 m .33137 .53365 L .33047 .53333 L F
.33118 .53706 m .33357 .53646 L .33137 .53365 L F
.014 0 .049 r
.62601 .41278 m .62679 .41112 L .62879 .40975 L F
.665 .543 .706 r
.35162 .56131 m .35614 .56456 L .35632 .56271 L F
0 0 .065 r
.31799 .637 m .31827 .63514 L .31796 .63601 L F
.654 .898 .565 r
.34847 .5718 m .34592 .57495 L .34706 .57317 L F
.036 0 .378 r
.34592 .57495 m .34737 .57596 L .34706 .57317 L F
.629 .772 .949 r
.27028 .53136 m .27429 .53183 L .27283 .53109 L F
.677 .858 .968 r
.27283 .53109 m .27429 .53183 L .27668 .53076 L F
.195 .034 .422 r
.34704 .52091 m .34868 .52034 L .34945 .51743 L F
.572 .434 .654 r
.34645 .52341 m .34868 .52034 L .34704 .52091 L F
.737 .651 .764 r
.21925 .58106 m .22164 .58158 L .22156 .57821 L F
.828 .547 .514 r
.2192 .5834 m .22164 .58158 L .21925 .58106 L F
.2192 .5834 m .22128 .58409 L .22164 .58158 L F
.725 .678 .805 r
.22164 .58158 m .22399 .57764 L .22156 .57821 L F
.708 .432 .504 r
.22164 .58158 m .22128 .58409 L .22539 .58396 L F
.501 .224 .426 r
.35779 .63705 m .35576 .63585 L .35571 .63813 L F
.383 .837 .917 r
.35899 .63519 m .35576 .63585 L .35779 .63705 L F
.759 .721 .817 r
.36654 .54042 m .36487 .54298 L .36868 .54335 L F
0 .186 .713 r
.36868 .54335 m .36909 .54268 L .36654 .54042 L F
0 0 .072 r
.36868 .54335 m .36955 .54355 L .36909 .54268 L F
.36868 .54335 m .36821 .5458 L .36955 .54355 L F
.481 .417 .708 r
.32097 .55282 m .32126 .55568 L .31916 .55633 L F
0 0 .004 r
.32126 .55568 m .3187 .55821 L .31916 .55633 L F
.59 .274 .401 r
.39415 .60028 m .39616 .60107 L .39833 .59898 L F
0 0 0 r
.39833 .59898 m .39616 .60107 L .39923 .59919 L F
.986 .776 .538 r
.41152 .54339 m .40958 .54491 L .40998 .54225 L F
.94 .642 .447 r
.41152 .54339 m .41164 .54589 L .40958 .54491 L F
.678 .725 .885 r
.63216 .39669 m .6362 .39748 L .63375 .39873 L F
.58 .574 .811 r
.34676 .56586 m .34412 .56628 L .34541 .56431 L F
.047 0 .037 r
.34235 .59659 m .3405 .59761 L .34164 .59399 L F
.139 0 .105 r
.3405 .59761 m .34158 .59449 L .34164 .59399 L F
.52 .258 .457 r
.34158 .59449 m .33705 .59371 L .33955 .59366 L F
.34158 .59449 m .33615 .59621 L .33705 .59371 L F
0 0 .32 r
.38988 .56571 m .39034 .56773 L .39092 .56674 L F
.38988 .56571 m .39092 .56674 L .38803 .56786 L F
0 0 .299 r
.27802 .64019 m .27821 .64136 L .27824 .64063 L F
.886 .673 .608 r
.28126 .64098 m .28075 .64442 L .27821 .64136 L F
.546 .076 0 r
.27821 .64136 m .27923 .64261 L .27824 .64063 L F
.27821 .64136 m .28075 .64442 L .27923 .64261 L F
.685 .411 .502 r
.36351 .64393 m .36431 .6416 L .36044 .64179 L F
.326 .141 .47 r
.36633 .6384 m .36431 .6416 L .36446 .64058 L F
.741 .777 .28 r
.36446 .64058 m .36431 .6416 L .36351 .64393 L F
.642 .787 .951 r
.4222 .54608 m .41808 .54546 L .41854 .54391 L F
.969 .696 .462 r
.4222 .54608 m .42029 .5479 L .41808 .54546 L F
.4222 .54608 m .42232 .54939 L .42029 .5479 L F
0 0 .393 r
.42423 .54253 m .42315 .54432 L .42283 .54468 L F
.011 .289 .786 r
.42283 .54468 m .4222 .54608 L .42178 .54584 L F
0 0 .393 r
.42188 .54644 m .42177 .54663 L .42283 .54468 L F
.884 .988 .806 r
.42177 .54663 m .42029 .5479 L .42283 .54468 L F
.918 .827 .74 r
.42029 .5479 m .4216 .54696 L .42283 .54468 L F
.011 .289 .786 r
.42283 .54468 m .42296 .546 L .4222 .54608 L F
0 0 .414 r
.42296 .546 m .42232 .54939 L .4222 .54608 L F
.918 .827 .74 r
.42188 .54644 m .42296 .546 L .42283 .54468 L F
.42166 .54692 m .42296 .546 L .42188 .54644 L F
.42029 .5479 m .42232 .54939 L .42296 .546 L F
0 0 .393 r
.42423 .54253 m .42428 .54577 L .4218 .54662 L F
.42188 .54644 m .4218 .54662 L .42177 .54663 L F
.42423 .54253 m .4218 .54662 L .42188 .54644 L F
.247 0 0 r
.42177 .54666 m .42029 .5479 L .42177 .54663 L F
.918 .827 .74 r
.4216 .54696 m .42166 .54692 L .42179 .54664 L F
.4216 .54696 m .42179 .54664 L .42176 .54667 L F
.247 0 0 r
.42172 .54887 m .42029 .5479 L .42177 .54666 L F
.918 .827 .74 r
.42176 .54667 m .42179 .54664 L .42188 .54644 L F
0 0 .393 r
.42315 .54432 m .42188 .54644 L .42283 .54468 L F
.011 .289 .786 r
.42283 .54468 m .42178 .54584 L .41854 .54391 L F
.799 .783 .838 r
.57091 .42664 m .56808 .4299 L .56682 .42792 L F
.857 .997 .799 r
.24395 .53934 m .2437 .54138 L .24554 .53989 L F
.24395 .53934 m .24184 .542 L .2437 .54138 L F
.905 .521 .087 r
.35269 .58153 m .35203 .5821 L .3497 .58077 L F
.35269 .58153 m .35346 .58398 L .35203 .5821 L F
0 0 .307 r
.35249 .58077 m .35346 .58398 L .35269 .58153 L F
.737 .707 .823 r
.3794 .60607 m .38257 .60657 L .38025 .60776 L F
.189 .393 .832 r
.3794 .60607 m .38025 .60776 L .3816 .60774 L F
.179 .447 .875 r
.38025 .60776 m .38254 .60898 L .3816 .60774 L F
.722 .895 .512 r
.39044 .63403 m .38837 .63759 L .39119 .63443 L F
.588 .906 .982 r
.56836 .41733 m .5718 .41703 L .57036 .4157 L F
.59 .844 .993 r
.20375 .60607 m .20139 .60707 L .19946 .60577 L F
.19946 .60577 m .20139 .60707 L .20375 .60607 L F
.509 .512 .795 r
.58089 .42949 m .58215 .42503 L .57965 .42593 L F
.515 .287 .506 r
.58187 .43169 m .58426 .42963 L .58089 .42949 L F
.118 .265 .74 r
.61962 .41753 m .61869 .41973 L .61857 .41922 L F
.318 .201 .559 r
.39825 .66582 m .39797 .67036 L .39621 .66986 L F
.477 .445 .744 r
.39797 .67036 m .3965 .67222 L .39621 .66986 L F
.688 .308 .322 r
.3388 .70745 m .3423 .70773 L .34091 .70983 L F
.506 .082 .171 r
.3423 .70773 m .34317 .70966 L .34091 .70983 L F
.3423 .70773 m .34535 .70744 L .34317 .70966 L F
.861 .85 .831 r
.68896 .3214 m .68924 .32493 L .68775 .32319 L F
.885 .795 .755 r
.68924 .32493 m .68554 .32652 L .68775 .32319 L F
.68924 .32493 m .68714 .32812 L .68554 .32652 L F
.875 .859 .822 r
.69184 .3213 m .68924 .32493 L .68896 .3214 L F
.364 .565 .913 r
.63216 .39669 m .63035 .39658 L .62829 .3936 L F
.276 .157 .531 r
.31255 .55594 m .31424 .55785 L .31392 .55527 L F
.31255 .55594 m .3126 .55876 L .31424 .55785 L F
.61 .637 .853 r
.33521 .57205 m .33946 .57501 L .33756 .57182 L F
.881 .922 .847 r
.33946 .57501 m .33968 .57182 L .33756 .57182 L F
.288 .788 .838 r
.37039 .56967 m .37428 .56933 L .37682 .56866 L F
.259 .613 .956 r
.36107 .50456 m .36036 .50595 L .35885 .50466 L F
.36107 .50456 m .36345 .5064 L .36036 .50595 L F
.953 .615 .224 r
.41292 .54967 m .4121 .55088 L .41164 .54848 L F
.41292 .54967 m .41342 .55215 L .4121 .55088 L F
.831 .946 .59 r
.32451 .61289 m .32285 .6159 L .3233 .61402 L F
0 .002 .562 r
.32285 .6159 m .32391 .61667 L .3233 .61402 L F
0 .018 .587 r
.32285 .6159 m .32389 .61704 L .32391 .61667 L F
.479 .203 .417 r
.23348 .58763 m .23298 .59002 L .2305 .59045 L F
.594 .611 .839 r
.23414 .58318 m .23348 .58763 L .23183 .58324 L F
.23414 .58318 m .23599 .5873 L .23348 .58763 L F
.527 .246 .432 r
.23348 .58763 m .23552 .58964 L .23298 .59002 L F
.523 .247 .437 r
.23348 .58763 m .23599 .5873 L .23552 .58964 L F
.332 .591 .94 r
.21712 .60948 m .21558 .60624 L .21515 .60659 L F
.21712 .60948 m .21705 .60795 L .21558 .60624 L F
.21712 .60948 m .21797 .60952 L .21705 .60795 L F
.318 .351 .738 r
.28699 .63062 m .28455 .63168 L .28438 .62821 L F
0 0 .419 r
.28641 .63304 m .28455 .63168 L .28699 .63062 L F
.28641 .63304 m .28479 .63429 L .28455 .63168 L F
0 0 0 r
.72233 .35389 m .72132 .3543 L .71863 .35531 L F
0 .287 .744 r
.34647 .53627 m .34249 .53348 L .34452 .53694 L F
0 0 .17 r
.34452 .53694 m .34532 .5374 L .34647 .53627 L F
.34452 .53694 m .3445 .53975 L .34532 .5374 L F
.553 .454 .696 r
.41401 .52679 m .41205 .53039 L .41131 .52761 L F
.41401 .52679 m .41478 .52981 L .41205 .53039 L F
.083 0 .341 r
.41351 .53149 m .41205 .53039 L .41478 .52981 L F
.41351 .53149 m .41201 .53272 L .41205 .53039 L F
.703 .78 .912 r
.34562 .6509 m .35 .65131 L .34837 .65075 L F
.898 .765 .706 r
.3463 .64903 m .34837 .65075 L .34826 .64857 L F
.466 .708 .973 r
.34562 .6509 m .34837 .65075 L .3463 .64903 L F
.898 .765 .706 r
.3463 .64903 m .34826 .64857 L .34858 .65121 L F
.677 .231 .185 r
.34826 .64857 m .3463 .64903 L .34812 .64931 L F
.902 .545 .078 r
.34826 .64857 m .35 .65131 L .34841 .64774 L F
.976 .818 .62 r
.34837 .65075 m .35 .65131 L .34826 .64857 L F
.677 .231 .185 r
.34826 .64857 m .34896 .64944 L .3495 .64952 L F
.271 .082 .43 r
.34826 .64857 m .3495 .64952 L .35147 .64831 L F
.235 0 .234 r
.34932 .64918 m .34826 .64857 L .35044 .64839 L F
.34896 .64944 m .34889 .64936 L .34932 .64918 L F
.34889 .64936 m .34826 .64857 L .34932 .64918 L F
.492 .495 .788 r
.35147 .64831 m .3495 .64952 L .34932 .64918 L F
.235 0 .234 r
.34896 .64944 m .35044 .64839 L .35147 .64831 L F
.492 .495 .788 r
.35147 .64831 m .34932 .64918 L .3479 .64648 L F
.235 0 .234 r
.34858 .65121 m .34826 .64857 L .34957 .65021 L F
.677 .231 .185 r
.34826 .64857 m .34812 .64931 L .34896 .64944 L F
.902 .545 .078 r
.34826 .64857 m .34841 .64774 L .3482 .64727 L F
.503 .023 .05 r
.3463 .64903 m .3482 .64727 L .34609 .64701 L F
.677 .231 .185 r
.34826 .64857 m .3482 .64727 L .3463 .64903 L F
.625 .559 .76 r
.3479 .64648 m .34932 .64918 L .3463 .64903 L F
.34932 .64918 m .3495 .64952 L .34896 .64944 L F
.34932 .64918 m .34896 .64944 L .3463 .64903 L F
.235 0 .234 r
.34957 .65021 m .34896 .64944 L .35147 .64831 L F
.263 0 .296 r
.29995 .59015 m .30186 .58979 L .30192 .58803 L F
.325 .24 .604 r
.29995 .59015 m .30227 .5922 L .30186 .58979 L F
.29995 .59015 m .29981 .59347 L .30227 .5922 L F
.704 .754 .891 r
.28777 .52721 m .29 .53043 L .29162 .52721 L F
.531 .54 .81 r
.29 .53043 m .29242 .53018 L .29162 .52721 L F
.433 .276 .567 r
.29033 .53317 m .29242 .53018 L .29 .53043 L F
.44 .325 .626 r
.35694 .62319 m .3568 .62561 L .35925 .62512 L F
.446 .251 .521 r
.3555 .65027 m .35301 .6534 L .35471 .65299 L F
.265 0 .249 r
.35471 .65299 m .35301 .6534 L .35246 .65422 L F
.986 .712 .364 r
.37802 .65016 m .37893 .6517 L .3791 .65164 L F
.371 0 0 r
.35167 .59512 m .35011 .59438 L .34956 .59599 L F
.35167 .59512 m .35271 .59429 L .35011 .59438 L F
.369 .14 .431 r
.39485 .69476 m .39458 .69731 L .39249 .69806 L F
.218 .021 .386 r
.39734 .69142 m .39706 .69424 L .39485 .69476 L F
.092 0 .258 r
.39706 .69424 m .39458 .69731 L .39485 .69476 L F
.791 .345 .188 r
.32324 .6917 m .32567 .69185 L .32458 .69318 L F
.755 .296 .161 r
.32567 .69185 m .32774 .69429 L .32458 .69318 L F
.672 .672 .841 r
.39157 .60014 m .39265 .59663 L .39001 .5971 L F
.39157 .60014 m .39415 .60028 L .39265 .59663 L F
.513 .003 0 r
.39362 .60206 m .39415 .60028 L .39157 .60014 L F
.659 .902 .571 r
.73456 .33914 m .73455 .33884 L .73289 .34133 L F
0 0 0 r
.73334 .34086 m .73289 .34133 L .73455 .33884 L F
.73334 .34086 m .73229 .34304 L .73289 .34133 L F
.751 .907 .526 r
.35254 .6069 m .35317 .60694 L .35406 .60517 L F
.9 .773 .712 r
.2985 .62282 m .29729 .62526 L .29531 .62399 L F
0 .262 .722 r
.30048 .62384 m .2985 .62282 L .29806 .6221 L F
.632 .403 .553 r
.33237 .59 m .33559 .58694 L .33245 .58769 L F
.543 .577 .839 r
.36953 .62732 m .36758 .6282 L .36603 .62475 L F
.565 .771 .975 r
.57545 .40478 m .57807 .4041 L .5766 .40236 L F
.57545 .40478 m .57807 .4041 L .5766 .40236 L F
.732 .661 .78 r
.31509 .51136 m .31949 .51261 L .31762 .51108 L F
.79 .848 .895 r
.31762 .51108 m .31949 .51261 L .32015 .51018 L F
0 .486 .832 r
.32685 .66467 m .32716 .66516 L .32548 .66423 L F
.32801 .66505 m .32716 .66516 L .32685 .66467 L F
.291 .062 .384 r
.32919 .66321 m .32752 .66576 L .32716 .66516 L F
.32752 .66576 m .32607 .66799 L .32716 .66516 L F
.41 0 0 r
.32801 .66505 m .32919 .66321 L .32716 .66516 L F
.32801 .66505 m .33137 .66379 L .32919 .66321 L F
.938 .728 .593 r
.40065 .51123 m .40219 .51556 L .40018 .51396 L F
.81 .695 .738 r
.40082 .51509 m .40018 .51396 L .40219 .51556 L F
.625 .584 .788 r
.40488 .51457 m .40219 .51556 L .40065 .51123 L F
.708 .444 .524 r
.40488 .51457 m .40082 .51509 L .40219 .51556 L F
.842 .866 .861 r
.21941 .57347 m .21834 .5749 L .22011 .5749 L F
.731 .547 .642 r
.21757 .57773 m .22011 .5749 L .21834 .5749 L F
.21757 .57773 m .22156 .57821 L .22011 .5749 L F
.848 .867 .856 r
.21941 .57347 m .22011 .5749 L .22267 .57128 L F
.642 .55 .735 r
.22011 .5749 m .22409 .57522 L .22267 .57128 L F
.636 .503 .683 r
.22011 .5749 m .22399 .57764 L .22409 .57522 L F
.22011 .5749 m .22156 .57821 L .22399 .57764 L F
0 .189 .718 r
.35864 .63171 m .36072 .63378 L .35901 .63004 L F
.379 .299 .64 r
.35864 .63171 m .35899 .63519 L .36072 .63378 L F
.611 .398 .568 r
.32912 .59312 m .33237 .59 L .33007 .59128 L F
.501 .282 .513 r
.31927 .56148 m .31638 .56427 L .31678 .56218 L F
.857 .514 0 r
.41769 .56812 m .41686 .56739 L .41624 .56457 L F
.803 .379 0 r
.41769 .56812 m .41781 .56966 L .41686 .56739 L F
.41769 .56812 m .41886 .57071 L .41781 .56966 L F
.733 .633 .748 r
.36015 .63442 m .36205 .63738 L .36072 .63378 L F
0 .032 .555 r
.36037 .63685 m .36038 .63718 L .3596 .63475 L F
.36038 .63718 m .36044 .64179 L .35969 .63551 L F
.36038 .63718 m .35969 .63551 L .3596 .63475 L F
.72 .418 .467 r
.36146 .63981 m .36205 .63738 L .36041 .63726 L F
0 .032 .555 r
.36146 .63981 m .36076 .64116 L .36037 .63685 L F
.36076 .64116 m .36044 .64179 L .36037 .63685 L F
.72 .418 .467 r
.36146 .63981 m .36041 .63726 L .35779 .63705 L F
0 .032 .555 r
.36146 .63981 m .36037 .63685 L .36205 .63738 L F
.36037 .63685 m .3596 .63475 L .36205 .63738 L F
.733 .633 .748 r
.35779 .63705 m .36041 .63726 L .36037 .63685 L F
.3585 .63626 m .36037 .63685 L .36015 .63442 L F
.35779 .63705 m .36037 .63685 L .3585 .63626 L F
.36041 .63726 m .36205 .63738 L .36015 .63442 L F
.685 .411 .502 r
.36351 .64393 m .36044 .64179 L .36101 .64454 L F
.603 .639 .86 r
.36146 .63981 m .36101 .64454 L .36044 .64179 L F
.989 .857 .494 r
.65327 .41002 m .65437 .4098 L .65316 .41052 L F
.76 .245 0 r
.65512 .40965 m .65437 .4098 L .65414 .40888 L F
0 0 .174 r
.65414 .40888 m .65437 .4098 L .65391 .40537 L F
0 0 .357 r
.65391 .40537 m .65437 .4098 L .65413 .40577 L F
.989 .857 .494 r
.65413 .40577 m .65437 .4098 L .65327 .41002 L F
.76 .245 0 r
.6558 .41017 m .65437 .4098 L .65512 .40965 L F
.16 .69 .862 r
.65845 .41 m .65437 .4098 L .6558 .41017 L F
.908 .93 .553 r
.36184 .61246 m .3606 .61549 L .36178 .61333 L F
.206 .726 .867 r
.36632 .66257 m .36521 .66306 L .36245 .66451 L F
.36632 .66257 m .36761 .66283 L .36521 .66306 L F
.996 .835 .566 r
.5893 .40827 m .5892 .41105 L .58791 .40961 L F
0 0 .506 r
.58791 .40961 m .5892 .41105 L .59001 .41187 L F
0 0 .19 r
.20764 .55929 m .20837 .5603 L .20959 .55844 L F
.20764 .55929 m .20704 .56171 L .20837 .5603 L F
.92 .687 .193 r
.36825 .51436 m .36864 .51678 L .36851 .51668 L F
0 0 .411 r
.36851 .51668 m .36948 .51712 L .36761 .51594 L F
.771 .711 .796 r
.36501 .51391 m .36562 .51707 L .36825 .51436 L F
.36426 .51381 m .36453 .51446 L .36501 .51391 L F
.36453 .51446 m .36562 .51707 L .36501 .51391 L F
.645 .68 .868 r
.36451 .51383 m .36562 .51707 L .36426 .51381 L F
.872 .954 .858 r
.36451 .51383 m .36165 .51713 L .36209 .51729 L F
.36399 .51509 m .36209 .51729 L .36295 .51758 L F
.36451 .51383 m .36209 .51729 L .36399 .51509 L F
.564 .819 .993 r
.36426 .51381 m .36825 .51436 L .36675 .51301 L F
.993 .745 .439 r
.36722 .514 m .3664 .51518 L .36675 .51301 L F
.36851 .51668 m .3664 .51518 L .36722 .514 L F
0 0 .411 r
.36851 .51668 m .36761 .51594 L .3664 .51518 L F
.92 .687 .193 r
.36864 .51678 m .36895 .51873 L .36851 .51668 L F
0 0 .387 r
.36988 .5204 m .36851 .51668 L .36895 .51873 L F
.645 .68 .868 r
.36451 .51383 m .36295 .51758 L .36562 .51707 L F
.993 .745 .439 r
.36851 .51668 m .36675 .51301 L .36825 .51436 L F
0 0 .411 r
.36851 .51668 m .36898 .51758 L .36948 .51712 L F
.36898 .51758 m .36975 .51907 L .36948 .51712 L F
.819 .583 .582 r
.37135 .51708 m .3698 .51682 L .36948 .51712 L F
0 0 .387 r
.36988 .5204 m .36975 .51907 L .36851 .51668 L F
.709 .271 .209 r
.3664 .51518 m .36948 .51712 L .36522 .51688 L F
.819 .583 .582 r
.3698 .51682 m .36639 .51625 L .36948 .51712 L F
.709 .271 .209 r
.3664 .51518 m .36522 .51688 L .36434 .51683 L F
.726 .578 .688 r
.69281 .35083 m .69511 .35037 L .69259 .3534 L F
.631 .442 .608 r
.69511 .35037 m .69535 .353 L .69259 .3534 L F
.616 .361 .509 r
.69893 .35028 m .69535 .353 L .69511 .35037 L F
0 0 0 r
.36561 .60576 m .36329 .60994 L .36481 .60827 L F
.017 0 .027 r
.36561 .60576 m .36626 .60766 L .36793 .60499 L F
.36561 .60576 m .36481 .60827 L .36626 .60766 L F
.673 .574 .736 r
.36558 .60368 m .36561 .60576 L .36828 .60309 L F
.939 .836 .715 r
.71581 .30329 m .71593 .29855 L .71451 .30221 L F
.821 .501 .448 r
.7139 .30467 m .71581 .30329 L .71451 .30221 L F
.7139 .30467 m .71754 .30582 L .71581 .30329 L F
.491 .36 .629 r
.31713 .58101 m .31736 .58377 L .31505 .58431 L F
.329 .204 .554 r
.31736 .58377 m .3157 .58709 L .31505 .58431 L F
.165 0 .245 r
.31074 .59679 m .31029 .59958 L .30815 .6001 L F
.023 0 .082 r
.31029 .59958 m .30811 .60207 L .30815 .6001 L F
.559 .69 .928 r
.61715 .39552 m .61393 .39277 L .61544 .394 L F
.769 .753 .838 r
.61544 .394 m .61918 .39434 L .61715 .39552 L F
0 0 .132 r
.34011 .53333 m .33927 .53626 L .33801 .53708 L F
.392 .133 .397 r
.33952 .53883 m .33801 .53708 L .33927 .53626 L F
.33952 .53883 m .33729 .53954 L .33801 .53708 L F
.354 .812 .934 r
.31947 .53091 m .31426 .53101 L .317 .53193 L F
.884 .756 .716 r
.68919 .3478 m .68864 .3503 L .68741 .34645 L F
.393 .849 .796 r
.71943 .34125 m .72117 .34017 L .7222 .34143 L F
.118 0 0 r
.34183 .59395 m .34307 .59475 L .34164 .59399 L F
.709 .931 .963 r
.34311 .5936 m .34404 .59424 L .34479 .59313 L F
.118 0 0 r
.34273 .59375 m .34214 .59399 L .34183 .59395 L F
.709 .931 .963 r
.34184 .59395 m .34214 .59399 L .34311 .5936 L F
.34214 .59399 m .34318 .59365 L .34273 .59375 L F
.118 0 0 r
.34484 .59329 m .34214 .59399 L .34273 .59375 L F
.34484 .59329 m .34273 .59375 L .34184 .59395 L F
.34273 .59375 m .34164 .59399 L .34184 .59395 L F
.709 .931 .963 r
.34214 .59399 m .34404 .59424 L .34318 .59365 L F
.34273 .59375 m .34318 .59365 L .34311 .5936 L F
.118 0 0 r
.34484 .59329 m .34375 .5942 L .34214 .59399 L F
0 .499 .702 r
.34143 .5939 m .34404 .59424 L .34214 .59399 L F
.118 0 0 r
.34375 .5942 m .34307 .59475 L .34183 .59395 L F
0 .499 .702 r
.33955 .59366 m .34143 .5939 L .34184 .59395 L F
.34143 .5939 m .34214 .59399 L .34184 .59395 L F
.67 .91 .581 r
.34479 .59313 m .34404 .59424 L .34665 .59106 L F
.334 0 .17 r
.26121 .5532 m .26334 .55422 L .26534 .5529 L F
.489 .021 .071 r
.26334 .55422 m .26775 .55259 L .26534 .5529 L F
.251 0 .272 r
.31239 .59853 m .31074 .59679 L .31258 .59575 L F
.31239 .59853 m .31029 .59958 L .31074 .59679 L F
.008 0 0 r
.34609 .64701 m .34165 .65011 L .3439 .64955 L F
.503 .023 .05 r
.3463 .64903 m .34609 .64701 L .3439 .64955 L F
0 0 .067 r
.33217 .52732 m .33291 .52841 L .33278 .52569 L F
.33217 .52732 m .33167 .52975 L .33291 .52841 L F
.335 .012 .26 r
.30186 .58979 m .30508 .58642 L .30192 .58803 L F
.757 .289 .136 r
.62142 .44832 m .62006 .44963 L .61794 .44729 L F
0 0 0 r
.62401 .44937 m .62006 .44963 L .62142 .44832 L F
.917 .523 .22 r
.31678 .57273 m .31856 .57246 L .3142 .57263 L F
.182 .702 .88 r
.31678 .57273 m .3153 .57237 L .31916 .57263 L F
.917 .523 .22 r
.31678 .57273 m .3142 .57263 L .31408 .57292 L F
0 0 0 r
.31408 .57292 m .31284 .57541 L .31487 .57281 L F
.31408 .57292 m .31522 .57237 L .31678 .57273 L F
.31489 .57253 m .31487 .57281 L .31522 .57237 L F
.31408 .57292 m .31487 .57281 L .31489 .57253 L F
.772 .484 .498 r
.31693 .57102 m .31522 .57237 L .31507 .56968 L F
.31916 .57263 m .3155 .57239 L .31693 .57102 L F
.3155 .57239 m .31522 .57237 L .31693 .57102 L F
.439 .213 .473 r
.31587 .57233 m .31521 .57266 L .31705 .57214 L F
.31521 .57266 m .31423 .57316 L .31497 .57289 L F
.182 .702 .88 r
.31678 .57273 m .31538 .5724 L .31541 .5724 L F
.439 .213 .473 r
.31521 .57266 m .31497 .57289 L .31705 .57214 L F
.31705 .57214 m .31487 .57293 L .31626 .57331 L F
.31487 .57293 m .31423 .57316 L .31485 .57321 L F
.31487 .57293 m .31485 .57321 L .31626 .57331 L F
.31746 .57152 m .31587 .57233 L .31705 .57214 L F
.182 .702 .88 r
.31541 .5724 m .31522 .57237 L .3153 .57237 L F
.31538 .5724 m .31522 .57237 L .31541 .5724 L F
.917 .523 .22 r
.31678 .57273 m .31915 .5746 L .31877 .57322 L F
.31678 .57273 m .31877 .57322 L .31856 .57246 L F
0 .335 .672 r
.39497 .60056 m .39415 .60028 L .39362 .60206 L F
.39497 .60056 m .39616 .60107 L .39415 .60028 L F
.616 .361 .509 r
.69893 .35028 m .69911 .35261 L .69535 .353 L F
.694 .453 .554 r
.70173 .35025 m .69911 .35261 L .69893 .35028 L F
.875 .859 .822 r
.69184 .3213 m .68896 .3214 L .69057 .31961 L F
.875 .864 .825 r
.69427 .31795 m .69184 .3213 L .69057 .31961 L F
.723 .317 .28 r
.3794 .60607 m .38257 .60657 L .3816 .60774 L F
.399 .771 .993 r
.38387 .60537 m .3856 .60632 L .38257 .60657 L F
.38257 .60657 m .3856 .60632 L .38387 .60537 L F
.522 .305 .526 r
.38254 .60898 m .3856 .60632 L .38257 .60657 L F
.399 .771 .993 r
.38387 .60537 m .38257 .60657 L .38228 .60743 L F
.38257 .60657 m .38196 .60737 L .3816 .60774 L F
.621 .109 .012 r
.38201 .6073 m .38257 .60657 L .3794 .60607 L F
.022 .448 .871 r
.37949 .60497 m .38205 .60723 L .3794 .60607 L F
.38208 .60725 m .38201 .6073 L .3794 .60607 L F
.399 .771 .993 r
.38201 .6073 m .38207 .60725 L .38196 .60737 L F
.7 .786 .918 r
.37949 .60497 m .3816 .60774 L .38207 .60725 L F
.399 .771 .993 r
.38257 .60657 m .38381 .60542 L .38207 .60725 L F
.38381 .60542 m .38387 .60537 L .38245 .60686 L F
.38381 .60542 m .38245 .60686 L .38207 .60725 L F
.621 .109 .012 r
.38228 .60743 m .38257 .60657 L .38201 .6073 L F
.399 .771 .993 r
.38257 .60657 m .38207 .60725 L .38201 .6073 L F
.7 .786 .918 r
.37949 .60497 m .38207 .60725 L .38245 .60686 L F
.715 .787 .908 r
.37949 .60497 m .38206 .6066 L .38196 .60373 L F
.38208 .60725 m .38225 .60706 L .38196 .60373 L F
.7 .786 .918 r
.37949 .60497 m .38245 .60686 L .38387 .60537 L F
.715 .787 .908 r
.37949 .60497 m .38208 .60725 L .38206 .6066 L F
.38208 .60725 m .38228 .60743 L .38225 .60706 L F
.022 .448 .871 r
.37949 .60497 m .38208 .60725 L .38205 .60723 L F
.38208 .60725 m .38228 .60743 L .38201 .6073 L F
.745 .785 .885 r
.6165 .39307 m .61918 .39434 L .61544 .394 L F
.748 .784 .883 r
.622 .3917 m .61918 .39434 L .6165 .39307 L F
0 0 0 r
.28417 .52905 m .28286 .52923 L .28562 .52808 L F
.28417 .52905 m .28188 .53002 L .28286 .52923 L F
.632 .592 .791 r
.38564 .54852 m .38619 .55189 L .38364 .55188 L F
.207 .538 .926 r
.2095 .60109 m .21002 .59975 L .20846 .59968 L F
.2095 .60109 m .21278 .60242 L .21002 .59975 L F
.722 .676 .805 r
.68741 .34645 m .68864 .3503 L .68464 .34968 L F
.748 .597 .689 r
.68864 .3503 m .68625 .35336 L .68464 .34968 L F
.706 .537 .657 r
.68864 .3503 m .69049 .35404 L .68625 .35336 L F
.743 .593 .688 r
.69281 .35083 m .69049 .35404 L .68864 .3503 L F
.334 0 .17 r
.26121 .5532 m .2609 .55488 L .26334 .55422 L F
.405 0 0 r
.62782 .44856 m .62663 .44961 L .62401 .44937 L F
.515 0 0 r
.62782 .44856 m .63025 .44975 L .62663 .44961 L F
.516 .121 .231 r
.62782 .44856 m .63028 .44872 L .63025 .44975 L F
.497 .702 .961 r
.35139 .56449 m .35096 .5668 L .34906 .56505 L F
.35139 .56449 m .35308 .566 L .35096 .5668 L F
.587 .586 .819 r
.35411 .56782 m .35096 .5668 L .35308 .566 L F
.079 .392 .851 r
.34434 .60324 m .34354 .60345 L .3458 .60435 L F
.895 .622 .517 r
.29571 .64801 m .29654 .64706 L .2949 .64426 L F
0 0 0 r
.29488 .64952 m .29654 .64706 L .29571 .64801 L F
.801 .308 0 r
.299 .64919 m .2949 .64426 L .29654 .64706 L F
.761 .889 .481 r
.2982 .65039 m .29654 .64706 L .29488 .64952 L F
.2982 .65039 m .299 .64919 L .29654 .64706 L F
.779 .57 .617 r
.3025 .52741 m .30277 .53082 L .30632 .53079 L F
.419 .832 .971 r
.30277 .53082 m .30492 .53015 L .30632 .53079 L F
.038 .236 .737 r
.30707 .52889 m .30632 .53079 L .30492 .53015 L F
.473 .327 .601 r
.30632 .53079 m .30868 .53315 L .30878 .52991 L F
.038 .236 .737 r
.30707 .52889 m .30868 .53315 L .30632 .53079 L F
.812 .686 .726 r
.42007 .52149 m .41683 .52089 L .41895 .51811 L F
.699 .402 .468 r
.42007 .52149 m .41633 .52353 L .41683 .52089 L F
.42007 .52149 m .41844 .52345 L .41633 .52353 L F
.649 .598 .784 r
.42276 .52101 m .42007 .52149 L .41895 .51811 L F
.673 .428 .543 r
.42276 .52101 m .41844 .52345 L .42007 .52149 L F
.158 0 0 r
.38151 .70783 m .38208 .70899 L .38027 .70998 L F
.38151 .70783 m .38391 .70732 L .38208 .70899 L F
.77 .986 .747 r
.56648 .41513 m .56761 .41476 L .56581 .41666 L F
.422 0 0 r
.56648 .41513 m .57036 .4157 L .56761 .41476 L F
.19 .44 .868 r
.23272 .61751 m .23335 .61957 L .23395 .61793 L F
.181 .429 .862 r
.23335 .61957 m .23635 .62117 L .23395 .61793 L F
.296 .027 .324 r
.39414 .70002 m .39249 .69806 L .39458 .69731 L F
.39414 .70002 m .39196 .70107 L .39249 .69806 L F
.802 .916 .916 r
.30066 .52733 m .29997 .53062 L .3025 .52741 L F
.30066 .52733 m .29833 .5296 L .29997 .53062 L F
.517 .035 .051 r
.29918 .53127 m .29997 .53062 L .29833 .5296 L F
.29918 .53127 m .30277 .53082 L .29997 .53062 L F
.6 .436 .63 r
.29997 .53062 m .30277 .53082 L .3025 .52741 L F
.639 .921 .641 r
.64827 .41966 m .64456 .42338 L .64704 .42051 L F
.168 .138 .578 r
.64456 .42338 m .64657 .42303 L .64704 .42051 L F
.64456 .42338 m .64527 .42579 L .64657 .42303 L F
.669 .179 .076 r
.28791 .65003 m .29204 .65067 L .2904 .65195 L F
0 .114 .575 r
.28791 .65003 m .28894 .65077 L .28851 .65032 L F
.374 0 0 r
.2876 .64989 m .28924 .64951 L .28791 .65003 L F
.568 .017 0 r
.28924 .64951 m .29204 .65067 L .28791 .65003 L F
0 .114 .575 r
.28791 .65003 m .28851 .65032 L .28687 .64857 L F
.374 0 0 r
.28585 .65029 m .2876 .64989 L .28791 .65003 L F
.765 .831 .903 r
.29717 .6304 m .29817 .63136 L .29448 .63097 L F
.68 .186 .069 r
.29655 .63289 m .29817 .63136 L .29448 .63097 L F
.864 .836 .816 r
.29717 .6304 m .29817 .63136 L .30074 .62765 L F
.903 .515 .273 r
.29655 .63289 m .29936 .63396 L .29817 .63136 L F
0 .219 .732 r
.2292 .61642 m .22992 .61487 L .22775 .61306 L F
.456 .634 .931 r
.23063 .61818 m .22992 .61487 L .2292 .61642 L F
.551 .413 .646 r
.3409 .58137 m .34137 .58381 L .34352 .57992 L F
.395 .85 .89 r
.56667 .40736 m .56497 .40891 L .56658 .41011 L F
.56667 .40736 m .56304 .40815 L .56497 .40891 L F
.332 .04 .309 r
.39033 .58156 m .38919 .58441 L .38734 .58433 L F
0 0 0 r
.39067 .58164 m .39033 .58156 L .39253 .5802 L F
.39067 .58164 m .38919 .58441 L .39033 .58156 L F
.661 .251 .256 r
.56133 .41647 m .56581 .41666 L .56471 .41864 L F
.37 .587 .928 r
.56581 .41666 m .56836 .41733 L .56648 .41513 L F
.682 .815 .368 r
.56471 .41864 m .56581 .41666 L .56648 .41513 L F
.066 .105 .592 r
.36329 .60994 m .36586 .61361 L .36481 .60827 L F
.893 .988 .776 r
.33362 .50255 m .33187 .50499 L .33119 .50366 L F
.33362 .50255 m .33119 .50366 L .33165 .50112 L F
.997 .774 .469 r
.33165 .50112 m .33119 .50366 L .32994 .50236 L F
0 .272 .672 r
.33314 .50413 m .33076 .50281 L .33119 .50366 L F
.33076 .50281 m .32994 .50236 L .33119 .50366 L F
.893 .988 .776 r
.33187 .50499 m .33177 .50512 L .33119 .50366 L F
0 0 .373 r
.33177 .50512 m .33297 .50732 L .33119 .50366 L F
0 0 0 r
.22321 .54241 m .22469 .54222 L .22639 .5413 L F
.22639 .5413 m .22666 .54118 L .22897 .54025 L F
.22639 .5413 m .22469 .54222 L .22666 .54118 L F
.589 .844 .486 r
.32544 .68218 m .32291 .68538 L .32312 .68518 L F
.716 .448 .518 r
.38164 .59061 m .37832 .5928 L .37872 .59119 L F
.623 .487 .676 r
.27434 .54945 m .27649 .54973 L .27675 .54619 L F
.465 .257 .512 r
.27642 .55154 m .27434 .54945 L .27649 .54973 L F
.27642 .55154 m .27417 .55215 L .27434 .54945 L F
.27642 .55154 m .27434 .54945 L .27649 .54973 L F
.27642 .55154 m .27417 .55215 L .27434 .54945 L F
.852 .601 .559 r
.34847 .54325 m .3445 .53975 L .34804 .53996 L F
.409 .329 .654 r
.35067 .54216 m .34804 .53996 L .35072 .53973 L F
.35067 .54216 m .34847 .54325 L .34822 .54135 L F
.34906 .54081 m .34822 .54135 L .34804 .53996 L F
.35067 .54216 m .34822 .54135 L .34906 .54081 L F
0 0 0 r
.35179 .53905 m .34886 .54096 L .35024 .54005 L F
.453 .212 .457 r
.35072 .53973 m .3531 .53935 L .3534 .53667 L F
0 0 0 r
.35127 .53938 m .35024 .54005 L .35072 .53973 L F
.35179 .53905 m .35024 .54005 L .35127 .53938 L F
0 0 .295 r
.34886 .54096 m .34804 .53996 L .34977 .53981 L F
.34886 .54096 m .34847 .54325 L .34804 .53996 L F
.48 .483 .783 r
.34863 .53806 m .34843 .54151 L .34886 .54096 L F
.34843 .54151 m .34832 .54344 L .34886 .54096 L F
0 0 .295 r
.34886 .54096 m .34977 .53981 L .35072 .53973 L F
.545 .429 .672 r
.71626 .29386 m .71258 .29539 L .71512 .29228 L F
.685 .638 .796 r
.71772 .28941 m .71626 .29386 L .71512 .29228 L F
.71772 .28941 m .71898 .29329 L .71626 .29386 L F
.664 .518 .676 r
.71626 .29386 m .71898 .29329 L .7165 .29651 L F
.946 .602 .331 r
.61769 .44526 m .61643 .44653 L .61575 .44429 L F
.61769 .44526 m .61794 .44729 L .61643 .44653 L F
.88 .494 .302 r
.35239 .52906 m .35379 .53129 L .35603 .53131 L F
.703 .486 .59 r
.35581 .53301 m .35344 .53409 L .35603 .53131 L F
.35581 .53301 m .35344 .53409 L .35603 .53131 L F
.951 .731 .569 r
.35379 .53129 m .35581 .53301 L .35603 .53131 L F
.876 .943 .856 r
.35603 .53131 m .35379 .53129 L .35592 .52816 L F
.563 .429 .656 r
.35848 .53068 m .35581 .53301 L .35603 .53131 L F
.469 .301 .57 r
.35842 .52725 m .35848 .53068 L .35603 .53131 L F
.503 .75 .984 r
.62778 .44017 m .62906 .44182 L .62643 .44208 L F
.871 .593 .514 r
.42373 .5843 m .42155 .58391 L .42139 .58121 L F
.811 .525 .504 r
.42376 .58621 m .42155 .58391 L .42373 .5843 L F
.688 .354 .405 r
.42373 .5843 m .42628 .58687 L .42376 .58621 L F
.621 .367 .511 r
.4269 .58417 m .42628 .58687 L .42373 .5843 L F
.559 .591 .843 r
.34214 .58799 m .34272 .58399 L .34137 .58381 L F
.996 .835 .566 r
.5893 .40827 m .58581 .40721 L .58839 .40632 L F
.5893 .40827 m .58791 .40961 L .58581 .40721 L F
.389 .599 .93 r
.59078 .40692 m .5893 .40827 L .58839 .40632 L F
.59078 .40692 m .59326 .40944 L .5893 .40827 L F
.523 .876 .986 r
.3892 .55709 m .38681 .55791 L .3878 .5586 L F
.087 .198 .685 r
.3892 .55709 m .3878 .5586 L .38681 .55791 L F
.428 .838 .97 r
.29447 .52055 m .29534 .51954 L .29664 .52004 L F
.512 .914 .875 r
.29447 .52055 m .29325 .52062 L .29534 .51954 L F
.632 .396 .543 r
.38734 .58433 m .38731 .5869 L .38465 .58672 L F
.624 .533 .731 r
.38919 .58441 m .38731 .5869 L .38734 .58433 L F
.684 .963 .94 r
.23183 .58324 m .22961 .58472 L .23008 .58348 L F
.576 .241 .365 r
.22764 .58374 m .23008 .58348 L .22961 .58472 L F
.574 .293 .453 r
.58362 .442 m .58359 .44419 L .58018 .44459 L F
.625 .4 .555 r
.58628 .44154 m .58359 .44419 L .58362 .442 L F
.322 .075 .375 r
.28981 .60907 m .29265 .6056 L .29015 .60632 L F
.547 .449 .695 r
.39001 .5971 m .39229 .59316 L .38968 .59431 L F
.656 .824 .964 r
.41131 .52761 m .40734 .52727 L .40969 .52573 L F
.432 .278 .572 r
.29918 .59595 m .30227 .5922 L .29981 .59347 L F
.686 .584 .736 r
.2391 .59892 m .24006 .60334 L .24265 .60019 L F
.589 .568 .798 r
.32552 .60335 m .32839 .60352 L .32707 .59938 L F
.567 .223 .345 r
.32552 .60335 m .32776 .6053 L .32537 .60585 L F
.32552 .60335 m .32776 .6053 L .32537 .60585 L F
.118 0 0 r
.20484 .56248 m .2036 .56397 L .20704 .56171 L F
0 .127 .674 r
.21515 .60659 m .21515 .60452 L .21278 .60242 L F
.21515 .60659 m .21558 .60624 L .21515 .60452 L F
.7 .555 .687 r
.3247 .62856 m .32713 .62537 L .32314 .62487 L F
0 0 0 r
.40034 .61561 m .39978 .61768 L .3983 .6191 L F
0 0 .099 r
.39978 .61768 m .39804 .62166 L .3983 .6191 L F
.715 .82 .93 r
.33539 .50061 m .33362 .50255 L .33165 .50112 L F
.051 .229 .728 r
.24745 .61708 m .24681 .61889 L .2455 .61531 L F
.366 .602 .938 r
.24745 .61708 m .24884 .61906 L .24681 .61889 L F
.157 0 .288 r
.31523 .58973 m .31492 .5925 L .31279 .59291 L F
.286 .015 .315 r
.31461 .59504 m .31279 .59291 L .31492 .5925 L F
.31461 .59504 m .31258 .59575 L .31279 .59291 L F
.977 .737 .32 r
.37061 .52362 m .36988 .5204 L .37209 .52148 L F
.452 .311 .598 r
.32413 .52119 m .32628 .52053 L .32624 .5178 L F
.375 .154 .446 r
.32392 .52357 m .32628 .52053 L .32413 .52119 L F
.972 .66 .347 r
.29442 .64868 m .2949 .64426 L .29344 .64392 L F
.29442 .64868 m .29571 .64801 L .2949 .64426 L F
.597 .934 .952 r
.29344 .64392 m .2949 .64426 L .29564 .64278 L F
.564 .708 .938 r
.64475 .39468 m .64237 .39532 L .64139 .39345 L F
.457 .393 .697 r
.3568 .62561 m .35944 .62758 L .35925 .62512 L F
.743 .593 .688 r
.69281 .35083 m .69259 .3534 L .69049 .35404 L F
.847 .689 .686 r
.39804 .58745 m .39906 .5904 L .39702 .59111 L F
.385 0 0 r
.39702 .59111 m .39906 .5904 L .39748 .59187 L F
.496 .013 .038 r
.39906 .5904 m .40014 .59212 L .39748 .59187 L F
.39906 .5904 m .40181 .5904 L .40014 .59212 L F
.208 0 .334 r
.21016 .55599 m .20959 .55844 L .21191 .5551 L F
.456 .527 .842 r
.35604 .5966 m .35392 .59701 L .35271 .59429 L F
.441 .409 .727 r
.35604 .5966 m .35684 .59933 L .35392 .59701 L F
.481 .409 .698 r
.35684 .59933 m .35492 .60043 L .35392 .59701 L F
.64 .4 .539 r
.3856 .60632 m .389 .6049 L .38811 .60289 L F
.331 .741 .979 r
.58426 .42963 m .58749 .42951 L .58663 .42776 L F
.58426 .42963 m .58823 .4301 L .58749 .42951 L F
.871 .761 .739 r
.58663 .42776 m .58749 .42951 L .58831 .42689 L F
.334 .199 .543 r
.58831 .42689 m .58749 .42951 L .58908 .42949 L F
.469 .465 .771 r
.28167 .53743 m .28263 .54047 L .28435 .53927 L F
.597 .415 .606 r
.28169 .54229 m .28435 .53927 L .28263 .54047 L F
.842 .835 .839 r
.2173 .58037 m .21925 .58106 L .22156 .57821 L F
.937 .603 .375 r
.21791 .58239 m .21925 .58106 L .2173 .58037 L F
.21791 .58239 m .2192 .5834 L .21925 .58106 L F
.787 .287 0 r
.22797 .60379 m .22785 .60202 L .22713 .60198 L F
.22797 .60379 m .22993 .60475 L .22785 .60202 L F
.476 .494 .797 r
.32067 .65627 m .31833 .65726 L .31723 .65531 L F
.031 0 .425 r
.31945 .65897 m .31833 .65726 L .32067 .65627 L F
.11 0 .147 r
.31945 .65897 m .32221 .65593 L .32161 .65761 L F
.542 .927 .85 r
.32073 .6579 m .31945 .65897 L .32161 .65761 L F
.031 0 .425 r
.31945 .65897 m .31784 .6603 L .31833 .65726 L F
.378 .128 .404 r
.31945 .65897 m .32067 .65627 L .32221 .65593 L F
.447 .517 .837 r
.32127 .65502 m .31723 .65531 L .31545 .65437 L F
.32127 .65502 m .32067 .65627 L .31723 .65531 L F
.241 .698 .951 r
.31732 .65429 m .32127 .65502 L .31545 .65437 L F
0 .498 .735 r
.32238 .65515 m .32186 .65509 L .32201 .65509 L F
.493 .572 .864 r
.32221 .65593 m .32127 .65502 L .32238 .65515 L F
.209 .615 .95 r
.32201 .65509 m .32221 .65593 L .32238 .65515 L F
0 .031 .593 r
.32423 .65824 m .32221 .65593 L .32201 .65509 L F
.209 .615 .95 r
.32191 .65468 m .32201 .65509 L .32238 .65515 L F
.45 .768 .997 r
.32191 .65468 m .32238 .65515 L .32205 .65508 L F
0 .031 .593 r
.32206 .6551 m .32201 .65509 L .32191 .65468 L F
.45 .768 .997 r
.32191 .65468 m .32205 .65508 L .31877 .65429 L F
0 .031 .593 r
.32219 .6551 m .32206 .6551 L .32191 .65468 L F
.32423 .65824 m .32201 .65509 L .32219 .6551 L F
0 .498 .735 r
.32201 .65509 m .32127 .65502 L .31882 .65457 L F
.32186 .65509 m .32127 .65502 L .32201 .65509 L F
.32238 .65515 m .31882 .65457 L .31732 .65429 L F
.32238 .65515 m .31732 .65429 L .31877 .65429 L F
.6 .543 .762 r
.31811 .65923 m .31877 .65429 L .31732 .65429 L F
.31824 .66006 m .31834 .65903 L .31811 .65923 L F
.542 .927 .85 r
.31978 .65822 m .32161 .65761 L .32047 .65881 L F
.31978 .65822 m .31945 .65897 L .32073 .6579 L F
.31908 .65862 m .31945 .65897 L .31978 .65822 L F
.498 0 0 r
.31882 .66192 m .32044 .66296 L .31931 .66209 L F
.31882 .66192 m .31931 .66209 L .31774 .66087 L F
.31882 .66192 m .31774 .66087 L .31846 .66007 L F
.31882 .66192 m .31846 .66007 L .31945 .65897 L F
.6 .543 .762 r
.31867 .65955 m .32043 .65877 L .31978 .65822 L F
.031 0 .425 r
.31945 .65897 m .31774 .66087 L .31784 .6603 L F
.6 .543 .762 r
.31824 .66006 m .31866 .65981 L .31867 .65955 L F
.977 .844 .447 r
.31882 .66192 m .31945 .65897 L .31924 .65893 L F
.31873 .65971 m .31924 .65893 L .3187 .65883 L F
.31882 .66192 m .31924 .65893 L .31873 .65971 L F
0 0 0 r
.31908 .66027 m .32043 .65877 L .31866 .65981 L F
.6 .543 .762 r
.31866 .65981 m .32043 .65877 L .31867 .65955 L F
.977 .844 .447 r
.31882 .66192 m .3187 .65883 L .31863 .66094 L F
.542 .927 .85 r
.3187 .65883 m .31945 .65897 L .31908 .65862 L F
.6 .543 .762 r
.31824 .66006 m .31978 .65822 L .31834 .65903 L F
.31834 .65903 m .31978 .65822 L .31851 .65715 L F
.542 .927 .85 r
.31895 .65849 m .31908 .65862 L .31978 .65822 L F
.31895 .65849 m .31978 .65822 L .31942 .65989 L F
.31941 .6599 m .31942 .65989 L .31942 .65991 L F
.31895 .65849 m .31942 .65989 L .31941 .6599 L F
.6 .543 .762 r
.32043 .65877 m .32064 .65865 L .31851 .65715 L F
.32064 .65865 m .32102 .65843 L .32092 .65838 L F
.32064 .65865 m .32092 .65838 L .31851 .65715 L F
.168 .607 .938 r
.32161 .65761 m .32171 .65754 L .32064 .65865 L F
.32047 .65881 m .32064 .65865 L .31908 .66027 L F
.32161 .65761 m .32064 .65865 L .32047 .65881 L F
0 0 0 r
.31908 .66027 m .32102 .65843 L .32064 .65865 L F
.614 .27 .363 r
.32161 .65761 m .32221 .65593 L .32423 .65824 L F
.168 .607 .938 r
.32161 .65761 m .32423 .65824 L .32247 .65699 L F
0 .084 .643 r
.31877 .65429 m .32097 .65834 L .32072 .65599 L F
.32097 .65834 m .32102 .65843 L .321 .65832 L F
.32097 .65834 m .321 .65832 L .32072 .65599 L F
.168 .607 .938 r
.32171 .65754 m .32247 .65699 L .32129 .65813 L F
.32088 .6584 m .321 .65832 L .31908 .66027 L F
.542 .927 .85 r
.31978 .65822 m .32047 .65881 L .31942 .65991 L F
0 0 0 r
.31908 .66027 m .32064 .65865 L .32043 .65877 L F
.6 .543 .762 r
.31851 .65715 m .32017 .658 L .31877 .65429 L F
.32017 .658 m .32102 .65843 L .32064 .65774 L F
.32017 .658 m .32064 .65774 L .31877 .65429 L F
.542 .927 .85 r
.31895 .65849 m .31942 .65991 L .31908 .66027 L F
0 0 0 r
.31847 .66011 m .31866 .65981 L .31824 .66006 L F
.31908 .66027 m .31866 .65981 L .31847 .66011 L F
.977 .844 .447 r
.31863 .66094 m .3187 .65883 L .31821 .65874 L F
.581 .421 .63 r
.31559 .66003 m .31824 .66006 L .31732 .65429 L F
.472 .716 .976 r
.31821 .65874 m .31824 .66006 L .31559 .66003 L F
.977 .844 .447 r
.31882 .66192 m .31821 .65874 L .31509 .66122 L F
.542 .927 .85 r
.31859 .65881 m .3187 .65883 L .31895 .65849 L F
.3187 .65883 m .31908 .65862 L .31895 .65849 L F
.31821 .65874 m .31859 .65881 L .31895 .65849 L F
.31821 .65874 m .31895 .65849 L .31908 .66027 L F
.797 .656 .707 r
.31509 .66122 m .31786 .66476 L .31882 .66192 L F
0 0 0 r
.31908 .66027 m .31824 .66006 L .31821 .65874 L F
.921 .975 .756 r
.31996 .65798 m .321 .65832 L .31908 .66027 L F
.32072 .65599 m .32088 .65735 L .31996 .65798 L F
.32088 .65735 m .321 .65832 L .31996 .65798 L F
.321 .65832 m .32102 .65843 L .31908 .66027 L F
.168 .607 .938 r
.321 .65832 m .32129 .65813 L .31908 .66027 L F
.32171 .65754 m .32129 .65813 L .32088 .6584 L F
.921 .975 .756 r
.32072 .65599 m .31908 .66027 L .32247 .65699 L F
.954 .776 .624 r
.31753 .65963 m .31945 .65949 L .31787 .66216 L F
.6 .543 .762 r
.31834 .65903 m .31851 .65715 L .31811 .65923 L F
.31851 .65715 m .31842 .65689 L .31811 .65923 L F
.472 .716 .976 r
.31821 .65874 m .31559 .66003 L .31509 .66122 L F
.954 .776 .624 r
.31728 .6578 m .31865 .65887 L .31753 .65963 L F
.31865 .65887 m .31945 .65949 L .31753 .65963 L F
.004 .306 .799 r
.31821 .66172 m .31882 .66192 L .31721 .66339 L F
.31908 .66027 m .31882 .66192 L .31821 .66172 L F
.6 .543 .762 r
.31851 .65715 m .31877 .65429 L .31842 .65689 L F
.814 .443 .354 r
.55904 .43799 m .56278 .439 L .56306 .44104 L F
.727 .301 .237 r
.56278 .439 m .56676 .44142 L .56306 .44104 L F
.06 .228 .723 r
.35186 .53563 m .35048 .53546 L .35344 .53409 L F
.652 .957 .939 r
.64142 .42938 m .6397 .43139 L .63922 .43094 L F
.64142 .42938 m .64331 .42959 L .6397 .43139 L F
0 0 0 r
.42706 .56106 m .4266 .56448 L .42914 .56277 L F
.42706 .56106 m .42674 .56385 L .4266 .56448 L F
0 .206 .709 r
.42674 .56385 m .42851 .56589 L .4266 .56448 L F
.581 .719 .938 r
.58831 .42689 m .58286 .42555 L .58675 .42611 L F
.362 .678 .977 r
.58498 .42459 m .58696 .42614 L .58477 .42582 L F
.58498 .42459 m .58477 .42582 L .58286 .42555 L F
.873 .977 .675 r
.58554 .4227 m .58498 .42459 L .58434 .42447 L F
.796 .866 .425 r
.58518 .42345 m .58498 .42459 L .58554 .4227 L F
.362 .678 .977 r
.58498 .42459 m .58286 .42555 L .58215 .42503 L F
.859 .829 .816 r
.58426 .42963 m .58498 .42459 L .58215 .42503 L F
.459 .777 .998 r
.58078 .42386 m .58215 .42503 L .58498 .42459 L F
.58498 .42459 m .58078 .42386 L .58434 .42447 L F
.81 .672 .71 r
.58089 .4255 m .5834 .4282 L .57946 .42756 L F
.459 .777 .998 r
.58078 .42386 m .58498 .42459 L .58407 .42581 L F
.58078 .42386 m .58407 .42581 L .58386 .42579 L F
.58078 .42386 m .58401 .42589 L .58389 .42587 L F
.464 .258 .514 r
.58215 .42503 m .57965 .42593 L .58078 .42386 L F
.591 .84 .992 r
.58078 .42386 m .57965 .42593 L .58215 .42503 L F
.537 .485 .745 r
.58275 .41994 m .58078 .42386 L .57953 .42003 L F
.58275 .41994 m .58434 .42447 L .58078 .42386 L F
0 .274 .771 r
.57959 .42215 m .58078 .42386 L .58389 .42587 L F
.57959 .42215 m .58389 .42587 L .58376 .42574 L F
.459 .777 .998 r
.58386 .42579 m .58407 .42581 L .58401 .42589 L F
0 .274 .771 r
.57959 .42215 m .58376 .42574 L .58183 .42414 L F
.773 .655 .732 r
.58183 .42414 m .58356 .42557 L .58241 .42565 L F
0 .274 .771 r
.58376 .42574 m .58398 .42593 L .58183 .42414 L F
.773 .655 .732 r
.58183 .42414 m .58417 .42552 L .58356 .42557 L F
.859 .829 .816 r
.58426 .42963 m .58546 .42552 L .58489 .42525 L F
.773 .655 .732 r
.58417 .42552 m .58504 .42604 L .58401 .42589 L F
.58417 .42552 m .58401 .42589 L .58241 .42565 L F
.796 .866 .425 r
.58409 .42571 m .58498 .42459 L .58518 .42345 L F
.58398 .42593 m .58401 .42589 L .58409 .42571 L F
.58401 .42589 m .58498 .42459 L .58409 .42571 L F
0 .274 .771 r
.58376 .42574 m .58389 .42587 L .58398 .42593 L F
.859 .829 .816 r
.58489 .42525 m .58546 .42552 L .58498 .42459 L F
.809 .814 .854 r
.58498 .42459 m .58663 .42776 L .58696 .42614 L F
.773 .655 .732 r
.58432 .42561 m .58586 .42494 L .58504 .42604 L F
.796 .866 .425 r
.58398 .42593 m .58409 .42571 L .58586 .42494 L F
.58409 .42571 m .58554 .4227 L .58586 .42494 L F
.773 .655 .732 r
.58271 .42466 m .58586 .42494 L .58432 .42561 L F
.58183 .42414 m .58229 .42423 L .58271 .42466 L F
.58229 .42423 m .58586 .42494 L .58271 .42466 L F
.81 .672 .71 r
.58183 .42414 m .58241 .42565 L .58089 .4255 L F
.58241 .42565 m .5834 .4282 L .58089 .4255 L F
.773 .655 .732 r
.58241 .42565 m .58504 .42604 L .5834 .4282 L F
.459 .777 .998 r
.58389 .42587 m .58401 .42589 L .58398 .42593 L F
.859 .829 .816 r
.58426 .42963 m .58663 .42776 L .58546 .42552 L F
.581 .719 .938 r
.58764 .42651 m .58675 .42611 L .58696 .42614 L F
.58831 .42689 m .58675 .42611 L .58764 .42651 L F
.871 .761 .739 r
.58663 .42776 m .58831 .42689 L .58696 .42614 L F
.634 .565 .759 r
.32625 .54424 m .32638 .54597 L .32932 .54383 L F
.799 .95 .919 r
.33485 .66242 m .33137 .66379 L .33429 .66314 L F
.776 .938 .588 r
.33654 .65934 m .33485 .66242 L .33621 .66191 L F
0 0 0 r
.33621 .66191 m .33485 .66242 L .33429 .66314 L F
.711 .598 .727 r
.36427 .59998 m .36558 .60368 L .36132 .60292 L F
.406 .742 .993 r
.36132 .60292 m .36558 .60368 L .36411 .60272 L F
.323 .367 .753 r
.36695 .60208 m .36558 .60368 L .36427 .59998 L F
.623 .829 .98 r
.36411 .60272 m .36558 .60368 L .36695 .60208 L F
.888 .853 .803 r
.69401 .31446 m .69427 .31795 L .69162 .31812 L F
.875 .864 .825 r
.69427 .31795 m .69057 .31961 L .69162 .31812 L F
.867 .84 .816 r
.69672 .31473 m .69427 .31795 L .69401 .31446 L F
.878 .822 .789 r
.69617 .31136 m .69672 .31473 L .69401 .31446 L F
.851 .807 .807 r
.69795 .31308 m .69672 .31473 L .69617 .31136 L F
.368 .194 .509 r
.40202 .68176 m .4019 .68497 L .39963 .68565 L F
.313 .065 .369 r
.4019 .68497 m .39942 .6879 L .39963 .68565 L F
.857 .806 .799 r
.70021 .30983 m .69617 .31136 L .69836 .30804 L F
.70021 .30983 m .69795 .31308 L .69617 .31136 L F
.831 .759 .783 r
.70248 .3064 m .70021 .30983 L .69836 .30804 L F
.033 .276 .772 r
.62391 .43168 m .62624 .43438 L .62752 .43261 L F
.528 .127 .224 r
.63027 .43401 m .62752 .43261 L .62624 .43438 L F
.792 .636 .688 r
.70565 .35068 m .70164 .35274 L .70173 .35025 L F
.70565 .35068 m .70534 .35327 L .70164 .35274 L F
.885 .454 .129 r
.39208 .5299 m .39363 .53365 L .39498 .53355 L F
.976 .726 .312 r
.39402 .53506 m .39498 .53355 L .39363 .53365 L F
.39402 .53506 m .39498 .53674 L .39498 .53355 L F
.209 0 .187 r
.36829 .58502 m .36966 .58575 L .36863 .5835 L F
.36829 .58502 m .36678 .58671 L .36966 .58575 L F
.011 0 0 r
.3289 .67881 m .32544 .68218 L .32735 .681 L F
.276 0 0 r
.32967 .68045 m .3289 .67881 L .32735 .681 L F
.32967 .68045 m .33141 .67828 L .3289 .67881 L F
.831 .759 .783 r
.70248 .3064 m .69836 .30804 L .70082 .30479 L F
.834 .781 .802 r
.70498 .3031 m .70248 .3064 L .70082 .30479 L F
.722 .895 .512 r
.39044 .63403 m .38825 .63748 L .38837 .63759 L F
.54 .221 .376 r
.33366 .64382 m .3363 .64288 L .33794 .64079 L F
.715 .441 .51 r
.3363 .64288 m .33947 .64201 L .33794 .64079 L F
.621 .81 .972 r
.62687 .38715 m .62446 .38819 L .62328 .38657 L F
.732 .652 .77 r
.62687 .38715 m .62425 .39064 L .62446 .38819 L F
.748 .637 .737 r
.33588 .51725 m .33992 .5179 L .33869 .51428 L F
.754 .611 .699 r
.33588 .51725 m .33738 .51943 L .33992 .5179 L F
.514 .502 .781 r
.33869 .51428 m .33992 .5179 L .34205 .51711 L F
.45 0 0 r
.37031 .65702 m .36809 .65705 L .36629 .65651 L F
.811 .916 .909 r
.37161 .65348 m .37031 .65702 L .37269 .65469 L F
.37161 .65348 m .36809 .65705 L .37031 .65702 L F
.592 .903 .636 r
.64953 .41819 m .64827 .41966 L .64704 .42051 L F
.004 .028 .532 r
.64953 .41819 m .64921 .42096 L .64827 .41966 L F
.64921 .42096 m .64861 .42115 L .64827 .41966 L F
.64953 .41819 m .65002 .42071 L .64899 .4228 L F
.581 .418 .626 r
.64704 .42051 m .65002 .42071 L .64953 .41819 L F
.195 .682 .927 r
.64858 .41995 m .65001 .42071 L .64704 .42051 L F
.65001 .42071 m .65002 .42071 L .65001 .42071 L F
.65001 .42071 m .65001 .42071 L .64704 .42051 L F
.004 .028 .532 r
.64921 .42096 m .64899 .4228 L .64861 .42115 L F
.113 .659 .828 r
.20643 .59974 m .20846 .59968 L .20477 .59952 L F
.633 .718 .908 r
.43 .56099 m .42914 .56277 L .42682 .56057 L F
.721 .825 .93 r
.42706 .56106 m .42914 .56277 L .43 .56099 L F
.617 .819 .978 r
.29384 .55075 m .29119 .5523 L .29456 .55132 L F
0 0 0 r
.2941 .55158 m .29456 .55132 L .29381 .55153 L F
.294 .5516 m .29381 .55153 L .29119 .5523 L F
.2941 .55158 m .29381 .55153 L .294 .5516 L F
.375 0 0 r
.29456 .55132 m .29446 .55178 L .29497 .5518 L F
0 .142 .68 r
.29475 .55179 m .29497 .5518 L .29488 .55194 L F
.294 .5516 m .29447 .55178 L .29425 .55292 L F
.29447 .55178 m .29488 .55194 L .29484 .552 L F
.29447 .55178 m .29484 .552 L .29425 .55292 L F
.585 .693 .916 r
.294 .5516 m .294 .55162 L .29119 .5523 L F
.294 .55162 m .29425 .55292 L .29212 .55249 L F
.294 .55162 m .29212 .55249 L .29119 .5523 L F
0 0 0 r
.29052 .55363 m .29153 .55334 L .29431 .55149 L F
.2941 .55158 m .29431 .55149 L .29456 .55132 L F
.29052 .55363 m .29431 .55149 L .2941 .55158 L F
.375 0 0 r
.29446 .55178 m .29153 .55334 L .29419 .5531 L F
.29456 .55132 m .29414 .55159 L .29446 .55178 L F
.29414 .55159 m .29153 .55334 L .29446 .55178 L F
.29446 .55178 m .29419 .5531 L .29497 .5518 L F
0 .142 .68 r
.29384 .55075 m .29497 .5518 L .29475 .55179 L F
.29384 .55075 m .29488 .55194 L .294 .5516 L F
.585 .693 .916 r
.29384 .55075 m .294 .5516 L .29119 .5523 L F
0 0 0 r
.29052 .55363 m .2941 .55158 L .29119 .5523 L F
.647 .812 .962 r
.64574 .42843 m .64627 .42972 L .64331 .42959 L F
.655 .505 .668 r
.64627 .42972 m .64978 .42935 L .64725 .43243 L F
.64627 .42972 m .64978 .42935 L .64725 .43243 L F
.153 0 .19 r
.21277 .55301 m .21191 .5551 L .21459 .55212 L F
.772 .563 .616 r
.57965 .42593 m .58035 .42325 L .57576 .42243 L F
.378 .095 .352 r
.34205 .53536 m .34011 .53333 L .34249 .53348 L F
.34205 .53536 m .33927 .53626 L .34011 .53333 L F
0 .24 .75 r
.2823 .64315 m .2853 .64779 L .28473 .64506 L F
.774 .316 0 r
.28556 .6452 m .28537 .64622 L .28578 .64537 L F
0 0 .531 r
.28473 .64506 m .28518 .64724 L .28537 .64622 L F
.634 .565 .76 r
.28427 .64271 m .28473 .64506 L .28681 .64336 L F
.28427 .64271 m .28681 .64336 L .28751 .64172 L F
.652 .599 .782 r
.28681 .64336 m .28473 .64506 L .28261 .64049 L F
.774 .316 0 r
.28317 .64343 m .28473 .64506 L .28537 .64622 L F
.28317 .64343 m .28537 .64622 L .28556 .6452 L F
0 0 .531 r
.28518 .64724 m .2853 .64779 L .28537 .64622 L F
.455 .319 .607 r
.2853 .64779 m .28687 .64857 L .28537 .64622 L F
.2853 .64779 m .28791 .65003 L .28687 .64857 L F
.2853 .64779 m .28585 .65029 L .28791 .65003 L F
.976 .728 .495 r
.32546 .56113 m .32442 .56114 L .32546 .55959 L F
0 0 0 r
.32546 .55959 m .32442 .56114 L .32672 .55896 L F
.32546 .55959 m .32442 .56114 L .32672 .55896 L F
.32546 .55959 m .32672 .55896 L .32693 .55797 L F
.785 .749 .82 r
.32672 .55896 m .32442 .56114 L .32274 .55784 L F
.824 .346 .005 r
.32524 .55922 m .32642 .56029 L .32672 .55896 L F
.625 .369 .51 r
.32928 .55898 m .32865 .56151 L .32546 .56113 L F
.551 .256 .42 r
.32695 .56296 m .32442 .56114 L .32865 .56151 L F
.052 0 0 r
.32955 .56172 m .32695 .56296 L .32865 .56151 L F
.33004 .56183 m .32861 .56235 L .32955 .56172 L F
.32882 .56221 m .32695 .56296 L .32955 .56172 L F
.754 .383 .351 r
.32672 .55896 m .32865 .5623 L .32882 .56221 L F
.508 .326 .569 r
.33113 .55816 m .32865 .56151 L .32928 .55898 L F
.052 0 0 r
.32955 .56172 m .32865 .56151 L .33111 .56098 L F
.508 .326 .569 r
.33113 .55816 m .33111 .56098 L .32865 .56151 L F
.754 .383 .351 r
.32672 .55896 m .32875 .56209 L .33082 .56085 L F
.32875 .56209 m .32882 .56221 L .32955 .56172 L F
.32875 .56209 m .32955 .56172 L .33082 .56085 L F
.052 0 0 r
.33004 .56183 m .32955 .56172 L .33111 .56098 L F
.419 .337 .657 r
.33113 .55816 m .32928 .55898 L .32908 .55561 L F
.688 .384 .456 r
.32908 .55561 m .32672 .55896 L .33113 .55816 L F
.754 .383 .351 r
.32672 .55896 m .33111 .56098 L .33113 .55816 L F
.929 .932 .784 r
.33114 .56076 m .32865 .5623 L .33171 .55669 L F
.754 .383 .351 r
.33082 .56085 m .32882 .56221 L .33111 .56098 L F
.929 .932 .784 r
.33111 .56098 m .32882 .56221 L .33114 .56076 L F
.32882 .56221 m .32865 .5623 L .33114 .56076 L F
.052 0 0 r
.32861 .56235 m .32857 .56237 L .32882 .56221 L F
.32857 .56237 m .32695 .56296 L .32882 .56221 L F
.824 .346 .005 r
.32642 .56029 m .32865 .5623 L .32672 .55896 L F
0 0 0 r
.32693 .55797 m .32672 .55896 L .32908 .55561 L F
.541 .323 .532 r
.24112 .56785 m .23807 .57112 L .23885 .56856 L F
.281 0 .139 r
.33381 .51859 m .33285 .52002 L .33047 .52073 L F
.143 0 .053 r
.33521 .519 m .33381 .51859 L .33588 .51725 L F
.33521 .519 m .33285 .52002 L .33381 .51859 L F
.603 .639 .86 r
.36146 .63981 m .36351 .64393 L .36101 .64454 L F
.69 .814 .363 r
.39508 .62678 m .39481 .62716 L .39398 .62922 L F
.822 .731 .205 r
.39355 .62901 m .39398 .62922 L .39481 .62716 L F
.39355 .62901 m .39359 .63142 L .39398 .62922 L F
.715 .342 .342 r
.34535 .70744 m .34711 .71004 L .34317 .70966 L F
.321 .729 .979 r
.36205 .63738 m .36633 .6384 L .36566 .63556 L F
.981 .765 .539 r
.36503 .63791 m .36633 .6384 L .36446 .64058 L F
.547 .484 .737 r
.36566 .63556 m .36633 .6384 L .36858 .63752 L F
.556 .887 .987 r
.36858 .63752 m .36633 .6384 L .36503 .63791 L F
0 .469 .72 r
.35232 .50274 m .3551 .50329 L .35615 .50356 L F
.31 0 0 r
.3551 .50329 m .35885 .50466 L .35615 .50356 L F
.906 .571 .4 r
.3363 .70432 m .3388 .70745 L .33459 .70726 L F
.629 .165 .131 r
.33459 .70726 m .3388 .70745 L .3376 .70969 L F
.33459 .70726 m .3376 .70969 L .33724 .70971 L F
.816 .683 .718 r
.33772 .70966 m .33848 .70948 L .33838 .70965 L F
.637 .159 .101 r
.33273 .70885 m .33652 .70971 L .33565 .70971 L F
.816 .683 .718 r
.33569 .7098 m .33721 .70971 L .33676 .71241 L F
.637 .159 .101 r
.33652 .70971 m .33747 .70992 L .33565 .70971 L F
.816 .683 .718 r
.33721 .70971 m .33724 .70971 L .33724 .70971 L F
.33721 .70971 m .33724 .70971 L .33676 .71241 L F
.33724 .70971 m .33838 .70965 L .33834 .70971 L F
.33724 .70971 m .33834 .70971 L .33676 .71241 L F
.637 .159 .101 r
.33273 .70885 m .33459 .70726 L .33724 .70971 L F
.816 .683 .718 r
.33565 .70971 m .33838 .70965 L .33569 .7098 L F
.637 .159 .101 r
.33652 .70971 m .33724 .70971 L .33747 .70992 L F
.33273 .70885 m .33724 .70971 L .33652 .70971 L F
.749 .274 .116 r
.3376 .70969 m .33848 .70948 L .33747 .70992 L F
.3388 .70745 m .33848 .70948 L .3376 .70969 L F
.816 .683 .718 r
.33565 .70971 m .33848 .70948 L .33772 .70966 L F
.629 .165 .131 r
.33724 .70971 m .3376 .70969 L .33747 .70992 L F
.749 .274 .116 r
.3388 .70745 m .34091 .70983 L .33848 .70948 L F
0 .125 .637 r
.40881 .53972 m .40818 .53868 L .40596 .53687 L F
.686 .306 0 r
.40881 .53972 m .40998 .54225 L .40818 .53868 L F
0 0 0 r
.3233 .61402 m .32709 .61144 L .32451 .61289 L F
.694 .588 .732 r
.35411 .56782 m .35505 .57195 L .35133 .57123 L F
.987 .884 .634 r
.29936 .65261 m .30103 .65115 L .29874 .64989 L F
.29936 .65261 m .30041 .65367 L .30103 .65115 L F
.834 .781 .802 r
.70498 .3031 m .70082 .30479 L .70388 .30179 L F
.831 .895 .886 r
.70791 .30035 m .70498 .3031 L .70388 .30179 L F
.73 .284 .192 r
.33164 .5232 m .33047 .52073 L .33285 .52002 L F
.617 .82 .978 r
.58686 .40493 m .58839 .40632 L .58581 .40721 L F
.108 .206 .685 r
.58686 .40493 m .58581 .40721 L .58791 .40961 L F
0 0 0 r
.37227 .56187 m .37378 .56072 L .37447 .55863 L F
.525 .583 .856 r
.33908 .52345 m .34137 .52646 L .33857 .52713 L F
.592 .524 .747 r
.35479 .64694 m .3555 .65027 L .357 .64861 L F
.194 0 .348 r
.357 .64861 m .3555 .65027 L .35471 .65299 L F
.667 .197 .127 r
.3368 .66964 m .33555 .67061 L .33367 .66842 L F
.3368 .66964 m .3409 .67176 L .33555 .67061 L F
.325 .386 .771 r
.37385 .55583 m .37447 .55863 L .37653 .55676 L F
0 0 0 r
.37447 .55863 m .37378 .56072 L .37653 .55676 L F
.747 .464 .502 r
.34971 .56233 m .34906 .56505 L .34541 .56431 L F
.448 .233 .494 r
.35162 .56131 m .34906 .56505 L .34971 .56233 L F
.978 .689 .4 r
.42139 .58121 m .41973 .58252 L .41922 .57986 L F
.42139 .58121 m .42155 .58391 L .41973 .58252 L F
.864 .836 .816 r
.29717 .6304 m .30074 .62765 L .3001 .6274 L F
.58 .943 .84 r
.3001 .6274 m .30074 .62765 L .30404 .62574 L F
0 0 0 r
.24502 .55027 m .24377 .55118 L .24688 .54952 L F
.257 0 0 r
.3507 .66892 m .34853 .66956 L .34803 .67152 L F
.629 .919 .644 r
.34879 .67029 m .3507 .66892 L .34944 .67015 L F
.34879 .67029 m .34944 .67015 L .34803 .67152 L F
.375 .823 .701 r
.34836 .67038 m .34879 .67029 L .34658 .6712 L F
0 0 0 r
.35233 .66844 m .3507 .66892 L .34879 .67029 L F
.375 .823 .701 r
.35114 .6691 m .34879 .67029 L .34836 .67038 L F
0 0 0 r
.35312 .66802 m .3507 .66892 L .35233 .66844 L F
.257 0 0 r
.3507 .66892 m .34887 .66823 L .34853 .66956 L F
.3507 .66892 m .35185 .66837 L .34887 .66823 L F
.885 .991 .778 r
.28395 .62425 m .2869 .62241 L .28552 .62105 L F
.229 .739 .883 r
.2869 .62241 m .28737 .62191 L .28552 .62105 L F
.2869 .62241 m .28917 .62215 L .28737 .62191 L F
.409 .811 .596 r
.22318 .54354 m .22565 .54187 L .22469 .54222 L F
.22565 .54187 m .22666 .54118 L .22469 .54222 L F
0 0 .026 r
.22321 .54241 m .22303 .54284 L .22469 .54222 L F
.22303 .54284 m .22211 .545 L .22469 .54222 L F
.93 .79 .321 r
.41652 .56232 m .41559 .56372 L .41515 .56116 L F
.41652 .56232 m .41624 .56457 L .41559 .56372 L F
.28 .134 .497 r
.23238 .56213 m .23337 .56217 L .2334 .56101 L F
.23238 .56213 m .23166 .56432 L .23337 .56217 L F
.564 .85 .997 r
.26246 .52525 m .25807 .52497 L .26047 .52433 L F
.486 .812 1 r
.26278 .52352 m .26246 .52525 L .26047 .52433 L F
.26278 .52352 m .26493 .5247 L .26246 .52525 L F
.224 0 .069 r
.30913 .52253 m .30818 .52151 L .30957 .52001 L F
.30913 .52253 m .30686 .52333 L .30818 .52151 L F
.357 .826 .896 r
.27028 .53136 m .26789 .53121 L .26571 .5318 L F
.297 .786 .895 r
.27283 .53109 m .26789 .53121 L .27028 .53136 L F
0 0 .136 r
.40273 .61198 m .40193 .61458 L .40034 .61561 L F
0 0 0 r
.40193 .61458 m .39978 .61768 L .40034 .61561 L F
.515 .181 .339 r
.40772 .5227 m .40571 .5233 L .40662 .52079 L F
.904 .717 .639 r
.40841 .51998 m .40772 .5227 L .40662 .52079 L F
.062 .265 .757 r
.34367 .54472 m .34539 .54853 L .34299 .54637 L F
.626 .934 .965 r
.2687 .52391 m .26493 .5247 L .26704 .52376 L F
.453 .875 .931 r
.27108 .52312 m .2687 .52391 L .26704 .52376 L F
.456 .634 .931 r
.23063 .61818 m .23272 .61751 L .22992 .61487 L F
.49 .269 .505 r
.36132 .60292 m .36411 .60272 L .36427 .59998 L F
.265 0 .249 r
.35471 .65299 m .35246 .65422 L .35388 .65463 L F
.747 .47 .511 r
.60776 .43578 m .60431 .43788 L .6041 .43523 L F
.60776 .43578 m .60821 .43822 L .60431 .43788 L F
.775 .772 .85 r
.5938 .4313 m .59786 .43206 L .59706 .43024 L F
.591 .037 0 r
.59627 .43258 m .59786 .43206 L .5938 .4313 L F
.526 .639 .904 r
.59706 .43024 m .59786 .43206 L .6004 .43172 L F
.55 .321 .521 r
.33869 .51428 m .34127 .51406 L .34146 .5112 L F
.541 .661 .914 r
.38605 .65248 m .38183 .65053 L .38308 .65194 L F
.409 .612 .932 r
.38673 .65039 m .38605 .65248 L .38308 .65194 L F
.38673 .65039 m .38836 .65272 L .38605 .65248 L F
.373 .465 .826 r
.35571 .63813 m .35663 .64112 L .35829 .64054 L F
.017 0 0 r
.35829 .64054 m .35663 .64112 L .35543 .64305 L F
.632 .403 .553 r
.33237 .59 m .3351 .59002 L .33559 .58694 L F
.542 .321 .53 r
.33559 .58694 m .33769 .58945 L .33866 .58688 L F
.33559 .58694 m .3351 .59002 L .33769 .58945 L F
.724 .263 .156 r
.38596 .54837 m .38959 .54946 L .38564 .54852 L F
.773 .689 .77 r
.38959 .54946 m .38619 .55189 L .38564 .54852 L F
.558 .483 .727 r
.35597 .55242 m .35401 .55313 L .35328 .54943 L F
.444 .327 .625 r
.35597 .55242 m .35441 .55535 L .35401 .55313 L F
.556 .018 0 r
.34916 .71054 m .34951 .71228 L .34711 .71004 L F
.34916 .71054 m .35078 .71137 L .34951 .71228 L F
.694 .453 .554 r
.70173 .35025 m .70164 .35274 L .69911 .35261 L F
.21 0 0 r
.27153 .53688 m .27227 .53782 L .27383 .53608 L F
.27153 .53688 m .26957 .53832 L .27227 .53782 L F
.79 .539 0 r
.4038 .56082 m .40464 .56481 L .40428 .56245 L F
.707 .855 .953 r
.72747 .34025 m .72723 .33836 L .72836 .33756 L F
.68 .955 .951 r
.73054 .33634 m .72836 .33756 L .73006 .33532 L F
.639 .912 .615 r
.72836 .33756 m .72723 .33836 L .73006 .33532 L F
.605 .268 .373 r
.69049 .35404 m .69259 .3534 L .69308 .35556 L F
.558 .239 .383 r
.69259 .3534 m .69538 .3551 L .69308 .35556 L F
.56 .238 .38 r
.69259 .3534 m .69535 .353 L .69538 .3551 L F
.77 .603 .671 r
.5774 .44217 m .57312 .44436 L .57337 .44164 L F
.5774 .44217 m .57725 .44487 L .57312 .44436 L F
.673 .519 .668 r
.58018 .44459 m .57725 .44487 L .5774 .44217 L F
.794 .591 .628 r
.2664 .55845 m .2624 .56122 L .26282 .55821 L F
.2664 .55845 m .26672 .56188 L .2624 .56122 L F
.254 .192 .591 r
.26824 .5608 m .2664 .55845 L .26874 .55806 L F
.26824 .5608 m .26672 .56188 L .2664 .55845 L F
.618 .951 .783 r
.7133 .36039 m .7164 .35895 L .71538 .36051 L F
.117 0 .417 r
.71863 .35531 m .71865 .35754 L .7164 .35895 L F
0 0 0 r
.7164 .35895 m .71865 .35754 L .71538 .36051 L F
0 .188 .679 r
.2823 .64315 m .28324 .64389 L .28317 .64343 L F
.28324 .64389 m .28473 .64506 L .28317 .64343 L F
.652 .599 .782 r
.28681 .64336 m .28261 .64049 L .28317 .64343 L F
0 0 .481 r
.28424 .64206 m .28317 .64343 L .28261 .64049 L F
.639 .946 .726 r
.28309 .643 m .28317 .64343 L .28424 .64206 L F
0 .188 .679 r
.2823 .64315 m .28317 .64343 L .27995 .64596 L F
.997 .803 .524 r
.27923 .64261 m .28075 .64442 L .27995 .64596 L F
.27923 .64261 m .27995 .64596 L .28317 .64343 L F
.27923 .64261 m .28317 .64343 L .28085 .64483 L F
.639 .946 .726 r
.28085 .64483 m .28317 .64343 L .28309 .643 L F
.346 .824 .855 r
.34342 .67297 m .34099 .67368 L .33853 .67381 L F
.526 .038 .04 r
.23166 .56432 m .22944 .56658 L .23213 .5664 L F
.753 .695 .796 r
.23039 .56652 m .22968 .56937 L .23213 .5664 L F
.2284 .56682 m .22968 .56937 L .23043 .56634 L F
.669 .718 .886 r
.22727 .57046 m .23101 .57172 L .22968 .56937 L F
.529 .645 .908 r
.23101 .57172 m .23193 .56898 L .22968 .56937 L F
.407 .21 .497 r
.22968 .56937 m .23193 .56898 L .23213 .56641 L F
.23212 .56642 m .23213 .56641 L .23213 .5664 L F
.22968 .56937 m .23213 .56641 L .23212 .56642 L F
.529 .31 .527 r
.23213 .5664 m .23193 .56898 L .23463 .56608 L F
.526 .038 .04 r
.22944 .56658 m .22889 .56714 L .23098 .56666 L F
.23132 .56646 m .23098 .56666 L .23213 .5664 L F
.22944 .56658 m .23098 .56666 L .23132 .56646 L F
.753 .695 .796 r
.23043 .56634 m .23039 .56652 L .23213 .5664 L F
.352 0 0 r
.22771 .56537 m .22864 .56677 L .23166 .56432 L F
.22864 .56677 m .22944 .56658 L .23166 .56432 L F
.753 .695 .796 r
.22811 .56626 m .2284 .56682 L .23043 .56634 L F
.352 0 0 r
.22864 .56677 m .22885 .56708 L .22944 .56658 L F
.94 .737 .601 r
.22821 .56853 m .22968 .56937 L .22811 .56626 L F
.648 .665 .853 r
.22935 .56714 m .22821 .56853 L .22814 .56699 L F
.352 0 0 r
.22885 .56708 m .22889 .56714 L .22894 .56709 L F
.22885 .56708 m .22894 .56709 L .22944 .56658 L F
.617 .106 0 r
.22811 .56626 m .22885 .56708 L .22835 .56633 L F
.69 .299 .302 r
.23213 .5664 m .229 .56712 L .22811 .56626 L F
.648 .665 .853 r
.22935 .56714 m .22885 .56708 L .22811 .56626 L F
.22885 .56708 m .22814 .56699 L .22811 .56626 L F
.617 .106 0 r
.22811 .56626 m .22889 .56714 L .22885 .56708 L F
.22811 .56626 m .22835 .56633 L .22771 .56537 L F
.643 .957 .768 r
.22771 .56537 m .22678 .56575 L .22567 .56388 L F
.22678 .56575 m .22545 .5663 L .22553 .5654 L F
.22678 .56575 m .22553 .5654 L .22567 .56388 L F
.919 .978 .726 r
.2219 .56302 m .22213 .56523 L .22401 .56189 L F
.664 .111 0 r
.2219 .56302 m .22501 .56525 L .22201 .56431 L F
.643 .957 .768 r
.2259 .56611 m .22305 .56871 L .22545 .5663 L F
.22771 .56537 m .22474 .5675 L .2259 .56611 L F
.22474 .5675 m .22305 .56871 L .2259 .56611 L F
.617 .106 0 r
.22811 .56626 m .22567 .56388 L .22553 .5654 L F
.22811 .56626 m .22553 .5654 L .22657 .56628 L F
.22811 .56626 m .22771 .56537 L .22567 .56388 L F
.018 .004 .496 r
.2281 .5648 m .22652 .56634 L .22628 .56566 L F
.22728 .56448 m .22628 .56566 L .22567 .56388 L F
.2281 .5648 m .22628 .56566 L .22728 .56448 L F
.617 .106 0 r
.22657 .56628 m .22553 .5654 L .22545 .5663 L F
.518 .27 .478 r
.22545 .5663 m .22652 .56634 L .22567 .56388 L F
.22567 .56388 m .22652 .56634 L .22545 .5663 L F
.664 .111 0 r
.22501 .56525 m .22652 .56634 L .22261 .56458 L F
.22501 .56525 m .22261 .56458 L .22201 .56431 L F
0 0 0 r
.22522 .56821 m .22811 .56626 L .22545 .5663 L F
.22522 .56821 m .22624 .56784 L .22811 .56626 L F
.77 .95 .622 r
.22811 .56626 m .22624 .56784 L .22749 .56606 L F
.22811 .56626 m .22749 .56606 L .22855 .56456 L F
.69 .299 .302 r
.229 .56712 m .22889 .56714 L .22811 .56626 L F
.648 .665 .853 r
.22956 .5669 m .22935 .56714 L .22811 .56626 L F
.769 .669 .752 r
.23463 .56608 m .23193 .56898 L .22956 .5669 L F
.23452 .56614 m .23131 .56663 L .23402 .56637 L F
.23463 .56608 m .23372 .56623 L .23452 .56614 L F
.23372 .56623 m .22956 .5669 L .23452 .56614 L F
.526 .038 .04 r
.23166 .56432 m .23213 .5664 L .23337 .56217 L F
.319 0 0 r
.23213 .5664 m .23643 .56422 L .23337 .56217 L F
.23213 .5664 m .23463 .56608 L .23643 .56422 L F
.285 .482 .876 r
.23256 .56305 m .23474 .5663 L .23402 .56637 L F
0 0 .294 r
.2349 .56654 m .23463 .56608 L .23402 .56637 L F
.285 .482 .876 r
.23474 .5663 m .2349 .56654 L .23402 .56637 L F
.769 .669 .752 r
.23131 .56663 m .22956 .5669 L .23402 .56637 L F
.648 .665 .853 r
.22956 .5669 m .23193 .56898 L .22821 .56853 L F
.669 .718 .886 r
.22727 .57046 m .22876 .57354 L .23101 .57172 L F
.724 .846 .939 r
.22821 .56853 m .22727 .57046 L .22968 .56937 L F
.245 0 0 r
.23193 .56898 m .22801 .57135 L .22821 .56853 L F
.23193 .56898 m .2301 .57092 L .22801 .57135 L F
.891 .581 .455 r
.23193 .56898 m .2301 .57092 L .22964 .5675 L F
.22999 .56728 m .22964 .5675 L .22956 .5669 L F
.23193 .56898 m .22964 .5675 L .22999 .56728 L F
.696 .154 0 r
.35308 .566 m .35742 .5684 L .35411 .56782 L F
.3569 .56811 m .3563 .56832 L .35742 .5684 L F
.822 .89 .467 r
.3563 .56832 m .35411 .56782 L .3567 .56827 L F
.3563 .56832 m .3567 .56827 L .35742 .5684 L F
.696 .154 0 r
.35308 .566 m .3563 .56832 L .3569 .56811 L F
.995 .789 .511 r
.35742 .5684 m .35614 .56456 L .36005 .56457 L F
.35742 .5684 m .3563 .56832 L .35614 .56456 L F
.665 .543 .706 r
.35162 .56131 m .35308 .566 L .35614 .56456 L F
.437 .533 .857 r
.354 .56372 m .3563 .56832 L .35308 .566 L F
.927 .737 .626 r
.35614 .56456 m .3563 .56832 L .354 .56372 L F
.559 .91 .705 r
.35779 .56702 m .35565 .5684 L .3563 .56832 L F
.822 .89 .467 r
.3563 .56832 m .35457 .56984 L .35411 .56782 L F
.559 .91 .705 r
.35565 .5684 m .35512 .56874 L .3563 .56832 L F
.35512 .56874 m .35508 .56876 L .3563 .56832 L F
.3582 .56675 m .35779 .56702 L .3563 .56832 L F
.822 .89 .467 r
.3563 .56832 m .35505 .57195 L .35457 .56984 L F
.3563 .56832 m .3552 .57045 L .35505 .57195 L F
.507 .826 1 r
.35505 .57195 m .3552 .57045 L .35768 .57134 L F
.474 .031 .115 r
.36606 .71426 m .36972 .71334 L .36822 .7136 L F
.322 0 0 r
.36972 .71334 m .37226 .71361 L .36822 .7136 L F
.572 .382 .586 r
.38242 .66641 m .38235 .66979 L .37956 .66961 L F
.559 .574 .825 r
.37956 .66961 m .38351 .67273 L .38235 .66979 L F
.569 .35 .543 r
.38235 .66979 m .37941 .67229 L .37956 .66961 L F
.572 .382 .586 r
.37956 .66961 m .38235 .66979 L .38242 .66641 L F
.718 .829 .934 r
.60041 .42498 m .60281 .42609 L .60007 .42742 L F
0 0 0 r
.36789 .61112 m .36902 .60941 L .37065 .60835 L F
.858 .879 .853 r
.36789 .61112 m .37065 .60835 L .37037 .60814 L F
.238 0 .099 r
.36629 .61304 m .36902 .60941 L .36789 .61112 L F
.858 .879 .853 r
.36789 .61112 m .37037 .60814 L .36885 .60701 L F
.238 0 .099 r
.36586 .61361 m .36629 .61304 L .36789 .61112 L F
.297 .296 .689 r
.29586 .5538 m .29425 .55292 L .29497 .5518 L F
.29586 .5538 m .29519 .55557 L .29425 .55292 L F
.242 .407 .828 r
.34684 .50064 m .34584 .50308 L .34444 .50145 L F
.34684 .50064 m .34841 .50391 L .34584 .50308 L F
.526 0 0 r
.59001 .41187 m .5936 .41381 L .59319 .41421 L F
.411 .32 .641 r
.5957 .41281 m .59651 .41593 L .5936 .41381 L F
.536 0 0 r
.5936 .41381 m .59651 .41593 L .59319 .41421 L F
.307 0 0 r
.33214 .6678 m .33146 .6689 L .32871 .66892 L F
0 0 0 r
.3332 .66701 m .33214 .6678 L .33367 .66842 L F
.3332 .66701 m .33146 .6689 L .33214 .6678 L F
.762 .601 .678 r
.36269 .63484 m .36566 .63556 L .36431 .63412 L F
.321 .729 .979 r
.36205 .63738 m .36566 .63556 L .36269 .63484 L F
.45 .538 .856 r
.36431 .63412 m .36566 .63556 L .36724 .63379 L F
.547 .484 .737 r
.36566 .63556 m .36695 .63642 L .36712 .63689 L F
.36695 .63642 m .36858 .63752 L .36712 .63689 L F
.556 .887 .987 r
.36858 .63752 m .36503 .63791 L .36712 .63689 L F
0 0 0 r
.36726 .63726 m .36712 .63689 L .36654 .63926 L F
.36827 .63445 m .36712 .63689 L .36726 .63726 L F
.547 .484 .737 r
.36566 .63556 m .36712 .63689 L .36724 .63379 L F
.23 0 0 r
.3444 .57347 m .34847 .5718 L .34563 .57262 L F
.36 .145 .446 r
.36089 .52377 m .36053 .52654 L .3587 .52686 L F
.35842 .52725 m .36053 .52654 L .36089 .52377 L F
.399 .178 .459 r
.36089 .52377 m .36053 .52654 L .36306 .52333 L F
.36089 .52377 m .36053 .52654 L .36306 .52333 L F
.629 .474 .653 r
.36053 .52654 m .36345 .52629 L .36306 .52333 L F
.36053 .52654 m .36345 .52629 L .36306 .52333 L F
.294 .778 .911 r
.3589 .52628 m .36196 .52628 L .36053 .52654 L F
.36196 .52628 m .36345 .52629 L .36053 .52654 L F
.36 .145 .446 r
.3587 .52686 m .36053 .52654 L .35842 .52725 L F
.567 .934 .802 r
.35842 .52725 m .3589 .52628 L .36053 .52654 L F
.35842 .52725 m .35592 .52816 L .3589 .52628 L F
.393 .243 .555 r
.36055 .52972 m .35842 .52725 L .36053 .52654 L F
.36055 .52972 m .35848 .53068 L .35842 .52725 L F
.41 .252 .554 r
.3845 .66869 m .38235 .66979 L .38242 .66641 L F
.3845 .66869 m .38235 .66979 L .38242 .66641 L F
.553 .275 .448 r
.38183 .65053 m .38138 .6524 L .37893 .6517 L F
.451 0 0 r
.37706 .65274 m .38138 .6524 L .37893 .6517 L F
.805 .707 .756 r
.55929 .41161 m .55725 .41489 L .55716 .41474 L F
.929 .941 .784 r
.55829 .41319 m .55832 .41317 L .55929 .41161 L F
.55832 .41317 m .56101 .41117 L .55929 .41161 L F
.95 .72 .554 r
.56101 .41117 m .55965 .41194 L .55943 .41174 L F
.55945 .41157 m .55943 .41174 L .55929 .41161 L F
.56101 .41117 m .55943 .41174 L .55945 .41157 L F
.839 .67 .673 r
.56167 .41377 m .55775 .41578 L .55894 .41257 L F
.55965 .41194 m .55894 .41257 L .55929 .41161 L F
.787 .994 .774 r
.55894 .41257 m .55982 .41205 L .55832 .41317 L F
.55949 .41207 m .55982 .41205 L .55894 .41257 L F
.839 .67 .673 r
.56167 .41377 m .55894 .41257 L .55965 .41194 L F
.787 .994 .774 r
.55944 .41208 m .55949 .41207 L .55894 .41257 L F
.56209 .4095 m .55982 .41205 L .55944 .41208 L F
.56209 .4095 m .56101 .41117 L .55982 .41205 L F
.95 .72 .554 r
.56101 .41117 m .56167 .41377 L .55965 .41194 L F
.787 .994 .774 r
.56237 .40908 m .56209 .4095 L .5595 .41202 L F
.56237 .40908 m .5595 .41202 L .55939 .41208 L F
.56209 .4095 m .55832 .41317 L .55829 .41319 L F
.616 .824 .422 r
.56304 .40815 m .56101 .41117 L .56237 .40908 L F
.787 .994 .774 r
.56237 .40908 m .55939 .41208 L .56267 .41186 L F
.55939 .41208 m .5595 .41202 L .55829 .41319 L F
.55939 .41208 m .55829 .41319 L .5593 .41288 L F
.55939 .41208 m .5593 .41288 L .56267 .41186 L F
.805 .707 .756 r
.55832 .41317 m .55775 .41578 L .55725 .41489 L F
.55929 .41161 m .55894 .41257 L .55832 .41317 L F
.55894 .41257 m .55775 .41578 L .55832 .41317 L F
.839 .67 .673 r
.56167 .41377 m .56133 .41647 L .55775 .41578 L F
0 0 0 r
.72928 .35069 m .72885 .35223 L .7285 .3533 L F
0 .218 .732 r
.6235 .4246 m .62193 .42351 L .62091 .42194 L F
.783 .691 .763 r
.71772 .28941 m .72152 .29015 L .71898 .29329 L F
0 0 0 r
.71898 .29329 m .72152 .29015 L .72071 .29118 L F
.798 .77 .828 r
.72006 .28819 m .72152 .29015 L .72419 .287 L F
.938 .572 .188 r
.72071 .29118 m .72152 .29015 L .72006 .28819 L F
.603 .868 .992 r
.42812 .53283 m .42561 .53363 L .42499 .53245 L F
.971 .708 .287 r
.42561 .53363 m .42468 .53452 L .42499 .53245 L F
.42586 .53643 m .42602 .53831 L .42572 .53746 L F
.42586 .53643 m .42572 .53746 L .42468 .53452 L F
.632 .444 .61 r
.42876 .53616 m .42602 .53831 L .42561 .53363 L F
.8 .927 .551 r
.42602 .53831 m .42604 .53691 L .42468 .53452 L F
.42602 .53831 m .42542 .53916 L .42604 .53691 L F
0 0 .55 r
.42557 .53862 m .42573 .53871 L .42604 .53691 L F
.42542 .53916 m .42551 .53902 L .42557 .53862 L F
.42551 .53902 m .42573 .53871 L .42557 .53862 L F
.971 .708 .287 r
.42561 .53363 m .42586 .53643 L .42468 .53452 L F
.632 .444 .61 r
.42876 .53616 m .42561 .53363 L .42812 .53283 L F
.775 .537 .574 r
.34137 .52646 m .34494 .52676 L .34429 .52421 L F
.68 .565 .719 r
.34494 .52676 m .34645 .52341 L .34429 .52421 L F
.581 .831 .992 r
.23988 .62499 m .24166 .62612 L .24391 .62531 L F
.329 .144 .471 r
.57288 .42273 m .57091 .42664 L .57216 .42513 L F
.469 .058 .176 r
.57507 .42463 m .57288 .42273 L .57216 .42513 L F
.57507 .42463 m .57576 .42243 L .57288 .42273 L F
.817 .978 .893 r
.30528 .51586 m .30379 .51806 L .30418 .51575 L F
.72 .908 .961 r
.30379 .51806 m .30206 .5172 L .30418 .51575 L F
.644 .876 .517 r
.7165 .29651 m .71898 .29329 L .71796 .2943 L F
0 0 .04 r
.71593 .29855 m .7165 .29651 L .71796 .2943 L F
.792 .559 .585 r
.37682 .56866 m .38158 .56916 L .3791 .56731 L F
.37682 .56866 m .37904 .57242 L .38158 .56916 L F
.035 0 .424 r
.37904 .57242 m .37964 .57345 L .38158 .56916 L F
0 0 .041 r
.38158 .56916 m .38131 .57218 L .38228 .57025 L F
.38158 .56916 m .37964 .57345 L .38131 .57218 L F
0 0 0 r
.31314 .64057 m .31114 .64437 L .31294 .64309 L F
.28 .152 .522 r
.31114 .64437 m .31393 .64545 L .31294 .64309 L F
.31114 .64437 m .31119 .64745 L .31393 .64545 L F
.408 .182 .456 r
.33883 .65882 m .33654 .65934 L .33621 .66191 L F
.764 .68 .769 r
.33829 .65877 m .33769 .65968 L .33465 .66106 L F
.33769 .65968 m .33621 .66191 L .33567 .66161 L F
.33769 .65968 m .33567 .66161 L .33465 .66106 L F
.541 .102 .156 r
.3385 .6589 m .33817 .65674 L .33654 .65934 L F
.33883 .65882 m .33877 .65864 L .3385 .6589 L F
.33877 .65864 m .33817 .65674 L .3385 .6589 L F
.33883 .65882 m .34036 .65663 L .33817 .65674 L F
.273 .111 .471 r
.29753 .59937 m .29918 .59595 L .29755 .5969 L F
.681 .165 0 r
.38873 .52658 m .39059 .52886 L .39208 .5299 L F
.818 .407 0 r
.39269 .53283 m .39208 .5299 L .39059 .52886 L F
.39269 .53283 m .39363 .53365 L .39208 .5299 L F
.579 .625 .862 r
.24785 .53957 m .24983 .5434 L .25209 .54254 L F
.622 .501 .694 r
.25023 .5451 m .25209 .54254 L .24983 .5434 L F
.25023 .5451 m .25209 .54254 L .24983 .5434 L F
.823 .583 .576 r
.70534 .35327 m .70177 .35528 L .70164 .35274 L F
.70534 .35327 m .7052 .35638 L .70177 .35528 L F
.051 0 0 r
.63408 .43243 m .63027 .43401 L .63265 .43381 L F
.151 0 0 r
.63518 .43337 m .63408 .43243 L .63265 .43381 L F
.63518 .43337 m .63674 .43193 L .63408 .43243 L F
.904 .808 .743 r
.68597 .33757 m .68518 .34019 L .68286 .33909 L F
.868 .541 .431 r
.68518 .34019 m .68526 .3426 L .68255 .34204 L F
.995 .789 .511 r
.35742 .5684 m .36005 .56457 L .3582 .56675 L F
.921 .723 .618 r
.3563 .56832 m .3582 .56675 L .35742 .5684 L F
.686 .976 .903 r
.3582 .56675 m .3563 .56832 L .35742 .5684 L F
.471 .555 .86 r
.39473 .65453 m .39674 .65538 L .39677 .65692 L F
.39674 .65538 m .39868 .65621 L .39758 .65662 L F
.308 0 0 r
.39693 .65553 m .39868 .65621 L .39674 .65538 L F
.39567 .65496 m .39674 .65538 L .39473 .65453 L F
.39693 .65553 m .39674 .65538 L .39567 .65496 L F
.921 .668 .537 r
.39533 .65328 m .39488 .65464 L .3928 .65335 L F
.39488 .65464 m .39446 .65588 L .39321 .65397 L F
.39488 .65464 m .39321 .65397 L .3928 .65335 L F
.308 0 0 r
.39693 .65553 m .39473 .65453 L .39556 .65328 L F
.921 .668 .537 r
.39556 .65328 m .39547 .65349 L .39533 .65328 L F
0 0 0 r
.39473 .65453 m .39446 .65588 L .39556 .65328 L F
.921 .668 .537 r
.39547 .65349 m .39446 .65588 L .39533 .65328 L F
.471 .555 .86 r
.39674 .65538 m .39758 .65662 L .39677 .65692 L F
.125 .248 .721 r
.399 .6589 m .39677 .65692 L .39868 .65621 L F
.753 .367 .322 r
.39661 .58086 m .39473 .5826 L .39253 .5802 L F
.719 .319 .29 r
.39661 .58086 m .39829 .58308 L .39473 .5826 L F
.479 .345 .621 r
.3059 .60611 m .3063 .60899 L .30393 .60979 L F
.487 .21 .419 r
.3063 .60899 m .30315 .61169 L .30393 .60979 L F
.195 0 .201 r
.2796 .54326 m .27675 .54619 L .27867 .54516 L F
.504 .194 .374 r
.2796 .54326 m .28414 .54242 L .28169 .54229 L F
.2796 .54326 m .27867 .54516 L .28414 .54242 L F
.594 .314 .461 r
.3247 .62856 m .32689 .63069 L .32407 .63088 L F
.11 0 0 r
.27491 .61833 m .27726 .61782 L .27888 .61658 L F
.43 .008 .135 r
.27726 .61782 m .28139 .61628 L .27888 .61658 L F
.575 .851 .512 r
.71796 .2943 m .71898 .29329 L .72071 .29118 L F
.784 .915 .53 r
.40565 .60167 m .40516 .60341 L .4071 .59998 L F
.666 .807 .361 r
.40473 .604 m .40516 .60341 L .40565 .60167 L F
.40473 .604 m .40396 .60569 L .40516 .60341 L F
.762 .486 .516 r
.23298 .59002 m .22796 .59183 L .2305 .59045 L F
.399 .81 .608 r
.23466 .53607 m .23587 .53525 L .2379 .53396 L F
.521 .881 .655 r
.2379 .53396 m .2376 .53382 L .24032 .53333 L F
.2379 .53396 m .23587 .53525 L .2376 .53382 L F
.765 .572 .637 r
.3739 .52036 m .37209 .52148 L .36988 .5204 L F
.646 .397 .528 r
.31106 .54191 m .30764 .54011 L .31146 .5397 L F
.31106 .54191 m .30705 .54218 L .30764 .54011 L F
.436 .874 .818 r
.63445 .40628 m .6364 .40504 L .63447 .40599 L F
.63445 .40628 m .63826 .4047 L .63681 .40497 L F
.63445 .40628 m .63681 .40497 L .6358 .40543 L F
.444 .226 .487 r
.63674 .40814 m .63404 .40887 L .63446 .40603 L F
.6345 .40602 m .63446 .40603 L .63447 .40599 L F
.63674 .40814 m .63446 .40603 L .6345 .40602 L F
.436 .874 .818 r
.6358 .40543 m .63681 .40497 L .6364 .40504 L F
.662 .918 .61 r
.35359 .52605 m .35293 .52707 L .35415 .52569 L F
.749 .234 0 r
.35592 .52816 m .35234 .52684 L .35359 .52605 L F
.35234 .52684 m .35191 .52668 L .35359 .52605 L F
.662 .918 .61 r
.35359 .52605 m .35415 .52569 L .35505 .52467 L F
.9 .811 .336 r
.35191 .52668 m .35239 .52906 L .35293 .52707 L F
.909 .595 .11 r
.70668 .3301 m .70807 .3341 L .70891 .33168 L F
0 0 .424 r
.27675 .54619 m .27809 .54801 L .27867 .54516 L F
.27675 .54619 m .27649 .54973 L .27809 .54801 L F
.733 .633 .748 r
.35779 .63705 m .36072 .63378 L .35899 .63519 L F
.936 .615 .405 r
.40181 .5904 m .40247 .59351 L .40014 .59212 L F
.608 .918 .976 r
.24153 .54451 m .23869 .54581 L .24054 .54627 L F
.348 0 .025 r
.24153 .54451 m .23991 .54535 L .23869 .54581 L F
.339 .795 .945 r
.24054 .54627 m .23869 .54581 L .23764 .54622 L F
.348 0 .025 r
.23991 .54535 m .23696 .54686 L .23869 .54581 L F
.339 .795 .945 r
.23764 .54622 m .23869 .54581 L .23638 .54619 L F
.608 .918 .976 r
.24153 .54451 m .24054 .54627 L .24288 .5456 L F
.732 .652 .77 r
.62687 .38715 m .62838 .3913 L .62425 .39064 L F
.747 .461 .498 r
.62425 .39064 m .62838 .3913 L .62829 .3936 L F
.517 .53 .808 r
.6308 .39039 m .62838 .3913 L .62687 .38715 L F
.367 .152 .449 r
.62829 .3936 m .62838 .3913 L .6308 .39039 L F
.799 .783 .838 r
.57091 .42664 m .56682 .42792 L .56911 .42676 L F
.693 .976 .91 r
.57216 .42513 m .57091 .42664 L .56911 .42676 L F
.401 .172 .448 r
.36427 .59998 m .36667 .59941 L .36686 .59681 L F
.585 .347 .522 r
.36427 .59998 m .36695 .60208 L .36667 .59941 L F
.36427 .59998 m .36411 .60272 L .36695 .60208 L F
.401 .172 .448 r
.36427 .59998 m .36667 .59941 L .36686 .59681 L F
.323 .367 .753 r
.36695 .60208 m .36427 .59998 L .36667 .59941 L F
.772 .695 .778 r
.38235 .66979 m .38351 .67273 L .37941 .67229 L F
.978 .734 .496 r
.31985 .63087 m .32174 .63144 L .32024 .63348 L F
.493 .795 .999 r
.32174 .63144 m .32407 .63088 L .32268 .62988 L F
.775 .571 .622 r
.32407 .63088 m .32024 .63348 L .32174 .63144 L F
0 .208 .622 r
.28814 .56657 m .28524 .56482 L .28742 .56527 L F
.441 0 .008 r
.2907 .5653 m .28814 .56657 L .28742 .56527 L F
0 0 0 r
.31858 .5379 m .31687 .53947 L .31722 .53974 L F
.153 .664 .899 r
.31781 .54021 m .31722 .53974 L .31422 .53962 L F
0 0 0 r
.31722 .53974 m .31352 .54144 L .31422 .53962 L F
.31687 .53947 m .31528 .54092 L .31722 .53974 L F
.153 .664 .899 r
.31833 .54029 m .31722 .53974 L .31781 .54021 L F
.827 .982 .881 r
.31858 .5379 m .31833 .54029 L .32066 .53954 L F
.31858 .5379 m .31722 .53974 L .31833 .54029 L F
.643 .224 .235 r
.23764 .55402 m .24001 .55469 L .24199 .5527 L F
.049 0 0 r
.24199 .5527 m .24247 .55372 L .24377 .55118 L F
.24199 .5527 m .24001 .55469 L .24247 .55372 L F
.497 .23 .44 r
.3391 .65059 m .34165 .65011 L .33981 .64912 L F
.102 .656 .726 r
.35441 .6681 m .35185 .66837 L .35391 .668 L F
.659 .896 .981 r
.35698 .66576 m .35441 .6681 L .35391 .668 L F
.35698 .66576 m .35886 .66668 L .35441 .6681 L F
.493 0 .014 r
.56497 .40891 m .56304 .40815 L .56237 .40908 L F
.821 .998 .842 r
.3433 .65356 m .34169 .65524 L .34195 .65451 L F
0 0 .52 r
.34165 .65011 m .3433 .65356 L .34148 .65351 L F
.821 .998 .842 r
.3433 .65356 m .33973 .65606 L .34148 .65351 L F
.862 .84 .822 r
.3433 .65356 m .34165 .65011 L .34148 .65351 L F
.3433 .65356 m .3439 .64955 L .34165 .65011 L F
.895 .616 .506 r
.34315 .65502 m .3433 .65356 L .34148 .65351 L F
.34315 .65502 m .3421 .65407 L .3433 .65266 L F
.3421 .65407 m .34148 .65351 L .34245 .65305 L F
.3421 .65407 m .34245 .65305 L .3433 .65266 L F
.821 .998 .842 r
.34195 .65451 m .34036 .65663 L .33973 .65606 L F
.34169 .65524 m .34036 .65663 L .34195 .65451 L F
.971 .891 .523 r
.33973 .65606 m .34036 .65663 L .33883 .65882 L F
.547 .449 .695 r
.39001 .5971 m .39265 .59663 L .39229 .59316 L F
.449 0 0 r
.70698 .34801 m .70977 .34829 L .7107 .34659 L F
.185 0 0 r
.70977 .34829 m .71293 .3456 L .7107 .34659 L F
.831 .757 .782 r
.68714 .32812 m .68307 .32965 L .68554 .32652 L F
.68714 .32812 m .68476 .33138 L .68307 .32965 L F
.568 .766 .972 r
.2776 .5233 m .27524 .52397 L .27355 .52241 L F
0 .142 .634 r
.38638 .52444 m .38844 .52599 L .38873 .52658 L F
0 0 .486 r
.38844 .52599 m .39059 .52886 L .38873 .52658 L F
.961 .673 .244 r
.38521 .52222 m .38638 .52444 L .38594 .52135 L F
.96 .745 .297 r
.38527 .51955 m .38521 .52222 L .38594 .52135 L F
.857 .403 .04 r
.30399 .65795 m .30421 .65699 L .30111 .65532 L F
.842 .835 .839 r
.2173 .58037 m .22156 .57821 L .21757 .57773 L F
.777 .945 .932 r
.36269 .63484 m .36431 .63412 L .36346 .6323 L F
.383 .713 .987 r
.36346 .6323 m .36431 .63412 L .36724 .63379 L F
.329 .204 .554 r
.31736 .58377 m .31747 .58649 L .3157 .58709 L F
.279 .143 .51 r
.31747 .58649 m .31523 .58973 L .3157 .58709 L F
.533 .39 .632 r
.31277 .63524 m .31532 .63722 L .31522 .63444 L F
.904 .808 .743 r
.68597 .33757 m .68286 .33909 L .68206 .33701 L F
.933 .766 .651 r
.23458 .54927 m .23307 .55251 L .23536 .55331 L F
.872 .448 .203 r
.23307 .55251 m .23347 .5538 L .23536 .55331 L F
.284 .76 .933 r
.23347 .5538 m .23764 .55402 L .23536 .55331 L F
.808 .442 .362 r
.64682 .40568 m .64662 .40371 L .64742 .4032 L F
.358 0 0 r
.64742 .4032 m .64915 .40436 L .64682 .40568 L F
.64742 .4032 m .6502 .40314 L .64915 .40436 L F
.899 .869 .8 r
.70716 .31459 m .70975 .31443 L .7093 .31137 L F
.91 .841 .765 r
.70758 .31814 m .70975 .31443 L .70716 .31459 L F
.865 .851 .827 r
.7093 .31137 m .70975 .31443 L .71235 .31104 L F
.444 .327 .625 r
.35597 .55242 m .35645 .55495 L .35441 .55535 L F
.543 .287 .477 r
.35645 .55495 m .35121 .557 L .35441 .55535 L F
.284 .491 .883 r
.22796 .59183 m .22945 .59449 L .22795 .59444 L F
.322 .359 .745 r
.22945 .59449 m .229 .59713 L .22795 .59444 L F
.115 0 .376 r
.19891 .57105 m .20069 .56729 L .19914 .56834 L F
.786 .613 .666 r
.68464 .34968 m .68625 .35336 L .68229 .35273 L F
.666 .41 .523 r
.68625 .35336 m .68217 .35575 L .68229 .35273 L F
.68625 .35336 m .68627 .35568 L .68217 .35575 L F
.638 .31 .4 r
.69049 .35404 m .68627 .35568 L .68625 .35336 L F
.921 .55 .297 r
.29676 .62677 m .29729 .62526 L .29531 .62399 L F
.29531 .62399 m .29729 .62526 L .29676 .62677 L F
.91 .893 .478 r
.22945 .59449 m .22802 .59932 L .229 .59713 L F
.888 .927 .542 r
.40714 .59802 m .40565 .60167 L .4071 .59998 L F
.592 .502 .722 r
.33521 .57205 m .33756 .57182 L .33721 .56816 L F
.776 .879 .455 r
.73241 .34546 m .73067 .34903 L .73065 .34959 L F
0 0 0 r
.31804 .55149 m .31503 .55643 L .31836 .55314 L F
.406 .099 .329 r
.42951 .56779 m .42894 .57067 L .42663 .5708 L F
.431 .539 .865 r
.43345 .56631 m .43194 .56767 L .43214 .56773 L F
.401 .438 .783 r
.43214 .56773 m .43167 .56791 L .42951 .56779 L F
.431 .539 .865 r
.43194 .56767 m .43167 .56791 L .43214 .56773 L F
0 0 .234 r
.43199 .56861 m .43167 .56791 L .43194 .56767 L F
0 .443 .855 r
.43203 .56763 m .43214 .56773 L .43197 .56764 L F
.401 .438 .783 r
.43214 .56773 m .43186 .56773 L .43194 .56767 L F
.594 .804 .98 r
.43345 .56631 m .43214 .56773 L .43203 .56763 L F
0 0 .234 r
.43199 .56861 m .43194 .56771 L .43324 .56664 L F
.43194 .56771 m .43194 .56767 L .43223 .56744 L F
.43194 .56771 m .43223 .56744 L .43324 .56664 L F
.43197 .56764 m .43197 .56764 L .43345 .56631 L F
.594 .804 .98 r
.43345 .56631 m .43203 .56763 L .42825 .56439 L F
0 0 .234 r
.43197 .56764 m .43194 .56767 L .43197 .56764 L F
.401 .438 .783 r
.43214 .56773 m .42903 .56687 L .42851 .56589 L F
.694 .359 .404 r
.43234 .57055 m .42951 .56779 L .43167 .56791 L F
.42963 .56791 m .42894 .57067 L .42951 .56779 L F
.43234 .57055 m .42894 .57067 L .42963 .56791 L F
.474 .486 .79 r
.42894 .57067 m .42986 .57368 L .42775 .57425 L F
.316 .014 .283 r
.43113 .57046 m .42894 .57067 L .43234 .57055 L F
.43113 .57046 m .42846 .57261 L .42894 .57067 L F
.42846 .57261 m .42825 .57277 L .42894 .57067 L F
0 0 .234 r
.43199 .56861 m .43234 .57055 L .43167 .56791 L F
.765 .547 .602 r
.42919 .56841 m .43199 .56861 L .43273 .56745 L F
0 0 .234 r
.43324 .56664 m .43197 .56764 L .43345 .56631 L F
.765 .547 .602 r
.43199 .56703 m .43273 .56745 L .43345 .56631 L F
0 .443 .855 r
.42835 .56497 m .43203 .56763 L .42851 .56589 L F
.43004 .56592 m .43203 .56763 L .42835 .56497 L F
.43203 .56763 m .43197 .56764 L .42851 .56589 L F
.401 .438 .783 r
.43194 .56767 m .42951 .56779 L .42903 .56687 L F
.43186 .56773 m .42951 .56779 L .43194 .56767 L F
.765 .547 .602 r
.42919 .56841 m .43273 .56745 L .43199 .56703 L F
.976 .913 .674 r
.42787 .56745 m .42919 .56841 L .4295 .56611 L F
.42787 .56745 m .4295 .56611 L .43034 .56549 L F
0 .443 .855 r
.42825 .56439 m .42986 .56577 L .42835 .56497 L F
.42986 .56577 m .43004 .56592 L .42982 .5658 L F
.42986 .56577 m .42982 .5658 L .42835 .56497 L F
.594 .804 .98 r
.43345 .56631 m .42825 .56439 L .4295 .56611 L F
.976 .913 .674 r
.43055 .56536 m .43034 .56549 L .43131 .56477 L F
.42787 .56745 m .43034 .56549 L .43055 .56536 L F
0 0 0 r
.25634 .5255 m .25557 .52566 L .25417 .52644 L F
.25634 .5255 m .25807 .52497 L .25557 .52566 L F
.67 .521 .673 r
.26383 .6087 m .26623 .60966 L .26721 .60929 L F
.26383 .6087 m .26459 .61259 L .26623 .60966 L F
.717 .768 .892 r
.28439 .53662 m .28167 .53743 L .2803 .53612 L F
.28439 .53662 m .28167 .53743 L .2803 .53612 L F
.469 .465 .771 r
.28167 .53743 m .28435 .53927 L .28439 .53662 L F
.816 .791 .829 r
.6837 .34578 m .68464 .34968 L .68239 .34962 L F
.786 .613 .666 r
.68464 .34968 m .68229 .35273 L .68239 .34962 L F
.775 .768 .846 r
.68741 .34645 m .68464 .34968 L .6837 .34578 L F
0 0 0 r
.34832 .54344 m .34847 .54325 L .34886 .54096 L F
.3 .106 .441 r
.34847 .54325 m .35042 .54469 L .35067 .54216 L F
.34847 .54325 m .34861 .54565 L .35042 .54469 L F
.708 .458 .545 r
.59523 .43851 m .59276 .44101 L .59274 .43858 L F
.59523 .43851 m .59519 .44149 L .59276 .44101 L F
.619 .386 .541 r
.59912 .44102 m .59523 .43851 L .59915 .4383 L F
.59912 .44102 m .59519 .44149 L .59523 .43851 L F
.819 .771 .262 r
.40876 .58871 m .40878 .59037 L .40941 .58681 L F
.892 .691 .176 r
.40816 .59141 m .40878 .59037 L .40876 .58871 L F
.40816 .59141 m .4088 .5932 L .40878 .59037 L F
.655 .624 .806 r
.33882 .50252 m .33633 .50414 L .33539 .50061 L F
.592 .524 .747 r
.35479 .64694 m .357 .64861 L .35687 .64675 L F
.653 .94 .964 r
.59899 .41457 m .59759 .41653 L .59651 .41593 L F
0 0 .475 r
.59899 .41457 m .59651 .41593 L .59759 .41653 L F
.511 .891 .963 r
.37337 .54719 m .37263 .54848 L .37461 .54652 L F
.37337 .54719 m .37101 .54805 L .37263 .54848 L F
.105 0 0 r
.28651 .5359 m .28854 .53536 L .29033 .53317 L F
.433 .276 .567 r
.29033 .53317 m .29251 .5326 L .29242 .53018 L F
.089 0 0 r
.29033 .53317 m .2908 .53442 L .29251 .5326 L F
.29033 .53317 m .28854 .53536 L .2908 .53442 L F
0 0 .333 r
.31794 .64239 m .31758 .64401 L .31734 .64206 L F
.31783 .64216 m .31734 .64206 L .31719 .64081 L F
.31794 .64239 m .31734 .64206 L .31783 .64216 L F
.728 .202 0 r
.31794 .64239 m .31719 .64081 L .31509 .63984 L F
.971 .714 .487 r
.31529 .63964 m .31799 .637 L .31855 .64264 L F
.21 .108 .514 r
.32008 .63616 m .31855 .64264 L .31799 .637 L F
.504 .646 .92 r
.31873 .63457 m .31796 .63601 L .31522 .63444 L F
.757 .961 .935 r
.32024 .63348 m .31796 .63601 L .31873 .63457 L F
.173 .032 .436 r
.31799 .637 m .31796 .63601 L .31922 .63461 L F
.31799 .637 m .31922 .63461 L .31932 .6348 L F
.31799 .637 m .31987 .63388 L .3198 .63417 L F
.659 .499 .656 r
.31817 .64229 m .31861 .6401 L .31864 .63872 L F
.173 .032 .436 r
.31799 .637 m .3198 .63417 L .3192 .63652 L F
.659 .499 .656 r
.31835 .63986 m .31864 .63872 L .31873 .63457 L F
.31817 .64229 m .31864 .63872 L .31835 .63986 L F
.173 .032 .436 r
.3192 .63652 m .32024 .63348 L .32008 .63616 L F
.3198 .63417 m .32024 .63348 L .3192 .63652 L F
.378 .268 .601 r
.31873 .63457 m .3187 .63615 L .32008 .63616 L F
.3187 .63615 m .31855 .64264 L .32008 .63616 L F
.123 0 0 r
.32205 .63618 m .32008 .63616 L .32217 .63616 L F
.31859 .6368 m .32008 .63616 L .32205 .63618 L F
.378 .268 .601 r
.31873 .63457 m .32004 .63611 L .31859 .6368 L F
.32004 .63611 m .32008 .63616 L .32007 .63617 L F
.32004 .63611 m .32007 .63617 L .31859 .6368 L F
.173 .032 .436 r
.31932 .6348 m .31922 .63461 L .31987 .63388 L F
.3198 .63417 m .31987 .63388 L .32024 .63348 L F
.659 .499 .656 r
.31529 .63955 m .31777 .6419 L .31873 .63457 L F
.31777 .6419 m .31817 .64229 L .31837 .63962 L F
.31777 .6419 m .31837 .63962 L .31873 .63457 L F
.31817 .64229 m .31855 .64264 L .31861 .6401 L F
.263 .423 .834 r
.31978 .64154 m .31817 .64229 L .31855 .64264 L F
.31817 .64229 m .31817 .64229 L .31855 .64264 L F
.31817 .64229 m .31794 .64239 L .31855 .64264 L F
.971 .714 .487 r
.31816 .64233 m .31817 .64229 L .31855 .64264 L F
.007 0 .463 r
.31816 .64233 m .31817 .64229 L .31817 .64229 L F
.971 .714 .487 r
.31509 .63984 m .31529 .63964 L .31817 .64229 L F
.31509 .63984 m .31817 .64229 L .31816 .64233 L F
.659 .499 .656 r
.31509 .63984 m .31855 .64264 L .31529 .63955 L F
0 .189 .678 r
.31814 .64222 m .31835 .64243 L .31799 .64219 L F
.31835 .64243 m .31855 .64264 L .31816 .64233 L F
.007 0 .463 r
.31816 .64233 m .31817 .64229 L .31978 .64154 L F
0 .189 .678 r
.31835 .64243 m .31816 .64233 L .31799 .64219 L F
.432 .716 .984 r
.31978 .64154 m .31855 .64264 L .31835 .64243 L F
.007 0 .463 r
.31835 .64243 m .31816 .64233 L .31978 .64154 L F
.432 .716 .984 r
.31978 .64154 m .31835 .64243 L .31729 .64134 L F
.007 0 .463 r
.31837 .64245 m .31835 .64243 L .31978 .64154 L F
.31816 .64233 m .31794 .64239 L .31817 .64229 L F
.728 .202 0 r
.31794 .64239 m .31509 .63984 L .31816 .64233 L F
.31794 .64239 m .31816 .64233 L .31855 .64264 L F
.007 0 .463 r
.31816 .64259 m .31794 .64239 L .31816 .64233 L F
.31816 .64259 m .31816 .64233 L .31837 .64245 L F
.31978 .64404 m .31816 .64259 L .31978 .64154 L F
0 .189 .678 r
.31729 .64134 m .31814 .64222 L .31509 .63984 L F
.31814 .64222 m .31799 .64219 L .31509 .63984 L F
.477 .445 .744 r
.39797 .67036 m .39879 .67205 L .3965 .67222 L F
.846 .736 .743 r
.68476 .33138 m .68071 .33316 L .68307 .32965 L F
.68476 .33138 m .68315 .33478 L .68071 .33316 L F
.268 .267 .673 r
.1961 .58401 m .19664 .5878 L .19821 .58592 L F
.413 .476 .816 r
.19664 .5878 m .19989 .58978 L .19821 .58592 L F
0 0 0 r
.35886 .65889 m .35809 .65879 L .35989 .65717 L F
.357 .66222 m .35809 .65879 L .35886 .65889 L F
.196 .497 .905 r
.21705 .60795 m .21797 .60952 L .21841 .60797 L F
.257 .566 .937 r
.21797 .60952 m .22016 .60998 L .21841 .60797 L F
.677 .858 .968 r
.27283 .53109 m .27668 .53076 L .27491 .5303 L F
.487 .867 .978 r
.27715 .5295 m .27668 .53076 L .27895 .53005 L F
.27715 .5295 m .27491 .5303 L .27668 .53076 L F
.71 .623 .757 r
.35684 .59933 m .35434 .60267 L .35492 .60043 L F
0 0 .374 r
.73914 .32961 m .73827 .33447 L .73883 .33035 L F
.73914 .32961 m .73939 .33223 L .73827 .33447 L F
0 0 0 r
.73856 .33398 m .73827 .33447 L .73939 .33223 L F
.73856 .33398 m .73771 .3366 L .73827 .33447 L F
.755 .56 .633 r
.32346 .54932 m .31922 .55097 L .32154 .54781 L F
.32346 .54932 m .32332 .55217 L .31922 .55097 L F
.517 .815 .999 r
.32415 .54762 m .32346 .54932 L .32154 .54781 L F
.734 .666 .783 r
.32583 .54871 m .32332 .55217 L .32346 .54932 L F
.513 .127 .246 r
.32214 .54816 m .3206 .55052 L .32407 .5493 L F
.32154 .54781 m .32139 .54823 L .32214 .54816 L F
.32139 .54823 m .3206 .55052 L .32214 .54816 L F
.517 .815 .999 r
.324 .54798 m .32583 .54871 L .32346 .54932 L F
.32415 .54762 m .32461 .54792 L .324 .54798 L F
.32461 .54792 m .32583 .54871 L .324 .54798 L F
0 0 .172 r
.38183 .65053 m .38276 .65216 L .38308 .65194 L F
.38183 .65053 m .38138 .6524 L .38276 .65216 L F
.717 .364 .379 r
.38459 .66318 m .38876 .66541 L .38711 .66269 L F
.38459 .66318 m .38598 .66634 L .38876 .66541 L F
.525 .277 .482 r
.3854 .6637 m .38459 .66318 L .38711 .66269 L F
.3854 .6637 m .38598 .66634 L .38459 .66318 L F
.419 .795 .993 r
.37536 .51284 m .37636 .51427 L .37379 .51226 L F
.37536 .51284 m .3775 .51368 L .37636 .51427 L F
.277 0 .232 r
.6417 .43846 m .64476 .43562 L .64401 .43745 L F
0 0 0 r
.64476 .43562 m .64725 .43243 L .64613 .43427 L F
.64401 .43745 m .64476 .43562 L .64613 .43427 L F
.775 .852 .909 r
.33816 .55778 m .33359 .5576 L .33503 .55503 L F
.296 0 0 r
.33816 .55778 m .33346 .56039 L .33359 .5576 L F
.33816 .55778 m .33626 .56007 L .33346 .56039 L F
0 .298 .75 r
.33503 .55503 m .33648 .55582 L .33816 .55778 L F
.889 .917 .521 r
.33702 .55742 m .33816 .55778 L .33648 .55582 L F
.33702 .55742 m .33626 .56007 L .33816 .55778 L F
.392 .149 .422 r
.33875 .56297 m .34249 .55859 L .33816 .55778 L F
.701 .919 .967 r
.25239 .53743 m .25234 .5398 L .2544 .53696 L F
.25239 .53743 m .25023 .53903 L .25234 .5398 L F
.44 0 0 r
.25935 .62291 m .26158 .62371 L .26358 .62225 L F
.334 0 0 r
.26158 .62371 m .2661 .62235 L .26358 .62225 L F
.693 .193 0 r
.36808 .51106 m .36912 .51178 L .36627 .50869 L F
.961 .858 .694 r
.36675 .51301 m .36912 .51178 L .36808 .51106 L F
.36675 .51301 m .36825 .51436 L .36912 .51178 L F
.486 .683 .953 r
.64939 .39687 m .64475 .39468 L .64664 .39398 L F
.513 .694 .95 r
.65079 .39449 m .64939 .39687 L .64664 .39398 L F
.65079 .39449 m .65193 .39641 L .64939 .39687 L F
.23 .738 .688 r
.27528 .53921 m .27248 .54006 L .27038 .54075 L F
.244 .748 .695 r
.27506 .5392 m .27528 .53921 L .27775 .5389 L F
.27506 .5392 m .27248 .54006 L .27528 .53921 L F
0 0 0 r
.3801 .61262 m .37776 .61569 L .37937 .61417 L F
.075 .098 .58 r
.37776 .61569 m .37959 .61783 L .37937 .61417 L F
.37776 .61569 m .37845 .61818 L .37959 .61783 L F
.638 .31 .4 r
.69049 .35404 m .68871 .35556 L .68627 .35568 L F
.605 .268 .373 r
.69049 .35404 m .69308 .35556 L .68871 .35556 L F
.131 0 .059 r
.63649 .44477 m .63599 .4468 L .63373 .44824 L F
.067 0 .16 r
.63915 .44147 m .63897 .44367 L .63649 .44477 L F
0 0 .001 r
.63784 .44518 m .63649 .44477 L .63897 .44367 L F
.63784 .44518 m .63599 .4468 L .63649 .44477 L F
.976 .767 .558 r
.39938 .52067 m .39689 .52112 L .39794 .51709 L F
.988 .74 .465 r
.39938 .52067 m .39771 .5223 L .39689 .52112 L F
.39938 .52067 m .39917 .52361 L .39771 .5223 L F
.738 .7 .815 r
.40192 .51797 m .39938 .52067 L .39794 .51709 L F
.677 .142 0 r
.36098 .5853 m .36678 .58671 L .36465 .58785 L F
.629 .928 .672 r
.36465 .58785 m .36678 .58671 L .36755 .58521 L F
.605 .527 .74 r
.36787 .59018 m .36966 .58575 L .36678 .58671 L F
0 0 .363 r
.39803 .5433 m .39848 .54456 L .39731 .54223 L F
.991 .803 .553 r
.39803 .5433 m .39813 .54383 L .39848 .54456 L F
0 0 .325 r
.39731 .54223 m .39848 .54456 L .39898 .54559 L F
.991 .803 .553 r
.39813 .54383 m .39883 .54729 L .39848 .54456 L F
0 0 .325 r
.39898 .54559 m .39848 .54456 L .39909 .54581 L F
.853 .423 0 r
.39883 .54729 m .39909 .54581 L .39848 .54456 L F
.39883 .54729 m .39999 .54816 L .39909 .54581 L F
.649 .598 .784 r
.42276 .52101 m .41895 .51811 L .42148 .51718 L F
.673 .428 .543 r
.42276 .52101 m .42266 .5234 L .41844 .52345 L F
.547 .503 .759 r
.42427 .51667 m .42276 .52101 L .42148 .51718 L F
.42427 .51667 m .42511 .52051 L .42276 .52101 L F
.483 .272 .516 r
.42511 .52051 m .42266 .5234 L .42276 .52101 L F
.912 .975 .689 r
.36526 .52746 m .36378 .52909 L .36523 .52538 L F
.72 .633 .76 r
.21989 .57772 m .21834 .5749 L .21941 .57347 L F
.21989 .57772 m .21757 .57773 L .21834 .5749 L F
0 0 0 r
.21989 .57772 m .2173 .58037 L .21757 .57773 L F
.21989 .57772 m .21898 .5792 L .2173 .58037 L F
0 .018 .555 r
.22107 .57568 m .21989 .57772 L .21941 .57347 L F
0 0 0 r
.22026 .57823 m .21989 .57772 L .22107 .57568 L F
.22026 .57823 m .21898 .5792 L .21989 .57772 L F
.798 .742 .801 r
.36929 .61294 m .37021 .61585 L .36759 .61546 L F
.266 .401 .813 r
.37182 .61424 m .37021 .61585 L .36929 .61294 L F
.953 .608 .298 r
.36931 .61751 m .37096 .61853 L .37021 .61585 L F
.36931 .61751 m .37021 .61585 L .37182 .61424 L F
.305 .064 .375 r
.38681 .55791 m .38427 .56112 L .38516 .55786 L F
.653 .169 0 r
.33336 .70086 m .3363 .70432 L .33463 .70338 L F
.72 .266 .172 r
.33076 .7066 m .33459 .70726 L .33273 .70885 L F
.66 .153 .029 r
.33306 .70757 m .33459 .70726 L .33076 .7066 L F
.939 .892 .756 r
.3363 .70432 m .33306 .70757 L .33463 .70338 L F
.3363 .70432 m .33459 .70726 L .33306 .70757 L F
.432 .039 .192 r
.35836 .53285 m .36133 .53274 L .36231 .53062 L F
.711 .907 .964 r
.36231 .53062 m .36055 .52972 L .36378 .52909 L F
.745 .817 .909 r
.65092 .42427 m .65244 .426 L .64841 .4255 L F
.811 .733 .778 r
.65244 .426 m .64978 .42935 L .64841 .4255 L F
.42 .191 .458 r
.65244 .426 m .65229 .42843 L .64978 .42935 L F
.315 .717 .979 r
.65092 .42427 m .65478 .4251 L .65244 .426 L F
.371 .153 .447 r
.65478 .4251 m .65229 .42843 L .65244 .426 L F
0 0 .108 r
.28126 .64098 m .28358 .63784 L .28261 .64049 L F
.679 .429 .537 r
.57764 .44666 m .57312 .44436 L .57725 .44487 L F
.688 .281 .271 r
.57725 .44487 m .57981 .44719 L .57764 .44666 L F
.617 .316 .436 r
.58018 .44459 m .57981 .44719 L .57725 .44487 L F
.549 .672 .919 r
.2521 .63075 m .2561 .6324 L .25457 .63017 L F
.269 .516 .905 r
.25457 .63017 m .2561 .6324 L .2563 .63032 L F
.599 .827 .987 r
.2563 .63032 m .2561 .6324 L .25846 .63158 L F
.854 .873 .853 r
.71181 .3083 m .7093 .31137 L .71235 .31104 L F
.732 .741 .859 r
.71235 .31104 m .71381 .30695 L .71181 .3083 L F
.71235 .31104 m .71551 .30885 L .71381 .30695 L F
.23 0 0 r
.3444 .57347 m .34706 .57317 L .34847 .5718 L F
.397 0 0 r
.37269 .65469 m .37332 .65525 L .37161 .65348 L F
.686 .756 .905 r
.3964 .5862 m .39804 .58745 L .39389 .58717 L F
.871 .716 .687 r
.39804 .58745 m .39426 .58943 L .39389 .58717 L F
.39804 .58745 m .39702 .59111 L .39426 .58943 L F
.575 .38 .58 r
.60173 .43546 m .60178 .43812 L .59915 .4383 L F
.60173 .43546 m .60178 .43812 L .59915 .4383 L F
.602 .381 .553 r
.6041 .43523 m .60178 .43812 L .60173 .43546 L F
.373 .804 .629 r
.37666 .54528 m .37461 .54652 L .37814 .54531 L F
.37666 .54528 m .37337 .54719 L .37461 .54652 L F
.745 .226 0 r
.30819 .66134 m .31147 .66296 L .31058 .6632 L F
.794 .348 .185 r
.30819 .66134 m .31058 .6632 L .30847 .66396 L F
.411 .85 .741 r
.30946 .66352 m .31058 .6632 L .31259 .66212 L F
.30847 .66396 m .31058 .6632 L .30946 .66352 L F
.745 .226 0 r
.31147 .66296 m .312 .66322 L .31058 .6632 L F
.417 0 0 r
.31058 .6632 m .312 .66322 L .31452 .6643 L F
.25 .071 .432 r
.34137 .58381 m .34272 .58399 L .34352 .57992 L F
.834 .717 .734 r
.5541 .42908 m .55528 .43264 L .55157 .43155 L F
.828 .729 .756 r
.55157 .43155 m .55528 .43264 L .55342 .43532 L F
.756 .847 .919 r
.72747 .34025 m .72641 .34099 L .72501 .33955 L F
.831 .895 .886 r
.70791 .30035 m .70388 .30179 L .70686 .29898 L F
.871 .906 .852 r
.70974 .29836 m .70791 .30035 L .70686 .29898 L F
.582 .016 0 r
.2676 .63745 m .2703 .6381 L .26933 .63839 L F
.207 0 0 r
.2703 .6381 m .27103 .63898 L .26933 .63839 L F
.2703 .6381 m .27263 .63795 L .27103 .63898 L F
.67 .278 0 r
.26616 .63345 m .26685 .63461 L .26606 .63335 L F
.811 .498 0 r
.26685 .63461 m .26675 .63581 L .26606 .63335 L F
.26685 .63461 m .2676 .63745 L .26675 .63581 L F
0 .285 .779 r
.3794 .60607 m .3816 .60774 L .37949 .60497 L F
.58 .432 .645 r
.42869 .58327 m .42628 .58687 L .4269 .58417 L F
0 0 0 r
.64725 .43243 m .64978 .42935 L .64882 .43078 L F
.64613 .43427 m .64725 .43243 L .64882 .43078 L F
.903 .847 .778 r
.70899 .29533 m .70974 .29836 L .7085 .29656 L F
.871 .906 .852 r
.70974 .29836 m .70686 .29898 L .7085 .29656 L F
.827 .811 .835 r
.70899 .29533 m .71258 .29539 L .70974 .29836 L F
0 0 .014 r
.35588 .52328 m .35505 .52467 L .3559 .52248 L F
.556 .351 .557 r
.35588 .52328 m .35359 .52605 L .35505 .52467 L F
.35588 .52328 m .35609 .52602 L .35359 .52605 L F
.805 .595 .035 r
.35552 .52323 m .35583 .52477 L .35588 .52328 L F
.35583 .52477 m .35609 .52602 L .35588 .52328 L F
0 0 .014 r
.35588 .52328 m .3559 .52248 L .35661 .52066 L F
.652 .969 .837 r
.35661 .52066 m .35984 .51854 L .35835 .51915 L F
0 0 0 r
.35691 .52138 m .35661 .52066 L .35835 .51915 L F
.35683 .52148 m .35588 .52328 L .35661 .52066 L F
.35683 .52151 m .35588 .52328 L .35683 .52148 L F
.805 .595 .035 r
.35552 .52323 m .35588 .52328 L .35683 .52151 L F
0 0 0 r
.35654 .52242 m .35684 .52147 L .3558 .522 L F
.805 .595 .035 r
.35552 .52323 m .35683 .52151 L .35684 .52149 L F
0 0 0 r
.35552 .52323 m .35654 .52242 L .35625 .52226 L F
.35552 .52323 m .35625 .52226 L .3558 .522 L F
.35654 .52242 m .35943 .52014 L .35684 .52147 L F
.35684 .52149 m .35683 .52151 L .35683 .52148 L F
.07 0 0 r
.35943 .52014 m .35684 .52149 L .35686 .52146 L F
.35943 .52014 m .35686 .52146 L .35835 .51915 L F
0 0 0 r
.35686 .52146 m .35683 .52146 L .35691 .52138 L F
.35684 .52149 m .35683 .52148 L .35686 .52146 L F
.35683 .52148 m .35683 .52146 L .35686 .52146 L F
.3558 .522 m .35686 .52146 L .35608 .52076 L F
.35686 .52146 m .35943 .52014 L .35787 .52043 L F
.35683 .52146 m .35661 .52066 L .35691 .52138 L F
.35686 .52146 m .35787 .52043 L .35608 .52076 L F
.646 .524 .7 r
.35586 .51783 m .35608 .52076 L .35787 .52043 L F
.35867 .51965 m .35787 .52043 L .35943 .52014 L F
.35586 .51783 m .35787 .52043 L .35867 .51965 L F
.714 .69 .825 r
.63599 .39305 m .6362 .39748 L .63216 .39669 L F
.789 .746 .814 r
.63893 .39443 m .6362 .39748 L .63599 .39305 L F
.8 .589 .615 r
.56133 .41647 m .5574 .41845 L .55775 .41578 L F
.56133 .41647 m .56149 .41916 L .5574 .41845 L F
.661 .251 .256 r
.56133 .41647 m .56471 .41864 L .56149 .41916 L F
.296 .184 .553 r
.19741 .57451 m .19905 .57375 L .19891 .57105 L F
.286 .156 .523 r
.19739 .5772 m .19905 .57375 L .19741 .57451 L F
.33 0 .076 r
.3612 .61841 m .36364 .61802 L .36487 .6165 L F
.696 .318 .328 r
.36364 .61802 m .36743 .61826 L .36487 .6165 L F
.028 .123 .629 r
.4024 .67787 m .40202 .68176 L .40003 .67831 L F
.4024 .67787 m .40337 .68076 L .40202 .68176 L F
0 0 .1 r
.40337 .68076 m .4019 .68497 L .40202 .68176 L F
.653 .52 .688 r
.36751 .55561 m .36809 .55862 L .36502 .55877 L F
.639 .415 .562 r
.36809 .55862 m .3649 .5614 L .36502 .55877 L F
.268 .267 .673 r
.1961 .58401 m .19821 .58592 L .19749 .58328 L F
.279 .409 .815 r
.22695 .55746 m .22701 .55431 L .22444 .55726 L F
.493 .282 .521 r
.22697 .55683 m .22444 .55726 L .22697 .55682 L F
.289 .78 .898 r
.22695 .55746 m .22444 .55726 L .22219 .55764 L F
.493 .282 .521 r
.22657 .55958 m .22444 .55726 L .22697 .55683 L F
.289 .78 .898 r
.22219 .55764 m .22444 .55726 L .22213 .55765 L F
.279 .409 .815 r
.22695 .55746 m .22864 .55787 L .22701 .55431 L F
0 .134 .679 r
.2161 .59021 m .2183 .59258 L .21789 .59393 L F
.544 .89 .982 r
.21789 .59393 m .2183 .59258 L .22014 .59307 L F
.567 .804 .988 r
.72665 .28362 m .72283 .28296 L .72567 .2825 L F
.915 .944 .807 r
.72419 .287 m .72665 .28362 L .72567 .2825 L F
.639 .882 .986 r
.72567 .2825 m .72665 .28362 L .7282 .28137 L F
.7282 .28137 m .72665 .28362 L .72567 .2825 L F
.324 0 .233 r
.71345 .34395 m .71293 .3456 L .71619 .343 L F
.471 .217 .446 r
.24408 .562 m .24335 .56441 L .24096 .56483 L F
.4 .15 .415 r
.24572 .56355 m .24408 .562 L .24597 .56125 L F
.24572 .56355 m .24335 .56441 L .24408 .562 L F
.54 .252 .427 r
.59915 .4383 m .60197 .4403 L .59912 .44102 L F
.59915 .4383 m .60178 .43812 L .60197 .4403 L F
.262 0 0 r
.35581 .53301 m .35186 .53563 L .35344 .53409 L F
.563 .429 .656 r
.35848 .53068 m .35836 .53285 L .35581 .53301 L F
.684 .481 .606 r
.35581 .53301 m .35937 .53608 L .35836 .53285 L F
.022 0 0 r
.35702 .53397 m .35581 .53301 L .35836 .53285 L F
.684 .481 .606 r
.35581 .53301 m .35513 .53719 L .35937 .53608 L F
.022 0 0 r
.35702 .53397 m .35457 .53512 L .35581 .53301 L F
.699 .348 0 r
.40524 .56703 m .40685 .57076 L .40645 .56829 L F
.982 .798 .579 r
.42036 .57447 m .41829 .57612 L .4186 .57345 L F
.42036 .57447 m .4199 .57716 L .41829 .57612 L F
0 0 .331 r
.34571 .58427 m .34352 .57992 L .34593 .58 L F
.751 .533 .599 r
.34272 .58399 m .34593 .58 L .34352 .57992 L F
.34272 .58399 m .34571 .58427 L .34593 .58 L F
0 0 0 r
.34593 .58 m .34697 .57832 L .34737 .57596 L F
.491 .312 .566 r
.34895 .58283 m .34593 .58 L .3497 .58077 L F
.34895 .58283 m .34571 .58427 L .34593 .58 L F
0 0 .226 r
.34593 .58 m .3469 .58145 L .34697 .57832 L F
.34593 .58 m .34571 .58427 L .3469 .58145 L F
.17 .664 .918 r
.55722 .39399 m .5581 .39418 L .55853 .39466 L F
.475 .267 .517 r
.55972 .3943 m .55917 .39537 L .55853 .39466 L F
.576 .001 0 r
.56236 .39605 m .55972 .3943 L .55853 .39466 L F
.55 .605 .861 r
.56401 .39681 m .55972 .3943 L .56236 .39605 L F
.17 .664 .918 r
.5581 .39418 m .56094 .39481 L .55853 .39466 L F
.475 .267 .517 r
.55917 .39537 m .55827 .39711 L .55853 .39466 L F
.61 .524 .732 r
.22409 .57522 m .2257 .57069 L .22267 .57128 L F
.22409 .57522 m .22654 .57445 L .2257 .57069 L F
.586 .448 .66 r
.22409 .57522 m .2263 .57714 L .22654 .57445 L F
.22409 .57522 m .22399 .57764 L .2263 .57714 L F
.324 .136 .464 r
.28435 .53927 m .28651 .5359 L .28439 .53662 L F
.279 .143 .51 r
.31747 .58649 m .31758 .58926 L .31523 .58973 L F
.331 .101 .407 r
.31758 .58926 m .31492 .5925 L .31523 .58973 L F
.861 .513 .004 r
.39575 .53863 m .39731 .54223 L .39663 .54003 L F
.445 .175 .408 r
.3531 .53935 m .35513 .53719 L .3534 .53667 L F
.777 .452 .438 r
.36774 .57634 m .37152 .5747 L .36773 .57422 L F
.36774 .57634 m .37173 .57687 L .37152 .5747 L F
.563 .926 .941 r
.64574 .42843 m .64331 .42959 L .64142 .42938 L F
.691 .941 .651 r
.65464 .40504 m .65598 .40303 L .65675 .40383 L F
.65464 .40504 m .65391 .40537 L .65598 .40303 L F
.602 .95 .821 r
.35835 .51915 m .35984 .51854 L .36165 .51713 L F
0 0 0 r
.64978 .42935 m .65117 .42971 L .64882 .43078 L F
.64978 .42935 m .65202 .42852 L .65117 .42971 L F
.056 0 .167 r
.65117 .42971 m .64869 .43301 L .64882 .43078 L F
.724 .848 .413 r
.65038 .43082 m .65117 .42971 L .65213 .42733 L F
0 0 0 r
.65025 .43108 m .64869 .43301 L .65117 .42971 L F
.724 .848 .413 r
.65025 .43108 m .65117 .42971 L .65038 .43082 L F
0 0 0 r
.65202 .42852 m .65229 .42843 L .65117 .42971 L F
.776 .66 .735 r
.34103 .50805 m .33776 .5079 L .33956 .50463 L F
.505 .118 .24 r
.34103 .50805 m .33688 .51044 L .33776 .5079 L F
.814 .675 .71 r
.33788 .51142 m .33795 .51135 L .33688 .51044 L F
0 0 0 r
.3406 .50863 m .33816 .51116 L .34103 .50805 L F
.33941 .50988 m .33816 .51116 L .3406 .50863 L F
.33816 .51116 m .33795 .51135 L .34103 .50805 L F
.505 .118 .24 r
.34103 .50805 m .33795 .51135 L .33688 .51044 L F
.704 .76 .262 r
.33776 .5079 m .33688 .51044 L .33745 .50853 L F
0 0 .069 r
.34053 .50872 m .33884 .51238 L .33816 .51116 L F
.814 .675 .71 r
.3387 .51199 m .33745 .50853 L .33719 .50941 L F
.33856 .51187 m .33719 .50941 L .33688 .51044 L F
.3387 .51199 m .33719 .50941 L .33856 .51187 L F
.33884 .51238 m .3387 .51199 L .33795 .51135 L F
.33884 .51238 m .33795 .51135 L .33788 .51142 L F
.445 .206 .456 r
.33688 .51044 m .33884 .51238 L .33666 .51271 L F
.624 .183 .182 r
.33744 .51191 m .33884 .51238 L .33688 .51044 L F
0 0 .069 r
.33816 .51116 m .33884 .51238 L .33744 .51191 L F
.505 .118 .24 r
.33795 .51135 m .33744 .51191 L .33688 .51044 L F
.567 .184 .276 r
.33446 .51097 m .33666 .51271 L .33688 .51044 L F
.091 0 .343 r
.33744 .51191 m .33666 .51271 L .33688 .51044 L F
.814 .675 .71 r
.33834 .511 m .33632 .51224 L .33745 .50853 L F
.33884 .51238 m .33712 .51229 L .33834 .511 L F
0 0 0 r
.33816 .51116 m .33744 .51191 L .33795 .51135 L F
.814 .675 .71 r
.33712 .51229 m .33632 .51224 L .33834 .511 L F
0 0 0 r
.34053 .50872 m .33941 .50988 L .3406 .50863 L F
.34418 .50717 m .34176 .50803 L .34103 .50805 L F
.34053 .50872 m .34103 .50805 L .34176 .50803 L F
.335 .012 .26 r
.30186 .58979 m .30409 .58922 L .30508 .58642 L F
.281 .127 .486 r
.30508 .58642 m .30833 .58297 L .30442 .58393 L F
.30508 .58642 m .30793 .58639 L .30833 .58297 L F
.515 .32 .554 r
.30409 .58922 m .30793 .58639 L .30508 .58642 L F
.217 0 .163 r
.37718 .71273 m .3781 .7102 L .38027 .70998 L F
.046 .131 .63 r
.35696 .61178 m .3579 .6161 L .35889 .61442 L F
.594 .847 .992 r
.3579 .6161 m .3606 .61549 L .35889 .61442 L F
.309 .507 .887 r
.3579 .6161 m .3612 .61841 L .3606 .61549 L F
.639 .966 .873 r
.28424 .5215 m .27981 .52328 L .28225 .52229 L F
.242 .758 .793 r
.2846 .52111 m .28424 .5215 L .28225 .52229 L F
.2846 .52111 m .28636 .52102 L .28424 .5215 L F
.432 .406 .73 r
.28816 .5561 m .29112 .55739 L .29052 .55363 L F
.37 .069 .318 r
.23807 .57112 m .23536 .57379 L .23624 .57182 L F
.634 .923 .976 r
.2461 .53821 m .24554 .53989 L .24785 .53957 L F
.2461 .53821 m .24395 .53934 L .24554 .53989 L F
.576 .567 .807 r
.31813 .57655 m .31948 .58042 L .31713 .58101 L F
.416 .251 .547 r
.31948 .58042 m .31736 .58377 L .31713 .58101 L F
0 0 0 r
.33666 .51271 m .33588 .51725 L .33869 .51428 L F
.514 .502 .781 r
.33869 .51428 m .34205 .51711 L .34127 .51406 L F
.85 .515 .419 r
.41808 .54546 m .418 .54891 L .42146 .54977 L F
0 .073 .554 r
.41652 .54215 m .41854 .54391 L .41808 .54546 L F
.539 .251 .425 r
.42029 .5479 m .418 .54891 L .41808 .54546 L F
.555 .504 .753 r
.32593 .51495 m .32865 .51694 L .32988 .51576 L F
.011 0 0 r
.32865 .51694 m .33182 .51416 L .32988 .51576 L F
.901 .671 .58 r
.70519 .32387 m .70695 .32748 L .707 .32482 L F
.436 0 0 r
.38731 .5869 m .38355 .58836 L .38465 .58672 L F
.58 .943 .84 r
.3001 .6274 m .30404 .62574 L .30048 .62384 L F
.734 .666 .783 r
.32583 .54871 m .32735 .55242 L .32332 .55217 L F
.345 .2 .537 r
.32553 .55396 m .32332 .55217 L .32735 .55242 L F
.076 0 0 r
.32999 .55191 m .32553 .55396 L .32735 .55242 L F
.824 .885 .456 r
.33047 .53333 m .33069 .53129 L .33167 .52975 L F
0 .227 .746 r
.33047 .53333 m .33137 .53365 L .33069 .53129 L F
0 0 .187 r
.40748 .57329 m .40778 .57465 L .40685 .57076 L F
.795 .384 0 r
.40783 .57596 m .40778 .57465 L .40748 .57329 L F
.40783 .57596 m .40876 .57668 L .40778 .57465 L F
.715 .441 .51 r
.3363 .64288 m .34021 .6437 L .33947 .64201 L F
.627 .516 .708 r
.36016 .55725 m .36338 .5535 L .35954 .5564 L F
.839 .947 .89 r
.37712 .55099 m .37768 .54829 L .37905 .5486 L F
.37712 .55099 m .37481 .55103 L .37768 .54829 L F
.354 .812 .934 r
.31947 .53091 m .31709 .53054 L .31426 .53101 L F
.792 .951 .923 r
.31947 .52879 m .31947 .53091 L .32112 .52797 L F
.31947 .52879 m .31709 .53054 L .31947 .53091 L F
.669 .891 .978 r
.37631 .62528 m .37262 .62524 L .37441 .62318 L F
.739 .77 .878 r
.37686 .62297 m .37631 .62528 L .37441 .62318 L F
.637 .869 .985 r
.35743 .71366 m .35922 .71466 L .36173 .71347 L F
.526 .361 .6 r
.24354 .5673 m .24096 .56483 L .24335 .56441 L F
.24354 .5673 m .24112 .56785 L .24096 .56483 L F
.348 .438 .812 r
.38782 .66128 m .3854 .6637 L .38711 .66269 L F
.663 .625 .801 r
.38711 .66269 m .39089 .6631 L .39011 .6604 L F
.704 .505 .616 r
.38876 .66541 m .39089 .6631 L .38711 .66269 L F
.88 .653 .129 r
.40889 .58359 m .40902 .58616 L .40941 .58681 L F
.819 .771 .262 r
.40876 .58871 m .40941 .58681 L .40902 .58616 L F
.22 .01 .367 r
.38254 .60898 m .3801 .61262 L .3819 .61167 L F
.703 .492 .599 r
.37959 .61783 m .38042 .61289 L .37937 .61417 L F
.003 0 0 r
.38106 .61212 m .3801 .61262 L .37982 .61322 L F
.38046 .61285 m .37982 .61322 L .37937 .61417 L F
.38106 .61212 m .37982 .61322 L .38046 .61285 L F
.401 .356 .693 r
.38052 .61281 m .38478 .61675 L .3843 .61405 L F
.38044 .61279 m .38049 .61283 L .38052 .61281 L F
.38049 .61283 m .38478 .61675 L .38052 .61281 L F
.703 .492 .599 r
.38042 .61289 m .38044 .61279 L .37937 .61417 L F
.37959 .61783 m .38268 .61731 L .38047 .61284 L F
.38042 .61289 m .38047 .61284 L .38044 .61279 L F
.37959 .61783 m .38047 .61284 L .38042 .61289 L F
.003 0 0 r
.3819 .61167 m .38123 .61203 L .38056 .6128 L F
.465 .293 .562 r
.38044 .61279 m .38072 .61266 L .3819 .61167 L F
.38072 .61266 m .38434 .61105 L .3819 .61167 L F
.38072 .61266 m .3843 .61405 L .38434 .61105 L F
.003 0 0 r
.38057 .61279 m .38042 .61289 L .37937 .61417 L F
.38123 .61203 m .38047 .61284 L .38057 .61279 L F
.401 .356 .693 r
.38047 .61284 m .38268 .61731 L .38049 .61283 L F
.003 0 0 r
.38047 .61284 m .38042 .61289 L .38057 .61279 L F
.401 .356 .693 r
.38049 .61283 m .38268 .61731 L .38478 .61675 L F
.38044 .61279 m .38047 .61284 L .38049 .61283 L F
.465 .293 .562 r
.38044 .61279 m .38052 .61281 L .38072 .61266 L F
.38052 .61281 m .3843 .61405 L .38072 .61266 L F
.003 0 0 r
.38147 .6121 m .38056 .6128 L .37937 .61417 L F
.3819 .61167 m .38072 .61266 L .38147 .6121 L F
.38072 .61266 m .38056 .6128 L .38147 .6121 L F
.38123 .61203 m .38106 .61212 L .38042 .61289 L F
.873 .792 .768 r
.41895 .51811 m .41515 .51981 L .41802 .51739 L F
.41895 .51811 m .41683 .52089 L .41515 .51981 L F
.725 .844 .938 r
.42148 .51718 m .41895 .51811 L .41901 .51607 L F
.897 .959 .827 r
.41901 .51607 m .41895 .51811 L .41802 .51739 L F
.866 .722 .701 r
.68315 .33478 m .68206 .33701 L .68071 .33316 L F
.582 .944 .85 r
.24652 .52986 m .2473 .52869 L .24842 .52856 L F
.511 .897 .953 r
.24652 .52986 m .24501 .52958 L .2473 .52869 L F
.424 .133 .365 r
.33866 .58688 m .33769 .58945 L .34034 .58874 L F
.434 .846 .967 r
.37459 .59311 m .37585 .59352 L .37832 .5928 L F
.572 .467 .696 r
.36654 .54042 m .36487 .54298 L .36487 .54022 L F
.321 .16 .5 r
.36715 .54188 m .36487 .54298 L .36654 .54042 L F
.486 .272 .513 r
.36715 .54188 m .36418 .54485 L .36487 .54298 L F
.041 0 .292 r
.31251 .56091 m .31424 .55785 L .3126 .55876 L F
0 .165 .699 r
.40596 .53687 m .40758 .53733 L .40465 .53537 L F
.40596 .53687 m .40818 .53868 L .40758 .53733 L F
.705 .298 .273 r
.60821 .43822 m .61213 .43863 L .61165 .44045 L F
.822 .445 .342 r
.61213 .43863 m .61604 .44163 L .6147 .44039 L F
.607 .2 .246 r
.61165 .44045 m .61213 .43863 L .6147 .44039 L F
0 0 0 r
.26944 .54105 m .26843 .54052 L .27038 .54075 L F
.26944 .54105 m .26712 .54232 L .26843 .54052 L F
.39245 .55629 m .3892 .55709 L .39099 .55672 L F
.16 0 .169 r
.29265 .6056 m .29467 .60537 L .29524 .60274 L F
.199 0 .34 r
.29524 .60274 m .29778 .60287 L .29753 .59937 L F
.208 0 .184 r
.29524 .60274 m .29635 .60457 L .29778 .60287 L F
.29524 .60274 m .29467 .60537 L .29635 .60457 L F
.428 .338 .652 r
.25071 .55186 m .25121 .55496 L .24918 .55536 L F
.082 0 .281 r
.25121 .55496 m .24887 .55816 L .24918 .55536 L F
.749 .533 .603 r
.69911 .35261 m .69538 .3551 L .69535 .353 L F
.422 .178 .437 r
.71551 .30885 m .71754 .30582 L .7139 .30467 L F
.71551 .30885 m .71805 .30775 L .71754 .30582 L F
.71754 .30582 m .71805 .30775 L .71551 .30885 L F
.73 .68 .802 r
.23815 .58406 m .23599 .5873 L .23414 .58318 L F
.618 .526 .728 r
.23815 .58406 m .23875 .58715 L .23599 .5873 L F
.602 .335 .485 r
.23875 .58715 m .23552 .58964 L .23599 .5873 L F
.549 .824 .997 r
.3641 .71305 m .36606 .71426 L .36822 .7136 L F
.48 .268 .513 r
.63915 .44147 m .6417 .43846 L .64153 .44071 L F
.091 0 .165 r
.64074 .44242 m .63915 .44147 L .64153 .44071 L F
.64074 .44242 m .63897 .44367 L .63915 .44147 L F
.551 .542 .798 r
.29419 .618 m .29282 .62015 L .29197 .61904 L F
.29419 .618 m .29614 .62171 L .29282 .62015 L F
.427 .157 .4 r
.23326 .57468 m .23276 .57697 L .23044 .57755 L F
.23326 .57468 m .23276 .57697 L .23044 .57755 L F
0 .463 .843 r
.23536 .57379 m .23101 .57172 L .23326 .57468 L F
.545 .264 .439 r
.23326 .57468 m .2353 .57656 L .23536 .57379 L F
.23326 .57468 m .23276 .57697 L .2353 .57656 L F
.23326 .57468 m .2353 .57656 L .23536 .57379 L F
.23326 .57468 m .23276 .57697 L .2353 .57656 L F
.752 .58 .662 r
.33645 .51474 m .33673 .51798 L .33934 .51545 L F
0 0 0 r
.33637 .51436 m .33642 .51497 L .33588 .51725 L F
.33642 .51497 m .33635 .51545 L .33588 .51725 L F
.33646 .51479 m .33643 .51514 L .33637 .51436 L F
.495 .284 .522 r
.33521 .519 m .33164 .5232 L .33285 .52002 L F
.33521 .519 m .33505 .52247 L .33164 .5232 L F
.397 .235 .542 r
.3325 .51785 m .33466 .51971 L .33489 .51952 L F
.024 .108 .614 r
.33617 .51614 m .33521 .519 L .33588 .51725 L F
.33635 .51545 m .33591 .51682 L .33617 .51614 L F
.33591 .51682 m .33521 .519 L .33617 .51614 L F
.752 .58 .662 r
.33605 .5163 m .33635 .51545 L .33645 .51474 L F
.024 .108 .614 r
.33643 .51514 m .33618 .51594 L .33635 .51545 L F
.33618 .51594 m .33521 .519 L .33635 .51545 L F
.33618 .51594 m .33673 .51798 L .33521 .519 L F
.752 .58 .662 r
.33618 .51594 m .33625 .51619 L .33635 .51545 L F
.33618 .51663 m .33673 .51798 L .33645 .51474 L F
.024 .108 .614 r
.33643 .51514 m .33673 .51798 L .33618 .51594 L F
.752 .58 .662 r
.33605 .5163 m .33618 .51663 L .33625 .51619 L F
.33605 .5163 m .33625 .51619 L .33618 .51594 L F
.57 .548 .79 r
.33673 .51798 m .33505 .52247 L .33521 .519 L F
.397 .235 .542 r
.33548 .51794 m .33489 .51952 L .33673 .51798 L F
.3325 .51785 m .33489 .51952 L .33548 .51794 L F
.752 .58 .662 r
.33531 .51446 m .33605 .5163 L .33645 .51474 L F
0 0 0 r
.33642 .51497 m .33643 .51514 L .33635 .51545 L F
.734 .281 .176 r
.33934 .51545 m .33643 .51514 L .33646 .51479 L F
.752 .58 .662 r
.33645 .51474 m .33934 .51545 L .33646 .51479 L F
.734 .281 .176 r
.33934 .51545 m .33646 .51479 L .33666 .51271 L F
.752 .58 .662 r
.33646 .51479 m .33934 .51545 L .33648 .51486 L F
.33648 .51486 m .33934 .51545 L .33692 .51501 L F
.33531 .51446 m .33645 .51474 L .33648 .51486 L F
0 0 0 r
.33666 .51271 m .33646 .51479 L .33637 .51436 L F
.848 .867 .856 r
.21941 .57347 m .22267 .57128 L .22098 .573 L F
.638 .636 .833 r
.22305 .56871 m .22267 .57128 L .2257 .57069 L F
0 0 0 r
.22285 .57014 m .22267 .57128 L .22305 .56871 L F
.549 .497 .75 r
.22285 .57014 m .22098 .573 L .22267 .57128 L F
.045 .158 .659 r
.60931 .41757 m .60821 .41949 L .61003 .4211 L F
0 .443 .86 r
.41446 .53582 m .41623 .53733 L .41335 .53618 L F
.66 .803 .952 r
.41792 .53591 m .41452 .53652 L .41446 .53577 L F
0 .443 .86 r
.41455 .53579 m .41623 .53733 L .41446 .53582 L F
.66 .803 .952 r
.41515 .53641 m .41623 .53733 L .41452 .53652 L F
.41792 .53591 m .41623 .53733 L .41515 .53641 L F
0 .443 .86 r
.41441 .53562 m .41335 .53618 L .41201 .53272 L F
.41446 .53543 m .41201 .53272 L .41351 .53149 L F
.41441 .53562 m .41201 .53272 L .41446 .53543 L F
.677 .46 .585 r
.41206 .53266 m .4143 .53548 L .41351 .53149 L F
.66 .803 .952 r
.41446 .53577 m .41441 .53562 L .41452 .53542 L F
0 .443 .86 r
.41455 .53579 m .41441 .53562 L .41446 .53543 L F
.677 .46 .585 r
.4143 .53548 m .41455 .53579 L .41446 .53543 L F
.4143 .53548 m .41446 .53543 L .41351 .53149 L F
.66 .803 .952 r
.41465 .53538 m .41452 .53542 L .4154 .53386 L F
.41446 .53577 m .41452 .53542 L .41465 .53538 L F
.41441 .53562 m .41413 .53476 L .41482 .53427 L F
.41441 .53562 m .41482 .53427 L .4154 .53386 L F
0 .443 .86 r
.41445 .53567 m .41443 .53568 L .41441 .53562 L F
.41443 .53568 m .41335 .53618 L .41441 .53562 L F
.66 .803 .952 r
.41792 .53591 m .41446 .53577 L .4154 .53386 L F
.41446 .53577 m .4128 .5357 L .41436 .53547 L F
0 .443 .86 r
.41455 .53579 m .41446 .53582 L .41445 .53567 L F
.702 .463 .559 r
.4128 .5357 m .41455 .53579 L .4143 .53548 L F
.4128 .5357 m .4143 .53548 L .41206 .53266 L F
.66 .803 .952 r
.41436 .53547 m .4128 .5357 L .41413 .53476 L F
0 .443 .86 r
.41446 .53582 m .41335 .53618 L .41445 .53567 L F
.66 .803 .952 r
.41446 .53577 m .41452 .53652 L .4128 .5357 L F
0 0 .173 r
.29586 .5538 m .29458 .55811 L .29519 .55557 L F
.826 .812 .837 r
.71135 .29238 m .71258 .29539 L .70899 .29533 L F
.849 .821 .82 r
.71512 .29228 m .71258 .29539 L .71135 .29238 L F
.951 .768 .621 r
.2197 .56457 m .22213 .56523 L .2219 .56302 L F
.2197 .56457 m .22099 .56751 L .22213 .56523 L F
.502 0 0 r
.34164 .59399 m .33955 .59366 L .34184 .59395 L F
.34164 .59399 m .34158 .59449 L .33955 .59366 L F
.679 .346 0 r
.60384 .40309 m .60531 .40685 L .60475 .40547 L F
.85 .539 .009 r
.60531 .40685 m .6051 .40791 L .60475 .40547 L F
.512 .613 .89 r
.62558 .3942 m .622 .3917 L .62425 .39064 L F
.747 .461 .498 r
.62425 .39064 m .62829 .3936 L .62558 .3942 L F
.431 .285 .581 r
.41633 .52353 m .41622 .52628 L .41401 .52679 L F
.282 .199 .582 r
.41622 .52628 m .41478 .52981 L .41401 .52679 L F
.995 .764 .469 r
.34496 .63478 m .34513 .63788 L .34367 .63641 L F
.541 .413 .654 r
.34496 .63478 m .34864 .63731 L .34513 .63788 L F
.471 0 0 r
.34656 .63609 m .34496 .63478 L .34367 .63641 L F
.458 .158 .367 r
.34513 .63788 m .34864 .63731 L .34752 .63937 L F
.34733 .6394 m .34752 .63937 L .34745 .63948 L F
.34513 .63788 m .34752 .63937 L .34733 .6394 L F
.56 .808 .991 r
.3411 .63688 m .34513 .63788 L .34367 .63641 L F
.977 .676 .318 r
.34367 .63641 m .34513 .63788 L .34505 .64001 L F
.458 .158 .367 r
.34513 .63788 m .34745 .63948 L .34505 .64001 L F
.553 .536 .79 r
.34498 .63984 m .34656 .63609 L .34367 .63641 L F
.34505 .64001 m .34513 .63981 L .34498 .63984 L F
.34513 .63981 m .34656 .63609 L .34498 .63984 L F
.471 0 0 r
.34849 .63722 m .34864 .63731 L .34849 .63721 L F
.34849 .63722 m .34849 .63721 L .34496 .63478 L F
.593 .818 .986 r
.34876 .63666 m .34864 .63731 L .34656 .63609 L F
.842 .909 .503 r
.34745 .63948 m .34864 .63731 L .34876 .63666 L F
0 0 0 r
.34818 .63801 m .34745 .63948 L .34848 .63727 L F
.34845 .63739 m .34848 .63727 L .34876 .63666 L F
.34818 .63801 m .34848 .63727 L .34845 .63739 L F
.471 0 0 r
.34656 .63609 m .34849 .63722 L .34496 .63478 L F
.729 .217 0 r
.35143 .51409 m .34782 .51184 L .35273 .51226 L F
.265 .773 .793 r
.55863 .39796 m .56401 .39681 L .56236 .39605 L F
.777 .945 .932 r
.36269 .63484 m .36346 .6323 L .36072 .63378 L F
.871 .696 .662 r
.36072 .63378 m .36205 .63738 L .36269 .63484 L F
.46 .791 .999 r
.35863 .67563 m .36034 .67549 L .35949 .67499 L F
.517 .191 .355 r
.35752 .67573 m .35864 .67689 L .36034 .67549 L F
.687 .87 .968 r
.35824 .67426 m .36034 .67549 L .36058 .67367 L F
.861 .99 .836 r
.36034 .67549 m .35864 .67689 L .36058 .67367 L F
0 0 .424 r
.36058 .67367 m .36034 .67549 L .36095 .67407 L F
0 0 0 r
.36095 .67407 m .35864 .67689 L .36001 .67461 L F
.36086 .67398 m .36001 .67461 L .36058 .67367 L F
.36095 .67407 m .36001 .67461 L .36086 .67398 L F
.46 .791 .999 r
.35752 .67573 m .35863 .67563 L .35824 .67426 L F
.35863 .67563 m .35949 .67499 L .35824 .67426 L F
0 0 .144 r
.35824 .67426 m .35864 .67689 L .35752 .67573 L F
0 0 0 r
.3151 .52785 m .31598 .52806 L .31759 .52739 L F
.3151 .52785 m .31341 .52902 L .31598 .52806 L F
.35875 .5478 m .3578 .55055 L .35597 .55242 L F
.471 .458 .762 r
.36063 .54503 m .35875 .5478 L .35822 .54562 L F
.36063 .54503 m .36144 .54758 L .35875 .5478 L F
.826 .403 .236 r
.35947 .54972 m .35875 .5478 L .36144 .54758 L F
.35947 .54972 m .3578 .55055 L .35875 .5478 L F
.992 .806 .556 r
.35822 .54562 m .3572 .54737 L .35875 .5478 L F
.441 .567 .886 r
.22399 .57764 m .22817 .58092 L .2263 .57714 L F
.458 .221 .466 r
.22539 .58396 m .22764 .58374 L .22817 .58092 L F
.745 .651 .757 r
.2263 .57714 m .22817 .58092 L .23044 .57755 L F
.357 0 0 r
.37845 .51754 m .38144 .51879 L .38247 .51897 L F
.157 0 0 r
.38144 .51879 m .38527 .51955 L .38247 .51897 L F
.751 .705 .808 r
.36007 .56848 m .36131 .57165 L .35768 .57134 L F
.676 .666 .833 r
.36411 .56741 m .36131 .57165 L .36007 .56848 L F
0 .03 .599 r
.60714 .4115 m .60686 .41307 L .6085 .41519 L F
.716 .448 .518 r
.38164 .59061 m .38184 .59289 L .37832 .5928 L F
.615 .585 .797 r
.38355 .58836 m .38184 .59289 L .38164 .59061 L F
.915 .944 .807 r
.72419 .287 m .72567 .2825 L .72283 .28296 L F
.187 0 .076 r
.6417 .43846 m .64355 .43942 L .64153 .44071 L F
.6417 .43846 m .64401 .43745 L .64355 .43942 L F
.913 .972 .677 r
.3376 .50604 m .33705 .50494 L .33607 .50562 L F
.3376 .50604 m .33956 .50463 L .33705 .50494 L F
.99 .798 .551 r
.40065 .51123 m .40018 .51396 L .39876 .51241 L F
.589 .831 .99 r
.4033 .51063 m .40065 .51123 L .40146 .50914 L F
.79 .982 .714 r
.40065 .51123 m .39876 .51241 L .40146 .50914 L F
.625 .584 .788 r
.40488 .51457 m .40065 .51123 L .4033 .51063 L F
.474 .486 .79 r
.42894 .57067 m .42775 .57425 L .42663 .5708 L F
.62 .471 .658 r
.43054 .5776 m .42775 .57425 L .42986 .57368 L F
.43054 .5776 m .42853 .5789 L .42775 .57425 L F
.269 0 0 r
.72519 .35366 m .72439 .35436 L .72132 .3543 L F
.708 .444 .524 r
.40488 .51457 m .40412 .5173 L .40082 .51509 L F
.483 .501 .8 r
.40647 .5125 m .40488 .51457 L .4033 .51063 L F
0 0 .129 r
.40583 .5151 m .40488 .51457 L .40647 .5125 L F
.40583 .5151 m .40412 .5173 L .40488 .51457 L F
.502 .861 .989 r
.35954 .66525 m .35886 .66668 L .35698 .66576 L F
.35954 .66525 m .3613 .66596 L .35886 .66668 L F
.555 .504 .753 r
.32593 .51495 m .32624 .5178 L .32865 .51694 L F
.234 .035 .393 r
.32628 .52053 m .32865 .51694 L .32624 .5178 L F
.359 .13 .423 r
.62063 .41626 m .62323 .41292 L .62274 .41511 L F
.137 0 0 r
.62063 .41626 m .62274 .41511 L .62208 .41693 L F
.55 .666 .914 r
.24959 .62819 m .2521 .63075 L .25457 .63017 L F
.849 .821 .82 r
.71512 .29228 m .71135 .29238 L .71404 .2916 L F
.849 .972 .873 r
.71772 .28941 m .71512 .29228 L .71404 .2916 L F
.552 .624 .877 r
.369 .51071 m .36825 .51436 L .36675 .51301 L F
.369 .51071 m .37067 .51368 L .36825 .51436 L F
.315 .241 .612 r
.34689 .59689 m .34893 .59916 L .34956 .59599 L F
.34689 .59689 m .347 .59957 L .34893 .59916 L F
.767 .987 .899 r
.73054 .33634 m .73326 .33287 L .73398 .3337 L F
.73054 .33634 m .73006 .33532 L .73326 .33287 L F
.942 .73 .259 r
.40831 .58212 m .40887 .58086 L .40911 .57933 L F
.40831 .58212 m .40889 .58359 L .40887 .58086 L F
.572 .902 .655 r
.29472 .54 m .29482 .54031 L .29721 .54079 L F
.29472 .54 m .29277 .54168 L .29482 .54031 L F
.618 .316 .436 r
.58349 .44646 m .58018 .44459 L .58359 .44419 L F
.58349 .44646 m .57981 .44719 L .58018 .44459 L F
.226 .61 .953 r
.26201 .63254 m .26265 .63129 L .26034 .6315 L F
.26201 .63254 m .26616 .63345 L .26265 .63129 L F
.954 .742 .577 r
.61604 .44163 m .61381 .443 L .6147 .44039 L F
.61604 .44163 m .61575 .44429 L .61381 .443 L F
.752 .965 .933 r
.26738 .75389 m .27007 .75362 L .26954 .75383 L F
.852 .946 .88 r
.26738 .75389 m .26954 .75383 L .26767 .75559 L F
.921 .739 .638 r
.26878 .75732 m .27007 .75362 L .26738 .75389 L F
.583 .409 .61 r
.37017 .55498 m .36751 .55561 L .36978 .55254 L F
.578 .808 .415 r
.37395 .55222 m .37358 .55275 L .37481 .55103 L F
.565 .587 .834 r
.37481 .55103 m .37375 .55277 L .37366 .55263 L F
.37481 .55103 m .37366 .55263 L .37101 .54805 L F
.578 .808 .415 r
.37358 .55275 m .3724 .55439 L .37481 .55103 L F
.37379 .55245 m .3724 .55439 L .37395 .55222 L F
.591 .25 .36 r
.37357 .55276 m .3724 .55439 L .36978 .55254 L F
.37375 .55277 m .3724 .55439 L .37357 .55276 L F
.319 .176 .525 r
.39942 .6879 m .39941 .69082 L .39734 .69142 L F
.105 0 .257 r
.39941 .69082 m .39706 .69424 L .39734 .69142 L F
.862 .84 .822 r
.3433 .65356 m .34562 .6509 L .3439 .64955 L F
.466 .708 .973 r
.34562 .6509 m .3463 .64903 L .3439 .64955 L F
.445 .549 .868 r
.22401 .56189 m .2198 .55844 L .22213 .55765 L F
.828 .729 .756 r
.55157 .43155 m .55342 .43532 L .55122 .43443 L F
.73 .371 .371 r
.55342 .43532 m .55112 .43723 L .55122 .43443 L F
.55342 .43532 m .55508 .43755 L .55112 .43723 L F
.491 .41 .692 r
.37033 .55778 m .36751 .55561 L .37017 .55498 L F
.37033 .55778 m .36809 .55862 L .36751 .55561 L F
.114 0 0 r
.22065 .58602 m .22539 .58396 L .22128 .58409 L F
.22065 .58602 m .22295 .58555 L .22539 .58396 L F
.004 0 0 r
.22539 .58396 m .22579 .58472 L .22764 .58374 L F
.22539 .58396 m .22295 .58555 L .22498 .58496 L F
.507 .348 .6 r
.22498 .58496 m .2255 .58778 L .22579 .58472 L F
.22295 .58555 m .22362 .58614 L .22498 .58496 L F
.632 .656 .855 r
.22482 .58493 m .22387 .58602 L .21987 .58084 L F
.22387 .58602 m .22369 .58623 L .22363 .58614 L F
.22387 .58602 m .22363 .58614 L .21987 .58084 L F
.806 .418 .319 r
.2192 .5834 m .22065 .58602 L .22128 .58409 L F
.838 .378 0 r
.21939 .58508 m .22065 .58602 L .2192 .5834 L F
.53 .794 .994 r
.21939 .58508 m .22295 .58555 L .22065 .58602 L F
.21939 .58508 m .22295 .58555 L .22065 .58602 L F
.519 .488 .762 r
.22065 .58602 m .22381 .58821 L .22295 .58555 L F
.329 .34 .72 r
.22381 .58821 m .2255 .58778 L .22362 .58614 L F
.22319 .5863 m .22361 .58621 L .22295 .58555 L F
.22342 .587 m .2236 .58625 L .22319 .5863 L F
.2236 .58625 m .22361 .58621 L .22319 .5863 L F
.519 .488 .762 r
.22065 .58602 m .2215 .58897 L .22381 .58821 L F
.03 0 0 r
.22219 .58667 m .22131 .58717 L .21878 .58766 L F
0 .035 .594 r
.21878 .58766 m .21819 .58746 L .22065 .58602 L F
.21878 .58766 m .22065 .58602 L .21939 .58508 L F
.03 0 0 r
.22361 .58621 m .21878 .58766 L .21939 .58508 L F
.22363 .58625 m .21878 .58766 L .22361 .58621 L F
.329 .34 .72 r
.22361 .58621 m .22352 .58605 L .22295 .58555 L F
.647 .662 .85 r
.21987 .58084 m .22362 .58613 L .21939 .58508 L F
.22362 .58613 m .22362 .58614 L .21939 .58508 L F
.329 .34 .72 r
.22361 .58621 m .22362 .58614 L .22352 .58605 L F
.647 .662 .85 r
.22363 .58614 m .22354 .58619 L .21939 .58508 L F
0 0 .084 r
.21923 .58881 m .21878 .58766 L .22131 .58717 L F
.802 .973 .675 r
.22171 .58551 m .21981 .58805 L .22131 .58717 L F
.21981 .58805 m .21923 .58881 L .22131 .58717 L F
.03 0 0 r
.22363 .58625 m .22131 .58717 L .22219 .58667 L F
.22369 .58623 m .22365 .58625 L .22363 .58625 L F
.22365 .58625 m .22131 .58717 L .22363 .58625 L F
.22369 .58623 m .22363 .58625 L .22361 .58621 L F
.647 .662 .85 r
.22363 .58614 m .22369 .58623 L .22354 .58619 L F
.329 .34 .72 r
.22381 .58821 m .22362 .58614 L .22342 .587 L F
.647 .662 .85 r
.22362 .58613 m .22363 .58614 L .22362 .58614 L F
.507 .348 .6 r
.22362 .58614 m .22369 .5862 L .22391 .58598 L F
.22362 .58614 m .22391 .58598 L .22498 .58496 L F
.759 .995 .861 r
.22366 .58622 m .22369 .58623 L .22387 .58602 L F
.507 .348 .6 r
.22369 .5862 m .2255 .58778 L .22498 .58496 L F
.759 .995 .861 r
.22299 .58598 m .22366 .58622 L .22464 .58514 L F
.22366 .58622 m .22387 .58602 L .22464 .58514 L F
.22171 .58551 m .22299 .58598 L .22482 .58493 L F
.22299 .58598 m .22464 .58514 L .22482 .58493 L F
.004 0 0 r
.22572 .58458 m .22498 .58496 L .22579 .58472 L F
.22539 .58396 m .22498 .58496 L .22572 .58458 L F
.612 .737 .935 r
.34906 .56505 m .34676 .56586 L .34541 .56431 L F
0 0 .254 r
.35186 .53563 m .35179 .53905 L .35072 .53973 L F
0 0 .328 r
.35072 .53973 m .35186 .54076 L .3531 .53935 L F
.35072 .53973 m .35067 .54216 L .35186 .54076 L F
.559 .59 .841 r
.42236 .51284 m .42148 .51718 L .41901 .51607 L F
.42236 .51284 m .42427 .51667 L .42148 .51718 L F
.8 .328 .108 r
.34689 .65616 m .3433 .65356 L .34315 .65502 L F
.512 0 0 r
.34589 .65663 m .34689 .65616 L .34315 .65502 L F
.562 .127 .171 r
.34837 .65872 m .34689 .65616 L .34589 .65663 L F
.208 .019 .39 r
.33529 .552 m .33503 .55503 L .3338 .55233 L F
.33529 .552 m .33503 .55503 L .3338 .55233 L F
.38 0 0 r
.62323 .41292 m .62486 .41413 L .62274 .41511 L F
.62489 .41284 m .62601 .41278 L .62486 .41413 L F
0 0 0 r
.62486 .41413 m .62601 .41278 L .62773 .4111 L F
.62601 .41278 m .62879 .40975 L .62773 .4111 L F
.777 .991 .763 r
.62486 .41413 m .62773 .4111 L .62573 .41211 L F
0 0 0 r
.62483 .4153 m .62486 .41413 L .62573 .41211 L F
.62469 .41576 m .62486 .41413 L .62483 .4153 L F
.38 0 0 r
.62323 .41292 m .62489 .41284 L .62486 .41413 L F
.679 .762 .274 r
.30903 .65913 m .30882 .65977 L .30819 .66134 L F
0 0 .453 r
.35696 .61178 m .35889 .61442 L .35834 .61349 L F
.936 .804 .689 r
.70654 .32039 m .70758 .31814 L .70618 .31648 L F
.91 .841 .765 r
.70758 .31814 m .70716 .31459 L .70618 .31648 L F
.574 .492 .725 r
.29064 .62605 m .29088 .62799 L .2934 .62547 L F
.651 .617 .802 r
.2934 .62547 m .29088 .62799 L .29369 .62718 L F
.662 .533 .696 r
.29065 .63052 m .29369 .62718 L .29088 .62799 L F
.707 .855 .953 r
.72747 .34025 m .72501 .33955 L .72723 .33836 L F
.898 .737 .674 r
.60143 .42279 m .60281 .42609 L .60041 .42498 L F
.608 .61 .828 r
.60371 .42177 m .60281 .42609 L .60143 .42279 L F
.60371 .42177 m .60542 .42527 L .60281 .42609 L F
.347 .777 .97 r
.28636 .52102 m .28858 .52081 L .29049 .52132 L F
.512 .849 .996 r
.29049 .52132 m .29353 .51978 L .29325 .52062 L F
.29049 .52132 m .28858 .52081 L .29353 .51978 L F
.747 .631 .731 r
.62052 .39009 m .62425 .39064 L .622 .3917 L F
.437 .295 .59 r
.26767 .75559 m .26679 .75811 L .26878 .75732 L F
.896 .705 .636 r
.36945 .58025 m .36863 .5835 L .37093 .58078 L F
.53 .48 .745 r
.36863 .5835 m .3718 .58497 L .37093 .58078 L F
.452 .266 .537 r
.37093 .58078 m .37495 .58261 L .37478 .57957 L F
.441 .17 .405 r
.3718 .58497 m .37495 .58261 L .37093 .58078 L F
.781 .538 .569 r
.39327 .65114 m .39063 .65253 L .39259 .65108 L F
.39474 .65037 m .39556 .65328 L .39063 .65253 L F
.921 .668 .537 r
.39556 .65328 m .3928 .65335 L .39063 .65253 L F
.975 .687 .293 r
.39259 .65108 m .3928 .65335 L .39154 .65098 L F
.39259 .65108 m .39154 .65098 L .39144 .65081 L F
.781 .538 .569 r
.39474 .65037 m .39327 .65114 L .39259 .65108 L F
0 0 .511 r
.395 .64962 m .39474 .65037 L .39259 .65108 L F
.395 .64962 m .39627 .65251 L .39474 .65037 L F
0 .041 .56 r
.39627 .65251 m .39556 .65328 L .39474 .65037 L F
.517 .035 .051 r
.29918 .53127 m .30153 .53168 L .30277 .53082 L F
.595 .83 .45 r
.30153 .53168 m .30492 .53015 L .30277 .53082 L F
.602 .381 .553 r
.6041 .43523 m .60431 .43788 L .60178 .43812 L F
.802 .999 .839 r
.6364 .40504 m .63826 .4047 L .63978 .40288 L F
.681 .255 .229 r
.26672 .56188 m .2624 .56272 L .2624 .56122 L F
.26672 .56188 m .26443 .56379 L .2624 .56272 L F
.335 0 0 r
.26813 .56269 m .26672 .56188 L .26824 .5608 L F
.26813 .56269 m .26443 .56379 L .26672 .56188 L F
.598 .026 0 r
.31408 .57292 m .3142 .57263 L .31251 .57156 L F
.178 0 0 r
.27246 .61905 m .27091 .62111 L .27298 .62047 L F
.822 .698 .728 r
.32044 .66296 m .32225 .66622 L .31904 .66614 L F
.687 .364 .424 r
.32225 .66622 m .31785 .66883 L .31904 .66614 L F
.32225 .66622 m .32225 .66813 L .31785 .66883 L F
.153 .36 .814 r
.3231 .66453 m .32225 .66622 L .32044 .66296 L F
.059 .236 .731 r
.3231 .66453 m .32489 .66907 L .32225 .66622 L F
.67 .351 .424 r
.32225 .66622 m .32489 .66907 L .32225 .66813 L F
.639 .966 .871 r
.31545 .65437 m .31258 .65636 L .31218 .65593 L F
.592 .872 .994 r
.34096 .54236 m .33829 .54245 L .33894 .54138 L F
.261 .09 .451 r
.33894 .54138 m .33865 .54403 L .34096 .54236 L F
.294 0 .247 r
.34096 .54236 m .3432 .54221 L .3445 .53975 L F
.253 .135 .519 r
.30811 .60207 m .30735 .60559 L .3059 .60611 L F
.181 .135 .567 r
.30746 .60777 m .3059 .60611 L .30735 .60559 L F
.30746 .60777 m .3063 .60899 L .3059 .60611 L F
.415 .781 .995 r
.73651 .32994 m .73914 .32961 L .73883 .33035 L F
0 0 .563 r
.26767 .75559 m .26878 .75732 L .26738 .75389 L F
.226 .626 .956 r
.3458 .60435 m .34887 .6059 L .34714 .60492 L F
.899 .728 .661 r
.5657 .41295 m .56658 .41011 L .56497 .40891 L F
.721 .658 .104 r
.32312 .68518 m .32264 .68931 L .32133 .68794 L F
.954 .609 .295 r
.32264 .68931 m .32167 .69075 L .32133 .68794 L F
.32264 .68931 m .32324 .6917 L .32167 .69075 L F
0 .029 .599 r
.36859 .56979 m .36868 .57179 L .36871 .57046 L F
.985 .901 .636 r
.36669 .57307 m .36868 .57179 L .36859 .56979 L F
.36669 .57307 m .36773 .57422 L .36868 .57179 L F
0 0 .165 r
.41624 .56457 m .41659 .56593 L .41559 .56372 L F
.41624 .56457 m .41686 .56739 L .41659 .56593 L F
.268 0 0 r
.63028 .44872 m .63264 .44902 L .63025 .44975 L F
.63028 .44872 m .63373 .44824 L .63264 .44902 L F
.621 .37 .516 r
.33108 .60259 m .32776 .6053 L .32839 .60352 L F
.973 .68 .288 r
.34539 .50747 m .34053 .50872 L .34176 .50803 L F
.364 0 0 r
.34418 .50717 m .34539 .50747 L .3434 .50778 L F
.3429 .50762 m .3434 .50778 L .34176 .50803 L F
.34418 .50717 m .3434 .50778 L .3429 .50762 L F
.973 .68 .288 r
.34539 .50747 m .34414 .50691 L .34053 .50872 L F
.34539 .50747 m .34529 .50973 L .34414 .50691 L F
.191 .363 .806 r
.34414 .50691 m .34465 .50816 L .34626 .50796 L F
.34465 .50816 m .34529 .50973 L .34593 .50856 L F
.34465 .50816 m .34593 .50856 L .34626 .50796 L F
.592 .662 .887 r
.29064 .62605 m .29253 .62344 L .28917 .62215 L F
.29064 .62605 m .2934 .62547 L .29253 .62344 L F
.194 0 .348 r
.357 .64861 m .35471 .65299 L .35654 .65182 L F
.102 .232 .713 r
.35687 .64675 m .357 .64861 L .35939 .64924 L F
.237 0 .252 r
.35939 .64924 m .357 .64861 L .35654 .65182 L F
0 0 .333 r
.33206 .5381 m .33208 .54082 L .33262 .53844 L F
.141 0 0 r
.33142 .53771 m .33206 .5381 L .33357 .53646 L F
.685 .896 .537 r
.33357 .53646 m .33206 .5381 L .33307 .5364 L F
0 0 .333 r
.33206 .5381 m .33262 .53844 L .33307 .5364 L F
.141 0 0 r
.32966 .53874 m .33206 .5381 L .33142 .53771 L F
.19 .456 .88 r
.33137 .53365 m .33333 .53616 L .33407 .53473 L F
0 .041 .55 r
.33407 .53473 m .33069 .53129 L .33137 .53365 L F
.3335 .53414 m .33376 .5343 L .33069 .53129 L F
.33407 .53473 m .33376 .5343 L .3335 .53414 L F
.697 .982 .828 r
.33503 .53303 m .33376 .5343 L .33407 .53473 L F
0 0 0 r
.33503 .53303 m .33389 .53437 L .33376 .5343 L F
.33389 .53437 m .33252 .53597 L .33376 .5343 L F
.689 .929 .617 r
.33407 .53473 m .33252 .53597 L .33484 .53326 L F
.33407 .53473 m .33484 .53326 L .33503 .53303 L F
.19 .456 .88 r
.33333 .53616 m .33357 .53646 L .33407 .53473 L F
.685 .896 .537 r
.33357 .53646 m .33307 .5364 L .33407 .53473 L F
.238 0 0 r
.36822 .7136 m .37226 .71361 L .37097 .7139 L F
.183 .711 .703 r
.37097 .7139 m .37226 .71361 L .37462 .71302 L F
.789 .746 .814 r
.63893 .39443 m .63599 .39305 L .63709 .39264 L F
.655 .715 .892 r
.64139 .39345 m .63893 .39443 L .63709 .39264 L F
.95 .932 .745 r
.7059 .3349 m .70634 .33774 L .70807 .3341 L F
.906 .875 .443 r
.7059 .3349 m .70508 .33956 L .70634 .33774 L F
0 .067 .63 r
.22213 .55765 m .22418 .56022 L .22401 .56189 L F
.824 .994 .749 r
.22418 .56022 m .2219 .56302 L .22401 .56189 L F
.483 .566 .864 r
.23757 .6252 m .23722 .62158 L .23635 .62117 L F
.23757 .6252 m .23988 .62499 L .23722 .62158 L F
.472 .23 .466 r
.36499 .55128 m .36472 .55253 L .36592 .54874 L F
.563 .393 .609 r
.36821 .5458 m .36592 .54874 L .36906 .54736 L F
.291 .007 .299 r
.36472 .55253 m .36906 .54736 L .36592 .54874 L F
.871 .696 .663 r
.37895 .53588 m .38144 .53969 L .37941 .53807 L F
.37895 .53588 m .38144 .53969 L .37941 .53807 L F
.898 .665 .578 r
.38144 .53969 m .38082 .54261 L .37941 .53807 L F
.519 .237 .426 r
.29752 .61264 m .2972 .61488 L .29436 .61528 L F
.247 0 .258 r
.29948 .61232 m .2972 .61488 L .29752 .61264 L F
0 .054 .62 r
.36754 .50885 m .36627 .50869 L .36481 .50717 L F
.36754 .50885 m .36808 .51106 L .36627 .50869 L F
.975 .761 .552 r
.37757 .58279 m .3792 .58413 L .37979 .5818 L F
.883 .992 .773 r
.38034 .5791 m .37979 .5818 L .38186 .58072 L F
.38034 .5791 m .37757 .58279 L .37979 .5818 L F
.649 .519 .692 r
.3792 .58413 m .38186 .58072 L .37979 .5818 L F
.322 .075 .375 r
.28981 .60907 m .29205 .61028 L .29265 .6056 L F
.313 .046 .338 r
.28981 .60907 m .29144 .61128 L .29205 .61028 L F
.009 0 0 r
.36242 .65646 m .36629 .65651 L .36461 .65538 L F
.41 .544 .88 r
.36629 .65651 m .3673 .65271 L .36461 .65538 L F
.36629 .65651 m .36809 .65705 L .3673 .65271 L F
.704 .505 .616 r
.38876 .66541 m .39103 .66592 L .39089 .6631 L F
0 .166 .691 r
.39089 .6631 m .39338 .66529 L .3915 .663 L F
.49 .341 .605 r
.39089 .6631 m .39103 .66592 L .39338 .66529 L F
.392 .149 .422 r
.33875 .56297 m .34276 .56194 L .34249 .55859 L F
0 0 .121 r
.34249 .55859 m .3427 .56006 L .34221 .55786 L F
.34249 .55859 m .34276 .56194 L .3427 .56006 L F
.344 .397 .773 r
.40094 .67229 m .40011 .67563 L .39879 .67205 L F
.40094 .67229 m .40171 .67536 L .40011 .67563 L F
.499 .371 .637 r
.40171 .67536 m .40003 .67831 L .40011 .67563 L F
.611 .398 .568 r
.32912 .59312 m .33174 .59304 L .33237 .59 L F
.733 .516 .598 r
.33237 .59 m .33559 .59281 L .3351 .59002 L F
.33237 .59 m .33174 .59304 L .33559 .59281 L F
.959 .782 .336 r
.26159 .55722 m .26132 .56071 L .2605 .55904 L F
.26052 .55857 m .2605 .55904 L .26036 .55876 L F
.26159 .55722 m .2605 .55904 L .26052 .55857 L F
.587 .446 .656 r
.26049 .5596 m .25867 .5617 L .25838 .55908 L F
.998 .791 .447 r
.26227 .56059 m .26132 .56071 L .26159 .55722 L F
.2624 .56122 m .26132 .56071 L .26227 .56059 L F
.575 .938 .812 r
.26132 .56071 m .25867 .5617 L .25994 .56089 L F
.26106 .56018 m .26156 .55986 L .26036 .55876 L F
.26132 .56071 m .25994 .56089 L .26156 .55986 L F
.587 .446 .656 r
.26156 .55986 m .26046 .56056 L .26049 .5596 L F
.26046 .56056 m .25867 .5617 L .26049 .5596 L F
.998 .791 .447 r
.2624 .56122 m .26159 .55722 L .26282 .55821 L F
.917 .543 .117 r
.26282 .55821 m .26159 .55722 L .26195 .55672 L F
.674 .346 .411 r
.26049 .55869 m .26138 .55927 L .26519 .556 L F
.959 .782 .336 r
.26041 .5587 m .26036 .55876 L .26045 .55868 L F
.26041 .5587 m .26045 .55868 L .26078 .55837 L F
.674 .346 .411 r
.26036 .55876 m .26519 .556 L .26262 .55664 L F
.794 .52 .522 r
.26062 .55765 m .26129 .55923 L .26036 .55876 L F
.26129 .55923 m .26156 .55986 L .26036 .55876 L F
.674 .346 .411 r
.26138 .55927 m .26263 .56008 L .26272 .55994 L F
.26138 .55927 m .26272 .55994 L .26519 .556 L F
.26036 .55876 m .26221 .55984 L .26049 .55869 L F
.26221 .55984 m .26263 .56008 L .26049 .55869 L F
.3 0 .178 r
.26519 .556 m .26263 .56008 L .26364 .55959 L F
.26554 .55693 m .26364 .55959 L .2661 .5584 L F
.26519 .556 m .26364 .55959 L .26554 .55693 L F
.3 0 .179 r
.26263 .56008 m .26322 .56019 L .2661 .5584 L F
.794 .52 .522 r
.26095 .55842 m .26322 .56019 L .26252 .56005 L F
.26129 .55923 m .26221 .55984 L .26156 .55986 L F
0 .498 .833 r
.26156 .55986 m .26263 .56008 L .26221 .55984 L F
.794 .52 .522 r
.26221 .55984 m .26252 .56005 L .26156 .55986 L F
0 .498 .833 r
.26156 .55986 m .26221 .55984 L .26036 .55876 L F
.794 .52 .522 r
.26095 .55842 m .26252 .56005 L .26129 .55923 L F
.959 .782 .336 r
.26159 .55722 m .26041 .5587 L .26078 .55837 L F
.794 .52 .522 r
.26062 .55765 m .26125 .55826 L .26095 .55842 L F
.26125 .55826 m .26322 .56019 L .26095 .55842 L F
.959 .782 .336 r
.26159 .55722 m .26078 .55837 L .26262 .55664 L F
.587 .446 .656 r
.26156 .55986 m .25848 .55911 L .25941 .55892 L F
.25848 .55911 m .25851 .55906 L .25941 .55892 L F
.957 .865 .707 r
.26132 .56071 m .26018 .56335 L .25867 .5617 L F
.759 .639 .728 r
.26057 .56522 m .25867 .5617 L .26018 .56335 L F
.26057 .56522 m .25709 .56547 L .25867 .5617 L F
.25709 .56547 m .25642 .56552 L .25757 .56358 L F
.25709 .56547 m .25757 .56358 L .25867 .5617 L F
.611 .413 .589 r
.25565 .55622 m .25867 .55853 L .25776 .55518 L F
.25565 .55622 m .25558 .5567 L .25829 .5583 L F
.25806 .55806 m .25829 .5583 L .25835 .55828 L F
.25565 .55622 m .25819 .55822 L .25806 .55806 L F
.25819 .55822 m .25829 .5583 L .25806 .55806 L F
.655 .541 .713 r
.25826 .55831 m .25838 .55908 L .25525 .55922 L F
.611 .413 .589 r
.25558 .5567 m .25843 .55858 L .25867 .55853 L F
.488 .45 .741 r
.25851 .55863 m .25838 .55908 L .25826 .55831 L F
.715 .46 .538 r
.25867 .5617 m .25525 .55922 L .25838 .55908 L F
.25867 .5617 m .2545 .56219 L .25525 .55922 L F
.569 .311 .486 r
.2545 .56219 m .25855 .55864 L .25525 .55922 L F
.488 .45 .741 r
.25852 .55861 m .25857 .55867 L .25851 .55863 L F
.569 .311 .486 r
.25852 .55861 m .25867 .55853 L .25846 .55857 L F
.25856 .55863 m .25867 .55853 L .25852 .55861 L F
.261 .228 .632 r
.25867 .55853 m .25963 .55476 L .25776 .55518 L F
.488 .45 .741 r
.25963 .55476 m .25858 .55863 L .25852 .55861 L F
.569 .311 .486 r
.25856 .55863 m .25867 .55867 L .25867 .55853 L F
0 0 .314 r
.25867 .55853 m .25867 .55867 L .25871 .55858 L F
.488 .45 .741 r
.25903 .55763 m .25851 .55906 L .25838 .55908 L F
.25983 .55586 m .25897 .55795 L .25903 .55763 L F
.261 .228 .632 r
.25867 .55853 m .25887 .55844 L .25963 .55476 L F
.488 .45 .741 r
.25897 .55795 m .25851 .55906 L .25903 .55763 L F
.25963 .55476 m .25983 .55586 L .25857 .55867 L F
.25871 .55858 m .26036 .55876 L .25851 .55906 L F
0 0 .314 r
.25867 .55853 m .25871 .55858 L .25887 .55844 L F
.488 .45 .741 r
.25983 .55586 m .26011 .55736 L .25871 .55858 L F
.26011 .55736 m .26036 .55876 L .25871 .55858 L F
.587 .446 .656 r
.26076 .55913 m .25941 .55892 L .26036 .55876 L F
.26156 .55986 m .25941 .55892 L .26076 .55913 L F
0 0 .544 r
.26062 .55765 m .26036 .55876 L .25963 .55476 L F
0 0 .314 r
.25887 .55844 m .25982 .56016 L .26062 .55765 L F
.25871 .55858 m .25982 .56016 L .25887 .55844 L F
.261 .228 .632 r
.25887 .55844 m .26062 .55765 L .25963 .55476 L F
.569 .311 .486 r
.25841 .55876 m .25867 .5588 L .25867 .55867 L F
.488 .45 .741 r
.25858 .55863 m .25857 .55867 L .25852 .55861 L F
.25851 .55863 m .25857 .55867 L .25838 .55908 L F
.569 .311 .486 r
.25841 .55876 m .25867 .55867 L .25856 .55863 L F
.488 .45 .741 r
.25856 .55863 m .25852 .55861 L .25852 .55861 L F
.25858 .55863 m .25852 .55861 L .25856 .55863 L F
.569 .311 .486 r
.25855 .55864 m .25856 .55863 L .25852 .55861 L F
.488 .45 .741 r
.25852 .55861 m .25851 .55863 L .25851 .5586 L F
.569 .311 .486 r
.25855 .55864 m .25846 .55857 L .25525 .55922 L F
.488 .45 .741 r
.25963 .55476 m .25852 .55861 L .25776 .55518 L F
.25852 .55861 m .25851 .5586 L .25776 .55518 L F
.611 .413 .589 r
.25835 .55828 m .25829 .5583 L .25867 .55853 L F
.488 .45 .741 r
.25851 .55863 m .25826 .55831 L .25776 .55518 L F
.611 .413 .589 r
.25558 .5567 m .25525 .55922 L .25843 .55858 L F
.655 .541 .713 r
.25776 .55518 m .25826 .55831 L .25525 .55922 L F
0 0 .314 r
.25871 .55858 m .25867 .5588 L .25876 .55865 L F
.25867 .55867 m .25867 .5588 L .25871 .55858 L F
.2588 .55871 m .25862 .56306 L .25982 .56016 L F
.25876 .55865 m .25875 .5589 L .2588 .55871 L F
.25875 .5589 m .25862 .56306 L .2588 .55871 L F
.756 .901 .51 r
.25867 .5617 m .25696 .56392 L .2545 .56219 L F
0 0 .314 r
.25867 .5588 m .25862 .56306 L .25876 .55865 L F
.587 .446 .656 r
.25848 .55911 m .25838 .55908 L .25851 .55906 L F
.756 .901 .51 r
.25867 .5617 m .25642 .56552 L .25685 .56427 L F
.25754 .56317 m .25685 .56427 L .25696 .56392 L F
.25867 .5617 m .25685 .56427 L .25754 .56317 L F
.569 .311 .486 r
.2545 .56219 m .25773 .56287 L .25867 .5588 L F
.25773 .56287 m .25862 .56306 L .25864 .56144 L F
.25773 .56287 m .25864 .56144 L .25867 .5588 L F
.2545 .56219 m .25867 .5588 L .25841 .55876 L F
0 .498 .833 r
.26156 .55986 m .26322 .56019 L .26263 .56008 L F
.794 .52 .522 r
.26062 .55765 m .25982 .56016 L .26322 .56019 L F
.917 .543 .117 r
.26195 .55672 m .26159 .55722 L .2609 .55488 L F
.18 0 .329 r
.29265 .6056 m .294 .60748 L .29467 .60537 L F
.29265 .6056 m .29205 .61028 L .294 .60748 L F
.963 .666 .419 r
.38279 .64385 m .38486 .64784 L .38427 .64597 L F
0 0 .004 r
.32126 .55568 m .32035 .55741 L .3187 .55821 L F
.573 .55 .79 r
.32035 .55741 m .31927 .56148 L .3187 .55821 L F
0 .195 .612 r
.24841 .62747 m .24807 .62723 L .24685 .62617 L F
.24841 .62747 m .24959 .62819 L .24807 .62723 L F
.84 .552 .502 r
.42711 .52691 m .42266 .5234 L .42544 .52273 L F
.42711 .52691 m .42264 .52607 L .42266 .5234 L F
.887 .68 .617 r
.42403 .52913 m .42264 .52607 L .42711 .52691 L F
.784 .549 .581 r
.42711 .52691 m .42648 .52946 L .42403 .52913 L F
.502 .5 .787 r
.42924 .52603 m .42711 .52691 L .42544 .52273 L F
.724 .639 .762 r
.42924 .52603 m .42648 .52946 L .42711 .52691 L F
.509 .343 .591 r
.37274 .55682 m .37017 .55498 L .37385 .55583 L F
.356 .798 .958 r
.37653 .55676 m .37274 .55682 L .37385 .55583 L F
.596 .084 0 r
.40203 .5264 m .40117 .52584 L .39917 .52361 L F
0 0 .316 r
.40366 .52994 m .40203 .5264 L .40635 .52563 L F
.40366 .52994 m .40328 .52906 L .40203 .5264 L F
.843 .426 0 r
.40328 .52906 m .40117 .52584 L .40203 .5264 L F
.625 .4 .555 r
.58628 .44154 m .58633 .44408 L .58359 .44419 L F
.626 .409 .567 r
.58844 .44138 m .58633 .44408 L .58628 .44154 L F
.62 .055 0 r
.23338 .60796 m .23315 .60663 L .23125 .60562 L F
.23338 .60796 m .23511 .60824 L .23315 .60663 L F
.772 .563 .616 r
.57965 .42593 m .57576 .42243 L .57825 .42445 L F
.656 .237 .236 r
.57507 .42463 m .57825 .42445 L .57576 .42243 L F
.95 .932 .745 r
.7059 .3349 m .70807 .3341 L .70724 .33301 L F
.759 .885 .474 r
.70735 .33199 m .70664 .33344 L .70724 .33301 L F
.70664 .33344 m .70619 .33434 L .70724 .33301 L F
.909 .595 .11 r
.7076 .33276 m .70724 .33301 L .70807 .3341 L F
.70668 .3301 m .70724 .33301 L .7076 .33276 L F
.82 .877 .887 r
.57605 .42859 m .57965 .42593 L .57825 .42445 L F
.57605 .42859 m .57825 .42445 L .57582 .42765 L F
.333 .677 .978 r
.28473 .62668 m .28438 .62821 L .28243 .62691 L F
.28473 .62668 m .28624 .62797 L .28438 .62821 L F
.318 .351 .738 r
.28699 .63062 m .28438 .62821 L .28624 .62797 L F
0 0 0 r
.35989 .65717 m .35967 .65782 L .35886 .65889 L F
.373 .288 .63 r
.39972 .66258 m .40018 .66534 L .39825 .66582 L F
.338 .218 .566 r
.40033 .66793 m .39825 .66582 L .40018 .66534 L F
.40033 .66793 m .39797 .67036 L .39825 .66582 L F
.835 .511 .44 r
.57312 .44436 m .5694 .4413 L .57337 .44164 L F
.904 .717 .639 r
.40841 .51998 m .40985 .52377 L .40772 .5227 L F
.698 .655 .804 r
.40969 .52573 m .40772 .5227 L .40985 .52377 L F
.934 .849 .735 r
.35889 .61442 m .36184 .61246 L .35954 .61175 L F
.35889 .61442 m .3606 .61549 L .36184 .61246 L F
.273 .111 .471 r
.29753 .59937 m .29994 .59912 L .29918 .59595 L F
.305 .05 .353 r
.29753 .59937 m .29939 .60119 L .29994 .59912 L F
.29753 .59937 m .29778 .60287 L .29939 .60119 L F
.922 .934 .571 r
.33463 .70338 m .3329 .70522 L .3335 .70228 L F
0 0 0 r
.33358 .70316 m .3335 .70228 L .3329 .70522 L F
.783 .347 0 r
.33336 .70086 m .33463 .70338 L .3335 .70228 L F
0 0 0 r
.33421 .70127 m .3335 .70228 L .33358 .70316 L F
.783 .347 0 r
.33336 .70086 m .33336 .70086 L .3335 .70228 L F
.328 .178 .52 r
.42247 .55488 m .42084 .55845 L .41928 .55499 L F
.42247 .55488 m .42294 .55813 L .42084 .55845 L F
.979 .712 .454 r
.41164 .54589 m .41008 .54741 L .40958 .54491 L F
.41164 .54589 m .41164 .54848 L .41008 .54741 L F
0 0 0 r
.28441 .63628 m .28358 .63784 L .28479 .63429 L F
.28261 .64049 m .28358 .63784 L .28441 .63628 L F
.56 .508 .754 r
.36199 .62183 m .36364 .61802 L .3612 .61841 L F
.36199 .62183 m .3645 .62142 L .36364 .61802 L F
.447 .573 .888 r
.36603 .62475 m .36199 .62183 L .3645 .62142 L F
.64 .457 .621 r
.36177 .62446 m .3645 .62142 L .36199 .62183 L F
.776 .405 0 r
.41381 .55444 m .4121 .55088 L .41342 .55215 L F
.991 .844 .6 r
.37905 .5486 m .38172 .54538 L .38151 .54846 L F
0 0 0 r
.62308 .43324 m .62118 .43518 L .62391 .43168 L F
.255 .303 .72 r
.62394 .43701 m .62118 .43518 L .62308 .43324 L F
.207 0 .219 r
.33398 .59927 m .33615 .59621 L .33591 .59875 L F
.475 .202 .419 r
.34158 .59449 m .33591 .59875 L .33615 .59621 L F
.488 .169 .352 r
.31638 .56427 m .31542 .56702 L .31301 .5674 L F
.501 .282 .513 r
.31927 .56148 m .31912 .56411 L .31638 .56427 L F
.637 .398 .54 r
.31912 .56411 m .31542 .56702 L .31638 .56427 L F
.842 .831 .836 r
.36462 .67933 m .36789 .67877 L .36633 .67707 L F
.679 .837 .959 r
.3596 .68335 m .36127 .68456 L .36292 .68301 L F
.3596 .68335 m .36127 .68456 L .36292 .68301 L F
.604 .201 .251 r
.36292 .68301 m .36202 .68396 L .3596 .68335 L F
.36292 .68301 m .36202 .68396 L .3596 .68335 L F
.958 .864 .703 r
.36032 .68228 m .36202 .68396 L .36427 .68025 L F
.889 .968 .833 r
.36555 .67578 m .36462 .67933 L .36633 .67707 L F
.567 .079 .056 r
.36528 .67976 m .36703 .67892 L .36462 .67933 L F
.36624 .68038 m .36703 .67892 L .36528 .67976 L F
.21 .274 .712 r
.36624 .68038 m .36462 .67933 L .36555 .67578 L F
.958 .864 .703 r
.3609 .68187 m .36427 .68025 L .36504 .67897 L F
.36032 .68228 m .36427 .68025 L .3609 .68187 L F
.567 .079 .056 r
.36624 .68038 m .36789 .67877 L .36703 .67892 L F
.523 .733 .97 r
.36633 .67707 m .36789 .67877 L .36849 .67648 L F
.835 .947 .59 r
.36849 .67648 m .36789 .67877 L .36624 .68038 L F
.011 0 0 r
.32865 .51694 m .33058 .51617 L .33182 .51416 L F
0 0 0 r
.33182 .51416 m .33338 .51327 L .33446 .51097 L F
.097 0 0 r
.33182 .51416 m .33274 .51525 L .33338 .51327 L F
.33182 .51416 m .33058 .51617 L .33274 .51525 L F
.566 .022 0 r
.36817 .62679 m .36603 .62475 L .36435 .62355 L F
.543 .577 .839 r
.36953 .62732 m .36603 .62475 L .36817 .62679 L F
0 0 .531 r
.31251 .56091 m .313 .56499 L .31396 .56309 L F
.852 .823 .819 r
.60257 .39428 m .60081 .39707 L .59903 .39548 L F
.914 .713 .216 r
.60081 .39707 m .60018 .39869 L .59903 .39548 L F
.60081 .39707 m .60081 .39923 L .60018 .39869 L F
.047 0 .037 r
.34235 .59659 m .34164 .59399 L .34307 .59475 L F
.747 .752 .857 r
.36338 .5535 m .36747 .55432 L .36472 .55253 L F
0 0 0 r
.36303 .55765 m .36747 .55432 L .36338 .5535 L F
.36303 .55765 m .36477 .55646 L .36747 .55432 L F
.847 .994 .749 r
.36741 .55428 m .36785 .55185 L .36472 .55253 L F
.291 .007 .299 r
.36472 .55253 m .36785 .55185 L .36906 .54736 L F
.839 .994 .749 r
.36785 .55185 m .36673 .55253 L .36798 .55109 L F
0 0 .078 r
.36906 .54736 m .36785 .55185 L .36928 .54959 L F
.839 .994 .749 r
.36785 .55185 m .36798 .55109 L .36928 .54959 L F
.847 .994 .749 r
.36747 .55432 m .36785 .55185 L .36741 .55428 L F
.36747 .55432 m .36673 .55253 L .36785 .55185 L F
.54 .868 .593 r
.36747 .55432 m .36652 .55475 L .36673 .55253 L F
.36747 .55432 m .36477 .55646 L .36652 .55475 L F
.086 0 0 r
.23008 .58348 m .23414 .58318 L .23183 .58324 L F
0 0 0 r
.33965 .56461 m .34276 .56194 L .33875 .56297 L F
.68 .782 .927 r
.61152 .39332 m .60919 .39456 L .60765 .39265 L F
.282 .199 .582 r
.41622 .52628 m .41596 .5301 L .41478 .52981 L F
.275 0 0 r
.41596 .5301 m .41351 .53149 L .41478 .52981 L F
.551 .052 .024 r
.32668 .66823 m .32871 .66892 L .32489 .66907 L F
.685 .546 .69 r
.31385 .53678 m .31422 .53962 L .31146 .5397 L F
.359 .007 .225 r
.31422 .53962 m .31106 .54191 L .31146 .5397 L F
.622 .956 .911 r
.39923 .59919 m .39616 .60107 L .39497 .60056 L F
.603 .868 .992 r
.42812 .53283 m .42403 .52913 L .42648 .52946 L F
.42812 .53283 m .42499 .53245 L .42403 .52913 L F
.718 .657 .788 r
.43049 .52986 m .42812 .53283 L .42648 .52946 L F
.597 .479 .69 r
.43049 .52986 m .43105 .5329 L .42812 .53283 L F
.305 .099 .427 r
.43105 .5329 m .42876 .53616 L .42812 .53283 L F
.197 .232 .672 r
.31508 .5347 m .31385 .53678 L .3131 .53307 L F
.564 .459 .693 r
.31643 .53667 m .31385 .53678 L .31508 .5347 L F
.31643 .53667 m .31422 .53962 L .31385 .53678 L F
.489 .021 .071 r
.26334 .55422 m .26589 .55433 L .26775 .55259 L F
.348 .402 .775 r
.65514 .39898 m .65298 .40031 L .65193 .39641 L F
.106 .051 .506 r
.65477 .40098 m .65298 .40031 L .65514 .39898 L F
.524 .571 .844 r
.42541 .55746 m .42465 .56137 L .42294 .55813 L F
.658 .84 .97 r
.42682 .56057 m .42465 .56137 L .42706 .56106 L F
.524 .571 .844 r
.42541 .55746 m .42706 .56106 L .42465 .56137 L F
.734 .37 .361 r
.34137 .52646 m .34343 .52883 L .34494 .52676 L F
.68 .565 .719 r
.34494 .52676 m .3479 .52707 L .34645 .52341 L F
.645 .26 .301 r
.34494 .52676 m .346 .52759 L .3479 .52707 L F
.34494 .52676 m .34343 .52883 L .346 .52759 L F
.748 .784 .883 r
.622 .3917 m .61808 .39058 L .62052 .39009 L F
.622 .3917 m .6165 .39307 L .61808 .39058 L F
.359 .146 .449 r
.2968 .64093 m .29897 .63782 L .29891 .64014 L F
.144 0 0 r
.29564 .64278 m .2968 .64093 L .29891 .64014 L F
.73 .747 .865 r
.3927 .58396 m .39389 .58717 L .38983 .58698 L F
.546 .026 0 r
.38983 .58698 m .39389 .58717 L .39227 .58852 L F
.671 .653 .824 r
.39473 .5826 m .39389 .58717 L .3927 .58396 L F
.39473 .5826 m .3964 .5862 L .39389 .58717 L F
.912 .537 .302 r
.39389 .58717 m .39426 .58943 L .39227 .58852 L F
.623 .356 .493 r
.33845 .55377 m .33529 .552 L .34022 .55252 L F
0 0 0 r
.34073 .55257 m .34022 .55252 L .34284 .55252 L F
.34073 .55257 m .33845 .55377 L .34022 .55252 L F
.647 .089 0 r
.62391 .43168 m .61982 .42903 L .62223 .42821 L F
0 .002 .56 r
.55827 .39711 m .55863 .39796 L .55853 .39466 L F
.639 .415 .562 r
.36809 .55862 m .36776 .56182 L .3649 .5614 L F
.513 .306 .535 r
.37027 .56114 m .36809 .55862 L .37033 .55778 L F
.37027 .56114 m .36776 .56182 L .36809 .55862 L F
.912 .516 .231 r
.29488 .64952 m .29571 .64801 L .29442 .64868 L F
.975 .676 .302 r
.64527 .42579 m .64452 .4272 L .64657 .42303 L F
.64527 .42579 m .64574 .42843 L .64452 .4272 L F
.888 .661 .588 r
.35339 .58345 m .35743 .587 L .35382 .58602 L F
.996 .764 .445 r
.35743 .587 m .35596 .588 L .35382 .58602 L F
.35743 .587 m .35725 .58957 L .35596 .588 L F
.57 .679 .913 r
.35998 .58633 m .35743 .587 L .35339 .58345 L F
.273 .112 .472 r
.35932 .58892 m .35743 .587 L .35998 .58633 L F
.35932 .58892 m .35725 .58957 L .35743 .587 L F
.57 .178 .26 r
.38434 .61105 m .38254 .60898 L .3819 .61167 L F
.38434 .61105 m .38505 .60953 L .38254 .60898 L F
.578 .389 .589 r
.38254 .60898 m .38505 .60953 L .3856 .60632 L F
.585 .88 .993 r
.30503 .54524 m .30257 .54588 L .30323 .54418 L F
.512 .441 .714 r
.30385 .54688 m .30257 .54588 L .30503 .54524 L F
.30385 .54688 m .30323 .54418 L .30257 .54588 L F
.194 0 .241 r
.347 .59957 m .34434 .60324 L .34685 .60232 L F
.586 .447 .659 r
.34685 .60232 m .34893 .59916 L .347 .59957 L F
0 0 0 r
.31719 .64672 m .31758 .64401 L .31794 .64239 L F
.984 .709 .342 r
.62778 .44017 m .62796 .44277 L .62906 .44182 L F
.59 .872 .551 r
.62906 .44182 m .62933 .44121 L .63209 .44148 L F
.62906 .44182 m .62796 .44277 L .62933 .44121 L F
.698 .655 .804 r
.40969 .52573 m .40734 .52727 L .40571 .5233 L F
.617 .533 .737 r
.29242 .53018 m .29438 .52638 L .29162 .52721 L F
.29242 .53018 m .29554 .5299 L .29438 .52638 L F
.643 .473 .638 r
.29251 .5326 m .29554 .5299 L .29242 .53018 L F
.222 0 .146 r
.27175 .55544 m .27053 .55764 L .26874 .55806 L F
.09 0 .07 r
.27292 .55631 m .27175 .55544 L .27348 .55374 L F
.27292 .55631 m .27053 .55764 L .27175 .55544 L F
.584 .533 .763 r
.32728 .53925 m .32932 .54383 L .331 .54228 L F
.298 .102 .437 r
.32932 .54383 m .3288 .5455 L .331 .54228 L F
.46 0 .008 r
.3288 .5455 m .331 .54228 L .32932 .54383 L F
.078 0 .124 r
.39521 .59325 m .39702 .59111 L .39748 .59187 L F
.633 .078 0 r
.39426 .58943 m .39702 .59111 L .39748 .59187 L F
.775 .965 .665 r
.34443 .5876 m .34476 .58687 L .34679 .58905 L F
.34476 .58687 m .34565 .58682 L .34588 .58728 L F
.34536 .58752 m .34588 .58728 L .34679 .58905 L F
.34476 .58687 m .34588 .58728 L .34536 .58752 L F
.34518 .58591 m .34567 .58621 L .34679 .58905 L F
.34679 .58905 m .34538 .58547 L .3472 .5893 L F
.787 .705 .774 r
.34962 .58618 m .3472 .5893 L .34617 .58714 L F
0 0 0 r
.34751 .58615 m .34766 .58603 L .34761 .58603 L F
.1 0 0 r
.34575 .58626 m .34761 .58603 L .34567 .58621 L F
.787 .705 .774 r
.34741 .58622 m .34617 .58714 L .34575 .58626 L F
.1 0 0 r
.34658 .58677 m .34733 .58623 L .34575 .58626 L F
.34733 .58623 m .34761 .58603 L .34575 .58626 L F
.817 .747 .787 r
.34538 .58547 m .34567 .58621 L .34761 .58603 L F
.799 .67 .721 r
.34895 .58283 m .34962 .58618 L .34766 .58585 L F
.34895 .58283 m .34766 .58585 L .34764 .5852 L F
.34895 .58283 m .34732 .58579 L .34631 .5856 L F
.34633 .58476 m .34631 .5856 L .34543 .58543 L F
.34895 .58283 m .34631 .5856 L .34633 .58476 L F
.34895 .58283 m .34538 .58547 L .34571 .58427 L F
0 0 0 r
.3464 .58263 m .34725 .58416 L .3469 .58145 L F
.34571 .58427 m .34635 .58423 L .3464 .58263 L F
.34635 .58423 m .34725 .58416 L .3464 .58263 L F
.787 .705 .774 r
.34787 .58588 m .34785 .5859 L .34732 .58579 L F
0 0 .273 r
.34766 .58586 m .34876 .5862 L .34846 .58329 L F
.34761 .58603 m .34766 .58586 L .34758 .58584 L F
.817 .747 .787 r
.34538 .58547 m .34761 .58603 L .34758 .58584 L F
.787 .705 .774 r
.34758 .58584 m .34732 .5858 L .34732 .58579 L F
.799 .67 .721 r
.34543 .58543 m .34732 .58579 L .34538 .58547 L F
.817 .747 .787 r
.34538 .58547 m .34758 .58584 L .34725 .58416 L F
.787 .705 .774 r
.34766 .58586 m .34741 .58622 L .34732 .5858 L F
.34766 .58586 m .34732 .5858 L .34758 .58584 L F
.34785 .5859 m .34766 .58603 L .34766 .58586 L F
0 0 .273 r
.34761 .58603 m .34766 .58603 L .34766 .58586 L F
.787 .705 .774 r
.34766 .58603 m .34741 .58622 L .34766 .58586 L F
0 0 .273 r
.34766 .58586 m .34767 .58604 L .34766 .58586 L F
.34766 .58603 m .34767 .58604 L .34766 .58586 L F
.787 .705 .774 r
.34962 .58618 m .34617 .58714 L .34751 .58615 L F
.34805 .58591 m .34751 .58615 L .34787 .58588 L F
.34962 .58618 m .34751 .58615 L .34805 .58591 L F
.1 0 0 r
.34658 .58677 m .34701 .58674 L .34751 .58615 L F
.34733 .58623 m .34751 .58615 L .34761 .58603 L F
.34658 .58677 m .34751 .58615 L .34733 .58623 L F
0 0 .273 r
.34767 .58604 m .34876 .5862 L .34766 .58586 L F
.799 .67 .721 r
.34764 .5852 m .34766 .58585 L .34732 .58579 L F
0 0 .273 r
.34758 .58584 m .34846 .58329 L .34725 .58416 L F
.34766 .58586 m .34846 .58329 L .34758 .58584 L F
.787 .705 .774 r
.34732 .58579 m .34741 .58622 L .34538 .58547 L F
.34741 .58622 m .34575 .58626 L .34538 .58547 L F
0 0 0 r
.34701 .58674 m .3483 .58613 L .34766 .58603 L F
.34701 .58674 m .34766 .58603 L .34751 .58615 L F
.34544 .58861 m .34876 .5862 L .3483 .58613 L F
.34544 .58861 m .3483 .58613 L .34701 .58674 L F
.1 0 0 r
.3432 .5892 m .34544 .58861 L .34701 .58674 L F
.3432 .5892 m .34701 .58674 L .34658 .58677 L F
.775 .965 .665 r
.34476 .58687 m .34518 .58591 L .34565 .58682 L F
.34518 .58591 m .34538 .58547 L .34567 .58621 L F
.1 0 0 r
.3432 .5892 m .34658 .58677 L .34514 .58626 L F
.34658 .58677 m .34567 .58621 L .34514 .58626 L F
.817 .747 .787 r
.34538 .58547 m .34514 .58626 L .34567 .58621 L F
.74 .656 .766 r
.19388 .60577 m .19761 .60699 L .19531 .60575 L F
.19388 .60577 m .19418 .60882 L .19761 .60699 L F
.655 .855 .976 r
.19946 .60577 m .19761 .60699 L .19531 .60575 L F
.19946 .60577 m .19761 .60699 L .19531 .60575 L F
.388 .469 .822 r
.36906 .54736 m .36955 .54355 L .36821 .5458 L F
.541 .893 .978 r
.29664 .52004 m .29764 .51864 L .29994 .5184 L F
.29664 .52004 m .29534 .51954 L .29764 .51864 L F
.157 .456 .884 r
.24591 .61377 m .2455 .61531 L .24347 .61296 L F
0 .204 .727 r
.24591 .61377 m .24745 .61708 L .2455 .61531 L F
0 .347 .701 r
.35142 .50165 m .3551 .50329 L .35232 .50274 L F
.755 .684 .783 r
.61152 .39332 m .61544 .394 L .61393 .39277 L F
.745 .703 .812 r
.61445 .39027 m .61544 .394 L .61152 .39332 L F
.692 .671 .825 r
.6165 .39307 m .61544 .394 L .61445 .39027 L F
.91 .97 .798 r
.36775 .66015 m .36761 .66283 L .36632 .66257 L F
.57 .773 .975 r
.57807 .4041 m .58078 .40345 L .5766 .40236 L F
.403 .748 .993 r
.5766 .40236 m .58078 .40345 L .5795 .40212 L F
.535 .823 .998 r
.57807 .4041 m .5795 .40212 L .5766 .40236 L F
.57807 .4041 m .58078 .40345 L .5795 .40212 L F
.5795 .40212 m .57807 .4041 L .5766 .40236 L F
.5795 .40212 m .58078 .40345 L .57807 .4041 L F
.601 .639 .86 r
.36446 .64058 m .36351 .64393 L .36146 .63981 L F
.36446 .64058 m .36351 .64393 L .36146 .63981 L F
.73 .622 .737 r
.32332 .55217 m .32097 .55282 L .31922 .55097 L F
.473 .29 .551 r
.32332 .55217 m .32126 .55568 L .32097 .55282 L F
.32332 .55217 m .32367 .55518 L .32126 .55568 L F
.345 .2 .537 r
.32553 .55396 m .32367 .55518 L .32332 .55217 L F
.709 .726 .863 r
.56648 .41513 m .56836 .41733 L .57036 .4157 L F
.367 .107 .381 r
.38678 .70419 m .38614 .70658 L .38391 .70732 L F
.207 0 .312 r
.38678 .70419 m .38861 .70317 L .38614 .70658 L F
.104 .593 .906 r
.38486 .64784 m .38304 .64689 L .38076 .64658 L F
.959 .675 .454 r
.38279 .64385 m .38304 .64689 L .38486 .64784 L F
.461 .173 .389 r
.24887 .55816 m .24862 .5607 L .24597 .56125 L F
.082 0 .281 r
.25121 .55496 m .25074 .55726 L .24887 .55816 L F
.365 .196 .515 r
.25074 .55726 m .24862 .5607 L .24887 .55816 L F
.586 .211 .297 r
.35203 .5821 m .34895 .58283 L .3497 .58077 L F
0 0 .06 r
.36988 .5204 m .36996 .52373 L .37005 .52198 L F
.671 .884 .977 r
.26401 .53103 m .26348 .53315 L .26571 .5318 L F
.73 .578 .001 r
.26342 .53355 m .26348 .53315 L .26401 .53103 L F
.26342 .53355 m .26355 .5359 L .26348 .53315 L F
.257 .294 .709 r
.3578 .55055 m .35645 .55495 L .35597 .55242 L F
.567 .184 .276 r
.33446 .51097 m .33338 .51327 L .33666 .51271 L F
.125 0 .414 r
.30071 .63909 m .29897 .63782 L .301 .63648 L F
.30071 .63909 m .29891 .64014 L .29897 .63782 L F
.338 0 .187 r
.32367 .55518 m .32035 .55741 L .32126 .55568 L F
.729 .217 0 r
.35143 .51409 m .34956 .51355 L .34782 .51184 L F
.751 .576 .002 r
.40366 .52994 m .40368 .53173 L .40328 .52906 L F
0 .104 .641 r
.40465 .53537 m .40539 .53376 L .40368 .53173 L F
0 0 .464 r
.40368 .53173 m .40424 .53233 L .40356 .53176 L F
.40368 .53173 m .40356 .53176 L .40224 .53065 L F
.751 .576 .002 r
.40366 .52994 m .40376 .5317 L .40368 .53173 L F
.40376 .5317 m .40386 .53343 L .40368 .53173 L F
.364 .565 .913 r
.63216 .39669 m .62829 .3936 L .63101 .39304 L F
.716 .694 .827 r
.63599 .39305 m .63216 .39669 L .63101 .39304 L F
.59 .844 .993 r
.20375 .60607 m .19946 .60577 L .20153 .60585 L F
.19946 .60577 m .20375 .60607 L .20153 .60585 L F
.489 .881 .961 r
.20479 .60508 m .20375 .60607 L .20153 .60585 L F
.528 .194 .345 r
.20479 .60508 m .20153 .60585 L .20375 .60607 L F
.807 .755 .805 r
.37066 .62388 m .37441 .62318 L .37262 .62524 L F
.424 .23 .511 r
.37401 .62334 m .37329 .62346 L .37297 .62586 L F
.37329 .62346 m .37066 .62388 L .37157 .62466 L F
.71 .959 .946 r
.37262 .62524 m .36953 .62732 L .36838 .62688 L F
.37262 .62524 m .36838 .62688 L .36883 .62656 L F
.36883 .62656 m .36838 .62688 L .36817 .62679 L F
.37262 .62524 m .36817 .62679 L .37114 .62646 L F
.424 .23 .511 r
.37329 .62346 m .37157 .62466 L .37297 .62586 L F
.701 .78 .296 r
.71534 .29979 m .71533 .30008 L .71593 .29855 L F
0 0 0 r
.71534 .29979 m .71593 .29855 L .71751 .29614 L F
.267 .085 .438 r
.71751 .29614 m .71767 .29825 L .71534 .29979 L F
0 0 0 r
.71767 .29825 m .71535 .29955 L .71534 .29979 L F
.71535 .29955 m .7143 .30014 L .71534 .29979 L F
.701 .78 .296 r
.71534 .29979 m .71451 .30221 L .71533 .30008 L F
0 0 .04 r
.71593 .29855 m .71796 .2943 L .71751 .29614 L F
0 .366 .823 r
.6502 .40314 m .65238 .40355 L .64915 .40436 L F
0 0 .396 r
.41671 .53751 m .41634 .53952 L .41623 .53733 L F
0 0 .15 r
.41671 .53751 m .41652 .54215 L .41634 .53952 L F
.578 .282 .43 r
.38718 .60917 m .389 .6049 L .3856 .60632 L F
.792 .679 .74 r
.38718 .60917 m .39247 .60177 L .389 .6049 L F
.171 0 .222 r
.20069 .56729 m .2036 .56397 L .20117 .56475 L F
.055 .23 .727 r
.22775 .61306 m .22975 .61345 L .22639 .61167 L F
.22775 .61306 m .22992 .61487 L .22975 .61345 L F
.717 .632 .762 r
.36787 .59018 m .37193 .5932 L .37035 .58936 L F
.36787 .59018 m .36923 .59367 L .37193 .5932 L F
.702 .546 .673 r
.36923 .59367 m .36941 .5963 L .37193 .5932 L F
.36923 .59367 m .36941 .5963 L .37193 .5932 L F
.508 .519 .803 r
.37193 .5932 m .37304 .58874 L .37035 .58936 L F
.37193 .5932 m .37459 .59311 L .37304 .58874 L F
0 0 0 r
.28615 .5282 m .28562 .52808 L .28777 .52721 L F
.28615 .5282 m .28417 .52905 L .28562 .52808 L F
.59 .939 .779 r
.22897 .54025 m .22854 .53972 L .231 .53906 L F
.22897 .54025 m .22666 .54118 L .22854 .53972 L F
.876 .507 .343 r
.3854 .6637 m .38563 .66698 L .38598 .66634 L F
.348 .438 .812 r
.38782 .66128 m .39007 .66581 L .3854 .6637 L F
.6 .169 .195 r
.38598 .66634 m .38563 .66698 L .38876 .66541 L F
.366 .836 .856 r
.38644 .66657 m .39103 .66592 L .38876 .66541 L F
.552 .294 .479 r
.3854 .6637 m .39007 .66581 L .3862 .66631 L F
.3859 .66597 m .3862 .66631 L .38598 .66634 L F
.3854 .6637 m .3862 .66631 L .3859 .66597 L F
.366 .836 .856 r
.38563 .66698 m .38662 .66678 L .38644 .66657 L F
.38662 .66678 m .39103 .66592 L .38644 .66657 L F
.569 .259 .403 r
.3854 .6637 m .39007 .66581 L .38563 .66698 L F
.634 .134 .047 r
.2904 .65195 m .29204 .65067 L .29429 .65255 L F
.764 .569 .633 r
.30878 .52991 m .3131 .53307 L .31105 .5299 L F
.30878 .52991 m .30868 .53315 L .3131 .53307 L F
.376 0 0 r
.30997 .53313 m .31122 .53397 L .3131 .53307 L F
.63 .1 0 r
.31122 .53397 m .31508 .5347 L .3131 .53307 L F
.759 .346 .267 r
.31122 .53397 m .31315 .53663 L .31508 .5347 L F
0 .045 .613 r
.31153 .53281 m .31235 .53474 L .31122 .53397 L F
.31235 .53474 m .31315 .53663 L .31122 .53397 L F
.376 0 0 r
.30868 .53315 m .31122 .53397 L .30997 .53313 L F
.661 .7 .875 r
.31105 .5299 m .3131 .53307 L .31426 .53101 L F
.47 .75 .991 r
.24121 .61144 m .2408 .61319 L .23929 .61174 L F
.24121 .61144 m .24347 .61296 L .2408 .61319 L F
.917 .749 .657 r
.41683 .52089 m .41633 .52353 L .41515 .51981 L F
.794 .689 .75 r
.68206 .33701 m .67837 .33631 L .68071 .33316 L F
.728 .416 .451 r
.68206 .33701 m .6783 .33888 L .67837 .33631 L F
.68206 .33701 m .68286 .33909 L .6783 .33888 L F
.781 .739 .814 r
.29448 .63097 m .29717 .6304 L .29676 .62677 L F
.638 .636 .831 r
.29676 .62677 m .29717 .6304 L .3001 .6274 L F
.297 .786 .895 r
.27283 .53109 m .27038 .53081 L .26789 .53121 L F
.592 .932 .952 r
.2727 .52972 m .27283 .53109 L .27491 .5303 L F
.2727 .52972 m .27038 .53081 L .27283 .53109 L F
.738 .7 .815 r
.40192 .51797 m .39794 .51709 L .40082 .51509 L F
.559 .507 .754 r
.40412 .5173 m .40192 .51797 L .40082 .51509 L F
.573 .55 .79 r
.32035 .55741 m .3219 .56103 L .31927 .56148 L F
.542 .33 .541 r
.3219 .56103 m .31912 .56411 L .31927 .56148 L F
.514 .119 .23 r
.35346 .58398 m .34962 .58618 L .35203 .5821 L F
.35346 .58398 m .35346 .58544 L .34962 .58618 L F
.864 .438 .206 r
.35346 .58398 m .35382 .58602 L .35346 .58544 L F
0 0 .307 r
.35249 .58077 m .35339 .58345 L .35346 .58398 L F
.888 .661 .588 r
.35339 .58345 m .35382 .58602 L .35346 .58398 L F
.204 .542 .928 r
.5893 .40509 m .58839 .40632 L .58686 .40493 L F
.5893 .40509 m .59078 .40692 L .58839 .40632 L F
.116 0 0 r
.38391 .70732 m .38461 .70854 L .38208 .70899 L F
.38391 .70732 m .38614 .70658 L .38461 .70854 L F
.499 .301 .542 r
.66127 .40623 m .6612 .40922 L .65845 .41 L F
.959 .733 .282 r
.66049 .40466 m .6612 .40922 L .66127 .40623 L F
.16 .69 .862 r
.65845 .41 m .65737 .40971 L .65437 .4098 L F
.626 .905 .984 r
.6612 .40922 m .65737 .40971 L .65845 .41 L F
0 0 .391 r
.34945 .51743 m .3504 .5157 L .34956 .51355 L F
.976 .885 .673 r
.35148 .51682 m .3504 .5157 L .34945 .51743 L F
.72 .538 .643 r
.34945 .51743 m .35269 .52031 L .35148 .51682 L F
.34945 .51743 m .34868 .52034 L .35269 .52031 L F
0 0 .391 r
.34945 .51743 m .3504 .5157 L .34956 .51355 L F
0 .289 .661 r
.32593 .51495 m .32378 .51388 L .32196 .51303 L F
.262 .467 .871 r
.32674 .51317 m .32593 .51495 L .32325 .51106 L F
.574 .833 .994 r
.32674 .51317 m .32378 .51388 L .32593 .51495 L F
.842 .985 .705 r
.39203 .65887 m .39011 .6604 L .38908 .65715 L F
.647 .21 .197 r
.38785 .65867 m .39203 .65887 L .38908 .65715 L F
.722 .812 .346 r
.39804 .62166 m .39701 .62371 L .39708 .62382 L F
0 0 .099 r
.39978 .61768 m .3992 .62032 L .39804 .62166 L F
0 0 0 r
.3992 .62032 m .39701 .62371 L .39804 .62166 L F
.779 .695 .771 r
.5574 .41845 m .56149 .41916 L .55869 .42208 L F
.709 .576 .704 r
.56149 .41916 m .56222 .4217 L .55869 .42208 L F
.198 .251 .693 r
.5638 .42084 m .56149 .41916 L .56471 .41864 L F
.5638 .42084 m .56222 .4217 L .56149 .41916 L F
.662 .533 .696 r
.29065 .63052 m .29448 .63097 L .29369 .62718 L F
.461 .44 .749 r
.29065 .63052 m .29411 .63332 L .29448 .63097 L F
.29065 .63052 m .29219 .63445 L .29411 .63332 L F
.521 0 0 r
.29456 .55132 m .29497 .5518 L .29384 .55075 L F
.336 .61 .949 r
.21002 .59975 m .21278 .60242 L .21341 .60073 L F
.036 .247 .747 r
.21278 .60242 m .21515 .60452 L .21341 .60073 L F
.71 .623 .757 r
.35684 .59933 m .35776 .60276 L .35434 .60267 L F
.319 .77 .956 r
.35434 .60267 m .35776 .60276 L .35631 .60217 L F
0 0 0 r
.3589 .60067 m .35775 .60047 L .35955 .59984 L F
0 0 .532 r
.35775 .60047 m .35776 .60276 L .35711 .60035 L F
.866 .948 .866 r
.35631 .60217 m .35776 .60276 L .35775 .60047 L F
0 0 0 r
.35703 .60308 m .35775 .60047 L .3589 .60067 L F
0 0 .532 r
.35775 .60047 m .35711 .60035 L .35684 .59933 L F
.436 0 0 r
.38731 .5869 m .38554 .58845 L .38355 .58836 L F
.624 .533 .731 r
.38919 .58441 m .38983 .58698 L .38731 .5869 L F
.565 0 0 r
.38731 .5869 m .3868 .5874 L .38554 .58845 L F
.38731 .5869 m .38918 .58862 L .3868 .5874 L F
.503 .048 .104 r
.38731 .5869 m .38983 .58698 L .38918 .58862 L F
.416 .251 .547 r
.31948 .58042 m .31944 .5831 L .31736 .58377 L F
.399 .209 .504 r
.31944 .5831 m .31929 .58558 L .31736 .58377 L F
.335 .208 .555 r
.31929 .58558 m .31747 .58649 L .31736 .58377 L F
0 0 0 r
.28959 .63761 m .28751 .64172 L .28837 .64035 L F
.161 0 .229 r
.2914 .63654 m .29219 .63445 L .28959 .63761 L F
.118 0 .159 r
.2914 .63654 m .28959 .63761 L .28837 .64035 L F
.369 .385 .745 r
.19795 .59711 m .19973 .59451 L .19643 .59547 L F
.19795 .59711 m .20196 .59921 L .19973 .59451 L F
0 0 .192 r
.3116 .57509 m .31113 .57657 L .31192 .57425 L F
0 0 0 r
.31113 .57657 m .31408 .57292 L .31192 .57425 L F
.537 .108 .174 r
.55869 .42208 m .56222 .4217 L .56162 .4242 L F
.659 .434 .567 r
.5638 .42084 m .56405 .42318 L .56162 .4242 L F
.229 .728 .909 r
.5666 .42298 m .56405 .42318 L .56304 .42291 L F
0 0 0 r
.56229 .42317 m .56222 .4217 L .5638 .42084 L F
.56162 .4242 m .56183 .42332 L .56229 .42317 L F
.56183 .42332 m .56222 .4217 L .56229 .42317 L F
.936 .85 .733 r
.56162 .4242 m .5638 .42084 L .5623 .41934 L F
.229 .728 .909 r
.56348 .42277 m .56304 .42291 L .56213 .42267 L F
.5666 .42298 m .56304 .42291 L .56348 .42277 L F
.704 .867 .46 r
.23638 .54619 m .23515 .54791 L .23458 .54927 L F
.967 .827 .653 r
.23194 .55017 m .23458 .54927 L .23515 .54791 L F
.23194 .55017 m .23307 .55251 L .23458 .54927 L F
.45 .663 .953 r
.25384 .61984 m .25699 .62354 L .25285 .62173 L F
.446 .659 .952 r
.25591 .61956 m .25699 .62354 L .25384 .61984 L F
.359 .007 .225 r
.31422 .53962 m .31352 .54144 L .31106 .54191 L F
0 0 .378 r
.33738 .5699 m .33756 .57182 L .33797 .56958 L F
.755 .918 .945 r
.33797 .56958 m .33756 .57182 L .33667 .57086 L F
.779 .665 .737 r
.3369 .57114 m .33866 .56921 L .33797 .56958 L F
.33866 .56921 m .33964 .56813 L .33797 .56958 L F
0 0 .378 r
.33721 .56816 m .33738 .5699 L .33797 .56958 L F
.231 0 .141 r
.33954 .57215 m .33756 .57182 L .33968 .57182 L F
.33954 .57215 m .33701 .57335 L .33756 .57182 L F
.788 .983 .721 r
.34191 .66615 m .34443 .66334 L .34246 .66443 L F
.123 0 0 r
.34246 .66443 m .34443 .66334 L .34678 .66309 L F
.747 .678 .785 r
.5574 .41845 m .55869 .42208 L .55457 .42105 L F
.971 .662 .366 r
.55457 .42105 m .55477 .42316 L .55366 .42412 L F
.55477 .42316 m .55488 .4242 L .55366 .42412 L F
.917 .97 .784 r
.55366 .42412 m .55275 .42721 L .55096 .42617 L F
0 0 0 r
.5522 .42537 m .55366 .42412 L .55129 .42594 L F
.682 .189 .069 r
.55457 .42105 m .55744 .42352 L .55488 .4242 L F
.572 .561 .804 r
.55488 .4242 m .55535 .42254 L .55366 .42412 L F
.917 .97 .784 r
.55366 .42412 m .55488 .4242 L .55275 .42721 L F
.682 .189 .069 r
.55602 .4223 m .55869 .42208 L .55744 .42352 L F
.55457 .42105 m .55745 .42177 L .55602 .4223 L F
.55745 .42177 m .55869 .42208 L .55602 .4223 L F
.572 .561 .804 r
.55488 .4242 m .55744 .42352 L .55617 .41964 L F
.487 .854 .988 r
.55626 .42282 m .55488 .4242 L .55366 .42412 L F
0 0 0 r
.55626 .42282 m .55366 .42412 L .5522 .42537 L F
.572 .561 .804 r
.55535 .42254 m .55617 .41964 L .55434 .42291 L F
.55535 .42254 m .55434 .42291 L .55366 .42412 L F
.449 .523 .842 r
.55943 .42392 m .56121 .42651 L .55884 .42494 L F
.57 .058 0 r
.55902 .42378 m .55869 .42208 L .56162 .4242 L F
.55744 .42352 m .55764 .42329 L .55902 .42378 L F
.55764 .42329 m .55869 .42208 L .55902 .42378 L F
.55744 .42352 m .56162 .4242 L .55999 .42294 L F
.449 .523 .842 r
.55999 .42294 m .56045 .42428 L .55943 .42392 L F
.56045 .42428 m .56121 .42651 L .55943 .42392 L F
.4 0 0 r
.27015 .55205 m .2728 .55348 L .27417 .55215 L F
.668 .27 .282 r
.27417 .55215 m .27628 .55434 L .27348 .55374 L F
.588 .853 .508 r
.27417 .55215 m .27479 .55123 L .27642 .55154 L F
.27417 .55215 m .2728 .55348 L .27479 .55123 L F
.476 .284 .54 r
.27642 .55154 m .27628 .55434 L .27417 .55215 L F
.73 .584 .692 r
.39229 .59316 m .39265 .59663 L .39521 .59325 L F
.59 .769 .965 r
.39445 .59152 m .39521 .59325 L .39748 .59187 L F
0 0 0 r
.55973 .42682 m .5546 .42817 L .55884 .42494 L F
.081 .437 .876 r
.56121 .42651 m .55973 .42682 L .55884 .42494 L F
.56121 .42651 m .56299 .42861 L .55973 .42682 L F
.186 0 0 r
.3336 .67764 m .33141 .67828 L .32967 .68045 L F
.192 0 .073 r
.3347 .67595 m .33141 .67828 L .3336 .67764 L F
.149 0 .223 r
.29411 .63332 m .29219 .63445 L .2914 .63654 L F
0 .287 .744 r
.34647 .53627 m .34505 .53474 L .34249 .53348 L F
.401 .022 .2 r
.34505 .53474 m .34205 .53536 L .34249 .53348 L F
.98 .731 .483 r
.37917 .67764 m .37923 .68057 L .38082 .67862 L F
.879 .9 .841 r
.37917 .67764 m .38082 .67862 L .38329 .67543 L F
.557 .107 .139 r
.38082 .67862 m .37923 .68057 L .38309 .68025 L F
.644 .508 .682 r
.38082 .67862 m .38385 .6791 L .38329 .67543 L F
.566 .093 .092 r
.38309 .68025 m .38385 .6791 L .38082 .67862 L F
0 0 0 r
.33603 .67477 m .3347 .67595 L .3336 .67764 L F
.749 .533 .603 r
.69911 .35261 m .69911 .35509 L .69538 .3551 L F
.634 .394 .537 r
.70164 .35274 m .69911 .35509 L .69911 .35261 L F
.981 .765 .539 r
.36503 .63791 m .36146 .63981 L .36205 .63738 L F
.36503 .63791 m .36446 .64058 L .36146 .63981 L F
.614 .236 .303 r
.36407 .63974 m .36205 .63738 L .36146 .63981 L F
.36407 .63974 m .36503 .63791 L .36205 .63738 L F
.732 .661 .108 r
.35434 .60267 m .35403 .60506 L .35406 .60517 L F
.319 .77 .956 r
.35434 .60267 m .35631 .60217 L .35403 .60506 L F
.673 .307 .344 r
.36255 .56629 m .3582 .56675 L .36005 .56457 L F
.926 .942 .789 r
.61947 .38652 m .62051 .38753 L .61808 .39058 L F
.986 .796 .565 r
.62051 .38753 m .62052 .39009 L .61808 .39058 L F
.626 .786 .958 r
.62179 .38503 m .62051 .38753 L .61947 .38652 L F
.62179 .38503 m .62328 .38657 L .62051 .38753 L F
.288 0 0 r
.25687 .5359 m .25239 .53743 L .2544 .53696 L F
.942 .706 .551 r
.71381 .30695 m .71551 .30885 L .7139 .30467 L F
.433 .222 .492 r
.33952 .53883 m .33894 .54138 L .33729 .53954 L F
.042 .148 .65 r
.33894 .54138 m .33829 .54245 L .33729 .53954 L F
.484 .9 .863 r
.56911 .42676 m .56682 .42792 L .56603 .42776 L F
.07 .459 .885 r
.37998 .51713 m .37845 .51754 L .37718 .51599 L F
.37998 .51713 m .38144 .51879 L .37845 .51754 L F
.721 .595 .714 r
.24209 .58698 m .23815 .58406 L .24056 .58324 L F
.24209 .58698 m .23875 .58715 L .23815 .58406 L F
.634 .363 .491 r
.24124 .58916 m .23875 .58715 L .24209 .58698 L F
.038 .237 .738 r
.24277 .58556 m .24209 .58698 L .24056 .58324 L F
0 0 0 r
.2425 .58741 m .24209 .58698 L .24277 .58556 L F
.2425 .58741 m .24124 .58916 L .24209 .58698 L F
0 .208 .716 r
.58791 .40961 m .59001 .41187 L .59033 .4114 L F
0 .202 .712 r
.59033 .4114 m .59001 .41187 L .59319 .41421 L F
.503 .47 .753 r
.34645 .52341 m .3479 .52707 L .34927 .52609 L F
.467 .152 .347 r
.346 .52759 m .34927 .52609 L .3479 .52707 L F
.453 .875 .931 r
.27108 .52312 m .26704 .52376 L .26948 .52333 L F
.293 .791 .796 r
.27355 .52241 m .27108 .52312 L .26948 .52333 L F
.3 .393 .79 r
.65002 .42071 m .65092 .42427 L .64899 .4228 L F
.591 .379 .562 r
.64899 .4228 m .65092 .42427 L .64841 .4255 L F
.81 .695 .738 r
.40082 .51509 m .39794 .51709 L .40018 .51396 L F
.91 .548 .096 r
.62288 .43061 m .62391 .43168 L .62223 .42821 L F
.986 .726 .35 r
.62308 .43324 m .62391 .43168 L .62288 .43061 L F
.611 .951 .799 r
.29217 .56401 m .28814 .56657 L .2907 .5653 L F
.438 .177 .419 r
.3211 .52688 m .32368 .52631 L .32392 .52357 L F
.375 .154 .446 r
.32392 .52357 m .32584 .52347 L .32628 .52053 L F
.665 .367 .458 r
.32392 .52357 m .32661 .52507 L .32584 .52347 L F
.32392 .52357 m .32368 .52631 L .32661 .52507 L F
.648 .393 .52 r
.32392 .52357 m .32661 .52507 L .32584 .52347 L F
.639 .222 .235 r
.30323 .54418 m .30705 .54218 L .30503 .54524 L F
.579 .392 .592 r
.30503 .54524 m .30843 .54472 L .30705 .54218 L F
.639 .222 .235 r
.30323 .54418 m .30612 .54499 L .30705 .54218 L F
0 0 0 r
.31106 .54191 m .30843 .54472 L .30705 .54218 L F
.31106 .54191 m .30977 .54431 L .30843 .54472 L F
.569 .153 .212 r
.30705 .54218 m .30977 .54431 L .30772 .54038 L F
.30705 .54218 m .30612 .54499 L .30977 .54431 L F
0 0 0 r
.35654 .65182 m .35471 .65299 L .35388 .65463 L F
.432 .278 .572 r
.29918 .59595 m .30267 .59595 L .30227 .5922 L F
.353 .159 .472 r
.29918 .59595 m .30167 .59828 L .30267 .59595 L F
.29918 .59595 m .29994 .59912 L .30167 .59828 L F
.913 .972 .677 r
.3376 .50604 m .33776 .5079 L .33956 .50463 L F
.359 .735 .988 r
.34647 .53627 m .3472 .53509 L .34505 .53474 L F
.624 .87 .519 r
.34647 .53627 m .34532 .5374 L .3472 .53509 L F
.973 .691 .432 r
.35062 .55526 m .34894 .55429 L .34983 .55273 L F
.572 .434 .654 r
.34645 .52341 m .34925 .52351 L .34868 .52034 L F
.503 .47 .753 r
.34645 .52341 m .34927 .52609 L .34925 .52351 L F
.757 .249 0 r
.61794 .44729 m .61876 .44958 L .61643 .44653 L F
.61794 .44729 m .62006 .44963 L .61876 .44958 L F
.564 .708 .938 r
.64475 .39468 m .64139 .39345 L .644 .39272 L F
.538 .667 .92 r
.64664 .39398 m .64475 .39468 L .644 .39272 L F
.628 .912 .626 r
.73625 .33697 m .73456 .33914 L .73771 .3366 L F
.73625 .33697 m .73455 .33884 L .73456 .33914 L F
0 .156 .665 r
.38714 .52446 m .38638 .52444 L .38521 .52222 L F
0 .048 .614 r
.38523 .52102 m .38714 .52446 L .38521 .52222 L F
.736 .309 0 r
.38619 .52308 m .38714 .52446 L .386 .52265 L F
0 .156 .665 r
.38714 .52446 m .38796 .52563 L .38638 .52444 L F
0 .261 .768 r
.38293 .51924 m .38521 .52222 L .38527 .51955 L F
.38293 .51924 m .38523 .52102 L .38521 .52222 L F
0 .118 .584 r
.38358 .51966 m .38523 .52102 L .38293 .51924 L F
.969 .655 .359 r
.38358 .51966 m .38396 .52249 L .38523 .52102 L F
.787 .337 .178 r
.38523 .52102 m .38396 .52249 L .386 .52265 L F
.045 .381 .845 r
.38419 .52101 m .38562 .52267 L .38396 .52249 L F
.736 .309 0 r
.38706 .52509 m .38714 .52446 L .38619 .52308 L F
.38741 .52589 m .38735 .52558 L .38706 .52509 L F
0 0 .34 r
.38674 .52397 m .38741 .52589 L .38633 .52341 L F
.38674 .52397 m .38633 .52341 L .386 .52265 L F
.38674 .52397 m .386 .52265 L .38574 .52263 L F
.38674 .52397 m .38574 .52263 L .38396 .52249 L F
0 .027 .555 r
.38569 .5226 m .38674 .52397 L .38419 .52101 L F
.799 .333 0 r
.38569 .5226 m .38706 .52439 L .38674 .52397 L F
0 .156 .665 r
.38714 .52446 m .38844 .52599 L .38796 .52563 L F
.779 .351 .235 r
.38714 .52446 m .38795 .52526 L .38844 .52599 L F
.38714 .52446 m .38864 .52745 L .38795 .52526 L F
0 0 .528 r
.38674 .52397 m .38838 .52614 L .3886 .52734 L F
.799 .333 0 r
.38706 .52439 m .38838 .52614 L .38674 .52397 L F
.045 .381 .845 r
.38562 .52267 m .38674 .52397 L .38623 .5237 L F
.38562 .52267 m .38623 .5237 L .38396 .52249 L F
.736 .309 0 r
.38735 .52558 m .38714 .52446 L .38706 .52509 L F
.578 .282 .43 r
.38718 .60917 m .3856 .60632 L .38505 .60953 L F
.634 .394 .537 r
.70164 .35274 m .70177 .35528 L .69911 .35509 L F
.655 .624 .806 r
.33882 .50252 m .33539 .50061 L .33755 .5002 L F
.736 .772 .882 r
.34209 .50142 m .33882 .50252 L .33755 .5002 L F
.709 .931 .963 r
.34184 .59395 m .34479 .59313 L .34484 .59329 L F
.106 0 .366 r
.3472 .5893 m .34688 .59203 L .34479 .59313 L F
0 0 0 r
.34688 .59203 m .34484 .59329 L .34479 .59313 L F
.839 .454 0 r
.311 .51672 m .31193 .51804 L .31131 .51575 L F
0 0 0 r
.31196 .51799 m .31165 .5182 L .31249 .51746 L F
.31228 .51768 m .31249 .51746 L .31263 .51734 L F
.31196 .51799 m .31249 .51746 L .31228 .51768 L F
0 0 .314 r
.31131 .51575 m .31196 .51799 L .31263 .51734 L F
.31131 .51575 m .31202 .51795 L .31196 .51799 L F
.471 .178 .386 r
.31317 .51961 m .31071 .52197 L .31196 .51799 L F
.31071 .52197 m .3102 .52246 L .31071 .52117 L F
.31071 .52197 m .31071 .52117 L .31196 .51799 L F
0 0 0 r
.31196 .51799 m .30913 .52253 L .30957 .52001 L F
.505 .597 .88 r
.3114 .52602 m .31268 .52783 L .30939 .5281 L F
.212 .673 .945 r
.30939 .5281 m .31341 .52902 L .31105 .5299 L F
.94 .952 .756 r
.31272 .52731 m .31263 .5284 L .31341 .52902 L F
.212 .673 .945 r
.30939 .5281 m .31263 .5284 L .31341 .52902 L F
.94 .952 .756 r
.31263 .5284 m .31255 .52934 L .31341 .52902 L F
.212 .673 .945 r
.31263 .5284 m .31311 .52844 L .31341 .52902 L F
.505 .597 .88 r
.31268 .52783 m .31311 .52844 L .31263 .5284 L F
.31268 .52783 m .31263 .5284 L .30939 .5281 L F
.94 .952 .756 r
.31324 .52641 m .3128 .52752 L .31341 .52902 L F
.744 .688 .798 r
.31324 .52641 m .31311 .52844 L .31268 .52783 L F
.31324 .52641 m .31268 .52783 L .3114 .52602 L F
.94 .952 .756 r
.31324 .52641 m .31272 .52731 L .3128 .52752 L F
.661 .7 .875 r
.31105 .5299 m .31426 .53101 L .31341 .52902 L F
0 0 .127 r
.31122 .52985 m .31105 .5299 L .31341 .52902 L F
.94 .952 .756 r
.31272 .52731 m .31122 .52985 L .31255 .52934 L F
.648 .151 .055 r
.30939 .5281 m .31122 .52985 L .3114 .52602 L F
.782 .558 .596 r
.31434 .52442 m .3114 .52602 L .31247 .52373 L F
.31434 .52442 m .31324 .52641 L .3114 .52602 L F
.768 .641 .722 r
.3114 .52602 m .31122 .52985 L .31324 .52641 L F
.335 .42 .8 r
.3102 .52246 m .30825 .52422 L .30913 .52253 L F
0 0 0 r
.31129 .51907 m .3102 .52246 L .30989 .52248 L F
.30989 .52131 m .30989 .52248 L .30913 .52253 L F
.31129 .51907 m .30989 .52248 L .30989 .52131 L F
.195 0 .349 r
.30825 .52422 m .30686 .52333 L .30913 .52253 L F
.335 .42 .8 r
.3102 .52246 m .31117 .5236 L .30825 .52422 L F
.852 .467 0 r
.31125 .52396 m .31117 .5236 L .31247 .52373 L F
.829 .493 .418 r
.31247 .52373 m .31146 .52394 L .31117 .5236 L F
.31247 .52373 m .31117 .5236 L .3102 .52246 L F
.852 .467 0 r
.31117 .5236 m .31114 .52345 L .31247 .52373 L F
0 0 0 r
.31071 .52117 m .3102 .52246 L .31129 .51907 L F
.829 .493 .418 r
.31247 .52373 m .3102 .52246 L .31317 .51961 L F
.868 .591 .515 r
.30861 .52014 m .31108 .52343 L .31247 .52373 L F
.852 .467 0 r
.31114 .52345 m .31106 .52309 L .31247 .52373 L F
.868 .591 .515 r
.31108 .52343 m .31146 .52394 L .31247 .52373 L F
.335 .42 .8 r
.31117 .5236 m .31146 .52394 L .31125 .52396 L F
.31117 .5236 m .31125 .52396 L .30825 .52422 L F
.852 .467 0 r
.31171 .52535 m .31125 .52396 L .31247 .52373 L F
.31125 .52396 m .31095 .52304 L .31106 .52309 L F
.334 .452 .832 r
.30825 .52422 m .31125 .52396 L .30861 .52014 L F
.31125 .52396 m .31108 .52343 L .30861 .52014 L F
.852 .467 0 r
.3114 .52602 m .3092 .52224 L .31095 .52304 L F
.3114 .52602 m .31095 .52304 L .31171 .52535 L F
.334 .452 .832 r
.31125 .52396 m .31146 .52394 L .31108 .52343 L F
.915 .554 .335 r
.31243 .52628 m .31027 .52532 L .3114 .52602 L F
.31243 .52628 m .31066 .52733 L .31027 .52532 L F
.461 .247 .502 r
.31027 .52532 m .31066 .52733 L .31086 .52711 L F
.852 .467 0 r
.3114 .52602 m .31027 .52532 L .30994 .52429 L F
.3114 .52602 m .3099 .52424 L .30989 .52344 L F
.181 0 0 r
.31301 .52636 m .31243 .52628 L .3114 .52602 L F
.31324 .52641 m .31243 .52628 L .31301 .52636 L F
.768 .976 .706 r
.31336 .5242 m .31166 .52618 L .31243 .52628 L F
.31166 .52618 m .31066 .52733 L .31243 .52628 L F
.461 .247 .502 r
.31027 .52532 m .31086 .52711 L .31336 .5242 L F
.852 .467 0 r
.30994 .52429 m .31027 .52532 L .3099 .52424 L F
.30989 .52344 m .3099 .52424 L .3092 .52224 L F
0 0 0 r
.31196 .51799 m .31071 .52117 L .31129 .51907 L F
.868 .591 .515 r
.30861 .52014 m .3105 .5219 L .3092 .52224 L F
.3105 .5219 m .31071 .52209 L .31044 .52212 L F
.3105 .5219 m .31044 .52212 L .3092 .52224 L F
.31071 .52209 m .31247 .52373 L .31071 .52293 L F
.31071 .52209 m .31071 .52293 L .3092 .52224 L F
.471 .178 .386 r
.31317 .51961 m .31196 .51799 L .31215 .51836 L F
0 0 .314 r
.31202 .51795 m .31215 .51836 L .31196 .51799 L F
0 0 0 r
.31196 .51799 m .30957 .52001 L .31165 .5182 L F
.839 .454 0 r
.31193 .51804 m .31215 .51836 L .31202 .51795 L F
.31193 .51804 m .31202 .51795 L .31131 .51575 L F
.991 .81 .561 r
.4199 .57716 m .41792 .57884 L .41829 .57612 L F
.4199 .57716 m .41922 .57986 L .41792 .57884 L F
0 .188 .702 r
.22492 .60991 m .22595 .61159 L .22639 .61167 L F
.635 .89 .986 r
.42247 .55488 m .41928 .55499 L .42245 .55388 L F
.568 .341 .531 r
.42541 .55746 m .42247 .55488 L .42245 .55388 L F
.42541 .55746 m .42294 .55813 L .42247 .55488 L F
.639 .311 .399 r
.36654 .54042 m .36909 .54268 L .36715 .54188 L F
.769 .782 .863 r
.62879 .40975 m .63073 .40593 L .62742 .40574 L F
.62879 .40975 m .63154 .40749 L .63124 .40691 L F
.63029 .4068 m .63124 .40691 L .63073 .40593 L F
.62879 .40975 m .63124 .40691 L .63029 .4068 L F
.62879 .40975 m .62742 .40574 L .62997 .40768 L F
.629 .112 0 r
.62997 .40768 m .62855 .4066 L .62595 .40707 L F
.62855 .4066 m .62742 .40574 L .6267 .40639 L F
.62855 .4066 m .6267 .40639 L .62595 .40707 L F
.657 .852 .454 r
.62773 .4111 m .62879 .40975 L .62997 .40768 L F
0 0 0 r
.3233 .61402 m .32405 .61392 L .32709 .61144 L F
.451 .549 .865 r
.32781 .60789 m .32709 .61144 L .32713 .61024 L F
.32781 .60789 m .32918 .61163 L .32709 .61144 L F
.824 .986 .715 r
.32709 .61144 m .32405 .61392 L .32713 .61024 L F
.454 .347 .643 r
.32912 .59312 m .33179 .59558 L .33174 .59304 L F
.32912 .59312 m .32963 .59621 L .33179 .59558 L F
0 0 0 r
.62208 .41693 m .62274 .41511 L .62486 .41413 L F
.835 .511 .44 r
.57312 .44436 m .56954 .44353 L .5694 .4413 L F
.718 .458 .532 r
.57312 .44436 m .57107 .44622 L .56954 .44353 L F
.57312 .44436 m .5734 .44702 L .57107 .44622 L F
.679 .429 .537 r
.57764 .44666 m .5734 .44702 L .57312 .44436 L F
.248 0 .274 r
.25331 .54868 m .25238 .55153 L .25071 .55186 L F
.827 .735 .763 r
.25331 .54868 m .25071 .55186 L .24927 .54853 L F
.405 .108 .344 r
.25507 .55071 m .25238 .55153 L .25331 .54868 L F
.532 .444 .7 r
.25558 .54555 m .25597 .54856 L .25331 .54868 L F
.457 .113 .292 r
.25597 .54856 m .25507 .55071 L .25331 .54868 L F
.773 .546 .591 r
.56676 .44142 m .56322 .44359 L .56306 .44104 L F
.56676 .44142 m .56662 .44408 L .56322 .44359 L F
.59 .389 .578 r
.56954 .44353 m .56676 .44142 L .5694 .4413 L F
.56954 .44353 m .56662 .44408 L .56676 .44142 L F
.621 .81 .972 r
.62687 .38715 m .62328 .38657 L .62577 .38623 L F
.648 .907 .982 r
.62957 .38551 m .62687 .38715 L .62577 .38623 L F
.615 .699 .904 r
.62957 .38551 m .63033 .38776 L .62687 .38715 L F
.517 .53 .808 r
.6308 .39039 m .62687 .38715 L .63033 .38776 L F
.092 0 .258 r
.39706 .69424 m .39642 .69664 L .39458 .69731 L F
.084 0 .237 r
.39642 .69664 m .39414 .70002 L .39458 .69731 L F
.946 .63 .405 r
.42155 .58391 m .41971 .58551 L .41973 .58252 L F
.42155 .58391 m .42187 .58666 L .41971 .58551 L F
.811 .525 .504 r
.42376 .58621 m .42187 .58666 L .42155 .58391 L F
.571 .918 .714 r
.63101 .43769 m .62788 .44021 L .62778 .44017 L F
.453 .884 .839 r
.62778 .44017 m .63167 .43897 L .63101 .43769 L F
0 .393 .843 r
.63101 .43769 m .63167 .43897 L .63449 .44031 L F
.462 .319 .6 r
.63167 .43897 m .63209 .44148 L .63449 .44031 L F
.432 .874 .862 r
.29994 .5184 m .29984 .51773 L .30206 .5172 L F
.29994 .5184 m .29764 .51864 L .29984 .51773 L F
.852 .823 .819 r
.60257 .39428 m .59903 .39548 L .60129 .39286 L F
.717 .805 .92 r
.60129 .39286 m .6051 .39321 L .60257 .39428 L F
0 0 .465 r
.34165 .65011 m .34151 .64583 L .33981 .64912 L F
.365 .627 .954 r
.30939 .5281 m .31105 .5299 L .30878 .52991 L F
.574 .848 .996 r
.30878 .52991 m .30707 .52889 L .30939 .5281 L F
.558 .454 .691 r
.31105 .5299 m .30868 .53315 L .30878 .52991 L F
0 .184 .669 r
.33366 .64382 m .33747 .64696 L .3363 .64288 L F
.825 .455 .356 r
.64285 .40248 m .64662 .40371 L .64682 .40568 L F
0 0 0 r
.22027 .54602 m .21887 .54771 L .22211 .545 L F
.608 .827 .984 r
.37093 .65845 m .37285 .65989 L .37036 .66069 L F
.799 .62 .659 r
.32728 .53925 m .32274 .53658 L .3252 .53587 L F
.32728 .53925 m .32328 .53953 L .32274 .53658 L F
.056 0 0 r
.32728 .53925 m .32525 .5396 L .32328 .53953 L F
.517 .076 .139 r
.31858 .5379 m .32274 .53658 L .32066 .53954 L F
.562 .461 .697 r
.32274 .53658 m .32328 .53953 L .32066 .53954 L F
.499 0 0 r
.32525 .5396 m .32093 .53824 L .32328 .53953 L F
.32525 .5396 m .32347 .53958 L .32093 .53824 L F
.908 .906 .809 r
.3257 .53726 m .32347 .53958 L .32525 .5396 L F
.724 .311 0 r
.3252 .53587 m .32634 .53819 L .32728 .53925 L F
0 0 .449 r
.32591 .53616 m .32683 .53919 L .3252 .53587 L F
.908 .906 .809 r
.32591 .53616 m .32541 .53685 L .3257 .53726 L F
.32541 .53685 m .32347 .53958 L .3257 .53726 L F
.724 .311 0 r
.32634 .53819 m .32683 .53919 L .32705 .53922 L F
.32634 .53819 m .32705 .53922 L .32728 .53925 L F
.218 .737 .738 r
.32683 .53919 m .32525 .5396 L .32728 .53925 L F
.584 .533 .763 r
.32728 .53925 m .331 .54228 L .32966 .53874 L F
.695 .579 .72 r
.2257 .57069 m .22654 .57445 L .22876 .57354 L F
0 0 .378 r
.33721 .56816 m .33797 .56958 L .33912 .56723 L F
.447 .425 .741 r
.31156 .64802 m .31393 .64545 L .31119 .64745 L F
.443 .498 .821 r
.23337 .56217 m .23493 .56049 L .2334 .56101 L F
.23337 .56217 m .23643 .56422 L .23493 .56049 L F
.704 .76 .262 r
.33776 .5079 m .33745 .50853 L .3376 .50604 L F
.346 .824 .855 r
.34342 .67297 m .33853 .67381 L .34152 .67243 L F
.517 .886 .974 r
.34565 .67213 m .34342 .67297 L .34152 .67243 L F
.748 .627 .725 r
.70537 .32639 m .70695 .32748 L .70519 .32387 L F
.827 .624 .628 r
.7029 .32892 m .70695 .32748 L .70537 .32639 L F
.7029 .32892 m .70668 .3301 L .70695 .32748 L F
.962 .632 .321 r
.41558 .55795 m .41409 .55734 L .41381 .55444 L F
.991 .818 .44 r
.41558 .55795 m .41412 .56008 L .41409 .55734 L F
.41558 .55795 m .41515 .56116 L .41412 .56008 L F
.938 .85 .73 r
.31014 .57763 m .30837 .57986 L .30844 .57815 L F
0 0 .192 r
.3116 .57509 m .31014 .57763 L .31113 .57657 L F
.413 .041 .219 r
.30844 .57815 m .31113 .57657 L .31014 .57763 L F
.867 .713 .689 r
.68229 .35273 m .67866 .35489 L .68113 .35146 L F
.68229 .35273 m .68217 .35575 L .67866 .35489 L F
.992 .828 .58 r
.68239 .34962 m .68229 .35273 L .68113 .35146 L F
.762 .486 .516 r
.23298 .59002 m .23262 .59225 L .22796 .59183 L F
.49 .238 .459 r
.23511 .59172 m .23298 .59002 L .23552 .58964 L F
.23511 .59172 m .23262 .59225 L .23298 .59002 L F
.861 .733 .721 r
.67866 .35489 m .68217 .35575 L .67985 .35848 L F
.704 .485 .588 r
.68217 .35575 m .68242 .35846 L .67985 .35848 L F
.648 .415 .552 r
.68627 .35568 m .68242 .35846 L .68217 .35575 L F
.403 .557 .894 r
.24982 .61674 m .24884 .61906 L .24745 .61708 L F
.24982 .61674 m .251 .6193 L .24884 .61906 L F
.37 .115 .392 r
.34893 .59916 m .35167 .59512 L .34956 .59599 L F
.736 .772 .882 r
.34209 .50142 m .33755 .5002 L .34039 .50052 L F
.337 .635 .962 r
.34277 .49981 m .34209 .50142 L .34039 .50052 L F
.34277 .49981 m .34444 .50145 L .34209 .50142 L F
0 0 0 r
.2036 .56397 m .2054 .56337 L .20704 .56171 L F
.20704 .56171 m .20704 .56247 L .20837 .5603 L F
.20704 .56171 m .2054 .56337 L .20704 .56247 L F
.722 .593 .712 r
.34127 .51406 m .34506 .51424 L .34371 .51356 L F
.34127 .51406 m .34205 .51711 L .34506 .51424 L F
.709 .955 .95 r
.34599 .51178 m .34371 .51356 L .34506 .51424 L F
0 .507 .817 r
.34678 .66309 m .35126 .66455 L .34888 .66158 L F
.723 .771 .89 r
.35126 .66455 m .35123 .65976 L .34888 .66158 L F
.35126 .66455 m .35681 .66261 L .35123 .65976 L F
.849 .972 .873 r
.71772 .28941 m .71404 .2916 L .71677 .29076 L F
.637 .485 .66 r
.71772 .28941 m .72006 .28819 L .72028 .28618 L F
.72 .416 .464 r
.71677 .29076 m .72006 .28819 L .71772 .28941 L F
.636 .454 .62 r
.41891 .52582 m .41633 .52353 L .41844 .52345 L F
.667 .406 .517 r
.42266 .5234 m .41891 .52582 L .41844 .52345 L F
.874 .791 .765 r
.41799 .55107 m .42146 .54977 L .418 .54891 L F
.58 .676 .906 r
.63317 .38598 m .63033 .38776 L .62957 .38551 L F
.597 .54 .761 r
.63317 .38598 m .6308 .39039 L .63033 .38776 L F
0 0 0 r
.3445 .53975 m .34503 .54049 L .34532 .5374 L F
.3445 .53975 m .3432 .54221 L .34503 .54049 L F
.903 .672 .164 r
.7323 .34315 m .73186 .34431 L .73241 .34546 L F
0 0 0 r
.73315 .34396 m .73144 .34543 L .73186 .34431 L F
.949 .957 .697 r
.73013 .34772 m .73241 .34546 L .73186 .34431 L F
0 0 0 r
.73144 .34543 m .73106 .34576 L .73186 .34431 L F
.903 .672 .164 r
.73229 .34304 m .73186 .34431 L .7323 .34315 L F
0 0 0 r
.73334 .34086 m .73186 .34431 L .73229 .34304 L F
0 .018 .555 r
.22107 .57568 m .21941 .57347 L .22098 .573 L F
.537 .456 .712 r
.36055 .52972 m .35836 .53285 L .35848 .53068 L F
.218 0 0 r
.27227 .53782 m .27621 .53555 L .27383 .53608 L F
.776 .347 .232 r
.39253 .5802 m .39473 .5826 L .39067 .58164 L F
.875 .839 .807 r
.41358 .51108 m .41164 .51443 L .41069 .51124 L F
.955 .851 .701 r
.41164 .51443 m .4091 .5156 L .41069 .51124 L F
.41164 .51443 m .41089 .51708 L .4091 .5156 L F
0 .101 .608 r
.59239 .40834 m .59326 .40944 L .59078 .40692 L F
0 .374 .809 r
.59514 .41025 m .59326 .40944 L .59239 .40834 L F
.411 .32 .642 r
.5957 .41281 m .59326 .40944 L .59514 .41025 L F
.751 .907 .526 r
.35254 .6069 m .35406 .60517 L .35403 .60506 L F
.602 .335 .485 r
.23875 .58715 m .23843 .58963 L .23552 .58964 L F
.634 .363 .491 r
.24124 .58916 m .23843 .58963 L .23875 .58715 L F
.234 .035 .393 r
.32628 .52053 m .32862 .51944 L .32865 .51694 L F
.284 .078 .414 r
.32628 .52053 m .32769 .52229 L .32862 .51944 L F
.32628 .52053 m .32584 .52347 L .32769 .52229 L F
.708 .38 .421 r
.33986 .64636 m .3363 .64288 L .33747 .64696 L F
.33986 .64636 m .34021 .6437 L .3363 .64288 L F
.719 .219 .049 r
.70177 .35528 m .7052 .35638 L .70615 .35764 L F
.511 .334 .577 r
.36854 .565 m .37158 .56686 L .37076 .56402 L F
.328 .159 .494 r
.37076 .56402 m .37367 .56336 L .37378 .56072 L F
.264 .116 .485 r
.37076 .56402 m .37324 .56589 L .37367 .56336 L F
.37076 .56402 m .37158 .56686 L .37324 .56589 L F
.373 .465 .826 r
.35571 .63813 m .35829 .64054 L .35779 .63705 L F
.626 .409 .567 r
.58844 .44138 m .58901 .44388 L .58633 .44408 L F
.609 .398 .569 r
.59262 .44321 m .58844 .44138 L .59276 .44101 L F
.59262 .44321 m .58901 .44388 L .58844 .44138 L F
.504 .646 .92 r
.31873 .63457 m .31522 .63444 L .31532 .63722 L F
.689 .457 .566 r
.36618 .56736 m .36854 .565 L .36518 .56411 L F
.36618 .56736 m .36892 .56755 L .36854 .565 L F
.511 .334 .577 r
.36854 .565 m .36892 .56755 L .37158 .56686 L F
.4 .739 .992 r
.3444 .57347 m .34573 .5717 L .34213 .57194 L F
.3444 .57347 m .34706 .57317 L .34573 .5717 L F
.723 .348 .337 r
.57966 .43379 m .58361 .43395 L .58187 .43169 L F
.662 .723 .895 r
.55853 .39466 m .55863 .39796 L .56236 .39605 L F
.115 0 .376 r
.19891 .57105 m .2003 .57022 L .20069 .56729 L F
.147 .06 .492 r
.19905 .57375 m .2003 .57022 L .19891 .57105 L F
.581 .831 .992 r
.23988 .62499 m .24391 .62531 L .24222 .62428 L F
0 .496 .85 r
.24391 .62531 m .24478 .625 L .24222 .62428 L F
.24391 .62531 m .24685 .62617 L .24478 .625 L F
.434 .705 .979 r
.31916 .57263 m .31915 .5746 L .31678 .57273 L F
.542 .553 .815 r
.31916 .57263 m .31813 .57655 L .31915 .5746 L F
.509 .275 .495 r
.27078 .56011 m .26874 .55806 L .27053 .55764 L F
.27078 .56011 m .26824 .5608 L .26874 .55806 L F
.741 .44 .472 r
.60431 .43788 m .60821 .43822 L .60835 .44045 L F
.705 .298 .273 r
.60821 .43822 m .61165 .44045 L .60835 .44045 L F
0 0 0 r
.21191 .5551 m .20959 .55844 L .21075 .55723 L F
0 0 .014 r
.20837 .5603 m .21075 .55723 L .20959 .55844 L F
.766 .851 .915 r
.5938 .4313 m .59706 .43024 L .59537 .4284 L F
.682 .826 .952 r
.59537 .4284 m .59706 .43024 L .59907 .42885 L F
.526 .639 .904 r
.59706 .43024 m .6004 .43172 L .59907 .42885 L F
.536 .424 .673 r
.33559 .59281 m .33769 .58945 L .3351 .59002 L F
.189 .707 .881 r
.20477 .59952 m .20846 .59968 L .20671 .59932 L F
.014 .579 .793 r
.20671 .59932 m .20846 .59968 L .21002 .59975 L F
.059 .485 .89 r
.27895 .53005 m .27918 .52895 L .27715 .5295 L F
.27895 .53005 m .28019 .52962 L .27918 .52895 L F
.285 .367 .772 r
.33367 .66842 m .33569 .66505 L .3332 .66701 L F
.33367 .66842 m .33555 .67061 L .33569 .66505 L F
.921 .723 .618 r
.3563 .56832 m .35768 .57134 L .36007 .56848 L F
.3563 .56832 m .3552 .57045 L .35768 .57134 L F
.205 .726 .86 r
.28694 .52043 m .28636 .52102 L .2846 .52111 L F
.28694 .52043 m .28858 .52081 L .28636 .52102 L F
.63 .421 .58 r
.33482 .54255 m .33469 .54523 L .33153 .5454 L F
.688 .47 .585 r
.33829 .54245 m .33469 .54523 L .33482 .54255 L F
.627 .865 .987 r
.26704 .52376 m .26493 .5247 L .26278 .52352 L F
.98 .69 .38 r
.39999 .54816 m .40027 .55124 L .40173 .55217 L F
.96 .623 .284 r
.40027 .55124 m .40209 .55451 L .40173 .55217 L F
.59 .831 .99 r
.40511 .50823 m .4033 .51063 L .40146 .50914 L F
.525 .738 .972 r
.40511 .50823 m .40689 .51069 L .4033 .51063 L F
.483 .501 .8 r
.40647 .5125 m .4033 .51063 L .40689 .51069 L F
.695 .579 .72 r
.2257 .57069 m .22876 .57354 L .22727 .57046 L F
.626 .315 .424 r
.60178 .43812 m .6042 .44011 L .60197 .4403 L F
.587 .33 .494 r
.60431 .43788 m .6042 .44011 L .60178 .43812 L F
.816 .791 .829 r
.6837 .34578 m .68239 .34962 L .6811 .34878 L F
.992 .828 .58 r
.68239 .34962 m .68113 .35146 L .6811 .34878 L F
.363 .555 .906 r
.25384 .61984 m .25285 .62173 L .251 .6193 L F
0 0 .438 r
.39575 .53863 m .39717 .54116 L .39731 .54223 L F
0 0 .363 r
.39803 .5433 m .39731 .54223 L .39717 .54116 L F
.286 .156 .523 r
.19739 .5772 m .19907 .57645 L .19905 .57375 L F
.26 .162 .55 r
.19739 .5772 m .19915 .57916 L .19907 .57645 L F
.19739 .5772 m .19707 .58071 L .19915 .57916 L F
.314 .126 .459 r
.33174 .59304 m .33372 .59467 L .33559 .59281 L F
.536 .424 .673 r
.33559 .59281 m .33799 .59225 L .33769 .58945 L F
.162 0 0 r
.33372 .59467 m .33799 .59225 L .33559 .59281 L F
.184 0 0 r
.33171 .665 m .33137 .66379 L .32801 .66505 L F
0 0 .352 r
.35143 .51409 m .35148 .51682 L .35226 .51457 L F
0 .184 .682 r
.31774 .66509 m .31786 .66476 L .31452 .6643 L F
.31774 .66509 m .31904 .66614 L .31786 .66476 L F
.268 .543 .923 r
.2257 .57069 m .22727 .57046 L .22305 .56871 L F
.695 .883 .5 r
.31532 .63722 m .31314 .64057 L .31509 .63984 L F
.318 .127 .457 r
.31314 .64057 m .31294 .64309 L .31509 .63984 L F
.416 .216 .499 r
.43069 .5481 m .42822 .55151 L .42801 .54873 L F
.43069 .5481 m .42822 .55151 L .42801 .54873 L F
.858 .807 .799 r
.41089 .51708 m .40692 .5176 L .4091 .5156 L F
.41089 .51708 m .40841 .51998 L .40692 .5176 L F
.663 .486 .635 r
.41089 .51708 m .41115 .51984 L .40841 .51998 L F
.658 .466 .613 r
.41415 .51714 m .41115 .51984 L .41089 .51708 L F
.952 .602 .273 r
.4076 .57848 m .40876 .57668 L .40783 .57596 L F
.4076 .57848 m .40911 .57933 L .40876 .57668 L F
.926 .942 .789 r
.61947 .38652 m .61808 .39058 L .61596 .39067 L F
.761 .744 .837 r
.61538 .3856 m .61596 .39067 L .61445 .39027 L F
.729 .721 .843 r
.61947 .38652 m .61596 .39067 L .61538 .3856 L F
.655 .791 .947 r
.61596 .39067 m .61808 .39058 L .61445 .39027 L F
.692 .671 .825 r
.6165 .39307 m .61445 .39027 L .61808 .39058 L F
.761 .889 .481 r
.2982 .65039 m .29874 .64989 L .299 .64919 L F
.941 .61 .376 r
.29708 .65135 m .29936 .65261 L .29874 .64989 L F
0 0 0 r
.29708 .65135 m .29874 .64989 L .2982 .65039 L F
.385 0 0 r
.35359 .71341 m .35576 .71316 L .35743 .71366 L F
.879 .9 .841 r
.37917 .67764 m .38329 .67543 L .38173 .67449 L F
0 .146 .675 r
.38329 .67543 m .38454 .67589 L .38173 .67449 L F
.38329 .67543 m .38569 .67757 L .38454 .67589 L F
.355 .303 .661 r
.38329 .67543 m .38385 .6791 L .38569 .67757 L F
.579 .625 .862 r
.24785 .53957 m .25209 .54254 L .25023 .53903 L F
.518 .599 .875 r
.25023 .53903 m .25209 .54254 L .25414 .54172 L F
.611 .491 .691 r
.25471 .54322 m .25209 .54254 L .25414 .54172 L F
.25558 .54555 m .25387 .54407 L .25471 .54322 L F
.25387 .54407 m .25209 .54254 L .25471 .54322 L F
.692 .602 .75 r
.2582 .54488 m .25558 .54555 L .25414 .54172 L F
.2582 .54488 m .25414 .54172 L .25668 .54106 L F
0 0 0 r
.25376 .54428 m .25538 .54287 L .25627 .54163 L F
.25486 .54306 m .25627 .54163 L .25668 .54106 L F
.25376 .54428 m .25627 .54163 L .25486 .54306 L F
.458 .346 .639 r
.25376 .54428 m .25209 .54254 L .25414 .54172 L F
.921 .55 .297 r
.29676 .62677 m .2934 .62547 L .29369 .62718 L F
.781 .739 .814 r
.29448 .63097 m .29676 .62677 L .29369 .62718 L F
.461 .164 .373 r
.33986 .64636 m .34021 .6437 L .34151 .64583 L F
0 0 0 r
.23696 .54686 m .23638 .54619 L .23869 .54581 L F
.23696 .54686 m .23515 .54791 L .23638 .54619 L F
.904 .968 .811 r
.37716 .64925 m .38076 .64658 L .37904 .64691 L F
.37716 .64925 m .37802 .65016 L .38076 .64658 L F
.411 .861 .824 r
.38135 .64588 m .38076 .64658 L .38304 .64689 L F
.38135 .64588 m .37904 .64691 L .38076 .64658 L F
.936 .804 .689 r
.70654 .32039 m .70618 .31648 L .70387 .32008 L F
.84 .71 .72 r
.70387 .32008 m .70519 .32387 L .70654 .32039 L F
.715 .82 .93 r
.33539 .50061 m .33165 .50112 L .3339 .50005 L F
.416 .749 .994 r
.33637 .49943 m .33539 .50061 L .3339 .50005 L F
.33637 .49943 m .33755 .5002 L .33539 .50061 L F
.845 .744 .752 r
.69836 .30804 m .69439 .30979 L .69711 .30648 L F
.69836 .30804 m .69617 .31136 L .69439 .30979 L F
.887 .892 .828 r
.70082 .30479 m .69836 .30804 L .69711 .30648 L F
.525 .902 .957 r
.27891 .53847 m .27506 .5392 L .27775 .5389 L F
.627 .516 .708 r
.36016 .55725 m .36303 .55765 L .36338 .5535 L F
.554 .101 .131 r
.35878 .5597 m .36303 .55765 L .36016 .55725 L F
.723 .608 .728 r
.42544 .52273 m .42266 .5234 L .42511 .52051 L F
.592 .586 .814 r
.4272 .51995 m .42544 .52273 L .42511 .52051 L F
.4272 .51995 m .42842 .52351 L .42544 .52273 L F
.502 .5 .787 r
.42924 .52603 m .42544 .52273 L .42842 .52351 L F
.753 .637 .732 r
.23659 .57939 m .23815 .58406 L .23414 .58318 L F
.602 .552 .771 r
.24056 .58324 m .23815 .58406 L .23659 .57939 L F
.681 .931 .969 r
.73482 .33037 m .7355 .32913 L .73651 .32994 L F
.504 .709 .963 r
.73799 .32785 m .73651 .32994 L .7355 .32913 L F
.73799 .32785 m .73914 .32961 L .73651 .32994 L F
.2 .193 .625 r
.30323 .54418 m .30385 .54688 L .30503 .54524 L F
.30323 .54418 m .30503 .54524 L .30629 .546 L F
.229 0 0 r
.30843 .54472 m .30629 .546 L .30503 .54524 L F
.41 .563 .896 r
.65854 .40184 m .65675 .40383 L .65598 .40303 L F
.65854 .40184 m .66049 .40466 L .65675 .40383 L F
0 0 0 r
.31922 .55097 m .3206 .55052 L .32154 .54781 L F
.078 0 .15 r
.31836 .55314 m .3206 .55052 L .31922 .55097 L F
0 0 .322 r
.70325 .3431 m .70293 .34241 L .70427 .34078 L F
.915 .926 .548 r
.7029 .34217 m .70325 .3431 L .70427 .34078 L F
0 0 .219 r
.70353 .34371 m .70325 .3431 L .7029 .34217 L F
.70385 .34448 m .70325 .3431 L .70353 .34371 L F
0 0 .322 r
.70325 .3431 m .70268 .34272 L .70293 .34241 L F
.456 .886 .841 r
.3791 .56731 m .38003 .56637 L .37777 .5674 L F
.241 0 0 r
.38001 .56648 m .37777 .5674 L .38003 .56637 L F
.785 .941 .928 r
.3753 .56836 m .37682 .56866 L .3791 .56731 L F
.241 0 0 r
.37977 .56782 m .37777 .5674 L .38001 .56648 L F
.785 .941 .928 r
.3753 .56836 m .37562 .56827 L .37777 .5674 L F
.37562 .56827 m .3791 .56731 L .37777 .5674 L F
.979 .888 .533 r
.71324 .30324 m .71451 .30221 L .71534 .29979 L F
.71324 .30324 m .7139 .30467 L .71451 .30221 L F
.928 .799 .332 r
.40787 .59379 m .4088 .5932 L .40816 .59141 L F
.40787 .59379 m .40836 .59585 L .4088 .5932 L F
0 0 0 r
.6004 .43172 m .59627 .43258 L .59896 .43192 L F
.024 .255 .756 r
.59907 .42885 m .6004 .43172 L .60084 .42962 L F
.822 .997 .771 r
.60084 .42962 m .6004 .43172 L .59896 .43192 L F
.541 .323 .532 r
.24112 .56785 m .24081 .57095 L .23807 .57112 L F
.488 .273 .513 r
.24354 .5673 m .24081 .57095 L .24112 .56785 L F
0 0 0 r
.63922 .43094 m .63674 .43193 L .63518 .43337 L F
.602 .475 .679 r
.331 .54228 m .3288 .5455 L .32999 .54507 L F
.703 .396 .455 r
.33179 .54815 m .3288 .5455 L .33153 .5454 L F
.745 .702 .163 r
.3288 .5455 m .32852 .5463 L .32999 .54507 L F
0 0 0 r
.40473 .604 m .40362 .6082 L .40396 .60569 L F
.871 .868 .832 r
.36929 .61294 m .36759 .61546 L .3655 .61478 L F
.94 .752 .62 r
.36759 .61546 m .36743 .61826 L .3655 .61478 L F
.994 .756 .452 r
.24184 .542 m .24153 .54451 L .24288 .5456 L F
0 .399 .689 r
.29253 .62344 m .28737 .62191 L .28917 .62215 L F
.56 .284 .455 r
.58633 .44408 m .58349 .44646 L .58359 .44419 L F
.568 .766 .972 r
.2776 .5233 m .27355 .52241 L .27584 .52188 L F
.541 .778 .986 r
.27836 .52138 m .2776 .5233 L .27584 .52188 L F
.372 .588 .927 r
.27981 .52328 m .2776 .5233 L .27836 .52138 L F
.674 .161 .011 r
.35078 .71137 m .35359 .71341 L .34951 .71228 L F
.334 0 0 r
.26158 .62371 m .26406 .62372 L .2661 .62235 L F
.187 0 0 r
.2661 .62235 m .26669 .62325 L .26845 .62179 L F
.2661 .62235 m .26406 .62372 L .26669 .62325 L F
.932 .756 .641 r
.36669 .57307 m .36774 .57634 L .36773 .57422 L F
.428 .44 .77 r
.29664 .61745 m .29614 .62171 L .29419 .618 L F
.29664 .61745 m .29806 .6221 L .29614 .62171 L F
.485 .278 .523 r
.29806 .6221 m .29531 .62399 L .29614 .62171 L F
.911 .509 .196 r
.61575 .44429 m .61643 .44653 L .61381 .443 L F
.217 .735 .726 r
.25862 .52472 m .25807 .52497 L .25634 .5255 L F
.25862 .52472 m .26047 .52433 L .25807 .52497 L F
.38 .737 .991 r
.32066 .53954 m .32093 .53824 L .31858 .5379 L F
.32066 .53954 m .32328 .53953 L .32093 .53824 L F
.731 .482 0 r
.4038 .56082 m .40436 .56374 L .40464 .56481 L F
.897 .537 .068 r
.40405 .56538 m .40464 .56481 L .40436 .56374 L F
.40405 .56538 m .40524 .56703 L .40464 .56481 L F
0 0 0 r
.24377 .55118 m .24538 .55067 L .24688 .54952 L F
.203 0 .069 r
.24377 .55118 m .24465 .55296 L .24538 .55067 L F
.24377 .55118 m .24247 .55372 L .24465 .55296 L F
.921 .652 .514 r
.39034 .56773 m .38803 .56786 L .39092 .56674 L F
.39034 .56773 m .38983 .57023 L .38803 .56786 L F
.887 .892 .828 r
.70082 .30479 m .69711 .30648 L .69971 .30331 L F
.83 .908 .892 r
.70388 .30179 m .70082 .30479 L .69971 .30331 L F
.509 .343 .591 r
.37274 .55682 m .37033 .55778 L .37017 .55498 L F
.731 .79 .899 r
.35858 .57974 m .36189 .58067 L .36168 .57893 L F
.321 .469 .852 r
.36168 .57893 m .36189 .58067 L .36345 .57884 L F
.014 .034 .534 r
.36189 .58067 m .36392 .58183 L .36345 .57884 L F
.36189 .58067 m .36266 .58309 L .36392 .58183 L F
.398 .783 .99 r
.43175 .57973 m .42853 .5789 L .43054 .5776 L F
.43175 .57973 m .42733 .57908 L .42853 .5789 L F
.385 .301 .637 r
.33747 .64696 m .33981 .64912 L .33986 .64636 L F
.688 .945 .666 r
.24032 .53333 m .24106 .53191 L .24167 .5317 L F
.651 .969 .886 r
.24032 .53333 m .2376 .53382 L .24106 .53191 L F
.737 .592 .693 r
.33555 .67061 m .34191 .66615 L .34023 .6656 L F
.33555 .67061 m .3409 .67176 L .34191 .66615 L F
.652 .924 .975 r
.34023 .6656 m .34191 .66615 L .34246 .66443 L F
.626 .91 .62 r
.5525 .4303 m .5541 .42908 L .55157 .43155 L F
.861 .862 .839 r
.5546 .42817 m .5541 .42908 L .55275 .42721 L F
.996 .779 .492 r
.55275 .42721 m .5541 .42908 L .5525 .4303 L F
.287 .162 .53 r
.37716 .64925 m .37688 .65186 L .37802 .65016 L F
.764 .478 .5 r
.55508 .43755 m .55904 .43799 L .55912 .44012 L F
.814 .443 .354 r
.55904 .43799 m .56306 .44104 L .55912 .44012 L F
.906 .776 .707 r
.40014 .59212 m .40247 .59351 L .40093 .59542 L F
.271 .226 .623 r
.34868 .52034 m .35106 .52188 L .35269 .52031 L F
.715 .612 .741 r
.35666 .54429 m .3572 .54737 L .35822 .54562 L F
.381 .489 .844 r
.35148 .51682 m .35269 .52031 L .35452 .51875 L F
.426 .141 .375 r
.35106 .52188 m .35452 .51875 L .35269 .52031 L F
.74 .251 0 r
.35822 .54562 m .3576 .54599 L .35666 .54429 L F
.715 .612 .741 r
.35666 .54429 m .35399 .54751 L .3572 .54737 L F
.474 0 0 r
.35399 .54751 m .35579 .54871 L .3572 .54737 L F
.704 .56 .688 r
.35746 .54628 m .35579 .54871 L .35543 .54624 L F
.364 .656 .968 r
.3572 .54737 m .3576 .546 L .35822 .54562 L F
.3576 .546 m .3576 .54599 L .35761 .54599 L F
.3572 .54737 m .35843 .5463 L .3576 .54599 L F
0 0 0 r
.3572 .54737 m .35579 .54871 L .35843 .5463 L F
.704 .56 .688 r
.35843 .5463 m .35665 .54792 L .35746 .54628 L F
.35665 .54792 m .35579 .54871 L .35746 .54628 L F
.364 .656 .968 r
.3576 .546 m .35761 .54599 L .35822 .54562 L F
.788 .721 .789 r
.31988 .50904 m .31762 .51108 L .32015 .51018 L F
.769 .53 .573 r
.39478 .55761 m .39719 .56094 L .39737 .55801 L F
.691 .263 .228 r
.39737 .55801 m .39506 .55847 L .39478 .55761 L F
.659 .211 .175 r
.39737 .55801 m .39609 .56 L .39506 .55847 L F
.997 .776 .434 r
.39719 .56094 m .39609 .56 L .39737 .55801 L F
.342 .05 .316 r
.27867 .54516 m .28013 .54731 L .28414 .54242 L F
.76 .651 .74 r
.28013 .54731 m .2836 .54499 L .28414 .54242 L F
.347 0 .2 r
.28414 .54242 m .28013 .54731 L .2836 .54499 L F
0 0 .052 r
.28414 .54242 m .28436 .54251 L .28169 .54229 L F
.597 .415 .606 r
.28169 .54229 m .28436 .54251 L .28435 .53927 L F
.324 .136 .464 r
.28435 .53927 m .28633 .53861 L .28651 .5359 L F
.395 .314 .646 r
.28435 .53927 m .28694 .54172 L .28633 .53861 L F
.475 .318 .588 r
.28435 .53927 m .28436 .54251 L .28694 .54172 L F
.832 .823 .84 r
.59122 .42424 m .59271 .42622 L .58908 .42949 L F
.113 .66 .824 r
.59396 .42592 m .59271 .42622 L .59122 .42424 L F
.59396 .42592 m .59516 .42617 L .59271 .42622 L F
.368 .508 .867 r
.2334 .56101 m .23493 .56049 L .23159 .55865 L F
.255 0 0 r
.26034 .6315 m .2563 .63032 L .25846 .63158 L F
.342 .05 .316 r
.27867 .54516 m .27809 .54801 L .28013 .54731 L F
.698 .655 .804 r
.40969 .52573 m .40571 .5233 L .40772 .5227 L F
.448 .233 .494 r
.35162 .56131 m .35139 .56449 L .34906 .56505 L F
.512 .286 .508 r
.354 .56372 m .35162 .56131 L .35353 .5609 L F
.354 .56372 m .35139 .56449 L .35162 .56131 L F
.288 .788 .838 r
.37039 .56967 m .37682 .56866 L .3753 .56836 L F
0 .39 .841 r
.2676 .63745 m .26933 .63839 L .26675 .63581 L F
0 .405 .805 r
.25998 .62259 m .25935 .62291 L .25929 .62258 L F
.25998 .62259 m .26158 .62371 L .25935 .62291 L F
0 .221 .661 r
.58565 .4333 m .58872 .43524 L .5877 .43443 L F
.58565 .4333 m .5877 .43443 L .58662 .43391 L F
.235 0 .084 r
.58492 .43285 m .58361 .43395 L .58565 .4333 L F
.421 .775 .996 r
.58565 .4333 m .58361 .43395 L .58365 .43247 L F
.58565 .4333 m .58361 .43395 L .58365 .43247 L F
.12 0 .046 r
.58565 .4333 m .58361 .43395 L .58351 .43569 L F
.835 .652 .655 r
.58351 .43569 m .58664 .43592 L .58615 .43462 L F
.58446 .43463 m .58615 .43462 L .58565 .4333 L F
.58351 .43569 m .58615 .43462 L .58446 .43463 L F
.365 0 0 r
.58231 .43463 m .58361 .43395 L .57966 .43379 L F
0 0 .016 r
.58351 .43569 m .58361 .43395 L .58443 .4353 L F
.365 0 0 r
.58443 .4353 m .58402 .43463 L .58231 .43463 L F
.58402 .43463 m .58361 .43395 L .58231 .43463 L F
.4 .419 .764 r
.58565 .4333 m .58664 .43592 L .58872 .43524 L F
0 .221 .661 r
.58565 .4333 m .58662 .43391 L .58365 .43247 L F
.235 0 .084 r
.58823 .4301 m .58492 .43285 L .58565 .4333 L F
.564 .036 0 r
.58767 .43244 m .58823 .4301 L .58565 .4333 L F
.58863 .43203 m .5886 .43191 L .58767 .43244 L F
.5886 .43191 m .58823 .4301 L .58767 .43244 L F
.58923 .43157 m .58823 .4301 L .58863 .43203 L F
.58922 .43156 m .58997 .43173 L .58823 .4301 L F
.5894 .43173 m .58997 .43173 L .58922 .43156 L F
.579 .369 .56 r
.58931 .43151 m .59031 .43219 L .58988 .4322 L F
.58923 .43157 m .58988 .4322 L .58831 .43227 L F
.564 .036 0 r
.58923 .43157 m .5894 .43173 L .58922 .43156 L F
.58939 .43173 m .5894 .43173 L .58923 .43157 L F
.737 .676 .792 r
.58997 .43173 m .5938 .4313 L .59242 .42922 L F
.238 0 0 r
.5935 .43225 m .5938 .4313 L .58997 .43173 L F
.623 .895 .583 r
.59105 .43183 m .59103 .43194 L .59265 .42993 L F
.48 .456 .754 r
.59265 .42993 m .59097 .43201 L .59095 .43194 L F
.582 .718 .936 r
.58908 .42949 m .59242 .42922 L .59116 .42687 L F
.737 .676 .792 r
.58997 .43173 m .59242 .42922 L .58908 .42949 L F
.48 .456 .754 r
.59265 .42993 m .59095 .43194 L .59001 .42902 L F
.623 .895 .583 r
.59108 .43165 m .59105 .43183 L .59265 .42993 L F
.59103 .43194 m .59099 .43215 L .59115 .43194 L F
.59103 .43194 m .59115 .43194 L .59265 .42993 L F
.113 0 0 r
.59103 .43194 m .58997 .43173 L .5894 .43173 L F
.832 .656 .664 r
.5902 .431 m .59028 .43185 L .58931 .43151 L F
.113 0 0 r
.5899 .4318 m .58974 .4318 L .59099 .43215 L F
.58974 .4318 m .58963 .4318 L .58965 .43181 L F
.58974 .4318 m .58965 .43181 L .59099 .43215 L F
.59103 .43194 m .5899 .4318 L .59099 .43215 L F
0 .549 .78 r
.5909 .432 m .59099 .43215 L .58934 .43173 L F
.113 0 0 r
.59143 .43194 m .58997 .43173 L .59103 .43194 L F
.623 .895 .583 r
.59085 .43191 m .59099 .43215 L .59108 .43165 L F
0 .549 .78 r
.59097 .43201 m .59099 .43215 L .5909 .432 L F
.623 .895 .583 r
.58938 .43351 m .59099 .43215 L .59085 .43191 L F
0 .549 .78 r
.59097 .43201 m .59015 .43187 L .59031 .43219 L F
.832 .656 .664 r
.59014 .43184 m .59031 .43219 L .58974 .4318 L F
0 .549 .78 r
.59015 .43187 m .58934 .43173 L .59031 .43219 L F
.832 .656 .664 r
.59028 .43185 m .59031 .43219 L .59014 .43184 L F
.58987 .4318 m .58974 .4318 L .5897 .43177 L F
.59028 .43185 m .58974 .4318 L .58987 .4318 L F
.113 0 0 r
.59103 .43194 m .5894 .43173 L .58987 .4318 L F
.832 .656 .664 r
.59028 .43185 m .5897 .43177 L .58931 .43151 L F
.113 0 0 r
.58987 .4318 m .5894 .43173 L .58934 .43173 L F
.5935 .43225 m .59143 .43194 L .59103 .43194 L F
.59107 .43195 m .59103 .43194 L .59099 .43215 L F
.605 .867 .527 r
.59112 .43182 m .59099 .43215 L .59097 .43201 L F
.59265 .42993 m .59099 .43215 L .59112 .43182 L F
.113 0 0 r
.5935 .43225 m .59107 .43195 L .59099 .43215 L F
.5899 .4318 m .58934 .43173 L .58963 .4318 L F
.579 .369 .56 r
.58931 .43151 m .58956 .4318 L .58923 .43157 L F
.58956 .4318 m .58988 .4322 L .58947 .43181 L F
.58956 .4318 m .58947 .43181 L .58923 .43157 L F
.564 .036 0 r
.58934 .43173 m .58939 .43173 L .58923 .43157 L F
.832 .656 .664 r
.59001 .42902 m .5902 .431 L .58813 .43052 L F
.5879 .4303 m .58813 .43052 L .5877 .43042 L F
.59001 .42902 m .58813 .43052 L .5879 .4303 L F
.5902 .431 m .58931 .43151 L .5877 .43042 L F
.579 .369 .56 r
.5877 .43042 m .58931 .43151 L .58365 .43247 L F
.58931 .43151 m .58863 .43203 L .58365 .43247 L F
.564 .036 0 r
.58934 .43173 m .58923 .43157 L .58863 .43203 L F
.47 .795 .999 r
.58934 .43173 m .58863 .43203 L .58365 .43247 L F
.58863 .43203 m .58565 .4333 L .58365 .43247 L F
.579 .369 .56 r
.58863 .43203 m .58831 .43227 L .58365 .43247 L F
.675 .255 .238 r
.42213 .58818 m .42187 .58666 L .42376 .58621 L F
.668 .248 .238 r
.42628 .58687 m .42213 .58818 L .42376 .58621 L F
.636 .454 .62 r
.41891 .52582 m .41622 .52628 L .41633 .52353 L F
.65 .477 .636 r
.32017 .50695 m .31762 .51108 L .31988 .50904 L F
.521 .36 .603 r
.32017 .50695 m .31988 .50904 L .32271 .50676 L F
.537 .456 .712 r
.36055 .52972 m .36153 .53259 L .35836 .53285 L F
.546 .486 .739 r
.35937 .53608 m .36133 .53274 L .35836 .53285 L F
.418 .378 .707 r
.36055 .52972 m .36152 .53252 L .36154 .53251 L F
.36212 .53074 m .36154 .53251 L .36351 .53165 L F
.36055 .52972 m .36154 .53251 L .36212 .53074 L F
0 0 .405 r
.36137 .53044 m .36153 .53254 L .36055 .52972 L F
.36153 .53254 m .36153 .53259 L .36055 .52972 L F
.418 .378 .707 r
.36055 .52972 m .3613 .53261 L .36152 .53252 L F
.3613 .53261 m .36133 .53274 L .36155 .53263 L F
.36147 .53261 m .36155 .53263 L .3616 .53261 L F
.3613 .53261 m .36155 .53263 L .36147 .53261 L F
.439 0 0 r
.35871 .53346 m .35938 .53459 L .35702 .53397 L F
.36147 .53261 m .35942 .53455 L .35871 .53346 L F
.35942 .53455 m .35938 .53459 L .35871 .53346 L F
.3615 .53262 m .35936 .53461 L .36147 .53261 L F
.546 .486 .739 r
.35937 .53608 m .36179 .53548 L .36133 .53274 L F
.622 .056 0 r
.36076 .53528 m .3608 .5354 L .35954 .53493 L F
.35938 .53459 m .35954 .53493 L .35702 .53397 L F
.35945 .53461 m .35954 .53493 L .35938 .53459 L F
.439 0 0 r
.36153 .53259 m .3615 .53262 L .36147 .53261 L F
.36127 .53261 m .35702 .53397 L .35836 .53285 L F
.36153 .53259 m .36147 .53261 L .36127 .53261 L F
.36147 .53261 m .35702 .53397 L .36127 .53261 L F
.909 .947 .595 r
.36137 .53044 m .35933 .53449 L .3615 .53262 L F
.439 0 0 r
.35936 .53461 m .35919 .53477 L .35936 .53461 L F
.35938 .53459 m .35919 .53477 L .35702 .53397 L F
.909 .947 .595 r
.35937 .53457 m .35919 .53477 L .35938 .53459 L F
.439 0 0 r
.35936 .53461 m .35936 .53461 L .36147 .53261 L F
.909 .947 .595 r
.35933 .53449 m .35938 .53459 L .3615 .53262 L F
.622 .056 0 r
.35937 .53457 m .35945 .53461 L .35932 .53458 L F
.196 .37 .81 r
.35702 .53397 m .35692 .53021 L .35502 .53232 L F
.622 .056 0 r
.35804 .53413 m .35839 .53433 L .35702 .53397 L F
.196 .37 .81 r
.35702 .53397 m .35919 .53477 L .35894 .53426 L F
.35702 .53397 m .35871 .53423 L .35699 .53294 L F
.852 .708 .702 r
.35692 .53021 m .35905 .53448 L .36137 .53044 L F
.35905 .53448 m .35919 .53477 L .35928 .53459 L F
.622 .056 0 r
.35871 .53423 m .35921 .5346 L .35937 .53457 L F
.852 .708 .702 r
.35905 .53448 m .35928 .53459 L .36137 .53044 L F
.622 .056 0 r
.35868 .53431 m .35893 .53466 L .35921 .5346 L F
.35502 .53232 m .35733 .5337 L .35868 .53431 L F
.35733 .5337 m .35893 .53466 L .35868 .53431 L F
.35502 .53232 m .35921 .5346 L .35871 .53423 L F
.196 .37 .81 r
.35699 .53294 m .35894 .53426 L .35692 .53021 L F
.35871 .53423 m .35894 .53426 L .35699 .53294 L F
.622 .056 0 r
.35502 .53232 m .35804 .53413 L .35702 .53397 L F
.909 .947 .595 r
.35933 .53449 m .35928 .53459 L .35937 .53457 L F
.35928 .53459 m .35919 .53477 L .35937 .53457 L F
.622 .056 0 r
.35945 .53461 m .36076 .53528 L .35954 .53493 L F
.35937 .53457 m .35983 .53519 L .35945 .53461 L F
.35893 .53466 m .35983 .53519 L .35937 .53457 L F
.059 0 0 r
.35937 .53608 m .36003 .53699 L .36179 .53548 L F
.851 .964 .634 r
.36103 .53613 m .36003 .53699 L .36082 .53549 L F
.852 .961 .625 r
.36179 .53548 m .36351 .53165 L .36133 .53274 L F
.851 .964 .634 r
.36103 .53613 m .36082 .53549 L .36183 .53358 L F
.316 .111 .435 r
.35513 .53719 m .35772 .53777 L .35937 .53608 L F
.059 0 0 r
.35937 .53608 m .35772 .53777 L .36003 .53699 L F
.851 .964 .634 r
.36179 .53548 m .36103 .53613 L .36134 .53514 L F
.3618 .53503 m .36134 .53514 L .36183 .53358 L F
.454 .354 .651 r
.36183 .53358 m .36003 .53699 L .36153 .53568 L F
.549 .53 .787 r
.36003 .53699 m .35702 .53397 L .36153 .53568 L F
.622 .056 0 r
.35502 .53232 m .35763 .53456 L .35983 .53519 L F
.914 .756 .672 r
.36036 .53474 m .36079 .5346 L .36072 .53244 L F
.622 .056 0 r
.35945 .53461 m .35983 .53519 L .36027 .53532 L F
.35945 .53461 m .36027 .53532 L .36036 .53532 L F
.35945 .53461 m .36042 .53536 L .36076 .53528 L F
.687 .925 .97 r
.36033 .53496 m .35763 .53456 L .36072 .53244 L F
.36027 .53532 m .35842 .53479 L .36033 .53496 L F
.35842 .53479 m .35763 .53456 L .36033 .53496 L F
.914 .756 .672 r
.36033 .53496 m .36053 .53497 L .36079 .5346 L F
.35985 .53532 m .36033 .53496 L .35854 .53534 L F
.36033 .53496 m .36079 .5346 L .36036 .53474 L F
.36033 .53496 m .36036 .53474 L .35854 .53534 L F
.622 .056 0 r
.36036 .53532 m .36027 .53532 L .36042 .53536 L F
.36076 .53528 m .36153 .53568 L .3608 .5354 L F
.36076 .53528 m .36042 .53536 L .36153 .53568 L F
.852 .961 .625 r
.36179 .53548 m .36183 .53358 L .3633 .53212 L F
.454 .354 .651 r
.36183 .53358 m .36153 .53568 L .36079 .5346 L F
.133 0 0 r
.36447 .53298 m .3608 .5346 L .36183 .53358 L F
.3608 .5346 m .36079 .5346 L .36183 .53358 L F
.852 .961 .625 r
.3633 .53212 m .36183 .53358 L .36351 .53165 L F
.133 0 0 r
.36447 .53298 m .36395 .53347 L .36079 .5346 L F
.851 .964 .634 r
.36179 .53548 m .36134 .53514 L .3618 .53503 L F
0 0 0 r
.36216 .53424 m .36279 .5347 L .36351 .53389 L F
.36178 .53434 m .36149 .53617 L .36279 .5347 L F
.998 .832 .548 r
.36351 .53389 m .36149 .53617 L .36158 .5358 L F
0 0 0 r
.36178 .53434 m .36279 .5347 L .36216 .53424 L F
.133 0 0 r
.36393 .53348 m .36351 .53389 L .36178 .53434 L F
.36395 .53347 m .36178 .53434 L .36079 .5346 L F
.998 .832 .548 r
.36351 .53389 m .36158 .5358 L .3621 .53357 L F
0 0 0 r
.36351 .53165 m .36183 .53358 L .3661 .53064 L F
.718 .587 .708 r
.36562 .53114 m .36745 .53257 L .36684 .52989 L F
0 0 0 r
.36625 .5305 m .3661 .53064 L .36642 .53042 L F
.36351 .53165 m .3661 .53064 L .36625 .5305 L F
.718 .587 .708 r
.36684 .52989 m .36745 .53257 L .36756 .52998 L F
.418 .378 .707 r
.36055 .52972 m .36351 .53165 L .36263 .52931 L F
.311 .276 .657 r
.36351 .53165 m .36625 .5305 L .36263 .52931 L F
.627 .515 .707 r
.3661 .53064 m .36183 .53358 L .36594 .53042 L F
.718 .587 .708 r
.36502 .53068 m .36562 .53114 L .3661 .53064 L F
.311 .276 .657 r
.36625 .5305 m .36619 .53036 L .36263 .52931 L F
.718 .587 .708 r
.36594 .53042 m .3661 .53064 L .36646 .53028 L F
.909 .947 .595 r
.36153 .53254 m .3615 .53262 L .36153 .53259 L F
.418 .378 .707 r
.3613 .53261 m .3616 .53261 L .36351 .53165 L F
.627 .515 .707 r
.36594 .53042 m .36183 .53358 L .36137 .53044 L F
.718 .587 .708 r
.36502 .53068 m .3661 .53064 L .36594 .53042 L F
.311 .276 .657 r
.36625 .5305 m .36642 .53042 L .36619 .53036 L F
.627 .515 .707 r
.36642 .53042 m .3661 .53064 L .36594 .53042 L F
.382 0 0 r
.36263 .52931 m .36619 .53036 L .36137 .53044 L F
.36619 .53036 m .36594 .53042 L .36137 .53044 L F
.718 .587 .708 r
.36346 .52947 m .36502 .53068 L .36613 .5302 L F
.36598 .52978 m .36613 .5302 L .36684 .52989 L F
.36346 .52947 m .36613 .5302 L .36598 .52978 L F
.382 0 0 r
.36619 .53036 m .36642 .53042 L .36594 .53042 L F
.718 .587 .708 r
.36502 .53068 m .36646 .53028 L .36684 .52989 L F
.518 .466 .737 r
.36183 .53358 m .36346 .52947 L .36137 .53044 L F
.36183 .53358 m .36447 .53298 L .36346 .52947 L F
.554 .711 .945 r
.36351 .53389 m .36497 .53597 L .36245 .53638 L F
.36351 .53389 m .36497 .53597 L .36245 .53638 L F
.133 0 0 r
.36395 .53347 m .36351 .53389 L .36393 .53348 L F
.72 .607 .73 r
.36447 .53298 m .36497 .53597 L .36745 .53257 L F
.718 .587 .708 r
.36346 .52947 m .36447 .53298 L .36745 .53257 L F
.749 .724 .828 r
.36416 .53073 m .36547 .53427 L .3621 .53357 L F
0 0 .423 r
.3621 .53357 m .36289 .52971 L .36416 .53073 L F
.909 .947 .595 r
.36137 .53044 m .3615 .53262 L .36153 .53254 L F
.852 .708 .702 r
.35692 .53021 m .36137 .53044 L .35941 .5291 L F
.757 .525 .582 r
.36378 .52909 m .36055 .52972 L .36053 .52654 L F
0 0 .405 r
.36137 .53044 m .36055 .52972 L .36263 .52931 L F
.56 .835 .997 r
.36346 .52947 m .35941 .5291 L .36137 .53044 L F
0 0 .423 r
.3621 .53357 m .36018 .52997 L .36289 .52971 L F
0 .035 .584 r
.3621 .53357 m .3638 .53543 L .36175 .53251 L F
.3638 .53543 m .36401 .53566 L .36389 .5355 L F
.3638 .53543 m .36389 .5355 L .36175 .53251 L F
.687 .925 .97 r
.36133 .5349 m .36125 .53456 L .36095 .53484 L F
.36125 .53456 m .36072 .53244 L .36093 .53459 L F
.36125 .53456 m .36093 .53459 L .36095 .53484 L F
0 0 0 r
.36079 .5346 m .36085 .53473 L .36125 .53456 L F
.36079 .5346 m .36125 .53456 L .36178 .53434 L F
.687 .925 .97 r
.36153 .53568 m .36133 .5349 L .36095 .53484 L F
.36153 .53568 m .36048 .53501 L .36125 .53456 L F
.36048 .53501 m .36036 .53494 L .36085 .53473 L F
.36048 .53501 m .36085 .53473 L .36125 .53456 L F
.36153 .53568 m .36027 .53532 L .36033 .53492 L F
.549 .53 .787 r
.36003 .53699 m .35772 .53777 L .35702 .53397 L F
.457 .274 .544 r
.35772 .53777 m .36003 .53966 L .36003 .53699 L F
.35772 .53777 m .36003 .53966 L .36003 .53699 L F
0 0 0 r
.36085 .53473 m .35805 .53854 L .36149 .53617 L F
.36079 .5346 m .36053 .53497 L .36085 .53473 L F
.36053 .53497 m .35805 .53854 L .36085 .53473 L F
.36085 .53473 m .36149 .53617 L .36178 .53434 L F
.687 .925 .97 r
.36125 .53456 m .36033 .53492 L .36125 .53456 L F
.36036 .53494 m .36033 .53492 L .36125 .53456 L F
.36086 .53471 m .36072 .53244 L .36079 .5346 L F
.36095 .53484 m .36072 .53244 L .36086 .53471 L F
.36125 .53456 m .36033 .53492 L .36072 .53244 L F
.316 .111 .435 r
.35513 .53719 m .35576 .53884 L .35772 .53777 L F
.445 .175 .408 r
.3531 .53935 m .35576 .53884 L .35513 .53719 L F
.534 .921 .908 r
.35576 .53884 m .35395 .53886 L .35772 .53777 L F
.35395 .53886 m .35355 .53886 L .35447 .53862 L F
.35395 .53886 m .35447 .53862 L .35772 .53777 L F
.32 0 .216 r
.35415 .53805 m .35392 .53887 L .35179 .53905 L F
.35392 .53887 m .35372 .53965 L .35293 .53932 L F
.182 .147 .581 r
.35308 .53938 m .35372 .53965 L .35355 .53886 L F
.35186 .54076 m .35372 .53965 L .35308 .53938 L F
.32 0 .216 r
.35293 .53932 m .35372 .53965 L .35282 .53937 L F
.35392 .53887 m .35282 .53937 L .35179 .53905 L F
.719 .482 .566 r
.35772 .53777 m .35457 .53512 L .35702 .53397 L F
.35772 .53777 m .35415 .53805 L .35457 .53512 L F
.529 .058 .08 r
.35772 .53777 m .35355 .53886 L .35415 .53805 L F
.914 .756 .672 r
.35677 .53769 m .35805 .53854 L .36053 .53497 L F
.35677 .53769 m .36053 .53497 L .36033 .53496 L F
.35854 .53534 m .36036 .53474 L .36072 .53244 L F
.35677 .53769 m .35985 .53532 L .35854 .53534 L F
.946 .707 .546 r
.38279 .64385 m .38585 .64063 L .38531 .64316 L F
0 0 0 r
.38825 .63748 m .38678 .63979 L .38585 .64063 L F
.38678 .63979 m .38531 .64316 L .38585 .64063 L F
.648 .415 .552 r
.68627 .35568 m .68667 .35806 L .68242 .35846 L F
.707 .476 .572 r
.68871 .35556 m .68667 .35806 L .68627 .35568 L F
.667 .406 .517 r
.42266 .5234 m .42264 .52607 L .41891 .52582 L F
.755 .381 0 r
.39402 .53506 m .39575 .53863 L .39498 .53674 L F
.525 .249 .438 r
.42876 .53616 m .42542 .53916 L .42602 .53831 L F
.42876 .53616 m .4286 .53882 L .42542 .53916 L F
.305 .099 .427 r
.43105 .5329 m .43064 .53556 L .42876 .53616 L F
.175 0 .354 r
.43068 .53678 m .42876 .53616 L .43064 .53556 L F
.43068 .53678 m .4286 .53882 L .42876 .53616 L F
.899 .728 .661 r
.5657 .41295 m .56497 .40891 L .56267 .41186 L F
.785 .505 .513 r
.56246 .41484 m .5657 .41295 L .56267 .41186 L F
.56246 .41484 m .56648 .41513 L .5657 .41295 L F
.804 .73 .782 r
.29833 .5296 m .29578 .53243 L .29918 .53127 L F
.657 .337 .42 r
.29578 .53243 m .29793 .53472 L .29918 .53127 L F
.332 .022 .281 r
.29918 .53127 m .30017 .53401 L .30153 .53168 L F
.29918 .53127 m .29793 .53472 L .30017 .53401 L F
.634 .187 .172 r
.42706 .56106 m .43 .56099 L .42682 .56057 L F
.447 .425 .741 r
.31156 .64802 m .31419 .64837 L .31393 .64545 L F
.749 .69 .795 r
.39829 .58308 m .3964 .5862 L .39473 .5826 L F
.435 .836 .977 r
.35047 .68442 m .35474 .68435 L .35233 .68484 L F
.35047 .68442 m .35474 .68435 L .35233 .68484 L F
.64 .816 .968 r
.41442 .50859 m .41691 .51083 L .41358 .51108 L F
.402 .469 .814 r
.41639 .51382 m .41358 .51108 L .41691 .51083 L F
.613 .806 .974 r
.41888 .50962 m .41691 .51083 L .41442 .50859 L F
.627 .526 .72 r
.41888 .50962 m .41639 .51382 L .41691 .51083 L F
0 0 0 r
.73482 .33037 m .73398 .3337 L .73497 .33076 L F
.851 .987 .854 r
.73497 .33076 m .73398 .3337 L .73326 .33287 L F
.114 .666 .747 r
.38276 .65216 m .38138 .6524 L .37706 .65274 L F
0 0 .052 r
.28414 .54242 m .2836 .54499 L .28436 .54251 L F
.896 .736 .676 r
.70166 .32559 m .70537 .32639 L .70519 .32387 L F
.896 .737 .677 r
.70166 .32559 m .7029 .32892 L .70537 .32639 L F
.837 .992 .738 r
.73856 .33398 m .73625 .33697 L .73771 .3366 L F
.521 .447 .714 r
.31424 .55785 m .31503 .55643 L .31392 .55527 L F
.868 .646 .115 r
.40856 .58498 m .40889 .58359 L .40831 .58212 L F
.40856 .58498 m .40902 .58616 L .40889 .58359 L F
.699 .922 .592 r
.36034 .67549 m .3587 .67691 L .36095 .67407 L F
.858 .775 .769 r
.40018 .51396 m .39672 .51396 L .39876 .51241 L F
.40018 .51396 m .39794 .51709 L .39672 .51396 L F
.514 0 0 r
.20207 .59867 m .20309 .59977 L .20196 .59921 L F
.96 .705 .506 r
.20477 .59952 m .20426 .60172 L .20266 .5997 L F
.189 .707 .881 r
.20477 .59952 m .20671 .59932 L .20426 .60172 L F
.779 .75 .826 r
.20266 .5997 m .20426 .60172 L .20589 .60013 L F
.96 .705 .506 r
.20314 .59976 m .20266 .5997 L .20309 .59977 L F
.20477 .59952 m .20266 .5997 L .20314 .59976 L F
.514 0 0 r
.20207 .59867 m .20477 .59952 L .20331 .59974 L F
.20304 .59972 m .20331 .59974 L .20314 .59976 L F
.20304 .59972 m .20314 .59976 L .20307 .59975 L F
.779 .75 .826 r
.20302 .59974 m .20589 .60013 L .20299 .59967 L F
.20302 .59975 m .20314 .59976 L .20302 .59974 L F
.20314 .59976 m .20589 .60013 L .20302 .59974 L F
.514 0 0 r
.20307 .59975 m .20314 .59976 L .20309 .59977 L F
.20207 .59867 m .20331 .59974 L .20304 .59972 L F
.352 .502 .869 r
.20196 .59921 m .20295 .5997 L .20127 .59647 L F
.20295 .5997 m .20302 .59974 L .20299 .59967 L F
.20295 .5997 m .20299 .59967 L .20127 .59647 L F
.779 .75 .826 r
.2032 .59951 m .20671 .59932 L .20466 .59898 L F
.352 .502 .869 r
.20302 .59974 m .20309 .59977 L .20285 .59933 L F
.20299 .59967 m .20285 .59933 L .20127 .59647 L F
.20302 .59974 m .20299 .59967 L .20299 .59967 L F
.20299 .59967 m .20285 .59933 L .20299 .59967 L F
.741 .7 .812 r
.20302 .59965 m .20266 .5997 L .20127 .59647 L F
.779 .75 .826 r
.20275 .59969 m .20299 .59967 L .20278 .59968 L F
.20275 .59969 m .20278 .59968 L .20273 .59969 L F
.20299 .59967 m .203 .59966 L .2027 .59969 L F
.20266 .5997 m .20302 .59975 L .20299 .59967 L F
.741 .7 .812 r
.20309 .59977 m .20266 .5997 L .20302 .59965 L F
.779 .75 .826 r
.20273 .59969 m .20278 .59968 L .2027 .59969 L F
.20299 .59967 m .20671 .59932 L .203 .59966 L F
.2027 .59969 m .203 .59966 L .2032 .59951 L F
.203 .59966 m .20671 .59932 L .2032 .59951 L F
.20266 .5997 m .20275 .59969 L .2027 .59969 L F
.20299 .59967 m .20589 .60013 L .20671 .59932 L F
.487 .21 .419 r
.3063 .60899 m .30548 .61136 L .30315 .61169 L F
.68 .743 .241 r
.30594 .60994 m .3063 .60899 L .30746 .60777 L F
.30594 .60994 m .30548 .61136 L .3063 .60899 L F
.72 .418 .467 r
.36146 .63981 m .35779 .63705 L .35829 .64054 L F
0 0 0 r
.21459 .55212 m .21191 .5551 L .21316 .55384 L F
.21738 .54908 m .21459 .55212 L .2161 .55062 L F
.21316 .55384 m .2161 .55062 L .21459 .55212 L F
.515 .421 .687 r
.36937 .56281 m .36518 .56411 L .3649 .5614 L F
.548 .071 .075 r
.36776 .56182 m .36937 .56281 L .3649 .5614 L F
.083 0 .285 r
.21075 .55723 m .21316 .55384 L .21191 .5551 L F
.319 .285 .663 r
.21898 .5792 m .21791 .58239 L .2173 .58037 L F
.333 .413 .794 r
.32131 .57879 m .31948 .58042 L .31813 .57655 L F
.278 .208 .596 r
.32131 .57879 m .31944 .5831 L .31948 .58042 L F
.483 .482 .78 r
.42625 .51606 m .42511 .52051 L .42427 .51667 L F
.42625 .51606 m .4272 .51995 L .42511 .52051 L F
.473 .121 .287 r
.31352 .54144 m .30977 .54431 L .31106 .54191 L F
.707 .476 .572 r
.68871 .35556 m .68888 .35858 L .68667 .35806 L F
.672 .469 .602 r
.69308 .35556 m .68888 .35858 L .68871 .35556 L F
0 0 .403 r
.40386 .53343 m .40465 .53537 L .40368 .53173 L F
.875 .839 .807 r
.41358 .51108 m .40953 .5105 L .41186 .5098 L F
.41358 .51108 m .41069 .51124 L .40953 .5105 L F
.64 .816 .968 r
.41442 .50859 m .41358 .51108 L .41186 .5098 L F
.719 .417 0 r
.37812 .53314 m .37895 .53588 L .37758 .53155 L F
.427 .598 .916 r
.37758 .53155 m .37812 .53314 L .37968 .53147 L F
.37968 .53147 m .37812 .53314 L .37758 .53155 L F
.719 .417 0 r
.37812 .53314 m .37895 .53588 L .37758 .53155 L F
.749 .896 .944 r
.72501 .33955 m .7222 .34143 L .72117 .34017 L F
.041 0 .292 r
.31251 .56091 m .3137 .56047 L .31424 .55785 L F
0 0 .531 r
.31251 .56091 m .31396 .56309 L .3137 .56047 L F
.366 .836 .856 r
.38563 .66698 m .39007 .66581 L .39103 .66592 L F
.936 .963 .674 r
.39103 .66592 m .3915 .663 L .39338 .66529 L F
.39103 .66592 m .39007 .66581 L .3915 .663 L F
.832 .823 .84 r
.59122 .42424 m .58908 .42949 L .59116 .42687 L F
0 0 0 r
.33965 .56461 m .34073 .56373 L .34276 .56194 L F
.058 0 .307 r
.33965 .56461 m .34047 .56599 L .34073 .56373 L F
.33965 .56461 m .33912 .56723 L .34047 .56599 L F
.367 .152 .449 r
.62829 .3936 m .6308 .39039 L .63101 .39304 L F
0 0 .003 r
.2161 .55062 m .21887 .54771 L .21738 .54908 L F
.25 .177 .575 r
.30186 .58979 m .3037 .59192 L .30409 .58922 L F
.30186 .58979 m .30227 .5922 L .3037 .59192 L F
.458 .457 .769 r
.35662 .59168 m .35604 .5966 L .35493 .59315 L F
.35662 .59168 m .35876 .59884 L .35604 .5966 L F
.129 .234 .705 r
.3586 .59338 m .35876 .59884 L .35727 .59386 L F
.3586 .59338 m .35727 .59386 L .35662 .59168 L F
0 0 .173 r
.3588 .59866 m .35876 .59884 L .3586 .59338 L F
.3588 .59866 m .3586 .59338 L .35968 .59657 L F
.52 .404 .661 r
.36385 .59238 m .35968 .59657 L .3586 .59338 L F
.598 .685 .903 r
.36137 .5903 m .36385 .59238 L .35969 .59163 L F
.775 .699 .78 r
.36137 .5903 m .36385 .59238 L .3586 .59338 L F
0 0 .096 r
.3603 .59277 m .3586 .59338 L .35804 .59605 L F
.36035 .59269 m .3586 .59338 L .3603 .59277 L F
0 .287 .783 r
.35604 .5966 m .35876 .59884 L .3588 .59866 L F
.35604 .5966 m .3588 .59866 L .35684 .59933 L F
.72 .416 .464 r
.71677 .29076 m .72071 .29118 L .72006 .28819 L F
.724 .639 .762 r
.42924 .52603 m .43049 .52986 L .42648 .52946 L F
.534 .523 .79 r
.43168 .52543 m .43049 .52986 L .42924 .52603 L F
.43168 .52543 m .43275 .52934 L .43049 .52986 L F
.526 .431 .69 r
.43382 .53193 m .43049 .52986 L .43275 .52934 L F
.43382 .53193 m .43105 .5329 L .43049 .52986 L F
.622 .953 .791 r
.38782 .66128 m .39011 .6604 L .38785 .65867 L F
.478 .402 .692 r
.39011 .6604 m .39203 .65887 L .38785 .65867 L F
0 0 0 r
.28837 .64035 m .28751 .64172 L .28681 .64336 L F
.604 .317 .455 r
.59276 .44101 m .59539 .44302 L .59262 .44321 L F
.669 .258 .258 r
.59519 .44149 m .59539 .44302 L .59276 .44101 L F
.699 .348 0 r
.40524 .56703 m .40617 .56942 L .40685 .57076 L F
.872 .55 .037 r
.40645 .57183 m .40685 .57076 L .40617 .56942 L F
.40645 .57183 m .40748 .57329 L .40685 .57076 L F
0 .276 .733 r
.36344 .50588 m .36345 .5064 L .36107 .50456 L F
.36344 .50588 m .36481 .50717 L .36345 .5064 L F
.357 .32 .68 r
.25238 .55153 m .25313 .55419 L .25071 .55186 L F
.411 .326 .65 r
.25071 .55186 m .25313 .55419 L .25121 .55496 L F
.254 0 0 r
.2183 .59258 m .22119 .59174 L .22014 .59307 L F
.62 .148 0 r
.60018 .39869 m .60081 .39923 L .60267 .40173 L F
0 0 .517 r
.60081 .39923 m .60384 .40309 L .60267 .40173 L F
.493 .262 .492 r
.29411 .63332 m .29655 .63289 L .29448 .63097 L F
.775 .571 .622 r
.32407 .63088 m .32426 .63367 L .32024 .63348 L F
.302 .693 .977 r
.3252 .63015 m .32407 .63088 L .32268 .62988 L F
.631 .461 .634 r
.32407 .63088 m .32689 .63069 L .32426 .63367 L F
.357 .794 .963 r
.3252 .63015 m .32689 .63069 L .32407 .63088 L F
.673 .247 .227 r
.32415 .54762 m .32831 .5481 L .32583 .54871 L F
.569 .031 0 r
.33136 .57403 m .33161 .57427 L .33256 .57552 L F
.971 .924 .685 r
.33255 .57558 m .33383 .57631 L .33226 .57715 L F
.33256 .57552 m .33257 .57553 L .33255 .57558 L F
.33257 .57553 m .33383 .57631 L .33255 .57558 L F
0 0 .119 r
.332 .57707 m .3331 .577 L .33314 .57635 L F
.949 .952 .728 r
.33256 .57552 m .32991 .57887 L .33191 .57713 L F
.956 .909 .731 r
.33255 .57558 m .32991 .57887 L .33256 .57552 L F
0 0 .119 r
.33191 .57713 m .33217 .57658 L .33256 .57552 L F
.956 .909 .731 r
.33226 .57715 m .33184 .57745 L .33255 .57558 L F
.33184 .57745 m .33217 .57658 L .33255 .57558 L F
0 0 .119 r
.33217 .57658 m .33263 .57561 L .33256 .57552 L F
.267 .017 .336 r
.33538 .57721 m .33209 .58103 L .33226 .57715 L F
0 0 0 r
.33196 .57712 m .33207 .57823 L .3331 .577 L F
.33191 .57713 m .33191 .57717 L .33196 .57712 L F
.956 .909 .731 r
.33184 .57745 m .33196 .57712 L .33197 .57711 L F
.656 .861 .476 r
.32911 .58115 m .33191 .57713 L .32991 .57887 L F
.723 .795 .909 r
.33032 .57928 m .32911 .58115 L .32991 .57887 L F
.656 .861 .476 r
.32911 .58115 m .32959 .58028 L .33031 .5793 L F
.32911 .58115 m .33031 .5793 L .33191 .57713 L F
.723 .795 .909 r
.33209 .58103 m .32911 .58115 L .33032 .57928 L F
.33209 .58103 m .33032 .57928 L .33226 .57715 L F
.33032 .57928 m .32991 .57887 L .33146 .57774 L F
.656 .861 .476 r
.32959 .58028 m .33184 .57721 L .33191 .57713 L F
.723 .795 .909 r
.33032 .57928 m .33146 .57774 L .33226 .57715 L F
.656 .861 .476 r
.32959 .58028 m .33008 .57938 L .33184 .57721 L F
0 0 0 r
.33191 .57717 m .33207 .57823 L .33196 .57712 L F
.956 .909 .731 r
.33184 .57745 m .33183 .57746 L .33196 .57713 L F
0 0 0 r
.33191 .57717 m .33008 .57938 L .33207 .57823 L F
.33191 .57713 m .33176 .57731 L .33191 .57717 L F
.33176 .57731 m .33008 .57938 L .33191 .57717 L F
.956 .909 .731 r
.33197 .57711 m .33196 .57712 L .33217 .57658 L F
0 0 .119 r
.33191 .57713 m .33196 .57712 L .33197 .57709 L F
.956 .909 .731 r
.33183 .57746 m .32991 .57887 L .33255 .57558 L F
0 0 .119 r
.33197 .57709 m .33198 .57712 L .332 .57707 L F
.33196 .57712 m .33198 .57712 L .33197 .57709 L F
.33198 .57712 m .3331 .577 L .332 .57707 L F
.569 .031 0 r
.33184 .57448 m .33383 .57631 L .33257 .57553 L F
.602 .375 .545 r
.33136 .57403 m .33383 .57631 L .33376 .57368 L F
0 0 .119 r
.33263 .57561 m .33314 .57635 L .3333 .57419 L F
.33191 .57713 m .33314 .57635 L .33263 .57561 L F
.569 .031 0 r
.33161 .57427 m .33184 .57448 L .33256 .57552 L F
.33184 .57448 m .33257 .57553 L .33256 .57552 L F
.33136 .57403 m .33256 .57552 L .33376 .57368 L F
.733 .847 .408 r
.33376 .57368 m .33256 .57552 L .33457 .5713 L F
0 0 .119 r
.33263 .57561 m .3333 .57419 L .33256 .57552 L F
.37 .069 .318 r
.23807 .57112 m .23761 .57319 L .23536 .57379 L F
.319 0 .153 r
.24081 .57095 m .23761 .57319 L .23807 .57112 L F
.736 .925 .576 r
.37481 .55103 m .3724 .55439 L .37375 .55277 L F
.308 0 0 r
.39693 .65553 m .39556 .65328 L .39627 .65251 L F
.895 .616 .506 r
.34315 .65502 m .3433 .65266 L .34413 .65497 L F
.01 .311 .802 r
.34589 .65663 m .34315 .65502 L .34413 .65497 L F
.906 .875 .443 r
.7059 .3349 m .70488 .33848 L .70508 .33956 L F
.104 0 0 r
.60393 .39318 m .6051 .39321 L .60129 .39286 L F
.145 0 0 r
.60642 .39403 m .6051 .39321 L .60393 .39318 L F
.60642 .39403 m .60765 .39265 L .6051 .39321 L F
.637 .531 .717 r
.35925 .62512 m .35944 .62758 L .36177 .62446 L F
.586 .461 .677 r
.35944 .62758 m .3622 .62711 L .36177 .62446 L F
.532 .278 .476 r
.36159 .62989 m .35944 .62758 L .35901 .63004 L F
.36159 .62989 m .3622 .62711 L .35944 .62758 L F
.655 .715 .892 r
.64139 .39345 m .63709 .39264 L .63998 .39012 L F
.593 .628 .856 r
.6427 .38918 m .64139 .39345 L .63998 .39012 L F
.6427 .38918 m .644 .39272 L .64139 .39345 L F
.658 .466 .613 r
.41415 .51714 m .41515 .51981 L .41115 .51984 L F
.621 .447 .625 r
.41802 .51739 m .41415 .51714 L .41511 .51613 L F
.41802 .51739 m .41515 .51981 L .41415 .51714 L F
.202 .561 .936 r
.19531 .60575 m .19388 .60577 L .19343 .604 L F
.19531 .60575 m .19388 .60577 L .19343 .604 L F
.621 .37 .516 r
.33108 .60259 m .33066 .60503 L .32776 .6053 L F
.14 0 .209 r
.33108 .60259 m .33398 .59927 L .33319 .60179 L F
.496 .31 .558 r
.33319 .60179 m .33066 .60503 L .33108 .60259 L F
0 0 0 r
.64355 .43942 m .64074 .44242 L .64153 .44071 L F
.563 .926 .941 r
.64574 .42843 m .64142 .42938 L .64452 .4272 L F
.757 .525 .582 r
.36378 .52909 m .36053 .52654 L .36345 .52629 L F
0 0 .532 r
.35775 .60047 m .35684 .59933 L .3588 .59866 L F
0 0 0 r
.4019 .68497 m .40057 .68666 L .39942 .6879 L F
0 0 .161 r
.40057 .68666 m .39941 .69082 L .39942 .6879 L F
.271 .226 .623 r
.34868 .52034 m .34925 .52351 L .35106 .52188 L F
0 0 0 r
.24688 .54952 m .2471 .54969 L .24927 .54853 L F
.24688 .54952 m .24538 .55067 L .2471 .54969 L F
.823 .834 .856 r
.68307 .32965 m .6798 .3294 L .68321 .32582 L F
.858 .769 .763 r
.68307 .32965 m .68071 .33316 L .6798 .3294 L F
.866 .866 .837 r
.68554 .32652 m .68307 .32965 L .68321 .32582 L F
.496 .395 .67 r
.3458 .60435 m .34685 .60232 L .34434 .60324 L F
.437 .533 .857 r
.354 .56372 m .35308 .566 L .35139 .56449 L F
.769 .803 .88 r
.3673 .65271 m .36809 .65705 L .37161 .65348 L F
0 0 0 r
.38977 .63614 m .38825 .63748 L .39044 .63403 L F
.203 0 .351 r
.38977 .63614 m .38678 .63979 L .38825 .63748 L F
.64 .08 0 r
.2748 .63867 m .27802 .64019 L .27824 .64063 L F
.458 .411 .718 r
.40033 .66793 m .39879 .67205 L .39797 .67036 L F
.588 .509 .734 r
.3927 .58396 m .38983 .58698 L .38919 .58441 L F
.546 .026 0 r
.38983 .58698 m .39227 .58852 L .38918 .58862 L F
.861 .862 .839 r
.5546 .42817 m .55275 .42721 L .55488 .4242 L F
.635 .633 .831 r
.55884 .42494 m .5546 .42817 L .55488 .4242 L F
.584 .453 .669 r
.24572 .56355 m .24354 .5673 L .24335 .56441 L F
.017 .511 .871 r
.35123 .65976 m .35681 .66261 L .357 .66222 L F
0 0 .506 r
.39917 .52361 m .40002 .52437 L .39771 .5223 L F
.39917 .52361 m .40117 .52584 L .40002 .52437 L F
.681 .227 .167 r
.21436 .57034 m .21645 .5724 L .21849 .57082 L F
.235 0 0 r
.21849 .57082 m .21639 .57068 L .21436 .57034 L F
.872 .834 .806 r
.21957 .56738 m .21849 .57082 L .22272 .57011 L F
.21957 .56738 m .21639 .57068 L .21849 .57082 L F
.576 .339 .519 r
.21957 .56738 m .21959 .57059 L .21639 .57068 L F
.21959 .57059 m .21959 .57083 L .21851 .57078 L F
.21959 .57059 m .21851 .57078 L .21639 .57068 L F
0 0 .157 r
.22018 .56805 m .21964 .57058 L .21957 .56738 L F
.549 .877 .608 r
.21923 .5707 m .21948 .57063 L .22272 .57011 L F
.21832 .57081 m .21999 .57052 L .22272 .57011 L F
0 0 0 r
.22012 .5707 m .22272 .57011 L .21964 .57058 L F
0 0 .157 r
.21964 .57058 m .21959 .57083 L .21959 .57059 L F
.549 .877 .608 r
.21849 .57082 m .21832 .57081 L .21948 .57063 L F
.21849 .57082 m .21948 .57063 L .21923 .5707 L F
.21832 .57081 m .21819 .5708 L .21999 .57052 L F
.611 .594 .809 r
.21964 .57058 m .21819 .5708 L .21959 .57083 L F
0 0 0 r
.21964 .57058 m .21964 .57058 L .21819 .5708 L F
0 0 .157 r
.21964 .57058 m .21959 .57059 L .21957 .56738 L F
.611 .594 .809 r
.22018 .56805 m .21819 .5708 L .21964 .57058 L F
0 0 0 r
.21985 .57071 m .21964 .57058 L .21819 .5708 L F
.22012 .5707 m .21964 .57058 L .21985 .57071 L F
.549 .877 .608 r
.21849 .57082 m .21645 .5724 L .21819 .5708 L F
.716 .463 .541 r
.59912 .44102 m .59539 .44302 L .59519 .44149 L F
.939 .78 .315 r
.41886 .57071 m .41804 .57238 L .41781 .56966 L F
.41886 .57071 m .4186 .57345 L .41804 .57238 L F
.756 .56 .631 r
.36255 .56629 m .36618 .56736 L .36518 .56411 L F
0 0 0 r
.36518 .56411 m .36301 .56606 L .36255 .56629 L F
.803 .716 .769 r
.36937 .56281 m .36301 .56606 L .36518 .56411 L F
.053 .597 .843 r
.36822 .7136 m .36984 .71325 L .36596 .71326 L F
.098 0 0 r
.36807 .71344 m .36596 .71326 L .36984 .71325 L F
.549 .824 .997 r
.36523 .7132 m .36822 .7136 L .36596 .71326 L F
.098 0 0 r
.36507 .71375 m .36596 .71326 L .36807 .71344 L F
.549 .824 .997 r
.3641 .71305 m .36523 .7132 L .36596 .71326 L F
.053 .597 .843 r
.36822 .7136 m .37097 .7139 L .36984 .71325 L F
0 0 0 r
.39245 .55629 m .39172 .55664 L .3892 .55709 L F
.762 .311 .177 r
.39478 .55761 m .39506 .55847 L .39245 .55629 L F
.175 .71 .758 r
.35312 .66802 m .35185 .66837 L .3507 .66892 L F
.35312 .66802 m .3533 .66811 L .35185 .66837 L F
.477 .868 .676 r
.35299 .66795 m .35312 .66802 L .35114 .6691 L F
.35499 .6667 m .35312 .66802 L .35299 .66795 L F
.175 .71 .758 r
.35312 .66802 m .35391 .668 L .3533 .66811 L F
.824 .369 .144 r
.56322 .44359 m .55912 .44012 L .56306 .44104 L F
.915 .738 .649 r
.70346 .32252 m .70519 .32387 L .70387 .32008 L F
.896 .736 .676 r
.70166 .32559 m .70519 .32387 L .70346 .32252 L F
.75 .391 0 r
.60384 .40309 m .60398 .40408 L .60267 .40173 L F
.60384 .40309 m .60475 .40547 L .60398 .40408 L F
.802 .999 .839 r
.6364 .40504 m .63978 .40288 L .63896 .40181 L F
.413 0 0 r
.27103 .63898 m .27263 .63795 L .2748 .63867 L F
.666 .468 .607 r
.36084 .55323 m .35941 .55456 L .35998 .55577 L F
.257 .294 .709 r
.35756 .55134 m .35998 .55577 L .35645 .55495 L F
.3577 .55088 m .35941 .55456 L .35756 .55134 L F
.35941 .55456 m .35998 .55577 L .35756 .55134 L F
.666 .468 .607 r
.36084 .55323 m .36068 .55625 L .36038 .55624 L F
.458 .863 .963 r
.35998 .55577 m .35624 .55715 L .35645 .55495 L F
.666 .468 .607 r
.35941 .55456 m .35772 .55612 L .35998 .55577 L F
.458 .863 .963 r
.35998 .55577 m .35772 .55612 L .35624 .55715 L F
.666 .468 .607 r
.35941 .55456 m .36038 .55624 L .35772 .55612 L F
.722 .544 .648 r
.36084 .55323 m .35998 .55577 L .35962 .55493 L F
.666 .468 .607 r
.36084 .55323 m .35962 .55493 L .35941 .55456 L F
.722 .544 .648 r
.36084 .55323 m .35962 .55493 L .3578 .55055 L F
.666 .468 .607 r
.36084 .55323 m .36038 .55624 L .35962 .55493 L F
.257 .294 .709 r
.3578 .55055 m .35998 .55577 L .3577 .55088 L F
.605 .381 .55 r
.33455 .54769 m .33153 .5454 L .33469 .54523 L F
.33455 .54769 m .33179 .54815 L .33153 .5454 L F
.388 .469 .822 r
.36906 .54736 m .37101 .54805 L .36955 .54355 L F
0 0 .078 r
.36906 .54736 m .36928 .54959 L .37101 .54805 L F
0 0 .56 r
.35191 .52668 m .35379 .53129 L .35239 .52906 L F
.234 .183 .592 r
.19707 .58071 m .19923 .58171 L .19915 .57916 L F
.19707 .58071 m .19749 .58328 L .19923 .58171 L F
.473 .12 .286 r
.19834 .59345 m .19973 .59451 L .199 .59309 L F
.19834 .59345 m .19643 .59547 L .19973 .59451 L F
.426 .336 .651 r
.32196 .51303 m .32378 .51388 L .32325 .51106 L F
.871 .868 .832 r
.36906 .61305 m .3655 .61478 L .36777 .61378 L F
.706 .545 .668 r
.36481 .60827 m .36586 .61361 L .36789 .61112 L F
.624 .816 .974 r
.36777 .61378 m .3655 .61478 L .36373 .61333 L F
.36777 .61378 m .36373 .61333 L .36622 .6126 L F
.993 .749 .441 r
.36622 .6126 m .36623 .61466 L .36777 .61378 L F
.431 .494 .824 r
.36743 .61826 m .36777 .61378 L .3655 .61478 L F
.011 0 0 r
.36623 .61534 m .3655 .61478 L .36777 .61378 L F
.993 .749 .441 r
.36623 .61466 m .36623 .61534 L .36777 .61378 L F
.871 .868 .832 r
.36929 .61294 m .36906 .61305 L .36777 .61378 L F
.569 .034 0 r
.36777 .61378 m .37182 .61424 L .36929 .61294 L F
.559 0 0 r
.63154 .40749 m .6316 .40552 L .63073 .40593 L F
.63154 .40749 m .62997 .40768 L .6316 .40552 L F
.63154 .40749 m .63404 .40887 L .62997 .40768 L F
.698 .956 .95 r
.63154 .40749 m .63447 .40599 L .63404 .40887 L F
0 .443 .855 r
.42825 .56439 m .42851 .56589 L .42674 .56385 L F
.637 .869 .985 r
.35743 .71366 m .36173 .71347 L .36015 .71242 L F
.071 0 0 r
.36173 .71347 m .3641 .71305 L .3633 .714 L F
.36173 .71347 m .3633 .714 L .36015 .71242 L F
.605 .527 .74 r
.36787 .59018 m .37035 .58936 L .36966 .58575 L F
.621 .421 .591 r
.38309 .68025 m .38569 .67757 L .38385 .6791 L F
.943 .923 .559 r
.29458 .55811 m .29314 .55962 L .29346 .56067 L F
0 0 .173 r
.29586 .5538 m .29578 .55688 L .29458 .55811 L F
.554 .839 .502 r
.2941 .5585 m .29458 .55811 L .29578 .55688 L F
.2941 .5585 m .29314 .55962 L .29458 .55811 L F
.551 .607 .863 r
.35901 .63004 m .36072 .63378 L .36346 .6323 L F
0 0 .272 r
.36306 .52333 m .36366 .52361 L .36444 .52431 L F
.422 .325 .641 r
.36523 .52538 m .36306 .52333 L .36444 .52431 L F
.36523 .52538 m .36345 .52629 L .36306 .52333 L F
0 0 .272 r
.36306 .52333 m .36345 .52629 L .36366 .52361 L F
.98 .759 .532 r
.38272 .62028 m .3838 .61828 L .38268 .61731 L F
.435 .737 .991 r
.38268 .61731 m .3838 .61828 L .38478 .61675 L F
0 0 0 r
.38478 .61675 m .3838 .61828 L .38272 .62028 L F
.393 .787 .988 r
.39438 .66143 m .39614 .6623 L .39348 .66259 L F
.705 .183 0 r
.32324 .6917 m .32458 .69318 L .32167 .69075 L F
.179 .357 .805 r
.60663 .42346 m .60542 .42527 L .60371 .42177 L F
.536 .317 .529 r
.60632 .42662 m .61113 .42664 L .60846 .42456 L F
.592 .821 .987 r
.60846 .42456 m .60691 .42662 L .60632 .42662 L F
.60846 .42456 m .60542 .42527 L .60691 .42662 L F
.064 .195 .691 r
.60691 .42662 m .60542 .42527 L .60663 .42346 L F
.408 .187 .463 r
.32707 .59938 m .32936 .59876 L .32963 .59621 L F
0 .147 .671 r
.32707 .59938 m .32909 .60127 L .32936 .59876 L F
.317 .418 .807 r
.19821 .58592 m .19989 .58978 L .20106 .58905 L F
.331 .197 .543 r
.19989 .58978 m .20163 .59192 L .20106 .58905 L F
.19989 .58978 m .199 .59309 L .20163 .59192 L F
.076 0 0 r
.32999 .55191 m .32792 .55337 L .32576 .55385 L F
.751 .969 .693 r
.33067 .55024 m .32792 .55337 L .32999 .55191 L F
.425 .192 .455 r
.33067 .55024 m .32992 .55292 L .32792 .55337 L F
.32992 .55292 m .32982 .5533 L .32792 .55337 L F
.076 0 0 r
.32576 .55385 m .32792 .55337 L .32553 .55396 L F
.766 .851 .915 r
.5938 .4313 m .59537 .4284 L .59242 .42922 L F
0 .308 .719 r
.59586 .43204 m .59627 .43258 L .5938 .4313 L F
.59586 .43204 m .5938 .4313 L .5935 .43225 L F
0 .171 .704 r
.33908 .52345 m .34144 .5256 L .34137 .52646 L F
0 .096 .65 r
.34144 .5256 m .34343 .52883 L .34137 .52646 L F
.1 .332 .805 r
.21558 .60624 m .21705 .60795 L .21515 .60452 L F
.772 .927 .564 r
.32999 .54507 m .32852 .5463 L .33062 .54294 L F
.802 .764 .819 r
.36117 .51525 m .36426 .51381 L .36251 .51377 L F
.36117 .51525 m .36451 .51383 L .36426 .51381 L F
.482 .009 .055 r
.36675 .51301 m .36251 .51377 L .36426 .51381 L F
.588 .509 .734 r
.3927 .58396 m .38919 .58441 L .39067 .58164 L F
.871 .87 .833 r
.68896 .3214 m .68775 .32319 L .68648 .32162 L F
.89 .854 .8 r
.68775 .32319 m .68422 .32479 L .68648 .32162 L F
.68775 .32319 m .68554 .32652 L .68422 .32479 L F
.327 .263 .631 r
.29816 .55062 m .29586 .5538 L .29497 .5518 L F
.29816 .55062 m .29865 .55389 L .29586 .5538 L F
.256 0 .302 r
.29785 .5559 m .29586 .5538 L .29865 .55389 L F
.29785 .5559 m .29578 .55688 L .29586 .5538 L F
0 0 .153 r
.36793 .60499 m .36861 .60425 L .36888 .60141 L F
.227 .652 .957 r
.36861 .60425 m .37057 .60541 L .36793 .60499 L F
0 0 0 r
.36793 .60499 m .36626 .60766 L .36861 .60425 L F
.996 .775 .424 r
.71256 .30586 m .7139 .30467 L .71324 .30324 L F
.71256 .30586 m .71381 .30695 L .7139 .30467 L F
0 0 .1 r
.40337 .68076 m .40285 .68376 L .4019 .68497 L F
.557 .812 .438 r
.40285 .68376 m .40057 .68666 L .4019 .68497 L F
0 .011 .567 r
.36364 .61802 m .36536 .61983 L .36743 .61826 L F
.431 .494 .824 r
.36743 .61826 m .36931 .61751 L .36777 .61378 L F
.622 .947 .942 r
.30528 .51586 m .30648 .51441 L .30884 .51526 L F
.30528 .51586 m .30418 .51575 L .30648 .51441 L F
.727 .91 .545 r
.37036 .57844 m .36945 .58025 L .37173 .57687 L F
0 0 .206 r
.37036 .58157 m .36945 .58025 L .37036 .57844 L F
.37036 .58157 m .36863 .5835 L .36945 .58025 L F
.285 .785 .786 r
.24842 .52856 m .24963 .528 L .25184 .52727 L F
.478 .89 .774 r
.25184 .52727 m .25167 .52679 L .25417 .52644 L F
.25184 .52727 m .24963 .528 L .25167 .52679 L F
.532 0 0 r
.70615 .35764 m .70933 .35918 L .70913 .35976 L F
.506 .226 .423 r
.70933 .35918 m .71172 .3595 L .70913 .35976 L F
.138 .194 .659 r
.43172 .57582 m .43054 .5776 L .42986 .57368 L F
.938 .898 .761 r
.43172 .57582 m .43175 .57973 L .43054 .5776 L F
.838 .378 0 r
.21933 .58458 m .2192 .5834 L .21833 .58271 L F
.2186 .58345 m .21833 .58271 L .21791 .58239 L F
.21933 .58458 m .21833 .58271 L .2186 .58345 L F
0 0 .377 r
.21987 .58084 m .21863 .58353 L .21898 .5792 L F
.21863 .58353 m .21859 .58363 L .2186 .58345 L F
.21863 .58353 m .2186 .58345 L .21898 .5792 L F
.319 .285 .663 r
.21898 .5792 m .2186 .58345 L .21791 .58239 L F
.2186 .58345 m .21859 .58363 L .21791 .58239 L F
.647 .662 .85 r
.21863 .58353 m .21939 .58508 L .21859 .58363 L F
.838 .378 0 r
.21939 .58508 m .21933 .58458 L .21856 .58339 L F
.647 .662 .85 r
.21987 .58084 m .21939 .58508 L .21863 .58353 L F
.838 .378 0 r
.21939 .58508 m .21856 .58339 L .21791 .58239 L F
0 .28 .783 r
.23635 .62117 m .23655 .61983 L .23395 .61793 L F
0 .256 .767 r
.23635 .62117 m .23722 .62158 L .23655 .61983 L F
.631 .101 0 r
.31598 .52806 m .31947 .52879 L .31759 .52739 L F
.15 .295 .757 r
.59712 .41147 m .5957 .41281 L .59514 .41025 L F
.534 .397 .64 r
.59899 .41457 m .5957 .41281 L .59712 .41147 L F
.59899 .41457 m .59651 .41593 L .5957 .41281 L F
.412 .327 .65 r
.36667 .59941 m .36695 .60208 L .36888 .60141 L F
.765 .862 .425 r
.39355 .62901 m .3919 .63298 L .39359 .63142 L F
.965 .852 .679 r
.60037 .42082 m .60143 .42279 L .60041 .42498 L F
.637 .762 .938 r
.60371 .42177 m .60143 .42279 L .60037 .42082 L F
.702 .784 .915 r
.38387 .60537 m .38228 .60743 L .37949 .60497 L F
.755 .905 .518 r
.32151 .6872 m .32312 .68518 L .32133 .68794 L F
.691 .911 .569 r
.32544 .68218 m .32312 .68518 L .32371 .68395 L F
.68 .875 .491 r
.32371 .68395 m .32312 .68518 L .32151 .6872 L F
.643 .473 .638 r
.29251 .5326 m .29578 .53243 L .29554 .5299 L F
.141 0 0 r
.29251 .5326 m .2908 .53442 L .29437 .53256 L F
0 0 0 r
.29317 .53313 m .29417 .53262 L .29437 .53256 L F
.642 .472 .638 r
.29554 .5299 m .29578 .53243 L .29833 .5296 L F
0 0 0 r
.29417 .53262 m .29634 .53153 L .29437 .53256 L F
.141 0 0 r
.29458 .53249 m .29437 .53256 L .29578 .53243 L F
.29251 .5326 m .29437 .53256 L .29458 .53249 L F
.668 .766 .923 r
.60152 .37891 m .6023 .38086 L .59843 .38014 L F
.59843 .38014 m .6023 .38086 L .60152 .37891 L F
.46 .636 .932 r
.60152 .37891 m .6023 .38086 L .60342 .3785 L F
.60342 .3785 m .6023 .38086 L .60152 .37891 L F
.874 .717 .685 r
.346 .52759 m .34144 .5256 L .34447 .52651 L F
.346 .52759 m .34343 .52883 L .34144 .5256 L F
.646 .522 .698 r
.34182 .53101 m .34239 .53163 L .34343 .52883 L F
.34239 .53163 m .34372 .53307 L .3436 .53134 L F
.34239 .53163 m .3436 .53134 L .34343 .52883 L F
.591 .48 .695 r
.34576 .53133 m .34612 .53172 L .346 .52759 L F
.34612 .53172 m .34645 .53208 L .34639 .53148 L F
.34612 .53172 m .34639 .53148 L .346 .52759 L F
.708 .56 .684 r
.34505 .53474 m .34645 .53208 L .34372 .53307 L F
.34505 .53474 m .3472 .53509 L .34645 .53208 L F
.613 .5 .702 r
.34645 .53208 m .35007 .53401 L .34928 .53209 L F
.34722 .53176 m .34928 .53209 L .34846 .5301 L F
.176 .076 .494 r
.34846 .5301 m .34725 .53186 L .34722 .53176 L F
.34846 .5301 m .34722 .53176 L .346 .52759 L F
.613 .5 .702 r
.34684 .5317 m .34722 .53176 L .34846 .5301 L F
.34645 .53208 m .34928 .53209 L .34684 .5317 L F
.216 .079 .469 r
.346 .52759 m .34645 .53208 L .34684 .5317 L F
.566 .298 .468 r
.34686 .53054 m .34709 .53133 L .34397 .53125 L F
.591 .48 .695 r
.34576 .53133 m .34372 .53307 L .34645 .53208 L F
.3436 .53134 m .34372 .53307 L .34408 .53277 L F
.34384 .53134 m .34408 .53277 L .34576 .53133 L F
.3436 .53134 m .34408 .53277 L .34384 .53134 L F
.566 .298 .468 r
.346 .52759 m .34384 .53134 L .34343 .52883 L F
.34384 .53134 m .34319 .53247 L .34343 .52883 L F
.34709 .53133 m .34722 .53176 L .34452 .53134 L F
.34709 .53133 m .34452 .53134 L .34397 .53125 L F
.34458 .53006 m .34536 .53091 L .34388 .53127 L F
.346 .52759 m .34536 .53091 L .34458 .53006 L F
.346 .52759 m .34686 .53054 L .34536 .53091 L F
.591 .48 .695 r
.34343 .52883 m .3436 .53134 L .34576 .53133 L F
.216 .079 .469 r
.346 .52759 m .34684 .5317 L .34846 .5301 L F
.566 .298 .468 r
.34397 .53125 m .34686 .53179 L .34388 .53127 L F
.34686 .53179 m .34725 .53186 L .34686 .53179 L F
.34686 .53179 m .34686 .53179 L .34388 .53127 L F
.34722 .53176 m .34725 .53186 L .34397 .53125 L F
.613 .5 .702 r
.34645 .53208 m .3472 .53509 L .35007 .53401 L F
.455 .052 .185 r
.34725 .53186 m .34472 .53312 L .34462 .53307 L F
.34571 .53209 m .34462 .53307 L .34319 .53247 L F
.34725 .53186 m .34462 .53307 L .34571 .53209 L F
.591 .48 .695 r
.34343 .52883 m .34576 .53133 L .346 .52759 L F
.566 .298 .468 r
.34388 .53127 m .34574 .5316 L .34319 .53247 L F
.34574 .5316 m .34725 .53186 L .34571 .53209 L F
.34574 .5316 m .34571 .53209 L .34319 .53247 L F
.327 .299 .674 r
.34838 .525 m .346 .52759 L .34447 .52651 L F
.467 .152 .347 r
.346 .52759 m .34883 .52798 L .34927 .52609 L F
.216 .079 .469 r
.346 .52759 m .34846 .5301 L .34883 .52798 L F
.157 .026 .439 r
.34883 .52798 m .351 .52457 L .34927 .52609 L F
.34883 .52798 m .35073 .52731 L .351 .52457 L F
.176 .076 .494 r
.34846 .5301 m .346 .52759 L .34902 .52846 L F
.34846 .5301 m .34902 .52846 L .34946 .52858 L F
.381 .154 .44 r
.34872 .52862 m .34904 .52841 L .34883 .52798 L F
.34904 .52841 m .35073 .52731 L .34924 .52783 L F
.34904 .52841 m .34924 .52783 L .34883 .52798 L F
.327 .299 .674 r
.34936 .52828 m .34946 .52858 L .34902 .52846 L F
.415 .354 .68 r
.35073 .52731 m .34946 .52858 L .34936 .52828 L F
0 0 .385 r
.34927 .52609 m .35106 .52188 L .34925 .52351 L F
.34927 .52609 m .351 .52457 L .35106 .52188 L F
.415 .354 .68 r
.35073 .52731 m .34936 .52828 L .34838 .525 L F
.381 .154 .44 r
.34846 .5301 m .35073 .52731 L .34946 .52858 L F
.34846 .5301 m .35039 .52773 L .34936 .52828 L F
.34869 .52875 m .34936 .52828 L .34872 .52862 L F
.34846 .5301 m .34936 .52828 L .34869 .52875 L F
.35039 .52773 m .35073 .52731 L .34872 .52862 L F
.327 .299 .674 r
.34838 .525 m .34936 .52828 L .346 .52759 L F
.34936 .52828 m .34902 .52846 L .346 .52759 L F
.877 .727 .692 r
.68255 .34204 m .68526 .3426 L .6837 .34578 L F
0 0 0 r
.73482 .33037 m .73497 .33076 L .7355 .32913 L F
.812 .75 .794 r
.69617 .31136 m .69262 .31069 L .69439 .30979 L F
.831 .74 .764 r
.69617 .31136 m .69196 .31322 L .69262 .31069 L F
.69617 .31136 m .69401 .31446 L .69196 .31322 L F
.668 .248 .238 r
.42628 .58687 m .42468 .58879 L .42213 .58818 L F
.505 .06 .126 r
.42831 .58825 m .42468 .58879 L .42628 .58687 L F
.58 .432 .645 r
.42869 .58327 m .42898 .58657 L .42628 .58687 L F
.466 .094 .249 r
.42628 .58687 m .42898 .58657 L .42831 .58825 L F
0 0 .31 r
.23022 .59812 m .22802 .59932 L .22945 .59449 L F
0 0 .101 r
.22713 .60198 m .22802 .59932 L .23022 .59812 L F
.355 .728 .987 r
.22016 .60998 m .21997 .60856 L .21841 .60797 L F
.22016 .60998 m .22492 .60991 L .21997 .60856 L F
0 0 0 r
.22285 .57014 m .22305 .56871 L .22099 .56751 L F
.263 .542 .923 r
.22305 .56871 m .22522 .56821 L .22545 .5663 L F
.22305 .56871 m .22727 .57046 L .22522 .56821 L F
.571 .812 .429 r
.65478 .4251 m .65375 .42646 L .65229 .42843 L F
.589 .839 .475 r
.65229 .42843 m .65375 .42646 L .65117 .42971 L F
.797 .68 .736 r
.37304 .58874 m .37719 .59235 L .37523 .58815 L F
.37304 .58874 m .37459 .59311 L .37719 .59235 L F
.434 .846 .967 r
.37459 .59311 m .37832 .5928 L .37719 .59235 L F
.716 .758 .885 r
.37523 .58815 m .37719 .59235 L .37921 .58871 L F
.296 .293 .687 r
.37832 .5928 m .37921 .58871 L .37719 .59235 L F
.678 .321 .361 r
.38184 .59289 m .38059 .59505 L .37832 .5928 L F
.615 .585 .797 r
.38355 .58836 m .38447 .59243 L .38184 .59289 L F
0 0 0 r
.38227 .59375 m .38184 .59289 L .38447 .59243 L F
.38227 .59375 m .38059 .59505 L .38184 .59289 L F
.655 .555 .73 r
.29438 .52638 m .29554 .5299 L .29833 .5296 L F
.242 .176 .58 r
.40059 .65849 m .399 .6589 L .39868 .65621 L F
.706 .17 0 r
.40059 .65849 m .39868 .65621 L .39693 .65553 L F
.554 .579 .834 r
.27817 .61078 m .27749 .61518 L .27563 .61399 L F
.27817 .61078 m .27993 .61484 L .27749 .61518 L F
.32 .742 .975 r
.27993 .61484 m .27563 .61399 L .27749 .61518 L F
.285 .785 .786 r
.24842 .52856 m .2473 .52869 L .24963 .528 L F
.506 .861 .613 r
.71619 .343 m .71293 .3456 L .71488 .34386 L F
.581 .895 .623 r
.71619 .343 m .71789 .34104 L .71826 .34133 L F
.71619 .343 m .71488 .34386 L .71789 .34104 L F
.95 .886 .734 r
.31786 .66476 m .32044 .66296 L .31882 .66192 L F
.31786 .66476 m .31904 .66614 L .32044 .66296 L F
.31786 .66476 m .32044 .66296 L .31882 .66192 L F
.31786 .66476 m .31904 .66614 L .32044 .66296 L F
.394 0 0 r
.32148 .66372 m .32044 .66296 L .31882 .66192 L F
.32148 .66372 m .3231 .66453 L .32044 .66296 L F
.997 .774 .469 r
.33165 .50112 m .33272 .49955 L .3339 .50005 L F
.33165 .50112 m .32994 .50236 L .33272 .49955 L F
.704 .754 .891 r
.28777 .52721 m .29162 .52721 L .29026 .52653 L F
.314 .793 .91 r
.29438 .52638 m .29026 .52653 L .29162 .52721 L F
.71 .765 .895 r
.60978 .39169 m .61152 .39332 L .60765 .39265 L F
.783 .775 .846 r
.61445 .39027 m .61152 .39332 L .60978 .39169 L F
.693 .454 .557 r
.37478 .57957 m .3787 .58074 L .37804 .57709 L F
.031 0 .418 r
.37964 .57345 m .37804 .57709 L .37872 .57534 L F
0 0 .275 r
.37804 .57709 m .37876 .57811 L .37872 .57534 L F
.37804 .57709 m .3787 .58074 L .37876 .57811 L F
.458 .411 .718 r
.40033 .66793 m .40094 .67229 L .39879 .67205 L F
.417 .861 .79 r
.30386 .52615 m .30226 .52658 L .30117 .52714 L F
.478 .239 .474 r
.30686 .52333 m .30609 .52623 L .30386 .52615 L F
.957 .615 .258 r
.30609 .52623 m .30542 .5274 L .30226 .52658 L F
.438 .473 .799 r
.30226 .52658 m .30542 .5274 L .30449 .52541 L F
.30226 .52658 m .30449 .52541 L .30378 .52387 L F
.417 .861 .79 r
.30117 .52714 m .30226 .52658 L .30066 .52733 L F
.757 .979 .916 r
.36245 .66451 m .3613 .66596 L .36177 .664 L F
.683 .925 .971 r
.36177 .664 m .3613 .66596 L .35954 .66525 L F
.003 0 0 r
.3819 .61167 m .37937 .61417 L .38044 .61279 L F
.61 .124 .076 r
.34272 .58399 m .34538 .58547 L .34571 .58427 L F
.925 .736 .628 r
.34272 .58399 m .34571 .58427 L .34538 .58547 L F
0 0 0 r
.34571 .58427 m .34538 .58547 L .34725 .58416 L F
.402 .516 .859 r
.65349 .39407 m .65193 .39641 L .65079 .39449 L F
.65349 .39407 m .65407 .39611 L .65193 .39641 L F
.348 .402 .775 r
.65514 .39898 m .65193 .39641 L .65407 .39611 L F
.676 .451 .572 r
.27992 .55323 m .27642 .55154 L .28042 .55155 L F
.291 0 .12 r
.28282 .55125 m .27992 .55323 L .28042 .55155 L F
.549 .93 .838 r
.3919 .63298 m .39187 .63264 L .39044 .63403 L F
0 0 0 r
.39102 .63515 m .39044 .63403 L .39187 .63264 L F
.39102 .63515 m .38977 .63614 L .39044 .63403 L F
.667 .131 0 r
.32458 .69318 m .32774 .69429 L .32561 .69418 L F
.82 .345 0 r
.32774 .69429 m .32775 .69622 L .32561 .69418 L F
.32774 .69429 m .32951 .69717 L .32775 .69622 L F
.816 .342 .081 r
.32774 .69429 m .33128 .69746 L .32951 .69717 L F
.014 0 .331 r
.32865 .51694 m .32991 .51819 L .33058 .51617 L F
.32865 .51694 m .32862 .51944 L .32991 .51819 L F
0 0 0 r
.23262 .59225 m .22945 .59449 L .22796 .59183 L F
.047 0 .318 r
.23069 .59701 m .22945 .59449 L .23035 .59442 L F
.23069 .59701 m .23022 .59812 L .22983 .59631 L F
.23069 .59701 m .22983 .59631 L .22945 .59449 L F
.313 .065 .368 r
.23173 .59786 m .23069 .59701 L .22931 .59593 L F
0 0 .101 r
.22713 .60198 m .23022 .59812 L .22903 .60046 L F
0 0 0 r
.23069 .59701 m .22903 .60046 L .23022 .59812 L F
.313 .065 .368 r
.23235 .59835 m .22947 .59972 L .23069 .59701 L F
0 0 0 r
.22987 .59871 m .22935 .59997 L .22903 .60046 L F
.23069 .59701 m .22947 .59972 L .22987 .59871 L F
.22947 .59972 m .22935 .59997 L .22987 .59871 L F
0 0 .341 r
.22938 .59992 m .22916 .60254 L .22903 .60046 L F
.22955 .60025 m .22916 .60254 L .22938 .59992 L F
.22955 .60025 m .22959 .60275 L .22916 .60254 L F
.047 .026 .508 r
.22963 .60041 m .22949 .60012 L .23235 .59835 L F
0 0 .341 r
.22969 .59945 m .22966 .60041 L .22955 .60025 L F
.22966 .60041 m .22959 .60275 L .22955 .60025 L F
.047 .026 .508 r
.22947 .60013 m .22947 .59972 L .23235 .59835 L F
.22925 .60027 m .22936 .59998 L .22947 .60013 L F
.22936 .59998 m .22947 .59972 L .22947 .60013 L F
.048 .145 .644 r
.22916 .60254 m .22713 .60198 L .22903 .60046 L F
.055 .03 .509 r
.22868 .60009 m .22959 .60275 L .22966 .60041 L F
.047 .026 .508 r
.22924 .60028 m .22924 .60027 L .22925 .60027 L F
.22924 .60027 m .22947 .59972 L .22925 .60027 L F
0 0 .341 r
.22969 .59945 m .22955 .60025 L .22938 .59992 L F
.047 .026 .508 r
.22963 .60041 m .22924 .60028 L .22949 .60012 L F
.22924 .60028 m .22868 .60009 L .22947 .59972 L F
.055 .03 .509 r
.22868 .60009 m .22966 .60041 L .22969 .59945 L F
.047 .026 .508 r
.23112 .60092 m .22964 .60041 L .23235 .59835 L F
0 0 0 r
.23393 .59823 m .23112 .60092 L .23235 .59835 L F
.23393 .59823 m .23221 .6005 L .23112 .60092 L F
.23578 .5971 m .23239 .6004 L .23393 .59823 L F
.518 .598 .873 r
.23221 .6005 m .23326 .60294 L .23211 .60057 L F
0 0 0 r
.23239 .6004 m .23198 .60079 L .23221 .6005 L F
.23239 .6004 m .23221 .6005 L .23393 .59823 L F
.518 .598 .873 r
.2339 .59922 m .23384 .59959 L .23221 .6005 L F
.313 .065 .368 r
.23235 .59835 m .23069 .59701 L .23173 .59786 L F
.386 .039 .249 r
.23465 .59339 m .23069 .59701 L .23035 .59442 L F
.23465 .59339 m .23309 .59657 L .23069 .59701 L F
.526 .434 .693 r
.23244 .5941 m .23069 .59701 L .23035 .59442 L F
.23244 .5941 m .23309 .59657 L .23069 .59701 L F
.313 .065 .368 r
.23235 .59835 m .23044 .59683 L .231 .59651 L F
.23044 .59683 m .22931 .59593 L .231 .59651 L F
.584 .106 .086 r
.22681 .59436 m .22908 .59578 L .23035 .59442 L F
.22908 .59578 m .22931 .59593 L .23035 .59442 L F
0 .28 .697 r
.22482 .59331 m .22931 .59593 L .22681 .59436 L F
.22911 .59581 m .22826 .59514 L .22931 .59593 L F
.22482 .59331 m .22826 .59514 L .22911 .59581 L F
0 0 0 r
.23188 .59277 m .23035 .59442 L .22945 .59449 L F
.251 .734 .93 r
.22798 .59183 m .2307 .59167 L .22796 .59183 L F
.23262 .59225 m .2307 .59167 L .22798 .59183 L F
.388 .183 .477 r
.23035 .59442 m .23252 .59156 L .2307 .59167 L F
.23252 .59156 m .23311 .59079 L .2307 .59167 L F
.75 .551 .625 r
.22681 .59436 m .23035 .59442 L .2307 .59167 L F
.22681 .59436 m .2307 .59167 L .22796 .59183 L F
.665 .121 0 r
.22482 .59331 m .22681 .59436 L .22466 .59212 L F
.198 .404 .838 r
.22556 .59134 m .22826 .59514 L .22482 .59331 L F
0 .152 .693 r
.2279 .59356 m .22826 .59514 L .22722 .59369 L F
.2279 .59356 m .22722 .59369 L .22556 .59134 L F
0 0 0 r
.22851 .59345 m .2279 .59356 L .23018 .59282 L F
.868 .96 .862 r
.22352 .59612 m .22513 .59655 L .2279 .59356 L F
.22352 .59612 m .2279 .59356 L .22544 .59462 L F
0 0 0 r
.22544 .59462 m .2279 .59356 L .22851 .59345 L F
.734 .334 .292 r
.2272 .59431 m .22826 .59514 L .2279 .59356 L F
.22513 .59655 m .22826 .59514 L .2272 .59431 L F
.819 .366 .155 r
.22828 .59516 m .231 .59651 L .22931 .59593 L F
.22826 .59514 m .22834 .59518 L .22828 .59516 L F
.22834 .59518 m .231 .59651 L .22828 .59516 L F
.313 .065 .368 r
.22947 .59972 m .22868 .60009 L .23069 .59701 L F
0 0 0 r
.23069 .59701 m .22969 .59945 L .22935 .59997 L F
.22868 .60009 m .22969 .59945 L .23069 .59701 L F
.23568 .59338 m .23309 .59657 L .23465 .59339 L F
.647 .509 .681 r
.23244 .5941 m .23309 .59657 L .23568 .59338 L F
.116 0 .402 r
.23424 .5949 m .23235 .59835 L .231 .59651 L F
.656 .294 .346 r
.22927 .59723 m .23183 .59769 L .23256 .59686 L F
.23197 .59596 m .23424 .5949 L .231 .59651 L F
.23121 .59632 m .23256 .59686 L .23424 .5949 L F
.68 .211 .133 r
.2271 .5986 m .22927 .59723 L .22513 .59655 L F
0 .164 .704 r
.22758 .59815 m .22927 .59723 L .2271 .5986 L F
.819 .366 .155 r
.22826 .59514 m .22927 .59723 L .23078 .5964 L F
.734 .334 .292 r
.22513 .59655 m .22927 .59723 L .22826 .59514 L F
0 .164 .704 r
.22973 .5961 m .22927 .59723 L .22758 .59815 L F
.819 .366 .155 r
.23078 .5964 m .22927 .59723 L .2309 .59646 L F
.656 .294 .346 r
.22927 .59723 m .23197 .59596 L .231 .59651 L F
.22927 .59723 m .23256 .59686 L .23121 .59632 L F
.116 0 .402 r
.23424 .5949 m .23393 .59823 L .23235 .59835 L F
.312 .137 .475 r
.23578 .5971 m .23393 .59823 L .23424 .5949 L F
.66 .377 .481 r
.23183 .59769 m .23196 .60022 L .23578 .5971 L F
.23196 .60022 m .23239 .6004 L .23578 .5971 L F
.973 .66 .317 r
.23149 .59931 m .23196 .60022 L .23183 .59769 L F
.518 .598 .873 r
.2339 .59922 m .23213 .60056 L .23149 .59931 L F
.23213 .60056 m .23211 .60057 L .23149 .59931 L F
0 0 0 r
.23221 .6005 m .23211 .60057 L .23112 .60092 L F
0 .192 .721 r
.23149 .59931 m .23211 .60057 L .23112 .60092 L F
.973 .66 .317 r
.23149 .59931 m .23198 .60079 L .23196 .60022 L F
0 0 0 r
.23221 .6005 m .23217 .60055 L .23211 .60057 L F
.66 .377 .481 r
.23196 .60022 m .23198 .60079 L .23239 .6004 L F
.518 .598 .873 r
.23239 .6004 m .23326 .60294 L .23221 .6005 L F
.23384 .59959 m .23361 .60089 L .23239 .6004 L F
.23361 .60089 m .23326 .60294 L .23239 .6004 L F
.23394 .59902 m .2339 .59922 L .23149 .59931 L F
0 .192 .721 r
.23211 .60057 m .23251 .60141 L .23112 .60092 L F
0 0 0 r
.23217 .60055 m .23198 .60079 L .23112 .60092 L F
0 .192 .721 r
.23251 .60141 m .23326 .60294 L .23112 .60092 L F
.047 .026 .508 r
.23112 .60092 m .22963 .60041 L .22964 .60041 L F
0 0 0 r
.23262 .59225 m .23035 .59442 L .23188 .59277 L F
.314 .126 .459 r
.33174 .59304 m .33179 .59523 L .33372 .59467 L F
.162 0 0 r
.33372 .59467 m .33612 .59411 L .33799 .59225 L F
.319 .804 .88 r
.33209 .59457 m .33532 .5942 L .33372 .59467 L F
.33532 .5942 m .33612 .59411 L .33372 .59467 L F
.314 .126 .459 r
.33179 .59523 m .33179 .59558 L .33372 .59467 L F
.531 .784 .99 r
.24785 .53957 m .24843 .53766 L .2461 .53821 L F
.24785 .53957 m .25023 .53903 L .24843 .53766 L F
0 0 .47 r
.199 .59309 m .20061 .59441 L .20163 .59192 L F
.199 .59309 m .19973 .59451 L .20061 .59441 L F
.597 .54 .761 r
.63317 .38598 m .63361 .38984 L .6308 .39039 L F
.562 .391 .607 r
.63361 .38984 m .63101 .39304 L .6308 .39039 L F
.747 .752 .857 r
.36338 .5535 m .36472 .55253 L .36499 .55128 L F
.468 .252 .501 r
.28651 .5359 m .28857 .53783 L .28854 .53536 L F
.28651 .5359 m .28633 .53861 L .28857 .53783 L F
.866 .866 .837 r
.68554 .32652 m .68321 .32582 L .68422 .32479 L F
.776 .405 0 r
.41381 .55444 m .41277 .553 L .4121 .55088 L F
.951 .645 .211 r
.41381 .55444 m .41289 .55599 L .41277 .553 L F
.41381 .55444 m .41409 .55734 L .41289 .55599 L F
.493 .572 .864 r
.32221 .65593 m .32067 .65627 L .32127 .65502 L F
.659 .499 .656 r
.31509 .63984 m .31873 .63457 L .31532 .63722 L F
0 0 0 r
.32735 .681 m .32544 .68218 L .32428 .68337 L F
.32735 .681 m .32428 .68337 L .32488 .683 L F
.32735 .681 m .32488 .683 L .32525 .68256 L F
.32488 .683 m .32428 .68337 L .32371 .68395 L F
.32488 .683 m .32371 .68395 L .32525 .68256 L F
.545 .913 .739 r
.32628 .68144 m .32525 .68256 L .32232 .68401 L F
.539 .868 .593 r
.32558 .68212 m .32525 .68256 L .32628 .68144 L F
.096 0 0 r
.32564 .6821 m .32525 .68256 L .32558 .68212 L F
.32967 .68045 m .32735 .681 L .32525 .68256 L F
.32784 .68119 m .32525 .68256 L .32564 .6821 L F
.32967 .68045 m .32688 .68178 L .32784 .68119 L F
.32688 .68178 m .32525 .68256 L .32784 .68119 L F
.205 .022 .398 r
.32963 .59621 m .331 .59777 L .33179 .59558 L F
.32963 .59621 m .32936 .59876 L .331 .59777 L F
.555 .368 .583 r
.43382 .53193 m .43064 .53556 L .43105 .5329 L F
.939 .644 .456 r
.23511 .60824 m .23534 .61083 L .23734 .611 L F
.18 .663 .927 r
.23534 .61083 m .23929 .61174 L .23734 .611 L F
.349 0 0 r
.3551 .50329 m .35746 .50428 L .35885 .50466 L F
.134 .668 .858 r
.35746 .50428 m .36107 .50456 L .35885 .50466 L F
.859 .488 0 r
.40998 .54225 m .40906 .54117 L .40818 .53868 L F
.994 .81 .44 r
.40958 .54491 m .40906 .54117 L .40998 .54225 L F
.424 .013 .154 r
.27298 .62047 m .27726 .61782 L .27491 .61833 L F
.891 .84 .789 r
.68995 .3164 m .69057 .31961 L .68767 .31996 L F
.876 .877 .832 r
.68767 .31996 m .69057 .31961 L .68896 .3214 L F
.839 .813 .825 r
.69162 .31812 m .69057 .31961 L .68995 .3164 L F
.49 .27 .506 r
.24836 .56292 m .24597 .56125 L .24862 .5607 L F
.24836 .56292 m .24572 .56355 L .24597 .56125 L F
.104 0 .041 r
.36712 .63689 m .36503 .63791 L .36407 .63974 L F
0 0 .303 r
.331 .54228 m .33206 .5381 L .32966 .53874 L F
.331 .54228 m .33208 .54082 L .33206 .5381 L F
0 0 0 r
.64401 .43745 m .64613 .43427 L .64615 .43631 L F
0 0 .008 r
.64355 .43942 m .64401 .43745 L .64615 .43631 L F
.702 .36 .394 r
.69538 .3551 m .69911 .35509 L .69831 .35762 L F
.582 .192 .267 r
.69911 .35509 m .70222 .35685 L .69831 .35762 L F
.69911 .35509 m .70177 .35528 L .70222 .35685 L F
.311 0 0 r
.7029 .32892 m .70591 .32999 L .70668 .3301 L F
.328 .442 .824 r
.70591 .32999 m .70724 .33301 L .70668 .3301 L F
.73 .723 .844 r
.35764 .51648 m .36165 .51713 L .36117 .51525 L F
.461 0 0 r
.35764 .51648 m .35991 .51758 L .36165 .51713 L F
.602 .95 .821 r
.35835 .51915 m .36165 .51713 L .35991 .51758 L F
.802 .764 .819 r
.36117 .51525 m .36165 .51713 L .36451 .51383 L F
.171 0 .222 r
.20069 .56729 m .20276 .56653 L .2036 .56397 L F
.25 .07 .431 r
.20069 .56729 m .2025 .56904 L .20276 .56653 L F
.20069 .56729 m .2003 .57022 L .2025 .56904 L F
.781 .76 .833 r
.29253 .62344 m .2934 .62547 L .29531 .62399 L F
.29253 .62344 m .2934 .62547 L .29531 .62399 L F
.921 .55 .297 r
.29676 .62677 m .29531 .62399 L .2934 .62547 L F
.463 0 0 r
.22797 .60379 m .23125 .60562 L .22993 .60475 L F
.485 .275 .519 r
.22444 .55726 m .22418 .56022 L .22213 .55765 L F
.07 0 0 r
.35943 .52014 m .35835 .51915 L .35991 .51758 L F
.195 0 .349 r
.30825 .52422 m .30609 .52623 L .30686 .52333 L F
.314 .793 .91 r
.29438 .52638 m .29292 .52608 L .29026 .52653 L F
.624 .945 .947 r
.29512 .5248 m .29438 .52638 L .29598 .52572 L F
.29512 .5248 m .29292 .52608 L .29438 .52638 L F
.655 .555 .73 r
.29438 .52638 m .29833 .5296 L .29598 .52572 L F
.622 .262 .338 r
.30196 .61372 m .29948 .61232 L .30315 .61169 L F
.604 .325 .466 r
.30548 .61136 m .30196 .61372 L .30315 .61169 L F
.69 .612 .763 r
.25668 .54106 m .25414 .54172 L .25713 .53888 L F
.25668 .54106 m .25414 .54172 L .25713 .53888 L F
.321 .234 .599 r
.25503 .53726 m .25694 .53943 L .25691 .53757 L F
.288 0 0 r
.25687 .5359 m .25503 .53726 L .25358 .53702 L F
.321 .234 .599 r
.25503 .53726 m .25691 .53757 L .25685 .53463 L F
.288 0 0 r
.25358 .53702 m .25503 .53726 L .25239 .53743 L F
.782 .491 .494 r
.26022 .53879 m .25687 .5359 L .25747 .53814 L F
.966 .652 .261 r
.2624 .56122 m .2624 .56272 L .26132 .56071 L F
.729 .717 .839 r
.39672 .51396 m .39794 .51709 L .39397 .51651 L F
.868 .625 .569 r
.39794 .51709 m .39464 .51899 L .39397 .51651 L F
.39794 .51709 m .39689 .52112 L .39464 .51899 L F
.434 .027 .166 r
.65437 .4098 m .6568 .41089 L .65316 .41052 L F
.65437 .4098 m .65737 .40971 L .6568 .41089 L F
.784 .998 .819 r
.34861 .54565 m .34539 .54853 L .34593 .54678 L F
.626 .131 .055 r
.34593 .54678 m .35001 .54729 L .34861 .54565 L F
.933 .661 .501 r
.34548 .54455 m .34593 .54678 L .34861 .54565 L F
.296 .099 .434 r
.34861 .54565 m .35001 .54729 L .35042 .54469 L F
0 0 .405 r
.65478 .4251 m .65471 .42433 L .65402 .42248 L F
.522 .551 .827 r
.65195 .41908 m .65402 .423 L .65092 .42427 L F
.981 .806 .4 r
.65399 .42283 m .65418 .42432 L .65478 .4251 L F
.522 .551 .827 r
.65402 .423 m .65471 .42433 L .65418 .42432 L F
.65402 .423 m .65418 .42432 L .65092 .42427 L F
.825 .679 .702 r
.65402 .42248 m .65471 .42433 L .65402 .423 L F
.65402 .42248 m .65402 .423 L .65195 .41908 L F
.981 .806 .4 r
.65402 .42248 m .65399 .42283 L .65402 .42289 L F
.65402 .42248 m .65402 .42289 L .65478 .4251 L F
.65399 .42283 m .65392 .42398 L .65418 .42432 L F
.315 .717 .979 r
.65092 .42427 m .65418 .42432 L .65478 .4251 L F
.981 .806 .4 r
.65392 .42398 m .65375 .42646 L .65478 .4251 L F
.315 .717 .979 r
.65418 .42432 m .65471 .42433 L .65478 .4251 L F
.836 .746 .765 r
.2197 .56457 m .21957 .56738 L .22099 .56751 L F
.872 .834 .806 r
.21957 .56738 m .22272 .57011 L .22099 .56751 L F
0 0 .44 r
.22272 .57011 m .22285 .57014 L .22099 .56751 L F
.472 .436 .736 r
.36523 .52538 m .36378 .52909 L .36345 .52629 L F
.659 .814 .377 r
.3957 .62545 m .39508 .62678 L .39708 .62382 L F
.3957 .62545 m .39481 .62716 L .39508 .62678 L F
.64 .551 .739 r
.41996 .51463 m .41511 .51613 L .41639 .51382 L F
.41996 .51463 m .41901 .51607 L .41511 .51613 L F
.639 .497 .673 r
.41901 .51607 m .41802 .51739 L .41511 .51613 L F
.377 .029 .243 r
.3793 .6236 m .37686 .62297 L .37779 .62241 L F
.558 .454 .691 r
.31105 .5299 m .31137 .53347 L .30868 .53315 L F
.389 0 0 r
.31137 .53347 m .31122 .53397 L .30868 .53315 L F
.921 .723 .618 r
.3563 .56832 m .36007 .56848 L .3582 .56675 L F
.761 .781 .869 r
.36255 .56629 m .36007 .56848 L .3582 .56675 L F
.676 .666 .833 r
.36411 .56741 m .36007 .56848 L .36255 .56629 L F
.493 .22 .428 r
.33591 .59875 m .33319 .60179 L .33398 .59927 L F
.178 .324 .775 r
.35543 .64305 m .35687 .64675 L .35811 .64562 L F
.127 .237 .709 r
.35811 .64562 m .35687 .64675 L .35939 .64924 L F
.719 .308 0 r
.4121 .55088 m .41008 .54741 L .41164 .54848 L F
.741 .44 .472 r
.60431 .43788 m .60835 .44045 L .6042 .44011 L F
.316 .17 .519 r
.31929 .58558 m .31758 .58926 L .31747 .58649 L F
.56 .284 .455 r
.58633 .44408 m .58623 .44624 L .58349 .44646 L F
.576 .298 .457 r
.58633 .44408 m .58899 .44611 L .58623 .44624 L F
.591 .29 .428 r
.58901 .44388 m .58899 .44611 L .58633 .44408 L F
.708 .46 .547 r
.56267 .41186 m .56497 .40891 L .56237 .40908 L F
.712 .183 0 r
.30001 .65774 m .30183 .65939 L .29847 .65797 L F
.017 0 0 r
.35829 .64054 m .35543 .64305 L .35804 .6428 L F
.551 .318 .516 r
.36181 .64298 m .35829 .64054 L .35804 .6428 L F
.36181 .64298 m .36146 .63981 L .35829 .64054 L F
.659 .814 .377 r
.3957 .62545 m .39708 .62382 L .39701 .62371 L F
.722 .989 .835 r
.29325 .52062 m .29416 .51878 L .29534 .51954 L F
.29325 .52062 m .29353 .51978 L .29416 .51878 L F
0 .218 .732 r
.6235 .4246 m .62091 .42194 L .62397 .42357 L F
.204 .052 .441 r
.62478 .42668 m .6235 .4246 L .62397 .42357 L F
.62478 .42668 m .62223 .42821 L .6235 .4246 L F
.893 .785 .735 r
.55349 .41787 m .55457 .42105 L .55173 .42064 L F
.971 .662 .366 r
.55457 .42105 m .55366 .42412 L .55173 .42064 L F
.774 .732 .814 r
.55349 .41787 m .5574 .41845 L .55457 .42105 L F
.575 .401 .609 r
.23023 .58018 m .23264 .5802 L .23276 .57697 L F
.23023 .58018 m .23264 .5802 L .23276 .57697 L F
.767 .702 .79 r
.63623 .38903 m .63709 .39264 L .63321 .39262 L F
.773 .594 .657 r
.63321 .39262 m .63709 .39264 L .63599 .39305 L F
.656 .633 .815 r
.63998 .39012 m .63709 .39264 L .63623 .38903 L F
.55 .666 .914 r
.24959 .62819 m .25457 .63017 L .25244 .62887 L F
.218 .56 .936 r
.25457 .63017 m .25467 .62851 L .25244 .62887 L F
.25457 .63017 m .2563 .63032 L .25467 .62851 L F
.22 .371 .803 r
.31715 .53488 m .31643 .53667 L .31542 .53519 L F
.31724 .53464 m .31779 .53597 L .31643 .53667 L F
.31779 .53597 m .31858 .5379 L .31696 .53698 L F
.31779 .53597 m .31696 .53698 L .31643 .53667 L F
.722 .636 .761 r
.32081 .53367 m .32137 .53502 L .31906 .53481 L F
.32004 .53394 m .31906 .53481 L .31786 .5347 L F
.32081 .53367 m .31906 .53481 L .32004 .53394 L F
.046 0 0 r
.31855 .53464 m .31913 .53453 L .32004 .53394 L F
.31855 .53464 m .32004 .53394 L .31998 .53396 L F
.731 .649 .768 r
.31978 .5312 m .31724 .53464 L .32009 .53391 L F
.722 .636 .761 r
.3201 .53381 m .32081 .53367 L .32011 .53386 L F
.31978 .5312 m .32025 .53232 L .3201 .53381 L F
.32025 .53232 m .32081 .53367 L .3201 .53381 L F
.752 .649 .748 r
.32398 .53372 m .32032 .53152 L .32382 .53178 L F
.32032 .53152 m .31978 .5312 L .32034 .53128 L F
.32032 .53152 m .32034 .53128 L .32382 .53178 L F
.32398 .53372 m .32137 .53502 L .31978 .5312 L F
.752 .664 .763 r
.32222 .52832 m .32382 .53178 L .31978 .5312 L F
.869 .892 .848 r
.32222 .52832 m .31978 .5312 L .31961 .52925 L F
.31962 .52925 m .31961 .52925 L .31961 .52925 L F
.32222 .52832 m .31961 .52925 L .31962 .52925 L F
.32222 .52832 m .31961 .52925 L .32213 .52721 L F
.645 .685 .873 r
.32472 .52745 m .32222 .52832 L .32213 .52721 L F
.365 .005 .214 r
.32217 .52729 m .32068 .52998 L .32299 .52895 L F
.32213 .52721 m .32203 .52741 L .32217 .52729 L F
.32203 .52741 m .32068 .52998 L .32217 .52729 L F
0 0 .032 r
.3201 .53383 m .32011 .5338 L .32012 .53367 L F
.32011 .5338 m .32043 .53299 L .32012 .53367 L F
.32009 .53391 m .32009 .53389 L .3201 .53383 L F
.32009 .53389 m .32043 .53299 L .3201 .53383 L F
.32006 .53366 m .32068 .52998 L .31961 .52925 L F
.32009 .53391 m .3201 .53383 L .32006 .53366 L F
.3201 .53383 m .32068 .52998 L .32006 .53366 L F
.722 .636 .761 r
.32006 .53366 m .32011 .53386 L .32009 .53387 L F
.31978 .5312 m .32011 .53386 L .32006 .53366 L F
0 0 .032 r
.32009 .53391 m .32006 .53366 L .31978 .5312 L F
.722 .636 .761 r
.31978 .5312 m .32009 .53387 L .31724 .53464 L F
0 0 .032 r
.32006 .53366 m .31961 .52925 L .31978 .5312 L F
.046 0 0 r
.31998 .53396 m .32009 .53391 L .31724 .53464 L F
.614 .925 .68 r
.32009 .53391 m .32004 .53394 L .32009 .53389 L F
.722 .636 .761 r
.32014 .53386 m .31998 .53396 L .31724 .53464 L F
.32081 .53367 m .32004 .53394 L .32014 .53386 L F
.046 0 0 r
.31998 .53396 m .32004 .53394 L .32009 .53391 L F
.722 .636 .761 r
.32004 .53394 m .31998 .53396 L .32014 .53386 L F
.31998 .53396 m .31786 .5347 L .31724 .53464 L F
.568 .44 .667 r
.32137 .53502 m .31858 .5379 L .31724 .53464 L F
.046 0 0 r
.31584 .53591 m .31998 .53396 L .31724 .53464 L F
.614 .925 .68 r
.32009 .53389 m .31878 .53476 L .32043 .53299 L F
.046 0 0 r
.31603 .53583 m .31694 .53595 L .31913 .53453 L F
.31584 .53591 m .31694 .53595 L .31603 .53583 L F
.517 .076 .139 r
.31858 .5379 m .32093 .53824 L .32274 .53658 L F
.568 .44 .667 r
.32137 .53502 m .32093 .53824 L .31858 .5379 L F
0 0 0 r
.31722 .53974 m .31528 .54092 L .31352 .54144 L F
.31854 .53795 m .31826 .5382 L .31825 .53821 L F
.31858 .5379 m .31584 .54047 L .31854 .53795 L F
.31961 .53782 m .31858 .5379 L .32093 .53824 L F
.31961 .53782 m .31584 .54047 L .31858 .5379 L F
.724 .6 .717 r
.31584 .53591 m .31584 .53872 L .31961 .53782 L F
0 0 0 r
.31825 .53821 m .31584 .54047 L .31528 .54092 L F
.31826 .5382 m .31584 .54047 L .31825 .53821 L F
.724 .6 .717 r
.31584 .53872 m .31584 .54047 L .31961 .53782 L F
.31584 .53591 m .31961 .53782 L .31787 .53816 L F
.192 .718 .716 r
.31953 .53778 m .31864 .53798 L .31961 .53782 L F
.86 .979 .681 r
.32274 .53658 m .32093 .53824 L .32398 .53372 L F
.728 .588 .699 r
.32398 .53372 m .32093 .53824 L .32137 .53502 L F
.192 .718 .716 r
.3225 .53709 m .31953 .53778 L .31961 .53782 L F
.31864 .53798 m .31787 .53816 L .31857 .53803 L F
.31864 .53798 m .31857 .53803 L .31961 .53782 L F
.684 .709 .867 r
.31321 .53936 m .31551 .54078 L .31584 .54047 L F
.465 .424 .728 r
.31584 .54047 m .31494 .54345 L .31528 .54092 L F
.684 .709 .867 r
.31628 .54127 m .31568 .54297 L .31732 .54191 L F
.502 0 0 r
.31568 .54297 m .31688 .54225 L .31732 .54191 L F
.31494 .54345 m .31694 .54221 L .31568 .54297 L F
.684 .709 .867 r
.31628 .54126 m .31494 .54345 L .31568 .54297 L F
.31628 .54126 m .31568 .54297 L .31628 .54127 L F
.465 .424 .728 r
.31584 .54047 m .31684 .54227 L .31494 .54345 L F
.394 .391 .738 r
.31728 .5415 m .31688 .54225 L .31629 .54124 L F
.143 .432 .871 r
.31732 .54191 m .31907 .54197 L .31584 .54047 L F
.839 .971 .658 r
.31729 .54156 m .31723 .54161 L .31728 .5415 L F
.502 0 0 r
.31688 .54225 m .31695 .5422 L .31732 .54191 L F
.839 .971 .658 r
.31732 .54191 m .31695 .5422 L .31729 .54156 L F
.106 .517 .909 r
.31728 .5415 m .31907 .54197 L .31732 .54191 L F
.684 .709 .867 r
.31628 .54126 m .31732 .54191 L .31584 .54047 L F
.394 .391 .738 r
.31907 .54197 m .31629 .54124 L .31646 .54076 L F
.106 .517 .909 r
.31719 .54056 m .31907 .54197 L .31728 .5415 L F
.31719 .54056 m .31907 .54197 L .31732 .54191 L F
.394 .391 .738 r
.31907 .54197 m .31629 .54124 L .31629 .54124 L F
.31786 .54165 m .31694 .54221 L .31728 .5415 L F
.502 0 0 r
.31688 .54225 m .31694 .54221 L .31695 .5422 L F
.394 .391 .738 r
.31694 .54221 m .31688 .54225 L .31728 .5415 L F
.465 .424 .728 r
.31628 .54126 m .31758 .54344 L .31748 .54344 L F
.31629 .54124 m .31758 .54344 L .31628 .54126 L F
.502 0 0 r
.31494 .54345 m .31672 .54505 L .31498 .54374 L F
.42 .096 .308 r
.31758 .54344 m .31672 .54505 L .31494 .54345 L F
.839 .971 .658 r
.31728 .5415 m .31498 .54374 L .31719 .54056 L F
.31723 .54161 m .31498 .54374 L .31728 .5415 L F
.465 .424 .728 r
.31684 .54227 m .31688 .54235 L .31494 .54345 L F
.31688 .54235 m .3163 .54345 L .31494 .54345 L F
.502 0 0 r
.31494 .54345 m .31498 .54374 L .31694 .54221 L F
.839 .971 .658 r
.31695 .5422 m .31498 .54374 L .31729 .54156 L F
.465 .424 .728 r
.31688 .54235 m .31748 .54344 L .3163 .54345 L F
.394 .391 .738 r
.31907 .54197 m .31758 .54344 L .31688 .54225 L F
.31907 .54197 m .31688 .54225 L .31786 .54165 L F
.31646 .54076 m .31629 .54124 L .31584 .54047 L F
.436 .085 .27 r
.31494 .54345 m .31352 .54144 L .31528 .54092 L F
.684 .709 .867 r
.31321 .53936 m .31494 .54345 L .31628 .54126 L F
.465 .424 .728 r
.31584 .54047 m .31629 .54124 L .31628 .54126 L F
.684 .709 .867 r
.31551 .54078 m .31628 .54126 L .31584 .54047 L F
.808 .962 .638 r
.31584 .53591 m .31321 .53936 L .31315 .53663 L F
.842 .696 .701 r
.31321 .53936 m .31584 .53591 L .31315 .53663 L F
.31321 .53936 m .31584 .54047 L .31584 .53591 L F
.808 .962 .638 r
.3155 .53636 m .31346 .53789 L .31321 .53936 L F
.31584 .53591 m .31542 .53626 L .3155 .53636 L F
.31542 .53626 m .31346 .53789 L .3155 .53636 L F
.61 .123 .073 r
.31787 .53816 m .31346 .53789 L .31542 .53626 L F
.31771 .53799 m .31542 .53626 L .31584 .53591 L F
.31787 .53816 m .31542 .53626 L .31771 .53799 L F
.229 0 0 r
.31508 .5347 m .31315 .53663 L .31584 .53591 L F
0 .186 .636 r
.31153 .53281 m .31584 .53591 L .31315 .53663 L F
.386 .372 .721 r
.31281 .53395 m .31699 .5374 L .3154 .53547 L F
.31275 .53391 m .31284 .53399 L .31281 .53395 L F
.31284 .53399 m .31699 .5374 L .31281 .53395 L F
.837 .388 .154 r
.31719 .54056 m .31346 .53789 L .31787 .53816 L F
.31436 .53854 m .31492 .5398 L .31346 .53789 L F
.31719 .54056 m .31492 .5398 L .31436 .53854 L F
.436 .085 .27 r
.31494 .54345 m .31244 .54403 L .31352 .54144 L F
.473 .121 .287 r
.31352 .54144 m .31244 .54403 L .30977 .54431 L F
.769 .751 .837 r
.31037 .54239 m .31494 .54345 L .31321 .53936 L F
.857 .766 .761 r
.31719 .54056 m .31345 .54191 L .31492 .5398 L F
.342 0 .08 r
.31494 .54345 m .3115 .5454 L .31244 .54403 L F
.407 0 .117 r
.31244 .54403 m .3115 .5454 L .30977 .54431 L F
0 .175 .695 r
.31037 .54239 m .3115 .5454 L .31494 .54345 L F
.857 .766 .761 r
.31719 .54056 m .31498 .54374 L .31345 .54191 L F
0 0 .474 r
.31492 .5398 m .3158 .54206 L .31576 .54171 L F
.31492 .5398 m .31576 .54171 L .31544 .53851 L F
0 0 .155 r
.31492 .5398 m .31533 .53698 L .31346 .53789 L F
.31533 .53698 m .31547 .53602 L .31494 .53651 L F
.31533 .53698 m .31494 .53651 L .31346 .53789 L F
.386 .372 .721 r
.315 .53576 m .31547 .53602 L .31699 .5374 L F
.31275 .53391 m .31474 .53545 L .315 .53576 L F
.31474 .53545 m .31547 .53602 L .315 .53576 L F
.61 .123 .073 r
.31692 .53714 m .31584 .53591 L .3154 .53547 L F
.39 .812 .629 r
.31547 .53602 m .31571 .53588 L .31699 .5374 L F
.61 .123 .073 r
.3172 .53744 m .31613 .53624 L .31692 .53714 L F
.31742 .53767 m .31613 .53624 L .3172 .53744 L F
.31613 .53624 m .31584 .53591 L .31692 .53714 L F
0 0 .284 r
.31694 .53595 m .31699 .53721 L .31773 .53606 L F
.039 .075 .57 r
.31584 .53591 m .31787 .53816 L .31694 .53595 L F
0 0 .284 r
.31699 .53721 m .31706 .53729 L .31773 .53606 L F
.046 0 0 r
.31584 .53591 m .31913 .53453 L .31855 .53464 L F
.614 .925 .68 r
.31878 .53476 m .31694 .53595 L .31976 .53356 L F
.572 .898 .644 r
.32043 .53299 m .31694 .53595 L .31885 .534 L F
0 0 .284 r
.31694 .53595 m .31773 .53606 L .31885 .534 L F
0 .186 .636 r
.31153 .53281 m .3154 .53547 L .31584 .53591 L F
0 .526 .836 r
.3154 .53547 m .31694 .53595 L .31584 .53591 L F
.39 .812 .629 r
.31571 .53588 m .31885 .534 L .31706 .53729 L F
.61 .123 .073 r
.31787 .53816 m .3154 .53547 L .31699 .5374 L F
0 0 .284 r
.31699 .53721 m .31699 .5374 L .31706 .53729 L F
.39 .812 .629 r
.31571 .53588 m .31706 .53729 L .31699 .5374 L F
.61 .123 .073 r
.31787 .53816 m .31742 .53767 L .3172 .53744 L F
.614 .925 .68 r
.31878 .53476 m .31976 .53356 L .32043 .53299 L F
.53 0 0 r
.31885 .534 m .32052 .53418 L .32043 .53299 L F
.32052 .53418 m .3226 .53441 L .32043 .53299 L F
0 0 .032 r
.32036 .5321 m .32043 .53299 L .32068 .52998 L F
.32012 .53367 m .32043 .53299 L .32036 .5321 L F
.614 .925 .68 r
.32004 .53394 m .31878 .53476 L .32009 .53389 L F
.22 .371 .803 r
.31724 .53464 m .31715 .53488 L .31508 .5347 L F
.31715 .53488 m .31542 .53519 L .31508 .5347 L F
.499 .371 .637 r
.40171 .67536 m .4024 .67787 L .40003 .67831 L F
.12 .453 .884 r
.23272 .61751 m .23354 .61665 L .22992 .61487 L F
.23272 .61751 m .23395 .61793 L .23354 .61665 L F
.289 .045 .36 r
.20276 .56653 m .2054 .56337 L .2036 .56397 L F
0 0 .15 r
.41671 .53751 m .41687 .54067 L .41652 .54215 L F
.234 0 0 r
.41854 .54391 m .41887 .54415 L .42283 .54468 L F
0 .196 .726 r
.41687 .54067 m .41887 .54415 L .41652 .54215 L F
0 .073 .554 r
.41652 .54215 m .41887 .54415 L .41854 .54391 L F
.931 .885 .765 r
.35596 .588 m .35725 .58957 L .35493 .59315 L F
.124 0 .214 r
.35493 .59315 m .35725 .58957 L .35662 .59168 L F
.187 0 .242 r
.35932 .58892 m .35725 .58957 L .35662 .59168 L F
.871 .87 .833 r
.68896 .3214 m .68648 .32162 L .68767 .31996 L F
.448 .85 .972 r
.32489 .66907 m .32871 .66892 L .32722 .66836 L F
.478 .671 .949 r
.32871 .66892 m .32949 .66695 L .32722 .66836 L F
.32871 .66892 m .33146 .6689 L .32949 .66695 L F
.738 .337 .289 r
.36774 .57634 m .37036 .57844 L .37173 .57687 L F
.64 .457 .621 r
.36177 .62446 m .36435 .62355 L .3645 .62142 L F
0 .011 .567 r
.36364 .61802 m .3645 .62142 L .36536 .61983 L F
.448 .295 .58 r
.3645 .62142 m .36689 .62072 L .36536 .61983 L F
.3645 .62142 m .36435 .62355 L .36689 .62072 L F
.36689 .62072 m .36435 .62355 L .3645 .62142 L F
.505 .532 .818 r
.4305 .52135 m .42842 .52351 L .4272 .51995 L F
.537 .505 .768 r
.4305 .52135 m .42924 .52603 L .42842 .52351 L F
.837 .775 .793 r
.62398 .40525 m .62742 .40574 L .62622 .4022 L F
.699 .199 .05 r
.62595 .40707 m .62742 .40574 L .62398 .40525 L F
.803 .759 .812 r
.62622 .4022 m .62742 .40574 L .62994 .40267 L F
.614 .468 .66 r
.62742 .40574 m .63073 .40593 L .62994 .40267 L F
.358 .302 .658 r
.62994 .40267 m .63073 .40593 L .6316 .40552 L F
.515 .235 .428 r
.62997 .40768 m .6316 .40552 L .62742 .40574 L F
.216 .441 .863 r
.21705 .60795 m .21618 .60458 L .21515 .60452 L F
.21705 .60795 m .21841 .60797 L .21618 .60458 L F
.649 .519 .692 r
.3792 .58413 m .38194 .58412 L .38186 .58072 L F
.566 .181 .272 r
.38175 .5855 m .38194 .58412 L .3792 .58413 L F
0 .283 .709 r
.38021 .58437 m .3792 .58413 L .37757 .58279 L F
.38021 .58437 m .38175 .5855 L .3792 .58413 L F
.714 .232 .1 r
.29531 .62399 m .2939 .6256 L .29253 .62344 L F
.921 .55 .297 r
.29531 .62399 m .29676 .62677 L .29722 .62681 L F
.783 .323 .152 r
.29531 .62399 m .29722 .62681 L .2939 .6256 L F
.353 .387 .757 r
.40059 .65849 m .39972 .66258 L .399 .6589 L F
.40059 .65849 m .40171 .6608 L .39972 .66258 L F
.32 .331 .715 r
.40171 .6608 m .40236 .66474 L .39972 .66258 L F
.438 .333 .638 r
.39972 .66258 m .40236 .66474 L .40018 .66534 L F
.248 0 .111 r
.38718 .60917 m .38505 .60953 L .38434 .61105 L F
.754 .552 .623 r
.23659 .57939 m .23276 .57697 L .2353 .57656 L F
.23659 .57939 m .23264 .5802 L .23276 .57697 L F
.781 .676 .748 r
.23659 .57939 m .23414 .58318 L .23264 .5802 L F
.528 .551 .822 r
.23796 .57773 m .23659 .57939 L .2353 .57656 L F
.656 .557 .731 r
.23724 .5748 m .23851 .57788 L .2367 .57714 L F
.23782 .57427 m .23851 .57788 L .23724 .5748 L F
.547 .383 .611 r
.23536 .57379 m .2353 .57656 L .23724 .5748 L F
.23536 .57379 m .23724 .5748 L .23761 .57319 L F
.656 .557 .731 r
.23761 .57319 m .2367 .57714 L .2353 .57656 L F
.211 .244 .679 r
.23856 .5755 m .23973 .57526 L .23761 .57319 L F
.102 0 .208 r
.23856 .5755 m .23856 .57551 L .23973 .57526 L F
.212 .245 .678 r
.23973 .57526 m .23915 .5765 L .23868 .57548 L F
.23855 .5755 m .23851 .57788 L .23796 .57503 L F
.528 .551 .822 r
.23796 .57773 m .2353 .57656 L .23851 .57788 L F
.49 .218 .428 r
.2353 .57656 m .23717 .5782 L .23856 .57551 L F
.23855 .5755 m .23856 .57551 L .23856 .5755 L F
.2353 .57656 m .23856 .57551 L .23855 .5755 L F
.212 .245 .678 r
.23855 .57549 m .23855 .5755 L .23782 .57427 L F
.23855 .5755 m .23796 .57503 L .23782 .57427 L F
.23915 .5765 m .23905 .57672 L .23855 .57549 L F
.23905 .57672 m .23851 .57788 L .23855 .57549 L F
.547 .383 .611 r
.23855 .57549 m .23856 .5755 L .23761 .57319 L F
.23855 .57549 m .23855 .5755 L .23856 .5755 L F
.212 .245 .678 r
.23915 .5765 m .23782 .57427 L .23761 .57319 L F
.656 .557 .731 r
.23761 .57319 m .23782 .57427 L .23724 .5748 L F
.547 .383 .611 r
.23724 .5748 m .23855 .57549 L .23761 .57319 L F
.102 0 .208 r
.23856 .57551 m .23717 .5782 L .23973 .57526 L F
.212 .245 .678 r
.23973 .57526 m .23868 .57548 L .23761 .57319 L F
.547 .383 .611 r
.23724 .5748 m .2353 .57656 L .23855 .5755 L F
.23724 .5748 m .23855 .5755 L .23855 .57549 L F
.579 .569 .806 r
.24297 .58269 m .23822 .57799 L .24281 .5801 L F
.23822 .57799 m .23796 .57773 L .2383 .5779 L F
.23822 .57799 m .2383 .5779 L .24281 .5801 L F
.44 .634 .937 r
.24064 .57798 m .24281 .5801 L .23908 .57828 L F
.579 .569 .806 r
.24297 .58269 m .24056 .58324 L .23796 .57773 L F
.682 .715 .874 r
.24537 .57945 m .24281 .5801 L .24064 .57798 L F
.24537 .57945 m .24064 .57798 L .24386 .57699 L F
.508 .308 .544 r
.24034 .58154 m .24282 .57756 L .24064 .57798 L F
.29 .785 .759 r
.24064 .57798 m .24308 .57714 L .24386 .57699 L F
.508 .308 .544 r
.24282 .57756 m .24308 .57714 L .24064 .57798 L F
.44 .634 .937 r
.24064 .57798 m .23908 .57828 L .2383 .5779 L F
.23834 .57776 m .2383 .5779 L .23796 .57773 L F
.839 .996 .838 r
.23867 .57753 m .23827 .57793 L .23851 .57788 L F
.44 .634 .937 r
.24064 .57798 m .2383 .5779 L .23834 .57776 L F
.839 .996 .838 r
.23832 .57785 m .23823 .57794 L .23827 .57793 L F
.23941 .57594 m .23834 .57777 L .23832 .57785 L F
.23834 .57777 m .23823 .57794 L .23832 .57785 L F
.23837 .57775 m .23827 .57793 L .2385 .57771 L F
.602 .552 .771 r
.23814 .57811 m .23659 .57939 L .23796 .57773 L F
.24056 .58324 m .2371 .57988 L .23814 .57811 L F
.351 0 0 r
.23834 .57776 m .23717 .5782 L .24064 .57798 L F
.23796 .57773 m .23717 .5782 L .23834 .57776 L F
.839 .996 .838 r
.23941 .57594 m .23837 .57775 L .23867 .57753 L F
.23837 .57775 m .2385 .57771 L .23867 .57753 L F
.23973 .57526 m .23717 .5782 L .23823 .57794 L F
.23973 .57526 m .23823 .57794 L .23941 .57594 L F
.602 .552 .771 r
.2371 .57988 m .23659 .57939 L .23814 .57811 L F
.622 .659 .865 r
.37379 .51226 m .37067 .51368 L .369 .51071 L F
.653 .126 0 r
.22579 .58472 m .2298 .58548 L .22764 .58374 L F
.576 .241 .365 r
.22764 .58374 m .2298 .58548 L .23008 .58348 L F
.394 .305 .636 r
.34197 .53767 m .33927 .53626 L .34205 .53536 L F
.34197 .53767 m .33952 .53883 L .33927 .53626 L F
.384 .316 .657 r
.42599 .51335 m .42427 .51667 L .42236 .51284 L F
.42599 .51335 m .42625 .51606 L .42427 .51667 L F
.444 .226 .487 r
.63674 .40814 m .63447 .40599 L .6364 .40504 L F
.26 0 0 r
.23159 .55865 m .23085 .55852 L .22864 .55787 L F
0 .387 .823 r
.23159 .55865 m .23493 .56049 L .23336 .55899 L F
.23159 .55865 m .23336 .55899 L .23085 .55852 L F
0 0 0 r
.3531 .53935 m .35355 .53886 L .35576 .53884 L F
.478 .254 .495 r
.35415 .53805 m .35179 .53905 L .35186 .53563 L F
.104 .315 .789 r
.35179 .53905 m .35304 .53944 L .35231 .5365 L F
.35304 .53944 m .35372 .53965 L .35343 .539 L F
.35304 .53944 m .35343 .539 L .35231 .5365 L F
0 0 0 r
.3531 .53935 m .35223 .54034 L .35355 .53886 L F
.35223 .54034 m .35186 .54076 L .35298 .5395 L F
.35223 .54034 m .35298 .5395 L .35355 .53886 L F
.639 .966 .871 r
.31545 .65437 m .31218 .65593 L .31414 .65476 L F
.241 .698 .951 r
.31732 .65429 m .31545 .65437 L .31414 .65476 L F
.617 .531 .734 r
.41891 .52582 m .41817 .52918 L .41596 .5301 L F
.41891 .52582 m .42051 .53021 L .41817 .52918 L F
.073 0 0 r
.42051 .53021 m .41596 .5301 L .41817 .52918 L F
.865 .812 .795 r
.69401 .31446 m .68995 .3164 L .69196 .31322 L F
.69401 .31446 m .69162 .31812 L .68995 .3164 L F
.435 .226 .495 r
.72122 .35612 m .71863 .35531 L .72132 .3543 L F
.72122 .35612 m .71865 .35754 L .71863 .35531 L F
0 0 0 r
.64613 .43427 m .64882 .43078 L .64869 .43301 L F
.063 0 .158 r
.64613 .43427 m .64869 .43301 L .64615 .43631 L F
.98 .858 .646 r
.31786 .66476 m .31904 .66614 L .31785 .66883 L F
.513 .127 .246 r
.32154 .54781 m .32407 .5493 L .32415 .54762 L F
.664 .805 .95 r
.40953 .5105 m .40511 .50823 L .40806 .50676 L F
.40953 .5105 m .40689 .51069 L .40511 .50823 L F
0 0 0 r
.40953 .5105 m .40647 .5125 L .40689 .51069 L F
.40953 .5105 m .4086 .51173 L .40647 .5125 L F
.543 .51 .769 r
.41075 .50592 m .40953 .5105 L .40806 .50676 L F
.41075 .50592 m .41186 .5098 L .40953 .5105 L F
.512 .009 0 r
.41069 .51124 m .4086 .51173 L .40953 .5105 L F
.927 .737 .626 r
.35614 .56456 m .354 .56372 L .35654 .56322 L F
.811 .744 .789 r
.6798 .3294 m .68071 .33316 L .67701 .3327 L F
.817 .728 .766 r
.68071 .33316 m .67837 .33631 L .67701 .3327 L F
.554 .101 .131 r
.35878 .5597 m .36224 .55966 L .36303 .55765 L F
0 0 0 r
.36224 .55966 m .36477 .55646 L .36303 .55765 L F
.559 .474 .715 r
.62624 .43438 m .63101 .43769 L .63027 .43401 L F
.83 .908 .892 r
.70388 .30179 m .69971 .30331 L .70234 .30013 L F
.804 .821 .865 r
.70686 .29898 m .70388 .30179 L .70234 .30013 L F
.938 .898 .761 r
.43172 .57582 m .43015 .57873 L .43175 .57973 L F
0 0 .564 r
.43096 .57768 m .43015 .57873 L .43088 .57743 L F
.398 .783 .99 r
.43175 .57973 m .43015 .57873 L .42962 .57941 L F
.774 .681 .761 r
.43175 .57973 m .42733 .57908 L .43015 .57873 L F
.43175 .57973 m .42869 .58327 L .42733 .57908 L F
.618 .445 .626 r
.43142 .58277 m .42869 .58327 L .43175 .57973 L F
.848 .413 .19 r
.43015 .57873 m .43322 .58073 L .43175 .57973 L F
.57 .472 .704 r
.43322 .58073 m .43142 .58277 L .43175 .57973 L F
.848 .413 .19 r
.43015 .57873 m .43198 .58178 L .43322 .58073 L F
0 0 .564 r
.43174 .5803 m .43015 .57873 L .43096 .57768 L F
.398 .783 .99 r
.42962 .57941 m .43015 .57873 L .42733 .57908 L F
.522 .195 .354 r
.23008 .58348 m .23245 .58491 L .23414 .58318 L F
.499 .544 .834 r
.23264 .5802 m .23414 .58318 L .23554 .58181 L F
.504 .21 .4 r
.23245 .58491 m .23554 .58181 L .23414 .58318 L F
.21 .136 .549 r
.62411 .42992 m .62223 .42821 L .62478 .42668 L F
.62411 .42992 m .62288 .43061 L .62223 .42821 L F
.412 .268 .574 r
.23276 .57697 m .23487 .57905 L .2353 .57656 L F
.23276 .57697 m .23264 .5802 L .23487 .57905 L F
.587 .279 .414 r
.23843 .58963 m .23605 .59124 L .23552 .58964 L F
0 0 .423 r
.236 .58802 m .23552 .58964 L .23605 .59124 L F
.236 .58802 m .23511 .59172 L .23552 .58964 L F
.366 .792 .972 r
.37462 .71302 m .37539 .71208 L .3733 .71299 L F
.222 0 .124 r
.37528 .7122 m .3733 .71299 L .37539 .71208 L F
.183 .711 .703 r
.37108 .71387 m .37462 .71302 L .3733 .71299 L F
.222 0 .124 r
.3716 .71627 m .3733 .71299 L .37528 .7122 L F
.183 .711 .703 r
.37097 .7139 m .37108 .71387 L .3733 .71299 L F
.366 .792 .972 r
.37462 .71302 m .37718 .71273 L .37539 .71208 L F
.719 .987 .878 r
.22864 .55787 m .23212 .55525 L .22701 .55431 L F
.22864 .55787 m .22911 .55631 L .23212 .55525 L F
.394 0 0 r
.23085 .55852 m .22911 .55631 L .22864 .55787 L F
.469 0 0 r
.36444 .52431 m .36996 .52373 L .36523 .52538 L F
.36744 .524 m .36778 .52471 L .36996 .52373 L F
.82 .999 .788 r
.36996 .52373 m .36778 .52471 L .37005 .52198 L F
.67 .585 .751 r
.36778 .52471 m .37074 .52474 L .37005 .52198 L F
.599 .335 .488 r
.37074 .52474 m .36766 .52732 L .36778 .52471 L F
.585 .581 .815 r
.3688 .52283 m .36814 .52544 L .36778 .52471 L F
.36814 .52544 m .36766 .52732 L .36778 .52471 L F
.469 0 0 r
.36444 .52431 m .36778 .52471 L .36744 .524 L F
.996 .768 .47 r
.62394 .43701 m .62392 .44008 L .62517 .44084 L F
.504 0 0 r
.62778 .44017 m .62394 .43701 L .62517 .44084 L F
.432 0 0 r
.62392 .44008 m .62778 .44017 L .62517 .44084 L F
.685 .65 .809 r
.33119 .50366 m .33297 .50732 L .33607 .50562 L F
.106 0 .112 r
.23747 .57256 m .23536 .57379 L .23761 .57319 L F
.23747 .57256 m .23564 .57383 L .23536 .57379 L F
0 .463 .843 r
.23536 .57379 m .23564 .57383 L .23101 .57172 L F
.656 .557 .731 r
.23761 .57319 m .2353 .57656 L .23536 .57379 L F
.802 .65 .694 r
.55775 .41578 m .55349 .41787 L .55716 .41474 L F
.55775 .41578 m .5574 .41845 L .55349 .41787 L F
.076 .212 .703 r
.62091 .42194 m .61962 .41753 L .61712 .42125 L F
.517 .795 .996 r
.61748 .42076 m .62091 .42194 L .61712 .42125 L F
.261 .44 .85 r
.62242 .42011 m .62091 .42194 L .61748 .42076 L F
.62242 .42011 m .62397 .42357 L .62091 .42194 L F
.634 .935 .691 r
.26355 .5359 m .26132 .53734 L .26022 .53879 L F
.922 .975 .715 r
.26342 .53355 m .26132 .53734 L .26355 .5359 L F
0 0 .147 r
.26159 .55722 m .26334 .55422 L .2609 .55488 L F
.553 .914 .957 r
.63209 .44148 m .63341 .43988 L .63449 .44031 L F
.63209 .44148 m .62933 .44121 L .63341 .43988 L F
.995 .765 .464 r
.37591 .51439 m .3775 .51368 L .37536 .51284 L F
.37591 .51439 m .37718 .51599 L .3775 .51368 L F
.519 .335 .572 r
.43142 .58277 m .42898 .58657 L .42869 .58327 L F
.76 .996 .828 r
.33667 .57086 m .33376 .57368 L .33457 .5713 L F
.63 .542 .736 r
.33667 .57086 m .33701 .57335 L .33376 .57368 L F
.592 .363 .538 r
.33701 .57335 m .33383 .57631 L .33376 .57368 L F
.478 .537 .839 r
.40583 .5151 m .40692 .5176 L .40412 .5173 L F
.185 0 0 r
.70977 .34829 m .71239 .34735 L .71293 .3456 L F
.193 0 0 r
.71293 .3456 m .71504 .34623 L .71488 .34386 L F
.71293 .3456 m .71239 .34735 L .71504 .34623 L F
.296 .293 .687 r
.37832 .5928 m .38 .59252 L .37921 .58871 L F
.299 .312 .706 r
.37832 .5928 m .38059 .59505 L .38 .59252 L F
.505 .339 .589 r
.37832 .5928 m .38059 .59505 L .37816 .59561 L F
.37832 .5928 m .38059 .59505 L .37816 .59561 L F
0 .481 .791 r
.24959 .62819 m .25077 .62815 L .24807 .62723 L F
.24959 .62819 m .25244 .62887 L .25077 .62815 L F
.748 .66 .105 r
.35067 .54216 m .35047 .54265 L .35186 .54076 L F
.569 .328 .511 r
.35035 .54421 m .34834 .54622 L .34832 .54344 L F
.758 .797 .884 r
.35141 .54461 m .35241 .54665 L .35042 .54469 L F
.569 .328 .511 r
.35141 .54461 m .35025 .54522 L .35035 .54421 L F
.35025 .54522 m .34834 .54622 L .35035 .54421 L F
.748 .66 .105 r
.35067 .54216 m .35042 .54469 L .35046 .54316 L F
.35052 .54253 m .35046 .54316 L .35047 .54265 L F
.35067 .54216 m .35046 .54316 L .35052 .54253 L F
.732 .533 .623 r
.56718 .44641 m .56322 .44359 L .56662 .44408 L F
.591 .392 .581 r
.56954 .44353 m .56718 .44641 L .56662 .44408 L F
.293 .791 .796 r
.27355 .52241 m .26948 .52333 L .27189 .52287 L F
.182 .712 .722 r
.27444 .52214 m .27355 .52241 L .27189 .52287 L F
.27444 .52214 m .27584 .52188 L .27355 .52241 L F
.085 0 .187 r
.25313 .55419 m .25074 .55726 L .25121 .55496 L F
.701 .274 .231 r
.33273 .70885 m .33306 .70757 L .33076 .7066 L F
.247 0 .258 r
.29948 .61232 m .29922 .61436 L .2972 .61488 L F
.622 .262 .338 r
.30196 .61372 m .29922 .61436 L .29948 .61232 L F
.774 .316 0 r
.28317 .64343 m .28578 .64537 L .28681 .64336 L F
0 0 0 r
.28837 .64035 m .28681 .64336 L .28859 .64231 L F
.045 0 0 r
.28859 .64231 m .28681 .64336 L .28578 .64537 L F
.562 0 0 r
.32951 .69717 m .33128 .69746 L .33045 .69794 L F
.496 .395 .67 r
.3458 .60435 m .34714 .60492 L .34685 .60232 L F
.766 .76 .249 r
.40362 .6082 m .40294 .6103 L .40273 .61198 L F
.915 .856 .412 r
.40176 .61241 m .40273 .61198 L .40294 .6103 L F
.40176 .61241 m .40193 .61458 L .40273 .61198 L F
0 0 0 r
.33621 .66191 m .33429 .66314 L .33171 .665 L F
.044 .252 .75 r
.34593 .54678 m .34539 .54853 L .34367 .54472 L F
.617 .531 .734 r
.41891 .52582 m .41596 .5301 L .41622 .52628 L F
.712 .593 .722 r
.34284 .55252 m .34428 .55599 L .34657 .55476 L F
.137 0 .083 r
.34428 .55599 m .3456 .55633 L .34657 .55476 L F
.34428 .55599 m .34221 .55786 L .3456 .55633 L F
.147 .06 .492 r
.19905 .57375 m .20031 .57302 L .2003 .57022 L F
.103 .007 .45 r
.19907 .57645 m .20031 .57302 L .19905 .57375 L F
.589 .822 .988 r
.58126 .40165 m .58078 .40345 L .5795 .40212 L F
.58126 .40165 m .58373 .40253 L .58078 .40345 L F
.58126 .40165 m .58078 .40345 L .5795 .40212 L F
.58126 .40165 m .58373 .40253 L .58078 .40345 L F
.405 0 0 r
.62663 .44961 m .63025 .44975 L .62892 .45052 L F
0 0 0 r
.63025 .44975 m .63134 .45017 L .62892 .45052 L F
.63025 .44975 m .63264 .44902 L .63134 .45017 L F
.144 0 0 r
.29564 .64278 m .29891 .64014 L .29827 .64246 L F
0 0 .154 r
.29827 .64246 m .29891 .64014 L .30071 .63909 L F
.844 .479 .363 r
.33848 .70948 m .34091 .70983 L .33912 .71188 L F
.75 .346 .286 r
.34091 .70983 m .34285 .71253 L .33912 .71188 L F
.571 .323 .501 r
.34091 .70983 m .34317 .70966 L .34285 .71253 L F
.542 .33 .541 r
.3219 .56103 m .32168 .56378 L .31912 .56411 L F
.659 .694 .871 r
.32274 .55784 m .3219 .56103 L .32035 .55741 L F
.32274 .55784 m .32442 .56114 L .3219 .56103 L F
.54 .248 .42 r
.32442 .56114 m .32168 .56378 L .3219 .56103 L F
.672 .469 .602 r
.69308 .35556 m .69294 .35755 L .68888 .35858 L F
.646 .452 .607 r
.69538 .3551 m .69294 .35755 L .69308 .35556 L F
.712 .593 .722 r
.34284 .55252 m .34657 .55476 L .34482 .55201 L F
0 .065 .616 r
.34482 .55201 m .34657 .55476 L .34601 .55357 L F
.504 .783 .995 r
.34601 .55357 m .34894 .55429 L .34657 .55476 L F
.21 .084 .481 r
.3456 .55633 m .34601 .55357 L .34657 .55476 L F
.654 .114 0 r
.36475 .64451 m .36593 .64341 L .36412 .64352 L F
.113 0 0 r
.36593 .64341 m .36556 .64456 L .36412 .64352 L F
.196 0 0 r
.36661 .64469 m .36593 .64341 L .36475 .64451 L F
.36661 .64469 m .36835 .64289 L .36593 .64341 L F
.113 0 0 r
.36593 .64341 m .36835 .64289 L .36556 .64456 L F
.573 .38 .582 r
.32689 .63069 m .32684 .63365 L .32426 .63367 L F
0 .102 .653 r
.32768 .63074 m .32689 .63069 L .3252 .63015 L F
.32768 .63074 m .32931 .63322 L .32689 .63069 L F
.483 .307 .567 r
.32689 .63069 m .32931 .63322 L .32684 .63365 L F
.669 .231 .2 r
.34317 .70966 m .34711 .71004 L .3457 .71226 L F
.69 .255 .212 r
.34711 .71004 m .34951 .71228 L .3457 .71226 L F
0 0 0 r
.31419 .64837 m .31719 .64672 L .31644 .6497 L F
.31719 .64672 m .31794 .64239 L .31824 .64601 L F
0 0 .134 r
.31644 .6497 m .31719 .64672 L .31824 .64601 L F
.636 .417 .568 r
.68242 .35846 m .6799 .36132 L .67985 .35848 L F
.68242 .35846 m .68263 .36133 L .6799 .36132 L F
.627 .346 .473 r
.68242 .35846 m .68647 .36037 L .68263 .36133 L F
.68242 .35846 m .68667 .35806 L .68647 .36037 L F
0 0 .144 r
.35824 .67426 m .3587 .67691 L .35864 .67689 L F
0 0 0 r
.35864 .67689 m .358 .6797 L .3587 .67691 L F
.36095 .67407 m .3587 .67691 L .35864 .67689 L F
.35864 .67689 m .358 .6797 L .3587 .67691 L F
0 .06 .624 r
.43051 .57346 m .42986 .57368 L .42825 .57277 L F
.43051 .57346 m .43172 .57582 L .42986 .57368 L F
0 0 0 r
.22012 .5707 m .22285 .57014 L .22272 .57011 L F
.749 .234 0 r
.35592 .52816 m .35359 .52605 L .35609 .52602 L F
.549 .438 .68 r
.33799 .59225 m .34034 .58874 L .33769 .58945 L F
.935 .937 .587 r
.28392 .62308 m .28395 .62425 L .28552 .62105 L F
0 0 0 r
.28566 .62238 m .28552 .62105 L .28737 .62191 L F
.28566 .62238 m .28392 .62308 L .28552 .62105 L F
.37027 .56114 m .36937 .56281 L .36776 .56182 L F
.37 .115 .392 r
.34893 .59916 m .35238 .59775 L .35167 .59512 L F
0 0 0 r
.35493 .59315 m .35167 .59512 L .35329 .59422 L F
.321 .088 .396 r
.35167 .59512 m .35395 .59697 L .35329 .59422 L F
.35167 .59512 m .35238 .59775 L .35395 .59697 L F
.933 .927 .559 r
.35508 .56876 m .3552 .57045 L .3563 .56832 L F
.35508 .56876 m .3552 .57045 L .3563 .56832 L F
.807 .329 .073 r
.32603 .61668 m .3233 .61402 L .32391 .61667 L F
.915 .633 .493 r
.37066 .62388 m .37262 .62524 L .37114 .62646 L F
.324 0 .199 r
.39414 .70002 m .39105 .70222 L .39196 .70107 L F
.421 .007 .146 r
.4286 .53882 m .4267 .54051 L .42542 .53916 L F
0 0 .55 r
.42542 .53916 m .4267 .54051 L .42573 .53871 L F
.687 .272 .254 r
.32024 .63348 m .32426 .63367 L .32217 .63616 L F
.412 0 .004 r
.32426 .63367 m .32513 .63572 L .32217 .63616 L F
.32426 .63367 m .32684 .63365 L .32513 .63572 L F
.556 .333 .532 r
.36418 .54485 m .36144 .54758 L .36063 .54503 L F
.36418 .54485 m .36384 .54734 L .36144 .54758 L F
.486 .272 .513 r
.36715 .54188 m .3666 .54455 L .36418 .54485 L F
.184 .018 .408 r
.3676 .54484 m .36418 .54485 L .3666 .54455 L F
.3676 .54484 m .36384 .54734 L .36418 .54485 L F
.704 .891 .965 r
.26562 .52945 m .26571 .5318 L .26789 .53121 L F
.26562 .52945 m .26401 .53103 L .26571 .5318 L F
0 0 0 r
.28261 .64049 m .28441 .63628 L .28391 .63872 L F
0 0 .481 r
.28424 .64206 m .28261 .64049 L .28391 .63872 L F
.6 .609 .832 r
.31301 .5674 m .31542 .56702 L .31396 .56309 L F
.546 .321 .525 r
.31542 .56702 m .31507 .56968 L .31301 .5674 L F
.31301 .5674 m .31507 .56968 L .31542 .56702 L F
.778 .793 .865 r
.33569 .66505 m .33555 .67061 L .34023 .6656 L F
.092 0 0 r
.29026 .52653 m .28615 .5282 L .28777 .52721 L F
.694 .216 .111 r
.36255 .56629 m .36495 .56778 L .36618 .56736 L F
.379 0 0 r
.36495 .56778 m .36892 .56755 L .36618 .56736 L F
.694 .216 .111 r
.36255 .56629 m .36495 .56778 L .36618 .56736 L F
.57 .679 .913 r
.35998 .58633 m .35339 .58345 L .3585 .58249 L F
.763 .713 .806 r
.36266 .58309 m .35998 .58633 L .3585 .58249 L F
0 0 0 r
.36098 .5853 m .35998 .58633 L .36195 .58394 L F
.555 .528 .78 r
.35828 .58536 m .36001 .58666 L .36098 .5853 L F
.813 .688 .726 r
.36098 .5853 m .35932 .58892 L .35998 .58633 L F
.36098 .5853 m .36386 .58945 L .35932 .58892 L F
.555 .528 .78 r
.36001 .58666 m .36197 .58811 L .36098 .5853 L F
0 0 0 r
.36098 .5853 m .36195 .58394 L .36266 .58309 L F
.484 .299 .553 r
.3622 .62711 m .36435 .62355 L .36177 .62446 L F
0 .268 .642 r
.24121 .61144 m .24591 .61377 L .24347 .61296 L F
.969 .739 .536 r
.54978 .43065 m .55122 .43443 L .54962 .43327 L F
.844 .692 .157 r
.55122 .43443 m .55103 .43788 L .54962 .43327 L F
.55122 .43443 m .55112 .43723 L .55103 .43788 L F
.856 .718 .709 r
.55157 .43155 m .55122 .43443 L .54978 .43065 L F
.812 .711 .754 r
.67866 .35489 m .67985 .35848 L .67637 .35802 L F
.729 .537 .632 r
.67985 .35848 m .67752 .36034 L .67637 .35802 L F
.67985 .35848 m .6799 .36132 L .67752 .36034 L F
.486 .725 .977 r
.62577 .38623 m .62328 .38657 L .62179 .38503 L F
0 .048 .616 r
.42698 .5596 m .42706 .56106 L .42541 .55746 L F
0 0 0 r
.42692 .56246 m .42706 .56106 L .42698 .5596 L F
.42692 .56246 m .42674 .56385 L .42706 .56106 L F
.57 .938 .836 r
.231 .53906 m .2319 .53788 L .23264 .53758 L F
.231 .53906 m .22854 .53972 L .2319 .53788 L F
.786 .713 .784 r
.67701 .3327 m .67837 .33631 L .67467 .33574 L F
.735 .515 .594 r
.67837 .33631 m .67416 .33835 L .67467 .33574 L F
.67837 .33631 m .6783 .33888 L .67416 .33835 L F
.627 .526 .72 r
.41888 .50962 m .41996 .51463 L .41639 .51382 L F
.521 .447 .714 r
.31424 .55785 m .31654 .55727 L .31503 .55643 L F
.276 .005 .309 r
.3137 .56047 m .31654 .55727 L .31424 .55785 L F
.563 .669 .909 r
.23643 .56422 m .23675 .56056 L .23493 .56049 L F
.23643 .56422 m .23875 .56364 L .23675 .56056 L F
.362 0 .071 r
.23463 .56608 m .23875 .56364 L .23643 .56422 L F
.493 .22 .428 r
.33591 .59875 m .33569 .60181 L .33319 .60179 L F
.475 .202 .419 r
.34158 .59449 m .33734 .59891 L .33591 .59875 L F
.375 .126 .403 r
.33813 .60096 m .33591 .59875 L .33734 .59891 L F
.33813 .60096 m .33569 .60181 L .33591 .59875 L F
.856 .718 .709 r
.55157 .43155 m .54978 .43065 L .5525 .4303 L F
.159 .404 .848 r
.23722 .62158 m .23988 .62499 L .2403 .62325 L F
.565 .831 .995 r
.2403 .62325 m .23988 .62499 L .24222 .62428 L F
.71 .337 .34 r
.28417 .52905 m .28019 .52962 L .28188 .53002 L F
.139 0 .105 r
.3405 .59761 m .33734 .59891 L .34158 .59449 L F
.655 .855 .976 r
.19946 .60577 m .19674 .60576 L .19767 .60508 L F
.19946 .60577 m .19531 .60575 L .19767 .60508 L F
.516 .518 .797 r
.20011 .60125 m .19946 .60577 L .19767 .60508 L F
.20011 .60125 m .20153 .60585 L .19946 .60577 L F
.629 .098 0 r
.20153 .60585 m .19767 .60508 L .19946 .60577 L F
.511 .856 .994 r
.19531 .60575 m .19946 .60577 L .19767 .60508 L F
.629 .098 0 r
.20153 .60585 m .19964 .60658 L .19767 .60508 L F
.235 .278 .703 r
.19767 .60508 m .19964 .60658 L .19889 .6042 L F
.791 .938 .581 r
.20011 .60125 m .19767 .60508 L .19856 .60312 L F
.235 .278 .703 r
.19767 .60508 m .19889 .6042 L .19856 .60312 L F
.655 .855 .976 r
.19674 .60576 m .19531 .60575 L .19767 .60508 L F
0 0 0 r
.27642 .55154 m .27739 .55047 L .27776 .54871 L F
.477 .881 .95 r
.27642 .55154 m .27479 .55123 L .27739 .55047 L F
.676 .451 .572 r
.27992 .55323 m .27628 .55434 L .27642 .55154 L F
.513 .145 .279 r
.27365 .55289 m .2768 .55326 L .27739 .55047 L F
.2768 .55326 m .27741 .55333 L .27739 .55047 L F
0 0 0 r
.27776 .54871 m .27739 .55047 L .27809 .54801 L F
.656 .922 .976 r
.65148 .41406 m .65066 .41583 L .64953 .41819 L F
.65148 .41406 m .65241 .41506 L .65066 .41583 L F
.59 .387 .573 r
.65241 .41506 m .64953 .41819 L .65066 .41583 L F
.294 .778 .911 r
.3589 .52628 m .36216 .52586 L .36345 .52629 L F
.878 .988 .816 r
.36345 .52629 m .36216 .52586 L .36366 .52361 L F
.186 0 0 r
.3336 .67764 m .32967 .68045 L .3327 .67804 L F
0 0 .063 r
.33603 .67477 m .3336 .67764 L .33531 .67717 L F
0 0 0 r
.33531 .67717 m .3336 .67764 L .3327 .67804 L F
.477 0 .019 r
.31785 .66883 m .32225 .66813 L .32039 .66967 L F
.597 .07 0 r
.32225 .66813 m .32273 .66991 L .32039 .66967 L F
.32225 .66813 m .32489 .66907 L .32273 .66991 L F
0 0 0 r
.30001 .52817 m .29833 .5296 L .30033 .52765 L F
.606 .836 .987 r
.29763 .52837 m .29833 .5296 L .30001 .52817 L F
.615 .253 .332 r
.30001 .52817 m .29937 .52984 L .29763 .52837 L F
.613 .468 .66 r
.29763 .52837 m .29981 .52857 L .29908 .52516 L F
.894 .839 .377 r
.3 .52771 m .29985 .52843 L .30001 .52817 L F
.613 .468 .66 r
.29981 .52857 m .30016 .52861 L .29995 .52793 L F
.29981 .52857 m .29995 .52793 L .29908 .52516 L F
0 0 .511 r
.29908 .52516 m .29995 .52793 L .29999 .52667 L F
.894 .839 .377 r
.29999 .52667 m .29995 .52793 L .3 .52771 L F
0 0 0 r
.30001 .52817 m .30033 .52765 L .30066 .52733 L F
.936 .933 .577 r
.29999 .52667 m .30001 .52817 L .30066 .52733 L F
0 0 .511 r
.29995 .52793 m .30016 .52861 L .29999 .52667 L F
.894 .839 .377 r
.29999 .52667 m .29985 .52843 L .29995 .52793 L F
.29989 .52836 m .29937 .52984 L .30001 .52817 L F
.592 .264 .383 r
.29981 .52857 m .29937 .52984 L .30016 .52861 L F
.29763 .52837 m .29937 .52984 L .29981 .52857 L F
.894 .839 .377 r
.29956 .52889 m .29937 .52984 L .29989 .52836 L F
.29999 .52667 m .29956 .52889 L .29985 .52843 L F
.54 .281 .471 r
.29937 .52984 m .2988 .53016 L .29763 .52837 L F
0 0 .419 r
.29701 .52743 m .29833 .5296 L .29763 .52837 L F
.54 .281 .471 r
.2988 .53016 m .29634 .53153 L .29763 .52837 L F
0 0 .419 r
.29598 .52572 m .29701 .52743 L .29763 .52837 L F
.54 .248 .42 r
.32442 .56114 m .32453 .56341 L .32168 .56378 L F
.551 .256 .42 r
.32695 .56296 m .32453 .56341 L .32442 .56114 L F
.651 .952 .948 r
.28383 .61512 m .28234 .61482 L .28446 .61354 L F
.716 .694 .827 r
.63599 .39305 m .63101 .39304 L .63321 .39262 L F
.184 .395 .835 r
.29429 .65255 m .29613 .65583 L .29758 .65398 L F
.959 .733 .282 r
.66097 .40772 m .66047 .40823 L .6612 .40922 L F
.66049 .40466 m .66047 .40823 L .66097 .40772 L F
0 0 .284 r
.66049 .40466 m .6618 .40602 L .66047 .40823 L F
.662 .867 .484 r
.65998 .40874 m .66047 .40823 L .66139 .40662 L F
.626 .905 .984 r
.65981 .4094 m .66047 .40823 L .65737 .40971 L F
.234 0 .145 r
.65737 .40971 m .66047 .40823 L .65882 .41047 L F
.662 .867 .484 r
.65882 .41047 m .66047 .40823 L .65998 .40874 L F
.66139 .40662 m .66047 .40823 L .6618 .40602 L F
.626 .905 .984 r
.6612 .40922 m .66047 .40823 L .65981 .4094 L F
.907 .981 .778 r
.43199 .56861 m .43113 .57046 L .43234 .57055 L F
.74 .402 .41 r
.55112 .43723 m .55508 .43755 L .55563 .43974 L F
.764 .478 .5 r
.55508 .43755 m .55912 .44012 L .55563 .43974 L F
.808 .751 .8 r
.62622 .4022 m .62994 .40267 L .6286 .3997 L F
.565 .631 .876 r
.6286 .3997 m .62994 .40267 L .63246 .40193 L F
.358 .302 .658 r
.62994 .40267 m .6316 .40552 L .63246 .40193 L F
0 0 .135 r
.41515 .56116 m .41534 .56203 L .41412 .56008 L F
.41515 .56116 m .41559 .56372 L .41534 .56203 L F
0 .114 .575 r
.28791 .65003 m .2904 .65195 L .28894 .65077 L F
.801 .953 .616 r
.33981 .6549 m .34148 .65351 L .33973 .65606 L F
0 0 0 r
.3433 .65266 m .34148 .65351 L .33981 .6549 L F
.038 .237 .738 r
.24277 .58556 m .24056 .58324 L .24297 .58269 L F
0 0 0 r
.37401 .62334 m .37441 .62318 L .37066 .62388 L F
.21 .734 .746 r
.3755 .62282 m .37779 .62241 L .37441 .62318 L F
.3755 .62282 m .37441 .62318 L .37401 .62334 L F
.37 .216 .538 r
.3427 .56006 m .3456 .55633 L .34221 .55786 L F
.108 .206 .685 r
.58686 .40493 m .58791 .40961 L .58536 .40809 L F
.465 0 0 r
.58536 .40809 m .58791 .40961 L .58695 .40922 L F
.482 0 0 r
.58695 .40922 m .58791 .40961 L .59033 .4114 L F
.023 0 .082 r
.31029 .59958 m .30941 .60143 L .30811 .60207 L F
.204 .09 .493 r
.30951 .60428 m .30811 .60207 L .30941 .60143 L F
.30951 .60428 m .30735 .60559 L .30811 .60207 L F
.637 .398 .54 r
.31912 .56411 m .31903 .56699 L .31542 .56702 L F
.582 .353 .534 r
.3216 .56654 m .31912 .56411 L .32168 .56378 L F
.3216 .56654 m .31903 .56699 L .31912 .56411 L F
.569 .48 .715 r
.29857 .54782 m .30142 .54774 L .30096 .54546 L F
.567 .305 .478 r
.29816 .55062 m .30142 .54774 L .29857 .54782 L F
.569 .48 .715 r
.30096 .54546 m .30142 .54774 L .29857 .54782 L F
.567 .305 .478 r
.29816 .55062 m .30142 .54774 L .29857 .54782 L F
.569 .48 .715 r
.29857 .54782 m .30142 .54774 L .30096 .54546 L F
.24 0 0 r
.38255 .51901 m .38293 .51924 L .38527 .51955 L F
0 .118 .584 r
.38355 .51961 m .38293 .51924 L .38206 .5173 L F
.38358 .51966 m .38293 .51924 L .38355 .51961 L F
.24 0 0 r
.38144 .51879 m .38293 .51924 L .38255 .51901 L F
0 0 0 r
.39513 .60202 m .39481 .60388 L .3951 .60228 L F
.622 .956 .911 r
.39923 .59919 m .39524 .60047 L .39753 .60076 L F
.39524 .60047 m .39497 .60056 L .39523 .60058 L F
.39524 .60047 m .39523 .60058 L .39753 .60076 L F
.232 .663 .957 r
.39531 .60021 m .39753 .60076 L .39497 .60056 L F
0 0 0 r
.39531 .60021 m .3952 .60103 L .39513 .60202 L F
.3952 .60103 m .39481 .60388 L .39513 .60202 L F
.954 .951 .708 r
.40093 .59542 m .39923 .59919 L .39842 .59814 L F
.987 .887 .551 r
.39842 .59814 m .39923 .59919 L .39753 .60076 L F
.949 .957 .697 r
.73013 .34772 m .73067 .34903 L .73241 .34546 L F
.77 .65 .73 r
.57107 .44622 m .56718 .44641 L .56954 .44353 L F
.734 .448 .495 r
.57107 .44622 m .5694 .44923 L .56718 .44641 L F
.69 .395 .47 r
.57343 .44907 m .57107 .44622 L .5734 .44702 L F
.57343 .44907 m .5694 .44923 L .57107 .44622 L F
.807 .329 .073 r
.32603 .61668 m .32466 .61663 L .3233 .61402 L F
.266 .772 .854 r
.3271 .61667 m .32466 .61663 L .32603 .61668 L F
.394 .202 .499 r
.32666 .61817 m .32466 .61663 L .3271 .61667 L F
0 0 0 r
.32867 .61545 m .32666 .61817 L .3271 .61667 L F
.593 .026 0 r
.3271 .61667 m .32666 .61817 L .32466 .61663 L F
.072 .634 .72 r
.34213 .57194 m .33954 .57215 L .33968 .57182 L F
.86 .979 .681 r
.32274 .53658 m .32398 .53372 L .3252 .53587 L F
.903 .584 .094 r
.41922 .57986 m .41882 .58126 L .41792 .57884 L F
.41922 .57986 m .41973 .58252 L .41882 .58126 L F
.716 .463 .541 r
.59912 .44102 m .59892 .44372 L .59539 .44302 L F
.593 .356 .527 r
.60269 .44283 m .59912 .44102 L .60197 .4403 L F
.60269 .44283 m .59892 .44372 L .59912 .44102 L F
.717 .517 .618 r
.37378 .56072 m .37033 .55778 L .37274 .55682 L F
.37378 .56072 m .37027 .56114 L .37033 .55778 L F
.61 .171 .181 r
.34482 .55201 m .34073 .55257 L .34284 .55252 L F
.245 .393 .814 r
.38186 .58072 m .38286 .57869 L .38034 .5791 L F
.38186 .58072 m .38452 .58243 L .38286 .57869 L F
.47 .377 .668 r
.38186 .58072 m .38194 .58412 L .38452 .58243 L F
.722 .544 .648 r
.36084 .55323 m .3578 .55055 L .35947 .54972 L F
.409 .112 .346 r
.36384 .54734 m .35947 .54972 L .36144 .54758 L F
.36384 .54734 m .36238 .55034 L .35947 .54972 L F
.44 .218 .479 r
.36248 .55253 m .35947 .54972 L .36238 .55034 L F
.36248 .55253 m .36084 .55323 L .35947 .54972 L F
.587 .911 .977 r
.42245 .55388 m .41928 .55499 L .42014 .55356 L F
.016 .178 .689 r
.42014 .55356 m .41928 .55499 L .41799 .55107 L F
.832 .67 .682 r
.55886 .41373 m .56267 .41186 L .55829 .41319 L F
.805 .707 .756 r
.55929 .41161 m .55886 .41373 L .55829 .41319 L F
.55929 .41161 m .55716 .41474 L .55886 .41373 L F
0 0 0 r
.72885 .35223 m .72678 .35326 L .72635 .35343 L F
.902 .985 .742 r
.729 .34986 m .72678 .35326 L .72885 .35223 L F
0 0 0 r
.72678 .35326 m .72884 .35147 L .72744 .35301 L F
.72678 .35326 m .72744 .35301 L .72598 .35461 L F
.72635 .35343 m .72678 .35326 L .72439 .35436 L F
.902 .985 .742 r
.729 .34986 m .72885 .35223 L .72928 .35069 L F
.416 .216 .499 r
.43069 .5481 m .43059 .55078 L .42822 .55151 L F
.437 .268 .552 r
.42822 .55151 m .4306 .5536 L .43059 .55078 L F
.416 .216 .499 r
.43069 .5481 m .43059 .55078 L .42822 .55151 L F
.437 .268 .552 r
.42822 .55151 m .4306 .5536 L .43059 .55078 L F
.105 0 .257 r
.39941 .69082 m .39863 .69326 L .39706 .69424 L F
.111 0 .267 r
.39863 .69326 m .39642 .69664 L .39706 .69424 L F
.522 .551 .827 r
.65195 .41908 m .65092 .42427 L .65002 .42071 L F
.627 .865 .987 r
.26704 .52376 m .26278 .52352 L .26481 .523 L F
.35 .806 .94 r
.26644 .5225 m .26704 .52376 L .26481 .523 L F
.26644 .5225 m .26948 .52333 L .26704 .52376 L F
.851 .793 .794 r
.7085 .29656 m .70755 .29357 L .70899 .29533 L F
.7085 .29656 m .70505 .29699 L .70755 .29357 L F
.854 .773 .771 r
.7085 .29656 m .70686 .29898 L .70505 .29699 L F
.522 .195 .354 r
.23008 .58348 m .2298 .58548 L .23245 .58491 L F
.275 0 0 r
.41596 .5301 m .41602 .53106 L .41351 .53149 L F
.073 0 0 r
.42051 .53021 m .41602 .53106 L .41596 .5301 L F
0 .053 .609 r
.28537 .64622 m .28687 .64857 L .28578 .64537 L F
.537 .505 .768 r
.4305 .52135 m .43168 .52543 L .42924 .52603 L F
.379 0 0 r
.36495 .56778 m .36859 .56979 L .36892 .56755 L F
.449 .84 .982 r
.36859 .56979 m .36726 .56913 L .36819 .56915 L F
0 .029 .599 r
.36859 .56979 m .36874 .57003 L .36892 .56755 L F
.633 .443 .608 r
.36892 .56755 m .37039 .56967 L .37158 .56686 L F
.36892 .56755 m .36871 .57046 L .37039 .56967 L F
.449 .84 .982 r
.36859 .56979 m .36819 .56915 L .37101 .56921 L F
0 .029 .599 r
.36859 .56979 m .36871 .57046 L .36874 .57003 L F
0 0 .278 r
.30837 .57986 m .30868 .58257 L .30844 .57815 L F
0 0 .38 r
.30833 .58297 m .30868 .58257 L .30837 .57986 L F
0 .16 .7 r
.29634 .53153 m .29578 .53243 L .29437 .53256 L F
.29634 .53153 m .29793 .53472 L .29578 .53243 L F
.516 .218 .4 r
.32367 .55518 m .32274 .55784 L .32035 .55741 L F
0 0 .029 r
.32468 .55492 m .32367 .55518 L .32553 .55396 L F
.32468 .55492 m .32274 .55784 L .32367 .55518 L F
.343 .817 .898 r
.29353 .51978 m .28858 .52081 L .28694 .52043 L F
.613 .266 .359 r
.28436 .54251 m .28759 .54321 L .28694 .54172 L F
.693 .976 .91 r
.57216 .42513 m .56911 .42676 L .57156 .42656 L F
.373 .009 .212 r
.57507 .42463 m .57216 .42513 L .57156 .42656 L F
.653 .569 .748 r
.29922 .61436 m .29664 .61745 L .2972 .61488 L F
.336 .347 .723 r
.19749 .58328 m .2 .58535 L .19923 .58171 L F
.386 .35 .696 r
.19749 .58328 m .19821 .58592 L .2 .58535 L F
.678 .449 .567 r
.68286 .33909 m .67812 .34178 L .6783 .33888 L F
.68286 .33909 m .68255 .34204 L .67812 .34178 L F
.749 .896 .944 r
.72501 .33955 m .72117 .34017 L .7239 .33894 L F
.34 .82 .849 r
.7239 .33894 m .72723 .33836 L .72501 .33955 L F
.652 .633 .819 r
.29827 .64246 m .29719 .64648 L .29711 .64601 L F
.29827 .64246 m .29941 .64685 L .29719 .64648 L F
0 .029 .592 r
.29719 .64648 m .29811 .6468 L .29711 .64601 L F
.29719 .64648 m .29929 .64899 L .29811 .6468 L F
.868 .861 .831 r
.70481 .31493 m .70618 .31648 L .70583 .31322 L F
.872 .799 .775 r
.70242 .31844 m .70618 .31648 L .70481 .31493 L F
.70242 .31844 m .70387 .32008 L .70618 .31648 L F
.912 .885 .794 r
.70583 .31322 m .70618 .31648 L .70716 .31459 L F
.595 .83 .45 r
.30153 .53168 m .30339 .52908 L .30492 .53015 L F
.30153 .53168 m .30171 .5313 L .30339 .52908 L F
.672 .564 .724 r
.30171 .5313 m .30173 .53369 L .30499 .53061 L F
0 .014 .566 r
.30137 .53188 m .30269 .5318 L .30173 .53369 L F
.30122 .53108 m .30169 .53131 L .30137 .53188 L F
.30169 .53131 m .30269 .5318 L .30137 .53188 L F
.416 .355 .681 r
.30069 .53311 m .30171 .5313 L .30153 .53168 L F
.30017 .53401 m .30122 .53217 L .30069 .53311 L F
.30122 .53217 m .30171 .5313 L .30069 .53311 L F
.448 .191 .43 r
.31239 .59853 m .30941 .60143 L .31029 .59958 L F
.383 .244 .565 r
.30227 .5922 m .30431 .59466 L .3037 .59192 L F
.30227 .5922 m .30267 .59595 L .30431 .59466 L F
.952 .951 .72 r
.56336 .41787 m .56648 .41513 L .56246 .41484 L F
.56336 .41787 m .56471 .41864 L .56648 .41513 L F
.469 .293 .559 r
.42428 .54577 m .42172 .54887 L .42177 .54663 L F
.814 .997 .772 r
.34197 .53767 m .33894 .54138 L .33952 .53883 L F
.607 .657 .874 r
.31426 .53101 m .31598 .52806 L .31341 .52902 L F
.31426 .53101 m .31709 .53054 L .31598 .52806 L F
.077 0 .197 r
.38614 .70658 m .38861 .70317 L .38791 .70544 L F
0 0 0 r
.38461 .70854 m .38614 .70658 L .38791 .70544 L F
.987 .798 .564 r
.40014 .59212 m .40093 .59542 L .39963 .59465 L F
.954 .951 .708 r
.40093 .59542 m .39842 .59814 L .39963 .59465 L F
.09 .058 .524 r
.32975 .60592 m .32918 .61163 L .32781 .60789 L F
.32975 .60592 m .33076 .61051 L .32918 .61163 L F
0 0 .359 r
.33042 .61331 m .32918 .61163 L .33076 .61051 L F
.906 .886 .801 r
.70583 .31322 m .7093 .31137 L .70806 .31019 L F
.70583 .31322 m .70716 .31459 L .7093 .31137 L F
.828 .997 .767 r
.71046 .30871 m .7093 .31137 L .71181 .3083 L F
.727 .893 .955 r
.70806 .31019 m .7093 .31137 L .71046 .30871 L F
.58 .294 .448 r
.59262 .44321 m .58899 .44611 L .58901 .44388 L F
.679 .762 .274 r
.30903 .65913 m .30819 .66134 L .30623 .66195 L F
.794 .348 .185 r
.30819 .66134 m .30847 .66396 L .30623 .66195 L F
.69 .749 .248 r
.32909 .60127 m .32776 .6053 L .32829 .60372 L F
.649 .345 .443 r
.32975 .60592 m .32776 .6053 L .33066 .60503 L F
.32975 .60592 m .32781 .60789 L .32776 .6053 L F
0 0 .119 r
.32776 .6053 m .32818 .60621 L .32829 .60372 L F
.32776 .6053 m .32781 .60789 L .32818 .60621 L F
.826 .839 .857 r
.35592 .52816 m .35379 .53129 L .35191 .52668 L F
.383 .713 .987 r
.36346 .6323 m .36724 .63379 L .36511 .63356 L F
0 0 .301 r
.36724 .63379 m .36712 .63689 L .36827 .63445 L F
.36724 .63379 m .36827 .63445 L .36511 .63356 L F
.729 .286 .198 r
.70177 .35528 m .70444 .3578 L .70222 .35685 L F
.719 .219 .049 r
.70177 .35528 m .70615 .35764 L .70444 .3578 L F
.567 .938 .843 r
.30206 .5172 m .30219 .51632 L .30418 .51575 L F
.30206 .5172 m .29984 .51773 L .30219 .51632 L F
.478 .254 .495 r
.35415 .53805 m .35186 .53563 L .35457 .53512 L F
.7 .49 .6 r
.26022 .53879 m .25668 .54106 L .25713 .53888 L F
.26022 .53879 m .26049 .54165 L .25668 .54106 L F
.611 .424 .605 r
.26309 .54095 m .26022 .53879 L .26132 .53734 L F
.26309 .54095 m .26049 .54165 L .26022 .53879 L F
.413 .041 .219 r
.30844 .57815 m .31047 .57826 L .31113 .57657 L F
0 0 0 r
.31113 .57657 m .31284 .57541 L .31408 .57292 L F
.372 .218 .54 r
.31047 .57826 m .31284 .57541 L .31113 .57657 L F
.503 .422 .698 r
.25812 .54771 m .25558 .54555 L .2582 .54488 L F
.25812 .54771 m .25597 .54856 L .25558 .54555 L F
0 0 0 r
.30977 .54431 m .30629 .546 L .30843 .54472 L F
.884 .985 .71 r
.73067 .34903 m .729 .34986 L .72928 .35069 L F
.958 .947 .662 r
.73013 .34772 m .729 .34986 L .73067 .34903 L F
.965 .653 .376 r
.292 .64456 m .29442 .64868 L .29344 .64392 L F
.357 .807 .671 r
.292 .64456 m .29344 .64392 L .29564 .64278 L F
0 0 0 r
.30951 .60428 m .30746 .60777 L .30735 .60559 L F
.856 .435 0 r
.30707 .53826 m .30643 .53816 L .30587 .53598 L F
0 0 .461 r
.38795 .52526 m .39059 .52886 L .38844 .52599 L F
.835 .37 0 r
.39098 .53146 m .39059 .52886 L .38795 .52526 L F
.39098 .53146 m .39269 .53283 L .39059 .52886 L F
.623 .101 0 r
.35932 .58892 m .36386 .58945 L .36137 .5903 L F
.677 .142 0 r
.36098 .5853 m .36465 .58785 L .36386 .58945 L F
.702 .983 .824 r
.36137 .5903 m .36386 .58945 L .36465 .58785 L F
.123 0 0 r
.34246 .66443 m .34678 .66309 L .34467 .66355 L F
.599 .95 .835 r
.34467 .66355 m .34678 .66309 L .34888 .66158 L F
.517 .886 .974 r
.34565 .67213 m .34152 .67243 L .34366 .67191 L F
.809 .989 .732 r
.24241 .54034 m .24184 .542 L .24395 .53934 L F
0 0 .202 r
.2427 .5429 m .24184 .542 L .24241 .54034 L F
.2427 .5429 m .24153 .54451 L .24184 .542 L F
.218 0 0 r
.27227 .53782 m .27459 .53736 L .27621 .53555 L F
.334 0 .034 r
.27459 .53736 m .27853 .53513 L .27621 .53555 L F
.646 .452 .607 r
.69538 .3551 m .69557 .35804 L .69294 .35755 L F
.702 .36 .394 r
.69538 .3551 m .69831 .35762 L .69557 .35804 L F
.565 .92 .734 r
.35499 .6667 m .35698 .66576 L .35391 .668 L F
.558 .929 .793 r
.35499 .6667 m .35391 .668 L .35312 .66802 L F
.109 0 .194 r
.29112 .55739 m .28835 .56109 L .29051 .5595 L F
.501 .554 .842 r
.29112 .55739 m .29153 .55334 L .29052 .55363 L F
.29112 .55739 m .29394 .55844 L .29153 .55334 L F
.544 .131 .208 r
.29051 .5595 m .29394 .55844 L .29112 .55739 L F
.871 .971 .852 r
.55582 .41306 m .55716 .41474 L .55349 .41787 L F
.449 .799 .998 r
.55886 .41373 m .55716 .41474 L .55582 .41306 L F
.95 .68 .226 r
.39937 .54958 m .39999 .54816 L .39883 .54729 L F
.39937 .54958 m .40027 .55124 L .39999 .54816 L F
.785 .749 .82 r
.32672 .55896 m .32274 .55784 L .32524 .55922 L F
.819 .797 .832 r
.71135 .29238 m .70899 .29533 L .70755 .29357 L F
.737 .652 .766 r
.4086 .51173 m .40583 .5151 L .40647 .5125 L F
.139 0 .177 r
.38452 .58243 m .38194 .58412 L .38175 .5855 L F
.682 .391 .475 r
.57764 .44666 m .57343 .44907 L .5734 .44702 L F
.57764 .44666 m .5761 .44936 L .57343 .44907 L F
.563 .193 .297 r
.57981 .44719 m .5761 .44936 L .57764 .44666 L F
.829 .956 .897 r
.71181 .3083 m .71381 .30695 L .71256 .30586 L F
.511 .294 .521 r
.36955 .54355 m .36715 .54188 L .36909 .54268 L F
.36955 .54355 m .3666 .54455 L .36715 .54188 L F
.593 .853 .504 r
.28835 .56109 m .28524 .56482 L .287 .56258 L F
.307 .321 .712 r
.28524 .56482 m .28791 .56641 L .287 .56258 L F
0 .208 .622 r
.28814 .56657 m .28791 .56641 L .28524 .56482 L F
.556 .855 .541 r
.38308 .65194 m .38451 .6503 L .38673 .65039 L F
.38308 .65194 m .38276 .65216 L .38451 .6503 L F
.488 .273 .513 r
.24354 .5673 m .24321 .57035 L .24081 .57095 L F
.584 .453 .669 r
.24572 .56355 m .24611 .56694 L .24354 .5673 L F
.577 .349 .533 r
.24608 .56954 m .24354 .5673 L .24611 .56694 L F
.24608 .56954 m .24321 .57035 L .24354 .5673 L F
.783 .775 .846 r
.61445 .39027 m .60978 .39169 L .61331 .38968 L F
.761 .744 .837 r
.61538 .3856 m .61445 .39027 L .61503 .38772 L F
.841 .959 .886 r
.61503 .38772 m .61445 .39027 L .61331 .38968 L F
.472 .821 .998 r
.39326 .56066 m .39609 .56 L .39719 .56094 L F
0 0 0 r
.63922 .43094 m .63518 .43337 L .63788 .42955 L F
.737 .852 .934 r
.64142 .42938 m .63922 .43094 L .63788 .42955 L F
0 .391 .842 r
.26675 .63581 m .26933 .63839 L .27103 .63898 L F
.563 .341 .536 r
.59116 .42687 m .59396 .42592 L .59122 .42424 L F
.791 .627 .678 r
.58617 .42479 m .59246 .42657 L .58586 .42494 L F
.58991 .42297 m .59212 .4261 L .58617 .42479 L F
.59212 .4261 m .59246 .42657 L .58617 .42479 L F
.594 .665 .889 r
.59242 .42922 m .59371 .42645 L .59116 .42687 L F
.59371 .42645 m .59396 .42592 L .59291 .42628 L F
.59371 .42645 m .59291 .42628 L .59116 .42687 L F
.59242 .42922 m .59537 .4284 L .59396 .42592 L F
.278 .208 .596 r
.32131 .57879 m .32093 .58246 L .31944 .5831 L F
.234 .077 .454 r
.3209 .58434 m .31944 .5831 L .32093 .58246 L F
.3209 .58434 m .31929 .58558 L .31944 .5831 L F
.691 .753 .899 r
.22965 .55143 m .23307 .55251 L .23194 .55017 L F
.618 .596 .806 r
.22965 .55143 m .23347 .5538 L .23307 .55251 L F
.484 .299 .553 r
.3622 .62711 m .3646 .62666 L .36435 .62355 L F
.566 .022 0 r
.36817 .62679 m .36435 .62355 L .3646 .62666 L F
.887 .68 .617 r
.42403 .52913 m .4226 .52879 L .42264 .52607 L F
0 .034 .582 r
.42403 .52913 m .4253 .53142 L .42505 .52989 L F
.42403 .52913 m .42499 .53245 L .4253 .53142 L F
.42403 .52913 m .42505 .52989 L .4226 .52879 L F
.549 .438 .68 r
.33799 .59225 m .33972 .59159 L .34034 .58874 L F
0 0 0 r
.33799 .59225 m .33819 .59305 L .33972 .59159 L F
.33799 .59225 m .33612 .59411 L .33819 .59305 L F
.848 .387 .064 r
.30075 .65526 m .29936 .65261 L .29708 .65135 L F
.699 .235 0 r
.30111 .65532 m .29936 .65261 L .30075 .65526 L F
.538 .667 .92 r
.64664 .39398 m .644 .39272 L .64669 .39198 L F
.577 .581 .82 r
.64951 .3913 m .64664 .39398 L .64669 .39198 L F
.64951 .3913 m .65079 .39449 L .64664 .39398 L F
.342 .05 .316 r
.38791 .70544 m .38861 .70317 L .39105 .70222 L F
.118 0 .159 r
.2914 .63654 m .28837 .64035 L .29077 .63924 L F
.149 0 .223 r
.29411 .63332 m .2914 .63654 L .29337 .6361 L F
.16 0 .222 r
.29337 .6361 m .2914 .63654 L .29077 .63924 L F
.965 .852 .679 r
.60037 .42082 m .60041 .42498 L .59963 .42333 L F
.963 .896 .711 r
.60041 .42498 m .59784 .42764 L .59963 .42333 L F
.43 .008 .135 r
.27726 .61782 m .27969 .61775 L .28139 .61628 L F
0 0 0 r
.28139 .61628 m .27969 .61775 L .28142 .61646 L F
.81 .956 .91 r
.30492 .53015 m .30542 .5274 L .30707 .52889 L F
.30492 .53015 m .30339 .52908 L .30542 .5274 L F
0 .195 .716 r
.60113 .41655 m .60052 .41813 L .59899 .41457 L F
0 0 .475 r
.59899 .41457 m .60052 .41813 L .60001 .41634 L F
.92 .735 .245 r
.60001 .41634 m .60052 .41813 L .60037 .42082 L F
.513 .297 .523 r
.60052 .41813 m .60338 .41987 L .60037 .42082 L F
0 0 .106 r
.60113 .41655 m .60052 .41813 L .60037 .42082 L F
.299 .791 .762 r
.26278 .52352 m .26047 .52433 L .25862 .52472 L F
.542 .553 .815 r
.31916 .57263 m .32043 .57626 L .31813 .57655 L F
.333 .413 .794 r
.32131 .57879 m .31813 .57655 L .32043 .57626 L F
.52 .08 .143 r
.23465 .59339 m .23262 .59225 L .23511 .59172 L F
.23465 .59339 m .23035 .59442 L .23262 .59225 L F
.935 .56 .212 r
.40638 .57466 m .40748 .57329 L .40645 .57183 L F
.40638 .57466 m .40783 .57596 L .40748 .57329 L F
.195 .682 .927 r
.64858 .41995 m .64704 .42051 L .64657 .42303 L F
.073 0 0 r
.42051 .53021 m .41856 .5308 L .41602 .53106 L F
.589 .515 .739 r
.4226 .52879 m .42051 .53021 L .41891 .52582 L F
.11 0 0 r
.42285 .53027 m .42051 .53021 L .4226 .52879 L F
.42285 .53027 m .41856 .5308 L .42051 .53021 L F
.925 .552 .283 r
.33111 .70824 m .33306 .70757 L .33273 .70885 L F
.922 .934 .571 r
.33463 .70338 m .33306 .70757 L .3329 .70522 L F
.912 .98 .716 r
.3329 .70522 m .33306 .70757 L .33111 .70824 L F
.925 .552 .283 r
.33111 .70824 m .33306 .70757 L .33273 .70885 L F
.399 .056 .265 r
.25753 .55005 m .25597 .54856 L .25812 .54771 L F
.25753 .55005 m .25507 .55071 L .25597 .54856 L F
.367 .413 .777 r
.40373 .67371 m .40171 .67536 L .40094 .67229 L F
.246 .213 .623 r
.40439 .67636 m .40171 .67536 L .40373 .67371 L F
.40439 .67636 m .4024 .67787 L .40171 .67536 L F
.623 .356 .493 r
.33529 .552 m .33845 .55377 L .33764 .55052 L F
.33529 .552 m .33503 .55503 L .33845 .55377 L F
.33845 .55377 m .33503 .55503 L .33529 .552 L F
.528 .331 .557 r
.43069 .5481 m .43323 .54771 L .43322 .54501 L F
.517 .297 .519 r
.43069 .5481 m .43059 .55078 L .43323 .54771 L F
.528 .331 .557 r
.43069 .5481 m .43323 .54771 L .43322 .54501 L F
.517 .297 .519 r
.43069 .5481 m .43059 .55078 L .43323 .54771 L F
0 .103 .642 r
.30024 .64451 m .29941 .64685 L .29827 .64246 L F
.819 .455 .368 r
.29929 .64899 m .29941 .64685 L .30212 .64829 L F
.36 .175 .49 r
.31443 .59775 m .31258 .59575 L .31461 .59504 L F
.31443 .59775 m .31239 .59853 L .31258 .59575 L F
.577 .607 .846 r
.35142 .50165 m .34841 .50391 L .34684 .50064 L F
.804 .821 .865 r
.70686 .29898 m .70234 .30013 L .70505 .29699 L F
.827 .732 .207 r
.42499 .53245 m .42451 .53286 L .4253 .53142 L F
.42499 .53245 m .42468 .53452 L .42451 .53286 L F
.784 .803 .315 r
.33981 .6549 m .33973 .65606 L .33883 .65882 L F
.705 .237 .138 r
.33827 .52437 m .34144 .5256 L .33908 .52345 L F
.417 0 0 r
.31058 .6632 m .31452 .6643 L .31259 .66212 L F
.47 .56 .865 r
.31452 .6643 m .31509 .66122 L .31259 .66212 L F
.31452 .6643 m .31786 .66476 L .31509 .66122 L F
.396 .83 .685 r
.43322 .54501 m .43445 .5442 L .43608 .54341 L F
.77 .691 .776 r
.43608 .54341 m .43323 .54771 L .43322 .54501 L F
0 0 .351 r
.43322 .54501 m .43448 .54586 L .43445 .5442 L F
.43322 .54501 m .43323 .54771 L .43448 .54586 L F
.563 .193 .297 r
.57981 .44719 m .57989 .44901 L .5761 .44936 L F
.599 .247 .344 r
.58349 .44646 m .57989 .44901 L .57981 .44719 L F
0 0 0 r
.62401 .44937 m .62267 .44947 L .62006 .44963 L F
.218 0 0 r
.62401 .44937 m .62663 .44961 L .62267 .44947 L F
.683 .526 .667 r
.36159 .62989 m .3646 .62666 L .3622 .62711 L F
.998 .8 .449 r
.4186 .57345 m .4171 .57465 L .41804 .57238 L F
.4186 .57345 m .41829 .57612 L .4171 .57465 L F
.79 .317 .111 r
.34956 .51355 m .34593 .51343 L .34599 .51178 L F
.34956 .51355 m .3504 .5157 L .34593 .51343 L F
.502 .883 .692 r
.24167 .5317 m .24287 .53059 L .24501 .52958 L F
.24167 .5317 m .24106 .53191 L .24287 .53059 L F
.992 .884 .585 r
.5638 .42084 m .56471 .41864 L .56336 .41787 L F
.589 .515 .739 r
.4226 .52879 m .41891 .52582 L .42264 .52607 L F
.607 .558 .774 r
.37035 .58936 m .3718 .58497 L .36966 .58575 L F
.37035 .58936 m .37304 .58874 L .3718 .58497 L F
0 .107 .571 r
.26616 .63345 m .26481 .63233 L .26265 .63129 L F
.26616 .63345 m .26606 .63335 L .26481 .63233 L F
.696 .558 .694 r
.63101 .43769 m .63265 .43381 L .63027 .43401 L F
0 0 .431 r
.39504 .53683 m .39575 .53863 L .39402 .53506 L F
.706 .27 0 r
.39609 .53983 m .39575 .53863 L .39504 .53683 L F
.39609 .53983 m .39717 .54116 L .39575 .53863 L F
.873 .434 .128 r
.41971 .58551 m .42187 .58666 L .42213 .58818 L F
.562 .788 .984 r
.4128 .5357 m .41623 .53733 L .41455 .53579 L F
0 0 0 r
.41792 .53591 m .41671 .53751 L .41623 .53733 L F
.685 .929 .969 r
.27548 .52819 m .27491 .5303 L .27715 .5295 L F
.27548 .52819 m .2727 .52972 L .27491 .5303 L F
.638 .636 .831 r
.29676 .62677 m .3001 .6274 L .29722 .62681 L F
.537 .541 .807 r
.36222 .60965 m .35999 .61058 L .35838 .60654 L F
.477 .89 .922 r
.36075 .61001 m .35999 .61058 L .36222 .60965 L F
.851 .398 .116 r
.35891 .6114 m .35726 .61049 L .35999 .61058 L F
.89 .55 .398 r
.35726 .61049 m .35558 .61254 L .35506 .61116 L F
.35726 .61049 m .35834 .61349 L .35558 .61254 L F
.569 .56 .804 r
.35838 .60654 m .35999 .61058 L .35726 .61049 L F
.477 .89 .922 r
.35564 .61125 m .35999 .61058 L .36075 .61001 L F
.851 .398 .116 r
.35954 .61175 m .35891 .6114 L .35999 .61058 L F
.97 .872 .483 r
.35834 .61349 m .35954 .61175 L .35999 .61058 L F
.35834 .61349 m .35889 .61442 L .35954 .61175 L F
.599 .247 .344 r
.58349 .44646 m .58258 .44887 L .57989 .44901 L F
.507 .152 .3 r
.58623 .44624 m .58258 .44887 L .58349 .44646 L F
0 0 0 r
.38563 .66698 m .3845 .66869 L .38598 .66634 L F
.38563 .66698 m .3845 .66869 L .38598 .66634 L F
.582 .308 .467 r
.68667 .35806 m .68909 .36007 L .68647 .36037 L F
.673 .251 .237 r
.68667 .35806 m .68888 .35858 L .68909 .36007 L F
.132 0 .301 r
.31509 .63984 m .31294 .64309 L .31445 .64246 L F
.209 .084 .482 r
.31445 .64246 m .31294 .64309 L .3143 .64526 L F
0 0 .517 r
.31294 .64309 m .31393 .64545 L .3143 .64526 L F
.49 .814 1 r
.34396 .64821 m .3463 .64903 L .3439 .64955 L F
.657 .939 .965 r
.34396 .64821 m .3439 .64955 L .34214 .64921 L F
.147 0 0 r
.3439 .64955 m .34436 .65069 L .3433 .65266 L F
.3439 .64955 m .3463 .64903 L .34436 .65069 L F
.284 .76 .933 r
.23347 .5538 m .23527 .5538 L .23764 .55402 L F
.614 .365 .517 r
.23527 .5538 m .24001 .55469 L .23764 .55402 L F
.308 .016 .296 r
.27078 .56011 m .26813 .56269 L .26824 .5608 L F
0 .32 .779 r
.36301 .56606 m .36495 .56778 L .36255 .56629 L F
.929 .932 .784 r
.33111 .56098 m .33171 .55669 L .33359 .5576 L F
.477 .272 .522 r
.33346 .56039 m .33111 .56098 L .33359 .5576 L F
.263 0 0 r
.33171 .55669 m .33503 .55503 L .33359 .5576 L F
.529 .645 .908 r
.23101 .57172 m .23564 .57383 L .23193 .56898 L F
.65 .695 .878 r
.23193 .56898 m .23564 .57383 L .23747 .57256 L F
.545 .523 .782 r
.38554 .58845 m .38447 .59243 L .38355 .58836 L F
.38554 .58845 m .38676 .59214 L .38447 .59243 L F
.798 .592 .623 r
.38676 .59214 m .38227 .59375 L .38447 .59243 L F
.77 .691 .776 r
.43608 .54341 m .43722 .54821 L .43323 .54771 L F
.524 0 0 r
.43722 .54821 m .43619 .54899 L .43476 .5479 L F
0 .041 .578 r
.43731 .54468 m .43722 .54821 L .43608 .54341 L F
.43731 .54468 m .43817 .54652 L .43722 .54821 L F
.294 .072 .395 r
.43817 .54652 m .43619 .54899 L .43722 .54821 L F
.43817 .54652 m .43695 .54957 L .43619 .54899 L F
.43695 .54957 m .43682 .5499 L .43619 .54899 L F
.524 0 0 r
.43476 .5479 m .43619 .54899 L .43323 .54771 L F
0 0 0 r
.40473 .604 m .40387 .60784 L .40362 .6082 L F
.40387 .60784 m .40294 .6103 L .40362 .6082 L F
.676 .549 .703 r
.63361 .38984 m .63321 .39262 L .63101 .39304 L F
.175 0 .371 r
.40236 .66474 m .40033 .66793 L .40018 .66534 L F
.987 .713 .371 r
.59711 .37881 m .59843 .38014 L .59717 .38145 L F
.615 .908 .983 r
.5997 .37821 m .59843 .38014 L .59711 .37881 L F
.5997 .37821 m .60152 .37891 L .59843 .38014 L F
.59843 .38014 m .5997 .37821 L .59717 .38145 L F
.59843 .38014 m .60152 .37891 L .5997 .37821 L F
.729 .623 .057 r
.21961 .56504 m .21957 .56738 L .2197 .56457 L F
0 0 .157 r
.22018 .56805 m .21957 .56738 L .21961 .56504 L F
.831 .913 .513 r
.40836 .59585 m .40694 .59762 L .40714 .59802 L F
.96 .895 .514 r
.40787 .59379 m .40694 .59762 L .40836 .59585 L F
.196 .438 .866 r
.28671 .62611 m .28624 .62797 L .28473 .62668 L F
.28671 .62611 m .28909 .6295 L .28624 .62797 L F
.457 .415 .723 r
.28909 .6295 m .28699 .63062 L .28624 .62797 L F
0 0 .024 r
.61003 .4211 m .60849 .42451 L .60997 .42272 L F
.60849 .42451 m .60851 .42451 L .60997 .42272 L F
.203 .325 .767 r
.60846 .42456 m .61113 .42664 L .60997 .42272 L F
0 .344 .721 r
.60816 .42392 m .60663 .42346 L .60587 .42173 L F
.845 .501 .402 r
.60684 .42315 m .60816 .42392 L .60686 .42265 L F
0 .344 .721 r
.60816 .42392 m .6092 .42453 L .60663 .42346 L F
.60953 .42467 m .60938 .42465 L .60663 .42346 L F
.532 .297 .504 r
.61106 .42914 m .60632 .42662 L .60852 .4281 L F
.61106 .42914 m .61113 .42664 L .60632 .42662 L F
.064 .195 .691 r
.60691 .42662 m .60663 .42346 L .60773 .42625 L F
0 0 .024 r
.60849 .42451 m .60846 .42456 L .60851 .42451 L F
.431 .421 .747 r
.60992 .42488 m .60773 .42625 L .60663 .42346 L F
.845 .501 .402 r
.60668 .42696 m .60816 .42392 L .60684 .42315 L F
0 .344 .721 r
.60816 .42392 m .60953 .42467 L .6092 .42453 L F
.60953 .42467 m .60992 .42488 L .60938 .42465 L F
.153 .238 .699 r
.60852 .4281 m .60632 .42662 L .60691 .42662 L F
.692 .167 0 r
.32167 .69075 m .32458 .69318 L .32381 .69324 L F
.613 .058 0 r
.32381 .69324 m .32458 .69318 L .32561 .69418 L F
0 0 .483 r
.32325 .51106 m .32456 .51152 L .32674 .51317 L F
.32325 .51106 m .32378 .51388 L .32456 .51152 L F
.291 0 .12 r
.28282 .55125 m .28166 .55361 L .27992 .55323 L F
.139 0 .049 r
.2835 .55274 m .28282 .55125 L .28525 .55081 L F
.28341 .55255 m .28166 .55361 L .28282 .55125 L F
.528 .008 0 r
.27924 .55151 m .28524 .55086 L .27976 .54977 L F
.27924 .55151 m .2815 .55194 L .28524 .55086 L F
.357 0 .061 r
.2815 .55194 m .28652 .54872 L .28526 .55084 L F
.235 0 0 r
.28615 .55165 m .2835 .55274 L .28525 .55081 L F
.357 0 .061 r
.28523 .55087 m .28526 .55084 L .28524 .55086 L F
.2815 .55194 m .28526 .55084 L .28523 .55087 L F
.139 0 .049 r
.2835 .55274 m .28288 .55304 L .28341 .55255 L F
.28288 .55304 m .28166 .55361 L .28341 .55255 L F
.317 .418 .807 r
.19821 .58592 m .20106 .58905 L .2 .58535 L F
.681 .599 .757 r
.26049 .54165 m .2582 .54488 L .25668 .54106 L F
.63 .528 .72 r
.26099 .54424 m .2582 .54488 L .26049 .54165 L F
.494 .295 .54 r
.2604 .54716 m .2582 .54488 L .26099 .54424 L F
.2604 .54716 m .25812 .54771 L .2582 .54488 L F
.384 .541 .888 r
.2518 .61663 m .251 .6193 L .24982 .61674 L F
.2518 .61663 m .25384 .61984 L .251 .6193 L F
.438 0 0 r
.59784 .42764 m .59516 .42617 L .59396 .42592 L F
0 0 0 r
.63373 .44824 m .63599 .4468 L .63264 .44902 L F
.772 .676 .757 r
.68255 .34204 m .6837 .34578 L .68001 .34564 L F
.6837 .34578 m .6811 .34878 L .68001 .34564 L F
.792 .462 .431 r
.55912 .44012 m .55759 .4426 L .55563 .43974 L F
.751 .411 .407 r
.5612 .44285 m .55759 .4426 L .55912 .44012 L F
.824 .369 .144 r
.56322 .44359 m .5612 .44285 L .55912 .44012 L F
.016 0 0 r
.26845 .62179 m .26903 .62248 L .27091 .62111 L F
.26845 .62179 m .26669 .62325 L .26903 .62248 L F
.889 .591 .082 r
.40343 .56227 m .4038 .56082 L .4039 .55921 L F
.40343 .56227 m .40436 .56374 L .4038 .56082 L F
0 0 .511 r
.3233 .61402 m .32466 .61663 L .32405 .61392 L F
0 .18 .714 r
.40188 .55276 m .40209 .55451 L .40027 .55124 L F
0 0 .022 r
.40216 .55522 m .40209 .55451 L .40188 .55276 L F
.668 .117 0 r
.59319 .41421 m .59651 .41593 L .59529 .41601 L F
.138 0 0 r
.59529 .41601 m .59651 .41593 L .60001 .41634 L F
0 0 .475 r
.59899 .41457 m .60001 .41634 L .59651 .41593 L F
0 0 .33 r
.29314 .55962 m .29217 .56401 L .29346 .56067 L F
.519 .335 .572 r
.43142 .58277 m .43154 .5862 L .42898 .58657 L F
.57 .472 .704 r
.43322 .58073 m .43401 .58236 L .43142 .58277 L F
.542 .353 .574 r
.43401 .58236 m .43154 .5862 L .43142 .58277 L F
.484 .9 .863 r
.56911 .42676 m .56603 .42776 L .56793 .42733 L F
.56911 .42676 m .56793 .42733 L .56775 .4243 L F
.535 .574 .841 r
.57051 .4233 m .56911 .42676 L .56775 .4243 L F
.57051 .4233 m .57156 .42656 L .56911 .42676 L F
.878 .635 .568 r
.39426 .58943 m .39183 .59143 L .39227 .58852 L F
.39426 .58943 m .39445 .59152 L .39183 .59143 L F
.633 .078 0 r
.39426 .58943 m .39748 .59187 L .39445 .59152 L F
.074 0 0 r
.33346 .56039 m .33004 .56183 L .33111 .56098 L F
.821 .642 .66 r
.70009 .32195 m .70387 .32008 L .70242 .31844 L F
.70009 .32195 m .70346 .32252 L .70387 .32008 L F
.807 .958 .912 r
.39672 .51396 m .39397 .51651 L .39311 .51496 L F
.879 .503 .027 r
.39397 .51651 m .39344 .51751 L .39311 .51496 L F
.39449 .51844 m .39464 .51899 L .39344 .51751 L F
0 .025 .515 r
.39464 .51899 m .39522 .51954 L .39344 .51751 L F
.866 .443 .211 r
.39522 .51954 m .393 .51712 L .39344 .51751 L F
.393 .51712 m .39127 .51524 L .39344 .51751 L F
.879 .503 .027 r
.39397 .51651 m .39449 .51844 L .39344 .51751 L F
.931 .885 .765 r
.35596 .588 m .35493 .59315 L .35662 .59168 L F
.364 0 .156 r
.35329 .59422 m .35662 .59168 L .35493 .59315 L F
0 0 .161 r
.40057 .68666 m .40032 .68948 L .39941 .69082 L F
0 0 0 r
.39921 .69174 m .39941 .69082 L .40032 .68948 L F
.39921 .69174 m .39863 .69326 L .39941 .69082 L F
.844 .41 0 r
.40503 .56841 m .40524 .56703 L .40405 .56538 L F
.40503 .56841 m .40617 .56942 L .40524 .56703 L F
.59 .387 .573 r
.65241 .41506 m .65269 .41764 L .64953 .41819 L F
.186 .1 .518 r
.6543 .41632 m .65241 .41506 L .65445 .41403 L F
.6543 .41632 m .65269 .41764 L .65241 .41506 L F
.586 .447 .659 r
.34685 .60232 m .34937 .60172 L .34893 .59916 L F
.495 .395 .67 r
.34685 .60232 m .34943 .60448 L .34937 .60172 L F
.34685 .60232 m .34714 .60492 L .34943 .60448 L F
.608 .257 .35 r
.21639 .57068 m .21645 .5724 L .21436 .57034 L F
.857 .403 .04 r
.30399 .65795 m .30111 .65532 L .30459 .65852 L F
.084 0 0 r
.30183 .65939 m .30399 .65795 L .30459 .65852 L F
.911 .759 .268 r
.40838 .58819 m .40902 .58616 L .40856 .58498 L F
.40838 .58819 m .40876 .58871 L .40902 .58616 L F
.822 .7 .73 r
.68001 .34564 m .6811 .34878 L .67921 .34804 L F
.835 .63 .626 r
.68113 .35146 m .67921 .34804 L .6811 .34878 L F
.553 .536 .79 r
.34505 .64001 m .34745 .63948 L .34656 .63609 L F
.435 .836 .977 r
.35047 .68442 m .35361 .68371 L .35474 .68435 L F
.35047 .68442 m .35361 .68371 L .35474 .68435 L F
.744 .695 .805 r
.42236 .51284 m .41901 .51607 L .41996 .51463 L F
.644 .518 .696 r
.3585 .58249 m .35249 .58077 L .35858 .57974 L F
.3585 .58249 m .35339 .58345 L .35249 .58077 L F
.228 0 .314 r
.28641 .63304 m .28699 .63062 L .28909 .6295 L F
0 .103 .611 r
.59156 .40723 m .59078 .40692 L .5893 .40509 L F
.59156 .40723 m .59239 .40834 L .59078 .40692 L F
.41 .063 .262 r
.29568 .63524 m .29411 .63332 L .29337 .6361 L F
.29568 .63524 m .29655 .63289 L .29411 .63332 L F
.556 .21 .336 r
.68888 .35858 m .69182 .36015 L .68909 .36007 L F
.68888 .35858 m .69294 .35755 L .69182 .36015 L F
.253 0 0 r
.24961 .5464 m .25219 .54609 L .25376 .54428 L F
0 0 0 r
.25376 .54428 m .25668 .54106 L .25414 .54172 L F
.25376 .54428 m .25399 .54497 L .25538 .54287 L F
.25376 .54428 m .25219 .54609 L .25399 .54497 L F
.53 .48 .745 r
.36863 .5835 m .36966 .58575 L .3718 .58497 L F
0 0 0 r
.36755 .58521 m .36863 .5835 L .37036 .58157 L F
.349 0 .084 r
.42898 .58657 m .43087 .58753 L .42831 .58825 L F
.42898 .58657 m .43154 .5862 L .43087 .58753 L F
.603 .069 0 r
.3793 .6236 m .37779 .62241 L .3755 .62282 L F
.921 .946 .601 r
.38884 .65435 m .38903 .65629 L .39063 .65253 L F
.921 .938 .578 r
.38785 .65867 m .38903 .65629 L .38884 .65435 L F
.49 .218 .428 r
.2353 .57656 m .23487 .57905 L .23717 .5782 L F
.566 .927 .762 r
.28954 .56524 m .28814 .56657 L .29217 .56401 L F
0 0 .33 r
.29314 .55962 m .29325 .56282 L .29217 .56401 L F
.55 .919 .756 r
.29325 .56282 m .28954 .56524 L .29217 .56401 L F
.319 0 .153 r
.24081 .57095 m .23993 .57261 L .23761 .57319 L F
.503 .179 .351 r
.24321 .57035 m .23993 .57261 L .24081 .57095 L F
.464 .648 .938 r
.35482 .51605 m .35645 .5158 L .35226 .51457 L F
.35645 .5158 m .35749 .51564 L .35655 .51545 L F
.35645 .5158 m .35655 .51545 L .35226 .51457 L F
0 .054 .604 r
.35449 .5116 m .35701 .515 L .3567 .5144 L F
.704 .888 .965 r
.35698 .51503 m .35704 .51498 L .35681 .51442 L F
.35681 .51442 m .35718 .51534 L .35819 .51468 L F
.35678 .51455 m .35693 .51483 L .35681 .51442 L F
.35819 .51468 m .35764 .51648 L .36117 .51525 L F
.35718 .51534 m .35764 .51648 L .35819 .51468 L F
.3567 .5144 m .35678 .51456 L .35681 .51442 L F
.791 .647 .704 r
.3567 .5144 m .35991 .51758 L .35801 .51666 L F
0 .054 .604 r
.35701 .515 m .35716 .51519 L .3567 .5144 L F
.704 .888 .965 r
.35678 .51456 m .35698 .51503 L .35693 .51483 L F
.35678 .51456 m .35693 .51483 L .35678 .51455 L F
.35698 .51503 m .35764 .51648 L .35704 .51498 L F
.791 .647 .704 r
.3567 .5144 m .35801 .51666 L .35764 .51648 L F
0 .054 .604 r
.35716 .51519 m .35749 .51564 L .3567 .5144 L F
.555 .592 .846 r
.35226 .51457 m .35655 .51545 L .35449 .5116 L F
.35655 .51545 m .35749 .51564 L .35701 .515 L F
.35655 .51545 m .35701 .515 L .35449 .5116 L F
0 0 0 r
.35452 .51875 m .35749 .51564 L .35645 .5158 L F
.35473 .51691 m .35645 .5158 L .35482 .51605 L F
.35452 .51875 m .35645 .5158 L .35473 .51691 L F
.833 .952 .604 r
.38446 .64334 m .38304 .64689 L .38531 .64316 L F
0 0 0 r
.38678 .63979 m .38615 .64167 L .38531 .64316 L F
.593 .411 .604 r
.38615 .64167 m .38446 .64334 L .38531 .64316 L F
.218 .473 .886 r
.39063 .65253 m .3928 .65335 L .39144 .65081 L F
.522 .71 .957 r
.369 .51071 m .36808 .51106 L .36754 .50885 L F
.18 0 0 r
.3197 .63584 m .31873 .63457 L .31859 .6368 L F
.757 .961 .935 r
.32024 .63348 m .31873 .63457 L .3197 .63584 L F
.629 .109 0 r
.63896 .40181 m .64285 .40248 L .64165 .40364 L F
.939 .572 .271 r
.64165 .40364 m .64285 .40248 L .64292 .40393 L F
.825 .455 .356 r
.64285 .40248 m .64682 .40568 L .64292 .40393 L F
.385 0 0 r
.35359 .71341 m .35743 .71366 L .35609 .71369 L F
.508 .911 .888 r
.35609 .71369 m .35743 .71366 L .36015 .71242 L F
.57 .744 .959 r
.74134 .32752 m .73914 .32961 L .73799 .32785 L F
.078 .017 .479 r
.74014 .32961 m .73914 .32961 L .74134 .32752 L F
.74014 .32961 m .73939 .33223 L .73914 .32961 L F
.672 .513 .661 r
.60855 .44287 m .6042 .44011 L .60835 .44045 L F
.73 .507 .59 r
.61165 .44045 m .60855 .44287 L .60835 .44045 L F
.392 .169 .453 r
.34962 .58618 m .34932 .58865 L .3472 .5893 L F
.48 .284 .536 r
.34932 .58865 m .34688 .59203 L .3472 .5893 L F
.415 .432 .769 r
.29944 .62064 m .29806 .6221 L .29664 .61745 L F
.376 .372 .727 r
.29944 .62064 m .30068 .6231 L .29806 .6221 L F
0 .262 .722 r
.30048 .62384 m .29806 .6221 L .30068 .6231 L F
.12 0 0 r
.33657 .67585 m .33603 .67477 L .33531 .67717 L F
.33657 .67585 m .33853 .67381 L .33603 .67477 L F
0 0 0 r
.24005 .58881 m .23843 .58963 L .24124 .58916 L F
.24005 .58881 m .23605 .59124 L .23843 .58963 L F
.531 .013 0 r
.69294 .35755 m .69614 .3588 L .69182 .36015 L F
.69294 .35755 m .69557 .35804 L .69614 .3588 L F
.62 .612 .822 r
.64535 .38822 m .644 .39272 L .6427 .38918 L F
.64535 .38822 m .64669 .39198 L .644 .39272 L F
.562 .792 .985 r
.67138 .36242 m .67405 .36411 L .67085 .36443 L F
.48 0 0 r
.67085 .36443 m .67366 .36646 L .67158 .36518 L F
.594 .337 .497 r
.67405 .36411 m .67366 .36646 L .67085 .36443 L F
.48 0 0 r
.67085 .36443 m .67158 .36518 L .67138 .36242 L F
0 0 .415 r
.30094 .6263 m .3001 .6274 L .30048 .62384 L F
.613 .856 .989 r
.29722 .62681 m .3001 .6274 L .30094 .6263 L F
0 0 .415 r
.30094 .6263 m .30084 .62577 L .3009 .62581 L F
.613 .856 .989 r
.30138 .62578 m .30094 .6263 L .30143 .62577 L F
.178 .195 .64 r
.30193 .62462 m .30138 .62578 L .30068 .6231 L F
.30138 .62578 m .3009 .62581 L .30068 .6231 L F
.30138 .62578 m .30094 .6263 L .3009 .62581 L F
.613 .856 .989 r
.29722 .62681 m .30094 .6263 L .30138 .62578 L F
.013 0 0 r
.30103 .62591 m .30099 .62588 L .30138 .62578 L F
.3014 .62578 m .30138 .62578 L .30143 .62577 L F
.30103 .62591 m .30138 .62578 L .3014 .62578 L F
.29566 .62772 m .29722 .62681 L .30099 .62588 L F
.29566 .62772 m .30099 .62588 L .30103 .62591 L F
0 0 .415 r
.3009 .62581 m .30048 .62384 L .30068 .6231 L F
.30084 .62577 m .30048 .62384 L .3009 .62581 L F
0 .06 .625 r
.30073 .62273 m .30253 .62534 L .30068 .6231 L F
.30087 .62174 m .30164 .62342 L .30073 .62273 L F
.30164 .62342 m .30253 .62534 L .30073 .62273 L F
.013 0 0 r
.29566 .62772 m .29653 .62743 L .29804 .62711 L F
.29653 .62743 m .30143 .62577 L .29804 .62711 L F
.281 0 .189 r
.29995 .62671 m .29804 .62711 L .3002 .62597 L F
.29913 .62922 m .29804 .62711 L .29995 .62671 L F
.258 .47 .874 r
.3014 .62578 m .30177 .62366 L .29804 .62711 L F
.558 .592 .844 r
.30308 .62117 m .30253 .62534 L .30087 .62174 L F
.293 0 .142 r
.3002 .62597 m .30177 .62366 L .30193 .62364 L F
.558 .592 .844 r
.30308 .62117 m .30491 .6248 L .30253 .62534 L F
.553 .716 .948 r
.30253 .62534 m .30351 .62338 L .30177 .62366 L F
.293 0 .142 r
.30257 .62411 m .30193 .62364 L .30351 .62338 L F
.258 .47 .874 r
.30144 .62571 m .30177 .62366 L .3014 .62578 L F
.178 .195 .64 r
.30214 .62488 m .30145 .6257 L .30193 .62462 L F
.30145 .6257 m .30144 .62571 L .30193 .62462 L F
.30143 .62573 m .30138 .62578 L .30193 .62462 L F
.258 .47 .874 r
.30143 .62577 m .30253 .62534 L .30144 .62571 L F
.30143 .62577 m .30144 .62571 L .3014 .62578 L F
.132 .101 .553 r
.30143 .62577 m .30094 .6263 L .30253 .62534 L F
.178 .195 .64 r
.30253 .62534 m .30094 .6263 L .30214 .62488 L F
.258 .47 .874 r
.30144 .62571 m .30253 .62534 L .30177 .62366 L F
.178 .195 .64 r
.30145 .6257 m .30143 .62573 L .30144 .62571 L F
.293 0 .142 r
.3002 .62597 m .30193 .62364 L .30257 .62411 L F
0 0 .324 r
.30833 .58297 m .30844 .58516 L .30868 .58257 L F
.30833 .58297 m .30793 .58639 L .30844 .58516 L F
.819 .612 .624 r
.56322 .44359 m .55909 .44551 L .5612 .44285 L F
.56322 .44359 m .56297 .44636 L .55909 .44551 L F
.732 .533 .623 r
.56718 .44641 m .56297 .44636 L .56322 .44359 L F
.763 .713 .806 r
.36266 .58309 m .35828 .58536 L .36098 .5853 L F
.36266 .58309 m .3585 .58249 L .35828 .58536 L F
0 0 0 r
.36392 .58183 m .36266 .58309 L .36098 .5853 L F
.624 .593 .798 r
.37315 .60476 m .37057 .60541 L .36888 .60141 L F
.784 .57 .61 r
.59874 .39088 m .60129 .39286 L .59724 .39231 L F
.77 .675 .758 r
.59724 .39231 m .60129 .39286 L .59903 .39548 L F
.207 .496 .903 r
.60105 .39138 m .60129 .39286 L .59874 .39088 L F
.213 .502 .906 r
.60393 .39318 m .60129 .39286 L .60105 .39138 L F
.685 .65 .809 r
.33119 .50366 m .33607 .50562 L .33314 .50413 L F
.054 .439 .874 r
.33607 .50562 m .33633 .50446 L .33314 .50413 L F
.33607 .50562 m .3376 .50604 L .33633 .50446 L F
.698 .67 .818 r
.31654 .55727 m .31836 .55314 L .31503 .55643 L F
.807 .546 .544 r
.38655 .61262 m .38839 .61013 L .38805 .60918 L F
.698 .383 .439 r
.38839 .61013 m .38783 .60969 L .38805 .60918 L F
.38783 .60969 m .38718 .60917 L .38805 .60918 L F
0 0 0 r
.38784 .60967 m .38805 .60918 L .38793 .60947 L F
.38655 .61262 m .38805 .60918 L .38784 .60967 L F
.38672 .61223 m .38793 .60947 L .38758 .61032 L F
.38655 .61262 m .38793 .60947 L .38672 .61223 L F
.698 .383 .439 r
.38839 .61013 m .39107 .60832 L .38815 .60896 L F
.38783 .60969 m .38793 .60947 L .38718 .60917 L F
.668 .192 .112 r
.38758 .61032 m .38793 .60947 L .38718 .60917 L F
.38793 .60947 m .38805 .60918 L .38718 .60917 L F
.698 .383 .439 r
.38793 .60947 m .38815 .60896 L .38718 .60917 L F
.38839 .61013 m .38815 .60896 L .38783 .60969 L F
0 0 0 r
.39294 .60713 m .39107 .60832 L .38839 .61013 L F
0 0 .357 r
.21859 .58363 m .21939 .58508 L .21791 .58239 L F
0 0 0 r
.33912 .56723 m .33964 .56813 L .34047 .56599 L F
.33912 .56723 m .33797 .56958 L .33964 .56813 L F
0 0 .014 r
.20837 .5603 m .20998 .55954 L .21075 .55723 L F
.168 0 0 r
.20837 .5603 m .20917 .56176 L .20998 .55954 L F
.20837 .5603 m .20704 .56247 L .20917 .56176 L F
0 .188 .702 r
.22492 .60991 m .22639 .61167 L .22532 .61006 L F
0 .38 .82 r
.22639 .61167 m .22751 .61147 L .22532 .61006 L F
.22639 .61167 m .22975 .61345 L .22751 .61147 L F
.889 .968 .833 r
.36555 .67578 m .36633 .67707 L .36477 .67423 L F
.203 0 0 r
.37224 .67576 m .36994 .67619 L .36849 .67648 L F
.36994 .67619 m .3671 .67671 L .36849 .67648 L F
.739 .722 .836 r
.36849 .67648 m .36996 .67741 L .37224 .67576 L F
.778 .273 0 r
.37143 .68033 m .36996 .67741 L .36849 .67648 L F
.813 .922 .909 r
.37187 .68047 m .36895 .68342 L .36927 .68269 L F
.63 .341 .461 r
.36589 .68303 m .36872 .68308 L .36624 .68038 L F
.36872 .68308 m .36902 .68308 L .36891 .68298 L F
.36872 .68308 m .36891 .68298 L .36624 .68038 L F
.734 .284 .181 r
.36624 .68038 m .36902 .68308 L .368 .68265 L F
.778 .273 0 r
.36957 .68182 m .36849 .67648 L .36809 .68147 L F
.36874 .68229 m .36809 .68147 L .368 .68265 L F
.36968 .68184 m .36809 .68147 L .36874 .68229 L F
.813 .922 .909 r
.36921 .68283 m .36893 .68297 L .36892 .68282 L F
.735 .973 .928 r
.36879 .68299 m .36968 .68184 L .368 .68265 L F
.813 .922 .909 r
.36916 .68251 m .36892 .68282 L .36883 .68043 L F
.36921 .68283 m .36892 .68282 L .36916 .68251 L F
.36921 .68283 m .36895 .68342 L .36893 .68297 L F
.37156 .68037 m .36927 .68269 L .36963 .68189 L F
.37187 .68047 m .36927 .68269 L .37156 .68037 L F
0 0 0 r
.37181 .68082 m .36895 .68342 L .37293 .6794 L F
.735 .973 .928 r
.36902 .68308 m .37181 .68082 L .36968 .68184 L F
.778 .273 0 r
.36968 .68184 m .36965 .6817 L .36957 .68182 L F
.36965 .6817 m .36849 .67648 L .36957 .68182 L F
.37143 .68033 m .36849 .67648 L .36968 .68184 L F
.813 .922 .909 r
.37046 .68002 m .36921 .68283 L .36883 .68043 L F
.735 .973 .928 r
.36902 .68308 m .36968 .68184 L .36892 .68282 L F
0 .111 .656 r
.36898 .68259 m .36897 .68294 L .36902 .68308 L F
.36897 .68294 m .36895 .68342 L .36902 .68308 L F
.735 .973 .928 r
.36902 .68308 m .36892 .68282 L .36879 .68299 L F
0 .111 .656 r
.36883 .68043 m .36891 .68251 L .36898 .68259 L F
.835 .947 .59 r
.36849 .67648 m .36624 .68038 L .368 .68265 L F
.906 .952 .818 r
.36883 .68043 m .36898 .68259 L .36741 .68273 L F
0 .111 .656 r
.36891 .68251 m .36895 .68342 L .36898 .68259 L F
.906 .952 .818 r
.36898 .68259 m .36902 .68308 L .36867 .68301 L F
.36898 .68259 m .36867 .68301 L .36741 .68273 L F
.813 .922 .909 r
.37156 .68037 m .36963 .68189 L .37143 .68033 L F
.778 .273 0 r
.37181 .68082 m .37143 .68033 L .36968 .68184 L F
.813 .922 .909 r
.37143 .68033 m .36963 .68189 L .37046 .68002 L F
.783 .591 .641 r
.37156 .68037 m .37354 .67636 L .36996 .67741 L F
.37225 .67968 m .37354 .67636 L .37156 .68037 L F
.778 .273 0 r
.37156 .68037 m .36996 .67741 L .37143 .68033 L F
.813 .922 .909 r
.37293 .6794 m .37187 .68047 L .37099 .68019 L F
.37293 .6794 m .37099 .68019 L .37046 .68002 L F
.783 .591 .641 r
.37225 .67968 m .37293 .6794 L .37354 .67636 L F
.37181 .68082 m .37293 .6794 L .37225 .67968 L F
.37181 .68082 m .37225 .67968 L .37156 .68037 L F
.778 .273 0 r
.37181 .68082 m .37156 .68037 L .37143 .68033 L F
.203 0 0 r
.36994 .67619 m .36949 .67668 L .3671 .67671 L F
.37224 .67576 m .37101 .67617 L .36994 .67619 L F
.37101 .67617 m .36949 .67668 L .36994 .67619 L F
.746 .242 .024 r
.36849 .67648 m .36803 .67621 L .36626 .67694 L F
.36803 .67621 m .36477 .67423 L .36587 .67624 L F
.36803 .67621 m .36587 .67624 L .36626 .67694 L F
.36849 .67648 m .36626 .67694 L .36633 .67707 L F
.816 .902 .901 r
.71176 .27678 m .7127 .27341 L .7141 .27453 L F
.71176 .27678 m .7127 .27341 L .7141 .27453 L F
.711 .629 .764 r
.22701 .55431 m .23212 .55525 L .22965 .55143 L F
.618 .596 .806 r
.22965 .55143 m .23212 .55525 L .23347 .5538 L F
.517 .134 .252 r
.22911 .55631 m .23347 .5538 L .23212 .55525 L F
.77 .675 .758 r
.59724 .39231 m .59903 .39548 L .59764 .39459 L F
.901 .489 .111 r
.59764 .39459 m .59903 .39548 L .60018 .39869 L F
.331 .101 .407 r
.31758 .58926 m .31698 .59177 L .31492 .5925 L F
.211 .027 .401 r
.31636 .59412 m .31492 .5925 L .31698 .59177 L F
.31636 .59412 m .31461 .59504 L .31492 .5925 L F
.576 .001 0 r
.56236 .39605 m .55853 .39466 L .56094 .39481 L F
.662 .723 .895 r
.55853 .39466 m .56236 .39605 L .56094 .39481 L F
.58 .929 .746 r
.24501 .52958 m .24579 .52849 L .2473 .52869 L F
.24501 .52958 m .24287 .53059 L .24579 .52849 L F
.757 .643 .736 r
.35203 .5821 m .34962 .58618 L .34895 .58283 L F
.69 .466 .577 r
.35346 .58544 m .34932 .58865 L .34962 .58618 L F
.445 .633 .935 r
.30906 .51259 m .30884 .51526 L .30648 .51441 L F
.30906 .51259 m .31131 .51575 L .30884 .51526 L F
.767 .702 .79 r
.63623 .38903 m .63321 .39262 L .63361 .38984 L F
.829 .956 .897 r
.71181 .3083 m .71256 .30586 L .71046 .30871 L F
.669 .231 .2 r
.34317 .70966 m .3457 .71226 L .34285 .71253 L F
.809 .702 .746 r
.67752 .36034 m .67567 .36129 L .67637 .35802 L F
.353 .15 .459 r
.67616 .36297 m .67567 .36129 L .67752 .36034 L F
.735 .303 .224 r
.67752 .36034 m .68004 .36305 L .67616 .36297 L F
.67752 .36034 m .6799 .36132 L .68004 .36305 L F
.14 0 0 r
.2461 .53821 m .24241 .54034 L .24395 .53934 L F
.695 .712 .862 r
.6345 .38557 m .63361 .38984 L .63317 .38598 L F
.6345 .38557 m .63623 .38903 L .63361 .38984 L F
.736 .743 .857 r
.35696 .57841 m .35858 .57974 L .36168 .57893 L F
.324 .45 .834 r
.36168 .57893 m .36234 .57537 L .35973 .5765 L F
.879 .855 .814 r
.36471 .57369 m .36234 .57537 L .36475 .57229 L F
.82 .741 .777 r
.36234 .57537 m .36256 .57538 L .36475 .57229 L F
0 0 0 r
.36451 .57388 m .36234 .57537 L .36471 .57369 L F
.82 .741 .777 r
.36256 .57538 m .36593 .57564 L .36515 .57344 L F
.36256 .57538 m .36515 .57344 L .36451 .57388 L F
.324 .45 .834 r
.36168 .57893 m .36345 .57884 L .36238 .57552 L F
.472 .552 .857 r
.36234 .57537 m .36345 .57884 L .36547 .57796 L F
.36234 .57537 m .36547 .57796 L .36593 .57564 L F
0 0 0 r
.36237 .57592 m .36234 .57537 L .36451 .57388 L F
.82 .741 .777 r
.36478 .57367 m .36515 .57344 L .36514 .5734 L F
.36468 .57377 m .36515 .57344 L .36478 .57367 L F
.881 .88 .829 r
.36726 .56913 m .3669 .57164 L .36859 .56979 L F
.3669 .57164 m .36669 .57307 L .36834 .57022 L F
.3669 .57164 m .36834 .57022 L .36859 .56979 L F
.36726 .56913 m .36475 .57229 L .36669 .57307 L F
.952 .784 .637 r
.36576 .5727 m .36593 .57564 L .36669 .57307 L F
.36475 .57229 m .36519 .57329 L .36576 .5727 L F
.36512 .57335 m .36593 .57564 L .36576 .5727 L F
.666 .362 .448 r
.36925 .57018 m .36927 .57067 L .36726 .56913 L F
.816 .58 .582 r
.36908 .57142 m .36889 .57097 L .36934 .57173 L F
.666 .362 .448 r
.36927 .57067 m .36934 .57173 L .36871 .57065 L F
.816 .58 .582 r
.36889 .57097 m .36865 .57038 L .36934 .57173 L F
.666 .362 .448 r
.36871 .57065 m .36889 .57097 L .36847 .57064 L F
.36889 .57097 m .36881 .57106 L .36847 .57064 L F
.36927 .57067 m .36847 .57064 L .36842 .57057 L F
.36874 .57025 m .36842 .57057 L .36726 .56913 L F
.36927 .57067 m .36842 .57057 L .36874 .57025 L F
0 0 0 r
.36835 .57064 m .36499 .57349 L .36527 .57322 L F
.393 .311 .645 r
.36726 .56913 m .36881 .57106 L .36865 .57038 L F
0 0 0 r
.36865 .57038 m .36833 .57066 L .36835 .57064 L F
.36833 .57066 m .36499 .57349 L .36835 .57064 L F
.816 .58 .582 r
.36889 .57097 m .3688 .57104 L .36865 .57038 L F
.666 .362 .448 r
.36889 .57097 m .36934 .57173 L .36881 .57106 L F
.393 .311 .645 r
.36881 .57106 m .36934 .57173 L .36865 .57038 L F
.816 .58 .582 r
.3688 .57104 m .36549 .57352 L .36865 .57038 L F
.36908 .57142 m .36777 .57218 L .36889 .57097 L F
.36777 .57218 m .36549 .57352 L .36889 .57097 L F
0 0 0 r
.36815 .57063 m .36519 .57329 L .36475 .57229 L F
.36865 .57038 m .36835 .57064 L .36815 .57063 L F
.36835 .57064 m .36519 .57329 L .36815 .57063 L F
.36519 .57329 m .36471 .57369 L .36475 .57229 L F
.952 .784 .637 r
.36475 .57229 m .36512 .57335 L .36519 .57329 L F
0 0 0 r
.36527 .57322 m .36478 .57367 L .36471 .57369 L F
.36478 .57367 m .36472 .57372 L .36471 .57369 L F
.82 .741 .777 r
.36256 .57538 m .36514 .5734 L .36475 .57229 L F
0 0 0 r
.36499 .57349 m .36478 .57367 L .36512 .57335 L F
.36499 .57349 m .36512 .57335 L .36527 .57322 L F
.36865 .57038 m .36549 .57352 L .36485 .57366 L F
.36518 .57333 m .36485 .57366 L .36478 .57367 L F
.36865 .57038 m .36485 .57366 L .36518 .57333 L F
.82 .741 .777 r
.36451 .57388 m .36468 .57377 L .36478 .57367 L F
0 0 0 r
.36549 .57352 m .36479 .57406 L .36472 .57372 L F
.36549 .57352 m .36472 .57372 L .36478 .57367 L F
.36479 .57406 m .36237 .57592 L .3635 .57484 L F
.36479 .57406 m .3635 .57484 L .36471 .57369 L F
.324 .45 .834 r
.3623 .57557 m .36238 .57552 L .36234 .57537 L F
.36168 .57893 m .36238 .57552 L .3623 .57557 L F
.611 .834 .985 r
.74293 .31678 m .74516 .31577 L .74484 .31439 L F
.74293 .31678 m .74516 .31577 L .74484 .31439 L F
.156 .261 .722 r
.43401 .52748 m .43275 .52934 L .43168 .52543 L F
.163 .272 .73 r
.43401 .52748 m .43522 .53142 L .43275 .52934 L F
.246 .282 .702 r
.43275 .52934 m .43522 .53142 L .43382 .53193 L F
.746 .518 .584 r
.61381 .443 m .61165 .44045 L .6147 .44039 L F
.469 .892 .829 r
.61016 .39109 m .60978 .39169 L .60765 .39265 L F
.61016 .39109 m .60765 .39265 L .60642 .39403 L F
.628 .763 .944 r
.60338 .41987 m .60371 .42177 L .60037 .42082 L F
.126 .356 .818 r
.60663 .42346 m .60371 .42177 L .60338 .41987 L F
.792 .742 .806 r
.39473 .5826 m .3927 .58396 L .39067 .58164 L F
.994 .81 .44 r
.40957 .54483 m .40868 .54379 L .40906 .54117 L F
.971 .706 .286 r
.40868 .54379 m .40755 .53995 L .40906 .54117 L F
.40868 .54379 m .40771 .54268 L .40755 .53995 L F
0 0 .491 r
.40868 .54379 m .40968 .54439 L .40776 .54272 L F
.40868 .54379 m .40776 .54272 L .40771 .54268 L F
.994 .81 .44 r
.40958 .54491 m .40868 .54379 L .40957 .54483 L F
0 0 .474 r
.41008 .54741 m .40868 .54379 L .40958 .54491 L F
.496 .31 .558 r
.33319 .60179 m .33307 .60459 L .33066 .60503 L F
.512 .293 .519 r
.33307 .60459 m .32975 .60592 L .33066 .60503 L F
.618 .842 .985 r
.36231 .6714 m .36563 .67187 L .36326 .6706 L F
.825 .573 .558 r
.36231 .6714 m .36477 .67423 L .36563 .67187 L F
.949 .738 .583 r
.36563 .67187 m .36477 .67423 L .36326 .6706 L F
.62 .209 .242 r
.6799 .36132 m .68267 .36304 L .68004 .36305 L F
.595 .258 .37 r
.68263 .36133 m .68267 .36304 L .6799 .36132 L F
.843 .426 0 r
.40328 .52906 m .40212 .52793 L .40117 .52584 L F
.981 .688 .339 r
.40368 .53173 m .40212 .52793 L .40328 .52906 L F
.74 .563 .654 r
.36181 .64298 m .36407 .63974 L .36146 .63981 L F
.592 .363 .538 r
.33701 .57335 m .33665 .57606 L .33383 .57631 L F
.456 .244 .502 r
.33963 .57496 m .33701 .57335 L .33954 .57215 L F
.33963 .57496 m .33665 .57606 L .33701 .57335 L F
.808 .547 .544 r
.32133 .68794 m .32167 .69075 L .31809 .68976 L F
.32133 .68794 m .31876 .68938 L .31999 .69021 L F
.31876 .68938 m .31809 .68976 L .31999 .69021 L F
.707 .181 0 r
.32167 .69075 m .32108 .69114 L .31999 .69021 L F
.009 .198 .71 r
.32095 .69085 m .31999 .69021 L .32108 .69114 L F
.808 .547 .544 r
.32133 .68794 m .31999 .69021 L .32151 .6872 L F
0 .461 .745 r
.31809 .68976 m .31916 .69006 L .31999 .69021 L F
.31916 .69006 m .32167 .69075 L .31999 .69021 L F
.009 .198 .71 r
.32074 .69034 m .31999 .69021 L .32095 .69085 L F
.706 .825 .376 r
.32151 .6872 m .31999 .69021 L .32215 .6857 L F
.944 .928 .758 r
.32215 .6857 m .31999 .69021 L .31981 .68817 L F
.009 .198 .71 r
.31981 .68817 m .31999 .69021 L .32074 .69034 L F
.986 .731 .459 r
.26957 .53832 m .27038 .54075 L .27248 .54006 L F
.26957 .53832 m .26944 .54105 L .27038 .54075 L F
.565 .587 .834 r
.37481 .55103 m .37101 .54805 L .37337 .54719 L F
.382 0 0 r
.37337 .54719 m .37768 .54829 L .37481 .55103 L F
.112 .342 .81 r
.40465 .53537 m .40758 .53733 L .40539 .53376 L F
.499 .544 .834 r
.23264 .5802 m .23554 .58181 L .23487 .57905 L F
.708 .888 .963 r
.36055 .51313 m .36117 .51525 L .36251 .51377 L F
.36055 .51313 m .3567 .5144 L .36117 .51525 L F
.419 .151 .398 r
.39506 .55847 m .39326 .56066 L .39172 .55664 L F
.39506 .55847 m .39609 .56 L .39326 .56066 L F
.605 .069 0 r
.70444 .3578 m .70615 .35764 L .7049 .35874 L F
.607 .072 0 r
.7049 .35874 m .70615 .35764 L .70913 .35976 L F
0 0 0 r
.21887 .54771 m .22058 .54695 L .22211 .545 L F
.693 .945 .662 r
.22469 .54222 m .22211 .545 L .22318 .54354 L F
0 0 0 r
.22211 .545 m .22195 .54572 L .22318 .54354 L F
.22211 .545 m .22058 .54695 L .22195 .54572 L F
.819 .797 .832 r
.71135 .29238 m .70755 .29357 L .71007 .2908 L F
.874 .457 .221 r
.71249 .29248 m .71404 .2916 L .71135 .29238 L F
.71249 .29248 m .71135 .29238 L .71007 .2908 L F
.69 .955 .951 r
.2425 .58741 m .24005 .58881 L .24124 .58916 L F
.693 .41 0 r
.39361 .53367 m .39363 .53365 L .39269 .53283 L F
.39361 .53367 m .39402 .53506 L .39363 .53365 L F
.64 .08 0 r
.2748 .63867 m .27824 .64063 L .27714 .63884 L F
.694 .294 0 r
.27824 .64063 m .27923 .64261 L .27714 .63884 L F
.733 .529 .616 r
.37495 .58261 m .3787 .58074 L .37478 .57957 L F
0 .347 .701 r
.35142 .50165 m .35333 .50246 L .3551 .50329 L F
0 .392 .781 r
.3555 .50304 m .3551 .50329 L .35333 .50246 L F
.3555 .50304 m .35746 .50428 L .3551 .50329 L F
.372 .247 .578 r
.27292 .55631 m .27078 .56011 L .27053 .55764 L F
.586 .464 .681 r
.39203 .65887 m .3949 .65854 L .39446 .65588 L F
.488 .357 .628 r
.30844 .57815 m .31045 .58158 L .31047 .57826 L F
.30844 .57815 m .30868 .58257 L .31045 .58158 L F
.7 .739 .882 r
.35451 .57952 m .35858 .57974 L .35696 .57841 L F
.776 .543 .583 r
.35405 .58205 m .35858 .57974 L .35451 .57952 L F
.35405 .58205 m .3585 .58249 L .35858 .57974 L F
.73 .507 .59 r
.61165 .44045 m .61231 .44352 L .60855 .44287 L F
.746 .518 .584 r
.61381 .443 m .61231 .44352 L .61165 .44045 L F
0 0 .127 r
.31112 .52988 m .31137 .53347 L .31105 .5299 L F
.31127 .53095 m .31137 .53347 L .31112 .52988 L F
.31122 .52985 m .31127 .53095 L .31112 .52988 L F
.933 .959 .765 r
.31122 .52985 m .30915 .53352 L .31137 .53347 L F
.703 .168 0 r
.31137 .53347 m .30915 .53352 L .31122 .53397 L F
0 .045 .613 r
.31153 .53281 m .31122 .53397 L .30915 .53352 L F
.308 0 .239 r
.3084 .53579 m .31153 .53281 L .30915 .53352 L F
.151 .678 .872 r
.29434 .74407 m .29843 .74444 L .29701 .74405 L F
.29434 .74407 m .29843 .74444 L .29701 .74405 L F
.255 0 0 r
.26034 .6315 m .25847 .63113 L .2563 .63032 L F
.091 .646 .8 r
.26142 .6312 m .26034 .6315 L .26265 .63129 L F
.26142 .6312 m .25847 .63113 L .26034 .6315 L F
.248 0 0 r
.3641 .71305 m .36507 .71375 L .3633 .714 L F
.3641 .71305 m .36596 .71326 L .36507 .71375 L F
.482 0 0 r
.37768 .54829 m .38015 .54962 L .37854 .54778 L F
0 0 .405 r
.38015 .54962 m .38006 .54535 L .37854 .54778 L F
.604 .325 .466 r
.30548 .61136 m .30332 .61409 L .30196 .61372 L F
0 0 0 r
.30603 .61258 m .30548 .61136 L .30594 .60994 L F
.30603 .61258 m .30332 .61409 L .30548 .61136 L F
.656 .922 .976 r
.65148 .41406 m .64953 .41819 L .65049 .41554 L F
.447 .054 .2 r
.64953 .41819 m .65269 .41764 L .65195 .41908 L F
0 0 .458 r
.64953 .41819 m .65101 .41876 L .65049 .41554 L F
.447 .054 .2 r
.64953 .41819 m .65195 .41908 L .65002 .42071 L F
0 0 .458 r
.64953 .41819 m .65002 .42071 L .65101 .41876 L F
.212 .622 .952 r
.64292 .40393 m .64682 .40568 L .64563 .40448 L F
.659 .876 .98 r
.64563 .40448 m .64682 .40568 L .64915 .40436 L F
.587 .598 .831 r
.36955 .54355 m .37101 .54805 L .37337 .54719 L F
.173 0 0 r
.36928 .54959 m .37337 .54719 L .37101 .54805 L F
.785 .537 .561 r
.37378 .56072 m .36963 .5628 L .37027 .56114 L F
.37378 .56072 m .37367 .56336 L .36963 .5628 L F
.725 .618 .738 r
.37653 .55676 m .37378 .56072 L .37274 .55682 L F
.52 .441 .707 r
.33499 .52403 m .33164 .5232 L .33505 .52247 L F
.33499 .52403 m .33278 .52569 L .33164 .5232 L F
.33164 .5232 m .33278 .52569 L .33499 .52403 L F
.648 .907 .982 r
.62957 .38551 m .62577 .38623 L .62816 .38521 L F
.504 .717 .967 r
.62961 .38329 m .62957 .38551 L .62816 .38521 L F
.62961 .38329 m .63317 .38598 L .62957 .38551 L F
.2 0 0 r
.37911 .71182 m .38046 .71217 L .37957 .71222 L F
.217 0 .163 r
.37718 .71273 m .37866 .71142 L .37911 .71182 L F
.2 0 0 r
.37911 .71182 m .37957 .71222 L .37689 .71239 L F
.217 0 .163 r
.37866 .71142 m .38027 .70998 L .37911 .71182 L F
0 0 0 r
.37911 .71182 m .38027 .70998 L .38208 .70899 L F
.481 .351 .626 r
.24836 .56292 m .24611 .56694 L .24572 .56355 L F
.134 .144 .604 r
.31985 .63087 m .32174 .63266 L .32268 .62988 L F
.31985 .63087 m .32024 .63348 L .32174 .63266 L F
.083 0 .285 r
.21075 .55723 m .21261 .55648 L .21316 .55384 L F
.121 0 .101 r
.21075 .55723 m .21185 .55865 L .21261 .55648 L F
.21075 .55723 m .20998 .55954 L .21185 .55865 L F
.231 .706 .938 r
.37758 .53155 m .37968 .53147 L .37572 .53076 L F
.37758 .53155 m .37968 .53147 L .37572 .53076 L F
.574 .002 0 r
.22797 .60379 m .22954 .60496 L .23125 .60562 L F
0 .021 .564 r
.2321 .60609 m .23125 .60562 L .22954 .60496 L F
.2321 .60609 m .23338 .60796 L .23125 .60562 L F
.924 .636 .156 r
.70294 .34622 m .70369 .34719 L .70345 .34528 L F
.579 .027 0 r
.70698 .34801 m .70345 .34528 L .70369 .34719 L F
0 .058 .616 r
.3949 .65854 m .39604 .662 L .39605 .65927 L F
.924 .911 .518 r
.39606 .65829 m .39605 .65927 L .39518 .65995 L F
.03 0 .445 r
.3949 .65854 m .39605 .65927 L .39654 .65737 L F
.924 .911 .518 r
.39654 .65737 m .39605 .65927 L .39606 .65829 L F
0 .058 .616 r
.39604 .662 m .39614 .6623 L .39605 .65927 L F
.811 .917 .909 r
.39605 .65927 m .39614 .6623 L .39438 .66143 L F
0 0 0 r
.3681 .65894 m .36787 .65943 L .36755 .65899 L F
.007 0 0 r
.36787 .65943 m .3689 .65871 L .36766 .65988 L F
0 0 0 r
.3702 .65874 m .36787 .65943 L .3681 .65894 L F
.007 0 0 r
.36787 .65943 m .36766 .65988 L .36692 .66059 L F
.782 .593 .643 r
.33865 .54403 m .34367 .54472 L .3432 .54221 L F
.407 .388 .726 r
.34367 .54472 m .34503 .54049 L .3432 .54221 L F
.315 .775 .636 r
.35967 .65782 m .36461 .65538 L .36305 .65499 L F
.754 .968 .93 r
.36305 .65499 m .36461 .65538 L .3673 .65271 L F
.285 .09 .431 r
.30409 .58922 m .30584 .58956 L .30674 .58885 L F
.30409 .58922 m .3037 .59192 L .30584 .58956 L F
.515 .32 .554 r
.30409 .58922 m .30674 .58885 L .30793 .58639 L F
.889 .598 .088 r
.60398 .40408 m .60475 .40547 L .6051 .40791 L F
0 .448 .808 r
.34714 .60492 m .35254 .6069 L .34943 .60448 L F
.86 .921 .528 r
.64599 .42285 m .64657 .42303 L .64452 .4272 L F
.195 .682 .927 r
.64858 .41995 m .64657 .42303 L .64599 .42285 L F
.632 .095 0 r
.70591 .34838 m .70698 .34801 L .70369 .34719 L F
.055 .604 .835 r
.70829 .34777 m .70698 .34801 L .70591 .34838 L F
.70829 .34777 m .70977 .34829 L .70698 .34801 L F
.784 .57 .61 r
.59874 .39088 m .59724 .39231 L .60055 .38902 L F
.207 .496 .903 r
.60105 .39138 m .59874 .39088 L .60055 .38902 L F
.32 .742 .975 r
.27993 .61484 m .27791 .61385 L .27563 .61399 L F
.446 .477 .798 r
.28053 .61023 m .27993 .61484 L .27817 .61078 L F
.28053 .61023 m .28234 .61482 L .27993 .61484 L F
.31 .681 .977 r
.27993 .61484 m .28042 .61352 L .27791 .61385 L F
.27993 .61484 m .28234 .61482 L .28042 .61352 L F
.264 0 .039 r
.34688 .59203 m .34307 .59475 L .34484 .59329 L F
.57 .01 0 r
.36344 .50588 m .36754 .50885 L .36481 .50717 L F
.718 .896 .96 r
.2806 .62585 m .27855 .62734 L .28243 .62691 L F
.598 .132 .119 r
.27855 .62734 m .28047 .62878 L .28243 .62691 L F
.978 .735 .498 r
.28243 .62691 m .28047 .62878 L .2806 .62585 L F
.768 .67 .755 r
.32716 .66516 m .32489 .66907 L .3231 .66453 L F
0 0 0 r
.32273 .66991 m .32489 .66907 L .32722 .66836 L F
0 0 .056 r
.35955 .59984 m .3588 .59866 L .35968 .59657 L F
.52 .404 .661 r
.36385 .59238 m .36584 .59722 L .35968 .59657 L F
.413 0 0 r
.35968 .59657 m .36169 .5989 L .35955 .59984 L F
.35968 .59657 m .36584 .59722 L .36169 .5989 L F
0 0 .1 r
.35955 .59984 m .3588 .59866 L .35968 .59657 L F
.447 .881 .853 r
.25417 .52644 m .25352 .52592 L .25634 .5255 L F
.25417 .52644 m .25167 .52679 L .25352 .52592 L F
0 0 .218 r
.38983 .57023 m .38981 .57336 L .3904 .57164 L F
.38983 .57023 m .3904 .57164 L .38773 .57213 L F
.812 .654 .687 r
.37814 .54531 m .3779 .54506 L .37666 .54528 L F
.843 .99 .729 r
.57599 .42586 m .57582 .42765 L .57825 .42445 L F
0 0 .371 r
.57706 .42826 m .57582 .42765 L .57599 .42586 L F
.57706 .42826 m .576 .42954 L .57582 .42765 L F
.834 .703 .719 r
.3673 .65271 m .37161 .65348 L .36959 .65148 L F
.22 .513 .912 r
.36959 .65148 m .37161 .65348 L .37189 .6519 L F
0 .123 .669 r
.37189 .6519 m .37161 .65348 L .37332 .65525 L F
.178 .324 .775 r
.35543 .64305 m .35811 .64562 L .35804 .6428 L F
.466 .242 .489 r
.35624 .55715 m .35639 .5603 L .35353 .5609 L F
.564 .315 .497 r
.35878 .5597 m .35624 .55715 L .35772 .55612 L F
.35878 .5597 m .35639 .5603 L .35624 .55715 L F
.866 .995 .766 r
.24927 .54853 m .2471 .54969 L .24961 .5464 L F
.589 .175 .225 r
.30772 .54038 m .30707 .53826 L .30643 .53816 L F
.365 .196 .515 r
.25074 .55726 m .25042 .56015 L .24862 .5607 L F
.123 0 .254 r
.25042 .56015 m .24836 .56292 L .24862 .5607 L F
0 .103 .625 r
.24685 .62617 m .24672 .62554 L .24478 .625 L F
.24685 .62617 m .24807 .62723 L .24672 .62554 L F
.495 .721 .972 r
.24857 .61507 m .24745 .61708 L .24591 .61377 L F
.24857 .61507 m .24982 .61674 L .24745 .61708 L F
.69 .466 .577 r
.35346 .58544 m .35303 .58848 L .34932 .58865 L F
0 0 .186 r
.35385 .58739 m .35346 .58544 L .35382 .58602 L F
.35385 .58739 m .35303 .58848 L .35346 .58544 L F
.512 .293 .519 r
.33307 .60459 m .33295 .60733 L .32975 .60592 L F
.298 .19 .559 r
.33245 .60965 m .32975 .60592 L .33295 .60733 L F
.33245 .60965 m .33076 .61051 L .32975 .60592 L F
.874 .457 .221 r
.71249 .29248 m .71431 .29318 L .71404 .2916 L F
.805 .655 .696 r
.71431 .29318 m .71677 .29076 L .71404 .2916 L F
.648 .776 .941 r
.34684 .50064 m .34444 .50145 L .34277 .49981 L F
0 .23 .658 r
.34706 .57317 m .34728 .5731 L .34573 .5717 L F
.34706 .57317 m .34956 .57467 L .34728 .5731 L F
.318 .121 .447 r
.34737 .57596 m .34956 .57467 L .34706 .57317 L F
0 .189 .678 r
.31729 .64134 m .31509 .63984 L .31445 .64246 L F
.689 .837 .954 r
.24843 .53766 m .25023 .53903 L .25239 .53743 L F
.665 .249 .245 r
.39445 .59152 m .39748 .59187 L .3957 .5938 L F
.521 .034 .041 r
.39748 .59187 m .39857 .59378 L .3957 .5938 L F
.39748 .59187 m .40014 .59212 L .39857 .59378 L F
.087 .261 .746 r
.60714 .4115 m .6085 .41519 L .60872 .41367 L F
0 .026 .557 r
.6085 .41519 m .61039 .41565 L .60872 .41367 L F
.6085 .41519 m .60931 .41757 L .61039 .41565 L F
.825 .834 .855 r
.69439 .30979 m .69123 .30934 L .69392 .30631 L F
.69439 .30979 m .69262 .31069 L .69123 .30934 L F
.827 .837 .855 r
.69711 .30648 m .69439 .30979 L .69392 .30631 L F
.377 .729 .99 r
.33637 .49943 m .34039 .50052 L .33755 .5002 L F
.482 .009 .055 r
.36675 .51301 m .36528 .51499 L .36251 .51377 L F
.993 .745 .439 r
.3664 .51518 m .36528 .51499 L .36675 .51301 L F
0 .173 .709 r
.61381 .443 m .61643 .44653 L .61586 .44501 L F
.563 .108 0 r
.61643 .44653 m .61723 .44759 L .61586 .44501 L F
.61643 .44653 m .61876 .44958 L .61723 .44759 L F
0 0 0 r
.61867 .4193 m .61712 .42125 L .61962 .41753 L F
.627 .906 .607 r
.61748 .42076 m .61712 .42125 L .61867 .4193 L F
.424 .013 .154 r
.27298 .62047 m .27572 .62025 L .27726 .61782 L F
.35 0 .112 r
.27726 .61782 m .27886 .61894 L .27969 .61775 L F
.27726 .61782 m .27572 .62025 L .27886 .61894 L F
.52 .402 .659 r
.34893 .59916 m .35168 .60115 L .35238 .59775 L F
.34893 .59916 m .34937 .60172 L .35168 .60115 L F
.354 0 0 r
.33457 .5713 m .33797 .56958 L .33667 .57086 L F
.432 .447 .775 r
.42884 .51836 m .4272 .51995 L .42625 .51606 L F
.488 .538 .834 r
.42884 .51836 m .4305 .52135 L .4272 .51995 L F
.843 .99 .729 r
.57599 .42586 m .57825 .42445 L .57507 .42463 L F
.731 .97 .932 r
.57742 .42384 m .57825 .42445 L .57959 .42215 L F
.57742 .42384 m .57825 .42445 L .57959 .42215 L F
.557 .753 .969 r
.57825 .42445 m .58078 .42386 L .57959 .42215 L F
.782 .891 .922 r
.38135 .64588 m .38304 .64689 L .38446 .64334 L F
0 0 .361 r
.23568 .61011 m .23534 .61083 L .23511 .60824 L F
.23568 .61011 m .23511 .60824 L .23338 .60796 L F
.677 .559 .714 r
.42236 .51284 m .41996 .51463 L .41888 .50962 L F
0 .374 .809 r
.59514 .41025 m .59259 .40847 L .59597 .40994 L F
.304 0 0 r
.59359 .40903 m .596 .40995 L .59597 .40994 L F
0 .266 .759 r
.59712 .41147 m .59597 .40994 L .59603 .40996 L F
.304 0 0 r
.596 .40995 m .59603 .40996 L .59597 .40994 L F
0 .374 .809 r
.59259 .40847 m .59239 .40834 L .59597 .40994 L F
0 .266 .759 r
.59712 .41147 m .59514 .41025 L .59597 .40994 L F
.613 .806 .974 r
.41888 .50962 m .41442 .50859 L .41677 .50879 L F
.885 .903 .836 r
.41888 .50962 m .41941 .5054 L .42096 .50665 L F
.41888 .50962 m .41677 .50879 L .41941 .5054 L F
.646 .546 .728 r
.42117 .50912 m .41888 .50962 L .42096 .50665 L F
.677 .559 .714 r
.42236 .51284 m .41888 .50962 L .42117 .50912 L F
.976 .885 .673 r
.35148 .51682 m .3494 .51804 L .3504 .5157 L F
.94 .913 .763 r
.3504 .5157 m .35148 .51682 L .35226 .51457 L F
.976 .885 .673 r
.3504 .5157 m .3494 .51804 L .35148 .51682 L F
.715 .642 .774 r
.35226 .51457 m .35148 .51682 L .35482 .51605 L F
.381 .489 .844 r
.35148 .51682 m .35452 .51875 L .35482 .51605 L F
0 .096 .649 r
.31396 .56309 m .31542 .56702 L .31584 .56503 L F
.686 .486 .61 r
.31903 .56699 m .31507 .56968 L .31542 .56702 L F
0 0 .018 r
.31542 .56702 m .31575 .56784 L .31584 .56503 L F
.31542 .56702 m .31507 .56968 L .31575 .56784 L F
.103 .007 .45 r
.19907 .57645 m .20028 .57569 L .20031 .57302 L F
.131 .06 .503 r
.19907 .57645 m .20045 .57844 L .20028 .57569 L F
.16 .068 .494 r
.19915 .57916 m .20045 .57844 L .19907 .57645 L F
.274 .597 .95 r
.38206 .5173 m .38144 .51879 L .37998 .51713 L F
.068 .343 .819 r
.38206 .5173 m .38293 .51924 L .38144 .51879 L F
.477 0 0 r
.23395 .61793 m .23481 .6188 L .23354 .61665 L F
.23395 .61793 m .23655 .61983 L .23481 .6188 L F
0 .243 .729 r
.42268 .55331 m .42245 .55388 L .42014 .55356 L F
.42268 .55331 m .42486 .55551 L .42245 .55388 L F
.568 .341 .531 r
.42541 .55746 m .42245 .55388 L .42486 .55551 L F
0 0 0 r
.61867 .4193 m .61962 .41753 L .61845 .4165 L F
.261 .09 .451 r
.33865 .54403 m .33721 .54481 L .33894 .54138 L F
.721 .455 0 r
.33719 .54511 m .33721 .54481 L .33865 .54403 L F
.261 .09 .451 r
.33894 .54138 m .33721 .54481 L .33865 .54403 L F
.34 .82 .849 r
.7239 .33894 m .72696 .33808 L .72723 .33836 L F
0 0 0 r
.72761 .33794 m .72939 .33675 L .73006 .33532 L F
.72857 .3367 m .73033 .33612 L .72939 .33675 L F
.008 0 0 r
.73006 .33532 m .72939 .33675 L .73175 .33564 L F
0 0 0 r
.73033 .33612 m .73175 .33564 L .72939 .33675 L F
.72723 .33836 m .72939 .33675 L .72761 .33794 L F
.497 .904 .813 r
.72723 .33836 m .72696 .33808 L .72939 .33675 L F
.465 .786 .999 r
.22518 .55572 m .22444 .55726 L .22701 .55431 L F
.22518 .55572 m .22697 .55682 L .22444 .55726 L F
.493 .282 .521 r
.22657 .55958 m .22418 .56022 L .22444 .55726 L F
.866 .986 .839 r
.60084 .42962 m .59896 .43192 L .59769 .43201 L F
.345 0 0 r
.59912 .43263 m .60118 .43116 L .59769 .43201 L F
0 .223 .734 r
.59912 .43263 m .59769 .43201 L .59765 .43176 L F
.59836 .43131 m .59765 .43176 L .59729 .42943 L F
.866 .986 .839 r
.60084 .42962 m .59769 .43201 L .60118 .43116 L F
0 .223 .734 r
.59912 .43263 m .59765 .43176 L .59836 .43131 L F
.329 .808 .894 r
.59729 .43199 m .59627 .43258 L .59586 .43204 L F
.59896 .43192 m .59641 .43254 L .59729 .43199 L F
.59641 .43254 m .59627 .43258 L .59729 .43199 L F
.763 .486 .513 r
.60441 .44281 m .60197 .4403 L .6042 .44011 L F
.60441 .44281 m .60269 .44283 L .60197 .4403 L F
.254 0 0 r
.2183 .59258 m .22077 .59238 L .22119 .59174 L F
.621 .576 .782 r
.22119 .59174 m .22381 .58821 L .2215 .58897 L F
.22119 .59174 m .22466 .59212 L .22381 .58821 L F
.264 .768 .87 r
.22077 .59238 m .22466 .59212 L .22119 .59174 L F
.465 .786 .999 r
.22518 .55572 m .22701 .55431 L .225 .55327 L F
.833 .872 .872 r
.22963 .55142 m .22701 .55431 L .22965 .55143 L F
.22739 .55234 m .22701 .55431 L .22963 .55142 L F
.22776 .55048 m .225 .55327 L .22701 .55431 L F
.526 .92 .837 r
.22901 .55413 m .22518 .55572 L .22501 .55332 L F
.22508 .55329 m .22501 .55332 L .225 .55327 L F
.22901 .55413 m .22501 .55332 L .22508 .55329 L F
.833 .872 .872 r
.22776 .55048 m .22739 .55234 L .22963 .55142 L F
.472 .887 .923 r
.36984 .71325 m .37097 .7139 L .3733 .71299 L F
0 0 .146 r
.31866 .58835 m .31758 .58926 L .31929 .58558 L F
.233 .015 .364 r
.3188 .59096 m .31758 .58926 L .31866 .58835 L F
.3188 .59096 m .31698 .59177 L .31758 .58926 L F
0 0 0 r
.21316 .55384 m .21491 .55301 L .2161 .55062 L F
0 0 .003 r
.2161 .55062 m .21776 .5502 L .21887 .54771 L F
0 0 0 r
.2161 .55062 m .21619 .55166 L .21776 .5502 L F
.2161 .55062 m .21491 .55301 L .21619 .55166 L F
0 0 .376 r
.33438 .60315 m .33319 .60179 L .33569 .60181 L F
.33438 .60315 m .33307 .60459 L .33319 .60179 L F
.733 .576 .679 r
.6783 .33888 m .67606 .34203 L .67416 .33835 L F
.757 .612 .697 r
.6783 .33888 m .67812 .34178 L .67606 .34203 L F
.103 .103 .571 r
.28837 .64035 m .29039 .64201 L .29077 .63924 L F
.28837 .64035 m .28859 .64231 L .29039 .64201 L F
.58 .294 .448 r
.59262 .44321 m .59145 .44599 L .58899 .44611 L F
.663 .384 .487 r
.59544 .44555 m .59262 .44321 L .59539 .44302 L F
.59544 .44555 m .59145 .44599 L .59262 .44321 L F
.69 .457 .565 r
.56718 .44863 m .56297 .44636 L .56718 .44641 L F
.741 .448 .486 r
.56718 .44641 m .5694 .44923 L .56718 .44863 L F
.149 0 0 r
.27628 .55434 m .27292 .55631 L .27348 .55374 L F
.822 .635 .65 r
.70166 .32559 m .70346 .32252 L .70009 .32195 L F
.869 .468 .27 r
.55103 .43788 m .55112 .43723 L .55155 .43927 L F
.74 .402 .41 r
.55112 .43723 m .55563 .43974 L .55155 .43927 L F
.547 .391 .62 r
.34343 .52883 m .34319 .53247 L .34182 .53101 L F
0 .012 .535 r
.34319 .53247 m .34372 .53307 L .34182 .53101 L F
.318 .121 .447 r
.34737 .57596 m .34793 .57704 L .34956 .57467 L F
.211 0 .274 r
.34737 .57596 m .34956 .57467 L .34793 .57704 L F
.318 .121 .447 r
.34737 .57596 m .34793 .57704 L .34956 .57467 L F
.211 0 .274 r
.34737 .57596 m .34697 .57832 L .34956 .57467 L F
.572 .902 .655 r
.29472 .54 m .29721 .54079 L .29553 .53796 L F
.479 .544 .846 r
.29721 .54079 m .2987 .53567 L .29553 .53796 L F
.29721 .54079 m .29926 .54084 L .2987 .53567 L F
.091 0 0 r
.62006 .44963 m .62177 .44996 L .61876 .44958 L F
.62006 .44963 m .62267 .44947 L .62177 .44996 L F
.932 .756 .641 r
.36669 .57307 m .36593 .57564 L .36774 .57634 L F
.608 .043 0 r
.36593 .57564 m .37036 .57844 L .36774 .57634 L F
.481 .849 .989 r
.37539 .71208 m .37718 .71273 L .37911 .71182 L F
0 .399 .689 r
.29253 .62344 m .28991 .62265 L .28737 .62191 L F
.754 .54 .606 r
.2939 .6256 m .28991 .62265 L .29253 .62344 L F
.688 .557 .701 r
.42029 .5479 m .41799 .55107 L .418 .54891 L F
.624 .772 .951 r
.62363 .40821 m .62119 .40932 L .61958 .4072 L F
.62363 .40821 m .62119 .40932 L .61958 .4072 L F
.328 0 0 r
.27992 .55323 m .27807 .55505 L .27628 .55434 L F
.394 0 .074 r
.28166 .55361 m .27807 .55505 L .27992 .55323 L F
.406 .78 .993 r
.32548 .66423 m .32527 .66487 L .3231 .66453 L F
.382 .783 .985 r
.32148 .66372 m .32548 .66423 L .3231 .66453 L F
.738 .348 .312 r
.32357 .66573 m .32548 .66423 L .32148 .66372 L F
.754 .716 .818 r
.32357 .66573 m .32583 .66314 L .32548 .66423 L F
.32583 .66314 m .32615 .66277 L .32548 .66423 L F
.406 .78 .993 r
.32548 .66423 m .32716 .66516 L .32527 .66487 L F
.687 .272 .254 r
.32024 .63348 m .32217 .63616 L .32008 .63616 L F
0 0 0 r
.32174 .63266 m .32024 .63348 L .3197 .63584 L F
.32174 .63266 m .32024 .63348 L .3197 .63584 L F
0 .287 .713 r
.23722 .62158 m .23862 .62203 L .23655 .61983 L F
.23722 .62158 m .2403 .62325 L .23862 .62203 L F
0 .082 .642 r
.25668 .54106 m .25503 .53726 L .25713 .53888 L F
.25668 .54106 m .25694 .53943 L .25503 .53726 L F
.34 .234 .586 r
.25538 .54287 m .25694 .53943 L .25668 .54106 L F
.923 .857 .759 r
.31783 .66677 m .31462 .6693 L .3178 .66663 L F
.98 .858 .646 r
.31786 .66476 m .31786 .66692 L .31783 .66677 L F
.883 .649 .127 r
.31721 .66339 m .31786 .66476 L .31783 .66677 L F
.31721 .66339 m .31775 .66635 L .31812 .66636 L F
.31775 .66635 m .31783 .66677 L .31812 .66636 L F
.791 .991 .883 r
.31515 .66724 m .31812 .66636 L .31603 .66812 L F
.31483 .66851 m .31603 .66812 L .31462 .6693 L F
.31515 .66724 m .31603 .66812 L .31483 .66851 L F
.923 .857 .759 r
.31783 .66677 m .31636 .67047 L .31462 .6693 L F
.312 .749 .967 r
.31636 .67047 m .31672 .6695 L .31462 .6693 L F
.791 .991 .883 r
.31515 .66724 m .31462 .6693 L .31292 .66847 L F
.852 .833 .827 r
.31292 .66847 m .31441 .66984 L .31038 .67176 L F
.484 .069 .177 r
.31038 .67176 m .31441 .66984 L .31305 .67191 L F
.342 0 .096 r
.31305 .67191 m .31441 .66984 L .31554 .67147 L F
.13 .625 .91 r
.31292 .66847 m .31511 .67098 L .31441 .66984 L F
.31511 .67098 m .31554 .67147 L .3154 .67127 L F
.31511 .67098 m .3154 .67127 L .31441 .66984 L F
.978 .745 .516 r
.30867 .67066 m .31079 .66893 L .31038 .67176 L F
.852 .833 .827 r
.31292 .66847 m .31038 .67176 L .31079 .66893 L F
.515 .599 .876 r
.31038 .67176 m .31305 .67191 L .31198 .6694 L F
.092 0 0 r
.31292 .66847 m .31079 .66893 L .3095 .66998 L F
.31292 .66847 m .3095 .66998 L .31006 .66985 L F
.31292 .66847 m .30908 .67033 L .30969 .67013 L F
.31006 .66985 m .3095 .66998 L .30908 .67033 L F
.30969 .67013 m .30908 .67033 L .30867 .67066 L F
.31292 .66847 m .3107 .66961 L .31131 .66783 L F
.3107 .66961 m .30867 .67066 L .31047 .66873 L F
.3107 .66961 m .31047 .66873 L .31131 .66783 L F
.206 .555 .933 r
.31017 .66763 m .3078 .66769 L .30777 .66567 L F
.515 .599 .876 r
.31038 .67176 m .3111 .66874 L .30867 .67066 L F
.3111 .66874 m .31131 .66783 L .31068 .6685 L F
.3111 .66874 m .31068 .6685 L .30867 .67066 L F
.397 0 .032 r
.31108 .66837 m .31114 .66735 L .30853 .6679 L F
0 0 .352 r
.31021 .66808 m .30853 .6679 L .31114 .66735 L F
.206 .555 .933 r
.31029 .66808 m .3078 .66769 L .31017 .66763 L F
.31033 .66822 m .30926 .668 L .31029 .66808 L F
0 0 .352 r
.30926 .668 m .30853 .6679 L .31021 .66808 L F
.206 .555 .933 r
.30926 .668 m .3078 .66769 L .31029 .66808 L F
0 0 .352 r
.31016 .66811 m .30926 .668 L .31021 .66808 L F
.397 0 .032 r
.31009 .66817 m .30853 .6679 L .30926 .668 L F
.31015 .6682 m .30853 .6679 L .31009 .66817 L F
0 0 .352 r
.30936 .66875 m .30853 .6679 L .31016 .66811 L F
.397 0 .032 r
.30926 .668 m .30853 .6679 L .3078 .66769 L F
.31108 .66837 m .31015 .6682 L .31009 .66817 L F
.569 .599 .844 r
.31198 .6694 m .31306 .66906 L .31131 .66783 L F
.634 .939 .961 r
.31515 .66724 m .31292 .66847 L .31131 .66783 L F
.31515 .66724 m .31131 .66783 L .31405 .66662 L F
.569 .599 .844 r
.31353 .66939 m .31176 .66763 L .31131 .66783 L F
0 0 .003 r
.31277 .6664 m .31114 .66735 L .31108 .66837 L F
.515 .599 .876 r
.31088 .66966 m .31198 .6694 L .31131 .66783 L F
.13 .625 .91 r
.31337 .66898 m .31672 .6695 L .31554 .67147 L F
.31292 .66847 m .31402 .66876 L .31337 .66898 L F
.31292 .66847 m .31462 .6693 L .31672 .6695 L F
.31402 .66876 m .31672 .6695 L .31337 .66898 L F
.569 .599 .844 r
.31353 .66939 m .31405 .66662 L .31176 .66763 L F
.31305 .67191 m .31554 .67147 L .31405 .66662 L F
.917 .939 .579 r
.31783 .66677 m .31785 .66883 L .31636 .67047 L F
.481 .006 .051 r
.31636 .67047 m .31785 .66883 L .32039 .66967 L F
.168 0 0 r
.31636 .67047 m .32039 .66967 L .31876 .67033 L F
.312 .749 .967 r
.31636 .67047 m .31876 .67033 L .31672 .6695 L F
.312 0 0 r
.31672 .6695 m .31778 .67067 L .31554 .67147 L F
.552 .588 .844 r
.31405 .66662 m .31554 .67147 L .31778 .67067 L F
0 0 .003 r
.31277 .6664 m .31108 .66837 L .31433 .66697 L F
0 0 0 r
.31087 .6677 m .31277 .6664 L .31232 .66742 L F
.628 .728 .919 r
.31262 .66663 m .31308 .66672 L .31052 .66792 L F
.31308 .66672 m .31433 .66697 L .31224 .66749 L F
.31308 .66672 m .31224 .66749 L .31052 .66792 L F
.31052 .66792 m .31338 .6672 L .31108 .66837 L F
.31338 .6672 m .31412 .66706 L .31108 .66837 L F
.109 .378 .838 r
.31393 .66597 m .31277 .6664 L .31433 .66697 L F
.628 .728 .919 r
.31338 .6672 m .31433 .66697 L .31412 .66706 L F
.744 .529 .603 r
.31175 .66871 m .31433 .66697 L .31308 .66672 L F
.791 .711 .776 r
.31306 .66675 m .31175 .66871 L .31232 .66742 L F
.31388 .66598 m .31232 .66742 L .31277 .6664 L F
.206 .555 .933 r
.31108 .66837 m .31033 .66822 L .31028 .66804 L F
.31108 .66837 m .31028 .66804 L .31052 .66792 L F
0 0 0 r
.30936 .66875 m .31087 .6677 L .31175 .66871 L F
.31087 .6677 m .31232 .66742 L .31175 .66871 L F
.31087 .6677 m .31114 .66735 L .31277 .6664 L F
.31069 .66782 m .31114 .66735 L .31087 .6677 L F
.31021 .66808 m .31114 .66735 L .31066 .66785 L F
.628 .728 .919 r
.30777 .66567 m .31262 .66663 L .31052 .66792 L F
0 0 0 r
.31066 .66785 m .31069 .66782 L .31087 .6677 L F
.744 .529 .603 r
.31175 .66871 m .31308 .66672 L .30777 .66567 L F
.791 .711 .776 r
.31393 .66597 m .31175 .66871 L .31306 .66675 L F
.31393 .66597 m .31232 .66742 L .31388 .66598 L F
0 0 0 r
.30936 .66875 m .31021 .66808 L .31066 .66785 L F
.206 .555 .933 r
.31052 .66792 m .31028 .66804 L .31017 .66763 L F
.515 .599 .876 r
.31038 .67176 m .31198 .6694 L .31088 .66966 L F
.569 .599 .844 r
.31305 .67191 m .31353 .66939 L .31306 .66906 L F
.31305 .67191 m .31306 .66906 L .31198 .6694 L F
0 0 0 r
.31837 .66637 m .31812 .66636 L .31515 .66724 L F
.31984 .66597 m .31812 .66636 L .31837 .66637 L F
.923 .857 .759 r
.31783 .66677 m .3178 .66663 L .31812 .66636 L F
.98 .858 .646 r
.31786 .66692 m .31785 .66883 L .31783 .66677 L F
.387 .845 .891 r
.4054 .50809 m .40632 .50779 L .40806 .50676 L F
.561 .135 .19 r
.40632 .50779 m .41075 .50592 L .40806 .50676 L F
.811 .669 .707 r
.41075 .50592 m .40863 .50934 L .41186 .5098 L F
0 0 0 r
.41075 .50592 m .40998 .50823 L .40863 .50934 L F
.561 .135 .19 r
.40632 .50779 m .40998 .50823 L .41075 .50592 L F
.354 .706 .985 r
.40728 .50643 m .40834 .50713 L .40632 .50779 L F
.40834 .50713 m .40998 .50823 L .40632 .50779 L F
.387 .845 .891 r
.40511 .50823 m .40632 .50779 L .4054 .50809 L F
.247 .137 .526 r
.2003 .57022 m .2024 .57169 L .2025 .56904 L F
.2003 .57022 m .20031 .57302 L .2024 .57169 L F
.534 .763 .982 r
.35784 .66358 m .35698 .66576 L .35499 .6667 L F
.35784 .66358 m .35954 .66525 L .35698 .66576 L F
.356 .798 .958 r
.37653 .55676 m .37505 .55637 L .37274 .55682 L F
.725 .618 .738 r
.37653 .55676 m .37274 .55682 L .37505 .55637 L F
.703 .598 .736 r
.28694 .54172 m .28857 .53783 L .28633 .53861 L F
.555 .368 .583 r
.43382 .53193 m .43333 .53514 L .43064 .53556 L F
.554 .227 .368 r
.43333 .53514 m .43068 .53678 L .43064 .53556 L F
.764 .979 .914 r
.38673 .65039 m .38737 .6483 L .38907 .64974 L F
.38673 .65039 m .38451 .6503 L .38737 .6483 L F
.039 0 0 r
.32684 .63365 m .32699 .63427 L .32513 .63572 L F
.32684 .63365 m .32931 .63322 L .32699 .63427 L F
.719 .308 0 r
.4121 .55088 m .4113 .54999 L .41008 .54741 L F
0 0 .258 r
.4121 .55088 m .41266 .552 L .4113 .54999 L F
.4121 .55088 m .41277 .553 L .41266 .552 L F
.936 .933 .577 r
.29999 .52667 m .30066 .52733 L .30226 .52658 L F
0 0 .002 r
.21887 .54771 m .21949 .54903 L .22058 .54695 L F
.21887 .54771 m .21776 .5502 L .21949 .54903 L F
.614 .365 .517 r
.23527 .5538 m .2393 .55632 L .24001 .55469 L F
.417 0 .075 r
.24001 .55469 m .24165 .55594 L .24247 .55372 L F
.24001 .55469 m .2393 .55632 L .24165 .55594 L F
0 0 0 r
.31218 .65593 m .30903 .65913 L .3112 .65837 L F
.721 .591 .71 r
.3112 .65837 m .31414 .65476 L .31218 .65593 L F
.598 .836 .989 r
.29764 .51864 m .29534 .51954 L .29588 .51752 L F
.712 .938 .96 r
.29588 .51752 m .29534 .51954 L .29416 .51878 L F
.989 .886 .616 r
.40735 .58111 m .40911 .57933 L .4076 .57848 L F
.40735 .58111 m .40831 .58212 L .40911 .57933 L F
0 0 0 r
.41911 .54954 m .41799 .55107 L .42029 .5479 L F
.135 .216 .684 r
.41911 .54954 m .42014 .55356 L .41799 .55107 L F
.67 .728 .893 r
.27836 .52138 m .28225 .52229 L .27981 .52328 L F
0 0 .147 r
.26159 .55722 m .26262 .55664 L .26334 .55422 L F
.478 .179 .379 r
.26334 .55422 m .26519 .556 L .26589 .55433 L F
.26334 .55422 m .26262 .55664 L .26519 .556 L F
.198 .011 .387 r
.32936 .59876 m .32909 .60127 L .331 .59777 L F
.6 .796 .974 r
.32456 .51152 m .32378 .51388 L .32674 .51317 L F
.931 .808 .702 r
.58521 .4035 m .58686 .40493 L .58536 .40809 L F
.291 .641 .966 r
.58792 .40369 m .58686 .40493 L .58521 .4035 L F
.295 .647 .968 r
.5893 .40509 m .58686 .40493 L .58792 .40369 L F
.828 .638 .646 r
.71265 .36042 m .70885 .36219 L .71172 .3595 L F
.762 .685 .777 r
.22418 .56022 m .22567 .56388 L .2219 .56302 L F
.772 .406 .363 r
.22567 .56388 m .22652 .56634 L .2219 .56302 L F
.521 .556 .832 r
.22775 .5631 m .22567 .56388 L .22418 .56022 L F
.018 .004 .496 r
.2281 .5648 m .22567 .56388 L .22775 .5631 L F
.157 .243 .703 r
.60931 .41757 m .61003 .4211 L .61142 .41943 L F
0 0 .025 r
.61142 .41943 m .61003 .4211 L .60997 .42272 L F
.907 .783 .713 r
.2624 .56272 m .26018 .56335 L .26132 .56071 L F
.742 .343 .295 r
.2624 .56272 m .26057 .56522 L .26018 .56335 L F
.671 .251 .24 r
.26443 .56379 m .26057 .56522 L .2624 .56272 L F
0 0 .416 r
.41686 .56739 m .41781 .56966 L .41659 .56593 L F
.707 .966 .723 r
.71826 .34133 m .72016 .33878 L .72117 .34017 L F
.71826 .34133 m .71789 .34104 L .72016 .33878 L F
.746 .573 .66 r
.67812 .34178 m .67571 .34466 L .67606 .34203 L F
.67812 .34178 m .68001 .34564 L .67571 .34466 L F
.682 .547 .695 r
.68255 .34204 m .68001 .34564 L .67812 .34178 L F
0 0 0 r
.37027 .56114 m .36963 .5628 L .36937 .56281 L F
.626 .842 .454 r
.70724 .33301 m .70619 .33434 L .7059 .3349 L F
.328 .442 .824 r
.70591 .32999 m .70881 .33123 L .70724 .33301 L F
.759 .885 .474 r
.70735 .33199 m .70724 .33301 L .70881 .33123 L F
.573 .395 .602 r
.41602 .53106 m .41206 .53266 L .41351 .53149 L F
.62 .488 .68 r
.3589 .52628 m .35609 .52602 L .35552 .52323 L F
.3589 .52628 m .35592 .52816 L .35609 .52602 L F
.129 0 .378 r
.33964 .59947 m .33734 .59891 L .3405 .59761 L F
.33964 .59947 m .33813 .60096 L .33734 .59891 L F
.092 0 0 r
.29026 .52653 m .28854 .52769 L .28615 .5282 L F
.006 0 0 r
.29089 .52703 m .29026 .52653 L .29292 .52608 L F
.29089 .52703 m .28854 .52769 L .29026 .52653 L F
.572 .934 .79 r
.28954 .56524 m .28791 .56641 L .28814 .56657 L F
.549 .439 .682 r
.39247 .60177 m .39294 .60713 L .39237 .60443 L F
.204 .567 .938 r
.39362 .60206 m .39247 .60177 L .39237 .60443 L F
.765 .524 .569 r
.38417 .56375 m .38003 .56637 L .3806 .56601 L F
.677 .704 .867 r
.639 .38654 m .63623 .38903 L .6345 .38557 L F
.645 .642 .833 r
.639 .38654 m .63998 .39012 L .63623 .38903 L F
0 0 0 r
.30951 .60428 m .30872 .60642 L .30746 .60777 L F
.30872 .60642 m .30594 .60994 L .30746 .60777 L F
.706 .545 .668 r
.36481 .60827 m .36789 .61112 L .36626 .60766 L F
.479 .681 .955 r
.57789 .40023 m .5795 .40212 L .5766 .40236 L F
.5766 .40236 m .5795 .40212 L .57789 .40023 L F
.957 .615 .258 r
.30609 .52623 m .30707 .52889 L .30542 .5274 L F
.30542 .5274 m .30707 .52889 L .30609 .52623 L F
.30542 .5274 m .30609 .52623 L .30825 .52422 L F
.716 .443 .512 r
.3957 .5938 m .39183 .59143 L .39445 .59152 L F
.731 .538 .631 r
.6042 .44011 m .60603 .44406 L .60441 .44281 L F
.672 .513 .661 r
.60855 .44287 m .60603 .44406 L .6042 .44011 L F
.381 0 0 r
.62267 .44947 m .62663 .44961 L .6256 .45033 L F
.405 0 0 r
.6256 .45033 m .62663 .44961 L .62892 .45052 L F
.211 .735 .752 r
.3753 .56836 m .37101 .56921 L .37039 .56967 L F
.3753 .56836 m .37209 .56888 L .37101 .56921 L F
.478 0 0 r
.37777 .5674 m .37209 .56888 L .3753 .56836 L F
.232 .446 .863 r
.32567 .53418 m .3252 .53587 L .32398 .53372 L F
0 0 .449 r
.32591 .53616 m .3252 .53587 L .32567 .53418 L F
.079 0 .029 r
.71865 .35754 m .71833 .35921 L .71538 .36051 L F
0 0 0 r
.71908 .35716 m .71865 .35754 L .72122 .35612 L F
.022 0 0 r
.72122 .35612 m .72353 .35608 L .71916 .35717 L F
0 0 0 r
.71896 .35722 m .71892 .35726 L .71908 .35716 L F
.022 0 0 r
.71908 .35716 m .71916 .35717 L .71896 .35722 L F
.72122 .35612 m .71916 .35717 L .71908 .35716 L F
0 .029 .566 r
.71963 .35997 m .71833 .35921 L .71922 .35718 L F
.538 .307 .513 r
.72132 .3543 m .72381 .35588 L .72122 .35612 L F
.022 0 0 r
.72122 .35612 m .72381 .35588 L .72353 .35608 L F
.989 .881 .545 r
.72143 .3564 m .72217 .35629 L .72142 .35425 L F
.252 .76 .75 r
.71924 .35714 m .72346 .3561 L .72217 .35629 L F
.71916 .35717 m .72353 .35608 L .71924 .35714 L F
0 .029 .566 r
.71928 .35705 m .71924 .35714 L .71928 .35704 L F
.71924 .35714 m .71924 .35714 L .71928 .35705 L F
.568 .814 .991 r
.71932 .35695 m .71924 .35714 L .71896 .35722 L F
.252 .76 .75 r
.71896 .35722 m .71916 .35717 L .71924 .35714 L F
.568 .814 .991 r
.71924 .35714 m .71833 .35921 L .71896 .35722 L F
.252 .76 .75 r
.71896 .35722 m .71924 .35714 L .71924 .35714 L F
.71896 .35722 m .71924 .35714 L .71932 .35695 L F
.71924 .35714 m .72217 .35629 L .71932 .35695 L F
0 .029 .566 r
.71929 .35712 m .71924 .35714 L .71928 .35705 L F
.245 .292 .714 r
.72144 .35822 m .71932 .35695 L .72217 .35629 L F
.989 .881 .545 r
.72144 .35822 m .72217 .35629 L .72143 .3564 L F
.252 .76 .75 r
.72346 .3561 m .72353 .35608 L .72217 .35629 L F
0 .029 .566 r
.7193 .35719 m .71922 .35718 L .71924 .35714 L F
.7193 .35719 m .71924 .35714 L .71929 .35712 L F
.71963 .35997 m .71922 .35718 L .7193 .35719 L F
.71933 .35701 m .71928 .35704 L .71932 .35695 L F
.71963 .35997 m .71928 .35704 L .71933 .35701 L F
0 0 0 r
.71892 .35726 m .71865 .35754 L .71908 .35716 L F
.71896 .35722 m .71833 .35921 L .71865 .35754 L F
.75 .974 .924 r
.3339 .50005 m .33443 .49836 L .33637 .49943 L F
.3339 .50005 m .33272 .49955 L .33443 .49836 L F
.926 .545 .156 r
.40818 .53868 m .40755 .53995 L .40758 .53733 L F
.40818 .53868 m .40906 .54117 L .40755 .53995 L F
.193 0 0 r
.35388 .65463 m .34909 .65362 L .35218 .65374 L F
.823 .895 .893 r
.35654 .65182 m .35388 .65463 L .35218 .65374 L F
.382 0 0 r
.37337 .54719 m .37675 .54869 L .37768 .54829 L F
.482 0 0 r
.37768 .54829 m .37675 .54869 L .38015 .54962 L F
.247 0 0 r
.42172 .54887 m .41911 .54954 L .42029 .5479 L F
.897 .811 .755 r
.69123 .30934 m .69196 .31322 L .69023 .31159 L F
.898 .81 .752 r
.69023 .31159 m .69196 .31322 L .68995 .3164 L F
.915 .819 .738 r
.69262 .31069 m .69196 .31322 L .69123 .30934 L F
.014 .579 .793 r
.20671 .59932 m .21002 .59975 L .20836 .59868 L F
.197 .593 .944 r
.21002 .59975 m .21158 .59917 L .20836 .59868 L F
.21002 .59975 m .21341 .60073 L .21158 .59917 L F
0 0 0 r
.33972 .59159 m .34284 .58873 L .34034 .58874 L F
.33972 .59159 m .34157 .59085 L .34284 .58873 L F
.33972 .59159 m .33819 .59305 L .34157 .59085 L F
.647 .677 .865 r
.24579 .59222 m .2482 .59294 L .24711 .59041 L F
.961 .663 .242 r
.24671 .58867 m .2482 .59294 L .24711 .59041 L F
.647 .677 .865 r
.24579 .59222 m .2482 .59294 L .24711 .59041 L F
.738 .724 .838 r
.25008 .58893 m .2482 .59294 L .24711 .59041 L F
.65 .617 .803 r
.25008 .58893 m .25131 .59265 L .2482 .59294 L F
.546 .62 .877 r
.24711 .59041 m .2482 .59294 L .25089 .59209 L F
.53 .816 .998 r
.25089 .59209 m .25131 .59265 L .2482 .59294 L F
0 0 .408 r
.61626 .39223 m .61815 .39581 L .61779 .3949 L F
.61626 .39223 m .61815 .39581 L .61779 .3949 L F
.525 .871 .99 r
.6156 .39498 m .61815 .39581 L .61779 .3949 L F
.61779 .3949 m .61815 .39581 L .6156 .39498 L F
.729 .623 .057 r
.21961 .56504 m .2197 .56457 L .2219 .56302 L F
.751 .907 .526 r
.35254 .6069 m .35377 .60539 L .35158 .6055 L F
.35377 .60539 m .35345 .60516 L .35158 .6055 L F
.781 .985 .9 r
.35244 .60456 m .35403 .60506 L .35393 .60293 L F
.35158 .6055 m .35345 .60516 L .35259 .60464 L F
.905 .808 .741 r
.35561 .6071 m .35726 .61049 L .35506 .61116 L F
.859 .764 .757 r
.35561 .6071 m .35506 .61116 L .35428 .60792 L F
.863 .95 .868 r
.35478 .60688 m .35428 .60792 L .35561 .6071 L F
.781 .985 .9 r
.3551 .60696 m .35561 .6071 L .35568 .6072 L F
.35158 .6055 m .35561 .6071 L .3551 .60696 L F
.35158 .6055 m .35337 .60536 L .35259 .60464 L F
.35158 .6055 m .35345 .60536 L .35561 .6071 L F
.35345 .60536 m .35487 .60525 L .3556 .60707 L F
.35345 .60536 m .3556 .60707 L .35561 .6071 L F
.3551 .60696 m .35521 .60683 L .35323 .60524 L F
.35521 .60683 m .35522 .60682 L .35323 .60524 L F
.35323 .60524 m .35522 .60682 L .35259 .60464 L F
.524 0 0 r
.35257 .60464 m .35339 .60531 L .35244 .60456 L F
.781 .985 .9 r
.35158 .6055 m .35259 .60464 L .35172 .60393 L F
.35158 .6055 m .35259 .60464 L .35244 .60456 L F
.35345 .60516 m .35403 .60506 L .35244 .60456 L F
.751 .907 .526 r
.35377 .60539 m .35403 .60506 L .35345 .60516 L F
.86 .996 .772 r
.35393 .60293 m .35403 .60506 L .35631 .60217 L F
.781 .985 .9 r
.35345 .60536 m .35393 .60293 L .35487 .60525 L F
.35158 .6055 m .35244 .60456 L .35345 .60536 L F
.524 0 0 r
.35345 .60536 m .35339 .60531 L .35174 .60395 L F
.781 .985 .9 r
.35244 .60456 m .35393 .60293 L .35345 .60536 L F
.524 0 0 r
.35177 .60397 m .35345 .60536 L .35174 .60395 L F
.863 .95 .868 r
.35515 .60678 m .35478 .60688 L .3551 .60696 L F
.015 .203 .713 r
.35567 .60501 m .35561 .6071 L .35491 .60535 L F
.35567 .60501 m .35491 .60535 L .35393 .60293 L F
0 0 0 r
.35728 .60402 m .35668 .60455 L .35567 .60501 L F
.524 0 0 r
.35345 .60536 m .35522 .60682 L .35339 .60531 L F
.35522 .60682 m .35522 .60682 L .35339 .60531 L F
.781 .985 .9 r
.35158 .6055 m .3551 .60696 L .35337 .60536 L F
.745 .791 .89 r
.35304 .60526 m .35428 .60792 L .3549 .60662 L F
.524 0 0 r
.35244 .60456 m .35519 .6068 L .35221 .60442 L F
.863 .95 .868 r
.35563 .60634 m .3551 .60696 L .35561 .6071 L F
.781 .985 .9 r
.3551 .60696 m .35568 .6072 L .35522 .60682 L F
.524 0 0 r
.35519 .6068 m .35546 .60702 L .35516 .60679 L F
.35519 .6068 m .35516 .60679 L .35221 .60442 L F
.863 .95 .868 r
.35567 .60501 m .35515 .60678 L .35563 .60634 L F
.35515 .60678 m .3551 .60696 L .35522 .60682 L F
.35515 .60678 m .35522 .60682 L .35563 .60634 L F
.524 0 0 r
.35546 .60702 m .35542 .60699 L .35221 .60442 L F
.35339 .60531 m .35568 .6072 L .35244 .60456 L F
.35221 .60442 m .35568 .6072 L .35304 .60526 L F
.745 .791 .89 r
.35304 .60526 m .3549 .60662 L .35567 .60501 L F
.524 0 0 r
.35546 .60702 m .35568 .6072 L .35542 .60699 L F
0 0 0 r
.35668 .60455 m .35465 .60639 L .35567 .60501 L F
.863 .95 .868 r
.35567 .60501 m .3549 .60662 L .35515 .60678 L F
.3549 .60662 m .35478 .60688 L .35515 .60678 L F
.524 0 0 r
.35522 .60682 m .35568 .6072 L .35522 .60682 L F
.35174 .60395 m .35257 .60464 L .35221 .60442 L F
.35172 .60393 m .35177 .60397 L .35174 .60395 L F
.208 0 .316 r
.21819 .5708 m .21639 .57068 L .21959 .57083 L F
.21819 .5708 m .21645 .5724 L .21639 .57068 L F
.545 .438 .683 r
.25507 .55071 m .25313 .55419 L .25238 .55153 L F
.432 0 0 r
.62392 .44008 m .62648 .44072 L .62778 .44017 L F
.472 .765 .995 r
.62648 .44072 m .62933 .44121 L .62778 .44017 L F
.494 .842 .996 r
.35399 .54751 m .35241 .54665 L .35001 .54729 L F
.531 .859 .996 r
.35543 .54624 m .35399 .54751 L .35666 .54429 L F
.35543 .54624 m .35241 .54665 L .35399 .54751 L F
.122 .139 .604 r
.35543 .54624 m .35399 .54751 L .35241 .54665 L F
.35543 .54624 m .35579 .54871 L .35399 .54751 L F
.699 .547 .678 r
.33865 .54403 m .34333 .54712 L .34367 .54472 L F
.586 .307 .46 r
.34367 .54472 m .34333 .54712 L .34593 .54678 L F
.968 .848 .44 r
.35889 .61442 m .35784 .6161 L .35834 .61349 L F
.35889 .61442 m .35784 .6161 L .35834 .61349 L F
.591 .557 .785 r
.64137 .3852 m .63998 .39012 L .639 .38654 L F
.64137 .3852 m .6427 .38918 L .63998 .39012 L F
.673 .945 .961 r
.61331 .38968 m .60978 .39169 L .61155 .38892 L F
0 0 0 r
.61155 .38892 m .60978 .39169 L .61016 .39109 L F
.887 .734 .686 r
.70166 .32559 m .70113 .32918 L .7029 .32892 L F
.1 0 0 r
.70113 .32918 m .7014 .3294 L .7029 .32892 L F
.087 .635 .83 r
.7014 .3294 m .70591 .32999 L .7029 .32892 L F
.633 .568 .764 r
.3676 .54484 m .36238 .55034 L .36384 .54734 L F
.084 .594 .888 r
.23493 .56049 m .23548 .55991 L .23336 .55899 L F
.23493 .56049 m .23675 .56056 L .23548 .55991 L F
.738 .754 .865 r
.32949 .66695 m .33146 .6689 L .3332 .66701 L F
.712 .957 .948 r
.36442 .662 m .36245 .66451 L .36177 .664 L F
.36442 .662 m .36632 .66257 L .36245 .66451 L F
0 .432 .839 r
.37773 .51545 m .37718 .51599 L .37591 .51439 L F
.37773 .51545 m .37998 .51713 L .37718 .51599 L F
.521 .337 .573 r
.43616 .5341 m .43382 .53193 L .43522 .53142 L F
.43616 .5341 m .43333 .53514 L .43382 .53193 L F
.853 .986 .708 r
.39986 .61598 m .39978 .61768 L .40193 .61458 L F
.814 .766 .255 r
.39926 .61839 m .39978 .61768 L .39986 .61598 L F
.39926 .61839 m .3992 .62032 L .39978 .61768 L F
.464 .491 .802 r
.40205 .66784 m .40094 .67229 L .40033 .66793 L F
.40205 .66784 m .40253 .67186 L .40094 .67229 L F
.439 .389 .705 r
.40253 .67186 m .40373 .67371 L .40094 .67229 L F
.552 .147 .228 r
.36909 .54268 m .37194 .54374 L .36955 .54355 L F
.36909 .54268 m .37194 .54374 L .36955 .54355 L F
.911 .68 .576 r
.54978 .43065 m .54643 .43199 L .54848 .43037 L F
.54978 .43065 m .54962 .43327 L .54643 .43199 L F
.447 .774 .998 r
.55133 .42912 m .54978 .43065 L .54848 .43037 L F
.55133 .42912 m .5525 .4303 L .54978 .43065 L F
.63 .421 .58 r
.32424 .56618 m .32168 .56378 L .32453 .56341 L F
.32424 .56618 m .3216 .56654 L .32168 .56378 L F
.142 0 0 r
.4086 .51173 m .41186 .5098 L .40863 .50934 L F
.869 .742 .72 r
.41069 .51124 m .4091 .5156 L .4086 .51173 L F
0 0 0 r
.4086 .51173 m .4104 .51152 L .41069 .51124 L F
.142 0 0 r
.4086 .51173 m .4104 .51152 L .41186 .5098 L F
0 0 0 r
.41186 .5098 m .41268 .50975 L .41442 .50859 L F
.579 .834 .471 r
.41069 .51124 m .4104 .51152 L .41186 .5098 L F
0 0 0 r
.41186 .5098 m .4104 .51152 L .41268 .50975 L F
.673 .247 .227 r
.32415 .54762 m .32641 .54979 L .32831 .5481 L F
.716 .303 .265 r
.32831 .5481 m .32889 .54914 L .32852 .5463 L F
.069 .101 .586 r
.66112 .40078 m .66049 .40466 L .65854 .40184 L F
.66112 .40078 m .66201 .40353 L .66049 .40466 L F
0 0 .284 r
.66049 .40466 m .66201 .40353 L .6618 .40602 L F
0 0 .331 r
.40288 .67841 m .4024 .67787 L .40439 .67636 L F
.40288 .67841 m .40337 .68076 L .4024 .67787 L F
.397 0 0 r
.33226 .57715 m .33383 .57631 L .33538 .57721 L F
.373 0 0 r
.33383 .57631 m .33665 .57606 L .33538 .57721 L F
0 0 .186 r
.35385 .58739 m .35382 .58602 L .35412 .58631 L F
.35385 .58739 m .35412 .58631 L .35596 .588 L F
.929 .803 .701 r
.35425 .58476 m .35385 .58739 L .35596 .588 L F
0 0 0 r
.35428 .58563 m .35385 .58739 L .35425 .58476 L F
.054 0 .454 r
.35428 .58563 m .35353 .58865 L .35385 .58739 L F
0 0 0 r
.35341 .58916 m .35175 .59094 L .35385 .58739 L F
.054 0 .454 r
.35353 .58865 m .35341 .58916 L .35385 .58739 L F
.663 .661 .838 r
.42498 .51065 m .42236 .51284 L .42117 .50912 L F
.42498 .51065 m .4262 .51278 L .42236 .51284 L F
.675 .578 .739 r
.4262 .51278 m .42599 .51335 L .42236 .51284 L F
.774 .672 .75 r
.20426 .60172 m .20153 .60585 L .20011 .60125 L F
.571 .026 0 r
.20153 .60585 m .20381 .60725 L .19964 .60658 L F
.489 .881 .961 r
.20479 .60508 m .20153 .60585 L .20426 .60172 L F
.528 .194 .345 r
.20479 .60508 m .20381 .60725 L .20153 .60585 L F
.597 .506 .722 r
.26357 .54372 m .26099 .54424 L .26049 .54165 L F
.557 .312 .501 r
.26357 .54372 m .2604 .54716 L .26099 .54424 L F
.724 .74 .864 r
.39259 .65108 m .38907 .64974 L .39144 .65081 L F
.568 .937 .897 r
.395 .64962 m .39259 .65108 L .39144 .65081 L F
.18 .663 .927 r
.23534 .61083 m .23729 .61086 L .23929 .61174 L F
.076 .622 .839 r
.23729 .61086 m .24121 .61144 L .23929 .61174 L F
.953 .633 .214 r
.7156 .32896 m .71463 .32919 L .71466 .3275 L F
0 0 0 r
.71734 .32521 m .7156 .32896 L .71466 .3275 L F
.71734 .32521 m .71652 .32705 L .7156 .32896 L F
.583 .25 .371 r
.71652 .32705 m .71463 .32919 L .7156 .32896 L F
0 0 .272 r
.31393 .64545 m .31419 .64837 L .31455 .64805 L F
0 .356 .793 r
.31419 .64837 m .31644 .6497 L .31455 .64805 L F
.737 .852 .934 r
.64142 .42938 m .63788 .42955 L .6411 .42748 L F
.782 .902 .926 r
.6433 .42598 m .64142 .42938 L .6411 .42748 L F
.6433 .42598 m .64452 .4272 L .64142 .42938 L F
.774 .672 .75 r
.20426 .60172 m .20011 .60125 L .20266 .5997 L F
.733 .713 .832 r
.20309 .59977 m .20283 .5999 L .20266 .5997 L F
.20283 .5999 m .20011 .60125 L .20266 .5997 L F
0 .022 .559 r
.2046 .6018 m .20429 .60173 L .20266 .5997 L F
.20429 .60173 m .20426 .60172 L .20266 .5997 L F
.434 .353 .666 r
.20697 .60401 m .20426 .60172 L .2046 .6018 L F
.20697 .60401 m .20479 .60508 L .20426 .60172 L F
.234 0 .145 r
.65737 .40971 m .65882 .41047 L .6568 .41089 L F
.702 .784 .915 r
.38387 .60537 m .37949 .60497 L .38196 .60373 L F
.7 .786 .918 r
.37949 .60497 m .38387 .60537 L .38196 .60373 L F
.045 0 0 r
.28859 .64231 m .28578 .64537 L .28566 .64386 L F
0 0 0 r
.29039 .64201 m .28859 .64231 L .28566 .64386 L F
.759 .687 .782 r
.39172 .55664 m .39326 .56066 L .39063 .56043 L F
.203 0 .25 r
.33179 .59558 m .331 .59777 L .33372 .59467 L F
0 0 .056 r
.35955 .59984 m .35775 .60047 L .3588 .59866 L F
.835 .63 .626 r
.68113 .35146 m .67787 .35094 L .67921 .34804 L F
.893 .886 .817 r
.68113 .35146 m .67746 .3535 L .67787 .35094 L F
.68113 .35146 m .67866 .35489 L .67746 .3535 L F
.597 .506 .722 r
.26357 .54372 m .26049 .54165 L .26309 .54095 L F
.527 .774 .988 r
.62997 .40768 m .63404 .40887 L .63264 .40712 L F
.539 .781 .987 r
.63264 .40712 m .63404 .40887 L .63674 .40814 L F
.753 .731 .832 r
.31598 .52806 m .31709 .53054 L .31947 .52879 L F
.939 .84 .719 r
.67637 .35802 m .67567 .36129 L .67394 .35877 L F
.877 .805 .775 r
.67567 .36129 m .67138 .36242 L .67394 .35877 L F
.67567 .36129 m .67405 .36411 L .67138 .36242 L F
.353 .15 .459 r
.67616 .36297 m .67405 .36411 L .67567 .36129 L F
.027 .24 .744 r
.21341 .60073 m .21515 .60452 L .21587 .60297 L F
.043 .263 .759 r
.21515 .60452 m .21618 .60458 L .21587 .60297 L F
.008 .497 .869 r
.24222 .62428 m .24243 .62358 L .2403 .62325 L F
.24222 .62428 m .24478 .625 L .24243 .62358 L F
.739 .768 .876 r
.42283 .54468 m .41887 .54415 L .42167 .54284 L F
.541 .678 .927 r
.42423 .54253 m .42283 .54468 L .42167 .54284 L F
.453 0 .06 r
.69614 .3588 m .69557 .35804 L .69827 .35896 L F
.454 .079 .237 r
.69557 .35804 m .69831 .35762 L .69827 .35896 L F
.658 .544 .714 r
.24537 .57945 m .24297 .58269 L .24281 .5801 L F
.59 .451 .66 r
.24551 .58208 m .24297 .58269 L .24537 .57945 L F
.624 .46 .641 r
.24551 .58208 m .24277 .58556 L .24297 .58269 L F
.149 0 0 r
.27628 .55434 m .2751 .55577 L .27292 .55631 L F
0 0 0 r
.27807 .55505 m .2751 .55577 L .27628 .55434 L F
.758 .797 .884 r
.35141 .54461 m .35042 .54469 L .35047 .54265 L F
.456 .236 .49 r
.35001 .54729 m .35241 .54665 L .35042 .54469 L F
.903 .885 .804 r
.67746 .3535 m .67866 .35489 L .67637 .35802 L F
.861 .977 .674 r
.33917 .54043 m .33902 .54005 L .33919 .53881 L F
.801 .991 .881 r
.33919 .53881 m .33902 .54005 L .33917 .53993 L F
0 0 .003 r
.33919 .53881 m .33917 .53998 L .33917 .54043 L F
0 0 0 r
.34505 .53474 m .34197 .53767 L .34205 .53536 L F
.34411 .53563 m .34306 .53671 L .34197 .53767 L F
.34505 .53474 m .3439 .53589 L .34411 .53563 L F
.3439 .53589 m .34306 .53671 L .34411 .53563 L F
.517 0 0 r
.34547 .53626 m .34368 .53739 L .34301 .53694 L F
.801 .991 .881 r
.34274 .53689 m .3428 .53693 L .34306 .53671 L F
.477 .835 .573 r
.34306 .53671 m .33917 .53993 L .34197 .53767 L F
.33917 .53993 m .33902 .54005 L .33917 .53993 L F
.33917 .53993 m .33917 .53993 L .34197 .53767 L F
.814 .997 .772 r
.33916 .5411 m .33917 .54043 L .33894 .54138 L F
0 0 .063 r
.339 .54312 m .33894 .54138 L .33917 .54043 L F
0 0 .003 r
.33917 .53993 m .339 .54312 L .33917 .54043 L F
.33917 .53926 m .33914 .53992 L .33917 .53993 L F
.33914 .53992 m .339 .54312 L .33917 .53993 L F
.166 .337 .791 r
.34472 .53312 m .34505 .53474 L .34319 .53247 L F
.97 .877 .687 r
.34472 .53312 m .34343 .53591 L .34505 .53474 L F
.34343 .53591 m .34306 .53671 L .3439 .53589 L F
.34343 .53591 m .3439 .53589 L .34505 .53474 L F
.86 .697 .679 r
.34547 .53626 m .34306 .53671 L .34472 .53312 L F
.865 .78 .765 r
.341 .53561 m .34306 .53671 L .34547 .53626 L F
.801 .991 .881 r
.33919 .53881 m .34306 .53671 L .341 .53561 L F
.517 0 0 r
.34379 .53602 m .34301 .53694 L .3416 .53601 L F
.34316 .53593 m .3416 .53601 L .341 .53561 L F
.34379 .53602 m .3416 .53601 L .34316 .53593 L F
.34547 .53626 m .34301 .53694 L .34379 .53602 L F
0 .17 .616 r
.34145 .53585 m .34368 .53739 L .34187 .53606 L F
.341 .53561 m .34189 .5362 L .34145 .53585 L F
.34189 .5362 m .34368 .53739 L .34145 .53585 L F
.801 .991 .881 r
.33919 .53881 m .33917 .53993 L .3428 .53693 L F
.33919 .53881 m .3428 .53693 L .34274 .53689 L F
0 0 .003 r
.33919 .53881 m .33917 .53926 L .33917 .53998 L F
.814 .997 .772 r
.34197 .53767 m .33917 .54043 L .33916 .5411 L F
0 0 .063 r
.339 .54312 m .33865 .54403 L .33894 .54138 L F
.558 .717 .947 r
.23761 .57319 m .2389 .57098 L .23747 .57256 L F
.23761 .57319 m .23993 .57261 L .2389 .57098 L F
.474 .271 .523 r
.23993 .57261 m .23973 .57526 L .23761 .57319 L F
0 0 .567 r
.23761 .57319 m .23856 .5755 L .23747 .57256 L F
.636 .378 .511 r
.68647 .36037 m .68267 .36304 L .68263 .36133 L F
.394 0 0 r
.23085 .55852 m .22657 .55958 L .22911 .55631 L F
.23085 .55852 m .22897 .5596 L .22657 .55958 L F
.359 0 0 r
.23336 .55899 m .22897 .5596 L .23085 .55852 L F
.121 .069 .52 r
.62412 .43248 m .62288 .43061 L .62411 .42992 L F
.62412 .43248 m .62308 .43324 L .62288 .43061 L F
.454 .883 .817 r
.35696 .57841 m .35606 .57846 L .35451 .57952 L F
0 0 .023 r
.35606 .57846 m .35405 .58205 L .35451 .57952 L F
.57 .917 .712 r
.36556 .64456 m .36835 .64289 L .36828 .64245 L F
.682 .902 .553 r
.36828 .64245 m .36835 .64289 L .36661 .64469 L F
.104 0 .041 r
.36712 .63689 m .36407 .63974 L .36654 .63926 L F
.481 .351 .626 r
.24836 .56292 m .24859 .5664 L .24611 .56694 L F
.519 .32 .55 r
.24863 .56894 m .24611 .56694 L .24859 .5664 L F
.24863 .56894 m .24608 .56954 L .24611 .56694 L F
.545 .864 .577 r
.43068 .53678 m .4267 .54051 L .4286 .53882 L F
.765 .544 .599 r
.33278 .52569 m .32849 .52783 L .32954 .5254 L F
.33278 .52569 m .33291 .52841 L .32849 .52783 L F
0 0 0 r
.33499 .52403 m .33291 .52841 L .33278 .52569 L F
.64 .526 .709 r
.33291 .52841 m .33499 .52403 L .33278 .52569 L F
.56 .448 .683 r
.35639 .5603 m .354 .56372 L .35353 .5609 L F
.544 .131 .208 r
.29051 .5595 m .29314 .55962 L .29394 .55844 L F
.565 .59 .837 r
.29153 .55334 m .29394 .55844 L .29578 .55688 L F
0 0 0 r
.2941 .5585 m .29394 .55844 L .29578 .55688 L F
.2941 .5585 m .29314 .55962 L .29394 .55844 L F
.044 0 0 r
.33985 .67398 m .34152 .67243 L .33853 .67381 L F
.33985 .67398 m .33853 .67381 L .33657 .67585 L F
.229 0 0 r
.31508 .5347 m .31584 .53591 L .31724 .53464 L F
.821 .998 .785 r
.35393 .60293 m .35631 .60217 L .35775 .60047 L F
.653 .569 .748 r
.29922 .61436 m .29925 .61728 L .29664 .61745 L F
.415 .432 .769 r
.29944 .62064 m .29664 .61745 L .29925 .61728 L F
.698 .67 .818 r
.31654 .55727 m .32107 .55756 L .31836 .55314 L F
.421 .091 .298 r
.31654 .55727 m .31893 .55909 L .32107 .55756 L F
.461 .561 .871 r
.31836 .55314 m .32107 .55756 L .32274 .55648 L F
.582 .232 .34 r
.31893 .55909 m .32274 .55648 L .32107 .55756 L F
.778 .754 .831 r
.67078 .33761 m .67164 .34143 L .66791 .34068 L F
.824 .645 .66 r
.66791 .34068 m .67164 .34143 L .66961 .34449 L F
.737 .523 .603 r
.67164 .34143 m .67518 .34521 L .67037 .34334 L F
.737 .538 .624 r
.67569 .34528 m .67562 .34703 L .67448 .3451 L F
.737 .523 .603 r
.67518 .34521 m .67548 .34553 L .67448 .3451 L F
.67518 .34521 m .67448 .3451 L .67037 .34334 L F
.737 .538 .624 r
.67448 .3451 m .67562 .34703 L .6716 .34613 L F
.67571 .34466 m .67569 .34528 L .67518 .34521 L F
.67571 .34466 m .67518 .34521 L .67502 .34491 L F
.67571 .34466 m .67502 .34491 L .67548 .34553 L F
.951 .779 .632 r
.6752 .34514 m .67548 .34553 L .67518 .34521 L F
.737 .538 .624 r
.67502 .34491 m .67518 .34521 L .67448 .3451 L F
.67502 .34491 m .67448 .3451 L .67548 .34553 L F
.951 .779 .632 r
.67606 .34203 m .67548 .34553 L .6752 .34514 L F
.67333 .34166 m .67518 .34521 L .67164 .34143 L F
.67606 .34203 m .67518 .34521 L .67333 .34166 L F
.737 .538 .624 r
.67448 .3451 m .6716 .34613 L .67548 .34553 L F
.737 .523 .603 r
.67037 .34334 m .67548 .34553 L .66961 .34449 L F
.834 .786 .806 r
.67416 .33835 m .67164 .34143 L .67078 .33761 L F
.696 .562 .699 r
.67416 .33835 m .67606 .34203 L .67164 .34143 L F
.732 .215 0 r
.29847 .65797 m .30183 .65939 L .30048 .66013 L F
0 0 0 r
.30048 .66013 m .30183 .65939 L .30459 .65852 L F
.669 .896 .978 r
.30648 .51441 m .30418 .51575 L .30513 .51372 L F
.777 .998 .83 r
.30418 .51575 m .30219 .51632 L .30513 .51372 L F
.876 .785 .756 r
.26957 .53832 m .26559 .53949 L .26852 .53739 L F
.26957 .53832 m .26712 .54232 L .26559 .53949 L F
.914 .651 .524 r
.2671 .54013 m .26957 .53832 L .26852 .53739 L F
.2671 .54013 m .26944 .54105 L .26957 .53832 L F
.986 .731 .459 r
.26957 .53832 m .27248 .54006 L .27227 .53782 L F
.907 .948 .818 r
.36775 .66015 m .36632 .66257 L .36442 .662 L F
.861 .736 .725 r
.67467 .33574 m .67416 .33835 L .67078 .33761 L F
.269 0 .138 r
.28759 .54321 m .28988 .54194 L .28694 .54172 L F
.315 .09 .405 r
.28759 .54321 m .28865 .54625 L .28904 .54364 L F
.583 .753 .958 r
.19531 .60575 m .19767 .60508 L .19343 .604 L F
.19531 .60575 m .19767 .60508 L .19343 .604 L F
.83 .863 .87 r
.65598 .40303 m .65238 .40355 L .65391 .4052 L F
.549 .497 .75 r
.22285 .57014 m .22337 .5729 L .22098 .573 L F
.225 0 .284 r
.22337 .5729 m .22107 .57568 L .22098 .573 L F
0 0 0 r
.33621 .66191 m .33171 .665 L .33465 .66106 L F
.764 .68 .769 r
.33829 .65877 m .33883 .65882 L .33621 .66191 L F
.512 .441 .714 r
.30096 .54546 m .30385 .54688 L .30323 .54418 L F
.30096 .54546 m .30142 .54774 L .30385 .54688 L F
.30385 .54688 m .30096 .54546 L .30323 .54418 L F
.30385 .54688 m .30142 .54774 L .30096 .54546 L F
.507 .152 .3 r
.58623 .44624 m .58516 .44857 L .58258 .44887 L F
.572 .22 .332 r
.58887 .44802 m .58623 .44624 L .58899 .44611 L F
.58887 .44802 m .58516 .44857 L .58623 .44624 L F
.565 .061 .016 r
.58181 .40379 m .58373 .40253 L .58521 .4035 L F
.505 0 0 r
.58521 .4035 m .58373 .40253 L .58126 .40165 L F
.733 .529 .616 r
.37495 .58261 m .37757 .58279 L .3787 .58074 L F
.137 0 .232 r
.3787 .58074 m .37757 .58279 L .38034 .5791 L F
.934 .966 .69 r
.39986 .61598 m .40193 .61458 L .40176 .61241 L F
.759 .687 .782 r
.39172 .55664 m .39063 .56043 L .3892 .55709 L F
.832 .67 .682 r
.55886 .41373 m .56246 .41484 L .56267 .41186 L F
.551 .607 .863 r
.35901 .63004 m .36346 .6323 L .36159 .62989 L F
.351 0 .129 r
.22727 .57046 m .22285 .57014 L .22522 .56821 L F
.22727 .57046 m .22337 .5729 L .22285 .57014 L F
.22727 .57046 m .22603 .5725 L .22337 .5729 L F
.015 0 0 r
.22801 .57135 m .22727 .57046 L .22821 .56853 L F
.22801 .57135 m .22603 .5725 L .22727 .57046 L F
.776 .937 .586 r
.43322 .58073 m .43483 .57774 L .43637 .57864 L F
.43322 .58073 m .43328 .57949 L .43483 .57774 L F
.43322 .58073 m .43198 .58178 L .43328 .57949 L F
.515 .364 .615 r
.43637 .57864 m .43401 .58236 L .43322 .58073 L F
.362 .818 .933 r
.27656 .52102 m .27836 .52138 L .27584 .52188 L F
.473 .893 .818 r
.27656 .52102 m .27584 .52188 L .27444 .52214 L F
.786 .977 .698 r
.38067 .67547 m .37917 .67764 L .38173 .67449 L F
.077 .01 .471 r
.38034 .67833 m .37917 .67764 L .38067 .67547 L F
.38034 .67833 m .37923 .68057 L .37917 .67764 L F
0 0 0 r
.64074 .44242 m .63784 .44518 L .63897 .44367 L F
.465 .783 .998 r
.71534 .27302 m .7141 .27453 L .71347 .27599 L F
.71534 .27302 m .7127 .27341 L .7141 .27453 L F
.71534 .27302 m .7141 .27453 L .71347 .27599 L F
.71534 .27302 m .7127 .27341 L .7141 .27453 L F
.765 .862 .425 r
.39355 .62901 m .39187 .63264 L .3919 .63298 L F
.753 .392 .371 r
.71265 .36042 m .71538 .36051 L .71598 .36296 L F
.368 .2 .517 r
.71833 .35921 m .71598 .36296 L .71538 .36051 L F
.007 0 .463 r
.31978 .64404 m .31824 .64601 L .31794 .64239 L F
.437 .118 .324 r
.4226 .52879 m .42505 .52989 L .42285 .53027 L F
.594 .259 .371 r
.72439 .35436 m .72381 .35588 L .72132 .3543 L F
0 .441 .727 r
.27038 .53081 m .26562 .52945 L .26789 .53121 L F
0 0 0 r
.35383 .5714 m .35143 .57224 L .3552 .57045 L F
.251 0 .292 r
.35508 .56876 m .35383 .5714 L .3552 .57045 L F
.932 .923 .549 r
.35383 .5714 m .3552 .57045 L .35508 .56876 L F
.622 .659 .865 r
.37379 .51226 m .369 .51071 L .37222 .51144 L F
0 .402 .757 r
.37222 .51144 m .37536 .51284 L .37379 .51226 L F
.858 .878 .852 r
.38642 .57517 m .38295 .57602 L .38634 .57565 L F
.38642 .57517 m .38647 .57204 L .38295 .57602 L F
.356 0 0 r
.38295 .57602 m .38642 .57517 L .38634 .57565 L F
.567 .305 .478 r
.29816 .55062 m .30089 .55028 L .30142 .54774 L F
.29816 .55062 m .30089 .55028 L .30142 .54774 L F
.461 .237 .487 r
.30089 .55028 m .30385 .54688 L .30142 .54774 L F
.30385 .54688 m .30089 .55028 L .30142 .54774 L F
.861 .736 .725 r
.67467 .33574 m .67078 .33761 L .67308 .33432 L F
.85 .826 .824 r
.67701 .3327 m .67467 .33574 L .67308 .33432 L F
0 .393 .843 r
.63101 .43769 m .63449 .44031 L .63285 .43607 L F
0 .042 .552 r
.63449 .44031 m .63397 .43519 L .63285 .43607 L F
.63443 .43973 m .63586 .43852 L .63397 .43519 L F
.349 .179 .505 r
.63397 .43519 m .63586 .43852 L .63783 .43675 L F
.496 .906 .852 r
.63586 .43852 m .63395 .43876 L .63728 .43731 L F
.63586 .43852 m .63765 .43715 L .63783 .43675 L F
.63586 .43852 m .63728 .43731 L .63765 .43715 L F
0 .042 .552 r
.63449 .44031 m .63586 .43852 L .63443 .43973 L F
.631 .95 .941 r
.63449 .44031 m .63341 .43988 L .63586 .43852 L F
.71 .337 .34 r
.28417 .52905 m .28282 .5307 L .28019 .52962 L F
.051 0 0 r
.28615 .5282 m .28282 .5307 L .28417 .52905 L F
.362 0 .071 r
.23463 .56608 m .23707 .56576 L .23875 .56364 L F
.662 .713 .886 r
.23675 .56056 m .23875 .56364 L .24041 .56191 L F
.467 .164 .366 r
.23707 .56576 m .24041 .56191 L .23875 .56364 L F
.642 .494 .667 r
.67616 .36297 m .67366 .36646 L .67405 .36411 L F
.717 .244 .124 r
.34951 .71228 m .35359 .71341 L .35185 .71451 L F
.349 0 0 r
.35359 .71341 m .35609 .71369 L .35185 .71451 L F
.607 .625 .844 r
.65477 .40098 m .65854 .40184 L .65598 .40303 L F
.094 .264 .747 r
.22975 .61345 m .22992 .61487 L .23076 .61323 L F
.273 .497 .89 r
.22992 .61487 m .23354 .61665 L .23076 .61323 L F
.203 0 .351 r
.38977 .63614 m .38917 .63888 L .38678 .63979 L F
.064 0 .026 r
.38917 .63888 m .38615 .64167 L .38678 .63979 L F
0 0 0 r
.34276 .56194 m .34316 .56231 L .3427 .56006 L F
.37 .216 .538 r
.3427 .56006 m .34548 .55979 L .3456 .55633 L F
.039 0 .094 r
.34316 .56231 m .34548 .55979 L .3427 .56006 L F
.51 .055 .107 r
.3237 .63199 m .32268 .62988 L .32174 .63266 L F
.3237 .63199 m .3252 .63015 L .32268 .62988 L F
0 0 .094 r
.61376 .44367 m .61231 .44352 L .61381 .443 L F
.522 .011 0 r
.61381 .443 m .61481 .4441 L .61376 .44367 L F
.61381 .443 m .61586 .44501 L .61481 .4441 L F
.805 .655 .696 r
.71431 .29318 m .71796 .2943 L .71677 .29076 L F
.817 .492 .438 r
.71751 .29614 m .71796 .2943 L .71431 .29318 L F
.728 .615 .732 r
.71796 .2943 m .72071 .29118 L .71677 .29076 L F
0 0 0 r
.34276 .56194 m .34073 .56373 L .34316 .56231 L F
.315 .235 .605 r
.37066 .62388 m .37114 .62646 L .37297 .62586 L F
.309 .527 .903 r
.36963 .5091 m .369 .51071 L .36754 .50885 L F
.36963 .5091 m .37222 .51144 L .369 .51071 L F
0 0 0 r
.63264 .44902 m .63599 .4468 L .63487 .44813 L F
.63487 .44813 m .63599 .4468 L .63784 .44518 L F
.343 .649 .968 r
.6345 .38557 m .63317 .38598 L .62961 .38329 L F
0 .124 .653 r
.2 .58535 m .20106 .58905 L .20184 .58746 L F
.166 .147 .59 r
.20106 .58905 m .20276 .59077 L .20184 .58746 L F
.20106 .58905 m .20163 .59192 L .20276 .59077 L F
.793 .703 .765 r
.37194 .54374 m .37337 .54719 L .37666 .54528 L F
.37209 .54379 m .37666 .54528 L .37443 .54472 L F
.168 .693 .871 r
.3779 .54506 m .37443 .54472 L .37666 .54528 L F
.444 .213 .468 r
.37646 .54461 m .37574 .54524 L .37443 .54472 L F
.37574 .54524 m .37363 .5471 L .37443 .54472 L F
.793 .703 .765 r
.37194 .54374 m .37209 .54379 L .37443 .54472 L F
.492 .488 .781 r
.3718 .58497 m .37304 .58874 L .37523 .58815 L F
.863 .791 .778 r
.5524 .41579 m .55349 .41787 L .55005 .41805 L F
.869 .745 .724 r
.55005 .41805 m .55349 .41787 L .55225 .41983 L F
.55005 .41805 m .55225 .41983 L .55103 .41957 L F
.55005 .41805 m .55173 .42064 L .55003 .41944 L F
.683 .684 .845 r
.54818 .41597 m .55003 .41944 L .54701 .42051 L F
.735 .706 .824 r
.55005 .41805 m .55003 .41944 L .54818 .41597 L F
.284 .744 .951 r
.54821 .41864 m .54961 .41926 L .55218 .41914 L F
.54961 .41926 m .55003 .41944 L .55029 .41941 L F
.54961 .41926 m .55029 .41941 L .55218 .41914 L F
.869 .745 .724 r
.55103 .41957 m .55225 .41983 L .55173 .42064 L F
.871 .971 .852 r
.55552 .4133 m .55349 .41787 L .5524 .41579 L F
.55568 .41335 m .55349 .41787 L .55552 .4133 L F
.765 .743 .832 r
.55218 .41914 m .55617 .41964 L .5553 .41579 L F
.786 .52 .534 r
.55431 .41489 m .55743 .41597 L .55699 .41368 L F
.896 .95 .831 r
.55135 .41424 m .5524 .41579 L .55005 .41805 L F
.775 .76 .839 r
.55021 .41752 m .55218 .41914 L .55499 .41576 L F
.786 .52 .534 r
.55501 .41576 m .55528 .41577 L .55431 .41489 L F
.775 .76 .839 r
.55481 .41575 m .55499 .41576 L .55523 .41548 L F
.786 .52 .534 r
.55501 .41576 m .5553 .41579 L .55528 .41577 L F
.5553 .41579 m .55743 .41597 L .55431 .41489 L F
.433 .517 .844 r
.55523 .41548 m .5553 .41579 L .55531 .41579 L F
.786 .52 .534 r
.55276 .41558 m .55709 .41595 L .55279 .41556 L F
.55709 .41595 m .55743 .41597 L .55279 .41556 L F
.433 .517 .844 r
.55523 .41548 m .55531 .41579 L .55657 .41694 L F
.768 .74 .827 r
.55523 .41548 m .55743 .41597 L .55531 .41579 L F
.765 .743 .832 r
.55499 .41576 m .5553 .41579 L .55523 .41548 L F
.768 .74 .827 r
.55523 .41548 m .55531 .41579 L .55481 .41575 L F
.786 .52 .534 r
.55279 .41556 m .55501 .41576 L .55431 .41489 L F
.768 .74 .827 r
.55523 .41548 m .55481 .41575 L .55276 .41558 L F
.775 .76 .839 r
.55458 .41574 m .55481 .41575 L .55523 .41548 L F
.55021 .41752 m .55499 .41576 L .55458 .41574 L F
.433 .517 .844 r
.55657 .41694 m .55617 .41964 L .55831 .41883 L F
.5553 .41579 m .55617 .41964 L .55657 .41694 L F
.765 .743 .832 r
.55218 .41914 m .5553 .41579 L .55499 .41576 L F
.786 .52 .534 r
.55657 .41357 m .55699 .41368 L .55693 .41338 L F
.55276 .41558 m .55699 .41368 L .55657 .41357 L F
.871 .971 .852 r
.55582 .41306 m .55568 .41335 L .55552 .4133 L F
.487 .854 .988 r
.55626 .42282 m .55744 .42352 L .55488 .4242 L F
.635 .633 .831 r
.55884 .42494 m .55488 .4242 L .55744 .42352 L F
.581 .421 .63 r
.31559 .66003 m .31732 .65429 L .31414 .65476 L F
.782 .655 .722 r
.68001 .34564 m .67562 .34703 L .67571 .34466 L F
.68001 .34564 m .67921 .34804 L .67562 .34703 L F
.857 .597 .544 r
.56297 .44636 m .55948 .44775 L .55909 .44551 L F
.56297 .44636 m .56298 .4491 L .55948 .44775 L F
.69 .457 .565 r
.56718 .44863 m .56298 .4491 L .56297 .44636 L F
.427 .824 .983 r
.26851 .52134 m .26948 .52333 L .26644 .5225 L F
.26851 .52134 m .27189 .52287 L .26948 .52333 L F
.519 .447 .714 r
.22796 .59183 m .2307 .59167 L .2297 .58811 L F
.167 0 .364 r
.34047 .56599 m .34316 .56231 L .34073 .56373 L F
.469 .312 .585 r
.34937 .60172 m .35172 .60393 L .35168 .60115 L F
.34937 .60172 m .34943 .60448 L .35172 .60393 L F
.391 .083 .318 r
.33338 .51327 m .33531 .51446 L .33666 .51271 L F
.482 .331 .599 r
.33884 .51238 m .33934 .51545 L .33666 .51271 L F
.899 .923 .536 r
.33666 .51271 m .33531 .51446 L .33632 .51224 L F
.515 .546 .826 r
.33744 .51191 m .33884 .51238 L .33666 .51271 L F
.59 .819 .987 r
.30939 .5281 m .30707 .52889 L .30542 .5274 L F
.693 .732 .881 r
.236 .58802 m .23605 .59124 L .24005 .58881 L F
.353 0 0 r
.28737 .62191 m .28991 .62265 L .28566 .62238 L F
.471 .096 .246 r
.29419 .5531 m .29816 .55062 L .29497 .5518 L F
.53 .888 .667 r
.73006 .33532 m .73212 .33348 L .73326 .33287 L F
.008 0 0 r
.73006 .33532 m .73175 .33564 L .73212 .33348 L F
.05 0 0 r
.36777 .54454 m .3666 .54455 L .36955 .54355 L F
.36777 .54454 m .3676 .54484 L .3666 .54455 L F
.175 0 .371 r
.40236 .66474 m .40205 .66784 L .40033 .66793 L F
.962 .784 .616 r
.3655 .61478 m .36289 .61627 L .36373 .61333 L F
.011 0 0 r
.36623 .61534 m .36289 .61627 L .3655 .61478 L F
.627 .473 .654 r
.39446 .65588 m .39693 .65553 L .39627 .65251 L F
.39446 .65588 m .39627 .65251 L .39567 .65392 L F
0 .195 .722 r
.39687 .65151 m .39627 .65251 L .395 .64962 L F
0 0 0 r
.39567 .65392 m .39627 .65251 L .39687 .65151 L F
.894 .915 .83 r
.36536 .61983 m .36689 .62072 L .36931 .61751 L F
.627 .953 .776 r
.23264 .53758 m .23349 .5363 L .23587 .53525 L F
.68 .972 .787 r
.23587 .53525 m .23644 .53393 L .2376 .53382 L F
.23587 .53525 m .23349 .5363 L .23644 .53393 L F
.357 .807 .671 r
.292 .64456 m .29564 .64278 L .29348 .64441 L F
.721 .335 0 r
.29564 .64278 m .29565 .64346 L .29348 .64441 L F
.29564 .64278 m .29711 .64601 L .29565 .64346 L F
.652 .633 .819 r
.29827 .64246 m .29711 .64601 L .29564 .64278 L F
.005 .247 .754 r
.42554 .55568 m .42541 .55746 L .42486 .55551 L F
.797 .366 .226 r
.42397 .5589 m .42541 .55746 L .42554 .55568 L F
.42397 .5589 m .42698 .5596 L .42541 .55746 L F
.048 .145 .644 r
.22916 .60254 m .22797 .60379 L .22713 .60198 L F
.6 .515 .729 r
.4236 .50582 m .42117 .50912 L .42096 .50665 L F
.4236 .50582 m .42498 .51065 L .42117 .50912 L F
.085 0 .187 r
.25313 .55419 m .25224 .55658 L .25074 .55726 L F
.553 .356 .569 r
.25296 .55949 m .25074 .55726 L .25224 .55658 L F
.25296 .55949 m .25042 .56015 L .25074 .55726 L F
0 .511 .798 r
.33637 .49943 m .33899 .49997 L .34039 .50052 L F
.61 .919 .976 r
.34039 .50052 m .34113 .49889 L .34277 .49981 L F
.34039 .50052 m .33899 .49997 L .34113 .49889 L F
.276 .005 .309 r
.3137 .56047 m .31703 .5597 L .31654 .55727 L F
.421 .091 .298 r
.31654 .55727 m .31703 .5597 L .31893 .55909 L F
.776 .645 .716 r
.61813 .3827 m .61947 .38652 L .61538 .3856 L F
.689 .647 .802 r
.62057 .38178 m .61947 .38652 L .61813 .3827 L F
.62057 .38178 m .62179 .38503 L .61947 .38652 L F
.573 .395 .602 r
.41602 .53106 m .4154 .53386 L .41206 .53266 L F
.578 .386 .585 r
.4154 .53386 m .4128 .5357 L .41206 .53266 L F
.999 .834 .516 r
.40014 .59212 m .39963 .59465 L .39857 .59378 L F
.209 0 .208 r
.30858 .6613 m .30903 .65913 L .30623 .66195 L F
.7 .329 .341 r
.30858 .6613 m .31125 .6612 L .30903 .65913 L F
.967 .653 .364 r
.30858 .6613 m .30903 .65913 L .30708 .65761 L F
.547 .366 .588 r
.30903 .65913 m .31125 .6612 L .3112 .65837 L F
.94 .913 .763 r
.3504 .5157 m .35226 .51457 L .35182 .51399 L F
.555 .592 .846 r
.35226 .51457 m .35449 .5116 L .35182 .51399 L F
.195 0 .132 r
.36996 .67741 m .37354 .67636 L .37224 .67576 L F
.308 .016 .296 r
.27078 .56011 m .27002 .56283 L .26813 .56269 L F
.372 .247 .578 r
.27292 .55631 m .27277 .5595 L .27078 .56011 L F
.446 .138 .349 r
.27283 .56191 m .27078 .56011 L .27277 .5595 L F
.27283 .56191 m .27002 .56283 L .27078 .56011 L F
.374 .146 .435 r
.294 .60748 m .29635 .60457 L .29467 .60537 L F
.747 .721 .827 r
.33747 .65608 m .33883 .65882 L .33829 .65877 L F
.784 .803 .315 r
.33981 .6549 m .33883 .65882 L .33747 .65608 L F
.802 .588 .612 r
.67921 .34804 m .67787 .35094 L .67562 .34703 L F
.704 .576 .708 r
.3576 .54599 m .35543 .54624 L .35666 .54429 L F
.951 .779 .632 r
.67606 .34203 m .67571 .34466 L .67548 .34553 L F
.807 .958 .912 r
.39672 .51396 m .39311 .51496 L .39476 .51224 L F
.777 .783 .858 r
.39876 .51241 m .39672 .51396 L .39476 .51224 L F
.976 .689 .411 r
.38782 .66128 m .38785 .65867 L .38627 .66029 L F
.73 .523 .611 r
.39103 .65627 m .38803 .65827 L .38836 .65664 L F
.921 .938 .578 r
.38785 .65867 m .38865 .65521 L .38836 .65664 L F
.793 .93 .56 r
.38627 .66029 m .38785 .65867 L .38836 .65664 L F
.626 .798 .364 r
.38701 .65895 m .38627 .66029 L .38836 .65664 L F
.73 .523 .611 r
.38803 .65827 m .38701 .65895 L .38836 .65664 L F
.921 .938 .578 r
.38865 .65521 m .38884 .65435 L .38836 .65664 L F
.595 .473 .684 r
.33986 .64636 m .33981 .64912 L .34151 .64583 L F
.134 .668 .858 r
.35746 .50428 m .3599 .50416 L .36107 .50456 L F
.324 0 0 r
.3599 .50416 m .36344 .50588 L .36107 .50456 L F
.632 .936 .696 r
.23264 .53758 m .2319 .53788 L .23349 .5363 L F
.324 0 .199 r
.39414 .70002 m .39289 .70196 L .39105 .70222 L F
0 0 0 r
.39642 .69664 m .39506 .69901 L .39414 .70002 L F
.39414 .70002 m .39257 .70211 L .39289 .70196 L F
.39414 .70002 m .39506 .69901 L .39257 .70211 L F
.094 .04 .498 r
.3137 .56047 m .31519 .56135 L .31703 .5597 L F
.3137 .56047 m .31396 .56309 L .31519 .56135 L F
.733 .555 .652 r
.3646 .62666 m .36553 .63014 L .36817 .62679 L F
.772 .614 .683 r
.36553 .63014 m .36811 .63069 L .36817 .62679 L F
.594 .45 .656 r
.36811 .63069 m .37114 .62646 L .36817 .62679 L F
.756 .729 .828 r
.3778 .6736 m .38173 .67449 L .38016 .67209 L F
.186 .439 .869 r
.38173 .67449 m .38454 .67589 L .38394 .675 L F
.38214 .67404 m .38394 .675 L .38281 .67329 L F
.38173 .67449 m .38394 .675 L .38214 .67404 L F
.287 .572 .937 r
.38454 .67589 m .38569 .67757 L .38656 .67611 L F
.968 .706 .483 r
.38281 .67329 m .38454 .67589 L .38353 .67539 L F
.099 .6 .899 r
.38454 .67589 m .38656 .67611 L .38353 .67539 L F
0 0 .369 r
.38457 .67781 m .38353 .67539 L .3856 .67588 L F
.38636 .67629 m .3856 .67588 L .38656 .67611 L F
.38457 .67781 m .3856 .67588 L .38636 .67629 L F
.444 .449 .769 r
.38281 .67329 m .38353 .67539 L .38145 .67545 L F
.38101 .67512 m .38145 .67545 L .38067 .67547 L F
.38281 .67329 m .38145 .67545 L .38101 .67512 L F
.739 .294 .194 r
.3778 .6736 m .38037 .67562 L .381 .6751 L F
.37952 .67399 m .381 .6751 L .38173 .67449 L F
.3778 .6736 m .381 .6751 L .37952 .67399 L F
.185 .438 .868 r
.38173 .67449 m .38281 .67329 L .38016 .67209 L F
.858 .879 .853 r
.36789 .61112 m .36885 .60701 L .36626 .60766 L F
0 0 .423 r
.236 .58802 m .23567 .59222 L .23511 .59172 L F
0 0 0 r
.23567 .59222 m .23465 .59339 L .23511 .59172 L F
.829 .592 .041 r
.41792 .57884 m .4171 .57465 L .41829 .57612 L F
.353 .264 .615 r
.30858 .6613 m .30623 .66195 L .30847 .66396 L F
.684 .932 .968 r
.23004 .54969 m .22965 .55143 L .23194 .55017 L F
.585 .849 .994 r
.23004 .54969 m .22776 .55048 L .22965 .55143 L F
.152 0 .29 r
.37158 .56686 m .37101 .56921 L .37324 .56589 L F
.433 .238 .514 r
.3209 .58434 m .31866 .58835 L .31929 .58558 L F
.787 .287 0 r
.301 .63648 m .29655 .63289 L .29861 .63393 L F
0 .242 .747 r
.30094 .6354 m .301 .63648 L .29861 .63393 L F
.238 .072 .443 r
.30232 .63848 m .301 .63648 L .30094 .6354 L F
.30232 .63848 m .30071 .63909 L .301 .63648 L F
.706 .46 .55 r
.59941 .44487 m .59539 .44302 L .59892 .44372 L F
.59941 .44487 m .59544 .44555 L .59539 .44302 L F
.801 .999 .843 r
.63285 .43607 m .63397 .43519 L .63518 .43337 L F
.438 .45 .775 r
.63518 .43337 m .63397 .43519 L .63838 .43506 L F
.349 .179 .505 r
.63397 .43519 m .63783 .43675 L .63838 .43506 L F
.069 .222 .715 r
.60773 .42625 m .60852 .4281 L .60691 .42662 L F
.624 .593 .798 r
.37315 .60476 m .36888 .60141 L .3708 .60021 L F
.477 .507 .809 r
.37298 .59896 m .37315 .60476 L .37104 .60068 L F
.37298 .59896 m .37526 .60413 L .37315 .60476 L F
.731 .676 .796 r
.3764 .59665 m .37787 .60088 L .37298 .59896 L F
.569 .557 .802 r
.37751 .6036 m .37298 .59896 L .37787 .60088 L F
.37751 .6036 m .37526 .60413 L .37298 .59896 L F
.731 .676 .796 r
.3764 .59665 m .37298 .59896 L .37367 .59752 L F
.006 0 .074 r
.37392 .59789 m .37281 .60002 L .37451 .59875 L F
.37367 .59752 m .37335 .59844 L .37392 .59789 L F
.37335 .59844 m .37281 .60002 L .37392 .59789 L F
.477 .507 .809 r
.37258 .5992 m .37104 .60068 L .3708 .60021 L F
.37298 .59896 m .37104 .60068 L .37258 .5992 L F
.082 0 .22 r
.37128 .5981 m .36888 .60141 L .37094 .60012 L F
.477 .507 .809 r
.37089 .60011 m .3708 .60021 L .37078 .60017 L F
.399 .095 .329 r
.37298 .59896 m .37128 .5981 L .37367 .59752 L F
.37298 .59896 m .37078 .60017 L .37128 .5981 L F
.206 0 .157 r
.37091 .60033 m .37281 .60002 L .37335 .59844 L F
.37154 .59969 m .37335 .59844 L .37367 .59752 L F
.477 .507 .809 r
.37298 .59896 m .3708 .60021 L .37082 .60018 L F
.37298 .59896 m .37082 .60018 L .3711 .59999 L F
.206 0 .157 r
.37091 .60033 m .37335 .59844 L .37154 .59969 L F
.477 .507 .809 r
.3711 .59999 m .37082 .60018 L .37089 .60011 L F
.082 0 .22 r
.37094 .60012 m .3708 .60021 L .37091 .60033 L F
.3708 .60021 m .36888 .60141 L .37048 .60056 L F
.3708 .60021 m .37048 .60056 L .37091 .60033 L F
.624 .593 .798 r
.3708 .60021 m .36888 .60141 L .37078 .60017 L F
.797 .709 .768 r
.37526 .60413 m .37217 .60767 L .37315 .60476 L F
.504 .21 .4 r
.23245 .58491 m .23492 .58449 L .23554 .58181 L F
.403 .329 .66 r
.23554 .58181 m .23717 .5782 L .23487 .57905 L F
.23554 .58181 m .23772 .58135 L .23717 .5782 L F
.636 .466 .635 r
.23492 .58449 m .23772 .58135 L .23554 .58181 L F
.363 .793 .969 r
.5997 .37821 m .60152 .37891 L .60342 .3785 L F
.5997 .37821 m .60152 .37891 L .60342 .3785 L F
.937 .95 .626 r
.40524 .5999 m .40565 .60167 L .40714 .59802 L F
.868 .871 .427 r
.40482 .60193 m .40565 .60167 L .40524 .5999 L F
.40482 .60193 m .40473 .604 L .40565 .60167 L F
.391 .083 .318 r
.33338 .51327 m .33274 .51525 L .33531 .51446 L F
.61 .49 .692 r
.28857 .53783 m .2908 .53442 L .28854 .53536 L F
.462 .03 .133 r
.26813 .56269 m .26643 .56515 L .26443 .56379 L F
.672 .392 .488 r
.27002 .56283 m .26643 .56515 L .26813 .56269 L F
.585 .4 .597 r
.32862 .51944 m .33068 .52154 L .32991 .51819 L F
.32862 .51944 m .32769 .52229 L .33068 .52154 L F
.486 .725 .977 r
.62577 .38623 m .62179 .38503 L .62454 .3827 L F
.621 .657 .864 r
.62816 .38521 m .62577 .38623 L .62454 .3827 L F
.627 .473 .654 r
.39446 .65588 m .39567 .65392 L .3928 .65335 L F
.632 .496 .679 r
.39446 .65588 m .3949 .65854 L .39693 .65553 L F
0 .235 .75 r
.25785 .61969 m .25929 .62258 L .25591 .61956 L F
.25785 .61969 m .25998 .62259 L .25929 .62258 L F
.568 .586 .831 r
.42769 .51137 m .42599 .51335 L .4262 .51278 L F
.42769 .51137 m .42793 .51307 L .42599 .51335 L F
.62 .492 .685 r
.4291 .51548 m .42599 .51335 L .42793 .51307 L F
.4291 .51548 m .42625 .51606 L .42599 .51335 L F
.877 .885 .836 r
.6798 .3294 m .67582 .3314 L .67853 .32802 L F
.6798 .3294 m .67701 .3327 L .67582 .3314 L F
.842 .886 .871 r
.68321 .32582 m .6798 .3294 L .67853 .32802 L F
.774 .681 .762 r
.36777 .61378 m .36931 .61751 L .37182 .61424 L F
.581 .627 .862 r
.3908 .61315 m .39283 .60825 L .38839 .61013 L F
.39283 .60825 m .3929 .60808 L .39273 .60816 L F
.39283 .60825 m .39273 .60816 L .38839 .61013 L F
.3908 .61315 m .39239 .61277 L .39289 .60829 L F
.39239 .61277 m .39258 .61225 L .39289 .60829 L F
.39283 .60825 m .39289 .60829 L .3929 .60808 L F
.3908 .61315 m .39289 .60829 L .39283 .60825 L F
0 0 0 r
.39294 .60713 m .38839 .61013 L .39273 .60816 L F
.39291 .60799 m .39273 .60816 L .3929 .60808 L F
.39294 .60713 m .39273 .60816 L .39291 .60799 L F
.39352 .60543 m .39294 .60713 L .3929 .60808 L F
.39352 .60543 m .3929 .60808 L .39444 .60895 L F
.382 .133 .407 r
.39636 .60637 m .39352 .60543 L .39444 .60895 L F
0 0 0 r
.39465 .60875 m .39444 .60895 L .39569 .60716 L F
.133 .212 .681 r
.3929 .60808 m .39471 .61223 L .39444 .60895 L F
0 0 0 r
.39322 .61094 m .39392 .6098 L .39465 .60875 L F
.39392 .6098 m .39444 .60895 L .39465 .60875 L F
.133 .212 .681 r
.39375 .61004 m .39255 .61273 L .39471 .61223 L F
.39321 .60879 m .39276 .61146 L .39375 .61004 L F
.39276 .61146 m .39255 .61273 L .39375 .61004 L F
.39289 .60829 m .39258 .61225 L .39318 .60871 L F
.805 .403 .288 r
.39226 .60863 m .39322 .60877 L .39159 .60928 L F
.39322 .60877 m .39384 .60886 L .39334 .60896 L F
.133 .212 .681 r
.39318 .60871 m .39258 .61225 L .39321 .60879 L F
.39258 .61225 m .39255 .61273 L .39321 .60879 L F
.805 .403 .288 r
.39322 .60877 m .39334 .60896 L .39159 .60928 L F
.133 .212 .681 r
.3929 .60808 m .39289 .60829 L .39318 .60871 L F
.776 .846 .905 r
.39288 .60644 m .39347 .60738 L .39074 .6084 L F
.39347 .60738 m .39405 .60832 L .3933 .60834 L F
.39347 .60738 m .3933 .60834 L .39074 .6084 L F
.39405 .60832 m .39444 .60895 L .39384 .60886 L F
.39405 .60832 m .39384 .60886 L .39074 .6084 L F
.581 .627 .862 r
.39239 .61277 m .39255 .61273 L .39258 .61225 L F
.805 .403 .288 r
.39384 .60886 m .39444 .60895 L .39406 .60899 L F
.39384 .60886 m .39406 .60899 L .39159 .60928 L F
.39159 .60928 m .39369 .60904 L .39322 .61094 L F
.39369 .60904 m .39444 .60895 L .39413 .60945 L F
.39369 .60904 m .39413 .60945 L .39322 .61094 L F
.39074 .6084 m .39226 .60863 L .39159 .60928 L F
.537 .531 .796 r
.39237 .60443 m .39294 .60713 L .39352 .60543 L F
.548 .77 .98 r
.23393 .56944 m .2389 .57098 L .23578 .56871 L F
.26 0 .123 r
.23578 .56871 m .23476 .56946 L .23393 .56944 L F
.65 .695 .878 r
.2326 .56941 m .23747 .57256 L .23393 .56944 L F
.548 .77 .98 r
.23393 .56944 m .23747 .57256 L .2389 .57098 L F
.26 0 .123 r
.23476 .56946 m .23288 .57085 L .23393 .56944 L F
.65 .695 .878 r
.23193 .56898 m .2326 .56941 L .23393 .56944 L F
.939 .84 .719 r
.67637 .35802 m .67394 .35877 L .67496 .3566 L F
.903 .885 .804 r
.67746 .3535 m .67637 .35802 L .67496 .3566 L F
0 0 0 r
.63264 .44902 m .63487 .44813 L .63134 .45017 L F
.728 .672 .795 r
.4091 .5156 m .40692 .5176 L .40583 .5151 L F
.994 .766 .479 r
.62255 .43862 m .62392 .44008 L .62394 .43701 L F
.867 .593 .064 r
.6235 .43633 m .62394 .43701 L .62361 .43555 L F
0 0 0 r
.62343 .43683 m .6235 .43633 L .62472 .43419 L F
.952 .916 .551 r
.62255 .43862 m .62394 .43701 L .6235 .43633 L F
0 0 0 r
.62255 .43862 m .6235 .43633 L .62343 .43683 L F
.867 .593 .064 r
.6235 .43633 m .62361 .43555 L .62308 .43324 L F
.759 .286 .121 r
.56119 .41613 m .56246 .41484 L .55886 .41373 L F
.896 .497 .248 r
.56336 .41787 m .56246 .41484 L .56119 .41613 L F
.945 .938 .598 r
.34886 .68601 m .35047 .68442 L .35002 .68353 L F
.531 .789 .992 r
.35047 .68442 m .35143 .68242 L .35002 .68353 L F
.35047 .68442 m .35361 .68371 L .35143 .68242 L F
.103 0 0 r
.34979 .68509 m .35047 .68442 L .34886 .68601 L F
.34979 .68509 m .35361 .68371 L .35047 .68442 L F
.364 0 .156 r
.35329 .59422 m .35583 .59362 L .35662 .59168 L F
.6 .462 .665 r
.35662 .59168 m .35932 .58892 L .35596 .588 L F
.35662 .59168 m .35969 .59163 L .35932 .58892 L F
.548 .221 .366 r
.3586 .59338 m .35662 .59168 L .35583 .59362 L F
.3586 .59338 m .35969 .59163 L .35662 .59168 L F
.187 0 .242 r
.35932 .58892 m .35662 .59168 L .35969 .59163 L F
.129 .234 .705 r
.3586 .59338 m .35662 .59168 L .35969 .59163 L F
.905 .971 .807 r
.37628 .64759 m .37716 .64925 L .37904 .64691 L F
.386 .845 .79 r
.37628 .64759 m .37904 .64691 L .38135 .64588 L F
.621 .421 .591 r
.38309 .68025 m .38589 .68073 L .38569 .67757 L F
0 0 .341 r
.38569 .67757 m .38689 .67916 L .38656 .67611 L F
.38569 .67757 m .38589 .68073 L .38689 .67916 L F
.568 .368 .57 r
.6016 .44401 m .59892 .44372 L .60269 .44283 L F
.6016 .44401 m .59941 .44487 L .59892 .44372 L F
0 0 0 r
.34818 .63801 m .34876 .63666 L .3481 .63521 L F
.884 .882 .826 r
.42354 .50334 m .41941 .5054 L .42177 .50221 L F
.42354 .50334 m .42096 .50665 L .41941 .5054 L F
.536 .343 .565 r
.4236 .50582 m .42096 .50665 L .42354 .50334 L F
0 0 .355 r
.42464 .50387 m .42354 .50334 L .42177 .50221 L F
.42464 .50387 m .4236 .50582 L .42354 .50334 L F
.31 .444 .835 r
.43323 .54771 m .43619 .54899 L .43448 .54586 L F
.925 .687 .199 r
.41409 .55734 m .41347 .5585 L .41289 .55599 L F
.41409 .55734 m .41412 .56008 L .41347 .5585 L F
.85 .826 .824 r
.67701 .3327 m .67308 .33432 L .67582 .3314 L F
.973 .861 .668 r
.70349 .33719 m .7059 .3349 L .70619 .33434 L F
.70349 .33719 m .70488 .33848 L .7059 .3349 L F
.967 .663 .262 r
.40712 .58342 m .40831 .58212 L .40735 .58111 L F
.40712 .58342 m .40856 .58498 L .40831 .58212 L F
.304 .091 .415 r
.29994 .59912 m .30128 .60046 L .30167 .59828 L F
.29994 .59912 m .29939 .60119 L .30128 .60046 L F
.352 .502 .869 r
.20196 .59921 m .20061 .59441 L .19973 .59451 L F
.624 .918 .978 r
.65101 .41876 m .65002 .42071 L .64858 .41995 L F
.674 .964 .934 r
.65195 .41908 m .65002 .42071 L .65101 .41876 L F
.77 .895 .49 r
.73455 .33884 m .73357 .33991 L .73334 .34086 L F
0 0 0 r
.73625 .33697 m .73649 .33686 L .73455 .33884 L F
.73649 .33686 m .73357 .33991 L .73455 .33884 L F
.545 0 0 r
.2904 .65195 m .29429 .65255 L .29243 .65314 L F
.89 .528 .351 r
.29758 .65398 m .29243 .65314 L .29429 .65255 L F
.517 .134 .252 r
.22911 .55631 m .23158 .55647 L .23347 .5538 L F
.75 .41 .407 r
.23347 .5538 m .23581 .5567 L .23527 .5538 L F
.23347 .5538 m .23158 .55647 L .23581 .5567 L F
.614 .365 .517 r
.23527 .5538 m .23581 .5567 L .2393 .55632 L F
.565 .631 .876 r
.6286 .3997 m .63246 .40193 L .63138 .3988 L F
.305 .466 .856 r
.63138 .3988 m .63246 .40193 L .63382 .39993 L F
.557 .81 .992 r
.63246 .40193 m .63508 .40122 L .63382 .39993 L F
.713 .655 .79 r
.6316 .40552 m .63508 .40122 L .63246 .40193 L F
.686 .486 .61 r
.31903 .56699 m .31896 .56983 L .31507 .56968 L F
.614 .426 .604 r
.3216 .56934 m .31903 .56699 L .3216 .56654 L F
.3216 .56934 m .31896 .56983 L .31903 .56699 L F
.114 .356 .82 r
.57706 .42826 m .57824 .43115 L .576 .42954 L F
0 .266 .773 r
.57805 .43193 m .576 .42954 L .57824 .43115 L F
.876 .822 .791 r
.57443 .43093 m .57824 .43115 L .57706 .42826 L F
.251 0 0 r
.57743 .43142 m .57824 .43115 L .57443 .43093 L F
.607 .693 .904 r
.58113 .42916 m .57824 .43115 L .57706 .42826 L F
.215 .432 .856 r
.57706 .42826 m .57824 .43115 L .57885 .42866 L F
.824 .932 .557 r
.57884 .42868 m .57824 .43115 L .57743 .43142 L F
.57885 .42866 m .57824 .43115 L .57884 .42868 L F
0 .266 .773 r
.57966 .43379 m .57805 .43193 L .57824 .43115 L F
.976 .81 .613 r
.33747 .65608 m .33829 .65877 L .33609 .65478 L F
.899 .825 .765 r
.33609 .65478 m .33829 .65877 L .33465 .66106 L F
0 0 .4 r
.31161 .51171 m .31131 .51575 L .30906 .51259 L F
.31161 .51171 m .31205 .51534 L .31131 .51575 L F
.839 .454 0 r
.311 .51672 m .31131 .51575 L .31205 .51534 L F
.382 .819 .956 r
.20466 .59898 m .20671 .59932 L .20836 .59868 L F
0 0 .457 r
.42468 .53452 m .42604 .53691 L .42451 .53286 L F
0 .208 .734 r
.2563 .63032 m .25724 .62995 L .25467 .62851 L F
.2563 .63032 m .25847 .63113 L .25724 .62995 L F
.226 .186 .602 r
.43307 .52096 m .43168 .52543 L .4305 .52135 L F
.43307 .52096 m .43323 .52497 L .43168 .52543 L F
.253 .274 .69 r
.43323 .52497 m .43401 .52748 L .43168 .52543 L F
.999 .787 .469 r
.55275 .42721 m .55133 .42912 L .55096 .42617 L F
.55275 .42721 m .5525 .4303 L .55133 .42912 L F
.837 .824 .835 r
.69711 .30648 m .69392 .30631 L .69575 .30496 L F
.846 .824 .827 r
.69971 .30331 m .69711 .30648 L .69575 .30496 L F
.508 .241 .445 r
.34132 .65134 m .34214 .64921 L .33981 .64912 L F
.396 .839 .938 r
.34803 .67152 m .34366 .67191 L .34593 .67154 L F
.542 .921 .926 r
.34879 .67029 m .34803 .67152 L .34593 .67154 L F
.034 .315 .802 r
.59972 .41325 m .59899 .41457 L .59712 .41147 L F
0 .189 .715 r
.60113 .41655 m .59899 .41457 L .59972 .41325 L F
0 0 .012 r
.37964 .57345 m .37872 .57534 L .38131 .57218 L F
.918 .602 .126 r
.25089 .59209 m .25211 .59525 L .25131 .59265 L F
.548 .606 .864 r
.42769 .51137 m .4262 .51278 L .42498 .51065 L F
.821 .998 .785 r
.35393 .60293 m .35775 .60047 L .35703 .60308 L F
.319 .248 .617 r
.32191 .57205 m .32043 .57626 L .31916 .57263 L F
.32191 .57205 m .32239 .57534 L .32043 .57626 L F
0 0 .375 r
.32239 .57534 m .32131 .57879 L .32043 .57626 L F
.074 0 .336 r
.36861 .60425 m .37091 .60033 L .36888 .60141 L F
.056 0 .197 r
.37078 .60017 m .36888 .60141 L .37128 .5981 L F
.746 .646 .75 r
.35811 .64562 m .36181 .64298 L .35804 .6428 L F
.915 .589 .411 r
.39937 .54958 m .40188 .55276 L .40027 .55124 L F
.734 .625 .738 r
.38175 .5855 m .37921 .58871 L .38355 .58836 L F
.593 .498 .716 r
.37921 .58871 m .38257 .59173 L .38355 .58836 L F
.565 .623 .868 r
.38355 .58836 m .38377 .58546 L .38175 .5855 L F
.38355 .58836 m .38554 .58845 L .38377 .58546 L F
.574 .269 .413 r
.38513 .59069 m .38355 .58836 L .38257 .59173 L F
.38513 .59069 m .38554 .58845 L .38355 .58836 L F
.929 .684 .547 r
.25049 .55498 m .25224 .55658 L .25313 .55419 L F
.617 .318 .44 r
.25313 .55419 m .25335 .55239 L .25049 .55498 L F
.597 .501 .716 r
.25566 .55359 m .25313 .55419 L .25507 .55071 L F
.617 .318 .44 r
.25565 .55622 m .25313 .55419 L .25566 .55359 L F
.25313 .55419 m .25565 .55622 L .25335 .55239 L F
.25313 .55419 m .25224 .55658 L .25565 .55622 L F
.25565 .55622 m .25224 .55658 L .25313 .55419 L F
.609 .571 .786 r
.64801 .38721 m .64669 .39198 L .64535 .38822 L F
.64801 .38721 m .64951 .3913 L .64669 .39198 L F
.554 .805 .992 r
.3904 .57164 m .38981 .57336 L .38773 .57213 L F
.912 .516 .231 r
.29488 .64952 m .29442 .64868 L .29369 .64835 L F
.71 .682 .82 r
.29369 .64835 m .2982 .65039 L .29488 .64952 L F
.817 .52 .488 r
.29708 .65135 m .2982 .65039 L .29369 .64835 L F
.542 .353 .574 r
.43401 .58236 m .43413 .58558 L .43154 .5862 L F
.515 .364 .615 r
.43637 .57864 m .43676 .58198 L .43401 .58236 L F
.413 .255 .555 r
.43651 .58441 m .43401 .58236 L .43676 .58198 L F
.43651 .58441 m .43413 .58558 L .43401 .58236 L F
.992 .884 .585 r
.5638 .42084 m .56336 .41787 L .5623 .41934 L F
.533 .487 .751 r
.6573 .39789 m .65514 .39898 L .65407 .39611 L F
.653 .565 .744 r
.6573 .39789 m .65477 .40098 L .65514 .39898 L F
.937 .95 .626 r
.40524 .5999 m .40714 .59802 L .40694 .59762 L F
.508 .122 .244 r
.36569 .56784 m .36495 .56778 L .36301 .56606 L F
.379 0 0 r
.36495 .56778 m .36726 .56913 L .36859 .56979 L F
.508 .122 .244 r
.36569 .56784 m .36726 .56913 L .36495 .56778 L F
.17 .664 .918 r
.55853 .39466 m .56094 .39481 L .55722 .39399 L F
0 0 0 r
.65195 .41908 m .65269 .41764 L .6543 .41632 L F
.73497 .33076 m .73799 .32785 L .7355 .32913 L F
.916 .857 .769 r
.40343 .56227 m .40405 .56538 L .40436 .56374 L F
.644 .562 .747 r
.30279 .61612 m .29922 .61436 L .30196 .61372 L F
.616 .44 .621 r
.30332 .61409 m .30279 .61612 L .30196 .61372 L F
.601 .487 .696 r
.36346 .6323 m .36553 .63014 L .36159 .62989 L F
.36346 .6323 m .36511 .63356 L .36553 .63014 L F
.563 .548 .796 r
.65233 .39055 m .65079 .39449 L .64951 .3913 L F
.65233 .39055 m .65349 .39407 L .65079 .39449 L F
.822 .351 0 r
.39342 .53577 m .39402 .53506 L .39361 .53367 L F
.39342 .53577 m .39504 .53683 L .39402 .53506 L F
.276 0 .2 r
.38272 .62028 m .3793 .6236 L .38261 .62306 L F
0 0 0 r
.38478 .61675 m .38272 .62028 L .38487 .61865 L F
.535 .433 .685 r
.38261 .62306 m .38487 .61865 L .38272 .62028 L F
.623 .925 .973 r
.72291 .33822 m .72117 .34017 L .72016 .33878 L F
.72291 .33822 m .7239 .33894 L .72117 .34017 L F
.413 .749 .994 r
.25998 .62259 m .26209 .62225 L .26158 .62371 L F
.397 .732 .991 r
.26209 .62225 m .26406 .62372 L .26158 .62371 L F
.772 .68 .762 r
.60867 .44432 m .60591 .44569 L .60855 .44287 L F
.327 0 .075 r
.60867 .44432 m .60775 .44701 L .60591 .44569 L F
.542 .18 .303 r
.61231 .44352 m .60867 .44432 L .60855 .44287 L F
.61231 .44352 m .61167 .44555 L .60867 .44432 L F
.564 .119 .151 r
.61059 .44676 m .60867 .44432 L .61167 .44555 L F
.61059 .44676 m .60775 .44701 L .60867 .44432 L F
.739 .645 .755 r
.56405 .42318 m .56603 .42776 L .56121 .42651 L F
.771 .497 .521 r
.56121 .42651 m .56603 .42776 L .56531 .42969 L F
.461 .498 .81 r
.56793 .42733 m .56603 .42776 L .56405 .42318 L F
.322 .042 .324 r
.56531 .42969 m .56603 .42776 L .56793 .42733 L F
.56531 .42969 m .56603 .42776 L .56793 .42733 L F
.56793 .42733 m .56603 .42776 L .56531 .42969 L F
.798 .592 .623 r
.38676 .59214 m .38689 .59485 L .38227 .59375 L F
.606 .607 .826 r
.3868 .5874 m .38676 .59214 L .38554 .58845 L F
.3868 .5874 m .38947 .59099 L .38676 .59214 L F
.436 .273 .561 r
.38947 .59099 m .38689 .59485 L .38676 .59214 L F
.777 .683 .76 r
.20697 .60401 m .20381 .60725 L .20479 .60508 L F
0 .37 .829 r
.36251 .51377 m .3636 .51316 L .36055 .51313 L F
.36251 .51377 m .36528 .51499 L .3636 .51316 L F
.713 .655 .79 r
.6316 .40552 m .6364 .40504 L .63508 .40122 L F
.805 .558 .564 r
.63264 .40712 m .6364 .40504 L .6316 .40552 L F
.63264 .40712 m .63674 .40814 L .6364 .40504 L F
.549 .367 .587 r
.6364 .40504 m .63896 .40181 L .63508 .40122 L F
.6364 .40504 m .6391 .40447 L .63896 .40181 L F
.467 .312 .587 r
.63911 .40691 m .6364 .40504 L .6391 .40447 L F
.63911 .40691 m .63674 .40814 L .6364 .40504 L F
.802 .999 .839 r
.6364 .40504 m .63896 .40181 L .6391 .40447 L F
.467 .312 .587 r
.63911 .40691 m .6364 .40504 L .6391 .40447 L F
.63911 .40691 m .63674 .40814 L .6364 .40504 L F
0 0 .042 r
.28159 .53492 m .27891 .53847 L .27853 .53513 L F
.92 .735 .245 r
.60001 .41634 m .60037 .42082 L .59903 .4196 L F
.983 .829 .612 r
.59903 .4196 m .60037 .42082 L .59963 .42333 L F
0 0 .106 r
.60113 .41655 m .60037 .42082 L .59903 .4196 L F
.622 .637 .844 r
.60113 .41655 m .60037 .42082 L .59903 .4196 L F
.60113 .41655 m .60338 .41987 L .60037 .42082 L F
.448 .191 .43 r
.31239 .59853 m .31188 .60097 L .30941 .60143 L F
.309 .07 .38 r
.31443 .59775 m .31188 .60097 L .31239 .59853 L F
.343 .17 .497 r
.34529 .50973 m .34371 .51356 L .34599 .51178 L F
0 0 .349 r
.34529 .50973 m .34595 .51006 L .34626 .50796 L F
.34529 .50973 m .34546 .51023 L .34595 .51006 L F
.465 .103 .265 r
.34493 .51031 m .34625 .50996 L .34595 .51006 L F
0 .358 .821 r
.34414 .50691 m .34626 .50796 L .34551 .50672 L F
.145 .229 .693 r
.34595 .51006 m .34551 .50672 L .34626 .50796 L F
.34595 .51006 m .34742 .50964 L .34551 .50672 L F
.465 .103 .265 r
.34625 .50996 m .34742 .50964 L .34595 .51006 L F
0 0 .349 r
.34546 .51023 m .34599 .51178 L .34595 .51006 L F
.838 .832 .842 r
.599 .38719 m .59724 .39231 L .59621 .3911 L F
.599 .38719 m .60055 .38902 L .59724 .39231 L F
.998 .793 .443 r
.59621 .3911 m .59724 .39231 L .59595 .39356 L F
.953 .613 .324 r
.59724 .39231 m .59764 .39459 L .59595 .39356 L F
.778 .793 .865 r
.33569 .66505 m .34023 .6656 L .33847 .66397 L F
.673 .798 .941 r
.33847 .66397 m .34023 .6656 L .34246 .66443 L F
.506 .589 .872 r
.65579 .39376 m .65407 .39611 L .65349 .39407 L F
.445 .504 .826 r
.65579 .39376 m .6573 .39789 L .65407 .39611 L F
0 0 0 r
.38573 .56925 m .38611 .56917 L .38803 .56786 L F
.769 .831 .9 r
.38998 .56502 m .38578 .56591 L .38894 .56348 L F
.682 .693 .853 r
.38803 .56786 m .39092 .56674 L .39 .56523 L F
.07 0 .059 r
.3897 .56521 m .38853 .56542 L .38998 .56502 L F
.38853 .56542 m .38735 .56558 L .38889 .56525 L F
.38917 .56525 m .38889 .56525 L .38998 .56502 L F
.38853 .56542 m .38889 .56525 L .38917 .56525 L F
.506 .61 .89 r
.39175 .56518 m .39092 .56674 L .39249 .56563 L F
.643 .85 .46 r
.39136 .56281 m .38998 .56502 L .38894 .56348 L F
.506 .61 .89 r
.38894 .56348 m .39036 .56434 L .39136 .56281 L F
.643 .85 .46 r
.39136 .56281 m .3908 .56367 L .38998 .56502 L F
.39117 .56306 m .39008 .56479 L .38998 .56502 L F
.506 .61 .89 r
.39036 .56434 m .39249 .56563 L .39136 .56281 L F
.643 .85 .46 r
.39136 .56281 m .39117 .56306 L .3908 .56367 L F
.39117 .56306 m .39037 .5641 L .39008 .56479 L F
.506 .61 .89 r
.39036 .56434 m .39 .56523 L .39175 .56518 L F
.38894 .56348 m .38987 .56501 L .39036 .56434 L F
.682 .693 .853 r
.38853 .56542 m .3896 .56528 L .38894 .56348 L F
.38803 .56786 m .39 .56523 L .38853 .56542 L F
.38803 .56786 m .38853 .56542 L .38578 .56591 L F
.07 0 .059 r
.38727 .56688 m .38578 .56591 L .3897 .56521 L F
.761 .605 .685 r
.3897 .56518 m .3896 .56528 L .38967 .56523 L F
.682 .693 .853 r
.3896 .56528 m .39 .56523 L .38987 .56501 L F
.3896 .56528 m .38987 .56501 L .38894 .56348 L F
.761 .605 .685 r
.39037 .5641 m .38727 .56688 L .3896 .56528 L F
.39037 .5641 m .3896 .56528 L .3897 .56518 L F
.39008 .56479 m .38967 .56523 L .38998 .56502 L F
.506 .61 .89 r
.38987 .56501 m .39008 .56479 L .39036 .56434 L F
.761 .605 .685 r
.39037 .5641 m .38967 .56523 L .39008 .56479 L F
.506 .61 .89 r
.38987 .56501 m .3899 .56507 L .39008 .56479 L F
.3899 .56507 m .39 .56523 L .39036 .56434 L F
.39 .56523 m .39092 .56674 L .39175 .56518 L F
.07 0 .059 r
.38853 .56542 m .38578 .56591 L .38735 .56558 L F
.682 .693 .853 r
.38853 .56542 m .38894 .56348 L .38578 .56591 L F
.674 .373 .457 r
.38611 .56917 m .39092 .56674 L .38803 .56786 L F
0 0 .134 r
.31644 .6497 m .31824 .64601 L .31959 .64904 L F
.3 0 .018 r
.31644 .6497 m .31959 .64904 L .31839 .65 L F
.072 .513 .899 r
.31455 .64805 m .31644 .6497 L .31839 .65 L F
.696 .558 .694 r
.63101 .43769 m .63285 .43607 L .63265 .43381 L F
.801 .999 .843 r
.63285 .43607 m .63518 .43337 L .63265 .43381 L F
1 .808 .497 r
.34778 .66175 m .34888 .66158 L .34837 .65872 L F
.599 .95 .835 r
.34467 .66355 m .34888 .66158 L .34778 .66175 L F
.471 .844 .607 r
.35008 .66054 m .34888 .66158 L .35123 .65976 L F
.476 .894 .813 r
.34778 .66175 m .34888 .66158 L .35008 .66054 L F
.026 0 .244 r
.30844 .58516 m .31045 .58158 L .30868 .58257 L F
0 .15 .691 r
.21841 .60797 m .21846 .60683 L .21618 .60458 L F
.001 .403 .852 r
.21841 .60797 m .21997 .60856 L .21846 .60683 L F
.991 .754 .38 r
.41973 .58252 m .41852 .58399 L .41882 .58126 L F
.41973 .58252 m .41971 .58551 L .41852 .58399 L F
.719 .342 .336 r
.33747 .70992 m .33848 .70948 L .33565 .70971 L F
.143 0 0 r
.33912 .71188 m .34285 .71253 L .34114 .71225 L F
.326 .571 .929 r
.33912 .71188 m .34114 .71225 L .34105 .71214 L F
.844 .479 .363 r
.33848 .70948 m .33912 .71188 L .33722 .71162 L F
.326 .571 .929 r
.33912 .71188 m .34105 .71214 L .33773 .70811 L F
.844 .479 .363 r
.33722 .71162 m .33912 .71188 L .33676 .71241 L F
.235 0 0 r
.28615 .55165 m .28525 .55081 L .28652 .54872 L F
.966 .816 .389 r
.40214 .6818 m .40337 .68076 L .40288 .67841 L F
.40214 .6818 m .40285 .68376 L .40337 .68076 L F
.151 .399 .846 r
.24573 .57751 m .24537 .57945 L .24386 .57699 L F
.025 .257 .758 r
.24573 .57751 m .24763 .58149 L .24537 .57945 L F
.435 .332 .638 r
.24537 .57945 m .24763 .58149 L .24551 .58208 L F
.648 .776 .941 r
.34684 .50064 m .34277 .49981 L .34509 .49962 L F
.115 .628 .893 r
.34509 .49962 m .34927 .50058 L .34684 .50064 L F
.577 .607 .846 r
.35142 .50165 m .34684 .50064 L .34927 .50058 L F
.777 .783 .858 r
.39876 .51241 m .39476 .51224 L .39737 .51182 L F
.871 .991 .817 r
.40146 .50914 m .39876 .51241 L .39885 .51009 L F
.842 .983 .868 r
.39876 .51241 m .39737 .51182 L .39885 .51009 L F
0 0 0 r
.357 .66222 m .35886 .65889 L .35795 .66112 L F
.35795 .66112 m .35886 .65889 L .35967 .65782 L F
.43 .136 .362 r
.63264 .40712 m .6316 .40552 L .62997 .40768 L F
0 0 0 r
.39863 .69326 m .39769 .69542 L .39642 .69664 L F
.39642 .69664 m .39659 .69738 L .39506 .69901 L F
.39642 .69664 m .39769 .69542 L .39659 .69738 L F
.888 .812 .333 r
.40796 .59049 m .40816 .59141 L .40876 .58871 L F
.919 .805 .335 r
.40796 .59049 m .40876 .58871 L .40838 .58819 L F
.401 .662 .965 r
.60155 .38723 m .60055 .38902 L .599 .38719 L F
0 0 .187 r
.60081 .38955 m .60055 .38902 L .60155 .38723 L F
.60081 .38955 m .60105 .39138 L .60055 .38902 L F
.597 .667 .888 r
.59396 .42592 m .59537 .4284 L .59784 .42764 L F
0 .198 .727 r
.59396 .42592 m .59537 .4284 L .59653 .42817 L F
0 0 .027 r
.41075 .50592 m .41107 .50215 L .41306 .50292 L F
.41075 .50592 m .41101 .50434 L .41107 .50215 L F
.539 .016 0 r
.41075 .50592 m .4138 .50887 L .41137 .50678 L F
.542 .401 .639 r
.41306 .50292 m .41348 .50621 L .41075 .50592 L F
.543 .313 .516 r
.41348 .50621 m .4138 .50887 L .41075 .50592 L F
.539 .016 0 r
.41075 .50592 m .41137 .50678 L .41101 .50434 L F
.703 .598 .736 r
.28694 .54172 m .28988 .54194 L .28857 .53783 L F
.537 .284 .479 r
.32407 .5493 m .32641 .54979 L .32415 .54762 L F
.035 0 0 r
.32792 .55337 m .32468 .55492 L .32553 .55396 L F
.625 .559 .76 r
.3479 .64648 m .3463 .64903 L .34396 .64821 L F
.69 .235 .165 r
.3463 .64903 m .34858 .65121 L .34436 .65069 L F
.508 .911 .888 r
.35609 .71369 m .36015 .71242 L .35831 .71478 L F
.49 .07 .171 r
.35831 .71478 m .36015 .71242 L .3633 .714 L F
.248 0 .111 r
.38718 .60917 m .38434 .61105 L .38758 .61032 L F
.56 .338 .535 r
.32991 .51819 m .33274 .51525 L .33058 .51617 L F
.604 .244 .332 r
.60441 .44281 m .6016 .44401 L .60269 .44283 L F
.60441 .44281 m .6048 .44484 L .6016 .44401 L F
.813 .396 .254 r
.60603 .44406 m .6048 .44484 L .60441 .44281 L F
.656 .702 .88 r
.34616 .65237 m .34413 .65497 L .3433 .65266 L F
.34616 .65237 m .34862 .65494 L .34413 .65497 L F
.711 .54 .656 r
.34862 .65494 m .34589 .65663 L .34413 .65497 L F
.348 0 .025 r
.24153 .54451 m .23918 .5467 L .23696 .54686 L F
.669 .273 .286 r
.24317 .54656 m .24153 .54451 L .2427 .5429 L F
.24317 .54656 m .23918 .5467 L .24153 .54451 L F
.432 .447 .775 r
.42884 .51836 m .42625 .51606 L .4291 .51548 L F
.727 .302 .24 r
.36833 .63275 m .36811 .63069 L .36553 .63014 L F
.594 .45 .656 r
.36811 .63069 m .37163 .63002 L .37114 .62646 L F
.509 .21 .394 r
.37034 .63252 m .36811 .63069 L .36833 .63275 L F
.37034 .63252 m .37163 .63002 L .36811 .63069 L F
.342 .05 .316 r
.38791 .70544 m .39105 .70222 L .38977 .70497 L F
0 0 0 r
.39105 .70222 m .39257 .70211 L .38977 .70497 L F
.39105 .70222 m .39289 .70196 L .39257 .70211 L F
.201 .085 .489 r
.38434 .61105 m .38634 .61271 L .38758 .61032 L F
.38434 .61105 m .3843 .61405 L .38634 .61271 L F
.43 .389 .711 r
.28988 .54194 m .2903 .53829 L .28857 .53783 L F
.335 0 .117 r
.28904 .54364 m .29209 .54209 L .28988 .54194 L F
.846 .824 .827 r
.69971 .30331 m .69575 .30496 L .69835 .30149 L F
.854 .835 .827 r
.70234 .30013 m .69971 .30331 L .69835 .30149 L F
.865 .873 .842 r
.68767 .31996 m .68648 .32162 L .68371 .32164 L F
.88 .849 .809 r
.68648 .32162 m .68422 .32479 L .68371 .32164 L F
.644 .562 .747 r
.30279 .61612 m .29925 .61728 L .29922 .61436 L F
.309 .225 .597 r
.30176 .61944 m .29925 .61728 L .30279 .61612 L F
.30176 .61944 m .29944 .62064 L .29925 .61728 L F
0 0 .163 r
.74014 .32961 m .73856 .33398 L .73939 .33223 L F
.753 .797 .888 r
.37446 .62944 m .37845 .62986 L .37701 .62827 L F
.767 .39 .342 r
.37662 .63203 m .37845 .62986 L .37446 .62944 L F
.561 .577 .827 r
.37845 .62986 m .37951 .62576 L .37701 .62827 L F
.37845 .62986 m .38094 .62951 L .37951 .62576 L F
.064 0 0 r
.37802 .6305 m .37831 .63003 L .37662 .63203 L F
.784 .953 .926 r
.37802 .6305 m .37662 .63203 L .37575 .63083 L F
.37802 .6305 m .37575 .63083 L .37792 .63067 L F
.37802 .6305 m .37792 .63067 L .38031 .63048 L F
.064 0 0 r
.37802 .6305 m .37845 .62986 L .37831 .63003 L F
.37802 .6305 m .38094 .62951 L .37845 .62986 L F
.405 .148 .408 r
.30267 .59595 m .3039 .5976 L .30431 .59466 L F
.30267 .59595 m .30167 .59828 L .3039 .5976 L F
.49 .199 .399 r
.26007 .54951 m .25812 .54771 L .2604 .54716 L F
.26007 .54951 m .25753 .55005 L .25812 .54771 L F
.934 .634 .17 r
.25089 .59209 m .25131 .59265 L .25008 .58893 L F
.264 .768 .87 r
.22077 .59238 m .22284 .592 L .22466 .59212 L F
.595 .632 .858 r
.22466 .59212 m .2255 .58778 L .22381 .58821 L F
.665 .121 0 r
.22482 .59331 m .22466 .59212 L .22284 .592 L F
.757 .359 .3 r
.26132 .53734 m .26559 .53949 L .26309 .54095 L F
.57 .661 .899 r
.26559 .53949 m .26712 .54232 L .26309 .54095 L F
.143 0 0 r
.26712 .54232 m .26357 .54372 L .26309 .54095 L F
.789 .306 0 r
.37691 .65036 m .37716 .64925 L .37628 .64759 L F
.287 .162 .53 r
.37716 .64925 m .37847 .65153 L .37688 .65186 L F
.789 .306 0 r
.37691 .65036 m .37847 .65153 L .37716 .64925 L F
.819 .489 .431 r
.42692 .56246 m .42825 .56439 L .42674 .56385 L F
.503 .179 .351 r
.24321 .57035 m .24243 .57242 L .23993 .57261 L F
.558 .261 .419 r
.24608 .56954 m .24243 .57242 L .24321 .57035 L F
.969 .853 .45 r
.65413 .40577 m .65316 .41052 L .6526 .40915 L F
.65413 .40577 m .6526 .40915 L .65422 .4058 L F
0 0 .272 r
.31393 .64545 m .31455 .64805 L .3143 .64526 L F
.779 .875 .447 r
.30793 .58639 m .30674 .58885 L .30844 .58516 L F
.717 .765 .891 r
.63508 .40122 m .63896 .40181 L .63859 .39941 L F
.435 .555 .878 r
.63859 .39941 m .63896 .40181 L .64036 .39999 L F
.473 .309 .578 r
.63896 .40181 m .64165 .40364 L .64036 .39999 L F
.63896 .40181 m .6391 .40447 L .64165 .40364 L F
.629 .109 0 r
.63896 .40181 m .64165 .40364 L .6391 .40447 L F
.797 .709 .768 r
.37526 .60413 m .3769 .60782 L .37217 .60767 L F
.802 .615 .649 r
.37217 .60767 m .3769 .60782 L .37523 .61079 L F
.145 .33 .792 r
.37782 .60591 m .3769 .60782 L .37583 .60541 L F
.37782 .60591 m .37583 .60541 L .37664 .60509 L F
.948 .63 .398 r
.37751 .6036 m .37782 .60591 L .37949 .60497 L F
.145 .33 .792 r
.37782 .60591 m .37526 .60413 L .37751 .6036 L F
.37664 .60509 m .37583 .60541 L .37526 .60413 L F
.647 .409 .544 r
.37751 .6036 m .37782 .60591 L .37492 .60596 L F
.021 0 .364 r
.37726 .60592 m .37606 .60805 L .37782 .60591 L F
.37492 .60596 m .37606 .60805 L .37726 .60592 L F
.37492 .60596 m .37443 .60954 L .37606 .60805 L F
.145 .223 .687 r
.37217 .60767 m .37443 .60954 L .37492 .60596 L F
.614 .757 .947 r
.37575 .60656 m .37606 .60805 L .37265 .60769 L F
.666 .82 .386 r
.37523 .61079 m .3769 .60782 L .37782 .60591 L F
.37523 .61079 m .37782 .60591 L .37857 .60947 L F
.77 .682 .765 r
.37857 .60947 m .37594 .61147 L .37523 .61079 L F
.37857 .60947 m .37917 .61265 L .37627 .61229 L F
.37594 .61147 m .37627 .61229 L .37506 .61215 L F
.37857 .60947 m .37627 .61229 L .37594 .61147 L F
.521 .439 .704 r
.37496 .60905 m .37686 .61118 L .37606 .60805 L F
.37443 .60954 m .37544 .61022 L .37496 .60905 L F
.37544 .61022 m .37686 .61118 L .37496 .60905 L F
.37686 .61118 m .37751 .61162 L .37728 .61104 L F
.37686 .61118 m .37728 .61104 L .37606 .60805 L F
.77 .682 .765 r
.37594 .61147 m .37506 .61215 L .37511 .61174 L F
.37594 .61147 m .37511 .61174 L .37523 .61079 L F
.802 .615 .649 r
.37217 .60767 m .37523 .61079 L .37309 .60945 L F
.789 .29 0 r
.37523 .61079 m .37506 .61215 L .37309 .60945 L F
.521 .439 .704 r
.37443 .60954 m .37506 .61215 L .37751 .61162 L F
.43 .283 .579 r
.3748 .61033 m .37265 .60769 L .37606 .60805 L F
.605 .508 .717 r
.37695 .60625 m .37511 .60973 L .37606 .60805 L F
.37511 .60973 m .3748 .61033 L .37606 .60805 L F
0 0 .11 r
.37854 .60468 m .3767 .60656 L .37715 .6049 L F
.37832 .60445 m .37715 .6049 L .37751 .6036 L F
.37854 .60468 m .37715 .6049 L .37832 .60445 L F
.599 .035 0 r
.29699 .63454 m .29655 .63289 L .29568 .63524 L F
.29699 .63454 m .29861 .63393 L .29655 .63289 L F
.683 .526 .667 r
.36159 .62989 m .36553 .63014 L .3646 .62666 L F
.434 .15 .381 r
.27809 .54801 m .27976 .54977 L .28013 .54731 L F
.27809 .54801 m .27739 .55047 L .27976 .54977 L F
.492 0 0 r
.70482 .3484 m .70591 .34838 L .70369 .34719 L F
.70482 .3484 m .70369 .34719 L .70294 .34622 L F
.074 0 0 r
.33346 .56039 m .33148 .56177 L .33004 .56183 L F
.557 .047 0 r
.33197 .56177 m .33346 .56039 L .33626 .56007 L F
.33197 .56177 m .33143 .5618 L .33346 .56039 L F
.635 .964 .882 r
.33695 .55848 m .33626 .56007 L .33702 .55742 L F
.802 .999 .799 r
.33508 .55706 m .3321 .56157 L .33695 .55848 L F
.3321 .56157 m .33197 .56177 L .33242 .56147 L F
.3321 .56157 m .33242 .56147 L .33695 .55848 L F
.074 0 0 r
.33148 .56177 m .33143 .5618 L .33137 .5618 L F
.33148 .56177 m .33137 .5618 L .33004 .56183 L F
.964 .941 .658 r
.36312 .67905 m .36504 .67897 L .36555 .67578 L F
.958 .864 .703 r
.36032 .68228 m .36504 .67897 L .36312 .67905 L F
.21 .274 .712 r
.36624 .68038 m .36555 .67578 L .36504 .67897 L F
.948 .954 .665 r
.36504 .67897 m .36589 .68303 L .36624 .68038 L F
.36504 .67897 m .36292 .68301 L .36589 .68303 L F
.36504 .67897 m .36202 .68396 L .36292 .68301 L F
.449 .523 .842 r
.55999 .42294 m .55884 .42494 L .55744 .42352 L F
.901 .861 .791 r
.68995 .3164 m .68627 .31842 L .6886 .31499 L F
.68995 .3164 m .68767 .31996 L .68627 .31842 L F
.898 .81 .752 r
.69023 .31159 m .68995 .3164 L .6886 .31499 L F
.643 .198 0 r
.39689 .52112 m .39771 .5223 L .39657 .52081 L F
.803 .313 0 r
.40002 .52437 m .39657 .52081 L .39771 .5223 L F
.846 .83 .832 r
.68422 .32479 m .68116 .32468 L .68371 .32164 L F
.861 .799 .789 r
.68422 .32479 m .68321 .32582 L .68116 .32468 L F
.789 .993 .768 r
.62622 .4022 m .6286 .3997 L .62727 .40001 L F
.254 .758 .723 r
.62727 .40001 m .6286 .3997 L .63138 .3988 L F
.86 .921 .528 r
.64599 .42285 m .64452 .4272 L .6433 .42598 L F
.484 .295 .547 r
.31188 .60097 m .30951 .60428 L .30941 .60143 L F
.754 .705 .806 r
.57051 .4233 m .57507 .42463 L .57156 .42656 L F
.378 .001 .191 r
.26589 .55433 m .26519 .556 L .26786 .55516 L F
.499 0 0 r
.32775 .69622 m .32951 .69717 L .33045 .69794 L F
.854 .835 .827 r
.70234 .30013 m .69835 .30149 L .70095 .29838 L F
.835 .826 .839 r
.70505 .29699 m .70234 .30013 L .70095 .29838 L F
.501 .324 .572 r
.39237 .60443 m .39497 .60056 L .39362 .60206 L F
.907 .948 .818 r
.36698 .66058 m .36442 .662 L .36692 .66059 L F
.198 0 .011 r
.36587 .66273 m .36692 .66059 L .36442 .662 L F
.681 .792 .326 r
.36683 .66059 m .36692 .66059 L .36587 .66273 L F
.36755 .65899 m .36692 .66059 L .36683 .66059 L F
.907 .948 .818 r
.36775 .66015 m .36698 .66058 L .36692 .66059 L F
0 0 0 r
.36392 .58183 m .36098 .5853 L .36323 .58412 L F
.668 .628 .8 r
.36197 .58811 m .36323 .58412 L .36098 .5853 L F
.718 .919 .57 r
.62516 .40314 m .62398 .40525 L .62622 .4022 L F
.749 .926 .572 r
.62516 .40314 m .62622 .4022 L .62727 .40001 L F
.246 0 0 r
.26903 .62248 m .27298 .62047 L .27091 .62111 L F
0 0 .094 r
.61376 .44367 m .61167 .44555 L .61231 .44352 L F
.14 0 0 r
.2461 .53821 m .24463 .5399 L .24241 .54034 L F
0 0 0 r
.24597 .53885 m .2461 .53821 L .24843 .53766 L F
.24597 .53885 m .24463 .5399 L .2461 .53821 L F
.838 .616 .602 r
.35425 .58476 m .3585 .58249 L .35405 .58205 L F
.35425 .58476 m .35828 .58536 L .3585 .58249 L F
0 0 0 r
.39693 .65553 m .3949 .65854 L .39654 .65737 L F
.31 0 .077 r
.37897 .68313 m .38309 .68025 L .37923 .68057 L F
.37897 .68313 m .38141 .68263 L .38309 .68025 L F
.514 .006 0 r
.38385 .68214 m .38309 .68025 L .38141 .68263 L F
.493 .295 .539 r
.38436 .68125 m .38307 .68185 L .38034 .67833 L F
.38307 .68185 m .38141 .68263 L .38109 .68134 L F
.38307 .68185 m .38109 .68134 L .38034 .67833 L F
.514 .006 0 r
.38381 .68204 m .38589 .68073 L .38309 .68025 L F
.38385 .68214 m .38394 .68207 L .38381 .68204 L F
.38394 .68207 m .38589 .68073 L .38381 .68204 L F
.407 .149 .406 r
.37128 .5981 m .37367 .59752 L .37413 .59509 L F
.37413 .59509 m .37367 .59752 L .37128 .5981 L F
.452 .187 .421 r
.37413 .59509 m .37367 .59752 L .3764 .59665 L F
.37413 .59509 m .37367 .59752 L .3764 .59665 L F
0 .051 .603 r
.34656 .63609 m .34745 .63948 L .34818 .63801 L F
.74 .563 .654 r
.36181 .64298 m .36412 .64352 L .36407 .63974 L F
.251 .174 .571 r
.36407 .63974 m .36556 .64456 L .36654 .63926 L F
.36407 .63974 m .36412 .64352 L .36556 .64456 L F
.74 .718 .832 r
.57336 .42029 m .57507 .42463 L .57051 .4233 L F
.551 .613 .868 r
.57742 .42384 m .57507 .42463 L .57336 .42029 L F
.286 0 .208 r
.57599 .42586 m .57507 .42463 L .57742 .42384 L F
.343 .817 .898 r
.29353 .51978 m .28694 .52043 L .28928 .52004 L F
.685 .949 .957 r
.29416 .51878 m .29353 .51978 L .28928 .52004 L F
.522 .76 .983 r
.28057 .5208 m .28225 .52229 L .27836 .52138 L F
.667 .814 .954 r
.2846 .52111 m .28225 .52229 L .28057 .5208 L F
.439 .292 .583 r
.62595 .40707 m .62398 .40525 L .62516 .40314 L F
.62595 .40707 m .62363 .40821 L .62398 .40525 L F
.699 .199 .05 r
.62595 .40707 m .62398 .40525 L .62363 .40821 L F
.782 .654 .721 r
.3915 .663 m .39033 .66186 L .39375 .66095 L F
.457 0 0 r
.39291 .66172 m .39375 .66095 L .39033 .66186 L F
.62 .148 0 r
.60018 .39869 m .60267 .40173 L .6013 .40049 L F
.793 .34 0 r
.60267 .40173 m .60275 .40309 L .6013 .40049 L F
.60267 .40173 m .60398 .40408 L .60275 .40309 L F
.48 .896 .819 r
.35776 .57747 m .35696 .57841 L .35973 .5765 L F
.35776 .57747 m .35606 .57846 L .35696 .57841 L F
.459 .763 .995 r
.21834 .59092 m .22077 .59238 L .2183 .59258 L F
.841 .745 .758 r
.43761 .57241 m .4351 .57278 L .43689 .56959 L F
.63 .386 .529 r
.43761 .57241 m .43457 .57521 L .4351 .57278 L F
.43761 .57241 m .43774 .57507 L .43457 .57521 L F
.346 .423 .799 r
.43689 .56959 m .43989 .57141 L .43761 .57241 L F
.395 .295 .623 r
.43989 .57141 m .43774 .57507 L .43761 .57241 L F
.361 .718 .987 r
.29499 .74279 m .29701 .74405 L .29434 .74407 L F
.29434 .74407 m .29701 .74405 L .29499 .74279 L F
.143 0 0 r
.26712 .54232 m .26625 .54312 L .26357 .54372 L F
0 0 0 r
.26944 .54105 m .26625 .54312 L .26712 .54232 L F
.643 .198 0 r
.39689 .52112 m .39657 .52081 L .39464 .51899 L F
.981 .688 .339 r
.40368 .53173 m .40224 .53065 L .40212 .52793 L F
0 0 .464 r
.40368 .53173 m .40539 .53376 L .40424 .53233 L F
.584 .26 .387 r
.43413 .58558 m .43087 .58753 L .43154 .5862 L F
.743 .456 .494 r
.55563 .43974 m .55134 .44182 L .55155 .43927 L F
.55563 .43974 m .5545 .44246 L .55134 .44182 L F
.747 .46 .496 r
.55759 .4426 m .5545 .44246 L .55563 .43974 L F
.425 .861 .925 r
.2473 .52869 m .2481 .52776 L .24963 .528 L F
.2473 .52869 m .24579 .52849 L .2481 .52776 L F
.383 0 0 r
.27268 .63901 m .2717 .63945 L .27175 .63926 L F
.038 0 0 r
.27103 .63898 m .27359 .63877 L .27268 .63901 L F
.226 .444 .863 r
.26892 .6355 m .27103 .63898 L .27258 .63783 L F
.137 .275 .742 r
.27258 .63783 m .27103 .63898 L .27268 .63901 L F
.165 .431 .867 r
.26892 .6355 m .27249 .63777 L .27178 .63686 L F
.27249 .63777 m .27258 .63783 L .27246 .63768 L F
.27249 .63777 m .27246 .63768 L .2695 .63392 L F
.233 .47 .881 r
.2695 .63392 m .27258 .63783 L .27233 .63724 L F
.383 0 0 r
.27268 .63901 m .27175 .63926 L .27233 .63726 L F
.27268 .63901 m .27233 .63726 L .27235 .63733 L F
.038 0 0 r
.27359 .63877 m .2748 .63867 L .27268 .63901 L F
0 .55 .731 r
.2748 .63867 m .27502 .63862 L .27268 .63901 L F
.383 0 0 r
.27268 .63901 m .27233 .63724 L .27258 .63783 L F
.27268 .63901 m .27377 .64028 L .2717 .63945 L F
.27268 .63901 m .27502 .63862 L .27377 .64028 L F
.745 .407 .411 r
.2717 .63945 m .27377 .64028 L .27235 .63728 L F
.27233 .63726 m .27235 .63728 L .27233 .63724 L F
.383 0 0 r
.27235 .63733 m .27233 .63726 L .27233 .63724 L F
.745 .407 .411 r
.2717 .63945 m .27235 .63728 L .27233 .63726 L F
.165 .431 .867 r
.26914 .63491 m .27178 .63686 L .2695 .63392 L F
.26892 .6355 m .27178 .63686 L .26914 .63491 L F
0 .55 .731 r
.2748 .63867 m .27714 .63884 L .27502 .63862 L F
.354 0 0 r
.33457 .5713 m .3369 .57114 L .33797 .56958 L F
.305 0 0 r
.37224 .67576 m .37354 .67636 L .36949 .67668 L F
.876 .922 .853 r
.60855 .44287 m .6048 .44484 L .60603 .44406 L F
.449 .848 .654 r
.73326 .33287 m .73368 .33237 L .73497 .33076 L F
.73326 .33287 m .73212 .33348 L .73368 .33237 L F
.42 .808 .989 r
.35669 .52441 m .3589 .52628 L .35552 .52323 L F
.35669 .52441 m .36216 .52586 L .3589 .52628 L F
.948 .693 .517 r
.29369 .64835 m .29442 .64868 L .292 .64456 L F
.874 .715 .682 r
.37374 .68317 m .37279 .68359 L .37632 .68402 L F
.479 .235 .465 r
.374 .68683 m .37632 .68402 L .37279 .68359 L F
.374 .68683 m .37646 .68638 L .37632 .68402 L F
.387 .168 .456 r
.37923 .68057 m .37657 .68372 L .37897 .68313 L F
.37657 .68372 m .37632 .68402 L .37897 .68313 L F
.524 .396 .648 r
.38034 .67833 m .38141 .68263 L .37897 .68313 L F
.571 .112 .125 r
.38141 .68263 m .38082 .68267 L .37897 .68313 L F
.524 .396 .648 r
.38034 .67833 m .37897 .68313 L .37923 .68057 L F
.571 .112 .125 r
.38082 .68267 m .3769 .68294 L .37897 .68313 L F
.159 .693 .845 r
.37897 .68313 m .37374 .68317 L .37632 .68402 L F
.521 .335 .57 r
.37646 .68638 m .37897 .68313 L .37632 .68402 L F
.978 .68 .33 r
.54962 .43327 m .55103 .43788 L .54841 .43449 L F
.948 .83 .695 r
.54841 .43449 m .55103 .43788 L .54911 .43838 L F
.869 .468 .27 r
.55103 .43788 m .55155 .43927 L .54911 .43838 L F
.586 .573 .806 r
.62035 .41752 m .61748 .42076 L .61867 .4193 L F
.62035 .41752 m .62242 .42011 L .61748 .42076 L F
.707 .181 0 r
.32167 .69075 m .32381 .69324 L .32108 .69114 L F
.211 .09 .488 r
.20031 .57302 m .20226 .57441 L .2024 .57169 L F
.20031 .57302 m .20028 .57569 L .20226 .57441 L F
.299 .791 .762 r
.26278 .52352 m .25862 .52472 L .26097 .52409 L F
.336 .817 .865 r
.26307 .52293 m .26278 .52352 L .26097 .52409 L F
.26307 .52293 m .26481 .523 L .26278 .52352 L F
.782 .654 .721 r
.3915 .663 m .38782 .66128 L .39033 .66186 L F
.3915 .663 m .39007 .66581 L .38782 .66128 L F
.986 .707 .367 r
.39757 .50633 m .39735 .50661 L .39592 .50415 L F
.39735 .50661 m .396 .50548 L .39592 .50415 L F
.422 .675 .967 r
.39849 .50447 m .39757 .50633 L .39592 .50415 L F
.978 .697 .417 r
.39594 .50446 m .39602 .50576 L .39542 .50512 L F
.39592 .50415 m .39594 .50446 L .39542 .50512 L F
.541 .117 .187 r
.39618 .50418 m .39542 .50512 L .39849 .50447 L F
.39592 .50415 m .39542 .50512 L .39618 .50418 L F
.909 .674 .571 r
.39542 .50512 m .39617 .50812 L .39416 .50668 L F
0 0 0 r
.39542 .50512 m .39416 .50668 L .39451 .50626 L F
.39549 .50511 m .39552 .50507 L .39555 .50509 L F
.39549 .50505 m .3968 .50356 L .39555 .50509 L F
.39542 .50512 m .39451 .50626 L .3968 .50356 L F
.3968 .50356 m .39477 .50595 L .39542 .50512 L F
.39477 .50595 m .39416 .50668 L .39542 .50512 L F
.978 .697 .417 r
.39602 .50576 m .39617 .50812 L .39542 .50512 L F
.628 .778 .953 r
.39376 .50334 m .39542 .50512 L .39046 .50309 L F
.3968 .50356 m .39542 .50512 L .39376 .50334 L F
.434 .56 .883 r
.39788 .5015 m .39796 .50159 L .3968 .50356 L F
0 0 0 r
.39595 .50501 m .3968 .50356 L .39849 .50447 L F
.986 .707 .367 r
.39735 .50661 m .39617 .50812 L .396 .50548 L F
.709 .533 .649 r
.39849 .50447 m .39617 .50812 L .39757 .50633 L F
.39849 .50447 m .39923 .50748 L .39617 .50812 L F
.527 .213 .379 r
.40177 .50641 m .40063 .50668 L .39849 .50447 L F
.17 .183 .63 r
.40063 .50668 m .39923 .50748 L .39921 .50742 L F
.40017 .5062 m .39921 .50742 L .39849 .50447 L F
.40063 .50668 m .39921 .50742 L .40017 .5062 L F
.434 .56 .883 r
.39796 .50159 m .4009 .50526 L .3968 .50356 L F
.603 .782 .966 r
.40375 .50751 m .40063 .50668 L .40177 .50641 L F
.527 .213 .379 r
.40187 .50647 m .40063 .50668 L .40177 .50641 L F
.40187 .50647 m .40177 .50641 L .40169 .50636 L F
.624 .516 .711 r
.40169 .50636 m .40063 .50668 L .40187 .50647 L F
.603 .782 .966 r
.40338 .50604 m .40172 .50642 L .40325 .5059 L F
.40172 .50642 m .40063 .50668 L .40171 .50636 L F
.40172 .50642 m .40171 .50636 L .40325 .5059 L F
.307 .498 .882 r
.40061 .50437 m .40168 .50615 L .39788 .5015 L F
.40168 .50615 m .40187 .50647 L .4017 .50625 L F
.40168 .50615 m .4017 .50625 L .39788 .5015 L F
.527 .213 .379 r
.40187 .50647 m .40169 .50636 L .40168 .50636 L F
.624 .516 .711 r
.40325 .5059 m .40169 .50636 L .40187 .50647 L F
.527 .213 .379 r
.40177 .50641 m .39849 .50447 L .40168 .50636 L F
.434 .56 .883 r
.4009 .50526 m .40187 .50647 L .40055 .50571 L F
.527 .213 .379 r
.40168 .50636 m .39849 .50447 L .3968 .50356 L F
.434 .56 .883 r
.4009 .50526 m .40055 .50571 L .3968 .50356 L F
.603 .782 .966 r
.40525 .50791 m .40375 .50751 L .40338 .50604 L F
.40375 .50751 m .40177 .50641 L .40338 .50604 L F
0 0 0 r
.39555 .50509 m .3968 .50356 L .39595 .50501 L F
.803 .716 .769 r
.36937 .56281 m .36569 .56784 L .36301 .56606 L F
0 0 0 r
.36855 .56492 m .36937 .56281 L .36963 .5628 L F
.36855 .56492 m .36569 .56784 L .36937 .56281 L F
.56 .448 .683 r
.35639 .5603 m .35654 .56322 L .354 .56372 L F
.289 .045 .36 r
.20276 .56653 m .20472 .56585 L .2054 .56337 L F
.025 0 .183 r
.2025 .56904 m .20472 .56585 L .20276 .56653 L F
.331 .263 .628 r
.19923 .58171 m .20045 .57844 L .19915 .57916 L F
.496 .591 .879 r
.62626 .42297 m .62397 .42357 L .62242 .42011 L F
.253 .217 .623 r
.62625 .4254 m .62397 .42357 L .62626 .42297 L F
.62625 .4254 m .62478 .42668 L .62397 .42357 L F
.671 .768 .288 r
.39921 .69174 m .39769 .69542 L .39863 .69326 L F
.935 .77 .652 r
.61653 .37855 m .61813 .3827 L .61577 .38062 L F
.861 .809 .797 r
.61577 .38062 m .61813 .3827 L .61538 .3856 L F
.603 .622 .843 r
.62057 .38178 m .61813 .3827 L .61653 .37855 L F
.091 .233 .719 r
.61039 .41565 m .60931 .41757 L .61142 .41943 L F
.849 .671 .661 r
.41602 .53106 m .41792 .53591 L .4154 .53386 L F
.642 .573 .763 r
.41956 .53428 m .41792 .53591 L .41602 .53106 L F
.366 .099 .37 r
.41956 .53428 m .41671 .53751 L .41792 .53591 L F
.616 .06 0 r
.32381 .69324 m .32561 .69418 L .32775 .69622 L F
.952 .603 .239 r
.26606 .63335 m .26675 .63581 L .26481 .63233 L F
.687 .87 .968 r
.35824 .67426 m .36058 .67367 L .36095 .67407 L F
.241 0 0 r
.34298 .67277 m .34152 .67243 L .33985 .67398 L F
.34298 .67277 m .34366 .67191 L .34152 .67243 L F
.961 .923 .581 r
.31882 .66192 m .31786 .66476 L .31721 .66339 L F
.004 .306 .799 r
.31908 .66027 m .32148 .66372 L .31882 .66192 L F
.936 .933 .577 r
.29999 .52667 m .30226 .52658 L .30187 .52489 L F
.438 .473 .799 r
.30226 .52658 m .30378 .52387 L .30187 .52489 L F
.737 .652 .766 r
.4086 .51173 m .4091 .5156 L .40583 .5151 L F
.747 .338 .274 r
.43445 .5442 m .43731 .54468 L .43608 .54341 L F
.999 .843 .521 r
.70339 .33948 m .70488 .33848 L .70349 .33719 L F
.70339 .33948 m .70427 .34078 L .70488 .33848 L F
.59 .831 .99 r
.40511 .50823 m .40146 .50914 L .40387 .50849 L F
0 0 0 r
.40146 .50914 m .40283 .5089 L .40387 .50849 L F
.40146 .50914 m .39885 .51009 L .40283 .5089 L F
.635 .347 .464 r
.26389 .56565 m .26225 .57028 L .26003 .56791 L F
.671 .251 .24 r
.26443 .56379 m .26427 .56569 L .26388 .56564 L F
.26216 .56463 m .26388 .56564 L .26057 .56522 L F
.26443 .56379 m .26388 .56564 L .26216 .56463 L F
.737 .53 .613 r
.26429 .56541 m .26057 .56522 L .26427 .56569 L F
.635 .347 .464 r
.26429 .56541 m .26413 .56579 L .26389 .56565 L F
.26413 .56579 m .26225 .57028 L .26389 .56565 L F
.607 .433 .621 r
.26643 .56515 m .2665 .5678 L .26449 .56563 L F
.433 .052 .214 r
.26643 .56515 m .26449 .56563 L .26443 .56379 L F
.26449 .56563 m .26427 .56568 L .26428 .56561 L F
.26449 .56563 m .26428 .56561 L .26443 .56379 L F
.515 .361 .611 r
.26643 .56515 m .26883 .56734 L .2665 .5678 L F
.381 .036 .25 r
.26883 .56734 m .26761 .56781 L .2665 .5678 L F
.64 .352 .466 r
.26761 .56781 m .2646 .56564 L .2665 .5678 L F
.607 .433 .621 r
.26643 .56515 m .26449 .56563 L .26429 .56541 L F
.64 .352 .466 r
.26451 .56563 m .26429 .56541 L .26449 .56563 L F
.607 .433 .621 r
.26451 .56563 m .26429 .56541 L .26427 .56569 L F
.433 .052 .214 r
.2647 .56557 m .26427 .56569 L .26427 .56568 L F
.26643 .56515 m .26468 .56559 L .2647 .56557 L F
.26468 .56559 m .26427 .56569 L .2647 .56557 L F
.64 .352 .466 r
.2646 .56564 m .26449 .56563 L .2665 .5678 L F
.26761 .56781 m .26225 .57028 L .26404 .566 L F
.607 .433 .621 r
.26643 .56515 m .26429 .56541 L .26451 .56563 L F
.64 .352 .466 r
.2646 .56564 m .26429 .56541 L .26451 .56563 L F
.2646 .56564 m .26404 .566 L .26429 .56541 L F
.26761 .56781 m .26404 .566 L .2646 .56564 L F
.4 .758 .994 r
.35824 .67426 m .36095 .67407 L .35922 .67296 L F
.525 .341 .575 r
.36095 .67407 m .35824 .67426 L .35922 .67296 L F
.36095 .67407 m .3587 .67691 L .35824 .67426 L F
.031 0 0 r
.33538 .57721 m .33665 .57606 L .33963 .57496 L F
.438 .407 .727 r
.38 .59252 m .38059 .59505 L .38227 .59375 L F
.813 .639 .666 r
.38227 .59375 m .38059 .59753 L .38059 .59505 L F
.751 .596 .024 r
.38059 .59505 m .38046 .59608 L .38227 .59375 L F
.51 .709 .961 r
.38046 .59608 m .37731 .59541 L .38033 .596 L F
.148 0 0 r
.37717 .59543 m .38033 .596 L .37731 .59541 L F
.883 .961 .844 r
.38029 .59334 m .38033 .596 L .37717 .59543 L F
.438 .407 .727 r
.38 .59252 m .38227 .59375 L .38257 .59173 L F
.883 .961 .844 r
.38257 .59181 m .38045 .59577 L .38029 .59334 L F
.38045 .59577 m .38033 .596 L .38029 .59334 L F
.751 .596 .024 r
.38059 .59505 m .38059 .59753 L .38051 .59661 L F
.38047 .59602 m .38051 .59661 L .38046 .59608 L F
.38059 .59505 m .38051 .59661 L .38047 .59602 L F
.972 .744 .535 r
.37367 .56336 m .37201 .56335 L .36963 .5628 L F
.37367 .56336 m .37324 .56589 L .37201 .56335 L F
.716 .758 .885 r
.37523 .58815 m .37921 .58871 L .37742 .58855 L F
.695 .955 .951 r
.37989 .58819 m .38043 .58736 L .38022 .58814 L F
0 0 0 r
.38043 .58736 m .37921 .58871 L .3793 .5886 L F
.38043 .58736 m .3793 .5886 L .38114 .58627 L F
.38043 .58736 m .38114 .58627 L .38175 .5855 L F
.974 .816 .625 r
.38043 .58736 m .38175 .5855 L .38021 .58437 L F
.38043 .58736 m .38175 .5855 L .38021 .58437 L F
.38043 .58736 m .38021 .58437 L .38174 .58592 L F
.38043 .58736 m .38174 .58592 L .38259 .58679 L F
.695 .955 .951 r
.37742 .58855 m .37921 .58871 L .38043 .58736 L F
.37742 .58855 m .38043 .58736 L .37989 .58819 L F
.593 .498 .716 r
.37921 .58871 m .38 .59252 L .38257 .59173 L F
.017 .511 .871 r
.35123 .65976 m .357 .66222 L .3541 .65918 L F
.573 .666 .901 r
.3541 .65918 m .357 .66222 L .35795 .66112 L F
.441 .17 .405 r
.3718 .58497 m .37446 .58442 L .37495 .58261 L F
.492 .488 .781 r
.3718 .58497 m .37523 .58815 L .37446 .58442 L F
.799 .727 .785 r
.34538 .58547 m .34284 .58873 L .34514 .58626 L F
0 0 0 r
.34284 .58873 m .3432 .5892 L .34514 .58626 L F
.072 .634 .72 r
.34213 .57194 m .34158 .57197 L .33954 .57215 L F
.006 0 .222 r
.34158 .57197 m .33963 .57496 L .33954 .57215 L F
.206 0 .157 r
.37091 .60033 m .37367 .59752 L .37128 .5981 L F
.876 .922 .853 r
.60855 .44287 m .60591 .44569 L .6048 .44484 L F
.931 .808 .702 r
.58521 .4035 m .58536 .40809 L .58519 .4068 L F
0 .241 .756 r
.58519 .4068 m .58536 .40809 L .58695 .40922 L F
0 0 .474 r
.41008 .54741 m .41001 .54604 L .40868 .54379 L F
0 0 .419 r
.41008 .54741 m .41109 .54837 L .41001 .54604 L F
.41008 .54741 m .4113 .54999 L .41109 .54837 L F
0 .066 .565 r
.59071 .40633 m .59156 .40723 L .59019 .40583 L F
0 .37 .803 r
.59597 .40994 m .59277 .40851 L .59156 .40723 L F
.59597 .40994 m .59156 .40723 L .59359 .40903 L F
0 .066 .565 r
.59359 .40903 m .59156 .40723 L .59071 .40633 L F
0 .37 .803 r
.59277 .40851 m .59239 .40834 L .59156 .40723 L F
.823 .895 .893 r
.35654 .65182 m .35218 .65374 L .35505 .65194 L F
0 0 0 r
.35831 .65048 m .35929 .64934 L .35711 .65131 L F
.35831 .65048 m .35711 .65131 L .35654 .65182 L F
.951 .745 .589 r
.3595 .64966 m .35831 .65048 L .36073 .6508 L F
0 0 0 r
.35831 .65048 m .35939 .64924 L .35929 .64934 L F
.951 .745 .589 r
.35759 .64791 m .35939 .64924 L .35831 .65048 L F
.35759 .64791 m .35831 .65048 L .3595 .64966 L F
.596 .949 .89 r
.35831 .65048 m .35654 .65182 L .35505 .65194 L F
.35831 .65048 m .35505 .65194 L .3574 .65155 L F
.35831 .65048 m .35756 .65136 L .35777 .65149 L F
.32 0 .068 r
.36073 .6508 m .35831 .65048 L .35777 .65149 L F
.36073 .6508 m .35777 .65149 L .35976 .65279 L F
0 .193 .655 r
.35911 .6523 m .35777 .65149 L .35578 .64983 L F
.35976 .65279 m .35777 .65149 L .35911 .6523 L F
.596 .949 .89 r
.35756 .65136 m .3574 .65155 L .35777 .65149 L F
.721 .591 .71 r
.3112 .65837 m .31559 .66003 L .31414 .65476 L F
.762 .43 .424 r
.31509 .66122 m .31559 .66003 L .3112 .65837 L F
.865 .873 .842 r
.68767 .31996 m .68371 .32164 L .68627 .31842 L F
.591 .823 .988 r
.71144 .34596 m .70977 .34829 L .70829 .34777 L F
.71144 .34596 m .71239 .34735 L .70977 .34829 L F
.527 .48 .747 r
.36855 .56492 m .36726 .56913 L .36569 .56784 L F
.985 .742 .35 r
.70645 .28978 m .70755 .29357 L .70691 .29212 L F
.854 .798 .795 r
.70755 .29357 m .70376 .29504 L .70691 .29212 L F
.70755 .29357 m .70505 .29699 L .70376 .29504 L F
.736 .707 .823 r
.71007 .2908 m .70755 .29357 L .70645 .28978 L F
.865 .882 .848 r
.3673 .65271 m .36959 .65148 L .36767 .65058 L F
0 .526 .844 r
.36767 .65058 m .36959 .65148 L .37189 .6519 L F
.908 .806 .331 r
.31324 .52641 m .31341 .52902 L .31598 .52806 L F
.31324 .52641 m .31311 .52844 L .31341 .52902 L F
.94 .952 .756 r
.31324 .52641 m .31341 .52902 L .31598 .52806 L F
.23 0 .208 r
.72678 .35326 m .72381 .35588 L .72439 .35436 L F
.332 .173 .509 r
.38034 .57959 m .38034 .5791 L .38286 .57869 L F
.38034 .57959 m .37876 .57811 L .38034 .5791 L F
.512 0 0 r
.37595 .58401 m .37757 .58279 L .37495 .58261 L F
.206 .356 .794 r
.37866 .58079 m .37757 .58279 L .37595 .58401 L F
.37866 .58079 m .38021 .58437 L .37757 .58279 L F
0 0 0 r
.33156 .67906 m .3327 .67804 L .32967 .68045 L F
.072 0 0 r
.33531 .67717 m .3327 .67804 L .33156 .67906 L F
.522 .723 .965 r
.27715 .5295 m .27778 .52721 L .27548 .52819 L F
.27715 .5295 m .27918 .52895 L .27778 .52721 L F
0 0 .063 r
.21316 .55384 m .21348 .55506 L .21491 .55301 L F
.21316 .55384 m .21261 .55648 L .21348 .55506 L F
.587 .598 .831 r
.36955 .54355 m .37337 .54719 L .37194 .54374 L F
.173 0 0 r
.36928 .54959 m .37171 .54899 L .37337 .54719 L F
0 .31 .698 r
.37363 .5471 m .37675 .54869 L .37337 .54719 L F
.37363 .5471 m .37337 .54719 L .37171 .54899 L F
.732 .893 .503 r
.3957 .62545 m .39355 .62901 L .39481 .62716 L F
.692 .403 0 r
.17917 .64311 m .1799 .64563 L .17898 .64251 L F
.712 .79 .913 r
.32949 .66695 m .3332 .66701 L .33171 .665 L F
.675 .776 .926 r
.33171 .665 m .3332 .66701 L .33569 .66505 L F
.638 .618 .814 r
.62454 .3827 m .62179 .38503 L .62057 .38178 L F
.636 .378 .511 r
.68647 .36037 m .68657 .36188 L .68267 .36304 L F
.553 .283 .46 r
.68909 .36007 m .68657 .36188 L .68647 .36037 L F
.811 .401 0 r
.40117 .52584 m .40212 .52793 L .40002 .52437 L F
0 0 .336 r
.33438 .60315 m .33295 .60733 L .33307 .60459 L F
0 .128 .596 r
.60591 .44569 m .60745 .44675 L .6048 .44484 L F
.60591 .44569 m .60775 .44701 L .60745 .44675 L F
.842 .886 .871 r
.68321 .32582 m .67853 .32802 L .68116 .32468 L F
.068 .003 .466 r
.62472 .43419 m .62308 .43324 L .62412 .43248 L F
.62472 .43419 m .6235 .43633 L .62308 .43324 L F
.352 .502 .869 r
.20196 .59921 m .20127 .59647 L .20061 .59441 L F
.264 0 .039 r
.34688 .59203 m .34561 .5942 L .34307 .59475 L F
.069 0 0 r
.34759 .59333 m .34688 .59203 L .34926 .59145 L F
.34759 .59333 m .34561 .5942 L .34688 .59203 L F
.48 .284 .536 r
.34932 .58865 m .34926 .59145 L .34688 .59203 L F
0 0 .042 r
.28159 .53492 m .28068 .5374 L .27891 .53847 L F
.447 .394 .706 r
.28282 .5307 m .28159 .53492 L .28019 .52962 L F
.28282 .5307 m .28377 .53418 L .28159 .53492 L F
.081 0 .097 r
.28275 .53572 m .28159 .53492 L .28377 .53418 L F
.541 .859 .997 r
.28545 .53505 m .28275 .53572 L .28554 .53307 L F
.28545 .53505 m .28406 .53505 L .28275 .53572 L F
0 0 0 r
.28554 .53307 m .28275 .53572 L .28377 .53418 L F
.541 .859 .997 r
.28406 .53505 m .28112 .53505 L .28275 .53572 L F
.081 0 .097 r
.28275 .53572 m .28068 .5374 L .28096 .53663 L F
.28275 .53572 m .28096 .53663 L .28159 .53492 L F
.236 .074 .448 r
.31636 .59412 m .31443 .59775 L .31461 .59504 L F
0 0 0 r
.34284 .58873 m .34157 .59085 L .3432 .5892 L F
.337 0 0 r
.62177 .44996 m .62267 .44947 L .6256 .45033 L F
.223 0 0 r
.29277 .54168 m .29148 .54314 L .28904 .54364 L F
.253 0 0 r
.29441 .54231 m .29277 .54168 L .29472 .54 L F
.29441 .54231 m .29148 .54314 L .29277 .54168 L F
.466 .874 .953 r
.64165 .40364 m .64292 .40393 L .6444 .40281 L F
.337 .626 .958 r
.64292 .40393 m .64563 .40448 L .6444 .40281 L F
.466 .874 .953 r
.64165 .40364 m .64292 .40393 L .6444 .40281 L F
0 0 .154 r
.29827 .64246 m .30071 .63909 L .30137 .64239 L F
0 .103 .642 r
.30024 .64451 m .29827 .64246 L .30137 .64239 L F
.536 .333 .552 r
.32695 .56296 m .32424 .56618 L .32453 .56341 L F
0 0 0 r
.32713 .61024 m .32405 .61392 L .32548 .61222 L F
.923 .97 .681 r
.32713 .61024 m .32818 .60621 L .32781 .60789 L F
.32713 .61024 m .32632 .60973 L .32818 .60621 L F
.97 .892 .522 r
.32713 .61024 m .32548 .61222 L .32632 .60973 L F
.967 .827 .653 r
.23194 .55017 m .23515 .54791 L .23406 .54956 L F
0 0 0 r
.23696 .54686 m .23406 .54956 L .23515 .54791 L F
.638 .311 .402 r
.57193 .4509 m .5694 .44923 L .57343 .44907 L F
.714 .371 .395 r
.57343 .44907 m .57589 .45154 L .57193 .4509 L F
.68 .381 .462 r
.5761 .44936 m .57589 .45154 L .57343 .44907 L F
.978 .68 .33 r
.54962 .43327 m .54841 .43449 L .54643 .43199 L F
.579 .421 .631 r
.27227 .53782 m .27506 .5392 L .27459 .53736 L F
.27227 .53782 m .27248 .54006 L .27506 .5392 L F
.482 .67 .947 r
.39567 .65392 m .39693 .65553 L .39654 .65737 L F
.39567 .65392 m .39889 .65526 L .39693 .65553 L F
.706 .17 0 r
.40059 .65849 m .39693 .65553 L .39889 .65526 L F
.464 .264 .523 r
.29144 .61128 m .294 .60748 L .29205 .61028 L F
.095 0 .135 r
.38452 .58243 m .38175 .5855 L .38385 .58508 L F
.249 .664 .963 r
.38385 .58508 m .38175 .5855 L .38021 .58437 L F
.24 .692 .953 r
.38175 .5855 m .3837 .58546 L .38385 .58508 L F
.641 .314 .402 r
.38259 .58679 m .38385 .58508 L .38021 .58437 L F
.67 .869 .483 r
.38399 .5847 m .38385 .58508 L .38259 .58679 L F
.09 0 .133 r
.3866 .58124 m .38452 .58243 L .38385 .58508 L F
.67 .869 .483 r
.38495 .58327 m .38385 .58508 L .38399 .5847 L F
.24 .692 .953 r
.3837 .58546 m .38377 .58546 L .38385 .58508 L F
.146 0 0 r
.27969 .61775 m .2817 .61779 L .28142 .61646 L F
.27969 .61775 m .27886 .61894 L .2817 .61779 L F
.664 .111 0 r
.2219 .56302 m .22201 .56431 L .21961 .56504 L F
.045 0 0 r
.35186 .54076 m .35295 .54161 L .35372 .53965 L F
.35186 .54076 m .35047 .54265 L .35295 .54161 L F
.624 .46 .641 r
.24551 .58208 m .24645 .58638 L .24277 .58556 L F
.953 .822 .676 r
.24645 .58638 m .2425 .58741 L .24277 .58556 L F
.123 0 .254 r
.25042 .56015 m .24987 .56238 L .24836 .56292 L F
.564 .504 .746 r
.24987 .56238 m .24859 .5664 L .24836 .56292 L F
.711 .54 .656 r
.34862 .65494 m .34837 .65872 L .34589 .65663 L F
.747 .72 .827 r
.34909 .65362 m .34862 .65494 L .34616 .65237 L F
0 0 .338 r
.34901 .65767 m .34837 .65872 L .34862 .65494 L F
.928 .901 .778 r
.34862 .65494 m .34837 .65872 L .34901 .65767 L F
.75 .636 .734 r
.27657 .62955 m .27851 .62998 L .27855 .62734 L F
.743 .362 .332 r
.27657 .62955 m .2782 .63237 L .27851 .62998 L F
.289 .253 .644 r
.27855 .62734 m .27851 .62998 L .28047 .62878 L F
.029 0 .178 r
.27851 .62998 m .2782 .63237 L .28047 .62878 L F
.349 0 .191 r
.35303 .58848 m .34926 .59145 L .34932 .58865 L F
.617 .456 .641 r
.24869 .58531 m .24551 .58208 L .24763 .58149 L F
.24869 .58531 m .24645 .58638 L .24551 .58208 L F
0 .151 .69 r
.32769 .52229 m .32963 .52344 L .33068 .52154 L F
.21 .401 .833 r
.58443 .4353 m .57966 .43379 L .57824 .43115 L F
.992 .74 .434 r
.41659 .56593 m .41781 .56966 L .41646 .56851 L F
.955 .68 .234 r
.41781 .56966 m .41715 .57116 L .41646 .56851 L F
.41781 .56966 m .41804 .57238 L .41715 .57116 L F
.591 .265 .385 r
.58899 .44611 m .59167 .44809 L .58887 .44802 L F
.574 .276 .425 r
.59145 .44599 m .59167 .44809 L .58899 .44611 L F
.554 .227 .368 r
.43333 .53514 m .43278 .53713 L .43068 .53678 L F
.742 .586 .682 r
.43616 .5341 m .43278 .53713 L .43333 .53514 L F
.349 0 .191 r
.35303 .58848 m .35175 .59094 L .34926 .59145 L F
0 0 0 r
.35385 .58739 m .35175 .59094 L .35303 .58848 L F
.499 .551 .841 r
.38286 .57869 m .38452 .58243 L .3866 .58124 L F
.471 .096 .246 r
.29419 .5531 m .29711 .55281 L .29816 .55062 L F
.451 .351 .651 r
.30073 .55298 m .29816 .55062 L .30089 .55028 L F
.30073 .55298 m .29865 .55389 L .29816 .55062 L F
.725 .471 .542 r
.29711 .55281 m .30089 .55028 L .29816 .55062 L F
.592 .208 .283 r
.35055 .63187 m .34855 .62974 L .34848 .63261 L F
.35055 .63187 m .35099 .63011 L .34855 .62974 L F
.35055 .63187 m .34855 .62974 L .34848 .63261 L F
.35055 .63187 m .35099 .63011 L .34855 .62974 L F
.087 .635 .83 r
.7014 .3294 m .70475 .32954 L .70591 .32999 L F
.289 0 0 r
.70475 .32954 m .70881 .33123 L .70591 .32999 L F
0 .504 .788 r
.3555 .50304 m .3599 .50416 L .35746 .50428 L F
.825 .999 .787 r
.26467 .52884 m .26401 .53103 L .26562 .52945 L F
.26467 .52884 m .26341 .53062 L .26401 .53103 L F
.961 .83 .404 r
.263 .53235 m .26401 .53103 L .26341 .53062 L F
.263 .53235 m .26342 .53355 L .26401 .53103 L F
.809 .485 0 r
.28578 .64537 m .28687 .64857 L .28627 .64794 L F
.518 .027 0 r
.28627 .64794 m .28687 .64857 L .28894 .65077 L F
.706 .62 .759 r
.35596 .588 m .35932 .58892 L .35828 .58536 L F
.555 .528 .78 r
.35828 .58536 m .35932 .58892 L .36197 .58811 L F
.397 .317 .648 r
.35932 .58892 m .36137 .5903 L .36197 .58811 L F
.35932 .58892 m .35969 .59163 L .36137 .5903 L F
.623 .101 0 r
.35932 .58892 m .36137 .5903 L .35969 .59163 L F
.95 .596 .238 r
.43637 .57864 m .43483 .57774 L .43457 .57521 L F
.506 .437 .714 r
.43774 .57507 m .43637 .57864 L .43457 .57521 L F
.43774 .57507 m .43878 .57832 L .43637 .57864 L F
.41 .254 .558 r
.43878 .57832 m .43676 .58198 L .43637 .57864 L F
.521 .491 .763 r
.43211 .51846 m .4305 .52135 L .42884 .51836 L F
.43211 .51846 m .43307 .52096 L .4305 .52135 L F
.736 .54 .627 r
.66961 .34449 m .67548 .34553 L .6716 .34613 L F
.835 .826 .839 r
.70505 .29699 m .70095 .29838 L .70376 .29504 L F
0 .096 .637 r
.55173 .42064 m .55218 .41914 L .55003 .41944 L F
.55173 .42064 m .55366 .42412 L .55218 .41914 L F
0 .357 .72 r
.22492 .60991 m .22276 .60877 L .21997 .60856 L F
.22492 .60991 m .22532 .61006 L .22276 .60877 L F
.557 .312 .501 r
.26357 .54372 m .26293 .54706 L .2604 .54716 L F
.556 .312 .501 r
.2658 .54558 m .26357 .54372 L .26625 .54312 L F
.2658 .54558 m .26293 .54706 L .26357 .54372 L F
.831 .637 .64 r
.22579 .58472 m .2297 .58811 L .2298 .58548 L F
.671 .518 .669 r
.2297 .58811 m .23245 .58491 L .2298 .58548 L F
.243 .512 .907 r
.23615 .60911 m .23568 .61011 L .2321 .60609 L F
.35 .594 .937 r
.23615 .60911 m .23534 .61083 L .23568 .61011 L F
.23615 .60911 m .23729 .61086 L .23534 .61083 L F
.443 .363 .672 r
.32468 .55492 m .32524 .55922 L .32274 .55784 L F
.61 .49 .692 r
.28857 .53783 m .2903 .53829 L .2908 .53442 L F
0 0 0 r
.38461 .70854 m .38504 .70813 L .38572 .70838 L F
.38504 .70813 m .38791 .70544 L .38578 .70831 L F
.38504 .70813 m .38578 .70831 L .38572 .70838 L F
0 .059 .624 r
.38681 .7094 m .38729 .71098 L .38596 .70835 L F
0 0 0 r
.38574 .70838 m .38791 .70544 L .38977 .70497 L F
.027 .267 .766 r
.38596 .70835 m .38729 .71098 L .38461 .70854 L F
0 0 0 r
.38569 .70843 m .38572 .70838 L .38574 .70838 L F
.38572 .70838 m .38791 .70544 L .38574 .70838 L F
.881 .871 .823 r
.38574 .70838 m .38977 .70497 L .38573 .70834 L F
.027 .267 .766 r
.38536 .70716 m .38557 .70775 L .38572 .70838 L F
.38549 .70742 m .38574 .70838 L .38572 .70838 L F
.881 .871 .823 r
.38569 .70843 m .38576 .70829 L .38536 .70716 L F
.38579 .70823 m .38977 .70497 L .38791 .70394 L F
.38581 .70819 m .38791 .70394 L .38697 .70603 L F
.38573 .70834 m .3858 .70828 L .38579 .70823 L F
.027 .267 .766 r
.38573 .70834 m .38596 .70835 L .38574 .70838 L F
.881 .871 .823 r
.38576 .70829 m .38579 .70823 L .38581 .70819 L F
.38573 .70834 m .38579 .70823 L .38576 .70829 L F
.38579 .70823 m .38791 .70394 L .38581 .70819 L F
.38576 .70829 m .38697 .70603 L .38536 .70716 L F
.027 .267 .766 r
.38549 .70742 m .38585 .70814 L .38573 .70834 L F
.38585 .70814 m .38596 .70835 L .38573 .70834 L F
0 0 0 r
.38461 .70854 m .38572 .70838 L .38569 .70843 L F
.881 .871 .823 r
.38569 .70843 m .38574 .70838 L .38573 .70834 L F
.38569 .70843 m .38573 .70834 L .38576 .70829 L F
0 .059 .624 r
.38616 .70839 m .38596 .70835 L .38585 .70814 L F
.38592 .70805 m .38585 .70814 L .38549 .70742 L F
.38616 .70839 m .38585 .70814 L .38592 .70805 L F
.027 .267 .766 r
.38536 .70716 m .38549 .70742 L .38557 .70775 L F
0 .059 .624 r
.38544 .70729 m .38549 .70742 L .38536 .70716 L F
.38616 .70839 m .38549 .70742 L .38544 .70729 L F
.881 .871 .823 r
.3858 .70828 m .38977 .70497 L .38579 .70823 L F
.027 .267 .766 r
.38467 .70843 m .38572 .70838 L .38461 .70854 L F
.38536 .70716 m .38572 .70838 L .38467 .70843 L F
0 .059 .624 r
.38681 .7094 m .38596 .70835 L .38616 .70839 L F
.479 .898 .866 r
.25634 .5255 m .25712 .52455 L .25862 .52472 L F
.25634 .5255 m .25352 .52592 L .25712 .52455 L F
.763 .6 .676 r
.33291 .52841 m .33069 .53129 L .32849 .52783 L F
.64 .526 .709 r
.33291 .52841 m .33609 .52875 L .33499 .52403 L F
0 0 0 r
.33461 .52484 m .33374 .52772 L .33291 .52841 L F
.895 .64 .546 r
.33374 .52772 m .3337 .52782 L .33383 .52784 L F
0 .195 .721 r
.33383 .52784 m .33291 .52841 L .3337 .52782 L F
.895 .64 .546 r
.3337 .52782 m .33366 .52791 L .33383 .52784 L F
0 .195 .721 r
.33383 .52784 m .3337 .52782 L .33371 .52781 L F
0 0 0 r
.33374 .52772 m .33371 .52781 L .3337 .52782 L F
.33374 .52772 m .3337 .52782 L .33291 .52841 L F
.895 .64 .546 r
.33197 .52555 m .33212 .52857 L .33366 .52791 L F
.33197 .52555 m .33366 .52791 L .33374 .52772 L F
.922 .54 .259 r
.33374 .52772 m .33371 .52781 L .33197 .52555 L F
.33383 .52784 m .33371 .52781 L .33374 .52772 L F
0 0 0 r
.33499 .52403 m .33371 .52781 L .33461 .52484 L F
.559 .11 .14 r
.33291 .52841 m .33493 .52991 L .33609 .52875 L F
0 .195 .721 r
.33383 .52784 m .33493 .52991 L .33291 .52841 L F
.508 .463 .742 r
.33764 .55052 m .33845 .55377 L .34073 .55257 L F
.457 .515 .83 r
.36326 .6706 m .36477 .67423 L .36231 .6714 L F
.627 .319 .429 r
.36477 .67423 m .3671 .67671 L .36555 .67578 L F
.746 .242 .024 r
.36849 .67648 m .3671 .67671 L .36477 .67423 L F
.826 .365 0 r
.61626 .39223 m .61779 .3949 L .61559 .3927 L F
0 0 .545 r
.61626 .39223 m .61779 .3949 L .61714 .39182 L F
.61626 .39223 m .61714 .39182 L .61559 .3927 L F
.177 .353 .802 r
.22916 .60254 m .22954 .60496 L .22797 .60379 L F
.078 .215 .706 r
.37209 .56888 m .37325 .57125 L .37101 .56921 L F
.37209 .56888 m .37325 .57125 L .37101 .56921 L F
.622 .606 .813 r
.37138 .56918 m .37056 .57124 L .36925 .57018 L F
.37273 .56855 m .37217 .56924 L .37138 .56918 L F
.37217 .56924 m .37056 .57124 L .37138 .56918 L F
.37217 .56924 m .37325 .57125 L .37056 .57124 L F
.478 0 0 r
.37405 .56938 m .37289 .56929 L .37209 .56888 L F
.622 .606 .813 r
.37273 .56855 m .37287 .56928 L .37217 .56924 L F
.464 .573 .88 r
.37357 .56964 m .37325 .57125 L .37209 .56888 L F
.622 .606 .813 r
.37287 .56928 m .37325 .57125 L .37217 .56924 L F
.478 0 0 r
.37777 .5674 m .37408 .56936 L .37209 .56888 L F
.37408 .56936 m .37405 .56938 L .37396 .56936 L F
.37408 .56936 m .37396 .56936 L .37209 .56888 L F
.37405 .56938 m .37357 .56964 L .37289 .56929 L F
.241 0 0 r
.37961 .56779 m .37407 .56948 L .37777 .5674 L F
.37407 .56948 m .37357 .56964 L .37388 .56947 L F
.37407 .56948 m .37388 .56947 L .37777 .5674 L F
.3779 .56837 m .37357 .56964 L .37961 .56779 L F
.392 0 .16 r
.37977 .56782 m .37521 .57093 L .37357 .56964 L F
.525 .64 .905 r
.37454 .56952 m .37616 .5669 L .37352 .56736 L F
.37521 .57093 m .37552 .56958 L .37454 .56952 L F
.37552 .56958 m .37616 .5669 L .37454 .56952 L F
.844 .692 .693 r
.37368 .56946 m .37394 .56972 L .37352 .56736 L F
.37394 .56972 m .37521 .57093 L .37454 .56952 L F
.37394 .56972 m .37454 .56952 L .37352 .56736 L F
.241 0 0 r
.37977 .56782 m .3779 .56837 L .37961 .56779 L F
0 0 .101 r
.30844 .58516 m .30674 .58885 L .30807 .58747 L F
.177 0 .335 r
.30584 .58956 m .30807 .58747 L .30674 .58885 L F
.653 .565 .744 r
.6573 .39789 m .65854 .40184 L .65477 .40098 L F
0 0 0 r
.28529 .63523 m .28441 .63628 L .28641 .63304 L F
0 0 .202 r
.28391 .63872 m .28441 .63628 L .28529 .63523 L F
0 .205 .73 r
.27714 .63884 m .27923 .64261 L .27948 .64103 L F
0 .032 .6 r
.27948 .64103 m .27923 .64261 L .28085 .64483 L F
.166 .423 .861 r
.4253 .53142 m .4269 .53164 L .42505 .52989 L F
.227 0 0 r
.42451 .53286 m .4269 .53164 L .4253 .53142 L F
.442 .299 .591 r
.3037 .59192 m .30605 .59393 L .30584 .58956 L F
.387 .3 .635 r
.3037 .59192 m .30431 .59466 L .30605 .59393 L F
.426 .141 .375 r
.35106 .52188 m .35349 .52128 L .35452 .51875 L F
0 0 0 r
.35452 .51875 m .35586 .51783 L .35749 .51564 L F
.61 .496 .699 r
.35349 .52128 m .35586 .51783 L .35452 .51875 L F
.759 .813 .895 r
.64563 .40448 m .64915 .40436 L .64801 .40292 L F
.609 .763 .953 r
.64915 .40436 m .65137 .40188 L .64801 .40292 L F
.64915 .40436 m .65238 .40355 L .65137 .40188 L F
.892 .801 .318 r
.39851 .5911 m .39903 .58903 L .39826 .5908 L F
.572 .831 .994 r
.39956 .58682 m .39903 .58903 L .40124 .58801 L F
.745 .79 .3 r
.39826 .5908 m .39903 .58903 L .39956 .58682 L F
.26 0 .306 r
.40124 .58801 m .39903 .58903 L .39851 .5911 L F
0 0 .111 r
.40275 .66038 m .40236 .66474 L .40171 .6608 L F
.40275 .66038 m .40272 .66354 L .40236 .66474 L F
.542 .284 .475 r
.40465 .6669 m .40236 .66474 L .40272 .66354 L F
.40465 .6669 m .40205 .66784 L .40236 .66474 L F
.636 .074 0 r
.37222 .51144 m .37458 .51335 L .37536 .51284 L F
.879 .462 .037 r
.37536 .51284 m .37458 .51335 L .37591 .51439 L F
.803 .891 .907 r
.69922 .31816 m .70242 .31844 L .70122 .31631 L F
.876 .818 .788 r
.69922 .31816 m .70009 .32195 L .70242 .31844 L F
.9 .912 .821 r
.70122 .31631 m .70242 .31844 L .70481 .31493 L F
.527 .148 .264 r
.69831 .35762 m .70093 .35909 L .69827 .35896 L F
.69831 .35762 m .70222 .35685 L .70093 .35909 L F
.483 .283 .532 r
.27563 .61399 m .27791 .61385 L .27817 .61078 L F
0 0 .368 r
.6051 .40791 m .60714 .4115 L .60693 .40985 L F
0 .145 .689 r
.60714 .4115 m .6089 .41199 L .60693 .40985 L F
.60714 .4115 m .60872 .41367 L .6089 .41199 L F
.999 .844 .532 r
.33307 .5364 m .33252 .53597 L .33407 .53473 L F
.963 .714 .511 r
.33565 .70971 m .33676 .71241 L .33512 .71093 L F
.438 .174 .414 r
.33676 .71241 m .33912 .71188 L .33943 .71238 L F
.33676 .71241 m .33943 .71238 L .33512 .71093 L F
0 0 0 r
.20163 .59192 m .20184 .59287 L .20276 .59077 L F
.20163 .59192 m .20061 .59441 L .20184 .59287 L F
.995 .865 .578 r
.29402 .53706 m .29472 .54 L .29553 .53796 L F
.637 .893 .986 r
.29692 .53543 m .29553 .53796 L .29793 .53472 L F
.29692 .53543 m .29402 .53706 L .29553 .53796 L F
.037 0 .151 r
.29793 .53472 m .29553 .53796 L .2987 .53567 L F
.268 .026 .35 r
.2054 .56337 m .20664 .56497 L .20704 .56247 L F
.2054 .56337 m .20472 .56585 L .20664 .56497 L F
.772 .484 .498 r
.31916 .57263 m .31507 .56968 L .31896 .56983 L F
.452 .24 .5 r
.31507 .56968 m .31746 .57152 L .31575 .56784 L F
.31507 .56968 m .31522 .57237 L .31746 .57152 L F
.538 .106 .168 r
.59941 .44487 m .59845 .44687 L .59544 .44555 L F
.515 .139 .266 r
.6016 .44401 m .59845 .44687 L .59941 .44487 L F
.481 .102 .244 r
.30188 .5399 m .30182 .5407 L .29926 .54084 L F
.787 .638 .697 r
.5612 .44285 m .55909 .44551 L .55759 .4426 L F
.554 .622 .874 r
.30017 .53401 m .29793 .53472 L .29634 .53153 L F
.516 .133 .253 r
.2987 .53567 m .30017 .53401 L .29793 .53472 L F
.726 .329 .297 r
.30017 .53401 m .29692 .53543 L .29793 .53472 L F
.068 .026 .495 r
.32257 .58097 m .32093 .58246 L .32131 .57879 L F
.293 .248 .636 r
.32257 .58097 m .3209 .58434 L .32093 .58246 L F
.674 .626 .793 r
.37163 .63002 m .37297 .62586 L .37114 .62646 L F
.464 .364 .656 r
.36553 .63014 m .36511 .63356 L .36833 .63275 L F
.473 .396 .689 r
.36511 .63356 m .36827 .63445 L .36833 .63275 L F
.762 .43 .424 r
.31509 .66122 m .3112 .65837 L .31125 .6612 L F
.461 .224 .467 r
.29635 .60457 m .29939 .60119 L .29778 .60287 L F
.34 .482 .856 r
.36948 .51712 m .36975 .51907 L .37135 .51708 L F
0 0 .31 r
.36975 .51907 m .37081 .51999 L .37135 .51708 L F
.36975 .51907 m .37005 .52198 L .37081 .51999 L F
.807 .629 .661 r
.69801 .32498 m .70166 .32559 L .70009 .32195 L F
.806 .655 .695 r
.69769 .32757 m .70166 .32559 L .69801 .32498 L F
.69769 .32757 m .70113 .32918 L .70166 .32559 L F
.7 .399 .464 r
.57974 .45146 m .5761 .44936 L .57989 .44901 L F
.57974 .45146 m .57589 .45154 L .5761 .44936 L F
.639 .454 .617 r
.32424 .56618 m .3216 .56934 L .3216 .56654 L F
.238 0 .132 r
.287 .56258 m .28935 .56191 L .29051 .5595 L F
.199 0 0 r
.28935 .56191 m .29314 .55962 L .29051 .5595 L F
.616 .44 .621 r
.30332 .61409 m .30465 .61564 L .30279 .61612 L F
.104 .087 .552 r
.30603 .61258 m .30465 .61564 L .30332 .61409 L F
.512 0 0 r
.37595 .58401 m .37495 .58261 L .37446 .58442 L F
0 0 .488 r
.41559 .56372 m .41659 .56593 L .41534 .56203 L F
.746 .646 .75 r
.35811 .64562 m .36177 .64566 L .36181 .64298 L F
.051 0 0 r
.36078 .64571 m .36177 .64566 L .35811 .64562 L F
.614 .093 0 r
.36475 .64451 m .36181 .64298 L .36177 .64566 L F
.36475 .64451 m .36177 .64566 L .36266 .64409 L F
.677 .976 .821 r
.36266 .64409 m .36177 .64566 L .36078 .64571 L F
.367 .81 .664 r
.29437 .53256 m .2908 .53442 L .29317 .53313 L F
0 .524 .824 r
.3928 .65335 m .39433 .65314 L .39144 .65081 L F
.93 .97 .741 r
.39433 .65314 m .39567 .65392 L .39687 .65151 L F
.645 .545 .727 r
.39687 .65151 m .39929 .65476 L .39567 .65392 L F
.93 .97 .741 r
.39433 .65314 m .39687 .65151 L .39636 .65302 L F
.39606 .6531 m .39636 .65302 L .39633 .65309 L F
.39433 .65314 m .39636 .65302 L .39606 .6531 L F
.482 .67 .947 r
.39567 .65392 m .39654 .65737 L .39714 .65612 L F
.797 .831 .878 r
.39423 .65355 m .39612 .65466 L .39362 .65588 L F
.513 .749 .981 r
.39433 .65314 m .39606 .6531 L .39467 .65186 L F
.39606 .6531 m .39633 .65309 L .39467 .65186 L F
.797 .831 .878 r
.39467 .65186 m .3954 .65326 L .39423 .65355 L F
0 .524 .824 r
.39417 .65362 m .39567 .65392 L .39433 .65314 L F
.797 .831 .878 r
.3954 .65326 m .39612 .65466 L .39423 .65355 L F
.39467 .65186 m .39437 .65301 L .39433 .65314 L F
.39437 .65301 m .39362 .65588 L .39433 .65314 L F
0 .524 .824 r
.3928 .65335 m .39417 .65362 L .39433 .65314 L F
.824 .917 .9 r
.34863 .53806 m .34886 .54096 L .35179 .53905 L F
.958 .759 .592 r
.34975 .53739 m .34863 .53806 L .35179 .53905 L F
.104 .315 .789 r
.35144 .53877 m .35231 .5365 L .34975 .53739 L F
.406 .231 .529 r
.35007 .53401 m .35231 .5365 L .35205 .53335 L F
.35007 .53401 m .34975 .53739 L .35231 .5365 L F
.181 0 .218 r
.3472 .53509 m .34619 .53633 L .34715 .53636 L F
.34619 .53633 m .34532 .5374 L .34665 .53664 L F
.34619 .53633 m .34665 .53664 L .34715 .53636 L F
0 0 0 r
.34503 .54049 m .34715 .53636 L .34532 .5374 L F
.573 .274 .423 r
.34783 .53714 m .34863 .53806 L .34952 .53753 L F
.335 0 0 r
.34812 .53761 m .34718 .53699 L .34944 .53769 L F
.573 .274 .423 r
.34834 .53773 m .34608 .53957 L .34863 .53806 L F
.335 0 0 r
.34835 .53732 m .34696 .5368 L .34944 .53769 L F
.573 .274 .423 r
.34698 .53684 m .34669 .53775 L .34783 .53714 L F
.335 0 0 r
.347 .53686 m .34698 .53684 L .34835 .53732 L F
.34698 .53684 m .34696 .5368 L .34835 .53732 L F
.573 .274 .423 r
.34783 .53714 m .34669 .53775 L .34834 .53773 L F
0 0 0 r
.34694 .53676 m .34696 .5368 L .34715 .53636 L F
.521 .354 .595 r
.34709 .53652 m .34747 .5367 L .34697 .53678 L F
.573 .274 .423 r
.34738 .53663 m .34803 .53716 L .34975 .53739 L F
.521 .354 .595 r
.34747 .5367 m .34951 .53766 L .34799 .53714 L F
.34747 .5367 m .34799 .53714 L .34697 .53678 L F
.573 .274 .423 r
.34715 .53636 m .34738 .53663 L .34975 .53739 L F
.34738 .53663 m .34783 .53714 L .34803 .53716 L F
0 0 0 r
.34696 .5368 m .34698 .53684 L .3471 .5365 L F
.34696 .5368 m .3471 .5365 L .34715 .53636 L F
.521 .354 .595 r
.34578 .53591 m .34709 .53652 L .34547 .53626 L F
.34709 .53652 m .34697 .53678 L .34547 .53626 L F
.573 .274 .423 r
.34715 .53636 m .3471 .5365 L .34738 .53663 L F
.34803 .53716 m .34952 .53753 L .34975 .53739 L F
.34783 .53714 m .34806 .53719 L .34803 .53716 L F
.34806 .53719 m .34952 .53753 L .34803 .53716 L F
.708 .302 .276 r
.34715 .53636 m .34975 .53739 L .3472 .53509 L F
.554 .357 .568 r
.3472 .53509 m .34975 .53739 L .35007 .53401 L F
.521 .354 .595 r
.34895 .53229 m .3495 .53758 L .34738 .53663 L F
.34609 .53555 m .34738 .53663 L .34578 .53591 L F
.34895 .53229 m .34738 .53663 L .34609 .53555 L F
.3495 .53758 m .34951 .53766 L .34578 .53591 L F
.573 .274 .423 r
.34738 .53663 m .34698 .53684 L .34783 .53714 L F
.3471 .5365 m .34698 .53684 L .34738 .53663 L F
.34669 .53775 m .34608 .53957 L .34834 .53773 L F
.335 0 0 r
.34944 .53771 m .34944 .53769 L .34952 .53771 L F
.521 .354 .595 r
.34951 .53766 m .34952 .53771 L .34944 .53769 L F
0 0 0 r
.34952 .53753 m .35231 .5365 L .34975 .53739 L F
.34945 .53767 m .35231 .5365 L .34952 .53753 L F
.476 .507 .81 r
.35007 .53401 m .35065 .52959 L .34846 .5301 L F
.35007 .53401 m .35205 .53335 L .35065 .52959 L F
.474 .456 .757 r
.35065 .52959 m .35234 .53208 L .35234 .53208 L F
.225 .344 .776 r
.35065 .52959 m .35133 .53142 L .35195 .53151 L F
.35234 .53208 m .35205 .53335 L .35272 .53233 L F
.35133 .53142 m .3516 .53215 L .35234 .53208 L F
.3516 .53215 m .35205 .53335 L .35234 .53208 L F
0 0 0 r
.35007 .53745 m .35231 .5365 L .34942 .53769 L F
.3495 .53766 m .34942 .53769 L .34918 .53778 L F
.35007 .53745 m .34942 .53769 L .3495 .53766 L F
0 0 .442 r
.35205 .53335 m .35231 .5365 L .35373 .5341 L F
.564 .362 .566 r
.35214 .53583 m .35286 .53504 L .35231 .5365 L F
.351 .144 .453 r
.35373 .5341 m .35189 .53672 L .35196 .53602 L F
0 0 .442 r
.35205 .53335 m .35373 .5341 L .35314 .53169 L F
.351 .144 .453 r
.35373 .5341 m .35196 .53602 L .35234 .53208 L F
.564 .362 .566 r
.35107 .5371 m .35214 .53583 L .35231 .5365 L F
.35214 .53583 m .35292 .53489 L .35286 .53504 L F
.189 .014 .399 r
.34955 .53765 m .34952 .53771 L .34951 .53766 L F
.72 .692 .823 r
.35231 .5365 m .34863 .53806 L .34975 .53739 L F
.189 .014 .399 r
.35234 .53208 m .35196 .53602 L .34988 .53756 L F
.35196 .53602 m .35113 .53704 L .34988 .53756 L F
.564 .362 .566 r
.35275 .53505 m .35292 .53489 L .35107 .5371 L F
.104 .315 .789 r
.35179 .53905 m .35231 .5365 L .35144 .53877 L F
.72 .692 .823 r
.35231 .5365 m .35372 .53965 L .34924 .53825 L F
.189 .014 .399 r
.34954 .53767 m .34968 .53761 L .34952 .53771 L F
.34955 .53765 m .34968 .53761 L .34954 .53767 L F
.72 .692 .823 r
.35231 .5365 m .35019 .53771 L .34972 .53762 L F
0 0 0 r
.35025 .53743 m .35019 .53754 L .35107 .5371 L F
.091 .646 .794 r
.35019 .53754 m .34955 .53771 L .35026 .53741 L F
.34955 .53771 m .34952 .53771 L .34965 .53766 L F
.72 .692 .823 r
.35019 .53771 m .34962 .53771 L .34968 .53761 L F
.091 .646 .794 r
.35019 .53754 m .34951 .53771 L .34955 .53771 L F
0 0 0 r
.34863 .53806 m .35019 .53754 L .35025 .53743 L F
.091 .646 .794 r
.35019 .53754 m .35026 .53741 L .35111 .53705 L F
.72 .692 .823 r
.35231 .5365 m .34972 .53762 L .35028 .53736 L F
0 0 0 r
.35028 .53736 m .35107 .5371 L .35231 .5365 L F
.72 .692 .823 r
.35028 .53736 m .34972 .53762 L .34968 .53761 L F
0 0 0 r
.34968 .53761 m .35026 .5374 L .35028 .53736 L F
.35026 .5374 m .35107 .5371 L .35028 .53736 L F
.091 .646 .794 r
.34955 .53771 m .34965 .53766 L .35026 .5374 L F
.35026 .53741 m .35026 .5374 L .35189 .53672 L F
.34955 .53771 m .35026 .5374 L .35026 .53741 L F
.189 .014 .399 r
.35234 .53208 m .35196 .53602 L .35234 .53208 L F
.35196 .53602 m .35189 .53672 L .35196 .53602 L F
.35196 .53602 m .35196 .53602 L .35234 .53208 L F
.564 .362 .566 r
.35019 .53754 m .35275 .53505 L .35113 .53704 L F
.35019 .53754 m .35113 .53704 L .35107 .5371 L F
.091 .646 .794 r
.35019 .53754 m .35111 .53705 L .35189 .53672 L F
.72 .692 .823 r
.35019 .53771 m .34924 .53825 L .34962 .53771 L F
.091 .646 .794 r
.34955 .53771 m .34949 .53771 L .34953 .53771 L F
.34951 .53771 m .34949 .53771 L .34955 .53771 L F
.189 .014 .399 r
.34968 .53761 m .34988 .53756 L .34965 .53766 L F
.34968 .53761 m .34965 .53766 L .34952 .53771 L F
0 0 0 r
.35007 .53745 m .34934 .53772 L .34951 .53766 L F
.34934 .53772 m .34918 .53778 L .34935 .53772 L F
.34934 .53772 m .34935 .53772 L .34951 .53766 L F
.189 .014 .399 r
.35234 .53208 m .34989 .53754 L .34961 .53753 L F
.34989 .53754 m .34988 .53756 L .34961 .53753 L F
.34961 .53753 m .34988 .53756 L .34955 .53765 L F
.35234 .53208 m .34955 .53765 L .34895 .53229 L F
.35234 .53208 m .34955 .53765 L .35234 .53208 L F
.34955 .53765 m .34951 .53766 L .34895 .53229 L F
.091 .646 .794 r
.35019 .53754 m .34763 .53751 L .34945 .53771 L F
.34947 .5377 m .34945 .53771 L .34946 .53771 L F
.35019 .53754 m .34945 .53771 L .34947 .5377 L F
.35019 .53754 m .34946 .53771 L .34949 .53771 L F
0 0 0 r
.34947 .5377 m .35107 .5371 L .34968 .53761 L F
.091 .646 .794 r
.34953 .53771 m .34949 .53771 L .34952 .53771 L F
.72 .692 .823 r
.34968 .53761 m .34924 .53825 L .34863 .53806 L F
0 0 0 r
.34863 .53806 m .34964 .53766 L .34947 .5377 L F
.34964 .53766 m .35107 .5371 L .34947 .5377 L F
.189 .014 .399 r
.35196 .53602 m .35189 .53672 L .35113 .53704 L F
.35234 .53208 m .35234 .53208 L .35234 .53208 L F
.35234 .53208 m .35234 .53208 L .35234 .53208 L F
.102 .053 .511 r
.35234 .53208 m .35305 .52907 L .35065 .52959 L F
.35234 .53208 m .35314 .53169 L .35305 .52907 L F
.225 .344 .776 r
.35133 .53142 m .35272 .53233 L .35314 .53169 L F
.474 .456 .757 r
.35065 .52959 m .35234 .53208 L .34895 .53229 L F
.225 .344 .776 r
.35065 .52959 m .35195 .53151 L .35314 .53169 L F
0 0 0 r
.34951 .53766 m .34918 .53778 L .34891 .5379 L F
.335 0 0 r
.34718 .53699 m .347 .53686 L .34776 .53712 L F
.34718 .53699 m .34776 .53712 L .34944 .53769 L F
0 0 0 r
.34503 .54049 m .34665 .53747 L .34694 .53676 L F
.34665 .53747 m .34698 .53684 L .34696 .5368 L F
.34665 .53747 m .34696 .5368 L .34694 .53676 L F
.521 .354 .595 r
.34951 .53766 m .34944 .53769 L .34696 .5368 L F
.34697 .53678 m .34696 .5368 L .34547 .53626 L F
.34951 .53766 m .34696 .5368 L .34697 .53678 L F
0 0 0 r
.34647 .5378 m .34669 .53775 L .34698 .53684 L F
.335 0 0 r
.34589 .53748 m .34681 .53674 L .34812 .53761 L F
.091 .646 .794 r
.34763 .53751 m .34589 .53748 L .34735 .53758 L F
0 0 0 r
.34891 .5379 m .34945 .53767 L .34952 .53753 L F
.335 0 0 r
.34589 .53748 m .34944 .53769 L .34944 .53771 L F
.091 .646 .794 r
.34763 .53751 m .34735 .53758 L .34952 .53771 L F
0 0 0 r
.34503 .54049 m .34608 .53957 L .34669 .53775 L F
.34503 .54049 m .34669 .53775 L .34647 .5378 L F
.335 0 0 r
.347 .53686 m .34681 .53674 L .34696 .5368 L F
.335 0 .208 r
.34608 .53957 m .34759 .54071 L .34863 .53806 L F
.715 .58 .702 r
.34301 .53999 m .34589 .53748 L .34368 .53739 L F
.558 .758 .971 r
.34759 .54071 m .34663 .5399 L .34589 .53748 L F
.977 .764 .346 r
.34503 .54049 m .34548 .54455 L .34479 .54297 L F
.757 .838 .382 r
.34479 .54297 m .34608 .53957 L .34503 .54049 L F
.34479 .54297 m .3452 .54136 L .34608 .53957 L F
.335 0 .208 r
.34608 .53957 m .3452 .54136 L .34759 .54071 L F
.558 .758 .971 r
.34716 .54065 m .3452 .54136 L .34301 .53999 L F
.34759 .54071 m .34725 .5408 L .34716 .54065 L F
.34725 .5408 m .3452 .54136 L .34716 .54065 L F
.715 .58 .702 r
.34301 .53999 m .34663 .5399 L .34589 .53748 L F
.558 .758 .971 r
.34663 .5399 m .34301 .53999 L .34368 .53739 L F
.34759 .54071 m .34301 .53999 L .34663 .5399 L F
.715 .58 .702 r
.34301 .53999 m .34691 .54082 L .34663 .5399 L F
.34691 .54082 m .34724 .54089 L .34589 .53748 L F
.816 .461 0 r
.34653 .53957 m .34724 .54089 L .34662 .53987 L F
.558 .758 .971 r
.34663 .5399 m .34368 .53739 L .34589 .53748 L F
.816 .461 0 r
.34653 .53957 m .34662 .53987 L .34571 .53836 L F
.34575 .53813 m .34653 .53957 L .34571 .53836 L F
.34589 .53748 m .3471 .54053 L .34575 .53813 L F
.3471 .54053 m .34724 .54089 L .34575 .53813 L F
.34589 .53748 m .34571 .53836 L .34573 .5382 L F
.335 0 0 r
.34589 .53748 m .34547 .53626 L .34612 .53649 L F
.521 .354 .595 r
.34895 .53229 m .34547 .53626 L .34472 .53312 L F
.335 0 0 r
.34589 .53748 m .34368 .53739 L .34547 .53626 L F
.533 .166 .289 r
.34895 .53229 m .34472 .53312 L .34725 .53186 L F
.796 .679 .735 r
.34404 .52972 m .34512 .53405 L .3463 .53412 L F
.34658 .53183 m .3463 .53412 L .34957 .53431 L F
.34404 .52972 m .3463 .53412 L .34658 .53183 L F
0 0 .526 r
.34512 .53405 m .34623 .534 L .34957 .53431 L F
.747 .763 .866 r
.34187 .53606 m .34589 .53748 L .34512 .53405 L F
.34187 .53606 m .34368 .53739 L .34589 .53748 L F
0 0 .526 r
.34512 .53405 m .34589 .53748 L .34623 .534 L F
.816 .461 0 r
.34592 .53714 m .34573 .5382 L .34623 .534 L F
.34589 .53748 m .34587 .53757 L .34592 .53714 L F
.34587 .53757 m .34573 .5382 L .34592 .53714 L F
.335 0 0 r
.34589 .53748 m .34612 .53649 L .34681 .53674 L F
0 0 0 r
.34863 .53806 m .35007 .53745 L .34891 .5379 L F
.564 .362 .566 r
.35292 .53489 m .35373 .5341 L .35231 .5365 L F
.887 .587 .473 r
.34601 .55357 m .34321 .55327 L .34482 .55201 L F
.738 .294 0 r
.34601 .55357 m .34539 .55336 L .34321 .55327 L F
.21 .084 .481 r
.3456 .55633 m .34713 .55575 L .34601 .55357 L F
.738 .294 0 r
.34601 .55357 m .34713 .55575 L .34539 .55336 L F
0 0 .377 r
.21987 .58084 m .21898 .5792 L .22026 .57823 L F
.566 .932 .796 r
.33156 .67906 m .32967 .68045 L .32558 .68212 L F
0 0 .372 r
.37706 .65274 m .37688 .65186 L .37847 .65153 L F
.525 .335 .566 r
.27791 .61385 m .28053 .61023 L .27817 .61078 L F
.345 .645 .966 r
.25042 .61508 m .24982 .61674 L .24857 .61507 L F
.25042 .61508 m .2518 .61663 L .24982 .61674 L F
.263 0 0 r
.33209 .5565 m .33412 .55629 L .33503 .55503 L F
.568 .104 .11 r
.33503 .55503 m .33412 .55629 L .33648 .55582 L F
.722 .199 0 r
.33281 .55454 m .33584 .55612 L .33412 .55629 L F
.844 .478 0 r
.33636 .55639 m .33648 .55582 L .33412 .55629 L F
.722 .199 0 r
.33584 .55612 m .33636 .55639 L .33412 .55629 L F
.263 0 0 r
.33171 .55669 m .33412 .55629 L .33209 .5565 L F
0 0 0 r
.28792 .63169 m .28641 .63304 L .28909 .6295 L F
0 0 .018 r
.28529 .63523 m .28641 .63304 L .28792 .63169 L F
.485 .582 .877 r
.38377 .58546 m .38554 .58845 L .3868 .5874 L F
.005 0 .221 r
.3868 .5874 m .38554 .58845 L .38513 .59069 L F
.128 .43 .871 r
.34943 .60448 m .35158 .6055 L .35172 .60393 L F
.34943 .60448 m .35254 .6069 L .35158 .6055 L F
.501 .324 .572 r
.39237 .60443 m .39481 .60388 L .39497 .60056 L F
.537 .531 .796 r
.39237 .60443 m .39352 .60543 L .39481 .60388 L F
.715 .899 .526 r
.39701 .62371 m .3954 .62554 L .3957 .62545 L F
.869 .982 .693 r
.39714 .62182 m .39701 .62371 L .3992 .62032 L F
.869 .936 .56 r
.39714 .62182 m .3954 .62554 L .39701 .62371 L F
.726 .329 .297 r
.29825 .53484 m .29873 .53628 L .29692 .53543 L F
.30017 .53401 m .29914 .53563 L .29825 .53484 L F
.29914 .53563 m .29873 .53628 L .29825 .53484 L F
.127 .225 .696 r
.29926 .54084 m .30022 .53712 L .2987 .53567 L F
.30022 .53712 m .30006 .53652 L .2987 .53567 L F
.431 .506 .835 r
.30076 .53913 m .30022 .53712 L .30275 .53606 L F
.30022 .53712 m .30009 .53626 L .30275 .53606 L F
.516 .133 .253 r
.3 .53629 m .30028 .5362 L .30017 .53401 L F
.643 .231 .248 r
.30275 .53606 m .30028 .5362 L .30017 .53401 L F
.516 .133 .253 r
.30028 .5362 m .30036 .53617 L .30017 .53401 L F
.2987 .53567 m .3 .53629 L .30017 .53401 L F
.431 .506 .835 r
.30022 .53712 m .29998 .53621 L .30008 .53621 L F
.127 .225 .696 r
.30033 .53669 m .29975 .53618 L .2987 .53567 L F
.643 .231 .248 r
.30028 .5362 m .29873 .53628 L .30017 .53401 L F
.431 .506 .835 r
.30009 .53626 m .30008 .53621 L .30028 .5362 L F
.30009 .53626 m .30028 .5362 L .30275 .53606 L F
.516 .133 .253 r
.3 .53629 m .30039 .53648 L .30036 .53617 L F
.431 .506 .835 r
.30057 .53942 m .29998 .53621 L .30076 .53913 L F
.127 .225 .696 r
.30022 .53712 m .30057 .53942 L .30039 .53648 L F
.29926 .54084 m .30057 .53942 L .30022 .53712 L F
.431 .506 .835 r
.30057 .53942 m .29873 .53628 L .29998 .53621 L F
.127 .225 .696 r
.30022 .53712 m .30033 .53669 L .30006 .53652 L F
.30033 .53669 m .30039 .53648 L .29975 .53618 L F
.469 .759 .993 r
.29926 .54084 m .30182 .5407 L .30057 .53942 L F
.929 .803 .701 r
.35425 .58476 m .35596 .588 L .35828 .58536 L F
.266 0 .078 r
.38689 .59485 m .38282 .59791 L .38227 .59375 L F
.408 0 0 r
.38768 .59788 m .38553 .59731 L .3889 .59676 L F
.12 .478 .897 r
.38714 .59751 m .38553 .59731 L .38768 .59788 L F
.266 0 .078 r
.38689 .59485 m .38553 .59731 L .38391 .5971 L F
.563 .157 .23 r
.3889 .59676 m .38553 .59731 L .38689 .59485 L F
.12 .478 .897 r
.38356 .5951 m .38553 .59731 L .38714 .59751 L F
.266 0 .078 r
.38391 .5971 m .38553 .59731 L .38282 .59791 L F
.436 .273 .561 r
.38947 .59099 m .39013 .59458 L .38689 .59485 L F
.563 .157 .23 r
.3889 .59676 m .38689 .59485 L .39013 .59458 L F
0 .17 .706 r
.60501 .40622 m .60693 .40985 L .60732 .40843 L F
.593 .048 0 r
.60566 .40706 m .60501 .40622 L .60732 .40843 L F
.889 .598 .088 r
.60437 .40539 m .6051 .40791 L .60501 .40622 L F
0 .144 .689 r
.6051 .40791 m .60693 .40985 L .60501 .40622 L F
.593 .048 0 r
.60347 .40525 m .60501 .40622 L .60566 .40706 L F
.889 .598 .088 r
.60398 .40408 m .60437 .40539 L .60501 .40622 L F
.372 .218 .54 r
.31047 .57826 m .31297 .57799 L .31284 .57541 L F
.249 .117 .497 r
.31045 .58158 m .31297 .57799 L .31047 .57826 L F
.719 .825 .931 r
.37751 .6036 m .37949 .60497 L .38196 .60373 L F
.37751 .6036 m .37949 .60497 L .38196 .60373 L F
.099 0 0 r
.20266 .5997 m .20011 .60125 L .19856 .60312 L F
.485 .773 .995 r
.33443 .49836 m .33717 .49776 L .33637 .49943 L F
.318 .577 .934 r
.33717 .49776 m .33899 .49997 L .33637 .49943 L F
.133 .2 .667 r
.19923 .58171 m .2 .58535 L .20133 .58395 L F
.11 .164 .638 r
.2 .58535 m .20184 .58746 L .20133 .58395 L F
.453 0 0 r
.25467 .62851 m .25077 .62815 L .25244 .62887 L F
.6 .836 .989 r
.29984 .51773 m .29764 .51864 L .29588 .51752 L F
.076 .622 .839 r
.23729 .61086 m .23886 .61096 L .24121 .61144 L F
.369 0 0 r
.24005 .61116 m .24121 .61144 L .23886 .61096 L F
0 .268 .642 r
.24426 .61296 m .24393 .61278 L .24591 .61377 L F
.24121 .61144 m .24393 .61278 L .24426 .61296 L F
.623 .058 0 r
.2435 .6126 m .24218 .61255 L .24393 .61278 L F
.24005 .61116 m .24218 .61255 L .2435 .6126 L F
.738 .218 0 r
.23909 .61096 m .23989 .61248 L .24218 .61255 L F
.474 0 0 r
.23989 .61248 m .24007 .61248 L .24218 .61255 L F
.369 0 0 r
.24005 .61116 m .24393 .61278 L .24121 .61144 L F
.474 0 0 r
.24007 .61248 m .24437 .61252 L .24218 .61255 L F
0 .414 .79 r
.24347 .61253 m .24393 .61278 L .24218 .61255 L F
.24437 .61252 m .24393 .61278 L .24347 .61253 L F
0 0 0 r
.29312 .52621 m .29292 .52608 L .29512 .5248 L F
.29312 .52621 m .29089 .52703 L .29292 .52608 L F
.2 .193 .625 r
.30385 .54688 m .30519 .54649 L .30323 .54418 L F
.30323 .54418 m .30629 .546 L .30612 .54499 L F
.30323 .54418 m .30519 .54649 L .30385 .54688 L F
.784 .708 .781 r
.2975 .52148 m .29512 .5248 L .29908 .52516 L F
.613 .468 .66 r
.29763 .52837 m .29512 .5248 L .29598 .52572 L F
.29763 .52837 m .29908 .52516 L .29512 .5248 L F
.646 .613 .802 r
.29908 .52516 m .30031 .521 L .2975 .52148 L F
.29908 .52516 m .30187 .52489 L .30031 .521 L F
0 0 .511 r
.29908 .52516 m .29999 .52667 L .30187 .52489 L F
.508 0 0 r
.32605 .63182 m .3252 .63015 L .3237 .63199 L F
.32605 .63182 m .32768 .63074 L .3252 .63015 L F
.198 0 .292 r
.31636 .59412 m .31698 .59177 L .3188 .59096 L F
.167 0 .364 r
.34047 .56599 m .34268 .56518 L .34316 .56231 L F
.535 .32 .535 r
.33964 .56813 m .34268 .56518 L .34047 .56599 L F
.619 .559 .765 r
.33764 .55052 m .34045 .5505 L .33713 .54793 L F
.508 .463 .742 r
.33764 .55052 m .34073 .55257 L .34045 .5505 L F
.771 .936 .937 r
.27405 .6074 m .27583 .60472 L .27621 .60679 L F
.27405 .6074 m .27229 .60679 L .27583 .60472 L F
.319 .786 .934 r
.27621 .60679 m .27229 .60679 L .27405 .6074 L F
.451 .85 .974 r
.23406 .54956 m .23004 .54969 L .23194 .55017 L F
.472 .887 .923 r
.36984 .71325 m .3733 .71299 L .3716 .71627 L F
.212 .729 .872 r
.34285 .71253 m .34341 .71207 L .34114 .71225 L F
.34285 .71253 m .3457 .71226 L .34341 .71207 L F
.45 0 0 r
.62255 .43862 m .62648 .44072 L .62392 .44008 L F
.441 .267 .548 r
.34956 .57467 m .34793 .57704 L .3517 .5749 L F
.3517 .5749 m .34793 .57704 L .34956 .57467 L F
.507 .816 1 r
.61845 .4165 m .62208 .41693 L .62102 .41608 L F
0 0 .009 r
.62208 .41693 m .62486 .41413 L .62469 .41576 L F
.62208 .41693 m .62469 .41576 L .62102 .41608 L F
.521 .556 .832 r
.22775 .5631 m .22418 .56022 L .22657 .55958 L F
.828 .638 .646 r
.71265 .36042 m .71247 .36305 L .70885 .36219 L F
.753 .392 .371 r
.71265 .36042 m .71598 .36296 L .71247 .36305 L F
.461 .498 .81 r
.56793 .42733 m .5666 .42298 L .56775 .4243 L F
.656 .824 .964 r
.5666 .42298 m .57051 .4233 L .56775 .4243 L F
0 .326 .741 r
.24686 .61389 m .24591 .61377 L .24393 .61278 L F
.24686 .61389 m .24857 .61507 L .24591 .61377 L F
.693 .875 .967 r
.27642 .62756 m .27657 .62955 L .27855 .62734 L F
.666 .972 .899 r
.27642 .62756 m .27855 .62734 L .2806 .62585 L F
.606 .806 .977 r
.38098 .65074 m .37706 .65274 L .37847 .65153 L F
.38098 .65074 m .38276 .65216 L .37706 .65274 L F
.384 .545 .892 r
.29 .62794 m .28909 .6295 L .28671 .62611 L F
0 0 0 r
.28792 .63169 m .28909 .6295 L .29 .62794 L F
.409 .811 .596 r
.22318 .54354 m .22458 .54257 L .22666 .54118 L F
.517 .874 .64 r
.22666 .54118 m .22609 .5413 L .22854 .53972 L F
.22666 .54118 m .22458 .54257 L .22609 .5413 L F
.697 .826 .944 r
.36177 .664 m .35954 .66525 L .35784 .66358 L F
.995 .865 .578 r
.29402 .53706 m .29318 .5401 L .29472 .54 L F
.253 0 0 r
.29441 .54231 m .29472 .54 L .29318 .5401 L F
.924 .716 .603 r
.34214 .64921 m .3433 .65266 L .34132 .65134 L F
0 0 0 r
.3433 .65266 m .33981 .6549 L .34132 .65134 L F
.515 .715 .963 r
.34436 .65069 m .34616 .65237 L .3433 .65266 L F
.569 .56 .804 r
.35838 .60654 m .35726 .61049 L .35561 .6071 L F
.747 .733 .839 r
.36998 .68663 m .374 .68683 L .37279 .68359 L F
.663 .225 .2 r
.37178 .68903 m .374 .68683 L .36998 .68663 L F
.685 .351 .404 r
.37178 .68903 m .37646 .68638 L .374 .68683 L F
.689 .837 .954 r
.24843 .53766 m .25239 .53743 L .25096 .5372 L F
.851 .958 .878 r
.25376 .53416 m .25239 .53743 L .25503 .53726 L F
.25376 .53416 m .25096 .5372 L .25239 .53743 L F
.05 .306 .793 r
.33273 .70885 m .33351 .70776 L .33111 .70824 L F
.689 .353 .4 r
.33273 .70885 m .33565 .70971 L .33512 .71093 L F
.05 .306 .793 r
.33273 .70885 m .33512 .71093 L .33351 .70776 L F
.865 .813 .796 r
.69817 .32028 m .70009 .32195 L .69922 .31816 L F
.894 .769 .717 r
.69634 .32362 m .70009 .32195 L .69817 .32028 L F
.69634 .32362 m .69801 .32498 L .70009 .32195 L F
.61 .171 .181 r
.34482 .55201 m .34321 .55327 L .34073 .55257 L F
.467 .611 .91 r
.2538 .61657 m .25384 .61984 L .2518 .61663 L F
.2538 .61657 m .25591 .61956 L .25384 .61984 L F
.541 .415 .658 r
.3904 .57164 m .39124 .57028 L .39209 .57094 L F
.674 .373 .457 r
.38839 .56802 m .39192 .57081 L .39092 .56674 L F
.39192 .57081 m .39205 .5708 L .39092 .56674 L F
.38838 .56803 m .39124 .57028 L .38839 .56802 L F
.39124 .57028 m .39209 .57094 L .38839 .56802 L F
.605 .569 .787 r
.39209 .57094 m .3904 .57164 L .39209 .57094 L F
.541 .415 .658 r
.3904 .57164 m .39234 .57114 L .39209 .57094 L F
.3904 .57164 m .39209 .57094 L .39124 .57028 L F
.605 .569 .787 r
.38611 .56917 m .3904 .57164 L .39209 .57094 L F
.674 .373 .457 r
.38611 .56917 m .39209 .57094 L .38838 .56803 L F
.164 .076 .502 r
.39092 .56674 m .39209 .57094 L .39251 .56824 L F
.39092 .56674 m .39209 .57094 L .39251 .56824 L F
.586 .651 .881 r
.39201 .56861 m .39082 .57084 L .38892 .56998 L F
.39082 .57084 m .3904 .57164 L .38972 .57088 L F
.39082 .57084 m .38972 .57088 L .38892 .56998 L F
.674 .373 .457 r
.39192 .57081 m .39209 .57094 L .39205 .5708 L F
.541 .415 .658 r
.39124 .57028 m .39251 .56824 L .39209 .57094 L F
.39124 .57028 m .3929 .571 L .39251 .56824 L F
.39234 .57114 m .3929 .571 L .39124 .57028 L F
.164 .076 .502 r
.39092 .56674 m .39251 .56824 L .39249 .56563 L F
.683 .684 .845 r
.54818 .41597 m .54701 .42051 L .54821 .41864 L F
.617 .911 .982 r
.54701 .42051 m .55003 .41944 L .54821 .41864 L F
.525 .798 .996 r
.54563 .41924 m .54701 .42051 L .54821 .41864 L F
.989 .746 .473 r
.2904 .65195 m .28876 .6535 L .28894 .65077 L F
.2904 .65195 m .29023 .65464 L .28876 .6535 L F
.545 0 0 r
.2904 .65195 m .29243 .65314 L .29023 .65464 L F
.717 .374 .397 r
.5694 .44923 m .56553 .451 L .56718 .44863 L F
.5694 .44923 m .56948 .45129 L .56553 .451 L F
.638 .311 .402 r
.57193 .4509 m .56948 .45129 L .5694 .44923 L F
.935 .75 .629 r
.41306 .50292 m .41107 .50215 L .41142 .49915 L F
.631 .654 .854 r
.41397 .49863 m .41306 .50292 L .41142 .49915 L F
.41397 .49863 m .41573 .50295 L .41306 .50292 L F
.527 .391 .638 r
.41595 .5052 m .41306 .50292 L .41573 .50295 L F
.41595 .5052 m .41348 .50621 L .41306 .50292 L F
.026 0 .244 r
.30844 .58516 m .31027 .58414 L .31045 .58158 L F
.265 .064 .409 r
.30807 .58747 m .31027 .58414 L .30844 .58516 L F
.685 .592 .745 r
.32637 .53098 m .32398 .53372 L .32382 .53178 L F
.232 .446 .863 r
.32567 .53418 m .32398 .53372 L .32637 .53098 L F
0 0 0 r
.43172 .57582 m .43088 .57743 L .43015 .57873 L F
.746 .713 .821 r
.4351 .57278 m .43172 .57582 L .43051 .57346 L F
.625 .14 .081 r
.43483 .57774 m .43088 .57743 L .43172 .57582 L F
.67 .573 .737 r
.43457 .57521 m .43172 .57582 L .4351 .57278 L F
.571 .275 .427 r
.43457 .57521 m .43483 .57774 L .43172 .57582 L F
.9 .986 .753 r
.70481 .31493 m .70583 .31322 L .70418 .31387 L F
.9 .912 .821 r
.70122 .31631 m .70481 .31493 L .70418 .31387 L F
.632 .879 .987 r
.3457 .71226 m .34951 .71228 L .34798 .71123 L F
.721 .229 .073 r
.34951 .71228 m .3484 .71393 L .34798 .71123 L F
.34951 .71228 m .35185 .71451 L .3484 .71393 L F
0 0 .108 r
.36771 .57993 m .36877 .57832 L .368 .57749 L F
.608 .043 0 r
.36679 .57619 m .368 .57749 L .37036 .57844 L F
.372 .369 .727 r
.3722 .57422 m .37036 .57844 L .368 .57749 L F
0 0 .108 r
.36877 .57832 m .36977 .57682 L .368 .57749 L F
.608 .043 0 r
.36593 .57564 m .368 .57749 L .36679 .57619 L F
.372 .369 .727 r
.3722 .57422 m .37213 .57804 L .37036 .57844 L F
.309 .142 .485 r
.37213 .57804 m .37036 .58157 L .37036 .57844 L F
.807 .546 .544 r
.38655 .61262 m .3908 .61315 L .38839 .61013 L F
0 0 .375 r
.32239 .57534 m .32226 .57824 L .32131 .57879 L F
0 0 .503 r
.32226 .57824 m .32257 .58097 L .32131 .57879 L F
0 .147 .691 r
.21587 .60297 m .21486 .59976 L .21335 .59965 L F
.084 0 0 r
.21473 .59977 m .21335 .59965 L .21486 .59976 L F
.047 .491 .887 r
.21202 .59954 m .21341 .60073 L .21335 .59965 L F
0 .147 .681 r
.21341 .60073 m .21587 .60297 L .21335 .59965 L F
.084 0 0 r
.20925 .59997 m .21335 .59965 L .21473 .59977 L F
.20916 .59995 m .21335 .59965 L .20925 .59997 L F
.382 .819 .956 r
.20466 .59898 m .20493 .59896 L .20692 .59857 L F
.20493 .59896 m .20836 .59868 L .20692 .59857 L F
.304 0 0 r
.20836 .59868 m .2094 .5993 L .20692 .59857 L F
.293 .62 .959 r
.20692 .59857 m .2094 .5993 L .20852 .59826 L F
.20692 .59857 m .20852 .59826 L .20793 .59757 L F
.304 0 0 r
.20836 .59868 m .21 .59893 L .2094 .5993 L F
.21 .59893 m .21158 .59917 L .2094 .5993 L F
.905 .525 .086 r
.20852 .59984 m .2094 .5993 L .20856 .6 L F
.20793 .59757 m .2094 .5993 L .20852 .59984 L F
.358 0 0 r
.2094 .5993 m .21335 .59965 L .20856 .6 L F
.047 .491 .887 r
.21158 .59917 m .21202 .59954 L .21335 .59965 L F
.329 0 0 r
.2094 .5993 m .21158 .59917 L .21335 .59965 L F
.084 0 0 r
.20924 .59982 m .21486 .59976 L .21338 .59877 L F
.20856 .6 m .20916 .59995 L .20925 .59997 L F
.20856 .6 m .20925 .59997 L .20924 .59982 L F
.20925 .59997 m .21486 .59976 L .20924 .59982 L F
0 0 .564 r
.20793 .59757 m .20923 .59958 L .2083 .59617 L F
.429 0 .025 r
.21338 .59877 m .20957 .60012 L .20856 .6 L F
0 0 .564 r
.20923 .59958 m .20951 .60002 L .2092 .59904 L F
.20923 .59958 m .2092 .59904 L .2083 .59617 L F
.20951 .60002 m .20957 .60012 L .20954 .60003 L F
.20951 .60002 m .20954 .60003 L .2083 .59617 L F
0 0 .561 r
.30087 .62174 m .29944 .62064 L .30176 .61944 L F
.30087 .62174 m .30068 .6231 L .29944 .62064 L F
.755 .598 .682 r
.30612 .54499 m .30629 .546 L .30977 .54431 L F
.101 .324 .798 r
.30772 .54038 m .30977 .54431 L .31037 .54239 L F
.794 .983 .717 r
.30977 .54431 m .30795 .54558 L .31037 .54239 L F
.445 0 0 r
.3115 .5454 m .30795 .54558 L .30977 .54431 L F
.64 .096 0 r
.70222 .35685 m .7049 .35874 L .70093 .35909 L F
.70222 .35685 m .70444 .3578 L .7049 .35874 L F
.411 .85 .741 r
.30847 .66396 m .31259 .66212 L .31125 .6612 L F
.664 .742 .908 r
.31259 .66212 m .31509 .66122 L .31125 .6612 L F
.645 .533 .713 r
.64541 .38586 m .6427 .38918 L .64137 .3852 L F
.64541 .38586 m .64535 .38822 L .6427 .38918 L F
.558 .261 .419 r
.24608 .56954 m .24515 .57248 L .24243 .57242 L F
.367 .054 .296 r
.24863 .56894 m .24515 .57248 L .24608 .56954 L F
0 .441 .727 r
.27038 .53081 m .26881 .5303 L .2663 .52965 L F
.543 .324 .533 r
.26871 .53282 m .27061 .53077 L .26881 .5303 L F
.41 .828 .969 r
.27143 .52989 m .26881 .5303 L .27038 .53081 L F
.543 .324 .533 r
.27061 .53077 m .27143 .52989 L .26881 .5303 L F
0 .441 .727 r
.2663 .52965 m .26881 .5303 L .26562 .52945 L F
.41 .828 .969 r
.27143 .52989 m .27038 .53081 L .2727 .52972 L F
.885 .98 .692 r
.39714 .62182 m .3992 .62032 L .39926 .61839 L F
.522 .811 .998 r
.22518 .55572 m .22911 .55631 L .22697 .55682 L F
.49 .289 .534 r
.22911 .55631 m .22657 .55958 L .22697 .55682 L F
.982 .902 .651 r
.39963 .59465 m .39681 .59726 L .39857 .59378 L F
.39963 .59465 m .39842 .59814 L .39681 .59726 L F
.357 .152 .458 r
.33293 .655 m .3307 .6551 L .33337 .65131 L F
.33293 .655 m .3307 .6551 L .33337 .65131 L F
.144 0 .251 r
.24538 .55067 m .24465 .55296 L .2471 .54969 L F
.765 .518 .56 r
.34589 .65663 m .34837 .65872 L .34778 .66175 L F
.34589 .65663 m .34837 .65872 L .34778 .66175 L F
.075 0 0 r
.33438 .60315 m .33569 .60181 L .33813 .60096 L F
.693 .875 .967 r
.27642 .62756 m .27412 .6289 L .27657 .62955 L F
.829 .355 .011 r
.27622 .63116 m .27657 .62955 L .27412 .6289 L F
.27622 .63116 m .2782 .63237 L .27657 .62955 L F
.953 .822 .676 r
.24645 .58638 m .24671 .58867 L .24483 .58738 L F
.491 .393 .672 r
.24869 .58531 m .24671 .58867 L .24645 .58638 L F
.24869 .58531 m .24924 .58823 L .24671 .58867 L F
.447 .774 .997 r
.24671 .58867 m .24924 .58823 L .24483 .58738 L F
.512 .543 .825 r
.43017 .51087 m .42793 .51307 L .42769 .51137 L F
.448 .443 .76 r
.43017 .51087 m .4291 .51548 L .42793 .51307 L F
.784 .58 .624 r
.38295 .57602 m .38656 .57879 L .38634 .57565 L F
.38295 .57602 m .38286 .57869 L .38656 .57879 L F
.499 .551 .841 r
.38286 .57869 m .3866 .58124 L .38656 .57879 L F
.443 .442 .762 r
.38656 .57879 m .38778 .5748 L .38634 .57565 L F
.38656 .57879 m .38852 .57869 L .38778 .5748 L F
.674 .524 .673 r
.3866 .58124 m .38852 .57869 L .38656 .57879 L F
.721 .455 0 r
.33719 .54511 m .33865 .54403 L .339 .54312 L F
.709 .271 .209 r
.3664 .51518 m .36434 .51683 L .36528 .51499 L F
.947 .84 .705 r
.32954 .5254 m .32849 .52783 L .32719 .52584 L F
.356 .358 .724 r
.40998 .50823 m .4086 .51173 L .40863 .50934 L F
.427 .204 .47 r
.7127 .30784 m .71046 .30871 L .71256 .30586 L F
.7127 .30784 m .71256 .30586 L .71033 .3037 L F
.99 .831 .591 r
.71256 .30586 m .71142 .30542 L .71033 .3037 L F
.427 .204 .47 r
.7127 .30784 m .71154 .30581 L .71275 .30753 L F
.71154 .30581 m .71033 .3037 L .71142 .30542 L F
.71154 .30581 m .71142 .30542 L .71275 .30753 L F
.99 .831 .591 r
.71256 .30586 m .71324 .30324 L .71137 .30527 L F
.71142 .30542 m .71129 .30537 L .71033 .3037 L F
.71142 .30542 m .71137 .30527 L .71129 .30537 L F
.71256 .30586 m .71137 .30527 L .71142 .30542 L F
.349 .804 .941 r
.70828 .30644 m .71025 .3064 L .71033 .3037 L F
.842 .956 .614 r
.7114 .30517 m .71324 .30324 L .71362 .30214 L F
.7114 .30517 m .71362 .30214 L .71188 .30434 L F
.474 .472 .775 r
.71033 .3037 m .71121 .30477 L .71064 .30032 L F
.787 .7 .769 r
.71064 .30032 m .71121 .30477 L .7143 .30014 L F
.427 .204 .47 r
.71136 .30533 m .71033 .3037 L .71143 .30505 L F
.787 .7 .769 r
.71121 .30477 m .71129 .30537 L .7114 .30517 L F
.71121 .30477 m .7114 .30517 L .7143 .30014 L F
.427 .204 .47 r
.71143 .30505 m .71121 .30477 L .71148 .30485 L F
.71121 .30477 m .71033 .3037 L .71103 .3044 L F
.71121 .30477 m .71103 .3044 L .71148 .30485 L F
.474 .472 .775 r
.71033 .3037 m .71129 .30537 L .71121 .30477 L F
.842 .956 .614 r
.71129 .30537 m .71137 .30527 L .7114 .30517 L F
.71137 .30527 m .71324 .30324 L .7114 .30517 L F
.427 .204 .47 r
.71275 .30753 m .71136 .30533 L .71296 .30635 L F
.71136 .30533 m .71148 .30485 L .71296 .30635 L F
.349 .804 .941 r
.71025 .3064 m .71296 .30635 L .71148 .30485 L F
.71025 .3064 m .71148 .30485 L .71033 .3037 L F
.842 .956 .614 r
.71188 .30434 m .71362 .30214 L .7143 .30014 L F
.849 .967 .642 r
.7143 .30014 m .71324 .30324 L .71534 .29979 L F
.936 .85 .733 r
.56162 .4242 m .5623 .41934 L .55999 .42294 L F
.879 .939 .852 r
.56213 .42267 m .56121 .42651 L .55999 .42294 L F
.56213 .42267 m .56405 .42318 L .56121 .42651 L F
.634 .5 .682 r
.3216 .56934 m .31916 .57263 L .31896 .56983 L F
.637 .777 .948 r
.38918 .58862 m .39227 .58852 L .3868 .5874 L F
.782 .638 .703 r
.25296 .55949 m .24987 .56238 L .25042 .56015 L F
.817 .897 .899 r
.42671 .57166 m .42825 .57277 L .43113 .57046 L F
.023 .515 .875 r
.42868 .57219 m .42825 .57277 L .42671 .57166 L F
.42868 .57219 m .43051 .57346 L .42825 .57277 L F
0 0 0 r
.22318 .54354 m .22195 .54572 L .22458 .54257 L F
.461 .224 .467 r
.29635 .60457 m .29886 .60412 L .29939 .60119 L F
.387 .159 .442 r
.29939 .60119 m .30102 .60324 L .30128 .60046 L F
.29939 .60119 m .29886 .60412 L .30102 .60324 L F
0 0 0 r
.37911 .71182 m .38208 .70899 L .38198 .71172 L F
.506 .303 .538 r
.38461 .70854 m .38198 .71172 L .38208 .70899 L F
0 0 .003 r
.33918 .53907 m .3391 .54163 L .339 .54312 L F
.33919 .53881 m .33918 .53899 L .33918 .53907 L F
.33918 .53899 m .3391 .54163 L .33918 .53907 L F
.814 .997 .772 r
.34197 .53767 m .33911 .53998 L .33917 .54043 L F
.33911 .53998 m .33902 .54005 L .33909 .54023 L F
.33911 .53998 m .33909 .54023 L .33917 .54043 L F
.004 0 .398 r
.31445 .64246 m .31587 .64375 L .31729 .64134 L F
.31445 .64246 m .3143 .64526 L .31587 .64375 L F
.225 0 .284 r
.22337 .5729 m .22284 .57507 L .22107 .57568 L F
.228 0 .29 r
.22284 .57507 m .22026 .57823 L .22107 .57568 L F
.773 .363 .275 r
.71159 .28266 m .71365 .28329 L .71137 .28096 L F
.71159 .28266 m .71365 .28329 L .71137 .28096 L F
0 0 .217 r
.39497 .60056 m .39481 .60388 L .39531 .60021 L F
.614 .093 0 r
.36475 .64451 m .36412 .64352 L .36181 .64298 L F
.618 .264 .348 r
.56718 .44863 m .56553 .451 L .56298 .4491 L F
.749 .925 .568 r
.63612 .43137 m .63682 .43106 L .63518 .43337 L F
0 .37 .809 r
.63518 .43337 m .63694 .43366 L .63612 .43137 L F
.883 .493 .036 r
.63612 .43137 m .63594 .43288 L .6355 .43165 L F
.63612 .43137 m .6355 .43165 L .63493 .43004 L F
.749 .925 .568 r
.63612 .43137 m .63788 .42955 L .63682 .43106 L F
.655 .967 .906 r
.6411 .42748 m .63788 .42955 L .63746 .42894 L F
.905 .945 .59 r
.63746 .42894 m .63788 .42955 L .63612 .43137 L F
0 0 .246 r
.70147 .32857 m .70113 .32918 L .69769 .32757 L F
.70147 .32857 m .7014 .3294 L .70113 .32918 L F
.182 .155 .591 r
.31396 .56309 m .31584 .56503 L .31519 .56135 L F
.352 .067 .333 r
.22502 .57441 m .22337 .5729 L .22603 .5725 L F
.22502 .57441 m .22284 .57507 L .22337 .5729 L F
0 0 0 r
.32273 .66991 m .32722 .66836 L .32536 .66741 L F
.767 .914 .938 r
.32536 .66741 m .32722 .66836 L .32949 .66695 L F
.335 .225 .578 r
.39481 .60388 m .39352 .60543 L .39636 .60637 L F
.496 .392 .666 r
.25753 .55005 m .25566 .55359 L .25507 .55071 L F
.045 .464 .881 r
.24807 .62723 m .2483 .62612 L .24672 .62554 L F
.24807 .62723 m .25077 .62815 L .2483 .62612 L F
.754 .714 .815 r
.61434 .38229 m .61538 .3856 L .61166 .38478 L F
.841 .969 .882 r
.61503 .38772 m .61331 .38968 L .6129 .3895 L F
.6134 .38828 m .6129 .3895 L .61155 .38892 L F
.61503 .38772 m .6129 .3895 L .6134 .38828 L F
.61503 .38772 m .61155 .38892 L .61397 .38684 L F
0 0 .302 r
.6144 .38813 m .61398 .38686 L .61402 .38926 L F
.61398 .38686 m .61397 .38684 L .61397 .38687 L F
.61398 .38686 m .61397 .38687 L .61402 .38926 L F
.999 .827 .5 r
.61538 .3856 m .61397 .38684 L .61341 .38517 L F
.61538 .3856 m .61503 .38772 L .61397 .38684 L F
.861 .809 .797 r
.61577 .38062 m .61538 .3856 L .61434 .38229 L F
0 0 .302 r
.61537 .38522 m .61397 .38684 L .6144 .38813 L F
.999 .827 .5 r
.61341 .38517 m .61397 .38684 L .61166 .38478 L F
.73 .572 .676 r
.6716 .34613 m .67562 .34703 L .6733 .35033 L F
.727 .567 .674 r
.67562 .34703 m .67787 .35094 L .6733 .35033 L F
.825 .679 .702 r
.65402 .42248 m .65195 .41908 L .65519 .42195 L F
0 0 .078 r
.65423 .42408 m .65402 .42248 L .65519 .42195 L F
.65423 .42408 m .65375 .42646 L .65402 .42248 L F
.464 .264 .523 r
.29144 .61128 m .29387 .61048 L .294 .60748 L F
.374 .146 .435 r
.294 .60748 m .2961 .60688 L .29635 .60457 L F
.289 .125 .477 r
.294 .60748 m .29549 .60931 L .2961 .60688 L F
.294 .60748 m .29387 .61048 L .29549 .60931 L F
.771 .647 .725 r
.28392 .62308 m .28473 .62668 L .2806 .62585 L F
.487 .493 .789 r
.28566 .62238 m .28473 .62668 L .28392 .62308 L F
.28566 .62238 m .28671 .62611 L .28473 .62668 L F
.829 .592 .041 r
.41792 .57884 m .41745 .57762 L .4171 .57465 L F
.67 .345 0 r
.41792 .57884 m .41882 .58126 L .41745 .57762 L F
.448 .443 .76 r
.43017 .51087 m .43113 .51486 L .4291 .51548 L F
.614 .551 .76 r
.43113 .51486 m .42884 .51836 L .4291 .51548 L F
.724 .698 .825 r
.42167 .54284 m .41887 .54415 L .41687 .54067 L F
.356 .162 .475 r
.34593 .54678 m .34834 .54622 L .35001 .54729 L F
.504 .837 .998 r
.35001 .54729 m .34834 .54622 L .35241 .54665 L F
.57 .548 .79 r
.33673 .51798 m .33744 .52174 L .33505 .52247 L F
0 0 0 r
.33744 .52174 m .33499 .52403 L .33505 .52247 L F
.777 .683 .76 r
.20697 .60401 m .20794 .60751 L .20381 .60725 L F
.341 .784 .96 r
.20381 .60725 m .20794 .60751 L .20617 .60693 L F
0 .011 .578 r
.20848 .60612 m .20792 .60741 L .20697 .60401 L F
.578 .133 0 r
.20616 .60292 m .20848 .60612 L .20697 .60401 L F
.257 .481 .883 r
.20966 .60462 m .20848 .60612 L .20616 .60292 L F
.419 .157 .408 r
.20966 .60462 m .20901 .60493 L .20848 .60612 L F
.583 .848 .995 r
.20403 .60595 m .20617 .60693 L .20848 .60612 L F
.20795 .6061 m .20848 .60612 L .20646 .60617 L F
.419 .157 .408 r
.20901 .60493 m .20646 .60617 L .20848 .60612 L F
0 .011 .578 r
.20848 .60612 m .20794 .60751 L .20792 .60741 L F
.541 .882 .987 r
.20617 .60693 m .20794 .60751 L .20848 .60612 L F
.419 .157 .408 r
.20966 .60462 m .2089 .60648 L .20646 .60617 L F
.2089 .60648 m .20864 .60713 L .20646 .60617 L F
.583 .848 .995 r
.20403 .60595 m .20493 .60598 L .20646 .60617 L F
.20493 .60598 m .20795 .6061 L .20646 .60617 L F
.799 .327 .103 r
.20646 .60617 m .2045 .60665 L .2043 .60628 L F
0 .127 .624 r
.20602 .60282 m .20697 .60401 L .2046 .6018 L F
.20616 .60292 m .20616 .60293 L .20602 .60282 L F
.477 .297 .557 r
.20195 .60603 m .20453 .60385 L .20195 .60501 L F
.20453 .60385 m .20578 .6028 L .20426 .60367 L F
.20453 .60385 m .20426 .60367 L .20195 .60501 L F
.202 .60598 m .20403 .60595 L .20578 .6028 L F
.20195 .60603 m .20403 .60595 L .202 .60598 L F
.799 .327 .103 r
.20646 .60617 m .20599 .60591 L .20403 .60595 L F
0 .127 .624 r
.20616 .60292 m .2046 .6018 L .20578 .6028 L F
.221 0 0 r
.20326 .60439 m .20578 .6028 L .20403 .60595 L F
.20326 .60439 m .20616 .60292 L .20578 .6028 L F
.568 .907 .679 r
.20616 .60292 m .20405 .60433 L .20611 .60257 L F
.799 .327 .103 r
.20599 .60591 m .20374 .60466 L .20403 .60595 L F
.20374 .60466 m .20326 .60439 L .20351 .6049 L F
.20374 .60466 m .20351 .6049 L .20403 .60595 L F
.20646 .60617 m .2043 .60628 L .20326 .60439 L F
.414 .781 .994 r
.20381 .60725 m .20617 .60693 L .20403 .60595 L F
0 .01 .537 r
.20378 .60462 m .2045 .60665 L .20431 .60485 L F
.20326 .60439 m .20367 .60515 L .20378 .60462 L F
.20367 .60515 m .2045 .60665 L .20378 .60462 L F
.221 0 0 r
.20326 .60439 m .20368 .60458 L .20616 .60292 L F
.451 .195 .434 r
.20195 .60501 m .20578 .6028 L .20497 .60199 L F
0 .022 .559 r
.2046 .6018 m .20266 .5997 L .20578 .6028 L F
.809 .884 .9 r
.20743 .6015 m .20383 .60442 L .20412 .60301 L F
0 .01 .537 r
.20326 .60439 m .20368 .60458 L .20412 .60301 L F
.568 .907 .679 r
.20405 .60433 m .20368 .60458 L .20443 .60393 L F
.20368 .60458 m .20383 .60442 L .20443 .60393 L F
0 .01 .537 r
.20368 .60458 m .20431 .60485 L .20422 .60398 L F
.20368 .60458 m .20422 .60398 L .20412 .60301 L F
.221 0 0 r
.20326 .60439 m .20337 .60478 L .20368 .60458 L F
.568 .907 .679 r
.20368 .60458 m .20337 .60478 L .20383 .60442 L F
.809 .884 .9 r
.20383 .60442 m .20337 .60478 L .20412 .60301 L F
.568 .907 .679 r
.20405 .60433 m .20443 .60393 L .20611 .60257 L F
.20616 .60292 m .20611 .60257 L .20743 .6015 L F
0 .127 .624 r
.20616 .60292 m .20617 .60294 L .20616 .60293 L F
.20617 .60294 m .20697 .60401 L .20602 .60282 L F
.451 .195 .434 r
.2026 .60013 m .20497 .60199 L .20266 .5997 L F
.20195 .60501 m .20497 .60199 L .2026 .60013 L F
.277 .412 .819 r
.39067 .58164 m .39217 .58042 L .38949 .58177 L F
.39067 .58164 m .39235 .58193 L .39217 .58042 L F
.894 .639 .546 r
.38988 .58429 m .39067 .58164 L .38949 .58177 L F
.38988 .58429 m .39235 .58193 L .39067 .58164 L F
.39 .848 .799 r
.34403 .5708 m .34213 .57194 L .34573 .5717 L F
.34403 .5708 m .34158 .57197 L .34213 .57194 L F
.793 .661 .717 r
.65316 .41052 m .65445 .41403 L .65148 .41406 L F
.526 .516 .788 r
.6566 .41308 m .65445 .41403 L .65316 .41052 L F
.485 .296 .549 r
.6566 .41308 m .6543 .41632 L .65445 .41403 L F
.491 .304 .553 r
.35106 .52188 m .3534 .52388 L .35349 .52128 L F
.35106 .52188 m .351 .52457 L .3534 .52388 L F
.873 .434 .128 r
.41971 .58551 m .42213 .58818 L .42029 .58777 L F
.761 .322 .211 r
.42213 .58818 m .42096 .59004 L .42029 .58777 L F
.42213 .58818 m .42443 .59074 L .42096 .59004 L F
.695 .352 .391 r
.42468 .58879 m .42443 .59074 L .42213 .58818 L F
.419 .141 .382 r
.24165 .55594 m .24465 .55296 L .24247 .55372 L F
0 0 .536 r
.33745 .50853 m .33633 .50446 L .3376 .50604 L F
.496 .392 .666 r
.25753 .55005 m .25779 .5531 L .25566 .55359 L F
.395 .221 .524 r
.25776 .55518 m .25566 .55359 L .25779 .5531 L F
.25776 .55518 m .25565 .55622 L .25566 .55359 L F
.809 .485 0 r
.28578 .64537 m .28627 .64794 L .28566 .64386 L F
.71 .538 .655 r
.39227 .58852 m .38947 .59099 L .3868 .5874 L F
.39227 .58852 m .39183 .59143 L .38947 .59099 L F
.218 .296 .731 r
.40205 .66784 m .4041 .66971 L .40253 .67186 L F
0 .024 .555 r
.4041 .66971 m .40373 .67371 L .40253 .67186 L F
.389 .833 .94 r
.28057 .5208 m .27836 .52138 L .27656 .52102 L F
.136 .469 .893 r
.22975 .61345 m .2296 .61156 L .22751 .61147 L F
.22975 .61345 m .23076 .61323 L .2296 .61156 L F
.288 .466 .862 r
.39889 .65526 m .40184 .65689 L .40059 .65849 L F
.152 .265 .728 r
.40184 .65689 m .40275 .66038 L .40059 .65849 L F
.138 .263 .731 r
.40275 .66038 m .40171 .6608 L .40059 .65849 L F
.864 .45 0 r
.32775 .63192 m .32931 .63322 L .32768 .63074 L F
.971 .902 .693 r
.32699 .63427 m .32931 .63322 L .32775 .63192 L F
.051 0 0 r
.36078 .64571 m .35811 .64562 L .35939 .64924 L F
.36078 .64571 m .35939 .64924 L .35759 .64791 L F
.239 .384 .808 r
.30368 .63707 m .30232 .63848 L .30094 .6354 L F
.277 .164 .539 r
.30226 .64113 m .30071 .63909 L .30232 .63848 L F
.142 .129 .582 r
.30226 .64113 m .30137 .64239 L .30071 .63909 L F
0 0 0 r
.30024 .64451 m .30137 .64239 L .30226 .64113 L F
.899 .86 .794 r
.29824 .6429 m .30024 .64451 L .30226 .64113 L F
.29824 .6429 m .30226 .64113 L .30061 .64265 L F
0 0 .2 r
.30244 .63655 m .30107 .64227 L .30261 .63737 L F
.404 0 0 r
.3017 .63596 m .30298 .63667 L .30125 .6356 L F
.30298 .63667 m .30368 .63707 L .30094 .6354 L F
.117 .556 .919 r
.30291 .63597 m .30368 .63707 L .3017 .63596 L F
.404 0 0 r
.30006 .63504 m .3017 .63596 L .30094 .6354 L F
.528 0 0 r
.30094 .6354 m .29859 .63394 L .29699 .63454 L F
.30094 .6354 m .29861 .63393 L .29859 .63394 L F
.30094 .6354 m .29699 .63454 L .30017 .63389 L F
.404 0 0 r
.30005 .63503 m .30009 .63506 L .30006 .63504 L F
.30009 .63506 m .3017 .63596 L .30006 .63504 L F
.665 .612 .786 r
.29838 .63784 m .30122 .63574 L .29874 .63653 L F
.404 0 0 r
.3017 .63596 m .30125 .6356 L .30094 .6354 L F
.117 .556 .919 r
.3021 .63557 m .3017 .63596 L .30009 .63506 L F
.404 0 0 r
.30005 .63503 m .30094 .6354 L .30017 .63389 L F
.117 .556 .919 r
.30087 .63525 m .30009 .63506 L .30005 .63503 L F
.3021 .63557 m .30009 .63506 L .30087 .63525 L F
.665 .612 .786 r
.30122 .63574 m .30164 .63543 L .30095 .63558 L F
.30171 .63547 m .30206 .63561 L .30214 .63506 L F
0 0 .2 r
.30214 .63506 m .30206 .63561 L .3021 .63557 L F
.524 .386 .635 r
.30214 .63506 m .30368 .63598 L .3021 .63557 L F
0 0 .2 r
.30214 .63506 m .3021 .63557 L .30222 .63545 L F
.524 .386 .635 r
.30214 .63506 m .3021 .63557 L .30171 .63547 L F
.30214 .63506 m .30171 .63547 L .30005 .63503 L F
.665 .612 .786 r
.30164 .63543 m .30171 .63547 L .30214 .63506 L F
.30164 .63543 m .30214 .63506 L .30141 .63538 L F
.30164 .63543 m .30141 .63538 L .30095 .63558 L F
.30122 .63574 m .30095 .63558 L .29874 .63653 L F
.117 .556 .919 r
.30368 .63598 m .3017 .63596 L .3021 .63557 L F
0 0 0 r
.30183 .64154 m .30226 .64113 L .30356 .63998 L F
.665 .612 .786 r
.30106 .64224 m .30107 .64227 L .30108 .64222 L F
.29838 .63784 m .30106 .64224 L .30206 .63561 L F
.30106 .64224 m .30108 .64222 L .30206 .63561 L F
0 0 .2 r
.30197 .63618 m .30107 .64227 L .30244 .63655 L F
0 0 0 r
.30261 .63737 m .30107 .64227 L .30154 .64149 L F
0 .11 .663 r
.30154 .64149 m .30112 .64219 L .29838 .63784 L F
.30112 .64219 m .30107 .64227 L .30106 .64224 L F
.30112 .64219 m .30106 .64224 L .29838 .63784 L F
0 0 0 r
.30061 .64265 m .30078 .64249 L .30106 .64224 L F
.3011 .6422 m .30106 .64224 L .30183 .64154 L F
.30061 .64265 m .30106 .64224 L .3011 .6422 L F
.30078 .64249 m .30226 .64113 L .30183 .64154 L F
.665 .612 .786 r
.29838 .63784 m .30206 .63561 L .30164 .63543 L F
.117 .556 .919 r
.30368 .63598 m .30368 .63629 L .30291 .63597 L F
.30368 .63629 m .30368 .63707 L .30291 .63597 L F
0 0 .2 r
.30222 .63545 m .30197 .63618 L .30244 .63655 L F
.30206 .63561 m .30197 .63618 L .30222 .63545 L F
.79 .632 .685 r
.66791 .34068 m .66961 .34449 L .66594 .3442 L F
.732 .548 .642 r
.66961 .34449 m .66534 .34676 L .66594 .3442 L F
.66961 .34449 m .66943 .34717 L .66534 .34676 L F
.736 .54 .627 r
.66961 .34449 m .6716 .34613 L .66943 .34717 L F
.765 .547 .602 r
.42919 .56841 m .43345 .56631 L .4295 .56611 L F
.733 .649 .766 r
.43589 .56567 m .43199 .56861 L .43345 .56631 L F
.43589 .56567 m .43689 .56959 L .43199 .56861 L F
.344 .053 .319 r
.43345 .56631 m .43528 .56755 L .43589 .56567 L F
.43345 .56631 m .43199 .56861 L .43528 .56755 L F
.228 0 .287 r
.42633 .59001 m .42468 .58879 L .42831 .58825 L F
.179 0 0 r
.42938 .58966 m .42831 .58825 L .43087 .58753 L F
.42938 .58966 m .42633 .59001 L .42831 .58825 L F
.444 .449 .769 r
.38281 .67329 m .38067 .67547 L .38037 .67562 L F
.558 .412 .638 r
.38353 .67539 m .38034 .67833 L .38067 .67547 L F
.739 .237 .036 r
.2939 .6256 m .29722 .62681 L .29566 .62772 L F
.642 .573 .763 r
.41956 .53428 m .41602 .53106 L .41856 .5308 L F
.505 .748 .982 r
.23993 .57261 m .2407 .5707 L .2389 .57098 L F
.23993 .57261 m .24243 .57242 L .2407 .5707 L F
.919 .551 .121 r
.59219 .41308 m .59159 .41385 L .59208 .41271 L F
.013 .252 .756 r
.59033 .4114 m .59219 .41308 L .59256 .41159 L F
.919 .551 .121 r
.59219 .41308 m .59208 .41271 L .59256 .41159 L F
0 .086 .596 r
.59033 .4114 m .59226 .41329 L .59219 .41308 L F
.59226 .41329 m .59319 .41421 L .59219 .41308 L F
.731 .25 .103 r
.59319 .41421 m .59302 .41579 L .59219 .41308 L F
.59319 .41421 m .59529 .41601 L .59302 .41579 L F
.57 .744 .959 r
.74134 .32752 m .73799 .32785 L .74069 .32468 L F
0 0 0 r
.74069 .32468 m .74063 .32475 L .73971 .32617 L F
.74063 .32475 m .73799 .32785 L .73971 .32617 L F
.73497 .33076 m .7374 .32767 L .73799 .32785 L F
.73497 .33076 m .73513 .33058 L .7374 .32767 L F
.585 .944 .828 r
.73799 .32785 m .7374 .32767 L .73971 .32617 L F
.744 .946 .626 r
.7374 .32767 m .73513 .33058 L .73635 .32865 L F
0 0 0 r
.73635 .32865 m .73896 .32733 L .73971 .32617 L F
.73896 .32733 m .73912 .32725 L .73971 .32617 L F
.74069 .32468 m .73971 .32617 L .7395 .32348 L F
.288 .743 .955 r
.7395 .32348 m .74377 .32409 L .74069 .32468 L F
0 0 0 r
.74377 .32409 m .74134 .32752 L .74069 .32468 L F
.566 .494 .733 r
.42671 .5096 m .42498 .51065 L .4236 .50582 L F
.548 .606 .864 r
.42769 .51137 m .42498 .51065 L .42671 .5096 L F
.564 .583 .831 r
.29929 .64899 m .30024 .64451 L .29811 .6468 L F
.29929 .64899 m .30212 .64829 L .30024 .64451 L F
0 .391 .842 r
.26675 .63581 m .27103 .63898 L .26892 .6355 L F
.983 .829 .612 r
.59903 .4196 m .59963 .42333 L .59833 .42219 L F
.873 .758 .733 r
.59963 .42333 m .59499 .42606 L .59833 .42219 L F
.59499 .42606 m .59498 .426 L .59833 .42219 L F
.59963 .42333 m .59784 .42764 L .59503 .42621 L F
.597 .667 .888 r
.59396 .42592 m .59784 .42764 L .59653 .42817 L F
.082 .254 .741 r
.59499 .42606 m .59396 .42592 L .59508 .42691 L F
.873 .758 .733 r
.59499 .42606 m .59503 .42621 L .59487 .42613 L F
.59963 .42333 m .59503 .42621 L .59499 .42606 L F
.082 .254 .741 r
.59483 .4246 m .59462 .42492 L .59499 .42606 L F
.59462 .42492 m .59396 .42592 L .59499 .42606 L F
.438 0 0 r
.59503 .42621 m .59396 .42592 L .59487 .42613 L F
.59784 .42764 m .59396 .42592 L .59503 .42621 L F
.082 .254 .741 r
.59567 .42637 m .59508 .42691 L .59653 .42817 L F
.889 .879 .819 r
.59639 .4213 m .59833 .42219 L .59498 .426 L F
.59496 .42585 m .59498 .426 L .59487 .42613 L F
.59639 .4213 m .59498 .426 L .59496 .42585 L F
.59639 .4213 m .59496 .42585 L .59513 .42414 L F
.082 .254 .741 r
.59483 .4246 m .59496 .42584 L .59504 .42505 L F
.889 .879 .819 r
.59496 .42585 m .59487 .42613 L .59513 .42414 L F
.082 .254 .741 r
.59504 .42505 m .59498 .426 L .59567 .42637 L F
.59496 .42584 m .59498 .426 L .59504 .42505 L F
.59498 .426 m .595 .4262 L .595 .4262 L F
.59498 .426 m .595 .4262 L .59567 .42637 L F
.595 .4262 m .59508 .42691 L .59567 .42637 L F
.59513 .42414 m .59483 .4246 L .59653 .42817 L F
.873 .758 .733 r
.59499 .42606 m .59487 .42613 L .59498 .426 L F
.617 .292 .396 r
.37194 .54374 m .36777 .54454 L .36955 .54355 L F
0 0 0 r
.36137 .5903 m .35969 .59163 L .3586 .59338 L F
.775 .699 .78 r
.36137 .5903 m .3586 .59338 L .35969 .59163 L F
.525 .902 .957 r
.27891 .53847 m .27663 .53821 L .27506 .5392 L F
.516 .898 .956 r
.28068 .5374 m .27663 .53821 L .27891 .53847 L F
.45 .271 .545 r
.33827 .52437 m .34068 .52714 L .34144 .5256 L F
.33827 .52437 m .33839 .52801 L .34068 .52714 L F
.697 .903 .969 r
.30648 .51441 m .30793 .51213 L .30906 .51259 L F
.30648 .51441 m .30513 .51372 L .30793 .51213 L F
.288 .42 .822 r
.39011 .64761 m .38907 .64974 L .38737 .6483 L F
.39011 .64761 m .39144 .65081 L .38907 .64974 L F
.39011 .64761 m .39144 .65081 L .38907 .64974 L F
.692 .208 .095 r
.30542 .5274 m .30755 .52942 L .30939 .5281 L F
.648 .151 .055 r
.30939 .5281 m .30755 .52942 L .31122 .52985 L F
0 0 0 r
.331 .59777 m .32909 .60127 L .33008 .60019 L F
0 0 .073 r
.33008 .60019 m .32909 .60127 L .32829 .60372 L F
.416 .551 .883 r
.42464 .50387 m .42565 .50567 L .4236 .50582 L F
.566 .494 .733 r
.42671 .5096 m .4236 .50582 L .42565 .50567 L F
0 0 0 r
.29144 .61128 m .29139 .61224 L .29387 .61048 L F
.848 .387 .064 r
.30075 .65526 m .29708 .65135 L .29901 .65417 L F
.627 .078 0 r
.30097 .65624 m .30075 .65526 L .29901 .65417 L F
.30097 .65624 m .30266 .65712 L .30075 .65526 L F
.686 .152 0 r
.30266 .65712 m .30111 .65532 L .30075 .65526 L F
.823 .798 .304 r
.40394 .60602 m .40387 .60784 L .40473 .604 L F
.928 .892 .482 r
.4028 .60799 m .40387 .60784 L .40394 .60602 L F
.4028 .60799 m .40294 .6103 L .40387 .60784 L F
.686 .152 0 r
.30266 .65712 m .30459 .65852 L .30111 .65532 L F
.536 .333 .552 r
.32695 .56296 m .32679 .56576 L .32424 .56618 L F
.522 .305 .526 r
.33004 .56183 m .32679 .56576 L .32695 .56296 L F
.844 .476 .355 r
.56298 .4491 m .56159 .45074 L .55948 .44775 L F
.652 .22 .207 r
.56298 .4491 m .56553 .451 L .56159 .45074 L F
0 0 0 r
.73497 .33076 m .73368 .33237 L .73513 .33058 L F
.366 .099 .37 r
.41956 .53428 m .41901 .53688 L .41671 .53751 L F
.463 .48 .791 r
.42143 .53331 m .41956 .53428 L .41856 .5308 L F
0 0 .221 r
.42087 .53555 m .41956 .53428 L .42143 .53331 L F
.42087 .53555 m .41901 .53688 L .41956 .53428 L F
0 0 0 r
.26769 .54218 m .26792 .54243 L .26625 .54312 L F
.261 .135 .512 r
.26792 .54243 m .2658 .54558 L .26625 .54312 L F
.703 .389 .443 r
.26559 .53949 m .26324 .54229 L .26792 .54243 L F
.261 .135 .512 r
.26792 .54243 m .2679 .54584 L .2658 .54558 L F
.723 .681 .809 r
.26792 .54243 m .26324 .54229 L .26586 .5414 L F
.143 .044 .473 r
.26914 .54406 m .2679 .54584 L .26792 .54243 L F
0 0 .454 r
.26832 .54285 m .26792 .54243 L .26586 .5414 L F
.2685 .54295 m .26914 .54406 L .26792 .54243 L F
.2685 .54295 m .26792 .54243 L .26832 .54285 L F
0 0 0 r
.26944 .54105 m .26792 .54243 L .26769 .54218 L F
.891 .522 .334 r
.2671 .54013 m .26792 .54243 L .26944 .54105 L F
0 0 .13 r
.39015 .63685 m .38977 .63614 L .39102 .63515 L F
.39015 .63685 m .38917 .63888 L .38977 .63614 L F
.747 .72 .827 r
.34909 .65362 m .34616 .65237 L .34858 .65121 L F
.091 .64 .825 r
.35086 .65339 m .34909 .65362 L .34858 .65121 L F
.35086 .65339 m .35218 .65374 L .34909 .65362 L F
0 0 .163 r
.74014 .32961 m .74042 .3319 L .73856 .33398 L F
.254 .221 .627 r
.74223 .3263 m .74014 .32961 L .74134 .32752 L F
.74223 .3263 m .74306 .32887 L .74014 .32961 L F
.121 0 .172 r
.74306 .32887 m .74042 .3319 L .74014 .32961 L F
.032 .196 .701 r
.22863 .56145 m .22775 .5631 L .22657 .55958 L F
0 0 .131 r
.22863 .56145 m .2281 .5648 L .22775 .5631 L F
0 0 0 r
.73357 .33991 m .73186 .34431 L .73334 .34086 L F
.738 .724 .838 r
.25008 .58893 m .24711 .59041 L .25089 .59209 L F
0 0 .564 r
.43174 .5803 m .43198 .58178 L .43015 .57873 L F
.766 .444 .441 r
.37951 .62576 m .3793 .6236 L .3755 .62282 L F
.661 .419 .544 r
.38223 .6257 m .3793 .6236 L .37951 .62576 L F
.38223 .6257 m .38261 .62306 L .3793 .6236 L F
.459 .217 .459 r
.29635 .60457 m .2961 .60688 L .29886 .60412 L F
.055 0 .203 r
.30334 .61837 m .30279 .61612 L .30465 .61564 L F
.30334 .61837 m .30176 .61944 L .30279 .61612 L F
.389 .261 .583 r
.27516 .55832 m .27292 .55631 L .2751 .55577 L F
.27516 .55832 m .27277 .5595 L .27292 .55631 L F
.442 0 0 r
.26265 .63129 m .26481 .63233 L .26142 .6312 L F
.485 .853 .988 r
.27444 .52214 m .27189 .52287 L .26851 .52134 L F
.788 .78 .846 r
.30621 .52087 m .30378 .52387 L .30825 .52422 L F
.823 .658 .679 r
.30378 .52387 m .30542 .5274 L .30825 .52422 L F
.334 .452 .832 r
.30825 .52422 m .30861 .52014 L .30621 .52087 L F
.67 .816 .953 r
.36922 .6387 m .37335 .63917 L .37214 .63749 L F
.79 .52 .528 r
.3724 .64152 m .37335 .63917 L .36922 .6387 L F
.992 .82 .573 r
.37214 .63749 m .37335 .63917 L .3724 .64152 L F
.119 0 .338 r
.34848 .63261 m .34656 .63609 L .3481 .63521 L F
.218 .122 .525 r
.3481 .63521 m .34656 .63609 L .34818 .63801 L F
.119 0 .338 r
.34848 .63261 m .34656 .63609 L .3481 .63521 L F
.744 .546 .626 r
.38635 .57734 m .38295 .57602 L .38634 .57565 L F
.38635 .57734 m .38286 .57869 L .38295 .57602 L F
.403 .847 .748 r
.384 .57791 m .38286 .57869 L .38635 .57734 L F
.634 .804 .371 r
.38778 .5748 m .38635 .57734 L .38634 .57565 L F
.38778 .5748 m .38647 .57699 L .38635 .57734 L F
.308 .795 .748 r
.38635 .57734 m .38647 .57699 L .384 .57791 L F
.553 .283 .46 r
.68909 .36007 m .68903 .36197 L .68657 .36188 L F
.529 .263 .457 r
.68909 .36007 m .69174 .36167 L .68903 .36197 L F
.58 .202 .29 r
.68909 .36007 m .69182 .36015 L .69174 .36167 L F
.506 .874 .981 r
.72592 .3375 m .7239 .33894 L .72291 .33822 L F
.72592 .3375 m .72696 .33808 L .7239 .33894 L F
.608 .57 .786 r
.6516 .3886 m .64951 .3913 L .64801 .38721 L F
.601 .56 .781 r
.6516 .3886 m .65233 .39055 L .64951 .3913 L F
.331 .263 .628 r
.19923 .58171 m .20098 .58115 L .20045 .57844 L F
.133 .2 .667 r
.19923 .58171 m .20133 .58395 L .20098 .58115 L F
.621 .657 .864 r
.62816 .38521 m .62454 .3827 L .62695 .38155 L F
.585 .597 .831 r
.62961 .38329 m .62816 .38521 L .62695 .38155 L F
.142 0 .218 r
.34697 .57832 m .34842 .57839 L .34956 .57467 L F
.841 .869 .863 r
.34728 .5731 m .34956 .57467 L .35143 .57224 L F
0 0 .006 r
.34956 .57467 m .35055 .5756 L .3517 .5749 L F
.34956 .57467 m .34842 .57839 L .35055 .5756 L F
.441 .267 .548 r
.34956 .57467 m .3517 .5749 L .35143 .57224 L F
0 .025 .515 r
.39464 .51899 m .39657 .52081 L .39522 .51954 L F
.914 .916 .804 r
.62663 .40967 m .62997 .40768 L .62749 .40731 L F
0 0 0 r
.62603 .41133 m .62663 .40967 L .62749 .40763 L F
.985 .875 .64 r
.62573 .41211 m .62773 .4111 L .62663 .40967 L F
0 0 0 r
.62573 .41211 m .62663 .40967 L .62603 .41133 L F
.914 .916 .804 r
.62663 .40967 m .62749 .40731 L .62595 .40707 L F
.62663 .40967 m .62773 .4111 L .62997 .40768 L F
0 0 0 r
.33744 .52174 m .33618 .52342 L .33499 .52403 L F
.314 0 .157 r
.33605 .52607 m .33371 .52781 L .33499 .52403 L F
0 0 0 r
.34144 .5256 m .34284 .52344 L .34447 .52651 L F
.34144 .5256 m .34189 .52574 L .34284 .52344 L F
.34144 .5256 m .34068 .52714 L .34189 .52574 L F
.327 .299 .674 r
.34838 .525 m .34447 .52651 L .34661 .52377 L F
.585 .742 .951 r
.34731 .52332 m .34838 .525 L .34661 .52377 L F
.34731 .52332 m .351 .52457 L .34838 .525 L F
.415 .354 .68 r
.35073 .52731 m .34838 .525 L .351 .52457 L F
.823 .718 .748 r
.34703 .64256 m .3479 .64648 L .34541 .6454 L F
.625 .559 .76 r
.3479 .64648 m .34396 .64821 L .34541 .6454 L F
.315 .376 .766 r
.34947 .64386 m .3479 .64648 L .34703 .64256 L F
.492 .495 .788 r
.35147 .64831 m .3479 .64648 L .34947 .64386 L F
.862 .991 .731 r
.70806 .31019 m .70634 .31231 L .70633 .31253 L F
.243 0 .248 r
.7104 .30982 m .70634 .31231 L .70806 .31019 L F
.23 0 .23 r
.70968 .31257 m .70634 .31231 L .7104 .30982 L F
.149 .451 .881 r
.70645 .30985 m .70634 .31231 L .70968 .31257 L F
.70597 .30944 m .70634 .31231 L .70645 .30985 L F
.862 .991 .731 r
.70633 .31253 m .70634 .31231 L .70583 .31322 L F
.243 0 .248 r
.7104 .30982 m .70806 .31019 L .71046 .30871 L F
.503 .229 .432 r
.58258 .44887 m .57974 .45146 L .57989 .44901 L F
.461 .498 .81 r
.56793 .42733 m .56405 .42318 L .5666 .42298 L F
.397 .286 .609 r
.35168 .60115 m .35395 .59697 L .35238 .59775 L F
.35168 .60115 m .3537 .6006 L .35395 .59697 L F
.34 .196 .535 r
.35168 .60115 m .35393 .60293 L .3537 .6006 L F
.35168 .60115 m .35172 .60393 L .35393 .60293 L F
.91 .556 .355 r
.71249 .29248 m .71311 .295 L .71431 .29318 L F
.808 .844 .877 r
.71725 .29519 m .7174 .2952 L .71746 .29421 L F
.441 .58 .896 r
.7174 .2952 m .72024 .29359 L .71746 .29421 L F
.7174 .2952 m .72008 .29517 L .72024 .29359 L F
.515 .649 .918 r
.72024 .29359 m .71848 .29523 L .71746 .29421 L F
.71848 .29523 m .71751 .29614 L .71748 .29522 L F
.819 .472 .398 r
.71737 .29522 m .72008 .29517 L .7174 .2952 L F
.71748 .29522 m .72008 .29517 L .71737 .29522 L F
.515 .649 .918 r
.71848 .29523 m .71748 .29522 L .71746 .29421 L F
.819 .472 .398 r
.71736 .29522 m .71748 .29522 L .71737 .29522 L F
.817 .492 .438 r
.71751 .29614 m .71713 .29578 L .71725 .29522 L F
.71751 .29614 m .71725 .29522 L .71748 .29522 L F
.71725 .29519 m .71431 .29318 L .71746 .29421 L F
.71713 .29578 m .71618 .29491 L .71725 .29519 L F
.71618 .29491 m .71431 .29318 L .71725 .29519 L F
.397 0 0 r
.71598 .29602 m .71736 .29522 L .71311 .295 L F
.71736 .29522 m .7174 .2952 L .71725 .29519 L F
.71736 .29522 m .71725 .29519 L .71311 .295 L F
.515 .649 .918 r
.71848 .29523 m .72008 .29517 L .71751 .29614 L F
.819 .472 .398 r
.72008 .29517 m .72008 .29517 L .71736 .29522 L F
.515 .649 .918 r
.72024 .29359 m .72008 .29517 L .71848 .29523 L F
.819 .472 .398 r
.71598 .29602 m .72008 .29517 L .72004 .29517 L F
.71727 .29527 m .72004 .29517 L .71736 .29522 L F
.71598 .29602 m .72004 .29517 L .71727 .29527 L F
.817 .492 .438 r
.71748 .29522 m .71725 .29522 L .71746 .29421 L F
.808 .844 .877 r
.71311 .295 m .71725 .29519 L .71746 .29421 L F
.71311 .295 m .71746 .29421 L .71431 .29318 L F
.671 .518 .669 r
.2297 .58811 m .2334 .58833 L .23245 .58491 L F
.643 .502 .675 r
.23245 .58491 m .236 .58802 L .23492 .58449 L F
.23245 .58491 m .2334 .58833 L .236 .58802 L F
.523 .8 .996 r
.55744 .42352 m .55866 .42169 L .55617 .41964 L F
.55744 .42352 m .55999 .42294 L .55866 .42169 L F
.55866 .42169 m .55744 .42352 L .55626 .42282 L F
.55866 .42169 m .55999 .42294 L .55744 .42352 L F
.904 .731 .656 r
.31324 .52641 m .31598 .52806 L .31434 .52442 L F
.013 .252 .756 r
.59033 .4114 m .59256 .41159 L .58993 .41083 L F
.321 0 0 r
.59127 .41137 m .58993 .41083 L .59256 .41159 L F
0 .322 .751 r
.58862 .4103 m .59033 .4114 L .58993 .41083 L F
.321 0 0 r
.58841 .41089 m .58993 .41083 L .59127 .41137 L F
0 .322 .751 r
.58695 .40922 m .58862 .4103 L .58993 .41083 L F
.642 .459 .62 r
.32424 .56618 m .32416 .56885 L .3216 .56934 L F
.451 .251 .517 r
.32679 .56576 m .32416 .56885 L .32424 .56618 L F
.519 .407 .667 r
.2908 .53442 m .2903 .53829 L .29402 .53706 L F
.281 .309 .713 r
.2903 .53829 m .29318 .5401 L .29402 .53706 L F
.2903 .53829 m .29209 .54209 L .29318 .5401 L F
.099 0 0 r
.20266 .5997 m .19856 .60312 L .20195 .60501 L F
.602 .714 .923 r
.20266 .5997 m .20314 .59637 L .20127 .59647 L F
.20266 .5997 m .20466 .59898 L .20314 .59637 L F
0 0 0 r
.41442 .50859 m .41268 .50975 L .41464 .50855 L F
.714 .685 .82 r
.3107 .62624 m .3147 .62686 L .31314 .62522 L F
.31314 .62522 m .3147 .62686 L .3107 .62624 L F
.548 .541 .799 r
.31562 .62269 m .3147 .62686 L .31314 .62522 L F
.31562 .62269 m .31641 .62621 L .3147 .62686 L F
.593 .054 0 r
.31641 .62621 m .31314 .62522 L .3147 .62686 L F
.602 .568 .788 r
.28446 .61354 m .28234 .61482 L .28053 .61023 L F
.593 .107 .07 r
.28042 .61352 m .28446 .61354 L .28234 .61482 L F
0 0 0 r
.28234 .61482 m .28264 .61497 L .28446 .61354 L F
.28234 .61482 m .28142 .61646 L .28264 .61497 L F
.664 .541 .705 r
.3216 .56934 m .32191 .57205 L .31916 .57263 L F
.535 .433 .685 r
.38261 .62306 m .38504 .62246 L .38487 .61865 L F
.176 0 0 r
.38346 .62475 m .38261 .62306 L .38223 .6257 L F
0 0 .444 r
.37951 .62576 m .38094 .62951 L .38135 .62895 L F
.38132 .62885 m .38135 .62895 L .38136 .62893 L F
.37951 .62576 m .38135 .62895 L .38132 .62885 L F
.561 .607 .856 r
.38018 .62704 m .38121 .62901 L .37802 .6305 L F
.748 .746 .85 r
.38183 .6301 m .38405 .62728 L .38136 .62893 L F
.38405 .62728 m .38384 .6273 L .38136 .62893 L F
.3828 .62931 m .38425 .62703 L .38189 .63001 L F
.3819 .63004 m .38189 .63001 L .38183 .6301 L F
.3828 .62931 m .38189 .63001 L .3819 .63004 L F
0 0 .444 r
.37951 .62576 m .38136 .62893 L .38223 .6257 L F
0 0 0 r
.38311 .6255 m .38223 .6257 L .38136 .62893 L F
.38751 .62128 m .38504 .62246 L .38351 .62471 L F
.764 .708 .8 r
.38524 .62317 m .38335 .625 L .38423 .62338 L F
0 0 0 r
.38352 .62471 m .38351 .62471 L .3835 .62472 L F
.38751 .62128 m .38351 .62471 L .38352 .62471 L F
.38751 .62128 m .38352 .62471 L .38698 .62505 L F
.38352 .62471 m .3835 .62472 L .38352 .62472 L F
.38352 .62471 m .38352 .62472 L .38698 .62505 L F
.819 .498 .446 r
.38635 .62648 m .38698 .62505 L .38352 .62472 L F
.38355 .62475 m .38352 .62472 L .3835 .62472 L F
.38635 .62648 m .38352 .62472 L .38355 .62475 L F
.38635 .62648 m .38355 .62475 L .38425 .62703 L F
.764 .708 .8 r
.38386 .6245 m .3839 .62625 L .38354 .62481 L F
.819 .498 .446 r
.38355 .62475 m .3835 .62472 L .38425 .62703 L F
.764 .708 .8 r
.38389 .62587 m .38425 .62703 L .3839 .62625 L F
.38388 .62513 m .38425 .62703 L .38389 .62587 L F
.38386 .6245 m .38398 .62525 L .38388 .62513 L F
.38398 .62525 m .38425 .62703 L .38388 .62513 L F
.38354 .62481 m .3839 .62625 L .38335 .625 L F
.38524 .62317 m .38509 .62376 L .38386 .6245 L F
.38509 .62376 m .38425 .62703 L .38386 .6245 L F
0 0 0 r
.3835 .62473 m .38346 .62475 L .38335 .625 L F
.176 0 0 r
.3835 .62473 m .38348 .62468 L .38346 .62475 L F
.3835 .62472 m .3835 .62472 L .3835 .62473 L F
.3835 .62472 m .38348 .62468 L .3835 .62473 L F
.38348 .62468 m .38261 .62306 L .38346 .62475 L F
.3835 .62472 m .38504 .62246 L .38261 .62306 L F
.3835 .62472 m .38351 .62471 L .3835 .62472 L F
.38351 .62471 m .38504 .62246 L .3835 .62472 L F
.764 .708 .8 r
.38388 .62346 m .38344 .62473 L .38277 .62369 L F
.38344 .62473 m .38335 .625 L .38325 .62478 L F
.38344 .62473 m .38325 .62478 L .38277 .62369 L F
.38423 .62338 m .3835 .62473 L .38388 .62346 L F
.3835 .62473 m .38335 .625 L .38388 .62346 L F
0 0 0 r
.3835 .62472 m .3835 .62473 L .38311 .6255 L F
.707 .567 .695 r
.38335 .625 m .38339 .62509 L .38327 .62516 L F
0 0 0 r
.3835 .62473 m .38335 .625 L .38311 .6255 L F
.38346 .62475 m .38223 .6257 L .38311 .6255 L F
.707 .567 .695 r
.38277 .62369 m .38335 .625 L .38018 .62704 L F
.38335 .625 m .38327 .62516 L .38018 .62704 L F
.38339 .62509 m .38425 .62703 L .38325 .62569 L F
0 0 0 r
.3835 .62472 m .38311 .6255 L .38425 .62703 L F
.38311 .6255 m .38136 .62893 L .38425 .62703 L F
.707 .567 .695 r
.38325 .62569 m .38425 .62703 L .38293 .62704 L F
0 .196 .726 r
.38049 .62732 m .38242 .62984 L .38247 .62913 L F
.38018 .62704 m .38064 .62762 L .38049 .62732 L F
.38064 .62762 m .38242 .62984 L .38049 .62732 L F
0 .207 .732 r
.38174 .62906 m .38201 .63055 L .38121 .62901 L F
.839 .817 .828 r
.38063 .62763 m .38234 .62984 L .38242 .62984 L F
0 .207 .732 r
.38247 .62913 m .38227 .62974 L .38174 .62906 L F
.38227 .62974 m .38201 .63055 L .38174 .62906 L F
.839 .817 .828 r
.38064 .62762 m .38063 .62763 L .38242 .62984 L F
.38063 .62762 m .38063 .62763 L .38064 .62762 L F
0 .207 .732 r
.38184 .62856 m .38153 .62878 L .38018 .62704 L F
.38153 .62878 m .38121 .62901 L .38018 .62704 L F
.561 .607 .856 r
.38018 .62704 m .37802 .6305 L .38027 .62945 L F
.839 .817 .828 r
.38018 .62704 m .38027 .62945 L .37643 .62949 L F
.37903 .62779 m .37643 .62949 L .38063 .62763 L F
.37903 .62779 m .38063 .62763 L .38063 .62762 L F
.38 .836 .755 r
.38136 .62894 m .38135 .62895 L .38121 .62901 L F
.38123 .629 m .38121 .62901 L .38033 .62942 L F
.38136 .62894 m .38121 .62901 L .38123 .629 L F
.38027 .62945 m .38033 .62942 L .37802 .6305 L F
.38136 .62894 m .38033 .62942 L .38027 .62945 L F
.38135 .62895 m .38094 .62951 L .37802 .6305 L F
.561 .607 .856 r
.38121 .62901 m .38176 .63006 L .37802 .6305 L F
.38176 .63006 m .38193 .63055 L .37802 .6305 L F
.38 .836 .755 r
.38028 .62972 m .37802 .6305 L .3804 .63053 L F
.561 .607 .856 r
.38028 .62972 m .37802 .6305 L .38031 .63048 L F
.38027 .62945 m .37802 .6305 L .38028 .62972 L F
.38 .836 .755 r
.38136 .62893 m .38136 .62894 L .37802 .6305 L F
.839 .817 .828 r
.38027 .62945 m .38028 .62972 L .38024 .62946 L F
.38 .836 .755 r
.38136 .62893 m .37802 .6305 L .3815 .62929 L F
.839 .817 .828 r
.38024 .62946 m .38031 .63048 L .37868 .63007 L F
.38028 .62972 m .38031 .63048 L .38024 .62946 L F
.561 .607 .856 r
.38176 .63006 m .38201 .63055 L .38193 .63055 L F
.38 .836 .755 r
.3815 .62929 m .38028 .62972 L .38201 .63055 L F
.38028 .62972 m .3804 .63053 L .38201 .63055 L F
.839 .817 .828 r
.38027 .62945 m .37868 .63007 L .37643 .62949 L F
.38063 .62763 m .37643 .62949 L .38234 .62984 L F
.38018 .62704 m .37903 .62779 L .38064 .62762 L F
.748 .746 .85 r
.38405 .62728 m .38425 .62703 L .38384 .6273 L F
.38201 .63055 m .3828 .62931 L .38183 .6301 L F
.38201 .63055 m .38422 .62953 L .38425 .62703 L F
.479 .52 .822 r
.38499 .62746 m .38422 .62953 L .3869 .62858 L F
.38425 .62703 m .38423 .62816 L .38499 .62746 L F
.38423 .62816 m .38422 .62953 L .38499 .62746 L F
.38425 .62703 m .3869 .62858 L .38635 .62648 L F
.918 .56 .115 r
.38635 .62648 m .38367 .62831 L .38425 .62703 L F
.38367 .62831 m .38247 .62913 L .3831 .62839 L F
.38367 .62831 m .3831 .62839 L .38425 .62703 L F
.668 .798 .944 r
.38673 .6279 m .3869 .62858 L .38712 .6283 L F
.918 .56 .115 r
.38601 .62671 m .38582 .6267 L .38521 .62726 L F
.38635 .62648 m .38627 .6265 L .38601 .62671 L F
.38627 .6265 m .38552 .62667 L .38601 .62671 L F
.38635 .62648 m .3869 .62858 L .38552 .62667 L F
.668 .798 .944 r
.38552 .62667 m .38644 .62794 L .38673 .6279 L F
.38644 .62794 m .3869 .62858 L .38673 .6279 L F
.918 .56 .115 r
.38521 .62726 m .38552 .62667 L .38247 .62913 L F
.38582 .6267 m .38552 .62667 L .38521 .62726 L F
0 .207 .732 r
.38247 .62913 m .38121 .62901 L .38184 .62856 L F
.707 .567 .695 r
.38339 .62509 m .38293 .62704 L .38018 .62704 L F
.637 .56 .751 r
.66021 .3968 m .65854 .40184 L .6573 .39789 L F
.66021 .3968 m .66112 .40078 L .65854 .40184 L F
.249 .117 .497 r
.31045 .58158 m .31285 .58083 L .31297 .57799 L F
.323 .105 .421 r
.31027 .58414 m .31285 .58083 L .31045 .58158 L F
.676 .318 0 r
.29328 .64758 m .29369 .64835 L .292 .64456 L F
.742 .43 0 r
.29433 .65074 m .29369 .64835 L .29328 .64758 L F
.817 .52 .488 r
.29708 .65135 m .29442 .64899 L .29433 .65074 L F
.89 .528 .351 r
.29758 .65398 m .29708 .65135 L .29433 .65074 L F
.29758 .65398 m .29433 .65074 L .29243 .65314 L F
0 0 .048 r
.29424 .65266 m .29433 .65074 L .29524 .64929 L F
.29419 .65285 m .29433 .65074 L .29424 .65266 L F
.817 .52 .488 r
.29442 .64899 m .29369 .64835 L .29433 .65074 L F
.242 .303 .726 r
.32019 .64769 m .31824 .64601 L .31978 .64404 L F
.32019 .64769 m .31959 .64904 L .31824 .64601 L F
.563 .327 .515 r
.33293 .655 m .33549 .65408 L .33337 .65131 L F
.33293 .655 m .33549 .65408 L .33337 .65131 L F
.662 .713 .886 r
.23675 .56056 m .24041 .56191 L .23925 .56 L F
.467 .164 .366 r
.23707 .56576 m .23948 .56549 L .24041 .56191 L F
.466 .611 .91 r
.24041 .56191 m .24136 .55958 L .23925 .56 L F
.24041 .56191 m .24341 .56247 L .24136 .55958 L F
.281 0 .296 r
.24041 .56191 m .24166 .56448 L .24341 .56247 L F
.24041 .56191 m .23948 .56549 L .24166 .56448 L F
.315 .16 .506 r
.36345 .57884 m .36536 .5807 L .36547 .57796 L F
.212 .155 .571 r
.36345 .57884 m .36392 .58183 L .36536 .5807 L F
.658 .937 .672 r
.38689 .67916 m .38589 .68073 L .38385 .68214 L F
.399 0 .148 r
.59544 .44555 m .59167 .44809 L .59145 .44599 L F
.59544 .44555 m .59439 .44757 L .59167 .44809 L F
.536 .128 .215 r
.59845 .44687 m .59439 .44757 L .59544 .44555 L F
0 0 0 r
.27479 .55123 m .2728 .55348 L .27365 .55289 L F
.513 .145 .279 r
.27365 .55289 m .27739 .55047 L .27479 .55123 L F
.588 .945 .903 r
.3401 .66393 m .34104 .66416 L .34319 .66294 L F
.011 .58 .78 r
.33847 .66397 m .34193 .66437 L .34104 .66416 L F
.157 0 0 r
.33847 .66397 m .34104 .66416 L .33862 .66441 L F
.588 .945 .903 r
.33862 .66441 m .34104 .66416 L .3401 .66393 L F
.011 .58 .78 r
.34193 .66437 m .34246 .66443 L .34104 .66416 L F
.553 .88 .991 r
.34319 .66294 m .34246 .66443 L .34467 .66355 L F
.629 .948 .944 r
.34104 .66416 m .34246 .66443 L .34319 .66294 L F
.228 0 .287 r
.42633 .59001 m .42443 .59074 L .42468 .58879 L F
.519 .407 .667 r
.2908 .53442 m .29402 .53706 L .29317 .53313 L F
.548 .702 .941 r
.36614 .52274 m .36444 .52431 L .36366 .52361 L F
.36614 .52274 m .36778 .52471 L .36444 .52431 L F
.746 .579 .668 r
.6716 .34613 m .66933 .34991 L .66943 .34717 L F
.6716 .34613 m .6733 .35033 L .66933 .34991 L F
0 0 .099 r
.34778 .66175 m .34837 .65872 L .34901 .65767 L F
.34778 .66175 m .34837 .65872 L .34901 .65767 L F
.916 .537 .281 r
.67158 .36518 m .67366 .36646 L .67365 .3685 L F
.576 .22 .329 r
.67365 .3685 m .67366 .36646 L .67634 .3681 L F
.642 .494 .667 r
.67616 .36297 m .67639 .36569 L .67366 .36646 L F
.545 .255 .426 r
.67366 .36646 m .67639 .36569 L .67634 .3681 L F
.514 .261 .469 r
.23772 .58135 m .24064 .57798 L .23717 .5782 L F
.23772 .58135 m .24034 .58154 L .24064 .57798 L F
.874 .994 .766 r
.70583 .31322 m .70634 .31231 L .70418 .31387 L F
.482 .847 .99 r
.35123 .65976 m .35012 .658 L .35008 .66054 L F
.35123 .65976 m .3541 .65918 L .3518 .6585 L F
.346 .814 .916 r
.3541 .65918 m .35169 .65873 L .35018 .65803 L F
.482 .847 .99 r
.35054 .65867 m .3518 .6585 L .35012 .658 L F
.76 .96 .934 r
.35013 .65744 m .35082 .6576 L .34818 .65932 L F
.346 .814 .916 r
.35019 .65802 m .35018 .65803 L .35012 .658 L F
.3541 .65918 m .35018 .65803 L .35019 .65802 L F
.585 .691 .914 r
.35076 .65767 m .35169 .65873 L .35295 .65653 L F
.35012 .658 m .35018 .65803 L .35076 .65767 L F
.35018 .65803 m .35169 .65873 L .35076 .65767 L F
0 0 0 r
.34973 .65842 m .35065 .65773 L .35139 .65738 L F
.35066 .65773 m .35082 .6576 L .35076 .65767 L F
.585 .691 .914 r
.35012 .658 m .35076 .65767 L .35013 .65744 L F
.35076 .65767 m .35295 .65653 L .35218 .65678 L F
0 0 0 r
.35076 .65767 m .35082 .6576 L .35092 .65757 L F
.585 .691 .914 r
.35092 .65756 m .35218 .65678 L .35013 .65744 L F
.014 .577 .799 r
.35139 .65738 m .35092 .65756 L .35013 .65744 L F
.35092 .65756 m .35082 .6576 L .35013 .65744 L F
.585 .691 .914 r
.35076 .65767 m .35092 .65756 L .35013 .65744 L F
0 0 0 r
.35065 .65773 m .35066 .65773 L .35076 .65767 L F
.35065 .65773 m .35092 .65757 L .35139 .65738 L F
.761 .872 .929 r
.34818 .65932 m .35008 .66054 L .35012 .65807 L F
0 0 0 r
.34818 .65932 m .35082 .6576 L .35073 .65767 L F
.761 .872 .929 r
.34818 .65932 m .35012 .65807 L .35012 .658 L F
0 0 0 r
.34818 .65932 m .35073 .65767 L .3494 .65863 L F
.3494 .65863 m .34993 .65825 L .34973 .65842 L F
.34993 .65825 m .35082 .6576 L .34973 .65842 L F
.728 .908 .957 r
.35169 .65873 m .35694 .65864 L .35898 .65726 L F
.35169 .65873 m .35516 .65803 L .35563 .65839 L F
.35516 .65803 m .35898 .65726 L .35776 .65767 L F
.35516 .65803 m .35776 .65767 L .35563 .65839 L F
.482 .847 .99 r
.35123 .65976 m .3518 .6585 L .35054 .65867 L F
.069 .347 .821 r
.32093 .53824 m .3225 .53709 L .31961 .53782 L F
.32093 .53824 m .32347 .53958 L .3225 .53709 L F
.196 0 0 r
.34593 .67154 m .34366 .67191 L .34298 .67277 L F
.286 0 0 r
.36202 .68396 m .36589 .68303 L .36292 .68301 L F
.375 .055 .29 r
.3002 .55529 m .29865 .55389 L .30073 .55298 L F
.3002 .55529 m .29785 .5559 L .29865 .55389 L F
.663 .801 .351 r
.73186 .34431 m .73106 .34576 L .73013 .34772 L F
0 0 0 r
.73357 .33991 m .73291 .34193 L .73186 .34431 L F
.73315 .34396 m .73186 .34431 L .73291 .34193 L F
.677 .704 .867 r
.639 .38654 m .6345 .38557 L .63763 .38476 L F
.742 .789 .891 r
.63763 .38476 m .64137 .3852 L .639 .38654 L F
.72 .524 .624 r
.67787 .35094 m .67332 .35298 L .6733 .35033 L F
.67787 .35094 m .67746 .3535 L .67332 .35298 L F
.817 .897 .899 r
.42671 .57166 m .43113 .57046 L .42919 .56841 L F
.736 .732 .848 r
.42919 .56841 m .43113 .57046 L .43199 .56861 L F
0 0 0 r
.23567 .59222 m .23568 .59338 L .23465 .59339 L F
.515 .139 .266 r
.6016 .44401 m .60065 .44699 L .59845 .44687 L F
.625 .259 .328 r
.6048 .44484 m .60065 .44699 L .6016 .44401 L F
.282 .599 .951 r
.35191 .50063 m .35142 .50165 L .34927 .50058 L F
.35191 .50063 m .35333 .50246 L .35142 .50165 L F
.831 .637 .64 r
.22579 .58472 m .2255 .58778 L .2297 .58811 L F
.56 .472 .712 r
.2297 .58811 m .23311 .59079 L .2334 .58833 L F
.2297 .58811 m .2307 .59167 L .23311 .59079 L F
.438 .226 .493 r
.64165 .40364 m .6391 .40447 L .63911 .40691 L F
.64165 .40364 m .6391 .40447 L .63911 .40691 L F
.991 .803 .553 r
.39803 .5433 m .39734 .54614 L .39883 .54729 L F
.947 .592 .22 r
.39734 .54614 m .39937 .54958 L .39883 .54729 L F
.329 .808 .894 r
.59896 .43192 m .59586 .43204 L .59769 .43201 L F
.903 .934 .823 r
.33524 .61684 m .33277 .62028 L .33132 .61954 L F
.427 .225 .502 r
.33499 .61987 m .33277 .62028 L .33524 .61684 L F
.379 .793 .978 r
.33132 .61954 m .33277 .62028 L .33499 .61987 L F
.832 .799 .306 r
.40394 .60602 m .40473 .604 L .40482 .60193 L F
.227 0 0 r
.38016 .67209 m .37604 .67321 L .3778 .6736 L F
0 .294 .789 r
.37878 .67319 m .3778 .6736 L .37604 .67321 L F
.37878 .67319 m .38037 .67562 L .3778 .6736 L F
0 .167 .696 r
.26477 .62327 m .26406 .62372 L .26209 .62225 L F
.501 .179 .353 r
.26406 .62372 m .26608 .62531 L .26669 .62325 L F
0 .167 .696 r
.26477 .62327 m .26608 .62531 L .26406 .62372 L F
.374 .759 .989 r
.34332 .49862 m .34277 .49981 L .34113 .49889 L F
.34332 .49862 m .34509 .49962 L .34277 .49981 L F
0 0 0 r
.64074 .44242 m .6399 .44412 L .63784 .44518 L F
.64355 .43942 m .64255 .44085 L .64074 .44242 L F
.64255 .44085 m .6399 .44412 L .64074 .44242 L F
.349 0 .047 r
.22012 .5707 m .22522 .56821 L .22285 .57014 L F
.706 .643 .784 r
.38647 .57204 m .38634 .57565 L .38295 .57602 L F
0 0 .069 r
.34053 .50872 m .34035 .5108 L .33884 .51238 L F
0 0 .34 r
.33975 .51325 m .33884 .51238 L .34035 .5108 L F
.33975 .51325 m .33934 .51545 L .33884 .51238 L F
.212 .736 .823 r
.26644 .5225 m .26481 .523 L .26307 .52293 L F
.827 .431 0 r
.39609 .53983 m .39803 .5433 L .39717 .54116 L F
.755 .359 .302 r
.38955 .61671 m .3908 .61315 L .38655 .61262 L F
.244 0 0 r
.39147 .61463 m .3908 .61315 L .38955 .61671 L F
.39147 .61463 m .39255 .61273 L .3908 .61315 L F
0 0 0 r
.36861 .60425 m .36655 .60724 L .36753 .60623 L F
.881 .452 .064 r
.36742 .60503 m .36793 .60519 L .3679 .60556 L F
.199 .535 .925 r
.36742 .60503 m .36803 .60571 L .36753 .60623 L F
.675 .926 .972 r
.36753 .60623 m .36885 .60701 L .37101 .60584 L F
.36753 .60623 m .37101 .60584 L .37071 .60306 L F
.881 .452 .064 r
.36742 .60503 m .3679 .60556 L .36777 .60712 L F
.199 .535 .925 r
.36742 .60503 m .36806 .60568 L .36803 .60571 L F
.679 .735 .893 r
.36885 .60701 m .37217 .60767 L .37101 .60584 L F
0 .34 .76 r
.36885 .60701 m .37309 .60945 L .37217 .60767 L F
.929 .562 .298 r
.36894 .60657 m .36978 .60837 L .36849 .60615 L F
.675 .926 .972 r
.36753 .60623 m .37071 .60306 L .36861 .60425 L F
.929 .562 .298 r
.36894 .60657 m .36849 .60615 L .36793 .60519 L F
.199 .535 .925 r
.36798 .60576 m .3685 .60646 L .36753 .60623 L F
.36801 .60573 m .36809 .60585 L .36798 .60576 L F
.36809 .60585 m .3685 .60646 L .36798 .60576 L F
.517 .863 .992 r
.36753 .60623 m .36626 .60766 L .36885 .60701 L F
.876 .598 .513 r
.36978 .60837 m .36934 .61077 L .36809 .60585 L F
.36849 .60615 m .36809 .60585 L .36793 .60519 L F
.199 .535 .925 r
.36802 .60572 m .36894 .60657 L .3685 .60646 L F
.36802 .60572 m .3685 .60646 L .36801 .60573 L F
.876 .598 .513 r
.36978 .60837 m .36809 .60585 L .36849 .60615 L F
.929 .599 .145 r
.3679 .60556 m .36911 .60993 L .36777 .60712 L F
.36793 .60519 m .36809 .60585 L .3679 .60556 L F
.36809 .60585 m .36934 .61077 L .3679 .60556 L F
.199 .535 .925 r
.36806 .60568 m .36894 .60657 L .36802 .60572 L F
0 0 0 r
.36655 .60724 m .36626 .60766 L .36753 .60623 L F
.074 0 .336 r
.36861 .60425 m .37071 .60306 L .37091 .60033 L F
.881 .452 .064 r
.36742 .60503 m .36894 .60657 L .36793 .60519 L F
.843 .78 .791 r
.36856 .60246 m .36894 .60657 L .36742 .60503 L F
.578 .583 .821 r
.37071 .60306 m .37101 .60584 L .37428 .60455 L F
.496 .521 .813 r
.37156 .60409 m .36894 .60657 L .36856 .60246 L F
.914 .881 .788 r
.36856 .60246 m .36742 .60503 L .36518 .60312 L F
.745 .327 .257 r
.36918 .60576 m .36619 .60379 L .36777 .60712 L F
.926 .544 .158 r
.36518 .60312 m .36742 .60503 L .36777 .60712 L F
.745 .327 .257 r
.36619 .60379 m .36518 .60312 L .36777 .60712 L F
.929 .599 .145 r
.36911 .60993 m .36934 .61077 L .36777 .60712 L F
0 .383 .743 r
.22532 .61006 m .2249 .60963 L .22276 .60877 L F
0 .192 .632 r
.22532 .61006 m .22751 .61147 L .2249 .60963 L F
.724 .698 .825 r
.42167 .54284 m .41687 .54067 L .41943 .54071 L F
.379 0 0 r
.41943 .54071 m .42423 .54253 L .42167 .54284 L F
.635 .351 .47 r
.29758 .65398 m .29901 .65417 L .29708 .65135 L F
.457 .871 .729 r
.2376 .53382 m .23869 .53292 L .24106 .53191 L F
.804 .999 .797 r
.24106 .53191 m .24036 .53068 L .24287 .53059 L F
.24106 .53191 m .23869 .53292 L .24036 .53068 L F
.946 .947 .746 r
.32466 .61663 m .32548 .61222 L .32405 .61392 L F
.649 .467 .625 r
.68004 .36305 m .67639 .36569 L .67616 .36297 L F
.954 .605 .261 r
.32795 .66568 m .32949 .66695 L .32801 .66505 L F
.767 .914 .938 r
.32536 .66741 m .32949 .66695 L .32795 .66568 L F
.712 .79 .913 r
.32949 .66695 m .33171 .665 L .32801 .66505 L F
.411 .248 .548 r
.3456 .55633 m .34765 .55908 L .34713 .55575 L F
.3456 .55633 m .34548 .55979 L .34765 .55908 L F
.693 .771 .911 r
.57789 .40023 m .58126 .40165 L .5795 .40212 L F
.57789 .40023 m .58126 .40165 L .5795 .40212 L F
.68 .875 .491 r
.32371 .68395 m .32151 .6872 L .32215 .6857 L F
0 0 0 r
.32525 .68256 m .32371 .68395 L .32215 .6857 L F
.356 .358 .724 r
.40998 .50823 m .4104 .51152 L .4086 .51173 L F
.258 0 .006 r
.33493 .52991 m .33839 .52801 L .33609 .52875 L F
.806 .627 .07 r
.71466 .3275 m .71463 .32919 L .71443 .32676 L F
.756 .995 .826 r
.71466 .3275 m .71606 .32496 L .71734 .32521 L F
.71466 .3275 m .71475 .32641 L .71518 .32657 L F
.583 .25 .371 r
.71652 .32705 m .7175 .3297 L .71463 .32919 L F
.756 .995 .826 r
.71466 .3275 m .71443 .32676 L .71475 .32641 L F
0 0 0 r
.71459 .32631 m .71606 .32496 L .71443 .32676 L F
.53 .555 .825 r
.71463 .32919 m .7175 .3297 L .71459 .32631 L F
.743 .255 0 r
.71693 .32903 m .71642 .329 L .71463 .32637 L F
.7175 .3297 m .71463 .32637 L .71465 .32638 L F
.41 .244 .543 r
.71995 .32393 m .72015 .32649 L .71652 .32705 L F
.381 .147 .43 r
.72015 .32649 m .7175 .3297 L .71652 .32705 L F
.743 .255 0 r
.71465 .32638 m .71463 .32637 L .71459 .32631 L F
.978 .69 .309 r
.71642 .329 m .71508 .32686 L .71459 .32631 L F
.71642 .329 m .7153 .32935 L .71508 .32686 L F
.699 .963 .718 r
.71827 .32637 m .7157 .32895 L .71642 .329 L F
.7157 .32895 m .7153 .32935 L .71642 .329 L F
.743 .255 0 r
.7175 .3297 m .71642 .329 L .71693 .32903 L F
.756 .995 .826 r
.71518 .32657 m .71475 .32641 L .71606 .32496 L F
.223 0 0 r
.32001 .55229 m .32407 .5493 L .3206 .55052 L F
.32001 .55229 m .32212 .55195 L .32407 .5493 L F
.347 0 .063 r
.32407 .5493 m .32477 .55113 L .32641 .54979 L F
.32407 .5493 m .32212 .55195 L .32477 .55113 L F
.927 .552 .151 r
.41971 .58551 m .4189 .58658 L .41852 .58399 L F
.41971 .58551 m .42029 .58777 L .4189 .58658 L F
.891 .859 .804 r
.59323 .38084 m .59478 .38263 L .59711 .37881 L F
.987 .713 .371 r
.59711 .37881 m .59717 .38145 L .59478 .38263 L F
.631 .799 .963 r
.59323 .38084 m .59478 .38263 L .59717 .38145 L F
.568 .429 .651 r
.34832 .54344 m .34593 .54678 L .34548 .54455 L F
.34832 .54344 m .34593 .54678 L .34548 .54455 L F
0 .035 .535 r
.59156 .40723 m .5893 .40509 L .58792 .40369 L F
.911 .662 .55 r
.71247 .36305 m .70952 .36418 L .70885 .36219 L F
.71247 .36305 m .71315 .36568 L .70952 .36418 L F
.413 .176 .443 r
.71598 .36296 m .71315 .36568 L .71247 .36305 L F
.838 .826 .836 r
.66643 .33901 m .66791 .34068 L .66496 .34015 L F
.898 .79 .733 r
.66791 .34068 m .66427 .34268 L .66496 .34015 L F
.66791 .34068 m .66594 .3442 L .66427 .34268 L F
.812 .823 .859 r
.67078 .33761 m .66791 .34068 L .66643 .33901 L F
.392 .295 .625 r
.33353 .59503 m .33662 .59797 L .33743 .5963 L F
0 0 0 r
.33372 .59467 m .331 .59777 L .33199 .59673 L F
.33372 .59467 m .33199 .59673 L .33229 .5964 L F
.319 .804 .88 r
.33209 .59457 m .33372 .59467 L .33219 .59651 L F
.392 .295 .625 r
.33209 .59457 m .3332 .5954 L .33353 .59503 L F
.3332 .5954 m .33662 .59797 L .33353 .59503 L F
0 0 0 r
.33229 .5964 m .33199 .59673 L .33219 .59651 L F
.33219 .59651 m .331 .59777 L .33008 .60019 L F
0 0 .03 r
.34045 .5505 m .34225 .54954 L .34333 .54712 L F
.709 .356 .377 r
.34333 .54712 m .34573 .54966 L .34593 .54678 L F
.34333 .54712 m .34225 .54954 L .34573 .54966 L F
.16 .171 .622 r
.3843 .61405 m .38642 .61481 L .38634 .61271 L F
.3843 .61405 m .38478 .61675 L .38642 .61481 L F
.765 .847 .913 r
.38773 .57213 m .38634 .57565 L .38778 .5748 L F
.308 .302 .689 r
.38778 .5748 m .38634 .57565 L .38647 .57204 L F
.418 .052 .233 r
.35327 .63122 m .35099 .63011 L .35055 .63187 L F
.35055 .63187 m .35099 .63011 L .35327 .63122 L F
.709 .575 .702 r
.25308 .58833 m .25089 .59209 L .25008 .58893 L F
.711 .586 .715 r
.32849 .52783 m .33069 .53129 L .32637 .53098 L F
.728 .513 .6 r
.32989 .53399 m .32637 .53098 L .33069 .53129 L F
.625 .427 .595 r
.33069 .53129 m .33376 .5343 L .32989 .53399 L F
.984 .732 .339 r
.60992 .42488 m .61113 .42664 L .61106 .42914 L F
.491 0 0 r
.60882 .42862 m .61106 .42914 L .60852 .4281 L F
.60882 .42862 m .60773 .42625 L .60992 .42488 L F
.984 .732 .339 r
.60992 .42488 m .61106 .42914 L .61158 .42673 L F
0 0 .281 r
.61039 .42814 m .60882 .42862 L .60882 .4286 L F
.61019 .42676 m .60882 .4286 L .60992 .42488 L F
.61039 .42814 m .60882 .4286 L .61019 .42676 L F
.613 .059 0 r
.61123 .42537 m .61158 .42673 L .6113 .4254 L F
0 0 .281 r
.61039 .42814 m .60992 .42488 L .60816 .42392 L F
.613 .059 0 r
.60909 .42469 m .60992 .42488 L .61158 .42673 L F
.60816 .42392 m .60992 .42488 L .60909 .42469 L F
.976 .711 .304 r
.60997 .42272 m .61066 .42506 L .60992 .42488 L F
.61066 .42506 m .61113 .42664 L .60992 .42488 L F
.131 0 .379 r
.61134 .42152 m .60997 .42272 L .60992 .42488 L F
.125 0 .371 r
.61142 .41943 m .60997 .42272 L .61134 .42152 L F
.131 0 .379 r
.61134 .42152 m .60992 .42488 L .60816 .42392 L F
.613 .059 0 r
.60816 .42392 m .61073 .42603 L .61123 .42537 L F
.61073 .42603 m .61158 .42673 L .61123 .42537 L F
.565 .59 .837 r
.29153 .55334 m .29578 .55688 L .29419 .5531 L F
.511 .517 .799 r
.29419 .5531 m .29578 .55688 L .29785 .5559 L F
0 0 0 r
.29785 .5559 m .2941 .5585 L .29578 .55688 L F
.29578 .55688 m .2941 .5585 L .29785 .5559 L F
.861 .742 .226 r
.40787 .59379 m .40816 .59141 L .40796 .59049 L F
.42 .179 .441 r
.30167 .59828 m .30128 .60046 L .3039 .5976 L F
.665 .673 .848 r
.41755 .49963 m .41573 .50295 L .41397 .49863 L F
.649 .652 .84 r
.41755 .49963 m .41924 .50264 L .41573 .50295 L F
.74 .562 .652 r
.41924 .50264 m .41595 .5052 L .41573 .50295 L F
0 0 .536 r
.60272 .41858 m .60338 .41987 L .60113 .41655 L F
0 .181 .674 r
.60469 .42038 m .60338 .41987 L .60272 .41858 L F
.60469 .42038 m .60587 .42173 L .60338 .41987 L F
.126 .356 .818 r
.60663 .42346 m .60338 .41987 L .60587 .42173 L F
.712 .742 .876 r
.63508 .40122 m .63606 .3967 L .63382 .39993 L F
.63508 .40122 m .63859 .39941 L .63606 .3967 L F
.82 .648 .67 r
.55759 .4426 m .55909 .44551 L .5556 .44463 L F
.812 .512 .483 r
.55948 .44775 m .5556 .44463 L .55909 .44551 L F
.774 .656 .732 r
.70892 .28664 m .71007 .2908 L .70645 .28978 L F
0 0 0 r
.71257 .28691 m .71007 .2908 L .70892 .28664 L F
.71257 .28691 m .71176 .28833 L .71007 .2908 L F
.66 .115 0 r
.70986 .2917 m .71249 .29248 L .71007 .2908 L F
.70986 .2917 m .71007 .2908 L .71176 .28833 L F
.515 .222 .408 r
.36593 .57564 m .36547 .57796 L .368 .57749 L F
.526 .516 .788 r
.6566 .41308 m .65316 .41052 L .6568 .41089 L F
.263 0 .102 r
.6568 .41089 m .65935 .41156 L .6566 .41308 L F
.6568 .41089 m .65882 .41047 L .65935 .41156 L F
.564 .504 .746 r
.24987 .56238 m .25084 .56611 L .24859 .5664 L F
.639 .511 .691 r
.25084 .56611 m .24863 .56894 L .24859 .5664 L F
.412 .312 .632 r
.36552 .59074 m .36385 .59238 L .36137 .5903 L F
.36552 .59074 m .36646 .59532 L .36385 .59238 L F
0 0 .535 r
.36587 .59671 m .36385 .59238 L .36646 .59532 L F
.506 .173 .337 r
.36587 .59671 m .36917 .59821 L .36715 .59812 L F
.36587 .59671 m .36715 .59812 L .36437 .59799 L F
0 0 .535 r
.36587 .59671 m .36584 .59722 L .36544 .59624 L F
.36587 .59671 m .36544 .59624 L .36385 .59238 L F
.224 .745 .772 r
.70829 .34777 m .70591 .34838 L .70482 .3484 L F
.482 .552 .851 r
.26481 .63233 m .26675 .63581 L .26892 .6355 L F
0 0 0 r
.63487 .44813 m .63784 .44518 L .63625 .4466 L F
.63784 .44518 m .6399 .44412 L .63625 .4466 L F
.916 .857 .769 r
.40343 .56227 m .4019 .56504 L .40405 .56538 L F
.714 .396 0 r
.40453 .56717 m .40405 .56538 L .4019 .56504 L F
.40453 .56717 m .40503 .56841 L .40405 .56538 L F
.58 .463 .685 r
.35906 .56262 m .35639 .5603 L .35878 .5597 L F
.35906 .56262 m .35654 .56322 L .35639 .5603 L F
.068 .22 .714 r
.29758 .65398 m .29847 .65797 L .29639 .65805 L F
.819 .465 .386 r
.29639 .65805 m .29847 .65797 L .29636 .65997 L F
.687 .278 .264 r
.29847 .65797 m .30048 .66013 L .29636 .65997 L F
.748 .919 .949 r
.55582 .41306 m .5524 .41579 L .55135 .41424 L F
.725 .471 .542 r
.29711 .55281 m .30073 .55298 L .30089 .55028 L F
.461 .237 .487 r
.30089 .55028 m .30321 .54978 L .30385 .54688 L F
.38 .184 .484 r
.3028 .55213 m .30089 .55028 L .30321 .54978 L F
.3028 .55213 m .30073 .55298 L .30089 .55028 L F
.461 .237 .487 r
.30385 .54688 m .30321 .54978 L .30089 .55028 L F
.38 .184 .484 r
.3028 .55213 m .30089 .55028 L .30321 .54978 L F
.3028 .55213 m .30073 .55298 L .30089 .55028 L F
.461 .237 .487 r
.30385 .54688 m .30321 .54978 L .30089 .55028 L F
0 0 0 r
.30321 .54978 m .30519 .54649 L .30385 .54688 L F
.57 .464 .694 r
.30519 .54649 m .30321 .54978 L .30385 .54688 L F
0 0 .277 r
.6257 .42765 m .62478 .42668 L .62625 .4254 L F
.6257 .42765 m .62411 .42992 L .62478 .42668 L F
.84 .828 .836 r
.42573 .53871 m .4267 .54051 L .43068 .53678 L F
.42573 .53871 m .43068 .53678 L .42941 .53942 L F
.628 .35 .478 r
.43278 .53713 m .42941 .53942 L .43068 .53678 L F
.674 .626 .793 r
.37163 .63002 m .37446 .62944 L .37297 .62586 L F
.613 .381 .541 r
.37422 .63209 m .37163 .63002 L .37034 .63252 L F
.37422 .63209 m .37446 .62944 L .37163 .63002 L F
.637 .952 .752 r
.28615 .5282 m .284 .52915 L .28282 .5307 L F
.788 .992 .758 r
.2866 .52633 m .28615 .5282 L .28854 .52769 L F
.2866 .52633 m .284 .52915 L .28615 .5282 L F
0 0 0 r
.3426 .50612 m .34053 .50872 L .34414 .50691 L F
.3426 .50612 m .34095 .50825 L .34053 .50872 L F
0 0 .022 r
.34095 .50825 m .34035 .5108 L .34053 .50872 L F
.505 .533 .819 r
.30031 .521 m .30187 .52489 L .30378 .52387 L F
.614 .551 .76 r
.43113 .51486 m .43211 .51846 L .42884 .51836 L F
.584 .26 .387 r
.43413 .58558 m .43353 .58765 L .43087 .58753 L F
.539 .322 .534 r
.43651 .58441 m .43353 .58765 L .43413 .58558 L F
.73 .695 .817 r
.236 .58802 m .24005 .58881 L .23901 .5871 L F
.693 .681 .834 r
.23901 .5871 m .24005 .58881 L .2425 .58741 L F
.65 .897 .565 r
.64355 .43942 m .64615 .43631 L .6449 .43743 L F
.592 .81 .41 r
.6449 .43743 m .64255 .44085 L .64355 .43942 L F
.373 .108 .378 r
.34396 .64821 m .34214 .64921 L .34132 .65134 L F
.903 .934 .823 r
.33524 .61684 m .33132 .61954 L .33499 .61987 L F
.728 .513 .6 r
.32989 .53399 m .32567 .53418 L .32637 .53098 L F
0 0 0 r
.73769 .33505 m .73625 .33697 L .73856 .33398 L F
.73769 .33505 m .73649 .33686 L .73625 .33697 L F
0 0 .023 r
.35606 .57846 m .35536 .58069 L .35405 .58205 L F
0 0 .177 r
.35457 .58291 m .35405 .58205 L .35536 .58069 L F
.35457 .58291 m .35425 .58476 L .35405 .58205 L F
.344 .01 .247 r
.26293 .54706 m .26007 .54951 L .2604 .54716 L F
.104 .024 .472 r
.41866 .53888 m .41671 .53751 L .41901 .53688 L F
.41866 .53888 m .41687 .54067 L .41671 .53751 L F
.503 .229 .432 r
.58258 .44887 m .58247 .45102 L .57974 .45146 L F
.584 .312 .469 r
.58516 .44857 m .58247 .45102 L .58258 .44887 L F
.995 .867 .586 r
.39681 .59726 m .39842 .59814 L .39753 .60076 L F
.564 .817 .445 r
.40122 .68582 m .40057 .68666 L .40285 .68376 L F
0 0 .223 r
.40122 .68582 m .40032 .68948 L .40057 .68666 L F
.667 .814 .954 r
.2846 .52111 m .28057 .5208 L .28287 .52013 L F
.525 .836 .999 r
.28694 .52043 m .2846 .52111 L .28287 .52013 L F
.958 .669 .235 r
.40638 .57466 m .4076 .57848 L .40783 .57596 L F
.199 0 0 r
.28935 .56191 m .29048 .56215 L .29314 .55962 L F
.675 .552 .707 r
.29513 .55969 m .2937 .56166 L .29332 .56055 L F
.535 .844 .535 r
.29315 .56006 m .29332 .56055 L .29325 .56282 L F
.678 .195 .095 r
.29325 .56282 m .28935 .56191 L .28954 .56524 L F
.29325 .56282 m .29085 .56388 L .28935 .56191 L F
.074 0 .019 r
.29332 .56055 m .29085 .56388 L .29325 .56282 L F
.675 .552 .707 r
.2937 .56166 m .29257 .56321 L .29332 .56055 L F
.535 .844 .535 r
.29314 .55962 m .29332 .56055 L .29315 .56006 L F
.29314 .55962 m .2936 .55902 L .29332 .56055 L F
.29314 .55962 m .29048 .56215 L .2936 .55902 L F
.443 .879 .844 r
.2376 .53382 m .23644 .53393 L .23869 .53292 L F
.193 .081 .488 r
.33068 .52154 m .3325 .51785 L .32991 .51819 L F
.33068 .52154 m .33256 .52053 L .3325 .51785 L F
.518 .273 .484 r
.32963 .52344 m .33256 .52053 L .33068 .52154 L F
.239 .418 .838 r
.4351 .57278 m .43199 .56861 L .43689 .56959 L F
0 0 .372 r
.43845 .56513 m .43689 .56959 L .43589 .56567 L F
.43845 .56513 m .43838 .5683 L .43689 .56959 L F
.25 .421 .837 r
.43838 .5683 m .43989 .57141 L .43689 .56959 L F
.321 .138 .469 r
.30431 .59466 m .30587 .59652 L .30605 .59393 L F
.30431 .59466 m .3039 .5976 L .30587 .59652 L F
.114 .048 .497 r
.20028 .57569 m .20207 .57698 L .20226 .57441 L F
.20028 .57569 m .20045 .57844 L .20207 .57698 L F
.227 0 0 r
.38016 .67209 m .37878 .67319 L .37604 .67321 L F
0 0 0 r
.38098 .67209 m .38016 .67209 L .38281 .67329 L F
.38098 .67209 m .37878 .67319 L .38016 .67209 L F
.16 0 .222 r
.29337 .6361 m .29077 .63924 L .29272 .63875 L F
.407 .163 .428 r
.29568 .63524 m .29337 .6361 L .29272 .63875 L F
.748 .431 .447 r
.43448 .54586 m .43731 .54468 L .43445 .5442 L F
.43448 .54586 m .43679 .54627 L .43725 .54471 L F
.788 .774 .267 r
.43619 .54899 m .43817 .54652 L .43448 .54586 L F
.349 .744 .985 r
.43448 .54586 m .43681 .54554 L .43817 .54652 L F
.788 .774 .267 r
.4365 .54727 m .436 .54867 L .43681 .54554 L F
.43619 .54899 m .43606 .54877 L .4365 .54727 L F
.43606 .54877 m .436 .54867 L .4365 .54727 L F
.748 .431 .447 r
.43725 .54471 m .43817 .54652 L .43731 .54468 L F
.43679 .54627 m .43817 .54652 L .43725 .54471 L F
0 .04 .608 r
.6089 .41199 m .60872 .41367 L .61039 .41565 L F
.605 .311 .444 r
.68267 .36304 m .68657 .36188 L .6855 .3652 L F
.544 .244 .408 r
.68657 .36188 m .68831 .36475 L .6855 .3652 L F
.68657 .36188 m .68903 .36197 L .68831 .36475 L F
.687 .568 .716 r
.64789 .38512 m .64535 .38822 L .64541 .38586 L F
.637 .496 .674 r
.64789 .38512 m .64801 .38721 L .64535 .38822 L F
.835 .596 .578 r
.55134 .44182 m .54911 .43838 L .55155 .43927 L F
.646 .925 .644 r
.61944 .39906 m .61792 .4012 L .62116 .39766 L F
.586 .542 .772 r
.61792 .4012 m .62158 .40097 L .62116 .39766 L F
.175 0 0 r
.61792 .4012 m .61951 .40144 L .61856 .40371 L F
.61792 .4012 m .62143 .40098 L .61951 .40144 L F
.62143 .40098 m .62158 .40097 L .61951 .40144 L F
0 0 .458 r
.61856 .40371 m .61896 .40157 L .61951 .40144 L F
.61896 .40157 m .61944 .39906 L .61951 .40144 L F
.61856 .40371 m .61792 .4012 L .61944 .39906 L F
0 .358 .821 r
.34414 .50691 m .34551 .50672 L .3426 .50612 L F
.506 .492 .776 r
.65468 .38979 m .65349 .39407 L .65233 .39055 L F
.65468 .38979 m .65579 .39376 L .65349 .39407 L F
.547 .351 .567 r
.56531 .42969 m .56821 .42946 L .56793 .42733 L F
.56531 .42969 m .56821 .42946 L .56793 .42733 L F
.901 .489 .111 r
.59764 .39459 m .60018 .39869 L .59871 .39675 L F
.844 .396 .146 r
.60018 .39869 m .59805 .39877 L .59871 .39675 L F
.60018 .39869 m .6013 .40049 L .59805 .39877 L F
.246 0 0 r
.26903 .62248 m .27131 .62213 L .27298 .62047 L F
.281 0 0 r
.27298 .62047 m .27377 .62171 L .27449 .62156 L F
.27298 .62047 m .27131 .62213 L .27377 .62171 L F
.302 0 0 r
.27298 .62047 m .27449 .62156 L .27572 .62025 L F
.378 .145 .43 r
.29272 .63875 m .29077 .63924 L .29039 .64201 L F
.676 .841 .963 r
.33981 .6549 m .33747 .65608 L .33609 .65478 L F
.689 .441 .543 r
.39211 .59407 m .38947 .59099 L .39183 .59143 L F
.39211 .59407 m .39013 .59458 L .38947 .59099 L F
.738 .991 .822 r
.38451 .6503 m .38276 .65216 L .38344 .6505 L F
.454 .743 .99 r
.38344 .6505 m .38276 .65216 L .38134 .65102 L F
.38344 .6505 m .38276 .65216 L .38098 .65074 L F
0 0 0 r
.38531 .65003 m .38344 .6505 L .38122 .65106 L F
.203 .727 .727 r
.38451 .6503 m .38593 .64987 L .38737 .6483 L F
.38451 .6503 m .38344 .6505 L .38593 .64987 L F
0 0 0 r
.38593 .64987 m .38344 .6505 L .38531 .65003 L F
.454 .743 .99 r
.38344 .6505 m .38134 .65102 L .38098 .65074 L F
.891 .859 .804 r
.59323 .38084 m .59711 .37881 L .59717 .38145 L F
.492 .292 .536 r
.59711 .37881 m .59717 .38145 L .5997 .37821 L F
.978 .678 .346 r
.40519 .57093 m .40617 .56942 L .40503 .56841 L F
.40519 .57093 m .40645 .57183 L .40617 .56942 L F
.115 .628 .893 r
.34509 .49962 m .34763 .49966 L .34927 .50058 L F
.003 .558 .817 r
.34763 .49966 m .35191 .50063 L .34927 .50058 L F
.107 .478 .896 r
.35191 .50063 m .35392 .50144 L .35333 .50246 L F
.142 .524 .917 r
.35392 .50144 m .3555 .50304 L .35333 .50246 L F
.189 .665 .933 r
.21834 .59092 m .22284 .592 L .22077 .59238 L F
.781 .351 0 r
.59764 .39459 m .59765 .39567 L .59595 .39356 L F
.59764 .39459 m .59871 .39675 L .59765 .39567 L F
.824 .346 .005 r
.32524 .55922 m .32743 .56194 L .32865 .5623 L F
.436 .542 .865 r
.32982 .5533 m .33176 .55512 L .32792 .55337 L F
.32982 .5533 m .33176 .55512 L .32792 .55337 L F
.508 .562 .845 r
.32982 .5533 m .33056 .55462 L .33176 .55512 L F
.33056 .55462 m .33171 .55669 L .33176 .55512 L F
.551 .356 .569 r
.33209 .54918 m .33239 .55449 L .32982 .5533 L F
.739 .5 .567 r
.33336 .55414 m .33239 .55449 L .33209 .54918 L F
.197 .468 .887 r
.33239 .55449 m .33281 .55454 L .32982 .5533 L F
.315 .455 .842 r
.33281 .55454 m .33227 .5556 L .32982 .5533 L F
.3314 .55511 m .33157 .55554 L .33056 .55462 L F
.33157 .55554 m .33161 .55651 L .33056 .55462 L F
.81 .695 .738 r
.3314 .55511 m .32743 .56194 L .3261 .55491 L F
.33176 .55512 m .33157 .55541 L .3314 .55511 L F
.315 .455 .842 r
.33156 .55539 m .33157 .55554 L .3314 .55511 L F
.81 .695 .738 r
.33157 .55541 m .32743 .56194 L .3314 .55511 L F
.315 .455 .842 r
.33153 .55518 m .33156 .55539 L .3314 .55511 L F
.33157 .55554 m .33171 .55669 L .33161 .55651 L F
.934 .93 .776 r
.32865 .5623 m .32743 .56194 L .33157 .55541 L F
.33157 .55554 m .33157 .55541 L .33176 .55512 L F
.32865 .5623 m .33157 .55541 L .33157 .55554 L F
.32865 .5623 m .33157 .55554 L .33171 .55669 L F
.33157 .55554 m .33176 .55512 L .33171 .55669 L F
.315 .455 .842 r
.33227 .5556 m .33171 .55669 L .33153 .55518 L F
.664 .198 .136 r
.33176 .55512 m .3314 .55511 L .33056 .55462 L F
.315 .455 .842 r
.33227 .5556 m .33056 .55462 L .32982 .5533 L F
.664 .198 .136 r
.33056 .55462 m .3261 .55491 L .3278 .55347 L F
.3314 .55511 m .3261 .55491 L .33056 .55462 L F
.33176 .55512 m .3278 .55347 L .32792 .55337 L F
.349 .502 .87 r
.31981 .68817 m .31999 .69021 L .31809 .68976 L F
.31981 .68817 m .31999 .69021 L .31809 .68976 L F
.721 .524 .623 r
.68004 .36305 m .68267 .36304 L .68015 .36579 L F
.678 .461 .584 r
.68267 .36304 m .68278 .36563 L .68015 .36579 L F
.605 .311 .444 r
.68267 .36304 m .6855 .3652 L .68278 .36563 L F
.568 .937 .897 r
.395 .64962 m .39144 .65081 L .39393 .64794 L F
.143 .26 .726 r
.39701 .64985 m .395 .64962 L .39393 .64794 L F
.39701 .64985 m .39687 .65151 L .395 .64962 L F
.151 .216 .677 r
.37446 .58442 m .37523 .58815 L .37688 .58664 L F
.368 .586 .927 r
.37523 .58815 m .37742 .58855 L .37688 .58664 L F
.726 .67 .795 r
.65969 .39443 m .6573 .39789 L .65579 .39376 L F
.619 .522 .722 r
.65969 .39443 m .66021 .3968 L .6573 .39789 L F
.776 .583 .638 r
.6733 .35033 m .67166 .35329 L .66933 .34991 L F
.6733 .35033 m .67332 .35298 L .67166 .35329 L F
.543 .481 .737 r
.287 .56258 m .28791 .56641 L .28954 .56524 L F
.754 .968 .93 r
.36305 .65499 m .3673 .65271 L .3656 .65445 L F
.95 .952 .724 r
.3656 .65445 m .3673 .65271 L .36767 .65058 L F
.581 .36 .546 r
.58363 .439 m .58664 .43592 L .58351 .43569 L F
.58363 .439 m .58646 .43897 L .58664 .43592 L F
.583 .468 .688 r
.58646 .43897 m .58872 .43524 L .58664 .43592 L F
0 .441 .703 r
.38812 .66131 m .38782 .66128 L .38627 .66029 L F
.38812 .66131 m .39033 .66186 L .38782 .66128 L F
.95 .826 .688 r
.35749 .51564 m .35586 .51783 L .3567 .5144 L F
0 0 .089 r
.73106 .34576 m .729 .34986 L .73013 .34772 L F
.112 0 .09 r
.38244 .59381 m .38257 .59173 L .38227 .59375 L F
.38244 .59381 m .38513 .59069 L .38257 .59173 L F
.349 0 .047 r
.22012 .5707 m .2234 .57067 L .22522 .56821 L F
.381 0 .157 r
.22455 .56931 m .22012 .5707 L .22018 .56805 L F
.22471 .56936 m .2244 .56945 L .22455 .56931 L F
.2244 .56945 m .22012 .5707 L .22455 .56931 L F
0 0 0 r
.22522 .56821 m .22409 .56974 L .2244 .56945 L F
.22465 .56914 m .2244 .56945 L .22455 .56931 L F
.22522 .56821 m .2244 .56945 L .22465 .56914 L F
.381 0 .157 r
.2244 .56945 m .2234 .57067 L .22012 .5707 L F
.22471 .56936 m .2234 .57067 L .2244 .56945 L F
.67 .62 .791 r
.22201 .56431 m .22464 .56922 L .22018 .56805 L F
.22464 .56922 m .22471 .56936 L .22455 .56931 L F
.22464 .56922 m .22455 .56931 L .22018 .56805 L F
.551 .565 .821 r
.22624 .56784 m .22471 .56936 L .22464 .56922 L F
0 0 0 r
.22603 .56791 m .22464 .56922 L .22608 .5679 L F
.22464 .56922 m .22467 .5692 L .22608 .5679 L F
.22522 .56821 m .22455 .56931 L .22603 .56791 L F
.551 .565 .821 r
.22624 .56784 m .22464 .56922 L .22201 .56431 L F
0 0 0 r
.22464 .56922 m .22455 .56931 L .22467 .5692 L F
.22624 .56784 m .2234 .57067 L .22471 .56936 L F
.22608 .5679 m .2234 .57067 L .22624 .56784 L F
.22409 .56974 m .2234 .57067 L .22608 .5679 L F
.104 .087 .552 r
.30603 .61258 m .30655 .61562 L .30465 .61564 L F
.078 0 .004 r
.30655 .61562 m .30334 .61837 L .30465 .61564 L F
.716 .443 .512 r
.3957 .5938 m .39211 .59407 L .39183 .59143 L F
.612 .473 .668 r
.32416 .56885 m .32191 .57205 L .3216 .56934 L F
.712 .765 .894 r
.37332 .65525 m .37458 .65531 L .37495 .65202 L F
.18 .264 .714 r
.37495 .65202 m .37458 .65531 L .37659 .65303 L F
.611 .18 .199 r
.35185 .71451 m .35609 .71369 L .35415 .7165 L F
.381 0 0 r
.35652 .71581 m .35831 .71478 L .36071 .71551 L F
.392 .788 .987 r
.35652 .71581 m .359 .71554 L .35825 .71545 L F
.54 0 0 r
.35609 .71369 m .35652 .71581 L .35431 .71628 L F
.35609 .71369 m .35831 .71478 L .35652 .71581 L F
.392 .788 .987 r
.35652 .71581 m .35825 .71545 L .35505 .71506 L F
.54 0 0 r
.35431 .71628 m .35652 .71581 L .35415 .7165 L F
.438 .018 .144 r
.69182 .36015 m .69614 .3588 L .69445 .36115 L F
.42 0 0 r
.69614 .3588 m .69714 .36047 L .69445 .36115 L F
.69614 .3588 m .69827 .35896 L .69714 .36047 L F
0 0 .381 r
.62489 .43148 m .62411 .42992 L .6257 .42765 L F
.62489 .43148 m .62412 .43248 L .62411 .42992 L F
.692 .651 .805 r
.64422 .38246 m .64541 .38586 L .64137 .3852 L F
.706 .649 .791 r
.64653 .38119 m .64541 .38586 L .64422 .38246 L F
.64653 .38119 m .64789 .38512 L .64541 .38586 L F
.847 .503 0 r
.58003 .39973 m .58126 .40165 L .58181 .40379 L F
.295 .647 .968 r
.58428 .40183 m .58126 .40165 L .58003 .39973 L F
.505 0 0 r
.58521 .4035 m .58126 .40165 L .58428 .40183 L F
.035 0 0 r
.32792 .55337 m .3261 .55491 L .32468 .55492 L F
.41 .244 .543 r
.71995 .32393 m .71652 .32705 L .71734 .32521 L F
.769 .571 .63 r
.59529 .41601 m .60001 .41634 L .59903 .4196 L F
.736 .604 .71 r
.57918 .41791 m .57953 .42003 L .57768 .42112 L F
.725 .579 .691 r
.57953 .42003 m .57742 .42384 L .57768 .42112 L F
.365 .159 .461 r
.57959 .42215 m .57742 .42384 L .57953 .42003 L F
.553 .477 .723 r
.58184 .41682 m .57953 .42003 L .57918 .41791 L F
.612 .557 .768 r
.58184 .41682 m .58275 .41994 L .57953 .42003 L F
.843 .404 .183 r
.37675 .54869 m .37821 .5511 L .38015 .54962 L F
0 0 .405 r
.38015 .54962 m .38076 .54852 L .38006 .54535 L F
.621 .903 .606 r
.38015 .54962 m .37821 .5511 L .38076 .54852 L F
.21 .547 .93 r
.61723 .44759 m .61876 .44958 L .62177 .44996 L F
.775 .968 .672 r
.45026 .56917 m .44772 .57239 L .44852 .57042 L F
.657 .71 .887 r
.44572 .57024 m .44748 .57214 L .44225 .57082 L F
.763 .937 .592 r
.44688 .5732 m .44748 .57214 L .44852 .57042 L F
.707 .723 .862 r
.44852 .57042 m .44748 .57214 L .44572 .57024 L F
.763 .937 .592 r
.44748 .57214 m .44819 .5709 L .44852 .57042 L F
.44772 .57239 m .44688 .5732 L .44852 .57042 L F
.707 .723 .862 r
.44852 .57042 m .44751 .57217 L .44748 .57214 L F
.657 .71 .887 r
.44748 .57214 m .44751 .57217 L .44747 .57216 L F
.44748 .57214 m .44747 .57216 L .44225 .57082 L F
.667 .566 .732 r
.44607 .57397 m .44225 .57082 L .44747 .57216 L F
.763 .937 .592 r
.44688 .5732 m .44607 .57397 L .44747 .57216 L F
.667 .566 .732 r
.44607 .57397 m .44747 .57216 L .44751 .57217 L F
.763 .937 .592 r
.44747 .57216 m .44607 .57397 L .44819 .5709 L F
.753 .317 .218 r
.44772 .57239 m .44981 .57469 L .44607 .57397 L F
.754 .956 .649 r
.44845 .57077 m .44772 .57239 L .45026 .56917 L F
.088 .242 .728 r
.44845 .57077 m .44981 .57469 L .44772 .57239 L F
.346 0 0 r
.37773 .51545 m .38206 .5173 L .37998 .51713 L F
.294 0 0 r
.24308 .57714 m .24573 .57751 L .24386 .57699 L F
.635 .964 .882 r
.33695 .55848 m .33197 .56177 L .33626 .56007 L F
.77 .95 .622 r
.22811 .56626 m .22855 .56456 L .22956 .5669 L F
.782 .638 .703 r
.25296 .55949 m .25399 .56287 L .24987 .56238 L F
.706 .511 .623 r
.24987 .56238 m .25204 .56342 L .25212 .56309 L F
.176 .241 .692 r
.25325 .56345 m .25212 .56309 L .25399 .56287 L F
.25212 .56309 m .24987 .56238 L .25172 .5626 L F
.25212 .56309 m .25172 .5626 L .25399 .56287 L F
0 0 0 r
.25525 .55922 m .25399 .56287 L .25296 .55949 L F
.25525 .55922 m .2545 .56219 L .25399 .56287 L F
.366 .187 .502 r
.25296 .55949 m .25212 .56309 L .2545 .56219 L F
.25212 .56309 m .25204 .56342 L .25228 .5633 L F
.64 .245 .28 r
.24987 .56238 m .25201 .56443 L .25204 .56342 L F
.089 0 .019 r
.25204 .56342 m .25201 .56443 L .25228 .5633 L F
.176 .241 .692 r
.25201 .56443 m .24987 .56238 L .25232 .56316 L F
.25201 .56443 m .25232 .56316 L .25325 .56345 L F
.089 0 .019 r
.25228 .5633 m .25201 .56443 L .2545 .56219 L F
.366 .187 .502 r
.25212 .56309 m .25228 .5633 L .2545 .56219 L F
.706 .511 .623 r
.24987 .56238 m .25212 .56309 L .25296 .55949 L F
.555 .877 .601 r
.2545 .56219 m .25201 .56443 L .25399 .56287 L F
.533 .166 .289 r
.34895 .53229 m .34725 .53186 L .34846 .5301 L F
0 .386 .773 r
.28282 .5307 m .27918 .52895 L .28019 .52962 L F
.28282 .5307 m .2816 .52991 L .27918 .52895 L F
.189 .031 .422 r
.28019 .52962 m .2816 .52991 L .28282 .5307 L F
.28019 .52962 m .27992 .53338 L .2816 .52991 L F
.946 .711 .244 r
.42622 .56096 m .42698 .5596 L .42397 .5589 L F
.42622 .56096 m .42692 .56246 L .42698 .5596 L F
.759 .995 .861 r
.22171 .58551 m .22131 .58717 L .22369 .58623 L F
.302 0 .106 r
.37047 .5644 m .36963 .5628 L .37201 .56335 L F
.37047 .5644 m .36855 .56492 L .36963 .5628 L F
.834 .996 .763 r
.31839 .65 m .31959 .64904 L .32019 .64769 L F
0 0 .088 r
.37101 .56921 m .37209 .56888 L .37324 .56589 L F
.318 .111 .433 r
.72008 .29517 m .71767 .29825 L .71751 .29614 L F
.949 .909 .746 r
.33208 .54082 m .33252 .53597 L .33307 .5364 L F
.33208 .54082 m .33054 .53971 L .33252 .53597 L F
.95 .815 .676 r
.33208 .54082 m .32929 .54183 L .33054 .53971 L F
.33208 .54082 m .33062 .54294 L .32929 .54183 L F
.552 .635 .887 r
.32997 .5447 m .3325 .54904 L .33485 .54801 L F
.097 0 0 r
.33229 .54913 m .33485 .54801 L .3325 .54904 L F
.719 .887 .958 r
.33209 .54918 m .32889 .54914 L .33067 .55024 L F
.722 .467 .54 r
.32852 .5463 m .33183 .54858 L .32997 .5447 L F
.33183 .54858 m .3325 .54904 L .33221 .54855 L F
.33183 .54858 m .33221 .54855 L .32997 .5447 L F
.521 .823 1 r
.3303 .55001 m .32641 .54979 L .32889 .54914 L F
.33067 .55024 m .32995 .55017 L .3303 .55001 L F
.32995 .55017 m .32641 .54979 L .3303 .55001 L F
.551 .356 .569 r
.33209 .54918 m .32982 .5533 L .32889 .54914 L F
.097 0 0 r
.33002 .55006 m .33197 .54979 L .33424 .54838 L F
.33389 .54841 m .33424 .54838 L .33485 .54801 L F
.143 0 .03 r
.32889 .54914 m .33002 .55006 L .3325 .54904 L F
.097 0 0 r
.33002 .55006 m .33414 .54831 L .33229 .54913 L F
.33414 .54831 m .33485 .54801 L .33229 .54913 L F
.33002 .55006 m .33424 .54838 L .33389 .54841 L F
.612 .473 .668 r
.32416 .56885 m .32533 .57163 L .32191 .57205 L F
.571 .425 .644 r
.32494 .57466 m .32191 .57205 L .32533 .57163 L F
.32494 .57466 m .32239 .57534 L .32191 .57205 L F
0 0 .142 r
.24463 .5399 m .2427 .5429 L .24241 .54034 L F
0 0 0 r
.36827 .63445 m .36654 .63926 L .36922 .6387 L F
.575 .383 .584 r
.36556 .64456 m .36922 .6387 L .36654 .63926 L F
.88 .986 .819 r
.38131 .57218 m .37872 .57534 L .37939 .57468 L F
.613 .393 .558 r
.37876 .57811 m .37939 .57468 L .37872 .57534 L F
.37876 .57811 m .38145 .57909 L .37939 .57468 L F
0 0 0 r
.37939 .57468 m .38486 .57137 L .38131 .57218 L F
.064 .124 .615 r
.37939 .57468 m .38225 .57448 L .38292 .57352 L F
.3804 .57683 m .38145 .57909 L .38169 .57768 L F
.467 0 0 r
.384 .57791 m .38225 .57448 L .38145 .57909 L F
.384 .57791 m .38145 .57909 L .38034 .57959 L F
.403 .847 .748 r
.384 .57791 m .38034 .57959 L .38286 .57869 L F
.332 .173 .509 r
.37876 .57811 m .38034 .57959 L .38145 .57909 L F
.467 0 0 r
.38245 .57818 m .38257 .5789 L .37968 .57866 L F
.384 .57791 m .38305 .57857 L .38245 .57818 L F
.38305 .57857 m .38257 .5789 L .38245 .57818 L F
.064 .124 .615 r
.37939 .57468 m .3804 .57683 L .38225 .57448 L F
.3804 .57683 m .38169 .57768 L .38225 .57448 L F
.424 0 .115 r
.36234 .57537 m .35776 .57747 L .35973 .5765 L F
.851 .975 .667 r
.34099 .55204 m .34225 .54954 L .34059 .55158 L F
.34073 .55257 m .34072 .5522 L .34225 .54954 L F
.696 .187 .02 r
.34321 .55327 m .34072 .5522 L .34073 .55257 L F
.3414 .55249 m .34147 .55413 L .34072 .5522 L F
.34321 .55327 m .34242 .55366 L .3414 .55249 L F
.34242 .55366 m .34147 .55413 L .3414 .55249 L F
.851 .975 .667 r
.34059 .55158 m .34225 .54954 L .34045 .5505 L F
.34073 .55257 m .34099 .55204 L .34059 .55158 L F
.567 .918 .961 r
.34174 .63807 m .3408 .63903 L .33908 .63937 L F
.34174 .63807 m .3408 .63903 L .33908 .63937 L F
0 .312 .803 r
.60277 .39231 m .60105 .39138 L .60081 .38955 L F
.213 .502 .906 r
.60393 .39318 m .60105 .39138 L .60277 .39231 L F
0 .24 .745 r
.2321 .60609 m .23568 .61011 L .23338 .60796 L F
.566 .815 .437 r
.64615 .43631 m .64869 .43301 L .64762 .43438 L F
.614 .883 .559 r
.6449 .43743 m .64615 .43631 L .64762 .43438 L F
.864 .467 0 r
.39488 .53846 m .39504 .53683 L .39342 .53577 L F
.39488 .53846 m .39609 .53983 L .39504 .53683 L F
.934 .869 .75 r
.69123 .30934 m .68833 .31097 L .6897 .30783 L F
.69123 .30934 m .69023 .31159 L .68833 .31097 L F
.825 .838 .858 r
.69392 .30631 m .69123 .30934 L .6897 .30783 L F
.433 .238 .514 r
.3209 .58434 m .3211 .58768 L .31866 .58835 L F
.293 .248 .636 r
.32257 .58097 m .32282 .58348 L .3209 .58434 L F
.481 .273 .519 r
.3239 .58677 m .3209 .58434 L .32282 .58348 L F
.3239 .58677 m .3211 .58768 L .3209 .58434 L F
.915 .926 .548 r
.7029 .34217 m .70427 .34078 L .70339 .33948 L F
.736 .604 .71 r
.57918 .41791 m .57546 .41905 L .57845 .41575 L F
.57918 .41791 m .57768 .42112 L .57546 .41905 L F
.447 .529 .848 r
.5807 .41552 m .57918 .41791 L .57845 .41575 L F
.553 .477 .723 r
.58184 .41682 m .57918 .41791 L .5807 .41552 L F
.986 .89 .635 r
.30016 .52861 m .29937 .52984 L .29999 .52667 L F
0 0 0 r
.29937 .52984 m .3001 .52953 L .30016 .52861 L F
.084 .356 .826 r
.29987 .52819 m .30042 .52938 L .29937 .52984 L F
.30042 .52938 m .30122 .53108 L .29937 .52984 L F
0 0 0 r
.29937 .52984 m .30008 .52978 L .3001 .52953 L F
.64762 .43438 m .64869 .43301 L .65025 .43108 L F
.74042 .3319 m .73769 .33505 L .73856 .33398 L F
.746 .713 .821 r
.4351 .57278 m .43051 .57346 L .43351 .57215 L F
.239 .418 .838 r
.4351 .57278 m .43594 .57078 L .43199 .56861 L F
.676 .916 .974 r
.43351 .57215 m .43594 .57078 L .4351 .57278 L F
.733 .564 .663 r
.66943 .34717 m .66697 .35023 L .66534 .34676 L F
.66943 .34717 m .66933 .34991 L .66697 .35023 L F
.676 .799 .341 r
.65243 .41187 m .65316 .41052 L .65148 .41406 L F
.938 .757 .284 r
.6526 .40915 m .65316 .41052 L .65243 .41187 L F
.174 0 .287 r
.31122 .6033 m .30951 .60428 L .31188 .60097 L F
.287 .011 .308 r
.31077 .60553 m .30951 .60428 L .31122 .6033 L F
.31077 .60553 m .30872 .60642 L .30951 .60428 L F
.603 .622 .843 r
.62057 .38178 m .61653 .37855 L .61921 .37793 L F
.702 .701 .846 r
.62328 .37891 m .62057 .38178 L .61921 .37793 L F
.646 .608 .797 r
.62328 .37891 m .62454 .3827 L .62057 .38178 L F
.633 .568 .764 r
.3676 .54484 m .36663 .54993 L .36238 .55034 L F
.656 .473 .625 r
.36663 .54993 m .36248 .55253 L .36238 .55034 L F
0 0 .404 r
.61586 .44501 m .61662 .44588 L .61481 .4441 L F
.61586 .44501 m .61723 .44759 L .61662 .44588 L F
.174 .192 .639 r
.38642 .61481 m .38478 .61675 L .38678 .61888 L F
.359 .222 .555 r
.38478 .61675 m .38487 .61865 L .38678 .61888 L F
.078 0 .15 r
.31836 .55314 m .32001 .55229 L .3206 .55052 L F
.461 .561 .871 r
.31836 .55314 m .32274 .55648 L .32001 .55229 L F
.794 .508 .503 r
.58181 .40379 m .58521 .4035 L .58519 .4068 L F
.349 .614 .949 r
.58792 .40369 m .58521 .4035 L .58428 .40183 L F
.224 .615 .953 r
.3596 .68335 m .36202 .68396 L .36032 .68228 L F
.3596 .68335 m .36202 .68396 L .36032 .68228 L F
.294 .077 .404 r
.35055 .63187 m .34848 .63261 L .3481 .63521 L F
.35055 .63187 m .34848 .63261 L .3481 .63521 L F
.428 .848 .691 r
.24952 .53682 m .24843 .53766 L .25096 .5372 L F
.24952 .53682 m .24597 .53885 L .24843 .53766 L F
.41 .254 .558 r
.43878 .57832 m .4389 .58128 L .43676 .58198 L F
.086 0 .198 r
.4389 .58128 m .43651 .58441 L .43676 .58198 L F
.415 .236 .528 r
.35395 .59697 m .35583 .59362 L .35329 .59422 L F
0 .366 .814 r
.4249 .55464 m .42486 .55551 L .42268 .55331 L F
.4249 .55464 m .42554 .55568 L .42486 .55551 L F
.525 .065 .103 r
.45262 .56995 m .45026 .56917 L .45286 .57048 L F
.45262 .56995 m .4521 .57005 L .45026 .56917 L F
.602 .484 .69 r
.45393 .56986 m .45325 .57019 L .45262 .56995 L F
.573 .617 .858 r
.45325 .57019 m .45262 .56995 L .45286 .57048 L F
.602 .484 .69 r
.45325 .57019 m .45308 .57027 L .45262 .56995 L F
.573 .617 .858 r
.45503 .56888 m .45537 .56976 L .45262 .56995 L F
.45503 .56888 m .45262 .56995 L .45325 .57019 L F
.682 .843 .96 r
.45503 .56888 m .45325 .57019 L .45076 .56917 L F
.45325 .57019 m .45286 .57048 L .45277 .57042 L F
.665 .617 .791 r
.45274 .57041 m .4521 .57005 L .45262 .56995 L F
.682 .843 .96 r
.45325 .57019 m .45277 .57042 L .45076 .56917 L F
.602 .484 .69 r
.45537 .56976 m .45474 .57145 L .45308 .57027 L F
.45537 .56976 m .45308 .57027 L .45393 .56986 L F
.45474 .57145 m .45372 .57421 L .45274 .57041 L F
.45474 .57145 m .45274 .57041 L .45262 .56995 L F
0 0 0 r
.45026 .56917 m .45151 .56977 L .45286 .57048 L F
.45151 .56977 m .4521 .57005 L .45264 .57036 L F
.45151 .56977 m .45264 .57036 L .45286 .57048 L F
.4521 .57005 m .45243 .57021 L .45279 .57043 L F
.4521 .57005 m .45279 .57043 L .45286 .57048 L F
.665 .617 .791 r
.45372 .57421 m .44845 .57077 L .4521 .57005 L F
.45372 .57421 m .4521 .57005 L .45274 .57041 L F
.525 .065 .103 r
.4521 .57005 m .44845 .57077 L .45026 .56917 L F
0 0 0 r
.45026 .56917 m .45076 .56917 L .4511 .56958 L F
.45026 .56917 m .44852 .57042 L .45076 .56917 L F
.871 .799 .31 r
.45076 .56917 m .45027 .56962 L .45042 .56878 L F
.45076 .56917 m .45042 .56878 L .45088 .56628 L F
0 0 0 r
.4511 .56958 m .45076 .56917 L .45243 .57021 L F
.708 .618 .754 r
.22776 .55048 m .22901 .55413 L .225 .55327 L F
.526 .92 .837 r
.22901 .55413 m .22679 .55448 L .22518 .55572 L F
0 0 .364 r
.22853 .55174 m .22901 .55413 L .22776 .55048 L F
0 0 .076 r
.22853 .55174 m .22679 .55448 L .22901 .55413 L F
0 0 .418 r
.40136 .6852 m .40122 .68582 L .40169 .68522 L F
.87 .45 .015 r
.40051 .68582 m .40166 .68547 L .40077 .68517 L F
.39918 .68508 m .40077 .68517 L .39715 .68395 L F
.40051 .68582 m .40077 .68517 L .39918 .68508 L F
0 0 .418 r
.40214 .6818 m .40136 .6852 L .40285 .68376 L F
.40136 .6852 m .40169 .68522 L .40285 .68376 L F
.824 .572 .559 r
.71235 .3671 m .70952 .36418 L .71315 .36568 L F
.413 .176 .443 r
.71598 .36296 m .71606 .36514 L .71315 .36568 L F
.222 0 0 r
.71315 .36568 m .71606 .36514 L .71235 .3671 L F
.908 .983 .764 r
.70418 .31387 m .70634 .31231 L .70597 .30944 L F
.649 .467 .625 r
.68004 .36305 m .68015 .36579 L .67639 .36569 L F
.53 .909 .946 r
.24963 .528 m .25033 .52681 L .25167 .52679 L F
.24963 .528 m .2481 .52776 L .25033 .52681 L F
.543 .481 .737 r
.287 .56258 m .28954 .56524 L .28935 .56191 L F
0 0 0 r
.35214 .66853 m .34879 .67029 L .35114 .6691 L F
.375 .823 .701 r
.35114 .6691 m .34658 .6712 L .34938 .66944 L F
.358 0 0 r
.35007 .66971 m .35114 .6691 L .34938 .66944 L F
.35158 .67028 m .35114 .6691 L .35007 .66971 L F
0 0 0 r
.35312 .66802 m .35214 .66853 L .35114 .6691 L F
.788 .68 .745 r
.23311 .59079 m .23567 .59222 L .236 .58802 L F
.607 .384 .552 r
.23311 .59079 m .23568 .59338 L .23567 .59222 L F
.496 .792 .998 r
.22201 .56431 m .22652 .56634 L .2281 .5648 L F
.404 .217 .51 r
.41464 .50855 m .41348 .50621 L .41595 .5052 L F
.41464 .50855 m .4138 .50887 L .41348 .50621 L F
0 .129 .661 r
.23354 .61665 m .23298 .61526 L .23076 .61323 L F
0 0 .398 r
.23354 .61665 m .23481 .6188 L .23298 .61526 L F
.922 .804 .713 r
.69023 .31159 m .68698 .3135 L .68833 .31097 L F
.69023 .31159 m .6886 .31499 L .68698 .3135 L F
.463 .48 .791 r
.42143 .53331 m .41856 .5308 L .42285 .53027 L F
.546 .323 .528 r
.42505 .52989 m .42143 .53331 L .42285 .53027 L F
.775 .751 .831 r
.64013 .382 m .64137 .3852 L .63763 .38476 L F
.734 .731 .848 r
.64422 .38246 m .64137 .3852 L .64013 .382 L F
.747 .334 0 r
.40212 .52793 m .40138 .52709 L .40002 .52437 L F
.883 .654 .132 r
.40212 .52793 m .40162 .52921 L .40138 .52709 L F
.40212 .52793 m .40224 .53065 L .40162 .52921 L F
.387 .845 .891 r
.40511 .50823 m .40387 .50849 L .40632 .50779 L F
.449 .799 .998 r
.55886 .41373 m .55582 .41306 L .55693 .41338 L F
.81 .47 .412 r
.55895 .41587 m .55886 .41373 L .55693 .41338 L F
.667 .352 .431 r
.55895 .41587 m .56119 .41613 L .55886 .41373 L F
.577 .617 .856 r
.37863 .59697 m .37787 .60088 L .3764 .59665 L F
.37863 .59697 m .38037 .60037 L .37787 .60088 L F
.612 .88 .552 r
.38037 .60037 m .37751 .6036 L .37787 .60088 L F
.438 .018 .144 r
.69182 .36015 m .69445 .36115 L .69174 .36167 L F
.676 .669 .836 r
.37074 .52474 m .37353 .52594 L .37163 .52143 L F
.728 .445 .499 r
.37074 .52474 m .37425 .5273 L .37353 .52594 L F
.249 .408 .826 r
.37163 .52143 m .37353 .52594 L .37435 .52295 L F
0 .094 .61 r
.37425 .5273 m .37435 .52295 L .37353 .52594 L F
.496 .776 .994 r
.35143 .68242 m .35361 .68371 L .35389 .68204 L F
.688 .939 .964 r
.35252 .68305 m .35361 .68371 L .35009 .68498 L F
.35068 .68442 m .35009 .68498 L .34979 .68509 L F
.35252 .68305 m .35009 .68498 L .35068 .68442 L F
.35252 .68305 m .35068 .68442 L .35209 .68475 L F
.646 .521 .697 r
.35172 .68345 m .35209 .68475 L .35014 .68422 L F
.35218 .68507 m .35244 .68596 L .35199 .68516 L F
.383 .357 .706 r
.35412 .68523 m .35244 .68596 L .35209 .68475 L F
0 0 0 r
.35171 .68629 m .35244 .68596 L .35412 .68523 L F
.646 .521 .697 r
.35199 .68516 m .35244 .68596 L .3519 .68555 L F
.195 .113 .53 r
.34979 .68509 m .3508 .68571 L .35199 .68516 L F
.688 .939 .964 r
.35068 .68442 m .34979 .68509 L .35199 .68516 L F
.733 .291 .2 r
.34859 .68713 m .34934 .68585 L .34886 .68601 L F
.34934 .68585 m .34979 .68509 L .34886 .68601 L F
.34859 .68713 m .35182 .68851 L .35067 .68658 L F
.34962 .686 m .35067 .68658 L .35021 .68581 L F
.34859 .68713 m .35067 .68658 L .34934 .68585 L F
.195 .113 .53 r
.35067 .68658 m .35182 .68851 L .35076 .68598 L F
0 0 0 r
.34956 .68726 m .35171 .68629 L .35172 .68628 L F
.3 0 0 r
.351 .68606 m .35244 .68596 L .35171 .68629 L F
.34962 .686 m .35244 .68596 L .34897 .6862 L F
.646 .521 .697 r
.3519 .68555 m .35244 .68596 L .35179 .68597 L F
.195 .113 .53 r
.35173 .68629 m .35281 .6865 L .35199 .68516 L F
.35247 .68595 m .35325 .68723 L .35412 .68523 L F
0 0 0 r
.35273 .68585 m .35172 .68628 L .35412 .68523 L F
.195 .113 .53 r
.35101 .68659 m .35182 .68851 L .35171 .68629 L F
0 0 0 r
.34956 .68726 m .35172 .68628 L .35273 .68585 L F
.195 .113 .53 r
.35171 .68629 m .35182 .68851 L .35173 .68629 L F
.35076 .68598 m .35101 .68659 L .35171 .68629 L F
.35021 .68581 m .35067 .68658 L .35076 .68598 L F
.646 .521 .697 r
.3519 .68555 m .35179 .68597 L .35076 .68598 L F
.3508 .68571 m .35076 .68598 L .34886 .68601 L F
.3519 .68555 m .35076 .68598 L .3508 .68571 L F
.3 0 0 r
.35068 .68608 m .351 .68606 L .35171 .68629 L F
.351 .68606 m .35171 .68629 L .35171 .68629 L F
.195 .113 .53 r
.35173 .68629 m .35182 .68851 L .35325 .68723 L F
.733 .291 .2 r
.34934 .68585 m .34962 .686 L .34979 .68509 L F
.646 .521 .697 r
.35014 .68422 m .35093 .68481 L .34934 .68585 L F
.35093 .68481 m .35139 .68516 L .35085 .68534 L F
.733 .291 .2 r
.34962 .686 m .35021 .68581 L .34979 .68509 L F
.646 .521 .697 r
.35093 .68481 m .35085 .68534 L .34934 .68585 L F
.195 .113 .53 r
.34979 .68509 m .35021 .68581 L .35076 .68598 L F
.3508 .68571 m .35076 .68598 L .35173 .68629 L F
.34979 .68509 m .35076 .68598 L .3508 .68571 L F
.3508 .68571 m .35173 .68629 L .35199 .68516 L F
.35173 .68629 m .35325 .68723 L .35281 .6865 L F
.3 0 0 r
.34897 .6862 m .35068 .68608 L .34956 .68726 L F
.35068 .68608 m .35171 .68629 L .34956 .68726 L F
.34886 .68601 m .34962 .686 L .34897 .6862 L F
.646 .521 .697 r
.34908 .6857 m .34934 .68585 L .34886 .68601 L F
.35014 .68422 m .34934 .68585 L .34908 .6857 L F
.35139 .68516 m .3519 .68555 L .34886 .68601 L F
.35209 .68475 m .35218 .68507 L .35199 .68516 L F
.688 .939 .964 r
.35209 .68475 m .35199 .68516 L .35412 .68523 L F
.35068 .68442 m .35199 .68516 L .35209 .68475 L F
.195 .113 .53 r
.35199 .68516 m .35247 .68595 L .35412 .68523 L F
.646 .521 .697 r
.35209 .68475 m .3519 .68555 L .35014 .68422 L F
.688 .939 .964 r
.35389 .68204 m .35383 .68242 L .35252 .68305 L F
.35383 .68242 m .35361 .68371 L .35252 .68305 L F
.35389 .68204 m .35252 .68305 L .35412 .68523 L F
.35252 .68305 m .35209 .68475 L .35412 .68523 L F
.383 .357 .706 r
.35412 .68523 m .35209 .68475 L .35172 .68345 L F
.35208 .68311 m .35172 .68345 L .35143 .68242 L F
.35412 .68523 m .35172 .68345 L .35208 .68311 L F
.646 .521 .697 r
.35143 .68242 m .35172 .68345 L .35014 .68422 L F
.596 .24 .335 r
.67639 .36569 m .67899 .36754 L .67634 .3681 L F
.67639 .36569 m .68015 .36579 L .67899 .36754 L F
0 0 .288 r
.601 .42821 m .60084 .42962 L .60118 .43116 L F
.56 .338 .535 r
.32991 .51819 m .3325 .51785 L .33274 .51525 L F
.684 .547 .693 r
.3325 .51785 m .33531 .51446 L .33274 .51525 L F
0 .37 .809 r
.63518 .43337 m .63838 .43506 L .63694 .43366 L F
.647 .811 .962 r
.30661 .62579 m .3107 .62624 L .30876 .6247 L F
.30661 .62579 m .3107 .62624 L .30876 .6247 L F
.729 .831 .927 r
.31314 .62522 m .3107 .62624 L .30876 .6247 L F
.31314 .62522 m .3107 .62624 L .30876 .6247 L F
.967 .773 .591 r
.35642 .67859 m .358 .6797 L .3587 .67691 L F
.788 .68 .745 r
.23311 .59079 m .236 .58802 L .2334 .58833 L F
.509 .004 0 r
.38397 .60049 m .38689 .60336 L .38723 .60371 L F
.38689 .60336 m .38868 .60512 L .38723 .60371 L F
.767 .812 .888 r
.38723 .60371 m .38868 .60512 L .38922 .60173 L F
.38723 .60371 m .38868 .60512 L .38922 .60173 L F
0 0 .375 r
.388 .60432 m .38798 .60449 L .38723 .60371 L F
.601 .48 .687 r
.38868 .60512 m .38884 .6074 L .3858 .60718 L F
.38868 .60512 m .38884 .6074 L .3858 .60718 L F
.96 .75 .575 r
.38868 .60512 m .38873 .60571 L .38723 .60371 L F
.38873 .60571 m .38884 .6074 L .38822 .60597 L F
.38873 .60571 m .38822 .60597 L .38723 .60371 L F
0 0 .375 r
.38798 .60449 m .38773 .60628 L .38723 .60371 L F
.509 .004 0 r
.38397 .60049 m .38868 .60512 L .38723 .60371 L F
.824 .693 .719 r
.38723 .60371 m .38773 .60628 L .38263 .60554 L F
.606 .066 0 r
.38263 .60554 m .38773 .60628 L .38493 .60727 L F
.604 .077 0 r
.38444 .60083 m .38723 .60371 L .38397 .60049 L F
.089 0 .186 r
.38595 .60245 m .38578 .60054 L .38723 .60371 L F
.38397 .60049 m .38578 .60054 L .38595 .60245 L F
.824 .693 .719 r
.38723 .60371 m .38297 .60408 L .38397 .60049 L F
.089 0 .186 r
.38397 .60049 m .38301 .60392 L .38578 .60054 L F
.38301 .60392 m .38297 .60408 L .38578 .60054 L F
.368 .07 .321 r
.38553 .59731 m .38404 .59965 L .38282 .59791 L F
.38404 .59965 m .3829 .60144 L .38283 .59839 L F
.38404 .59965 m .38283 .59839 L .38282 .59791 L F
.773 .386 .322 r
.38282 .59791 m .3829 .60144 L .38059 .59753 L F
0 0 .518 r
.38059 .59753 m .38075 .5978 L .38046 .59608 L F
.38075 .5978 m .3829 .60144 L .38186 .59915 L F
.813 .639 .666 r
.38227 .59375 m .38282 .59791 L .38059 .59753 L F
0 0 .518 r
.38075 .5978 m .38186 .59915 L .38046 .59608 L F
.829 .625 .627 r
.38046 .59608 m .38168 .59875 L .38553 .59731 L F
.38168 .59875 m .3829 .60144 L .38534 .59761 L F
.38168 .59875 m .38534 .59761 L .38553 .59731 L F
.842 .818 .825 r
.38578 .60054 m .38234 .60136 L .38224 .5994 L F
.38578 .60054 m .38297 .60408 L .38076 .60173 L F
0 0 .37 r
.38238 .6022 m .3831 .60362 L .38314 .60066 L F
.612 .88 .552 r
.38037 .60037 m .37824 .60241 L .37751 .6036 L F
.711 .563 .685 r
.37824 .60241 m .37854 .60468 L .3816 .6035 L F
.945 .787 .655 r
.38297 .60408 m .38266 .6054 L .38162 .60339 L F
.711 .563 .685 r
.38162 .60339 m .38161 .60346 L .38177 .60343 L F
.945 .787 .655 r
.3817 .60273 m .38162 .60339 L .38076 .60173 L F
.711 .563 .685 r
.38162 .60339 m .38177 .60343 L .38076 .60173 L F
.37824 .60241 m .38177 .60343 L .38076 .60173 L F
.722 .726 .853 r
.38076 .60173 m .38161 .60346 L .38177 .60343 L F
.945 .787 .655 r
.38266 .6054 m .38263 .60554 L .38161 .60346 L F
.711 .563 .685 r
.37824 .60241 m .38162 .60339 L .38076 .60173 L F
.945 .787 .655 r
.38162 .60339 m .38161 .60346 L .38076 .60173 L F
.38266 .6054 m .38161 .60346 L .38162 .60339 L F
.711 .563 .685 r
.37824 .60241 m .37854 .60468 L .3816 .6035 L F
.38162 .60339 m .3816 .6035 L .38177 .60343 L F
.37824 .60241 m .3816 .6035 L .38162 .60339 L F
.722 .726 .853 r
.38161 .60346 m .38263 .60554 L .38177 .60343 L F
.711 .563 .685 r
.38161 .60346 m .3816 .6035 L .38177 .60343 L F
.37824 .60241 m .3816 .6035 L .38162 .60339 L F
.945 .787 .655 r
.38297 .60408 m .38162 .60339 L .3817 .60273 L F
0 0 .37 r
.38177 .60343 m .38245 .60353 L .38238 .6022 L F
.38245 .60353 m .3831 .60362 L .38238 .6022 L F
.842 .818 .825 r
.38224 .5994 m .38076 .60173 L .38094 .59898 L F
.38234 .60136 m .38076 .60173 L .38224 .5994 L F
.38101 .59896 m .38094 .59898 L .38095 .59894 L F
.38578 .60054 m .38094 .59898 L .38101 .59896 L F
.38448 .60011 m .38196 .59927 L .38493 .60058 L F
.38196 .59927 m .38095 .59894 L .38206 .5994 L F
.38196 .59927 m .38206 .5994 L .38493 .60058 L F
.38493 .60058 m .38095 .59894 L .38314 .60066 L F
.38578 .60054 m .38448 .60011 L .38493 .60058 L F
.406 .539 .878 r
.38557 .59816 m .38578 .60054 L .38314 .60066 L F
.3861 .59761 m .38578 .60054 L .38557 .59816 L F
.824 .693 .719 r
.38723 .60371 m .38263 .60554 L .38297 .60408 L F
0 .223 .744 r
.38177 .60343 m .38511 .60696 L .3831 .60362 L F
.793 .997 .788 r
.3851 .60711 m .38735 .60641 L .388 .60432 L F
.38493 .60727 m .38509 .60721 L .3851 .60711 L F
.38509 .60721 m .38735 .60641 L .3851 .60711 L F
.38735 .60641 m .38773 .60628 L .38774 .60621 L F
.38735 .60641 m .38774 .60621 L .388 .60432 L F
.467 .377 .671 r
.39083 .60619 m .38884 .6074 L .38868 .60512 L F
.39083 .60619 m .38884 .6074 L .38868 .60512 L F
.189 0 .234 r
.39074 .6084 m .38884 .6074 L .39083 .60619 L F
.165 0 .229 r
.39074 .6084 m .39083 .60619 L .39288 .60644 L F
.793 .997 .788 r
.38493 .60727 m .388 .60432 L .39094 .60633 L F
0 .223 .744 r
.38511 .60696 m .38532 .60718 L .38516 .60693 L F
.38512 .60689 m .38516 .60693 L .38512 .60687 L F
.38511 .60696 m .38516 .60693 L .38512 .60689 L F
.357 .492 .857 r
.38532 .60718 m .38516 .60693 L .38616 .60547 L F
.402 0 0 r
.38493 .60727 m .3886 .6067 L .38724 .60795 L F
.3886 .6067 m .39094 .60633 L .38983 .60682 L F
.3886 .6067 m .38983 .60682 L .38724 .60795 L F
0 0 0 r
.39288 .60644 m .39074 .6084 L .3919 .60742 L F
.562 .084 .078 r
.38724 .60795 m .39094 .60633 L .3919 .60742 L F
.631 .076 0 r
.39172 .607 m .388 .60432 L .39018 .60335 L F
.3919 .60742 m .39132 .60696 L .39172 .607 L F
.3919 .60742 m .39094 .60633 L .388 .60432 L F
.39132 .60696 m .388 .60432 L .39172 .607 L F
.269 .37 .782 r
.38616 .60547 m .38516 .60693 L .38724 .60795 L F
0 .231 .745 r
.38177 .60343 m .38493 .60727 L .38532 .60718 L F
.357 .492 .857 r
.38532 .60718 m .38493 .60727 L .38516 .60693 L F
0 .223 .744 r
.38512 .60687 m .38532 .60718 L .38512 .60686 L F
.269 .37 .782 r
.38516 .60693 m .38493 .60727 L .38568 .60749 L F
.38516 .60693 m .38568 .60749 L .38724 .60795 L F
0 .223 .744 r
.38511 .60696 m .38512 .60686 L .3831 .60362 L F
.808 .983 .708 r
.65117 .42971 m .65375 .42646 L .65213 .42733 L F
.953 .822 .676 r
.24645 .58638 m .24483 .58738 L .2425 .58741 L F
.781 .626 .687 r
.30847 .66396 m .31125 .6612 L .30858 .6613 L F
.045 .317 .802 r
.59898 .4112 m .59712 .41147 L .59603 .40996 L F
.59898 .4112 m .59972 .41325 L .59712 .41147 L F
.512 .543 .825 r
.42984 .50999 m .42769 .51137 L .42671 .5096 L F
.42984 .50999 m .43017 .51087 L .42769 .51137 L F
.77 .639 .716 r
.57546 .41905 m .57768 .42112 L .57336 .42029 L F
.551 .613 .868 r
.57742 .42384 m .57336 .42029 L .57768 .42112 L F
.524 .512 .784 r
.58113 .42916 m .58092 .43146 L .57824 .43115 L F
.21 .401 .833 r
.58443 .4353 m .57824 .43115 L .58092 .43146 L F
.662 .89 .98 r
.58113 .42916 m .57824 .43115 L .57885 .42866 L F
.778 .406 .351 r
.58586 .42494 m .59246 .42657 L .59001 .42902 L F
.053 .307 .794 r
.59253 .42483 m .59246 .42657 L .58991 .42297 L F
.898 .968 .652 r
.59001 .42902 m .59246 .42657 L .59253 .42483 L F
.386 .845 .79 r
.37628 .64759 m .38135 .64588 L .37966 .64465 L F
.779 .873 .917 r
.37966 .64465 m .38135 .64588 L .38446 .64334 L F
.696 .644 .793 r
.65044 .38203 m .64789 .38512 L .64653 .38119 L F
.642 .562 .749 r
.65044 .38203 m .65082 .38449 L .64789 .38512 L F
.653 .53 .702 r
.65082 .38449 m .64801 .38721 L .64789 .38512 L F
.124 .255 .728 r
.34697 .57832 m .34958 .58126 L .34842 .57839 L F
.482 .35 .624 r
.3469 .58145 m .34958 .58126 L .34697 .57832 L F
.177 0 .335 r
.30584 .58956 m .30769 .58981 L .30807 .58747 L F
.283 .179 .555 r
.30584 .58956 m .30754 .59323 L .30769 .58981 L F
.30584 .58956 m .30605 .59393 L .30754 .59323 L F
.733 .776 .887 r
.5686 .42179 m .57051 .4233 L .5666 .42298 L F
.771 .777 .858 r
.57336 .42029 m .57051 .4233 L .5686 .42179 L F
.623 .203 .226 r
.38003 .56637 m .38234 .5684 L .37977 .56782 L F
.19 0 .273 r
.3137 .60003 m .31188 .60097 L .31443 .59775 L F
.331 .105 .412 r
.3137 .60003 m .31122 .6033 L .31188 .60097 L F
.258 .43 .842 r
.37324 .56589 m .37486 .56477 L .37201 .56335 L F
0 0 0 r
.37324 .56589 m .37352 .56736 L .37486 .56477 L F
.37324 .56589 m .37209 .56888 L .37286 .56806 L F
.614 .591 .804 r
.37263 .56842 m .36925 .57018 L .3704 .5655 L F
.052 .015 .491 r
.37209 .56888 m .37273 .56855 L .37352 .56736 L F
.614 .591 .804 r
.37273 .56855 m .37246 .56867 L .37263 .56842 L F
.37246 .56867 m .36925 .57018 L .37263 .56842 L F
0 0 0 r
.37348 .56714 m .37286 .56806 L .37352 .56736 L F
.37324 .56589 m .37286 .56806 L .37348 .56714 L F
0 .272 .672 r
.33314 .50413 m .33244 .50367 L .32994 .50236 L F
.978 .715 .46 r
.32962 .50502 m .32792 .50121 L .32994 .50236 L F
0 .272 .672 r
.33244 .50367 m .33208 .50345 L .32994 .50236 L F
.721 .882 .955 r
.33096 .50261 m .32994 .50236 L .33221 .50352 L F
.33096 .50261 m .32962 .50502 L .32994 .50236 L F
.978 .715 .46 r
.32962 .50502 m .32793 .50388 L .32792 .50121 L F
.721 .882 .955 r
.33089 .50274 m .32793 .50388 L .32962 .50502 L F
.33096 .50261 m .3308 .50268 L .33089 .50274 L F
.3308 .50268 m .32793 .50388 L .33089 .50274 L F
0 .272 .672 r
.33244 .50367 m .33221 .50352 L .33208 .50345 L F
.117 .631 .892 r
.33633 .50446 m .33221 .50352 L .33314 .50413 L F
.647 .409 .544 r
.37751 .6036 m .37492 .60596 L .37526 .60413 L F
.789 .458 .428 r
.37751 .6036 m .37428 .60455 L .37526 .60413 L F
.858 .789 .782 r
.67308 .33432 m .66914 .336 L .67186 .33293 L F
.67308 .33432 m .67078 .33761 L .66914 .336 L F
.848 .898 .872 r
.67582 .3314 m .67308 .33432 L .67186 .33293 L F
.573 .666 .901 r
.3541 .65918 m .35795 .66112 L .35694 .65864 L F
.837 .783 .8 r
.35694 .65864 m .35795 .66112 L .35967 .65782 L F
.828 .849 .862 r
.36366 .52361 m .36216 .52586 L .35669 .52441 L F
.764 .554 .614 r
.55759 .4426 m .5556 .44463 L .5545 .44246 L F
.659 .799 .95 r
.3931 .50902 m .39476 .51224 L .39149 .51162 L F
.853 .716 .711 r
.39476 .51224 m .39109 .51395 L .39149 .51162 L F
.39476 .51224 m .39311 .51496 L .39109 .51395 L F
.516 .552 .831 r
.39617 .50812 m .39476 .51224 L .3931 .50902 L F
.39617 .50812 m .39737 .51182 L .39476 .51224 L F
.575 .034 0 r
.27714 .63884 m .2779 .64003 L .27502 .63862 L F
.27714 .63884 m .27948 .64103 L .2779 .64003 L F
.481 .849 .989 r
.37539 .71208 m .37911 .71182 L .37689 .71239 L F
.2 0 0 r
.37911 .71182 m .38198 .71172 L .38046 .71217 L F
0 .024 .555 r
.4041 .66971 m .40491 .67239 L .40373 .67371 L F
.808 .727 .197 r
.40491 .67239 m .40457 .67572 L .40373 .67371 L F
0 0 .345 r
.40457 .67572 m .40439 .67636 L .40373 .67371 L F
.712 .765 .894 r
.37332 .65525 m .37495 .65202 L .37189 .6519 L F
.392 .242 .555 r
.35143 .57224 m .3517 .5749 L .35387 .5742 L F
.502 0 0 r
.34963 .57291 m .35232 .57413 L .34931 .57318 L F
.841 .869 .863 r
.34728 .5731 m .35012 .57251 L .34963 .57291 L F
.635 .074 0 r
.34963 .57291 m .34535 .57084 L .34728 .5731 L F
.502 0 0 r
.34963 .57291 m .34931 .57318 L .34805 .57278 L F
.841 .869 .863 r
.35012 .57251 m .35143 .57224 L .34963 .57291 L F
.251 0 .292 r
.35383 .5714 m .35143 .57224 L .35508 .56876 L F
.392 .242 .555 r
.35143 .57224 m .35387 .5742 L .35383 .5714 L F
0 0 0 r
.34963 .57291 m .35143 .57224 L .35383 .5714 L F
.251 0 .292 r
.35508 .56876 m .35143 .57224 L .35383 .5714 L F
0 0 .301 r
.33155 .61165 m .33076 .61051 L .33245 .60965 L F
.33155 .61165 m .33042 .61331 L .33076 .61051 L F
.648 .921 .632 r
.37065 .68563 m .36998 .68663 L .37279 .68359 L F
0 .066 .59 r
.37178 .68903 m .36998 .68663 L .37065 .68563 L F
.277 .761 .668 r
.40387 .50849 m .40525 .50791 L .40632 .50779 L F
.40387 .50849 m .40283 .5089 L .40525 .50791 L F
.591 .058 0 r
.35885 .66501 m .36177 .664 L .35784 .66358 L F
0 0 0 r
.36425 .66213 m .36177 .664 L .3637 .66259 L F
.546 .923 .789 r
.3637 .66259 m .36177 .664 L .35885 .66501 L F
.3637 .66259 m .35885 .66501 L .36199 .664 L F
.3637 .66259 m .36199 .664 L .36304 .66366 L F
0 0 0 r
.36442 .662 m .36425 .66213 L .3637 .66259 L F
.99 .791 .405 r
.40723 .58607 m .40856 .58498 L .40712 .58342 L F
.40723 .58607 m .40838 .58819 L .40856 .58498 L F
.611 .64 .855 r
.63449 .3833 m .63763 .38476 L .6345 .38557 L F
.63449 .3833 m .6345 .38557 L .63458 .38518 L F
.343 .649 .968 r
.6345 .38557 m .62961 .38329 L .63458 .38518 L F
.408 0 0 r
.35808 .50355 m .36175 .50508 L .3599 .50416 L F
0 .348 .706 r
.36057 .50453 m .36175 .50508 L .35998 .50431 L F
.324 0 0 r
.3599 .50416 m .36175 .50508 L .36258 .50546 L F
0 .348 .706 r
.36268 .50529 m .36175 .50508 L .36057 .50453 L F
.324 0 0 r
.36258 .50546 m .36175 .50508 L .36344 .50588 L F
0 .145 .668 r
.36459 .50621 m .36344 .50588 L .36175 .50508 L F
.57 .01 0 r
.36344 .50588 m .36583 .50793 L .36754 .50885 L F
0 .145 .668 r
.36459 .50621 m .36583 .50793 L .36344 .50588 L F
.025 0 .183 r
.2025 .56904 m .20392 .56824 L .20472 .56585 L F
.294 .178 .546 r
.2024 .57169 m .20392 .56824 L .2025 .56904 L F
.972 .684 .422 r
.40758 .53733 m .40581 .53861 L .40666 .53594 L F
0 0 0 r
.40666 .53594 m .40581 .53861 L .40656 .53709 L F
.40666 .53594 m .40656 .53709 L .40655 .53594 L F
.644 .228 0 r
.40539 .53376 m .40673 .53595 L .40666 .53594 L F
0 .159 .7 r
.40666 .53594 m .40424 .53233 L .40539 .53376 L F
.40666 .53594 m .40654 .53454 L .40424 .53233 L F
0 0 0 r
.40666 .53594 m .40655 .53594 L .40654 .53454 L F
.644 .228 0 r
.40673 .53595 m .40758 .53733 L .40666 .53594 L F
.972 .684 .422 r
.40758 .53733 m .40755 .53995 L .40581 .53861 L F
.617 .292 .396 r
.37194 .54374 m .3716 .54625 L .36777 .54454 L F
.404 .631 .946 r
.3688 .52283 m .36778 .52471 L .36614 .52274 L F
.493 .185 .371 r
.37443 .54472 m .3716 .54625 L .37194 .54374 L F
.876 .982 .694 r
.65213 .42733 m .65375 .42646 L .65423 .42408 L F
.791 .647 .704 r
.3567 .5144 m .35586 .51783 L .35991 .51758 L F
.646 .524 .7 r
.35586 .51783 m .35943 .52014 L .35991 .51758 L F
.575 .289 .445 r
.36235 .51785 m .35943 .52014 L .35991 .51758 L F
.35943 .52014 m .36235 .51785 L .35991 .51758 L F
.579 .447 .665 r
.27516 .55832 m .27283 .56191 L .27277 .5595 L F
.742 .586 .682 r
.43616 .5341 m .43648 .53776 L .43278 .53713 L F
.474 .448 .749 r
.4383 .53315 m .43616 .5341 L .43522 .53142 L F
.534 .431 .683 r
.4387 .53702 m .43616 .5341 L .4383 .53315 L F
.4387 .53702 m .43648 .53776 L .43616 .5341 L F
.582 .232 .34 r
.31893 .55909 m .32146 .55962 L .32274 .55648 L F
.721 .676 .806 r
.32001 .55229 m .32274 .55648 L .32468 .55492 L F
0 0 0 r
.32274 .55648 m .32303 .55623 L .32468 .55492 L F
.32274 .55648 m .32146 .55962 L .32303 .55623 L F
.914 .77 .688 r
.3504 .5157 m .34778 .51616 L .34593 .51343 L F
.3504 .5157 m .3494 .51804 L .34778 .51616 L F
.764 .979 .718 r
.35092 .5143 m .3504 .5157 L .35182 .51399 L F
.914 .77 .688 r
.34778 .51616 m .3504 .5157 L .35092 .5143 L F
.34778 .51616 m .3494 .51804 L .3504 .5157 L F
0 0 .268 r
.41534 .56203 m .41659 .56593 L .41603 .5639 L F
.955 .748 .293 r
.41659 .56593 m .41583 .56733 L .41603 .5639 L F
.41659 .56593 m .41646 .56851 L .41583 .56733 L F
0 0 .128 r
.39226 .62816 m .39187 .63264 L .39355 .62901 L F
.39226 .62816 m .39227 .63109 L .39187 .63264 L F
.841 .837 .368 r
.39129 .63298 m .39187 .63264 L .39227 .63109 L F
.39129 .63298 m .39102 .63515 L .39187 .63264 L F
.019 .243 .747 r
.30182 .5407 m .30249 .53875 L .30057 .53942 L F
.478 .065 .177 r
.30452 .54059 m .30314 .54151 L .30182 .5407 L F
.019 .243 .747 r
.30182 .5407 m .30314 .54151 L .30249 .53875 L F
.914 .923 .806 r
.39226 .62816 m .39355 .62901 L .3957 .62545 L F
.008 .148 .662 r
.59487 .42613 m .59396 .42592 L .59513 .42414 L F
.366 .795 .969 r
.56755 .39761 m .57137 .39781 L .57033 .39718 L F
.56755 .39761 m .57137 .39781 L .57033 .39718 L F
.669 .944 .961 r
.57033 .39718 m .57137 .39781 L .5726 .3958 L F
.5726 .3958 m .57137 .39781 L .57033 .39718 L F
.04 .51 .885 r
.24478 .625 m .2451 .6243 L .24243 .62358 L F
.24478 .625 m .24672 .62554 L .2451 .6243 L F
.135 .642 .901 r
.32039 .66967 m .32273 .66991 L .3211 .66922 L F
.346 .806 .696 r
.31876 .67033 m .32039 .66967 L .3211 .66922 L F
.628 .961 .843 r
.64563 .40448 m .64801 .40292 L .64732 .40263 L F
.482 .712 .972 r
.6444 .40281 m .64563 .40448 L .64732 .40263 L F
.733 .685 .805 r
.37446 .62944 m .37574 .62555 L .37297 .62586 L F
.37446 .62944 m .37701 .62827 L .37574 .62555 L F
.633 .398 .544 r
.37422 .63209 m .37662 .63203 L .37446 .62944 L F
.518 .38 .633 r
.62102 .41608 m .61867 .4193 L .61845 .4165 L F
.908 .906 .809 r
.32591 .53616 m .32525 .5396 L .32683 .53919 L F
.57 .49 .726 r
.32683 .53919 m .32785 .54043 L .32525 .5396 L F
.395 .295 .623 r
.43989 .57141 m .43996 .57426 L .43774 .57507 L F
.535 .455 .712 r
.44119 .57767 m .43774 .57507 L .43996 .57426 L F
.44119 .57767 m .43878 .57832 L .43774 .57507 L F
.817 .647 .671 r
.24823 .55864 m .25296 .55949 L .25224 .55658 L F
.706 .511 .623 r
.24987 .56238 m .25296 .55949 L .24823 .55864 L F
.496 .311 .56 r
.25565 .55622 m .25296 .55949 L .25224 .55658 L F
.25565 .55622 m .25525 .55922 L .25296 .55949 L F
.366 .187 .502 r
.25296 .55949 m .2545 .56219 L .25525 .55922 L F
.496 .311 .56 r
.25565 .55622 m .25296 .55949 L .25224 .55658 L F
.25565 .55622 m .25525 .55922 L .25296 .55949 L F
.487 .527 .825 r
.43689 .52894 m .43522 .53142 L .43401 .52748 L F
.43689 .52894 m .43738 .53089 L .43522 .53142 L F
.472 .449 .751 r
.43738 .53089 m .4383 .53315 L .43522 .53142 L F
.621 .089 0 r
.23655 .61983 m .2369 .62078 L .23481 .6188 L F
.23655 .61983 m .23862 .62203 L .2369 .62078 L F
0 0 0 r
.27548 .52819 m .27143 .52989 L .2727 .52972 L F
.093 0 .335 r
.31604 .59643 m .31443 .59775 L .31636 .59412 L F
.318 .126 .455 r
.31604 .59643 m .3137 .60003 L .31443 .59775 L F
.82 .569 .559 r
.71488 .34386 m .71144 .34596 L .71342 .34255 L F
.71488 .34386 m .71504 .34623 L .71144 .34596 L F
.796 .825 .875 r
.71789 .34104 m .71488 .34386 L .71342 .34255 L F
0 .128 .669 r
.21618 .60458 m .21749 .60511 L .21587 .60297 L F
.21618 .60458 m .21846 .60683 L .21749 .60511 L F
0 0 .499 r
.41412 .56008 m .41534 .56203 L .41347 .5585 L F
0 .398 .841 r
.23091 .60481 m .22954 .60496 L .22916 .60254 L F
.23091 .60481 m .2321 .60609 L .22954 .60496 L F
.822 .774 .808 r
.69575 .30496 m .69231 .30457 L .69515 .30163 L F
.69575 .30496 m .69392 .30631 L .69231 .30457 L F
.845 .832 .834 r
.69835 .30149 m .69575 .30496 L .69515 .30163 L F
.356 .162 .475 r
.34593 .54678 m .34573 .54966 L .34834 .54622 L F
.12 0 0 r
.35175 .59094 m .34759 .59333 L .34926 .59145 L F
0 0 .491 r
.40868 .54379 m .41001 .54604 L .40968 .54439 L F
.667 .908 .58 r
.39518 .65995 m .39438 .66143 L .39291 .66172 L F
.39518 .65995 m .39605 .65927 L .39438 .66143 L F
.433 .291 .588 r
.32086 .5898 m .31866 .58835 L .3211 .58768 L F
.32086 .5898 m .3188 .59096 L .31866 .58835 L F
.768 .851 .913 r
.25699 .53353 m .25376 .53416 L .25744 .53418 L F
.655 .68 .862 r
.25376 .53416 m .25685 .53463 L .25744 .53418 L F
.392 .662 .967 r
.25744 .53418 m .25881 .53312 L .25699 .53353 L F
.155 0 .199 r
.25685 .53463 m .25881 .53312 L .25744 .53418 L F
.131 .671 .842 r
.23158 .55647 m .23369 .55636 L .23581 .5567 L F
0 .004 .58 r
.23675 .55664 m .23581 .5567 L .23369 .55636 L F
.537 .169 .29 r
.23581 .5567 m .23778 .55903 L .2393 .55632 L F
0 .004 .58 r
.23675 .55664 m .23778 .55903 L .23581 .5567 L F
.781 .989 .749 r
.28652 .54872 m .28865 .54625 L .2867 .5471 L F
.297 .078 .403 r
.28865 .54625 m .28652 .54872 L .2867 .5471 L F
.445 .093 .274 r
.23463 .56608 m .23578 .56871 L .23707 .56576 L F
0 0 .294 r
.2349 .56654 m .23578 .56871 L .23463 .56608 L F
.97 .915 .695 r
.57599 .42586 m .57742 .42384 L .57528 .42463 L F
.624 .955 .797 r
.57528 .42463 m .57742 .42384 L .57959 .42215 L F
.655 .68 .862 r
.25376 .53416 m .25503 .53726 L .25685 .53463 L F
0 0 .202 r
.28391 .63872 m .28529 .63523 L .28433 .63914 L F
0 0 .443 r
.2851 .6416 m .28391 .63872 L .28433 .63914 L F
0 0 .472 r
.2851 .6416 m .28424 .64206 L .28391 .63872 L F
.901 .895 .477 r
.41804 .57238 m .41688 .57387 L .41715 .57116 L F
.41804 .57238 m .4171 .57465 L .41688 .57387 L F
.814 .633 .658 r
.67332 .35298 m .67496 .3566 L .67125 .35597 L F
.814 .631 .655 r
.67125 .35597 m .67496 .3566 L .67394 .35877 L F
.713 .592 .719 r
.67746 .3535 m .67496 .3566 L .67332 .35298 L F
.82 .717 .75 r
.70691 .29212 m .703 .28906 L .70645 .28978 L F
.70691 .29212 m .70247 .29163 L .703 .28906 L F
.813 .738 .781 r
.70691 .29212 m .70376 .29504 L .70247 .29163 L F
.651 .965 .911 r
.35505 .65194 m .35218 .65374 L .35086 .65339 L F
0 0 .566 r
.33231 .69866 m .3335 .70228 L .33421 .70127 L F
.817 .647 .671 r
.24823 .55864 m .25224 .55658 L .25049 .55498 L F
.18 .493 .904 r
.65137 .40188 m .65238 .40355 L .65302 .40226 L F
0 .122 .664 r
.65238 .40355 m .65422 .4058 L .65302 .40226 L F
.074 .608 .863 r
.36925 .50854 m .36754 .50885 L .36583 .50793 L F
.36925 .50854 m .36963 .5091 L .36754 .50885 L F
.666 .861 .974 r
.71504 .34623 m .71239 .34735 L .71144 .34596 L F
.791 .633 .686 r
.37297 .62586 m .3755 .62282 L .37401 .62334 L F
.652 .43 .57 r
.37297 .62586 m .37574 .62555 L .3755 .62282 L F
.766 .444 .441 r
.37951 .62576 m .3755 .62282 L .37574 .62555 L F
.451 .251 .517 r
.32679 .56576 m .32676 .56825 L .32416 .56885 L F
.484 .407 .693 r
.3252 .56996 m .32416 .56885 L .32676 .56825 L F
.3252 .56996 m .32533 .57163 L .32416 .56885 L F
.915 .589 .411 r
.39937 .54958 m .40079 .55478 L .40188 .55276 L F
.975 .67 .345 r
.40079 .55478 m .40216 .55522 L .40188 .55276 L F
.019 .469 .874 r
.33045 .69794 m .33107 .69724 L .32775 .69622 L F
.33045 .69794 m .33231 .69866 L .33107 .69724 L F
.676 .318 0 r
.29328 .64758 m .292 .64456 L .29348 .64441 L F
.523 .712 .958 r
.33281 .55454 m .33412 .55629 L .33171 .55669 L F
.491 0 0 r
.60882 .42862 m .60852 .4281 L .60773 .42625 L F
.968 .849 .671 r
.58224 .43779 m .58363 .439 L .58351 .43569 L F
.647 .11 0 r
.58224 .43779 m .58646 .43897 L .58363 .439 L F
.206 .461 .88 r
.32713 .66419 m .32548 .66423 L .32615 .66277 L F
0 .486 .832 r
.32801 .66505 m .32548 .66423 L .32713 .66419 L F
.529 .352 .585 r
.36315 .55564 m .36084 .55323 L .36248 .55253 L F
.36315 .55564 m .36068 .55625 L .36084 .55323 L F
0 .031 .593 r
.32423 .65824 m .32191 .65468 L .32247 .65699 L F
.592 .832 .99 r
.32247 .65699 m .32423 .65824 L .32648 .65737 L F
.32247 .65699 m .32423 .65824 L .32648 .65737 L F
.733 .623 .737 r
.66594 .3442 m .66534 .34676 L .66305 .34692 L F
.771 .578 .638 r
.66534 .34676 m .66313 .34955 L .66305 .34692 L F
.66534 .34676 m .66697 .35023 L .66313 .34955 L F
.158 .086 .518 r
.3143 .64526 m .3165 .64651 L .31587 .64375 L F
.3143 .64526 m .31455 .64805 L .3165 .64651 L F
.637 .717 .905 r
.37101 .60584 m .37217 .60767 L .37492 .60596 L F
.145 .223 .687 r
.37217 .60767 m .37309 .60945 L .37443 .60954 L F
0 .195 .72 r
.29565 .64346 m .29711 .64601 L .29811 .6468 L F
.868 .776 .758 r
.35558 .61254 m .35999 .61058 L .35564 .61125 L F
.35558 .61254 m .35834 .61349 L .35999 .61058 L F
.33 .411 .794 r
.27918 .52895 m .28026 .52622 L .27778 .52721 L F
.27918 .52895 m .2816 .52991 L .28026 .52622 L F
.692 .625 .777 r
.36928 .54959 m .3676 .54484 L .36777 .54454 L F
.532 .431 .686 r
.3716 .54625 m .36928 .54959 L .36777 .54454 L F
0 0 0 r
.72598 .35461 m .72381 .35588 L .72678 .35326 L F
.72353 .35608 m .72381 .35588 L .72598 .35461 L F
.913 .973 .685 r
.6498 .41498 m .65148 .41406 L .65049 .41554 L F
.785 .981 .713 r
.65243 .41187 m .65148 .41406 L .6498 .41498 L F
.556 .503 .752 r
.66309 .39577 m .66112 .40078 L .66021 .3968 L F
.66309 .39577 m .66414 .40047 L .66112 .40078 L F
.539 .379 .613 r
.66414 .40047 m .66201 .40353 L .66112 .40078 L F
0 0 .044 r
.33383 .60622 m .33295 .60733 L .33438 .60315 L F
.716 .811 .347 r
.33305 .60815 m .33245 .60965 L .33286 .60774 L F
.33383 .60622 m .33305 .60815 L .33295 .60733 L F
.33383 .60622 m .33291 .60814 L .33245 .60965 L F
.737 .825 .919 r
.33291 .60814 m .33155 .61165 L .33245 .60965 L F
.33291 .60814 m .33443 .61012 L .33155 .61165 L F
.277 0 .12 r
.33443 .61012 m .3306 .61411 L .33155 .61165 L F
.632 .183 0 r
.33328 .60863 m .3343 .61031 L .33443 .61012 L F
.33291 .60814 m .33347 .60902 L .33328 .60863 L F
.33347 .60902 m .3343 .61031 L .33328 .60863 L F
.716 .811 .347 r
.33305 .60815 m .33286 .60774 L .33295 .60733 L F
.504 .505 .79 r
.42827 .50556 m .42671 .5096 L .42565 .50567 L F
.42827 .50556 m .42984 .50999 L .42671 .5096 L F
.25 .1 .474 r
.36068 .55625 m .35878 .5597 L .35772 .55612 L F
.36068 .55625 m .36052 .55957 L .35878 .5597 L F
0 0 .346 r
.35977 .56072 m .35878 .5597 L .36052 .55957 L F
.35977 .56072 m .35906 .56262 L .35878 .5597 L F
.653 .53 .702 r
.65082 .38449 m .6516 .3886 L .64801 .38721 L F
.717 .678 .811 r
.37574 .62555 m .37701 .62827 L .37951 .62576 L F
0 0 0 r
.36224 .55966 m .36318 .55899 L .36477 .55646 L F
0 0 .242 r
.36224 .55966 m .36203 .56229 L .36318 .55899 L F
.151 .216 .677 r
.37446 .58442 m .37688 .58664 L .37595 .58401 L F
.067 .563 .891 r
.2403 .62325 m .2405 .62252 L .23862 .62203 L F
.2403 .62325 m .24243 .62358 L .2405 .62252 L F
.422 .848 .952 r
.2593 .52373 m .25862 .52472 L .25712 .52455 L F
.2593 .52373 m .26097 .52409 L .25862 .52472 L F
.023 0 .188 r
.27506 .5392 m .27695 .53704 L .27459 .53736 L F
.27506 .5392 m .27663 .53821 L .27695 .53704 L F
.618 .276 .368 r
.57974 .45146 m .57601 .45382 L .57589 .45154 L F
.57974 .45146 m .5789 .45398 L .57601 .45382 L F
.475 .138 .314 r
.58227 .45303 m .57974 .45146 L .58247 .45102 L F
.58227 .45303 m .5789 .45398 L .57974 .45146 L F
.812 .823 .859 r
.67078 .33761 m .66643 .33901 L .66914 .336 L F
.522 .305 .526 r
.33004 .56183 m .32942 .56551 L .32679 .56576 L F
.508 .38 .641 r
.33143 .5618 m .32942 .56551 L .33004 .56183 L F
0 .261 .724 r
.37634 .51411 m .37591 .51439 L .37458 .51335 L F
.37634 .51411 m .37773 .51545 L .37591 .51439 L F
.97 .886 .691 r
.34593 .51343 m .34595 .51006 L .34599 .51178 L F
.067 0 0 r
.21997 .60856 m .22096 .60868 L .21846 .60683 L F
.21997 .60856 m .22276 .60877 L .22096 .60868 L F
.729 .831 .927 r
.31314 .62522 m .30916 .62475 L .31129 .62455 L F
.31314 .62522 m .30876 .6247 L .31129 .62455 L F
.803 .967 .91 r
.31562 .62269 m .31314 .62522 L .31129 .62455 L F
.568 0 0 r
.31361 .62687 m .31314 .62522 L .31129 .62455 L F
.31361 .62687 m .31541 .62678 L .31314 .62522 L F
.593 .054 0 r
.31641 .62621 m .31541 .62678 L .31314 .62522 L F
.447 .297 .584 r
.31129 .62455 m .31361 .62687 L .31354 .62434 L F
.31129 .62455 m .31354 .62434 L .31353 .6238 L F
.729 .831 .927 r
.30916 .62475 m .30876 .6247 L .31129 .62455 L F
.684 .968 .76 r
.35967 .65782 m .36237 .65557 L .3612 .65575 L F
.67 .945 .96 r
.35898 .65726 m .35967 .65782 L .3612 .65575 L F
.562 .933 .815 r
.3558 .65831 m .35898 .65726 L .3612 .65575 L F
.35563 .65839 m .35569 .65837 L .3558 .65831 L F
.35569 .65837 m .35898 .65726 L .3558 .65831 L F
.787 .732 .801 r
.35998 .65586 m .3603 .65586 L .36245 .65343 L F
.562 .933 .815 r
.35563 .65839 m .3612 .65575 L .35998 .65586 L F
.138 0 0 r
.3612 .65575 m .3637 .65594 L .36048 .65587 L F
.3612 .65575 m .36048 .65587 L .35998 .65586 L F
.684 .968 .76 r
.36237 .65557 m .36305 .65499 L .3612 .65575 L F
.134 0 0 r
.36305 .65499 m .3637 .65594 L .3612 .65575 L F
.138 0 0 r
.3612 .65575 m .3637 .65594 L .35998 .65586 L F
.787 .732 .801 r
.3603 .65586 m .3637 .65594 L .36294 .65442 L F
.3603 .65586 m .36294 .65442 L .36245 .65343 L F
.134 0 0 r
.36305 .65499 m .3656 .65445 L .3637 .65594 L F
.751 .505 .559 r
.6543 .41632 m .65101 .41876 L .65195 .41908 L F
.529 .381 .624 r
.65506 .41985 m .65195 .41908 L .65101 .41876 L F
.65506 .41985 m .65519 .42195 L .65195 .41908 L F
.806 .359 0 r
.60275 .40309 m .60398 .40408 L .60501 .40622 L F
.567 .205 .314 r
.22897 .5596 m .22863 .56145 L .22657 .55958 L F
.326 .571 .929 r
.33912 .71188 m .33773 .70811 L .33943 .71238 L F
.431 .009 .137 r
.23393 .56944 m .2301 .57092 L .23193 .56898 L F
.522 .362 .606 r
.26342 .53355 m .26523 .53678 L .26132 .53734 L F
.757 .359 .3 r
.26132 .53734 m .26311 .5396 L .26559 .53949 L F
.892 .94 .837 r
.26523 .53678 m .26311 .5396 L .26132 .53734 L F
.604 .108 .049 r
.32775 .63192 m .32768 .63074 L .32605 .63182 L F
.774 .905 .932 r
.30906 .51259 m .3099 .51052 L .31161 .51171 L F
.505 .809 1 r
.3099 .51052 m .31406 .51108 L .31161 .51171 L F
.881 .632 .109 r
.31143 .51331 m .31205 .51534 L .31161 .51171 L F
.31143 .51331 m .31161 .51171 L .31406 .51108 L F
0 0 0 r
.30048 .66013 m .30459 .65852 L .30266 .65712 L F
.666 .972 .899 r
.27642 .62756 m .2806 .62585 L .27909 .62704 L F
.977 .733 .499 r
.2806 .62585 m .28047 .62878 L .27909 .62704 L F
.437 .122 .332 r
.7127 .30784 m .7104 .30982 L .71046 .30871 L F
.877 .595 .506 r
.32466 .61663 m .32116 .61906 L .32353 .61585 L F
.32466 .61663 m .32467 .61924 L .32116 .61906 L F
.946 .947 .746 r
.32466 .61663 m .32353 .61585 L .32548 .61222 L F
.394 .202 .499 r
.32666 .61817 m .32467 .61924 L .32466 .61663 L F
.636 .466 .635 r
.23492 .58449 m .23822 .58493 L .23772 .58135 L F
.567 .417 .637 r
.23772 .58135 m .2407 .58427 L .24034 .58154 L F
.23772 .58135 m .23822 .58493 L .2407 .58427 L F
.006 0 .074 r
.37367 .59752 m .37451 .59875 L .3764 .59665 L F
.724 .523 .618 r
.66697 .35023 m .66933 .34991 L .66705 .35289 L F
.739 .544 .63 r
.66933 .34991 m .67166 .35329 L .66705 .35289 L F
.688 .73 .217 r
.33745 .50853 m .33632 .51224 L .3369 .51029 L F
0 0 .536 r
.33745 .50853 m .33805 .50737 L .33633 .50446 L F
.723 .682 .81 r
.3369 .51029 m .33805 .50737 L .33745 .50853 L F
.975 .67 .345 r
.40079 .55478 m .40031 .5548 L .40216 .55522 L F
.967 .648 .275 r
.40087 .55717 m .40216 .55522 L .40031 .5548 L F
.222 0 .124 r
.3716 .71627 m .37539 .71208 L .37396 .71163 L F
.141 .595 .927 r
.37539 .71208 m .37628 .71139 L .37396 .71163 L F
.37539 .71208 m .37689 .71239 L .37628 .71139 L F
.667 .606 .777 r
.62573 .37765 m .62454 .3827 L .62328 .37891 L F
.62573 .37765 m .62695 .38155 L .62454 .3827 L F
.982 .714 .438 r
.33329 .69244 m .33495 .69274 L .33342 .68912 L F
0 .2 .718 r
.33418 .69092 m .33495 .69274 L .33568 .69135 L F
.596 .936 .946 r
.33568 .69135 m .33495 .69274 L .33329 .69244 L F
.783 .552 .586 r
.33386 .69323 m .33671 .69165 L .33568 .69135 L F
.33671 .69165 m .33815 .69085 L .33568 .69135 L F
0 .2 .718 r
.33342 .68912 m .33418 .69092 L .33568 .69135 L F
.913 .754 .671 r
.69634 .32362 m .69769 .32757 L .69801 .32498 L F
.74 .562 .652 r
.41924 .50264 m .41941 .5054 L .41595 .5052 L F
.64 .648 .842 r
.42177 .50221 m .41924 .50264 L .41755 .49963 L F
.617 .468 .656 r
.42177 .50221 m .41941 .5054 L .41924 .50264 L F
.466 .446 .751 r
.42268 .55331 m .42014 .55356 L .41911 .54954 L F
.472 .765 .995 r
.62648 .44072 m .62913 .44016 L .62933 .44121 L F
.37 .826 .926 r
.62913 .44016 m .63341 .43988 L .62933 .44121 L F
.509 .366 .622 r
.26007 .54951 m .25779 .5531 L .25753 .55005 L F
.04 0 0 r
.33963 .57496 m .33717 .57692 L .33538 .57721 L F
.385 .009 .197 r
.34086 .5744 m .33717 .57692 L .33963 .57496 L F
.006 0 .222 r
.34158 .57197 m .34086 .5744 L .33963 .57496 L F
.659 .168 .073 r
.22568 .5558 m .22722 .5575 L .22911 .55631 L F
.413 0 0 r
.22722 .5575 m .23158 .55647 L .22911 .55631 L F
.22722 .5575 m .22958 .55766 L .23158 .55647 L F
.542 .137 .223 r
.23336 .55899 m .22863 .56145 L .22897 .5596 L F
.587 .296 .442 r
.22722 .5575 m .22916 .55995 L .22958 .55766 L F
0 .051 .618 r
.22747 .55632 m .22886 .55932 L .22722 .5575 L F
.22886 .55932 m .22916 .55995 L .22722 .5575 L F
.659 .168 .073 r
.22518 .55572 m .22722 .5575 L .22568 .5558 L F
.838 .634 .626 r
.43648 .53776 m .4331 .53952 L .43278 .53713 L F
.43648 .53776 m .43719 .54057 L .4331 .53952 L F
.473 .408 .703 r
.43935 .53965 m .43648 .53776 L .4387 .53702 L F
.43935 .53965 m .43719 .54057 L .43648 .53776 L F
.368 .2 .517 r
.71833 .35921 m .71841 .36193 L .71598 .36296 L F
.219 0 .22 r
.71598 .36296 m .71763 .36378 L .71606 .36514 L F
.71598 .36296 m .71841 .36193 L .71763 .36378 L F
.161 .318 .775 r
.284 .52915 m .28554 .53307 L .28282 .5307 L F
.387 .355 .702 r
.28554 .53307 m .28377 .53418 L .28282 .5307 L F
.685 .949 .957 r
.29416 .51878 m .28928 .52004 L .29134 .51888 L F
.699 .962 .943 r
.29588 .51752 m .29416 .51878 L .29134 .51888 L F
.807 .548 0 r
.35784 .6161 m .35864 .61976 L .3584 .61935 L F
.888 .895 .476 r
.3584 .61935 m .35864 .61976 L .35748 .62158 L F
0 0 .363 r
.35876 .61817 m .35864 .61976 L .35784 .6161 L F
.907 .621 .49 r
.35784 .6161 m .3584 .61935 L .35747 .61871 L F
.35707 .61673 m .35747 .61871 L .35593 .61765 L F
.35784 .6161 m .35747 .61871 L .35707 .61673 L F
.827 .887 .46 r
.35801 .62138 m .35876 .61817 L .3593 .6209 L F
.35748 .62158 m .35785 .62059 L .35801 .62138 L F
.638 .579 .772 r
.35446 .62198 m .35593 .61765 L .3584 .61935 L F
.888 .895 .476 r
.3584 .61935 m .35748 .62158 L .35446 .62198 L F
.827 .887 .46 r
.35748 .62158 m .35864 .61976 L .35876 .61817 L F
.35785 .62059 m .35876 .61817 L .35801 .62138 L F
.072 0 0 r
.33531 .67717 m .33156 .67906 L .33279 .67844 L F
.652 .959 .763 r
.33657 .67585 m .33531 .67717 L .33279 .67844 L F
.367 .054 .296 r
.24863 .56894 m .24708 .57206 L .24515 .57248 L F
.639 .511 .691 r
.25084 .56611 m .25127 .56873 L .24863 .56894 L F
.754 .472 .505 r
.25124 .57171 m .24863 .56894 L .25127 .56873 L F
.25124 .57171 m .24708 .57206 L .24863 .56894 L F
.526 .827 .999 r
.23675 .56056 m .23778 .55903 L .23548 .55991 L F
.23675 .56056 m .23925 .56 L .23778 .55903 L F
.511 .517 .799 r
.29419 .5531 m .29785 .5559 L .29711 .55281 L F
.657 .251 .263 r
.36555 .67578 m .36646 .67714 L .36312 .67905 L F
.36555 .67578 m .3671 .67671 L .36646 .67714 L F
.67 .789 .938 r
.71895 .34946 m .72278 .35009 L .7216 .34832 L F
.7216 .34832 m .72278 .35009 L .71895 .34946 L F
.599 .763 .957 r
.72278 .35009 m .72478 .34745 L .7216 .34832 L F
.72278 .35009 m .72555 .34933 L .72478 .34745 L F
.72278 .35009 m .72478 .34745 L .7216 .34832 L F
.72278 .35009 m .72555 .34933 L .72478 .34745 L F
.853 .791 .79 r
.70892 .28664 m .70565 .28611 L .70811 .28446 L F
.70892 .28664 m .70645 .28978 L .70565 .28611 L F
.814 .796 .836 r
.71159 .28266 m .70892 .28664 L .70811 .28446 L F
.698 .624 .771 r
.71159 .28266 m .71257 .28691 L .70892 .28664 L F
.774 .576 .631 r
.67166 .35329 m .67332 .35298 L .67125 .35597 L F
.394 0 .074 r
.28166 .55361 m .28042 .555 L .27807 .55505 L F
.485 .155 .331 r
.2835 .55274 m .28042 .555 L .28166 .55361 L F
.335 0 .117 r
.28904 .54364 m .29148 .54314 L .29209 .54209 L F
.672 .834 .41 r
.29148 .54314 m .29318 .5401 L .29209 .54209 L F
.519 .755 .982 r
.2407 .5707 m .24243 .57242 L .24296 .57022 L F
.377 0 0 r
.24243 .57242 m .24415 .57297 L .24515 .57248 L F
.149 .359 .815 r
.24243 .57242 m .24415 .57297 L .24296 .57022 L F
.027 0 .384 r
.71365 .28329 m .71257 .28691 L .71159 .28266 L F
.71365 .28329 m .71408 .2852 L .71257 .28691 L F
0 0 0 r
.71257 .28691 m .71408 .2852 L .71176 .28833 L F
.542 .137 .223 r
.23336 .55899 m .23132 .56135 L .22863 .56145 L F
.44 0 .091 r
.23548 .55991 m .23132 .56135 L .23336 .55899 L F
.329 .01 .264 r
.27739 .55047 m .27741 .55333 L .27924 .55151 L F
.351 0 .207 r
.27739 .55047 m .27924 .55151 L .27976 .54977 L F
.525 .335 .566 r
.27791 .61385 m .28042 .61352 L .28053 .61023 L F
.602 .568 .788 r
.28446 .61354 m .28053 .61023 L .28289 .60968 L F
.674 .537 .69 r
.28289 .60968 m .28042 .61352 L .28053 .61023 L F
.718 .886 .958 r
.28876 .6535 m .29023 .65464 L .29243 .65314 L F
0 .03 .555 r
.61383 .38342 m .61537 .38522 L .61413 .38366 L F
0 0 0 r
.61383 .38342 m .61434 .38229 L .61344 .38312 L F
.61577 .38062 m .61434 .38229 L .61383 .38342 L F
.61577 .38062 m .6141 .38302 L .61349 .38286 L F
.6141 .38302 m .61383 .38342 L .61349 .38286 L F
0 .03 .555 r
.61383 .38342 m .61413 .38366 L .61349 .38286 L F
.366 .754 .988 r
.61537 .38522 m .61312 .38276 L .61349 .38286 L F
.61312 .38276 m .61243 .38201 L .61349 .38286 L F
0 0 0 r
.61383 .38342 m .61344 .38312 L .61166 .38478 L F
.27 .293 .702 r
.61166 .38478 m .61397 .38684 L .61383 .38342 L F
.543 .372 .599 r
.31522 .57237 m .31284 .57541 L .31423 .57316 L F
0 0 .374 r
.31284 .57541 m .31407 .57647 L .31423 .57316 L F
.31284 .57541 m .31297 .57799 L .31407 .57647 L F
.958 .669 .235 r
.40638 .57466 m .40653 .57728 L .4076 .57848 L F
.876 .644 .118 r
.40653 .57728 m .40735 .58111 L .4076 .57848 L F
.914 .923 .806 r
.39226 .62816 m .3957 .62545 L .3954 .62554 L F
.693 .681 .834 r
.23901 .5871 m .2425 .58741 L .2407 .58427 L F
.491 .539 .834 r
.2425 .58741 m .24322 .58369 L .2407 .58427 L F
.2425 .58741 m .24483 .58738 L .24322 .58369 L F
.439 .213 .473 r
.31746 .57152 m .31522 .57237 L .31423 .57316 L F
0 0 .116 r
.31407 .57647 m .31626 .57331 L .31423 .57316 L F
.701 .566 .699 r
.23492 .58449 m .23901 .5871 L .23822 .58493 L F
.23492 .58449 m .236 .58802 L .23901 .5871 L F
.795 .887 .466 r
.39288 .60644 m .39337 .60582 L .3951 .60228 L F
0 0 0 r
.3951 .60228 m .39337 .60582 L .3934 .60578 L F
.794 .352 .198 r
.39481 .60388 m .39343 .6057 L .3951 .60228 L F
0 0 0 r
.3951 .60228 m .3934 .60578 L .39486 .60317 L F
.794 .352 .198 r
.39343 .6057 m .39288 .60644 L .3951 .60228 L F
.39554 .60504 m .39636 .60637 L .39426 .60641 L F
.39554 .60504 m .39373 .60642 L .39357 .60607 L F
0 .319 .782 r
.39337 .60582 m .3937 .60601 L .39346 .60584 L F
.39337 .60582 m .39346 .60584 L .39342 .60574 L F
.612 .099 .004 r
.39288 .60644 m .3937 .60601 L .39337 .60582 L F
.794 .352 .198 r
.39481 .60388 m .39554 .60504 L .39288 .60644 L F
.913 .531 .108 r
.39636 .60637 m .39569 .60716 L .39288 .60644 L F
0 .319 .782 r
.39346 .60584 m .39569 .60716 L .39505 .60618 L F
.794 .352 .198 r
.39554 .60504 m .39426 .60641 L .39399 .60622 L F
0 .319 .782 r
.3937 .60601 m .39569 .60716 L .39346 .60584 L F
.794 .352 .198 r
.39399 .60622 m .39426 .60641 L .39373 .60642 L F
.39357 .60607 m .39373 .60642 L .39288 .60644 L F
0 .319 .782 r
.39342 .60574 m .39505 .60618 L .39486 .60317 L F
.39346 .60584 m .39505 .60618 L .39342 .60574 L F
.612 .099 .004 r
.39288 .60644 m .39569 .60716 L .3937 .60601 L F
0 0 0 r
.2975 .52148 m .29649 .52357 L .29512 .5248 L F
.29524 .52501 m .29512 .5248 L .29649 .52357 L F
.29524 .52501 m .29312 .52621 L .29512 .5248 L F
.668 .628 .8 r
.36197 .58811 m .36465 .58785 L .36323 .58412 L F
.702 .983 .824 r
.36137 .5903 m .36465 .58785 L .36552 .59074 L F
.503 .081 .171 r
.36336 .59031 m .36197 .58811 L .36137 .5903 L F
.36336 .59031 m .36465 .58785 L .36197 .58811 L F
.426 .146 .382 r
.26608 .62531 m .26903 .62248 L .26669 .62325 L F
.727 .292 0 r
.32975 .53713 m .32905 .53612 L .32882 .53514 L F
.45 .25 .516 r
.32882 .53514 m .32567 .53418 L .32856 .53405 L F
.32882 .53514 m .32591 .53616 L .32567 .53418 L F
.588 .769 .966 r
.32447 .53461 m .32591 .53616 L .32882 .53514 L F
.32447 .53461 m .32882 .53514 L .32682 .53423 L F
.727 .292 0 r
.32905 .53612 m .32789 .53447 L .32882 .53514 L F
.45 .25 .516 r
.32882 .53514 m .32856 .53405 L .32989 .53399 L F
.81 .585 .597 r
.33376 .5343 m .32882 .53514 L .32989 .53399 L F
.442 .729 .987 r
.35156 .52264 m .351 .52457 L .34731 .52332 L F
.579 .378 .573 r
.351 .52457 m .35329 .52585 L .3534 .52388 L F
.351 .52457 m .35073 .52731 L .35329 .52585 L F
0 0 .14 r
.35147 .52568 m .351 .52457 L .35156 .52264 L F
.35147 .52568 m .35073 .52731 L .351 .52457 L F
.798 .618 .658 r
.66146 .34628 m .66305 .34692 L .65948 .34667 L F
.696 .483 .595 r
.66305 .34692 m .65893 .34914 L .65948 .34667 L F
.66305 .34692 m .66313 .34955 L .65893 .34914 L F
.823 .806 .835 r
.66427 .34268 m .66305 .34692 L .66146 .34628 L F
.66427 .34268 m .66594 .3442 L .66305 .34692 L F
.609 .26 .354 r
.36477 .55646 m .367 .5588 L .36652 .55475 L F
.36477 .55646 m .36318 .55899 L .367 .5588 L F
.916 .862 .772 r
.58524 .41875 m .58554 .4227 L .58434 .42447 L F
.58524 .41875 m .58466 .42242 L .58275 .41994 L F
.774 .697 .778 r
.58618 .41923 m .58653 .41963 L .58645 .41986 L F
.58505 .41657 m .58653 .41963 L .58618 .41923 L F
.752 .951 .942 r
.58741 .41982 m .58691 .42008 L .58653 .41963 L F
.58691 .42008 m .58469 .42119 L .58653 .41963 L F
.58837 .42003 m .58661 .42058 L .58741 .41982 L F
.58661 .42058 m .58469 .42119 L .58741 .41982 L F
.916 .862 .772 r
.58466 .42242 m .58463 .42266 L .58454 .42254 L F
.58466 .42242 m .58454 .42254 L .58275 .41994 L F
.58463 .42266 m .58434 .42447 L .58395 .42336 L F
.58463 .42266 m .58395 .42336 L .58275 .41994 L F
.752 .951 .942 r
.58837 .42003 m .58554 .4227 L .58519 .42207 L F
.58661 .42058 m .58519 .42207 L .58469 .42119 L F
.58837 .42003 m .58519 .42207 L .58661 .42058 L F
.657 .703 .88 r
.58837 .42003 m .58991 .42297 L .58554 .4227 L F
.791 .627 .678 r
.58991 .42297 m .58586 .42494 L .58554 .4227 L F
.6 .836 .989 r
.29984 .51773 m .29588 .51752 L .29847 .51619 L F
.681 .529 .673 r
.29984 .51773 m .2975 .52148 L .30031 .521 L F
.29984 .51773 m .2975 .52148 L .30031 .521 L F
.705 .785 .914 r
.30219 .51632 m .29984 .51773 L .29847 .51619 L F
.533 .424 .676 r
.29984 .51773 m .30031 .521 L .30281 .51976 L F
0 0 .205 r
.30024 .51837 m .29984 .51773 L .30111 .5186 L F
.705 .785 .914 r
.30219 .51632 m .29847 .51619 L .30137 .51434 L F
.634 .958 .921 r
.30137 .51434 m .29847 .51619 L .29666 .51608 L F
.30137 .51434 m .29666 .51608 L .29851 .51527 L F
.29897 .51507 m .29851 .51527 L .2989 .51509 L F
.30137 .51434 m .29851 .51527 L .29897 .51507 L F
.841 .88 .87 r
.30513 .51372 m .30219 .51632 L .30137 .51434 L F
.854 .853 .841 r
.3037 .5124 m .30513 .51372 L .30137 .51434 L F
.777 .998 .825 r
.30196 .51281 m .3037 .5124 L .30137 .51434 L F
.657 .654 .836 r
.30024 .51837 m .30305 .51747 L .30178 .51389 L F
.761 .993 .876 r
.30196 .51281 m .30137 .51434 L .2989 .51509 L F
.657 .654 .836 r
.30129 .51409 m .30178 .51389 L .30152 .51316 L F
.30024 .51837 m .30178 .51389 L .30129 .51409 L F
.30024 .51837 m .30152 .51316 L .29952 .51818 L F
.30024 .51837 m .29952 .51818 L .29948 .51829 L F
0 0 .205 r
.30024 .51837 m .30111 .5186 L .30281 .51976 L F
.30024 .51837 m .30031 .521 L .29984 .51773 L F
.685 .351 .404 r
.37178 .68903 m .37597 .68862 L .37646 .68638 L F
.401 .075 .293 r
.37597 .68862 m .37895 .68595 L .37646 .68638 L F
.521 .335 .57 r
.37646 .68638 m .37895 .68595 L .37897 .68313 L F
.843 .861 .856 r
.33272 .49955 m .32994 .50236 L .32792 .50121 L F
.996 .784 .497 r
.4021 .56127 m .4039 .55921 L .40225 .55834 L F
.4021 .56127 m .40343 .56227 L .4039 .55921 L F
.702 .789 .918 r
.62557 .41875 m .62462 .42002 L .62242 .42011 L F
.496 .591 .879 r
.62626 .42297 m .62242 .42011 L .62462 .42002 L F
.503 .483 .768 r
.62866 .42208 m .62462 .42002 L .62557 .41875 L F
.62866 .42208 m .62626 .42297 L .62462 .42002 L F
.587 .514 .74 r
.25119 .58432 m .24869 .58531 L .24763 .58149 L F
0 0 0 r
.25119 .58432 m .24717 .58643 L .24869 .58531 L F
.599 .335 .488 r
.37074 .52474 m .37056 .52753 L .36766 .52732 L F
.676 .669 .836 r
.37074 .52474 m .37163 .52143 L .37005 .52198 L F
.728 .445 .499 r
.37074 .52474 m .37056 .52753 L .37425 .5273 L F
.987 .715 .405 r
.3688 .52283 m .37056 .52753 L .37074 .52474 L F
.484 .37 .649 r
.43199 .56861 m .43594 .57078 L .43528 .56755 L F
.896 .95 .831 r
.55135 .41424 m .55005 .41805 L .54818 .41597 L F
.518 .8 .997 r
.19964 .60658 m .20381 .60725 L .20195 .60603 L F
.414 .781 .994 r
.20381 .60725 m .20403 .60595 L .20195 .60603 L F
.314 0 0 r
.38227 .59375 m .38356 .5951 L .38244 .59381 L F
.38227 .59375 m .38046 .59608 L .38356 .5951 L F
.648 .218 .212 r
.42868 .57219 m .43351 .57215 L .43051 .57346 L F
.554 .622 .874 r
.30017 .53401 m .29634 .53153 L .29937 .52984 L F
.431 .434 .761 r
.30122 .53108 m .30017 .53401 L .29937 .52984 L F
.416 .355 .681 r
.30017 .53401 m .30173 .53369 L .30171 .5313 L F
.431 .434 .761 r
.30122 .53108 m .30173 .53369 L .30017 .53401 L F
.643 .231 .248 r
.30275 .53606 m .30017 .53401 L .30173 .53369 L F
.644 .229 .241 r
.30017 .53401 m .30275 .53606 L .30173 .53369 L F
.30017 .53401 m .30036 .53615 L .30266 .53599 L F
.582 .892 .989 r
.29912 .53462 m .29873 .53626 L .30086 .53526 L F
.29873 .53626 m .29873 .53628 L .29877 .53626 L F
.29873 .53626 m .29877 .53626 L .30086 .53526 L F
.644 .229 .241 r
.30266 .53599 m .30039 .53648 L .30275 .53606 L F
.30036 .53615 m .30039 .53648 L .30266 .53599 L F
.519 .543 .82 r
.2817 .61779 m .28264 .61497 L .28142 .61646 L F
.255 .592 .949 r
.60487 .39242 m .60393 .39318 L .60277 .39231 L F
.60487 .39242 m .60642 .39403 L .60393 .39318 L F
.003 0 .358 r
.26637 .53433 m .26342 .53355 L .263 .53235 L F
.26637 .53433 m .26523 .53678 L .26342 .53355 L F
.855 .463 0 r
.33805 .63774 m .33908 .63937 L .33809 .63846 L F
.61 .721 .924 r
.34174 .63807 m .33908 .63937 L .33744 .63634 L F
.308 0 .061 r
.33959 .63861 m .3381 .63869 L .33812 .63908 L F
.3381 .63869 m .33683 .63876 L .33812 .63908 L F
.855 .463 0 r
.33809 .63846 m .33908 .63937 L .33838 .63916 L F
.33723 .63645 m .33805 .63774 L .33809 .63846 L F
.544 .458 .708 r
.33683 .63876 m .33809 .63851 L .33748 .63719 L F
.242 .131 .521 r
.33748 .63719 m .33683 .63876 L .33723 .63645 L F
.544 .458 .708 r
.33683 .63876 m .33748 .63719 L .33732 .63683 L F
.084 .38 .843 r
.33744 .63634 m .33889 .63901 L .33723 .63645 L F
.33889 .63901 m .33886 .63902 L .33723 .63645 L F
.61 .721 .924 r
.34174 .63807 m .33744 .63634 L .34077 .63793 L F
.673 .976 .868 r
.33959 .63861 m .34174 .63807 L .34079 .63793 L F
.61 .721 .924 r
.34174 .63807 m .34077 .63793 L .34083 .63796 L F
.673 .976 .868 r
.34079 .63793 m .34174 .63807 L .3422 .63714 L F
.544 .458 .708 r
.33732 .63683 m .34077 .63794 L .33744 .63634 L F
.34077 .63794 m .34083 .63796 L .34077 .63793 L F
.34077 .63794 m .34077 .63793 L .33744 .63634 L F
.855 .463 0 r
.33723 .63645 m .33838 .63916 L .33748 .63719 L F
.544 .458 .708 r
.33809 .63851 m .34083 .63796 L .33732 .63683 L F
.673 .976 .868 r
.33959 .63861 m .34071 .63798 L .34249 .63657 L F
.34071 .63798 m .3422 .63714 L .34247 .63661 L F
.34071 .63798 m .34247 .63661 L .34249 .63657 L F
.308 0 .061 r
.33959 .63861 m .34083 .63796 L .34071 .63798 L F
.33959 .63861 m .34071 .63798 L .33809 .63851 L F
.3381 .63869 m .33809 .63851 L .33683 .63876 L F
.33959 .63861 m .33809 .63851 L .3381 .63869 L F
.855 .463 0 r
.33748 .63719 m .33809 .63851 L .33812 .63908 L F
.33809 .63851 m .33838 .63916 L .33813 .63908 L F
.33809 .63851 m .33813 .63908 L .33812 .63908 L F
.242 .131 .521 r
.33812 .63908 m .33683 .63876 L .33748 .63719 L F
.471 .894 .853 r
.33812 .63908 m .33986 .6386 L .33959 .63861 L F
.33986 .6386 m .34174 .63807 L .34015 .63847 L F
.33986 .6386 m .34015 .63847 L .33959 .63861 L F
.084 .38 .843 r
.33889 .63901 m .33908 .63937 L .33886 .63902 L F
.471 .894 .853 r
.33812 .63908 m .33908 .63937 L .34174 .63807 L F
.423 .265 .56 r
.44105 .58046 m .43878 .57832 L .44119 .57767 L F
.44105 .58046 m .4389 .58128 L .43878 .57832 L F
.785 .989 .891 r
.37327 .68185 m .37279 .68359 L .37374 .68317 L F
.404 .702 .982 r
.37374 .68317 m .37569 .68117 L .37327 .68185 L F
.37374 .68317 m .3769 .68294 L .37569 .68117 L F
.159 .693 .845 r
.37897 .68313 m .3769 .68294 L .37681 .68315 L F
.53 .355 .589 r
.37895 .68595 m .38141 .68263 L .37897 .68313 L F
.571 .112 .125 r
.38141 .68263 m .37953 .68451 L .3769 .68294 L F
0 .216 .638 r
.3769 .68294 m .37808 .68353 L .37707 .68253 L F
.3769 .68294 m .37707 .68253 L .37569 .68117 L F
.159 .693 .845 r
.37681 .68315 m .3769 .68294 L .37374 .68317 L F
0 0 0 r
.39471 .61223 m .39255 .61273 L .39147 .61463 L F
.578 .625 .862 r
.38187 .71446 m .38046 .71217 L .38198 .71172 L F
.506 .303 .538 r
.38461 .70854 m .38444 .71125 L .38198 .71172 L F
.602 .432 .624 r
.38444 .71125 m .38187 .71446 L .38198 .71172 L F
0 0 0 r
.729 .34986 m .72884 .35147 L .72678 .35326 L F
.825 .838 .858 r
.69392 .30631 m .6897 .30783 L .69231 .30457 L F
.848 .898 .872 r
.67582 .3314 m .67186 .33293 L .67454 .32976 L F
.866 .861 .833 r
.67853 .32802 m .67582 .3314 L .67454 .32976 L F
0 0 0 r
.22854 .53972 m .22962 .53923 L .2319 .53788 L F
.22854 .53972 m .22609 .5413 L .22962 .53923 L F
.168 .693 .871 r
.3779 .54506 m .37646 .54461 L .37443 .54472 L F
.133 .316 .783 r
.3779 .54506 m .37968 .54404 L .37646 .54461 L F
.3779 .54506 m .38006 .54535 L .37968 .54404 L F
.254 .758 .723 r
.62727 .40001 m .63138 .3988 L .63032 .39717 L F
.551 .353 .566 r
.63138 .3988 m .63368 .39736 L .63032 .39717 L F
.63138 .3988 m .63382 .39993 L .63368 .39736 L F
.577 .046 0 r
.39235 .53255 m .39361 .53367 L .39269 .53283 L F
.39244 .53269 m .39361 .53367 L .39235 .53255 L F
.39098 .53146 m .39244 .53269 L .39235 .53255 L F
0 .209 .681 r
.39098 .53146 m .39265 .53256 L .39361 .53367 L F
0 0 .333 r
.39265 .53256 m .39342 .53577 L .39361 .53367 L F
.39282 .53325 m .39341 .53474 L .39342 .53577 L F
.39265 .53256 m .39297 .53348 L .39282 .53325 L F
.39297 .53348 m .39341 .53474 L .39282 .53325 L F
.024 0 0 r
.23406 .54956 m .23256 .54966 L .23004 .54969 L F
0 0 0 r
.23696 .54686 m .23493 .54888 L .23406 .54956 L F
.363 .834 .844 r
.23493 .54888 m .23256 .54966 L .23406 .54956 L F
.377 .367 .721 r
.4344 .51648 m .43307 .52096 L .43211 .51846 L F
.4344 .51648 m .43494 .52054 L .43307 .52096 L F
.46 .371 .668 r
.43596 .52343 m .43307 .52096 L .43494 .52054 L F
.43596 .52343 m .43323 .52497 L .43307 .52096 L F
.235 0 .289 r
.20472 .56585 m .20392 .56824 L .20664 .56497 L F
0 .492 .704 r
.54981 .42599 m .55096 .42617 L .54702 .42559 L F
.54981 .42599 m .55096 .42617 L .54702 .42559 L F
0 0 0 r
.55129 .42594 m .55096 .42617 L .54981 .42599 L F
.55129 .42594 m .55366 .42412 L .55096 .42617 L F
0 0 .442 r
.55096 .42617 m .55133 .42912 L .5527 .4266 L F
.55096 .42617 m .5527 .4266 L .54981 .42599 L F
0 0 0 r
.38655 .61262 m .38758 .61032 L .38634 .61271 L F
.584 .312 .469 r
.58516 .44857 m .58525 .45095 L .58247 .45102 L F
.538 .276 .467 r
.58795 .45038 m .58516 .44857 L .58887 .44802 L F
.58795 .45038 m .58525 .45095 L .58516 .44857 L F
.438 0 0 r
.33636 .55639 m .33508 .55706 L .33612 .55714 L F
.844 .478 0 r
.33636 .55639 m .33702 .55742 L .33651 .55592 L F
.33636 .55639 m .33695 .55848 L .33702 .55742 L F
.471 .227 .462 r
.33892 .55736 m .33695 .55848 L .33636 .55639 L F
.438 0 0 r
.33636 .55639 m .33612 .55714 L .33892 .55736 L F
.844 .478 0 r
.33636 .55639 m .33651 .55592 L .33648 .55582 L F
0 .21 .726 r
.38536 .70716 m .38461 .70854 L .38569 .70843 L F
.56 .347 .548 r
.38461 .70854 m .38729 .71098 L .38444 .71125 L F
.837 .783 .8 r
.35694 .65864 m .35967 .65782 L .35898 .65726 L F
0 0 .089 r
.73106 .34576 m .7307 .34769 L .729 .34986 L F
0 0 0 r
.7307 .34769 m .72884 .35147 L .729 .34986 L F
0 0 .192 r
.36392 .58183 m .36323 .58412 L .36536 .5807 L F
.92 .756 .662 r
.69517 .32586 m .69769 .32757 L .69634 .32362 L F
.716 .193 0 r
.69517 .32586 m .69695 .32791 L .69769 .32757 L F
0 .457 .779 r
.69939 .32774 m .69769 .32757 L .69695 .32791 L F
.69939 .32774 m .70147 .32857 L .69875 .32785 L F
.474 .68 .956 r
.70231 .32671 m .70147 .32857 L .69939 .32774 L F
0 0 0 r
.69939 .32774 m .69826 .32913 L .69993 .32764 L F
.69939 .32774 m .7016 .32615 L .70231 .32671 L F
.69939 .32774 m .69993 .32764 L .7016 .32615 L F
0 .457 .779 r
.69939 .32774 m .69875 .32785 L .69769 .32757 L F
.373 .108 .378 r
.34396 .64821 m .34132 .65134 L .34436 .65069 L F
0 0 .096 r
.34541 .6454 m .34396 .64821 L .34501 .64673 L F
.152 .037 .457 r
.34501 .64673 m .34396 .64821 L .34436 .65069 L F
.574 .64 .878 r
.25335 .55239 m .25565 .55622 L .25776 .55518 L F
.655 .541 .713 r
.25776 .55518 m .25525 .55922 L .25565 .55622 L F
.456 .547 .86 r
.63859 .39941 m .63901 .39599 L .63606 .3967 L F
.63859 .39941 m .64036 .39999 L .63901 .39599 L F
.79 .594 .635 r
.35685 .6134 m .35309 .61567 L .35363 .61321 L F
.35699 .61405 m .35309 .61567 L .35685 .6134 L F
.35834 .61349 m .35784 .6161 L .35309 .61567 L F
.954 .606 .28 r
.35558 .61254 m .35608 .61538 L .35737 .6159 L F
.3572 .61508 m .35737 .6159 L .35784 .6161 L F
.35558 .61254 m .35737 .6159 L .3572 .61508 L F
.79 .594 .635 r
.35834 .61349 m .35699 .61405 L .35685 .6134 L F
.954 .606 .28 r
.35558 .61254 m .35784 .6161 L .35834 .61349 L F
.721 .676 .806 r
.32001 .55229 m .32468 .55492 L .32212 .55195 L F
.069 .21 .703 r
.32468 .55492 m .32477 .55113 L .32212 .55195 L F
.32468 .55492 m .3261 .55491 L .32477 .55113 L F
.391 .407 .757 r
.3261 .55491 m .32524 .55922 L .32468 .55492 L F
.19 0 0 r
.32303 .55623 m .3261 .55491 L .32468 .55492 L F
.392 .202 .5 r
.62625 .4254 m .62626 .42297 L .62866 .42208 L F
.57 .263 .409 r
.30339 .52908 m .30499 .53061 L .30542 .5274 L F
.30339 .52908 m .30171 .5313 L .30499 .53061 L F
0 0 0 r
.23706 .54735 m .23696 .54686 L .23918 .5467 L F
.23706 .54735 m .23493 .54888 L .23696 .54686 L F
.21261 .55648 m .21185 .55865 L .21348 .55506 L F
.849 .794 .797 r
.26991 .53598 m .26637 .53433 L .26871 .53282 L F
.26991 .53598 m .26852 .53739 L .26637 .53433 L F
.842 .793 .804 r
.26637 .53433 m .26526 .53727 L .26719 .53735 L F
.26815 .53687 m .26719 .53735 L .26852 .53739 L F
.26637 .53433 m .26719 .53735 L .26815 .53687 L F
.949 .875 .728 r
.26578 .53839 m .26852 .53739 L .26526 .53727 L F
.26578 .53839 m .26852 .53739 L .26991 .53598 L F
.26578 .53839 m .26977 .53606 L .26765 .53785 L F
.26977 .53606 m .26991 .53598 L .26988 .53601 L F
.26977 .53606 m .26988 .53601 L .26765 .53785 L F
0 0 .142 r
.27125 .53252 m .26991 .53598 L .26871 .53282 L F
.27125 .53252 m .27098 .53519 L .26991 .53598 L F
0 0 0 r
.27098 .53519 m .26765 .53785 L .26991 .53598 L F
.523 .376 .623 r
.59557 .42167 m .59513 .42414 L .59324 .42464 L F
.59291 .42444 m .59324 .42464 L .59253 .42483 L F
.59557 .42167 m .59324 .42464 L .59291 .42444 L F
.59557 .42167 m .59291 .42444 L .59322 .42448 L F
.59291 .42444 m .59253 .42483 L .59322 .42448 L F
.164 .404 .847 r
.59322 .42448 m .59228 .42406 L .58837 .42003 L F
.59228 .42406 m .58991 .42297 L .58963 .42244 L F
.59228 .42406 m .58963 .42244 L .58837 .42003 L F
.053 .307 .794 r
.59253 .42483 m .58991 .42297 L .59322 .42448 L F
.485 .582 .877 r
.38377 .58546 m .3868 .5874 L .38606 .58593 L F
.339 0 0 r
.38259 .58679 m .38377 .58546 L .38606 .58593 L F
.655 .967 .906 r
.6411 .42748 m .63746 .42894 L .63898 .42733 L F
.77 .901 .933 r
.64209 .42474 m .6411 .42748 L .63898 .42733 L F
.64209 .42474 m .6433 .42598 L .6411 .42748 L F
.79 .685 .748 r
.55218 .41914 m .55366 .42412 L .55617 .41964 L F
.354 .281 .635 r
.55831 .41883 m .55617 .41964 L .55866 .42169 L F
.439 .256 .535 r
.55617 .41964 m .55371 .42403 L .55626 .42282 L F
.406 .853 .773 r
.55852 .42174 m .55626 .42282 L .55373 .42356 L F
.55866 .42169 m .55626 .42282 L .55852 .42174 L F
.439 .256 .535 r
.55371 .42403 m .55366 .42412 L .55626 .42282 L F
0 0 0 r
.74377 .32409 m .74223 .3263 L .74211 .32643 L F
.288 .743 .955 r
.7395 .32348 m .74223 .32363 L .74377 .32409 L F
.928 .754 .646 r
.74377 .32409 m .74223 .32363 L .74223 .3263 L F
0 0 .328 r
.74222 .32556 m .74237 .32614 L .74223 .3263 L F
.74237 .32614 m .74306 .32887 L .74223 .3263 L F
0 0 0 r
.74211 .32643 m .74223 .3263 L .74134 .32752 L F
.493 .277 .513 r
.29148 .54314 m .28865 .54625 L .28904 .54364 L F
0 0 0 r
.28904 .54364 m .28898 .54412 L .29148 .54314 L F
.28904 .54364 m .28865 .54625 L .28898 .54412 L F
.613 .598 .812 r
.23822 .58493 m .23901 .5871 L .2407 .58427 L F
.72 .781 .9 r
.34436 .65069 m .34858 .65121 L .34616 .65237 L F
.431 .448 .777 r
.33868 .52023 m .33744 .52174 L .33673 .51798 L F
0 0 0 r
.33868 .52023 m .33618 .52342 L .33744 .52174 L F
.336 .559 .918 r
.20314 .59637 m .20466 .59898 L .20692 .59857 L F
.388 .183 .477 r
.23035 .59442 m .23244 .5941 L .23311 .59079 L F
.462 .481 .793 r
.31873 .62467 m .31641 .62621 L .31588 .62386 L F
.31649 .62324 m .31588 .62386 L .31562 .62269 L F
.31873 .62467 m .31588 .62386 L .31649 .62324 L F
.31873 .62467 m .31562 .62269 L .31562 .62269 L F
.31873 .62467 m .31562 .62269 L .31813 .62185 L F
0 0 0 r
.31757 .62215 m .31415 .62354 L .31574 .62313 L F
.31415 .62354 m .31353 .6238 L .31574 .62313 L F
.189 0 .108 r
.31793 .62295 m .31811 .62251 L .31574 .62313 L F
0 0 0 r
.31715 .62227 m .31353 .6238 L .31757 .62215 L F
.462 .481 .793 r
.31562 .62269 m .31562 .62269 L .31562 .62269 L F
0 0 0 r
.31813 .62185 m .31562 .62269 L .31353 .6238 L F
.629 .942 .724 r
.31887 .62058 m .31851 .62121 L .31574 .62313 L F
.31851 .62121 m .31813 .62185 L .31757 .62215 L F
0 0 0 r
.31813 .62185 m .31715 .62227 L .31757 .62215 L F
.629 .942 .724 r
.31851 .62121 m .31757 .62215 L .31574 .62313 L F
.579 .564 .801 r
.32116 .61906 m .32101 .62175 L .31813 .62185 L F
.278 .055 .385 r
.32101 .62175 m .31873 .62467 L .31813 .62185 L F
.189 0 .108 r
.31811 .62251 m .31887 .62058 L .31574 .62313 L F
.419 .829 .636 r
.31873 .62467 m .31541 .62678 L .31641 .62621 L F
.346 .814 .916 r
.3541 .65918 m .35694 .65864 L .35169 .65873 L F
.377 .837 .773 r
.33569 .66505 m .33847 .66397 L .33609 .66457 L F
.157 0 0 r
.33847 .66397 m .33862 .66441 L .33609 .66457 L F
0 0 .364 r
.22853 .55174 m .22776 .55048 L .23004 .54969 L F
.996 .862 .563 r
.36373 .61333 m .36289 .61627 L .36197 .61499 L F
.759 .537 .596 r
.36197 .61499 m .36622 .6126 L .36373 .61333 L F
.788 .774 .267 r
.43619 .54899 m .43681 .54554 L .43817 .54652 L F
0 0 .493 r
.43682 .5499 m .43795 .55193 L .43619 .54899 L F
.791 .577 .612 r
.43678 .54997 m .43277 .55052 L .43273 .54724 L F
.705 .429 .503 r
.44109 .54946 m .43795 .55193 L .43682 .5499 L F
.719 .513 .611 r
.44109 .54946 m .43682 .5499 L .43817 .54652 L F
.385 .506 .858 r
.436 .54867 m .43795 .55193 L .43967 .55003 L F
.791 .577 .612 r
.43751 .55047 m .43708 .55047 L .43678 .54997 L F
0 0 .363 r
.43619 .54899 m .43795 .55193 L .43703 .55039 L F
.43621 .54902 m .43703 .55039 L .43624 .54908 L F
.43619 .54899 m .43703 .55039 L .43621 .54902 L F
.414 .076 .28 r
.43724 .55075 m .43605 .55457 L .43344 .55466 L F
.43751 .55047 m .43735 .55093 L .43724 .55075 L F
.43735 .55093 m .43605 .55457 L .43724 .55075 L F
.791 .577 .612 r
.43708 .55047 m .43277 .55052 L .43678 .54997 L F
0 0 .363 r
.43601 .54868 m .43624 .54908 L .436 .54867 L F
.43619 .54899 m .43624 .54908 L .43601 .54868 L F
.111 .04 .489 r
.3469 .58145 m .34846 .58329 L .34958 .58126 L F
.3469 .58145 m .34725 .58416 L .34846 .58329 L F
.8 .714 .77 r
.61526 .37514 m .61653 .37855 L .6134 .37769 L F
.761 .306 .167 r
.6134 .37769 m .61653 .37855 L .6158 .38033 L F
.703 .768 .276 r
.6158 .38033 m .61653 .37855 L .61577 .38062 L F
.556 .581 .835 r
.61921 .37793 m .61653 .37855 L .61526 .37514 L F
.524 0 0 r
.35172 .60393 m .35304 .60526 L .35393 .60293 L F
.201 0 .247 r
.20998 .55954 m .20917 .56176 L .21185 .55865 L F
.593 .107 .07 r
.28276 .61353 m .28369 .61414 L .28446 .61354 L F
.28273 .61389 m .28369 .61414 L .28276 .61353 L F
.579 .577 .815 r
.28682 .61277 m .28446 .61354 L .28289 .60968 L F
.28682 .61277 m .28572 .61191 L .28659 .6119 L F
.28572 .61191 m .28289 .60968 L .28659 .6119 L F
.45 .696 .971 r
.28825 .61135 m .28682 .61277 L .28659 .6119 L F
.51 .246 .45 r
.28486 .61527 m .28778 .61189 L .28659 .6119 L F
.28778 .61189 m .28825 .61135 L .28659 .6119 L F
.421 .088 .294 r
.28264 .61497 m .28659 .6119 L .28272 .61397 L F
.28264 .61497 m .28272 .61397 L .28261 .61403 L F
.593 .107 .07 r
.28129 .61352 m .28273 .61389 L .28276 .61353 L F
.28042 .61352 m .28261 .61394 L .28129 .61352 L F
.28261 .61394 m .28369 .61414 L .28129 .61352 L F
.597 .47 .678 r
.28289 .60968 m .28261 .61394 L .28659 .6119 L F
.28261 .61394 m .28261 .61403 L .28272 .61397 L F
.28261 .61394 m .28272 .61397 L .28659 .6119 L F
.674 .537 .69 r
.28289 .60968 m .28261 .61394 L .28042 .61352 L F
.28261 .61394 m .28261 .61403 L .28042 .61352 L F
.595 .09 .023 r
.28042 .61352 m .28264 .61497 L .28261 .61403 L F
.593 .107 .07 r
.28042 .61352 m .28264 .61497 L .28369 .61414 L F
0 0 .219 r
.70385 .34448 m .70294 .34622 L .70325 .3431 L F
.039 0 .094 r
.34316 .56231 m .34469 .56165 L .34548 .55979 L F
.215 .018 .383 r
.34316 .56231 m .3444 .56422 L .34469 .56165 L F
.34316 .56231 m .34268 .56518 L .3444 .56422 L F
.843 .861 .856 r
.33272 .49955 m .32792 .50121 L .33142 .4993 L F
.735 .981 .912 r
.33272 .49955 m .33333 .49779 L .33443 .49836 L F
.703 .958 .947 r
.33272 .49955 m .33142 .4993 L .33333 .49779 L F
.675 .776 .926 r
.33171 .665 m .33569 .66505 L .33404 .66469 L F
.377 .837 .773 r
.33569 .66505 m .33609 .66457 L .33404 .66469 L F
.78 .567 .612 r
.66697 .35023 m .66313 .35228 L .66313 .34955 L F
.66697 .35023 m .66705 .35289 L .66313 .35228 L F
.893 .929 .836 r
.54721 .42936 m .54848 .43037 L .54643 .43199 L F
.62 .879 .989 r
.55133 .42912 m .54848 .43037 L .54721 .42936 L F
.338 .163 .492 r
.32871 .56759 m .32679 .56576 L .32942 .56551 L F
.32871 .56759 m .32676 .56825 L .32679 .56576 L F
.552 .532 .786 r
.6516 .3886 m .65468 .38979 L .65233 .39055 L F
.786 .702 .771 r
.25022 .57822 m .24763 .58149 L .24573 .57751 L F
.598 .427 .621 r
.25022 .57822 m .25038 .58107 L .24763 .58149 L F
.587 .514 .74 r
.25119 .58432 m .24763 .58149 L .25038 .58107 L F
.883 .561 .435 r
.43604 .54235 m .4331 .53952 L .43719 .54057 L F
.212 0 .176 r
.43935 .53965 m .43604 .54235 L .43719 .54057 L F
.848 .77 .775 r
.70003 .29489 m .70095 .29838 L .69763 .29817 L F
.839 .795 .809 r
.70095 .29838 m .69835 .30149 L .69763 .29817 L F
.813 .752 .795 r
.70376 .29504 m .70095 .29838 L .70003 .29489 L F
.672 .392 .488 r
.27002 .56283 m .26965 .56529 L .26643 .56515 L F
.297 0 .264 r
.27283 .56191 m .26965 .56529 L .27002 .56283 L F
.876 .938 .567 r
.40176 .61241 m .40294 .6103 L .40141 .61191 L F
.938 .926 .561 r
.40141 .61191 m .40294 .6103 L .4028 .60799 L F
.399 .626 .945 r
.26562 .52945 m .26728 .52839 L .26467 .52884 L F
.26562 .52945 m .26881 .5303 L .26728 .52839 L F
.866 .861 .833 r
.67853 .32802 m .67454 .32976 L .67709 .3265 L F
.866 .853 .828 r
.68116 .32468 m .67853 .32802 L .67709 .3265 L F
.604 .673 .889 r
.64801 .40292 m .64943 .39902 L .6472 .40011 L F
.64801 .40292 m .65137 .40188 L .64943 .39902 L F
.83 .86 .867 r
.5744 .41675 m .57546 .41905 L .57336 .42029 L F
.865 .934 .866 r
.57677 .41488 m .57546 .41905 L .5744 .41675 L F
.57677 .41488 m .57845 .41575 L .57546 .41905 L F
0 0 0 r
.2319 .53788 m .23175 .53818 L .23349 .5363 L F
.2319 .53788 m .22962 .53923 L .23175 .53818 L F
.805 .83 .871 r
.34661 .52377 m .34447 .52651 L .34284 .52344 L F
.787 .999 .831 r
.39826 .5908 m .39857 .59378 L .39851 .5911 L F
.692 .936 .635 r
.40124 .58801 m .39851 .5911 L .39938 .5895 L F
.923 .921 .793 r
.39857 .59378 m .39938 .5895 L .39851 .5911 L F
.45 0 0 r
.62255 .43862 m .62518 .44027 L .62546 .44018 L F
.336 .332 .707 r
.62417 .43639 m .62518 .44027 L .62255 .43862 L F
.168 .217 .67 r
.62638 .43643 m .62518 .44027 L .62417 .43639 L F
.678 .159 0 r
.62486 .44039 m .62518 .44027 L .62638 .43643 L F
.62443 .44152 m .62518 .44027 L .62486 .44039 L F
.45 0 0 r
.62546 .44018 m .62518 .44027 L .62648 .44072 L F
.321 .797 .913 r
.62648 .44072 m .62518 .44027 L .62913 .44016 L F
.361 .318 .675 r
.33531 .51446 m .3369 .51029 L .33632 .51224 L F
.61 .496 .699 r
.35349 .52128 m .35608 .52076 L .35586 .51783 L F
.624 .41 .572 r
.35349 .52128 m .35552 .52323 L .35608 .52076 L F
.35349 .52128 m .3534 .52388 L .35552 .52323 L F
.817 .74 .779 r
.70247 .29163 m .70376 .29504 L .70003 .29489 L F
.451 .696 .971 r
.26139 .6208 m .25998 .62259 L .25785 .61969 L F
.26139 .6208 m .26209 .62225 L .25998 .62259 L F
.715 .615 .744 r
.38611 .56917 m .38773 .57213 L .38647 .57204 L F
.308 .302 .689 r
.38778 .5748 m .38647 .57204 L .38773 .57213 L F
.605 .569 .787 r
.38611 .56917 m .38773 .57213 L .3904 .57164 L F
.38611 .56917 m .38773 .57213 L .3904 .57164 L F
.543 .318 .523 r
.38773 .57213 m .39022 .57422 L .3904 .57164 L F
.554 .805 .992 r
.3904 .57164 m .38773 .57213 L .39022 .57422 L F
0 0 .018 r
.28529 .63523 m .28792 .63169 L .28745 .63449 L F
.17 .008 .404 r
.28707 .63705 m .28529 .63523 L .28745 .63449 L F
.28707 .63705 m .28433 .63914 L .28529 .63523 L F
.289 0 .093 r
.34307 .59475 m .34441 .59582 L .34235 .59659 L F
.34307 .59475 m .34561 .5942 L .34441 .59582 L F
.073 0 .245 r
.34679 .64429 m .34541 .6454 L .34703 .64256 L F
.533 .259 .445 r
.34947 .64386 m .34703 .64256 L .34679 .64429 L F
.34947 .64386 m .34973 .64165 L .34703 .64256 L F
.315 .376 .766 r
.34947 .64386 m .34703 .64256 L .34973 .64165 L F
.856 .804 .799 r
.69835 .30149 m .69515 .30163 L .69763 .29817 L F
.593 .148 0 r
.58519 .4068 m .58695 .40922 L .5864 .40855 L F
.554 0 0 r
.58695 .40922 m .58993 .41083 L .58841 .41089 L F
.58695 .40922 m .58841 .41089 L .5864 .40855 L F
.841 .589 .557 r
.26311 .5396 m .26324 .54229 L .26559 .53949 L F
.703 .389 .443 r
.26559 .53949 m .26792 .54243 L .2671 .54013 L F
.565 .819 .993 r
.24787 .57671 m .25022 .57822 L .24573 .57751 L F
.54 .809 .996 r
.25284 .57766 m .25022 .57822 L .24787 .57671 L F
.508 .34 .589 r
.25284 .57766 m .25038 .58107 L .25022 .57822 L F
0 .047 .531 r
.36963 .5091 m .3718 .51104 L .37222 .51144 L F
0 .124 .614 r
.37338 .51218 m .37222 .51144 L .3718 .51104 L F
.37338 .51218 m .37458 .51335 L .37222 .51144 L F
.453 0 0 r
.25467 .62851 m .2529 .62878 L .25077 .62815 L F
.531 0 0 r
.25724 .62995 m .2529 .62878 L .25467 .62851 L F
.606 .369 .532 r
.31978 .64404 m .31729 .64134 L .31587 .64375 L F
.31978 .64404 m .31978 .64154 L .31729 .64134 L F
.566 .932 .796 r
.33156 .67906 m .32558 .68212 L .33094 .67986 L F
0 0 0 r
.33279 .67844 m .33156 .67906 L .33094 .67986 L F
.321 .264 .637 r
.38487 .61865 m .38751 .62128 L .38678 .61888 L F
.38487 .61865 m .38504 .62246 L .38751 .62128 L F
.459 .451 .762 r
.4344 .51648 m .43211 .51846 L .43113 .51486 L F
.583 .928 .734 r
.35279 .51271 m .35182 .51399 L .35449 .5116 L F
.35279 .51271 m .35092 .5143 L .35182 .51399 L F
.404 .217 .51 r
.41464 .50855 m .41595 .5052 L .41677 .50879 L F
.736 .631 .742 r
.41941 .5054 m .41677 .50879 L .41595 .5052 L F
.802 .38 .247 r
.41677 .50879 m .4153 .51015 L .41464 .50855 L F
0 0 0 r
.29759 .52193 m .2975 .52148 L .30031 .521 L F
.29759 .52193 m .29649 .52357 L .2975 .52148 L F
.39 .676 .974 r
.23753 .60928 m .23729 .61086 L .23615 .60911 L F
.23753 .60928 m .23886 .61096 L .23729 .61086 L F
.811 .767 .812 r
.70565 .28611 m .70645 .28978 L .703 .28906 L F
.382 .233 .551 r
.32462 .57712 m .32239 .57534 L .32494 .57466 L F
.32462 .57712 m .32226 .57824 L .32239 .57534 L F
.059 0 0 r
.38022 .58814 m .38043 .58736 L .38259 .58679 L F
.649 .936 .967 r
.72939 .33675 m .72696 .33808 L .72592 .3375 L F
0 0 .439 r
.62472 .43419 m .62412 .43248 L .62489 .43148 L F
.758 .797 .884 r
.35141 .54461 m .34834 .54622 L .35241 .54665 L F
.32 .09 .4 r
.36639 .51625 m .36443 .51681 L .36948 .51712 L F
.36443 .51681 m .36441 .51684 L .36948 .51712 L F
.36443 .51681 m .36434 .51683 L .36441 .51684 L F
.36639 .51625 m .36399 .51886 L .36434 .51683 L F
.621 .663 .869 r
.36399 .51886 m .36614 .52274 L .36366 .52361 L F
.481 .484 .783 r
.36639 .51625 m .36614 .52274 L .36399 .51886 L F
.621 .663 .869 r
.36399 .51886 m .36366 .52361 L .36181 .51964 L F
.146 .03 .452 r
.3633 .52161 m .36502 .52053 L .36467 .51825 L F
.595 .061 0 r
.36502 .52053 m .3644 .51998 L .36467 .51825 L F
0 0 .036 r
.36399 .51886 m .36467 .51825 L .36493 .51661 L F
.36399 .51886 m .36525 .51584 L .36517 .51594 L F
.575 .289 .445 r
.36235 .51785 m .36181 .51964 L .35943 .52014 L F
.35943 .52014 m .36181 .51964 L .36235 .51785 L F
.188 0 .212 r
.36528 .51499 m .36235 .51785 L .36434 .51683 L F
.316 .048 .339 r
.36235 .51785 m .36399 .51886 L .36434 .51683 L F
.36235 .51785 m .36181 .51964 L .36399 .51886 L F
.188 0 .212 r
.36528 .51499 m .36235 .51785 L .36434 .51683 L F
.316 .048 .339 r
.36235 .51785 m .36399 .51886 L .36434 .51683 L F
.36235 .51785 m .36181 .51964 L .36399 .51886 L F
.838 .617 .604 r
.36366 .52361 m .35943 .52014 L .36181 .51964 L F
.36366 .52361 m .35669 .52441 L .35943 .52014 L F
.45 .139 .346 r
.36077 .52208 m .36399 .51886 L .36181 .51964 L F
0 0 .036 r
.36399 .51886 m .36532 .51557 L .36434 .51683 L F
.45 .139 .346 r
.36077 .52208 m .3633 .52161 L .36399 .51886 L F
.146 .03 .452 r
.3633 .52161 m .36467 .51825 L .36399 .51886 L F
.595 .061 0 r
.3644 .51998 m .36136 .5173 L .36467 .51825 L F
0 0 .036 r
.36493 .51661 m .36467 .51825 L .36525 .51584 L F
.36517 .51594 m .36525 .51584 L .36532 .51557 L F
.67 .448 .574 r
.43845 .56513 m .43528 .56755 L .43589 .56567 L F
.509 .366 .622 r
.26007 .54951 m .26039 .55262 L .25779 .5531 L F
.278 0 .284 r
.26039 .55262 m .25776 .55518 L .25779 .5531 L F
.667 .382 .48 r
.57589 .45154 m .57364 .45376 L .57193 .4509 L F
.57589 .45154 m .57601 .45382 L .57364 .45376 L F
.672 .214 .155 r
.33318 .66268 m .33465 .66106 L .33112 .6606 L F
.33318 .66268 m .33112 .6606 L .33041 .6605 L F
.668 .885 .521 r
.33318 .66268 m .33465 .66106 L .3326 .66382 L F
.264 .514 .905 r
.33318 .66268 m .33404 .66469 L .33609 .66457 L F
.33318 .66268 m .33609 .66457 L .33492 .66444 L F
0 .171 .691 r
.33491 .66443 m .33318 .66268 L .33492 .66444 L F
0 0 0 r
.33615 .65989 m .33465 .66106 L .33318 .66268 L F
.138 0 0 r
.33819 .65907 m .33422 .66267 L .33819 .65992 L F
0 .171 .691 r
.33412 .66271 m .33386 .66337 L .33419 .66286 L F
.138 0 0 r
.33422 .66267 m .33363 .6632 L .33448 .66259 L F
.33422 .66267 m .33448 .66259 L .33819 .65992 L F
.33819 .65907 m .33615 .65989 L .33402 .66269 L F
.33819 .65907 m .33402 .66269 L .33417 .66272 L F
0 0 0 r
.33615 .65989 m .33318 .66268 L .33402 .66269 L F
.607 .591 .81 r
.33412 .6627 m .33621 .66099 L .3336 .66157 L F
.33492 .66444 m .33576 .66219 L .33412 .6627 L F
.64 .955 .765 r
.33621 .66099 m .33819 .65992 L .33448 .66259 L F
.607 .591 .81 r
.33448 .66259 m .33621 .66099 L .33412 .6627 L F
.64 .955 .765 r
.33621 .66099 m .33448 .66259 L .33426 .66275 L F
.607 .591 .81 r
.33576 .66219 m .33621 .66099 L .33448 .66259 L F
.64 .955 .765 r
.33439 .66255 m .33426 .66275 L .33363 .6632 L F
.33621 .66099 m .33426 .66275 L .33439 .66255 L F
0 .171 .691 r
.33412 .66271 m .33318 .66268 L .33386 .66337 L F
.33419 .66286 m .33386 .66337 L .33491 .66443 L F
.33411 .66269 m .33402 .66269 L .33412 .66271 L F
.33402 .66269 m .33318 .66268 L .33412 .66271 L F
.138 0 0 r
.33417 .66272 m .33402 .66269 L .33363 .6632 L F
0 0 0 r
.33402 .66269 m .33318 .66268 L .33363 .6632 L F
0 .171 .691 r
.3336 .66157 m .33318 .66268 L .33411 .66269 L F
0 0 .249 r
.3336 .66186 m .33318 .66268 L .3336 .66157 L F
.33363 .6632 m .33318 .66268 L .3336 .66186 L F
.668 .885 .521 r
.33318 .66268 m .3326 .66382 L .33171 .665 L F
.899 .825 .765 r
.33609 .65478 m .33465 .66106 L .33615 .65989 L F
.016 .161 .672 r
.2876 .62413 m .28566 .62238 L .28991 .62265 L F
.2876 .62413 m .28991 .62265 L .28797 .62249 L F
.384 .545 .892 r
.29 .62794 m .28671 .62611 L .28889 .62505 L F
.418 .045 .221 r
.2939 .6256 m .29042 .62769 L .29035 .62665 L F
.754 .54 .606 r
.2939 .6256 m .29055 .62659 L .29014 .62478 L F
.29068 .6272 m .29037 .62682 L .29014 .62478 L F
.29221 .62435 m .29014 .62478 L .28991 .62265 L F
.2939 .6256 m .29014 .62478 L .29221 .62435 L F
.418 .045 .221 r
.2939 .6256 m .29025 .62668 L .29075 .62414 L F
0 0 .174 r
.29015 .62474 m .29035 .62665 L .29032 .6263 L F
.28991 .62265 m .29014 .62478 L .29015 .62474 L F
.29014 .62478 m .29035 .62665 L .29015 .62474 L F
.28991 .62265 m .29032 .6263 L .29005 .62304 L F
.657 .922 .976 r
.29018 .62414 m .28889 .62505 L .2876 .62413 L F
.29075 .62414 m .29017 .62443 L .29018 .62414 L F
0 0 .174 r
.29005 .62304 m .29015 .62421 L .2901 .62319 L F
.384 .545 .892 r
.29032 .6263 m .29017 .62443 L .29075 .62414 L F
0 0 .174 r
.29015 .62421 m .29032 .6263 L .29017 .62416 L F
.29015 .62421 m .29017 .62416 L .2901 .62319 L F
.895 .792 .305 r
.29034 .62386 m .29075 .62414 L .29018 .62414 L F
0 0 .174 r
.2901 .62319 m .29019 .62433 L .29034 .62386 L F
.29019 .62433 m .29042 .62732 L .29034 .62386 L F
.29035 .62665 m .29042 .62732 L .2901 .62319 L F
.895 .792 .305 r
.29034 .62386 m .29018 .62414 L .2876 .62413 L F
0 0 .174 r
.28991 .62265 m .29034 .62386 L .28797 .62249 L F
0 .281 .781 r
.28797 .62249 m .29034 .62386 L .28877 .62083 L F
.873 .479 .286 r
.28799 .62263 m .29034 .62386 L .2876 .62413 L F
.28799 .62263 m .28845 .62531 L .29034 .62386 L F
.376 .546 .895 r
.28877 .62083 m .29034 .62386 L .2915 .62235 L F
.651 .397 .522 r
.28845 .62531 m .2905 .62332 L .29034 .62386 L F
.2905 .62332 m .2915 .62235 L .29034 .62386 L F
.657 .922 .976 r
.29017 .62443 m .28889 .62505 L .29018 .62414 L F
.384 .545 .892 r
.29025 .62668 m .28889 .62505 L .29017 .62443 L F
.29025 .62668 m .29017 .62443 L .29032 .6263 L F
.418 .045 .221 r
.29035 .62665 m .29 .62794 L .29025 .62668 L F
.29042 .62769 m .29 .62794 L .29035 .62665 L F
.754 .54 .606 r
.2939 .6256 m .29068 .6272 L .29055 .62659 L F
.384 .545 .892 r
.29 .62794 m .28889 .62505 L .29025 .62668 L F
.754 .54 .606 r
.29068 .6272 m .29042 .62732 L .29037 .62682 L F
.657 .922 .976 r
.28889 .62505 m .28671 .62611 L .28701 .62544 L F
.28889 .62505 m .28701 .62544 L .2876 .62413 L F
0 0 0 r
.32174 .63266 m .3197 .63584 L .32217 .63616 L F
.498 .814 1 r
.32217 .63616 m .32513 .63572 L .32361 .63486 L F
.32217 .63616 m .32361 .63486 L .3236 .63486 L F
.32217 .63616 m .3236 .63485 L .32229 .63532 L F
.806 .586 .026 r
.32174 .63266 m .32205 .63523 L .32195 .63549 L F
.32205 .63523 m .32217 .63616 L .32195 .63549 L F
.123 0 0 r
.31859 .6368 m .32217 .63616 L .3197 .63584 L F
.45 .814 .995 r
.32195 .63549 m .32217 .63616 L .3217 .6361 L F
.32195 .63549 m .3217 .6361 L .3197 .63584 L F
.606 .369 .531 r
.31859 .6368 m .32195 .63549 L .32099 .63785 L F
.32099 .63785 m .32195 .63549 L .31859 .6368 L F
.32099 .63785 m .32195 .63549 L .31859 .6368 L F
.659 .753 .267 r
.32229 .63463 m .32195 .63549 L .32099 .63785 L F
.806 .586 .026 r
.32174 .63266 m .32194 .63537 L .3223 .63526 L F
.32329 .63463 m .3223 .63526 L .3235 .63489 L F
.32174 .63266 m .32229 .63522 L .32329 .63463 L F
.32174 .63266 m .3235 .63489 L .3237 .63199 L F
.3235 .63489 m .3236 .63485 L .3237 .63199 L F
.756 .889 .938 r
.3236 .63485 m .32513 .63572 L .32433 .63423 L F
.35 .152 .465 r
.3237 .63199 m .32393 .63444 L .32533 .63338 L F
.32393 .63444 m .32394 .63456 L .32433 .63423 L F
.32393 .63444 m .32433 .63423 L .32533 .63338 L F
.756 .889 .938 r
.32432 .63423 m .32513 .63572 L .32699 .63427 L F
.32442 .63423 m .32699 .63427 L .32569 .63365 L F
.32442 .63423 m .32569 .63365 L .32558 .6336 L F
.35 .152 .465 r
.32533 .63338 m .32403 .63557 L .32558 .6336 L F
.756 .889 .938 r
.32433 .63423 m .32442 .63423 L .32558 .6336 L F
.3236 .63485 m .32433 .63423 L .32394 .63456 L F
.35 .152 .465 r
.32394 .63456 m .32403 .63557 L .32533 .63338 L F
.806 .586 .026 r
.3236 .63485 m .32394 .63456 L .3237 .63199 L F
.756 .889 .938 r
.32246 .63421 m .32433 .63423 L .32558 .6336 L F
.32394 .63456 m .32433 .63423 L .32432 .63423 L F
.806 .586 .026 r
.3236 .63485 m .32396 .63473 L .32394 .63456 L F
.756 .889 .938 r
.32246 .63421 m .3236 .63485 L .32432 .63423 L F
.806 .586 .026 r
.32229 .63522 m .3223 .63526 L .32252 .63512 L F
.32229 .63522 m .32252 .63512 L .32329 .63463 L F
.498 .814 1 r
.32217 .63616 m .3223 .63526 L .32195 .63549 L F
.3223 .63526 m .32246 .63421 L .32195 .63549 L F
.659 .753 .267 r
.32246 .63421 m .32195 .63549 L .32229 .63463 L F
.32184 .63574 m .32195 .63549 L .32099 .63785 L F
.32246 .63421 m .32195 .63549 L .32184 .63574 L F
.806 .586 .026 r
.3235 .63489 m .32195 .63549 L .32403 .63557 L F
.498 .814 1 r
.32229 .63532 m .3236 .63485 L .32246 .63421 L F
.806 .586 .026 r
.32194 .63537 m .32195 .63549 L .3235 .63489 L F
.498 .814 1 r
.3236 .63486 m .32361 .63486 L .3236 .63485 L F
.806 .586 .026 r
.3235 .63489 m .32403 .63557 L .32396 .63473 L F
.85 .88 .862 r
.36465 .58785 m .36755 .58521 L .36514 .58384 L F
0 0 0 r
.36755 .58521 m .37036 .58157 L .3698 .5842 L F
.587 .846 .994 r
.36514 .58384 m .36755 .58521 L .3698 .5842 L F
.3 0 .178 r
.26519 .556 m .2661 .5584 L .26786 .55516 L F
.558 .412 .638 r
.38353 .67539 m .38436 .68125 L .38034 .67833 L F
.37 .349 .706 r
.43499 .52511 m .43323 .52497 L .43596 .52343 L F
.43499 .52511 m .43401 .52748 L .43323 .52497 L F
.344 .016 .258 r
.33209 .58103 m .32967 .58428 L .32911 .58115 L F
.33209 .58103 m .33197 .58375 L .32967 .58428 L F
.267 .017 .336 r
.33538 .57721 m .33503 .5805 L .33209 .58103 L F
.439 .186 .432 r
.33503 .5805 m .33197 .58375 L .33209 .58103 L F
.757 .552 .619 r
.5545 .44246 m .55127 .44415 L .55134 .44182 L F
.5545 .44246 m .5556 .44463 L .55127 .44415 L F
.591 .209 .287 r
.68015 .36579 m .68225 .36812 L .67899 .36754 L F
.68015 .36579 m .68278 .36563 L .68225 .36812 L F
.774 .768 .847 r
.61559 .3927 m .61779 .3949 L .6156 .39498 L F
.728 .835 .931 r
.61714 .39182 m .61779 .3949 L .6156 .39498 L F
0 0 .492 r
.311 .51672 m .31317 .51961 L .31215 .51836 L F
.502 .346 .602 r
.66266 .39356 m .66021 .3968 L .65969 .39443 L F
.66266 .39356 m .66309 .39577 L .66021 .3968 L F
.872 .579 .49 r
.34832 .54344 m .3455 .54529 L .34479 .54297 L F
.34832 .54344 m .34834 .54622 L .3455 .54529 L F
.48 .483 .783 r
.34863 .53806 m .35047 .54265 L .34832 .54344 L F
.569 .328 .511 r
.35141 .54461 m .34832 .54344 L .35047 .54265 L F
.866 .853 .828 r
.68116 .32468 m .67709 .3265 L .67968 .32327 L F
.858 .859 .84 r
.68371 .32164 m .68116 .32468 L .67968 .32327 L F
.751 .505 .559 r
.6543 .41632 m .65506 .41985 L .65101 .41876 L F
.485 .296 .549 r
.6566 .41308 m .6572 .41533 L .6543 .41632 L F
.619 .476 .665 r
.6572 .41533 m .65506 .41985 L .6543 .41632 L F
.466 .446 .751 r
.42268 .55331 m .41911 .54954 L .42172 .54887 L F
.6 .914 .978 r
.34341 .71207 m .3457 .71226 L .34798 .71123 L F
.199 .336 .778 r
.20061 .59441 m .20314 .59637 L .20184 .59287 L F
.378 .35 .701 r
.20127 .59647 m .20314 .59637 L .20061 .59441 L F
.704 .702 .845 r
.65838 .39254 m .65969 .39443 L .65579 .39376 L F
.675 .692 .858 r
.66266 .39356 m .65969 .39443 L .65838 .39254 L F
.98 .737 .496 r
.39956 .58682 m .40124 .58801 L .39938 .5895 L F
0 0 0 r
.28792 .63169 m .29 .62794 L .28943 .63048 L F
.314 .028 .309 r
.28956 .63385 m .28792 .63169 L .28943 .63048 L F
.28956 .63385 m .28745 .63449 L .28792 .63169 L F
.913 .903 .801 r
.59726 .38628 m .599 .38719 L .59621 .3911 L F
.233 .694 .949 r
.59726 .38628 m .60155 .38723 L .599 .38719 L F
.781 .608 .043 r
.41277 .553 m .4127 .55448 L .41266 .552 L F
.41277 .553 m .41289 .55599 L .4127 .55448 L F
1 .833 .519 r
.41142 .49915 m .41107 .50215 L .41 .50082 L F
0 0 0 r
.41 .50082 m .41397 .49863 L .41142 .49915 L F
.424 .816 .588 r
.29387 .61048 m .29139 .61224 L .29549 .60931 L F
.344 .01 .247 r
.26293 .54706 m .26236 .5489 L .26007 .54951 L F
.119 0 .158 r
.26411 .54802 m .26293 .54706 L .2658 .54558 L F
.26411 .54802 m .26236 .5489 L .26293 .54706 L F
.678 .654 .818 r
.62469 .41576 m .62242 .42011 L .62035 .41752 L F
.62469 .41576 m .62557 .41875 L .62242 .42011 L F
.176 .241 .692 r
.25201 .56443 m .25084 .56611 L .2502 .56363 L F
.622 .5 .692 r
.25385 .56825 m .25084 .56611 L .25201 .56443 L F
.25385 .56825 m .25127 .56873 L .25084 .56611 L F
.722 .695 .824 r
.25642 .56552 m .25385 .56825 L .25201 .56443 L F
.408 0 .107 r
.25201 .56443 m .25025 .56651 L .2537 .56518 L F
.722 .695 .824 r
.25642 .56552 m .25201 .56443 L .25462 .56484 L F
.408 0 .107 r
.25201 .56443 m .2549 .56472 L .25462 .56484 L F
.25201 .56443 m .2537 .56518 L .2549 .56472 L F
.176 .241 .692 r
.25201 .56443 m .2502 .56363 L .24987 .56238 L F
.156 .143 .591 r
.20045 .57844 m .20216 .58055 L .20207 .57698 L F
.20045 .57844 m .20098 .58115 L .20216 .58055 L F
.706 .305 0 r
.386 .52265 m .38714 .52446 L .38523 .52102 L F
.736 .309 0 r
.38741 .52589 m .38864 .52745 L .38714 .52446 L F
.005 0 .221 r
.3868 .5874 m .38513 .59069 L .38746 .59009 L F
.512 .764 .987 r
.38606 .58593 m .3868 .5874 L .38891 .58543 L F
.55 .546 .803 r
.38746 .59009 m .38891 .58543 L .3868 .5874 L F
.546 .427 .669 r
.65306 .38114 m .65082 .38449 L .65044 .38203 L F
.65306 .38114 m .65351 .38388 L .65082 .38449 L F
.514 .435 .705 r
.65415 .38782 m .65082 .38449 L .65351 .38388 L F
.65415 .38782 m .6516 .3886 L .65082 .38449 L F
.319 .786 .934 r
.27621 .60679 m .27445 .60639 L .27229 .60679 L F
.473 0 0 r
.27583 .60472 m .27789 .60626 L .27621 .60679 L F
.434 .849 .962 r
.27707 .60575 m .27621 .60679 L .27789 .60626 L F
.27707 .60575 m .27445 .60639 L .27621 .60679 L F
.276 .505 .896 r
.25675 .6178 m .25591 .61956 L .2538 .61657 L F
.333 .576 .93 r
.25675 .6178 m .25785 .61969 L .25591 .61956 L F
.525 .183 .33 r
.59158 .44987 m .58887 .44802 L .59167 .44809 L F
.59158 .44987 m .58795 .45038 L .58887 .44802 L F
0 0 0 r
.29317 .53313 m .29473 .53244 L .29634 .53153 L F
.29634 .53153 m .30008 .52978 L .29937 .52984 L F
.29634 .53153 m .29473 .53244 L .30008 .52978 L F
.11 .642 .866 r
.36266 .64409 m .36661 .64469 L .36475 .64451 L F
.586 .126 .127 r
.36386 .64557 m .36477 .64483 L .36266 .64409 L F
.64 .917 .626 r
.36435 .64508 m .36477 .64483 L .36386 .64557 L F
.479 0 0 r
.36477 .64483 m .36527 .64453 L .36266 .64409 L F
.36634 .64471 m .36611 .64461 L .36266 .64409 L F
.64 .917 .626 r
.3669 .64247 m .36477 .64483 L .36435 .64508 L F
.479 0 0 r
.36477 .64483 m .36634 .64471 L .36527 .64453 L F
.36634 .64471 m .36661 .64469 L .36611 .64461 L F
.57 .917 .712 r
.36565 .64441 m .36828 .64245 L .36922 .6387 L F
.36556 .64456 m .36571 .64444 L .36565 .64441 L F
.36571 .64444 m .36828 .64245 L .36565 .64441 L F
.662 .7 .874 r
.36922 .6387 m .37039 .63464 L .36827 .63445 L F
.36922 .6387 m .37214 .63749 L .37039 .63464 L F
.79 .52 .528 r
.3724 .64152 m .36922 .6387 L .36828 .64245 L F
.628 .35 .478 r
.43278 .53713 m .4331 .53952 L .42941 .53942 L F
.835 .423 .261 r
.71078 .28363 m .71365 .28329 L .71159 .28266 L F
.71078 .28363 m .71408 .2852 L .71365 .28329 L F
.244 .707 .948 r
.34573 .5717 m .34535 .57084 L .34403 .5708 L F
0 .098 .62 r
.34573 .5717 m .34728 .5731 L .34535 .57084 L F
.861 .742 .226 r
.40787 .59379 m .40796 .59049 L .40767 .59329 L F
.95 .889 .492 r
.40656 .59559 m .40787 .59379 L .40767 .59329 L F
.40656 .59559 m .40694 .59762 L .40787 .59379 L F
.561 .657 .9 r
.24136 .55958 m .24341 .56247 L .24576 .56165 L F
.493 .049 .122 r
.24341 .56247 m .24555 .56389 L .24576 .56165 L F
.24341 .56247 m .24166 .56448 L .24555 .56389 L F
.611 .594 .809 r
.22018 .56805 m .22012 .5707 L .21819 .5708 L F
.829 .493 .418 r
.31247 .52373 m .31317 .51961 L .31434 .52442 L F
0 .068 .611 r
.31507 .52261 m .31434 .52442 L .31317 .51961 L F
.697 .832 .394 r
.31507 .52261 m .31324 .52641 L .31434 .52442 L F
.473 .289 .55 r
.65049 .41554 m .64697 .41796 L .6498 .41498 L F
.65049 .41554 m .64858 .41995 L .64697 .41796 L F
.65049 .41554 m .65101 .41876 L .64858 .41995 L F
.949 .875 .728 r
.26578 .53839 m .2671 .54013 L .26852 .53739 L F
.26578 .53839 m .2671 .54013 L .26852 .53739 L F
.405 0 0 r
.6256 .45033 m .62892 .45052 L .62806 .45091 L F
.059 0 0 r
.62892 .45052 m .63134 .45017 L .62806 .45091 L F
.937 .568 .268 r
.36289 .61627 m .36536 .61983 L .36347 .61844 L F
.419 .729 .99 r
.36347 .61844 m .36536 .61983 L .36576 .61818 L F
.802 .716 .771 r
.56119 .41613 m .5623 .41934 L .56336 .41787 L F
.499 .157 .318 r
.2276 .57403 m .22603 .5725 L .22801 .57135 L F
.2276 .57403 m .22502 .57441 L .22603 .5725 L F
.109 .198 .676 r
.62706 .4058 m .62595 .40707 L .62516 .40314 L F
0 0 .484 r
.62749 .40763 m .62595 .40707 L .62706 .4058 L F
.62749 .40763 m .62663 .40967 L .62595 .40707 L F
.837 .736 .752 r
.33934 .51545 m .33673 .51798 L .33643 .51514 L F
.709 .903 .965 r
.33975 .51325 m .33692 .51501 L .33934 .51545 L F
.85 .88 .862 r
.36465 .58785 m .36514 .58384 L .36323 .58412 L F
.417 .383 .713 r
.36762 .58988 m .36552 .59074 L .36465 .58785 L F
.554 0 0 r
.36553 .58916 m .36465 .58785 L .36336 .59031 L F
.36553 .58916 m .36762 .58988 L .36465 .58785 L F
.618 .234 .293 r
.35804 .59605 m .3586 .59338 L .35583 .59362 L F
0 0 0 r
.36137 .5903 m .3586 .59338 L .36035 .59269 L F
.922 .617 .447 r
.39311 .51496 m .39127 .51524 L .39109 .51395 L F
.39311 .51496 m .39344 .51751 L .39127 .51524 L F
.991 .753 .47 r
.56117 .41864 m .5623 .41934 L .56119 .41613 L F
.911 .896 .8 r
.5623 .41934 m .55999 .42294 L .55866 .42169 L F
.5623 .41934 m .56055 .42046 L .56179 .42019 L F
.56055 .42046 m .55866 .42169 L .56179 .42019 L F
.5623 .41934 m .56179 .42019 L .56117 .41864 L F
.489 .176 .362 r
.56117 .41864 m .56327 .41987 L .56179 .42019 L F
.56327 .41987 m .56379 .42018 L .56179 .42019 L F
.81 .8 .842 r
.62102 .41608 m .62035 .41752 L .61867 .4193 L F
0 0 .137 r
.20704 .56247 m .20761 .5636 L .20917 .56176 L F
.20704 .56247 m .20664 .56497 L .20761 .5636 L F
0 0 .073 r
.33008 .60019 m .32829 .60372 L .32978 .60274 L F
0 0 .318 r
.32829 .60372 m .32951 .60493 L .32978 .60274 L F
.32829 .60372 m .32818 .60621 L .32951 .60493 L F
.513 .72 .966 r
.37005 .52198 m .37163 .52143 L .37081 .51999 L F
.632 .731 .919 r
.34113 .49889 m .33899 .49997 L .33717 .49776 L F
0 0 .096 r
.34541 .6454 m .34501 .64673 L .34679 .64429 L F
.124 0 0 r
.43353 .58765 m .42938 .58966 L .43087 .58753 L F
.676 .841 .963 r
.33981 .6549 m .33609 .65478 L .33838 .65605 L F
.01 0 .29 r
.34132 .65134 m .33981 .6549 L .34098 .65386 L F
.491 .84 .572 r
.34098 .65386 m .33981 .6549 L .33838 .65605 L F
.389 .833 .94 r
.28057 .5208 m .27656 .52102 L .27874 .51979 L F
.532 .794 .993 r
.28135 .51886 m .28057 .5208 L .27874 .51979 L F
.28135 .51886 m .28287 .52013 L .28057 .5208 L F
.016 0 .002 r
.2393 .55632 m .23933 .55779 L .24165 .55594 L F
.2393 .55632 m .23778 .55903 L .23933 .55779 L F
.419 .141 .382 r
.24165 .55594 m .24393 .55536 L .24465 .55296 L F
.093 0 .206 r
.2471 .54969 m .24465 .55296 L .24642 .55193 L F
.576 .422 .635 r
.24393 .55536 m .24642 .55193 L .24465 .55296 L F
.389 .033 .235 r
.68225 .36812 m .68278 .36563 L .68543 .36654 L F
.392 .014 .196 r
.68278 .36563 m .6855 .3652 L .68543 .36654 L F
.883 .832 .791 r
.6886 .31499 m .68479 .3168 L .68698 .3135 L F
.6886 .31499 m .68627 .31842 L .68479 .3168 L F
.198 0 .292 r
.31636 .59412 m .3188 .59096 L .31846 .59357 L F
.433 .199 .457 r
.31812 .59568 m .31636 .59412 L .31846 .59357 L F
.31812 .59568 m .31604 .59643 L .31636 .59412 L F
.849 .729 .73 r
.67086 .35856 m .67138 .36242 L .66865 .36156 L F
.924 .682 .554 r
.67138 .36242 m .66898 .36396 L .66865 .36156 L F
.67138 .36242 m .67158 .36518 L .66898 .36396 L F
.773 .677 .758 r
.67394 .35877 m .67138 .36242 L .67086 .35856 L F
.674 .524 .673 r
.3866 .58124 m .38949 .58177 L .38852 .57869 L F
.233 .288 .714 r
.38778 .5748 m .38852 .57869 L .39018 .57687 L F
.579 .469 .692 r
.38852 .57869 m .39217 .58042 L .39018 .57687 L F
.38852 .57869 m .38949 .58177 L .39217 .58042 L F
.905 .984 .77 r
.29759 .52193 m .30031 .521 L .30024 .51837 L F
.505 .533 .819 r
.30031 .521 m .30378 .52387 L .30281 .51976 L F
.497 .484 .773 r
.58524 .41875 m .58275 .41994 L .58184 .41682 L F
.075 0 0 r
.33438 .60315 m .33813 .60096 L .33656 .6027 L F
0 0 0 r
.33656 .6027 m .33813 .60096 L .33964 .59947 L F
.016 0 0 r
.368 .57749 m .36977 .57682 L .3722 .57422 L F
.395 .389 .735 r
.37397 .577 m .37213 .57804 L .3722 .57422 L F
.37397 .577 m .3722 .57422 L .37312 .57357 L F
.32 .018 .286 r
.36977 .57682 m .37217 .57652 L .37312 .57357 L F
.33 .006 .255 r
.36945 .57871 m .37217 .57652 L .36977 .57682 L F
.318 .339 .726 r
.37017 .57459 m .37057 .57594 L .36945 .57871 L F
.918 .97 .677 r
.36967 .57902 m .37036 .58157 L .37112 .58005 L F
.36994 .57891 m .37112 .58005 L .37213 .57804 L F
.36967 .57902 m .37112 .58005 L .36994 .57891 L F
.492 .302 .551 r
.36547 .57796 m .36771 .57993 L .368 .57749 L F
0 0 .108 r
.36841 .57886 m .36945 .57871 L .36977 .57682 L F
.36771 .57993 m .36945 .57871 L .36841 .57886 L F
.32 .018 .286 r
.36977 .57682 m .37312 .57357 L .3722 .57422 L F
.38 0 0 r
.37397 .577 m .37 .57886 L .37213 .57804 L F
.918 .97 .677 r
.36961 .57922 m .37036 .58157 L .36967 .57902 L F
.918 .813 .346 r
.3698 .5842 m .37036 .58157 L .36958 .57913 L F
.3698 .5842 m .36958 .57913 L .36957 .57924 L F
.38 0 0 r
.37 .57886 m .36967 .57901 L .36994 .57891 L F
.36967 .57901 m .36962 .57904 L .36994 .57891 L F
.918 .97 .677 r
.36962 .57904 m .36961 .57922 L .36967 .57902 L F
.36958 .57913 m .36961 .57922 L .36962 .57904 L F
.38 0 0 r
.37397 .577 m .37462 .5789 L .36982 .57905 L F
.583 .577 .812 r
.36958 .5793 m .36982 .57905 L .36962 .57904 L F
.36982 .57905 m .36967 .57901 L .36962 .57904 L F
.3694 .57916 m .3701 .57877 L .36945 .57871 L F
.38 0 0 r
.36967 .57901 m .36956 .57906 L .36962 .57904 L F
.36967 .57901 m .36982 .57905 L .36956 .57906 L F
.37 .57886 m .36994 .57891 L .37213 .57804 L F
.37397 .577 m .36982 .57905 L .36967 .57901 L F
.583 .577 .812 r
.36982 .57905 m .3701 .57877 L .36967 .57901 L F
.614 .484 .68 r
.37262 .58166 m .36979 .57926 L .37462 .5789 L F
.583 .577 .812 r
.36934 .5797 m .36962 .57904 L .3694 .57916 L F
.918 .97 .677 r
.36956 .57906 m .36958 .57913 L .36962 .57904 L F
.614 .484 .68 r
.36979 .57926 m .36956 .57906 L .36982 .57905 L F
.36979 .57926 m .36982 .57905 L .37462 .5789 L F
.583 .577 .812 r
.36964 .58014 m .36965 .58012 L .36958 .5793 L F
.614 .484 .68 r
.37262 .58166 m .36972 .58128 L .36965 .58022 L F
.583 .577 .812 r
.36972 .58128 m .37262 .58166 L .36971 .58099 L F
.36975 .5817 m .37262 .58166 L .36972 .58128 L F
.918 .813 .346 r
.3698 .5842 m .36957 .57924 L .36959 .57951 L F
.3698 .5842 m .36959 .57951 L .36973 .58148 L F
.3698 .5842 m .36973 .58141 L .36981 .58279 L F
.587 .846 .994 r
.36514 .58384 m .3698 .5842 L .36788 .58568 L F
.803 .972 .671 r
.36788 .58568 m .3698 .5842 L .36982 .58263 L F
.36788 .58568 m .36982 .58263 L .36952 .58305 L F
.486 .435 .726 r
.36909 .5837 m .36952 .58305 L .36912 .58171 L F
.803 .972 .671 r
.36936 .5833 m .36952 .58305 L .36943 .58317 L F
.36788 .58568 m .36952 .58305 L .36936 .5833 L F
.486 .435 .726 r
.3675 .58247 m .36909 .5837 L .36912 .58171 L F
.803 .972 .671 r
.36788 .58568 m .36936 .5833 L .36991 .58434 L F
.486 .435 .726 r
.36936 .5833 m .36991 .58434 L .36952 .58305 L F
.918 .813 .346 r
.36981 .58279 m .36973 .58141 L .36982 .58256 L F
0 0 0 r
.36994 .58431 m .36975 .5817 L .36912 .58171 L F
.803 .972 .671 r
.36936 .5833 m .36943 .58317 L .36991 .58434 L F
.36943 .58317 m .36982 .58263 L .36982 .58256 L F
0 0 0 r
.36991 .58434 m .36994 .58431 L .36953 .58303 L F
.36991 .58434 m .36953 .58303 L .36952 .58305 L F
.803 .972 .671 r
.36943 .58317 m .36982 .58256 L .36991 .58434 L F
.486 .435 .726 r
.36909 .5837 m .36991 .58434 L .36936 .5833 L F
0 0 0 r
.36952 .58305 m .36953 .58303 L .36912 .58171 L F
.36994 .58431 m .37262 .58166 L .36975 .5817 L F
.918 .813 .346 r
.36973 .58148 m .36959 .57951 L .36973 .58141 L F
.614 .484 .68 r
.37262 .58166 m .36982 .58256 L .36972 .58128 L F
.583 .577 .812 r
.36965 .58012 m .36967 .58005 L .36979 .57926 L F
.36965 .58012 m .36983 .57905 L .36958 .5793 L F
.918 .813 .346 r
.36957 .57924 m .36958 .57913 L .36956 .57906 L F
.614 .484 .68 r
.36979 .57926 m .36965 .58022 L .36956 .57906 L F
.37262 .58166 m .36965 .58022 L .36979 .57926 L F
.583 .577 .812 r
.36979 .57926 m .3701 .57877 L .36983 .57905 L F
.36967 .58005 m .3701 .57877 L .36979 .57926 L F
.36971 .58099 m .37262 .58166 L .37143 .57889 L F
.36912 .58171 m .36975 .5817 L .36971 .58099 L F
.918 .813 .346 r
.36957 .57924 m .36956 .57906 L .36965 .58022 L F
.36957 .57924 m .36965 .58022 L .36982 .58256 L F
.583 .577 .812 r
.36912 .58171 m .36964 .58014 L .36958 .5793 L F
.36912 .58171 m .36962 .57904 L .36934 .5797 L F
.36934 .58104 m .37143 .57889 L .3701 .57877 L F
.36912 .58171 m .36928 .58151 L .36934 .58104 L F
.36928 .58151 m .37143 .57889 L .36934 .58104 L F
.33 .006 .255 r
.36945 .57871 m .36975 .57874 L .3696 .57859 L F
.36975 .57874 m .37143 .57889 L .3696 .57859 L F
.3696 .57859 m .37143 .57889 L .37217 .57652 L F
.318 .339 .726 r
.37057 .57594 m .3698 .57859 L .36956 .57844 L F
.36953 .57852 m .36975 .57874 L .36945 .57871 L F
.37017 .57459 m .37143 .57889 L .36945 .57871 L F
.328 0 0 r
.3701 .57877 m .36925 .57826 L .36975 .57874 L F
.318 .339 .726 r
.37057 .57594 m .37143 .57889 L .36975 .57874 L F
.328 0 0 r
.37143 .57889 m .37033 .57857 L .3701 .57877 L F
.37033 .57857 m .36925 .57826 L .3701 .57877 L F
.36975 .57874 m .36963 .57869 L .36945 .57871 L F
.318 .339 .726 r
.37017 .57459 m .36945 .57871 L .36739 .57771 L F
.328 0 0 r
.36963 .57869 m .36739 .57771 L .36945 .57871 L F
.36925 .57826 m .36739 .57771 L .36975 .57874 L F
.088 .321 .798 r
.30772 .54038 m .3085 .53869 L .30603 .53958 L F
.30772 .54038 m .31037 .54239 L .3085 .53869 L F
.098 0 .124 r
.33964 .59947 m .3405 .59761 L .34235 .59659 L F
.499 .183 .362 r
.68903 .36197 m .6915 .36321 L .68831 .36475 L F
.68903 .36197 m .69174 .36167 L .6915 .36321 L F
.555 .666 .911 r
.33512 .71093 m .33564 .70765 L .33351 .70776 L F
.33512 .71093 m .33943 .71238 L .33564 .70765 L F
.633 .596 .794 r
.65935 .41156 m .6572 .41533 L .6566 .41308 L F
.106 .66 .752 r
.3957 .5938 m .39474 .59381 L .39211 .59407 L F
.787 .999 .831 r
.39826 .5908 m .3957 .5938 L .39857 .59378 L F
.39826 .5908 m .39474 .59381 L .3957 .5938 L F
.016 .161 .672 r
.2876 .62413 m .28671 .62611 L .28566 .62238 L F
.408 .739 .992 r
.56213 .42267 m .55999 .42294 L .55866 .42169 L F
0 0 .543 r
.39734 .54614 m .39936 .54885 L .39937 .54958 L F
0 0 .466 r
.40091 .55153 m .39937 .54958 L .39936 .54885 L F
.40091 .55153 m .40079 .55478 L .39937 .54958 L F
.304 .513 .894 r
.36202 .68396 m .36278 .68149 L .36032 .68228 L F
.286 0 0 r
.36202 .68396 m .36417 .68412 L .36589 .68303 L F
.304 .513 .894 r
.36202 .68396 m .36417 .68412 L .36278 .68149 L F
.992 .742 .39 r
.40519 .57093 m .40638 .57466 L .40645 .57183 L F
.5 .279 .51 r
.30542 .5274 m .30499 .53061 L .30755 .52942 L F
.632 .656 .855 r
.22482 .58493 m .21987 .58084 L .22198 .58046 L F
.518 .336 .574 r
.22588 .58153 m .22536 .58281 L .22449 .58249 L F
0 .258 .768 r
.22449 .58249 m .22482 .58493 L .22289 .5819 L F
.85 .996 .829 r
.22449 .58249 m .22171 .58551 L .22482 .58493 L F
.518 .336 .574 r
.22536 .58281 m .22391 .5864 L .22449 .58249 L F
0 .258 .768 r
.22449 .58249 m .22289 .5819 L .22198 .58046 L F
.535 .707 .95 r
.39613 .59909 m .39753 .60076 L .39531 .60021 L F
0 0 0 r
.39531 .60021 m .3951 .60228 L .39613 .59909 L F
.735 .973 .928 r
.36902 .68308 m .36895 .68342 L .37181 .68082 L F
.876 .644 .118 r
.40653 .57728 m .40669 .57978 L .40735 .58111 L F
.976 .674 .314 r
.40603 .58298 m .40735 .58111 L .40669 .57978 L F
.40603 .58298 m .40712 .58342 L .40735 .58111 L F
.786 .52 .534 r
.55276 .41558 m .55693 .41338 L .55582 .41306 L F
.81 .47 .412 r
.55895 .41587 m .55693 .41338 L .55743 .41597 L F
.769 .571 .63 r
.59529 .41601 m .59903 .4196 L .59786 .4182 L F
.955 .799 .649 r
.59903 .4196 m .59639 .4213 L .59786 .4182 L F
.59903 .4196 m .59833 .42219 L .59639 .4213 L F
.8 .832 .876 r
.65953 .34434 m .66146 .34628 L .65948 .34667 L F
.802 .832 .875 r
.66427 .34268 m .66146 .34628 L .65953 .34434 L F
.379 0 0 r
.41943 .54071 m .42213 .54192 L .42423 .54253 L F
.583 .51 .738 r
.42535 .53924 m .42537 .53942 L .42385 .53917 L F
.799 .956 .917 r
.42538 .5396 m .42537 .53942 L .42573 .53871 L F
.677 .595 .756 r
.42573 .53871 m .42675 .54325 L .42423 .54253 L F
.584 .533 .764 r
.43178 .54133 m .42675 .54325 L .42573 .53871 L F
.43178 .54133 m .42573 .53871 L .42941 .53942 L F
.583 .51 .738 r
.42732 .53932 m .42678 .53764 L .4255 .53924 L F
.42604 .53938 m .4255 .53924 L .42537 .53942 L F
.42732 .53932 m .4255 .53924 L .42604 .53938 L F
.42704 .53931 m .42537 .53942 L .42535 .53924 L F
.42732 .53932 m .42718 .53991 L .42699 .53931 L F
0 0 0 r
.42573 .53871 m .42739 .5358 L .42604 .53691 L F
.42675 .53692 m .42678 .53764 L .42739 .5358 L F
.42573 .53871 m .42678 .53764 L .42675 .53692 L F
.583 .51 .738 r
.42732 .53932 m .42679 .53806 L .42678 .53764 L F
.42679 .53806 m .42621 .5367 L .42678 .53764 L F
0 0 0 r
.42573 .53871 m .42537 .53942 L .42678 .53764 L F
.583 .51 .738 r
.42732 .53932 m .42699 .53931 L .42621 .5367 L F
.42732 .53932 m .42604 .53938 L .42699 .53931 L F
.42732 .53932 m .42699 .53931 L .42704 .53931 L F
.42604 .53938 m .42537 .53942 L .42704 .53931 L F
0 0 0 r
.42739 .5358 m .42678 .53764 L .42831 .53588 L F
.923 .968 .774 r
.42831 .53588 m .42678 .53764 L .42621 .5367 L F
.044 .155 .656 r
.42699 .53931 m .42704 .53929 L .42621 .5367 L F
.564 .403 .621 r
.42275 .53459 m .42414 .53926 L .41981 .53938 L F
.58 .579 .817 r
.42451 .53286 m .42604 .53691 L .42739 .5358 L F
.54 .389 .624 r
.42621 .5367 m .42414 .53926 L .42275 .53459 L F
.857 .748 .741 r
.42423 .53688 m .42414 .53926 L .42621 .5367 L F
.42423 .53688 m .42385 .53917 L .42414 .53926 L F
.42423 .53688 m .42708 .53913 L .42385 .53917 L F
.42708 .53913 m .42732 .53932 L .42704 .53931 L F
.42708 .53913 m .42704 .53931 L .42385 .53917 L F
.044 .155 .656 r
.42704 .53929 m .42808 .53896 L .42732 .53805 L F
.454 .829 .99 r
.42414 .53926 m .42052 .54007 L .41981 .53938 L F
.758 .737 .833 r
.42537 .53942 m .42052 .54007 L .42385 .53917 L F
.454 .829 .99 r
.42414 .53926 m .42385 .53917 L .42052 .54007 L F
.857 .748 .741 r
.42423 .53688 m .42222 .53956 L .42711 .53933 L F
.42708 .53913 m .42711 .53933 L .42732 .53932 L F
.42423 .53688 m .42711 .53933 L .42708 .53913 L F
.044 .155 .656 r
.42704 .53929 m .42708 .53913 L .42621 .5367 L F
.42708 .53913 m .42732 .53805 L .42679 .5374 L F
.42708 .53913 m .42679 .5374 L .42621 .5367 L F
.937 .88 .752 r
.42732 .53932 m .42716 .53944 L .42718 .53991 L F
.044 .155 .656 r
.4271 .53966 m .42716 .53961 L .42699 .53931 L F
.937 .88 .752 r
.42716 .53944 m .4247 .54123 L .42718 .53991 L F
.044 .155 .656 r
.42716 .53961 m .42767 .53926 L .42715 .5393 L F
.42716 .53961 m .42716 .53944 L .42699 .53931 L F
.799 .956 .917 r
.42423 .54253 m .42537 .53942 L .42538 .5396 L F
.42423 .54253 m .42213 .54192 L .42537 .53942 L F
.758 .737 .833 r
.42537 .53942 m .42213 .54192 L .42052 .54007 L F
.805 .641 .679 r
.42222 .53956 m .4247 .54123 L .42716 .53944 L F
.42711 .53933 m .42716 .53944 L .42732 .53932 L F
.044 .155 .656 r
.42716 .53944 m .4271 .5393 L .42699 .53931 L F
.805 .641 .679 r
.42222 .53956 m .42716 .53944 L .42711 .53933 L F
.044 .155 .656 r
.42716 .53944 m .42715 .5393 L .4271 .5393 L F
.42767 .53926 m .42808 .53896 L .42699 .53931 L F
.42718 .53991 m .42736 .53972 L .4271 .53966 L F
.42736 .53972 m .42808 .53896 L .4271 .53966 L F
.665 .385 .485 r
.42675 .54325 m .42428 .54577 L .42423 .54253 L F
.66 .468 .614 r
.67166 .35329 m .66706 .35601 L .66705 .35289 L F
.67166 .35329 m .67125 .35597 L .66706 .35601 L F
.418 .045 .221 r
.2939 .6256 m .29075 .62414 L .29042 .62732 L F
.2939 .6256 m .29271 .6272 L .29 .62794 L F
.614 .266 .357 r
.2939 .6256 m .29566 .62772 L .29271 .6272 L F
.835 .803 .311 r
.24387 .5422 m .24317 .54656 L .2427 .5429 L F
.758 .988 .896 r
.24312 .54499 m .2421 .54631 L .24317 .54656 L F
.187 .122 .547 r
.24312 .54499 m .24328 .54598 L .2421 .54631 L F
.24328 .54598 m .24353 .54758 L .2421 .54631 L F
.257 .759 .886 r
.24089 .54664 m .2421 .54631 L .23918 .5467 L F
.24317 .54656 m .2421 .54631 L .24089 .54664 L F
.835 .803 .311 r
.24387 .5422 m .24312 .54499 L .24317 .54656 L F
.173 0 0 r
.69827 .35896 m .69961 .35945 L .69714 .36047 L F
.69827 .35896 m .7006 .35908 L .69961 .35945 L F
.726 .948 .646 r
.69871 .35979 m .69961 .35945 L .70101 .35707 L F
.061 0 0 r
.69629 .36195 m .69714 .36047 L .69961 .35945 L F
.726 .948 .646 r
.69828 .3603 m .69961 .35945 L .69871 .35979 L F
.173 0 0 r
.7006 .35908 m .70093 .35909 L .69961 .35945 L F
.4 .244 .552 r
.32671 .57372 m .32533 .57163 L .3252 .56996 L F
.42 .295 .603 r
.3291 .5704 m .3252 .56996 L .32676 .56825 L F
.294 .232 .615 r
.32891 .57301 m .3252 .56996 L .3291 .5704 L F
.32891 .57301 m .32671 .57372 L .3252 .56996 L F
.168 0 .159 r
.34548 .55979 m .34662 .56079 L .34765 .55908 L F
.34548 .55979 m .34469 .56165 L .34662 .56079 L F
.796 .825 .875 r
.71789 .34104 m .71342 .34255 L .71655 .33954 L F
.833 .866 .869 r
.72016 .33878 m .71789 .34104 L .71655 .33954 L F
.4 .244 .552 r
.32671 .57372 m .32494 .57466 L .32533 .57163 L F
.37 .826 .926 r
.63107 .44003 m .63168 .43952 L .63341 .43988 L F
.329 .813 .806 r
.63168 .43952 m .63586 .43852 L .63341 .43988 L F
.63168 .43952 m .63395 .43876 L .63586 .43852 L F
.498 .875 .976 r
.63168 .43952 m .63316 .43814 L .63395 .43876 L F
0 0 0 r
.63168 .43952 m .63037 .44127 L .63269 .43867 L F
.63168 .43952 m .63269 .43867 L .63316 .43814 L F
.37 .826 .926 r
.62913 .44016 m .63168 .43952 L .63107 .44003 L F
.15 .189 .647 r
.37309 .60945 m .37506 .61215 L .37443 .60954 L F
.858 .859 .84 r
.68371 .32164 m .67968 .32327 L .68233 .32011 L F
.865 .862 .834 r
.68627 .31842 m .68371 .32164 L .68233 .32011 L F
.657 .274 .308 r
.59529 .41601 m .59352 .41792 L .59302 .41579 L F
.59529 .41601 m .59786 .4182 L .59352 .41792 L F
.762 .944 .94 r
.34467 .66355 m .34526 .66155 L .34319 .66294 L F
.34467 .66355 m .34778 .66175 L .34526 .66155 L F
.995 .867 .586 r
.39681 .59726 m .39753 .60076 L .39845 .59901 L F
.416 .647 .953 r
.39845 .59901 m .39753 .60076 L .39613 .59909 L F
0 0 0 r
.29886 .60412 m .2961 .60688 L .29758 .60572 L F
0 0 .221 r
.29549 .60931 m .29758 .60572 L .2961 .60688 L F
.368 .605 .94 r
.25261 .61485 m .2518 .61663 L .25042 .61508 L F
.25261 .61485 m .2538 .61657 L .2518 .61663 L F
.161 0 .017 r
.29758 .60572 m .30102 .60324 L .29886 .60412 L F
.704 .576 .708 r
.3576 .54599 m .35843 .5463 L .35543 .54624 L F
.667 .123 0 r
.26481 .63233 m .26399 .63301 L .26142 .6312 L F
0 .15 .587 r
.26481 .63233 m .2657 .63293 L .26399 .63301 L F
.26481 .63233 m .26739 .6341 L .2657 .63293 L F
.482 .552 .851 r
.26481 .63233 m .26892 .6355 L .26739 .6341 L F
.939 .766 .641 r
.70913 .35976 m .70697 .36124 L .7049 .35874 L F
.70913 .35976 m .70885 .36219 L .70697 .36124 L F
.708 .846 .948 r
.71878 .32237 m .71734 .32521 L .71606 .32496 L F
.71878 .32237 m .71995 .32393 L .71734 .32521 L F
.721 .902 .527 r
.40457 .67572 m .40288 .67841 L .40439 .67636 L F
.09 0 .133 r
.3866 .58124 m .38385 .58508 L .38495 .58327 L F
.445 0 0 r
.38737 .58249 m .3866 .58124 L .38495 .58327 L F
.339 0 0 r
.38259 .58679 m .38606 .58593 L .38496 .58641 L F
0 0 0 r
.38713 .58324 m .38737 .58249 L .38564 .58623 L F
.445 0 0 r
.38737 .58249 m .38949 .58177 L .3877 .58144 L F
0 0 .167 r
.38991 .58218 m .38988 .58429 L .38949 .58177 L F
.38991 .58218 m .38949 .58177 L .38737 .58249 L F
.498 .785 .996 r
.38825 .58098 m .38991 .58218 L .38737 .58249 L F
0 0 0 r
.38825 .58098 m .38737 .58249 L .38713 .58324 L F
.445 0 0 r
.38737 .58249 m .3877 .58144 L .3866 .58124 L F
.665 .76 .921 r
.24483 .58738 m .24924 .58823 L .24717 .58643 L F
.415 .236 .528 r
.35395 .59697 m .35595 .59683 L .35583 .59362 L F
.212 .13 .541 r
.35395 .59697 m .35564 .59926 L .35595 .59683 L F
.35395 .59697 m .3537 .6006 L .35564 .59926 L F
.549 .534 .791 r
.62976 .38097 m .62695 .38155 L .62573 .37765 L F
.585 .597 .831 r
.62961 .38329 m .62695 .38155 L .62976 .38097 L F
.111 0 .038 r
.36137 .5903 m .36035 .59269 L .36336 .59031 L F
.814 .631 .655 r
.67125 .35597 m .67394 .35877 L .67086 .35856 L F
.443 .828 .987 r
.30708 .65761 m .30946 .6571 L .3078 .65641 L F
0 0 0 r
.27807 .55505 m .27725 .55535 L .2751 .55577 L F
.427 .248 .533 r
.27791 .5567 m .2751 .55577 L .27725 .55535 L F
.27791 .5567 m .27516 .55832 L .2751 .55577 L F
0 0 .47 r
.39609 .53983 m .39771 .54233 L .39803 .5433 L F
.732 .657 .102 r
.39771 .54233 m .39734 .54614 L .39803 .5433 L F
.365 .813 .946 r
.33443 .49836 m .33333 .49779 L .33717 .49776 L F
.485 .853 .988 r
.27444 .52214 m .26851 .52134 L .2712 .52262 L F
.526 .92 .884 r
.27656 .52102 m .27444 .52214 L .2712 .52262 L F
.512 .306 .537 r
.34426 .6535 m .34132 .65134 L .34098 .65386 L F
.34426 .6535 m .34436 .65069 L .34132 .65134 L F
.184 .62 .943 r
.34618 .49881 m .34509 .49962 L .34332 .49862 L F
.34618 .49881 m .34763 .49966 L .34509 .49962 L F
.625 .259 .328 r
.6048 .44484 m .60317 .44701 L .60065 .44699 L F
.582 .208 .298 r
.6048 .44484 m .60745 .44675 L .60317 .44701 L F
.646 .521 .697 r
.35143 .68242 m .34886 .68601 L .35002 .68353 L F
.738 .919 .56 r
.40538 .59919 m .40524 .5999 L .40694 .59762 L F
.954 .918 .559 r
.40538 .59919 m .40694 .59762 L .40656 .59559 L F
0 0 0 r
.61376 .44367 m .61059 .44676 L .61167 .44555 L F
.948 .83 .695 r
.54841 .43449 m .54911 .43838 L .54607 .4375 L F
.929 .715 .591 r
.54911 .43838 m .54623 .44005 L .54607 .4375 L F
.54911 .43838 m .54821 .44122 L .54623 .44005 L F
.835 .596 .578 r
.55134 .44182 m .54821 .44122 L .54911 .43838 L F
.542 .538 .8 r
.65415 .38782 m .65468 .38979 L .6516 .3886 L F
.664 .496 .647 r
.57364 .45376 m .56948 .45129 L .57193 .4509 L F
.69 .607 .758 r
.64013 .382 m .63449 .3833 L .63594 .38224 L F
.63985 .3816 m .63594 .38224 L .63882 .38012 L F
.64013 .382 m .63594 .38224 L .63985 .3816 L F
.704 .623 .763 r
.63194 .37853 m .63477 .38243 L .62976 .38097 L F
.63477 .38243 m .6351 .38289 L .63412 .38254 L F
.63477 .38243 m .63412 .38254 L .62976 .38097 L F
0 0 0 r
.63882 .38012 m .63602 .38218 L .63673 .38167 L F
.63602 .38218 m .63449 .3833 L .63551 .38256 L F
.63602 .38218 m .63551 .38256 L .63673 .38167 L F
.69 .607 .758 r
.64013 .382 m .63763 .38476 L .63449 .3833 L F
.642 .518 .696 r
.6351 .38289 m .63458 .38518 L .63288 .38453 L F
.63506 .3829 m .63288 .38453 L .62961 .38329 L F
.6351 .38289 m .63288 .38453 L .63506 .3829 L F
.6351 .38289 m .62961 .38329 L .62976 .38097 L F
.613 .462 .653 r
.25385 .56825 m .25124 .57171 L .25127 .56873 L F
0 0 .317 r
.35428 .60792 m .35506 .61116 L .35558 .61254 L F
.328 .092 .396 r
.35506 .61116 m .35363 .61321 L .35558 .61254 L F
.391 .407 .757 r
.3261 .55491 m .32743 .56194 L .32524 .55922 L F
0 0 0 r
.22058 .54695 m .21949 .54903 L .22195 .54572 L F
.21776 .5502 m .21619 .55166 L .21949 .54903 L F
0 0 .534 r
.29937 .52984 m .30008 .52978 L .29987 .52819 L F
0 0 0 r
.29937 .52984 m .29987 .52819 L .29999 .52667 L F
.112 0 .09 r
.38244 .59381 m .38395 .59342 L .38513 .59069 L F
.38395 .59342 m .38469 .59322 L .38501 .59139 L F
.38395 .59342 m .38501 .59139 L .38513 .59069 L F
.349 .67 .975 r
.38257 .59181 m .38469 .59322 L .38244 .59381 L F
.313 .365 .756 r
.38215 .59453 m .38244 .59381 L .38356 .5951 L F
.38215 .59453 m .38257 .59181 L .38244 .59381 L F
.521 .334 .569 r
.38257 .59181 m .38215 .59453 L .38316 .59494 L F
.38338 .5945 m .38316 .59494 L .38356 .5951 L F
.38257 .59181 m .38316 .59494 L .38338 .5945 L F
.744 .442 .471 r
.38469 .59322 m .38746 .59009 L .38513 .59069 L F
.607 .384 .552 r
.23311 .59079 m .23244 .5941 L .23568 .59338 L F
.458 .449 .76 r
.43499 .52511 m .43689 .52894 L .43401 .52748 L F
.646 .889 .984 r
.43817 .54652 m .43681 .54554 L .4394 .54457 L F
.259 .378 .794 r
.4394 .54457 m .43991 .54673 L .43817 .54652 L F
.646 .889 .984 r
.43817 .54652 m .43681 .54554 L .4394 .54457 L F
.719 .513 .611 r
.44109 .54946 m .43817 .54652 L .43991 .54673 L F
.439 .612 .922 r
.33564 .70765 m .33943 .71238 L .33773 .70811 L F
.768 .69 .777 r
.66313 .35228 m .66441 .35611 L .66054 .35551 L F
.678 .484 .617 r
.66441 .35611 m .66181 .35885 L .66054 .35551 L F
.66441 .35611 m .66444 .35881 L .66181 .35885 L F
.757 .685 .781 r
.66705 .35289 m .66441 .35611 L .66313 .35228 L F
.7 .595 .736 r
.66705 .35289 m .66706 .35601 L .66441 .35611 L F
.693 .497 .618 r
.66706 .35601 m .66444 .35881 L .66441 .35611 L F
.794 .765 .827 r
.63032 .39717 m .63368 .39736 L .63264 .39418 L F
.517 .601 .876 r
.63264 .39418 m .63368 .39736 L .63606 .3967 L F
.427 .261 .551 r
.63368 .39736 m .63382 .39993 L .63606 .3967 L F
0 0 .024 r
.30128 .60046 m .30276 .59974 L .3039 .5976 L F
.304 .126 .467 r
.30128 .60046 m .3029 .60204 L .30276 .59974 L F
.30128 .60046 m .30102 .60324 L .3029 .60204 L F
.001 0 .083 r
.21348 .55506 m .21619 .55166 L .21491 .55301 L F
.296 .738 .964 r
.5807 .41552 m .57845 .41575 L .57677 .41488 L F
0 0 0 r
.24961 .5464 m .2471 .54969 L .24863 .54777 L F
.354 .216 .551 r
.24642 .55193 m .24863 .54777 L .2471 .54969 L F
.788 .68 .746 r
.24576 .56165 m .24987 .56238 L .24823 .55864 L F
.721 .349 .345 r
.24555 .56389 m .24987 .56238 L .24576 .56165 L F
.24555 .56389 m .24787 .56459 L .24987 .56238 L F
.64 .245 .28 r
.24987 .56238 m .24787 .56459 L .25201 .56443 L F
.665 .385 .485 r
.42675 .54325 m .42647 .5462 L .42428 .54577 L F
.348 .071 .344 r
.43178 .54133 m .42647 .5462 L .42675 .54325 L F
.558 .318 .508 r
.40465 .6669 m .4041 .66971 L .40205 .66784 L F
.045 .183 .685 r
.20276 .59077 m .20377 .58947 L .20184 .58746 L F
0 0 0 r
.20276 .59077 m .20184 .59287 L .20377 .58947 L F
0 0 .084 r
.21923 .58881 m .21834 .59092 L .21878 .58766 L F
.64 .648 .842 r
.42177 .50221 m .41755 .49963 L .42054 .49908 L F
.499 .504 .793 r
.42299 .49788 m .42177 .50221 L .42054 .49908 L F
.42299 .49788 m .42427 .50156 L .42177 .50221 L F
.497 .496 .786 r
.42427 .50156 m .42464 .50387 L .42177 .50221 L F
.474 .456 .757 r
.35065 .52959 m .34895 .53229 L .34846 .5301 L F
0 .054 .604 r
.35449 .5116 m .3567 .5144 L .35678 .51358 L F
.675 .171 .039 r
.35449 .5116 m .35678 .51358 L .35279 .51271 L F
.473 .695 .965 r
.39119 .65928 m .39033 .66186 L .38812 .66131 L F
.39119 .65928 m .39291 .66172 L .39033 .66186 L F
.863 .581 .509 r
.55127 .44415 m .54821 .44122 L .55134 .44182 L F
0 0 .361 r
.39249 .56563 m .39267 .56552 L .39136 .56281 L F
.239 .372 .797 r
.39251 .56824 m .39267 .56552 L .39249 .56563 L F
.42 .802 .991 r
.59099 .43215 m .59586 .43204 L .5935 .43225 L F
.719 .619 .744 r
.33041 .6605 m .33171 .665 L .32801 .66505 L F
.049 .616 .745 r
.32801 .66505 m .33171 .665 L .33018 .66496 L F
.668 .885 .521 r
.33318 .66268 m .33171 .665 L .33041 .6605 L F
.561 .717 .945 r
.33171 .665 m .33318 .66268 L .33018 .66496 L F
.33171 .665 m .33404 .66469 L .33318 .66268 L F
.817 .781 .819 r
.38464 .6385 m .38917 .63888 L .38708 .63752 L F
.38464 .6385 m .38615 .64167 L .38917 .63888 L F
.805 .826 .868 r
.38708 .63752 m .38917 .63888 L .39015 .63685 L F
.511 .883 .677 r
.24287 .53059 m .24385 .52963 L .24579 .52849 L F
.48 .896 .898 r
.24287 .53059 m .24036 .53068 L .24385 .52963 L F
.029 .251 .752 r
.60099 .41472 m .60113 .41655 L .59972 .41325 L F
0 .076 .637 r
.60263 .41709 m .60113 .41655 L .60099 .41472 L F
.60263 .41709 m .60272 .41858 L .60113 .41655 L F
.072 .513 .899 r
.31455 .64805 m .31839 .65 L .31736 .64902 L F
.872 .925 .858 r
.31736 .64902 m .31839 .65 L .32019 .64769 L F
.1 0 .089 r
.3039 .5976 m .30511 .59861 L .30587 .59652 L F
.3039 .5976 m .30276 .59974 L .30511 .59861 L F
.3 .123 .465 r
.32086 .59253 m .3188 .59096 L .32086 .5898 L F
.32086 .59253 m .31846 .59357 L .3188 .59096 L F
.779 .823 .887 r
.38281 .67329 m .38037 .67562 L .37878 .67319 L F
.866 .443 .211 r
.39522 .51954 m .39299 .51887 L .39127 .51524 L F
.044 .401 .856 r
.39418 .51905 m .39614 .52044 L .39582 .51929 L F
.735 .258 0 r
.39657 .52081 m .39675 .522 L .39522 .51954 L F
.39675 .522 m .39661 .52184 L .39522 .51954 L F
.39675 .522 m .39676 .52209 L .39661 .52184 L F
0 0 .453 r
.39522 .51954 m .39676 .52209 L .39614 .52044 L F
.39522 .51954 m .39614 .52044 L .39299 .51887 L F
.044 .401 .856 r
.39299 .51887 m .39482 .51978 L .39418 .51905 L F
.39482 .51978 m .39614 .52044 L .39418 .51905 L F
.735 .258 0 r
.39657 .52081 m .39831 .52353 L .39676 .52209 L F
.803 .313 0 r
.40002 .52437 m .39831 .52353 L .39657 .52081 L F
.343 0 0 r
.27572 .62025 m .27735 .62106 L .27886 .61894 L F
.27572 .62025 m .27449 .62156 L .27735 .62106 L F
.527 .818 .999 r
.2866 .52633 m .28854 .52769 L .29089 .52703 L F
.656 .473 .625 r
.36663 .54993 m .36673 .55253 L .36248 .55253 L F
.692 .625 .777 r
.36928 .54959 m .36663 .54993 L .3676 .54484 L F
.671 .485 .625 r
.36928 .54959 m .36673 .55253 L .36663 .54993 L F
.606 .83 .985 r
.38098 .65074 m .37847 .65153 L .37691 .65036 L F
.258 0 .006 r
.33493 .52991 m .33731 .52939 L .33839 .52801 L F
.524 .213 .381 r
.33731 .52939 m .34068 .52714 L .33839 .52801 L F
.796 .697 .755 r
.36762 .58988 m .36646 .59532 L .36552 .59074 L F
.618 .234 .293 r
.35804 .59605 m .35583 .59362 L .35595 .59683 L F
.116 0 .35 r
.37091 .60033 m .37238 .60217 L .37281 .60002 L F
.37091 .60033 m .37071 .60306 L .37226 .60224 L F
.37091 .60033 m .37226 .60224 L .37228 .60205 L F
.971 .679 .417 r
.37086 .60087 m .3725 .60015 L .37109 .59816 L F
.3725 .60015 m .37281 .60002 L .37255 .59974 L F
.3725 .60015 m .37255 .59974 L .37109 .59816 L F
.116 0 .35 r
.37228 .60205 m .37226 .60224 L .37238 .60217 L F
.005 .015 .516 r
.32852 .5463 m .32929 .54183 L .33062 .54294 L F
.32852 .5463 m .32997 .5447 L .32929 .54183 L F
.041 0 .424 r
.71963 .35997 m .71841 .36193 L .71833 .35921 L F
.15 .682 .859 r
.36741 .68273 m .36902 .68308 L .36589 .68303 L F
.36741 .68273 m .36589 .68303 L .36417 .68412 L F
.257 0 .041 r
.2679 .54584 m .26411 .54802 L .2658 .54558 L F
.771 .777 .858 r
.57336 .42029 m .5686 .42179 L .57212 .41948 L F
.861 .892 .857 r
.5744 .41675 m .57336 .42029 L .57212 .41948 L F
.793 .677 .737 r
.37966 .64465 m .38446 .64334 L .38207 .64123 L F
.593 .411 .604 r
.38446 .64334 m .38615 .64167 L .38207 .64123 L F
.38446 .64334 m .38637 .6449 L .38615 .64167 L F
.38615 .64167 m .38637 .6449 L .38446 .64334 L F
.257 0 .256 r
.34858 .65121 m .35147 .64831 L .35074 .651 L F
.422 .511 .844 r
.35295 .64743 m .35147 .64831 L .34947 .64386 L F
.04 0 .167 r
.35074 .651 m .35147 .64831 L .35295 .64743 L F
.916 .9 .795 r
.42548 .5706 m .42919 .56841 L .42787 .56745 L F
.42548 .5706 m .42671 .57166 L .42919 .56841 L F
.678 .654 .818 r
.62469 .41576 m .62035 .41752 L .62102 .41608 L F
.693 .497 .618 r
.66706 .35601 m .66957 .35945 L .66444 .35881 L F
.793 .65 .704 r
.67125 .35597 m .66957 .35945 L .66706 .35601 L F
.502 .234 .44 r
.28085 .64483 m .28112 .64478 L .28312 .64659 L F
.28112 .64478 m .28337 .64439 L .28312 .64659 L F
.689 .152 0 r
.28312 .64659 m .28346 .64673 L .28534 .64865 L F
.28346 .64673 m .28627 .64794 L .28534 .64865 L F
.996 .764 .427 r
.28775 .65014 m .28876 .6535 L .28736 .6522 L F
.925 .701 .581 r
.28534 .64865 m .28775 .65014 L .28736 .6522 L F
0 .039 .581 r
.28534 .64865 m .2878 .65129 L .28728 .65064 L F
.836 .367 .05 r
.28627 .64794 m .28775 .65014 L .28534 .64865 L F
0 .039 .581 r
.28534 .64865 m .28728 .65064 L .28521 .64802 L F
0 .106 .638 r
.28312 .64659 m .28534 .64865 L .28515 .64843 L F
.808 .64 .673 r
.28566 .64386 m .28312 .64659 L .28337 .64439 L F
.28566 .64386 m .28627 .64794 L .28312 .64659 L F
0 .106 .638 r
.28312 .64659 m .28515 .64843 L .28303 .64584 L F
.502 .234 .44 r
.28085 .64483 m .28337 .64439 L .28312 .64659 L F
.989 .724 .415 r
.2831 .64654 m .28337 .64439 L .28312 .64659 L F
.639 .946 .726 r
.28085 .64483 m .2836 .64258 L .28337 .64439 L F
.532 .794 .993 r
.28085 .64483 m .28337 .64439 L .28191 .64298 L F
.989 .724 .415 r
.28191 .64298 m .28337 .64439 L .2831 .64654 L F
.639 .946 .726 r
.2836 .64258 m .28424 .64206 L .28337 .64439 L F
.674 .648 .816 r
.28565 .64258 m .28424 .64206 L .2851 .6416 L F
.28565 .64258 m .28337 .64439 L .28424 .64206 L F
.57 .464 .694 r
.30519 .54649 m .3056 .54931 L .30321 .54978 L F
0 0 0 r
.30321 .54978 m .30442 .54826 L .30519 .54649 L F
.546 .299 .492 r
.3056 .54931 m .3028 .55213 L .30321 .54978 L F
0 0 0 r
.30321 .54978 m .30334 .55034 L .30442 .54826 L F
.30321 .54978 m .3028 .55213 L .30334 .55034 L F
.818 .78 .817 r
.64444 .42129 m .6433 .42598 L .64209 .42474 L F
.64444 .42129 m .64599 .42285 L .6433 .42598 L F
.699 .64 .787 r
.64918 .38059 m .65044 .38203 L .64653 .38119 L F
.68 .677 .84 r
.65196 .37771 m .65044 .38203 L .64918 .38059 L F
.65196 .37771 m .65306 .38114 L .65044 .38203 L F
.734 .731 .848 r
.64422 .38246 m .64013 .382 L .64269 .38086 L F
.766 .881 .929 r
.64531 .37981 m .64422 .38246 L .64269 .38086 L F
.64531 .37981 m .64653 .38119 L .64422 .38246 L F
.619 .905 .984 r
.33819 .59305 m .33612 .59411 L .33209 .59457 L F
.303 .489 .875 r
.38727 .56688 m .38611 .56917 L .38519 .56829 L F
.38727 .56688 m .38892 .56998 L .38611 .56917 L F
.605 .569 .787 r
.38611 .56917 m .3904 .57164 L .38892 .56998 L F
.603 .413 .598 r
.36652 .55475 m .36248 .55253 L .36673 .55253 L F
.36652 .55475 m .36315 .55564 L .36248 .55253 L F
.887 .862 .81 r
.66588 .36735 m .66723 .36879 L .66475 .37159 L F
.721 .555 .665 r
.66723 .36879 m .66756 .37198 L .66475 .37159 L F
.794 .819 .871 r
.66898 .36396 m .66723 .36879 L .66588 .36735 L F
.66898 .36396 m .67153 .36553 L .66723 .36879 L F
.699 .593 .734 r
.67153 .36553 m .67073 .36892 L .66723 .36879 L F
.511 .263 .474 r
.67073 .36892 m .66756 .37198 L .66723 .36879 L F
.717 .183 0 r
.59805 .39877 m .6013 .40049 L .60048 .40101 L F
.835 .369 0 r
.6013 .40049 m .60275 .40309 L .60048 .40101 L F
0 0 .035 r
.22185 .57721 m .22026 .57823 L .22284 .57507 L F
.422 .281 .582 r
.22185 .57721 m .21987 .58084 L .22026 .57823 L F
.629 .93 .97 r
.34526 .66155 m .34778 .66175 L .35008 .66054 L F
.326 .279 .652 r
.35074 .651 m .35086 .65339 L .34858 .65121 L F
.996 .821 .464 r
.40796 .59049 m .40838 .58819 L .40723 .58607 L F
.482 .67 .947 r
.39567 .65392 m .39929 .65476 L .39889 .65526 L F
.373 .466 .826 r
.4003 .65325 m .40184 .65689 L .39889 .65526 L F
.4003 .65325 m .39889 .65526 L .39929 .65476 L F
.865 .862 .834 r
.68627 .31842 m .68233 .32011 L .68479 .3168 L F
.774 .839 .902 r
.25339 .5318 m .25376 .53416 L .25699 .53353 L F
.396 .578 .913 r
.25699 .53353 m .25674 .52959 L .25339 .5318 L F
.25699 .53353 m .25881 .53312 L .25674 .52959 L F
.202 .726 .729 r
.37194 .64154 m .3724 .64152 L .36828 .64245 L F
.992 .82 .573 r
.37214 .63749 m .3724 .64152 L .37432 .63927 L F
.635 .925 .656 r
.37432 .63927 m .3724 .64152 L .37194 .64154 L F
.497 .093 .206 r
.32477 .55113 m .32889 .54914 L .32641 .54979 L F
0 .526 .844 r
.36767 .65058 m .37189 .6519 L .37061 .64854 L F
.563 .507 .751 r
.37189 .6519 m .37314 .64711 L .37061 .64854 L F
.37189 .6519 m .37495 .65202 L .37314 .64711 L F
.888 .906 .834 r
.38733 .65341 m .38884 .65435 L .39144 .65081 L F
.985 .735 .472 r
.38836 .65664 m .38884 .65435 L .38733 .65341 L F
0 0 0 r
.38994 .65342 m .38884 .65435 L .39144 .65081 L F
.24863 .54777 m .25219 .54609 L .24961 .5464 L F
.464 .587 .891 r
.41866 .53888 m .41943 .54071 L .41687 .54067 L F
.379 .674 .974 r
.2389 .57098 m .23909 .56892 L .23578 .56871 L F
.2389 .57098 m .2407 .5707 L .23909 .56892 L F
.501 .727 .974 r
.56755 .39761 m .56873 .39534 L .56644 .39681 L F
.56755 .39761 m .57033 .39718 L .56873 .39534 L F
.56873 .39534 m .56755 .39761 L .56644 .39681 L F
.56873 .39534 m .57033 .39718 L .56755 .39761 L F
0 0 0 r
.22365 .57511 m .22284 .57507 L .22502 .57441 L F
.22365 .57511 m .22185 .57721 L .22284 .57507 L F
.407 .163 .428 r
.29568 .63524 m .29272 .63875 L .29519 .6385 L F
0 0 .316 r
.29699 .63454 m .29568 .63524 L .29519 .6385 L F
.838 .924 .89 r
.60836 .38986 m .61016 .39109 L .60642 .39403 L F
.791 .922 .925 r
.61155 .38892 m .61016 .39109 L .60836 .38986 L F
.525 .836 .999 r
.28694 .52043 m .28287 .52013 L .28523 .51987 L F
.438 .802 .995 r
.2876 .51912 m .28694 .52043 L .28523 .51987 L F
.2876 .51912 m .28928 .52004 L .28694 .52043 L F
.718 .354 .358 r
.5556 .44463 m .55361 .44676 L .55127 .44415 L F
.829 .514 .455 r
.5556 .44463 m .55771 .4481 L .55361 .44676 L F
.812 .512 .483 r
.55948 .44775 m .55771 .4481 L .5556 .44463 L F
.556 .433 .668 r
.64165 .40364 m .64478 .40057 L .64036 .39999 L F
.64165 .40364 m .6444 .40281 L .64478 .40057 L F
.728 .744 .865 r
.38207 .64123 m .38615 .64167 L .38464 .6385 L F
.669 .795 .942 r
.39194 .68587 m .39585 .68611 L .39303 .68339 L F
.494 .245 .466 r
.39194 .68587 m .39491 .68584 L .39585 .68611 L F
.436 .293 .587 r
.38637 .6449 m .38848 .64384 L .38615 .64167 L F
.38637 .6449 m .38848 .64384 L .38615 .64167 L F
.64 .786 .952 r
.39367 .684 m .39585 .68611 L .39521 .68316 L F
.98 .915 .625 r
.39512 .68275 m .39585 .68611 L .39491 .68584 L F
.64 .786 .952 r
.39367 .684 m .39521 .68316 L .39512 .68275 L F
.678 .679 .843 r
.39512 .68275 m .39491 .68584 L .39339 .68406 L F
.447 .873 .766 r
.39515 .68177 m .39924 .68115 L .39526 .6813 L F
.39483 .68312 m .39636 .68244 L .39515 .68177 L F
.39636 .68244 m .39924 .68115 L .39515 .68177 L F
.39483 .68312 m .39628 .68226 L .39709 .68196 L F
.39657 .68229 m .39709 .68196 L .39805 .6816 L F
.39483 .68312 m .39709 .68196 L .39657 .68229 L F
.39723 .68205 m .39805 .6816 L .39924 .68115 L F
.39636 .68244 m .39805 .6816 L .39723 .68205 L F
.39483 .68312 m .39657 .68229 L .39636 .68244 L F
.39657 .68229 m .39805 .6816 L .39636 .68244 L F
0 0 .418 r
.40214 .6818 m .40166 .68547 L .40122 .68582 L F
.829 .722 .746 r
.39715 .68395 m .40166 .68547 L .40214 .6818 L F
.39715 .68395 m .40214 .6818 L .39924 .68115 L F
.727 .48 .552 r
.39519 .67814 m .39526 .6813 L .39924 .68115 L F
.363 .543 .898 r
.39757 .68099 m .39924 .68115 L .39628 .68226 L F
.39757 .68099 m .39715 .68395 L .39924 .68115 L F
.39747 .68171 m .39835 .68354 L .39729 .68295 L F
.39757 .68099 m .39774 .68154 L .39747 .68171 L F
.39774 .68154 m .39835 .68354 L .39747 .68171 L F
.39774 .68154 m .40045 .68282 L .39835 .68354 L F
.39757 .68099 m .39808 .68131 L .39774 .68154 L F
.39808 .68131 m .40045 .68282 L .39774 .68154 L F
.39729 .68295 m .39835 .68354 L .39715 .68395 L F
.64 .786 .952 r
.39303 .68339 m .39367 .684 L .39512 .68275 L F
.546 .323 .528 r
.42505 .52989 m .42451 .53286 L .42143 .53331 L F
.227 0 0 r
.4269 .53164 m .42451 .53286 L .42505 .52989 L F
.48 .273 .521 r
.35309 .61567 m .35558 .61254 L .35363 .61321 L F
.913 .903 .801 r
.59726 .38628 m .59621 .3911 L .59477 .38973 L F
.991 .768 .503 r
.59477 .38973 m .59621 .3911 L .59595 .39356 L F
.841 .659 .656 r
.70475 .32954 m .70735 .33199 L .70881 .33123 L F
.774 .905 .932 r
.30906 .51259 m .30793 .51213 L .3099 .51052 L F
.266 .016 .336 r
.33698 .57959 m .33538 .57721 L .33717 .57692 L F
.33698 .57959 m .33503 .5805 L .33538 .57721 L F
.599 .948 .813 r
.40632 .50779 m .40525 .50791 L .40728 .50643 L F
.715 .987 .871 r
.35916 .51185 m .3567 .5144 L .36055 .51313 L F
.35916 .51185 m .35678 .51358 L .3567 .5144 L F
.423 .071 .26 r
.37421 .68487 m .37279 .68359 L .37327 .68185 L F
.37421 .68487 m .37065 .68563 L .37279 .68359 L F
.538 .48 .739 r
.29711 .55281 m .3002 .55529 L .30073 .55298 L F
.468 .252 .501 r
.3028 .55213 m .3002 .55529 L .30073 .55298 L F
.3028 .55213 m .3002 .55529 L .30073 .55298 L F
.441 .438 .76 r
.43222 .51042 m .43113 .51486 L .43017 .51087 L F
.43222 .51042 m .4332 .5147 L .43113 .51486 L F
.459 .451 .762 r
.4344 .51648 m .43113 .51486 L .4332 .5147 L F
.743 .688 .799 r
.30499 .53061 m .30173 .53369 L .30653 .53376 L F
.763 .481 .507 r
.30173 .53369 m .30612 .5363 L .30653 .53376 L F
.623 .614 .821 r
.30653 .53376 m .30755 .52942 L .30499 .53061 L F
.30653 .53376 m .30915 .53352 L .30755 .52942 L F
.338 .029 .286 r
.30612 .5363 m .30915 .53352 L .30653 .53376 L F
0 0 .223 r
.40122 .68582 m .40138 .68853 L .40032 .68948 L F
.719 .928 .594 r
.40138 .68853 m .39921 .69174 L .40032 .68948 L F
.647 .11 0 r
.32108 .69114 m .32381 .69324 L .32342 .69373 L F
.616 .06 0 r
.32381 .69324 m .32775 .69622 L .32638 .69484 L F
.493 0 0 r
.32342 .69373 m .32381 .69324 L .32638 .69484 L F
.531 0 0 r
.3636 .51316 m .35916 .51185 L .36055 .51313 L F
.842 .648 .641 r
.56948 .45129 m .56569 .45311 L .56553 .451 L F
.56948 .45129 m .56937 .45427 L .56569 .45311 L F
.664 .496 .647 r
.57364 .45376 m .56937 .45427 L .56948 .45129 L F
.607 .925 .969 r
.30876 .6247 m .30661 .62579 L .30729 .62427 L F
.30876 .6247 m .30661 .62579 L .30729 .62427 L F
.494 .816 1 r
.30729 .62427 m .30661 .62579 L .30491 .6248 L F
.694 .177 0 r
.60944 .42989 m .61106 .42914 L .60882 .42862 L F
.809 .986 .718 r
.61158 .42673 m .61106 .42914 L .60944 .42989 L F
0 .115 .666 r
.60732 .40843 m .60693 .40985 L .6089 .41199 L F
.511 .263 .474 r
.67073 .36892 m .67003 .3716 L .66756 .37198 L F
.916 .537 .281 r
.67158 .36518 m .67073 .36892 L .67153 .36553 L F
.67158 .36518 m .67365 .3685 L .67073 .36892 L F
.724 .556 .662 r
.67365 .3685 m .67003 .3716 L .67073 .36892 L F
.495 .135 .284 r
.27735 .62106 m .2817 .61779 L .27886 .61894 L F
.503 .392 .661 r
.37923 .71517 m .37958 .71824 L .38176 .7172 L F
.37923 .71517 m .37958 .71824 L .38176 .7172 L F
.35 .805 .941 r
.37742 .58855 m .37804 .58745 L .37688 .58664 L F
.37742 .58855 m .38022 .58814 L .37804 .58745 L F
.712 .306 .276 r
.55948 .44775 m .55773 .44962 L .55771 .4481 L F
.836 .48 .381 r
.55948 .44775 m .56159 .45074 L .55773 .44962 L F
0 .08 .632 r
.37057 .50908 m .36963 .5091 L .36925 .50854 L F
.37057 .50908 m .3718 .51104 L .36963 .5091 L F
.357 0 .061 r
.2815 .55194 m .2847 .55149 L .28652 .54872 L F
.781 .989 .749 r
.28652 .54872 m .28621 .54759 L .28865 .54625 L F
0 0 0 r
.28652 .54872 m .2847 .55149 L .28633 .55006 L F
.28652 .54872 m .28633 .55006 L .28621 .54759 L F
.297 .078 .403 r
.28865 .54625 m .28843 .54856 L .28652 .54872 L F
.408 .296 .614 r
.28843 .54856 m .28615 .55165 L .28652 .54872 L F
.418 .757 .995 r
.37689 .71239 m .37866 .71077 L .37628 .71139 L F
.37689 .71239 m .38046 .71217 L .37866 .71077 L F
.783 .725 .798 r
.62116 .39766 m .62384 .39755 L .62378 .39506 L F
.484 .466 .762 r
.62116 .39766 m .6236 .39958 L .62384 .39755 L F
.479 .33 .601 r
.62384 .39755 m .62596 .39366 L .62378 .39506 L F
.62384 .39755 m .62672 .39692 L .62596 .39366 L F
.775 .706 .786 r
.6236 .39958 m .62672 .39692 L .62384 .39755 L F
.779 .665 .737 r
.3369 .57114 m .34158 .57197 L .33964 .56813 L F
.106 .635 .873 r
.33906 .57152 m .33965 .57134 L .34158 .57197 L F
.437 .501 .827 r
.34081 .56884 m .34158 .57197 L .34403 .5708 L F
.33964 .56813 m .34008 .569 L .34081 .56884 L F
.34008 .569 m .34158 .57197 L .34081 .56884 L F
.33964 .56813 m .34403 .5708 L .34236 .56801 L F
.299 .014 .301 r
.34236 .56801 m .34213 .56857 L .34428 .56733 L F
.34213 .56857 m .34173 .5695 L .34306 .56837 L F
.34213 .56857 m .34306 .56837 L .34428 .56733 L F
.818 .939 .907 r
.34158 .57197 m .33965 .57134 L .34173 .5695 L F
.302 0 .17 r
.33793 .5734 m .34006 .57121 L .33965 .57134 L F
.34006 .57121 m .34173 .5695 L .33965 .57134 L F
.106 .635 .873 r
.3369 .57114 m .33965 .57134 L .33906 .57152 L F
.311 .066 .373 r
.34294 .57367 m .34158 .57197 L .34173 .5695 L F
.34294 .57367 m .34086 .5744 L .34158 .57197 L F
.719 .619 .744 r
.33041 .6605 m .32801 .66505 L .32713 .66419 L F
.049 .616 .745 r
.32801 .66505 m .33018 .66496 L .32795 .66568 L F
0 0 0 r
.33457 .5713 m .33256 .57552 L .3333 .57419 L F
.575 .592 .832 r
.35063 .63746 m .34973 .64165 L .34999 .6404 L F
.35063 .63746 m .35245 .64123 L .34973 .64165 L F
.549 .273 .449 r
.34947 .64386 m .34973 .64165 L .35167 .64416 L F
.509 .265 .481 r
.34973 .64165 m .35245 .64123 L .35167 .64416 L F
0 .022 .595 r
.34999 .6404 m .34973 .64165 L .35167 .64416 L F
.549 .273 .449 r
.34947 .64386 m .34973 .64165 L .35167 .64416 L F
.79 .365 0 r
.40002 .52437 m .40004 .52564 L .39831 .52353 L F
.40002 .52437 m .40138 .52709 L .40004 .52564 L F
.849 .8 .803 r
.65804 .34541 m .65893 .34914 L .65713 .35 L F
.771 .533 .575 r
.65893 .34914 m .65696 .35209 L .65713 .35 L F
.65893 .34914 m .65896 .3518 L .65696 .35209 L F
.909 .828 .754 r
.65948 .34667 m .65893 .34914 L .65804 .34541 L F
.708 .498 .601 r
.66313 .34955 m .65896 .3518 L .65893 .34914 L F
.63 .408 .562 r
.36318 .55899 m .36068 .55625 L .36315 .55564 L F
.36318 .55899 m .36052 .55957 L .36068 .55625 L F
.229 .728 .909 r
.5666 .42298 m .56213 .42267 L .56516 .424 L F
.696 .966 .937 r
.56786 .42089 m .5686 .42179 L .5666 .42298 L F
.699 .939 .639 r
.56786 .42089 m .5666 .42298 L .56516 .424 L F
.833 .866 .869 r
.72016 .33878 m .71655 .33954 L .71876 .33761 L F
.598 .753 .952 r
.7223 .33576 m .72016 .33878 L .71876 .33761 L F
.7223 .33576 m .72291 .33822 L .72016 .33878 L F
.5 .512 .801 r
.42658 .5026 m .42565 .50567 L .42464 .50387 L F
.42658 .5026 m .42827 .50556 L .42565 .50567 L F
.79 .992 .88 r
.3931 .50902 m .39149 .51162 L .39175 .50986 L F
1 .824 .51 r
.39149 .51162 m .39003 .51272 L .39175 .50986 L F
.39149 .51162 m .39109 .51395 L .39003 .51272 L F
.366 .006 .214 r
.31961 .52925 m .32068 .52998 L .32213 .52721 L F
.645 .685 .873 r
.32472 .52745 m .32213 .52721 L .32337 .52628 L F
.365 .005 .214 r
.32213 .52721 m .32299 .52895 L .32337 .52628 L F
.894 .639 .546 r
.38988 .58429 m .39307 .58444 L .39235 .58193 L F
.356 .478 .846 r
.39217 .58042 m .39235 .58193 L .39383 .5802 L F
.434 .374 .691 r
.39235 .58193 m .39464 .58312 L .39383 .5802 L F
.39235 .58193 m .39307 .58444 L .39464 .58312 L F
.056 .183 .681 r
.70385 .34448 m .70482 .3484 L .70294 .34622 L F
.189 .665 .933 r
.21834 .59092 m .22057 .59102 L .22284 .592 L F
0 .23 .736 r
.22347 .59155 m .22284 .592 L .22057 .59102 L F
.22347 .59155 m .22482 .59331 L .22284 .592 L F
.161 0 0 r
.28042 .555 m .27725 .55535 L .27807 .55505 L F
0 0 0 r
.27548 .52819 m .27353 .52906 L .27143 .52989 L F
.637 .955 .768 r
.27569 .52713 m .27548 .52819 L .27778 .52721 L F
.27569 .52713 m .27353 .52906 L .27548 .52819 L F
.789 .458 .428 r
.37751 .6036 m .3767 .60656 L .37428 .60455 L F
0 0 .11 r
.37854 .60468 m .37751 .6036 L .37824 .60241 L F
.816 .936 .909 r
.3211 .66922 m .32273 .66991 L .32536 .66741 L F
.227 0 0 r
.4269 .53164 m .42692 .53245 L .42451 .53286 L F
.42451 .53286 m .42692 .53245 L .4269 .53164 L F
0 .355 .824 r
.4269 .53164 m .43001 .53285 L .42831 .53108 L F
.394 0 0 r
.42692 .53245 m .43001 .53285 L .4269 .53164 L F
0 .355 .824 r
.4269 .53164 m .42831 .53108 L .42692 .53245 L F
.581 .114 .11 r
.58607 .43534 m .5877 .43443 L .58847 .43486 L F
.697 .502 .62 r
.58872 .43524 m .5912 .43307 L .59099 .43215 L F
.583 .468 .688 r
.58646 .43897 m .58914 .4385 L .58872 .43524 L F
.661 .524 .687 r
.58872 .43524 m .59249 .43728 L .5912 .43307 L F
.58872 .43524 m .58914 .4385 L .59249 .43728 L F
.581 .114 .11 r
.5878 .43551 m .58847 .43486 L .59006 .43573 L F
.58607 .43534 m .58847 .43486 L .5878 .43551 L F
.773 .943 .603 r
.58909 .43426 m .59099 .43215 L .58938 .43351 L F
.58872 .43524 m .5903 .43309 L .58909 .43426 L F
.5903 .43309 m .59099 .43215 L .58909 .43426 L F
.654 .415 .545 r
.59469 .43429 m .59099 .43215 L .5912 .43307 L F
.59469 .43429 m .59586 .43204 L .59099 .43215 L F
.946 .874 .733 r
.29758 .65398 m .29639 .65805 L .29552 .65703 L F
.968 .657 .27 r
.29552 .65703 m .29639 .65805 L .29636 .65997 L F
.532 .431 .686 r
.3716 .54625 m .37171 .54899 L .36928 .54959 L F
.829 .625 .627 r
.38046 .59608 m .38553 .59731 L .38356 .5951 L F
.976 .7 .298 r
.3807 .59713 m .38046 .59608 L .38215 .59453 L F
.367 .309 .66 r
.38046 .59608 m .38095 .59894 L .37863 .59697 L F
.976 .7 .298 r
.38004 .59833 m .38095 .59894 L .38046 .59608 L F
.38004 .59833 m .38024 .59726 L .3807 .59713 L F
.38024 .59726 m .38046 .59608 L .3807 .59713 L F
0 .249 .758 r
.37895 .59761 m .38095 .59894 L .38037 .60037 L F
.37863 .59697 m .37927 .59752 L .37895 .59761 L F
.37927 .59752 m .38095 .59894 L .37895 .59761 L F
.474 .219 .447 r
.38095 .59894 m .37824 .60241 L .38037 .60037 L F
.904 .508 .092 r
.4189 .58658 m .42029 .58777 L .42096 .59004 L F
.893 .519 .057 r
.41347 .5585 m .41534 .56203 L .41411 .56056 L F
.938 .567 .233 r
.41603 .5639 m .41411 .56056 L .41534 .56203 L F
.972 .745 .537 r
.35648 .68178 m .358 .6797 L .35642 .67859 L F
.487 .783 .997 r
.35642 .67859 m .358 .6797 L .35914 .67811 L F
.701 .624 .768 r
.35648 .68178 m .35914 .67811 L .358 .6797 L F
.484 .466 .762 r
.62116 .39766 m .62158 .40097 L .6236 .39958 L F
.622 .948 .94 r
.6236 .39958 m .62158 .40097 L .61951 .40144 L F
.942 .626 .408 r
.70697 .36124 m .70885 .36219 L .70729 .36372 L F
.841 .445 .296 r
.70729 .36372 m .70885 .36219 L .70952 .36418 L F
.64 .168 0 r
.38797 .61478 m .38655 .61262 L .38634 .61271 L F
.38797 .61478 m .38955 .61671 L .38655 .61262 L F
.432 .669 .961 r
.23402 .56637 m .22956 .5669 L .22855 .56456 L F
.127 0 .13 r
.42275 .53459 m .42143 .53331 L .42451 .53286 L F
.42275 .53459 m .42087 .53555 L .42143 .53331 L F
.516 .073 .136 r
.357 .60818 m .35838 .60654 L .35561 .6071 L F
.649 .227 .228 r
.36116 .60914 m .35838 .60654 L .357 .60818 L F
.537 .541 .807 r
.36222 .60965 m .35838 .60654 L .36116 .60914 L F
.059 0 0 r
.24165 .55594 m .24202 .55672 L .24393 .55536 L F
.24165 .55594 m .23933 .55779 L .24202 .55672 L F
.222 0 .304 r
.30872 .60642 m .30781 .60921 L .30594 .60994 L F
.248 .087 .457 r
.30781 .60921 m .30603 .61258 L .30594 .60994 L F
.813 .745 .789 r
.70165 .33538 m .70619 .33434 L .70459 .33243 L F
.70165 .33538 m .70349 .33719 L .70619 .33434 L F
.834 .845 .854 r
.70459 .33243 m .70619 .33434 L .70735 .33199 L F
.512 .312 .545 r
.36865 .57038 m .36475 .57229 L .36726 .56913 L F
.527 .48 .747 r
.36855 .56492 m .36925 .57018 L .36726 .56913 L F
0 .084 .643 r
.31877 .65429 m .32247 .65699 L .32191 .65468 L F
0 0 .352 r
.3391 .54163 m .33719 .54511 L .339 .54312 L F
.83 .797 .82 r
.64697 .41796 m .64599 .42285 L .64444 .42129 L F
.64697 .41796 m .64858 .41995 L .64599 .42285 L F
.919 .551 .121 r
.59219 .41308 m .59302 .41579 L .59159 .41385 L F
.826 .424 0 r
.38939 .52907 m .38795 .52526 L .38864 .52745 L F
.38939 .52907 m .39098 .53146 L .38795 .52526 L F
.684 .547 .693 r
.3325 .51785 m .33673 .51798 L .33531 .51446 L F
.397 .235 .542 r
.3325 .51785 m .33256 .52053 L .33466 .51971 L F
.144 0 .244 r
.35776 .57747 m .35536 .58069 L .35606 .57846 L F
.647 .11 0 r
.58224 .43779 m .58508 .4398 L .58646 .43897 L F
.065 0 0 r
.58646 .43897 m .58853 .43899 L .58914 .4385 L F
.369 .795 .606 r
.58646 .43897 m .58733 .43844 L .58853 .43899 L F
.58646 .43897 m .58508 .4398 L .58733 .43844 L F
.907 .621 .49 r
.35784 .6161 m .35608 .61538 L .35309 .61567 L F
.35784 .6161 m .35593 .61765 L .35608 .61538 L F
.63 .195 .196 r
.35593 .61765 m .35784 .6161 L .35608 .61538 L F
.35593 .61765 m .35876 .61817 L .35784 .6161 L F
.797 .486 .462 r
.70911 .29402 m .71249 .29248 L .70986 .2917 L F
.70911 .29402 m .71311 .295 L .71249 .29248 L F
.68 .818 .949 r
.64517 .37902 m .64653 .38119 L .64531 .37981 L F
.64517 .37902 m .64918 .38059 L .64653 .38119 L F
.662 .867 .484 r
.65882 .41047 m .6618 .40602 L .66099 .40826 L F
0 0 .219 r
.65935 .41156 m .65882 .41047 L .66099 .40826 L F
.635 .791 .345 r
.36632 .65304 m .36767 .65058 L .3662 .64983 L F
.36632 .65304 m .3656 .65445 L .36767 .65058 L F
.68 .934 .968 r
.3662 .64983 m .36767 .65058 L .37061 .64854 L F
.373 0 0 r
.24686 .61389 m .25042 .61508 L .24857 .61507 L F
.294 .178 .546 r
.2024 .57169 m .20405 .57096 L .20392 .56824 L F
.163 .01 .413 r
.20226 .57441 m .20405 .57096 L .2024 .57169 L F
.343 .286 .649 r
.36833 .63275 m .36827 .63445 L .37039 .63464 L F
.36833 .63275 m .36827 .63445 L .37039 .63464 L F
.838 .924 .89 r
.60836 .38986 m .60642 .39403 L .60487 .39242 L F
.828 .976 .887 r
.36169 .5989 m .36584 .59722 L .36587 .59671 L F
.153 .622 .928 r
.39567 .65392 m .39929 .65476 L .39633 .65309 L F
0 0 .546 r
.39633 .65309 m .39567 .65392 L .39684 .65567 L F
.722 .8 .913 r
.39544 .65334 m .39613 .65327 L .39612 .65466 L F
0 0 0 r
.39633 .65309 m .39687 .65151 L .39836 .64961 L F
.639 .458 .622 r
.39836 .64961 m .39898 .65215 L .39633 .65309 L F
.716 .805 .92 r
.39633 .65309 m .39898 .65215 L .39467 .65186 L F
.722 .8 .913 r
.39613 .65196 m .39618 .65224 L .39612 .65466 L F
0 0 .546 r
.39633 .65309 m .39616 .65327 L .39612 .65466 L F
.39633 .65309 m .39638 .65325 L .39616 .65327 L F
.681 .876 .972 r
.4003 .65325 m .39929 .65476 L .39633 .65309 L F
.4003 .65325 m .39633 .65309 L .39898 .65215 L F
.717 .788 .908 r
.39633 .65309 m .39898 .65215 L .39657 .65427 L F
0 0 .546 r
.39633 .65309 m .39684 .65567 L .39638 .65325 L F
.717 .788 .908 r
.39633 .65309 m .39657 .65427 L .39612 .65466 L F
0 0 .546 r
.39638 .65325 m .39657 .65427 L .39714 .65612 L F
.39657 .65427 m .39684 .65567 L .39686 .6557 L F
.39657 .65427 m .39686 .6557 L .39714 .65612 L F
.722 .8 .913 r
.39616 .65327 m .39657 .65427 L .39612 .65466 L F
.39618 .65224 m .39638 .65325 L .39616 .65327 L F
.39638 .65325 m .39657 .65427 L .39616 .65327 L F
0 0 .546 r
.39616 .65327 m .39362 .65588 L .39612 .65466 L F
.39616 .65327 m .39714 .65612 L .39362 .65588 L F
.39638 .65325 m .39714 .65612 L .39616 .65327 L F
.722 .8 .913 r
.39467 .65186 m .39613 .65196 L .39613 .65327 L F
.39467 .65186 m .39613 .65327 L .39544 .65334 L F
.39613 .65196 m .39898 .65215 L .39657 .65427 L F
0 0 .44 r
.61039 .41565 m .61142 .41943 L .61134 .41803 L F
.773 .637 .076 r
.61134 .41803 m .61142 .41943 L .61134 .42152 L F
.737 .445 .485 r
.35055 .5756 m .35387 .5742 L .3517 .5749 L F
.594 .113 .082 r
.37201 .56335 m .37486 .56477 L .37047 .5644 L F
.425 .439 .771 r
.4249 .55464 m .42397 .5589 L .42554 .55568 L F
.378 .145 .43 r
.29272 .63875 m .29039 .64201 L .29193 .6407 L F
.405 .002 .159 r
.29433 .63999 m .29272 .63875 L .29193 .6407 L F
.29433 .63999 m .29519 .6385 L .29272 .63875 L F
.624 .955 .797 r
.57528 .42463 m .57959 .42215 L .57862 .42384 L F
.737 .25 .086 r
.57959 .42215 m .58183 .42414 L .57862 .42384 L F
.263 0 0 r
.34127 .67453 m .34298 .67277 L .33985 .67398 L F
.196 0 0 r
.34593 .67154 m .34298 .67277 L .3446 .67226 L F
0 0 0 r
.3446 .67226 m .34298 .67277 L .34127 .67453 L F
.672 .597 .763 r
.65838 .39254 m .65579 .39376 L .65468 .38979 L F
.395 .697 .981 r
.26739 .6341 m .26892 .6355 L .2695 .63392 L F
.942 .624 .404 r
.41107 .50215 m .41007 .50367 L .41 .50082 L F
.41107 .50215 m .41101 .50434 L .41007 .50367 L F
.381 .154 .44 r
.34846 .5301 m .35065 .52959 L .35073 .52731 L F
.34846 .5301 m .35065 .52959 L .35073 .52731 L F
.462 .276 .541 r
.27642 .62756 m .27622 .63116 L .27412 .6289 L F
.871 .544 .032 r
.41745 .57762 m .41882 .58126 L .41804 .58012 L F
.951 .782 .328 r
.41882 .58126 m .41799 .5827 L .41804 .58012 L F
.41882 .58126 m .41852 .58399 L .41799 .5827 L F
.651 .965 .911 r
.35505 .65194 m .35086 .65339 L .35276 .65267 L F
.534 .782 .989 r
.35578 .64983 m .35505 .65194 L .35276 .65267 L F
.35578 .64983 m .35777 .65149 L .35505 .65194 L F
.383 .48 .835 r
.31455 .64805 m .31736 .64902 L .3165 .64651 L F
0 0 .4 r
.3537 .6006 m .35504 .60176 L .35564 .59926 L F
.3537 .6006 m .35393 .60293 L .35504 .60176 L F
0 0 0 r
.33219 .59651 m .33008 .60019 L .33187 .59915 L F
.41 .279 .591 r
.32978 .60274 m .33187 .59915 L .33008 .60019 L F
.562 .91 .696 r
.24579 .52849 m .24567 .52806 L .2481 .52776 L F
.24579 .52849 m .24385 .52963 L .24567 .52806 L F
0 .084 .643 r
.31877 .65429 m .32072 .65599 L .32247 .65699 L F
.361 .318 .675 r
.33531 .51446 m .33692 .51501 L .3369 .51029 L F
.979 .71 .45 r
.37871 .58165 m .38021 .58437 L .37866 .58079 L F
.692 .298 .295 r
.37748 .58687 m .38021 .58437 L .37871 .58165 L F
.37748 .58687 m .38259 .58679 L .38021 .58437 L F
.168 0 .14 r
.23707 .56576 m .23804 .56731 L .23948 .56549 L F
.23707 .56576 m .23578 .56871 L .23804 .56731 L F
.585 .581 .815 r
.3688 .52283 m .37056 .52753 L .36766 .52732 L F
.985 .746 .493 r
.36591 .5286 m .36756 .52998 L .36766 .52732 L F
.36872 .52796 m .36766 .52732 L .37056 .52753 L F
.195 .073 .476 r
.36911 .52819 m .36756 .52998 L .36766 .52732 L F
.3693 .5283 m .36847 .5291 L .36911 .52819 L F
.36847 .5291 m .36756 .52998 L .36911 .52819 L F
.36958 .52804 m .36872 .52796 L .36911 .52787 L F
.985 .746 .493 r
.36872 .52796 m .36937 .52781 L .36829 .52806 L F
.195 .073 .476 r
.36911 .52787 m .36872 .52796 L .36766 .52732 L F
.985 .746 .493 r
.36872 .52796 m .37056 .52753 L .36911 .52787 L F
.324 0 0 r
.36766 .52732 m .36911 .52787 L .37056 .52753 L F
.36911 .52787 m .36958 .52804 L .37056 .52753 L F
.985 .746 .493 r
.36911 .52787 m .37056 .52753 L .36937 .52781 L F
0 .15 .682 r
.37097 .52525 m .37056 .52753 L .3688 .52283 L F
.826 .999 .829 r
.37097 .52525 m .36829 .52806 L .36937 .52781 L F
.3709 .52562 m .36937 .52781 L .37056 .52753 L F
.37097 .52525 m .36937 .52781 L .3709 .52562 L F
.985 .746 .493 r
.36591 .5286 m .36872 .52796 L .36829 .52806 L F
.195 .073 .476 r
.36958 .52804 m .3693 .5283 L .36872 .52796 L F
.985 .746 .493 r
.36591 .5286 m .36766 .52732 L .36872 .52796 L F
.332 .173 .509 r
.37876 .57811 m .37866 .58079 L .38034 .57959 L F
.38034 .57959 m .37866 .58079 L .37876 .57811 L F
.813 .682 .72 r
.32911 .58115 m .32514 .58322 L .32759 .5813 L F
.32911 .58115 m .32671 .58415 L .32514 .58322 L F
.637 .425 .579 r
.32911 .58115 m .32967 .58428 L .32671 .58415 L F
.668 .973 .825 r
.32911 .58115 m .32759 .5813 L .33008 .57938 L F
.538 .48 .739 r
.29711 .55281 m .29785 .5559 L .3002 .55529 L F
.617 .595 .805 r
.64036 .39999 m .64314 .39671 L .63901 .39599 L F
.64036 .39999 m .64249 .39966 L .64314 .39671 L F
.617 .587 .797 r
.64036 .39999 m .64478 .40057 L .64249 .39966 L F
0 0 .142 r
.24463 .5399 m .24387 .5422 L .2427 .5429 L F
.298 .774 .667 r
.34658 .6712 m .34593 .67154 L .3446 .67226 L F
.34658 .6712 m .34879 .67029 L .34593 .67154 L F
.699 .793 .923 r
.5807 .41552 m .58464 .41603 L .58184 .41682 L F
.497 .484 .773 r
.58524 .41875 m .58184 .41682 L .58464 .41603 L F
.4 .286 .608 r
.26232 .55163 m .26007 .54951 L .26236 .5489 L F
.26232 .55163 m .26039 .55262 L .26007 .54951 L F
.81 1 .815 r
.25143 .53526 m .25096 .5372 L .25376 .53416 L F
.744 .97 .93 r
.25143 .53526 m .24952 .53682 L .25096 .5372 L F
.752 .891 .941 r
.32719 .52584 m .32472 .52745 L .32337 .52628 L F
.99 .799 .553 r
.32337 .52628 m .32299 .52895 L .32472 .52745 L F
.502 .327 .576 r
.33111 .70824 m .33351 .70776 L .3329 .70522 L F
.929 .919 .783 r
.69698 .31872 m .69817 .32028 L .69922 .31816 L F
.952 .911 .74 r
.69634 .32362 m .69817 .32028 L .69698 .31872 L F
0 0 0 r
.61577 .38062 m .61349 .38286 L .6158 .38033 L F
.464 .879 .749 r
.6158 .38033 m .61577 .38062 L .61798 .37905 L F
.61798 .37905 m .61577 .38062 L .6158 .38033 L F
.6158 .38033 m .61577 .38062 L .61798 .37905 L F
.814 .796 .836 r
.71159 .28266 m .71004 .28347 L .71078 .28363 L F
0 .203 .729 r
.71184 .28386 m .71078 .28363 L .70929 .28293 L F
.7122 .28399 m .71078 .28363 L .71184 .28386 L F
.814 .796 .836 r
.71004 .28347 m .70811 .28446 L .71078 .28363 L F
.991 .881 .605 r
.31143 .51331 m .311 .51672 L .31205 .51534 L F
.888 .906 .834 r
.38733 .65341 m .39144 .65081 L .38994 .65342 L F
.768 .698 .785 r
.39393 .64794 m .39144 .65081 L .39011 .64761 L F
.574 .146 .19 r
.38994 .65342 m .39144 .65081 L .39433 .65314 L F
.968 .849 .671 r
.58224 .43779 m .58351 .43569 L .58443 .4353 L F
0 0 0 r
.33421 .70127 m .3329 .70522 L .3347 .70365 L F
.465 .304 .577 r
.3329 .70522 m .33564 .70765 L .3347 .70365 L F
.3329 .70522 m .33351 .70776 L .33564 .70765 L F
.675 .692 .858 r
.66266 .39356 m .65838 .39254 L .66108 .38972 L F
.419 .323 .64 r
.66498 .39138 m .66266 .39356 L .66108 .38972 L F
.66498 .39138 m .66492 .3929 L .66266 .39356 L F
.296 .209 .585 r
.66501 .3956 m .66266 .39356 L .66492 .3929 L F
.66501 .3956 m .66309 .39577 L .66266 .39356 L F
.927 .656 .175 r
.4171 .57465 m .4167 .5764 L .41688 .57387 L F
.4171 .57465 m .41745 .57762 L .4167 .5764 L F
0 0 .106 r
.42087 .53555 m .41866 .53888 L .41901 .53688 L F
.477 .868 .676 r
.35499 .6667 m .35114 .6691 L .35366 .66956 L F
.34 .091 .383 r
.35722 .66605 m .35784 .66358 L .35499 .6667 L F
.213 0 .089 r
.35722 .66605 m .35499 .6667 L .35366 .66956 L F
.793 .358 0 r
.3208 .66337 m .32148 .66372 L .31908 .66027 L F
0 .156 .697 r
.32043 .66144 m .3208 .66337 L .32042 .66141 L F
.745 .341 .286 r
.31984 .66597 m .32357 .66573 L .32148 .66372 L F
0 .156 .697 r
.32253 .66498 m .3208 .66337 L .32043 .66144 L F
.745 .341 .286 r
.31984 .66597 m .32099 .66439 L .3208 .66337 L F
.32099 .66439 m .32148 .66372 L .3208 .66337 L F
.708 .498 .601 r
.66313 .34955 m .66313 .35228 L .65896 .3518 L F
.701 .832 .946 r
.30793 .51213 m .30513 .51372 L .3037 .5124 L F
.513 .277 .494 r
.36011 .64855 m .36078 .64571 L .35759 .64791 L F
.951 .745 .589 r
.35759 .64791 m .36073 .6508 L .36011 .64855 L F
.847 .806 .811 r
.34731 .52332 m .34466 .52246 L .34731 .51997 L F
.34731 .52332 m .34661 .52377 L .34466 .52246 L F
.482 .601 .895 r
.34964 .51918 m .34731 .52332 L .34731 .51997 L F
.34964 .51918 m .35156 .52264 L .34731 .52332 L F
.451 .883 .858 r
.25167 .52679 m .25262 .5259 L .25352 .52592 L F
.441 .877 .88 r
.25167 .52679 m .25033 .52681 L .25262 .5259 L F
.614 .27 .364 r
.37039 .63464 m .37034 .63252 L .36833 .63275 L F
.576 .401 .607 r
.31519 .56135 m .31893 .55909 L .31703 .5597 L F
.31519 .56135 m .3188 .56186 L .31893 .55909 L F
.544 .405 .642 r
.31519 .56135 m .31835 .56446 L .3188 .56186 L F
.31519 .56135 m .31584 .56503 L .31835 .56446 L F
.795 .696 .755 r
.7029 .30749 m .70668 .30826 L .7054 .30437 L F
.468 .372 .663 r
.7029 .30749 m .70597 .30944 L .70668 .30826 L F
0 0 0 r
.70668 .30826 m .71033 .3037 L .7054 .30437 L F
.70668 .30826 m .70828 .30644 L .70825 .30629 L F
.889 .881 .82 r
.70828 .30644 m .70449 .30788 L .70795 .30626 L F
.189 0 0 r
.70831 .3066 m .70828 .30644 L .70795 .30626 L F
.70915 .30739 m .70828 .30644 L .70831 .3066 L F
0 0 0 r
.70825 .30629 m .70828 .30644 L .71033 .3037 L F
.70668 .30826 m .70597 .30944 L .70828 .30644 L F
.117 .631 .892 r
.33633 .50446 m .33443 .50371 L .33221 .50352 L F
0 .025 .566 r
.33633 .50446 m .33734 .50747 L .33443 .50371 L F
.33633 .50446 m .33805 .50737 L .33734 .50747 L F
.161 0 0 r
.3671 .67671 m .3677 .67721 L .36646 .67714 L F
.3671 .67671 m .36949 .67668 L .3677 .67721 L F
.371 .122 .401 r
.31077 .60553 m .30781 .60921 L .30872 .60642 L F
.532 .794 .993 r
.28085 .64483 m .28191 .64298 L .27948 .64103 L F
.728 .835 .931 r
.61714 .39182 m .6156 .39498 L .61559 .3927 L F
0 0 .361 r
.30356 .63998 m .30232 .63848 L .30368 .63707 L F
0 0 0 r
.3042 .63963 m .30356 .63998 L .3051 .639 L F
0 0 .361 r
.30356 .63998 m .30226 .64113 L .30227 .64067 L F
.574 .892 .623 r
.30061 .64265 m .30356 .63998 L .30154 .64149 L F
0 0 0 r
.30154 .64149 m .30356 .63998 L .3042 .63963 L F
0 0 .361 r
.30356 .63998 m .30227 .64067 L .30232 .63848 L F
.677 .602 .764 r
.30281 .51976 m .30378 .52387 L .30621 .52087 L F
.911 .562 .1 r
.41646 .56851 m .41582 .56974 L .41583 .56733 L F
.41646 .56851 m .41715 .57116 L .41582 .56974 L F
.702 .701 .846 r
.62328 .37891 m .61921 .37793 L .62171 .37691 L F
.718 .694 .827 r
.62171 .37691 m .62573 .37765 L .62328 .37891 L F
.807 .999 .798 r
.32232 .68401 m .32525 .68256 L .32215 .6857 L F
.802 .586 .609 r
.37039 .63464 m .37422 .63209 L .37034 .63252 L F
0 .504 .788 r
.3555 .50304 m .35808 .50355 L .3599 .50416 L F
.652 .559 .737 r
.5834 .4282 m .58092 .43146 L .58113 .42916 L F
.5834 .4282 m .58365 .43247 L .58092 .43146 L F
.637 .337 .446 r
.58365 .43247 m .58443 .4353 L .58092 .43146 L F
.424 0 .115 r
.36234 .57537 m .36074 .57731 L .35776 .57747 L F
0 0 0 r
.36237 .57592 m .36074 .57731 L .36234 .57537 L F
.539 .322 .534 r
.43651 .58441 m .43625 .58724 L .43353 .58765 L F
.086 0 .198 r
.4389 .58128 m .43827 .58356 L .43651 .58441 L F
.462 .257 .515 r
.43861 .58654 m .43651 .58441 L .43827 .58356 L F
.43861 .58654 m .43625 .58724 L .43651 .58441 L F
.974 .727 .5 r
.70178 .33833 m .70349 .33719 L .70165 .33538 L F
.70178 .33833 m .70339 .33948 L .70349 .33719 L F
.523 .297 .514 r
.3914 .59623 m .39013 .59458 L .39211 .59407 L F
.557 .307 .493 r
.39474 .59381 m .3914 .59623 L .39211 .59407 L F
.699 .962 .943 r
.29588 .51752 m .29134 .51888 L .2946 .51723 L F
.612 .95 .922 r
.29666 .51608 m .29847 .51619 L .29588 .51752 L F
.595 .937 .943 r
.29666 .51608 m .29588 .51752 L .2946 .51723 L F
.42 .279 .581 r
.30587 .59652 m .30754 .59323 L .30605 .59393 L F
.543 .514 .773 r
.19964 .60658 m .20195 .60501 L .19856 .60312 L F
.614 .146 0 r
.33107 .69724 m .33231 .69866 L .33421 .70127 L F
.96 .943 .653 r
.25124 .57171 m .24739 .57241 L .24708 .57206 L F
.25124 .57171 m .24907 .57295 L .24739 .57241 L F
.25124 .57171 m .2496 .57477 L .24907 .57295 L F
.787 .59 .634 r
.25124 .57171 m .25185 .57541 L .2496 .57477 L F
.613 .462 .653 r
.25385 .56825 m .25468 .57138 L .25124 .57171 L F
.53 .414 .666 r
.25418 .57418 m .25124 .57171 L .25468 .57138 L F
.25418 .57418 m .25185 .57541 L .25124 .57171 L F
.785 .872 .912 r
.39021 .63503 m .39015 .63685 L .39102 .63515 L F
.907 .979 .706 r
.39129 .63298 m .39021 .63503 L .39102 .63515 L F
.744 .717 .827 r
.29565 .64346 m .29811 .6468 L .30024 .64451 L F
.508 .34 .589 r
.25284 .57766 m .25287 .58049 L .25038 .58107 L F
.589 .495 .716 r
.25328 .58374 m .25038 .58107 L .25287 .58049 L F
.25328 .58374 m .25119 .58432 L .25038 .58107 L F
.442 .177 .415 r
.35065 .52959 m .35329 .52585 L .35073 .52731 L F
.545 .519 .777 r
.35147 .52568 m .35065 .52959 L .35073 .52731 L F
.236 0 0 r
.24708 .57206 m .24415 .57297 L .24515 .57248 L F
0 0 0 r
.66414 .40047 m .66327 .40208 L .66201 .40353 L F
0 0 .109 r
.66201 .40353 m .66323 .40409 L .6618 .40602 L F
.66201 .40353 m .66327 .40208 L .66323 .40409 L F
.513 .181 .342 r
.58247 .45102 m .58515 .45249 L .58227 .45303 L F
.53 .154 .272 r
.58525 .45095 m .58515 .45249 L .58247 .45102 L F
.65 .65 .836 r
.31735 .64862 m .31814 .64911 L .31778 .64965 L F
.31665 .64655 m .31736 .64902 L .32003 .64737 L F
.3165 .64651 m .31664 .64692 L .31665 .64655 L F
.31664 .64692 m .31736 .64902 L .31665 .64655 L F
.3165 .64651 m .31773 .64846 L .31735 .64862 L F
.31773 .64846 m .31814 .64911 L .31735 .64862 L F
.872 .925 .858 r
.31736 .64902 m .32019 .64769 L .32006 .64743 L F
.31736 .64902 m .32006 .64743 L .31959 .64764 L F
.117 0 0 r
.31808 .64399 m .31587 .64375 L .3165 .64651 L F
.31808 .64399 m .3165 .64651 L .31617 .64427 L F
.872 .925 .858 r
.31959 .64764 m .32006 .64743 L .32003 .64737 L F
.65 .65 .836 r
.3165 .64651 m .32003 .64737 L .31814 .64911 L F
0 0 .481 r
.31671 .64489 m .31778 .64965 L .31866 .64711 L F
.31617 .64427 m .31667 .64595 L .31671 .64489 L F
.31667 .64595 m .31778 .64965 L .31671 .64489 L F
.773 .575 .005 r
.32003 .64737 m .32019 .64769 L .31978 .64404 L F
.131 0 0 r
.23158 .55647 m .23293 .55689 L .23369 .55636 L F
.23158 .55647 m .22958 .55766 L .23293 .55689 L F
0 0 .163 r
.41347 .5585 m .4127 .55448 L .41289 .55599 L F
.906 .901 .81 r
.40511 .50204 m .40599 .49747 L .40596 .49998 L F
.40511 .50204 m .40327 .50088 L .40599 .49747 L F
.556 .366 .578 r
.40596 .49998 m .40327 .50088 L .40511 .50204 L F
.802 .586 .609 r
.37039 .63464 m .37406 .63465 L .37422 .63209 L F
.629 .379 .521 r
.37639 .63355 m .37422 .63209 L .37406 .63465 L F
.37639 .63355 m .37662 .63203 L .37422 .63209 L F
0 0 .288 r
.601 .42821 m .60118 .43116 L .60315 .43056 L F
0 0 0 r
.60315 .43056 m .60118 .43116 L .59912 .43263 L F
.164 .161 .608 r
.20098 .58115 m .20274 .5832 L .20216 .58055 L F
.239 .177 .582 r
.20133 .58395 m .20274 .5832 L .20098 .58115 L F
.847 .598 .562 r
.42443 .59074 m .4211 .59272 L .42096 .59004 L F
.42443 .59074 m .42449 .59352 L .4211 .59272 L F
.156 .06 .485 r
.42615 .59218 m .42443 .59074 L .42633 .59001 L F
.42615 .59218 m .42449 .59352 L .42443 .59074 L F
.998 .807 .456 r
.59765 .39567 m .59871 .39675 L .59805 .39877 L F
.346 .794 .645 r
.34318 .55322 m .34321 .55327 L .34539 .55336 L F
.34318 .55322 m .34147 .55413 L .34321 .55327 L F
.608 .204 .25 r
.59414 .44985 m .59158 .44987 L .59167 .44809 L F
.531 .266 .458 r
.59439 .44757 m .59414 .44985 L .59167 .44809 L F
.736 .813 .912 r
.65196 .37771 m .64918 .38059 L .64517 .37902 L F
.508 .308 .544 r
.24034 .58154 m .24276 .5811 L .24308 .57714 L F
.593 .38 .562 r
.24308 .57714 m .24554 .58051 L .24573 .57751 L F
.24308 .57714 m .24276 .5811 L .24554 .58051 L F
.841 .937 .565 r
.38737 .6483 m .38782 .64677 L .39011 .64761 L F
.38737 .6483 m .38593 .64987 L .38782 .64677 L F
.587 .417 .618 r
.59249 .43728 m .59469 .43429 L .5912 .43307 L F
.198 0 .011 r
.36587 .66273 m .36442 .662 L .3637 .66259 L F
.881 .788 .754 r
.67158 .36518 m .67153 .36553 L .66898 .36396 L F
.418 .281 .587 r
.63673 .38167 m .63449 .3833 L .63458 .38518 L F
.81 .585 .597 r
.33376 .5343 m .33252 .53597 L .32882 .53514 L F
0 0 0 r
.71767 .29825 m .71648 .29893 L .7143 .30014 L F
.318 .111 .433 r
.72008 .29517 m .72031 .29729 L .71767 .29825 L F
0 0 0 r
.71767 .29825 m .72031 .29729 L .71648 .29893 L F
.684 .566 .716 r
.27695 .53704 m .28068 .5374 L .27992 .53338 L F
.67 .359 .438 r
.27695 .53704 m .27663 .53821 L .28068 .5374 L F
.415 .767 .995 r
.37205 .69416 m .37384 .69533 L .37123 .69549 L F
.37123 .69549 m .37384 .69533 L .37205 .69416 L F
.737 .53 .613 r
.26429 .56541 m .26003 .56791 L .26057 .56522 L F
.726 .784 .295 r
.31454 .50834 m .31473 .5074 L .31499 .50691 L F
.599 .675 .893 r
.31518 .50633 m .31718 .50833 L .31454 .50834 L F
.603 .321 .461 r
.31718 .50833 m .31638 .51042 L .31454 .50834 L F
0 .089 .646 r
.31454 .50834 m .31638 .51042 L .31473 .5074 L F
.46 .625 .923 r
.31786 .50687 m .31718 .50833 L .31518 .50633 L F
0 0 0 r
.31786 .50687 m .31638 .51042 L .31718 .50833 L F
.79 .73 .797 r
.31473 .5074 m .31638 .51042 L .31786 .50687 L F
.04 0 0 r
.31473 .5074 m .31566 .50778 L .31432 .50816 L F
.31473 .5074 m .31432 .50816 L .31322 .50847 L F
.726 .784 .295 r
.31499 .50691 m .31473 .5074 L .31518 .50633 L F
.482 .31 .571 r
.31454 .50834 m .31638 .51042 L .31406 .51108 L F
.702 .168 0 r
.23753 .60928 m .24005 .61116 L .23886 .61096 L F
.035 0 0 r
.3385 .67555 m .33985 .67398 L .33657 .67585 L F
.27 0 0 r
.34127 .67453 m .33985 .67398 L .3385 .67555 L F
.702 .365 .403 r
.66756 .37198 m .66739 .37388 L .66475 .37159 L F
.348 .008 .239 r
.67003 .3716 m .66739 .37388 L .66756 .37198 L F
.641 .9 .984 r
.71895 .34946 m .7216 .34832 L .72019 .34713 L F
.72019 .34713 m .7216 .34832 L .71895 .34946 L F
.71895 .34946 m .7216 .34832 L .72019 .34713 L F
.944 .928 .758 r
.32215 .6857 m .31981 .68817 L .32159 .68567 L F
.807 .999 .798 r
.32232 .68401 m .32215 .6857 L .32159 .68567 L F
.508 .44 .715 r
.29317 .53313 m .29692 .53543 L .29473 .53244 L F
.29317 .53313 m .29402 .53706 L .29692 .53543 L F
.894 .987 .783 r
.62596 .39366 m .62757 .39153 L .62662 .39203 L F
.633 .468 .641 r
.62596 .39366 m .62943 .39382 L .62852 .39026 L F
.797 .982 .899 r
.62378 .39506 m .62596 .39366 L .62523 .39273 L F
.894 .987 .783 r
.62596 .39366 m .62762 .38956 L .62523 .39273 L F
.797 .982 .899 r
.62378 .39506 m .62523 .39273 L .62322 .39523 L F
.768 .997 .833 r
.62182 .39513 m .62322 .39523 L .62523 .39273 L F
.423 0 0 r
.6236 .39396 m .62504 .39287 L .62714 .39342 L F
.62504 .39287 m .62523 .39273 L .62527 .39274 L F
.62504 .39287 m .62527 .39274 L .62714 .39342 L F
.894 .987 .783 r
.62662 .39203 m .62852 .39026 L .62762 .38956 L F
.62757 .39153 m .62852 .39026 L .62662 .39203 L F
.754 .984 .906 r
.62762 .38956 m .62852 .39026 L .63138 .38782 L F
.658 .623 .804 r
.62852 .39026 m .63136 .39034 L .63138 .38782 L F
.325 .273 .644 r
.62852 .39026 m .63117 .39227 L .63136 .39034 L F
.62852 .39026 m .62943 .39382 L .63117 .39227 L F
.277 0 .115 r
.26786 .55516 m .2683 .55745 L .27029 .5548 L F
.26786 .55516 m .2661 .5584 L .2683 .55745 L F
.246 0 0 r
.26786 .55516 m .27029 .5548 L .2728 .55348 L F
.78 .896 .49 r
.4004 .61408 m .40176 .61241 L .40141 .61191 L F
.4004 .61408 m .39986 .61598 L .40176 .61241 L F
.644 .137 .028 r
.24136 .55958 m .23778 .55903 L .23925 .56 L F
.848 .936 .882 r
.43328 .57949 m .43198 .58178 L .43174 .5803 L F
.748 .919 .949 r
.55582 .41306 m .55135 .41424 L .55276 .41558 L F
0 0 .121 r
.28047 .62878 m .2782 .63237 L .27962 .631 L F
.01 .3 .794 r
.28203 .62936 m .27909 .62704 L .28047 .62878 L F
.28203 .62936 m .28282 .63032 L .28169 .62933 L F
.28203 .62936 m .28148 .62915 L .28169 .62933 L F
.28203 .62936 m .28169 .62933 L .27909 .62704 L F
.28203 .62936 m .28169 .62933 L .28187 .62947 L F
0 .071 .557 r
.27909 .62704 m .28169 .62933 L .27947 .62724 L F
.542 .313 .516 r
.27839 .63347 m .2819 .6295 L .27962 .631 L F
.2819 .6295 m .28203 .62936 L .28187 .62947 L F
.2819 .6295 m .28187 .62947 L .27962 .631 L F
.115 0 .367 r
.28235 .62988 m .28145 .63343 L .28323 .63126 L F
.28203 .62936 m .282 .62958 L .28221 .62975 L F
.28203 .62936 m .28221 .62975 L .28224 .6297 L F
.159 .381 .83 r
.28203 .62936 m .2825 .62939 L .28282 .63032 L F
.087 .273 .757 r
.28282 .63032 m .28348 .62944 L .28187 .62578 L F
.159 .381 .83 r
.2825 .62939 m .28348 .62944 L .28282 .63032 L F
.542 .313 .516 r
.27839 .63347 m .28145 .63343 L .282 .62958 L F
.2819 .6295 m .282 .62958 L .28203 .62936 L F
0 .071 .557 r
.28187 .62947 m .28189 .62949 L .28195 .62954 L F
.28187 .62947 m .28195 .62954 L .28193 .62952 L F
.542 .313 .516 r
.27839 .63347 m .282 .62958 L .2819 .6295 L F
0 .071 .557 r
.28193 .62952 m .28195 .62954 L .28214 .62969 L F
.087 .273 .757 r
.28221 .62975 m .28208 .6282 L .27947 .62724 L F
.28208 .6282 m .28187 .62578 L .28134 .6261 L F
.28208 .6282 m .28134 .6261 L .27947 .62724 L F
.115 0 .367 r
.2825 .62939 m .28323 .63126 L .28348 .62944 L F
.28203 .62936 m .28224 .6297 L .2825 .62939 L F
.087 .273 .757 r
.28282 .63032 m .2826 .62926 L .28221 .62975 L F
.2826 .62926 m .28224 .6297 L .28221 .62975 L F
.115 0 .367 r
.28224 .6297 m .28323 .63126 L .2825 .62939 L F
.087 .273 .757 r
.2826 .62926 m .28258 .62913 L .28224 .6297 L F
.28258 .62913 m .28187 .62578 L .28221 .62975 L F
.115 0 .367 r
.28224 .6297 m .28221 .62975 L .28235 .62988 L F
0 .071 .557 r
.28189 .62949 m .28282 .63032 L .28221 .62975 L F
.28176 .62938 m .28282 .63032 L .28187 .62947 L F
.115 0 .367 r
.282 .62958 m .28145 .63343 L .28235 .62988 L F
0 .071 .557 r
.28189 .62949 m .28221 .62975 L .28214 .62969 L F
.28169 .62933 m .28176 .62938 L .28187 .62947 L F
.28169 .62933 m .28214 .62969 L .27947 .62724 L F
.01 .3 .794 r
.28187 .62947 m .28047 .62878 L .27962 .631 L F
.28148 .62915 m .28047 .62878 L .28187 .62947 L F
0 .075 .628 r
.62622 .41717 m .62557 .41875 L .62469 .41576 L F
.197 .503 .908 r
.62802 .41941 m .62557 .41875 L .62622 .41717 L F
.503 .483 .768 r
.62707 .42038 m .62557 .41875 L .62802 .41941 L F
.834 .544 .499 r
.6268 .41929 m .62802 .41941 L .62622 .41717 L F
.6268 .41929 m .62906 .41835 L .62802 .41941 L F
.62906 .41835 m .63025 .41785 L .62802 .41941 L F
.503 .483 .768 r
.62866 .42208 m .62707 .42038 L .62802 .41941 L F
.633 .191 .184 r
.28876 .6535 m .29243 .65314 L .29258 .65614 L F
0 0 .149 r
.29419 .65285 m .29243 .65314 L .29433 .65074 L F
0 0 .168 r
.29258 .65614 m .29243 .65314 L .29419 .65285 L F
.893 .929 .836 r
.54721 .42936 m .54643 .43199 L .54482 .43164 L F
.643 .435 .586 r
.54643 .43199 m .54582 .43489 L .54482 .43164 L F
.54643 .43199 m .54841 .43449 L .54582 .43489 L F
.053 .482 .888 r
.32638 .69484 m .32775 .69622 L .33107 .69724 L F
.315 0 0 r
.70093 .35909 m .7049 .35874 L .70483 .35993 L F
0 0 .46 r
.7049 .35874 m .70593 .35994 L .70483 .35993 L F
.7049 .35874 m .70697 .36124 L .70593 .35994 L F
.546 .032 0 r
.36958 .52804 m .37425 .5273 L .37056 .52753 L F
.36958 .52804 m .37231 .52857 L .37425 .5273 L F
0 .094 .61 r
.37425 .5273 m .3754 .52562 L .37435 .52295 L F
0 0 0 r
.37425 .5273 m .37461 .52719 L .3754 .52562 L F
.37425 .5273 m .37231 .52857 L .37461 .52719 L F
.542 .284 .475 r
.40465 .6669 m .40272 .66354 L .40351 .6656 L F
0 0 0 r
.4048 .66809 m .4041 .66971 L .40465 .6669 L F
.4048 .66809 m .40465 .6669 L .40351 .6656 L F
.4 .129 .383 r
.33636 .6054 m .33438 .60315 L .33656 .6027 L F
.33636 .6054 m .33383 .60622 L .33438 .60315 L F
.864 .689 .664 r
.3484 .71393 m .35185 .71451 L .34921 .7169 L F
.743 .477 .528 r
.34921 .7169 m .35185 .71451 L .35197 .71749 L F
.463 .854 .977 r
.35635 .71582 m .35415 .7165 L .35652 .71581 L F
.611 .18 .199 r
.35185 .71451 m .35415 .7165 L .35196 .71718 L F
.463 .854 .977 r
.3526 .71596 m .35415 .7165 L .35635 .71582 L F
.611 .18 .199 r
.35196 .71718 m .35415 .7165 L .35197 .71749 L F
.761 .966 .677 r
.6942 .33365 m .69277 .33635 L .69537 .33382 L F
.6942 .33365 m .69222 .33617 L .69277 .33635 L F
.346 0 0 r
.695 .33729 m .69277 .33635 L .69222 .33617 L F
.695 .33729 m .69567 .33708 L .69277 .33635 L F
.653 .605 .788 r
.69277 .33635 m .69582 .33692 L .69537 .33382 L F
.229 0 0 r
.69277 .33635 m .69567 .33708 L .69582 .33692 L F
.221 .252 .682 r
.22679 .55448 m .22722 .5575 L .22518 .55572 L F
.492 .302 .551 r
.36547 .57796 m .36536 .5807 L .36771 .57993 L F
.147 .538 .922 r
.28897 .64139 m .28898 .64139 L .28834 .64224 L F
.505 .91 .848 r
.28834 .64224 m .29039 .64201 L .28775 .64304 L F
.626 .961 .859 r
.29193 .6407 m .29039 .64201 L .28834 .64224 L F
.29193 .6407 m .28834 .64224 L .29057 .64299 L F
.147 .538 .922 r
.28898 .64139 m .29057 .64299 L .28834 .64224 L F
.505 .91 .848 r
.28834 .64224 m .28775 .64304 L .28566 .64386 L F
.543 .514 .773 r
.19964 .60658 m .20195 .60603 L .20195 .60501 L F
0 0 0 r
.25119 .58432 m .25035 .58515 L .24717 .58643 L F
.25154 .58479 m .25119 .58432 L .25328 .58374 L F
.25154 .58479 m .25035 .58515 L .25119 .58432 L F
.051 .02 .497 r
.31285 .58083 m .31407 .57647 L .31297 .57799 L F
.874 .474 .018 r
.57581 .42709 m .57599 .42586 L .57528 .42463 L F
.57581 .42709 m .57706 .42826 L .57599 .42586 L F
.961 .687 .469 r
.33329 .69244 m .33342 .68912 L .3316 .69094 L F
.69 .251 .202 r
.33342 .68912 m .33568 .69135 L .3316 .69094 L F
.398 .366 .707 r
.44126 .5355 m .4387 .53702 L .4383 .53315 L F
.296 .22 .599 r
.44126 .5355 m .43935 .53965 L .4387 .53702 L F
0 0 0 r
.35428 .58563 m .35425 .58476 L .35457 .58291 L F
.294 .077 .404 r
.35055 .63187 m .3481 .63521 L .3504 .63471 L F
.52 .361 .606 r
.34818 .63801 m .3504 .63471 L .3481 .63521 L F
.294 .077 .404 r
.35055 .63187 m .3481 .63521 L .3504 .63471 L F
.52 .361 .606 r
.34818 .63801 m .3504 .63471 L .3481 .63521 L F
.847 .503 0 r
.5816 .40332 m .58181 .40379 L .58093 .40329 L F
0 .396 .797 r
.58181 .40379 m .58321 .40378 L .58093 .40329 L F
.176 0 0 r
.57963 .40324 m .58093 .40329 L .58321 .40378 L F
.57931 .40319 m .58093 .40329 L .57963 .40324 L F
.847 .503 0 r
.58003 .39973 m .5816 .40332 L .58093 .40329 L F
0 .396 .797 r
.58181 .40379 m .58486 .40504 L .58321 .40378 L F
.794 .508 .503 r
.58181 .40379 m .58519 .4068 L .58486 .40504 L F
.919 .901 .792 r
.30048 .66013 m .30266 .65712 L .30097 .65624 L F
.367 .633 .956 r
.37731 .59541 m .37863 .59697 L .3764 .59665 L F
.596 .856 .507 r
.3764 .59665 m .37451 .59875 L .37731 .59541 L F
.367 .633 .956 r
.37731 .59541 m .37863 .59697 L .3764 .59665 L F
.669 .838 .42 r
.34072 .5522 m .34102 .55147 L .34225 .54954 L F
0 0 .303 r
.34072 .5522 m .34147 .55413 L .34102 .55147 L F
0 .125 .657 r
.23076 .61323 m .23177 .61352 L .2296 .61156 L F
.23076 .61323 m .23298 .61526 L .23177 .61352 L F
.756 .636 .728 r
.66054 .35551 m .66181 .35885 L .65808 .35862 L F
.707 .454 .54 r
.66181 .35885 m .65804 .36125 L .65808 .35862 L F
.66181 .35885 m .66194 .3614 L .65804 .36125 L F
.691 .457 .564 r
.66444 .35881 m .66194 .3614 L .66181 .35885 L F
.297 0 .264 r
.27283 .56191 m .27171 .56468 L .26965 .56529 L F
.579 .447 .665 r
.27516 .55832 m .27547 .5617 L .27283 .56191 L F
.584 .268 .401 r
.27503 .5638 m .27283 .56191 L .27547 .5617 L F
.27503 .5638 m .27171 .56468 L .27283 .56191 L F
.919 .944 .8 r
.2492 .55452 m .24823 .55864 L .25049 .55498 L F
.924 .97 .766 r
.25147 .551 m .25049 .55498 L .25335 .55239 L F
.25147 .551 m .2492 .55452 L .25049 .55498 L F
0 .166 .692 r
.40224 .53065 m .40424 .53233 L .40162 .52921 L F
.833 .932 .895 r
.26289 .52811 m .26341 .53062 L .26467 .52884 L F
.96 .719 .528 r
.26094 .52981 m .26341 .53062 L .26289 .52811 L F
.26094 .52981 m .263 .53235 L .26341 .53062 L F
.437 .122 .332 r
.7127 .30784 m .71257 .30943 L .7104 .30982 L F
0 0 .174 r
.71406 .30849 m .7127 .30784 L .71296 .30635 L F
.71406 .30849 m .71257 .30943 L .7127 .30784 L F
.21 .56 .935 r
.35686 .50207 m .3555 .50304 L .35392 .50144 L F
.35686 .50207 m .35808 .50355 L .3555 .50304 L F
.887 .862 .81 r
.66588 .36735 m .66475 .37159 L .66329 .37071 L F
.61 .4 .572 r
.66475 .37159 m .66456 .37402 L .66329 .37071 L F
.66475 .37159 m .66739 .37388 L .66456 .37402 L F
.78 .336 .195 r
.3914 .58589 m .39307 .58444 L .38988 .58429 L F
0 0 0 r
.39464 .58312 m .39307 .58444 L .3914 .58589 L F
.78 .336 .195 r
.3914 .58589 m .39307 .58444 L .38988 .58429 L F
.808 .488 .45 r
.33466 .51971 m .33868 .52023 L .33673 .51798 L F
.929 .919 .783 r
.69698 .31872 m .69922 .31816 L .69795 .3166 L F
.742 .735 .845 r
.69922 .31816 m .70045 .31336 L .69795 .3166 L F
.69922 .31816 m .70122 .31631 L .70045 .31336 L F
.353 .237 .58 r
.32462 .57712 m .32257 .58097 L .32226 .57824 L F
.561 .238 .378 r
.27029 .5548 m .27365 .55289 L .2728 .55348 L F
0 0 0 r
.62255 .43862 m .62472 .43419 L .62417 .43639 L F
.124 0 0 r
.43353 .58765 m .43185 .58897 L .42938 .58966 L F
.536 .006 0 r
.43353 .58765 m .43559 .58911 L .43185 .58897 L F
.447 .09 .265 r
.43625 .58724 m .43559 .58911 L .43353 .58765 L F
0 0 0 r
.62674 .40164 m .62516 .40314 L .62727 .40001 L F
.765 .27 0 r
.62546 .40473 m .62706 .4058 L .62516 .40314 L F
.62546 .40473 m .62516 .40314 L .62674 .40164 L F
.819 .813 .844 r
.34661 .52377 m .34284 .52344 L .34466 .52246 L F
.53 .555 .825 r
.71463 .32919 m .71459 .32631 L .71443 .32676 L F
.166 0 .307 r
.35885 .66501 m .35784 .66358 L .35722 .66605 L F
.608 .929 .965 r
.26307 .52293 m .26097 .52409 L .2593 .52373 L F
.589 .4 .593 r
.62596 .39366 m .63038 .39424 L .62943 .39382 L F
.62596 .39366 m .62672 .39692 L .63038 .39424 L F
.8 .832 .876 r
.65953 .34434 m .65948 .34667 L .65804 .34541 L F
.757 .725 .823 r
.39216 .64538 m .39393 .64794 L .39011 .64761 L F
.426 .583 .905 r
.39516 .64607 m .39393 .64794 L .39216 .64538 L F
.335 .461 .839 r
.39516 .64607 m .39701 .64985 L .39393 .64794 L F
.734 .988 .795 r
.36787 .65943 m .36692 .66059 L .36755 .65899 L F
.371 .147 .439 r
.29271 .6272 m .28943 .63048 L .29 .62794 L F
.29271 .6272 m .29235 .63107 L .28943 .63048 L F
.377 .048 .274 r
.28943 .63048 m .2915 .63308 L .28956 .63385 L F
.28943 .63048 m .29235 .63107 L .2915 .63308 L F
.774 .78 .858 r
.545 .41716 m .54563 .41924 L .54206 .41857 L F
.454 0 0 r
.54206 .41857 m .54563 .41924 L .54512 .4195 L F
.788 .542 .565 r
.54702 .42559 m .54307 .42754 L .54559 .42427 L F
.54702 .42559 m .54721 .42936 L .54307 .42754 L F
.932 .704 .222 r
.54757 .41671 m .54563 .41924 L .545 .41716 L F
.54757 .41671 m .54821 .41864 L .54563 .41924 L F
0 0 0 r
.54512 .4195 m .54563 .41924 L .54821 .41864 L F
.481 .567 .866 r
.54816 .42284 m .54702 .42559 L .54559 .42427 L F
.54816 .42284 m .54981 .42599 L .54702 .42559 L F
.555 .318 .511 r
.54702 .42559 m .55 .42863 L .54721 .42936 L F
.54702 .42559 m .54981 .42599 L .55 .42863 L F
.661 .81 .955 r
.58337 .41439 m .58464 .41603 L .5807 .41552 L F
.426 .69 .974 r
.58574 .41417 m .58464 .41603 L .58337 .41439 L F
0 0 .233 r
.58505 .41657 m .58464 .41603 L .58574 .41417 L F
.58505 .41657 m .58524 .41875 L .58464 .41603 L F
.784 .304 0 r
.28627 .64794 m .28894 .65077 L .28775 .65014 L F
.996 .764 .427 r
.28775 .65014 m .28894 .65077 L .28876 .6535 L F
.803 .967 .91 r
.31562 .62269 m .31129 .62455 L .31353 .6238 L F
.586 .651 .881 r
.39201 .56861 m .3929 .571 L .3904 .57164 L F
0 0 0 r
.3929 .571 m .39022 .57422 L .3904 .57164 L F
.672 .519 .669 r
.39022 .57422 m .3929 .571 L .3904 .57164 L F
.331 .105 .412 r
.3137 .60003 m .31349 .60241 L .31122 .6033 L F
.281 .043 .364 r
.31349 .60241 m .31077 .60553 L .31122 .6033 L F
.598 .198 .257 r
.29764 .65632 m .29758 .65398 L .29552 .65703 L F
.29764 .65632 m .29901 .65417 L .29758 .65398 L F
.793 .65 .704 r
.67125 .35597 m .67086 .35856 L .66957 .35945 L F
.726 .703 .829 r
.65571 .37828 m .65306 .38114 L .65196 .37771 L F
.671 .611 .779 r
.65571 .37828 m .65624 .38107 L .65306 .38114 L F
.5 .27 .497 r
.65624 .38107 m .65351 .38388 L .65306 .38114 L F
.992 .742 .39 r
.40519 .57093 m .40511 .57355 L .40638 .57466 L F
.933 .662 .186 r
.40577 .57603 m .40638 .57466 L .40511 .57355 L F
.40577 .57603 m .40653 .57728 L .40638 .57466 L F
0 0 0 r
.3888 .5752 m .38778 .5748 L .39018 .57687 L F
.645 .419 .562 r
.39022 .57422 m .39018 .57687 L .39335 .57369 L F
.1 .641 .848 r
.3888 .5752 m .39097 .57523 L .38959 .57507 L F
.3888 .5752 m .38959 .57507 L .38692 .57475 L F
0 0 0 r
.3888 .5752 m .38647 .57699 L .3874 .57543 L F
.3888 .5752 m .3874 .57543 L .38778 .5748 L F
.592 .065 0 r
.62177 .44996 m .6256 .45033 L .62392 .4507 L F
.351 0 0 r
.6256 .45033 m .62677 .45127 L .62392 .4507 L F
.6256 .45033 m .62806 .45091 L .62677 .45127 L F
.485 .155 .331 r
.2835 .55274 m .28312 .55475 L .28042 .555 L F
.685 .416 .509 r
.28615 .55165 m .28312 .55475 L .2835 .55274 L F
0 0 .371 r
.4103 .50888 m .4104 .51152 L .41 .50841 L F
.633 .16 0 r
.40966 .50841 m .41088 .50981 L .4103 .50888 L F
.594 .645 .871 r
.41268 .50975 m .4104 .51152 L .4103 .50888 L F
.633 .16 0 r
.41088 .50981 m .41136 .51036 L .4103 .50888 L F
0 0 .371 r
.4103 .50888 m .41 .50841 L .40998 .50823 L F
.687 .935 .638 r
.3637 .65594 m .3656 .65445 L .36632 .65304 L F
0 .092 .62 r
.36434 .51683 m .3636 .51316 L .36528 .51499 L F
.12 0 0 r
.35175 .59094 m .34993 .59266 L .34759 .59333 L F
.531 .32 .539 r
.35341 .58916 m .34993 .59266 L .35175 .59094 L F
.549 .23 .38 r
.44096 .58313 m .4389 .58128 L .44105 .58046 L F
.44096 .58313 m .43827 .58356 L .4389 .58128 L F
.64 .56 .749 r
.25642 .56552 m .25733 .56803 L .25385 .56825 L F
.333 .092 .392 r
.25733 .56803 m .25468 .57138 L .25385 .56825 L F
.844 .848 .847 r
.66635 .33544 m .66643 .33901 L .66496 .34015 L F
.838 .844 .85 r
.66914 .336 m .66643 .33901 L .66635 .33544 L F
.568 .756 .967 r
.41137 .50678 m .4138 .50887 L .41464 .50855 L F
0 0 .027 r
.32671 .57372 m .32462 .57712 L .32494 .57466 L F
.848 .996 .759 r
.38485 .67664 m .38457 .67781 L .38714 .67512 L F
.38387 .6773 m .38457 .67781 L .38485 .67664 L F
0 0 .369 r
.38457 .67781 m .38436 .68125 L .38413 .67964 L F
.38457 .67781 m .38413 .67964 L .38353 .67539 L F
.469 .193 .412 r
.33011 .66327 m .33041 .6605 L .32713 .66419 L F
.59 .296 .437 r
.33011 .66327 m .33318 .66268 L .33041 .6605 L F
.568 .782 .979 r
.72151 .32166 m .71995 .32393 L .71878 .32237 L F
0 0 .397 r
.7216 .32426 m .71995 .32393 L .72151 .32166 L F
.7216 .32426 m .72015 .32649 L .71995 .32393 L F
.702 .968 .934 r
.57212 .41948 m .5686 .42179 L .56786 .42089 L F
.523 .297 .514 r
.3914 .59623 m .3889 .59676 L .39013 .59458 L F
.932 .704 .222 r
.54757 .41671 m .54818 .41597 L .54821 .41864 L F
.559 .935 .873 r
.55135 .41424 m .54818 .41597 L .54939 .41492 L F
.692 .629 .782 r
.54821 .41864 m .54818 .41597 L .54757 .41671 L F
.54821 .41864 m .54939 .41492 L .54818 .41597 L F
0 0 .067 r
.40755 .53995 m .40769 .54094 L .40581 .53861 L F
.40755 .53995 m .40771 .54268 L .40769 .54094 L F
.215 .131 .54 r
.28704 .63964 m .28433 .63914 L .28707 .63705 L F
.28704 .63964 m .2851 .6416 L .28433 .63914 L F
.665 .673 .848 r
.41755 .49963 m .41397 .49863 L .4165 .4979 L F
.595 .626 .852 r
.41886 .4972 m .41755 .49963 L .4165 .4979 L F
.41886 .4972 m .42054 .49908 L .41755 .49963 L F
.425 .439 .771 r
.4249 .55464 m .42534 .55943 L .42397 .5589 L F
.559 .272 .437 r
.42534 .55943 m .42622 .56096 L .42397 .5589 L F
0 .388 .81 r
.24672 .62554 m .24699 .62496 L .2451 .6243 L F
.24672 .62554 m .2483 .62612 L .24699 .62496 L F
.401 .075 .293 r
.37597 .68862 m .37798 .68832 L .37895 .68595 L F
0 0 0 r
.37895 .68595 m .37971 .68712 L .38158 .68564 L F
.37895 .68595 m .37798 .68832 L .37971 .68712 L F
.53 .355 .589 r
.37895 .68595 m .38158 .68564 L .38141 .68263 L F
.042 .506 .886 r
.42868 .57219 m .42671 .57166 L .42548 .5706 L F
.97 .886 .691 r
.34593 .51343 m .34435 .51408 L .34595 .51006 L F
.831 .514 .453 r
.34593 .51343 m .34323 .51526 L .34435 .51408 L F
.34593 .51343 m .34778 .51616 L .34323 .51526 L F
.669 .775 .929 r
.59586 .43204 m .59769 .43201 L .59729 .42943 L F
.673 .598 .763 r
.40531 .5193 m .40769 .51716 L .40533 .51995 L F
.589 .083 .02 r
.40533 .51995 m .40833 .52061 L .4057 .51947 L F
.40533 .51995 m .4057 .51947 L .40531 .5193 L F
.673 .598 .763 r
.40531 .5193 m .4057 .51947 L .40769 .51716 L F
.714 .949 .953 r
.4057 .51947 m .40533 .51995 L .40769 .51716 L F
.673 .598 .763 r
.4057 .51947 m .40833 .52061 L .40769 .51716 L F
.714 .949 .953 r
.40715 .51755 m .4057 .51947 L .40769 .51716 L F
.40608 .51831 m .40533 .51995 L .40715 .51755 L F
.40608 .51831 m .40357 .5192 L .40533 .51995 L F
.028 .133 .64 r
.40608 .51831 m .40533 .51995 L .40357 .5192 L F
.589 .083 .02 r
.40533 .51995 m .40713 .52156 L .40833 .52061 L F
.028 .133 .64 r
.40608 .51831 m .40713 .52156 L .40533 .51995 L F
.34 .234 .586 r
.25538 .54287 m .25705 .54214 L .25694 .53943 L F
.046 0 0 r
.25538 .54287 m .25399 .54497 L .25705 .54214 L F
.575 .834 .994 r
.3442 .5496 m .34225 .54954 L .34424 .54851 L F
0 0 0 r
.34225 .54954 m .34318 .54977 L .34424 .54851 L F
.88 .916 .517 r
.34424 .54851 m .34318 .54977 L .34429 .54676 L F
.34424 .54851 m .34429 .54676 L .34442 .5464 L F
.575 .834 .994 r
.34573 .54966 m .3442 .5496 L .34424 .54851 L F
.863 .896 .857 r
.34834 .54622 m .34573 .54966 L .34424 .54851 L F
.753 .563 .638 r
.56951 .45623 m .56569 .45311 L .56937 .45427 L F
.619 .319 .439 r
.57364 .45376 m .56951 .45623 L .56937 .45427 L F
0 .414 .79 r
.24437 .61252 m .24686 .61389 L .24393 .61278 L F
.603 .725 .931 r
.26728 .52839 m .26881 .5303 L .27143 .52989 L F
.543 .324 .533 r
.26871 .53282 m .27143 .52989 L .26881 .5303 L F
.153 0 .217 r
.35329 .52585 m .35552 .52323 L .3534 .52388 L F
.921 .738 .639 r
.37354 .67636 m .37093 .67822 L .36949 .67668 L F
.37354 .67636 m .37293 .6794 L .37093 .67822 L F
.578 .625 .862 r
.38187 .71446 m .38275 .71093 L .38046 .71217 L F
.602 .432 .624 r
.38444 .71125 m .38486 .71452 L .38187 .71446 L F
.578 .625 .862 r
.38187 .71446 m .38486 .71452 L .38275 .71093 L F
.579 .293 .446 r
.3842 .71674 m .38486 .71452 L .38187 .71446 L F
.495 .297 .541 r
.38176 .7172 m .3842 .71674 L .38187 .71446 L F
.579 .293 .446 r
.3842 .71674 m .38486 .71452 L .38187 .71446 L F
.495 .297 .541 r
.38176 .7172 m .3842 .71674 L .38187 .71446 L F
0 0 .392 r
.40274 .65942 m .40275 .66038 L .40184 .65689 L F
.732 .6 .028 r
.40264 .66248 m .40275 .66038 L .40274 .65942 L F
.40264 .66248 m .40272 .66354 L .40275 .66038 L F
.866 .996 .793 r
.36828 .64245 m .36661 .64469 L .3669 .64247 L F
.808 .976 .9 r
.3669 .64247 m .36661 .64469 L .36477 .64483 L F
.265 .064 .409 r
.30807 .58747 m .30995 .58677 L .31027 .58414 L F
.15 0 .324 r
.30807 .58747 m .30924 .58914 L .30995 .58677 L F
.30807 .58747 m .30769 .58981 L .30924 .58914 L F
.295 0 .143 r
.27229 .60679 m .27445 .60639 L .27583 .60472 L F
.152 .037 .457 r
.34501 .64673 m .34436 .65069 L .34615 .65032 L F
.319 .006 .266 r
.34501 .64673 m .34947 .64386 L .34679 .64429 L F
.34501 .64673 m .34788 .64662 L .34947 .64386 L F
.286 .204 .585 r
.34501 .64673 m .34857 .6501 L .34788 .64662 L F
.34501 .64673 m .34615 .65032 L .34857 .6501 L F
.435 0 0 r
.33383 .52784 m .33731 .52939 L .33493 .52991 L F
.226 .341 .772 r
.39836 .64961 m .39687 .65151 L .39701 .64985 L F
.516 .073 .136 r
.357 .60818 m .35561 .6071 L .35428 .60792 L F
0 0 0 r
.35561 .6071 m .35428 .60792 L .35568 .6072 L F
.705 .429 .503 r
.44109 .54946 m .44199 .55213 L .4392 .55199 L F
.186 .701 .888 r
.44199 .55213 m .44018 .55179 L .43795 .55193 L F
.687 .546 .688 r
.44461 .55168 m .44197 .55491 L .44199 .55213 L F
.939 .754 .626 r
.44199 .55213 m .44197 .55491 L .44018 .55179 L F
.175 .409 .849 r
.44018 .55179 m .44119 .55355 L .44237 .55305 L F
.44119 .55355 m .44197 .55491 L .44211 .55427 L F
.44119 .55355 m .44211 .55427 L .44237 .55305 L F
.705 .429 .503 r
.43853 .55147 m .4392 .55199 L .43795 .55193 L F
.44109 .54946 m .4392 .55199 L .43853 .55147 L F
.488 .573 .867 r
.44317 .54728 m .44109 .54946 L .43991 .54673 L F
.645 .396 .528 r
.44461 .55168 m .44109 .54946 L .44317 .54728 L F
.44461 .55168 m .44199 .55213 L .44109 .54946 L F
.472 .648 .935 r
.33773 .70811 m .34114 .71225 L .34245 .70991 L F
.501 .685 .949 r
.34114 .71225 m .34341 .71207 L .34245 .70991 L F
.119 .55 .919 r
.25077 .62815 m .25112 .62725 L .2483 .62612 L F
.25077 .62815 m .2529 .62878 L .25112 .62725 L F
.346 0 0 r
.37773 .51545 m .38008 .51654 L .38166 .51713 L F
.086 .435 .875 r
.37828 .51494 m .38008 .51654 L .37773 .51545 L F
.821 .341 .006 r
.37828 .51494 m .3791 .51618 L .38008 .51654 L F
.3791 .51618 m .3803 .518 L .38008 .51654 L F
.346 0 0 r
.38166 .51713 m .38008 .51654 L .38206 .5173 L F
.799 .307 .001 r
.3803 .518 m .38206 .5173 L .38008 .51654 L F
.3803 .518 m .38358 .51966 L .38206 .5173 L F
.777 .616 .68 r
.66957 .35945 m .67086 .35856 L .66865 .36156 L F
.615 .354 .5 r
.36652 .55475 m .36807 .55532 L .36673 .55253 L F
.36652 .55475 m .36807 .55532 L .36673 .55253 L F
.377 0 .12 r
.2316 .55086 m .23004 .54969 L .23256 .54966 L F
.2316 .55086 m .22853 .55174 L .23004 .54969 L F
.637 .717 .905 r
.37101 .60584 m .37492 .60596 L .37428 .60455 L F
.544 .292 .484 r
.38444 .71125 m .38679 .71356 L .38486 .71452 L F
.38444 .71125 m .38729 .71098 L .38679 .71356 L F
.452 .506 .824 r
.43222 .51042 m .43017 .51087 L .42984 .50999 L F
.634 .465 .636 r
.33457 .5713 m .33738 .57138 L .3369 .57114 L F
.33457 .5713 m .3333 .57419 L .33738 .57138 L F
.768 .47 .482 r
.36289 .61627 m .35876 .61817 L .36197 .61499 L F
.36289 .61627 m .36347 .61844 L .35876 .61817 L F
.461 .287 .558 r
.36576 .61818 m .36289 .61627 L .36623 .61534 L F
.36576 .61818 m .36347 .61844 L .36289 .61627 L F
0 .098 .651 r
.4113 .54999 m .41266 .552 L .41109 .54837 L F
.86 .99 .836 r
.34077 .50627 m .34095 .50825 L .3426 .50612 L F
.921 .702 .588 r
.33805 .50737 m .34095 .50825 L .34077 .50627 L F
.33805 .50737 m .34035 .5108 L .34095 .50825 L F
.04 .353 .828 r
.34713 .55575 m .34744 .55434 L .34539 .55336 L F
0 .165 .703 r
.34713 .55575 m .349 .55733 L .34744 .55434 L F
.244 .196 .603 r
.34713 .55575 m .34765 .55908 L .349 .55733 L F
.698 .446 .539 r
.56569 .45311 m .56159 .45074 L .56553 .451 L F
0 .147 .691 r
.21587 .60297 m .21652 .60302 L .21486 .59976 L F
0 .036 .598 r
.21587 .60297 m .21749 .60511 L .21652 .60302 L F
.694 .838 .952 r
.27962 .631 m .2782 .63237 L .27622 .63116 L F
.571 .588 .831 r
.66501 .3956 m .66414 .40047 L .66309 .39577 L F
.66501 .3956 m .66491 .39826 L .66414 .40047 L F
0 0 .344 r
.66414 .40047 m .66564 .40096 L .66327 .40208 L F
.66414 .40047 m .66491 .39826 L .66564 .40096 L F
.835 .465 .352 r
.32116 .61906 m .32467 .61924 L .32322 .62101 L F
0 0 0 r
.32322 .62101 m .32467 .61924 L .32666 .61817 L F
.795 .804 .859 r
.38231 .55291 m .38056 .55476 L .38308 .55538 L F
.823 .421 .287 r
.38056 .55476 m .38186 .55732 L .38308 .55538 L F
.312 .489 .872 r
.38231 .55291 m .38308 .55538 L .38361 .55317 L F
.814 .877 .442 r
.38308 .55538 m .38186 .55732 L .38361 .55317 L F
.3 0 0 r
.34886 .68601 m .34701 .68768 L .34859 .68713 L F
.536 .04 .025 r
.34859 .68713 m .34886 .68601 L .34701 .68768 L F
.78 .413 .362 r
.35007 .69095 m .34859 .68713 L .34701 .68768 L F
.754 .401 .384 r
.35007 .69095 m .35182 .68851 L .34859 .68713 L F
.3 0 0 r
.34886 .68601 m .34956 .68726 L .34701 .68768 L F
.71 .67 .809 r
.39885 .51009 m .39737 .51182 L .39617 .50812 L F
.911 .51 .202 r
.42607 .56372 m .42692 .56246 L .42622 .56096 L F
.42607 .56372 m .42783 .56467 L .42692 .56246 L F
.819 .489 .431 r
.42692 .56246 m .42783 .56467 L .42825 .56439 L F
.571 .614 .857 r
.3385 .68269 m .33923 .67875 L .33745 .68179 L F
.3385 .68269 m .34094 .68234 L .33923 .67875 L F
.499 .234 .443 r
.34069 .68539 m .3385 .68269 L .33745 .68179 L F
.34069 .68539 m .34094 .68234 L .3385 .68269 L F
0 0 .515 r
.27992 .53338 m .28068 .5374 L .28112 .53505 L F
.766 .912 .938 r
.28112 .53505 m .28068 .5374 L .28275 .53572 L F
0 0 .118 r
.40155 .68665 m .40122 .68582 L .40166 .68547 L F
.40155 .68665 m .40138 .68853 L .40122 .68582 L F
.835 .994 .749 r
.28865 .54625 m .28621 .54759 L .28898 .54412 L F
.493 .277 .513 r
.29148 .54314 m .29112 .54585 L .28865 .54625 L F
.103 0 .088 r
.29112 .54585 m .28843 .54856 L .28865 .54625 L F
.691 .457 .564 r
.66444 .35881 m .6645 .36137 L .66194 .3614 L F
.736 .566 .663 r
.66957 .35945 m .6645 .36137 L .66444 .35881 L F
.318 .126 .455 r
.31604 .59643 m .31561 .59963 L .3137 .60003 L F
.402 .161 .431 r
.31543 .60161 m .3137 .60003 L .31561 .59963 L F
.31543 .60161 m .31349 .60241 L .3137 .60003 L F
.681 .731 .888 r
.62482 .37486 m .62573 .37765 L .62171 .37691 L F
.654 .69 .872 r
.62706 .37334 m .62573 .37765 L .62482 .37486 L F
.62706 .37334 m .6288 .37674 L .62573 .37765 L F
.549 .534 .791 r
.62976 .38097 m .62573 .37765 L .6288 .37674 L F
.284 .07 .402 r
.36266 .64409 m .36078 .64571 L .36011 .64855 L F
.425 .844 .682 r
.63134 .45017 m .63487 .44813 L .63318 .44892 L F
.593 .88 .569 r
.63641 .44624 m .63487 .44813 L .63625 .4466 L F
.636 .945 .726 r
.63318 .44892 m .63487 .44813 L .63641 .44624 L F
.923 .84 .39 r
.39926 .61839 m .39986 .61598 L .39883 .61805 L F
.74 .816 .348 r
.39883 .61805 m .39986 .61598 L .4004 .61408 L F
0 0 .362 r
.34479 .54297 m .34582 .54404 L .3452 .54136 L F
.34479 .54297 m .3455 .54529 L .34582 .54404 L F
.801 .72 .775 r
.43838 .5683 m .43594 .57078 L .43989 .57141 L F
.663 .251 .252 r
.43582 .57313 m .43989 .57141 L .43594 .57078 L F
.43582 .57313 m .43863 .57376 L .43989 .57141 L F
.632 .547 .741 r
.44225 .57082 m .43996 .57426 L .43989 .57141 L F
.128 0 0 r
.43989 .57141 m .44101 .57266 L .44225 .57082 L F
.43989 .57141 m .43863 .57376 L .44101 .57266 L F
.637 .337 .446 r
.58365 .43247 m .58535 .43377 L .58443 .4353 L F
.579 .369 .56 r
.5877 .43042 m .58365 .43247 L .5834 .4282 L F
.548 .372 .595 r
.58365 .43247 m .5877 .43443 L .58535 .43377 L F
.47 .795 .999 r
.58934 .43173 m .58365 .43247 L .59031 .43219 L F
.669 .775 .929 r
.59586 .43204 m .59494 .4322 L .59469 .43429 L F
.59586 .43204 m .59729 .42943 L .59494 .4322 L F
.685 .416 .509 r
.28615 .55165 m .28592 .55491 L .28312 .55475 L F
.408 .296 .614 r
.28843 .54856 m .28863 .55108 L .28615 .55165 L F
.51 .329 .571 r
.28863 .55108 m .28592 .55491 L .28615 .55165 L F
.254 .477 .881 r
.37039 .63464 m .37214 .63749 L .37335 .63715 L F
.209 .284 .722 r
.37335 .63715 m .37214 .63749 L .37432 .63927 L F
.688 .904 .554 r
.33155 .61165 m .32867 .61545 L .33042 .61331 L F
.074 0 0 r
.62806 .45091 m .63134 .45017 L .63118 .4505 L F
0 0 0 r
.63118 .4505 m .63134 .45017 L .63318 .44892 L F
.188 0 0 r
.74612 .30517 m .74198 .30687 L .74548 .30331 L F
.74612 .30517 m .74507 .30633 L .74198 .30687 L F
.983 .833 .441 r
.74612 .30517 m .74507 .30633 L .74548 .30331 L F
.697 .832 .394 r
.31507 .52261 m .31361 .52532 L .31324 .52641 L F
.611 .956 .848 r
.31361 .52532 m .31243 .52628 L .31324 .52641 L F
.477 .89 .922 r
.35564 .61125 m .36222 .60965 L .36116 .60914 L F
.58 .117 .119 r
.2421 .54631 m .23706 .54735 L .23918 .5467 L F
.705 .468 .563 r
.4331 .53952 m .43178 .54133 L .42941 .53942 L F
.063 .128 .619 r
.20133 .58395 m .20184 .58746 L .20298 .58573 L F
.116 .2 .676 r
.20184 .58746 m .20377 .58947 L .20298 .58573 L F
.863 .581 .509 r
.55127 .44415 m .54886 .44402 L .54821 .44122 L F
.851 .537 .456 r
.55127 .44415 m .54952 .44652 L .54886 .44402 L F
.718 .354 .359 r
.55361 .44676 m .54952 .44652 L .55127 .44415 L F
.874 .549 .433 r
.43604 .54235 m .43681 .54554 L .43456 .5442 L F
.43604 .54235 m .43456 .5442 L .43474 .5441 L F
.687 .46 .572 r
.43456 .5442 m .4334 .54571 L .43421 .54297 L F
.43453 .54396 m .43421 .54297 L .43433 .54255 L F
.43456 .5442 m .43421 .54297 L .43453 .54396 L F
.883 .561 .435 r
.43604 .54235 m .43474 .5441 L .43312 .53955 L F
.4331 .53952 m .43312 .53955 L .4331 .53952 L F
.43604 .54235 m .43312 .53955 L .4331 .53952 L F
0 0 0 r
.43935 .53965 m .43767 .54109 L .43604 .54235 L F
.562 .357 .56 r
.4394 .54457 m .43604 .54235 L .43767 .54109 L F
.4394 .54457 m .43681 .54554 L .43604 .54235 L F
.621 .556 .76 r
.44356 .57716 m .44119 .57767 L .43996 .57426 L F
.662 .423 .548 r
.44456 .57927 m .44119 .57767 L .44356 .57716 L F
.44456 .57927 m .44105 .58046 L .44119 .57767 L F
.672 .834 .41 r
.29148 .54314 m .29197 .54201 L .29318 .5401 L F
.475 .164 .357 r
.28898 .54412 m .29197 .54201 L .29148 .54314 L F
.432 .224 .495 r
.29348 .54505 m .29148 .54314 L .29441 .54231 L F
.29348 .54505 m .29112 .54585 L .29148 .54314 L F
.433 .517 .844 r
.55523 .41548 m .55895 .41587 L .55743 .41597 L F
.55523 .41548 m .55831 .41883 L .55895 .41587 L F
.463 0 0 r
.55988 .41716 m .55895 .41587 L .55831 .41883 L F
.55988 .41716 m .56119 .41613 L .55895 .41587 L F
.672 .597 .763 r
.65838 .39254 m .65468 .38979 L .65848 .39058 L F
.739 .714 .828 r
.66108 .38972 m .65838 .39254 L .65848 .39058 L F
.447 .248 .517 r
.3239 .58677 m .32086 .5898 L .3211 .58768 L F
.442 .177 .415 r
.35065 .52959 m .35305 .52907 L .35329 .52585 L F
.604 .098 0 r
.35542 .52838 m .35329 .52585 L .35305 .52907 L F
.35542 .52838 m .35476 .52783 L .35329 .52585 L F
.153 0 .217 r
.35329 .52585 m .35476 .52783 L .35552 .52323 L F
0 0 .046 r
.27992 .53338 m .28088 .53261 L .2816 .52991 L F
0 0 .502 r
.27992 .53338 m .28112 .53505 L .28088 .53261 L F
.54 .809 .996 r
.25284 .57766 m .2496 .57477 L .25185 .57541 L F
.25284 .57766 m .24787 .57671 L .2496 .57477 L F
.078 0 .449 r
.25418 .57418 m .25284 .57766 L .25185 .57541 L F
.25347 .57602 m .25388 .57752 L .25284 .57766 L F
.417 .36 .687 r
.25388 .57752 m .25287 .58049 L .25284 .57766 L F
.25388 .57752 m .25481 .57991 L .25287 .58049 L F
.849 .479 0 r
.25285 .57609 m .25423 .57879 L .25388 .57752 L F
.25423 .57879 m .25481 .57991 L .25388 .57752 L F
.078 0 .449 r
.25418 .57418 m .25388 .57752 L .25347 .57602 L F
.658 .575 .751 r
.45013 .5772 m .44607 .57397 L .44981 .57469 L F
.665 .617 .791 r
.45372 .57421 m .44981 .57469 L .44845 .57077 L F
.459 .138 .334 r
.45372 .57421 m .45013 .5772 L .44981 .57469 L F
.246 0 0 r
.69961 .35945 m .70093 .35909 L .70483 .35993 L F
.388 .666 .969 r
.37604 .67321 m .37878 .67319 L .37723 .67152 L F
.978 .751 .526 r
.37723 .67152 m .37878 .67319 L .37604 .67321 L F
.392 .202 .5 r
.62625 .4254 m .62866 .42208 L .62834 .42426 L F
.307 .04 .334 r
.6257 .42765 m .62625 .4254 L .62834 .42426 L F
.365 .438 .803 r
.39339 .68406 m .39194 .68587 L .39303 .68339 L F
.494 .245 .466 r
.39491 .68584 m .39194 .68587 L .39339 .68406 L F
.39491 .68584 m .39188 .6885 L .39194 .68587 L F
.39194 .68587 m .39188 .6885 L .39491 .68584 L F
.649 .936 .967 r
.72939 .33675 m .72592 .3375 L .72857 .3367 L F
.598 .565 .789 r
.69537 .33382 m .69582 .33692 L .69958 .33598 L F
.492 .032 .088 r
.69567 .33708 m .69958 .33598 L .69582 .33692 L F
0 0 0 r
.33719 .54511 m .33485 .54801 L .33613 .54699 L F
.771 .548 .597 r
.43328 .57949 m .43088 .57743 L .43483 .57774 L F
.119 .086 .543 r
.28935 .56191 m .29085 .56388 L .29048 .56215 L F
.393 .228 .535 r
.73175 .33564 m .73368 .33237 L .73212 .33348 L F
.338 .029 .286 r
.30612 .5363 m .3084 .53579 L .30915 .53352 L F
.791 .7 .764 r
.30755 .52942 m .30915 .53352 L .31122 .52985 L F
.519 .55 .827 r
.43935 .52857 m .43738 .53089 L .43689 .52894 L F
.331 .323 .7 r
.43935 .52857 m .4383 .53315 L .43738 .53089 L F
.36 0 .191 r
.27583 .60472 m .27445 .60639 L .27707 .60575 L F
.473 0 0 r
.27583 .60472 m .27707 .60575 L .27789 .60626 L F
.073 .29 .775 r
.31575 .56784 m .31746 .57152 L .3182 .5699 L F
.687 .848 .43 r
.3182 .5699 m .31746 .57152 L .31626 .57331 L F
.6 .914 .978 r
.34341 .71207 m .34798 .71123 L .34633 .71306 L F
.916 .572 .373 r
.34633 .71306 m .34798 .71123 L .3484 .71393 L F
.844 .848 .847 r
.66635 .33544 m .66496 .34015 L .66368 .33893 L F
.941 .802 .679 r
.66496 .34015 m .66268 .34118 L .66368 .33893 L F
.66496 .34015 m .66427 .34268 L .66268 .34118 L F
.355 .201 .529 r
.63136 .39034 m .63359 .38685 L .63138 .38782 L F
.63136 .39034 m .63413 .38919 L .63359 .38685 L F
.191 0 .19 r
.63117 .39227 m .63413 .38919 L .63136 .39034 L F
.314 0 .257 r
.35943 .52014 m .35552 .52323 L .35684 .52149 L F
.763 .481 .507 r
.30173 .53369 m .30275 .53606 L .30612 .5363 L F
.887 .891 .827 r
.30269 .5318 m .30275 .53606 L .30173 .53369 L F
.67 .448 .574 r
.43845 .56513 m .43838 .5683 L .43528 .56755 L F
.656 .436 .573 r
.44124 .56806 m .43845 .56513 L .44095 .56453 L F
.111 .005 .442 r
.43845 .56513 m .44008 .56568 L .44095 .56453 L F
.656 .436 .573 r
.44124 .56806 m .43838 .5683 L .43845 .56513 L F
.111 .005 .442 r
.43845 .56513 m .43838 .5683 L .44008 .56568 L F
.419 0 .035 r
.35831 .71478 m .3633 .714 L .36071 .71551 L F
.035 0 .177 r
.73566 .3398 m .73357 .33991 L .73503 .33855 L F
.73566 .3398 m .73291 .34193 L .73357 .33991 L F
0 0 0 r
.73649 .33686 m .73503 .33855 L .73473 .33869 L F
.612 .849 .479 r
.73648 .33639 m .73503 .33855 L .73647 .33665 L F
.73648 .33639 m .73647 .33665 L .73769 .33505 L F
.986 .895 .577 r
.73621 .33469 m .73648 .33639 L .73754 .33426 L F
0 0 .139 r
.73621 .33469 m .73649 .33632 L .73648 .33639 L F
.726 .933 .601 r
.73769 .33505 m .73503 .33855 L .73649 .33686 L F
0 0 .139 r
.73649 .33632 m .73697 .33919 L .73648 .33639 L F
.162 .154 .601 r
.73648 .33639 m .73609 .33801 L .73503 .33855 L F
.73609 .33801 m .73566 .3398 L .73503 .33855 L F
0 0 0 r
.73473 .33869 m .73503 .33855 L .73357 .33991 L F
.779 .823 .887 r
.38281 .67329 m .37878 .67319 L .38098 .67209 L F
.734 .759 .873 r
.54821 .41864 m .55218 .41914 L .55021 .41752 L F
.42 .295 .603 r
.3291 .5704 m .32676 .56825 L .32871 .56759 L F
.047 .026 .508 r
.23112 .60092 m .22959 .60275 L .22868 .60009 L F
.556 .051 .012 r
.59653 .42817 m .601 .42821 L .59959 .42997 L F
.712 .233 .109 r
.59959 .42997 m .601 .42821 L .60315 .43056 L F
.585 .462 .679 r
.24034 .58154 m .24322 .58369 L .24276 .5811 L F
.24034 .58154 m .2407 .58427 L .24322 .58369 L F
.657 .452 .595 r
.26057 .56522 m .25733 .56803 L .25642 .56552 L F
.26057 .56522 m .26003 .56791 L .25733 .56803 L F
0 0 .162 r
.24597 .53885 m .24387 .5422 L .24463 .5399 L F
.622 .501 .694 r
.30806 .54874 m .30519 .54649 L .30795 .54558 L F
.30806 .54874 m .3056 .54931 L .30543 .54817 L F
.30623 .54731 m .30543 .54817 L .30519 .54649 L F
.30806 .54874 m .30543 .54817 L .30623 .54731 L F
0 0 0 r
.30519 .54649 m .30545 .54698 L .30795 .54558 L F
.729 .971 .719 r
.30802 .54538 m .30545 .54698 L .30851 .54391 L F
.30795 .54558 m .3077 .54572 L .30802 .54538 L F
.3077 .54572 m .30545 .54698 L .30802 .54538 L F
0 0 0 r
.30519 .54649 m .30442 .54826 L .30545 .54698 L F
.626 .577 .78 r
.24483 .58738 m .24591 .58295 L .24322 .58369 L F
.24483 .58738 m .24717 .58643 L .24591 .58295 L F
.984 .798 .397 r
.37575 .63083 m .37662 .63203 L .37639 .63355 L F
.331 .323 .7 r
.43935 .52857 m .44004 .53276 L .4383 .53315 L F
.398 .366 .707 r
.44126 .5355 m .4383 .53315 L .44004 .53276 L F
.016 0 .138 r
.30334 .61837 m .30087 .62174 L .30176 .61944 L F
.724 .556 .662 r
.67365 .3685 m .67378 .37126 L .67003 .3716 L F
.684 .525 .664 r
.67365 .3685 m .67634 .3681 L .67378 .37126 L F
.508 .38 .641 r
.33143 .5618 m .3319 .56488 L .32942 .56551 L F
.384 .074 .31 r
.3319 .56488 m .32871 .56759 L .32942 .56551 L F
.493 .295 .539 r
.38436 .68125 m .38385 .68214 L .38141 .68263 L F
.96 .693 .485 r
.38141 .68263 m .38158 .68564 L .37953 .68451 L F
.775 .706 .786 r
.62672 .39692 m .62727 .40001 L .6236 .39958 L F
.6236 .39958 m .62727 .40001 L .62672 .39692 L F
0 0 0 r
.62727 .40001 m .63032 .39717 L .6293 .39884 L F
.62674 .40164 m .62727 .40001 L .6293 .39884 L F
.647 .157 .071 r
.6236 .39958 m .62727 .40001 L .62674 .40164 L F
.845 .645 .631 r
.39857 .59378 m .39452 .59637 L .39714 .59297 L F
.39857 .59378 m .39681 .59726 L .39452 .59637 L F
.923 .921 .793 r
.39857 .59378 m .39714 .59297 L .39938 .5895 L F
.458 .824 .567 r
.23349 .5363 m .23472 .53527 L .23644 .53393 L F
0 0 0 r
.23349 .5363 m .23175 .53818 L .23472 .53527 L F
.992 .781 .516 r
.63694 .43366 m .63838 .43506 L .63783 .43675 L F
.63694 .43366 m .63838 .43506 L .63783 .43675 L F
.516 .585 .862 r
.43131 .56477 m .4295 .56611 L .42825 .56439 L F
.849 .8 .803 r
.65804 .34541 m .65713 .35 L .6552 .34848 L F
.902 .646 .543 r
.65713 .35 m .65515 .35105 L .6552 .34848 L F
.65713 .35 m .65696 .35209 L .65515 .35105 L F
.942 .782 .32 r
.69502 .32199 m .69517 .32586 L .69634 .32362 L F
.952 .911 .74 r
.69634 .32362 m .69698 .31872 L .69502 .32199 L F
.759 .659 .752 r
.35327 .63122 m .3504 .63471 L .35055 .63187 L F
.35327 .63122 m .35389 .63419 L .3504 .63471 L F
.493 .202 .399 r
.35294 .63402 m .35055 .63187 L .3504 .63471 L F
.35294 .63402 m .35327 .63122 L .35055 .63187 L F
.402 .013 .182 r
.31859 .6368 m .32195 .63549 L .3197 .63584 L F
.426 .146 .382 r
.26608 .62531 m .26844 .62478 L .26903 .62248 L F
.312 .044 .338 r
.26903 .62248 m .27075 .62381 L .27131 .62213 L F
.26903 .62248 m .26844 .62478 L .27075 .62381 L F
.777 .73 .809 r
.6138 .37339 m .61526 .37514 L .61189 .37395 L F
.798 .711 .769 r
.61189 .37395 m .61526 .37514 L .6134 .37769 L F
.592 .678 .9 r
.61764 .37443 m .61526 .37514 L .6138 .37339 L F
.556 .581 .835 r
.61921 .37793 m .61526 .37514 L .61764 .37443 L F
.621 .066 0 r
.2296 .61156 m .2249 .60963 L .22751 .61147 L F
.909 .965 .648 r
.71291 .34172 m .71342 .34255 L .71144 .34596 L F
.777 .996 .86 r
.71655 .33954 m .71342 .34255 L .71291 .34172 L F
.346 .182 .511 r
.36536 .5807 m .36323 .58412 L .36514 .58384 L F
.481 .484 .783 r
.36639 .51625 m .3688 .52283 L .36614 .52274 L F
.383 .724 .989 r
.70314 .32863 m .7014 .3294 L .70147 .32857 L F
.70314 .32863 m .70475 .32954 L .7014 .3294 L F
0 0 0 r
.41 .50082 m .41224 .50008 L .41397 .49863 L F
.574 .829 .993 r
.4165 .4979 m .41397 .49863 L .41225 .49765 L F
.951 .638 .404 r
.41397 .49863 m .41224 .50008 L .41225 .49765 L F
.406 .576 .907 r
.40329 .56302 m .4019 .56504 L .40343 .56227 L F
.40329 .56302 m .40343 .56227 L .4021 .56127 L F
.314 0 .257 r
.35943 .52014 m .35669 .52441 L .35552 .52323 L F
0 0 0 r
.35552 .52323 m .35811 .52216 L .35943 .52014 L F
.701 .664 .81 r
.35542 .52838 m .35941 .5291 L .35833 .52551 L F
.698 .669 .818 r
.35542 .52838 m .35692 .53021 L .35707 .53014 L F
.35746 .52874 m .35707 .53014 L .35941 .5291 L F
.35542 .52838 m .35707 .53014 L .35746 .52874 L F
.716 .673 .807 r
.35833 .52551 m .35941 .5291 L .36222 .52795 L F
0 0 0 r
.35858 .52604 m .35743 .52891 L .35802 .52666 L F
.35833 .52552 m .35802 .52666 L .35833 .52551 L F
.35858 .52604 m .35802 .52666 L .35833 .52552 L F
.681 .63 .791 r
.35833 .52551 m .35743 .52891 L .35542 .52838 L F
0 0 0 r
.35858 .52604 m .35833 .52551 L .35732 .52473 L F
.109 0 .203 r
.35552 .52323 m .35476 .52783 L .35688 .52424 L F
.35584 .5231 m .35688 .52424 L .35811 .52216 L F
.35552 .52323 m .35688 .52424 L .35584 .5231 L F
.848 .774 .779 r
.35522 .51862 m .35522 .52382 L .3538 .52258 L F
.769 .583 .647 r
.35811 .52216 m .35565 .52391 L .35552 .52321 L F
.35544 .52242 m .35552 .52321 L .35537 .52243 L F
.35811 .52216 m .35552 .52321 L .35544 .52242 L F
.35811 .52216 m .35665 .52463 L .35565 .52391 L F
.35811 .52216 m .35544 .52242 L .3557 .52286 L F
0 .018 .543 r
.35729 .51965 m .3557 .52286 L .35522 .51862 L F
.3557 .52286 m .35552 .52321 L .35548 .52257 L F
.3557 .52286 m .35548 .52257 L .35522 .51862 L F
.769 .583 .647 r
.35644 .52385 m .3557 .52286 L .35634 .52396 L F
.35811 .52216 m .3557 .52286 L .35644 .52385 L F
0 0 .405 r
.35587 .52315 m .35634 .52396 L .35558 .52386 L F
.35729 .51965 m .35558 .52386 L .35552 .52321 L F
0 .018 .543 r
.35552 .52321 m .35522 .52382 L .35522 .52222 L F
.35537 .52243 m .35522 .52222 L .35522 .52161 L F
.35552 .52321 m .35522 .52222 L .35537 .52243 L F
.35552 .52321 m .35522 .52161 L .35522 .51862 L F
0 0 .405 r
.35552 .52321 m .35558 .52386 L .35522 .52382 L F
.769 .583 .647 r
.35537 .52243 m .35565 .52391 L .3538 .52258 L F
.3557 .52286 m .3538 .52258 L .35634 .52396 L F
.35544 .52242 m .35537 .52243 L .3557 .52286 L F
.35537 .52243 m .3538 .52258 L .3557 .52286 L F
0 0 .405 r
.35729 .51965 m .35634 .52396 L .35587 .52315 L F
0 .333 .788 r
.35522 .52382 m .35558 .52386 L .3538 .52258 L F
.769 .583 .647 r
.35665 .52463 m .35476 .52783 L .3538 .52258 L F
0 .333 .788 r
.35558 .52386 m .35634 .52396 L .3538 .52258 L F
0 0 0 r
.35822 .52571 m .35732 .52473 L .35634 .52396 L F
.35858 .52604 m .35732 .52473 L .35822 .52571 L F
.979 .696 .313 r
.40399 .56974 m .40503 .56841 L .40453 .56717 L F
.40399 .56974 m .40519 .57093 L .40503 .56841 L F
.391 .01 .191 r
.69174 .36167 m .69416 .36329 L .6915 .36321 L F
.69174 .36167 m .69445 .36115 L .69416 .36329 L F
.798 .711 .769 r
.61189 .37395 m .6134 .37769 L .6116 .37653 L F
.526 .04 0 r
.6134 .37769 m .61408 .37845 L .6116 .37653 L F
.6134 .37769 m .6158 .38033 L .61408 .37845 L F
.778 .637 .705 r
.58183 .42414 m .58586 .42494 L .58398 .42593 L F
.706 .557 .683 r
.58586 .42494 m .5877 .43042 L .5834 .4282 L F
.778 .406 .351 r
.58586 .42494 m .59001 .42902 L .5877 .43042 L F
.828 .821 .842 r
.62116 .39766 m .62322 .39523 L .62048 .3966 L F
.62116 .39766 m .62378 .39506 L .62322 .39523 L F
.974 .906 .683 r
.61944 .39906 m .62116 .39766 L .62048 .3966 L F
.54 .518 .78 r
.35295 .54161 m .34863 .53806 L .35372 .53965 L F
.625 .266 .341 r
.35295 .54161 m .35582 .54157 L .35372 .53965 L F
.563 .018 0 r
.35372 .53965 m .35395 .54028 L .35295 .54161 L F
.35372 .53965 m .35582 .54157 L .35395 .54028 L F
0 0 0 r
.32818 .60621 m .32632 .60973 L .32763 .60821 L F
.357 .193 .517 r
.32763 .60821 m .32951 .60493 L .32818 .60621 L F
.349 .614 .949 r
.58792 .40369 m .58428 .40183 L .58706 .40168 L F
.549 .703 .942 r
.58974 .40116 m .58792 .40369 L .58706 .40168 L F
.24 .272 .694 r
.59019 .40583 m .58792 .40369 L .58974 .40116 L F
0 .035 .535 r
.59156 .40723 m .58792 .40369 L .59019 .40583 L F
.002 0 .382 r
.29411 .6444 m .29328 .64758 L .29348 .64441 L F
0 0 0 r
.29411 .6444 m .29348 .64441 L .29565 .64346 L F
.664 .274 .296 r
.29764 .65632 m .30097 .65624 L .29901 .65417 L F
.924 .911 .518 r
.39654 .65737 m .39518 .65995 L .39714 .65612 L F
.951 .854 .709 r
.6897 .30783 m .68683 .30956 L .68859 .30641 L F
.6897 .30783 m .68833 .31097 L .68683 .30956 L F
.886 .912 .838 r
.69231 .30457 m .6897 .30783 L .68859 .30641 L F
0 0 .501 r
.58486 .40504 m .58519 .4068 L .5864 .40855 L F
.584 .566 .8 r
.65722 .38726 m .65468 .38979 L .65415 .38782 L F
.605 .601 .821 r
.65722 .38726 m .65848 .39058 L .65468 .38979 L F
.727 .737 .86 r
.69036 .34223 m .69418 .34284 L .69228 .33954 L F
.756 .554 .623 r
.69057 .34471 m .69418 .34284 L .69036 .34223 L F
.69057 .34471 m .69469 .34564 L .69418 .34284 L F
.472 .612 .908 r
.69228 .33954 m .69418 .34284 L .69584 .34044 L F
.484 .628 .916 r
.69584 .34044 m .69418 .34284 L .69615 .3422 L F
.452 .349 .647 r
.69418 .34284 m .69717 .34474 L .69615 .3422 L F
.69418 .34284 m .69469 .34564 L .69717 .34474 L F
0 .191 .703 r
.31343 .51908 m .31317 .51961 L .31119 .51698 L F
.31343 .51908 m .31428 .52043 L .31317 .51961 L F
0 .068 .611 r
.31507 .52261 m .31317 .51961 L .31428 .52043 L F
.794 .428 0 r
.31343 .51908 m .31507 .52261 L .31428 .52043 L F
.068 .279 .768 r
.31576 .52086 m .31507 .52261 L .31343 .51908 L F
.617 .209 .246 r
.31205 .52058 m .31529 .52083 L .31343 .51908 L F
.31529 .52083 m .31576 .52086 L .31343 .51908 L F
0 .191 .703 r
.31343 .51908 m .31119 .51698 L .311 .51672 L F
.489 .372 .647 r
.33609 .65478 m .33819 .65907 L .33838 .65605 L F
.33609 .65478 m .33615 .65989 L .33819 .65907 L F
.85 .832 .829 r
.66762 .33436 m .66914 .336 L .66635 .33544 L F
.826 .831 .852 r
.67186 .33293 m .66914 .336 L .66762 .33436 L F
.5 .27 .497 r
.65624 .38107 m .65626 .38329 L .65351 .38388 L F
.535 .448 .704 r
.65827 .37723 m .65624 .38107 L .65571 .37828 L F
.65827 .37723 m .65885 .38033 L .65624 .38107 L F
.462 .242 .494 r
.65885 .38033 m .65626 .38329 L .65624 .38107 L F
.968 .723 .513 r
.35977 .56072 m .35977 .56345 L .36203 .56229 L F
.937 .925 .771 r
.36318 .55899 m .36203 .56229 L .36162 .56071 L F
.973 .918 .68 r
.36203 .56229 m .35977 .56345 L .36162 .56071 L F
.754 .716 .818 r
.32357 .66573 m .32795 .66568 L .32615 .66277 L F
.76 .685 .779 r
.32536 .66741 m .32795 .66568 L .32357 .66573 L F
.469 .193 .412 r
.33011 .66327 m .32713 .66419 L .32615 .66277 L F
.525 .619 .888 r
.32615 .66277 m .32795 .66568 L .33018 .66496 L F
.685 .758 .907 r
.63882 .38012 m .64269 .38086 L .64013 .382 L F
.469 .293 .559 r
.42428 .54577 m .42413 .54835 L .42172 .54887 L F
.534 .449 .705 r
.42495 .55179 m .42172 .54887 L .42413 .54835 L F
.42495 .55179 m .42268 .55331 L .42172 .54887 L F
.951 .922 .743 r
.25339 .5318 m .25143 .53526 L .25376 .53416 L F
.857 .955 .874 r
.38977 .70497 m .39064 .70184 L .38791 .70394 L F
.38977 .70497 m .39257 .70211 L .39064 .70184 L F
.638 .723 .909 r
.30249 .53875 m .30314 .54151 L .30603 .53958 L F
.76 .737 .831 r
.64314 .39671 m .64249 .39966 L .64567 .39587 L F
.719 .63 .757 r
.64478 .40057 m .64567 .39587 L .64249 .39966 L F
.081 0 .386 r
.32548 .61222 m .32763 .60821 L .32632 .60973 L F
.214 0 0 r
.36587 .66273 m .3637 .66259 L .36304 .66366 L F
.577 .549 .786 r
.43197 .50802 m .42984 .50999 L .42827 .50556 L F
.452 .506 .824 r
.43222 .51042 m .42984 .50999 L .43197 .50802 L F
0 0 0 r
.40482 .60193 m .40524 .5999 L .40538 .59919 L F
.796 .697 .755 r
.36762 .58988 m .36838 .59378 L .36646 .59532 L F
.568 .373 .577 r
.36838 .59378 m .36587 .59671 L .36646 .59532 L F
.36838 .59378 m .36866 .59651 L .36587 .59671 L F
.089 .191 .676 r
.36962 .59213 m .36838 .59378 L .36762 .58988 L F
.723 .528 0 r
.36836 .59429 m .36838 .59378 L .36962 .59213 L F
.36836 .59429 m .36866 .59651 L .36838 .59378 L F
.363 .666 .973 r
.60352 .39085 m .60277 .39231 L .60081 .38955 L F
.60352 .39085 m .60487 .39242 L .60277 .39231 L F
.155 0 .199 r
.25685 .53463 m .25818 .53493 L .25881 .53312 L F
.499 .466 .752 r
.25694 .53943 m .25818 .53493 L .25685 .53463 L F
.785 .872 .912 r
.39021 .63503 m .38708 .63752 L .39015 .63685 L F
.574 .64 .878 r
.25335 .55239 m .25776 .55518 L .25599 .55134 L F
.432 .545 .871 r
.25776 .55518 m .25783 .55151 L .25599 .55134 L F
.278 0 .284 r
.26039 .55262 m .25963 .55476 L .25776 .55518 L F
.432 .545 .871 r
.25776 .55518 m .25963 .55476 L .25783 .55151 L F
.661 .913 .978 r
.5877 .43443 m .58872 .43524 L .58938 .43351 L F
.609 .736 .936 r
.33979 .49693 m .34113 .49889 L .33717 .49776 L F
.417 .635 .945 r
.34186 .49675 m .34113 .49889 L .33979 .49693 L F
.479 .703 .967 r
.34186 .49675 m .34332 .49862 L .34113 .49889 L F
.655 .723 .899 r
.32514 .58322 m .32671 .58415 L .32282 .58348 L F
.624 .472 .655 r
.32648 .58634 m .32282 .58348 L .32671 .58415 L F
.573 .277 .428 r
.32671 .58415 m .32899 .58623 L .32648 .58634 L F
.603 .27 .378 r
.32967 .58428 m .32899 .58623 L .32671 .58415 L F
.44 .047 .196 r
.32299 .52895 m .32602 .52858 L .32719 .52584 L F
.319 .082 .388 r
.32719 .52584 m .32949 .52567 L .32963 .52344 L F
0 0 0 r
.32719 .52584 m .32773 .52698 L .32949 .52567 L F
.32719 .52584 m .32602 .52858 L .32773 .52698 L F
.852 .915 .875 r
.7069 .28267 m .70811 .28446 L .70565 .28611 L F
.495 .761 .99 r
.71078 .28363 m .70811 .28446 L .7069 .28267 L F
.029 0 0 r
.29636 .65997 m .30048 .66013 L .29867 .66006 L F
.919 .901 .792 r
.30048 .66013 m .30097 .65624 L .29867 .66006 L F
.606 .416 .599 r
.67634 .3681 m .67643 .37095 L .67378 .37126 L F
.623 .43 .6 r
.67899 .36754 m .67643 .37095 L .67634 .3681 L F
.798 .631 .675 r
.65896 .3518 m .66054 .35551 L .65673 .35491 L F
.786 .683 .751 r
.65673 .35491 m .66054 .35551 L .65808 .35862 L F
.701 .588 .726 r
.66313 .35228 m .66054 .35551 L .65896 .3518 L F
.58 .481 .707 r
.56117 .41864 m .56319 .41614 L .56119 .41613 L F
.201 0 0 r
.56319 .41614 m .56119 .41613 L .55988 .41716 L F
.236 .284 .709 r
.40833 .52061 m .41006 .51915 L .40769 .51716 L F
.462 .824 .561 r
.40833 .52061 m .40713 .52156 L .41006 .51915 L F
0 0 .393 r
.38656 .67611 m .38731 .67844 L .38714 .67512 L F
.669 .923 .618 r
.38457 .67781 m .38656 .67611 L .38714 .67512 L F
.451 .372 .676 r
.38714 .67512 m .38731 .67844 L .38787 .67425 L F
.45 .371 .676 r
.38787 .67425 m .38731 .67844 L .39016 .6741 L F
0 0 .311 r
.38656 .67611 m .38757 .67811 L .38731 .67844 L F
.38656 .67611 m .38689 .67916 L .38757 .67811 L F
.184 0 0 r
.71235 .3671 m .71606 .36514 L .71454 .36647 L F
0 0 0 r
.71763 .36378 m .71454 .36647 L .71606 .36514 L F
.835 .499 .417 r
.37056 .57124 m .36934 .57173 L .36925 .57018 L F
.256 .766 .844 r
.37325 .57125 m .36934 .57173 L .37056 .57124 L F
.418 .281 .587 r
.63673 .38167 m .63458 .38518 L .6351 .38289 L F
.586 .893 .612 r
.23644 .53393 m .23603 .53388 L .23869 .53292 L F
.23644 .53393 m .23472 .53527 L .23603 .53388 L F
.816 .936 .909 r
.3211 .66922 m .32536 .66741 L .32357 .66573 L F
.62 .879 .989 r
.55133 .42912 m .54721 .42936 L .54901 .42909 L F
.507 .283 .508 r
.54981 .42599 m .5527 .4266 L .55 .42863 L F
.038 0 0 r
.54901 .42909 m .54721 .42936 L .55 .42863 L F
.735 .99 .878 r
.55 .42863 m .5527 .4266 L .54901 .42909 L F
.789 .978 .907 r
.5527 .4266 m .55133 .42912 L .54901 .42909 L F
.987 .717 .405 r
.39127 .51524 m .39003 .51272 L .39109 .51395 L F
.737 .949 .64 r
.30795 .54558 m .30851 .54391 L .31037 .54239 L F
.308 0 .269 r
.3115 .5454 m .30806 .54874 L .30795 .54558 L F
.501 0 0 r
.37904 .6519 m .38098 .65074 L .37691 .65036 L F
.023 0 0 r
.38122 .65106 m .38098 .65074 L .37904 .6519 L F
.38122 .65106 m .38344 .6505 L .38098 .65074 L F
.886 .912 .838 r
.69231 .30457 m .68859 .30641 L .69129 .30333 L F
.843 .937 .887 r
.69515 .30163 m .69231 .30457 L .69129 .30333 L F
.786 .677 .744 r
.24396 .56002 m .24823 .55864 L .2469 .55786 L F
.24368 .56026 m .24823 .55864 L .24396 .56002 L F
.24362 .56028 m .24576 .56165 L .24823 .55864 L F
.24362 .56028 m .24368 .56026 L .24396 .56002 L F
0 0 0 r
.24491 .55942 m .24362 .56028 L .24396 .56002 L F
.24491 .55942 m .24396 .56002 L .2469 .55786 L F
.001 0 .066 r
.24761 .55651 m .24491 .55942 L .2469 .55786 L F
.24564 .55863 m .24599 .55874 L .24491 .55942 L F
.24599 .55874 m .24725 .55913 L .24491 .55942 L F
.24761 .55651 m .24753 .55706 L .24564 .55863 L F
.576 .422 .635 r
.24393 .55536 m .24824 .55599 L .24642 .55193 L F
.708 .449 .53 r
.24227 .55655 m .24824 .55599 L .24393 .55536 L F
.24202 .55672 m .24418 .55647 L .24227 .55655 L F
.524 .397 .648 r
.24642 .55193 m .24824 .55599 L .2492 .55452 L F
.708 .449 .53 r
.24202 .55672 m .24541 .55728 L .24824 .55599 L F
.919 .944 .8 r
.24919 .55454 m .2469 .55786 L .24823 .55864 L F
.829 .885 .883 r
.24824 .55599 m .24749 .55353 L .2492 .55452 L F
.919 .944 .8 r
.2491 .55466 m .2469 .55786 L .24919 .55454 L F
.708 .449 .53 r
.24418 .55647 m .24761 .55606 L .24227 .55655 L F
.24761 .55606 m .24824 .55599 L .2476 .55605 L F
.24761 .55606 m .2476 .55605 L .24227 .55655 L F
.829 .885 .883 r
.24824 .55599 m .24541 .55728 L .24579 .55661 L F
.2481 .55552 m .24579 .55661 L .24749 .55353 L F
.24824 .55599 m .24579 .55661 L .2481 .55552 L F
.817 .73 .768 r
.24761 .55651 m .2469 .55786 L .2487 .55524 L F
.24857 .55531 m .2487 .55524 L .2492 .55452 L F
.24761 .55651 m .2487 .55524 L .24857 .55531 L F
.024 0 .294 r
.25044 .5529 m .24996 .55558 L .24781 .55643 L F
.24775 .55632 m .24781 .55643 L .24761 .55651 L F
.919 .944 .8 r
.2492 .55452 m .2491 .55466 L .24919 .55454 L F
.024 0 .294 r
.25044 .5529 m .24781 .55643 L .24775 .55632 L F
.354 .216 .551 r
.24642 .55193 m .24839 .55355 L .24863 .54777 L F
.524 .397 .648 r
.24642 .55193 m .2492 .55452 L .24839 .55355 L F
.715 .515 .618 r
.24863 .54777 m .24839 .55355 L .25147 .551 L F
.837 .754 .772 r
.24839 .55355 m .2492 .55452 L .25147 .551 L F
.024 0 .294 r
.25044 .5529 m .24775 .55632 L .24749 .55353 L F
.24775 .55632 m .24761 .55651 L .2476 .55633 L F
.24775 .55632 m .2476 .55633 L .24749 .55353 L F
.001 0 .066 r
.24753 .55706 m .24725 .55913 L .24594 .55872 L F
.2467 .55775 m .24594 .55872 L .24564 .55863 L F
.24753 .55706 m .24594 .55872 L .2467 .55775 L F
.567 .457 .688 r
.65626 .38329 m .65415 .38782 L .65351 .38388 L F
.652 .959 .763 r
.33657 .67585 m .33279 .67844 L .33664 .67583 L F
.118 .669 .727 r
.33664 .67583 m .3385 .67555 L .33657 .67585 L F
.914 .978 .768 r
.37966 .64465 m .38207 .64123 L .38107 .64073 L F
.801 .992 .876 r
.38107 .64073 m .38207 .64123 L .38464 .6385 L F
0 0 0 r
.55626 .42282 m .55129 .42594 L .55373 .42356 L F
.074 0 .019 r
.29332 .56055 m .29257 .56321 L .29085 .56388 L F
0 0 0 r
.29645 .5579 m .29332 .56055 L .2936 .55902 L F
.29645 .5579 m .29513 .55969 L .29332 .56055 L F
.74 .347 .307 r
.3333 .57419 m .33717 .57692 L .33738 .57138 L F
.3333 .57419 m .3331 .577 L .33717 .57692 L F
.295 .647 .968 r
.58428 .40183 m .58003 .39973 L .58348 .40069 L F
.37 .707 .986 r
.58706 .40168 m .58428 .40183 L .58348 .40069 L F
.659 .339 .421 r
.26965 .56529 m .26883 .56734 L .26643 .56515 L F
.772 .524 .561 r
.36646 .67714 m .36278 .68149 L .36312 .67905 L F
.36646 .67714 m .36741 .68273 L .36278 .68149 L F
.456 .31 .594 r
.36883 .68043 m .36646 .67714 L .3677 .67721 L F
.36883 .68043 m .36741 .68273 L .36646 .67714 L F
.546 .299 .492 r
.3056 .54931 m .30532 .55179 L .3028 .55213 L F
.567 .321 .503 r
.30806 .54874 m .30532 .55179 L .3056 .54931 L F
.559 .13 .184 r
.35943 .52014 m .36077 .52208 L .36181 .51964 L F
.35943 .52014 m .35811 .52216 L .36077 .52208 L F
.495 .135 .284 r
.27735 .62106 m .27981 .62093 L .2817 .61779 L F
.519 .543 .82 r
.2817 .61779 m .2841 .61871 L .28264 .61497 L F
.277 0 .155 r
.2817 .61779 m .28212 .62025 L .2841 .61871 L F
.2817 .61779 m .27981 .62093 L .28212 .62025 L F
0 .042 .555 r
.60816 .42392 m .60587 .42173 L .60469 .42038 L F
.561 .238 .378 r
.27029 .5548 m .27269 .55528 L .27365 .55289 L F
.765 .458 .466 r
.27365 .55289 m .27725 .55535 L .27741 .55333 L F
.27365 .55289 m .27269 .55528 L .27725 .55535 L F
.048 .589 .847 r
.36551 .59794 m .36437 .59799 L .36616 .59806 L F
.828 .976 .887 r
.36334 .59804 m .36587 .59671 L .36437 .59799 L F
.048 .589 .847 r
.36265 .5974 m .36437 .59799 L .36551 .59794 L F
.828 .976 .887 r
.36169 .5989 m .36334 .59804 L .36437 .59799 L F
.506 .173 .337 r
.36587 .59671 m .36866 .59651 L .36917 .59821 L F
.895 .792 .305 r
.29034 .62386 m .29042 .62732 L .29075 .62414 L F
.285 .753 .944 r
.28465 .75841 m .28875 .75878 L .28697 .75813 L F
.28465 .75841 m .28875 .75878 L .28697 .75813 L F
.819 .472 .398 r
.71598 .29602 m .72031 .29729 L .72008 .29517 L F
.558 .689 .927 r
.72024 .29359 m .72008 .29517 L .72209 .29355 L F
.165 .009 .41 r
.72209 .29355 m .72031 .29729 L .72008 .29517 L F
.558 .689 .927 r
.72209 .29355 m .72008 .29517 L .72024 .29359 L F
.165 .009 .41 r
.72209 .29355 m .72031 .29729 L .72008 .29517 L F
.616 .596 .807 r
.63673 .38167 m .6351 .38289 L .63194 .37853 L F
.723 .787 .903 r
.62063 .37422 m .61921 .37793 L .61764 .37443 L F
.62063 .37422 m .62171 .37691 L .61921 .37793 L F
0 0 0 r
.33719 .54511 m .33624 .54733 L .33485 .54801 L F
0 0 .352 r
.3391 .54163 m .33881 .54437 L .33719 .54511 L F
.501 .28 .511 r
.33881 .54437 m .33624 .54733 L .33719 .54511 L F
.756 .994 .819 r
.63898 .42733 m .63746 .42894 L .63837 .42696 L F
.679 .825 .389 r
.63837 .42696 m .63746 .42894 L .63612 .43137 L F
.441 .416 .736 r
.3704 .5655 m .36925 .57018 L .36855 .56492 L F
.894 .871 .807 r
.3225 .53709 m .32591 .53616 L .32447 .53461 L F
.3225 .53709 m .32347 .53958 L .32591 .53616 L F
.736 .566 .663 r
.66957 .35945 m .66865 .36156 L .6645 .36137 L F
.866 .996 .793 r
.36828 .64245 m .3669 .64247 L .36753 .64043 L F
.558 .704 .938 r
.37194 .64154 m .36828 .64245 L .36753 .64043 L F
.744 .442 .471 r
.38469 .59322 m .38595 .59301 L .38746 .59009 L F
.55 .546 .803 r
.38746 .59009 m .38995 .58925 L .38891 .58543 L F
.397 .066 .283 r
.38746 .59009 m .39049 .59274 L .38995 .58925 L F
.38746 .59009 m .38595 .59301 L .39049 .59274 L F
.535 .32 .535 r
.33964 .56813 m .34236 .56801 L .34268 .56518 L F
.503 .78 .994 r
.29565 .64346 m .30024 .64451 L .29824 .6429 L F
.892 .94 .837 r
.26523 .53678 m .26507 .53685 L .26511 .53695 L F
.897 .931 .83 r
.26429 .53499 m .26178 .53827 L .26523 .53678 L F
.26429 .53499 m .26523 .53678 L .26526 .53727 L F
.26435 .53512 m .26526 .53727 L .26578 .53839 L F
.26429 .53499 m .26444 .53533 L .26435 .53512 L F
.26444 .53533 m .26526 .53727 L .26435 .53512 L F
.892 .94 .837 r
.26511 .53695 m .26178 .53827 L .26311 .5396 L F
.26507 .53685 m .26178 .53827 L .26511 .53695 L F
.852 .581 .529 r
.25918 .53909 m .26311 .5396 L .26178 .53827 L F
.25918 .53909 m .26324 .54229 L .26311 .5396 L F
.678 .595 .756 r
.27791 .5567 m .27547 .5617 L .27516 .55832 L F
.991 .768 .503 r
.59477 .38973 m .59595 .39356 L .59473 .3922 L F
.587 .11 0 r
.59473 .3922 m .59595 .39356 L .59765 .39567 L F
.377 .152 .441 r
.32007 .59497 m .31846 .59357 L .32086 .59253 L F
.32007 .59497 m .31812 .59568 L .31846 .59357 L F
.788 .307 0 r
.3955 .54034 m .39609 .53983 L .39488 .53846 L F
.3955 .54034 m .39771 .54233 L .39609 .53983 L F
.323 .105 .421 r
.31027 .58414 m .31232 .58341 L .31285 .58083 L F
.21 .02 .39 r
.31027 .58414 m .31155 .58582 L .31232 .58341 L F
.31027 .58414 m .30995 .58677 L .31155 .58582 L F
.533 .751 .976 r
.30281 .51976 m .30305 .51747 L .30024 .51837 L F
.30281 .51976 m .30477 .51904 L .30305 .51747 L F
.529 .675 .931 r
.30281 .51976 m .30621 .52087 L .30477 .51904 L F
0 .358 .829 r
.37435 .52295 m .37081 .51999 L .37163 .52143 L F
.406 .576 .907 r
.40329 .56302 m .40362 .5647 L .4019 .56504 L F
.377 .328 .676 r
.40362 .5647 m .40453 .56717 L .4019 .56504 L F
.358 .017 .243 r
.71257 .30943 m .70968 .31257 L .7104 .30982 L F
0 0 0 r
.20664 .56497 m .20392 .56824 L .20569 .56677 L F
.244 .053 .411 r
.20569 .56677 m .20761 .5636 L .20664 .56497 L F
.505 .809 1 r
.3099 .51052 m .31235 .50995 L .31406 .51108 L F
.87 .834 .809 r
.31235 .50995 m .31143 .51331 L .31406 .51108 L F
.665 .618 .792 r
.42698 .50092 m .42464 .50387 L .42427 .50156 L F
.545 .445 .693 r
.42658 .5026 m .42464 .50387 L .42698 .50092 L F
.421 .272 .572 r
.34236 .56801 m .3444 .56422 L .34268 .56518 L F
.996 .821 .464 r
.40796 .59049 m .40723 .58607 L .40718 .58966 L F
.957 .785 .339 r
.40696 .59117 m .40796 .59049 L .40718 .58966 L F
.40696 .59117 m .40767 .59329 L .40796 .59049 L F
.619 .319 .439 r
.57364 .45376 m .57216 .45628 L .56951 .45623 L F
.638 .34 .45 r
.57601 .45574 m .57364 .45376 L .57601 .45382 L F
.57601 .45574 m .57216 .45628 L .57364 .45376 L F
.181 0 0 r
.29139 .61224 m .29416 .61159 L .29549 .60931 L F
0 0 .221 r
.29549 .60931 m .29731 .60832 L .29758 .60572 L F
.293 0 .087 r
.29549 .60931 m .29672 .61095 L .29731 .60832 L F
.29549 .60931 m .29416 .61159 L .29672 .61095 L F
.58 .579 .817 r
.42451 .53286 m .42739 .5358 L .42692 .53245 L F
0 0 .159 r
.42739 .5358 m .43001 .53285 L .42692 .53245 L F
.42739 .5358 m .42831 .53588 L .43001 .53285 L F
.383 .357 .706 r
.35412 .68523 m .35143 .68242 L .35389 .68204 L F
.679 .978 .851 r
.34249 .63657 m .34174 .63807 L .34083 .63796 L F
.2 0 .247 r
.26232 .55163 m .25963 .55476 L .26039 .55262 L F
.632 .547 .741 r
.44225 .57082 m .44378 .57506 L .43996 .57426 L F
.621 .556 .76 r
.44356 .57716 m .43996 .57426 L .44378 .57506 L F
.748 .34 .276 r
.39136 .56281 m .39267 .56552 L .39037 .5641 L F
.353 .237 .58 r
.32462 .57712 m .32442 .58084 L .32257 .58097 L F
.359 .483 .848 r
.32442 .58084 m .32514 .58322 L .32257 .58097 L F
.655 .723 .899 r
.32514 .58322 m .32282 .58348 L .32257 .58097 L F
.618 .935 .961 r
.37804 .58745 m .38022 .58814 L .38259 .58679 L F
.075 .015 .478 r
.20392 .56824 m .2051 .57007 L .20569 .56677 L F
.20392 .56824 m .20405 .57096 L .2051 .57007 L F
.757 .49 .53 r
.30249 .53875 m .30612 .5363 L .30275 .53606 L F
.30249 .53875 m .30603 .53958 L .30612 .5363 L F
.51 .287 .512 r
.30612 .5363 m .3085 .53869 L .3084 .53579 L F
.30612 .5363 m .30603 .53958 L .3085 .53869 L F
.47 .363 .651 r
.38637 .6449 m .38782 .64677 L .38848 .64384 L F
.785 .675 .743 r
.38848 .64384 m .38782 .64677 L .38637 .6449 L F
.627 .773 .95 r
.72592 .3375 m .72291 .33822 L .7223 .33576 L F
.436 .035 .179 r
.6855 .3652 m .68812 .36623 L .68543 .36654 L F
.6855 .3652 m .68831 .36475 L .68812 .36623 L F
.587 .415 .616 r
.24554 .58051 m .24787 .57671 L .24573 .57751 L F
.619 .476 .665 r
.6572 .41533 m .65752 .41865 L .65506 .41985 L F
0 0 0 r
.65506 .41985 m .65599 .41979 L .65519 .42195 L F
.65506 .41985 m .65669 .41906 L .65599 .41979 L F
.858 .846 .384 r
.65537 .42043 m .65599 .41979 L .65591 .41885 L F
.65513 .42115 m .65599 .41979 L .65537 .42043 L F
0 0 0 r
.65669 .41906 m .65752 .41865 L .65599 .41979 L F
.888 .82 .775 r
.41101 .50434 m .40998 .50823 L .40728 .50643 L F
0 0 .371 r
.4103 .50888 m .40998 .50823 L .41137 .50678 L F
.769 .759 .843 r
.57946 .42756 m .5834 .4282 L .58113 .42916 L F
.841 .659 .656 r
.70475 .32954 m .70459 .33243 L .70735 .33199 L F
.063 .128 .619 r
.20133 .58395 m .20298 .58573 L .20274 .5832 L F
.753 .739 .84 r
.38218 .66015 m .38627 .66029 L .38465 .65812 L F
.776 .758 .837 r
.38423 .66155 m .38442 .66337 L .38472 .66215 L F
.38442 .66337 m .38457 .66471 L .38472 .66215 L F
.657 .216 .192 r
.38472 .66215 m .38627 .66029 L .38519 .66025 L F
.38472 .66215 m .38519 .66025 L .38218 .66015 L F
.195 .47 .888 r
.38465 .65812 m .38627 .66029 L .38701 .65895 L F
.092 .333 .807 r
.38812 .66131 m .38627 .66029 L .38701 .65895 L F
.657 .87 .494 r
.38701 .65895 m .38627 .66029 L .38472 .66215 L F
.385 .162 .448 r
.31812 .59568 m .31561 .59963 L .31604 .59643 L F
.229 .471 .882 r
.64943 .39902 m .65137 .40188 L .65302 .40226 L F
.224 .745 .772 r
.70829 .34777 m .70482 .3484 L .70711 .34686 L F
.748 .919 .949 r
.71144 .34596 m .70829 .34777 L .70711 .34686 L F
.779 .757 .833 r
.70122 .31631 m .70418 .31387 L .70045 .31336 L F
.808 .693 .739 r
.65673 .35491 m .65808 .35862 L .65465 .35831 L F
.732 .525 .612 r
.65808 .35862 m .65394 .36062 L .65465 .35831 L F
.65808 .35862 m .65804 .36125 L .65394 .36062 L F
.73 .531 .622 r
.31893 .55909 m .32077 .56168 L .32146 .55962 L F
.31893 .55909 m .3188 .56186 L .32077 .56168 L F
.633 .596 .794 r
.65935 .41156 m .66008 .41542 L .6572 .41533 L F
.414 0 0 r
.6572 .41533 m .65883 .41666 L .65752 .41865 L F
.6572 .41533 m .66008 .41542 L .65883 .41666 L F
.608 .709 .916 r
.30477 .51904 m .30621 .52087 L .30861 .52014 L F
.365 .132 .421 r
.2301 .57092 m .2276 .57403 L .22801 .57135 L F
.629 .93 .97 r
.34526 .66155 m .35008 .66054 L .34818 .65932 L F
.231 0 0 r
.3914 .59623 m .38768 .59788 L .3889 .59676 L F
.526 .92 .884 r
.27656 .52102 m .2712 .52262 L .27486 .52072 L F
.643 .941 .96 r
.27874 .51979 m .27656 .52102 L .27486 .52072 L F
.079 0 0 r
.34441 .59582 m .34561 .5942 L .34759 .59333 L F
.828 .397 0 r
.41464 .50855 m .41336 .50753 L .41137 .50678 L F
.657 .309 .372 r
.41268 .50975 m .4153 .51015 L .41464 .50855 L F
.828 .397 0 r
.41464 .50855 m .4153 .51015 L .41336 .50753 L F
.819 .699 .733 r
.33466 .51971 m .33618 .52342 L .33868 .52023 L F
.553 .716 .948 r
.30253 .62534 m .30491 .6248 L .30351 .62338 L F
.978 .774 .562 r
.30846 .65352 m .30946 .6571 L .3078 .65641 L F
0 .077 .624 r
.31014 .65564 m .30946 .6571 L .30846 .65352 L F
.536 .87 .992 r
.3078 .65641 m .30946 .6571 L .31014 .65564 L F
.683 .877 .971 r
.39937 .6786 m .40288 .67841 L .40143 .67735 L F
.871 .671 .629 r
.39924 .68115 m .40288 .67841 L .39937 .6786 L F
.39924 .68115 m .40214 .6818 L .40288 .67841 L F
.856 .899 .865 r
.40143 .67735 m .40288 .67841 L .40457 .67572 L F
.703 .924 .595 r
.39257 .70211 m .39506 .69901 L .39328 .70065 L F
.566 .863 .552 r
.39328 .70065 m .39506 .69901 L .39659 .69738 L F
.482 .001 .038 r
.3504 .63471 m .35389 .63419 L .35148 .63543 L F
.185 .258 .706 r
.35551 .6339 m .35389 .63419 L .35327 .63122 L F
0 0 0 r
.35148 .63543 m .35389 .63419 L .35551 .6339 L F
.392 0 .16 r
.37977 .56782 m .37798 .57065 L .37521 .57093 L F
.274 0 0 r
.38234 .5684 m .37798 .57065 L .37977 .56782 L F
.614 .311 .433 r
.59845 .44687 m .59414 .44985 L .59439 .44757 L F
.59845 .44687 m .59674 .44984 L .59414 .44985 L F
.678 .385 .471 r
.6007 .44975 m .59845 .44687 L .60065 .44699 L F
.6007 .44975 m .59674 .44984 L .59845 .44687 L F
0 0 0 r
.24863 .54777 m .24977 .54749 L .25219 .54609 L F
.25219 .54609 m .25219 .54675 L .25399 .54497 L F
.25219 .54609 m .24977 .54749 L .25219 .54675 L F
.802 .832 .875 r
.66427 .34268 m .65953 .34434 L .66268 .34118 L F
.798 .631 .675 r
.65896 .3518 m .65673 .35491 L .65696 .35209 L F
.898 .902 .82 r
.70247 .29163 m .69883 .2934 L .70147 .29021 L F
.70247 .29163 m .70003 .29489 L .69883 .2934 L F
.983 .897 .648 r
.703 .28906 m .70247 .29163 L .70147 .29021 L F
.648 .218 .212 r
.42868 .57219 m .43145 .57346 L .43351 .57215 L F
.458 0 .026 r
.43351 .57215 m .43582 .57313 L .43594 .57078 L F
.43351 .57215 m .43145 .57346 L .43582 .57313 L F
.296 .22 .599 r
.44126 .5355 m .44098 .5388 L .43935 .53965 L F
.755 .513 .566 r
.44098 .5388 m .43767 .54109 L .43935 .53965 L F
0 0 0 r
.21185 .55865 m .20917 .56176 L .2107 .56054 L F
0 0 .276 r
.21348 .55506 m .21185 .55865 L .21297 .55749 L F
.149 0 .235 r
.2107 .56054 m .21297 .55749 L .21185 .55865 L F
0 .117 .662 r
.26139 .6208 m .26204 .62119 L .26209 .62225 L F
0 .426 .839 r
.26349 .62203 m .26209 .62225 L .26204 .62119 L F
.26349 .62203 m .26477 .62327 L .26209 .62225 L F
.254 .477 .881 r
.37039 .63464 m .37335 .63715 L .37406 .63465 L F
.629 .379 .521 r
.37639 .63355 m .37406 .63465 L .37498 .63355 L F
0 0 0 r
.37498 .63355 m .37406 .63465 L .37335 .63715 L F
.649 .369 .481 r
.58795 .45038 m .58515 .45249 L .58525 .45095 L F
.849 .905 .495 r
.39921 .69174 m .3978 .69369 L .39769 .69542 L F
.797 .776 .27 r
.39769 .69542 m .39721 .69583 L .39659 .69738 L F
.39769 .69542 m .3978 .69369 L .39721 .69583 L F
.32 0 .239 r
.20761 .5636 m .2107 .56054 L .20917 .56176 L F
.628 .944 .732 r
.32116 .61906 m .31813 .62185 L .31887 .62058 L F
.292 0 .251 r
.27171 .56468 m .26883 .56734 L .26965 .56529 L F
.469 .33 .609 r
.42495 .55179 m .4249 .55464 L .42268 .55331 L F
.719 .63 .757 r
.64478 .40057 m .6472 .40011 L .64567 .39587 L F
.711 .58 .706 r
.6444 .40281 m .6472 .40011 L .64478 .40057 L F
.518 .289 .507 r
.64732 .40263 m .6472 .40011 L .6444 .40281 L F
.513 .513 .793 r
.64567 .39587 m .6472 .40011 L .64943 .39902 L F
.354 .168 .485 r
.64943 .39902 m .6472 .40011 L .64732 .40263 L F
.161 0 .017 r
.29758 .60572 m .29968 .60546 L .30102 .60324 L F
.295 0 .088 r
.30102 .60324 m .30211 .60483 L .3029 .60204 L F
.30102 .60324 m .29968 .60546 L .30211 .60483 L F
.163 .01 .413 r
.20226 .57441 m .20379 .5736 L .20405 .57096 L F
.279 .144 .512 r
.20207 .57698 m .20379 .5736 L .20226 .57441 L F
.098 0 0 r
.36507 .71375 m .36984 .71325 L .36729 .71366 L F
.692 .273 0 r
.36984 .71325 m .36992 .71365 L .36729 .71366 L F
.37002 .71355 m .3716 .71627 L .36992 .71365 L F
.863 .788 .775 r
.36992 .71365 m .3716 .71627 L .37396 .71163 L F
0 0 0 r
.36992 .71365 m .37225 .713 L .3697 .71388 L F
.36992 .71365 m .3697 .71388 L .36941 .71398 L F
.692 .273 0 r
.36984 .71325 m .37002 .71355 L .36992 .71365 L F
.68 .978 .859 r
.62048 .3966 m .62322 .39523 L .62182 .39513 L F
.868 .717 .196 r
.39723 .54303 m .39744 .54453 L .39771 .54233 L F
0 0 .323 r
.39723 .54303 m .39747 .54395 L .39744 .54453 L F
.39747 .54395 m .39834 .54726 L .39744 .54453 L F
.732 .657 .102 r
.3974 .54551 m .39744 .54453 L .39734 .54614 L F
.39771 .54233 m .39744 .54453 L .3974 .54551 L F
0 0 .461 r
.39834 .54726 m .39734 .54614 L .39744 .54453 L F
.39834 .54726 m .39936 .54885 L .39734 .54614 L F
.543 .835 .504 r
.39423 .69957 m .39328 .70065 L .39448 .69931 L F
.618 .936 .959 r
.39064 .70184 m .39205 .70204 L .39328 .70065 L F
.044 0 0 r
.39064 .70184 m .39328 .70065 L .39155 .70245 L F
.543 .835 .504 r
.39155 .70245 m .39328 .70065 L .39423 .69957 L F
.618 .936 .959 r
.39205 .70204 m .39257 .70211 L .39328 .70065 L F
.531 0 0 r
.25724 .62995 m .25584 .63079 L .2529 .62878 L F
.25584 .63079 m .25551 .63074 L .2529 .62878 L F
.839 .775 .79 r
.25743 .63023 m .25684 .63093 L .25616 .63067 L F
0 0 0 r
.25743 .63023 m .25584 .63079 L .25724 .62995 L F
.839 .775 .79 r
.25684 .63093 m .25551 .63074 L .25383 .62979 L F
.25551 .63074 m .25409 .63053 L .25383 .62979 L F
.473 0 0 r
.2529 .62878 m .25551 .63074 L .25383 .62979 L F
.25551 .63074 m .25569 .63087 L .25383 .62979 L F
0 0 0 r
.25743 .63023 m .25569 .63087 L .25584 .63079 L F
.839 .775 .79 r
.25743 .63023 m .25616 .63067 L .25383 .62979 L F
.25684 .63093 m .25499 .63314 L .25409 .63053 L F
.531 0 0 r
.25584 .63079 m .25569 .63087 L .25551 .63074 L F
.704 .342 .359 r
.25724 .62995 m .26142 .6312 L .25963 .63019 L F
0 0 0 r
.25743 .63023 m .25724 .62995 L .25963 .63019 L F
.704 .342 .359 r
.25724 .62995 m .25847 .63113 L .26142 .6312 L F
.342 .774 .969 r
.28337 .51919 m .28287 .52013 L .28135 .51886 L F
.28337 .51919 m .28523 .51987 L .28287 .52013 L F
.522 0 0 r
.59444 .40943 m .59603 .40996 L .59359 .40903 L F
0 .385 .783 r
.59747 .41014 m .59603 .40996 L .59444 .40943 L F
.59747 .41014 m .59898 .4112 L .59603 .40996 L F
.668 .723 .89 r
.37314 .64711 m .37628 .64759 L .37526 .64627 L F
.618 .538 .742 r
.37314 .64711 m .37691 .65036 L .37628 .64759 L F
.795 .76 .821 r
.37628 .64759 m .3783 .64332 L .37526 .64627 L F
.37628 .64759 m .37966 .64465 L .3783 .64332 L F
.725 .401 .431 r
.67378 .37126 m .67 .37311 L .67003 .3716 L F
.67378 .37126 m .6741 .37373 L .67 .37311 L F
.608 .317 .45 r
.67652 .37319 m .6741 .37373 L .67378 .37126 L F
.582 .333 .504 r
.67643 .37095 m .67652 .37319 L .67378 .37126 L F
.297 0 0 r
.2451 .6243 m .2405 .62252 L .24243 .62358 L F
.788 .375 .267 r
.55771 .4481 m .55395 .44858 L .55361 .44676 L F
.55771 .4481 m .55773 .44962 L .55395 .44858 L F
.392 .187 .478 r
.73368 .33237 m .73635 .32865 L .73513 .33058 L F
0 0 0 r
.73635 .32865 m .73971 .32617 L .7374 .32767 L F
.648 .281 .335 r
.58853 .43899 m .59249 .43728 L .58914 .4385 L F
.003 .558 .817 r
.34763 .49966 m .34999 .50006 L .35191 .50063 L F
.329 0 0 r
.34999 .50006 m .35392 .50144 L .35191 .50063 L F
0 .398 .841 r
.23091 .60481 m .22916 .60254 L .22959 .60275 L F
.622 .058 0 r
.26477 .62327 m .26844 .62478 L .26608 .62531 L F
0 0 0 r
.34157 .59085 m .33819 .59305 L .33976 .59222 L F
.34157 .59085 m .34177 .59151 L .3432 .5892 L F
.34157 .59085 m .33976 .59222 L .34177 .59151 L F
.624 .834 .981 r
.36591 .5286 m .36346 .52947 L .36756 .52998 L F
.698 .957 .949 r
.36958 .52804 m .36756 .52998 L .36829 .52806 L F
0 0 .325 r
.36756 .52998 m .3686 .5309 L .36829 .52806 L F
.36756 .52998 m .36745 .53257 L .3686 .5309 L F
.971 .879 .499 r
.4059 .58779 m .40718 .58966 L .40723 .58607 L F
.873 .578 .057 r
.40696 .59117 m .40718 .58966 L .4059 .58779 L F
.397 .612 .936 r
.21923 .58881 m .22057 .59102 L .21834 .59092 L F
.603 .292 .416 r
.57601 .45382 m .57866 .45585 L .57601 .45574 L F
.619 .281 .376 r
.5789 .45398 m .57866 .45585 L .57601 .45382 L F
.6 .623 .846 r
.63033 .421 m .62866 .42208 L .62802 .41941 L F
0 0 .26 r
.62979 .42255 m .62866 .42208 L .63033 .421 L F
.62979 .42255 m .62834 .42426 L .62866 .42208 L F
.448 .323 .618 r
.36548 .55659 m .36315 .55564 L .36652 .55475 L F
.36548 .55659 m .36318 .55899 L .36315 .55564 L F
.075 .231 .722 r
.29524 .64929 m .29433 .65074 L .29328 .64758 L F
0 .281 .781 r
.28797 .62249 m .28799 .62263 L .2876 .62413 L F
.28797 .62249 m .28877 .62083 L .28799 .62263 L F
0 0 0 r
.34963 .57291 m .35383 .5714 L .35387 .5742 L F
.844 .567 .518 r
.56159 .45074 m .55774 .45218 L .55773 .44962 L F
.56159 .45074 m .56164 .45315 L .55774 .45218 L F
.698 .446 .539 r
.56569 .45311 m .56164 .45315 L .56159 .45074 L F
.298 0 0 r
.3633 .714 m .36339 .71506 L .36071 .71551 L F
.3633 .714 m .36507 .71375 L .36339 .71506 L F
.308 0 .269 r
.3115 .5454 m .3109 .54793 L .30806 .54874 L F
0 .175 .695 r
.31037 .54239 m .31273 .54438 L .3115 .5454 L F
.188 .082 .493 r
.31273 .54438 m .3109 .54793 L .3115 .5454 L F
.574 .144 .186 r
.29318 .5401 m .29643 .54091 L .29576 .54016 L F
.467 .537 .845 r
.29531 .54087 m .29441 .54231 L .29318 .5401 L F
.29524 .54098 m .29583 .54143 L .29441 .54231 L F
.29583 .54143 m .29694 .54225 L .29493 .54229 L F
.29583 .54143 m .29493 .54229 L .29441 .54231 L F
.29547 .541 m .29694 .54225 L .29524 .54098 L F
.29632 .54115 m .29694 .54225 L .29531 .54087 L F
.265 0 .29 r
.29197 .54201 m .29363 .54282 L .29621 .54106 L F
.29591 .54104 m .29621 .54106 L .29643 .54091 L F
.29197 .54201 m .29621 .54106 L .29591 .54104 L F
.467 .537 .845 r
.29576 .54016 m .29632 .54115 L .29531 .54087 L F
.574 .144 .186 r
.29318 .5401 m .29583 .54106 L .29643 .54091 L F
.369 .837 .853 r
.29643 .54091 m .2989 .54007 L .29576 .54016 L F
.664 .631 .807 r
.29899 .54159 m .29694 .54225 L .29625 .54103 L F
.29675 .54059 m .29625 .54103 L .29576 .54016 L F
.564 .898 .653 r
.29643 .54091 m .29621 .54106 L .29625 .54103 L F
.29643 .54091 m .29625 .54103 L .29646 .54084 L F
.664 .631 .807 r
.29899 .54159 m .29625 .54103 L .29675 .54059 L F
.564 .898 .653 r
.29646 .54084 m .29625 .54103 L .29648 .54081 L F
.369 .837 .853 r
.29643 .54091 m .29646 .54086 L .2989 .54007 L F
.664 .631 .807 r
.29899 .54159 m .29697 .54069 L .2989 .54007 L F
.29697 .54069 m .29576 .54016 L .2989 .54007 L F
.369 .837 .853 r
.29646 .54086 m .2967 .54026 L .2989 .54007 L F
.564 .898 .653 r
.29648 .54081 m .29363 .54282 L .2967 .54026 L F
.29621 .54106 m .29363 .54282 L .29648 .54081 L F
.467 .537 .845 r
.29531 .54087 m .29547 .541 L .29524 .54098 L F
.574 .144 .186 r
.29531 .54087 m .29197 .54201 L .29583 .54106 L F
.29318 .5401 m .29308 .54026 L .29531 .54087 L F
.29308 .54026 m .29197 .54201 L .29531 .54087 L F
.467 .537 .845 r
.29576 .54016 m .29531 .54087 L .29318 .5401 L F
.494 .212 .415 r
.29694 .54225 m .29348 .54505 L .29441 .54231 L F
.909 .901 .805 r
.69883 .2934 m .70003 .29489 L .69763 .29817 L F
.694 .766 .907 r
.35568 .6072 m .35428 .60792 L .35304 .60526 L F
.592 .489 .705 r
.35428 .60792 m .35564 .61125 L .357 .60818 L F
.35428 .60792 m .35558 .61254 L .35564 .61125 L F
0 0 0 r
.57443 .43093 m .57706 .42826 L .57614 .42966 L F
.991 .739 .386 r
.57614 .42966 m .57706 .42826 L .57581 .42709 L F
.525 .829 1 r
.57946 .42756 m .57706 .42826 L .57581 .42709 L F
.368 0 0 r
.57614 .42966 m .57706 .42826 L .57885 .42866 L F
.991 .739 .386 r
.57614 .42966 m .57706 .42826 L .57581 .42709 L F
.607 .693 .904 r
.58113 .42916 m .57706 .42826 L .57946 .42756 L F
.685 .556 .702 r
.74223 .3263 m .7395 .32348 L .73971 .32617 L F
.74223 .3263 m .74223 .32363 L .7395 .32348 L F
0 0 0 r
.34225 .54954 m .34102 .55147 L .34318 .54977 L F
.502 .318 .564 r
.31584 .56503 m .31829 .56715 L .31835 .56446 L F
.31584 .56503 m .31575 .56784 L .31829 .56715 L F
.533 .54 .808 r
.28026 .52622 m .2816 .52991 L .284 .52915 L F
.387 .093 .339 r
.2816 .52991 m .28344 .5317 L .284 .52915 L F
.2816 .52991 m .28088 .53261 L .28344 .5317 L F
.283 0 0 r
.24491 .55942 m .2445 .55976 L .24362 .56028 L F
.561 .657 .9 r
.24328 .56048 m .24576 .56165 L .24362 .56028 L F
.283 0 0 r
.2445 .55976 m .24151 .56218 L .24362 .56028 L F
.561 .657 .9 r
.24136 .55958 m .24328 .56048 L .24362 .56028 L F
.239 .372 .797 r
.39251 .56824 m .39395 .56678 L .39267 .56552 L F
.503 .388 .656 r
.39531 .57039 m .39251 .56824 L .39395 .56678 L F
.39531 .57039 m .3929 .571 L .39251 .56824 L F
.476 .809 .999 r
.37506 .61215 m .37917 .61265 L .37751 .61162 L F
.978 .793 .586 r
.37751 .61162 m .37917 .61265 L .37857 .60947 L F
.293 0 0 r
.28026 .52622 m .27569 .52713 L .27778 .52721 L F
.619 .905 .984 r
.33819 .59305 m .33209 .59457 L .33743 .5963 L F
0 0 0 r
.33976 .59222 m .33819 .59305 L .33743 .5963 L F
.228 .727 .909 r
.30729 .62427 m .31129 .62455 L .30876 .6247 L F
.30729 .62427 m .31129 .62455 L .30876 .6247 L F
0 0 .466 r
.39341 .53474 m .39488 .53846 L .39342 .53577 L F
.31 .683 .977 r
.39217 .58042 m .39246 .57895 L .39018 .57687 L F
.39217 .58042 m .39383 .5802 L .39246 .57895 L F
.286 0 0 r
.59854 .38701 m .60003 .38691 L .59726 .38628 L F
.079 .639 .717 r
.59989 .38689 m .60003 .38691 L .59854 .38701 L F
.60255 .38664 m .60003 .38691 L .59989 .38689 L F
.16 0 0 r
.60003 .38691 m .60155 .38723 L .60011 .38691 L F
.60003 .38691 m .60011 .38691 L .59726 .38628 L F
.979 .8 .592 r
.60081 .38955 m .60155 .38723 L .60003 .38691 L F
.60081 .38955 m .60155 .38723 L .60003 .38691 L F
.905 .69 .6 r
.33734 .50747 m .3333 .50659 L .33443 .50371 L F
.892 .58 .449 r
.33734 .50747 m .33414 .50897 L .3333 .50659 L F
.379 0 0 r
.33805 .50737 m .33414 .50897 L .33734 .50747 L F
.919 .524 .183 r
.70178 .33833 m .70247 .34047 L .70339 .33948 L F
.96 .822 .391 r
.70247 .34047 m .7029 .34217 L .70339 .33948 L F
.71 .67 .809 r
.39885 .51009 m .39617 .50812 L .39923 .50748 L F
.709 .643 .781 r
.40283 .5089 m .39885 .51009 L .39923 .50748 L F
0 0 .116 r
.25481 .57991 m .25328 .58374 L .25287 .58049 L F
.25481 .57991 m .25438 .58246 L .25328 .58374 L F
.573 .912 .687 r
.25438 .58246 m .25154 .58479 L .25328 .58374 L F
.572 .895 .986 r
.33197 .56177 m .33194 .56042 L .33143 .5618 L F
.802 .999 .799 r
.33508 .55706 m .33194 .56042 L .33197 .56177 L F
.566 .4 .616 r
.34426 .6535 m .34615 .65032 L .34436 .65069 L F
.64 .168 0 r
.38797 .61478 m .38634 .61271 L .38642 .61481 L F
0 0 0 r
.71763 .36378 m .71841 .36193 L .71963 .35997 L F
.863 .896 .857 r
.34834 .54622 m .34424 .54851 L .3455 .54529 L F
0 .278 .779 r
.21846 .60683 m .22036 .60729 L .21749 .60511 L F
.21846 .60683 m .22096 .60868 L .22036 .60729 L F
0 0 0 r
.63175 .39533 m .63032 .39717 L .63264 .39418 L F
.6293 .39884 m .63032 .39717 L .63175 .39533 L F
.73 .227 0 r
.38939 .52907 m .39265 .53256 L .39098 .53146 L F
.518 .273 .484 r
.32963 .52344 m .33208 .52301 L .33256 .52053 L F
.757 .672 .768 r
.33208 .52301 m .33466 .51971 L .33256 .52053 L F
.287 0 0 r
.36507 .71375 m .36537 .71521 L .36339 .71506 L F
.36507 .71375 m .36729 .71366 L .36537 .71521 L F
.003 0 .358 r
.26637 .53433 m .26526 .53727 L .26523 .53678 L F
.367 0 .093 r
.33738 .57138 m .33965 .57134 L .3369 .57114 L F
.33738 .57138 m .33793 .5734 L .33965 .57134 L F
0 0 0 r
.33717 .57692 m .33793 .5734 L .33738 .57138 L F
.806 .359 0 r
.60275 .40309 m .60501 .40622 L .60347 .40525 L F
.344 .3 .665 r
.37379 .68679 m .37065 .68563 L .37421 .68487 L F
.37379 .68679 m .37178 .68903 L .37065 .68563 L F
0 0 .2 r
.27711 .62948 m .27642 .62756 L .27909 .62704 L F
.27711 .62948 m .27622 .63116 L .27642 .62756 L F
.664 .892 .98 r
.29134 .51888 m .28928 .52004 L .2876 .51912 L F
.525 .821 .999 r
.34551 .50672 m .34077 .50627 L .3426 .50612 L F
.914 .978 .768 r
.37966 .64465 m .38107 .64073 L .3783 .64332 L F
0 .078 .638 r
.30111 .52853 m .30122 .53108 L .29987 .52819 L F
.30111 .52853 m .30269 .5318 L .30122 .53108 L F
.333 .092 .392 r
.25733 .56803 m .25557 .57211 L .25468 .57138 L F
0 0 .298 r
.25553 .57275 m .25468 .57138 L .25557 .57211 L F
.25553 .57275 m .25418 .57418 L .25468 .57138 L F
.624 .472 .655 r
.32648 .58634 m .3239 .58677 L .32282 .58348 L F
.397 .427 .774 r
.34842 .57839 m .34958 .58126 L .35041 .57958 L F
.678 .821 .38 r
.35041 .57958 m .34958 .58126 L .34846 .58329 L F
0 0 .363 r
.60944 .42989 m .60882 .42862 L .61039 .42814 L F
.35 .152 .465 r
.3237 .63199 m .32558 .6336 L .32605 .63182 L F
.408 .739 .992 r
.56213 .42267 m .55866 .42169 L .56179 .42019 L F
.352 .436 .808 r
.56379 .42018 m .56213 .42267 L .56179 .42019 L F
.56379 .42018 m .56516 .424 L .56213 .42267 L F
0 0 0 r
.35447 .63926 m .35316 .64018 L .35524 .63866 L F
.247 .399 .818 r
.35316 .64018 m .35245 .64123 L .35225 .64081 L F
0 0 .034 r
.35167 .64416 m .35245 .64123 L .35316 .64018 L F
.35167 .64416 m .35316 .64018 L .35147 .64163 L F
0 0 0 r
.35147 .64163 m .35316 .64018 L .35447 .63926 L F
.247 .399 .818 r
.35316 .64018 m .35225 .64081 L .35063 .63746 L F
.524 .213 .381 r
.33731 .52939 m .33998 .5292 L .34068 .52714 L F
0 0 .011 r
.34068 .52714 m .33998 .5292 L .34189 .52574 L F
.168 0 .133 r
.61377 .44461 m .61059 .44676 L .61376 .44367 L F
.185 .341 .788 r
.6152 .44225 m .61376 .44367 L .61481 .4441 L F
.173 .328 .78 r
.61481 .4441 m .61662 .44588 L .6152 .44225 L F
.146 .309 .772 r
.6152 .44225 m .61662 .44588 L .61775 .44419 L F
.029 0 .121 r
.61579 .44343 m .61376 .44367 L .6152 .44225 L F
.61579 .44343 m .61377 .44461 L .61376 .44367 L F
.497 .329 .583 r
.33187 .59915 m .33209 .59457 L .33219 .59651 L F
.33187 .59915 m .33505 .59887 L .33209 .59457 L F
.392 .295 .625 r
.33209 .59457 m .33505 .59887 L .33662 .59797 L F
0 .159 .699 r
.60469 .42038 m .60272 .41858 L .60263 .41709 L F
.608 .378 .542 r
.25968 .5703 m .25733 .56803 L .26003 .56791 L F
.25968 .5703 m .25557 .57211 L .25733 .56803 L F
0 .025 .546 r
.37931 .60767 m .37857 .60947 L .37782 .60591 L F
.544 .102 .149 r
.37606 .60805 m .37931 .60767 L .37782 .60591 L F
.653 .787 .945 r
.39518 .65995 m .39291 .66172 L .39119 .65928 L F
.123 .542 .919 r
.25934 .61911 m .25785 .61969 L .25675 .6178 L F
.25934 .61911 m .26139 .6208 L .25785 .61969 L F
.447 .248 .517 r
.3239 .58677 m .32355 .58879 L .32086 .5898 L F
.25 0 .31 r
.32355 .58879 m .32086 .59253 L .32086 .5898 L F
.819 .785 .82 r
.30039 .53648 m .30057 .53942 L .30275 .53606 L F
.431 .506 .835 r
.30057 .53942 m .30086 .53526 L .29873 .53628 L F
.30057 .53942 m .30249 .53875 L .30086 .53526 L F
.531 .131 .228 r
.42692 .53245 m .42275 .53459 L .42451 .53286 L F
.527 .818 .999 r
.2866 .52633 m .29089 .52703 L .28947 .52543 L F
.735 .285 .183 r
.29312 .52621 m .28947 .52543 L .29089 .52703 L F
.422 .281 .582 r
.22185 .57721 m .22198 .58046 L .21987 .58084 L F
.618 .538 .742 r
.37314 .64711 m .37495 .65202 L .37691 .65036 L F
.401 .196 .484 r
.37691 .65036 m .37495 .65202 L .37659 .65303 L F
.62 .886 .989 r
.31672 .6695 m .31876 .67033 L .3211 .66922 L F
.551 .447 .688 r
.37363 .5471 m .3716 .54625 L .37443 .54472 L F
.37363 .5471 m .37171 .54899 L .3716 .54625 L F
.686 .934 .967 r
.62252 .39872 m .61951 .40144 L .61944 .39906 L F
.62252 .39872 m .6236 .39958 L .61951 .40144 L F
.694 .772 .911 r
.62482 .37486 m .62171 .37691 L .62063 .37422 L F
.601 .408 .593 r
.37595 .58401 m .37871 .58165 L .37866 .58079 L F
.361 .331 .689 r
.63117 .39227 m .62943 .39382 L .63038 .39424 L F
.632 .814 .391 r
.31908 .66027 m .31721 .66339 L .31787 .66216 L F
0 .194 .723 r
.31721 .66339 m .31984 .66597 L .31787 .66216 L F
.475 .317 .587 r
.31721 .66339 m .31812 .66636 L .31984 .66597 L F
.086 .435 .875 r
.37828 .51494 m .37773 .51545 L .37634 .51411 L F
.736 .643 .755 r
.65394 .36062 m .65544 .36443 L .65305 .36513 L F
.711 .548 .666 r
.65305 .36513 m .65544 .36443 L .65293 .36771 L F
.702 .535 .659 r
.65544 .36443 m .65549 .36744 L .65293 .36771 L F
.713 .631 .765 r
.65804 .36125 m .65544 .36443 L .65394 .36062 L F
.65 .537 .714 r
.65804 .36125 m .65902 .36445 L .65544 .36443 L F
.675 .537 .689 r
.65902 .36445 m .65549 .36744 L .65544 .36443 L F
.52 .361 .606 r
.34818 .63801 m .35063 .63746 L .3504 .63471 L F
.463 .205 .437 r
.34999 .6404 m .35063 .63746 L .34818 .63801 L F
.52 .361 .606 r
.34818 .63801 m .35063 .63746 L .3504 .63471 L F
.575 .592 .832 r
.35063 .63746 m .34999 .6404 L .34818 .63801 L F
.558 .835 .997 r
.7166 .35535 m .71939 .35457 L .71911 .35311 L F
.489 .263 .498 r
.71932 .35695 m .71939 .35457 L .7166 .35535 L F
.282 .338 .743 r
.71932 .35695 m .7166 .35535 L .71911 .35311 L F
.878 .938 .566 r
.65422 .4058 m .6526 .40915 L .65288 .40694 L F
.711 .401 0 r
.65302 .40226 m .65422 .4058 L .65374 .40458 L F
.952 .907 .531 r
.65374 .40458 m .65422 .4058 L .65288 .40694 L F
.67 .62 .791 r
.22201 .56431 m .22018 .56805 L .21961 .56504 L F
.429 .105 .313 r
.29566 .62772 m .29235 .63107 L .29271 .6272 L F
.243 .512 .907 r
.23615 .60911 m .2321 .60609 L .23436 .60792 L F
0 .47 .844 r
.23436 .60792 m .23602 .60841 L .23615 .60911 L F
.063 .57 .884 r
.23615 .60911 m .23602 .60841 L .23753 .60928 L F
0 0 0 r
.23397 .56137 m .23128 .56338 L .23132 .56135 L F
.23397 .56137 m .23256 .56305 L .23128 .56338 L F
.98 .77 .548 r
.23132 .56197 m .23256 .56305 L .23397 .56137 L F
0 0 0 r
.23256 .56305 m .23264 .56296 L .23397 .56137 L F
.44 0 .091 r
.23508 .56005 m .23397 .56137 L .23132 .56135 L F
.802 .671 .719 r
.22916 .55995 m .23397 .56137 L .23293 .55689 L F
.603 .389 .563 r
.23128 .56338 m .22863 .56145 L .23132 .56135 L F
.98 .77 .548 r
.23132 .56197 m .23337 .56151 L .22916 .55995 L F
.23337 .56151 m .23397 .56137 L .23343 .56121 L F
.23337 .56151 m .23343 .56121 L .22916 .55995 L F
.006 .121 .635 r
.23293 .55689 m .23397 .56137 L .23514 .55967 L F
0 0 0 r
.23264 .56296 m .23514 .55967 L .23397 .56137 L F
.23321 .56221 m .23354 .56221 L .23514 .55967 L F
.475 .837 .582 r
.23555 .56038 m .23256 .56305 L .23397 .56137 L F
.23745 .5592 m .2358 .5605 L .23555 .56038 L F
.2358 .5605 m .23256 .56305 L .23555 .56038 L F
.644 .137 .028 r
.24136 .55958 m .24017 .56023 L .23797 .55913 L F
.24136 .55958 m .23797 .55913 L .238 .55907 L F
.24017 .56023 m .23939 .56015 L .23778 .55903 L F
.643 .179 .137 r
.23778 .55903 m .2398 .56043 L .23745 .5592 L F
.445 0 .04 r
.23777 .56156 m .23758 .56019 L .2398 .56043 L F
.23758 .56019 m .23745 .5592 L .23833 .55966 L F
.23758 .56019 m .23833 .55966 L .2398 .56043 L F
0 0 0 r
.23933 .55779 m .24083 .55687 L .24202 .55672 L F
.23933 .55779 m .23754 .55997 L .24083 .55687 L F
.445 0 .04 r
.2362 .56063 m .23585 .56043 L .23745 .5592 L F
.823 .586 .58 r
.2367 .56041 m .23669 .56101 L .23745 .56008 L F
.963 .714 .511 r
.23637 .56073 m .23669 .56101 L .2367 .56041 L F
.445 0 .04 r
.23758 .56019 m .23475 .56127 L .23756 .56003 L F
.681 .462 .582 r
.23637 .56073 m .23658 .56086 L .23644 .56079 L F
.285 .482 .876 r
.23256 .56305 m .23402 .56637 L .23128 .56338 L F
0 .084 .636 r
.23256 .56305 m .23474 .56539 L .2349 .56654 L F
.432 .669 .961 r
.23402 .56637 m .22855 .56456 L .23128 .56338 L F
.723 .304 .252 r
.23238 .56356 m .23474 .56539 L .23256 .56305 L F
.23193 .56476 m .23262 .56492 L .23238 .56356 L F
.23294 .56499 m .23474 .56539 L .233 .56404 L F
.23262 .56492 m .23294 .56499 L .23238 .56356 L F
.23294 .56499 m .233 .56404 L .23238 .56356 L F
.743 .528 .603 r
.23263 .56349 m .23324 .5642 L .23371 .56219 L F
.445 0 .04 r
.23544 .56192 m .23397 .56214 L .2373 .56033 L F
.2337 .56219 m .23368 .56218 L .23386 .56209 L F
.23397 .56214 m .23386 .56209 L .2373 .56033 L F
.23379 .56213 m .23374 .56211 L .2373 .56033 L F
0 0 0 r
.23745 .56008 m .23669 .56101 L .23719 .56051 L F
.615 .91 .631 r
.23719 .56051 m .23669 .56101 L .23697 .56068 L F
.075 0 .439 r
.23777 .56156 m .23697 .56068 L .23669 .56101 L F
.681 .462 .582 r
.23644 .56079 m .23777 .56156 L .23669 .56101 L F
.445 0 .04 r
.23544 .56192 m .2373 .56033 L .23719 .56051 L F
.475 .837 .582 r
.2358 .5605 m .23356 .5622 L .23256 .56305 L F
.743 .528 .603 r
.23263 .56349 m .23371 .56219 L .23355 .5622 L F
.475 .837 .582 r
.23356 .5622 m .23354 .56221 L .23353 .56222 L F
.445 0 .04 r
.2368 .56049 m .23354 .56221 L .23475 .56127 L F
.23686 .56055 m .23354 .56221 L .2368 .56049 L F
.681 .462 .582 r
.23658 .56086 m .23777 .56156 L .23644 .56079 L F
.445 0 .04 r
.23777 .56156 m .23544 .56192 L .23668 .56092 L F
.23777 .56156 m .23668 .56092 L .23758 .56019 L F
.681 .462 .582 r
.23716 .56112 m .23777 .56156 L .23658 .56086 L F
.23593 .56032 m .23716 .56112 L .23658 .56086 L F
.475 .837 .582 r
.23745 .5592 m .23585 .56043 L .2358 .5605 L F
.011 0 0 r
.23745 .5592 m .23548 .55991 L .23778 .55903 L F
.23745 .5592 m .23397 .56137 L .23548 .55991 L F
.963 .714 .511 r
.23514 .55967 m .23637 .56073 L .23675 .55664 L F
.681 .462 .582 r
.23514 .55967 m .23597 .56027 L .23593 .56032 L F
.23597 .56027 m .23716 .56112 L .23593 .56032 L F
.475 .837 .582 r
.23585 .56043 m .23356 .5622 L .2358 .5605 L F
.23356 .5622 m .23353 .56222 L .23256 .56305 L F
.743 .528 .603 r
.23355 .5622 m .23356 .5622 L .23357 .56216 L F
.445 0 .04 r
.23366 .56219 m .23357 .5622 L .23374 .56211 L F
.743 .528 .603 r
.23356 .5622 m .23366 .56219 L .23359 .56217 L F
.23356 .5622 m .23359 .56217 L .23357 .56216 L F
.445 0 .04 r
.23366 .56219 m .23374 .56211 L .23379 .56213 L F
.196 .241 .683 r
.23626 .56333 m .23474 .56539 L .23397 .56215 L F
.328 .194 .542 r
.23324 .5642 m .23341 .564 L .23371 .56219 L F
.754 .614 .703 r
.23353 .56407 m .23474 .56539 L .23322 .56505 L F
.23404 .56244 m .23432 .5636 L .23353 .56407 L F
.23432 .5636 m .23474 .56539 L .23353 .56407 L F
.23404 .56244 m .23322 .56505 L .23331 .56457 L F
0 0 .111 r
.23337 .56416 m .23464 .56504 L .23626 .56333 L F
.23324 .5642 m .23327 .56422 L .23337 .56416 L F
.23327 .56422 m .23464 .56504 L .23337 .56416 L F
.754 .614 .703 r
.23404 .56244 m .23315 .56503 L .23347 .56375 L F
.328 .194 .542 r
.23341 .564 m .23468 .56252 L .23374 .5622 L F
.23341 .564 m .23374 .5622 L .23371 .56219 L F
.754 .614 .703 r
.23331 .56457 m .23322 .56505 L .23315 .56503 L F
.328 .194 .542 r
.23324 .5642 m .23337 .56416 L .23337 .56416 L F
.754 .614 .703 r
.23347 .56375 m .23315 .56503 L .23294 .56499 L F
.328 .194 .542 r
.23337 .56416 m .23626 .56333 L .23625 .56321 L F
.23337 .56416 m .23626 .56333 L .23337 .56416 L F
.963 .714 .511 r
.23637 .56073 m .2367 .56041 L .23675 .55664 L F
.445 0 .04 r
.23751 .55963 m .2362 .56063 L .23745 .5592 L F
.2367 .56041 m .2362 .56063 L .23751 .55963 L F
.2362 .56063 m .23475 .56127 L .23585 .56043 L F
.681 .462 .582 r
.23514 .55967 m .23658 .56086 L .23637 .56073 L F
.44 0 .091 r
.23548 .55991 m .23397 .56137 L .23508 .56005 L F
.681 .462 .582 r
.23514 .55967 m .23379 .56181 L .23777 .56156 L F
.23379 .56181 m .23395 .56211 L .23777 .56156 L F
.445 0 .04 r
.23397 .56214 m .2337 .56219 L .23386 .56209 L F
.2337 .56219 m .23366 .56219 L .23368 .56218 L F
.681 .462 .582 r
.23357 .56216 m .23366 .56219 L .23777 .56156 L F
.49 .823 .999 r
.23384 .56161 m .23623 .56072 L .23777 .56156 L F
.196 .241 .683 r
.23491 .5626 m .23397 .56215 L .23384 .56161 L F
.328 .194 .542 r
.23468 .56252 m .23489 .56227 L .23371 .56219 L F
.196 .241 .683 r
.23637 .5632 m .23404 .56161 L .23777 .56156 L F
.328 .194 .542 r
.23489 .56227 m .23623 .56072 L .23425 .56187 L F
.23489 .56227 m .23425 .56187 L .23371 .56219 L F
.196 .241 .683 r
.23626 .56333 m .23489 .56227 L .23637 .5632 L F
.23489 .56227 m .23404 .56161 L .23637 .5632 L F
.328 .194 .542 r
.23489 .56227 m .23625 .56321 L .23623 .56072 L F
.23475 .56244 m .23581 .56298 L .23489 .56227 L F
.23581 .56298 m .23625 .56321 L .23489 .56227 L F
.23324 .5642 m .23612 .56325 L .23468 .56252 L F
.23612 .56325 m .23625 .56321 L .23544 .56285 L F
.196 .241 .683 r
.23626 .56333 m .23397 .56215 L .23544 .56285 L F
.328 .194 .542 r
.23612 .56325 m .23544 .56285 L .23468 .56252 L F
.196 .241 .683 r
.23626 .56333 m .23544 .56285 L .23588 .56306 L F
.328 .194 .542 r
.23417 .56192 m .23425 .56187 L .23384 .56161 L F
.196 .241 .683 r
.23489 .56227 m .23384 .56161 L .23404 .56161 L F
.328 .194 .542 r
.23425 .56187 m .23623 .56072 L .23384 .56161 L F
.196 .241 .683 r
.23626 .56333 m .23384 .56161 L .23489 .56227 L F
.328 .194 .542 r
.23544 .56285 m .23625 .56321 L .23475 .56244 L F
.196 .241 .683 r
.23588 .56306 m .23544 .56285 L .23384 .56161 L F
.23544 .56285 m .23491 .5626 L .23475 .56244 L F
.23544 .56285 m .23475 .56244 L .23384 .56161 L F
.328 .194 .542 r
.23468 .56252 m .23544 .56285 L .23475 .56244 L F
.681 .462 .582 r
.23379 .56181 m .23357 .56216 L .23395 .56211 L F
.754 .614 .703 r
.23384 .56161 m .23404 .56244 L .23361 .56291 L F
.328 .194 .542 r
.23371 .56219 m .23374 .56217 L .23384 .56161 L F
.743 .528 .603 r
.23357 .56216 m .23371 .56219 L .23379 .56186 L F
.23366 .56219 m .23371 .56219 L .23357 .56216 L F
.445 0 .04 r
.23366 .56219 m .23354 .56221 L .23357 .5622 L F
.681 .462 .582 r
.23357 .56216 m .23354 .56221 L .23366 .56219 L F
.743 .528 .603 r
.23263 .56349 m .23379 .56186 L .23384 .56161 L F
0 0 0 r
.23354 .56221 m .23354 .56221 L .23357 .56216 L F
.603 .389 .563 r
.23128 .56338 m .22855 .56456 L .22863 .56145 L F
.411 0 .138 r
.22884 .56523 m .23256 .56305 L .23132 .56197 L F
.22884 .56523 m .23193 .56476 L .23256 .56305 L F
.743 .528 .603 r
.23132 .56197 m .23193 .56476 L .23324 .5642 L F
.754 .614 .703 r
.23384 .56161 m .23361 .56291 L .23193 .56476 L F
.328 .194 .542 r
.23374 .56217 m .23417 .56192 L .23384 .56161 L F
0 0 .111 r
.23324 .5642 m .23321 .56437 L .23327 .56422 L F
.754 .614 .703 r
.23404 .56244 m .23294 .56499 L .23193 .56476 L F
0 0 .111 r
.23327 .56422 m .23286 .56625 L .23464 .56504 L F
.23321 .56437 m .23286 .56625 L .23327 .56422 L F
.23286 .56625 m .2326 .56767 L .23279 .56743 L F
.23286 .56625 m .23279 .56743 L .23464 .56504 L F
.378 .073 .315 r
.23138 .56703 m .2326 .56767 L .23286 .56625 L F
.23265 .56509 m .23286 .56625 L .23324 .5642 L F
.23138 .56703 m .23286 .56625 L .23265 .56509 L F
.445 0 .04 r
.23719 .56051 m .2373 .56033 L .23758 .56019 L F
0 0 0 r
.23754 .55997 m .23745 .56008 L .23735 .56035 L F
.445 0 .04 r
.23758 .56019 m .23686 .56055 L .2368 .56049 L F
0 0 0 r
.23745 .56008 m .23719 .56051 L .23735 .56035 L F
.615 .91 .631 r
.23732 .56038 m .23719 .56051 L .2371 .56053 L F
.23719 .56051 m .23697 .56068 L .2371 .56053 L F
0 0 0 r
.23754 .55997 m .23735 .56035 L .24083 .55687 L F
.615 .91 .631 r
.23732 .56038 m .2371 .56053 L .23941 .55788 L F
.075 0 .439 r
.23704 .56076 m .23941 .55788 L .23697 .56068 L F
.23777 .56156 m .23865 .55959 L .23704 .56076 L F
.615 .91 .631 r
.24083 .55687 m .23732 .56038 L .23941 .55788 L F
.075 0 .439 r
.23865 .55959 m .23941 .55788 L .23704 .56076 L F
.445 0 .04 r
.23756 .56003 m .2367 .56041 L .23751 .55963 L F
.823 .586 .58 r
.23671 .55989 m .2367 .56041 L .23754 .55997 L F
.2367 .56041 m .23745 .56008 L .23754 .55997 L F
.644 .137 .028 r
.238 .55907 m .23797 .55913 L .23778 .55903 L F
.24017 .56023 m .2398 .56043 L .23939 .56015 L F
.706 .71 .851 r
.23933 .55779 m .23778 .55903 L .23675 .55664 L F
.823 .586 .58 r
.23675 .55664 m .23671 .55989 L .23933 .55779 L F
.23671 .55989 m .23754 .55997 L .23933 .55779 L F
0 0 0 r
.23256 .56305 m .23312 .56257 L .23321 .56221 L F
.23312 .56257 m .23354 .56221 L .23321 .56221 L F
.743 .528 .603 r
.23132 .56197 m .23263 .56349 L .23384 .56161 L F
0 0 0 r
.23354 .56221 m .23357 .56216 L .23514 .55967 L F
.929 .619 .433 r
.54821 .44122 m .54649 .44303 L .54623 .44005 L F
.54821 .44122 m .54886 .44402 L .54649 .44303 L F
.674 .648 .816 r
.28565 .64258 m .28566 .64386 L .28337 .64439 L F
.459 .138 .334 r
.45372 .57421 m .45254 .57683 L .45013 .5772 L F
.602 .484 .69 r
.45537 .56976 m .4564 .57409 L .45372 .57421 L F
.577 .272 .415 r
.4564 .57409 m .45254 .57683 L .45372 .57421 L F
.497 .093 .206 r
.32477 .55113 m .32785 .5511 L .32889 .54914 L F
.143 0 .03 r
.32889 .54914 m .32785 .5511 L .33002 .55006 L F
.526 .854 .997 r
.7232 .3466 m .7216 .34832 L .72019 .34713 L F
.7232 .3466 m .72478 .34745 L .7216 .34832 L F
.7232 .3466 m .7216 .34832 L .72019 .34713 L F
.7232 .3466 m .72478 .34745 L .7216 .34832 L F
.803 .961 .639 r
.44852 .57042 m .44607 .57397 L .44751 .57217 L F
.813 .922 .909 r
.37293 .6794 m .36883 .68043 L .37093 .67822 L F
.664 .561 .728 r
.63194 .37853 m .62976 .38097 L .6288 .37674 L F
.826 .831 .852 r
.67186 .33293 m .66762 .33436 L .67042 .3314 L F
.854 .852 .84 r
.67454 .32976 m .67186 .33293 L .67042 .3314 L F
.759 .537 .596 r
.36197 .61499 m .36623 .61534 L .36622 .6126 L F
0 .034 .581 r
.60042 .41337 m .59972 .41325 L .59898 .4112 L F
.60042 .41337 m .60099 .41472 L .59972 .41325 L F
.403 .806 .591 r
.33279 .67844 m .33506 .6769 L .33664 .67583 L F
.015 0 0 r
.33623 .6771 m .33664 .67583 L .33506 .6769 L F
.33623 .6771 m .3385 .67555 L .33664 .67583 L F
.51 .431 .702 r
.43786 .52239 m .43499 .52511 L .43596 .52343 L F
.43786 .52239 m .43833 .52645 L .43499 .52511 L F
.518 .512 .789 r
.43833 .52645 m .43689 .52894 L .43499 .52511 L F
.478 .511 .813 r
.43564 .51618 m .43494 .52054 L .4344 .51648 L F
.43564 .51618 m .43697 .51995 L .43494 .52054 L F
.454 .413 .723 r
.43697 .51995 m .43786 .52239 L .43494 .52054 L F
.455 .413 .723 r
.43786 .52239 m .43596 .52343 L .43494 .52054 L F
.516 .585 .862 r
.43131 .56477 m .42825 .56439 L .42783 .56467 L F
.817 .531 .504 r
.34778 .51616 m .34306 .51837 L .34323 .51526 L F
.34778 .51616 m .34731 .51997 L .34306 .51837 L F
.441 .87 .925 r
.34917 .51528 m .34816 .51513 L .34778 .51616 L F
.779 .69 .145 r
.34753 .51607 m .34778 .51616 L .34816 .51513 L F
.34753 .51607 m .34731 .51997 L .34778 .51616 L F
.582 .926 .732 r
.35279 .51271 m .34917 .51528 L .35092 .5143 L F
.436 .867 .925 r
.35196 .51432 m .34917 .51528 L .35279 .51271 L F
.35196 .51432 m .35004 .51473 L .34917 .51528 L F
.35004 .51473 m .34816 .51513 L .34917 .51528 L F
.914 .77 .688 r
.34778 .51616 m .34782 .51614 L .34917 .51528 L F
.34782 .51614 m .35092 .5143 L .34917 .51528 L F
.7 .52 .641 r
.7054 .30437 m .71033 .3037 L .70834 .30519 L F
.474 .472 .775 r
.71033 .3037 m .71064 .30032 L .70834 .30519 L F
.687 .259 .225 r
.62518 .44027 m .62841 .4425 L .62913 .44016 L F
0 0 0 r
.62841 .4425 m .63168 .43952 L .62913 .44016 L F
0 .276 .78 r
.61723 .44759 m .61943 .44791 L .61662 .44588 L F
.21 .547 .93 r
.61723 .44759 m .62177 .44996 L .61974 .44944 L F
0 .276 .78 r
.61723 .44759 m .61974 .44944 L .61943 .44791 L F
.733 .639 .754 r
.54482 .43164 m .54582 .43489 L .54232 .43392 L F
.85 .628 .601 r
.54582 .43489 m .54277 .43659 L .54232 .43392 L F
.54582 .43489 m .54607 .4375 L .54277 .43659 L F
.656 .485 .64 r
.54582 .43489 m .54841 .43449 L .54607 .4375 L F
.54 .518 .78 r
.35295 .54161 m .35047 .54265 L .34863 .53806 L F
.354 .277 .63 r
.35295 .54161 m .35141 .54461 L .35047 .54265 L F
.35141 .54461 m .35295 .54161 L .35047 .54265 L F
.719 .928 .594 r
.40138 .68853 m .39971 .69041 L .39921 .69174 L F
.708 .867 .459 r
.39971 .69041 m .3978 .69369 L .39921 .69174 L F
.185 0 .179 r
.33964 .59947 m .33891 .60206 L .33656 .6027 L F
.31 .04 .332 r
.33964 .59947 m .34235 .59659 L .3417 .59862 L F
.053 0 .129 r
.34066 .60099 m .33964 .59947 L .3417 .59862 L F
.34066 .60099 m .33891 .60206 L .33964 .59947 L F
0 0 .316 r
.29699 .63454 m .29519 .6385 L .29715 .63718 L F
0 0 0 r
.29715 .63718 m .29519 .6385 L .29433 .63999 L F
.81 .682 .722 r
.70045 .31336 m .70418 .31387 L .70324 .31021 L F
.908 .983 .764 r
.70418 .31387 m .70597 .30944 L .70324 .31021 L F
.451 .341 .637 r
.4331 .53952 m .43474 .5441 L .43433 .54255 L F
.705 .468 .563 r
.4331 .53952 m .43433 .54255 L .43178 .54133 L F
.403 .004 .163 r
.28042 .555 m .27791 .5567 L .27725 .55535 L F
.28042 .555 m .27897 .5567 L .27791 .5567 L F
.687 .457 .569 r
.28312 .55475 m .27897 .5567 L .28042 .555 L F
.722 .453 .52 r
.6645 .36137 m .66865 .36156 L .66898 .36396 L F
.567 .457 .688 r
.65626 .38329 m .65722 .38726 L .65415 .38782 L F
.701 .832 .946 r
.30793 .51213 m .3037 .5124 L .30595 .51047 L F
.756 .828 .908 r
.3099 .51052 m .30793 .51213 L .30595 .51047 L F
.623 .43 .6 r
.67899 .36754 m .68018 .37062 L .67643 .37095 L F
.596 .43 .628 r
.68225 .36812 m .68018 .37062 L .67899 .36754 L F
.95 .912 .745 r
.33252 .53597 m .32975 .53713 L .32882 .53514 L F
.33252 .53597 m .33054 .53971 L .32975 .53713 L F
.51 .314 .55 r
.33503 .53303 m .33486 .53589 L .33252 .53597 L F
.33503 .53303 m .33486 .53589 L .33252 .53597 L F
.86 .88 .851 r
.70565 .28611 m .703 .28906 L .7023 .28795 L F
.70565 .28611 m .7023 .28795 L .70268 .28745 L F
.70565 .28611 m .70268 .28745 L .70451 .28507 L F
0 0 0 r
.70294 .2871 m .70293 .28711 L .70293 .28711 L F
.70293 .28711 m .70277 .28724 L .70279 .28729 L F
.834 .999 .813 r
.70214 .28769 m .70277 .28724 L .70451 .28507 L F
.86 .88 .851 r
.70268 .28745 m .70214 .28769 L .70435 .28525 L F
0 0 0 r
.70451 .28507 m .70277 .28724 L .70294 .2871 L F
.86 .88 .851 r
.70268 .28745 m .70294 .2871 L .70451 .28507 L F
.852 .915 .875 r
.7069 .28267 m .70565 .28611 L .70451 .28507 L F
0 0 0 r
.70451 .28507 m .70294 .2871 L .70565 .28486 L F
.86 .88 .851 r
.70294 .2871 m .70435 .28525 L .70451 .28507 L F
0 0 0 r
.70565 .28486 m .70294 .2871 L .70327 .28823 L F
.70294 .2871 m .70293 .28711 L .70327 .28823 L F
.70293 .28711 m .70279 .28729 L .70327 .28823 L F
.86 .88 .851 r
.70268 .28745 m .7023 .28795 L .70214 .28769 L F
.983 .897 .648 r
.703 .28906 m .70147 .29021 L .70214 .28769 L F
.471 .84 .991 r
.26728 .52839 m .26289 .52811 L .26467 .52884 L F
.524 .047 .065 r
.27377 .64028 m .27502 .63862 L .2779 .64003 L F
.601 .032 0 r
.27948 .64103 m .28018 .64228 L .2779 .64003 L F
.27948 .64103 m .28191 .64298 L .28018 .64228 L F
.734 .635 .749 r
.66329 .37071 m .66456 .37402 L .66084 .37404 L F
.678 .443 .558 r
.66456 .37402 m .66065 .37661 L .66084 .37404 L F
.66456 .37402 m .6649 .37716 L .66065 .37661 L F
.612 .395 .562 r
.66741 .37617 m .66456 .37402 L .66739 .37388 L F
.66741 .37617 m .6649 .37716 L .66456 .37402 L F
.603 .725 .931 r
.26728 .52839 m .27143 .52989 L .26974 .52781 L F
.543 .324 .533 r
.26871 .53282 m .27125 .53252 L .27143 .52989 L F
.26871 .53282 m .27125 .53252 L .27143 .52989 L F
.509 .647 .919 r
.27143 .52989 m .27225 .52708 L .26974 .52781 L F
.27143 .52989 m .27353 .52906 L .27225 .52708 L F
.133 0 .412 r
.27294 .53113 m .27143 .52989 L .27353 .52906 L F
.27294 .53113 m .27125 .53252 L .27143 .52989 L F
.27294 .53113 m .27143 .52989 L .27353 .52906 L F
.27294 .53113 m .27125 .53252 L .27143 .52989 L F
.81 .335 .081 r
.42383 .59485 m .4211 .59272 L .42449 .59352 L F
.603 .858 .508 r
.42567 .59249 m .42449 .59352 L .42615 .59218 L F
.42567 .59249 m .42383 .59485 L .42449 .59352 L F
0 .327 .67 r
.35808 .50355 m .35998 .50431 L .36175 .50508 L F
0 .348 .706 r
.36268 .50529 m .36459 .50621 L .36175 .50508 L F
.546 .891 .982 r
.27958 .60498 m .27707 .60575 L .27789 .60626 L F
.27958 .60498 m .27707 .60575 L .27789 .60626 L F
.909 .621 .126 r
.41852 .58399 m .41815 .58552 L .41799 .5827 L F
.41852 .58399 m .4189 .58658 L .41815 .58552 L F
0 0 0 r
.34765 .55908 m .34662 .56079 L .349 .55733 L F
.248 .087 .457 r
.30781 .60921 m .3077 .61258 L .30603 .61258 L F
.233 .176 .585 r
.3078 .61417 m .30603 .61258 L .3077 .61258 L F
.3078 .61417 m .30655 .61562 L .30603 .61258 L F
.53 .1 .17 r
.2276 .57403 m .22365 .57511 L .22502 .57441 L F
.761 .862 .924 r
.58973 .41696 m .58837 .42003 L .58653 .41963 L F
.58973 .41696 m .59118 .41849 L .58837 .42003 L F
.164 .404 .847 r
.59322 .42448 m .58837 .42003 L .59118 .41849 L F
.718 .223 .061 r
.36949 .67668 m .37093 .67822 L .3677 .67721 L F
.385 .009 .197 r
.34086 .5744 m .33966 .57675 L .33717 .57692 L F
.608 .525 .735 r
.3459 .5723 m .34294 .57367 L .34219 .57107 L F
.34522 .57184 m .34219 .57107 L .34173 .5695 L F
.3459 .5723 m .34219 .57107 L .34522 .57184 L F
.354 0 .181 r
.34293 .57384 m .34086 .5744 L .34294 .57367 L F
.547 .227 .377 r
.34751 .57427 m .34294 .57367 L .3459 .5723 L F
.34751 .57427 m .34285 .57551 L .34294 .57367 L F
.481 .668 .946 r
.34403 .5708 m .34535 .57084 L .34173 .5695 L F
.608 .525 .735 r
.3459 .5723 m .34173 .5695 L .34535 .57084 L F
.572 .35 .54 r
.34619 .57203 m .34805 .57278 L .34587 .57221 L F
0 0 0 r
.34631 .57197 m .34568 .57233 L .34605 .57212 L F
.34638 .57192 m .3462 .57203 L .34631 .57197 L F
.3462 .57203 m .34568 .57233 L .34631 .57197 L F
.572 .35 .54 r
.34587 .57221 m .34805 .57278 L .3459 .5723 L F
.34573 .57185 m .34619 .57203 L .34587 .57221 L F
.392 .136 .402 r
.346 .57195 m .3462 .57203 L .34638 .57192 L F
.635 .074 0 r
.34963 .57291 m .34866 .57283 L .34668 .57164 L F
.34677 .57159 m .34668 .57164 L .34595 .5712 L F
.34963 .57291 m .34668 .57164 L .34677 .57159 L F
0 0 0 r
.34568 .57233 m .34247 .57418 L .34605 .57212 L F
.34638 .57192 m .34451 .57307 L .34495 .57269 L F
.572 .35 .54 r
.34637 .57158 m .34665 .57209 L .34631 .57158 L F
0 .135 .652 r
.3463 .57154 m .34631 .57158 L .34651 .57174 L F
.34631 .57158 m .34638 .57192 L .34646 .57181 L F
.34631 .57158 m .34646 .57181 L .34651 .57174 L F
.572 .35 .54 r
.34637 .57158 m .34797 .57272 L .34665 .57209 L F
.747 .387 .371 r
.34577 .5716 m .34638 .57192 L .34631 .57158 L F
.572 .35 .54 r
.34631 .57158 m .34665 .57209 L .34564 .57161 L F
.635 .074 0 r
.34963 .57291 m .34595 .5712 L .3458 .57106 L F
.34866 .57283 m .34637 .57158 L .34535 .57084 L F
0 .135 .652 r
.3463 .57154 m .34651 .57174 L .34724 .57077 L F
.747 .387 .371 r
.34173 .5695 m .34045 .57243 L .346 .57195 L F
.34577 .5716 m .346 .57195 L .34638 .57192 L F
.572 .35 .54 r
.34564 .57161 m .34584 .5717 L .34573 .57185 L F
.34584 .5717 m .34596 .57188 L .34573 .57185 L F
.747 .387 .371 r
.34173 .5695 m .346 .57195 L .34577 .5716 L F
.572 .35 .54 r
.34584 .5717 m .34633 .57194 L .34596 .57188 L F
.34633 .57194 m .34797 .57272 L .34623 .57204 L F
.34633 .57194 m .34623 .57204 L .34573 .57185 L F
.392 .136 .402 r
.34045 .57243 m .34612 .57207 L .34574 .57198 L F
0 0 0 r
.34646 .57181 m .34495 .57269 L .34651 .57174 L F
.34638 .57192 m .34632 .57196 L .34646 .57181 L F
.392 .136 .402 r
.34045 .57243 m .34247 .57418 L .34612 .57207 L F
0 0 0 r
.34632 .57196 m .34495 .57269 L .34646 .57181 L F
.572 .35 .54 r
.34797 .57272 m .34805 .57278 L .34573 .57185 L F
.392 .136 .402 r
.34574 .57198 m .34612 .57207 L .3462 .57203 L F
.34574 .57198 m .3462 .57203 L .346 .57195 L F
0 0 0 r
.34651 .57174 m .34495 .57269 L .34724 .57077 L F
0 .135 .652 r
.34564 .56847 m .3463 .57154 L .34724 .57077 L F
.635 .074 0 r
.3458 .57106 m .34595 .5712 L .34535 .57084 L F
.34866 .57283 m .34805 .57278 L .34637 .57158 L F
.747 .387 .371 r
.34173 .5695 m .34577 .5716 L .34576 .57124 L F
.6 .65 .871 r
.34173 .5695 m .34535 .57084 L .34564 .56847 L F
.747 .387 .371 r
.34231 .56935 m .34576 .57124 L .34564 .56847 L F
.34173 .5695 m .34576 .57124 L .34231 .56935 L F
.572 .35 .54 r
.34535 .57084 m .34637 .57158 L .34564 .57161 L F
.747 .387 .371 r
.34577 .5716 m .34631 .57158 L .34564 .56847 L F
.354 0 .181 r
.34285 .57551 m .34138 .57469 L .34293 .57384 L F
.34285 .57551 m .33966 .57675 L .34086 .5744 L F
.365 .024 .247 r
.3413 .57569 m .34368 .57519 L .34451 .57307 L F
.878 .844 .383 r
.34451 .57307 m .3442 .57381 L .34448 .5731 L F
.514 .313 .545 r
.34173 .5695 m .34564 .56847 L .34428 .56733 L F
.666 .244 .235 r
.34564 .56847 m .34639 .56952 L .34428 .56733 L F
.604 .259 .358 r
.34428 .56733 m .34639 .56952 L .34806 .56689 L F
0 0 0 r
.34806 .56689 m .34639 .56952 L .34851 .56801 L F
0 .135 .652 r
.34564 .56847 m .34724 .57077 L .34639 .56952 L F
.461 .388 .689 r
.34851 .56801 m .34639 .56952 L .34724 .57077 L F
.743 .659 .767 r
.34802 .56732 m .34451 .57307 L .34312 .56968 L F
0 .153 .686 r
.34451 .57307 m .34498 .57187 L .34312 .56968 L F
.878 .844 .383 r
.34451 .57307 m .34448 .5731 L .34498 .57187 L F
0 0 0 r
.34605 .57212 m .34456 .57298 L .34451 .57307 L F
.34456 .57298 m .34247 .57418 L .34451 .57307 L F
.354 0 .181 r
.34138 .57469 m .34086 .5744 L .34293 .57384 L F
.016 0 0 r
.23948 .56549 m .23804 .56731 L .24166 .56448 L F
.681 .604 .763 r
.44607 .57397 m .44356 .57716 L .44378 .57506 L F
.663 .578 .749 r
.44607 .57397 m .44743 .57752 L .44356 .57716 L F
.654 .482 .638 r
.44743 .57752 m .44456 .57927 L .44356 .57716 L F
.927 .58 .138 r
.41745 .57762 m .41692 .57892 L .4167 .5764 L F
.41745 .57762 m .41804 .58012 L .41692 .57892 L F
.56 .933 .906 r
.39321 .62688 m .39226 .62816 L .39423 .62691 L F
.977 .713 .463 r
.3906 .63006 m .39226 .62816 L .39321 .62688 L F
.3906 .63006 m .39227 .63109 L .39226 .62816 L F
.914 .923 .806 r
.39226 .62816 m .3954 .62554 L .39423 .62691 L F
.491 .84 .572 r
.34098 .65386 m .33838 .65605 L .34206 .6551 L F
.576 .371 .565 r
.34206 .6551 m .34426 .6535 L .34098 .65386 L F
.305 .035 .329 r
.3417 .59862 m .34235 .59659 L .34441 .59582 L F
0 0 .163 r
.41347 .5585 m .41323 .55697 L .4127 .55448 L F
.887 .651 .132 r
.41411 .56056 m .41323 .55697 L .41347 .5585 L F
.722 .452 .518 r
.37178 .68903 m .3738 .69386 L .37597 .68862 L F
.233 0 0 r
.37756 .68929 m .37597 .68862 L .3738 .69386 L F
.37756 .68929 m .37798 .68832 L .37597 .68862 L F
0 0 .034 r
.21641 .55277 m .21809 .55016 L .21756 .55058 L F
0 0 0 r
.2169 .55109 m .21756 .55058 L .21949 .54903 L F
.57 .896 .641 r
.21756 .55058 m .21858 .54942 L .22047 .54805 L F
0 0 .034 r
.21809 .55016 m .21858 .54942 L .21756 .55058 L F
0 0 0 r
.21619 .55166 m .21756 .55058 L .2169 .55109 L F
.22195 .54572 m .21949 .54903 L .22109 .54732 L F
.509 .85 .579 r
.21949 .54903 m .22047 .54805 L .22109 .54732 L F
.21949 .54903 m .21756 .55058 L .22047 .54805 L F
.051 .02 .497 r
.31285 .58083 m .31371 .58004 L .31407 .57647 L F
.187 0 .364 r
.31285 .58083 m .31381 .58228 L .31371 .58004 L F
.31285 .58083 m .31232 .58341 L .31381 .58228 L F
.888 .829 .783 r
.59159 .41385 m .59302 .41579 L .59118 .41849 L F
.604 .416 .6 r
.59302 .41579 m .59352 .41792 L .59118 .41849 L F
.429 .149 .385 r
.62624 .43392 m .62417 .43639 L .62472 .43419 L F
.62624 .43392 m .62736 .43634 L .62417 .43639 L F
.285 .088 .427 r
.62922 .43507 m .62736 .43634 L .62642 .43431 L F
.62669 .4341 m .62642 .43431 L .62624 .43392 L F
.62922 .43507 m .62642 .43431 L .62669 .4341 L F
0 0 .439 r
.62721 .43357 m .62711 .43348 L .62744 .43351 L F
.62711 .43348 m .62489 .43148 L .62721 .43333 L F
.62711 .43348 m .62721 .43333 L .62744 .43351 L F
.397 .427 .774 r
.62916 .43251 m .62742 .43335 L .62791 .43388 L F
.62709 .43352 m .62624 .43392 L .62791 .43388 L F
0 0 .439 r
.62684 .43398 m .62744 .43351 L .62791 .43388 L F
.397 .427 .774 r
.62742 .43335 m .62709 .43352 L .62791 .43388 L F
.2 .359 .799 r
.6263 .43132 m .62759 .43337 L .62563 .4314 L F
.62759 .43337 m .62791 .43388 L .62742 .43335 L F
.62759 .43337 m .62742 .43335 L .62563 .4314 L F
.285 .088 .427 r
.62669 .4341 m .62624 .43392 L .62709 .43352 L F
0 0 .439 r
.62472 .43419 m .62791 .43388 L .62624 .43392 L F
.62472 .43419 m .62744 .43351 L .62684 .43398 L F
.285 .088 .427 r
.62669 .4341 m .62709 .43352 L .62742 .43335 L F
.431 .478 .808 r
.62916 .43251 m .62791 .43388 L .62759 .43337 L F
.285 .088 .427 r
.62759 .43337 m .62742 .43335 L .62916 .43251 L F
.431 .478 .808 r
.62916 .43251 m .62759 .43337 L .6263 .43132 L F
.285 .088 .427 r
.62779 .43339 m .62759 .43337 L .62916 .43251 L F
.2 .359 .799 r
.62742 .43335 m .62791 .43388 L .62721 .43333 L F
.285 .088 .427 r
.62669 .4341 m .62742 .43335 L .62779 .43339 L F
.62922 .43507 m .62669 .4341 L .62779 .43339 L F
.62919 .43356 m .62779 .43339 L .62916 .43251 L F
.62922 .43507 m .62779 .43339 L .62919 .43356 L F
.2 .359 .799 r
.62563 .4314 m .62742 .43335 L .62489 .43148 L F
.62742 .43335 m .62721 .43333 L .62489 .43148 L F
0 0 .439 r
.62472 .43419 m .62482 .43252 L .62721 .43357 L F
.62482 .43252 m .62489 .43148 L .62721 .43357 L F
0 0 .328 r
.74222 .32556 m .74223 .3263 L .73971 .32617 L F
.902 .925 .823 r
.70206 .30633 m .7054 .30437 L .70449 .30306 L F
.70206 .30633 m .7029 .30749 L .7054 .30437 L F
.619 .637 .847 r
.7054 .30437 m .7072 .29989 L .70449 .30306 L F
.7054 .30437 m .70834 .30519 L .7072 .29989 L F
0 .174 .695 r
.23182 .60492 m .2321 .60609 L .23091 .60481 L F
.23182 .60492 m .23436 .60792 L .2321 .60609 L F
.012 .264 .767 r
.33194 .56042 m .33323 .56293 L .33143 .5618 L F
.296 .231 .612 r
.33323 .56293 m .3319 .56488 L .33143 .5618 L F
.817 .777 .815 r
.39613 .59909 m .39242 .59911 L .39452 .59637 L F
.984 .881 .527 r
.39613 .59909 m .39448 .60108 L .39242 .59911 L F
.39613 .59909 m .3951 .60228 L .39448 .60108 L F
.749 .755 .858 r
.39681 .59726 m .39613 .59909 L .39452 .59637 L F
.348 .008 .239 r
.67003 .3716 m .67 .37311 L .66739 .37388 L F
.751 .673 .775 r
.65198 .36154 m .65305 .36513 L .6492 .36464 L F
.76 .59 .666 r
.65305 .36513 m .64883 .3672 L .6492 .36464 L F
.65305 .36513 m .65293 .36771 L .64883 .3672 L F
.736 .643 .755 r
.65394 .36062 m .65305 .36513 L .65198 .36154 L F
.709 .643 .781 r
.40283 .5089 m .39923 .50748 L .40063 .50668 L F
.603 .782 .966 r
.40525 .50791 m .40283 .5089 L .40063 .50668 L F
.09 .269 .753 r
.6089 .41199 m .61039 .41565 L .61144 .41398 L F
0 .066 .589 r
.61039 .41565 m .61237 .4161 L .61144 .41398 L F
.61039 .41565 m .61134 .41803 L .61237 .4161 L F
.438 .434 .757 r
.24787 .57671 m .24907 .57295 L .2496 .57477 L F
.662 .452 .59 r
.42647 .5462 m .42413 .54835 L .42428 .54577 L F
.363 .145 .443 r
.35595 .59683 m .35564 .59926 L .35804 .59605 L F
.651 .53 .703 r
.42882 .55514 m .42534 .55943 L .4249 .55464 L F
.42882 .55514 m .42869 .55818 L .42534 .55943 L F
.534 .264 .452 r
.42869 .55818 m .42622 .56096 L .42534 .55943 L F
.662 .489 .639 r
.43528 .56755 m .43594 .57078 L .43838 .5683 L F
.925 .869 .765 r
.68833 .31097 m .68698 .3135 L .68683 .30956 L F
.354 .277 .63 r
.35295 .54161 m .35317 .54508 L .35141 .54461 L F
.35141 .54461 m .35317 .54508 L .35295 .54161 L F
.664 .974 .856 r
.37061 .64854 m .37314 .64711 L .37191 .64698 L F
.633 .898 .985 r
.37314 .64711 m .37526 .64627 L .37334 .64528 L F
.829 .999 .791 r
.37191 .64698 m .37314 .64711 L .37334 .64528 L F
.569 .672 .908 r
.24415 .57297 m .24511 .56986 L .24296 .57022 L F
.236 0 0 r
.24708 .57206 m .24739 .57241 L .24415 .57297 L F
.569 .672 .908 r
.24415 .57297 m .24739 .57241 L .24511 .56986 L F
.678 .595 .756 r
.27791 .5567 m .27815 .56159 L .27547 .5617 L F
.617 .333 .464 r
.27815 .56159 m .27503 .5638 L .27547 .5617 L F
0 .158 .698 r
.23481 .6188 m .23508 .61733 L .23298 .61526 L F
0 .179 .713 r
.23481 .6188 m .2369 .62078 L .23508 .61733 L F
.12 0 .258 r
.29758 .60572 m .2989 .60742 L .29968 .60546 L F
.29758 .60572 m .29731 .60832 L .2989 .60742 L F
.634 .615 .814 r
.28817 .53273 m .28554 .53307 L .284 .52915 L F
.592 .363 .538 r
.28817 .53273 m .28545 .53505 L .28554 .53307 L F
.602 .893 .989 r
.25696 .56392 m .25642 .56552 L .25462 .56484 L F
.557 .934 .889 r
.2481 .52776 m .24785 .52686 L .25033 .52681 L F
.2481 .52776 m .24567 .52806 L .24785 .52686 L F
.75 .589 .676 r
.69172 .34852 m .69469 .34564 L .69057 .34471 L F
.578 .329 .503 r
.69172 .34852 m .69484 .34797 L .69469 .34564 L F
.384 .187 .485 r
.69469 .34564 m .69484 .34797 L .69717 .34474 L F
.669 .808 .949 r
.25147 .551 m .25335 .55239 L .25599 .55134 L F
.785 .675 .743 r
.38848 .64384 m .39011 .64761 L .38782 .64677 L F
.708 .64 .779 r
.39216 .64538 m .39011 .64761 L .38848 .64384 L F
.595 .075 0 r
.24362 .56028 m .2398 .56043 L .24136 .55958 L F
.025 0 .199 r
.58444 .43631 m .58224 .43779 L .58443 .4353 L F
.344 .356 .73 r
.58444 .43631 m .58508 .4398 L .58224 .43779 L F
.937 .925 .771 r
.36318 .55899 m .35977 .56072 L .36052 .55957 L F
.468 .252 .501 r
.3028 .55213 m .30258 .5547 L .3002 .55529 L F
.3028 .55213 m .30258 .5547 L .3002 .55529 L F
.498 .249 .467 r
.30532 .55179 m .30258 .5547 L .3028 .55213 L F
0 0 .038 r
.3028 .55213 m .3031 .5529 L .30334 .55034 L F
.3028 .55213 m .30258 .5547 L .3031 .5529 L F
.299 .144 .496 r
.36536 .5807 m .3675 .58247 L .36771 .57993 L F
.36536 .5807 m .36514 .58384 L .3675 .58247 L F
0 0 .29 r
.33723 .63645 m .33683 .63876 L .33744 .63634 L F
.953 .939 .733 r
.69515 .30163 m .69633 .2967 L .69763 .29817 L F
.909 .901 .805 r
.69883 .2934 m .69763 .29817 L .69633 .2967 L F
.397 .427 .774 r
.34842 .57839 m .35041 .57958 L .35055 .5756 L F
.313 .65 .97 r
.33221 .50352 m .33297 .50229 L .33096 .50261 L F
.33221 .50352 m .33443 .50371 L .33297 .50229 L F
.511 .813 1 r
.37384 .69533 m .37629 .69477 L .37205 .69416 L F
.37205 .69416 m .37629 .69477 L .37384 .69533 L F
.518 .512 .789 r
.43833 .52645 m .43935 .52857 L .43689 .52894 L F
.726 .703 .829 r
.65571 .37828 m .65196 .37771 L .65437 .37642 L F
.685 .681 .841 r
.65437 .37642 m .65827 .37723 L .65571 .37828 L F
.306 .111 .443 r
.3444 .56422 m .34662 .56079 L .34469 .56165 L F
.42 .279 .581 r
.30587 .59652 m .30798 .59557 L .30754 .59323 L F
.087 0 .043 r
.30511 .59861 m .30798 .59557 L .30587 .59652 L F
.48 .273 .521 r
.35309 .61567 m .35608 .61538 L .35558 .61254 L F
.468 .59 .892 r
.63106 .37629 m .6288 .37674 L .62706 .37334 L F
.664 .561 .728 r
.63194 .37853 m .6288 .37674 L .63106 .37629 L F
.176 .12 .55 r
.6263 .43132 m .62489 .43148 L .6257 .42765 L F
.05 .56 .878 r
.36824 .50781 m .36583 .50793 L .36459 .50621 L F
.36824 .50781 m .36925 .50854 L .36583 .50793 L F
.248 0 .075 r
.27502 .55614 m .27581 .55788 L .27615 .55709 L F
.418 0 0 r
.27401 .5553 m .27502 .55614 L .27725 .55535 L F
.444 .868 .746 r
.27725 .55535 m .27502 .55614 L .27701 .55507 L F
.248 0 .075 r
.27502 .55614 m .27615 .55709 L .27701 .55507 L F
.418 0 0 r
.27269 .55528 m .27502 .55614 L .27401 .5553 L F
.618 .532 .735 r
.27725 .55535 m .27924 .55151 L .27741 .55333 L F
.27725 .55535 m .28015 .55545 L .27924 .55151 L F
.444 .868 .746 r
.27725 .55535 m .27701 .55507 L .28015 .55545 L F
.015 .203 .713 r
.35567 .60501 m .35393 .60293 L .35703 .60308 L F
0 0 0 r
.35393 .60293 m .35304 .60526 L .35504 .60176 L F
.636 .231 .259 r
.40769 .51716 m .41006 .51915 L .40608 .51831 L F
.793 .867 .903 r
.33142 .4993 m .32792 .50121 L .33137 .49848 L F
0 0 0 r
.33137 .49848 m .33333 .49779 L .33142 .4993 L F
.531 .602 .87 r
.38275 .71093 m .38486 .71452 L .38679 .71356 L F
.234 0 .303 r
.38679 .71356 m .38486 .71452 L .3842 .71674 L F
.38679 .71356 m .38486 .71452 L .3842 .71674 L F
0 .444 .851 r
.25544 .61657 m .2538 .61657 L .25261 .61485 L F
.25544 .61657 m .25675 .6178 L .2538 .61657 L F
.14 0 .178 r
.33105 .58526 m .32967 .58428 L .33197 .58375 L F
.33105 .58526 m .32899 .58623 L .32967 .58428 L F
.741 .754 .863 r
.26094 .52981 m .25881 .53312 L .263 .53235 L F
.494 .172 .351 r
.25881 .53312 m .26091 .53434 L .263 .53235 L F
.703 .326 .332 r
.26091 .53434 m .26429 .53499 L .263 .53235 L F
.003 0 .358 r
.26637 .53433 m .263 .53235 L .26429 .53499 L F
.819 .583 .582 r
.37135 .51708 m .37081 .51999 L .36639 .51625 L F
0 0 .516 r
.37595 .58401 m .37741 .58365 L .37871 .58165 L F
.37595 .58401 m .37688 .58664 L .37741 .58365 L F
.854 .852 .84 r
.67454 .32976 m .67042 .3314 L .67333 .32836 L F
.886 .899 .834 r
.67709 .3265 m .67454 .32976 L .67333 .32836 L F
.309 0 .234 r
.39826 .5908 m .39714 .59297 L .39474 .59381 L F
.054 0 .394 r
.39938 .5895 m .39826 .5908 L .39956 .58682 L F
0 0 0 r
.39938 .5895 m .39714 .59297 L .39826 .5908 L F
.424 0 0 r
.26142 .6312 m .26144 .63128 L .25963 .63019 L F
.26142 .6312 m .26399 .63301 L .26144 .63128 L F
.638 .579 .772 r
.35446 .62198 m .35748 .62158 L .35593 .61765 L F
.574 .343 .528 r
.35433 .62466 m .35748 .62158 L .35446 .62198 L F
.35748 .62158 m .35433 .62466 L .35446 .62198 L F
.037 .483 .882 r
.23862 .62203 m .23881 .62109 L .2369 .62078 L F
.23862 .62203 m .2405 .62252 L .23881 .62109 L F
.569 .834 .478 r
.22195 .54572 m .22299 .54439 L .22326 .54415 L F
0 0 0 r
.22195 .54572 m .22193 .54625 L .22299 .54439 L F
.68 .828 .394 r
.22299 .54439 m .22193 .54625 L .22286 .54451 L F
.22299 .54439 m .22286 .54451 L .22399 .54238 L F
.569 .834 .478 r
.22326 .54415 m .22299 .54439 L .22458 .54257 L F
0 0 0 r
.22195 .54572 m .22109 .54732 L .22193 .54625 L F
.843 .937 .887 r
.69515 .30163 m .69129 .30333 L .6944 .30033 L F
.953 .939 .733 r
.69515 .30163 m .6944 .30033 L .69633 .2967 L F
0 0 0 r
.62806 .45091 m .62939 .45096 L .62677 .45127 L F
.62806 .45091 m .63118 .4505 L .62939 .45096 L F
.719 .713 .844 r
.38922 .60173 m .38723 .60371 L .38578 .60054 L F
.38922 .60173 m .38578 .60054 L .38851 .60122 L F
.154 0 .055 r
.39018 .60335 m .388 .60432 L .38922 .60173 L F
.39018 .60335 m .38922 .60173 L .38851 .60122 L F
0 .005 .578 r
.38831 .59969 m .38989 .60277 L .38851 .60122 L F
.38989 .60277 m .39018 .60335 L .38966 .60269 L F
.38989 .60277 m .38966 .60269 L .38851 .60122 L F
0 0 .375 r
.388 .60432 m .38723 .60371 L .38865 .6023 L F
.38891 .6024 m .38865 .6023 L .38922 .60173 L F
.388 .60432 m .38865 .6023 L .38891 .6024 L F
0 0 .138 r
.37368 .56946 m .37255 .57116 L .37248 .57111 L F
.37255 .57116 m .37209 .57186 L .37248 .57111 L F
.37255 .57116 m .37349 .5724 L .37209 .57186 L F
.37368 .56946 m .37262 .57114 L .37255 .57116 L F
.875 .991 .74 r
.37368 .56946 m .37248 .57111 L .37262 .57114 L F
.37368 .56946 m .37262 .57114 L .37325 .57125 L F
0 0 .138 r
.37368 .56946 m .37359 .57078 L .37262 .57114 L F
.256 .766 .844 r
.37325 .57125 m .37248 .57111 L .37276 .57131 L F
0 0 .138 r
.37359 .57078 m .37349 .5724 L .37255 .57116 L F
.256 .766 .844 r
.37183 .57142 m .37248 .57111 L .36934 .57173 L F
.37276 .57131 m .37255 .57116 L .37183 .57142 L F
.37255 .57116 m .37248 .57111 L .37183 .57142 L F
.464 .573 .88 r
.37357 .56964 m .37521 .57093 L .37325 .57125 L F
.394 .179 .465 r
.37521 .57093 m .37312 .57357 L .37325 .57125 L F
.738 .708 .823 r
.65983 .38613 m .66108 .38972 L .65848 .39058 L F
.667 .668 .842 r
.66384 .38888 m .66108 .38972 L .65983 .38613 L F
.646 .563 .747 r
.66384 .38888 m .66498 .39138 L .66108 .38972 L F
0 0 .075 r
.6255 .41406 m .62469 .41576 L .62573 .41211 L F
.058 .084 .571 r
.62622 .41717 m .62469 .41576 L .6255 .41406 L F
.431 .872 .869 r
.69537 .33382 m .69744 .33252 L .6942 .33365 L F
.69537 .33382 m .69735 .33297 L .69744 .33252 L F
.598 .565 .789 r
.69537 .33382 m .69958 .33598 L .69735 .33297 L F
0 .216 .638 r
.3769 .68294 m .37953 .68451 L .37808 .68353 L F
.881 .972 .659 r
.71033 .2891 m .70986 .2917 L .71176 .28833 L F
.96 .872 .47 r
.70871 .29256 m .70986 .2917 L .71033 .2891 L F
.70871 .29256 m .70911 .29402 L .70986 .2917 L F
.59 .059 0 r
.41825 .54138 m .42213 .54192 L .41943 .54071 L F
.686 .808 .94 r
.56873 .39534 m .57033 .39718 L .5726 .3958 L F
.5726 .3958 m .57033 .39718 L .56873 .39534 L F
.009 .198 .71 r
.31981 .68817 m .32108 .69114 L .32027 .69094 L F
.63 .099 0 r
.32027 .69094 m .32108 .69114 L .32342 .69373 L F
.984 .798 .397 r
.37575 .63083 m .37639 .63355 L .37498 .63355 L F
.545 .266 .442 r
.43861 .58654 m .43559 .58911 L .43625 .58724 L F
.131 0 .379 r
.61134 .42152 m .60816 .42392 L .61059 .42395 L F
.773 .637 .076 r
.61134 .41803 m .61134 .42152 L .6138 .42018 L F
0 0 0 r
.6138 .42018 m .61134 .42152 L .61059 .42395 L F
.818 .985 .713 r
.35739 .60117 m .35703 .60308 L .35955 .59984 L F
.819 .936 .568 r
.35567 .60501 m .35703 .60308 L .35739 .60117 L F
0 0 .507 r
.40182 .65556 m .40184 .65689 L .4003 .65325 L F
0 0 .299 r
.4025 .65814 m .40184 .65689 L .40182 .65556 L F
.4025 .65814 m .40274 .65942 L .40184 .65689 L F
.722 .199 0 r
.33281 .55454 m .33508 .55706 L .33636 .55639 L F
0 0 .387 r
.26327 .55045 m .26236 .5489 L .26411 .54802 L F
.26327 .55045 m .26232 .55163 L .26236 .5489 L F
.517 .601 .876 r
.63264 .39418 m .63606 .3967 L .63503 .39281 L F
.73 .653 .773 r
.63413 .38919 m .63503 .39281 L .63786 .3898 L F
.773 .991 .767 r
.63786 .3898 m .63503 .39281 L .63655 .39017 L F
.649 .678 .864 r
.63606 .3967 m .63655 .39017 L .63503 .39281 L F
.63606 .3967 m .63901 .39599 L .63655 .39017 L F
.75 .835 .379 r
.65423 .42408 m .65519 .42195 L .65433 .42339 L F
.722 .829 .377 r
.65433 .42339 m .65519 .42195 L .65599 .41979 L F
.738 .708 .823 r
.65983 .38613 m .65848 .39058 L .65722 .38726 L F
.554 .617 .869 r
.32759 .5813 m .32514 .58322 L .32442 .58084 L F
.969 .77 .337 r
.6526 .40915 m .6517 .41084 L .65288 .40694 L F
.6526 .40915 m .65243 .41187 L .6517 .41084 L F
.535 .061 .077 r
.33336 .55414 m .33281 .55454 L .33239 .55449 L F
.33336 .55414 m .33413 .55511 L .33281 .55454 L F
.184 .105 .527 r
.33632 .55017 m .33336 .55414 L .33485 .54801 L F
.14 0 .405 r
.33656 .55319 m .33336 .55414 L .33632 .55017 L F
.33656 .55319 m .33413 .55511 L .33336 .55414 L F
.382 .133 .407 r
.39636 .60637 m .39444 .60895 L .39706 .60866 L F
.913 .531 .108 r
.39636 .60637 m .39706 .60866 L .39569 .60716 L F
.648 .281 .335 r
.58853 .43899 m .59144 .43957 L .59249 .43728 L F
.587 .417 .618 r
.59249 .43728 m .59491 .43696 L .59469 .43429 L F
.006 0 .026 r
.59249 .43728 m .59373 .4376 L .59491 .43696 L F
.59249 .43728 m .59144 .43957 L .59373 .4376 L F
.832 .726 .748 r
.61231 .39245 m .61559 .3927 L .61402 .38926 L F
.744 .316 .235 r
.61438 .39475 m .61559 .3927 L .61231 .39245 L F
.48 .553 .853 r
.61402 .38926 m .61559 .3927 L .61714 .39182 L F
0 0 0 r
.61714 .39182 m .61559 .3927 L .61438 .39475 L F
.926 .611 .145 r
.41109 .54837 m .40968 .54439 L .41001 .54604 L F
.992 .74 .394 r
.33076 .52429 m .32963 .52344 L .32949 .52567 L F
.33076 .52429 m .33208 .52301 L .32963 .52344 L F
.672 .928 .629 r
.65599 .41979 m .65752 .41865 L .65883 .41666 L F
.66 .678 .856 r
.24717 .58643 m .24917 .58393 L .24591 .58295 L F
.24717 .58643 m .25035 .58515 L .24917 .58393 L F
.022 0 0 r
.26637 .53433 m .26708 .53448 L .26871 .53282 L F
.51 .906 .783 r
.26708 .53448 m .27125 .53252 L .26871 .53282 L F
.567 .321 .503 r
.30806 .54874 m .30824 .55153 L .30532 .55179 L F
.447 .233 .494 r
.31074 .55064 m .30806 .54874 L .3109 .54793 L F
.31074 .55064 m .30824 .55153 L .30806 .54874 L F
.499 .466 .752 r
.25694 .53943 m .25918 .53909 L .25818 .53493 L F
.649 .566 .748 r
.25705 .54214 m .25918 .53909 L .25694 .53943 L F
.769 .538 0 r
.40138 .52709 m .40124 .52747 L .40004 .52564 L F
.40139 .52722 m .40162 .52921 L .40124 .52747 L F
0 0 .496 r
.40303 .53098 m .40124 .52747 L .40162 .52921 L F
.595 .162 0 r
.40124 .52747 m .40191 .52853 L .40109 .52772 L F
.40124 .52747 m .40109 .52772 L .39964 .52632 L F
.769 .538 0 r
.40138 .52709 m .40139 .52722 L .40124 .52747 L F
.51 .709 .961 r
.38046 .59608 m .37863 .59697 L .37731 .59541 L F
.598 .613 .838 r
.38678 .61888 m .38797 .61478 L .38642 .61481 L F
.38678 .61888 m .38965 .61844 L .38797 .61478 L F
.518 .243 .437 r
.38813 .62118 m .38965 .61844 L .38678 .61888 L F
0 .05 .561 r
.38678 .61888 m .38751 .62128 L .38813 .62118 L F
.518 .243 .437 r
.38813 .62118 m .38965 .61844 L .38678 .61888 L F
.649 .227 .228 r
.36116 .60914 m .357 .60818 L .35895 .60762 L F
.667 .803 .948 r
.35564 .61125 m .35895 .60762 L .357 .60818 L F
.35564 .61125 m .36116 .60914 L .35895 .60762 L F
.748 .919 .949 r
.71144 .34596 m .70711 .34686 L .7102 .34444 L F
.909 .965 .648 r
.71291 .34172 m .71144 .34596 L .7102 .34444 L F
.001 0 .083 r
.21348 .55506 m .21556 .55396 L .21619 .55166 L F
0 0 0 r
.21619 .55166 m .21641 .55277 L .21756 .55058 L F
.21619 .55166 m .21556 .55396 L .21641 .55277 L F
.899 .821 .35 r
.37748 .58687 m .37871 .58165 L .37741 .58365 L F
.595 .359 .528 r
.31835 .56446 m .32077 .56168 L .3188 .56186 L F
.31835 .56446 m .32097 .56404 L .32077 .56168 L F
.42 .291 .598 r
.32077 .56168 m .32303 .55623 L .32146 .55962 L F
.32077 .56168 m .32329 .56085 L .32303 .55623 L F
.521 .376 .625 r
.32097 .56404 m .32329 .56085 L .32077 .56168 L F
.633 .963 .841 r
.22458 .54257 m .22522 .54131 L .22609 .5413 L F
.754 .914 .54 r
.22458 .54257 m .22399 .54238 L .22522 .54131 L F
.22458 .54257 m .22299 .54439 L .22399 .54238 L F
.868 .843 .818 r
.64363 .41798 m .64444 .42129 L .64135 .42087 L F
.891 .804 .757 r
.64135 .42087 m .64444 .42129 L .64209 .42474 L F
.84 .83 .837 r
.64697 .41796 m .64444 .42129 L .64363 .41798 L F
.927 .961 .65 r
.39519 .62354 m .3954 .62554 L .39714 .62182 L F
.928 .958 .64 r
.39423 .62691 m .3954 .62554 L .39519 .62354 L F
.61 .348 .496 r
.26003 .56791 m .26225 .57028 L .25968 .5703 L F
0 0 0 r
.3702 .65874 m .37217 .65765 L .36787 .65943 L F
.004 0 .481 r
.59469 .43429 m .5963 .4354 L .59494 .4322 L F
.59469 .43429 m .59491 .43696 L .5963 .4354 L F
.824 .572 .559 r
.71235 .3671 m .70939 .3666 L .70952 .36418 L F
.653 .136 0 r
.71235 .3671 m .71117 .3684 L .70939 .3666 L F
.185 0 0 r
.71454 .36647 m .71117 .3684 L .71235 .3671 L F
.886 .899 .834 r
.67709 .3265 m .67333 .32836 L .67592 .32513 L F
.884 .908 .84 r
.67968 .32327 m .67709 .3265 L .67592 .32513 L F
.356 .809 .942 r
.33333 .49779 m .33544 .49729 L .33717 .49776 L F
.502 .879 .974 r
.33717 .49776 m .33784 .49646 L .33979 .49693 L F
.517 .892 .967 r
.33717 .49776 m .33544 .49729 L .33784 .49646 L F
.919 .732 .24 r
.40264 .66248 m .40351 .6656 L .40272 .66354 L F
.754 .984 .906 r
.62762 .38956 m .63138 .38782 L .62985 .38768 L F
.539 .926 .872 r
.63138 .38782 m .6328 .38656 L .62985 .38768 L F
.63138 .38782 m .63359 .38685 L .6328 .38656 L F
.442 0 0 r
.35024 .64555 m .34947 .64386 L .34788 .64662 L F
.422 .511 .844 r
.35295 .64743 m .34947 .64386 L .35167 .64416 L F
.442 0 0 r
.35024 .64555 m .35167 .64416 L .34947 .64386 L F
.558 .324 .516 r
.61402 .38926 m .61397 .38684 L .61155 .38892 L F
.514 .912 .904 r
.61537 .38522 m .61698 .38394 L .61647 .38415 L F
0 .03 .555 r
.61383 .38342 m .61396 .38658 L .61537 .38522 L F
.366 .754 .988 r
.61537 .38522 m .61134 .38473 L .61243 .38201 L F
.514 .912 .904 r
.61537 .38522 m .61647 .38415 L .61418 .38512 L F
0 .03 .555 r
.61396 .38658 m .61397 .38684 L .61537 .38522 L F
.117 0 0 r
.31808 .64399 m .31978 .64404 L .31587 .64375 L F
0 0 .421 r
.32069 .64605 m .32003 .64737 L .31978 .64404 L F
.32069 .64605 m .31978 .64404 L .31808 .64399 L F
.073 0 .237 r
.73315 .34396 m .7307 .34769 L .73106 .34576 L F
.721 .731 .859 r
.64145 .37879 m .64269 .38086 L .63882 .38012 L F
.638 .593 .787 r
.64402 .37612 m .64269 .38086 L .64145 .37879 L F
.64402 .37612 m .64531 .37981 L .64269 .38086 L F
.801 .755 .81 r
.7072 .29989 m .70834 .30519 L .71064 .30032 L F
.334 .802 .704 r
.32857 .68074 m .33094 .67986 L .32558 .68212 L F
.597 .944 .794 r
.33279 .67844 m .33094 .67986 L .32857 .68074 L F
.934 .691 .212 r
.41688 .57387 m .41582 .56974 L .41715 .57116 L F
.947 .693 .231 r
.70196 .30712 m .7029 .30749 L .70206 .30633 L F
.70196 .30712 m .70324 .31021 L .7029 .30749 L F
.468 .372 .663 r
.7029 .30749 m .70324 .31021 L .70597 .30944 L F
.709 .443 .521 r
.70911 .29402 m .71314 .29604 L .71311 .295 L F
.479 .026 .096 r
.71314 .29604 m .71598 .29602 L .71311 .295 L F
.418 .239 .53 r
.63359 .38685 m .63413 .38919 L .63615 .38815 L F
.347 0 0 r
.6328 .38656 m .63359 .38685 L .63615 .38815 L F
.41 .279 .591 r
.32978 .60274 m .33236 .60237 L .33187 .59915 L F
.32 .007 .268 r
.32978 .60274 m .33156 .60435 L .33236 .60237 L F
.32978 .60274 m .32951 .60493 L .33156 .60435 L F
.624 .864 .988 r
.60745 .44675 m .60775 .44701 L .61059 .44676 L F
.701 .303 .291 r
.61059 .44676 m .61005 .44891 L .60745 .44675 L F
.089 0 .066 r
.61377 .44461 m .61005 .44891 L .61059 .44676 L F
.629 .367 .503 r
.58227 .45303 m .57866 .45585 L .5789 .45398 L F
.985 .735 .472 r
.38836 .65664 m .38733 .65341 L .38994 .65342 L F
.288 .685 .973 r
.38946 .65285 m .38994 .65342 L .38933 .65342 L F
.38946 .65285 m .38933 .65342 L .38733 .65341 L F
.746 .911 .535 r
.38954 .65252 m .38946 .65285 L .3906 .65091 L F
.288 .685 .973 r
.38946 .65285 m .38994 .65342 L .38733 .65341 L F
.746 .911 .535 r
.38805 .65481 m .38946 .65285 L .38954 .65252 L F
.639 .894 .985 r
.38946 .65285 m .38994 .65342 L .39171 .65312 L F
.774 .63 .701 r
.38805 .65481 m .3906 .65091 L .39087 .65144 L F
.677 .587 .748 r
.39433 .65314 m .39103 .65627 L .39085 .65581 L F
.39144 .65332 m .39085 .65581 L .38994 .65342 L F
.39433 .65314 m .39085 .65581 L .39144 .65332 L F
.574 .146 .19 r
.38994 .65342 m .39433 .65314 L .39171 .65312 L F
.677 .587 .748 r
.39433 .65314 m .38994 .65342 L .39171 .65312 L F
.774 .63 .701 r
.39086 .65351 m .39087 .65144 L .39156 .65282 L F
.39146 .65324 m .39156 .65282 L .39171 .65312 L F
.39086 .65351 m .39156 .65282 L .39146 .65324 L F
.985 .735 .472 r
.38836 .65664 m .38994 .65342 L .39085 .65581 L F
.774 .63 .701 r
.38856 .65443 m .39171 .65312 L .38994 .65342 L F
.38805 .65481 m .38898 .65438 L .38856 .65443 L F
.38898 .65438 m .39171 .65312 L .38856 .65443 L F
.97 .926 .684 r
.38805 .65481 m .38994 .65342 L .38946 .65285 L F
.774 .63 .701 r
.38805 .65481 m .39087 .65144 L .39086 .65351 L F
0 0 0 r
.39174 .65405 m .3933 .65289 L .3906 .65091 L F
.3933 .65289 m .39227 .6513 L .3906 .65091 L F
.697 .873 .964 r
.38717 .649 m .39072 .64866 L .38927 .64741 L F
.996 .794 .518 r
.38892 .65058 m .39072 .64866 L .38717 .649 L F
.38892 .65058 m .3906 .65091 L .39072 .64866 L F
.407 .725 .989 r
.3906 .65091 m .39334 .65071 L .39072 .64866 L F
.491 .546 .841 r
.39334 .65071 m .39404 .64671 L .3925 .64919 L F
.407 .725 .989 r
.39175 .65082 m .39382 .65156 L .39334 .65071 L F
.3906 .65091 m .39227 .6513 L .39175 .65082 L F
.39227 .6513 m .39467 .65186 L .39175 .65082 L F
.687 .204 .099 r
.39072 .64866 m .39334 .65071 L .39107 .65149 L F
.491 .546 .841 r
.39334 .65071 m .3925 .64919 L .39107 .65149 L F
.407 .725 .989 r
.39382 .65156 m .39467 .65186 L .39334 .65071 L F
.687 .204 .099 r
.39035 .64834 m .3907 .64986 L .38927 .64741 L F
.3907 .64986 m .39107 .65149 L .39012 .64933 L F
.3907 .64986 m .39012 .64933 L .38927 .64741 L F
.39072 .64866 m .39076 .64897 L .39035 .64834 L F
.39076 .64897 m .39107 .65149 L .39035 .64834 L F
0 0 0 r
.3933 .65289 m .39467 .65186 L .39227 .6513 L F
.39212 .65509 m .39306 .6539 L .39174 .65405 L F
.39306 .6539 m .39467 .65186 L .39174 .65405 L F
.985 .735 .472 r
.39085 .6563 m .39085 .65581 L .39103 .65627 L F
.38836 .65664 m .39085 .65581 L .39085 .6563 L F
.585 .196 .271 r
.36908 .57142 m .36778 .57538 L .36549 .57352 L F
.544 .634 .89 r
.36934 .57173 m .37209 .57186 L .36908 .57142 L F
.303 0 .17 r
.37017 .57459 m .36908 .57142 L .37209 .57186 L F
.37017 .57459 m .36778 .57538 L .36908 .57142 L F
.869 .833 .809 r
.68683 .30956 m .68698 .3135 L .68559 .31166 L F
.87 .798 .778 r
.68698 .3135 m .68313 .3152 L .68559 .31166 L F
.68698 .3135 m .68479 .3168 L .68313 .3152 L F
0 0 0 r
.72015 .32649 m .7194 .32801 L .7175 .3297 L F
.547 .885 .987 r
.7175 .3297 m .7194 .32801 L .71642 .329 L F
.565 .002 0 r
.22276 .60877 m .2249 .60963 L .22096 .60868 L F
.431 .009 .137 r
.23393 .56944 m .23288 .57085 L .2301 .57092 L F
.964 .642 .262 r
.41109 .54837 m .41266 .552 L .41136 .5507 L F
0 0 .13 r
.41266 .552 m .4127 .55448 L .41305 .55304 L F
.41266 .552 m .41305 .55304 L .41136 .5507 L F
.774 .55 .595 r
.42671 .5802 m .43088 .57743 L .42877 .57603 L F
.42671 .5802 m .43174 .5803 L .43088 .57743 L F
.645 .801 .958 r
.42877 .57603 m .43088 .57743 L .43292 .5751 L F
.235 .227 .646 r
.43088 .57743 m .43202 .5767 L .43292 .5751 L F
.771 .548 .597 r
.43328 .57949 m .43174 .5803 L .43088 .57743 L F
.235 .227 .646 r
.43088 .57743 m .43174 .5803 L .43202 .5767 L F
0 0 .247 r
.3504 .63471 m .35111 .63586 L .35294 .63402 L F
.482 .001 .038 r
.3504 .63471 m .35148 .63543 L .35063 .63746 L F
0 0 .247 r
.3504 .63471 m .35063 .63746 L .35111 .63586 L F
.978 .818 .409 r
.38679 .71356 m .38729 .71098 L .38681 .7094 L F
.197 0 0 r
.57875 .41536 m .5807 .41552 L .57677 .41488 L F
.613 .911 .982 r
.58204 .41355 m .58337 .41439 L .5807 .41552 L F
.667 .971 .907 r
.58204 .41355 m .5807 .41552 L .57875 .41536 L F
0 0 0 r
.35739 .60117 m .35955 .59984 L .36169 .5989 L F
.61 .397 .567 r
.32792 .50121 m .33096 .50261 L .33137 .49848 L F
.32792 .50121 m .32793 .50388 L .33096 .50261 L F
.099 0 0 r
.70385 .33124 m .70222 .33207 L .70056 .33301 L F
.70222 .33207 m .69926 .33358 L .70056 .33301 L F
.788 .659 .72 r
.69735 .33297 m .699 .33389 L .70056 .33301 L F
.699 .33389 m .70165 .33538 L .70056 .33301 L F
.69735 .33297 m .69958 .33598 L .70165 .33538 L F
.822 .534 .503 r
.69822 .33737 m .70165 .33538 L .69958 .33598 L F
.69822 .33737 m .70178 .33833 L .70165 .33538 L F
.829 .955 .897 r
.70165 .33538 m .70385 .33124 L .70056 .33301 L F
.70165 .33538 m .70459 .33243 L .70385 .33124 L F
.223 0 .324 r
.33822 .60426 m .33656 .6027 L .33891 .60206 L F
.33822 .60426 m .33636 .6054 L .33656 .6027 L F
.521 .918 .864 r
.25352 .52592 m .25468 .52477 L .25712 .52455 L F
.25352 .52592 m .25262 .5259 L .25468 .52477 L F
.981 .727 .473 r
.55831 .41883 m .55866 .42169 L .55711 .42018 L F
0 0 0 r
.55988 .41716 m .55831 .41883 L .55711 .42018 L F
.795 .701 .761 r
.71176 .28833 m .71408 .2852 L .71078 .28363 L F
.885 .805 .322 r
.58469 .42119 m .58524 .41875 L .58505 .41657 L F
.779 .657 .729 r
.32605 .63182 m .32699 .63427 L .32775 .63192 L F
.663 .601 .776 r
.42698 .50092 m .42427 .50156 L .42299 .49788 L F
0 .092 .62 r
.36434 .51683 m .36532 .51557 L .3636 .51316 L F
.848 .604 .061 r
.65961 .41406 m .65982 .41407 L .65935 .41156 L F
0 0 .208 r
.6599 .41206 m .65961 .41406 L .65935 .41156 L F
.905 .853 .403 r
.6592 .41402 m .65961 .41406 L .6599 .41206 L F
.65852 .41595 m .65961 .41406 L .6592 .41402 L F
.848 .604 .061 r
.65961 .41406 m .66008 .41542 L .65982 .41407 L F
.975 .872 .491 r
.65883 .41666 m .66008 .41542 L .65961 .41406 L F
.386 .4 .752 r
.43499 .51221 m .4332 .5147 L .43222 .51042 L F
.33 .323 .701 r
.43499 .51221 m .43564 .51618 L .4332 .5147 L F
.192 .339 .784 r
.4332 .5147 m .43564 .51618 L .4344 .51648 L F
.123 0 .346 r
.21297 .55749 m .21556 .55396 L .21348 .55506 L F
.672 .519 .669 r
.39022 .57422 m .39335 .57369 L .3929 .571 L F
0 0 0 r
.3929 .571 m .39157 .57357 L .39022 .57422 L F
.55 .629 .883 r
.39531 .57039 m .3929 .571 L .39201 .56861 L F
.695 .644 .794 r
.39335 .57369 m .39531 .57039 L .3929 .571 L F
.738 .548 .636 r
.39531 .57039 m .39157 .57357 L .3929 .571 L F
0 0 0 r
.62573 .41211 m .62749 .40763 L .62756 .41016 L F
0 0 .152 r
.6255 .41406 m .62573 .41211 L .62756 .41016 L F
.441 .416 .736 r
.3704 .5655 m .36855 .56492 L .37047 .5644 L F
.632 .814 .391 r
.31908 .66027 m .31787 .66216 L .31945 .65949 L F
.563 .879 .992 r
.32026 .65867 m .31908 .66027 L .31945 .65949 L F
0 0 .528 r
.32042 .66141 m .31908 .66027 L .32026 .65867 L F
.563 .374 .583 r
.31787 .66216 m .31948 .65981 L .31728 .6578 L F
.494 .762 .99 r
.32026 .65867 m .31945 .65949 L .31728 .6578 L F
.563 .374 .583 r
.31948 .65981 m .32026 .65867 L .3188 .65824 L F
.31948 .65981 m .3188 .65824 L .31728 .6578 L F
0 0 .528 r
.32005 .66109 m .3208 .66337 L .31908 .66027 L F
.32042 .66141 m .3206 .66237 L .32005 .66109 L F
.3206 .66237 m .3208 .66337 L .32005 .66109 L F
.505 .91 .848 r
.28834 .64224 m .28566 .64386 L .28565 .64258 L F
.58 .481 .707 r
.56117 .41864 m .56396 .41825 L .56319 .41614 L F
.489 .176 .362 r
.56117 .41864 m .56396 .41825 L .56379 .42018 L F
.559 .592 .843 r
.43031 .50437 m .42827 .50556 L .42658 .5026 L F
.43031 .50437 m .43098 .50647 L .42827 .50556 L F
.577 .549 .786 r
.43197 .50802 m .42827 .50556 L .43098 .50647 L F
.181 0 0 r
.29139 .61224 m .29189 .61252 L .29416 .61159 L F
.678 .362 .432 r
.35294 .63402 m .35551 .6339 L .35327 .63122 L F
.927 .961 .65 r
.39519 .62354 m .39714 .62182 L .39586 .62092 L F
.92 .92 .797 r
.39586 .62092 m .39714 .62182 L .39926 .61839 L F
.482 .561 .86 r
.45503 .56888 m .4579 .56962 L .45537 .56976 L F
.522 .444 .709 r
.4579 .56962 m .4564 .57409 L .45537 .56976 L F
.284 .07 .402 r
.36266 .64409 m .36011 .64855 L .36243 .64687 L F
.586 .126 .127 r
.36386 .64557 m .36266 .64409 L .36243 .64687 L F
0 0 .537 r
.29552 .65703 m .29701 .65851 L .29764 .65632 L F
.29552 .65703 m .29636 .65997 L .29701 .65851 L F
.521 0 0 r
.28876 .6535 m .2896 .65464 L .28736 .6522 L F
.28876 .6535 m .29258 .65614 L .2896 .65464 L F
.519 .913 .803 r
.72217 .35629 m .72353 .35608 L .72598 .35461 L F
.87 .45 .015 r
.40051 .68582 m .40155 .68665 L .40166 .68547 L F
.473 0 0 r
.2529 .62878 m .25383 .62979 L .25112 .62725 L F
.274 0 0 r
.38234 .5684 m .38074 .57017 L .37798 .57065 L F
.662 .692 .868 r
.38727 .56688 m .39201 .56861 L .38892 .56998 L F
.518 .829 1 r
.39044 .56937 m .38731 .56881 L .38711 .56935 L F
.198 .162 .59 r
.38711 .56935 m .38573 .57041 L .38519 .56829 L F
.455 0 0 r
.38519 .56829 m .38711 .56935 L .38315 .56902 L F
.518 .829 1 r
.38731 .56881 m .38435 .56829 L .38589 .56888 L F
.38731 .56881 m .38589 .56888 L .38711 .56935 L F
0 0 0 r
.38321 .569 m .38234 .5684 L .38519 .56829 L F
.38315 .56902 m .38312 .569 L .38321 .569 L F
.38312 .569 m .38234 .5684 L .38321 .569 L F
.38315 .56902 m .38074 .57017 L .38234 .5684 L F
.888 .829 .783 r
.59159 .41385 m .59118 .41849 L .58973 .41696 L F
.63 .504 .691 r
.59557 .42167 m .59118 .41849 L .59352 .41792 L F
.59557 .42167 m .59322 .42448 L .59118 .41849 L F
0 0 .039 r
.32315 .66383 m .32253 .66498 L .32316 .6637 L F
.523 .897 .964 r
.32253 .66498 m .32357 .66573 L .32207 .66583 L F
0 0 .039 r
.3228 .66634 m .32253 .66498 L .32315 .66383 L F
.523 .897 .964 r
.32253 .66498 m .32207 .66583 L .31984 .66597 L F
0 0 0 r
.3211 .66922 m .32357 .66573 L .32215 .66821 L F
.986 .808 .414 r
.32215 .66821 m .32357 .66573 L .32253 .66498 L F
.863 .788 .775 r
.36992 .71365 m .37396 .71163 L .37225 .713 L F
0 0 0 r
.37451 .71203 m .37628 .71139 L .37866 .71077 L F
.37451 .71203 m .37866 .71077 L .37671 .71136 L F
.224 .736 .703 r
.376 .71157 m .37451 .71203 L .37671 .71136 L F
.052 0 0 r
.37396 .71163 m .37451 .71203 L .37277 .71258 L F
.224 .736 .703 r
.37075 .71305 m .37451 .71203 L .376 .71157 L F
.052 0 0 r
.37277 .71258 m .37451 .71203 L .37225 .713 L F
.37396 .71163 m .37628 .71139 L .37451 .71203 L F
.371 .122 .401 r
.31077 .60553 m .31068 .60871 L .30781 .60921 L F
.281 .043 .364 r
.31349 .60241 m .31293 .60495 L .31077 .60553 L F
.388 .135 .405 r
.31233 .60744 m .31077 .60553 L .31293 .60495 L F
.31233 .60744 m .31068 .60871 L .31077 .60553 L F
.495 .789 .998 r
.2407 .5707 m .24105 .56889 L .23909 .56892 L F
.2407 .5707 m .24296 .57022 L .24105 .56889 L F
.617 .333 .464 r
.27815 .56159 m .27782 .56379 L .27503 .5638 L F
.462 .424 .73 r
.28021 .56057 m .27815 .56159 L .27791 .5567 L F
.269 .036 .365 r
.28021 .56057 m .27782 .56379 L .27815 .56159 L F
0 0 0 r
.72168 .3264 m .72015 .32649 L .7216 .32426 L F
.72168 .3264 m .7194 .32801 L .72015 .32649 L F
.702 .968 .934 r
.57212 .41948 m .56786 .42089 L .5703 .41767 L F
.829 .818 .839 r
.5744 .41675 m .57212 .41948 L .5703 .41767 L F
0 .233 .75 r
.40771 .54268 m .40968 .54439 L .40769 .54094 L F
.082 .254 .741 r
.59513 .42414 m .59653 .42817 L .59452 .42675 L F
.784 .284 0 r
.59452 .42675 m .59653 .42817 L .59729 .42943 L F
.556 .051 .012 r
.59653 .42817 m .59959 .42997 L .59729 .42943 L F
.699 .679 .827 r
.33923 .67875 m .34094 .68234 L .34356 .67984 L F
.527 .256 .448 r
.34329 .68441 m .34094 .68234 L .34069 .68539 L F
.571 .465 .695 r
.34094 .68234 m .34414 .68251 L .34356 .67984 L F
.551 .251 .412 r
.34329 .68441 m .34414 .68251 L .34094 .68234 L F
.593 .39 .576 r
.66194 .3614 m .65902 .36445 L .65804 .36125 L F
.66194 .3614 m .66194 .36399 L .65902 .36445 L F
.666 .431 .555 r
.6645 .36137 m .66194 .36399 L .66194 .3614 L F
.184 0 .279 r
.35722 .57974 m .35536 .58069 L .35776 .57747 L F
.354 .06 .319 r
.35731 .58204 m .35536 .58069 L .35722 .57974 L F
.35731 .58204 m .35457 .58291 L .35536 .58069 L F
.782 .731 .805 r
.71064 .30032 m .7143 .30014 L .71314 .29604 L F
.617 .636 .846 r
.7143 .30014 m .71598 .29602 L .71314 .29604 L F
.7143 .30014 m .71648 .29893 L .71598 .29602 L F
0 .28 .747 r
.37338 .51218 m .3742 .51249 L .37458 .51335 L F
0 .357 .794 r
.3742 .51249 m .37634 .51411 L .37458 .51335 L F
.757 .672 .768 r
.33208 .52301 m .33618 .52342 L .33466 .51971 L F
.733 .547 .641 r
.33208 .52301 m .33605 .52607 L .33618 .52342 L F
.534 .332 .552 r
.33857 .52548 m .33605 .52607 L .33618 .52342 L F
.743 .635 .74 r
.65952 .37012 m .66084 .37404 L .65862 .37463 L F
.731 .585 .692 r
.65862 .37463 m .66084 .37404 L .65827 .37723 L F
.646 .464 .623 r
.66084 .37404 m .66065 .37661 L .65827 .37723 L F
.729 .627 .745 r
.66329 .37071 m .66084 .37404 L .65952 .37012 L F
.884 .908 .84 r
.67968 .32327 m .67592 .32513 L .67823 .32179 L F
.857 .858 .841 r
.68233 .32011 m .67968 .32327 L .67823 .32179 L F
.673 .646 .815 r
.42299 .49788 m .42054 .49908 L .41886 .4972 L F
.775 .76 .839 r
.55021 .41752 m .55523 .41548 L .55276 .41558 L F
.88 .703 .658 r
.65696 .35209 m .65673 .35491 L .65515 .35105 L F
.59 .945 .905 r
.25712 .52455 m .25602 .52373 L .2593 .52373 L F
.25712 .52455 m .25468 .52477 L .25602 .52373 L F
.644 .858 .981 r
.37866 .71077 m .38046 .71217 L .38275 .71093 L F
.92 .92 .797 r
.39586 .62092 m .39926 .61839 L .39883 .61805 L F
.723 .682 .81 r
.3369 .51029 m .34035 .5108 L .33805 .50737 L F
.585 .501 .727 r
.3369 .51029 m .33975 .51325 L .34035 .5108 L F
.965 .747 .559 r
.20184 .59287 m .20314 .59637 L .20124 .59542 L F
.14 .526 .918 r
.20314 .59637 m .20345 .59518 L .20124 .59542 L F
.20314 .59637 m .20503 .59686 L .20345 .59518 L F
.336 .559 .918 r
.20314 .59637 m .20692 .59857 L .20503 .59686 L F
.684 .98 .862 r
.63625 .4466 m .63761 .44453 L .63641 .44624 L F
.63625 .4466 m .6399 .44412 L .63761 .44453 L F
.666 .431 .555 r
.6645 .36137 m .66467 .36388 L .66194 .36399 L F
.722 .453 .52 r
.6645 .36137 m .66898 .36396 L .66467 .36388 L F
.967 .713 .499 r
.70952 .36418 m .70798 .366 L .70729 .36372 L F
.70952 .36418 m .70939 .3666 L .70798 .366 L F
.305 .562 .927 r
.32403 .63557 m .32195 .63549 L .32246 .63421 L F
.508 .107 .215 r
.27029 .5548 m .2721 .55666 L .27269 .55528 L F
.27029 .5548 m .2683 .55745 L .2721 .55666 L F
.795 .701 .761 r
.71176 .28833 m .71078 .28363 L .71262 .28505 L F
.885 .971 .657 r
.71033 .2891 m .71176 .28833 L .71262 .28505 L F
.723 .503 .592 r
.65549 .36744 m .65301 .37022 L .65293 .36771 L F
.65549 .36744 m .65703 .37084 L .65301 .37022 L F
.675 .537 .689 r
.65902 .36445 m .65944 .36755 L .65549 .36744 L F
.76 .602 .682 r
.65944 .36755 m .65703 .37084 L .65549 .36744 L F
.578 .583 .821 r
.37071 .60306 m .37428 .60455 L .37238 .60217 L F
.04 0 .167 r
.35074 .651 m .35295 .64743 L .35368 .65114 L F
0 .036 .605 r
.35376 .64724 m .35295 .64743 L .35167 .64416 L F
.714 .769 .896 r
.35427 .6481 m .35295 .64743 L .35376 .64724 L F
.35427 .6481 m .35368 .65114 L .35295 .64743 L F
.896 .802 .748 r
.68814 .34526 m .69036 .34223 L .68913 .34026 L F
.78 .609 .668 r
.68814 .34526 m .69057 .34471 L .69036 .34223 L F
.746 .767 .87 r
.68913 .34026 m .69036 .34223 L .69228 .33954 L F
.408 .123 .366 r
.35776 .57747 m .35949 .57931 L .35722 .57974 L F
.483 .126 .283 r
.36074 .57731 m .35949 .57931 L .35776 .57747 L F
.495 .334 .592 r
.31353 .6238 m .31528 .6256 L .31574 .62313 L F
.695 .981 .883 r
.31365 .62685 m .31541 .62678 L .31873 .62467 L F
.31361 .62687 m .31363 .62687 L .31365 .62685 L F
.31361 .62687 m .31873 .62467 L .31599 .62634 L F
.495 .334 .592 r
.31528 .6256 m .31599 .62634 L .3159 .62513 L F
.31528 .6256 m .3159 .62513 L .31574 .62313 L F
.695 .981 .883 r
.31363 .62687 m .31541 .62678 L .31365 .62685 L F
.59 .584 .815 r
.28264 .61497 m .2841 .61871 L .28693 .61719 L F
.326 0 0 r
.2841 .61871 m .28484 .61986 L .28693 .61719 L F
.2841 .61871 m .28212 .62025 L .28484 .61986 L F
.176 .454 .88 r
.34245 .70991 m .34341 .71207 L .34633 .71306 L F
0 0 .027 r
.32671 .57372 m .326 .5761 L .32462 .57712 L F
.115 0 .127 r
.32891 .57301 m .326 .5761 L .32671 .57372 L F
0 0 0 r
.66263 .40627 m .6618 .40602 L .66323 .40409 L F
.66263 .40627 m .66099 .40826 L .6618 .40602 L F
.734 .484 .55 r
.65293 .36771 m .64881 .36962 L .64883 .3672 L F
.65293 .36771 m .65301 .37022 L .64881 .36962 L F
.283 .157 .526 r
.34306 .51837 m .341 .51649 L .34323 .51526 L F
.34306 .51837 m .34114 .51961 L .341 .51649 L F
.34306 .51837 m .341 .51649 L .34323 .51526 L F
.34306 .51837 m .34114 .51961 L .341 .51649 L F
.372 .83 .917 r
.39022 .57422 m .39335 .57369 L .39157 .57357 L F
.39157 .57357 m .39335 .57369 L .39022 .57422 L F
.791 .922 .925 r
.61155 .38892 m .60836 .38986 L .61062 .38824 L F
.558 .324 .516 r
.61402 .38926 m .61155 .38892 L .61062 .38824 L F
.373 0 0 r
.24686 .61389 m .24831 .61455 L .25042 .61508 L F
.503 .827 1 r
.24831 .61455 m .25261 .61485 L .25042 .61508 L F
.937 .925 .771 r
.36318 .55899 m .36162 .56071 L .35977 .56072 L F
.676 .675 .842 r
.367 .5588 m .36318 .55899 L .36548 .55659 L F
.692 .473 .585 r
.44439 .58281 m .44105 .58046 L .44456 .57927 L F
.654 .482 .638 r
.44743 .57752 m .44734 .58016 L .44456 .57927 L F
.506 .232 .433 r
.44734 .58016 m .44439 .58281 L .44456 .57927 L F
.585 .501 .727 r
.3369 .51029 m .33692 .51501 L .33975 .51325 L F
.755 .445 .46 r
.54939 .41492 m .55276 .41558 L .55135 .41424 L F
.95 .664 .216 r
.40087 .55717 m .4021 .56127 L .40225 .55834 L F
.906 .774 .285 r
.4048 .66809 m .40491 .67239 L .4041 .66971 L F
.641 .695 .884 r
.63106 .37629 m .63485 .37739 L .63194 .37853 L F
.616 .596 .807 r
.63673 .38167 m .63194 .37853 L .63485 .37739 L F
.702 .168 0 r
.23753 .60928 m .23909 .61096 L .24005 .61116 L F
.738 .218 0 r
.23909 .61096 m .24218 .61255 L .24005 .61116 L F
.398 0 0 r
.62177 .44996 m .62288 .45089 L .61974 .44944 L F
.62177 .44996 m .62392 .4507 L .62288 .45089 L F
0 0 0 r
.32756 .61715 m .32666 .61817 L .32867 .61545 L F
.33155 .61165 m .3306 .61411 L .32867 .61545 L F
.32907 .61563 m .32867 .61545 L .3306 .61411 L F
.32907 .61563 m .32756 .61715 L .32867 .61545 L F
.888 .8 .757 r
.57862 .42384 m .58183 .42414 L .57946 .42756 L F
0 0 0 r
.63264 .39418 m .63397 .39426 L .63175 .39533 L F
.63264 .39418 m .63503 .39281 L .63397 .39426 L F
.862 .881 .849 r
.42975 .56175 m .42783 .56467 L .42607 .56372 L F
.516 .585 .862 r
.43131 .56477 m .42783 .56467 L .42975 .56175 L F
0 0 0 r
.31873 .62467 m .3205 .62427 L .31843 .62512 L F
.53 .583 .853 r
.32059 .62412 m .31843 .62512 L .32072 .62417 L F
0 0 0 r
.31873 .62467 m .31843 .62512 L .31651 .62602 L F
.278 .055 .385 r
.32101 .62175 m .3205 .62427 L .31873 .62467 L F
.53 .583 .853 r
.31793 .62295 m .31843 .62512 L .32059 .62412 L F
0 0 0 r
.31651 .62602 m .31843 .62512 L .31599 .62634 L F
.37442 .65682 m .37217 .65765 L .3702 .65874 L F
.947 .614 .362 r
.37953 .68451 m .38158 .68564 L .37971 .68712 L F
.844 .459 .32 r
.39046 .50309 m .39542 .50512 L .39038 .50324 L F
.796 .641 .69 r
.39416 .50668 m .39038 .50324 L .39542 .50512 L F
.888 .82 .775 r
.41101 .50434 m .40728 .50643 L .41007 .50367 L F
.831 .978 .883 r
.62415 .39692 m .62672 .39692 L .6236 .39958 L F
.772 .981 .909 r
.63038 .39424 m .62672 .39692 L .62415 .39692 L F
.942 .782 .32 r
.69502 .32199 m .69457 .32515 L .69517 .32586 L F
.557 .072 0 r
.69598 .32689 m .69517 .32586 L .69457 .32515 L F
.69598 .32689 m .69695 .32791 L .69517 .32586 L F
.667 .566 .732 r
.44607 .57397 m .44378 .57506 L .44225 .57082 L F
.919 .876 .779 r
.33054 .53971 m .32762 .54015 L .32975 .53713 L F
.33054 .53971 m .32929 .54183 L .32762 .54015 L F
.662 .452 .59 r
.42647 .5462 m .42585 .54912 L .42413 .54835 L F
.348 .071 .344 r
.43178 .54133 m .42944 .54541 L .42647 .5462 L F
0 0 .027 r
.42716 .54616 m .42647 .5462 L .42944 .54541 L F
.42716 .54616 m .42585 .54912 L .42647 .5462 L F
0 0 0 r
.39464 .58312 m .3914 .58589 L .39385 .58532 L F
0 .132 .665 r
.39383 .5802 m .39464 .58312 L .39521 .58176 L F
0 0 0 r
.39464 .58312 m .39385 .58532 L .39521 .58176 L F
.759 .688 .783 r
.54311 .42975 m .54232 .43392 L .54059 .43331 L F
.54311 .42975 m .54482 .43164 L .54232 .43392 L F
.928 .58 .349 r
.54059 .43331 m .54232 .43392 L .54277 .43659 L F
.545 .519 .777 r
.35147 .52568 m .35305 .52907 L .35065 .52959 L F
.225 .344 .776 r
.35065 .52959 m .35314 .53169 L .35305 .52907 L F
.608 .929 .965 r
.26307 .52293 m .2593 .52373 L .26182 .52296 L F
.559 .907 .972 r
.26529 .52199 m .26307 .52293 L .26385 .52156 L F
.632 .963 .883 r
.26385 .52156 m .26307 .52293 L .26182 .52296 L F
.212 .736 .823 r
.26644 .5225 m .26307 .52293 L .26529 .52199 L F
.607 .357 .512 r
.68018 .37062 m .67652 .37319 L .67643 .37095 L F
.668 .621 .793 r
.63882 .38012 m .63673 .38167 L .63485 .37739 L F
.81 .964 .907 r
.62415 .39692 m .6236 .39958 L .62252 .39872 L F
.211 .721 .893 r
.35876 .61817 m .36347 .61844 L .36247 .61805 L F
.241 .742 .902 r
.36247 .61805 m .36347 .61844 L .36576 .61818 L F
0 0 0 r
.54512 .4195 m .54821 .41864 L .54757 .41671 L F
.692 .629 .782 r
.54821 .41864 m .55021 .41752 L .54939 .41492 L F
.887 .891 .827 r
.30269 .5318 m .30086 .53526 L .30275 .53606 L F
.966 .713 .501 r
.30086 .53526 m .30249 .53875 L .30275 .53606 L F
.025 0 .199 r
.58444 .43631 m .58443 .4353 L .58535 .43377 L F
.536 .056 .063 r
.58535 .43377 m .58607 .43534 L .58444 .43631 L F
.58535 .43377 m .5877 .43443 L .58607 .43534 L F
.13 0 .37 r
.3029 .60204 m .30511 .59861 L .30276 .59974 L F
.827 .578 .562 r
.6552 .34848 m .65164 .3504 L .65405 .34716 L F
.6552 .34848 m .65515 .35105 L .65164 .3504 L F
.855 .917 .873 r
.65804 .34541 m .6552 .34848 L .65405 .34716 L F
0 0 0 r
.32322 .62101 m .32666 .61817 L .32559 .62053 L F
.32559 .62053 m .32666 .61817 L .32756 .61715 L F
.808 .873 .894 r
.64066 .4234 m .63898 .42733 L .63837 .42696 L F
.64066 .4234 m .64209 .42474 L .63898 .42733 L F
.36 .683 .979 r
.29636 .65997 m .29867 .66006 L .29701 .65851 L F
.741 .924 .952 r
.36694 .58731 m .36762 .58988 L .36553 .58916 L F
0 .069 .631 r
.36962 .59213 m .36762 .58988 L .36694 .58731 L F
.741 .924 .952 r
.36694 .58731 m .36762 .58988 L .36553 .58916 L F
.658 .575 .751 r
.45013 .5772 m .44743 .57752 L .44607 .57397 L F
.352 .083 .359 r
.45013 .5772 m .44734 .58016 L .44743 .57752 L F
.733 .762 .876 r
.39416 .50668 m .39923 .50748 L .39617 .50812 L F
.39416 .50668 m .39923 .50748 L .39617 .50812 L F
.655 .719 .895 r
.36278 .68149 m .36741 .68273 L .36417 .68412 L F
.272 .442 .848 r
.55129 .42594 m .54981 .42599 L .54816 .42284 L F
.904 .508 .092 r
.4189 .58658 m .42096 .59004 L .41922 .58907 L F
.978 .696 .417 r
.42096 .59004 m .41964 .59172 L .41922 .58907 L F
.42096 .59004 m .4211 .59272 L .41964 .59172 L F
.765 .762 .251 r
.62698 .42588 m .62718 .42568 L .62721 .42502 L F
.307 .04 .334 r
.6257 .42765 m .6274 .42547 L .62718 .42568 L F
0 0 .439 r
.6271 .42931 m .6257 .42765 L .62605 .42718 L F
.6271 .42931 m .62605 .42718 L .62718 .42568 L F
.934 .734 .256 r
.62656 .42743 m .6271 .42931 L .62718 .42568 L F
0 0 .351 r
.62656 .42743 m .62757 .43026 L .6271 .42931 L F
.431 .478 .808 r
.62916 .43251 m .6263 .43132 L .6271 .42931 L F
.62916 .43251 m .6271 .42931 L .62806 .43163 L F
0 0 .351 r
.62757 .43026 m .62806 .43163 L .6271 .42931 L F
.765 .762 .251 r
.62656 .42743 m .62718 .42568 L .62698 .42588 L F
.307 .04 .334 r
.6274 .42547 m .62834 .42426 L .62718 .42568 L F
0 0 0 r
.62718 .42568 m .62834 .42426 L .62979 .42255 L F
.333 0 .155 r
.68831 .36475 m .69078 .36551 L .68812 .36623 L F
.68831 .36475 m .6915 .36321 L .69078 .36551 L F
.822 .654 .673 r
.22433 .56373 m .2281 .5648 L .22863 .56145 L F
.22433 .56373 m .22863 .56145 L .22671 .56357 L F
.905 .648 .539 r
.22863 .56145 m .22855 .56456 L .22671 .56357 L F
.776 .812 .882 r
.61233 .37026 m .6138 .37339 L .61189 .37395 L F
.161 0 0 r
.6114 .36835 m .61233 .37026 L .61126 .36821 L F
.682 .767 .916 r
.61644 .3708 m .61384 .37335 L .61233 .37026 L F
.61644 .3708 m .61501 .37061 L .61543 .36948 L F
.61501 .37061 m .61233 .37026 L .61543 .36948 L F
.161 0 0 r
.61397 .37086 m .61543 .36948 L .61233 .37026 L F
.704 .832 .944 r
.61613 .36758 m .61543 .36948 L .61397 .37086 L F
.61655 .36694 m .61543 .36948 L .61613 .36758 L F
.161 0 0 r
.61397 .37086 m .61233 .37026 L .6114 .36835 L F
.682 .767 .916 r
.61384 .37335 m .6138 .37339 L .61233 .37026 L F
.592 .678 .9 r
.61764 .37443 m .6138 .37339 L .61644 .3708 L F
0 0 .113 r
.32548 .61222 m .32353 .61585 L .32489 .61464 L F
.081 0 .386 r
.32548 .61222 m .32755 .61098 L .32763 .60821 L F
.503 .374 .637 r
.32489 .61464 m .32755 .61098 L .32548 .61222 L F
.898 .968 .652 r
.59001 .42902 m .59253 .42483 L .59371 .4277 L F
.958 .837 .681 r
.59513 .42414 m .59371 .4277 L .59253 .42483 L F
.743 .704 .814 r
.3085 .53869 m .31037 .54239 L .31321 .53936 L F
0 .088 .586 r
.31103 .54277 m .31273 .54438 L .31037 .54239 L F
.31103 .54277 m .31037 .54239 L .30851 .54391 L F
.487 .087 .207 r
.34863 .53806 m .35052 .54022 L .35019 .53754 L F
.34863 .53806 m .34759 .54071 L .35052 .54022 L F
.741 .754 .863 r
.25674 .52959 m .25881 .53312 L .26094 .52981 L F
.494 .172 .351 r
.25881 .53312 m .25818 .53493 L .26091 .53434 L F
.338 .296 .664 r
.36652 .55475 m .36894 .55764 L .36807 .55532 L F
.36652 .55475 m .367 .5588 L .36894 .55764 L F
.638 .359 .479 r
.36807 .55532 m .36548 .55659 L .36652 .55475 L F
.189 0 0 r
.23394 .55012 m .23256 .54966 L .23493 .54888 L F
.23394 .55012 m .2316 .55086 L .23256 .54966 L F
.752 .696 .798 r
.4165 .4979 m .41225 .49765 L .41499 .49421 L F
.679 .66 .824 r
.41886 .4972 m .4165 .4979 L .41499 .49421 L F
.103 0 .088 r
.29112 .54585 m .29024 .54785 L .28843 .54856 L F
.388 .025 .223 r
.29282 .54723 m .29112 .54585 L .29348 .54505 L F
.29282 .54723 m .29024 .54785 L .29112 .54585 L F
.557 .307 .493 r
.39474 .59381 m .39452 .59637 L .3914 .59623 L F
.419 .193 .462 r
.39714 .59297 m .39452 .59637 L .39474 .59381 L F
.649 .369 .481 r
.58795 .45038 m .58776 .45283 L .58515 .45249 L F
.666 .446 .577 r
.59158 .44987 m .58776 .45283 L .58795 .45038 L F
.839 .585 .556 r
.54623 .44005 m .54277 .43659 L .54607 .4375 L F
.694 .838 .952 r
.27962 .631 m .27622 .63116 L .27839 .63347 L F
.477 .699 .966 r
.39569 .60716 m .39444 .60895 L .39288 .60644 L F
.554 .348 .556 r
.39471 .61223 m .39706 .60866 L .39444 .60895 L F
.888 .881 .821 r
.68479 .3168 m .68104 .31864 L .68313 .3152 L F
.68479 .3168 m .68233 .32011 L .68104 .31864 L F
.768 .723 .811 r
.3098 .51325 m .30723 .51633 L .311 .51672 L F
.73 .644 .764 r
.30723 .51633 m .31058 .51764 L .311 .51672 L F
.889 .777 .732 r
.3098 .51325 m .311 .51672 L .31143 .51331 L F
.557 .274 .442 r
.31058 .51764 m .31343 .51908 L .311 .51672 L F
0 0 0 r
.34963 .57291 m .35387 .5742 L .35232 .57413 L F
.737 .445 .485 r
.35055 .5756 m .35232 .57413 L .35387 .5742 L F
.761 .747 .84 r
.64314 .39671 m .64567 .39587 L .64427 .39237 L F
.614 .638 .85 r
.64567 .39587 m .64687 .39122 L .64427 .39237 L F
.64567 .39587 m .64928 .39548 L .64687 .39122 L F
.617 .583 .793 r
.64567 .39587 m .64829 .39657 L .64928 .39548 L F
.513 .513 .793 r
.64567 .39587 m .64943 .39902 L .64829 .39657 L F
.627 .773 .95 r
.72592 .3375 m .7223 .33576 L .72428 .33445 L F
.556 .634 .884 r
.72702 .3337 m .72592 .3375 L .72428 .33445 L F
.72702 .3337 m .72857 .3367 L .72592 .3375 L F
.857 .858 .841 r
.68233 .32011 m .67823 .32179 L .68104 .31864 L F
.508 .661 .93 r
.57614 .42966 m .57743 .43142 L .57443 .43093 L F
.734 .588 .693 r
.65862 .37463 m .65437 .37642 L .65689 .37384 L F
.65862 .37463 m .65827 .37723 L .65437 .37642 L F
.743 .635 .74 r
.65952 .37012 m .65862 .37463 L .65689 .37384 L F
0 0 0 r
.71459 .32631 m .71508 .32686 L .71606 .32496 L F
.435 0 0 r
.33383 .52784 m .33597 .52896 L .33731 .52939 L F
.983 .717 .44 r
.33731 .52939 m .33857 .52548 L .33998 .5292 L F
.33731 .52939 m .33605 .52607 L .33857 .52548 L F
.33731 .52939 m .33597 .52896 L .33605 .52607 L F
.635 .526 .713 r
.24276 .5811 m .24322 .58369 L .24554 .58051 L F
.448 .321 .614 r
.22365 .57511 m .22198 .58046 L .22185 .57721 L F
.777 .996 .86 r
.71655 .33954 m .71291 .34172 L .71517 .34018 L F
.768 .996 .857 r
.71876 .33761 m .71655 .33954 L .71795 .33718 L F
.751 .974 .712 r
.71795 .33718 m .71655 .33954 L .71517 .34018 L F
.962 .943 .68 r
.39973 .55321 m .40031 .5548 L .40079 .55478 L F
.53 .599 .867 r
.40091 .55153 m .40079 .55478 L .40249 .55021 L F
.868 .975 .853 r
.40249 .55021 m .39973 .55321 L .40079 .55478 L F
.774 .872 .92 r
.38464 .6385 m .38708 .63752 L .38512 .6363 L F
.785 .873 .913 r
.38512 .6363 m .38708 .63752 L .39021 .63503 L F
.883 .493 .036 r
.63612 .43137 m .63694 .43366 L .63594 .43288 L F
.679 .825 .389 r
.63837 .42696 m .63612 .43137 L .63493 .43004 L F
.696 .602 .747 r
.66194 .36399 m .65944 .36755 L .65902 .36445 L F
.828 .825 .846 r
.38457 .67781 m .38385 .68214 L .38436 .68125 L F
.552 .154 .241 r
.2545 .56219 m .25696 .56392 L .25862 .56306 L F
.503 .557 .843 r
.44176 .54424 m .43991 .54673 L .4394 .54457 L F
.44176 .54424 m .44317 .54728 L .43991 .54673 L F
.42 0 0 r
.34539 .55336 m .34744 .55434 L .34318 .55322 L F
.034 0 .36 r
.20405 .57096 m .20487 .57276 L .2051 .57007 L F
.20405 .57096 m .20379 .5736 L .20487 .57276 L F
.548 .613 .87 r
.61934 .37212 m .61764 .37443 L .61644 .3708 L F
.503 .55 .837 r
.62063 .37422 m .61764 .37443 L .61934 .37212 L F
.692 .605 .755 r
.24554 .58051 m .24322 .58369 L .24591 .58295 L F
.791 .676 .737 r
.6649 .3797 m .66632 .38375 L .66235 .38287 L F
.441 .151 .375 r
.66632 .38375 m .66331 .38671 L .66235 .38287 L F
.66632 .38375 m .66597 .38598 L .66331 .38671 L F
.573 .556 .797 r
.66885 .38276 m .66632 .38375 L .6649 .3797 L F
.477 .224 .451 r
.66885 .38276 m .66597 .38598 L .66632 .38375 L F
.866 .681 .65 r
.54307 .42754 m .54482 .43164 L .54311 .42975 L F
.736 .629 .741 r
.54307 .42754 m .54721 .42936 L .54482 .43164 L F
.384 .187 .485 r
.31068 .60871 m .3077 .61258 L .30781 .60921 L F
.544 .523 .782 r
.42924 .5004 m .42658 .5026 L .42698 .50092 L F
.42924 .5004 m .43031 .50437 L .42658 .5026 L F
.53 .911 .942 r
.35031 .71717 m .35415 .7165 L .3526 .71596 L F
0 0 0 r
.35031 .71717 m .3526 .71596 L .35057 .71728 L F
.35031 .71717 m .35057 .71728 L .35053 .7173 L F
.167 0 0 r
.34921 .7169 m .35015 .7171 L .35031 .71717 L F
.35015 .7171 m .35197 .71749 L .35031 .71717 L F
.53 .911 .942 r
.35031 .71717 m .35197 .71749 L .35415 .7165 L F
.99 .794 .546 r
.32929 .54183 m .32845 .54267 L .32762 .54015 L F
.032 0 0 r
.32929 .54183 m .32799 .54355 L .32845 .54267 L F
.204 .141 .56 r
.32997 .5447 m .33161 .5443 L .32929 .54183 L F
.64 .148 .069 r
.32929 .54183 m .33161 .5443 L .32799 .54355 L F
.732 .616 .728 r
.66211 .36675 m .66329 .37071 L .65952 .37012 L F
.729 .614 .729 r
.66211 .36675 m .66588 .36735 L .66329 .37071 L F
.652 .548 .724 r
.31907 .54197 m .31672 .54505 L .31758 .54344 L F
.695 .644 .794 r
.39335 .57369 m .3967 .57413 L .39531 .57039 L F
.066 .241 .734 r
.39531 .57039 m .3967 .57413 L .39763 .57246 L F
.621 .731 .925 r
.39643 .57258 m .3967 .57413 L .39335 .57369 L F
.148 .351 .809 r
.39763 .57246 m .3967 .57413 L .39643 .57258 L F
.189 0 0 r
.69445 .36115 m .69629 .36195 L .69416 .36329 L F
.69445 .36115 m .69714 .36047 L .69629 .36195 L F
.213 0 .089 r
.35722 .66605 m .35366 .66956 L .35617 .66863 L F
.166 0 .307 r
.35885 .66501 m .35722 .66605 L .35791 .66504 L F
0 0 0 r
.35791 .66504 m .35722 .66605 L .35617 .66863 L F
.623 .117 .027 r
.24362 .56028 m .24151 .56218 L .2398 .56043 L F
.772 .601 .666 r
.68787 .34794 m .69057 .34471 L .68814 .34526 L F
.68787 .34794 m .69172 .34852 L .69057 .34471 L F
.974 .916 .679 r
.4028 .60799 m .40394 .60602 L .40177 .60731 L F
.984 .9 .579 r
.40313 .60533 m .40394 .60602 L .40482 .60193 L F
.945 .96 .715 r
.40177 .60731 m .40394 .60602 L .40313 .60533 L F
.36 .108 .39 r
.36243 .64687 m .36011 .64855 L .36153 .64916 L F
.238 .227 .644 r
.36011 .64855 m .36073 .6508 L .36153 .64916 L F
.768 .747 .834 r
.54307 .41324 m .545 .41716 L .54206 .41857 L F
.459 .586 .893 r
.54757 .41671 m .545 .41716 L .54307 .41324 L F
.307 .247 .625 r
.30769 .58981 m .30754 .59323 L .30977 .59167 L F
.411 .272 .581 r
.30754 .59323 m .30975 .59456 L .30977 .59167 L F
.30754 .59323 m .30798 .59557 L .30975 .59456 L F
.627 .331 .448 r
.27075 .62381 m .27377 .62171 L .27131 .62213 L F
.708 .64 .779 r
.39216 .64538 m .38848 .64384 L .3907 .64397 L F
.232 .609 .953 r
.39267 .64441 m .39216 .64538 L .3907 .64397 L F
.39267 .64441 m .39516 .64607 L .39216 .64538 L F
.709 .931 .608 r
.64255 .44085 m .64111 .44197 L .6399 .44412 L F
0 0 0 r
.6449 .43743 m .64443 .43896 L .64255 .44085 L F
.534 .862 .581 r
.64443 .43896 m .64111 .44197 L .64255 .44085 L F
.978 .793 .586 r
.37751 .61162 m .37857 .60947 L .37931 .60767 L F
.421 .088 .294 r
.28264 .61497 m .28486 .61527 L .28659 .6119 L F
.687 .374 0 r
.60275 .40309 m .60283 .40348 L .60048 .40101 L F
.60275 .40309 m .60347 .40525 L .60283 .40348 L F
.308 0 .239 r
.3084 .53579 m .31085 .53516 L .31153 .53281 L F
.475 0 0 r
.31275 .53391 m .31153 .53281 L .31085 .53516 L F
.31275 .53391 m .3154 .53547 L .31153 .53281 L F
.747 .775 .276 r
.44225 .57082 m .44323 .56694 L .44572 .57024 L F
.44225 .57082 m .44197 .5707 L .44323 .56694 L F
.414 .609 .929 r
.44101 .57266 m .44195 .57074 L .44225 .57082 L F
.44195 .57074 m .44197 .5707 L .44198 .5707 L F
.44101 .57266 m .4423 .57191 L .44197 .5707 L F
.062 0 .283 r
.44101 .57266 m .44054 .57508 L .4423 .57191 L F
0 0 0 r
.44054 .57508 m .44182 .57377 L .4423 .57191 L F
.931 .713 .23 r
.4423 .57191 m .44182 .57377 L .44178 .57094 L F
.44185 .57086 m .44178 .57094 L .44178 .57068 L F
.4423 .57191 m .44178 .57094 L .44185 .57086 L F
.414 .609 .929 r
.44195 .57074 m .44198 .5707 L .44225 .57082 L F
.904 .888 .805 r
.70045 .31336 m .70324 .31021 L .70196 .30712 L F
0 0 .128 r
.37564 .57334 m .37397 .577 L .37312 .57357 L F
.37564 .57334 m .37547 .57569 L .37397 .577 L F
.546 0 0 r
.37435 .57742 m .37397 .577 L .37547 .57569 L F
.37542 .57865 m .37462 .5789 L .37397 .577 L F
.252 0 .09 r
.37143 .57889 m .37388 .57789 L .37547 .57569 L F
.611 .829 .436 r
.37547 .57569 m .37388 .57789 L .3757 .57535 L F
.531 .18 .317 r
.37564 .57334 m .37802 .57552 L .37547 .57569 L F
.37564 .57334 m .37802 .57552 L .37547 .57569 L F
.611 .829 .436 r
.37547 .57569 m .3757 .57535 L .37575 .57527 L F
.546 0 0 r
.37542 .57865 m .37435 .57742 L .37547 .57569 L F
.987 .717 .405 r
.39127 .51524 m .3899 .51509 L .39003 .51272 L F
.847 .407 0 r
.39127 .51524 m .39151 .5176 L .3899 .51509 L F
.39127 .51524 m .39299 .51887 L .39151 .5176 L F
.692 .473 .585 r
.44439 .58281 m .44096 .58313 L .44105 .58046 L F
0 .278 .782 r
.36836 .59429 m .37109 .59816 L .36866 .59651 L F
.562 .205 .321 r
.36866 .59651 m .37109 .59816 L .36917 .59821 L F
.979 .714 .454 r
.43938 .55821 m .43939 .56099 L .43727 .55989 L F
.579 .829 .459 r
.44197 .55491 m .43938 .55821 L .44057 .55659 L F
.598 .894 .604 r
.43727 .55989 m .43938 .55821 L .44057 .55659 L F
.684 .567 .717 r
.44197 .55491 m .44245 .55791 L .43938 .55821 L F
.647 .416 .555 r
.44245 .55791 m .43939 .56099 L .43938 .55821 L F
.111 .149 .621 r
.37646 .54461 m .37675 .54869 L .37363 .5471 L F
.37646 .54461 m .37703 .5485 L .37675 .54869 L F
.128 .181 .65 r
.37703 .5485 m .37821 .5511 L .37675 .54869 L F
.37703 .5485 m .37821 .5511 L .37675 .54869 L F
.852 .581 .529 r
.25918 .53909 m .26169 .54234 L .26324 .54229 L F
0 0 0 r
.26169 .54234 m .26122 .54261 L .26324 .54229 L F
.26122 .54261 m .26586 .5414 L .26324 .54229 L F
.989 .729 .431 r
.40368 .57241 m .40519 .57093 L .40399 .56974 L F
.40368 .57241 m .40511 .57355 L .40519 .57093 L F
.591 .245 .352 r
.44124 .56806 m .44203 .57007 L .43838 .5683 L F
.434 .409 .732 r
.43838 .5683 m .44203 .57007 L .44008 .56568 L F
.543 .3 .498 r
.32648 .58634 m .32355 .58879 L .3239 .58677 L F
0 0 0 r
.73912 .32725 m .74222 .32556 L .73971 .32617 L F
.32353 .61585 m .32116 .61906 L .32216 .61807 L F
.531 .325 .545 r
.32216 .61807 m .32489 .61464 L .32353 .61585 L F
.34 .384 .762 r
.66786 .39739 m .66491 .39826 L .66501 .3956 L F
.209 0 .355 r
.66564 .40096 m .66491 .39826 L .66786 .39739 L F
.75 .681 .784 r
.65703 .37084 m .65689 .37384 L .65183 .37272 L F
.768 .643 .723 r
.65183 .37272 m .65689 .37384 L .65437 .37642 L F
.782 .708 .782 r
.65952 .37012 m .65689 .37384 L .65703 .37084 L F
.81 .754 .801 r
.39416 .50668 m .39617 .50812 L .3931 .50902 L F
.21 .334 .772 r
.63694 .43366 m .63783 .43675 L .63964 .43554 L F
0 0 0 r
.63783 .43675 m .63765 .43715 L .63964 .43554 L F
.233 .397 .821 r
.39836 .64961 m .39701 .64985 L .39516 .64607 L F
.369 .258 .595 r
.29524 .64929 m .29328 .64758 L .29411 .6444 L F
.755 .571 .647 r
.42869 .55818 m .42975 .56175 L .42622 .56096 L F
.581 .57 .805 r
.43113 .55513 m .42869 .55818 L .42882 .55514 L F
.43113 .55513 m .43223 .55773 L .42869 .55818 L F
.391 .353 .696 r
.43231 .56069 m .42869 .55818 L .43223 .55773 L F
.43231 .56069 m .42975 .56175 L .42869 .55818 L F
.717 .645 .776 r
.66467 .36388 m .66588 .36735 L .66211 .36675 L F
.72 .646 .775 r
.66898 .36396 m .66588 .36735 L .66467 .36388 L F
.768 .672 .756 r
.42778 .55136 m .42882 .55514 L .4249 .55464 L F
.238 .325 .751 r
.42994 .55317 m .42882 .55514 L .42778 .55136 L F
.38 .507 .861 r
.43113 .55513 m .42882 .55514 L .42994 .55317 L F
.247 .069 .432 r
.37904 .6519 m .37691 .65036 L .37659 .65303 L F
.828 .825 .846 r
.38457 .67781 m .38689 .67916 L .38385 .68214 L F
0 .071 .557 r
.27909 .62704 m .27947 .62724 L .27711 .62948 L F
.542 .377 .607 r
.40853 .49304 m .40599 .49747 L .40843 .4953 L F
.944 .857 .724 r
.40853 .49304 m .40843 .4953 L .40794 .49454 L F
.965 .933 .696 r
.40599 .49747 m .40794 .49454 L .40843 .4953 L F
.542 .377 .607 r
.40853 .49304 m .40683 .49738 L .40599 .49747 L F
.965 .933 .696 r
.40599 .49747 m .40668 .49263 L .40794 .49454 L F
.542 .377 .607 r
.40794 .49454 m .40832 .49722 L .40683 .49738 L F
.40853 .49304 m .40849 .49371 L .40794 .49454 L F
.40849 .49371 m .40832 .49722 L .40794 .49454 L F
.944 .857 .724 r
.40853 .49304 m .40794 .49454 L .40668 .49263 L F
.805 .941 .916 r
.38253 .65828 m .38218 .66015 L .38465 .65812 L F
.852 .946 .879 r
.38369 .65806 m .38446 .65815 L .38535 .6577 L F
.699 .337 .358 r
.37955 .66128 m .38253 .65828 L .37987 .65893 L F
0 .132 .614 r
.38342 .66 m .38218 .66015 L .38253 .65828 L F
.38423 .66155 m .3833 .66091 L .38342 .66 L F
.3833 .66091 m .38218 .66015 L .38342 .66 L F
.38423 .66155 m .38472 .66215 L .38218 .66015 L F
.699 .337 .358 r
.37955 .66128 m .38423 .66155 L .38253 .65828 L F
0 0 0 r
.38253 .65828 m .38446 .65815 L .38169 .65849 L F
.852 .946 .879 r
.38169 .65849 m .38366 .65825 L .38369 .65806 L F
.805 .941 .916 r
.38253 .65828 m .38465 .65812 L .38446 .65815 L F
.852 .946 .879 r
.38366 .65825 m .38446 .65815 L .38369 .65806 L F
.496 .892 .948 r
.39157 .57357 m .39643 .57258 L .39335 .57369 L F
.097 .05 .51 r
.44262 .56355 m .44124 .56806 L .44095 .56453 L F
.554 .353 .562 r
.44008 .56568 m .44262 .56355 L .44095 .56453 L F
.588 .945 .903 r
.33862 .66441 m .34319 .66294 L .34212 .66307 L F
.643 .967 .86 r
.34319 .66294 m .34526 .66155 L .34393 .66155 L F
.657 .969 .818 r
.34212 .66307 m .34319 .66294 L .34393 .66155 L F
.14 0 0 r
.38606 .58593 m .3875 .58619 L .38496 .58641 L F
.38606 .58593 m .38891 .58543 L .3875 .58619 L F
.638 .592 .787 r
.66597 .38598 m .66498 .39138 L .66384 .38888 L F
.66597 .38598 m .66726 .39007 L .66498 .39138 L F
.554 .425 .659 r
.66726 .39007 m .66492 .3929 L .66498 .39138 L F
.788 .963 .65 r
.32159 .68567 m .31981 .68817 L .32071 .68611 L F
0 0 .271 r
.32071 .68611 m .31981 .68817 L .32027 .69094 L F
.51 .146 .284 r
.33999 .65843 m .33838 .65605 L .33819 .65907 L F
.33999 .65843 m .34206 .6551 L .33838 .65605 L F
1 .819 .495 r
.25285 .57609 m .25388 .57752 L .25418 .57418 L F
.25285 .57609 m .25418 .57418 L .25553 .57275 L F
.637 .399 .541 r
.60317 .44701 m .6007 .44975 L .60065 .44699 L F
.833 .781 .803 r
.57282 .41435 m .5744 .41675 L .5703 .41767 L F
.748 .759 .861 r
.57282 .41435 m .57677 .41488 L .5744 .41675 L F
.358 .017 .243 r
.71257 .30943 m .71244 .31176 L .70968 .31257 L F
0 0 .135 r
.71406 .30849 m .71244 .31176 L .71257 .30943 L F
.025 0 .136 r
.66323 .40409 m .66327 .40208 L .66564 .40096 L F
.472 .587 .888 r
.36894 .55764 m .367 .5588 L .36548 .55659 L F
.827 .849 .863 r
.64566 .41627 m .64697 .41796 L .64363 .41798 L F
.825 .848 .865 r
.6498 .41498 m .64697 .41796 L .64566 .41627 L F
.971 .679 .417 r
.37086 .60087 m .37238 .60217 L .37281 .60002 L F
.37086 .60087 m .37281 .60002 L .37109 .59816 L F
.37086 .60087 m .37238 .60217 L .37281 .60002 L F
.11 0 .226 r
.37281 .60002 m .37238 .60217 L .37451 .59875 L F
.91 .785 .711 r
.34595 .51006 m .34258 .51201 L .34493 .51031 L F
.34595 .51006 m .34435 .51408 L .34258 .51201 L F
.736 .992 .859 r
.6399 .44412 m .64111 .44197 L .63761 .44453 L F
0 0 0 r
.40482 .60193 m .40538 .59919 L .40432 .60155 L F
.984 .9 .579 r
.40313 .60533 m .40482 .60193 L .40432 .60155 L F
.809 .677 .718 r
.65515 .35105 m .65673 .35491 L .65306 .35406 L F
.805 .689 .737 r
.65306 .35406 m .65673 .35491 L .65465 .35831 L F
.592 .487 .704 r
.6607 .37942 m .65827 .37723 L .66065 .37661 L F
.6607 .37942 m .65885 .38033 L .65827 .37723 L F
.808 .727 .197 r
.40491 .67239 m .40451 .67506 L .40457 .67572 L F
.856 .899 .865 r
.40143 .67735 m .40457 .67572 L .40451 .67506 L F
.834 .808 .826 r
.39452 .59637 m .39242 .59911 L .39038 .59754 L F
.326 .324 .704 r
.39038 .59754 m .3921 .59791 L .39206 .5976 L F
.231 0 0 r
.3914 .59623 m .39038 .59754 L .3886 .59747 L F
.834 .808 .826 r
.39452 .59637 m .39038 .59754 L .3914 .59623 L F
.326 .324 .704 r
.39038 .59754 m .39206 .5976 L .39157 .59361 L F
.231 0 0 r
.3886 .59747 m .39038 .59754 L .38768 .59788 L F
.788 .697 .764 r
.65465 .35831 m .65394 .36062 L .65198 .36154 L F
.85 .646 .106 r
.40688 .58515 m .40712 .58342 L .40603 .58298 L F
.40688 .58515 m .40723 .58607 L .40712 .58342 L F
.984 .808 .409 r
.70385 .33124 m .70475 .32954 L .70314 .32863 L F
.70385 .33124 m .70459 .33243 L .70475 .32954 L F
0 0 0 r
.31518 .50633 m .31701 .5037 L .31786 .50687 L F
.31518 .50633 m .31473 .5074 L .31701 .5037 L F
.939 .683 .523 r
.54206 .41857 m .54223 .42151 L .54012 .41683 L F
.768 .747 .834 r
.54307 .41324 m .54206 .41857 L .54012 .41683 L F
.339 .651 .969 r
.54206 .41857 m .54307 .41704 L .54012 .41683 L F
.54206 .41857 m .54512 .4195 L .54307 .41704 L F
.685 .482 .607 r
.54206 .41857 m .54512 .4195 L .54223 .42151 L F
.753 .938 .601 r
.36805 .64905 m .36857 .64906 L .36909 .64759 L F
.68 .934 .968 r
.3662 .64983 m .36886 .64906 L .36857 .64906 L F
0 0 .202 r
.36679 .65083 m .3662 .64983 L .36857 .64906 L F
.753 .938 .601 r
.36679 .65083 m .36857 .64906 L .36805 .64905 L F
.68 .934 .968 r
.36886 .64906 m .37061 .64854 L .36857 .64906 L F
.664 .974 .856 r
.37061 .64854 m .37191 .64698 L .36857 .64906 L F
.72 .631 .757 r
.67 .37311 m .66741 .37617 L .66739 .37388 L F
0 0 .454 r
.60263 .41709 m .60099 .41472 L .60042 .41337 L F
.756 .828 .908 r
.3099 .51052 m .30595 .51047 L .30794 .50928 L F
.338 0 0 r
.30794 .50928 m .31235 .50995 L .3099 .51052 L F
.797 .407 .316 r
.28693 .61719 m .28877 .62083 L .29056 .61831 L F
.121 0 0 r
.29056 .61831 m .29099 .61981 L .29299 .6185 L F
.29056 .61831 m .28877 .62083 L .29099 .61981 L F
.81 .999 .837 r
.37526 .64627 m .37689 .64305 L .37334 .64528 L F
.37526 .64627 m .3783 .64332 L .37689 .64305 L F
.293 0 0 r
.28026 .52622 m .27799 .52724 L .27569 .52713 L F
.533 .54 .808 r
.28026 .52622 m .284 .52915 L .28254 .5259 L F
0 0 0 r
.28033 .5265 m .28026 .52622 L .28254 .5259 L F
.28033 .5265 m .27799 .52724 L .28026 .52622 L F
.804 1 .824 r
.38231 .55291 m .38059 .55349 L .38056 .55476 L F
0 0 .479 r
.38059 .55349 m .38186 .55732 L .38056 .55476 L F
.619 .247 .316 r
.32558 .6336 m .32824 .63333 L .32605 .63182 L F
.612 .849 .479 r
.73648 .33639 m .73769 .33505 L .73754 .33426 L F
.796 .976 .69 r
.74005 .33104 m .73769 .33505 L .74042 .3319 L F
.74005 .33104 m .73754 .33426 L .73769 .33505 L F
.307 .247 .625 r
.30769 .58981 m .30977 .59167 L .30924 .58914 L F
.682 .843 .96 r
.45503 .56888 m .45076 .56917 L .45377 .56713 L F
.447 .58 .893 r
.45611 .56646 m .45503 .56888 L .45377 .56713 L F
.45611 .56646 m .4579 .56962 L .45503 .56888 L F
0 0 0 r
.26344 .5421 m .26469 .54186 L .26469 .54186 L F
.26256 .54226 m .26344 .5421 L .26586 .5414 L F
.146 .145 .599 r
.26891 .53725 m .26586 .5414 L .26344 .5421 L F
0 0 0 r
.26344 .5421 m .26469 .54186 L .26891 .53725 L F
.26122 .54261 m .26344 .5421 L .26256 .54226 L F
.697 .247 .178 r
.27098 .53519 m .26708 .53448 L .26765 .53785 L F
.26868 .53477 m .26893 .53663 L .26708 .53448 L F
.27098 .53519 m .26893 .53663 L .26868 .53477 L F
.146 .145 .599 r
.26891 .53725 m .2685 .54295 L .26597 .54147 L F
.2675 .53917 m .26597 .54147 L .26586 .5414 L F
.26891 .53725 m .26597 .54147 L .2675 .53917 L F
.761 .505 .546 r
.26891 .53725 m .26469 .54186 L .26825 .54171 L F
0 0 .101 r
.26863 .53903 m .26862 .53921 L .26891 .53725 L F
.26862 .53921 m .2685 .54295 L .26891 .53725 L F
.26858 .54053 m .26871 .54169 L .2685 .54295 L F
0 0 0 r
.26648 .54703 m .26411 .54802 L .26445 .54783 L F
.26648 .54703 m .26445 .54783 L .2679 .54584 L F
.234 0 .224 r
.26914 .54406 m .26648 .54703 L .2679 .54584 L F
.26914 .54406 m .26855 .54621 L .26648 .54703 L F
.26855 .54621 m .26834 .54697 L .26648 .54703 L F
.31 0 .254 r
.27056 .54626 m .26914 .54406 L .2685 .54295 L F
.27056 .54626 m .26834 .54697 L .26914 .54406 L F
0 0 .575 r
.26854 .54267 m .27056 .54626 L .2685 .54295 L F
.26871 .54169 m .26981 .54441 L .26854 .54267 L F
.26981 .54441 m .27056 .54626 L .26854 .54267 L F
.706 .941 .639 r
.26788 .54663 m .26834 .54697 L .27056 .54626 L F
.648 .272 .318 r
.26788 .54663 m .27152 .54694 L .27158 .54686 L F
.27083 .54582 m .27158 .54686 L .27284 .54527 L F
.833 .514 .449 r
.26871 .54169 m .27284 .54527 L .27056 .54626 L F
.648 .272 .318 r
.27284 .54527 m .27092 .54579 L .27056 .54626 L F
.27092 .54579 m .26788 .54663 L .27032 .54629 L F
.27092 .54579 m .27032 .54629 L .27056 .54626 L F
.833 .514 .449 r
.26871 .54169 m .2687 .54179 L .27284 .54527 L F
.2687 .54179 m .26839 .54503 L .27084 .54516 L F
.2687 .54179 m .27084 .54516 L .27284 .54527 L F
.417 0 0 r
.27245 .54453 m .27077 .54462 L .27155 .54214 L F
.648 .272 .318 r
.26788 .54663 m .27284 .54527 L .26927 .54508 L F
.26828 .54538 m .26927 .54508 L .26839 .54503 L F
.26788 .54663 m .26927 .54508 L .26828 .54538 L F
.27284 .54527 m .27152 .54694 L .26788 .54663 L F
0 0 0 r
.27478 .54425 m .27152 .54694 L .27284 .54527 L F
.27478 .54425 m .27152 .54694 L .27284 .54527 L F
.417 0 0 r
.27291 .54575 m .27051 .54602 L .27077 .54463 L F
.27077 .54463 m .27077 .54463 L .27077 .54462 L F
.27291 .54575 m .27077 .54463 L .27077 .54463 L F
.27291 .54575 m .27173 .54513 L .27245 .54453 L F
.27173 .54513 m .27077 .54462 L .27245 .54453 L F
.648 .272 .318 r
.26788 .54663 m .27158 .54686 L .27083 .54582 L F
.501 .865 .986 r
.26871 .54169 m .26469 .54186 L .26684 .54105 L F
.76 .443 .45 r
.27077 .54462 m .26839 .54503 L .26871 .54169 L F
.26884 .54287 m .26871 .54169 L .26684 .54105 L F
.27077 .54462 m .26871 .54169 L .26884 .54287 L F
0 0 .101 r
.26862 .53921 m .26871 .54169 L .26858 .54053 L F
.761 .505 .546 r
.26891 .53725 m .26862 .53921 L .26871 .54169 L F
0 0 .101 r
.26863 .53903 m .26871 .54169 L .26862 .53921 L F
.761 .505 .546 r
.26862 .53921 m .26825 .54171 L .26871 .54169 L F
.26891 .53725 m .26871 .54169 L .26863 .53903 L F
.397 .096 .333 r
.27151 .53643 m .26863 .53903 L .26893 .53663 L F
.535 .462 .72 r
.26887 .53711 m .26897 .53693 L .26893 .53663 L F
.087 0 .344 r
.27294 .53113 m .27098 .53519 L .27121 .53286 L F
.27294 .53113 m .27121 .53286 L .27125 .53252 L F
.492 .249 .473 r
.27457 .52946 m .27445 .52962 L .27294 .53113 L F
.76 .871 .445 r
.27166 .53323 m .27098 .53519 L .27294 .53113 L F
.492 .249 .473 r
.27445 .52962 m .27166 .53323 L .27294 .53113 L F
.548 .335 .544 r
.27166 .53323 m .26893 .53663 L .27098 .53519 L F
.27166 .53323 m .27151 .53643 L .26893 .53663 L F
.535 .462 .72 r
.26897 .53693 m .27051 .53418 L .26893 .53663 L F
.26863 .53903 m .27008 .5353 L .26887 .53711 L F
.27008 .5353 m .27051 .53418 L .26887 .53711 L F
.554 .425 .659 r
.66726 .39007 m .66762 .39227 L .66492 .3929 L F
.492 .281 .521 r
.66762 .39227 m .66501 .3956 L .66492 .3929 L F
.634 .615 .814 r
.28817 .53273 m .284 .52915 L .28608 .53125 L F
.592 .363 .538 r
.28817 .53273 m .28794 .53557 L .28545 .53505 L F
.519 .814 .999 r
.28608 .53125 m .28864 .53086 L .28817 .53273 L F
0 0 .033 r
.28845 .53343 m .28817 .53273 L .28864 .53086 L F
.28845 .53343 m .28794 .53557 L .28817 .53273 L F
.928 .637 .162 r
.70697 .36124 m .7064 .36224 L .70593 .35994 L F
.70697 .36124 m .70729 .36372 L .7064 .36224 L F
.716 .531 .638 r
.59352 .41792 m .59786 .4182 L .59639 .4213 L F
.771 .889 .929 r
.60743 .3883 m .60487 .39242 L .60352 .39085 L F
.60743 .3883 m .60836 .38986 L .60487 .39242 L F
.406 .853 .773 r
.55866 .42169 m .55373 .42356 L .55711 .42018 L F
.106 0 0 r
.29197 .64186 m .29193 .6407 L .29057 .64299 L F
.29197 .64186 m .29433 .63999 L .29193 .6407 L F
.713 .62 .752 r
.63901 .39599 m .64314 .39671 L .6412 .39573 L F
.761 .747 .84 r
.64314 .39671 m .64427 .39237 L .6412 .39573 L F
.387 .138 .409 r
.42615 .59218 m .42633 .59001 L .42938 .58966 L F
.426 .655 .955 r
.26739 .6341 m .26861 .63243 L .2657 .63293 L F
.26739 .6341 m .2695 .63392 L .26861 .63243 L F
.58 .117 .119 r
.2421 .54631 m .2396 .54783 L .23706 .54735 L F
.547 .075 .087 r
.24353 .54758 m .2396 .54783 L .2421 .54631 L F
.187 .122 .547 r
.24312 .54499 m .24353 .54758 L .2421 .54631 L F
.385 .162 .448 r
.31812 .59568 m .31649 .5996 L .31561 .59963 L F
.329 .106 .416 r
.3201 .59784 m .31812 .59568 L .32007 .59497 L F
.3201 .59784 m .31649 .5996 L .31812 .59568 L F
.204 0 .121 r
.3319 .56488 m .33081 .56686 L .32871 .56759 L F
0 0 0 r
.33257 .56505 m .3319 .56488 L .33323 .56293 L F
.33257 .56505 m .33081 .56686 L .3319 .56488 L F
.818 .999 .833 r
.24036 .53068 m .23869 .53292 L .23909 .53091 L F
.82 1 .829 r
.23869 .53292 m .23603 .53388 L .23909 .53091 L F
.306 .246 .624 r
.37379 .68679 m .3738 .69386 L .37178 .68903 L F
.058 .622 .766 r
.72934 .336 m .73129 .33602 L .73091 .33607 L F
.407 0 .03 r
.73091 .33607 m .73358 .33604 L .73436 .33461 L F
.058 .622 .766 r
.73129 .33602 m .73358 .33604 L .73091 .33607 L F
0 0 0 r
.73016 .33617 m .73091 .33607 L .73175 .33564 L F
.72857 .3367 m .73091 .33607 L .73016 .33617 L F
.393 .228 .535 r
.73175 .33564 m .73436 .33461 L .73368 .33237 L F
.407 0 .03 r
.73091 .33607 m .73436 .33461 L .73175 .33564 L F
.544 .634 .89 r
.36934 .57173 m .37248 .57111 L .37209 .57186 L F
.985 .704 .371 r
.35477 .67855 m .35642 .67859 L .35496 .67499 L F
.63 .466 .642 r
.35389 .68204 m .35648 .68178 L .35642 .67859 L F
.972 .745 .537 r
.35648 .68178 m .35642 .67859 L .35389 .68204 L F
.935 .732 .254 r
.35559 .67988 m .35648 .68178 L .35642 .67859 L F
.701 .624 .768 r
.35648 .68178 m .36032 .68228 L .35914 .67811 L F
.958 .864 .703 r
.36032 .68228 m .36312 .67905 L .36278 .68149 L F
.589 .556 .785 r
.35914 .67811 m .36032 .68228 L .36278 .68149 L F
.726 .196 0 r
.35888 .6792 m .36128 .68055 L .35941 .6797 L F
.935 .732 .254 r
.356 .67966 m .35642 .67859 L .35889 .67816 L F
.35559 .67988 m .35569 .67971 L .356 .67966 L F
.35569 .67971 m .35642 .67859 L .356 .67966 L F
.35559 .67988 m .35889 .67816 L .35889 .67824 L F
.35889 .67824 m .35889 .67816 L .35914 .67811 L F
.35559 .67988 m .35914 .67811 L .35702 .67742 L F
.726 .196 0 r
.35702 .67742 m .35889 .67879 L .35888 .6792 L F
.35702 .67742 m .35914 .67811 L .36128 .68055 L F
.492 .327 .585 r
.35702 .67742 m .35888 .6792 L .35943 .67682 L F
.726 .196 0 r
.35889 .67879 m .36128 .68055 L .35888 .6792 L F
.492 .327 .585 r
.35888 .6792 m .35941 .6797 L .35942 .67911 L F
.589 .556 .785 r
.35914 .67811 m .36278 .68149 L .36128 .68055 L F
.492 .327 .585 r
.35888 .6792 m .35942 .67911 L .35943 .67682 L F
.608 .709 .916 r
.30477 .51904 m .30861 .52014 L .30723 .51633 L F
.73 .644 .764 r
.30723 .51633 m .30861 .52014 L .31058 .51764 L F
.801 .808 .322 r
.3092 .52224 m .31058 .51764 L .30861 .52014 L F
.14 .685 .793 r
.23293 .55689 m .23675 .55664 L .23369 .55636 L F
.462 .242 .494 r
.65885 .38033 m .65845 .38244 L .65626 .38329 L F
.64 .536 .72 r
.65845 .38244 m .65722 .38726 L .65626 .38329 L F
.76 .602 .682 r
.65944 .36755 m .65952 .37012 L .65703 .37084 L F
.696 .602 .747 r
.66194 .36399 m .66211 .36675 L .65944 .36755 L F
.732 .616 .728 r
.66211 .36675 m .65952 .37012 L .65944 .36755 L F
.577 .272 .415 r
.4564 .57409 m .45481 .57715 L .45254 .57683 L F
.522 .444 .709 r
.4579 .56962 m .45876 .57349 L .4564 .57409 L F
.519 .249 .445 r
.45876 .57349 m .45481 .57715 L .4564 .57409 L F
.643 .941 .96 r
.27874 .51979 m .27486 .52072 L .27722 .51985 L F
.286 .779 .73 r
.27961 .51935 m .27874 .51979 L .27722 .51985 L F
.27961 .51935 m .28135 .51886 L .27874 .51979 L F
.456 .382 .685 r
.29024 .54785 m .28863 .55108 L .28843 .54856 L F
.736 .813 .912 r
.65196 .37771 m .64517 .37902 L .65005 .37556 L F
.733 .702 .821 r
.65005 .37556 m .65437 .37642 L .65196 .37771 L F
.998 .807 .456 r
.59765 .39567 m .59805 .39877 L .59787 .3982 L F
.662 .118 0 r
.59805 .39877 m .60048 .40101 L .59889 .40024 L F
.59805 .39877 m .59889 .40024 L .59787 .3982 L F
.53 .1 .17 r
.2276 .57403 m .22629 .57574 L .22365 .57511 L F
.214 0 0 r
.22843 .57503 m .2276 .57403 L .22985 .57333 L F
.22843 .57503 m .22629 .57574 L .2276 .57403 L F
.365 .132 .421 r
.2301 .57092 m .22985 .57333 L .2276 .57403 L F
.663 .601 .776 r
.42698 .50092 m .42299 .49788 L .42577 .49723 L F
.445 .375 .685 r
.42872 .49637 m .42698 .50092 L .42577 .49723 L F
.42872 .49637 m .42924 .5004 L .42698 .50092 L F
.429 .105 .313 r
.29566 .62772 m .29476 .63068 L .29235 .63107 L F
.3 0 .261 r
.29693 .62995 m .29566 .62772 L .29804 .62711 L F
.29693 .62995 m .29476 .63068 L .29566 .62772 L F
.587 .184 .246 r
.688 .35034 m .69172 .34852 L .68787 .34794 L F
.688 .35034 m .69102 .35031 L .69172 .34852 L F
.382 0 .051 r
.69395 .34978 m .69172 .34852 L .69102 .35031 L F
.69395 .34978 m .69484 .34797 L .69172 .34852 L F
.707 .675 .817 r
.64795 .36113 m .6492 .36464 L .64508 .36391 L F
.748 .587 .677 r
.6492 .36464 m .64715 .36747 L .64508 .36391 L F
.6492 .36464 m .64883 .3672 L .64715 .36747 L F
.772 .71 .793 r
.65198 .36154 m .6492 .36464 L .64795 .36113 L F
.864 .689 .664 r
.3484 .71393 m .34921 .7169 L .34807 .71658 L F
.167 0 0 r
.34921 .7169 m .35031 .71717 L .34807 .71658 L F
.969 .928 .617 r
.40656 .59559 m .40767 .59329 L .40584 .59484 L F
.982 .909 .604 r
.40584 .59484 m .40767 .59329 L .40696 .59117 L F
.454 .469 .785 r
.28834 .64224 m .28565 .64258 L .2851 .6416 L F
.452 .224 .476 r
.31014 .65564 m .30846 .65352 L .3078 .65641 L F
.667 .668 .842 r
.66384 .38888 m .65983 .38613 L .66331 .38671 L F
.587 .553 .783 r
.66597 .38598 m .66384 .38888 L .66331 .38671 L F
.637 .399 .541 r
.60317 .44701 m .60352 .44974 L .6007 .44975 L F
.65 .408 .54 r
.60726 .44917 m .60317 .44701 L .60745 .44675 L F
.60726 .44917 m .60352 .44974 L .60317 .44701 L F
.547 .746 .969 r
.3316 .69094 m .33329 .69244 L .32922 .69149 L F
.3316 .69094 m .33329 .69244 L .32922 .69149 L F
.695 .794 .926 r
.3316 .69094 m .33568 .69135 L .33329 .69244 L F
0 0 0 r
.39016 .6741 m .38731 .67844 L .38757 .67811 L F
.292 .682 .974 r
.38757 .67811 m .38689 .67916 L .38457 .67781 L F
.566 .863 .552 r
.39328 .70065 m .39659 .69738 L .39607 .69764 L F
.714 .917 .568 r
.39721 .69583 m .39607 .69764 L .39659 .69738 L F
.709 .483 .579 r
.43433 .54255 m .42944 .54541 L .43178 .54133 L F
.454 .469 .785 r
.28834 .64224 m .2851 .6416 L .28704 .63964 L F
.442 .299 .591 r
.27635 .53911 m .27864 .54116 L .27843 .53846 L F
.27843 .53846 m .27864 .54116 L .27635 .53911 L F
.982 .692 .349 r
.40542 .57877 m .40653 .57728 L .40577 .57603 L F
.40542 .57877 m .40669 .57978 L .40653 .57728 L F
.042 .506 .886 r
.42868 .57219 m .42548 .5706 L .42512 .57319 L F
.42868 .57219 m .42512 .57319 L .42718 .57256 L F
.54 0 0 r
.42718 .57256 m .43145 .57346 L .42868 .57219 L F
.597 .519 .737 r
.24591 .58295 m .2481 .57989 L .24554 .58051 L F
.24591 .58295 m .24917 .58393 L .2481 .57989 L F
.772 .981 .909 r
.63038 .39424 m .62415 .39692 L .62714 .39342 L F
.846 .886 .869 r
.63117 .39227 m .63038 .39424 L .62714 .39342 L F
.672 .975 .833 r
.30595 .51047 m .3037 .5124 L .30196 .51281 L F
.293 .62 .959 r
.20692 .59857 m .20793 .59757 L .20503 .59686 L F
.737 .655 .769 r
.55021 .41752 m .55276 .41558 L .54939 .41492 L F
.509 .337 .583 r
.31575 .56784 m .3182 .5699 L .31829 .56715 L F
.37 .15 .444 r
.28707 .63705 m .28745 .63449 L .28956 .63385 L F
.199 0 .13 r
.25399 .54497 m .25626 .54432 L .25705 .54214 L F
.496 .116 .248 r
.25705 .54214 m .25626 .54432 L .25896 .54381 L F
.649 .566 .748 r
.25705 .54214 m .26169 .54234 L .25918 .53909 L F
.543 .1 .147 r
.25705 .54214 m .25896 .54381 L .26169 .54234 L F
.007 .489 .869 r
.34186 .49675 m .34618 .49881 L .34332 .49862 L F
0 0 0 r
.6449 .43743 m .64762 .43438 L .64653 .43597 L F
.64584 .43716 m .6449 .43743 L .64653 .43597 L F
.64584 .43716 m .64443 .43896 L .6449 .43743 L F
.492 .032 .088 r
.69567 .33708 m .69822 .33737 L .69958 .33598 L F
.723 .679 .806 r
.60919 .37028 m .61189 .37395 L .60747 .37366 L F
.937 .729 .596 r
.61189 .37395 m .60947 .37488 L .60747 .37366 L F
.61189 .37395 m .6116 .37653 L .60947 .37488 L F
.776 .812 .882 r
.61233 .37026 m .61189 .37395 L .60919 .37028 L F
.801 .992 .876 r
.38107 .64073 m .38464 .6385 L .3827 .63879 L F
.774 .872 .92 r
.38464 .6385 m .38512 .6363 L .3827 .63879 L F
0 .098 .631 r
.6357 .39036 m .63503 .39281 L .63413 .38919 L F
.791 .879 .451 r
.63397 .39426 m .63503 .39281 L .6357 .39036 L F
.302 0 .145 r
.69078 .36551 m .6915 .36321 L .69416 .36329 L F
0 0 0 r
.38741 .64744 m .38593 .64987 L .38717 .649 L F
.42 .865 .812 r
.38717 .649 m .38593 .64987 L .38474 .65003 L F
.388 .844 .777 r
.38468 .64965 m .38717 .649 L .38474 .65003 L F
.615 .077 0 r
.38699 .65015 m .38717 .649 L .38468 .64965 L F
.38892 .65058 m .38717 .649 L .38699 .65015 L F
0 0 0 r
.38782 .64677 m .38741 .64744 L .38717 .649 L F
.724 .721 .194 r
.38848 .64384 m .38782 .64677 L .388 .64544 L F
.697 .873 .964 r
.38717 .649 m .388 .64544 L .38782 .64677 L F
.835 .465 .352 r
.32116 .61906 m .32322 .62101 L .32101 .62175 L F
.51 .298 .527 r
.32322 .62101 m .3205 .62427 L .32101 .62175 L F
.276 .039 .362 r
.31504 .60411 m .31349 .60241 L .31543 .60161 L F
.31504 .60411 m .31293 .60495 L .31349 .60241 L F
.6 .623 .846 r
.63033 .421 m .62802 .41941 L .63025 .41785 L F
0 0 .523 r
.63106 .42059 m .63033 .421 L .63025 .41785 L F
0 0 0 r
.62979 .42255 m .63033 .421 L .63106 .42059 L F
.268 .054 .392 r
.23176 .5723 m .2301 .57092 L .23288 .57085 L F
.23176 .5723 m .22985 .57333 L .23001 .57174 L F
.23176 .5723 m .23001 .57174 L .23139 .572 L F
.249 0 0 r
.22581 .5741 m .22841 .574 L .23204 .57212 L F
0 0 0 r
.23233 .57197 m .23224 .57204 L .23433 .57167 L F
.355 .044 .293 r
.2328 .57195 m .23091 .57435 L .23176 .5723 L F
.23334 .57185 m .23091 .57435 L .2328 .57195 L F
0 0 0 r
.23224 .57204 m .2343 .57168 L .23433 .57167 L F
.353 .519 .882 r
.23233 .57197 m .23433 .57167 L .23431 .57165 L F
.23233 .57197 m .23431 .57165 L .23374 .5717 L F
.355 .044 .293 r
.23386 .57169 m .23091 .57435 L .23348 .57172 L F
.306 0 .231 r
.23176 .5723 m .23091 .57435 L .22843 .57503 L F
.355 .044 .293 r
.23376 .57178 m .23312 .574 L .23091 .57435 L F
.361 .051 .296 r
.23542 .57331 m .23312 .574 L .23396 .57174 L F
.23542 .57331 m .23396 .57174 L .23401 .57173 L F
.23542 .57331 m .23398 .57169 L .23417 .57169 L F
.355 .044 .293 r
.23396 .57174 m .23312 .574 L .23376 .57178 L F
0 0 0 r
.23378 .57178 m .23078 .5733 L .2343 .57168 L F
.23376 .57178 m .23376 .57178 L .23378 .57178 L F
.23376 .57178 m .23078 .5733 L .23378 .57178 L F
.361 .051 .296 r
.23401 .57173 m .23396 .57174 L .23398 .57169 L F
.23417 .57169 m .23398 .57169 L .23404 .57152 L F
.353 .519 .882 r
.2338 .57169 m .23431 .57165 L .23428 .57159 L F
.355 .044 .293 r
.23404 .57152 m .23386 .57169 L .23348 .57172 L F
.353 .519 .882 r
.23379 .57169 m .23381 .57169 L .2338 .57169 L F
.355 .044 .293 r
.23404 .57152 m .23398 .57169 L .23386 .57169 L F
.353 .519 .882 r
.23381 .57169 m .23431 .57165 L .2338 .57169 L F
.23374 .5717 m .23386 .57169 L .23379 .57169 L F
.23386 .57169 m .23431 .57165 L .23379 .57169 L F
.355 .044 .293 r
.23386 .57169 m .23396 .57174 L .23376 .57178 L F
.23398 .57169 m .23396 .57174 L .23386 .57169 L F
0 0 0 r
.23224 .57204 m .23219 .57209 L .23376 .57178 L F
.23219 .57209 m .23078 .5733 L .23376 .57178 L F
.355 .044 .293 r
.23348 .57172 m .23334 .57185 L .2328 .57195 L F
.158 0 0 r
.23404 .57152 m .23348 .57172 L .23288 .57085 L F
.23348 .57172 m .23241 .57188 L .23288 .57085 L F
.249 0 0 r
.23214 .57203 m .23218 .57205 L .23233 .57197 L F
.22581 .5741 m .23214 .57203 L .22638 .57144 L F
.23214 .57203 m .23233 .57197 L .23221 .57196 L F
.158 0 0 r
.23214 .57203 m .23202 .57197 L .2322 .57197 L F
.268 .054 .392 r
.23139 .572 m .23001 .57174 L .2301 .57092 L F
.249 0 0 r
.23214 .57203 m .23221 .57196 L .22638 .57144 L F
.158 0 0 r
.2322 .57197 m .23202 .57197 L .23211 .57185 L F
.306 0 .231 r
.23176 .5723 m .22843 .57503 L .22985 .57333 L F
0 0 0 r
.23227 .57202 m .22841 .574 L .23078 .5733 L F
.23233 .57197 m .23218 .57205 L .23227 .57202 L F
.158 0 0 r
.23231 .57212 m .23176 .5723 L .23202 .57197 L F
0 0 0 r
.23218 .57205 m .22841 .574 L .23227 .57202 L F
.158 0 0 r
.23224 .57203 m .23214 .57203 L .2322 .57197 L F
.23231 .57212 m .23218 .57205 L .23224 .57203 L F
.23218 .57205 m .23214 .57203 L .23224 .57203 L F
.786 .446 .413 r
.22789 .56762 m .22638 .57144 L .23221 .57196 L F
.23226 .57189 m .23221 .57196 L .23233 .57197 L F
.22789 .56762 m .23221 .57196 L .23226 .57189 L F
.158 0 0 r
.2326 .57147 m .23211 .57185 L .23288 .57085 L F
.23239 .57193 m .23226 .57189 L .2326 .57147 L F
.23226 .57189 m .23211 .57185 L .2326 .57147 L F
.786 .446 .413 r
.23226 .57189 m .23233 .57197 L .23229 .5719 L F
.158 0 0 r
.23231 .57212 m .23211 .57185 L .23239 .57193 L F
.786 .446 .413 r
.22789 .56762 m .23226 .57189 L .22915 .56732 L F
.23226 .57189 m .23229 .5719 L .22915 .56732 L F
.26 0 .123 r
.23578 .56871 m .2351 .57017 L .23288 .57085 L F
.158 0 0 r
.23404 .57152 m .23288 .57085 L .2351 .57017 L F
.395 0 .044 r
.23909 .56892 m .23404 .57152 L .2351 .57017 L F
.23909 .56892 m .23657 .57137 L .23404 .57152 L F
.361 .051 .296 r
.23617 .57204 m .23404 .57152 L .23657 .57137 L F
.23542 .57331 m .23417 .57169 L .23617 .57204 L F
.23417 .57169 m .23404 .57152 L .23617 .57204 L F
.353 .519 .882 r
.23221 .57135 m .23428 .57159 L .23138 .56703 L F
.23232 .57189 m .23392 .57165 L .23221 .57135 L F
.23392 .57165 m .23428 .57159 L .23221 .57135 L F
.23233 .57197 m .23428 .57159 L .23232 .57189 L F
.158 0 0 r
.23348 .57172 m .23231 .57212 L .23241 .57188 L F
.249 0 0 r
.23193 .5721 m .23204 .57212 L .23218 .57205 L F
.23193 .5721 m .23218 .57205 L .23214 .57203 L F
.22581 .5741 m .23204 .57212 L .23193 .5721 L F
.716 .531 .638 r
.59352 .41792 m .59639 .4213 L .59557 .42167 L F
.703 .55 .677 r
.6607 .37942 m .65845 .38244 L .65885 .38033 L F
.369 .258 .595 r
.29524 .64929 m .29431 .64529 L .29398 .64587 L F
.29431 .64529 m .29411 .6444 L .29398 .64587 L F
0 .074 .633 r
.295 .6479 m .29524 .64929 L .29398 .64587 L F
.615 .529 .734 r
.29667 .64566 m .295 .6479 L .29398 .64587 L F
.156 .696 .812 r
.29398 .64587 m .29499 .64556 L .29364 .6465 L F
.925 .62 .448 r
.29231 .64742 m .295 .6479 L .29398 .64587 L F
.156 .696 .812 r
.29398 .64587 m .29364 .6465 L .29231 .64742 L F
0 0 0 r
.29411 .6444 m .29565 .64346 L .29398 .64587 L F
.341 0 .193 r
.29565 .64346 m .29667 .64566 L .29398 .64587 L F
.29565 .64346 m .29824 .6429 L .29667 .64566 L F
.421 .272 .572 r
.34236 .56801 m .34428 .56733 L .3444 .56422 L F
.479 .27 .517 r
.35412 .68523 m .35648 .68178 L .35389 .68204 L F
.35412 .68523 m .35648 .68178 L .35389 .68204 L F
.785 .512 .523 r
.36197 .61499 m .36576 .61818 L .36623 .61534 L F
.478 .271 .52 r
.36817 .6175 m .36576 .61818 L .36623 .61534 L F
.36817 .6175 m .36576 .61818 L .36623 .61534 L F
.819 .857 .876 r
.65959 .34093 m .65953 .34434 L .65804 .34541 L F
.807 .849 .881 r
.66268 .34118 m .65953 .34434 L .65959 .34093 L F
.647 .416 .555 r
.44245 .55791 m .44283 .56139 L .43939 .56099 L F
.539 .36 .587 r
.44508 .55462 m .44245 .55791 L .44197 .55491 L F
.44508 .55462 m .44543 .55772 L .44245 .55791 L F
.527 .326 .551 r
.44543 .55772 m .44283 .56139 L .44245 .55791 L F
.843 .956 .612 r
.41137 .50678 m .40966 .50841 L .4103 .50888 L F
.708 .259 .182 r
.4103 .50888 m .41136 .51036 L .41268 .50975 L F
.675 .772 .924 r
.39519 .67814 m .39937 .6786 L .39748 .67554 L F
.727 .48 .552 r
.39519 .67814 m .39924 .68115 L .39937 .6786 L F
.667 .768 .926 r
.39748 .67554 m .39937 .6786 L .40143 .67735 L F
.574 .343 .528 r
.35433 .62466 m .35718 .62427 L .35748 .62158 L F
.35748 .62158 m .35718 .62427 L .35433 .62466 L F
.42 .454 .789 r
.35593 .61765 m .35748 .62158 L .3593 .6209 L F
.354 .157 .468 r
.35748 .62158 m .35922 .6236 L .3593 .6209 L F
.35748 .62158 m .35718 .62427 L .35922 .6236 L F
.35922 .6236 m .35748 .62158 L .3593 .6209 L F
.35922 .6236 m .35718 .62427 L .35748 .62158 L F
.7 .419 .495 r
.37486 .56477 m .3704 .5655 L .37047 .5644 L F
.37486 .56477 m .37352 .56736 L .3704 .5655 L F
.166 0 .188 r
.37486 .56477 m .37352 .56736 L .3768 .56375 L F
.37486 .56477 m .37352 .56736 L .3768 .56375 L F
.567 .597 .843 r
.43311 .50382 m .43098 .50647 L .43031 .50437 L F
.684 .688 .847 r
.43311 .50382 m .43197 .50802 L .43098 .50647 L F
.096 0 .267 r
.24532 .54123 m .24387 .5422 L .24597 .53885 L F
.032 0 .269 r
.24525 .54251 m .24387 .5422 L .24532 .54123 L F
.24525 .54251 m .24312 .54499 L .24387 .5422 L F
.54 .455 .708 r
.73566 .3398 m .73315 .34396 L .73291 .34193 L F
.938 .567 .233 r
.41603 .5639 m .41497 .56391 L .41411 .56056 L F
.933 .69 .209 r
.41583 .56733 m .41497 .56391 L .41603 .5639 L F
.763 .502 .539 r
.56548 .4563 m .56164 .45315 L .56569 .45311 L F
.753 .563 .638 r
.56951 .45623 m .56548 .4563 L .56569 .45311 L F
.618 .935 .961 r
.37804 .58745 m .38259 .58679 L .37748 .58687 L F
0 .013 .579 r
.37804 .58745 m .37748 .58687 L .37741 .58365 L F
0 .026 .588 r
.37741 .58365 m .37688 .58664 L .37804 .58745 L F
.751 .683 .137 r
.64921 .43246 m .64931 .4323 L .64944 .43027 L F
0 0 0 r
.64653 .43597 m .64931 .4323 L .64896 .43488 L F
.751 .683 .137 r
.64896 .43488 m .64931 .4323 L .64921 .43246 L F
0 0 0 r
.64762 .43438 m .64945 .43208 L .64931 .4323 L F
.64945 .43208 m .65025 .43108 L .64931 .4323 L F
.64653 .43597 m .64762 .43438 L .64931 .4323 L F
.743 .645 .751 r
.63854 .36652 m .63998 .37077 L .63584 .36986 L F
.747 .38 .359 r
.63584 .36986 m .63998 .37077 L .64008 .37301 L F
.755 .651 .747 r
.64255 .36719 m .63998 .37077 L .63854 .36652 L F
.593 .257 .37 r
.63998 .37077 m .64233 .3722 L .64008 .37301 L F
.646 .499 .669 r
.64255 .36719 m .64512 .37163 L .63998 .37077 L F
.616 .214 .258 r
.63998 .37077 m .64512 .37163 L .64233 .3722 L F
.621 .066 0 r
.2296 .61156 m .22727 .61141 L .2249 .60963 L F
0 .12 .652 r
.2296 .61156 m .23177 .61352 L .23123 .61242 L F
.23 .61167 m .23123 .61242 L .23099 .61193 L F
.2296 .61156 m .23123 .61242 L .23 .61167 L F
.251 .639 .962 r
.23177 .61352 m .232 .61211 L .23099 .61193 L F
0 .347 .824 r
.23177 .61352 m .2333 .61425 L .23258 .61306 L F
.2319 .61271 m .23258 .61306 L .232 .61211 L F
.23177 .61352 m .23258 .61306 L .2319 .61271 L F
.217 .363 .797 r
.2333 .61425 m .23438 .6139 L .232 .61211 L F
.379 0 0 r
.2335 .61353 m .23293 .61346 L .23208 .61294 L F
.23438 .6139 m .23398 .61378 L .2335 .61353 L F
.23398 .61378 m .23293 .61346 L .2335 .61353 L F
.378 .823 .945 r
.23099 .61193 m .2251 .6125 L .22727 .61141 L F
0 .12 .652 r
.2296 .61156 m .23099 .61193 L .22727 .61141 L F
.378 .823 .945 r
.22957 .61207 m .2295 .61149 L .2251 .6125 L F
.23099 .61193 m .22963 .61153 L .22957 .61207 L F
.22963 .61153 m .2295 .61149 L .22957 .61207 L F
0 0 .452 r
.22963 .61153 m .22956 .6103 L .22821 .60792 L F
.22981 .612 m .22968 .6111 L .22963 .61153 L F
.22968 .6111 m .22956 .6103 L .22963 .61153 L F
.379 0 0 r
.23208 .61294 m .23229 .61327 L .22981 .612 L F
.23293 .61346 m .23229 .61327 L .23208 .61294 L F
.351 .144 .453 r
.35373 .5341 m .35234 .53208 L .35314 .53169 L F
.692 .552 .691 r
.44508 .55462 m .44197 .55491 L .44461 .55168 L F
.526 .522 .794 r
.44578 .54724 m .44461 .55168 L .44317 .54728 L F
.44578 .54724 m .44698 .55112 L .44461 .55168 L F
.493 .408 .688 r
.44698 .55112 m .44508 .55462 L .44461 .55168 L F
.782 .613 .67 r
.33735 .53245 m .341 .53561 L .3392 .53347 L F
.33735 .53245 m .33938 .53607 L .341 .53561 L F
.794 .661 .715 r
.33938 .53607 m .33919 .53881 L .341 .53561 L F
.527 .737 .971 r
.3392 .53347 m .341 .53561 L .3434 .53318 L F
0 .17 .616 r
.341 .53561 m .34187 .53606 L .3434 .53318 L F
.471 .84 .991 r
.26728 .52839 m .26528 .5275 L .26289 .52811 L F
.118 .662 .833 r
.26974 .52781 m .26528 .5275 L .26728 .52839 L F
.832 .656 .664 r
.59001 .42902 m .59097 .43201 L .59031 .43219 L F
.805 .771 .822 r
.59265 .42993 m .59494 .4322 L .58938 .43351 L F
.526 .074 .12 r
.58938 .43351 m .59494 .4322 L .59258 .43502 L F
.772 .769 .85 r
.59729 .42943 m .59494 .4322 L .59265 .42993 L F
.765 .362 .289 r
.59258 .43502 m .59494 .4322 L .5963 .4354 L F
.022 0 0 r
.26637 .53433 m .26429 .53499 L .26708 .53448 L F
.279 .144 .512 r
.20207 .57698 m .20378 .57626 L .20379 .5736 L F
.286 .235 .624 r
.20207 .57698 m .20416 .57902 L .20378 .57626 L F
.20207 .57698 m .20216 .58055 L .20416 .57902 L F
.815 .788 .827 r
.34466 .52246 m .34114 .51961 L .34306 .51837 L F
.34466 .52246 m .34153 .5221 L .34114 .51961 L F
.34466 .52246 m .34284 .52344 L .34153 .5221 L F
.694 .721 .871 r
.34731 .51997 m .34466 .52246 L .34306 .51837 L F
.19 0 0 r
.32303 .55623 m .32513 .55606 L .3261 .55491 L F
.464 .325 .606 r
.32303 .55623 m .32473 .56016 L .32513 .55606 L F
.32303 .55623 m .32329 .56085 L .32473 .56016 L F
.667 .273 .29 r
.56951 .45623 m .56595 .45822 L .56548 .4563 L F
.56951 .45623 m .56818 .45822 L .56595 .45822 L F
.689 .299 .304 r
.56951 .45623 m .57218 .45854 L .56818 .45822 L F
.624 .337 .462 r
.57216 .45628 m .57218 .45854 L .56951 .45623 L F
.855 .917 .873 r
.65804 .34541 m .65405 .34716 L .65669 .34395 L F
.819 .857 .876 r
.65959 .34093 m .65804 .34541 L .65669 .34395 L F
.097 .05 .51 r
.44262 .56355 m .44323 .56694 L .44124 .56806 L F
.071 0 .455 r
.44323 .56694 m .44203 .57007 L .44124 .56806 L F
.707 .723 .862 r
.44852 .57042 m .44572 .57024 L .44732 .56945 L F
.216 0 0 r
.44732 .56945 m .45076 .56917 L .44852 .57042 L F
0 0 .189 r
.27924 .55151 m .28015 .55545 L .27965 .55292 L F
.779 .949 .93 r
.28015 .55545 m .27701 .55507 L .27965 .55292 L F
.626 .586 .789 r
.70711 .34686 m .70482 .3484 L .70385 .34448 L F
0 0 .155 r
.3261 .55491 m .32785 .5511 L .32477 .55113 L F
.3261 .55491 m .32724 .55376 L .32785 .5511 L F
.302 .079 .4 r
.32513 .55606 m .32724 .55376 L .3261 .55491 L F
.462 .209 .443 r
.35477 .67855 m .35496 .67499 L .35248 .67568 L F
.35477 .67855 m .35496 .67499 L .35248 .67568 L F
.358 0 0 r
.35158 .67028 m .35366 .66956 L .35114 .6691 L F
.669 .808 .949 r
.25147 .551 m .25599 .55134 L .25386 .54891 L F
.318 .486 .868 r
.25599 .55134 m .25587 .54818 L .25386 .54891 L F
.25599 .55134 m .25783 .55151 L .25587 .54818 L F
0 0 .383 r
.3257 .57879 m .32462 .57712 L .326 .5761 L F
.3257 .57879 m .32442 .58084 L .32462 .57712 L F
.815 .897 .483 r
.44197 .55491 m .44057 .55659 L .44237 .55305 L F
.7 .168 0 r
.34228 .65713 m .34206 .6551 L .33999 .65843 L F
.34228 .65713 m .34439 .65672 L .34206 .6551 L F
.633 .465 .638 r
.34206 .6551 m .34439 .65672 L .34426 .6535 L F
.684 .688 .847 r
.43311 .50382 m .43406 .50685 L .43197 .50802 L F
.417 .28 .585 r
.43406 .50685 m .43222 .51042 L .43197 .50802 L F
.16 .31 .768 r
.60255 .38664 m .60081 .38955 L .60003 .38691 L F
.251 .432 .846 r
.60255 .38664 m .60352 .39085 L .60081 .38955 L F
.605 .39 .563 r
.31835 .56446 m .31829 .56715 L .32097 .56404 L F
.794 .503 .497 r
.54886 .44402 m .54565 .44565 L .54649 .44303 L F
.54886 .44402 m .54952 .44652 L .54565 .44565 L F
.429 .576 .898 r
.43795 .55193 m .44018 .55179 L .43967 .55003 L F
.648 .553 .733 r
.42585 .54912 m .42495 .55179 L .42413 .54835 L F
.801 .714 .769 r
.59726 .38628 m .59304 .38588 L .59544 .386 L F
.59726 .38628 m .59477 .38973 L .59304 .38588 L F
.286 0 0 r
.59854 .38701 m .59726 .38628 L .59544 .386 L F
.464 .266 .526 r
.41504 .51306 m .41812 .50954 L .4153 .51015 L F
0 0 .037 r
.41538 .51109 m .41504 .51306 L .4153 .51015 L F
.41538 .51109 m .41268 .50975 L .41136 .51036 L F
.41538 .51109 m .4153 .51015 L .41268 .50975 L F
.711 .69 .827 r
.63901 .39599 m .6412 .39573 L .64138 .39303 L F
.664 .648 .824 r
.64138 .39303 m .6412 .39573 L .64427 .39237 L F
.597 .782 .969 r
.26851 .52134 m .26644 .5225 L .26529 .52199 L F
.352 .083 .359 r
.45013 .5772 m .44972 .5795 L .44734 .58016 L F
.491 .206 .408 r
.45254 .57683 m .44972 .5795 L .45013 .5772 L F
.673 .28 .294 r
.24765 .56624 m .25201 .56443 L .24787 .56459 L F
.24765 .56624 m .25025 .56651 L .25201 .56443 L F
.202 0 .134 r
.30542 .6175 m .30334 .61837 L .30655 .61562 L F
.244 0 .159 r
.30736 .61684 m .30655 .61562 L .3078 .61417 L F
.30736 .61684 m .30542 .6175 L .30655 .61562 L F
.891 .804 .757 r
.64135 .42087 m .64209 .42474 L .64066 .4234 L F
.699 .212 .088 r
.22727 .61141 m .2251 .6125 L .22326 .61045 L F
0 .118 .658 r
.22326 .61045 m .2251 .6125 L .2249 .61195 L F
.437 .215 .477 r
.22326 .61045 m .22146 .6088 L .2249 .60963 L F
.63 .094 0 r
.2249 .60963 m .22727 .61141 L .22326 .61045 L F
0 .118 .658 r
.22326 .61045 m .2249 .61195 L .2238 .60892 L F
.437 .215 .477 r
.22326 .61045 m .22096 .60868 L .22146 .6088 L F
.87 .834 .809 r
.31235 .50995 m .3098 .51325 L .31143 .51331 L F
.543 .369 .595 r
.36497 .53597 m .36752 .5355 L .36745 .53257 L F
.015 .522 .866 r
.36351 .53389 m .36752 .5355 L .36497 .53597 L F
.679 .66 .824 r
.41886 .4972 m .41499 .49421 L .41759 .49332 L F
.693 .671 .823 r
.42158 .49425 m .41886 .4972 L .41759 .49332 L F
.676 .642 .808 r
.42158 .49425 m .42299 .49788 L .41886 .4972 L F
0 0 0 r
.33137 .49848 m .3314 .49876 L .33333 .49779 L F
.413 .503 .842 r
.33096 .50261 m .3314 .49876 L .33137 .49848 L F
.711 .69 .827 r
.63901 .39599 m .64138 .39303 L .63655 .39017 L F
.417 .28 .585 r
.43406 .50685 m .43446 .51084 L .43222 .51042 L F
.37 .401 .763 r
.43446 .51084 m .43499 .51221 L .43222 .51042 L F
.343 .817 .767 r
.35916 .51185 m .3559 .51286 L .35678 .51358 L F
.983 .908 .626 r
.3559 .51286 m .35556 .51342 L .35678 .51358 L F
.343 .817 .767 r
.35916 .51185 m .35761 .51207 L .3559 .51286 L F
.318 .206 .565 r
.35761 .51207 m .35735 .51392 L .35556 .51342 L F
.35735 .51392 m .35728 .51441 L .35556 .51342 L F
.223 0 0 r
.35395 .51296 m .35556 .51342 L .35279 .51271 L F
.35678 .51358 m .35556 .51342 L .35395 .51296 L F
.777 .564 .611 r
.43681 .54554 m .43273 .54724 L .43456 .5442 L F
.43681 .54554 m .436 .54867 L .43273 .54724 L F
.915 .747 .659 r
.59304 .38588 m .59477 .38973 L .59284 .38793 L F
.981 .723 .466 r
.59477 .38973 m .59318 .39117 L .59284 .38793 L F
.59477 .38973 m .59473 .3922 L .59318 .39117 L F
.708 .727 .865 r
.64283 .36302 m .64255 .36719 L .63854 .36652 L F
.861 .854 .834 r
.64508 .36391 m .64255 .36719 L .64283 .36302 L F
.681 .559 .711 r
.64508 .36391 m .64715 .36747 L .64255 .36719 L F
.639 .461 .626 r
.64715 .36747 m .64512 .37163 L .64255 .36719 L F
.602 .941 .94 r
.72036 .33577 m .71876 .33761 L .71795 .33718 L F
.72036 .33577 m .7223 .33576 L .71876 .33761 L F
.754 .994 .865 r
.37689 .64305 m .3783 .64332 L .38107 .64073 L F
.511 .811 .999 r
.19028 .63405 m .19464 .63461 L .19243 .63342 L F
.19243 .63342 m .19464 .63461 L .19028 .63405 L F
.332 .727 .982 r
.19243 .63342 m .19464 .63461 L .19508 .63354 L F
.19508 .63354 m .19464 .63461 L .19243 .63342 L F
.19243 .63342 m .19464 .63461 L .19508 .63354 L F
.766 .607 .681 r
.32068 .52998 m .32435 .53275 L .32299 .52895 L F
.32068 .52998 m .32043 .53299 L .32435 .53275 L F
.496 0 0 r
.32043 .53299 m .32447 .53461 L .32435 .53275 L F
.134 .278 .746 r
.32299 .52895 m .32435 .53275 L .32549 .53101 L F
.46 .52 .833 r
.32447 .53461 m .32549 .53101 L .32435 .53275 L F
.496 .792 .998 r
.22201 .56431 m .2281 .5648 L .22433 .56373 L F
.709 .573 .699 r
.6649 .37716 m .6607 .37942 L .66065 .37661 L F
.862 .977 .676 r
.65169 .42688 m .65423 .42408 L .65433 .42339 L F
.65169 .42688 m .65213 .42733 L .65423 .42408 L F
.789 .933 .569 r
.32232 .68401 m .32159 .68567 L .32205 .68401 L F
.794 .963 .648 r
.32205 .68401 m .32159 .68567 L .32071 .68611 L F
.6 .922 .686 r
.59491 .43696 m .59373 .4376 L .5963 .4354 L F
.685 .594 .748 r
.66467 .36388 m .66211 .36675 L .66194 .36399 L F
.822 .999 .795 r
.74107 .3295 m .74042 .3319 L .74306 .32887 L F
.74107 .3295 m .74005 .33104 L .74042 .3319 L F
.577 .096 0 r
.39831 .52353 m .39874 .52421 L .39676 .52209 L F
.39831 .52353 m .40004 .52564 L .39874 .52421 L F
.493 .256 .484 r
.33413 .55511 m .33508 .55706 L .33281 .55454 L F
.498 .249 .467 r
.30532 .55179 m .30505 .55425 L .30258 .5547 L F
.541 .274 .459 r
.30824 .55153 m .30505 .55425 L .30532 .55179 L F
0 0 .439 r
.6271 .42931 m .6263 .43132 L .6257 .42765 L F
.664 .892 .98 r
.29134 .51888 m .2876 .51912 L .2899 .51835 L F
.648 .958 .932 r
.29209 .51723 m .29134 .51888 L .2899 .51835 L F
.29209 .51723 m .2946 .51723 L .29134 .51888 L F
.606 .528 .74 r
.37428 .60455 m .3758 .60268 L .37238 .60217 L F
.37428 .60455 m .3767 .60656 L .3758 .60268 L F
.546 .744 .968 r
.30576 .62276 m .30491 .6248 L .30308 .62117 L F
.30576 .62276 m .30729 .62427 L .30491 .6248 L F
.30576 .62276 m .30491 .6248 L .30351 .62338 L F
.30576 .62276 m .30729 .62427 L .30491 .6248 L F
.104 0 .022 r
.29804 .62711 m .30177 .62366 L .3002 .62597 L F
.778 .274 0 r
.29873 .53628 m .29473 .53244 L .29692 .53543 L F
0 0 .453 r
.74282 .32617 m .74306 .32887 L .74222 .32556 L F
.944 .961 .696 r
.74282 .32617 m .74107 .3295 L .74306 .32887 L F
.812 .738 .783 r
.65465 .35831 m .65011 .35999 L .65294 .35678 L F
.65465 .35831 m .65198 .36154 L .65011 .35999 L F
.805 .689 .737 r
.65306 .35406 m .65465 .35831 L .65294 .35678 L F
.267 .231 .631 r
.20216 .58055 m .20413 .58259 L .20416 .57902 L F
.20216 .58055 m .20274 .5832 L .20413 .58259 L F
.277 0 .12 r
.33443 .61012 m .33284 .61359 L .3306 .61411 L F
.246 0 .106 r
.33517 .61281 m .33284 .61359 L .33443 .61012 L F
.33517 .61281 m .33443 .61012 L .3343 .61031 L F
.629 .367 .503 r
.58227 .45303 m .58134 .45586 L .57866 .45585 L F
.595 .333 .489 r
.58478 .45506 m .58227 .45303 L .58515 .45249 L F
.58478 .45506 m .58134 .45586 L .58227 .45303 L F
.603 .418 .604 r
.4305 .58234 m .43303 .58228 L .43271 .5805 L F
.918 .644 .506 r
.43025 .58035 m .43174 .5803 L .42822 .58023 L F
.42742 .58045 m .4305 .58234 L .43174 .5803 L F
.603 .418 .604 r
.4305 .58234 m .43202 .5767 L .43174 .5803 L F
.43102 .5804 m .43271 .5805 L .43202 .5767 L F
.4305 .58234 m .43271 .5805 L .43102 .5804 L F
.918 .644 .506 r
.42742 .58045 m .43025 .58035 L .42671 .5802 L F
.43025 .58035 m .42822 .58023 L .42671 .5802 L F
.947 .957 .719 r
.64974 .42944 m .65213 .42733 L .65169 .42688 L F
.64974 .42944 m .65025 .43108 L .65213 .42733 L F
.648 .553 .733 r
.42585 .54912 m .42778 .55136 L .42495 .55179 L F
.631 .462 .636 r
.42778 .55136 m .4249 .55464 L .42495 .55179 L F
0 0 .421 r
.70354 .34269 m .7029 .34217 L .70247 .34047 L F
.70354 .34269 m .70385 .34448 L .7029 .34217 L F
.936 .859 .74 r
.56164 .45315 m .55824 .45455 L .55774 .45218 L F
.56164 .45315 m .55989 .45458 L .55824 .45455 L F
.801 .534 .534 r
.56164 .45315 m .56165 .45607 L .55989 .45458 L F
.763 .502 .539 r
.56548 .4563 m .56165 .45607 L .56164 .45315 L F
.121 0 .284 r
.64928 .39548 m .64829 .39657 L .651 .39448 L F
.6 .581 .804 r
.64943 .39902 m .651 .39448 L .64829 .39657 L F
.742 .676 .786 r
.42538 .49474 m .42299 .49788 L .42158 .49425 L F
.691 .599 .748 r
.42577 .49723 m .42299 .49788 L .42538 .49474 L F
.665 .695 .868 r
.57995 .398 m .58003 .39973 L .57642 .39909 L F
.821 .624 .636 r
.58003 .39973 m .57674 .40132 L .57642 .39909 L F
.58003 .39973 m .58093 .40329 L .57674 .40132 L F
.339 .426 .804 r
.58157 .39768 m .58003 .39973 L .57995 .398 L F
.486 .635 .92 r
.58157 .39768 m .58348 .40069 L .58003 .39973 L F
.764 .642 .726 r
.65183 .37272 m .65437 .37642 L .65005 .37556 L F
.485 .405 .69 r
.35276 .65267 m .35086 .65339 L .35074 .651 L F
.213 0 0 r
.62288 .45089 m .62392 .4507 L .62677 .45127 L F
.612 .92 .667 r
.28545 .53505 m .28177 .53823 L .28112 .53505 L F
.55 .258 .425 r
.28319 .53388 m .28459 .53521 L .2858 .53381 L F
.612 .92 .667 r
.28545 .53505 m .28294 .53661 L .28177 .53823 L F
.583 .337 .509 r
.28257 .53865 m .28557 .53613 L .28284 .53689 L F
0 0 0 r
.28247 .53926 m .28016 .54059 L .28177 .53823 L F
.28228 .5394 m .28016 .54059 L .28247 .53926 L F
.578 .601 .84 r
.28212 .53923 m .28432 .53991 L .28282 .53917 L F
.28432 .53991 m .28336 .53939 L .28282 .53917 L F
.2823 .53938 m .28547 .54052 L .28525 .54019 L F
.58 .612 .848 r
.28547 .54052 m .28248 .53928 L .28336 .53939 L F
.28547 .54052 m .28336 .53939 L .28711 .53986 L F
.578 .601 .84 r
.28432 .53991 m .28525 .54019 L .28336 .53939 L F
.28185 .53925 m .28224 .53936 L .28212 .53923 L F
.28224 .53936 m .28525 .54019 L .28212 .53923 L F
.45 .524 .843 r
.28228 .5394 m .28312 .54145 L .28016 .54059 L F
.578 .601 .84 r
.28229 .53941 m .28312 .54145 L .28547 .54052 L F
.28185 .53925 m .28312 .54145 L .28229 .53941 L F
.45 .524 .843 r
.28248 .53928 m .28263 .53977 L .28229 .53941 L F
.578 .601 .84 r
.28227 .5394 m .28547 .54052 L .2823 .53938 L F
.45 .524 .843 r
.28228 .5394 m .28229 .53941 L .28228 .5394 L F
.28248 .53928 m .28229 .53941 L .28228 .5394 L F
.28263 .53977 m .28312 .54145 L .28228 .5394 L F
0 0 0 r
.28248 .53928 m .28228 .5394 L .28247 .53926 L F
.578 .601 .84 r
.28185 .53925 m .28227 .5394 L .2823 .53938 L F
.696 .494 .61 r
.28557 .53613 m .28711 .53986 L .28336 .53939 L F
.28557 .53613 m .28336 .53939 L .28282 .53917 L F
.578 .601 .84 r
.28282 .53917 m .28525 .54019 L .28446 .53902 L F
.696 .494 .61 r
.28282 .53917 m .28336 .53939 L .28269 .53931 L F
.583 .337 .509 r
.28257 .53865 m .28318 .53877 L .28557 .53613 L F
.28248 .5392 m .28446 .53902 L .28257 .53865 L F
.696 .494 .61 r
.28557 .53613 m .28269 .53931 L .28248 .53928 L F
.583 .337 .509 r
.28318 .53877 m .28446 .53902 L .28557 .53613 L F
.28185 .53925 m .28248 .5392 L .28257 .53865 L F
.612 .92 .667 r
.28294 .53661 m .28294 .53661 L .28177 .53823 L F
.28294 .53661 m .28292 .53663 L .28177 .53823 L F
.28293 .53662 m .28288 .53666 L .28177 .53823 L F
0 0 0 r
.28257 .53865 m .28177 .53823 L .28287 .53667 L F
.28247 .53927 m .28247 .53927 L .28257 .53865 L F
.28247 .53927 m .28177 .53823 L .28257 .53865 L F
.28248 .53928 m .28247 .53927 L .28289 .53664 L F
.28247 .53927 m .28287 .53667 L .28289 .53664 L F
.583 .337 .509 r
.28284 .53689 m .28557 .53613 L .28296 .53659 L F
.28185 .53925 m .28257 .53865 L .28284 .53689 L F
.28211 .53733 m .28296 .53659 L .28219 .53673 L F
.28185 .53925 m .28296 .53659 L .28211 .53733 L F
.612 .92 .667 r
.28294 .53661 m .28294 .53661 L .28294 .53661 L F
.28294 .53661 m .28293 .53662 L .28292 .53663 L F
.55 .258 .425 r
.28319 .53388 m .28219 .53673 L .28296 .53659 L F
.134 0 0 r
.28557 .53613 m .28289 .53664 L .28545 .53505 L F
.55 .258 .425 r
.28459 .53521 m .28296 .53659 L .28557 .53613 L F
.28319 .53388 m .28296 .53659 L .28459 .53521 L F
.28459 .53521 m .28557 .53613 L .28576 .53421 L F
.28459 .53521 m .28576 .53421 L .2858 .53381 L F
.612 .92 .667 r
.28293 .53662 m .28289 .53664 L .28288 .53666 L F
.134 0 0 r
.28557 .53613 m .28545 .53505 L .28794 .53557 L F
.525 .619 .888 r
.32615 .66277 m .33018 .66496 L .33011 .66327 L F
.485 .405 .69 r
.35276 .65267 m .35074 .651 L .35368 .65114 L F
.506 .232 .433 r
.44734 .58016 m .44704 .58256 L .44439 .58281 L F
.521 .312 .538 r
.44972 .5795 m .44704 .58256 L .44734 .58016 L F
.587 .415 .616 r
.24554 .58051 m .2481 .57989 L .24787 .57671 L F
.438 .434 .757 r
.24787 .57671 m .25028 .5767 L .24907 .57295 L F
.614 .435 .617 r
.24787 .57671 m .25086 .57934 L .25028 .5767 L F
.24787 .57671 m .2481 .57989 L .25086 .57934 L F
.622 .058 0 r
.26477 .62327 m .2658 .62419 L .26582 .6237 L F
0 .118 .667 r
.26502 .62253 m .2658 .62419 L .26477 .62327 L F
.811 .477 0 r
.26502 .62253 m .26578 .62458 L .2658 .62419 L F
.26578 .62458 m .26648 .62647 L .2658 .62419 L F
.622 .058 0 r
.26582 .6237 m .2658 .62419 L .26844 .62478 L F
.904 .57 .402 r
.2658 .62419 m .26648 .62647 L .26844 .62478 L F
.28 0 0 r
.26844 .62478 m .27002 .62511 L .27075 .62381 L F
.26844 .62478 m .26648 .62647 L .27002 .62511 L F
.724 .721 .194 r
.38848 .64384 m .39004 .64379 L .3907 .64397 L F
.38848 .64384 m .388 .64544 L .39004 .64379 L F
.65 .65 .836 r
.3165 .64651 m .31778 .64965 L .31617 .64427 L F
0 0 .421 r
.32069 .64605 m .31808 .64399 L .32023 .64336 L F
.095 0 0 r
.31808 .64399 m .31617 .64427 L .31913 .64455 L F
0 0 .481 r
.31617 .64427 m .31866 .64711 L .31913 .64455 L F
.281 0 0 r
.3331 .577 m .33465 .57768 L .33717 .57692 L F
0 0 0 r
.33717 .57692 m .33757 .57531 L .33793 .5734 L F
.727 .986 .794 r
.33717 .57692 m .33465 .57768 L .33757 .57531 L F
.374 .133 .415 r
.33914 .57887 m .33717 .57692 L .33966 .57675 L F
.33914 .57887 m .33698 .57959 L .33717 .57692 L F
.956 .829 .398 r
.64931 .4323 m .65025 .43108 L .64974 .42944 L F
.675 .898 .549 r
.29759 .52193 m .29524 .52501 L .29649 .52357 L F
.265 .2 .595 r
.38995 .58925 m .3914 .58589 L .38891 .58543 L F
.38995 .58925 m .39248 .58879 L .3914 .58589 L F
.295 .032 .333 r
.38995 .58925 m .39178 .59115 L .39248 .58879 L F
.38995 .58925 m .39049 .59274 L .39178 .59115 L F
.921 .932 .565 r
.69671 .31757 m .69795 .3166 L .69651 .31516 L F
.69671 .31757 m .69698 .31872 L .69795 .3166 L F
.862 .867 .842 r
.69651 .31516 m .69795 .3166 L .70045 .31336 L F
.469 .271 .529 r
.30308 .62117 m .30087 .62174 L .30334 .61837 L F
.204 .488 .898 r
.2483 .62612 m .24906 .62448 L .24699 .62496 L F
.2483 .62612 m .25112 .62725 L .24906 .62448 L F
.493 .408 .688 r
.44698 .55112 m .44804 .55406 L .44508 .55462 L F
.53 .388 .632 r
.44804 .55406 m .44543 .55772 L .44508 .55462 L F
.679 .583 .74 r
.33018 .66496 m .33318 .66268 L .33011 .66327 L F
0 .162 .683 r
.64517 .37902 m .64531 .37981 L .64402 .37612 L F
.089 .58 .901 r
.35221 .50045 m .35392 .50144 L .34999 .50006 L F
.141 .57 .928 r
.35519 .50071 m .35392 .50144 L .35221 .50045 L F
.35519 .50071 m .35686 .50207 L .35392 .50144 L F
.515 0 0 r
.24437 .61252 m .24831 .61455 L .24686 .61389 L F
.906 .498 .131 r
.62749 .40763 m .62706 .4058 L .62546 .40473 L F
.507 .871 .984 r
.28592 .51854 m .28523 .51987 L .28337 .51919 L F
.28592 .51854 m .2876 .51912 L .28523 .51987 L F
.788 .877 .912 r
.37958 .6207 m .37912 .62218 L .37723 .62151 L F
.72 .391 .422 r
.37912 .62218 m .37618 .62384 L .37723 .62151 L F
.37912 .62218 m .38014 .62433 L .37618 .62384 L F
.45 .518 .836 r
.38165 .62023 m .37912 .62218 L .37958 .6207 L F
.897 .932 .831 r
.38132 .61741 m .37958 .6207 L .37981 .61871 L F
.45 .518 .836 r
.38165 .62023 m .37958 .6207 L .38119 .61766 L F
.38151 .61896 m .38119 .61766 L .38132 .61741 L F
.38165 .62023 m .38119 .61766 L .38151 .61896 L F
.653 .608 .792 r
.38148 .62036 m .38014 .62433 L .37912 .62218 L F
.38157 .62045 m .38014 .62433 L .38148 .62036 L F
.345 0 0 r
.37719 .62285 m .37958 .6207 L .37723 .62151 L F
.746 .505 .566 r
.37719 .62285 m .37981 .61871 L .37958 .6207 L F
.653 .608 .792 r
.38157 .62045 m .38277 .62369 L .38014 .62433 L F
.38165 .62023 m .3818 .62068 L .38157 .62045 L F
.3818 .62068 m .38277 .62369 L .38157 .62045 L F
.478 .824 .998 r
.38179 .62037 m .38277 .62369 L .38165 .62023 L F
.746 .505 .566 r
.38295 .62253 m .38368 .62249 L .3821 .62095 L F
0 .057 .566 r
.38307 .62181 m .38368 .62249 L .38356 .62226 L F
.478 .824 .998 r
.38355 .62224 m .3821 .62095 L .38179 .62037 L F
0 .057 .566 r
.38187 .62072 m .3821 .62095 L .38307 .62181 L F
.3821 .62095 m .38368 .62249 L .38307 .62181 L F
.478 .824 .998 r
.38317 .62294 m .38277 .62369 L .38179 .62037 L F
.993 .755 .462 r
.38014 .62433 m .37888 .62664 L .37618 .62384 L F
.38014 .62433 m .38018 .62704 L .37888 .62664 L F
.609 .432 .617 r
.38014 .62433 m .38277 .62369 L .38018 .62704 L F
.749 .515 .578 r
.38123 .62527 m .38321 .62303 L .37719 .62285 L F
.38321 .62303 m .38368 .62249 L .38295 .62253 L F
.38321 .62303 m .38295 .62253 L .37719 .62285 L F
.478 .824 .998 r
.38355 .62224 m .38317 .62294 L .38295 .62253 L F
.38213 .62098 m .38295 .62253 L .3821 .62095 L F
.38355 .62224 m .38295 .62253 L .38213 .62098 L F
.746 .505 .566 r
.38237 .62257 m .38295 .62253 L .38195 .6208 L F
.38295 .62253 m .3821 .62095 L .38195 .6208 L F
0 .057 .566 r
.38016 .61904 m .38187 .62072 L .38355 .62224 L F
.37981 .61871 m .38068 .61956 L .38016 .61904 L F
.38068 .61956 m .38187 .62072 L .38016 .61904 L F
.746 .505 .566 r
.37719 .62285 m .38237 .62257 L .37981 .61871 L F
.38237 .62257 m .38195 .6208 L .37981 .61871 L F
0 .057 .566 r
.38187 .62072 m .38356 .62226 L .38355 .62224 L F
.653 .608 .792 r
.38165 .62023 m .38157 .62045 L .38148 .62036 L F
.772 .71 .793 r
.65198 .36154 m .64795 .36113 L .65011 .35999 L F
.677 .472 .601 r
.64883 .3672 m .64682 .37067 L .64715 .36747 L F
.64883 .3672 m .64881 .36962 L .64682 .37067 L F
.756 .663 .759 r
.34439 .65672 m .34794 .65716 L .34689 .65291 L F
.708 .301 .274 r
.34625 .65933 m .34794 .65716 L .34439 .65672 L F
.08 .197 .687 r
.34689 .65291 m .34794 .65716 L .34899 .65503 L F
.708 .885 .497 r
.34899 .65503 m .34794 .65716 L .34625 .65933 L F
.486 .851 .99 r
.44096 .58313 m .43827 .58356 L .43962 .58232 L F
.44096 .58313 m .43827 .58356 L .43962 .58232 L F
.552 .385 .608 r
.44096 .58313 m .43861 .58654 L .43827 .58356 L F
.566 .4 .616 r
.34426 .6535 m .34689 .65291 L .34615 .65032 L F
0 0 .468 r
.34615 .65032 m .34755 .65148 L .34857 .6501 L F
.34615 .65032 m .34689 .65291 L .34755 .65148 L F
.927 .709 .587 r
.3484 .71393 m .34598 .71586 L .34633 .71306 L F
.3484 .71393 m .34807 .71658 L .34598 .71586 L F
.801 .808 .322 r
.3092 .52224 m .30927 .52096 L .31058 .51764 L F
.562 .165 .247 r
.31058 .51764 m .31205 .52058 L .31343 .51908 L F
.31058 .51764 m .30927 .52096 L .31205 .52058 L F
.756 .663 .759 r
.34439 .65672 m .34689 .65291 L .34426 .6535 L F
.53 .168 .299 r
.26761 .56781 m .26428 .57201 L .26225 .57028 L F
.381 .036 .25 r
.26883 .56734 m .26785 .56917 L .26761 .56781 L F
.418 .039 .209 r
.26785 .56917 m .26428 .57201 L .26761 .56781 L F
0 0 .189 r
.27924 .55151 m .27965 .55292 L .2815 .55194 L F
.163 .527 .92 r
.35686 .50207 m .35865 .50243 L .35808 .50355 L F
.12 .473 .894 r
.35865 .50243 m .35998 .50431 L .35808 .50355 L F
.687 .457 .569 r
.28312 .55475 m .2829 .55743 L .27897 .5567 L F
.599 .321 .466 r
.28592 .55491 m .2829 .55743 L .28312 .55475 L F
.735 .736 .216 r
.36752 .5355 m .3686 .5309 L .36745 .53257 L F
.583 .723 .939 r
.40195 .49705 m .39965 .49785 L .39941 .49589 L F
.794 .347 .183 r
.40195 .49705 m .39941 .49589 L .39965 .49785 L F
.129 0 .25 r
.30995 .58677 m .30924 .58914 L .31155 .58582 L F
.718 .638 .767 r
.57862 .42384 m .57581 .42709 L .57528 .42463 L F
.712 .773 .9 r
.21671 .57341 m .22086 .57389 L .21968 .57212 L F
.712 .295 .252 r
.21671 .57341 m .21924 .57603 L .22086 .57389 L F
.406 .62 .939 r
.21968 .57212 m .22086 .57389 L .22164 .57202 L F
.709 .879 .483 r
.22086 .57389 m .22125 .57273 L .22164 .57202 L F
.22086 .57389 m .21924 .57603 L .22125 .57273 L F
.431 .521 .849 r
.37352 .56736 m .37273 .56855 L .3704 .5655 L F
.175 .176 .62 r
.37352 .56736 m .37368 .56946 L .37273 .56855 L F
.639 .965 .883 r
.24952 .53682 m .24715 .5373 L .24597 .53885 L F
.255 .179 .575 r
.24715 .5373 m .24532 .54123 L .24597 .53885 L F
.127 .272 .744 r
.61134 .41803 m .6138 .42018 L .61237 .4161 L F
.318 .242 .612 r
.33093 .56945 m .32871 .56759 L .33081 .56686 L F
.33093 .56945 m .3291 .5704 L .32871 .56759 L F
.718 .618 .746 r
.37081 .51999 m .3688 .52283 L .36639 .51625 L F
.104 0 .246 r
.37081 .51999 m .37059 .5224 L .3688 .52283 L F
.211 .227 .658 r
.37059 .5224 m .37097 .52525 L .3688 .52283 L F
.862 .881 .849 r
.42975 .56175 m .42607 .56372 L .42622 .56096 L F
.421 .432 .766 r
.43231 .56069 m .43278 .5635 L .42975 .56175 L F
.419 .432 .767 r
.43278 .5635 m .43131 .56477 L .42975 .56175 L F
.462 .424 .73 r
.28021 .56057 m .27791 .5567 L .27897 .5567 L F
.418 .2 .474 r
.34762 .60881 m .34507 .61203 L .34743 .6116 L F
.34762 .60881 m .34507 .61203 L .34743 .6116 L F
.247 .399 .818 r
.35316 .64018 m .35063 .63746 L .35148 .63543 L F
0 0 0 r
.35111 .63586 m .35063 .63746 L .34999 .6404 L F
.36153 .64916 m .36073 .6508 L .35976 .65279 L F
.233 .47 .881 r
.2695 .63392 m .27233 .63724 L .27284 .63595 L F
0 .172 .702 r
.27284 .63595 m .27233 .63724 L .27361 .63598 L F
.406 .261 .57 r
.27233 .63724 m .27577 .6394 L .27361 .63598 L F
.27233 .63724 m .27377 .64028 L .27577 .6394 L F
.423 .666 .962 r
.22556 .59134 m .22482 .59331 L .22347 .59155 L F
.497 .327 .581 r
.38259 .58679 m .38496 .58641 L .38495 .58327 L F
.714 .695 .83 r
.34244 .6881 m .34552 .68808 L .34329 .68441 L F
.705 .483 .584 r
.34228 .69093 m .34552 .68808 L .34244 .6881 L F
.34228 .69093 m .34512 .69129 L .34552 .68808 L F
.328 .502 .878 r
.34329 .68441 m .34552 .68808 L .34701 .68768 L F
.478 .281 .534 r
.34552 .68808 m .34749 .69118 L .34701 .68768 L F
.34552 .68808 m .34512 .69129 L .34749 .69118 L F
.818 .827 .856 r
.30305 .51747 m .30477 .51904 L .30723 .51633 L F
0 0 .544 r
.29473 .53244 m .29609 .53362 L .30008 .52978 L F
.778 .274 0 r
.29873 .53628 m .29693 .53554 L .29473 .53244 L F
0 0 .544 r
.29473 .53244 m .29693 .53554 L .29609 .53362 L F
.081 .286 .77 r
.60732 .40843 m .6089 .41199 L .60905 .4104 L F
.061 .264 .756 r
.60905 .4104 m .6089 .41199 L .61144 .41398 L F
0 .447 .845 r
.38465 .65812 m .38535 .6577 L .38446 .65815 L F
.38465 .65812 m .38701 .65895 L .38535 .6577 L F
.397 .211 .508 r
.30542 .6175 m .30308 .62117 L .30334 .61837 L F
.668 .621 .793 r
.63882 .38012 m .63485 .37739 L .63754 .37632 L F
.698 .652 .801 r
.64022 .37564 m .63882 .38012 L .63754 .37632 L F
.64022 .37564 m .64145 .37879 L .63882 .38012 L F
.327 .144 .473 r
.31649 .5996 m .31543 .60161 L .31561 .59963 L F
.413 .274 .582 r
.38751 .62128 m .38777 .62461 L .38813 .62118 L F
.38751 .62128 m .38698 .62505 L .38777 .62461 L F
.978 .751 .526 r
.37723 .67152 m .37738 .67452 L .37878 .67319 L F
.706 .808 .928 r
.37723 .67152 m .37878 .67319 L .38098 .67209 L F
.385 .291 .625 r
.37738 .67452 m .3793 .67322 L .37878 .67319 L F
.3793 .67322 m .38098 .67209 L .37937 .6729 L F
.3793 .67322 m .37937 .6729 L .37878 .67319 L F
.37738 .67452 m .37723 .67152 L .38098 .67209 L F
.977 .752 .532 r
.37738 .67452 m .37565 .67075 L .37723 .67152 L F
.385 .291 .625 r
.37738 .67452 m .37924 .67394 L .37723 .67152 L F
.797 .561 .58 r
.37918 .67387 m .37565 .67075 L .37723 .67152 L F
.37924 .67394 m .37918 .67388 L .37918 .67387 L F
.37918 .67388 m .37565 .67075 L .37918 .67387 L F
.59 .115 0 r
.40162 .52921 m .40424 .53233 L .40303 .53098 L F
0 .029 .53 r
.40424 .53233 m .40522 .53319 L .40303 .53098 L F
.40424 .53233 m .40654 .53454 L .40522 .53319 L F
.525 .829 1 r
.57946 .42756 m .57581 .42709 L .57787 .42575 L F
.888 .8 .757 r
.57862 .42384 m .57946 .42756 L .57787 .42575 L F
.417 .865 .833 r
.36059 .6638 m .36304 .66366 L .35885 .66501 L F
.36059 .6638 m .36304 .66366 L .36059 .6638 L F
.476 0 0 r
.36458 .66503 m .36331 .66376 L .36212 .66606 L F
.014 0 0 r
.36519 .66368 m .36304 .66366 L .36139 .66376 L F
.36237 .66376 m .36139 .66376 L .36059 .6638 L F
.36519 .66368 m .36139 .66376 L .36237 .66376 L F
.36061 .6638 m .36059 .6638 L .36059 .6638 L F
.36519 .66368 m .36059 .6638 L .36061 .6638 L F
.36519 .66368 m .36059 .6638 L .36319 .66364 L F
.476 0 0 r
.36331 .66376 m .36319 .66364 L .36314 .66376 L F
.36331 .66376 m .36314 .66376 L .36212 .66606 L F
.645 .299 .371 r
.36212 .66606 m .36314 .66376 L .36028 .6639 L F
.36314 .66376 m .36319 .66364 L .36157 .66378 L F
.36314 .66376 m .36157 .66378 L .36028 .6639 L F
.373 .837 .789 r
.36059 .6638 m .35752 .66503 L .35925 .66399 L F
.645 .299 .371 r
.35947 .66415 m .36028 .6639 L .35925 .66399 L F
.417 .865 .833 r
.36059 .6638 m .35885 .66501 L .35791 .66504 L F
.373 .837 .789 r
.36059 .6638 m .35791 .66504 L .35752 .66503 L F
.645 .299 .371 r
.36212 .66606 m .36028 .6639 L .35947 .66415 L F
.417 .865 .833 r
.36059 .6638 m .36059 .6638 L .36059 .6638 L F
.214 0 0 r
.36587 .66273 m .36304 .66366 L .36519 .66368 L F
.779 .859 .91 r
.54307 .41704 m .54512 .4195 L .54757 .41671 L F
.672 .944 .679 r
.74358 .30466 m .74548 .30331 L .74198 .30687 L F
.546 .763 .978 r
.74198 .30687 m .74507 .30633 L .74358 .30466 L F
0 0 0 r
.36992 .71365 m .36941 .71398 L .36771 .71426 L F
.187 .71 .867 r
.36897 .71398 m .36771 .71426 L .36941 .71398 L F
.158 0 0 r
.36729 .71366 m .36992 .71365 L .36771 .71426 L F
.187 .71 .867 r
.36645 .71398 m .36771 .71426 L .36897 .71398 L F
.158 0 0 r
.36613 .7146 m .36771 .71426 L .36537 .71521 L F
.36729 .71366 m .36771 .71426 L .36613 .7146 L F
.83 .667 .123 r
.71911 .35311 m .71939 .35457 L .71932 .35695 L F
.531 0 0 r
.3636 .51316 m .3612 .51295 L .35916 .51185 L F
.265 0 0 r
.3636 .51316 m .36071 .51298 L .3612 .51295 L F
.812 .493 .449 r
.36532 .51557 m .36071 .51298 L .3636 .51316 L F
.802 .998 .852 r
.55988 .41716 m .56247 .41473 L .56251 .41463 L F
.201 0 0 r
.56319 .41614 m .55988 .41716 L .56246 .41477 L F
0 0 .531 r
.56251 .41463 m .56247 .41473 L .56249 .41474 L F
.201 0 0 r
.56254 .4147 m .56249 .41474 L .56254 .41469 L F
.56249 .41474 m .56249 .41473 L .56254 .41469 L F
.56 .796 .987 r
.56569 .41441 m .56319 .41614 L .56251 .41463 L F
0 0 .531 r
.56251 .41463 m .56249 .41474 L .56402 .41501 L F
0 0 0 r
.56249 .41474 m .56247 .41473 L .56246 .41477 L F
.201 0 0 r
.56249 .41474 m .56246 .41477 L .56249 .41473 L F
.56319 .41614 m .56246 .41477 L .56254 .4147 L F
0 0 0 r
.56402 .41501 m .56249 .41474 L .56091 .41738 L F
.56249 .41474 m .56246 .41477 L .56091 .41738 L F
.56091 .41738 m .56246 .41477 L .55988 .41716 L F
.56246 .41477 m .56247 .41473 L .55988 .41716 L F
.201 0 0 r
.56254 .41469 m .55988 .41716 L .56251 .41463 L F
.643 .686 .875 r
.56569 .41441 m .56396 .41825 L .56319 .41614 L F
0 0 .411 r
.69615 .3422 m .69794 .33956 L .69584 .34044 L F
.69615 .3422 m .69692 .34323 L .69794 .33956 L F
.69615 .3422 m .69717 .34474 L .69692 .34323 L F
.992 .74 .394 r
.33076 .52429 m .33197 .52555 L .33208 .52301 L F
.899 .625 .512 r
.33197 .52555 m .33371 .52781 L .33208 .52301 L F
.733 .547 .641 r
.33208 .52301 m .33371 .52781 L .33605 .52607 L F
.617 .457 .643 r
.71606 .32496 m .72069 .32539 L .71878 .32237 L F
.027 0 0 r
.71508 .32686 m .72069 .32539 L .71606 .32496 L F
.604 .363 .524 r
.60745 .44675 m .61005 .44891 L .60726 .44917 L F
.923 .968 .774 r
.42831 .53588 m .42621 .5367 L .4268 .53536 L F
.531 .131 .228 r
.42692 .53245 m .42724 .53495 L .42275 .53459 L F
.42724 .53495 m .42714 .53505 L .42275 .53459 L F
.54 .389 .624 r
.42621 .5367 m .42275 .53459 L .42714 .53505 L F
.42621 .5367 m .42714 .53505 L .42726 .53506 L F
.923 .968 .774 r
.4278 .53387 m .42736 .53452 L .42767 .53335 L F
0 0 .198 r
.42767 .53335 m .42726 .53506 L .42724 .53495 L F
.42767 .53335 m .42724 .53495 L .42692 .53245 L F
.923 .968 .774 r
.42736 .53452 m .4268 .53536 L .42767 .53335 L F
.42792 .53434 m .42714 .53505 L .4278 .53387 L F
.42714 .53505 m .4268 .53536 L .4278 .53387 L F
.42831 .53588 m .4268 .53536 L .42792 .53434 L F
.531 .131 .228 r
.42724 .53495 m .42726 .53506 L .42714 .53505 L F
0 0 .198 r
.42767 .53335 m .42692 .53245 L .42831 .53108 L F
.62 .886 .989 r
.31983 .6693 m .3211 .66922 L .3198 .66942 L F
.482 .898 .832 r
.3198 .66942 m .3211 .66922 L .32215 .66821 L F
0 0 0 r
.31976 .66956 m .3198 .66942 L .32215 .66821 L F
.31778 .67067 m .3198 .66942 L .31976 .66956 L F
.62 .886 .989 r
.31672 .6695 m .31983 .6693 L .3198 .66942 L F
.825 .848 .865 r
.6498 .41498 m .64566 .41627 L .64893 .41386 L F
.881 .978 .833 r
.6517 .41084 m .6498 .41498 L .64893 .41386 L F
.6517 .41084 m .65243 .41187 L .6498 .41498 L F
.777 .648 .719 r
.37821 .5511 m .38231 .55291 L .38076 .54852 L F
.785 .337 .183 r
.37821 .5511 m .38059 .55349 L .38231 .55291 L F
.665 .589 .76 r
.38394 .55108 m .38231 .55291 L .38422 .5513 L F
.38388 .55102 m .38215 .55245 L .38394 .55108 L F
.38215 .55245 m .38231 .55291 L .38394 .55108 L F
.38076 .54852 m .38198 .55197 L .38388 .55102 L F
.38198 .55197 m .38215 .55245 L .38388 .55102 L F
.38409 .55116 m .38422 .5513 L .38422 .55126 L F
.38076 .54852 m .38408 .55118 L .38409 .55116 L F
.38408 .55118 m .38422 .5513 L .38409 .55116 L F
.38076 .54852 m .3839 .55101 L .38406 .55064 L F
.3839 .55101 m .38409 .55116 L .38408 .55092 L F
.3839 .55101 m .38408 .55092 L .38406 .55064 L F
.38409 .55116 m .38421 .55095 L .38421 .55088 L F
.791 .685 .747 r
.38391 .5477 m .38408 .5491 L .38403 .54911 L F
.665 .589 .76 r
.38408 .55097 m .38419 .55089 L .38391 .5477 L F
.38209 .54817 m .38406 .55064 L .38391 .5477 L F
.38076 .54852 m .38406 .55064 L .38209 .54817 L F
.791 .685 .747 r
.38391 .5477 m .38403 .54911 L .38002 .54999 L F
.38408 .5491 m .38419 .55079 L .38002 .54999 L F
.665 .589 .76 r
.38419 .55089 m .38421 .55088 L .38391 .5477 L F
.38409 .55116 m .38421 .55088 L .38408 .55097 L F
.487 .858 .628 r
.38423 .55086 m .38299 .55168 L .38418 .55079 L F
.38418 .55079 m .38059 .55349 L .38002 .54999 L F
.38423 .55086 m .38173 .55252 L .38059 .55349 L F
.3843 .55081 m .38423 .55086 L .3842 .55081 L F
.3842 .55079 m .3842 .55081 L .38418 .55079 L F
.3843 .55081 m .3842 .55081 L .3842 .55079 L F
.791 .685 .747 r
.38408 .5491 m .3843 .55081 L .38419 .55079 L F
.504 .499 .785 r
.38533 .54933 m .38614 .55052 L .38551 .54885 L F
.38532 .54916 m .38551 .54885 L .38525 .54819 L F
.38533 .54933 m .38551 .54885 L .38532 .54916 L F
0 0 0 r
.38429 .55081 m .3843 .55081 L .38531 .54917 L F
.38531 .54918 m .38531 .54917 L .38574 .54847 L F
.38429 .55081 m .38531 .54917 L .38531 .54918 L F
.243 .379 .802 r
.38424 .55128 m .38461 .55113 L .38455 .55041 L F
0 .081 .596 r
.38526 .54827 m .3843 .55081 L .38391 .5477 L F
.487 .858 .628 r
.3843 .55081 m .38427 .55082 L .38424 .55085 L F
0 0 0 r
.38427 .55083 m .38427 .55083 L .38427 .55082 L F
.38429 .55081 m .38429 .55081 L .3843 .55081 L F
.38429 .55081 m .3843 .55081 L .38431 .55078 L F
.38429 .55081 m .38427 .55082 L .3843 .55081 L F
.243 .379 .802 r
.38425 .55089 m .38455 .55041 L .38431 .54784 L F
.38424 .55128 m .38455 .55041 L .38425 .55089 L F
0 0 0 r
.38527 .54924 m .38429 .55081 L .38531 .54918 L F
.38428 .55085 m .38429 .55081 L .38527 .54924 L F
.243 .379 .802 r
.38461 .55113 m .38533 .54933 L .38527 .54924 L F
0 .081 .596 r
.38531 .54908 m .3843 .55081 L .38526 .54827 L F
.38554 .54881 m .3843 .55081 L .38568 .54845 L F
0 0 0 r
.38429 .55081 m .38431 .55078 L .38574 .54847 L F
.243 .379 .802 r
.38455 .55041 m .38527 .54924 L .38431 .54784 L F
.38461 .55113 m .38527 .54924 L .38455 .55041 L F
0 0 0 r
.38419 .55103 m .38527 .54924 L .38574 .54847 L F
.38527 .54924 m .38531 .54918 L .38551 .54885 L F
.504 .499 .785 r
.38551 .54885 m .38614 .55052 L .38579 .54839 L F
0 0 0 r
.38527 .54924 m .38551 .54885 L .38574 .54847 L F
.38419 .55103 m .38428 .55085 L .38527 .54924 L F
.38404 .55133 m .38419 .55103 L .38574 .54847 L F
.504 .499 .785 r
.38579 .54839 m .38614 .55052 L .38785 .54915 L F
.38525 .54819 m .38551 .54885 L .38579 .54839 L F
.38431 .54784 m .38526 .54827 L .38525 .54819 L F
0 .081 .596 r
.38574 .54847 m .38526 .54827 L .38431 .54784 L F
.38526 .54827 m .38391 .5477 L .38431 .54784 L F
.504 .499 .785 r
.38431 .54784 m .38533 .54933 L .38526 .54827 L F
0 .081 .596 r
.38568 .54845 m .38531 .54908 L .38526 .54827 L F
.38574 .54847 m .38554 .54881 L .38568 .54845 L F
.243 .379 .802 r
.38461 .55113 m .38614 .55052 L .38533 .54933 L F
.3842 .55081 m .38431 .54784 L .38391 .5477 L F
.38424 .55128 m .38425 .55113 L .3842 .55081 L F
.487 .858 .628 r
.38424 .55085 m .38424 .55085 L .38423 .55086 L F
.243 .379 .802 r
.38425 .55113 m .38431 .54784 L .3842 .55081 L F
.487 .858 .628 r
.38424 .55085 m .38173 .55252 L .38423 .55086 L F
.38427 .55082 m .38173 .55252 L .38424 .55085 L F
0 0 0 r
.38404 .55133 m .38173 .55252 L .38427 .55083 L F
.665 .589 .76 r
.38409 .55116 m .38424 .55128 L .38421 .55095 L F
0 0 0 r
.38404 .55133 m .38427 .55083 L .38427 .55083 L F
.38404 .55133 m .38427 .55082 L .38429 .55081 L F
.665 .589 .76 r
.38422 .55126 m .38422 .5513 L .38424 .55128 L F
.445 .236 .5 r
.38231 .55291 m .38361 .55317 L .38424 .55128 L F
.967 .646 .33 r
.4189 .58658 m .41772 .58802 L .41815 .58552 L F
.4189 .58658 m .41922 .58907 L .41772 .58802 L F
.381 .579 .918 r
.24917 .58393 m .25035 .58515 L .25154 .58479 L F
.599 .321 .466 r
.28592 .55491 m .28574 .55749 L .2829 .55743 L F
.51 .329 .571 r
.28863 .55108 m .28876 .55462 L .28592 .55491 L F
.329 .102 .41 r
.2878 .55651 m .28592 .55491 L .28876 .55462 L F
.2878 .55651 m .28574 .55749 L .28592 .55491 L F
.392 .187 .478 r
.73368 .33237 m .73688 .3314 L .73635 .32865 L F
.591 .473 .687 r
.73436 .33461 m .73688 .3314 L .73368 .33237 L F
.547 .245 .407 r
.29874 .63653 m .29699 .63454 L .29715 .63718 L F
.29874 .63653 m .30017 .63389 L .29699 .63454 L F
.926 .611 .145 r
.41109 .54837 m .41013 .54723 L .40968 .54439 L F
.857 .539 .015 r
.41136 .5507 m .41013 .54723 L .41109 .54837 L F
.552 .635 .887 r
.32997 .5447 m .33485 .54801 L .33161 .5443 L F
.387 .557 .9 r
.33485 .54801 m .33438 .54385 L .33161 .5443 L F
.33485 .54801 m .33624 .54733 L .33438 .54385 L F
.184 .105 .527 r
.33632 .55017 m .33485 .54801 L .33624 .54733 L F
.474 .058 .17 r
.33197 .54979 m .33624 .54733 L .33485 .54801 L F
0 .447 .784 r
.32882 .53514 m .32789 .53447 L .32682 .53423 L F
.887 .651 .132 r
.41411 .56056 m .41337 .55927 L .41323 .55697 L F
.907 .549 .09 r
.41411 .56056 m .41348 .56231 L .41337 .55927 L F
.41411 .56056 m .41497 .56391 L .41348 .56231 L F
.551 .565 .821 r
.22624 .56784 m .22201 .56431 L .22433 .56373 L F
.657 .515 .679 r
.38006 .54535 m .37703 .5485 L .37646 .54461 L F
.38006 .54535 m .38076 .54852 L .37703 .5485 L F
.651 .447 .594 r
.38076 .54852 m .37821 .5511 L .37703 .5485 L F
.165 0 .127 r
.38076 .54852 m .37821 .5511 L .38002 .54999 L F
.508 .38 .641 r
.38002 .54999 m .37821 .5511 L .37703 .5485 L F
.039 0 0 r
.34441 .59582 m .34759 .59333 L .34667 .59519 L F
0 0 0 r
.34759 .59333 m .34808 .59365 L .34667 .59519 L F
.34759 .59333 m .34993 .59266 L .34808 .59365 L F
.467 0 0 r
.384 .57791 m .37968 .57866 L .38225 .57448 L F
0 0 0 r
.38428 .57781 m .384 .57791 L .38647 .57699 L F
.38428 .57781 m .38257 .5789 L .384 .57791 L F
.875 .449 .037 r
.57415 .39657 m .57642 .39909 L .57418 .39657 L F
.823 .374 0 r
.57418 .39657 m .57642 .39909 L .57594 .39965 L F
.644 .845 .977 r
.57884 .39612 m .57642 .39909 L .57422 .39663 L F
.57884 .39612 m .57422 .39663 L .57421 .39656 L F
.21 .735 .821 r
.57415 .39657 m .57418 .39657 L .57421 .39656 L F
.403 .793 .989 r
.57656 .39535 m .57819 .3959 L .57422 .39655 L F
0 .05 .611 r
.57421 .39656 m .57421 .39656 L .57421 .39656 L F
.403 .793 .989 r
.57422 .39653 m .57421 .39656 L .57415 .39657 L F
.21 .735 .821 r
.57415 .39657 m .57421 .39656 L .57468 .39635 L F
.403 .793 .989 r
.57422 .39655 m .57884 .39612 L .57421 .39656 L F
.57819 .3959 m .57884 .39612 L .57422 .39655 L F
.57656 .39535 m .57421 .39656 L .57422 .39653 L F
0 .05 .611 r
.57421 .39656 m .57594 .39965 L .57468 .39635 L F
.57421 .39656 m .57594 .39965 L .57421 .39656 L F
.57418 .39657 m .57421 .39663 L .57421 .39656 L F
.57421 .39663 m .57594 .39965 L .57421 .39656 L F
.644 .845 .977 r
.57421 .39656 m .57422 .39663 L .57415 .39657 L F
.57884 .39612 m .57995 .398 L .57642 .39909 L F
.894 .595 .09 r
.57594 .39965 m .57642 .39909 L .57674 .40132 L F
.504 .906 .916 r
.25033 .52681 m .25044 .52581 L .25262 .5259 L F
.25033 .52681 m .24785 .52686 L .25044 .52581 L F
.689 .981 .854 r
.34393 .66155 m .34526 .66155 L .34818 .65932 L F
.715 .515 .618 r
.24863 .54777 m .25147 .551 L .24977 .54749 L F
.861 .854 .834 r
.64508 .36391 m .64283 .36302 L .6435 .36253 L F
.794 .861 .9 r
.64795 .36113 m .64508 .36391 L .6435 .36253 L F
.638 .359 .479 r
.36807 .55532 m .36894 .55764 L .36548 .55659 L F
.51 .906 .783 r
.26708 .53448 m .26787 .53385 L .27125 .53252 L F
.391 .838 .729 r
.27125 .53252 m .26787 .53385 L .27207 .53196 L F
.493 0 0 r
.32342 .69373 m .3249 .69428 L .32458 .69447 L F
.584 .015 0 r
.32342 .69373 m .32458 .69447 L .32175 .6929 L F
.835 .394 .181 r
.32175 .6929 m .32458 .69447 L .32313 .69559 L F
.052 .389 .849 r
.32458 .69447 m .32518 .69316 L .32355 .6951 L F
.32458 .69447 m .32355 .6951 L .32313 .69559 L F
.493 0 0 r
.3249 .69428 m .32638 .69484 L .32458 .69447 L F
0 .017 .514 r
.32638 .69484 m .32765 .69604 L .32458 .69447 L F
.053 .482 .888 r
.32638 .69484 m .33107 .69724 L .32882 .69721 L F
0 .017 .514 r
.32638 .69484 m .32823 .69664 L .32765 .69604 L F
.475 0 0 r
.32765 .69604 m .32768 .69658 L .32711 .69549 L F
.052 .389 .849 r
.32458 .69447 m .32765 .69604 L .32518 .69316 L F
.475 0 0 r
.32765 .69604 m .32711 .69549 L .32693 .69515 L F
0 .017 .514 r
.32823 .69664 m .32882 .69721 L .32765 .69604 L F
0 0 0 r
.37971 .68712 m .37798 .68832 L .37756 .68929 L F
.558 .341 .542 r
.32946 .51558 m .32679 .51345 L .32949 .51297 L F
.32946 .51558 m .32664 .51606 L .32679 .51345 L F
0 0 .073 r
.32679 .51345 m .32664 .51606 L .32719 .51385 L F
.628 .865 .505 r
.32719 .51385 m .32553 .51577 L .32668 .51428 L F
0 0 .073 r
.32679 .51345 m .32719 .51385 L .32794 .51324 L F
.628 .865 .505 r
.32719 .51385 m .32668 .51428 L .3281 .51244 L F
0 0 .073 r
.32794 .51324 m .32719 .51385 L .32949 .51297 L F
.469 .242 .487 r
.34762 .60881 m .34743 .6116 L .35004 .60826 L F
.35004 .60826 m .34743 .6116 L .34762 .60881 L F
.147 0 .241 r
.26327 .55045 m .26306 .55302 L .26114 .5535 L F
.226 .747 .812 r
.26114 .5535 m .26306 .55302 L .26177 .55325 L F
.725 .229 .058 r
.26114 .5535 m .26049 .55377 L .26232 .55163 L F
.26114 .5535 m .25963 .55476 L .26049 .55377 L F
.26114 .5535 m .25783 .55151 L .25963 .55476 L F
.26114 .5535 m .25999 .55357 L .25783 .55151 L F
.226 .747 .812 r
.26114 .5535 m .26177 .55325 L .25999 .55357 L F
.147 0 .241 r
.26327 .55045 m .26114 .5535 L .26232 .55163 L F
.404 .275 .59 r
.33187 .59915 m .33466 .60108 L .33505 .59887 L F
.33187 .59915 m .33236 .60237 L .33466 .60108 L F
.543 .3 .498 r
.32648 .58634 m .32616 .58829 L .32355 .58879 L F
.649 .436 .581 r
.32899 .58623 m .32616 .58829 L .32648 .58634 L F
.863 .759 .747 r
.54171 .42399 m .54307 .42754 L .54009 .42714 L F
.846 .665 .657 r
.54307 .42754 m .53912 .42955 L .54009 .42714 L F
.54307 .42754 m .54311 .42975 L .53912 .42955 L F
.801 .734 .79 r
.54559 .42427 m .54307 .42754 L .54171 .42399 L F
0 0 .196 r
.30008 .52978 m .30099 .53451 L .29987 .52819 L F
.926 .593 .389 r
.29715 .53262 m .29742 .53234 L .29609 .53362 L F
.582 .892 .989 r
.29912 .53462 m .29693 .53554 L .29873 .53628 L F
.961 .738 .556 r
.29912 .53462 m .29609 .53362 L .29693 .53554 L F
.29912 .53462 m .29715 .53262 L .29609 .53362 L F
.982 .756 .522 r
.29715 .53262 m .29723 .53584 L .29485 .53405 L F
.029 0 0 r
.29485 .53405 m .29692 .53286 L .29715 .53262 L F
.926 .593 .389 r
.29715 .53262 m .30014 .53409 L .30008 .52978 L F
.30014 .53409 m .30099 .53451 L .30069 .53296 L F
.30014 .53409 m .30069 .53296 L .30008 .52978 L F
.201 .048 .437 r
.30251 .53393 m .30086 .53526 L .30269 .5318 L F
0 0 .289 r
.29987 .52819 m .30032 .53075 L .30077 .53016 L F
.30032 .53075 m .30078 .53331 L .30077 .53016 L F
.30078 .53331 m .30099 .53451 L .30096 .53384 L F
.30078 .53331 m .30096 .53384 L .30077 .53016 L F
.81 .842 .874 r
.30077 .53016 m .30099 .53451 L .29715 .53262 L F
.30077 .53016 m .29715 .53262 L .29994 .53112 L F
.556 .827 .474 r
.30077 .53016 m .29994 .53112 L .30091 .52997 L F
.454 .479 .795 r
.30488 .53018 m .30269 .5318 L .30111 .52853 L F
0 0 0 r
.30111 .52853 m .30245 .5263 L .30488 .53018 L F
.30111 .52853 m .30077 .53016 L .30196 .52872 L F
.556 .827 .474 r
.30077 .53016 m .30091 .52997 L .30196 .52872 L F
.553 .136 .205 r
.29996 .53445 m .29912 .53462 L .29976 .53486 L F
.29996 .53445 m .29976 .53486 L .30086 .53526 L F
.30251 .53393 m .29996 .53445 L .30086 .53526 L F
.30108 .53422 m .2997 .53497 L .29996 .53445 L F
.30251 .53393 m .30116 .53443 L .30108 .53422 L F
.30116 .53443 m .2997 .53497 L .30108 .53422 L F
.30251 .53393 m .30129 .53592 L .2997 .53497 L F
.29996 .53445 m .2997 .53497 L .29912 .53462 L F
.961 .738 .556 r
.29912 .53462 m .29723 .53584 L .29715 .53262 L F
.029 0 0 r
.29692 .53286 m .29994 .53112 L .29715 .53262 L F
.926 .593 .389 r
.29715 .53262 m .30008 .52978 L .29742 .53234 L F
.934 .691 .212 r
.41688 .57387 m .41591 .57229 L .41582 .56974 L F
.995 .754 .422 r
.41688 .57387 m .41543 .57498 L .41591 .57229 L F
.41688 .57387 m .4167 .5764 L .41543 .57498 L F
.597 .533 .753 r
.42872 .49637 m .42577 .49723 L .42538 .49474 L F
.504 .379 .643 r
.3675 .58247 m .36945 .57871 L .36771 .57993 L F
0 0 .304 r
.3886 .52734 m .38864 .52745 L .38741 .52589 L F
.3886 .52734 m .38939 .52907 L .38864 .52745 L F
.351 .433 .806 r
.44599 .56599 m .44572 .57024 L .44323 .56694 L F
.44599 .56599 m .44732 .56945 L .44572 .57024 L F
.944 .849 .719 r
.39129 .63298 m .39227 .63109 L .3906 .63006 L F
.008 0 .239 r
.62201 .39633 m .62048 .3966 L .62182 .39513 L F
.62201 .39633 m .61944 .39906 L .62048 .3966 L F
.597 .899 .986 r
.32173 .5197 m .32241 .51815 L .32453 .51886 L F
.522 .221 .397 r
.32453 .51886 m .32384 .52136 L .32173 .5197 L F
.765 .676 .764 r
.32384 .52136 m .32241 .51815 L .32173 .5197 L F
.193 .72 .73 r
.36055 .51143 m .35916 .51185 L .3612 .51295 L F
.36055 .51143 m .35761 .51207 L .35916 .51185 L F
.976 .913 .674 r
.42787 .56745 m .43131 .56477 L .43031 .56685 L F
0 0 .003 r
.43031 .56685 m .43131 .56477 L .43278 .5635 L F
.079 .196 .686 r
.37545 .68394 m .37421 .68487 L .37327 .68185 L F
.271 0 .266 r
.37554 .6868 m .37421 .68487 L .37545 .68394 L F
.37554 .6868 m .37379 .68679 L .37421 .68487 L F
.733 .78 .89 r
.36222 .52795 m .35941 .5291 L .36346 .52947 L F
.637 .747 .928 r
.36222 .52795 m .36346 .52947 L .36591 .5286 L F
.209 .284 .722 r
.37335 .63715 m .37002 .64021 L .37146 .63864 L F
.37335 .63715 m .37432 .63927 L .37002 .64021 L F
0 0 0 r
.37498 .63355 m .37335 .63715 L .37549 .63684 L F
.167 0 0 r
.37549 .63684 m .37335 .63715 L .37146 .63864 L F
.709 .483 .579 r
.43433 .54255 m .4334 .54571 L .43122 .54554 L F
.43433 .54255 m .43122 .54554 L .43045 .54482 L F
.932 .874 .757 r
.4334 .54571 m .43273 .54724 L .43456 .5442 L F
.709 .483 .579 r
.43045 .54482 m .43122 .54554 L .42944 .54541 L F
0 0 0 r
.4315 .54498 m .42944 .54541 L .43135 .54555 L F
.4315 .54498 m .43135 .54555 L .4334 .54571 L F
0 .323 .81 r
.4315 .54498 m .43365 .54607 L .43163 .54447 L F
.4315 .54498 m .43163 .54447 L .43111 .54406 L F
.023 .322 .808 r
.43242 .54668 m .43365 .54607 L .4315 .54498 L F
.43273 .54724 m .43285 .54709 L .43242 .54668 L F
.43285 .54709 m .43365 .54607 L .43242 .54668 L F
.687 .46 .572 r
.43456 .5442 m .43433 .54255 L .43474 .5441 L F
.353 .676 .977 r
.34879 .49866 m .34763 .49966 L .34618 .49881 L F
.34879 .49866 m .34999 .50006 L .34763 .49966 L F
.607 .357 .512 r
.68018 .37062 m .6796 .37313 L .67652 .37319 L F
.596 .43 .628 r
.68225 .36812 m .68274 .36982 L .68018 .37062 L F
.447 .173 .404 r
.68274 .36982 m .6796 .37313 L .68018 .37062 L F
.897 .622 .114 r
.40222 .66092 m .40274 .65942 L .4025 .65814 L F
.40222 .66092 m .40264 .66248 L .40274 .65942 L F
.049 .111 .607 r
.34189 .52574 m .34153 .5221 L .34284 .52344 L F
.894 .937 .567 r
.38802 .62025 m .38965 .61844 L .38813 .62118 L F
.796 .668 .723 r
.38797 .61478 m .39147 .61463 L .38955 .61671 L F
.054 .271 .764 r
.38797 .61478 m .38965 .61844 L .39058 .61731 L F
.552 .829 .482 r
.39058 .61731 m .38965 .61844 L .38802 .62025 L F
.349 .804 .941 r
.70828 .30644 m .71089 .30602 L .71296 .30635 L F
.779 .281 0 r
.71305 .30797 m .71296 .30635 L .71089 .30602 L F
.71305 .30797 m .71406 .30849 L .71296 .30635 L F
.753 .645 .741 r
.66235 .38287 m .66331 .38671 L .65983 .38613 L F
.743 .704 .814 r
.3085 .53869 m .31321 .53936 L .31087 .53836 L F
.497 .823 1 r
.31321 .53936 m .31346 .53789 L .31087 .53836 L F
.584 .895 .621 r
.27019 .56578 m .26883 .56734 L .27171 .56468 L F
.18 0 0 r
.27398 .56533 m .27019 .56578 L .27171 .56468 L F
.312 0 0 r
.27503 .5638 m .27398 .56533 L .27171 .56468 L F
.051 .217 .716 r
.27711 .62948 m .27839 .63347 L .27622 .63116 L F
.73 .653 .773 r
.63413 .38919 m .63786 .3898 L .63615 .38815 L F
.79 .866 .905 r
.63786 .3898 m .63836 .38788 L .63615 .38815 L F
.63786 .3898 m .64037 .38783 L .63869 .38663 L F
.847 .65 .636 r
.63655 .39017 m .64138 .39303 L .64054 .3887 L F
.63956 .38833 m .64054 .3887 L .64037 .38783 L F
.63655 .39017 m .64037 .38783 L .63786 .3898 L F
.63655 .39017 m .64054 .3887 L .63956 .38833 L F
.79 .866 .905 r
.63836 .38788 m .63869 .38663 L .63728 .38747 L F
.63836 .38788 m .63728 .38747 L .63615 .38815 L F
.766 .738 .827 r
.71648 .29893 m .72031 .29729 L .71598 .29602 L F
0 0 .499 r
.40222 .66092 m .40285 .66493 L .40264 .66248 L F
.919 .732 .24 r
.40264 .66248 m .40272 .66348 L .40278 .663 L F
.40272 .66348 m .40285 .66493 L .40278 .663 L F
0 0 .499 r
.40246 .66242 m .40297 .66333 L .40285 .66493 L F
.40222 .66092 m .40297 .66333 L .40246 .66242 L F
.317 .306 .688 r
.40426 .66321 m .40358 .6644 L .40297 .66333 L F
0 0 .049 r
.40297 .66333 m .40179 .66737 L .40285 .66493 L F
.40297 .66333 m .40155 .66792 L .40179 .66737 L F
.919 .732 .24 r
.40278 .663 m .40285 .66493 L .40351 .6656 L F
.788 .693 .76 r
.40285 .66493 m .4048 .66809 L .40351 .6656 L F
.40285 .66493 m .40155 .66792 L .4048 .66809 L F
.317 .306 .688 r
.40358 .6644 m .4017 .66767 L .40297 .66333 L F
0 0 .049 r
.4026 .66452 m .4017 .66767 L .40155 .66792 L F
.40297 .66333 m .40258 .66464 L .4026 .66452 L F
.40258 .66464 m .4017 .66767 L .4026 .66452 L F
.428 .391 .716 r
.36514 .58384 m .36788 .58568 L .3675 .58247 L F
.64 .536 .72 r
.65845 .38244 m .65983 .38613 L .65722 .38726 L F
.75 .725 .83 r
.41336 .50753 m .4153 .51015 L .41697 .50736 L F
.538 .449 .703 r
.4153 .51015 m .41812 .50954 L .41697 .50736 L F
.735 .285 .183 r
.29312 .52621 m .29119 .52763 L .28947 .52543 L F
.631 .937 .963 r
.29524 .52501 m .29366 .52462 L .29312 .52621 L F
.757 .965 .674 r
.29366 .52462 m .29119 .52763 L .29312 .52621 L F
.769 .952 .628 r
.33562 .53393 m .33486 .53589 L .33735 .53245 L F
.7 .585 .724 r
.33486 .53589 m .33938 .53607 L .33735 .53245 L F
.493 0 0 r
.33486 .53589 m .33919 .53881 L .33938 .53607 L F
.33486 .53589 m .33688 .53749 L .33919 .53881 L F
.004 .169 .684 r
.33562 .53393 m .33688 .53749 L .33486 .53589 L F
.181 .599 .942 r
.22062 .58988 m .22057 .59102 L .21923 .58881 L F
.22062 .58988 m .22347 .59155 L .22057 .59102 L F
.724 .782 .899 r
.57589 .41343 m .57677 .41488 L .57282 .41435 L F
.485 .664 .941 r
.57798 .41304 m .57677 .41488 L .57589 .41343 L F
.189 .263 .709 r
.57875 .41536 m .57677 .41488 L .57798 .41304 L F
.896 .802 .748 r
.68814 .34526 m .68913 .34026 L .68633 .34414 L F
.853 .682 .669 r
.68633 .34414 m .68787 .34794 L .68814 .34526 L F
.13 0 .37 r
.3029 .60204 m .30472 .60109 L .30511 .59861 L F
.367 .05 .291 r
.3029 .60204 m .30456 .60394 L .30472 .60109 L F
.3029 .60204 m .30211 .60483 L .30456 .60394 L F
0 .135 .682 r
.23298 .61526 m .2333 .61425 L .23177 .61352 L F
.23298 .61526 m .23508 .61733 L .2333 .61425 L F
.481 .339 .61 r
.3085 .53869 m .31085 .53516 L .3084 .53579 L F
.737 .462 0 r
.4127 .55448 m .41285 .55574 L .41305 .55304 L F
.4127 .55448 m .41323 .55697 L .41285 .55574 L F
.302 .745 .964 r
.58574 .41417 m .58337 .41439 L .58204 .41355 L F
.834 .688 .701 r
.41 .50082 m .41007 .50367 L .40555 .50251 L F
.835 .685 .698 r
.41007 .50367 m .40728 .50643 L .40555 .50251 L F
.556 .845 .998 r
.64994 .39951 m .65137 .40078 L .64951 .40019 L F
.229 .471 .882 r
.64943 .39902 m .65251 .4018 L .65137 .40078 L F
.6 .581 .804 r
.64943 .39902 m .65212 .39829 L .651 .39448 L F
.556 .845 .998 r
.65139 .39714 m .65212 .39829 L .64943 .39902 L F
.65139 .39714 m .64943 .39902 L .65137 .40078 L F
.65139 .39714 m .65137 .40078 L .64994 .39951 L F
.229 .471 .882 r
.65251 .4018 m .65302 .40226 L .65137 .40078 L F
.921 .527 .18 r
.65137 .40078 m .65302 .40226 L .65374 .40458 L F
.547 .674 .921 r
.61126 .36821 m .61233 .37026 L .60919 .37028 L F
.61126 .36821 m .60919 .37028 L .6085 .37179 L F
0 0 0 r
.60919 .37028 m .60788 .37285 L .6085 .37179 L F
.609 .453 .645 r
.61126 .36821 m .6085 .37179 L .6085 .36894 L F
.271 .73 .953 r
.6085 .37179 m .61028 .37094 L .60916 .37066 L F
.998 .783 .475 r
.6085 .36894 m .6085 .37179 L .60732 .37019 L F
.271 .73 .953 r
.6085 .37179 m .60916 .37066 L .60732 .37019 L F
0 0 0 r
.60788 .37285 m .60747 .37366 L .6085 .37179 L F
.13 .293 .763 r
.6085 .37179 m .60747 .37366 L .60947 .37488 L F
.185 0 0 r
.71454 .36647 m .71353 .36778 L .71117 .3684 L F
0 0 0 r
.71763 .36378 m .71695 .36517 L .71454 .36647 L F
.71695 .36517 m .71353 .36778 L .71454 .36647 L F
.863 .865 .84 r
.66635 .33544 m .66368 .33893 L .6621 .33754 L F
.938 .838 .719 r
.66368 .33893 m .66268 .34118 L .6621 .33754 L F
0 0 0 r
.71763 .36378 m .71963 .35997 L .71928 .36175 L F
.71928 .36175 m .71695 .36517 L .71763 .36378 L F
.972 .737 .525 r
.33688 .53749 m .33689 .54026 L .33919 .53881 L F
.445 .3 .59 r
.34132 .54062 m .3391 .54163 L .33919 .53881 L F
.673 .201 .123 r
.33919 .53881 m .33689 .54026 L .34132 .54062 L F
.567 0 0 r
.57674 .40132 m .58093 .40329 L .57931 .40319 L F
.431 .06 .231 r
.33545 .6076 m .33383 .60622 L .33636 .6054 L F
.33545 .6076 m .33291 .60814 L .33383 .60622 L F
.131 .36 .82 r
.21486 .59976 m .21652 .60302 L .21726 .60147 L F
.074 .228 .719 r
.21749 .60511 m .21726 .60147 L .21652 .60302 L F
.831 .601 .59 r
.36162 .56071 m .35977 .56345 L .35977 .56072 L F
0 0 .018 r
.33999 .65843 m .33819 .65907 L .33819 .65992 L F
.744 .39 .381 r
.27782 .56379 m .27398 .56533 L .27503 .5638 L F
.906 .774 .285 r
.4048 .66809 m .40442 .67118 L .40491 .67239 L F
0 0 .11 r
.40442 .67118 m .40451 .67506 L .40491 .67239 L F
.634 .099 0 r
.23602 .60841 m .23909 .61096 L .23753 .60928 L F
.777 .639 .709 r
.39714 .65612 m .39518 .65995 L .39362 .65588 L F
.573 .34 .525 r
.35433 .62466 m .35679 .62719 L .35718 .62427 L F
.35433 .62466 m .35679 .62719 L .35718 .62427 L F
.657 .515 .679 r
.38006 .54535 m .37646 .54461 L .37968 .54404 L F
.583 .415 .62 r
.31155 .58582 m .31381 .58228 L .31232 .58341 L F
.72 .631 .757 r
.67 .37311 m .67141 .37703 L .66741 .37617 L F
.721 .563 .675 r
.67141 .37703 m .66887 .38002 L .66741 .37617 L F
.67141 .37703 m .67177 .37985 L .66887 .38002 L F
.648 .592 .777 r
.67402 .3763 m .67141 .37703 L .67 .37311 L F
.394 .215 .516 r
.67402 .3763 m .67177 .37985 L .67141 .37703 L F
.764 .678 .767 r
.28254 .5259 m .284 .52915 L .2866 .52633 L F
.547 .255 .424 r
.284 .52915 m .28344 .5317 L .28608 .53125 L F
0 0 .202 r
.70214 .28769 m .70327 .28823 L .70277 .28724 L F
.933 .69 .209 r
.41583 .56733 m .4149 .56595 L .41497 .56391 L F
.88 .651 .127 r
.41583 .56733 m .41536 .56859 L .4149 .56595 L F
.41583 .56733 m .41582 .56974 L .41536 .56859 L F
.694 .772 .911 r
.62482 .37486 m .62063 .37422 L .62331 .37292 L F
.721 .798 .912 r
.62706 .37334 m .62482 .37486 L .62331 .37292 L F
0 0 .051 r
.42675 .5699 m .42548 .5706 L .42787 .56745 L F
.035 0 .324 r
.42512 .57319 m .42548 .5706 L .42675 .5699 L F
0 0 .034 r
.35167 .64416 m .35147 .64163 L .34999 .6404 L F
.801 .369 .222 r
.35024 .64555 m .35376 .64724 L .35167 .64416 L F
.714 .341 .342 r
.55361 .44676 m .54984 .4483 L .54952 .44652 L F
.55361 .44676 m .55395 .44858 L .54984 .4483 L F
0 0 .451 r
.40424 .56433 m .40362 .5647 L .40329 .56302 L F
.40424 .56433 m .40453 .56717 L .40362 .5647 L F
.785 .699 .769 r
.33915 .68837 m .34244 .6881 L .34069 .68539 L F
.741 .524 .6 r
.33815 .69085 m .34244 .6881 L .33915 .68837 L F
.33815 .69085 m .34228 .69093 L .34244 .6881 L F
.714 .695 .83 r
.34244 .6881 m .34329 .68441 L .34069 .68539 L F
.83 .776 .801 r
.57885 .42866 m .57743 .43142 L .57614 .42966 L F
.149 0 .235 r
.2107 .56054 m .21269 .56 L .21297 .55749 L F
.123 0 .346 r
.21297 .55749 m .21512 .55656 L .21556 .55396 L F
.158 0 .237 r
.21297 .55749 m .21447 .55906 L .21512 .55656 L F
.21297 .55749 m .21269 .56 L .21447 .55906 L F
.639 .461 .626 r
.64715 .36747 m .64682 .37067 L .64512 .37163 L F
.655 .235 .235 r
.35913 .68428 m .36032 .68228 L .35648 .68178 L F
0 .024 .592 r
.35756 .68684 m .35862 .68927 L .35817 .68758 L F
0 0 0 r
.35808 .68578 m .35913 .68428 L .35707 .68692 L F
.376 .016 .221 r
.3568 .68727 m .35913 .68428 L .35648 .68475 L F
0 0 0 r
.35808 .68578 m .35707 .68692 L .35711 .68691 L F
.24 0 .019 r
.36278 .68149 m .36057 .6822 L .35913 .68428 L F
.36278 .68149 m .36204 .68206 L .36065 .68282 L F
.36204 .68206 m .35913 .68428 L .36065 .68282 L F
0 0 0 r
.36065 .68282 m .35913 .68428 L .35808 .68578 L F
.24 0 .019 r
.36057 .6822 m .36032 .68228 L .35913 .68428 L F
.655 .235 .235 r
.35913 .68428 m .35648 .68178 L .35648 .68475 L F
.376 .016 .221 r
.3568 .68727 m .35648 .68475 L .35484 .68726 L F
.97 .904 .549 r
.35484 .68726 m .35672 .68583 L .3568 .68727 L F
.486 .577 .872 r
.35484 .68726 m .35627 .68802 L .35672 .68583 L F
.78 .975 .692 r
.35796 .68499 m .36065 .68282 L .3586 .68519 L F
.35752 .68598 m .3586 .68519 L .35711 .68691 L F
.35796 .68499 m .3586 .68519 L .35752 .68598 L F
.486 .577 .872 r
.35627 .68802 m .35674 .68718 L .35672 .68583 L F
.866 .751 .239 r
.35672 .68583 m .3568 .68727 L .35674 .68691 L F
.78 .975 .692 r
.35849 .68379 m .3568 .68727 L .35672 .68583 L F
.486 .577 .872 r
.35674 .68718 m .3571 .68652 L .35672 .68583 L F
.866 .751 .239 r
.35672 .68583 m .35674 .68691 L .35662 .68621 L F
0 .024 .592 r
.35672 .68583 m .3571 .68652 L .3571 .68629 L F
.715 .274 .2 r
.35655 .68644 m .35672 .68583 L .3571 .68629 L F
.315 0 .096 r
.35484 .68726 m .35412 .68523 L .35325 .68723 L F
.35484 .68726 m .35648 .68475 L .35412 .68523 L F
.35484 .68726 m .35412 .68523 L .35325 .68723 L F
.35484 .68726 m .35648 .68475 L .35412 .68523 L F
.479 .27 .517 r
.35412 .68523 m .35648 .68475 L .35648 .68178 L F
.35412 .68523 m .35648 .68475 L .35648 .68178 L F
.97 .904 .549 r
.35484 .68726 m .35648 .68475 L .35587 .68373 L F
.35484 .68726 m .35587 .68373 L .35672 .68583 L F
0 0 0 r
.35325 .68723 m .35182 .68851 L .35007 .69095 L F
.787 .632 .689 r
.34956 .68726 m .35325 .68723 L .35007 .69095 L F
.898 .658 .567 r
.35099 .68953 m .35346 .69003 L .35191 .68757 L F
.699 .624 .769 r
.35191 .68757 m .35346 .69003 L .35484 .68726 L F
.35191 .68757 m .35484 .68726 L .35441 .68664 L F
.367 .058 .302 r
.35099 .68953 m .35191 .68757 L .35441 .68664 L F
.486 .577 .872 r
.35484 .68726 m .35672 .68583 L .35441 .68664 L F
.367 .058 .302 r
.35174 .6881 m .35441 .68664 L .35192 .68773 L F
.35099 .68953 m .35345 .68745 L .35174 .6881 L F
.35345 .68745 m .35441 .68664 L .35174 .6881 L F
.528 .22 .389 r
.35099 .68953 m .35191 .68757 L .34956 .68726 L F
.996 .761 .446 r
.34977 .68827 m .35008 .68872 L .35131 .6874 L F
.35008 .68872 m .35112 .69022 L .35125 .68828 L F
.35008 .68872 m .35125 .68828 L .35131 .6874 L F
.715 .274 .2 r
.35336 .68735 m .35672 .68583 L .35655 .68644 L F
.866 .751 .239 r
.35672 .68583 m .35662 .68621 L .35657 .68595 L F
0 0 0 r
.35711 .68691 m .35707 .68692 L .3568 .68727 L F
.78 .975 .692 r
.3571 .68664 m .35711 .68691 L .3568 .68727 L F
.35849 .68379 m .35711 .68691 L .3571 .68664 L F
.486 .577 .872 r
.35627 .68802 m .35862 .68927 L .3571 .68652 L F
0 .024 .592 r
.3571 .68629 m .3573 .68688 L .35756 .68684 L F
.3571 .68652 m .3573 .68688 L .3571 .68629 L F
.3573 .68688 m .35862 .68927 L .35756 .68684 L F
.715 .274 .2 r
.35551 .68745 m .3571 .68629 L .35817 .68758 L F
.35336 .68735 m .3571 .68629 L .35551 .68745 L F
.78 .975 .692 r
.35836 .68409 m .35851 .68401 L .35796 .68499 L F
.35851 .68401 m .36065 .68282 L .35796 .68499 L F
.465 0 0 r
.35864 .68344 m .35849 .68379 L .35834 .68312 L F
.78 .975 .692 r
.35849 .68379 m .36065 .68282 L .35836 .68408 L F
.24 0 .019 r
.36278 .68149 m .36065 .68282 L .36128 .68055 L F
.962 .751 .573 r
.35941 .6797 m .36128 .68055 L .36065 .68282 L F
.35941 .6797 m .36128 .68055 L .36065 .68282 L F
0 .123 .668 r
.35941 .6797 m .36065 .68282 L .36158 .68193 L F
.476 .871 .69 r
.36158 .68193 m .36065 .68282 L .35849 .68379 L F
.812 .62 .643 r
.35849 .68379 m .36191 .68506 L .36158 .68193 L F
.465 0 0 r
.35962 .68449 m .35849 .68379 L .35864 .68344 L F
.78 .975 .692 r
.35849 .68379 m .35836 .68408 L .35836 .68409 L F
.456 .382 .685 r
.29024 .54785 m .29079 .55069 L .28863 .55108 L F
.398 .243 .552 r
.29081 .55366 m .28863 .55108 L .29079 .55069 L F
.29081 .55366 m .28876 .55462 L .28863 .55108 L F
.617 .347 .485 r
.59414 .44985 m .59143 .452 L .59158 .44987 L F
.59414 .44985 m .59419 .45216 L .59143 .452 L F
.599 .316 .459 r
.59674 .44984 m .59419 .45216 L .59414 .44985 L F
.966 .742 .303 r
.41804 .58012 m .41694 .58106 L .41692 .57892 L F
.41804 .58012 m .41799 .5827 L .41694 .58106 L F
.439 .503 .828 r
.34323 .51526 m .34258 .51201 L .34435 .51408 L F
.713 .22 0 r
.40182 .65556 m .4003 .65325 L .39898 .65215 L F
.03 0 .239 r
.34846 .58329 m .35044 .58232 L .35041 .57958 L F
0 0 .315 r
.35041 .57958 m .352 .57595 L .35055 .5756 L F
.35041 .57958 m .352 .57819 L .352 .57595 L F
.227 0 .273 r
.35041 .57958 m .35261 .58153 L .352 .57819 L F
.35041 .57958 m .35044 .58232 L .35261 .58153 L F
.559 .822 .46 r
.22109 .54732 m .22047 .54805 L .22193 .54625 L F
0 0 0 r
.65935 .41156 m .66099 .40826 L .66051 .40969 L F
0 0 .208 r
.6599 .41206 m .65935 .41156 L .66051 .40969 L F
.785 .873 .913 r
.38512 .6363 m .39021 .63503 L .38793 .63321 L F
.82 .773 .808 r
.38793 .63321 m .39021 .63503 L .39129 .63298 L F
.305 .035 .329 r
.3417 .59862 m .34441 .59582 L .34359 .5985 L F
.087 0 .026 r
.3417 .59862 m .34359 .5985 L .34066 .60099 L F
0 0 0 r
.22796 .55366 m .22722 .5575 L .22679 .55448 L F
.22796 .55366 m .22747 .55632 L .22722 .5575 L F
.79 .587 .627 r
.41225 .49765 m .40853 .49304 L .41113 .49295 L F
.41225 .49765 m .40832 .49722 L .40853 .49304 L F
.881 .566 .448 r
.41225 .49765 m .40876 .49819 L .40832 .49722 L F
.41225 .49765 m .41224 .50008 L .40876 .49819 L F
.719 .645 .774 r
.41499 .49421 m .41225 .49765 L .41113 .49295 L F
.816 .72 .759 r
.70956 .29637 m .7072 .29989 L .71064 .30032 L F
.746 .681 .788 r
.70956 .29637 m .71064 .30032 L .71314 .29604 L F
.309 .102 .428 r
.42087 .53555 m .41981 .53938 L .41866 .53888 L F
0 .318 .803 r
.41981 .53938 m .42052 .54007 L .41866 .53888 L F
.545 .309 .508 r
.42052 .54007 m .41825 .54138 L .41866 .53888 L F
.435 .81 .992 r
.72499 .34585 m .72478 .34745 L .7232 .3466 L F
.145 0 0 r
.25399 .54497 m .25456 .54609 L .25626 .54432 L F
.25399 .54497 m .25219 .54675 L .25456 .54609 L F
.542 .279 .466 r
.68225 .36812 m .68508 .36919 L .68274 .36982 L F
.68225 .36812 m .68543 .36654 L .68508 .36919 L F
.666 .446 .577 r
.59158 .44987 m .59143 .452 L .58776 .45283 L F
.597 .315 .46 r
.57475 .45806 m .57216 .45628 L .57601 .45574 L F
.57475 .45806 m .57218 .45854 L .57216 .45628 L F
.398 .372 .713 r
.44224 .53076 m .44004 .53276 L .43935 .52857 L F
.37 .327 .68 r
.44224 .53076 m .44256 .53472 L .44004 .53276 L F
.271 .324 .735 r
.44004 .53276 m .44256 .53472 L .44126 .5355 L F
.25 0 .31 r
.32355 .58879 m .32272 .59192 L .32086 .59253 L F
.303 .036 .332 r
.32482 .59113 m .32355 .58879 L .32616 .58829 L F
.32482 .59113 m .32272 .59192 L .32355 .58879 L F
.682 .629 .79 r
.30456 .55588 m .30258 .5547 L .30505 .55425 L F
.30456 .55588 m .3031 .5529 L .30258 .5547 L F
.334 .802 .704 r
.32857 .68074 m .32558 .68212 L .32628 .68144 L F
.801 .734 .79 r
.54559 .42427 m .54171 .42399 L .54363 .42259 L F
.741 .811 .907 r
.54697 .42032 m .54559 .42427 L .54363 .42259 L F
.54697 .42032 m .54816 .42284 L .54559 .42427 L F
.474 .68 .956 r
.70231 .32671 m .70314 .32863 L .70147 .32857 L F
.689 .783 .923 r
.28487 .52481 m .28254 .5259 L .2866 .52633 L F
.622 .765 .948 r
.28487 .52481 m .2866 .52633 L .28947 .52543 L F
.74 .656 .767 r
.22855 .56456 m .22624 .56784 L .22433 .56373 L F
.439 .186 .432 r
.33503 .5805 m .33453 .58302 L .33197 .58375 L F
.28 .049 .375 r
.33649 .58207 m .33503 .5805 L .33698 .57959 L F
.33649 .58207 m .33453 .58302 L .33503 .5805 L F
.92 .947 .798 r
.24955 .53419 m .24952 .53682 L .25143 .53526 L F
.24955 .53419 m .24715 .5373 L .24952 .53682 L F
0 0 .005 r
.2936 .55902 m .29048 .56215 L .29275 .56048 L F
.288 .142 .502 r
.29085 .56388 m .29275 .56048 L .29048 .56215 L F
.463 .135 .324 r
.41015 .51654 m .41248 .51778 L .41299 .51574 L F
.41299 .51574 m .41248 .51778 L .41015 .51654 L F
.779 .652 .722 r
.40599 .49747 m .40327 .50088 L .40195 .49705 L F
.591 .072 0 r
.40195 .49705 m .40465 .49809 L .40599 .49747 L F
.965 .933 .696 r
.40599 .49747 m .40465 .49809 L .40668 .49263 L F
.524 .302 .52 r
.40832 .49722 m .40596 .49998 L .40599 .49747 L F
.952 .606 .233 r
.58321 .40378 m .58486 .40504 L .58529 .40825 L F
0 0 .501 r
.58486 .40504 m .5864 .40855 L .58529 .40825 L F
.306 .111 .443 r
.3444 .56422 m .34628 .56381 L .34662 .56079 L F
.684 .49 .618 r
.3444 .56422 m .34806 .56689 L .34628 .56381 L F
.3444 .56422 m .34428 .56733 L .34806 .56689 L F
.641 .864 .983 r
.37643 .62949 m .38031 .63048 L .37575 .63083 L F
.643 .686 .875 r
.56569 .41441 m .56744 .41785 L .56396 .41825 L F
.469 .045 .151 r
.56396 .41825 m .56657 .41959 L .56379 .42018 L F
.56396 .41825 m .56744 .41785 L .56657 .41959 L F
.48 .456 .754 r
.59265 .42993 m .59001 .42902 L .59371 .4277 L F
.862 .764 .753 r
.69844 .31066 m .70045 .31336 L .69957 .30998 L F
.862 .867 .842 r
.69651 .31516 m .70045 .31336 L .69844 .31066 L F
.904 .888 .805 r
.70045 .31336 m .70196 .30712 L .69957 .30998 L F
.709 .695 .835 r
.38785 .50726 m .39102 .51026 L .38526 .50996 L F
.602 .141 .13 r
.39102 .51026 m .38795 .51165 L .38526 .50996 L F
.539 .655 .911 r
.39175 .50986 m .39102 .51026 L .38785 .50726 L F
.89 .849 .797 r
.39175 .50986 m .38795 .51165 L .39102 .51026 L F
.699 .679 .827 r
.33923 .67875 m .34356 .67984 L .3416 .67844 L F
.422 .365 .69 r
.34356 .67984 m .34591 .68159 L .34587 .67848 L F
0 0 .372 r
.34587 .67848 m .34591 .68159 L .34719 .68024 L F
.047 0 0 r
.34356 .67984 m .34587 .67848 L .34647 .67927 L F
.34356 .67984 m .34647 .67927 L .3416 .67844 L F
.422 .365 .69 r
.34356 .67984 m .34414 .68251 L .34591 .68159 L F
.183 0 .286 r
.35804 .59605 m .35564 .59926 L .35735 .59847 L F
.46 .286 .558 r
.35504 .60176 m .35735 .59847 L .35564 .59926 L F
0 .157 .677 r
.40581 .53861 m .40769 .54094 L .40656 .53709 L F
.493 .049 .122 r
.24166 .56448 m .24344 .56611 L .24555 .56389 L F
.717 .183 0 r
.24596 .56545 m .24555 .56389 L .24344 .56611 L F
.24596 .56545 m .24765 .56624 L .24555 .56389 L F
.7 .268 .221 r
.24555 .56389 m .24765 .56624 L .24787 .56459 L F
.951 .614 .211 r
.7083 .29501 m .70911 .29402 L .70871 .29256 L F
.7083 .29501 m .70956 .29637 L .70911 .29402 L F
.709 .443 .521 r
.70911 .29402 m .70956 .29637 L .71314 .29604 L F
.834 .688 .701 r
.41 .50082 m .40596 .49998 L .40859 .49994 L F
.41 .50082 m .40555 .50251 L .40596 .49998 L F
.983 .887 .65 r
.41 .50082 m .40876 .49819 L .41224 .50008 L F
.41 .50082 m .40859 .49994 L .40876 .49819 L F
0 .358 .829 r
.37435 .52295 m .37405 .5219 L .37081 .51999 L F
.606 .257 .352 r
.37405 .5219 m .37059 .5224 L .37081 .51999 L F
.662 .538 .702 r
.73688 .3314 m .73912 .32725 L .73635 .32865 L F
.747 .231 0 r
.25812 .57159 m .25966 .57304 L .25781 .57205 L F
.069 0 0 r
.25812 .57159 m .25557 .57211 L .2587 .57073 L F
.25812 .57159 m .25553 .57275 L .25557 .57211 L F
.188 .701 .892 r
.25812 .57159 m .25396 .57128 L .25553 .57275 L F
.25523 .57137 m .25614 .57116 L .25396 .57128 L F
.25812 .57159 m .25614 .57116 L .25523 .57137 L F
.747 .231 0 r
.25812 .57159 m .25781 .57205 L .25614 .57116 L F
.841 .451 .308 r
.25966 .57304 m .2578 .57296 L .25614 .57116 L F
.928 .672 .189 r
.2578 .57296 m .25713 .57093 L .25614 .57116 L F
.25713 .57093 m .25653 .5691 L .25614 .57116 L F
.069 0 0 r
.25812 .57159 m .2587 .57073 L .25968 .5703 L F
.219 0 0 r
.34395 .59069 m .3432 .5892 L .34177 .59151 L F
.34395 .59069 m .34544 .58861 L .3432 .5892 L F
.928 .707 .22 r
.35587 .68373 m .35648 .68178 L .35559 .67988 L F
.35587 .68373 m .35648 .68475 L .35648 .68178 L F
.584 .938 .931 r
.29666 .51608 m .2946 .51723 L .29209 .51723 L F
.21 .717 .899 r
.33979 .49693 m .33784 .49646 L .34186 .49675 L F
.642 .345 .451 r
.57866 .45585 m .57475 .45806 L .57601 .45574 L F
.827 .815 .838 r
.43047 .55092 m .42846 .55116 L .43094 .54909 L F
0 .148 .684 r
.4284 .55101 m .42778 .55136 L .42818 .55056 L F
0 .124 .623 r
.428 .55121 m .42778 .55136 L .4284 .55101 L F
.827 .815 .838 r
.4284 .55101 m .428 .55121 L .42836 .55095 L F
0 .124 .623 r
.428 .55121 m .4284 .55101 L .42844 .55099 L F
.827 .815 .838 r
.42846 .55116 m .428 .55121 L .4284 .55101 L F
.189 0 .164 r
.428 .55121 m .43018 .5516 L .43071 .54984 L F
.827 .815 .838 r
.42846 .55116 m .42836 .55095 L .4304 .54947 L F
.4305 .54945 m .4304 .54947 L .43094 .54909 L F
.42846 .55116 m .4304 .54947 L .4305 .54945 L F
0 .148 .684 r
.42818 .55056 m .42778 .55136 L .42585 .54912 L F
.189 0 .164 r
.428 .55121 m .43071 .54984 L .43094 .54909 L F
0 .148 .684 r
.42867 .55086 m .42585 .54912 L .42716 .54616 L F
.661 .971 .891 r
.42378 .5484 m .4223 .55002 L .42567 .54814 L F
.598 .95 .845 r
.42414 .54844 m .42393 .54862 L .42567 .54814 L F
.42393 .54862 m .4223 .55002 L .42358 .5493 L F
.42393 .54862 m .42358 .5493 L .42567 .54814 L F
0 .148 .684 r
.42867 .55086 m .4284 .55101 L .42818 .55056 L F
.757 .709 .807 r
.42399 .54851 m .428 .55121 L .42867 .55086 L F
.763 .515 .56 r
.42667 .54649 m .42673 .54648 L .42716 .54616 L F
.42378 .5484 m .42663 .54655 L .42667 .54649 L F
.42663 .54655 m .42673 .54648 L .42667 .54649 L F
.42378 .5484 m .42663 .54655 L .42567 .54814 L F
.462 .888 .82 r
.42578 .54783 m .42567 .54814 L .42663 .54655 L F
.763 .515 .56 r
.42399 .54851 m .42719 .54701 L .42716 .54616 L F
.462 .888 .82 r
.42594 .54736 m .42578 .54783 L .42699 .54594 L F
.42578 .54783 m .42663 .54655 L .42699 .54594 L F
.763 .515 .56 r
.42378 .5484 m .42716 .54616 L .42699 .54594 L F
.42378 .5484 m .42699 .54594 L .42663 .54655 L F
.42378 .5484 m .42399 .54851 L .42673 .54648 L F
.462 .888 .82 r
.42578 .54783 m .42457 .54828 L .42567 .54814 L F
.42416 .54833 m .42401 .54847 L .42567 .54814 L F
.763 .515 .56 r
.42399 .54851 m .4273 .55017 L .4272 .54729 L F
.42413 .54844 m .4272 .54729 L .42719 .54701 L F
.598 .95 .845 r
.42413 .54844 m .42412 .54846 L .42414 .54844 L F
.763 .515 .56 r
.42399 .54851 m .4272 .54729 L .42413 .54844 L F
.462 .888 .82 r
.42594 .54736 m .42416 .54833 L .42457 .54828 L F
.42594 .54736 m .42457 .54828 L .42578 .54783 L F
.757 .709 .807 r
.42378 .5484 m .42396 .54852 L .42398 .5485 L F
.462 .888 .82 r
.42416 .54833 m .42385 .5485 L .42401 .54847 L F
.757 .709 .807 r
.42398 .5485 m .42398 .54853 L .42399 .54851 L F
.42396 .54852 m .42398 .54853 L .42398 .5485 L F
.42398 .54853 m .428 .55121 L .42399 .54851 L F
.42398 .54853 m .42559 .55278 L .428 .55121 L F
.42378 .5484 m .42386 .5486 L .42398 .54853 L F
.42386 .5486 m .42559 .55278 L .42398 .54853 L F
.598 .95 .845 r
.42412 .54846 m .4223 .55002 L .42414 .54844 L F
.42385 .5485 m .4237 .54864 L .42413 .54844 L F
.738 .7 .815 r
.42146 .55224 m .42559 .55278 L .42386 .5486 L F
.42356 .54878 m .42386 .5486 L .42378 .5484 L F
.598 .95 .845 r
.42413 .54844 m .4223 .55002 L .42413 .54844 L F
.42358 .54876 m .4223 .55002 L .42413 .54844 L F
.082 0 .338 r
.42358 .54876 m .42146 .55224 L .4223 .55002 L F
.738 .7 .815 r
.42146 .55224 m .42386 .5486 L .42358 .54876 L F
.082 0 .338 r
.42385 .5485 m .42146 .55224 L .42358 .54876 L F
.738 .7 .815 r
.42146 .55224 m .42358 .54876 L .42356 .54878 L F
.598 .95 .845 r
.4237 .54864 m .42358 .54876 L .42413 .54844 L F
.763 .515 .56 r
.4273 .55017 m .42867 .55086 L .42837 .54993 L F
.4273 .55017 m .42837 .54993 L .42716 .54616 L F
0 .124 .623 r
.428 .55121 m .42844 .55099 L .42867 .55086 L F
.168 .217 .67 r
.62638 .43643 m .62417 .43639 L .62736 .43634 L F
.868 .717 .196 r
.39723 .54303 m .39771 .54233 L .3955 .54034 L F
.099 .29 .769 r
.37981 .54395 m .38006 .54535 L .37968 .54404 L F
.37968 .54404 m .38006 .54535 L .37981 .54395 L F
.822 .966 .898 r
.33605 .52607 m .336 .52487 L .33857 .52548 L F
.33605 .52607 m .33513 .52509 L .336 .52487 L F
.943 .67 .491 r
.33605 .52607 m .33399 .52754 L .33513 .52509 L F
.33605 .52607 m .33597 .52896 L .33399 .52754 L F
.02 0 .196 r
.36386 .64557 m .36243 .64687 L .36153 .64916 L F
0 0 .243 r
.38495 .58327 m .38564 .58623 L .38737 .58249 L F
.38495 .58327 m .38496 .58641 L .38564 .58623 L F
.453 .446 .76 r
.26578 .53839 m .26708 .53448 L .26429 .53499 L F
.26578 .53839 m .26765 .53785 L .26708 .53448 L F
.509 .746 .981 r
.46156 .56954 m .46168 .57057 L .4579 .56962 L F
.543 .459 .709 r
.46136 .57241 m .4579 .56962 L .46168 .57057 L F
.465 .71 .975 r
.46277 .56883 m .46168 .57057 L .46156 .56954 L F
.602 .548 .766 r
.46277 .56883 m .46136 .57241 L .46168 .57057 L F
.81 .335 .081 r
.42383 .59485 m .42317 .59552 L .4211 .59272 L F
.603 .858 .508 r
.42567 .59249 m .42317 .59552 L .42383 .59485 L F
.647 .142 .031 r
.70939 .3666 m .70949 .36815 L .70798 .366 L F
.70939 .3666 m .71117 .3684 L .70949 .36815 L F
.69 .938 .964 r
.40853 .49304 m .40912 .49142 L .41113 .49295 L F
.40853 .49304 m .40668 .49263 L .40912 .49142 L F
.709 .573 .699 r
.6649 .37716 m .6649 .3797 L .6607 .37942 L F
.675 .545 .699 r
.66741 .37617 m .6649 .3797 L .6649 .37716 L F
.315 .338 .726 r
.71878 .32237 m .7216 .32426 L .72151 .32166 L F
.71878 .32237 m .72069 .32539 L .7216 .32426 L F
.845 .711 .715 r
.53912 .42955 m .54311 .42975 L .54059 .43331 L F
.692 .785 .922 r
.40728 .50643 m .40525 .50791 L .40325 .5059 L F
.862 .879 .849 r
.66634 .33278 m .66762 .33436 L .66635 .33544 L F
.833 .876 .875 r
.67042 .3314 m .66762 .33436 L .66634 .33278 L F
.141 0 .332 r
.20377 .58947 m .20184 .59287 L .20305 .59233 L F
.472 .312 .582 r
.20124 .59542 m .20305 .59233 L .20184 .59287 L F
.214 .059 .443 r
.27019 .56578 m .26785 .56917 L .26883 .56734 L F
.75 .681 .784 r
.65703 .37084 m .65183 .37272 L .65301 .37022 L F
0 .058 .591 r
.28303 .64584 m .28419 .64659 L .28305 .64546 L F
.989 .724 .415 r
.28191 .64298 m .28301 .64626 L .28303 .64584 L F
.854 .408 .142 r
.28018 .64228 m .28191 .64298 L .28303 .64584 L F
0 .058 .591 r
.28303 .64584 m .28305 .64546 L .28196 .64437 L F
.989 .724 .415 r
.28301 .64626 m .28312 .64659 L .28303 .64584 L F
0 .057 .585 r
.23112 .60092 m .23091 .60481 L .22959 .60275 L F
.297 0 0 r
.2451 .6243 m .24311 .62359 L .2405 .62252 L F
.069 .436 .874 r
.2451 .6243 m .24543 .62314 L .24311 .62359 L F
.2451 .6243 m .24699 .62496 L .24543 .62314 L F
.433 .412 .735 r
.3758 .60268 m .3767 .60656 L .37854 .60468 L F
.627 .331 .448 r
.27075 .62381 m .27378 .62409 L .27377 .62171 L F
.306 .798 .861 r
.27449 .62156 m .27377 .62171 L .27735 .62106 L F
.167 0 .376 r
.27377 .62171 m .27534 .62288 L .27735 .62106 L F
.27377 .62171 m .27378 .62409 L .27534 .62288 L F
.597 .944 .794 r
.33279 .67844 m .32857 .68074 L .33094 .68031 L F
0 0 0 r
.33265 .67961 m .33279 .67844 L .33094 .68031 L F
.33265 .67961 m .33506 .6769 L .33279 .67844 L F
.317 0 .137 r
.23804 .56731 m .24054 .56664 L .24166 .56448 L F
0 0 0 r
.24166 .56448 m .24193 .56523 L .24344 .56611 L F
.24166 .56448 m .24054 .56664 L .24193 .56523 L F
.545 .266 .442 r
.43861 .58654 m .43828 .58883 L .43559 .58911 L F
.552 .385 .608 r
.44096 .58313 m .44107 .5861 L .43861 .58654 L F
.535 .275 .468 r
.44107 .5861 m .43828 .58883 L .43861 .58654 L F
0 0 0 r
.3951 .60228 m .39486 .60317 L .39448 .60108 L F
.703 .545 .671 r
.59639 .4213 m .59513 .42414 L .59557 .42167 L F
.59 .584 .815 r
.28264 .61497 m .28693 .61719 L .28486 .61527 L F
.42 .454 .789 r
.35593 .61765 m .3593 .6209 L .35876 .61817 L F
0 0 .306 r
.34846 .58329 m .34939 .58449 L .35044 .58232 L F
.34846 .58329 m .34876 .5862 L .34939 .58449 L F
.775 .988 .751 r
.33333 .49779 m .33344 .49641 L .33544 .49729 L F
.33333 .49779 m .3314 .49876 L .33344 .49641 L F
.089 0 .066 r
.61377 .44461 m .61197 .44793 L .61005 .44891 L F
0 0 0 r
.61579 .44343 m .61197 .44793 L .61377 .44461 L F
.66051 .40969 m .66099 .40826 L .66263 .40627 L F
.696 .264 .218 r
.33386 .69323 m .33568 .69135 L .33411 .69119 L F
.33386 .69323 m .33411 .69119 L .3316 .69094 L F
.478 0 0 r
.3316 .69094 m .33568 .69135 L .33459 .69167 L F
.583 .573 .808 r
.3316 .69094 m .33278 .68699 L .33176 .69003 L F
.3316 .69094 m .33459 .69167 L .33278 .68699 L F
0 .12 .668 r
.33176 .69003 m .33386 .69323 L .3316 .69094 L F
.942 .649 .193 r
.33366 .6949 m .33386 .69323 L .33298 .69206 L F
.33392 .69602 m .33386 .69323 L .33366 .6949 L F
0 0 0 r
.33459 .69167 m .33568 .69135 L .33815 .69085 L F
.37 .707 .986 r
.58706 .40168 m .58348 .40069 L .58529 .40116 L F
.072 0 0 r
.58862 .40211 m .58706 .40168 L .58529 .40116 L F
0 .483 .835 r
.58699 .40117 m .58862 .40211 L .58633 .40146 L F
.58699 .40117 m .58633 .40146 L .58529 .40116 L F
0 .066 .628 r
.58742 .40098 m .58699 .40117 L .58638 .39945 L F
.766 .262 0 r
.58835 .40261 m .58862 .40211 L .58699 .40117 L F
.072 0 0 r
.58862 .40211 m .58906 .40129 L .58706 .40168 L F
.24 .272 .694 r
.59019 .40583 m .59008 .40465 L .58964 .40377 L F
.59008 .40465 m .58974 .40116 L .58964 .40377 L F
.987 .751 .362 r
.58964 .40377 m .58974 .40116 L .58862 .40211 L F
0 .075 .617 r
.5891 .40268 m .58964 .40377 L .58862 .40211 L F
.59226 .40637 m .58964 .40377 L .5891 .40268 L F
.01 .279 .779 r
.58964 .40377 m .59208 .40732 L .59019 .40583 L F
0 .12 .669 r
.59226 .40637 m .59208 .40732 L .59123 .40608 L F
.59226 .40637 m .59123 .40608 L .58964 .40377 L F
0 .075 .617 r
.59226 .40637 m .58862 .40211 L .59091 .40533 L F
0 .338 .702 r
.59342 .4067 m .59226 .40637 L .59091 .40533 L F
.59378 .40689 m .59226 .40637 L .59342 .4067 L F
.766 .262 0 r
.59091 .40533 m .58699 .40117 L .5894 .40391 L F
0 .066 .628 r
.5894 .40391 m .58699 .40117 L .58742 .40098 L F
.766 .262 0 r
.59091 .40533 m .58862 .40211 L .58835 .40261 L F
.072 0 0 r
.58862 .40211 m .58974 .40116 L .58906 .40129 L F
.32 0 .239 r
.20761 .5636 m .20981 .56313 L .2107 .56054 L F
.249 0 .209 r
.2107 .56054 m .21197 .56233 L .21269 .56 L F
.2107 .56054 m .20981 .56313 L .21197 .56233 L F
.494 .212 .415 r
.29694 .54225 m .29591 .54471 L .29348 .54505 L F
.525 .243 .43 r
.29886 .54357 m .29694 .54225 L .29899 .54159 L F
.29886 .54357 m .29591 .54471 L .29694 .54225 L F
.71 .553 .673 r
.6649 .3797 m .66235 .38287 L .6607 .37942 L F
.688 .562 .708 r
.66741 .37617 m .66887 .38002 L .6649 .3797 L F
.573 .556 .797 r
.66885 .38276 m .6649 .3797 L .66887 .38002 L F
0 0 0 r
.62841 .4425 m .63037 .44127 L .63168 .43952 L F
.948 .627 .198 r
.71847 .34474 m .71994 .34485 L .72016 .34337 L F
.71836 .34483 m .71852 .34483 L .71847 .34474 L F
.71852 .34483 m .71994 .34485 L .71847 .34474 L F
.637 .686 .879 r
.72017 .34689 m .72016 .34337 L .71994 .34485 L F
.72019 .34713 m .72019 .34671 L .72017 .34689 L F
.72019 .34671 m .72016 .34337 L .72017 .34689 L F
.72019 .34671 m .72047 .3463 L .72016 .34337 L F
.948 .627 .198 r
.7183 .34487 m .71835 .34487 L .71836 .34483 L F
.7183 .34487 m .72019 .34713 L .71994 .34485 L F
0 .145 .666 r
.71995 .34259 m .72016 .34337 L .71741 .34019 L F
.56 .083 0 r
.71741 .34019 m .72016 .34337 L .71881 .34186 L F
.819 .969 .657 r
.71981 .34287 m .72016 .34337 L .71996 .34266 L F
0 .078 .574 r
.72016 .34337 m .72091 .34385 L .71968 .34269 L F
.926 .903 .783 r
.71824 .34463 m .71839 .34475 L .7183 .34487 L F
.819 .969 .657 r
.7184 .34474 m .71978 .34282 L .71824 .34463 L F
.765 .914 .939 r
.71841 .34463 m .71838 .34473 L .71824 .34463 L F
.71838 .34473 m .71838 .34474 L .71824 .34463 L F
.819 .969 .657 r
.7183 .34487 m .7184 .34474 L .71824 .34463 L F
.71978 .34282 m .71995 .34259 L .71976 .34281 L F
.71978 .34282 m .71976 .34281 L .71824 .34463 L F
0 .078 .574 r
.72016 .34337 m .71978 .34282 L .71881 .34186 L F
.55 .405 .637 r
.71881 .34186 m .71824 .34463 L .71976 .34281 L F
.71881 .34186 m .71976 .34281 L .71995 .34259 L F
0 .078 .574 r
.71976 .34281 m .71968 .34269 L .71944 .34246 L F
.71978 .34282 m .71977 .34282 L .71976 .34281 L F
.71977 .34282 m .71968 .34269 L .71976 .34281 L F
.71978 .34282 m .71944 .34246 L .71881 .34186 L F
.819 .969 .657 r
.7183 .34487 m .72016 .34337 L .71981 .34287 L F
.7183 .34487 m .71996 .34266 L .71995 .34259 L F
.926 .903 .783 r
.71839 .34475 m .72047 .3463 L .7183 .34487 L F
.72047 .3463 m .72074 .3465 L .72047 .34632 L F
.72047 .3463 m .72047 .34632 L .7183 .34487 L F
.637 .686 .879 r
.72047 .3463 m .72163 .34467 L .72097 .3441 L F
.72047 .3463 m .72097 .3441 L .72016 .34337 L F
.765 .914 .939 r
.72163 .34467 m .72074 .3465 L .72047 .3463 L F
.637 .686 .879 r
.72019 .34713 m .72048 .3463 L .72019 .34671 L F
.888 .918 .838 r
.72047 .34632 m .72019 .34713 L .7183 .34487 L F
.72074 .3465 m .72019 .34713 L .72047 .34632 L F
.637 .686 .879 r
.72019 .34713 m .72163 .34467 L .72048 .3463 L F
.765 .914 .939 r
.72163 .34467 m .72047 .3463 L .72026 .34614 L F
.948 .627 .198 r
.71835 .34487 m .71994 .34485 L .71836 .34483 L F
.765 .914 .939 r
.72044 .3447 m .72026 .34614 L .71838 .34474 L F
.72163 .34467 m .72026 .34614 L .72044 .3447 L F
0 .078 .574 r
.72016 .34337 m .72143 .3445 L .72091 .34385 L F
.72143 .3445 m .72163 .34467 L .72091 .34385 L F
.55 .405 .637 r
.71881 .34186 m .72091 .34385 L .71824 .34463 L F
.533 .869 .992 r
.71951 .34359 m .72091 .34385 L .71824 .34463 L F
.597 .029 0 r
.71936 .34428 m .72091 .34385 L .71951 .34359 L F
.786 .988 .744 r
.72042 .34323 m .72091 .34385 L .71936 .34428 L F
.636 .711 .901 r
.71964 .34191 m .72091 .34385 L .72287 .34083 L F
.786 .988 .744 r
.72287 .34083 m .72091 .34385 L .72042 .34323 L F
.765 .914 .939 r
.72163 .34467 m .71841 .34463 L .72091 .34385 L F
.71841 .34463 m .71824 .34463 L .71838 .34459 L F
.71841 .34463 m .71838 .34459 L .72091 .34385 L F
.72163 .34467 m .71838 .34474 L .71841 .34463 L F
.878 .912 .509 r
.3455 .54529 m .34424 .54851 L .34442 .5464 L F
.483 .167 .353 r
.37312 .57357 m .37547 .57569 L .37564 .57334 L F
.37312 .57357 m .37217 .57652 L .37547 .57569 L F
.414 .323 .644 r
.35484 .54158 m .35479 .54391 L .35582 .54157 L F
.35295 .54161 m .35387 .54276 L .35484 .54158 L F
.35387 .54276 m .35479 .54391 L .35484 .54158 L F
.35295 .54161 m .35317 .54508 L .35479 .54391 L F
.958 .919 .727 r
.35395 .54028 m .35346 .54328 L .35295 .54161 L F
.35346 .54328 m .35317 .54508 L .35301 .5426 L F
.35346 .54328 m .35301 .5426 L .35295 .54161 L F
.35395 .54028 m .35167 .5441 L .35237 .54456 L F
.35347 .54324 m .35237 .54456 L .35317 .54508 L F
.35395 .54028 m .35237 .54456 L .35347 .54324 L F
.663 .923 .974 r
.35317 .54508 m .35167 .5441 L .35479 .54391 L F
.652 .172 .101 r
.35167 .5441 m .35371 .5455 L .35434 .54458 L F
.35392 .54396 m .35434 .54458 L .35479 .54391 L F
.35167 .5441 m .35434 .54458 L .35392 .54396 L F
.878 .912 .509 r
.3455 .54529 m .34442 .5464 L .34582 .54404 L F
.603 .585 .806 r
.6688 .38535 m .66726 .39007 L .66597 .38598 L F
.6688 .38535 m .6697 .38941 L .66726 .39007 L F
.529 .387 .631 r
.6697 .38941 m .66762 .39227 L .66726 .39007 L F
.664 .471 .614 r
.31829 .56715 m .32087 .56717 L .32097 .56404 L F
.521 .376 .625 r
.32097 .56404 m .32361 .56344 L .32329 .56085 L F
.49 .328 .588 r
.32097 .56404 m .32381 .56641 L .32361 .56344 L F
.32097 .56404 m .32087 .56717 L .32381 .56641 L F
.768 .744 .831 r
.35314 .53169 m .35502 .53232 L .35692 .53021 L F
.647 .094 0 r
.35511 .53364 m .35502 .53232 L .35314 .53169 L F
.35511 .53364 m .35763 .53456 L .35502 .53232 L F
0 0 0 r
.33443 .50371 m .33494 .50361 L .33297 .50229 L F
.33443 .50371 m .3333 .50659 L .33494 .50361 L F
.216 0 0 r
.44732 .56945 m .45027 .56962 L .45076 .56917 L F
.871 .799 .31 r
.45076 .56917 m .45088 .56628 L .45377 .56713 L F
.332 .754 .976 r
.58336 .42038 m .58469 .42119 L .58075 .42054 L F
.58075 .42054 m .58469 .42119 L .58336 .42038 L F
0 0 0 r
.58653 .41963 m .58469 .42119 L .58645 .41986 L F
.885 .805 .322 r
.58469 .42119 m .58497 .41756 L .58336 .42038 L F
.58497 .41756 m .58449 .41783 L .58336 .42038 L F
.576 .88 .993 r
.58645 .41986 m .58469 .42119 L .58336 .42038 L F
.857 .637 .605 r
.58505 .41657 m .58204 .41872 L .58336 .42038 L F
.576 .88 .993 r
.58645 .41986 m .58336 .42038 L .58579 .42198 L F
.85 .536 .457 r
.58238 .41901 m .58645 .41986 L .58579 .42198 L F
.58204 .41872 m .58264 .41887 L .58238 .41901 L F
.58264 .41887 m .58645 .41986 L .58238 .41901 L F
.885 .805 .322 r
.58497 .41756 m .58505 .41657 L .58449 .41783 L F
.332 .754 .976 r
.58336 .42038 m .58469 .42119 L .58075 .42054 L F
.846 .848 .845 r
.37002 .64021 m .37432 .63927 L .37194 .64154 L F
.746 .656 .761 r
.34189 .52574 m .33998 .5292 L .33857 .52548 L F
.703 .55 .677 r
.6607 .37942 m .66235 .38287 L .65845 .38244 L F
.678 .159 0 r
.62443 .44152 m .62841 .4425 L .62518 .44027 L F
.8 .712 .768 r
.64682 .37067 m .64668 .37313 L .64441 .37366 L F
.682 .509 .646 r
.64668 .37313 m .64402 .37612 L .64441 .37366 L F
.64668 .37313 m .648 .37662 L .64402 .37612 L F
.656 .536 .705 r
.64881 .36962 m .64668 .37313 L .64682 .37067 L F
.64881 .36962 m .65059 .37338 L .64668 .37313 L F
.779 .678 .752 r
.65059 .37338 m .648 .37662 L .64668 .37313 L F
.587 .817 .427 r
.69717 .34474 m .69589 .34651 L .69637 .3458 L F
0 0 .177 r
.69637 .3458 m .69701 .34595 L .69693 .34495 L F
.916 .832 .374 r
.69692 .34323 m .69717 .34474 L .69637 .3458 L F
.714 .702 .168 r
.69692 .34323 m .69637 .3458 L .69682 .34341 L F
0 0 .177 r
.69637 .3458 m .69693 .34495 L .69682 .34341 L F
.587 .817 .427 r
.69589 .34651 m .69484 .34797 L .69637 .3458 L F
0 0 0 r
.69637 .3458 m .69484 .34797 L .69395 .34978 L F
0 0 .202 r
.36679 .65083 m .36632 .65304 L .3662 .64983 L F
.952 .868 .718 r
.39978 .6107 m .4028 .60799 L .40177 .60731 L F
.39978 .6107 m .40141 .61191 L .4028 .60799 L F
.92 .634 .15 r
.38308 .52047 m .38358 .51966 L .3803 .518 L F
.38308 .52047 m .38396 .52249 L .38358 .51966 L F
.618 .954 .807 r
.62939 .45096 m .63118 .4505 L .63318 .44892 L F
.496 0 0 r
.32043 .53299 m .3226 .53441 L .32447 .53461 L F
0 0 .299 r
.3226 .53441 m .3225 .53709 L .32447 .53461 L F
.46 .52 .833 r
.32447 .53461 m .32682 .53423 L .32549 .53101 L F
.539 .045 .03 r
.3392 .53347 m .33562 .53393 L .33735 .53245 L F
.768 .692 .779 r
.35567 .60501 m .35465 .60639 L .35304 .60526 L F
.371 .63 .954 r
.35304 .60526 m .35465 .60639 L .35443 .60457 L F
.875 .598 .515 r
.35304 .60526 m .35242 .60772 L .35465 .60639 L F
.819 .936 .568 r
.35567 .60501 m .35739 .60117 L .35728 .60402 L F
.582 .801 .983 r
.35443 .60457 m .35465 .60639 L .35728 .60402 L F
.817 .69 .724 r
.65164 .3504 m .65515 .35105 L .65306 .35406 L F
.357 .642 .963 r
.39018 .57687 m .39097 .57523 L .3888 .5752 L F
.547 .005 0 r
.39018 .57687 m .39246 .57895 L .39103 .57798 L F
.39018 .57687 m .39103 .57798 L .39097 .57523 L F
.095 .454 .885 r
.24739 .57241 m .24686 .56998 L .24511 .56986 L F
.24739 .57241 m .24907 .57295 L .24686 .56998 L F
.063 0 .11 r
.34546 .59717 m .34441 .59582 L .34667 .59519 L F
.34546 .59717 m .34359 .5985 L .34441 .59582 L F
.554 .617 .869 r
.32759 .5813 m .32442 .58084 L .3257 .57879 L F
.448 .321 .614 r
.22365 .57511 m .22401 .57991 L .22198 .58046 L F
.458 .353 .647 r
.22401 .57991 m .22449 .58249 L .22198 .58046 L F
.864 .781 .768 r
.63637 .36746 m .63584 .36986 L .63237 .36944 L F
.864 .779 .765 r
.63237 .36944 m .63584 .36986 L .63351 .37308 L F
.687 .511 .643 r
.63584 .36986 m .63751 .3737 L .63351 .37308 L F
.743 .645 .751 r
.63854 .36652 m .63584 .36986 L .63637 .36746 L F
.747 .38 .359 r
.63584 .36986 m .64008 .37301 L .63751 .3737 L F
.921 .532 .237 r
.60947 .37488 m .6116 .37653 L .61196 .37843 L F
.575 .279 .429 r
.6116 .37653 m .61408 .37845 L .61196 .37843 L F
.734 .569 .669 r
.64881 .36962 m .65301 .37022 L .65059 .37338 L F
.801 .671 .72 r
.65301 .37022 m .65183 .37272 L .65059 .37338 L F
0 .124 .623 r
.428 .55121 m .42994 .55317 L .42778 .55136 L F
.727 .618 .736 r
.63351 .37308 m .63485 .37739 L .63106 .37629 L F
.599 .543 .763 r
.63754 .37632 m .63485 .37739 L .63351 .37308 L F
.114 0 .217 r
.39659 .6105 m .39706 .60866 L .39471 .61223 L F
.991 .742 .45 r
.39569 .60716 m .39706 .60866 L .39659 .6105 L F
.438 .234 .504 r
.37569 .68117 m .37545 .68394 L .37327 .68185 L F
.735 .692 .81 r
.42452 .49073 m .42538 .49474 L .42158 .49425 L F
.666 .647 .822 r
.42798 .49394 m .42538 .49474 L .42452 .49073 L F
.597 .533 .753 r
.42872 .49637 m .42538 .49474 L .42798 .49394 L F
.054 .271 .764 r
.38797 .61478 m .39058 .61731 L .39147 .61463 L F
.764 .683 .772 r
.39278 .61648 m .39393 .61472 L .39346 .61377 L F
0 0 0 r
.39346 .61377 m .39368 .61299 L .39147 .61463 L F
0 0 .063 r
.39346 .61377 m .39147 .61463 L .39058 .61731 L F
.39346 .61377 m .39058 .61731 L .39278 .61648 L F
.817 .737 .776 r
.39393 .61472 m .39278 .61648 L .39149 .61273 L F
.39422 .61495 m .39278 .61648 L .39393 .61472 L F
.764 .683 .772 r
.39278 .61648 m .39398 .61481 L .39393 .61472 L F
.817 .737 .776 r
.39422 .61495 m .39393 .61472 L .39346 .61377 L F
.39422 .61495 m .39346 .61377 L .39527 .61301 L F
.764 .683 .772 r
.39398 .61481 m .39527 .61301 L .39346 .61377 L F
.817 .737 .776 r
.39393 .61472 m .39334 .61423 L .39346 .61377 L F
.39334 .61423 m .39149 .61273 L .39346 .61377 L F
0 0 0 r
.39346 .61377 m .39471 .61223 L .39368 .61299 L F
.587 .337 .505 r
.44439 .58281 m .44107 .5861 L .44096 .58313 L F
.44439 .58281 m .4439 .58588 L .44107 .5861 L F
.536 .292 .492 r
.44686 .58522 m .44439 .58281 L .44704 .58256 L F
.44686 .58522 m .4439 .58588 L .44439 .58281 L F
0 0 0 r
.36035 .59269 m .35804 .59605 L .35934 .59511 L F
0 0 .112 r
.35934 .59511 m .35804 .59605 L .35735 .59847 L F
.81 .754 .801 r
.39416 .50668 m .3931 .50902 L .39175 .50986 L F
.519 .913 .803 r
.72217 .35629 m .72598 .35461 L .72459 .35297 L F
.872 .937 .86 r
.72598 .35461 m .72632 .35156 L .72459 .35297 L F
.72598 .35461 m .72884 .35147 L .72632 .35156 L F
.775 .781 .858 r
.63289 .41575 m .63365 .41662 L .63025 .41785 L F
.477 .079 .206 r
.63305 .41781 m .63365 .41662 L .63025 .41785 L F
.318 .636 .964 r
.63588 .41621 m .63365 .41662 L .63289 .41575 L F
.63588 .41621 m .63676 .41772 L .63365 .41662 L F
.63365 .41662 m .63676 .41772 L .63588 .41621 L F
.63365 .41662 m .63588 .41621 L .63305 .41781 L F
.457 .031 .141 r
.27269 .55528 m .2721 .55666 L .27502 .55614 L F
.451 .493 .812 r
.43895 .51795 m .43697 .51995 L .43564 .51618 L F
.399 .394 .738 r
.43895 .51795 m .43786 .52239 L .43697 .51995 L F
.527 .532 .804 r
.43563 .50296 m .43406 .50685 L .43311 .50382 L F
.43563 .50296 m .43827 .50812 L .43406 .50685 L F
.453 .306 .59 r
.43656 .51001 m .43406 .50685 L .43827 .50812 L F
.43656 .51001 m .43446 .51084 L .43406 .50685 L F
.292 .346 .746 r
.3347 .70365 m .33564 .70765 L .3373 .70566 L F
.454 .585 .895 r
.3373 .70566 m .33564 .70765 L .33776 .70755 L F
.439 .612 .922 r
.33564 .70765 m .33773 .70811 L .33776 .70755 L F
.988 .751 .485 r
.42457 .56261 m .42607 .56372 L .42622 .56096 L F
.42622 .56096 m .42607 .56372 L .42457 .56261 L F
.257 .206 .607 r
.20274 .5832 m .20463 .58528 L .20413 .58259 L F
.312 .216 .582 r
.20298 .58573 m .20463 .58528 L .20274 .5832 L F
.657 .736 .908 r
.36894 .66561 m .37339 .66641 L .37149 .66326 L F
.64 .15 .071 r
.37064 .66752 m .37339 .66641 L .36894 .66561 L F
.61 .714 .919 r
.37149 .66326 m .37339 .66641 L .37552 .66536 L F
.368 .821 .709 r
.37552 .66536 m .37339 .66641 L .37064 .66752 L F
.564 .403 .621 r
.42275 .53459 m .41981 .53938 L .42087 .53555 L F
.883 .632 .554 r
.56467 .45723 m .56025 .45911 L .56036 .4575 L F
.717 .196 0 r
.55989 .45458 m .56234 .45709 L .56042 .45666 L F
.883 .632 .554 r
.56249 .45712 m .56036 .4575 L .56042 .45666 L F
.717 .196 0 r
.56234 .45709 m .56246 .45721 L .56042 .45666 L F
.628 .088 0 r
.56165 .45607 m .56241 .45713 L .55989 .45458 L F
.883 .632 .554 r
.56467 .45723 m .56036 .4575 L .56307 .45702 L F
.628 .088 0 r
.56241 .45713 m .56246 .45721 L .56234 .45709 L F
.56241 .45713 m .56234 .45709 L .55989 .45458 L F
.716 .3 .256 r
.56307 .45702 m .56241 .45713 L .56165 .45607 L F
.883 .632 .554 r
.56307 .45702 m .56249 .45712 L .56234 .45709 L F
.56206 .45688 m .56234 .45709 L .56042 .45666 L F
.56307 .45702 m .56234 .45709 L .56206 .45688 L F
.716 .3 .256 r
.56538 .4563 m .56307 .45702 L .56165 .45607 L F
.56307 .45702 m .56246 .45721 L .56241 .45713 L F
.87 .511 .367 r
.56307 .45702 m .56246 .45721 L .56467 .45723 L F
.56042 .45666 m .56246 .45721 L .56307 .45702 L F
.716 .3 .256 r
.56548 .4563 m .56246 .45721 L .56538 .4563 L F
.56548 .4563 m .56467 .45723 L .56246 .45721 L F
.56548 .4563 m .56595 .45822 L .56467 .45723 L F
.923 .968 .674 r
.61196 .39038 m .61201 .38866 L .61062 .38824 L F
0 0 .482 r
.61196 .39038 m .61062 .38824 L .61177 .38683 L F
.835 .572 .025 r
.61158 .38923 m .61195 .39088 L .61196 .39038 L F
.923 .968 .674 r
.61196 .39038 m .61231 .39245 L .61402 .38926 L F
0 0 .108 r
.61269 .39423 m .61231 .39245 L .61196 .39038 L F
.835 .572 .025 r
.61195 .39088 m .61269 .39423 L .61196 .39038 L F
.923 .968 .674 r
.61196 .39038 m .61402 .38926 L .61201 .38866 L F
0 0 .302 r
.61537 .38522 m .61402 .38926 L .61651 .3884 L F
.48 .553 .853 r
.61402 .38926 m .61714 .39182 L .61651 .3884 L F
.477 .877 .958 r
.26615 .52085 m .26529 .52199 L .26385 .52156 L F
.26615 .52085 m .26787 .52126 L .26529 .52199 L F
.597 .782 .969 r
.26851 .52134 m .26529 .52199 L .26787 .52126 L F
.722 .573 .687 r
.66887 .38002 m .67177 .37985 L .66885 .38276 L F
.472 .213 .439 r
.67177 .37985 m .67161 .38207 L .66885 .38276 L F
.394 .215 .516 r
.67402 .3763 m .67417 .37885 L .67177 .37985 L F
.341 .108 .408 r
.67417 .37885 m .67161 .38207 L .67177 .37985 L F
.864 .686 .658 r
.6847 .34735 m .68787 .34794 L .68633 .34414 L F
.788 .5 .499 r
.6842 .34983 m .68787 .34794 L .6847 .34735 L F
.6842 .34983 m .688 .35034 L .68787 .34794 L F
.502 .909 .842 r
.22609 .5413 m .22731 .54018 L .22962 .53923 L F
.684 .974 .794 r
.22962 .53923 m .23026 .53778 L .23175 .53818 L F
.22962 .53923 m .22731 .54018 L .23026 .53778 L F
0 .162 .683 r
.64517 .37902 m .64402 .37612 L .648 .37662 L F
.804 .921 .916 r
.648 .37662 m .65005 .37556 L .64517 .37902 L F
.558 .704 .938 r
.37194 .64154 m .36902 .64081 L .37002 .64021 L F
0 0 0 r
.37022 .64159 m .37121 .63951 L .37002 .64021 L F
.37121 .63951 m .37133 .63924 L .37002 .64021 L F
.558 .704 .938 r
.36902 .64081 m .36753 .64043 L .37002 .64021 L F
.442 .435 .756 r
.44077 .52448 m .43935 .52857 L .43833 .52645 L F
.44077 .52448 m .44147 .5282 L .43935 .52857 L F
.398 .372 .713 r
.44224 .53076 m .43935 .52857 L .44147 .5282 L F
.38 .781 .985 r
.24296 .57022 m .24288 .56909 L .24105 .56889 L F
.24296 .57022 m .24511 .56986 L .24288 .56909 L F
0 .223 .734 r
.59912 .43263 m .59729 .42943 L .59836 .4314 L F
.751 .808 .898 r
.59959 .42997 m .59912 .43263 L .59836 .4314 L F
.59959 .42997 m .60315 .43056 L .59912 .43263 L F
.919 .821 .734 r
.61408 .37845 m .6158 .38033 L .61349 .38286 L F
.666 .793 .942 r
.61408 .37845 m .6158 .38033 L .61798 .37905 L F
.61408 .37845 m .6158 .38033 L .61798 .37905 L F
.245 .292 .714 r
.72144 .35822 m .71963 .35997 L .71932 .35695 L F
0 0 0 r
.71928 .36175 m .71963 .35997 L .72144 .35822 L F
.743 .734 .843 r
.42052 .54007 m .42213 .54192 L .41825 .54138 L F
.423 .051 .225 r
.33453 .58302 m .33105 .58526 L .33197 .58375 L F
.827 .581 .568 r
.41336 .50753 m .40966 .50841 L .41137 .50678 L F
.751 .679 .781 r
.64022 .37564 m .64402 .37612 L .64145 .37879 L F
.452 .555 .869 r
.64687 .39122 m .64928 .39548 L .651 .39448 L F
.811 .54 .528 r
.69161 .3241 m .69502 .32199 L .69395 .32048 L F
.69161 .3241 m .69457 .32515 L .69502 .32199 L F
.925 .926 .791 r
.69395 .32048 m .69502 .32199 L .69698 .31872 L F
.682 .85 .963 r
.35395 .54028 m .35582 .54157 L .35874 .54041 L F
.686 .726 .881 r
.35905 .54117 m .35582 .54157 L .35874 .54041 L F
.46 .159 .367 r
.35582 .54157 m .35874 .54041 L .35905 .54117 L F
.35582 .54157 m .35479 .54391 L .35874 .54041 L F
.301 .65 .969 r
.26144 .63128 m .26399 .63301 L .2657 .63293 L F
.732 .364 .353 r
.26172 .57213 m .25968 .5703 L .26225 .57028 L F
.26172 .57213 m .25812 .57159 L .25968 .5703 L F
.87 .935 .558 r
.34153 .5221 m .34306 .51837 L .34114 .51961 L F
.518 .833 .523 r
.36197 .61499 m .35876 .61817 L .36021 .61668 L F
.934 .617 .415 r
.36021 .61668 m .36247 .61805 L .36197 .61499 L F
.785 .512 .523 r
.36197 .61499 m .36247 .61805 L .36576 .61818 L F
.365 .122 .406 r
.37002 .64021 m .36753 .64043 L .3669 .64247 L F
0 0 0 r
.25602 .52373 m .26182 .52296 L .2593 .52373 L F
.709 .235 .122 r
.39383 .5802 m .39231 .58171 L .39246 .57895 L F
.39383 .5802 m .39521 .58176 L .39231 .58171 L F
.488 .383 .661 r
.44132 .54145 m .4394 .54457 L .43767 .54109 L F
.44132 .54145 m .44176 .54424 L .4394 .54457 L F
0 0 0 r
.36237 .57592 m .35949 .57931 L .36074 .57731 L F
.755 .513 .566 r
.44098 .5388 m .44132 .54145 L .43767 .54109 L F
.396 .307 .636 r
.44355 .53722 m .44098 .5388 L .44126 .5355 L F
.523 .425 .685 r
.44355 .53722 m .44132 .54145 L .44098 .5388 L F
0 0 .016 r
.39748 .67554 m .39666 .67742 L .39519 .67814 L F
0 0 .362 r
.39666 .67742 m .39526 .6813 L .39519 .67814 L F
.087 0 .043 r
.30511 .59861 m .30691 .59784 L .30798 .59557 L F
.222 0 .16 r
.30691 .59784 m .30975 .59456 L .30798 .59557 L F
.818 .827 .856 r
.30305 .51747 m .30723 .51633 L .3057 .51531 L F
.863 .924 .867 r
.3057 .51531 m .30723 .51633 L .3098 .51325 L F
.693 .709 .86 r
.39119 .65928 m .38812 .66131 L .38701 .65895 L F
.976 .778 .572 r
.38701 .65895 m .38812 .66131 L .38639 .66143 L F
0 0 0 r
.26169 .54234 m .25896 .54381 L .26122 .54261 L F
.502 .909 .842 r
.22609 .5413 m .22522 .54131 L .22731 .54018 L F
.993 .747 .399 r
.39973 .55321 m .40087 .55717 L .40031 .5548 L F
.45 0 0 r
.27965 .55292 m .28363 .55225 L .2815 .55194 L F
.287 0 0 r
.2815 .55194 m .28363 .55225 L .2847 .55149 L F
0 0 .317 r
.37435 .52295 m .3754 .52562 L .37405 .5219 L F
.396 .307 .636 r
.44355 .53722 m .44126 .5355 L .44256 .53472 L F
.099 0 0 r
.70385 .33124 m .70311 .33242 L .70307 .3324 L F
0 0 .251 r
.70349 .33258 m .70311 .33242 L .70424 .33047 L F
.70277 .33462 m .70311 .33242 L .70349 .33258 L F
.099 0 0 r
.70307 .3324 m .70311 .33242 L .70306 .33243 L F
.70097 .33271 m .70306 .33243 L .69926 .33358 L F
.70385 .33124 m .70306 .33243 L .70097 .33271 L F
.691 .185 .031 r
.69886 .33299 m .69744 .33252 L .69735 .33297 L F
.70056 .33301 m .69971 .33288 L .69886 .33299 L F
.69971 .33288 m .69744 .33252 L .69886 .33299 L F
.78 .563 .606 r
.29189 .61252 m .28825 .61135 L .289 .61135 L F
0 .183 .7 r
.29204 .61159 m .29189 .61252 L .289 .61135 L F
.41 .144 .396 r
.29189 .61252 m .29376 .61385 L .29416 .61159 L F
0 .183 .7 r
.29204 .61159 m .29376 .61385 L .29189 .61252 L F
.6 .533 .752 r
.25818 .53493 m .25918 .53909 L .26178 .53827 L F
.149 0 .195 r
.34591 .68159 m .34414 .68251 L .34329 .68441 L F
.925 .926 .791 r
.69395 .32048 m .69698 .31872 L .69671 .31757 L F
.2 0 .128 r
.23706 .54735 m .23394 .55012 L .23493 .54888 L F
.799 .359 .201 r
.4211 .59272 m .41998 .59424 L .41964 .59172 L F
.4211 .59272 m .42317 .59552 L .41998 .59424 L F
.863 .865 .84 r
.66635 .33544 m .6621 .33754 L .66498 .33422 L F
.862 .879 .849 r
.66634 .33278 m .66635 .33544 L .66498 .33422 L F
.491 .174 .357 r
.68543 .36654 m .68783 .36875 L .68508 .36919 L F
.68543 .36654 m .68812 .36623 L .68783 .36875 L F
0 0 0 r
.34956 .68726 m .35412 .68523 L .35325 .68723 L F
.898 .851 .789 r
.29701 .65851 m .30097 .65624 L .29764 .65632 L F
.29701 .65851 m .29867 .66006 L .30097 .65624 L F
.79 .73 .797 r
.31473 .5074 m .31786 .50687 L .3177 .50672 L F
0 .074 .624 r
.31782 .50404 m .31786 .50687 L .31701 .5037 L F
.839 .739 .217 r
.31782 .50404 m .3177 .50672 L .31786 .50687 L F
.61 .213 .265 r
.58515 .45249 m .58762 .45451 L .58478 .45506 L F
.58515 .45249 m .58776 .45283 L .58762 .45451 L F
.495 .761 .99 r
.71078 .28363 m .7069 .28267 L .70929 .28293 L F
0 .203 .729 r
.7122 .28399 m .71262 .28505 L .71078 .28363 L F
.642 .272 .328 r
.27534 .62288 m .27981 .62093 L .27735 .62106 L F
.413 .503 .842 r
.33096 .50261 m .33297 .50229 L .3314 .49876 L F
.525 .64 .905 r
.37521 .57093 m .37798 .57065 L .37616 .5669 L F
.129 .298 .767 r
.38991 .58218 m .3914 .58589 L .38988 .58429 L F
.645 .401 .535 r
.38891 .58543 m .3914 .58589 L .38988 .58429 L F
.979 .825 .62 r
.4004 .61408 m .40141 .61191 L .39978 .6107 L F
.849 .791 .794 r
.66268 .34118 m .65959 .34093 L .6621 .33754 L F
.414 .104 .329 r
.42675 .5699 m .42787 .56745 L .43031 .56685 L F
.165 .185 .635 r
.20377 .58947 m .20463 .58528 L .20298 .58573 L F
.20377 .58947 m .20486 .5891 L .20463 .58528 L F
.325 .165 .504 r
.20305 .59233 m .20486 .5891 L .20377 .58947 L F
.788 .648 .707 r
.37238 .60217 m .3758 .60268 L .37451 .59875 L F
.503 .497 .783 r
.3758 .60268 m .37776 .60113 L .37451 .59875 L F
.3758 .60268 m .37824 .60241 L .37776 .60113 L F
.433 .412 .735 r
.3758 .60268 m .37854 .60468 L .37824 .60241 L F
.746 .767 .87 r
.68913 .34026 m .69228 .33954 L .69172 .33759 L F
.592 .511 .731 r
.69228 .33954 m .695 .33729 L .69172 .33759 L F
.69228 .33954 m .69584 .34044 L .695 .33729 L F
.907 .635 .514 r
.55773 .44962 m .55581 .45154 L .55395 .44858 L F
.55773 .44962 m .55774 .45218 L .55581 .45154 L F
.839 .585 .556 r
.54623 .44005 m .54373 .43952 L .54277 .43659 L F
.795 .518 .517 r
.54623 .44005 m .54227 .44209 L .54373 .43952 L F
.54623 .44005 m .54649 .44303 L .54227 .44209 L F
.531 .602 .87 r
.38275 .71093 m .38679 .71356 L .38566 .71047 L F
.942 .797 .673 r
.38566 .71047 m .38679 .71356 L .38681 .7094 L F
.648 .592 .777 r
.67402 .3763 m .67 .37311 L .6741 .37373 L F
.687 .536 .676 r
.67652 .37319 m .67402 .3763 L .6741 .37373 L F
.55 .629 .883 r
.39531 .57039 m .39201 .56861 L .39395 .56678 L F
.738 .548 .636 r
.39531 .57039 m .39643 .57258 L .39157 .57357 L F
.142 .256 .722 r
.39763 .57246 m .39643 .57258 L .39531 .57039 L F
.14 0 .127 r
.38777 .62461 m .38698 .62505 L .38635 .62648 L F
.759 .884 .935 r
.61062 .38824 m .60836 .38986 L .60743 .3883 L F
.562 .609 .857 r
.62201 .39633 m .62252 .39872 L .61944 .39906 L F
.587 .11 0 r
.59473 .3922 m .59765 .39567 L .59673 .39583 L F
.974 .666 .314 r
.59673 .39583 m .59765 .39567 L .59787 .3982 L F
.774 .901 .931 r
.63714 .36507 m .63854 .36652 L .63637 .36746 L F
.766 .899 .935 r
.64283 .36302 m .63854 .36652 L .63714 .36507 L F
.78 .641 .707 r
.39362 .65588 m .39518 .65995 L .39119 .65928 L F
0 0 0 r
.36336 .59031 m .36035 .59269 L .36219 .59182 L F
.074 0 .079 r
.36219 .59182 m .36035 .59269 L .35934 .59511 L F
0 .059 .624 r
.38681 .7094 m .38536 .70716 L .38697 .70603 L F
.082 .046 .514 r
.31407 .57647 m .31371 .58004 L .31548 .57838 L F
.282 .242 .635 r
.31381 .58228 m .31548 .57838 L .31371 .58004 L F
.735 .777 .281 r
.38424 .55128 m .38404 .55133 L .38614 .55052 L F
.38424 .55128 m .38361 .55317 L .38404 .55133 L F
.814 .91 .51 r
.72964 .34882 m .72884 .35147 L .73057 .34795 L F
0 0 0 r
.72899 .34943 m .72964 .34882 L .73079 .34799 L F
.798 .964 .915 r
.72632 .35156 m .72884 .35147 L .72964 .34882 L F
0 0 0 r
.72632 .35156 m .72964 .34882 L .72899 .34943 L F
.814 .91 .51 r
.72964 .34882 m .73057 .34795 L .7307 .34769 L F
.589 .309 .459 r
.60077 .45138 m .59674 .44984 L .6007 .44975 L F
.638 .218 .229 r
.6007 .44975 m .60331 .45164 L .60077 .45138 L F
.599 .263 .372 r
.60352 .44974 m .60331 .45164 L .6007 .44975 L F
.315 0 .202 r
.2936 .55902 m .29513 .55969 L .29645 .5579 L F
.2936 .55902 m .29275 .56048 L .29513 .55969 L F
.824 .769 .801 r
.6328 .38656 m .63413 .38919 L .63117 .39227 L F
0 .116 .668 r
.6357 .39036 m .63413 .38919 L .6328 .38656 L F
.944 .849 .719 r
.39129 .63298 m .3906 .63006 L .38793 .63321 L F
0 0 0 r
.35739 .60117 m .36169 .5989 L .35934 .59852 L F
.537 .879 .988 r
.36265 .5974 m .36169 .5989 L .36437 .59799 L F
.609 .948 .925 r
.35934 .59852 m .36169 .5989 L .3626 .59748 L F
.406 .303 .625 r
.35934 .59852 m .35728 .60402 L .35739 .60117 L F
.476 .46 .761 r
.35946 .60292 m .36082 .60665 L .35948 .60291 L F
.35764 .60428 m .36082 .60665 L .35946 .60292 L F
.289 .344 .746 r
.36056 .60332 m .36082 .60665 L .36071 .60353 L F
.35948 .60291 m .36082 .60665 L .36056 .60332 L F
.371 .276 .616 r
.35992 .60003 m .3598 .60034 L .35934 .59852 L F
.3598 .60034 m .35942 .60135 L .35939 .60028 L F
.3598 .60034 m .35939 .60028 L .35934 .59852 L F
.36124 .60286 m .36014 .60036 L .36241 .59981 L F
.315 0 0 r
.3598 .60034 m .3601 .60037 L .36241 .59981 L F
.3598 .60034 m .36241 .59981 L .35992 .60003 L F
.371 .276 .616 r
.36014 .60036 m .36 .60003 L .36241 .59981 L F
.36085 .60242 m .36006 .60038 L .36124 .60286 L F
.36006 .60038 m .35934 .59852 L .36014 .60036 L F
.36006 .60038 m .36014 .60036 L .36124 .60286 L F
.406 .303 .625 r
.35934 .59852 m .35942 .60135 L .3583 .60129 L F
.35942 .60135 m .35945 .60236 L .35912 .60205 L F
.35942 .60135 m .35912 .60205 L .3583 .60129 L F
.315 0 0 r
.3585 .60016 m .35998 .60003 L .35834 .59967 L F
.371 .276 .616 r
.36 .60003 m .35934 .59852 L .36241 .59981 L F
.315 0 0 r
.35998 .60003 m .36241 .59981 L .36011 .59973 L F
.35998 .60003 m .36011 .59973 L .35834 .59967 L F
.35864 .60058 m .35923 .60058 L .3598 .60034 L F
.371 .276 .616 r
.36069 .60201 m .35942 .60135 L .35992 .60003 L F
.315 0 0 r
.35923 .60058 m .36142 .60058 L .36006 .60038 L F
.35923 .60058 m .36006 .60038 L .3598 .60034 L F
.808 .561 .565 r
.36518 .60312 m .36137 .60315 L .36241 .59981 L F
.59 .683 .906 r
.36573 .60536 m .36381 .60651 L .3613 .60336 L F
.289 .344 .746 r
.36113 .60342 m .36144 .60331 L .36116 .60269 L F
.59 .683 .906 r
.36145 .6033 m .3613 .60336 L .36113 .60315 L F
.36573 .60536 m .3613 .60336 L .36145 .6033 L F
.289 .344 .746 r
.36087 .60323 m .36113 .60342 L .36116 .60269 L F
.36113 .60342 m .36138 .6036 L .3613 .60336 L F
.957 .62 .321 r
.3613 .60336 m .36381 .60651 L .36204 .60543 L F
.36109 .60363 m .36204 .60543 L .36082 .60665 L F
.289 .344 .746 r
.36071 .60353 m .36109 .60363 L .36087 .60323 L F
.957 .62 .321 r
.36113 .60315 m .36082 .60665 L .3607 .60337 L F
.289 .344 .746 r
.36071 .60353 m .36204 .60543 L .36212 .60393 L F
.957 .62 .321 r
.36113 .60315 m .3613 .60336 L .36204 .60543 L F
.289 .344 .746 r
.3613 .60336 m .36166 .6038 L .36144 .60331 L F
.36138 .6036 m .36166 .6038 L .3613 .60336 L F
.36109 .60363 m .36166 .6038 L .36087 .60323 L F
.957 .62 .321 r
.36113 .60315 m .36204 .60543 L .36109 .60363 L F
.808 .561 .565 r
.36137 .60315 m .36113 .60315 L .36124 .60286 L F
.36137 .60315 m .36124 .60286 L .36241 .59981 L F
.59 .683 .906 r
.36573 .60536 m .36145 .6033 L .36518 .60312 L F
.36145 .6033 m .36113 .60315 L .36137 .60315 L F
.36145 .6033 m .36137 .60315 L .36518 .60312 L F
.289 .344 .746 r
.36137 .60315 m .36212 .60393 L .36116 .60269 L F
.36166 .6038 m .36173 .60382 L .36137 .60315 L F
.36173 .60382 m .36212 .60393 L .36137 .60315 L F
.36116 .60269 m .36212 .60393 L .3623 .60058 L F
.315 0 0 r
.3601 .60037 m .3623 .60058 L .36241 .59981 L F
.36142 .60058 m .3623 .60058 L .3598 .60034 L F
.35864 .60058 m .3598 .60034 L .3585 .60016 L F
.3598 .60034 m .35992 .60003 L .3585 .60016 L F
.371 .276 .616 r
.36069 .60201 m .35946 .60292 L .35942 .60135 L F
.289 .344 .746 r
.36142 .60058 m .36095 .60253 L .3623 .60058 L F
.36095 .60253 m .36071 .60353 L .36113 .60274 L F
.36095 .60253 m .36113 .60274 L .3623 .60058 L F
.36056 .60332 m .36071 .60353 L .36142 .60058 L F
.371 .276 .616 r
.36113 .60315 m .36085 .60242 L .36124 .60286 L F
.36113 .60315 m .3607 .60337 L .36056 .60332 L F
.36064 .60308 m .36056 .60332 L .35953 .60293 L F
.36113 .60315 m .36056 .60332 L .36064 .60308 L F
.36113 .60315 m .35946 .60292 L .36069 .60201 L F
.289 .344 .746 r
.35864 .60058 m .36056 .60332 L .36142 .60058 L F
.957 .62 .321 r
.36052 .60347 m .36082 .60665 L .35949 .60402 L F
.3607 .60337 m .36071 .60353 L .36052 .60347 L F
.36071 .60353 m .36082 .60665 L .36052 .60347 L F
.289 .344 .746 r
.36071 .60353 m .36082 .60665 L .36204 .60543 L F
.35864 .60058 m .35948 .60291 L .36056 .60332 L F
.371 .276 .616 r
.35953 .60293 m .35949 .60402 L .35946 .60292 L F
.3607 .60337 m .35949 .60402 L .35953 .60293 L F
.476 .46 .761 r
.35728 .60402 m .35764 .60428 L .35946 .60292 L F
.406 .303 .625 r
.3583 .60129 m .35909 .60311 L .35728 .60402 L F
.35945 .60236 m .35949 .60402 L .3583 .60129 L F
.476 .46 .761 r
.35728 .60402 m .35948 .60291 L .35864 .60058 L F
.406 .303 .625 r
.35909 .60311 m .35949 .60402 L .35728 .60402 L F
0 0 .363 r
.35768 .6007 m .35864 .60058 L .35834 .59967 L F
.35739 .60117 m .35791 .60092 L .35768 .6007 L F
.35791 .60092 m .35864 .60058 L .35768 .6007 L F
.609 .948 .925 r
.36049 .59813 m .3626 .59748 L .36265 .5974 L F
.35934 .59852 m .3626 .59748 L .36049 .59813 L F
.35934 .59852 m .36265 .5974 L .36241 .59981 L F
.733 .434 .474 r
.36014 .59824 m .35834 .59967 L .36241 .59981 L F
.35888 .59737 m .35856 .59873 L .36014 .59824 L F
.35856 .59873 m .35834 .59967 L .36014 .59824 L F
.644 .858 .981 r
.37866 .71077 m .38275 .71093 L .38145 .70918 L F
.533 .658 .916 r
.38145 .70918 m .38275 .71093 L .38566 .71047 L F
.792 .669 .728 r
.37093 .67822 m .36883 .68043 L .3677 .67721 L F
.243 .724 .932 r
.32453 .51886 m .32241 .51815 L .32664 .51867 L F
.523 .286 .497 r
.32664 .51867 m .32384 .52136 L .32453 .51886 L F
0 .112 .651 r
.39188 .59869 m .3921 .59791 L .39038 .59754 L F
.114 .161 .633 r
.39157 .59361 m .3921 .59791 L .39345 .59599 L F
.674 .938 .656 r
.3921 .59791 m .39059 .59883 L .39233 .5971 L F
.3921 .59791 m .39233 .5971 L .39345 .59599 L F
0 .112 .651 r
.39242 .59911 m .3921 .59791 L .39188 .59869 L F
.39242 .59911 m .39448 .60108 L .3921 .59791 L F
0 0 0 r
.61714 .39182 m .61438 .39475 L .61703 .39397 L F
.392 .467 .818 r
.61651 .3884 m .61714 .39182 L .61999 .39136 L F
.244 0 .164 r
.61999 .39136 m .61714 .39182 L .61703 .39397 L F
.156 0 .28 r
.349 .55733 m .34662 .56079 L .3482 .55984 L F
0 0 .217 r
.34662 .56079 m .34755 .56197 L .3482 .55984 L F
.34662 .56079 m .34628 .56381 L .34755 .56197 L F
0 .206 .653 r
.35147 .52568 m .35542 .52838 L .35305 .52907 L F
.107 0 .263 r
.35542 .52838 m .35314 .53169 L .35305 .52907 L F
.768 .744 .831 r
.35314 .53169 m .35542 .52838 L .35305 .52907 L F
.35314 .53169 m .35692 .53021 L .35542 .52838 L F
.107 0 .263 r
.35542 .52838 m .35481 .53119 L .35314 .53169 L F
.45 .168 .393 r
.35542 .52838 m .35481 .53119 L .35305 .52907 L F
0 .15 .66 r
.26088 .61974 m .26139 .6208 L .25934 .61911 L F
.26088 .61974 m .26204 .62119 L .26139 .6208 L F
.642 .667 .859 r
.23804 .56731 m .23578 .56871 L .2349 .56654 L F
.555 .167 .26 r
.23909 .56892 m .2351 .57017 L .23578 .56871 L F
.599 .566 .788 r
.23578 .56871 m .23909 .56892 L .23804 .56731 L F
.47 .297 .564 r
.59006 .43573 m .5877 .43443 L .58938 .43351 L F
.425 .115 .334 r
.37349 .5724 m .37017 .57459 L .37209 .57186 L F
.073 0 .438 r
.20378 .57626 m .20487 .57276 L .20379 .5736 L F
.503 .827 1 r
.24831 .61455 m .25074 .61391 L .25261 .61485 L F
.36 .171 .484 r
.25074 .61391 m .25544 .61657 L .25261 .61485 L F
.283 0 0 r
.24491 .55942 m .24352 .56199 L .24151 .56218 L F
0 0 0 r
.24725 .55913 m .24352 .56199 L .24491 .55942 L F
.98 .916 .631 r
.40463 .59724 m .40656 .59559 L .40584 .59484 L F
.40463 .59724 m .40538 .59919 L .40656 .59559 L F
.784 .284 0 r
.59452 .42675 m .59729 .42943 L .59265 .42993 L F
.441 .321 .62 r
.59959 .42997 m .59836 .4314 L .59729 .42943 L F
.335 0 0 r
.25664 .61783 m .25675 .6178 L .25544 .61657 L F
.25664 .61783 m .25934 .61911 L .25675 .6178 L F
0 0 .076 r
.22853 .55174 m .22796 .55366 L .22679 .55448 L F
.881 .776 .742 r
.24955 .53419 m .25339 .5318 L .25268 .53155 L F
.24955 .53419 m .25143 .53526 L .25339 .5318 L F
.625 .961 .851 r
.25442 .53019 m .25339 .5318 L .25674 .52959 L F
.25442 .53019 m .25268 .53155 L .25339 .5318 L F
.178 .024 .421 r
.33051 .57207 m .3291 .5704 L .33093 .56945 L F
.33051 .57207 m .32891 .57301 L .3291 .5704 L F
.822 .988 .721 r
.31814 .64911 m .32003 .64737 L .32069 .64605 L F
0 0 .202 r
.70214 .28769 m .70147 .29021 L .70327 .28823 L F
.24 0 .301 r
.38292 .57352 m .38481 .57282 L .38416 .57214 L F
.038 0 0 r
.38292 .57352 m .38225 .57448 L .38481 .57282 L F
.353 0 0 r
.38094 .57394 m .38481 .57282 L .38225 .57448 L F
.38094 .57394 m .38289 .57432 L .38481 .57282 L F
.664 .699 .872 r
.38278 .57194 m .38289 .57432 L .38236 .57175 L F
.565 .013 0 r
.38262 .5718 m .38278 .57188 L .38289 .57432 L F
.38278 .57194 m .38481 .57282 L .38289 .57432 L F
.664 .699 .872 r
.38304 .57206 m .38289 .57432 L .38278 .57194 L F
.565 .013 0 r
.38291 .57194 m .38481 .57282 L .38278 .57194 L F
.38469 .57277 m .38615 .57422 L .38481 .57282 L F
.664 .699 .872 r
.38414 .57286 m .38289 .57432 L .38304 .57206 L F
.597 .024 0 r
.38278 .57194 m .38291 .57207 L .38292 .57207 L F
.565 .013 0 r
.38291 .57194 m .38429 .57293 L .38469 .57277 L F
.38301 .57204 m .38429 .57293 L .38291 .57194 L F
.38429 .57293 m .38615 .57422 L .38469 .57277 L F
.3837 .57254 m .38615 .57422 L .38278 .57188 L F
.817 .771 .809 r
.38402 .57249 m .38692 .57475 L .3837 .57254 L F
.664 .699 .872 r
.38431 .57266 m .38414 .57286 L .3837 .57254 L F
.24 0 .301 r
.38416 .57214 m .38481 .57282 L .38573 .57041 L F
.457 .309 .591 r
.38481 .57282 m .38711 .56935 L .38573 .57041 L F
.38481 .57282 m .38707 .57212 L .38711 .56935 L F
.404 .1 .332 r
.38707 .57212 m .39044 .56937 L .38711 .56935 L F
.38707 .57212 m .38963 .57154 L .39044 .56937 L F
.817 .771 .809 r
.38963 .57154 m .3837 .57254 L .38337 .57178 L F
.664 .699 .872 r
.38431 .57266 m .3837 .57254 L .38361 .57233 L F
.38361 .57233 m .3837 .57254 L .38304 .57206 L F
.699 .757 .897 r
.38264 .57195 m .38289 .57432 L .38431 .57266 L F
.597 .024 0 r
.38361 .57233 m .38363 .57237 L .38431 .57266 L F
.38363 .57237 m .38401 .57304 L .38431 .57266 L F
.38304 .57206 m .38311 .57214 L .38361 .57233 L F
.38311 .57214 m .38401 .57304 L .38361 .57233 L F
.423 .225 .504 r
.38481 .57282 m .38692 .57475 L .38707 .57212 L F
.474 .265 .516 r
.38707 .57212 m .38692 .57475 L .38963 .57154 L F
.817 .771 .809 r
.38963 .57154 m .38764 .57389 L .38402 .57249 L F
.565 .013 0 r
.38615 .57422 m .38692 .57475 L .38481 .57282 L F
.817 .771 .809 r
.38764 .57389 m .38692 .57475 L .38402 .57249 L F
.565 .013 0 r
.38278 .57188 m .38301 .57204 L .38291 .57194 L F
.597 .024 0 r
.38278 .57194 m .38401 .57304 L .38304 .57206 L F
.565 .013 0 r
.38278 .57188 m .38291 .57194 L .38278 .57194 L F
.38268 .57183 m .3837 .57254 L .38278 .57188 L F
.597 .024 0 r
.38291 .57207 m .38399 .57306 L .38292 .57207 L F
.38236 .57175 m .38261 .57195 L .38278 .57194 L F
.38261 .57195 m .38399 .57306 L .38278 .57194 L F
.518 .199 .366 r
.38252 .57168 m .38399 .57306 L .38236 .57175 L F
.565 .013 0 r
.38262 .5718 m .38273 .57188 L .38268 .57183 L F
.38273 .57188 m .3837 .57254 L .38268 .57183 L F
.817 .771 .809 r
.38337 .57178 m .3837 .57254 L .38273 .57188 L F
.518 .199 .366 r
.38398 .57108 m .38273 .57188 L .38252 .57168 L F
.817 .771 .809 r
.38285 .5718 m .38273 .57188 L .38262 .5718 L F
.38337 .57178 m .38273 .57188 L .38285 .5718 L F
.699 .757 .897 r
.38276 .57187 m .38264 .57195 L .38431 .57266 L F
.38262 .5718 m .38263 .57191 L .38276 .57187 L F
.38263 .57191 m .38264 .57195 L .38276 .57187 L F
.817 .771 .809 r
.38963 .57154 m .38457 .57173 L .38842 .57022 L F
.38457 .57173 m .38262 .5718 L .38462 .57126 L F
.38457 .57173 m .38462 .57126 L .38842 .57022 L F
.803 .805 .316 r
.38431 .57266 m .38406 .57298 L .38462 .57126 L F
.38459 .57155 m .38462 .57126 L .38479 .57075 L F
.38431 .57266 m .38462 .57126 L .38459 .57155 L F
.38406 .57298 m .38401 .57304 L .38479 .57075 L F
.614 .335 .471 r
.38842 .57022 m .38462 .57126 L .38479 .57075 L F
.38462 .57126 m .3839 .57146 L .38479 .57075 L F
.518 .199 .366 r
.38479 .57075 m .38377 .57156 L .38273 .57188 L F
.38479 .57075 m .38273 .57188 L .38398 .57108 L F
.614 .335 .471 r
.3839 .57146 m .38262 .5718 L .38479 .57075 L F
.518 .199 .366 r
.38479 .57075 m .38459 .57131 L .38377 .57156 L F
.38459 .57131 m .38399 .57304 L .38273 .57188 L F
.38459 .57131 m .38273 .57188 L .38273 .57188 L F
.597 .024 0 r
.38292 .57207 m .38399 .57306 L .38401 .57304 L F
.518 .199 .366 r
.38399 .57304 m .38399 .57306 L .38252 .57168 L F
.803 .805 .316 r
.38401 .57304 m .38399 .57306 L .38399 .57304 L F
.38401 .57304 m .38399 .57304 L .38479 .57075 L F
.27 0 0 r
.34127 .67453 m .3385 .67555 L .34078 .67482 L F
0 0 0 r
.34268 .67391 m .34127 .67453 L .34078 .67482 L F
.34268 .67391 m .3446 .67226 L .34185 .67414 L F
.34268 .67391 m .34185 .67414 L .34127 .67453 L F
.34268 .67391 m .34078 .67482 L .33833 .67604 L F
.137 .683 .76 r
.34087 .67396 m .34268 .67391 L .3419 .67383 L F
0 0 0 r
.34268 .67391 m .33833 .67604 L .34179 .6739 L F
.34268 .67391 m .34179 .6739 L .3419 .67383 L F
.923 .718 .608 r
.34087 .67396 m .3419 .67383 L .34183 .67389 L F
.137 .683 .76 r
.34087 .67396 m .34173 .6739 L .34179 .6739 L F
.34158 .67394 m .34179 .6739 L .34268 .67391 L F
.34087 .67396 m .34179 .6739 L .34158 .67394 L F
0 0 0 r
.34078 .67482 m .3385 .67555 L .33623 .6771 L F
.34078 .67482 m .33653 .67695 L .33833 .67604 L F
.33653 .67695 m .33623 .6771 L .33833 .67604 L F
.33981 .67559 m .3407 .67484 L .33833 .67604 L F
.3407 .67484 m .34183 .67389 L .33833 .67604 L F
.34183 .67389 m .3419 .67383 L .34179 .6739 L F
.34183 .67389 m .34179 .6739 L .33833 .67604 L F
.923 .718 .608 r
.34087 .67396 m .34183 .67389 L .33981 .67559 L F
.137 .683 .76 r
.34087 .67396 m .34162 .6739 L .34173 .6739 L F
.34162 .6739 m .34326 .67376 L .34268 .67391 L F
0 0 0 r
.34658 .6712 m .34268 .67391 L .34538 .67358 L F
.137 .683 .76 r
.34326 .67376 m .34538 .67358 L .34268 .67391 L F
.958 .837 .681 r
.59513 .42414 m .59452 .42675 L .59371 .4277 L F
.764 .642 .726 r
.65183 .37272 m .65005 .37556 L .65059 .37338 L F
.761 .605 .685 r
.39037 .5641 m .39201 .56861 L .38727 .56688 L F
.55 .491 .743 r
.39395 .56678 m .39201 .56861 L .39037 .5641 L F
.744 .316 .235 r
.61438 .39475 m .61231 .39245 L .61168 .39513 L F
0 0 .108 r
.61269 .39423 m .61168 .39513 L .61231 .39245 L F
.73 .227 0 r
.38939 .52907 m .39117 .53151 L .39265 .53256 L F
.752 .408 0 r
.39256 .53295 m .39265 .53256 L .39117 .53151 L F
.39256 .53295 m .39341 .53474 L .39265 .53256 L F
.524 .63 .898 r
.64037 .38783 m .64154 .38466 L .63869 .38663 L F
.64037 .38783 m .64317 .38774 L .64154 .38466 L F
.258 .252 .662 r
.64037 .38783 m .64296 .39073 L .64317 .38774 L F
.64037 .38783 m .64138 .39303 L .64296 .39073 L F
.612 .956 .852 r
.24036 .53068 m .24115 .52954 L .24385 .52963 L F
.374 .838 .788 r
.24115 .52954 m .24567 .52806 L .24385 .52963 L F
.982 .796 .579 r
.74548 .30331 m .74507 .30633 L .74358 .30466 L F
.095 .391 .848 r
.58529 .40116 m .58348 .40069 L .58157 .39768 L F
.541 .438 .686 r
.24917 .58393 m .25086 .57934 L .2481 .57989 L F
.24917 .58393 m .25177 .58315 L .25086 .57934 L F
.381 .579 .918 r
.24917 .58393 m .25154 .58479 L .25177 .58315 L F
.701 .568 .702 r
.65845 .38244 m .66235 .38287 L .65983 .38613 L F
.557 .505 .753 r
.43185 .49966 m .43031 .50437 L .42924 .5004 L F
.43185 .49966 m .43311 .50382 L .43031 .50437 L F
.779 .284 .028 r
.34625 .65933 m .34439 .65672 L .34228 .65713 L F
.437 .215 .477 r
.22096 .60868 m .22141 .60806 L .22036 .60729 L F
.22096 .60868 m .22326 .61045 L .22141 .60806 L F
.22096 .60868 m .2209 .61111 L .22326 .61045 L F
.22326 .61045 m .2209 .61111 L .22096 .60868 L F
.872 .751 .726 r
.59256 .41159 m .58854 .41328 L .58841 .41089 L F
.59256 .41159 m .59159 .41385 L .58854 .41328 L F
.74 .656 .767 r
.22855 .56456 m .22433 .56373 L .22671 .56357 L F
.399 .394 .738 r
.43895 .51795 m .43983 .52194 L .43786 .52239 L F
.429 .37 .69 r
.44077 .52448 m .43786 .52239 L .43983 .52194 L F
.44077 .52448 m .43833 .52645 L .43786 .52239 L F
.749 .634 .732 r
.28177 .53823 m .27843 .53846 L .28112 .53505 L F
0 0 0 r
.28177 .53823 m .27864 .54116 L .27843 .53846 L F
.28177 .53823 m .28016 .54059 L .27864 .54116 L F
.55 .491 .743 r
.39395 .56678 m .39037 .5641 L .39267 .56552 L F
.648 .522 .697 r
.41006 .51915 m .40713 .52156 L .40608 .51831 L F
0 0 0 r
.33803 .68091 m .33745 .68179 L .33923 .67875 L F
.499 .234 .443 r
.34069 .68539 m .33745 .68179 L .33658 .68389 L F
0 0 0 r
.33658 .68389 m .33745 .68179 L .33803 .68091 L F
.667 .615 .787 r
.38143 .5454 m .38076 .54852 L .38391 .5477 L F
.791 .685 .747 r
.38391 .5477 m .38002 .54999 L .38076 .54852 L F
.667 .615 .787 r
.38143 .5454 m .38076 .54852 L .38391 .5477 L F
.357 .523 .884 r
.35905 .54117 m .36097 .54037 L .35874 .54041 L F
.35874 .54041 m .36097 .54037 L .35905 .54117 L F
.344 .104 .4 r
.2829 .55743 m .28021 .56057 L .27897 .5567 L F
.436 .312 .612 r
.22607 .57902 m .22365 .57511 L .22629 .57574 L F
.22607 .57902 m .22401 .57991 L .22365 .57511 L F
.472 .758 .993 r
.36021 .61668 m .36247 .61805 L .35876 .61817 L F
.588 .417 .618 r
.35876 .61817 m .36247 .61805 L .3593 .6209 L F
0 0 .137 r
.35876 .61817 m .35937 .61895 L .36021 .61668 L F
.559 .14 .203 r
.31672 .54505 m .3124 .54703 L .31498 .54374 L F
.31672 .54505 m .31501 .54717 L .3124 .54703 L F
.722 .336 .318 r
.31864 .54741 m .31501 .54717 L .31672 .54505 L F
.652 .548 .724 r
.31907 .54197 m .31947 .54494 L .31672 .54505 L F
.745 .331 .263 r
.31976 .54733 m .31672 .54505 L .31947 .54494 L F
.31976 .54733 m .31864 .54741 L .31672 .54505 L F
.531 .326 .546 r
.67652 .37319 m .67679 .37588 L .67402 .3763 L F
.438 .149 .375 r
.6796 .37313 m .67679 .37588 L .67652 .37319 L F
.302 0 .17 r
.33793 .5734 m .34045 .57243 L .34173 .5695 L F
0 .066 .565 r
.59359 .40903 m .59019 .40583 L .59208 .40732 L F
.599 .316 .459 r
.59674 .44984 m .59695 .45231 L .59419 .45216 L F
.589 .309 .459 r
.60077 .45138 m .59695 .45231 L .59674 .44984 L F
.525 .821 .999 r
.34551 .50672 m .34318 .50564 L .34077 .50627 L F
.669 .62 .791 r
.34742 .50964 m .34318 .50564 L .34551 .50672 L F
.975 .687 .414 r
.43939 .56099 m .43775 .56233 L .43727 .55989 L F
.999 .828 .528 r
.44283 .56139 m .44143 .56317 L .43939 .56099 L F
.44179 .5627 m .44262 .56355 L .44143 .56317 L F
.44283 .56139 m .44278 .56195 L .44179 .5627 L F
.44278 .56195 m .44262 .56355 L .44179 .5627 L F
.532 .128 .222 r
.43939 .56099 m .44143 .56317 L .44172 .56288 L F
.44165 .56282 m .44172 .56288 L .44147 .56301 L F
.44143 .56299 m .44147 .56301 L .44126 .56312 L F
.44165 .56282 m .44147 .56301 L .44143 .56299 L F
.89 .542 .382 r
.44202 .56273 m .44143 .56317 L .44262 .56355 L F
.44172 .56288 m .44143 .56317 L .44202 .56273 L F
.554 .353 .562 r
.44008 .56568 m .44323 .56694 L .44262 .56355 L F
.89 .542 .382 r
.44242 .56319 m .4432 .56416 L .44143 .56317 L F
.532 .128 .222 r
.44209 .56318 m .44143 .56317 L .44253 .56353 L F
.44172 .56288 m .44143 .56317 L .44209 .56318 L F
.89 .542 .382 r
.44147 .56301 m .44209 .56318 L .44143 .56317 L F
.451 .39 .698 r
.44253 .56353 m .44143 .56317 L .44147 .56301 L F
0 .233 .633 r
.44143 .56317 m .44167 .5633 L .44147 .56301 L F
.532 .128 .222 r
.44147 .56301 m .44253 .56353 L .44126 .56312 L F
.44172 .56288 m .44209 .56318 L .44147 .56301 L F
.44209 .56318 m .44253 .56353 L .44147 .56301 L F
.89 .542 .382 r
.44196 .56264 m .44172 .56288 L .44202 .56273 L F
.44167 .56223 m .44242 .56319 L .44209 .56318 L F
.44167 .56223 m .44143 .56317 L .44196 .56264 L F
.44167 .56223 m .44209 .56318 L .44147 .56301 L F
.451 .39 .698 r
.44253 .56353 m .44147 .56301 L .44167 .56223 L F
.532 .128 .222 r
.44126 .56312 m .44163 .56324 L .44116 .56319 L F
.44163 .56324 m .44168 .56332 L .44116 .56319 L F
.43939 .56099 m .44165 .56282 L .43775 .56233 L F
.44165 .56282 m .44116 .56319 L .43775 .56233 L F
.598 .894 .604 r
.43727 .55989 m .44057 .55659 L .43984 .55962 L F
.481 .588 .884 r
.43984 .55962 m .43727 .55989 L .43935 .55791 L F
.999 .83 .534 r
.43935 .55791 m .44057 .55659 L .43984 .55962 L F
.609 .606 .824 r
.43775 .56233 m .44168 .56332 L .43935 .55791 L F
.532 .128 .222 r
.44163 .56324 m .44253 .56353 L .44168 .56332 L F
.609 .606 .824 r
.44168 .56332 m .44253 .56353 L .44197 .56254 L F
0 .233 .633 r
.44147 .56301 m .44173 .56318 L .44167 .56223 L F
.44173 .56318 m .44194 .56262 L .44167 .56223 L F
.994 .832 .469 r
.44167 .56223 m .44262 .56355 L .44283 .56139 L F
.44167 .56223 m .44283 .56139 L .4456 .56027 L F
.749 .516 .579 r
.44819 .55999 m .44167 .56223 L .4456 .56027 L F
.44819 .55999 m .44822 .56266 L .44167 .56223 L F
.89 .542 .382 r
.44167 .56223 m .44599 .56599 L .4432 .56416 L F
.239 .032 .384 r
.44822 .56266 m .44599 .56599 L .44167 .56223 L F
.451 .39 .698 r
.44253 .56353 m .44167 .56223 L .44312 .56115 L F
.527 .326 .551 r
.44543 .55772 m .4456 .56027 L .44283 .56139 L F
.056 0 .393 r
.44312 .56115 m .44251 .56161 L .44255 .56185 L F
.44251 .56161 m .44167 .56223 L .44194 .56262 L F
.49 .548 .843 r
.43935 .55791 m .44198 .56256 L .44312 .56115 L F
.44198 .56256 m .44253 .56353 L .44312 .56115 L F
.056 0 .393 r
.44312 .56115 m .44255 .56185 L .4429 .56395 L F
.44251 .56161 m .44194 .56262 L .4429 .56395 L F
.609 .606 .824 r
.44162 .56318 m .44197 .56254 L .43935 .55791 L F
.44168 .56332 m .44194 .56262 L .44162 .56318 L F
.44194 .56262 m .44197 .56254 L .44162 .56318 L F
0 .233 .633 r
.44173 .56318 m .4429 .56395 L .44194 .56262 L F
.44167 .5633 m .4429 .56395 L .44147 .56301 L F
.666 .222 .187 r
.33212 .52857 m .33597 .52896 L .33383 .52784 L F
.368 .095 .362 r
.29662 .63939 m .29715 .63718 L .29433 .63999 L F
.172 0 .283 r
.29874 .63653 m .29715 .63718 L .29662 .63939 L F
.498 .301 .544 r
.63694 .43366 m .63899 .4314 L .63594 .43288 L F
.63694 .43366 m .63958 .43298 L .63899 .4314 L F
.63694 .43366 m .63964 .43553 L .63958 .43298 L F
.704 .981 .899 r
.63789 .43677 m .63561 .43718 L .63902 .43499 L F
.63765 .43715 m .63735 .43715 L .63789 .43677 L F
.63735 .43715 m .63561 .43718 L .63789 .43677 L F
.498 .301 .544 r
.63964 .43553 m .63964 .43554 L .63964 .43553 L F
.63964 .43553 m .63964 .43553 L .63958 .43298 L F
.614 .803 .972 r
.38503 .70256 m .38791 .70394 L .38427 .70165 L F
.907 .649 .536 r
.38697 .70603 m .38791 .70394 L .38503 .70256 L F
.446 .822 .577 r
.38791 .70394 m .39064 .70184 L .38874 .70326 L F
.2 .618 .948 r
.38427 .70165 m .38791 .70394 L .38874 .70326 L F
.659 .718 .893 r
.27225 .52708 m .27353 .52906 L .27569 .52713 L F
.379 .395 .751 r
.35524 .63866 m .35316 .64018 L .35148 .63543 L F
0 .057 .585 r
.23112 .60092 m .23182 .60492 L .23091 .60481 L F
.379 0 0 r
.33805 .50737 m .33674 .51008 L .33414 .50897 L F
.669 .62 .791 r
.34655 .50988 m .34409 .50806 L .34318 .50564 L F
.475 .506 .811 r
.34318 .50564 m .34409 .50806 L .3448 .50832 L F
.669 .62 .791 r
.34655 .50988 m .34493 .51031 L .34409 .50806 L F
.475 .506 .811 r
.34409 .50806 m .34493 .51031 L .3448 .50832 L F
.34318 .50564 m .3448 .50832 L .34263 .50578 L F
.34145 .50609 m .3448 .50832 L .34077 .50627 L F
.669 .62 .791 r
.34742 .50964 m .34655 .50988 L .34318 .50564 L F
.933 .73 .605 r
.34284 .50519 m .34614 .50816 L .343 .50578 L F
.949 .621 .371 r
.34284 .50519 m .34284 .50535 L .34324 .50588 L F
.281 .572 .937 r
.34295 .50555 m .34506 .50391 L .34241 .50264 L F
.343 .50578 m .34305 .50573 L .34295 .50555 L F
.949 .621 .371 r
.34284 .50535 m .34306 .50574 L .34324 .50588 L F
.34284 .50519 m .34324 .50588 L .34432 .50652 L F
.281 .572 .937 r
.34305 .50573 m .34506 .50391 L .34295 .50555 L F
.91 .618 .125 r
.343 .50578 m .34291 .50573 L .34284 .50519 L F
.949 .621 .371 r
.34284 .50535 m .34284 .50557 L .3429 .50561 L F
.34284 .50535 m .3429 .50561 L .34287 .50539 L F
.838 .746 .762 r
.34449 .50812 m .34152 .50448 L .34098 .50577 L F
.34462 .50812 m .34152 .50448 L .34449 .50812 L F
.34363 .50773 m .34098 .50577 L .34077 .50627 L F
.3448 .50832 m .34098 .50577 L .34363 .50773 L F
.3448 .50832 m .34462 .50812 L .34449 .50812 L F
.038 0 0 r
.34158 .5061 m .33805 .50737 L .34077 .50627 L F
.34158 .5061 m .33871 .50846 L .33805 .50737 L F
.33871 .50846 m .33781 .5092 L .33784 .50897 L F
.33871 .50846 m .33784 .50897 L .33805 .50737 L F
0 0 0 r
.34258 .51201 m .33958 .51601 L .33912 .51537 L F
.34011 .51326 m .33912 .51537 L .33828 .51419 L F
.34258 .51201 m .33912 .51537 L .34011 .51326 L F
.73 .73 .85 r
.33903 .50827 m .34059 .51224 L .33905 .51256 L F
0 0 0 r
.34258 .51201 m .33828 .51419 L .33905 .51256 L F
.797 .651 .701 r
.33905 .51256 m .34095 .51315 L .34258 .51201 L F
.73 .73 .85 r
.34059 .51224 m .34095 .51315 L .34026 .51294 L F
.34059 .51224 m .34026 .51294 L .33905 .51256 L F
.33903 .50803 m .3391 .50823 L .33903 .50827 L F
.3391 .50823 m .34095 .51315 L .33903 .50827 L F
0 .133 .66 r
.34152 .50448 m .34158 .5061 L .34077 .50627 L F
.454 .708 .976 r
.33494 .50361 m .34117 .50595 L .33755 .50363 L F
.34117 .50595 m .34158 .5061 L .34116 .50584 L F
.34117 .50595 m .34116 .50584 L .33755 .50363 L F
.038 0 0 r
.33781 .5092 m .33674 .51008 L .3368 .50995 L F
.33781 .5092 m .3368 .50995 L .33805 .50737 L F
.786 .563 .597 r
.33494 .50361 m .33651 .50927 L .34158 .5061 L F
.33651 .50927 m .33674 .51008 L .3383 .5088 L F
.73 .73 .85 r
.33861 .50845 m .33905 .51256 L .3362 .51083 L F
.33903 .50803 m .33903 .50851 L .33861 .50845 L F
.33903 .50851 m .33905 .51256 L .33861 .50845 L F
.786 .563 .597 r
.33651 .50927 m .3383 .5088 L .3387 .50846 L F
.33798 .50835 m .3387 .50846 L .34158 .5061 L F
.33651 .50927 m .3387 .50846 L .33798 .50835 L F
.828 .777 .803 r
.3448 .50832 m .34095 .51315 L .33923 .50855 L F
.34084 .50812 m .33923 .50855 L .33903 .50803 L F
.3448 .50832 m .33923 .50855 L .34084 .50812 L F
.67 .756 .915 r
.33755 .50363 m .34158 .5061 L .34152 .50448 L F
.909 .983 .753 r
.34106 .50458 m .33903 .50803 L .33937 .50493 L F
.34152 .50448 m .3411 .50508 L .34106 .50458 L F
.3411 .50508 m .33903 .50803 L .34106 .50458 L F
.838 .746 .762 r
.34254 .50568 m .33903 .50803 L .34152 .50448 L F
.3448 .50832 m .33935 .50805 L .34254 .50568 L F
.33935 .50805 m .33903 .50803 L .34254 .50568 L F
.921 .669 .179 r
.34216 .50525 m .34288 .50749 L .34284 .50519 L F
.91 .618 .125 r
.34291 .50573 m .34216 .50525 L .34284 .50519 L F
.949 .621 .371 r
.34287 .50539 m .3429 .50561 L .34306 .50574 L F
.34432 .50652 m .34324 .50588 L .34614 .50816 L F
.34284 .50557 m .34288 .50749 L .3453 .50798 L F
0 .499 .857 r
.34324 .50588 m .343 .50578 L .34614 .50816 L F
.949 .621 .371 r
.34309 .50576 m .3453 .50798 L .34614 .50816 L F
.281 .572 .937 r
.343 .50578 m .34316 .50583 L .34305 .50573 L F
0 .499 .857 r
.34324 .50588 m .34316 .50583 L .343 .50578 L F
.949 .621 .371 r
.34284 .50557 m .3453 .50798 L .34309 .50576 L F
.281 .572 .937 r
.34316 .50583 m .34703 .50708 L .34305 .50573 L F
.34703 .50708 m .34691 .50603 L .34506 .50391 L F
0 0 0 r
.34676 .50672 m .34681 .5062 L .34699 .50702 L F
.965 .734 .537 r
.34688 .50487 m .34691 .50603 L .34747 .50518 L F
.34506 .50391 m .34682 .50593 L .34688 .50487 L F
.34682 .50593 m .34691 .50603 L .34688 .50487 L F
.34506 .50391 m .34747 .50518 L .34699 .50404 L F
0 0 0 r
.34681 .5062 m .34699 .50404 L .34699 .50592 L F
.34679 .50653 m .34685 .50666 L .34696 .50465 L F
.281 .572 .937 r
.34671 .50697 m .34703 .50708 L .34674 .50662 L F
0 .499 .857 r
.3474 .5076 m .34735 .5075 L .34316 .50583 L F
.34735 .5075 m .34703 .50708 L .34671 .50698 L F
.34665 .50723 m .34671 .50698 L .34316 .50583 L F
.34735 .5075 m .34671 .50698 L .34665 .50723 L F
.34875 .50816 m .34316 .50583 L .34324 .50588 L F
.34875 .50816 m .34324 .50588 L .34614 .50816 L F
.614 .089 0 r
.34588 .5081 m .34875 .50816 L .34614 .50816 L F
0 0 0 r
.34667 .50775 m .34676 .50672 L .34678 .5078 L F
.34668 .50772 m .34673 .50758 L .34678 .50674 L F
.614 .089 0 r
.34662 .50791 m .34717 .50798 L .34658 .50803 L F
.34288 .50749 m .34662 .50791 L .34588 .5081 L F
.34662 .50791 m .34658 .50803 L .34588 .5081 L F
.34717 .50798 m .34802 .50807 L .3474 .50808 L F
.34717 .50798 m .3474 .50808 L .34588 .5081 L F
.34288 .50749 m .34662 .50843 L .34764 .5083 L F
.34802 .50807 m .34875 .50816 L .34588 .5081 L F
.34746 .50801 m .34764 .5083 L .34875 .50816 L F
.34288 .50749 m .34764 .5083 L .34746 .50801 L F
0 .499 .857 r
.34875 .50816 m .34788 .5076 L .3474 .5076 L F
.34735 .5075 m .34712 .50711 L .34703 .50708 L F
.34788 .5076 m .34712 .50711 L .3474 .5076 L F
.914 .881 .789 r
.34875 .50816 m .34662 .50843 L .34699 .50702 L F
.34875 .50816 m .34712 .50711 L .34747 .50518 L F
.281 .572 .937 r
.34703 .50708 m .34712 .50711 L .34701 .50692 L F
.914 .881 .789 r
.34712 .50711 m .34699 .50702 L .34701 .50692 L F
.34712 .50711 m .34701 .50692 L .34747 .50518 L F
.281 .572 .937 r
.34701 .50692 m .34814 .50744 L .34691 .50603 L F
.34712 .50711 m .34814 .50744 L .34701 .50692 L F
.522 .892 .97 r
.35036 .50839 m .34875 .50816 L .34742 .50964 L F
.761 .731 .204 r
.34725 .50943 m .34742 .50964 L .34875 .50816 L F
.532 .484 .748 r
.34937 .5124 m .35036 .50839 L .34742 .50964 L F
.34937 .5124 m .3515 .51231 L .35036 .50839 L F
.936 .705 .563 r
.35036 .50839 m .3515 .51231 L .34954 .51079 L F
0 0 .062 r
.3512 .50912 m .34954 .51079 L .35036 .50839 L F
.3512 .50912 m .35036 .50839 L .34875 .50816 L F
.864 .559 .035 r
.34747 .50518 m .34768 .5059 L .34875 .50816 L F
.34768 .5059 m .34814 .50744 L .34825 .50757 L F
.34768 .5059 m .34825 .50757 L .34875 .50816 L F
0 0 .062 r
.3512 .50912 m .34875 .50816 L .34849 .50837 L F
.34857 .50932 m .34849 .50837 L .34725 .50943 L F
.3512 .50912 m .34849 .50837 L .34857 .50932 L F
.532 .484 .748 r
.34937 .5124 m .34742 .50964 L .34699 .51138 L F
.449 .708 .977 r
.34954 .51079 m .34937 .5124 L .34699 .51138 L F
0 0 .112 r
.34881 .50856 m .34887 .51098 L .34873 .51143 L F
.34864 .51022 m .34873 .51143 L .34838 .51266 L F
.34881 .50856 m .34873 .51143 L .34864 .51022 L F
0 0 .062 r
.3512 .50912 m .34884 .5093 L .34833 .5076 L F
.34884 .5093 m .34725 .50943 L .34829 .50768 L F
.34884 .5093 m .34829 .50768 L .34833 .5076 L F
.34958 .50806 m .34833 .5076 L .34849 .50735 L F
.3512 .50912 m .34833 .5076 L .34958 .50806 L F
0 .499 .857 r
.34727 .50721 m .34814 .50744 L .34712 .50711 L F
.34875 .50816 m .34825 .50757 L .34727 .50721 L F
.34825 .50757 m .34814 .50744 L .34727 .50721 L F
0 0 .364 r
.34833 .5076 m .34881 .50856 L .34805 .50898 L F
.34778 .50853 m .34805 .50898 L .34725 .50943 L F
.34833 .5076 m .34805 .50898 L .34778 .50853 L F
0 0 0 r
.34662 .50843 m .34667 .50775 L .34678 .5078 L F
.34662 .50843 m .34673 .50758 L .34668 .50772 L F
.34673 .50758 m .34673 .50758 L .34668 .50772 L F
.34678 .5078 m .34676 .50672 L .34699 .50702 L F
.34662 .50843 m .34678 .50674 L .34678 .50662 L F
.34678 .50665 m .34678 .50662 L .34679 .50653 L F
.34662 .50843 m .34678 .50662 L .34678 .50665 L F
.34673 .50758 m .34685 .50666 L .34679 .50653 L F
.34681 .5062 m .34699 .50592 L .34699 .50702 L F
.965 .734 .537 r
.34691 .50603 m .34814 .50744 L .34747 .50518 L F
0 0 0 r
.34686 .50556 m .34696 .50465 L .34699 .50404 L F
.34662 .50843 m .34696 .50465 L .34686 .50556 L F
.281 .572 .937 r
.34305 .50573 m .34671 .50697 L .34506 .50391 L F
.34671 .50697 m .34674 .50662 L .34506 .50391 L F
0 0 0 r
.34701 .50692 m .34699 .50404 L .34747 .50518 L F
.34699 .50702 m .34699 .50669 L .34701 .50692 L F
.34699 .50669 m .34699 .50404 L .34701 .50692 L F
0 0 .364 r
.34849 .50735 m .34855 .5076 L .34833 .5076 L F
.34855 .5076 m .34881 .50856 L .34833 .5076 L F
.289 0 .244 r
.23012 .55289 m .22853 .55174 L .2316 .55086 L F
.23012 .55289 m .22796 .55366 L .22853 .55174 L F
.396 .498 .845 r
.349 .55733 m .35068 .55633 L .34744 .55434 L F
0 0 0 r
.3482 .55984 m .35068 .55633 L .349 .55733 L F
.971 .879 .499 r
.4059 .58779 m .40723 .58607 L .40688 .58515 L F
0 0 .039 r
.30005 .63503 m .30017 .63389 L .29874 .63653 L F
.744 .39 .381 r
.27782 .56379 m .27609 .56618 L .27398 .56533 L F
.001 0 .127 r
.27959 .56273 m .27782 .56379 L .28021 .56057 L F
.323 0 .104 r
.27883 .56494 m .27782 .56379 L .27959 .56273 L F
.27883 .56494 m .27609 .56618 L .27782 .56379 L F
.199 0 .241 r
.26648 .54703 m .26327 .55045 L .26411 .54802 L F
.007 .512 .864 r
.59392 .4086 m .59444 .40943 L .59359 .40903 L F
.012 .518 .866 r
.59747 .41014 m .59444 .40943 L .59392 .4086 L F
.275 .117 .477 r
.32241 .59449 m .32086 .59253 L .32272 .59192 L F
.32241 .59449 m .32007 .59497 L .32086 .59253 L F
.714 .769 .896 r
.35427 .6481 m .35578 .64983 L .35368 .65114 L F
.411 .16 .42 r
.35368 .65114 m .35578 .64983 L .35276 .65267 L F
.77 .271 .027 r
.40596 .49998 m .40195 .49705 L .40327 .50088 L F
.556 .366 .578 r
.40596 .49998 m .40555 .50251 L .40327 .50088 L F
0 .179 .646 r
.40327 .50088 m .40396 .50114 L .40596 .49998 L F
.40327 .50088 m .40555 .50251 L .40396 .50114 L F
.813 .928 .91 r
.38785 .50726 m .38526 .50996 L .38464 .50833 L F
.869 .462 .257 r
.38795 .51165 m .38464 .50833 L .38526 .50996 L F
.074 .228 .719 r
.21749 .60511 m .21859 .60544 L .21726 .60147 L F
0 .304 .798 r
.21749 .60511 m .22036 .60729 L .21859 .60544 L F
.718 .662 .794 r
.62943 .37254 m .63063 .37371 L .62706 .37334 L F
.468 .59 .892 r
.63106 .37629 m .62706 .37334 L .63063 .37371 L F
.702 .695 .84 r
.63237 .36944 m .63063 .37371 L .62943 .37254 L F
.63237 .36944 m .63351 .37308 L .63063 .37371 L F
.684 .556 .704 r
.63351 .37308 m .63106 .37629 L .63063 .37371 L F
.332 .251 .613 r
.34102 .55147 m .34318 .55322 L .34318 .54977 L F
.34102 .55147 m .34147 .55413 L .34318 .55322 L F
.258 .54 .922 r
.20503 .59686 m .20545 .59495 L .20345 .59518 L F
.20503 .59686 m .20793 .59757 L .20545 .59495 L F
.952 .952 .711 r
.68859 .30641 m .68671 .30716 L .68809 .30533 L F
.68859 .30641 m .68683 .30956 L .68671 .30716 L F
.883 .987 .81 r
.68859 .30641 m .68923 .30349 L .69129 .30333 L F
.68859 .30641 m .68809 .30533 L .68923 .30349 L F
.089 0 0 r
.29662 .63939 m .29433 .63999 L .29197 .64186 L F
.94 .575 .2 r
.40368 .57241 m .40577 .57603 L .40511 .57355 L F
.73 .523 .611 r
.39103 .65627 m .39119 .65928 L .38701 .65895 L F
.677 .587 .748 r
.39433 .65314 m .39362 .65588 L .39103 .65627 L F
.652 .463 .615 r
.39103 .65627 m .39362 .65588 L .39119 .65928 L F
.329 .588 .938 r
.70636 .3444 m .70385 .34448 L .70354 .34269 L F
.626 .586 .789 r
.70711 .34686 m .70385 .34448 L .70636 .3444 L F
0 0 .169 r
.73315 .34396 m .73289 .34624 L .7307 .34769 L F
0 0 0 r
.7307 .34769 m .7321 .34729 L .72964 .34882 L F
.7307 .34769 m .73289 .34624 L .7321 .34729 L F
.37665 .59671 m .37451 .59875 L .37627 .59744 L F
.37731 .59541 m .37606 .59691 L .37665 .59671 L F
.37606 .59691 m .37451 .59875 L .37665 .59671 L F
.37731 .59541 m .37627 .59744 L .37548 .59529 L F
.148 0 0 r
.37717 .59543 m .37731 .59541 L .37548 .59529 L F
.355 .362 .729 r
.37548 .59529 m .37627 .59744 L .37798 .59673 L F
.098 0 0 r
.37655 .59542 m .37548 .59529 L .37466 .59541 L F
.37717 .59543 m .37548 .59529 L .37655 .59542 L F
0 .352 .827 r
.37548 .59529 m .37748 .59644 L .37679 .59545 L F
.906 .499 .125 r
.37668 .59448 m .37717 .59543 L .379 .593 L F
.098 0 0 r
.37717 .59543 m .37655 .59542 L .3766 .59434 L F
.37655 .59542 m .3761 .59452 L .37661 .5942 L F
.906 .499 .125 r
.37629 .59473 m .37717 .59543 L .37668 .59448 L F
.731 .868 .945 r
.379 .593 m .37717 .59543 L .37672 .59445 L F
.379 .593 m .37672 .59445 L .37661 .5942 L F
.397 .813 .619 r
.37668 .59448 m .37629 .59473 L .37668 .59448 L F
.37719 .59409 m .37629 .59472 L .37668 .59448 L F
.37629 .59472 m .37629 .59473 L .37668 .59448 L F
.3786 .59324 m .37668 .59448 L .379 .593 L F
.37719 .59409 m .37668 .59448 L .3786 .59324 L F
.098 0 0 r
.37672 .59445 m .3766 .59434 L .37661 .5942 L F
.37717 .59543 m .37668 .59448 L .37672 .59445 L F
.37668 .59448 m .3766 .59434 L .37672 .59445 L F
0 .352 .827 r
.37548 .59529 m .37655 .59542 L .37623 .59477 L F
.418 .557 .887 r
.37548 .59529 m .37321 .59518 L .37106 .59191 L F
.068 0 0 r
.37133 .59524 m .37321 .59518 L .37426 .59523 L F
.3744 .59528 m .37426 .59523 L .37548 .59529 L F
.37133 .59524 m .37426 .59523 L .3744 .59528 L F
.37133 .59524 m .37548 .59529 L .37391 .59625 L F
.418 .557 .887 r
.37548 .59529 m .37106 .59191 L .37466 .59541 L F
0 .057 .572 r
.37238 .59292 m .37459 .59534 L .37106 .59191 L F
.37216 .59268 m .37238 .59292 L .37106 .59191 L F
.37459 .59534 m .37466 .59541 L .37458 .59533 L F
.37459 .59534 m .37458 .59533 L .37106 .59191 L F
.098 0 0 r
.37655 .59542 m .37466 .59541 L .3761 .59452 L F
0 .352 .827 r
.37623 .59477 m .37679 .59545 L .37629 .59473 L F
.37655 .59542 m .37679 .59545 L .37623 .59477 L F
.37748 .59644 m .37798 .59673 L .37768 .59637 L F
.37748 .59644 m .37768 .59637 L .37629 .59473 L F
.624 .567 .77 r
.39303 .68339 m .39512 .68275 L .39339 .68406 L F
.652 .173 0 r
.38983 .53012 m .38939 .52907 L .3886 .52734 L F
.38983 .53012 m .39117 .53151 L .38939 .52907 L F
.785 .83 .887 r
.55083 .42035 m .54816 .42284 L .54697 .42032 L F
.272 .442 .848 r
.55129 .42594 m .54816 .42284 L .55083 .42035 L F
0 0 0 r
.34658 .6712 m .3446 .67226 L .34268 .67391 L F
.928 .958 .64 r
.39423 .62691 m .39519 .62354 L .39321 .62688 L F
0 0 .372 r
.34587 .67848 m .34719 .68024 L .34647 .67927 L F
.677 .173 0 r
.33107 .69724 m .33147 .69829 L .32882 .69721 L F
.614 .146 0 r
.33107 .69724 m .33343 .70027 L .333 .6996 L F
.33343 .70027 m .33421 .70127 L .333 .6996 L F
.404 .725 .989 r
.33232 .69854 m .333 .6996 L .33523 .69942 L F
.677 .173 0 r
.33107 .69724 m .33298 .69958 L .33147 .69829 L F
.33298 .69958 m .333 .6996 L .33147 .69829 L F
.567 .742 .959 r
.33147 .69829 m .33225 .69581 L .32981 .69686 L F
.33147 .69829 m .32981 .69686 L .32929 .69709 L F
.404 .725 .989 r
.33147 .69829 m .333 .6996 L .33232 .69854 L F
.569 .894 .636 r
.32949 .52567 m .32773 .52698 L .33076 .52429 L F
.327 .144 .473 r
.31649 .5996 m .31772 .60156 L .31543 .60161 L F
.233 0 .227 r
.31772 .60156 m .31504 .60411 L .31543 .60161 L F
.634 .947 .735 r
.32216 .61807 m .32116 .61906 L .31887 .62058 L F
.759 .655 .747 r
.64233 .3722 m .64402 .37612 L .64022 .37564 L F
.758 .655 .748 r
.64441 .37366 m .64402 .37612 L .64233 .3722 L F
.777 .89 .925 r
.38547 .67255 m .38714 .67512 L .38787 .67425 L F
.848 .996 .759 r
.38387 .6773 m .38714 .67512 L .38547 .67255 L F
.649 .436 .581 r
.32899 .58623 m .32867 .58935 L .32616 .58829 L F
.287 .128 .483 r
.3305 .58792 m .32899 .58623 L .33105 .58526 L F
.3305 .58792 m .32867 .58935 L .32899 .58623 L F
.533 .001 0 r
.33857 .52548 m .34116 .5267 L .34189 .52574 L F
.049 .111 .607 r
.34189 .52574 m .34384 .52415 L .34153 .5221 L F
.413 .299 .614 r
.34116 .5267 m .34314 .52481 L .34189 .52574 L F
.34314 .52481 m .34341 .52449 L .34189 .52574 L F
.34116 .5267 m .34318 .52691 L .34384 .52415 L F
.386 .418 .772 r
.34229 .5233 m .34318 .52691 L .34116 .5267 L F
.987 .765 .515 r
.34229 .5233 m .34165 .52608 L .34192 .52623 L F
.34277 .52525 m .34192 .52623 L .34318 .52691 L F
.34229 .5233 m .34192 .52623 L .34277 .52525 L F
.413 .299 .614 r
.34314 .52481 m .34384 .52415 L .34341 .52449 L F
.791 .577 .612 r
.43751 .55047 m .43273 .54724 L .436 .54867 L F
.414 .076 .28 r
.43751 .55047 m .43344 .55466 L .43277 .55052 L F
.395 .503 .85 r
.436 .54867 m .43967 .55003 L .43751 .55047 L F
0 0 0 r
.43726 .55134 m .43751 .55047 L .43967 .55003 L F
.43726 .55134 m .43605 .55457 L .43751 .55047 L F
.541 .274 .459 r
.30824 .55153 m .30764 .55395 L .30505 .55425 L F
.529 .31 .526 r
.31074 .55064 m .30764 .55395 L .30824 .55153 L F
.267 .11 .474 r
.37904 .6519 m .37659 .65303 L .37646 .65562 L F
.492 .281 .521 r
.66762 .39227 m .66754 .39478 L .66501 .3956 L F
.529 .387 .631 r
.6697 .38941 m .67025 .39148 L .66762 .39227 L F
.119 0 .418 r
.66971 .39318 m .66762 .39227 L .67025 .39148 L F
.66971 .39318 m .66754 .39478 L .66762 .39227 L F
.877 .494 .023 r
.70064 .33707 m .70178 .33833 L .69822 .33737 L F
.70064 .33707 m .70247 .34047 L .70178 .33833 L F
.96 .941 .705 r
.59371 .4277 m .59452 .42675 L .59265 .42993 L F
.335 .771 .968 r
.62462 .39334 m .6236 .39396 L .6262 .39346 L F
.768 .997 .833 r
.62277 .39446 m .62523 .39273 L .6236 .39396 L F
.335 .771 .968 r
.62241 .39317 m .6236 .39396 L .62462 .39334 L F
.768 .997 .833 r
.62182 .39513 m .62277 .39446 L .6236 .39396 L F
.88 .993 .777 r
.62523 .39273 m .62693 .38842 L .62474 .3911 L F
.62523 .39273 m .62609 .39158 L .62571 .3915 L F
.051 .401 .856 r
.62714 .39342 m .62523 .39273 L .62474 .3911 L F
.62714 .39342 m .62501 .39136 L .6262 .39346 L F
.62501 .39136 m .62474 .3911 L .62489 .39133 L F
.62501 .39136 m .62489 .39133 L .6262 .39346 L F
.88 .993 .777 r
.62571 .3915 m .62762 .38956 L .62693 .38842 L F
.62609 .39158 m .62762 .38956 L .62571 .3915 L F
.723 .7 .828 r
.25086 .57934 m .25481 .57991 L .25285 .57609 L F
.662 .515 .674 r
.25086 .57934 m .25438 .58246 L .25481 .57991 L F
.95 .664 .216 r
.40087 .55717 m .40111 .55988 L .4021 .56127 L F
.598 .161 0 r
.40111 .55988 m .40329 .56302 L .4021 .56127 L F
.477 .224 .451 r
.66885 .38276 m .6688 .38535 L .66597 .38598 L F
.492 .236 .454 r
.67141 .38455 m .66885 .38276 L .67161 .38207 L F
.67141 .38455 m .6688 .38535 L .66885 .38276 L F
.846 .886 .869 r
.63117 .39227 m .62714 .39342 L .62972 .39067 L F
.824 .769 .801 r
.6328 .38656 m .63117 .39227 L .62972 .39067 L F
.787 .835 .888 r
.7102 .34444 m .70711 .34686 L .70636 .3444 L F
.445 .478 .8 r
.35259 .51837 m .35156 .52264 L .34964 .51918 L F
.35259 .51837 m .3538 .52258 L .35156 .52264 L F
.469 .38 .673 r
.3538 .52258 m .35147 .52568 L .35156 .52264 L F
.541 .255 .43 r
.384 .63284 m .38422 .62953 L .38201 .63055 L F
0 .097 .65 r
.38239 .62997 m .38201 .63055 L .38227 .62976 L F
.384 .63284 m .3823 .63089 L .38239 .62997 L F
.3823 .63089 m .38201 .63055 L .38239 .62997 L F
.795 .783 .281 r
.38247 .62913 m .38242 .62984 L .38239 .62993 L F
.853 .769 .769 r
.38164 .63648 m .38192 .6323 L .3802 .63497 L F
.38192 .6323 m .38196 .63177 L .38132 .63293 L F
.694 .392 .461 r
.38128 .633 m .37643 .62949 L .37646 .63214 L F
.853 .769 .769 r
.38192 .6323 m .38132 .63293 L .3802 .63497 L F
.38132 .63293 m .38131 .63296 L .3802 .63497 L F
.65 .435 .577 r
.3802 .63497 m .38131 .63296 L .38147 .63303 L F
.694 .392 .461 r
.38147 .63303 m .38132 .63293 L .38131 .63296 L F
.38132 .63293 m .37643 .62949 L .38128 .633 L F
.853 .769 .769 r
.38132 .63293 m .38132 .63293 L .38131 .63296 L F
.694 .392 .461 r
.3814 .63298 m .38147 .63278 L .38132 .63293 L F
.38147 .63303 m .38151 .63289 L .3814 .63298 L F
.38151 .63289 m .38239 .62993 L .3814 .63298 L F
.65 .435 .577 r
.38131 .63296 m .38196 .63177 L .38147 .63303 L F
.694 .392 .461 r
.38147 .63303 m .38131 .63296 L .38128 .633 L F
.38132 .63293 m .38239 .62993 L .37643 .62949 L F
.38147 .63278 m .38239 .62993 L .38132 .63293 L F
.38239 .62993 m .38242 .62984 L .38232 .62983 L F
.38239 .62993 m .38232 .62983 L .37643 .62949 L F
0 .097 .65 r
.384 .63284 m .38227 .62976 L .38334 .63124 L F
.38246 .63203 m .38247 .62913 L .38196 .63177 L F
.384 .63284 m .38334 .63124 L .38246 .63203 L F
.38334 .63124 m .38227 .62976 L .38247 .62913 L F
.38334 .63124 m .38247 .62913 L .38246 .63203 L F
.795 .783 .281 r
.38247 .62913 m .38239 .62993 L .38147 .63303 L F
.461 .142 .338 r
.29591 .54471 m .29282 .54723 L .29348 .54505 L F
.106 0 0 r
.36219 .59182 m .36553 .58916 L .36336 .59031 L F
.447 .173 .404 r
.68274 .36982 m .68229 .37251 L .6796 .37313 L F
.483 .205 .414 r
.68554 .37114 m .68274 .36982 L .68508 .36919 L F
.68554 .37114 m .68229 .37251 L .68274 .36982 L F
.281 0 .189 r
.29913 .62922 m .29693 .62995 L .29804 .62711 L F
.779 .678 .752 r
.65059 .37338 m .65005 .37556 L .648 .37662 L F
.389 .163 .446 r
.31987 .60077 m .31649 .5996 L .3201 .59784 L F
.31987 .60077 m .31772 .60156 L .31649 .5996 L F
0 0 0 r
.37442 .65682 m .3702 .65874 L .37197 .65771 L F
.715 .207 0 r
.60042 .41337 m .59898 .4112 L .59747 .41014 L F
.406 .539 .878 r
.3861 .59761 m .38851 .60122 L .38578 .60054 L F
.648 .238 0 r
.39895 .54821 m .40091 .55153 L .39936 .54885 L F
.39921 .54871 m .40091 .55153 L .39895 .54821 L F
.39834 .54726 m .39921 .54871 L .39895 .54821 L F
.543 .622 .881 r
.40249 .55021 m .40091 .55153 L .39834 .54726 L F
0 0 .339 r
.39987 .54899 m .39973 .55321 L .40249 .55021 L F
.39984 .54991 m .40017 .55168 L .39973 .55321 L F
.39987 .54899 m .40001 .55024 L .39984 .54991 L F
.40001 .55024 m .40017 .55168 L .39984 .54991 L F
.134 .278 .746 r
.32299 .52895 m .32549 .53101 L .32602 .52858 L F
.381 0 0 r
.35652 .71581 m .36071 .71551 L .359 .71554 L F
.202 .73 .809 r
.359 .71554 m .36071 .71551 L .36339 .71506 L F
.977 .69 .412 r
.35141 .69653 m .35271 .69442 L .35103 .69312 L F
.35103 .69312 m .35271 .69442 L .35141 .69653 L F
.377 0 .134 r
.33923 .67875 m .34053 .68042 L .33803 .68091 L F
.33923 .67875 m .3416 .67844 L .34053 .68042 L F
.557 .701 .936 r
.45853 .56631 m .4579 .56962 L .45611 .56646 L F
.45853 .56631 m .46156 .56954 L .4579 .56962 L F
.543 .459 .709 r
.46136 .57241 m .45876 .57349 L .4579 .56962 L F
.834 .544 .499 r
.6268 .41929 m .63106 .42059 L .63025 .41785 L F
.567 .385 .594 r
.63289 .41575 m .63305 .41781 L .63025 .41785 L F
.568 .393 .604 r
.63305 .41781 m .63106 .42059 L .63025 .41785 L F
.63305 .41781 m .63106 .42059 L .63025 .41785 L F
.627 .717 .911 r
.28486 .61527 m .28693 .61719 L .29173 .61669 L F
.69 .371 .43 r
.28484 .61986 m .28877 .62083 L .28693 .61719 L F
.655 .494 .653 r
.64512 .37163 m .64441 .37366 L .64233 .3722 L F
.64512 .37163 m .64682 .37067 L .64441 .37366 L F
.527 .313 .532 r
.67679 .37588 m .67417 .37885 L .67402 .3763 L F
.768 .976 .706 r
.31336 .5242 m .31243 .52628 L .31361 .52532 L F
.313 .365 .756 r
.38215 .59453 m .38033 .596 L .38257 .59181 L F
.38215 .59453 m .38046 .59608 L .38033 .596 L F
0 .5 .741 r
.28179 .51883 m .28135 .51886 L .27961 .51935 L F
.28179 .51883 m .28337 .51919 L .28135 .51886 L F
.818 .408 0 r
.62824 .38712 m .62882 .3875 L .62741 .38565 L F
.734 .99 .871 r
.62882 .3875 m .62762 .38956 L .62952 .38795 L F
.234 .368 .795 r
.62972 .39067 m .62762 .38956 L .62882 .3875 L F
.818 .408 0 r
.62975 .3898 m .62882 .3875 L .62824 .38712 L F
.734 .99 .871 r
.62882 .3875 m .62952 .38795 L .62985 .38768 L F
0 .326 .78 r
.62693 .38842 m .62762 .38956 L .62972 .39067 L F
.281 .384 .791 r
.30054 .5402 m .29899 .54159 L .2989 .54007 L F
.542 .487 .744 r
.30054 .5402 m .29886 .54357 L .29899 .54159 L F
.667 .768 .926 r
.39748 .67554 m .40143 .67735 L .39951 .67509 L F
.766 .789 .871 r
.39951 .67509 m .40143 .67735 L .40451 .67506 L F
.824 .762 .793 r
.68524 .34017 m .68913 .34026 L .6878 .33689 L F
.829 .744 .77 r
.68633 .34414 m .68913 .34026 L .68524 .34017 L F
.729 .718 .84 r
.6878 .33689 m .68913 .34026 L .69172 .33759 L F
.384 .316 .657 r
.28088 .53261 m .28319 .53388 L .28344 .5317 L F
.28088 .53261 m .28112 .53505 L .28319 .53388 L F
.864 .781 .768 r
.63637 .36746 m .63237 .36944 L .6348 .36612 L F
.723 .848 .941 r
.63714 .36507 m .63637 .36746 L .6348 .36612 L F
.728 .816 .919 r
.33508 .55706 m .33695 .55848 L .33892 .55736 L F
0 .231 .745 r
.38177 .60343 m .38263 .60554 L .38493 .60727 L F
.014 .343 .823 r
.60283 .40348 m .60347 .40525 L .60641 .40696 L F
.593 .048 0 r
.60347 .40525 m .60732 .40843 L .60641 .40696 L F
.671 .336 0 r
.39341 .53474 m .39461 .53782 L .39488 .53846 L F
.938 .626 .174 r
.39461 .53782 m .3955 .54034 L .39488 .53846 L F
0 .476 .801 r
.34807 .71658 m .34599 .71876 L .34598 .71586 L F
.34807 .71658 m .34933 .71691 L .34853 .71627 L F
.34933 .71691 m .35031 .71717 L .34853 .71627 L F
.544 0 0 r
.34853 .71627 m .34894 .71726 L .34828 .71606 L F
0 0 0 r
.35031 .71717 m .35053 .7173 L .34853 .71627 L F
.715 .959 .687 r
.35053 .7173 m .3526 .71596 L .35333 .71443 L F
.544 0 0 r
.34853 .71627 m .35053 .7173 L .34894 .71726 L F
.463 .854 .977 r
.3526 .71596 m .35652 .71581 L .35505 .71506 L F
.566 .884 .991 r
.35333 .71443 m .3526 .71596 L .35505 .71506 L F
.715 .959 .687 r
.35053 .7173 m .35333 .71443 L .35341 .7173 L F
.375 .063 .302 r
.35174 .71652 m .34811 .71576 L .34894 .71726 L F
.971 .697 .455 r
.34598 .71586 m .34599 .71876 L .34427 .71773 L F
.763 .889 .934 r
.34427 .71773 m .34717 .7144 L .34598 .71586 L F
.34427 .71773 m .34853 .71627 L .34717 .7144 L F
.375 .063 .302 r
.34811 .71576 m .34806 .71575 L .34894 .71726 L F
0 .476 .801 r
.34807 .71658 m .34853 .71627 L .34599 .71876 L F
.65 .213 0 r
.34777 .71537 m .34806 .71575 L .34717 .7144 L F
.34894 .71726 m .3481 .71582 L .34777 .71537 L F
.3481 .71582 m .34806 .71575 L .34777 .71537 L F
.763 .889 .934 r
.34427 .71773 m .34599 .71876 L .34848 .71633 L F
.34845 .7163 m .34848 .71633 L .34853 .71627 L F
.34427 .71773 m .34848 .71633 L .34845 .7163 L F
.544 0 0 r
.34828 .71606 m .34894 .71726 L .34812 .71593 L F
.523 .512 .785 r
.34717 .7144 m .34806 .71575 L .34806 .71569 L F
.524 .512 .785 r
.34808 .71571 m .35234 .7148 L .35065 .70997 L F
.34806 .71575 m .3481 .71574 L .34808 .71571 L F
.3481 .71574 m .35234 .7148 L .34808 .71571 L F
.544 0 0 r
.34853 .71627 m .34839 .71615 L .34762 .71505 L F
.34717 .71441 m .34762 .71505 L .34717 .7144 L F
.34853 .71627 m .34762 .71505 L .34717 .71441 L F
.34839 .71615 m .34838 .71615 L .34806 .71569 L F
.34839 .71615 m .34806 .71569 L .34717 .7144 L F
.524 .512 .785 r
.34806 .71569 m .35065 .70997 L .34816 .71033 L F
.34806 .71575 m .34808 .71571 L .34806 .71569 L F
.34808 .71571 m .35065 .70997 L .34806 .71569 L F
.523 .512 .785 r
.34717 .7144 m .34806 .71569 L .34816 .71033 L F
.544 0 0 r
.34838 .71615 m .34812 .71593 L .34717 .7144 L F
.441 .238 .507 r
.35731 .58204 m .35428 .58563 L .35457 .58291 L F
.634 .422 .577 r
.34421 .54287 m .3391 .54163 L .34132 .54062 L F
.34421 .54287 m .33881 .54437 L .3391 .54163 L F
.934 .944 .604 r
.31507 .52261 m .31336 .5242 L .31361 .52532 L F
.75 .936 .597 r
.31576 .52086 m .31336 .5242 L .31507 .52261 L F
.81 .771 .816 r
.38257 .59181 m .38595 .59301 L .38469 .59322 L F
.521 .334 .569 r
.38257 .59181 m .38356 .5951 L .38595 .59301 L F
.631 .428 .589 r
.38356 .5951 m .38686 .59476 L .38595 .59301 L F
.185 0 .184 r
.38686 .59476 m .39049 .59274 L .38595 .59301 L F
0 0 .231 r
.43202 .5767 m .43414 .57468 L .43292 .5751 L F
.43202 .5767 m .43324 .5789 L .43414 .57468 L F
.576 .707 .932 r
.43303 .58228 m .43324 .5789 L .43202 .5767 L F
.721 .265 .166 r
.25386 .54891 m .24977 .54749 L .25147 .551 L F
.96 .829 .401 r
.40345 .56882 m .40453 .56717 L .40424 .56433 L F
.40345 .56882 m .40399 .56974 L .40453 .56717 L F
.799 .609 .645 r
.29887 .55779 m .29645 .5579 L .29892 .55719 L F
.29876 .5592 m .29748 .55848 L .29887 .55779 L F
.29748 .55848 m .29645 .5579 L .29887 .55779 L F
.29876 .5592 m .29513 .55969 L .29645 .5579 L F
.41 .84 .697 r
.29513 .55969 m .29989 .55724 L .29645 .5579 L F
.29931 .55753 m .2996 .55737 L .29989 .55724 L F
.291 .098 .437 r
.30096 .5566 m .29876 .5592 L .29887 .55779 L F
.451 .689 .967 r
.29989 .55724 m .30096 .5566 L .29892 .55719 L F
.855 .997 .776 r
.29989 .55724 m .29969 .55724 L .30096 .5566 L F
.291 .098 .437 r
.30088 .55663 m .30065 .55676 L .29892 .55719 L F
.30065 .55676 m .29889 .55764 L .29892 .55719 L F
.855 .997 .776 r
.29969 .55724 m .29737 .55726 L .30096 .5566 L F
.377 0 0 r
.29892 .55719 m .29645 .5579 L .29989 .55724 L F
.855 .997 .776 r
.29969 .55724 m .29677 .55864 L .29737 .55726 L F
.29989 .55724 m .2996 .55737 L .29969 .55724 L F
.291 .098 .437 r
.29969 .55724 m .29887 .55779 L .29889 .55764 L F
.855 .997 .776 r
.2996 .55737 m .29677 .55864 L .29969 .55724 L F
.291 .098 .437 r
.30065 .55676 m .2996 .55737 L .29969 .55724 L F
.2996 .55737 m .29887 .55779 L .29969 .55724 L F
.30096 .5566 m .29887 .55779 L .30088 .55663 L F
.41 .84 .697 r
.29724 .5586 m .29677 .55864 L .2996 .55737 L F
.29724 .5586 m .2996 .55737 L .29931 .55753 L F
.29513 .55969 m .29539 .55952 L .29724 .5586 L F
.29539 .55952 m .29677 .55864 L .29724 .5586 L F
.491 .304 .554 r
.36817 .6175 m .36795 .62011 L .36576 .61818 L F
.36817 .6175 m .36795 .62011 L .36576 .61818 L F
0 0 0 r
.35148 .63543 m .35551 .6339 L .35596 .63668 L F
.35148 .63543 m .35596 .63668 L .35565 .6369 L F
.379 .395 .751 r
.35524 .63866 m .35148 .63543 L .35578 .63694 L F
.785 .77 .839 r
.35773 .63586 m .35524 .63866 L .35789 .63587 L F
0 0 0 r
.35565 .6369 m .35596 .63668 L .35599 .63683 L F
.35565 .6369 m .35599 .63683 L .35578 .63694 L F
.785 .77 .839 r
.35578 .63694 m .35524 .63866 L .35773 .63586 L F
.555 .253 .41 r
.35602 .63703 m .35599 .63683 L .35789 .63587 L F
.35599 .63683 m .35551 .6339 L .35789 .63587 L F
.785 .77 .839 r
.35617 .63574 m .35579 .63693 L .35773 .63586 L F
.35579 .63693 m .35578 .63694 L .35599 .63683 L F
.35579 .63693 m .35599 .63683 L .35773 .63586 L F
0 0 0 r
.35578 .63694 m .35599 .63683 L .35602 .63703 L F
.379 .395 .751 r
.35524 .63866 m .35578 .63694 L .35602 .63703 L F
.785 .77 .839 r
.35387 .63556 m .35524 .63866 L .35617 .63574 L F
.823 .785 .817 r
.35126 .63865 m .35311 .63865 L .35387 .63556 L F
.35311 .63865 m .35524 .63866 L .35474 .63753 L F
.35311 .63865 m .35474 .63753 L .35387 .63556 L F
.025 .447 .872 r
.34879 .49866 m .35041 .49922 L .34999 .50006 L F
.146 .593 .929 r
.35041 .49922 m .35221 .50045 L .34999 .50006 L F
.778 .337 0 r
.59473 .3922 m .5946 .39305 L .59318 .39117 L F
.59473 .3922 m .59673 .39583 L .5946 .39305 L F
.325 .672 .976 r
.39267 .64441 m .39739 .64589 L .39516 .64607 L F
.233 .397 .821 r
.39836 .64961 m .39516 .64607 L .39739 .64589 L F
.118 .662 .833 r
.26974 .52781 m .26763 .52746 L .26768 .52766 L F
.47 0 0 r
.27225 .52708 m .26763 .52746 L .26974 .52781 L F
.27207 .5271 m .27122 .52795 L .26763 .52746 L F
.27225 .52708 m .27122 .52795 L .27207 .5271 L F
.615 .867 .518 r
.27248 .52629 m .27089 .52828 L .27122 .52795 L F
.644 .411 .551 r
.27122 .52795 m .2699 .52952 L .26763 .52746 L F
.615 .867 .518 r
.27089 .52828 m .2699 .52952 L .27122 .52795 L F
.675 .157 0 r
.2699 .52952 m .2676 .52731 L .26763 .52746 L F
.2676 .52731 m .26597 .52574 L .26763 .52746 L F
.118 .662 .833 r
.26768 .52766 m .26763 .52746 L .26528 .5275 L F
.833 .485 0 r
.70729 .36372 m .70798 .366 L .7064 .36224 L F
.491 .206 .408 r
.45254 .57683 m .45238 .57903 L .44972 .5795 L F
.543 .249 .417 r
.45254 .57683 m .45506 .57873 L .45238 .57903 L F
.57 .234 .36 r
.45481 .57715 m .45506 .57873 L .45254 .57683 L F
.344 .104 .4 r
.2829 .55743 m .2823 .55991 L .28021 .56057 L F
.383 .055 .279 r
.28171 .56184 m .28021 .56057 L .2823 .55991 L F
.28171 .56184 m .27959 .56273 L .28021 .56057 L F
.999 .838 .529 r
.40502 .58152 m .40669 .57978 L .40542 .57877 L F
.40502 .58152 m .40603 .58298 L .40669 .57978 L F
.833 .876 .875 r
.67042 .3314 m .66634 .33278 L .66922 .32992 L F
.843 .894 .875 r
.67333 .32836 m .67042 .3314 L .66922 .32992 L F
.517 .342 .582 r
.66754 .39478 m .66786 .39739 L .66501 .3956 L F
.799 .69 .745 r
.384 .63284 m .3869 .62858 L .38422 .62953 L F
.65 .693 .877 r
.4135 .4918 m .41499 .49421 L .41113 .49295 L F
.682 .707 .867 r
.41759 .49332 m .41499 .49421 L .4135 .4918 L F
.455 .267 .535 r
.34788 .64662 m .35034 .64722 L .35024 .64555 L F
.34788 .64662 m .34857 .6501 L .35034 .64722 L F
.573 .35 .538 r
.3768 .56375 m .37952 .56346 L .37968 .56074 L F
.3768 .56375 m .37952 .56346 L .37968 .56074 L F
.46 .308 .588 r
.38229 .55997 m .37968 .56074 L .38186 .55732 L F
.478 .293 .551 r
.37952 .56346 m .38229 .55997 L .37968 .56074 L F
.46 .308 .588 r
.38229 .55997 m .37968 .56074 L .38186 .55732 L F
.478 .293 .551 r
.37952 .56346 m .38229 .55997 L .37968 .56074 L F
.469 .38 .673 r
.3538 .52258 m .35476 .52783 L .35147 .52568 L F
0 .206 .653 r
.35147 .52568 m .35476 .52783 L .35542 .52838 L F
.89 .849 .797 r
.39175 .50986 m .39003 .51272 L .38795 .51165 L F
.846 .445 0 r
.3899 .51509 m .38795 .51165 L .39003 .51272 L F
.796 .641 .69 r
.39416 .50668 m .39026 .5061 L .39038 .50324 L F
.784 .69 .76 r
.39416 .50668 m .39175 .50986 L .39026 .5061 L F
.483 .812 1 r
.36709 .53524 m .36785 .53357 L .36752 .5355 L F
.36547 .53427 m .36785 .53357 L .36709 .53524 L F
.184 0 .015 r
.36846 .53129 m .36547 .53427 L .36416 .53073 L F
.735 .736 .216 r
.36752 .5355 m .36765 .53477 L .3686 .5309 L F
.36765 .53477 m .36789 .53373 L .3686 .5309 L F
.36837 .53181 m .3683 .53197 L .3686 .5309 L F
.36768 .53455 m .3682 .5324 L .36837 .53181 L F
.3682 .5324 m .3683 .53197 L .36837 .53181 L F
.184 0 .015 r
.36822 .53233 m .36785 .53357 L .36547 .53427 L F
.735 .736 .216 r
.36768 .53455 m .36785 .53357 L .3683 .53197 L F
.467 .082 .225 r
.37096 .53091 m .37065 .53293 L .37137 .53091 L F
.3686 .5309 m .36908 .53138 L .3697 .5309 L F
.3686 .5309 m .36832 .53191 L .36918 .53147 L F
.184 0 .015 r
.36935 .53132 m .36846 .53129 L .36857 .53083 L F
.3695 .53142 m .36927 .53139 L .36935 .53132 L F
.467 .082 .225 r
.36908 .53138 m .36918 .53148 L .3694 .53126 L F
.36918 .53148 m .36935 .53132 L .3694 .53126 L F
.184 0 .015 r
.36927 .53139 m .36846 .53129 L .36935 .53132 L F
.36927 .53139 m .36832 .53191 L .36846 .53129 L F
.36932 .5314 m .36918 .53147 L .36927 .53139 L F
.36918 .53147 m .36832 .53191 L .36927 .53139 L F
.467 .082 .225 r
.36918 .53148 m .3692 .5315 L .36933 .53135 L F
.36927 .53139 m .36933 .53135 L .36935 .53132 L F
.36918 .53148 m .36933 .53135 L .36927 .53139 L F
.36908 .53138 m .3694 .53126 L .36954 .5311 L F
.36908 .53138 m .36954 .5311 L .36956 .53101 L F
.359 0 0 r
.36829 .52806 m .37231 .52857 L .36958 .52804 L F
.341 .742 .983 r
.36829 .52806 m .36453 .52733 L .36591 .5286 L F
.372 0 .187 r
.3686 .5309 m .37231 .52857 L .36829 .52806 L F
.36985 .53012 m .37041 .53091 L .37231 .52857 L F
.3686 .5309 m .36959 .5309 L .36985 .53012 L F
.36959 .5309 m .37041 .53091 L .36985 .53012 L F
.341 .742 .983 r
.3666 .52773 m .36665 .52701 L .36453 .52733 L F
.36829 .52806 m .36665 .52701 L .3666 .52773 L F
.637 .747 .928 r
.36222 .52795 m .36591 .5286 L .36453 .52733 L F
.424 .473 .807 r
.36453 .52733 m .36665 .52701 L .36528 .52325 L F
.519 .191 .351 r
.36289 .52971 m .36665 .52701 L .36618 .5293 L F
.793 .652 .707 r
.36566 .52936 m .36416 .53073 L .36289 .52971 L F
.36618 .5293 m .36549 .52979 L .36566 .52936 L F
.36549 .52979 m .36416 .53073 L .36566 .52936 L F
.519 .191 .351 r
.36289 .52971 m .3651 .53018 L .36628 .52728 L F
.36663 .52703 m .3651 .53018 L .36665 .52701 L F
.148 .289 .753 r
.36528 .52325 m .36665 .52701 L .36716 .52511 L F
.793 .859 .413 r
.36665 .52698 m .3651 .53018 L .36671 .52622 L F
.36665 .52701 m .36658 .52715 L .36665 .52698 L F
.36658 .52715 m .3651 .53018 L .36665 .52698 L F
.36665 .52701 m .36671 .52622 L .36716 .52511 L F
.567 .856 .997 r
.36962 .52622 m .36829 .52806 L .37097 .52525 L F
.36962 .52622 m .36665 .52701 L .36829 .52806 L F
.909 .804 .33 r
.36962 .52622 m .36951 .53116 L .36665 .52701 L F
.36951 .53116 m .36947 .53117 L .36665 .52701 L F
.3695 .53123 m .3694 .53126 L .36665 .52701 L F
.859 .709 .696 r
.36665 .52701 m .3694 .53126 L .36618 .5293 L F
.3694 .53126 m .36935 .53132 L .36618 .5293 L F
.184 0 .015 r
.3695 .53142 m .36911 .53192 L .36822 .53233 L F
.467 .082 .225 r
.36918 .53147 m .36785 .53357 L .36865 .53338 L F
.36937 .53167 m .36865 .53338 L .37065 .53293 L F
.36918 .53147 m .36865 .53338 L .36937 .53167 L F
.184 0 .015 r
.36911 .53192 m .36785 .53357 L .36819 .53243 L F
.36911 .53192 m .36819 .53243 L .36822 .53233 L F
.3695 .53142 m .36822 .53233 L .36832 .53191 L F
.3695 .53142 m .36832 .53191 L .36932 .5314 L F
.467 .082 .225 r
.36832 .53191 m .36785 .53357 L .36918 .53147 L F
.909 .804 .33 r
.36962 .52622 m .36882 .53241 L .36934 .53165 L F
.859 .709 .696 r
.3694 .53126 m .3695 .53142 L .36935 .53132 L F
.909 .804 .33 r
.3695 .53123 m .36942 .53153 L .3695 .53142 L F
.743 .907 .529 r
.3689 .53173 m .36785 .53357 L .3695 .53142 L F
.36869 .53184 m .36818 .53288 L .3689 .53173 L F
.36818 .53288 m .36785 .53357 L .3689 .53173 L F
.467 .082 .225 r
.36954 .5311 m .36945 .53174 L .3697 .5309 L F
.909 .804 .33 r
.3695 .53123 m .3695 .53142 L .3694 .53126 L F
.467 .082 .225 r
.3692 .5315 m .36938 .53168 L .36954 .5311 L F
.743 .907 .529 r
.36947 .53142 m .3695 .53142 L .36944 .53151 L F
.467 .082 .225 r
.36938 .53168 m .36945 .53174 L .36951 .5313 L F
.36942 .53153 m .36951 .5313 L .36954 .5311 L F
.909 .804 .33 r
.36942 .53146 m .36934 .53165 L .36942 .53153 L F
.743 .907 .529 r
.36947 .53142 m .36944 .53151 L .36882 .53241 L F
.467 .082 .225 r
.36938 .53168 m .36951 .5313 L .36942 .53153 L F
.909 .804 .33 r
.3694 .53147 m .36934 .53165 L .36942 .53146 L F
.624 .479 .665 r
.36903 .53166 m .36882 .53241 L .3689 .53173 L F
.909 .804 .33 r
.36943 .5314 m .3694 .53147 L .36942 .53146 L F
.743 .907 .529 r
.36889 .53144 m .36869 .53184 L .3695 .53142 L F
.36889 .53144 m .36909 .53143 L .36882 .53241 L F
.36909 .53143 m .36947 .53142 L .36882 .53241 L F
.909 .804 .33 r
.36962 .52622 m .36934 .53165 L .36943 .5314 L F
.372 0 .187 r
.37041 .53091 m .37149 .5306 L .37231 .52857 L F
.909 .804 .33 r
.36951 .53116 m .3695 .53123 L .36947 .53117 L F
.36962 .52622 m .36942 .53153 L .3695 .53123 L F
.467 .082 .225 r
.3697 .5309 m .36945 .53174 L .37096 .53091 L F
.36945 .53174 m .37065 .53293 L .37096 .53091 L F
0 0 0 r
.37137 .53091 m .37461 .52719 L .37231 .52857 L F
.37137 .53091 m .37269 .52964 L .37461 .52719 L F
.624 .479 .665 r
.37124 .52801 m .3689 .53173 L .36962 .52622 L F
.467 .082 .225 r
.36956 .53101 m .36954 .5311 L .3697 .5309 L F
.624 .479 .665 r
.37269 .52964 m .3689 .53173 L .37124 .52801 L F
0 0 0 r
.36848 .53387 m .36785 .53357 L .37065 .53293 L F
.37137 .53091 m .37132 .53136 L .37269 .52964 L F
.822 1 .811 r
.37132 .53136 m .36973 .53203 L .37269 .52964 L F
.36973 .53203 m .36882 .53241 L .36987 .53166 L F
.372 0 .187 r
.37041 .53091 m .37137 .53091 L .37149 .5306 L F
.822 1 .811 r
.36973 .53203 m .36987 .53166 L .37269 .52964 L F
.624 .479 .665 r
.3698 .53124 m .36889 .53232 L .36903 .53166 L F
.36889 .53232 m .36882 .53241 L .36884 .53232 L F
.36889 .53232 m .36884 .53232 L .36903 .53166 L F
.822 1 .811 r
.36919 .53226 m .36889 .53144 L .36882 .53241 L F
.624 .479 .665 r
.37269 .52964 m .36987 .53166 L .3698 .53124 L F
.36987 .53166 m .36882 .53241 L .3698 .53124 L F
.822 1 .811 r
.37132 .53136 m .36889 .53144 L .36919 .53226 L F
.37054 .53138 m .371 .53094 L .36889 .53144 L F
.37132 .53136 m .371 .53094 L .37054 .53138 L F
0 0 0 r
.37137 .53091 m .37065 .53293 L .37132 .53136 L F
.822 1 .811 r
.37132 .53136 m .37065 .53293 L .371 .53094 L F
.545 .253 .422 r
.37269 .52964 m .37132 .53136 L .37564 .52901 L F
.37564 .52901 m .37132 .53136 L .37269 .52964 L F
.179 .117 .545 r
.37069 .53321 m .37191 .53005 L .371 .53094 L F
.37191 .53005 m .37218 .52937 L .371 .53094 L F
.469 .736 .985 r
.371 .53094 m .37074 .53241 L .36889 .53144 L F
.37074 .53241 m .37065 .53293 L .36999 .53238 L F
.37074 .53241 m .36999 .53238 L .36889 .53144 L F
0 0 0 r
.36848 .53387 m .36913 .53359 L .36889 .53144 L F
.36913 .53359 m .37013 .53315 L .36959 .5324 L F
.36913 .53359 m .36959 .5324 L .36889 .53144 L F
.37013 .53315 m .37065 .53293 L .36999 .53238 L F
.37013 .53315 m .36999 .53238 L .36889 .53144 L F
.184 0 .015 r
.36822 .53233 m .36547 .53427 L .36846 .53129 L F
.735 .736 .216 r
.36765 .53477 m .36768 .53455 L .36789 .53373 L F
.184 0 .015 r
.36857 .53083 m .36416 .53073 L .36618 .5293 L F
.36846 .53129 m .36416 .53073 L .36857 .53083 L F
.669 .814 .373 r
.36889 .53144 m .36833 .5325 L .36785 .53357 L F
.015 .522 .866 r
.36442 .53425 m .36547 .53427 L .36752 .5355 L F
.382 0 .104 r
.36785 .53357 m .36676 .53547 L .36401 .53566 L F
.36785 .53357 m .36676 .53547 L .36401 .53566 L F
.669 .814 .373 r
.36833 .5325 m .36676 .53547 L .36785 .53357 L F
.382 0 .104 r
.36785 .53357 m .36653 .53428 L .36547 .53427 L F
.36653 .53428 m .36401 .53566 L .36547 .53427 L F
.015 .522 .866 r
.36351 .53389 m .36547 .53427 L .36442 .53425 L F
0 .118 .667 r
.26502 .62253 m .26477 .62327 L .26349 .62203 L F
0 0 0 r
.70451 .28507 m .70565 .28486 L .7069 .28267 L F
0 0 .116 r
.31407 .57647 m .31539 .57568 L .31626 .57331 L F
.082 .046 .514 r
.31407 .57647 m .31548 .57838 L .31539 .57568 L F
0 0 .367 r
.3092 .52224 m .31027 .52532 L .30927 .52096 L F
.757 .678 .774 r
.56786 .42089 m .56516 .424 L .56379 .42018 L F
.642 .345 .451 r
.57866 .45585 m .57862 .45807 L .57475 .45806 L F
.608 .31 .439 r
.58134 .45586 m .57862 .45807 L .57866 .45585 L F
.338 0 0 r
.30794 .50928 m .31096 .51003 L .31235 .50995 L F
.835 .987 .716 r
.31035 .51121 m .3098 .51325 L .31235 .50995 L F
.657 .969 .903 r
.31235 .50995 m .31096 .51003 L .31322 .50847 L F
.684 .954 .701 r
.31035 .51121 m .31235 .50995 L .31322 .50847 L F
0 .163 .693 r
.34755 .65148 m .34689 .65291 L .34899 .65503 L F
.313 .156 .501 r
.3051 .639 m .30368 .63707 L .30368 .63598 L F
.3051 .639 m .30356 .63998 L .30368 .63707 L F
.549 .586 .844 r
.44411 .54363 m .44317 .54728 L .44176 .54424 L F
.44411 .54363 m .44578 .54724 L .44317 .54728 L F
.568 .907 .679 r
.20616 .60292 m .20743 .6015 L .20966 .60462 L F
.986 .709 .36 r
.35477 .67855 m .35496 .67499 L .35406 .67533 L F
.403 .775 .993 r
.35564 .6737 m .35496 .67499 L .35732 .67468 L F
.657 .951 .723 r
.35406 .67533 m .35496 .67499 L .35564 .6737 L F
.454 .203 .442 r
.35732 .67468 m .35496 .67499 L .35477 .67855 L F
.633 .326 .434 r
.32063 .56939 m .31829 .56715 L .3182 .5699 L F
.32063 .56939 m .32087 .56717 L .31829 .56715 L F
.6 .533 .752 r
.25818 .53493 m .26178 .53827 L .26091 .53434 L F
0 .368 .742 r
.2405 .62252 m .2413 .62259 L .23881 .62109 L F
.2405 .62252 m .24311 .62359 L .2413 .62259 L F
.789 .843 .893 r
.33828 .51419 m .33604 .51535 L .33958 .51601 L F
.749 .269 .103 r
.33918 .51594 m .33746 .5172 L .33604 .51535 L F
.388 .232 .545 r
.33746 .5172 m .33546 .51801 L .33604 .51535 L F
.33746 .5172 m .33546 .51801 L .33604 .51535 L F
.824 .42 .282 r
.33546 .51801 m .33495 .52132 L .33274 .51729 L F
.897 .707 .198 r
.33448 .5197 m .33495 .52132 L .33546 .51801 L F
.33462 .51958 m .33546 .51801 L .33746 .5172 L F
.33448 .5197 m .33454 .5196 L .33462 .51958 L F
.33454 .5196 m .33546 .51801 L .33462 .51958 L F
.188 .384 .825 r
.33502 .51948 m .33697 .52046 L .33585 .5215 L F
.33486 .5191 m .33534 .51941 L .33502 .51948 L F
.33534 .51941 m .33697 .52046 L .33502 .51948 L F
.713 .94 .63 r
.33842 .51539 m .33529 .51881 L .33746 .5172 L F
.33529 .51881 m .33448 .5197 L .33746 .5172 L F
.749 .269 .103 r
.33958 .51601 m .33746 .5172 L .33918 .51594 L F
.036 0 0 r
.3428 .51353 m .34083 .51453 L .34099 .51429 L F
.3428 .51353 m .34099 .51429 L .34258 .51201 L F
.439 .503 .828 r
.34323 .51526 m .34481 .51283 L .34258 .51201 L F
.036 0 0 r
.3428 .51353 m .34258 .51201 L .34481 .51283 L F
0 0 0 r
.34508 .51277 m .3428 .51353 L .34481 .51283 L F
.34508 .51277 m .34448 .51282 L .3428 .51353 L F
.34258 .51201 m .34083 .51453 L .33959 .51599 L F
.862 .844 .825 r
.34258 .51201 m .34095 .51315 L .3448 .50832 L F
0 0 0 r
.34448 .51282 m .34049 .51315 L .3428 .51353 L F
.731 .989 .812 r
.34181 .51337 m .34083 .51453 L .3428 .51353 L F
.34049 .51315 m .34083 .51453 L .34181 .51337 L F
0 0 0 r
.33959 .51599 m .34083 .51453 L .33958 .51601 L F
.578 .913 .685 r
.34083 .51453 m .33746 .5172 L .33958 .51601 L F
.539 .655 .911 r
.39175 .50986 m .38785 .50726 L .39026 .5061 L F
.387 .788 .985 r
.33609 .66457 m .3374 .6638 L .33492 .66444 L F
.33609 .66457 m .33862 .66441 L .3374 .6638 L F
.599 .543 .763 r
.63754 .37632 m .63351 .37308 L .63751 .3737 L F
.87 .757 .736 r
.58854 .41328 m .59159 .41385 L .58973 .41696 L F
.414 .151 .404 r
.32218 .59724 m .32007 .59497 L .32241 .59449 L F
.32218 .59724 m .3201 .59784 L .32007 .59497 L F
.553 .273 .446 r
.28845 .53343 m .28557 .53613 L .28794 .53557 L F
.244 .053 .411 r
.20569 .56677 m .20738 .56628 L .20761 .5636 L F
0 0 .215 r
.2051 .57007 m .20738 .56628 L .20569 .56677 L F
.536 .588 .854 r
.37156 .60409 m .37158 .60606 L .36894 .60657 L F
.592 .46 .671 r
.37265 .60769 m .36894 .60657 L .37158 .60606 L F
.37265 .60769 m .36978 .60837 L .36894 .60657 L F
.501 .636 .914 r
.37057 .50908 m .37338 .51218 L .3718 .51104 L F
0 .262 .75 r
.37299 .51099 m .37338 .51218 L .3709 .50945 L F
.37299 .51099 m .3742 .51249 L .37338 .51218 L F
0 .181 .716 r
.37585 .51277 m .3742 .51249 L .37299 .51099 L F
.649 .112 0 r
.37096 .51068 m .37479 .51231 L .37299 .51099 L F
.37479 .51231 m .37585 .51277 L .37299 .51099 L F
0 .262 .75 r
.37299 .51099 m .3709 .50945 L .37057 .50908 L F
.666 .648 .822 r
.56937 .41373 m .56744 .41785 L .56569 .41441 L F
.56937 .41373 m .5703 .41767 L .56744 .41785 L F
.888 .903 .832 r
.5703 .41767 m .56657 .41959 L .56744 .41785 L F
.689 .981 .854 r
.34393 .66155 m .34818 .65932 L .34625 .65933 L F
.761 .872 .929 r
.34818 .65932 m .35012 .658 L .35013 .65744 L F
0 0 0 r
.34818 .65932 m .3494 .65863 L .34625 .65933 L F
.98 .916 .631 r
.40432 .60155 m .40538 .59919 L .40463 .59724 L F
.83 .983 .878 r
.69225 .30062 m .6944 .30033 L .69129 .30333 L F
.836 .988 .864 r
.69225 .30062 m .69129 .30333 L .68923 .30349 L F
.542 .888 .652 r
.29299 .6185 m .29404 .61736 L .29532 .61753 L F
.29299 .6185 m .29099 .61981 L .29404 .61736 L F
0 0 .485 r
.70496 .32887 m .70314 .32863 L .70231 .32671 L F
.70496 .32887 m .70385 .33124 L .70314 .32863 L F
.817 .69 .724 r
.65164 .3504 m .65306 .35406 L .6511 .35264 L F
.723 .517 .611 r
.65306 .35406 m .64887 .35641 L .6511 .35264 L F
.65306 .35406 m .65294 .35678 L .64887 .35641 L F
.513 .531 .812 r
.43443 .55713 m .43223 .55773 L .43113 .55513 L F
.186 .054 .457 r
.43388 .55936 m .43223 .55773 L .43443 .55713 L F
.43388 .55936 m .43231 .56069 L .43223 .55773 L F
.339 .656 .971 r
.58157 .39768 m .57995 .398 L .57884 .39612 L F
.591 .404 .597 r
.35949 .57931 m .35731 .58204 L .35722 .57974 L F
.098 .082 .549 r
.33632 .5555 m .33413 .55511 L .33656 .55319 L F
.33632 .5555 m .33508 .55706 L .33413 .55511 L F
.814 .767 .809 r
.42718 .57256 m .42877 .57603 L .43145 .57346 L F
.645 .801 .958 r
.42877 .57603 m .43292 .5751 L .43145 .57346 L F
0 0 0 r
.43292 .5751 m .43582 .57313 L .43145 .57346 L F
.96 .934 .716 r
.40155 .68665 m .39971 .69041 L .40138 .68853 L F
.967 .7 .272 r
.32762 .54015 m .32845 .54267 L .32698 .54037 L F
.951 .666 .218 r
.32845 .54267 m .32799 .54355 L .32698 .54037 L F
.375 0 0 r
.695 .33729 m .69822 .33737 L .69567 .33708 L F
.664 .648 .824 r
.64138 .39303 m .64427 .39237 L .64296 .39073 L F
0 0 0 r
.38488 .65014 m .38122 .65106 L .38474 .65003 L F
.388 .844 .777 r
.38444 .64981 m .38474 .65003 L .38283 .65088 L F
.38468 .64965 m .38474 .65003 L .38444 .64981 L F
0 0 0 r
.38593 .64987 m .38488 .65014 L .38474 .65003 L F
.574 .108 .109 r
.38891 .58543 m .3914 .58589 L .3875 .58619 L F
.741 .754 .863 r
.25674 .52959 m .26094 .52981 L .25876 .52916 L F
.328 0 0 r
.26289 .52811 m .25876 .52916 L .26094 .52981 L F
.343 .465 .839 r
.37451 .59875 m .37776 .60113 L .37627 .59744 L F
.519 .249 .445 r
.45876 .57349 m .45831 .57733 L .45481 .57715 L F
.504 .237 .442 r
.46128 .57508 m .45876 .57349 L .46136 .57241 L F
.46128 .57508 m .45831 .57733 L .45876 .57349 L F
.411 .768 .995 r
.69598 .32689 m .69939 .32774 L .69695 .32791 L F
.587 .022 0 r
.3742 .51249 m .37828 .51494 L .37634 .51411 L F
.3742 .51249 m .37628 .51429 L .37828 .51494 L F
.637 .075 0 r
.37769 .51593 m .37828 .51494 L .37628 .51429 L F
0 .039 .607 r
.37828 .51494 m .38059 .51739 L .3803 .518 L F
.637 .075 0 r
.37769 .51593 m .38059 .51739 L .37828 .51494 L F
.341 .248 .602 r
.32329 .56085 m .32529 .56272 L .32473 .56016 L F
.32329 .56085 m .32361 .56344 L .32529 .56272 L F
.802 .671 .719 r
.22916 .55995 m .23293 .55689 L .22958 .55766 L F
.12 .478 .897 r
.38356 .5951 m .38768 .59788 L .38686 .59476 L F
.517 .582 .859 r
.38768 .59788 m .38864 .59444 L .38686 .59476 L F
.38768 .59788 m .39038 .59754 L .38864 .59444 L F
.327 .804 .905 r
.72934 .336 m .72857 .3367 L .72702 .3337 L F
.72934 .336 m .73091 .33607 L .72857 .3367 L F
.439 .503 .828 r
.34323 .51526 m .34577 .51556 L .34481 .51283 L F
.458 .255 .516 r
.34323 .51526 m .34539 .51692 L .34577 .51556 L F
.34323 .51526 m .34306 .51837 L .34539 .51692 L F
.666 .647 .822 r
.42798 .49394 m .42452 .49073 L .42659 .49002 L F
.503 .438 .716 r
.42942 .48921 m .42798 .49394 L .42659 .49002 L F
.42942 .48921 m .43024 .49339 L .42798 .49394 L F
.454 .403 .711 r
.43042 .49537 m .42798 .49394 L .43024 .49339 L F
.43042 .49537 m .42872 .49637 L .42798 .49394 L F
.612 .956 .852 r
.24036 .53068 m .23909 .53091 L .24115 .52954 L F
0 0 .152 r
.6255 .41406 m .62756 .41016 L .62758 .41289 L F
0 0 .511 r
.627 .4151 m .6255 .41406 L .62758 .41289 L F
.627 .4151 m .62622 .41717 L .6255 .41406 L F
.288 .142 .502 r
.29085 .56388 m .29257 .56321 L .29275 .56048 L F
.76 .908 .522 r
.29068 .56652 m .29257 .56321 L .29085 .56388 L F
.528 .405 .656 r
.29257 .56321 m .29068 .56652 L .29085 .56388 L F
.564 .408 .628 r
.35922 .6236 m .35679 .62719 L .35718 .62427 L F
.35922 .6236 m .35679 .62719 L .35718 .62427 L F
0 0 .474 r
.60419 .41935 m .60469 .42038 L .60263 .41709 L F
0 .042 .555 r
.60816 .42392 m .60469 .42038 L .60686 .42265 L F
0 .052 .597 r
.60686 .42265 m .60469 .42038 L .60419 .41935 L F
.77 .946 .936 r
.27229 .5203 m .27486 .52072 L .2712 .52262 L F
.533 .895 .973 r
.27722 .51985 m .27486 .52072 L .27229 .5203 L F
.471 .098 .249 r
.58776 .45283 m .59033 .45415 L .58762 .45451 L F
.484 .07 .179 r
.59143 .452 m .59033 .45415 L .58776 .45283 L F
.928 .58 .349 r
.54059 .43331 m .54277 .43659 L .54093 .43547 L F
.957 .619 .308 r
.54277 .43659 m .54199 .43826 L .54093 .43547 L F
.54277 .43659 m .54373 .43952 L .54199 .43826 L F
.49 .33 .59 r
.24585 .5469 m .24312 .54499 L .24525 .54251 L F
.24585 .5469 m .24353 .54758 L .24312 .54499 L F
0 0 .363 r
.60944 .42989 m .61039 .42814 L .60817 .42951 L F
.42 .322 .637 r
.61158 .42673 m .60944 .42989 L .61129 .42983 L F
.977 .684 .392 r
.61024 .43148 m .60944 .42989 L .60817 .42951 L F
.61024 .43148 m .61129 .42983 L .60944 .42989 L F
.51 .298 .527 r
.32322 .62101 m .32315 .62369 L .3205 .62427 L F
.305 .136 .48 r
.32499 .62298 m .32322 .62101 L .32559 .62053 L F
.32499 .62298 m .32315 .62369 L .32322 .62101 L F
.847 .75 .756 r
.36665 .66865 m .36894 .66561 L .3661 .66415 L F
.36594 .66623 m .3661 .66415 L .36519 .66368 L F
.36665 .66865 m .3661 .66415 L .36594 .66623 L F
.892 .531 .353 r
.36519 .66368 m .3661 .66415 L .3662 .665 L F
.3661 .66415 m .36894 .66561 L .3662 .665 L F
0 0 .26 r
.3661 .66415 m .36587 .66273 L .3661 .66428 L F
.3663 .66173 m .36593 .66259 L .3661 .66415 L F
.36593 .66259 m .36587 .66273 L .3661 .66415 L F
.36659 .66105 m .3663 .66173 L .3662 .665 L F
.3663 .66173 m .3661 .66428 L .3662 .665 L F
.67 .484 .625 r
.36665 .66865 m .36914 .66869 L .36894 .66561 L F
.726 .905 .958 r
.3662 .665 m .36894 .66561 L .37149 .66326 L F
.64 .15 .071 r
.37064 .66752 m .36894 .66561 L .36914 .66869 L F
.54 .455 .708 r
.73566 .3398 m .73548 .34308 L .73315 .34396 L F
.193 0 .147 r
.73548 .34308 m .73289 .34624 L .73315 .34396 L F
.092 0 .17 r
.27843 .53846 m .28053 .53748 L .28112 .53505 L F
.194 0 .208 r
.28112 .53505 m .28219 .53673 L .28319 .53388 L F
.28112 .53505 m .28053 .53748 L .28219 .53673 L F
.555 .324 .521 r
.21968 .57212 m .21924 .57603 L .21671 .57341 L F
.764 .376 .318 r
.54565 .44565 m .54952 .44652 L .54984 .4483 L F
.721 .798 .912 r
.62706 .37334 m .62331 .37292 L .62548 .37161 L F
.729 .748 .867 r
.62838 .36889 m .62706 .37334 L .62548 .37161 L F
.62838 .36889 m .62943 .37254 L .62706 .37334 L F
.356 .132 .43 r
.41299 .51574 m .41508 .5153 L .41504 .51306 L F
.301 0 .267 r
.41299 .51574 m .41248 .51778 L .41508 .5153 L F
.356 .132 .43 r
.41299 .51574 m .41508 .5153 L .41504 .51306 L F
.301 0 .267 r
.41299 .51574 m .41248 .51778 L .41508 .5153 L F
.318 .772 .954 r
.32719 .51385 m .33159 .51221 L .32949 .51297 L F
.159 .037 .453 r
.33142 .51401 m .32949 .51297 L .33159 .51221 L F
.33142 .51401 m .32946 .51558 L .32949 .51297 L F
.845 .501 .402 r
.60668 .42696 m .61039 .42814 L .60816 .42392 L F
.349 .539 .899 r
.61059 .42395 m .60816 .42392 L .60947 .42196 L F
.289 .457 .854 r
.60816 .42392 m .6113 .4254 L .60947 .42196 L F
0 0 0 r
.33623 .6771 m .33506 .6769 L .33265 .67961 L F
.042 0 .27 r
.35504 .60176 m .35304 .60526 L .35443 .60457 L F
.863 .924 .867 r
.3057 .51531 m .3098 .51325 L .30832 .51291 L F
.754 .963 .934 r
.30832 .51291 m .3098 .51325 L .31035 .51121 L F
.806 .578 .592 r
.42512 .57319 m .42877 .57603 L .42718 .57256 L F
.42512 .57319 m .42755 .57675 L .42877 .57603 L F
.891 .817 .768 r
.42554 .5783 m .42877 .57603 L .42755 .57675 L F
.42554 .5783 m .42671 .5802 L .42791 .57779 L F
.42554 .5783 m .42791 .57779 L .42759 .57687 L F
0 0 .543 r
.42689 .57528 m .42755 .57675 L .42526 .57339 L F
.42689 .57528 m .42526 .57339 L .42512 .57319 L F
.891 .817 .768 r
.42759 .57687 m .42791 .57779 L .42877 .57603 L F
0 .076 .59 r
.42898 .57746 m .42881 .57752 L .42689 .57528 L F
.891 .817 .768 r
.42554 .5783 m .42755 .57675 L .4276 .578 L F
.811 .51 0 r
.42689 .57528 m .4276 .578 L .42755 .57676 L F
.42755 .57674 m .42755 .57676 L .42755 .57675 L F
.42689 .57528 m .42755 .57676 L .42755 .57674 L F
0 .076 .59 r
.42881 .57752 m .4276 .578 L .42689 .57528 L F
.58 .242 .362 r
.43559 .58911 m .43177 .59171 L .43185 .58897 L F
.43559 .58911 m .43452 .59184 L .43177 .59171 L F
.43 .095 .295 r
.43712 .59118 m .43559 .58911 L .43828 .58883 L F
.43712 .59118 m .43452 .59184 L .43559 .58911 L F
.953 .944 .727 r
.69633 .2967 m .69459 .29705 L .69553 .2957 L F
.69633 .2967 m .6944 .30033 L .69459 .29705 L F
.901 .972 .812 r
.69883 .2934 m .69633 .2967 L .69553 .2957 L F
.615 .597 .81 r
.59006 .43573 m .58853 .43899 L .58733 .43844 L F
.59006 .43573 m .59144 .43957 L .58853 .43899 L F
0 .096 .646 r
.60048 .40101 m .60226 .40207 L .59889 .40024 L F
.60048 .40101 m .60283 .40348 L .60226 .40207 L F
0 0 0 r
.37643 .62949 m .37575 .63083 L .37498 .63355 L F
.592 .196 .26 r
.59419 .45216 m .59033 .45415 L .59143 .452 L F
.37 .15 .444 r
.28707 .63705 m .28956 .63385 L .28913 .63635 L F
.319 .168 .513 r
.28888 .639 m .28707 .63705 L .28913 .63635 L F
.28888 .639 m .28704 .63964 L .28707 .63705 L F
.357 .193 .517 r
.32763 .60821 m .32942 .60785 L .32951 .60493 L F
0 0 .352 r
.32763 .60821 m .32852 .61012 L .32942 .60785 L F
.32763 .60821 m .32755 .61098 L .32852 .61012 L F
.515 .173 .325 r
.26225 .57028 m .26428 .57201 L .26172 .57213 L F
0 .059 .624 r
.38681 .7094 m .38697 .70603 L .38566 .71047 L F
.177 .7 .873 r
.35279 .51271 m .3515 .51231 L .34937 .5124 L F
.436 .867 .925 r
.35196 .51432 m .35279 .51271 L .34937 .5124 L F
.544 .139 .223 r
.35279 .51271 m .35196 .51432 L .3515 .51231 L F
.35279 .51271 m .35556 .51342 L .35196 .51432 L F
.918 .973 .691 r
.33897 .68674 m .33915 .68837 L .34069 .68539 L F
.925 .919 .537 r
.33815 .69085 m .33915 .68837 L .33897 .68674 L F
.591 .6 .83 r
.3205 .54152 m .31787 .53816 L .3225 .53709 L F
0 0 .299 r
.3226 .53441 m .32304 .53754 L .3225 .53709 L F
.679 .79 .322 r
.32114 .53996 m .3205 .54152 L .3225 .53709 L F
0 0 0 r
.32493 .53624 m .32365 .53718 L .32304 .53754 L F
.679 .79 .322 r
.32114 .53996 m .32199 .53816 L .32304 .53754 L F
.883 .99 .8 r
.3217 .5386 m .32114 .53996 L .32304 .53754 L F
0 0 0 r
.32365 .53718 m .3217 .5386 L .32304 .53754 L F
.679 .79 .322 r
.32199 .53816 m .3225 .53709 L .32304 .53754 L F
.696 .291 0 r
.40968 .54439 m .40879 .54315 L .40769 .54094 L F
.948 .667 .215 r
.41013 .54723 m .40879 .54315 L .40968 .54439 L F
.666 .322 .381 r
.60716 .4515 m .60352 .44974 L .60726 .44917 L F
.60716 .4515 m .60331 .45164 L .60352 .44974 L F
.354 .113 .404 r
.28448 .55911 m .2829 .55743 L .28574 .55749 L F
.28448 .55911 m .2823 .55991 L .2829 .55743 L F
.638 .713 .901 r
.41998 .49237 m .42158 .49425 L .41759 .49332 L F
.768 .748 .835 r
.42452 .49073 m .42158 .49425 L .41998 .49237 L F
.871 .765 .742 r
.68309 .3434 m .68633 .34414 L .68524 .34017 L F
.886 .717 .667 r
.6847 .34735 m .68633 .34414 L .68309 .3434 L F
.879 .885 .834 r
.22644 .56579 m .22389 .56902 L .22789 .56762 L F
.639 .432 .586 r
.22389 .56902 m .22638 .57144 L .22789 .56762 L F
0 0 .451 r
.22789 .56762 m .22884 .56523 L .22644 .56579 L F
.22789 .56762 m .22915 .56732 L .22884 .56523 L F
0 .405 .712 r
.29173 .61669 m .29404 .61736 L .28938 .61596 L F
.794 .861 .9 r
.64795 .36113 m .6435 .36253 L .64634 .35926 L F
.756 .746 .843 r
.64634 .35926 m .65011 .35999 L .64795 .36113 L F
.156 .324 .782 r
.61662 .44588 m .61943 .44791 L .61775 .44419 L F
.901 .972 .812 r
.69883 .2934 m .69553 .2957 L .69707 .29366 L F
.657 .9 .567 r
.70033 .29117 m .70147 .29021 L .69883 .2934 L F
.714 .986 .828 r
.70033 .29117 m .69883 .2934 L .69707 .29366 L F
.371 0 0 r
.41697 .50736 m .41646 .50771 L .41336 .50753 L F
.556 .699 .936 r
.41336 .50753 m .41646 .50771 L .41469 .5046 L F
.458 .832 .59 r
.41697 .50736 m .41627 .50786 L .41646 .50771 L F
.371 0 0 r
.41697 .50736 m .41717 .50775 L .41646 .50771 L F
.556 .699 .936 r
.41646 .50771 m .41717 .50775 L .41688 .50738 L F
.41646 .50771 m .41688 .50738 L .41469 .5046 L F
.458 .832 .59 r
.41646 .50771 m .4157 .50828 L .41614 .50794 L F
.41627 .50786 m .4157 .50828 L .41646 .50771 L F
0 0 .156 r
.41838 .50324 m .41697 .50736 L .41822 .50524 L F
.41838 .50324 m .41737 .50701 L .41697 .50736 L F
.41737 .50701 m .41717 .50775 L .41697 .50736 L F
.806 .783 .832 r
.41469 .5046 m .41688 .50738 L .41838 .50324 L F
.41688 .50738 m .41717 .50775 L .41737 .50701 L F
.41688 .50738 m .41737 .50701 L .41838 .50324 L F
.458 .832 .59 r
.41697 .50736 m .41894 .50578 L .41822 .50524 L F
.41737 .50701 m .41614 .50794 L .41756 .50684 L F
.41697 .50736 m .41627 .50785 L .41737 .50701 L F
.41627 .50785 m .41614 .50794 L .41737 .50701 L F
.41697 .50736 m .41756 .50684 L .41894 .50578 L F
.8 .784 .838 r
.69045 .33377 m .69222 .33617 L .6942 .33365 L F
.958 .767 .603 r
.69172 .33759 m .69222 .33617 L .69045 .33377 L F
.346 0 0 r
.695 .33729 m .69222 .33617 L .69172 .33759 L F
.672 .975 .833 r
.30595 .51047 m .30343 .51194 L .30437 .51183 L F
0 0 0 r
.30515 .51199 m .30595 .51047 L .30437 .51183 L F
.064 .385 .847 r
.30501 .51176 m .30437 .51183 L .30391 .50987 L F
.30515 .51199 m .30437 .51183 L .30501 .51176 L F
.672 .975 .833 r
.30343 .51194 m .30196 .51281 L .30437 .51183 L F
0 0 0 r
.30515 .51199 m .30794 .50928 L .30595 .51047 L F
.67 .235 .208 r
.32616 .58829 m .3274 .59099 L .32482 .59113 L F
.32616 .58829 m .32867 .58935 L .3274 .59099 L F
.188 .082 .493 r
.31273 .54438 m .3124 .54703 L .3109 .54793 L F
.412 .31 .628 r
.3124 .54703 m .31074 .55064 L .3109 .54793 L F
.739 .666 .779 r
.37606 .60805 m .37751 .61162 L .37931 .60767 L F
.974 .729 .505 r
.3748 .61033 m .37751 .61162 L .37606 .60805 L F
.007 .512 .864 r
.59392 .4086 m .59359 .40903 L .59208 .40732 L F
.384 .187 .485 r
.31068 .60871 m .30946 .61169 L .3077 .61258 L F
.417 .301 .613 r
.30964 .61314 m .3077 .61258 L .30946 .61169 L F
.30964 .61314 m .3078 .61417 L .3077 .61258 L F
.203 .094 .5 r
.27864 .54116 m .28053 .53748 L .27843 .53846 L F
.53 .388 .632 r
.44804 .55406 m .4474 .55746 L .44543 .55772 L F
.648 .416 .554 r
.44819 .55999 m .44543 .55772 L .4474 .55746 L F
.44819 .55999 m .4456 .56027 L .44543 .55772 L F
0 0 .289 r
.29987 .52819 m .30077 .53016 L .30111 .52853 L F
.904 .983 .727 r
.68559 .31166 m .68498 .31073 L .68683 .30956 L F
.9 .892 .813 r
.68559 .31166 m .6819 .31355 L .68498 .31073 L F
.68559 .31166 m .68313 .3152 L .6819 .31355 L F
.481 .339 .61 r
.3085 .53869 m .31087 .53836 L .31085 .53516 L F
.724 .978 .917 r
.34249 .63657 m .34083 .63796 L .33959 .63861 L F
0 .053 .607 r
.42742 .58045 m .42671 .5802 L .42554 .5783 L F
.894 .774 .722 r
.38813 .62118 m .38777 .62461 L .38524 .62317 L F
.898 .769 .711 r
.38524 .62317 m .38777 .62461 L .38635 .62648 L F
.659 .279 0 r
.33194 .56042 m .3331 .56278 L .33323 .56293 L F
.713 .593 .72 r
.33425 .56556 m .33361 .56917 L .33257 .56505 L F
.33595 .56608 m .33499 .56736 L .33425 .56556 L F
.33499 .56736 m .33361 .56917 L .33425 .56556 L F
.509 0 0 r
.3332 .56304 m .33323 .56293 L .3331 .56278 L F
.33445 .56621 m .33595 .56608 L .33257 .56505 L F
.33445 .56621 m .33257 .56505 L .33323 .56293 L F
.33445 .56621 m .33384 .56459 L .3332 .56304 L F
.33384 .56459 m .33323 .56293 L .3332 .56304 L F
.928 .88 .767 r
.68313 .3152 m .67978 .31717 L .6819 .31355 L F
.68313 .3152 m .68104 .31864 L .67978 .31717 L F
.405 .053 .25 r
.29235 .63107 m .29388 .63253 L .2915 .63308 L F
.29235 .63107 m .29476 .63068 L .29388 .63253 L F
.754 .994 .865 r
.37689 .64305 m .38107 .64073 L .37904 .63938 L F
.829 .83 .847 r
.37904 .63938 m .38107 .64073 L .3827 .63879 L F
.474 .632 .923 r
.333 .6996 m .33421 .70127 L .33523 .69942 L F
.205 .221 .656 r
.33421 .70127 m .33623 .70074 L .33523 .69942 L F
.33421 .70127 m .3347 .70365 L .33623 .70074 L F
.527 .415 .67 r
.38002 .54999 m .38059 .55349 L .37821 .5511 L F
.166 .7 .708 r
.3205 .62427 m .32072 .62417 L .31843 .62512 L F
.3205 .62427 m .32315 .62369 L .32072 .62417 L F
.128 0 .091 r
.24929 .55809 m .24761 .55651 L .24996 .55558 L F
.24929 .55809 m .24725 .55913 L .24761 .55651 L F
.645 .543 .724 r
.32266 .54455 m .31947 .54494 L .31907 .54197 L F
.607 .405 .582 r
.32266 .54455 m .31976 .54733 L .31947 .54494 L F
.651 .241 .253 r
.34036 .69281 m .34228 .69093 L .33815 .69085 L F
.722 .19 0 r
.34267 .69249 m .34228 .69093 L .34036 .69281 L F
.469 .291 .556 r
.33815 .69085 m .33808 .69315 L .34036 .69281 L F
.33808 .69315 m .33805 .69381 L .34036 .69281 L F
.343 .784 .962 r
.34252 .69248 m .34036 .69281 L .33869 .69221 L F
.34267 .69249 m .34036 .69281 L .34252 .69248 L F
.169 0 .023 r
.34036 .69281 m .33805 .69381 L .33716 .69577 L F
.34036 .69281 m .3383 .6947 L .33869 .69221 L F
.34036 .69281 m .33919 .69389 L .3383 .6947 L F
.33919 .69389 m .33716 .69577 L .3383 .6947 L F
.719 .304 .259 r
.33716 .69577 m .33805 .69381 L .33386 .69323 L F
.33716 .69577 m .33386 .69323 L .33392 .69602 L F
.632 .764 .942 r
.3335 .69788 m .33523 .69942 L .33817 .69823 L F
.3335 .69788 m .33817 .69823 L .33716 .69577 L F
.677 .13 0 r
.33817 .69823 m .3383 .6947 L .33716 .69577 L F
.632 .764 .942 r
.3335 .69788 m .33716 .69577 L .33392 .69602 L F
.98 .892 .662 r
.3383 .6947 m .33709 .69825 L .33652 .69573 L F
.011 0 0 r
.33749 .69543 m .3383 .6947 L .33652 .69573 L F
.677 .13 0 r
.33817 .69823 m .33709 .69825 L .3383 .6947 L F
.011 0 0 r
.33988 .6947 m .3383 .6947 L .33749 .69543 L F
.605 .1 .025 r
.34092 .6939 m .34267 .69249 L .33869 .69221 L F
.491 .838 .566 r
.34193 .69304 m .34267 .69249 L .34092 .6939 L F
.722 .19 0 r
.34267 .69249 m .34335 .69199 L .34228 .69093 L F
.691 .379 .443 r
.34484 .69346 m .34512 .69129 L .34228 .69093 L F
.491 .838 .566 r
.34388 .69137 m .34267 .69249 L .34193 .69304 L F
.722 .19 0 r
.34267 .69249 m .34484 .69346 L .34335 .69199 L F
.717 .74 .87 r
.63237 .36944 m .62943 .37254 L .62838 .36889 L F
.464 .266 .526 r
.41812 .50954 m .41504 .51306 L .41538 .51109 L F
.41812 .50954 m .41778 .51227 L .41504 .51306 L F
.43 .187 .442 r
.41504 .51306 m .41508 .5153 L .41778 .51227 L F
.464 .266 .526 r
.41504 .51306 m .41778 .51227 L .41812 .50954 L F
.43 .187 .442 r
.41504 .51306 m .41508 .5153 L .41778 .51227 L F
.535 .518 .784 r
.35169 .65873 m .35556 .65541 L .35295 .65653 L F
.35169 .65873 m .35563 .65839 L .35556 .65541 L F
.628 .778 .953 r
.3968 .50356 m .39046 .50309 L .39537 .50172 L F
.561 .718 .946 r
.39788 .5015 m .3968 .50356 L .39537 .50172 L F
.836 .713 .728 r
.38361 .55317 m .38186 .55732 L .38059 .55349 L F
.614 .141 .107 r
.38059 .55349 m .38209 .55511 L .38361 .55317 L F
.793 .901 .495 r
.38361 .55317 m .38209 .55511 L .38404 .55133 L F
.757 .678 .774 r
.56786 .42089 m .56379 .42018 L .56657 .41959 L F
.888 .903 .832 r
.5703 .41767 m .56786 .42089 L .56657 .41959 L F
.397 .211 .508 r
.30542 .6175 m .30487 .62145 L .30308 .62117 L F
.327 .427 .812 r
.30487 .62145 m .30576 .62276 L .30308 .62117 L F
.513 .874 .984 r
.28841 .51774 m .2899 .51835 L .2876 .51912 L F
.513 .873 .984 r
.28841 .51774 m .2876 .51912 L .28592 .51854 L F
.866 .956 .864 r
.54307 .41324 m .54012 .41683 L .53902 .41582 L F
.192 .636 .945 r
.53902 .41582 m .54012 .41683 L .54307 .41704 L F
.815 .513 .479 r
.5864 .40855 m .58471 .41037 L .58529 .40825 L F
.5864 .40855 m .58841 .41089 L .58471 .41037 L F
.51 .246 .45 r
.28486 .61527 m .28745 .61478 L .28825 .61135 L F
.342 .096 .388 r
.28825 .61135 m .28953 .61397 L .289 .61135 L F
.28825 .61135 m .28745 .61478 L .28953 .61397 L F
.578 .076 .027 r
.70206 .30633 m .70038 .30764 L .70196 .30712 L F
0 0 0 r
.70406 .30433 m .70206 .30633 L .70449 .30306 L F
.755 .607 .693 r
.70406 .30433 m .70038 .30764 L .70206 .30633 L F
.581 .619 .855 r
.53618 .41976 m .53519 .42386 L .53399 .42242 L F
.53618 .41976 m .53945 .42422 L .53519 .42386 L F
.6 .028 0 r
.53519 .42386 m .53425 .42437 L .53399 .42242 L F
.53519 .42386 m .53769 .42569 L .53425 .42437 L F
.593 .254 .365 r
.53519 .42386 m .53945 .42422 L .53769 .42569 L F
.293 0 .142 r
.3002 .62597 m .30351 .62338 L .30208 .6262 L F
.22 0 .084 r
.30208 .6262 m .30351 .62338 L .30576 .62276 L F
.346 .604 .944 r
.26861 .63243 m .2695 .63392 L .2704 .63226 L F
.206 .424 .853 r
.2695 .63392 m .27284 .63595 L .2704 .63226 L F
.647 .094 0 r
.35511 .53364 m .35314 .53169 L .35373 .5341 L F
.222 .156 .567 r
.35481 .53119 m .35373 .5341 L .35314 .53169 L F
0 0 0 r
.73912 .32725 m .74137 .32643 L .74222 .32556 L F
.333 0 0 r
.74222 .32556 m .74137 .32643 L .74282 .32617 L F
.797 .676 .731 r
.64887 .35641 m .65011 .35999 L .64634 .35926 L F
.712 .633 .767 r
.65294 .35678 m .65011 .35999 L .64887 .35641 L F
.642 .085 0 r
.42783 .5911 m .42815 .59239 L .42758 .59171 L F
.387 .138 .409 r
.42615 .59218 m .42796 .59076 L .42783 .5911 L F
.384 .799 .595 r
.42783 .5911 m .42567 .59249 L .42615 .59218 L F
0 0 0 r
.42449 .59394 m .42567 .59249 L .42783 .5911 L F
.42449 .59394 m .42783 .5911 L .42626 .59016 L F
.642 .085 0 r
.42783 .5911 m .42758 .59171 L .42626 .59016 L F
.387 .138 .409 r
.42796 .59076 m .42938 .58966 L .42783 .5911 L F
.499 .905 .811 r
.28234 .52531 m .28254 .5259 L .28487 .52481 L F
.28234 .52531 m .28033 .5265 L .28254 .5259 L F
.682 .85 .963 r
.35395 .54028 m .35874 .54041 L .35677 .53769 L F
0 0 0 r
.35479 .54391 m .3568 .54313 L .35874 .54041 L F
.358 .52 .881 r
.35874 .54041 m .35805 .53854 L .35677 .53769 L F
.35874 .54041 m .36097 .54037 L .35805 .53854 L F
.076 0 0 r
.35874 .54041 m .35886 .54205 L .36097 .54037 L F
.35874 .54041 m .3568 .54313 L .35886 .54205 L F
0 .376 .808 r
.61974 .44944 m .62165 .44973 L .61943 .44791 L F
.61974 .44944 m .62288 .45089 L .62165 .44973 L F
.149 .451 .881 r
.70597 .30944 m .70968 .31257 L .70612 .31149 L F
.807 .402 .283 r
.70612 .31149 m .70968 .31257 L .70908 .31407 L F
.36 .02 .246 r
.70968 .31257 m .71167 .31363 L .70908 .31407 L F
.70968 .31257 m .71244 .31176 L .71167 .31363 L F
.611 .52 .727 r
.55373 .42356 m .55129 .42594 L .55083 .42035 L F
.565 0 0 r
.35073 .56677 m .34628 .56381 L .34806 .56689 L F
0 0 0 r
.34806 .56689 m .34851 .56801 L .35073 .56677 L F
.452 .171 .395 r
.34749 .69118 m .34512 .69129 L .34484 .69346 L F
.526 .521 .794 r
.44926 .5503 m .44698 .55112 L .44578 .54724 L F
.421 .239 .527 r
.44926 .5503 m .44895 .55328 L .44698 .55112 L F
.121 .184 .656 r
.44698 .55112 m .44895 .55328 L .44804 .55406 L F
.738 .678 .792 r
.32558 .6336 m .32403 .63557 L .32246 .63421 L F
.486 .131 .289 r
.29824 .6429 m .29938 .64565 L .29667 .64566 L F
.29824 .6429 m .30061 .64265 L .29938 .64565 L F
0 .405 .834 r
.36465 .50537 m .36459 .50621 L .36268 .50529 L F
.36465 .50537 m .36824 .50781 L .36459 .50621 L F
.687 .848 .43 r
.3182 .5699 m .31626 .57331 L .31788 .57247 L F
.088 0 .187 r
.31626 .57331 m .31539 .57568 L .31788 .57247 L F
0 0 0 r
.30442 .54826 m .30334 .55034 L .30545 .54698 L F
.497 .334 .589 r
.63289 .41575 m .63305 .41781 L .63588 .41621 L F
.597 .486 .698 r
.43185 .49966 m .42872 .49637 L .43042 .49537 L F
.43185 .49966 m .42924 .5004 L .42872 .49637 L F
.416 .143 .39 r
.32381 .56641 m .32087 .56717 L .32063 .56939 L F
0 .125 .625 r
.38391 .5477 m .38431 .54784 L .38143 .5454 L F
.38143 .5454 m .38431 .54784 L .38391 .5477 L F
.534 .604 .869 r
.34753 .51607 m .34964 .51918 L .34731 .51997 L F
.634 .608 .807 r
.61934 .37212 m .62331 .37292 L .62063 .37422 L F
.832 .979 .684 r
.29759 .52193 m .30024 .51837 L .29948 .51829 L F
0 .069 .632 r
.2369 .62078 m .23728 .61991 L .23508 .61733 L F
.11 .558 .916 r
.2369 .62078 m .23881 .62109 L .23728 .61991 L F
.551 .802 .992 r
.32719 .51385 m .32664 .51606 L .32946 .51558 L F
.563 .357 .559 r
.32946 .51558 m .32664 .51867 L .32664 .51606 L F
.171 .451 .879 r
.36175 .50322 m .35998 .50431 L .35865 .50243 L F
.36175 .50322 m .36268 .50529 L .35998 .50431 L F
0 0 .198 r
.42767 .53335 m .43001 .53285 L .42831 .53588 L F
.47 0 0 r
.35387 .63556 m .35551 .6339 L .35294 .63402 L F
.656 .17 .083 r
.35789 .63587 m .35551 .6339 L .35387 .63556 L F
.3 .08 .403 r
.28913 .63635 m .28956 .63385 L .2915 .63308 L F
.557 .862 .559 r
.70327 .28823 m .70147 .29021 L .70033 .29117 L F
.851 .744 .745 r
.31787 .53816 m .31907 .54197 L .31719 .54056 L F
.591 .6 .83 r
.3205 .54152 m .31907 .54197 L .31787 .53816 L F
.645 .543 .724 r
.32266 .54455 m .31907 .54197 L .3205 .54152 L F
0 .492 .848 r
.33773 .70811 m .34063 .70884 L .33776 .70755 L F
.33773 .70811 m .34245 .70991 L .34063 .70884 L F
.169 0 0 r
.23237 .55209 m .2316 .55086 L .23394 .55012 L F
.189 0 0 r
.23453 .55144 m .23237 .55209 L .23394 .55012 L F
.482 .838 .995 r
.23453 .55144 m .23434 .55143 L .23237 .55209 L F
.169 0 0 r
.23237 .55209 m .23017 .55282 L .2316 .55086 L F
.482 .838 .995 r
.23434 .55143 m .23065 .55127 L .23237 .55209 L F
.169 0 0 r
.23237 .55209 m .23012 .55289 L .23017 .55282 L F
.308 .347 .74 r
.3347 .70365 m .3373 .70566 L .33623 .70074 L F
.61 .474 .672 r
.64008 .37301 m .63754 .37632 L .63751 .3737 L F
.889 .881 .82 r
.70828 .30644 m .70597 .30944 L .70449 .30788 L F
.189 0 0 r
.70915 .30739 m .71089 .30602 L .70828 .30644 L F
.553 .355 .566 r
.33156 .60435 m .33466 .60108 L .33236 .60237 L F
.446 .778 .998 r
.336 .52487 m .33892 .52384 L .33857 .52548 L F
.093 .404 .857 r
.33892 .52384 m .34116 .5267 L .33857 .52548 L F
.717 .196 0 r
.55989 .45458 m .56042 .45666 L .55824 .45455 L F
0 0 0 r
.43292 .5751 m .43414 .57468 L .43582 .57313 L F
.138 0 0 r
.43414 .57468 m .43863 .57376 L .43582 .57313 L F
.759 .884 .935 r
.61062 .38824 m .60743 .3883 L .60929 .3866 L F
.928 .551 .264 r
.61134 .38473 m .61062 .38824 L .60929 .3866 L F
.61134 .38473 m .61177 .38683 L .61062 .38824 L F
.363 .183 .498 r
.31504 .60411 m .31233 .60744 L .31293 .60495 L F
.281 0 0 r
.34993 .59266 m .35048 .59395 L .34808 .59365 L F
.34993 .59266 m .35243 .59249 L .35048 .59395 L F
.531 .32 .539 r
.35341 .58916 m .35243 .59249 L .34993 .59266 L F
.744 .386 .374 r
.37952 .56346 m .37921 .56586 L .3768 .56375 L F
.554 .288 .467 r
.3768 .56375 m .37921 .56586 L .37952 .56346 L F
.015 .483 .873 r
.23409 .60688 m .23436 .60792 L .23182 .60492 L F
.23409 .60688 m .23602 .60841 L .23436 .60792 L F
.583 .723 .939 r
.40195 .49705 m .39941 .49589 L .40008 .4935 L F
.794 .347 .183 r
.40195 .49705 m .40031 .4986 L .39941 .49589 L F
.35 .555 .911 r
.40202 .49422 m .40195 .49705 L .40008 .4935 L F
.40202 .49422 m .40465 .49809 L .40195 .49705 L F
.77 .313 .162 r
.40195 .49705 m .40499 .50033 L .40031 .4986 L F
.77 .271 .027 r
.40582 .49988 m .40499 .50033 L .40195 .49705 L F
.772 .64 .715 r
.40396 .50114 m .40031 .4986 L .40499 .50033 L F
.594 .914 .669 r
.40673 .49865 m .40466 .5005 L .40499 .50033 L F
.40466 .5005 m .40396 .50114 L .40499 .50033 L F
.77 .271 .027 r
.40596 .49998 m .40499 .50033 L .40582 .49988 L F
.578 .524 .759 r
.58733 .43844 m .58508 .4398 L .58444 .43631 L F
.632 .397 .545 r
.61005 .44891 m .60716 .4515 L .60726 .44917 L F
.805 .733 .785 r
.57282 .41435 m .5703 .41767 L .56937 .41373 L F
.474 .219 .447 r
.38095 .59894 m .38076 .60173 L .37824 .60241 L F
.457 .205 .444 r
.38095 .59894 m .38076 .60173 L .38314 .60066 L F
.201 .715 .886 r
.27024 .52108 m .26787 .52126 L .26615 .52085 L F
.427 .643 .947 r
.27024 .52108 m .26851 .52134 L .26787 .52126 L F
.37 .834 .897 r
.25262 .5259 m .25343 .52516 L .25468 .52477 L F
.25262 .5259 m .25044 .52581 L .25343 .52516 L F
.946 .737 .588 r
.53912 .42955 m .54059 .43331 L .53876 .43196 L F
.944 .602 .34 r
.53876 .43196 m .54059 .43331 L .54093 .43547 L F
.819 .527 .495 r
.35232 .57413 m .34814 .57498 L .34805 .57278 L F
.737 .445 .485 r
.35055 .5756 m .352 .57595 L .35232 .57413 L F
.819 .527 .495 r
.35232 .57413 m .352 .57595 L .34814 .57498 L F
0 0 .215 r
.2051 .57007 m .20683 .56873 L .20738 .56628 L F
.128 0 .417 r
.2051 .57007 m .20693 .57143 L .20683 .56873 L F
.2051 .57007 m .20487 .57276 L .20693 .57143 L F
.183 .005 .391 r
.20761 .5636 m .20901 .56528 L .20981 .56313 L F
.20761 .5636 m .20738 .56628 L .20901 .56528 L F
.312 0 0 r
.31672 .6695 m .3198 .66942 L .31778 .67067 L F
.166 0 0 r
.32472 .68387 m .32628 .68144 L .32232 .68401 L F
.205 0 .006 r
.32857 .68074 m .32628 .68144 L .32472 .68387 L F
.862 .902 .86 r
.71291 .34172 m .70897 .34312 L .71144 .34123 L F
.71291 .34172 m .7102 .34444 L .70897 .34312 L F
.663 .96 .937 r
.71517 .34018 m .71291 .34172 L .71144 .34123 L F
.439 .245 .518 r
.29598 .52135 m .29524 .52501 L .29759 .52193 L F
.29598 .52135 m .29366 .52462 L .29524 .52501 L F
.718 .638 .767 r
.57862 .42384 m .57787 .42575 L .57581 .42709 L F
.955 .951 .701 r
.68683 .30956 m .68498 .31073 L .68671 .30716 L F
.23 0 0 r
.38496 .58641 m .3875 .58619 L .38585 .58741 L F
.38496 .58641 m .38585 .58741 L .38564 .58623 L F
.881 .838 .799 r
.67823 .32179 m .67437 .32362 L .67684 .32028 L F
.67823 .32179 m .67592 .32513 L .67437 .32362 L F
.847 .863 .854 r
.68104 .31864 m .67823 .32179 L .67684 .32028 L F
0 0 0 r
.31984 .66597 m .31515 .66724 L .31665 .66682 L F
.167 .367 .817 r
.31787 .66216 m .31984 .66597 L .31981 .66325 L F
.896 .962 .827 r
.31981 .66325 m .31984 .66597 L .31665 .66682 L F
.044 0 0 r
.39064 .70184 m .39155 .70245 L .38874 .70326 L F
.777 .89 .925 r
.38547 .67255 m .38787 .67425 L .38511 .6715 L F
.329 .715 .982 r
.38787 .67425 m .38829 .67275 L .38511 .6715 L F
.38787 .67425 m .39016 .6741 L .38829 .67275 L F
.126 .494 .904 r
.38511 .6715 m .38787 .67425 L .38829 .67275 L F
.968 .695 .272 r
.41799 .5827 m .41679 .58363 L .41694 .58106 L F
.41799 .5827 m .41815 .58552 L .41679 .58363 L F
.642 .953 .752 r
.40673 .49865 m .40627 .49962 L .40832 .49722 L F
0 0 0 r
.40933 .49756 m .40832 .49722 L .40876 .49819 L F
.40933 .49756 m .40673 .49865 L .40832 .49722 L F
.658 .891 .981 r
.4069 .49714 m .40673 .49865 L .40933 .49756 L F
0 .034 .565 r
.40712 .49782 m .40673 .49865 L .4069 .49714 L F
.575 .414 .625 r
.40673 .49865 m .40933 .49756 L .40876 .49819 L F
.642 .953 .752 r
.40673 .49865 m .40596 .49998 L .40627 .49962 L F
.645 .949 .731 r
.40596 .49998 m .40673 .49865 L .40859 .49994 L F
.575 .414 .625 r
.40673 .49865 m .40876 .49819 L .40859 .49994 L F
.40673 .49865 m .40895 .50103 L .40933 .49756 L F
0 .034 .565 r
.40753 .49913 m .40673 .49865 L .40712 .49782 L F
.787 .835 .888 r
.7102 .34444 m .70636 .3444 L .70897 .34312 L F
.8 .992 .751 r
.70524 .30087 m .70449 .30306 L .7072 .29989 L F
.414 .361 .689 r
.70524 .30087 m .70406 .30433 L .70449 .30306 L F
.535 .275 .468 r
.44107 .5861 m .44089 .58859 L .43828 .58883 L F
.586 .321 .482 r
.4439 .58588 m .44089 .58859 L .44107 .5861 L F
.679 .492 .627 r
.3257 .57879 m .33008 .57938 L .32759 .5813 L F
.918 .973 .691 r
.33897 .68674 m .34069 .68539 L .33658 .68389 L F
.502 .515 .803 r
.67245 .38843 m .6697 .38941 L .6688 .38535 L F
.443 .333 .634 r
.67205 .38976 m .6697 .38941 L .67245 .38843 L F
.67205 .38976 m .67025 .39148 L .6697 .38941 L F
.805 .403 .288 r
.39074 .6084 m .39322 .61094 L .39051 .61149 L F
.558 .611 .862 r
.39051 .61149 m .3919 .60742 L .39074 .6084 L F
.39051 .61149 m .39322 .61094 L .3919 .60742 L F
.476 0 0 r
.25963 .63019 m .25901 .6304 L .25743 .63023 L F
.25963 .63019 m .26144 .63128 L .25901 .6304 L F
.827 .392 .205 r
.22203 .56322 m .22263 .56482 L .22433 .56373 L F
.455 0 0 r
.22671 .56357 m .22203 .56322 L .22433 .56373 L F
.795 .469 .436 r
.22395 .56397 m .22671 .56357 L .22433 .56373 L F
.22563 .5639 m .22671 .56357 L .22395 .56397 L F
.22263 .56482 m .22644 .56579 L .22664 .56416 L F
.22563 .5639 m .22664 .56416 L .22671 .56357 L F
.22263 .56482 m .22664 .56416 L .22563 .5639 L F
.455 0 0 r
.22398 .56337 m .22664 .56386 L .22203 .56322 L F
.22671 .56357 m .22664 .56386 L .22398 .56337 L F
.22671 .56357 m .22666 .56386 L .22664 .56386 L F
.459 .767 .996 r
.22224 .56305 m .22664 .56386 L .22382 .56174 L F
.22203 .56322 m .22403 .5635 L .22224 .56305 L F
.22403 .5635 m .22664 .56386 L .22224 .56305 L F
.22664 .56386 m .22666 .56386 L .22665 .56386 L F
.22664 .56386 m .22665 .56386 L .22382 .56174 L F
.795 .469 .436 r
.22263 .56482 m .22563 .5639 L .22395 .56397 L F
.843 .894 .875 r
.67333 .32836 m .66922 .32992 L .67205 .32687 L F
.875 .881 .836 r
.67592 .32513 m .67333 .32836 L .67205 .32687 L F
.591 .217 .302 r
.30505 .55425 m .3072 .55618 L .30456 .55588 L F
.527 .234 .413 r
.30764 .55395 m .3072 .55618 L .30505 .55425 L F
.923 .601 .134 r
.41692 .57892 m .41543 .57498 L .4167 .5764 L F
.521 .316 .544 r
.70917 .28048 m .70929 .28293 L .7069 .28267 L F
.327 .286 .659 r
.71108 .27845 m .70969 .28193 L .70917 .28048 L F
.70969 .28193 m .70929 .28293 L .70924 .28184 L F
.70969 .28193 m .70924 .28184 L .70917 .28048 L F
.71108 .27845 m .7118 .28177 L .70955 .28227 L F
.7118 .28177 m .71198 .28259 L .70955 .28227 L F
.791 .856 .898 r
.71476 .28139 m .71165 .28325 L .71246 .28163 L F
.327 .286 .659 r
.71198 .28259 m .71202 .28282 L .71186 .28283 L F
.70955 .28227 m .71198 .28259 L .70929 .28293 L F
.71198 .28259 m .71186 .28283 L .70929 .28293 L F
.635 .492 .67 r
.70956 .28158 m .71181 .28271 L .71108 .27845 L F
.71181 .28271 m .71202 .28282 L .71198 .28259 L F
.71181 .28271 m .71198 .28259 L .71108 .27845 L F
.791 .856 .898 r
.71246 .28163 m .71198 .28259 L .71059 .28182 L F
.71198 .28259 m .71165 .28325 L .71145 .28298 L F
.71198 .28259 m .71181 .28271 L .71059 .28182 L F
0 .389 .801 r
.71115 .28221 m .71202 .28282 L .71181 .28271 L F
.71111 .2822 m .71181 .28271 L .71061 .28211 L F
.71115 .28221 m .71181 .28271 L .71111 .2822 L F
.71115 .28221 m .71061 .28211 L .70956 .28158 L F
.172 .521 .918 r
.71059 .28182 m .70929 .28293 L .71186 .28283 L F
.791 .856 .898 r
.71181 .28271 m .71176 .28275 L .71059 .28182 L F
.172 .521 .918 r
.71059 .28182 m .71186 .28283 L .71202 .28282 L F
.791 .856 .898 r
.71176 .28275 m .71145 .28298 L .71059 .28182 L F
.71372 .28135 m .71059 .28182 L .71342 .28134 L F
.71476 .28139 m .71246 .28163 L .71372 .28135 L F
.71246 .28163 m .71059 .28182 L .71372 .28135 L F
.71476 .28139 m .7122 .28399 L .71165 .28325 L F
0 .389 .801 r
.71059 .28182 m .71115 .28221 L .70956 .28158 L F
.521 .316 .544 r
.70917 .28048 m .7069 .28267 L .70956 .28158 L F
0 0 0 r
.7069 .28267 m .70565 .28486 L .70956 .28158 L F
.427 .643 .947 r
.27024 .52108 m .2712 .52262 L .26851 .52134 L F
.77 .946 .936 r
.27229 .5203 m .2712 .52262 L .27024 .52108 L F
.552 .865 .571 r
.37616 .5669 m .37368 .56946 L .37352 .56736 L F
.37616 .5669 m .37496 .56798 L .37368 .56946 L F
.659 .247 .252 r
.3763 .57169 m .37368 .56946 L .37496 .56798 L F
.3763 .57169 m .37349 .5724 L .37368 .56946 L F
.268 .766 .89 r
.61234 .39436 m .61168 .39513 L .61269 .39423 L F
.61234 .39436 m .61438 .39475 L .61168 .39513 L F
.001 .251 .757 r
.60732 .40843 m .60936 .40851 L .60641 .40696 L F
.60732 .40843 m .60905 .4104 L .60936 .40851 L F
0 .118 .657 r
.33076 .52429 m .33212 .52857 L .33197 .52555 L F
0 .193 .655 r
.35976 .65279 m .35578 .64983 L .35791 .6492 L F
.806 .702 .75 r
.36153 .64916 m .35976 .65279 L .35791 .6492 L F
.487 .287 .534 r
.32724 .55376 m .33002 .55006 L .32785 .5511 L F
.806 .702 .75 r
.36153 .64916 m .35791 .6492 L .3607 .65173 L F
.02 0 .196 r
.36386 .64557 m .36153 .64916 L .36306 .64804 L F
0 0 0 r
.36306 .64804 m .36153 .64916 L .3607 .65173 L F
.908 .922 .814 r
.31701 .5037 m .31473 .5074 L .3141 .50626 L F
.04 0 0 r
.31473 .5074 m .3177 .50672 L .31566 .50778 L F
.282 .338 .743 r
.71932 .35695 m .71911 .35311 L .71548 .35633 L F
.503 .803 .999 r
.71826 .35577 m .71932 .35695 L .71548 .35633 L F
.615 .895 .988 r
.71716 .35491 m .71826 .35577 L .71707 .35493 L F
.83 .667 .123 r
.71911 .35311 m .7193 .35659 L .71826 .35577 L F
.742 .689 .801 r
.71548 .35633 m .71911 .35311 L .71431 .35247 L F
.689 .756 .903 r
.71431 .35247 m .71911 .35311 L .71363 .35013 L F
.382 .69 .98 r
.71761 .35161 m .71911 .35311 L .71363 .35013 L F
.71363 .35013 m .71911 .35311 L .71761 .35161 L F
.71363 .35013 m .71911 .35311 L .71761 .35161 L F
.966 .816 .643 r
.71761 .35161 m .71911 .35311 L .71826 .35577 L F
.71761 .35161 m .71826 .35577 L .72142 .35425 L F
.615 .895 .988 r
.72142 .35425 m .71826 .35577 L .71716 .35491 L F
.83 .667 .123 r
.7193 .35659 m .71932 .35695 L .71826 .35577 L F
.868 .746 .726 r
.59186 .38277 m .59304 .38588 L .59093 .38333 L F
.149 0 0 r
.5882 .38492 m .5904 .38536 L .58728 .38477 L F
.985 .837 .451 r
.593 .38584 m .59159 .38558 L .59093 .38333 L F
0 0 .29 r
.59093 .38333 m .59202 .38707 L .59183 .38565 L F
.149 0 0 r
.5904 .38536 m .59183 .38565 L .58937 .38518 L F
.5904 .38536 m .58937 .38518 L .58728 .38477 L F
.985 .837 .451 r
.59304 .38588 m .59202 .38707 L .59159 .38558 L F
.59304 .38588 m .59159 .38558 L .593 .38584 L F
.59304 .38588 m .59284 .38793 L .59202 .38707 L F
.225 .371 .801 r
.59398 .38416 m .59304 .38588 L .59186 .38277 L F
.148 0 0 r
.59462 .38627 m .59544 .386 L .59304 .38588 L F
.59462 .38627 m .59304 .38588 L .59398 .38416 L F
.668 .786 .937 r
.4135 .4918 m .41113 .49295 L .40912 .49142 L F
.054 0 .454 r
.35428 .58563 m .35437 .5886 L .35341 .58916 L F
.285 .087 .426 r
.35455 .59112 m .35341 .58916 L .35437 .5886 L F
.35455 .59112 m .35243 .59249 L .35341 .58916 L F
.968 .649 .282 r
.70449 .30788 m .70597 .30944 L .70612 .31149 L F
.424 .072 .262 r
.2549 .56472 m .25696 .56392 L .25462 .56484 L F
.255 .179 .575 r
.24715 .5373 m .24749 .53996 L .24532 .54123 L F
.045 0 .187 r
.24749 .53996 m .24525 .54251 L .24532 .54123 L F
.759 .973 .924 r
.72428 .33445 m .7223 .33576 L .72036 .33577 L F
.861 .941 .573 r
.43273 .54724 m .43047 .55092 L .43094 .54909 L F
.811 .594 .608 r
.43273 .54724 m .43277 .55052 L .43047 .55092 L F
.563 .845 .51 r
.43273 .54724 m .43094 .54909 L .43365 .54607 L F
.79 .757 .823 r
.57185 .41106 m .57282 .41435 L .56937 .41373 L F
.721 .688 .818 r
.574 .4096 m .57282 .41435 L .57185 .41106 L F
.574 .4096 m .57589 .41343 L .57282 .41435 L F
.264 .582 .944 r
.30828 .50728 m .31096 .51003 L .30794 .50928 L F
.816 .967 .65 r
.30828 .50728 m .30794 .50928 L .30515 .51199 L F
.027 0 0 r
.71508 .32686 m .71827 .32637 L .72069 .32539 L F
.509 0 0 r
.72069 .32539 m .72168 .3264 L .7216 .32426 L F
.72069 .32539 m .71827 .32637 L .72168 .3264 L F
.897 .605 .1 r
.651 .39448 m .65212 .39829 L .65139 .39714 L F
.766 .789 .871 r
.39951 .67509 m .40451 .67506 L .40169 .67629 L F
0 0 .11 r
.40442 .67118 m .40461 .67369 L .40451 .67506 L F
.754 .995 .825 r
.40451 .67506 m .40461 .67369 L .40169 .67629 L F
.964 .642 .257 r
.41922 .58907 m .41839 .59077 L .41772 .58802 L F
.41922 .58907 m .41964 .59172 L .41839 .59077 L F
.661 .776 .305 r
.36755 .65899 m .36587 .66273 L .36659 .66105 L F
.608 .31 .439 r
.58134 .45586 m .58124 .45796 L .57862 .45807 L F
.594 .299 .438 r
.58492 .45704 m .58134 .45586 L .58478 .45506 L F
.58492 .45704 m .58124 .45796 L .58134 .45586 L F
.622 .765 .948 r
.28487 .52481 m .28947 .52543 L .28732 .52427 L F
.339 .717 .984 r
.28947 .52543 m .28964 .52416 L .28732 .52427 L F
0 .04 .61 r
.28947 .52543 m .29119 .52763 L .28964 .52416 L F
0 0 0 r
.64896 .43488 m .64584 .43716 L .64653 .43597 L F
.691 .505 .631 r
.37265 .60769 m .36934 .61077 L .36978 .60837 L F
0 0 0 r
.35391 .6697 m .35366 .66956 L .35158 .67028 L F
.35391 .6697 m .35617 .66863 L .35366 .66956 L F
.095 0 0 r
.31808 .64399 m .31913 .64455 L .32023 .64336 L F
.563 .715 .943 r
.35791 .6492 m .35578 .64983 L .35427 .6481 L F
.255 0 .121 r
.36549 .57352 m .36515 .5751 L .36237 .57592 L F
.606 .18 .206 r
.36549 .57352 m .36778 .57538 L .36515 .5751 L F
0 0 0 r
.34719 .58802 m .34876 .5862 L .34544 .58861 L F
.34719 .58802 m .34544 .58861 L .34395 .59069 L F
.743 .432 .456 r
.63493 .43004 m .63204 .43242 L .63448 .42879 L F
.63493 .43004 m .63594 .43288 L .63204 .43242 L F
.558 .884 .619 r
.63699 .4279 m .63493 .43004 L .63448 .42879 L F
.63699 .4279 m .63837 .42696 L .63493 .43004 L F
.455 .715 .98 r
.58204 .41872 m .58075 .42054 L .57942 .41939 L F
.58204 .41872 m .58336 .42038 L .58075 .42054 L F
.58204 .41872 m .58075 .42054 L .57942 .41939 L F
.58204 .41872 m .58336 .42038 L .58075 .42054 L F
.438 .149 .375 r
.6796 .37313 m .67951 .37522 L .67679 .37588 L F
.401 .103 .341 r
.68229 .37251 m .67951 .37522 L .6796 .37313 L F
.691 .907 .56 r
.3413 .52063 m .33925 .52339 L .33999 .52192 L F
.33925 .52339 m .33892 .52384 L .33999 .52192 L F
0 0 .562 r
.34089 .52013 m .33999 .52192 L .34084 .51989 L F
.537 .812 .997 r
.33999 .52192 m .3401 .52186 L .3413 .52063 L F
.87 .935 .558 r
.34153 .5221 m .3413 .52063 L .34273 .51918 L F
.559 0 0 r
.34153 .5221 m .33892 .52384 L .3413 .52063 L F
.537 .812 .997 r
.3401 .52186 m .34383 .52007 L .3413 .52063 L F
.559 0 0 r
.34153 .5221 m .34229 .5233 L .33892 .52384 L F
.34153 .5221 m .34384 .52415 L .34229 .5233 L F
.537 .812 .997 r
.33999 .52192 m .34229 .5233 L .34444 .52248 L F
.33999 .52192 m .34444 .52248 L .34383 .52007 L F
0 0 .562 r
.34144 .52294 m .33999 .52192 L .34089 .52013 L F
.87 .935 .558 r
.34273 .51918 m .3413 .52063 L .34306 .51837 L F
.608 .546 .76 r
.25028 .5767 m .25086 .57934 L .25285 .57609 L F
.662 .515 .674 r
.25086 .57934 m .25177 .58315 L .25438 .58246 L F
.778 .664 .737 r
.40555 .50251 m .40728 .50643 L .40325 .5059 L F
0 0 0 r
.4315 .54498 m .42716 .54616 L .42944 .54541 L F
.691 .185 .031 r
.70056 .33301 m .69926 .33358 L .69744 .33252 L F
.389 .2 .5 r
.30736 .61684 m .30487 .62145 L .30542 .6175 L F
.633 .276 .349 r
.32558 .6336 m .32888 .63415 L .32824 .63333 L F
.628 .266 .337 r
.32558 .6336 m .32824 .63333 L .32812 .63402 L F
.403 .237 .54 r
.32824 .63333 m .32888 .63415 L .33105 .63267 L F
.68 .819 .95 r
.33105 .63267 m .32888 .63415 L .32861 .63395 L F
.585 .36 .541 r
.33105 .63267 m .32929 .6336 L .32824 .63333 L F
.32992 .63376 m .32812 .63402 L .32824 .63333 L F
.68 .819 .95 r
.33105 .63267 m .32861 .63395 L .32627 .63211 L F
.585 .36 .541 r
.33105 .63267 m .32992 .63376 L .32929 .6336 L F
.377 .698 .983 r
.32861 .63395 m .32886 .63414 L .32812 .63402 L F
.585 .36 .541 r
.32992 .63376 m .32783 .63576 L .32812 .63402 L F
.377 .698 .983 r
.32627 .63211 m .32861 .63395 L .32558 .6336 L F
.32861 .63395 m .32812 .63402 L .32558 .6336 L F
.32886 .63414 m .32888 .63415 L .32558 .6336 L F
.628 .266 .337 r
.32558 .6336 m .32812 .63402 L .32783 .63576 L F
.829 .83 .847 r
.37904 .63938 m .3827 .63879 L .38164 .63648 L F
.822 .838 .86 r
.38164 .63648 m .3827 .63879 L .38512 .6363 L F
.14 .685 .793 r
.23293 .55689 m .23574 .55663 L .23675 .55664 L F
.963 .714 .511 r
.23514 .55967 m .23675 .55664 L .23574 .55663 L F
.784 .778 .847 r
.45206 .56376 m .45377 .56713 L .45088 .56628 L F
.567 .561 .807 r
.45479 .56264 m .45377 .56713 L .45206 .56376 L F
.45479 .56264 m .45611 .56646 L .45377 .56713 L F
.424 .271 .568 r
.59258 .43502 m .59006 .43573 L .58938 .43351 L F
.59258 .43502 m .59006 .43573 L .58938 .43351 L F
.923 .931 .794 r
.69459 .29705 m .6944 .30033 L .69225 .30062 L F
.682 .707 .867 r
.41759 .49332 m .4135 .4918 L .41593 .48967 L F
.636 .697 .89 r
.41998 .49237 m .41759 .49332 L .41593 .48967 L F
.47 0 0 r
.35387 .63556 m .35294 .63402 L .35111 .63586 L F
.77 .645 .724 r
.54307 .41324 m .54514 .41376 L .54543 .41091 L F
.459 .586 .893 r
.54757 .41671 m .54307 .41324 L .54514 .41376 L F
.787 .482 .473 r
.54446 .41603 m .54514 .41376 L .54307 .41324 L F
.77 .645 .724 r
.54307 .41324 m .54514 .41376 L .54543 .41091 L F
.459 .586 .893 r
.54757 .41671 m .54514 .41376 L .54446 .41603 L F
.18 .667 .925 r
.24202 .55672 m .24318 .55618 L .24541 .55728 L F
.278 .78 .774 r
.24202 .55672 m .24083 .55687 L .24318 .55618 L F
.928 .551 .264 r
.61134 .38473 m .61285 .38553 L .61177 .38683 L F
.366 .754 .988 r
.61537 .38522 m .61285 .38553 L .61134 .38473 L F
.183 0 0 r
.61177 .38683 m .61285 .38553 L .61537 .38522 L F
.749 .91 .534 r
.34939 .58449 m .34876 .5862 L .34719 .58802 L F
.328 0 0 r
.26289 .52811 m .26061 .52956 L .25876 .52916 L F
.504 .823 1 r
.26528 .5275 m .26349 .52657 L .26289 .52811 L F
.739 .975 .723 r
.26349 .52657 m .26061 .52956 L .26289 .52811 L F
.677 .435 .547 r
.34478 .55583 m .34193 .55437 L .34318 .55322 L F
.34193 .55437 m .34147 .55413 L .34318 .55322 L F
.34478 .55583 m .34116 .55677 L .34147 .55413 L F
.603 .292 .415 r
.34744 .55434 m .34478 .55583 L .34318 .55322 L F
0 0 0 r
.34288 .55506 m .34481 .5517 L .34318 .55322 L F
.34481 .5517 m .34487 .5516 L .34318 .55322 L F
0 0 .308 r
.34147 .55413 m .34288 .55506 L .34318 .55322 L F
.34147 .55413 m .34116 .55677 L .34288 .55506 L F
.875 .881 .836 r
.67592 .32513 m .67205 .32687 L .67437 .32362 L F
0 0 0 r
.25862 .56306 m .25899 .56288 L .25982 .56016 L F
.25862 .56306 m .25696 .56392 L .25899 .56288 L F
.905 .853 .403 r
.65852 .41595 m .65883 .41666 L .65961 .41406 L F
.334 .132 .45 r
.30964 .61314 m .30736 .61684 L .3078 .61417 L F
.479 .433 .729 r
.44008 .56568 m .44203 .57007 L .44323 .56694 L F
.341 0 0 r
.41386 .5109 m .41538 .51109 L .41136 .51036 L F
.41386 .5109 m .41136 .51036 L .40966 .50841 L F
.898 .743 .681 r
.3754 .52562 m .37285 .52479 L .37405 .5219 L F
.91 .667 .559 r
.3754 .52562 m .37461 .52719 L .37285 .52479 L F
.689 .63 .785 r
.25177 .58315 m .25154 .58479 L .25438 .58246 L F
.642 .272 .328 r
.27534 .62288 m .27827 .62335 L .27981 .62093 L F
.534 .151 .262 r
.27981 .62093 m .28199 .62273 L .28212 .62025 L F
.27981 .62093 m .27827 .62335 L .28199 .62273 L F
.95 .682 .494 r
.35634 .52396 m .35833 .52551 L .35811 .52216 L F
.7 .485 .594 r
.35811 .52216 m .36098 .52449 L .36077 .52208 L F
.35811 .52216 m .35833 .52551 L .36098 .52449 L F
.34 .158 .483 r
.30472 .60109 m .30691 .59784 L .30511 .59861 L F
0 0 0 r
.27075 .62381 m .27153 .6243 L .27378 .62409 L F
.27075 .62381 m .27002 .62511 L .27153 .6243 L F
.168 0 0 r
.3914 .64418 m .3907 .64397 L .39004 .64379 L F
.3914 .64418 m .39267 .64441 L .3907 .64397 L F
.007 .489 .869 r
.34186 .49675 m .34509 .49767 L .34618 .49881 L F
.199 0 0 r
.34509 .49767 m .34879 .49866 L .34618 .49881 L F
.857 .539 .015 r
.41136 .5507 m .41063 .55002 L .41013 .54723 L F
.583 .135 0 r
.41136 .5507 m .41194 .55155 L .41063 .55002 L F
.957 .708 .258 r
.41194 .55155 m .41111 .5525 L .41173 .55132 L F
.583 .135 0 r
.41136 .5507 m .41214 .55177 L .41194 .55155 L F
0 .022 .594 r
.41194 .55155 m .41226 .55031 L .41057 .54813 L F
.957 .708 .258 r
.41194 .55155 m .41173 .55132 L .41226 .55031 L F
.583 .135 0 r
.41214 .55177 m .41305 .55304 L .41194 .55155 L F
.615 .804 .972 r
.61864 .36979 m .61644 .3708 L .61543 .36948 L F
.548 .613 .87 r
.61934 .37212 m .61644 .3708 L .61864 .36979 L F
.492 .571 .863 r
.57798 .41304 m .57589 .41343 L .574 .4096 L F
.894 .774 .722 r
.38813 .62118 m .38524 .62317 L .38802 .62025 L F
.468 .429 .731 r
.4372 .51176 m .43564 .51618 L .43499 .51221 L F
.4372 .51176 m .43799 .51582 L .43564 .51618 L F
.475 .489 .793 r
.43799 .51582 m .43895 .51795 L .43564 .51618 L F
.876 .694 .652 r
.34357 .69602 m .34638 .69766 L .34574 .69493 L F
.772 .264 0 r
.34453 .69744 m .34638 .69766 L .34357 .69602 L F
.513 .383 .641 r
.34638 .69766 m .3487 .69458 L .34574 .69493 L F
.34638 .69766 m .34882 .69712 L .3487 .69458 L F
.318 .802 .888 r
.34453 .69744 m .34882 .69712 L .34638 .69766 L F
.715 .595 .72 r
.26091 .53434 m .26178 .53827 L .26429 .53499 L F
.372 .14 .428 r
.29731 .60832 m .29883 .6102 L .2989 .60742 L F
.29731 .60832 m .29672 .61095 L .29883 .6102 L F
.442 .26 .537 r
.35699 .55072 m .357 .55345 L .35464 .55383 L F
.35464 .55383 m .357 .55345 L .35699 .55072 L F
.558 .082 .081 r
.357 .55345 m .35281 .55379 L .35464 .55383 L F
0 0 0 r
.35321 .5554 m .357 .55345 L .35464 .55383 L F
.6293 .39884 m .63175 .39533 L .63124 .39725 L F
.233 0 .268 r
.63124 .39725 m .63175 .39533 L .63397 .39426 L F
.72 .632 .758 r
.64008 .37301 m .64022 .37564 L .63754 .37632 L F
.759 .655 .747 r
.64233 .3722 m .64022 .37564 L .64008 .37301 L F
.64 .917 .626 r
.3669 .64247 m .36386 .64557 L .36623 .64511 L F
0 0 0 r
.37022 .64159 m .37002 .64021 L .36876 .64174 L F
.212 .582 .943 r
.36996 .64132 m .36876 .64174 L .37022 .64159 L F
.365 .122 .406 r
.37002 .64021 m .36715 .64229 L .36876 .64174 L F
.212 .582 .943 r
.36894 .64027 m .36876 .64174 L .36996 .64132 L F
.365 .122 .406 r
.36715 .64229 m .3669 .64247 L .36876 .64174 L F
.512 .346 .593 r
.36623 .64511 m .36876 .64174 L .3669 .64247 L F
.879 .943 .853 r
.3637 .65594 m .36473 .65248 L .36245 .65343 L F
.3637 .65594 m .36632 .65304 L .36473 .65248 L F
.779 .859 .91 r
.54307 .41704 m .54757 .41671 L .54446 .41603 L F
.439 .108 .307 r
.29968 .60546 m .30141 .60693 L .30211 .60483 L F
.29968 .60546 m .2989 .60742 L .30141 .60693 L F
.431 0 0 r
.36824 .50781 m .37057 .50908 L .36925 .50854 L F
.925 .701 .581 r
.28534 .64865 m .28736 .6522 L .2878 .65129 L F
0 .114 .667 r
.2878 .65129 m .28736 .6522 L .2896 .65464 L F
.708 .566 0 r
.40045 .68282 m .40051 .68582 L .39715 .68395 L F
.505 .855 .993 r
.24541 .55728 m .24578 .55562 L .24749 .55353 L F
.398 .134 .393 r
.24499 .55764 m .24814 .55467 L .24578 .55562 L F
.24814 .55467 m .2483 .55452 L .24578 .55562 L F
.505 .855 .993 r
.24541 .55728 m .24372 .55644 L .24578 .55562 L F
.24372 .55644 m .24318 .55618 L .24578 .55562 L F
.035 0 .324 r
.42512 .57319 m .42675 .5699 L .42718 .57256 L F
0 0 .543 r
.42689 .57528 m .42512 .57319 L .42718 .57256 L F
.47 .17 .373 r
.34285 .57551 m .33914 .57887 L .33966 .57675 L F
.77 .71 .795 r
.58854 .41328 m .58973 .41696 L .58505 .41657 L F
.774 .697 .778 r
.58505 .41657 m .58973 .41696 L .58653 .41963 L F
.523 .425 .685 r
.44355 .53722 m .44381 .54116 L .44132 .54145 L F
.49 .368 .64 r
.44381 .54116 m .44176 .54424 L .44132 .54145 L F
0 .317 .774 r
.44018 .55179 m .44081 .55157 L .43967 .55003 L F
.44018 .55179 m .44237 .55305 L .44081 .55157 L F
.496 .521 .813 r
.37156 .60409 m .37086 .60087 L .37238 .60217 L F
.955 .853 .434 r
.37156 .60409 m .37158 .60606 L .37205 .60374 L F
.37156 .60409 m .37205 .60374 L .37238 .60217 L F
0 0 0 r
.37078 .60464 m .37156 .60409 L .36918 .60576 L F
.522 .637 .905 r
.37287 .60319 m .37158 .60606 L .37156 .60409 L F
0 0 0 r
.37287 .60319 m .37156 .60409 L .37078 .60464 L F
.37287 .60319 m .37156 .60409 L .37238 .60217 L F
.37287 .60319 m .37238 .60217 L .37086 .60087 L F
.584 .938 .931 r
.29666 .51608 m .29209 .51723 L .29444 .51607 L F
.502 .905 .914 r
.2989 .51509 m .29666 .51608 L .29444 .51607 L F
.953 .756 .6 r
.39519 .62354 m .39586 .62092 L .39395 .61973 L F
.83 .84 .855 r
.39586 .62092 m .39677 .6167 L .39395 .61973 L F
.39586 .62092 m .39883 .61805 L .39677 .6167 L F
.68 .322 .361 r
.36437 .59799 m .36917 .59821 L .36648 .60061 L F
.97 .71 .484 r
.37109 .59816 m .36648 .60061 L .36917 .59821 L F
.495 .334 .592 r
.31353 .6238 m .31361 .62687 L .31599 .62634 L F
.917 .91 .799 r
.70618 .2983 m .70956 .29637 L .7083 .29501 L F
.70618 .2983 m .7072 .29989 L .70956 .29637 L F
.583 .396 .594 r
.33822 .60426 m .33545 .6076 L .33636 .6054 L F
.785 .83 .887 r
.55083 .42035 m .54697 .42032 L .5492 .41844 L F
.534 .715 .955 r
.55329 .41975 m .55083 .42035 L .5492 .41844 L F
.611 .52 .727 r
.55373 .42356 m .55083 .42035 L .55329 .41975 L F
0 0 .168 r
.29258 .65614 m .29419 .65285 L .29378 .65584 L F
0 0 .18 r
.29487 .65205 m .29419 .65285 L .29524 .64929 L F
0 0 .218 r
.29378 .65584 m .29419 .65285 L .29487 .65205 L F
.434 .164 .403 r
.29376 .61385 m .29672 .61095 L .29416 .61159 L F
.973 .666 .361 r
.59284 .38793 m .5917 .39023 L .59202 .38707 L F
.59284 .38793 m .59318 .39117 L .5917 .39023 L F
.716 .673 .807 r
.35833 .52551 m .36222 .52795 L .36098 .52449 L F
.524 .522 .795 r
.36222 .52795 m .36338 .52406 L .36098 .52449 L F
.36222 .52795 m .36453 .52733 L .36338 .52406 L F
.138 0 0 r
.43414 .57468 m .43651 .5746 L .43758 .57397 L F
.496 .513 .804 r
.43565 .57048 m .43651 .5746 L .43414 .57468 L F
.674 .203 .126 r
.43545 .57521 m .43651 .5746 L .43537 .57324 L F
.4355 .57643 m .43651 .5746 L .43545 .57521 L F
.138 0 0 r
.43758 .57397 m .43651 .5746 L .43863 .57376 L F
.536 0 0 r
.43651 .5746 m .44054 .57508 L .43863 .57376 L F
.374 .128 .407 r
.43863 .57376 m .44054 .57508 L .44101 .57266 L F
.479 .287 .542 r
.36161 .62304 m .35922 .6236 L .3593 .6209 L F
.36161 .62304 m .35922 .6236 L .3593 .6209 L F
.847 .75 .756 r
.36665 .66865 m .36519 .66368 L .36688 .66708 L F
.924 .77 .29 r
.36591 .67075 m .36665 .66865 L .36688 .66708 L F
.36591 .67075 m .36639 .67143 L .36665 .66865 L F
.644 .352 .46 r
.36898 .6711 m .36665 .66865 L .36639 .67143 L F
.36898 .6711 m .36914 .66869 L .36665 .66865 L F
.499 .588 .874 r
.25587 .54818 m .25783 .55151 L .25916 .54894 L F
.265 .3 .711 r
.25783 .55151 m .25999 .55357 L .25916 .54894 L F
.535 .356 .585 r
.29282 .54723 m .29282 .54997 L .29024 .54785 L F
.427 .363 .683 r
.29024 .54785 m .29282 .54997 L .29079 .55069 L F
.639 .507 .686 r
.25982 .56016 m .26184 .56238 L .26322 .56019 L F
0 0 0 r
.2661 .5584 m .26322 .56019 L .26499 .55923 L F
.317 .025 .301 r
.26184 .56238 m .26499 .55923 L .26322 .56019 L F
.741 .637 .745 r
.32942 .60785 m .33156 .60435 L .32951 .60493 L F
.583 .415 .62 r
.31155 .58582 m .31368 .58628 L .31381 .58228 L F
.282 .242 .635 r
.31381 .58228 m .31608 .5816 L .31548 .57838 L F
.084 .012 .468 r
.31381 .58228 m .31565 .58393 L .31608 .5816 L F
.31381 .58228 m .31368 .58628 L .31565 .58393 L F
.306 .396 .791 r
.71108 .27845 m .70917 .28048 L .7079 .27656 L F
.02 .192 .701 r
.7079 .27656 m .70917 .28048 L .70953 .27981 L F
.521 .316 .544 r
.70917 .28048 m .70956 .28158 L .70953 .27981 L F
.642 .953 .752 r
.40673 .49865 m .40499 .50033 L .40596 .49998 L F
.645 .949 .731 r
.40596 .49998 m .40396 .50114 L .40673 .49865 L F
.969 .776 .588 r
.40596 .49998 m .40555 .50251 L .40396 .50114 L F
.684 .504 .637 r
.38692 .57475 m .38647 .57699 L .3888 .5752 L F
.38692 .57475 m .38428 .57781 L .38647 .57699 L F
.776 .953 .931 r
.36473 .65248 m .36632 .65304 L .36679 .65083 L F
.759 .973 .924 r
.72428 .33445 m .72036 .33577 L .72368 .33397 L F
.583 .807 .984 r
.72552 .33226 m .72702 .3337 L .72428 .33445 L F
.745 .993 .853 r
.72428 .33445 m .72368 .33397 L .72552 .33226 L F
.692 .804 .935 r
.64427 .39237 m .64687 .39122 L .64296 .39073 L F
.332 0 0 r
.3684 .66062 m .36755 .65899 L .36659 .66105 L F
.3684 .66062 m .3702 .65874 L .36755 .65899 L F
.412 .205 .486 r
.30924 .58914 m .31137 .58852 L .31155 .58582 L F
.436 .264 .548 r
.30924 .58914 m .31137 .59124 L .31137 .58852 L F
.293 .251 .639 r
.30977 .59167 m .31137 .59124 L .30924 .58914 L F
.523 .53 .804 r
.43344 .55466 m .43113 .55513 L .42994 .55317 L F
.43344 .55466 m .43443 .55713 L .43113 .55513 L F
.006 .121 .635 r
.23293 .55689 m .23514 .55967 L .23574 .55663 L F
.099 0 .098 r
.28971 .55555 m .28876 .55462 L .29081 .55366 L F
.28971 .55555 m .2878 .55651 L .28876 .55462 L F
.245 0 .319 r
.35771 .52984 m .35542 .52838 L .35743 .52891 L F
.293 .227 .609 r
.35858 .52604 m .35771 .52984 L .35743 .52891 L F
.521 .312 .538 r
.44972 .5795 m .44964 .5821 L .44704 .58256 L F
.521 .313 .538 r
.45217 .58158 m .44972 .5795 L .45238 .57903 L F
.45217 .58158 m .44964 .5821 L .44972 .5795 L F
0 .255 .765 r
.57594 .39965 m .57674 .40132 L .57931 .40319 L F
.591 .473 .687 r
.73436 .33461 m .73754 .33426 L .73688 .3314 L F
.02 0 0 r
.73436 .33461 m .73621 .33469 L .73754 .33426 L F
.73436 .33461 m .73358 .33604 L .73621 .33469 L F
.02 .162 .672 r
.39946 .64828 m .39836 .64961 L .39739 .64589 L F
.325 .259 .627 r
.4008 .65194 m .39836 .64961 L .39946 .64828 L F
.4008 .65194 m .39898 .65215 L .39836 .64961 L F
.486 0 0 r
.3914 .58589 m .39184 .58757 L .3875 .58619 L F
.563 .592 .841 r
.39231 .58171 m .3914 .58589 L .38991 .58218 L F
.39231 .58171 m .39385 .58532 L .3914 .58589 L F
.203 .166 .592 r
.3914 .58589 m .39248 .58879 L .39268 .58814 L F
.79 .322 0 r
.3914 .58589 m .39268 .58814 L .39151 .5875 L F
.3914 .58589 m .39151 .5875 L .39184 .58757 L F
.611 .53 .738 r
.33257 .56505 m .33093 .56945 L .33081 .56686 L F
.717 .633 .763 r
.33508 .55706 m .33505 .56308 L .33194 .56042 L F
0 0 .457 r
.33288 .56107 m .33194 .56042 L .33505 .56308 L F
0 0 .486 r
.33586 .56046 m .33505 .56308 L .33507 .55805 L F
.33653 .55828 m .33586 .56046 L .33508 .55706 L F
.33586 .56046 m .33507 .55805 L .33508 .55706 L F
.787 .684 .751 r
.33653 .55828 m .33288 .56107 L .33505 .56308 L F
.915 .973 .785 r
.33824 .56221 m .33595 .56608 L .33445 .56621 L F
.33842 .56203 m .33833 .56217 L .33824 .56221 L F
.33833 .56217 m .33595 .56608 L .33824 .56221 L F
.63 .578 .777 r
.33662 .56301 m .33288 .56107 L .33654 .56256 L F
.915 .973 .785 r
.33768 .56305 m .33445 .56621 L .33683 .56422 L F
.33842 .56203 m .33728 .56322 L .33768 .56305 L F
.33728 .56322 m .33445 .56621 L .33768 .56305 L F
.858 .831 .819 r
.33809 .56391 m .33595 .56608 L .33842 .56203 L F
.423 .022 .172 r
.33881 .56254 m .33744 .56292 L .33758 .56053 L F
.412 .277 .586 r
.341 .5619 m .33809 .56391 L .33842 .56203 L F
.341 .5619 m .34118 .56476 L .33809 .56391 L F
.365 0 .086 r
.33842 .56203 m .33683 .56422 L .33927 .56328 L F
.423 .022 .172 r
.33927 .56328 m .3378 .56299 L .33881 .56254 L F
.3378 .56299 m .33744 .56292 L .33881 .56254 L F
.63 .578 .777 r
.33683 .56422 m .33581 .5634 L .33662 .56301 L F
.33581 .5634 m .33288 .56107 L .33662 .56301 L F
.33698 .5639 m .33654 .56256 L .33744 .56292 L F
.33683 .56422 m .33654 .56256 L .33698 .5639 L F
.661 .623 .801 r
.59373 .4376 m .59144 .43957 L .59006 .43573 L F
.401 .761 .994 r
.34063 .70884 m .34245 .70991 L .34301 .7086 L F
.051 .347 .823 r
.34245 .70991 m .34585 .71219 L .34301 .7086 L F
.176 .454 .88 r
.34245 .70991 m .34633 .71306 L .34585 .71219 L F
.531 .325 .545 r
.32216 .61807 m .32488 .61748 L .32489 .61464 L F
.503 .374 .637 r
.32489 .61464 m .32734 .61423 L .32755 .61098 L F
.585 .421 .625 r
.32488 .61748 m .32734 .61423 L .32489 .61464 L F
.471 .423 .723 r
.23909 .56892 m .24054 .56664 L .23804 .56731 L F
.23909 .56892 m .24105 .56889 L .24054 .56664 L F
.772 .985 .738 r
.23906 .56795 m .23909 .56892 L .24105 .56889 L F
.23906 .56795 m .23773 .56974 L .23909 .56892 L F
.507 .062 .128 r
.24074 .57066 m .23909 .56892 L .24105 .56889 L F
.24074 .57066 m .23657 .57137 L .23909 .56892 L F
.566 .146 .204 r
.31354 .58771 m .31155 .58582 L .31137 .58852 L F
.31354 .58771 m .31368 .58628 L .31155 .58582 L F
.285 .098 .443 r
.22125 .57273 m .21968 .57212 L .22164 .57202 L F
.22125 .57273 m .21924 .57603 L .21968 .57212 L F
.333 0 .161 r
.68812 .36623 m .69063 .36735 L .68783 .36875 L F
.68812 .36623 m .69078 .36551 L .69063 .36735 L F
.699 .963 .718 r
.71827 .32637 m .71642 .329 L .7194 .32801 L F
.464 .266 .526 r
.41812 .50954 m .41538 .51109 L .4157 .50828 L F
.537 .33 .546 r
.41778 .51227 m .42052 .51185 L .41812 .50954 L F
.41778 .51227 m .42052 .51185 L .41812 .50954 L F
.472 .312 .582 r
.20124 .59542 m .20345 .59518 L .20305 .59233 L F
.245 0 .319 r
.35771 .52984 m .35481 .53119 L .35542 .52838 L F
.515 0 0 r
.24538 .61304 m .2464 .61388 L .24831 .61455 L F
.82 .35 .09 r
.24481 .61238 m .2476 .61486 L .2464 .61388 L F
0 .206 .731 r
.2464 .61388 m .24819 .61713 L .24831 .61455 L F
.452 .243 .504 r
.24819 .61713 m .25074 .61391 L .24831 .61455 L F
.82 .35 .09 r
.2476 .61486 m .24859 .61575 L .2464 .61388 L F
.515 0 0 r
.24437 .61252 m .2464 .61388 L .24538 .61304 L F
.839 .992 .737 r
.64174 .41903 m .64363 .41798 L .64135 .42087 L F
.822 .982 .884 r
.6445 .41554 m .64566 .41627 L .64363 .41798 L F
.848 .992 .736 r
.6445 .41554 m .64363 .41798 L .64174 .41903 L F
.486 .313 .571 r
.36098 .52449 m .3633 .52161 L .36077 .52208 L F
.508 .277 .499 r
.44964 .5821 m .44686 .58522 L .44704 .58256 L F
.247 .085 .455 r
.34805 .57278 m .34751 .57427 L .3459 .5723 L F
0 .206 .722 r
.32558 .6336 m .32783 .63576 L .32627 .63211 L F
.46 .286 .558 r
.35504 .60176 m .35739 .60117 L .35735 .59847 L F
.571 .37 .57 r
.35443 .60457 m .35739 .60117 L .35504 .60176 L F
.537 .895 .974 r
.63395 .43876 m .63561 .43718 L .63765 .43715 L F
.63395 .43876 m .63316 .43814 L .63561 .43718 L F
.6 .768 .96 r
.34301 .53999 m .3452 .54136 L .34132 .54062 L F
.707 .464 .555 r
.3452 .54136 m .34421 .54287 L .34132 .54062 L F
.3452 .54136 m .34582 .54404 L .34421 .54287 L F
.492 .329 .587 r
.3452 .54136 m .34582 .54404 L .34759 .54071 L F
.3452 .54136 m .34582 .54404 L .34759 .54071 L F
.841 .74 .753 r
.42659 .49002 m .42261 .48972 L .42508 .48638 L F
.789 .832 .885 r
.42659 .49002 m .42452 .49073 L .42261 .48972 L F
.649 .65 .838 r
.42942 .48921 m .42659 .49002 L .42508 .48638 L F
.75 .972 .927 r
.64893 .41386 m .64566 .41627 L .6445 .41554 L F
.073 0 .438 r
.20378 .57626 m .20489 .57586 L .20487 .57276 L F
.131 .148 .61 r
.20378 .57626 m .20553 .57833 L .20489 .57586 L F
.221 .168 .583 r
.20416 .57902 m .20553 .57833 L .20378 .57626 L F
.817 .524 .493 r
.58471 .41037 m .58841 .41089 L .58854 .41328 L F
.437 0 0 r
.20646 .60617 m .20864 .60713 L .2045 .60665 L F
.847 .863 .854 r
.68104 .31864 m .67684 .32028 L .67978 .31717 L F
.565 0 0 r
.35073 .56677 m .3496 .56634 L .34628 .56381 L F
.651 .951 .949 r
.3515 .56511 m .3496 .56634 L .35073 .56677 L F
.726 .975 .739 r
.35073 .56677 m .34851 .56801 L .3515 .56511 L F
.8 .784 .838 r
.69045 .33377 m .6942 .33365 L .69302 .33218 L F
.606 .802 .975 r
.69302 .33218 m .6942 .33365 L .69744 .33252 L F
.876 .917 .851 r
.69844 .31066 m .69957 .30998 L .69823 .30888 L F
.822 .917 .901 r
.69823 .30888 m .69957 .30998 L .70196 .30712 L F
.618 .954 .807 r
.62939 .45096 m .63318 .44892 L .63126 .44902 L F
.469 .827 .561 r
.63318 .44892 m .63641 .44624 L .63489 .44745 L F
.535 .924 .88 r
.63126 .44902 m .63318 .44892 L .63489 .44745 L F
.82 1 .823 r
.23472 .53527 m .23175 .53818 L .23214 .5362 L F
.607 .95 .809 r
.23472 .53527 m .2354 .53408 L .23603 .53388 L F
.23472 .53527 m .23214 .5362 L .2354 .53408 L F
.088 0 .381 r
.64135 .42087 m .64287 .42152 L .64174 .41903 L F
.64135 .42087 m .64066 .4234 L .64287 .42152 L F
.185 0 .184 r
.38686 .59476 m .38864 .59444 L .39049 .59274 L F
.166 0 0 r
.32472 .68387 m .32232 .68401 L .32205 .68401 L F
.832 .979 .684 r
.29759 .52193 m .29769 .52186 L .29598 .52135 L F
.29759 .52193 m .29948 .51829 L .29769 .52186 L F
.775 .983 .73 r
.62769 .39947 m .62674 .40164 L .6293 .39884 L F
.572 .923 .732 r
.62769 .39947 m .6293 .39884 L .63124 .39725 L F
.695 .762 .903 r
.62985 .38768 m .63131 .38382 L .62882 .3875 L F
.62985 .38768 m .6328 .38656 L .63131 .38382 L F
.431 .244 .526 r
.34066 .60099 m .33822 .60426 L .33891 .60206 L F
.634 .099 0 r
.23602 .60841 m .23809 .61073 L .23909 .61096 L F
.737 .249 0 r
.23809 .61073 m .23989 .61248 L .23909 .61096 L F
.905 .812 .745 r
.34357 .69602 m .34574 .69493 L .34484 .69346 L F
.822 .624 .635 r
.3487 .69458 m .34484 .69346 L .34574 .69493 L F
.877 .968 .847 r
.55607 .41931 m .55711 .42018 L .55373 .42356 L F
.862 .969 .863 r
.55988 .41716 m .55711 .42018 L .55607 .41931 L F
.649 .442 .589 r
.36306 .64804 m .36623 .64511 L .36386 .64557 L F
.921 .527 .18 r
.65137 .40078 m .65374 .40458 L .65047 .40374 L F
.867 .686 .654 r
.65047 .40374 m .65374 .40458 L .65288 .40694 L F
.603 .292 .415 r
.34744 .55434 m .3474 .55627 L .34478 .55583 L F
.703 .375 .418 r
.35068 .55633 m .3474 .55627 L .34744 .55434 L F
0 0 0 r
.33459 .69167 m .33815 .69085 L .33658 .68931 L F
.783 .552 .586 r
.33386 .69323 m .33805 .69381 L .33815 .69085 L F
.925 .919 .537 r
.33815 .69085 m .33897 .68674 L .33658 .68931 L F
.967 .643 .308 r
.37953 .68451 m .37971 .68712 L .37808 .68353 L F
.37953 .68451 m .37971 .68712 L .37808 .68353 L F
.689 .974 .913 r
.36857 .64906 m .37191 .64698 L .36909 .64759 L F
.5 .452 .734 r
.695 .33729 m .69584 .34044 L .69794 .33956 L F
.234 .02 .37 r
.32361 .56344 m .32472 .56525 L .32529 .56272 L F
0 0 .443 r
.32361 .56344 m .32381 .56641 L .32472 .56525 L F
.323 .125 .449 r
.31225 .60993 m .31068 .60871 L .31233 .60744 L F
.31225 .60993 m .30946 .61169 L .31068 .60871 L F
.961 .814 .652 r
.54199 .43826 m .54373 .43952 L .54227 .44209 L F
.647 .79 .951 r
.33399 .52754 m .33597 .52896 L .33212 .52857 L F
0 0 0 r
.25602 .52373 m .25612 .52376 L .26182 .52296 L F
0 .214 .736 r
.26269 .51976 m .26299 .52027 L .26236 .52174 L F
.579 .932 .942 r
.26183 .52295 m .26236 .52174 L .26385 .52156 L F
.652 .288 .341 r
.26236 .52174 m .26615 .52085 L .26385 .52156 L F
.26236 .52174 m .26578 .52494 L .26615 .52085 L F
0 .214 .736 r
.26299 .52027 m .26578 .52494 L .26236 .52174 L F
.579 .932 .942 r
.26182 .52296 m .26236 .52174 L .26183 .52295 L F
.26182 .52296 m .25612 .52376 L .26236 .52174 L F
.894 .531 .347 r
.39046 .50309 m .38869 .50221 L .39116 .50083 L F
.39046 .50309 m .39038 .50324 L .38869 .50221 L F
.658 .754 .921 r
.39537 .50172 m .39046 .50309 L .39116 .50083 L F
0 .239 .756 r
.38308 .52047 m .38419 .52101 L .38396 .52249 L F
.71 .87 .957 r
.33862 .66441 m .33976 .6614 L .3374 .6638 L F
.33862 .66441 m .34212 .66307 L .33976 .6614 L F
.897 .816 .76 r
.39677 .6167 m .39883 .61805 L .4004 .61408 L F
.891 .546 .387 r
.55581 .45154 m .55774 .45218 L .55824 .45455 L F
.827 .581 .568 r
.41336 .50753 m .41386 .5109 L .40966 .50841 L F
.531 .375 .615 r
.4157 .50828 m .41386 .5109 L .41336 .50753 L F
.392 .504 .853 r
.41469 .5046 m .4157 .50828 L .41336 .50753 L F
.8 .992 .751 r
.70524 .30087 m .7072 .29989 L .70618 .2983 L F
.592 .196 .26 r
.59419 .45216 m .59299 .45422 L .59033 .45415 L F
.536 .135 .229 r
.59696 .45379 m .59299 .45422 L .59419 .45216 L F
.539 .128 .209 r
.59419 .45216 m .59695 .45231 L .59696 .45379 L F
.752 .969 .929 r
.23175 .53818 m .23026 .53778 L .23214 .5362 L F
.453 .395 .703 r
.43656 .51001 m .43499 .51221 L .43446 .51084 L F
.43656 .51001 m .4372 .51176 L .43499 .51221 L F
.84 .727 .739 r
.54171 .42399 m .53945 .42422 L .54018 .42267 L F
.54171 .42399 m .53769 .42569 L .53945 .42422 L F
.54171 .42399 m .54009 .42714 L .53769 .42569 L F
0 0 0 r
.54379 .42317 m .54363 .42259 L .5426 .42334 L F
.54379 .42317 m .5426 .42334 L .54171 .42399 L F
.54579 .42087 m .54363 .42259 L .54379 .42317 L F
.473 .867 .68 r
.54697 .42032 m .54363 .42259 L .54579 .42087 L F
0 0 0 r
.54579 .42087 m .54379 .42317 L .54542 .42349 L F
0 .489 .844 r
.54436 .42309 m .54379 .42317 L .54123 .42192 L F
.54542 .42349 m .54379 .42317 L .54436 .42309 L F
0 0 0 r
.54379 .42317 m .54171 .42399 L .54018 .42267 L F
.908 .922 .814 r
.31701 .5037 m .31548 .50445 L .31568 .50227 L F
.31701 .5037 m .3141 .50626 L .31548 .50445 L F
.278 0 0 r
.31694 .5037 m .31701 .5037 L .31568 .50227 L F
.31694 .5037 m .31782 .50404 L .31701 .5037 L F
.222 0 .16 r
.30691 .59784 m .30897 .59718 L .30975 .59456 L F
.154 .102 .541 r
.30975 .59456 m .31137 .59124 L .30977 .59167 L F
.30975 .59456 m .31167 .5942 L .31137 .59124 L F
.062 0 .101 r
.30975 .59456 m .30897 .59718 L .31167 .5942 L F
.5 .452 .734 r
.695 .33729 m .69794 .33956 L .69822 .33737 L F
.687 .303 0 r
.62626 .40648 m .62427 .40258 L .62521 .40567 L F
.685 .935 .967 r
.62523 .40566 m .62626 .40648 L .62521 .40567 L F
.906 .498 .131 r
.62721 .40723 m .62546 .40473 L .62626 .40648 L F
.687 .303 0 r
.62626 .40648 m .62546 .40473 L .62427 .40258 L F
.685 .935 .967 r
.62758 .40426 m .62626 .40648 L .62523 .40566 L F
.906 .498 .131 r
.62749 .40763 m .62721 .40723 L .62626 .40648 L F
.986 .711 .358 r
.62756 .41016 m .62749 .40763 L .62626 .40648 L F
.652 .873 .981 r
.62883 .40543 m .62749 .40763 L .62626 .40648 L F
.472 .64 .93 r
.63037 .40724 m .62749 .40763 L .62883 .40543 L F
.44 .249 .524 r
.62756 .41016 m .62749 .40763 L .63037 .40724 L F
.61 .714 .919 r
.37149 .66326 m .37552 .66536 L .37405 .66172 L F
.368 .821 .709 r
.37552 .66536 m .37064 .66752 L .3739 .66458 L F
.584 .601 .835 r
.37552 .66536 m .37646 .66119 L .37405 .66172 L F
.37552 .66536 m .37814 .66513 L .37646 .66119 L F
.431 .79 .996 r
.37639 .66402 m .37539 .66529 L .3739 .66458 L F
.54 .57 .834 r
.37814 .66513 m .37955 .66128 L .37646 .66119 L F
.495 .815 1 r
.37639 .66402 m .3739 .66458 L .37224 .66358 L F
.566 .35 .547 r
.37639 .66402 m .37955 .66128 L .37646 .66119 L F
.841 .897 .879 r
.37222 .66368 m .37378 .66469 L .37159 .66667 L F
.37224 .66358 m .37159 .66667 L .37064 .66752 L F
.726 .905 .958 r
.3662 .665 m .37149 .66326 L .37087 .66409 L F
.841 .897 .879 r
.37224 .66358 m .37064 .66752 L .37087 .66409 L F
.785 .672 .739 r
.37087 .66409 m .36688 .66708 L .3662 .665 L F
.37087 .66409 m .37064 .66752 L .36877 .6673 L F
.36787 .66634 m .36877 .6673 L .36688 .66708 L F
.37087 .66409 m .36877 .6673 L .36787 .66634 L F
.965 .874 .48 r
.36659 .66105 m .3662 .665 L .36568 .66388 L F
.29 .168 .536 r
.36879 .66669 m .36728 .6657 L .36568 .66388 L F
.36728 .6657 m .3662 .665 L .36577 .66407 L F
.36728 .6657 m .36577 .66407 L .36568 .66388 L F
.636 .258 .311 r
.37436 .66622 m .37224 .66358 L .36986 .6646 L F
.273 0 0 r
.36986 .6646 m .37224 .66358 L .37238 .66394 L F
.561 .013 0 r
.36979 .66224 m .37238 .66394 L .37154 .66324 L F
.36952 .66193 m .37154 .66324 L .3684 .66062 L F
.36979 .66224 m .37154 .66324 L .36952 .66193 L F
.841 .897 .879 r
.37224 .66358 m .3739 .66458 L .37378 .66469 L F
.37224 .66358 m .37378 .66469 L .37222 .66368 L F
0 0 0 r
.37149 .66326 m .37179 .66308 L .37224 .66358 L F
.37179 .66308 m .37405 .66172 L .37224 .66358 L F
.998 .825 .542 r
.37224 .66358 m .37405 .66172 L .37247 .66073 L F
0 0 .159 r
.37238 .66374 m .37224 .66358 L .37241 .66276 L F
.37238 .66394 m .37224 .66358 L .37238 .66374 L F
.37241 .66276 m .37224 .66358 L .37247 .66073 L F
.495 .815 1 r
.37639 .66402 m .37224 .66358 L .37436 .66622 L F
.57 .843 .499 r
.37739 .66274 m .37639 .66402 L .37436 .66622 L F
.37748 .66263 m .37639 .66402 L .37739 .66274 L F
.431 .79 .996 r
.37639 .66402 m .37552 .66536 L .37539 .66529 L F
.37639 .66402 m .37814 .66513 L .37552 .66536 L F
.622 .623 .831 r
.62187 .36916 m .61934 .37212 L .61864 .36979 L F
.62187 .36916 m .62331 .37292 L .61934 .37212 L F
.414 .104 .329 r
.42675 .5699 m .43031 .56685 L .42904 .56813 L F
.594 .126 .113 r
.43094 .5657 m .42953 .56712 L .42975 .56712 L F
.635 .86 .487 r
.43094 .5657 m .43031 .56685 L .43269 .56364 L F
.636 .887 .551 r
.42904 .56813 m .43031 .56685 L .43094 .5657 L F
.42904 .56813 m .43094 .5657 L .43159 .56717 L F
.382 .581 .919 r
.43425 .56708 m .43159 .56717 L .43094 .5657 L F
.594 .126 .113 r
.43094 .5657 m .42975 .56712 L .43425 .56708 L F
.635 .86 .487 r
.43094 .5657 m .43269 .56364 L .43278 .5635 L F
.968 .879 .692 r
.62427 .40258 m .62546 .40473 L .62674 .40164 L F
.77 .997 .828 r
.62427 .40258 m .62674 .40164 L .62769 .39947 L F
.254 .52 .91 r
.24906 .62448 m .25112 .62725 L .25179 .6256 L F
.002 .204 .717 r
.25112 .62725 m .25383 .62979 L .25179 .6256 L F
.725 .407 .442 r
.2349 .56654 m .23773 .56974 L .23804 .56731 L F
.843 .755 .765 r
.34767 .52824 m .35207 .53039 L .34949 .5267 L F
.34767 .52824 m .34737 .52997 L .35207 .53039 L F
.745 .901 .514 r
.34957 .53431 m .35207 .53039 L .34737 .52997 L F
.34957 .53431 m .35002 .53268 L .35207 .53039 L F
.717 .88 .481 r
.35207 .53039 m .35372 .52727 L .34949 .5267 L F
.35207 .53039 m .35239 .529 L .35372 .52727 L F
0 0 0 r
.35207 .53039 m .35185 .53152 L .35239 .529 L F
.35207 .53039 m .35002 .53268 L .35185 .53152 L F
.622 .851 .476 r
.63762 .4444 m .63641 .44624 L .63761 .44453 L F
.662 .917 .607 r
.63489 .44745 m .63641 .44624 L .63762 .4444 L F
.205 .025 .402 r
.3182 .5699 m .31957 .57122 L .32063 .56939 L F
.3182 .5699 m .31788 .57247 L .31957 .57122 L F
0 0 0 r
.35111 .63586 m .34999 .6404 L .35126 .63865 L F
.13 .237 .707 r
.35126 .63865 m .34999 .6404 L .35147 .64163 L F
.925 .768 .289 r
.29487 .65205 m .29524 .64929 L .295 .6479 L F
0 .092 .641 r
.23474 .56539 m .23773 .56974 L .2349 .56654 L F
.283 .458 .857 r
.37106 .59191 m .36962 .59213 L .36694 .58731 L F
.801 .714 .77 r
.37106 .59191 m .36836 .59429 L .36962 .59213 L F
.147 .538 .922 r
.28897 .64139 m .28834 .64224 L .28704 .63964 L F
.345 0 0 r
.37719 .62285 m .37723 .62151 L .37618 .62384 L F
.281 0 0 r
.3331 .577 m .33207 .57823 L .33465 .57768 L F
.606 .536 .75 r
.24907 .57295 m .25028 .5767 L .25285 .57609 L F
.634 .947 .735 r
.32216 .61807 m .31887 .62058 L .32089 .61939 L F
.363 0 .139 r
.32355 .61941 m .32216 .61807 L .32089 .61939 L F
.32355 .61941 m .32488 .61748 L .32216 .61807 L F
.181 0 0 r
.26499 .55923 m .2683 .55745 L .2661 .5584 L F
.578 .524 .759 r
.58733 .43844 m .58444 .43631 L .58607 .43534 L F
.783 .713 .786 r
.58471 .41037 m .58574 .41417 L .58204 .41355 L F
.817 .524 .493 r
.58471 .41037 m .58854 .41328 L .58574 .41417 L F
.478 .249 .487 r
.58574 .41417 m .58854 .41328 L .58505 .41657 L F
.83 .76 .785 r
.65405 .34716 m .64992 .34868 L .65269 .3457 L F
.65405 .34716 m .65164 .3504 L .64992 .34868 L F
.867 .875 .841 r
.65669 .34395 m .65405 .34716 L .65269 .3457 L F
.54 .249 .422 r
.45831 .57733 m .45506 .57873 L .45481 .57715 L F
.607 .405 .582 r
.32266 .54455 m .32222 .54711 L .31976 .54733 L F
.411 .481 .822 r
.32397 .54284 m .32266 .54455 L .3205 .54152 L F
0 0 .335 r
.32397 .54284 m .32222 .54711 L .32266 .54455 L F
.423 .051 .225 r
.33453 .58302 m .3334 .58466 L .33105 .58526 L F
.072 0 0 r
.33649 .58207 m .3334 .58466 L .33453 .58302 L F
.524 .047 .065 r
.27377 .64028 m .2779 .64003 L .27577 .6394 L F
0 .233 .752 r
.2779 .64003 m .278 .63883 L .27577 .6394 L F
.2779 .64003 m .28018 .64228 L .278 .63883 L F
.758 .971 .926 r
.37866 .71077 m .38145 .70918 L .37959 .70862 L F
.293 .773 .921 r
.38145 .70918 m .38214 .70832 L .37959 .70862 L F
.38145 .70918 m .38356 .70899 L .38214 .70832 L F
.533 .658 .916 r
.38145 .70918 m .38566 .71047 L .38356 .70899 L F
0 0 .198 r
.42767 .53335 m .42831 .53108 L .43001 .53285 L F
.744 .74 .848 r
.42831 .53108 m .43001 .53285 L .43233 .53159 L F
.42831 .53108 m .43001 .53285 L .43233 .53159 L F
.716 .742 .872 r
.60501 .38695 m .60352 .39085 L .60255 .38664 L F
.60501 .38695 m .60743 .3883 L .60352 .39085 L F
.627 .115 .01 r
.2398 .56043 m .24151 .56218 L .23777 .56156 L F
.848 .761 .767 r
.38164 .63648 m .38512 .6363 L .384 .63284 L F
.786 .731 .802 r
.38512 .6363 m .38793 .63321 L .384 .63284 L F
.628 .417 .577 r
.60745 .37884 m .60803 .3821 L .60499 .3818 L F
0 0 0 r
.60664 .3801 m .60745 .37884 L .60499 .3818 L F
.741 .868 .447 r
.60947 .37488 m .60745 .37884 L .60845 .37617 L F
.716 .827 .376 r
.60845 .37617 m .60745 .37884 L .60664 .3801 L F
.921 .532 .237 r
.60947 .37488 m .61196 .37843 L .60745 .37884 L F
.644 .367 .484 r
.60745 .37884 m .61039 .38098 L .60803 .3821 L F
.60745 .37884 m .61196 .37843 L .61039 .38098 L F
.534 .922 .898 r
.2989 .54007 m .29874 .53916 L .30054 .5402 L F
.2989 .54007 m .2967 .54026 L .29874 .53916 L F
.486 .432 .722 r
.29824 .56244 m .29513 .55969 L .29876 .5592 L F
.291 .098 .437 r
.30096 .5566 m .30097 .55943 L .29876 .5592 L F
0 0 .206 r
.29976 .56088 m .29876 .5592 L .30097 .55943 L F
.29976 .56088 m .29824 .56244 L .29876 .5592 L F
0 0 0 r
.34444 .68399 m .34591 .68159 L .34329 .68441 L F
.328 .502 .878 r
.34329 .68441 m .34701 .68768 L .34355 .68648 L F
0 0 .192 r
.34329 .68441 m .3438 .68575 L .34444 .68399 L F
.34329 .68441 m .34355 .68648 L .3438 .68575 L F
.347 0 0 r
.6328 .38656 m .63615 .38815 L .63427 .38632 L F
.688 .728 .881 r
.63427 .38632 m .63615 .38815 L .63869 .38663 L F
.338 .096 .392 r
.33866 .58115 m .33698 .57959 L .33914 .57887 L F
.33866 .58115 m .33649 .58207 L .33698 .57959 L F
.862 .844 .825 r
.34258 .51201 m .3448 .50832 L .34493 .51031 L F
.465 .103 .265 r
.34742 .50964 m .34699 .51138 L .34493 .51031 L F
.34493 .51031 m .34699 .51138 L .34742 .50964 L F
.375 .244 .573 r
.44993 .55592 m .44804 .55406 L .44895 .55328 L F
.44993 .55592 m .4474 .55746 L .44804 .55406 L F
.824 .655 .673 r
.38535 .6577 m .38186 .6597 L .38169 .65849 L F
0 0 .485 r
.38169 .65849 m .38246 .65898 L .38231 .65835 L F
0 0 0 r
.38253 .65828 m .38169 .65849 L .38098 .65866 L F
.852 .946 .879 r
.38169 .65849 m .38535 .6577 L .3839 .65693 L F
.824 .655 .673 r
.38535 .6577 m .38169 .65849 L .3839 .65693 L F
.843 .893 .874 r
.38169 .65849 m .3839 .65693 L .38184 .65638 L F
0 0 .485 r
.38169 .65849 m .38184 .65638 L .3839 .65693 L F
.38169 .65849 m .38231 .65835 L .38184 .65638 L F
0 0 0 r
.38098 .65866 m .38169 .65849 L .37987 .65893 L F
.751 .685 .788 r
.6878 .33689 m .69172 .33759 L .69045 .33377 L F
.042 0 .314 r
.37064 .66752 m .36914 .66869 L .36898 .6711 L F
.897 .816 .76 r
.39677 .6167 m .4004 .61408 L .39937 .61356 L F
.979 .825 .62 r
.4004 .61408 m .39978 .6107 L .39937 .61356 L F
.635 .86 .487 r
.43094 .5657 m .43278 .5635 L .43112 .56244 L F
.968 .792 .613 r
.43112 .56244 m .43278 .5635 L .43231 .56069 L F
.202 0 .066 r
.2878 .55651 m .28448 .55911 L .28574 .55749 L F
.434 .258 .541 r
.29302 .55288 m .29079 .55069 L .29282 .54997 L F
.29302 .55288 m .29081 .55366 L .29079 .55069 L F
.971 .922 .602 r
.40254 .60318 m .40313 .60533 L .40432 .60155 L F
.98 .916 .631 r
.40432 .60155 m .40463 .59724 L .40372 .60086 L F
.949 .941 .613 r
.40254 .60318 m .40432 .60155 L .40372 .60086 L F
.461 .142 .338 r
.29591 .54471 m .29537 .54674 L .29282 .54723 L F
.344 .039 .295 r
.29768 .546 m .29591 .54471 L .29886 .54357 L F
.29768 .546 m .29537 .54674 L .29591 .54471 L F
.52 .292 .51 r
.58762 .45451 m .58492 .45704 L .58478 .45506 L F
.475 .164 .357 r
.28898 .54412 m .2916 .54385 L .29197 .54201 L F
.265 0 .29 r
.29197 .54201 m .2916 .54385 L .29363 .54282 L F
0 .215 .739 r
.40111 .55988 m .40335 .56169 L .40329 .56302 L F
.995 .754 .422 r
.40335 .56169 m .40424 .56433 L .40329 .56302 L F
.535 .883 .643 r
.2847 .55149 m .28363 .55225 L .28633 .55006 L F
.958 .879 .48 r
.38387 .6773 m .3831 .68021 L .38457 .67781 L F
.237 0 .004 r
.38457 .67781 m .38561 .67948 L .38757 .67811 L F
.38457 .67781 m .3831 .68021 L .38561 .67948 L F
.709 .509 .616 r
.68556 .35331 m .688 .35034 L .6842 .34983 L F
.68556 .35331 m .68813 .35305 L .688 .35034 L F
.651 .352 .453 r
.69107 .35256 m .688 .35034 L .68813 .35305 L F
.69107 .35256 m .69102 .35031 L .688 .35034 L F
.501 .28 .511 r
.33881 .54437 m .3388 .54679 L .33624 .54733 L F
.543 .313 .516 r
.34146 .54607 m .33881 .54437 L .34421 .54287 L F
.34146 .54607 m .3388 .54679 L .33881 .54437 L F
.758 .672 .767 r
.36795 .62011 m .36973 .62395 L .36532 .6231 L F
.531 0 0 r
.36532 .6231 m .36973 .62395 L .36753 .62438 L F
.433 .504 .832 r
.37178 .62282 m .36973 .62395 L .36795 .62011 L F
.448 .881 .825 r
.36753 .62438 m .36973 .62395 L .37178 .62282 L F
.338 .27 .632 r
.22588 .58153 m .22401 .57991 L .22607 .57902 L F
.22588 .58153 m .22449 .58249 L .22401 .57991 L F
.813 .928 .91 r
.38785 .50726 m .38464 .50833 L .38631 .50564 L F
.743 .776 .879 r
.39026 .5061 m .38785 .50726 L .38631 .50564 L F
.808 .761 .81 r
.64992 .34868 m .65164 .3504 L .6483 .34951 L F
.875 .752 .724 r
.65164 .3504 m .64774 .3523 L .6483 .34951 L F
.65164 .3504 m .6511 .35264 L .64774 .3523 L F
.573 .84 .489 r
.69828 .3603 m .70101 .35707 L .69979 .3584 L F
0 0 0 r
.69875 .35971 m .69828 .3603 L .69979 .3584 L F
.061 0 0 r
.69797 .36069 m .69961 .35945 L .69828 .3603 L F
0 0 0 r
.69735 .36148 m .69828 .3603 L .69875 .35971 L F
.061 0 0 r
.69629 .36195 m .69797 .36069 L .69828 .3603 L F
.628 .834 .979 r
.69961 .35945 m .70392 .35832 L .70101 .35707 L F
.246 0 0 r
.69961 .35945 m .70483 .35993 L .70392 .35832 L F
.657 .87 .494 r
.38701 .65895 m .38472 .66215 L .38639 .66143 L F
.38 .187 .489 r
.38472 .66215 m .38457 .66471 L .38639 .66143 L F
0 .034 .576 r
.34585 .71219 m .34633 .71306 L .34609 .71228 L F
0 0 .217 r
.34633 .71306 m .34717 .7144 L .34609 .71228 L F
.34633 .71306 m .34598 .71586 L .34717 .7144 L F
.685 .559 .706 r
.32513 .55606 m .32473 .56016 L .32859 .55903 L F
.41 .239 .537 r
.32473 .56016 m .32952 .56072 L .32859 .55903 L F
.32473 .56016 m .32529 .56272 L .32952 .56072 L F
0 0 .405 r
.6268 .41929 m .62622 .41717 L .627 .4151 L F
.863 .791 .779 r
.6511 .35264 m .64887 .35641 L .64774 .3523 L F
.669 .363 .446 r
.57218 .45854 m .56824 .46074 L .56818 .45822 L F
.57218 .45854 m .57226 .46069 L .56824 .46074 L F
.655 .352 .447 r
.57661 .46009 m .57218 .45854 L .57475 .45806 L F
.57661 .46009 m .57226 .46069 L .57218 .45854 L F
.866 .969 .649 r
.42646 .52216 m .42537 .52358 L .42712 .52222 L F
.714 .977 .76 r
.42811 .5204 m .42646 .52216 L .42712 .52222 L F
.703 .94 .637 r
.42712 .52222 m .42537 .52358 L .42811 .5204 L F
.176 .697 .879 r
.33784 .49646 m .34009 .4964 L .34186 .49675 L F
0 .448 .782 r
.34275 .49663 m .34186 .49675 L .34009 .4964 L F
.34275 .49663 m .34509 .49767 L .34186 .49675 L F
0 0 0 r
.33976 .59222 m .33743 .5963 L .3394 .59464 L F
.322 .092 .401 r
.34177 .59151 m .33976 .59222 L .3394 .59464 L F
0 0 0 r
.29257 .56321 m .29513 .55969 L .29275 .56048 L F
.325 .165 .504 r
.20305 .59233 m .20495 .59205 L .20486 .5891 L F
.436 .328 .633 r
.20345 .59518 m .20495 .59205 L .20305 .59233 L F
.075 .347 .821 r
.21486 .59976 m .21647 .59961 L .21338 .59877 L F
.21486 .59976 m .21726 .60147 L .21647 .59961 L F
.302 .079 .4 r
.32513 .55606 m .32701 .55578 L .32724 .55376 L F
.685 .559 .706 r
.32513 .55606 m .32859 .55903 L .32701 .55578 L F
.261 .245 .651 r
.36437 .59799 m .36648 .60061 L .36616 .59806 L F
.361 .092 .363 r
.3282 .57542 m .326 .5761 L .32891 .57301 L F
.213 0 .297 r
.33019 .57445 m .32891 .57301 L .33051 .57207 L F
.33019 .57445 m .3282 .57542 L .32891 .57301 L F
0 0 0 r
.3274 .59099 m .32867 .58935 L .3305 .58792 L F
.136 0 .313 r
.32602 .52858 m .32549 .53101 L .32773 .52698 L F
.586 .513 .74 r
.31087 .53836 m .31275 .53391 L .31085 .53516 L F
.632 .397 .545 r
.61005 .44891 m .61007 .45146 L .60716 .4515 L F
.122 .007 .438 r
.6115 .45042 m .61005 .44891 L .61197 .44793 L F
.6115 .45042 m .61007 .45146 L .61005 .44891 L F
0 0 .163 r
.21556 .55396 m .21512 .55656 L .21641 .55277 L F
.285 .457 .855 r
.33776 .70755 m .33882 .70555 L .3373 .70566 L F
.33776 .70755 m .34063 .70884 L .33882 .70555 L F
.466 .88 .751 r
.37646 .65562 m .37197 .65771 L .37481 .65752 L F
.267 .11 .474 r
.37904 .6519 m .37646 .65562 L .37823 .65477 L F
.551 .328 .531 r
.37569 .68117 m .37808 .68353 L .37545 .68394 L F
.905 .749 .678 r
.38639 .66143 m .38535 .6577 L .38701 .65895 L F
.993 .747 .399 r
.39973 .55321 m .39938 .55622 L .40087 .55717 L F
.973 .67 .292 r
.39938 .55622 m .40111 .55988 L .40087 .55717 L F
.041 .214 .716 r
.37618 .62384 m .37888 .62664 L .37719 .62285 L F
.919 .821 .734 r
.61408 .37845 m .61349 .38286 L .61243 .38201 L F
.859 .573 .503 r
.32114 .53996 m .32397 .54284 L .3205 .54152 L F
.414 .572 .901 r
.46088 .56564 m .46156 .56954 L .45853 .56631 L F
.46088 .56564 m .46277 .56883 L .46156 .56954 L F
.171 .703 .711 r
.2859 .52453 m .28487 .52481 L .28732 .52427 L F
.2859 .52453 m .28234 .52531 L .28487 .52481 L F
.827 .644 .655 r
.62979 .42255 m .63106 .42059 L .6268 .41929 L F
.866 .956 .864 r
.54307 .41324 m .53902 .41582 L .54194 .41525 L F
.787 .482 .473 r
.54446 .41603 m .54307 .41324 L .54194 .41525 L F
.103 0 0 r
.349 .67045 m .34938 .66944 L .34658 .6712 L F
.416 0 0 r
.35158 .67028 m .34938 .66944 L .349 .67045 L F
.415 .042 .22 r
.43948 .5906 m .43828 .58883 L .44089 .58859 L F
.43948 .5906 m .43712 .59118 L .43828 .58883 L F
0 0 0 r
.22767 .55967 m .22671 .56357 L .22933 .56286 L F
.22767 .55967 m .22666 .56386 L .22671 .56357 L F
.443 .156 .381 r
.22671 .56357 m .22884 .56523 L .22933 .56286 L F
.22671 .56357 m .22644 .56579 L .22884 .56523 L F
.637 .686 .879 r
.72163 .34467 m .72019 .34713 L .72074 .3465 L F
.937 .646 .464 r
.36059 .61977 m .36247 .61805 L .36021 .61668 L F
.268 .069 .415 r
.33505 .59887 m .33466 .60108 L .33662 .59797 L F
.418 .039 .209 r
.26785 .56917 m .26677 .57168 L .26428 .57201 L F
.214 .059 .443 r
.27019 .56578 m .26986 .56878 L .26785 .56917 L F
.315 0 .163 r
.26914 .57105 m .26785 .56917 L .26986 .56878 L F
.26914 .57105 m .26677 .57168 L .26785 .56917 L F
.822 .988 .721 r
.31814 .64911 m .32069 .64605 L .32074 .64915 L F
.38 .461 .818 r
.32298 .64501 m .32069 .64605 L .3206 .64549 L F
.32298 .64501 m .3206 .64549 L .32174 .64427 L F
.32298 .64501 m .32023 .64336 L .32287 .64222 L F
0 0 .14 r
.32329 .64342 m .32298 .64501 L .32287 .64222 L F
.32329 .64342 m .32309 .64284 L .32197 .64545 L F
.32309 .64284 m .32287 .64222 L .32253 .64343 L F
.32309 .64284 m .32253 .64343 L .32197 .64545 L F
.38 .461 .818 r
.32174 .64427 m .3206 .64549 L .32023 .64336 L F
.215 .082 .474 r
.32277 .64795 m .32069 .64605 L .32298 .64501 L F
.32277 .64795 m .32074 .64915 L .32069 .64605 L F
0 0 0 r
.37643 .62949 m .37498 .63355 L .37646 .63214 L F
.298 .277 .667 r
.37498 .63355 m .37549 .63684 L .37717 .63275 L F
.658 .444 .583 r
.3803 .63482 m .38147 .63303 L .37739 .6323 L F
.37722 .63267 m .37739 .6323 L .37646 .63214 L F
.3803 .63482 m .37739 .6323 L .37722 .63267 L F
.73 .832 .381 r
.37713 .63285 m .37549 .63684 L .37541 .63684 L F
.298 .277 .667 r
.37709 .63258 m .37712 .63264 L .37728 .63249 L F
.658 .444 .583 r
.3802 .63497 m .3803 .63482 L .37724 .63268 L F
.37724 .63269 m .37724 .63268 L .37709 .63258 L F
.3802 .63497 m .37724 .63268 L .37724 .63269 L F
.3802 .63497 m .37709 .63258 L .37712 .63264 L F
.3802 .63497 m .37722 .63272 L .37728 .63249 L F
.37722 .63272 m .37712 .63264 L .37728 .63249 L F
.298 .277 .667 r
.37712 .63264 m .37717 .63275 L .37728 .63249 L F
.37498 .63355 m .37717 .63275 L .37709 .63258 L F
.167 0 0 r
.37549 .63684 m .37146 .63864 L .37541 .63684 L F
0 0 0 r
.37346 .63819 m .37541 .63684 L .37366 .63764 L F
.37346 .63819 m .37366 .63764 L .37146 .63864 L F
.37346 .63819 m .37146 .63864 L .37133 .63924 L F
.199 0 .17 r
.37346 .63819 m .37133 .63924 L .37022 .64159 L F
0 0 0 r
.37133 .63924 m .37146 .63864 L .37002 .64021 L F
.886 .877 .821 r
.37174 .63683 m .37346 .63819 L .37022 .64159 L F
.712 .21 0 r
.37334 .63854 m .37346 .63819 L .37174 .63683 L F
.37466 .63995 m .37346 .63819 L .37334 .63854 L F
.913 .976 .7 r
.37728 .63249 m .37713 .63285 L .37346 .63819 L F
.37713 .63285 m .37541 .63684 L .37357 .63812 L F
.37713 .63285 m .37357 .63812 L .37346 .63819 L F
.375 .476 .835 r
.37646 .63214 m .37498 .63355 L .37709 .63258 L F
.658 .444 .583 r
.37712 .63264 m .37709 .63258 L .37646 .63214 L F
.375 .476 .835 r
.37646 .63214 m .37709 .63258 L .37728 .63249 L F
.658 .444 .583 r
.37712 .63264 m .37646 .63214 L .37728 .63249 L F
.73 .832 .381 r
.37728 .63249 m .37717 .63275 L .37713 .63285 L F
.37717 .63275 m .37549 .63684 L .37713 .63285 L F
.984 .906 .605 r
.3612 .51295 m .36071 .51298 L .36055 .51143 L F
.172 .183 .63 r
.33414 .50897 m .33494 .50361 L .3333 .50659 L F
.736 .724 .839 r
.64774 .3523 m .64887 .35641 L .64657 .35669 L F
.797 .676 .731 r
.64887 .35641 m .64634 .35926 L .64657 .35669 L F
.4 .654 .961 r
.3928 .53235 m .39341 .53474 L .39256 .53295 L F
.83 .454 0 r
.39315 .53579 m .39341 .53474 L .3928 .53235 L F
.39315 .53579 m .39461 .53782 L .39341 .53474 L F
.958 .819 .384 r
.39526 .6813 m .39432 .68411 L .39483 .68312 L F
0 0 .362 r
.39666 .67742 m .39685 .68022 L .39526 .6813 L F
.108 0 .21 r
.39483 .68312 m .39653 .68334 L .39628 .68226 L F
.042 0 0 r
.39483 .68312 m .39528 .68506 L .39653 .68334 L F
.39483 .68312 m .39361 .68576 L .39528 .68506 L F
0 0 0 r
.39685 .68022 m .39432 .68411 L .39526 .6813 L F
.866 .702 .676 r
.39038 .50324 m .39026 .5061 L .38869 .50221 L F
.448 .674 .96 r
.63899 .4314 m .63958 .43298 L .64071 .43087 L F
0 0 .155 r
.63958 .43298 m .6401 .43279 L .64071 .43087 L F
.63958 .43298 m .63964 .43554 L .6401 .43279 L F
.082 .534 .904 r
.35704 .50114 m .35686 .50207 L .35519 .50071 L F
.35704 .50114 m .35865 .50243 L .35686 .50207 L F
.529 .12 .21 r
.3416 .67844 m .34647 .67927 L .34053 .68042 L F
.605 .048 0 r
.56875 .40535 m .5705 .40474 L .57073 .40577 L F
.404 .85 .918 r
.57105 .40379 m .5705 .40474 L .56875 .40535 L F
.57105 .40379 m .5733 .40402 L .5705 .40474 L F
.791 .502 .498 r
.5733 .40402 m .57073 .40577 L .5705 .40474 L F
.867 .875 .841 r
.65669 .34395 m .65269 .3457 L .65518 .34248 L F
.825 .853 .868 r
.65959 .34093 m .65669 .34395 L .65518 .34248 L F
.793 .736 .8 r
.37554 .6868 m .3738 .69386 L .37379 .68679 L F
.389 .818 .963 r
.33344 .49641 m .33784 .49646 L .33544 .49729 L F
.199 0 .241 r
.26648 .54703 m .26581 .54974 L .26327 .55045 L F
0 0 .115 r
.26406 .55118 m .26327 .55045 L .26581 .54974 L F
.26406 .55118 m .26306 .55302 L .26327 .55045 L F
.693 .698 .851 r
.62415 .39692 m .62252 .39872 L .62201 .39633 L F
.637 .686 .879 r
.72019 .34713 m .7232 .3466 L .72163 .34467 L F
.72163 .34467 m .7232 .3466 L .72019 .34713 L F
.528 0 0 r
.34355 .68648 m .34701 .68768 L .34484 .6874 L F
.814 .354 0 r
.34701 .68768 m .34654 .68859 L .34484 .6874 L F
.267 .21 .606 r
.34701 .68768 m .34749 .69118 L .34835 .69011 L F
.814 .354 0 r
.34701 .68768 m .34835 .69011 L .34654 .68859 L F
.78 .413 .362 r
.35007 .69095 m .34701 .68768 L .34956 .68726 L F
.505 .231 .432 r
.25025 .56651 m .25236 .56826 L .2549 .56472 L F
.424 .072 .262 r
.2549 .56472 m .25657 .56536 L .25696 .56392 L F
.592 .297 .438 r
.25236 .56826 m .25657 .56536 L .2549 .56472 L F
.97 .71 .484 r
.37109 .59816 m .36894 .59756 L .36648 .60061 L F
.37109 .59816 m .37086 .60087 L .36894 .59756 L F
.314 .517 .894 r
.37133 .59524 m .37109 .59816 L .36836 .59429 L F
.97 .71 .484 r
.36894 .59756 m .37109 .59816 L .37133 .59524 L F
.36894 .59756 m .37086 .60087 L .37109 .59816 L F
.974 .666 .314 r
.59673 .39583 m .59787 .3982 L .59695 .39659 L F
.747 .408 .408 r
.59787 .3982 m .59481 .39982 L .59695 .39659 L F
.59787 .3982 m .59889 .40024 L .59481 .39982 L F
.704 .981 .899 r
.63765 .43715 m .63902 .43499 L .63964 .43554 L F
.47 .599 .899 r
.64154 .38466 m .64317 .38774 L .64553 .38749 L F
.436 .223 .49 r
.64553 .38749 m .64317 .38774 L .64296 .39073 L F
.474 .058 .17 r
.33197 .54979 m .33493 .54958 L .33624 .54733 L F
.375 .55 .899 r
.33438 .54385 m .33624 .54733 L .33774 .54544 L F
.546 .383 .611 r
.3388 .54679 m .33632 .55017 L .33624 .54733 L F
.096 0 0 r
.33624 .54733 m .33755 .54847 L .33774 .54544 L F
.33624 .54733 m .33493 .54958 L .33755 .54847 L F
.203 .094 .5 r
.27864 .54116 m .28016 .54059 L .28053 .53748 L F
.805 .421 0 r
.40502 .58152 m .40688 .58515 L .40603 .58298 L F
.251 .757 .725 r
.25678 .52944 m .25674 .52959 L .25876 .52916 L F
.25678 .52944 m .25442 .53019 L .25674 .52959 L F
.95 .954 .72 r
.40177 .60731 m .40313 .60533 L .40254 .60318 L F
.462 .493 .805 r
.22418 .58768 m .22347 .59155 L .22062 .58988 L F
.22418 .58768 m .22556 .59134 L .22347 .59155 L F
.396 .138 .401 r
.36237 .57592 m .36174 .5795 L .35949 .57931 L F
.519 .293 .511 r
.36515 .5751 m .36174 .5795 L .36237 .57592 L F
.764 .708 .8 r
.38524 .62317 m .38635 .62648 L .38425 .62703 L F
.808 .873 .894 r
.64066 .4234 m .63837 .42696 L .64023 .42535 L F
.602 .547 .765 r
.64023 .42535 m .64287 .42152 L .64066 .4234 L F
.608 .26 .354 r
.24686 .56998 m .24288 .56909 L .24511 .56986 L F
.805 .461 .404 r
.31976 .54733 m .31876 .54937 L .31864 .54741 L F
.287 0 .019 r
.32222 .54711 m .31876 .54937 L .31976 .54733 L F
.516 .865 .611 r
.64023 .42535 m .63837 .42696 L .63699 .4279 L F
.963 .75 .568 r
.64951 .40019 m .65137 .40078 L .65047 .40374 L F
.2 0 .128 r
.23706 .54735 m .23566 .55004 L .23394 .55012 L F
.451 .092 .264 r
.23884 .54899 m .23566 .55004 L .23706 .54735 L F
.558 .069 .051 r
.2396 .54783 m .23884 .54899 L .23706 .54735 L F
.68 .667 .831 r
.30152 .51316 m .30305 .51747 L .3057 .51531 L F
.49 .368 .64 r
.44381 .54116 m .44411 .54363 L .44176 .54424 L F
.744 .386 .374 r
.37952 .56346 m .37578 .56528 L .37921 .56586 L F
.478 .293 .551 r
.37952 .56346 m .3821 .56288 L .38229 .55997 L F
.37952 .56346 m .3821 .56288 L .38229 .55997 L F
0 0 0 r
.3808 .56286 m .37952 .56346 L .3821 .56288 L F
.732 .573 0 r
.38068 .56237 m .38068 .56238 L .38078 .56286 L F
0 0 0 r
.38078 .56286 m .38076 .56286 L .38078 .56286 L F
.389 .355 .7 r
.3804 .56521 m .38325 .56435 L .3827 .56235 L F
0 0 0 r
.37921 .56586 m .3821 .56288 L .37952 .56346 L F
.37921 .56586 m .3804 .56521 L .3821 .56288 L F
.389 .355 .7 r
.3804 .56521 m .3827 .56235 L .38183 .56258 L F
.812 .782 .825 r
.37745 .56653 m .37798 .57065 L .37903 .56607 L F
.37616 .5669 m .37652 .56764 L .37745 .56653 L F
.37652 .56764 m .37798 .57065 L .37745 .56653 L F
.873 .792 .768 r
.3776 .56674 m .37734 .56991 L .37496 .56798 L F
.37903 .56607 m .37841 .56748 L .3776 .56674 L F
.37841 .56748 m .37734 .56991 L .3776 .56674 L F
.583 .027 0 r
.37578 .56528 m .37807 .56595 L .37812 .56568 L F
.744 .386 .374 r
.37952 .56346 m .37807 .56595 L .37578 .56528 L F
.771 .566 .622 r
.37921 .56586 m .37616 .5669 L .37903 .56607 L F
.744 .386 .374 r
.37807 .56595 m .3777 .56659 L .37578 .56528 L F
0 0 0 r
.37803 .56619 m .3777 .56659 L .37807 .56595 L F
.604 .214 .277 r
.37903 .56607 m .37496 .56798 L .37616 .5669 L F
.583 .027 0 r
.37812 .56568 m .37816 .56623 L .37921 .56586 L F
.574 .177 .253 r
.37847 .56634 m .37819 .5667 L .3777 .56659 L F
.583 .027 0 r
.37847 .56634 m .37819 .5667 L .37858 .56638 L F
.955 .932 .733 r
.37734 .56991 m .37798 .57065 L .37903 .56607 L F
.932 .631 .165 r
.38023 .5675 m .37921 .56586 L .37819 .5667 L F
.583 .027 0 r
.37816 .56623 m .37858 .56638 L .37921 .56586 L F
0 0 0 r
.38315 .56902 m .38 .57121 L .38074 .57017 L F
.932 .631 .165 r
.38036 .56571 m .38156 .56991 L .3804 .56521 L F
.38023 .5675 m .38136 .56953 L .38036 .56571 L F
.38136 .56953 m .38156 .56991 L .38036 .56571 L F
0 0 0 r
.38078 .56286 m .38078 .56286 L .3808 .56286 L F
.389 .355 .7 r
.3804 .56521 m .38246 .56144 L .38078 .56286 L F
.683 .559 .708 r
.38078 .56286 m .38087 .56503 L .38027 .56535 L F
.37995 .56411 m .38027 .56535 L .37847 .56634 L F
.38078 .56286 m .38027 .56535 L .37995 .56411 L F
0 .029 .568 r
.3804 .56521 m .38072 .56651 L .38074 .56637 L F
.3804 .56521 m .3805 .56554 L .38071 .56534 L F
.3805 .56554 m .38164 .56944 L .38076 .56559 L F
.3805 .56554 m .38076 .56559 L .38071 .56534 L F
.574 .177 .253 r
.38076 .56559 m .38045 .56573 L .38036 .56572 L F
.38089 .56554 m .38079 .56559 L .38076 .56559 L F
.38079 .56559 m .38045 .56573 L .38076 .56559 L F
.683 .559 .708 r
.38069 .56527 m .38076 .56559 L .38036 .56572 L F
.932 .631 .165 r
.38023 .5675 m .38036 .56572 L .38035 .56572 L F
.37969 .56662 m .38035 .56572 L .37921 .56586 L F
.38023 .5675 m .38035 .56572 L .37969 .56662 L F
.574 .177 .253 r
.38079 .56559 m .38023 .5675 L .37819 .5667 L F
.38089 .56554 m .38085 .56567 L .38079 .56559 L F
.38085 .56567 m .38023 .5675 L .38079 .56559 L F
.802 .785 .283 r
.38087 .56552 m .38085 .56567 L .38089 .56554 L F
0 .029 .568 r
.38071 .56534 m .38076 .56555 L .3822 .56599 L F
.38076 .56555 m .38164 .56944 L .382 .5672 L F
.38076 .56555 m .382 .5672 L .3822 .56599 L F
.802 .785 .283 r
.38046 .56515 m .38023 .5675 L .38085 .56567 L F
.38046 .56515 m .38085 .56567 L .38087 .56552 L F
0 .029 .568 r
.38074 .56637 m .38156 .56991 L .38164 .56944 L F
.38072 .56651 m .38156 .56991 L .38074 .56637 L F
.38121 .56496 m .3822 .56599 L .38325 .56435 L F
.3804 .56521 m .38071 .56534 L .38091 .56519 L F
.3804 .56521 m .38091 .56519 L .38093 .56505 L F
.683 .559 .708 r
.38083 .56525 m .38089 .56554 L .38076 .56559 L F
.38087 .56503 m .38076 .56559 L .38069 .56527 L F
.38078 .56286 m .37847 .56634 L .37803 .56619 L F
0 0 0 r
.38078 .56286 m .37803 .56619 L .3784 .56538 L F
.38076 .56286 m .37952 .56346 L .3808 .56286 L F
.38078 .56286 m .3784 .56538 L .38033 .56307 L F
.802 .785 .283 r
.38046 .56515 m .38086 .56551 L .38068 .56237 L F
.38086 .56551 m .38089 .56554 L .38088 .56536 L F
.683 .559 .708 r
.38087 .56503 m .38088 .56521 L .38083 .56525 L F
.38088 .56521 m .38089 .56554 L .38083 .56525 L F
.802 .785 .283 r
.38086 .56551 m .38088 .56536 L .38068 .56237 L F
0 .029 .568 r
.38093 .56505 m .38091 .56519 L .38121 .56496 L F
.38071 .56534 m .3822 .56599 L .38121 .56496 L F
.932 .631 .165 r
.38036 .56572 m .3804 .56521 L .37964 .56563 L F
.38036 .56572 m .37964 .56563 L .37921 .56586 L F
.683 .559 .708 r
.38087 .56503 m .38036 .56572 L .37847 .56634 L F
.574 .177 .253 r
.38036 .56572 m .37819 .5667 L .37847 .56634 L F
.38045 .56573 m .37819 .5667 L .38036 .56572 L F
.583 .027 0 r
.37816 .56623 m .37819 .5667 L .37847 .56634 L F
.683 .559 .708 r
.37803 .56619 m .37847 .56634 L .3777 .56659 L F
.583 .027 0 r
.37578 .56528 m .37637 .56563 L .37807 .56595 L F
.37637 .56563 m .37796 .56656 L .37803 .56619 L F
.37637 .56563 m .37803 .56619 L .37807 .56595 L F
0 .295 .761 r
.3777 .56659 m .37819 .5667 L .3764 .56565 L F
.37666 .56588 m .3764 .56565 L .37578 .56528 L F
.3777 .56659 m .3764 .56565 L .37666 .56588 L F
0 0 0 r
.37803 .56619 m .37807 .56595 L .3784 .56538 L F
.583 .027 0 r
.37796 .56656 m .37819 .5667 L .37812 .56568 L F
.732 .573 0 r
.38068 .56238 m .38089 .56554 L .38078 .56286 L F
.389 .355 .7 r
.38183 .56258 m .3827 .56235 L .38246 .56144 L F
0 0 0 r
.38033 .56307 m .3784 .56538 L .37952 .56346 L F
.37 0 0 r
.38 .57121 m .37798 .57065 L .38074 .57017 L F
.38 .57121 m .3763 .57169 L .37798 .57065 L F
.049 .013 .49 r
.66951 .39546 m .66754 .39478 L .66971 .39318 L F
.66951 .39546 m .66786 .39739 L .66754 .39478 L F
.643 .256 .297 r
.39527 .61301 m .39659 .6105 L .39322 .61094 L F
.991 .742 .45 r
.39569 .60716 m .39659 .6105 L .39783 .60977 L F
0 0 0 r
.39783 .60977 m .39659 .6105 L .39527 .61301 L F
.758 .971 .926 r
.37866 .71077 m .37959 .70862 L .37671 .71136 L F
.195 0 .277 r
.67362 .381 m .67161 .38207 L .67417 .37885 L F
.442 .265 .544 r
.67362 .381 m .67141 .38455 L .67161 .38207 L F
.035 0 0 r
.67184 .39208 m .67025 .39148 L .67205 .38976 L F
.67184 .39208 m .66971 .39318 L .67025 .39148 L F
.147 0 .18 r
.67639 .37758 m .67417 .37885 L .67679 .37588 L F
.356 .005 .224 r
.67951 .37522 m .67639 .37758 L .67679 .37588 L F
.792 .58 .614 r
.43185 .58897 m .42783 .5911 L .42938 .58966 L F
.602 .509 .722 r
.43476 .49903 m .43311 .50382 L .43185 .49966 L F
.43476 .49903 m .43563 .50296 L .43311 .50382 L F
.768 .748 .835 r
.42452 .49073 m .41998 .49237 L .42261 .48972 L F
.883 .632 .554 r
.56467 .45723 m .56228 .46009 L .56025 .45911 L F
.842 .652 .646 r
.56595 .45822 m .56228 .46009 L .56467 .45723 L F
.545 .838 .508 r
.39328 .70065 m .39607 .69764 L .39448 .69931 L F
0 0 .112 r
.35934 .59511 m .35735 .59847 L .35888 .59737 L F
0 0 .298 r
.35735 .59847 m .35834 .59967 L .35888 .59737 L F
.35735 .59847 m .35739 .60117 L .35834 .59967 L F
.792 .58 .614 r
.43185 .58897 m .43177 .59171 L .42783 .5911 L F
.275 .739 .948 r
.43233 .53159 m .43099 .53094 L .42831 .53108 L F
.43233 .53159 m .43099 .53094 L .42831 .53108 L F
.615 .916 .979 r
.43327 .52986 m .43099 .53094 L .43233 .53159 L F
.43233 .53159 m .43099 .53094 L .43327 .52986 L F
.862 .969 .863 r
.55988 .41716 m .55607 .41931 L .55829 .41788 L F
0 0 0 r
.56091 .41738 m .55988 .41716 L .55829 .41788 L F
.854 .716 .71 r
.54009 .42714 m .53912 .42955 L .53769 .42569 L F
.106 0 0 r
.36219 .59182 m .3648 .59084 L .36553 .58916 L F
0 0 0 r
.36694 .58731 m .36553 .58916 L .36788 .58568 L F
.36788 .58568 m .36553 .58916 L .36684 .58753 L F
.36553 .58916 m .36601 .58996 L .36684 .58753 L F
.36553 .58916 m .3648 .59084 L .36601 .58996 L F
.607 .941 .753 r
.33999 .65843 m .33819 .65992 L .33621 .66099 L F
.683 .267 .249 r
.55395 .44858 m .55238 .45045 L .54984 .4483 L F
.845 .486 .375 r
.55395 .44858 m .55581 .45154 L .55238 .45045 L F
.526 .526 .798 r
.24907 .57295 m .24995 .5687 L .24686 .56998 L F
.24907 .57295 m .25136 .57247 L .24995 .5687 L F
.606 .536 .75 r
.24907 .57295 m .25285 .57609 L .25136 .57247 L F
.403 .066 .276 r
.69346 .35148 m .69102 .35031 L .69107 .35256 L F
.69346 .35148 m .69395 .34978 L .69102 .35031 L F
.503 .007 .012 r
.24353 .54758 m .23884 .54899 L .2396 .54783 L F
.24353 .54758 m .24158 .54911 L .23884 .54899 L F
.199 0 0 r
.24441 .54837 m .24353 .54758 L .24585 .5469 L F
.24441 .54837 m .24158 .54911 L .24353 .54758 L F
.344 .144 .459 r
.32771 .57799 m .326 .5761 L .3282 .57542 L F
.32771 .57799 m .3257 .57879 L .326 .5761 L F
.486 .435 .726 r
.3675 .58247 m .36788 .58568 L .36991 .58434 L F
.584 .365 .549 r
.36991 .58434 m .36694 .58731 L .36788 .58568 L F
.36991 .58434 m .37194 .58816 L .36694 .58731 L F
.283 .458 .857 r
.37106 .59191 m .36694 .58731 L .37194 .58816 L F
.202 0 .086 r
.36684 .58753 m .36991 .58434 L .36788 .58568 L F
0 0 0 r
.29938 .64565 m .30061 .64265 L .30154 .64149 L F
.505 .49 .774 r
.44678 .54295 m .44578 .54724 L .44411 .54363 L F
.44678 .54295 m .44807 .54675 L .44578 .54724 L F
.526 .521 .794 r
.44926 .5503 m .44578 .54724 L .44807 .54675 L F
.574 .346 .531 r
.28319 .53388 m .28608 .53125 L .28344 .5317 L F
.364 .353 .714 r
.39941 .49589 m .40148 .49739 L .40008 .4935 L F
.64 .252 .294 r
.39941 .49589 m .40031 .4986 L .40148 .49739 L F
.679 .492 .627 r
.32641 .57888 m .32893 .58115 L .33008 .57938 L F
.32651 .57938 m .32893 .58115 L .32641 .57888 L F
.3257 .57879 m .32618 .58157 L .32893 .58115 L F
.141 .018 .439 r
.32771 .57799 m .32769 .58075 L .32689 .58119 L F
.32671 .58034 m .32689 .58119 L .32618 .58157 L F
.32771 .57799 m .32689 .58119 L .32671 .58034 L F
.679 .492 .627 r
.3257 .57879 m .32651 .57938 L .32641 .57888 L F
.494 .826 .53 r
.32893 .58115 m .33207 .57823 L .33008 .57938 L F
.64 .495 .67 r
.28898 .54412 m .28621 .54759 L .28898 .54641 L F
0 0 0 r
.28633 .55006 m .28898 .54641 L .28621 .54759 L F
.764 .611 .689 r
.61408 .37845 m .61039 .38098 L .61196 .37843 L F
.799 .69 .745 r
.384 .63284 m .38793 .63321 L .3869 .62858 L F
.733 .65 .766 r
.3869 .62858 m .38793 .63321 L .3906 .63006 L F
.493 .515 .808 r
.43899 .50461 m .43827 .50812 L .43563 .50296 L F
0 0 0 r
.43874 .50852 m .43827 .50812 L .43899 .50461 L F
.43874 .50852 m .43656 .51001 L .43827 .50812 L F
.69822 .33737 m .69809 .33885 L .69872 .33602 L F
.69822 .33737 m .69794 .33956 L .69809 .33885 L F
.639 .907 .599 r
.37179 .61329 m .36817 .6175 L .36915 .61604 L F
.64 .624 .818 r
.37179 .61329 m .37143 .61584 L .36817 .6175 L F
.728 .63 .749 r
.37143 .61584 m .36795 .62011 L .36817 .6175 L F
0 0 .194 r
.36817 .6175 m .369 .61826 L .36915 .61604 L F
.36817 .6175 m .36795 .62011 L .369 .61826 L F
.977 .801 .385 r
.40295 .57146 m .40368 .57241 L .40399 .56974 L F
.959 .826 .395 r
.40295 .57146 m .40399 .56974 L .40345 .56882 L F
0 0 0 r
.34719 .68024 m .34607 .68177 L .34636 .68252 L F
.34607 .68177 m .34444 .68399 L .34636 .68252 L F
.773 .686 .768 r
.3438 .68575 m .34788 .68616 L .34636 .68252 L F
.697 .264 .217 r
.34617 .68811 m .34788 .68616 L .3438 .68575 L F
.979 .682 .332 r
.34643 .6838 m .34788 .68616 L .34662 .68728 L F
.34636 .68252 m .34749 .68521 L .34643 .6838 L F
.34749 .68521 m .34788 .68616 L .34643 .6838 L F
.11 .001 .437 r
.34636 .68252 m .34643 .6838 L .348 .6851 L F
.782 .925 .553 r
.34662 .68728 m .34788 .68616 L .34617 .68811 L F
.772 .903 .932 r
.34663 .68727 m .34961 .683 L .348 .6851 L F
.34662 .68728 m .34663 .68727 L .34663 .68727 L F
.34663 .68727 m .34961 .683 L .34663 .68727 L F
.34662 .68728 m .35128 .68437 L .34961 .683 L F
.608 .433 .619 r
.34662 .68728 m .35131 .6874 L .35128 .68437 L F
.255 .724 .944 r
.34685 .68659 m .35131 .6874 L .34665 .68728 L F
.11 .001 .437 r
.34647 .68459 m .34662 .68728 L .3475 .6859 L F
.255 .724 .944 r
.34685 .68659 m .34665 .68728 L .34662 .68728 L F
.996 .761 .446 r
.34977 .68827 m .35131 .6874 L .34823 .68684 L F
.34899 .68782 m .34823 .68684 L .34685 .68659 L F
.34977 .68827 m .34823 .68684 L .34899 .68782 L F
0 .363 .82 r
.34805 .68615 m .34962 .68808 L .34685 .68659 L F
.34962 .68808 m .34977 .68827 L .3493 .688 L F
.34962 .68808 m .3493 .688 L .34685 .68659 L F
.11 .001 .437 r
.34643 .6838 m .34647 .68459 L .348 .6851 L F
.34647 .68459 m .3475 .6859 L .348 .6851 L F
0 0 0 r
.34671 .68089 m .34591 .68159 L .34444 .68399 L F
.773 .686 .768 r
.3438 .68575 m .34636 .68252 L .34444 .68399 L F
.11 .001 .437 r
.34636 .68252 m .34691 .68395 L .34469 .6816 L F
0 .067 .601 r
.3448 .68161 m .348 .6851 L .34531 .68165 L F
.34469 .6816 m .34516 .6821 L .3448 .68161 L F
.34516 .6821 m .348 .6851 L .3448 .68161 L F
.11 .001 .437 r
.34636 .68252 m .348 .6851 L .34691 .68395 L F
.655 .363 .464 r
.34647 .67927 m .34639 .68149 L .34469 .6816 L F
.34639 .68149 m .34636 .68252 L .34595 .68229 L F
.34639 .68149 m .34595 .68229 L .34469 .6816 L F
0 0 0 r
.34719 .68024 m .3469 .68054 L .34671 .68089 L F
.3469 .68054 m .34591 .68159 L .34671 .68089 L F
.524 .776 .989 r
.56657 .41959 m .56379 .42018 L .56501 .41821 L F
.56657 .41959 m .56379 .42018 L .56501 .41821 L F
.582 .203 .289 r
.23424 .5949 m .23578 .5971 L .23594 .59442 L F
.23424 .5949 m .23183 .59769 L .23578 .5971 L F
.312 .137 .475 r
.23578 .5971 m .23424 .5949 L .23594 .59442 L F
.681 .832 .956 r
.25396 .57128 m .25136 .57247 L .25553 .57275 L F
.797 .67 .724 r
.25136 .57247 m .25285 .57609 L .25553 .57275 L F
.918 .636 .493 r
.42742 .58045 m .42875 .58466 L .4305 .58234 L F
.107 0 0 r
.4305 .58234 m .43123 .58357 L .43303 .58228 L F
.4305 .58234 m .42875 .58466 L .43012 .58406 L F
.43071 .5827 m .43012 .58406 L .43123 .58357 L F
.4305 .58234 m .43012 .58406 L .43071 .5827 L F
.965 .637 .316 r
.42707 .58329 m .42875 .58466 L .42742 .58045 L F
.613 .829 .983 r
.43123 .58357 m .42875 .58466 L .42707 .58329 L F
.43123 .58357 m .42707 .58329 L .42913 .58309 L F
.977 .752 .335 r
.42933 .58585 m .43004 .58413 L .42913 .58309 L F
.42939 .58659 m .42998 .58438 L .42933 .58585 L F
.42998 .58438 m .43004 .58413 L .42933 .58585 L F
.586 .321 .482 r
.4439 .58588 m .44364 .5885 L .44089 .58859 L F
.563 .302 .478 r
.44646 .58737 m .4439 .58588 L .44686 .58522 L F
.44646 .58737 m .44364 .5885 L .4439 .58588 L F
.844 .442 0 r
.40368 .57241 m .40485 .57522 L .40577 .57603 L F
.992 .773 .505 r
.40401 .57766 m .40577 .57603 L .40485 .57522 L F
.40401 .57766 m .40542 .57877 L .40577 .57603 L F
.82 .701 .734 r
.54649 .44303 m .54198 .44474 L .54227 .44209 L F
.54649 .44303 m .54565 .44565 L .54198 .44474 L F
.441 .238 .507 r
.35731 .58204 m .35773 .58457 L .35428 .58563 L F
.319 .111 .432 r
.35773 .58457 m .35437 .5886 L .35428 .58563 L F
.044 .401 .856 r
.39299 .51887 m .39582 .51929 L .39151 .5176 L F
.834 .537 .486 r
.54198 .44474 m .54565 .44565 L .54583 .44825 L F
.764 .376 .318 r
.54565 .44565 m .54984 .4483 L .54583 .44825 L F
.795 .674 .731 r
.38869 .50221 m .39026 .5061 L .38631 .50564 L F
.733 .874 .947 r
.33976 .6614 m .34212 .66307 L .34393 .66155 L F
.958 .937 .719 r
.69585 .31366 m .69651 .31516 L .69844 .31066 L F
.951 .675 .224 r
.69581 .31624 m .69651 .31516 L .69585 .31366 L F
.69581 .31624 m .69671 .31757 L .69651 .31516 L F
.925 .689 .2 r
.41497 .56391 m .41433 .56476 L .41348 .56231 L F
.41497 .56391 m .4149 .56595 L .41433 .56476 L F
.55 .414 .649 r
.35371 .5455 m .3568 .54313 L .35479 .54391 L F
.582 .532 .764 r
.37824 .60241 m .38004 .59833 L .37776 .60113 L F
.37824 .60241 m .38076 .60173 L .38004 .59833 L F
.301 .65 .969 r
.26144 .63128 m .2657 .63293 L .26509 .63093 L F
.462 .846 .984 r
.2657 .63293 m .26687 .63123 L .26509 .63093 L F
.2657 .63293 m .26861 .63243 L .26708 .63128 L F
.26687 .63123 m .26708 .63128 L .26692 .63115 L F
.2657 .63293 m .26708 .63128 L .26687 .63123 L F
.242 .726 .929 r
.25901 .6304 m .26144 .63128 L .26509 .63093 L F
.25901 .6304 m .26509 .63093 L .26199 .6304 L F
.71 .185 0 r
.26469 .6308 m .26736 .63153 L .26699 .63273 L F
0 .524 .752 r
.26199 .6304 m .26557 .63095 L .26438 .63054 L F
.26557 .63095 m .26692 .63115 L .26438 .63054 L F
.26199 .6304 m .26509 .63093 L .26692 .63115 L F
.152 .625 .926 r
.25982 .62959 m .26199 .6304 L .26438 .63054 L F
.25982 .62959 m .26285 .63022 L .26284 .62977 L F
.26285 .63022 m .26438 .63054 L .26284 .62977 L F
.709 .181 0 r
.26438 .63054 m .26467 .63216 L .26309 .6301 L F
.26438 .63054 m .26309 .6301 L .26284 .62977 L F
0 0 .553 r
.26284 .62977 m .26467 .63216 L .26282 .62897 L F
.26284 .62977 m .26282 .62897 L .26262 .62863 L F
.71 .185 0 r
.26438 .63054 m .26587 .63103 L .26469 .6308 L F
.26587 .63103 m .26736 .63153 L .26469 .6308 L F
.242 .705 .948 r
.26692 .63115 m .26861 .63243 L .2704 .63226 L F
.71 .185 0 r
.26736 .63153 m .268 .63174 L .26789 .63184 L F
.26736 .63153 m .26789 .63184 L .26699 .63273 L F
.462 .846 .984 r
.26687 .63123 m .26692 .63115 L .26669 .63113 L F
.26687 .63123 m .26669 .63113 L .26509 .63093 L F
.529 .31 .526 r
.31074 .55064 m .31058 .55344 L .30764 .55395 L F
.412 .31 .628 r
.3124 .54703 m .31278 .54992 L .31074 .55064 L F
.297 .123 .468 r
.31242 .55244 m .31074 .55064 L .31278 .54992 L F
.31242 .55244 m .31058 .55344 L .31074 .55064 L F
.793 .736 .8 r
.37554 .6868 m .37756 .68929 L .3738 .69386 L F
.744 .283 .157 r
.69598 .32689 m .69826 .32913 L .69939 .32774 L F
.474 0 0 r
.23989 .61248 m .24249 .61314 L .24437 .61252 L F
.612 .079 0 r
.24249 .61314 m .2464 .61388 L .24437 .61252 L F
.147 .538 .922 r
.28897 .64139 m .28704 .63964 L .28888 .639 L F
.363 .183 .498 r
.31504 .60411 m .31482 .60712 L .31233 .60744 L F
.351 .105 .394 r
.31482 .60712 m .31225 .60993 L .31233 .60744 L F
.382 .054 .28 r
.30136 .62865 m .3002 .62597 L .30208 .6262 L F
.30136 .62865 m .29913 .62922 L .3002 .62597 L F
.547 .492 .746 r
.44993 .55592 m .44819 .55999 L .4474 .55746 L F
0 0 .37 r
.38177 .60343 m .38314 .60066 L .38076 .60173 L F
.648 .903 .581 r
.27248 .52629 m .27225 .52708 L .27442 .5263 L F
.27248 .52629 m .27122 .52795 L .27225 .52708 L F
.659 .718 .893 r
.27225 .52708 m .27569 .52713 L .27442 .5263 L F
.624 .516 .711 r
.40325 .5059 m .40187 .50647 L .40061 .50437 L F
.877 .968 .847 r
.55607 .41931 m .55373 .42356 L .55329 .41975 L F
.478 .824 .998 r
.38355 .62224 m .38524 .62317 L .38277 .62369 L F
.21 0 .283 r
.67362 .381 m .67417 .37885 L .67639 .37758 L F
.815 .684 .72 r
.27002 .62511 m .26502 .62253 L .26745 .62197 L F
.27002 .62511 m .26648 .62647 L .26502 .62253 L F
.304 .594 .946 r
.27153 .6243 m .27002 .62511 L .26745 .62197 L F
.556 .931 .903 r
.27378 .62409 m .27368 .62297 L .27534 .62288 L F
.27378 .62409 m .27153 .6243 L .27368 .62297 L F
0 .045 .612 r
.7064 .36224 m .70798 .366 L .70777 .36436 L F
0 0 .573 r
.70798 .366 m .70925 .36664 L .70777 .36436 L F
.70798 .366 m .70949 .36815 L .70925 .36664 L F
0 0 .362 r
.32859 .55903 m .32952 .55545 L .32701 .55578 L F
.32859 .55903 m .32969 .55777 L .32952 .55545 L F
.817 .667 .697 r
.32952 .56072 m .32969 .55777 L .32859 .55903 L F
.286 .404 .808 r
.34628 .56381 m .3496 .56634 L .34755 .56197 L F
0 0 0 r
.3482 .55984 m .34935 .55832 L .35068 .55633 L F
.461 .057 .186 r
.3482 .55984 m .35017 .56149 L .34935 .55832 L F
.3482 .55984 m .34755 .56197 L .35017 .56149 L F
.721 .265 .166 r
.25386 .54891 m .25239 .54968 L .24977 .54749 L F
.071 0 0 r
.25587 .54818 m .25239 .54968 L .25386 .54891 L F
.863 .931 .549 r
.39961 .68978 m .40155 .68665 L .40051 .68582 L F
.39961 .68978 m .39971 .69041 L .40155 .68665 L F
.801 .714 .77 r
.37106 .59191 m .37321 .59518 L .36836 .59429 L F
.314 .517 .894 r
.37133 .59524 m .36836 .59429 L .37321 .59518 L F
.533 .895 .973 r
.27722 .51985 m .27229 .5203 L .27567 .51883 L F
.423 .838 .968 r
.27741 .51863 m .27722 .51985 L .27567 .51883 L F
.27741 .51863 m .27961 .51935 L .27722 .51985 L F
.029 .273 .77 r
.70198 .33837 m .70247 .34047 L .70064 .33707 L F
0 .09 .608 r
.70456 .34114 m .70247 .34047 L .70198 .33837 L F
.70456 .34114 m .70354 .34269 L .70247 .34047 L F
.736 .724 .839 r
.64774 .3523 m .64657 .35669 L .64485 .3555 L F
.906 .73 .653 r
.64657 .35669 m .64634 .35926 L .64485 .3555 L F
.664 .618 .793 r
.33278 .68699 m .33459 .69167 L .33658 .68931 L F
.76 .908 .522 r
.29068 .56652 m .2911 .56504 L .29257 .56321 L F
.528 .405 .656 r
.29257 .56321 m .29309 .56603 L .29068 .56652 L F
.481 .814 .999 r
.29309 .56603 m .2911 .56504 L .29068 .56652 L F
.876 .917 .851 r
.69844 .31066 m .69823 .30888 L .69742 .30945 L F
.958 .937 .719 r
.69585 .31366 m .69844 .31066 L .69742 .30945 L F
.229 .044 .411 r
.6236 .39396 m .62201 .39633 L .62182 .39513 L F
.424 .222 .499 r
.22843 .57503 m .22607 .57902 L .22629 .57574 L F
.562 .935 .89 r
.33513 .52509 m .33574 .5242 L .336 .52487 L F
.388 .834 .934 r
.336 .52487 m .33574 .5242 L .33892 .52384 L F
0 0 0 r
.34658 .6712 m .34688 .67204 L .349 .67045 L F
.34658 .6712 m .34538 .67358 L .34688 .67204 L F
.617 .363 .511 r
.57862 .45807 m .57661 .46009 L .57475 .45806 L F
.727 .292 0 r
.32975 .53713 m .32925 .53677 L .32789 .53447 L F
.816 .956 .618 r
.32762 .54015 m .32925 .53677 L .32975 .53713 L F
0 .308 .783 r
.26088 .61974 m .26349 .62203 L .26204 .62119 L F
.26 .483 .884 r
.37695 .60625 m .37606 .60805 L .37575 .60656 L F
.908 .861 .782 r
.37968 .57866 m .38094 .57394 L .38225 .57448 L F
.724 .605 .724 r
.38356 .70899 m .38566 .71047 L .38697 .70603 L F
.536 .369 .601 r
.68783 .36875 m .68554 .37114 L .68508 .36919 L F
1 .828 .521 r
.32765 .69604 m .32882 .69721 L .32708 .69874 L F
0 .361 .741 r
.32882 .69721 m .32929 .69709 L .32765 .69604 L F
.32882 .69721 m .33147 .69829 L .32929 .69709 L F
.318 .772 .954 r
.33142 .51401 m .32719 .51385 L .32946 .51558 L F
.449 .736 .989 r
.24699 .62496 m .24771 .6241 L .24543 .62314 L F
.24699 .62496 m .24906 .62448 L .24771 .6241 L F
.806 .322 0 r
.3214 .52513 m .31796 .52166 L .32072 .52294 L F
.32133 .52507 m .31993 .52441 L .31796 .52166 L F
0 .062 .617 r
.32184 .52319 m .3214 .52513 L .32072 .52294 L F
.826 .416 .267 r
.31796 .52166 m .31993 .52441 L .31658 .52265 L F
.146 0 0 r
.32184 .52319 m .31866 .5238 L .31993 .52441 L F
.707 .172 0 r
.31993 .52441 m .31791 .52395 L .31658 .52265 L F
.146 0 0 r
.31866 .5238 m .31791 .52395 L .31993 .52441 L F
.806 .322 0 r
.3214 .52513 m .31993 .52441 L .32133 .52507 L F
.646 .909 .981 r
.32184 .52319 m .31993 .52441 L .3214 .52513 L F
.939 .947 .762 r
.27294 .53113 m .27442 .5263 L .27457 .52946 L F
.27294 .53113 m .27207 .53196 L .27442 .5263 L F
.411 .427 .766 r
.44245 .52389 m .44147 .5282 L .44077 .52448 L F
.44245 .52389 m .44339 .52763 L .44147 .5282 L F
.375 .302 .646 r
.44339 .52763 m .44394 .53026 L .44147 .5282 L F
.32 .301 .681 r
.44147 .5282 m .44394 .53026 L .44224 .53076 L F
0 0 .457 r
.33288 .56107 m .3331 .56278 L .33194 .56042 L F
.816 .956 .618 r
.32762 .54015 m .32698 .54037 L .32925 .53677 L F
.349 .121 .42 r
.22171 .58551 m .2217 .58839 L .21923 .58881 L F
.382 .226 .542 r
.2217 .58839 m .22062 .58988 L .21923 .58881 L F
.318 .206 .565 r
.35761 .51207 m .35556 .51342 L .3559 .51286 L F
0 .519 .799 r
.27656 .52686 m .27647 .52669 L .27442 .5263 L F
.27799 .52724 m .27715 .52694 L .27656 .52686 L F
.27715 .52694 m .27647 .52669 L .27656 .52686 L F
.208 .124 .534 r
.27804 .52705 m .27902 .5289 L .27647 .52923 L F
.505 .868 .985 r
.27882 .52595 m .27799 .52724 L .28033 .5265 L F
.208 .124 .534 r
.2785 .5264 m .27865 .52712 L .27804 .52705 L F
.27865 .52712 m .27902 .5289 L .27804 .52705 L F
.27882 .52595 m .27884 .52631 L .2785 .5264 L F
.27884 .52631 m .27902 .5289 L .2785 .5264 L F
0 .519 .799 r
.27799 .52724 m .27656 .52686 L .27569 .52713 L F
.27656 .52686 m .27442 .5263 L .27562 .52709 L F
.27656 .52686 m .27562 .52709 L .27569 .52713 L F
.791 .313 0 r
.40004 .52564 m .39964 .52632 L .39874 .52421 L F
.40004 .52564 m .40124 .52747 L .39964 .52632 L F
.171 .314 .768 r
.44827 .56781 m .44732 .56945 L .44599 .56599 L F
.449 .676 .961 r
.44827 .56781 m .45027 .56962 L .44732 .56945 L F
.547 .284 .468 r
.31058 .55344 m .3072 .55618 L .30764 .55395 L F
.972 .737 .524 r
.32682 .53423 m .32504 .53352 L .32549 .53101 L F
0 0 0 r
.32779 .52977 m .32729 .53424 L .32771 .53074 L F
0 .447 .76 r
.32682 .53423 m .32727 .53433 L .32504 .53352 L F
.32727 .53433 m .32789 .53447 L .32729 .53426 L F
.32727 .53433 m .32729 .53426 L .32504 .53352 L F
.768 .494 .519 r
.32789 .53447 m .32493 .53624 L .32504 .53352 L F
0 0 0 r
.32729 .53424 m .32726 .53455 L .3273 .53422 L F
.32729 .53424 m .3273 .53422 L .32771 .53074 L F
.393 .246 .559 r
.31225 .60993 m .30964 .61314 L .30946 .61169 L F
.354 0 0 r
.59462 .38627 m .59854 .38701 L .59544 .386 L F
.193 0 .147 r
.73548 .34308 m .73537 .34512 L .73289 .34624 L F
.178 .152 .589 r
.73697 .33919 m .73548 .34308 L .73566 .3398 L F
.73697 .33919 m .73751 .34153 L .73548 .34308 L F
0 0 .1 r
.73751 .34153 m .73537 .34512 L .73548 .34308 L F
.744 .945 .624 r
.39448 .69931 m .39607 .69764 L .39721 .69583 L F
0 0 .035 r
.26697 .54814 m .26648 .54703 L .26834 .54697 L F
.26697 .54814 m .26581 .54974 L .26648 .54703 L F
.401 .289 .61 r
.38366 .61955 m .38165 .62023 L .38132 .61741 L F
.576 .278 .426 r
.37981 .61871 m .38366 .61955 L .38132 .61741 L F
.513 .392 .652 r
.28898 .54412 m .29167 .54546 L .2916 .54385 L F
.28898 .54412 m .28898 .54641 L .29167 .54546 L F
.635 .267 .327 r
.38018 .62704 m .38425 .62703 L .38247 .62913 L F
.15 .263 .726 r
.38018 .62704 m .38247 .62913 L .38123 .62527 L F
.693 .961 .944 r
.37888 .62664 m .38018 .62704 L .38123 .62527 L F
.564 .362 .566 r
.35373 .5341 m .35019 .53754 L .35189 .53672 L F
.956 .797 .644 r
.64253 .35876 m .6435 .36253 L .64185 .36134 L F
.828 .801 .826 r
.6435 .36253 m .64017 .36131 L .64185 .36134 L F
.6435 .36253 m .64283 .36302 L .64017 .36131 L F
.783 .717 .79 r
.64253 .35876 m .64634 .35926 L .6435 .36253 L F
.611 .573 .786 r
.61651 .3884 m .61809 .38409 L .61537 .38522 L F
.61651 .3884 m .61966 .38803 L .61809 .38409 L F
.392 .467 .818 r
.61651 .3884 m .61999 .39136 L .61966 .38803 L F
.425 .194 .458 r
.22449 .58249 m .22391 .5864 L .22171 .58551 L F
.61 .322 .455 r
.22418 .58768 m .22171 .58551 L .22391 .5864 L F
.22418 .58768 m .2217 .58839 L .22171 .58551 L F
0 .193 .717 r
.60936 .40851 m .60905 .4104 L .61099 .41207 L F
.061 .264 .756 r
.60905 .4104 m .61144 .41398 L .61099 .41207 L F
.403 .793 .989 r
.57656 .39535 m .57415 .39657 L .57468 .39635 L F
.675 .665 .833 r
.37627 .59744 m .37776 .60113 L .38004 .59833 L F
.756 .73 .828 r
.6244 .36799 m .62331 .37292 L .62187 .36916 L F
.6244 .36799 m .62548 .37161 L .62331 .37292 L F
.661 .502 .658 r
.43277 .55052 m .42994 .55317 L .43047 .55092 L F
.43277 .55052 m .43344 .55466 L .42994 .55317 L F
.827 .815 .838 r
.43047 .55092 m .42994 .55317 L .428 .55121 L F
.089 0 0 r
.29662 .63939 m .29197 .64186 L .29608 .64099 L F
.172 0 .283 r
.29874 .63653 m .29662 .63939 L .29838 .63784 L F
0 0 0 r
.29838 .63784 m .29662 .63939 L .29608 .64099 L F
0 0 .547 r
.32175 .6929 m .32313 .69559 L .32313 .69557 L F
.63 .099 0 r
.32113 .6917 m .32342 .69373 L .32175 .6929 L F
0 0 .547 r
.32175 .6929 m .32313 .69557 L .32243 .69171 L F
.63 .099 0 r
.32027 .69094 m .32113 .6917 L .32175 .6929 L F
.976 .915 .667 r
.31566 .50778 m .3177 .50672 L .31782 .50404 L F
.761 .731 .204 r
.34725 .50943 m .34699 .51138 L .34742 .50964 L F
.486 .313 .571 r
.36098 .52449 m .36338 .52406 L .3633 .52161 L F
.418 .813 .589 r
.33764 .5432 m .34132 .54062 L .33689 .54026 L F
.778 .942 .598 r
.33518 .5419 m .33438 .54385 L .33689 .54026 L F
.718 .562 .677 r
.33764 .5432 m .33438 .54385 L .33689 .54026 L F
.674 .385 .475 r
.33882 .53924 m .33879 .54236 L .33518 .5419 L F
0 0 .18 r
.33951 .54023 m .33879 .54236 L .33882 .53924 L F
.375 .55 .899 r
.33438 .54385 m .33774 .54544 L .33764 .5432 L F
.578 .104 .094 r
.33879 .54236 m .33749 .54371 L .33518 .5419 L F
.83 .942 .581 r
.33951 .54023 m .33794 .54293 L .33879 .54236 L F
0 0 .387 r
.33764 .5432 m .33868 .54439 L .33879 .54236 L F
.83 .942 .581 r
.33794 .54293 m .33749 .54371 L .33879 .54236 L F
.418 .813 .589 r
.34033 .54131 m .33879 .54236 L .34132 .54062 L F
.33764 .5432 m .33879 .54236 L .34033 .54131 L F
.563 .039 0 r
.34132 .54062 m .3423 .54259 L .34301 .53999 L F
.34132 .54062 m .33879 .54236 L .3423 .54259 L F
0 0 0 r
.63123 .38917 m .6328 .38656 L .62972 .39067 L F
.524 .594 .866 r
.6328 .38656 m .63347 .38318 L .63131 .38382 L F
.6328 .38656 m .63427 .38632 L .63347 .38318 L F
.667 .27 .284 r
.63465 .38904 m .6328 .38656 L .63123 .38917 L F
0 .116 .668 r
.6357 .39036 m .6328 .38656 L .63465 .38904 L F
.776 .831 .364 r
.24163 .52741 m .24115 .52954 L .23961 .52923 L F
.24163 .52741 m .24096 .5293 L .24115 .52954 L F
.374 .838 .788 r
.24115 .52954 m .24096 .5293 L .24567 .52806 L F
.43 .859 .735 r
.24567 .52806 m .24674 .52723 L .24785 .52686 L F
.419 .864 .809 r
.24567 .52806 m .24096 .5293 L .24674 .52723 L F
.741 .637 .745 r
.32942 .60785 m .33291 .60814 L .33156 .60435 L F
.68 .977 .886 r
.32852 .61012 m .33291 .60814 L .32942 .60785 L F
.32852 .61012 m .33235 .60805 L .33196 .60857 L F
.036 .194 .699 r
.33156 .60435 m .33291 .60814 L .33372 .6064 L F
0 0 0 r
.33085 .60919 m .33235 .60805 L .32852 .61012 L F
.645 .924 .645 r
.33324 .60687 m .33235 .60805 L .33085 .60919 L F
.33372 .6064 m .33235 .60805 L .33324 .60687 L F
.68 .977 .886 r
.33196 .60857 m .33235 .60805 L .33291 .60814 L F
.727 .989 .874 r
.33291 .60814 m .33235 .60805 L .33372 .6064 L F
.445 .086 .261 r
.33545 .6076 m .3343 .61031 L .33291 .60814 L F
.47 .17 .373 r
.34285 .57551 m .34166 .5785 L .33914 .57887 L F
.325 0 .148 r
.34751 .57427 m .34166 .5785 L .34285 .57551 L F
.237 .194 .605 r
.20416 .57902 m .20413 .58259 L .20609 .58126 L F
0 .001 .52 r
.20413 .58259 m .20568 .58352 L .20609 .58126 L F
.20413 .58259 m .20463 .58528 L .20568 .58352 L F
.542 .487 .744 r
.30054 .5402 m .3014 .54296 L .29886 .54357 L F
.482 .15 .327 r
.3014 .54296 m .29768 .546 L .29886 .54357 L F
0 0 .553 r
.69366 .32356 m .69457 .32515 L .69161 .3241 L F
.69366 .32356 m .69598 .32689 L .69457 .32515 L F
.83 .923 .534 r
.35791 .66504 m .35617 .66863 L .35656 .66665 L F
.833 .998 .778 r
.35656 .66665 m .35617 .66863 L .35391 .6697 L F
.783 .702 .775 r
.64296 .39073 m .64687 .39122 L .64553 .38749 L F
.627 .616 .82 r
.64687 .39122 m .64818 .38661 L .64553 .38749 L F
.64687 .39122 m .64964 .39043 L .64818 .38661 L F
.452 .555 .869 r
.64687 .39122 m .651 .39448 L .64964 .39043 L F
.776 .66 .735 r
.40555 .50251 m .40061 .50437 L .40396 .50114 L F
.40555 .50251 m .40325 .5059 L .40061 .50437 L F
0 .031 .576 r
.39676 .52209 m .39789 .52284 L .39614 .52044 L F
.39676 .52209 m .39874 .52421 L .39789 .52284 L F
.875 .738 .707 r
.39521 .58176 m .39385 .58532 L .39231 .58171 L F
.652 .565 .745 r
.43476 .49903 m .43185 .49966 L .43042 .49537 L F
.105 .623 .885 r
.35321 .49995 m .35221 .50045 L .35041 .49922 L F
.35321 .49995 m .35519 .50071 L .35221 .50045 L F
.712 .798 .918 r
.70483 .35993 m .70593 .35994 L .70592 .35809 L F
.385 .52 .871 r
.70592 .35809 m .70593 .35994 L .70765 .35767 L F
.089 .067 .536 r
.70593 .35994 m .7083 .36006 L .70765 .35767 L F
.70593 .35994 m .7064 .36224 L .7083 .36006 L F
.014 .577 .799 r
.35139 .65738 m .35013 .65744 L .35295 .65653 L F
.915 .523 .242 r
.6152 .44225 m .61431 .44379 L .61579 .44343 L F
0 .26 .769 r
.6152 .44225 m .61539 .44099 L .61431 .44379 L F
.6152 .44225 m .61775 .44419 L .61539 .44099 L F
.504 .379 .643 r
.3675 .58247 m .36912 .58171 L .36945 .57871 L F
.868 .951 .863 r
.36909 .64759 m .37191 .64698 L .37334 .64528 L F
.158 0 0 r
.25456 .54609 m .25896 .54381 L .25626 .54432 L F
.543 .306 .506 r
.35702 .67742 m .35732 .67468 L .35477 .67855 L F
.53 .835 .999 r
.35564 .6737 m .35732 .67468 L .35809 .67305 L F
0 0 .088 r
.35809 .67305 m .35732 .67468 L .35702 .67742 L F
.319 .805 .777 r
.32072 .62417 m .32315 .62369 L .32499 .62298 L F
.585 .219 .314 r
.25657 .56536 m .25895 .56554 L .25696 .56392 L F
.494 .253 .478 r
.25696 .56392 m .25895 .56554 L .25899 .56288 L F
.418 .843 .955 r
.28434 .51816 m .28337 .51919 L .28179 .51883 L F
.28434 .51816 m .28592 .51854 L .28337 .51919 L F
0 0 .454 r
.60263 .41709 m .60042 .41337 L .60161 .41566 L F
.603 .161 0 r
.60296 .41768 m .60263 .41709 L .60161 .41566 L F
.60296 .41768 m .60419 .41935 L .60263 .41709 L F
.846 .445 0 r
.38961 .51459 m .38892 .51441 L .38795 .51165 L F
.892 .468 .104 r
.38795 .51165 m .38892 .51441 L .38755 .51371 L F
.02 .437 .868 r
.38892 .51441 m .39089 .5143 L .38814 .5142 L F
.512 0 0 r
.38892 .51441 m .38812 .5142 L .38755 .51371 L F
.02 .437 .868 r
.38892 .51441 m .38814 .5142 L .38812 .5142 L F
.846 .445 0 r
.3899 .51509 m .38892 .51441 L .38961 .51459 L F
.721 .25 0 r
.3899 .51509 m .39151 .5176 L .38892 .51441 L F
.549 .366 .586 r
.33569 .68357 m .33479 .68623 L .33658 .68389 L F
0 0 0 r
.33658 .68389 m .33698 .68308 L .33744 .68321 L F
.33698 .68308 m .33803 .68091 L .33744 .68321 L F
.33744 .68321 m .33848 .68344 L .3384 .68347 L F
.702 .41 .478 r
.33479 .68623 m .33897 .68674 L .33658 .68389 L F
.549 .366 .586 r
.33479 .68623 m .33278 .68699 L .33569 .68357 L F
.33569 .68357 m .33278 .68699 L .33479 .68623 L F
.776 .811 .33 r
.33496 .68459 m .33479 .68623 L .33542 .68436 L F
.33496 .68459 m .33542 .68436 L .33569 .68357 L F
.151 0 .394 r
.3346 .68477 m .33496 .68459 L .33357 .68331 L F
.688 .642 .798 r
.33479 .68623 m .33658 .68931 L .33897 .68674 L F
.664 .618 .793 r
.33278 .68699 m .33658 .68931 L .33479 .68623 L F
.996 .84 .568 r
.33065 .68864 m .33176 .69003 L .33278 .68699 L F
0 0 0 r
.33065 .68864 m .33278 .68699 L .33479 .68623 L F
.33065 .68864 m .33479 .68623 L .33342 .68809 L F
.794 .879 .451 r
.33342 .68809 m .33479 .68623 L .33496 .68459 L F
.131 0 .387 r
.33475 .68789 m .33342 .68809 L .33496 .68459 L F
.151 0 .394 r
.33622 .68709 m .33475 .68789 L .33496 .68459 L F
.33622 .68709 m .33496 .68459 L .3346 .68477 L F
0 0 0 r
.33744 .68321 m .3384 .68347 L .33496 .68459 L F
.33 .775 .961 r
.33569 .68357 m .33658 .68389 L .33744 .68321 L F
.782 .476 0 r
.27779 .63204 m .27839 .63347 L .27711 .62948 L F
.354 0 0 r
.27982 .63551 m .28145 .63343 L .27839 .63347 L F
.27982 .63551 m .27839 .63347 L .27779 .63204 L F
.427 .301 .606 r
.42988 .57155 m .42675 .5699 L .42904 .56813 L F
.42988 .57155 m .42718 .57256 L .42675 .5699 L F
0 .144 .686 r
.38831 .59969 m .38851 .60122 L .3861 .59761 L F
.602 .548 .766 r
.46277 .56883 m .46411 .5726 L .46136 .57241 L F
.598 .37 .541 r
.46411 .5726 m .46128 .57508 L .46136 .57241 L F
.886 .717 .667 r
.6847 .34735 m .68309 .3434 L .68266 .34586 L F
.847 .654 .641 r
.68266 .34586 m .6842 .34983 L .6847 .34735 L F
.691 .505 .631 r
.37265 .60769 m .3724 .61125 L .36934 .61077 L F
.614 .757 .947 r
.37575 .60656 m .37265 .60769 L .37158 .60606 L F
.43 .283 .579 r
.3748 .61033 m .3724 .61125 L .37265 .60769 L F
.662 .538 .702 r
.73688 .3314 m .74005 .33104 L .73912 .32725 L F
.659 .516 .679 r
.73688 .3314 m .73754 .33426 L .74005 .33104 L F
.519 .594 .869 r
.54018 .42267 m .53945 .42422 L .53618 .41976 L F
0 0 .269 r
.39961 .68978 m .3978 .69369 L .39971 .69041 L F
.39961 .68978 m .39917 .69292 L .3978 .69369 L F
0 0 0 r
.3978 .69369 m .39656 .69565 L .39721 .69583 L F
.3978 .69369 m .39917 .69292 L .39656 .69565 L F
.523 .286 .497 r
.32664 .51867 m .32634 .52139 L .32384 .52136 L F
.82 .462 .379 r
.32241 .51815 m .32634 .52139 L .32664 .51867 L F
.7 .336 .354 r
.31778 .64965 m .31814 .64911 L .31748 .65138 L F
.76 .537 .595 r
.32074 .64915 m .31748 .65138 L .31814 .64911 L F
.237 .194 .605 r
.20416 .57902 m .20609 .58126 L .20553 .57833 L F
.259 0 .175 r
.29388 .63253 m .29476 .63068 L .29693 .62995 L F
.591 .404 .597 r
.35949 .57931 m .35971 .58197 L .35731 .58204 L F
.505 .405 .675 r
.36174 .5795 m .35971 .58197 L .35949 .57931 L F
.766 .899 .935 r
.64283 .36302 m .63714 .36507 L .64017 .36131 L F
.738 .529 .61 r
.34582 .54404 m .34146 .54607 L .34421 .54287 L F
.713 .22 0 r
.40182 .65556 m .39898 .65215 L .4008 .65194 L F
.668 .786 .937 r
.4135 .4918 m .40912 .49142 L .41199 .48917 L F
.654 .691 .872 r
.41593 .48967 m .4135 .4918 L .41199 .48917 L F
.907 .649 .536 r
.38697 .70603 m .38503 .70256 L .38586 .70537 L F
.724 .605 .724 r
.38356 .70899 m .38697 .70603 L .38586 .70537 L F
.314 .035 .32 r
.35019 .53754 m .34759 .54071 L .34589 .53748 L F
.667 .517 .671 r
.34808 .54368 m .35052 .54022 L .3481 .54063 L F
.34766 .54116 m .3481 .54063 L .34759 .54071 L F
.34808 .54368 m .3481 .54063 L .34766 .54116 L F
.746 .515 .58 r
.35019 .53754 m .35052 .54022 L .35395 .54028 L F
.753 .566 .643 r
.35052 .54022 m .35167 .5441 L .35395 .54028 L F
.667 .517 .671 r
.34808 .54368 m .35167 .5441 L .35052 .54022 L F
.235 0 .292 r
.35167 .5396 m .3494 .5415 L .35004 .53827 L F
.3504 .53783 m .35004 .53827 L .35019 .53754 L F
.35167 .5396 m .35004 .53827 L .3504 .53783 L F
.314 .035 .32 r
.35019 .53754 m .3494 .5415 L .34759 .54071 L F
.564 .362 .566 r
.35373 .5341 m .35336 .53729 L .35019 .53754 L F
.746 .515 .58 r
.35019 .53754 m .35395 .54028 L .35336 .53729 L F
.235 0 .292 r
.35167 .5396 m .35019 .53754 L .35336 .53729 L F
.564 .362 .566 r
.35019 .53754 m .35336 .53729 L .35373 .5341 L F
.888 .87 .814 r
.6621 .33754 m .65825 .3395 L .66095 .3363 L F
.6621 .33754 m .65959 .34093 L .65825 .3395 L F
.873 .918 .855 r
.66498 .33422 m .6621 .33754 L .66095 .3363 L F
0 0 .249 r
.40769 .54094 m .40747 .5399 L .40656 .53709 L F
.788 .449 0 r
.40879 .54315 m .40747 .5399 L .40769 .54094 L F
.822 .624 .635 r
.3487 .69458 m .34438 .69625 L .34484 .69346 L F
.3487 .69458 m .34882 .69712 L .34438 .69625 L F
.977 .69 .412 r
.35141 .69653 m .3487 .69458 L .34882 .69712 L F
.35141 .69653 m .35103 .69312 L .3487 .69458 L F
0 0 .176 r
.34915 .69528 m .3487 .69458 L .35103 .69312 L F
.34915 .69528 m .34882 .69712 L .3487 .69458 L F
.175 .06 .473 r
.20487 .57276 m .20697 .57413 L .20693 .57143 L F
.20487 .57276 m .20489 .57586 L .20697 .57413 L F
.886 .728 .68 r
.53769 .42569 m .53912 .42955 L .53694 .42884 L F
.936 .726 .592 r
.53912 .42955 m .53706 .43047 L .53694 .42884 L F
.53912 .42955 m .53876 .43196 L .53706 .43047 L F
0 .245 .755 r
.59392 .4086 m .59208 .40732 L .59226 .40637 L F
.189 0 0 r
.23453 .55144 m .23394 .55012 L .23566 .55004 L F
.616 .568 .777 r
.33948 .53692 m .33562 .53393 L .3392 .53347 L F
.523 .322 .548 r
.34187 .53606 m .3392 .53347 L .3434 .53318 L F
.34187 .53606 m .33948 .53692 L .3392 .53347 L F
.707 .701 .843 r
.62838 .36889 m .62548 .37161 L .6244 .36799 L F
.872 .993 .804 r
.38214 .70832 m .38356 .70899 L .38586 .70537 L F
0 .118 .657 r
.33076 .52429 m .33292 .52709 L .33212 .52857 L F
.59 .937 .938 r
.33212 .52857 m .33292 .52709 L .33399 .52754 L F
.202 .73 .809 r
.359 .71554 m .36339 .71506 L .36146 .71498 L F
.082 .622 .853 r
.36339 .71506 m .36391 .71475 L .36146 .71498 L F
.36339 .71506 m .36537 .71521 L .36391 .71475 L F
.671 .191 .105 r
.70915 .30739 m .71305 .30797 L .71089 .30602 L F
0 .217 .732 r
.33297 .50229 m .33364 .50068 L .3314 .49876 L F
0 .223 .736 r
.33297 .50229 m .33494 .50361 L .33364 .50068 L F
.649 .65 .838 r
.42942 .48921 m .42508 .48638 L .42814 .48611 L F
.601 .613 .835 r
.43177 .48699 m .42942 .48921 L .42814 .48611 L F
.566 .552 .798 r
.43177 .48699 m .43022 .49001 L .42942 .48921 L F
.514 .421 .687 r
.43022 .49001 m .43024 .49339 L .42942 .48921 L F
.857 .765 .761 r
.40668 .49263 m .40202 .49422 L .40322 .49247 L F
.75 .231 0 r
.40434 .4935 m .40322 .49247 L .40202 .49422 L F
.40434 .4935 m .40154 .49126 L .40198 .49158 L F
.40334 .49259 m .40198 .49158 L .40322 .49247 L F
.40434 .4935 m .40198 .49158 L .40334 .49259 L F
.857 .765 .761 r
.40444 .4934 m .40465 .49809 L .40202 .49422 L F
.40668 .49263 m .40598 .49453 L .40444 .4934 L F
.40598 .49453 m .40465 .49809 L .40444 .4934 L F
.564 .408 .628 r
.35922 .6236 m .35937 .62675 L .35679 .62719 L F
.497 .21 .408 r
.35679 .62719 m .35937 .62675 L .35893 .62896 L F
.564 .408 .628 r
.35922 .6236 m .35937 .62675 L .35679 .62719 L F
.497 .21 .408 r
.35679 .62719 m .35937 .62675 L .35893 .62896 L F
0 0 .033 r
.41582 .56974 m .41589 .57108 L .41536 .56859 L F
.41582 .56974 m .41591 .57229 L .41589 .57108 L F
0 0 .496 r
.40303 .53098 m .40284 .52987 L .40124 .52747 L F
0 .095 .643 r
.40303 .53098 m .40522 .53319 L .40284 .52987 L F
.961 .94 .702 r
.61454 .41993 m .6119 .42258 L .6153 .42063 L F
0 0 0 r
.6138 .42018 m .61079 .4237 L .6119 .42258 L F
.961 .94 .702 r
.61313 .41861 m .6138 .42018 L .6119 .42258 L F
.61313 .41861 m .6119 .42258 L .61454 .41993 L F
0 0 0 r
.61079 .4237 m .61059 .42395 L .6119 .42258 L F
.748 .428 0 r
.61237 .4161 m .6138 .42018 L .61313 .41861 L F
.583 .199 .28 r
.60499 .3818 m .60803 .3821 L .60772 .38371 L F
.203 .303 .745 r
.60664 .3801 m .60499 .3818 L .60772 .38371 L F
.61 .913 .98 r
.29209 .51723 m .2899 .51835 L .28841 .51774 L F
.938 .626 .174 r
.39461 .53782 m .39468 .54023 L .3955 .54034 L F
.766 .292 0 r
.39472 .54019 m .3955 .54034 L .39468 .54023 L F
.39472 .54019 m .39723 .54303 L .3955 .54034 L F
.825 .522 .477 r
.62783 .44442 m .62841 .4425 L .62443 .44152 L F
.149 0 .225 r
.62783 .44442 m .63037 .44127 L .62841 .4425 L F
.988 .733 .357 r
.71446 .3556 m .71548 .35633 L .71431 .35247 L F
.463 .823 .995 r
.71707 .35493 m .71548 .35633 L .71446 .3556 L F
.71707 .35493 m .71826 .35577 L .71548 .35633 L F
.665 .433 .559 r
.56818 .45822 m .56564 .46077 L .56595 .45822 L F
.56818 .45822 m .56824 .46074 L .56564 .46077 L F
.05 .233 .731 r
.6085 .37179 m .60947 .37488 L .61128 .37446 L F
0 0 0 r
.61128 .37446 m .60947 .37488 L .60845 .37617 L F
.585 .237 .346 r
.34478 .55583 m .34324 .55891 L .34116 .55677 L F
.715 .437 .504 r
.3474 .55627 m .34324 .55891 L .34478 .55583 L F
.514 .421 .687 r
.43022 .49001 m .43311 .49325 L .43024 .49339 L F
.613 .585 .798 r
.43311 .49325 m .43042 .49537 L .43024 .49339 L F
.335 .322 .696 r
.20463 .58528 m .20486 .5891 L .2071 .58743 L F
.212 .081 .476 r
.20486 .5891 m .20717 .59008 L .2071 .58743 L F
.20486 .5891 m .20495 .59205 L .20717 .59008 L F
.908 .977 .789 r
.64974 .42944 m .65169 .42688 L .64934 .42759 L F
.862 .977 .676 r
.65169 .42688 m .65433 .42339 L .65315 .42535 L F
.734 .991 .838 r
.64934 .42759 m .65169 .42688 L .65315 .42535 L F
.599 .592 .817 r
.4357 .48873 m .43022 .49001 L .43177 .48699 L F
.581 .432 .645 r
.43545 .49203 m .43022 .49001 L .4357 .48873 L F
.43545 .49203 m .43311 .49325 L .43022 .49001 L F
.867 .686 .654 r
.65047 .40374 m .65288 .40694 L .65036 .40579 L F
.958 .849 .691 r
.65288 .40694 m .65018 .40929 L .65036 .40579 L F
.65288 .40694 m .6517 .41084 L .65018 .40929 L F
.636 .697 .89 r
.41998 .49237 m .41593 .48967 L .41849 .48908 L F
.698 .696 .844 r
.42261 .48972 m .41998 .49237 L .41849 .48908 L F
.689 .573 .719 r
.59006 .43573 m .58733 .43844 L .58607 .43534 L F
.222 .156 .567 r
.35481 .53119 m .35511 .53364 L .35373 .5341 L F
.004 0 .361 r
.35471 .53594 m .35373 .5341 L .35511 .53364 L F
.35471 .53594 m .35336 .53729 L .35373 .5341 L F
.35471 .53594 m .35373 .5341 L .35511 .53364 L F
.35471 .53594 m .35336 .53729 L .35373 .5341 L F
.321 0 .146 r
.3413 .52063 m .34539 .51692 L .34306 .51837 L F
0 0 .039 r
.30005 .63503 m .29874 .63653 L .30214 .63506 L F
0 0 0 r
.35048 .59395 m .35243 .59249 L .35455 .59112 L F
.214 .669 .948 r
.43443 .55713 m .43667 .55726 L .43242 .55619 L F
.479 .171 .366 r
.43443 .55713 m .43388 .55936 L .43667 .55726 L F
.609 .703 .911 r
.3869 .62858 m .3906 .63006 L .38712 .6283 L F
.755 .665 .762 r
.38712 .6283 m .3906 .63006 L .39321 .62688 L F
.422 .549 .878 r
.41822 .50524 m .42145 .50475 L .41838 .50324 L F
.265 0 .143 r
.42145 .50475 m .41894 .50578 L .41822 .50524 L F
.41822 .50524 m .41894 .50578 L .42145 .50475 L F
0 .015 .565 r
.41822 .50524 m .41894 .50578 L .41838 .50324 L F
.793 .689 .75 r
.64485 .3555 m .64634 .35926 L .64253 .35876 L F
.163 .28 .738 r
.64964 .39043 m .651 .39448 L .65255 .39283 L F
0 0 .43 r
.65255 .39283 m .651 .39448 L .65139 .39714 L F
.074 0 .079 r
.36219 .59182 m .35934 .59511 L .3616 .59473 L F
.769 .705 .791 r
.3616 .59473 m .3648 .59084 L .36219 .59182 L F
.522 .637 .905 r
.37287 .60319 m .37575 .60656 L .37158 .60606 L F
.368 .117 .396 r
.28448 .55911 m .28171 .56184 L .2823 .55991 L F
.181 0 0 r
.26499 .55923 m .26638 .55926 L .2683 .55745 L F
.446 0 .093 r
.2683 .55745 m .26638 .55926 L .27037 .55861 L F
.445 .001 .099 r
.2683 .55745 m .27037 .55861 L .2721 .55666 L F
0 0 0 r
.32205 .68401 m .32071 .68611 L .32075 .68622 L F
0 0 .071 r
.32075 .68622 m .32071 .68611 L .321 .68962 L F
0 0 .201 r
.32071 .68611 m .32027 .69094 L .321 .68962 L F
.481 .267 .511 r
.32485 .59374 m .32272 .59192 L .32482 .59113 L F
.32485 .59374 m .32241 .59449 L .32272 .59192 L F
.66 .2 .15 r
.3919 .60742 m .39569 .60716 L .39288 .60644 L F
0 0 0 r
.37971 .68712 m .37756 .68929 L .37924 .68908 L F
.401 .592 .921 r
.37924 .68908 m .37756 .68929 L .37554 .6868 L F
.634 .367 .496 r
.35966 .58436 m .35731 .58204 L .35971 .58197 L F
.35966 .58436 m .35773 .58457 L .35731 .58204 L F
.732 .836 .388 r
.65513 .42115 m .65433 .42339 L .65599 .41979 L F
.766 .891 .484 r
.65315 .42535 m .65433 .42339 L .65513 .42115 L F
.825 .853 .868 r
.65959 .34093 m .65518 .34248 L .65825 .3395 L F
.319 .794 .707 r
.36941 .71398 m .37225 .713 L .37451 .71203 L F
0 0 .303 r
.40656 .53709 m .40522 .53319 L .40654 .53454 L F
.848 .774 .779 r
.35522 .51862 m .3538 .52258 L .35259 .51837 L F
0 0 .064 r
.31565 .58393 m .31368 .58628 L .31354 .58771 L F
.491 .38 .655 r
.24977 .54749 m .25239 .54968 L .25219 .54675 L F
.679 .822 .382 r
.70496 .32887 m .70311 .33242 L .70385 .33124 L F
.977 .752 .532 r
.37738 .67452 m .3753 .67348 L .37565 .67075 L F
.968 .672 .41 r
.3753 .67348 m .37675 .67642 L .37738 .67452 L F
.194 0 .146 r
.37738 .67452 m .37675 .67642 L .37924 .67394 L F
0 0 0 r
.43388 .55936 m .43112 .56244 L .43231 .56069 L F
.167 .187 .636 r
.26708 .53448 m .26893 .53663 L .26787 .53385 L F
0 0 0 r
.28633 .55006 m .28797 .54885 L .28898 .54641 L F
.28898 .54641 m .28958 .54786 L .29167 .54546 L F
.28898 .54641 m .28797 .54885 L .28958 .54786 L F
.302 0 .145 r
.69078 .36551 m .69416 .36329 L .69325 .36444 L F
0 0 0 r
.69325 .36444 m .69416 .36329 L .69629 .36195 L F
.56 .796 .987 r
.56569 .41441 m .56251 .41463 L .56458 .41394 L F
0 0 .531 r
.56251 .41463 m .56402 .41501 L .56458 .41394 L F
0 0 0 r
.22047 .54805 m .22044 .54834 L .22193 .54625 L F
.22047 .54805 m .21858 .54942 L .22044 .54834 L F
.812 .493 .449 r
.36532 .51557 m .36298 .51642 L .36071 .51298 L F
.848 .628 .604 r
.36532 .51557 m .36136 .5173 L .36298 .51642 L F
.36532 .51557 m .36467 .51825 L .36136 .5173 L F
.487 .287 .534 r
.32724 .55376 m .33021 .5531 L .33002 .55006 L F
.448 .194 .435 r
.32701 .55578 m .33021 .5531 L .32724 .55376 L F
.709 .431 .501 r
.60077 .45138 m .59696 .45379 L .59695 .45231 L F
.162 .154 .601 r
.73648 .33639 m .73697 .33919 L .73566 .3398 L F
.765 .676 .764 r
.32384 .52136 m .32072 .52294 L .32241 .51815 L F
0 .062 .617 r
.32184 .52319 m .32072 .52294 L .32384 .52136 L F
.934 .957 .644 r
.32293 .52098 m .32184 .52319 L .32384 .52136 L F
.118 .658 .847 r
.32634 .52139 m .32293 .52098 L .32384 .52136 L F
.422 0 0 r
.3875 .58619 m .38912 .58745 L .38585 .58741 L F
.3875 .58619 m .39184 .58757 L .38912 .58745 L F
.357 .329 .69 r
.44394 .53026 m .44256 .53472 L .44224 .53076 L F
.44394 .53026 m .44434 .53463 L .44256 .53472 L F
.358 .383 .75 r
.44434 .53463 m .44537 .53658 L .44256 .53472 L F
.382 .381 .734 r
.44256 .53472 m .44537 .53658 L .44355 .53722 L F
.863 .989 .836 r
.65599 .41979 m .65621 .41725 L .65591 .41885 L F
.65599 .41979 m .65883 .41666 L .65621 .41725 L F
.325 .672 .976 r
.39267 .64441 m .39759 .64513 L .39739 .64589 L F
.517 .859 .994 r
.39759 .64513 m .39819 .64444 L .39739 .64589 L F
0 .141 .671 r
.39819 .64444 m .39946 .64828 L .39739 .64589 L F
.661 .623 .801 r
.59373 .4376 m .59006 .43573 L .59258 .43502 L F
.791 .791 .852 r
.5963 .4354 m .59373 .4376 L .59258 .43502 L F
.895 .971 .661 r
.71255 .30963 m .71244 .31176 L .71406 .30849 L F
.856 .848 .387 r
.71167 .31363 m .71244 .31176 L .71255 .30963 L F
.712 .798 .918 r
.70483 .35993 m .70592 .35809 L .70392 .35832 L F
.42 .322 .637 r
.61158 .42673 m .61129 .42983 L .6113 .4254 L F
.173 .06 .474 r
.33002 .55006 m .33163 .55204 L .33197 .54979 L F
.33002 .55006 m .33021 .5531 L .33163 .55204 L F
.65 .296 .358 r
.27037 .55861 m .27502 .55614 L .2721 .55666 L F
0 0 .164 r
.36097 .54037 m .36149 .53617 L .35805 .53854 L F
.387 .165 .45 r
.23012 .55289 m .22747 .55632 L .22796 .55366 L F
.501 .481 .767 r
.44111 .51749 m .43983 .52194 L .43895 .51795 L F
.44111 .51749 m .44207 .52119 L .43983 .52194 L F
.455 .343 .636 r
.44207 .52119 m .44245 .52389 L .43983 .52194 L F
.355 .349 .715 r
.43983 .52194 m .44245 .52389 L .44077 .52448 L F
.65 .334 .424 r
.34902 .57572 m .34394 .57798 L .34751 .57427 L F
.693 .157 0 r
.352 .57819 m .35076 .57757 L .34898 .57568 L F
.65 .334 .424 r
.34913 .57583 m .34912 .57583 L .34902 .57572 L F
.34912 .57583 m .34394 .57798 L .34902 .57572 L F
.318 .002 .261 r
.34561 .57924 m .34394 .57798 L .34912 .57583 L F
.34912 .57583 m .34912 .57583 L .34913 .57583 L F
.34561 .57924 m .34912 .57583 L .34912 .57583 L F
.693 .157 0 r
.34898 .57568 m .34918 .57594 L .34814 .57498 L F
.311 0 0 r
.35026 .57731 m .34561 .57924 L .34913 .57583 L F
.693 .157 0 r
.34918 .57594 m .35026 .57731 L .34945 .57643 L F
.34918 .57594 m .34945 .57643 L .34814 .57498 L F
.35076 .57757 m .35026 .57731 L .34898 .57568 L F
.65 .334 .424 r
.34913 .57583 m .34751 .57427 L .34814 .57498 L F
.693 .157 0 r
.352 .57819 m .34814 .57498 L .352 .57595 L F
.04 .289 .782 r
.32316 .6637 m .32253 .66498 L .32042 .66141 L F
0 0 .039 r
.3228 .66634 m .32215 .66821 L .32253 .66498 L F
.357 .174 .491 r
.304 .5329 m .30269 .5318 L .30488 .53018 L F
.304 .5329 m .30251 .53393 L .30269 .5318 L F
.547 .478 .729 r
.37285 .52479 m .37097 .52525 L .37059 .5224 L F
0 0 0 r
.37158 .52527 m .37097 .52525 L .37285 .52479 L F
.37158 .52527 m .36962 .52622 L .37097 .52525 L F
.547 .492 .746 r
.44993 .55592 m .45068 .55942 L .44819 .55999 L F
.582 .425 .635 r
.45068 .55942 m .44822 .56266 L .44819 .55999 L F
.675 .765 .919 r
.29258 .65614 m .29378 .65584 L .2896 .65464 L F
.617 .363 .511 r
.57862 .45807 m .5786 .46046 L .57661 .46009 L F
.602 .352 .51 r
.57862 .45807 m .58134 .46028 L .5786 .46046 L F
.619 .346 .482 r
.58124 .45796 m .58134 .46028 L .57862 .45807 L F
.092 .108 .583 r
.38173 .55252 m .38209 .55511 L .38059 .55349 L F
.977 .684 .392 r
.61024 .43148 m .6118 .43284 L .61129 .42983 L F
.165 .158 .604 r
.6113 .4254 m .61129 .42983 L .61342 .42801 L F
.391 .398 .747 r
.61613 .43182 m .61497 .43158 L .6165 .43027 L F
.125 0 .392 r
.61573 .43297 m .61499 .43171 L .61539 .43414 L F
.446 .088 .262 r
.61522 .43203 m .61497 .43158 L .61613 .43182 L F
.61522 .43203 m .61613 .43182 L .61538 .4315 L F
.384 .539 .886 r
.61538 .4315 m .61613 .43182 L .61576 .43129 L F
.125 0 .392 r
.6165 .43027 m .61549 .43114 L .61544 .43128 L F
.6165 .43027 m .61499 .43171 L .61629 .43101 L F
.647 .658 .846 r
.61342 .42801 m .61576 .43129 L .6165 .43027 L F
.61576 .43129 m .61613 .43182 L .6165 .43027 L F
.125 0 .392 r
.61629 .43101 m .61576 .43129 L .61573 .43297 L F
.61576 .43129 m .61538 .4315 L .61543 .43175 L F
.61576 .43129 m .61543 .43175 L .61573 .43297 L F
.61538 .4315 m .61503 .43169 L .61522 .43203 L F
.61538 .4315 m .61522 .43203 L .61573 .43297 L F
.61503 .43169 m .61499 .43171 L .61573 .43297 L F
.531 .231 .404 r
.61539 .43414 m .61497 .43158 L .6118 .43284 L F
.446 .088 .262 r
.6118 .43284 m .61497 .43158 L .61522 .43203 L F
.6118 .43284 m .61522 .43203 L .61129 .42983 L F
.125 0 .392 r
.61544 .43128 m .61497 .43158 L .61499 .43171 L F
.446 .088 .262 r
.61522 .43203 m .61538 .4315 L .61129 .42983 L F
.125 0 .392 r
.61549 .43114 m .61497 .43158 L .61544 .43128 L F
.384 .539 .886 r
.61129 .42983 m .61538 .4315 L .61342 .42801 L F
.61538 .4315 m .61576 .43129 L .61342 .42801 L F
.75 .972 .927 r
.64893 .41386 m .6445 .41554 L .64796 .4121 L F
.854 .879 .857 r
.65018 .40929 m .64893 .41386 L .64796 .4121 L F
.65018 .40929 m .6517 .41084 L .64893 .41386 L F
.62 .955 .914 r
.62922 .43507 m .62638 .43643 L .62736 .43634 L F
.471 0 0 r
.36549 .67127 m .36772 .67219 L .36639 .67143 L F
.85 .996 .763 r
.36549 .67127 m .36639 .67143 L .36591 .67075 L F
.82 .844 .867 r
.36532 .67139 m .36772 .67219 L .36549 .67127 L F
.502 .195 .378 r
.36886 .67309 m .36898 .6711 L .36878 .67113 L F
.526 0 0 r
.36639 .67143 m .36772 .67219 L .36733 .67206 L F
.502 .195 .378 r
.36733 .67206 m .36878 .67113 L .36639 .67143 L F
.394 .04 .242 r
.36886 .67309 m .36772 .67219 L .36538 .67618 L F
.526 0 0 r
.36733 .67206 m .36772 .67219 L .36886 .67309 L F
.502 .195 .378 r
.36886 .67309 m .36878 .67113 L .36733 .67206 L F
.82 .844 .867 r
.36206 .67372 m .36668 .67248 L .36532 .67139 L F
.36668 .67248 m .36772 .67219 L .36733 .67206 L F
.36668 .67248 m .36733 .67206 L .36532 .67139 L F
.967 .803 .373 r
.40384 .66995 m .4048 .66809 L .40155 .66792 L F
.40384 .66995 m .40442 .67118 L .4048 .66809 L F
.649 .914 .61 r
.71795 .33718 m .71517 .34018 L .71705 .33781 L F
.501 .552 .84 r
.72054 .33324 m .72053 .33499 L .71948 .33595 L F
.438 .871 .783 r
.72036 .33577 m .71948 .33595 L .72169 .33493 L F
.87 .597 .522 r
.72052 .33684 m .72169 .33493 L .71948 .33595 L F
.501 .552 .84 r
.72053 .33499 m .72052 .33684 L .71948 .33595 L F
.5 .903 .793 r
.71848 .33687 m .71948 .33595 L .72036 .33577 L F
.71795 .33718 m .71948 .33595 L .71848 .33687 L F
.453 .829 .588 r
.71705 .33781 m .71948 .33595 L .71795 .33718 L F
.718 .452 .523 r
.35034 .64722 m .35376 .64724 L .35024 .64555 L F
.35034 .64722 m .35427 .6481 L .35376 .64724 L F
.648 .327 .414 r
.60716 .4515 m .60335 .45381 L .60331 .45164 L F
.60716 .4515 m .60595 .45417 L .60335 .45381 L F
.716 .462 .541 r
.61007 .45146 m .60595 .45417 L .60716 .4515 L F
.884 .814 .774 r
.59063 .3807 m .59186 .38277 L .59093 .38333 L F
.451 0 0 r
.59175 .38294 m .59186 .38277 L .59063 .3807 L F
.59175 .38294 m .59398 .38416 L .59186 .38277 L F
.127 .36 .821 r
.2333 .61425 m .23508 .61733 L .2358 .61575 L F
0 .151 .677 r
.23508 .61733 m .23728 .61991 L .2358 .61575 L F
.396 .449 .798 r
.21726 .60147 m .21859 .60544 L .2201 .6032 L F
0 .073 .606 r
.22036 .60729 m .2201 .6032 L .21859 .60544 L F
0 0 0 r
.25468 .52477 m .25589 .52393 L .25602 .52373 L F
.41 .851 .751 r
.25468 .52477 m .25343 .52516 L .25589 .52393 L F
.873 .919 .855 r
.66634 .33278 m .66398 .33285 L .66509 .33133 L F
.66634 .33278 m .66498 .33422 L .66398 .33285 L F
.83 .904 .891 r
.66922 .32992 m .66634 .33278 L .66509 .33133 L F
.502 .515 .803 r
.67245 .38843 m .6688 .38535 L .67141 .38455 L F
.903 .939 .824 r
.72288 .35426 m .72371 .35185 L .72142 .35425 L F
0 0 0 r
.72142 .35425 m .72371 .35185 L .72235 .35375 L F
.966 .816 .643 r
.71761 .35161 m .72142 .35425 L .71973 .35429 L F
0 0 0 r
.72142 .35425 m .72235 .35375 L .72001 .35424 L F
.72142 .35425 m .72001 .35424 L .71973 .35429 L F
.903 .939 .824 r
.72217 .35629 m .72288 .35426 L .72142 .35425 L F
.72217 .35629 m .72459 .35297 L .72371 .35185 L F
.953 .756 .6 r
.39519 .62354 m .39395 .61973 L .39214 .62291 L F
.894 .849 .792 r
.39142 .6258 m .39519 .62354 L .39214 .62291 L F
.39142 .6258 m .39321 .62688 L .39519 .62354 L F
.287 0 .019 r
.32222 .54711 m .32115 .54893 L .31876 .54937 L F
0 0 .335 r
.32397 .54284 m .32379 .54595 L .32222 .54711 L F
0 0 0 r
.32379 .54595 m .32115 .54893 L .32222 .54711 L F
.627 .383 .529 r
.68531 .35518 m .68813 .35305 L .68556 .35331 L F
.68531 .35518 m .68822 .35553 L .68813 .35305 L F
.484 .174 .364 r
.69062 .35441 m .68813 .35305 L .68822 .35553 L F
.69062 .35441 m .69107 .35256 L .68813 .35305 L F
.326 .324 .704 r
.39038 .59754 m .39157 .59361 L .38864 .59444 L F
.84 .761 .775 r
.3919 .60742 m .39322 .61094 L .39569 .60716 L F
.724 .294 .229 r
.39569 .60716 m .39444 .60973 L .39505 .60618 L F
.39569 .60716 m .39783 .60977 L .39444 .60973 L F
.868 .951 .863 r
.36909 .64759 m .37334 .64528 L .37216 .64411 L F
.693 .973 .919 r
.37334 .64528 m .37455 .64321 L .37216 .64411 L F
.37334 .64528 m .37689 .64305 L .37455 .64321 L F
.873 .918 .855 r
.66498 .33422 m .66095 .3363 L .66398 .33285 L F
.944 .602 .34 r
.53876 .43196 m .54093 .43547 L .53693 .43176 L F
.916 .56 .345 r
.54093 .43547 m .53936 .43694 L .53693 .43176 L F
.895 .522 .321 r
.54093 .43547 m .54199 .43826 L .53936 .43694 L F
.607 .591 .81 r
.33492 .66444 m .3374 .6638 L .33621 .66099 L F
.213 0 0 r
.62288 .45089 m .62677 .45127 L .62563 .45084 L F
.301 .774 .932 r
.62677 .45127 m .62939 .45096 L .62563 .45084 L F
.318 .772 .954 r
.32719 .51385 m .33142 .51401 L .33159 .51221 L F
.423 .383 .709 r
.73912 .32725 m .74107 .3295 L .74137 .32643 L F
.73912 .32725 m .74005 .33104 L .74107 .3295 L F
.815 .402 .263 r
.42317 .59552 m .42112 .59672 L .41998 .59424 L F
0 0 0 r
.42449 .59394 m .42317 .59552 L .42567 .59249 L F
.34 .026 .278 r
.42449 .59394 m .42112 .59672 L .42317 .59552 L F
.432 .861 .937 r
.61563 .39371 m .61438 .39475 L .61234 .39436 L F
.61563 .39371 m .61703 .39397 L .61438 .39475 L F
.093 .612 .883 r
.39416 .64394 m .39267 .64441 L .3914 .64418 L F
.39416 .64394 m .39759 .64513 L .39267 .64441 L F
.755 .665 .762 r
.38712 .6283 m .39321 .62688 L .39142 .6258 L F
.773 .682 .762 r
.31902 .65504 m .32026 .65867 L .31728 .6578 L F
.759 .321 .211 r
.31728 .6578 m .32026 .65867 L .31898 .66042 L F
.563 .374 .583 r
.31787 .66216 m .32042 .66141 L .32026 .65867 L F
.409 .465 .807 r
.32169 .65779 m .32026 .65867 L .31902 .65504 L F
.986 .713 .409 r
.31898 .66042 m .32042 .66141 L .32026 .65867 L F
0 0 0 r
.31898 .66042 m .32026 .65867 L .32169 .65779 L F
.83 .923 .534 r
.35791 .66504 m .35656 .66665 L .35752 .66503 L F
.586 .513 .74 r
.31087 .53836 m .31346 .53789 L .31275 .53391 L F
.548 .366 .586 r
.29537 .54674 m .29282 .54997 L .29282 .54723 L F
.34 .158 .483 r
.30472 .60109 m .30681 .60045 L .30691 .59784 L F
.402 .24 .544 r
.30456 .60394 m .30681 .60045 L .30472 .60109 L F
.613 .585 .798 r
.43311 .49325 m .43401 .49659 L .43042 .49537 L F
.652 .565 .745 r
.43476 .49903 m .43042 .49537 L .43401 .49659 L F
.952 .606 .233 r
.58321 .40378 m .58529 .40825 L .58303 .40652 L F
.85 .663 .65 r
.58529 .40825 m .58471 .41037 L .58303 .40652 L F
0 0 .349 r
.32755 .61098 m .32828 .61284 L .32852 .61012 L F
.32755 .61098 m .32734 .61423 L .32828 .61284 L F
0 0 0 r
.32559 .62053 m .32756 .61715 L .32669 .61933 L F
.58 .845 .995 r
.32355 .61941 m .32559 .62053 L .32669 .61933 L F
.966 .732 .535 r
.32355 .61941 m .32499 .62298 L .32559 .62053 L F
.021 0 .036 r
.32089 .61939 m .31887 .62058 L .31793 .62295 L F
.64 .955 .765 r
.33621 .66099 m .33363 .6632 L .3336 .66157 L F
.247 .085 .455 r
.34805 .57278 m .34814 .57498 L .34751 .57427 L F
.713 .416 .473 r
.24765 .56624 m .24995 .5687 L .25025 .56651 L F
.505 .231 .432 r
.25025 .56651 m .24995 .5687 L .25236 .56826 L F
.435 .367 .682 r
.45793 .56214 m .45611 .56646 L .45479 .56264 L F
.45793 .56214 m .45853 .56631 L .45611 .56646 L F
.738 .991 .868 r
.65621 .41725 m .65883 .41666 L .65852 .41595 L F
.563 .715 .943 r
.35791 .6492 m .35427 .6481 L .35699 .64771 L F
.536 0 0 r
.35891 .65036 m .35791 .6492 L .35699 .64771 L F
.35891 .65036 m .3607 .65173 L .35791 .6492 L F
.42 .14 .38 r
.45506 .57873 m .45217 .58158 L .45238 .57903 L F
.923 .601 .134 r
.41692 .57892 m .41587 .57781 L .41543 .57498 L F
.944 .642 .193 r
.41692 .57892 m .41617 .58025 L .41587 .57781 L F
.41692 .57892 m .41694 .58106 L .41617 .58025 L F
.353 .519 .882 r
.23233 .57197 m .23138 .56703 L .22915 .56732 L F
.641 .769 .302 r
.70976 .29032 m .70931 .29129 L .71033 .2891 L F
0 0 0 r
.71033 .2891 m .71262 .28505 L .71221 .28705 L F
.70976 .29032 m .71033 .2891 L .71221 .28705 L F
.852 .992 .74 r
.70976 .29032 m .71221 .28705 L .71032 .28762 L F
0 0 .204 r
.71018 .28942 m .70976 .29032 L .71032 .28762 L F
.7099 .29286 m .70976 .29032 L .71018 .28942 L F
.641 .769 .302 r
.70976 .29032 m .70871 .29256 L .70931 .29129 L F
.743 .575 .666 r
.35556 .51342 m .35259 .51837 L .35196 .51432 L F
.779 .623 .687 r
.35556 .51342 m .35522 .51862 L .35259 .51837 L F
.422 .352 .673 r
.35728 .51441 m .35522 .51862 L .35556 .51342 L F
.852 .832 .827 r
.62718 .42568 m .62754 .42105 L .62721 .42502 L F
.62718 .42568 m .62979 .42255 L .62754 .42105 L F
.611 .53 .738 r
.33257 .56505 m .33361 .56917 L .33093 .56945 L F
.396 .186 .473 r
.33282 .57104 m .33093 .56945 L .33361 .56917 L F
.33282 .57104 m .33051 .57207 L .33093 .56945 L F
0 .224 .737 r
.22747 .55632 m .22976 .55836 L .22916 .55995 L F
.489 .261 .494 r
.22916 .55995 m .22933 .56286 L .23132 .56197 L F
.656 .956 .942 r
.22976 .55836 m .22767 .55967 L .22916 .55995 L F
.663 .96 .937 r
.71517 .34018 m .71144 .34123 L .71495 .33994 L F
.684 .949 .682 r
.71517 .34018 m .71495 .33994 L .71705 .33781 L F
.484 .18 .375 r
.42052 .51185 m .41993 .51385 L .41778 .51227 L F
.42052 .51185 m .41993 .51385 L .41778 .51227 L F
0 0 .023 r
.29042 .63535 m .28913 .63635 L .2915 .63308 L F
.091 0 .381 r
.28888 .639 m .28913 .63635 L .29042 .63535 L F
.504 .362 .62 r
.36161 .62304 m .35937 .62675 L .35922 .6236 L F
.36161 .62304 m .35937 .62675 L .35922 .6236 L F
.63 .816 .972 r
.33523 .69942 m .33941 .69986 L .33817 .69823 L F
.696 .262 .215 r
.33753 .70182 m .33941 .69986 L .33523 .69942 L F
0 .062 .591 r
.33817 .69823 m .33941 .69986 L .34 .70003 L F
0 0 0 r
.34 .70003 m .33941 .69986 L .33753 .70182 L F
.811 .815 .854 r
.40668 .49263 m .40322 .49247 L .40535 .4912 L F
.725 .799 .91 r
.40912 .49142 m .40668 .49263 L .40535 .4912 L F
.778 .714 .791 r
.68398 .33631 m .6878 .33689 L .68658 .33307 L F
.786 .697 .766 r
.68524 .34017 m .6878 .33689 L .68398 .33631 L F
.763 .705 .798 r
.68658 .33307 m .6878 .33689 L .69045 .33377 L F
0 0 0 r
.29838 .63784 m .29608 .64099 L .29743 .64105 L F
0 .11 .663 r
.30154 .64149 m .29838 .63784 L .29743 .64105 L F
0 0 .485 r
.61144 .41398 m .61258 .41461 L .61099 .41207 L F
.61144 .41398 m .61237 .4161 L .61258 .41461 L F
.799 .704 .759 r
.68155 .33955 m .68524 .34017 L .68398 .33631 L F
.81 .668 .706 r
.68309 .3434 m .68524 .34017 L .68155 .33955 L F
.007 .213 .724 r
.32027 .69094 m .32243 .69171 L .321 .68962 L F
.32027 .69094 m .32175 .6929 L .32243 .69171 L F
.431 0 0 r
.36824 .50781 m .36883 .5082 L .37057 .50908 L F
.766 .274 .054 r
.36883 .5082 m .37299 .51099 L .37057 .50908 L F
0 .065 .6 r
.28303 .64584 m .28534 .64865 L .28521 .64802 L F
.962 .649 .385 r
.41964 .59172 m .41801 .59305 L .41839 .59077 L F
.41964 .59172 m .41998 .59424 L .41801 .59305 L F
.446 .064 .221 r
.31772 .54833 m .31864 .54741 L .31876 .54937 L F
.31772 .54833 m .31501 .54717 L .31864 .54741 L F
.731 .625 .741 r
.38457 .66471 m .38178 .66807 L .38514 .66794 L F
.747 .523 .591 r
.38173 .67077 m .38514 .66794 L .38178 .66807 L F
.38173 .67077 m .38511 .6715 L .38514 .66794 L F
.245 .279 .699 r
.38514 .66794 m .38538 .66786 L .38517 .66704 L F
.38492 .66669 m .38517 .66704 L .38457 .66471 L F
.38514 .66794 m .38517 .66704 L .38492 .66669 L F
.38526 .66737 m .38538 .66676 L .38457 .66471 L F
.783 .71 .783 r
.3809 .66503 m .38178 .66807 L .38457 .66471 L F
.776 .758 .837 r
.38423 .66155 m .3809 .66503 L .38457 .66471 L F
.696 .66 .81 r
.38546 .66695 m .3809 .66503 L .38288 .66389 L F
.38572 .66726 m .38538 .66711 L .38546 .66695 L F
.245 .279 .699 r
.38538 .66711 m .38538 .66676 L .38526 .66737 L F
.696 .66 .81 r
.38538 .66711 m .3809 .66503 L .38546 .66695 L F
.245 .279 .699 r
.38538 .66786 m .38538 .66711 L .38526 .66737 L F
.148 .258 .722 r
.38457 .66471 m .38572 .66726 L .38546 .66695 L F
.38457 .66471 m .38717 .66726 L .38572 .66726 L F
.245 .279 .699 r
.38538 .66676 m .38538 .66551 L .38457 .66471 L F
.148 .258 .722 r
.38457 .66471 m .38546 .66695 L .38288 .66389 L F
.566 .887 .619 r
.38538 .66733 m .38173 .67077 L .38178 .66807 L F
.38572 .66726 m .38548 .66747 L .38538 .66733 L F
.38548 .66747 m .38173 .67077 L .38538 .66733 L F
.696 .66 .81 r
.38538 .66711 m .38178 .66807 L .3809 .66503 L F
.38572 .66726 m .38538 .66733 L .38538 .66711 L F
.38538 .66733 m .38178 .66807 L .38538 .66711 L F
.566 .887 .619 r
.38548 .66747 m .38287 .66947 L .38173 .67077 L F
.38572 .66726 m .38558 .66737 L .38548 .66747 L F
.38558 .66737 m .38287 .66947 L .38548 .66747 L F
.245 .279 .699 r
.38538 .66786 m .38717 .66726 L .3864 .66651 L F
.38538 .66758 m .3864 .66651 L .38538 .66551 L F
0 0 .131 r
.38514 .66794 m .38567 .66897 L .38717 .66726 L F
.28 0 0 r
.38567 .66897 m .38572 .6674 L .38717 .66726 L F
.38572 .6674 m .38572 .66726 L .38717 .66726 L F
.245 .279 .699 r
.38538 .66786 m .38573 .6674 L .38538 .66758 L F
.38573 .6674 m .38554 .66742 L .38538 .66758 L F
0 0 .131 r
.38514 .66794 m .38511 .6715 L .38567 .66897 L F
.28 0 0 r
.38567 .66897 m .38287 .66947 L .38558 .66737 L F
.38572 .6674 m .38558 .66737 L .38572 .66726 L F
.245 .279 .699 r
.38573 .6674 m .38573 .6674 L .38538 .66758 L F
.28 0 0 r
.38567 .66897 m .38558 .66737 L .38572 .6674 L F
.245 .279 .699 r
.38573 .6674 m .38573 .6674 L .38573 .6674 L F
.38573 .6674 m .3864 .66651 L .38554 .66742 L F
.547 .478 .729 r
.37285 .52479 m .37059 .5224 L .37405 .5219 L F
.764 .704 .165 r
.64944 .43027 m .64974 .42944 L .64934 .42759 L F
.64944 .43027 m .64931 .4323 L .64974 .42944 L F
.205 0 .006 r
.32857 .68074 m .32472 .68387 L .32696 .68298 L F
.301 0 .042 r
.32939 .68256 m .32857 .68074 L .32696 .68298 L F
.32939 .68256 m .33094 .68031 L .32857 .68074 L F
.646 .107 0 r
.23594 .60931 m .23602 .60841 L .23409 .60688 L F
.23594 .60931 m .23809 .61073 L .23602 .60841 L F
0 .263 .772 r
.37461 .52719 m .3754 .52656 L .37285 .52479 L F
.331 0 0 r
.37461 .52719 m .37564 .52901 L .3754 .52656 L F
.37461 .52719 m .37269 .52964 L .37564 .52901 L F
.193 .208 .647 r
.34116 .55677 m .34324 .55891 L .34288 .55506 L F
.266 0 0 r
.24543 .62314 m .2413 .62259 L .24311 .62359 L F
.574 .346 .531 r
.28319 .53388 m .2858 .53381 L .28608 .53125 L F
.558 .33 .526 r
.2858 .53381 m .28864 .53086 L .28608 .53125 L F
0 0 0 r
.22399 .54238 m .22373 .54272 L .22522 .54131 L F
.22522 .54131 m .22524 .54151 L .22731 .54018 L F
.22522 .54131 m .22373 .54272 L .22524 .54151 L F
.636 .625 .822 r
.34481 .51283 m .34577 .51556 L .34816 .51513 L F
.105 0 0 r
.34539 .51692 m .34816 .51513 L .34577 .51556 L F
0 0 .222 r
.61431 .44379 m .61197 .44793 L .61579 .44343 L F
.728 .63 .749 r
.37143 .61584 m .37156 .62022 L .36795 .62011 L F
.433 .504 .832 r
.37178 .62282 m .36795 .62011 L .37156 .62022 L F
0 0 .473 r
.37238 .61926 m .37156 .62022 L .37143 .61584 L F
.582 .348 .527 r
.37425 .62266 m .37156 .62022 L .37238 .61926 L F
.37425 .62266 m .37178 .62282 L .37156 .62022 L F
.81 .616 .641 r
.36518 .60312 m .37086 .60087 L .36856 .60246 L F
.496 .521 .813 r
.37156 .60409 m .36856 .60246 L .37086 .60087 L F
.158 0 0 r
.25456 .54609 m .2569 .54558 L .25896 .54381 L F
0 0 0 r
.25896 .54381 m .25876 .54463 L .26122 .54261 L F
.25896 .54381 m .2569 .54558 L .25876 .54463 L F
.436 .267 .552 r
.30545 .54698 m .30334 .55034 L .30551 .54965 L F
.372 .171 .473 r
.30334 .55034 m .30514 .55213 L .30551 .54965 L F
.30334 .55034 m .3031 .5529 L .30514 .55213 L F
.474 .504 .808 r
.45031 .54642 m .44926 .5503 L .44807 .54675 L F
.45031 .54642 m .45139 .54973 L .44926 .5503 L F
.507 .357 .612 r
.45139 .54973 m .44895 .55328 L .44926 .5503 L F
.732 .283 .185 r
.72577 .33535 m .72702 .3337 L .72552 .33226 L F
.72577 .33535 m .72934 .336 L .72702 .3337 L F
.85 .963 .878 r
.34389 .69142 m .34749 .69118 L .34484 .69346 L F
.763 .976 .919 r
.34835 .69011 m .34749 .69118 L .34389 .69142 L F
.687 .659 .817 r
.31498 .54374 m .31273 .54438 L .31103 .54277 L F
.643 .48 .648 r
.31498 .54374 m .3124 .54703 L .31273 .54438 L F
.533 .485 .748 r
.44537 .53658 m .44381 .54116 L .44355 .53722 L F
.764 .611 .689 r
.61408 .37845 m .61243 .38201 L .61039 .38098 L F
0 0 0 r
.66438 .40267 m .66323 .40409 L .66564 .40096 L F
0 0 .135 r
.66263 .40627 m .66323 .40409 L .66438 .40267 L F
.172 .183 .63 r
.33414 .50897 m .33674 .51008 L .33494 .50361 L F
.797 .754 .814 r
.35563 .65839 m .35998 .65586 L .35783 .65429 L F
.844 .866 .859 r
.35998 .65586 m .357 .65357 L .35783 .65429 L F
.35998 .65586 m .3607 .65173 L .357 .65357 L F
.35998 .65586 m .36245 .65343 L .3607 .65173 L F
.571 .334 .517 r
.30141 .60693 m .30456 .60394 L .30211 .60483 L F
.365 .39 .754 r
.7079 .27656 m .70953 .27981 L .71108 .27845 L F
.172 .521 .918 r
.71059 .28182 m .7122 .28399 L .70929 .28293 L F
.778 .922 .933 r
.72371 .35185 m .72459 .35297 L .72632 .35156 L F
.41 .588 .915 r
.72163 .34467 m .7232 .3466 L .72499 .34585 L F
.72499 .34585 m .7232 .3466 L .72163 .34467 L F
.325 0 .148 r
.34751 .57427 m .34394 .57798 L .34166 .5785 L F
.827 .644 .655 r
.62979 .42255 m .6268 .41929 L .62754 .42105 L F
0 0 .486 r
.33653 .55828 m .33508 .55706 L .33632 .5555 L F
0 0 .057 r
.20412 .60301 m .20337 .60478 L .20326 .60439 L F
.271 .574 .94 r
.715 .28457 m .71262 .28505 L .7122 .28399 L F
.073 0 .02 r
.71221 .28705 m .71262 .28505 L .715 .28457 L F
.736 .61 .717 r
.68186 .35279 m .68556 .35331 L .6842 .34983 L F
.785 .593 .642 r
.68195 .35529 m .68556 .35331 L .68186 .35279 L F
.68195 .35529 m .68531 .35518 L .68556 .35331 L F
.71 .614 .748 r
.4157 .50828 m .41538 .51109 L .41386 .5109 L F
.999 .826 .491 r
.41815 .58552 m .41677 .58678 L .41679 .58363 L F
.41815 .58552 m .41772 .58802 L .41677 .58678 L F
.314 .147 .488 r
.33224 .58746 m .33105 .58526 L .3334 .58466 L F
.33224 .58746 m .3305 .58792 L .33105 .58526 L F
.383 .266 .594 r
.39322 .61094 m .39346 .61377 L .39527 .61301 L F
.54 .57 .834 r
.37814 .66513 m .3809 .66503 L .37955 .66128 L F
.354 .748 .985 r
.37814 .66513 m .3809 .66503 L .37639 .66402 L F
.542 .563 .826 r
.37814 .66513 m .38178 .66807 L .3809 .66503 L F
.948 .667 .215 r
.41013 .54723 m .40909 .54617 L .40879 .54315 L F
0 0 .206 r
.41013 .54723 m .41057 .54813 L .40909 .54617 L F
.41013 .54723 m .41063 .55002 L .41057 .54813 L F
0 0 0 r
.63123 .38917 m .62972 .39067 L .62882 .3875 L F
0 .326 .78 r
.62693 .38842 m .62972 .39067 L .62975 .3898 L F
.741 .969 .702 r
.62975 .3898 m .62972 .39067 L .62714 .39342 L F
.401 .103 .341 r
.68229 .37251 m .68216 .37431 L .67951 .37522 L F
.478 .164 .355 r
.68478 .3735 m .68229 .37251 L .68554 .37114 L F
.68478 .3735 m .68216 .37431 L .68229 .37251 L F
.502 .905 .914 r
.2989 .51509 m .29444 .51607 L .29811 .51501 L F
.772 .992 .884 r
.29957 .51309 m .30196 .51281 L .2989 .51509 L F
.804 .994 .763 r
.29957 .51309 m .2989 .51509 L .29811 .51501 L F
.521 .393 .646 r
.28336 .60141 m .28188 .60448 L .28347 .60249 L F
.995 .871 .557 r
.28336 .60141 m .28347 .60249 L .28329 .6019 L F
.562 .57 .819 r
.28188 .60448 m .28275 .60017 L .28329 .6019 L F
.28188 .60448 m .28329 .6019 L .28347 .60249 L F
.521 .393 .646 r
.28329 .6019 m .28427 .60389 L .28291 .60422 L F
.28336 .60141 m .28344 .60161 L .28329 .6019 L F
.28344 .60161 m .28427 .60389 L .28329 .6019 L F
.28336 .60141 m .28291 .60422 L .28188 .60448 L F
.995 .871 .557 r
.28336 .60141 m .28329 .6019 L .28275 .60017 L F
.413 .863 .85 r
.30437 .51183 m .30196 .51281 L .29957 .51309 L F
.138 .418 .862 r
.39448 .60108 m .39558 .60011 L .3921 .59791 L F
.752 .829 .911 r
.39486 .60317 m .39558 .60011 L .39448 .60108 L F
.476 .775 .996 r
.39231 .58171 m .38991 .58218 L .38825 .58098 L F
.3 .218 .593 r
.36338 .52406 m .36502 .52053 L .3633 .52161 L F
.968 .649 .282 r
.70449 .30788 m .70612 .31149 L .70727 .30957 L F
.807 .402 .283 r
.70612 .31149 m .70908 .31407 L .70679 .313 L F
0 0 .506 r
.70679 .313 m .70727 .30957 L .70612 .31149 L F
.508 .277 .499 r
.44964 .5821 m .44939 .58457 L .44686 .58522 L F
.491 .255 .483 r
.45217 .58158 m .44939 .58457 L .44964 .5821 L F
.689 .691 .846 r
.31599 .62634 m .31793 .62295 L .31574 .62313 L F
.873 .578 .057 r
.40696 .59117 m .4059 .58779 L .40567 .59033 L F
.994 .869 .59 r
.40567 .59033 m .40584 .59484 L .40696 .59117 L F
.775 .862 .914 r
.38225 .70265 m .38503 .70256 L .38427 .70165 L F
.944 .586 .205 r
.38478 .70526 m .38503 .70256 L .38225 .70265 L F
.38478 .70526 m .38586 .70537 L .38503 .70256 L F
0 0 0 r
.37197 .65771 m .3702 .65874 L .3684 .66062 L F
.817 .569 .565 r
.2896 .65464 m .29378 .65584 L .2925 .65692 L F
0 0 .218 r
.29378 .65584 m .29487 .65205 L .2949 .65466 L F
.582 .897 .629 r
.2925 .65692 m .29378 .65584 L .2949 .65466 L F
.757 .673 .769 r
.63111 .36548 m .63237 .36944 L .62838 .36889 L F
.766 .678 .765 r
.6348 .36612 m .63237 .36944 L .63111 .36548 L F
.688 .728 .881 r
.63427 .38632 m .63869 .38663 L .6377 .3838 L F
.696 .734 .88 r
.6377 .3838 m .63869 .38663 L .64154 .38466 L F
.184 0 0 r
.33284 .61359 m .32907 .61563 L .3306 .61411 L F
.519 .917 .864 r
.30096 .5566 m .29737 .55726 L .30151 .55552 L F
0 0 0 r
.29705 .55655 m .30151 .55552 L .29737 .55726 L F
.363 0 0 r
.2995 .55604 m .30108 .55617 L .30151 .55552 L F
.635 .808 .379 r
.30096 .5566 m .30151 .55552 L .30201 .55479 L F
.682 .629 .79 r
.30456 .55588 m .30096 .5566 L .3031 .5529 L F
.353 .145 .451 r
.30299 .55855 m .30096 .5566 L .30456 .55588 L F
.363 0 0 r
.30108 .55617 m .30341 .55637 L .30151 .55552 L F
.635 .808 .379 r
.30201 .55479 m .30151 .55552 L .3031 .5529 L F
.353 .145 .451 r
.30299 .55855 m .30097 .55943 L .30096 .5566 L F
.389 .2 .5 r
.30736 .61684 m .30689 .62221 L .30487 .62145 L F
.334 .132 .45 r
.30964 .61314 m .31002 .61648 L .30736 .61684 L F
.198 .045 .436 r
.30933 .61874 m .30736 .61684 L .31002 .61648 L F
.30933 .61874 m .30689 .62221 L .30736 .61684 L F
.796 .355 .2 r
.24726 .5684 m .24765 .56624 L .24596 .56545 L F
.24726 .5684 m .24995 .5687 L .24765 .56624 L F
.714 .547 0 r
.41323 .55697 m .4133 .55833 L .41285 .55574 L F
.41323 .55697 m .41337 .55927 L .4133 .55833 L F
.898 .822 .764 r
.39783 .60977 m .40177 .60731 L .40043 .60658 L F
.39783 .60977 m .39978 .6107 L .40177 .60731 L F
.95 .954 .72 r
.40177 .60731 m .40254 .60318 L .40043 .60658 L F
.374 .013 .217 r
.39951 .67509 m .39666 .67742 L .39748 .67554 L F
.679 .624 .787 r
.35336 .53729 m .35395 .54028 L .35677 .53769 L F
.842 .652 .646 r
.56595 .45822 m .56564 .46077 L .56228 .46009 L F
.687 .22 .137 r
.43177 .59171 m .4302 .59328 L .42783 .5911 L F
.594 .108 .068 r
.43177 .59171 m .43403 .59359 L .4302 .59328 L F
.545 .143 .231 r
.43452 .59184 m .43403 .59359 L .43177 .59171 L F
.857 .637 .605 r
.58505 .41657 m .58645 .41986 L .58204 .41872 L F
0 .154 .675 r
.5875 .41734 m .58505 .41657 L .58899 .41866 L F
.774 .697 .778 r
.58505 .41657 m .58645 .41986 L .58899 .41866 L F
0 .154 .675 r
.5875 .41734 m .58645 .41986 L .58505 .41657 L F
0 .181 .716 r
.37585 .51277 m .37628 .51429 L .3742 .51249 L F
.615 .804 .972 r
.61864 .36979 m .61543 .36948 L .6179 .36821 L F
.632 .68 .877 r
.62038 .36721 m .61864 .36979 L .6179 .36821 L F
.62038 .36721 m .62187 .36916 L .61864 .36979 L F
.861 .662 .633 r
.25383 .62979 m .25569 .63087 L .25743 .63023 L F
.713 .937 .622 r
.25565 .63166 m .25499 .63314 L .25743 .63023 L F
0 0 0 r
.25783 .63096 m .25743 .63023 L .25901 .6304 L F
.25783 .63096 m .25565 .63166 L .25743 .63023 L F
.442 .689 .97 r
.26528 .5275 m .26597 .52574 L .26349 .52657 L F
.26528 .5275 m .26763 .52746 L .26597 .52574 L F
.801 .85 .887 r
.24815 .53241 m .24569 .53401 L .24955 .53419 L F
.851 .762 .764 r
.24569 .53401 m .24715 .5373 L .24955 .53419 L F
.794 .848 .892 r
.24815 .53241 m .24955 .53419 L .25268 .53155 L F
.021 .027 .522 r
.4276 .578 m .42742 .58045 L .42554 .5783 L F
.184 0 .216 r
.58899 .41866 m .58645 .41986 L .58579 .42198 L F
0 0 0 r
.58579 .42198 m .58645 .41986 L .5875 .41734 L F
.175 .492 .904 r
.20545 .59495 m .20793 .59757 L .2083 .59617 L F
.905 .525 .086 r
.20793 .59757 m .20856 .6 L .20957 .60012 L F
0 0 .078 r
.7083 .29501 m .70871 .29256 L .70976 .29032 L F
.85 .536 .457 r
.58204 .41872 m .58579 .42198 L .58336 .42038 L F
.806 .724 .774 r
.62806 .43163 m .62922 .43507 L .62916 .43251 L F
.493 .736 .98 r
.63052 .43057 m .62916 .43251 L .62806 .43163 L F
.63052 .43057 m .63204 .43242 L .62916 .43251 L F
.63052 .43057 m .62916 .43251 L .62806 .43163 L F
.63052 .43057 m .63204 .43242 L .62916 .43251 L F
.796 .679 .735 r
.34404 .52972 m .34957 .53431 L .34737 .52997 L F
.457 .003 .084 r
.34623 .534 m .35002 .53268 L .34957 .53431 L F
.738 .529 .61 r
.34582 .54404 m .34442 .5464 L .34146 .54607 L F
.614 .471 .664 r
.34759 .54071 m .34582 .54404 L .34808 .54368 L F
.685 .512 .647 r
.34442 .5464 m .34808 .54368 L .34582 .54404 L F
.614 .471 .664 r
.34759 .54071 m .34582 .54404 L .34808 .54368 L F
.752 .642 .738 r
.34442 .5464 m .34808 .54368 L .34582 .54404 L F
.248 .422 .838 r
.38674 .52397 m .3886 .52734 L .38741 .52589 L F
.987 .736 .462 r
.38838 .52614 m .38983 .53012 L .3886 .52734 L F
.823 .603 .605 r
.34438 .69625 m .34882 .69712 L .34453 .69744 L F
.037 0 0 r
.35141 .69653 m .34882 .69712 L .34909 .69759 L F
0 0 .127 r
.34909 .69759 m .34882 .69712 L .34915 .69528 L F
.717 .875 .955 r
.71827 .32637 m .7194 .32801 L .72168 .3264 L F
.61 .808 .976 r
.3607 .65173 m .36245 .65343 L .36473 .65248 L F
.249 0 .149 r
.69063 .36735 m .69078 .36551 L .69325 .36444 L F
.675 .552 .707 r
.29513 .55969 m .29604 .56325 L .29257 .56321 L F
.436 .342 .651 r
.29479 .56426 m .29257 .56321 L .29604 .56325 L F
.486 .432 .722 r
.29824 .56244 m .29604 .56325 L .29513 .55969 L F
.004 0 0 r
.29824 .56244 m .29479 .56426 L .29604 .56325 L F
.754 .722 .822 r
.2941 .56183 m .29479 .56426 L .29824 .56244 L F
.2941 .56183 m .29824 .56244 L .29597 .56333 L F
.047 .242 .74 r
.2941 .56183 m .29597 .56333 L .2952 .5611 L F
0 0 0 r
.29513 .55969 m .2941 .56183 L .29677 .55864 L F
.782 .981 .714 r
.29677 .55864 m .2941 .56183 L .29479 .55991 L F
.047 .242 .74 r
.2941 .56183 m .2952 .5611 L .29479 .55991 L F
0 0 0 r
.29307 .56253 m .2941 .56183 L .29513 .55969 L F
.29257 .56321 m .2941 .56183 L .29307 .56253 L F
.436 .342 .651 r
.29479 .56426 m .29309 .56603 L .29257 .56321 L F
0 0 0 r
.29257 .56321 m .2911 .56504 L .2941 .56183 L F
.883 .961 .844 r
.38257 .59181 m .37717 .59543 L .38215 .59453 L F
.521 .334 .569 r
.38215 .59453 m .38476 .59441 L .38257 .59181 L F
.38257 .59181 m .38476 .59441 L .38215 .59453 L F
.576 .707 .932 r
.43303 .58228 m .43542 .58154 L .43324 .5789 L F
.234 0 0 r
.43123 .58357 m .43542 .58154 L .43303 .58228 L F
.639 .507 .686 r
.25982 .56016 m .25899 .56288 L .26184 .56238 L F
.57 .307 .477 r
.25895 .56554 m .26184 .56238 L .25899 .56288 L F
.252 0 .09 r
.37143 .57889 m .37547 .57569 L .37217 .57652 L F
.431 .833 .978 r
.36161 .62304 m .36532 .6231 L .36404 .6225 L F
.36161 .62304 m .36532 .6231 L .36404 .6225 L F
.878 .956 .851 r
.36795 .62011 m .36532 .6231 L .36404 .6225 L F
.546 .028 0 r
.36532 .6231 m .36647 .62196 L .36404 .6225 L F
.36532 .6231 m .36753 .62438 L .36651 .62516 L F
.36532 .6231 m .36651 .62516 L .36647 .62196 L F
.612 .656 .869 r
.31812 .51886 m .32072 .52294 L .31796 .52166 L F
.807 .725 .774 r
.32241 .51815 m .32072 .52294 L .31838 .51926 L F
.612 .656 .869 r
.31812 .51886 m .31796 .52166 L .31576 .52086 L F
.826 .416 .267 r
.31796 .52166 m .31658 .52265 L .31576 .52086 L F
.545 .308 .507 r
.31658 .52265 m .31996 .52077 L .31686 .52084 L F
.31611 .52162 m .31686 .52084 L .31576 .52086 L F
.31658 .52265 m .31686 .52084 L .31611 .52162 L F
.807 .725 .774 r
.31888 .51874 m .31838 .51926 L .31812 .51886 L F
.32241 .51815 m .31838 .51926 L .31888 .51874 L F
.546 .383 .611 r
.3388 .54679 m .33887 .54986 L .33632 .55017 L F
.459 .261 .524 r
.33887 .54986 m .33656 .55319 L .33632 .55017 L F
.765 .362 .289 r
.59258 .43502 m .5963 .4354 L .59528 .43435 L F
.791 .791 .852 r
.5963 .4354 m .59258 .43502 L .59528 .43435 L F
.232 0 0 r
.31891 .66332 m .31787 .66216 L .31981 .66325 L F
.31891 .66332 m .32042 .66141 L .31787 .66216 L F
.194 0 0 r
.20503 .60224 m .20957 .60012 L .20743 .6015 L F
.091 .388 .847 r
.21012 .60324 m .20743 .6015 L .20957 .60012 L F
.194 0 0 r
.20503 .60224 m .20749 .60176 L .20957 .60012 L F
0 .054 .611 r
.2083 .59617 m .20957 .60012 L .21004 .5983 L F
.804 .973 .673 r
.20957 .60012 m .20841 .60104 L .21004 .5983 L F
.20841 .60104 m .20749 .60176 L .20855 .60033 L F
.20841 .60104 m .20855 .60033 L .21004 .5983 L F
0 0 0 r
.211 .60204 m .21062 .60265 L .21012 .60324 L F
.091 .388 .847 r
.21012 .60324 m .20966 .60462 L .20934 .60418 L F
.774 .827 .358 r
.20915 .60498 m .20966 .60462 L .21012 .60324 L F
0 0 0 r
.21062 .60265 m .20915 .60498 L .21012 .60324 L F
.091 .388 .847 r
.21012 .60324 m .20934 .60418 L .20812 .60247 L F
.20821 .60201 m .20812 .60247 L .20743 .6015 L F
.21012 .60324 m .20812 .60247 L .20821 .60201 L F
.774 .827 .358 r
.20915 .60498 m .20864 .60713 L .20966 .60462 L F
.65 .652 .839 r
.35259 .51837 m .34964 .51918 L .34753 .51607 L F
.434 .164 .403 r
.29376 .61385 m .29614 .6133 L .29672 .61095 L F
.313 .057 .356 r
.29672 .61095 m .2983 .61251 L .29883 .6102 L F
.29672 .61095 m .29614 .6133 L .2983 .61251 L F
0 .189 .713 r
.3438 .68575 m .34355 .68648 L .34484 .6874 L F
.791 .502 .498 r
.5733 .40402 m .5731 .40615 L .57073 .40577 L F
.558 .797 .988 r
.57397 .40141 m .57373 .40388 L .5733 .40402 L F
.765 .977 .916 r
.57397 .40141 m .5733 .40402 L .57105 .40379 L F
.41 .173 .441 r
.57373 .40388 m .5731 .40615 L .5733 .40402 L F
.478 .824 .998 r
.38355 .62224 m .38165 .62023 L .38366 .61955 L F
0 .057 .566 r
.37981 .61871 m .38355 .62224 L .38366 .61955 L F
.678 .855 .967 r
.56784 .41257 m .56937 .41373 L .56569 .41441 L F
.843 .877 .866 r
.57185 .41106 m .56937 .41373 L .56784 .41257 L F
.682 .297 .311 r
.54984 .4483 m .54824 .45032 L .54583 .44825 L F
.669 .282 .302 r
.54984 .4483 m .55238 .45045 L .54824 .45032 L F
.393 .246 .559 r
.31225 .60993 m .3125 .61329 L .30964 .61314 L F
.224 .058 .435 r
.31161 .61547 m .30964 .61314 L .3125 .61329 L F
.31161 .61547 m .31002 .61648 L .30964 .61314 L F
.446 .827 .989 r
.37247 .66073 m .37405 .66172 L .37646 .66119 L F
.37247 .66073 m .37405 .66172 L .37646 .66119 L F
.585 .421 .625 r
.32488 .61748 m .32756 .61715 L .32734 .61423 L F
.58 .845 .995 r
.32355 .61941 m .32756 .61715 L .32488 .61748 L F
.339 .656 .971 r
.58157 .39768 m .57884 .39612 L .58022 .3967 L F
.05 .37 .838 r
.58342 .39739 m .58157 .39768 L .58022 .3967 L F
.58342 .39739 m .58439 .39928 L .58157 .39768 L F
.095 .391 .848 r
.58529 .40116 m .58157 .39768 L .58439 .39928 L F
.137 0 .311 r
.20738 .56628 m .20683 .56873 L .20901 .56528 L F
.813 .736 .779 r
.60817 .42951 m .61039 .42814 L .60668 .42696 L F
.416 .143 .39 r
.32381 .56641 m .32063 .56939 L .32304 .56879 L F
0 0 .013 r
.32381 .56641 m .32304 .56879 L .32472 .56525 L F
.584 .574 .808 r
.30927 .52096 m .31027 .52532 L .31336 .5242 L F
.22 0 .084 r
.30208 .6262 m .30576 .62276 L .30456 .62527 L F
0 0 .236 r
.30689 .62221 m .30576 .62276 L .30487 .62145 L F
.30689 .62221 m .30547 .6244 L .30576 .62276 L F
.055 0 .328 r
.3088 .62126 m .30648 .62345 L .30689 .62221 L F
.30648 .62345 m .30547 .6244 L .30619 .62331 L F
.30648 .62345 m .30619 .62331 L .30689 .62221 L F
0 0 .161 r
.30684 .62441 m .30547 .6244 L .3088 .62126 L F
0 0 .224 r
.3057 .62311 m .30547 .6244 L .30684 .62441 L F
.30576 .62276 m .3057 .62311 L .30684 .62441 L F
.30563 .62303 m .30684 .62441 L .30456 .62527 L F
.30576 .62276 m .30609 .62326 L .30563 .62303 L F
.30609 .62326 m .30684 .62441 L .30563 .62303 L F
.717 .879 .956 r
.31103 .54277 m .30851 .54391 L .30814 .54245 L F
.31103 .54277 m .30814 .54245 L .30935 .53957 L F
.865 .982 .847 r
.30793 .5433 m .30545 .54698 L .30772 .54308 L F
.30851 .54391 m .30717 .54526 L .30793 .5433 L F
.30717 .54526 m .30545 .54698 L .30793 .5433 L F
.346 .243 .593 r
.30772 .54308 m .3075 .54871 L .3076 .54865 L F
.3082 .54405 m .3076 .54865 L .30979 .54728 L F
.30772 .54308 m .3076 .54865 L .3082 .54405 L F
.432 .133 .355 r
.30772 .54308 m .30814 .54245 L .30851 .54391 L F
0 0 .296 r
.30818 .54266 m .3086 .54513 L .30832 .54231 L F
.346 .243 .593 r
.30779 .54323 m .3082 .54405 L .3086 .54513 L F
.30772 .54308 m .30779 .54322 L .30779 .54323 L F
.30779 .54322 m .3082 .54405 L .30779 .54323 L F
.432 .133 .355 r
.30772 .54308 m .3086 .54513 L .30814 .54245 L F
0 0 .296 r
.30836 .54277 m .3086 .54513 L .30844 .54221 L F
.305 .167 .523 r
.30545 .54698 m .3075 .54871 L .30772 .54308 L F
0 0 0 r
.30495 .54388 m .3055 .54188 L .30851 .54303 L F
.065 0 0 r
.30848 .543 m .30702 .54336 L .30851 .54303 L F
.30702 .54336 m .30495 .54388 L .3074 .5433 L F
.30702 .54336 m .3074 .5433 L .30851 .54303 L F
.346 .243 .593 r
.3082 .54405 m .30979 .54728 L .3086 .54513 L F
0 0 .296 r
.30844 .54221 m .30852 .5437 L .30881 .5419 L F
.30832 .54231 m .30836 .54277 L .30844 .54221 L F
.30814 .54245 m .30818 .54266 L .30832 .54231 L F
0 0 .052 r
.30814 .54245 m .30881 .5419 L .30935 .53957 L F
.519 0 0 r
.30935 .53957 m .31345 .54191 L .31103 .54277 L F
.507 .204 .388 r
.30935 .53957 m .30881 .5419 L .31151 .54118 L F
.264 .139 .516 r
.30881 .5419 m .30934 .54223 L .31151 .54118 L F
.30934 .54223 m .31137 .54143 L .31151 .54118 L F
.519 0 0 r
.30935 .53957 m .31151 .54118 L .31171 .54125 L F
.31203 .5411 m .31171 .54125 L .31345 .54191 L F
.30935 .53957 m .31171 .54125 L .31203 .5411 L F
.355 .794 .629 r
.31164 .54129 m .30892 .5428 L .3104 .54079 L F
.264 .139 .516 r
.30881 .5419 m .30874 .54306 L .30934 .54223 L F
0 0 .296 r
.30852 .5437 m .30874 .54306 L .30881 .5419 L F
.355 .794 .629 r
.3088 .54287 m .30851 .54303 L .3096 .54046 L F
.30892 .5428 m .30848 .543 L .30851 .54303 L F
.264 .139 .516 r
.30934 .54223 m .30962 .54241 L .31137 .54143 L F
.355 .794 .629 r
.31141 .54142 m .30962 .54241 L .30892 .5428 L F
.264 .139 .516 r
.30962 .54241 m .31054 .54297 L .31137 .54144 L F
.30962 .54241 m .31137 .54144 L .31137 .54143 L F
.355 .794 .629 r
.31164 .54129 m .31072 .54179 L .30962 .54241 L F
.31164 .54129 m .30962 .54241 L .31141 .54142 L F
.264 .139 .516 r
.30934 .54223 m .30924 .54262 L .30962 .54241 L F
.30874 .54306 m .3086 .54513 L .30934 .54223 L F
.355 .794 .629 r
.31072 .54179 m .30848 .543 L .30892 .5428 L F
.264 .139 .516 r
.30962 .54241 m .3086 .54513 L .31054 .54297 L F
.30924 .54262 m .3086 .54513 L .30962 .54241 L F
.355 .794 .629 r
.3104 .54079 m .3088 .54287 L .3096 .54046 L F
.30892 .5428 m .3088 .54287 L .3104 .54079 L F
.31306 .5405 m .31164 .54129 L .3096 .54046 L F
.31306 .5405 m .31141 .5414 L .31164 .54129 L F
.31141 .5414 m .30848 .543 L .31164 .54129 L F
.3096 .54046 m .30875 .54247 L .30626 .54042 L F
.30875 .54247 m .30851 .54303 L .30821 .54268 L F
.30875 .54247 m .30821 .54268 L .30626 .54042 L F
0 0 .296 r
.30852 .5437 m .3086 .54513 L .30874 .54306 L F
.482 .407 .696 r
.43655 .49574 m .43476 .49903 L .43401 .49659 L F
.43655 .49574 m .43704 .49836 L .43476 .49903 L F
.584 .497 .723 r
.43818 .50213 m .43476 .49903 L .43704 .49836 L F
.43818 .50213 m .43563 .50296 L .43476 .49903 L F
.493 .515 .808 r
.43899 .50461 m .43563 .50296 L .43818 .50213 L F
.663 .816 .957 r
.29197 .64186 m .29057 .64299 L .28897 .64139 L F
.533 .485 .748 r
.44537 .53658 m .44622 .54059 L .44381 .54116 L F
.617 .459 .645 r
.44678 .54295 m .44381 .54116 L .44622 .54059 L F
.44678 .54295 m .44411 .54363 L .44381 .54116 L F
.752 .642 .738 r
.34442 .5464 m .34896 .54725 L .34808 .54368 L F
.705 .27 .215 r
.34442 .5464 m .347 .54856 L .34896 .54725 L F
.654 .581 .76 r
.34808 .54368 m .34896 .54725 L .35167 .5441 L F
.627 .166 .138 r
.347 .54856 m .35104 .54907 L .34896 .54725 L F
.555 .436 .672 r
.34896 .54725 m .35184 .54684 L .35167 .5441 L F
.492 .219 .428 r
.34896 .54725 m .35104 .54907 L .35184 .54684 L F
0 .073 .606 r
.22036 .60729 m .22141 .60806 L .2201 .6032 L F
.507 .659 .929 r
.70392 .35832 m .70398 .35501 L .70101 .35707 L F
.70392 .35832 m .70592 .35809 L .70398 .35501 L F
.732 .364 .353 r
.26172 .57213 m .25966 .57304 L .25812 .57159 L F
.768 .427 .408 r
.26172 .57213 m .26005 .57389 L .25966 .57304 L F
.515 .104 .2 r
.26267 .57316 m .26172 .57213 L .26428 .57201 L F
.26267 .57316 m .26005 .57389 L .26172 .57213 L F
.65 .296 .358 r
.27037 .55861 m .27297 .55873 L .27502 .55614 L F
.248 0 .075 r
.27502 .55614 m .27297 .55873 L .27581 .55788 L F
.795 .874 .441 r
.33513 .52509 m .33454 .52527 L .33574 .5242 L F
.33513 .52509 m .33399 .52754 L .33454 .52527 L F
.709 .431 .501 r
.60077 .45138 m .59918 .45438 L .59696 .45379 L F
.69 .407 .49 r
.60335 .45381 m .60077 .45138 L .60331 .45164 L F
.60335 .45381 m .59918 .45438 L .60077 .45138 L F
0 .206 .731 r
.2464 .61388 m .24859 .61575 L .24815 .61705 L F
.585 .799 .981 r
.24481 .61238 m .2464 .61388 L .24249 .61314 L F
.24481 .61238 m .2464 .61388 L .24249 .61314 L F
.82 .35 .09 r
.24481 .61238 m .24659 .6152 L .24859 .61575 L F
.423 0 0 r
.24659 .6152 m .2488 .61512 L .24859 .61575 L F
.452 .243 .504 r
.24819 .61713 m .25065 .6171 L .25074 .61391 L F
.36 .171 .484 r
.25074 .61391 m .25309 .61336 L .25544 .61657 L F
.25074 .61391 m .25065 .6171 L .25293 .61466 L F
.423 0 0 r
.2488 .61512 m .2511 .61503 L .24859 .61575 L F
0 .206 .731 r
.24815 .61705 m .24859 .61575 L .24819 .61713 L F
.334 .685 .98 r
.24859 .61575 m .25065 .6171 L .24819 .61713 L F
.553 .25 .408 r
.29042 .63535 m .2915 .63308 L .2936 .63511 L F
.472 .255 .502 r
.2915 .63308 m .29388 .63253 L .2936 .63511 L F
.477 .078 .204 r
.27207 .53196 m .26787 .53385 L .27166 .53323 L F
.27207 .53196 m .27166 .53323 L .2699 .52952 L F
.844 .805 .812 r
.27442 .5263 m .27207 .53196 L .2699 .52952 L F
.758 .381 .34 r
.62369 .39928 m .62415 .39692 L .62201 .39633 L F
.786 .708 .778 r
.6236 .39396 m .62714 .39342 L .62415 .39692 L F
.349 .401 .774 r
.6236 .39396 m .62415 .39692 L .62632 .39534 L F
.722 .619 .742 r
.62369 .39928 m .62632 .39534 L .62415 .39692 L F
0 0 0 r
.66786 .39739 m .66724 .39886 L .66564 .40096 L F
.66564 .40096 m .66646 .40079 L .66438 .40267 L F
.66564 .40096 m .66724 .39886 L .66646 .40079 L F
.225 .262 .691 r
.23326 .60294 m .23182 .60492 L .23112 .60092 L F
.232 .272 .698 r
.23326 .60294 m .23409 .60688 L .23182 .60492 L F
.27 0 .251 r
.20981 .56313 m .20901 .56528 L .21197 .56233 L F
.822 .917 .901 r
.69823 .30888 m .70196 .30712 L .70038 .30764 L F
.717 .436 .499 r
.28212 .62025 m .28489 .62261 L .28484 .61986 L F
.28212 .62025 m .28199 .62273 L .28489 .62261 L F
.409 .17 .438 r
.34935 .55832 m .3474 .55627 L .35068 .55633 L F
.747 .777 .877 r
.35281 .55379 m .35068 .55633 L .35321 .5554 L F
0 0 0 r
.35281 .55379 m .35225 .55503 L .35068 .55633 L F
.61 .161 .16 r
.35068 .55633 m .35303 .55822 L .35321 .5554 L F
.35068 .55633 m .34935 .55832 L .35303 .55822 L F
.35068 .55633 m .34935 .55832 L .35303 .55822 L F
.615 .881 .552 r
.35225 .55503 m .34935 .55832 L .35068 .55633 L F
.201 .715 .886 r
.27024 .52108 m .26615 .52085 L .26864 .52078 L F
.492 .887 .954 r
.27229 .5203 m .27024 .52108 L .26864 .52078 L F
0 0 0 r
.35321 .5554 m .35538 .55495 L .357 .55345 L F
.35303 .55822 m .35538 .55495 L .35321 .5554 L F
.61 .798 .373 r
.3494 .5415 m .34808 .54368 L .34759 .54071 L F
0 0 0 r
.30111 .52853 m .30196 .52872 L .30245 .5263 L F
.243 0 0 r
.26061 .52956 m .25678 .52944 L .25876 .52916 L F
.759 .556 .622 r
.34755 .65148 m .35034 .64722 L .34857 .6501 L F
.905 .812 .745 r
.34357 .69602 m .34484 .69346 L .34438 .69625 L F
.949 .692 .513 r
.34267 .69249 m .34484 .69346 L .34438 .69625 L F
.85 .963 .878 r
.34389 .69142 m .34484 .69346 L .34267 .69249 L F
.949 .692 .513 r
.34267 .69249 m .34484 .69346 L .34438 .69625 L F
.759 .556 .622 r
.34755 .65148 m .35115 .65185 L .35034 .64722 L F
.713 .396 .44 r
.35379 .65152 m .35034 .64722 L .35115 .65185 L F
.35379 .65152 m .35427 .6481 L .35034 .64722 L F
.553 .355 .566 r
.33156 .60435 m .3349 .60417 L .33466 .60108 L F
.036 .194 .699 r
.33156 .60435 m .33372 .6064 L .3349 .60417 L F
.178 0 .274 r
.21269 .56 m .21197 .56233 L .21447 .55906 L F
.679 .413 .513 r
.36934 .61077 m .37179 .61329 L .36925 .61336 L F
.385 .487 .841 r
.36777 .60712 m .36934 .61077 L .37118 .60884 L F
.91 .662 .55 r
.3724 .61125 m .37179 .61329 L .36934 .61077 L F
.578 .52 .754 r
.36925 .61336 m .37118 .60884 L .36934 .61077 L F
.1 .382 .842 r
.278 .63883 m .28018 .64228 L .28118 .64086 L F
0 .05 .601 r
.28118 .64086 m .28018 .64228 L .28196 .64437 L F
.854 .408 .142 r
.28018 .64228 m .28303 .64584 L .28196 .64437 L F
.466 .198 .423 r
.33757 .57531 m .34045 .57243 L .33793 .5734 L F
.455 .44 .753 r
.44008 .51349 m .43895 .51795 L .43799 .51582 L F
.44008 .51349 m .44111 .51749 L .43895 .51795 L F
.702 .579 .714 r
.57798 .41304 m .58204 .41355 L .57875 .41536 L F
.803 .367 0 r
.5946 .39305 m .59673 .39583 L .59695 .39659 L F
.727 .661 .784 r
.61966 .38803 m .62305 .38815 L .62249 .3853 L F
.678 .497 .634 r
.61999 .39136 m .62305 .38815 L .61966 .38803 L F
.61999 .39136 m .62474 .3911 L .62305 .38815 L F
.582 .481 .704 r
.62305 .38815 m .62481 .38395 L .62249 .3853 L F
.62305 .38815 m .62693 .38842 L .62481 .38395 L F
.584 .462 .68 r
.62305 .38815 m .62474 .3911 L .62693 .38842 L F
.575 .191 .278 r
.44089 .58859 m .44324 .59042 L .43948 .5906 L F
.549 .206 .34 r
.44089 .58859 m .44364 .5885 L .44324 .59042 L F
.4 .183 .465 r
.31788 .57247 m .31539 .57568 L .31754 .57504 L F
.335 .162 .492 r
.31548 .57838 m .31754 .57504 L .31539 .57568 L F
.753 .704 .805 r
.63342 .36428 m .6348 .36612 L .63111 .36548 L F
.71 .702 .841 r
.63633 .36134 m .6348 .36612 L .63342 .36428 L F
.63633 .36134 m .63714 .36507 L .6348 .36612 L F
.685 .767 .913 r
.37443 .69832 m .37568 .69953 L .37186 .69928 L F
.37443 .69832 m .37568 .69953 L .37186 .69928 L F
.228 .562 .937 r
.37443 .69832 m .37568 .69953 L .37674 .69858 L F
.37674 .69858 m .37568 .69953 L .37443 .69832 L F
.754 .872 .449 r
.45088 .56628 m .45104 .56548 L .45206 .56376 L F
.908 .738 .659 r
.45088 .56628 m .44827 .56781 L .45104 .56548 L F
.45088 .56628 m .45027 .56962 L .44827 .56781 L F
.658 .754 .921 r
.39537 .50172 m .39116 .50083 L .39375 .49915 L F
.589 .647 .876 r
.39623 .49783 m .39537 .50172 L .39375 .49915 L F
.39623 .49783 m .39788 .5015 L .39537 .50172 L F
.629 .33 .444 r
.24288 .56909 m .24074 .57066 L .24105 .56889 L F
0 0 0 r
.44022 .55027 m .43967 .55003 L .44081 .55157 L F
.44022 .55027 m .43726 .55134 L .43967 .55003 L F
0 .055 .613 r
.40243 .65443 m .40182 .65556 L .4008 .65194 L F
0 .054 .593 r
.40243 .65443 m .4025 .65814 L .40182 .65556 L F
.389 .818 .963 r
.33344 .49641 m .3361 .49598 L .33784 .49646 L F
.111 .651 .848 r
.3361 .49598 m .34009 .4964 L .33784 .49646 L F
.077 .403 .858 r
.25969 .61811 m .25934 .61911 L .25664 .61783 L F
.25969 .61811 m .26088 .61974 L .25934 .61911 L F
.741 .969 .702 r
.62975 .3898 m .62714 .39342 L .6262 .39346 L F
.534 .856 .565 r
.24054 .56664 m .23906 .56795 L .24193 .56523 L F
.61 .164 .166 r
.38541 .50327 m .38684 .50318 L .38704 .50352 L F
.806 .956 .624 r
.38869 .50221 m .38739 .50409 L .38704 .50352 L F
.773 .951 .623 r
.38869 .50221 m .38704 .50352 L .38953 .50003 L F
.684 .939 .964 r
.39116 .50083 m .38869 .50221 L .38953 .50003 L F
.479 .294 .552 r
.38704 .50352 m .38956 .503 L .38953 .50003 L F
.61 .164 .166 r
.38684 .50318 m .38956 .503 L .38704 .50352 L F
.806 .956 .624 r
.38739 .50409 m .38631 .50564 L .38704 .50352 L F
.562 .57 .819 r
.28188 .60448 m .28427 .60389 L .28275 .60017 L F
.449 .708 .977 r
.34954 .51079 m .3515 .51231 L .34937 .5124 L F
.436 .867 .925 r
.35196 .51432 m .34937 .5124 L .3515 .51231 L F
.524 .561 .835 r
.3515 .51231 m .35196 .51432 L .34937 .5124 L F
.492 .571 .863 r
.57798 .41304 m .574 .4096 L .57792 .41026 L F
.644 .528 .707 r
.58063 .40958 m .57798 .41304 L .57792 .41026 L F
.697 .603 .747 r
.58063 .40958 m .58204 .41355 L .57798 .41304 L F
.65 .631 .817 r
.31748 .65138 m .31866 .64711 L .31778 .64965 L F
.761 .733 .827 r
.60501 .38695 m .60929 .3866 L .60743 .3883 L F
0 0 0 r
.43558 .55321 m .43344 .55466 L .43605 .55457 L F
.43558 .55321 m .43242 .55619 L .43344 .55466 L F
.667 .582 .75 r
.63037 .40724 m .63059 .40967 L .62756 .41016 L F
.699 .596 .737 r
.63059 .40967 m .62758 .41289 L .62756 .41016 L F
0 0 .495 r
.38983 .53012 m .39256 .53295 L .39117 .53151 L F
.689 .667 .824 r
.57684 .40716 m .57792 .41026 L .574 .4096 L F
.667 .645 .819 r
.57919 .40582 m .57792 .41026 L .57684 .40716 L F
.57919 .40582 m .58063 .40958 L .57792 .41026 L F
.374 .013 .217 r
.39951 .67509 m .39903 .67687 L .39666 .67742 L F
.58 .198 .281 r
.40169 .67629 m .39903 .67687 L .39951 .67509 L F
.805 .637 .673 r
.68045 .34922 m .6842 .34983 L .68266 .34586 L F
.791 .695 .759 r
.68045 .34922 m .68186 .35279 L .6842 .34983 L F
.363 .194 .514 r
.31137 .59124 m .31354 .58771 L .31137 .58852 L F
.878 .956 .851 r
.36795 .62011 m .36404 .6225 L .36647 .62196 L F
.655 .861 .475 r
.369 .61826 m .36795 .62011 L .36647 .62196 L F
.264 0 .118 r
.31957 .57122 m .32304 .56879 L .32063 .56939 L F
.24 0 .257 r
.28171 .56184 m .27883 .56494 L .27959 .56273 L F
0 0 .087 r
.33662 .59797 m .33466 .60108 L .3359 .6002 L F
0 0 .359 r
.33466 .60108 m .33544 .60233 L .3359 .6002 L F
.33466 .60108 m .3349 .60417 L .33544 .60233 L F
.424 .473 .807 r
.36453 .52733 m .36528 .52325 L .36338 .52406 L F
.182 .3 .75 r
.20463 .58528 m .2071 .58743 L .20568 .58352 L F
.42 .14 .379 r
.35699 .64771 m .35427 .6481 L .35379 .65152 L F
.384 .27 .599 r
.32734 .61423 m .32756 .61715 L .32907 .61563 L F
.32734 .61423 m .32907 .61563 L .32892 .61563 L F
.32734 .61423 m .32892 .61563 L .32828 .61284 L F
.36 .171 .484 r
.25074 .61391 m .25293 .61466 L .25309 .61336 L F
.583 .396 .594 r
.33822 .60426 m .33822 .6075 L .33545 .6076 L F
.431 .244 .526 r
.34066 .60099 m .34058 .60361 L .33822 .60426 L F
.486 .335 .6 r
.34058 .60361 m .33822 .6075 L .33822 .60426 L F
.422 .352 .673 r
.35728 .51441 m .35817 .51794 L .35522 .51862 L F
0 .018 .543 r
.35729 .51965 m .35522 .51862 L .35817 .51794 L F
.725 .97 .717 r
.24749 .53996 m .24496 .5416 L .24525 .54251 L F
.233 .724 .921 r
.24525 .54251 m .24496 .5416 L .24276 .54177 L F
0 0 .321 r
.24496 .5416 m .24657 .54528 L .24525 .54251 L F
0 0 .426 r
.24525 .54251 m .24657 .54528 L .24585 .5469 L F
.635 .492 .67 r
.70956 .28158 m .71108 .27845 L .70953 .27981 L F
.452 .126 .321 r
.58492 .45704 m .58134 .46028 L .58124 .45796 L F
.906 .974 .681 r
.25499 .63314 m .25293 .63473 L .25413 .63318 L F
0 0 0 r
.25413 .63318 m .25293 .63473 L .25385 .63369 L F
.986 .737 .352 r
.25499 .63314 m .25413 .63318 L .25466 .63221 L F
0 0 0 r
.25413 .63318 m .25385 .63369 L .25565 .63166 L F
.986 .737 .352 r
.25466 .63221 m .25413 .63318 L .25383 .62979 L F
.714 .95 .661 r
.25565 .63166 m .25293 .63473 L .25499 .63314 L F
.723 .617 .738 r
.58063 .40958 m .58471 .41037 L .58204 .41355 L F
.661 .165 .061 r
.71117 .3684 m .7097 .36871 L .70949 .36815 L F
0 0 0 r
.71353 .36778 m .7097 .36871 L .71117 .3684 L F
.691 .778 .918 r
.31322 .50847 m .31096 .51003 L .30828 .50728 L F
.436 .328 .633 r
.20345 .59518 m .20545 .59495 L .20495 .59205 L F
.678 .855 .967 r
.56784 .41257 m .56569 .41441 L .56458 .41394 L F
.978 .807 .396 r
.627 .4151 m .62758 .41289 L .62629 .41388 L F
.699 .596 .737 r
.63059 .40967 m .63149 .41334 L .62758 .41289 L F
.564 .753 .966 r
.63238 .41103 m .63149 .41334 L .63256 .41096 L F
.043 .145 .647 r
.63237 .41104 m .63149 .41334 L .63101 .41137 L F
.63236 .41103 m .63101 .41137 L .63059 .40967 L F
.63237 .41104 m .63101 .41137 L .63236 .41103 L F
.564 .753 .966 r
.62758 .41289 m .63149 .41334 L .63238 .41103 L F
0 0 0 r
.62629 .41388 m .62758 .41289 L .63238 .41103 L F
.043 .145 .647 r
.63257 .41094 m .63256 .41094 L .63316 .41001 L F
.63256 .41094 m .63059 .40967 L .6331 .41001 L F
.63256 .41094 m .6331 .41001 L .63316 .41001 L F
.63255 .41096 m .63059 .40967 L .63257 .41094 L F
0 0 0 r
.63253 .41097 m .63245 .411 L .63256 .41096 L F
.043 .145 .647 r
.63236 .41103 m .63059 .40967 L .63256 .41096 L F
.88 .98 .689 r
.63254 .41096 m .63227 .41018 L .62961 .41131 L F
.63256 .41096 m .63255 .41095 L .63254 .41096 L F
.63255 .41095 m .63227 .41018 L .63254 .41096 L F
.63256 .41096 m .63246 .41111 L .63255 .41095 L F
.043 .145 .647 r
.63246 .41111 m .63236 .41103 L .63256 .41096 L F
0 0 0 r
.63244 .41101 m .63245 .411 L .63253 .41097 L F
.88 .98 .689 r
.63255 .41095 m .63246 .41111 L .63227 .41018 L F
.043 .145 .647 r
.63256 .41096 m .63255 .41096 L .63257 .41094 L F
0 0 0 r
.63244 .41101 m .63238 .41103 L .63245 .411 L F
.62629 .41388 m .63238 .41103 L .63244 .41101 L F
.043 .145 .647 r
.63246 .41111 m .63149 .41334 L .63237 .41104 L F
.792 .565 .593 r
.28484 .61986 m .28799 .62263 L .28877 .62083 L F
.28484 .61986 m .28489 .62261 L .28799 .62263 L F
.702 .414 .484 r
.28489 .62261 m .28845 .62531 L .28799 .62263 L F
.687 .659 .817 r
.31498 .54374 m .31103 .54277 L .31345 .54191 L F
.116 .371 .832 r
.23881 .62109 m .23927 .61944 L .23728 .61991 L F
.23881 .62109 m .2413 .62259 L .23927 .61944 L F
.429 .174 .423 r
.44939 .58457 m .44646 .58737 L .44686 .58522 L F
.905 .749 .678 r
.38639 .66143 m .38423 .66155 L .38535 .6577 L F
.924 .893 .78 r
.38639 .66143 m .38288 .66389 L .38423 .66155 L F
.38639 .66143 m .38457 .66471 L .38288 .66389 L F
.534 .715 .955 r
.55329 .41975 m .55002 .41669 L .55261 .4155 L F
.55329 .41975 m .5492 .41844 L .55002 .41669 L F
.002 0 0 r
.55528 .41957 m .55607 .41931 L .55329 .41975 L F
.55528 .41957 m .55329 .41975 L .55415 .41747 L F
.52 .912 .789 r
.55829 .41788 m .55607 .41931 L .55528 .41957 L F
.002 0 0 r
.55528 .41957 m .55415 .41747 L .55329 .42117 L F
.302 0 .002 r
.55349 .42188 m .55528 .41957 L .55329 .42117 L F
.52 .912 .789 r
.55829 .41788 m .55528 .41957 L .55751 .42002 L F
.401 0 0 r
.55779 .42058 m .55528 .41957 L .55349 .42188 L F
.55779 .42058 m .55751 .42002 L .55528 .41957 L F
.74 .638 .746 r
.55449 .41752 m .55779 .42058 L .55349 .42188 L F
.957 .853 .435 r
.55329 .42117 m .55415 .41747 L .55307 .41952 L F
0 0 0 r
.55307 .41952 m .55347 .41877 L .55515 .41658 L F
.257 0 0 r
.55971 .41902 m .55829 .41788 L .55751 .42002 L F
.568 .584 .829 r
.55971 .41902 m .55502 .41675 L .55515 .41658 L F
0 0 0 r
.55493 .4169 m .55515 .41658 L .55528 .4164 L F
.74 .638 .746 r
.55449 .41752 m .55349 .42188 L .55307 .41952 L F
0 0 0 r
.55307 .41952 m .55515 .41658 L .55493 .4169 L F
.257 0 0 r
.55971 .41902 m .56091 .41738 L .55829 .41788 L F
.689 .532 .668 r
.56003 .41602 m .55971 .41902 L .55515 .41658 L F
0 0 0 r
.55542 .41618 m .55415 .41747 L .55559 .41592 L F
0 0 .015 r
.55415 .41747 m .55583 .41309 L .55574 .41576 L F
.689 .532 .668 r
.55532 .41633 m .55515 .41658 L .55475 .41637 L F
.56003 .41602 m .55515 .41658 L .55532 .41633 L F
0 0 0 r
.55347 .41877 m .55415 .41747 L .55528 .4164 L F
.74 .638 .746 r
.55475 .41637 m .55449 .41752 L .55307 .41952 L F
.689 .532 .668 r
.56003 .41602 m .55532 .41633 L .55574 .41576 L F
0 0 0 r
.55553 .41606 m .55542 .41618 L .55574 .41576 L F
.55542 .41618 m .55559 .41592 L .55574 .41576 L F
.689 .532 .668 r
.55532 .41633 m .55475 .41637 L .55574 .41576 L F
0 0 0 r
.55526 .41643 m .55521 .41647 L .55549 .4161 L F
.55521 .41647 m .55415 .41747 L .55548 .4161 L F
.55521 .41647 m .55548 .4161 L .55549 .4161 L F
.55528 .4164 m .55526 .41643 L .55553 .41606 L F
.55526 .41643 m .55549 .4161 L .55553 .41606 L F
0 0 .063 r
.55971 .41902 m .55751 .42002 L .55779 .42058 L F
.568 .584 .829 r
.55971 .41902 m .55779 .42058 L .55502 .41675 L F
.55515 .41658 m .55502 .41675 L .55475 .41637 L F
.74 .638 .746 r
.55475 .41637 m .55502 .41675 L .55449 .41752 L F
.55502 .41675 m .55779 .42058 L .55449 .41752 L F
0 .05 .572 r
.55415 .41747 m .55329 .41975 L .55309 .41855 L F
.55415 .41747 m .55309 .41855 L .55261 .4155 L F
.122 0 .169 r
.6697 .39835 m .66786 .39739 L .66951 .39546 L F
.6697 .39835 m .66724 .39886 L .66786 .39739 L F
.865 .871 .841 r
.22382 .56174 m .22666 .56386 L .22767 .55967 L F
.941 .625 .179 r
.39352 .5384 m .39461 .53782 L .39315 .53579 L F
.39352 .5384 m .39468 .54023 L .39461 .53782 L F
0 0 0 r
.39016 .6741 m .38757 .67811 L .38955 .67697 L F
1 .811 .495 r
.39016 .6741 m .38838 .67617 L .38829 .67275 L F
.39016 .6741 m .38955 .67697 L .38838 .67617 L F
.895 .743 .685 r
.44237 .55305 m .43911 .55344 L .44081 .55157 L F
.44237 .55305 m .44057 .55659 L .43911 .55344 L F
.571 .37 .57 r
.35443 .60457 m .35728 .60402 L .35739 .60117 L F
0 0 .363 r
.35739 .60117 m .35728 .60402 L .35864 .60058 L F
0 0 0 r
.37149 .66326 m .37224 .66358 L .37087 .66409 L F
.071 0 0 r
.25587 .54818 m .25481 .5491 L .25239 .54968 L F
0 0 0 r
.25654 .54772 m .25587 .54818 L .25916 .54894 L F
.25654 .54772 m .25481 .5491 L .25587 .54818 L F
.304 0 .164 r
.29207 .5548 m .29081 .55366 L .29302 .55288 L F
.29207 .5548 m .28971 .55555 L .29081 .55366 L F
.199 0 0 r
.34509 .49767 m .34661 .49809 L .34879 .49866 L F
.272 0 0 r
.34661 .49809 m .35041 .49922 L .34879 .49866 L F
.45 0 0 r
.27965 .55292 m .28163 .55307 L .28363 .55225 L F
.319 0 0 r
.28363 .55225 m .28516 .55258 L .28633 .55006 L F
.28363 .55225 m .28163 .55307 L .28516 .55258 L F
.424 .222 .499 r
.22843 .57503 m .22801 .5785 L .22607 .57902 L F
.427 .228 .506 r
.23091 .57435 m .22801 .5785 L .22843 .57503 L F
.327 .155 .489 r
.31754 .57504 m .31957 .57122 L .31788 .57247 L F
0 .483 .835 r
.58699 .40117 m .58529 .40116 L .58439 .39928 L F
.749 .91 .532 r
.63256 .41096 m .63149 .41334 L .63246 .41111 L F
.951 .673 .475 r
.33298 .60898 m .3343 .61031 L .33545 .6076 L F
.428 0 0 r
.33545 .6076 m .33828 .60812 L .33298 .60898 L F
.529 .196 .348 r
.33822 .6075 m .33828 .60812 L .33545 .6076 L F
.352 .147 .457 r
.69395 .32048 m .69366 .32356 L .69161 .3241 L F
0 0 0 r
.31548 .50445 m .3141 .50626 L .31322 .50847 L F
.68 .667 .831 r
.30152 .51316 m .3057 .51531 L .30271 .51491 L F
.832 .976 .884 r
.3057 .51531 m .30832 .51291 L .30575 .51314 L F
.735 .919 .955 r
.30271 .51491 m .3057 .51531 L .30575 .51314 L F
.305 .167 .523 r
.30545 .54698 m .30551 .54965 L .3075 .54871 L F
.884 .814 .774 r
.59063 .3807 m .59093 .38333 L .5882 .38492 L F
0 0 .29 r
.59093 .38333 m .59183 .38565 L .5882 .38492 L F
.89 .99 .768 r
.42936 .54251 m .42716 .54616 L .4315 .54498 L F
0 .323 .81 r
.4315 .54498 m .43111 .54406 L .42936 .54251 L F
.76 .355 .285 r
.34301 .53999 m .347 .54332 L .34724 .54089 L F
.901 .725 .22 r
.34724 .54089 m .3461 .54034 L .34571 .53836 L F
.34724 .54089 m .347 .54332 L .3461 .54034 L F
.607 .941 .753 r
.33999 .65843 m .33621 .66099 L .33976 .6614 L F
0 0 0 r
.34228 .65713 m .33999 .65843 L .34144 .65784 L F
0 0 .268 r
.34144 .65784 m .33999 .65843 L .33976 .6614 L F
.875 .439 .146 r
.36071 .51298 m .35953 .51373 L .36055 .51143 L F
.36071 .51298 m .36298 .51642 L .35953 .51373 L F
.572 .923 .732 r
.62769 .39947 m .63124 .39725 L .63069 .39665 L F
.822 .783 .816 r
.63124 .39725 m .63212 .39283 L .63118 .39447 L F
.63124 .39725 m .63397 .39426 L .63212 .39283 L F
.952 .891 .498 r
.63069 .39665 m .63124 .39725 L .63118 .39447 L F
.685 .722 .878 r
.6119 .42258 m .61059 .42395 L .60947 .42196 L F
.53 .597 .866 r
.60947 .42196 m .6113 .4254 L .61309 .42475 L F
.165 .158 .604 r
.6113 .4254 m .61342 .42801 L .61309 .42475 L F
.41 .173 .441 r
.57373 .40388 m .57526 .40509 L .5731 .40615 L F
.88 .966 .641 r
.57594 .39965 m .57373 .40388 L .57397 .40141 L F
0 .255 .765 r
.57594 .39965 m .57931 .40319 L .57373 .40388 L F
.741 .533 .613 r
.57931 .40319 m .57526 .40509 L .57373 .40388 L F
.81 .703 .747 r
.67816 .35257 m .68186 .35279 L .68045 .34922 L F
.723 .489 .572 r
.67751 .35518 m .68186 .35279 L .67816 .35257 L F
.67751 .35518 m .68195 .35529 L .68186 .35279 L F
.72 .207 0 r
.5917 .39023 m .59318 .39117 L .5946 .39305 L F
.889 .988 .736 r
.63964 .43554 m .63902 .43499 L .6401 .43279 L F
.82 .627 .642 r
.63269 .40369 m .62883 .40543 L .62852 .40488 L F
.63269 .40369 m .63234 .40612 L .62883 .40543 L F
.368 .14 .431 r
.63269 .40369 m .63526 .40045 L .63494 .40221 L F
.389 .158 .438 r
.63494 .40221 m .63526 .40045 L .63766 .3995 L F
.63494 .40221 m .63766 .3995 L .63554 .4017 L F
0 0 .102 r
.63419 .40567 m .63494 .40221 L .63554 .4017 L F
0 0 0 r
.63993 .39764 m .63766 .3995 L .63742 .40012 L F
.739 .647 .758 r
.63742 .40012 m .64185 .40273 L .63579 .40174 L F
.63993 .39764 m .64019 .39834 L .63742 .40012 L F
.64019 .39834 m .64185 .40273 L .63742 .40012 L F
.124 0 0 r
.63742 .40012 m .636 .40152 L .63707 .40106 L F
.63766 .3995 m .63684 .40049 L .63742 .40012 L F
.63766 .3995 m .63526 .40045 L .63569 .40122 L F
.739 .647 .758 r
.63684 .4005 m .63579 .40174 L .63554 .4017 L F
.63684 .40049 m .63554 .4017 L .63766 .3995 L F
.124 0 0 r
.63676 .40055 m .63569 .40122 L .63589 .40157 L F
.63766 .3995 m .63569 .40122 L .63676 .40055 L F
.739 .647 .758 r
.63993 .39764 m .63742 .40012 L .63684 .40049 L F
.63742 .40012 m .63579 .40174 L .63684 .40049 L F
.124 0 0 r
.63684 .40049 m .63589 .40157 L .636 .40152 L F
.63766 .3995 m .63676 .40055 L .63684 .40049 L F
.63676 .40055 m .63589 .40157 L .63684 .40049 L F
.63684 .40049 m .636 .40152 L .63742 .40012 L F
0 0 0 r
.63993 .39764 m .63742 .40012 L .63707 .40106 L F
.739 .647 .758 r
.63993 .39764 m .63684 .40049 L .63766 .3995 L F
.846 .613 .586 r
.64185 .40273 m .63751 .40541 L .63564 .40189 L F
.636 .40177 m .63564 .40189 L .63554 .4017 L F
.64185 .40273 m .63564 .40189 L .636 .40177 L F
0 0 .102 r
.63419 .40567 m .63554 .4017 L .63751 .40541 L F
0 0 .049 r
.63589 .40157 m .63526 .40045 L .63269 .40369 L F
.523 .919 .87 r
.63398 .40243 m .63269 .40369 L .62852 .40488 L F
.63589 .40157 m .63517 .40204 L .63398 .40243 L F
.63517 .40204 m .63269 .40369 L .63398 .40243 L F
.16 .036 .451 r
.63419 .40567 m .63269 .40369 L .63494 .40221 L F
.63419 .40567 m .63234 .40612 L .63269 .40369 L F
.448 .276 .555 r
.22389 .56902 m .22383 .57173 L .22164 .57202 L F
.22389 .56902 m .22383 .57173 L .22164 .57202 L F
.717 .722 .854 r
.41894 .50578 m .4157 .50828 L .41469 .5046 L F
.233 0 .227 r
.31772 .60156 m .31698 .60349 L .31504 .60411 L F
.398 .212 .508 r
.31707 .60632 m .31504 .60411 L .31698 .60349 L F
.31707 .60632 m .31482 .60712 L .31504 .60411 L F
.586 .209 .294 r
.31501 .54717 m .31408 .54892 L .3124 .54703 L F
.217 .17 .588 r
.31408 .54892 m .31278 .54992 L .3124 .54703 L F
.383 .789 .982 r
.38711 .56935 m .38435 .56829 L .38315 .56902 L F
.541 .867 .588 r
.64276 .44027 m .64111 .44197 L .64443 .43896 L F
.654 .913 .605 r
.64584 .43716 m .64276 .44027 L .64443 .43896 L F
.716 .462 .541 r
.61007 .45146 m .60997 .45402 L .60595 .45417 L F
.241 .08 .452 r
.61178 .45243 m .61007 .45146 L .6115 .45042 L F
.61178 .45243 m .60997 .45402 L .61007 .45146 L F
.436 .822 .589 r
.63761 .44453 m .64111 .44197 L .63968 .44297 L F
.55 .88 .616 r
.63968 .44297 m .64111 .44197 L .64276 .44027 L F
.738 .632 .741 r
.33828 .51419 m .334 .51158 L .3362 .51083 L F
.33828 .51419 m .33604 .51535 L .334 .51158 L F
.803 .715 .767 r
.33905 .51256 m .33828 .51419 L .3362 .51083 L F
.831 .824 .346 r
.69794 .33956 m .69692 .34323 L .69714 .34105 L F
.73 .812 .343 r
.69809 .33885 m .69794 .33956 L .69714 .34105 L F
.558 .082 .081 r
.357 .55345 m .35538 .55495 L .35281 .55379 L F
.772 .689 .772 r
.68658 .33307 m .69045 .33377 L .68901 .32992 L F
.723 .75 .874 r
.69045 .33377 m .69152 .32922 L .68901 .32992 L F
.69045 .33377 m .69302 .33218 L .69152 .32922 L F
.381 .815 .96 r
.28179 .51883 m .27961 .51935 L .27741 .51863 L F
.559 .677 .918 r
.29391 .61022 m .29376 .61385 L .29204 .61159 L F
.29391 .61022 m .29614 .6133 L .29376 .61385 L F
.399 .299 .624 r
.43874 .50852 m .4372 .51176 L .43656 .51001 L F
.673 .693 .861 r
.63347 .38318 m .63427 .38632 L .6377 .3838 L F
.72 .355 0 r
.40358 .57274 m .40368 .57241 L .40295 .57146 L F
.40358 .57274 m .40485 .57522 L .40368 .57241 L F
.948 .668 .473 r
.35103 .69312 m .35141 .69653 L .34915 .69528 L F
.598 .37 .541 r
.46411 .5726 m .46379 .57493 L .46128 .57508 L F
.745 .626 .727 r
.46552 .57 m .46411 .5726 L .46277 .56883 L F
.424 .129 .358 r
.46685 .57214 m .46379 .57493 L .46411 .5726 L F
.634 .488 .666 r
.46685 .57214 m .46411 .5726 L .46552 .57 L F
.612 .69 .899 r
.46545 .56798 m .46552 .57 L .46277 .56883 L F
.484 .584 .879 r
.46786 .56746 m .46552 .57 L .46545 .56798 L F
.417 .479 .816 r
.46786 .56746 m .46918 .57148 L .46552 .57 L F
.497 .436 .719 r
.46552 .57 m .46918 .57148 L .46685 .57214 L F
.756 .55 .617 r
.34318 .54977 m .3388 .54679 L .34146 .54607 L F
.34318 .54977 m .33887 .54986 L .3388 .54679 L F
.714 .191 0 r
.59642 .41104 m .59747 .41014 L .59392 .4086 L F
.753 .244 0 r
.59964 .41275 m .59747 .41014 L .59642 .41104 L F
.715 .207 0 r
.60042 .41337 m .59747 .41014 L .59964 .41275 L F
.664 .326 .391 r
.68207 .35756 m .68531 .35518 L .68195 .35529 L F
.68207 .35756 m .68466 .35798 L .68531 .35518 L F
.524 .044 .058 r
.6875 .35718 m .68531 .35518 L .68466 .35798 L F
.6875 .35718 m .68822 .35553 L .68531 .35518 L F
.077 0 0 r
.34318 .54977 m .33892 .55252 L .33887 .54986 L F
.34318 .54977 m .34116 .5518 L .33892 .55252 L F
.727 .639 .761 r
.34442 .5464 m .34318 .54977 L .34146 .54607 L F
.265 .211 .608 r
.34318 .54977 m .34318 .55322 L .34487 .5516 L F
.661 .227 .206 r
.34487 .5516 m .34116 .5518 L .34318 .54977 L F
0 .268 .775 r
.25513 .6146 m .2548 .6157 L .25309 .61336 L F
.525 .04 .047 r
.25309 .61336 m .25513 .6146 L .25544 .61281 L F
.881 .528 .375 r
.25293 .61466 m .2511 .61503 L .25309 .61336 L F
.78 .817 .881 r
.25293 .61466 m .25065 .6171 L .24859 .61575 L F
.525 .04 .047 r
.25309 .61336 m .2511 .61503 L .25513 .6146 L F
0 .268 .775 r
.25513 .6146 m .25309 .61336 L .25544 .61281 L F
.641 .966 .877 r
.25513 .6146 m .25361 .61482 L .25536 .61385 L F
.25513 .6146 m .2576 .61495 L .25544 .61281 L F
.56 .272 .435 r
.25544 .61281 m .2576 .61495 L .25513 .6146 L F
.641 .966 .877 r
.25513 .6146 m .25536 .61385 L .25548 .61379 L F
0 .268 .775 r
.25513 .6146 m .25544 .61657 L .2548 .6157 L F
0 .036 .606 r
.25513 .6146 m .25664 .61783 L .25544 .61657 L F
.725 .799 .91 r
.40912 .49142 m .40535 .4912 L .40802 .48902 L F
.763 .809 .89 r
.41199 .48917 m .40912 .49142 L .40802 .48902 L F
.329 .588 .938 r
.70636 .3444 m .70354 .34269 L .70453 .34412 L F
.72 .902 .96 r
.70801 .34187 m .70636 .3444 L .70453 .34412 L F
.70801 .34187 m .70897 .34312 L .70636 .3444 L F
.91 .662 .55 r
.3724 .61125 m .37333 .61381 L .37179 .61329 L F
.526 .229 .406 r
.3748 .61033 m .37175 .61269 L .3724 .61125 L F
.909 .736 .654 r
.37802 .57552 m .37968 .57866 L .37542 .57865 L F
.502 .316 .56 r
.37758 .57914 m .37542 .57865 L .37968 .57866 L F
.909 .736 .654 r
.37802 .57552 m .37758 .57914 L .37968 .57866 L F
.908 .861 .782 r
.37968 .57866 m .37758 .57914 L .38094 .57394 L F
.728 .226 0 r
.37968 .57866 m .38019 .58016 L .37758 .57914 L F
.37968 .57866 m .38197 .58152 L .38019 .58016 L F
.686 .423 .519 r
.37968 .57866 m .38257 .5789 L .38197 .58152 L F
.891 .546 .387 r
.55581 .45154 m .55824 .45455 L .55603 .45363 L F
.855 .573 .509 r
.55603 .45363 m .55824 .45455 L .55761 .45667 L F
.566 .267 .421 r
.55824 .45455 m .56042 .45666 L .55761 .45667 L F
.545 .858 .559 r
.23603 .53388 m .23719 .53259 L .23909 .53091 L F
.691 .966 .934 r
.23909 .53091 m .23961 .52923 L .24115 .52954 L F
.776 .953 .628 r
.23909 .53091 m .23719 .53259 L .23961 .52923 L F
.736 .669 .784 r
.37508 .54735 m .37278 .55004 L .37534 .54976 L F
.565 .14 .195 r
.37278 .55004 m .37443 .55195 L .37534 .54976 L F
.498 .445 .728 r
.37534 .54976 m .37756 .54676 L .37508 .54735 L F
.37534 .54976 m .37768 .5494 L .37756 .54676 L F
.785 .563 .599 r
.37443 .55195 m .37768 .5494 L .37534 .54976 L F
.845 .777 .785 r
.63212 .39283 m .63397 .39426 L .6357 .39036 L F
.733 .874 .947 r
.33976 .6614 m .34393 .66155 L .34174 .66258 L F
0 0 0 r
.34393 .66155 m .34625 .65933 L .3456 .66001 L F
.63 .954 .779 r
.34174 .66258 m .34393 .66155 L .3456 .66001 L F
.975 .772 .567 r
.39773 .61246 m .39978 .6107 L .39783 .60977 L F
.39773 .61246 m .39937 .61356 L .39978 .6107 L F
.985 .721 .346 r
.69384 .31975 m .69394 .31995 L .69477 .31841 L F
.87 .94 .862 r
.69395 .32048 m .69522 .31757 L .69477 .31841 L F
.69395 .32048 m .69671 .31757 L .69581 .31624 L F
0 0 .141 r
.6947 .32141 m .69395 .32048 L .69477 .31841 L F
.985 .721 .346 r
.69394 .31995 m .6947 .32141 L .69477 .31841 L F
.87 .94 .862 r
.69522 .31757 m .69581 .31624 L .69477 .31841 L F
0 0 .141 r
.6947 .32141 m .69366 .32356 L .69395 .32048 L F
.993 .861 .597 r
.53693 .43176 m .53706 .43047 L .53876 .43196 L F
.895 .971 .661 r
.71255 .30963 m .71406 .30849 L .71305 .30797 L F
.774 .691 .771 r
.5731 .40615 m .574 .4096 L .57166 .40656 L F
.762 .688 .781 r
.57166 .40656 m .574 .4096 L .57185 .41106 L F
.667 .626 .799 r
.57684 .40716 m .574 .4096 L .5731 .40615 L F
.319 .111 .432 r
.35773 .58457 m .35646 .58826 L .35437 .5886 L F
.364 .231 .563 r
.35622 .59037 m .35437 .5886 L .35646 .58826 L F
.35622 .59037 m .35455 .59112 L .35437 .5886 L F
.606 .802 .975 r
.69302 .33218 m .69744 .33252 L .69627 .33049 L F
.235 .488 .893 r
.69744 .33252 m .69826 .32913 L .69627 .33049 L F
.69744 .33252 m .69892 .33139 L .69826 .32913 L F
.69744 .33252 m .69926 .33358 L .69892 .33139 L F
.983 .886 .651 r
.44323 .56694 m .4432 .56416 L .44599 .56599 L F
.239 .032 .384 r
.44822 .56266 m .44776 .56604 L .44599 .56599 L F
.23 .322 .752 r
.44776 .56604 m .44827 .56781 L .44599 .56599 L F
.156 .696 .812 r
.29398 .64587 m .29667 .64566 L .29499 .64556 L F
.823 .839 .371 r
.39432 .68411 m .39361 .68576 L .39483 .68312 L F
.6 .577 .799 r
.43655 .49574 m .43401 .49659 L .43311 .49325 L F
.97 .932 .66 r
.40584 .59484 m .40383 .59625 L .40463 .59724 L F
.533 .033 .014 r
.40475 .59568 m .40383 .59625 L .40584 .59484 L F
.994 .869 .59 r
.40567 .59033 m .40475 .59568 L .40584 .59484 L F
.76 .355 .285 r
.34301 .53999 m .3423 .54259 L .347 .54332 L F
.793 .68 .74 r
.67885 .34524 m .68266 .34586 L .68309 .3434 L F
.803 .633 .671 r
.68045 .34922 m .68266 .34586 L .67885 .34524 L F
.752 .966 .681 r
.38757 .67811 m .38838 .67617 L .38955 .67697 L F
.38757 .67811 m .38561 .67948 L .38838 .67617 L F
.616 .568 .777 r
.33948 .53692 m .33688 .53749 L .33562 .53393 L F
.372 .244 .575 r
.33882 .53924 m .33688 .53749 L .33948 .53692 L F
.33882 .53924 m .33689 .54026 L .33688 .53749 L F
.849 .676 .668 r
.61039 .38098 m .60772 .38371 L .60803 .3821 L F
.57 .394 .604 r
.37808 .68353 m .37554 .6868 L .37545 .68394 L F
.939 .955 .754 r
.37621 .64114 m .37689 .64305 L .37904 .63938 L F
.664 .924 .624 r
.37988 .63792 m .37904 .63938 L .38164 .63648 L F
.667 .958 .739 r
.37621 .64114 m .37904 .63938 L .37988 .63792 L F
.362 .176 .489 r
.30691 .59784 m .30681 .60045 L .30897 .59718 L F
.842 .742 .753 r
.42508 .48638 m .42125 .48611 L .42355 .48515 L F
.42508 .48638 m .42261 .48972 L .42125 .48611 L F
.622 .772 .953 r
.42814 .48611 m .42508 .48638 L .42355 .48515 L F
.284 .137 .498 r
.6746 .38607 m .67205 .38976 L .67245 .38843 L F
.6746 .38607 m .67446 .38922 L .67205 .38976 L F
.64 .41 .553 r
.67446 .38922 m .67184 .39208 L .67205 .38976 L F
0 .252 .764 r
.2704 .63226 m .27284 .63595 L .27361 .63598 L F
0 0 0 r
.39248 .58879 m .39178 .59115 L .39268 .58814 L F
.452 .126 .321 r
.58492 .45704 m .58408 .45973 L .58134 .46028 L F
.52 .292 .51 r
.58762 .45451 m .58773 .45673 L .58492 .45704 L F
.395 .074 .298 r
.58657 .45899 m .58492 .45704 L .58773 .45673 L F
.58657 .45899 m .58408 .45973 L .58492 .45704 L F
.604 .383 .553 r
.59033 .45415 m .58773 .45673 L .58762 .45451 L F
.478 .435 .732 r
.44008 .51349 m .43799 .51582 L .4372 .51176 L F
.578 .21 .307 r
.30708 .55754 m .30456 .55588 L .3072 .55618 L F
.30708 .55754 m .30299 .55855 L .30456 .55588 L F
.725 .613 .733 r
.58303 .40652 m .58471 .41037 L .58063 .40958 L F
.566 .914 .705 r
.23603 .53388 m .2354 .53408 L .23719 .53259 L F
.565 .341 .535 r
.43001 .57461 m .42718 .57256 L .42988 .57155 L F
.43001 .57461 m .42689 .57528 L .42718 .57256 L F
.372 .301 .647 r
.70411 .32639 m .70496 .32887 L .70231 .32671 L F
.283 .756 .937 r
.70231 .32671 m .7016 .32615 L .70411 .32639 L F
.398 .176 .457 r
.63766 .3995 m .63782 .39721 L .63526 .40045 L F
.63766 .3995 m .63782 .39721 L .63526 .40045 L F
.668 .958 .944 r
.55057 .41488 m .55261 .4155 L .55002 .41669 L F
0 0 .093 r
.55002 .41669 m .55104 .41694 L .55057 .41488 L F
.55002 .41669 m .5492 .41844 L .55104 .41694 L F
.75 .58 .665 r
.35196 .51432 m .34753 .51607 L .34816 .51513 L F
.35196 .51432 m .35259 .51837 L .34753 .51607 L F
.317 .025 .301 r
.26184 .56238 m .26462 .56145 L .26499 .55923 L F
.167 0 .218 r
.26462 .56145 m .26638 .55926 L .26499 .55923 L F
.847 .815 .819 r
.37333 .61381 m .37143 .61584 L .37179 .61329 L F
.639 .907 .599 r
.37179 .61329 m .36915 .61604 L .36925 .61336 L F
.878 .909 .846 r
.36915 .61604 m .37333 .61381 L .37175 .61269 L F
.36915 .61604 m .37143 .61584 L .37333 .61381 L F
.753 .622 .714 r
.61243 .38201 m .61134 .38473 L .61039 .38098 L F
.742 .591 .688 r
.35888 .59737 m .3616 .59473 L .35934 .59511 L F
.381 .091 .342 r
.31987 .60077 m .31698 .60349 L .31772 .60156 L F
.83 .904 .891 r
.66922 .32992 m .66509 .33133 L .66803 .32853 L F
.855 .906 .869 r
.67205 .32687 m .66922 .32992 L .66803 .32853 L F
.82 .792 .826 r
.35147 .64163 m .35524 .63866 L .35126 .63865 L F
.833 .884 .879 r
.35789 .63587 m .35524 .63866 L .35602 .63703 L F
.843 .877 .866 r
.57185 .41106 m .56784 .41257 L .57028 .40948 L F
.762 .688 .781 r
.57166 .40656 m .57185 .41106 L .57028 .40948 L F
.183 0 0 r
.61177 .38683 m .61537 .38522 L .61418 .38512 L F
.514 .912 .904 r
.61537 .38522 m .61809 .38409 L .61698 .38394 L F
.172 .136 .573 r
.34453 .69744 m .34357 .69602 L .34438 .69625 L F
.587 .551 .781 r
.64964 .39043 m .65162 .38775 L .64818 .38661 L F
.64964 .39043 m .65252 .38975 L .65162 .38775 L F
.163 .28 .738 r
.64964 .39043 m .65255 .39283 L .65252 .38975 L F
0 .339 .82 r
.38059 .51739 m .38308 .52047 L .3803 .518 L F
.632 .135 .051 r
.33161 .5443 m .3306 .54551 L .32799 .54355 L F
0 0 0 r
.33293 .54321 m .33161 .5443 L .33438 .54385 L F
.33293 .54321 m .3306 .54551 L .33161 .5443 L F
.763 .66 .748 r
.43542 .58154 m .43962 .58232 L .43841 .57841 L F
.45 .778 .998 r
.43806 .58115 m .43813 .58204 L .43542 .58154 L F
.134 0 0 r
.43593 .58245 m .43806 .58115 L .43542 .58154 L F
.864 .99 .731 r
.43794 .57955 m .43806 .58115 L .43593 .58245 L F
.986 .736 .466 r
.43841 .57841 m .43962 .58232 L .43806 .58115 L F
0 0 0 r
.43841 .57841 m .43806 .58115 L .43839 .57889 L F
.864 .99 .731 r
.43839 .57889 m .43806 .58115 L .43794 .57955 L F
.45 .778 .998 r
.43806 .58115 m .43962 .58232 L .43813 .58204 L F
.9 .67 .581 r
.334 .51158 m .33604 .51535 L .33313 .51381 L F
.855 .712 .703 r
.33546 .51801 m .33313 .51381 L .33604 .51535 L F
.806 .627 .66 r
.58321 .40378 m .57919 .40582 L .57931 .40319 L F
.58321 .40378 m .58303 .40652 L .57919 .40582 L F
.597 .796 .976 r
.63204 .43242 m .63594 .43288 L .63458 .43128 L F
.712 .842 .944 r
.63594 .43288 m .63899 .4314 L .63458 .43128 L F
.797 .754 .814 r
.35563 .65839 m .35783 .65429 L .35556 .65541 L F
.961 .814 .652 r
.54199 .43826 m .54227 .44209 L .54023 .44097 L F
.867 .681 .649 r
.54227 .44209 m .54198 .44474 L .54023 .44097 L F
0 0 .131 r
.40039 .5545 m .39973 .55321 L .40017 .55168 L F
.40039 .5545 m .39938 .55622 L .39973 .55321 L F
.912 .783 .3 r
.40471 .58034 m .40542 .57877 L .40401 .57766 L F
.40471 .58034 m .40502 .58152 L .40542 .57877 L F
.86 .582 .516 r
.55581 .45154 m .55242 .45299 L .55238 .45045 L F
.55581 .45154 m .55603 .45363 L .55242 .45299 L F
.869 .462 .257 r
.38795 .51165 m .38584 .51121 L .38464 .50833 L F
.892 .468 .104 r
.38795 .51165 m .38755 .51371 L .38584 .51121 L F
.759 .615 .7 r
.54307 .41704 m .54446 .41603 L .54194 .41525 L F
.272 .761 .913 r
.55473 .41511 m .55261 .4155 L .55057 .41488 L F
0 .05 .572 r
.55415 .41747 m .55261 .4155 L .55473 .41511 L F
.436 .822 .589 r
.63761 .44453 m .63968 .44297 L .63762 .4444 L F
.376 .065 .304 r
.34166 .5785 m .33866 .58115 L .33914 .57887 L F
.925 .768 .289 r
.29487 .65205 m .2949 .65115 L .29588 .65072 L F
.2949 .65115 m .295 .6479 L .29588 .65072 L F
.823 .368 .145 r
.29588 .65072 m .295 .6479 L .29231 .64742 L F
.29588 .65072 m .29231 .64742 L .292 .64842 L F
.684 .137 0 r
.29451 .65045 m .29588 .65072 L .292 .64842 L F
.042 .33 .812 r
.29696 .65025 m .29588 .65072 L .29451 .65045 L F
.29732 .65022 m .29588 .65072 L .29696 .65025 L F
.782 .872 .44 r
.22382 .56174 m .22263 .56482 L .22203 .56322 L F
.705 .622 .762 r
.61809 .38409 m .61966 .38803 L .62249 .3853 L F
0 0 .102 r
.21641 .55277 m .21512 .55656 L .21621 .5551 L F
0 0 .13 r
.21512 .55656 m .21557 .55745 L .21621 .5551 L F
.21512 .55656 m .21447 .55906 L .21557 .55745 L F
.529 .338 .565 r
.29883 .6102 m .30141 .60693 L .2989 .60742 L F
.95 .909 .532 r
.4059 .58779 m .40688 .58515 L .40543 .58682 L F
.93 .572 .148 r
.40569 .58405 m .40688 .58515 L .40502 .58152 L F
.998 .784 .467 r
.40543 .58682 m .40688 .58515 L .40569 .58405 L F
.889 .961 .836 r
.6207 .3951 m .62201 .39633 L .6236 .39396 L F
.833 .389 .173 r
.6203 .39794 m .62201 .39633 L .6207 .3951 L F
.6203 .39794 m .62369 .39928 L .62201 .39633 L F
.208 0 0 r
.38088 .65178 m .38122 .65106 L .37904 .6519 L F
0 0 0 r
.38283 .65088 m .38122 .65106 L .38088 .65178 L F
.16 0 .161 r
.38283 .65088 m .38088 .65178 L .37995 .65378 L F
.663 .934 .656 r
.38067 .65227 m .38283 .65088 L .37995 .65378 L F
.354 .106 .392 r
.38088 .65178 m .37823 .65477 L .37995 .65378 L F
.38088 .65178 m .37904 .6519 L .37823 .65477 L F
.663 .934 .656 r
.38045 .65224 m .37995 .65378 L .3781 .65277 L F
.746 .567 .653 r
.38008 .65284 m .38067 .65227 L .38001 .65263 L F
.38067 .65227 m .38085 .65209 L .38059 .65226 L F
.663 .934 .656 r
.38067 .65227 m .37995 .65378 L .38045 .65224 L F
.746 .567 .653 r
.38067 .65227 m .38059 .65226 L .38001 .65263 L F
.391 .645 .958 r
.38045 .65224 m .3781 .65277 L .3798 .65194 L F
.746 .567 .653 r
.38001 .65263 m .38055 .65228 L .3798 .65194 L F
.38055 .65228 m .38124 .65184 L .3798 .65194 L F
.391 .645 .958 r
.38071 .65218 m .38045 .65224 L .3798 .65194 L F
.663 .934 .656 r
.38071 .65218 m .38067 .65227 L .38045 .65224 L F
.38071 .65218 m .38085 .65209 L .38067 .65227 L F
.38085 .65209 m .38283 .65088 L .38067 .65227 L F
.405 .815 .612 r
.38156 .65163 m .38085 .65209 L .38116 .65189 L F
.399 .645 .956 r
.37739 .65702 m .37995 .65378 L .37823 .65477 L F
.37739 .65702 m .38169 .65849 L .37995 .65378 L F
.843 .893 .874 r
.38169 .65849 m .38184 .65638 L .37995 .65378 L F
.759 .337 .248 r
.37995 .65378 m .38184 .65638 L .37958 .65599 L F
.37856 .65518 m .37958 .65599 L .37802 .65572 L F
.37995 .65378 m .37958 .65599 L .37856 .65518 L F
.891 .551 .061 r
.38184 .65638 m .38081 .65524 L .37802 .65572 L F
.38184 .65638 m .38246 .65898 L .38081 .65524 L F
.274 .431 .837 r
.38081 .65524 m .38199 .6579 L .38375 .6583 L F
.38199 .6579 m .38246 .65898 L .38299 .6587 L F
.38199 .6579 m .38299 .6587 L .38375 .6583 L F
.405 .815 .612 r
.38156 .65163 m .38283 .65088 L .38085 .65209 L F
0 0 0 r
.38283 .65088 m .38374 .65033 L .38122 .65106 L F
.405 .815 .612 r
.38468 .64965 m .38283 .65088 L .38156 .65163 L F
0 0 0 r
.38283 .65088 m .38474 .65003 L .38374 .65033 L F
.405 .815 .612 r
.38468 .64965 m .38116 .65189 L .38327 .6517 L F
.746 .567 .653 r
.38081 .65524 m .38123 .65188 L .38085 .65209 L F
.38123 .65188 m .38116 .65189 L .38085 .65209 L F
.38081 .65524 m .38327 .6517 L .38124 .65184 L F
.405 .815 .612 r
.38116 .65189 m .38085 .65209 L .38071 .65218 L F
.38116 .65189 m .38071 .65218 L .38327 .6517 L F
.746 .567 .653 r
.38123 .65188 m .38124 .65184 L .38116 .65189 L F
.38081 .65524 m .38085 .65209 L .38008 .65284 L F
.505 .405 .675 r
.36174 .5795 m .36201 .58141 L .35971 .58197 L F
.543 .378 .607 r
.36201 .58141 m .35966 .58436 L .35971 .58197 L F
.818 .827 .857 r
.64942 .34537 m .64992 .34868 L .6483 .34951 L F
.803 .818 .863 r
.65269 .3457 m .64992 .34868 L .64942 .34537 L F
.311 0 .177 r
.19508 .63354 m .1981 .63202 L .1972 .6332 L F
.19508 .63354 m .1981 .63202 L .1972 .6332 L F
.202 0 .066 r
.2878 .55651 m .2866 .55867 L .28448 .55911 L F
.262 0 .097 r
.28912 .55764 m .2878 .55651 L .28971 .55555 L F
.28912 .55764 m .2866 .55867 L .2878 .55651 L F
.252 .001 .326 r
.40396 .50114 m .40061 .50437 L .40273 .50294 L F
.307 .498 .882 r
.40061 .50437 m .39788 .5015 L .40273 .50294 L F
.026 .17 .678 r
.7064 .36224 m .70852 .36237 L .7083 .36006 L F
.7064 .36224 m .70777 .36436 L .70852 .36237 L F
.235 0 0 r
.35505 .71506 m .359 .71554 L .35746 .71553 L F
.286 .786 .847 r
.35746 .71553 m .359 .71554 L .36146 .71498 L F
.998 .783 .475 r
.6085 .36894 m .60732 .37019 L .60669 .36814 L F
.654 .653 .836 r
.60991 .36481 m .6085 .36894 L .60669 .36814 L F
.60991 .36481 m .61126 .36821 L .6085 .36894 L F
.637 .307 .397 r
.57661 .46009 m .57476 .46286 L .57226 .46069 L F
.646 .332 .425 r
.5786 .46046 m .57476 .46286 L .57661 .46009 L F
.401 .058 .264 r
.33855 .59937 m .33662 .59797 L .3359 .6002 L F
.33855 .59937 m .33922 .5975 L .33662 .59797 L F
.496 .294 .535 r
.33662 .59797 m .3394 .59464 L .33743 .5963 L F
.33662 .59797 m .33922 .5975 L .3394 .59464 L F
.434 .218 .485 r
.33809 .56391 m .34081 .5673 L .33863 .56625 L F
.791 .515 .52 r
.34081 .5673 m .33988 .56658 L .33863 .56625 L F
.392 .112 .364 r
.33863 .56625 m .33637 .56566 L .33809 .56391 L F
.791 .515 .52 r
.33988 .56658 m .33683 .56422 L .33863 .56625 L F
.392 .112 .364 r
.33863 .56625 m .33595 .56608 L .33637 .56566 L F
.434 .218 .485 r
.33809 .56391 m .34118 .56476 L .34081 .5673 L F
.198 0 .36 r
.32773 .52698 m .32549 .53101 L .32779 .52977 L F
0 0 0 r
.32773 .52698 m .32874 .52652 L .33076 .52429 L F
.652 .452 .6 r
.32779 .52977 m .32874 .52652 L .32773 .52698 L F
0 .164 .702 r
.32329 .64342 m .32507 .6471 L .32298 .64501 L F
.469 .283 .546 r
.32507 .6471 m .32277 .64795 L .32298 .64501 L F
.72 .687 .818 r
.32101 .64618 m .32507 .6471 L .32419 .64527 L F
.351 0 .175 r
.32184 .64541 m .32023 .64336 L .31913 .64455 L F
.32193 .6454 m .32023 .64336 L .32184 .64541 L F
.32193 .6454 m .32287 .64222 L .32023 .64336 L F
.72 .687 .818 r
.32101 .64618 m .32419 .64527 L .32164 .64542 L F
.351 0 .175 r
.32197 .64545 m .32199 .64537 L .32193 .6454 L F
.32199 .64537 m .32287 .64222 L .32193 .6454 L F
.72 .687 .818 r
.32164 .64542 m .32193 .6454 L .32329 .64342 L F
.32193 .6454 m .32419 .64527 L .32382 .64451 L F
.32193 .6454 m .32382 .64451 L .32329 .64342 L F
.351 0 .175 r
.32197 .64545 m .32193 .6454 L .32184 .64541 L F
.356 .005 .224 r
.67951 .37522 m .67931 .37695 L .67639 .37758 L F
.532 .146 .255 r
.67951 .37522 m .68205 .3766 L .67931 .37695 L F
.466 .232 .474 r
.68216 .37431 m .68205 .3766 L .67951 .37522 L F
.802 .745 .799 r
.24309 .53623 m .24715 .5373 L .24569 .53401 L F
.724 .228 .058 r
.24309 .53623 m .24531 .53798 L .24715 .5373 L F
0 0 .312 r
.24715 .5373 m .24798 .53892 L .24749 .53996 L F
.643 .248 0 r
.24743 .53794 m .24715 .5373 L .24531 .53798 L F
.24743 .53794 m .24798 .53892 L .24715 .5373 L F
.384 0 .111 r
.32344 .68569 m .32205 .68401 L .32075 .68622 L F
.32344 .68569 m .32472 .68387 L .32205 .68401 L F
.534 .866 .592 r
.35144 .67765 m .35406 .67533 L .35254 .6765 L F
.719 .578 .696 r
.35144 .67765 m .35477 .67855 L .35406 .67533 L F
.584 .89 .606 r
.35254 .6765 m .35406 .67533 L .35564 .6737 L F
.779 .284 .028 r
.34625 .65933 m .34228 .65713 L .34476 .65716 L F
.874 .839 .807 r
.34899 .65503 m .34625 .65933 L .34476 .65716 L F
0 0 0 r
.34625 .65933 m .34697 .65943 L .3456 .66001 L F
.34625 .65933 m .3494 .65863 L .34697 .65943 L F
.714 .392 .432 r
.36538 .67618 m .36772 .67219 L .36206 .67372 L F
.373 .359 .714 r
.40008 .4935 m .40148 .49739 L .40202 .49422 L F
.718 .923 .581 r
.24657 .54528 m .24441 .54837 L .24585 .5469 L F
.516 .865 .611 r
.64023 .42535 m .63699 .4279 L .63972 .42751 L F
.602 .547 .765 r
.64023 .42535 m .64353 .42524 L .64287 .42152 L F
.528 .177 .315 r
.64339 .42697 m .64023 .42535 L .63972 .42751 L F
.64339 .42697 m .64353 .42524 L .64023 .42535 L F
.863 .683 .658 r
.69926 .33358 m .70064 .33707 L .69872 .33602 L F
.348 .409 .783 r
.70277 .33462 m .70064 .33707 L .69926 .33358 L F
0 .259 .765 r
.70265 .33703 m .70064 .33707 L .70277 .33462 L F
.70265 .33703 m .70198 .33837 L .70064 .33707 L F
.752 .435 .448 r
.56564 .46077 m .56207 .46277 L .56228 .46009 L F
.56564 .46077 m .5658 .463 L .56207 .46277 L F
.742 .427 .449 r
.56564 .46077 m .56806 .46336 L .5658 .463 L F
.666 .438 .566 r
.56824 .46074 m .56806 .46336 L .56564 .46077 L F
.505 .868 .985 r
.27882 .52595 m .27647 .52669 L .27799 .52724 L F
.338 .16 .487 r
.22801 .5785 m .22588 .58153 L .22607 .57902 L F
.849 .676 .668 r
.61039 .38098 m .61134 .38473 L .60772 .38371 L F
.803 .761 .814 r
.60772 .38371 m .61134 .38473 L .60929 .3866 L F
.434 .205 .466 r
.63766 .3995 m .63782 .39721 L .64054 .3963 L F
.63766 .3995 m .63782 .39721 L .64054 .3963 L F
.758 .745 .841 r
.60772 .38371 m .60929 .3866 L .60501 .38695 L F
0 0 0 r
.34546 .59717 m .34667 .59519 L .34808 .59365 L F
.071 0 .284 r
.38197 .58152 m .38257 .5789 L .38428 .57781 L F
.754 .995 .841 r
.54812 .41804 m .54697 .42032 L .54579 .42087 L F
.54812 .41804 m .5492 .41844 L .54697 .42032 L F
.277 0 .091 r
.36034 .54075 m .36169 .53979 L .36149 .53877 L F
.36169 .53979 m .36387 .53825 L .36149 .53877 L F
0 0 .164 r
.3613 .53773 m .36149 .53877 L .36149 .53617 L F
.36097 .54037 m .36149 .53877 L .3613 .53773 L F
.772 .966 .669 r
.36097 .54037 m .35886 .54205 L .36149 .53877 L F
.737 .719 .835 r
.64017 .36131 m .63714 .36507 L .63633 .36134 L F
.702 .644 .789 r
.32504 .53352 m .32779 .52977 L .32549 .53101 L F
.715 .437 .504 r
.3474 .55627 m .34701 .55937 L .34324 .55891 L F
.409 .17 .438 r
.34935 .55832 m .34701 .55937 L .3474 .55627 L F
.741 .98 .915 r
.30575 .51314 m .30832 .51291 L .31035 .51121 L F
.367 .773 .983 r
.31665 .66682 m .31515 .66724 L .31698 .66614 L F
.39 .828 .95 r
.31698 .66614 m .31515 .66724 L .31405 .66662 L F
.878 .522 .03 r
.37147 .61818 m .37143 .61584 L .36915 .61604 L F
.37147 .61818 m .37238 .61926 L .37143 .61584 L F
.946 .959 .713 r
.38464 .50833 m .38501 .50494 L .38631 .50564 L F
.38464 .50833 m .38358 .5076 L .38501 .50494 L F
.839 .422 0 r
.38464 .50833 m .38443 .5096 L .38358 .5076 L F
.38464 .50833 m .38584 .51121 L .38443 .5096 L F
.458 .26 .523 r
.32229 .60003 m .3201 .59784 L .32218 .59724 L F
.32229 .60003 m .31987 .60077 L .3201 .59784 L F
.778 .922 .933 r
.72371 .35185 m .72632 .35156 L .72616 .34952 L F
.434 .851 .69 r
.72964 .34882 m .7321 .34729 L .73029 .34826 L F
.72964 .34882 m .73029 .34826 L .73079 .34799 L F
0 0 0 r
.73289 .34624 m .73537 .34512 L .7321 .34729 L F
.7321 .34729 m .73537 .34512 L .73428 .34612 L F
.645 .715 .899 r
.72999 .34557 m .73029 .34826 L .73428 .34612 L F
.077 .246 .735 r
.73079 .34799 m .73029 .34826 L .72999 .34557 L F
0 0 0 r
.72632 .35156 m .73079 .34799 L .72616 .34952 L F
.636 .625 .822 r
.34481 .51283 m .34816 .51513 L .34699 .51138 L F
.105 0 0 r
.34539 .51692 m .34706 .51706 L .34816 .51513 L F
0 0 .43 r
.34816 .51513 m .34841 .51462 L .34699 .51138 L F
0 0 0 r
.34816 .51513 m .3493 .51511 L .34841 .51462 L F
.34816 .51513 m .34706 .51706 L .3493 .51511 L F
.607 .884 .568 r
.39344 .69381 m .394 .69344 L .39515 .69194 L F
.661 .54 .706 r
.39279 .69572 m .39515 .69194 L .394 .69344 L F
.863 .88 .445 r
.39279 .69572 m .394 .69344 L .39344 .69381 L F
.175 0 .225 r
.28633 .55006 m .28785 .55128 L .28797 .54885 L F
.28633 .55006 m .28516 .55258 L .28785 .55128 L F
.877 .983 .699 r
.68655 .30606 m .68809 .30533 L .68671 .30716 L F
.875 .94 .857 r
.68923 .30349 m .68809 .30533 L .68831 .30231 L F
.943 .956 .659 r
.68831 .30231 m .68809 .30533 L .68655 .30606 L F
.321 0 .146 r
.3413 .52063 m .34383 .52007 L .34539 .51692 L F
.105 0 .041 r
.34539 .51692 m .34383 .52007 L .34706 .51706 L F
.883 .616 .529 r
.44323 .56694 m .44197 .5707 L .44118 .56934 L F
.983 .886 .651 r
.44323 .56694 m .44118 .56934 L .4432 .56416 L F
0 0 0 r
.3356 .58312 m .3334 .58466 L .33649 .58207 L F
.299 0 .207 r
.33866 .58115 m .3356 .58312 L .33649 .58207 L F
.76 .986 .754 r
.38656 .62074 m .38524 .62317 L .38355 .62224 L F
.38656 .62074 m .38802 .62025 L .38524 .62317 L F
.75 .964 .934 r
.38704 .50352 m .38631 .50564 L .38501 .50494 L F
.813 .736 .779 r
.60817 .42951 m .60668 .42696 L .60737 .42755 L F
0 .154 .695 r
.61024 .43148 m .60817 .42951 L .60737 .42755 L F
.306 .502 .885 r
.28506 .59994 m .28336 .60141 L .28275 .60017 L F
.28506 .59994 m .28645 .60131 L .28336 .60141 L F
.409 .399 .737 r
.28645 .60131 m .28427 .60389 L .28336 .60141 L F
.083 0 .443 r
.29652 .65429 m .29487 .65205 L .29588 .65072 L F
.29652 .65429 m .2949 .65466 L .29487 .65205 L F
.553 .491 .74 r
.6746 .38607 m .67245 .38843 L .67141 .38455 L F
.141 .018 .439 r
.32771 .57799 m .32618 .58157 L .3257 .57879 L F
.451 .157 .373 r
.34053 .68042 m .33744 .68321 L .33803 .68091 L F
.158 .366 .818 r
.40191 .55807 m .40111 .55988 L .39938 .55622 L F
.081 .268 .755 r
.40191 .55807 m .40335 .56169 L .40111 .55988 L F
0 .052 .597 r
.60686 .42265 m .60419 .41935 L .60598 .42318 L F
.991 .763 .494 r
.60512 .42432 m .60686 .42265 L .60598 .42318 L F
.60512 .42432 m .60668 .42696 L .60686 .42265 L F
.565 .239 .374 r
.31694 .5037 m .31568 .50227 L .31548 .50445 L F
.81 .616 .641 r
.36518 .60312 m .37156 .60409 L .37086 .60087 L F
.246 .244 .658 r
.37086 .60087 m .37156 .60409 L .37287 .60319 L F
.818 .671 .701 r
.68109 .34205 m .68309 .3434 L .68155 .33955 L F
.793 .68 .74 r
.67885 .34524 m .68309 .3434 L .68109 .34205 L F
0 0 0 r
.37508 .54735 m .37419 .54921 L .37278 .55004 L F
.113 .087 .547 r
.37419 .54921 m .37443 .55195 L .37278 .55004 L F
0 0 .519 r
.23112 .60092 m .23198 .60079 L .23149 .59931 L F
.89 .957 .838 r
.37455 .64321 m .37689 .64305 L .37621 .64114 L F
.668 .798 .944 r
.38552 .62667 m .38712 .6283 L .38755 .62576 L F
.38552 .62667 m .38755 .62576 L .38663 .62597 L F
.674 .603 .768 r
.38123 .62527 m .38247 .62913 L .38552 .62667 L F
.38123 .62527 m .38414 .62622 L .3841 .62516 L F
.38414 .62622 m .38552 .62667 L .38508 .6262 L F
.38414 .62622 m .38508 .6262 L .3841 .62516 L F
.454 0 .041 r
.38376 .62779 m .38598 .62618 L .38473 .62873 L F
.721 .671 .8 r
.38552 .62667 m .38762 .62535 L .3841 .62516 L F
.454 0 .041 r
.38598 .62618 m .38609 .6261 L .38605 .62618 L F
.38598 .62618 m .38605 .62618 L .38473 .62873 L F
.38609 .6261 m .38616 .62605 L .38614 .62609 L F
.38609 .6261 m .38614 .62609 L .38473 .62873 L F
.668 .798 .944 r
.38663 .62597 m .38755 .62576 L .38762 .62535 L F
.71 .771 .899 r
.38712 .6283 m .39142 .6258 L .38762 .62535 L F
.809 .346 0 r
.61257 .43428 m .6118 .43284 L .61024 .43148 L F
.531 .231 .404 r
.61539 .43414 m .6118 .43284 L .61257 .43428 L F
0 0 0 r
.32472 .56525 m .32952 .56072 L .32529 .56272 L F
.704 .832 .944 r
.61655 .36694 m .6179 .36821 L .61543 .36948 L F
.723 .341 .326 r
.35207 .67965 m .35477 .67855 L .35144 .67765 L F
.3523 .68038 m .35144 .67765 L .35037 .68054 L F
0 0 0 r
.35037 .68054 m .35144 .67765 L .35254 .6765 L F
.35037 .68054 m .35254 .6765 L .3523 .67843 L F
.34922 .67955 m .3523 .67843 L .34891 .67929 L F
.35037 .68054 m .35122 .67962 L .34922 .67955 L F
.35122 .67962 m .3523 .67843 L .34922 .67955 L F
.723 .341 .326 r
.3523 .68038 m .35324 .67969 L .35207 .67965 L F
.35324 .67969 m .35477 .67855 L .35207 .67965 L F
.58 .374 .567 r
.35559 .67988 m .35477 .67855 L .3523 .68038 L F
.35559 .67988 m .35702 .67742 L .35477 .67855 L F
.215 0 .259 r
.33484 .58631 m .3334 .58466 L .3356 .58312 L F
.33484 .58631 m .33224 .58746 L .3334 .58466 L F
0 0 0 r
.30154 .64149 m .3051 .639 L .30509 .64161 L F
.289 .451 .849 r
.30681 .63774 m .3051 .639 L .30368 .63598 L F
0 0 .333 r
.30509 .64161 m .3051 .639 L .30681 .63774 L F
.662 .766 .927 r
.36072 .53244 m .35763 .53456 L .35511 .53364 L F
0 .266 .77 r
.60226 .40207 m .60283 .40348 L .60542 .40531 L F
.014 .343 .823 r
.60283 .40348 m .60641 .40696 L .60542 .40531 L F
.129 .313 .781 r
.69628 .32375 m .69546 .32554 L .69366 .32356 L F
.859 .413 .132 r
.69575 .32481 m .69546 .32554 L .69628 .32375 L F
0 .142 .683 r
.69546 .32554 m .69531 .32593 L .69366 .32356 L F
.859 .413 .132 r
.69458 .32718 m .69546 .32554 L .69575 .32481 L F
0 .142 .683 r
.69546 .32554 m .69598 .32689 L .69531 .32593 L F
.854 .405 .01 r
.69546 .32554 m .69826 .32913 L .69598 .32689 L F
0 .031 .559 r
.70453 .34412 m .70354 .34269 L .70456 .34114 L F
.76 .537 .595 r
.32074 .64915 m .32109 .65177 L .31748 .65138 L F
0 0 .418 r
.32204 .65091 m .32074 .64915 L .32277 .64795 L F
.32144 .65046 m .32113 .65022 L .32074 .64915 L F
.32134 .65083 m .32086 .65005 L .32074 .64915 L F
.32141 .65148 m .32109 .65177 L .32152 .65019 L F
0 .047 .583 r
.31866 .64711 m .32149 .65049 L .32204 .65091 L F
.32149 .65049 m .32188 .65096 L .32204 .65091 L F
0 0 .418 r
.32152 .65019 m .32144 .65046 L .32074 .64915 L F
.32144 .65046 m .32134 .65083 L .32113 .65022 L F
.32134 .65083 m .32109 .65177 L .32086 .65005 L F
.53 .393 .639 r
.32109 .65177 m .31733 .65409 L .31748 .65138 L F
.473 .038 .132 r
.31924 .65276 m .32156 .65118 L .31748 .65138 L F
.32156 .65118 m .32188 .65096 L .32145 .651 L F
.32156 .65118 m .32145 .651 L .31748 .65138 L F
.65 .631 .817 r
.31748 .65138 m .32145 .651 L .31866 .64711 L F
.32145 .651 m .32188 .65096 L .32149 .65049 L F
.32145 .651 m .32149 .65049 L .31866 .64711 L F
0 0 .418 r
.32204 .65091 m .32141 .65148 L .32152 .65019 L F
.543 .622 .881 r
.40035 .54869 m .39834 .54726 L .39987 .54899 L F
0 .04 .603 r
.39984 .54798 m .39987 .54899 L .39834 .54726 L F
.981 .747 .338 r
.39956 .54919 m .39987 .54899 L .39984 .54798 L F
.39926 .55049 m .39987 .54899 L .39956 .54919 L F
.543 .622 .881 r
.40249 .55021 m .40035 .54869 L .39987 .54899 L F
0 .528 .716 r
.59481 .39982 m .59889 .40024 L .59698 .40003 L F
0 .276 .696 r
.59889 .40024 m .60226 .40207 L .60037 .40078 L F
.59889 .40024 m .60037 .40078 L .59698 .40003 L F
0 0 0 r
.34083 .59285 m .34177 .59151 L .3394 .59464 L F
.204 .058 .449 r
.3394 .59464 m .34075 .59665 L .34083 .59285 L F
.3394 .59464 m .33922 .5975 L .34075 .59665 L F
.595 .162 0 r
.40124 .52747 m .40284 .52987 L .40191 .52853 L F
.288 .333 .735 r
.33623 .70074 m .3373 .70566 L .33882 .70555 L F
.57 .307 .477 r
.25895 .56554 m .26152 .56557 L .26184 .56238 L F
.569 .306 .477 r
.26184 .56238 m .26488 .56458 L .26462 .56145 L F
.26184 .56238 m .26152 .56557 L .26488 .56458 L F
.076 0 0 r
.29479 .56426 m .2911 .56504 L .29309 .56603 L F
.714 .702 .168 r
.69692 .34323 m .69682 .34341 L .69714 .34105 L F
.558 .923 .759 r
.24785 .52686 m .24863 .52582 L .25044 .52581 L F
.24785 .52686 m .24674 .52723 L .24863 .52582 L F
.634 .588 .785 r
.24995 .5687 m .25136 .57247 L .25396 .57128 L F
.685 .512 .647 r
.34442 .5464 m .34686 .54684 L .34808 .54368 L F
.61 .798 .373 r
.3494 .5415 m .34792 .54393 L .34808 .54368 L F
0 0 0 r
.34792 .54437 m .34686 .54684 L .34808 .54368 L F
.34788 .54457 m .34743 .54556 L .34792 .54437 L F
.34743 .54556 m .34686 .54684 L .34792 .54437 L F
.765 .754 .843 r
.35293 .54356 m .34811 .54392 L .35293 .54162 L F
.34811 .54392 m .34792 .54393 L .34815 .54382 L F
.34811 .54392 m .34815 .54382 L .35293 .54162 L F
0 0 0 r
.34788 .54457 m .34808 .54368 L .34792 .54393 L F
.685 .512 .647 r
.34808 .54368 m .34686 .54684 L .34442 .5464 L F
.853 .769 .769 r
.38164 .63648 m .384 .63284 L .38196 .63177 L F
.766 .997 .838 r
.34066 .60099 m .34359 .5985 L .34113 .5992 L F
.245 .291 .713 r
.34113 .5992 m .34058 .60361 L .34066 .60099 L F
.155 0 .165 r
.27701 .55507 m .27917 .55459 L .27965 .55292 L F
.165 0 .088 r
.27581 .55788 m .27917 .55459 L .27701 .55507 L F
.261 .268 .678 r
.63316 .41001 m .63059 .40967 L .63037 .40724 L F
.244 0 .164 r
.61999 .39136 m .61703 .39397 L .61926 .39271 L F
.535 .103 .166 r
.62241 .39317 m .61999 .39136 L .61926 .39271 L F
.62241 .39317 m .62474 .3911 L .61999 .39136 L F
0 0 0 r
.3274 .59099 m .3305 .58792 L .33036 .59034 L F
.296 .021 .316 r
.33214 .5894 m .3305 .58792 L .33224 .58746 L F
.33214 .5894 m .33036 .59034 L .3305 .58792 L F
.527 .89 .975 r
.36391 .71475 m .36537 .71521 L .36771 .71426 L F
.548 .414 .65 r
.28953 .61397 m .29204 .61159 L .289 .61135 L F
.399 .299 .624 r
.43874 .50852 m .43919 .51149 L .4372 .51176 L F
.478 .435 .732 r
.44008 .51349 m .4372 .51176 L .43919 .51149 L F
.547 .284 .468 r
.31058 .55344 m .30994 .55587 L .3072 .55618 L F
.406 .153 .414 r
.312 .55515 m .31058 .55344 L .31242 .55244 L F
.312 .55515 m .30994 .55587 L .31058 .55344 L F
.905 .932 .821 r
.67684 .32028 m .67335 .32225 L .67576 .31896 L F
.67684 .32028 m .67437 .32362 L .67335 .32225 L F
.853 .93 .877 r
.67978 .31717 m .67684 .32028 L .67576 .31896 L F
.025 .062 .562 r
.27138 .56607 m .27169 .56793 L .27019 .56578 L F
.18 0 0 r
.27398 .56533 m .27138 .56607 L .27019 .56578 L F
.321 .147 .482 r
.27169 .56793 m .26986 .56878 L .27019 .56578 L F
.42 .14 .38 r
.45506 .57873 m .45463 .581 L .45217 .58158 L F
.476 .188 .397 r
.45728 .58044 m .45463 .581 L .45506 .57873 L F
.54 .249 .422 r
.45831 .57733 m .45765 .57865 L .45506 .57873 L F
.514 .173 .326 r
.45765 .57865 m .45728 .58044 L .45506 .57873 L F
.794 .848 .892 r
.24815 .53241 m .25268 .53155 L .25089 .53148 L F
0 0 0 r
.25442 .53019 m .25089 .53148 L .25268 .53155 L F
.894 .874 .81 r
.67437 .32362 m .67073 .32537 L .67335 .32225 L F
.67437 .32362 m .67205 .32687 L .67073 .32537 L F
.576 .94 .823 r
.34113 .5992 m .34359 .5985 L .34546 .59717 L F
.475 .345 .623 r
.29167 .54546 m .29363 .54282 L .2916 .54385 L F
.678 .7 .863 r
.35295 .65653 m .3515 .65463 L .35139 .65738 L F
.35295 .65653 m .35393 .65377 L .3515 .65463 L F
.35295 .65653 m .35556 .65541 L .35393 .65377 L F
.731 .934 .602 r
.33595 .56608 m .33416 .5677 L .33361 .56917 L F
.471 .463 .767 r
.33416 .5677 m .33282 .57104 L .33361 .56917 L F
.326 .809 .781 r
.28843 .52361 m .28732 .52427 L .28964 .52416 L F
.28843 .52361 m .2859 .52453 L .28732 .52427 L F
.197 0 .208 r
.35261 .58153 m .35044 .58232 L .34939 .58449 L F
.203 .478 .892 r
.22141 .60806 m .22326 .61045 L .2238 .60892 L F
.922 .77 .674 r
.53769 .42569 m .53417 .42795 L .53425 .42437 L F
.53769 .42569 m .53694 .42884 L .53417 .42795 L F
.562 .558 .807 r
.59954 .36382 m .60094 .36792 L .59829 .36845 L F
.59954 .36382 m .59829 .36845 L .59962 .36685 L F
.487 .813 1 r
.59829 .36845 m .60094 .36792 L .59962 .36685 L F
.354 .151 .459 r
.33019 .57445 m .32771 .57799 L .3282 .57542 L F
.737 .339 .296 r
.27609 .56618 m .27565 .56775 L .27398 .56533 L F
0 .005 .581 r
.27398 .56533 m .27565 .56775 L .27457 .56533 L F
0 0 0 r
.27457 .56533 m .27138 .56607 L .27398 .56533 L F
.807 .725 .774 r
.32241 .51815 m .31812 .51886 L .32064 .51945 L F
.894 .519 .319 r
.32064 .51945 m .32293 .52098 L .32241 .51815 L F
.82 .462 .379 r
.32241 .51815 m .32293 .52098 L .32634 .52139 L F
.322 0 .08 r
.30384 .53537 m .30251 .53393 L .304 .5329 L F
.30384 .53537 m .30129 .53592 L .30251 .53393 L F
.794 .994 .872 r
.33399 .52754 m .33292 .52709 L .33454 .52527 L F
.532 .921 .902 r
.55104 .41694 m .5492 .41844 L .54812 .41804 L F
.63 .954 .779 r
.34174 .66258 m .3456 .66001 L .34506 .66102 L F
.694 .572 .714 r
.34506 .66102 m .34535 .65752 L .34341 .65978 L F
.34535 .65752 m .34543 .65655 L .34442 .65816 L F
.34535 .65752 m .34442 .65816 L .34341 .65978 L F
.874 .839 .807 r
.34899 .65503 m .34895 .65505 L .34671 .65701 L F
.34895 .65505 m .34476 .65716 L .34601 .65706 L F
.34895 .65505 m .34601 .65706 L .34671 .65701 L F
.541 .395 .632 r
.34899 .65503 m .35115 .65185 L .34755 .65148 L F
.34899 .65503 m .3515 .65463 L .35115 .65185 L F
.289 0 0 r
.34982 .65674 m .34899 .65503 L .34671 .65701 L F
.34982 .65674 m .3515 .65463 L .34899 .65503 L F
.85 .496 .383 r
.70679 .313 m .70908 .31407 L .70802 .31593 L F
.705 .426 .5 r
.71167 .31363 m .70802 .31593 L .70908 .31407 L F
0 0 .441 r
.61237 .4161 m .6137 .41669 L .61258 .41461 L F
.61237 .4161 m .61313 .41861 L .6137 .41669 L F
.656 .544 .716 r
.25068 .55141 m .24749 .55353 L .25044 .5529 L F
.25068 .55141 m .24749 .55353 L .25044 .5529 L F
.26 .179 .571 r
.25068 .55141 m .25194 .55208 L .25044 .5529 L F
.348 0 0 r
.25044 .5529 m .25062 .55405 L .25194 .55208 L F
.399 .255 .568 r
.25016 .55455 m .25251 .55263 L .25031 .55429 L F
.431 .178 .427 r
.25481 .5491 m .25194 .55208 L .25239 .54968 L F
.25481 .5491 m .25194 .55208 L .25239 .54968 L F
.576 .539 .777 r
.253 .55309 m .25254 .55277 L .25325 .55057 L F
.399 .255 .568 r
.25251 .55263 m .25319 .55208 L .25251 .5526 L F
.25251 .55263 m .25251 .5526 L .25031 .55429 L F
.348 0 0 r
.25062 .55405 m .25073 .55396 L .25194 .55208 L F
.576 .539 .777 r
.25254 .55277 m .25214 .55089 L .25325 .55057 L F
.232 0 .334 r
.25551 .55032 m .253 .55309 L .25325 .55057 L F
.399 .255 .568 r
.25059 .5542 m .25096 .55415 L .25319 .55208 L F
.25096 .55415 m .2532 .55219 L .25319 .55208 L F
.348 0 0 r
.25062 .55405 m .25063 .55412 L .25073 .55396 L F
.26 .179 .571 r
.25068 .55141 m .25194 .55208 L .25044 .5529 L F
0 0 .036 r
.25063 .55412 m .25044 .5529 L .25194 .55208 L F
.356 .113 .402 r
.25239 .54968 m .25194 .55208 L .25068 .55141 L F
.25239 .54968 m .25194 .55208 L .25068 .55141 L F
.815 .799 .836 r
.25325 .55057 m .2505 .55135 L .25293 .54962 L F
.399 .255 .568 r
.25046 .55402 m .25319 .55208 L .25293 .54962 L F
0 0 .036 r
.25046 .55441 m .24996 .55558 L .25021 .55417 L F
0 0 0 r
.25049 .55444 m .24929 .55809 L .24996 .55558 L F
.25057 .55424 m .2505 .55447 L .25049 .55444 L F
.2505 .55447 m .24929 .55809 L .25049 .55444 L F
.25033 .55501 m .24929 .55809 L .25057 .55424 L F
0 0 .212 r
.25051 .55449 m .25044 .55697 L .24929 .55809 L F
0 0 0 r
.25055 .5545 m .25052 .55447 L .25047 .55448 L F
.399 .255 .568 r
.2505 .55447 m .2521 .55412 L .25059 .5542 L F
.2521 .55412 m .25337 .55383 L .25236 .55397 L F
.2521 .55412 m .25236 .55397 L .25059 .5542 L F
0 0 0 r
.25311 .55394 m .25337 .55383 L .2521 .55412 L F
.399 .255 .568 r
.25096 .55415 m .25337 .55383 L .25335 .5536 L F
.281 .053 .38 r
.25292 .55364 m .25136 .5538 L .253 .55309 L F
.576 .539 .777 r
.253 .55309 m .25136 .5538 L .25254 .55277 L F
.399 .255 .568 r
.25136 .5538 m .25335 .5536 L .2532 .55219 L F
.25096 .55415 m .25335 .5536 L .25136 .5538 L F
.281 .053 .38 r
.25287 .55398 m .25063 .55412 L .25136 .5538 L F
.25287 .55398 m .25136 .5538 L .25292 .55364 L F
.25256 .55596 m .25098 .55445 L .25287 .55399 L F
.962 .725 .533 r
.25337 .55383 m .25256 .55596 L .25513 .55291 L F
.222 0 .28 r
.25446 .5537 m .25256 .55596 L .25287 .55399 L F
.25311 .55394 m .25287 .55399 L .25287 .55398 L F
.25446 .5537 m .25287 .55399 L .25311 .55394 L F
0 0 .212 r
.25061 .55451 m .25044 .55697 L .25051 .55449 L F
0 0 .036 r
.25057 .55424 m .24996 .55558 L .25062 .55405 L F
.504 .848 .579 r
.24683 .55734 m .25016 .55455 L .2483 .55452 L F
.24683 .55734 m .24837 .5559 L .25016 .55455 L F
.281 .053 .38 r
.25256 .55596 m .25044 .55697 L .2506 .55452 L F
.25098 .55445 m .2506 .55452 L .25063 .55412 L F
.25256 .55596 m .2506 .55452 L .25098 .55445 L F
.009 0 .113 r
.25122 .55775 m .25044 .55697 L .25256 .55596 L F
.962 .725 .533 r
.25337 .55383 m .25145 .55488 L .25256 .55596 L F
.25145 .55488 m .25065 .55531 L .25145 .55558 L F
.25145 .55488 m .25145 .55558 L .25256 .55596 L F
.953 .807 .661 r
.25065 .55531 m .25122 .55775 L .25256 .55596 L F
0 0 .433 r
.25233 .55486 m .25274 .55712 L .25147 .55765 L F
.25146 .55712 m .25147 .55765 L .25122 .55775 L F
.25233 .55486 m .25147 .55765 L .25146 .55712 L F
.25266 .554 m .25268 .55485 L .25233 .55486 L F
.25268 .55485 m .25274 .55712 L .25233 .55486 L F
0 0 0 r
.24837 .5559 m .25065 .55531 L .25145 .55488 L F
.25089 .55489 m .25145 .55488 L .25297 .55405 L F
.24837 .5559 m .25145 .55488 L .25089 .55489 L F
.25282 .55408 m .25297 .55405 L .25321 .55392 L F
.24837 .5559 m .25297 .55405 L .25282 .55408 L F
.25316 .55393 m .25321 .55392 L .25328 .55388 L F
.24837 .5559 m .25321 .55392 L .25316 .55393 L F
.2532 .5539 m .25328 .55388 L .25337 .55383 L F
.24837 .5559 m .25328 .55388 L .2532 .5539 L F
.281 .053 .38 r
.25287 .55399 m .25097 .55444 L .25287 .55398 L F
.25098 .55445 m .25097 .55444 L .25287 .55399 L F
0 0 0 r
.25058 .55453 m .25266 .55403 L .25052 .55447 L F
.25311 .55394 m .2521 .55412 L .25052 .55447 L F
.281 .053 .38 r
.25097 .55444 m .25063 .55412 L .25287 .55398 L F
0 0 0 r
.25091 .55485 m .25311 .55394 L .25266 .55403 L F
.25091 .55485 m .25266 .55403 L .25058 .55453 L F
.222 0 .28 r
.25403 .55301 m .25333 .55341 L .253 .55309 L F
.25513 .55291 m .25292 .55364 L .25403 .55301 L F
.497 .357 .62 r
.25239 .54968 m .25481 .5491 L .25456 .54609 L F
.381 .27 .601 r
.25456 .54609 m .25481 .5491 L .25654 .54772 L F
.386 .349 .695 r
.25525 .54748 m .25325 .55057 L .25293 .54962 L F
.25525 .54748 m .25551 .55032 L .25325 .55057 L F
.232 0 .334 r
.25551 .55032 m .25513 .55291 L .253 .55309 L F
.316 .196 .553 r
.25293 .54962 m .25333 .55341 L .25513 .55291 L F
.25333 .55341 m .25337 .55383 L .25513 .55291 L F
.222 0 .28 r
.25333 .55341 m .25292 .55364 L .25294 .55352 L F
.25333 .55341 m .25294 .55352 L .253 .55309 L F
.25513 .55291 m .25446 .5537 L .25292 .55364 L F
.25446 .5537 m .25287 .55398 L .25292 .55364 L F
0 0 .212 r
.25063 .55412 m .25061 .55451 L .25051 .55449 L F
0 0 0 r
.25091 .55485 m .25055 .5545 L .25016 .55455 L F
.25055 .5545 m .25047 .55448 L .25016 .55455 L F
.24837 .5559 m .25068 .55495 L .25016 .55455 L F
.25068 .55495 m .25091 .55485 L .25059 .55472 L F
.25068 .55495 m .25059 .55472 L .25016 .55455 L F
0 0 .036 r
.25061 .55398 m .25046 .55441 L .25044 .5529 L F
.25046 .55441 m .25021 .55417 L .25044 .5529 L F
.348 0 0 r
.25044 .5529 m .24925 .5538 L .25046 .55402 L F
.25061 .55398 m .25046 .55402 L .25062 .55405 L F
.25044 .5529 m .25046 .55402 L .25061 .55398 L F
.802 .757 .811 r
.25021 .55407 m .2483 .55452 L .25016 .55455 L F
.348 0 0 r
.25046 .55402 m .2483 .55452 L .25062 .55405 L F
.24925 .5538 m .2483 .55451 L .25046 .55402 L F
.2483 .55451 m .2483 .55452 L .25046 .55402 L F
.399 .255 .568 r
.25021 .55407 m .25059 .55378 L .25023 .55389 L F
.25016 .55455 m .25046 .55402 L .25021 .55407 L F
.25046 .55402 m .25059 .55378 L .25021 .55407 L F
.043 0 0 r
.24749 .55353 m .2483 .55452 L .25044 .5529 L F
.2483 .55452 m .2483 .55451 L .25044 .5529 L F
.802 .757 .811 r
.2505 .55135 m .2483 .55452 L .25021 .55407 L F
.399 .255 .568 r
.25059 .55378 m .25075 .5535 L .25023 .55389 L F
.576 .539 .777 r
.25216 .55098 m .2505 .55135 L .25214 .55089 L F
.399 .255 .568 r
.25075 .5535 m .25216 .55098 L .25098 .55271 L F
.25216 .55098 m .25205 .55101 L .25098 .55271 L F
.25062 .55405 m .25319 .55208 L .25046 .55402 L F
.25023 .55389 m .25293 .54962 L .2505 .55135 L F
.576 .539 .777 r
.25254 .55277 m .2505 .55135 L .25216 .55098 L F
.399 .255 .568 r
.25216 .55098 m .25293 .54962 L .25205 .55101 L F
.25075 .5535 m .25098 .55271 L .25023 .55389 L F
0 0 .036 r
.25062 .55405 m .25053 .55425 L .25061 .55398 L F
.25053 .55425 m .25046 .55441 L .25061 .55398 L F
.399 .255 .568 r
.25058 .5542 m .25057 .55424 L .25059 .5542 L F
0 0 .036 r
.25063 .55412 m .25057 .55424 L .25062 .55405 L F
.399 .255 .568 r
.25016 .55455 m .2505 .55447 L .25057 .55424 L F
.25016 .55455 m .25057 .55424 L .25058 .5542 L F
.25031 .55429 m .25062 .55405 L .25046 .55402 L F
.348 0 0 r
.25062 .55405 m .2483 .55452 L .25063 .55412 L F
.576 .539 .777 r
.25254 .55277 m .25063 .55412 L .2505 .55135 L F
.25136 .5538 m .25063 .55412 L .25254 .55277 L F
0 0 0 r
.25063 .55412 m .25033 .55501 L .25057 .55424 L F
.043 0 0 r
.2483 .55452 m .2483 .55452 L .2483 .55451 L F
.24749 .55353 m .24578 .55562 L .2483 .55452 L F
.744 .637 .742 r
.37808 .68353 m .37971 .68712 L .37554 .6868 L F
.401 .592 .921 r
.37924 .68908 m .37554 .6868 L .37971 .68712 L F
.536 .369 .601 r
.68783 .36875 m .68771 .37094 L .68554 .37114 L F
.587 .336 .504 r
.68771 .37094 m .68478 .3735 L .68554 .37114 L F
.576 .833 .994 r
.38857 .61608 m .39278 .61648 L .39058 .61731 L F
0 .413 .794 r
.38857 .61608 m .39058 .61731 L .38884 .61622 L F
.881 .886 .831 r
.38884 .61622 m .39058 .61731 L .38802 .62025 L F
.8 .947 .6 r
.31902 .65504 m .31728 .6578 L .31682 .6572 L F
.609 .179 0 r
.31682 .6572 m .31728 .6578 L .31898 .66042 L F
.192 .636 .945 r
.53902 .41582 m .54307 .41704 L .54194 .41525 L F
.22 0 .118 r
.34395 .59069 m .34177 .59151 L .34083 .59285 L F
0 .002 .563 r
.39178 .59115 m .39151 .5875 L .39268 .58814 L F
.715 .668 .802 r
.32698 .54037 m .32799 .54355 L .32397 .54284 L F
.423 0 .118 r
.32799 .54355 m .32379 .54595 L .32397 .54284 L F
.32799 .54355 m .32656 .54589 L .32379 .54595 L F
.609 .188 .219 r
.3306 .54551 m .32656 .54589 L .32799 .54355 L F
.571 0 0 r
.37285 .52479 m .3754 .52656 L .37158 .52527 L F
.674 .459 .585 r
.37542 .57865 m .37262 .58166 L .37462 .5789 L F
.37542 .57865 m .37529 .58151 L .37262 .58166 L F
.774 .63 .701 r
.38805 .65481 m .39212 .65509 L .3906 .65091 L F
0 .573 .747 r
.38987 .65484 m .39212 .65509 L .38805 .65481 L F
.909 .736 .654 r
.37802 .57552 m .37542 .57865 L .37547 .57569 L F
.502 .316 .56 r
.37758 .57914 m .37529 .58151 L .37542 .57865 L F
0 0 0 r
.39212 .65509 m .39335 .65412 L .39467 .65186 L F
.717 .407 .452 r
.38987 .65484 m .39335 .65412 L .39212 .65509 L F
0 0 .303 r
.40656 .53709 m .40614 .53546 L .40522 .53319 L F
.895 .478 .093 r
.40656 .53709 m .40575 .53831 L .40614 .53546 L F
.40656 .53709 m .40747 .5399 L .40575 .53831 L F
.784 .705 .777 r
.58303 .40652 m .58063 .40958 L .57919 .40582 L F
.494 .902 .909 r
.37186 .69928 m .37443 .69832 L .37262 .6982 L F
.37186 .69928 m .37443 .69832 L .37262 .6982 L F
0 .359 .817 r
.60641 .40696 m .60829 .40711 L .60542 .40531 L F
.60641 .40696 m .60936 .40851 L .60829 .40711 L F
.278 .561 .931 r
.26271 .6201 m .26349 .62203 L .26088 .61974 L F
.26271 .6201 m .26502 .62253 L .26349 .62203 L F
.442 .265 .544 r
.67362 .381 m .67403 .38387 L .67141 .38455 L F
.553 .491 .74 r
.6746 .38607 m .67141 .38455 L .67403 .38387 L F
.618 .398 .56 r
.57233 .46253 m .56824 .46074 L .57226 .46069 L F
.646 .303 .376 r
.57226 .46069 m .57476 .46286 L .57233 .46253 L F
0 0 .479 r
.36568 .66388 m .36688 .66708 L .36519 .66368 L F
.15 0 0 r
.36568 .66388 m .36519 .66368 L .36319 .66364 L F
.502 .225 .427 r
.46128 .57508 m .45765 .57865 L .45831 .57733 L F
.46128 .57508 m .45975 .57887 L .45765 .57865 L F
.616 .343 .48 r
.46355 .57736 m .46128 .57508 L .46379 .57493 L F
.46355 .57736 m .45975 .57887 L .46128 .57508 L F
.817 .694 .728 r
.74137 .32643 m .74107 .3295 L .74282 .32617 L F
0 0 .222 r
.61431 .44379 m .6138 .44626 L .61197 .44793 L F
0 0 .051 r
.6138 .44626 m .6115 .45042 L .61197 .44793 L F
.414 .463 .803 r
.22735 .59079 m .22556 .59134 L .22418 .58768 L F
.362 .288 .637 r
.22735 .59079 m .2279 .59356 L .22556 .59134 L F
.226 .023 .382 r
.57544 .41543 m .57289 .41938 L .57456 .41836 L F
.286 .126 .481 r
.57284 .42186 m .57289 .41938 L .57456 .41836 L F
.226 .023 .382 r
.57456 .41836 m .57289 .41938 L .57544 .41543 L F
.636 .52 .704 r
.57284 .42186 m .57456 .41836 L .57289 .41938 L F
.558 .33 .526 r
.2858 .53381 m .28845 .53343 L .28864 .53086 L F
.266 .019 .341 r
.29537 .54674 m .29447 .54943 L .29282 .54997 L F
.346 .206 .543 r
.29447 .54943 m .29464 .55188 L .29282 .54997 L F
.315 .202 .562 r
.29464 .55188 m .29302 .55288 L .29282 .54997 L F
.81 .711 .756 r
.64369 .35162 m .64485 .3555 L .6413 .35493 L F
.809 .714 .76 r
.6413 .35493 m .64485 .3555 L .64253 .35876 L F
.731 .669 .789 r
.64774 .3523 m .64485 .3555 L .64369 .35162 L F
.618 .398 .56 r
.57233 .46253 m .56806 .46336 L .56824 .46074 L F
.59 .63 .859 r
.25999 .55357 m .26054 .54923 L .25916 .54894 L F
.25999 .55357 m .26306 .55302 L .26054 .54923 L F
.897 .9 .821 r
.39346 .61377 m .39274 .6119 L .39527 .61301 L F
.39346 .61377 m .39149 .61273 L .39274 .6119 L F
0 0 .353 r
.33288 .56107 m .33445 .56621 L .3331 .56278 L F
.519 .812 .999 r
.33288 .56107 m .3331 .56278 L .33047 .56166 L F
.386 .418 .772 r
.34229 .5233 m .34116 .5267 L .33892 .52384 L F
.631 .335 .45 r
.43712 .59118 m .43403 .59359 L .43452 .59184 L F
.622 .309 .419 r
.27883 .56494 m .27565 .56775 L .27609 .56618 L F
.739 .743 .855 r
.53277 .41877 m .53399 .42242 L .52983 .422 L F
.681 .237 .189 r
.52983 .422 m .53399 .42242 L .53212 .42394 L F
.805 .777 .827 r
.53618 .41976 m .53399 .42242 L .53277 .41877 L F
.834 .457 .34 r
.53212 .42394 m .53399 .42242 L .53425 .42437 L F
.456 .483 .798 r
.44899 .54251 m .44807 .54675 L .44678 .54295 L F
.44899 .54251 m .45031 .54642 L .44807 .54675 L F
.73 .934 .602 r
.33683 .56422 m .33595 .56608 L .33863 .56625 L F
.33683 .56422 m .33416 .5677 L .33595 .56608 L F
.979 .769 .355 r
.41305 .55304 m .41205 .55455 L .41194 .55155 L F
.41305 .55304 m .41285 .55574 L .41205 .55455 L F
.834 .537 .486 r
.54198 .44474 m .54583 .44825 L .54224 .4471 L F
.815 .416 .296 r
.54224 .4471 m .54583 .44825 L .5443 .44978 L F
.706 .265 .202 r
.54583 .44825 m .54824 .45032 L .5443 .44978 L F
.74 .848 .407 r
.37059 .66764 m .36898 .6711 L .36946 .66937 L F
.143 .473 .895 r
.36946 .66937 m .36898 .6711 L .37049 .67138 L F
.338 .068 .348 r
.37049 .67138 m .36898 .6711 L .36886 .67309 L F
.952 .68 .484 r
.36946 .66937 m .36959 .67176 L .36798 .67071 L F
.281 0 0 r
.36868 .67058 m .36946 .66937 L .36798 .67071 L F
.143 .473 .895 r
.36946 .66937 m .37049 .67138 L .36959 .67176 L F
.281 0 0 r
.37087 .67016 m .36946 .66937 L .36868 .67058 L F
.74 .848 .407 r
.37064 .66752 m .37059 .66764 L .36946 .66937 L F
.014 .22 .728 r
.4017 .66767 m .40384 .66995 L .40155 .66792 L F
.769 .705 .791 r
.3616 .59473 m .36578 .59377 L .3648 .59084 L F
.752 .596 .683 r
.36265 .5974 m .36578 .59377 L .3616 .59473 L F
.72 .548 .656 r
.36265 .5974 m .36616 .59806 L .36578 .59377 L F
.456 .517 .832 r
.3648 .59084 m .36578 .59377 L .36859 .59275 L F
.488 .679 .95 r
.36578 .59377 m .36836 .59429 L .36859 .59275 L F
.61 .466 .661 r
.36578 .59377 m .36894 .59756 L .36836 .59429 L F
.36578 .59377 m .36616 .59806 L .36894 .59756 L F
.776 .811 .33 r
.33496 .68459 m .33569 .68357 L .33744 .68321 L F
.591 .583 .812 r
.33621 .66099 m .3374 .6638 L .33976 .6614 L F
.172 .068 .486 r
.28053 .53748 m .28185 .53925 L .28219 .53673 L F
.28053 .53748 m .28016 .54059 L .28185 .53925 L F
.518 .829 1 r
.39044 .56937 m .389 .56772 L .3846 .56826 L F
.38451 .56831 m .3846 .56826 L .38435 .56829 L F
.39044 .56937 m .3846 .56826 L .38451 .56831 L F
.221 .087 .478 r
.38541 .56753 m .38495 .56776 L .38639 .56663 L F
.518 .829 1 r
.389 .56772 m .38881 .56749 L .38592 .56794 L F
.758 .566 .637 r
.38943 .56759 m .3883 .56741 L .38639 .56663 L F
.518 .829 1 r
.38881 .56749 m .38867 .56733 L .3883 .56741 L F
.38881 .56749 m .3883 .56741 L .38592 .56794 L F
.758 .566 .637 r
.39029 .56712 m .38943 .56759 L .38639 .56663 L F
.741 .93 .952 r
.39029 .56712 m .38867 .56733 L .38881 .56749 L F
.39029 .56712 m .38881 .56749 L .39044 .56937 L F
.758 .566 .637 r
.38943 .56759 m .38914 .56775 L .38862 .56754 L F
.38881 .56749 m .38862 .56754 L .3883 .56741 L F
.38943 .56759 m .38862 .56754 L .38881 .56749 L F
.568 .772 .975 r
.38465 .56822 m .3883 .56741 L .38665 .56674 L F
.38465 .56822 m .38668 .56672 L .385 .5679 L F
.518 .829 1 r
.389 .56772 m .38592 .56794 L .3845 .56825 L F
.38446 .56827 m .3845 .56825 L .38435 .56829 L F
.389 .56772 m .3845 .56825 L .38446 .56827 L F
.221 .087 .478 r
.38565 .56969 m .38479 .57075 L .38493 .56801 L F
.38496 .568 m .38493 .56801 L .38494 .56795 L F
.38565 .56969 m .38493 .56801 L .38496 .568 L F
.758 .566 .637 r
.38914 .56775 m .38565 .56969 L .38639 .56663 L F
.568 .772 .975 r
.38665 .56674 m .38867 .56733 L .38668 .56672 L F
.3883 .56741 m .38867 .56733 L .38665 .56674 L F
.385 .5679 m .38668 .56672 L .38639 .56663 L F
.221 .087 .478 r
.385 .5679 m .38494 .56795 L .38495 .56776 L F
.38565 .56969 m .38494 .56795 L .385 .5679 L F
.38502 .56796 m .38495 .56776 L .38628 .56709 L F
.568 .772 .975 r
.38435 .56829 m .38495 .56795 L .38477 .56795 L F
.66 .447 .585 r
.38469 .56795 m .38493 .56801 L .38457 .56804 L F
.38495 .56776 m .38494 .56795 L .38469 .56795 L F
.38494 .56795 m .38493 .56801 L .38469 .56795 L F
.568 .772 .975 r
.38435 .56829 m .38465 .56822 L .38495 .56795 L F
.38477 .56795 m .38495 .56795 L .38639 .56663 L F
.221 .087 .478 r
.38628 .56709 m .38541 .56753 L .38639 .56663 L F
.38565 .56969 m .38502 .56796 L .38628 .56709 L F
0 0 0 r
.38315 .56902 m .38435 .56829 L .38495 .56776 L F
.66 .447 .585 r
.38457 .56804 m .38479 .57075 L .38134 .57037 L F
.38493 .56801 m .38479 .57075 L .38457 .56804 L F
.741 .93 .952 r
.39029 .56712 m .39044 .56937 L .39203 .56828 L F
.031 0 .149 r
.39044 .56937 m .38963 .57154 L .39203 .56828 L F
.679 .624 .787 r
.35336 .53729 m .35677 .53769 L .35471 .53594 L F
.487 .072 .177 r
.35492 .53891 m .35336 .53729 L .35471 .53594 L F
.35492 .53891 m .35167 .5396 L .35336 .53729 L F
.855 .906 .869 r
.67205 .32687 m .66803 .32853 L .67073 .32537 L F
0 0 0 r
.69637 .3458 m .69395 .34978 L .69639 .3486 L F
.203 0 .2 r
.69639 .3486 m .69395 .34978 L .69346 .35148 L F
.202 0 .086 r
.36684 .58753 m .37021 .5865 L .37018 .58629 L F
.36728 .58708 m .37018 .58629 L .36991 .58434 L F
.36684 .58753 m .37018 .58629 L .36728 .58708 L F
.37021 .5865 m .37052 .58626 L .36991 .58434 L F
.555 .417 .648 r
.37262 .58166 m .37195 .58508 L .36991 .58434 L F
.552 .352 .563 r
.37292 .58695 m .36991 .58434 L .37195 .58508 L F
.37292 .58695 m .37194 .58816 L .36991 .58434 L F
0 0 .182 r
.3705 .5862 m .37054 .58616 L .37102 .58347 L F
.603 .362 .524 r
.37102 .58347 m .37054 .58616 L .37064 .58616 L F
.456 .517 .832 r
.3648 .59084 m .36859 .59275 L .36601 .58996 L F
.895 .861 .415 r
.36684 .58753 m .36601 .58996 L .3663 .58783 L F
.459 0 0 r
.36859 .59275 m .36826 .59258 L .36601 .58996 L F
.699 .585 .725 r
.3663 .58783 m .36826 .59258 L .37008 .58797 L F
.603 .362 .524 r
.37101 .58587 m .37064 .58616 L .37101 .58616 L F
.586 .323 .485 r
.37054 .58616 m .3709 .58609 L .37064 .58616 L F
.603 .362 .524 r
.37102 .58347 m .37064 .58616 L .37101 .58587 L F
.586 .323 .485 r
.3706 .5861 m .3709 .58609 L .37054 .58616 L F
.3706 .5861 m .37084 .58605 L .3709 .58609 L F
.699 .585 .725 r
.37063 .58613 m .37008 .58797 L .37084 .58605 L F
0 0 .182 r
.37052 .58626 m .37056 .58638 L .37061 .58608 L F
.37056 .58638 m .37057 .58631 L .37061 .58608 L F
.37052 .58626 m .37061 .58608 L .37054 .58616 L F
.3705 .5862 m .37052 .58626 L .37054 .58616 L F
.202 0 .086 r
.37021 .5865 m .3705 .58642 L .37052 .58626 L F
.699 .585 .725 r
.36832 .5879 m .37008 .58797 L .37056 .58638 L F
.202 0 .086 r
.3705 .58642 m .37056 .5864 L .37056 .58638 L F
.3705 .58642 m .37056 .58638 L .37052 .58626 L F
.506 .698 .956 r
.36724 .5862 m .3704 .58639 L .36684 .58753 L F
.699 .585 .725 r
.36832 .5879 m .37056 .58638 L .37057 .58631 L F
0 0 .182 r
.37054 .58616 m .37061 .58608 L .37102 .58347 L F
.36991 .58434 m .3705 .5862 L .37087 .58428 L F
.37096 .58351 m .37087 .58428 L .37102 .58347 L F
.36991 .58434 m .37087 .58428 L .37096 .58351 L F
.603 .362 .524 r
.37102 .58347 m .36724 .5862 L .37054 .58616 L F
.586 .323 .485 r
.36724 .5862 m .3706 .5861 L .37054 .58616 L F
.603 .362 .524 r
.37102 .58347 m .37061 .58608 L .36724 .5862 L F
.586 .323 .485 r
.36724 .5862 m .37061 .58608 L .3706 .5861 L F
.603 .362 .524 r
.37061 .58608 m .37057 .58631 L .36724 .5862 L F
.586 .323 .485 r
.36724 .5862 m .37064 .58605 L .37061 .58608 L F
.699 .585 .725 r
.37017 .58648 m .37057 .58631 L .37063 .58613 L F
.36832 .5879 m .37057 .58631 L .37017 .58648 L F
0 0 .182 r
.37056 .58638 m .37056 .5864 L .37057 .58631 L F
.603 .362 .524 r
.37057 .58631 m .37056 .5864 L .3704 .58639 L F
.37057 .58631 m .3704 .58639 L .36724 .5862 L F
.506 .698 .956 r
.3704 .58639 m .37056 .5864 L .3705 .58642 L F
.3704 .58639 m .3705 .58642 L .36684 .58753 L F
.699 .585 .725 r
.3663 .58783 m .36832 .5879 L .37032 .58636 L F
.37015 .58632 m .37032 .58636 L .37063 .58613 L F
.3663 .58783 m .37032 .58636 L .37015 .58632 L F
.895 .861 .415 r
.36684 .58753 m .3663 .58783 L .36724 .5862 L F
.586 .323 .485 r
.36724 .5862 m .3663 .58783 L .37063 .58613 L F
.37064 .58605 m .37084 .58605 L .3706 .5861 L F
.37064 .58605 m .37063 .58613 L .37084 .58605 L F
.36724 .5862 m .37063 .58613 L .37064 .58605 L F
.37064 .58616 m .3709 .58609 L .37101 .58616 L F
0 0 0 r
.36991 .58434 m .37102 .58347 L .37262 .58166 L F
.555 .417 .648 r
.37262 .58166 m .36991 .58434 L .36982 .58256 L F
.902 .835 .771 r
.6819 .31355 m .6783 .31555 L .68082 .31205 L F
.6819 .31355 m .67978 .31717 L .6783 .31555 L F
.822 .903 .897 r
.68498 .31073 m .6819 .31355 L .68082 .31205 L F
.582 .425 .635 r
.45068 .55942 m .45088 .56249 L .44822 .56266 L F
0 0 .057 r
.44849 .56428 m .44822 .56266 L .45088 .56249 L F
.44849 .56428 m .44776 .56604 L .44821 .56279 L F
.681 .133 0 r
.44775 .56493 m .44861 .56494 L .44849 .56428 L F
.719 .642 .771 r
.45104 .56548 m .44776 .56604 L .44831 .56471 L F
.44904 .56454 m .44831 .56471 L .44849 .56428 L F
.45104 .56548 m .44831 .56471 L .44904 .56454 L F
.908 .652 .539 r
.45206 .56376 m .45104 .56548 L .45088 .56249 L F
.45206 .56376 m .45104 .56548 L .45088 .56249 L F
.235 .134 .53 r
.45088 .56249 m .45104 .56548 L .4527 .5635 L F
.719 .642 .771 r
.45104 .56548 m .44996 .56498 L .44911 .56495 L F
.44996 .56498 m .44849 .56428 L .44911 .56495 L F
.069 .633 .746 r
.44775 .56493 m .4481 .56492 L .44911 .56495 L F
.768 .976 .917 r
.4527 .5635 m .45104 .56548 L .44958 .56508 L F
.45011 .56455 m .44958 .56508 L .44911 .56495 L F
.4527 .5635 m .44958 .56508 L .45011 .56455 L F
.767 .691 .779 r
.45479 .56264 m .45206 .56376 L .45088 .56249 L F
.321 0 0 r
.4527 .5635 m .44849 .56428 L .45088 .56249 L F
.768 .976 .917 r
.45241 .56375 m .45113 .56421 L .45188 .5642 L F
.45113 .56421 m .44911 .56495 L .45188 .5642 L F
.45188 .5642 m .44911 .56495 L .45112 .56483 L F
.4527 .5635 m .45164 .56393 L .45241 .56375 L F
.45164 .56393 m .44911 .56495 L .45241 .56375 L F
0 0 0 r
.4527 .5635 m .45112 .56483 L .45147 .56461 L F
.321 0 0 r
.4527 .5635 m .45232 .56419 L .45193 .56419 L F
0 0 0 r
.45443 .56269 m .45232 .56419 L .4527 .5635 L F
.4527 .5635 m .45193 .56419 L .45443 .56269 L F
.321 0 0 r
.4527 .5635 m .45193 .56419 L .44849 .56428 L F
.579 .575 .812 r
.45205 .56296 m .45227 .56399 L .45443 .56269 L F
.45227 .56399 m .45232 .56419 L .45443 .56269 L F
0 0 0 r
.45193 .56419 m .45147 .56461 L .45443 .56269 L F
.592 .584 .812 r
.45145 .56318 m .45232 .56419 L .45205 .56296 L F
.44849 .56428 m .45042 .56423 L .45145 .56318 L F
.45042 .56423 m .45232 .56419 L .45145 .56318 L F
.069 .633 .746 r
.4481 .56492 m .45112 .56483 L .44911 .56495 L F
.681 .133 0 r
.44861 .56494 m .44911 .56495 L .44849 .56428 L F
0 0 .057 r
.44849 .56428 m .44821 .56279 L .44822 .56266 L F
0 0 .277 r
.70949 .36815 m .7097 .36871 L .70925 .36664 L F
.622 .772 .953 r
.42814 .48611 m .42355 .48515 L .426 .48178 L F
.599 .626 .849 r
.43068 .48512 m .42814 .48611 L .426 .48178 L F
.601 .613 .835 r
.43177 .48699 m .42814 .48611 L .43068 .48512 L F
0 0 0 r
.71353 .36778 m .71374 .36774 L .7097 .36871 L F
.71573 .36623 m .71353 .36778 L .71695 .36517 L F
.71573 .36623 m .71374 .36774 L .71353 .36778 L F
.611 .677 .888 r
.46545 .56798 m .46277 .56883 L .46088 .56564 L F
.246 .443 .856 r
.21726 .60147 m .2182 .59963 L .21647 .59961 L F
.21726 .60147 m .2201 .6032 L .2182 .59963 L F
.29 .168 .536 r
.36879 .66669 m .36688 .66708 L .3662 .665 L F
.087 .535 .906 r
.36015 .50191 m .35865 .50243 L .35704 .50114 L F
.36015 .50191 m .36175 .50322 L .35865 .50243 L F
0 0 .052 r
.34423 .52835 m .34339 .53099 L .34404 .52972 L F
.977 .68 .311 r
.34318 .52691 m .34404 .52972 L .34423 .52835 L F
.72 .348 .345 r
.34423 .52835 m .34737 .52997 L .34767 .52824 L F
.34466 .52857 m .34404 .52972 L .34737 .52997 L F
.34423 .52835 m .34404 .52972 L .34466 .52857 L F
.961 .918 .569 r
.34404 .52972 m .3434 .53318 L .34339 .53099 L F
0 0 .052 r
.34404 .52972 m .34339 .53099 L .34359 .53036 L F
.593 .553 .779 r
.34404 .52972 m .3434 .53318 L .34339 .53099 L F
.961 .918 .569 r
.34404 .52972 m .34255 .53213 L .3434 .53318 L F
.593 .553 .779 r
.34404 .52972 m .34512 .53405 L .3434 .53318 L F
0 0 0 r
.34559 .52939 m .34292 .5318 L .34404 .52972 L F
.34292 .5318 m .34255 .53213 L .34404 .52972 L F
.34767 .52824 m .34404 .52972 L .34423 .52835 L F
.112 .214 .691 r
.34318 .52691 m .34483 .5286 L .34404 .52972 L F
0 0 0 r
.34731 .52839 m .34559 .52939 L .34404 .52972 L F
.34767 .52824 m .34559 .52939 L .34731 .52839 L F
.112 .214 .691 r
.34483 .5286 m .34559 .52939 L .34404 .52972 L F
.326 .122 .443 r
.34652 .52719 m .34429 .53015 L .34559 .52939 L F
.34429 .53015 m .34411 .53039 L .34559 .52939 L F
0 0 .052 r
.34404 .52972 m .34359 .53036 L .34423 .52835 L F
.845 .777 .785 r
.63212 .39283 m .6357 .39036 L .63465 .38904 L F
.818 .827 .857 r
.64942 .34537 m .6483 .34951 L .64637 .34841 L F
.903 .727 .654 r
.6483 .34951 m .64774 .3523 L .64637 .34841 L F
0 0 0 r
.71928 .36175 m .71876 .36328 L .71695 .36517 L F
.534 .85 .55 r
.71695 .36517 m .71876 .36328 L .71573 .36623 L F
.055 .255 .75 r
.61775 .44419 m .61943 .44791 L .62051 .44619 L F
.054 .254 .749 r
.62051 .44619 m .61943 .44791 L .62165 .44973 L F
.725 .681 .807 r
.62701 .36541 m .62838 .36889 L .6244 .36799 L F
.778 .707 .785 r
.63111 .36548 m .62838 .36889 L .62701 .36541 L F
.097 .393 .849 r
.36175 .50322 m .36322 .50392 L .36268 .50529 L F
.29 .625 .961 r
.36322 .50392 m .36465 .50537 L .36268 .50529 L F
.575 .546 .785 r
.27943 .62727 m .27711 .62948 L .27947 .62724 L F
0 0 .497 r
.27854 .63041 m .27711 .62948 L .27943 .62727 L F
.27854 .63041 m .27779 .63204 L .27711 .62948 L F
.47 .599 .899 r
.64154 .38466 m .64553 .38749 L .64413 .38372 L F
.635 .64 .838 r
.64553 .38749 m .64687 .38293 L .64413 .38372 L F
.64553 .38749 m .64818 .38661 L .64687 .38293 L F
.879 .81 .777 r
.37798 .59673 m .38215 .59453 L .37717 .59543 L F
.37798 .59673 m .38004 .59833 L .38215 .59453 L F
.999 .83 .531 r
.39716 .67277 m .39857 .67372 L .39884 .67098 L F
.39716 .67277 m .39857 .67372 L .39884 .67098 L F
.153 0 0 r
.39995 .67167 m .39716 .67277 L .39884 .67098 L F
.391 .199 .497 r
.38724 .60795 m .38478 .61013 L .38493 .60727 L F
.38724 .60795 m .38478 .61013 L .38493 .60727 L F
.436 .74 .992 r
.39334 .65071 m .39467 .65186 L .39576 .65034 L F
.504 .362 .621 r
.39335 .65412 m .39576 .65034 L .39467 .65186 L F
.734 .991 .838 r
.64934 .42759 m .65315 .42535 L .65321 .42484 L F
.766 .891 .484 r
.65315 .42535 m .65513 .42115 L .65321 .42484 L F
.376 .546 .895 r
.28877 .62083 m .2915 .62235 L .29099 .61981 L F
.761 .916 .942 r
.71144 .34123 m .70897 .34312 L .70801 .34187 L F
.556 .391 .613 r
.32485 .59374 m .32218 .59724 L .32241 .59449 L F
.386 .372 .721 r
.31275 .53391 m .31346 .53789 L .31547 .53602 L F
.62 .8 .968 r
.32132 .53287 m .3226 .53441 L .31885 .534 L F
.32132 .53287 m .3226 .53441 L .31885 .534 L F
.63 .804 .966 r
.32504 .53352 m .3226 .53441 L .32132 .53287 L F
.428 .319 .628 r
.32493 .53624 m .3226 .53441 L .32504 .53352 L F
.32493 .53624 m .32304 .53754 L .3226 .53441 L F
0 .105 .653 r
.62468 .41766 m .626 .41802 L .62383 .41722 L F
0 0 .405 r
.6268 .41929 m .62685 .41825 L .626 .41802 L F
0 0 .511 r
.6284 .42054 m .6268 .41929 L .626 .41802 L F
0 .105 .653 r
.62804 .41936 m .6284 .42054 L .626 .41802 L F
.62804 .41936 m .626 .41802 L .62468 .41766 L F
0 0 .405 r
.62685 .41825 m .627 .4151 L .626 .41802 L F
0 0 .511 r
.6284 .42054 m .62754 .42105 L .6268 .41929 L F
.68 .819 .95 r
.33105 .63267 m .32995 .63254 L .33016 .63265 L F
0 0 .136 r
.33216 .63207 m .33105 .63267 L .33294 .62952 L F
.392 .85 .877 r
.33216 .63207 m .33105 .63267 L .32896 .63262 L F
.68 .819 .95 r
.33016 .63265 m .32627 .63211 L .32896 .63262 L F
.32995 .63254 m .32627 .63211 L .33016 .63265 L F
.392 .85 .877 r
.33216 .63207 m .32896 .63262 L .33128 .63082 L F
.585 .36 .541 r
.33105 .63267 m .33071 .63582 L .32783 .63576 L F
.377 .183 .486 r
.33281 .63477 m .33105 .63267 L .33216 .63207 L F
.33281 .63477 m .33071 .63582 L .33105 .63267 L F
.428 .738 .991 r
.32783 .63576 m .33071 .63582 L .32962 .63468 L F
.367 .165 .468 r
.33248 .63751 m .33071 .63582 L .33281 .63477 L F
0 .029 .534 r
.32983 .63488 m .33071 .63582 L .33248 .63751 L F
.32937 .63442 m .32962 .63468 L .32973 .63479 L F
.793 .7 .762 r
.32937 .63442 m .32957 .63533 L .32976 .63482 L F
.32937 .63442 m .32976 .63482 L .33128 .63082 L F
0 .029 .534 r
.32937 .63442 m .32973 .63479 L .32983 .63488 L F
.084 0 .421 r
.33166 .63201 m .33019 .63435 L .33129 .63369 L F
0 0 .051 r
.33051 .63284 m .32976 .63482 L .33121 .63321 L F
0 .029 .534 r
.32962 .63468 m .3297 .63477 L .32978 .63483 L F
.428 .738 .991 r
.32783 .63576 m .32962 .63468 L .32788 .63572 L F
0 .029 .534 r
.32978 .63483 m .33071 .63582 L .32983 .63488 L F
.3297 .63477 m .33071 .63582 L .32978 .63483 L F
.3298 .63485 m .32983 .63488 L .32921 .63706 L F
.32983 .63488 m .33248 .63751 L .32976 .63713 L F
.084 0 .421 r
.32982 .63543 m .32957 .63533 L .3298 .6359 L F
0 .029 .534 r
.32983 .63488 m .32976 .63713 L .32921 .63706 L F
.335 0 0 r
.32841 .63695 m .33248 .63751 L .33046 .63748 L F
.084 0 .421 r
.33083 .6358 m .32982 .63543 L .33046 .63748 L F
.32982 .63543 m .3298 .6359 L .33046 .63748 L F
0 0 .359 r
.3298 .6359 m .32957 .63533 L .32937 .63442 L F
0 0 .051 r
.32976 .63482 m .32957 .63533 L .32973 .63513 L F
.32976 .63482 m .32973 .63513 L .3298 .63485 L F
0 .029 .534 r
.3298 .63485 m .32921 .63706 L .32841 .63695 L F
.084 0 .421 r
.33019 .63435 m .32957 .63533 L .33129 .63369 L F
.428 .738 .991 r
.32788 .63572 m .32962 .63468 L .32937 .63442 L F
0 0 .359 r
.33046 .63748 m .3298 .6359 L .32937 .63442 L F
0 .029 .534 r
.32937 .63442 m .3298 .63485 L .32959 .63517 L F
.32937 .63442 m .32959 .63517 L .32841 .63695 L F
0 0 .051 r
.3298 .63485 m .32973 .63513 L .32989 .63492 L F
.32976 .63482 m .32989 .63492 L .33121 .63321 L F
.084 0 .421 r
.33129 .63369 m .32994 .63498 L .33083 .6358 L F
.32994 .63498 m .32957 .63533 L .33083 .6358 L F
.99 .792 .405 r
.33248 .63751 m .33166 .63201 L .33046 .63748 L F
0 0 .051 r
.33128 .63082 m .33051 .63284 L .33172 .63255 L F
.33051 .63284 m .33121 .63321 L .33172 .63255 L F
.524 .602 .874 r
.27361 .63598 m .27577 .6394 L .278 .63883 L F
.482 .15 .327 r
.3014 .54296 m .30031 .54573 L .29768 .546 L F
.294 .234 .618 r
.3027 .5397 m .3014 .54296 L .30054 .5402 L F
.3027 .5397 m .30349 .54297 L .3014 .54296 L F
.073 0 .133 r
.30237 .54403 m .3014 .54296 L .30349 .54297 L F
.30237 .54403 m .30031 .54573 L .3014 .54296 L F
.776 .705 .785 r
.28964 .52416 m .29119 .52763 L .29366 .52462 L F
.218 0 .317 r
.29656 .54829 m .29537 .54674 L .29768 .546 L F
.29656 .54829 m .29447 .54943 L .29537 .54674 L F
.221 .331 .765 r
.32303 .65952 m .32316 .6637 L .32042 .66141 L F
.32305 .6595 m .32306 .6596 L .32303 .65952 L F
.32306 .6596 m .32316 .6637 L .32303 .65952 L F
.32311 .6597 m .32316 .6637 L .32305 .6595 L F
.942 .842 .404 r
.32274 .66225 m .32316 .6637 L .32311 .65975 L F
.814 .671 .705 r
.32085 .66277 m .3233 .66023 L .32317 .65988 L F
.942 .842 .404 r
.32274 .66225 m .32311 .65975 L .32311 .65946 L F
.814 .671 .705 r
.32299 .66056 m .32274 .66225 L .3233 .66023 L F
.32085 .66277 m .32274 .66225 L .32299 .66056 L F
.32317 .65988 m .3233 .66023 L .32353 .65944 L F
0 0 0 r
.31898 .66042 m .32169 .65779 L .32308 .65942 L F
.814 .671 .705 r
.32317 .65988 m .32353 .65944 L .32293 .65909 L F
0 0 0 r
.323 .65949 m .32308 .65942 L .32311 .65946 L F
.31898 .66042 m .32308 .65942 L .323 .65949 L F
.814 .671 .705 r
.32085 .66277 m .32317 .65988 L .32286 .6596 L F
.32096 .6612 m .32286 .6596 L .32119 .65806 L F
.32085 .66277 m .32286 .6596 L .32096 .6612 L F
.32317 .65988 m .32293 .65909 L .32119 .65806 L F
.221 .331 .765 r
.32311 .65946 m .32311 .6597 L .32305 .6595 L F
.991 .755 .476 r
.31891 .66332 m .32042 .66141 L .31898 .66042 L F
.8 .947 .6 r
.31902 .65504 m .31682 .6572 L .31733 .65409 L F
.53 .393 .639 r
.32109 .65177 m .31902 .65504 L .31733 .65409 L F
.32109 .65177 m .3215 .65444 L .31902 .65504 L F
.409 .465 .807 r
.32169 .65779 m .31902 .65504 L .3215 .65444 L F
.963 .75 .568 r
.64951 .40019 m .65047 .40374 L .64867 .4023 L F
.95 .663 .46 r
.64867 .4023 m .65047 .40374 L .65036 .40579 L F
.772 .571 .626 r
.45479 .56264 m .45068 .55942 L .45349 .55907 L F
.45479 .56264 m .45088 .56249 L .45068 .55942 L F
.65 .603 .788 r
.45793 .56214 m .45479 .56264 L .45349 .55907 L F
.941 .953 .753 r
.69368 .296 m .69553 .2957 L .69459 .29705 L F
.825 .942 .902 r
.69707 .29366 m .69553 .2957 L .69628 .29278 L F
.884 .987 .81 r
.69628 .29278 m .69553 .2957 L .69368 .296 L F
.924 .54 .155 r
.60371 .4216 m .60419 .41935 L .60296 .41768 L F
.60371 .4216 m .60598 .42318 L .60419 .41935 L F
.24 0 .257 r
.28171 .56184 m .281 .56468 L .27883 .56494 L F
.368 .117 .396 r
.28448 .55911 m .28421 .56189 L .28171 .56184 L F
.416 .101 .321 r
.28332 .56413 m .28171 .56184 L .28421 .56189 L F
.28332 .56413 m .281 .56468 L .28171 .56184 L F
.446 .064 .221 r
.31772 .54833 m .31408 .54892 L .31501 .54717 L F
.923 .566 .128 r
.41772 .58802 m .41647 .5879 L .41677 .58678 L F
.41772 .58802 m .41839 .59077 L .41647 .5879 L F
.278 .138 .504 r
.35771 .52984 m .35511 .53364 L .35481 .53119 L F
.3 .218 .593 r
.36338 .52406 m .36528 .52325 L .36502 .52053 L F
.462 .873 .949 r
.28721 .51734 m .28592 .51854 L .28434 .51816 L F
.28721 .51734 m .28841 .51774 L .28592 .51854 L F
.855 .712 .703 r
.33546 .51801 m .33274 .51729 L .33313 .51381 L F
.659 .247 .252 r
.3763 .57169 m .37496 .56798 L .37734 .56991 L F
.698 .571 .709 r
.22734 .56853 m .22389 .56902 L .22644 .56579 L F
.639 .432 .586 r
.22389 .56902 m .22383 .57173 L .2259 .57149 L F
.22606 .57112 m .2259 .57149 L .22638 .57144 L F
.22389 .56902 m .2259 .57149 L .22606 .57112 L F
0 0 .226 r
.2247 .57016 m .22389 .56902 L .22734 .56853 L F
.973 .662 .321 r
.22644 .56579 m .22568 .56776 L .22734 .56853 L F
.22644 .56579 m .22568 .56776 L .22734 .56853 L F
.939 .937 .767 r
.22734 .56853 m .22568 .56776 L .22644 .56602 L F
.979 .916 .649 r
.22644 .56602 m .2247 .57016 L .22713 .56866 L F
.22727 .56834 m .22713 .56866 L .22734 .56853 L F
.22644 .56602 m .22713 .56866 L .22727 .56834 L F
0 0 .226 r
.2247 .57016 m .22383 .57173 L .22389 .56902 L F
.147 .159 .614 r
.20489 .57586 m .20711 .57684 L .20697 .57413 L F
.20489 .57586 m .20553 .57833 L .20711 .57684 L F
.777 .744 .823 r
.62883 .40543 m .63234 .40612 L .63037 .40724 L F
.261 .268 .678 r
.63316 .41001 m .63037 .40724 L .63234 .40612 L F
.163 .045 .461 r
.63316 .41001 m .63234 .40612 L .63419 .40567 L F
.952 .949 .654 r
.38884 .61622 m .38802 .62025 L .38656 .62074 L F
0 0 0 r
.28323 .63126 m .28145 .63343 L .27982 .63551 L F
.71928 .36175 m .72144 .35822 L .72083 .35972 L F
.989 .881 .545 r
.72144 .35822 m .72142 .35425 L .7226 .3559 L F
0 0 0 r
.72083 .35972 m .72144 .35822 L .7226 .3559 L F
.67 .312 .357 r
.34686 .54684 m .347 .54856 L .34442 .5464 L F
0 0 0 r
.34508 .51277 m .34481 .51283 L .34699 .51138 L F
.394 0 0 r
.38431 .54784 m .38785 .54915 L .38574 .54847 L F
0 .369 .804 r
.38431 .54784 m .38657 .54847 L .38574 .54847 L F
.988 .779 .535 r
.37988 .63792 m .38164 .63648 L .3802 .63497 L F
.963 .919 .575 r
.41543 .57498 m .41589 .57108 L .41591 .57229 L F
.957 .632 .23 r
.57468 .39635 m .57594 .39965 L .57471 .39889 L F
.88 .966 .641 r
.57594 .39965 m .57397 .40141 L .57471 .39889 L F
.632 .647 .847 r
.23906 .56795 m .23773 .56974 L .23474 .56539 L F
.606 .841 .988 r
.24596 .56545 m .24344 .56611 L .24193 .56523 L F
.741 .974 .925 r
.62249 .3853 m .62481 .38395 L .6236 .38333 L F
.448 .739 .99 r
.62481 .38395 m .62725 .38384 L .62612 .38207 L F
.602 .93 .962 r
.6236 .38333 m .62481 .38395 L .62612 .38207 L F
.204 .28 .72 r
.62481 .38395 m .62741 .38565 L .62725 .38384 L F
.62481 .38395 m .62693 .38842 L .62741 .38565 L F
.153 .171 .625 r
.37319 .59028 m .37106 .59191 L .37194 .58816 L F
0 .057 .572 r
.37216 .59268 m .37106 .59191 L .37319 .59028 L F
.957 .621 .321 r
.36518 .60312 m .36608 .60451 L .36573 .60536 L F
.36608 .60451 m .36777 .60712 L .36573 .60536 L F
.766 .63 .71 r
.36625 .60495 m .36519 .60664 L .36573 .60536 L F
.36519 .60664 m .36403 .6085 L .36573 .60536 L F
.745 .327 .257 r
.36918 .60576 m .36695 .60339 L .36664 .60408 L F
.766 .63 .71 r
.36736 .60409 m .36559 .60643 L .36625 .60495 L F
.36559 .60643 m .36403 .6085 L .36625 .60495 L F
.745 .327 .257 r
.36918 .60576 m .37156 .60409 L .36695 .60339 L F
.36664 .60408 m .36695 .60339 L .36518 .60312 L F
.828 .868 .875 r
.33344 .49641 m .3314 .49876 L .32998 .49716 L F
.655 .111 0 r
.3314 .49876 m .33115 .49982 L .32998 .49716 L F
.3314 .49876 m .33364 .50068 L .33115 .49982 L F
.675 .665 .833 r
.37627 .59744 m .38004 .59833 L .37798 .59673 L F
.424 .129 .358 r
.46685 .57214 m .4663 .57433 L .46379 .57493 L F
.37 .081 .338 r
.46846 .57363 m .46685 .57214 L .46918 .57148 L F
.46846 .57363 m .4663 .57433 L .46685 .57214 L F
.909 .841 .766 r
.3902 .62215 m .39395 .61973 L .39297 .61921 L F
.3902 .62215 m .39214 .62291 L .39395 .61973 L F
.968 .676 .267 r
.39297 .61921 m .39395 .61973 L .39278 .61648 L F
.763 .688 .78 r
.39349 .61846 m .39386 .61654 L .39278 .61648 L F
.764 .683 .772 r
.39462 .61468 m .39677 .6167 L .39565 .61393 L F
.39464 .61465 m .39565 .61393 L .39527 .61301 L F
.39462 .61468 m .39565 .61393 L .39464 .61465 L F
0 0 0 r
.39464 .61465 m .39428 .61491 L .39422 .61495 L F
.39464 .61465 m .39422 .61495 L .39527 .61301 L F
.538 .309 .516 r
.3941 .61533 m .39278 .61648 L .39422 .61495 L F
.764 .683 .772 r
.39319 .61613 m .39386 .61654 L .3941 .61533 L F
.39278 .61648 m .39287 .61648 L .39319 .61613 L F
.39287 .61648 m .39386 .61654 L .39319 .61613 L F
.538 .309 .516 r
.39297 .61921 m .39278 .61648 L .3941 .61533 L F
.3941 .61533 m .3942 .61501 L .39416 .61504 L F
.3942 .61501 m .39422 .61495 L .39416 .61504 L F
.764 .683 .772 r
.39386 .61654 m .39677 .6167 L .39455 .61461 L F
0 0 0 r
.39422 .61495 m .39428 .61491 L .39416 .61504 L F
.764 .683 .772 r
.39416 .61504 m .39455 .61461 L .39429 .61437 L F
.39386 .61654 m .39455 .61461 L .39416 .61504 L F
.39278 .61648 m .3941 .61533 L .39429 .61437 L F
.538 .309 .516 r
.39409 .61539 m .3941 .61533 L .39415 .61505 L F
.3941 .61533 m .39416 .61504 L .39415 .61505 L F
.39297 .61921 m .39409 .61539 L .39295 .61703 L F
.39409 .61539 m .39415 .61505 L .39295 .61703 L F
.766 .683 .772 r
.39549 .61355 m .39565 .61393 L .3959 .61309 L F
.39565 .61393 m .39677 .6167 L .39603 .61366 L F
.39565 .61393 m .39603 .61366 L .3959 .61309 L F
0 0 0 r
.39464 .61465 m .39428 .61491 L .39464 .61465 L F
.766 .683 .772 r
.39527 .61301 m .39751 .61331 L .39773 .61246 L F
.39751 .61331 m .39937 .61356 L .39773 .61246 L F
0 0 .323 r
.39773 .61246 m .39783 .60977 L .39927 .60843 L F
.794 .975 .686 r
.3983 .61064 m .39817 .6108 L .39773 .61246 L F
0 0 0 r
.39773 .61246 m .39573 .61391 L .39428 .6149 L F
.766 .683 .772 r
.3959 .61309 m .39603 .61366 L .39668 .6132 L F
.39527 .61301 m .39549 .61355 L .3959 .61309 L F
0 0 0 r
.39773 .61246 m .39464 .61465 L .39527 .61301 L F
.39783 .60977 m .39527 .61301 L .39773 .61246 L F
.827 .574 .556 r
.39444 .60973 m .39773 .61246 L .39527 .61301 L F
.39444 .60973 m .39783 .60977 L .39773 .61246 L F
.794 .975 .686 r
.39817 .6108 m .39573 .61391 L .39773 .61246 L F
0 0 0 r
.39773 .61246 m .39429 .6149 L .39464 .61465 L F
.39429 .6149 m .39428 .61491 L .39464 .61465 L F
.39429 .6149 m .39428 .6149 L .39428 .61491 L F
.39773 .61246 m .39428 .6149 L .39429 .6149 L F
.766 .683 .772 r
.39668 .6132 m .39677 .6167 L .39937 .61356 L F
.39603 .61366 m .39677 .6167 L .39668 .6132 L F
0 0 0 r
.39416 .61504 m .39573 .61391 L .39295 .61703 L F
.39416 .61504 m .39416 .61504 L .39416 .61504 L F
.39416 .61504 m .39573 .61391 L .39416 .61504 L F
.39428 .61491 m .39573 .61391 L .39416 .61504 L F
.764 .683 .772 r
.39429 .61437 m .39462 .61468 L .39527 .61301 L F
.763 .688 .78 r
.39395 .61973 m .39677 .6167 L .39386 .61654 L F
.39395 .61973 m .39386 .61654 L .39349 .61846 L F
.61 .913 .98 r
.29209 .51723 m .28841 .51774 L .29047 .51633 L F
.657 .868 .979 r
.29444 .51607 m .29209 .51723 L .29047 .51633 L F
.696 .701 .851 r
.62038 .36721 m .6244 .36799 L .62187 .36916 L F
.882 .684 .631 r
.54198 .44474 m .53835 .4439 L .54023 .44097 L F
.829 .516 .461 r
.54198 .44474 m .54016 .44687 L .53835 .4439 L F
.54198 .44474 m .54224 .4471 L .54016 .44687 L F
0 0 0 r
.72083 .35972 m .71876 .36328 L .71928 .36175 L F
.31778 .67067 m .32215 .66821 L .32021 .6699 L F
.762 .955 .64 r
.32021 .6699 m .32215 .66821 L .3228 .66634 L F
.801 .81 .858 r
.35588 .53526 m .35677 .53769 L .36072 .53244 L F
.35471 .53594 m .36072 .53244 L .35511 .53364 L F
.434 .184 .433 r
.35677 .53521 m .3562 .53467 L .35712 .53334 L F
.3562 .53467 m .35511 .53364 L .35688 .53338 L F
.3562 .53467 m .35688 .53338 L .35712 .53334 L F
.801 .81 .858 r
.35471 .53594 m .35527 .53642 L .35588 .53526 L F
.35527 .53642 m .35677 .53769 L .35588 .53526 L F
.957 .697 .499 r
.35471 .53594 m .35492 .53891 L .35677 .53769 L F
.774 .696 .777 r
.6413 .35493 m .64253 .35876 L .63867 .35814 L F
.757 .568 .641 r
.64253 .35876 m .64017 .36131 L .63867 .35814 L F
.64253 .35876 m .64185 .36134 L .64017 .36131 L F
.593 .296 .434 r
.44646 .58737 m .44324 .59042 L .44364 .5885 L F
.622 .309 .419 r
.27883 .56494 m .27842 .56812 L .27565 .56775 L F
.382 .106 .366 r
.28069 .56737 m .27883 .56494 L .281 .56468 L F
.28069 .56737 m .27842 .56812 L .27883 .56494 L F
.281 0 .292 r
.69346 .35148 m .69107 .35256 L .69062 .35441 L F
.516 .542 .822 r
.30129 .53592 m .30054 .5402 L .29874 .53916 L F
.30129 .53592 m .3027 .5397 L .30054 .5402 L F
.31 0 0 r
.27368 .62297 m .27827 .62447 L .27534 .62288 L F
.604 .163 .174 r
.27534 .62288 m .27827 .62447 L .27827 .62335 L F
.71 .679 .818 r
.42125 .48611 m .42261 .48972 L .41849 .48908 L F
.435 .727 .987 r
.62288 .45089 m .62432 .44934 L .62165 .44973 L F
.62288 .45089 m .62563 .45084 L .62432 .44934 L F
.976 .915 .667 r
.31566 .50778 m .31782 .50404 L .31694 .5037 L F
.404 .725 .989 r
.33147 .69829 m .33523 .69942 L .3335 .69788 L F
.696 .262 .215 r
.33753 .70182 m .33523 .69942 L .33623 .70074 L F
.894 .64 .127 r
.40384 .66995 m .40461 .67369 L .40442 .67118 L F
.744 .945 .624 r
.39448 .69931 m .39721 .69583 L .39503 .69758 L F
.824 .981 .696 r
.39721 .69583 m .39656 .69565 L .39503 .69758 L F
0 .269 .682 r
.3824 .51987 m .38308 .52047 L .38059 .51739 L F
.3824 .51987 m .38419 .52101 L .38308 .52047 L F
.738 .7 .815 r
.42146 .55224 m .42378 .5484 L .4223 .55002 L F
.94 .965 .706 r
.62472 .38895 m .62474 .3911 L .62241 .39317 L F
0 0 .552 r
.6262 .39346 m .62474 .3911 L .62472 .38895 L F
0 0 .088 r
.35809 .67305 m .35702 .67742 L .35943 .67682 L F
.588 .888 .991 r
.62072 .38426 m .62216 .38243 L .62089 .38332 L F
.705 .622 .762 r
.61809 .38409 m .62062 .38479 L .62072 .38426 L F
0 .562 .746 r
.61698 .38394 m .61809 .38409 L .62072 .38426 L F
.61698 .38394 m .6203 .38423 L .61927 .38446 L F
.6203 .38423 m .62072 .38426 L .61927 .38446 L F
.368 0 0 r
.61561 .38485 m .61698 .38394 L .61927 .38446 L F
.08 0 0 r
.61561 .38485 m .61927 .38446 L .61773 .38502 L F
.81 .984 .713 r
.61801 .38475 m .61927 .38446 L .61953 .38331 L F
.61773 .38502 m .61927 .38446 L .61801 .38475 L F
.588 .888 .991 r
.62072 .38426 m .62089 .38332 L .61927 .38446 L F
.705 .622 .762 r
.62062 .38479 m .62249 .3853 L .62072 .38426 L F
.741 .974 .925 r
.62249 .3853 m .6236 .38333 L .62072 .38426 L F
0 .352 .827 r
.37548 .59529 m .37629 .59473 L .37391 .59625 L F
.959 .651 .4 r
.37548 .59529 m .37627 .59744 L .37391 .59625 L F
.58 .845 .995 r
.32355 .61941 m .32669 .61933 L .32756 .61715 L F
.055 0 .215 r
.32669 .61933 m .32756 .61715 L .32907 .61563 L F
.32669 .61933 m .32756 .61715 L .32907 .61563 L F
.817 .569 .565 r
.2896 .65464 m .2925 .65692 L .29115 .65735 L F
.582 .897 .629 r
.2925 .65692 m .2937 .6574 L .29115 .65735 L F
.2925 .65692 m .2949 .65466 L .2937 .6574 L F
.319 .794 .707 r
.36941 .71398 m .37451 .71203 L .37075 .71305 L F
0 0 .024 r
.40031 .4986 m .40202 .49422 L .40148 .49739 L F
0 0 0 r
.22193 .54625 m .22373 .54272 L .22399 .54238 L F
.22193 .54625 m .22287 .54503 L .22373 .54272 L F
.22193 .54625 m .22044 .54834 L .22287 .54503 L F
.21 0 .283 r
.67362 .381 m .67639 .37758 L .67547 .37956 L F
.573 .423 .639 r
.67547 .37956 m .67403 .38387 L .67362 .381 L F
.068 0 0 r
.26122 .54261 m .26255 .54291 L .26344 .5421 L F
.26122 .54261 m .25876 .54463 L .26255 .54291 L F
.75 .318 .225 r
.22263 .56482 m .22568 .56776 L .22644 .56579 L F
.766 .687 .775 r
.57456 .41836 m .57942 .41939 L .57807 .41561 L F
.366 .385 .748 r
.5748 .42272 m .57892 .42315 L .57775 .42079 L F
.828 .379 0 r
.57817 .42212 m .57775 .42079 L .57892 .42315 L F
.707 .243 .145 r
.57775 .42079 m .57456 .41836 L .5748 .42272 L F
.828 .379 0 r
.57631 .41955 m .57775 .42079 L .57817 .42212 L F
.707 .243 .145 r
.57775 .42079 m .57942 .41939 L .57716 .41891 L F
.57775 .42079 m .57716 .41891 L .57456 .41836 L F
.565 .575 .822 r
.57807 .41561 m .57942 .41939 L .58204 .41872 L F
.087 0 0 r
.58204 .41872 m .57942 .41939 L .57775 .42079 L F
.438 .871 .783 r
.72036 .33577 m .72169 .33493 L .72368 .33397 L F
.726 .938 .617 r
.38355 .62224 m .38368 .62249 L .38123 .62527 L F
.053 0 .33 r
.31408 .54892 m .31242 .55244 L .31278 .54992 L F
.755 .607 .693 r
.70406 .30433 m .70449 .30788 L .70038 .30764 L F
.414 .361 .689 r
.70524 .30087 m .70629 .30307 L .70406 .30433 L F
.706 .68 .823 r
.70629 .30307 m .70449 .30788 L .70406 .30433 L F
.763 .976 .919 r
.34835 .69011 m .34389 .69142 L .34654 .68859 L F
.382 0 .104 r
.36785 .53357 m .36401 .53566 L .36547 .53427 L F
.269 0 .288 r
.42278 .51088 m .41993 .51385 L .42052 .51185 L F
.42052 .51185 m .41993 .51385 L .42278 .51088 L F
.519 .293 .511 r
.36515 .5751 m .36624 .57897 L .36174 .5795 L F
.642 .365 .483 r
.36739 .57771 m .36515 .5751 L .36778 .57538 L F
.36739 .57771 m .36624 .57897 L .36515 .5751 L F
.564 .743 .96 r
.37575 .57527 m .37802 .57552 L .37547 .57569 L F
.611 .829 .436 r
.37547 .57569 m .37388 .57789 L .37575 .57527 L F
.648 .967 .89 r
.38614 .55052 m .38404 .55133 L .38785 .54915 L F
.271 .73 .953 r
.6085 .37179 m .61178 .37179 L .61028 .37094 L F
.05 .233 .731 r
.6085 .37179 m .61128 .37446 L .61178 .37179 L F
.391 .119 .376 r
.38314 .60066 m .38571 .6001 L .3861 .59761 L F
.562 .265 .422 r
.3861 .59761 m .38571 .6001 L .38831 .59969 L F
.507 .357 .612 r
.45139 .54973 m .45165 .55263 L .44895 .55328 L F
.591 .519 .742 r
.45165 .55263 m .44993 .55592 L .44895 .55328 L F
.669 .238 0 r
.33298 .69206 m .33386 .69323 L .33176 .69003 L F
.689 .691 .846 r
.31599 .62634 m .31843 .62512 L .31793 .62295 L F
.591 .315 .466 r
.32874 .52652 m .33224 .52699 L .33076 .52429 L F
.652 .452 .6 r
.32779 .52977 m .33 .52967 L .32874 .52652 L F
0 .09 .607 r
.32874 .52652 m .33 .52967 L .3311 .52665 L F
0 0 0 r
.32779 .52977 m .32771 .53074 L .33 .52967 L F
.827 .995 .758 r
.33025 .529 m .32771 .53074 L .3311 .52665 L F
.33 .52967 m .3292 .53005 L .33025 .529 L F
.3292 .53005 m .32771 .53074 L .33025 .529 L F
.591 .315 .466 r
.33224 .52699 m .33292 .52709 L .33259 .52665 L F
.33224 .52699 m .33259 .52665 L .33076 .52429 L F
.494 .294 .537 r
.35126 .63865 m .35387 .63556 L .35111 .63586 L F
.741 .597 .696 r
.53841 .41447 m .53902 .41582 L .53513 .41553 L F
.581 .086 .045 r
.53513 .41553 m .53902 .41582 L .53776 .4172 L F
.814 .438 0 r
.53826 .41487 m .53902 .41582 L .53841 .41447 L F
.99 .856 .496 r
.53776 .4172 m .53902 .41582 L .53826 .41487 L F
.649 .715 .896 r
.69152 .32922 m .69302 .33218 L .69627 .33049 L F
0 0 .347 r
.60077 .41395 m .60042 .41337 L .59964 .41275 L F
.60077 .41395 m .60161 .41566 L .60042 .41337 L F
.53 .329 .553 r
.39049 .59274 m .38864 .59444 L .39157 .59361 L F
.701 .706 .852 r
.40031 .4986 m .39788 .5015 L .39623 .49783 L F
.621 .582 .788 r
.40031 .4986 m .40273 .50294 L .39788 .5015 L F
0 0 0 r
.26677 .57168 m .26267 .57316 L .26428 .57201 L F
.065 0 0 r
.38953 .50003 m .39375 .49915 L .39116 .50083 L F
.259 0 .175 r
.29388 .63253 m .29693 .62995 L .29569 .63177 L F
.2 0 .031 r
.29569 .63177 m .29693 .62995 L .29913 .62922 L F
.519 .594 .869 r
.54018 .42267 m .53618 .41976 L .53972 .42111 L F
.195 .628 .947 r
.54123 .42192 m .54018 .42267 L .53972 .42111 L F
.54123 .42192 m .54379 .42317 L .54018 .42267 L F
.868 .588 .061 r
.4149 .56595 m .41536 .56859 L .41433 .56476 L F
.968 .808 .63 r
.69926 .33358 m .6968 .33407 L .69892 .33139 L F
.69926 .33358 m .69872 .33602 L .6968 .33407 L F
.348 .409 .783 r
.70277 .33462 m .69926 .33358 L .70311 .33242 L F
.963 .919 .575 r
.41543 .57498 m .41441 .57454 L .41589 .57108 L F
.702 .485 0 r
.41543 .57498 m .41565 .57642 L .41441 .57454 L F
.41543 .57498 m .41587 .57781 L .41565 .57642 L F
.494 .826 .53 r
.32893 .58115 m .32984 .58026 L .33207 .57823 L F
.641 .192 .169 r
.33207 .57823 m .33384 .58014 L .33465 .57768 L F
.33207 .57823 m .32984 .58026 L .33384 .58014 L F
.794 .692 .752 r
.53819 .41178 m .53841 .41447 L .53534 .41398 L F
.741 .597 .696 r
.53841 .41447 m .53513 .41553 L .53534 .41398 L F
.748 .944 .618 r
.54016 .40904 m .53819 .41178 L .53849 .41117 L F
.54016 .40904 m .53819 .41178 L .53849 .41117 L F
0 .054 .572 r
.53849 .41117 m .53841 .41447 L .53819 .41178 L F
.814 .438 0 r
.53826 .41487 m .53841 .41447 L .53849 .41117 L F
0 .054 .593 r
.40243 .65443 m .40344 .65669 L .4025 .65814 L F
0 0 0 r
.40282 .65924 m .40439 .65802 L .40311 .6596 L F
.40282 .65924 m .40311 .6596 L .40203 .66092 L F
0 0 .001 r
.40244 .65876 m .40282 .65924 L .40222 .66092 L F
.4025 .65814 m .40282 .65924 L .40244 .65876 L F
.4025 .65814 m .40344 .65669 L .40282 .65924 L F
0 0 0 r
.38967 .65313 m .38805 .65481 L .3906 .65091 L F
.38967 .65313 m .3906 .65091 L .38892 .65058 L F
.448 .194 .435 r
.32701 .55578 m .32952 .55545 L .33021 .5531 L F
0 0 .034 r
.21641 .55277 m .21788 .55153 L .21858 .54942 L F
.048 0 .221 r
.21641 .55277 m .21766 .5542 L .21788 .55153 L F
.21641 .55277 m .21621 .5551 L .21766 .5542 L F
.755 .614 .702 r
.43242 .55619 m .43388 .55936 L .43667 .55726 L F
.842 .902 .88 r
.43911 .55344 m .43667 .55726 L .43796 .55382 L F
.684 .663 .823 r
.43911 .55344 m .44057 .55659 L .43667 .55726 L F
.376 0 0 r
.43667 .55726 m .43713 .55718 L .43935 .55791 L F
.43713 .55718 m .44057 .55659 L .43935 .55791 L F
.07 .373 .839 r
.43935 .55791 m .44172 .5595 L .44107 .55847 L F
.43935 .55791 m .44107 .55847 L .43974 .55637 L F
.315 .31 .695 r
.43667 .55726 m .43935 .55791 L .43796 .55382 L F
.571 .334 .517 r
.30141 .60693 m .30433 .60653 L .30456 .60394 L F
.402 .24 .544 r
.30456 .60394 m .30666 .60334 L .30681 .60045 L F
.342 .131 .441 r
.30433 .60653 m .30666 .60334 L .30456 .60394 L F
.897 .853 .791 r
.62558 .43488 m .62379 .43784 L .62638 .43643 L F
.921 .83 .739 r
.62277 .4403 m .62638 .43643 L .62379 .43784 L F
.62277 .4403 m .62443 .44152 L .62638 .43643 L F
.758 .811 .895 r
.62558 .43488 m .62638 .43643 L .62922 .43507 L F
.581 .808 .986 r
.72287 .34083 m .72163 .34467 L .72091 .34385 L F
.72287 .34083 m .72427 .34318 L .72163 .34467 L F
.554 .917 .952 r
.72091 .34385 m .72427 .34318 L .72287 .34083 L F
.72427 .34318 m .72526 .34299 L .72287 .34083 L F
.581 .808 .986 r
.72287 .34083 m .72451 .34305 L .72427 .34318 L F
.554 .917 .952 r
.72427 .34318 m .72163 .34467 L .7246 .34329 L F
.72454 .34313 m .7246 .34329 L .72526 .34299 L F
.72427 .34318 m .7246 .34329 L .72454 .34313 L F
.41 .588 .915 r
.72499 .34585 m .72163 .34467 L .72506 .34379 L F
.72163 .34467 m .72499 .34585 L .72518 .34386 L F
.7246 .34329 m .72518 .34386 L .72526 .34299 L F
0 .14 .657 r
.72536 .34403 m .72506 .34379 L .72491 .34359 L F
.41 .588 .915 r
.72163 .34467 m .72491 .34359 L .7246 .34329 L F
.581 .808 .986 r
.72451 .34305 m .72491 .34359 L .72163 .34467 L F
.72491 .34359 m .72506 .34379 L .72163 .34467 L F
.41 .588 .915 r
.72163 .34467 m .72518 .34386 L .72491 .34359 L F
.593 .106 .067 r
.72597 .34408 m .72774 .34461 L .72596 .34407 L F
.586 .513 .739 r
.7259 .34406 m .72774 .34461 L .72734 .34123 L F
.72499 .34585 m .72774 .34461 L .7259 .34406 L F
.215 0 .079 r
.72781 .34599 m .72774 .34461 L .72499 .34585 L F
.593 .106 .067 r
.72781 .34599 m .72774 .34461 L .72597 .34408 L F
.72531 .34399 m .72596 .34407 L .72506 .34379 L F
.586 .513 .739 r
.72499 .34585 m .7259 .34406 L .72531 .34399 L F
.593 .106 .067 r
.72781 .34599 m .72596 .34407 L .72531 .34399 L F
.586 .513 .739 r
.72531 .34399 m .72734 .34123 L .72552 .34277 L F
.7259 .34406 m .72734 .34123 L .72531 .34399 L F
.215 0 .079 r
.72531 .34399 m .72499 .34585 L .72506 .34379 L F
.586 .513 .739 r
.72499 .34585 m .72552 .34277 L .72526 .34299 L F
.215 0 .079 r
.72781 .34599 m .72499 .34585 L .72531 .34399 L F
0 .14 .657 r
.72781 .34599 m .72536 .34403 L .72451 .34305 L F
.72536 .34403 m .72491 .34359 L .72451 .34305 L F
.72416 .34219 m .72451 .34305 L .72287 .34083 L F
.72781 .34599 m .72451 .34305 L .72416 .34219 L F
.554 .917 .952 r
.72091 .34385 m .72163 .34467 L .72427 .34318 L F
0 0 0 r
.7083 .29501 m .70775 .29657 L .70618 .2983 L F
0 0 .078 r
.7083 .29501 m .70976 .29032 L .7099 .29286 L F
0 0 0 r
.70898 .2941 m .7083 .29501 L .7099 .29286 L F
.70898 .2941 m .70775 .29657 L .7083 .29501 L F
.491 .255 .483 r
.45217 .58158 m .45196 .58407 L .44939 .58457 L F
.465 .237 .482 r
.45463 .581 m .45196 .58407 L .45217 .58158 L F
.88 .707 .663 r
.3763 .57169 m .37267 .57402 L .37349 .5724 L F
.3763 .57169 m .37575 .57527 L .37267 .57402 L F
.697 .529 .657 r
.3763 .57169 m .37802 .57552 L .37575 .57527 L F
.689 .525 .66 r
.38094 .57394 m .3763 .57169 L .38 .57121 L F
.38094 .57394 m .37802 .57552 L .3763 .57169 L F
.278 0 0 r
.38427 .70165 m .38874 .70326 L .38621 .70242 L F
.38427 .70165 m .38621 .70242 L .38498 .70064 L F
.509 .835 .999 r
.38874 .70326 m .38715 .70192 L .38621 .70242 L F
.278 0 0 r
.38621 .70242 m .3868 .70265 L .38647 .70229 L F
.38621 .70242 m .38647 .70229 L .38498 .70064 L F
.509 .835 .999 r
.38874 .70326 m .38986 .70142 L .38715 .70192 L F
.775 .862 .914 r
.38225 .70265 m .38427 .70165 L .38498 .70064 L F
.474 .852 .628 r
.38225 .70265 m .38359 .70166 L .38384 .70136 L F
.38359 .70166 m .38498 .70064 L .38384 .70136 L F
.669 .152 0 r
.38498 .70064 m .38647 .70229 L .38384 .70136 L F
.372 .777 .983 r
.38384 .70136 m .38693 .70117 L .38595 .7008 L F
.38393 .70084 m .38595 .7008 L .38407 .7001 L F
.38384 .70136 m .38595 .7008 L .38393 .70084 L F
.509 .835 .999 r
.38621 .70242 m .38647 .70229 L .38571 .70222 L F
.38566 .70224 m .38571 .70222 L .38558 .70221 L F
.38621 .70242 m .38571 .70222 L .38566 .70224 L F
.669 .152 0 r
.38647 .70229 m .38577 .7022 L .38384 .70136 L F
.579 .6 .838 r
.38384 .70136 m .38577 .7022 L .38693 .70117 L F
.509 .835 .999 r
.38647 .70229 m .38568 .70219 L .38558 .70221 L F
.669 .152 0 r
.38647 .70229 m .3868 .70265 L .38577 .7022 L F
.509 .835 .999 r
.38647 .70229 m .38715 .70192 L .38568 .70219 L F
.485 .828 .998 r
.38407 .7001 m .38693 .70117 L .3881 .70037 L F
.596 .843 .991 r
.38441 .70242 m .38597 .70214 L .3881 .70037 L F
.233 .281 .707 r
.38693 .70117 m .38688 .70177 L .3881 .70037 L F
.596 .843 .991 r
.38688 .70177 m .38986 .70142 L .389 .70091 L F
.38667 .70201 m .38986 .70142 L .38688 .70177 L F
.579 .6 .838 r
.38577 .7022 m .38687 .70185 L .38693 .70117 L F
.596 .843 .991 r
.38597 .70214 m .389 .70091 L .3881 .70037 L F
.233 .281 .707 r
.38688 .70177 m .3868 .70265 L .3881 .70037 L F
.596 .843 .991 r
.38597 .70214 m .38667 .70201 L .38688 .70177 L F
.579 .6 .838 r
.38597 .70214 m .3868 .70265 L .38687 .70185 L F
.38577 .7022 m .38579 .70221 L .38597 .70214 L F
.38579 .70221 m .3868 .70265 L .38597 .70214 L F
.596 .843 .991 r
.38441 .70242 m .38737 .70078 L .3868 .70265 L F
.38737 .70078 m .3881 .70037 L .38787 .70077 L F
.38737 .70078 m .38787 .70077 L .3868 .70265 L F
0 0 .249 r
.38415 .70096 m .38384 .70136 L .38407 .7001 L F
.38438 .7036 m .38384 .70136 L .38415 .70096 L F
.509 .835 .999 r
.38874 .70326 m .38558 .70221 L .38441 .70242 L F
.278 0 0 r
.38621 .70242 m .38874 .70326 L .3868 .70265 L F
.094 .635 .851 r
.3868 .70265 m .38874 .70326 L .38441 .70242 L F
.509 .835 .999 r
.38874 .70326 m .39155 .70245 L .38986 .70142 L F
.253 .741 .921 r
.37275 .60599 m .37695 .60625 L .37575 .60656 L F
.77 .384 .325 r
.42001 .59674 m .42003 .59792 L .41966 .59703 L F
.41998 .59424 m .42112 .59672 L .42003 .59792 L F
.932 .57 .307 r
.41801 .59305 m .42003 .59792 L .41736 .59612 L F
.926 .552 .279 r
.41736 .59612 m .42003 .59792 L .41803 .59811 L F
.993 .83 .574 r
.42003 .59792 m .42112 .59672 L .41803 .59811 L F
.287 0 .168 r
.42112 .59672 m .42275 .59878 L .41832 .59815 L F
.41876 .59779 m .41832 .59815 L .41803 .59811 L F
.42112 .59672 m .41832 .59815 L .41876 .59779 L F
.77 .384 .325 r
.41998 .59424 m .42001 .59674 L .41801 .59305 L F
.42001 .59674 m .41966 .59703 L .41801 .59305 L F
.903 .822 .757 r
.42767 .53335 m .42621 .5367 L .42726 .53506 L F
.429 0 .025 r
.21338 .59877 m .21224 .60007 L .20957 .60012 L F
.563 .1 .112 r
.21338 .59877 m .21647 .59961 L .21224 .60007 L F
.531 .004 0 r
.70449 .30788 m .70336 .30898 L .70038 .30764 L F
.706 .68 .823 r
.70629 .30307 m .70795 .30626 L .70449 .30788 L F
.622 .107 .002 r
.70449 .30788 m .70727 .30957 L .70336 .30898 L F
.335 .162 .492 r
.31548 .57838 m .3175 .5778 L .31754 .57504 L F
.398 .322 .654 r
.31548 .57838 m .3179 .58068 L .3175 .5778 L F
.31548 .57838 m .31608 .5816 L .3179 .58068 L F
.641 .555 .742 r
.45349 .55907 m .45068 .55942 L .44993 .55592 L F
0 0 0 r
.38315 .56902 m .38134 .57037 L .38 .57121 L F
.66 .447 .585 r
.38495 .56776 m .38134 .57037 L .38315 .56902 L F
.609 .606 .824 r
.43775 .56233 m .43935 .55791 L .43727 .55989 L F
0 0 0 r
.37518 .54765 m .37508 .54735 L .37756 .54676 L F
.37518 .54765 m .37419 .54921 L .37508 .54735 L F
.889 .961 .836 r
.6207 .3951 m .6236 .39396 L .62241 .39317 L F
.349 .401 .774 r
.6236 .39396 m .62632 .39534 L .6262 .39346 L F
.326 .253 .619 r
.20545 .59495 m .20717 .59008 L .20495 .59205 L F
.42 .185 .448 r
.33252 .57367 m .33051 .57207 L .33282 .57104 L F
.33252 .57367 m .33019 .57445 L .33051 .57207 L F
.491 .681 .95 r
.34063 .70884 m .34199 .70701 L .33882 .70555 L F
.34063 .70884 m .34301 .7086 L .34199 .70701 L F
.773 .783 .861 r
.63242 .36072 m .63342 .36428 L .63111 .36548 L F
.737 .763 .874 r
.63633 .36134 m .63342 .36428 L .63242 .36072 L F
.778 .707 .785 r
.63111 .36548 m .62701 .36541 L .6294 .36399 L F
.773 .783 .861 r
.63242 .36072 m .63111 .36548 L .6294 .36399 L F
.502 .317 .562 r
.71508 .32686 m .7153 .32935 L .71827 .32637 L F
.776 .705 .785 r
.28964 .52416 m .29366 .52462 L .29211 .52298 L F
.55 .751 .97 r
.29211 .52298 m .29366 .52462 L .29443 .52249 L F
.439 .245 .518 r
.29598 .52135 m .29589 .52435 L .29366 .52462 L F
.459 .65 .941 r
.29366 .52462 m .29589 .52435 L .29443 .52249 L F
.642 .085 0 r
.42783 .5911 m .4302 .59328 L .42815 .59239 L F
.884 .87 .818 r
.63448 .42879 m .63204 .43242 L .63052 .43057 L F
.596 .788 .972 r
.63052 .43057 m .63204 .43242 L .63458 .43128 L F
.602 .428 .618 r
.67931 .37695 m .67547 .37956 L .67639 .37758 L F
.595 .856 .993 r
.62563 .45084 m .62939 .45096 L .62819 .44985 L F
.778 .919 .932 r
.62819 .44985 m .62939 .45096 L .63126 .44902 L F
.183 .254 .703 r
.38384 .70136 m .38478 .70526 L .38225 .70265 L F
.953 .885 .488 r
.38415 .70456 m .38478 .70526 L .38438 .7036 L F
.872 .993 .804 r
.38214 .70832 m .38528 .70583 L .38478 .70526 L F
0 0 0 r
.38214 .70832 m .38478 .70526 L .3835 .70727 L F
.953 .885 .488 r
.3835 .70727 m .38478 .70526 L .38415 .70456 L F
.872 .993 .804 r
.38528 .70583 m .38586 .70537 L .38478 .70526 L F
.492 .249 .473 r
.27457 .52946 m .27429 .53269 L .27166 .53323 L F
.68 .584 .741 r
.27647 .52923 m .27457 .52946 L .27442 .5263 L F
.383 .085 .331 r
.27647 .52923 m .27429 .53269 L .27457 .52946 L F
.838 .883 .451 r
.29969 .51657 m .30007 .51681 L .30152 .51316 L F
.778 .276 0 r
.30152 .51316 m .30201 .51564 L .29969 .51657 L F
.386 .847 .82 r
.29935 .51634 m .29969 .51657 L .30201 .51564 L F
.29763 .5168 m .29969 .51657 L .29935 .51634 L F
.838 .883 .451 r
.29969 .51657 m .29948 .51829 L .30007 .51681 L F
.778 .276 0 r
.30152 .51316 m .30271 .51491 L .30201 .51564 L F
0 0 0 r
.33313 .51381 m .3362 .51083 L .334 .51158 L F
.965 .668 .254 r
.71329 .35102 m .71431 .35247 L .71306 .34844 L F
.99 .733 .376 r
.71322 .35385 m .71431 .35247 L .71329 .35102 L F
.71322 .35385 m .71446 .3556 L .71431 .35247 L F
.612 .707 .912 r
.71431 .35247 m .71761 .35161 L .71363 .35013 L F
.965 .668 .254 r
.71329 .35102 m .71431 .35247 L .71306 .34844 L F
0 0 .2 r
.30214 .63506 m .30261 .63737 L .30368 .63598 L F
.59 .932 .95 r
.61926 .39271 m .61703 .39397 L .61563 .39371 L F
.573 .917 .966 r
.42694 .56145 m .42579 .56078 L .42457 .56261 L F
.42457 .56261 m .42579 .56078 L .42694 .56145 L F
.217 .363 .797 r
.2333 .61425 m .2358 .61575 L .23438 .6139 L F
.887 .9 .832 r
.22915 .55317 m .22747 .55632 L .23012 .55289 L F
.408 .285 .6 r
.22915 .55317 m .22976 .55836 L .22747 .55632 L F
.62 .223 .27 r
.24906 .62448 m .25002 .62479 L .24771 .6241 L F
.24906 .62448 m .25179 .6256 L .25002 .62479 L F
.852 .755 .755 r
.68071 .33591 m .68398 .33631 L .68285 .33255 L F
.843 .777 .788 r
.68155 .33955 m .68398 .33631 L .68071 .33591 L F
.782 .719 .794 r
.68285 .33255 m .68398 .33631 L .68658 .33307 L F
.592 .297 .438 r
.25236 .56826 m .25504 .56839 L .25657 .56536 L F
.601 .308 .443 r
.25657 .56536 m .25843 .56772 L .25895 .56554 L F
.25657 .56536 m .25504 .56839 L .25843 .56772 L F
.534 .508 .773 r
.44051 .50138 m .43818 .50213 L .43704 .49836 L F
.47 .318 .592 r
.44051 .50138 m .44064 .50413 L .43818 .50213 L F
.318 .321 .705 r
.43818 .50213 m .44064 .50413 L .43899 .50461 L F
.553 .273 .446 r
.28557 .53613 m .28845 .53343 L .2858 .53381 L F
.518 .336 .574 r
.22588 .58153 m .22638 .58627 L .22391 .5864 L F
.338 .16 .487 r
.22801 .5785 m .22744 .58156 L .22588 .58153 L F
.289 .162 .527 r
.22744 .58156 m .22638 .58627 L .22588 .58153 L F
.442 .35 .656 r
.35167 .5441 m .35184 .54684 L .35371 .5455 L F
0 0 .215 r
.34255 .53213 m .34187 .53606 L .3434 .53318 L F
.747 .763 .866 r
.34187 .53606 m .34512 .53405 L .3434 .53318 L F
.674 .385 .475 r
.33882 .53924 m .33518 .5419 L .33689 .54026 L F
.853 .93 .877 r
.67978 .31717 m .67576 .31896 L .6783 .31555 L F
.091 0 .381 r
.28888 .639 m .29042 .63535 L .29036 .63814 L F
.196 .066 .466 r
.28897 .64139 m .28888 .639 L .29036 .63814 L F
.954 .917 .738 r
.68671 .30716 m .68395 .30946 L .68655 .30606 L F
.68671 .30716 m .68498 .31073 L .68395 .30946 L F
.599 .212 .281 r
.3072 .55618 m .3094 .55807 L .30708 .55754 L F
.53 .236 .412 r
.30994 .55587 m .3094 .55807 L .3072 .55618 L F
.53 .329 .553 r
.39049 .59274 m .39157 .59361 L .39178 .59115 L F
0 .002 .563 r
.39178 .59115 m .39245 .58969 L .39151 .5875 L F
0 0 0 r
.39157 .59361 m .39245 .58969 L .39178 .59115 L F
.067 0 0 r
.69062 .35441 m .68822 .35553 L .6875 .35718 L F
0 0 .35 r
.34788 .54457 m .347 .54856 L .34686 .54684 L F
.731 .692 .814 r
.22418 .58768 m .22062 .58988 L .2217 .58839 L F
0 .051 .594 r
.39723 .54303 m .39901 .54615 L .39834 .54726 L F
0 .04 .603 r
.39984 .54798 m .39834 .54726 L .39901 .54615 L F
.77 .923 .554 r
.66051 .40969 m .66263 .40627 L .66135 .40748 L F
0 0 0 r
.6599 .41206 m .66051 .40969 L .66135 .40748 L F
.009 0 0 r
.1994 .63172 m .1981 .63202 L .1972 .6332 L F
.1994 .63172 m .1981 .63202 L .1972 .6332 L F
.448 .797 .998 r
.27989 .62747 m .28164 .62755 L .28248 .62841 L F
.917 .573 .115 r
.28187 .62578 m .28346 .62941 L .28248 .62841 L F
.448 .797 .998 r
.28164 .62755 m .28281 .6276 L .28248 .62841 L F
.917 .573 .115 r
.28346 .62941 m .28348 .62944 L .28248 .62841 L F
.666 .131 0 r
.28348 .62944 m .28391 .63075 L .28248 .62841 L F
.693 .387 .453 r
.28323 .63126 m .2864 .63238 L .28348 .62944 L F
.666 .131 0 r
.28348 .62944 m .2864 .63238 L .28391 .63075 L F
.743 .687 .798 r
.6377 .3838 m .64154 .38466 L .6404 .38047 L F
.572 .485 .718 r
.64154 .38466 m .64343 .38051 L .6404 .38047 L F
.64154 .38466 m .64413 .38372 L .64343 .38051 L F
.768 .494 .519 r
.32789 .53447 m .32925 .53677 L .32493 .53624 L F
.459 .261 .524 r
.33887 .54986 m .33892 .55252 L .33656 .55319 L F
.448 .234 .495 r
.33892 .55252 m .33632 .5555 L .33656 .55319 L F
.849 .447 .279 r
.38511 .6715 m .38426 .67256 L .38547 .67255 L F
.675 .214 .151 r
.38173 .67077 m .38426 .67256 L .38511 .6715 L F
.821 .911 .51 r
.38511 .6715 m .38426 .67256 L .38567 .66897 L F
.033 .041 .533 r
.38426 .67256 m .38387 .6773 L .38547 .67255 L F
.574 .098 .086 r
.38511 .6715 m .38829 .67275 L .38426 .67256 L F
.475 .345 .623 r
.29167 .54546 m .29351 .54513 L .29363 .54282 L F
.015 0 0 r
.28958 .54786 m .29351 .54513 L .29167 .54546 L F
1 .81 .503 r
.33216 .63207 m .33294 .62952 L .33128 .63082 L F
.668 .613 .785 r
.3515 .65463 m .35379 .65152 L .35115 .65185 L F
.763 .809 .89 r
.41199 .48917 m .40802 .48902 L .41045 .48814 L F
.776 .916 .933 r
.41199 .48917 m .41204 .48642 L .41451 .48826 L F
.41199 .48917 m .41045 .48814 L .41204 .48642 L F
.689 .635 .789 r
.41451 .48826 m .41593 .48967 L .41199 .48917 L F
.902 .834 .77 r
.64967 .3957 m .65139 .39714 L .64951 .40019 L F
0 0 .43 r
.65255 .39283 m .65139 .39714 L .64967 .3957 L F
.646 .332 .425 r
.5786 .46046 m .57747 .46334 L .57476 .46286 L F
.61 .294 .41 r
.58118 .46252 m .5786 .46046 L .58134 .46028 L F
.58118 .46252 m .57747 .46334 L .5786 .46046 L F
0 0 .297 r
.352 .57819 m .35282 .57999 L .35248 .57923 L F
.35282 .57999 m .35285 .58007 L .35248 .57923 L F
.75 .949 .944 r
.35183 .57776 m .35248 .57923 L .35501 .5767 L F
0 0 .484 r
.352 .57819 m .35261 .58153 L .35285 .58007 L F
0 0 .297 r
.352 .57819 m .35248 .57923 L .35026 .57731 L F
.75 .949 .944 r
.35155 .57785 m .35248 .57923 L .35183 .57776 L F
.197 .204 .641 r
.26787 .53385 m .27051 .53418 L .27166 .53323 L F
.26787 .53385 m .26893 .53663 L .27051 .53418 L F
.046 0 0 r
.33265 .67961 m .33094 .68031 L .32939 .68256 L F
.874 .59 .505 r
.53694 .42884 m .53378 .43019 L .53417 .42795 L F
.53694 .42884 m .53706 .43047 L .53378 .43019 L F
.859 .573 .503 r
.32114 .53996 m .32021 .54192 L .32397 .54284 L F
.892 .486 .237 r
.32021 .54192 m .32379 .54595 L .32397 .54284 L F
.654 .553 .728 r
.32397 .54284 m .32604 .54375 L .32698 .54037 L F
.482 .138 .307 r
.32379 .54595 m .32604 .54375 L .32397 .54284 L F
.266 0 0 r
.24543 .62314 m .24331 .623 L .2413 .62259 L F
.009 .559 .828 r
.24771 .6241 m .24331 .623 L .24543 .62314 L F
.696 .635 .784 r
.41849 .48908 m .41593 .48967 L .41451 .48826 L F
.138 .673 .853 r
.29667 .64566 m .29767 .64518 L .29499 .64556 L F
.29832 .64566 m .29938 .64565 L .29826 .64534 L F
.29832 .64566 m .29826 .64534 L .29767 .64518 L F
.524 0 0 r
.29767 .64518 m .29938 .64565 L .30125 .64711 L F
.29767 .64518 m .30125 .64711 L .29917 .64613 L F
.757 .421 .415 r
.29793 .64543 m .30154 .64149 L .29743 .64105 L F
0 0 0 r
.30261 .63737 m .30154 .64149 L .30229 .64009 L F
.673 .903 .563 r
.30229 .64009 m .30154 .64149 L .29822 .64511 L F
.29822 .64508 m .29822 .64511 L .29793 .64543 L F
.30229 .64009 m .29822 .64511 L .29822 .64508 L F
.138 .673 .853 r
.29667 .64566 m .29832 .64566 L .29767 .64518 L F
.86 .683 .661 r
.53513 .41553 m .53618 .41976 L .53277 .41877 L F
.581 .086 .045 r
.53513 .41553 m .53776 .4172 L .53618 .41976 L F
.398 .478 .826 r
.53776 .4172 m .53972 .42111 L .53618 .41976 L F
.793 .72 .783 r
.43414 .57468 m .43001 .57461 L .43253 .57144 L F
.854 .591 .541 r
.43414 .57468 m .43031 .57719 L .43001 .57461 L F
.43414 .57468 m .43324 .5789 L .43031 .57719 L F
.496 .513 .804 r
.43565 .57048 m .43414 .57468 L .43253 .57144 L F
.729 .57 0 r
.41337 .55927 m .41348 .56231 L .4133 .55833 L F
.262 .034 .367 r
.28592 .56077 m .28448 .55911 L .2866 .55867 L F
.28592 .56077 m .28421 .56189 L .28448 .55911 L F
.453 .298 .579 r
.36021 .61668 m .36059 .61977 L .35937 .61895 L F
.35937 .61895 m .36059 .61977 L .36021 .61668 L F
.551 .857 .997 r
.23237 .55209 m .23065 .55127 L .23012 .55289 L F
.354 .45 .821 r
.23065 .55127 m .22915 .55317 L .23012 .55289 L F
.697 .161 0 r
.34814 .57498 m .35026 .57731 L .34913 .57583 L F
.497 .357 .62 r
.25239 .54968 m .25456 .54609 L .25219 .54675 L F
.543 .835 .504 r
.39155 .70245 m .39448 .69931 L .39281 .70087 L F
.809 .971 .664 r
.39448 .69931 m .39503 .69758 L .39281 .70087 L F
.3 .108 .444 r
.69063 .36735 m .68771 .37094 L .68783 .36875 L F
.532 .582 .85 r
.61385 .36736 m .61126 .36821 L .60991 .36481 L F
.451 .314 .603 r
.61385 .36736 m .61397 .37086 L .61126 .36821 L F
.441 .099 .288 r
.30151 .55552 m .30514 .55213 L .3031 .5529 L F
.466 .198 .423 r
.33757 .57531 m .34011 .57489 L .34045 .57243 L F
.392 .136 .402 r
.34045 .57243 m .34011 .57489 L .34247 .57418 L F
.806 .724 .774 r
.62806 .43163 m .62558 .43488 L .62922 .43507 L F
.825 .522 .477 r
.62783 .44442 m .62443 .44152 L .62409 .44424 L F
.695 .29 .275 r
.62409 .44424 m .62688 .44618 L .62783 .44442 L F
.318 .074 .377 r
.63061 .44375 m .63037 .44127 L .62783 .44442 L F
.703 .561 .691 r
.62688 .44618 m .63061 .44375 L .62783 .44442 L F
.801 .709 .763 r
.63458 .43128 m .63899 .4314 L .63699 .4279 L F
.434 .544 .869 r
.63699 .4279 m .63899 .4314 L .64071 .43087 L F
.74 .848 .407 r
.37064 .66752 m .36946 .66937 L .36688 .66708 L F
.497 .853 .602 r
.23026 .53778 m .22731 .54018 L .22891 .53882 L F
.244 0 .009 r
.22524 .54151 m .22891 .53882 L .22731 .54018 L F
.802 .819 .865 r
.65127 .34399 m .65269 .3457 L .64942 .34537 L F
.857 .825 .816 r
.65518 .34248 m .65269 .3457 L .65127 .34399 L F
.987 .893 .572 r
.40288 .59897 m .40463 .59724 L .40383 .59625 L F
.40288 .59897 m .40372 .60086 L .40463 .59724 L F
.824 .601 .6 r
.30475 .66747 m .30587 .66912 L .30323 .66992 L F
.806 .55 .552 r
.30323 .66992 m .30587 .66912 L .30499 .67128 L F
.655 .541 .714 r
.30766 .6678 m .30587 .66912 L .30475 .66747 L F
.627 .235 .282 r
.3078 .66769 m .30853 .6679 L .30475 .66747 L F
.332 0 0 r
.3058 .66838 m .3078 .66769 L .30475 .66747 L F
.839 .996 .759 r
.30777 .66567 m .3078 .66762 L .3058 .66838 L F
.3078 .66762 m .3078 .66769 L .30772 .66772 L F
.3078 .66762 m .30772 .66772 L .3058 .66838 L F
.655 .541 .714 r
.30853 .6679 m .30709 .66856 L .30766 .6678 L F
.30709 .66856 m .30587 .66912 L .30766 .6678 L F
.30853 .6679 m .30867 .67066 L .30587 .66912 L F
.572 0 0 r
.30587 .66912 m .30738 .67051 L .30499 .67128 L F
.30587 .66912 m .30867 .67066 L .30738 .67051 L F
.593 .296 .434 r
.44646 .58737 m .44599 .59036 L .44324 .59042 L F
.429 .174 .423 r
.44939 .58457 m .44889 .58725 L .44646 .58737 L F
.521 .275 .483 r
.44889 .58725 m .44599 .59036 L .44646 .58737 L F
.402 .803 .984 r
.40043 .67279 m .39857 .67372 L .39716 .67277 L F
.39716 .67277 m .39857 .67372 L .40043 .67279 L F
.426 .179 .435 r
.3274 .59099 m .32485 .59374 L .32482 .59113 L F
.371 .304 .652 r
.44826 .53992 m .44678 .54295 L .44622 .54059 L F
.44826 .53992 m .44899 .54251 L .44678 .54295 L F
0 0 0 r
.30427 .66837 m .30475 .66747 L .30323 .66992 L F
.332 0 0 r
.3058 .66838 m .30475 .66747 L .30427 .66837 L F
.896 .859 .797 r
.69459 .29705 m .69087 .29923 L .69368 .296 L F
.69459 .29705 m .69225 .30062 L .69087 .29923 L F
.735 .484 .548 r
.39097 .57523 m .38706 .5776 L .38692 .57475 L F
.39097 .57523 m .39103 .57798 L .38706 .5776 L F
.766 .687 .775 r
.57456 .41836 m .57807 .41561 L .57544 .41543 L F
.418 0 0 r
.57544 .41543 m .57707 .41687 L .57456 .41836 L F
.57544 .41543 m .57807 .41561 L .57707 .41687 L F
.839 .863 .862 r
.69087 .29923 m .68923 .30349 L .68831 .30231 L F
.69087 .29923 m .69225 .30062 L .68923 .30349 L F
0 0 .135 r
.66263 .40627 m .66438 .40267 L .66395 .40419 L F
.661 .893 .546 r
.66135 .40748 m .66263 .40627 L .66395 .40419 L F
.597 .87 .542 r
.63316 .43814 m .63037 .44127 L .63187 .43935 L F
0 0 .287 r
.63187 .43935 m .63037 .44127 L .63061 .44375 L F
.568 .085 .07 r
.30129 .53592 m .29723 .53584 L .29912 .53462 L F
.39 .592 .925 r
.70398 .35501 m .70592 .35809 L .70765 .35767 L F
.857 .825 .816 r
.65518 .34248 m .65127 .34399 L .65391 .34105 L F
.828 .891 .887 r
.65825 .3395 m .65518 .34248 L .65391 .34105 L F
.842 .72 .729 r
.39903 .67687 m .39685 .68022 L .39666 .67742 L F
.967 .759 .571 r
.62277 .4403 m .62409 .44424 L .62443 .44152 L F
.496 .288 .526 r
.38314 .60066 m .38553 .60299 L .38571 .6001 L F
.38314 .60066 m .3831 .60362 L .38553 .60299 L F
.943 .777 .646 r
.3902 .62215 m .39142 .6258 L .39214 .62291 L F
0 .058 .591 r
.28303 .64584 m .28521 .64802 L .28419 .64659 L F
.826 .78 .808 r
.43687 .57856 m .43841 .57841 L .43705 .57832 L F
.43324 .5789 m .43542 .58154 L .43841 .57841 L F
0 0 0 r
.43841 .57841 m .43839 .57889 L .43705 .57832 L F
0 .255 .746 r
.43732 .57798 m .43705 .57832 L .43839 .57889 L F
.4355 .57643 m .43705 .57832 L .43732 .57798 L F
.826 .78 .808 r
.43324 .5789 m .43687 .57856 L .43705 .57832 L F
0 0 0 r
.33991 .53762 m .33948 .53692 L .34187 .53606 L F
.33991 .53762 m .33882 .53924 L .33948 .53692 L F
.521 .249 .443 r
.28187 .62578 m .28489 .62261 L .28199 .62273 L F
.28187 .62578 m .28438 .62562 L .28489 .62261 L F
.702 .414 .484 r
.28489 .62261 m .28438 .62562 L .28845 .62531 L F
.47 .21 .436 r
.45159 .58639 m .44939 .58457 L .45196 .58407 L F
.45159 .58639 m .44889 .58725 L .44939 .58457 L F
.216 .365 .8 r
.32627 .63211 m .32783 .63576 L .32937 .63442 L F
.363 .194 .514 r
.31137 .59124 m .3133 .59075 L .31354 .58771 L F
.389 .27 .595 r
.31137 .59124 m .31321 .5927 L .3133 .59075 L F
.387 .27 .597 r
.31137 .59124 m .31167 .5942 L .31321 .5927 L F
.206 .501 .906 r
.29598 .52135 m .29587 .51958 L .29576 .52059 L F
.29598 .52135 m .29769 .52186 L .29587 .51958 L F
.879 .974 .665 r
.29576 .52059 m .29443 .52249 L .29598 .52135 L F
.167 0 0 r
.29598 .52135 m .29714 .52158 L .29769 .52186 L F
.752 .502 .553 r
.30019 .52384 m .29598 .52135 L .29769 .52186 L F
.30019 .52384 m .29589 .52435 L .29598 .52135 L F
.975 .711 .468 r
.29443 .52249 m .29589 .52435 L .29598 .52135 L F
.167 0 0 r
.29598 .52135 m .29443 .52249 L .29714 .52158 L F
.836 .69 .701 r
.67759 .34138 m .68155 .33955 L .67984 .33837 L F
.67759 .34138 m .68109 .34205 L .68155 .33955 L F
.843 .777 .788 r
.68155 .33955 m .68071 .33591 L .67984 .33837 L F
.055 .235 .732 r
.36859 .59275 m .36836 .59429 L .36967 .59357 L F
.514 .375 .629 r
.36836 .59429 m .37133 .59524 L .36967 .59357 L F
.36836 .59429 m .36894 .59756 L .37133 .59524 L F
.486 .335 .6 r
.34058 .60361 m .34101 .60674 L .33822 .6075 L F
.318 0 .24 r
.34101 .60674 m .33828 .60812 L .33822 .6075 L F
.903 .972 .809 r
.69742 .30945 m .69823 .30888 L .69684 .30857 L F
.419 .842 .683 r
.69823 .30888 m .69969 .30784 L .69684 .30857 L F
.69823 .30888 m .70038 .30764 L .69969 .30784 L F
.249 0 .149 r
.69063 .36735 m .69325 .36444 L .69245 .3661 L F
.131 0 .062 r
.69325 .36444 m .69629 .36195 L .69493 .36397 L F
.057 0 0 r
.69245 .3661 m .69325 .36444 L .69493 .36397 L F
.604 .383 .553 r
.59033 .45415 m .59029 .45664 L .58773 .45673 L F
.55 .268 .44 r
.59299 .45422 m .59029 .45664 L .59033 .45415 L F
0 .194 .705 r
.36762 .50656 m .36824 .50781 L .36465 .50537 L F
.36762 .50656 m .36883 .5082 L .36824 .50781 L F
.772 .701 .784 r
.37955 .66128 m .3809 .66503 L .37639 .66402 L F
.734 .682 .799 r
.37955 .66128 m .3809 .66503 L .38423 .66155 L F
.537 .568 .834 r
.38288 .66389 m .3809 .66503 L .37955 .66128 L F
.318 .339 .726 r
.37017 .57459 m .36739 .57771 L .36778 .57538 L F
.824 .655 .673 r
.38535 .6577 m .38423 .66155 L .38186 .6597 L F
.68 .584 .741 r
.27647 .52923 m .27442 .5263 L .27647 .52669 L F
.383 .085 .331 r
.27647 .52923 m .27676 .53214 L .27429 .53269 L F
.208 .124 .534 r
.27882 .52595 m .27647 .52923 L .27647 .52669 L F
.191 0 .334 r
.27902 .5289 m .27676 .53214 L .27647 .52923 L F
.884 .87 .818 r
.63448 .42879 m .63052 .43057 L .63458 .43128 L F
.442 .23 .495 r
.63699 .4279 m .63448 .42879 L .63458 .43128 L F
0 0 0 r
.63187 .43935 m .63561 .43718 L .63316 .43814 L F
.483 .475 .773 r
.44558 .52677 m .44339 .52763 L .44245 .52389 L F
.371 .271 .61 r
.44558 .52677 m .44394 .53026 L .44339 .52763 L F
.503 0 0 r
.29127 .64271 m .29197 .64186 L .28897 .64139 L F
.326 0 .119 r
.29319 .64373 m .29197 .64186 L .29127 .64271 L F
.29319 .64373 m .29608 .64099 L .29197 .64186 L F
.871 .968 .854 r
.43087 .56099 m .43112 .56244 L .43388 .55936 L F
0 0 .062 r
.43139 .56331 m .43112 .56244 L .43087 .56099 L F
.43139 .56331 m .43094 .5657 L .43112 .56244 L F
.4 .238 .543 r
.32952 .55545 m .33163 .55204 L .33021 .5531 L F
.439 .531 .854 r
.28016 .54059 m .28312 .54145 L .28185 .53925 L F
.6 .577 .799 r
.43655 .49574 m .43311 .49325 L .43545 .49203 L F
.376 .514 .869 r
.3831 .60362 m .38532 .60718 L .38616 .60547 L F
.886 .851 .803 r
.59063 .3807 m .5882 .38492 L .58674 .38262 L F
.149 0 0 r
.5882 .38492 m .58912 .38247 L .58674 .38262 L F
.5882 .38492 m .58728 .38477 L .58912 .38247 L F
.323 0 0 r
.57656 .39535 m .58022 .3967 L .57884 .39612 L F
.61 .808 .976 r
.3607 .65173 m .36473 .65248 L .36293 .65008 L F
.692 .66 .815 r
.36293 .65008 m .36473 .65248 L .36679 .65083 L F
0 0 0 r
.35048 .59395 m .35455 .59112 L .35376 .59338 L F
.197 0 .23 r
.35376 .59338 m .35455 .59112 L .35622 .59037 L F
.561 .923 .753 r
.42718 .53991 m .4247 .54123 L .42808 .53896 L F
.584 .576 .81 r
.34755 .56197 m .3496 .56634 L .3515 .56511 L F
.319 .805 .777 r
.32072 .62417 m .32499 .62298 L .32333 .62338 L F
.39 .467 .818 r
.32661 .62169 m .32499 .62298 L .32355 .61941 L F
.547 .924 .793 r
.32333 .62338 m .32499 .62298 L .32661 .62169 L F
.492 .887 .954 r
.27105 .52046 m .26864 .52078 L .27108 .51999 L F
.388 0 0 r
.26714 .52064 m .27108 .51999 L .26864 .52078 L F
.26714 .52064 m .26899 .52128 L .27108 .51999 L F
.696 .96 .711 r
.27108 .51999 m .26899 .52128 L .27112 .51922 L F
.27108 .51999 m .27112 .51922 L .27169 .51866 L F
.492 .887 .954 r
.27229 .5203 m .27105 .52046 L .27108 .51999 L F
.534 .914 .94 r
.27567 .51883 m .27229 .5203 L .27108 .51999 L F
.629 .33 .444 r
.24288 .56909 m .24303 .57118 L .24074 .57066 L F
.573 .288 .446 r
.24288 .56909 m .24571 .57109 L .24303 .57118 L F
.608 .26 .354 r
.24686 .56998 m .24571 .57109 L .24288 .56909 L F
.542 .151 .25 r
.32618 .58157 m .32783 .58348 L .32893 .58115 L F
.185 .107 .529 r
.32769 .58075 m .32783 .58348 L .32618 .58157 L F
.73 .662 .783 r
.35346 .69003 m .35637 .69006 L .35484 .68726 L F
.713 .436 .504 r
.35581 .69256 m .35637 .69006 L .35346 .69003 L F
.535 .574 .841 r
.35484 .68726 m .35637 .69006 L .35862 .68927 L F
.586 .4 .596 r
.35581 .69256 m .35862 .68927 L .35637 .69006 L F
0 0 0 r
.24712 .5408 m .24749 .53996 L .24798 .53892 L F
.24712 .5408 m .24496 .5416 L .24749 .53996 L F
.365 0 .086 r
.33842 .56203 m .33927 .56328 L .341 .5619 L F
.858 .771 .765 r
.54199 .43826 m .54023 .44097 L .53936 .43694 L F
.266 .737 .942 r
.20864 .60713 m .20689 .60649 L .2045 .60665 L F
.726 .934 .957 r
.20915 .60498 m .20689 .60649 L .20864 .60713 L F
.111 .651 .848 r
.3361 .49598 m .33901 .49587 L .34009 .4964 L F
.348 0 0 r
.33901 .49587 m .34275 .49663 L .34009 .4964 L F
.48 .804 1 r
.34185 .7182 m .34599 .71876 L .34427 .71773 L F
.712 .437 .507 r
.68207 .35756 m .68195 .35529 L .67751 .35518 L F
.075 0 .294 r
.3582 .58672 m .35773 .58457 L .35966 .58436 L F
.3582 .58672 m .35646 .58826 L .35773 .58457 L F
.508 .502 .784 r
.44335 .51709 m .44207 .52119 L .44111 .51749 L F
.44335 .51709 m .44455 .52059 L .44207 .52119 L F
.536 .435 .687 r
.44455 .52059 m .44245 .52389 L .44207 .52119 L F
0 0 .121 r
.26615 .52085 m .26714 .52064 L .26864 .52078 L F
.26615 .52085 m .26578 .52494 L .26714 .52064 L F
.091 0 0 r
.37674 .69858 m .37443 .69832 L .37262 .6982 L F
.37262 .6982 m .37443 .69832 L .37674 .69858 L F
.37674 .69858 m .37443 .69832 L .37262 .6982 L F
.994 .876 .573 r
.40543 .58682 m .40567 .59033 L .4059 .58779 L F
.949 .683 .498 r
.2878 .65129 m .2896 .65464 L .28752 .65365 L F
.835 .366 0 r
.2896 .65464 m .2893 .65626 L .28752 .65365 L F
.2896 .65464 m .29115 .65735 L .2893 .65626 L F
.957 .632 .23 r
.57468 .39635 m .57471 .39889 L .57656 .39535 L F
.559 .097 .112 r
.35538 .55495 m .35225 .55503 L .35281 .55379 L F
.395 .456 .805 r
.35949 .60402 m .36082 .60665 L .35728 .60402 L F
.448 .881 .825 r
.36753 .62438 m .37178 .62282 L .36999 .62421 L F
.397 0 0 r
.36999 .62421 m .37178 .62282 L .37425 .62266 L F
0 0 0 r
.69493 .36397 m .69629 .36195 L .69828 .3603 L F
.009 .559 .828 r
.24771 .6241 m .24594 .62328 L .24331 .623 L F
.095 .613 .885 r
.25002 .62479 m .24594 .62328 L .24771 .6241 L F
.591 .519 .742 r
.45165 .55263 m .45253 .55533 L .44993 .55592 L F
.641 .555 .742 r
.45349 .55907 m .44993 .55592 L .45253 .55533 L F
0 0 0 r
.70618 .2983 m .70584 .29956 L .70524 .30087 L F
.70618 .2983 m .70775 .29657 L .70584 .29956 L F
.741 .533 .613 r
.57931 .40319 m .57919 .40582 L .57526 .40509 L F
.314 .126 .459 r
.30514 .55213 m .3075 .54871 L .30551 .54965 L F
.472 .357 .641 r
.44147 .50633 m .43899 .50461 L .44064 .50413 L F
.44147 .50633 m .43874 .50852 L .43899 .50461 L F
.15 0 0 r
.35034 .67071 m .34854 .67079 L .34688 .67204 L F
.376 .838 .785 r
.34821 .67117 m .35034 .67071 L .34688 .67204 L F
.008 0 0 r
.35235 .67061 m .35034 .67071 L .34821 .67117 L F
.35279 .67055 m .35034 .67071 L .35235 .67061 L F
.15 0 0 r
.35034 .67071 m .349 .67045 L .34854 .67079 L F
.35034 .67071 m .35158 .67028 L .349 .67045 L F
.864 .67 .638 r
.55242 .45299 m .55603 .45363 L .55411 .45641 L F
.855 .573 .509 r
.55603 .45363 m .55761 .45667 L .55411 .45641 L F
0 .031 .574 r
.34301 .7086 m .34585 .71219 L .34609 .71228 L F
.645 .885 .984 r
.62758 .40426 m .62883 .40543 L .62626 .40648 L F
.234 0 0 r
.43123 .58357 m .43381 .58316 L .43542 .58154 L F
0 .467 .862 r
.42913 .58309 m .43004 .58413 L .43338 .58521 L F
.5 .142 .291 r
.43338 .58521 m .43004 .58413 L .43094 .58783 L F
0 .467 .862 r
.42913 .58309 m .43338 .58521 L .433 .58547 L F
.5 .142 .291 r
.43338 .58521 m .43094 .58783 L .43136 .58789 L F
.606 .831 .443 r
.43406 .58415 m .43338 .58521 L .43136 .58789 L F
.637 .867 .502 r
.4352 .58257 m .43338 .58521 L .433 .58547 L F
.606 .831 .443 r
.4352 .58257 m .43452 .58356 L .43406 .58415 L F
.43452 .58356 m .43338 .58521 L .43406 .58415 L F
.134 0 0 r
.43519 .58269 m .43542 .58154 L .43381 .58316 L F
.43593 .58245 m .4357 .58204 L .43519 .58269 L F
.4357 .58204 m .43542 .58154 L .43519 .58269 L F
.833 .768 .789 r
.60391 .38416 m .60501 .38695 L .60186 .38641 L F
.528 .844 .999 r
.60186 .38641 m .60501 .38695 L .60255 .38664 L F
.758 .745 .841 r
.60772 .38371 m .60501 .38695 L .60391 .38416 L F
.822 .903 .897 r
.68498 .31073 m .68082 .31205 L .68395 .30946 L F
0 .046 .614 r
.42621 .5367 m .42808 .53896 L .42733 .53698 L F
.42621 .5367 m .42733 .53698 L .42423 .53688 L F
.254 .074 .434 r
.2936 .63511 m .29388 .63253 L .29569 .63177 L F
0 0 .387 r
.33764 .5432 m .33774 .54544 L .33868 .54439 L F
.674 .672 .84 r
.61918 .36352 m .6179 .36821 L .61655 .36694 L F
.61918 .36352 m .62038 .36721 L .6179 .36821 L F
.754 .715 .816 r
.35393 .65377 m .35783 .65429 L .357 .65357 L F
.755 .712 .812 r
.35556 .65541 m .35783 .65429 L .35393 .65377 L F
.696 .635 .784 r
.41849 .48908 m .41451 .48826 L .41699 .48538 L F
.702 .665 .811 r
.42125 .48611 m .41849 .48908 L .41699 .48538 L F
.738 .654 .766 r
.64637 .34841 m .64774 .3523 L .64369 .35162 L F
.53 .597 .866 r
.60947 .42196 m .61309 .42475 L .6119 .42258 L F
.294 .361 .762 r
.6119 .42258 m .61402 .42466 L .6153 .42063 L F
.6119 .42258 m .61309 .42475 L .61402 .42466 L F
.171 0 .268 r
.35184 .54684 m .35104 .54907 L .35371 .5455 L F
.682 .654 .816 r
.43407 .48568 m .43177 .48699 L .43068 .48512 L F
.599 .592 .817 r
.4357 .48873 m .43177 .48699 L .43407 .48568 L F
.829 .734 .76 r
.37247 .66073 m .37646 .66119 L .37481 .65752 L F
.797 .561 .58 r
.37924 .67394 m .3753 .67348 L .37565 .67075 L F
.688 .497 .623 r
.37675 .67642 m .37973 .677 L .37924 .67394 L F
.793 .67 .729 r
.37924 .67394 m .37675 .67642 L .3753 .67348 L F
.688 .497 .623 r
.37675 .67642 m .37973 .677 L .37924 .67394 L F
.709 .726 .863 r
.37646 .66119 m .37739 .65702 L .37481 .65752 L F
.37646 .66119 m .37987 .65893 L .37739 .65702 L F
.572 .433 .653 r
.37646 .66119 m .37955 .66128 L .37987 .65893 L F
.12 .102 .562 r
.37973 .677 m .38062 .67702 L .37924 .67394 L F
.37973 .677 m .38062 .67702 L .37924 .67394 L F
.164 0 0 r
.24805 .57016 m .24686 .56998 L .24995 .5687 L F
.24805 .57016 m .24995 .5687 L .24726 .5684 L F
.634 .588 .785 r
.24995 .5687 m .25396 .57128 L .25236 .56826 L F
.806 .783 .832 r
.41469 .5046 m .41838 .50324 L .41894 .50578 L F
.578 .514 .747 r
.41838 .50324 m .41894 .50578 L .42145 .50475 L F
.351 .105 .394 r
.31482 .60712 m .31433 .60948 L .31225 .60993 L F
.311 .186 .543 r
.31412 .61222 m .31225 .60993 L .31433 .60948 L F
.31412 .61222 m .3125 .61329 L .31225 .60993 L F
.708 .566 0 r
.40045 .68282 m .40051 .68596 L .40051 .68582 L F
.965 .835 .664 r
.39753 .68889 m .39961 .68978 L .40051 .68582 L F
.39753 .68889 m .40051 .68582 L .40051 .68596 L F
0 0 .177 r
.69637 .3458 m .69639 .3486 L .69701 .34595 L F
.691 .778 .918 r
.31322 .50847 m .30828 .50728 L .30928 .5073 L F
.31054 .5075 m .30928 .5073 L .31001 .50731 L F
.31322 .50847 m .30928 .5073 L .31054 .5075 L F
.885 .918 .842 r
.31548 .50445 m .31322 .50847 L .31147 .50765 L F
.574 .712 .936 r
.31113 .507 m .31075 .50754 L .31143 .50728 L F
.3096 .50554 m .31052 .50714 L .31113 .507 L F
.31052 .50714 m .31075 .50754 L .31113 .507 L F
.885 .918 .842 r
.31548 .50445 m .31147 .50765 L .31139 .50694 L F
.31548 .50445 m .31139 .50694 L .31374 .50641 L F
.574 .712 .936 r
.31126 .50589 m .31143 .50728 L .31374 .50641 L F
.3096 .50554 m .31143 .50728 L .31126 .50589 L F
.885 .918 .842 r
.31139 .50694 m .31077 .50732 L .31374 .50641 L F
.31139 .50694 m .31147 .50765 L .31077 .50732 L F
.691 .778 .918 r
.31322 .50847 m .31001 .50731 L .31211 .50795 L F
.574 .712 .936 r
.31075 .50754 m .31191 .50953 L .31288 .50788 L F
.31075 .50754 m .31288 .50788 L .31374 .50641 L F
.859 .835 .821 r
.30828 .50728 m .30515 .51199 L .30391 .50987 L F
.803 .813 .859 r
.30697 .50849 m .31191 .50953 L .31075 .50754 L F
.31001 .50731 m .31075 .50754 L .3096 .50554 L F
.401 .54 .88 r
.3096 .50554 m .31077 .50732 L .31001 .50731 L F
.3096 .50554 m .31001 .50731 L .30828 .50728 L F
.803 .813 .859 r
.30845 .50683 m .31001 .50731 L .3096 .50554 L F
.859 .835 .821 r
.30828 .50728 m .30391 .50987 L .30697 .50849 L F
.803 .813 .859 r
.30697 .50849 m .3096 .50554 L .30828 .50728 L F
.30697 .50849 m .31075 .50754 L .30845 .50683 L F
.691 .778 .918 r
.31211 .50795 m .31001 .50731 L .31077 .50732 L F
.754 .987 .767 r
.31156 .51005 m .31322 .50847 L .31191 .50953 L F
.227 0 .029 r
.31191 .50953 m .31322 .50847 L .31566 .50778 L F
.31191 .50953 m .31566 .50778 L .31392 .50654 L F
.31191 .50953 m .31392 .50654 L .31374 .50641 L F
.754 .987 .767 r
.31035 .51121 m .31156 .51005 L .31191 .50953 L F
.723 .772 .892 r
.71803 .28004 m .71852 .28201 L .71476 .28139 L F
.715 .777 .901 r
.71672 .27884 m .71752 .28024 L .71476 .28139 L F
.411 .557 .89 r
.71803 .28004 m .71852 .28201 L .72017 .27975 L F
.627 .449 .622 r
.71476 .28139 m .71742 .28028 L .71737 .28038 L F
.343 .812 .729 r
.71798 .28005 m .71803 .28004 L .71476 .28139 L F
.715 .777 .901 r
.71752 .28024 m .71756 .28031 L .71476 .28139 L F
.71756 .28031 m .71852 .28201 L .71476 .28139 L F
.627 .449 .622 r
.71476 .28139 m .71737 .28038 L .715 .28457 L F
.71742 .28028 m .71803 .28004 L .71781 .28036 L F
.481 .655 .937 r
.7195 .28066 m .71852 .28201 L .71756 .28031 L F
.627 .449 .622 r
.71742 .28028 m .71781 .28036 L .715 .28457 L F
.481 .655 .937 r
.72017 .27975 m .7195 .28066 L .71752 .28024 L F
.7195 .28066 m .71756 .28031 L .71752 .28024 L F
.71916 .27948 m .71752 .28024 L .71672 .27884 L F
.343 .812 .729 r
.71784 .28009 m .71798 .28005 L .71752 .28024 L F
.481 .655 .937 r
.72017 .27975 m .71752 .28024 L .71784 .28009 L F
0 0 0 r
.71784 .28009 m .72017 .27975 L .71679 .28042 L F
.71803 .28004 m .72017 .27975 L .71784 .28009 L F
.481 .655 .937 r
.72017 .27975 m .71784 .28009 L .71916 .27948 L F
.343 .812 .729 r
.71679 .28042 m .71784 .28009 L .71476 .28139 L F
.71784 .28009 m .71752 .28024 L .71476 .28139 L F
.065 .562 .889 r
.24056 .61208 m .23989 .61248 L .23809 .61073 L F
.24056 .61208 m .24249 .61314 L .23989 .61248 L F
.399 .149 .415 r
.4663 .57433 m .46355 .57736 L .46379 .57493 L F
.721 .221 .046 r
.27827 .62447 m .28199 .62273 L .27827 .62335 L F
.551 .929 .902 r
.28997 .60051 m .28645 .60131 L .28984 .6 L F
.602 .565 .785 r
.28905 .60267 m .28645 .60131 L .28997 .60051 L F
.135 .623 .915 r
.28984 .6 m .29259 .6008 L .28997 .60051 L F
.452 .044 .174 r
.29259 .6008 m .28905 .60267 L .28997 .60051 L F
.461 .388 .689 r
.34851 .56801 m .34724 .57077 L .34802 .56732 L F
.859 .977 .674 r
.34724 .57077 m .34451 .57307 L .34802 .56732 L F
.823 .729 .761 r
.67759 .34138 m .67885 .34524 L .68109 .34205 L F
.323 .249 .616 r
.3237 .65304 m .32109 .65177 L .32204 .65091 L F
.3237 .65304 m .3215 .65444 L .32109 .65177 L F
.413 .863 .85 r
.30437 .51183 m .29957 .51309 L .30306 .51136 L F
.901 .973 .81 r
.30391 .50987 m .30437 .51183 L .30306 .51136 L F
.584 .574 .808 r
.30927 .52096 m .31336 .5242 L .31205 .52058 L F
.687 .554 .698 r
.31205 .52058 m .31336 .5242 L .31576 .52086 L F
.416 .466 .803 r
.28427 .60389 m .28506 .59994 L .28275 .60017 L F
.409 .399 .737 r
.28645 .60131 m .28637 .60354 L .28427 .60389 L F
.416 .466 .803 r
.28427 .60389 m .28637 .60354 L .28506 .59994 L F
.359 .768 .982 r
.57073 .40577 m .5731 .40615 L .56875 .40535 L F
.78 .745 .821 r
.56875 .40535 m .5731 .40615 L .57166 .40656 L F
.667 .626 .799 r
.57684 .40716 m .5731 .40615 L .57526 .40509 L F
.053 0 0 r
.66646 .40079 m .66724 .39886 L .6697 .39835 L F
.62 .179 .181 r
.72169 .33493 m .72577 .33535 L .72368 .33397 L F
.463 .313 .591 r
.72368 .33397 m .72577 .33535 L .72552 .33226 L F
.72368 .33397 m .72577 .33535 L .72552 .33226 L F
.516 .383 .638 r
.32783 .58348 m .32984 .58026 L .32893 .58115 L F
.317 .306 .688 r
.40426 .66321 m .40517 .66597 L .4017 .66767 L F
.052 0 .136 r
.4017 .66767 m .40393 .66834 L .40352 .66898 L F
.851 .807 .807 r
.40069 .66537 m .39831 .66863 L .40215 .66889 L F
.4028 .66807 m .40215 .66889 L .40352 .66898 L F
.052 0 .136 r
.4017 .66767 m .404 .66654 L .40284 .66801 L F
.851 .807 .807 r
.40069 .66537 m .40215 .66889 L .4028 .66807 L F
.052 0 .136 r
.40284 .66801 m .40517 .66597 L .40393 .66834 L F
.404 .66654 m .40517 .66597 L .40284 .66801 L F
.778 .727 .805 r
.68285 .33255 m .68658 .33307 L .6856 .32954 L F
.803 .74 .794 r
.6856 .32954 m .68658 .33307 L .68901 .32992 L F
.529 .87 .611 r
.24083 .55687 m .24103 .55435 L .24318 .55618 L F
.24083 .55687 m .2405 .55682 L .24103 .55435 L F
.24083 .55687 m .23941 .55788 L .2405 .55682 L F
.871 .867 .831 r
.62741 .38565 m .62882 .3875 L .63131 .38382 L F
0 0 0 r
.63123 .38917 m .62882 .3875 L .62975 .3898 L F
.886 .678 .159 r
.35513 .6819 m .35559 .67988 L .3523 .68038 L F
.35513 .6819 m .35587 .68373 L .35559 .67988 L F
.273 .522 .908 r
.39787 .54189 m .39723 .54303 L .39472 .54019 L F
.962 .663 .245 r
.39787 .54189 m .39901 .54615 L .39723 .54303 L F
.844 .805 .812 r
.27442 .5263 m .27208 .52797 L .27393 .52741 L F
.287 0 .231 r
.27442 .5263 m .27523 .52875 L .27647 .52669 L F
.27466 .52703 m .27291 .52969 L .27523 .52875 L F
.27442 .5263 m .27393 .52741 L .27466 .52703 L F
.27393 .52741 m .27291 .52969 L .27466 .52703 L F
.237 0 0 r
.27546 .5265 m .27248 .52629 L .27442 .5263 L F
.27647 .52669 m .27248 .52629 L .27546 .5265 L F
.676 .807 .946 r
.27476 .52514 m .27248 .52629 L .27551 .5266 L F
.27599 .52635 m .27551 .5266 L .27633 .52668 L F
.27476 .52514 m .27551 .5266 L .27599 .52635 L F
.27642 .52665 m .27633 .52668 L .27647 .52669 L F
.27476 .52514 m .27633 .52668 L .27642 .52665 L F
.844 .805 .812 r
.27393 .52741 m .2699 .52952 L .27291 .52969 L F
.27208 .52797 m .2699 .52952 L .27393 .52741 L F
.476 .775 .996 r
.39231 .58171 m .38825 .58098 L .39103 .57798 L F
.36 .83 .882 r
.39395 .58087 m .39482 .58103 L .39231 .58171 L F
.166 .301 .758 r
.39395 .58087 m .39231 .58171 L .39103 .57798 L F
.482 .138 .307 r
.32379 .54595 m .32656 .54589 L .32604 .54375 L F
0 0 .174 r
.32698 .54037 m .32604 .54375 L .32755 .54137 L F
.375 .075 .323 r
.32604 .54375 m .32912 .54492 L .32755 .54137 L F
.32604 .54375 m .32656 .54589 L .32912 .54492 L F
.62 .51 .707 r
.36616 .59806 m .36648 .60061 L .36894 .59756 L F
.977 .675 .342 r
.60512 .42432 m .60598 .42318 L .60371 .4216 L F
.168 .365 .814 r
.38287 .66947 m .38426 .67256 L .38173 .67077 L F
.953 .879 .724 r
.53353 .41411 m .53513 .41553 L .53277 .41877 L F
.936 .89 .76 r
.53534 .41398 m .53513 .41553 L .53353 .41411 L F
.566 .275 .434 r
.33163 .55204 m .33493 .54958 L .33197 .54979 L F
0 .473 .776 r
.35321 .49995 m .35704 .50114 L .35519 .50071 L F
0 .189 .716 r
.70265 .33703 m .70456 .34114 L .70198 .33837 L F
.682 .568 .721 r
.43159 .56717 m .42988 .57155 L .42904 .56813 L F
.523 .478 .748 r
.44826 .53992 m .44622 .54059 L .44537 .53658 L F
.724 .598 .714 r
.67619 .34858 m .68045 .34922 L .67885 .34524 L F
.763 .634 .718 r
.67612 .35097 m .68045 .34922 L .67619 .34858 L F
.67612 .35097 m .67816 .35257 L .68045 .34922 L F
0 .459 .796 r
.25916 .54894 m .26054 .54923 L .25654 .54772 L F
.828 .475 .387 r
.5918 .38448 m .59398 .38416 L .59175 .38294 L F
.59246 .38522 m .59398 .38416 L .5918 .38448 L F
.59183 .38565 m .59246 .38522 L .5918 .38448 L F
.753 .935 .945 r
.59292 .3856 m .59183 .38565 L .59212 .38359 L F
.59302 .38586 m .59183 .38565 L .59292 .3856 L F
.828 .475 .387 r
.59246 .38522 m .59322 .38559 L .59398 .38416 L F
.59322 .38559 m .59462 .38627 L .59439 .38553 L F
.59322 .38559 m .59439 .38553 L .59398 .38416 L F
0 .341 .818 r
.59335 .38597 m .59305 .38587 L .59295 .38563 L F
.59305 .38587 m .59302 .38586 L .593 .38581 L F
.314 0 0 r
.59302 .38586 m .59462 .38627 L .59183 .38565 L F
.828 .475 .387 r
.59183 .38565 m .59339 .386 L .59246 .38522 L F
.59339 .386 m .59462 .38627 L .59246 .38522 L F
.36 .759 .985 r
.59699 .38614 m .59854 .38701 L .59462 .38627 L F
.152 0 0 r
.59596 .38685 m .59462 .38627 L .59302 .38586 L F
.59596 .38685 m .59699 .38614 L .59462 .38627 L F
0 .341 .818 r
.59596 .38685 m .59335 .38597 L .59212 .38359 L F
.59335 .38597 m .59295 .38563 L .59212 .38359 L F
.59305 .38587 m .593 .38581 L .59212 .38359 L F
.791 .688 .751 r
.64335 .37766 m .64718 .37778 L .64552 .37412 L F
.706 .511 .622 r
.64343 .38051 m .64718 .37778 L .64335 .37766 L F
.64343 .38051 m .64682 .38036 L .64718 .37778 L F
.699 .635 .781 r
.64718 .37778 m .64818 .37309 L .64552 .37412 L F
.64718 .37778 m .64936 .37723 L .64818 .37309 L F
.736 .579 .679 r
.64682 .38036 m .64936 .37723 L .64718 .37778 L F
.432 .853 .705 r
.3292 .61548 m .33284 .61359 L .33024 .61465 L F
.32892 .61563 m .32907 .61563 L .33284 .61359 L F
.727 .38 .391 r
.33517 .61281 m .33024 .61465 L .33284 .61359 L F
.33517 .61281 m .33378 .61447 L .33024 .61465 L F
.705 .336 .346 r
.33378 .61447 m .33006 .61533 L .33024 .61465 L F
0 0 0 r
.33024 .61465 m .3288 .61659 L .33147 .61365 L F
.33024 .61465 m .33147 .61365 L .33163 .61348 L F
.432 .853 .705 r
.32892 .61563 m .3292 .61548 L .33024 .61465 L F
.547 .457 .704 r
.43812 .49093 m .43655 .49574 L .43545 .49203 L F
.43812 .49093 m .43914 .49504 L .43655 .49574 L F
.484 .374 .654 r
.43914 .49504 m .43704 .49836 L .43655 .49574 L F
.742 .591 .688 r
.35888 .59737 m .36265 .5974 L .3616 .59473 L F
.813 .826 .861 r
.40535 .4912 m .40154 .49126 L .4045 .48886 L F
.40535 .4912 m .40322 .49247 L .40154 .49126 L F
.745 .838 .921 r
.40802 .48902 m .40535 .4912 L .4045 .48886 L F
.69 .678 .833 r
.57526 .40509 m .57919 .40582 L .57684 .40716 L F
.565 .696 .929 r
.26745 .62197 m .26502 .62253 L .26271 .6201 L F
.095 .613 .885 r
.25002 .62479 m .24812 .62351 L .24594 .62328 L F
0 .552 .716 r
.25249 .62377 m .24812 .62351 L .25002 .62479 L F
.233 .484 .891 r
.25002 .62479 m .25179 .6256 L .25249 .62377 L F
.85 .915 .515 r
.29769 .52186 m .29948 .51829 L .29969 .51657 L F
.731 .65 .769 r
.62314 .36408 m .6244 .36799 L .62038 .36721 L F
.696 .631 .779 r
.62701 .36541 m .6244 .36799 L .62314 .36408 L F
.651 .397 .522 r
.28845 .62531 m .29111 .62568 L .2915 .62235 L F
.455 .323 .612 r
.2915 .62235 m .29356 .61927 L .29099 .61981 L F
.2915 .62235 m .2937 .62205 L .29356 .61927 L F
.497 .29 .529 r
.29111 .62568 m .2937 .62205 L .2915 .62235 L F
.894 .974 .674 r
.34725 .50943 m .34508 .51277 L .34699 .51138 L F
0 0 0 r
.66395 .40419 m .66438 .40267 L .66646 .40079 L F
0 0 .084 r
.20901 .56528 m .20683 .56873 L .20813 .56767 L F
0 0 .426 r
.20683 .56873 m .20783 .57047 L .20813 .56767 L F
.20683 .56873 m .20693 .57143 L .20783 .57047 L F
.529 .338 .565 r
.29883 .6102 m .30133 .60975 L .30141 .60693 L F
.58 .329 .501 r
.2983 .61251 m .30133 .60975 L .29883 .6102 L F
.113 .103 .567 r
.20553 .57833 m .20711 .5804 L .20711 .57684 L F
.094 .098 .571 r
.20553 .57833 m .20609 .58126 L .20711 .5804 L F
.803 .367 0 r
.5946 .39305 m .59695 .39659 L .59539 .39568 L F
.606 .814 .408 r
.59695 .39659 m .5961 .39781 L .59539 .39568 L F
.237 .507 .906 r
.5961 .39781 m .59698 .40003 L .60037 .40078 L F
0 .005 .505 r
.5961 .39781 m .59711 .3988 L .59605 .39781 L F
.5961 .39781 m .59605 .39781 L .59469 .39654 L F
.606 .814 .408 r
.59695 .39659 m .59614 .39781 L .5961 .39781 L F
.59614 .39781 m .59481 .39982 L .5961 .39781 L F
.543 .378 .607 r
.36201 .58141 m .36218 .58415 L .35966 .58436 L F
.697 .425 .508 r
.36218 .58415 m .3582 .58672 L .35966 .58436 L F
.733 .434 .474 r
.35888 .59737 m .36241 .59981 L .36265 .5974 L F
.65 .603 .788 r
.45793 .56214 m .45349 .55907 L .45624 .55829 L F
.466 .501 .81 r
.45862 .55758 m .45793 .56214 L .45624 .55829 L F
.45862 .55758 m .4599 .56138 L .45793 .56214 L F
.582 .522 .753 r
.4599 .56138 m .45853 .56631 L .45793 .56214 L F
.288 .333 .735 r
.33623 .70074 m .33882 .70555 L .33753 .70182 L F
.467 .45 .756 r
.25396 .57128 m .25504 .56839 L .25236 .56826 L F
.25396 .57128 m .25614 .57116 L .25504 .56839 L F
.462 .803 .999 r
.31876 .54937 m .32115 .54893 L .31772 .54833 L F
.539 .179 .304 r
.27917 .55459 m .282 .5545 L .27965 .55292 L F
.555 .163 .254 r
.27965 .55292 m .282 .5545 L .28163 .55307 L F
.229 .114 .508 r
.72934 .336 m .7328 .33691 L .73358 .33604 L F
.7328 .33691 m .73282 .33691 L .73282 .3369 L F
.7328 .33691 m .73282 .3369 L .73358 .33604 L F
.72934 .336 m .72977 .33839 L .73269 .33734 L F
.952 .609 .225 r
.72839 .3373 m .72977 .33839 L .72934 .336 L F
.39 .764 .992 r
.7319 .33714 m .72977 .33839 L .72839 .3373 L F
.466 .236 .481 r
.73278 .33738 m .73503 .33683 L .73282 .33691 L F
.229 .114 .508 r
.73282 .33691 m .73269 .33734 L .73343 .33707 L F
.466 .236 .481 r
.7326 .33972 m .73273 .33766 L .73223 .33915 L F
.73273 .33766 m .73276 .33706 L .73264 .33754 L F
.73273 .33766 m .73264 .33754 L .73223 .33915 L F
.229 .114 .508 r
.7328 .33691 m .73276 .33706 L .73282 .33691 L F
.72934 .336 m .73269 .33734 L .7328 .33691 L F
.466 .236 .481 r
.73276 .33706 m .73282 .33691 L .73277 .33691 L F
.229 .114 .508 r
.73282 .33691 m .73343 .33707 L .73346 .33689 L F
.39 .764 .992 r
.73343 .33707 m .73233 .33712 L .73277 .33658 L F
.897 .765 .708 r
.73036 .33443 m .73116 .33556 L .73288 .33509 L F
.521 .653 .918 r
.73198 .33671 m .72839 .3373 L .73036 .33443 L F
.897 .765 .708 r
.73155 .33546 m .7321 .33681 L .73288 .33509 L F
.73076 .33567 m .73102 .33589 L .73155 .33546 L F
.73102 .33589 m .7321 .33681 L .73155 .33546 L F
.39 .764 .992 r
.73233 .33712 m .72839 .3373 L .73198 .33671 L F
.952 .609 .224 r
.72839 .3373 m .72977 .33839 L .73005 .34047 L F
.72839 .3373 m .72977 .33839 L .73005 .34047 L F
.39 .764 .992 r
.73267 .33735 m .72977 .33839 L .7319 .33714 L F
.897 .765 .708 r
.73099 .33587 m .73153 .33806 L .7321 .33681 L F
.405 .455 .799 r
.731 .33591 m .73153 .33806 L .72839 .3373 L F
.731 .33591 m .72839 .3373 L .73087 .33602 L F
.897 .765 .708 r
.73076 .33567 m .73153 .33806 L .73099 .33587 L F
.405 .455 .799 r
.73131 .33574 m .73153 .33806 L .731 .33591 L F
.389 .471 .824 r
.72839 .3373 m .73153 .33806 L .73087 .33602 L F
.405 .455 .799 r
.73087 .33602 m .72839 .3373 L .72852 .33794 L F
.73087 .33602 m .72852 .33794 L .72919 .33742 L F
.389 .471 .824 r
.72839 .3373 m .73087 .33602 L .73036 .33443 L F
.405 .455 .799 r
.73131 .33574 m .731 .33591 L .72853 .33798 L F
.731 .33591 m .72852 .33796 L .72853 .33798 L F
.952 .609 .225 r
.72839 .3373 m .72934 .336 L .72577 .33535 L F
.616 .058 0 r
.72519 .33632 m .72839 .3373 L .72577 .33535 L F
.422 0 0 r
.72842 .33793 m .72839 .3373 L .72519 .33632 L F
.865 .982 .847 r
.72725 .33779 m .72728 .33891 L .72852 .33794 L F
.422 0 0 r
.72853 .33798 m .72852 .33794 L .72842 .33793 L F
.72852 .33794 m .72839 .3373 L .72842 .33793 L F
.865 .982 .847 r
.72872 .3376 m .72852 .33794 L .73131 .33574 L F
.276 .304 .711 r
.72846 .33782 m .72808 .33765 L .7283 .33745 L F
.865 .982 .847 r
.72829 .33791 m .72834 .33792 L .72872 .3376 L F
.72834 .33792 m .72852 .33794 L .72872 .3376 L F
.897 .765 .708 r
.73036 .33443 m .73076 .33567 L .73116 .33556 L F
.832 .663 .672 r
.73036 .33443 m .73131 .33574 L .72872 .3376 L F
.865 .982 .847 r
.72879 .33701 m .73042 .33619 L .7295 .33636 L F
.73042 .33619 m .73131 .33574 L .73098 .33585 L F
.73042 .33619 m .73098 .33585 L .7295 .33636 L F
.746 .551 .631 r
.72676 .33381 m .73036 .33443 L .72902 .33702 L F
.72856 .33729 m .72902 .33702 L .72872 .3376 L F
.72676 .33381 m .72902 .33702 L .72856 .33729 L F
.72846 .33782 m .72872 .3376 L .72853 .33798 L F
.72676 .33381 m .72872 .3376 L .72846 .33782 L F
.865 .982 .847 r
.72728 .33891 m .7273 .33963 L .73131 .33574 L F
.405 .455 .799 r
.72919 .33742 m .72852 .33794 L .72852 .33796 L F
.832 .663 .672 r
.72872 .3376 m .73131 .33574 L .72853 .33798 L F
.276 .304 .711 r
.7283 .33745 m .72519 .33632 L .72676 .33381 L F
.72808 .33765 m .72519 .33632 L .7283 .33745 L F
.72842 .33793 m .72519 .33632 L .72846 .33782 L F
.865 .982 .847 r
.72725 .33779 m .72829 .33791 L .73131 .33574 L F
.7295 .33636 m .73131 .33574 L .72973 .33622 L F
.72725 .33778 m .72879 .33701 L .7295 .33636 L F
.276 .304 .711 r
.72853 .33798 m .72842 .33793 L .72846 .33782 L F
.865 .982 .847 r
.72725 .33778 m .72725 .33779 L .72878 .33702 L F
.72879 .33701 m .72878 .33702 L .73131 .33574 L F
.72725 .33778 m .72878 .33702 L .72879 .33701 L F
.39 .764 .992 r
.73233 .33712 m .73198 .33671 L .7321 .33681 L F
.466 .236 .481 r
.73277 .33691 m .73288 .33509 L .732 .33703 L F
.521 .653 .918 r
.73277 .33658 m .73198 .33671 L .73036 .33443 L F
.39 .764 .992 r
.7321 .33681 m .73198 .33671 L .73202 .3367 L F
.73233 .33712 m .73202 .3367 L .73277 .33658 L F
.229 .114 .508 r
.73276 .33706 m .73269 .33734 L .73282 .33691 L F
.466 .236 .481 r
.73223 .33915 m .73267 .33733 L .73153 .33806 L F
.73267 .33733 m .73277 .33691 L .73246 .3372 L F
.39 .764 .992 r
.73269 .33734 m .73267 .33735 L .73233 .33712 L F
.466 .236 .481 r
.73267 .33733 m .73246 .3372 L .73153 .33806 L F
.39 .764 .992 r
.73233 .33712 m .73267 .33735 L .7319 .33714 L F
.73343 .33707 m .73269 .33734 L .73233 .33712 L F
.466 .236 .481 r
.7326 .33972 m .73424 .33777 L .73278 .33738 L F
.73424 .33777 m .73503 .33683 L .73278 .33738 L F
.7326 .33972 m .73282 .33691 L .73276 .33706 L F
.73276 .33706 m .73277 .33691 L .73223 .33915 L F
.73277 .33691 m .732 .33703 L .73153 .33806 L F
.229 .114 .508 r
.73282 .33691 m .73346 .33689 L .73358 .33604 L F
.117 0 0 r
.73358 .33604 m .73534 .33647 L .73621 .33469 L F
.73358 .33604 m .73346 .33689 L .73534 .33647 L F
.466 .236 .481 r
.73503 .33683 m .73534 .33647 L .73346 .33689 L F
.117 0 0 r
.73346 .33689 m .73343 .33707 L .73534 .33647 L F
.466 .236 .481 r
.73346 .33689 m .73534 .33647 L .73277 .33691 L F
.73277 .33691 m .73534 .33647 L .73288 .33509 L F
.888 .656 .582 r
.43159 .55812 m .43388 .55936 L .43242 .55619 L F
.871 .968 .854 r
.43087 .56099 m .43388 .55936 L .43159 .55812 L F
.803 .873 .899 r
.41699 .48538 m .41451 .48826 L .41204 .48642 L F
0 0 0 r
.25602 .52373 m .25776 .52261 L .25612 .52376 L F
.25602 .52373 m .25589 .52393 L .25776 .52261 L F
.828 .868 .875 r
.33344 .49641 m .32998 .49716 L .33181 .49574 L F
.303 .769 .942 r
.33181 .49574 m .3361 .49598 L .33344 .49641 L F
.264 0 .118 r
.31957 .57122 m .32188 .57103 L .32304 .56879 L F
0 0 .26 r
.32472 .56525 m .32304 .56879 L .32442 .56739 L F
.221 0 .097 r
.32304 .56879 m .32418 .57015 L .32442 .56739 L F
.32304 .56879 m .32188 .57103 L .32418 .57015 L F
0 .233 .633 r
.44143 .56317 m .4432 .56416 L .4429 .56395 L F
.696 .666 .816 r
.64695 .3985 m .64951 .40019 L .64439 .39952 L F
.726 .486 .563 r
.64439 .39952 m .64951 .40019 L .64867 .4023 L F
.902 .834 .77 r
.64967 .3957 m .64951 .40019 L .64695 .3985 L F
.981 .762 .535 r
.37906 .67924 m .38059 .68057 L .37973 .677 L F
.39 .799 .98 r
.38059 .68057 m .38062 .67702 L .37973 .677 L F
.38059 .68057 m .38147 .6795 L .38062 .67702 L F
.38059 .68057 m .3831 .68021 L .38147 .6795 L F
.38147 .6795 m .38059 .68057 L .37906 .67924 L F
.38147 .6795 m .3831 .68021 L .38059 .68057 L F
.802 .334 .119 r
.38983 .53012 m .3928 .53235 L .39256 .53295 L F
0 0 0 r
.22891 .53882 m .23214 .5362 L .23026 .53778 L F
.918 .658 .529 r
.31883 .54096 m .32114 .53996 L .3217 .5386 L F
.31883 .54096 m .32021 .54192 L .32114 .53996 L F
.568 .359 .556 r
.30133 .60975 m .30433 .60653 L .30141 .60693 L F
.843 .906 .497 r
.33544 .60233 m .3349 .60417 L .33372 .6064 L F
0 0 .454 r
.3225 .65742 m .32169 .65779 L .3215 .65444 L F
0 0 .425 r
.32311 .65946 m .32169 .65779 L .3225 .65742 L F
.385 .838 .919 r
.30019 .52384 m .29837 .52366 L .29589 .52435 L F
0 .468 .821 r
.29769 .52186 m .30287 .52393 L .30019 .52384 L F
.29769 .52186 m .30075 .52272 L .30287 .52393 L F
0 .173 .708 r
.30019 .52384 m .30075 .52272 L .29837 .52366 L F
.618 .348 .486 r
.30287 .52393 m .30245 .5263 L .30019 .52384 L F
0 .173 .708 r
.30019 .52384 m .30245 .5263 L .30075 .52272 L F
.91 .805 .731 r
.34915 .69528 m .35141 .69653 L .34909 .69759 L F
.021 .027 .522 r
.4276 .578 m .42855 .58094 L .42742 .58045 L F
.965 .637 .316 r
.42707 .58329 m .42742 .58045 L .42855 .58094 L F
.705 .426 .5 r
.71167 .31363 m .71175 .31605 L .70802 .31593 L F
.856 .848 .387 r
.71167 .31363 m .71255 .30963 L .7128 .31228 L F
.41 .403 .741 r
.7128 .31228 m .71175 .31605 L .71167 .31363 L F
.838 .713 .726 r
.60609 .36356 m .60669 .36814 L .6035 .36711 L F
.833 .443 .311 r
.6035 .36711 m .60669 .36814 L .60732 .37019 L F
.661 .59 .765 r
.60991 .36481 m .60669 .36814 L .60609 .36356 L F
.697 .873 .964 r
.38717 .649 m .38927 .64741 L .388 .64544 L F
.754 .619 .709 r
.64439 .39952 m .64556 .40321 L .64185 .40273 L F
.583 .403 .604 r
.64185 .40273 m .64373 .40389 L .64192 .40542 L F
.72 .987 .813 r
.64248 .40452 m .64373 .40389 L .64323 .40332 L F
.64192 .40542 m .64373 .40389 L .64248 .40452 L F
.684 .253 .221 r
.64185 .40273 m .64519 .40316 L .64373 .40389 L F
.64519 .40316 m .64556 .40321 L .64373 .40389 L F
.726 .486 .563 r
.64439 .39952 m .64867 .4023 L .64556 .40321 L F
.428 .865 .913 r
.64556 .40321 m .64737 .40223 L .64373 .40389 L F
.64556 .40321 m .64867 .4023 L .64737 .40223 L F
.39 .812 .629 r
.31547 .53602 m .3168 .53518 L .31885 .534 L F
.845 .99 .729 r
.31885 .534 m .31927 .53183 L .32132 .53287 L F
.31885 .534 m .3168 .53518 L .31927 .53183 L F
.271 .574 .94 r
.715 .28457 m .7122 .28399 L .71476 .28139 L F
.886 .851 .803 r
.59063 .3807 m .58674 .38262 L .58912 .38247 L F
.995 .784 .505 r
.59202 .38707 m .59029 .38861 L .59183 .38565 L F
.59202 .38707 m .5917 .39023 L .59029 .38861 L F
.79 .383 .279 r
.59175 .38294 m .59063 .3807 L .58912 .38247 L F
.997 .791 .503 r
.58912 .38247 m .59063 .3807 L .58939 .37939 L F
.439 .657 .952 r
.59481 .39982 m .59698 .40003 L .5961 .39781 L F
.035 0 .03 r
.35925 .66399 m .35752 .66503 L .35656 .66665 L F
.729 .948 .951 r
.33518 .5419 m .33293 .54321 L .33438 .54385 L F
.207 0 0 r
.35505 .71506 m .35341 .7173 L .35333 .71443 L F
.35505 .71506 m .35483 .71529 L .35341 .7173 L F
.35505 .71506 m .35746 .71553 L .35483 .71529 L F
.375 .343 .694 r
.44648 .5321 m .44434 .53463 L .44394 .53026 L F
.512 .503 .783 r
.44648 .5321 m .44537 .53658 L .44434 .53463 L F
.371 .558 .906 r
.36777 .60712 m .3707 .60747 L .36918 .60576 L F
.385 .487 .841 r
.36777 .60712 m .37118 .60884 L .3707 .60747 L F
.769 .748 .834 r
.42936 .54251 m .43111 .54406 L .43148 .54045 L F
.613 .608 .822 r
.43148 .54045 m .43111 .54406 L .43247 .54169 L F
.196 .395 .832 r
.43111 .54406 m .43445 .54414 L .43247 .54169 L F
.43111 .54406 m .43365 .54607 L .43445 .54414 L F
.702 .644 .789 r
.32504 .53352 m .32726 .53455 L .32779 .52977 L F
.517 .876 .645 r
.32493 .53624 m .32726 .53455 L .32504 .53352 L F
.32493 .53624 m .32624 .53497 L .32693 .53479 L F
.289 0 0 r
.32925 .53677 m .32717 .5367 L .32493 .53624 L F
0 .32 .715 r
.32834 .5368 m .32624 .53497 L .32717 .5367 L F
.33004 .53696 m .32834 .53607 L .32834 .5368 L F
.32834 .53607 m .32624 .53497 L .32834 .5368 L F
.869 .98 .687 r
.32834 .53746 m .32698 .54037 L .32792 .53777 L F
.32925 .53677 m .32834 .53822 L .32834 .53746 L F
.32834 .53822 m .32698 .54037 L .32834 .53746 L F
.814 .33 .021 r
.32132 .53287 m .32493 .53624 L .32504 .53352 L F
0 0 0 r
.32493 .53624 m .32316 .53775 L .3217 .5386 L F
.814 .33 .021 r
.32132 .53287 m .3229 .53533 L .32493 .53624 L F
.943 .641 .439 r
.3229 .53533 m .32316 .53775 L .32493 .53624 L F
.969 .665 .385 r
.3214 .53649 m .32316 .53775 L .3229 .53533 L F
.822 .878 .886 r
.32624 .53497 m .32316 .53775 L .3214 .53649 L F
.319 .629 .961 r
.32493 .53624 m .32717 .5367 L .32624 .53497 L F
.672 .558 .717 r
.32711 .53646 m .32316 .53775 L .32624 .53497 L F
.32711 .53646 m .32316 .53775 L .32624 .53497 L F
0 .32 .715 r
.32883 .53633 m .32825 .53584 L .32624 .53497 L F
.33004 .53696 m .32825 .53584 L .32883 .53633 L F
.139 .299 .765 r
.3264 .53525 m .32825 .53584 L .32711 .53646 L F
.343 0 0 r
.32624 .53497 m .32825 .53584 L .32585 .53507 L F
.822 .878 .886 r
.32624 .53497 m .3214 .53649 L .32389 .53521 L F
.343 0 0 r
.32624 .53497 m .32585 .53507 L .32556 .53498 L F
.517 .876 .645 r
.32693 .53479 m .32624 .53497 L .32726 .53455 L F
.343 0 0 r
.32556 .53498 m .32825 .53584 L .32624 .53497 L F
.864 .893 .47 r
.32726 .53455 m .32624 .53497 L .32771 .53074 L F
.951 .86 .441 r
.32624 .53497 m .32648 .53005 L .32771 .53074 L F
.32624 .53497 m .32556 .53498 L .32648 .53005 L F
.064 0 .444 r
.32825 .53584 m .32932 .533 L .32556 .53498 L F
.303 .673 .975 r
.32704 .53466 m .32825 .53584 L .32556 .53498 L F
0 0 0 r
.3276 .53531 m .32825 .53584 L .32704 .53466 L F
.3284 .53623 m .32825 .53584 L .3276 .53531 L F
.673 .207 .138 r
.43651 .5746 m .43893 .57668 L .44054 .57508 L F
.508 .821 .504 r
.44054 .57508 m .43893 .57668 L .44182 .57377 L F
.152 .448 .88 r
.59465 .40737 m .59392 .4086 L .59226 .40637 L F
.62 .075 0 r
.59457 .40988 m .59642 .41104 L .59392 .4086 L F
.59457 .40988 m .59392 .4086 L .59465 .40737 L F
.55 .268 .44 r
.59299 .45422 m .59306 .45638 L .59029 .45664 L F
.648 .344 .442 r
.5967 .45572 m .59299 .45422 L .59696 .45379 L F
.5967 .45572 m .59306 .45638 L .59299 .45422 L F
.506 .479 .761 r
.64287 .42152 m .64353 .42524 L .64586 .42447 L F
.308 .005 .277 r
.64586 .42447 m .64353 .42524 L .64339 .42697 L F
.354 .165 .481 r
.32828 .61284 m .33085 .60919 L .32852 .61012 L F
.741 .98 .915 r
.30575 .51314 m .31035 .51121 L .30874 .51055 L F
.834 .965 .89 r
.30874 .51055 m .31035 .51121 L .31191 .50953 L F
.95 .833 .397 r
.69872 .33602 m .69765 .33629 L .6968 .33407 L F
.69872 .33602 m .69809 .33885 L .69765 .33629 L F
.425 0 .026 r
.34053 .68042 m .34647 .67927 L .34155 .68155 L F
.655 .363 .464 r
.34647 .67927 m .34469 .6816 L .34155 .68155 L F
.34647 .67927 m .34719 .68024 L .34636 .68252 L F
.558 .516 .765 r
.22654 .58701 m .22418 .58768 L .22391 .5864 L F
.414 .463 .803 r
.22735 .59079 m .22418 .58768 L .22654 .58701 L F
.857 .921 .872 r
.53612 .41099 m .53819 .41178 L .53534 .41398 L F
.683 .917 .973 r
.53849 .41117 m .53819 .41178 L .53612 .41099 L F
.899 .684 .603 r
.3513 .6916 m .35346 .69003 L .35099 .68953 L F
.568 .067 0 r
.35429 .69107 m .35346 .69003 L .3513 .6916 L F
.35429 .69107 m .35581 .69256 L .35346 .69003 L F
.564 .169 .251 r
.60335 .45381 m .59949 .45594 L .59918 .45438 L F
.60335 .45381 m .60208 .45619 L .59949 .45594 L F
.654 .266 .298 r
.60335 .45381 m .60604 .45596 L .60208 .45619 L F
.637 .281 .35 r
.60595 .45417 m .60604 .45596 L .60335 .45381 L F
.73 .716 .838 r
.34949 .5267 m .35372 .52727 L .35193 .5244 L F
.399 .559 .896 r
.35193 .5244 m .35372 .52727 L .35479 .52529 L F
.287 .057 .38 r
.35239 .529 m .35479 .52529 L .35372 .52727 L F
.278 .138 .504 r
.35771 .52984 m .35712 .53334 L .35511 .53364 L F
.434 .184 .433 r
.35677 .53521 m .35471 .53594 L .35511 .53364 L F
.327 .155 .489 r
.31754 .57504 m .31938 .57476 L .31957 .57122 L F
.561 .339 .536 r
.31754 .57504 m .32013 .57728 L .31938 .57476 L F
.31754 .57504 m .3175 .5778 L .32013 .57728 L F
.896 .791 .737 r
.53936 .43694 m .54023 .44097 L .53786 .44079 L F
.953 .75 .591 r
.53835 .4439 m .53786 .44079 L .54023 .44097 L F
.958 .717 .531 r
.36136 .5173 m .35953 .51373 L .36298 .51642 L F
.772 .64 .715 r
.40396 .50114 m .40273 .50294 L .40031 .4986 L F
.796 .755 .816 r
.6856 .32954 m .68901 .32992 L .68824 .32801 L F
.531 .566 .835 r
.68901 .32992 m .69183 .3275 L .68824 .32801 L F
.68901 .32992 m .69152 .32922 L .69183 .3275 L F
.265 .119 .488 r
.61402 .42466 m .61309 .42475 L .61342 .42801 L F
.273 .364 .774 r
.39946 .64828 m .40237 .65036 L .4008 .65194 L F
0 0 .262 r
.4008 .65194 m .40195 .65302 L .40243 .65443 L F
.4008 .65194 m .40227 .65046 L .40195 .65302 L F
.004 .316 .805 r
.40004 .64709 m .40237 .65036 L .40081 .64924 L F
.40004 .64709 m .40081 .64924 L .39946 .64828 L F
0 0 .541 r
.39941 .64526 m .40004 .64709 L .39819 .64444 L F
.814 .332 0 r
.39946 .6455 m .40004 .64709 L .39941 .64526 L F
0 .023 .591 r
.39819 .64444 m .40004 .64709 L .39946 .64828 L F
.814 .332 0 r
.4004 .64925 m .40004 .64709 L .39946 .6455 L F
.961 .626 .267 r
.40142 .65202 m .40184 .64948 L .4004 .64925 L F
0 0 .235 r
.40099 .65065 m .40135 .65176 L .40142 .65202 L F
0 .048 .601 r
.40142 .65202 m .40188 .6536 L .40195 .65302 L F
0 0 .235 r
.40135 .65176 m .40218 .65437 L .40142 .65202 L F
0 .048 .601 r
.40142 .65202 m .4016 .6558 L .40188 .6536 L F
.4016 .6558 m .40163 .65626 L .40195 .65302 L F
0 0 .262 r
.40227 .65046 m .40237 .65036 L .40195 .65302 L F
.78 .537 .568 r
.42146 .55224 m .42582 .55556 L .42559 .55278 L F
.984 .715 .428 r
.42559 .55278 m .42676 .55301 L .428 .55121 L F
.78 .537 .568 r
.42146 .55224 m .42142 .55532 L .42582 .55556 L F
.984 .715 .428 r
.42559 .55278 m .42582 .55556 L .42426 .55457 L F
.42559 .55278 m .42426 .55457 L .42676 .55301 L F
.885 .69 .633 r
.37575 .57527 m .37388 .57789 L .37267 .57402 L F
.318 .418 .806 r
.38134 .57037 m .38094 .57394 L .38 .57121 L F
.49 .514 .809 r
.45422 .54813 m .45139 .54973 L .45031 .54642 L F
.445 .347 .65 r
.45422 .54813 m .45165 .55263 L .45139 .54973 L F
.688 .973 .917 r
.25044 .52581 m .25067 .5244 L .25343 .52516 L F
.25044 .52581 m .24863 .52582 L .25067 .5244 L F
.567 .359 .558 r
.29404 .61736 m .29099 .61981 L .29356 .61927 L F
.391 .139 .409 r
.31662 .60882 m .31482 .60712 L .31707 .60632 L F
.31662 .60882 m .31433 .60948 L .31482 .60712 L F
.376 .065 .304 r
.34166 .5785 m .341 .5806 L .33866 .58115 L F
.34337 .57991 m .34166 .5785 L .34394 .57798 L F
.34337 .57991 m .341 .5806 L .34166 .5785 L F
.606 .841 .988 r
.24596 .56545 m .24193 .56523 L .24352 .56199 L F
0 0 .482 r
.24497 .56394 m .24596 .56545 L .24352 .56199 L F
0 0 .348 r
.24657 .56633 m .24596 .56545 L .24497 .56394 L F
.24657 .56633 m .24726 .5684 L .24596 .56545 L F
.881 .93 .849 r
.62741 .38565 m .62693 .38842 L .62472 .38895 L F
.614 .121 .057 r
.62693 .38842 m .62975 .3898 L .62472 .38895 L F
.943 .603 .185 r
.56335 .42697 m .56382 .42528 L .56257 .42364 L F
.581 .85 .995 r
.56382 .42528 m .56661 .42449 L .56505 .42332 L F
.474 .713 .974 r
.56257 .42364 m .56382 .42528 L .56505 .42332 L F
.531 .32 .539 r
.56649 .42718 m .56661 .42449 L .56382 .42528 L F
.199 .346 .788 r
.56505 .42332 m .56649 .42718 L .56382 .42528 L F
0 0 0 r
.56505 .42332 m .56382 .42528 L .56335 .42697 L F
.81 .48 .43 r
.29391 .61022 m .2983 .61251 L .29614 .6133 L F
0 0 .352 r
.30936 .66875 m .30867 .67066 L .30853 .6679 L F
.746 .988 .892 r
.30738 .67051 m .30867 .67066 L .30936 .66875 L F
.59 .15 .173 r
.60595 .45417 m .60997 .45402 L .60956 .45599 L F
0 0 .014 r
.60956 .45599 m .60997 .45402 L .61178 .45243 L F
.654 .913 .605 r
.64584 .43716 m .64559 .43714 L .64276 .44027 L F
.685 .913 .578 r
.64703 .43518 m .64584 .43716 L .64896 .43488 L F
.64703 .43518 m .64559 .43714 L .64584 .43716 L F
.269 0 .207 r
.36055 .51143 m .35728 .51441 L .35761 .51207 L F
.36055 .51143 m .35953 .51373 L .35728 .51441 L F
0 .096 .636 r
.70777 .30536 m .70795 .30626 L .70629 .30307 L F
.70777 .30536 m .70915 .30739 L .70795 .30626 L F
.378 .051 .28 r
.33465 .57768 m .33691 .5772 L .33757 .57531 L F
.237 0 .218 r
.33757 .57531 m .33898 .57629 L .34011 .57489 L F
.33757 .57531 m .33691 .5772 L .33898 .57629 L F
.299 0 .207 r
.33866 .58115 m .33763 .58354 L .3356 .58312 L F
.466 .21 .441 r
.33763 .58354 m .33484 .58631 L .3356 .58312 L F
.223 .458 .874 r
.38892 .51441 m .39151 .5176 L .39234 .51588 L F
.268 .514 .904 r
.39151 .5176 m .39582 .51929 L .39234 .51588 L F
.939 .941 .601 r
.40199 .60257 m .40372 .60086 L .40288 .59897 L F
.40199 .60257 m .40254 .60318 L .40372 .60086 L F
0 0 .516 r
.36313 .57974 m .36174 .5795 L .36624 .57897 L F
.36313 .57974 m .36201 .58141 L .36174 .5795 L F
.686 .667 .826 r
.37262 .58166 m .37388 .57789 L .37143 .57889 L F
.37262 .58166 m .37529 .58151 L .37388 .57789 L F
.668 .514 .667 r
.37529 .58151 m .37195 .58508 L .37262 .58166 L F
.094 0 0 r
.37262 .58166 m .37326 .58259 L .37529 .58151 L F
.37262 .58166 m .37102 .58347 L .37326 .58259 L F
.578 .52 .754 r
.36925 .61336 m .37175 .61269 L .37118 .60884 L F
.517 .324 .558 r
.36925 .61336 m .36915 .61604 L .37175 .61269 L F
0 .187 .609 r
.3921 .59791 m .39335 .59866 L .39059 .59883 L F
.39271 .59829 m .39558 .60011 L .39335 .59866 L F
.862 .839 .821 r
.39558 .60011 m .39356 .6019 L .39335 .59866 L F
.005 0 .088 r
.39335 .59866 m .39444 .59995 L .3941 .5991 L F
.39335 .59866 m .3941 .5991 L .39339 .59732 L F
0 .187 .609 r
.3921 .59791 m .39271 .59829 L .39335 .59866 L F
.736 .579 .679 r
.64682 .38036 m .65028 .38034 L .64936 .37723 L F
.688 .628 .784 r
.64818 .37309 m .64936 .37723 L .65194 .37399 L F
.627 .539 .735 r
.64936 .37723 m .65222 .37668 L .65194 .37399 L F
.597 .483 .694 r
.65028 .38034 m .65222 .37668 L .64936 .37723 L F
.69 .528 .663 r
.38094 .57394 m .37758 .57914 L .37802 .57552 L F
.318 .418 .806 r
.38134 .57037 m .38289 .57432 L .38094 .57394 L F
.309 .785 .691 r
.56625 .41314 m .56458 .41394 L .56402 .41501 L F
.56625 .41314 m .56784 .41257 L .56458 .41394 L F
.411 .233 .527 r
.31565 .58393 m .3179 .58068 L .31608 .5816 L F
0 0 .506 r
.70679 .313 m .70764 .31292 L .70727 .30957 L F
0 .058 .58 r
.70679 .313 m .70802 .31593 L .70764 .31292 L F
.756 .695 .794 r
.67656 .3462 m .67885 .34524 L .67759 .34138 L F
.73 .606 .719 r
.67656 .3462 m .67619 .34858 L .67885 .34524 L F
0 0 .345 r
.30488 .53018 m .30475 .53298 L .304 .5329 L F
0 0 .185 r
.30475 .53298 m .30384 .53537 L .304 .5329 L F
.464 .484 .794 r
.65162 .38775 m .65252 .38975 L .65479 .38919 L F
.376 .18 .483 r
.65479 .38919 m .65252 .38975 L .65255 .39283 L F
.484 .374 .654 r
.43914 .49504 m .43938 .49775 L .43704 .49836 L F
.534 .508 .773 r
.44051 .50138 m .43704 .49836 L .43938 .49775 L F
0 .076 .59 r
.42898 .57746 m .42689 .57528 L .43001 .57461 L F
.411 .083 .297 r
.45985 .57988 m .45765 .57865 L .45975 .57887 L F
.45985 .57988 m .45728 .58044 L .45765 .57865 L F
0 0 .453 r
.60296 .41768 m .60161 .41566 L .60077 .41395 L F
.579 .419 .628 r
.31576 .52086 m .31996 .52077 L .31812 .51886 L F
.407 .775 .994 r
.31151 .54118 m .3158 .54206 L .31345 .54191 L F
.568 .417 .636 r
.44207 .51057 m .43874 .50852 L .44147 .50633 L F
.44207 .51057 m .43919 .51149 L .43874 .50852 L F
.139 .132 .587 r
.38987 .65484 m .38805 .65481 L .38967 .65313 L F
.995 .754 .422 r
.40335 .56169 m .4033 .56427 L .40424 .56433 L F
.992 .868 .531 r
.4033 .56427 m .40345 .56882 L .40424 .56433 L F
.721 .221 .046 r
.27827 .62447 m .28187 .62578 L .28199 .62273 L F
.935 .576 .165 r
.40447 .58288 m .40502 .58152 L .40471 .58034 L F
.40447 .58288 m .40569 .58405 L .40502 .58152 L F
.546 .375 .601 r
.22933 .56286 m .22884 .56523 L .23132 .56197 L F
.558 .846 .517 r
.35849 .68379 m .35671 .68579 L .35815 .68133 L F
0 0 .266 r
.35672 .68583 m .35587 .68373 L .35553 .68289 L F
.35623 .68461 m .35553 .68289 L .35513 .6819 L F
.35672 .68583 m .35553 .68289 L .35623 .68461 L F
0 0 0 r
.35576 .68621 m .35441 .68664 L .35672 .68583 L F
.35192 .68773 m .35394 .68684 L .35576 .68621 L F
.35394 .68684 m .35441 .68664 L .35576 .68621 L F
.35192 .68773 m .35672 .68583 L .35336 .68735 L F
.589 .768 .965 r
.35128 .68437 m .35654 .68594 L .35507 .68365 L F
.35654 .68594 m .35657 .68595 L .35656 .68593 L F
.35654 .68594 m .35656 .68593 L .35507 .68365 L F
0 0 .266 r
.35672 .68583 m .35513 .6819 L .35657 .68595 L F
.558 .846 .517 r
.35671 .68579 m .35657 .68595 L .35666 .68568 L F
.35671 .68579 m .35666 .68568 L .35815 .68133 L F
.78 .745 .821 r
.56875 .40535 m .57166 .40656 L .56864 .40793 L F
.909 .762 .688 r
.56864 .40793 m .57166 .40656 L .57028 .40948 L F
0 0 .037 r
.2937 .6574 m .2949 .65466 L .29652 .65429 L F
0 .026 .567 r
.70852 .36237 m .70777 .36436 L .70925 .36664 L F
.954 .744 .582 r
.42808 .53896 m .42936 .54251 L .42988 .53928 L F
.769 .748 .834 r
.42936 .54251 m .43148 .54045 L .42988 .53928 L F
.154 .13 .576 r
.43011 .54002 m .4309 .54218 L .42936 .54251 L F
.604 .034 0 r
.42988 .53928 m .43148 .54045 L .42975 .5397 L F
.42915 .53915 m .42975 .5397 L .42808 .53896 L F
.42988 .53928 m .42975 .5397 L .42915 .53915 L F
.591 .693 .913 r
.42808 .53896 m .43148 .54045 L .43064 .53823 L F
.154 .13 .576 r
.43064 .53823 m .4308 .54065 L .43011 .54002 L F
.4308 .54065 m .4309 .54218 L .43011 .54002 L F
.544 .852 .546 r
.20901 .56528 m .21028 .56389 L .21197 .56233 L F
0 0 0 r
.21197 .56233 m .21301 .56117 L .21447 .55906 L F
.21197 .56233 m .21132 .56299 L .21301 .56117 L F
.21197 .56233 m .21028 .56389 L .21132 .56299 L F
.777 .646 .717 r
.67379 .35444 m .67751 .35518 L .67612 .35097 L F
.682 .45 .563 r
.67517 .35786 m .67751 .35518 L .67379 .35444 L F
.67517 .35786 m .67772 .35754 L .67751 .35518 L F
.757 .635 .726 r
.67612 .35097 m .67751 .35518 L .67816 .35257 L F
.712 .437 .507 r
.68207 .35756 m .67751 .35518 L .67772 .35754 L F
.599 .554 .775 r
.45624 .55829 m .45349 .55907 L .45253 .55533 L F
0 .469 .741 r
.42956 .55139 m .43018 .5516 L .428 .55121 L F
.42956 .55139 m .428 .55121 L .42676 .55301 L F
.525 .179 .322 r
.29042 .63535 m .29297 .63723 L .29036 .63814 L F
.29042 .63535 m .2936 .63511 L .29297 .63723 L F
.015 0 .06 r
.29464 .55188 m .29207 .5548 L .29302 .55288 L F
.567 .742 .959 r
.33147 .69829 m .3335 .69788 L .33225 .69581 L F
.081 0 .252 r
.30681 .60045 m .30822 .59992 L .30897 .59718 L F
.228 .221 .643 r
.30681 .60045 m .30885 .60268 L .30822 .59992 L F
.419 .254 .548 r
.30666 .60334 m .30885 .60268 L .30681 .60045 L F
.663 .456 .595 r
.68478 .3735 m .68205 .3766 L .68216 .37431 L F
.556 .391 .613 r
.32485 .59374 m .32473 .59727 L .32218 .59724 L F
.39 .207 .508 r
.32441 .59928 m .32218 .59724 L .32473 .59727 L F
.32441 .59928 m .32229 .60003 L .32218 .59724 L F
.495 .829 .999 r
.39416 .64394 m .39819 .64444 L .39759 .64513 L F
.498 .122 .257 r
.59029 .45664 m .58657 .45899 L .58773 .45673 L F
0 0 0 r
.42811 .5204 m .42537 .52358 L .42646 .52216 L F
.565 .895 .984 r
.28109 .525 m .28033 .5265 L .28234 .52531 L F
.28109 .525 m .27882 .52595 L .28033 .5265 L F
.245 .515 .909 r
.26154 .6181 m .26088 .61974 L .25969 .61811 L F
.243 .512 .908 r
.26154 .6181 m .26271 .6201 L .26088 .61974 L F
.398 .116 .364 r
.25895 .56554 m .26078 .56697 L .26152 .56557 L F
.25895 .56554 m .25843 .56772 L .26078 .56697 L F
.791 .664 .723 r
.67247 .34789 m .67619 .34858 L .67656 .3462 L F
.795 .647 .698 r
.67386 .3517 m .67619 .34858 L .67247 .34789 L F
.72 .537 .642 r
.67386 .3517 m .67612 .35097 L .67619 .34858 L F
.401 0 0 r
.70038 .30764 m .70336 .30898 L .69969 .30784 L F
.649 .442 .589 r
.36306 .64804 m .36592 .64765 L .36623 .64511 L F
.512 .346 .593 r
.36623 .64511 m .3681 .64429 L .36876 .64174 L F
.74 .62 .725 r
.36592 .64765 m .3681 .64429 L .36623 .64511 L F
.997 .857 .569 r
.43101 .55446 m .43159 .55812 L .43242 .55619 L F
.809 .921 .912 r
.43101 .55446 m .43242 .55619 L .43558 .55321 L F
.562 .084 .078 r
.38724 .60795 m .3919 .60742 L .38965 .60901 L F
0 .141 .669 r
.39229 .60561 m .3919 .60742 L .39018 .60335 L F
.852 .987 .715 r
.38965 .60901 m .3919 .60742 L .39229 .60561 L F
.841 .451 .308 r
.25966 .57304 m .26005 .57389 L .2578 .57296 L F
.651 .618 .803 r
.64818 .38661 m .65059 .38365 L .64687 .38293 L F
.64818 .38661 m .6509 .3859 L .65059 .38365 L F
.65 .612 .798 r
.64818 .38661 m .65162 .38775 L .6509 .3859 L F
.33 0 .156 r
.36172 .51928 m .35967 .52225 L .35729 .52268 L F
.583 .831 .462 r
.35827 .52238 m .35729 .52268 L .35967 .52225 L F
.35718 .52248 m .35729 .52268 L .35827 .52238 L F
0 0 .405 r
.35657 .52291 m .35729 .52268 L .35634 .52396 L F
.35729 .51965 m .35729 .52268 L .35657 .52291 L F
.679 .225 .168 r
.35479 .52529 m .35634 .52396 L .35729 .52268 L F
.35479 .52529 m .35858 .52604 L .35634 .52396 L F
.645 .204 .187 r
.56852 .42563 m .57019 .42448 L .56661 .42449 L F
.56981 .42641 m .56995 .42569 L .56852 .42563 L F
.56995 .42569 m .57019 .42448 L .56852 .42563 L F
.209 0 0 r
.56661 .42449 m .57019 .42448 L .56964 .42474 L F
.564 .35 .549 r
.56964 .42474 m .56505 .42332 L .56661 .42449 L F
.56964 .42474 m .56849 .42563 L .56505 .42332 L F
.645 .204 .187 r
.56981 .42641 m .56661 .42449 L .56649 .42718 L F
.564 .35 .549 r
.56849 .42563 m .56649 .42718 L .56588 .42553 L F
.56849 .42563 m .56588 .42553 L .56505 .42332 L F
.607 .901 .614 r
.57019 .42448 m .5715 .42279 L .56964 .42474 L F
.57019 .42448 m .57284 .42186 L .5715 .42279 L F
.446 .211 .463 r
.5723 .42553 m .57284 .42186 L .57019 .42448 L F
.344 .286 .648 r
.57019 .42448 m .57335 .42796 L .5723 .42553 L F
.672 .402 .503 r
.5723 .42553 m .5748 .42272 L .57284 .42186 L F
.5723 .42553 m .57552 .42341 L .5748 .42272 L F
.531 .186 .328 r
.57533 .42627 m .57552 .42341 L .5723 .42553 L F
.57533 .42627 m .5723 .42553 L .57335 .42796 L F
.086 .219 .706 r
.5715 .42279 m .57335 .42796 L .57019 .42448 L F
.57039 .42517 m .57019 .42448 L .56981 .42641 L F
.582 .504 .732 r
.56815 .42977 m .56981 .42641 L .56649 .42718 L F
.564 .35 .549 r
.56964 .42474 m .56981 .42641 L .56649 .42718 L F
0 0 .328 r
.56748 .42752 m .56649 .42718 L .56981 .42641 L F
0 0 .378 r
.56991 .42484 m .56981 .42641 L .56964 .42474 L F
.995 .843 .579 r
.56748 .42752 m .56981 .42641 L .56991 .42484 L F
.086 .219 .706 r
.5715 .42279 m .57072 .4238 L .57039 .42517 L F
.57072 .4238 m .57019 .42448 L .57039 .42517 L F
.5715 .42279 m .56981 .42641 L .56991 .42484 L F
.68 .574 .73 r
.56981 .42641 m .57052 .43158 L .57335 .42796 L F
.56981 .42641 m .57335 .42796 L .57171 .42864 L F
.56981 .42641 m .57171 .42864 L .56991 .42484 L F
.995 .843 .579 r
.56748 .42752 m .56991 .42484 L .57028 .42563 L F
.582 .504 .732 r
.56815 .42977 m .57052 .43158 L .56981 .42641 L F
.995 .843 .579 r
.56969 .42811 m .57028 .42563 L .57171 .42864 L F
.56748 .42752 m .57028 .42563 L .56969 .42811 L F
.524 .915 .804 r
.34697 .65943 m .3494 .65863 L .35139 .65738 L F
.631 .335 .45 r
.43712 .59118 m .43674 .59343 L .43403 .59359 L F
.59 .334 .497 r
.43948 .5906 m .43674 .59343 L .43712 .59118 L F
.587 .336 .504 r
.68771 .37094 m .68748 .37284 L .68478 .3735 L F
.3 .108 .444 r
.69063 .36735 m .69053 .36968 L .68771 .37094 L F
.328 .137 .462 r
.69053 .36968 m .68748 .37284 L .68771 .37094 L F
.74 .358 0 r
.39874 .52421 m .39964 .52632 L .39789 .52284 L F
.021 0 .036 r
.32089 .61939 m .31793 .62295 L .31945 .62195 L F
.462 0 .019 r
.32166 .62121 m .32089 .61939 L .31945 .62195 L F
.32166 .62121 m .32355 .61941 L .32089 .61939 L F
.93 .766 .657 r
.39753 .68889 m .39917 .69292 L .39961 .68978 L F
.751 .683 .137 r
.64896 .43488 m .64944 .43027 L .64974 .43243 L F
.824 .999 .836 r
.64974 .43243 m .64703 .43518 L .64896 .43488 L F
.925 .552 .281 r
.69585 .31366 m .69407 .31268 L .6945 .31479 L F
.872 .849 .818 r
.69684 .30857 m .69585 .31366 L .69742 .30945 L F
.69684 .30857 m .69407 .31268 L .69585 .31366 L F
.991 .732 .406 r
.6945 .31479 m .69581 .31624 L .69585 .31366 L F
.897 .968 .822 r
.60417 .38331 m .60253 .38552 L .6018 .38389 L F
.57 .728 .948 r
.60193 .38453 m .59854 .38701 L .59699 .38614 L F
.306 .796 .769 r
.59797 .38554 m .60192 .38453 L .59699 .38614 L F
.842 .952 .887 r
.6018 .38389 m .60192 .38453 L .59797 .38554 L F
.897 .968 .822 r
.60192 .38451 m .60182 .38456 L .60181 .38434 L F
.60193 .38453 m .60192 .38453 L .60192 .38451 L F
.60192 .38453 m .60182 .38456 L .60192 .38451 L F
.60253 .38552 m .60181 .38434 L .6018 .38389 L F
.842 .952 .887 r
.6018 .38389 m .60193 .38453 L .60192 .38453 L F
.306 .796 .769 r
.60192 .38453 m .60193 .38453 L .60193 .38453 L F
.60192 .38453 m .60193 .38453 L .59699 .38614 L F
.897 .968 .822 r
.60253 .38552 m .60186 .38641 L .60182 .38456 L F
.60253 .38552 m .60182 .38456 L .60193 .38453 L F
.57 .728 .948 r
.60193 .38453 m .60193 .38453 L .60193 .38453 L F
.60193 .38453 m .59854 .38701 L .60193 .38453 L F
.60193 .38453 m .60186 .38641 L .59854 .38701 L F
.473 .824 .997 r
.60186 .38641 m .60255 .38664 L .59854 .38701 L F
.761 .916 .942 r
.71144 .34123 m .70801 .34187 L .70971 .34053 L F
.704 .777 .908 r
.71307 .33768 m .71144 .34123 L .70971 .34053 L F
.71307 .33768 m .71495 .33994 L .71144 .34123 L F
.788 .449 0 r
.40879 .54315 m .40811 .54195 L .40747 .5399 L F
.818 .591 .035 r
.40879 .54315 m .40865 .54438 L .40811 .54195 L F
.40879 .54315 m .40909 .54617 L .40865 .54438 L F
.671 .721 .887 r
.2924 .615 m .29404 .61736 L .29597 .61598 L F
.569 .42 .639 r
.29356 .61927 m .29597 .61598 L .29404 .61736 L F
.562 .281 .446 r
.36 .7152 m .3617 .71764 L .35897 .71537 L F
.286 .786 .847 r
.35746 .71553 m .36104 .71503 L .36 .7152 L F
.357 .789 .969 r
.35746 .71553 m .36 .7152 L .35803 .71459 L F
.562 .281 .446 r
.36 .7152 m .35897 .71537 L .35803 .71459 L F
.286 .786 .847 r
.36104 .71503 m .36146 .71498 L .36 .7152 L F
.109 .663 .76 r
.36146 .71498 m .3626 .71478 L .36 .7152 L F
.36146 .71498 m .36391 .71475 L .3626 .71478 L F
.245 .291 .713 r
.34113 .5992 m .34229 .60272 L .34058 .60361 L F
0 0 .179 r
.341 .60464 m .34058 .60361 L .34229 .60272 L F
.341 .60464 m .34101 .60674 L .34058 .60361 L F
.668 .514 .667 r
.37529 .58151 m .37741 .58365 L .37195 .58508 L F
.753 .702 .804 r
.37388 .57789 m .37529 .58151 L .37758 .57914 L F
.479 0 0 r
.37574 .58204 m .37529 .58151 L .37326 .58259 L F
0 .178 .701 r
.37764 .5834 m .37741 .58365 L .37529 .58151 L F
.479 0 0 r
.37574 .58204 m .37764 .5834 L .37529 .58151 L F
.543 .267 .447 r
.58134 .46028 m .58393 .46217 L .58118 .46252 L F
.517 .279 .492 r
.58408 .45973 m .58393 .46217 L .58134 .46028 L F
.791 .664 .723 r
.67247 .34789 m .67656 .3462 L .67486 .3445 L F
.756 .695 .794 r
.67656 .3462 m .67759 .34138 L .67486 .3445 L F
.826 .957 .899 r
.53277 .41877 m .52983 .422 L .52857 .42152 L F
.68 .141 0 r
.52983 .422 m .52892 .42309 L .52857 .42152 L F
.52983 .422 m .53212 .42394 L .52892 .42309 L F
.558 .516 .765 r
.22654 .58701 m .22391 .5864 L .22638 .58627 L F
.542 .735 .964 r
.64253 .39726 m .64439 .39952 L .63993 .39764 L F
.787 .67 .735 r
.63993 .39764 m .64439 .39952 L .64185 .40273 L F
.713 .77 .897 r
.6461 .39568 m .64439 .39952 L .64253 .39726 L F
.6461 .39568 m .64695 .3985 L .64439 .39952 L F
.89 .99 .768 r
.42936 .54251 m .42699 .54594 L .42716 .54616 L F
0 0 .022 r
.64437 .41725 m .6445 .41554 L .64174 .41903 L F
.539 .85 .545 r
.64796 .4121 m .6445 .41554 L .6462 .41373 L F
0 0 0 r
.6462 .41373 m .6445 .41554 L .64437 .41725 L F
.582 .522 .753 r
.4599 .56138 m .46088 .56564 L .45853 .56631 L F
.768 .263 0 r
.71881 .34186 m .71995 .34259 L .71741 .34019 L F
.551 .755 .972 r
.7097 .36871 m .71222 .36615 L .70925 .36664 L F
.7097 .36871 m .71374 .36774 L .71222 .36615 L F
.828 .995 .756 r
.31891 .66332 m .31981 .66325 L .31665 .66682 L F
.19 .65 .941 r
.34661 .49809 m .34892 .49827 L .35041 .49922 L F
.038 .512 .884 r
.35169 .49877 m .35041 .49922 L .34892 .49827 L F
.35169 .49877 m .35321 .49995 L .35041 .49922 L F
.795 .783 .281 r
.38247 .62913 m .38147 .63303 L .38196 .63177 L F
.381 .091 .342 r
.31987 .60077 m .31925 .60297 L .31698 .60349 L F
.487 .23 .45 r
.32229 .60003 m .31925 .60297 L .31987 .60077 L F
.427 .228 .506 r
.23091 .57435 m .23102 .57883 L .22801 .5785 L F
.44 .259 .538 r
.23102 .57883 m .22744 .58156 L .22801 .5785 L F
.326 .253 .619 r
.20545 .59495 m .20651 .59454 L .20717 .59008 L F
.405 .477 .821 r
.20545 .59495 m .2083 .59617 L .20651 .59454 L F
.267 .6 .952 r
.39614 .52044 m .39655 .51904 L .39582 .51929 L F
0 .046 .61 r
.39614 .52044 m .39789 .52284 L .39655 .51904 L F
0 0 0 r
.21447 .55906 m .21435 .55964 L .21557 .55745 L F
.21447 .55906 m .21301 .56117 L .21435 .55964 L F
.56 .808 .991 r
.34719 .68024 m .35037 .68054 L .34891 .67929 L F
.34719 .68024 m .35037 .68054 L .34891 .67929 L F
.34 .695 .982 r
.3523 .68038 m .35037 .68054 L .34891 .67929 L F
.958 .829 .675 r
.4432 .56416 m .43985 .56718 L .4429 .56395 L F
.4432 .56416 m .44118 .56934 L .43985 .56718 L F
.499 .585 .872 r
.39059 .59883 m .39018 .60335 L .38831 .59969 L F
.39059 .59883 m .39242 .60301 L .39018 .60335 L F
0 .141 .669 r
.39229 .60561 m .39018 .60335 L .39242 .60301 L F
.065 0 0 r
.30299 .55855 m .29976 .56088 L .30097 .55943 L F
.734 .498 .571 r
.64687 .38293 m .65028 .38034 L .64682 .38036 L F
.64687 .38293 m .65059 .38365 L .65028 .38034 L F
.597 .483 .694 r
.65028 .38034 m .6532 .38001 L .65222 .37668 L F
.576 .381 .58 r
.65059 .38365 m .6532 .38001 L .65028 .38034 L F
.828 .891 .887 r
.65825 .3395 m .65391 .34105 L .6568 .33795 L F
.867 .877 .842 r
.65955 .33482 m .65825 .3395 L .6568 .33795 L F
.65955 .33482 m .66095 .3363 L .65825 .3395 L F
0 0 .155 r
.31492 .5398 m .31544 .53851 L .31547 .53602 L F
.706 .941 .639 r
.26788 .54663 m .26697 .54814 L .26834 .54697 L F
.992 .868 .531 r
.4033 .56427 m .40222 .56764 L .40345 .56882 L F
.773 .541 0 r
.40222 .56764 m .40295 .57146 L .40345 .56882 L F
.607 .349 .5 r
.37195 .58508 m .37294 .58707 L .37292 .58695 L F
.37195 .58508 m .37741 .58365 L .37294 .58707 L F
.203 .645 .948 r
.34275 .49663 m .34661 .49809 L .34509 .49767 L F
.512 .503 .783 r
.44648 .5321 m .44765 .53608 L .44537 .53658 L F
.523 .478 .748 r
.44826 .53992 m .44537 .53658 L .44765 .53608 L F
.747 .778 .878 r
.42355 .48515 m .41945 .48452 L .42218 .48174 L F
.8 .694 .748 r
.42355 .48515 m .42125 .48611 L .41945 .48452 L F
.815 .809 .845 r
.426 .48178 m .42355 .48515 L .42218 .48174 L F
0 0 .064 r
.31565 .58393 m .31354 .58771 L .31543 .58639 L F
.309 .151 .497 r
.31354 .58771 m .31585 .5895 L .31543 .58639 L F
.31354 .58771 m .3133 .59075 L .31585 .5895 L F
.021 0 .099 r
.34075 .59665 m .33922 .5975 L .33855 .59937 L F
.993 .879 .576 r
.40329 .576 m .40485 .57522 L .40358 .57274 L F
.40329 .576 m .40401 .57766 L .40485 .57522 L F
.754 .715 .816 r
.35393 .65377 m .357 .65357 L .35644 .65092 L F
.726 .823 .925 r
.357 .65357 m .35891 .65036 L .35644 .65092 L F
.357 .65357 m .3607 .65173 L .35891 .65036 L F
.451 .157 .373 r
.34053 .68042 m .34 .68283 L .33744 .68321 L F
.425 0 .026 r
.34053 .68042 m .34155 .68155 L .34 .68283 L F
.577 .481 .709 r
.43707 .48492 m .4357 .48873 L .43407 .48568 L F
.43707 .48492 m .43763 .48894 L .4357 .48873 L F
.581 .457 .676 r
.43763 .48894 m .43545 .49203 L .4357 .48873 L F
.956 .623 .234 r
.37443 .55195 m .37489 .55447 L .37651 .55589 L F
.505 .586 .869 r
.37443 .55195 m .37651 .55589 L .37773 .55443 L F
0 0 .257 r
.37651 .55589 m .37612 .55836 L .37773 .55443 L F
.37651 .55589 m .37612 .55836 L .37773 .55443 L F
.22 0 .118 r
.34395 .59069 m .34083 .59285 L .343 .59283 L F
.318 .148 .486 r
.34083 .59285 m .34329 .59583 L .343 .59283 L F
.34083 .59285 m .34075 .59665 L .34329 .59583 L F
0 0 .234 r
.3627 .58245 m .36201 .58141 L .36313 .57974 L F
.3627 .58245 m .36218 .58415 L .36201 .58141 L F
.611 .222 .281 r
.56806 .46336 m .56433 .46567 L .5658 .463 L F
.56806 .46336 m .56832 .46519 L .56433 .46567 L F
.685 .412 .503 r
.57233 .46253 m .56832 .46519 L .56806 .46336 L F
.809 .346 0 r
.61257 .43428 m .61024 .43148 L .61115 .43328 L F
.866 .46 .258 r
.61115 .43328 m .61346 .43577 L .61257 .43428 L F
.444 .067 .229 r
.61257 .43428 m .61346 .43577 L .61539 .43414 L F
.993 .861 .597 r
.53693 .43176 m .53522 .4343 L .53706 .43047 L F
.812 .631 .657 r
.53936 .43694 m .53522 .4343 L .53693 .43176 L F
.756 .83 .368 r
.27166 .53323 m .27291 .52969 L .27034 .53044 L F
.27166 .53323 m .27204 .53155 L .27291 .52969 L F
.536 .279 .473 r
.27204 .53155 m .27477 .52915 L .27291 .52969 L F
.27477 .52915 m .27523 .52875 L .27291 .52969 L F
.756 .83 .368 r
.27034 .53044 m .27291 .52969 L .2699 .52952 L F
0 0 .118 r
.27051 .53418 m .27204 .53155 L .27166 .53323 L F
.517 .311 .54 r
.27429 .53269 m .27151 .53643 L .27166 .53323 L F
0 0 .174 r
.32698 .54037 m .32755 .54137 L .32792 .53777 L F
.217 0 .28 r
.27169 .56793 m .26914 .57105 L .26986 .56878 L F
.729 .262 .142 r
.2218 .57301 m .22383 .57173 L .2247 .57016 L F
.2218 .57301 m .22581 .5741 L .22383 .57173 L F
.587 .275 .408 r
.22383 .57173 m .22581 .5741 L .22638 .57144 L F
.668 .613 .785 r
.3515 .65463 m .35393 .65377 L .35379 .65152 L F
.987 .737 .461 r
.34982 .65674 m .35139 .65738 L .3515 .65463 L F
.371 .271 .61 r
.44558 .52677 m .44595 .52963 L .44394 .53026 L F
.394 .341 .68 r
.44595 .52963 m .44648 .5321 L .44394 .53026 L F
.037 0 0 r
.23716 .54995 m .23566 .55004 L .23884 .54899 L F
.23716 .54995 m .23453 .55144 L .23566 .55004 L F
.751 .61 .701 r
.63867 .35814 m .64017 .36131 L .63633 .36134 L F
.452 .369 .672 r
.44292 .51495 m .44111 .51749 L .44008 .51349 L F
.44292 .51495 m .44335 .51709 L .44111 .51749 L F
.697 .709 .858 r
.39685 .68022 m .39757 .68099 L .39628 .68226 L F
.076 0 0 r
.29479 .56426 m .29372 .56481 L .2911 .56504 L F
.071 .245 .737 r
.29597 .56333 m .29479 .56426 L .2941 .56183 L F
.452 .85 .657 r
.29597 .56333 m .29372 .56481 L .29479 .56426 L F
.242 .705 .948 r
.26692 .63115 m .2704 .63226 L .268 .63174 L F
.709 .201 .023 r
.2704 .63226 m .26883 .63317 L .268 .63174 L F
0 .252 .764 r
.2704 .63226 m .27184 .63393 L .27252 .6344 L F
.27184 .63393 m .27361 .63598 L .27252 .6344 L F
.083 .539 .905 r
.27361 .63598 m .27561 .63586 L .27252 .6344 L F
.391 0 0 r
.27252 .6344 m .27561 .63586 L .27372 .63523 L F
.27252 .6344 m .27372 .63523 L .27231 .63477 L F
.709 .201 .023 r
.2704 .63226 m .27252 .6344 L .26883 .63317 L F
0 .275 .78 r
.61539 .44099 m .61775 .44419 L .61758 .44289 L F
0 .19 .694 r
.61775 .44419 m .61898 .44455 L .61758 .44289 L F
.61775 .44419 m .62051 .44619 L .61898 .44455 L F
.548 .414 .65 r
.28953 .61397 m .29153 .61442 L .29204 .61159 L F
.559 .373 .585 r
.28953 .61397 m .2924 .615 L .29153 .61442 L F
.716 .783 .905 r
.60213 .36241 m .60348 .36439 L .59954 .36382 L F
.787 .685 .752 r
.60348 .36439 m .60094 .36792 L .59954 .36382 L F
.481 .275 .522 r
.6035 .36711 m .60094 .36792 L .60348 .36439 L F
.684 .771 .917 r
.60609 .36356 m .60348 .36439 L .60213 .36241 L F
.838 .713 .726 r
.60609 .36356 m .6035 .36711 L .60348 .36439 L F
.434 .205 .466 r
.63766 .3995 m .64054 .3963 L .63993 .39764 L F
.63766 .3995 m .64054 .3963 L .63993 .39764 L F
.785 .563 .599 r
.37443 .55195 m .37637 .55252 L .37768 .5494 L F
.346 .237 .584 r
.37768 .5494 m .37985 .54559 L .37756 .54676 L F
.37768 .5494 m .3807 .54859 L .37985 .54559 L F
.199 0 .298 r
.37768 .5494 m .37959 .55057 L .3807 .54859 L F
.37768 .5494 m .37637 .55252 L .37959 .55057 L F
.712 .65 .787 r
.62725 .38384 m .63131 .38382 L .62983 .38004 L F
.871 .867 .831 r
.62741 .38565 m .63131 .38382 L .62725 .38384 L F
.673 .579 .742 r
.63131 .38382 m .63407 .38065 L .62983 .38004 L F
.63131 .38382 m .63347 .38318 L .63407 .38065 L F
.001 0 0 r
.35279 .67055 m .35158 .67028 L .35034 .67071 L F
.35279 .67055 m .35391 .6697 L .35158 .67028 L F
.093 0 .374 r
.20813 .56767 m .21028 .56389 L .20901 .56528 L F
.155 .379 .829 r
.33507 .5131 m .33695 .51415 L .3363 .51274 L F
0 0 0 r
.33334 .5136 m .33507 .5131 L .3362 .51083 L F
.3362 .51083 m .33507 .5131 L .33705 .51076 L F
.795 .969 .913 r
.33705 .51076 m .33507 .5131 L .33538 .51074 L F
.155 .379 .829 r
.33507 .5131 m .3363 .51274 L .33538 .51074 L F
0 0 0 r
.33313 .51381 m .33507 .5131 L .33334 .5136 L F
.002 .161 .676 r
.33762 .50943 m .33941 .51105 L .3387 .50836 L F
0 0 0 r
.3364 .51063 m .33762 .50943 L .33903 .50803 L F
.912 .948 .599 r
.33903 .50803 m .33762 .50943 L .33937 .50493 L F
.002 .161 .676 r
.33762 .50943 m .3387 .50836 L .33861 .50801 L F
0 0 0 r
.3362 .51083 m .33762 .50943 L .3364 .51063 L F
.3362 .51083 m .33705 .51076 L .33762 .50943 L F
.809 .446 0 r
.60936 .40851 m .61099 .41207 L .6101 .41069 L F
.607 .186 0 r
.6101 .41069 m .61099 .41207 L .61258 .41461 L F
0 0 .482 r
.61196 .39038 m .61177 .38683 L .61158 .38923 L F
.749 .639 .738 r
.66353 .36732 m .66745 .36786 L .6661 .364 L F
.694 .513 .638 r
.66509 .3703 m .66745 .36786 L .66353 .36732 L F
.66509 .3703 m .66783 .371 L .66745 .36786 L F
.647 .533 .711 r
.66745 .36786 m .66994 .36462 L .6661 .364 L F
.66745 .36786 m .67038 .36745 L .66994 .36462 L F
.597 .341 .5 r
.67045 .36993 m .66745 .36786 L .66783 .371 L F
.67045 .36993 m .67038 .36745 L .66745 .36786 L F
.958 .696 .25 r
.35252 .67506 m .35345 .67489 L .35212 .6738 L F
.35298 .67652 m .35345 .67489 L .35252 .67506 L F
.584 .89 .606 r
.35254 .6765 m .35453 .6747 L .35345 .67489 L F
.35453 .6747 m .35564 .6737 L .35345 .67489 L F
.464 .856 .976 r
.35564 .6737 m .3566 .6725 L .35345 .67489 L F
.35564 .6737 m .35809 .67305 L .3566 .6725 L F
.592 .925 .712 r
.34766 .52767 m .34767 .52824 L .34949 .5267 L F
.34766 .52767 m .34559 .52939 L .34767 .52824 L F
.313 0 0 r
.24151 .56218 m .24026 .56218 L .23777 .56156 L F
.695 .339 .366 r
.24352 .56199 m .24026 .56218 L .24151 .56218 L F
.809 .884 .9 r
.20743 .6015 m .20412 .60301 L .20503 .60224 L F
.602 .585 .807 r
.6509 .3859 m .65162 .38775 L .6545 .38634 L F
.464 .484 .794 r
.65162 .38775 m .65479 .38919 L .6545 .38634 L F
.454 .299 .581 r
.31938 .57476 m .32188 .57103 L .31957 .57122 L F
.636 .52 .704 r
.57284 .42186 m .5748 .42272 L .57456 .41836 L F
.986 .802 .572 r
.57707 .41687 m .57411 .41988 L .57456 .41836 L F
.526 .769 .986 r
.57411 .41988 m .5754 .41798 L .57517 .41826 L F
.286 .126 .481 r
.5729 .42172 m .57456 .41836 L .57411 .41988 L F
.526 .769 .986 r
.57411 .41988 m .57517 .41826 L .57278 .42109 L F
.286 .126 .481 r
.57284 .42186 m .5729 .42172 L .57411 .41988 L F
.668 .923 .619 r
.5715 .42279 m .57284 .42186 L .57411 .41988 L F
.689 .406 .489 r
.37675 .67642 m .37906 .67924 L .37973 .677 L F
.37675 .67642 m .37906 .67924 L .37973 .677 L F
.42 .14 .379 r
.35699 .64771 m .35379 .65152 L .35644 .65092 L F
.491 .274 .511 r
.35644 .65092 m .35891 .65036 L .35699 .64771 L F
.608 .353 .505 r
.59696 .45379 m .59949 .45594 L .5967 .45572 L F
.693 .307 .312 r
.59696 .45379 m .59918 .45438 L .59949 .45594 L F
.184 0 .216 r
.58899 .41866 m .58579 .42198 L .58869 .42123 L F
0 0 0 r
.58579 .42198 m .5875 .41734 L .58869 .42123 L F
.467 .264 .52 r
.58869 .42123 m .58579 .42198 L .586 .42446 L F
.58869 .42123 m .58579 .42198 L .586 .42446 L F
.461 .774 .997 r
.3281 .51244 m .32977 .51367 L .32719 .51385 L F
.979 .721 .468 r
.3281 .51244 m .32809 .51306 L .32977 .51367 L F
.318 .772 .954 r
.32719 .51385 m .32977 .51367 L .33063 .51398 L F
.33142 .51401 m .32977 .51367 L .32719 .51385 L F
.116 0 0 r
.32977 .51367 m .32553 .51577 L .32719 .51385 L F
.32977 .51367 m .32802 .51517 L .32553 .51577 L F
.979 .721 .468 r
.32809 .51306 m .32802 .51517 L .32977 .51367 L F
.318 .772 .954 r
.33063 .51398 m .32977 .51367 L .33142 .51401 L F
0 0 0 r
.32472 .56525 m .32654 .56388 L .32952 .56072 L F
.349 .241 .587 r
.32442 .56739 m .32654 .56388 L .32472 .56525 L F
0 .126 .67 r
.60737 .42755 m .60668 .42696 L .60512 .42432 L F
.354 .45 .821 r
.23065 .55127 m .23331 .55463 L .22915 .55317 L F
.5 .351 .61 r
.23188 .55659 m .22915 .55317 L .23331 .55463 L F
.23188 .55659 m .22976 .55836 L .22915 .55317 L F
.771 .506 .535 r
.55761 .45667 m .55395 .45908 L .55411 .45641 L F
.55761 .45667 m .55795 .45999 L .55395 .45908 L F
.708 .529 .645 r
.56042 .45666 m .55795 .45999 L .55761 .45667 L F
.96 .776 .331 r
.44197 .5707 m .4423 .57191 L .44178 .57068 L F
.864 .95 .867 r
.38821 .64448 m .39004 .64379 L .388 .64544 L F
.397 0 0 r
.3914 .64418 m .39004 .64379 L .38821 .64448 L F
.749 .515 .578 r
.38123 .62527 m .37719 .62285 L .37888 .62664 L F
0 0 0 r
.33024 .61465 m .33163 .61348 L .33329 .61154 L F
.695 .892 .521 r
.33329 .61154 m .33163 .61348 L .3325 .61225 L F
.94 .706 .558 r
.33298 .60898 m .33517 .61281 L .3343 .61031 L F
.104 0 .328 r
.33684 .61016 m .33661 .6105 L .33574 .61116 L F
.07 .312 .795 r
.33574 .61116 m .33517 .61281 L .33469 .61197 L F
.576 .834 .473 r
.33456 .61343 m .33517 .61281 L .33574 .61116 L F
.104 0 .328 r
.33642 .61064 m .33456 .61343 L .33574 .61116 L F
.33589 .61153 m .33456 .61343 L .33642 .61064 L F
.07 .312 .795 r
.33574 .61116 m .33469 .61197 L .33375 .61032 L F
.33574 .61116 m .33375 .61032 L .33404 .60982 L F
.586 .355 .532 r
.33085 .60919 m .33329 .61154 L .33298 .60898 L F
.33085 .60919 m .33068 .61203 L .33329 .61154 L F
.07 .312 .795 r
.33404 .60982 m .33375 .61032 L .33298 .60898 L F
.33433 .61005 m .33298 .60898 L .33558 .60855 L F
.585 .575 .808 r
.33329 .61154 m .33503 .6079 L .33298 .60898 L F
0 0 0 r
.33024 .61465 m .33329 .61154 L .33068 .61203 L F
.695 .892 .521 r
.33365 .61088 m .3325 .61225 L .33418 .60988 L F
.33329 .61154 m .3325 .61225 L .33365 .61088 L F
.07 .312 .795 r
.33574 .61116 m .33433 .61005 L .33828 .60812 L F
.33433 .61005 m .33558 .60855 L .33828 .60812 L F
.585 .575 .808 r
.33329 .61154 m .33574 .61116 L .33503 .6079 L F
.104 0 .328 r
.33684 .61016 m .33669 .61249 L .33456 .61343 L F
.678 .502 .641 r
.33418 .60988 m .33163 .61348 L .33515 .61275 L F
.3352 .61267 m .33515 .61275 L .33522 .61274 L F
.33418 .60988 m .33515 .61275 L .3352 .61267 L F
.104 0 .328 r
.33661 .6105 m .33589 .61153 L .33642 .61064 L F
0 0 0 r
.33464 .6088 m .33329 .61154 L .33418 .60988 L F
.33503 .6079 m .33441 .6092 L .33464 .6088 L F
.33441 .6092 m .33329 .61154 L .33464 .6088 L F
.3375 .60952 m .33828 .60812 L .34001 .60837 L F
.3375 .60952 m .33574 .61116 L .33828 .60812 L F
.318 0 .24 r
.34101 .60674 m .34001 .60837 L .33828 .60812 L F
.597 .373 .548 r
.30456 .62527 m .30136 .62865 L .30208 .6262 L F
.938 .729 .594 r
.53706 .43047 m .53392 .43273 L .53378 .43019 L F
.53706 .43047 m .53522 .4343 L .53392 .43273 L F
.426 .179 .435 r
.3274 .59099 m .32706 .59321 L .32485 .59374 L F
.698 .539 .668 r
.33036 .59034 m .32706 .59321 L .3274 .59099 L F
.855 .736 .731 r
.62877 .39217 m .63212 .39283 L .63123 .38917 L F
.869 .64 .59 r
.63118 .39447 m .63212 .39283 L .62877 .39217 L F
.77 .688 .772 r
.63123 .38917 m .63212 .39283 L .63465 .38904 L F
.697 .264 .217 r
.34617 .68811 m .34484 .6874 L .34654 .68859 L F
.34617 .68811 m .3438 .68575 L .34484 .6874 L F
.536 .435 .687 r
.44455 .52059 m .44494 .52328 L .44245 .52389 L F
.483 .475 .773 r
.44558 .52677 m .44245 .52389 L .44494 .52328 L F
.561 .928 .783 r
.29799 .5618 m .29824 .56244 L .29939 .56126 L F
0 0 0 r
.29929 .56166 m .2972 .5621 L .29799 .5618 L F
.738 .243 .059 r
.29799 .5618 m .29479 .55991 L .29597 .56333 L F
0 0 0 r
.2972 .5621 m .29679 .56219 L .29799 .5618 L F
.561 .928 .783 r
.29799 .5618 m .29939 .56126 L .29976 .56088 L F
.29799 .5618 m .29597 .56333 L .29824 .56244 L F
.411 .143 .393 r
.26267 .57316 m .25939 .57716 L .26005 .57389 L F
.26267 .57316 m .26214 .57824 L .25939 .57716 L F
0 0 0 r
.26677 .57168 m .26472 .573 L .26267 .57316 L F
.335 .082 .374 r
.26497 .57615 m .26267 .57316 L .26472 .573 L F
.26497 .57615 m .26214 .57824 L .26267 .57316 L F
.571 .818 .992 r
.58371 .42797 m .58114 .42888 L .58211 .42642 L F
.783 .981 .715 r
.57955 .42958 m .58114 .42888 L .58211 .42642 L F
0 0 0 r
.58371 .42797 m .58114 .42888 L .57955 .42958 L F
.311 .352 .743 r
.73941 .33608 m .73697 .33919 L .73621 .33469 L F
.088 .062 .53 r
.73941 .33608 m .73751 .34153 L .73697 .33919 L F
.86 .877 .85 r
.66398 .33285 m .66095 .3363 L .65955 .33482 L F
.7 .955 .687 r
.26406 .55118 m .26581 .54974 L .26697 .54814 L F
.673 .695 .863 r
.43558 .55321 m .43605 .55457 L .43726 .55134 L F
.761 .702 .796 r
.38762 .62535 m .39142 .6258 L .3902 .62215 L F
.576 .518 .753 r
.67701 .38303 m .6746 .38607 L .67403 .38387 L F
.67701 .38303 m .67702 .38553 L .6746 .38607 L F
.631 .466 .641 r
.67702 .38553 m .67446 .38922 L .6746 .38607 L F
.79 .678 .74 r
.63696 .37768 m .63923 .37723 L .63922 .37444 L F
.682 .508 .644 r
.63652 .38002 m .63923 .37723 L .63696 .37768 L F
.63652 .38002 m .6404 .38047 L .63923 .37723 L F
.656 .523 .69 r
.63923 .37723 m .64152 .37328 L .63922 .37444 L F
.63923 .37723 m .64335 .37766 L .64152 .37328 L F
.658 .495 .652 r
.6404 .38047 m .64335 .37766 L .63923 .37723 L F
0 .012 .546 r
.27854 .63041 m .27982 .63551 L .27779 .63204 L F
.965 .874 .48 r
.36659 .66105 m .36568 .66388 L .3684 .66062 L F
.772 .965 .926 r
.36042 .53004 m .3604 .5295 L .36125 .52914 L F
0 0 .423 r
.36115 .53172 m .36175 .53251 L .3606 .53064 L F
.3621 .53357 m .36175 .53251 L .36115 .53172 L F
.518 .615 .888 r
.36183 .53261 m .36466 .53184 L .36175 .53251 L F
.36401 .53566 m .36466 .53184 L .36183 .53261 L F
.853 .751 .75 r
.36466 .53184 m .36889 .53144 L .36732 .53064 L F
0 0 0 r
.36732 .53064 m .36614 .53144 L .36466 .53184 L F
.518 .615 .888 r
.36401 .53566 m .36676 .53547 L .36466 .53184 L F
.853 .751 .75 r
.36466 .53184 m .36676 .53547 L .36889 .53144 L F
0 0 0 r
.36614 .53144 m .36426 .53274 L .36466 .53184 L F
.212 0 0 r
.36426 .53274 m .36236 .53331 L .36175 .53251 L F
.36236 .53331 m .36112 .53367 L .36175 .53251 L F
0 0 .423 r
.36067 .53089 m .3606 .53064 L .36018 .52997 L F
.3621 .53357 m .3606 .53064 L .36067 .53089 L F
.647 .259 .294 r
.36018 .52997 m .36175 .53251 L .3587 .53189 L F
0 0 0 r
.36018 .52997 m .36125 .52914 L .36289 .52971 L F
.36018 .52997 m .3587 .53189 L .36125 .52914 L F
.772 .965 .926 r
.3587 .53189 m .3603 .52964 L .36042 .53004 L F
.3603 .52964 m .3604 .5295 L .36042 .53004 L F
.454 .26 .526 r
.23312 .574 m .23102 .57883 L .23091 .57435 L F
.826 .942 .901 r
.70033 .29117 m .69628 .29278 L .69909 .2897 L F
.70033 .29117 m .69707 .29366 L .69628 .29278 L F
.859 .942 .873 r
.70218 .28702 m .70033 .29117 L .69909 .2897 L F
.70218 .28702 m .70327 .28823 L .70033 .29117 L F
.381 .815 .96 r
.28179 .51883 m .27741 .51863 L .27902 .51781 L F
.503 .838 .998 r
.28195 .51722 m .28179 .51883 L .27902 .51781 L F
.28195 .51722 m .28434 .51816 L .28179 .51883 L F
.711 .627 .762 r
.36293 .65008 m .36679 .65083 L .36592 .64765 L F
.739 .644 .754 r
.36592 .64765 m .36679 .65083 L .36909 .64759 L F
.669 .575 .741 r
.43812 .49093 m .43545 .49203 L .43763 .48894 L F
.611 .677 .888 r
.46545 .56798 m .46088 .56564 L .46445 .5665 L F
.553 .523 .776 r
.46458 .56053 m .46582 .56642 L .46325 .56583 L F
.262 0 0 r
.46448 .56651 m .46786 .56746 L .46445 .56651 L F
.553 .523 .776 r
.46582 .56642 m .46594 .567 L .46477 .56649 L F
.46582 .56642 m .46477 .56649 L .46325 .56583 L F
.262 0 0 r
.46445 .56651 m .46786 .56746 L .46545 .56798 L F
.46445 .5665 m .46448 .56651 L .46445 .56651 L F
.986 .734 .348 r
.41433 .56476 m .41536 .56859 L .41435 .56733 L F
.928 .598 .144 r
.41536 .56859 m .41489 .56986 L .41435 .56733 L F
.41536 .56859 m .41589 .57108 L .41489 .56986 L F
.867 .81 .791 r
.64207 .34995 m .64369 .35162 L .6413 .35493 L F
.828 .811 .834 r
.64637 .34841 m .64369 .35162 L .64207 .34995 L F
.718 .605 .729 r
.63347 .38318 m .6377 .3838 L .63652 .38002 L F
.672 .579 .742 r
.63652 .38002 m .6377 .3838 L .6404 .38047 L F
.967 .649 .35 r
.38019 .58016 m .38197 .58152 L .38127 .58315 L F
.217 0 .031 r
.38127 .58315 m .38197 .58152 L .38423 .58077 L F
.071 0 .284 r
.38197 .58152 m .38428 .57781 L .38423 .58077 L F
.643 .248 .28 r
.23149 .59931 m .23183 .59769 L .22927 .59723 L F
0 .164 .704 r
.22973 .5961 m .23149 .59931 L .22927 .59723 L F
.993 .753 .396 r
.41694 .58106 m .41593 .58274 L .41617 .58025 L F
.41694 .58106 m .41679 .58363 L .41593 .58274 L F
.505 .358 .615 r
.32706 .59321 m .32473 .59727 L .32485 .59374 L F
.444 .098 .284 r
.64253 .39726 m .64054 .3963 L .63993 .39764 L F
.542 .735 .964 r
.64253 .39726 m .63993 .39764 L .64054 .3963 L F
.561 .85 .997 r
.59962 .36685 m .60094 .36792 L .6035 .36711 L F
.657 .868 .979 r
.29444 .51607 m .29047 .51633 L .29341 .51517 L F
.622 .89 .988 r
.29665 .51417 m .29444 .51607 L .29341 .51517 L F
.29665 .51417 m .29811 .51501 L .29444 .51607 L F
.73 .676 .798 r
.62582 .37974 m .62725 .38384 L .62983 .38004 L F
.553 .273 .446 r
.28557 .53613 m .28821 .536 L .28845 .53343 L F
.28845 .53343 m .28821 .536 L .28557 .53613 L F
.618 .33 .457 r
.28821 .536 m .29086 .53591 L .28845 .53343 L F
.28821 .536 m .29086 .53591 L .28845 .53343 L F
.499 .85 .589 r
.2967 .54026 m .29375 .54272 L .29482 .54178 L F
.326 .278 .65 r
.29482 .54178 m .29874 .53916 L .2967 .54026 L F
.29482 .54178 m .29675 .5383 L .29874 .53916 L F
.29482 .54178 m .29707 .54087 L .29695 .53991 L F
.29482 .54178 m .29695 .53991 L .29675 .5383 L F
.499 .85 .589 r
.29375 .54272 m .29363 .54282 L .29482 .54178 L F
.778 .73 .808 r
.62314 .36408 m .62038 .36721 L .61918 .36352 L F
.771 .715 .8 r
.39149 .61273 m .39278 .61648 L .38857 .61608 L F
0 0 .123 r
.29351 .54513 m .29482 .54178 L .29363 .54282 L F
.544 .609 .869 r
.26054 .54923 m .26306 .55302 L .26406 .55118 L F
.129 .313 .781 r
.69628 .32375 m .69366 .32356 L .6947 .32141 L F
.402 .244 .55 r
.40155 .67884 m .39903 .67687 L .40169 .67629 L F
0 0 0 r
.40461 .67369 m .40331 .67534 L .40169 .67629 L F
0 0 .075 r
.40169 .67629 m .40246 .6779 L .40155 .67884 L F
.40169 .67629 m .40331 .67534 L .40246 .6779 L F
.643 .699 .886 r
.43296 .48359 m .43407 .48568 L .43068 .48512 L F
.678 .716 .877 r
.43707 .48492 m .43407 .48568 L .43296 .48359 L F
0 .09 .607 r
.32874 .52652 m .3311 .52665 L .3312 .52491 L F
.864 .497 .351 r
.32925 .53677 m .32792 .53777 L .32717 .5367 L F
.473 .038 .132 r
.31924 .65276 m .31748 .65138 L .31733 .65409 L F
.59 .15 .173 r
.60595 .45417 m .60956 .45599 L .60604 .45596 L F
.826 .653 .669 r
.38423 .66155 m .38288 .66389 L .38186 .6597 L F
.162 0 0 r
.32696 .68298 m .32472 .68387 L .32344 .68569 L F
.914 .554 .104 r
.38564 .58623 m .38463 .58614 L .38475 .58373 L F
.38564 .58623 m .38585 .58741 L .38463 .58614 L F
.785 .677 .746 r
.38825 .58098 m .38564 .58623 L .38423 .58077 L F
.31 .075 .386 r
.38487 .58579 m .38475 .58373 L .38463 .58614 L F
.906 .625 .125 r
.38468 .58253 m .38564 .58623 L .38475 .58373 L F
.31 .075 .386 r
.38662 .58319 m .38475 .58373 L .38487 .58579 L F
.906 .625 .125 r
.38423 .58077 m .38468 .58253 L .38475 .58373 L F
0 0 0 r
.34555 .58987 m .34719 .58802 L .34395 .59069 L F
.34939 .58449 m .34719 .58802 L .34843 .58654 L F
.566 .839 .493 r
.34843 .58654 m .34719 .58802 L .34555 .58987 L F
.922 .617 .141 r
.41285 .55574 m .41235 .55694 L .41205 .55455 L F
.41285 .55574 m .4133 .55833 L .41235 .55694 L F
.538 .187 .32 r
.34055 .58287 m .33866 .58115 L .341 .5806 L F
.34055 .58287 m .33763 .58354 L .33866 .58115 L F
.781 .484 .485 r
.71255 .30963 m .71305 .30797 L .70915 .30739 L F
.833 .742 .763 r
.63756 .35434 m .63867 .35814 L .63536 .35763 L F
.834 .738 .758 r
.63536 .35763 m .63867 .35814 L .63633 .36134 L F
.787 .718 .787 r
.63756 .35434 m .6413 .35493 L .63867 .35814 L F
.526 .229 .406 r
.3748 .61033 m .37447 .61236 L .37175 .61269 L F
.605 .508 .717 r
.37695 .60625 m .37748 .60974 L .3748 .61033 L F
.254 0 .148 r
.37748 .60974 m .37447 .61236 L .3748 .61033 L F
.62 .9 .986 r
.25343 .52516 m .25364 .52324 L .25589 .52393 L F
.25343 .52516 m .25067 .5244 L .25364 .52324 L F
.751 .303 0 r
.40284 .52987 m .40522 .53319 L .40398 .53188 L F
.672 .253 0 r
.40614 .53546 m .40398 .53188 L .40522 .53319 L F
.592 .372 .551 r
.312 .55515 m .3094 .55807 L .30994 .55587 L F
.256 .13 .51 r
.31875 .6054 m .31698 .60349 L .31925 .60297 L F
.31875 .6054 m .31707 .60632 L .31698 .60349 L F
.956 .911 .545 r
.24085 .5383 m .24064 .54237 L .24276 .54177 L F
.24085 .5383 m .2398 .54151 L .24064 .54237 L F
.345 .088 .373 r
.24276 .54177 m .24064 .54237 L .2398 .54151 L F
.24276 .54177 m .2399 .54529 L .24064 .54237 L F
.24064 .54237 m .2399 .54529 L .24276 .54177 L F
0 .239 .756 r
.23138 .56703 m .23433 .57167 L .23384 .569 L F
0 0 0 r
.23433 .57167 m .233 .57233 L .23384 .569 L F
.23433 .57167 m .23078 .5733 L .233 .57233 L F
.612 .865 .991 r
.61176 .39433 m .61047 .39644 L .60918 .39533 L F
.61176 .39433 m .61047 .39644 L .60918 .39533 L F
.442 .328 .629 r
.35953 .51373 m .35974 .51642 L .35728 .51441 L F
.389 .33 .67 r
.35974 .51642 m .35817 .51794 L .35728 .51441 L F
.782 .872 .44 r
.22382 .56174 m .2226 .56399 L .22263 .56482 L F
0 .13 .661 r
.2226 .56399 m .22568 .56776 L .22263 .56482 L F
.263 .138 .516 r
.3225 .65742 m .3215 .65444 L .3237 .65304 L F
.576 .94 .823 r
.34113 .5992 m .34546 .59717 L .34367 .59881 L F
.099 0 .233 r
.34733 .59598 m .34546 .59717 L .34808 .59365 L F
0 0 0 r
.34367 .59881 m .34546 .59717 L .34733 .59598 L F
.804 .554 .561 r
.282 .5545 m .28516 .55258 L .28163 .55307 L F
.282 .5545 m .28598 .55535 L .28516 .55258 L F
.737 .716 .831 r
.28598 .55535 m .28785 .55128 L .28516 .55258 L F
.395 .414 .761 r
.64174 .41903 m .64478 .42072 L .64437 .41725 L F
.405 .411 .753 r
.64174 .41903 m .64287 .42152 L .64478 .42072 L F
.599 .626 .849 r
.43068 .48512 m .426 .48178 L .42818 .48107 L F
.603 .603 .825 r
.43296 .48359 m .43068 .48512 L .42818 .48107 L F
0 0 0 r
.33384 .58014 m .33691 .5772 L .33465 .57768 L F
.913 .976 .7 r
.37728 .63249 m .37346 .63819 L .37572 .63735 L F
.779 .391 .321 r
.3781 .63681 m .37728 .63249 L .37572 .63735 L F
.3781 .63681 m .3802 .63497 L .37728 .63249 L F
.913 .75 .665 r
.62257 .44402 m .62409 .44424 L .62277 .4403 L F
.877 .521 .369 r
.62282 .44579 m .62409 .44424 L .62257 .44402 L F
.699 .272 .231 r
.62282 .44579 m .62688 .44618 L .62409 .44424 L F
0 0 0 r
.6131 .38684 m .61177 .38683 L .61418 .38512 L F
0 0 .328 r
.61158 .38923 m .61177 .38683 L .6131 .38684 L F
.784 .678 .747 r
.38706 .5776 m .38825 .58098 L .38423 .58077 L F
.728 .65 .771 r
.39103 .57798 m .38825 .58098 L .38706 .5776 L F
0 .047 .614 r
.25179 .6256 m .25383 .62979 L .25378 .62809 L F
.417 .314 .63 r
.25383 .62979 m .25565 .63166 L .25378 .62809 L F
.25383 .62979 m .25413 .63318 L .25565 .63166 L F
.936 .89 .76 r
.53534 .41398 m .53353 .41411 L .53612 .41099 L F
0 0 0 r
.31167 .5942 m .30897 .59718 L .31035 .59624 L F
.363 .171 .482 r
.30822 .59992 m .31035 .59624 L .30897 .59718 L F
0 .115 .648 r
.42931 .57891 m .4276 .578 L .42898 .57746 L F
.42931 .57891 m .42985 .58001 L .4276 .578 L F
.41 .246 .546 r
.42985 .58001 m .42855 .58094 L .4276 .578 L F
.541 0 0 r
.30344 .63668 m .30368 .63598 L .30261 .63737 L F
.30344 .63668 m .30681 .63774 L .30368 .63598 L F
.059 .322 .804 r
.30522 .52822 m .30488 .53018 L .30245 .5263 L F
0 0 0 r
.30478 .53273 m .30476 .5328 L .30488 .53018 L F
.293 .688 .975 r
.30489 .53212 m .30492 .53212 L .30447 .53116 L F
.487 .413 .698 r
.30522 .52822 m .31031 .53224 L .30489 .53212 L F
.293 .688 .975 r
.30492 .53212 m .31031 .53224 L .30511 .53128 L F
0 0 0 r
.30522 .52822 m .30478 .53273 L .30488 .53018 L F
.293 .688 .975 r
.30492 .53212 m .30511 .53128 L .30447 .53116 L F
0 0 0 r
.30478 .53273 m .30475 .53298 L .30476 .5328 L F
0 0 .486 r
.32518 .69316 m .32765 .69604 L .32693 .69515 L F
.475 0 0 r
.32765 .69604 m .32929 .69709 L .32768 .69658 L F
.95 .663 .46 r
.64867 .4023 m .65036 .40579 L .65111 .4046 L F
.966 .8 .368 r
.65036 .40579 m .65018 .40929 L .64963 .40803 L F
.65036 .40579 m .64963 .40803 L .65111 .4046 L F
.033 .041 .533 r
.38426 .67256 m .38504 .67668 L .38387 .6773 L F
.973 .822 .634 r
.38147 .6795 m .3831 .68021 L .38387 .6773 L F
.38147 .6795 m .38387 .6773 L .38504 .67668 L F
0 0 0 r
.25442 .53019 m .25233 .53119 L .25089 .53148 L F
.25678 .52944 m .25233 .53119 L .25442 .53019 L F
.34506 .66102 m .3456 .66001 L .34697 .65943 L F
.894 .499 .062 r
.37204 .62037 m .37425 .62266 L .37238 .61926 L F
.826 .887 .887 r
.36999 .62421 m .37425 .62266 L .37204 .62037 L F
.871 .642 .589 r
.30874 .51055 m .31191 .50953 L .30697 .50849 L F
.632 .647 .847 r
.23906 .56795 m .23474 .56539 L .23748 .56699 L F
.515 .073 .137 r
.23748 .56699 m .24193 .56523 L .23906 .56795 L F
.452 0 .021 r
.34144 .65784 m .34476 .65716 L .34228 .65713 L F
.683 .537 .681 r
.38404 .55133 m .38209 .55511 L .38173 .55252 L F
.393 .389 .736 r
.31812 .51886 m .31996 .52077 L .32064 .51945 L F
.737 .716 .831 r
.28598 .55535 m .28904 .55602 L .28785 .55128 L F
0 .478 .755 r
.2864 .55524 m .28904 .55602 L .28598 .55535 L F
.2864 .55524 m .28688 .55525 L .28904 .55602 L F
.439 .507 .831 r
.28904 .55602 m .28956 .55048 L .28785 .55128 L F
.067 0 .008 r
.29207 .5548 m .29096 .55587 L .28971 .55555 L F
.29096 .55587 m .28912 .55764 L .28959 .55597 L F
.29096 .55587 m .28959 .55597 L .28971 .55555 L F
.439 .507 .831 r
.28904 .556 m .29195 .55468 L .28956 .55048 L F
.29195 .55468 m .29202 .55432 L .28956 .55048 L F
.28908 .556 m .29219 .55457 L .28904 .556 L F
.28904 .55602 m .28908 .556 L .28904 .556 L F
.328 0 0 r
.28688 .55525 m .29194 .5546 L .28904 .55602 L F
.067 0 .008 r
.29064 .55618 m .29126 .55674 L .28912 .55764 L F
.29207 .5548 m .29126 .55674 L .29064 .55618 L F
.328 0 0 r
.29194 .5546 m .29195 .55468 L .28904 .55602 L F
.516 .383 .637 r
.29126 .55674 m .28853 .56037 L .28912 .55764 L F
.29126 .55674 m .29147 .55983 L .28853 .56037 L F
.678 .726 .886 r
.2939 .55842 m .29147 .55983 L .29126 .55674 L F
.76 .258 .017 r
.28887 .55558 m .29179 .55722 L .29126 .55674 L F
.29179 .55722 m .2939 .55842 L .29126 .55674 L F
.806 .814 .331 r
.29207 .5544 m .29176 .55554 L .29207 .5548 L F
.29207 .55412 m .29198 .55454 L .29207 .5544 L F
.29198 .55454 m .29176 .55554 L .29207 .5544 L F
.328 0 0 r
.28688 .55525 m .28887 .55558 L .2919 .55466 L F
.439 .507 .831 r
.29195 .55468 m .29219 .55457 L .29202 .55432 L F
.328 0 0 r
.29194 .5546 m .29219 .55457 L .29195 .55468 L F
.29194 .5546 m .2919 .55466 L .29219 .55457 L F
.28688 .55525 m .2919 .55466 L .29194 .5546 L F
.806 .814 .331 r
.29194 .55462 m .29126 .55674 L .29176 .55554 L F
.29207 .55395 m .29192 .55445 L .29194 .55462 L F
.29193 .55456 m .29126 .55674 L .29194 .55462 L F
.944 .796 .666 r
.29219 .55457 m .2919 .55466 L .29126 .55674 L F
.2919 .55466 m .28887 .55558 L .29126 .55674 L F
.806 .814 .331 r
.29192 .55445 m .29126 .55674 L .29193 .55456 L F
.29207 .55395 m .29176 .55554 L .29207 .55412 L F
.323 .049 .333 r
.31035 .59624 m .31321 .5927 L .31167 .5942 L F
.058 0 .078 r
.34555 .58987 m .34395 .59069 L .343 .59283 L F
.395 .161 .437 r
.22915 .56732 m .23193 .56476 L .22884 .56523 L F
0 0 .215 r
.34255 .53213 m .34267 .53448 L .34187 .53606 L F
.682 .929 .624 r
.34267 .53448 m .33991 .53762 L .34187 .53606 L F
.788 .78 .846 r
.63922 .37444 m .64152 .37328 L .64027 .36974 L F
.727 .749 .869 r
.64027 .36974 m .64152 .37328 L .64414 .37031 L F
.641 .607 .799 r
.64152 .37328 m .64552 .37412 L .64414 .37031 L F
.676 .533 .683 r
.64152 .37328 m .64335 .37766 L .64552 .37412 L F
.889 .99 .756 r
.70414 .28499 m .70565 .28486 L .70327 .28823 L F
.816 .937 .909 r
.70414 .28499 m .70327 .28823 L .70218 .28702 L F
.565 .77 .975 r
.71707 .35493 m .71446 .3556 L .71322 .35385 L F
.88 .648 .582 r
.56228 .46009 m .56207 .46277 L .56025 .45911 L F
.737 .917 .954 r
.29047 .51633 m .28841 .51774 L .28874 .51546 L F
.842 .987 .862 r
.28874 .51546 m .28841 .51774 L .28721 .51734 L F
.527 .89 .975 r
.36391 .71475 m .36771 .71426 L .36645 .71398 L F
.072 0 0 r
.26914 .57105 m .26472 .573 L .26677 .57168 L F
.596 .865 .993 r
.30287 .52393 m .30328 .52193 L .30527 .52332 L F
.30287 .52393 m .30075 .52272 L .30328 .52193 L F
.417 .169 .428 r
.30527 .52332 m .30245 .5263 L .30287 .52393 L F
.846 .613 .586 r
.64185 .40273 m .6419 .40453 L .63751 .40541 L F
.6419 .40453 m .64017 .40541 L .63751 .40541 L F
.6419 .40453 m .64192 .40542 L .64017 .40541 L F
.411 .841 .951 r
.63751 .40541 m .64192 .40542 L .64101 .40478 L F
.63751 .40541 m .64101 .40478 L .63772 .40682 L F
.67 .654 .825 r
.63716 .40388 m .63772 .40682 L .64101 .40478 L F
.162 .276 .735 r
.63923 .40494 m .63772 .40682 L .63716 .40388 L F
.641 .964 .818 r
.63718 .40658 m .63756 .40675 L .63923 .40494 L F
.63756 .40675 m .63772 .40682 L .63793 .40656 L F
.63756 .40675 m .63793 .40656 L .63923 .40494 L F
.909 .759 .683 r
.62383 .41722 m .627 .4151 L .62629 .41388 L F
.62383 .41722 m .626 .41802 L .627 .4151 L F
.747 .993 .83 r
.70956 .28158 m .70565 .28486 L .70708 .28246 L F
.747 .993 .824 r
.70708 .28246 m .70565 .28486 L .70414 .28499 L F
.528 .323 .546 r
.64413 .38372 m .64682 .38036 L .64343 .38051 L F
.64413 .38372 m .64687 .38293 L .64682 .38036 L F
0 0 0 r
.39157 .59361 m .39195 .59227 L .39245 .58969 L F
.965 .738 .544 r
.39345 .59599 m .39195 .59227 L .39157 .59361 L F
.752 .433 .445 r
.56207 .46277 m .5658 .463 L .56433 .46567 L F
0 0 0 r
.37823 .65477 m .37481 .65752 L .37739 .65702 L F
.578 .087 0 r
.36933 .50901 m .36883 .5082 L .36762 .50656 L F
.36933 .50901 m .37096 .51068 L .36883 .5082 L F
.766 .274 .054 r
.36883 .5082 m .37096 .51068 L .37299 .51099 L F
0 0 .071 r
.32075 .68622 m .321 .68962 L .32136 .68687 L F
.269 0 .188 r
.32344 .68569 m .32075 .68622 L .32136 .68687 L F
.212 .582 .943 r
.36894 .64027 m .36876 .64174 L .37022 .64159 L F
.702 .747 .886 r
.3681 .64429 m .37022 .64159 L .36876 .64174 L F
.994 .876 .573 r
.40543 .58682 m .40459 .58937 L .40567 .59033 L F
.978 .872 .496 r
.40418 .59195 m .40567 .59033 L .40459 .58937 L F
.40418 .59195 m .40475 .59568 L .40567 .59033 L F
.86 .877 .85 r
.66398 .33285 m .65955 .33482 L .66251 .33134 L F
.874 .879 .836 r
.66509 .33133 m .66398 .33285 L .66251 .33134 L F
.729 .974 .925 r
.72501 .34948 m .72371 .35185 L .72616 .34952 L F
.659 .841 .431 r
.72235 .35375 m .72371 .35185 L .72501 .34948 L F
.381 .27 .601 r
.25456 .54609 m .25654 .54772 L .2569 .54558 L F
.948 .619 .197 r
.20252 .61473 m .20367 .6166 L .20291 .61456 L F
.20252 .61473 m .20367 .6166 L .20291 .61456 L F
.583 .714 .933 r
.20252 .61473 m .20367 .6166 L .20564 .61564 L F
.20564 .61564 m .20367 .6166 L .20252 .61473 L F
.354 .151 .459 r
.33019 .57445 m .32977 .57747 L .32771 .57799 L F
.452 .288 .568 r
.32977 .57747 m .32769 .58075 L .32771 .57799 L F
.853 .861 .847 r
.57028 .40948 m .56784 .41257 L .56621 .40987 L F
.999 .791 .484 r
.56621 .40987 m .56784 .41257 L .56625 .41314 L F
.816 .673 .705 r
.70411 .32639 m .7016 .32615 L .70344 .32235 L F
.506 .46 .739 r
.70686 .32518 m .70411 .32639 L .70344 .32235 L F
.406 .321 .647 r
.70709 .32661 m .70411 .32639 L .70686 .32518 L F
.70709 .32661 m .70496 .32887 L .70411 .32639 L F
.747 .654 .758 r
.63347 .38318 m .63652 .38002 L .63407 .38065 L F
.862 .92 .867 r
.65471 .41724 m .65591 .41885 L .65621 .41725 L F
.996 .855 .578 r
.65513 .42115 m .65591 .41885 L .65471 .41724 L F
.773 .644 .72 r
.3607 .65173 m .36293 .65008 L .36306 .64804 L F
.711 .627 .762 r
.36293 .65008 m .36592 .64765 L .36306 .64804 L F
.398 .177 .458 r
.27347 .58751 m .27297 .59046 L .27092 .59074 L F
.27347 .58751 m .27297 .59046 L .27092 .59074 L F
.094 .18 .663 r
.33359 .68987 m .33176 .69003 L .33065 .68864 L F
.33359 .68987 m .33298 .69206 L .33176 .69003 L F
.722 .987 .812 r
.33842 .51539 m .33746 .5172 L .34083 .51453 L F
.731 .989 .812 r
.34049 .51315 m .33842 .51539 L .34083 .51453 L F
.721 .221 .046 r
.27827 .62447 m .27925 .62536 L .28187 .62578 L F
.807 .318 0 r
.27645 .62399 m .2772 .62474 L .27925 .62536 L F
0 0 .325 r
.27925 .62536 m .27947 .62724 L .28146 .62603 L F
.27925 .62536 m .27943 .62727 L .27947 .62724 L F
.27925 .62536 m .27989 .62747 L .27943 .62727 L F
.807 .318 0 r
.2772 .62474 m .27989 .62747 L .27925 .62536 L F
0 0 .325 r
.27925 .62536 m .28146 .62603 L .28187 .62578 L F
.917 .573 .115 r
.28187 .62578 m .28248 .62841 L .28438 .62562 L F
.753 .702 .804 r
.37388 .57789 m .37758 .57914 L .37685 .57999 L F
.868 .767 .748 r
.38019 .58016 m .37685 .57999 L .37758 .57914 L F
.696 .631 .779 r
.62701 .36541 m .62314 .36408 L .62585 .36337 L F
.732 .734 .853 r
.62585 .36337 m .6294 .36399 L .62701 .36541 L F
.506 .479 .761 r
.64287 .42152 m .64586 .42447 L .64478 .42072 L F
.767 .8 .88 r
.64967 .3957 m .64695 .3985 L .6461 .39568 L F
.682 .556 .707 r
.38785 .54915 m .38404 .55133 L .38574 .54847 L F
0 .123 .595 r
.5875 .41734 m .58899 .41866 L .59117 .42033 L F
.434 .214 .48 r
.59117 .42033 m .58899 .41866 L .58869 .42123 L F
.156 0 .188 r
.34939 .58449 m .35064 .58602 L .35149 .58366 L F
.34939 .58449 m .34843 .58654 L .35064 .58602 L F
.197 0 .208 r
.35261 .58153 m .34939 .58449 L .35149 .58366 L F
.777 .646 .717 r
.67379 .35444 m .67612 .35097 L .67386 .3517 L F
.609 .817 .98 r
.62563 .45084 m .62819 .44985 L .62432 .44934 L F
.116 0 .25 r
.38062 .67702 m .37906 .67924 L .37973 .677 L F
.618 .817 .977 r
.57807 .41561 m .5767 .41416 L .57707 .41687 L F
.57807 .41561 m .58074 .41463 L .5767 .41416 L F
.565 .575 .822 r
.57807 .41561 m .58204 .41872 L .58074 .41463 L F
.777 .737 .816 r
.64047 .35147 m .6413 .35493 L .63756 .35434 L F
.867 .81 .791 r
.64207 .34995 m .6413 .35493 L .64047 .35147 L F
.466 .016 .097 r
.37985 .54559 m .37518 .54765 L .37756 .54676 L F
.737 .758 .869 r
.23937 .57097 m .23657 .57137 L .24074 .57066 L F
.456 0 0 r
.24303 .57118 m .23937 .57097 L .24074 .57066 L F
.002 0 0 r
.34157 .54437 m .347 .54332 L .3423 .54259 L F
.34157 .54437 m .34414 .54408 L .347 .54332 L F
.929 .97 .748 r
.347 .54332 m .34414 .54408 L .3461 .54034 L F
.749 .648 .748 r
.6404 .38047 m .64343 .38051 L .64335 .37766 L F
.987 .777 .38 r
.2869 .65019 m .2878 .65129 L .28752 .65365 L F
0 0 .38 r
.28741 .65085 m .2869 .65019 L .28797 .65254 L F
.565 .104 0 r
.28653 .64969 m .2878 .65129 L .2869 .65019 L F
0 0 .38 r
.2867 .64873 m .2869 .65019 L .28741 .65085 L F
.565 .104 0 r
.28521 .64802 m .28653 .64969 L .2869 .65019 L F
0 0 0 r
.37197 .65771 m .3684 .66062 L .37247 .66073 L F
.604 .413 .597 r
.37247 .66073 m .37481 .65752 L .37197 .65771 L F
.051 .617 .768 r
.26061 .52956 m .25944 .52944 L .25678 .52944 L F
.76 .994 .87 r
.26167 .52722 m .26069 .52948 L .26349 .52657 L F
.282 0 .083 r
.26597 .52574 m .2664 .527 L .26349 .52657 L F
.195 0 0 r
.2664 .527 m .26167 .52722 L .26349 .52657 L F
.583 .828 .991 r
.26216 .5261 m .26167 .52722 L .2664 .527 L F
.26024 .5257 m .26167 .52722 L .26216 .5261 L F
.76 .994 .87 r
.26167 .52722 m .26061 .52956 L .26069 .52948 L F
.26167 .52722 m .25944 .52944 L .26061 .52956 L F
.113 0 0 r
.30031 .54573 m .29656 .54829 L .29768 .546 L F
.74 .62 .725 r
.36592 .64765 m .36909 .64759 L .3681 .64429 L F
.727 .612 .729 r
.36909 .64759 m .37216 .64411 L .3681 .64429 L F
.754 .921 .946 r
.62852 .40488 m .62883 .40543 L .62758 .40426 L F
.73 .474 .54 r
.54824 .45032 m .55238 .45045 L .55242 .45299 L F
.482 .328 .596 r
.67184 .39208 m .66951 .39546 L .66971 .39318 L F
.573 .423 .639 r
.67547 .37956 m .67701 .38303 L .67403 .38387 L F
.602 .428 .618 r
.67931 .37695 m .67953 .37983 L .67547 .37956 L F
.602 .436 .63 r
.67953 .37983 m .67701 .38303 L .67547 .37956 L F
0 0 .024 r
.40031 .4986 m .40159 .49697 L .40202 .49422 L F
.103 0 .155 r
.40202 .49422 m .40406 .4941 L .40434 .4935 L F
.40202 .49422 m .40159 .49697 L .40406 .4941 L F
.381 .292 .628 r
.20568 .58352 m .20711 .5804 L .20609 .58126 L F
0 0 0 r
.26344 .5421 m .26255 .54291 L .26469 .54186 L F
.657 .313 .378 r
.31597 .66751 m .31698 .66614 L .3155 .66732 L F
.31823 .66844 m .31698 .66614 L .31597 .66751 L F
.828 .995 .756 r
.31891 .66332 m .31789 .6649 L .31698 .66614 L F
.31789 .6649 m .31665 .66682 L .31698 .66614 L F
.389 .381 .729 r
.2201 .6032 m .22141 .60806 L .22325 .60506 L F
.407 .405 .744 r
.22141 .60806 m .2238 .60892 L .22325 .60506 L F
.752 .829 .911 r
.39486 .60317 m .39356 .6019 L .39558 .60011 L F
.39486 .60317 m .39242 .60301 L .39356 .6019 L F
.908 .721 .637 r
.39486 .60317 m .39229 .60561 L .39242 .60301 L F
.39486 .60317 m .39505 .60618 L .39229 .60561 L F
.98 .729 .479 r
.39179 .68248 m .39361 .68576 L .39432 .68411 L F
.876 .893 .842 r
.39179 .68248 m .39432 .68411 L .39685 .68022 L F
.79 .973 .912 r
.2905 .52176 m .28964 .52416 L .29211 .52298 L F
.2905 .52176 m .28843 .52361 L .28964 .52416 L F
.233 .445 .861 r
.23927 .61944 m .2413 .62259 L .2422 .62081 L F
.381 .63 .952 r
.2413 .62259 m .24331 .623 L .2422 .62081 L F
.573 .499 .734 r
.44207 .51057 m .44008 .51349 L .43919 .51149 L F
.44207 .51057 m .44292 .51495 L .44008 .51349 L F
.095 .199 .683 r
.61355 .39131 m .61269 .39423 L .61158 .38923 L F
.608 .893 .989 r
.61434 .39244 m .61269 .39423 L .61355 .39131 L F
.61434 .39244 m .61234 .39436 L .61269 .39423 L F
.761 .942 .606 r
.4003 .66269 m .40222 .66092 L .40282 .65924 L F
.118 .154 .623 r
.40222 .66092 m .40426 .66321 L .40297 .66333 L F
.669 .206 .145 r
.4003 .66269 m .40426 .66321 L .40222 .66092 L F
.894 .986 .727 r
.24418 .5333 m .24309 .53623 L .24569 .53401 L F
.801 .921 .918 r
.246 .53137 m .24569 .53401 L .24815 .53241 L F
.822 .937 .904 r
.246 .53137 m .24418 .5333 L .24569 .53401 L F
.72 .207 0 r
.5917 .39023 m .5946 .39305 L .59309 .39177 L F
.936 .561 .216 r
.5946 .39305 m .5939 .39475 L .59309 .39177 L F
.5946 .39305 m .59539 .39568 L .5939 .39475 L F
.949 .929 .58 r
.65859 .41288 m .65852 .41595 L .6599 .41206 L F
0 0 0 r
.6599 .41206 m .66135 .40748 L .66006 .41123 L F
.766 .958 .648 r
.65859 .41288 m .6599 .41206 L .66006 .41123 L F
.811 .553 .549 r
.62202 .37901 m .62582 .37709 L .62521 .37592 L F
.62202 .37901 m .62582 .37974 L .62582 .37709 L F
.577 .83 .993 r
.62582 .37709 m .6254 .37534 L .62521 .37592 L F
.62582 .37709 m .62867 .37645 L .6254 .37534 L F
.743 .61 .71 r
.62582 .37974 m .62867 .37645 L .62582 .37709 L F
.587 .568 .8 r
.35943 .67682 m .3604 .67256 L .35809 .67305 L F
.35943 .67682 m .36204 .67621 L .3604 .67256 L F
.352 .216 .552 r
.35943 .67682 m .36193 .67905 L .36204 .67621 L F
.35943 .67682 m .35941 .6797 L .36193 .67905 L F
.054 .619 .767 r
.25089 .53148 m .246 .53137 L .24815 .53241 L F
.894 .763 .711 r
.36315 .6697 m .36591 .67075 L .36688 .66708 L F
.36315 .6697 m .36688 .66708 L .36477 .66909 L F
.989 .734 .443 r
.36507 .66719 m .36688 .66708 L .36568 .66388 L F
.936 .965 .739 r
.36477 .66909 m .36688 .66708 L .36507 .66719 L F
.312 .251 .626 r
.36879 .66669 m .36688 .66708 L .36946 .66937 L F
.345 .768 .975 r
.31841 .63134 m .31998 .63225 L .3157 .63172 L F
.31841 .63134 m .31998 .63225 L .3157 .63172 L F
.916 .97 .672 r
.31233 .55034 m .31242 .55244 L .31408 .54892 L F
.369 .637 .958 r
.31233 .55034 m .31417 .55209 L .31242 .55244 L F
.603 .401 .58 r
.3159 .55419 m .31242 .55244 L .31417 .55209 L F
.3159 .55419 m .312 .55515 L .31242 .55244 L F
.702 .747 .886 r
.3681 .64429 m .37216 .64411 L .37022 .64159 L F
.59 .704 .922 r
.37022 .64159 m .37216 .64411 L .37455 .64321 L F
.566 .275 .434 r
.33163 .55204 m .3344 .55197 L .33493 .54958 L F
.422 .198 .466 r
.3344 .55197 m .33755 .54847 L .33493 .54958 L F
0 0 .154 r
.27347 .58751 m .27418 .58784 L .27541 .58933 L F
.738 .485 .546 r
.27583 .5903 m .27347 .58751 L .27541 .58933 L F
.811 .659 .694 r
.27418 .58784 m .27653 .59068 L .27662 .59047 L F
.738 .485 .546 r
.27583 .58989 m .27541 .58933 L .27583 .58972 L F
.27583 .5903 m .27541 .58933 L .27583 .58989 L F
.27583 .5903 m .27297 .59046 L .27347 .58751 L F
.668 .291 .323 r
.27583 .5903 m .27601 .59192 L .27297 .59046 L F
.125 0 .32 r
.27662 .59047 m .27601 .59192 L .27583 .5903 L F
.811 .659 .694 r
.27418 .58784 m .27601 .59192 L .27649 .59079 L F
0 .388 .826 r
.27583 .58989 m .27662 .59047 L .27583 .5903 L F
.27583 .58972 m .27662 .59047 L .27583 .58989 L F
.811 .659 .694 r
.27596 .58999 m .27649 .59079 L .27653 .59068 L F
.27541 .58933 m .27583 .58989 L .27596 .58999 L F
.27583 .58989 m .27649 .59079 L .27596 .58999 L F
.27418 .58784 m .27649 .59079 L .27541 .58933 L F
0 0 .154 r
.27541 .58933 m .27418 .58784 L .27583 .58972 L F
.27347 .58751 m .27297 .59046 L .27418 .58784 L F
.448 .234 .495 r
.33892 .55252 m .33871 .55529 L .33632 .5555 L F
.125 .026 .461 r
.33785 .55724 m .33632 .5555 L .33871 .55529 L F
.33785 .55724 m .33653 .55828 L .33632 .5555 L F
.204 0 0 r
.23937 .57097 m .23542 .57331 L .23657 .57137 L F
.23937 .57097 m .23754 .57297 L .23542 .57331 L F
.424 0 0 r
.24116 .57248 m .23754 .57297 L .23937 .57097 L F
.456 0 0 r
.24303 .57118 m .24116 .57248 L .23937 .57097 L F
0 0 .16 r
.29656 .54829 m .29464 .55188 L .29447 .54943 L F
.958 .77 .608 r
.62266 .40171 m .62427 .40258 L .62369 .39928 L F
.92 .546 .125 r
.62381 .40417 m .62427 .40258 L .62266 .40171 L F
.62381 .40417 m .62521 .40567 L .62427 .40258 L F
.721 .627 .753 r
.62427 .40258 m .62769 .39947 L .62369 .39928 L F
.535 .352 .58 r
.37764 .5834 m .37294 .58707 L .37741 .58365 L F
.684 .504 .637 r
.38692 .57475 m .38706 .5776 L .38428 .57781 L F
.936 .795 .68 r
.26005 .57389 m .25696 .5751 L .2578 .57296 L F
.26005 .57389 m .25894 .57623 L .25696 .5751 L F
.902 .741 .673 r
.26005 .57389 m .25939 .57716 L .25894 .57623 L F
.304 .594 .946 r
.27153 .6243 m .26745 .62197 L .2697 .62157 L F
.553 .664 .911 r
.27368 .62297 m .27153 .6243 L .2697 .62157 L F
.677 .13 0 r
.33817 .69823 m .34 .70003 L .33709 .69825 L F
.745 .642 .746 r
.63407 .38065 m .63652 .38002 L .63696 .37768 L F
.072 .257 .747 r
.61313 .41861 m .6153 .42063 L .6137 .41669 L F
.827 .574 .556 r
.39444 .60973 m .39527 .61301 L .39274 .6119 L F
0 0 0 r
.62743 .42244 m .62754 .42105 L .6284 .42054 L F
.62743 .42244 m .62721 .42502 L .62754 .42105 L F
.29938 .64565 m .30154 .64149 L .30227 .64502 L F
.483 .105 .245 r
.29938 .64565 m .30227 .64502 L .30125 .64711 L F
.778 .919 .932 r
.62819 .44985 m .63126 .44902 L .63062 .44667 L F
.735 .894 .952 r
.63126 .44902 m .63336 .44613 L .63062 .44667 L F
.63126 .44902 m .63489 .44745 L .63336 .44613 L F
0 .389 .801 r
.71059 .28182 m .70956 .28158 L .70708 .28246 L F
.874 .879 .836 r
.66509 .33133 m .66251 .33134 L .66488 .32849 L F
.818 .858 .878 r
.66803 .32853 m .66509 .33133 L .66488 .32849 L F
.055 0 .328 r
.3088 .62126 m .30689 .62221 L .30933 .61874 L F
.132 0 .219 r
.34891 .67929 m .34719 .68024 L .34636 .68252 L F
.34891 .67929 m .34719 .68024 L .34636 .68252 L F
.282 .013 .316 r
.33544 .60233 m .33855 .59937 L .3359 .6002 L F
.524 .602 .874 r
.27361 .63598 m .278 .63883 L .27677 .63698 L F
.17 .451 .88 r
.27677 .63698 m .278 .63883 L .2786 .63734 L F
.117 .385 .842 r
.278 .63883 m .28118 .64086 L .2786 .63734 L F
.828 .811 .834 r
.64637 .34841 m .64207 .34995 L .64489 .34693 L F
.815 .854 .878 r
.64942 .34537 m .64637 .34841 L .64489 .34693 L F
.838 .754 .77 r
.63696 .37768 m .63922 .37444 L .63747 .37251 L F
.788 .78 .846 r
.63922 .37444 m .64027 .36974 L .63747 .37251 L F
0 .48 .804 r
.38574 .54847 m .38657 .54847 L .38785 .54915 L F
.38574 .54847 m .38657 .54847 L .38785 .54915 L F
.087 0 0 r
.58204 .41872 m .57775 .42079 L .58111 .41775 L F
.94 .642 .185 r
.58074 .41463 m .58204 .41872 L .58111 .41775 L F
.544 .884 .987 r
.61028 .37094 m .61178 .37179 L .61397 .37086 L F
.352 .122 .419 r
.61397 .37086 m .61178 .37179 L .61128 .37446 L F
0 0 .37 r
.70562 .3013 m .70524 .30087 L .70584 .29956 L F
.70562 .3013 m .70629 .30307 L .70524 .30087 L F
.093 .266 .749 r
.41063 .55002 m .41194 .55155 L .41057 .54813 L F
.962 .848 .683 r
.31374 .50641 m .31694 .5037 L .31548 .50445 L F
.31374 .50641 m .31566 .50778 L .31694 .5037 L F
.977 .731 .495 r
.33454 .50272 m .33342 .50358 L .33364 .50068 L F
.396 .73 .991 r
.33494 .50361 m .3361 .50231 L .33364 .50068 L F
.845 .594 .558 r
.33364 .50068 m .33342 .50358 L .32981 .50257 L F
.809 .408 .292 r
.33342 .50358 m .33152 .50513 L .32981 .50257 L F
.848 .975 .668 r
.33404 .50128 m .33162 .50498 L .33342 .50358 L F
.33162 .50498 m .33152 .50513 L .33342 .50358 L F
.977 .731 .495 r
.33494 .50361 m .33342 .50358 L .33454 .50272 L F
.396 .73 .991 r
.33494 .50361 m .33755 .50363 L .3361 .50231 L F
.167 0 .218 r
.26462 .56145 m .2661 .56094 L .26638 .55926 L F
.707 .45 .533 r
.2661 .56094 m .27037 .55861 L .26638 .55926 L F
.92 .678 .556 r
.39505 .60618 m .39193 .6086 L .39229 .60561 L F
.39505 .60618 m .39444 .60973 L .39193 .6086 L F
.663 .456 .595 r
.68478 .3735 m .6855 .37648 L .68205 .3766 L F
.483 .344 .615 r
.68808 .37548 m .68478 .3735 L .68748 .37284 L F
.68808 .37548 m .6855 .37648 L .68478 .3735 L F
.366 .385 .748 r
.5748 .42272 m .57552 .42341 L .57892 .42315 L F
.122 .282 .755 r
.3037 .53806 m .3027 .5397 L .30129 .53592 L F
.125 .287 .758 r
.3037 .53806 m .30465 .54173 L .3027 .5397 L F
.525 .383 .63 r
.30465 .54173 m .30349 .54297 L .3027 .5397 L F
.555 .756 .971 r
.23884 .54899 m .24158 .54911 L .23978 .54761 L F
.713 .976 .756 r
.23978 .54761 m .23716 .54995 L .23884 .54899 L F
.555 .756 .971 r
.23884 .54899 m .24158 .54911 L .23978 .54761 L F
.514 .473 .748 r
.45501 .55452 m .45253 .55533 L .45165 .55263 L F
.599 .554 .775 r
.45624 .55829 m .45253 .55533 L .45501 .55452 L F
.822 .803 .834 r
.71705 .33781 m .71495 .33994 L .71307 .33768 L F
.795 .623 .668 r
.6613 .37027 m .66509 .3703 L .66353 .36732 L F
.691 .425 .516 r
.66113 .37301 m .66509 .3703 L .6613 .37027 L F
.66113 .37301 m .66419 .37313 L .66509 .3703 L F
.664 .227 .202 r
.66718 .3721 m .66509 .3703 L .66419 .37313 L F
.66718 .3721 m .66783 .371 L .66509 .3703 L F
.196 .066 .466 r
.28897 .64139 m .29036 .63814 L .29018 .64132 L F
.179 .262 .713 r
.29127 .64271 m .28897 .64139 L .29018 .64132 L F
.754 .614 .703 r
.23384 .56161 m .23193 .56476 L .23132 .56197 L F
.015 0 0 r
.28958 .54786 m .29166 .54716 L .29351 .54513 L F
0 0 .123 r
.29351 .54513 m .29449 .54476 L .29482 .54178 L F
.283 0 .162 r
.29166 .54716 m .29449 .54476 L .29351 .54513 L F
.842 .72 .729 r
.39903 .67687 m .39757 .68099 L .39685 .68022 L F
.402 .244 .55 r
.40155 .67884 m .39757 .68099 L .39903 .67687 L F
.485 0 0 r
.32506 .62059 m .32355 .61941 L .32166 .62121 L F
.39 .467 .818 r
.32661 .62169 m .32355 .61941 L .3266 .61976 L F
.485 0 0 r
.32506 .62059 m .3266 .61976 L .32355 .61941 L F
.033 .546 .871 r
.5788 .39586 m .58022 .3967 L .57656 .39535 L F
.124 .57 .921 r
.58188 .39612 m .58022 .3967 L .5788 .39586 L F
.58188 .39612 m .58342 .39739 L .58022 .3967 L F
.685 .691 .85 r
.2182 .59963 m .2201 .6032 L .22255 .60046 L F
.512 .425 .694 r
.2201 .6032 m .22049 .60318 L .22255 .60046 L F
.389 .381 .729 r
.2201 .6032 m .22325 .60506 L .22049 .60318 L F
.679 .622 .785 r
.35379 .65152 m .35393 .65377 L .35644 .65092 L F
.328 0 0 r
.37143 .57889 m .36725 .58086 L .36739 .57771 L F
.37143 .57889 m .37015 .58045 L .36725 .58086 L F
.604 .54 .755 r
.37267 .57402 m .37143 .57889 L .37017 .57459 L F
.37267 .57402 m .37388 .57789 L .37143 .57889 L F
0 0 0 r
.37209 .57926 m .37143 .57889 L .37388 .57789 L F
.37209 .57926 m .37015 .58045 L .37143 .57889 L F
.083 .539 .905 r
.27361 .63598 m .27677 .63698 L .27561 .63586 L F
.842 .669 .669 r
.34701 .55937 m .34755 .56197 L .34415 .56163 L F
0 0 .516 r
.34839 .56012 m .34755 .56197 L .34732 .56084 L F
.34839 .56012 m .34732 .56084 L .34701 .55937 L F
.343 .234 .583 r
.34839 .56012 m .34528 .56173 L .34755 .56197 L F
.34839 .56012 m .34833 .56143 L .34528 .56173 L F
.842 .669 .669 r
.34701 .55937 m .34415 .56163 L .34324 .55891 L F
.757 .41 .398 r
.34442 .5594 m .3462 .56146 L .34839 .56012 L F
0 .237 .747 r
.34928 .55951 m .34839 .56012 L .3462 .56146 L F
.34945 .5594 m .34839 .56012 L .34928 .55951 L F
.175 .697 .877 r
.34523 .56174 m .34755 .56197 L .34528 .56173 L F
.584 .576 .81 r
.34755 .56197 m .3515 .56511 L .35017 .56149 L F
.343 .234 .583 r
.34833 .56143 m .34828 .56287 L .34528 .56173 L F
.175 .697 .877 r
.34415 .56163 m .34523 .56174 L .34528 .56173 L F
.477 .229 .459 r
.37671 .71136 m .37959 .70862 L .37855 .71063 L F
.322 0 .011 r
.37959 .70862 m .38057 .71039 L .37855 .71063 L F
.37959 .70862 m .38214 .70832 L .38057 .71039 L F
.746 .497 0 r
.40384 .66995 m .40431 .67253 L .40461 .67369 L F
.952 .895 .506 r
.4045 .67324 m .40331 .67534 L .40461 .67369 L F
.4041 .67311 m .40331 .67534 L .4045 .67324 L F
.662 .43 .558 r
.40043 .67279 m .40431 .67253 L .40384 .66995 L F
.352 0 .196 r
.40043 .67279 m .40279 .67209 L .40431 .67253 L F
0 0 .506 r
.40279 .67209 m .40446 .67399 L .40331 .67534 L F
.594 .05 0 r
.40292 .67302 m .40446 .67399 L .40354 .67294 L F
.40288 .67273 m .40354 .67294 L .40279 .67209 L F
.40292 .67302 m .40354 .67294 L .40288 .67273 L F
.952 .895 .506 r
.40431 .67253 m .4041 .67311 L .4045 .67324 L F
.709 .302 .273 r
.24056 .61208 m .24481 .61238 L .24249 .61314 L F
.451 .157 .375 r
.17928 .67355 m .18082 .67523 L .18199 .67272 L F
.17928 .67355 m .18082 .67523 L .18199 .67272 L F
.218 .307 .741 r
.388 .64544 m .38927 .64741 L .38821 .64448 L F
.958 .717 .531 r
.36136 .5173 m .35974 .51642 L .35953 .51373 L F
.357 .21 .541 r
.36136 .5173 m .36172 .51928 L .35974 .51642 L F
.36136 .5173 m .36439 .52045 L .36172 .51928 L F
.595 .061 0 r
.36502 .52053 m .36439 .52045 L .36136 .5173 L F
0 0 .323 r
.20412 .60301 m .2045 .60665 L .20493 .60506 L F
.4 .722 .989 r
.2045 .60665 m .20689 .60649 L .20493 .60506 L F
.498 .122 .257 r
.59029 .45664 m .58931 .45866 L .58657 .45899 L F
.535 .226 .391 r
.59029 .45664 m .59294 .45853 L .58931 .45866 L F
.59029 .45664 m .59306 .45638 L .59294 .45853 L F
.819 .483 .42 r
.54016 .44687 m .54224 .4471 L .54044 .4488 L F
.784 .429 .385 r
.54224 .4471 m .5443 .44978 L .54044 .4488 L F
.2 0 .031 r
.29569 .63177 m .29913 .62922 L .29845 .631 L F
.344 0 .198 r
.29845 .631 m .29913 .62922 L .30136 .62865 L F
.765 .754 .843 r
.35293 .54162 m .34792 .54393 L .35293 .54356 L F
.249 .315 .736 r
.35293 .54162 m .35293 .54356 L .35404 .5413 L F
.35293 .54162 m .35293 .54356 L .35404 .5413 L F
.622 .122 .043 r
.71329 .35102 m .71761 .35161 L .71614 .3528 L F
.386 .797 .98 r
.72235 .35375 m .71973 .35429 L .71932 .35352 L F
0 0 .499 r
.71931 .3535 m .71973 .35429 L .71936 .35356 L F
.386 .797 .98 r
.72235 .35375 m .71932 .35352 L .72122 .35189 L F
0 0 .499 r
.71761 .35161 m .71973 .35429 L .71932 .35352 L F
.71761 .35161 m .71932 .35352 L .7193 .35349 L F
.71761 .35161 m .7193 .35349 L .71614 .3528 L F
.386 .797 .98 r
.71932 .35352 m .71907 .35351 L .7193 .35349 L F
.71907 .35351 m .71892 .35349 L .71907 .35349 L F
.71907 .35351 m .71907 .35349 L .7193 .35349 L F
0 0 .499 r
.7193 .35349 m .71907 .35349 L .71614 .3528 L F
.418 .555 .886 r
.71614 .3528 m .71907 .35349 L .71717 .35053 L F
.386 .797 .98 r
.71932 .35352 m .71911 .35321 L .72122 .35189 L F
.631 .649 .85 r
.71717 .35053 m .71911 .35321 L .72122 .35189 L F
.386 .797 .98 r
.71911 .35321 m .71872 .35261 L .72122 .35189 L F
.631 .649 .85 r
.71911 .35321 m .71936 .35356 L .72122 .35189 L F
0 0 .499 r
.7193 .35349 m .71932 .35352 L .71931 .3535 L F
.7193 .35349 m .71936 .35356 L .71907 .35349 L F
.418 .555 .886 r
.71907 .35349 m .71911 .35321 L .71717 .35053 L F
.386 .797 .98 r
.7193 .35349 m .71635 .3533 L .71872 .35261 L F
.418 .555 .886 r
.71907 .35349 m .71936 .35356 L .71911 .35321 L F
.386 .797 .98 r
.71892 .35349 m .71635 .3533 L .7193 .35349 L F
.71932 .35352 m .71973 .35429 L .71635 .3533 L F
.684 .771 .917 r
.60609 .36356 m .60213 .36241 L .60404 .36079 L F
.681 .76 .911 r
.60776 .36169 m .60609 .36356 L .60404 .36079 L F
.605 .633 .852 r
.60776 .36169 m .60991 .36481 L .60609 .36356 L F
.082 0 .338 r
.42385 .5485 m .42336 .55087 L .42146 .55224 L F
.505 .312 .551 r
.42426 .55457 m .42146 .55224 L .42336 .55087 L F
.42426 .55457 m .42142 .55532 L .42146 .55224 L F
.568 .359 .556 r
.30133 .60975 m .30434 .60959 L .30433 .60653 L F
.342 .131 .441 r
.30433 .60653 m .30636 .6059 L .30666 .60334 L F
.301 .151 .504 r
.30433 .60653 m .30613 .60856 L .30636 .6059 L F
.30433 .60653 m .30434 .60959 L .30613 .60856 L F
.465 .237 .482 r
.45463 .581 m .45444 .58346 L .45196 .58407 L F
.423 .202 .472 r
.45686 .5828 m .45463 .581 L .45728 .58044 L F
.45686 .5828 m .45444 .58346 L .45463 .581 L F
.731 .483 .553 r
.30154 .64149 m .30509 .64161 L .30457 .6444 L F
0 0 .333 r
.30509 .64161 m .30681 .63774 L .30706 .64049 L F
.279 .075 .414 r
.30457 .6444 m .30509 .64161 L .30706 .64049 L F
.477 .82 .998 r
.30229 .64009 m .30509 .64161 L .30154 .64149 L F
.163 .457 .884 r
.58526 .39784 m .58439 .39928 L .58342 .39739 L F
.044 .293 .784 r
.58699 .40117 m .58439 .39928 L .58526 .39784 L F
.783 .676 .746 r
.60664 .3801 m .60772 .38371 L .60417 .38331 L F
.744 .757 .863 r
.60417 .38331 m .60772 .38371 L .60391 .38416 L F
.602 .467 .669 r
.33484 .58631 m .33214 .5894 L .33224 .58746 L F
0 .168 .685 r
.24368 .55385 m .24318 .55618 L .24103 .55435 L F
.463 .126 .308 r
.24318 .55618 m .24499 .55764 L .24578 .55562 L F
0 .168 .685 r
.24368 .55385 m .24499 .55764 L .24318 .55618 L F
.312 0 .152 r
.43796 .55382 m .44081 .55157 L .43911 .55344 L F
.43796 .55382 m .4401 .55414 L .44081 .55157 L F
.071 .045 .518 r
.44081 .55157 m .44244 .5478 L .44022 .55027 L F
.44081 .55157 m .44266 .55057 L .44244 .5478 L F
.307 0 .151 r
.44081 .55157 m .44264 .55334 L .44266 .55057 L F
.44081 .55157 m .4401 .55414 L .44264 .55334 L F
.569 .42 .639 r
.29356 .61927 m .2963 .6188 L .29597 .61598 L F
.501 .322 .571 r
.2937 .62205 m .2963 .6188 L .29356 .61927 L F
0 .05 .611 r
.2358 .61575 m .23728 .61991 L .23763 .6182 L F
.492 .784 .997 r
.23728 .61991 m .23927 .61944 L .23763 .6182 L F
.588 .46 .674 r
.65222 .37668 m .6545 .37323 L .65194 .37399 L F
.65222 .37668 m .6556 .37695 L .6545 .37323 L F
.632 .54 .733 r
.6532 .38001 m .6556 .37695 L .65222 .37668 L F
.642 .611 .804 r
.65059 .38365 m .6509 .3859 L .65343 .38287 L F
.602 .585 .807 r
.6509 .3859 m .6545 .38634 L .65343 .38287 L F
.719 .642 .771 r
.45104 .56548 m .44827 .56781 L .44776 .56604 L F
0 0 0 r
.39927 .60843 m .39783 .60977 L .40043 .60658 L F
.33463 .67881 m .33623 .6771 L .33265 .67961 L F
.33833 .67604 m .33623 .6771 L .33463 .67881 L F
.874 .865 .418 r
.36582 .51657 m .36502 .52053 L .36712 .52003 L F
.36582 .51657 m .36439 .52045 L .36502 .52053 L F
.422 .308 .618 r
.36502 .52053 m .36677 .5224 L .36712 .52003 L F
.36502 .52053 m .36528 .52325 L .36677 .5224 L F
0 0 .051 r
.6138 .44626 m .6132 .44841 L .6115 .45042 L F
0 0 .291 r
.6115 .45042 m .61288 .45014 L .61178 .45243 L F
.6115 .45042 m .6132 .44841 L .61288 .45014 L F
.87 .99 .824 r
.63489 .44745 m .63762 .4444 L .63558 .44462 L F
.609 .955 .878 r
.63558 .44462 m .63762 .4444 L .63968 .44297 L F
.009 0 .189 r
.27972 .63017 m .27943 .62727 L .27989 .62747 L F
.27972 .63017 m .27854 .63041 L .27943 .62727 L F
.728 .939 .618 r
.64878 .41045 m .65018 .40929 L .64796 .4121 L F
.728 .938 .615 r
.64878 .41045 m .64796 .4121 L .6462 .41373 L F
.973 .915 .587 r
.40418 .59195 m .40383 .59625 L .40475 .59568 L F
.578 .571 .81 r
.44024 .48829 m .43812 .49093 L .43763 .48894 L F
.44024 .48829 m .44067 .4905 L .43812 .49093 L F
.603 .492 .7 r
.44172 .49449 m .43812 .49093 L .44067 .4905 L F
.44172 .49449 m .43914 .49504 L .43812 .49093 L F
.272 .761 .913 r
.55473 .41511 m .55057 .41488 L .55315 .41391 L F
.598 .847 .992 r
.55583 .41309 m .55473 .41511 L .55315 .41391 L F
0 0 .015 r
.55415 .41747 m .55473 .41511 L .55583 .41309 L F
.696 .494 .61 r
.28557 .53613 m .28248 .53928 L .28289 .53664 L F
.39 .621 .944 r
.34199 .70701 m .34301 .7086 L .34423 .70693 L F
.332 .54 .905 r
.34423 .70693 m .34301 .7086 L .34483 .70844 L F
0 .031 .574 r
.34301 .7086 m .34609 .71228 L .34483 .70844 L F
.762 .996 .845 r
.35063 .52433 m .34949 .5267 L .35193 .5244 L F
.764 .978 .717 r
.35063 .52433 m .34766 .52767 L .34949 .5267 L F
0 0 .057 r
.33274 .51729 m .3329 .51704 L .33313 .51381 L F
.255 .087 .451 r
.33313 .51381 m .3371 .51424 L .33507 .5131 L F
.33313 .51381 m .3329 .51704 L .3371 .51424 L F
.894 .986 .727 r
.24418 .5333 m .24231 .53635 L .24309 .53623 L F
.716 .356 .365 r
.24085 .5383 m .24309 .53623 L .24231 .53635 L F
.24085 .5383 m .24531 .53798 L .24309 .53623 L F
.141 .191 .654 r
.2071 .58743 m .20761 .58307 L .20568 .58352 L F
.2071 .58743 m .20813 .58673 L .20761 .58307 L F
.051 0 .456 r
.20717 .59008 m .20813 .58673 L .2071 .58743 L F
.682 .568 .721 r
.43159 .56717 m .43253 .57144 L .42988 .57155 L F
.681 .548 .696 r
.43253 .57144 m .43001 .57461 L .42988 .57155 L F
0 0 0 r
.33744 .68321 m .34 .68283 L .33848 .68344 L F
.235 .38 .806 r
.40039 .5545 m .40191 .55807 L .39938 .55622 L F
.737 .763 .874 r
.63633 .36134 m .63242 .36072 L .63454 .35992 L F
.834 .738 .758 r
.63536 .35763 m .63633 .36134 L .63454 .35992 L F
.711 .591 .719 r
.6661 .364 m .66994 .36462 L .6688 .36061 L F
.634 .549 .741 r
.66994 .36462 m .67117 .3601 L .6688 .36061 L F
.66994 .36462 m .67272 .3639 L .67117 .3601 L F
.626 .519 .712 r
.66994 .36462 m .67038 .36745 L .67272 .3639 L F
.745 .772 .874 r
.62174 .36184 m .62314 .36408 L .61918 .36352 L F
.611 .667 .88 r
.62449 .35964 m .62314 .36408 L .62174 .36184 L F
.62449 .35964 m .62585 .36337 L .62314 .36408 L F
.445 .347 .65 r
.45422 .54813 m .45389 .55215 L .45165 .55263 L F
.473 .482 .786 r
.45389 .55215 m .45501 .55452 L .45165 .55263 L F
.526 .842 .999 r
.42582 .55556 m .42142 .55532 L .42426 .55457 L F
0 0 0 r
.33574 .5242 m .33772 .52319 L .33892 .52384 L F
.658 .935 .968 r
.33892 .52384 m .33772 .52319 L .33999 .52192 L F
.905 .953 .818 r
.39203 .56828 m .38963 .57154 L .38842 .57022 L F
.623 .938 .959 r
.26236 .52174 m .25776 .52261 L .25814 .52167 L F
.26236 .52174 m .25612 .52376 L .25776 .52261 L F
0 .214 .736 r
.26269 .51976 m .26236 .52174 L .25814 .52167 L F
.623 .938 .959 r
.26236 .52174 m .25612 .52376 L .25776 .52261 L F
.802 .833 .875 r
.71596 .33507 m .71705 .33781 L .71307 .33768 L F
.768 .817 .891 r
.71842 .3333 m .71705 .33781 L .71596 .33507 L F
.71842 .3333 m .71948 .33595 L .71705 .33781 L F
0 0 .516 r
.34839 .56012 m .34701 .55937 L .34935 .55832 L F
.702 .665 .811 r
.42125 .48611 m .41699 .48538 L .41945 .48452 L F
.224 .736 .703 r
.37075 .71305 m .37671 .71136 L .37605 .71206 L F
.03 0 0 r
.37671 .71136 m .3782 .71146 L .37605 .71206 L F
.37671 .71136 m .37855 .71063 L .3782 .71146 L F
.604 .111 0 r
.3771 .51556 m .37628 .51429 L .37585 .51277 L F
.3771 .51556 m .37769 .51593 L .37628 .51429 L F
.321 .414 .801 r
.47095 .56917 m .46786 .56746 L .47033 .56908 L F
.47095 .56917 m .46918 .57148 L .46786 .56746 L F
0 0 .145 r
.47072 .57181 m .46918 .57148 L .47095 .56917 L F
.47072 .57181 m .46846 .57363 L .46918 .57148 L F
.828 .8 .306 r
.62656 .42743 m .62721 .42502 L .62743 .42244 L F
.419 .379 .708 r
.32627 .63211 m .32937 .63442 L .32896 .63262 L F
0 0 .505 r
.33274 .51729 m .33495 .52132 L .3329 .51704 L F
.487 .342 .61 r
.67272 .3639 m .67038 .36745 L .67296 .36671 L F
.44 .221 .484 r
.67296 .36671 m .67038 .36745 L .67045 .36993 L F
.981 .904 .576 r
.64963 .40803 m .65018 .40929 L .64878 .41045 L F
.157 0 .033 r
.21313 .60118 m .21224 .60007 L .21647 .59961 L F
.442 0 0 r
.2182 .59963 m .21313 .60118 L .21647 .59961 L F
.656 .1 0 r
.36322 .50392 m .36762 .50656 L .36465 .50537 L F
.59 .334 .497 r
.43948 .5906 m .43934 .59329 L .43674 .59343 L F
.644 .379 .503 r
.44303 .59284 m .43948 .5906 L .44324 .59042 L F
.44303 .59284 m .43934 .59329 L .43948 .5906 L F
.399 .645 .956 r
.37739 .65702 m .37987 .65893 L .38169 .65849 L F
.326 .214 .569 r
.37987 .65893 m .37955 .66128 L .38169 .65849 L F
.001 0 0 r
.34851 .56801 m .35008 .56754 L .3515 .56511 L F
.43 .36 .677 r
.3515 .56511 m .3535 .56341 L .35017 .56149 L F
.3515 .56511 m .35321 .56449 L .3535 .56341 L F
.539 .174 .296 r
.3515 .56511 m .35337 .56684 L .35321 .56449 L F
.3515 .56511 m .35008 .56754 L .35337 .56684 L F
.332 .132 .451 r
.33202 .57653 m .33019 .57445 L .33252 .57367 L F
.33202 .57653 m .32977 .57747 L .33019 .57445 L F
.753 .627 .72 r
.66995 .35119 m .67386 .3517 L .67247 .34789 L F
.729 .582 .691 r
.67128 .35472 m .67386 .3517 L .66995 .35119 L F
.67128 .35472 m .67379 .35444 L .67386 .3517 L F
.571 .93 .77 r
.22728 .55904 m .22623 .55951 L .22547 .56049 L F
.709 .905 .542 r
.22623 .55951 m .2262 .55955 L .22547 .56049 L F
.865 .871 .841 r
.22497 .56112 m .22767 .55967 L .22547 .56049 L F
.709 .905 .542 r
.2262 .55955 m .22442 .56209 L .22547 .56049 L F
.865 .871 .841 r
.22382 .56174 m .22497 .56112 L .22547 .56049 L F
.585 .94 .795 r
.22728 .55904 m .22767 .55967 L .22976 .55836 L F
.22728 .55904 m .22547 .56049 L .22767 .55967 L F
0 0 .4 r
.35786 .58901 m .35646 .58826 L .3582 .58672 L F
.35786 .58901 m .35622 .59037 L .35646 .58826 L F
.461 .207 .441 r
.45444 .58346 m .45159 .58639 L .45196 .58407 L F
.553 .892 .984 r
.33753 .70182 m .34128 .70143 L .34029 .70041 L F
.43 .475 .805 r
.33753 .70182 m .34087 .7039 L .34128 .70143 L F
.128 .605 .918 r
.34029 .70041 m .34128 .70143 L .34223 .70096 L F
0 0 .068 r
.34223 .70096 m .34128 .70143 L .34087 .7039 L F
0 0 .373 r
.20693 .57143 m .20777 .57345 L .20783 .57047 L F
0 0 .375 r
.20697 .57413 m .20777 .57345 L .20693 .57143 L F
.425 .115 .334 r
.37349 .5724 m .37267 .57402 L .37017 .57459 L F
.863 .516 .394 r
.34802 .56732 m .35008 .56754 L .34851 .56801 L F
.495 .848 .589 r
.34389 .69142 m .34267 .69249 L .34388 .69137 L F
.471 .463 .767 r
.33416 .5677 m .33494 .5706 L .33282 .57104 L F
.426 .224 .502 r
.33494 .5706 m .33252 .57367 L .33282 .57104 L F
.863 .928 .868 r
.65621 .41725 m .65852 .41595 L .65859 .41288 L F
.756 .899 .941 r
.63336 .44613 m .63489 .44745 L .63558 .44462 L F
0 0 0 r
.22891 .53882 m .23042 .53799 L .23214 .5362 L F
.683 .979 .874 r
.23214 .5362 m .23278 .53468 L .2354 .53408 L F
.717 .914 .56 r
.23214 .5362 m .23042 .53799 L .23278 .53468 L F
.626 .511 .702 r
.38123 .62527 m .3841 .62516 L .38355 .62224 L F
.854 .405 .01 r
.69546 .32554 m .69649 .32783 L .69826 .32913 L F
.92 .952 .796 r
.69649 .32783 m .69627 .33049 L .69826 .32913 L F
0 0 0 r
.69826 .32913 m .70051 .32738 L .7016 .32615 L F
.914 .526 .118 r
.69826 .32913 m .69916 .3289 L .70051 .32738 L F
.69826 .32913 m .69892 .33139 L .6973 .32992 L F
.69826 .32913 m .6973 .32992 L .69916 .3289 L F
0 0 0 r
.36753 .62438 m .36913 .62434 L .36651 .62516 L F
.36753 .62438 m .36999 .62421 L .36913 .62434 L F
.749 .49 .54 r
.34288 .55506 m .33892 .55252 L .34116 .5518 L F
.34288 .55506 m .33871 .55529 L .33892 .55252 L F
.506 .889 .708 r
.70098 .35684 m .70101 .35707 L .70398 .35501 L F
.666 .877 .504 r
.69979 .3584 m .70101 .35707 L .70098 .35684 L F
.905 .953 .818 r
.39203 .56828 m .38842 .57022 L .39029 .56712 L F
.987 .895 .58 r
.39303 .58229 m .39482 .58103 L .39395 .58087 L F
.669 .974 .883 r
.39395 .58087 m .39482 .58103 L .39575 .57941 L F
.684 .938 .65 r
.39575 .57941 m .39482 .58103 L .39303 .58229 L F
.399 0 0 r
.38657 .54847 m .38908 .55 L .38785 .54915 L F
.31 .2 .564 r
.34275 .56458 m .34118 .56476 L .341 .5619 L F
.34275 .56458 m .341 .5619 L .33927 .56328 L F
.987 .767 .517 r
.41647 .5879 m .41839 .59077 L .41801 .59305 L F
.065 0 0 r
.38953 .50003 m .39225 .49973 L .39375 .49915 L F
.36 0 0 r
.39375 .49915 m .39566 .49968 L .39623 .49783 L F
.39375 .49915 m .39225 .49973 L .39566 .49968 L F
.6 .221 .295 r
.34808 .59365 m .34987 .59577 L .34733 .59598 L F
.34808 .59365 m .35048 .59395 L .34987 .59577 L F
.067 0 0 r
.69062 .35441 m .6875 .35718 L .68974 .35581 L F
0 0 0 r
.69292 .35311 m .69346 .35148 L .69062 .35441 L F
.69292 .35311 m .69062 .35441 L .68974 .35581 L F
.755 .928 .946 r
.70708 .34071 m .70453 .34412 L .70456 .34114 L F
.70708 .34071 m .70801 .34187 L .70453 .34412 L F
.701 .706 .852 r
.40031 .4986 m .39623 .49783 L .39839 .49875 L F
.643 .964 .908 r
.40031 .4986 m .39839 .49875 L .40159 .49697 L F
.852 .813 .811 r
.36549 .67127 m .36591 .67075 L .36315 .6697 L F
0 .101 .639 r
.25179 .6256 m .25378 .62809 L .25249 .62377 L F
0 0 0 r
.69493 .36397 m .69828 .3603 L .69735 .36148 L F
.568 .537 .78 r
.44302 .50069 m .44051 .50138 L .43938 .49775 L F
.455 .307 .589 r
.44304 .50345 m .44051 .50138 L .44302 .50069 L F
.44304 .50345 m .44064 .50413 L .44051 .50138 L F
.799 .671 .722 r
.66229 .36344 m .6661 .364 L .66489 .36005 L F
.79 .702 .768 r
.66353 .36732 m .6661 .364 L .66229 .36344 L F
.745 .642 .746 r
.6661 .364 m .6688 .36061 L .66489 .36005 L F
.43 .475 .805 r
.33753 .70182 m .33882 .70555 L .34087 .7039 L F
.442 .496 .82 r
.33882 .70555 m .34199 .70701 L .34087 .7039 L F
.507 .516 .801 r
.45124 .54213 m .45031 .54642 L .44899 .54251 L F
.45124 .54213 m .45249 .546 L .45031 .54642 L F
.49 .514 .809 r
.45422 .54813 m .45031 .54642 L .45249 .546 L F
.815 .822 .856 r
.36206 .67372 m .36549 .67127 L .36315 .6697 L F
0 0 0 r
.28323 .63126 m .28134 .63361 L .28125 .63175 L F
.373 .83 .737 r
.28125 .63175 m .28391 .63075 L .28323 .63126 L F
.2811 .63179 m .2813 .63172 L .28125 .63175 L F
.2813 .63172 m .28391 .63075 L .28125 .63175 L F
0 0 0 r
.28125 .63175 m .27982 .63551 L .2811 .63179 L F
.28134 .63361 m .27982 .63551 L .28125 .63175 L F
.693 .34 .374 r
.28538 .63388 m .2864 .63238 L .28323 .63126 L F
0 .104 .658 r
.28391 .63075 m .28538 .63388 L .28323 .63126 L F
.924 .733 .626 r
.2811 .63179 m .28538 .63388 L .28391 .63075 L F
.712 .281 .224 r
.2811 .63179 m .28391 .63075 L .27972 .63017 L F
.579 .089 .055 r
.2811 .63179 m .28391 .63075 L .28198 .63225 L F
.682 .218 .144 r
.28198 .63225 m .28391 .63075 L .27972 .63017 L F
0 .182 .716 r
.28121 .63091 m .28156 .63152 L .28124 .63157 L F
.28156 .63152 m .28198 .63225 L .28136 .63167 L F
.28156 .63152 m .28136 .63167 L .28124 .63157 L F
.28007 .62894 m .28121 .63091 L .27972 .63017 L F
.28121 .63091 m .28124 .63157 L .27972 .63017 L F
.765 .69 .779 r
.6597 .36672 m .66353 .36732 L .66229 .36344 L F
.785 .609 .661 r
.6613 .37027 m .66353 .36732 L .6597 .36672 L F
.635 .605 .803 r
.30323 .66992 m .30499 .67128 L .30427 .66837 L F
.511 .523 .805 r
.30427 .66837 m .30499 .67128 L .30738 .67051 L F
0 0 0 r
.69639 .3486 m .69346 .35148 L .69551 .34985 L F
.69551 .34985 m .69346 .35148 L .69292 .35311 L F
0 0 .268 r
.34144 .65784 m .33976 .6614 L .34033 .65983 L F
.266 .49 .887 r
.33976 .6614 m .34174 .66258 L .34033 .65983 L F
.506 .377 .639 r
.26462 .56145 m .26688 .56368 L .2661 .56094 L F
.26462 .56145 m .26488 .56458 L .26688 .56368 L F
.685 .412 .503 r
.57233 .46253 m .57112 .46562 L .56832 .46519 L F
.65 .322 .402 r
.57233 .46253 m .57487 .46485 L .57112 .46562 L F
.57233 .46253 m .57476 .46286 L .57487 .46485 L F
0 0 .269 r
.34318 .52691 m .34444 .52248 L .34384 .52415 L F
.34337 .52624 m .34429 .52536 L .34444 .52248 L F
.332 .352 .731 r
.34429 .52536 m .34489 .52072 L .34444 .52248 L F
.34429 .52536 m .34635 .52455 L .34489 .52072 L F
.66 .376 .479 r
.34194 .52489 m .34505 .52465 L .34429 .52536 L F
.34505 .52465 m .34635 .52455 L .34429 .52536 L F
0 0 .269 r
.34318 .52691 m .34429 .52536 L .34337 .52624 L F
.16 .216 .672 r
.22864 .58904 m .22735 .59079 L .22654 .58701 L F
.352 .281 .636 r
.23018 .59282 m .22735 .59079 L .22864 .58904 L F
.23018 .59282 m .2279 .59356 L .22735 .59079 L F
.678 .716 .877 r
.43707 .48492 m .43296 .48359 L .43523 .48111 L F
.492 .559 .852 r
.43756 .48059 m .43707 .48492 L .43523 .48111 L F
.43756 .48059 m .43929 .48465 L .43707 .48492 L F
.083 .116 .597 r
.43897 .48696 m .43707 .48492 L .43929 .48465 L F
.43897 .48696 m .43763 .48894 L .43707 .48492 L F
.017 .262 .764 r
.64867 .4023 m .64962 .40149 L .64737 .40223 L F
.64867 .4023 m .65111 .4046 L .64962 .40149 L F
.879 .979 .684 r
.40084 .60423 m .40043 .60658 L .40254 .60318 L F
.916 .97 .672 r
.40084 .60423 m .40254 .60318 L .40199 .60257 L F
.835 .875 .435 r
.39927 .60843 m .40043 .60658 L .40084 .60423 L F
.939 .936 .768 r
.62675 .4301 m .62558 .43488 L .62806 .43163 L F
.604 .578 .798 r
.63052 .43057 m .62806 .43163 L .62656 .42743 L F
.644 .823 .969 r
.62675 .4301 m .62806 .43163 L .63052 .43057 L F
0 0 0 r
.42936 .54251 m .42835 .54492 L .42699 .54594 L F
.42835 .54492 m .42594 .54736 L .42699 .54594 L F
.835 .93 .893 r
.29957 .51309 m .29811 .51501 L .29665 .51417 L F
.775 .429 .4 r
.43001 .57461 m .43031 .57719 L .42898 .57746 L F
.722 .655 .783 r
.62983 .38004 m .63407 .38065 L .63266 .37682 L F
.745 .642 .746 r
.63407 .38065 m .63696 .37768 L .63266 .37682 L F
.218 .262 .694 r
.23581 .6053 m .23409 .60688 L .23326 .60294 L F
0 .044 .606 r
.23559 .6075 m .23409 .60688 L .23581 .6053 L F
.871 .893 .846 r
.23599 .60382 m .23559 .6075 L .23581 .6053 L F
.23599 .60382 m .23524 .60475 L .23559 .6075 L F
0 .044 .606 r
.23559 .6075 m .2358 .60913 L .23409 .60688 L F
.3 0 0 r
.23095 .60735 m .23291 .60767 L .23073 .60734 L F
.23559 .6075 m .23291 .60767 L .23095 .60735 L F
.23559 .6075 m .23291 .60767 L .23073 .60734 L F
.871 .893 .846 r
.23524 .60475 m .23291 .60767 L .23559 .6075 L F
0 .044 .606 r
.23559 .6075 m .23594 .60931 L .2358 .60913 L F
.811 .327 0 r
.23594 .60931 m .23882 .61243 L .23809 .61073 L F
.34 .475 .85 r
.23559 .6075 m .23882 .61243 L .23594 .60931 L F
.711 .277 0 r
.23709 .61025 m .23882 .61243 L .23797 .61113 L F
.2366 .60935 m .23797 .61113 L .23559 .6075 L F
.23709 .61025 m .23797 .61113 L .2366 .60935 L F
0 0 .477 r
.2366 .6089 m .23709 .61025 L .23559 .6075 L F
.2366 .6089 m .23559 .6075 L .23291 .60767 L F
.302 .633 .964 r
.23587 .60815 m .2366 .6089 L .23613 .60874 L F
.23564 .60811 m .23613 .60874 L .23291 .60767 L F
.23587 .60815 m .23613 .60874 L .23564 .60811 L F
.218 .262 .694 r
.23581 .6053 m .23326 .60294 L .23562 .60246 L F
0 0 .13 r
.23599 .60382 m .23581 .6053 L .23562 .60246 L F
.875 .903 .847 r
.23215 .60564 m .23291 .60767 L .23599 .60382 L F
.302 .633 .964 r
.23363 .60585 m .23587 .60815 L .23291 .60767 L F
.652 .095 0 r
.37769 .51593 m .37967 .51783 L .38059 .51739 L F
.448 0 0 r
.37967 .51783 m .3824 .51987 L .38059 .51739 L F
0 0 .229 r
.40155 .67884 m .40045 .68282 L .39757 .68099 L F
.835 .597 .579 r
.53425 .42437 m .53218 .4268 L .53212 .42394 L F
.53425 .42437 m .53417 .42795 L .53218 .4268 L F
.593 .683 .903 r
.2576 .61495 m .25664 .61783 L .25513 .6146 L F
.2576 .61495 m .25969 .61811 L .25664 .61783 L F
.975 .76 .55 r
.53637 .41354 m .53849 .41117 L .53612 .41099 L F
.53637 .41354 m .53826 .41487 L .53849 .41117 L F
.826 .904 .495 r
.70344 .32235 m .7016 .32615 L .7023 .32349 L F
.611 .871 .532 r
.70344 .32235 m .70499 .32023 L .70609 .3192 L F
.604 .86 .511 r
.70344 .32235 m .7023 .32349 L .70499 .32023 L F
.633 .514 .701 r
.70609 .3192 m .70626 .32207 L .70344 .32235 L F
.506 .46 .739 r
.70686 .32518 m .70344 .32235 L .70626 .32207 L F
.4 .238 .543 r
.32952 .55545 m .33163 .55474 L .33163 .55204 L F
.377 .23 .551 r
.32969 .55777 m .33163 .55474 L .32952 .55545 L F
.678 .528 .674 r
.36886 .67309 m .37301 .67371 L .37049 .67138 L F
.282 .453 .853 r
.37049 .67138 m .37301 .67371 L .37357 .67268 L F
.442 0 0 r
.37049 .67138 m .37357 .67268 L .36959 .67176 L F
.395 .161 .437 r
.22915 .56732 m .23138 .56703 L .23193 .56476 L F
.649 .715 .896 r
.69152 .32922 m .69627 .33049 L .69463 .33066 L F
.92 .952 .796 r
.69649 .32783 m .69463 .33066 L .69627 .33049 L F
.807 .862 .415 r
.69701 .34595 m .69639 .3486 L .69551 .34985 L F
.67 .756 .915 r
.33755 .50363 m .34152 .50448 L .33964 .50346 L F
.909 .983 .753 r
.34152 .50448 m .33937 .50493 L .33964 .50346 L F
.976 .723 .484 r
.36381 .60651 m .36189 .60842 L .36204 .60543 L F
.36381 .60651 m .36368 .6092 L .36189 .60842 L F
0 0 .067 r
.36403 .6085 m .36381 .60651 L .36573 .60536 L F
.36403 .6085 m .36368 .6092 L .36381 .60651 L F
.745 .4 .398 r
.55973 .43025 m .56054 .42796 L .56071 .42828 L F
.917 .891 .79 r
.56089 .42783 m .56071 .42828 L .56089 .42783 L F
.943 .603 .185 r
.56335 .42697 m .56257 .42364 L .56071 .42828 L F
.56335 .42697 m .56071 .42828 L .56089 .42783 L F
.773 .728 .811 r
.55983 .43006 m .56322 .42701 L .56089 .42783 L F
.55973 .43025 m .56191 .42823 L .55983 .43006 L F
.56191 .42823 m .56322 .42701 L .55983 .43006 L F
.784 .776 .845 r
.56335 .42697 m .56197 .42903 L .56191 .42823 L F
.56335 .42697 m .56191 .42823 L .56174 .42597 L F
.943 .603 .185 r
.56089 .42783 m .56071 .42828 L .56054 .42796 L F
.773 .728 .811 r
.56036 .42846 m .56089 .42783 L .56054 .42796 L F
.917 .891 .79 r
.55895 .42709 m .56071 .42828 L .56254 .42367 L F
.987 .763 .514 r
.55973 .43025 m .56071 .42828 L .56059 .4282 L F
.773 .728 .811 r
.55973 .43025 m .56059 .4282 L .56036 .42846 L F
.987 .763 .514 r
.55973 .43025 m .56059 .4282 L .55895 .42709 L F
.773 .728 .811 r
.55973 .43025 m .56089 .42783 L .56059 .4282 L F
.809 .793 .837 r
.56174 .42597 m .56191 .42823 L .55973 .43025 L F
.56191 .42823 m .56197 .42903 L .55973 .43025 L F
.773 .728 .811 r
.55973 .43025 m .56335 .42697 L .56322 .42701 L F
.917 .891 .79 r
.56254 .42367 m .56089 .42783 L .56257 .42364 L F
.56089 .42783 m .56089 .42783 L .56257 .42364 L F
.766 .676 .763 r
.63266 .37682 m .63696 .37768 L .63531 .37395 L F
.838 .754 .77 r
.63696 .37768 m .63747 .37251 L .63531 .37395 L F
.167 .023 .428 r
.71476 .28139 m .71679 .28042 L .71672 .27884 L F
0 0 .423 r
.71634 .28153 m .715 .28457 L .71476 .28139 L F
.71634 .28153 m .71476 .28139 L .71342 .28134 L F
.675 .157 0 r
.2699 .52952 m .26802 .52829 L .26597 .52574 L F
.831 .943 .897 r
.27078 .52584 m .2699 .52952 L .27248 .52629 L F
.27078 .52584 m .26802 .52829 L .2699 .52952 L F
.028 .078 .579 r
.34288 .55506 m .34324 .55891 L .34448 .55725 L F
0 0 .45 r
.34324 .55891 m .34442 .5594 L .34448 .55725 L F
.902 .778 .714 r
.34422 .56154 m .34275 .56458 L .3421 .56116 L F
.34528 .56173 m .34439 .56273 L .34422 .56154 L F
.34439 .56273 m .34275 .56458 L .34422 .56154 L F
0 0 .45 r
.34324 .55891 m .34415 .56163 L .34419 .5613 L F
.34388 .55917 m .34419 .5613 L .34442 .5594 L F
.34324 .55891 m .34419 .5613 L .34388 .55917 L F
.303 .769 .942 r
.33181 .49574 m .33491 .49513 L .3361 .49598 L F
.15 .659 .901 r
.33491 .49513 m .33901 .49587 L .3361 .49598 L F
.863 .863 .837 r
.33225 .69581 m .3335 .69788 L .33392 .69602 L F
.967 .669 .263 r
.42575 .5582 m .42579 .56078 L .42694 .56145 L F
.998 .825 .481 r
.42694 .56145 m .42559 .5635 L .42579 .56078 L F
.967 .669 .263 r
.42694 .56145 m .42579 .56078 L .42575 .5582 L F
.998 .825 .481 r
.42694 .56145 m .42559 .5635 L .42579 .56078 L F
.091 0 .239 r
.311 .61774 m .31002 .61648 L .31161 .61547 L F
.311 .61774 m .30933 .61874 L .31002 .61648 L F
.894 .499 .062 r
.37204 .62037 m .37238 .61926 L .37147 .61818 L F
.723 .656 .783 r
.64552 .37412 m .64703 .36955 L .64414 .37031 L F
.64552 .37412 m .64818 .37309 L .64703 .36955 L F
.749 .25 0 r
.38584 .51121 m .3858 .5125 L .38443 .5096 L F
.38584 .51121 m .38755 .51371 L .3858 .5125 L F
.773 .963 .928 r
.34688 .67204 m .34538 .67358 L .34582 .67122 L F
.731 .932 .955 r
.34582 .67122 m .34538 .67358 L .34087 .67396 L F
.126 0 0 r
.67045 .36993 m .66783 .371 L .66718 .3721 L F
.394 .04 .242 r
.36886 .67309 m .3665 .67551 L .36831 .67318 L F
.36886 .67309 m .36538 .67618 L .3665 .67551 L F
.766 .301 0 r
.36937 .67489 m .36886 .67309 L .36831 .67318 L F
.36937 .67489 m .37085 .67625 L .36886 .67309 L F
.68 .419 .52 r
.36886 .67309 m .37085 .67625 L .37301 .67371 L F
0 0 0 r
.63187 .43935 m .63434 .43828 L .63561 .43718 L F
.465 .863 .681 r
.63561 .43718 m .63743 .4358 L .63902 .43499 L F
0 0 0 r
.63561 .43718 m .63434 .43828 L .63743 .4358 L F
.445 .337 .637 r
.22049 .60318 m .2245 .60198 L .22255 .60046 L F
0 0 .159 r
.22325 .60506 m .2245 .60198 L .22049 .60318 L F
.191 0 .243 r
.21858 .54942 m .21972 .55067 L .22044 .54834 L F
.21858 .54942 m .21788 .55153 L .21972 .55067 L F
.046 0 0 r
.33265 .67961 m .32939 .68256 L .33189 .68203 L F
0 0 .036 r
.33463 .67881 m .33265 .67961 L .33189 .68203 L F
.92 .928 .798 r
.62462 .43379 m .62379 .43784 L .62558 .43488 L F
.939 .936 .768 r
.62675 .4301 m .62462 .43379 L .62558 .43488 L F
.55 .287 .471 r
.32316 .53775 m .32283 .54025 L .32026 .54021 L F
.259 .719 .952 r
.32026 .54021 m .32283 .54025 L .32092 .53991 L F
.918 .658 .529 r
.31915 .5407 m .3217 .5386 L .32026 .54021 L F
.55 .287 .471 r
.32316 .53775 m .32026 .54021 L .3217 .5386 L F
.259 .719 .952 r
.32026 .54021 m .32092 .53991 L .3189 .53954 L F
.918 .658 .529 r
.31883 .54096 m .31915 .5407 L .32026 .54021 L F
.987 .736 .462 r
.38838 .52614 m .38831 .52904 L .38983 .53012 L F
.566 .058 0 r
.38831 .52904 m .39119 .53188 L .38983 .53012 L F
.802 .334 .119 r
.38983 .53012 m .39119 .53188 L .3928 .53235 L F
.524 .72 .963 r
.43897 .48696 m .44024 .48829 L .43763 .48894 L F
.853 .861 .847 r
.57028 .40948 m .56621 .40987 L .56864 .40793 L F
.58 .329 .501 r
.2983 .61251 m .30101 .61229 L .30133 .60975 L F
.489 .25 .479 r
.30133 .60975 m .30357 .61174 L .30434 .60959 L F
.30133 .60975 m .30101 .61229 L .30357 .61174 L F
.85 .915 .515 r
.29769 .52186 m .29969 .51657 L .29587 .51958 L F
.955 .608 .271 r
.29714 .52158 m .29769 .52186 L .29587 .51958 L F
0 .448 .778 r
.29714 .52158 m .30075 .52272 L .29769 .52186 L F
.722 .619 .742 r
.62369 .39928 m .62769 .39947 L .62632 .39534 L F
.758 .702 .799 r
.62769 .39947 m .6287 .39462 L .62632 .39534 L F
.62769 .39947 m .63069 .39665 L .6287 .39462 L F
0 0 .323 r
.20412 .60301 m .20493 .60506 L .20503 .60224 L F
.748 .633 .733 r
.66489 .36005 m .6688 .36061 L .66753 .35745 L F
.616 .508 .707 r
.6688 .36061 m .67139 .35744 L .66753 .35745 L F
.6688 .36061 m .67117 .3601 L .67139 .35744 L F
.86 .781 .773 r
.67661 .3375 m .67984 .33837 L .67891 .33428 L F
.862 .778 .767 r
.67759 .34138 m .67984 .33837 L .67661 .3375 L F
.83 .765 .791 r
.67891 .33428 m .67984 .33837 L .68071 .33591 L F
.72 .534 .638 r
.67139 .35744 m .67379 .35444 L .67128 .35472 L F
.76 .591 .669 r
.67139 .35744 m .67517 .35786 L .67379 .35444 L F
.721 .544 .65 r
.40933 .49756 m .41305 .50061 L .41203 .49713 L F
.40933 .49756 m .40895 .50103 L .41305 .50061 L F
.556 .054 .018 r
.40862 .50143 m .41305 .50061 L .40895 .50103 L F
.40862 .50143 m .41167 .50214 L .41305 .50061 L F
.594 .533 .756 r
.41032 .4982 m .41167 .50214 L .40979 .5017 L F
.40897 .50078 m .40979 .5017 L .40862 .50143 L F
.41032 .4982 m .40979 .5017 L .40897 .50078 L F
0 .034 .565 r
.40744 .49907 m .40895 .50103 L .40673 .49865 L F
.40753 .49913 m .40776 .49943 L .40744 .49907 L F
.40776 .49943 m .40895 .50103 L .40744 .49907 L F
.749 .713 .818 r
.62834 .36025 m .6294 .36399 L .62585 .36337 L F
.73 .702 .824 r
.63242 .36072 m .6294 .36399 L .62834 .36025 L F
.702 .604 .743 r
.64818 .37309 m .65194 .37399 L .65074 .37014 L F
.688 .637 .793 r
.65194 .37399 m .65328 .36938 L .65074 .37014 L F
.65194 .37399 m .6545 .37323 L .65328 .36938 L F
0 .002 .514 r
.21114 .60182 m .21106 .60173 L .21224 .60007 L F
.21106 .60173 m .20957 .60012 L .21161 .60008 L F
.21106 .60173 m .21161 .60008 L .21224 .60007 L F
.211 .60204 m .21092 .60194 L .21114 .60182 L F
.311 0 0 r
.21438 .60299 m .21203 .60378 L .21105 .60189 L F
.157 0 .033 r
.21313 .60118 m .21291 .60127 L .21224 .60007 L F
.21291 .60127 m .211 .60204 L .21121 .6017 L F
.21291 .60127 m .21121 .6017 L .21224 .60007 L F
.391 .379 .726 r
.21116 .60152 m .21278 .6013 L .21246 .5985 L F
.309 0 0 r
.21662 .60186 m .21652 .60186 L .21313 .60118 L F
.391 .379 .726 r
.21278 .6013 m .21299 .60128 L .21293 .60127 L F
.421 .338 .658 r
.21105 .60189 m .211 .60204 L .21284 .6013 L F
.21274 .60132 m .21284 .6013 L .21291 .60127 L F
.2129 .60126 m .21291 .60127 L .21313 .60118 L F
.391 .379 .726 r
.21278 .6013 m .21291 .60127 L .21276 .60107 L F
.421 .338 .658 r
.21274 .60132 m .21291 .60127 L .2129 .60126 L F
.391 .379 .726 r
.21276 .60107 m .21315 .60121 L .21246 .5985 L F
.21291 .60127 m .21315 .60121 L .21276 .60107 L F
.421 .338 .658 r
.21105 .60189 m .21284 .6013 L .21274 .60132 L F
.309 0 0 r
.21652 .60186 m .2129 .60126 L .21313 .60118 L F
0 0 0 r
.21299 .60128 m .21312 .60128 L .21316 .60126 L F
.21249 .60134 m .21274 .60132 L .21299 .60128 L F
.309 0 0 r
.21652 .60186 m .21274 .60132 L .21299 .60128 L F
0 0 0 r
.21274 .60132 m .21312 .60128 L .21299 .60128 L F
.309 0 0 r
.21652 .60186 m .21105 .60189 L .21274 .60132 L F
.21299 .60128 m .21274 .60132 L .2129 .60126 L F
.391 .379 .726 r
.21293 .60127 m .21316 .60126 L .21315 .60121 L F
.21299 .60128 m .21316 .60126 L .21293 .60127 L F
.309 0 0 r
.21662 .60186 m .21438 .60299 L .21105 .60189 L F
.179 0 .015 r
.21274 .60132 m .21239 .60254 L .21105 .60189 L F
.21239 .60254 m .21203 .60378 L .21128 .60233 L F
.21239 .60254 m .21128 .60233 L .21105 .60189 L F
.21309 .60128 m .21254 .60257 L .21274 .60132 L F
.21254 .60257 m .21203 .60378 L .21239 .60254 L F
.21254 .60257 m .21239 .60254 L .21274 .60132 L F
0 .462 .748 r
.21153 .60218 m .21438 .60299 L .21662 .60186 L F
.765 .697 .787 r
.21153 .60218 m .21359 .60277 L .21229 .60231 L F
.21359 .60277 m .21438 .60299 L .21383 .60281 L F
.21359 .60277 m .21383 .60281 L .21229 .60231 L F
0 .462 .748 r
.21153 .60218 m .21229 .60231 L .21383 .60281 L F
.21359 .60277 m .21383 .60281 L .21438 .60299 L F
.21153 .60218 m .21383 .60281 L .21359 .60277 L F
0 0 0 r
.21259 .60134 m .21153 .60218 L .21312 .60128 L F
.21116 .60152 m .21119 .60157 L .21259 .60134 L F
.21119 .60157 m .21153 .60218 L .21259 .60134 L F
.179 0 .015 r
.21313 .60118 m .21309 .60128 L .21274 .60132 L F
0 0 0 r
.21116 .60152 m .21312 .60128 L .21249 .60134 L F
.21116 .60152 m .21085 .60235 L .21153 .60218 L F
0 .002 .514 r
.21082 .60181 m .21012 .60324 L .20957 .60012 L F
.21092 .60194 m .20957 .60012 L .21114 .60182 L F
.767 .677 .763 r
.21004 .5983 m .20749 .60176 L .21083 .60154 L F
.21086 .60064 m .21083 .60154 L .21116 .60152 L F
.21004 .5983 m .21083 .60154 L .21086 .60064 L F
0 .002 .514 r
.21092 .60194 m .21081 .60212 L .21082 .60181 L F
.21081 .60212 m .21012 .60324 L .21082 .60181 L F
.211 .60204 m .21096 .6021 L .21092 .60194 L F
.21096 .6021 m .21012 .60324 L .21092 .60194 L F
.976 .713 .466 r
.20749 .60176 m .20915 .60498 L .2074 .60411 L F
.788 .595 .64 r
.21091 .60219 m .2103 .60211 L .20915 .60498 L F
.2103 .60211 m .20791 .60257 L .20915 .60498 L F
.585 .243 .357 r
.21024 .60211 m .21087 .60171 L .20749 .60176 L F
.20894 .60305 m .21116 .60152 L .20741 .60391 L F
.788 .595 .64 r
.211 .60204 m .20749 .60176 L .21091 .60219 L F
.211 .60204 m .21144 .60492 L .2074 .60411 L F
.43 0 0 r
.21144 .60492 m .20988 .60499 L .2074 .60411 L F
.585 .243 .357 r
.2074 .60411 m .20988 .60499 L .21099 .60198 L F
.2103 .60211 m .21099 .60198 L .21116 .60152 L F
.2074 .60411 m .21076 .60203 L .2103 .60211 L F
.788 .595 .64 r
.2103 .60211 m .20749 .60176 L .20791 .60257 L F
.585 .243 .357 r
.20741 .60391 m .21024 .60211 L .20749 .60176 L F
.2074 .60411 m .20894 .60305 L .20741 .60391 L F
.788 .595 .64 r
.21076 .60203 m .2074 .60411 L .20749 .60176 L F
.211 .60204 m .2074 .60411 L .21076 .60203 L F
.585 .243 .357 r
.2074 .60411 m .21099 .60198 L .21076 .60203 L F
.21087 .60171 m .21116 .60152 L .21083 .60154 L F
.21087 .60171 m .21083 .60154 L .20749 .60176 L F
0 0 0 r
.21085 .60235 m .20988 .60499 L .21009 .60463 L F
.421 .338 .658 r
.21105 .60189 m .21144 .60492 L .211 .60204 L F
.466 .89 .884 r
.21203 .60378 m .21144 .60492 L .21105 .60189 L F
0 0 0 r
.21085 .60235 m .21009 .60463 L .21153 .60218 L F
.254 .074 .434 r
.2936 .63511 m .29569 .63177 L .2956 .6344 L F
.242 0 .216 r
.29297 .63723 m .2936 .63511 L .2956 .6344 L F
0 0 0 r
.34487 .5516 m .34288 .55506 L .34116 .5518 L F
.34487 .5516 m .34388 .55411 L .34288 .55506 L F
.34288 .55506 m .34388 .55411 L .34487 .5516 L F
.707 .904 .542 r
.347 .54856 m .34539 .55016 L .34487 .5516 L F
.683 .565 .716 r
.34487 .5516 m .34844 .55158 L .347 .54856 L F
.653 .21 .185 r
.34487 .5516 m .34709 .55404 L .34844 .55158 L F
.34709 .55404 m .34487 .5516 L .34539 .55016 L F
.34709 .55404 m .34388 .55411 L .34487 .5516 L F
.34487 .5516 m .34388 .55411 L .34709 .55404 L F
.409 .003 .155 r
.26078 .56697 m .26488 .56458 L .26152 .56557 L F
0 0 0 r
.24725 .55913 m .24533 .56114 L .24352 .56199 L F
.601 .816 .982 r
.24499 .55764 m .24725 .55913 L .24929 .55809 L F
0 0 .305 r
.33774 .54544 m .33755 .54847 L .33868 .54439 L F
.858 .967 .643 r
.73751 .34153 m .73625 .34234 L .73537 .34512 L F
.822 .915 .518 r
.73537 .34512 m .73625 .34234 L .73428 .34612 L F
.947 .953 .654 r
.42278 .51088 m .42137 .51328 L .42123 .51178 L F
0 0 0 r
.43094 .54909 m .43225 .54765 L .43365 .54607 L F
.43094 .54909 m .43165 .54991 L .43225 .54765 L F
.43094 .54909 m .43018 .5516 L .43165 .54991 L F
.998 .782 .441 r
.43537 .57324 m .43651 .5746 L .43565 .57048 L F
.674 .203 .126 r
.4355 .57643 m .43893 .57668 L .43651 .5746 L F
.917 .753 .664 r
.28908 .60524 m .29093 .60667 L .28905 .60267 L F
.809 .818 .858 r
.426 .48178 m .42218 .48174 L .42442 .4801 L F
.668 .785 .937 r
.42818 .48107 m .426 .48178 L .42442 .4801 L F
0 0 .484 r
.59029 .38861 m .5917 .39023 L .59309 .39177 L F
.545 .724 .957 r
.34229 .5233 m .34384 .52415 L .34444 .52248 L F
.626 .532 .728 r
.43471 .56863 m .43253 .57144 L .43159 .56717 L F
.559 .439 .673 r
.43471 .56863 m .43565 .57048 L .43253 .57144 L F
.516 .441 .709 r
.29589 .52435 m .29714 .52158 L .29443 .52249 L F
.29589 .52435 m .29837 .52366 L .29714 .52158 L F
.947 .735 .583 r
.23978 .54761 m .24158 .54911 L .2399 .54529 L F
.689 .649 .805 r
.2399 .54529 m .24158 .54911 L .24441 .54837 L F
.915 .707 .606 r
.24441 .54837 m .2417 .55115 L .24158 .54911 L F
0 0 .152 r
.24158 .54911 m .24241 .55053 L .24441 .54837 L F
.24158 .54911 m .2417 .55115 L .24241 .55053 L F
.92 .928 .798 r
.62462 .43379 m .62237 .43694 L .62379 .43784 L F
.958 .929 .592 r
.62235 .43904 m .62379 .43784 L .62237 .43694 L F
.62235 .43904 m .62277 .4403 L .62379 .43784 L F
.399 .149 .415 r
.4663 .57433 m .46592 .5767 L .46355 .57736 L F
.386 .131 .4 r
.46846 .57363 m .46592 .5767 L .4663 .57433 L F
.594 .628 .855 r
.61258 .36388 m .60991 .36481 L .60776 .36169 L F
.532 .582 .85 r
.61385 .36736 m .60991 .36481 L .61258 .36388 L F
.601 .918 .672 r
.37748 .66263 m .37955 .66128 L .37639 .66402 L F
.793 .895 .916 r
.37955 .66128 m .38186 .6597 L .38169 .65849 L F
.615 .952 .8 r
.38024 .66013 m .37955 .66128 L .37748 .66263 L F
.793 .895 .916 r
.37955 .66128 m .38186 .6597 L .38169 .65849 L F
.615 .952 .8 r
.38024 .66013 m .38186 .6597 L .37955 .66128 L F
.537 .568 .834 r
.38288 .66389 m .37955 .66128 L .38186 .6597 L F
.434 .544 .869 r
.63699 .4279 m .64071 .43087 L .63972 .42751 L F
.59 .932 .95 r
.61926 .39271 m .61563 .39371 L .61821 .39392 L F
.39 0 0 r
.62138 .39399 m .61926 .39271 L .61821 .39392 L F
.62138 .39399 m .62241 .39317 L .61926 .39271 L F
.856 .76 .757 r
.67891 .33428 m .68285 .33255 L .68136 .33089 L F
.67891 .33428 m .68071 .33591 L .68285 .33255 L F
.82 .809 .84 r
.68136 .33089 m .68285 .33255 L .6856 .32954 L F
.697 .425 .508 r
.36218 .58415 m .36061 .58903 L .3582 .58672 L F
0 0 .031 r
.36279 .58519 m .36218 .58415 L .3627 .58245 L F
.36279 .58519 m .36061 .58903 L .36218 .58415 L F
.535 .283 .48 r
.369 .61826 m .37147 .61818 L .36915 .61604 L F
.684 .4 .485 r
.68156 .3597 m .68207 .35756 L .67772 .35754 L F
.527 .25 .438 r
.68156 .3597 m .68395 .35918 L .68207 .35756 L F
.628 .208 .227 r
.68395 .35918 m .68466 .35798 L .68207 .35756 L F
.247 .053 .409 r
.30666 .60334 m .30819 .60502 L .30885 .60268 L F
.30666 .60334 m .30636 .6059 L .30819 .60502 L F
.745 .838 .921 r
.40802 .48902 m .4045 .48886 L .40631 .48729 L F
.633 .763 .941 r
.41045 .48814 m .40802 .48902 L .40631 .48729 L F
.945 .584 .26 r
.39119 .53188 m .39315 .53579 L .3928 .53235 L F
.376 .514 .869 r
.3831 .60362 m .38616 .60547 L .38553 .60299 L F
.669 .975 .873 r
.2354 .53408 m .23447 .53316 L .23719 .53259 L F
.2354 .53408 m .23278 .53468 L .23447 .53316 L F
.741 .666 .776 r
.64703 .36955 m .64818 .37309 L .65074 .37014 L F
.441 .099 .288 r
.30151 .55552 m .30408 .55507 L .30514 .55213 L F
.314 .126 .459 r
.30514 .55213 m .30773 .55216 L .3075 .54871 L F
.392 .053 .267 r
.30514 .55213 m .30637 .55424 L .30773 .55216 L F
.30514 .55213 m .30408 .55507 L .30637 .55424 L F
.815 .822 .856 r
.36206 .67372 m .36315 .6697 L .3604 .67256 L F
.936 .7 .558 r
.3604 .67256 m .36204 .67621 L .36206 .67372 L F
.714 .392 .432 r
.36538 .67618 m .36206 .67372 L .36204 .67621 L F
.515 .073 .137 r
.23748 .56699 m .23995 .56729 L .24193 .56523 L F
.576 .459 .683 r
.24352 .56199 m .24193 .56523 L .24497 .56394 L F
.265 0 0 r
.24193 .56523 m .24248 .5667 L .24497 .56394 L F
.24193 .56523 m .23995 .56729 L .24248 .5667 L F
.598 .39 .57 r
.34844 .55158 m .35104 .54907 L .347 .54856 L F
.34844 .55158 m .35106 .5517 L .35104 .54907 L F
.078 0 .185 r
.35371 .5455 m .35104 .54907 L .35289 .54804 L F
.225 .102 .494 r
.35104 .54907 m .35284 .55054 L .35289 .54804 L F
.35104 .54907 m .35106 .5517 L .35284 .55054 L F
.787 .684 .751 r
.33653 .55828 m .33744 .56292 L .33288 .56107 L F
0 0 .361 r
.33758 .56053 m .33744 .56292 L .33653 .55828 L F
.423 .022 .172 r
.33927 .56328 m .33683 .56422 L .33744 .56292 L F
.707 .45 .533 r
.2661 .56094 m .27013 .56116 L .27037 .55861 L F
.761 .552 .614 r
.27013 .56116 m .27297 .55873 L .27037 .55861 L F
.608 .563 .778 r
.39155 .70245 m .38971 .69846 L .38986 .70142 L F
.39155 .70245 m .392 .69774 L .38971 .69846 L F
.39155 .70245 m .39281 .70087 L .392 .69774 L F
.688 .287 .281 r
.36172 .51928 m .35817 .51794 L .35974 .51642 L F
.36172 .51928 m .35729 .51965 L .35817 .51794 L F
.297 .383 .782 r
.23626 .56333 m .23748 .56699 L .23474 .56539 L F
.663 .343 .421 r
.35925 .66399 m .36319 .66364 L .36059 .6638 L F
.476 0 0 r
.36458 .66503 m .36568 .66388 L .36319 .66364 L F
.973 .926 .661 r
.35285 .58007 m .35261 .58153 L .35149 .58366 L F
.804 .791 .84 r
.68406 .32774 m .68824 .32801 L .68703 .32583 L F
.68406 .32774 m .6856 .32954 L .68824 .32801 L F
.554 .703 .939 r
.68824 .32801 m .68987 .32457 L .68703 .32583 L F
.68824 .32801 m .69183 .3275 L .68987 .32457 L F
.467 .445 .75 r
.45063 .53791 m .44826 .53992 L .44765 .53608 L F
.49 .423 .709 r
.45063 .53791 m .44899 .54251 L .44826 .53992 L F
.647 .658 .846 r
.61342 .42801 m .6165 .43027 L .61658 .42967 L F
.796 .821 .344 r
.61539 .43414 m .61658 .42967 L .6165 .43027 L F
.697 .506 .625 r
.67531 .36057 m .67772 .35754 L .67517 .35786 L F
.727 .548 .649 r
.67531 .36057 m .67782 .3603 L .67772 .35754 L F
.684 .4 .485 r
.68156 .3597 m .67772 .35754 L .67782 .3603 L F
.806 .515 .497 r
.54824 .45032 m .54441 .45193 L .5443 .44978 L F
.54824 .45032 m .54831 .45271 L .54441 .45193 L F
.73 .474 .54 r
.54824 .45032 m .55242 .45299 L .54831 .45271 L F
.439 .037 .179 r
.46355 .57736 m .45985 .57988 L .45975 .57887 L F
.46355 .57736 m .46248 .57963 L .45985 .57988 L F
.541 .222 .376 r
.46592 .5767 m .46248 .57963 L .46355 .57736 L F
.301 .008 .289 r
.31376 .61471 m .3125 .61329 L .31412 .61222 L F
.31376 .61471 m .31161 .61547 L .3125 .61329 L F
.088 .062 .53 r
.73941 .33608 m .7397 .34002 L .73751 .34153 L F
.407 .812 .6 r
.73751 .34153 m .7397 .34002 L .73625 .34234 L F
.565 .696 .929 r
.26745 .62197 m .26271 .6201 L .26549 .61987 L F
.494 .696 .959 r
.2685 .6198 m .26745 .62197 L .26549 .61987 L F
.2685 .6198 m .2697 .62157 L .26745 .62197 L F
0 .246 .753 r
.39352 .5384 m .39472 .54019 L .39468 .54023 L F
.599 .654 .875 r
.37175 .61269 m .37237 .60896 L .37118 .60884 L F
.37175 .61269 m .37447 .61236 L .37237 .60896 L F
.552 .304 .493 r
.37175 .61269 m .37447 .61522 L .37447 .61236 L F
.983 .7 .341 r
.37447 .61236 m .37447 .61522 L .37175 .61269 L F
.164 0 0 r
.24805 .57016 m .24571 .57109 L .24686 .56998 L F
.491 .546 .841 r
.39334 .65071 m .39576 .65034 L .39404 .64671 L F
.731 .483 .553 r
.30154 .64149 m .30457 .6444 L .30227 .64502 L F
.373 .014 .221 r
.30227 .64502 m .30369 .64672 L .30125 .64711 L F
.30227 .64502 m .30457 .6444 L .30369 .64672 L F
0 0 0 r
.36848 .53387 m .36676 .53547 L .36785 .53357 L F
.315 .199 .559 r
.29204 .61159 m .29439 .6117 L .29391 .61022 L F
.29204 .61159 m .29153 .61442 L .29439 .6117 L F
.197 0 .23 r
.35376 .59338 m .35622 .59037 L .35585 .59042 L F
.499 .883 .699 r
.35786 .58901 m .35585 .59042 L .35622 .59037 L F
.594 .457 .664 r
.44172 .49449 m .43938 .49775 L .43914 .49504 L F
.809 .921 .912 r
.43101 .55446 m .43558 .55321 L .4335 .55176 L F
.773 .886 .926 r
.4335 .55176 m .43558 .55321 L .43726 .55134 L F
0 0 .18 r
.33951 .54023 m .33882 .53924 L .33991 .53762 L F
.828 .858 .869 r
.67154 .34444 m .67486 .3445 L .67346 .34281 L F
.86 .804 .794 r
.67247 .34789 m .67486 .3445 L .67154 .34444 L F
.846 .86 .853 r
.67346 .34281 m .67486 .3445 L .67759 .34138 L F
.7 .508 .625 r
.67117 .3601 m .67517 .35786 L .67139 .35744 L F
.67117 .3601 m .67531 .36057 L .67517 .35786 L F
.203 .645 .948 r
.34275 .49663 m .34491 .49701 L .34661 .49809 L F
.022 .548 .858 r
.34491 .49701 m .34892 .49827 L .34661 .49809 L F
.265 .119 .488 r
.61402 .42466 m .61342 .42801 L .61513 .42565 L F
0 0 .328 r
.6153 .42063 m .61402 .42466 L .61529 .42312 L F
.336 .418 .798 r
.61342 .42801 m .61658 .42967 L .61513 .42565 L F
.862 .633 .098 r
.6152 .42762 m .61513 .42565 L .61529 .42814 L F
.61468 .4245 m .61513 .42565 L .6152 .42762 L F
0 0 .299 r
.61529 .42312 m .61505 .42341 L .61513 .42565 L F
.61505 .42341 m .61402 .42466 L .61513 .42565 L F
.654 .467 .618 r
.67931 .37695 m .68205 .3766 L .67953 .37983 L F
.02 .437 .868 r
.38892 .51441 m .39234 .51588 L .39089 .5143 L F
.005 0 0 r
.28438 .62562 m .28662 .62551 L .28845 .62531 L F
.634 .071 0 r
.28662 .62551 m .29052 .62783 L .28845 .62531 L F
.643 .336 .437 r
.28845 .62531 m .29052 .62783 L .29111 .62568 L F
.537 .598 .862 r
.45683 .55401 m .45624 .55829 L .45501 .55452 L F
.45683 .55401 m .45862 .55758 L .45624 .55829 L F
.765 .391 0 r
.25939 .57716 m .2597 .57824 L .25894 .57623 L F
.504 .636 .912 r
.26214 .57824 m .2597 .57824 L .25939 .57716 L F
.382 .581 .919 r
.43425 .56708 m .43471 .56863 L .43159 .56717 L F
.53 .583 .853 r
.31793 .62295 m .32072 .62417 L .31945 .62195 L F
.803 .873 .899 r
.41699 .48538 m .41204 .48642 L .41567 .48431 L F
.784 .917 .928 r
.41699 .48538 m .41703 .48349 L .41945 .48452 L F
.41699 .48538 m .41567 .48431 L .41703 .48349 L F
0 0 .341 r
.4133 .55833 m .41348 .56231 L .41367 .56105 L F
.684 .368 0 r
.41348 .56231 m .41371 .56309 L .41367 .56105 L F
.41348 .56231 m .41433 .56476 L .41371 .56309 L F
.339 .04 .304 r
.35371 .5455 m .35537 .54714 L .35625 .54529 L F
.35371 .5455 m .35289 .54804 L .35537 .54714 L F
.55 .414 .649 r
.35371 .5455 m .35625 .54529 L .3568 .54313 L F
.244 0 .009 r
.22524 .54151 m .22756 .54094 L .22891 .53882 L F
0 0 0 r
.22891 .53882 m .22756 .54094 L .23042 .53799 L F
.378 .073 .315 r
.23138 .56703 m .23324 .5642 L .23193 .56476 L F
.429 .801 .994 r
.3841 .62516 m .38762 .62535 L .3859 .62439 L F
.925 .974 .742 r
.3859 .62439 m .38616 .62605 L .38376 .62779 L F
0 .105 .66 r
.3876 .6261 m .38616 .62605 L .3859 .62439 L F
0 0 0 r
.38473 .62873 m .38616 .62605 L .3876 .6261 L F
.447 .517 .837 r
.34483 .70844 m .34609 .71228 L .34816 .71033 L F
.523 .512 .785 r
.34717 .7144 m .34816 .71033 L .34609 .71228 L F
.075 0 .439 r
.23777 .56156 m .23949 .56031 L .23941 .55788 L F
.396 .589 .92 r
.23777 .56156 m .24026 .56218 L .23949 .56031 L F
.976 .723 .486 r
.23623 .56072 m .23626 .56333 L .23777 .56156 L F
.289 .162 .527 r
.22744 .58156 m .22808 .58489 L .22638 .58627 L F
.44 .259 .538 r
.23102 .57883 m .2295 .58289 L .22744 .58156 L F
.595 .36 .53 r
.22824 .5841 m .22744 .58156 L .2295 .58289 L F
.22824 .5841 m .22808 .58489 L .22744 .58156 L F
.761 .552 .614 r
.27013 .56116 m .2739 .56222 L .27297 .55873 L F
.446 .359 .664 r
.27297 .55873 m .27524 .56127 L .27581 .55788 L F
.27297 .55873 m .2739 .56222 L .27524 .56127 L F
.615 .895 .988 r
.72142 .35425 m .71707 .35493 L .71973 .35429 L F
.729 .245 .094 r
.7226 .3559 m .72142 .35425 L .71973 .35429 L F
.7226 .3559 m .72142 .35425 L .71973 .35429 L F
.301 .009 .29 r
.57892 .42315 m .57552 .42341 L .57533 .42627 L F
.136 .039 .471 r
.22808 .58489 m .22654 .58701 L .22638 .58627 L F
.22808 .58489 m .22795 .58707 L .22654 .58701 L F
.124 .21 .682 r
.22795 .58707 m .22864 .58904 L .22654 .58701 L F
.576 .381 .58 r
.65059 .38365 m .65343 .38287 L .6532 .38001 L F
.632 .54 .733 r
.6532 .38001 m .65595 .37959 L .6556 .37695 L F
.601 .4 .581 r
.65343 .38287 m .65595 .37959 L .6532 .38001 L F
.671 .721 .887 r
.2924 .615 m .29597 .61598 L .29451 .61553 L F
.58 .775 .972 r
.27476 .52514 m .27647 .52669 L .27882 .52595 L F
.678 .278 .281 r
.27647 .52669 m .27902 .5289 L .27882 .52595 L F
.27647 .52669 m .27523 .52875 L .27902 .5289 L F
0 .221 .74 r
.29597 .61598 m .29621 .6146 L .29451 .61553 L F
.29597 .61598 m .29835 .61816 L .29621 .6146 L F
.414 .307 .624 r
.2963 .6188 m .29835 .61816 L .29597 .61598 L F
.884 .452 .13 r
.3824 .51987 m .38315 .52172 L .38419 .52101 L F
.773 .271 .005 r
.38419 .52101 m .38315 .52172 L .38569 .5226 L F
0 .154 .695 r
.61024 .43148 m .60737 .42755 L .60939 .43133 L F
.845 .387 0 r
.61115 .43328 m .61024 .43148 L .60939 .43133 L F
.58 .612 .848 r
.28547 .54052 m .28312 .54145 L .28248 .53928 L F
.784 .678 .747 r
.38706 .5776 m .38423 .58077 L .38428 .57781 L F
.78 .817 .881 r
.25293 .61466 m .24859 .61575 L .2511 .61503 L F
.328 .137 .462 r
.69053 .36968 m .69047 .37204 L .68748 .37284 L F
.427 .261 .551 r
.69047 .37204 m .68808 .37548 L .68748 .37284 L F
.513 .472 .749 r
.46232 .56086 m .46088 .56564 L .4599 .56138 L F
.46232 .56086 m .46325 .56583 L .46088 .56564 L F
.494 .528 .821 r
.46325 .56583 m .46445 .5665 L .46088 .56564 L F
.411 .233 .527 r
.31565 .58393 m .31794 .58331 L .3179 .58068 L F
.32 .16 .502 r
.31543 .58639 m .31794 .58331 L .31565 .58393 L F
0 .501 .73 r
.32115 .54893 m .32001 .54869 L .31772 .54833 L F
.844 .999 .799 r
.32145 .54673 m .32115 .54893 L .32379 .54595 L F
.822 .996 .853 r
.32145 .54673 m .32001 .54869 L .32115 .54893 L F
.558 .909 .968 r
.37092 .54111 m .36948 .54229 L .37227 .54124 L F
.643 .658 .85 r
.36948 .54229 m .3744 .54229 L .37227 .54124 L F
.435 .072 .249 r
.36929 .54526 m .3744 .54229 L .36948 .54229 L F
.544 .453 .703 r
.37092 .54111 m .36929 .54526 L .36948 .54229 L F
.718 .603 .727 r
.66738 .35441 m .67128 .35472 L .66995 .35119 L F
.678 .501 .639 r
.66753 .35745 m .67128 .35472 L .66738 .35441 L F
.66753 .35745 m .67139 .35744 L .67128 .35472 L F
.154 .13 .576 r
.43064 .53823 m .42936 .54251 L .42808 .53896 L F
.036 0 .005 r
.43047 .54354 m .42936 .54251 L .4309 .54218 L F
.43047 .54354 m .42835 .54492 L .42936 .54251 L F
.545 .308 .507 r
.31658 .52265 m .31791 .52395 L .31996 .52077 L F
0 0 0 r
.33574 .5242 m .33454 .52527 L .33772 .52319 L F
.513 .859 .993 r
.38561 .67948 m .3831 .68021 L .38147 .6795 L F
.9 .578 .088 r
.38023 .5675 m .38134 .57037 L .38156 .56991 L F
.709 .825 .937 r
.3822 .56599 m .38156 .56991 L .38023 .5675 L F
.9 .578 .088 r
.38156 .56991 m .38134 .57037 L .38023 .5675 L F
.354 .165 .481 r
.32828 .61284 m .33068 .61203 L .33085 .60919 L F
.165 .159 .605 r
.32828 .61284 m .33024 .61465 L .33068 .61203 L F
.32828 .61284 m .32892 .61563 L .33024 .61465 L F
.193 .722 .74 r
.34317 .65743 m .34476 .65716 L .34144 .65784 L F
.722 .583 .698 r
.34543 .65655 m .34476 .65716 L .34317 .65743 L F
.34543 .65655 m .34671 .65701 L .34476 .65716 L F
.586 .4 .596 r
.35581 .69256 m .35868 .69241 L .35862 .68927 L F
.715 .314 .288 r
.35862 .68927 m .35671 .69112 L .35817 .68758 L F
.445 .29 .576 r
.35862 .68927 m .35868 .69241 L .36056 .69166 L F
.715 .314 .288 r
.35862 .68927 m .36056 .69166 L .35671 .69112 L F
0 .112 .629 r
.63972 .42751 m .64175 .42847 L .64339 .42697 L F
.63972 .42751 m .64071 .43087 L .64175 .42847 L F
.392 0 0 r
.30708 .55754 m .30552 .55858 L .30299 .55855 L F
0 0 0 r
.3094 .55807 m .30552 .55858 L .30708 .55754 L F
.872 .541 .031 r
.40367 .57893 m .40401 .57766 L .40329 .576 L F
.40367 .57893 m .40471 .58034 L .40401 .57766 L F
.847 .813 .816 r
.66647 .32697 m .66803 .32853 L .66488 .32849 L F
.845 .831 .833 r
.66925 .32371 m .66803 .32853 L .66647 .32697 L F
.66925 .32371 m .67073 .32537 L .66803 .32853 L F
.645 .924 .645 r
.33372 .6064 m .33085 .60919 L .33298 .60898 L F
.843 .906 .497 r
.33544 .60233 m .33372 .6064 L .33491 .60497 L F
.024 0 .234 r
.33372 .6064 m .33503 .6079 L .33491 .60497 L F
.33372 .6064 m .33298 .60898 L .33503 .6079 L F
.616 .449 .633 r
.35017 .56149 m .35303 .55822 L .34935 .55832 L F
.35017 .56149 m .3535 .56341 L .35303 .55822 L F
.896 .675 .595 r
.62266 .40171 m .62369 .39928 L .6203 .39794 L F
.708 .529 .645 r
.56042 .45666 m .56025 .45911 L .55795 .45999 L F
.318 .002 .261 r
.34561 .57924 m .34337 .57991 L .34394 .57798 L F
.576 .834 .473 r
.33456 .61343 m .33378 .61447 L .33517 .61281 L F
0 0 0 r
.58142 .40867 m .58244 .40762 L .58444 .40696 L F
.58444 .40696 m .58244 .40762 L .58191 .40823 L F
.653 .815 .961 r
.58191 .40823 m .58142 .40867 L .58444 .40696 L F
0 0 0 r
.58444 .40696 m .58191 .40823 L .58157 .40862 L F
.653 .815 .961 r
.58343 .40686 m .58191 .40823 L .58444 .40696 L F
0 0 0 r
.58191 .40823 m .58244 .40762 L .58142 .40867 L F
.653 .815 .961 r
.58022 .40652 m .58142 .40867 L .58343 .40686 L F
0 0 0 r
.58157 .40862 m .58191 .40823 L .58142 .40867 L F
.32204 .65091 m .32188 .65096 L .31924 .65276 L F
.505 .358 .615 r
.32706 .59321 m .32739 .59672 L .32473 .59727 L F
.336 .009 .255 r
.32739 .59672 m .32441 .59928 L .32473 .59727 L F
.892 .486 .237 r
.32021 .54192 m .32193 .54519 L .32379 .54595 L F
.844 .999 .799 r
.32145 .54673 m .32379 .54595 L .32193 .54519 L F
.754 .646 .742 r
.27565 .56775 m .27169 .56793 L .27457 .56533 L F
.503 0 0 r
.27565 .56775 m .27353 .56921 L .27169 .56793 L F
.372 0 0 r
.27842 .56812 m .27353 .56921 L .27565 .56775 L F
.551 .3 .489 r
.44324 .59042 m .44567 .59258 L .44303 .59284 L F
.591 .291 .428 r
.44599 .59036 m .44567 .59258 L .44324 .59042 L F
0 0 0 r
.43365 .54607 m .43392 .54653 L .43445 .54414 L F
.43365 .54607 m .43225 .54765 L .43392 .54653 L F
.079 0 0 r
.31772 .54833 m .31233 .55034 L .31408 .54892 L F
.78 .762 .837 r
.66869 .34732 m .67247 .34789 L .67154 .34444 L F
.807 .711 .759 r
.66995 .35119 m .67247 .34789 L .66869 .34732 L F
.678 .841 .42 r
.3408 .60661 m .34101 .60674 L .341 .60464 L F
.3408 .60661 m .34001 .60837 L .34101 .60674 L F
0 0 0 r
.37287 .60319 m .36918 .60576 L .37275 .60599 L F
.983 .7 .341 r
.37447 .61236 m .37565 .61595 L .37447 .61522 L F
.37447 .61522 m .37565 .61595 L .37447 .61236 L F
.571 .323 .502 r
.58676 .46165 m .58408 .45973 L .58657 .45899 L F
.58676 .46165 m .58393 .46217 L .58408 .45973 L F
.462 .726 .983 r
.35671 .69112 m .35581 .69256 L .35429 .69107 L F
.554 .272 .442 r
.35808 .69472 m .35868 .69241 L .35581 .69256 L F
.093 .231 .716 r
.35808 .69472 m .35581 .69256 L .35671 .69112 L F
.991 .746 .453 r
.40186 .5633 m .4033 .56427 L .40335 .56169 L F
.866 .531 .019 r
.40191 .55807 m .40261 .56074 L .40335 .56169 L F
.986 .877 .528 r
.40261 .56074 m .40186 .5633 L .40335 .56169 L F
0 0 .35 r
.34788 .54457 m .34838 .5476 L .347 .54856 L F
0 0 0 r
.34746 .54883 m .347 .54856 L .34838 .5476 L F
.34746 .54883 m .34539 .55016 L .347 .54856 L F
.99 .86 .505 r
.6394 .4323 m .64071 .43087 L .6401 .43279 L F
.744 .909 .533 r
.64175 .42847 m .64071 .43087 L .6394 .4323 L F
.391 .33 .67 r
.2924 .615 m .29439 .6117 L .29153 .61442 L F
.678 .343 .4 r
.57476 .46286 m .57746 .46535 L .57487 .46485 L F
.649 .353 .457 r
.57747 .46334 m .57746 .46535 L .57476 .46286 L F
.013 .568 .821 r
.282 .5545 m .2864 .55524 L .28598 .55535 L F
.868 .915 .859 r
.3859 .62439 m .38762 .62535 L .3902 .62215 L F
.195 .027 .413 r
.69228 .36846 m .69063 .36735 L .69245 .3661 L F
.69228 .36846 m .69053 .36968 L .69063 .36735 L F
.002 0 0 r
.34709 .55404 m .35106 .5517 L .34844 .55158 L F
0 0 0 r
.35303 .55822 m .35478 .557 L .35538 .55495 L F
.407 .294 .613 r
.35303 .55822 m .35576 .5603 L .35478 .557 L F
.35303 .55822 m .3535 .56341 L .35576 .5603 L F
.518 .598 .873 r
.23394 .59902 m .23562 .60246 L .23326 .60294 L F
0 0 .485 r
.38169 .65849 m .38186 .6597 L .38246 .65898 L F
.425 .862 .767 r
.38246 .65898 m .38186 .6597 L .38024 .66013 L F
.658 .451 .592 r
.35293 .54162 m .3494 .5415 L .35167 .5396 L F
.35293 .54162 m .34792 .54393 L .3494 .5415 L F
.254 0 .148 r
.37748 .60974 m .37662 .61181 L .37447 .61236 L F
.39 .353 .697 r
.37972 .60872 m .37748 .60974 L .37695 .60625 L F
.454 .199 .438 r
.37972 .60872 m .37662 .61181 L .37748 .60974 L F
.997 .857 .569 r
.43101 .55446 m .43006 .5571 L .43159 .55812 L F
0 0 .396 r
.43006 .5571 m .43087 .56099 L .43159 .55812 L F
.405 .15 .411 r
.38553 .60299 m .38831 .59969 L .38571 .6001 L F
.17 0 0 r
.33898 .57629 m .34247 .57418 L .34011 .57489 L F
.687 .865 .966 r
.29124 .51368 m .29047 .51633 L .28874 .51546 L F
.29124 .51368 m .29341 .51517 L .29047 .51633 L F
.632 .192 0 r
.60642 .42629 m .60737 .42755 L .60512 .42432 L F
.856 .413 .006 r
.60673 .42832 m .60737 .42755 L .60642 .42629 L F
.60673 .42832 m .60939 .43133 L .60737 .42755 L F
.597 .373 .548 r
.30456 .62527 m .30401 .62836 L .30136 .62865 L F
.544 .325 .533 r
.30567 .62775 m .30456 .62527 L .30684 .62441 L F
.30567 .62775 m .30401 .62836 L .30456 .62527 L F
.911 .976 .694 r
.63902 .43499 m .6394 .4323 L .6401 .43279 L F
.63902 .43499 m .63743 .4358 L .6394 .4323 L F
.833 .768 .789 r
.60391 .38416 m .60186 .38641 L .60417 .38331 L F
0 0 0 r
.70424 .33047 m .70311 .33242 L .70496 .32887 L F
.684 .667 .828 r
.61524 .36293 m .61385 .36736 L .61258 .36388 L F
.61524 .36293 m .61655 .36694 L .61385 .36736 L F
.658 .475 .625 r
.61385 .36736 m .61655 .36694 L .61397 .37086 L F
.684 .444 .553 r
.28557 .53613 m .28819 .53873 L .28821 .536 L F
.602 .448 .646 r
.28819 .53873 m .28711 .53986 L .28557 .53613 L F
.684 .444 .553 r
.28557 .53613 m .28446 .53902 L .28819 .53873 L F
.602 .448 .646 r
.28819 .53873 m .28557 .53613 L .28821 .536 L F
0 0 0 r
.35548 .66899 m .35656 .66665 L .35391 .6697 L F
.621 .357 .497 r
.35279 .67055 m .35548 .66899 L .35391 .6697 L F
.188 .545 .929 r
.36325 .59883 m .36451 .60042 L .36241 .59981 L F
.808 .561 .565 r
.36518 .60312 m .36241 .59981 L .36451 .60042 L F
.188 .545 .929 r
.36325 .59883 m .36241 .59981 L .3623 .60058 L F
.658 .104 0 r
.37514 .60622 m .37972 .60872 L .37695 .60625 L F
.37514 .60622 m .37812 .60884 L .37972 .60872 L F
0 .221 .736 r
.3769 .60608 m .37812 .60884 L .37514 .60622 L F
.37666 .60652 m .37514 .60622 L .37521 .6091 L F
.3769 .60608 m .37514 .60622 L .37666 .60652 L F
.123 0 0 r
.37514 .60622 m .37695 .60625 L .37449 .6061 L F
.37514 .60622 m .37449 .6061 L .37275 .60599 L F
.724 .515 0 r
.41587 .57781 m .41617 .58025 L .41565 .57642 L F
.439 .272 .556 r
.3179 .58068 m .32013 .57728 L .3175 .5778 L F
.582 .131 .146 r
.24571 .57109 m .24116 .57248 L .24303 .57118 L F
.329 .126 .445 r
.32392 .52221 m .32184 .52319 L .32293 .52098 L F
.32392 .52221 m .32293 .52098 L .32064 .51945 L F
.819 .701 .734 r
.6287 .39462 m .63069 .39665 L .63118 .39447 L F
.974 .915 .586 r
.69765 .33629 m .69809 .33885 L .69714 .34105 L F
.859 .413 .132 r
.69458 .32718 m .69649 .32783 L .69546 .32554 L F
.921 .58 .378 r
.43247 .54169 m .4309 .54218 L .43148 .54045 L F
.674 .196 .108 r
.43247 .54169 m .43047 .54354 L .4309 .54218 L F
.43247 .54169 m .43445 .54414 L .43047 .54354 L F
.867 .527 .406 r
.232 .61211 m .23438 .6139 L .22981 .612 L F
.281 .712 .967 r
.23629 .6142 m .23229 .61327 L .23438 .6139 L F
0 .249 .757 r
.2358 .61575 m .23629 .6142 L .23438 .6139 L F
.844 .542 .006 r
.33166 .63201 m .33216 .63207 L .33128 .63082 L F
.33166 .63201 m .33281 .63477 L .33216 .63207 L F
.113 0 .336 r
.31321 .5927 m .31585 .5895 L .3133 .59075 L F
.747 .67 .776 r
.65328 .36938 m .6545 .37323 L .65716 .36997 L F
.655 .532 .702 r
.6545 .37323 m .65836 .37322 L .65716 .36997 L F
.605 .434 .624 r
.6556 .37695 m .65836 .37322 L .6545 .37323 L F
.895 .915 .828 r
.39274 .6119 m .39002 .61183 L .39193 .6086 L F
.39274 .6119 m .39149 .61273 L .39002 .61183 L F
.777 .834 .896 r
.39444 .60973 m .39274 .6119 L .39193 .6086 L F
.82 .658 .682 r
.55242 .45299 m .55411 .45641 L .55192 .45575 L F
.779 .528 .556 r
.55411 .45641 m .55013 .4587 L .55192 .45575 L F
.55411 .45641 m .55395 .45908 L .55013 .4587 L F
.99 .793 .406 r
.40448 .58581 m .40569 .58405 L .40447 .58288 L F
.40448 .58581 m .40543 .58682 L .40569 .58405 L F
.521 .275 .483 r
.44889 .58725 m .44878 .58991 L .44599 .59036 L F
.452 .22 .47 r
.45136 .58924 m .44889 .58725 L .45159 .58639 L F
.45136 .58924 m .44878 .58991 L .44889 .58725 L F
.773 .541 0 r
.40222 .56764 m .40254 .56993 L .40295 .57146 L F
.812 .494 0 r
.40254 .56993 m .40358 .57274 L .40295 .57146 L F
.974 .866 .668 r
.6937 .31721 m .69581 .31624 L .6945 .31479 L F
.6937 .31721 m .69477 .31841 L .69581 .31624 L F
.709 .98 .906 r
.64101 .40478 m .64192 .40542 L .64323 .40332 L F
.588 .888 .991 r
.62072 .38426 m .6236 .38333 L .62216 .38243 L F
.467 .257 .51 r
.36149 .53877 m .36401 .53566 L .36149 .53617 L F
.774 .677 .757 r
.34288 .55506 m .33871 .55529 L .34116 .5518 L F
.328 0 .238 r
.34101 .55497 m .33871 .55529 L .34288 .55506 L F
.867 .76 .742 r
.34388 .55411 m .34101 .55497 L .34288 .55506 L F
.028 .078 .579 r
.34288 .55506 m .34448 .55725 L .34388 .55411 L F
.776 .695 .774 r
.66349 .3538 m .66738 .35441 L .66611 .35059 L F
.788 .66 .722 r
.66349 .3538 m .66498 .35763 L .66738 .35441 L F
.748 .601 .693 r
.66498 .35763 m .66753 .35745 L .66738 .35441 L F
.777 .695 .773 r
.66738 .35441 m .66995 .35119 L .66611 .35059 L F
.589 .551 .779 r
.44691 .5198 m .44455 .52059 L .44335 .51709 L F
.407 .271 .582 r
.44691 .5198 m .44494 .52328 L .44455 .52059 L F
.534 .914 .94 r
.27567 .51883 m .27108 .51999 L .27309 .51836 L F
.411 .775 .995 r
.27654 .5175 m .27567 .51883 L .27309 .51836 L F
.27654 .5175 m .27741 .51863 L .27567 .51883 L F
.827 .585 .573 r
.22102 .59916 m .22513 .59655 L .22352 .59612 L F
.22102 .59916 m .22558 .59993 L .22513 .59655 L F
.68 .211 .133 r
.2271 .5986 m .22513 .59655 L .22558 .59993 L F
.96 .946 .68 r
.61382 .44211 m .61431 .44379 L .61539 .44099 L F
0 0 0 r
.61431 .44417 m .61431 .44379 L .61382 .44211 L F
.61431 .44417 m .6138 .44626 L .61431 .44379 L F
0 0 .368 r
.20717 .59008 m .20651 .59454 L .20807 .59221 L F
.283 .529 .911 r
.2083 .59617 m .20807 .59221 L .20651 .59454 L F
.743 .61 .71 r
.62582 .37974 m .62983 .38004 L .62867 .37645 L F
.665 .566 .734 r
.62867 .37645 m .62983 .38004 L .63266 .37682 L F
.243 0 .029 r
.68395 .35918 m .6875 .35718 L .68466 .35798 L F
.774 .563 .613 r
.29332 .56211 m .28592 .56077 L .28853 .56037 L F
.29332 .56211 m .28602 .56372 L .28592 .56077 L F
.43 .69 .973 r
.2911 .56504 m .29372 .56481 L .29308 .56421 L F
.742 .972 .712 r
.2941 .56183 m .2911 .56504 L .29173 .5637 L F
.03 0 0 r
.29252 .56306 m .29123 .56385 L .29332 .56211 L F
.29173 .5637 m .29123 .56385 L .29252 .56306 L F
.742 .972 .712 r
.29252 .56306 m .29173 .5637 L .29197 .5632 L F
.03 0 0 r
.29205 .56361 m .29173 .5637 L .29252 .56306 L F
.29205 .56361 m .29252 .56306 L .29197 .5632 L F
.29252 .56306 m .29332 .56211 L .29197 .5632 L F
.742 .972 .712 r
.29371 .56208 m .29252 .56306 L .29197 .5632 L F
.2941 .56183 m .29173 .5637 L .29371 .56208 L F
.43 .69 .973 r
.29163 .56393 m .29215 .56403 L .29205 .56361 L F
.29173 .5637 m .29205 .56361 L .29197 .5632 L F
.29163 .56393 m .29205 .56361 L .29173 .5637 L F
.03 0 0 r
.2912 .56462 m .28838 .56621 L .29123 .56385 L F
.2912 .56462 m .29123 .56385 L .29205 .56361 L F
.2912 .56462 m .29205 .56361 L .29197 .5632 L F
.43 .69 .973 r
.29215 .56403 m .29308 .56421 L .29197 .5632 L F
.2911 .56504 m .29308 .56421 L .29163 .56393 L F
.509 .268 .484 r
.28838 .56621 m .28602 .56372 L .2882 .56324 L F
.29123 .56385 m .2882 .56324 L .29332 .56211 L F
.28838 .56621 m .2882 .56324 L .29123 .56385 L F
.995 .761 .419 r
.29147 .55983 m .29332 .56211 L .28853 .56037 L F
.29147 .55983 m .29197 .5632 L .29332 .56211 L F
.643 .103 0 r
.39352 .5384 m .39787 .54189 L .39472 .54019 L F
.957 .691 .489 r
.31931 .52922 m .31927 .53183 L .32132 .53287 L F
.847 .872 .86 r
.32132 .53287 m .32167 .52887 L .31931 .52922 L F
.957 .691 .489 r
.31931 .52922 m .31927 .53183 L .32132 .53287 L F
.847 .872 .86 r
.32132 .53287 m .31927 .53183 L .32167 .52887 L F
.799 .351 .18 r
.31926 .53398 m .32132 .53287 L .31927 .53183 L F
.31926 .53398 m .3229 .53533 L .32132 .53287 L F
.455 .209 .451 r
.35983 .66698 m .35925 .66399 L .35656 .66665 L F
.624 .318 .431 r
.35983 .66698 m .36212 .66606 L .35925 .66399 L F
0 0 .229 r
.40151 .679 m .40143 .68142 L .40045 .68282 L F
0 0 .188 r
.40143 .68142 m .40051 .68596 L .40045 .68282 L F
.40143 .68142 m .40135 .6843 L .40051 .68596 L F
.943 .663 .48 r
.40143 .68142 m .39932 .68328 L .40135 .6843 L F
.40143 .68142 m .40135 .6843 L .40135 .6843 L F
0 0 .229 r
.40155 .67884 m .40143 .68142 L .40151 .679 L F
.119 0 .426 r
.29242 .63982 m .29036 .63814 L .29297 .63723 L F
.29242 .63982 m .29018 .64132 L .29036 .63814 L F
0 0 0 r
.30201 .51564 m .30271 .51491 L .30575 .51314 L F
.119 .665 .822 r
.38912 .58745 m .39184 .58757 L .39151 .5875 L F
.815 .854 .878 r
.64942 .34537 m .64489 .34693 L .64806 .34382 L F
.804 .825 .868 r
.65075 .34098 m .64942 .34537 L .64806 .34382 L F
.65075 .34098 m .65127 .34399 L .64942 .34537 L F
.357 .789 .969 r
.35746 .71553 m .35803 .71459 L .35483 .71529 L F
.48 .436 .731 r
.44809 .52535 m .44558 .52677 L .44494 .52328 L F
.45 .343 .641 r
.44809 .52535 m .44595 .52963 L .44558 .52677 L F
.812 .6 .615 r
.36739 .57771 m .36313 .57974 L .36624 .57897 L F
.36739 .57771 m .36725 .58086 L .36313 .57974 L F
.843 .831 .835 r
.67335 .32225 m .67073 .32537 L .66925 .32371 L F
.971 .692 .444 r
.38821 .64448 m .38927 .64741 L .38785 .64808 L F
.541 .333 .547 r
.38927 .64741 m .38892 .65058 L .38785 .64808 L F
.38927 .64741 m .39107 .65149 L .38892 .65058 L F
.581 .203 .29 r
.5967 .45572 m .59565 .45816 L .59306 .45638 L F
.557 .174 .271 r
.59949 .45594 m .59565 .45816 L .5967 .45572 L F
.778 .687 .764 r
.35548 .66899 m .35983 .66698 L .35656 .66665 L F
.689 .649 .805 r
.2399 .54529 m .24441 .54837 L .24263 .54792 L F
.645 .566 .751 r
.24368 .55385 m .2417 .55115 L .24372 .55196 L F
.24368 .55385 m .24103 .55435 L .2417 .55115 L F
.538 .867 .994 r
.2417 .55248 m .24163 .55289 L .24241 .55053 L F
.24103 .55435 m .24128 .55375 L .2417 .55248 L F
.24128 .55375 m .24163 .55289 L .2417 .55248 L F
.915 .707 .606 r
.24441 .54837 m .24372 .55196 L .2421 .5513 L F
.24238 .55045 m .2421 .5513 L .2417 .55115 L F
.24441 .54837 m .2421 .5513 L .24238 .55045 L F
.894 .867 .804 r
.24426 .54403 m .24441 .54837 L .24657 .54528 L F
.24426 .54403 m .24263 .54792 L .24441 .54837 L F
.313 .13 .466 r
.24638 .55034 m .24372 .55196 L .24441 .54837 L F
.58 .117 .119 r
.24441 .54837 m .24241 .55053 L .24638 .55034 L F
.926 .603 .41 r
.24263 .54792 m .24241 .55053 L .24441 .54837 L F
.855 .736 .731 r
.62877 .39217 m .63123 .38917 L .62975 .3898 L F
.336 .783 .625 r
.73029 .34826 m .7321 .34729 L .73428 .34612 L F
.82 .809 .84 r
.68136 .33089 m .6856 .32954 L .68406 .32774 L F
.631 .466 .641 r
.67702 .38553 m .67859 .38884 L .67446 .38922 L F
.617 .449 .631 r
.67982 .38231 m .67702 .38553 L .67701 .38303 L F
.67982 .38231 m .68145 .38529 L .67702 .38553 L F
.694 .493 .612 r
.68104 .38859 m .67702 .38553 L .68145 .38529 L F
.68104 .38859 m .67859 .38884 L .67702 .38553 L F
.552 .588 .844 r
.31405 .66662 m .31778 .67067 L .3155 .66732 L F
.575 .811 .988 r
.31778 .67067 m .31823 .66844 L .3155 .66732 L F
.31778 .67067 m .32021 .6699 L .31823 .66844 L F
0 0 .005 r
.35677 .53521 m .35492 .53891 L .35471 .53594 L F
.876 .893 .842 r
.39442 .68131 m .39685 .68022 L .39541 .68112 L F
.26 .133 .51 r
.39685 .68022 m .39653 .68334 L .39832 .6815 L F
.196 0 0 r
.39716 .68101 m .39424 .68186 L .39685 .68022 L F
.876 .893 .842 r
.39442 .68131 m .39541 .68112 L .39424 .68186 L F
.785 .711 .782 r
.39476 .67911 m .39424 .68186 L .39716 .68101 L F
.471 .28 .54 r
.39245 .67797 m .39472 .68008 L .39233 .67806 L F
.196 0 0 r
.39716 .68101 m .39685 .68022 L .39832 .6815 L F
.721 .768 .89 r
.39518 .67744 m .39716 .68101 L .39905 .67786 L F
.39518 .67744 m .39716 .68101 L .39518 .67744 L F
.39451 .67791 m .39716 .68101 L .39518 .67744 L F
.785 .711 .782 r
.39476 .67911 m .39694 .68084 L .3945 .67791 L F
.39694 .68084 m .397 .68083 L .39476 .67821 L F
.471 .28 .54 r
.39519 .67743 m .39453 .6779 L .39245 .67797 L F
.39453 .6779 m .39451 .67791 L .39425 .67792 L F
.39453 .6779 m .39425 .67792 L .39245 .67797 L F
.45 .663 .953 r
.39233 .67806 m .39476 .67911 L .39425 .67792 L F
.39233 .67806 m .39425 .67792 L .39399 .67731 L F
.785 .711 .782 r
.39475 .67822 m .39476 .67821 L .39399 .67731 L F
.39694 .68084 m .39476 .67821 L .39475 .67822 L F
.775 .494 .51 r
.39511 .6766 m .39952 .675 L .3968 .67553 L F
.777 .906 .931 r
.39552 .67553 m .39233 .67806 L .3968 .67553 L F
.471 .28 .54 r
.39502 .67665 m .39507 .67745 L .39254 .67795 L F
.45 .663 .953 r
.39233 .67806 m .39399 .67731 L .39511 .6766 L F
0 0 .175 r
.39608 .67579 m .39579 .67632 L .39552 .67553 L F
.775 .494 .51 r
.3951 .67684 m .39905 .67786 L .39952 .675 L F
.39518 .67744 m .39905 .67786 L .3951 .67684 L F
0 0 .175 r
.39579 .67632 m .39519 .67743 L .39536 .67647 L F
.45 .663 .953 r
.39482 .67665 m .39527 .6765 L .3968 .67553 L F
0 0 .175 r
.39579 .67632 m .39536 .67647 L .39552 .67553 L F
.45 .663 .953 r
.39233 .67806 m .39511 .6766 L .39527 .6765 L F
.39233 .67806 m .39527 .6765 L .39482 .67665 L F
.471 .28 .54 r
.39498 .67596 m .39502 .67665 L .39245 .67797 L F
.39502 .67665 m .39254 .67795 L .39245 .67797 L F
.39514 .67582 m .3951 .67684 L .39498 .67596 L F
.3951 .67684 m .39507 .67745 L .39498 .67596 L F
.775 .494 .51 r
.39399 .67731 m .39518 .67744 L .3951 .67684 L F
.39399 .67731 m .3951 .67684 L .39511 .6766 L F
.3951 .67684 m .39952 .675 L .39511 .6766 L F
.471 .28 .54 r
.39552 .67553 m .39519 .67743 L .39507 .67745 L F
.39552 .67553 m .39507 .67745 L .39514 .67582 L F
0 0 .175 r
.39667 .67607 m .39631 .67681 L .39519 .67743 L F
.39631 .67681 m .39472 .68008 L .3951 .6779 L F
.39631 .67681 m .3951 .6779 L .39519 .67743 L F
.39667 .67607 m .39519 .67743 L .39608 .67579 L F
.721 .768 .89 r
.39518 .67744 m .39518 .67744 L .39518 .67744 L F
.39399 .67731 m .39451 .67791 L .39518 .67744 L F
.471 .28 .54 r
.39519 .67743 m .3951 .6779 L .39451 .67791 L F
.785 .711 .782 r
.39476 .67911 m .3945 .67791 L .39425 .67792 L F
.471 .28 .54 r
.3951 .6779 m .39472 .68008 L .39245 .67797 L F
.785 .711 .782 r
.39425 .67792 m .3945 .67791 L .39399 .67731 L F
.39694 .68084 m .39716 .68101 L .397 .68083 L F
.876 .893 .842 r
.39179 .68248 m .39442 .68131 L .39424 .68186 L F
.663 .719 .891 r
.39917 .69292 m .39515 .69194 L .39656 .69565 L F
.39917 .69292 m .39775 .69089 L .39515 .69194 L F
.93 .766 .657 r
.39753 .68889 m .39775 .69089 L .39917 .69292 L F
.405 .15 .411 r
.32204 .65091 m .32277 .64795 L .32507 .6471 L F
.724 .247 0 r
.70643 .30409 m .70629 .30307 L .70562 .3013 L F
.70643 .30409 m .70777 .30536 L .70629 .30307 L F
.71 .924 .589 r
.37301 .67371 m .37085 .67625 L .37357 .67268 L F
.517 .311 .54 r
.27429 .53269 m .2742 .53598 L .27151 .53643 L F
.39 .186 .479 r
.27676 .53214 m .2742 .53598 L .27429 .53269 L F
.301 .373 .77 r
.34954 .51079 m .35193 .51246 L .3512 .50912 L F
.518 .349 .592 r
.34954 .51079 m .34841 .51462 L .35193 .51246 L F
0 .266 .77 r
.60226 .40207 m .60542 .40531 L .6044 .40383 L F
0 .214 .654 r
.60542 .40531 m .6067 .40592 L .6044 .40383 L F
.60542 .40531 m .60829 .40711 L .6067 .40592 L F
.501 .552 .84 r
.72054 .33324 m .71948 .33595 L .71842 .3333 L F
.323 .126 .452 r
.70785 .31832 m .70609 .3192 L .70802 .31593 L F
.70785 .31832 m .70609 .3192 L .70802 .31593 L F
0 0 .246 r
.70764 .31292 m .70802 .31593 L .70805 .31409 L F
0 0 .127 r
.70794 .31699 m .70805 .31409 L .70802 .31593 L F
.70785 .31832 m .70791 .31693 L .70794 .31699 L F
.70791 .31693 m .70805 .31409 L .70794 .31699 L F
.608 .87 .531 r
.70676 .31832 m .70499 .32023 L .70786 .31682 L F
.73 .485 .557 r
.70886 .31596 m .70794 .31699 L .70802 .31593 L F
0 0 .127 r
.70785 .31832 m .70813 .3165 L .70805 .31409 L F
.608 .87 .531 r
.70787 .31684 m .70786 .31682 L .70813 .3165 L F
.70676 .31832 m .70786 .31682 L .70787 .31684 L F
.70609 .3192 m .70533 .31991 L .70676 .31832 L F
.70533 .31991 m .70499 .32023 L .70676 .31832 L F
.73 .485 .557 r
.71175 .31605 m .70785 .31832 L .70794 .31699 L F
.71175 .31605 m .70794 .31699 L .70886 .31596 L F
.71175 .31605 m .7111 .31851 L .70785 .31832 L F
.41 .403 .741 r
.7128 .31228 m .71434 .31455 L .71175 .31605 L F
0 0 .13 r
.71304 .31595 m .71175 .31605 L .71434 .31455 L F
.71304 .31595 m .7111 .31851 L .71175 .31605 L F
.869 .64 .59 r
.63118 .39447 m .62877 .39217 L .6287 .39462 L F
.651 .106 0 r
.2576 .61495 m .26154 .6181 L .25969 .61811 L F
.817 .667 .697 r
.32952 .56072 m .33047 .56166 L .32969 .55777 L F
0 0 0 r
.32654 .56388 m .33047 .56166 L .32952 .56072 L F
0 0 .389 r
.32821 .56324 m .32929 .5633 L .32922 .56325 L F
0 0 0 r
.32769 .56323 m .32821 .56324 L .33047 .56166 L F
.555 .543 .796 r
.33047 .56166 m .33167 .55743 L .32969 .55777 L F
.33047 .56166 m .33288 .56107 L .33167 .55743 L F
.523 .874 .629 r
.33047 .56166 m .32821 .56324 L .33142 .56065 L F
.831 .894 .886 r
.33142 .56065 m .32821 .56324 L .32711 .56158 L F
0 0 .389 r
.32821 .56324 m .32922 .56325 L .32711 .56158 L F
0 0 0 r
.32654 .56388 m .32821 .56324 L .32769 .56323 L F
.523 .874 .629 r
.33047 .56166 m .33142 .56065 L .33288 .56107 L F
.357 .83 .87 r
.3626 .71478 m .36391 .71475 L .36645 .71398 L F
.627 .817 .973 r
.34301 .62405 m .3444 .62545 L .34032 .62499 L F
.34301 .62405 m .3444 .62545 L .34032 .62499 L F
0 .325 .736 r
.36168 .50283 m .36175 .50322 L .36031 .50204 L F
.36168 .50283 m .36322 .50392 L .36175 .50322 L F
.631 .069 0 r
.35992 .50202 m .36355 .50392 L .36168 .50283 L F
0 .091 .627 r
.36426 .50429 m .36322 .50392 L .36168 .50283 L F
.631 .069 0 r
.36355 .50392 m .36426 .50429 L .36168 .50283 L F
0 .325 .736 r
.36168 .50283 m .36031 .50204 L .36015 .50191 L F
.698 .539 .668 r
.33036 .59034 m .33057 .59408 L .32706 .59321 L F
.741 .572 .664 r
.33416 .59386 m .33036 .59034 L .33214 .5894 L F
.33416 .59386 m .33057 .59408 L .33036 .59034 L F
.593 .928 .96 r
.2837 .52383 m .28234 .52531 L .2859 .52453 L F
.553 .892 .983 r
.286 .52284 m .2859 .52453 L .28843 .52361 L F
.286 .52284 m .2837 .52383 L .2859 .52453 L F
.148 .289 .753 r
.36528 .52325 m .36716 .52511 L .36677 .5224 L F
0 0 .151 r
.22373 .54272 m .22287 .54503 L .22524 .54151 L F
.905 .674 .168 r
.71011 .35589 m .71048 .35434 L .70992 .3529 L F
.70992 .3529 m .71048 .35434 L .71011 .35589 L F
.524 .915 .804 r
.34697 .65943 m .35139 .65738 L .34982 .65674 L F
.361 .161 .468 r
.70709 .32661 m .70424 .33047 L .70496 .32887 L F
.63 .144 .079 r
.2941 .56183 m .29197 .5632 L .29597 .56333 L F
.047 .242 .74 r
.2941 .56183 m .29597 .56333 L .29479 .55991 L F
.63 .144 .079 r
.2941 .56183 m .29197 .5632 L .29597 .56333 L F
.32 .16 .502 r
.31543 .58639 m .31806 .58617 L .31794 .58331 L F
.072 0 .423 r
.31543 .58639 m .31705 .5885 L .31806 .58617 L F
.31543 .58639 m .31585 .5895 L .31705 .5885 L F
.765 .671 .759 r
.67982 .38231 m .67701 .38303 L .67953 .37983 L F
.61 .474 .67 r
.68201 .37934 m .67982 .38231 L .67953 .37983 L F
.68201 .37934 m .68306 .38312 L .67982 .38231 L F
.635 .472 .644 r
.68306 .38312 m .68145 .38529 L .67982 .38231 L F
.518 .027 0 r
.59939 .4125 m .59964 .41275 L .59642 .41104 L F
.59939 .4125 m .60077 .41395 L .59964 .41275 L F
.311 .352 .743 r
.73941 .33608 m .73621 .33469 L .73879 .33418 L F
.631 .282 .36 r
.73534 .33647 m .73879 .33418 L .73621 .33469 L F
.932 .826 .373 r
.33031 .5946 m .33057 .59408 L .33416 .59386 L F
.375 .452 .813 r
.33537 .59119 m .33416 .59386 L .33214 .5894 L F
.391 .129 .392 r
.33537 .59119 m .33031 .5946 L .33416 .59386 L F
.34 .026 .278 r
.42449 .59394 m .42351 .59598 L .42112 .59672 L F
.745 .67 .778 r
.42815 .59239 m .42627 .59552 L .42564 .59348 L F
.42815 .59239 m .42564 .59348 L .42634 .59194 L F
.615 .595 .807 r
.42627 .59552 m .42351 .59598 L .42559 .59333 L F
.42559 .59333 m .42351 .59598 L .42627 .59552 L F
.745 .67 .778 r
.42564 .59348 m .42557 .59351 L .42562 .59341 L F
.42564 .59348 m .42562 .59341 L .42634 .59194 L F
.615 .595 .807 r
.42627 .59552 m .42559 .59333 L .4259 .59294 L F
.4259 .59294 m .42559 .59333 L .42627 .59552 L F
.745 .67 .778 r
.42564 .59348 m .42627 .59552 L .42557 .59351 L F
0 0 0 r
.42449 .59394 m .42536 .59209 L .42591 .59281 L F
.42536 .59209 m .42626 .59016 L .42602 .59199 L F
.42536 .59209 m .42602 .59199 L .42591 .59281 L F
.978 .684 .32 r
.42537 .59167 m .42626 .59016 L .42499 .59077 L F
0 0 0 r
.42582 .59299 m .42351 .59598 L .42449 .59394 L F
.745 .67 .778 r
.42591 .59281 m .42557 .59351 L .4255 .59174 L F
0 0 0 r
.4259 .59294 m .42559 .59333 L .42582 .59299 L F
.42559 .59333 m .42351 .59598 L .42582 .59299 L F
.745 .67 .778 r
.4255 .59174 m .42556 .59337 L .42489 .59159 L F
.42556 .59337 m .42557 .59351 L .42553 .59341 L F
.42556 .59337 m .42553 .59341 L .42489 .59159 L F
.978 .684 .32 r
.42591 .59281 m .42602 .59199 L .4255 .59174 L F
.745 .67 .778 r
.42634 .59194 m .42591 .59281 L .4255 .59174 L F
.978 .684 .32 r
.4259 .59294 m .42591 .59281 L .42537 .59167 L F
.42591 .59281 m .4255 .59174 L .42537 .59167 L F
.42602 .59199 m .42626 .59016 L .42537 .59167 L F
.029 .57 .846 r
.42644 .59168 m .42688 .59186 L .42531 .59165 L F
0 0 0 r
.42582 .59299 m .42591 .59281 L .4259 .59294 L F
.978 .684 .32 r
.4259 .59294 m .42537 .59167 L .42489 .59159 L F
.42537 .59167 m .42499 .59077 L .42489 .59159 L F
.029 .57 .846 r
.42688 .59186 m .42662 .5919 L .42489 .59159 L F
.42662 .5919 m .42634 .59194 L .42489 .59159 L F
.42523 .59161 m .42531 .59165 L .42489 .59159 L F
.42644 .59168 m .42531 .59165 L .42523 .59161 L F
.42688 .59186 m .42815 .59239 L .42634 .59194 L F
0 0 0 r
.42449 .59394 m .42591 .59281 L .42582 .59299 L F
.497 .29 .529 r
.29111 .62568 m .29366 .62523 L .2937 .62205 L F
.501 .322 .571 r
.2937 .62205 m .29633 .62154 L .2963 .6188 L F
.426 .234 .515 r
.2937 .62205 m .29581 .62445 L .29633 .62154 L F
.2937 .62205 m .29366 .62523 L .29581 .62445 L F
.481 .301 .56 r
.31913 .64455 m .32101 .64618 L .32197 .64545 L F
.497 .3 .543 r
.31866 .64711 m .32101 .64618 L .31913 .64455 L F
.737 .675 .789 r
.64703 .36955 m .65074 .37014 L .6493 .36628 L F
.607 .584 .801 r
.65074 .37014 m .65212 .36625 L .6493 .36628 L F
.65074 .37014 m .65328 .36938 L .65212 .36625 L F
.906 .499 .125 r
.37629 .59473 m .37798 .59673 L .37717 .59543 L F
.631 .936 .964 r
.38436 .62055 m .38656 .62074 L .38355 .62224 L F
.721 .969 .72 r
.38436 .62055 m .38355 .62224 L .3816 .62354 L F
.295 .281 .673 r
.3859 .62439 m .3841 .62516 L .38355 .62224 L F
.952 .715 .543 r
.38355 .62224 m .3841 .62516 L .3816 .62354 L F
.295 .281 .673 r
.3859 .62439 m .3841 .62516 L .38355 .62224 L F
.503 0 0 r
.60037 .40078 m .60226 .40207 L .6044 .40383 L F
0 .091 .636 r
.25504 .56839 m .25653 .5691 L .25843 .56772 L F
.333 .812 .883 r
.2549 .56849 m .25684 .56827 L .25653 .5691 L F
0 0 0 r
.25843 .56772 m .25793 .56808 L .25881 .56804 L F
.25793 .56808 m .25653 .5691 L .25881 .56804 L F
.008 .582 .744 r
.25881 .56804 m .25726 .56791 L .25938 .56801 L F
.294 0 0 r
.25881 .56804 m .26137 .56811 L .26334 .56671 L F
.008 .582 .744 r
.25881 .56804 m .25938 .56801 L .26137 .56811 L F
.333 .812 .883 r
.25684 .56827 m .25881 .56804 L .25653 .5691 L F
0 .091 .636 r
.25504 .56839 m .25595 .57068 L .25653 .5691 L F
.25595 .57068 m .25614 .57116 L .25653 .5691 L F
.825 .838 .858 r
.65391 .34105 m .65127 .34399 L .65075 .34098 L F
.748 .633 .733 r
.66489 .36005 m .66753 .35745 L .66498 .35763 L F
.481 .898 .83 r
.24863 .52582 m .24708 .52629 L .2496 .52487 L F
.807 .746 .796 r
.24596 .52702 m .24163 .52741 L .24462 .52667 L F
.24559 .52727 m .24163 .52741 L .24596 .52702 L F
.24674 .52723 m .24096 .5293 L .24163 .52741 L F
.13 0 0 r
.24462 .52667 m .24863 .52582 L .24674 .52723 L F
.24462 .52667 m .24303 .52749 L .24863 .52582 L F
.481 .898 .83 r
.24708 .52629 m .24303 .52749 L .24865 .52525 L F
.24708 .52629 m .24865 .52525 L .2496 .52487 L F
.807 .746 .796 r
.24674 .52723 m .24559 .52727 L .24596 .52702 L F
.796 .901 .916 r
.72287 .34083 m .72526 .34299 L .72734 .34123 L F
.719 .557 .669 r
.68205 .3766 m .68201 .37934 L .67953 .37983 L F
.594 .392 .577 r
.6855 .37648 m .68201 .37934 L .68205 .3766 L F
.574 .575 .816 r
.35809 .67305 m .35922 .66918 L .3566 .6725 L F
.35809 .67305 m .3604 .67256 L .35922 .66918 L F
.735 .604 .712 r
.56025 .45911 m .56207 .46277 L .55774 .46252 L F
.678 .3 .323 r
.56207 .46277 m .5603 .46496 L .55774 .46252 L F
.777 .43 .398 r
.56207 .46277 m .56433 .46567 L .5603 .46496 L F
.18 .551 .93 r
.24331 .623 m .24258 .62109 L .2422 .62081 L F
.24331 .623 m .24594 .62328 L .24258 .62109 L F
.401 .845 .928 r
.35048 .59395 m .35293 .59353 L .35339 .59309 L F
.35293 .59353 m .35376 .59338 L .35339 .59309 L F
.197 0 .23 r
.35376 .59338 m .35585 .59042 L .35339 .59309 L F
0 0 0 r
.35389 .59262 m .35339 .59309 L .35486 .59154 L F
.35117 .59562 m .35339 .59309 L .35389 .59262 L F
.291 0 .181 r
.34987 .59577 m .35048 .59395 L .35339 .59309 L F
.74 .724 .836 r
.65848 .35759 m .66108 .35754 L .65971 .35329 L F
.663 .467 .61 r
.65835 .36034 m .66108 .35754 L .65848 .35759 L F
.65835 .36034 m .66122 .36028 L .66108 .35754 L F
.772 .741 .825 r
.65971 .35329 m .66108 .35754 L .66349 .3538 L F
.675 .604 .769 r
.66108 .35754 m .66498 .35763 L .66349 .3538 L F
.766 .651 .735 r
.66122 .36028 m .66498 .35763 L .66108 .35754 L F
.905 .75 .254 r
.3228 .66634 m .32316 .6637 L .32274 .66225 L F
.766 .406 .373 r
.39471 .6629 m .39472 .66041 L .39542 .66117 L F
.415 .392 .725 r
.39542 .66117 m .39472 .66041 L .39757 .66008 L F
.344 .073 .35 r
.39508 .66254 m .39495 .66179 L .39471 .6629 L F
.39495 .66179 m .39472 .66041 L .39471 .6629 L F
.992 .75 .455 r
.39471 .6629 m .39542 .66117 L .39513 .66095 L F
.344 .073 .35 r
.39516 .66036 m .39472 .66041 L .39478 .66072 L F
.39515 .66064 m .39478 .66072 L .39508 .66254 L F
.39516 .66036 m .39478 .66072 L .39515 .66064 L F
.483 .561 .859 r
.39291 .65634 m .39515 .66064 L .39757 .66008 L F
.39515 .66064 m .39542 .66117 L .39757 .66008 L F
.76 .678 .771 r
.3943 .66153 m .39471 .6629 L .39177 .66265 L F
.992 .75 .455 r
.39471 .6629 m .39513 .66095 L .39391 .66004 L F
.76 .678 .771 r
.3943 .66153 m .39177 .66265 L .3938 .65978 L F
.969 .649 .299 r
.39391 .66004 m .39513 .66095 L .39452 .66013 L F
.3938 .65978 m .39452 .66013 L .39307 .65815 L F
.39391 .66004 m .39452 .66013 L .3938 .65978 L F
.39307 .65815 m .39513 .66095 L .39291 .65634 L F
.39318 .65949 m .39391 .66004 L .39307 .65815 L F
.39513 .66095 m .39515 .66064 L .39291 .65634 L F
.908 .956 .813 r
.3938 .65978 m .39318 .65949 L .3949 .65822 L F
.39177 .66265 m .39318 .65949 L .3938 .65978 L F
.76 .678 .771 r
.39391 .66004 m .3938 .65978 L .39383 .65973 L F
.3943 .66153 m .3938 .65978 L .39391 .66004 L F
.992 .75 .455 r
.3943 .66153 m .39391 .66004 L .39383 .65997 L F
.39471 .6629 m .39391 .66004 L .3943 .66153 L F
.969 .649 .299 r
.39513 .66095 m .39542 .66117 L .39515 .66064 L F
.344 .073 .35 r
.39757 .66008 m .39516 .66036 L .39508 .66254 L F
.76 .678 .771 r
.39757 .66008 m .3943 .66153 L .3949 .65822 L F
.3943 .66153 m .39383 .65973 L .3949 .65822 L F
.39757 .66008 m .39471 .6629 L .3943 .66153 L F
.992 .75 .455 r
.39471 .6629 m .39383 .65997 L .39318 .65949 L F
.542 .33 .542 r
.31644 .61177 m .31433 .60948 L .31662 .60882 L F
.31644 .61177 m .31412 .61222 L .31433 .60948 L F
.826 .957 .899 r
.53277 .41877 m .52857 .42152 L .53072 .41908 L F
.953 .879 .724 r
.53353 .41411 m .53277 .41877 L .53355 .41679 L F
.79 .959 .921 r
.53355 .41679 m .53277 .41877 L .53072 .41908 L F
.269 .201 .593 r
.38648 .67516 m .38426 .67256 L .38829 .67275 L F
.95 .687 .501 r
.38829 .67275 m .38838 .67617 L .38648 .67516 L F
.421 .783 .995 r
.29443 .52249 m .2905 .52176 L .29211 .52298 L F
0 0 0 r
.3782 .71146 m .37855 .71063 L .38057 .71039 L F
1 .82 .515 r
.38463 .58614 m .38585 .58741 L .38422 .58889 L F
.56 .062 .03 r
.38422 .58889 m .38585 .58741 L .38801 .58885 L F
.524 .123 .222 r
.38585 .58741 m .38912 .58745 L .38801 .58885 L F
.878 .629 .559 r
.56875 .40535 m .56548 .40747 L .56795 .40443 L F
.56875 .40535 m .56864 .40793 L .56548 .40747 L F
.772 .932 .937 r
.56964 .40281 m .56875 .40535 L .56795 .40443 L F
.56964 .40281 m .57105 .40379 L .56875 .40535 L F
.777 .696 .774 r
.66611 .35059 m .66995 .35119 L .66869 .34732 L F
.681 .607 .767 r
.32243 .69171 m .32313 .69559 L .32518 .69316 L F
.94 .811 .69 r
.6759 .34004 m .67759 .34138 L .67661 .3375 L F
.846 .86 .853 r
.67346 .34281 m .67759 .34138 L .6759 .34004 L F
.74 .318 0 r
.40398 .53188 m .40191 .52853 L .40284 .52987 L F
.674 .953 .952 r
.60085 .36177 m .60213 .36241 L .59954 .36382 L F
.578 .557 .795 r
.59962 .36685 m .60085 .36177 L .59954 .36382 L F
.901 .951 .604 r
.43139 .56331 m .42953 .56712 L .43094 .5657 L F
0 .444 .746 r
.35526 .5005 m .35704 .50114 L .35321 .49995 L F
0 .509 .848 r
.35863 .501 m .35704 .50114 L .35526 .5005 L F
0 .163 .671 r
.35841 .50023 m .35867 .50054 L .35863 .501 L F
.35867 .50054 m .35992 .50202 L .35863 .501 L F
0 .509 .848 r
.35863 .501 m .36015 .50191 L .3586 .50153 L F
.35863 .501 m .3586 .50153 L .35704 .50114 L F
.924 .535 .177 r
.40747 .5399 m .40811 .54195 L .40575 .53831 L F
.831 .567 .539 r
.64944 .43027 m .64934 .42759 L .64624 .42681 L F
.662 .132 0 r
.64624 .42681 m .64934 .42759 L .64725 .42738 L F
.807 .92 .913 r
.64934 .42759 m .65189 .42355 L .64725 .42738 L F
.64934 .42759 m .65321 .42484 L .65189 .42355 L F
.633 .212 .226 r
.23809 .61073 m .23882 .61243 L .24056 .61208 L F
.624 .479 .665 r
.37269 .52964 m .36962 .52622 L .37158 .52527 L F
.897 .478 .147 r
.7081 .30806 m .70915 .30739 L .70777 .30536 L F
.7081 .30806 m .70975 .30904 L .70915 .30739 L F
.781 .484 .485 r
.71255 .30963 m .70915 .30739 L .70975 .30904 L F
.472 .184 .394 r
.39623 .49783 m .39566 .49968 L .39839 .49875 L F
.057 0 0 r
.69245 .3661 m .69493 .36397 L .69438 .36459 L F
0 0 0 r
.69438 .36459 m .69493 .36397 L .69735 .36148 L F
.855 .475 0 r
.60936 .40851 m .60904 .40934 L .60829 .40711 L F
.60936 .40851 m .6101 .41069 L .60904 .40934 L F
.988 .741 .467 r
.2295 .61149 m .22981 .612 L .22963 .61153 L F
.2295 .61149 m .22963 .61153 L .22821 .60792 L F
.897 .801 .746 r
.23103 .61194 m .2295 .61149 L .23099 .61193 L F
.232 .61211 m .2295 .61149 L .23103 .61194 L F
.638 .828 .973 r
.28391 .63075 m .2864 .63238 L .28829 .63116 L F
0 0 0 r
.28829 .63116 m .2864 .63238 L .28538 .63388 L F
.782 .351 .225 r
.43373 .5958 m .4302 .59328 L .43403 .59359 L F
.64 .397 .534 r
.43403 .59359 m .43664 .59602 L .43373 .5958 L F
.649 .395 .521 r
.43674 .59343 m .43664 .59602 L .43403 .59359 L F
.952 .949 .654 r
.38884 .61622 m .38788 .62192 L .3902 .62215 L F
.38884 .61622 m .38656 .62074 L .38788 .62192 L F
.844 .854 .851 r
.38935 .61844 m .39102 .61799 L .38884 .61622 L F
.3902 .62215 m .39102 .61799 L .38935 .61844 L F
.538 .309 .516 r
.39297 .61921 m .39295 .61703 L .39102 .61799 L F
0 0 0 r
.39211 .61769 m .39102 .61799 L .39295 .61703 L F
.844 .854 .851 r
.3902 .62215 m .39297 .61921 L .39102 .61799 L F
0 0 0 r
.38954 .61973 m .39102 .61799 L .39211 .61769 L F
.591 .017 0 r
.38884 .61622 m .39102 .61799 L .38857 .61608 L F
.971 .757 .558 r
.3781 .63681 m .37988 .63792 L .3802 .63497 L F
.732 .672 .791 r
.3304 .54808 m .33163 .55204 L .32719 .55101 L F
.175 0 0 r
.33163 .55204 m .32748 .55275 L .32719 .55101 L F
.33163 .55204 m .32972 .55288 L .32748 .55275 L F
.033 .201 .706 r
.33239 .55007 m .33122 .55072 L .3304 .54808 L F
.876 .944 .855 r
.32719 .55101 m .32871 .54682 L .3304 .54808 L F
.77 .261 0 r
.32871 .54682 m .33239 .55007 L .3304 .54808 L F
.33074 .54861 m .33085 .54961 L .33239 .55007 L F
.32871 .54682 m .33085 .54961 L .33074 .54861 L F
.735 .329 .28 r
.32884 .5508 m .33093 .55037 L .33085 .54961 L F
.305 .776 .935 r
.33239 .55007 m .33085 .54961 L .33307 .54969 L F
.33239 .55007 m .33307 .54969 L .33478 .54975 L F
.735 .329 .28 r
.33093 .55037 m .33363 .54982 L .33085 .54961 L F
.033 .201 .706 r
.33239 .55007 m .33163 .55204 L .33122 .55072 L F
.543 .206 .348 r
.33163 .55204 m .33248 .55423 L .3344 .55197 L F
.33248 .55423 m .3326 .55454 L .3328 .55426 L F
.33248 .55423 m .3328 .55426 L .3344 .55197 L F
0 0 .412 r
.33239 .55007 m .3326 .55454 L .33163 .55204 L F
.385 .693 .981 r
.33163 .55211 m .32972 .55288 L .33163 .55204 L F
.33163 .55474 m .32972 .55288 L .33163 .55211 L F
.057 0 .437 r
.33163 .55474 m .3326 .55454 L .33163 .55204 L F
.385 .693 .981 r
.33099 .55412 m .33225 .55308 L .32972 .55288 L F
.399 .834 .95 r
.33225 .55308 m .32872 .55328 L .32972 .55288 L F
.32872 .55328 m .3282 .55331 L .32972 .55288 L F
.385 .693 .981 r
.33163 .55474 m .33184 .55418 L .33099 .55412 L F
.33184 .55418 m .33225 .55308 L .33099 .55412 L F
.339 .715 .984 r
.28752 .59906 m .29259 .6008 L .28984 .6 L F
.733 .611 .721 r
.28984 .6 m .28506 .59994 L .28752 .59906 L F
.28984 .6 m .28645 .60131 L .28506 .59994 L F
.812 .669 .705 r
.28752 .59906 m .28905 .60267 L .29259 .6008 L F
.436 .548 .871 r
.37133 .59524 m .37216 .59268 L .36967 .59357 L F
.37133 .59524 m .37391 .59625 L .37216 .59268 L F
.39 .592 .925 r
.70398 .35501 m .70765 .35767 L .70672 .35397 L F
.905 .674 .168 r
.71011 .35589 m .70672 .35397 L .70765 .35767 L F
0 .019 .539 r
.70765 .35767 m .7096 .35784 L .71011 .35589 L F
.70765 .35767 m .7083 .36006 L .7096 .35784 L F
.633 .508 .693 r
.44205 .49679 m .43938 .49775 L .44172 .49449 L F
.568 .537 .78 r
.44302 .50069 m .43938 .49775 L .44205 .49679 L F
.909 .951 .813 r
.67735 .31431 m .6783 .31555 L .67576 .31896 L F
.907 .951 .816 r
.68082 .31205 m .6783 .31555 L .67735 .31431 L F
.024 .187 .695 r
.36451 .60042 m .36645 .60194 L .36518 .60312 L F
.132 .115 .57 r
.36736 .60409 m .36518 .60312 L .36645 .60194 L F
.36736 .60409 m .36573 .60536 L .36518 .60312 L F
.608 .87 .531 r
.70609 .3192 m .70813 .3165 L .70785 .31832 L F
.591 .534 .759 r
.70785 .31832 m .70626 .32207 L .70609 .3192 L F
.64 .41 .553 r
.67446 .38922 m .67472 .39193 L .67184 .39208 L F
.602 .351 .508 r
.67446 .38922 m .67693 .39029 L .67472 .39193 L F
.67446 .38922 m .67859 .38884 L .67693 .39029 L F
.409 .003 .155 r
.26078 .56697 m .26334 .56671 L .26488 .56458 L F
.165 0 .004 r
.26488 .56458 m .26582 .56573 L .26688 .56368 L F
.26488 .56458 m .26334 .56671 L .26582 .56573 L F
.282 .013 .316 r
.33544 .60233 m .33788 .60242 L .33855 .59937 L F
.01 0 .144 r
.33544 .60233 m .33648 .604 L .33788 .60242 L F
.33544 .60233 m .33491 .60497 L .33648 .604 L F
.94 .71 .562 r
.39964 .52632 m .3973 .52555 L .39789 .52284 L F
.39964 .52632 m .3973 .52555 L .39789 .52284 L F
.536 .013 0 r
.39964 .52632 m .39891 .52584 L .3973 .52555 L F
.39964 .52632 m .40191 .52853 L .39891 .52584 L F
.308 .005 .277 r
.64586 .42447 m .64339 .42697 L .64624 .42681 L F
.286 .366 .771 r
.64478 .42072 m .64586 .42447 L .6475 .42245 L F
.515 .493 .771 r
.64624 .42681 m .6475 .42245 L .64586 .42447 L F
.693 .579 .723 r
.67117 .3601 m .67272 .3639 L .67531 .36057 L F
.661 .533 .697 r
.67272 .3639 m .67521 .36374 L .67531 .36057 L F
.497 .35 .611 r
.67272 .3639 m .67554 .3659 L .67521 .36374 L F
.67272 .3639 m .67296 .36671 L .67554 .3659 L F
0 0 .428 r
.37536 .55005 m .37419 .54921 L .37518 .54765 L F
.37536 .55005 m .37443 .55195 L .37419 .54921 L F
.381 .292 .628 r
.20568 .58352 m .20761 .58307 L .20711 .5804 L F
.593 .928 .96 r
.2837 .52383 m .28109 .525 L .28234 .52531 L F
.583 .466 .685 r
.62632 .39534 m .62877 .39217 L .6262 .39346 L F
.62632 .39534 m .6287 .39462 L .62877 .39217 L F
.824 .808 .836 r
.6254 .37534 m .62614 .37559 L .63106 .37285 L F
0 0 .271 r
.62636 .37443 m .62521 .37592 L .6254 .37534 L F
.824 .808 .836 r
.6254 .37534 m .63106 .37285 L .62976 .3714 L F
.825 .944 .902 r
.6254 .37534 m .62976 .3714 L .62901 .37014 L F
.6254 .37534 m .62901 .37014 L .62899 .37326 L F
.619 .95 .931 r
.623 .37605 m .62509 .37593 L .62636 .37443 L F
.62509 .37593 m .62521 .37592 L .62525 .37588 L F
.62509 .37593 m .62525 .37588 L .62636 .37443 L F
.824 .808 .836 r
.62614 .37559 m .62867 .37645 L .63009 .37432 L F
.62614 .37559 m .63009 .37432 L .63106 .37285 L F
.663 .574 .744 r
.62867 .37645 m .63266 .37682 L .63106 .37285 L F
.96 .946 .68 r
.61382 .44211 m .61539 .44099 L .61481 .43927 L F
.164 .353 .805 r
.61539 .44099 m .61805 .44083 L .61481 .43927 L F
.61539 .44099 m .61758 .44289 L .61805 .44083 L F
.35 .209 .545 r
.36193 .67905 m .35941 .6797 L .36158 .68193 L F
.487 .23 .45 r
.32229 .60003 m .32182 .60259 L .31925 .60297 L F
.299 .068 .385 r
.32383 .60169 m .32229 .60003 L .32441 .59928 L F
.32383 .60169 m .32182 .60259 L .32229 .60003 L F
.544 .268 .447 r
.28853 .56037 m .2866 .55867 L .28912 .55764 L F
.28853 .56037 m .28592 .56077 L .2866 .55867 L F
.89 .465 .1 r
.25894 .57623 m .25791 .57691 L .25696 .5751 L F
.25894 .57623 m .2597 .57824 L .25791 .57691 L F
.893 .967 .829 r
.6018 .38389 m .60186 .38641 L .60193 .38453 L F
0 .338 .702 r
.59378 .40689 m .59465 .40737 L .59226 .40637 L F
.592 .372 .551 r
.312 .55515 m .31196 .55819 L .3094 .55807 L F
.53 .286 .49 r
.3159 .55419 m .31196 .55819 L .312 .55515 L F
0 0 0 r
.7016 .32615 m .70243 .32589 L .7023 .32349 L F
.7016 .32615 m .70051 .32738 L .70243 .32589 L F
.669 .875 .976 r
.64373 .40389 m .64605 .40072 L .64323 .40332 L F
.64373 .40389 m .64737 .40223 L .64605 .40072 L F
.287 0 .168 r
.42112 .59672 m .42351 .59598 L .42275 .59878 L F
.539 .504 .765 r
.62165 .44973 m .62282 .44579 L .62051 .44619 L F
.62165 .44973 m .62432 .44934 L .62282 .44579 L F
.695 .339 .366 r
.24352 .56199 m .24327 .56381 L .24026 .56218 L F
0 0 .09 r
.24454 .56186 m .24352 .56199 L .24533 .56114 L F
0 0 0 r
.24548 .56148 m .24546 .56149 L .24454 .56186 L F
0 0 .09 r
.24454 .56186 m .24327 .56381 L .24348 .56228 L F
.24454 .56186 m .24348 .56228 L .24352 .56199 L F
.652 .835 .971 r
.24086 .56143 m .24327 .56381 L .24454 .56186 L F
0 0 0 r
.24546 .56149 m .2428 .56262 L .24454 .56186 L F
.979 .856 .648 r
.41589 .57108 m .41441 .57454 L .41341 .57247 L F
.975 .896 .68 r
.41589 .57108 m .41341 .57247 L .41489 .56986 L F
.162 0 0 r
.32696 .68298 m .32344 .68569 L .32559 .68538 L F
.246 0 0 r
.32755 .68442 m .32696 .68298 L .32559 .68538 L F
.32755 .68442 m .32939 .68256 L .32696 .68298 L F
.948 .646 .432 r
.37104 .58613 m .37292 .58695 L .37101 .58616 L F
.153 .171 .625 r
.37319 .59028 m .37194 .58816 L .37292 .58695 L F
.948 .646 .432 r
.37107 .58619 m .37108 .5862 L .37292 .58695 L F
.37108 .5862 m .37319 .59028 L .37298 .58764 L F
.37108 .5862 m .37298 .58764 L .37292 .58695 L F
0 0 .302 r
.37346 .58962 m .37319 .59028 L .37292 .58695 L F
.598 .358 .524 r
.37776 .58631 m .37346 .58962 L .37339 .58931 L F
.37454 .58681 m .37339 .58931 L .37294 .58707 L F
.37776 .58631 m .37339 .58931 L .37454 .58681 L F
.865 .664 .628 r
.37216 .59268 m .37319 .59028 L .37084 .58605 L F
.872 .89 .464 r
.37281 .59058 m .37319 .59028 L .37216 .59268 L F
0 0 .302 r
.37339 .58931 m .37292 .58695 L .37294 .58707 L F
.37346 .58962 m .37339 .58931 L .37339 .58931 L F
.37339 .58931 m .37292 .58695 L .37339 .58931 L F
0 0 .261 r
.37292 .58695 m .37313 .58952 L .37362 .5879 L F
.37315 .58983 m .37319 .59028 L .37334 .58941 L F
.948 .646 .432 r
.37107 .58647 m .37319 .59028 L .37104 .58613 L F
.872 .89 .464 r
.37362 .5879 m .37334 .58941 L .37281 .59058 L F
.37334 .58941 m .37319 .59028 L .37281 .59058 L F
0 0 .261 r
.37292 .58695 m .37362 .5879 L .37105 .58619 L F
0 .195 .644 r
.37104 .58618 m .37362 .5879 L .37259 .58719 L F
0 0 .261 r
.37292 .58695 m .37105 .58619 L .37101 .58616 L F
0 .195 .644 r
.37101 .58616 m .37105 .58619 L .37104 .58618 L F
.37105 .58619 m .37362 .5879 L .37104 .58618 L F
.948 .646 .432 r
.37104 .58613 m .37107 .58619 L .37292 .58695 L F
.453 .272 .544 r
.37101 .58616 m .37104 .58618 L .37104 .58613 L F
.948 .646 .432 r
.37084 .58605 m .37104 .58613 L .37101 .58616 L F
.37084 .58605 m .37107 .58647 L .37104 .58613 L F
.453 .272 .544 r
.37104 .58613 m .37259 .58719 L .37293 .5849 L F
.37104 .58618 m .37259 .58719 L .37104 .58613 L F
.37101 .58616 m .37293 .5849 L .37326 .58259 L F
0 0 .143 r
.31544 .53851 m .3168 .53518 L .31547 .53602 L F
.668 .785 .937 r
.42818 .48107 m .42442 .4801 L .42735 .47775 L F
.715 .764 .892 r
.43099 .47829 m .42818 .48107 L .42735 .47775 L F
.615 .586 .798 r
.43099 .47829 m .43238 .48197 L .42818 .48107 L F
.603 .603 .825 r
.43296 .48359 m .42818 .48107 L .43238 .48197 L F
0 .118 .669 r
.40909 .54617 m .41057 .54813 L .40865 .54438 L F
.164 0 .33 r
.31924 .65276 m .31733 .65409 L .31682 .6572 L F
.679 .847 .963 r
.27292 .56474 m .27138 .56607 L .27457 .56533 L F
.686 .527 .666 r
.27457 .56533 m .27138 .56607 L .27292 .56474 L F
.27457 .56533 m .27169 .56793 L .27138 .56607 L F
0 0 .504 r
.41367 .56105 m .41235 .55694 L .4133 .55833 L F
.176 0 .36 r
.31875 .6054 m .31662 .60882 L .31707 .60632 L F
.766 .651 .735 r
.66122 .36028 m .66489 .36005 L .66498 .35763 L F
.764 .617 .696 r
.66229 .36344 m .66489 .36005 L .66122 .36028 L F
.517 .307 .534 r
.71329 .35102 m .71614 .3528 L .71322 .35385 L F
.825 .65 .102 r
.41433 .56476 m .414 .5663 L .41371 .56309 L F
.41433 .56476 m .41435 .56733 L .414 .5663 L F
.407 .271 .582 r
.44691 .5198 m .44707 .52272 L .44494 .52328 L F
.48 .436 .731 r
.44809 .52535 m .44494 .52328 L .44707 .52272 L F
.31 0 0 r
.27368 .62297 m .27645 .62399 L .27636 .62385 L F
.405 .518 .859 r
.27439 .62056 m .27645 .62399 L .27368 .62297 L F
0 0 .443 r
.27662 .62425 m .27645 .62399 L .27517 .62304 L F
.807 .318 0 r
.27645 .62399 m .27804 .62663 L .27989 .62747 L F
0 0 .443 r
.2772 .62473 m .27804 .62663 L .27645 .62399 L F
.2772 .62473 m .27645 .62399 L .27662 .62425 L F
.31 0 0 r
.27636 .62385 m .27645 .62399 L .27827 .62447 L F
.684 .138 0 r
.27645 .62399 m .27925 .62536 L .27827 .62447 L F
.957 .708 .258 r
.41194 .55155 m .41205 .55455 L .41111 .5525 L F
.209 .25 .685 r
.69183 .3275 m .69152 .32922 L .69339 .32696 L F
.368 .483 .845 r
.69152 .32922 m .69463 .33066 L .69339 .32696 L F
.591 .534 .759 r
.70785 .31832 m .70931 .32198 L .70626 .32207 L F
.527 .351 .586 r
.70931 .32198 m .70686 .32518 L .70626 .32207 L F
.711 .575 .7 r
.67531 .36057 m .67868 .36058 L .67782 .3603 L F
.592 .404 .596 r
.67868 .36058 m .68156 .3597 L .67782 .3603 L F
.897 .985 .788 r
.60478 .38035 m .60664 .3801 L .60417 .38331 L F
.916 .962 .643 r
.60845 .37617 m .60664 .3801 L .60679 .37785 L F
.895 .986 .79 r
.60679 .37785 m .60664 .3801 L .60478 .38035 L F
.768 .714 .801 r
.61918 .36352 m .61655 .36694 L .61524 .36293 L F
.587 .431 .637 r
.31791 .52395 m .3206 .52389 L .3206 .52369 L F
.146 0 0 r
.32184 .52319 m .32123 .52361 L .31791 .52395 L F
.63 .467 .642 r
.3206 .52369 m .3206 .52389 L .32294 .52341 L F
.146 0 0 r
.32123 .52361 m .3212 .52363 L .3206 .52369 L F
.32123 .52361 m .3206 .52369 L .31791 .52395 L F
.329 .126 .445 r
.32392 .52221 m .32064 .51945 L .32298 .51986 L F
.63 .467 .642 r
.32064 .51945 m .32302 .5227 L .32298 .51986 L F
.32313 .52284 m .32125 .5236 L .32346 .5233 L F
.525 .129 .234 r
.32287 .52277 m .32286 .52286 L .3227 .52286 L F
.63 .467 .642 r
.32313 .52284 m .32346 .5233 L .32341 .52292 L F
.3206 .52369 m .32294 .52341 L .32346 .5233 L F
.52 .069 .12 r
.32091 .52383 m .32346 .5233 L .3206 .52389 L F
.32091 .52383 m .32272 .52447 L .32346 .5233 L F
.525 .129 .234 r
.32353 .52295 m .32272 .52447 L .32287 .52277 L F
.63 .467 .642 r
.32302 .5227 m .3227 .52286 L .32313 .52284 L F
.3227 .52286 m .32125 .5236 L .32313 .52284 L F
.525 .129 .234 r
.3227 .52286 m .32272 .52447 L .32091 .52383 L F
.32286 .52286 m .32272 .52447 L .3227 .52286 L F
.32392 .52221 m .32287 .52277 L .32184 .52319 L F
.554 .596 .85 r
.32638 .5214 m .32392 .52221 L .32298 .51986 L F
.32638 .5214 m .32298 .51986 L .32527 .51904 L F
0 0 .374 r
.32298 .51986 m .32341 .52292 L .32383 .52008 L F
.528 .216 .382 r
.32638 .5214 m .3238 .52356 L .32392 .52221 L F
0 0 .374 r
.32347 .52306 m .32346 .5233 L .32349 .52309 L F
.32342 .52298 m .32346 .5233 L .32347 .52306 L F
.528 .216 .382 r
.3238 .52356 m .32272 .52447 L .32347 .52306 L F
.3238 .52356 m .32347 .52306 L .32392 .52221 L F
0 0 .374 r
.32341 .52292 m .32342 .52298 L .32347 .52306 L F
.525 .129 .234 r
.32392 .52221 m .32341 .52292 L .32326 .52257 L F
0 0 .374 r
.32341 .52292 m .32349 .52309 L .32383 .52008 L F
.525 .129 .234 r
.32392 .52221 m .32353 .52295 L .32341 .52292 L F
.32326 .52257 m .32341 .52292 L .32287 .52277 L F
.63 .467 .642 r
.32302 .5227 m .32313 .52284 L .32336 .52254 L F
.32313 .52284 m .32341 .52292 L .32336 .52254 L F
.32302 .5227 m .32336 .52254 L .32298 .51986 L F
.525 .129 .234 r
.32287 .52277 m .3227 .52286 L .32258 .52291 L F
.32287 .52277 m .32258 .52291 L .32184 .52319 L F
.3227 .52286 m .32091 .52383 L .32123 .52361 L F
.3227 .52286 m .32123 .52361 L .32184 .52319 L F
.63 .467 .642 r
.32064 .51945 m .3206 .52369 L .32125 .5236 L F
.32064 .51945 m .32125 .5236 L .32302 .5227 L F
.587 .431 .637 r
.31791 .52395 m .32064 .51945 L .31996 .52077 L F
.31791 .52395 m .3206 .52369 L .32064 .51945 L F
.146 0 0 r
.3212 .52363 m .32091 .52383 L .31791 .52395 L F
.988 .737 .455 r
.38706 .61477 m .38857 .61608 L .38695 .61746 L F
.857 .891 .86 r
.39149 .61273 m .38857 .61608 L .38706 .61477 L F
.641 .148 .066 r
.38857 .61608 m .39102 .61799 L .38695 .61746 L F
0 .158 .632 r
.26802 .52829 m .2664 .527 L .26597 .52574 L F
0 0 .014 r
.60956 .45599 m .61178 .45243 L .61109 .45455 L F
0 0 0 r
.61288 .45014 m .61109 .45455 L .61178 .45243 L F
.61418 .38512 m .61561 .38485 L .6131 .38684 L F
.61418 .38512 m .61698 .38394 L .61561 .38485 L F
.946 .617 .375 r
.3816 .62354 m .3841 .62516 L .38376 .62779 L F
.111 0 .243 r
.38376 .62779 m .3841 .62516 L .3859 .62439 L F
.551 .465 .711 r
.44474 .50985 m .44292 .51495 L .44207 .51057 L F
.44474 .50985 m .44397 .51429 L .44292 .51495 L F
.519 .412 .672 r
.44397 .51429 m .44335 .51709 L .44292 .51495 L F
.782 .908 .927 r
.33181 .49574 m .32998 .49716 L .32795 .49641 L F
.853 .662 .644 r
.33115 .49982 m .32795 .49641 L .32998 .49716 L F
.536 .544 .81 r
.2251 .6125 m .22605 .60845 L .2238 .60892 L F
.2251 .6125 m .2295 .61149 L .22605 .60845 L F
.523 0 0 r
.3771 .51556 m .37967 .51783 L .37769 .51593 L F
.217 0 .031 r
.38186 .58267 m .38423 .58077 L .3826 .5823 L F
0 .155 .697 r
.38423 .58077 m .385 .57994 L .3826 .5823 L F
0 0 .019 r
.38348 .57795 m .3826 .5823 L .385 .57994 L F
0 .207 .731 r
.38314 .5809 m .38359 .5818 L .3826 .5823 L F
.38359 .5818 m .38488 .58435 L .3826 .5823 L F
.217 0 .031 r
.38127 .58315 m .38186 .58267 L .3826 .5823 L F
0 .155 .697 r
.38423 .58077 m .38662 .58319 L .385 .57994 L F
.4 .309 .637 r
.38423 .58077 m .38475 .58373 L .38662 .58319 L F
.843 .831 .835 r
.67335 .32225 m .66925 .32371 L .67182 .32069 L F
.866 .833 .811 r
.67576 .31896 m .67335 .32225 L .67182 .32069 L F
.907 .951 .816 r
.68082 .31205 m .67735 .31431 L .67957 .31082 L F
.782 .811 .876 r
.68236 .30774 m .68082 .31205 L .67957 .31082 L F
.68236 .30774 m .68395 .30946 L .68082 .31205 L F
.561 .85 .997 r
.59962 .36685 m .6035 .36711 L .6019 .36621 L F
.045 .357 .83 r
.6035 .36711 m .60444 .36695 L .6019 .36621 L F
.6035 .36711 m .60634 .36875 L .60444 .36695 L F
.833 .443 .311 r
.6035 .36711 m .60732 .37019 L .60674 .36934 L F
.6035 .36711 m .60674 .36934 L .60568 .36837 L F
.893 .613 .506 r
.60118 .36772 m .6042 .36701 L .6031 .37109 L F
.6042 .36701 m .60444 .36695 L .60438 .36716 L F
.6042 .36701 m .60438 .36716 L .6031 .37109 L F
.833 .443 .311 r
.60568 .36837 m .60674 .36934 L .60634 .36875 L F
.319 0 0 r
.35193 .5244 m .35479 .52529 L .35063 .52433 L F
.99 .765 .382 r
.43148 .54045 m .4309 .54218 L .43064 .53823 L F
.87 .597 .522 r
.72052 .33684 m .72336 .3381 L .72169 .33493 L F
.233 .323 .752 r
.72169 .33493 m .72519 .33632 L .72577 .33535 L F
.72169 .33493 m .72336 .3381 L .72519 .33632 L F
.559 .283 .453 r
.28602 .56372 m .28421 .56189 L .28592 .56077 L F
.28602 .56372 m .28332 .56413 L .28421 .56189 L F
.535 .583 .85 r
.46069 .55733 m .4599 .56138 L .45862 .55758 L F
.46069 .55733 m .46232 .56086 L .4599 .56138 L F
.866 .833 .811 r
.67576 .31896 m .67182 .32069 L .67452 .31751 L F
.909 .951 .813 r
.67735 .31431 m .67576 .31896 L .67452 .31751 L F
.511 .868 .987 r
.25589 .52393 m .25632 .52253 L .25776 .52261 L F
.25589 .52393 m .25364 .52324 L .25632 .52253 L F
.86 .649 .616 r
.70727 .30957 m .70382 .31103 L .70336 .30898 L F
.70727 .30957 m .70764 .31292 L .70382 .31103 L F
.81 .48 .43 r
.29391 .61022 m .29628 .61249 L .2983 .61251 L F
.823 .521 .479 r
.29628 .61249 m .29621 .6146 L .2983 .61251 L F
.659 .287 .329 r
.29621 .6146 m .30063 .61474 L .2983 .61251 L F
.573 .307 .475 r
.2983 .61251 m .30063 .61474 L .30101 .61229 L F
.96 .776 .331 r
.44197 .5707 m .44178 .57068 L .44118 .56934 L F
0 0 0 r
.63993 .39764 m .63707 .40106 L .63902 .39986 L F
.444 .098 .284 r
.64253 .39726 m .63993 .39764 L .64253 .39786 L F
.291 0 .034 r
.64253 .39786 m .63993 .39764 L .63902 .39986 L F
.546 .235 .392 r
.59306 .45638 m .59565 .45816 L .59294 .45853 L F
0 0 0 r
.32686 .62027 m .3266 .61976 L .32506 .62059 L F
.556 .494 .741 r
.32866 .619 m .32661 .62169 L .3266 .61976 L F
0 0 0 r
.32686 .62027 m .32866 .619 L .3266 .61976 L F
.769 .373 0 r
.44118 .56934 m .44178 .57068 L .43985 .56718 L F
.938 .91 .766 r
.65189 .42355 m .65513 .42115 L .65414 .41994 L F
.65189 .42355 m .65321 .42484 L .65513 .42115 L F
.996 .855 .578 r
.65513 .42115 m .65471 .41724 L .65414 .41994 L F
.69 .768 .911 r
.32021 .54192 m .3158 .54206 L .31883 .54096 L F
.551 .084 .1 r
.3158 .54206 m .31771 .54382 L .32021 .54192 L F
.852 .416 0 r
.32016 .54368 m .32021 .54192 L .31771 .54382 L F
.32016 .54368 m .32193 .54519 L .32021 .54192 L F
.397 .096 .333 r
.27151 .53643 m .271 .53843 L .26863 .53903 L F
0 0 0 r
.27211 .53626 m .27151 .53643 L .2742 .53598 L F
.27211 .53626 m .271 .53843 L .27151 .53643 L F
.462 .152 .353 r
.29482 .54178 m .29735 .5442 L .29707 .54087 L F
.29482 .54178 m .29449 .54476 L .29735 .5442 L F
.505 .586 .869 r
.37443 .55195 m .37773 .55443 L .37637 .55252 L F
.667 .8 .346 r
.37773 .55443 m .37884 .55214 L .37637 .55252 L F
.37773 .55443 m .37789 .55396 L .37959 .55057 L F
.37789 .55396 m .37868 .55233 L .37959 .55057 L F
.745 .661 .767 r
.37897 .55377 m .38186 .5545 L .38286 .55417 L F
.726 .62 .739 r
.38186 .5545 m .37942 .55628 L .3787 .5537 L F
.046 .28 .773 r
.37781 .55643 m .37942 .55628 L .37798 .55367 L F
.894 .709 .645 r
.37811 .55372 m .37942 .55628 L .37792 .55482 L F
.745 .661 .767 r
.37798 .55367 m .37822 .55372 L .37841 .55371 L F
.667 .8 .346 r
.37789 .55396 m .37797 .55372 L .37834 .553 L F
.37791 .55391 m .37834 .553 L .37868 .55233 L F
.37789 .55396 m .37834 .553 L .37791 .55391 L F
.745 .661 .767 r
.37798 .55367 m .37942 .55628 L .37822 .55372 L F
.894 .709 .645 r
.37822 .55372 m .37942 .55628 L .37811 .55372 L F
.3787 .5537 m .37942 .55628 L .37822 .55372 L F
.745 .661 .767 r
.37822 .55372 m .37942 .55628 L .38186 .5545 L F
.37798 .55367 m .38286 .55417 L .38228 .55387 L F
.667 .8 .346 r
.37797 .55372 m .37815 .55334 L .37868 .55233 L F
.828 .508 .448 r
.37959 .55057 m .37815 .55334 L .37869 .5537 L F
.726 .62 .739 r
.37871 .55371 m .3787 .5537 L .3787 .5537 L F
.894 .709 .645 r
.3787 .5537 m .3787 .5537 L .37869 .5537 L F
.828 .508 .448 r
.38228 .55284 m .37869 .5537 L .38358 .55394 L F
.37959 .55057 m .37869 .5537 L .38228 .55284 L F
.726 .62 .739 r
.38186 .5545 m .37871 .55371 L .37844 .55276 L F
.37871 .55371 m .3787 .5537 L .37844 .55276 L F
.828 .508 .448 r
.37869 .5537 m .37798 .55367 L .37869 .5537 L F
.667 .8 .346 r
.37797 .55372 m .37798 .55367 L .37815 .55334 L F
.828 .508 .448 r
.37815 .55334 m .37798 .55367 L .37869 .5537 L F
.894 .709 .645 r
.37834 .5524 m .3787 .5537 L .37811 .55372 L F
.3787 .5537 m .37869 .5537 L .37811 .55372 L F
.726 .62 .739 r
.38186 .5545 m .37856 .55253 L .38035 .55174 L F
.37856 .55253 m .37834 .5524 L .37867 .55229 L F
.37856 .55253 m .37867 .55229 L .38035 .55174 L F
.745 .661 .767 r
.37841 .55371 m .38186 .5545 L .37897 .55377 L F
.37822 .55372 m .38186 .5545 L .37841 .55371 L F
.726 .62 .739 r
.37856 .55253 m .37844 .55276 L .37834 .5524 L F
.38186 .5545 m .37844 .55276 L .37856 .55253 L F
.205 .152 .572 r
.3807 .54859 m .38231 .54854 L .37985 .54559 L F
.466 .016 .097 r
.37985 .54559 m .38079 .54767 L .37518 .54765 L F
.468 .739 .987 r
.37518 .54765 m .38079 .54767 L .37649 .54594 L F
.843 .583 .545 r
.37667 .54333 m .38079 .54767 L .37822 .54663 L F
.37663 .54395 m .37822 .54663 L .37649 .54594 L F
.37667 .54333 m .37822 .54663 L .37663 .54395 L F
.533 .485 .748 r
.38081 .5476 m .38084 .54786 L .3797 .54914 L F
.37964 .54905 m .3797 .54914 L .37836 .55065 L F
.38081 .5476 m .3797 .54914 L .37964 .54905 L F
0 .376 .716 r
.38079 .54767 m .38081 .5476 L .37649 .54594 L F
.174 0 .211 r
.3807 .54859 m .37959 .55057 L .38231 .54854 L F
.828 .508 .448 r
.37959 .55057 m .38358 .55394 L .38194 .54996 L F
.647 .65 .839 r
.38231 .54854 m .37959 .55057 L .38194 .54996 L F
.533 .485 .748 r
.38084 .54786 m .38115 .55066 L .37949 .55065 L F
.38084 .54786 m .37949 .55065 L .37836 .55065 L F
.745 .661 .767 r
.38228 .55387 m .38286 .55417 L .38358 .55394 L F
.667 .8 .346 r
.37884 .55214 m .37959 .55057 L .37784 .55163 L F
.37884 .55214 m .37784 .55163 L .37637 .55252 L F
.081 .242 .73 r
.3707 .60747 m .37118 .60884 L .37237 .60896 L F
.313 .568 .93 r
.36307 .52564 m .36289 .52971 L .36125 .52914 L F
.36307 .52564 m .3651 .53018 L .36289 .52971 L F
.796 .821 .344 r
.61544 .43396 m .61562 .43237 L .61658 .42967 L F
.98 .89 .539 r
.61658 .42967 m .61562 .43237 L .61528 .43058 L F
0 0 .53 r
.61686 .43452 m .6157 .43164 L .61562 .43237 L F
.6157 .43164 m .61528 .43058 L .61562 .43237 L F
.796 .821 .344 r
.61539 .43414 m .61562 .43237 L .61544 .43396 L F
.411 .383 .717 r
.61346 .43577 m .61562 .43237 L .61539 .43414 L F
.071 .029 .498 r
.35149 .58366 m .35248 .57923 L .35285 .58007 L F
.636 .714 .904 r
.34033 .65983 m .34174 .66258 L .34506 .66102 L F
.395 .371 .714 r
.38724 .60795 m .38857 .605 L .38616 .60547 L F
.38724 .60795 m .38965 .60901 L .38857 .605 L F
.323 .049 .333 r
.31035 .59624 m .31293 .59575 L .31321 .5927 L F
.113 0 .336 r
.31321 .5927 m .31526 .59186 L .31585 .5895 L F
.474 .303 .568 r
.31293 .59575 m .31526 .59186 L .31321 .5927 L F
.596 .736 .942 r
.37661 .5942 m .37466 .59541 L .37216 .59268 L F
.754 .632 .725 r
.39017 .69551 m .39279 .69572 L .39344 .69381 L F
.756 .536 .598 r
.392 .69774 m .39279 .69572 L .39017 .69551 L F
.661 .54 .706 r
.39279 .69572 m .39656 .69565 L .39515 .69194 L F
.653 .458 .607 r
.39503 .69758 m .39279 .69572 L .392 .69774 L F
.39503 .69758 m .39656 .69565 L .39279 .69572 L F
.42 .81 .578 r
.30299 .55855 m .30104 .55994 L .29976 .56088 L F
.317 0 0 r
.30552 .55858 m .30104 .55994 L .30299 .55855 L F
.07 .534 .899 r
.60732 .37019 m .60859 .36965 L .60634 .36875 L F
.60732 .37019 m .61028 .37094 L .60859 .36965 L F
.71 .894 .518 r
.28248 .62841 m .28281 .6276 L .28438 .62562 L F
.15 0 0 r
.28438 .62562 m .28518 .62682 L .28662 .62551 L F
.28438 .62562 m .28281 .6276 L .28518 .62682 L F
.754 .921 .946 r
.62852 .40488 m .62758 .40426 L .63021 .40363 L F
.523 .919 .87 r
.63589 .40157 m .63401 .40241 L .63411 .4043 L F
.63401 .40241 m .62852 .40488 L .63411 .4043 L F
.49 .8 .999 r
.63021 .40363 m .63411 .4043 L .62852 .40488 L F
.163 .045 .461 r
.63316 .41001 m .63419 .40567 L .6353 .40805 L F
.63382 .4096 m .6353 .40805 L .63553 .40854 L F
.63316 .41001 m .6353 .40805 L .63382 .4096 L F
0 0 0 r
.62629 .41388 m .63256 .41096 L .62961 .41131 L F
.808 .967 .907 r
.63245 .41104 m .63433 .40777 L .63227 .41018 L F
.63246 .41111 m .63258 .4109 L .63245 .41104 L F
.63258 .4109 m .63433 .40777 L .63245 .41104 L F
.793 .514 .515 r
.6343 .40775 m .63411 .4043 L .63021 .40363 L F
.63433 .40777 m .63411 .4043 L .6343 .40775 L F
.535 .352 .58 r
.37764 .5834 m .37776 .58631 L .37294 .58707 L F
.971 .692 .444 r
.38821 .64448 m .39019 .64494 L .3914 .64418 L F
.38821 .64448 m .38785 .64808 L .39019 .64494 L F
0 .053 .612 r
.2358 .61575 m .23763 .6182 L .23629 .6142 L F
.732 .573 0 r
.38068 .56237 m .38078 .56286 L .38246 .56144 L F
.021 0 0 r
.29052 .62783 m .29366 .62523 L .29111 .62568 L F
.439 .272 .556 r
.3179 .58068 m .32013 .58008 L .32013 .57728 L F
.125 .018 .45 r
.3179 .58068 m .31928 .58229 L .32013 .58008 L F
.3179 .58068 m .31794 .58331 L .31928 .58229 L F
.462 .451 .759 r
.44064 .50413 m .44371 .50587 L .44147 .50633 L F
.609 .555 .769 r
.44371 .50587 m .44207 .51057 L .44147 .50633 L F
.899 .568 .412 r
.71077 .31085 m .71255 .30963 L .70975 .30904 L F
.71077 .31085 m .7128 .31228 L .71255 .30963 L F
.347 .197 .53 r
.29761 .63373 m .29569 .63177 L .29845 .631 L F
.29761 .63373 m .2956 .6344 L .29569 .63177 L F
.997 .815 .537 r
.41679 .58363 m .4155 .58581 L .41593 .58274 L F
.41679 .58363 m .41677 .58678 L .4155 .58581 L F
.805 .834 .874 r
.39017 .69551 m .39344 .69381 L .39124 .69205 L F
.822 .834 .857 r
.39344 .69381 m .39515 .69194 L .39124 .69205 L F
.543 .359 .582 r
.58511 .43647 m .58225 .43713 L .58482 .43389 L F
.58511 .43647 m .58225 .43713 L .58482 .43389 L F
.683 .688 .848 r
.39356 .6019 m .39242 .60301 L .39059 .59883 L F
.477 .482 .784 r
.44872 .5317 m .44765 .53608 L .44648 .5321 L F
.44872 .5317 m .44995 .53581 L .44765 .53608 L F
.467 .445 .75 r
.45063 .53791 m .44765 .53608 L .44995 .53581 L F
.773 .685 .767 r
.31415 .62803 m .3157 .63172 L .31159 .63127 L F
.684 .235 .178 r
.31159 .63127 m .3157 .63172 L .31384 .63343 L F
0 .093 .648 r
.31607 .63078 m .3157 .63172 L .31415 .62803 L F
.378 .76 .99 r
.31841 .63134 m .3157 .63172 L .31607 .63078 L F
.31607 .63078 m .3157 .63172 L .31841 .63134 L F
.699 .924 .597 r
.31384 .63343 m .3157 .63172 L .31607 .63078 L F
.378 .76 .99 r
.31841 .63134 m .3157 .63172 L .31607 .63078 L F
.799 .923 .919 r
.70971 .34053 m .70801 .34187 L .70864 .33909 L F
.826 .946 .9 r
.70864 .33909 m .70801 .34187 L .70708 .34071 L F
.812 .631 .657 r
.53936 .43694 m .53531 .43695 L .53522 .4343 L F
.874 .762 .735 r
.53936 .43694 m .53519 .43913 L .53531 .43695 L F
.53936 .43694 m .53786 .44079 L .53519 .43913 L F
.609 .179 0 r
.31811 .65913 m .31898 .66042 L .31733 .65905 L F
.244 .122 .508 r
.31898 .66042 m .31967 .65977 L .31733 .65905 L F
.285 0 0 r
.31601 .65892 m .31733 .65905 L .31967 .65977 L F
.31531 .65876 m .31733 .65905 L .31601 .65892 L F
.609 .179 0 r
.31682 .6572 m .31811 .65913 L .31733 .65905 L F
.244 .122 .508 r
.31898 .66042 m .32085 .66277 L .31967 .65977 L F
.31898 .66042 m .31891 .66332 L .32085 .66277 L F
.767 .8 .88 r
.64967 .3957 m .6461 .39568 L .64797 .39386 L F
.862 .946 .87 r
.65095 .39236 m .64967 .3957 L .64797 .39386 L F
.65095 .39236 m .65255 .39283 L .64967 .3957 L F
.607 .811 .402 r
.586 .42446 m .58371 .42797 L .58509 .42585 L F
.618 .468 .656 r
.6545 .38634 m .65721 .38298 L .65343 .38287 L F
.6545 .38634 m .65684 .38582 L .65721 .38298 L F
.161 .154 .601 r
.6545 .38634 m .65712 .38776 L .65684 .38582 L F
.6545 .38634 m .65479 .38919 L .65712 .38776 L F
.525 .9 .717 r
.29231 .64742 m .29499 .64556 L .29325 .64641 L F
0 0 0 r
.292 .64842 m .29231 .64742 L .29325 .64641 L F
.293 .227 .609 r
.35858 .52604 m .35899 .53061 L .35771 .52984 L F
.307 .163 .516 r
.3587 .53189 m .35771 .52984 L .35899 .53061 L F
.3587 .53189 m .35712 .53334 L .35771 .52984 L F
.642 .658 .851 r
.38567 .66897 m .38426 .67256 L .38287 .66947 L F
.269 .201 .593 r
.38648 .67516 m .38504 .67668 L .38426 .67256 L F
.919 .777 .297 r
.62209 .44205 m .62257 .44402 L .62277 .4403 L F
.926 .774 .297 r
.62235 .43904 m .62209 .44205 L .62277 .4403 L F
.783 .983 .721 r
.29464 .55188 m .29207 .55395 L .29207 .5548 L F
0 0 .16 r
.29656 .54829 m .29611 .55111 L .29464 .55188 L F
0 0 0 r
.29611 .55111 m .29207 .55395 L .29464 .55188 L F
.522 .37 .616 r
.32993 .596 m .32706 .59321 L .33057 .59408 L F
.32993 .596 m .32739 .59672 L .32706 .59321 L F
.165 .272 .73 r
.28118 .64086 m .28196 .64437 L .28282 .64425 L F
.16 .235 .693 r
.28282 .64425 m .28196 .64437 L .28419 .64659 L F
.522 .457 .724 r
.321 .68962 m .32243 .69171 L .32136 .68687 L F
.734 .604 .711 r
.55795 .45999 m .56025 .45911 L .55774 .46252 L F
.679 .847 .963 r
.27292 .56474 m .27457 .56533 L .2739 .56222 L F
.27292 .56474 m .2739 .56222 L .27013 .56116 L F
.827 .539 .502 r
.26988 .56361 m .27292 .56474 L .27013 .56116 L F
.587 .237 .342 r
.26988 .56361 m .27193 .56525 L .27292 .56474 L F
.435 .183 .431 r
.27193 .56525 m .2741 .56309 L .27292 .56474 L F
0 0 .154 r
.27398 .56257 m .27416 .5634 L .2739 .56222 L F
.27416 .5634 m .2742 .56363 L .2739 .56222 L F
.27416 .5634 m .27457 .56533 L .2742 .56363 L F
.771 .839 .904 r
.27398 .56257 m .27457 .56533 L .27292 .56474 L F
0 0 .154 r
.27398 .56257 m .27452 .56267 L .27292 .56474 L F
.435 .183 .431 r
.2741 .56309 m .27452 .56267 L .27412 .56319 L F
.2741 .56309 m .27412 .56319 L .27292 .56474 L F
.512 0 0 r
.37388 .57789 m .3745 .57882 L .37209 .57926 L F
.37388 .57789 m .37685 .57999 L .3745 .57882 L F
.336 .818 .854 r
.28589 .51695 m .28434 .51816 L .28195 .51722 L F
0 0 0 r
.29022 .51472 m .28874 .51546 L .28678 .51689 L F
.783 .989 .751 r
.28874 .51546 m .28721 .51734 L .28589 .51695 L F
0 0 0 r
.28716 .5167 m .28678 .51689 L .2861 .51738 L F
.29022 .51472 m .28678 .51689 L .28716 .5167 L F
.336 .818 .854 r
.28452 .51801 m .28721 .51734 L .28434 .51816 L F
.28589 .51695 m .28637 .51709 L .28452 .51801 L F
.28637 .51709 m .28721 .51734 L .28452 .51801 L F
.113 0 0 r
.30031 .54573 m .29883 .54766 L .29656 .54829 L F
.246 0 .149 r
.30237 .54403 m .29883 .54766 L .30031 .54573 L F
.772 .832 .898 r
.42218 .48174 m .41945 .48452 L .41703 .48349 L F
.123 .31 .78 r
.53994 .41908 m .53972 .42111 L .53776 .4172 L F
.162 .35 .803 r
.54123 .42192 m .53972 .42111 L .53994 .41908 L F
.721 .594 .713 r
.62472 .38895 m .62975 .3898 L .6262 .39346 L F
.818 .408 0 r
.62975 .3898 m .62741 .38565 L .62836 .38855 L F
.964 .852 .682 r
.62877 .39217 m .62975 .3898 L .62836 .38855 L F
0 0 .576 r
.33999 .52192 m .34165 .52608 L .34229 .5233 L F
.165 0 .088 r
.27581 .55788 m .27771 .55716 L .27917 .55459 L F
.425 .021 .167 r
.27771 .55716 m .282 .5545 L .27917 .55459 L F
.962 .643 .25 r
.41677 .58678 m .41578 .58823 L .4155 .58581 L F
.41677 .58678 m .41647 .5879 L .41578 .58823 L F
.403 .376 .715 r
.72734 .34123 m .72774 .34461 L .73017 .34309 L F
.021 0 .078 r
.73017 .34309 m .72774 .34461 L .72781 .34599 L F
.552 .631 .884 r
.31945 .62195 m .32072 .62417 L .32333 .62338 L F
.553 .299 .485 r
.3075 .54871 m .31027 .55094 L .30979 .54728 L F
.3075 .54871 m .30773 .55216 L .31027 .55094 L F
.377 .23 .551 r
.32969 .55777 m .33167 .55743 L .33163 .55474 L F
.602 .565 .785 r
.28905 .60267 m .28637 .60354 L .28645 .60131 L F
.606 .581 .799 r
.28506 .59994 m .28637 .60354 L .28905 .60267 L F
.578 .48 .707 r
.28637 .60354 m .28908 .60524 L .28905 .60267 L F
.28905 .60267 m .28908 .60524 L .28637 .60354 L F
0 0 0 r
.43935 .55791 m .4401 .55414 L .43796 .55382 L F
.579 .191 .271 r
.43094 .58783 m .43004 .58413 L .42939 .58659 L F
.749 .665 .768 r
.65328 .36938 m .65716 .36997 L .65584 .36629 L F
.761 .671 .762 r
.65584 .36629 m .65716 .36997 L .6597 .36672 L F
.694 .57 .711 r
.65716 .36997 m .6613 .37027 L .6597 .36672 L F
.66 .498 .654 r
.65836 .37322 m .6613 .37027 L .65716 .36997 L F
0 0 .159 r
.37238 .66394 m .37247 .66073 L .3684 .66062 L F
.953 .75 .591 r
.53835 .4439 m .53659 .44395 L .53786 .44079 L F
.879 .596 .504 r
.53835 .4439 m .53645 .4458 L .53659 .44395 L F
.53835 .4439 m .54016 .44687 L .53645 .4458 L F
0 0 0 r
.25843 .56772 m .25881 .56804 L .26078 .56697 L F
.484 .746 .987 r
.26338 .61814 m .26271 .6201 L .26154 .6181 L F
.26338 .61814 m .26549 .61987 L .26271 .6201 L F
.855 .997 .793 r
.29737 .55726 m .29677 .55864 L .29705 .55655 L F
.87 .986 .713 r
.29677 .55864 m .29479 .55991 L .29705 .55655 L F
.63 .578 .777 r
.33683 .56422 m .33445 .56621 L .33288 .56107 L F
0 0 .328 r
.61158 .38923 m .6131 .38684 L .61298 .38722 L F
.121 .205 .678 r
.61355 .39131 m .61158 .38923 L .61298 .38722 L F
0 0 .211 r
.21557 .55745 m .21766 .5542 L .21621 .5551 L F
.21557 .55745 m .21711 .55668 L .21766 .5542 L F
0 0 0 r
.21557 .55745 m .21435 .55964 L .21711 .55668 L F
.662 .43 .558 r
.40043 .67279 m .40384 .66995 L .40352 .66898 L F
.459 0 0 r
.36859 .59275 m .36967 .59357 L .36826 .59258 L F
.499 .441 .723 r
.44304 .50345 m .44371 .50587 L .44064 .50413 L F
.597 .806 .98 r
.3744 .54229 m .37589 .54236 L .37459 .54089 L F
.09 0 0 r
.3744 .54229 m .37416 .54389 L .37589 .54236 L F
.262 .739 .936 r
.39633 .6439 m .39819 .64444 L .39416 .64394 L F
.995 .784 .51 r
.37589 .54236 m .37416 .54389 L .37459 .54089 L F
0 0 .541 r
.39941 .64526 m .39819 .64444 L .39633 .6439 L F
.928 .672 .189 r
.2578 .57296 m .25677 .5721 L .25653 .5691 L F
0 0 .533 r
.25696 .5751 m .25677 .5721 L .2578 .57296 L F
.286 .093 .434 r
.34081 .5673 m .34118 .56476 L .34275 .56458 L F
.34081 .5673 m .34118 .56476 L .34275 .56458 L F
0 0 0 r
.33384 .58014 m .33494 .57934 L .33691 .5772 L F
.408 0 .118 r
.33546 .57877 m .33898 .57629 L .33691 .5772 L F
.33599 .57854 m .33898 .57629 L .33546 .57877 L F
.33494 .57934 m .33758 .57877 L .33898 .57629 L F
.59 .487 .705 r
.33959 .57467 m .33815 .57761 L .33731 .57578 L F
.33815 .57761 m .33758 .57877 L .3375 .57789 L F
.33815 .57761 m .3375 .57789 L .33731 .57578 L F
.408 0 .118 r
.33494 .57934 m .33599 .57854 L .33546 .57877 L F
.552 .291 .475 r
.43934 .59329 m .43664 .59602 L .43674 .59343 L F
.765 .885 .931 r
.40955 .49424 m .40933 .49756 L .41203 .49713 L F
.40955 .49424 m .4069 .49714 L .40933 .49756 L F
.75 .231 0 r
.40434 .4935 m .40406 .4941 L .40154 .49126 L F
0 0 0 r
.4063 .49292 m .40406 .4941 L .40434 .4935 L F
.4063 .49292 m .40406 .4941 L .40434 .4935 L F
.443 0 .002 r
.29507 .64324 m .29608 .64099 L .29319 .64373 L F
.29507 .64324 m .29743 .64105 L .29608 .64099 L F
.588 .304 .454 r
.58153 .46393 m .57747 .46334 L .58118 .46252 L F
.53 .231 .405 r
.58118 .46252 m .58404 .46393 L .58153 .46393 L F
.58118 .46252 m .58393 .46217 L .58404 .46393 L F
0 0 .026 r
.65479 .38919 m .65255 .39283 L .65394 .39105 L F
.814 .954 .908 r
.65394 .39105 m .65255 .39283 L .65095 .39236 L F
.605 .891 .588 r
.30465 .54173 m .30237 .54403 L .30349 .54297 L F
.511 .523 .805 r
.30427 .66837 m .30738 .67051 L .3058 .66838 L F
.482 .328 .596 r
.67184 .39208 m .67203 .39486 L .66951 .39546 L F
.314 .158 .503 r
.67162 .397 m .66951 .39546 L .67203 .39486 L F
.67162 .397 m .6697 .39835 L .66951 .39546 L F
.614 .818 .978 r
.5767 .41416 m .58074 .41463 L .57954 .41316 L F
.962 .651 .247 r
.57954 .41316 m .58074 .41463 L .58111 .41775 L F
.951 .685 .498 r
.29874 .53916 m .29675 .5383 L .29723 .53584 L F
.739 .632 .741 r
.30129 .53592 m .29874 .53916 L .29723 .53584 L F
.881 .977 .835 r
.60478 .38035 m .60417 .38331 L .6018 .38389 L F
.714 .402 .449 r
.36193 .67905 m .36456 .67905 L .36204 .67621 L F
.626 .405 .563 r
.36456 .67905 m .36538 .67618 L .36204 .67621 L F
.711 .575 .7 r
.67531 .36057 m .67521 .36374 L .67868 .36058 L F
.477 .22 .444 r
.67554 .3659 m .67868 .36058 L .67521 .36374 L F
.67554 .3659 m .67825 .36532 L .67868 .36058 L F
.592 .404 .596 r
.67868 .36058 m .68129 .36186 L .68156 .3597 L F
.344 .003 .234 r
.67825 .36532 m .68129 .36186 L .67868 .36058 L F
.868 .915 .859 r
.3859 .62439 m .3902 .62215 L .38788 .62192 L F
.898 .927 .829 r
.68976 .29786 m .69087 .29923 L .68831 .30231 L F
.863 .927 .868 r
.69368 .296 m .69087 .29923 L .68976 .29786 L F
.349 .241 .587 r
.32442 .56739 m .32683 .56674 L .32654 .56388 L F
.369 .114 .39 r
.32442 .56739 m .32664 .56934 L .32683 .56674 L F
.32442 .56739 m .32418 .57015 L .32664 .56934 L F
.699 .64 .787 r
.65595 .37959 m .65949 .37997 L .65856 .37636 L F
.67 .513 .664 r
.65721 .38298 m .65949 .37997 L .65595 .37959 L F
.65721 .38298 m .65962 .38231 L .65949 .37997 L F
.604 .517 .729 r
.65949 .37997 m .66128 .37555 L .65856 .37636 L F
.65949 .37997 m .66185 .37902 L .66128 .37555 L F
.129 .097 .55 r
.65949 .37997 m .66185 .38121 L .66185 .37902 L F
.65949 .37997 m .65962 .38231 L .66185 .38121 L F
.49 .423 .709 r
.45063 .53791 m .45124 .54213 L .44899 .54251 L F
.93 .882 .764 r
.38358 .5076 m .38353 .50372 L .38501 .50494 L F
.768 .897 .933 r
.38704 .50352 m .38501 .50494 L .38353 .50372 L F
.728 .948 .643 r
.3662 .66243 m .3684 .66062 L .36622 .66323 L F
.561 .013 0 r
.36979 .66224 m .3684 .66062 L .3662 .66243 L F
.306 .767 .947 r
.36832 .66151 m .3662 .66243 L .36557 .661 L F
.911 .911 .806 r
.36822 .66192 m .36994 .66109 L .36836 .66134 L F
.306 .767 .947 r
.36851 .66155 m .36829 .66163 L .36832 .66151 L F
.36829 .66163 m .3662 .66243 L .36832 .66151 L F
.911 .911 .806 r
.36836 .66134 m .36994 .66109 L .36983 .66013 L F
.526 .817 .999 r
.36849 .66366 m .36979 .66224 L .3662 .66243 L F
.911 .911 .806 r
.36845 .66181 m .36979 .66224 L .36994 .66109 L F
.306 .767 .947 r
.36868 .66188 m .36979 .66224 L .36887 .66229 L F
.36829 .66163 m .36887 .66229 L .3662 .66243 L F
.032 0 0 r
.3662 .66243 m .36979 .66224 L .36683 .6626 L F
.911 .911 .806 r
.36683 .6626 m .36979 .66224 L .36845 .66181 L F
.306 .767 .947 r
.36851 .66155 m .36979 .66224 L .36868 .66188 L F
.36851 .66155 m .36887 .66229 L .36829 .66163 L F
.911 .911 .806 r
.36683 .6626 m .36822 .66192 L .36829 .66163 L F
.36817 .66149 m .36829 .66163 L .36836 .66134 L F
.36683 .6626 m .36829 .66163 L .36824 .66157 L F
.492 .193 .385 r
.36683 .6626 m .36851 .66155 L .36832 .66151 L F
.36683 .6626 m .36832 .66151 L .36557 .661 L F
.911 .911 .806 r
.36683 .6626 m .36824 .66157 L .36817 .66149 L F
.032 0 0 r
.3662 .66243 m .36683 .6626 L .36618 .66178 L F
.3662 .66243 m .36618 .66178 L .36557 .661 L F
.728 .948 .643 r
.3662 .66243 m .36622 .66323 L .36568 .66388 L F
.993 .745 .436 r
.36507 .66719 m .36568 .66388 L .36458 .66503 L F
.36 .715 .987 r
.3662 .66243 m .36568 .66388 L .36849 .66366 L F
.29 .168 .536 r
.36879 .66669 m .36568 .66388 L .36849 .66366 L F
.615 .232 .294 r
.35478 .557 m .35225 .55503 L .35538 .55495 L F
.664 .406 .52 r
.35478 .557 m .3577 .55445 L .35538 .55495 L F
.35478 .557 m .3577 .55445 L .35538 .55495 L F
0 0 0 r
.25678 .52944 m .25424 .53061 L .25233 .53119 L F
.461 .869 .713 r
.25802 .52839 m .25678 .52944 L .25944 .52944 L F
.25802 .52839 m .25424 .53061 L .25678 .52944 L F
.594 .392 .577 r
.6855 .37648 m .68603 .37984 L .68201 .37934 L F
.558 .416 .644 r
.68603 .37984 m .68306 .38312 L .68201 .37934 L F
0 .063 .579 r
.33359 .68987 m .33446 .69454 L .33298 .69206 L F
.574 .177 .252 r
.33446 .69454 m .33652 .69573 L .33565 .69609 L F
.942 .649 .193 r
.33392 .69602 m .33318 .69287 L .33446 .69454 L F
.863 .863 .837 r
.33225 .69581 m .33392 .69602 L .33446 .69454 L F
.574 .177 .252 r
.33446 .69454 m .33565 .69609 L .33302 .69716 L F
.942 .649 .193 r
.33318 .69287 m .33298 .69206 L .33446 .69454 L F
.335 .771 .968 r
.62241 .39317 m .6262 .39346 L .62492 .39193 L F
.724 .794 .907 r
.6262 .39346 m .62747 .39035 L .62492 .39193 L F
.6262 .39346 m .62877 .39217 L .62747 .39035 L F
0 .265 .671 r
.38231 .54854 m .38079 .54767 L .37985 .54559 L F
.676 .346 .407 r
.35351 .54433 m .34792 .54393 L .35293 .54162 L F
.712 .631 .765 r
.35492 .53891 m .35293 .54162 L .35167 .5396 L F
.103 0 .253 r
.35492 .53891 m .35404 .5413 L .35293 .54162 L F
.727 .7 .162 r
.35404 .5413 m .35351 .54433 L .35293 .54162 L F
.103 0 .253 r
.35492 .53891 m .35404 .5413 L .35293 .54162 L F
.228 0 0 r
.3925 .64496 m .3914 .64418 L .39019 .64494 L F
.3925 .64496 m .39416 .64394 L .3914 .64418 L F
0 .063 .626 r
.28521 .64802 m .2867 .64873 L .28419 .64659 L F
.28521 .64802 m .2869 .65019 L .2867 .64873 L F
.835 .93 .893 r
.29957 .51309 m .29665 .51417 L .29835 .51299 L F
.677 .939 .965 r
.30306 .51136 m .29957 .51309 L .30023 .51122 L F
.758 .994 .865 r
.30023 .51122 m .29957 .51309 L .29835 .51299 L F
.712 .666 .803 r
.43523 .48111 m .43296 .48359 L .43238 .48197 L F
.322 .054 .342 r
.34337 .57991 m .34055 .58287 L .341 .5806 L F
.908 .749 .673 r
.61898 .44455 m .62257 .44402 L .62209 .44205 L F
.61898 .44455 m .62051 .44619 L .62257 .44402 L F
.877 .521 .369 r
.62282 .44579 m .62257 .44402 L .62051 .44619 L F
.858 .793 .786 r
.39831 .66863 m .39995 .67167 L .40352 .66898 L F
.662 .43 .558 r
.40043 .67279 m .40352 .66898 L .39995 .67167 L F
.533 .551 .819 r
.40393 .66834 m .40069 .66537 L .40352 .66898 L F
.565 .77 .975 r
.71707 .35493 m .71322 .35385 L .71614 .3528 L F
.521 .854 .996 r
.71635 .3533 m .71707 .35493 L .71614 .3528 L F
.71635 .3533 m .71973 .35429 L .71707 .35493 L F
.609 .555 .769 r
.44371 .50587 m .44474 .50985 L .44207 .51057 L F
.851 .893 .867 r
.71221 .28705 m .715 .28457 L .71149 .28389 L F
.738 .92 .953 r
.71149 .28389 m .715 .28457 L .71634 .28153 L F
.738 .336 0 r
.43501 .56992 m .43565 .57048 L .43492 .56975 L F
.171 .018 .417 r
.43745 .57163 m .43537 .57324 L .43565 .57048 L F
0 0 .167 r
.43657 .57325 m .43537 .57324 L .43745 .57163 L F
.43586 .57455 m .43571 .57415 L .43657 .57325 L F
.43571 .57415 m .43537 .57324 L .43657 .57325 L F
.738 .336 0 r
.43492 .56975 m .43494 .56976 L .43492 .5697 L F
.972 .768 .34 r
.43984 .57223 m .43586 .57455 L .43745 .57163 L F
.636 .736 .921 r
.43944 .56909 m .43745 .57163 L .43549 .57025 L F
.738 .336 0 r
.43492 .5697 m .43565 .57048 L .43471 .56863 L F
.544 .435 .68 r
.43554 .57024 m .43568 .5702 L .43485 .56946 L F
.43775 .572 m .43779 .57196 L .43485 .56946 L F
.738 .336 0 r
.43494 .56976 m .43565 .57048 L .43492 .5697 L F
.544 .435 .68 r
.43498 .56986 m .4354 .57018 L .43492 .56975 L F
.171 .018 .417 r
.43745 .57163 m .43565 .57048 L .43501 .56992 L F
.43745 .57163 m .43501 .56992 L .43549 .57025 L F
.972 .768 .34 r
.43685 .57397 m .43889 .57354 L .43586 .57455 L F
.43984 .57223 m .43889 .57354 L .43685 .57397 L F
.711 .965 .714 r
.44182 .57377 m .43893 .57668 L .43953 .57523 L F
.44182 .57377 m .43953 .57523 L .43984 .57223 L F
.972 .768 .34 r
.43984 .57223 m .43953 .57523 L .43889 .57354 L F
.381 .231 .549 r
.43889 .57354 m .4407 .57479 L .44077 .57315 L F
0 0 .473 r
.43985 .56718 m .44099 .56925 L .44097 .5689 L F
.44099 .56925 m .44178 .57068 L .44097 .5689 L F
.981 .912 .627 r
.44097 .5689 m .43944 .56909 L .44093 .56834 L F
0 0 .577 r
.43985 .56718 m .44097 .5689 L .44134 .56814 L F
.981 .912 .627 r
.44097 .5689 m .44093 .56834 L .44134 .56814 L F
.949 .684 .5 r
.44178 .57068 m .43984 .57223 L .44097 .5689 L F
.44178 .57068 m .44182 .57377 L .43984 .57223 L F
.981 .912 .627 r
.44097 .5689 m .43984 .57223 L .43944 .56909 L F
.636 .736 .921 r
.43944 .56909 m .43984 .57223 L .43745 .57163 L F
.381 .231 .549 r
.43889 .57354 m .44077 .57315 L .4409 .57005 L F
.544 .435 .68 r
.4354 .57018 m .43912 .5731 L .43591 .57054 L F
.4354 .57018 m .43591 .57054 L .43492 .56975 L F
.547 .374 .597 r
.4354 .57018 m .43889 .57354 L .43912 .5731 L F
.43498 .56986 m .43514 .57001 L .4354 .57018 L F
.43514 .57001 m .43889 .57354 L .4354 .57018 L F
.171 .018 .417 r
.43549 .57025 m .4354 .57018 L .43495 .56986 L F
.4354 .57018 m .43501 .56992 L .435 .56992 L F
.547 .374 .597 r
.43503 .56997 m .43889 .57354 L .43498 .56986 L F
.171 .018 .417 r
.4354 .57018 m .435 .56992 L .43495 .56986 L F
.544 .435 .68 r
.43485 .56946 m .43912 .5731 L .43944 .56909 L F
.636 .736 .921 r
.43944 .56909 m .43549 .57025 L .43495 .56986 L F
.544 .435 .68 r
.43492 .56975 m .43554 .57024 L .43485 .56946 L F
.43554 .57024 m .43775 .572 L .43568 .5702 L F
.43775 .572 m .43912 .5731 L .43779 .57196 L F
.547 .374 .597 r
.43451 .56949 m .43503 .56997 L .43498 .56986 L F
.544 .435 .68 r
.43495 .56983 m .43498 .56986 L .43492 .56975 L F
.738 .336 0 r
.43495 .56986 m .43501 .56992 L .43492 .56975 L F
.544 .435 .68 r
.43451 .56949 m .43495 .56983 L .43485 .56946 L F
.738 .336 0 r
.43485 .56946 m .43471 .56863 L .43429 .5672 L F
.43495 .56986 m .43492 .56975 L .43485 .56946 L F
.43492 .56975 m .43471 .56863 L .43485 .56946 L F
.544 .435 .68 r
.43451 .56949 m .43485 .56946 L .43495 .56986 L F
.43485 .56946 m .43944 .56909 L .43495 .56986 L F
.738 .336 0 r
.43495 .56986 m .43429 .5672 L .43425 .56708 L F
.676 .944 .676 r
.42499 .59077 m .42626 .59016 L .42732 .5885 L F
.031 .146 .652 r
.42626 .59016 m .42815 .59239 L .42732 .5885 L F
.7 .869 .962 r
.40198 .48856 m .40154 .49126 L .4045 .48886 L F
.40198 .48856 m .39976 .49017 L .40154 .49126 L F
.056 .225 .722 r
.40154 .49126 m .40198 .48856 L .39976 .49017 L F
.40154 .49126 m .40406 .4941 L .40198 .48856 L F
.072 0 0 r
.26914 .57105 m .26706 .57247 L .26472 .573 L F
0 0 0 r
.27094 .56961 m .26914 .57105 L .27169 .56793 L F
.26946 .57133 m .26914 .57105 L .27094 .56961 L F
.26946 .57133 m .26706 .57247 L .26914 .57105 L F
.382 0 0 r
.29115 .65735 m .29164 .65894 L .2893 .65626 L F
.29115 .65735 m .2937 .6574 L .29164 .65894 L F
.361 .204 .529 r
.29633 .62154 m .29835 .61816 L .2963 .6188 L F
.552 .4 .629 r
.68808 .37548 m .68603 .37984 L .6855 .37648 L F
.34 .695 .982 r
.3523 .68038 m .34891 .67929 L .3523 .67843 L F
.274 .372 .782 r
.35372 .67834 m .3523 .68038 L .3523 .67843 L F
.35372 .67834 m .35513 .6819 L .3523 .68038 L F
.33 0 .156 r
.36172 .51928 m .35729 .52268 L .35729 .51965 L F
.27 0 0 r
.36439 .52045 m .35967 .52225 L .36172 .51928 L F
.501 .278 .508 r
.28332 .56413 m .28069 .56737 L .281 .56468 L F
0 0 0 r
.58371 .42797 m .57955 .42958 L .58211 .42642 L F
.873 .899 .847 r
.58509 .42585 m .58371 .42797 L .58211 .42642 L F
.58211 .42642 m .58371 .42797 L .58509 .42585 L F
.283 .529 .911 r
.2083 .59617 m .20899 .59431 L .20807 .59221 L F
.2083 .59617 m .20946 .59598 L .20899 .59431 L F
0 .054 .611 r
.2083 .59617 m .21004 .5983 L .20946 .59598 L F
.051 0 .456 r
.20717 .59008 m .20831 .58927 L .20813 .58673 L F
0 0 .359 r
.20717 .59008 m .20807 .59221 L .20831 .58927 L F
.391 .33 .67 r
.2924 .615 m .29451 .61553 L .29439 .6117 L F
.434 .054 .217 r
.27169 .56793 m .27353 .56921 L .27094 .56961 L F
.193 .722 .74 r
.34317 .65743 m .34144 .65784 L .34033 .65983 L F
.312 .149 .493 r
.28797 .54885 m .28956 .55048 L .28958 .54786 L F
.28797 .54885 m .28785 .55128 L .28956 .55048 L F
.978 .746 .518 r
.32871 .54682 m .3306 .54551 L .32912 .54492 L F
.32871 .54682 m .3304 .54808 L .3306 .54551 L F
.736 .986 .78 r
.33293 .54321 m .33099 .54427 L .3306 .54551 L F
.52 .856 .995 r
.33099 .54427 m .32912 .54492 L .3306 .54551 L F
.978 .746 .518 r
.32871 .54682 m .3306 .54551 L .32912 .54492 L F
.32871 .54682 m .3304 .54808 L .3306 .54551 L F
.588 .304 .454 r
.58153 .46393 m .57746 .46535 L .57747 .46334 L F
.405 .15 .411 r
.38553 .60299 m .38786 .60254 L .38831 .59969 L F
.429 .171 .419 r
.38831 .59969 m .39022 .60208 L .39059 .59883 L F
.38831 .59969 m .38786 .60254 L .39022 .60208 L F
.799 .475 .441 r
.62612 .38207 m .62582 .37974 L .62202 .37901 L F
.865 .518 .393 r
.53645 .4458 m .54016 .44687 L .54044 .4488 L F
0 0 0 r
.25654 .54772 m .25876 .54463 L .2569 .54558 L F
.845 .594 .558 r
.33364 .50068 m .32981 .50257 L .33115 .49982 L F
.737 .587 .688 r
.65343 .38287 m .65721 .38298 L .65595 .37959 L F
.631 .54 .733 r
.6556 .37695 m .65595 .37959 L .65856 .37636 L F
0 0 .082 r
.65712 .38776 m .65479 .38919 L .65394 .39105 L F
.854 .746 .743 r
.57656 .39535 m .57235 .3976 L .57528 .39383 L F
.57656 .39535 m .57471 .39889 L .57235 .3976 L F
.265 .589 .947 r
.57749 .39403 m .57656 .39535 L .57528 .39383 L F
.57749 .39403 m .5788 .39586 L .57656 .39535 L F
.649 .582 .766 r
.37564 .52901 m .37158 .52527 L .3754 .52656 L F
.351 0 0 r
.33964 .50346 m .3361 .50231 L .33755 .50363 L F
.608 .893 .989 r
.61434 .39244 m .61563 .39371 L .61234 .39436 L F
.166 .617 .936 r
.61821 .39392 m .61563 .39371 L .61434 .39244 L F
.431 .151 .385 r
.4594 .58211 m .45728 .58044 L .45985 .57988 L F
.4594 .58211 m .45686 .5828 L .45728 .58044 L F
.454 .299 .581 r
.31938 .57476 m .32082 .57472 L .32188 .57103 L F
.404 .367 .703 r
.31938 .57476 m .3217 .57638 L .32082 .57472 L F
.31938 .57476 m .32013 .57728 L .3217 .57638 L F
.571 .722 .944 r
.35192 .68773 m .3513 .6916 L .35099 .68953 L F
.631 .818 .972 r
.57739 .44841 m .57457 .44943 L .57855 .44959 L F
.636 .188 .171 r
.57457 .44943 m .57719 .45134 L .57855 .44959 L F
.55 .784 .985 r
.57855 .44959 m .58126 .44931 L .57739 .44841 L F
.989 .745 .467 r
.57855 .44959 m .57719 .45134 L .57739 .44841 L F
.55 .784 .985 r
.57855 .44959 m .58126 .44931 L .57739 .44841 L F
.53 .255 .442 r
.44878 .58991 m .44567 .59258 L .44599 .59036 L F
.815 .676 .709 r
.55795 .45999 m .55774 .46252 L .55393 .4618 L F
.761 .338 .245 r
.55393 .4618 m .55774 .46252 L .55634 .46435 L F
.711 .274 .21 r
.55774 .46252 m .5603 .46496 L .55634 .46435 L F
.808 .626 .656 r
.29675 .5383 m .30348 .54085 L .29941 .53745 L F
.29675 .5383 m .29707 .54087 L .30348 .54085 L F
.153 0 0 r
.29735 .5442 m .30348 .54085 L .29707 .54087 L F
.29735 .5442 m .29995 .54364 L .30348 .54085 L F
.149 .252 .715 r
.30348 .54085 m .3037 .53806 L .29941 .53745 L F
.007 0 .493 r
.3061 .5374 m .30502 .54063 L .3037 .53806 L F
.30502 .54063 m .30465 .54173 L .3044 .54076 L F
.30502 .54063 m .3044 .54076 L .3037 .53806 L F
.3061 .5374 m .30626 .54042 L .30465 .54173 L F
.077 0 0 r
.30382 .54088 m .30225 .54298 L .30498 .541 L F
.30348 .54085 m .30342 .54097 L .30382 .54088 L F
.30342 .54097 m .30225 .54298 L .30382 .54088 L F
.149 .252 .715 r
.30348 .54085 m .30498 .541 L .3037 .53806 L F
.077 0 0 r
.30348 .54085 m .29995 .54364 L .30225 .54298 L F
.699 .62 .765 r
.39281 .70087 m .39503 .69758 L .392 .69774 L F
.329 .016 .273 r
.32182 .60259 m .31875 .6054 L .31925 .60297 L F
.839 .678 .682 r
.55242 .45299 m .54837 .45503 L .54831 .45271 L F
.55242 .45299 m .55192 .45575 L .54837 .45503 L F
.431 .843 .666 r
.30104 .55994 m .29799 .5618 L .29976 .56088 L F
.753 .609 .698 r
.65443 .35952 m .65848 .35759 L .65681 .35669 L F
.65443 .35952 m .65835 .36034 L .65848 .35759 L F
.74 .724 .836 r
.65848 .35759 m .65971 .35329 L .65681 .35669 L F
.862 .92 .867 r
.65471 .41724 m .65621 .41725 L .65525 .4162 L F
.863 .928 .868 r
.65621 .41725 m .65859 .41288 L .65525 .4162 L F
0 0 .147 r
.59212 .38359 m .59183 .38565 L .59175 .38294 L F
.59212 .38359 m .59175 .38294 L .58912 .38247 L F
.018 0 0 r
.64532 .42696 m .64339 .42697 L .64175 .42847 L F
.64532 .42696 m .64624 .42681 L .64339 .42697 L F
.122 .282 .755 r
.3037 .53806 m .30129 .53592 L .30384 .53537 L F
.695 .464 .569 r
.32638 .65077 m .3237 .65304 L .32204 .65091 L F
.32638 .65077 m .3265 .65391 L .3237 .65304 L F
.32638 .65077 m .32204 .65091 L .32539 .65289 L F
.525 .333 .562 r
.32638 .65077 m .32835 .65305 L .3265 .65391 L F
.759 .314 .195 r
.32539 .65289 m .32835 .65305 L .32638 .65077 L F
.767 .651 .734 r
.65584 .36629 m .6597 .36672 L .65865 .36323 L F
.725 .628 .749 r
.65865 .36323 m .6597 .36672 L .66229 .36344 L F
.452 .288 .568 r
.32977 .57747 m .32984 .58026 L .32769 .58075 L F
.516 .383 .638 r
.32984 .58026 m .32783 .58348 L .32769 .58075 L F
.093 0 .374 r
.20813 .56767 m .20995 .56658 L .21028 .56389 L F
.045 0 .361 r
.20783 .57047 m .20995 .56658 L .20813 .56767 L F
.815 .676 .709 r
.55795 .45999 m .55393 .4618 L .55395 .45908 L F
.027 .005 .492 r
.20711 .57684 m .20777 .57345 L .20697 .57413 L F
.932 .826 .373 r
.33031 .5946 m .32993 .596 L .33057 .59408 L F
.776 .758 .837 r
.62834 .36025 m .62585 .36337 L .62449 .35964 L F
.789 .633 .687 r
.62432 .44934 m .62819 .44985 L .62688 .44618 L F
.698 .586 .727 r
.62688 .44618 m .62819 .44985 L .63062 .44667 L F
.108 .276 .753 r
.38236 .57175 m .38289 .57432 L .38134 .57037 L F
.781 .934 .931 r
.57397 .40141 m .57105 .40379 L .56964 .40281 L F
.969 .787 .601 r
.53637 .41354 m .53776 .4172 L .53826 .41487 L F
0 .123 .595 r
.5875 .41734 m .59117 .42033 L .58869 .42123 L F
.2 .719 .69 r
.22963 .55837 m .22976 .55836 L .23188 .55659 L F
.22963 .55837 m .22728 .55904 L .22976 .55836 L F
.435 .072 .249 r
.36929 .54526 m .37202 .54501 L .3744 .54229 L F
.597 .806 .98 r
.3744 .54229 m .37459 .54089 L .37227 .54124 L F
.09 0 0 r
.3744 .54229 m .37202 .54501 L .37416 .54389 L F
.66 .498 .654 r
.65836 .37322 m .66113 .37301 L .6613 .37027 L F
0 0 .324 r
.33006 .61533 m .32892 .61563 L .33024 .61465 L F
.33006 .61533 m .32866 .619 L .32892 .61563 L F
.72 .629 .066 r
.32892 .61563 m .3288 .61659 L .33024 .61465 L F
.32892 .61563 m .32866 .619 L .3288 .61659 L F
.599 .546 .767 r
.44294 .48759 m .44067 .4905 L .44024 .48829 L F
.44294 .48759 m .44392 .49091 L .44067 .4905 L F
.459 .329 .616 r
.44392 .49091 m .44172 .49449 L .44067 .4905 L F
.735 .893 .951 r
.29456 .52044 m .29576 .52059 L .29587 .51958 L F
.29456 .52044 m .29443 .52249 L .29576 .52059 L F
.344 0 .198 r
.29845 .631 m .30136 .62865 L .30099 .63076 L F
.661 .395 .507 r
.30401 .62836 m .30099 .63076 L .30136 .62865 L F
.828 .8 .306 r
.62656 .42743 m .62743 .42244 L .62798 .42555 L F
0 0 .219 r
.62731 .42674 m .62656 .42743 L .62798 .42555 L F
.604 .578 .798 r
.63052 .43057 m .62656 .42743 L .62675 .4301 L F
0 0 .219 r
.62731 .42674 m .62675 .4301 L .62656 .42743 L F
.311 0 0 r
.35026 .57731 m .3484 .57895 L .34561 .57924 L F
.066 0 0 r
.35155 .57785 m .35026 .57731 L .35248 .57923 L F
.35155 .57785 m .3484 .57895 L .35026 .57731 L F
.844 .759 .769 r
.63569 .35285 m .63756 .35434 L .63536 .35763 L F
.819 .832 .859 r
.63889 .34984 m .63756 .35434 L .63569 .35285 L F
.63889 .34984 m .64047 .35147 L .63756 .35434 L F
.517 .776 .991 r
.25901 .6304 m .25982 .62959 L .25783 .63096 L F
.25901 .6304 m .26199 .6304 L .25982 .62959 L F
0 0 0 r
.30522 .52822 m .30489 .53212 L .30475 .53298 L F
.93 .741 .626 r
.30169 .53162 m .30475 .53298 L .30489 .53212 L F
.30169 .53162 m .30384 .53537 L .30475 .53298 L F
.925 .707 .588 r
.53786 .44079 m .53523 .44185 L .53519 .43913 L F
.53786 .44079 m .53659 .44395 L .53523 .44185 L F
.582 .84 .994 r
.29388 .51287 m .29341 .51517 L .29124 .51368 L F
.29388 .51287 m .29665 .51417 L .29341 .51517 L F
.372 0 0 r
.27842 .56812 m .27622 .56934 L .27353 .56921 L F
.207 0 0 r
.27973 .56862 m .27842 .56812 L .28069 .56737 L F
.27973 .56862 m .27622 .56934 L .27842 .56812 L F
.987 .898 .595 r
.71032 .28762 m .71221 .28705 L .71149 .28389 L F
.839 .423 .248 r
.72209 .34029 m .72336 .3381 L .72052 .33684 L F
0 0 0 r
.72519 .33632 m .72336 .3381 L .72209 .34029 L F
.338 0 .004 r
.65916 .38402 m .65721 .38298 L .65684 .38582 L F
.65916 .38402 m .65962 .38231 L .65721 .38298 L F
.519 .412 .672 r
.44397 .51429 m .44592 .51658 L .44335 .51709 L F
.589 .551 .779 r
.44691 .5198 m .44335 .51709 L .44592 .51658 L F
.676 .346 .407 r
.35351 .54433 m .34788 .54457 L .34792 .54393 L F
0 0 .347 r
.24657 .56633 m .24805 .57016 L .24726 .5684 L F
.346 .465 .839 r
.42817 .59476 m .42943 .59243 L .42669 .59748 L F
.42817 .59476 m .42669 .59748 L .42667 .59752 L F
.954 .662 .445 r
.4292 .59285 m .42817 .59476 L .42815 .59239 L F
.4302 .59328 m .42817 .59476 L .4292 .59285 L F
.782 .351 .225 r
.4302 .59328 m .43218 .59587 L .42817 .59476 L F
.43373 .5958 m .43218 .59587 L .4302 .59328 L F
.071 .029 .498 r
.35149 .58366 m .35297 .58263 L .35248 .57923 L F
.153 0 .109 r
.35149 .58366 m .3526 .58515 L .35297 .58263 L F
.35149 .58366 m .35064 .58602 L .3526 .58515 L F
.709 .302 .273 r
.24056 .61208 m .24279 .61448 L .24481 .61238 L F
.752 .359 .308 r
.24279 .61448 m .24659 .6152 L .24481 .61238 L F
.246 0 .2 r
.34841 .51462 m .3493 .51511 L .35193 .51246 L F
.459 .329 .616 r
.44392 .49091 m .44413 .49395 L .44172 .49449 L F
.627 .602 .805 r
.44413 .49395 m .44205 .49679 L .44172 .49449 L F
.902 .778 .714 r
.34528 .56173 m .34442 .5594 L .34415 .56163 L F
.34528 .56173 m .3421 .56116 L .34442 .5594 L F
.663 .469 .612 r
.34528 .56173 m .34309 .56763 L .34275 .56458 L F
.34528 .56173 m .34679 .56737 L .34309 .56763 L F
.278 .23 .623 r
.34894 .56551 m .34528 .56173 L .34828 .56287 L F
.34894 .56551 m .34679 .56737 L .34528 .56173 L F
.701 .732 .875 r
.33454 .52527 m .33292 .52709 L .3312 .52491 L F
0 0 .154 r
.27398 .56257 m .2739 .56222 L .27524 .56127 L F
.77 .558 .611 r
.37489 .55447 m .37781 .55643 L .37773 .55443 L F
.046 .28 .773 r
.37781 .55643 m .37798 .55367 L .37773 .55443 L F
0 0 .323 r
.39773 .61246 m .39927 .60843 L .3983 .61064 L F
0 0 0 r
.62472 .38895 m .62241 .39317 L .62385 .39056 L F
.622 .872 .524 r
.62741 .38565 m .62472 .38895 L .62609 .387 L F
0 0 0 r
.62609 .387 m .62472 .38895 L .62385 .39056 L F
.56 .458 .696 r
.29714 .52158 m .29837 .52366 L .30075 .52272 L F
0 0 .396 r
.43006 .5571 m .43099 .55979 L .43087 .56099 L F
.992 .828 .458 r
.43099 .55979 m .43139 .56331 L .43087 .56099 L F
.825 .838 .858 r
.65391 .34105 m .65075 .34098 L .65234 .33946 L F
.819 .813 .844 r
.6552 .33628 m .65391 .34105 L .65234 .33946 L F
.6552 .33628 m .6568 .33795 L .65391 .34105 L F
.767 .937 .939 r
.60936 .37394 m .61128 .37446 L .60845 .37617 L F
.809 .956 .621 r
.60936 .37394 m .60845 .37617 L .60679 .37785 L F
.987 .777 .38 r
.2869 .65019 m .28752 .65365 L .28797 .65254 L F
.804 .314 .013 r
.28752 .65365 m .2893 .65626 L .2871 .65544 L F
.28752 .65365 m .2871 .65544 L .28797 .65254 L F
.76 .574 .645 r
.65598 .36343 m .65835 .36034 L .65443 .35952 L F
.761 .575 .646 r
.65598 .36343 m .65865 .36323 L .65835 .36034 L F
.729 .599 .711 r
.65865 .36323 m .66122 .36028 L .65835 .36034 L F
.605 .434 .624 r
.6556 .37695 m .65856 .37636 L .65836 .37322 L F
.691 .521 .653 r
.65856 .37636 m .66113 .37301 L .65836 .37322 L F
.897 .801 .746 r
.232 .61211 m .22981 .612 L .2295 .61149 L F
.407 .775 .994 r
.31231 .54134 m .31394 .54092 L .3158 .54206 L F
.31151 .54118 m .31239 .54109 L .31231 .54134 L F
.31239 .54109 m .31394 .54092 L .31231 .54134 L F
.652 .4 .525 r
.31054 .54297 m .31394 .54092 L .31151 .54118 L F
.706 .981 .794 r
.31025 .54098 m .30848 .543 L .31247 .54082 L F
.31021 .54098 m .31247 .54082 L .31255 .54059 L F
.778 .59 .646 r
.31306 .5405 m .3061 .5374 L .30861 .53675 L F
.31306 .5405 m .30626 .54042 L .3061 .5374 L F
.997 .766 .443 r
.31071 .53613 m .3125 .53946 L .30861 .53675 L F
.3125 .53946 m .31306 .5405 L .31239 .53994 L F
.3125 .53946 m .31239 .53994 L .30861 .53675 L F
.804 .598 .623 r
.31593 .53673 m .31306 .53701 L .31544 .53443 L F
.997 .766 .443 r
.31071 .53613 m .31084 .53943 L .31306 .5405 L F
.742 .559 .646 r
.31468 .53928 m .31084 .53943 L .31071 .53613 L F
.31468 .53928 m .31071 .53613 L .31111 .5372 L F
.804 .598 .623 r
.31306 .53701 m .31111 .5372 L .31334 .53577 L F
.31306 .53701 m .31334 .53577 L .31544 .53443 L F
.706 .981 .794 r
.31021 .54098 m .31306 .5405 L .31084 .53943 L F
.669 .624 .795 r
.31544 .53851 m .3158 .54206 L .31883 .54096 L F
.31544 .53851 m .31883 .54096 L .31613 .53981 L F
.31544 .53851 m .31613 .53981 L .31623 .53768 L F
.478 .29 .546 r
.31623 .53768 m .31394 .54092 L .31613 .53981 L F
.575 .132 .162 r
.31468 .53928 m .31059 .54084 L .31084 .53943 L F
.509 .911 .821 r
.31026 .54097 m .31266 .53945 L .31084 .53943 L F
.575 .132 .162 r
.31059 .54084 m .31021 .54098 L .31084 .53943 L F
.706 .981 .794 r
.31255 .54059 m .31247 .54082 L .31306 .5405 L F
.575 .132 .162 r
.31468 .53928 m .31416 .54003 L .3107 .54103 L F
.31416 .54003 m .31142 .54109 L .3107 .54103 L F
.31468 .53928 m .3107 .54103 L .31059 .54084 L F
.509 .911 .821 r
.31072 .54107 m .31435 .53978 L .31266 .53945 L F
.773 .559 .609 r
.3189 .53954 m .31623 .53768 L .31613 .53981 L F
0 0 0 r
.31653 .53971 m .31468 .53928 L .31735 .53971 L F
.509 .911 .821 r
.31435 .53978 m .31515 .53949 L .31456 .53948 L F
.31515 .53949 m .31509 .53948 L .31456 .53948 L F
0 0 0 r
.31442 .53972 m .3146 .53941 L .31653 .53971 L F
.3146 .53941 m .31468 .53928 L .31653 .53971 L F
.509 .911 .821 r
.31515 .53949 m .31517 .53949 L .31509 .53948 L F
.31435 .53978 m .31456 .53948 L .31266 .53945 L F
.623 .533 .733 r
.31084 .53943 m .31456 .53948 L .31111 .5372 L F
0 0 0 r
.31456 .53948 m .31454 .5395 L .3146 .53941 L F
.623 .533 .733 r
.31456 .53948 m .31473 .53923 L .31111 .5372 L F
.661 .973 .85 r
.31466 .53936 m .31167 .54039 L .3135 .53909 L F
.31517 .53949 m .31443 .53968 L .31466 .53936 L F
0 0 0 r
.3146 .53941 m .31428 .53988 L .31468 .53928 L F
.661 .973 .85 r
.31443 .53968 m .31167 .54039 L .31466 .53936 L F
0 0 0 r
.31351 .541 m .31333 .54126 L .31418 .54002 L F
.31422 .53997 m .31418 .54002 L .31454 .5395 L F
.31351 .541 m .31418 .54002 L .31422 .53997 L F
.31351 .541 m .31454 .5395 L .31456 .53948 L F
.623 .533 .733 r
.31456 .53948 m .31517 .53949 L .31473 .53923 L F
.614 .231 .293 r
.31333 .54126 m .30915 .54283 L .30985 .54162 L F
.509 .911 .821 r
.31007 .54146 m .31266 .53945 L .31026 .54097 L F
.706 .981 .794 r
.31021 .54098 m .31017 .54103 L .31025 .54098 L F
.614 .231 .293 r
.3107 .54103 m .30985 .54162 L .31021 .54098 L F
.31333 .54126 m .30985 .54162 L .3107 .54103 L F
.509 .911 .821 r
.30999 .54168 m .3111 .54075 L .31007 .54146 L F
.3111 .54075 m .31266 .53945 L .31007 .54146 L F
.31077 .54114 m .31517 .53949 L .31072 .54107 L F
.31048 .54147 m .31517 .53949 L .31052 .54123 L F
.31086 .54131 m .31145 .54064 L .31443 .53968 L F
.31145 .54064 m .31197 .54032 L .31443 .53968 L F
0 0 0 r
.31428 .53988 m .31416 .54003 L .31468 .53928 L F
.509 .911 .821 r
.31086 .54131 m .31443 .53968 L .3143 .53986 L F
.575 .132 .162 r
.31416 .54003 m .31333 .54126 L .31142 .54109 L F
0 0 0 r
.31428 .53988 m .31333 .54126 L .31416 .54003 L F
.31442 .53972 m .31351 .541 L .3146 .53941 L F
.775 .96 .928 r
.31442 .53972 m .30915 .54283 L .31333 .54126 L F
.072 0 .128 r
.31355 .53912 m .30915 .54283 L .31442 .53972 L F
.3135 .53909 m .3131 .53943 L .31355 .53912 L F
.3131 .53943 m .30915 .54283 L .31355 .53912 L F
.487 .455 .747 r
.3086 .54513 m .31163 .54654 L .31054 .54297 L F
.646 .39 .518 r
.30942 .54355 m .30836 .54528 L .31111 .54485 L F
.072 0 .128 r
.31065 .54154 m .30903 .54419 L .30915 .54283 L F
.706 .981 .794 r
.31017 .54103 m .30848 .543 L .31025 .54098 L F
.373 .629 .953 r
.30626 .54042 m .30851 .54303 L .3055 .54188 L F
.487 .455 .748 r
.3086 .54513 m .30979 .54728 L .31163 .54654 L F
.065 0 0 r
.30745 .54326 m .30734 .54355 L .30495 .54388 L F
.30848 .543 m .30734 .54355 L .30745 .54326 L F
.427 .197 .461 r
.3084 .54277 m .30716 .54404 L .30734 .54355 L F
.30716 .54404 m .30554 .54568 L .30734 .54355 L F
.685 .964 .74 r
.31021 .54098 m .30734 .54355 L .30848 .543 L F
.646 .39 .518 r
.3084 .54277 m .30802 .54534 L .30945 .54511 L F
.889 .476 .215 r
.30915 .54283 m .30903 .54419 L .3084 .54277 L F
.646 .39 .518 r
.3084 .54277 m .30945 .54511 L .31111 .54485 L F
.3084 .54277 m .30836 .54528 L .30942 .54355 L F
.889 .476 .215 r
.30903 .54419 m .30901 .54438 L .3084 .54277 L F
.072 0 .128 r
.31235 .54008 m .30901 .54438 L .30903 .54419 L F
.31235 .54008 m .30903 .54419 L .31065 .54154 L F
.646 .39 .518 r
.3084 .54277 m .30802 .54534 L .30836 .54528 L F
.509 .911 .821 r
.30999 .54168 m .31048 .54147 L .31052 .54123 L F
.30999 .54168 m .31008 .54161 L .31086 .54131 L F
.31008 .54161 m .31167 .54039 L .31086 .54131 L F
.74 .644 .754 r
.3067 .54141 m .30734 .54355 L .31021 .54098 L F
0 0 0 r
.31021 .54098 m .30734 .54355 L .3067 .54141 L F
.395 .057 .27 r
.30952 .54164 m .3084 .54277 L .3098 .54166 L F
0 0 0 r
.30988 .54128 m .30952 .54164 L .30734 .54355 L F
.30952 .54164 m .3084 .54277 L .30812 .54298 L F
.30952 .54164 m .30812 .54298 L .30734 .54355 L F
.6 .206 .268 r
.3067 .54141 m .30952 .54164 L .31021 .54098 L F
.30952 .54164 m .3098 .54166 L .31021 .54098 L F
.395 .057 .27 r
.3067 .54141 m .3084 .54277 L .30952 .54164 L F
0 0 0 r
.31021 .54098 m .3084 .54277 L .30988 .54128 L F
.889 .476 .215 r
.30909 .54282 m .3084 .54277 L .31021 .54098 L F
.395 .057 .27 r
.3098 .54166 m .3084 .54277 L .30999 .54168 L F
.889 .476 .215 r
.30915 .54283 m .30909 .54282 L .3098 .54166 L F
.30984 .54162 m .3098 .54166 L .31021 .54098 L F
.30915 .54283 m .3098 .54166 L .30984 .54162 L F
.6 .206 .268 r
.3098 .54166 m .30999 .54168 L .31021 .54098 L F
.511 .294 .52 r
.3084 .54277 m .30901 .54438 L .31161 .54048 L F
.509 .911 .821 r
.31052 .54123 m .31077 .54114 L .31072 .54107 L F
.511 .294 .52 r
.3084 .54277 m .31167 .54039 L .30999 .54168 L F
.30991 .54167 m .31161 .54048 L .31167 .54039 L F
.3084 .54277 m .31161 .54048 L .30991 .54167 L F
.072 0 .128 r
.3135 .53909 m .31301 .53967 L .31235 .54008 L F
.31301 .53967 m .30901 .54438 L .31235 .54008 L F
.509 .911 .821 r
.31145 .54064 m .31167 .54039 L .31197 .54032 L F
.3143 .53986 m .31443 .53968 L .31517 .53949 L F
.575 .132 .162 r
.31059 .54084 m .3107 .54103 L .31021 .54098 L F
.762 .495 .53 r
.31394 .54092 m .31771 .54382 L .3158 .54206 L F
.654 .112 0 r
.26054 .54923 m .25855 .54944 L .25654 .54772 L F
.251 .557 .933 r
.26054 .54923 m .26212 .54814 L .25855 .54944 L F
.26054 .54923 m .26291 .54986 L .26212 .54814 L F
.544 .609 .869 r
.26054 .54923 m .26406 .55118 L .26291 .54986 L F
0 0 .35 r
.40195 .65302 m .40344 .65669 L .40243 .65443 L F
.021 .55 .856 r
.20564 .61564 m .20376 .61479 L .20252 .61473 L F
.20564 .61564 m .20376 .61479 L .20252 .61473 L F
.227 0 0 r
.35351 .54433 m .34838 .5476 L .34788 .54457 L F
.35351 .54433 m .35078 .54712 L .34838 .5476 L F
.441 .123 .33 r
.3531 .546 m .35078 .54712 L .35351 .54433 L F
.727 .7 .162 r
.35404 .5413 m .3531 .546 L .35351 .54433 L F
.547 .924 .793 r
.32333 .62338 m .32661 .62169 L .32577 .62403 L F
.556 .494 .741 r
.32866 .619 m .32922 .62173 L .32661 .62169 L F
.484 .096 .227 r
.32661 .62169 m .32922 .62173 L .32667 .62483 L F
0 .018 .584 r
.32695 .62519 m .32625 .6245 L .32744 .62605 L F
.637 .11 0 r
.32744 .62605 m .32577 .62403 L .32649 .62504 L F
.527 .344 .576 r
.32683 .62498 m .32744 .62605 L .32649 .62504 L F
.33011 .62441 m .32744 .62605 L .32683 .62498 L F
0 .018 .584 r
.32725 .62548 m .32695 .62519 L .32744 .62605 L F
.32625 .6245 m .32577 .62403 L .32599 .6243 L F
.32625 .6245 m .32599 .6243 L .32744 .62605 L F
.298 0 .094 r
.32672 .62487 m .32922 .62173 L .33158 .62128 L F
.32649 .62504 m .32667 .62483 L .32672 .62487 L F
.32667 .62483 m .32922 .62173 L .32672 .62487 L F
0 .018 .584 r
.3266 .62475 m .32577 .62403 L .32725 .62548 L F
.3265 .62465 m .32639 .62456 L .3266 .62475 L F
.32639 .62456 m .32577 .62403 L .3266 .62475 L F
.298 0 .094 r
.32683 .62498 m .33158 .62128 L .33067 .62322 L F
.32683 .62498 m .33067 .62322 L .32816 .62475 L F
.32649 .62504 m .32672 .62487 L .32683 .62498 L F
.32672 .62487 m .33158 .62128 L .32683 .62498 L F
.484 .096 .227 r
.3265 .62465 m .32667 .62483 L .32649 .62504 L F
.32661 .62169 m .32667 .62483 L .3265 .62465 L F
0 .018 .584 r
.32715 .62519 m .3265 .62465 L .32725 .62548 L F
.484 .096 .227 r
.32661 .62169 m .3265 .62465 L .32577 .62403 L F
0 .018 .584 r
.32629 .62259 m .32577 .62403 L .32715 .62519 L F
.484 .096 .227 r
.3265 .62465 m .32649 .62504 L .32577 .62403 L F
0 .018 .584 r
.32629 .62259 m .3272 .62534 L .3252 .62534 L F
.3272 .62534 m .32744 .62605 L .32651 .62576 L F
.3272 .62534 m .32651 .62576 L .3252 .62534 L F
.298 0 .094 r
.32816 .62475 m .33067 .62322 L .33011 .62441 L F
.939 .877 .747 r
.68831 .30231 m .68523 .3046 L .68711 .30109 L F
.68831 .30231 m .68655 .30606 L .68523 .3046 L F
.898 .927 .829 r
.68976 .29786 m .68831 .30231 L .68711 .30109 L F
.987 .767 .517 r
.41647 .5879 m .41801 .59305 L .41633 .59198 L F
.932 .57 .307 r
.41801 .59305 m .41736 .59612 L .41633 .59198 L F
.789 .717 .784 r
.30075 .52272 m .30245 .5263 L .30527 .52332 L F
.568 .28 .439 r
.30245 .5263 m .30196 .52872 L .30522 .52822 L F
.45 .21 .457 r
.34092 .6939 m .33869 .69221 L .3383 .6947 L F
.789 .717 .784 r
.30075 .52272 m .30527 .52332 L .30328 .52193 L F
.503 .785 .996 r
.30553 .52133 m .30527 .52332 L .30328 .52193 L F
.30553 .52133 m .30527 .52332 L .30328 .52193 L F
.454 .26 .526 r
.23312 .574 m .23281 .57727 L .23102 .57883 L F
.719 .591 .712 r
.23542 .57331 m .23281 .57727 L .23312 .574 L F
.375 .063 .302 r
.35174 .71652 m .35234 .7148 L .34806 .71575 L F
.745 .488 .541 r
.43324 .5789 m .42985 .58001 L .43031 .57719 L F
.43324 .5789 m .43343 .58046 L .42985 .58001 L F
0 0 .272 r
.43423 .5792 m .43363 .57884 L .43705 .57832 L F
.524 .36 .601 r
.43839 .57889 m .43593 .58245 L .43374 .58044 L F
.43839 .57889 m .43374 .58044 L .43548 .58063 L F
0 0 .57 r
.43548 .58063 m .43391 .57914 L .43482 .57932 L F
0 0 .272 r
.43403 .57927 m .43391 .57914 L .43423 .5792 L F
.43391 .57914 m .43363 .57884 L .43423 .5792 L F
0 0 .57 r
.43548 .58063 m .43374 .58044 L .43391 .57914 L F
0 0 .272 r
.43417 .57899 m .43705 .57832 L .4355 .57643 L F
0 0 .57 r
.43417 .57899 m .43391 .57914 L .43401 .57838 L F
.43423 .5792 m .43419 .5792 L .43417 .57899 L F
.43419 .5792 m .43391 .57914 L .43417 .57899 L F
.43423 .5792 m .43401 .57838 L .43408 .57786 L F
.961 .916 .563 r
.43403 .57927 m .43417 .57899 L .43408 .57786 L F
.43417 .57899 m .4355 .57643 L .43408 .57786 L F
0 0 .272 r
.43403 .57927 m .43423 .5792 L .43417 .57899 L F
.43423 .5792 m .43705 .57832 L .43417 .57899 L F
0 0 .57 r
.43482 .57932 m .43423 .5792 L .43408 .57786 L F
0 0 .142 r
.43408 .57786 m .43391 .57914 L .43403 .57927 L F
.43391 .57914 m .43374 .58044 L .43403 .57927 L F
0 0 .272 r
.43403 .57927 m .43324 .5789 L .43363 .57884 L F
.43403 .57927 m .43343 .58046 L .43324 .5789 L F
.722 .753 .877 r
.64027 .36974 m .64414 .37031 L .6429 .3685 L F
.722 .712 .841 r
.64414 .37031 m .64541 .36554 L .6429 .3685 L F
.64414 .37031 m .64703 .36955 L .64541 .36554 L F
.615 .881 .552 r
.35225 .55503 m .34952 .55785 L .34935 .55832 L F
.66 .799 .347 r
.34952 .55785 m .34839 .56012 L .34935 .55832 L F
.836 .807 .822 r
.39124 .69205 m .39515 .69194 L .39344 .68924 L F
.777 .79 .864 r
.39344 .68924 m .39515 .69194 L .39753 .68889 L F
.619 .547 .752 r
.39515 .69194 m .39775 .69089 L .39753 .68889 L F
.739 .676 .789 r
.63318 .35616 m .63454 .35992 L .63242 .36072 L F
.809 .71 .756 r
.63536 .35763 m .63454 .35992 L .63318 .35616 L F
0 0 .556 r
.36712 .52003 m .36726 .51925 L .36582 .51657 L F
.932 .899 .499 r
.36677 .5224 m .36726 .51925 L .36712 .52003 L F
.615 .232 .294 r
.35478 .557 m .34952 .55785 L .35225 .55503 L F
.345 .088 .373 r
.24276 .54177 m .2398 .54151 L .24051 .54362 L F
.469 .515 .823 r
.24276 .54177 m .24373 .53942 L .24085 .5383 L F
.24276 .54177 m .24496 .5416 L .24373 .53942 L F
.805 .98 .698 r
.24276 .54177 m .2399 .54529 L .24051 .54362 L F
.722 .327 .302 r
.24276 .54177 m .24051 .54362 L .24426 .54403 L F
.448 .261 .533 r
.24276 .54177 m .24426 .54403 L .24496 .5416 L F
.722 .327 .302 r
.24276 .54177 m .24051 .54362 L .24426 .54403 L F
.805 .641 .679 r
.42222 .53956 m .42148 .5417 L .4247 .54123 L F
.024 0 0 r
.42148 .5417 m .42416 .54147 L .4247 .54123 L F
.601 .905 .631 r
.4247 .54123 m .42593 .53972 L .42808 .53896 L F
.4247 .54123 m .42416 .54147 L .42593 .53972 L F
.857 .891 .86 r
.39149 .61273 m .38706 .61477 L .39002 .61183 L F
.703 .561 .691 r
.62688 .44618 m .63062 .44667 L .63061 .44375 L F
0 0 .287 r
.63187 .43935 m .63061 .44375 L .63314 .44304 L F
.505 .322 .566 r
.63062 .44667 m .63314 .44304 L .63061 .44375 L F
.798 .923 .92 r
.71307 .33768 m .70971 .34053 L .70864 .33909 L F
.566 .839 .493 r
.34843 .58654 m .34555 .58987 L .3478 .58923 L F
.194 0 .217 r
.34843 .58654 m .34989 .58822 L .35064 .58602 L F
.34843 .58654 m .3478 .58923 L .34989 .58822 L F
.568 .772 .975 r
.38435 .56829 m .38639 .56663 L .38495 .56776 L F
.784 .697 .769 r
.56197 .42903 m .56391 .43056 L .55973 .43025 L F
.634 .489 .668 r
.56649 .42718 m .56391 .43056 L .56197 .42903 L F
.56649 .42718 m .56197 .42903 L .56335 .42697 L F
.773 .728 .811 r
.55973 .43025 m .56391 .43056 L .56335 .42697 L F
.81 .752 .798 r
.56335 .42697 m .56391 .43056 L .56649 .42718 L F
.697 .577 .717 r
.56391 .43056 m .56815 .42977 L .56649 .42718 L F
.639 .376 .505 r
.56694 .43103 m .56815 .42977 L .56391 .43056 L F
.576 .233 .35 r
.56674 .43004 m .56815 .42977 L .56688 .43054 L F
0 0 .328 r
.56697 .43084 m .56694 .43103 L .56688 .43054 L F
.634 .489 .668 r
.56688 .43054 m .56694 .43103 L .56391 .43056 L F
.604 .207 .263 r
.56649 .43243 m .56694 .43103 L .56391 .43056 L F
.218 0 .128 r
.56649 .43243 m .56815 .42977 L .56694 .43103 L F
.576 .233 .35 r
.56391 .43056 m .56706 .43054 L .56649 .43243 L F
0 0 .307 r
.56697 .43084 m .56649 .43243 L .56694 .43103 L F
.576 .233 .35 r
.56706 .43054 m .56768 .43053 L .56649 .43243 L F
.56649 .43243 m .56815 .42977 L .56391 .43056 L F
0 0 .328 r
.56748 .42752 m .56697 .43084 L .56649 .42718 L F
.56697 .43084 m .56688 .43054 L .56649 .42718 L F
0 0 .307 r
.56748 .42752 m .56649 .43243 L .56697 .43084 L F
.576 .233 .35 r
.56688 .43054 m .56815 .42977 L .56768 .43053 L F
.56391 .43056 m .56674 .43004 L .56688 .43054 L F
.634 .489 .668 r
.56649 .42718 m .56688 .43054 L .56391 .43056 L F
.604 .207 .263 r
.56649 .43243 m .56391 .43056 L .56401 .43322 L F
.576 .233 .35 r
.56391 .43056 m .56649 .43243 L .56401 .43322 L F
.796 .901 .916 r
.72287 .34083 m .72734 .34123 L .72685 .34389 L F
0 .274 .754 r
.72734 .34123 m .73017 .34309 L .72871 .34145 L F
.72734 .34123 m .72871 .34145 L .72685 .34389 L F
.954 .815 .669 r
.37466 .63995 m .37572 .63735 L .37346 .63819 L F
.802 .74 .795 r
.63266 .37682 m .63395 .37179 L .63106 .37285 L F
.63266 .37682 m .63531 .37395 L .63395 .37179 L F
.492 .622 .907 r
.37447 .61236 m .37521 .6091 L .37237 .60896 L F
.37447 .61236 m .37662 .61181 L .37521 .6091 L F
.379 .171 .466 r
.37447 .61236 m .37447 .61522 L .37662 .61181 L F
.983 .7 .341 r
.37447 .61522 m .37447 .61236 L .37662 .61181 L F
.518 .474 .746 r
.38553 .60299 m .38616 .60547 L .38857 .605 L F
0 0 .567 r
.28248 .62841 m .28391 .63075 L .28281 .6276 L F
.99 .792 .405 r
.33248 .63751 m .33281 .63477 L .33166 .63201 L F
.547 .826 .998 r
.39345 .59599 m .39757 .59641 L .39598 .59524 L F
.39345 .59599 m .39757 .59641 L .39598 .59524 L F
.706 .18 0 r
.37055 .55413 m .37482 .55648 L .37489 .55447 L F
.093 0 0 r
.37489 .55447 m .3726 .5543 L .37055 .55413 L F
.802 .511 .495 r
.37443 .55195 m .3726 .5543 L .37489 .55447 L F
.719 .902 .529 r
.37536 .55005 m .3726 .5543 L .37443 .55195 L F
.802 .511 .495 r
.37443 .55195 m .3726 .5543 L .37489 .55447 L F
0 .374 .798 r
.23927 .61944 m .24058 .61946 L .23763 .6182 L F
.23927 .61944 m .2422 .62081 L .24058 .61946 L F
.93 .882 .764 r
.38358 .5076 m .38195 .50664 L .38353 .50372 L F
.832 .416 0 r
.38358 .5076 m .38312 .50798 L .38195 .50664 L F
.38358 .5076 m .38443 .5096 L .38312 .50798 L F
.731 .683 .804 r
.36918 .60576 m .3707 .60747 L .37275 .60599 L F
.504 .274 .498 r
.3707 .60747 m .37237 .60896 L .37275 .60599 L F
.3707 .60747 m .37237 .60896 L .37275 .60599 L F
.733 .697 .816 r
.6307 .35916 m .63242 .36072 L .62834 .36025 L F
.739 .676 .789 r
.63318 .35616 m .63242 .36072 L .6307 .35916 L F
.535 .462 .72 r
.26863 .53903 m .271 .53843 L .27051 .53418 L F
.762 .728 .821 r
.63531 .37395 m .63747 .37251 L .63395 .37179 L F
.571 .722 .944 r
.35192 .68773 m .35429 .69107 L .3513 .6916 L F
.59 .704 .922 r
.37022 .64159 m .37455 .64321 L .37326 .64205 L F
.865 .867 .837 r
.37455 .64321 m .37466 .63995 L .37326 .64205 L F
.37455 .64321 m .37621 .64114 L .37466 .63995 L F
.987 .714 .382 r
.54243 .39486 m .54104 .39101 L .54258 .39232 L F
.482 .77 .995 r
.54104 .39101 m .54405 .39081 L .54258 .39232 L F
.876 .923 .853 r
.54405 .39081 m .54243 .39486 L .54258 .39232 L F
.568 .418 .639 r
.32984 .58026 m .33283 .58241 L .33384 .58014 L F
0 0 0 r
.33283 .58241 m .33494 .57934 L .33384 .58014 L F
.909 .503 .139 r
.5939 .39475 m .59539 .39568 L .5961 .39781 L F
.021 0 .099 r
.34075 .59665 m .33855 .59937 L .34113 .5992 L F
.563 .517 .762 r
.34113 .5992 m .34329 .59583 L .34075 .59665 L F
.497 .317 .568 r
.38062 .67702 m .38147 .6795 L .37906 .67924 L F
.288 .633 .964 r
.37985 .67797 m .38147 .6795 L .37906 .67924 L F
.37985 .67797 m .38147 .6795 L .37906 .67924 L F
0 0 0 r
.3094 .55807 m .30776 .55836 L .30552 .55858 L F
.065 .629 .738 r
.31196 .55819 m .30776 .55836 L .3094 .55807 L F
.376 .838 .785 r
.34821 .67117 m .34688 .67204 L .34582 .67122 L F
.633 .763 .941 r
.41045 .48814 m .40631 .48729 L .40882 .48647 L F
.729 .809 .914 r
.41204 .48642 m .41045 .48814 L .40882 .48647 L F
.948 .921 .557 r
.42137 .51328 m .41985 .51376 L .42123 .51178 L F
.297 .537 .913 r
.42123 .51178 m .42287 .51144 L .42137 .51328 L F
.607 .933 .721 r
.42137 .51328 m .41985 .51376 L .42287 .51144 L F
.709 .635 .772 r
.63316 .41001 m .63553 .40854 L .63246 .41111 L F
.808 .967 .907 r
.63246 .41111 m .63553 .40854 L .63433 .40777 L F
.782 .742 .816 r
.64541 .36554 m .64703 .36955 L .6493 .36628 L F
0 0 0 r
.38057 .71039 m .38214 .70832 L .3835 .70727 L F
.8 .991 .747 r
.34617 .68811 m .34654 .68859 L .34389 .69142 L F
.953 .742 .581 r
.42985 .58001 m .43123 .58357 L .42913 .58309 L F
.546 .412 .65 r
.43343 .58046 m .43123 .58357 L .42985 .58001 L F
.43343 .58046 m .43381 .58316 L .43123 .58357 L F
.482 .838 .995 r
.23453 .55144 m .23299 .55067 L .23065 .55127 L F
.525 .857 .995 r
.23523 .55063 m .23453 .55144 L .23716 .54995 L F
.23523 .55063 m .23299 .55067 L .23453 .55144 L F
0 0 0 r
.30201 .51564 m .30575 .51314 L .30487 .51235 L F
.798 .969 .911 r
.30487 .51235 m .30575 .51314 L .30874 .51055 L F
.805 .834 .874 r
.39017 .69551 m .39124 .69205 L .38957 .69511 L F
.964 .853 .442 r
.38912 .69776 m .39017 .69551 L .38957 .69511 L F
.38912 .69776 m .38971 .69846 L .39017 .69551 L F
.756 .536 .598 r
.392 .69774 m .39017 .69551 L .38971 .69846 L F
.209 0 .291 r
.30357 .61174 m .30613 .60856 L .30434 .60959 L F
.784 .624 .683 r
.62432 .44934 m .62688 .44618 L .62282 .44579 L F
.975 .73 .503 r
.35802 .51526 m .35974 .51642 L .35953 .51373 L F
.822 .808 .837 r
.26291 .54986 m .26406 .55118 L .26697 .54814 L F
.627 .602 .805 r
.44413 .49395 m .44545 .49707 L .44205 .49679 L F
.516 .373 .625 r
.44545 .49707 m .44302 .50069 L .44205 .49679 L F
.582 .131 .146 r
.24571 .57109 m .24374 .57307 L .24116 .57248 L F
.269 0 .001 r
.24805 .57016 m .24374 .57307 L .24571 .57109 L F
.717 .407 .452 r
.38987 .65484 m .39291 .65634 L .39335 .65412 L F
.504 .362 .621 r
.39335 .65412 m .39598 .65354 L .39576 .65034 L F
.257 0 .317 r
.39335 .65412 m .39485 .6555 L .39598 .65354 L F
.39335 .65412 m .39291 .65634 L .39485 .6555 L F
0 0 .361 r
.33758 .56053 m .33653 .55828 L .33785 .55724 L F
0 0 .149 r
.65916 .38402 m .65712 .38776 L .65825 .38594 L F
.683 .796 .333 r
.65859 .38517 m .65916 .38402 L .65825 .38594 L F
0 0 0 r
.66012 .38206 m .65962 .38231 L .65916 .38402 L F
.683 .796 .333 r
.6601 .38175 m .65916 .38402 L .65859 .38517 L F
0 0 0 r
.66185 .38121 m .66012 .38206 L .65916 .38402 L F
.586 .48 .7 r
.63772 .40682 m .63419 .40567 L .63751 .40541 L F
.63772 .40682 m .63553 .40854 L .63419 .40567 L F
.167 0 .272 r
.33855 .59937 m .33978 .60123 L .34113 .5992 L F
.33855 .59937 m .33788 .60242 L .33978 .60123 L F
.917 .891 .79 r
.55895 .42709 m .56257 .42364 L .56174 .42597 L F
.845 .753 .762 r
.56505 .42332 m .56174 .42597 L .56257 .42364 L F
.782 .908 .927 r
.33181 .49574 m .32795 .49641 L .33022 .49579 L F
.256 .759 .886 r
.33269 .49503 m .33181 .49574 L .33022 .49579 L F
.216 .71 .918 r
.33085 .49453 m .33269 .49503 L .32857 .49455 L F
.395 0 0 r
.33156 .49481 m .33269 .49503 L .33085 .49453 L F
.256 .759 .886 r
.33269 .49503 m .33407 .49529 L .33181 .49574 L F
.395 0 0 r
.33362 .49562 m .33269 .49503 L .33156 .49481 L F
.256 .759 .886 r
.33269 .49503 m .33491 .49513 L .33407 .49529 L F
.965 .757 .573 r
.69167 .3116 m .69407 .31268 L .69331 .31153 L F
.928 .554 .275 r
.6945 .31479 m .69407 .31268 L .69167 .3116 L F
.83 .775 .8 r
.69331 .31153 m .69407 .31268 L .69684 .30857 L F
0 0 .005 r
.369 .61826 m .36647 .62196 L .36768 .62134 L F
.468 .313 .587 r
.36647 .62196 m .36913 .62434 L .36768 .62134 L F
.36647 .62196 m .36651 .62516 L .36913 .62434 L F
.195 .68 .928 r
.36189 .60842 m .36368 .6092 L .36403 .6085 L F
.804 .962 .64 r
.42319 .53743 m .42222 .53956 L .42423 .53688 L F
.108 0 .333 r
.42505 .53409 m .42423 .53688 L .42733 .53698 L F
.42505 .53409 m .42319 .53743 L .42423 .53688 L F
.516 .373 .625 r
.44545 .49707 m .4455 .50015 L .44302 .50069 L F
.551 .345 .554 r
.44568 .50286 m .44302 .50069 L .4455 .50015 L F
.44568 .50286 m .44304 .50345 L .44302 .50069 L F
.42 .352 .675 r
.41305 .50061 m .41524 .49683 L .41203 .49713 L F
.41305 .50061 m .41573 .50008 L .41524 .49683 L F
.806 .66 .702 r
.41167 .50214 m .41573 .50008 L .41305 .50061 L F
.826 .887 .887 r
.36999 .62421 m .37204 .62037 L .36913 .62434 L F
.783 .499 .506 r
.39151 .5875 m .38801 .58885 L .38912 .58745 L F
.39151 .5875 m .39245 .58969 L .38801 .58885 L F
.279 .075 .414 r
.30457 .6444 m .30706 .64049 L .30686 .6434 L F
.096 0 .101 r
.30369 .64672 m .30457 .6444 L .30686 .6434 L F
.681 .607 .767 r
.32243 .69171 m .32518 .69316 L .32349 .69165 L F
.786 .286 0 r
.32518 .69316 m .32524 .69425 L .32349 .69165 L F
.32518 .69316 m .32693 .69515 L .32524 .69425 L F
0 0 0 r
.39653 .68334 m .39528 .68506 L .39832 .6815 L F
.142 .042 .471 r
.32013 .57728 m .3215 .57847 L .3217 .57638 L F
.32013 .57728 m .32013 .58008 L .3215 .57847 L F
.081 .495 .898 r
.27677 .63698 m .27714 .63588 L .27561 .63586 L F
.27677 .63698 m .2786 .63734 L .27714 .63588 L F
.496 .414 .692 r
.44769 .51178 m .44397 .51429 L .44474 .50985 L F
.579 .499 .729 r
.44769 .51178 m .44592 .51658 L .44397 .51429 L F
.506 .889 .708 r
.70098 .35684 m .70398 .35501 L .70312 .35349 L F
.666 .81 .952 r
.70398 .35501 m .70672 .35397 L .70312 .35349 L F
0 0 0 r
.33833 .67604 m .33463 .67881 L .33639 .67776 L F
.33981 .67559 m .33833 .67604 L .33639 .67776 L F
.602 .032 0 r
.70382 .31103 m .70764 .31292 L .70706 .31332 L F
.763 .265 0 r
.70706 .31332 m .70764 .31292 L .70805 .31409 L F
.716 .356 .365 r
.24085 .5383 m .24373 .53942 L .24531 .53798 L F
.353 0 .053 r
.24531 .53798 m .24373 .53942 L .24743 .53794 L F
.45 .343 .641 r
.44809 .52535 m .44828 .52899 L .44595 .52963 L F
.454 .376 .679 r
.44828 .52899 m .44648 .5321 L .44595 .52963 L F
.002 0 0 r
.34709 .55404 m .34929 .55331 L .35106 .5517 L F
.195 0 0 r
.35106 .5517 m .35192 .55275 L .35284 .55054 L F
.35106 .5517 m .34929 .55331 L .35192 .55275 L F
.177 .034 .435 r
.35372 .67834 m .35254 .6765 L .35345 .67489 L F
.35372 .67834 m .3523 .67843 L .35254 .6765 L F
.058 0 .078 r
.34555 .58987 m .343 .59283 L .34567 .5925 L F
.061 0 .305 r
.34555 .58987 m .34709 .59126 L .3478 .58923 L F
.34555 .58987 m .34567 .5925 L .34709 .59126 L F
.581 .923 .717 r
.33848 .68344 m .34 .68283 L .34155 .68155 L F
.808 .797 .842 r
.54812 .41804 m .54579 .42087 L .54369 .41975 L F
.57 .309 .481 r
.54579 .42087 m .54542 .42349 L .54369 .41975 L F
.54579 .42087 m .54802 .42296 L .54542 .42349 L F
.54542 .42349 m .54802 .42296 L .54579 .42087 L F
.804 .792 .841 r
.23397 .54353 m .23546 .5473 L .23992 .54491 L F
.501 .823 1 r
.23992 .54491 m .23642 .54294 L .23397 .54353 L F
0 0 0 r
.23992 .54491 m .23546 .5473 L .23841 .54592 L F
.23992 .54491 m .23841 .54592 L .23642 .54294 L F
.39 .828 .95 r
.31698 .66614 m .31405 .66662 L .3155 .66732 L F
.461 .207 .441 r
.45444 .58346 m .45411 .58582 L .45159 .58639 L F
.357 .1 .381 r
.45686 .5828 m .45411 .58582 L .45444 .58346 L F
.844 .759 .769 r
.63569 .35285 m .63536 .35763 L .63318 .35616 L F
.715 .776 .9 r
.61765 .36174 m .61918 .36352 L .61524 .36293 L F
.756 .812 .897 r
.6209 .35897 m .61918 .36352 L .61765 .36174 L F
.6209 .35897 m .62174 .36184 L .61918 .36352 L F
.296 .732 .967 r
.63395 .37179 m .63747 .37251 L .63645 .37163 L F
.63395 .37179 m .63747 .37251 L .63645 .37163 L F
.82 .977 .891 r
.63645 .37163 m .63747 .37251 L .64027 .36974 L F
.487 .197 .399 r
.3055 .54188 m .30237 .54403 L .30465 .54173 L F
.373 .629 .953 r
.30626 .54042 m .3055 .54188 L .30465 .54173 L F
.426 .224 .502 r
.33494 .5706 m .33494 .57322 L .33252 .57367 L F
.517 .292 .512 r
.33494 .57322 m .33202 .57653 L .33252 .57367 L F
.237 .745 .881 r
.37227 .54124 m .37459 .54089 L .37092 .54111 L F
.505 .322 .566 r
.63062 .44667 m .63336 .44613 L .63314 .44304 L F
.487 .502 .798 r
.27297 .59046 m .27601 .59192 L .27418 .58784 L F
.363 .171 .482 r
.30822 .59992 m .31063 .59977 L .31035 .59624 L F
.385 .327 .669 r
.30822 .59992 m .31068 .60177 L .31063 .59977 L F
.30822 .59992 m .30885 .60268 L .31068 .60177 L F
.954 .815 .669 r
.37466 .63995 m .37621 .64114 L .37572 .63735 L F
.829 .883 .882 r
.37621 .64114 m .3781 .63681 L .37572 .63735 L F
.37621 .64114 m .37988 .63792 L .3781 .63681 L F
0 0 0 r
.58692 .38265 m .58674 .38262 L .58617 .38302 L F
.58751 .38113 m .58674 .38262 L .58692 .38265 L F
.879 .87 .824 r
.58407 .38221 m .58617 .38302 L .58667 .38232 L F
.754 .346 0 r
.58593 .38094 m .58672 .38231 L .58597 .38112 L F
.58438 .3783 m .58649 .38205 L .58641 .38192 L F
.58597 .38112 m .58672 .38231 L .58649 .38205 L F
.58641 .38192 m .58649 .38205 L .58645 .38199 L F
.677 .884 .513 r
.58672 .38231 m .58692 .38227 L .58751 .38113 L F
.647 .645 .834 r
.58751 .38113 m .58692 .38265 L .58672 .38231 L F
.58751 .38113 m .58672 .38231 L .58438 .3783 L F
.677 .884 .513 r
.58667 .38232 m .58672 .38231 L .58751 .38113 L F
.879 .87 .824 r
.58615 .38156 m .58667 .38232 L .58751 .38113 L F
.754 .346 0 r
.58438 .3783 m .58645 .38199 L .58637 .38189 L F
.879 .87 .824 r
.58407 .38221 m .58667 .38232 L .58615 .38156 L F
.754 .346 0 r
.58637 .38189 m .58645 .38199 L .58641 .38195 L F
.891 .897 .826 r
.58606 .38144 m .58667 .38232 L .58751 .38113 L F
.879 .87 .824 r
.58407 .38221 m .58615 .38156 L .58546 .38057 L F
.754 .346 0 r
.58524 .38026 m .58641 .38195 L .58525 .38029 L F
.58438 .3783 m .58622 .3816 L .58524 .38026 L F
.58622 .3816 m .58641 .38195 L .58524 .38026 L F
.88 .925 .85 r
.58276 .38115 m .58407 .38221 L .58546 .38057 L F
.754 .346 0 r
.58438 .3783 m .58593 .38094 L .58597 .38112 L F
.647 .645 .834 r
.58751 .38113 m .58438 .3783 L .58658 .37925 L F
.88 .925 .85 r
.58506 .38001 m .58546 .38057 L .58658 .37925 L F
.798 .366 0 r
.58308 .3769 m .58438 .3783 L .58524 .38026 L F
.88 .925 .85 r
.58276 .38115 m .58546 .38057 L .58524 .38026 L F
.798 .366 0 r
.58308 .3769 m .58524 .38026 L .58491 .37992 L F
0 .417 .837 r
.58519 .37796 m .58658 .37925 L .58558 .37882 L F
.58519 .37796 m .58558 .37882 L .58438 .3783 L F
.381 .448 .805 r
.58397 .37401 m .58519 .37796 L .58308 .3769 L F
.881 .563 .055 r
.58481 .37712 m .58519 .37796 L .5848 .37662 L F
0 .417 .837 r
.58519 .37796 m .58438 .3783 L .58308 .3769 L F
.88 .925 .85 r
.58358 .38007 m .58502 .38003 L .58426 .37918 L F
.58276 .38115 m .58344 .38082 L .58358 .38007 L F
.58344 .38082 m .58502 .38003 L .58358 .38007 L F
.798 .366 0 r
.58337 .37737 m .5849 .37989 L .58426 .37918 L F
.381 .448 .805 r
.58397 .37401 m .58308 .3769 L .58386 .37862 L F
.798 .366 0 r
.58337 .37737 m .5846 .37989 L .58398 .37918 L F
.381 .448 .805 r
.58419 .37692 m .58386 .37862 L .58441 .37984 L F
.58397 .37401 m .58386 .37862 L .58419 .37692 L F
.798 .366 0 r
.58426 .37918 m .58556 .38098 L .5846 .37989 L F
.5849 .37989 m .58556 .38098 L .58426 .37918 L F
.88 .925 .85 r
.5849 .37989 m .58658 .37925 L .58426 .37918 L F
.58502 .38003 m .58502 .38003 L .5849 .37989 L F
.58502 .38003 m .58658 .37925 L .5849 .37989 L F
.58426 .37918 m .58506 .3792 L .58519 .37796 L F
.58546 .37922 m .58658 .37925 L .58519 .37796 L F
.798 .366 0 r
.58491 .37992 m .58502 .38003 L .58556 .38098 L F
.88 .925 .85 r
.58276 .38115 m .58524 .38026 L .58502 .38003 L F
.798 .366 0 r
.58502 .38003 m .58524 .38026 L .58526 .38029 L F
.58502 .38003 m .58526 .38029 L .58556 .38098 L F
.88 .925 .85 r
.58502 .38003 m .58524 .38026 L .58506 .38001 L F
.58493 .38056 m .58519 .37796 L .5857 .38034 L F
.58276 .38115 m .58426 .37918 L .5846 .37989 L F
.679 .895 .975 r
.5846 .37989 m .58276 .38115 L .58398 .37918 L F
.879 .87 .824 r
.58546 .38057 m .58751 .38113 L .58658 .37925 L F
.58615 .38156 m .58751 .38113 L .58546 .38057 L F
.754 .346 0 r
.58525 .38029 m .58641 .38195 L .58556 .38098 L F
.482 .736 .983 r
.58893 .37895 m .58444 .38164 L .5857 .38034 L F
.679 .895 .975 r
.58556 .38098 m .58407 .38221 L .58276 .38115 L F
.482 .736 .983 r
.58444 .38164 m .58406 .38187 L .58438 .38157 L F
.58444 .38164 m .58438 .38157 L .5857 .38034 L F
.679 .895 .975 r
.58556 .38098 m .58399 .38108 L .5846 .37989 L F
.58399 .38108 m .58276 .38115 L .58359 .38058 L F
.58399 .38108 m .58359 .38058 L .5846 .37989 L F
.88 .925 .85 r
.58276 .38115 m .5846 .37989 L .58493 .38056 L F
.58426 .37918 m .58519 .37796 L .58493 .38056 L F
.798 .366 0 r
.58308 .3769 m .58337 .37737 L .58398 .37918 L F
.881 .563 .055 r
.58484 .37916 m .58519 .37796 L .58481 .37712 L F
.913 .879 .788 r
.58751 .38113 m .58912 .38247 L .58728 .38477 L F
0 .425 .836 r
.59064 .38231 m .58912 .38247 L .58751 .38113 L F
.677 .884 .513 r
.58617 .38302 m .58674 .38262 L .58692 .38227 L F
.58617 .38302 m .58692 .38227 L .58667 .38232 L F
.913 .879 .788 r
.58667 .38232 m .58728 .38477 L .58617 .38302 L F
.754 .346 0 r
.58672 .38231 m .58692 .38265 L .58672 .3824 L F
.58672 .38231 m .58672 .3824 L .58667 .38232 L F
.913 .879 .788 r
.58751 .38113 m .58737 .38339 L .58667 .38232 L F
.58737 .38339 m .58728 .38477 L .58667 .38232 L F
.754 .346 0 r
.58667 .38232 m .58672 .3824 L .58665 .38232 L F
.497 0 0 r
.59064 .38231 m .58751 .38113 L .58606 .38144 L F
.891 .897 .826 r
.58424 .3819 m .58617 .38302 L .58667 .38232 L F
.887 .975 .83 r
.58453 .38183 m .58617 .38302 L .58436 .38197 L F
.891 .897 .826 r
.58406 .38187 m .58667 .38232 L .58606 .38144 L F
.497 0 0 r
.58579 .38177 m .58606 .38144 L .58415 .38185 L F
.887 .975 .83 r
.58611 .38166 m .58692 .38265 L .58579 .38177 L F
.497 0 0 r
.58614 .38175 m .58611 .38166 L .58579 .38177 L F
.58611 .38166 m .58606 .38144 L .58579 .38177 L F
.887 .975 .83 r
.58579 .38177 m .58692 .38265 L .58617 .38302 L F
.58556 .38098 m .58611 .38166 L .58579 .38177 L F
.58556 .38098 m .58579 .38177 L .58453 .38183 L F
.58579 .38177 m .58617 .38302 L .58453 .38183 L F
.497 0 0 r
.5862 .38202 m .58614 .38175 L .58406 .38187 L F
.58614 .38175 m .58415 .38185 L .58406 .38187 L F
.754 .346 0 r
.58672 .38231 m .58665 .38232 L .58556 .38098 L F
.497 0 0 r
.59064 .38231 m .58606 .38144 L .5862 .38202 L F
.887 .975 .83 r
.58436 .38197 m .58617 .38302 L .58407 .38221 L F
.891 .897 .826 r
.58406 .38187 m .58617 .38302 L .58424 .3819 L F
.729 .599 .711 r
.65865 .36323 m .66229 .36344 L .66122 .36028 L F
.247 .305 .726 r
.46706 .56256 m .46595 .56696 L .46458 .56053 L F
.46595 .56696 m .46594 .567 L .46593 .56695 L F
.46595 .56696 m .46593 .56695 L .46458 .56053 L F
.262 0 0 r
.46445 .5665 m .46592 .56695 L .46534 .56675 L F
0 .374 .684 r
.46561 .56685 m .46445 .5665 L .46325 .56583 L F
.46594 .567 m .46445 .5665 L .46561 .56685 L F
.262 0 0 r
.46445 .5665 m .46643 .56712 L .46592 .56695 L F
.46445 .5665 m .46611 .56704 L .46643 .56712 L F
.478 .498 .8 r
.46595 .56696 m .46611 .56704 L .46594 .567 L F
.262 0 0 r
.46595 .56696 m .46643 .56712 L .46581 .56688 L F
.478 .498 .8 r
.46706 .56256 m .46611 .56704 L .46595 .56696 L F
.262 0 0 r
.46581 .56688 m .46643 .56712 L .46786 .56746 L F
.46534 .56675 m .46595 .56696 L .46581 .56688 L F
0 .308 .781 r
.46881 .56734 m .46786 .56746 L .46611 .56704 L F
.46881 .56734 m .47033 .56908 L .46786 .56746 L F
.857 .857 .403 r
.40383 .59625 m .40275 .5982 L .40288 .59897 L F
.973 .915 .587 r
.40418 .59195 m .40319 .59566 L .40383 .59625 L F
.981 .812 .408 r
.40319 .59566 m .40275 .5982 L .40383 .59625 L F
.738 .97 .931 r
.60404 .36079 m .60213 .36241 L .60085 .36177 L F
.676 .348 .412 r
.56649 .43243 m .57001 .4322 L .56815 .42977 L F
.777 .337 .207 r
.57001 .4322 m .57052 .43158 L .56815 .42977 L F
.518 .474 .746 r
.38553 .60299 m .38857 .605 L .38786 .60254 L F
.23 .456 .871 r
.42733 .53698 m .42901 .53724 L .42808 .53896 L F
.543 .841 .999 r
.43064 .53823 m .42901 .53724 L .42808 .53896 L F
.701 .983 .825 r
.42808 .53896 m .42593 .53972 L .42901 .53724 L F
.543 .841 .999 r
.43064 .53823 m .42901 .53724 L .42808 .53896 L F
.557 .174 .271 r
.59949 .45594 m .5986 .45809 L .59565 .45816 L F
.534 .151 .261 r
.59949 .45594 m .6021 .45739 L .5986 .45809 L F
.546 .121 .186 r
.59949 .45594 m .60208 .45619 L .6021 .45739 L F
.823 .858 .873 r
.64182 .34709 m .64207 .34995 L .63889 .34984 L F
.843 .833 .836 r
.63889 .34984 m .64207 .34995 L .64047 .35147 L F
.826 .86 .871 r
.64489 .34693 m .64207 .34995 L .64182 .34709 L F
.885 .708 .657 r
.57471 .39889 m .57397 .40141 L .57235 .3976 L F
.65 .35 .451 r
.5443 .44978 m .54184 .45181 L .54044 .4488 L F
.5443 .44978 m .54441 .45193 L .54184 .45181 L F
0 0 0 r
.34706 .51706 m .34383 .52007 L .34576 .5186 L F
.34576 .5186 m .3493 .51511 L .34706 .51706 L F
.544 .884 .987 r
.61028 .37094 m .61397 .37086 L .61332 .37031 L F
.539 .586 .85 r
.61128 .37446 m .61527 .3759 L .61469 .37322 L F
.991 .733 .412 r
.61669 .3716 m .61527 .3759 L .61469 .37322 L F
.61669 .3716 m .61661 .37423 L .61527 .3759 L F
.359 .473 .84 r
.61661 .37423 m .61527 .3759 L .61439 .37337 L F
.352 .122 .419 r
.61397 .37086 m .61213 .37332 L .61469 .37322 L F
.61213 .37332 m .61426 .37337 L .61469 .37322 L F
.47 .202 .424 r
.61669 .3716 m .61397 .37086 L .61469 .37322 L F
.359 .473 .84 r
.61592 .37341 m .61439 .37337 L .61332 .37031 L F
.61661 .37423 m .61439 .37337 L .61592 .37341 L F
.352 .122 .419 r
.61213 .37332 m .61128 .37446 L .61426 .37337 L F
0 .459 .79 r
.61332 .37031 m .61397 .37086 L .61669 .3716 L F
.843 .653 .645 r
.54837 .45503 m .55192 .45575 L .55013 .4587 L F
.633 .896 .576 r
.6207 .3951 m .62241 .39317 L .62138 .39399 L F
0 0 .066 r
.6203 .39794 m .6207 .3951 L .62138 .39399 L F
.533 .588 .856 r
.61332 .37031 m .61128 .37446 L .60936 .37394 L F
.61332 .37031 m .61527 .3759 L .61128 .37446 L F
.985 .721 .346 r
.69384 .31975 m .69477 .31841 L .6937 .31721 L F
.636 .907 .983 r
.62216 .38243 m .6236 .38333 L .62612 .38207 L F
.096 .159 .64 r
.32136 .68687 m .32243 .69171 L .32349 .69165 L F
.82 .72 .755 r
.56505 .42332 m .56649 .42718 L .56335 .42697 L F
.814 .631 .654 r
.53417 .42795 m .53378 .43019 L .53218 .4268 L F
.341 .079 .362 r
.36056 .69166 m .35868 .69241 L .35808 .69472 L F
.661 .299 .349 r
.24497 .56394 m .24248 .5667 L .24657 .56633 L F
.563 .605 .853 r
.25378 .62809 m .25565 .63166 L .25783 .63096 L F
.799 .333 0 r
.38569 .5226 m .38701 .52508 L .38838 .52614 L F
.991 .742 .447 r
.38701 .52508 m .38831 .52904 L .38838 .52614 L F
.427 .217 .49 r
.31035 .59624 m .3128 .59859 L .31293 .59575 L F
.31035 .59624 m .31063 .59977 L .3128 .59859 L F
.654 .5 .662 r
.28821 .536 m .28819 .53873 L .29086 .53591 L F
.28821 .536 m .28819 .53873 L .29086 .53591 L F
.071 .28 .768 r
.70584 .33963 m .70456 .34114 L .70265 .33703 L F
.394 .756 .993 r
.70584 .33963 m .70708 .34071 L .70456 .34114 L F
.269 0 .188 r
.32344 .68569 m .32136 .68687 L .3224 .68785 L F
.096 .159 .64 r
.32136 .68687 m .32349 .69165 L .3224 .68785 L F
.817 .993 .866 r
.63968 .44297 m .64276 .44027 L .64054 .44063 L F
.867 .985 .84 r
.64276 .44027 m .64559 .43714 L .64326 .43753 L F
.865 .985 .843 r
.64276 .44027 m .64326 .43753 L .64054 .44063 L F
.91 .528 .283 r
.62609 .387 m .62836 .38855 L .62741 .38565 L F
.99 .87 .526 r
.40167 .56592 m .4033 .56427 L .40186 .5633 L F
.40167 .56592 m .40222 .56764 L .4033 .56427 L F
.856 .817 .811 r
.68655 .30606 m .68236 .30774 L .68523 .3046 L F
.68655 .30606 m .68395 .30946 L .68236 .30774 L F
.48 .801 1 r
.36571 .57984 m .36797 .57911 L .36551 .5797 L F
.36725 .58086 m .36797 .57911 L .36571 .57984 L F
.626 .857 .986 r
.36797 .57911 m .37209 .57926 L .37044 .57829 L F
.727 .376 .384 r
.37044 .57829 m .36991 .57849 L .36797 .57911 L F
.319 .722 .979 r
.36402 .57998 m .36725 .58086 L .36551 .5797 L F
.48 .801 1 r
.36725 .58086 m .37015 .58045 L .36797 .57911 L F
.626 .857 .986 r
.36797 .57911 m .37015 .58045 L .37209 .57926 L F
.319 .722 .979 r
.36313 .57974 m .36402 .57998 L .36551 .5797 L F
.27 .072 .417 r
.36464 .58149 m .36313 .57974 L .36551 .5797 L F
.36464 .58149 m .3627 .58245 L .36296 .58078 L F
.3638 .58052 m .36296 .58078 L .36313 .57974 L F
.36464 .58149 m .36296 .58078 L .3638 .58052 L F
.727 .376 .384 r
.36991 .57849 m .36774 .57931 L .36797 .57911 L F
.969 .885 .505 r
.3632 .58101 m .36464 .58149 L .36551 .5797 L F
.727 .376 .384 r
.36774 .57931 m .3632 .58101 L .3666 .57966 L F
.36774 .57931 m .3666 .57966 L .36797 .57911 L F
.969 .885 .505 r
.36736 .57935 m .36551 .5797 L .36797 .57911 L F
.3632 .58101 m .36551 .5797 L .36736 .57935 L F
.749 .304 0 r
.38576 .52367 m .38569 .5226 L .38315 .52172 L F
.38576 .52367 m .38701 .52508 L .38569 .5226 L F
0 0 .149 r
.65916 .38402 m .65684 .38582 L .65712 .38776 L F
.875 .515 .364 r
.29793 .64543 m .29743 .64105 L .29507 .64324 L F
.36 .826 .904 r
.29949 .65353 m .30022 .65381 L .29652 .65429 L F
.34 0 0 r
.29652 .65429 m .30022 .65381 L .29816 .65499 L F
.78 .998 .836 r
.29987 .65278 m .30022 .65381 L .29949 .65353 L F
.042 .33 .812 r
.29732 .65022 m .29904 .65286 L .29588 .65072 L F
.29904 .65286 m .29949 .65353 L .29815 .65249 L F
.29904 .65286 m .29815 .65249 L .29588 .65072 L F
.36 .826 .904 r
.29949 .65353 m .29652 .65429 L .29588 .65072 L F
.397 .547 .888 r
.29987 .65278 m .29949 .65353 L .29732 .65022 L F
.849 .99 .725 r
.29816 .65499 m .30022 .65381 L .29987 .65278 L F
.352 .098 .383 r
.29816 .65499 m .29963 .65309 L .29971 .65454 L F
.29963 .65309 m .29987 .65278 L .29984 .65318 L F
.29963 .65309 m .29984 .65318 L .29971 .65454 L F
.887 .716 .665 r
.52892 .42309 m .53212 .42394 L .53042 .42559 L F
.847 .639 .62 r
.53212 .42394 m .53218 .4268 L .53042 .42559 L F
.685 .691 .85 r
.2182 .59963 m .22255 .60046 L .22102 .59916 L F
.658 .83 .966 r
.22255 .60046 m .22558 .59993 L .22102 .59916 L F
.605 .295 .418 r
.22255 .60046 m .2245 .60198 L .22558 .59993 L F
.616 .937 .957 r
.27476 .52514 m .27305 .52484 L .27248 .52629 L F
.591 .917 .973 r
.27305 .52484 m .27078 .52584 L .27248 .52629 L F
.726 .838 .934 r
.20493 .60506 m .20689 .60649 L .20915 .60498 L F
.259 .129 .507 r
.35321 .56449 m .35576 .5603 L .3535 .56341 L F
.35321 .56449 m .35535 .5635 L .35576 .5603 L F
.251 .111 .488 r
.35337 .56684 m .35535 .5635 L .35321 .56449 L F
.832 .397 .2 r
.29439 .6117 m .29628 .61249 L .29391 .61022 L F
.609 .955 .878 r
.63558 .44462 m .63968 .44297 L .63869 .44212 L F
.817 .993 .866 r
.63968 .44297 m .64054 .44063 L .63869 .44212 L F
.681 .76 .911 r
.60776 .36169 m .60404 .36079 L .60703 .36048 L F
.505 .751 .984 r
.60977 .3598 m .60776 .36169 L .60703 .36048 L F
.60977 .3598 m .61154 .36169 L .60776 .36169 L F
.594 .628 .855 r
.61258 .36388 m .60776 .36169 L .61154 .36169 L F
.422 .782 .996 r
.27902 .51781 m .27741 .51863 L .27654 .5175 L F
.558 .534 .784 r
.63314 .44304 m .63434 .43828 L .63187 .43935 L F
.63314 .44304 m .63574 .4426 L .63434 .43828 L F
.521 .337 .572 r
.63336 .44613 m .63574 .4426 L .63314 .44304 L F
.962 .663 .245 r
.39787 .54189 m .39815 .54606 L .39901 .54615 L F
.878 .452 .048 r
.39815 .54606 m .39984 .54798 L .39901 .54615 L F
.974 .664 .336 r
.32719 .55101 m .32748 .55275 L .32577 .55024 L F
.876 .944 .855 r
.32719 .55101 m .32577 .55024 L .32871 .54682 L F
.597 .922 .97 r
.32768 .69658 m .32929 .69709 L .33225 .69581 L F
.702 .852 .954 r
.62758 .40426 m .62521 .40567 L .62381 .40417 L F
.863 .927 .868 r
.69368 .296 m .68976 .29786 L .69244 .29466 L F
.85 .819 .818 r
.69468 .2914 m .69368 .296 L .69244 .29466 L F
.69468 .2914 m .69628 .29278 L .69368 .296 L F
0 0 .197 r
.69757 .33878 m .69804 .33997 L .69777 .33927 L F
.974 .915 .586 r
.69765 .33629 m .69743 .3384 L .69757 .33878 L F
.892 .699 .186 r
.69765 .33629 m .69757 .33878 L .69714 .33765 L F
0 0 .197 r
.69757 .33878 m .69777 .33927 L .69714 .33765 L F
.974 .915 .586 r
.69743 .3384 m .69714 .34105 L .69757 .33878 L F
0 0 .261 r
.69682 .34341 m .69757 .33878 L .69714 .34105 L F
.483 .28 .527 r
.35625 .54529 m .35886 .54205 L .3568 .54313 L F
.386 .131 .4 r
.46846 .57363 m .4684 .57605 L .46592 .5767 L F
.27 .124 .491 r
.47072 .57181 m .4684 .57605 L .46846 .57363 L F
.522 .028 .025 r
.60208 .45619 m .60604 .45596 L .60466 .45748 L F
.634 .156 .099 r
.60604 .45596 m .60865 .45781 L .60466 .45748 L F
.577 .245 .369 r
.60956 .45599 m .60865 .45781 L .60604 .45596 L F
0 0 .005 r
.35677 .53521 m .35597 .53829 L .35492 .53891 L F
0 0 .162 r
.35626 .5395 m .35492 .53891 L .35597 .53829 L F
.35626 .5395 m .35404 .5413 L .35492 .53891 L F
.652 .955 .744 r
.35234 .7148 m .35333 .71443 L .35415 .71306 L F
.844 .939 .887 r
.35174 .71652 m .35333 .71443 L .35234 .7148 L F
.35174 .71652 m .35415 .71306 L .35333 .71443 L F
.517 .813 .999 r
.30791 .6362 m .30681 .63774 L .30344 .63668 L F
0 0 .518 r
.30854 .64025 m .30681 .63774 L .30791 .6362 L F
0 0 .516 r
.30854 .64025 m .30706 .64049 L .30681 .63774 L F
.981 .747 .338 r
.39926 .55049 m .40017 .55168 L .39987 .54899 L F
.683 .688 .848 r
.39356 .6019 m .39059 .59883 L .39335 .59866 L F
0 0 .169 r
.38438 .7036 m .38478 .70526 L .38384 .70136 L F
0 .188 .642 r
.38479 .50262 m .38541 .50327 L .38394 .50204 L F
.38632 .50366 m .38541 .50327 L .38479 .50262 L F
.768 .897 .933 r
.38704 .50352 m .38571 .5036 L .38541 .50327 L F
.38571 .5036 m .38353 .50372 L .38541 .50327 L F
.328 0 .238 r
.34101 .55497 m .33785 .55724 L .33871 .55529 L F
0 .047 .583 r
.31866 .64711 m .32204 .65091 L .32101 .64618 L F
.961 .679 .248 r
.39941 .55292 m .40017 .55168 L .39926 .55049 L F
.39941 .55292 m .40039 .5545 L .40017 .55168 L F
.662 .973 .857 r
.27108 .51999 m .27169 .51866 L .27309 .51836 L F
.793 .833 .882 r
.71222 .36615 m .71374 .36774 L .71573 .36623 L F
.163 0 .292 r
.53072 .41908 m .52857 .42152 L .52892 .42309 L F
.594 .823 .434 r
.23719 .53259 m .23802 .53136 L .23961 .52923 L F
.602 .953 .862 r
.23719 .53259 m .23447 .53316 L .23802 .53136 L F
.334 .198 .542 r
.33192 .57937 m .32977 .57747 L .33202 .57653 L F
.33192 .57937 m .32984 .58026 L .32977 .57747 L F
0 .4 .834 r
.24026 .56218 m .24002 .55991 L .23949 .56031 L F
.24026 .56218 m .24086 .56143 L .24002 .55991 L F
.24026 .56218 m .24327 .56381 L .24086 .56143 L F
.857 .442 0 r
.60181 .41659 m .60077 .41395 L .59939 .4125 L F
0 0 .453 r
.60296 .41768 m .60077 .41395 L .60181 .41659 L F
.566 .058 0 r
.38831 .52904 m .39027 .53114 L .39119 .53188 L F
.913 .59 .113 r
.39068 .53362 m .39119 .53188 L .39027 .53114 L F
.39068 .53362 m .39163 .53487 L .39119 .53188 L F
.945 .584 .26 r
.39119 .53188 m .39163 .53487 L .39315 .53579 L F
.998 .792 .494 r
.23841 .54592 m .23978 .54761 L .2399 .54529 L F
.209 .389 .823 r
.2399 .54529 m .24051 .54362 L .23841 .54592 L F
.2399 .54529 m .24263 .54792 L .24051 .54362 L F
.773 .886 .926 r
.4335 .55176 m .43726 .55134 L .4358 .55036 L F
.653 .883 .982 r
.4358 .55036 m .43726 .55134 L .44022 .55027 L F
.38 .43 .787 r
.45683 .55401 m .45501 .55452 L .45389 .55215 L F
.643 .103 0 r
.39352 .5384 m .39538 .54049 L .39787 .54189 L F
.964 .641 .347 r
.39582 .54333 m .39787 .54189 L .39538 .54049 L F
.39582 .54333 m .39815 .54606 L .39787 .54189 L F
.84 .821 .83 r
.69583 .28941 m .69628 .29278 L .69468 .2914 L F
.826 .812 .837 r
.69583 .28941 m .69909 .2897 L .69628 .29278 L F
.873 .899 .847 r
.58509 .42585 m .58211 .42642 L .58469 .42555 L F
.58211 .42642 m .58509 .42585 L .58469 .42555 L F
.822 .808 .837 r
.26291 .54986 m .26697 .54814 L .26589 .54769 L F
.809 .968 .905 r
.26839 .54503 m .26697 .54814 L .26788 .54663 L F
.26839 .54503 m .26589 .54769 L .26697 .54814 L F
.346 0 .156 r
.35625 .54529 m .35729 .5466 L .35876 .54472 L F
.35625 .54529 m .35537 .54714 L .35729 .5466 L F
.483 .28 .527 r
.35625 .54529 m .35876 .54472 L .35886 .54205 L F
.325 .377 .762 r
.36601 .58996 m .36826 .59258 L .3663 .58783 L F
.972 .709 .474 r
.3781 .65277 m .37995 .65378 L .37802 .65572 L F
.964 .672 .429 r
.3881 .70037 m .38971 .69846 L .38912 .69776 L F
.3881 .70037 m .38986 .70142 L .38971 .69846 L F
.646 .842 .975 r
.63106 .37285 m .63252 .37028 L .62976 .3714 L F
.63106 .37285 m .63395 .37179 L .63252 .37028 L F
.691 .521 .653 r
.65856 .37636 m .66128 .37555 L .66113 .37301 L F
.589 .349 .52 r
.66128 .37555 m .66419 .37313 L .66113 .37301 L F
.839 .553 .505 r
.29723 .53584 m .29255 .53646 L .29485 .53405 L F
.29723 .53584 m .29675 .5383 L .29255 .53646 L F
.802 .65 .695 r
.34838 .51266 m .34508 .51277 L .34725 .50943 L F
.453 0 0 r
.34838 .51266 m .34356 .51297 L .34508 .51277 L F
.34838 .51266 m .34647 .51364 L .34356 .51297 L F
0 0 .112 r
.34881 .50856 m .34838 .51266 L .34725 .50943 L F
.515 .881 .663 r
.34876 .51181 m .34838 .51266 L .34887 .51098 L F
.34876 .51181 m .34647 .51364 L .34838 .51266 L F
.493 .248 .472 r
.37237 .60896 m .37514 .60622 L .37275 .60599 L F
.316 .391 .781 r
.45403 .54386 m .45249 .546 L .45124 .54213 L F
.323 .4 .787 r
.45403 .54386 m .45527 .54766 L .45249 .546 L F
.242 .401 .822 r
.45249 .546 m .45527 .54766 L .45422 .54813 L F
.931 .568 .155 r
.39163 .53487 m .39352 .5384 L .39315 .53579 L F
.964 .852 .682 r
.62877 .39217 m .62836 .38855 L .62747 .39035 L F
0 0 .424 r
.3329 .51704 m .33448 .5197 L .3371 .51424 L F
.3329 .51704 m .33495 .52132 L .33448 .5197 L F
0 0 0 r
.67219 .36827 m .67296 .36671 L .67045 .36993 L F
.325 0 .226 r
.67554 .3659 m .67296 .36671 L .67219 .36827 L F
.829 .813 .835 r
.65955 .33482 m .6568 .33795 L .6552 .33628 L F
.654 .856 .977 r
.62385 .39056 m .62241 .39317 L .62492 .39193 L F
.53 .286 .49 r
.3159 .55419 m .31451 .55799 L .31196 .55819 L F
.404 .411 .753 r
.31658 .55138 m .3159 .55419 L .31417 .55209 L F
.31658 .55138 m .31736 .55489 L .3159 .55419 L F
.566 .322 .506 r
.31777 .55643 m .3159 .55419 L .31736 .55489 L F
.31777 .55643 m .31451 .55799 L .3159 .55419 L F
.589 .349 .52 r
.66128 .37555 m .66444 .37507 L .66419 .37313 L F
.464 .122 .3 r
.66704 .37597 m .66419 .37313 L .66444 .37507 L F
.66704 .37597 m .66718 .3721 L .66419 .37313 L F
.425 .661 .959 r
.29319 .64373 m .29499 .64556 L .29767 .64518 L F
0 0 0 r
.43935 .55791 m .43974 .55637 L .4401 .55414 L F
.49 .548 .843 r
.43935 .55791 m .44312 .56115 L .44172 .5595 L F
.828 .898 .89 r
.56235 .41311 m .56402 .41501 L .56091 .41738 L F
.701 .864 .959 r
.56625 .41314 m .56402 .41501 L .56235 .41311 L F
.604 .405 .585 r
.58931 .45866 m .58676 .46165 L .58657 .45899 L F
.466 .63 .925 r
.32792 .53777 m .33004 .53696 L .32717 .5367 L F
.643 .682 .872 r
.61396 .36087 m .61258 .36388 L .61154 .36169 L F
.61396 .36087 m .61524 .36293 L .61258 .36388 L F
.973 .663 .349 r
.56107 .40651 m .56312 .4087 L .5627 .40951 L F
.54 .745 .971 r
.56548 .40747 m .56312 .4087 L .56107 .40651 L F
0 0 0 r
.5627 .40951 m .56312 .4087 L .56548 .40747 L F
.126 0 0 r
.67045 .36993 m .66718 .3721 L .6694 .37127 L F
0 0 0 r
.67219 .36827 m .67045 .36993 L .6694 .37127 L F
.014 0 .292 r
.3587 .53189 m .35677 .53521 L .35712 .53334 L F
.465 .251 .503 r
.42631 .54991 m .42385 .5485 L .42594 .54736 L F
.42631 .54991 m .42336 .55087 L .42385 .5485 L F
.835 .967 .888 r
.64589 .43457 m .64559 .43714 L .64703 .43518 L F
.87 .984 .838 r
.64326 .43753 m .64559 .43714 L .64589 .43457 L F
.475 .113 .27 r
.33868 .54439 m .3423 .54259 L .33879 .54236 L F
.33868 .54439 m .34157 .54437 L .3423 .54259 L F
.83 .775 .8 r
.69331 .31153 m .69684 .30857 L .69564 .30747 L F
.719 .902 .961 r
.69865 .30592 m .69684 .30857 L .69969 .30784 L F
.69865 .30592 m .69564 .30747 L .69684 .30857 L F
.967 .649 .275 r
.60227 .41959 m .60296 .41768 L .60181 .41659 L F
.60227 .41959 m .60371 .4216 L .60296 .41768 L F
.706 .636 .776 r
.43523 .48111 m .43238 .48197 L .43099 .47829 L F
.014 0 .292 r
.3587 .53189 m .35854 .53421 L .35677 .53521 L F
.655 .293 .346 r
.35972 .53769 m .35677 .53521 L .35854 .53421 L F
.35972 .53769 m .35597 .53829 L .35677 .53521 L F
.601 .623 .845 r
.44174 .48383 m .43929 .48465 L .43756 .48059 L F
.764 .621 .701 r
.44174 .48383 m .43897 .48696 L .43929 .48465 L F
.422 .198 .466 r
.3344 .55197 m .33693 .55135 L .33755 .54847 L F
.31 0 .189 r
.3344 .55197 m .3326 .55454 L .33693 .55135 L F
.567 .895 .642 r
.23961 .52923 m .24068 .52799 L .24163 .52741 L F
0 0 0 r
.23961 .52923 m .23802 .53136 L .24068 .52799 L F
.36149 .53877 m .35886 .54205 L .36034 .54075 L F
.467 .257 .51 r
.36149 .53877 m .36387 .53825 L .36401 .53566 L F
.991 .881 .563 r
.40543 .58682 m .40374 .58841 L .40459 .58937 L F
.40448 .58581 m .40374 .58841 L .40543 .58682 L F
0 0 .096 r
.56991 .42484 m .56964 .42474 L .5715 .42279 L F
0 0 .27 r
.30686 .6434 m .30706 .64049 L .30854 .64025 L F
.693 .49 .607 r
.67693 .39029 m .68104 .38859 L .67972 .38971 L F
.67693 .39029 m .67859 .38884 L .68104 .38859 L F
.55 .405 .637 r
.68363 .38548 m .68104 .38859 L .68145 .38529 L F
.68363 .38548 m .68379 .38809 L .68104 .38859 L F
.219 .742 .808 r
.68104 .38859 m .68185 .38811 L .67972 .38971 L F
.68104 .38859 m .68379 .38809 L .68185 .38811 L F
.433 .165 .406 r
.67472 .39193 m .67203 .39486 L .67184 .39208 L F
0 0 0 r
.22558 .59993 m .2245 .60198 L .2271 .5986 L F
.582 .365 .551 r
.30063 .61474 m .30357 .61174 L .30101 .61229 L F
.461 .496 .808 r
.44907 .51803 m .44691 .5198 L .44592 .51658 L F
.43 .345 .659 r
.44907 .51803 m .44707 .52272 L .44691 .5198 L F
0 0 0 r
.34367 .59881 m .34733 .59598 L .34632 .59823 L F
.443 .08 .252 r
.34987 .59577 m .34632 .59823 L .34733 .59598 L F
.444 .575 .891 r
.39528 .68506 m .39361 .68576 L .39179 .68248 L F
.828 .898 .89 r
.56235 .41311 m .56091 .41738 L .56003 .41602 L F
.981 .835 .44 r
.56003 .41602 m .56091 .41738 L .55971 .41902 L F
.275 .639 .965 r
.39582 .51929 m .39543 .51764 L .39234 .51588 L F
.39582 .51929 m .39655 .51904 L .39543 .51764 L F
.7 .971 .751 r
.3375 .60952 m .34001 .60837 L .3408 .60661 L F
.202 0 .261 r
.42707 .58329 m .42855 .58094 L .42985 .58001 L F
.875 .508 .022 r
.40753 .49913 m .40862 .50143 L .40895 .50103 L F
.295 .01 .299 r
.45411 .58582 m .45136 .58924 L .45159 .58639 L F
.14 0 .325 r
.311 .61774 m .3088 .62126 L .30933 .61874 L F
.433 .491 .819 r
.34087 .7039 m .34199 .70701 L .34423 .70693 L F
.57 .725 .947 r
.31658 .55138 m .31417 .55209 L .31233 .55034 L F
.745 .435 .458 r
.32001 .54869 m .31881 .55084 L .31505 .54982 L F
.57 .725 .947 r
.31658 .55138 m .31233 .55034 L .31505 .54982 L F
.466 .456 .763 r
.31881 .55084 m .31658 .55138 L .31505 .54982 L F
.201 0 .231 r
.31505 .54982 m .31625 .55188 L .31693 .55004 L F
.079 0 0 r
.31772 .54833 m .31505 .54982 L .31405 .5497 L F
.745 .435 .458 r
.32001 .54869 m .31505 .54982 L .31772 .54833 L F
.201 0 .231 r
.31505 .54982 m .31693 .55004 L .31808 .54694 L F
.079 0 0 r
.31405 .5497 m .31505 .54982 L .31233 .55034 L F
.454 .376 .679 r
.44828 .52899 m .44872 .5317 L .44648 .5321 L F
.58 .775 .972 r
.27476 .52514 m .27882 .52595 L .27734 .52424 L F
.609 .757 .949 r
.27734 .52424 m .27882 .52595 L .28109 .525 L F
.455 .743 .99 r
.41203 .49713 m .4132 .49552 L .40955 .49424 L F
.41203 .49713 m .41524 .49683 L .4132 .49552 L F
.054 .619 .767 r
.25089 .53148 m .24829 .53135 L .24742 .5314 L F
.197 .722 .85 r
.25233 .53119 m .24829 .53135 L .25089 .53148 L F
.614 .19 .215 r
.25233 .53119 m .25166 .53341 L .24829 .53135 L F
.098 .36 .827 r
.24829 .53135 m .25166 .53341 L .25079 .53119 L F
.24829 .53135 m .25079 .53119 L .25005 .52932 L F
.054 .619 .767 r
.24742 .5314 m .24829 .53135 L .246 .53137 L F
.528 .271 .469 r
.26688 .56368 m .27013 .56116 L .2661 .56094 L F
.26688 .56368 m .26988 .56361 L .27013 .56116 L F
0 0 .003 r
.35876 .54472 m .36034 .54075 L .35886 .54205 L F
.955 .773 .32 r
.40361 .58092 m .40471 .58034 L .40367 .57893 L F
.40361 .58092 m .40447 .58288 L .40471 .58034 L F
.513 .859 .993 r
.38561 .67948 m .38147 .6795 L .38401 .67885 L F
.176 0 .164 r
.38607 .67746 m .38838 .67617 L .38561 .67948 L F
.717 .935 .959 r
.38561 .67948 m .38401 .67885 L .38607 .67746 L F
.713 .49 .586 r
.36768 .62134 m .37147 .61818 L .369 .61826 L F
.527 .351 .586 r
.70931 .32198 m .70961 .32463 L .70686 .32518 L F
.622 .485 .674 r
.70961 .32463 m .70709 .32661 L .70686 .32518 L F
.306 .796 .769 r
.59797 .38554 m .59699 .38614 L .59596 .38685 L F
0 0 0 r
.69851 .33192 m .69892 .33139 L .6968 .33407 L F
.763 .293 0 r
.6973 .32992 m .69892 .33139 L .69851 .33192 L F
0 0 0 r
.2511 .61503 m .25149 .61542 L .25361 .61482 L F
.603 .331 .478 r
.25149 .61542 m .25202 .61507 L .25361 .61482 L F
0 0 0 r
.2511 .61503 m .25361 .61482 L .25469 .61465 L F
.603 .331 .478 r
.25202 .61507 m .2551 .61303 L .25361 .61482 L F
0 0 0 r
.25469 .61465 m .25361 .61482 L .25513 .6146 L F
.641 .966 .877 r
.25513 .6146 m .25548 .61379 L .2576 .61495 L F
.874 .648 .594 r
.26692 .63115 m .268 .63174 L .26438 .63054 L F
.812 .33 .039 r
.268 .63174 m .26883 .63317 L .26699 .63273 L F
.378 .238 .561 r
.7083 .36006 m .71095 .3621 L .7096 .35784 L F
.7083 .36006 m .70852 .36237 L .71095 .3621 L F
.524 .651 .914 r
.2238 .60892 m .22406 .60513 L .22325 .60506 L F
.2238 .60892 m .22605 .60845 L .22406 .60513 L F
.767 .651 .734 r
.65584 .36629 m .65865 .36323 L .65598 .36343 L F
.745 .658 .764 r
.65328 .36938 m .65584 .36629 L .65212 .36625 L F
.602 .467 .669 r
.33484 .58631 m .33477 .58907 L .33214 .5894 L F
.375 .452 .813 r
.33537 .59119 m .33214 .5894 L .33477 .58907 L F
.263 .085 .442 r
.30636 .6059 m .30613 .60856 L .30819 .60502 L F
0 0 .251 r
.70277 .33462 m .70424 .33047 L .70458 .33327 L F
0 0 .354 r
.70265 .33703 m .70277 .33462 L .70458 .33327 L F
.74 .668 .779 r
.28819 .53873 m .28547 .54052 L .28711 .53986 L F
.381 .145 .426 r
.28711 .53986 m .29034 .53963 L .28819 .53873 L F
.552 .291 .475 r
.43934 .59329 m .43923 .59589 L .43664 .59602 L F
.621 .348 .483 r
.44242 .59462 m .43934 .59329 L .44303 .59284 L F
.44242 .59462 m .43923 .59589 L .43934 .59329 L F
.557 .537 .788 r
.3368 .56721 m .33494 .5706 L .33416 .5677 L F
.3368 .56721 m .33784 .57005 L .33494 .5706 L F
.506 .294 .526 r
.33784 .57005 m .33494 .57322 L .33494 .5706 L F
.504 .287 .518 r
.36401 .53566 m .36387 .53825 L .36676 .53547 L F
.54 .28 .47 r
.6833 .36131 m .68156 .3597 L .68129 .36186 L F
.6833 .36131 m .68395 .35918 L .68156 .3597 L F
0 .506 .854 r
.35349 .49946 m .35321 .49995 L .35169 .49877 L F
.35349 .49946 m .35526 .5005 L .35321 .49995 L F
.635 .472 .644 r
.68306 .38312 m .68363 .38548 L .68145 .38529 L F
.558 .416 .644 r
.68603 .37984 m .68584 .3826 L .68306 .38312 L F
.624 .464 .646 r
.6864 .38472 m .68306 .38312 L .68584 .3826 L F
.6864 .38472 m .68363 .38548 L .68306 .38312 L F
.313 .029 .311 r
.29835 .55006 m .29656 .54829 L .29883 .54766 L F
.29835 .55006 m .29611 .55111 L .29656 .54829 L F
0 .345 .769 r
.59792 .41131 m .59642 .41104 L .59457 .40988 L F
.59792 .41131 m .59939 .4125 L .59642 .41104 L F
0 0 0 r
.22547 .56049 m .2226 .56399 L .22382 .56174 L F
.774 .737 .819 r
.65971 .35329 m .66349 .3538 L .66264 .35049 L F
.84 .808 .82 r
.66349 .3538 m .66473 .34888 L .66264 .35049 L F
.66349 .3538 m .66611 .35059 L .66473 .34888 L F
.71 .599 .731 r
.28446 .53902 m .28547 .54052 L .28819 .53873 L F
.924 .59 .389 r
.28446 .53902 m .28382 .54088 L .28547 .54052 L F
.35 .265 .618 r
.4561 .55005 m .45422 .54813 L .45527 .54766 L F
.4561 .55005 m .45389 .55215 L .45422 .54813 L F
.425 .021 .167 r
.27771 .55716 m .28017 .55702 L .282 .5545 L F
.229 0 0 r
.28017 .55702 m .2864 .55524 L .282 .5545 L F
.854 .824 .818 r
.65328 .35588 m .65681 .35669 L .65516 .35479 L F
.65328 .35588 m .65443 .35952 L .65681 .35669 L F
.817 .88 .891 r
.65516 .35479 m .65681 .35669 L .65971 .35329 L F
.805 .509 .488 r
.54441 .45193 m .54831 .45271 L .54837 .45503 L F
.746 .698 .806 r
.36456 .67905 m .3665 .67551 L .36538 .67618 L F
.553 .523 .776 r
.46458 .56053 m .46325 .56583 L .46232 .56086 L F
.601 .816 .982 r
.24499 .55764 m .24929 .55809 L .24683 .55734 L F
.565 .238 .374 r
.25044 .55697 m .24683 .55734 L .24929 .55809 L F
.381 0 .072 r
.33518 .5419 m .33099 .54427 L .33293 .54321 L F
.87 .758 .736 r
.56548 .40747 m .56864 .40793 L .56621 .40987 L F
.463 .775 .997 r
.39061 .49851 m .39225 .49973 L .38953 .50003 L F
.53 .335 .56 r
.38953 .50003 m .39225 .49973 L .39061 .49851 L F
.38953 .50003 m .38956 .503 L .39225 .49973 L F
.38 .43 .787 r
.45683 .55401 m .45389 .55215 L .4561 .55005 L F
0 0 .504 r
.41367 .56105 m .41374 .5594 L .41235 .55694 L F
.899 .606 .104 r
.41367 .56105 m .41307 .56227 L .41374 .5594 L F
.41367 .56105 m .41371 .56309 L .41307 .56227 L F
.52 0 0 r
.33709 .69825 m .34 .70003 L .34029 .70041 L F
.087 .644 .787 r
.31791 .52395 m .32091 .52383 L .3206 .52389 L F
.8 .991 .747 r
.34617 .68811 m .34389 .69142 L .34388 .69137 L F
.453 .272 .544 r
.37101 .58616 m .37326 .58259 L .37102 .58347 L F
.623 .099 0 r
.64478 .42072 m .64379 .42208 L .64414 .41936 L F
0 0 .051 r
.6439 .42165 m .64414 .41936 L .64379 .42208 L F
.951 .748 .288 r
.64437 .41728 m .64478 .42072 L .64414 .41936 L F
0 0 .051 r
.64493 .41747 m .64414 .41936 L .6439 .42165 L F
.951 .748 .288 r
.64437 .41725 m .64437 .41728 L .64414 .41936 L F
.623 .099 0 r
.64478 .42072 m .6475 .42245 L .64379 .42208 L F
.64478 .42072 m .6475 .42245 L .64379 .42208 L F
.843 .636 .623 r
.35455 .52822 m .35858 .52604 L .35479 .52529 L F
.35455 .52822 m .35899 .53061 L .35858 .52604 L F
.742 .977 .921 r
.37391 .59625 m .3741 .59445 L .37267 .59371 L F
.37391 .59625 m .37629 .59473 L .3741 .59445 L F
.976 .871 .667 r
.3741 .59445 m .37264 .5972 L .37245 .59825 L F
.345 .52 .886 r
.37273 .59731 m .37245 .59825 L .37264 .5972 L F
.767 .854 .409 r
.37288 .59704 m .37245 .59825 L .37271 .5974 L F
.37301 .59695 m .37299 .59701 L .37288 .59704 L F
.37299 .59701 m .37245 .59825 L .37282 .59721 L F
.37299 .59701 m .37282 .59721 L .37288 .59704 L F
.345 .52 .886 r
.37593 .60114 m .37245 .59825 L .37273 .59731 L F
.37593 .60114 m .37424 .60136 L .37245 .59825 L F
.767 .854 .409 r
.3741 .59445 m .37301 .59695 L .37288 .59704 L F
.976 .871 .667 r
.3741 .59445 m .37629 .59473 L .37288 .59704 L F
.405 .807 .589 r
.37284 .59707 m .37629 .59473 L .37719 .59409 L F
.976 .871 .667 r
.3741 .59445 m .37288 .59704 L .37264 .5972 L F
.405 .807 .589 r
.37264 .5972 m .37288 .59704 L .37284 .59707 L F
.37288 .59704 m .37629 .59473 L .37284 .59707 L F
.868 .427 .041 r
.37316 .59815 m .37329 .59829 L .37273 .59731 L F
.37329 .59829 m .37593 .60114 L .37336 .59806 L F
.37329 .59829 m .37336 .59806 L .37273 .59731 L F
.865 .759 .743 r
.37245 .59825 m .37424 .60136 L .37058 .60145 L F
.795 .92 .536 r
.37245 .59825 m .37058 .60145 L .37119 .59976 L F
.055 0 0 r
.37245 .59825 m .37119 .59976 L .37314 .59885 L F
.868 .427 .041 r
.37464 .60067 m .37593 .60114 L .37316 .59815 L F
.37465 .60025 m .37338 .59833 L .37705 .59711 L F
.37338 .59833 m .37271 .59734 L .37548 .59719 L F
.37338 .59833 m .37548 .59719 L .37705 .59711 L F
.055 0 0 r
.37328 .59835 m .37326 .59839 L .37334 .59835 L F
.37328 .59835 m .37334 .59835 L .37294 .59778 L F
.868 .427 .041 r
.3744 .60058 m .37464 .60067 L .37316 .59815 L F
.3744 .60058 m .37273 .59731 L .37271 .59734 L F
.3744 .60058 m .37294 .59778 L .37465 .60025 L F
.37294 .59778 m .37271 .59734 L .37465 .60025 L F
.055 0 0 r
.37334 .59835 m .37314 .59885 L .37403 .59844 L F
.37326 .59839 m .37314 .59885 L .37334 .59835 L F
.37245 .59825 m .37314 .59885 L .37328 .59835 L F
.37294 .59778 m .37403 .59844 L .37269 .59736 L F
.37334 .59835 m .37403 .59844 L .37294 .59778 L F
.868 .427 .041 r
.37271 .59734 m .37273 .59731 L .37264 .5972 L F
.37271 .59734 m .37264 .5972 L .37278 .5972 L F
.37271 .59734 m .37278 .5972 L .37705 .59711 L F
.767 .854 .409 r
.3741 .59445 m .37265 .59752 L .37268 .5974 L F
.37274 .59728 m .37268 .5974 L .37269 .59739 L F
.3741 .59445 m .37268 .5974 L .37274 .59728 L F
.405 .807 .589 r
.37264 .5972 m .37284 .59707 L .37278 .5972 L F
.767 .854 .409 r
.37398 .59466 m .37269 .59739 L .37299 .5963 L F
.3741 .59445 m .37269 .59739 L .37398 .59466 L F
.405 .807 .589 r
.37278 .5972 m .37719 .59409 L .37705 .59711 L F
.37284 .59707 m .37719 .59409 L .37278 .5972 L F
.055 0 0 r
.37269 .59736 m .37403 .59844 L .37299 .5963 L F
.767 .854 .409 r
.37271 .5974 m .37245 .59825 L .37265 .59752 L F
.055 0 0 r
.37245 .59825 m .37328 .59835 L .37269 .59736 L F
.765 .498 .53 r
.37299 .5963 m .37532 .59507 L .3741 .59445 L F
.596 .736 .942 r
.37661 .5942 m .37319 .59028 L .37346 .58962 L F
.598 .358 .524 r
.37776 .58631 m .37626 .58946 L .37346 .58962 L F
.373 .149 .44 r
.37411 .58968 m .37626 .58946 L .37362 .5879 L F
.731 .867 .945 r
.37467 .59044 m .37498 .59105 L .37346 .58962 L F
.37498 .59105 m .37661 .5942 L .37424 .59076 L F
.37498 .59105 m .37424 .59076 L .37346 .58962 L F
.373 .149 .44 r
.37517 .59112 m .37636 .59158 L .37626 .58946 L F
.731 .867 .945 r
.3752 .59117 m .37661 .5942 L .37467 .59044 L F
.37636 .59158 m .37643 .59229 L .37495 .59063 L F
.37643 .59229 m .37661 .5942 L .37495 .59063 L F
.373 .149 .44 r
.37471 .59182 m .37636 .59158 L .37517 .59112 L F
.731 .867 .945 r
.37636 .59158 m .37467 .59044 L .37626 .58946 L F
.37467 .59044 m .37346 .58962 L .37626 .58946 L F
.373 .149 .44 r
.37471 .59182 m .37517 .59112 L .37467 .59044 L F
.37437 .59062 m .37467 .59044 L .37411 .58968 L F
.37471 .59182 m .37467 .59044 L .37437 .59062 L F
.37517 .59112 m .37626 .58946 L .37411 .58968 L F
.731 .867 .945 r
.37495 .59063 m .3752 .59117 L .37467 .59044 L F
.596 .736 .942 r
.37661 .5942 m .37216 .59268 L .37319 .59028 L F
.872 .89 .464 r
.37411 .58968 m .37216 .59268 L .37471 .59182 L F
.37362 .5879 m .37334 .58881 L .37411 .58968 L F
.37334 .58881 m .37216 .59268 L .37411 .58968 L F
.765 .498 .53 r
.37532 .59507 m .37719 .59409 L .3741 .59445 L F
.742 .977 .921 r
.37267 .59371 m .3741 .59445 L .37216 .59268 L F
.885 .716 .667 r
.24426 .54403 m .24657 .54528 L .24496 .5416 L F
.955 .78 .329 r
.41593 .58274 m .4153 .58181 L .41617 .58025 L F
.769 .559 0 r
.41617 .58025 m .41593 .57923 L .41565 .57642 L F
.892 .823 .352 r
.41617 .58025 m .4153 .58181 L .41593 .57923 L F
.835 .937 .894 r
.4045 .48886 m .40479 .48628 L .40631 .48729 L F
.4045 .48886 m .40198 .48856 L .40479 .48628 L F
.986 .719 .428 r
.36677 .5224 m .36519 .52341 L .36631 .52164 L F
.36677 .5224 m .36716 .52511 L .36519 .52341 L F
.932 .899 .499 r
.36677 .5224 m .36631 .52164 L .36726 .51925 L F
.721 .659 .788 r
.35922 .66918 m .3604 .67256 L .36315 .6697 L F
0 0 .52 r
.40159 .55663 m .40191 .55807 L .40039 .5545 L F
0 0 .225 r
.40167 .55672 m .40191 .55807 L .40159 .55663 L F
.40167 .55672 m .40261 .56074 L .40191 .55807 L F
.793 .833 .882 r
.71222 .36615 m .71573 .36623 L .71481 .36501 L F
.839 .975 .879 r
.71573 .36623 m .71801 .36228 L .71481 .36501 L F
.71573 .36623 m .71876 .36328 L .71801 .36228 L F
.631 .282 .36 r
.73534 .33647 m .73941 .33608 L .73879 .33418 L F
.727 .54 .639 r
.74222 .33316 m .73941 .33608 L .73879 .33418 L F
.74222 .33316 m .74084 .33614 L .73941 .33608 L F
.123 .134 .598 r
.74323 .32919 m .74222 .33316 L .74055 .3319 L F
.025 0 0 r
.74282 .3321 m .74084 .33614 L .74222 .33316 L F
.123 .134 .598 r
.74323 .32919 m .74282 .3321 L .74222 .33316 L F
.025 0 0 r
.74282 .3321 m .74078 .33495 L .74084 .33614 L F
.74274 .33221 m .74401 .33208 L .74078 .33495 L F
.74282 .3321 m .74294 .3321 L .74274 .33221 L F
.74294 .3321 m .74401 .33208 L .74274 .33221 L F
.621 .823 .978 r
.74055 .3319 m .74175 .3328 L .73879 .33418 L F
.74175 .3328 m .74222 .33316 L .74004 .3338 L F
.74175 .3328 m .74004 .3338 L .73879 .33418 L F
.011 0 .439 r
.73879 .33418 m .74078 .33495 L .74055 .3319 L F
.73879 .33418 m .73941 .33608 L .74078 .33495 L F
.029 0 0 r
.29485 .53405 m .29759 .53326 L .29994 .53112 L F
.3 .132 .479 r
.29994 .53112 m .30169 .53162 L .30196 .52872 L F
.448 0 0 r
.29994 .53112 m .30191 .53399 L .30169 .53162 L F
.29994 .53112 m .3003 .53317 L .30191 .53399 L F
.29994 .53112 m .29759 .53326 L .3003 .53317 L F
0 0 .55 r
.58157 .40862 m .58142 .40867 L .58022 .40652 L F
.744 .652 .759 r
.36181 .58969 m .36462 .59384 L .35945 .59266 L F
.77 .497 .521 r
.35945 .59266 m .36462 .59384 L .36278 .59651 L F
.086 .337 .811 r
.36459 .59162 m .36462 .59384 L .36181 .58969 L F
.754 .669 .767 r
.35786 .58901 m .36181 .58969 L .35945 .59266 L F
.77 .497 .521 r
.35945 .59266 m .36278 .59651 L .35941 .5954 L F
.664 .685 .86 r
.35941 .5954 m .36323 .59524 L .35996 .59127 L F
.924 .956 .63 r
.36316 .5955 m .36462 .59384 L .3646 .59253 L F
.36332 .59505 m .3646 .59253 L .36459 .59162 L F
.36316 .5955 m .3646 .59253 L .36332 .59505 L F
.738 .561 .654 r
.36278 .59651 m .35905 .59865 L .35941 .5954 L F
.618 .405 .571 r
.35905 .59865 m .36313 .59543 L .35941 .5954 L F
.924 .956 .63 r
.36342 .59504 m .36459 .59162 L .36413 .59427 L F
.618 .405 .571 r
.36326 .59533 m .36338 .59523 L .36328 .59524 L F
.924 .956 .63 r
.36332 .59505 m .36459 .59162 L .36357 .59461 L F
.664 .685 .86 r
.36328 .59524 m .36338 .59523 L .36331 .59516 L F
.924 .956 .63 r
.36328 .59524 m .36357 .59461 L .3631 .59598 L F
.36332 .59505 m .36357 .59461 L .36328 .59524 L F
.664 .685 .86 r
.36323 .59524 m .36328 .59524 L .36326 .5951 L F
.924 .956 .63 r
.36278 .59651 m .36295 .59627 L .36316 .5955 L F
.36295 .59627 m .36462 .59384 L .36316 .5955 L F
.36278 .59651 m .3633 .59512 L .3631 .59598 L F
.3633 .59512 m .36332 .59505 L .36326 .59533 L F
.3633 .59512 m .36326 .59533 L .3631 .59598 L F
.615 .48 .675 r
.36598 .59794 m .36332 .59675 L .36345 .59613 L F
0 0 .36 r
.36338 .59523 m .36347 .59602 L .36357 .59554 L F
.618 .405 .571 r
.36336 .59598 m .36347 .59602 L .36338 .59523 L F
.615 .48 .675 r
.36345 .59613 m .36278 .59651 L .36315 .59591 L F
.36332 .59675 m .36278 .59651 L .36345 .59613 L F
.36598 .59794 m .36335 .59606 L .36535 .59669 L F
.36335 .59606 m .36315 .59591 L .36338 .59599 L F
.36335 .59606 m .36338 .59599 L .36535 .59669 L F
0 0 .36 r
.36338 .59523 m .36357 .59554 L .36413 .59427 L F
.615 .48 .675 r
.36535 .59669 m .36338 .59599 L .36413 .59427 L F
.36338 .59599 m .36315 .59591 L .36413 .59427 L F
0 0 .36 r
.36357 .59554 m .3642 .59656 L .36413 .59427 L F
.615 .48 .675 r
.36598 .59794 m .36325 .59883 L .36278 .59651 L F
.618 .405 .571 r
.36265 .59848 m .36375 .59843 L .36326 .59533 L F
0 0 .36 r
.36357 .59554 m .36375 .59843 L .3642 .59656 L F
.36347 .59602 m .36375 .59843 L .36357 .59554 L F
.618 .405 .571 r
.36326 .59533 m .36336 .59598 L .36338 .59523 L F
.36336 .59598 m .36375 .59843 L .36347 .59602 L F
.738 .561 .654 r
.36278 .59651 m .36325 .59883 L .35905 .59865 L F
.618 .405 .571 r
.35905 .59865 m .36265 .59848 L .36326 .59533 L F
.664 .685 .86 r
.36328 .59524 m .36331 .59516 L .36326 .5951 L F
.332 .548 .911 r
.35996 .59127 m .36331 .59516 L .36413 .59427 L F
.36331 .59516 m .36338 .59523 L .36413 .59427 L F
.924 .956 .63 r
.3631 .59598 m .36342 .59504 L .36413 .59427 L F
.618 .405 .571 r
.36313 .59543 m .36326 .59533 L .36323 .59524 L F
.36326 .59533 m .36328 .59524 L .36323 .59524 L F
.36313 .59543 m .36323 .59524 L .35941 .5954 L F
.664 .685 .86 r
.36323 .59524 m .36326 .5951 L .35996 .59127 L F
.632 .264 .328 r
.56832 .46519 m .56665 .46757 L .56433 .46567 L F
.686 .329 .364 r
.56832 .46519 m .57087 .46759 L .56665 .46757 L F
.672 .336 .396 r
.57112 .46562 m .57087 .46759 L .56832 .46519 L F
.502 .292 .527 r
.57739 .44841 m .57719 .45134 L .57457 .44943 L F
.766 .659 .744 r
.33693 .55135 m .3326 .55454 L .33239 .55007 L F
0 .182 .706 r
.33163 .55474 m .33376 .55674 L .33225 .55308 L F
.396 .245 .555 r
.33167 .55743 m .33376 .55674 L .33163 .55474 L F
.706 .636 .776 r
.43523 .48111 m .43099 .47829 L .43366 .47741 L F
.482 .396 .682 r
.4374 .47788 m .43523 .48111 L .43366 .47741 L F
.4374 .47788 m .43756 .48059 L .43523 .48111 L F
.764 .78 .867 r
.65053 .35892 m .65443 .35952 L .65328 .35588 L F
.81 .704 .748 r
.65188 .36296 m .65443 .35952 L .65053 .35892 L F
.705 .548 .672 r
.65188 .36296 m .65598 .36343 L .65443 .35952 L F
.425 .24 .524 r
.31931 .52922 m .31927 .53183 L .32167 .52887 L F
0 0 .531 r
.41057 .54813 m .41036 .54677 L .40865 .54438 L F
0 0 .55 r
.41057 .54813 m .41226 .55031 L .41036 .54677 L F
.446 .637 .937 r
.44172 .5595 m .44312 .56115 L .44398 .55946 L F
.248 .095 .468 r
.44312 .56115 m .44507 .56279 L .44398 .55946 L F
.44312 .56115 m .4429 .56395 L .44507 .56279 L F
.977 .675 .342 r
.60512 .42432 m .60371 .4216 L .60429 .42266 L F
.627 .189 0 r
.60544 .42497 m .60512 .42432 L .60429 .42266 L F
.60544 .42497 m .60642 .42629 L .60512 .42432 L F
0 0 0 r
.61389 .44664 m .6138 .44626 L .61431 .44417 L F
.61389 .44664 m .6132 .44841 L .6138 .44626 L F
.752 .54 .608 r
.55395 .45908 m .54983 .46142 L .55013 .4587 L F
.55395 .45908 m .55393 .4618 L .54983 .46142 L F
.464 .8 .999 r
.27029 .62006 m .2697 .62157 L .26857 .6199 L F
.27029 .62006 m .27201 .62109 L .2697 .62157 L F
.491 .813 1 r
.27029 .62006 m .27439 .62056 L .27201 .62109 L F
.281 .783 .829 r
.26823 .62069 m .27171 .62019 L .27029 .62006 L F
.122 .655 .864 r
.27029 .62006 m .27236 .62009 L .27439 .62056 L F
.281 .783 .829 r
.27171 .62019 m .27236 .62009 L .27029 .62006 L F
.464 .8 .999 r
.27029 .62006 m .26857 .6199 L .2685 .6198 L F
.553 .664 .911 r
.27368 .62297 m .2697 .62157 L .27201 .62109 L F
.687 .703 .86 r
.3058 .66838 m .30738 .67051 L .30936 .66875 L F
.835 .798 .815 r
.6978 .28763 m .69909 .2897 L .69583 .28941 L F
.816 .908 .903 r
.70076 .2858 m .69909 .2897 L .6978 .28763 L F
.70076 .2858 m .70218 .28702 L .69909 .2897 L F
.242 0 .216 r
.29297 .63723 m .2956 .6344 L .29525 .63675 L F
.291 .066 .39 r
.29525 .63675 m .2956 .6344 L .29761 .63373 L F
.598 .249 .349 r
.26582 .56573 m .26988 .56361 L .26688 .56368 L F
.661 .395 .507 r
.30401 .62836 m .30355 .63113 L .30099 .63076 L F
.453 .209 .453 r
.30684 .63022 m .30401 .62836 L .30567 .62775 L F
.30684 .63022 m .30355 .63113 L .30401 .62836 L F
.374 .222 .542 r
.32188 .57103 m .32404 .57269 L .32418 .57015 L F
.32188 .57103 m .32082 .57472 L .32404 .57269 L F
.761 .96 .934 r
.63433 .40777 m .63553 .40854 L .63772 .40682 L F
.541 .222 .376 r
.46592 .5767 m .46535 .57974 L .46248 .57963 L F
.398 .112 .359 r
.4684 .57605 m .46535 .57974 L .46592 .5767 L F
.838 .516 0 r
.39655 .51904 m .39789 .52284 L .39718 .52157 L F
0 0 .053 r
.39789 .52284 m .39842 .52375 L .39718 .52157 L F
.39789 .52284 m .3973 .52555 L .39842 .52375 L F
.872 .9 .849 r
.30391 .50987 m .30306 .51136 L .30023 .51122 L F
.752 .25 .028 r
.38436 .62055 m .38788 .62192 L .38656 .62074 L F
.606 .581 .799 r
.28506 .59994 m .28905 .60267 L .28752 .59906 L F
.502 .484 .769 r
.71241 .32047 m .70785 .31832 L .7111 .31851 L F
.119 .095 .553 r
.71304 .31595 m .71241 .32047 L .7111 .31851 L F
.862 .523 .409 r
.43356 .59611 m .43249 .59813 L .43218 .59587 L F
.454 .011 .104 r
.43664 .59602 m .43249 .59813 L .43373 .5958 L F
0 0 .313 r
.43218 .59587 m .43249 .59813 L .43306 .59778 L F
0 .132 .679 r
.43306 .59778 m .43249 .59813 L .43241 .59716 L F
0 0 .313 r
.43218 .59587 m .4326 .59677 L .43081 .59564 L F
.4326 .59677 m .43306 .59778 L .43241 .59716 L F
.4326 .59677 m .43241 .59716 L .43081 .59564 L F
.459 .02 .116 r
.43249 .59813 m .4319 .59847 L .43197 .59808 L F
.43249 .59813 m .43232 .59811 L .43241 .59716 L F
.43232 .59811 m .43197 .59808 L .43233 .59733 L F
.43232 .59811 m .43233 .59733 L .43241 .59716 L F
0 0 .313 r
.43081 .59564 m .432 .59676 L .42912 .59534 L F
.432 .59676 m .43306 .59778 L .42912 .59534 L F
.43218 .59587 m .42912 .59534 L .42817 .59476 L F
.346 .465 .839 r
.42817 .59476 m .43233 .59733 L .42943 .59243 L F
0 .132 .679 r
.43306 .59778 m .43241 .59716 L .43232 .59603 L F
.346 .465 .839 r
.43233 .59733 m .43306 .59778 L .43234 .59671 L F
.43233 .59733 m .43234 .59671 L .42943 .59243 L F
.165 .368 .818 r
.42943 .59243 m .43234 .59671 L .43232 .59603 L F
.43234 .59671 m .43306 .59778 L .43232 .59603 L F
.459 .02 .116 r
.43241 .59716 m .43235 .59728 L .43232 .59603 L F
.43235 .59728 m .43197 .59808 L .43232 .59603 L F
.862 .523 .409 r
.43373 .5958 m .43356 .59611 L .43218 .59587 L F
.227 0 .249 r
.28819 .53873 m .29024 .53818 L .29086 .53591 L F
.571 .415 .631 r
.29255 .53646 m .29034 .53963 L .29024 .53818 L F
.227 0 .249 r
.29024 .53818 m .29032 .53816 L .29033 .53811 L F
.29024 .53818 m .29033 .53811 L .29086 .53591 L F
.877 .881 .834 r
.29033 .53811 m .29255 .53646 L .29086 .53591 L F
.29008 .53916 m .29255 .53646 L .29033 .53811 L F
.571 .415 .631 r
.29222 .53655 m .29033 .53811 L .29016 .53714 L F
.29033 .53811 m .29024 .53818 L .29024 .53818 L F
.29033 .53811 m .29024 .53818 L .29016 .53714 L F
.29255 .53646 m .29024 .53818 L .29222 .53655 L F
.333 .204 .552 r
.29016 .53714 m .29024 .53818 L .28819 .53873 L F
.29024 .53818 m .29034 .53963 L .28819 .53873 L F
.227 0 .249 r
.28819 .53873 m .29008 .53916 L .29032 .53816 L F
.034 .356 .83 r
.28819 .53873 m .29034 .53963 L .29008 .53916 L F
0 0 0 r
.29016 .53714 m .28819 .53873 L .29086 .53591 L F
.309 .132 .471 r
.21788 .55153 m .21766 .5542 L .21972 .55067 L F
.421 .783 .995 r
.29443 .52249 m .2925 .52142 L .2905 .52176 L F
.735 .893 .951 r
.29456 .52044 m .2925 .52142 L .29443 .52249 L F
.841 .808 .818 r
.66473 .34888 m .66611 .35059 L .66869 .34732 L F
.329 .761 .97 r
.32026 .54021 m .31613 .53981 L .31883 .54096 L F
.177 0 .271 r
.30885 .60268 m .30819 .60502 L .31068 .60177 L F
.829 .813 .835 r
.65955 .33482 m .6552 .33628 L .65807 .33326 L F
.848 .852 .845 r
.66251 .33134 m .65955 .33482 L .65807 .33326 L F
.294 .294 .688 r
.66128 .37555 m .66185 .37902 L .66465 .37816 L F
.114 0 .16 r
.66465 .37816 m .66185 .37902 L .66185 .38121 L F
.757 .615 .701 r
.32204 .65091 m .32507 .6471 L .32101 .64618 L F
.569 .628 .87 r
.32565 .64301 m .32507 .6471 L .32416 .64575 L F
.32565 .64301 m .32778 .64645 L .32507 .6471 L F
0 0 0 r
.32507 .6471 m .32778 .64645 L .32574 .64733 L F
.32507 .6471 m .32574 .64733 L .32416 .64575 L F
.439 .754 .995 r
.32101 .64618 m .32507 .6471 L .32416 .64575 L F
.896 .675 .595 r
.62266 .40171 m .6203 .39794 L .62028 .39913 L F
.848 .399 0 r
.62381 .40417 m .62266 .40171 L .62028 .39913 L F
.845 .387 0 r
.61115 .43328 m .60939 .43133 L .60972 .43215 L F
.87 .426 .103 r
.61029 .4344 m .61115 .43328 L .60972 .43215 L F
.61029 .4344 m .61287 .43612 L .61115 .43328 L F
.866 .46 .258 r
.61115 .43328 m .61287 .43612 L .61346 .43577 L F
.205 .044 .428 r
.69228 .36846 m .69047 .37204 L .69053 .36968 L F
.524 .299 .516 r
.31376 .61471 m .311 .61774 L .31161 .61547 L F
.743 .279 .146 r
.35405 .51483 m .35519 .51538 L .35802 .51526 L F
.716 .871 .955 r
.35703 .5153 m .35974 .51642 L .35802 .51526 L F
.743 .279 .146 r
.35519 .51538 m .35783 .51665 L .35802 .51526 L F
.716 .871 .955 r
.35615 .51494 m .35703 .5153 L .35802 .51526 L F
.233 0 .312 r
.31858 .66586 m .31891 .66332 L .31698 .66614 L F
.797 .466 .428 r
.31858 .66586 m .32045 .66742 L .31891 .66332 L F
.31858 .66586 m .32045 .66742 L .31891 .66332 L F
.786 .48 .471 r
.31858 .66586 m .31999 .66602 L .32045 .66742 L F
.31999 .66602 m .3228 .66634 L .32045 .66742 L F
.755 .376 .338 r
.32074 .66828 m .32106 .66798 L .31858 .66586 L F
.32049 .66694 m .3228 .66634 L .31999 .66602 L F
.814 .67 .704 r
.32049 .66694 m .32045 .66742 L .32066 .66695 L F
.755 .376 .338 r
.32052 .66699 m .32066 .66695 L .32049 .66694 L F
.32066 .66695 m .3228 .66634 L .32049 .66694 L F
.814 .67 .704 r
.32085 .66277 m .32049 .66694 L .32274 .66225 L F
.32049 .66694 m .32066 .66695 L .32274 .66225 L F
.905 .75 .254 r
.3228 .66634 m .32274 .66225 L .32066 .66695 L F
.3228 .66634 m .32066 .66695 L .32045 .66742 L F
.755 .376 .338 r
.32106 .66798 m .3228 .66634 L .32052 .66699 L F
.267 .192 .583 r
.31999 .66602 m .32045 .66742 L .32049 .66694 L F
.755 .376 .338 r
.32106 .66798 m .31999 .66602 L .31858 .66586 L F
.267 .192 .583 r
.31909 .66327 m .31999 .66602 L .32085 .66277 L F
.31999 .66602 m .32049 .66694 L .32085 .66277 L F
.31891 .66332 m .32045 .66742 L .31909 .66327 L F
.764 .693 .784 r
.22644 .56602 m .22568 .56776 L .2226 .56399 L F
0 0 0 r
.25654 .54772 m .25744 .54686 L .25876 .54463 L F
.503 .909 .844 r
.25876 .54463 m .26044 .54339 L .26255 .54291 L F
.681 .505 .641 r
.25744 .54686 m .26044 .54339 L .25876 .54463 L F
.931 .56 .276 r
.70336 .30898 m .70091 .30859 L .69969 .30784 L F
.70336 .30898 m .70382 .31103 L .70091 .30859 L F
.241 .011 .351 r
.24638 .55034 m .24368 .55385 L .24372 .55196 L F
.77 .727 .812 r
.53355 .41679 m .53776 .4172 L .53637 .41354 L F
.22 0 0 r
.53618 .41722 m .53776 .4172 L .53355 .41679 L F
0 .13 .638 r
.53817 .41723 m .53776 .4172 L .53618 .41722 L F
.53817 .41723 m .53994 .41908 L .53776 .4172 L F
.615 .294 .404 r
.58393 .46217 m .58664 .46441 L .58404 .46393 L F
.567 .312 .489 r
.58676 .46165 m .58664 .46441 L .58393 .46217 L F
.597 .369 .542 r
.31644 .61177 m .31376 .61471 L .31412 .61222 L F
.615 .077 0 r
.38892 .65058 m .38468 .64965 L .38785 .64808 L F
.52 .361 .605 r
.39107 .65149 m .39204 .65263 L .38892 .65058 L F
.443 .381 .693 r
.38892 .65058 m .39096 .65192 L .38967 .65313 L F
.977 .901 .558 r
.38972 .65248 m .39102 .65153 L .39072 .64956 L F
.39102 .65153 m .39107 .65149 L .39105 .65136 L F
.39102 .65153 m .39105 .65136 L .39072 .64956 L F
.443 .381 .693 r
.39096 .65192 m .39204 .65263 L .3908 .65289 L F
.39096 .65192 m .3908 .65289 L .38967 .65313 L F
.762 .955 .64 r
.32021 .6699 m .3228 .66634 L .3217 .66826 L F
.703 .85 .953 r
.31823 .66844 m .32021 .6699 L .3217 .66826 L F
.59 .163 .2 r
.2186 .60057 m .21843 .6028 L .21632 .60112 L F
0 .205 .732 r
.21632 .60112 m .21843 .6028 L .21802 .60212 L F
.442 0 0 r
.2182 .59963 m .21632 .60112 L .2153 .60052 L F
.416 0 0 r
.2186 .60057 m .21632 .60112 L .2182 .59963 L F
0 .205 .732 r
.21632 .60112 m .21802 .60212 L .2165 .5996 L F
.442 0 0 r
.2153 .60052 m .21632 .60112 L .21313 .60118 L F
.416 0 0 r
.2186 .60057 m .2182 .59963 L .22102 .59916 L F
.08 .076 .551 r
.20711 .57684 m .20711 .5804 L .20859 .57884 L F
.016 .041 .542 r
.20711 .5804 m .20882 .58149 L .20859 .57884 L F
.20711 .5804 m .20761 .58307 L .20882 .58149 L F
.405 .518 .859 r
.27439 .62056 m .27368 .62297 L .27201 .62109 L F
.28 0 .086 r
.29255 .53646 m .29016 .53714 L .29086 .53591 L F
.651 .771 .937 r
.44294 .48759 m .44024 .48829 L .43897 .48696 L F
.173 .188 .634 r
.36598 .59794 m .36451 .60042 L .36325 .59883 L F
.36598 .59794 m .36645 .60194 L .36451 .60042 L F
.3 .615 .957 r
.53245 .41352 m .53199 .41461 L .53089 .4128 L F
.792 .534 .547 r
.53353 .41411 m .53178 .41511 L .53199 .41461 L F
.53353 .41411 m .53355 .41679 L .52953 .41638 L F
.441 .228 .492 r
.53612 .41099 m .53353 .41411 L .53637 .41354 L F
0 0 0 r
.53637 .41354 m .53353 .41411 L .53199 .41461 L F
.53637 .41354 m .53199 .41461 L .53509 .41473 L F
.3 .615 .957 r
.53509 .41473 m .53199 .41461 L .53245 .41352 L F
.792 .534 .547 r
.53178 .41511 m .52953 .41638 L .53199 .41461 L F
.941 .908 .523 r
.33755 .54847 m .33717 .54729 L .33868 .54439 L F
.33717 .54729 m .33734 .54654 L .33868 .54439 L F
.165 0 .014 r
.34004 .54438 m .33976 .54591 L .34157 .54437 L F
.33868 .54439 m .33976 .54591 L .34004 .54438 L F
.383 .835 .734 r
.33976 .54591 m .34414 .54408 L .34157 .54437 L F
.33976 .54591 m .34103 .5452 L .34414 .54408 L F
.497 .498 .788 r
.34051 .5442 m .33962 .54668 L .33976 .54591 L F
.424 .267 .562 r
.33922 .54779 m .34103 .5452 L .33976 .54591 L F
.497 .498 .788 r
.33962 .54668 m .33922 .54779 L .33976 .54591 L F
.165 0 .014 r
.33868 .54439 m .33707 .54696 L .33976 .54591 L F
.485 .363 .639 r
.33976 .54591 m .33787 .54408 L .33911 .54341 L F
.33787 .54408 m .33749 .54371 L .33797 .54362 L F
.33787 .54408 m .33797 .54362 L .33911 .54341 L F
.941 .908 .523 r
.33717 .54729 m .33707 .54696 L .33734 .54654 L F
0 0 0 r
.33755 .54847 m .33752 .54984 L .33707 .54696 L F
.33755 .54847 m .33693 .55135 L .33752 .54984 L F
.482 .163 .349 r
.44567 .59258 m .44242 .59462 L .44303 .59284 L F
.722 .617 .74 r
.55057 .41488 m .55104 .41694 L .54812 .41804 L F
.502 .484 .769 r
.71241 .32047 m .70931 .32198 L .70785 .31832 L F
.333 .212 .562 r
.71232 .32263 m .70931 .32198 L .71241 .32047 L F
.71232 .32263 m .70961 .32463 L .70931 .32198 L F
.706 .652 .794 r
.39716 .67277 m .40043 .67279 L .39995 .67167 L F
.641 .269 .322 r
.39716 .67277 m .39952 .675 L .40043 .67279 L F
.352 0 .196 r
.40043 .67279 m .39952 .675 L .40279 .67209 L F
.516 .383 .638 r
.32984 .58026 m .33029 .58303 L .32783 .58348 L F
.502 .333 .584 r
.32783 .58348 m .32785 .58622 L .33029 .58303 L F
.516 .383 .638 r
.32783 .58348 m .33029 .58303 L .32984 .58026 L F
.502 .333 .584 r
.32783 .58348 m .32785 .58622 L .33029 .58303 L F
.022 .548 .858 r
.34491 .49701 m .34711 .4974 L .34892 .49827 L F
0 .428 .725 r
.34711 .4974 m .35169 .49877 L .34892 .49827 L F
0 .258 .765 r
.23138 .56703 m .23384 .569 L .2326 .56767 L F
.831 .567 .539 r
.64944 .43027 m .64624 .42681 L .6489 .42898 L F
.931 .636 .165 r
.64897 .43154 m .64944 .43027 L .6489 .42898 L F
.64897 .43154 m .64974 .43243 L .64944 .43027 L F
.651 .64 .826 r
.72616 .34952 m .72781 .34599 L .72501 .34948 L F
.72616 .34952 m .73079 .34799 L .72781 .34599 L F
.466 .63 .925 r
.32792 .53777 m .331 .5388 L .33004 .53696 L F
.641 .416 .561 r
.32755 .54137 m .331 .5388 L .32792 .53777 L F
.336 .009 .255 r
.32739 .59672 m .32666 .59865 L .32441 .59928 L F
.483 .188 .388 r
.32993 .596 m .32666 .59865 L .32739 .59672 L F
0 .365 .781 r
.2914 .64234 m .29018 .64132 L .29242 .63982 L F
.2914 .64234 m .29127 .64271 L .29018 .64132 L F
.701 .781 .913 r
.62449 .35964 m .62174 .36184 L .6209 .35897 L F
.232 .323 .752 r
.69183 .3275 m .69203 .323 L .68987 .32457 L F
.69183 .3275 m .69339 .32696 L .69203 .323 L F
.898 .651 .556 r
.53218 .4268 m .53378 .43019 L .53167 .42933 L F
.897 .598 .472 r
.53167 .42933 m .53378 .43019 L .53392 .43273 L F
.854 .974 .664 r
.24274 .53444 m .24231 .53635 L .24418 .5333 L F
.605 .59 .81 r
.24274 .53444 m .24085 .5383 L .24231 .53635 L F
.562 .281 .446 r
.36 .7152 m .3626 .71478 L .3617 .71764 L F
.649 .582 .766 r
.37564 .52901 m .37269 .52964 L .37158 .52527 L F
.426 .477 .809 r
.45929 .55343 m .45862 .55758 L .45683 .55401 L F
.45929 .55343 m .46069 .55733 L .45862 .55758 L F
.886 .877 .821 r
.37174 .63683 m .37022 .64159 L .36894 .64027 L F
0 .543 .788 r
.37022 .64159 m .37008 .64127 L .36894 .64027 L F
.37022 .64159 m .37326 .64205 L .37008 .64127 L F
.92 .746 .649 r
.26092 .80353 m .26299 .80381 L .26198 .80525 L F
.26092 .80353 m .26299 .80381 L .26198 .80525 L F
0 0 .231 r
.33288 .56107 m .33376 .55674 L .33167 .55743 L F
.33288 .56107 m .33372 .55965 L .33348 .55811 L F
.564 .91 .97 r
.33288 .56107 m .33142 .56065 L .33372 .55965 L F
.831 .894 .886 r
.33142 .56065 m .32711 .56158 L .32866 .56 L F
.7 .287 .26 r
.32866 .56 m .33372 .55965 L .33142 .56065 L F
.32866 .56 m .33421 .56276 L .33372 .55965 L F
0 0 .414 r
.33372 .55965 m .33517 .56315 L .33496 .56007 L F
.7 .287 .26 r
.33421 .56276 m .33495 .56313 L .33372 .55965 L F
.33495 .56313 m .33517 .56315 L .33372 .55965 L F
.735 .695 .812 r
.33462 .56228 m .33557 .56321 L .33496 .56007 L F
.67 .633 .804 r
.33496 .56007 m .33457 .56261 L .33052 .55854 L F
.735 .695 .812 r
.33495 .56313 m .33557 .56321 L .33357 .56125 L F
.33136 .56314 m .33557 .56321 L .33185 .56272 L F
0 0 .414 r
.33517 .56315 m .33522 .56326 L .33496 .56007 L F
.67 .633 .804 r
.33496 .56007 m .33522 .56326 L .33457 .56261 L F
.735 .695 .812 r
.33357 .56125 m .33462 .56228 L .33496 .56007 L F
.378 .546 .894 r
.33052 .55854 m .33335 .56138 L .32866 .56 L F
.33335 .56138 m .33457 .56261 L .33264 .56176 L F
.33335 .56138 m .33264 .56176 L .32866 .56 L F
.33457 .56261 m .33495 .56313 L .32866 .56 L F
.735 .695 .812 r
.33185 .56272 m .33495 .56313 L .33357 .56125 L F
.361 .811 .945 r
.33292 .56242 m .33136 .56314 L .33357 .56125 L F
.33426 .56088 m .33357 .56125 L .33496 .56007 L F
.33292 .56242 m .33357 .56125 L .33426 .56088 L F
.7 .287 .26 r
.33495 .56313 m .33522 .56326 L .33517 .56315 L F
.378 .546 .894 r
.33457 .56261 m .33522 .56326 L .33495 .56313 L F
.735 .695 .812 r
.33518 .5632 m .33575 .56413 L .33557 .56321 L F
.33136 .56314 m .33523 .56401 L .33518 .5632 L F
.33523 .56401 m .33575 .56413 L .33518 .5632 L F
0 0 .231 r
.33348 .55811 m .33372 .55965 L .33376 .55674 L F
.367 .107 .382 r
.63707 .40106 m .63589 .40157 L .63411 .4043 L F
.853 .662 .644 r
.33115 .49982 m .32753 .49976 L .32795 .49641 L F
.925 .69 .565 r
.33115 .49982 m .32713 .50196 L .32753 .49976 L F
.33115 .49982 m .32981 .50257 L .32713 .50196 L F
.141 .028 .453 r
.343 .59283 m .34473 .59461 L .34567 .5925 L F
.343 .59283 m .34329 .59583 L .34473 .59461 L F
.782 .603 .658 r
.58728 .38477 m .59183 .38565 L .59029 .38861 L F
.677 .4 .495 r
.71679 .28042 m .72017 .27975 L .71672 .27884 L F
.361 .161 .468 r
.70709 .32661 m .707 .32982 L .70424 .33047 L F
.185 0 .233 r
.707 .32982 m .70458 .33327 L .70424 .33047 L F
.722 .646 .773 r
.54669 .41419 m .54812 .41804 L .54411 .41723 L F
.808 .797 .842 r
.54812 .41804 m .54369 .41975 L .54411 .41723 L F
.722 .617 .74 r
.55057 .41488 m .54812 .41804 L .54669 .41419 L F
.662 .123 0 r
.26883 .63317 m .27252 .6344 L .27024 .63419 L F
.391 0 0 r
.27252 .6344 m .27231 .63477 L .27024 .63419 L F
.348 0 0 r
.33901 .49587 m .34085 .49639 L .34275 .49663 L F
.172 0 0 r
.34085 .49639 m .34491 .49701 L .34275 .49663 L F
.501 .884 .698 r
.24863 .52582 m .2496 .52487 L .25067 .5244 L F
.545 .557 .818 r
.70925 .36664 m .71095 .3621 L .70852 .36237 L F
.70925 .36664 m .71222 .36615 L .71095 .3621 L F
.814 .769 .811 r
.36315 .6697 m .36477 .66909 L .36458 .66503 L F
.108 .191 .67 r
.36458 .66503 m .36477 .66909 L .36507 .66719 L F
.019 0 .151 r
.22287 .54503 m .22044 .54834 L .22207 .54732 L F
0 0 0 r
.21972 .55067 m .22207 .54732 L .22044 .54834 L F
.544 .453 .703 r
.37092 .54111 m .37202 .54501 L .36929 .54526 L F
.747 .636 .737 r
.65212 .36625 m .65584 .36629 L .65598 .36343 L F
.629 .119 .016 r
.3382 .56154 m .3421 .56116 L .33927 .56328 L F
.34021 .5609 m .3421 .56116 L .3382 .56154 L F
.31 .2 .564 r
.34275 .56458 m .33927 .56328 L .3421 .56116 L F
.629 .119 .016 r
.33758 .56053 m .34021 .5609 L .3382 .56154 L F
.33758 .56053 m .33999 .56196 L .3421 .56116 L F
.227 0 0 r
.34312 .56044 m .34236 .56144 L .33999 .56196 L F
.645 .29 .355 r
.3432 .56032 m .34236 .56144 L .34312 .56044 L F
.25 0 0 r
.34338 .56008 m .34236 .56144 L .3442 .55962 L F
.34033 .56183 m .34347 .55996 L .3421 .56116 L F
.34347 .55996 m .34343 .56015 L .3421 .56116 L F
.33999 .56196 m .34153 .56107 L .34033 .56183 L F
.34153 .56107 m .3439 .5597 L .34033 .56183 L F
.3439 .5597 m .34442 .5594 L .34389 .55972 L F
.3439 .5597 m .34389 .55972 L .34033 .56183 L F
.34347 .55996 m .34442 .5594 L .34343 .56015 L F
.34384 .55973 m .3442 .55962 L .34442 .5594 L F
.759 .657 .749 r
.34442 .5594 m .34839 .56012 L .34678 .5566 L F
.773 .404 .358 r
.34442 .5594 m .34236 .56144 L .3462 .56146 L F
0 .172 .707 r
.34597 .55925 m .34601 .56148 L .34402 .55946 L F
.34412 .55927 m .34402 .55946 L .34383 .55928 L F
.34597 .55925 m .34402 .55946 L .34412 .55927 L F
.25 0 0 r
.33999 .56196 m .34023 .56191 L .34123 .56132 L F
.33999 .56196 m .34123 .56132 L .34338 .56008 L F
.34023 .56191 m .34321 .56031 L .34338 .56008 L F
.34153 .56107 m .3442 .55962 L .34384 .55973 L F
.33999 .56196 m .34186 .56093 L .34153 .56107 L F
.34186 .56093 m .3442 .55962 L .34153 .56107 L F
.707 .519 .632 r
.3435 .55982 m .3432 .56032 L .34306 .5601 L F
.3432 .56032 m .34312 .56044 L .34311 .56036 L F
.3432 .56032 m .34311 .56036 L .34306 .5601 L F
.227 0 0 r
.34301 .56041 m .33999 .56196 L .34019 .55974 L F
.34312 .56044 m .33999 .56196 L .34301 .56041 L F
.952 .677 .48 r
.33591 .55863 m .33758 .56053 L .33785 .55724 L F
.33591 .55863 m .33758 .56053 L .33785 .55724 L F
.732 .497 .572 r
.33993 .55663 m .34019 .55974 L .33591 .55863 L F
.544 .303 .5 r
.3429 .55515 m .33785 .55724 L .34101 .55497 L F
.867 .76 .742 r
.34388 .55411 m .34319 .55493 L .34101 .55497 L F
.518 .162 .303 r
.34101 .55497 m .34172 .55557 L .3429 .55515 L F
.544 .924 .916 r
.3429 .55515 m .34228 .55533 L .34172 .55557 L F
.518 .162 .303 r
.34172 .55557 m .34195 .55577 L .3429 .55515 L F
.732 .497 .572 r
.34207 .55654 m .34146 .55759 L .3414 .55687 L F
.759 .553 .618 r
.34226 .55603 m .34019 .55974 L .3429 .55515 L F
.867 .76 .742 r
.34388 .55411 m .34448 .55725 L .34226 .55603 L F
.832 .784 .806 r
.34226 .55603 m .34268 .55625 L .34709 .55404 L F
.34268 .55625 m .34448 .55725 L .34695 .55421 L F
.34268 .55625 m .34695 .55421 L .34709 .55404 L F
.732 .497 .572 r
.3414 .55687 m .34146 .55759 L .34101 .55731 L F
.3429 .55515 m .34207 .55654 L .3414 .55687 L F
.34195 .55577 m .34101 .55731 L .34029 .55685 L F
.3429 .55515 m .34101 .55731 L .34195 .55577 L F
.518 .162 .303 r
.34195 .55577 m .34226 .55603 L .3429 .55515 L F
.867 .76 .742 r
.34319 .55493 m .34226 .55603 L .34195 .55577 L F
.544 .924 .916 r
.34172 .55557 m .33747 .55673 L .33768 .55702 L F
.34228 .55533 m .33747 .55673 L .34172 .55557 L F
.3429 .55515 m .33768 .55702 L .33785 .55724 L F
.221 .713 .922 r
.33785 .55724 m .33747 .55673 L .33376 .55674 L F
.678 .218 .153 r
.33376 .55674 m .33591 .55863 L .33785 .55724 L F
.732 .497 .572 r
.34228 .55533 m .33591 .55863 L .33747 .55673 L F
.3429 .55515 m .34208 .55555 L .34228 .55533 L F
.867 .76 .742 r
.3422 .55536 m .34208 .55555 L .34172 .55557 L F
.34208 .55555 m .34192 .55574 L .34172 .55557 L F
.732 .497 .572 r
.34208 .55555 m .33591 .55863 L .34228 .55533 L F
.867 .76 .742 r
.34208 .55555 m .34195 .55577 L .34192 .55574 L F
.34319 .55493 m .34195 .55577 L .3422 .55536 L F
.34319 .55493 m .34172 .55557 L .34101 .55497 L F
.732 .497 .572 r
.3429 .55515 m .34029 .55685 L .33993 .55663 L F
.34146 .55759 m .34019 .55974 L .33993 .55663 L F
.707 .519 .632 r
.34383 .55928 m .3435 .55982 L .34311 .55863 L F
.3437 .55899 m .34311 .55863 L .34226 .55603 L F
.34383 .55928 m .34311 .55863 L .3437 .55899 L F
.759 .553 .618 r
.34226 .55603 m .34311 .56036 L .34019 .55974 L F
.34311 .56036 m .34312 .56044 L .34301 .56041 L F
.34311 .56036 m .34301 .56041 L .34019 .55974 L F
.25 0 0 r
.34023 .56191 m .34236 .56144 L .34321 .56031 L F
.645 .29 .355 r
.3435 .55982 m .34236 .56144 L .3432 .56032 L F
.34383 .55928 m .34352 .55974 L .3435 .55982 L F
.34352 .55974 m .34236 .56144 L .3435 .55982 L F
.707 .519 .632 r
.3435 .55982 m .34306 .5601 L .34226 .55603 L F
.472 .359 .644 r
.43374 .58044 m .43343 .58046 L .43403 .57927 L F
.43374 .58044 m .43381 .58316 L .43343 .58046 L F
0 0 .264 r
.41435 .56733 m .41498 .56838 L .414 .5663 L F
.41435 .56733 m .41489 .56986 L .41498 .56838 L F
.135 .038 .471 r
.22959 .58558 m .22808 .58489 L .22824 .5841 L F
.162 0 .262 r
.23204 .58185 m .22824 .5841 L .2295 .58289 L F
.484 .308 .566 r
.23204 .58185 m .22959 .58558 L .22824 .5841 L F
.646 .933 .969 r
.39746 .67114 m .39716 .67277 L .39995 .67167 L F
.666 .256 .258 r
.3968 .67553 m .39952 .675 L .39716 .67277 L F
.3968 .67553 m .39716 .67277 L .39746 .67114 L F
.856 .834 .824 r
.38019 .58016 m .37764 .5834 L .37574 .58204 L F
.967 .649 .35 r
.38019 .58016 m .38127 .58315 L .37764 .5834 L F
.313 .184 .54 r
.37936 .58541 m .37764 .5834 L .38127 .58315 L F
.37936 .58541 m .37776 .58631 L .37764 .5834 L F
.325 .762 .967 r
.35053 .7173 m .35174 .71652 L .34894 .71726 L F
.35053 .7173 m .35341 .7173 L .35174 .71652 L F
0 0 .046 r
.69765 .33629 m .69851 .33192 L .6968 .33407 L F
.776 .758 .837 r
.62834 .36025 m .62449 .35964 L .6266 .35864 L F
.74 .728 .84 r
.62958 .35554 m .62834 .36025 L .6266 .35864 L F
.62958 .35554 m .6307 .35916 L .62834 .36025 L F
.917 .585 .118 r
.6137 .41669 m .6153 .42063 L .61421 .41925 L F
.979 .724 .32 r
.61421 .41925 m .6153 .42063 L .61529 .42312 L F
0 .214 .731 r
.25654 .54772 m .25855 .54944 L .25744 .54686 L F
.445 .755 .994 r
.29555 .61096 m .29628 .61249 L .29439 .6117 L F
.646 .534 .713 r
.29439 .6117 m .29621 .6146 L .29628 .61249 L F
.787 .291 0 r
.70917 .30977 m .70975 .30904 L .7081 .30806 L F
.808 .327 0 r
.71077 .31085 m .70975 .30904 L .70917 .30977 L F
.752 .673 .774 r
.36061 .58903 m .35786 .58901 L .3582 .58672 L F
.795 .721 .782 r
.64541 .36554 m .6493 .36628 L .64799 .36229 L F
.789 .718 .785 r
.64799 .36229 m .6493 .36628 L .65188 .36296 L F
.652 .512 .68 r
.6493 .36628 m .65212 .36625 L .65188 .36296 L F
.909 .905 .808 r
.70584 .29956 m .70775 .29657 L .70513 .29574 L F
.92 .742 .253 r
.70562 .3013 m .70584 .29956 L .70513 .29574 L F
.515 .493 .771 r
.64624 .42681 m .64725 .42738 L .6475 .42245 L F
.498 0 0 r
.64697 .42759 m .64624 .42681 L .64532 .42696 L F
.64697 .42759 m .6489 .42898 L .64624 .42681 L F
.583 .412 .615 r
.31159 .63127 m .31526 .63166 L .31415 .62803 L F
.572 .276 .427 r
.31384 .63343 m .31526 .63166 L .31159 .63127 L F
.193 .014 .395 r
.2324 .57917 m .23102 .57883 L .23281 .57727 L F
.2324 .57917 m .2295 .58289 L .23102 .57883 L F
.434 0 0 r
.37058 .51045 m .37096 .51068 L .36933 .50901 L F
.37058 .51045 m .37357 .51261 L .37096 .51068 L F
.649 .112 0 r
.37096 .51068 m .37357 .51261 L .37585 .51277 L F
.841 .808 .818 r
.66473 .34888 m .66869 .34732 L .66732 .34576 L F
.816 .843 .87 r
.66732 .34576 m .66869 .34732 L .67154 .34444 L F
.17 0 0 r
.33898 .57629 m .3413 .57569 L .34247 .57418 L F
.365 .024 .247 r
.3413 .57569 m .34451 .57307 L .34247 .57418 L F
0 .097 .652 r
.40575 .53831 m .40811 .54195 L .40775 .54066 L F
0 0 .357 r
.40865 .54438 m .40775 .54066 L .40811 .54195 L F
.633 .605 .804 r
.44799 .49653 m .44545 .49707 L .44413 .49395 L F
.461 .267 .53 r
.44799 .49653 m .4455 .50015 L .44545 .49707 L F
0 0 .456 r
.34383 .52007 m .34489 .52072 L .34576 .5186 L F
.34383 .52007 m .34444 .52248 L .34489 .52072 L F
.454 .461 .776 r
.44571 .5054 m .44474 .50985 L .44371 .50587 L F
.44571 .5054 m .44691 .50946 L .44474 .50985 L F
.496 .414 .692 r
.44769 .51178 m .44474 .50985 L .44691 .50946 L F
.466 .21 .441 r
.33763 .58354 m .33755 .58582 L .33484 .58631 L F
.02 0 0 r
.34055 .58287 m .33755 .58582 L .33763 .58354 L F
.534 .501 .765 r
.42319 .53743 m .42148 .5417 L .42222 .53956 L F
.052 0 .062 r
.30303 .54588 m .30237 .54403 L .3055 .54188 L F
0 0 0 r
.30495 .54388 m .30303 .54588 L .3055 .54188 L F
.176 0 .164 r
.38607 .67746 m .38648 .67516 L .38838 .67617 L F
.294 .294 .688 r
.66128 .37555 m .66465 .37816 L .66444 .37507 L F
.602 .947 .795 r
.23538 .5539 m .23188 .55659 L .23331 .55463 L F
.23538 .5539 m .23242 .55546 L .23188 .55659 L F
.648 .919 .625 r
.23242 .55546 m .22963 .55837 L .23188 .55659 L F
.369 .799 .968 r
.71936 .35356 m .71973 .35429 L .72235 .35375 L F
.729 .245 .094 r
.7226 .3559 m .71973 .35429 L .72235 .35375 L F
.889 .906 .832 r
.36846 .67912 m .37085 .67625 L .36937 .67489 L F
.608 .864 .517 r
.36934 .67783 m .37085 .67625 L .36846 .67912 L F
.879 .907 .845 r
.37357 .67268 m .36937 .67489 L .36959 .67176 L F
.324 .186 .534 r
.36959 .67176 m .37037 .67315 L .37087 .67016 L F
.879 .907 .845 r
.37357 .67268 m .37085 .67625 L .36988 .67536 L F
.37357 .67268 m .36988 .67536 L .37007 .67452 L F
.324 .186 .534 r
.37037 .67315 m .37113 .67452 L .3709 .67074 L F
.37037 .67315 m .3709 .67074 L .37087 .67016 L F
.879 .907 .845 r
.37007 .67452 m .36988 .67536 L .36937 .67489 L F
.993 .747 .438 r
.36937 .67489 m .37085 .67625 L .36934 .67783 L F
.986 .802 .572 r
.57707 .41687 m .57775 .42079 L .57631 .41955 L F
.707 .644 .784 r
.58111 .41775 m .57775 .42079 L .57707 .41687 L F
.045 0 .361 r
.20783 .57047 m .20968 .56923 L .20995 .56658 L F
.089 0 .436 r
.20783 .57047 m .20963 .57194 L .20968 .56923 L F
.20783 .57047 m .20777 .57345 L .20963 .57194 L F
0 0 0 r
.64482 .39658 m .64253 .39726 L .64253 .39786 L F
.64482 .39658 m .6461 .39568 L .64253 .39726 L F
.73 .36 0 r
.39404 .64671 m .39576 .65034 L .39511 .64926 L F
.574 .05 0 r
.39576 .65034 m .3967 .65163 L .39511 .64926 L F
.408 .29 .606 r
.39598 .65354 m .39806 .65268 L .39576 .65034 L F
.574 .05 0 r
.39576 .65034 m .39806 .65268 L .3967 .65163 L F
.656 .1 0 r
.36322 .50392 m .36538 .50593 L .36762 .50656 L F
0 .091 .627 r
.36426 .50429 m .36538 .50593 L .36322 .50392 L F
0 0 0 r
.40051 .68596 m .39874 .68791 L .39753 .68889 L F
.672 .855 .452 r
.40051 .68596 m .40003 .68632 L .39874 .68791 L F
.40051 .68596 m .40135 .6843 L .40003 .68632 L F
.587 .097 .059 r
.39225 .49973 m .39389 .50118 L .39566 .49968 L F
0 0 0 r
.39389 .50118 m .39839 .49875 L .39566 .49968 L F
.87 .825 .801 r
.67891 .33428 m .68136 .33089 L .68005 .32906 L F
.834 .82 .836 r
.68005 .32906 m .68136 .33089 L .68406 .32774 L F
0 .389 .801 r
.71059 .28182 m .70708 .28246 L .70983 .28157 L F
.271 .773 .87 r
.70983 .28157 m .71342 .28134 L .71059 .28182 L F
.463 .249 .502 r
.33681 .5661 m .33416 .5677 L .33677 .5643 L F
.33683 .5644 m .33677 .5643 L .33683 .56422 L F
.33681 .5661 m .33677 .5643 L .33683 .5644 L F
.3368 .56721 m .33453 .56763 L .33681 .5661 L F
.33453 .56763 m .33416 .5677 L .33681 .5661 L F
.791 .515 .52 r
.34081 .5673 m .3368 .56721 L .33683 .56422 L F
.645 .587 .775 r
.34049 .56976 m .3368 .56721 L .34081 .5673 L F
.945 .841 .71 r
.33833 .56564 m .3368 .56721 L .33587 .56553 L F
.645 .587 .775 r
.34049 .56976 m .33784 .57005 L .33708 .56797 L F
.33735 .56758 m .33708 .56797 L .3368 .56721 L F
.34049 .56976 m .33708 .56797 L .33735 .56758 L F
0 0 0 r
.33995 .56463 m .33895 .56526 L .33764 .56817 L F
.33895 .56526 m .33833 .56564 L .3381 .56649 L F
.33895 .56526 m .3381 .56649 L .33764 .56817 L F
.806 .344 .134 r
.33764 .56817 m .33809 .56654 L .33587 .56553 L F
.33809 .56654 m .33833 .56564 L .33754 .56561 L F
.33809 .56654 m .33754 .56561 L .33587 .56553 L F
.727 .961 .942 r
.33587 .56553 m .33754 .56561 L .33808 .56388 L F
.33754 .56561 m .33833 .56564 L .33826 .56513 L F
.33754 .56561 m .33826 .56513 L .33808 .56388 L F
.563 .517 .762 r
.34113 .5992 m .34367 .59881 L .34329 .59583 L F
0 0 0 r
.34113 .5992 m .34246 .5982 L .34367 .59881 L F
.633 .53 .72 r
.34489 .60193 m .34113 .5992 L .34367 .59881 L F
.34489 .60193 m .34229 .60272 L .34113 .5992 L F
0 0 0 r
.34113 .5992 m .33978 .60123 L .34246 .5982 L F
.604 .86 .992 r
.22205 .57116 m .2218 .57301 L .2247 .57016 L F
.988 .736 .457 r
.22205 .57116 m .22217 .57308 L .22363 .5735 L F
0 .418 .696 r
.2218 .57301 m .22363 .5735 L .22488 .57385 L F
.356 0 0 r
.21957 .57486 m .22363 .5735 L .2218 .57301 L F
.2211 .57435 m .22229 .57472 L .22363 .5735 L F
.21957 .57486 m .22229 .57472 L .2211 .57435 L F
.988 .736 .457 r
.22217 .57308 m .22229 .57472 L .22363 .5735 L F
.544 .042 .013 r
.22229 .57472 m .22608 .57477 L .22363 .5735 L F
.79 .488 .478 r
.2235 .5767 m .22229 .57472 L .22334 .57613 L F
.794 .561 .585 r
.22358 .57645 m .22358 .57645 L .22358 .57625 L F
.22358 .57645 m .22598 .57751 L .2236 .57626 L F
.22358 .57645 m .2236 .57626 L .22358 .57625 L F
.982 .695 .385 r
.22354 .57719 m .22336 .58075 L .22598 .57751 L F
0 0 .241 r
.22336 .57787 m .22331 .57806 L .2235 .5767 L F
.897 .613 .498 r
.22331 .57806 m .22168 .57695 L .2235 .5767 L F
.982 .695 .385 r
.22168 .57695 m .22289 .57969 L .22331 .57806 L F
.897 .613 .498 r
.22325 .57854 m .22168 .57695 L .22331 .57806 L F
.982 .695 .385 r
.22168 .57695 m .22331 .57806 L .22354 .57719 L F
.22289 .57969 m .22336 .58075 L .22354 .57719 L F
0 0 .241 r
.22357 .57664 m .22336 .57787 L .2235 .5767 L F
.22336 .57787 m .22325 .57854 L .22331 .57806 L F
.794 .561 .585 r
.22387 .57724 m .22404 .57726 L .22347 .5764 L F
.22404 .57726 m .22598 .57751 L .22347 .5764 L F
.22334 .57613 m .22598 .57751 L .22608 .57477 L F
0 0 .241 r
.22567 .57504 m .22347 .57822 L .22357 .57664 L F
.22347 .57822 m .22325 .57854 L .22357 .57664 L F
.794 .561 .585 r
.22334 .57613 m .22608 .57477 L .22229 .57472 L F
0 .418 .696 r
.22488 .57385 m .22363 .5735 L .22581 .5741 L F
.53 0 0 r
.22363 .5735 m .22841 .574 L .22581 .5741 L F
.22363 .5735 m .22608 .57477 L .22841 .574 L F
0 0 .37 r
.22576 .57232 m .22567 .57504 L .22357 .57664 L F
.22357 .57655 m .22357 .57664 L .2235 .5767 L F
.22576 .57232 m .22357 .57664 L .22357 .57655 L F
.794 .561 .585 r
.22347 .5764 m .22358 .57645 L .22334 .57613 L F
.22358 .57645 m .22358 .57625 L .22334 .57613 L F
0 0 .37 r
.22576 .57232 m .22357 .57655 L .22313 .57257 L F
.22357 .57655 m .2235 .5767 L .22347 .5764 L F
.22357 .57655 m .22347 .5764 L .22313 .57257 L F
.79 .488 .478 r
.22347 .5764 m .22334 .57613 L .22346 .57629 L F
.2235 .5767 m .22334 .57613 L .22347 .5764 L F
.794 .561 .585 r
.22168 .57695 m .22387 .57724 L .22334 .57613 L F
.79 .488 .478 r
.2235 .5767 m .22168 .57695 L .22229 .57472 L F
.794 .561 .585 r
.22168 .57695 m .22334 .57613 L .22229 .57472 L F
.79 .488 .478 r
.22346 .57629 m .22229 .57472 L .22335 .57506 L F
.22335 .57506 m .22229 .57472 L .22313 .57257 L F
.558 .846 .517 r
.35849 .68379 m .35672 .68583 L .35657 .68595 L F
.207 .105 .512 r
.27581 .55788 m .27742 .55968 L .27771 .55716 L F
.27581 .55788 m .27524 .56127 L .27742 .55968 L F
.577 .252 .383 r
.57487 .46485 m .57087 .46759 L .57112 .46562 L F
.263 .138 .516 r
.3225 .65742 m .32156 .65518 L .31973 .65596 L F
.3225 .65742 m .3237 .65304 L .32156 .65518 L F
.867 .443 .206 r
.32119 .65806 m .3225 .65742 L .31973 .65596 L F
0 0 .425 r
.32311 .65946 m .3225 .65742 L .32353 .65944 L F
.867 .443 .206 r
.32119 .65806 m .32353 .65944 L .3225 .65742 L F
.187 .71 .867 r
.36645 .71398 m .36941 .71398 L .36913 .71403 L F
.467 .877 .736 r
.36913 .71403 m .36941 .71398 L .37075 .71305 L F
.179 .482 .898 r
.34483 .70844 m .34571 .70746 L .34423 .70693 L F
.34483 .70844 m .34816 .71033 L .34571 .70746 L F
.475 .494 .797 r
.23218 .59504 m .23149 .59931 L .22973 .5961 L F
.23218 .59504 m .23394 .59902 L .23149 .59931 L F
.416 .538 .872 r
.23701 .60093 m .23562 .60246 L .23394 .59902 L F
0 0 .13 r
.23599 .60382 m .23562 .60246 L .23701 .60093 L F
.334 .051 .326 r
.67693 .39029 m .67488 .39422 L .67472 .39193 L F
.67693 .39029 m .67781 .39143 L .67488 .39422 L F
.235 .033 .389 r
.67972 .38971 m .67781 .39143 L .67693 .39029 L F
.501 .173 .342 r
.29845 .631 m .30039 .63398 L .29761 .63373 L F
.29845 .631 m .30099 .63076 L .30039 .63398 L F
.487 .328 .59 r
.32795 .49641 m .32753 .49976 L .3256 .49755 L F
.552 .065 0 r
.3256 .49755 m .32579 .49788 L .32795 .49641 L F
.3256 .49755 m .32753 .49976 L .32579 .49788 L F
.826 .86 .871 r
.64489 .34693 m .64182 .34709 L .64349 .34539 L F
.819 .856 .876 r
.64806 .34382 m .64489 .34693 L .64349 .34539 L F
.735 .992 .847 r
.29587 .51958 m .29969 .51657 L .29763 .5168 L F
.711 .955 .679 r
.29456 .52044 m .29587 .51958 L .29763 .5168 L F
.433 .165 .406 r
.67472 .39193 m .67488 .39422 L .67203 .39486 L F
.009 .485 .87 r
.58526 .39784 m .58342 .39739 L .58188 .39612 L F
.672 .253 0 r
.40614 .53546 m .4054 .53441 L .40398 .53188 L F
.993 .833 .467 r
.40614 .53546 m .40575 .53831 L .4054 .53441 L F
.967 .932 .687 r
.65111 .4046 m .64916 .40584 L .65058 .40369 L F
.65111 .4046 m .64963 .40803 L .64916 .40584 L F
.703 .335 0 r
.64962 .40149 m .65111 .4046 L .65058 .40369 L F
.34 .017 .263 r
.66976 .37385 m .66718 .3721 L .66704 .37597 L F
.66976 .37385 m .6694 .37127 L .66718 .3721 L F
.53 0 0 r
.3237 .65304 m .32352 .65384 L .32156 .65518 L F
.3237 .65304 m .3265 .65391 L .32352 .65384 L F
.856 .834 .824 r
.38019 .58016 m .37574 .58204 L .37612 .58241 L F
.868 .767 .748 r
.38019 .58016 m .37612 .58241 L .37685 .57999 L F
.361 .204 .529 r
.29633 .62154 m .29835 .62088 L .29835 .61816 L F
.459 .273 .541 r
.29581 .62445 m .29835 .62088 L .29633 .62154 L F
.865 .927 .865 r
.70513 .29574 m .70775 .29657 L .70898 .2941 L F
.271 .291 .698 r
.20761 .58307 m .20813 .58673 L .20993 .58521 L F
.314 .245 .618 r
.20831 .58927 m .20993 .58521 L .20813 .58673 L F
.898 .651 .556 r
.53218 .4268 m .53167 .42933 L .53042 .42559 L F
.918 .655 .524 r
.61208 .4382 m .61346 .43577 L .61287 .43612 L F
.61208 .4382 m .61481 .43927 L .61346 .43577 L F
.411 .383 .717 r
.61346 .43577 m .61686 .43452 L .61562 .43237 L F
.241 .208 .62 r
.61481 .43927 m .61686 .43452 L .61346 .43577 L F
.936 .963 .747 r
.71801 .36228 m .72083 .35972 L .72096 .35884 L F
.71801 .36228 m .71876 .36328 L .72083 .35972 L F
0 0 0 r
.72216 .3575 m .72083 .35972 L .7226 .3559 L F
.734 .991 .849 r
.72096 .35884 m .72083 .35972 L .72216 .3575 L F
.027 .005 .492 r
.20711 .57684 m .2081 .57611 L .20777 .57345 L F
.08 .076 .551 r
.20711 .57684 m .20859 .57884 L .2081 .57611 L F
.606 .525 .737 r
.23841 .54592 m .23716 .54995 L .23978 .54761 L F
.15 .406 .851 r
.2786 .63734 m .28118 .64086 L .28156 .6391 L F
0 .102 .648 r
.28118 .64086 m .28301 .64295 L .28156 .6391 L F
.165 .272 .73 r
.28118 .64086 m .28282 .64425 L .28301 .64295 L F
.544 .816 .996 r
.64605 .40072 m .64737 .40223 L .64962 .40149 L F
.757 .776 .869 r
.5731 .4136 m .5767 .41416 L .57607 .40974 L F
.773 .533 .572 r
.57273 .41669 m .5767 .41416 L .5731 .4136 L F
.57273 .41669 m .57707 .41687 L .5767 .41416 L F
.593 .561 .787 r
.5767 .41416 m .57844 .40927 L .57607 .40974 L F
.5767 .41416 m .57954 .41316 L .57844 .40927 L F
.509 .369 .625 r
.31415 .62803 m .31526 .63166 L .31607 .63078 L F
.126 .019 .451 r
.31794 .58331 m .31806 .58617 L .31928 .58229 L F
0 .115 .645 r
.61758 .44289 m .61898 .44455 L .61805 .44083 L F
.317 0 .108 r
.33049 .68454 m .32939 .68256 L .32755 .68442 L F
.33049 .68454 m .33189 .68203 L .32939 .68256 L F
0 .374 .684 r
.46594 .567 m .46611 .56704 L .46445 .5665 L F
.562 .482 .723 r
.4456 .48684 m .44392 .49091 L .44294 .48759 L F
.4456 .48684 m .44655 .49034 L .44392 .49091 L F
.567 .426 .648 r
.44655 .49034 m .44413 .49395 L .44392 .49091 L F
.29 0 0 r
.32486 .68667 m .32344 .68569 L .3224 .68785 L F
.32486 .68667 m .32559 .68538 L .32344 .68569 L F
.798 .759 .818 r
.63318 .35616 m .6307 .35916 L .62958 .35554 L F
.401 .828 .665 r
.68614 .35781 m .68655 .35772 L .68395 .35918 L F
0 0 .204 r
.68614 .35781 m .68395 .35918 L .6833 .36131 L F
.794 .852 .4 r
.68571 .35791 m .68614 .35781 L .68525 .35901 L F
.68687 .35509 m .68614 .35781 L .68571 .35791 L F
.401 .828 .665 r
.68614 .35781 m .6875 .35718 L .68655 .35772 L F
.414 .835 .668 r
.68974 .35581 m .6875 .35718 L .68614 .35781 L F
.621 .313 .427 r
.34489 .60193 m .341 .60464 L .34229 .60272 L F
.296 .077 .402 r
.57266 .42987 m .57052 .43158 L .57231 .43084 L F
.57335 .42796 m .57139 .43047 L .57266 .42987 L F
.57139 .43047 m .57052 .43158 L .57266 .42987 L F
.51 .231 .426 r
.57433 .42929 m .57335 .42796 L .57342 .42952 L F
.296 .077 .402 r
.57335 .42796 m .57231 .43084 L .57343 .4298 L F
.776 .876 .92 r
.57171 .42864 m .57405 .42922 L .57275 .43018 L F
.57033 .43155 m .57275 .43018 L .57001 .4322 L F
.57171 .42864 m .57275 .43018 L .57033 .43155 L F
.51 .231 .426 r
.57562 .42897 m .57521 .42879 L .57433 .42929 L F
.57521 .42879 m .57335 .42796 L .57433 .42929 L F
.776 .876 .92 r
.57343 .4298 m .57582 .42966 L .57159 .43151 L F
.51 .231 .426 r
.57433 .42929 m .57342 .42952 L .57343 .4298 L F
.776 .876 .92 r
.57405 .42922 m .57433 .42929 L .57343 .4298 L F
.57433 .42929 m .57582 .42966 L .57343 .4298 L F
.51 .231 .426 r
.57562 .42897 m .57433 .42929 L .57346 .43036 L F
.57433 .42929 m .57343 .4298 L .57346 .43036 L F
.556 .861 .997 r
.57562 .42897 m .57582 .42966 L .57433 .42929 L F
.57562 .42897 m .57433 .42929 L .57405 .42922 L F
.57474 .4289 m .57405 .42922 L .57171 .42864 L F
.57562 .42897 m .57405 .42922 L .57474 .4289 L F
.776 .876 .92 r
.57231 .43084 m .57159 .43151 L .57001 .4322 L F
.568 .938 .883 r
.57001 .4322 m .57346 .43036 L .57231 .43084 L F
.57001 .4322 m .57231 .43084 L .57052 .43158 L F
.776 .876 .92 r
.57405 .42922 m .57231 .43084 L .57001 .4322 L F
.296 .077 .402 r
.57343 .4298 m .57231 .43084 L .57346 .43036 L F
0 0 .484 r
.59029 .38861 m .59309 .39177 L .59116 .39061 L F
.926 .575 .346 r
.59309 .39177 m .59148 .39303 L .59116 .39061 L F
.59309 .39177 m .5939 .39475 L .59148 .39303 L F
.976 .922 .637 r
.70898 .2941 m .7099 .29286 L .70832 .29318 L F
0 0 .204 r
.7099 .29286 m .71032 .28762 L .71076 .29081 L F
.788 .996 .791 r
.70832 .29318 m .7099 .29286 L .71076 .29081 L F
.267 0 .304 r
.33137 .5974 m .32993 .596 L .33031 .5946 L F
.391 .129 .392 r
.33537 .59119 m .33461 .59484 L .33031 .5946 L F
.321 .023 .293 r
.33354 .59676 m .33031 .5946 L .33461 .59484 L F
.33354 .59676 m .33137 .5974 L .33031 .5946 L F
0 0 0 r
.29705 .55655 m .2995 .55604 L .30151 .55552 L F
.337 0 .052 r
.30151 .55552 m .30341 .55637 L .30408 .55507 L F
.814 .954 .908 r
.65394 .39105 m .65095 .39236 L .65411 .391 L F
0 0 .082 r
.65712 .38776 m .65394 .39105 L .65581 .38925 L F
0 0 0 r
.65581 .38925 m .65394 .39105 L .65411 .391 L F
.273 0 0 r
.36986 .6646 m .36849 .66366 L .36879 .66669 L F
.662 .516 .675 r
.36946 .66937 m .36986 .6646 L .36879 .66669 L F
.766 .254 0 r
.35803 .71459 m .3617 .71764 L .3588 .71755 L F
.921 .974 .76 r
.3588 .71755 m .36048 .7176 L .36315 .71326 L F
.36048 .7176 m .3617 .71764 L .36213 .71635 L F
.36048 .7176 m .36213 .71635 L .36315 .71326 L F
.357 .83 .87 r
.36343 .71536 m .36645 .71398 L .36459 .71617 L F
.3626 .71478 m .36479 .71433 L .36343 .71536 L F
.36479 .71433 m .36645 .71398 L .36343 .71536 L F
.433 0 .034 r
.36645 .71398 m .36917 .71576 L .36459 .71617 L F
.36645 .71398 m .36913 .71403 L .36917 .71576 L F
.852 .698 .69 r
.57235 .3976 m .57397 .40141 L .57101 .40131 L F
.781 .934 .931 r
.57397 .40141 m .56964 .40281 L .57101 .40131 L F
.39 .186 .479 r
.27676 .53214 m .27654 .53523 L .2742 .53598 L F
.324 .811 .829 r
.27654 .53523 m .27211 .53626 L .2742 .53598 L F
.592 .867 .994 r
.40631 .48729 m .40725 .48542 L .40882 .48647 L F
.40631 .48729 m .40479 .48628 L .40725 .48542 L F
.246 0 .149 r
.30237 .54403 m .3012 .54691 L .29883 .54766 L F
.052 0 .062 r
.30303 .54588 m .3012 .54691 L .30237 .54403 L F
.317 0 0 r
.30552 .55858 m .3035 .56003 L .30104 .55994 L F
0 0 0 r
.30625 .55856 m .30552 .55858 L .30776 .55836 L F
.30625 .55856 m .3035 .56003 L .30552 .55858 L F
.24712 .5408 m .24798 .53892 L .24743 .53794 L F
.746 .698 .806 r
.36456 .67905 m .36846 .67912 L .3665 .67551 L F
.672 .274 .284 r
.36685 .68139 m .36846 .67912 L .36456 .67905 L F
.889 .906 .832 r
.36846 .67912 m .36937 .67489 L .3665 .67551 L F
.589 .812 .415 r
.36934 .67783 m .36846 .67912 L .36685 .68139 L F
.807 .893 .905 r
.36111 .68883 m .36339 .68885 L .36409 .68796 L F
.878 .841 .805 r
.36111 .68883 m .36204 .68979 L .36339 .68885 L F
0 0 .078 r
.36409 .68796 m .36339 .68885 L .36488 .68773 L F
0 0 .466 r
.36352 .68872 m .36111 .68883 L .36409 .68796 L F
.447 .837 .621 r
.3634 .6888 m .36339 .68885 L .36204 .68979 L F
.485 .262 .499 r
.36205 .68991 m .36061 .69425 L .36245 .69328 L F
.36204 .68979 m .36198 .68996 L .36205 .68991 L F
.36198 .68996 m .36061 .69425 L .36205 .68991 L F
0 0 0 r
.36462 .68801 m .36409 .68796 L .36488 .68773 L F
.447 .837 .621 r
.36396 .68842 m .36339 .68885 L .3634 .68881 L F
.36352 .68872 m .3634 .68881 L .3634 .6888 L F
.36396 .68842 m .3634 .68881 L .36352 .68872 L F
0 0 0 r
.36343 .68885 m .36352 .68872 L .36396 .68843 L F
.447 .837 .621 r
.36488 .68773 m .36344 .68884 L .36476 .69042 L F
.36488 .68773 m .36396 .68842 L .3634 .6888 L F
0 0 0 r
.36352 .68872 m .36451 .688 L .36462 .68801 L F
0 0 .466 r
.36343 .68883 m .3634 .6888 L .36352 .68872 L F
.36343 .68885 m .3634 .6888 L .36343 .68883 L F
.447 .837 .621 r
.36488 .68773 m .3634 .6888 L .36344 .68884 L F
0 0 0 r
.36334 .68895 m .36343 .68885 L .36462 .68801 L F
.36343 .68885 m .36396 .68843 L .36462 .68801 L F
.36352 .68872 m .36409 .68796 L .36451 .688 L F
.447 .837 .621 r
.3634 .6888 m .36204 .68979 L .36408 .69026 L F
.3634 .6888 m .36408 .69026 L .36476 .69042 L F
.361 .104 .382 r
.36476 .69042 m .36204 .68979 L .36245 .69328 L F
0 0 .466 r
.36185 .69095 m .36154 .69006 L .3634 .6888 L F
.36185 .69095 m .3634 .6888 L .36343 .68885 L F
0 0 0 r
.36185 .69095 m .36334 .68895 L .36462 .68801 L F
0 0 .466 r
.36154 .69006 m .36111 .68883 L .36352 .68872 L F
.798 .969 .911 r
.30487 .51235 m .30874 .51055 L .30697 .50849 L F
.224 .084 .471 r
.3217 .57638 m .32404 .57269 L .32082 .57472 L F
.735 .231 0 r
.3678 .50795 m .36762 .50656 L .36538 .50593 L F
.3678 .50795 m .36933 .50901 L .36762 .50656 L F
.381 0 .072 r
.33518 .5419 m .33352 .5439 L .33099 .54427 L F
.552 .127 .187 r
.33749 .54371 m .33352 .5439 L .33518 .5419 L F
.964 .751 .568 r
.53522 .4343 m .53379 .43537 L .53392 .43273 L F
.53522 .4343 m .53531 .43695 L .53379 .43537 L F
.509 0 0 r
.6101 .41069 m .61081 .41153 L .60904 .40934 L F
.607 .186 0 r
.6101 .41069 m .61258 .41461 L .61246 .41264 L F
.509 0 0 r
.6101 .41069 m .61246 .41264 L .61081 .41153 L F
.722 .617 .74 r
.55057 .41488 m .54669 .41419 L .54901 .4131 L F
.698 .677 .827 r
.54901 .4131 m .55315 .41391 L .55057 .41488 L F
.578 .557 .795 r
.59962 .36685 m .6019 .36621 L .60085 .36177 L F
0 0 .475 r
.41235 .55694 m .41111 .5525 L .41205 .55455 L F
0 0 .24 r
.23949 .56031 m .2405 .55682 L .23941 .55788 L F
.352 .18 .503 r
.31875 .6054 m .31865 .60838 L .31662 .60882 L F
.617 .45 .633 r
.32029 .61024 m .31662 .60882 L .31865 .60838 L F
.32029 .61024 m .31644 .61177 L .31662 .60882 L F
.065 .629 .738 r
.31196 .55819 m .31036 .55818 L .30776 .55836 L F
.083 0 0 r
.31303 .55844 m .31036 .55818 L .31196 .55819 L F
.064 0 0 r
.31451 .55799 m .31303 .55844 L .31196 .55819 L F
.798 .698 .755 r
.64799 .36229 m .65188 .36296 L .65053 .35892 L F
.747 .636 .737 r
.65212 .36625 m .65598 .36343 L .65188 .36296 L F
.062 .598 .857 r
.32748 .55275 m .32642 .55218 L .32577 .55024 L F
.32748 .55275 m .32972 .55288 L .32642 .55218 L F
.834 .737 .758 r
.67486 .33622 m .67891 .33428 L .67746 .33263 L F
.67486 .33622 m .67661 .3375 L .67891 .33428 L F
.87 .825 .801 r
.67891 .33428 m .68005 .32906 L .67746 .33263 L F
.472 .359 .644 r
.43374 .58044 m .43593 .58245 L .43381 .58316 L F
.29 .172 .541 r
.31858 .66586 m .31698 .66614 L .31823 .66844 L F
.552 .631 .884 r
.31945 .62195 m .32333 .62338 L .32166 .62121 L F
.501 .278 .508 r
.28332 .56413 m .28308 .56695 L .28069 .56737 L F
.544 .296 .49 r
.28602 .56372 m .28308 .56695 L .28332 .56413 L F
.468 .135 .318 r
.36937 .67489 m .36831 .67318 L .3665 .67551 L F
.815 .842 .87 r
.42442 .4801 m .42057 .48036 L .42293 .47754 L F
.42442 .4801 m .42218 .48174 L .42057 .48036 L F
.733 .805 .909 r
.42735 .47775 m .42442 .4801 L .42293 .47754 L F
.578 .893 .622 r
.64797 .39386 m .6461 .39568 L .64482 .39658 L F
.131 0 0 r
.26044 .54339 m .26469 .54186 L .26255 .54291 L F
.711 .459 .542 r
.36726 .51925 m .36439 .52045 L .36582 .51657 L F
.848 .852 .845 r
.66251 .33134 m .65807 .33326 L .66088 .32997 L F
.853 .856 .843 r
.66488 .32849 m .66251 .33134 L .66088 .32997 L F
.868 .513 .013 r
.61208 .4382 m .61382 .44211 L .61481 .43927 L F
.241 .208 .62 r
.61481 .43927 m .61697 .43867 L .61686 .43452 L F
.282 .363 .769 r
.61481 .43927 m .61805 .44083 L .61697 .43867 L F
.798 .923 .92 r
.71307 .33768 m .70864 .33909 L .71168 .3361 L F
.806 .845 .88 r
.71596 .33507 m .71307 .33768 L .71168 .3361 L F
.354 0 0 r
.35479 .52529 m .35237 .52504 L .35063 .52433 L F
.287 .057 .38 r
.35239 .529 m .35455 .52822 L .35479 .52529 L F
.962 .664 .42 r
.35479 .52529 m .35455 .52822 L .35237 .52504 L F
0 0 0 r
.35729 .52268 m .35583 .52428 L .35479 .52529 L F
.353 .821 .906 r
.35573 .52434 m .35479 .52529 L .35583 .52428 L F
.35573 .52434 m .35237 .52504 L .35479 .52529 L F
0 0 0 r
.22287 .54503 m .22444 .54358 L .22524 .54151 L F
.164 0 .222 r
.22287 .54503 m .22403 .54618 L .22444 .54358 L F
.22287 .54503 m .22207 .54732 L .22403 .54618 L F
.223 .052 .426 r
.22747 .56516 m .22669 .56649 L .22572 .56583 L F
0 0 0 r
.22549 .56856 m .2247 .57016 L .22598 .5671 L F
.22549 .56856 m .22598 .5671 L .22644 .56602 L F
.22713 .56782 m .22525 .56926 L .22549 .56856 L F
.373 .827 .726 r
.22405 .57018 m .2247 .57016 L .22549 .56856 L F
0 0 0 r
.22525 .56926 m .22405 .57018 L .22549 .56856 L F
.22549 .56856 m .22644 .56602 L .22572 .56583 L F
.223 .052 .426 r
.22669 .56649 m .22549 .56856 L .22572 .56583 L F
.764 .693 .784 r
.22644 .56602 m .22446 .56498 L .22572 .56583 L F
.22446 .56498 m .2226 .56399 L .22572 .56583 L F
.094 .18 .663 r
.33359 .68987 m .33065 .68864 L .33342 .68809 L F
.571 .854 .524 r
.2937 .6574 m .29652 .65429 L .29494 .65589 L F
.606 .91 .641 r
.29164 .65894 m .2937 .6574 L .29494 .65589 L F
.191 0 .334 r
.27891 .52906 m .27848 .53134 L .27676 .53214 L F
.276 .095 .445 r
.27829 .53397 m .27676 .53214 L .27848 .53134 L F
.775 .689 .769 r
.2767 .53034 m .27807 .53346 L .27848 .53134 L F
.27807 .53346 m .27829 .53397 L .27848 .53134 L F
.191 0 .334 r
.27902 .5289 m .27848 .53134 L .27891 .52906 L F
.276 .095 .445 r
.27829 .53397 m .27654 .53523 L .27676 .53214 L F
.74 .318 0 r
.40398 .53188 m .4032 .53111 L .40191 .52853 L F
.712 .276 0 r
.40398 .53188 m .4054 .53441 L .4032 .53111 L F
.441 .059 .217 r
.42275 .59878 m .42351 .59598 L .42627 .59552 L F
.772 .832 .898 r
.42218 .48174 m .41703 .48349 L .42057 .48036 L F
.599 .914 .662 r
.34411 .53039 m .34255 .53213 L .34559 .52939 L F
.58 .536 .77 r
.34411 .53039 m .34458 .53143 L .34267 .53448 L F
.842 .778 .79 r
.34623 .534 m .34571 .53836 L .34383 .53697 L F
.34623 .534 m .34383 .53697 L .3441 .53499 L F
.34623 .534 m .34229 .53582 L .34267 .53448 L F
.366 0 0 r
.34267 .53448 m .34598 .53455 L .34623 .534 L F
.58 .536 .77 r
.34458 .53143 m .34598 .53455 L .34416 .53451 L F
.34458 .53143 m .34416 .53451 L .34267 .53448 L F
.842 .778 .79 r
.3441 .53499 m .34383 .53697 L .34229 .53582 L F
.849 .388 .046 r
.34571 .53836 m .3461 .54034 L .34229 .53582 L F
.294 0 0 r
.25881 .56804 m .26334 .56671 L .26078 .56697 L F
.021 0 0 r
.29052 .62783 m .29223 .62736 L .29366 .62523 L F
.106 0 0 r
.29366 .62523 m .29418 .6265 L .29581 .62445 L F
.29366 .62523 m .29223 .62736 L .29418 .6265 L F
.794 .982 .9 r
.69167 .3116 m .69331 .31153 L .69263 .31011 L F
.883 .99 .798 r
.69263 .31011 m .69331 .31153 L .69564 .30747 L F
0 0 .505 r
.41441 .57454 m .41565 .57642 L .41341 .57247 L F
.6 .334 .487 r
.34081 .5673 m .34312 .56968 L .34049 .56976 L F
.643 .542 .726 r
.34275 .56458 m .34309 .56763 L .34081 .5673 L F
.644 .33 .424 r
.34081 .5673 m .34309 .56763 L .34312 .56968 L F
0 0 .154 r
.27398 .56257 m .27524 .56127 L .27452 .56267 L F
0 0 0 r
.27524 .56127 m .27452 .56267 L .27742 .55968 L F
.638 .828 .973 r
.28391 .63075 m .28829 .63116 L .28623 .63008 L F
0 0 0 r
.28829 .63116 m .28538 .63388 L .28784 .63413 L F
.566 .666 .905 r
.28829 .63116 m .28936 .62786 L .28623 .63008 L F
.28829 .63116 m .29053 .6308 L .28936 .62786 L F
.502 .262 .482 r
.2903 .63343 m .28829 .63116 L .28784 .63413 L F
.2903 .63343 m .29053 .6308 L .28829 .63116 L F
.774 .268 0 r
.32524 .69425 m .32693 .69515 L .32768 .69658 L F
.951 .892 .734 r
.36716 .52511 m .36307 .52564 L .36519 .52341 L F
.36716 .52511 m .3651 .53018 L .36307 .52564 L F
.53 .255 .442 r
.44878 .58991 m .44836 .59237 L .44567 .59258 L F
.437 .177 .42 r
.45136 .58924 m .44836 .59237 L .44878 .58991 L F
.854 .832 .824 r
.66647 .32697 m .66336 .32684 L .66609 .32375 L F
.66647 .32697 m .66488 .32849 L .66336 .32684 L F
.849 .857 .849 r
.66925 .32371 m .66647 .32697 L .66609 .32375 L F
.522 .028 .025 r
.60208 .45619 m .60466 .45748 L .6021 .45739 L F
.82 .977 .891 r
.63645 .37163 m .64027 .36974 L .6394 .36834 L F
.722 .753 .877 r
.64027 .36974 m .64199 .3651 L .6394 .36834 L F
.64027 .36974 m .6429 .3685 L .64199 .3651 L F
.752 .751 .851 r
.70312 .35349 m .70672 .35397 L .70555 .35214 L F
.672 .798 .942 r
.70672 .35397 m .70959 .35147 L .70555 .35214 L F
.70672 .35397 m .70992 .3529 L .70959 .35147 L F
.905 .674 .168 r
.71011 .35589 m .70992 .3529 L .70672 .35397 L F
.843 .391 0 r
.37551 .51436 m .37585 .51277 L .37357 .51261 L F
.37551 .51436 m .3771 .51556 L .37585 .51277 L F
.82 .546 .524 r
.38639 .56663 m .38867 .56733 L .39029 .56712 L F
.758 .566 .637 r
.39029 .56712 m .38842 .57022 L .38565 .56969 L F
0 0 0 r
.37936 .58541 m .38127 .58315 L .3826 .5823 L F
.02 0 0 r
.34055 .58287 m .33931 .58506 L .33755 .58582 L F
.322 .054 .342 r
.34337 .57991 m .34296 .58195 L .34055 .58287 L F
.271 0 .053 r
.34175 .58445 m .34055 .58287 L .34296 .58195 L F
.34175 .58445 m .33931 .58506 L .34055 .58287 L F
.684 .174 .023 r
.26338 .61814 m .2685 .6198 L .26549 .61987 L F
0 0 .469 r
.40184 .64948 m .40237 .65036 L .40004 .64709 L F
.951 .805 .359 r
.40195 .65302 m .40237 .65036 L .40184 .64948 L F
.51 .38 .64 r
.33755 .58582 m .33477 .58907 L .33484 .58631 L F
.899 .783 .724 r
.71964 .34191 m .72091 .34385 L .71951 .34359 L F
.653 .883 .982 r
.4358 .55036 m .44022 .55027 L .43826 .54945 L F
.837 .929 .892 r
.43826 .54945 m .44022 .55027 L .44244 .5478 L F
.71 .255 .169 r
.56433 .46567 m .563 .46716 L .5603 .46496 L F
.674 .21 .142 r
.56433 .46567 m .56665 .46757 L .563 .46716 L F
.646 .933 .969 r
.39746 .67114 m .39995 .67167 L .39831 .66863 L F
.569 .557 .801 r
.39204 .65263 m .38987 .65484 L .38967 .65313 L F
.429 .792 .996 r
.25776 .52261 m .25866 .52136 L .25814 .52167 L F
.564 .933 .917 r
.25776 .52261 m .25632 .52253 L .25866 .52136 L F
.855 .738 .734 r
.30191 .53399 m .30384 .53537 L .30169 .53162 L F
.804 .636 .673 r
.30191 .53399 m .3037 .53806 L .30384 .53537 L F
.497 .304 .549 r
.3061 .5374 m .3037 .53806 L .30384 .53537 L F
.3061 .5374 m .3037 .53806 L .30384 .53537 L F
.793 .7 .762 r
.32937 .63442 m .33128 .63082 L .32896 .63262 L F
.075 0 .035 r
.36917 .71576 m .37111 .71301 L .36949 .71531 L F
0 0 0 r
.37075 .71305 m .37112 .71298 L .37112 .713 L F
.37075 .71305 m .37329 .71266 L .37127 .71279 L F
.075 0 .035 r
.37111 .71301 m .37127 .71279 L .37111 .71301 L F
.37111 .71301 m .37111 .71301 L .36949 .71531 L F
0 0 0 r
.37283 .71267 m .37605 .71206 L .37329 .71266 L F
.221 .738 .726 r
.37329 .71266 m .37605 .71206 L .3782 .71146 L F
.37329 .71266 m .3782 .71146 L .37614 .71243 L F
.281 .772 .902 r
.37329 .71266 m .37614 .71243 L .3747 .71203 L F
.37329 .71266 m .3747 .71203 L .37371 .71264 L F
.37329 .71266 m .37371 .71264 L .37175 .71386 L F
0 0 0 r
.37112 .713 m .37283 .71267 L .37329 .71266 L F
.37112 .71298 m .37605 .71206 L .37112 .713 L F
.707 .943 .643 r
.24346 .53323 m .24418 .5333 L .246 .53137 L F
.24346 .53323 m .24274 .53444 L .24418 .5333 L F
.491 .774 .994 r
.38857 .605 m .39229 .60561 L .39165 .60441 L F
.526 .296 .508 r
.38965 .60901 m .39229 .60561 L .38857 .605 L F
.38965 .60901 m .39193 .6086 L .39229 .60561 L F
.852 .987 .715 r
.38965 .60901 m .39229 .60561 L .39193 .6086 L F
.962 .739 .555 r
.40163 .65626 m .40344 .65669 L .40195 .65302 L F
.962 .749 .57 r
.40282 .65924 m .40344 .65669 L .40163 .65626 L F
.927 .95 .785 r
.39165 .60441 m .39229 .60561 L .39172 .60305 L F
.976 .786 .367 r
.39165 .60441 m .39179 .60645 L .39229 .60561 L F
.978 .787 .371 r
.39229 .60561 m .39193 .6086 L .39117 .60761 L F
.976 .786 .367 r
.39179 .60645 m .39193 .6086 L .39229 .60561 L F
.978 .787 .371 r
.39229 .60561 m .39117 .60761 L .39119 .60745 L F
.531 .504 .771 r
.38857 .605 m .39165 .60441 L .39022 .60208 L F
.225 .354 .785 r
.39022 .60208 m .39165 .60441 L .39172 .60305 L F
.978 .787 .371 r
.39229 .60561 m .39119 .60745 L .39172 .60305 L F
.773 .559 .609 r
.3189 .53954 m .3169 .53765 L .31623 .53768 L F
.895 .986 .732 r
.31623 .53768 m .31926 .53398 L .3168 .53518 L F
.333 .116 .428 r
.31927 .53183 m .3168 .53518 L .31926 .53398 L F
.895 .986 .732 r
.31623 .53768 m .31749 .53442 L .31926 .53398 L F
0 0 .143 r
.31578 .5377 m .31623 .53768 L .3168 .53518 L F
.895 .986 .732 r
.31623 .53768 m .31593 .53673 L .31749 .53442 L F
.773 .559 .609 r
.3169 .53765 m .31593 .53673 L .31623 .53768 L F
0 0 .143 r
.31544 .53851 m .31623 .53768 L .31578 .5377 L F
.604 .405 .585 r
.58931 .45866 m .5904 .46144 L .58676 .46165 L F
.685 .481 .604 r
.59294 .45853 m .5904 .46144 L .58931 .45866 L F
.326 0 0 r
.29494 .65589 m .29652 .65429 L .29816 .65499 L F
.648 .774 .94 r
.33349 .52343 m .33454 .52527 L .3312 .52491 L F
.781 .832 .891 r
.33772 .52319 m .33454 .52527 L .33349 .52343 L F
.238 .102 .484 r
.30837 .62661 m .30567 .62775 L .30684 .62441 L F
0 0 .49 r
.30783 .62914 m .30567 .62775 L .30837 .62661 L F
.30783 .62914 m .30684 .63022 L .30567 .62775 L F
.457 .003 .084 r
.34623 .534 m .34854 .53414 L .35002 .53268 L F
0 0 0 r
.35002 .53268 m .34854 .53414 L .35185 .53152 L F
.973 .822 .634 r
.38147 .6795 m .38504 .67668 L .38401 .67885 L F
.176 0 .164 r
.38607 .67746 m .38504 .67668 L .38648 .67516 L F
.38607 .67746 m .38401 .67885 L .38504 .67668 L F
.622 .46 .641 r
.6864 .38472 m .68379 .38809 L .68363 .38548 L F
.6864 .38472 m .68379 .38809 L .68363 .38548 L F
.661 .478 .626 r
.38479 .57075 m .38236 .57175 L .38134 .57037 L F
.666 .929 .639 r
.34165 .52608 m .3397 .52768 L .33894 .52899 L F
.666 .933 .649 r
.3397 .52768 m .33718 .53031 L .33894 .52899 L F
.597 .105 .057 r
.33894 .52899 m .33718 .53031 L .34134 .53006 L F
.605 .449 .644 r
.33894 .52899 m .34217 .52892 L .34165 .52608 L F
.582 .324 .491 r
.33894 .52899 m .34134 .53006 L .34217 .52892 L F
.577 .252 .383 r
.57487 .46485 m .57364 .46768 L .57087 .46759 L F
.591 .268 .39 r
.57734 .46664 m .57487 .46485 L .57746 .46535 L F
.57734 .46664 m .57364 .46768 L .57487 .46485 L F
.581 .923 .717 r
.33848 .68344 m .34155 .68155 L .34047 .68348 L F
.48 .116 .269 r
.34155 .68155 m .34405 .68431 L .34047 .68348 L F
.34155 .68155 m .34469 .6816 L .34405 .68431 L F
.483 .56 .858 r
.46307 .55731 m .46232 .56086 L .46069 .55733 L F
.46307 .55731 m .46458 .56053 L .46232 .56086 L F
.965 .861 .458 r
.42931 .57891 m .43031 .57719 L .42898 .57746 L F
.42931 .57891 m .42985 .58001 L .43031 .57719 L F
.288 0 .285 r
.34561 .57924 m .34296 .58195 L .34337 .57991 L F
.872 .9 .849 r
.30391 .50987 m .30023 .51122 L .30353 .50887 L F
.651 .946 .957 r
.30697 .50849 m .30391 .50987 L .30353 .50887 L F
.344 .003 .234 r
.67825 .36532 m .68098 .36446 L .68129 .36186 L F
.03 0 .159 r
.68129 .36186 m .68278 .36291 L .6833 .36131 L F
.68129 .36186 m .68098 .36446 L .68278 .36291 L F
.159 .168 .619 r
.2811 .63179 m .27854 .63041 L .27972 .63017 L F
.2811 .63179 m .27982 .63551 L .27854 .63041 L F
0 0 .189 r
.55349 .42188 m .55329 .42117 L .55307 .41952 L F
.606 .525 .737 r
.23841 .54592 m .23523 .55063 L .23716 .54995 L F
0 .501 .74 r
.389 .58904 m .39245 .58969 L .39029 .58923 L F
.941 .709 .559 r
.39245 .58969 m .39195 .59227 L .39029 .58923 L F
.39245 .58969 m .39195 .59227 L .39029 .58923 L F
.251 .42 .835 r
.39029 .58923 m .39195 .59227 L .39271 .5896 L F
.39029 .58923 m .39271 .5896 L .3928 .5893 L F
0 .501 .74 r
.38801 .58885 m .389 .58904 L .39029 .58923 L F
.834 .82 .836 r
.68005 .32906 m .68406 .32774 L .68277 .32607 L F
.744 .835 .92 r
.68277 .32607 m .68406 .32774 L .68703 .32583 L F
.877 .985 .826 r
.42931 .57891 m .42707 .58329 L .42768 .58169 L F
.42931 .57891 m .42985 .58001 L .42707 .58329 L F
.847 .412 .192 r
.42642 .58539 m .42939 .58659 L .42707 .58329 L F
.42642 .58539 m .42707 .58329 L .42768 .58169 L F
0 0 .359 r
.33046 .63748 m .32937 .63442 L .32841 .63695 L F
.865 .664 .628 r
.37216 .59268 m .36826 .59258 L .36967 .59357 L F
.421 .181 .442 r
.31518 .51522 m .31283 .51574 L .31235 .51858 L F
.31518 .51522 m .31283 .51574 L .31235 .51858 L F
.135 .038 .471 r
.22959 .58558 m .22795 .58707 L .22808 .58489 L F
.448 0 0 r
.37967 .51783 m .38114 .51897 L .3824 .51987 L F
.848 .426 0 r
.38179 .52037 m .3824 .51987 L .38114 .51897 L F
.38179 .52037 m .38315 .52172 L .3824 .51987 L F
0 0 0 r
.62596 .41515 m .62383 .41722 L .62629 .41388 L F
.351 .423 .796 r
.62596 .41515 m .62804 .41936 L .62383 .41722 L F
.965 .936 .637 r
.65988 .40829 m .66006 .41123 L .66135 .40748 L F
.938 .951 .761 r
.65859 .41288 m .66006 .41123 L .65988 .40829 L F
.395 .13 .39 r
.32666 .59865 m .32383 .60169 L .32441 .59928 L F
.446 .121 .32 r
.46248 .57963 m .4594 .58211 L .45985 .57988 L F
.066 .427 .87 r
.33808 .56388 m .33833 .56564 L .33995 .56463 L F
.51 .517 .799 r
.25853 .57237 m .26012 .57702 L .26218 .57391 L F
.344 .752 .981 r
.2597 .57824 m .26122 .57711 L .25986 .57703 L F
.25804 .577 m .25986 .57703 L .25791 .57691 L F
.2597 .57824 m .25986 .57703 L .25804 .577 L F
.503 .576 .862 r
.26031 .57704 m .26281 .57599 L .26218 .57391 L F
.344 .752 .981 r
.26122 .57711 m .26123 .57711 L .26096 .57709 L F
.26122 .57711 m .26096 .57709 L .25791 .57691 L F
.501 .452 .733 r
.25791 .57691 m .26123 .57711 L .26019 .57723 L F
.503 .576 .862 r
.26019 .57723 m .2606 .57704 L .26031 .57704 L F
.2606 .57704 m .26281 .57599 L .26031 .57704 L F
.51 .517 .799 r
.26012 .57702 m .26019 .57723 L .26031 .57704 L F
.26012 .57702 m .26031 .57704 L .26218 .57391 L F
.273 0 .294 r
.26497 .57615 m .26267 .57806 L .26214 .57824 L F
.344 .752 .981 r
.2597 .57824 m .26267 .57806 L .26123 .57711 L F
.504 .636 .912 r
.26214 .57824 m .26267 .57806 L .2597 .57824 L F
.705 .336 .346 r
.33378 .61447 m .33403 .61695 L .33006 .61533 L F
0 0 .229 r
.33456 .61343 m .33403 .61695 L .33378 .61447 L F
.655 .304 .365 r
.23629 .6142 m .24056 .61208 L .23882 .61243 L F
.23629 .6142 m .23842 .61506 L .24056 .61208 L F
.664 .315 .371 r
.24056 .61208 m .23842 .61506 L .24279 .61448 L F
.329 .016 .273 r
.32182 .60259 m .32112 .6048 L .31875 .6054 L F
.564 .344 .539 r
.32383 .60169 m .32112 .6048 L .32182 .60259 L F
.742 .985 .901 r
.62733 .41165 m .62629 .41388 L .62961 .41131 L F
0 0 0 r
.62596 .41515 m .62629 .41388 L .62733 .41165 L F
.987 .714 .382 r
.54243 .39486 m .54111 .39378 L .54104 .39101 L F
.876 .923 .853 r
.54405 .39081 m .54111 .39378 L .54243 .39486 L F
0 0 0 r
.22524 .54151 m .22492 .54259 L .22756 .54094 L F
.22524 .54151 m .22444 .54358 L .22492 .54259 L F
.764 .571 .637 r
.54411 .41723 m .53994 .41908 L .54302 .41514 L F
.54411 .41723 m .54369 .41975 L .53994 .41908 L F
.354 .56 .913 r
.54533 .41538 m .54411 .41723 L .54302 .41514 L F
.659 .909 .588 r
.54669 .41419 m .54411 .41723 L .54533 .41538 L F
.748 .731 .836 r
.38662 .58319 m .39066 .58322 L .38917 .58016 L F
.56 .061 .026 r
.38861 .58478 m .39066 .58322 L .38662 .58319 L F
.558 .636 .884 r
.38917 .58016 m .39066 .58322 L .39303 .58229 L F
0 0 0 r
.39303 .58229 m .39066 .58322 L .38861 .58478 L F
.965 .738 .544 r
.39345 .59599 m .39177 .59623 L .39195 .59227 L F
.554 .795 .989 r
.39059 .59883 m .39177 .59623 L .39345 .59599 L F
.58 .536 .77 r
.34411 .53039 m .34267 .53448 L .34255 .53213 L F
.983 .697 .38 r
.32016 .54368 m .32145 .54673 L .32193 .54519 L F
.932 .648 .48 r
.2811 .63179 m .28357 .63414 L .28538 .63388 L F
.443 0 0 r
.28584 .63585 m .28538 .63388 L .2838 .63411 L F
.28584 .63585 m .28784 .63413 L .28538 .63388 L F
.319 0 .158 r
.28971 .63529 m .28784 .63413 L .28584 .63585 L F
.587 .239 .346 r
.28971 .63529 m .28584 .63585 L .28799 .63778 L F
0 .121 .653 r
.28764 .6374 m .28584 .63585 L .28467 .63411 L F
.28799 .63778 m .28584 .63585 L .28764 .6374 L F
.443 0 0 r
.28584 .63585 m .2838 .63411 L .28357 .63414 L F
.31 .62 .958 r
.58188 .39612 m .5788 .39586 L .57749 .39403 L F
.736 .707 .824 r
.29658 .6385 m .29365 .64122 L .29314 .64014 L F
.345 0 .097 r
.29297 .63723 m .29389 .63939 L .29242 .63982 L F
.29389 .63939 m .29377 .6395 L .29242 .63982 L F
.29297 .63723 m .29525 .63675 L .29398 .63935 L F
.736 .707 .824 r
.29658 .6385 m .29314 .64014 L .29385 .63943 L F
.183 0 .026 r
.29415 .63925 m .29746 .63608 L .29658 .6385 L F
.736 .707 .824 r
.29658 .6385 m .29385 .63943 L .29551 .63844 L F
.183 0 .026 r
.29392 .63947 m .29415 .63925 L .29658 .6385 L F
.736 .707 .824 r
.29551 .63844 m .29415 .63925 L .29485 .63841 L F
.29415 .63925 m .29385 .63943 L .29397 .6393 L F
.183 0 .026 r
.29415 .63925 m .29525 .63675 L .29746 .63608 L F
.736 .707 .824 r
.29415 .63925 m .29397 .6393 L .29485 .63841 L F
.183 0 .026 r
.29392 .63947 m .29398 .63935 L .29415 .63925 L F
.29398 .63935 m .29525 .63675 L .29415 .63925 L F
.345 0 .097 r
.29389 .63939 m .29398 .63935 L .29392 .63947 L F
.29297 .63723 m .29398 .63935 L .29389 .63939 L F
.736 .707 .824 r
.29485 .63841 m .29389 .63939 L .29225 .63827 L F
.29389 .63939 m .29314 .64014 L .29296 .63976 L F
.294 .581 .94 r
.29225 .63827 m .29242 .63982 L .29377 .6395 L F
.736 .707 .824 r
.29389 .63939 m .29372 .63946 L .29225 .63827 L F
.345 0 .097 r
.29389 .63939 m .29392 .63947 L .29377 .6395 L F
.294 .581 .94 r
.29225 .63827 m .29377 .6395 L .29392 .63947 L F
.736 .707 .824 r
.29372 .63946 m .29296 .63976 L .29225 .63827 L F
.595 .825 .987 r
.61661 .37423 m .61809 .37572 L .61527 .3759 L F
.662 .86 .975 r
.33404 .50128 m .33342 .50358 L .3361 .50231 L F
.726 .838 .934 r
.20493 .60506 m .20915 .60498 L .2074 .60411 L F
.809 .907 .908 r
.70414 .28499 m .70218 .28702 L .70076 .2858 L F
.508 .461 .739 r
.33158 .62128 m .32922 .62173 L .32866 .619 L F
.777 .79 .864 r
.39344 .68924 m .39753 .68889 L .39605 .68847 L F
.448 .853 .968 r
.39753 .68889 m .39874 .68791 L .39605 .68847 L F
.702 .655 .8 r
.6475 .42245 m .64725 .42738 L .65189 .42355 L F
.883 .894 .834 r
.28746 .51999 m .28843 .52361 L .2905 .52176 L F
.28746 .51999 m .286 .52284 L .28843 .52361 L F
0 0 .159 r
.22325 .60506 m .22406 .60513 L .2245 .60198 L F
.894 .852 .399 r
.40188 .60053 m .40288 .59897 L .40275 .5982 L F
.40188 .60053 m .40199 .60257 L .40288 .59897 L F
.951 .711 .539 r
.39303 .58229 m .39395 .58087 L .39159 .57921 L F
.685 .819 .947 r
.39159 .57921 m .39395 .58087 L .39575 .57941 L F
.841 .967 .883 r
.62202 .37901 m .623 .37605 L .62183 .37798 L F
.62202 .37901 m .62521 .37592 L .623 .37605 L F
.891 .959 .623 r
.62061 .38001 m .62202 .37901 L .62183 .37798 L F
.799 .475 .441 r
.62612 .38207 m .62202 .37901 L .62528 .38136 L F
.646 .13 0 r
.62061 .38001 m .62528 .38136 L .62202 .37901 L F
.991 .733 .412 r
.61669 .3716 m .61809 .37572 L .61661 .37423 L F
.988 .716 .383 r
.61679 .37685 m .61809 .37572 L .61661 .37423 L F
.081 .245 .733 r
.61669 .3716 m .61809 .37572 L .61918 .37351 L F
.718 .92 .575 r
.61918 .37351 m .61809 .37572 L .61679 .37685 L F
0 0 0 r
.32013 .58008 m .32073 .58096 L .3215 .57847 L F
.32013 .58008 m .31928 .58229 L .32073 .58096 L F
.473 .848 .616 r
.69454 .36441 m .69245 .3661 L .69438 .36459 L F
.014 0 .321 r
.69454 .36441 m .69228 .36846 L .69245 .3661 L F
.981 .904 .577 r
.64916 .40584 m .64963 .40803 L .64878 .41045 L F
.534 .501 .765 r
.42319 .53743 m .42416 .54147 L .42148 .5417 L F
.962 .846 .429 r
.42931 .57891 m .42985 .58001 L .42913 .58309 L F
.713 .28 0 r
.28282 .64425 m .28298 .64499 L .28301 .64295 L F
.28282 .64425 m .28419 .64659 L .28298 .64499 L F
.735 .613 .722 r
.35922 .66918 m .36315 .6697 L .36212 .66606 L F
.814 .769 .811 r
.36315 .6697 m .36458 .66503 L .36212 .66606 L F
.111 0 0 r
.38287 .66947 m .3815 .66928 L .37856 .66885 L F
.38287 .66947 m .3815 .66928 L .37856 .66885 L F
.571 .933 .928 r
.38354 .66813 m .3815 .66928 L .38287 .66947 L F
.38287 .66947 m .3815 .66928 L .38354 .66813 L F
.38354 .66813 m .3815 .66928 L .38287 .66947 L F
.556 .404 .631 r
.35185 .53152 m .35455 .52822 L .35239 .529 L F
.454 .011 .104 r
.43664 .59602 m .43488 .59808 L .43249 .59813 L F
.458 .015 .107 r
.43881 .59714 m .43664 .59602 L .43923 .59589 L F
.43881 .59714 m .43488 .59808 L .43664 .59602 L F
0 0 0 r
.32204 .65091 m .31924 .65276 L .32098 .65145 L F
.602 .23 .31 r
.32098 .65145 m .32539 .65289 L .32204 .65091 L F
.958 .686 .48 r
.2287 .55004 m .22861 .55282 L .23065 .55127 L F
.492 .326 .584 r
.23065 .55127 m .23131 .54745 L .2287 .55004 L F
.23065 .55127 m .23299 .54792 L .23131 .54745 L F
.23065 .55127 m .23299 .55067 L .23299 .54792 L F
.477 .468 .769 r
.23299 .55067 m .23331 .55463 L .23065 .55127 L F
.158 0 0 r
.22861 .55282 m .23299 .55067 L .23065 .55127 L F
.719 .591 .712 r
.23542 .57331 m .23623 .57681 L .23281 .57727 L F
.072 0 .2 r
.23388 .57841 m .23281 .57727 L .23623 .57681 L F
0 .087 .606 r
.23735 .57569 m .23623 .57681 L .23542 .57331 L F
.525 .877 .637 r
.23388 .57841 m .23623 .57681 L .23735 .57569 L F
.853 .856 .843 r
.66488 .32849 m .66088 .32997 L .66336 .32684 L F
.163 0 .292 r
.53072 .41908 m .52776 .42234 L .5291 .41964 L F
.53072 .41908 m .52892 .42309 L .52776 .42234 L F
.753 .763 .861 r
.53355 .41679 m .53072 .41908 L .52953 .41638 L F
.543 .65 .904 r
.52953 .41638 m .53072 .41908 L .53215 .41812 L F
.477 .881 .732 r
.53156 .41842 m .53072 .41908 L .5291 .41964 L F
.53215 .41812 m .53143 .4186 L .53156 .41842 L F
.53143 .4186 m .53072 .41908 L .53156 .41842 L F
.53215 .41812 m .5291 .41964 L .53216 .41834 L F
.543 .65 .904 r
.52953 .41638 m .53215 .41812 L .53216 .41834 L F
0 .223 .735 r
.52953 .41638 m .53179 .41807 L .53129 .4169 L F
.53179 .41807 m .53216 .41834 L .5319 .41791 L F
.53179 .41807 m .5319 .41791 L .53129 .4169 L F
0 0 0 r
.60956 .45599 m .61109 .45455 L .60865 .45781 L F
.816 .936 .909 r
.26024 .5257 m .25944 .52944 L .26167 .52722 L F
.26024 .5257 m .25802 .52839 L .25944 .52944 L F
.661 .163 0 r
.27418 .58784 m .27662 .59047 L .27583 .58972 L F
.66 .908 .979 r
.3265 .65391 m .32539 .65289 L .32352 .65384 L F
.3265 .65391 m .32835 .65305 L .32539 .65289 L F
.728 .685 .809 r
.54369 .41975 m .54123 .42192 L .53994 .41908 L F
0 .489 .844 r
.54542 .42349 m .54123 .42192 L .54369 .41975 L F
0 .425 .836 r
.59064 .38231 m .59212 .38359 L .58912 .38247 L F
.762 .802 .885 r
.29197 .5632 m .29372 .56481 L .29597 .56333 L F
.46 .278 .547 r
.35284 .55054 m .35537 .54714 L .35289 .54804 L F
.569 .557 .801 r
.39204 .65263 m .39291 .65634 L .38987 .65484 L F
0 0 .161 r
.30684 .62441 m .3088 .62126 L .30824 .62382 L F
.238 .102 .484 r
.30837 .62661 m .30684 .62441 L .30824 .62382 L F
.455 .186 .415 r
.45091 .49379 m .44677 .49324 L .44974 .49274 L F
.45091 .49379 m .44799 .49653 L .44677 .49324 L F
.45091 .49379 m .45038 .49603 L .44799 .49653 L F
.561 .783 .982 r
.45247 .49214 m .45091 .49379 L .44974 .49274 L F
.424 .316 .627 r
.45247 .49214 m .45038 .49603 L .45091 .49379 L F
.43 .857 .943 r
.27558 .5241 m .27476 .52514 L .27734 .52424 L F
.27558 .5241 m .27305 .52484 L .27476 .52514 L F
.376 0 .184 r
.33758 .57877 m .3413 .57569 L .33898 .57629 L F
.729 .809 .914 r
.41204 .48642 m .40882 .48647 L .41182 .4851 L F
.769 .895 .932 r
.41567 .48431 m .41204 .48642 L .41182 .4851 L F
.392 0 .116 r
.28308 .56695 m .27973 .56862 L .28069 .56737 L F
.414 .519 .856 r
.72446 .35344 m .7226 .3559 L .72235 .35375 L F
0 0 0 r
.72216 .3575 m .7226 .3559 L .72446 .35344 L F
.622 .485 .674 r
.70961 .32463 m .71122 .32641 L .70709 .32661 L F
.592 .341 .505 r
.71122 .32641 m .707 .32982 L .70709 .32661 L F
.792 .975 .687 r
.66135 .40748 m .66395 .40419 L .66239 .4051 L F
.795 .981 .707 r
.65988 .40829 m .66135 .40748 L .66239 .4051 L F
.484 .437 .729 r
.35248 .57923 m .35524 .57913 L .35501 .5767 L F
.427 .272 .568 r
.35248 .57923 m .35521 .5819 L .35524 .57913 L F
.35248 .57923 m .35297 .58263 L .35521 .5819 L F
.886 .97 .654 r
.625 .43122 m .62462 .43379 L .62675 .4301 L F
.898 .967 .65 r
.625 .43122 m .62675 .4301 L .62731 .42674 L F
.97 .73 .518 r
.53531 .43695 m .53519 .43913 L .53379 .43537 L F
.77 .558 .611 r
.37489 .55447 m .37482 .55648 L .37781 .55643 L F
.531 .018 0 r
.37482 .55648 m .37709 .55735 L .37781 .55643 L F
0 0 0 r
.37781 .55643 m .37709 .55735 L .37942 .55628 L F
.865 .518 .393 r
.53645 .4458 m .54044 .4488 L .53825 .44895 L F
.729 .501 .581 r
.53825 .44895 m .54044 .4488 L .53828 .45143 L F
.785 .582 .627 r
.54044 .4488 m .54184 .45181 L .53828 .45143 L F
0 0 .275 r
.33166 .63201 m .33128 .63082 L .33184 .62948 L F
.33166 .63201 m .33184 .62948 L .33172 .63255 L F
0 0 .051 r
.33128 .63082 m .33172 .63255 L .33184 .62948 L F
.652 .201 .167 r
.28518 .62682 m .28936 .62786 L .28662 .62551 L F
.634 .071 0 r
.28662 .62551 m .28936 .62786 L .29052 .62783 L F
.618 .396 .558 r
.3493 .51511 m .35182 .51586 L .35193 .51246 L F
.473 .656 .941 r
.35193 .51246 m .3519 .50923 L .3512 .50912 L F
.35193 .51246 m .35298 .51021 L .35189 .50852 L F
.702 .416 .488 r
.35231 .50994 m .34887 .51098 L .34881 .50856 L F
.35298 .51021 m .35252 .5103 L .35231 .50994 L F
.35252 .5103 m .34887 .51098 L .35231 .50994 L F
.473 .656 .941 r
.3519 .50923 m .35189 .50852 L .35162 .50876 L F
.3519 .50923 m .35162 .50876 L .3512 .50912 L F
.35193 .51246 m .35415 .5121 L .35298 .51021 L F
.438 .25 .527 r
.35193 .51246 m .35405 .51483 L .35415 .5121 L F
.35193 .51246 m .35185 .51493 L .35405 .51483 L F
.777 .676 .752 r
.35405 .51483 m .35662 .51124 L .35415 .5121 L F
.35405 .51483 m .35802 .51526 L .35662 .51124 L F
.644 .3 .374 r
.35526 .51478 m .35405 .51483 L .35296 .51435 L F
.35615 .51494 m .35405 .51483 L .35526 .51478 L F
.438 .25 .527 r
.35185 .51493 m .35182 .51586 L .35405 .51483 L F
.596 .739 .944 r
.61303 .35787 m .61154 .36169 L .60977 .3598 L F
.61303 .35787 m .61396 .36087 L .61154 .36169 L F
.526 .817 .999 r
.36849 .66366 m .37238 .66394 L .36979 .66224 L F
.273 0 0 r
.36986 .6646 m .37238 .66394 L .36849 .66366 L F
.876 .881 .835 r
.36994 .66109 m .37238 .66394 L .36979 .66224 L F
.36994 .66109 m .37238 .66394 L .36979 .66224 L F
0 .014 .585 r
.58638 .39945 m .58699 .40117 L .58526 .39784 L F
.51 .38 .64 r
.33755 .58582 m .33644 .58933 L .33477 .58907 L F
.636 .481 .656 r
.33644 .58933 m .33537 .59119 L .33477 .58907 L F
.643 .855 .981 r
.63187 .43935 m .63366 .43694 L .63069 .43821 L F
.63187 .43935 m .63434 .43828 L .63366 .43694 L F
.63366 .43694 m .63187 .43935 L .63069 .43821 L F
.63366 .43694 m .63434 .43828 L .63187 .43935 L F
.778 .666 .74 r
.42935 .47701 m .43099 .47829 L .42735 .47775 L F
.684 .675 .836 r
.43366 .47741 m .43099 .47829 L .42935 .47701 L F
.963 .647 .249 r
.32894 .63999 m .32995 .64063 L .32841 .63695 L F
.989 .889 .616 r
.32763 .64272 m .32995 .64063 L .32894 .63999 L F
.963 .647 .249 r
.32894 .63999 m .32995 .64063 L .32841 .63695 L F
.989 .889 .616 r
.32894 .63999 m .32995 .64063 L .32763 .64272 L F
.641 .416 .561 r
.32755 .54137 m .33096 .54124 L .331 .5388 L F
.35 .557 .912 r
.331 .5388 m .33255 .53728 L .33004 .53696 L F
.548 .34 .551 r
.331 .5388 m .33352 .54072 L .33255 .53728 L F
.331 .5388 m .33096 .54124 L .33352 .54072 L F
.789 .771 .837 r
.63248 .35259 m .63318 .35616 L .62958 .35554 L F
.845 .804 .811 r
.63569 .35285 m .63318 .35616 L .63248 .35259 L F
.636 .714 .904 r
.34033 .65983 m .34506 .66102 L .34341 .65978 L F
.694 .572 .714 r
.34506 .66102 m .34697 .65943 L .34543 .65655 L F
.731 .867 .945 r
.37636 .59158 m .379 .593 L .37661 .5942 L F
.412 .367 .698 r
.45353 .54019 m .45124 .54213 L .45063 .53791 L F
.419 .378 .706 r
.45353 .54019 m .45403 .54386 L .45124 .54213 L F
.987 .763 .514 r
.55973 .43025 m .55895 .42709 L .55886 .4288 L F
.809 .793 .837 r
.56174 .42597 m .55973 .43025 L .55886 .4288 L F
.552 .4 .629 r
.68808 .37548 m .68789 .37884 L .68603 .37984 L F
.509 .358 .611 r
.68789 .37884 m .68584 .3826 L .68603 .37984 L F
.878 .841 .805 r
.36111 .68883 m .36056 .69166 L .36204 .68979 L F
.485 .262 .499 r
.36204 .68979 m .36056 .69166 L .36061 .69425 L F
0 .087 .606 r
.23735 .57569 m .23542 .57331 L .23754 .57297 L F
.575 .917 .705 r
.66646 .40079 m .6697 .39835 L .66818 .39905 L F
.476 .87 .689 r
.66818 .39905 m .6697 .39835 L .67162 .397 L F
.425 .148 .386 r
.67203 .39486 m .67488 .39422 L .67162 .397 L F
.703 .912 .564 r
.66521 .40192 m .66395 .40419 L .66646 .40079 L F
.736 .964 .689 r
.66239 .4051 m .66395 .40419 L .66521 .40192 L F
.291 0 .181 r
.34987 .59577 m .35339 .59309 L .35117 .59562 L F
0 0 0 r
.35339 .59309 m .35585 .59042 L .35486 .59154 L F
.496 .457 .743 r
.44995 .53581 m .45305 .53733 L .45063 .53791 L F
.412 .367 .698 r
.45353 .54019 m .45063 .53791 L .45305 .53733 L F
.678 .971 .917 r
.2377 .56553 m .23725 .56495 L .23845 .56385 L F
.72 .919 .57 r
.23845 .56385 m .23806 .56439 L .2377 .56553 L F
0 0 .533 r
.23626 .56333 m .2377 .56553 L .23736 .56662 L F
.692 .254 .207 r
.23464 .56504 m .2377 .56553 L .23626 .56333 L F
.72 .919 .57 r
.23806 .56439 m .23605 .56714 L .2377 .56553 L F
0 0 .533 r
.23736 .56662 m .2377 .56553 L .23748 .56699 L F
.967 .708 .491 r
.2377 .56553 m .23995 .56729 L .23748 .56699 L F
.269 0 .001 r
.24805 .57016 m .24616 .57252 L .24374 .57307 L F
.505 .691 .952 r
.24867 .56783 m .24805 .57016 L .24657 .56633 L F
.24867 .56783 m .25021 .56962 L .24805 .57016 L F
.77 .914 .534 r
.24712 .57036 m .24805 .57016 L .25021 .56962 L F
.24712 .57036 m .24616 .57252 L .24805 .57016 L F
.394 .12 .376 r
.3617 .71764 m .3626 .71478 L .36459 .71617 L F
.427 .836 .972 r
.35469 .53164 m .35899 .53061 L .35455 .52822 L F
.35469 .53164 m .3587 .53189 L .35899 .53061 L F
.662 .516 .675 r
.36946 .66937 m .37198 .66922 L .36986 .6646 L F
.636 .258 .311 r
.37436 .66622 m .36986 .6646 L .37298 .66475 L F
.573 .474 .703 r
.36986 .6646 m .37436 .66622 L .37298 .66475 L F
.36986 .6646 m .37198 .66922 L .37436 .66622 L F
.702 .852 .954 r
.62758 .40426 m .62381 .40417 L .62616 .40284 L F
.425 .843 .963 r
.6297 .40308 m .62758 .40426 L .62616 .40284 L F
.6297 .40308 m .63021 .40363 L .62758 .40426 L F
.801 .621 .659 r
.62833 .40713 m .63021 .40363 L .62758 .40426 L F
.029 0 0 r
.62758 .40426 m .62824 .40482 L .62833 .40713 L F
.62758 .40426 m .63021 .40363 L .62824 .40482 L F
.82 .742 .779 r
.67293 .33691 m .67661 .3375 L .67486 .33622 L F
.786 .632 .691 r
.67238 .33973 m .67661 .3375 L .67293 .33691 L F
.67238 .33973 m .6759 .34004 L .67661 .3375 L F
.664 .406 .52 r
.35478 .557 m .35739 .55696 L .3577 .55445 L F
.35478 .557 m .35739 .55696 L .3577 .55445 L F
.397 .175 .457 r
.3577 .55445 m .35739 .55696 L .35995 .55372 L F
.35995 .55372 m .35739 .55696 L .3577 .55445 L F
.532 .673 .928 r
.35336 .68735 m .35429 .69107 L .35192 .68773 L F
.35336 .68735 m .35671 .69112 L .35429 .69107 L F
.616 .53 .734 r
.32197 .64545 m .32101 .64618 L .32329 .64342 L F
.383 .708 .986 r
.63252 .37028 m .63395 .37179 L .63645 .37163 L F
.738 .97 .931 r
.60404 .36079 m .60085 .36177 L .60346 .3584 L F
.52 .67 .931 r
.60577 .358 m .60404 .36079 L .60346 .3584 L F
.60577 .358 m .60703 .36048 L .60404 .36079 L F
.43 .345 .659 r
.44907 .51803 m .44933 .52206 L .44707 .52272 L F
.446 .396 .708 r
.44933 .52206 m .44992 .52466 L .44707 .52272 L F
.391 .4 .749 r
.44707 .52272 m .44992 .52466 L .44809 .52535 L F
.568 .418 .639 r
.33283 .58241 m .32984 .58026 L .33192 .57937 L F
.33283 .58241 m .33029 .58303 L .32984 .58026 L F
.32984 .58026 m .33029 .58303 L .33283 .58241 L F
.072 0 .2 r
.23388 .57841 m .2324 .57917 L .23281 .57727 L F
.834 .765 .786 r
.69339 .32696 m .69463 .33066 L .69649 .32783 L F
.496 .477 .765 r
.45118 .53109 m .44995 .53581 L .44872 .5317 L F
.45118 .53109 m .45233 .53543 L .44995 .53581 L F
.494 .458 .746 r
.45233 .53543 m .45305 .53733 L .44995 .53581 L F
.76 .695 .789 r
.24051 .54362 m .24263 .54792 L .24426 .54403 L F
0 .145 .67 r
.61258 .41461 m .6137 .41669 L .61246 .41264 L F
.518 .45 .719 r
.44992 .52466 m .44828 .52899 L .44809 .52535 L F
.713 .764 .892 r
.6173 .35826 m .61524 .36293 L .61396 .36087 L F
.6173 .35826 m .61765 .36174 L .61524 .36293 L F
.162 0 .262 r
.23204 .58185 m .2295 .58289 L .2324 .57917 L F
.676 .862 .97 r
.29835 .51299 m .29665 .51417 L .29388 .51287 L F
.764 .621 .701 r
.44174 .48383 m .44294 .48759 L .43897 .48696 L F
.636 .55 .74 r
.4456 .48684 m .44294 .48759 L .44174 .48383 L F
.427 .261 .551 r
.69047 .37204 m .69047 .37443 L .68808 .37548 L F
.537 .417 .664 r
.69047 .37443 m .68789 .37884 L .68808 .37548 L F
.674 .702 .868 r
.55249 .41038 m .55315 .41391 L .54901 .4131 L F
.621 .612 .82 r
.55447 .40927 m .55315 .41391 L .55249 .41038 L F
.55447 .40927 m .55583 .41309 L .55315 .41391 L F
.754 .28 0 r
.60972 .43215 m .60939 .43133 L .60673 .42832 L F
.853 .851 .84 r
.66925 .32371 m .66609 .32375 L .66865 .32055 L F
.85 .85 .842 r
.67182 .32069 m .66925 .32371 L .66865 .32055 L F
0 0 0 r
.35486 .59154 m .35585 .59042 L .35786 .58901 L F
.576 .433 .65 r
.32333 .62338 m .32506 .62059 L .32166 .62121 L F
.32333 .62338 m .32577 .62403 L .32506 .62059 L F
.29 .277 .671 r
.27051 .53418 m .271 .53843 L .27211 .53626 L F
.705 .985 .835 r
.29052 .62783 m .29117 .6263 L .29223 .62736 L F
.29052 .62783 m .28936 .62786 L .29117 .6263 L F
.333 .231 .587 r
.32683 .56674 m .32821 .56324 L .32654 .56388 L F
.816 .843 .87 r
.66732 .34576 m .67154 .34444 L .67 .34268 L F
.766 .7 .788 r
.67154 .34444 m .67238 .33973 L .67 .34268 L F
.67154 .34444 m .67346 .34281 L .67238 .33973 L F
.812 .494 0 r
.40254 .56993 m .40316 .57226 L .40358 .57274 L F
.983 .889 .543 r
.40316 .57226 m .40329 .576 L .40358 .57274 L F
.058 0 0 r
.395 .64414 m .39416 .64394 L .3925 .64496 L F
.395 .64414 m .39633 .6439 L .39416 .64394 L F
.42 .39 .72 r
.44571 .5054 m .44304 .50345 L .44568 .50286 L F
.44571 .5054 m .44371 .50587 L .44304 .50345 L F
.722 .583 .698 r
.34543 .65655 m .34697 .65943 L .34671 .65701 L F
.543 .785 .988 r
.34671 .65701 m .34982 .65674 L .34805 .65544 L F
.625 .512 .704 r
.34671 .65701 m .34982 .65674 L .34805 .65544 L F
.34671 .65701 m .34697 .65943 L .34982 .65674 L F
.477 .073 .194 r
.57746 .46535 m .57999 .46658 L .57734 .46664 L F
.469 .094 .244 r
.58153 .46393 m .57999 .46658 L .57746 .46535 L F
.699 .57 .706 r
.42676 .55301 m .42336 .55087 L .42631 .54991 L F
.42676 .55301 m .42426 .55457 L .42336 .55087 L F
.909 .972 .672 r
.3288 .61659 m .32866 .619 L .32686 .62027 L F
.508 .461 .739 r
.33158 .62128 m .32866 .619 L .33006 .61533 L F
.863 .516 .394 r
.34802 .56732 m .34906 .56945 L .35008 .56754 L F
.603 .202 .256 r
.35008 .56754 m .35241 .56884 L .35337 .56684 L F
.35008 .56754 m .34906 .56945 L .35241 .56884 L F
.748 .674 .779 r
.25063 .55412 m .2483 .55452 L .2505 .55135 L F
.579 .499 .729 r
.44769 .51178 m .44827 .51576 L .44592 .51658 L F
.461 .496 .808 r
.44907 .51803 m .44592 .51658 L .44827 .51576 L F
.834 .765 .786 r
.69447 .32726 m .69649 .32783 L .69458 .32718 L F
.771 .619 .691 r
.69458 .32718 m .6973 .32992 L .69461 .3287 L F
.685 .618 .775 r
.69916 .3289 m .6973 .32992 L .69458 .32718 L F
.69916 .3289 m .69458 .32718 L .6988 .32775 L F
.272 .623 .96 r
.69765 .32631 m .69458 .32718 L .69494 .3267 L F
.69765 .32631 m .6988 .32775 L .69458 .32718 L F
0 0 .175 r
.69458 .32718 m .69461 .3287 L .6949 .32693 L F
.69458 .32718 m .6949 .32693 L .69494 .3267 L F
.834 .765 .786 r
.69339 .32696 m .69447 .32726 L .69458 .32718 L F
.781 .832 .891 r
.33772 .52319 m .33349 .52343 L .33585 .5215 L F
.682 .814 .946 r
.33999 .52192 m .33772 .52319 L .33585 .5215 L F
.367 .107 .382 r
.63707 .40106 m .63411 .4043 L .63716 .40388 L F
.318 .167 .513 r
.63707 .40106 m .6391 .40308 L .63902 .39986 L F
.63707 .40106 m .63716 .40388 L .6391 .40308 L F
.177 .274 .727 r
.20761 .58307 m .20993 .58521 L .20882 .58149 L F
.844 .939 .887 r
.35174 .71652 m .35341 .7173 L .35483 .71529 L F
.46 .15 .352 r
.5904 .46144 m .58664 .46441 L .58676 .46165 L F
.868 .915 .859 r
.3859 .62439 m .38712 .62286 L .38723 .62392 L F
.38712 .62286 m .38788 .62192 L .38723 .62392 L F
0 .105 .66 r
.3876 .6261 m .3859 .62439 L .38723 .62392 L F
.904 .576 .092 r
.38741 .62563 m .38723 .62392 L .38626 .62282 L F
.3876 .6261 m .38723 .62392 L .38741 .62563 L F
.865 .601 .537 r
.38723 .62392 m .38788 .62192 L .38436 .62055 L F
.823 .836 .858 r
.6354 .34991 m .63569 .35285 L .63248 .35259 L F
.777 .805 .875 r
.63889 .34984 m .63569 .35285 L .6354 .34991 L F
0 0 .576 r
.33999 .52192 m .34194 .52489 L .34165 .52608 L F
.648 .478 .64 r
.34165 .52608 m .34217 .52892 L .34266 .52884 L F
.904 .595 .451 r
.34165 .52608 m .34266 .52884 L .3397 .52768 L F
0 .033 .573 r
.34206 .52394 m .34194 .52489 L .34144 .52294 L F
.504 .87 .983 r
.34179 .52604 m .34194 .52489 L .34429 .52536 L F
.66 .376 .479 r
.34194 .52489 m .34481 .52802 L .34635 .52455 L F
0 .033 .573 r
.34335 .52602 m .34194 .52489 L .34206 .52394 L F
.504 .87 .983 r
.34165 .52608 m .34194 .52489 L .34179 .52604 L F
.748 .96 .666 r
.34194 .52489 m .3397 .52768 L .34165 .52608 L F
.229 0 0 r
.28017 .55702 m .28292 .55671 L .2864 .55524 L F
0 0 0 r
.2864 .55524 m .28292 .55671 L .28688 .55525 L F
.477 .468 .769 r
.23299 .55067 m .23538 .5539 L .23331 .55463 L F
.899 .74 .676 r
.35553 .51852 m .35729 .52268 L .35729 .51965 L F
.35553 .51852 m .35729 .52268 L .35729 .51965 L F
.583 .831 .462 r
.35718 .52248 m .35583 .52428 L .35729 .52268 L F
.772 .702 .786 r
.67346 .34281 m .6759 .34004 L .67238 .33973 L F
.254 .042 .386 r
.27523 .52875 m .2767 .53034 L .27902 .5289 L F
.413 .78 .994 r
.2767 .53034 m .27848 .53134 L .27902 .5289 L F
.992 .855 .6 r
.34153 .65779 m .34317 .65743 L .34203 .65563 L F
.39 .846 .784 r
.34153 .65779 m .34543 .65655 L .34317 .65743 L F
.773 .997 .823 r
.34153 .65779 m .34317 .65743 L .34033 .65983 L F
.883 .67 .61 r
.34341 .65978 m .34543 .65655 L .34153 .65779 L F
.813 .794 .834 r
.65258 .41608 m .65471 .41724 L .65525 .4162 L F
.907 .704 .618 r
.65258 .41608 m .65414 .41994 L .65471 .41724 L F
.466 .244 .491 r
.56401 .43322 m .56648 .43484 L .56649 .43243 L F
.56401 .43322 m .56648 .43484 L .56649 .43243 L F
.527 .001 0 r
.33032 .69643 m .33074 .69839 L .3288 .69706 L F
.597 .922 .97 r
.32768 .69658 m .33155 .69593 L .33032 .69643 L F
.099 .655 .781 r
.32768 .69658 m .33032 .69643 L .3278 .69637 L F
.527 .001 0 r
.33032 .69643 m .3288 .69706 L .3278 .69637 L F
.597 .922 .97 r
.33155 .69593 m .33225 .69581 L .33032 .69643 L F
.496 .899 .783 r
.33032 .69643 m .33225 .69581 L .33446 .69454 L F
.715 .359 .374 r
.54983 .46142 m .55393 .4618 L .55243 .46406 L F
.719 .364 .377 r
.55393 .4618 m .55634 .46435 L .55243 .46406 L F
.423 0 0 r
.24659 .6152 m .24885 .61611 L .2511 .61503 L F
0 0 0 r
.2511 .61503 m .24885 .61611 L .25149 .61542 L F
0 0 .25 r
.21028 .56389 m .21087 .56548 L .21132 .56299 L F
.21028 .56389 m .20995 .56658 L .21087 .56548 L F
.501 .552 .84 r
.72054 .33324 m .72286 .33772 L .72052 .33684 L F
.656 .35 .441 r
.72052 .33684 m .72286 .33772 L .72209 .34029 L F
.469 .456 .761 r
.31981 .55329 m .31736 .55489 L .31658 .55138 L F
.39 .231 .541 r
.31926 .5552 m .31736 .55489 L .31981 .55329 L F
.31926 .5552 m .31777 .55643 L .31736 .55489 L F
.219 .477 .888 r
.20899 .59431 m .20946 .59598 L .21046 .59437 L F
.523 .574 .848 r
.21004 .5983 m .21046 .59437 L .20946 .59598 L F
0 0 .068 r
.34223 .70096 m .34087 .7039 L .34265 .70351 L F
.433 .491 .819 r
.34087 .7039 m .34423 .70693 L .34265 .70351 L F
0 .085 .635 r
.388 .52689 m .38831 .52904 L .38701 .52508 L F
0 .006 .539 r
.38924 .52975 m .38831 .52904 L .388 .52689 L F
.38924 .52975 m .39027 .53114 L .38831 .52904 L F
0 .227 .742 r
.62901 .41982 m .6284 .42054 L .62804 .41936 L F
0 0 0 r
.62743 .42244 m .6284 .42054 L .62901 .41982 L F
.73 .919 .563 r
.62338 .43505 m .62237 .43694 L .62462 .43379 L F
0 0 0 r
.62548 .43387 m .62462 .43379 L .625 .43122 L F
.62548 .43387 m .62338 .43505 L .62462 .43379 L F
.622 .559 .762 r
.57533 .42627 m .57335 .42796 L .5715 .42279 L F
.493 0 0 r
.57171 .42864 m .57335 .42796 L .57562 .42897 L F
.258 0 .009 r
.34679 .56737 m .34312 .56968 L .34309 .56763 L F
.011 0 0 r
.33988 .6947 m .34092 .6939 L .3383 .6947 L F
0 0 0 r
.4335 .55176 m .43206 .55333 L .43101 .55446 L F
.719 .774 .28 r
.43054 .5554 m .43101 .55446 L .43206 .55333 L F
.43054 .5554 m .43006 .5571 L .43101 .55446 L F
.998 .84 .547 r
.40374 .58841 m .40418 .59195 L .40459 .58937 L F
.761 .96 .934 r
.63433 .40777 m .63772 .40682 L .63718 .40658 L F
.906 .949 .599 r
.24163 .52741 m .2419 .52497 L .24462 .52667 L F
0 0 0 r
.23936 .52926 m .24013 .52838 L .24068 .52799 L F
.906 .949 .599 r
.24164 .52729 m .24068 .52799 L .2419 .52497 L F
.125 0 .424 r
.2419 .52497 m .24068 .52799 L .24213 .52609 L F
0 0 0 r
.24013 .52838 m .24213 .52609 L .24068 .52799 L F
.906 .949 .599 r
.24163 .52741 m .24068 .52799 L .24164 .52729 L F
.819 .856 .876 r
.64806 .34382 m .64349 .34539 L .64683 .34242 L F
.843 .895 .876 r
.65075 .34098 m .64806 .34382 L .64683 .34242 L F
.49 .104 .234 r
.58404 .46393 m .57999 .46658 L .58153 .46393 L F
.382 .546 .893 r
.38246 .56144 m .38346 .55921 L .38068 .56237 L F
.38246 .56144 m .38369 .56079 L .38346 .55921 L F
.444 .391 .704 r
.38246 .56144 m .38514 .56327 L .38369 .56079 L F
.38246 .56144 m .38325 .56435 L .38514 .56327 L F
.461 .267 .53 r
.44799 .49653 m .44795 .49948 L .4455 .50015 L F
.499 .35 .61 r
.44795 .49948 m .44568 .50286 L .4455 .50015 L F
0 0 .185 r
.36204 .60543 m .36271 .60699 L .36218 .60434 L F
.792 .464 .433 r
.36218 .60434 m .36271 .60699 L .36211 .60684 L F
0 0 .008 r
.36229 .60089 m .36204 .60543 L .36218 .60434 L F
0 0 .185 r
.36204 .60543 m .36198 .60681 L .36271 .60699 L F
.36198 .60681 m .36189 .60842 L .36271 .60699 L F
.132 .413 .859 r
.36403 .6085 m .36501 .60719 L .36271 .60699 L F
.951 .886 .488 r
.36324 .60711 m .36271 .60699 L .36501 .60719 L F
.343 0 0 r
.36271 .60699 m .35863 .60883 L .35886 .60607 L F
.36213 .60725 m .36153 .60855 L .35863 .60883 L F
.36271 .60699 m .36252 .60724 L .36213 .60725 L F
.36252 .60724 m .36153 .60855 L .36213 .60725 L F
.951 .886 .488 r
.36156 .60703 m .36153 .60855 L .36263 .60708 L F
.36156 .60703 m .36271 .60699 L .36324 .60711 L F
.766 .63 .71 r
.36736 .60409 m .36815 .60815 L .36403 .6085 L F
0 .078 .639 r
.36483 .60719 m .36607 .60697 L .36156 .60703 L F
.36501 .60719 m .36508 .60718 L .36483 .60719 L F
.36508 .60718 m .36607 .60697 L .36483 .60719 L F
.792 .464 .433 r
.36218 .60434 m .36211 .60684 L .35886 .60607 L F
0 0 .008 r
.3623 .60058 m .36229 .60089 L .36218 .60434 L F
.789 .792 .855 r
.64199 .3651 m .6429 .3685 L .64541 .36554 L F
.57 .086 .065 r
.42953 .56712 m .43201 .56864 L .43425 .56708 L F
0 0 .167 r
.43586 .57455 m .4355 .57643 L .43537 .57324 L F
.75 .495 .546 r
.43167 .57425 m .43586 .57455 L .43451 .56949 L F
.202 0 .196 r
.43327 .57232 m .43167 .57425 L .43451 .56949 L F
.829 .539 .498 r
.43201 .56864 m .43327 .57232 L .43451 .56949 L F
.547 .374 .597 r
.43451 .56949 m .43586 .57455 L .43879 .57358 L F
.43786 .57259 m .43879 .57358 L .43889 .57354 L F
.43451 .56949 m .43879 .57358 L .43786 .57259 L F
.594 .025 0 r
.43451 .56949 m .43495 .56986 L .43201 .56864 L F
.758 .335 .246 r
.43201 .56864 m .43495 .56986 L .43483 .56939 L F
.43328 .56776 m .43483 .56939 L .43425 .56708 L F
.43201 .56864 m .43483 .56939 L .43328 .56776 L F
.861 .411 .055 r
.71264 .31336 m .7128 .31228 L .71077 .31085 L F
.71264 .31336 m .71434 .31455 L .7128 .31228 L F
.527 .555 .827 r
.42956 .55139 m .42676 .55301 L .42631 .54991 L F
.698 .304 0 r
.38443 .5096 m .38474 .51069 L .38312 .50798 L F
.38443 .5096 m .3858 .5125 L .38474 .51069 L F
.498 .903 .912 r
.36054 .59044 m .35996 .59127 L .36117 .59016 L F
.754 .669 .767 r
.35786 .58901 m .35928 .59226 L .35996 .59127 L F
.578 .261 .395 r
.35786 .58901 m .35996 .59127 L .35752 .59116 L F
.498 .903 .912 r
.35889 .59116 m .35996 .59127 L .36054 .59044 L F
.754 .669 .767 r
.35928 .59226 m .35945 .59266 L .35996 .59127 L F
.664 .685 .86 r
.35941 .5954 m .35996 .59127 L .35945 .59266 L F
.99 .74 .371 r
.59457 .40988 m .59465 .40737 L .59378 .40689 L F
.341 .079 .362 r
.36056 .69166 m .35808 .69472 L .36061 .69425 L F
.683 .24 .192 r
.35671 .69112 m .35953 .69339 L .35808 .69472 L F
.35953 .69339 m .36061 .69425 L .35835 .69467 L F
.35953 .69339 m .35835 .69467 L .35808 .69472 L F
.35671 .69112 m .3596 .69425 L .36061 .69425 L F
0 0 0 r
.3596 .69425 m .36018 .69269 L .36185 .69095 L F
.36018 .69269 m .36056 .69166 L .36175 .69101 L F
.36018 .69269 m .36175 .69101 L .36185 .69095 L F
.683 .24 .192 r
.35671 .69112 m .36056 .69166 L .3596 .69425 L F
0 0 .466 r
.36185 .69095 m .36056 .69166 L .36111 .68883 L F
.539 .312 .519 r
.63718 .40658 m .63411 .4043 L .63433 .40777 L F
.63718 .40658 m .63716 .40388 L .63411 .4043 L F
0 0 0 r
.292 .64842 m .2927 .64896 L .29042 .64926 L F
.292 .64842 m .29325 .64641 L .2927 .64896 L F
0 .091 .558 r
.2927 .64896 m .292 .64842 L .29042 .64926 L F
.2927 .64896 m .29451 .65045 L .292 .64842 L F
.962 .943 .67 r
.3217 .66826 m .3228 .66634 L .32074 .66828 L F
0 0 0 r
.34508 .51277 m .34356 .51297 L .34049 .51315 L F
.899 .513 .284 r
.38812 .5142 m .3858 .5125 L .38755 .51371 L F
.631 .944 .952 r
.30344 .63668 m .30261 .63737 L .30295 .63588 L F
0 0 0 r
.30295 .63588 m .30261 .63737 L .30229 .64009 L F
.164 0 .33 r
.31924 .65276 m .31682 .6572 L .31973 .65596 L F
.801 .635 .676 r
.31973 .65596 m .32098 .65145 L .31924 .65276 L F
.781 .691 .764 r
.35922 .66918 m .36212 .66606 L .35983 .66698 L F
.763 .883 .932 r
.26212 .54814 m .26291 .54986 L .26589 .54769 L F
.855 .966 .872 r
.64589 .43457 m .64703 .43518 L .64974 .43243 L F
.596 .303 .442 r
.35703 .54358 m .35404 .5413 L .35626 .5395 L F
.35703 .54358 m .3531 .546 L .35404 .5413 L F
.931 .568 .155 r
.39163 .53487 m .39221 .53723 L .39352 .5384 L F
.579 .07 0 r
.3942 .53943 m .39352 .5384 L .39221 .53723 L F
.3942 .53943 m .39538 .54049 L .39352 .5384 L F
.656 .659 .841 r
.3096 .50554 m .31077 .50732 L .31374 .50641 L F
.796 .74 .8 r
.23742 .59863 m .23394 .59902 L .2356 .59717 L F
.416 .538 .872 r
.23701 .60093 m .23394 .59902 L .23742 .59863 L F
.525 .7 .949 r
.23905 .59747 m .23742 .59863 L .2356 .59717 L F
.23905 .59747 m .23866 .59796 L .23971 .59823 L F
.388 .114 .371 r
.23912 .59778 m .23866 .59796 L .23905 .59747 L F
.23895 .59759 m .23892 .59756 L .23905 .59747 L F
.23866 .59796 m .238 .59822 L .23892 .59756 L F
.23866 .59796 m .23892 .59756 L .23895 .59759 L F
.525 .7 .949 r
.23905 .59747 m .2356 .59717 L .23866 .59796 L F
.421 .683 .972 r
.23912 .59778 m .23971 .59823 L .23866 .59796 L F
0 0 .199 r
.23971 .59823 m .23948 .59948 L .23912 .59778 L F
.23971 .59823 m .23912 .59778 L .23905 .59747 L F
.421 .683 .972 r
.23917 .59776 m .23971 .59823 L .23912 .59778 L F
0 .109 .586 r
.23818 .59677 m .23844 .59711 L .23566 .59471 L F
.23946 .59799 m .23917 .59776 L .23566 .59471 L F
.421 .683 .972 r
.23566 .59471 m .23917 .59776 L .2356 .59717 L F
.729 .625 .742 r
.2356 .59717 m .23218 .59504 L .23513 .5941 L F
.421 .683 .972 r
.23566 .59471 m .2356 .59717 L .23513 .5941 L F
.344 0 0 r
.23479 .59595 m .23698 .59687 L .23818 .59677 L F
.194 .444 .87 r
.23789 .59637 m .23818 .59677 L .23698 .59687 L F
.23992 .59527 m .23818 .59677 L .23789 .59637 L F
0 .109 .586 r
.23818 .59677 m .23946 .59799 L .23844 .59711 L F
.23946 .59799 m .23971 .59823 L .23917 .59776 L F
.421 .683 .972 r
.23917 .59776 m .23866 .59796 L .2356 .59717 L F
.388 .114 .371 r
.23948 .59948 m .23742 .59863 L .238 .59822 L F
.23948 .59948 m .238 .59822 L .23912 .59778 L F
.23948 .59948 m .23701 .60093 L .23742 .59863 L F
.065 .612 .837 r
.34085 .49639 m .3433 .49657 L .34491 .49701 L F
.24 .694 .953 r
.3433 .49657 m .34711 .4974 L .34491 .49701 L F
.636 .907 .983 r
.62216 .38243 m .62612 .38207 L .62528 .38136 L F
.718 .967 .937 r
.62528 .38136 m .62612 .38207 L .62732 .37987 L F
.62528 .38136 m .62612 .38207 L .62732 .37987 L F
.815 .659 .689 r
.26714 .52064 m .26269 .51976 L .26493 .51925 L F
.26714 .52064 m .26578 .52494 L .26269 .51976 L F
.104 .364 .828 r
.26765 .51877 m .26714 .52064 L .26493 .51925 L F
.26765 .51877 m .26899 .52128 L .26714 .52064 L F
0 .255 .746 r
.4355 .57643 m .43839 .57889 L .43893 .57668 L F
.133 .125 .582 r
.43839 .57889 m .43953 .57523 L .43893 .57668 L F
.531 .504 .771 r
.38857 .605 m .39022 .60208 L .38786 .60254 L F
.666 .181 .09 r
.4182 .49931 m .4207 .50151 L .42223 .49997 L F
.531 .256 .443 r
.4182 .49931 m .4207 .50151 L .42223 .49997 L F
.806 .845 .88 r
.71596 .33507 m .71168 .3361 L .71439 .33291 L F
.745 .743 .85 r
.71842 .3333 m .71596 .33507 L .71439 .33291 L F
.499 .329 .581 r
.32112 .6048 m .31865 .60838 L .31875 .6054 L F
.633 .605 .804 r
.44799 .49653 m .44413 .49395 L .44677 .49324 L F
.497 .295 .536 r
.45038 .49603 m .44795 .49948 L .44799 .49653 L F
.563 .605 .853 r
.25378 .62809 m .25783 .63096 L .25596 .62753 L F
.757 .69 .787 r
.25596 .62753 m .25783 .63096 L .25982 .62959 L F
.865 .664 .628 r
.37216 .59268 m .37084 .58605 L .36826 .59258 L F
.614 .258 .343 r
.38657 .54847 m .38609 .55054 L .38908 .55 L F
0 .312 .784 r
.38657 .54847 m .38602 .54723 L .38441 .54745 L F
.38657 .54847 m .38908 .55 L .38602 .54723 L F
.29 .066 .391 r
.66647 .37649 m .66645 .37649 L .66465 .37816 L F
.66645 .37649 m .66444 .37507 L .66461 .3776 L F
.66645 .37649 m .66461 .3776 L .66465 .37816 L F
.536 .925 .849 r
.66652 .37645 m .66651 .37646 L .6665 .37646 L F
.813 .999 .844 r
.6665 .37646 m .66651 .37646 L .66646 .37651 L F
.29 .066 .391 r
.66704 .37597 m .66698 .37595 L .66647 .37649 L F
.66698 .37595 m .66444 .37507 L .66647 .37649 L F
.536 .925 .849 r
.66834 .37489 m .66652 .37645 L .6644 .37683 L F
.66652 .37645 m .6665 .37646 L .6644 .37683 L F
.29 .066 .391 r
.66704 .37597 m .66647 .37649 L .66651 .37646 L F
.66647 .37649 m .66465 .37816 L .66651 .37646 L F
.813 .999 .844 r
.6644 .37683 m .6665 .37646 L .66634 .37661 L F
.114 0 .16 r
.66465 .37816 m .66185 .38121 L .66335 .37943 L F
0 0 0 r
.66651 .37646 m .66465 .37816 L .66335 .37943 L F
.813 .999 .844 r
.66341 .37927 m .66634 .37661 L .66335 .37943 L F
.6644 .37683 m .66634 .37661 L .66341 .37927 L F
.6665 .37646 m .66646 .37651 L .66335 .37943 L F
0 0 .568 r
.24368 .55385 m .24543 .5564 L .24499 .55764 L F
.398 .134 .393 r
.24499 .55764 m .24683 .55734 L .2483 .55452 L F
.721 .858 .435 r
.24854 .55927 m .24698 .55912 L .24964 .55906 L F
.232 .177 .587 r
.24698 .55912 m .24533 .56114 L .24512 .55896 L F
.618 .888 .569 r
.24454 .56186 m .24533 .56114 L .24698 .55912 L F
0 0 0 r
.24543 .56086 m .24548 .56148 L .24454 .56186 L F
.24698 .55912 m .24626 .56025 L .24543 .56086 L F
.24626 .56025 m .24548 .56148 L .24543 .56086 L F
.554 .25 .406 r
.24683 .55734 m .24964 .55906 L .24698 .55912 L F
.565 .238 .374 r
.25044 .55697 m .24964 .55906 L .24683 .55734 L F
.009 0 .113 r
.25122 .55775 m .24964 .55906 L .25044 .55697 L F
.721 .858 .435 r
.24632 .55967 m .24548 .56148 L .24698 .55912 L F
.24632 .55967 m .24698 .55912 L .24854 .55927 L F
.232 .177 .587 r
.24698 .55912 m .24512 .55896 L .24499 .55764 L F
0 .184 .717 r
.24543 .5564 m .24698 .55912 L .24499 .55764 L F
.502 .829 .999 r
.24683 .55734 m .24543 .5564 L .24837 .5559 L F
.763 .524 .572 r
.24478 .55803 m .24776 .55937 L .24837 .5559 L F
0 0 0 r
.24837 .5559 m .24776 .55937 L .24857 .55664 L F
.271 .299 .707 r
.24478 .55803 m .24632 .55967 L .24776 .55937 L F
.464 .89 .852 r
.24776 .55937 m .25039 .55817 L .24857 .55664 L F
.24776 .55937 m .24632 .55967 L .25039 .55817 L F
.473 .895 .859 r
.25039 .55817 m .2478 .55913 L .24964 .55906 L F
.2478 .55913 m .24632 .55967 L .2473 .55949 L F
.2478 .55913 m .2473 .55949 L .24964 .55906 L F
.494 .316 .567 r
.20503 .60224 m .2074 .60411 L .20749 .60176 L F
.20503 .60224 m .20493 .60506 L .2074 .60411 L F
.251 .111 .488 r
.35337 .56684 m .35542 .56598 L .35535 .5635 L F
.363 .128 .418 r
.35241 .56884 m .35542 .56598 L .35337 .56684 L F
0 0 .118 r
.27051 .53418 m .27145 .534 L .27204 .53155 L F
.29 .277 .671 r
.27051 .53418 m .27211 .53626 L .27145 .534 L F
.918 .969 .674 r
.40084 .60423 m .40199 .60257 L .40188 .60053 L F
.713 .49 .586 r
.36768 .62134 m .37204 .62037 L .37147 .61818 L F
.757 .69 .787 r
.25596 .62753 m .25982 .62959 L .25983 .62799 L F
.308 .574 .934 r
.25982 .62959 m .26074 .62733 L .25983 .62799 L F
.25982 .62959 m .26284 .62977 L .26074 .62733 L F
0 0 0 r
.29835 .61816 m .30063 .61474 L .29621 .6146 L F
.992 .741 .399 r
.29835 .61816 m .29683 .61976 L .29919 .61721 L F
.816 .989 .731 r
.29919 .61721 m .29683 .61976 L .29709 .61837 L F
.49 0 0 r
.29709 .61837 m .29862 .61839 L .29919 .61721 L F
.29862 .61839 m .30106 .6184 L .29919 .61721 L F
0 0 0 r
.29971 .61612 m .29919 .61721 L .30063 .61474 L F
.29835 .61816 m .29919 .61721 L .29971 .61612 L F
.992 .741 .399 r
.29835 .61816 m .29835 .62088 L .29683 .61976 L F
.86 .936 .561 r
.30502 .51049 m .30697 .50849 L .30513 .50869 L F
.30502 .51049 m .30487 .51235 L .30697 .50849 L F
0 0 0 r
.30496 .51155 m .30502 .51049 L .3058 .50872 L F
.30326 .5146 m .30201 .51564 L .30487 .51235 L F
.857 .921 .528 r
.30326 .5146 m .30487 .51235 L .30502 .51049 L F
0 0 0 r
.30459 .5128 m .30502 .51049 L .30496 .51155 L F
.86 .936 .561 r
.30502 .51049 m .30513 .50869 L .30353 .50887 L F
.601 .623 .845 r
.44174 .48383 m .43756 .48059 L .44023 .47955 L F
.624 .597 .802 r
.44423 .4811 m .44174 .48383 L .44023 .47955 L F
.633 .612 .811 r
.44423 .4811 m .4456 .48442 L .44174 .48383 L F
.636 .55 .74 r
.4456 .48684 m .44174 .48383 L .4456 .48442 L F
.621 .313 .427 r
.34489 .60193 m .34453 .60509 L .341 .60464 L F
.636 .585 .78 r
.34632 .59823 m .34489 .60193 L .34367 .59881 L F
.34632 .59823 m .34762 .60196 L .34489 .60193 L F
.145 0 .305 r
.34634 .60364 m .34489 .60193 L .34762 .60196 L F
.34634 .60364 m .34453 .60509 L .34489 .60193 L F
.94 .625 .412 r
.29917 .64613 m .30125 .64711 L .29935 .64871 L F
.252 0 0 r
.30125 .64711 m .30276 .64821 L .29935 .64871 L F
.30125 .64711 m .30369 .64672 L .30276 .64821 L F
.597 .369 .542 r
.31644 .61177 m .31643 .61446 L .31376 .61471 L F
.548 .318 .518 r
.32029 .61024 m .31643 .61446 L .31644 .61177 L F
.932 .97 .73 r
.6462 .41373 m .64437 .41725 L .64382 .41511 L F
.892 .73 .222 r
.64382 .41511 m .64437 .41725 L .64414 .41936 L F
.969 .665 .385 r
.3214 .53649 m .3229 .53533 L .31926 .53398 L F
.901 .941 .826 r
.3312 .52491 m .3317 .52098 L .33349 .52343 L F
.3312 .52491 m .32932 .52396 L .3317 .52098 L F
.664 .234 .217 r
.33349 .52343 m .3312 .52491 L .3311 .52665 L F
.33349 .52343 m .32932 .52396 L .3312 .52491 L F
.782 .603 .658 r
.58728 .38477 m .59029 .38861 L .58755 .38724 L F
.72 .187 0 r
.58755 .38724 m .59029 .38861 L .58969 .38941 L F
.871 .44 .031 r
.59029 .38861 m .59116 .39061 L .58969 .38941 L F
0 0 .438 r
.4054 .53441 m .40575 .53831 L .4061 .53685 L F
.84 .485 0 r
.40775 .54066 m .4061 .53685 L .40575 .53831 L F
.799 .663 .713 r
.53645 .4458 m .53825 .44895 L .53617 .44875 L F
.788 .493 .49 r
.53617 .44875 m .53825 .44895 L .5363 .45084 L F
.729 .501 .581 r
.53825 .44895 m .53828 .45143 L .5363 .45084 L F
.454 .199 .438 r
.37972 .60872 m .37907 .61128 L .37662 .61181 L F
.65 .969 .854 r
.37972 .60872 m .37812 .60884 L .38068 .60729 L F
.319 .079 .383 r
.38075 .61087 m .37972 .60872 L .38068 .60729 L F
.38075 .61087 m .37907 .61128 L .37972 .60872 L F
0 0 .261 r
.69682 .34341 m .69733 .34241 L .69757 .33878 L F
0 0 .211 r
.69682 .34341 m .69729 .34472 L .69733 .34241 L F
.69682 .34341 m .69701 .34595 L .69729 .34472 L F
.887 .716 .665 r
.52892 .42309 m .53042 .42559 L .52848 .42573 L F
.945 .64 .429 r
.53042 .42559 m .52928 .42793 L .52848 .42573 L F
.53042 .42559 m .53167 .42933 L .52928 .42793 L F
.518 .837 .533 r
.66521 .40192 m .66646 .40079 L .66818 .39905 L F
.983 .889 .543 r
.40316 .57226 m .40208 .5754 L .40329 .576 L F
.917 .6 .125 r
.40276 .57776 m .40329 .576 L .40208 .5754 L F
.40276 .57776 m .40367 .57893 L .40329 .576 L F
.707 .644 .784 r
.58111 .41775 m .57707 .41687 L .57971 .41648 L F
.962 .651 .247 r
.57954 .41316 m .58111 .41775 L .5802 .41438 L F
.966 .855 .68 r
.5802 .41438 m .58111 .41775 L .57971 .41648 L F
.88 .99 .737 r
.70155 .35413 m .70098 .35684 L .70312 .35349 L F
.879 .971 .658 r
.69979 .3584 m .70098 .35684 L .70155 .35413 L F
.77 .469 .478 r
.53828 .45143 m .54184 .45181 L .54035 .4542 L F
.777 .556 .6 r
.54441 .45193 m .54035 .4542 L .54184 .45181 L F
.521 .337 .572 r
.63336 .44613 m .63558 .44462 L .63574 .4426 L F
.572 .649 .888 r
.63574 .4426 m .63725 .4403 L .63434 .43828 L F
.63574 .4426 m .63869 .44212 L .63725 .4403 L F
.531 .345 .574 r
.63558 .44462 m .63869 .44212 L .63574 .4426 L F
.802 .64 .681 r
.54837 .45503 m .55013 .4587 L .54805 .45758 L F
.823 .644 .661 r
.55013 .4587 m .54612 .46076 L .54805 .45758 L F
.55013 .4587 m .54983 .46142 L .54612 .46076 L F
.759 .407 0 r
.70643 .30409 m .7081 .30806 L .70777 .30536 L F
.715 .406 .454 r
.36422 .68135 m .36456 .67905 L .36193 .67905 L F
.672 .274 .284 r
.36685 .68139 m .36456 .67905 L .36422 .68135 L F
.854 .844 .834 r
.67182 .32069 m .66865 .32055 L .67029 .31906 L F
.843 .844 .845 r
.67452 .31751 m .67182 .32069 L .67029 .31906 L F
.909 .503 .139 r
.59514 .39648 m .5961 .39781 L .59469 .39654 L F
.237 .507 .906 r
.5961 .39781 m .60037 .40078 L .59837 .40006 L F
0 .197 .725 r
.59469 .39654 m .59711 .3988 L .59671 .39692 L F
.59469 .39654 m .59671 .39692 L .59381 .39666 L F
.59469 .39654 m .59381 .39666 L .59368 .39664 L F
.909 .503 .139 r
.5939 .39475 m .59514 .39648 L .59469 .39654 L F
0 .005 .505 r
.5961 .39781 m .59837 .40006 L .59711 .3988 L F
.685 .481 .604 r
.59294 .45853 m .59302 .46125 L .5904 .46144 L F
.485 .325 .588 r
.59557 .46044 m .59294 .45853 L .59565 .45816 L F
.59557 .46044 m .59302 .46125 L .59294 .45853 L F
.747 .893 .945 r
.62492 .39193 m .62747 .39035 L .62385 .39056 L F
.778 .687 .764 r
.35548 .66899 m .35922 .66918 L .35983 .66698 L F
.881 .839 .8 r
.35461 .67161 m .35922 .66918 L .35548 .66899 L F
.35461 .67161 m .3566 .6725 L .35922 .66918 L F
.154 0 .092 r
.39485 .6555 m .39806 .65268 L .39598 .65354 L F
.351 0 0 r
.33964 .50346 m .3383 .50318 L .3361 .50231 L F
.961 .644 .372 r
.33964 .50346 m .33937 .50493 L .3383 .50318 L F
0 0 0 r
.34241 .50264 m .3383 .50318 L .33964 .50346 L F
.582 .227 .332 r
.33937 .50493 m .34216 .50525 L .33964 .50346 L F
.498 .275 .506 r
.33964 .50346 m .34216 .50525 L .34241 .50264 L F
.769 .895 .932 r
.41567 .48431 m .41182 .4851 L .41411 .48299 L F
.789 .882 .914 r
.41703 .48349 m .41567 .48431 L .41411 .48299 L F
.533 .547 .815 r
.24373 .53942 m .24496 .5416 L .24712 .5408 L F
.485 .315 .576 r
.28958 .54786 m .29199 .54974 L .29166 .54716 L F
.28958 .54786 m .28956 .55048 L .29199 .54974 L F
.533 .547 .815 r
.24373 .53942 m .24712 .5408 L .24743 .53794 L F
.473 .252 .497 r
.24743 .53794 m .2495 .54024 L .24712 .5408 L F
.473 .253 .498 r
.24992 .53728 m .24712 .5408 L .24743 .53794 L F
.24712 .5408 m .24992 .53728 L .24743 .53794 L F
.424 .844 .683 r
.25067 .5244 m .25165 .52362 L .25364 .52324 L F
.25067 .5244 m .2496 .52487 L .25165 .52362 L F
0 0 .396 r
.32506 .62059 m .32629 .62259 L .32686 .62027 L F
.32506 .62059 m .32577 .62403 L .32629 .62259 L F
.582 .365 .551 r
.30063 .61474 m .30337 .61451 L .30357 .61174 L F
.209 0 .291 r
.30357 .61174 m .30536 .61104 L .30613 .60856 L F
.411 .223 .512 r
.30357 .61174 m .30555 .6138 L .30536 .61104 L F
.30357 .61174 m .30337 .61451 L .30555 .6138 L F
.985 .902 .627 r
.23884 .53983 m .2398 .54151 L .24085 .5383 L F
.605 .59 .81 r
.24274 .53444 m .24373 .53942 L .24085 .5383 L F
0 0 0 r
.24167 .53801 m .24085 .5383 L .24373 .53942 L F
.24167 .53801 m .23884 .53983 L .24085 .5383 L F
.323 .668 .975 r
.25548 .61379 m .25795 .61348 L .2576 .61495 L F
.651 .106 0 r
.2576 .61495 m .25934 .61673 L .26154 .6181 L F
.25934 .61673 m .25974 .61715 L .2604 .61749 L F
.25934 .61673 m .2604 .61749 L .26154 .6181 L F
.266 .715 .958 r
.2551 .61303 m .25795 .61348 L .25548 .61379 L F
.917 .705 .602 r
.2551 .61303 m .25626 .61452 L .25795 .61348 L F
.25626 .61452 m .25758 .61623 L .25768 .61554 L F
.25626 .61452 m .25768 .61554 L .25795 .61348 L F
0 .15 .691 r
.25795 .61348 m .25897 .61557 L .2576 .61495 L F
.25897 .61557 m .25877 .61615 L .2576 .61495 L F
.531 .707 .951 r
.26023 .61413 m .25974 .61715 L .25795 .61348 L F
.572 .923 .956 r
.25758 .61623 m .26023 .61413 L .25795 .61348 L F
.25758 .61623 m .25939 .61416 L .25947 .61415 L F
.25919 .61496 m .25947 .61415 L .26023 .61413 L F
.25758 .61623 m .25947 .61415 L .25919 .61496 L F
0 .15 .691 r
.25897 .61557 m .25974 .61715 L .25877 .61615 L F
.577 .824 .449 r
.68525 .38613 m .68379 .38809 L .6864 .38472 L F
.65 .968 .892 r
.68185 .38811 m .68379 .38809 L .68525 .38613 L F
.482 .163 .349 r
.44567 .59258 m .44514 .59451 L .44242 .59462 L F
.42 .107 .326 r
.44745 .59385 m .44567 .59258 L .44836 .59237 L F
.44745 .59385 m .44514 .59451 L .44567 .59258 L F
.878 .452 .048 r
.39815 .54606 m .39836 .54704 L .39984 .54798 L F
.946 .721 .568 r
.39731 .54932 m .39984 .54798 L .39836 .54704 L F
.39731 .54932 m .39926 .55049 L .39984 .54798 L F
.845 .753 .762 r
.56505 .42332 m .56335 .42697 L .56174 .42597 L F
.976 .837 .434 r
.41593 .58274 m .41467 .58458 L .4153 .58181 L F
.41593 .58274 m .4155 .58581 L .41467 .58458 L F
.051 0 0 r
.27169 .51866 m .27654 .5175 L .27309 .51836 L F
.839 .996 .759 r
.30777 .66567 m .3058 .66838 L .30936 .66875 L F
.13 .658 .871 r
.3058 .66838 m .30936 .66875 L .30763 .66829 L F
.744 .529 .603 r
.31175 .66871 m .30777 .66567 L .30936 .66875 L F
.804 .792 .841 r
.23397 .54353 m .23299 .54792 L .23546 .5473 L F
.23397 .54353 m .23131 .54745 L .23299 .54792 L F
0 0 0 r
.23299 .55067 m .23546 .5473 L .23299 .54792 L F
0 0 .066 r
.6203 .39794 m .62138 .39399 L .6198 .39618 L F
.869 .676 .148 r
.62028 .39913 m .6203 .39794 L .6198 .39618 L F
.986 .714 .352 r
.40326 .58447 m .40447 .58288 L .40361 .58092 L F
.40326 .58447 m .40448 .58581 L .40447 .58288 L F
.567 .426 .648 r
.44655 .49034 m .44677 .49324 L .44413 .49395 L F
.115 .501 .906 r
.46881 .56734 m .47095 .56917 L .47033 .56908 L F
.543 .474 .728 r
.68895 .38172 m .6864 .38472 L .68584 .3826 L F
.68895 .38172 m .68903 .384 L .6864 .38472 L F
0 0 0 r
.68741 .38435 m .6864 .38472 L .68903 .384 L F
.68741 .38435 m .68525 .38613 L .6864 .38472 L F
.265 .606 .954 r
.39234 .51588 m .39255 .51435 L .39089 .5143 L F
.038 .36 .832 r
.39234 .51588 m .39543 .51764 L .39255 .51435 L F
0 .365 .781 r
.2914 .64234 m .29319 .64373 L .29127 .64271 L F
.614 .335 .471 r
.38842 .57022 m .38479 .57075 L .38565 .56969 L F
0 0 0 r
.39472 .50073 m .39686 .49976 L .39839 .49875 L F
.39839 .49875 m .39982 .49867 L .40159 .49697 L F
.782 .806 .873 r
.40161 .49763 m .40046 .49976 L .39956 .49882 L F
0 0 0 r
.39982 .49867 m .39991 .49867 L .40001 .49856 L F
.39982 .49867 m .40001 .49856 L .40159 .49697 L F
.40159 .49697 m .40001 .49856 L .40192 .49705 L F
.782 .806 .873 r
.40161 .49763 m .39956 .49882 L .39792 .4971 L F
0 0 0 r
.40001 .49856 m .39991 .49867 L .40192 .49705 L F
.782 .806 .873 r
.40192 .49705 m .40161 .49763 L .40125 .49758 L F
.40192 .49705 m .40125 .49758 L .39792 .4971 L F
.611 .759 .95 r
.39954 .49879 m .40046 .49976 L .39686 .49976 L F
.601 .766 .958 r
.39686 .49976 m .39991 .49867 L .39988 .49867 L F
.39686 .49976 m .39988 .49867 L .39839 .49875 L F
.611 .759 .95 r
.39937 .49862 m .39954 .49879 L .39686 .49976 L F
.39792 .4971 m .39937 .49862 L .39686 .49976 L F
0 0 0 r
.39389 .50118 m .39686 .49976 L .39472 .50073 L F
.789 .882 .914 r
.41703 .48349 m .41411 .48299 L .41709 .48129 L F
.792 .94 .924 r
.42057 .48036 m .41703 .48349 L .41709 .48129 L F
.454 .851 .975 r
.3825 .67823 m .38147 .6795 L .37985 .67797 L F
.3825 .67823 m .38401 .67885 L .38147 .6795 L F
.3825 .67823 m .38147 .6795 L .37985 .67797 L F
.3825 .67823 m .38401 .67885 L .38147 .6795 L F
.947 .667 .476 r
.31682 .6572 m .31733 .65905 L .31531 .65876 L F
.171 0 0 r
.3177 .65834 m .31682 .6572 L .31531 .65876 L F
.3177 .65834 m .31973 .65596 L .31682 .6572 L F
.996 .822 .466 r
.41633 .59198 m .41578 .58823 L .41647 .5879 L F
.443 .08 .252 r
.34987 .59577 m .34882 .59814 L .34632 .59823 L F
.097 0 .087 r
.35087 .59706 m .34987 .59577 L .35117 .59562 L F
.35087 .59706 m .34882 .59814 L .34987 .59577 L F
.401 .806 .982 r
.371 .53094 m .36732 .53064 L .36889 .53144 L F
.311 .049 .346 r
.36848 .53387 m .371 .53094 L .36889 .53144 L F
.509 .358 .611 r
.68789 .37884 m .68895 .38172 L .68584 .3826 L F
.544 .296 .49 r
.28602 .56372 m .28582 .56678 L .28308 .56695 L F
.509 .268 .484 r
.28838 .56621 m .28582 .56678 L .28602 .56372 L F
.427 .836 .972 r
.35469 .53164 m .35698 .53114 L .3587 .53189 L F
.772 .965 .926 r
.3587 .53189 m .35698 .53114 L .3604 .5295 L F
.493 .216 .422 r
.36112 .53367 m .3587 .53189 L .36175 .53251 L F
.36112 .53367 m .35854 .53421 L .3587 .53189 L F
.552 .838 .502 r
.21301 .56117 m .21132 .56299 L .21435 .55964 L F
0 0 .003 r
.35876 .54472 m .35966 .54349 L .36034 .54075 L F
.681 .285 .289 r
.3579 .54579 m .3531 .546 L .35703 .54358 L F
.081 0 .269 r
.35859 .54489 m .35966 .54349 L .3594 .54384 L F
.35859 .54489 m .3594 .54384 L .35876 .54472 L F
.35859 .54489 m .35873 .54502 L .35966 .54349 L F
.35729 .5466 m .35859 .54489 L .35876 .54472 L F
.35729 .5466 m .35799 .54629 L .35859 .54489 L F
0 0 .22 r
.35805 .54615 m .35966 .54349 L .35703 .54358 L F
.3582 .54654 m .35966 .54349 L .35805 .54615 L F
.3582 .54654 m .35938 .54564 L .35966 .54349 L F
.081 0 .269 r
.35873 .54502 m .35938 .54564 L .35966 .54349 L F
.35799 .54629 m .35938 .54564 L .35859 .54489 L F
.681 .285 .289 r
.35805 .54615 m .35739 .54646 L .3579 .54579 L F
.3582 .54654 m .35796 .54652 L .35805 .54615 L F
.211 .055 .44 r
.35818 .54656 m .35942 .54833 L .35938 .54564 L F
.681 .285 .289 r
.35796 .54652 m .35799 .54629 L .35805 .54615 L F
.211 .055 .44 r
.35789 .54709 m .35942 .54833 L .35799 .54629 L F
0 0 0 r
.35772 .54701 m .35817 .54657 L .35938 .54564 L F
.35817 .54657 m .3582 .54654 L .35938 .54564 L F
.211 .055 .44 r
.35799 .54629 m .35818 .54656 L .35938 .54564 L F
.46 .278 .547 r
.35284 .55054 m .35521 .55011 L .35537 .54714 L F
.378 .162 .454 r
.35521 .55011 m .35729 .5466 L .35537 .54714 L F
.35521 .55011 m .35777 .54954 L .35729 .5466 L F
.211 .055 .44 r
.35752 .54679 m .35777 .54954 L .35942 .54833 L F
.35729 .5466 m .35733 .54685 L .35752 .54679 L F
.35733 .54685 m .35777 .54954 L .35752 .54679 L F
0 0 0 r
.35772 .54701 m .35537 .54789 L .35809 .54659 L F
.35818 .54656 m .35809 .54659 L .3582 .54654 L F
.35772 .54701 m .35809 .54659 L .35818 .54656 L F
.238 0 0 r
.35797 .54654 m .35262 .54809 L .3532 .54659 L F
.3582 .54654 m .358 .5466 L .35797 .54654 L F
.358 .5466 m .35262 .54809 L .35797 .54654 L F
.358 .5466 m .35537 .54789 L .35262 .54809 L F
.3582 .54654 m .35805 .54661 L .358 .5466 L F
.211 .055 .44 r
.35729 .5466 m .35789 .54709 L .35795 .54659 L F
.238 0 0 r
.35805 .54661 m .35537 .54789 L .358 .5466 L F
.211 .055 .44 r
.35777 .54654 m .35795 .54659 L .35796 .54652 L F
.35729 .5466 m .35795 .54659 L .35777 .54654 L F
.35788 .54634 m .35796 .54652 L .35799 .54629 L F
.35729 .5466 m .35796 .54652 L .35788 .54634 L F
.681 .285 .289 r
.35796 .54652 m .35789 .54651 L .35799 .54629 L F
.35789 .54651 m .35739 .54646 L .35805 .54615 L F
.35739 .54646 m .3531 .546 L .3579 .54579 L F
.745 .775 .276 r
.22959 .58558 m .22893 .58799 L .22795 .58707 L F
.22959 .58558 m .2287 .5882 L .22864 .58904 L F
.099 .586 .905 r
.2287 .5882 m .23037 .58925 L .22864 .58904 L F
.714 .682 .818 r
.23037 .58925 m .23018 .59282 L .22864 .58904 L F
.23037 .58925 m .23255 .59246 L .23018 .59282 L F
.505 0 0 r
.23053 .58988 m .23038 .58929 L .2287 .5882 L F
.23038 .58929 m .23037 .58925 L .23025 .58917 L F
.23038 .58929 m .23025 .58917 L .2287 .5882 L F
.745 .775 .276 r
.22893 .58799 m .22864 .58904 L .22797 .58713 L F
.22893 .58799 m .22797 .58713 L .22795 .58707 L F
.901 .951 .825 r
.61561 .38485 m .61298 .38722 L .6131 .38684 L F
.657 .937 .674 r
.39952 .675 m .4004 .67356 L .40279 .67209 L F
.594 .05 0 r
.40292 .67302 m .40279 .67209 L .4004 .67356 L F
.159 0 0 r
.40069 .66537 m .40426 .66321 L .4003 .66269 L F
.40069 .66537 m .40289 .66481 L .40403 .66335 L F
.528 .522 .793 r
.40203 .66092 m .40289 .66481 L .40069 .66537 L F
.533 .551 .819 r
.40393 .66834 m .40289 .66481 L .40069 .66537 L F
.139 0 0 r
.40147 .66664 m .40069 .66537 L .40289 .66481 L F
0 0 .307 r
.40203 .66092 m .40273 .66284 L .40289 .66481 L F
.918 .911 .516 r
.40289 .66481 m .40273 .66284 L .40149 .66659 L F
.40289 .66481 m .40149 .66659 L .40147 .66664 L F
.159 0 0 r
.40403 .66335 m .40289 .66481 L .40426 .66321 L F
.947 .641 .423 r
.40426 .66321 m .40289 .66481 L .40517 .66597 L F
.969 .649 .319 r
.26092 .80353 m .26198 .80525 L .26129 .80637 L F
0 .24 .757 r
.26339 .80538 m .26198 .80525 L .26092 .80353 L F
.009 0 0 r
.26129 .80637 m .26198 .80525 L .26339 .80538 L F
.928 .554 .275 r
.6945 .31479 m .69167 .3116 L .69052 .31413 L F
.825 .571 .556 r
.69052 .31413 m .6937 .31721 L .6945 .31479 L F
.752 .673 .774 r
.36061 .58903 m .36181 .58969 L .35786 .58901 L F
.533 .53 .797 r
.36279 .58519 m .36181 .58969 L .36061 .58903 L F
.36279 .58519 m .36426 .59122 L .36181 .58969 L F
.52 0 0 r
.36426 .59122 m .36459 .59162 L .36181 .58969 L F
.786 .748 .818 r
.54476 .41102 m .54669 .41419 L .54351 .41363 L F
.718 .251 .139 r
.54351 .41363 m .54669 .41419 L .54533 .41538 L F
.762 .802 .886 r
.54722 .41093 m .54669 .41419 L .54476 .41102 L F
.54722 .41093 m .54901 .4131 L .54669 .41419 L F
.618 .615 .826 r
.4063 .49292 m .4069 .49714 L .40955 .49424 L F
.025 .15 .658 r
.40812 .49469 m .4069 .49714 L .4063 .49292 L F
.521 .245 .436 r
.41032 .4982 m .4069 .49714 L .40812 .49469 L F
.41032 .4982 m .40753 .49913 L .4069 .49714 L F
0 0 0 r
.44166 .56594 m .4429 .56395 L .43985 .56718 L F
.44507 .56279 m .4429 .56395 L .44166 .56594 L F
0 0 .354 r
.70265 .33703 m .70458 .33327 L .70355 .33489 L F
0 .19 .708 r
.70419 .33745 m .70265 .33703 L .70355 .33489 L F
.70419 .33745 m .70584 .33963 L .70265 .33703 L F
.806 .323 .05 r
.3623 .60058 m .35905 .59865 L .36325 .59883 L F
.3623 .60058 m .36023 .60045 L .35905 .59865 L F
.922 .671 .54 r
.36218 .60434 m .36023 .60045 L .3623 .60058 L F
.295 .01 .299 r
.45411 .58582 m .45354 .58851 L .45136 .58924 L F
.357 .1 .381 r
.45686 .5828 m .4564 .58571 L .45411 .58582 L F
.251 0 .284 r
.45566 .58752 m .45411 .58582 L .4564 .58571 L F
.45566 .58752 m .45354 .58851 L .45411 .58582 L F
.224 .084 .471 r
.3217 .57638 m .32391 .57539 L .32404 .57269 L F
.244 .073 .44 r
.3215 .57847 m .32391 .57539 L .3217 .57638 L F
.392 .129 .392 r
.45872 .58503 m .45686 .5828 L .4594 .58211 L F
.45872 .58503 m .4564 .58571 L .45686 .5828 L F
.795 .674 .73 r
.37424 .60136 m .37514 .60622 L .37171 .60461 L F
.389 0 0 r
.37171 .60461 m .37514 .60622 L .37439 .60599 L F
.493 .248 .472 r
.37237 .60896 m .37521 .6091 L .37514 .60622 L F
.133 .204 .672 r
.37548 .60291 m .37514 .60622 L .37424 .60136 L F
.37659 .60429 m .37424 .60136 L .37593 .60114 L F
.966 .926 .704 r
.3744 .60058 m .37397 .60235 L .37559 .60135 L F
.37561 .60102 m .37559 .60135 L .37593 .60114 L F
.3744 .60058 m .37559 .60135 L .37561 .60102 L F
.133 .204 .672 r
.37659 .60429 m .37527 .60606 L .37548 .60291 L F
.37527 .60606 m .37514 .60622 L .37548 .60291 L F
.678 .978 .873 r
.37439 .60599 m .37514 .60622 L .37659 .60429 L F
.807 .697 .743 r
.34356 .51297 m .34595 .51842 L .34079 .51728 L F
.34602 .51858 m .34617 .51894 L .34586 .51884 L F
.565 .442 .671 r
.34551 .51921 m .34633 .51805 L .34576 .5186 L F
.34518 .51999 m .34602 .51858 L .34551 .51921 L F
.34602 .51858 m .34633 .51805 L .34551 .51921 L F
.331 .439 .821 r
.34687 .51753 m .34617 .51894 L .34602 .51858 L F
0 0 0 r
.34576 .5186 m .34633 .51805 L .3493 .51511 L F
.331 .439 .821 r
.34687 .51753 m .34602 .51858 L .34356 .51297 L F
.82 .453 .361 r
.34586 .51884 m .34475 .52079 L .34079 .51728 L F
.34617 .51894 m .34546 .51986 L .34586 .51884 L F
.565 .442 .671 r
.34544 .51983 m .34547 .51984 L .34687 .51753 L F
.34489 .52072 m .34608 .52066 L .34544 .51983 L F
.82 .453 .361 r
.34546 .51986 m .34538 .51997 L .34544 .51983 L F
.34546 .51986 m .34544 .51983 L .34586 .51884 L F
.565 .442 .671 r
.34489 .52072 m .34544 .51983 L .34571 .51919 L F
.34544 .51983 m .34687 .51753 L .34571 .51919 L F
0 0 0 r
.34687 .51753 m .34475 .52079 L .34546 .51986 L F
.34687 .51753 m .34546 .51986 L .34617 .51894 L F
.565 .442 .671 r
.34547 .51984 m .34762 .52058 L .34687 .51753 L F
.34608 .52066 m .34762 .52058 L .34544 .51983 L F
.34489 .52072 m .34633 .51805 L .34518 .51999 L F
.82 .453 .361 r
.34538 .51997 m .34475 .52079 L .34586 .51884 L F
.565 .442 .671 r
.34571 .51919 m .34687 .51753 L .34633 .51805 L F
.807 .697 .743 r
.34595 .51842 m .34602 .51858 L .34561 .51876 L F
.34602 .51858 m .34586 .51884 L .34561 .51876 L F
.34595 .51842 m .34561 .51876 L .34079 .51728 L F
0 0 0 r
.34681 .51757 m .34687 .51753 L .34838 .51602 L F
.34633 .51805 m .34838 .51602 L .3493 .51511 L F
.3493 .51511 m .34687 .51753 L .35021 .51541 L F
.708 .615 .75 r
.35021 .51541 m .34687 .51753 L .34647 .51364 L F
0 0 0 r
.34812 .5157 m .34687 .51753 L .34993 .51945 L F
.34812 .5157 m .34696 .51746 L .34687 .51753 L F
.473 .383 .673 r
.34687 .51753 m .34762 .52058 L .34993 .51945 L F
0 0 0 r
.34696 .51746 m .34492 .52057 L .34687 .51753 L F
.34633 .51805 m .34687 .51753 L .34681 .51757 L F
0 0 .307 r
.40246 .6779 m .40143 .68142 L .40155 .67884 L F
.017 0 0 r
.38325 .56435 m .3822 .56599 L .38514 .56327 L F
0 .136 .661 r
.25249 .62377 m .25378 .62809 L .25445 .62627 L F
.539 .8 .993 r
.25445 .62627 m .25378 .62809 L .25596 .62753 L F
.526 .442 .704 r
.37416 .54389 m .37092 .54111 L .37459 .54089 L F
.37416 .54389 m .37202 .54501 L .37092 .54111 L F
.076 .238 .729 r
.4371 .53791 m .43793 .53846 L .43817 .53638 L F
.4371 .53791 m .43793 .53846 L .43817 .53638 L F
.475 .458 .76 r
.71232 .32263 m .71122 .32641 L .70961 .32463 L F
.272 .609 .955 r
.26202 .61666 m .26154 .6181 L .25974 .61715 L F
.26202 .61666 m .26338 .61814 L .26154 .6181 L F
.813 .794 .834 r
.65258 .41608 m .65525 .4162 L .65557 .41326 L F
.85 .924 .879 r
.65525 .4162 m .65756 .41174 L .65557 .41326 L F
.65525 .4162 m .65859 .41288 L .65756 .41174 L F
.058 .451 .88 r
.38136 .61356 m .38138 .61495 L .38313 .61519 L F
.222 0 .214 r
.38311 .61718 m .38138 .61495 L .38313 .61519 L F
0 0 .472 r
.38136 .61356 m .38138 .61495 L .3831 .61717 L F
.38136 .61356 m .3831 .61717 L .3831 .61715 L F
.694 .937 .964 r
.38523 .61423 m .38706 .61477 L .38313 .61519 L F
.972 .716 .486 r
.3846 .61504 m .38311 .61718 L .38313 .61519 L F
.38706 .61477 m .38568 .61561 L .3846 .61504 L F
.38568 .61561 m .38311 .61718 L .3846 .61504 L F
.38706 .61477 m .38523 .61423 L .38311 .61718 L F
.38706 .61477 m .38695 .61746 L .38523 .61423 L F
.312 .43 .821 r
.38608 .61583 m .38715 .61409 L .38523 .61423 L F
.38695 .61746 m .38702 .61633 L .38608 .61583 L F
.38702 .61633 m .38715 .61409 L .38608 .61583 L F
.739 .843 .928 r
.38384 .61274 m .38313 .61519 L .38136 .61356 L F
.38384 .61274 m .38523 .61423 L .38313 .61519 L F
.968 .819 .642 r
.38311 .61718 m .38384 .61274 L .38136 .61356 L F
.791 .879 .911 r
.3828 .61599 m .38111 .61841 L .37947 .61684 L F
.968 .819 .642 r
.38311 .61718 m .38523 .61423 L .38384 .61274 L F
.791 .879 .911 r
.38374 .61575 m .38294 .61655 L .3828 .61599 L F
.38294 .61655 m .38111 .61841 L .3828 .61599 L F
0 0 .472 r
.3831 .61715 m .3831 .61717 L .38311 .61718 L F
0 .114 .664 r
.37907 .61128 m .38138 .61495 L .38136 .61356 L F
.559 .668 .911 r
.37662 .61181 m .37812 .60884 L .37521 .6091 L F
.37662 .61181 m .37907 .61128 L .37812 .60884 L F
.453 .345 .641 r
.31526 .59186 m .31705 .5885 L .31585 .5895 L F
.427 .145 .381 r
.30169 .53162 m .30522 .52822 L .30196 .52872 L F
.609 .757 .949 r
.27734 .52424 m .28109 .525 L .27976 .52351 L F
.674 .799 .942 r
.27976 .52351 m .28109 .525 L .2837 .52383 L F
.639 .527 .711 r
.54802 .42296 m .54551 .42584 L .54542 .42349 L F
.54802 .42296 m .54551 .42584 L .54542 .42349 L F
.609 .62 .837 r
.37986 .58817 m .379 .593 L .37636 .59158 L F
.37986 .58817 m .38203 .5924 L .379 .593 L F
.286 0 0 r
.37719 .59409 m .379 .593 L .38049 .59367 L F
.253 0 0 r
.379 .593 m .38203 .5924 L .38049 .59367 L F
.552 .754 .971 r
.36819 .66848 m .37087 .67016 L .36798 .67071 L F
.324 .186 .534 r
.36959 .67176 m .37087 .67016 L .36798 .67071 L F
.27 0 0 r
.36798 .67071 m .37087 .67016 L .36992 .67113 L F
.36817 .6713 m .36992 .67113 L .36854 .67252 L F
.36798 .67071 m .36992 .67113 L .36817 .6713 L F
.703 .186 0 r
.37087 .67016 m .37476 .67176 L .37198 .66922 L F
.326 0 0 r
.37393 .67147 m .37476 .67176 L .37087 .67016 L F
.101 .117 .589 r
.37087 .67016 m .37113 .67452 L .37263 .67295 L F
.324 .186 .534 r
.36959 .67176 m .36937 .67489 L .37113 .67452 L F
.719 .312 .276 r
.36854 .67252 m .37087 .67016 L .37263 .67295 L F
.607 .058 0 r
.37143 .67096 m .37393 .67147 L .37087 .67016 L F
.62 .288 .387 r
.37476 .67176 m .37645 .66916 L .37198 .66922 L F
.83 .641 .647 r
.37476 .67176 m .37856 .66885 L .37645 .66916 L F
.562 .818 .993 r
.37593 .67042 m .37393 .67147 L .37143 .67096 L F
0 0 0 r
.37353 .67082 m .37202 .67092 L .36941 .67128 L F
.37202 .67092 m .37143 .67096 L .37114 .67101 L F
.37202 .67092 m .37114 .67101 L .36941 .67128 L F
.607 .058 0 r
.37107 .67061 m .37087 .67016 L .36953 .66909 L F
.37143 .67096 m .37087 .67016 L .37107 .67061 L F
.281 0 0 r
.37087 .67016 m .37198 .66922 L .37048 .66931 L F
.37087 .67016 m .37048 .66931 L .36946 .66937 L F
.162 0 0 r
.35227 .67642 m .35298 .67652 L .35058 .6761 L F
.958 .696 .25 r
.35298 .67652 m .35372 .67834 L .35358 .6766 L F
.163 .412 .854 r
.35455 .67686 m .35372 .67834 L .35298 .67652 L F
.162 0 0 r
.35455 .67686 m .35298 .67652 L .35227 .67642 L F
.958 .696 .25 r
.35298 .67652 m .35358 .6766 L .35345 .67489 L F
.809 .868 .892 r
.35345 .67489 m .35461 .67161 L .35212 .6738 L F
.35345 .67489 m .3566 .6725 L .35461 .67161 L F
.606 .525 .737 r
.23841 .54592 m .24009 .55253 L .23523 .55063 L F
.581 .279 .422 r
.24009 .55253 m .23699 .55324 L .23523 .55063 L F
.24009 .55253 m .23933 .55368 L .23699 .55324 L F
.69 .578 .724 r
.24241 .55053 m .24009 .55253 L .23841 .54592 L F
.669 .973 .894 r
.24009 .55207 m .23842 .55302 L .23933 .55368 L F
.017 .557 .843 r
.23978 .55401 m .23933 .55368 L .23699 .55324 L F
.24103 .55435 m .23933 .55368 L .23699 .55324 L F
0 0 0 r
.23933 .55368 m .23442 .55506 L .23699 .55324 L F
.23933 .55368 m .2347 .55511 L .23442 .55506 L F
.669 .973 .894 r
.23842 .55302 m .2347 .55511 L .23933 .55368 L F
.017 .557 .843 r
.24103 .55435 m .23933 .55368 L .23978 .55401 L F
.971 .731 .517 r
.24103 .55435 m .2405 .55682 L .23933 .55368 L F
.538 .867 .994 r
.24103 .55435 m .24241 .55053 L .2417 .55115 L F
.24103 .55435 m .23933 .55368 L .24163 .55289 L F
.855 .966 .872 r
.64589 .43457 m .64974 .43243 L .64897 .43154 L F
.71 .788 .912 r
.55249 .41038 m .54901 .4131 L .54722 .41093 L F
.87 .758 .736 r
.56548 .40747 m .56621 .40987 L .56451 .4099 L F
.774 .604 .668 r
.56621 .40987 m .56625 .41314 L .56451 .4099 L F
.637 .493 .67 r
.56625 .41314 m .56909 .41352 L .56621 .40987 L F
.686 .776 .919 r
.56909 .41352 m .57134 .41199 L .56621 .40987 L F
.579 .527 .761 r
.56655 .41085 m .56626 .41302 L .56826 .41165 L F
.56626 .41302 m .56639 .41304 L .56826 .41165 L F
.56626 .41302 m .56625 .41314 L .56639 .41304 L F
0 0 .445 r
.56644 .41015 m .56625 .41314 L .56621 .40987 L F
.56661 .41037 m .56655 .41085 L .56644 .41015 L F
.56655 .41085 m .56625 .41314 L .56644 .41015 L F
.579 .527 .761 r
.56536 .41149 m .56625 .41314 L .56655 .41085 L F
.676 .431 .543 r
.56451 .4099 m .56655 .41085 L .56235 .41311 L F
.56655 .41085 m .56826 .41165 L .56673 .41202 L F
0 0 .445 r
.56715 .41105 m .56625 .41314 L .56661 .41037 L F
.701 .864 .959 r
.56625 .41314 m .56235 .41311 L .56673 .41202 L F
.56625 .41314 m .56673 .41202 L .56826 .41165 L F
0 0 .445 r
.56754 .41154 m .56625 .41314 L .56715 .41105 L F
.676 .431 .543 r
.56655 .41085 m .56673 .41202 L .56235 .41311 L F
.686 .776 .919 r
.56909 .41352 m .5731 .4136 L .57134 .41199 L F
.424 .692 .975 r
.5708 .41267 m .56947 .41334 L .56754 .41154 L F
.56947 .41334 m .56909 .41352 L .56891 .41328 L F
.56947 .41334 m .56891 .41328 L .56754 .41154 L F
.581 .039 0 r
.56621 .40987 m .56839 .41077 L .56754 .41154 L F
.56839 .41077 m .56864 .41087 L .56754 .41154 L F
.997 .774 .454 r
.56611 .41296 m .56754 .41154 L .5661 .41241 L F
.65 .888 .541 r
.56643 .41255 m .56754 .41154 L .56611 .41296 L F
.997 .774 .454 r
.5661 .41241 m .56754 .41154 L .56603 .4089 L F
.364 .603 .94 r
.56603 .4089 m .56754 .41154 L .56876 .40961 L F
.65 .888 .541 r
.56876 .40961 m .56754 .41154 L .56643 .41255 L F
.581 .039 0 r
.56864 .41087 m .57134 .41199 L .56754 .41154 L F
.801 .635 .676 r
.31973 .65596 m .32156 .65518 L .32098 .65145 L F
.372 .333 .686 r
.32098 .65145 m .32352 .65384 L .32539 .65289 L F
.32098 .65145 m .32156 .65518 L .32352 .65384 L F
.568 .938 .883 r
.57001 .4322 m .57582 .42966 L .57346 .43036 L F
.768 .976 .917 r
.57346 .43036 m .57582 .42966 L .57562 .42897 L F
.075 .056 .529 r
.62338 .43505 m .62235 .43904 L .62237 .43694 L F
0 0 .556 r
.39718 .52157 m .39543 .51764 L .39655 .51904 L F
.326 .122 .443 r
.34652 .52719 m .34559 .52939 L .34766 .52767 L F
0 0 0 r
.67219 .36827 m .6694 .37127 L .67172 .37013 L F
.325 0 .226 r
.673 .36769 m .67219 .36827 L .67297 .36767 L F
.673 .36769 m .67297 .36767 L .67422 .36672 L F
0 0 0 r
.67422 .36672 m .67219 .36827 L .67172 .37013 L F
.887 .991 .772 r
.67284 .36758 m .67172 .37013 L .6728 .36765 L F
.6736 .36608 m .67288 .36761 L .67284 .36758 L F
.67288 .36761 m .67172 .37013 L .67284 .36758 L F
.325 0 .226 r
.67554 .3659 m .673 .36769 L .67422 .36672 L F
.858 .886 .856 r
.65219 .33639 m .65234 .33946 L .64943 .33958 L F
.863 .88 .848 r
.64943 .33958 m .65234 .33946 L .65075 .34098 L F
.846 .878 .864 r
.6552 .33628 m .65234 .33946 L .65219 .33639 L F
.277 0 .091 r
.36034 .54075 m .36279 .54018 L .36387 .53825 L F
0 0 0 r
.36387 .53825 m .36512 .53747 L .36676 .53547 L F
.455 .25 .512 r
.36279 .54018 m .36512 .53747 L .36387 .53825 L F
.61 .164 .166 r
.38541 .50327 m .3879 .50494 L .38956 .503 L F
.177 0 0 r
.38956 .503 m .39048 .5042 L .39243 .50311 L F
.38956 .503 m .3879 .50494 L .39048 .5042 L F
.501 .296 .534 r
.38956 .503 m .39243 .50311 L .39225 .49973 L F
.277 .78 .845 r
.67566 .36533 m .67554 .3659 L .67422 .36672 L F
.67566 .36533 m .67825 .36532 L .67554 .3659 L F
.567 0 0 r
.35863 .501 m .36168 .50283 L .36015 .50191 L F
.684 .675 .836 r
.43366 .47741 m .42935 .47701 L .43213 .47356 L F
.709 .645 .784 r
.43606 .47422 m .43366 .47741 L .43213 .47356 L F
.675 .595 .759 r
.43606 .47422 m .4374 .47788 L .43366 .47741 L F
.45 .856 .679 r
.24667 .53088 m .24645 .53103 L .24659 .53122 L F
0 0 0 r
.24659 .53122 m .246 .53137 L .24669 .53136 L F
.24659 .53122 m .24346 .53323 L .246 .53137 L F
.45 .856 .679 r
.24645 .53103 m .2451 .53196 L .24659 .53122 L F
0 0 0 r
.24659 .53122 m .24669 .53136 L .24829 .53135 L F
.504 .68 .945 r
.70959 .35147 m .70992 .3529 L .71079 .35067 L F
.35 .22 .56 r
.70992 .3529 m .71225 .35494 L .71079 .35067 L F
.70992 .3529 m .71011 .35589 L .71225 .35494 L F
.773 .362 0 r
.39941 .55292 m .40159 .55663 L .40039 .5545 L F
.519 .485 .759 r
.32755 .54137 m .32912 .54492 L .33099 .54427 L F
.844 .858 .854 r
.32683 .5449 m .32512 .54631 L .32871 .54682 L F
.196 .192 .627 r
.33016 .54399 m .32912 .54492 L .32683 .5449 L F
.504 .909 .881 r
.32562 .54537 m .33016 .54399 L .32683 .5449 L F
.32601 .54525 m .32692 .54442 L .33016 .54399 L F
.32562 .54537 m .32577 .54526 L .32601 .54525 L F
.32577 .54526 m .32692 .54442 L .32601 .54525 L F
.844 .858 .854 r
.32683 .5449 m .32713 .54521 L .32912 .54492 L F
.32713 .54521 m .32871 .54682 L .32907 .54515 L F
.32713 .54521 m .32907 .54515 L .32912 .54492 L F
.196 .192 .627 r
.33016 .54399 m .32871 .54682 L .32912 .54492 L F
.588 .25 .364 r
.30099 .63076 m .30392 .63332 L .30039 .63398 L F
.625 .233 .281 r
.30099 .63076 m .30355 .63113 L .30392 .63332 L F
.31 .155 .503 r
.39225 .49973 m .39243 .50311 L .39389 .50118 L F
.646 .534 .713 r
.29439 .6117 m .29451 .61553 L .29621 .6146 L F
0 0 .214 r
.30819 .60502 m .30613 .60856 L .30764 .60741 L F
.283 .096 .442 r
.30536 .61104 m .30764 .60741 L .30613 .60856 L F
.817 .88 .891 r
.65516 .35479 m .65971 .35329 L .65826 .35175 L F
.803 .801 .849 r
.65971 .35329 m .66095 .34861 L .65826 .35175 L F
.65971 .35329 m .66264 .35049 L .66095 .34861 L F
.481 .616 .908 r
.34033 .65983 m .34341 .65978 L .34153 .65779 L F
.512 .912 .828 r
.38515 .64881 m .38785 .64808 L .38468 .64965 L F
.618 .821 .414 r
.38515 .64881 m .38468 .64965 L .38327 .6517 L F
.837 .929 .892 r
.43826 .54945 m .44244 .5478 L .44056 .54865 L F
0 .273 .776 r
.44244 .5478 m .44342 .54735 L .44056 .54865 L F
.44244 .5478 m .44507 .54979 L .44342 .54735 L F
.49 .357 .627 r
.44266 .55057 m .44507 .54979 L .44244 .5478 L F
0 0 0 r
.3493 .51511 m .35021 .51541 L .35182 .51586 L F
0 0 .533 r
.25696 .5751 m .25791 .57691 L .25677 .5721 L F
.96 .642 .372 r
.58728 .38477 m .58589 .38604 L .58617 .38302 L F
.58728 .38477 m .58755 .38724 L .58589 .38604 L F
.258 0 .009 r
.34679 .56737 m .34802 .56732 L .34312 .56968 L F
.269 .266 .672 r
.34894 .56551 m .34802 .56732 L .34679 .56737 L F
0 .258 .764 r
.28956 .55048 m .29219 .55457 L .29207 .55395 L F
.944 .796 .666 r
.29219 .55457 m .29126 .55674 L .29207 .55395 L F
.461 .774 .997 r
.60859 .36965 m .61028 .37094 L .61332 .37031 L F
.391 .379 .726 r
.21116 .60152 m .21246 .5985 L .21004 .5983 L F
.148 0 .113 r
.32159 .54938 m .32001 .54869 L .32145 .54673 L F
.32159 .54938 m .31881 .55084 L .32001 .54869 L F
0 0 .577 r
.43985 .56718 m .44134 .56814 L .44166 .56594 L F
.93 .571 .321 r
.23229 .61327 m .23153 .61245 L .22981 .612 L F
.23153 .61245 m .22956 .6103 L .22976 .61168 L F
.23153 .61245 m .22976 .61168 L .22981 .612 L F
.23229 .61327 m .23034 .61258 L .22956 .6103 L F
.217 .702 .93 r
.23229 .61327 m .23457 .61324 L .23034 .61258 L F
.401 0 0 r
.23269 .61295 m .23262 .61328 L .23034 .61258 L F
.23457 .61324 m .23342 .61327 L .23269 .61295 L F
.23342 .61327 m .23262 .61328 L .23269 .61295 L F
.519 .485 .759 r
.32755 .54137 m .33099 .54427 L .33096 .54124 L F
.991 .837 .594 r
.40062 .562 m .40261 .56074 L .40167 .55672 L F
.40062 .562 m .40186 .5633 L .40261 .56074 L F
.858 .751 .745 r
.57125 .39388 m .57235 .3976 L .56992 .39759 L F
.829 .67 .685 r
.56756 .39948 m .56712 .39965 L .56766 .39926 L F
.57235 .3976 m .57101 .40131 L .56741 .39978 L F
.56756 .39948 m .56741 .39978 L .56712 .39965 L F
.57235 .3976 m .56741 .39978 L .56756 .39948 L F
.792 .714 .779 r
.56712 .39965 m .57101 .40131 L .56974 .4027 L F
.56712 .39965 m .56974 .4027 L .56964 .40281 L F
.362 .565 .915 r
.56712 .39965 m .56729 .40017 L .56735 .39992 L F
.862 .966 .865 r
.56998 .39494 m .56992 .39759 L .56712 .39965 L F
.362 .565 .915 r
.56712 .39965 m .56735 .39992 L .56772 .39828 L F
.803 .848 .884 r
.56734 .39993 m .56729 .40017 L .56712 .39965 L F
.56964 .40281 m .56729 .40017 L .56734 .39993 L F
.829 .905 .496 r
.56772 .39828 m .56736 .39989 L .56735 .3999 L F
0 .421 .837 r
.56536 .39934 m .56654 .40034 L .56495 .39988 L F
.829 .905 .496 r
.56767 .3984 m .56735 .3999 L .56671 .40118 L F
.56667 .40097 m .56671 .40118 L .56609 .40244 L F
.56767 .3984 m .56671 .40118 L .56667 .40097 L F
.56736 .39989 m .56734 .39998 L .56636 .40192 L F
.56736 .39989 m .56636 .40192 L .56609 .40244 L F
.56734 .39998 m .56704 .40064 L .56609 .40244 L F
.862 .966 .865 r
.56998 .39494 m .56728 .3994 L .56772 .39828 L F
.56728 .3994 m .56712 .39965 L .56772 .39828 L F
.765 .937 .591 r
.56998 .39494 m .56895 .39646 L .56848 .39626 L F
.56895 .39646 m .56772 .39828 L .56848 .39626 L F
.924 .925 .55 r
.57125 .39388 m .56992 .39759 L .56998 .39494 L F
.44 .499 .823 r
.56932 .3977 m .57109 .39544 L .56848 .39626 L F
.145 0 0 r
.56848 .39626 m .5694 .39696 L .56812 .3961 L F
.56848 .39626 m .56812 .3961 L .56673 .39517 L F
.331 .58 .933 r
.5685 .3963 m .56772 .39828 L .56932 .3977 L F
.56848 .39626 m .56772 .39828 L .5685 .3963 L F
.829 .905 .496 r
.56772 .39828 m .56609 .40244 L .56708 .4008 L F
0 .421 .837 r
.56654 .40034 m .56708 .4008 L .56659 .40059 L F
.56654 .40034 m .56659 .40059 L .56495 .39988 L F
.829 .905 .496 r
.56772 .39828 m .56735 .3999 L .56767 .3984 L F
.56734 .39998 m .56729 .40017 L .56704 .40064 L F
.829 .67 .685 r
.57235 .3976 m .56756 .39948 L .56992 .39759 L F
.56756 .39948 m .56766 .39926 L .56992 .39759 L F
.791 .718 .783 r
.57528 .39383 m .57235 .3976 L .57125 .39388 L F
.503 0 0 r
.60037 .40078 m .6044 .40383 L .60297 .40237 L F
0 .061 .561 r
.60297 .40237 m .6044 .40383 L .6067 .40592 L F
.796 .59 .623 r
.37362 .5879 m .37626 .58946 L .37776 .58631 L F
.37362 .5879 m .37776 .58631 L .37579 .58769 L F
.535 .878 .627 r
.37864 .58531 m .37776 .58631 L .37936 .58541 L F
.37864 .58531 m .37579 .58769 L .37776 .58631 L F
.932 .97 .73 r
.6462 .41373 m .64382 .41511 L .64478 .41235 L F
.891 .979 .816 r
.64806 .40943 m .6462 .41373 L .64478 .41235 L F
.64806 .40943 m .64878 .41045 L .6462 .41373 L F
.707 .869 .463 r
.21766 .5542 m .21836 .55256 L .21972 .55067 L F
0 0 0 r
.21711 .55668 m .21836 .55256 L .21766 .5542 L F
.823 .739 .771 r
.39832 .6815 m .39528 .68506 L .39424 .68186 L F
.39832 .6815 m .39424 .68186 L .39663 .68384 L F
.57 .655 .894 r
.39832 .6815 m .39905 .67786 L .39716 .68101 L F
.39832 .6815 m .40143 .68142 L .39905 .67786 L F
.112 0 0 r
.39663 .68384 m .40143 .68142 L .39832 .6815 L F
.973 .663 .349 r
.56107 .40651 m .5627 .40951 L .5591 .41042 L F
.753 .499 .549 r
.5591 .41042 m .5627 .40951 L .56235 .41311 L F
.676 .431 .543 r
.56451 .4099 m .56235 .41311 L .5627 .40951 L F
.644 .562 .748 r
.56548 .40747 m .56451 .4099 L .5627 .40951 L F
.49 .52 .815 r
.44172 .5595 m .44247 .55579 L .43974 .55637 L F
.44172 .5595 m .44398 .55946 L .44247 .55579 L F
.642 .279 .341 r
.27353 .56921 m .26946 .57133 L .27094 .56961 L F
.039 0 .239 r
.31068 .6199 m .3088 .62126 L .311 .61774 L F
.205 0 .337 r
.31012 .62255 m .3088 .62126 L .31068 .6199 L F
.31012 .62255 m .30824 .62382 L .3088 .62126 L F
.796 .838 .883 r
.42935 .47701 m .42558 .47639 L .42812 .47386 L F
.42935 .47701 m .42735 .47775 L .42558 .47639 L F
.824 .855 .87 r
.43213 .47356 m .42935 .47701 L .42812 .47386 L F
.777 .556 .6 r
.54441 .45193 m .54427 .45455 L .54035 .4542 L F
.805 .509 .488 r
.54441 .45193 m .54837 .45503 L .54427 .45455 L F
.881 .897 .838 r
.23709 .61025 m .23629 .6142 L .23882 .61243 L F
.707 .274 0 r
.60429 .42266 m .60371 .4216 L .60227 .41959 L F
.171 .598 .938 r
.35654 .49959 m .35526 .5005 L .35349 .49946 L F
.35654 .49959 m .35863 .501 L .35526 .5005 L F
.518 0 0 r
.5754 .41798 m .57707 .41687 L .57273 .41669 L F
.986 .802 .572 r
.57707 .41687 m .57631 .41955 L .57411 .41988 L F
.073 0 0 r
.57971 .41648 m .57707 .41687 L .5754 .41798 L F
.518 .45 .719 r
.44992 .52466 m .45068 .52842 L .44828 .52899 L F
.523 .432 .694 r
.45068 .52842 m .44872 .5317 L .44828 .52899 L F
.235 0 .158 r
.34165 .67525 m .34087 .67396 L .33981 .67559 L F
.349 .012 .244 r
.34456 .67478 m .34582 .67122 L .34087 .67396 L F
.347 0 .09 r
.34456 .67478 m .34087 .67396 L .34165 .67525 L F
.681 .133 0 r
.44775 .56493 m .44849 .56428 L .44746 .56316 L F
.592 .584 .812 r
.44849 .56428 m .45205 .56296 L .44746 .56316 L F
.267 .271 .678 r
.69969 .30784 m .70101 .30344 L .69865 .30592 L F
.69969 .30784 m .70172 .30655 L .70101 .30344 L F
.183 .036 .435 r
.70091 .30859 m .70172 .30655 L .69969 .30784 L F
.863 .934 .556 r
.39026 .68933 m .39024 .69072 L .39183 .68752 L F
0 0 .331 r
.39063 .691 m .39024 .69072 L .39026 .68933 L F
.992 .867 .602 r
.38967 .69376 m .39124 .69205 L .39024 .69072 L F
0 0 .331 r
.39112 .69325 m .39061 .69178 L .39063 .691 L F
.39061 .69178 m .39024 .69072 L .39063 .691 L F
.853 .956 .612 r
.38967 .69376 m .38957 .69511 L .39056 .6933 L F
.39057 .69277 m .39056 .6933 L .39124 .69205 L F
.38967 .69376 m .39056 .6933 L .39057 .69277 L F
.855 .767 .259 r
.38892 .69633 m .38957 .69511 L .38967 .69376 L F
.38892 .69633 m .38944 .69591 L .38957 .69511 L F
.38892 .69633 m .38912 .69776 L .38944 .69591 L F
.585 .474 .694 r
.39112 .69325 m .39171 .69637 L .38892 .69633 L F
.273 .728 .955 r
.38892 .69633 m .3899 .69539 L .38842 .69674 L F
.755 .989 .777 r
.38531 .69911 m .38627 .69922 L .38892 .69633 L F
.38531 .69911 m .38892 .69633 L .38708 .69797 L F
.273 .728 .955 r
.38892 .69633 m .38842 .69674 L .38708 .69797 L F
0 .045 .597 r
.39383 .65523 m .39291 .65634 L .39204 .65263 L F
.735 .442 .483 r
.3949 .65822 m .39318 .65949 L .39291 .65634 L F
.483 .561 .859 r
.39291 .65634 m .39757 .66008 L .3949 .65822 L F
.475 .885 .938 r
.39485 .6555 m .39291 .65634 L .39383 .65523 L F
.913 .711 .617 r
.53659 .44395 m .53645 .4458 L .53523 .44185 L F
.517 .292 .512 r
.33494 .57322 m .33444 .57612 L .33202 .57653 L F
.506 .294 .526 r
.33784 .57005 m .33739 .57292 L .33494 .57322 L F
.591 .4 .591 r
.33739 .57292 m .33444 .57612 L .33494 .57322 L F
.504 .44 .718 r
.25293 .54962 m .25551 .55032 L .25525 .54748 L F
.316 .196 .553 r
.25293 .54962 m .25513 .55291 L .25551 .55032 L F
.712 .985 .883 r
.43165 .54991 m .43018 .5516 L .42956 .55139 L F
.5 .522 .811 r
.22605 .60845 m .22678 .60418 L .22406 .60513 L F
.22605 .60845 m .22821 .60792 L .22678 .60418 L F
.988 .741 .467 r
.2295 .61149 m .22821 .60792 L .22605 .60845 L F
.64 .613 .807 r
.42489 .59159 m .42627 .59552 L .4259 .59294 L F
.075 0 0 r
.42627 .59552 m .42667 .59752 L .42432 .59766 L F
.363 .726 .988 r
.42432 .59766 m .42667 .59752 L .42585 .59683 L F
.42432 .59766 m .42585 .59683 L .42526 .59634 L F
.441 .059 .217 r
.42275 .59878 m .42343 .59815 L .42432 .59766 L F
.42343 .59815 m .42627 .59552 L .42432 .59766 L F
.075 0 0 r
.42627 .59552 m .42817 .59476 L .42667 .59752 L F
.302 .13 .474 r
.42815 .59239 m .42817 .59476 L .42627 .59552 L F
.927 .611 .146 r
.60673 .42832 m .60642 .42629 L .60544 .42497 L F
.554 .795 .989 r
.39059 .59883 m .39302 .59744 L .39177 .59623 L F
.39059 .59883 m .39335 .59866 L .39302 .59744 L F
.264 0 .227 r
.39022 .60208 m .39335 .59866 L .39059 .59883 L F
.783 .989 .751 r
.28874 .51546 m .28589 .51695 L .2861 .51738 L F
0 0 0 r
.29124 .51368 m .28874 .51546 L .29022 .51472 L F
0 .28 .75 r
.60037 .40078 m .60181 .40107 L .59837 .40006 L F
.60037 .40078 m .60297 .40237 L .60181 .40107 L F
.067 0 .386 r
.37326 .58259 m .37487 .58416 L .37574 .58204 L F
.37326 .58259 m .37259 .58719 L .37487 .58416 L F
.478 .735 .983 r
.3172 .49831 m .31878 .49984 L .31965 .49794 L F
.3172 .49831 m .31878 .49984 L .31965 .49794 L F
.724 .772 .89 r
.6209 .35897 m .61765 .36174 L .6173 .35826 L F
.992 .75 .455 r
.39471 .6629 m .39318 .65949 L .39177 .66265 L F
0 0 .357 r
.40865 .54438 m .40866 .54288 L .40775 .54066 L F
.625 .161 0 r
.40865 .54438 m .40921 .54544 L .40866 .54288 L F
.40865 .54438 m .41036 .54677 L .40921 .54544 L F
.843 .895 .876 r
.65075 .34098 m .64683 .34242 L .64943 .33958 L F
.636 .077 0 r
.26883 .63317 m .26873 .63455 L .26699 .63273 L F
.26883 .63317 m .27024 .63419 L .26873 .63455 L F
.616 .882 .554 r
.53509 .41473 m .53355 .41679 L .53637 .41354 L F
.417 .614 .931 r
.53509 .41473 m .53618 .41722 L .53355 .41679 L F
.955 .658 .225 r
.40153 .56858 m .40222 .56764 L .40167 .56592 L F
.40153 .56858 m .40254 .56993 L .40222 .56764 L F
.705 .55 .675 r
.30979 .54728 m .31233 .55034 L .31163 .54654 L F
.30979 .54728 m .31027 .55094 L .31233 .55034 L F
.744 .835 .92 r
.68277 .32607 m .68703 .32583 L .68545 .32312 L F
.611 .672 .884 r
.68545 .32312 m .68703 .32583 L .68987 .32457 L F
0 0 0 r
.29022 .51472 m .2861 .51738 L .28762 .51706 L F
.676 .718 .881 r
.28802 .51675 m .28769 .51675 L .28768 .51654 L F
0 0 0 r
.29022 .51472 m .28762 .51706 L .28772 .51702 L F
.676 .718 .881 r
.28932 .51753 m .28755 .51719 L .28802 .51675 L F
0 0 0 r
.28856 .51677 m .2877 .51705 L .28846 .51689 L F
.29022 .51472 m .2877 .51705 L .28856 .51677 L F
.28772 .51702 m .28762 .51706 L .2877 .51705 L F
.526 .644 .908 r
.28764 .51559 m .2877 .51705 L .2861 .51738 L F
.676 .718 .881 r
.28837 .51643 m .28767 .51625 L .28764 .51559 L F
.28802 .51675 m .28684 .51603 L .28837 .51643 L F
.52 .52 .796 r
.28846 .51689 m .2877 .51705 L .28764 .51559 L F
.2877 .51705 m .2861 .51738 L .28764 .51559 L F
.676 .718 .881 r
.28767 .51625 m .28684 .51603 L .28764 .51559 L F
0 0 0 r
.29218 .51369 m .29022 .51472 L .28856 .51677 L F
.676 .718 .881 r
.28932 .51753 m .2883 .51692 L .28863 .51673 L F
0 0 0 r
.28868 .5167 m .28856 .51677 L .28846 .51689 L F
.29218 .51369 m .28856 .51677 L .28868 .5167 L F
.676 .718 .881 r
.28863 .51673 m .28802 .51675 L .28837 .51643 L F
.2883 .51692 m .28802 .51675 L .28863 .51673 L F
.28889 .51745 m .28656 .51895 L .28734 .51757 L F
.52 .52 .796 r
.28755 .51719 m .28656 .51895 L .28637 .51828 L F
.28755 .51719 m .28637 .51828 L .2861 .51738 L F
.676 .718 .881 r
.28889 .51745 m .28593 .51767 L .28737 .51715 L F
.52 .52 .796 r
.28846 .51689 m .28656 .51895 L .28755 .51719 L F
.2877 .51705 m .28755 .51719 L .28762 .51706 L F
.28846 .51689 m .28755 .51719 L .2877 .51705 L F
.526 .644 .908 r
.28764 .51559 m .28846 .51689 L .2877 .51705 L F
.659 .861 .977 r
.28764 .51559 m .2861 .51738 L .28549 .51678 L F
.676 .718 .881 r
.28768 .51654 m .28549 .51678 L .28684 .51603 L F
.28769 .51675 m .28549 .51678 L .28768 .51654 L F
.28755 .51719 m .28549 .51678 L .28802 .51675 L F
.52 .52 .796 r
.28762 .51706 m .28755 .51719 L .2861 .51738 L F
.676 .718 .881 r
.28734 .51757 m .28656 .51895 L .28593 .51767 L F
.28737 .51715 m .28593 .51767 L .28549 .51678 L F
.28955 .51758 m .28932 .51753 L .28864 .51674 L F
.28872 .51671 m .28864 .51674 L .28764 .51559 L F
.28955 .51758 m .28864 .51674 L .28872 .51671 L F
.146 .561 .928 r
.29245 .51967 m .28968 .51774 L .29205 .51861 L F
.29245 .51967 m .29241 .51961 L .28983 .51784 L F
.29241 .51961 m .29172 .51901 L .28983 .51784 L F
.29221 .51932 m .29213 .51923 L .28983 .51784 L F
.29205 .51861 m .29076 .51799 L .29174 .51777 L F
.28968 .51774 m .28949 .5176 L .29205 .51861 L F
.119 0 0 r
.28966 .51759 m .28951 .5176 L .28955 .51758 L F
.146 .561 .928 r
.28966 .51759 m .28846 .51689 L .2899 .51758 L F
.29076 .51799 m .28846 .51689 L .29174 .51777 L F
.096 .544 .91 r
.28846 .51689 m .29013 .51766 L .28966 .51759 L F
.28846 .51689 m .28966 .51759 L .28955 .51758 L F
.146 .561 .928 r
.28949 .5176 m .28846 .51689 L .28966 .51759 L F
.28949 .5176 m .2899 .51758 L .29205 .51861 L F
.491 .705 .965 r
.29129 .51868 m .29161 .51744 L .29061 .51805 L F
.2905 .52176 m .2925 .52142 L .29198 .51909 L F
.29129 .51868 m .29198 .51909 L .29161 .51744 L F
.2905 .52176 m .29198 .51909 L .29129 .51868 L F
.146 .561 .928 r
.29184 .519 m .29163 .51846 L .29071 .51814 L F
.788 .848 .896 r
.29245 .51967 m .29456 .52044 L .29763 .5168 L F
.29245 .51967 m .29763 .5168 L .29635 .51699 L F
.29245 .51967 m .29635 .51699 L .29434 .51832 L F
.739 .875 .943 r
.29198 .51909 m .29221 .51932 L .29232 .51927 L F
.29161 .51744 m .29306 .51892 L .29245 .51967 L F
.214 .739 .779 r
.29434 .51832 m .29221 .51932 L .29245 .51967 L F
.739 .875 .943 r
.29306 .51892 m .29456 .52044 L .29245 .51967 L F
.29161 .51744 m .29198 .51909 L .29456 .52044 L F
.214 .739 .779 r
.29321 .51873 m .29119 .5178 L .29221 .51932 L F
.29615 .51702 m .29437 .5173 L .29321 .51873 L F
.29437 .5173 m .29119 .5178 L .29321 .51873 L F
.29615 .51702 m .29221 .51932 L .29434 .51832 L F
.739 .875 .943 r
.29232 .51927 m .29246 .51956 L .29264 .51944 L F
.29221 .51932 m .29246 .51956 L .29232 .51927 L F
.29264 .51944 m .29375 .52082 L .29456 .52044 L F
.29246 .51956 m .29375 .52082 L .29264 .51944 L F
.788 .848 .896 r
.29434 .51832 m .29635 .51699 L .29615 .51702 L F
.146 .561 .928 r
.29218 .51926 m .29211 .51916 L .29184 .519 L F
.29211 .51916 m .29163 .51846 L .29184 .519 L F
.29143 .51881 m .29071 .51814 L .28983 .51784 L F
.29218 .51926 m .29071 .51814 L .29143 .51881 L F
.29163 .51846 m .29119 .5178 L .29036 .51783 L F
.603 .808 .979 r
.29034 .51782 m .29061 .51805 L .29152 .51749 L F
.146 .561 .928 r
.29174 .51777 m .28846 .51689 L .29161 .51744 L F
.603 .808 .979 r
.29133 .51752 m .29152 .51749 L .29161 .51744 L F
.29034 .51782 m .29152 .51749 L .29133 .51752 L F
.676 .718 .881 r
.28941 .51764 m .28656 .51895 L .28889 .51745 L F
.603 .808 .979 r
.28656 .51895 m .29013 .51766 L .28925 .51776 L F
0 0 0 r
.28925 .51776 m .28656 .51895 L .28955 .51758 L F
.603 .808 .979 r
.28656 .51895 m .28925 .51776 L .28748 .51796 L F
0 0 0 r
.28745 .51884 m .28656 .51895 L .28925 .51776 L F
.146 .561 .928 r
.28983 .51784 m .29037 .51783 L .29005 .51767 L F
.28949 .5176 m .29004 .51767 L .28846 .51689 L F
.28983 .51784 m .29005 .51767 L .28949 .5176 L F
.119 0 0 r
.29005 .51767 m .28925 .51776 L .28951 .5176 L F
.676 .718 .881 r
.28955 .51758 m .28941 .51764 L .28889 .51745 L F
.603 .808 .979 r
.28748 .51796 m .29004 .51767 L .28846 .51689 L F
.29004 .51767 m .29013 .51766 L .28846 .51689 L F
.146 .561 .928 r
.29004 .51767 m .29005 .51767 L .28846 .51689 L F
.603 .808 .979 r
.29007 .51768 m .29042 .51779 L .29013 .51766 L F
.119 0 0 r
.2902 .51768 m .29019 .51769 L .29005 .51767 L F
.29019 .51769 m .28925 .51776 L .29004 .51767 L F
.29019 .51769 m .29004 .51767 L .29005 .51767 L F
.603 .808 .979 r
.29034 .51782 m .29042 .51779 L .29007 .51768 L F
.29042 .51779 m .29161 .51744 L .28846 .51689 L F
.119 0 0 r
.29119 .5178 m .29019 .51769 L .2902 .51768 L F
.096 .544 .91 r
.28846 .51689 m .29119 .5178 L .29013 .51766 L F
.146 .561 .928 r
.29022 .51769 m .29119 .5178 L .28986 .51736 L F
.29037 .51783 m .29119 .5178 L .29022 .51769 L F
.119 0 0 r
.29119 .5178 m .28963 .51777 L .29019 .51769 L F
.28963 .51777 m .28925 .51776 L .2902 .51768 L F
.146 .561 .928 r
.29163 .51846 m .29036 .51783 L .28983 .51784 L F
.603 .808 .979 r
.28656 .51895 m .29034 .51782 L .29007 .51768 L F
.28656 .51895 m .29061 .51805 L .29034 .51782 L F
.119 0 0 r
.29119 .5178 m .28745 .51884 L .28925 .51776 L F
.29119 .5178 m .28951 .5176 L .28966 .51759 L F
.603 .808 .979 r
.28656 .51895 m .28746 .51999 L .29061 .51805 L F
.146 .561 .928 r
.29241 .51961 m .29221 .51932 L .29172 .51901 L F
.29221 .51932 m .29218 .51926 L .29213 .51923 L F
.739 .875 .943 r
.29198 .51909 m .2925 .52142 L .29375 .52082 L F
.491 .705 .965 r
.2905 .52176 m .29129 .51868 L .28746 .51999 L F
.29129 .51868 m .29061 .51805 L .28746 .51999 L F
.146 .561 .928 r
.29037 .51783 m .28986 .51736 L .28846 .51689 L F
.214 .739 .779 r
.2926 .51758 m .29316 .51737 L .29119 .5178 L F
.29615 .51702 m .29393 .51728 L .2926 .51758 L F
.29393 .51728 m .29316 .51737 L .2926 .51758 L F
0 0 0 r
.41341 .57247 m .41498 .56838 L .41489 .56986 L F
.843 .844 .845 r
.67452 .31751 m .67029 .31906 L .67319 .31603 L F
.855 .879 .856 r
.67735 .31431 m .67452 .31751 L .67319 .31603 L F
.99 .872 .528 r
.62894 .37265 m .62931 .37122 L .62985 .37078 L F
.825 .944 .902 r
.62803 .37381 m .62899 .37326 L .62819 .37361 L F
.481 .898 .883 r
.62454 .37433 m .62636 .37443 L .62819 .37361 L F
.62836 .37341 m .62819 .37361 L .62899 .37326 L F
.62454 .37433 m .62819 .37361 L .62836 .37341 L F
.088 .004 .455 r
.62931 .37122 m .62899 .37326 L .62901 .37014 L F
.825 .944 .902 r
.6254 .37534 m .62803 .37381 L .62636 .37443 L F
.62803 .37381 m .62819 .37361 L .62636 .37443 L F
.563 .936 .889 r
.623 .37605 m .62636 .37443 L .62454 .37433 L F
.481 .898 .883 r
.62454 .37433 m .62899 .37326 L .62787 .37493 L F
.99 .872 .528 r
.62787 .37493 m .62899 .37326 L .62931 .37122 L F
.62787 .37493 m .62885 .37287 L .62956 .37273 L F
.876 .647 .588 r
.62885 .37287 m .62956 .37273 L .62891 .37272 L F
.855 .839 .829 r
.62891 .37272 m .62956 .37273 L .62985 .37078 L F
.99 .872 .528 r
.62885 .37287 m .62985 .37078 L .62956 .37273 L F
0 0 0 r
.62787 .37493 m .62956 .37273 L .62741 .37647 L F
.876 .647 .588 r
.62741 .37647 m .62956 .37273 L .62885 .37287 L F
.99 .872 .528 r
.62889 .37277 m .62856 .37316 L .6289 .37274 L F
.62787 .37493 m .62855 .37318 L .62891 .37275 L F
.62855 .37318 m .62856 .37316 L .62891 .37275 L F
.672 .234 .2 r
.62454 .37433 m .62787 .37493 L .62741 .37647 L F
.876 .647 .588 r
.62741 .37647 m .62891 .37272 L .62577 .3727 L F
.62741 .37647 m .62891 .37272 L .62741 .37647 L F
.99 .872 .528 r
.62891 .37275 m .62889 .37277 L .62893 .3727 L F
.62889 .37277 m .6289 .37274 L .62893 .3727 L F
.62856 .37316 m .62931 .37122 L .62893 .3727 L F
.641 .756 .932 r
.62976 .3714 m .63104 .36828 L .62901 .37014 L F
.88 .49 .028 r
.62931 .37122 m .62901 .37014 L .6276 .36842 L F
.784 .859 .906 r
.6276 .36842 m .62901 .37014 L .63104 .36828 L F
.88 .49 .028 r
.62931 .37122 m .6276 .36842 L .62985 .37078 L F
.855 .839 .829 r
.62577 .3727 m .62891 .37272 L .62985 .37078 L F
.99 .872 .528 r
.62893 .3727 m .62894 .37265 L .62985 .37078 L F
.72 .928 .593 r
.2271 .5986 m .2245 .60198 L .22516 .60047 L F
0 0 0 r
.22973 .5961 m .2271 .5986 L .22862 .59782 L F
.778 .659 .732 r
.22516 .60047 m .22862 .59782 L .2271 .5986 L F
.483 .188 .388 r
.32993 .596 m .32931 .59834 L .32666 .59865 L F
.267 0 .304 r
.33137 .5974 m .32931 .59834 L .32993 .596 L F
.857 .403 .08 r
.33709 .69825 m .33573 .69795 L .33652 .69573 L F
.33709 .69825 m .33827 .70044 L .33573 .69795 L F
.52 0 0 r
.33709 .69825 m .34029 .70041 L .33827 .70044 L F
.679 .204 .116 r
.60235 .36634 m .60444 .36695 L .60277 .36735 L F
0 0 .364 r
.60271 .36627 m .60302 .36797 L .60344 .36191 L F
.60302 .36797 m .6031 .36837 L .60311 .36817 L F
.60302 .36797 m .60311 .36817 L .60344 .36191 L F
.679 .204 .116 r
.6019 .36621 m .60235 .36634 L .60118 .36772 L F
.60235 .36634 m .60277 .36735 L .60118 .36772 L F
.777 .53 .561 r
.60444 .36695 m .60622 .3713 L .6031 .37109 L F
.60444 .36695 m .60634 .36875 L .60622 .3713 L F
.706 .18 0 r
.37055 .55413 m .37281 .55633 L .37482 .55648 L F
.619 .271 .359 r
.3726 .5543 m .37281 .55633 L .37055 .55413 L F
.068 0 .259 r
.67172 .37013 m .6694 .37127 L .66976 .37385 L F
.38 .177 .474 r
.32418 .57015 m .32607 .57196 L .32664 .56934 L F
.32418 .57015 m .32404 .57269 L .32607 .57196 L F
.444 .239 .506 r
.33954 .57223 m .33784 .57005 L .34049 .56976 L F
.33954 .57223 m .33739 .57292 L .33784 .57005 L F
.626 .239 .291 r
.30063 .61474 m .29919 .61721 L .30274 .61673 L F
.55 .257 .424 r
.30063 .61474 m .30274 .61673 L .30337 .61451 L F
.537 .417 .664 r
.69047 .37443 m .69137 .38005 L .68789 .37884 L F
.594 .403 .592 r
.69136 .38074 m .68789 .37884 L .69137 .38005 L F
.69136 .38074 m .68895 .38172 L .68789 .37884 L F
.466 .456 .763 r
.31881 .55084 m .31981 .55329 L .31658 .55138 L F
.981 .904 .577 r
.64916 .40584 m .64878 .41045 L .64806 .40943 L F
.813 .65 .68 r
.54837 .45503 m .54646 .45811 L .54427 .45455 L F
.54837 .45503 m .54805 .45758 L .54646 .45811 L F
0 0 0 r
.22544 .59462 m .23018 .59282 L .22815 .59427 L F
.804 .554 .561 r
.23255 .59246 m .22815 .59427 L .23018 .59282 L F
0 .47 .853 r
.34852 .51153 m .34832 .51089 L .34697 .50964 L F
.34876 .51181 m .34697 .50964 L .34648 .5093 L F
.836 .823 .835 r
.34647 .51364 m .34564 .50912 L .34186 .51054 L F
.331 .439 .821 r
.34687 .51753 m .34356 .51297 L .34647 .51364 L F
.836 .823 .835 r
.34647 .51364 m .34186 .51054 L .34356 .51297 L F
.364 0 .195 r
.34356 .51297 m .34323 .51446 L .34647 .51364 L F
.836 .823 .835 r
.34647 .51364 m .34323 .51446 L .34564 .50912 L F
.34564 .50912 m .34647 .51364 L .34876 .51181 L F
.34564 .50912 m .34323 .51446 L .34647 .51364 L F
.186 0 .112 r
.34434 .50786 m .34592 .50892 L .34662 .50843 L F
.872 .773 .272 r
.34662 .50843 m .34564 .50912 L .3457 .50845 L F
.836 .823 .835 r
.34564 .50912 m .34876 .51181 L .3457 .50845 L F
.202 .289 .73 r
.3457 .50845 m .34832 .51089 L .34749 .50749 L F
.729 .967 .705 r
.34832 .51089 m .34599 .51271 L .34815 .51037 L F
.092 .207 .692 r
.34749 .50749 m .34832 .51089 L .34931 .5091 L F
.729 .967 .705 r
.34832 .51089 m .34815 .51037 L .34931 .5091 L F
0 .47 .853 r
.34876 .51181 m .34832 .51089 L .34852 .51153 L F
.34648 .5093 m .34697 .50964 L .3457 .50845 L F
.186 0 .112 r
.34288 .50749 m .34564 .50912 L .34592 .50892 L F
.34288 .50749 m .34592 .50892 L .34434 .50786 L F
.872 .773 .272 r
.34662 .50843 m .3457 .50845 L .34685 .50666 L F
0 .285 .764 r
.39891 .52584 m .40191 .52853 L .40103 .52718 L F
.752 .324 0 r
.40191 .52853 m .40201 .52961 L .40103 .52718 L F
.40191 .52853 m .4032 .53111 L .40201 .52961 L F
.446 .052 .198 r
.44242 .59462 m .44141 .59716 L .43923 .59589 L F
.434 .041 .192 r
.44514 .59451 m .44141 .59716 L .44242 .59462 L F
.938 .645 .458 r
.2245 .60198 m .22406 .60513 L .2225 .60414 L F
.716 .913 .558 r
.2245 .60198 m .2225 .60414 L .22516 .60047 L F
.071 0 0 r
.36676 .53547 m .36746 .53644 L .36848 .53387 L F
.36676 .53547 m .36512 .53747 L .36746 .53644 L F
.804 .554 .561 r
.23255 .59246 m .23218 .59504 L .22815 .59427 L F
.199 .43 .859 r
.23363 .59165 m .23255 .59246 L .23037 .58925 L F
.636 .606 .802 r
.23363 .59165 m .23218 .59504 L .23255 .59246 L F
.93 .741 .626 r
.30169 .53162 m .30489 .53212 L .30447 .53116 L F
.876 .882 .835 r
.37008 .64127 m .37326 .64205 L .37466 .63995 L F
.967 .684 .265 r
.61246 .41264 m .6137 .41669 L .61262 .41529 L F
.92 .587 .124 r
.61262 .41529 m .6137 .41669 L .61421 .41925 L F
.637 .709 .899 r
.34571 .70746 m .34816 .71033 L .3493 .70756 L F
.528 .583 .854 r
.34816 .71033 m .35065 .70997 L .3493 .70756 L F
.971 .657 .337 r
.41803 .59811 m .42092 .60202 L .41945 .60159 L F
.273 .535 .916 r
.42184 .60043 m .42092 .60202 L .41803 .59811 L F
.616 .939 .955 r
.41945 .60159 m .42092 .60202 L .42184 .60043 L F
.604 .86 .992 r
.22205 .57116 m .21972 .57212 L .2218 .57301 L F
.356 0 0 r
.21957 .57486 m .2218 .57301 L .21972 .57212 L F
.075 0 .035 r
.36917 .71576 m .36913 .71403 L .37127 .71279 L F
.467 .877 .736 r
.36913 .71403 m .37075 .71305 L .37127 .71279 L F
.844 .972 .66 r
.38648 .5834 m .38463 .58614 L .38488 .58435 L F
.401 .226 .526 r
.38463 .58614 m .38639 .58808 L .38488 .58435 L F
.556 .731 .957 r
.38639 .58808 m .3869 .58463 L .38488 .58435 L F
.629 .42 .58 r
.3869 .58463 m .38372 .58505 L .38488 .58435 L F
.38372 .58505 m .38276 .58517 L .38488 .58435 L F
.844 .972 .66 r
.38662 .58319 m .38648 .5834 L .38488 .58435 L F
.77 .769 .852 r
.385 .57994 m .38704 .58269 L .38917 .58016 L F
.385 .57994 m .38917 .58016 L .38721 .57931 L F
.676 .429 .54 r
.38587 .58029 m .385 .57994 L .38721 .57931 L F
.38587 .58029 m .38362 .57808 L .385 .57994 L F
.38362 .57808 m .38348 .57795 L .385 .57994 L F
.77 .769 .852 r
.385 .57994 m .38662 .58319 L .38704 .58269 L F
.573 .045 0 r
.38861 .58478 m .38662 .58319 L .38488 .58435 L F
0 0 .462 r
.41341 .57247 m .41529 .57578 L .41503 .57488 L F
0 0 .531 r
.41341 .57247 m .41503 .57488 L .41489 .57376 L F
.896 .703 .192 r
.41503 .57488 m .41459 .57643 L .41483 .57422 L F
.41503 .57488 m .41483 .57422 L .41489 .57376 L F
0 0 .462 r
.41529 .57578 m .41565 .57642 L .41503 .57488 L F
.908 .646 .145 r
.41565 .57642 m .41502 .57745 L .41503 .57488 L F
.41565 .57642 m .41593 .57923 L .41502 .57745 L F
.715 .406 .454 r
.36422 .68135 m .36193 .67905 L .36158 .68193 L F
.809 .793 .837 r
.56174 .42597 m .55886 .4288 L .55895 .42709 L F
.042 0 .301 r
.69228 .36846 m .69189 .37123 L .69047 .37204 L F
.23 .253 .678 r
.69189 .37123 m .69277 .37366 L .69047 .37204 L F
.385 .228 .542 r
.69047 .37204 m .69277 .37366 L .69047 .37443 L F
.314 .513 .891 r
.3973 .52555 m .39891 .52584 L .39842 .52375 L F
.635 .326 .43 r
.30341 .55637 m .30637 .55424 L .30408 .55507 L F
.684 .374 0 r
.60829 .40711 m .60871 .40846 L .6067 .40592 L F
.60829 .40711 m .60904 .40934 L .60871 .40846 L F
.809 .907 .908 r
.70414 .28499 m .70076 .2858 L .70369 .28488 L F
0 0 0 r
.70603 .28345 m .70708 .28246 L .70414 .28499 L F
.70603 .28345 m .70414 .28499 L .70369 .28488 L F
.196 .667 .938 r
.37281 .55633 m .37709 .55735 L .37482 .55648 L F
0 0 .475 r
.20777 .57345 m .20942 .57451 L .20963 .57194 L F
.20777 .57345 m .2081 .57611 L .20942 .57451 L F
.314 .245 .618 r
.20831 .58927 m .21034 .58828 L .20993 .58521 L F
.342 .201 .539 r
.20807 .59221 m .21034 .58828 L .20831 .58927 L F
.281 .387 .793 r
.42733 .53698 m .42763 .53346 L .42505 .53409 L F
.42733 .53698 m .42901 .53724 L .42763 .53346 L F
.598 .249 .349 r
.26582 .56573 m .26826 .56621 L .26988 .56361 L F
.587 .237 .342 r
.26988 .56361 m .26826 .56621 L .27193 .56525 L F
.775 .671 .749 r
.71842 .3333 m .71439 .33291 L .71488 .32958 L F
.166 .455 .882 r
.71488 .32958 m .71971 .3322 L .71842 .3333 L F
.31 .693 .978 r
.71971 .3322 m .72054 .33324 L .71842 .3333 L F
0 .309 .736 r
.59043 .4047 m .59091 .40533 L .5894 .40391 L F
.59043 .4047 m .59378 .40689 L .59091 .40533 L F
.695 .532 .662 r
.23699 .55324 m .23299 .55067 L .23523 .55063 L F
.487 .287 .534 r
.32553 .51577 m .32802 .51517 L .3281 .51244 L F
.735 .651 .765 r
.34056 .6005 m .34131 .59973 L .34246 .5982 L F
.999 .799 .495 r
.34343 .59691 m .34367 .59881 L .34246 .5982 L F
.735 .651 .765 r
.34131 .59973 m .34473 .59624 L .34246 .5982 L F
.999 .799 .495 r
.34329 .59583 m .34343 .59691 L .34246 .5982 L F
.653 .868 .98 r
.57391 .39261 m .57528 .39383 L .57125 .39388 L F
.215 .63 .953 r
.57749 .39403 m .57528 .39383 L .57391 .39261 L F
.418 .555 .886 r
.71614 .3528 m .71717 .35053 L .71621 .35214 L F
0 0 .204 r
.71635 .3533 m .71614 .3528 L .71621 .35214 L F
.804 .467 .417 r
.35336 .68735 m .35657 .68595 L .35128 .68437 L F
.628 .554 .752 r
.35815 .68133 m .35657 .68595 L .35513 .6819 L F
.927 .595 .14 r
.35507 .68365 m .35657 .68595 L .3558 .68377 L F
.35507 .68365 m .3558 .68377 L .35513 .6819 L F
0 .551 .739 r
.35445 .68354 m .35507 .68365 L .35622 .6837 L F
.35188 .6833 m .35507 .68365 L .35445 .68354 L F
.053 .415 .863 r
.35507 .68365 m .35657 .68595 L .35622 .6837 L F
.82 .994 .861 r
.35622 .6837 m .35657 .68595 L .35336 .68735 L F
.87 .858 .827 r
.31393 .66597 m .31433 .66697 L .31175 .66871 L F
0 0 .24 r
.24439 .5343 m .24311 .53611 L .24346 .53323 L F
.625 .883 .551 r
.24439 .5343 m .24309 .53582 L .24311 .53611 L F
0 0 .157 r
.24311 .53611 m .24373 .53942 L .24274 .53444 L F
.625 .883 .551 r
.24309 .53582 m .24174 .53739 L .24311 .53611 L F
0 0 .157 r
.24311 .53611 m .24373 .53942 L .24313 .5364 L F
.24311 .53611 m .24313 .5364 L .24274 .53444 L F
.905 .954 .819 r
.24311 .53611 m .24167 .53801 L .24373 .53942 L F
.55 .363 .581 r
.57411 .41988 m .57418 .42252 L .5715 .42279 L F
.622 .559 .762 r
.5743 .42533 m .5715 .42279 L .57343 .4259 L F
.554 .381 .602 r
.57418 .42252 m .57343 .4259 L .5715 .42279 L F
.954 .95 .667 r
.57229 .42665 m .57343 .4259 L .57308 .42393 L F
.57171 .42864 m .57343 .4259 L .57229 .42665 L F
.622 .559 .762 r
.57533 .42627 m .5743 .42533 L .57343 .4259 L F
.759 .56 .627 r
.29409 .53907 m .29255 .53646 L .29675 .5383 L F
.74 .975 .924 r
.29711 .53607 m .29675 .5383 L .29941 .53745 L F
.29711 .53607 m .29409 .53907 L .29675 .5383 L F
.791 .419 .353 r
.54612 .46076 m .54983 .46142 L .54823 .46347 L F
.736 .347 .313 r
.54983 .46142 m .55243 .46406 L .54823 .46347 L F
.718 .515 .614 r
.68804 .31992 m .6931 .32113 L .69367 .3183 L F
.783 .503 .512 r
.69353 .32071 m .6947 .32141 L .69398 .32003 L F
.411 .149 .403 r
.68987 .32457 m .69277 .32196 L .68804 .31992 L F
.783 .503 .512 r
.69287 .32172 m .69299 .32243 L .69353 .32071 L F
.411 .149 .403 r
.69277 .32196 m .6931 .32113 L .68804 .31992 L F
.783 .503 .512 r
.69246 .32274 m .69299 .32243 L .69287 .32172 L F
.411 .149 .403 r
.69277 .32196 m .69203 .323 L .69357 .32124 L F
.68987 .32457 m .69203 .323 L .69277 .32196 L F
.783 .503 .512 r
.69203 .323 m .69246 .32274 L .69277 .32196 L F
.69203 .323 m .69277 .32196 L .69287 .32172 L F
.69203 .323 m .69398 .32003 L .69299 .32127 L F
.411 .149 .403 r
.69277 .32196 m .69357 .32124 L .6931 .32113 L F
.783 .503 .512 r
.69299 .32243 m .6947 .32141 L .69353 .32071 L F
.224 .112 .509 r
.69367 .3183 m .6936 .32051 L .69384 .31975 L F
.6936 .32051 m .69357 .32124 L .69384 .31975 L F
.718 .515 .614 r
.6931 .32113 m .69357 .32124 L .6936 .32051 L F
.6931 .32113 m .6936 .32051 L .69367 .3183 L F
.783 .503 .512 r
.69299 .32127 m .69398 .32003 L .69384 .31975 L F
.69203 .323 m .69628 .32375 L .6947 .32141 L F
.373 .827 .726 r
.22405 .57018 m .22205 .57116 L .2247 .57016 L F
.67 .555 .716 r
.44806 .48361 m .4456 .48684 L .4456 .48442 L F
.592 .447 .654 r
.448 .48642 m .4456 .48684 L .44806 .48361 L F
.616 .521 .724 r
.448 .48642 m .44655 .49034 L .4456 .48684 L F
.76 .774 .865 r
.28936 .62786 m .29053 .6308 L .29223 .62736 L F
.574 .545 .784 r
.29053 .6308 m .29354 .63044 L .29223 .62736 L F
.509 .238 .439 r
.2929 .63284 m .29053 .6308 L .2903 .63343 L F
.2929 .63284 m .29354 .63044 L .29053 .6308 L F
.108 .22 .699 r
.60085 .36177 m .6019 .36621 L .60271 .36627 L F
.131 0 0 r
.60271 .36627 m .6019 .36621 L .60118 .36772 L F
.92 .902 .791 r
.67957 .31082 m .67617 .31291 L .67869 .30961 L F
.67957 .31082 m .67735 .31431 L .67617 .31291 L F
.84 .831 .838 r
.68073 .30616 m .67957 .31082 L .67869 .30961 L F
.68073 .30616 m .68236 .30774 L .67957 .31082 L F
.508 .798 .998 r
.33022 .49579 m .32795 .49641 L .32857 .49455 L F
.778 .977 .701 r
.32857 .49455 m .32795 .49641 L .32579 .49788 L F
.077 .246 .735 r
.73079 .34799 m .72999 .34557 L .72781 .34599 L F
.578 .893 .622 r
.64797 .39386 m .64482 .39658 L .64739 .39566 L F
.472 .888 .782 r
.64997 .39245 m .65095 .39236 L .64797 .39386 L F
0 0 0 r
.64997 .39245 m .64797 .39386 L .64739 .39566 L F
.866 .756 .739 r
.62609 .387 m .62747 .39035 L .62836 .38855 L F
.766 .659 .744 r
.33693 .55135 m .33239 .55007 L .33462 .54978 L F
.33487 .54983 m .33462 .54978 L .33478 .54975 L F
.33693 .55135 m .33462 .54978 L .33487 .54983 L F
.33693 .55135 m .33225 .55308 L .33323 .54994 L F
.74 .421 .442 r
.33438 .55038 m .33465 .54992 L .33693 .55135 L F
.766 .659 .744 r
.33693 .55135 m .33487 .54983 L .33475 .54998 L F
.33487 .54983 m .33467 .5499 L .33332 .55167 L F
.33329 .55179 m .33332 .55167 L .33225 .55308 L F
.33487 .54983 m .33332 .55167 L .33329 .55179 L F
.735 .936 .606 r
.33465 .54992 m .33463 .54994 L .33335 .55163 L F
.33332 .55167 m .33335 .55163 L .33225 .55308 L F
.33465 .54992 m .33335 .55163 L .33332 .55167 L F
.33335 .55163 m .33335 .55164 L .33225 .55308 L F
.766 .659 .744 r
.33693 .55135 m .33475 .54998 L .33225 .55308 L F
.56 .526 .774 r
.33376 .55674 m .33336 .55162 L .33225 .55308 L F
.33333 .55124 m .33323 .54994 L .33259 .55201 L F
.33333 .55124 m .3336 .55054 L .33323 .54994 L F
.33335 .55155 m .33347 .5511 L .33333 .55124 L F
.33347 .5511 m .3336 .55054 L .33333 .55124 L F
.534 .574 .842 r
.33641 .54796 m .33478 .54975 L .33331 .54594 L F
.541 .236 .4 r
.33641 .54796 m .33599 .54838 L .33474 .54979 L F
.74 .421 .442 r
.33323 .54994 m .33465 .54992 L .33438 .55038 L F
.33424 .55004 m .33442 .55016 L .33451 .55007 L F
.33323 .54994 m .33463 .54991 L .33465 .54992 L F
.372 .44 .802 r
.33417 .55044 m .33777 .55515 L .33816 .55253 L F
.33323 .54994 m .33393 .55075 L .33417 .55044 L F
.735 .936 .606 r
.33417 .55044 m .33404 .55061 L .33384 .55091 L F
.33463 .54994 m .33384 .55091 L .33364 .55126 L F
.372 .44 .802 r
.33393 .55075 m .33777 .55515 L .33417 .55044 L F
.735 .936 .606 r
.33463 .54994 m .33417 .55044 L .33384 .55091 L F
.33417 .55044 m .3341 .55051 L .33404 .55061 L F
.33364 .55126 m .33384 .55091 L .33335 .55163 L F
.372 .44 .802 r
.33393 .55075 m .33747 .55673 L .33777 .55515 L F
.33323 .54994 m .33384 .55091 L .33393 .55075 L F
.33384 .55091 m .33747 .55673 L .33393 .55075 L F
.74 .421 .442 r
.33375 .55021 m .33417 .55044 L .33424 .55004 L F
.33417 .55044 m .33816 .55253 L .33442 .55016 L F
.33417 .55044 m .33442 .55016 L .33424 .55004 L F
.735 .936 .606 r
.33466 .54991 m .33463 .54994 L .33465 .54992 L F
.74 .421 .442 r
.33521 .5499 m .33752 .54984 L .33733 .55033 L F
.33497 .55012 m .33732 .55036 L .33693 .55135 L F
.33323 .54994 m .33765 .55039 L .33521 .5499 L F
.735 .936 .606 r
.33472 .54981 m .33293 .55145 L .33463 .54994 L F
.33472 .54981 m .33463 .54994 L .33466 .54991 L F
.786 .712 .781 r
.33478 .54975 m .33085 .54961 L .33331 .54594 L F
.541 .236 .4 r
.33584 .54855 m .33293 .55145 L .33435 .55015 L F
.33579 .54858 m .33293 .55145 L .33584 .54855 L F
.33641 .54796 m .33474 .54979 L .33483 .54969 L F
.17 .226 .679 r
.33707 .54696 m .33752 .54984 L .33922 .54779 L F
.541 .236 .4 r
.33599 .54838 m .33579 .54858 L .33584 .54855 L F
.33599 .54838 m .33435 .55015 L .33474 .54979 L F
.33483 .54969 m .33474 .54979 L .33478 .54975 L F
.56 .526 .774 r
.33336 .55162 m .33333 .55124 L .33225 .55308 L F
.33333 .55124 m .33259 .55201 L .33225 .55308 L F
.33336 .55162 m .3336 .55054 L .33335 .55155 L F
.735 .936 .606 r
.3341 .55051 m .33267 .55207 L .33335 .55163 L F
.56 .526 .774 r
.33376 .55674 m .33362 .55123 L .33336 .55162 L F
.33362 .55123 m .3336 .55054 L .33336 .55162 L F
.33376 .55674 m .33747 .55673 L .33384 .55091 L F
.33362 .55123 m .33384 .55091 L .3336 .55054 L F
.33376 .55674 m .33384 .55091 L .33362 .55123 L F
.74 .421 .442 r
.33451 .55007 m .33816 .55253 L .33765 .55039 L F
.33442 .55016 m .33816 .55253 L .33451 .55007 L F
.735 .936 .606 r
.33463 .54994 m .33293 .55145 L .33267 .55207 L F
.33478 .54975 m .33472 .54981 L .33465 .54992 L F
.766 .659 .744 r
.33487 .54983 m .33478 .54975 L .33467 .5499 L F
.74 .421 .442 r
.33521 .5499 m .33765 .55039 L .33752 .54984 L F
.541 .236 .4 r
.33641 .54796 m .3355 .55148 L .33293 .55145 L F
.808 .8 .308 r
.33816 .55253 m .33909 .54839 L .33752 .54984 L F
.33909 .54839 m .33922 .54779 L .33899 .54807 L F
.33909 .54839 m .33899 .54807 L .33752 .54984 L F
.556 .525 .776 r
.33984 .55093 m .34166 .55368 L .34359 .55171 L F
.38 .091 .343 r
.33813 .55069 m .33641 .54796 L .33693 .54793 L F
.33911 .5481 m .33693 .54793 L .33922 .54779 L F
.33813 .55069 m .33693 .54793 L .33911 .5481 L F
.33741 .54984 m .3355 .55148 L .33628 .54848 L F
.3367 .54841 m .33628 .54848 L .33641 .54796 L F
.33813 .55069 m .33628 .54848 L .3367 .54841 L F
.534 .574 .842 r
.33641 .54796 m .33331 .54594 L .33707 .54696 L F
.374 0 0 r
.33707 .54696 m .33922 .54779 L .33641 .54796 L F
.006 0 0 r
.33369 .5496 m .33802 .5482 L .334 .5466 L F
.33802 .5482 m .33824 .54813 L .33807 .54807 L F
.33802 .5482 m .33807 .54807 L .334 .5466 L F
.38 .091 .343 r
.33813 .55069 m .33697 .55104 L .33741 .54984 L F
.33697 .55104 m .3355 .55148 L .33741 .54984 L F
.006 0 0 r
.33498 .54919 m .33616 .54916 L .33813 .54819 L F
.33802 .5482 m .33813 .54819 L .33824 .54813 L F
.33498 .54919 m .33813 .54819 L .33802 .5482 L F
.265 0 0 r
.33824 .54813 m .33616 .54916 L .33844 .54904 L F
.808 .8 .308 r
.33816 .55253 m .33821 .55153 L .33915 .54804 L F
.33816 .55253 m .33915 .54804 L .33917 .54802 L F
.33821 .55153 m .33862 .54955 L .33922 .54779 L F
.33917 .54802 m .33915 .54804 L .33922 .54779 L F
.33821 .55153 m .33826 .55061 L .33862 .54955 L F
.846 .519 .434 r
.33922 .54779 m .33826 .55061 L .34359 .55171 L F
0 0 0 r
.33965 .54898 m .33813 .55069 L .33922 .54779 L F
.265 0 0 r
.33884 .54849 m .33844 .54904 L .33965 .54898 L F
.33824 .54813 m .33844 .54904 L .33884 .54849 L F
.846 .519 .434 r
.33922 .54779 m .34359 .55171 L .34119 .54721 L F
.424 .267 .562 r
.33922 .54779 m .34119 .54721 L .34103 .5452 L F
.497 .498 .788 r
.34051 .5442 m .34119 .54721 L .33922 .54779 L F
0 0 0 r
.33965 .54898 m .33922 .54779 L .34119 .54721 L F
.265 0 0 r
.3391 .54721 m .33965 .54898 L .33973 .54654 L F
.33824 .54813 m .33884 .54849 L .3391 .54721 L F
.33884 .54849 m .33965 .54898 L .3391 .54721 L F
.556 .525 .776 r
.33826 .55061 m .34028 .55243 L .33984 .55093 L F
.34028 .55243 m .34166 .55368 L .33984 .55093 L F
.006 0 0 r
.33369 .5496 m .33465 .54943 L .33498 .54919 L F
.33465 .54943 m .33616 .54916 L .33498 .54919 L F
.735 .936 .606 r
.33335 .55164 m .33267 .55207 L .33225 .55308 L F
.74 .421 .442 r
.33323 .54994 m .33375 .55021 L .33424 .55004 L F
.847 .942 .884 r
.39002 .61183 m .38706 .61477 L .38523 .61423 L F
.928 .942 .785 r
.39072 .64956 m .39107 .65149 L .39123 .65124 L F
.39072 .64956 m .39123 .65124 L .39404 .64671 L F
.39072 .64956 m .3928 .64778 L .39336 .64799 L F
.3928 .64778 m .39404 .64671 L .39336 .64799 L F
.744 .245 0 r
.39336 .64799 m .39511 .64926 L .3967 .65163 L F
.982 .866 .647 r
.39545 .65095 m .3967 .65163 L .39577 .65405 L F
.744 .245 0 r
.3955 .65098 m .3967 .65163 L .39584 .65145 L F
.39336 .64799 m .3967 .65163 L .3955 .65098 L F
.982 .866 .647 r
.3953 .64951 m .3967 .65163 L .39545 .65095 L F
0 0 .545 r
.39525 .65064 m .39519 .65043 L .39393 .64821 L F
.39469 .64986 m .39525 .65064 L .39485 .64989 L F
.39551 .651 m .39522 .6504 L .39393 .64821 L F
.903 .492 .119 r
.39404 .64671 m .39511 .64926 L .39336 .64799 L F
.64 .593 .785 r
.3938 .6477 m .39522 .6504 L .3953 .64951 L F
.953 .928 .583 r
.3953 .64951 m .3951 .65017 L .39503 .64993 L F
.3953 .64951 m .39503 .64993 L .39516 .64996 L F
.976 .704 .301 r
.39584 .65145 m .3967 .65163 L .3953 .64951 L F
.64 .593 .785 r
.3932 .64697 m .39366 .64776 L .3938 .6477 L F
.39366 .64776 m .39522 .6504 L .3938 .6477 L F
.953 .928 .583 r
.39503 .64993 m .39431 .6528 L .3935 .6523 L F
.64 .593 .785 r
.39475 .64966 m .3953 .64951 L .39507 .65022 L F
.3932 .64697 m .3953 .64951 L .39475 .64966 L F
.708 .535 .652 r
.39507 .65022 m .39664 .64727 L .39419 .64755 L F
.39383 .64769 m .39419 .64755 L .39378 .6476 L F
.39507 .65022 m .39419 .64755 L .39383 .64769 L F
.982 .866 .647 r
.3953 .64951 m .39544 .65085 L .39522 .6504 L F
.64 .593 .785 r
.39522 .6504 m .39584 .65145 L .3953 .64951 L F
.982 .866 .647 r
.3953 .64951 m .39522 .6504 L .3951 .65017 L F
.953 .928 .583 r
.39511 .65002 m .3935 .6523 L .39507 .65022 L F
.39503 .64993 m .3935 .6523 L .39516 .64996 L F
.3951 .65017 m .39431 .6528 L .39503 .64993 L F
.78 .276 0 r
.39483 .65138 m .39507 .65022 L .39402 .65094 L F
.982 .866 .647 r
.3951 .65017 m .39577 .65405 L .39431 .6528 L F
0 0 .545 r
.39525 .65064 m .39551 .651 L .39519 .65043 L F
.982 .866 .647 r
.39544 .65085 m .39577 .65405 L .3951 .65017 L F
.78 .276 0 r
.39596 .652 m .39507 .65022 L .39483 .65138 L F
.953 .928 .583 r
.39516 .64996 m .39511 .65002 L .39507 .65022 L F
0 0 .545 r
.39336 .64799 m .39469 .64986 L .39393 .64821 L F
.39469 .64986 m .39485 .64989 L .39393 .64821 L F
.39551 .651 m .39584 .65145 L .39522 .6504 L F
.39336 .64799 m .39393 .64821 L .3932 .64697 L F
.667 .831 .962 r
.39025 .64799 m .39072 .64956 L .39336 .64799 L F
.38832 .64799 m .39072 .64956 L .39025 .64799 L F
.975 .786 .587 r
.61045 .43678 m .61287 .43612 L .61029 .4344 L F
.61045 .43678 m .61208 .4382 L .61287 .43612 L F
.112 .366 .829 r
.32852 .64592 m .32778 .64645 L .32565 .64301 L F
.419 .845 .696 r
.32574 .64733 m .32778 .64645 L .32852 .64592 L F
.634 .406 .555 r
.30773 .55216 m .30921 .55316 L .31027 .55094 L F
.30773 .55216 m .30637 .55424 L .30921 .55316 L F
.684 .52 .658 r
.22352 .59612 m .22555 .59748 L .22102 .59916 L F
.837 .67 .129 r
.22544 .59462 m .22555 .59748 L .22352 .59612 L F
0 0 0 r
.32755 .68442 m .32559 .68538 L .32486 .68667 L F
0 0 .24 r
.35576 .5603 m .35739 .55696 L .35478 .557 L F
.35576 .5603 m .3569 .55988 L .35739 .55696 L F
.522 .492 .764 r
.35535 .5635 m .3569 .55988 L .35576 .5603 L F
.628 .234 .277 r
.31777 .55643 m .31303 .55844 L .31451 .55799 L F
.74 .758 .25 r
.32272 .52447 m .32383 .52008 L .32346 .5233 L F
.949 .654 .444 r
.70382 .31103 m .70234 .3127 L .70091 .30859 L F
.713 .286 .232 r
.70706 .31332 m .70234 .3127 L .70382 .31103 L F
.453 0 .007 r
.22608 .57477 m .23078 .5733 L .22841 .574 L F
.536 .279 .473 r
.27204 .53155 m .27487 .5312 L .27523 .52875 L F
.254 .042 .386 r
.27523 .52875 m .27487 .5312 L .2767 .53034 L F
.497 .286 .524 r
.37459 .54089 m .37667 .54333 L .37416 .54389 L F
.37416 .54389 m .37667 .54333 L .37459 .54089 L F
.673 .594 .759 r
.43996 .4773 m .4374 .47788 L .43606 .47422 L F
.66 .534 .699 r
.43996 .4773 m .43756 .48059 L .4374 .47788 L F
.612 .361 .513 r
.34217 .52892 m .34134 .53006 L .34266 .52884 L F
.671 .614 .783 r
.37198 .66922 m .37645 .66916 L .37436 .66622 L F
.911 .505 .156 r
.32648 .5115 m .32858 .51462 L .3281 .51244 L F
.938 .951 .761 r
.65859 .41288 m .65988 .40829 L .65756 .41174 L F
.741 .722 .834 r
.44322 .47388 m .4386 .47345 L .44103 .47069 L F
.385 .109 .367 r
.44322 .47388 m .43996 .4773 L .4386 .47345 L F
.44322 .47388 m .44229 .4767 L .43996 .4773 L F
.341 .431 .809 r
.44366 .46993 m .44322 .47388 L .44103 .47069 L F
.44366 .46993 m .44469 .47282 L .44322 .47388 L F
.482 .323 .588 r
.44469 .47282 m .44229 .4767 L .44322 .47388 L F
.544 .914 .747 r
.40198 .48856 m .39976 .49017 L .40169 .48849 L F
.40169 .48849 m .39976 .49017 L .40198 .48856 L F
.844 .704 .708 r
.53379 .43537 m .53519 .43913 L .53211 .43866 L F
.817 .602 .612 r
.53519 .43913 m .53138 .44117 L .53211 .43866 L F
.53519 .43913 m .53523 .44185 L .53138 .44117 L F
.649 .876 .983 r
.40882 .48647 m .40981 .48414 L .41182 .4851 L F
.40882 .48647 m .40725 .48542 L .40981 .48414 L F
.898 .974 .815 r
.39019 .64494 m .38785 .64808 L .38515 .64881 L F
.979 .724 .32 r
.61421 .41925 m .61529 .42312 L .61419 .42154 L F
.994 .764 .401 r
.61419 .42154 m .61529 .42312 L .61513 .42565 L F
.992 .828 .458 r
.43099 .55979 m .43045 .56237 L .43139 .56331 L F
0 0 0 r
.43094 .56508 m .42953 .56712 L .43033 .56549 L F
.43094 .56508 m .43033 .56549 L .43139 .56331 L F
.43172 .56456 m .43094 .56508 L .4309 .56371 L F
.43187 .56472 m .43094 .56508 L .43172 .56456 L F
.43094 .56508 m .43139 .56331 L .43045 .56237 L F
.291 .066 .39 r
.29525 .63675 m .29761 .63373 L .29746 .63608 L F
.15 .659 .901 r
.33491 .49513 m .33684 .4953 L .33901 .49587 L F
.316 .717 .979 r
.33684 .4953 m .34085 .49639 L .33901 .49587 L F
0 0 .24 r
.23949 .56031 m .24002 .55991 L .2405 .55682 L F
.897 .598 .472 r
.53167 .42933 m .53392 .43273 L .53178 .43172 L F
.83 .598 .587 r
.53392 .43273 m .53025 .43471 L .53178 .43172 L F
.53392 .43273 m .53379 .43537 L .53025 .43471 L F
.724 .903 .529 r
.43348 .5511 m .4335 .55176 L .4358 .55036 L F
.43348 .5511 m .43206 .55333 L .4335 .55176 L F
.742 .985 .901 r
.62733 .41165 m .62961 .41131 L .62793 .40922 L F
.693 .663 .816 r
.62961 .41131 m .63227 .41018 L .62793 .40922 L F
.312 0 0 r
.3975 .64451 m .39633 .6439 L .395 .64414 L F
.3975 .64451 m .39941 .64526 L .39633 .6439 L F
.789 .323 .131 r
.38972 .65248 m .39204 .65263 L .39107 .65149 L F
0 .018 .587 r
.34798 .60017 m .34762 .60196 L .34632 .59823 L F
.799 .895 .482 r
.34634 .60364 m .34762 .60196 L .34798 .60017 L F
.693 .643 .795 r
.44806 .48361 m .4456 .48442 L .44423 .4811 L F
.448 .705 .977 r
.56754 .41154 m .56909 .41352 L .56625 .41314 L F
.804 .636 .673 r
.30191 .53399 m .29941 .53745 L .3037 .53806 L F
.303 .224 .599 r
.30498 .541 m .3061 .5374 L .3037 .53806 L F
.616 .521 .724 r
.448 .48642 m .44927 .4899 L .44655 .49034 L F
.683 .513 .65 r
.44974 .49274 m .44655 .49034 L .44927 .4899 L F
.44974 .49274 m .44677 .49324 L .44655 .49034 L F
.746 .776 .877 r
.62609 .35534 m .6266 .35864 L .62296 .35797 L F
.775 .747 .828 r
.62296 .35797 m .6266 .35864 L .62449 .35964 L F
.792 .806 .863 r
.62958 .35554 m .6266 .35864 L .62609 .35534 L F
.917 .534 .122 r
.27439 .62056 m .27517 .62304 L .27645 .62399 L F
.766 .915 .536 r
.69583 .28941 m .69468 .2914 L .69495 .29024 L F
.767 .934 .583 r
.69495 .29024 m .69468 .2914 L .69244 .29466 L F
.764 .902 .937 r
.70312 .35349 m .70555 .35214 L .70407 .35077 L F
.865 .992 .744 r
.70155 .35413 m .70312 .35349 L .70407 .35077 L F
.316 .7 .98 r
.29507 .64324 m .29319 .64373 L .2914 .64234 L F
.425 .661 .959 r
.29319 .64373 m .29767 .64518 L .29507 .64324 L F
.538 .476 .734 r
.29507 .64324 m .29325 .64641 L .29319 .64373 L F
.868 .513 .013 r
.61208 .4382 m .61284 .44103 L .61382 .44211 L F
0 0 .332 r
.61284 .44103 m .61431 .44417 L .61382 .44211 L F
.902 .763 .699 r
.70989 .28412 m .71342 .28134 L .70983 .28157 L F
.70989 .28412 m .71149 .28389 L .71342 .28134 L F
.514 .219 .405 r
.71149 .28389 m .71634 .28153 L .71342 .28134 L F
.99 .742 .452 r
.71264 .31336 m .71304 .31595 L .71434 .31455 L F
.791 .711 .776 r
.31393 .66597 m .3155 .66732 L .31175 .66871 L F
.38 0 .035 r
.31175 .66871 m .3155 .66732 L .3141 .6687 L F
.435 .546 .869 r
.31677 .66588 m .3155 .66732 L .31393 .66597 L F
.31677 .66588 m .31823 .66844 L .3155 .66732 L F
.554 0 0 r
.3155 .66732 m .31675 .66872 L .3141 .6687 L F
.3155 .66732 m .31823 .66844 L .31675 .66872 L F
.523 .432 .694 r
.45068 .52842 m .45118 .53109 L .44872 .5317 L F
.928 .916 .784 r
.56401 .40735 m .56548 .40747 L .56506 .40738 L F
.5631 .40709 m .56506 .40738 L .56107 .40651 L F
.56401 .40735 m .56506 .40738 L .5631 .40709 L F
.915 .867 .777 r
.56107 .40651 m .5591 .41042 L .55768 .40876 L F
.127 .551 .921 r
.56247 .40593 m .56401 .40735 L .56107 .40651 L F
.56247 .40593 m .56107 .40651 L .55895 .40766 L F
.584 .883 .992 r
.56247 .40593 m .5608 .40675 L .55768 .4062 L F
.5608 .40675 m .55895 .40766 L .55777 .4063 L F
.5608 .40675 m .55777 .4063 L .55768 .4062 L F
.769 .875 .925 r
.56556 .4056 m .56401 .40735 L .56247 .40593 L F
.56649 .4055 m .56516 .40649 L .56556 .4056 L F
.56516 .40649 m .56401 .40735 L .56556 .4056 L F
.803 .848 .884 r
.56964 .40281 m .56795 .40443 L .56609 .40244 L F
.985 .718 .431 r
.56609 .40244 m .56795 .40443 L .56649 .4055 L F
.803 .848 .884 r
.56964 .40281 m .56609 .40244 L .56729 .40017 L F
.108 .095 .56 r
.56609 .40244 m .56823 .40381 L .56708 .4008 L F
.56609 .40244 m .56649 .4055 L .56823 .40381 L F
0 0 .176 r
.56708 .4008 m .56649 .40352 L .56609 .40244 L F
.64 .091 0 r
.56584 .40585 m .56578 .40568 L .56537 .40578 L F
.56557 .40587 m .56537 .40578 L .56487 .40591 L F
.928 .916 .784 r
.56548 .40747 m .56401 .40735 L .56649 .4055 L F
.769 .875 .925 r
.56568 .40564 m .56247 .40593 L .56406 .40592 L F
.56649 .4055 m .56556 .4056 L .56568 .40564 L F
.56556 .4056 m .56247 .40593 L .56568 .40564 L F
0 0 .176 r
.56649 .40352 m .56599 .40575 L .56597 .40468 L F
.835 .371 .099 r
.56563 .4059 m .56584 .40618 L .56538 .40599 L F
.56584 .40618 m .56589 .40623 L .56565 .40612 L F
.56584 .40618 m .56565 .40612 L .56538 .40599 L F
.899 .754 .692 r
.56538 .40599 m .56565 .40612 L .56592 .40608 L F
.56565 .40612 m .56589 .40623 L .5659 .40618 L F
.759 .433 .433 r
.5659 .40601 m .56589 .40619 L .56563 .4059 L F
.56589 .40619 m .56589 .40623 L .56584 .40618 L F
.56589 .40619 m .56584 .40618 L .56563 .4059 L F
.64 .091 0 r
.56687 .40587 m .56649 .4055 L .5656 .40599 L F
.56687 .40587 m .5656 .40599 L .56548 .40605 L F
0 0 .176 r
.56592 .40608 m .5659 .40618 L .5659 .40601 L F
.5659 .40618 m .56589 .40623 L .56589 .40619 L F
.5659 .40618 m .56589 .40619 L .5659 .40601 L F
.761 .956 .644 r
.56649 .4055 m .56759 .40488 L .56548 .40747 L F
.64 .091 0 r
.56747 .40647 m .56687 .40587 L .56548 .40605 L F
.56745 .40638 m .56598 .40613 L .56736 .40583 L F
0 0 .176 r
.56599 .40575 m .56592 .40608 L .56593 .40573 L F
.56599 .40575 m .56593 .40573 L .56597 .40468 L F
.769 .875 .925 r
.56649 .4055 m .56406 .40592 L .56537 .40578 L F
.759 .433 .433 r
.56609 .40244 m .56591 .40572 L .56238 .40156 L F
.56591 .40572 m .5659 .40601 L .56569 .40575 L F
.56591 .40572 m .56569 .40575 L .56238 .40156 L F
.64 .091 0 r
.56584 .40585 m .56537 .40578 L .56557 .40587 L F
.759 .433 .433 r
.5659 .40601 m .56563 .4059 L .56238 .40156 L F
.835 .371 .099 r
.56238 .40156 m .56563 .4059 L .56349 .40502 L F
.56246 .40439 m .56349 .40502 L .56246 .40459 L F
.56238 .40156 m .56349 .40502 L .56246 .40439 L F
0 0 .176 r
.56649 .40352 m .56597 .40468 L .56609 .40244 L F
.899 .754 .692 r
.56584 .40459 m .56619 .40487 L .56708 .4008 L F
.56538 .40599 m .56619 .40487 L .56584 .40459 L F
.64 .091 0 r
.56548 .40605 m .56584 .40585 L .56573 .40586 L F
.56548 .40605 m .56573 .40586 L .56531 .40602 L F
0 0 .176 r
.56592 .40608 m .5659 .40601 L .56597 .40468 L F
.899 .754 .692 r
.56538 .40599 m .56592 .40608 L .56619 .40487 L F
.64 .091 0 r
.56531 .40602 m .56573 .40586 L .56483 .40592 L F
.835 .371 .099 r
.56563 .4059 m .56538 .40599 L .56258 .40465 L F
.56258 .40464 m .56258 .40465 L .56246 .40459 L F
.56563 .4059 m .56258 .40465 L .56258 .40464 L F
.584 .883 .992 r
.56247 .40593 m .55768 .4062 L .56083 .4046 L F
.301 .691 .976 r
.56483 .40592 m .56247 .40593 L .56083 .4046 L F
.769 .875 .925 r
.56537 .40578 m .56406 .40592 L .56483 .40592 L F
.301 .691 .976 r
.56483 .40592 m .56083 .4046 L .56332 .40474 L F
.453 .013 .112 r
.55977 .40561 m .56258 .40492 L .56083 .4046 L F
.56258 .40492 m .56332 .40474 L .56258 .4047 L F
.56258 .40492 m .56258 .4047 L .56083 .4046 L F
.709 .686 .826 r
.56495 .39988 m .56609 .40244 L .56238 .40156 L F
.322 .462 .846 r
.56708 .4008 m .56609 .40244 L .56495 .39988 L F
.899 .754 .692 r
.56246 .40459 m .56538 .40599 L .56708 .4008 L F
.64 .091 0 r
.56557 .40587 m .56487 .40591 L .5649 .40591 L F
.56584 .40585 m .56649 .4055 L .56578 .40568 L F
.761 .956 .644 r
.56649 .4055 m .56795 .40443 L .56759 .40488 L F
.299 .405 .803 r
.56823 .40381 m .56649 .4055 L .56903 .40597 L F
.421 .699 .979 r
.56548 .40431 m .56736 .40583 L .56496 .40591 L F
.64 .091 0 r
.5649 .40591 m .56487 .40591 L .56483 .40592 L F
.421 .699 .979 r
.56486 .40585 m .56496 .40591 L .56483 .40592 L F
.56548 .40431 m .56496 .40591 L .56486 .40585 L F
.64 .091 0 r
.56598 .40613 m .56531 .40602 L .5663 .40593 L F
.56598 .40613 m .5663 .40593 L .56736 .40583 L F
.56747 .40647 m .56645 .40625 L .56745 .40638 L F
.56645 .40625 m .56531 .40602 L .56745 .40638 L F
.899 .754 .692 r
.56565 .40612 m .5659 .40618 L .56592 .40608 L F
.64 .091 0 r
.56531 .40602 m .56483 .40592 L .56496 .40591 L F
.56531 .40602 m .56496 .40591 L .56736 .40583 L F
.859 .788 .78 r
.34266 .52884 m .34134 .53006 L .3397 .52768 L F
0 0 .399 r
.57844 .40927 m .57954 .41316 L .57954 .41183 L F
0 0 .421 r
.57954 .41183 m .57954 .41316 L .5802 .41438 L F
.194 .61 .946 r
.41524 .49683 m .41567 .49633 L .4132 .49552 L F
.41567 .49633 m .41545 .49579 L .4132 .49552 L F
.688 .542 .682 r
.41524 .49683 m .41573 .50008 L .4182 .49931 L F
.695 .565 .703 r
.41573 .50008 m .41558 .50284 L .4182 .49931 L F
.296 .062 .38 r
.41558 .50284 m .41783 .50237 L .4182 .49931 L F
.531 .256 .443 r
.4182 .49931 m .41783 .50237 L .4207 .50151 L F
.647 .559 .742 r
.4207 .50151 m .41783 .50237 L .41741 .5007 L F
.806 .66 .702 r
.41167 .50214 m .41558 .50284 L .41573 .50008 L F
.654 .141 .01 r
.41324 .50352 m .41558 .50284 L .41167 .50214 L F
.378 .331 .679 r
.41754 .50068 m .41558 .50284 L .41452 .50315 L F
.41754 .50068 m .41452 .50315 L .41705 .501 L F
.41754 .50068 m .41783 .50237 L .41558 .50284 L F
.981 .735 .488 r
.41754 .50068 m .41519 .50039 L .41679 .49818 L F
.701 .901 .537 r
.41324 .50352 m .41519 .50039 L .41754 .50068 L F
.986 .732 .46 r
.41679 .49818 m .41783 .50237 L .41754 .50068 L F
.647 .559 .742 r
.41858 .49971 m .41741 .5007 L .41679 .49818 L F
.4207 .50151 m .41741 .5007 L .41858 .49971 L F
.378 .331 .679 r
.41705 .501 m .41452 .50315 L .41324 .50352 L F
.101 0 0 r
.41679 .49818 m .41759 .49942 L .41771 .49903 L F
.688 .542 .682 r
.41634 .49776 m .4182 .49931 L .41679 .49818 L F
.101 0 0 r
.41679 .49818 m .41771 .49903 L .41823 .49738 L F
.688 .542 .682 r
.41566 .4972 m .41634 .49776 L .41679 .49818 L F
.41524 .49683 m .41583 .49733 L .41566 .4972 L F
.41583 .49733 m .4182 .49931 L .41566 .4972 L F
.796 .727 .788 r
.41513 .49857 m .41032 .4982 L .4132 .49552 L F
.916 .968 .666 r
.41553 .49498 m .4132 .49552 L .41601 .49585 L F
0 0 .24 r
.41685 .49738 m .41711 .49368 L .41553 .49498 L F
.916 .968 .666 r
.41553 .49498 m .41601 .49585 L .41608 .49586 L F
0 0 .24 r
.41679 .49818 m .41685 .49738 L .4161 .49601 L F
.688 .542 .682 r
.41606 .49588 m .41679 .49818 L .41608 .49586 L F
.41524 .49683 m .41679 .49818 L .41606 .49588 L F
0 0 .24 r
.41679 .49818 m .4161 .49601 L .41553 .49498 L F
.916 .968 .666 r
.41553 .49498 m .41513 .49857 L .4132 .49552 L F
.41531 .49693 m .41406 .49849 L .41513 .49857 L F
.41544 .49576 m .41498 .49668 L .41531 .49693 L F
.41498 .49668 m .41406 .49849 L .41531 .49693 L F
.41553 .49498 m .41533 .49546 L .41544 .49576 L F
.41533 .49546 m .41406 .49849 L .41544 .49576 L F
.194 .61 .946 r
.41567 .49633 m .41608 .49586 L .41545 .49579 L F
.558 .172 .265 r
.26137 .56811 m .26582 .56573 L .26334 .56671 L F
.928 .916 .784 r
.56401 .40735 m .56451 .4099 L .56548 .40747 L F
.56548 .40747 m .56451 .4099 L .56401 .40735 L F
.182 .253 .703 r
.33475 .68789 m .336 .69063 L .33342 .68809 L F
0 .416 .78 r
.336 .69063 m .33359 .68987 L .33342 .68809 L F
0 0 0 r
.22442 .56209 m .22394 .56236 L .22547 .56049 L F
.709 .905 .542 r
.22509 .56113 m .22471 .56127 L .22442 .56209 L F
.22623 .55951 m .22471 .56127 L .22509 .56113 L F
.883 .576 .066 r
.2241 .56001 m .22453 .56134 L .22471 .56127 L F
.448 .788 .998 r
.22485 .56185 m .22442 .56209 L .22471 .56127 L F
.2254 .56404 m .22442 .56209 L .22485 .56185 L F
.883 .576 .066 r
.22453 .56134 m .2254 .56404 L .22471 .56127 L F
0 0 0 r
.22442 .56209 m .2226 .56399 L .22394 .56236 L F
.542 .379 .61 r
.35704 .59784 m .35905 .59865 L .35941 .5954 L F
.35704 .59784 m .35905 .59865 L .35941 .5954 L F
.628 .49 .675 r
.44023 .47955 m .43756 .48059 L .43996 .4773 L F
.442 .248 .521 r
.60622 .3713 m .60634 .36875 L .60859 .36965 L F
.104 .037 .489 r
.26636 .57455 m .26472 .573 L .26706 .57247 L F
.26636 .57455 m .26497 .57615 L .26472 .573 L F
.586 .403 .601 r
.33444 .57612 m .33192 .57937 L .33202 .57653 L F
.942 .772 .642 r
.40517 .66597 m .40289 .66481 L .40393 .66834 L F
.446 .121 .32 r
.46248 .57963 m .46211 .58163 L .4594 .58211 L F
.518 .183 .339 r
.46248 .57963 m .46476 .58129 L .46211 .58163 L F
.528 .177 .316 r
.46248 .57963 m .46535 .57974 L .46476 .58129 L F
0 .124 .581 r
.2422 .62081 m .24048 .61946 L .24058 .61946 L F
.2422 .62081 m .24258 .62109 L .24048 .61946 L F
.865 .927 .865 r
.70513 .29574 m .70898 .2941 L .70832 .29318 L F
0 0 0 r
.40406 .4941 m .40159 .49697 L .40318 .49563 L F
.575 .562 .802 r
.40198 .48856 m .40406 .4941 L .4063 .49292 L F
.738 .986 .778 r
.40318 .49563 m .4063 .49292 L .40406 .4941 L F
.786 .788 .854 r
.64683 .35859 m .65053 .35892 L .64978 .35568 L F
.815 .726 .767 r
.64799 .36229 m .65053 .35892 L .64683 .35859 L F
.759 .772 .863 r
.64978 .35568 m .65053 .35892 L .65328 .35588 L F
.978 .686 .312 r
.61513 .42565 m .61658 .42967 L .61529 .42814 L F
.994 .747 .418 r
.61529 .42814 m .61658 .42967 L .61528 .43058 L F
.802 .454 0 r
.23884 .53983 m .24051 .54362 L .2398 .54151 L F
.524 .299 .516 r
.31376 .61471 m .31356 .61734 L .311 .61774 L F
.586 .347 .521 r
.31643 .61446 m .31356 .61734 L .31376 .61471 L F
.942 .842 .404 r
.32274 .66225 m .32311 .65946 L .32353 .65944 L F
.121 .205 .678 r
.61355 .39131 m .61298 .38722 L .61331 .38965 L F
0 0 .568 r
.61434 .39244 m .61355 .39131 L .61331 .38965 L F
.721 .754 .878 r
.73334 .34224 m .73625 .34234 L .73525 .3393 L F
.76 .601 .681 r
.73428 .34612 m .73625 .34234 L .73334 .34224 L F
.746 .911 .949 r
.73625 .34234 m .73876 .33867 L .73525 .3393 L F
.73625 .34234 m .7397 .34002 L .73876 .33867 L F
.131 0 0 r
.26044 .54339 m .26324 .54292 L .26469 .54186 L F
0 0 .045 r
.26392 .54645 m .26434 .54493 L .26447 .54295 L F
.26392 .54645 m .26452 .5426 L .26449 .54256 L F
.763 .883 .932 r
.26212 .54814 m .26589 .54769 L .26392 .54645 L F
.782 .863 .909 r
.26392 .54645 m .26589 .54769 L .26839 .54503 L F
.669 .497 .643 r
.26044 .54339 m .26392 .54645 L .26324 .54292 L F
.26044 .54339 m .26119 .54773 L .26392 .54645 L F
.782 .863 .909 r
.26392 .54645 m .26689 .54551 L .2661 .54532 L F
.26689 .54551 m .26839 .54503 L .2661 .54532 L F
.239 0 0 r
.27051 .54602 m .26874 .54586 L .2661 .54532 L F
.28 0 0 r
.26874 .54586 m .2652 .54511 L .2661 .54532 L F
.2652 .54511 m .26434 .54493 L .2661 .54532 L F
.763 .809 .89 r
.26119 .54773 m .26212 .54814 L .26392 .54645 L F
.618 .919 .977 r
.2661 .54532 m .26434 .54493 L .26392 .54645 L F
.438 .858 .715 r
.26324 .54292 m .26436 .54235 L .26425 .54219 L F
.26436 .54235 m .26684 .54105 L .26425 .54219 L F
.26666 .54115 m .26457 .54205 L .26684 .54105 L F
.26324 .54292 m .26457 .54205 L .26666 .54115 L F
0 0 .045 r
.26392 .54645 m .26457 .54205 L .26324 .54292 L F
.26447 .54295 m .26434 .54493 L .26452 .5426 L F
.26449 .54256 m .26452 .5426 L .26457 .54205 L F
.429 .485 .816 r
.26434 .54493 m .26347 .54252 L .26457 .54205 L F
.26347 .54252 m .26292 .54098 L .26457 .54205 L F
.398 .196 .485 r
.26219 .54793 m .26417 .54743 L .26434 .54493 L F
.26417 .54743 m .26432 .54739 L .26434 .54493 L F
.438 .858 .715 r
.26425 .54219 m .26684 .54105 L .26469 .54186 L F
0 .416 .78 r
.336 .69063 m .33702 .6913 L .33359 .68987 L F
0 0 .39 r
.33493 .6933 m .33359 .68987 L .33702 .6913 L F
.33493 .6933 m .33446 .69454 L .33359 .68987 L F
.212 0 0 r
.36426 .53274 m .36175 .53251 L .36466 .53184 L F
.999 .841 .542 r
.34216 .50525 m .34147 .50799 L .34288 .50749 L F
.972 .668 .377 r
.34147 .50799 m .34186 .51054 L .34288 .50749 L F
.186 0 .112 r
.34288 .50749 m .34186 .51054 L .34564 .50912 L F
.577 .904 .656 r
.40331 .67534 m .40291 .67521 L .40246 .6779 L F
.40331 .67534 m .40446 .67399 L .40291 .67521 L F
.529 .469 .734 r
.28281 .6276 m .28623 .63008 L .28518 .62682 L F
.28281 .6276 m .28391 .63075 L .28623 .63008 L F
.458 .037 .152 r
.43923 .59589 m .44141 .59716 L .43881 .59714 L F
.825 .831 .852 r
.68523 .3046 m .68236 .30774 L .68073 .30616 L F
.793 .8 .857 r
.66264 .35049 m .66473 .34888 L .66095 .34861 L F
.526 .769 .986 r
.57411 .41988 m .57631 .41955 L .5754 .41798 L F
.178 0 .228 r
.33377 .68107 m .33463 .67881 L .33189 .68203 L F
.078 0 .176 r
.33639 .67776 m .33463 .67881 L .33377 .68107 L F
0 0 0 r
.40159 .49697 m .40192 .49705 L .40318 .49563 L F
.6132 .44841 m .61298 .4502 L .61288 .45014 L F
.61389 .44664 m .61298 .4502 L .6132 .44841 L F
.821 .751 .785 r
.35817 .68758 m .35671 .69112 L .35336 .68735 L F
.089 .575 .902 r
.61714 .39305 m .61821 .39392 L .61434 .39244 L F
.538 .578 .843 r
.6203 .39017 m .61821 .39392 L .61714 .39305 L F
.6203 .39017 m .62138 .39399 L .61821 .39392 L F
.56 .062 .03 r
.38422 .58889 m .38801 .58885 L .38639 .58808 L F
.3 .628 .962 r
.38801 .58885 m .38885 .58751 L .38639 .58808 L F
.38801 .58885 m .39029 .58923 L .38885 .58751 L F
.943 .691 .525 r
.53178 .43172 m .52928 .42793 L .53167 .42933 L F
.381 .141 .42 r
.34448 .55725 m .34442 .5594 L .34678 .5566 L F
.388 .155 .436 r
.34448 .55725 m .34678 .5566 L .34709 .55404 L F
.381 .141 .42 r
.34448 .55725 m .34442 .5594 L .34678 .5566 L F
.839 .811 .824 r
.39124 .69205 m .39183 .68752 L .39024 .69072 L F
.39124 .69205 m .39344 .68924 L .39183 .68752 L F
.983 .702 .336 r
.37404 .54654 m .37536 .55005 L .37518 .54765 L F
.468 .739 .987 r
.37518 .54765 m .37649 .54594 L .37404 .54654 L F
.884 .74 .696 r
.70184 .30056 m .70562 .3013 L .70363 .29823 L F
.729 .42 .457 r
.70101 .30344 m .70562 .3013 L .70184 .30056 L F
.70101 .30344 m .70615 .30347 L .70562 .3013 L F
.92 .742 .253 r
.70562 .3013 m .70513 .29574 L .70363 .29823 L F
.933 .556 .19 r
.70615 .30347 m .70643 .30409 L .70562 .3013 L F
.901 .951 .825 r
.61561 .38485 m .61487 .38588 L .61298 .38722 L F
.529 .148 .262 r
.61298 .38722 m .61487 .38588 L .61631 .38748 L F
.08 0 0 r
.61561 .38485 m .61773 .38502 L .61487 .38588 L F
.2 .119 .534 r
.61631 .38748 m .61487 .38588 L .61773 .38502 L F
.946 .617 .375 r
.3816 .62354 m .38376 .62779 L .37942 .62649 L F
.88 .702 .657 r
.38376 .62779 m .38001 .63023 L .37942 .62649 L F
.38376 .62779 m .38322 .63067 L .38001 .63023 L F
.115 0 .42 r
.38473 .62873 m .38322 .63067 L .38376 .62779 L F
.736 .453 .501 r
.36631 .52164 m .36439 .52045 L .36726 .51925 L F
.754 .971 .697 r
.2447 .52548 m .24439 .52653 L .2419 .52497 L F
.292 .79 .827 r
.24213 .52609 m .2447 .52548 L .2419 .52497 L F
.563 .936 .888 r
.2447 .52548 m .24323 .52553 L .24498 .52453 L F
.2447 .52548 m .24498 .52453 L .24536 .52432 L F
.754 .971 .697 r
.2447 .52548 m .24462 .52667 L .24439 .52653 L F
.2447 .52548 m .24303 .52749 L .24462 .52667 L F
.994 .748 .416 r
.4194 .51087 m .41985 .51376 L .42123 .51178 L F
.292 .647 .968 r
.42123 .51178 m .42194 .5104 L .4194 .51087 L F
.42123 .51178 m .42287 .51144 L .42194 .5104 L F
.994 .748 .416 r
.4194 .51087 m .4193 .51376 L .41985 .51376 L F
.977 .719 .475 r
.4194 .51087 m .41932 .51316 L .42123 .51178 L F
.87 .995 .782 r
.42006 .5136 m .42194 .5104 L .42287 .51144 L F
.41985 .51376 m .41998 .51355 L .42006 .5136 L F
.41998 .51355 m .42194 .5104 L .42006 .5136 L F
.977 .719 .475 r
.41932 .51316 m .4193 .51376 L .41968 .51337 L F
.41932 .51316 m .41968 .51337 L .42123 .51178 L F
.401 .226 .526 r
.38463 .58614 m .38422 .58889 L .38639 .58808 L F
.021 0 .078 r
.73017 .34309 m .72781 .34599 L .72999 .34557 L F
.854 .871 .852 r
.72871 .34145 m .73017 .34309 L .7326 .33972 L F
.669 .577 .743 r
.73017 .34309 m .73334 .34224 L .7326 .33972 L F
.716 .574 .695 r
.72999 .34557 m .73334 .34224 L .73017 .34309 L F
.491 .838 .566 r
.34388 .69137 m .34092 .6939 L .34352 .69415 L F
.886 .99 .788 r
.34617 .68811 m .34388 .69137 L .34288 .69084 L F
.991 .802 .421 r
.34288 .69084 m .34388 .69137 L .34352 .69415 L F
.946 .959 .7 r
.68649 .29985 m .68711 .30109 L .68523 .3046 L F
.883 .931 .847 r
.68879 .29644 m .68711 .30109 L .68649 .29985 L F
.68879 .29644 m .68976 .29786 L .68711 .30109 L F
.381 .84 .777 r
.65411 .391 m .65095 .39236 L .64997 .39245 L F
.793 .535 .549 r
.70603 .28345 m .70983 .28157 L .70708 .28246 L F
.701 .834 .946 r
.71685 .32718 m .71324 .32691 L .71574 .32554 L F
.765 .545 .6 r
.71685 .32718 m .71297 .32916 L .71324 .32691 L F
.71685 .32718 m .71488 .32958 L .71297 .32916 L F
.531 .75 .976 r
.7184 .32501 m .71685 .32718 L .71574 .32554 L F
.055 0 .027 r
.71872 .32759 m .71685 .32718 L .7184 .32501 L F
.71872 .32759 m .71488 .32958 L .71685 .32718 L F
.028 0 0 r
.33377 .68107 m .33189 .68203 L .33049 .68454 L F
.59 .598 .829 r
.72519 .33632 m .72286 .33772 L .72054 .33324 L F
.244 0 .279 r
.72209 .34029 m .72286 .33772 L .72519 .33632 L F
.333 .231 .587 r
.32683 .56674 m .32868 .56595 L .32821 .56324 L F
.128 0 .396 r
.32683 .56674 m .32812 .56839 L .32868 .56595 L F
.32683 .56674 m .32664 .56934 L .32812 .56839 L F
.797 .6 .635 r
.54646 .45811 m .54805 .45758 L .54612 .46076 L F
0 .226 .738 r
.34265 .70351 m .34423 .70693 L .3449 .70549 L F
.106 .371 .833 r
.3449 .70549 m .34423 .70693 L .34571 .70746 L F
.695 .253 .198 r
.38695 .61746 m .39102 .61799 L .38954 .61973 L F
.821 .681 .708 r
.30684 .63022 m .30392 .63332 L .30355 .63113 L F
.846 .878 .864 r
.6552 .33628 m .65219 .33639 L .6538 .33473 L F
.832 .87 .873 r
.65807 .33326 m .6552 .33628 L .6538 .33473 L F
.177 0 .213 r
.42835 .54492 m .42715 .54773 L .42594 .54736 L F
.058 .103 .594 r
.42715 .54773 m .42762 .54962 L .42594 .54736 L F
.166 .134 .574 r
.42594 .54736 m .42762 .54962 L .42631 .54991 L F
.724 .937 .956 r
.3822 .56599 m .38023 .5675 L .38046 .56515 L F
0 0 0 r
.71966 .34259 m .71957 .34278 L .71964 .34191 L F
.636 .711 .901 r
.71964 .34191 m .72287 .34083 L .72209 .34029 L F
0 .471 .765 r
.71774 .34188 m .71966 .34259 L .72043 .34105 L F
.71819 .34167 m .72043 .34105 L .72071 .34051 L F
.472 .495 .801 r
.7167 .33774 m .71811 .3417 L .71908 .33734 L F
0 .471 .765 r
.71797 .34181 m .72043 .34105 L .71807 .34173 L F
.472 .495 .801 r
.71811 .3417 m .71816 .34183 L .7182 .34162 L F
.71811 .3417 m .7182 .34162 L .71908 .33734 L F
0 .471 .765 r
.71807 .34173 m .72043 .34105 L .71819 .34167 L F
.71774 .34188 m .71797 .34181 L .71807 .34173 L F
.751 .655 .755 r
.71432 .33938 m .718 .34173 L .7167 .33774 L F
.718 .34173 m .71816 .34183 L .71811 .3417 L F
.718 .34173 m .71811 .3417 L .7167 .33774 L F
0 .471 .765 r
.71774 .34188 m .71972 .34247 L .71966 .34259 L F
.786 .988 .744 r
.72287 .34083 m .71936 .34428 L .72232 .34291 L F
.711 .686 .146 r
.71936 .34428 m .71951 .34359 L .71966 .34259 L F
.276 0 0 r
.71966 .34259 m .72232 .34291 L .71936 .34428 L F
.71966 .34259 m .7218 .34308 L .72232 .34291 L F
0 .471 .765 r
.71972 .34247 m .7218 .34308 L .71966 .34259 L F
0 0 0 r
.71966 .34259 m .71951 .34359 L .71957 .34278 L F
.855 .879 .856 r
.67735 .31431 m .67319 .31603 L .67617 .31291 L F
.653 .21 .185 r
.34709 .55404 m .34539 .55016 L .3434 .55362 L F
.832 .784 .806 r
.34226 .55603 m .34709 .55404 L .3434 .55362 L F
.366 .138 .43 r
.34709 .55404 m .34678 .5566 L .34929 .55331 L F
0 0 .034 r
.28007 .62894 m .27972 .63017 L .27977 .62936 L F
.28007 .62894 m .27977 .62936 L .27989 .62747 L F
0 .28 .663 r
.28038 .62851 m .28007 .62894 L .27963 .62761 L F
.28108 .62935 m .28007 .62894 L .28038 .62851 L F
0 0 .034 r
.28007 .62894 m .27989 .62747 L .27804 .62663 L F
.839 .746 .761 r
.62385 .39056 m .62747 .39035 L .62609 .387 L F
.656 .164 .071 r
.55634 .46435 m .5603 .46496 L .55889 .46621 L F
.712 .236 .117 r
.5603 .46496 m .563 .46716 L .55889 .46621 L F
0 0 0 r
.31607 .63078 m .31526 .63166 L .31384 .63343 L F
.503 .272 .497 r
.56649 .43243 m .56963 .43224 L .57001 .4322 L F
.776 .876 .92 r
.57171 .42864 m .57001 .4322 L .57133 .42969 L F
.78 .945 .604 r
.57001 .4322 m .56963 .43224 L .57133 .42969 L F
.951 .805 .359 r
.40195 .65302 m .40184 .64948 L .40142 .65202 L F
.444 .575 .891 r
.39528 .68506 m .39179 .68248 L .39424 .68186 L F
.805 .668 .712 r
.53645 .4458 m .53617 .44875 L .53239 .44768 L F
.821 .52 .481 r
.53239 .44768 m .53617 .44875 L .5363 .45084 L F
0 .128 .639 r
.28419 .64659 m .28416 .64606 L .28298 .64499 L F
.28419 .64659 m .2867 .64873 L .28416 .64606 L F
.584 .287 .431 r
.5986 .45809 m .59557 .46044 L .59565 .45816 L F
0 0 .475 r
.41235 .55694 m .41257 .55571 L .41111 .5525 L F
0 0 .516 r
.41235 .55694 m .41374 .5594 L .41257 .55571 L F
.822 .982 .885 r
.70806 .33805 m .70708 .34071 L .70584 .33963 L F
.70806 .33805 m .70864 .33909 L .70708 .34071 L F
.878 .844 .383 r
.34451 .57307 m .34368 .57519 L .3442 .57381 L F
.757 .731 .828 r
.58022 .40652 m .58444 .40696 L .58157 .40862 L F
.325 0 .251 r
.30921 .55316 m .31233 .55034 L .31027 .55094 L F
.30921 .55316 m .3115 .55274 L .31233 .55034 L F
.484 .342 .612 r
.31233 .55034 m .31483 .54722 L .31163 .54654 L F
.31233 .55034 m .31505 .54982 L .31483 .54722 L F
.372 .043 .271 r
.3115 .55274 m .31505 .54982 L .31233 .55034 L F
.679 .386 0 r
.41578 .58823 m .41467 .58458 L .4155 .58581 L F
.49 .104 .234 r
.58404 .46393 m .58274 .46643 L .57999 .46658 L F
.4 0 .051 r
.58664 .46441 m .58274 .46643 L .58404 .46393 L F
.807 .86 .888 r
.37932 .62161 m .3816 .62354 L .378 .62345 L F
.864 .667 .634 r
.378 .62345 m .3816 .62354 L .37942 .62649 L F
.811 .86 .885 r
.38436 .62055 m .3816 .62354 L .37932 .62161 L F
.898 .974 .815 r
.39019 .64494 m .38515 .64881 L .38832 .64799 L F
.044 .61 .772 r
.39083 .64477 m .3925 .64496 L .39019 .64494 L F
.667 .831 .962 r
.38832 .64799 m .39083 .64477 L .39019 .64494 L F
.962 .771 .598 r
.5708 .41267 m .5731 .4136 L .56909 .41352 L F
.5708 .41267 m .57273 .41669 L .5731 .4136 L F
.765 .79 .874 r
.57134 .41199 m .5731 .4136 L .57607 .40974 L F
.701 .781 .913 r
.62449 .35964 m .6209 .35897 L .62296 .35797 L F
.733 .805 .909 r
.42735 .47775 m .42293 .47754 L .42558 .47639 L F
0 0 .374 r
.32298 .51986 m .32383 .52008 L .32527 .51904 L F
.331 0 .183 r
.35192 .55275 m .35521 .55011 L .35284 .55054 L F
.548 .318 .518 r
.32029 .61024 m .31935 .61408 L .31643 .61446 L F
.459 .496 .809 r
.32113 .60776 m .32029 .61024 L .31865 .60838 L F
.32113 .60776 m .32131 .60985 L .32029 .61024 L F
.395 .189 .478 r
.32131 .60985 m .31935 .61408 L .32029 .61024 L F
.059 .624 .725 r
.31823 .66844 m .3217 .66826 L .32074 .66828 L F
.398 .112 .359 r
.4684 .57605 m .468 .57891 L .46535 .57974 L F
.27 .124 .491 r
.47131 .57628 m .47133 .57644 L .47114 .57641 L F
.26 .001 .319 r
.46999 .5778 m .4684 .57605 L .47133 .57644 L F
.472 .261 .511 r
.47072 .57181 m .47274 .57467 L .47133 .57644 L F
.551 .361 .578 r
.47274 .57467 m .46999 .5778 L .47133 .57644 L F
0 0 0 r
.47162 .57665 m .46999 .5778 L .47135 .57625 L F
.47222 .57559 m .47135 .57625 L .47274 .57467 L F
.47162 .57665 m .47135 .57625 L .47222 .57559 L F
.27 .124 .491 r
.47072 .57181 m .47131 .57628 L .4684 .57605 L F
.47131 .57628 m .47114 .57641 L .4684 .57605 L F
.26 .001 .319 r
.46999 .5778 m .468 .57891 L .4684 .57605 L F
.495 .354 .619 r
.32329 .64342 m .32416 .64575 L .32565 .64301 L F
.496 .899 .783 r
.33032 .69643 m .33446 .69454 L .33302 .69716 L F
.021 .345 .824 r
.33493 .6933 m .33652 .69573 L .33446 .69454 L F
.075 .056 .529 r
.62338 .43505 m .62385 .43792 L .62235 .43904 L F
0 0 0 r
.62385 .43792 m .62209 .44205 L .62235 .43904 L F
.499 .35 .61 r
.44795 .49948 m .44815 .50221 L .44568 .50286 L F
.485 .31 .568 r
.44568 .50286 m .44815 .50221 L .44571 .5054 L F
0 .126 .674 r
.32349 .69165 m .32529 .69268 L .32426 .6911 L F
.601 .176 0 r
.32426 .6911 m .32529 .69268 L .32448 .69143 L F
0 0 .525 r
.32259 .68849 m .32349 .69165 L .32426 .6911 L F
.601 .176 0 r
.32426 .6911 m .32448 .69143 L .32301 .68919 L F
0 0 .525 r
.3224 .68785 m .32259 .68849 L .32426 .6911 L F
0 .126 .674 r
.32349 .69165 m .32524 .69425 L .32529 .69268 L F
.849 .684 .677 r
.53523 .44185 m .53645 .4458 L .53536 .44438 L F
.805 .668 .712 r
.53645 .4458 m .53239 .44768 L .53536 .44438 L F
.343 .548 .908 r
.30776 .55836 m .30856 .55635 L .30619 .5563 L F
.30776 .55836 m .31036 .55818 L .30856 .55635 L F
.996 .822 .466 r
.41633 .59198 m .41525 .59098 L .41578 .58823 L F
.954 .606 .279 r
.41633 .59198 m .41535 .59405 L .41525 .59098 L F
.41633 .59198 m .41736 .59612 L .41535 .59405 L F
0 0 0 r
.33762 .50943 m .33861 .50801 L .33937 .50493 L F
.546 .155 .251 r
.33705 .51076 m .33941 .51105 L .33762 .50943 L F
.712 .21 0 r
.37466 .63995 m .37174 .63683 L .3741 .63932 L F
.876 .882 .835 r
.37008 .64127 m .37466 .63995 L .3741 .63932 L F
0 0 0 r
.21972 .55067 m .22102 .5496 L .22207 .54732 L F
.21972 .55067 m .21836 .55256 L .22102 .5496 L F
.857 .442 0 r
.60181 .41659 m .59939 .4125 L .60002 .41509 L F
.955 .622 .344 r
.60009 .41739 m .60181 .41659 L .60002 .41509 L F
.60009 .41739 m .60227 .41959 L .60181 .41659 L F
.718 .198 0 r
.2893 .65626 m .28973 .65788 L .2871 .65544 L F
.2893 .65626 m .29164 .65894 L .28973 .65788 L F
0 .171 .64 r
.3371 .51424 m .33695 .51415 L .33507 .5131 L F
.493 0 0 r
.57171 .42864 m .57533 .42627 L .57343 .4259 L F
.57171 .42864 m .57562 .42897 L .57533 .42627 L F
.476 .308 .574 r
.57533 .42627 m .57777 .42741 L .57808 .42559 L F
.57533 .42627 m .57562 .42897 L .57777 .42741 L F
.301 .009 .29 r
.57892 .42315 m .57533 .42627 L .57808 .42559 L F
.82 .739 .774 r
.64199 .3651 m .64541 .36554 L .64432 .36179 L F
.8 .728 .785 r
.64541 .36554 m .64799 .36229 L .64432 .36179 L F
.838 .731 .745 r
.38353 .50372 m .37946 .50481 L .38132 .50195 L F
.38353 .50372 m .38195 .50664 L .37946 .50481 L F
.588 .848 .994 r
.38394 .50204 m .38263 .50299 L .38132 .50195 L F
.676 .174 .043 r
.37962 .50073 m .38394 .50204 L .38132 .50195 L F
.923 .869 .768 r
.38132 .50195 m .378 .50352 L .37962 .50073 L F
.38016 .5025 m .37946 .50481 L .378 .50352 L F
.38132 .50195 m .38041 .50335 L .38016 .5025 L F
.38041 .50335 m .37946 .50481 L .38016 .5025 L F
.676 .174 .043 r
.37962 .50073 m .37965 .50075 L .37966 .50074 L F
.38127 .50123 m .38211 .5029 L .38394 .50204 L F
0 .224 .739 r
.38047 .49962 m .38211 .5029 L .37965 .50075 L F
.37963 .50071 m .37965 .50075 L .37962 .50073 L F
.38047 .49962 m .37965 .50075 L .37963 .50071 L F
.44 .288 .577 r
.38495 .50129 m .38394 .50204 L .38211 .5029 L F
.38637 .50049 m .38394 .50204 L .38495 .50129 L F
.588 .848 .994 r
.38394 .50204 m .38353 .50372 L .38263 .50299 L F
.38394 .50204 m .38541 .50327 L .38353 .50372 L F
.646 .147 .05 r
.34029 .70041 m .34223 .70096 L .33827 .70044 L F
.544 .816 .996 r
.64605 .40072 m .64962 .40149 L .64858 .39938 L F
.863 .448 0 r
.64962 .40149 m .649 .40215 L .64858 .39938 L F
.64962 .40149 m .65058 .40369 L .649 .40215 L F
0 0 0 r
.40282 .65924 m .40203 .66092 L .40165 .66084 L F
.182 .34 .788 r
.40163 .65626 m .40439 .65802 L .40282 .65924 L F
.864 .876 .844 r
.40203 .66092 m .40439 .65802 L .40256 .657 L F
.698 .473 0 r
.4022 .65975 m .40242 .661 L .40203 .66092 L F
.40242 .661 m .40273 .66284 L .40203 .66092 L F
0 0 0 r
.40165 .66084 m .40203 .66092 L .4003 .66269 L F
0 .346 .813 r
.2786 .63734 m .27896 .6366 L .27714 .63588 L F
.2786 .63734 m .28156 .6391 L .27896 .6366 L F
.636 .481 .656 r
.33644 .58933 m .33818 .59195 L .33537 .59119 L F
.212 .083 .478 r
.33909 .58768 m .33644 .58933 L .33755 .58582 L F
.077 .245 .734 r
.33914 .59066 m .33644 .58933 L .33909 .58768 L F
.33914 .59066 m .33818 .59195 L .33644 .58933 L F
.967 .708 .491 r
.2377 .56553 m .23785 .56832 L .23995 .56729 L F
.37 0 0 r
.23995 .56729 m .23785 .56832 L .24181 .56813 L F
.334 0 .092 r
.23995 .56729 m .24181 .56813 L .24248 .5667 L F
.786 .985 .899 r
.2773 .52246 m .27734 .52424 L .27976 .52351 L F
.2773 .52246 m .27558 .5241 L .27734 .52424 L F
.268 .485 .883 r
.3361 .50231 m .33723 .50068 L .33404 .50128 L F
.3361 .50231 m .3383 .50318 L .33723 .50068 L F
0 0 .002 r
.37536 .55005 m .37456 .55267 L .3726 .5543 L F
0 0 .255 r
.37398 .55441 m .3726 .5543 L .37456 .55267 L F
.37398 .55441 m .37281 .55633 L .3726 .5543 L F
.592 .341 .505 r
.71122 .32641 m .71239 .32869 L .707 .32982 L F
.475 .458 .76 r
.71232 .32263 m .71324 .32691 L .71122 .32641 L F
.844 .683 .683 r
.71324 .32691 m .71239 .32869 L .71122 .32641 L F
.396 .179 .463 r
.31068 .60177 m .30819 .60502 L .31034 .60435 L F
.425 .153 .396 r
.30819 .60502 m .31021 .60667 L .31034 .60435 L F
.30819 .60502 m .30764 .60741 L .31021 .60667 L F
.746 .609 .705 r
.36913 .62434 m .37204 .62037 L .36768 .62134 L F
.82 .676 .703 r
.65059 .41946 m .65414 .41994 L .65258 .41608 L F
.786 .678 .745 r
.64955 .42195 m .65414 .41994 L .65059 .41946 L F
.64955 .42195 m .65189 .42355 L .65414 .41994 L F
.618 .735 .93 r
.70555 .35214 m .70728 .34827 L .70407 .35077 L F
.70555 .35214 m .70959 .35147 L .70728 .34827 L F
.454 .59 .898 r
.72122 .35189 m .72334 .35157 L .72172 .34914 L F
.363 .754 .987 r
.72253 .35122 m .72334 .35157 L .72122 .35189 L F
.896 .498 .253 r
.72253 .35122 m .72309 .35187 L .72334 .35157 L F
.717 .883 .488 r
.72235 .35375 m .72478 .34986 L .72334 .35157 L F
.72235 .35375 m .72334 .35157 L .72122 .35189 L F
.397 .643 .956 r
.72446 .35344 m .72122 .35189 L .72334 .35157 L F
0 0 .376 r
.72457 .35359 m .72446 .35344 L .72334 .35157 L F
.896 .498 .253 r
.72309 .35187 m .72457 .35359 L .72334 .35157 L F
.717 .883 .488 r
.72478 .34986 m .72501 .34948 L .72334 .35157 L F
.76 .962 .662 r
.72501 .34948 m .72781 .34599 L .72609 .34728 L F
.709 .88 .486 r
.72334 .35157 m .72501 .34948 L .72609 .34728 L F
.825 .571 .556 r
.69052 .31413 m .69367 .3183 L .6937 .31721 L F
.224 .112 .509 r
.69367 .3183 m .69384 .31975 L .6937 .31721 L F
.303 .224 .599 r
.30498 .541 m .30626 .54042 L .3061 .5374 L F
.286 0 0 r
.30225 .54298 m .30626 .54042 L .30498 .541 L F
.38 .085 .333 r
.24241 .55053 m .24368 .55385 L .24638 .55034 L F
.24241 .55053 m .24398 .55203 L .24368 .55385 L F
.15 .129 .578 r
.24383 .55475 m .24543 .5564 L .24368 .55385 L F
.24383 .55475 m .24368 .55385 L .24398 .55203 L F
.454 .519 .835 r
.24594 .62328 m .24654 .61996 L .24258 .62109 L F
.24594 .62328 m .24812 .62351 L .24654 .61996 L F
.56 .542 .792 r
.45811 .54959 m .45683 .55401 L .4561 .55005 L F
.45811 .54959 m .45929 .55343 L .45683 .55401 L F
.114 0 0 r
.33827 .70044 m .34223 .70096 L .34064 .70078 L F
0 0 .409 r
.34223 .70096 m .34265 .70351 L .3436 .70209 L F
.34223 .70096 m .3436 .70209 L .34064 .70078 L F
.856 .584 .049 r
.3633 .58842 m .36358 .58845 L .36279 .58519 L F
.233 .151 .554 r
.36465 .5868 m .3633 .58842 L .36279 .58519 L F
.654 .925 .638 r
.363 .58839 m .3633 .58842 L .36465 .5868 L F
.36117 .59016 m .3633 .58842 L .363 .58839 L F
.856 .584 .049 r
.3633 .58842 m .36426 .59122 L .36358 .58845 L F
0 0 .418 r
.3633 .58842 m .36459 .59162 L .36426 .59122 L F
0 0 0 r
.31928 .58229 m .31806 .58617 L .31838 .5853 L F
0 0 .078 r
.31806 .58617 m .31893 .58707 L .31838 .5853 L F
.31806 .58617 m .31705 .5885 L .31893 .58707 L F
.509 .288 .515 r
.37216 .59268 m .3741 .59445 L .37471 .59182 L F
.715 .665 .799 r
.5591 .41042 m .55583 .41309 L .55447 .40927 L F
.55 .377 .599 r
.5591 .41042 m .55762 .41271 L .55583 .41309 L F
.715 .526 .633 r
.55762 .41271 m .55574 .41576 L .55583 .41309 L F
.571 .356 .55 r
.54104 .39101 m .54111 .39378 L .54405 .39081 L F
.636 .653 .85 r
.35524 .67862 m .35513 .6819 L .35372 .67834 L F
.35524 .67862 m .35815 .68133 L .35513 .6819 L F
.777 .805 .875 r
.63889 .34984 m .6354 .34991 L .63722 .34817 L F
.808 .816 .857 r
.64182 .34709 m .63889 .34984 L .63722 .34817 L F
.81 1 .828 r
.69699 .28702 m .6978 .28763 L .69583 .28941 L F
.639 .96 .92 r
.70076 .2858 m .6978 .28763 L .69699 .28702 L F
.534 .659 .917 r
.29082 .66257 m .29332 .6624 L .29239 .66 L F
.29082 .66257 m .29332 .6624 L .29239 .66 L F
.116 .117 .581 r
.29164 .65894 m .29082 .66257 L .29239 .66 L F
.728 .852 .94 r
.66095 .34861 m .66473 .34888 L .66333 .34723 L F
.855 .879 .856 r
.66333 .34723 m .66473 .34888 L .66732 .34576 L F
.657 .627 .808 r
.71095 .3621 m .71222 .36615 L .71481 .36501 L F
.884 .768 .729 r
.68696 .31622 m .68804 .31992 L .68795 .31734 L F
.888 .96 .838 r
.68696 .31622 m .68795 .31734 L .69052 .31413 L F
.682 .558 .709 r
.68795 .31734 m .69367 .3183 L .69052 .31413 L F
.718 .515 .614 r
.68804 .31992 m .69367 .3183 L .68795 .31734 L F
.844 .939 .887 r
.35174 .71652 m .35483 .71529 L .35415 .71306 L F
.439 .858 .952 r
.35483 .71529 m .35757 .7142 L .35415 .71306 L F
.35483 .71529 m .35803 .71459 L .35757 .7142 L F
.459 .273 .541 r
.29581 .62445 m .29824 .62384 L .29835 .62088 L F
.234 0 .012 r
.29581 .62445 m .29418 .6265 L .29824 .62384 L F
.296 0 .005 r
.22555 .59748 m .2186 .60057 L .22102 .59916 L F
.923 .696 .577 r
.39195 .59227 m .389 .59361 L .39083 .59205 L F
.39195 .59227 m .39177 .59623 L .389 .59361 L F
.834 .997 .839 r
.3928 .5893 m .39195 .59227 L .39083 .59205 L F
.264 0 .227 r
.39022 .60208 m .39217 .6013 L .39335 .59866 L F
.023 .202 .71 r
.38194 .54996 m .38358 .55394 L .38442 .55225 L F
.708 .985 .831 r
.38358 .55394 m .38186 .5545 L .38442 .55225 L F
0 .032 .601 r
.39335 .59866 m .39339 .59732 L .39302 .59744 L F
.005 0 .088 r
.39335 .59866 m .39217 .6013 L .39444 .59995 L F
.373 0 0 r
.34623 .534 m .34598 .53455 L .34854 .53414 L F
.183 .309 .759 r
.43094 .56508 m .43201 .56864 L .42953 .56712 L F
.146 .279 .744 r
.23629 .6142 m .23763 .6182 L .23869 .61609 L F
.271 .437 .843 r
.23763 .6182 m .24058 .61946 L .23869 .61609 L F
.319 0 .158 r
.28971 .63529 m .2903 .63343 L .28784 .63413 L F
0 0 .204 r
.68614 .35781 m .6833 .36131 L .68502 .35959 L F
0 0 0 r
.68502 .35959 m .6833 .36131 L .68278 .36291 L F
.305 .055 .361 r
.33671 .59392 m .33537 .59119 L .33818 .59195 L F
.33671 .59392 m .33461 .59484 L .33537 .59119 L F
0 0 .118 r
.33096 .54124 m .33129 .54204 L .33352 .54072 L F
.33096 .54124 m .33099 .54427 L .33129 .54204 L F
.825 .935 .902 r
.63743 .4358 m .63434 .43828 L .63366 .43694 L F
.391 .447 .798 r
.63434 .43828 m .63602 .43636 L .63366 .43694 L F
.63434 .43828 m .63725 .4403 L .63602 .43636 L F
.869 .676 .148 r
.62028 .39913 m .6198 .39618 L .62064 .39958 L F
0 .02 .592 r
.62187 .40039 m .62248 .40212 L .62117 .40033 L F
.62089 .39961 m .62117 .40033 L .62028 .39913 L F
.62187 .40039 m .62117 .40033 L .62089 .39961 L F
.696 .429 0 r
.61979 .39671 m .6198 .39618 L .61911 .39428 L F
0 .02 .592 r
.62074 .39965 m .62028 .39913 L .62064 .39958 L F
.62187 .40039 m .62089 .39961 L .62074 .39965 L F
.62089 .39961 m .62028 .39913 L .62074 .39965 L F
.696 .429 0 r
.62063 .39968 m .62017 .39771 L .61979 .39671 L F
.848 .399 0 r
.62381 .40417 m .62028 .39913 L .62248 .40212 L F
.673 .125 0 r
.61986 .40014 m .62187 .40039 L .62064 .39958 L F
.61986 .40014 m .62064 .39958 L .62077 .40015 L F
.696 .429 0 r
.62077 .40015 m .62065 .39968 L .62063 .39968 L F
.62065 .39968 m .62017 .39771 L .62063 .39968 L F
.62017 .39771 m .6198 .39618 L .61979 .39671 L F
.174 .507 .911 r
.3512 .50912 m .35189 .50852 L .34849 .50735 L F
.347 .134 .441 r
.27771 .55716 m .2796 .55889 L .28017 .55702 L F
.27771 .55716 m .27742 .55968 L .2796 .55889 L F
.963 .939 .642 r
.39876 .60607 m .40084 .60423 L .39978 .60399 L F
.39876 .60607 m .39927 .60843 L .40084 .60423 L F
.918 .969 .674 r
.40084 .60423 m .40188 .60053 L .39978 .60399 L F
.4 .478 .824 r
.22442 .56209 m .22572 .56583 L .2226 .56399 L F
.989 .891 .61 r
.33493 .6933 m .33702 .6913 L .336 .69063 L F
.803 .72 .773 r
.64432 .36179 m .64799 .36229 L .64683 .35859 L F
.482 0 0 r
.37929 .51775 m .37967 .51783 L .3771 .51556 L F
.37929 .51775 m .38114 .51897 L .37967 .51783 L F
0 0 0 r
.37614 .71243 m .3782 .71146 L .38057 .71039 L F
.552 .195 .316 r
.34849 .50735 m .35189 .50852 L .34881 .50856 L F
.407 .374 .71 r
.45012 .51591 m .44827 .51576 L .44769 .51178 L F
.417 .302 .615 r
.45012 .51591 m .45082 .51785 L .44827 .51576 L F
.315 .302 .686 r
.44827 .51576 m .45082 .51785 L .44907 .51803 L F
.609 .302 .424 r
.4401 .55414 m .44247 .55579 L .44264 .55334 L F
.4401 .55414 m .43974 .55637 L .44247 .55579 L F
.424 0 0 r
.24393 .6147 m .24534 .61564 L .24659 .6152 L F
.38 0 0 r
.24534 .61564 m .24885 .61611 L .24659 .6152 L F
.761 .378 .329 r
.24534 .61564 m .24709 .61841 L .24885 .61611 L F
0 .054 .61 r
.24588 .61451 m .24647 .61641 L .24534 .61564 L F
.24647 .61641 m .24709 .61841 L .24534 .61564 L F
.424 0 0 r
.24279 .61448 m .24534 .61564 L .24393 .6147 L F
.872 .978 .677 r
.29978 .53479 m .30191 .53399 L .3003 .53317 L F
.29978 .53479 m .29941 .53745 L .30191 .53399 L F
.414 .835 .668 r
.68974 .35581 m .68614 .35781 L .68912 .35526 L F
.734 .989 .81 r
.69107 .3536 m .69292 .35311 L .68974 .35581 L F
.728 .987 .888 r
.69107 .3536 m .68974 .35581 L .68912 .35526 L F
.392 0 .116 r
.28308 .56695 m .28233 .56836 L .27973 .56862 L F
.417 0 .127 r
.28308 .56695 m .28495 .56813 L .28233 .56836 L F
.423 0 .108 r
.28582 .56678 m .28495 .56813 L .28308 .56695 L F
.598 .342 .5 r
.31356 .61734 m .31068 .6199 L .311 .61774 L F
.46 .15 .352 r
.5904 .46144 m .58937 .46393 L .58664 .46441 L F
.557 .141 .208 r
.5904 .46144 m .59202 .46339 L .58937 .46393 L F
.5904 .46144 m .59302 .46125 L .59202 .46339 L F
.871 .942 .861 r
.41313 .4985 m .41032 .4982 L .41488 .49855 L F
.41313 .4985 m .41167 .50214 L .41032 .4982 L F
.463 .233 .479 r
.414 .49567 m .41155 .49846 L .41313 .4985 L F
.41155 .49846 m .41086 .49924 L .41313 .4985 L F
.871 .942 .861 r
.41313 .4985 m .41488 .49855 L .41513 .49857 L F
.079 .64 .761 r
.41513 .49857 m .41406 .49849 L .41313 .4985 L F
.628 .234 .277 r
.31777 .55643 m .31609 .55868 L .31303 .55844 L F
.105 0 0 r
.31855 .55758 m .31777 .55643 L .31926 .5552 L F
.346 .814 .914 r
.32076 .55705 m .31855 .55758 L .32127 .55513 L F
.32076 .55705 m .32012 .55711 L .31855 .55758 L F
.105 0 0 r
.31855 .55758 m .31645 .5582 L .31777 .55643 L F
.122 0 .073 r
.32127 .55513 m .31855 .55758 L .31926 .5552 L F
.346 .814 .914 r
.32012 .55711 m .31717 .5574 L .31855 .55758 L F
.105 0 0 r
.31855 .55758 m .31609 .55868 L .31645 .5582 L F
.41 .437 .777 r
.45641 .54361 m .45527 .54766 L .45403 .54386 L F
.45641 .54361 m .45733 .54714 L .45527 .54766 L F
.399 .391 .734 r
.45733 .54714 m .45811 .54959 L .45527 .54766 L F
.427 .388 .713 r
.45527 .54766 m .45811 .54959 L .4561 .55005 L F
.437 .177 .42 r
.45136 .58924 m .45094 .59175 L .44836 .59237 L F
.334 .09 .387 r
.45354 .58851 m .45094 .59175 L .45136 .58924 L F
.296 0 .005 r
.22555 .59748 m .22164 .6005 L .2186 .60057 L F
.661 .302 .353 r
.22516 .60047 m .22164 .6005 L .22555 .59748 L F
.837 .67 .129 r
.22544 .59462 m .22538 .59779 L .22555 .59748 L F
.661 .302 .353 r
.22516 .60047 m .22555 .59748 L .22538 .59779 L F
.826 .994 .753 r
.69214 .29383 m .68976 .29786 L .68879 .29644 L F
.69214 .29383 m .69244 .29466 L .68976 .29786 L F
.617 .759 .947 r
.39344 .68924 m .39605 .68847 L .39183 .68752 L F
.796 .753 .813 r
.54302 .41514 m .53994 .41908 L .53817 .41723 L F
0 0 0 r
.22756 .54094 m .22873 .54026 L .23042 .53799 L F
.23042 .53799 m .2319 .53664 L .23278 .53468 L F
.001 0 0 r
.23042 .53799 m .23087 .53921 L .2319 .53664 L F
.23042 .53799 m .22873 .54026 L .23087 .53921 L F
0 0 0 r
.62743 .42244 m .62901 .41982 L .62935 .42077 L F
.268 .185 .573 r
.62974 .4239 m .62743 .42244 L .62935 .42077 L F
.62974 .4239 m .62798 .42555 L .62743 .42244 L F
.868 .424 .109 r
.59148 .39303 m .5939 .39475 L .59469 .39654 L F
.553 .526 .78 r
.42732 .5885 m .42815 .59239 L .43073 .59113 L F
.597 .905 .983 r
.43073 .59113 m .42815 .59239 L .42644 .59168 L F
.478 .498 .8 r
.46706 .56256 m .46881 .56734 L .46611 .56704 L F
.971 .919 .592 r
.39876 .60607 m .3983 .61064 L .39927 .60843 L F
.693 .643 .795 r
.44806 .48361 m .44423 .4811 L .44665 .47991 L F
.589 .597 .827 r
.45063 .48293 m .44806 .48361 L .44665 .47991 L F
.65 .553 .731 r
.45063 .48293 m .448 .48642 L .44806 .48361 L F
.702 .655 .8 r
.6475 .42245 m .65189 .42355 L .64955 .42195 L F
.582 .833 .993 r
.33999 .52192 m .33585 .5215 L .33985 .52103 L F
.545 .872 .993 r
.33985 .52103 m .33697 .52046 L .33947 .52009 L F
0 0 .243 r
.34079 .51728 m .34006 .52153 L .33985 .52103 L F
.34079 .51728 m .34084 .51989 L .33999 .52192 L F
.545 .872 .993 r
.33985 .52103 m .34084 .51989 L .34079 .51728 L F
.33985 .52103 m .33947 .52009 L .34084 .51989 L F
0 0 .243 r
.34006 .52153 m .33999 .52192 L .33985 .52103 L F
0 0 .562 r
.34144 .52294 m .34194 .52489 L .33999 .52192 L F
.709 .796 .919 r
.33695 .51415 m .33842 .51539 L .34049 .51315 L F
0 .171 .64 r
.3371 .51424 m .33842 .51539 L .33695 .51415 L F
.917 .857 .767 r
.3371 .51424 m .33448 .5197 L .33842 .51539 L F
.115 .501 .906 r
.46881 .56734 m .47129 .56809 L .47095 .56917 L F
.103 .168 .647 r
.47129 .56809 m .47072 .57181 L .47095 .56917 L F
.427 .145 .381 r
.30169 .53162 m .30447 .53116 L .30522 .52822 L F
.665 .369 .461 r
.30447 .53116 m .31031 .53224 L .30522 .52822 L F
.673 .594 .759 r
.43996 .4773 m .43606 .47422 L .4386 .47345 L F
.579 .455 .675 r
.44254 .47888 m .43996 .4773 L .44229 .4767 L F
.44254 .47888 m .44023 .47955 L .43996 .4773 L F
.798 .998 .799 r
.69424 .35128 m .69292 .35311 L .69107 .3536 L F
0 0 0 r
.69551 .34985 m .69292 .35311 L .69424 .35128 L F
.479 .402 .692 r
.31063 .59977 m .31068 .60177 L .31263 .60101 L F
.42 .216 .494 r
.31034 .60435 m .31263 .60101 L .31068 .60177 L F
.236 .753 .779 r
.28045 .51736 m .28195 .51722 L .27902 .51781 L F
.388 .727 .99 r
.28549 .51678 m .28569 .51697 L .28286 .51685 L F
0 0 0 r
.28589 .51695 m .28195 .51722 L .28085 .51732 L F
.28589 .51695 m .28085 .51732 L .28309 .51716 L F
.28309 .51716 m .28085 .51732 L .28045 .51736 L F
.28589 .51695 m .28045 .51736 L .28286 .51685 L F
.69 .444 .545 r
.28286 .51685 m .2861 .51738 L .28589 .51695 L F
.388 .727 .99 r
.28569 .51697 m .2861 .51738 L .28424 .51708 L F
.28569 .51697 m .28424 .51708 L .28286 .51685 L F
.212 .083 .478 r
.33909 .58768 m .33755 .58582 L .33931 .58506 L F
.517 .324 .557 r
.44266 .55057 m .4452 .55265 L .44507 .54979 L F
.44266 .55057 m .44264 .55334 L .4452 .55265 L F
.727 .545 .644 r
.7397 .34002 m .74084 .33614 L .73941 .33608 L F
.73941 .33608 m .74084 .33614 L .7397 .34002 L F
.847 .942 .884 r
.39002 .61183 m .38523 .61423 L .38715 .61409 L F
.929 .963 .77 r
.39193 .6086 m .39002 .61183 L .38965 .60957 L F
.947 .958 .716 r
.39002 .61183 m .38715 .61409 L .38965 .60957 L F
.77 .982 .726 r
.69438 .36459 m .69735 .36148 L .69717 .36096 L F
.79 .975 .689 r
.69717 .36096 m .69735 .36148 L .69979 .3584 L F
0 0 0 r
.22756 .54094 m .22717 .54122 L .22873 .54026 L F
.22462 .5451 m .22579 .54354 L .22717 .54122 L F
.636 .807 .375 r
.22717 .54122 m .22579 .54354 L .22705 .54133 L F
.22717 .54122 m .22705 .54133 L .22783 .53998 L F
0 0 0 r
.22756 .54094 m .22733 .54108 L .22717 .54122 L F
.22733 .54108 m .22492 .54259 L .22717 .54122 L F
.242 0 .068 r
.59202 .46339 m .59302 .46125 L .59557 .46044 L F
.175 .198 .645 r
.23384 .569 m .23464 .56504 L .2326 .56767 L F
.386 .847 .82 r
.29763 .5168 m .30201 .51564 L .29886 .5163 L F
.481 .898 .839 r
.29886 .5163 m .30201 .51564 L .30326 .5146 L F
.767 .934 .583 r
.69495 .29024 m .69244 .29466 L .69214 .29383 L F
.413 .201 .479 r
.29746 .63608 m .29761 .63373 L .30039 .63398 L F
.864 .792 .779 r
.37424 .60136 m .36931 .60365 L .37058 .60145 L F
.37424 .60136 m .37171 .60461 L .36931 .60365 L F
.542 .364 .59 r
.32841 .63695 m .32894 .63999 L .33046 .63748 L F
.74 .73 .843 r
.61927 .38446 m .62061 .38001 L .61953 .38331 L F
.61927 .38446 m .62216 .38243 L .62061 .38001 L F
.283 0 .162 r
.29166 .54716 m .29403 .54648 L .29449 .54476 L F
.601 .302 .434 r
.29403 .54648 m .29735 .5442 L .29449 .54476 L F
0 0 0 r
.71966 .34259 m .71964 .34191 L .72209 .34029 L F
.823 .834 .857 r
.67158 .33571 m .67486 .33622 L .67353 .33416 L F
.67158 .33571 m .67293 .33691 L .67486 .33622 L F
.869 .872 .837 r
.67353 .33416 m .67486 .33622 L .67746 .33263 L F
.981 .912 .628 r
.40222 .5937 m .40319 .59566 L .40418 .59195 L F
.976 .812 .399 r
.40195 .59616 m .40319 .59566 L .40222 .5937 L F
.40195 .59616 m .40275 .5982 L .40319 .59566 L F
.714 .923 .585 r
.69424 .35085 m .69551 .34985 L .69424 .35128 L F
.807 .862 .415 r
.69701 .34595 m .69551 .34985 L .69669 .34787 L F
.754 .932 .583 r
.69669 .34787 m .69551 .34985 L .69424 .35085 L F
.474 .303 .568 r
.31293 .59575 m .31549 .59506 L .31526 .59186 L F
.438 .262 .543 r
.31293 .59575 m .31531 .5968 L .31549 .59506 L F
.31293 .59575 m .3128 .59859 L .31531 .5968 L F
0 .258 .764 r
.28956 .55048 m .29207 .55395 L .29199 .54974 L F
.524 .875 .987 r
.33496 .68459 m .33848 .68344 L .33357 .68331 L F
.516 .218 .399 r
.27204 .53155 m .27145 .534 L .27416 .53344 L F
.514 .219 .403 r
.27204 .53155 m .27416 .53344 L .27487 .5312 L F
.479 .402 .692 r
.31063 .59977 m .31263 .60101 L .3128 .59859 L F
.583 .828 .991 r
.26024 .5257 m .2664 .527 L .262 .52501 L F
.827 .586 .574 r
.26688 .52721 m .262 .52501 L .2664 .527 L F
.942 .924 .762 r
.26899 .5237 m .26688 .52721 L .26802 .52829 L F
.116 0 .227 r
.26899 .5237 m .26698 .52726 L .26688 .52721 L F
.26698 .52726 m .26611 .52879 L .26688 .52721 L F
0 .158 .632 r
.26643 .52702 m .26688 .52721 L .2664 .527 L F
.942 .924 .762 r
.26899 .5237 m .26802 .52829 L .27078 .52584 L F
.644 .728 .909 r
.26899 .5237 m .27078 .52584 L .27305 .52484 L F
.558 .744 .963 r
.26899 .5237 m .27305 .52484 L .27132 .52294 L F
0 0 0 r
.26979 .52274 m .26899 .5237 L .27132 .52294 L F
.26979 .52274 m .26772 .52769 L .26899 .5237 L F
0 .158 .632 r
.26802 .52829 m .26735 .52765 L .2672 .52764 L F
.26735 .52765 m .26688 .52721 L .2672 .52764 L F
.974 .808 .616 r
.26783 .53043 m .26688 .52721 L .26802 .52829 L F
.26778 .53102 m .26762 .53034 L .26783 .53043 L F
.26762 .53034 m .26688 .52721 L .26783 .53043 L F
.45 .268 .542 r
.26802 .52829 m .2702 .53031 L .26778 .53102 L F
.974 .808 .616 r
.26778 .53102 m .26725 .53068 L .26688 .52721 L F
.26725 .53068 m .26601 .5299 L .26629 .52905 L F
.26725 .53068 m .26629 .52905 L .26688 .52721 L F
0 .158 .632 r
.2672 .52764 m .26688 .52721 L .26643 .52702 L F
.805 .316 0 r
.26688 .52721 m .2702 .53031 L .26802 .52829 L F
.26688 .52721 m .26854 .52983 L .2702 .53031 L F
.748 .266 0 r
.26686 .52728 m .26854 .52983 L .26688 .52721 L F
.116 0 .227 r
.26699 .52757 m .26734 .5284 L .26641 .5287 L F
.748 .266 0 r
.26755 .5289 m .26854 .52983 L .26686 .52728 L F
.116 0 .227 r
.26899 .5237 m .26641 .5287 L .26673 .52769 L F
.748 .266 0 r
.26673 .52775 m .26734 .5284 L .26686 .52728 L F
.116 0 .227 r
.26899 .5237 m .26744 .52837 L .26734 .5284 L F
.26899 .5237 m .26734 .5284 L .26699 .52757 L F
.748 .266 0 r
.26616 .52947 m .26639 .52874 L .26601 .5299 L F
.26639 .52874 m .26688 .52721 L .26629 .52905 L F
.26639 .52874 m .26629 .52905 L .26601 .5299 L F
.827 .586 .574 r
.26688 .52721 m .26611 .52879 L .262 .52501 L F
.967 .904 .703 r
.2652 .5261 m .26608 .5287 L .26644 .52861 L F
.26673 .52775 m .26644 .52861 L .26734 .5284 L F
.748 .266 0 r
.26686 .52728 m .26688 .52721 L .26616 .52947 L F
.116 0 .227 r
.26673 .52769 m .26641 .5287 L .26611 .52879 L F
.967 .904 .703 r
.2652 .5261 m .26644 .52861 L .26673 .52775 L F
.748 .266 0 r
.26665 .52804 m .26673 .52775 L .26616 .52947 L F
.26673 .52775 m .26686 .52728 L .26641 .5287 L F
.967 .904 .703 r
.26608 .5287 m .26613 .52878 L .26744 .52837 L F
.748 .266 0 r
.26673 .52775 m .26641 .5287 L .26616 .52947 L F
.967 .904 .703 r
.26451 .52408 m .2652 .5261 L .26675 .52768 L F
.26682 .52748 m .26675 .52768 L .26744 .52837 L F
.26451 .52408 m .26675 .52768 L .26682 .52748 L F
.2652 .5261 m .26734 .5284 L .26744 .52837 L F
.748 .266 0 r
.26665 .52804 m .26755 .5289 L .26734 .5284 L F
.26665 .52804 m .26734 .5284 L .26673 .52775 L F
.967 .904 .703 r
.26608 .5287 m .26611 .52879 L .26613 .52878 L F
.775 .685 .764 r
.26649 .52989 m .2702 .53031 L .26854 .52983 L F
.26601 .5299 m .26668 .52996 L .26649 .52989 L F
.26668 .52996 m .2702 .53031 L .26649 .52989 L F
0 0 0 r
.26772 .52769 m .26744 .52837 L .26766 .52769 L F
.26772 .52769 m .26766 .52769 L .26899 .5237 L F
.334 .055 .333 r
.32666 .59865 m .32598 .60106 L .32383 .60169 L F
.116 0 .003 r
.32931 .59834 m .32598 .60106 L .32666 .59865 L F
.158 0 0 r
.22861 .55282 m .23104 .55228 L .23299 .55067 L F
0 0 0 r
.23299 .55067 m .23446 .54943 L .23546 .5473 L F
.695 .532 .662 r
.23699 .55324 m .23538 .5539 L .23299 .55067 L F
.091 0 0 r
.23299 .55067 m .23357 .55151 L .23446 .54943 L F
.23299 .55067 m .23104 .55228 L .23357 .55151 L F
0 .14 .657 r
.72781 .34599 m .72287 .34083 L .72685 .34389 L F
.049 .218 .718 r
.72801 .34421 m .72781 .34599 L .72685 .34389 L F
.915 .967 .66 r
.72609 .34728 m .72781 .34599 L .72801 .34421 L F
.75 .469 .506 r
.53828 .45143 m .53645 .45395 L .5363 .45084 L F
.53828 .45143 m .54035 .4542 L .53645 .45395 L F
.315 .016 .289 r
.34207 .5714 m .34049 .56976 L .34312 .56968 L F
.34207 .5714 m .33954 .57223 L .34049 .56976 L F
.756 .277 0 r
.32013 .65754 m .31973 .65596 L .3177 .65834 L F
.32013 .65754 m .32119 .65806 L .31973 .65596 L F
0 0 0 r
.35486 .59154 m .35786 .58901 L .35752 .59116 L F
.47 .537 .844 r
.46234 .55528 m .46069 .55733 L .45929 .55343 L F
.46234 .55528 m .46307 .55731 L .46069 .55733 L F
.81 .41 .292 r
.70903 .31232 m .71077 .31085 L .70917 .30977 L F
.70903 .31232 m .71264 .31336 L .71077 .31085 L F
.647 .559 .742 r
.4207 .50151 m .41679 .49818 L .4182 .49931 L F
.715 .978 .915 r
.30667 .6342 m .30344 .63668 L .30295 .63588 L F
.517 .813 .999 r
.30791 .6362 m .30344 .63668 L .30667 .6342 L F
.014 0 .321 r
.69454 .36441 m .69443 .36668 L .69228 .36846 L F
0 0 .151 r
.69228 .36846 m .69384 .36881 L .69189 .37123 L F
.69228 .36846 m .69443 .36668 L .69384 .36881 L F
.198 .079 .482 r
.33491 .60497 m .33503 .6079 L .33648 .604 L F
.437 .316 .616 r
.33718 .53031 m .33987 .53284 L .34134 .53006 L F
.365 .599 .937 r
.34134 .53006 m .34213 .52787 L .3397 .52768 L F
.34134 .53006 m .34411 .53039 L .34213 .52787 L F
.033 0 0 r
.34134 .53006 m .34182 .53188 L .34411 .53039 L F
.34134 .53006 m .33987 .53284 L .34182 .53188 L F
.203 .717 .886 r
.39159 .57921 m .39575 .57941 L .39402 .57906 L F
.684 .938 .65 r
.39575 .57941 m .39303 .58229 L .39577 .58211 L F
.814 .644 .091 r
.39575 .57941 m .39544 .58057 L .39402 .57906 L F
.39575 .57941 m .39577 .58211 L .39544 .58057 L F
.096 0 .101 r
.30369 .64672 m .30686 .6434 L .30606 .64634 L F
0 0 .27 r
.30686 .6434 m .30854 .64025 L .30877 .64283 L F
.358 .115 .403 r
.30606 .64634 m .30686 .6434 L .30877 .64283 L F
.676 .862 .97 r
.29551 .51292 m .29388 .51287 L .29661 .51198 L F
0 0 0 r
.29467 .5132 m .29661 .51198 L .29388 .51287 L F
.513 .878 .657 r
.29751 .51121 m .29661 .51198 L .29467 .5132 L F
.29856 .51047 m .29661 .51198 L .29751 .51121 L F
.676 .862 .97 r
.29835 .51299 m .29551 .51292 L .29661 .51198 L F
.788 .919 .926 r
.30023 .51122 m .29835 .51299 L .29661 .51198 L F
.359 .473 .84 r
.61661 .37423 m .61332 .37031 L .61669 .3716 L F
.433 .232 .507 r
.61661 .37423 m .61669 .3716 L .61918 .37351 L F
.825 .935 .902 r
.63743 .4358 m .63366 .43694 L .63602 .43636 L F
.043 0 .24 r
.6394 .4323 m .63743 .4358 L .63903 .43444 L F
.688 .469 .583 r
.63602 .43636 m .63903 .43444 L .63743 .4358 L F
.814 .332 0 r
.4004 .64925 m .40184 .64948 L .40004 .64709 L F
.622 .245 .308 r
.35478 .557 m .35318 .55912 L .34952 .55785 L F
.751 .47 .506 r
.35739 .55696 m .35318 .55912 L .35478 .557 L F
.999 .799 .495 r
.34329 .59583 m .34246 .5982 L .34473 .59461 L F
0 .245 .732 r
.38312 .50798 m .37946 .50481 L .38195 .50664 L F
.529 .51 .778 r
.44923 .50887 m .44691 .50946 L .44571 .5054 L F
.506 .414 .686 r
.44923 .50887 m .44985 .51124 L .44691 .50946 L F
.457 .427 .737 r
.44691 .50946 m .44985 .51124 L .44769 .51178 L F
.694 .801 .931 r
.6173 .35826 m .61396 .36087 L .61303 .35787 L F
0 0 .046 r
.69765 .33629 m .69806 .33528 L .69851 .33192 L F
.892 .699 .186 r
.69765 .33629 m .69714 .33765 L .69806 .33528 L F
.528 .522 .793 r
.40203 .66092 m .40069 .66537 L .4003 .66269 L F
.592 .198 .264 r
.73876 .33867 m .73941 .33608 L .73534 .33647 L F
.727 .545 .644 r
.7397 .34002 m .73941 .33608 L .73876 .33867 L F
0 0 .004 r
.74047 .33521 m .73941 .33608 L .73876 .33867 L F
.727 .545 .644 r
.73943 .33731 m .73876 .33867 L .73938 .33678 L F
.7397 .34002 m .73876 .33867 L .73943 .33731 L F
.977 .909 .67 r
.73876 .33867 m .7397 .34002 L .73938 .33678 L F
0 0 .004 r
.74078 .33495 m .74047 .33521 L .73876 .33867 L F
.703 .7 .844 r
.37645 .66916 m .37666 .66547 L .37436 .66622 L F
.37645 .66916 m .37856 .66885 L .37666 .66547 L F
.789 .68 .744 r
.23933 .55368 m .24383 .55475 L .24163 .55289 L F
.23933 .55368 m .2405 .55682 L .24383 .55475 L F
.144 .029 .452 r
.2405 .55682 m .24216 .5583 L .24383 .55475 L F
.15 .129 .578 r
.24383 .55475 m .24398 .55203 L .24163 .55289 L F
.38 0 .087 r
.24216 .5583 m .24543 .5564 L .24383 .55475 L F
.684 .174 .023 r
.26338 .61814 m .2662 .62005 L .2685 .6198 L F
.2 0 0 r
.2685 .6198 m .2662 .62005 L .27029 .62006 L F
.998 .84 .547 r
.40374 .58841 m .40308 .591 L .40418 .59195 L F
.981 .912 .628 r
.40222 .5937 m .40418 .59195 L .40308 .591 L F
0 0 0 r
.33788 .60242 m .33648 .604 L .33978 .60123 L F
.745 .911 .537 r
.69699 .28702 m .69583 .28941 L .69495 .29024 L F
.606 .304 .431 r
.43085 .54575 m .42835 .54492 L .43047 .54354 L F
.43085 .54575 m .42715 .54773 L .42835 .54492 L F
.664 .802 .949 r
.35318 .72466 m .35452 .72622 L .3504 .72586 L F
.35318 .72466 m .35452 .72622 L .3504 .72586 L F
.489 .723 .975 r
.35318 .72466 m .35452 .72622 L .3569 .72587 L F
.35318 .72466 m .35452 .72622 L .3569 .72587 L F
.79 .975 .689 r
.69717 .36096 m .69979 .3584 L .69874 .35905 L F
.879 .971 .658 r
.69979 .3584 m .70155 .35413 L .70003 .35785 L F
.63 .912 .621 r
.69874 .35905 m .69979 .3584 L .70003 .35785 L F
.724 .665 .791 r
.29199 .54974 m .29207 .55395 L .29611 .55111 L F
.043 0 .24 r
.6394 .4323 m .63903 .43444 L .63851 .43107 L F
.905 .948 .82 r
.64175 .42847 m .6394 .4323 L .63851 .43107 L F
.887 .776 .28 r
.25181 .53133 m .25233 .53119 L .25424 .53061 L F
.25181 .53133 m .25166 .53341 L .25233 .53119 L F
.288 0 .285 r
.34561 .57924 m .34519 .58211 L .34296 .58195 L F
.511 .179 .341 r
.34814 .58128 m .34561 .57924 L .3484 .57895 L F
.34814 .58128 m .34519 .58211 L .34561 .57924 L F
.888 .96 .838 r
.68696 .31622 m .69052 .31413 L .69001 .31367 L F
0 0 .047 r
.69401 .31025 m .69205 .31196 L .69469 .30873 L F
.556 .899 .669 r
.69274 .31118 m .69205 .31196 L .69401 .31025 L F
0 0 0 r
.69205 .31196 m .69096 .31316 L .69167 .3116 L F
.556 .899 .669 r
.6907 .31268 m .69205 .31196 L .69274 .31118 L F
0 0 0 r
.69205 .31196 m .69052 .31413 L .69096 .31316 L F
.697 .983 .862 r
.69001 .31367 m .69052 .31413 L .69205 .31196 L F
.962 .846 .429 r
.42931 .57891 m .42913 .58309 L .42768 .58169 L F
0 .341 .82 r
.42913 .58309 m .43222 .58382 L .42768 .58169 L F
.4316 .58461 m .433 .58547 L .43258 .58457 L F
.898 .931 .829 r
.43222 .58382 m .433 .58547 L .43366 .5846 L F
.43395 .58309 m .43366 .5846 L .4352 .58257 L F
.43222 .58382 m .43366 .5846 L .43395 .58309 L F
.748 .733 .209 r
.43409 .58151 m .43383 .58325 L .43431 .58121 L F
.43444 .58051 m .43431 .58121 L .43453 .58025 L F
.43409 .58151 m .43431 .58121 L .43444 .58051 L F
.857 .978 .677 r
.43136 .58789 m .4352 .58257 L .43383 .58325 L F
.43136 .58789 m .43314 .58455 L .43282 .58602 L F
.43314 .58455 m .43383 .58325 L .43336 .58455 L F
.43314 .58455 m .43336 .58455 L .43282 .58602 L F
0 .341 .82 r
.42913 .58309 m .4316 .58461 L .43222 .58382 L F
.4316 .58461 m .43258 .58457 L .43222 .58382 L F
.635 .185 .166 r
.29767 .64518 m .29917 .64613 L .2958 .64616 L F
.921 .97 .776 r
.39193 .6086 m .38965 .60957 L .39117 .60761 L F
.919 .753 .66 r
.52892 .42309 m .52605 .42495 L .52776 .42234 L F
.52892 .42309 m .52848 .42573 L .52605 .42495 L F
.792 .76 .823 r
.66872 .33877 m .67238 .33973 L .67158 .33571 L F
.824 .716 .746 r
.66872 .33877 m .67 .34268 L .67238 .33973 L F
.902 .82 .757 r
.67158 .33571 m .67238 .33973 L .67293 .33691 L F
.511 .828 1 r
.36976 .63558 m .37174 .63683 L .36744 .63644 L F
.778 .686 .762 r
.36744 .63644 m .37174 .63683 L .36894 .64027 L F
.467 .807 .999 r
.3724 .63538 m .37174 .63683 L .36976 .63558 L F
0 .185 .71 r
.3724 .63538 m .3741 .63932 L .37174 .63683 L F
.833 .402 .211 r
.38179 .52037 m .38576 .52367 L .38315 .52172 L F
.91 .956 .81 r
.34875 .52387 m .34766 .52767 L .35063 .52433 L F
.34875 .52387 m .34652 .52719 L .34766 .52767 L F
.728 .599 .713 r
.62793 .40922 m .63227 .41018 L .63158 .40763 L F
.631 .54 .734 r
.63158 .40763 m .63227 .41018 L .63433 .40777 L F
.407 .374 .71 r
.45012 .51591 m .44769 .51178 L .44985 .51124 L F
.186 0 .3 r
.30015 .54893 m .29883 .54766 L .3012 .54691 L F
.30015 .54893 m .29835 .55006 L .29883 .54766 L F
.67 .654 .825 r
.63716 .40388 m .64101 .40478 L .63923 .40494 L F
.67 .975 .874 r
.64101 .40478 m .64251 .40302 L .63923 .40494 L F
.64101 .40478 m .64323 .40332 L .64251 .40302 L F
.527 .374 .616 r
.36191 .68506 m .36422 .68135 L .36158 .68193 L F
.69 .677 .832 r
.43461 .4709 m .43606 .47422 L .43213 .47356 L F
.679 .671 .835 r
.4386 .47345 m .43606 .47422 L .43461 .4709 L F
.729 .625 .742 r
.2356 .59717 m .23394 .59902 L .23218 .59504 L F
.166 0 .221 r
.342 .53657 m .33991 .53762 L .34267 .53448 L F
.151 0 .322 r
.342 .53657 m .33951 .54023 L .33991 .53762 L F
.758 .738 .834 r
.27145 .534 m .27654 .53523 L .27416 .53344 L F
.27145 .534 m .27211 .53626 L .27654 .53523 L F
.646 .809 .962 r
.27416 .53344 m .27654 .53523 L .27829 .53397 L F
.539 .246 .419 r
.34854 .53414 m .35121 .53412 L .35185 .53152 L F
.206 0 .292 r
.35185 .53152 m .35338 .53167 L .35469 .53164 L F
.35185 .53152 m .35121 .53412 L .35338 .53167 L F
.556 .404 .631 r
.35185 .53152 m .35469 .53164 L .35455 .52822 L F
.766 .427 0 r
.36744 .63644 m .36894 .64027 L .36854 .63963 L F
.927 .959 .643 r
.36854 .63963 m .36894 .64027 L .36712 .64168 L F
.439 0 0 r
.36712 .64168 m .36894 .64027 L .37008 .64127 L F
0 0 0 r
.61288 .45014 m .6125 .45265 L .61109 .45455 L F
.61288 .45014 m .61298 .4502 L .6125 .45265 L F
.69701 .34595 m .69669 .34787 L .69681 .34737 L F
.69729 .34472 m .69701 .34595 L .69681 .34737 L F
.621 .357 .497 r
.35279 .67055 m .35461 .67161 L .35548 .66899 L F
.316 .717 .979 r
.33684 .4953 m .33916 .4953 L .34085 .49639 L F
.043 .566 .867 r
.33916 .4953 m .3433 .49657 L .34085 .49639 L F
.418 .864 .816 r
.25364 .52324 m .25382 .52265 L .25632 .52253 L F
.25364 .52324 m .25165 .52362 L .25382 .52265 L F
0 0 0 r
.23278 .53468 m .23296 .53548 L .23447 .53316 L F
.23278 .53468 m .2319 .53664 L .23296 .53548 L F
.15 0 .29 r
.43225 .54765 m .43165 .54991 L .43392 .54653 L F
.705 .983 .886 r
.35019 .65192 m .3505 .65244 L .34917 .65285 L F
.785 .388 .303 r
.34917 .65285 m .3505 .65244 L .35031 .65467 L F
.724 .975 .924 r
.3512 .65102 m .34917 .65285 L .34916 .65176 L F
0 0 .546 r
.34917 .65285 m .35031 .65467 L .34916 .65176 L F
.681 .166 .003 r
.34906 .6552 m .35031 .65467 L .34759 .65529 L F
.988 .749 .483 r
.34915 .65195 m .35031 .65467 L .34907 .65494 L F
.34923 .65195 m .35031 .65467 L .34915 .65195 L F
0 0 .116 r
.35031 .65467 m .3505 .65244 L .35203 .65048 L F
.705 .983 .886 r
.3512 .65102 m .35076 .65191 L .35019 .65192 L F
.35076 .65191 m .3505 .65244 L .35019 .65192 L F
.716 .988 .854 r
.35203 .65048 m .3505 .65244 L .3512 .65102 L F
.842 .912 .883 r
.34916 .65176 m .35203 .65048 L .3512 .65102 L F
.842 .74 .751 r
.34916 .65176 m .35031 .65467 L .35203 .65048 L F
.042 .249 .748 r
.35176 .65425 m .35031 .65467 L .34945 .65249 L F
.34973 .6523 m .34945 .65249 L .34916 .65176 L F
.35176 .65425 m .34945 .65249 L .34973 .6523 L F
.996 .767 .419 r
.34916 .65176 m .34907 .65494 L .34814 .65349 L F
.34907 .65494 m .34906 .6552 L .34894 .65497 L F
.34907 .65494 m .34894 .65497 L .34814 .65349 L F
.928 .865 .756 r
.34814 .65349 m .34894 .65497 L .34759 .65529 L F
.198 .721 .712 r
.34759 .65529 m .35031 .65467 L .3482 .65513 L F
.928 .865 .756 r
.34894 .65497 m .34906 .6552 L .34759 .65529 L F
.198 .721 .712 r
.34845 .65507 m .34915 .65492 L .35176 .65425 L F
.34915 .65492 m .35031 .65467 L .35068 .65457 L F
.34915 .65492 m .35068 .65457 L .35176 .65425 L F
.3482 .65513 m .34907 .65494 L .34845 .65507 L F
.34907 .65494 m .35031 .65467 L .34845 .65507 L F
.042 .249 .748 r
.35176 .65425 m .34916 .65176 L .35147 .65107 L F
.143 0 0 r
.35063 .6517 m .34814 .65349 L .34959 .65248 L F
.35147 .65107 m .35029 .65192 L .35063 .6517 L F
.35029 .65192 m .34814 .65349 L .35063 .6517 L F
.988 .749 .483 r
.34907 .65494 m .35031 .65467 L .34906 .6552 L F
.34916 .65176 m .34923 .65195 L .34915 .65195 L F
.801 .621 .659 r
.62833 .40713 m .63158 .40763 L .63021 .40363 L F
.732 .988 .888 r
.6297 .40308 m .63021 .40363 L .63144 .40142 L F
.736 .971 .711 r
.62824 .40482 m .63021 .40363 L .63144 .40142 L F
.793 .514 .515 r
.63433 .40777 m .63021 .40363 L .63158 .40763 L F
0 0 0 r
.53467 .4169 m .53215 .41812 L .53216 .41834 L F
.53467 .4169 m .53215 .41812 L .53216 .41834 L F
.83 .641 .647 r
.37476 .67176 m .37836 .67166 L .37856 .66885 L F
.712 .904 .539 r
.36815 .60815 m .366 .61133 L .36676 .60962 L F
.249 0 0 r
.366 .61133 m .36867 .61107 L .36678 .61268 L F
.554 .416 .648 r
.36815 .60815 m .36867 .61107 L .366 .61133 L F
0 0 .495 r
.36897 .60936 m .36867 .61107 L .36815 .60815 L F
.712 .904 .539 r
.36815 .60815 m .36676 .60962 L .36403 .6085 L F
.779 .718 .796 r
.36954 .60714 m .36897 .60936 L .36815 .60815 L F
.37003 .60679 m .36945 .60819 L .36954 .60714 L F
.36945 .60819 m .36897 .60936 L .36954 .60714 L F
.36945 .60819 m .36676 .60962 L .36897 .60936 L F
.36795 .60859 m .36676 .60962 L .36945 .60819 L F
.93 .944 .601 r
.36678 .61268 m .36897 .60936 L .36676 .60962 L F
.779 .718 .796 r
.37003 .60679 m .36795 .60859 L .36945 .60819 L F
.93 .944 .601 r
.36841 .61021 m .36867 .61107 L .36897 .60936 L F
.779 .718 .796 r
.37003 .60679 m .37089 .61023 L .36676 .60962 L F
.84 .672 .675 r
.36852 .60988 m .36501 .60719 L .36676 .60962 L F
.36876 .60913 m .36501 .60719 L .36852 .60988 L F
.36934 .60943 m .3669 .60886 L .36779 .60863 L F
.37089 .61023 m .36876 .60913 L .36852 .60988 L F
.37089 .61023 m .36932 .60969 L .36934 .60943 L F
.36932 .60969 m .3669 .60886 L .36934 .60943 L F
.93 .944 .601 r
.36796 .61089 m .36808 .61123 L .36841 .61021 L F
.36766 .61134 m .36787 .61129 L .36796 .61089 L F
.36787 .61129 m .36808 .61123 L .36796 .61089 L F
.184 .225 .671 r
.37003 .60679 m .36815 .60815 L .36736 .60409 L F
.37003 .60679 m .36736 .60409 L .36931 .60365 L F
.825 .843 .862 r
.36942 .60483 m .36933 .60504 L .37089 .61023 L F
.93 .944 .601 r
.36808 .61123 m .36867 .61107 L .36841 .61021 L F
.84 .672 .675 r
.37089 .61023 m .3668 .61067 L .3669 .60886 L F
.36806 .61054 m .36685 .61077 L .3668 .61067 L F
.36803 .61061 m .36685 .61077 L .36806 .61054 L F
.825 .843 .862 r
.36933 .60504 m .36685 .61077 L .36803 .61061 L F
.84 .672 .675 r
.37089 .61023 m .36803 .61061 L .36806 .61054 L F
.825 .843 .862 r
.36933 .60504 m .36803 .61061 L .37089 .61023 L F
.84 .672 .675 r
.36779 .60863 m .3669 .60886 L .36694 .60819 L F
.93 .944 .601 r
.36678 .61268 m .36717 .61235 L .36766 .61134 L F
.36717 .61235 m .36867 .61107 L .36766 .61134 L F
.249 0 0 r
.366 .61133 m .36603 .61138 L .36676 .60962 L F
.36603 .61138 m .36669 .61252 L .36673 .61073 L F
.36603 .61138 m .36673 .61073 L .36676 .60962 L F
.132 .413 .859 r
.36403 .6085 m .36676 .60962 L .36501 .60719 L F
.84 .672 .675 r
.36694 .60819 m .3668 .61067 L .36501 .60719 L F
0 .078 .639 r
.36501 .60719 m .3668 .61067 L .36607 .60697 L F
.3668 .61067 m .36685 .61077 L .36682 .61065 L F
.3668 .61067 m .36682 .61065 L .36607 .60697 L F
.249 0 0 r
.36669 .61252 m .36678 .61268 L .36677 .61117 L F
.36669 .61252 m .36677 .61117 L .36676 .60962 L F
.16 .637 .926 r
.37856 .66885 m .3803 .66836 L .37666 .66547 L F
.37856 .66885 m .3815 .66928 L .3803 .66836 L F
.998 .807 .524 r
.37856 .66885 m .37836 .67166 L .37683 .67064 L F
.583 .424 .631 r
.37856 .66885 m .37836 .67166 L .3815 .66928 L F
.258 0 0 r
.37879 .66939 m .37856 .66885 L .37683 .67064 L F
.37879 .66939 m .3815 .66928 L .37856 .66885 L F
.438 .247 .523 r
.3781 .65277 m .37577 .65606 L .37802 .65572 L F
.972 .709 .474 r
.3781 .65277 m .37802 .65572 L .37577 .65606 L F
.389 .121 .381 r
.37666 .66547 m .37748 .66263 L .37436 .66622 L F
0 0 0 r
.37887 .66166 m .38024 .66013 L .37748 .66263 L F
0 0 .178 r
.37887 .66166 m .37748 .66263 L .37666 .66547 L F
.503 .272 .497 r
.56963 .43224 m .56649 .43243 L .5676 .43079 L F
0 0 0 r
.56639 .4317 m .56811 .43108 L .5676 .43079 L F
.875 .859 .822 r
.57133 .42969 m .56963 .43224 L .5676 .43079 L F
0 0 0 r
.56811 .43108 m .57047 .43022 L .5676 .43079 L F
0 0 .307 r
.5669 .43039 m .5676 .43079 L .56649 .43243 L F
.56748 .42752 m .5676 .43079 L .5669 .43039 L F
.503 .272 .497 r
.56963 .43224 m .56648 .43484 L .56649 .43243 L F
.56649 .43243 m .56648 .43484 L .56963 .43224 L F
.886 .542 .051 r
.39068 .53362 m .39221 .53723 L .39163 .53487 L F
.56 .534 .783 r
.35065 .70997 m .35234 .7148 L .35415 .71306 L F
.049 .218 .718 r
.72801 .34421 m .72685 .34389 L .72871 .34145 L F
.709 .181 0 r
.26438 .63054 m .26699 .63273 L .26467 .63216 L F
.02 .064 .567 r
.42475 .53649 m .42416 .54147 L .42319 .53743 L F
0 0 0 r
.42416 .54147 m .42535 .54056 L .42593 .53972 L F
.02 .064 .567 r
.42475 .53649 m .42535 .54056 L .42416 .54147 L F
.811 .854 .881 r
.42636 .50576 m .4279 .50522 L .42908 .5034 L F
.544 .303 .501 r
.42605 .50858 m .4279 .50522 L .42636 .50576 L F
.42605 .50858 m .42897 .50824 L .4279 .50522 L F
0 0 0 r
.4279 .50522 m .42899 .50439 L .42908 .5034 L F
.365 .208 .531 r
.4279 .50522 m .43105 .50719 L .42899 .50439 L F
.4279 .50522 m .42897 .50824 L .43105 .50719 L F
0 0 0 r
.70051 .32738 m .69916 .3289 L .70243 .32589 L F
0 0 .063 r
.29835 .62088 m .29824 .62384 L .2985 .6225 L F
.29835 .62088 m .29861 .62183 L .29683 .61976 L F
.29835 .62088 m .2985 .6225 L .29861 .62183 L F
0 0 0 r
.38246 .65898 m .38024 .66013 L .37887 .66166 L F
.438 .257 .537 r
.26092 .80353 m .26129 .80637 L .26339 .80538 L F
.849 .43 0 r
.38576 .52367 m .388 .52689 L .38701 .52508 L F
.641 .917 .627 r
.23131 .54745 m .22953 .54868 L .2287 .55004 L F
0 0 0 r
.23397 .54353 m .23267 .54584 L .23131 .54745 L F
.546 .878 .614 r
.23174 .54673 m .23131 .54745 L .23267 .54584 L F
.23174 .54673 m .22953 .54868 L .23131 .54745 L F
0 0 .275 r
.20995 .56658 m .21059 .56818 L .21087 .56548 L F
.20995 .56658 m .20968 .56923 L .21059 .56818 L F
.291 0 .034 r
.64253 .39786 m .63902 .39986 L .64185 .3992 L F
.373 .157 .452 r
.64471 .39894 m .64253 .39786 L .64185 .3992 L F
.64471 .39894 m .64482 .39658 L .64253 .39786 L F
.825 .831 .852 r
.68523 .3046 m .68073 .30616 L .68369 .30309 L F
.946 .959 .7 r
.68649 .29985 m .68523 .3046 L .68369 .30309 L F
.552 .108 .147 r
.57087 .46759 m .56696 .46921 L .56665 .46757 L F
.57087 .46759 m .56989 .46969 L .56696 .46921 L F
.422 0 0 r
.57087 .46759 m .57256 .46909 L .56989 .46969 L F
.57087 .46759 m .57316 .46863 L .57256 .46909 L F
.423 0 0 r
.57364 .46768 m .57316 .46863 L .57087 .46759 L F
.541 .432 .679 r
.33403 .61695 m .33158 .62128 L .33006 .61533 L F
.33403 .61695 m .33385 .62082 L .33158 .62128 L F
.378 .013 .213 r
.33158 .62128 m .33317 .62307 L .33011 .62441 L F
.33158 .62128 m .33385 .62082 L .33317 .62307 L F
.434 .728 .988 r
.29521 .6486 m .29451 .65045 L .2927 .64896 L F
.29521 .6486 m .29732 .65022 L .29451 .65045 L F
.76 .443 .45 r
.27077 .54462 m .26684 .54105 L .26867 .54023 L F
.587 .081 .019 r
.27077 .54462 m .2661 .54532 L .26839 .54503 L F
.27077 .54462 m .27051 .54602 L .2661 .54532 L F
.466 0 0 r
.26738 .53999 m .27142 .53937 L .26867 .54023 L F
.242 .455 .867 r
.27155 .54214 m .26867 .54023 L .27142 .53937 L F
.27012 .54119 m .26978 .54256 L .26867 .54023 L F
.466 0 0 r
.26738 .53999 m .26945 .54088 L .27142 .53937 L F
.838 .975 .669 r
.27142 .53937 m .27038 .54016 L .27184 .53733 L F
.27038 .54016 m .26945 .54088 L .27065 .5391 L F
.27038 .54016 m .27065 .5391 L .27184 .53733 L F
.242 .455 .867 r
.27155 .54214 m .27077 .54462 L .26978 .54256 L F
.27155 .54214 m .26978 .54256 L .27012 .54119 L F
.466 .89 .884 r
.21203 .60378 m .20988 .60499 L .21144 .60492 L F
.646 .248 .276 r
.24181 .56813 m .24657 .56633 L .24248 .5667 L F
.24181 .56813 m .24438 .56855 L .24657 .56633 L F
.622 .218 .256 r
.24657 .56633 m .24438 .56855 L .24867 .56783 L F
.065 0 .042 r
.34337 .58385 m .34296 .58195 L .34519 .58211 L F
.34337 .58385 m .34175 .58445 L .34296 .58195 L F
.333 .199 .545 r
.6391 .40308 m .63716 .40388 L .63923 .40494 L F
.364 .177 .489 r
.63923 .40494 m .63716 .40388 L .63718 .40658 L F
.899 .513 .284 r
.38812 .5142 m .38639 .51454 L .3858 .5125 L F
.212 .735 .839 r
.39089 .5143 m .38639 .51454 L .38812 .5142 L F
.828 .379 0 r
.57631 .41955 m .57892 .42315 L .57958 .42102 L F
.7 .756 .257 r
.57958 .42102 m .57892 .42315 L .57808 .42559 L F
.674 .799 .942 r
.27976 .52351 m .2837 .52383 L .28205 .5226 L F
.594 .809 .982 r
.28205 .5226 m .2837 .52383 L .286 .52284 L F
.903 .894 .809 r
.67624 .33101 m .68005 .32906 L .67894 .32794 L F
.67624 .33101 m .67746 .33263 L .68005 .32906 L F
.854 .968 .871 r
.67894 .32794 m .68005 .32906 L .68277 .32607 L F
.886 .99 .788 r
.34617 .68811 m .34288 .69084 L .34466 .68779 L F
.682 .84 .416 r
.34662 .68728 m .34617 .68811 L .34685 .68659 L F
.626 .944 .95 r
.34685 .68659 m .34617 .68811 L .34466 .68779 L F
.656 .796 .95 r
.58211 .42642 m .58469 .42555 L .58068 .42489 L F
.58211 .42642 m .58469 .42555 L .58068 .42489 L F
.53 .353 .586 r
.33911 .65604 m .34153 .65779 L .34203 .65563 L F
.33911 .65604 m .34153 .65779 L .34203 .65563 L F
0 .067 .601 r
.34469 .6816 m .34531 .68165 L .34405 .68431 L F
.728 .599 .713 r
.62793 .40922 m .63158 .40763 L .62833 .40713 L F
.375 .139 .423 r
.325 .53926 m .32316 .53775 L .32711 .53646 L F
.325 .53926 m .32283 .54025 L .32316 .53775 L F
0 0 0 r
.23546 .5473 m .23575 .54794 L .23841 .54592 L F
.23546 .5473 m .23446 .54943 L .23575 .54794 L F
.926 .544 .157 r
.60002 .41509 m .59939 .4125 L .59792 .41131 L F
.453 .345 .641 r
.31526 .59186 m .31773 .59137 L .31705 .5885 L F
.303 .177 .538 r
.31526 .59186 m .31739 .59397 L .31773 .59137 L F
.31526 .59186 m .31549 .59506 L .31739 .59397 L F
.716 .574 .695 r
.72999 .34557 m .73428 .34612 L .73334 .34224 L F
.721 .754 .878 r
.73334 .34224 m .73525 .3393 L .7326 .33972 L F
.272 0 .09 r
.45094 .59175 m .44745 .59385 L .44836 .59237 L F
0 .552 .716 r
.25249 .62377 m .25049 .62364 L .24812 .62351 L F
0 0 .479 r
.25249 .62377 m .25224 .62317 L .25049 .62364 L F
.25249 .62377 m .25445 .62627 L .25224 .62317 L F
.15 0 .363 r
.23903 .57445 m .23754 .57297 L .24116 .57248 L F
.23903 .57445 m .23735 .57569 L .23754 .57297 L F
.709 .775 .903 r
.22815 .59427 m .22973 .5961 L .22862 .59782 L F
.22815 .59427 m .23218 .59504 L .22973 .5961 L F
.921 .948 .796 r
.60936 .37394 m .60598 .37621 L .6091 .37325 L F
.60936 .37394 m .60679 .37785 L .60598 .37621 L F
.725 .987 .807 r
.61332 .37031 m .60936 .37394 L .6091 .37325 L F
.454 .543 .858 r
.46626 .55822 m .46458 .56053 L .46307 .55731 L F
.284 .308 .71 r
.46626 .55822 m .46706 .56256 L .46458 .56053 L F
.613 .805 .974 r
.43737 .54841 m .4358 .55036 L .43826 .54945 L F
.704 .984 .829 r
.43737 .54841 m .43348 .5511 L .4358 .55036 L F
.703 .76 .896 r
.62248 .40212 m .62616 .40284 L .62381 .40417 L F
.624 .597 .802 r
.44423 .4811 m .44023 .47955 L .44254 .47888 L F
.467 .769 .996 r
.63416 .39892 m .63279 .40038 L .6314 .39913 L F
.63416 .39892 m .63279 .40038 L .6314 .39913 L F
.808 .816 .857 r
.64182 .34709 m .63722 .34817 L .64034 .34556 L F
.836 .879 .875 r
.64349 .34539 m .64182 .34709 L .64034 .34556 L F
.523 .574 .848 r
.21004 .5983 m .21246 .5985 L .21046 .59437 L F
.909 .949 .814 r
.60598 .37621 m .60679 .37785 L .60478 .38035 L F
.641 .756 .932 r
.62976 .3714 m .63252 .37028 L .63104 .36828 L F
.751 .47 .506 r
.35739 .55696 m .3569 .55988 L .35318 .55912 L F
.101 .428 .871 r
.35229 .53624 m .35368 .53615 L .3532 .53779 L F
.35229 .53624 m .35368 .53615 L .3532 .53779 L F
.497 .295 .536 r
.45038 .49603 m .4505 .4989 L .44795 .49948 L F
.424 .316 .627 r
.45247 .49214 m .45278 .49537 L .45038 .49603 L F
.533 .388 .631 r
.45278 .49537 m .4505 .4989 L .45038 .49603 L F
0 0 .211 r
.3604 .5295 m .36236 .52647 L .36125 .52914 L F
.807 .986 .719 r
.36239 .52694 m .36125 .52914 L .36236 .52647 L F
0 0 .211 r
.3604 .5295 m .36181 .52895 L .36236 .52647 L F
.234 .28 .706 r
.36181 .52895 m .3623 .52539 L .36236 .52647 L F
.3623 .52539 m .36237 .52485 L .36236 .52647 L F
.807 .986 .719 r
.36307 .52564 m .36239 .52694 L .36236 .52647 L F
.564 .344 .539 r
.32383 .60169 m .32374 .60438 L .32112 .6048 L F
.497 .328 .581 r
.32598 .60106 m .32374 .60438 L .32383 .60169 L F
.912 .699 .602 r
.73534 .33647 m .73277 .33658 L .73288 .33509 L F
.73534 .33647 m .73343 .33707 L .73277 .33658 L F
.466 .236 .481 r
.7326 .33972 m .73525 .3393 L .73534 .33647 L F
0 .275 .764 r
.73707 .33681 m .73876 .33867 L .73534 .33647 L F
.73707 .33681 m .73534 .33647 L .73525 .3393 L F
.652 .4 .525 r
.31054 .54297 m .3138 .54363 L .31394 .54092 L F
.762 .495 .53 r
.31394 .54092 m .3138 .54363 L .31771 .54382 L F
.865 .601 .537 r
.38723 .62392 m .38436 .62055 L .38626 .62282 L F
.528 .216 .382 r
.32638 .5214 m .32553 .5243 L .32272 .52447 L F
.533 .55 .818 r
.32751 .51841 m .32638 .5214 L .32527 .51904 L F
.32751 .51841 m .32901 .52131 L .32638 .5214 L F
.652 .337 .426 r
.32932 .52396 m .32638 .5214 L .32901 .52131 L F
.32932 .52396 m .32553 .5243 L .32638 .5214 L F
.225 0 0 r
.30276 .64821 m .30369 .64672 L .30606 .64634 L F
.959 .661 .425 r
.70811 .31578 m .70796 .316 L .70706 .31332 L F
0 0 .398 r
.70706 .31332 m .70813 .3165 L .70802 .31593 L F
0 0 0 r
.70499 .32023 m .70802 .31593 L .70813 .3165 L F
.70499 .32023 m .70656 .31808 L .70723 .31709 L F
.70775 .31631 m .70723 .31709 L .70802 .31593 L F
.70499 .32023 m .70723 .31709 L .70775 .31631 L F
.959 .661 .425 r
.70805 .31409 m .70811 .31578 L .70706 .31332 L F
.70811 .31578 m .70813 .3165 L .70796 .316 L F
0 .127 .655 r
.59523 .40801 m .59457 .40988 L .59378 .40689 L F
0 .36 .746 r
.59645 .41038 m .59457 .40988 L .59523 .40801 L F
.59645 .41038 m .59792 .41131 L .59457 .40988 L F
.022 0 0 r
.27561 .63586 m .27461 .63591 L .27231 .63477 L F
.27561 .63586 m .27714 .63588 L .27461 .63591 L F
.778 .575 .625 r
.54035 .4542 m .54427 .45455 L .54407 .45736 L F
.796 .591 .624 r
.54427 .45455 m .54646 .45811 L .54407 .45736 L F
.429 .07 .252 r
.34724 .67385 m .34582 .67122 L .34456 .67478 L F
.34724 .67385 m .34821 .67117 L .34582 .67122 L F
.635 .326 .43 r
.30341 .55637 m .30619 .5563 L .30637 .55424 L F
.497 .181 .361 r
.30619 .5563 m .30921 .55316 L .30637 .55424 L F
.977 .677 .32 r
.32579 .49788 m .32753 .49976 L .32713 .50196 L F
.522 .492 .764 r
.35535 .5635 m .35791 .56285 L .3569 .55988 L F
.282 .053 .379 r
.35542 .56598 m .35791 .56285 L .35535 .5635 L F
.505 .265 .484 r
.35966 .54349 m .36279 .54018 L .36034 .54075 L F
.529 .883 .983 r
.3515 .52299 m .34875 .52387 L .35063 .52433 L F
.13 .372 .829 r
.35063 .52433 m .35237 .52504 L .3515 .52299 L F
.529 .883 .983 r
.3515 .52299 m .34875 .52387 L .35063 .52433 L F
0 0 .055 r
.34229 .53582 m .342 .53657 L .34267 .53448 L F
.558 .636 .884 r
.38917 .58016 m .39303 .58229 L .39159 .57921 L F
0 0 0 r
.39303 .58229 m .38861 .58478 L .39148 .58485 L F
.725 .48 .555 r
.39148 .58485 m .39577 .58211 L .39303 .58229 L F
.369 .682 .978 r
.36189 .60842 m .36403 .6085 L .36271 .60699 L F
.621 .36 .501 r
.34326 .69672 m .34092 .6939 L .33988 .6947 L F
.34326 .69672 m .34352 .69415 L .34092 .6939 L F
.524 .904 .952 r
.35021 .51541 m .35405 .51483 L .35182 .51586 L F
.794 .936 .923 r
.26123 .57711 m .26267 .57806 L .26497 .57615 L F
.391 .145 .418 r
.35297 .58263 m .35489 .58442 L .35521 .5819 L F
.35297 .58263 m .3526 .58515 L .35489 .58442 L F
0 0 0 r
.22207 .54732 m .22254 .54772 L .22403 .54618 L F
.22207 .54732 m .22102 .5496 L .22254 .54772 L F
.066 .603 .857 r
.34506 .50391 m .33914 .50309 L .34241 .50264 L F
0 .569 .774 r
.34314 .50336 m .34078 .50307 L .33914 .50309 L F
.34078 .50307 m .33899 .50285 L .33914 .50309 L F
0 0 0 r
.33896 .50309 m .33914 .50309 L .3383 .50318 L F
.34241 .50264 m .33914 .50309 L .33896 .50309 L F
.832 .87 .873 r
.65807 .33326 m .6538 .33473 L .65694 .332 L F
.871 .925 .859 r
.66088 .32997 m .65807 .33326 L .65694 .332 L F
.612 .524 .731 r
.45194 .48935 m .44974 .49274 L .44927 .4899 L F
.561 .783 .982 r
.45247 .49214 m .44974 .49274 L .45194 .48935 L F
.85 .805 .807 r
.38001 .63023 m .38322 .63067 L .38072 .63363 L F
.661 .905 .576 r
.38072 .63363 m .38322 .63067 L .38137 .63237 L F
.786 .978 .908 r
.38369 .62836 m .38322 .63067 L .38473 .62873 L F
.849 .952 .603 r
.38137 .63237 m .38322 .63067 L .38369 .62836 L F
.869 .805 .785 r
.66555 .34498 m .66732 .34576 L .66642 .34201 L F
.855 .879 .856 r
.66333 .34723 m .66732 .34576 L .66555 .34498 L F
.807 .772 .821 r
.66642 .34201 m .66732 .34576 L .67 .34268 L F
.369 .799 .968 r
.71936 .35356 m .72235 .35375 L .72122 .35189 L F
.397 .643 .956 r
.72446 .35344 m .72235 .35375 L .72122 .35189 L F
.688 .976 .907 r
.25548 .61379 m .25361 .61482 L .2551 .61303 L F
.604 .394 .569 r
.69339 .32696 m .69628 .32375 L .69203 .323 L F
.69339 .32696 m .69458 .32718 L .69628 .32375 L F
.821 .663 .686 r
.53523 .44185 m .53069 .44374 L .53138 .44117 L F
.53523 .44185 m .53536 .44438 L .53069 .44374 L F
.49 0 .015 r
.24374 .57307 m .23903 .57445 L .24116 .57248 L F
0 .188 .642 r
.38632 .50366 m .3879 .50494 L .38541 .50327 L F
.983 .757 .519 r
.43445 .54414 m .43292 .54438 L .43047 .54354 L F
.43445 .54414 m .43392 .54653 L .43292 .54438 L F
.655 .193 .145 r
.60466 .45748 m .60865 .45781 L .60808 .4597 L F
0 0 0 r
.60865 .45781 m .61109 .45455 L .61089 .45626 L F
.60808 .4597 m .60865 .45781 L .61089 .45626 L F
.497 .181 .361 r
.30619 .5563 m .30856 .55635 L .30921 .55316 L F
.397 .11 .356 r
.30856 .55635 m .3115 .55274 L .30921 .55316 L F
.843 .985 .864 r
.71168 .3361 m .70864 .33909 L .70806 .33805 L F
0 0 0 r
.30124 .64257 m .30229 .64009 L .29793 .64543 L F
.30295 .63588 m .30229 .64009 L .30368 .63717 L F
.30368 .63717 m .30229 .64009 L .30124 .64257 L F
.65 .553 .731 r
.45063 .48293 m .45156 .48669 L .448 .48642 L F
.6 .472 .677 r
.45156 .48669 m .44927 .4899 L .448 .48642 L F
.337 .062 .341 r
.30337 .61451 m .30274 .61673 L .30555 .6138 L F
.842 .952 .887 r
.6018 .38389 m .59797 .38554 L .60086 .38228 L F
.861 .865 .841 r
.60478 .38035 m .6018 .38389 L .60086 .38228 L F
.192 0 .212 r
.34989 .58822 m .3478 .58923 L .34709 .59126 L F
.816 .694 .731 r
.53536 .44438 m .53239 .44768 L .53069 .44374 L F
.642 .279 .341 r
.27353 .56921 m .27172 .57191 L .26946 .57133 L F
.578 .206 .3 r
.27562 .57148 m .27353 .56921 L .27622 .56934 L F
.27562 .57148 m .27172 .57191 L .27353 .56921 L F
.584 .287 .431 r
.5986 .45809 m .5985 .46025 L .59557 .46044 L F
.41 .149 .404 r
.60095 .45956 m .5986 .45809 L .6021 .45739 L F
.60095 .45956 m .5985 .46025 L .5986 .45809 L F
.632 .609 .809 r
.64758 .42515 m .64379 .42208 L .6475 .42245 L F
.654 .677 .859 r
.6475 .42245 m .64889 .41806 L .64767 .42112 L F
.6475 .42245 m .64955 .42195 L .64889 .41806 L F
0 0 .099 r
.64758 .42515 m .6475 .42245 L .64767 .42112 L F
.995 .753 .429 r
.40062 .562 m .40167 .56592 L .40186 .5633 L F
.954 .739 .575 r
.38561 .67631 m .38648 .67516 L .38498 .67149 L F
.243 0 0 r
.38307 .67258 m .3841 .67285 L .38177 .67217 L F
.99 .748 .376 r
.3841 .67285 m .38555 .67617 L .38518 .67313 L F
.38555 .67617 m .38559 .67613 L .38498 .67149 L F
.3841 .67285 m .38518 .67313 L .38498 .67149 L F
.332 .436 .818 r
.38498 .67149 m .38648 .67516 L .38792 .67332 L F
.996 .769 .424 r
.3841 .67285 m .38476 .67696 L .38561 .67631 L F
.792 .668 .727 r
.38792 .67332 m .38476 .67696 L .3841 .67285 L F
.243 0 0 r
.38561 .67337 m .3841 .67285 L .38307 .67258 L F
.99 .748 .376 r
.38555 .67617 m .38561 .67631 L .38559 .67613 L F
.593 .859 .517 r
.38792 .67332 m .38648 .67516 L .38504 .67667 L F
.38486 .67685 m .38504 .67667 L .38476 .67696 L F
.38792 .67332 m .38504 .67667 L .38486 .67685 L F
.874 .947 .588 r
.38476 .67696 m .38648 .67516 L .38561 .67631 L F
.883 .99 .798 r
.69263 .31011 m .69564 .30747 L .69469 .30873 L F
.688 .943 .961 r
.69639 .30508 m .69564 .30747 L .69865 .30592 L F
.758 .868 .44 r
.69469 .30873 m .69564 .30747 L .69639 .30508 L F
0 .018 .587 r
.34798 .60017 m .34632 .59823 L .34882 .59814 L F
.422 .782 .996 r
.27902 .51781 m .27654 .5175 L .27805 .51798 L F
.236 .753 .779 r
.28045 .51736 m .27902 .51781 L .27805 .51798 L F
.123 0 .289 r
.38367 .59126 m .38203 .5924 L .38305 .59076 L F
.38367 .59126 m .38305 .59076 L .38422 .58889 L F
.465 0 0 r
.38367 .59126 m .38416 .59162 L .38391 .59146 L F
.492 .559 .852 r
.38367 .59126 m .38203 .5924 L .37986 .58817 L F
0 0 0 r
.38049 .59367 m .38203 .5924 L .38367 .59126 L F
.847 .942 .884 r
.38049 .59367 m .38367 .59126 L .38211 .59027 L F
.465 0 0 r
.38367 .59126 m .38391 .59146 L .38211 .59027 L F
.499 .329 .581 r
.32112 .6048 m .32113 .60776 L .31865 .60838 L F
0 0 0 r
.33699 .61 m .33684 .61016 L .33574 .61116 L F
.17 0 .349 r
.33522 .61274 m .33684 .61016 L .33418 .60988 L F
.935 .719 .241 r
.33684 .61016 m .33606 .61142 L .33627 .61078 L F
.564 .526 .772 r
.33418 .60988 m .33684 .61016 L .33651 .60706 L F
0 0 .358 r
.33651 .60706 m .33662 .60811 L .3373 .60773 L F
.33662 .60811 m .33684 .61016 L .3373 .60773 L F
.564 .526 .772 r
.33418 .60988 m .33651 .60706 L .33503 .6079 L F
.215 0 0 r
.33558 .60708 m .33757 .60759 L .3373 .60773 L F
.338 0 .135 r
.3405 .60872 m .3375 .60952 L .3408 .60661 L F
.63 .344 .466 r
.3373 .60773 m .34024 .60826 L .34075 .60569 L F
.215 0 0 r
.33757 .60759 m .34024 .60826 L .3373 .60773 L F
.935 .719 .241 r
.33684 .61016 m .33627 .61078 L .3373 .60773 L F
0 0 0 r
.3375 .60952 m .33684 .61016 L .33699 .61 L F
.839 .942 .577 r
.43408 .57786 m .4355 .57643 L .43586 .57455 L F
.009 .485 .87 r
.58526 .39784 m .58188 .39612 L .58444 .39773 L F
.782 .29 0 r
.58458 .39812 m .58526 .39784 L .58444 .39773 L F
.801 .323 0 r
.58458 .39812 m .58638 .39945 L .58526 .39784 L F
0 0 .024 r
.34567 .5925 m .34473 .59461 L .34709 .59126 L F
.516 .473 .747 r
.45082 .51785 m .44933 .52206 L .44907 .51803 L F
.413 .78 .994 r
.2767 .53034 m .27913 .53006 L .27848 .53134 L F
.27848 .53134 m .27913 .53006 L .2767 .53034 L F
.846 .792 .799 r
.42732 .5885 m .42939 .58659 L .42642 .58539 L F
.579 .191 .271 r
.43094 .58783 m .42939 .58659 L .42732 .5885 L F
.792 .41 .332 r
.32981 .50257 m .32683 .5042 L .32713 .50196 L F
.32981 .50257 m .33152 .50513 L .32683 .5042 L F
.224 .035 .401 r
.31928 .58229 m .3211 .58421 L .32073 .58096 L F
.31928 .58229 m .31838 .5853 L .3211 .58421 L F
.824 .855 .87 r
.43213 .47356 m .42812 .47386 L .43028 .47225 L F
.792 .878 .91 r
.43461 .4709 m .43213 .47356 L .43028 .47225 L F
.136 .014 .436 r
.3798 .65194 m .3781 .65277 L .37802 .65572 L F
.123 .603 .915 r
.33004 .53696 m .33255 .53728 L .32825 .53584 L F
0 0 .285 r
.43049 .5579 m .43006 .5571 L .43054 .5554 L F
.43049 .5579 m .43099 .55979 L .43006 .5571 L F
.586 .347 .521 r
.31643 .61446 m .31624 .61703 L .31356 .61734 L F
.525 .283 .491 r
.31935 .61408 m .31624 .61703 L .31643 .61446 L F
.239 0 .268 r
.3526 .58515 m .35064 .58602 L .34989 .58822 L F
0 .075 .625 r
.31901 .66572 m .31858 .66586 L .31677 .66588 L F
.31901 .66572 m .32074 .66828 L .31858 .66586 L F
.047 .18 .681 r
.42866 .54773 m .42896 .54867 L .42762 .54962 L F
.527 .555 .827 r
.42956 .55139 m .42686 .55016 L .42762 .54962 L F
.674 .233 .194 r
.42762 .54962 m .43165 .54991 L .42956 .55139 L F
.42762 .54962 m .43015 .55229 L .43165 .54991 L F
.047 .18 .681 r
.42896 .54867 m .43015 .55229 L .42762 .54962 L F
.527 .555 .827 r
.42686 .55016 m .42631 .54991 L .42762 .54962 L F
.215 0 .286 r
.71225 .35494 m .71011 .35589 L .7096 .35784 L F
.71225 .35494 m .71011 .35589 L .7096 .35784 L F
.835 .636 .634 r
.54646 .45811 m .54255 .45997 L .54407 .45736 L F
.54646 .45811 m .54612 .46076 L .54255 .45997 L F
.571 .43 .651 r
.4505 .4989 m .44815 .50221 L .44795 .49948 L F
.307 .436 .829 r
.3745 .57882 m .37612 .58241 L .37574 .58204 L F
.82 .713 .746 r
.37685 .57999 m .37612 .58241 L .37587 .58185 L F
.37624 .57969 m .37587 .58185 L .3745 .57882 L F
.37685 .57999 m .37587 .58185 L .37624 .57969 L F
.193 0 .046 r
.37585 .58194 m .37701 .58348 L .37707 .58082 L F
.37574 .58204 m .37582 .58213 L .37585 .58194 L F
.37582 .58213 m .37701 .58348 L .37585 .58194 L F
.123 .308 .778 r
.37574 .58204 m .37707 .58082 L .3745 .57882 L F
.193 0 .046 r
.37574 .58204 m .37487 .58416 L .37701 .58348 L F
.773 .362 0 r
.39941 .55292 m .40054 .55551 L .40059 .55493 L F
0 0 .39 r
.40041 .55423 m .40054 .55551 L .39941 .55292 L F
.983 .865 .494 r
.40041 .55423 m .40052 .55582 L .40054 .55551 L F
.40052 .55582 m .40062 .55738 L .40054 .55551 L F
.773 .362 0 r
.40059 .55493 m .40054 .55551 L .40159 .55663 L F
.981 .733 .331 r
.40054 .55551 m .40167 .55672 L .40159 .55663 L F
.694 .229 .143 r
.25983 .62799 m .25445 .62627 L .25596 .62753 L F
.013 .21 .72 r
.32577 .55024 m .32512 .54631 L .32871 .54682 L F
.32577 .55024 m .32656 .54872 L .32512 .54631 L F
0 0 .322 r
.32642 .55218 m .32656 .54872 L .32577 .55024 L F
.27 0 0 r
.36157 .52152 m .36215 .52184 L .35967 .52225 L F
.36439 .52045 m .36215 .52184 L .36157 .52152 L F
.397 0 0 r
.36519 .52341 m .36425 .52306 L .36215 .52184 L F
.572 .001 0 r
.36425 .52306 m .36328 .52246 L .36215 .52184 L F
.36328 .52246 m .35989 .5204 L .36215 .52184 L F
.723 .981 .909 r
.35989 .5204 m .35967 .52225 L .36215 .52184 L F
.35989 .5204 m .35718 .52248 L .35967 .52225 L F
.829 .982 .88 r
.67162 .397 m .67488 .39422 L .67414 .39318 L F
.849 .974 .871 r
.67488 .39422 m .67781 .39143 L .67542 .39152 L F
.866 .984 .842 r
.67414 .39318 m .67488 .39422 L .67542 .39152 L F
.622 .736 .928 r
.35298 .51021 m .35415 .5121 L .35662 .51124 L F
.741 .672 .783 r
.61805 .44083 m .61898 .44455 L .62209 .44205 L F
.759 .407 0 r
.70643 .30409 m .70717 .30625 L .7081 .30806 L F
0 0 .413 r
.70717 .30625 m .70917 .30977 L .7081 .30806 L F
.938 .598 .359 r
.39731 .54932 m .39765 .55172 L .39926 .55049 L F
.97 .679 .416 r
.39765 .55172 m .39941 .55292 L .39926 .55049 L F
.539 .745 .971 r
.25103 .56751 m .25021 .56962 L .24867 .56783 L F
.25103 .56751 m .25254 .56907 L .25021 .56962 L F
.796 .998 .854 r
.25103 .56751 m .25021 .56962 L .25254 .56907 L F
.25103 .56751 m .24712 .57036 L .25021 .56962 L F
.707 .274 0 r
.60429 .42266 m .60227 .41959 L .60312 .42128 L F
.826 .389 0 r
.60394 .42348 m .60429 .42266 L .60312 .42128 L F
.60394 .42348 m .60544 .42497 L .60429 .42266 L F
.473 .253 .498 r
.24992 .53728 m .2495 .54024 L .24712 .5408 L F
.24712 .5408 m .2495 .54024 L .24992 .53728 L F
.428 .214 .484 r
.25206 .537 m .2495 .54024 L .24992 .53728 L F
.25206 .537 m .2495 .54024 L .24992 .53728 L F
.473 .253 .498 r
.24992 .53728 m .2495 .54024 L .24712 .5408 L F
0 .428 .725 r
.34711 .4974 m .34971 .4981 L .35169 .49877 L F
0 .383 .753 r
.35181 .49852 m .35169 .49877 L .34971 .4981 L F
.35181 .49852 m .35349 .49946 L .35169 .49877 L F
.603 .725 .93 r
.60859 .35717 m .60703 .36048 L .60577 .358 L F
.60859 .35717 m .60977 .3598 L .60703 .36048 L F
.869 .872 .837 r
.67353 .33416 m .67746 .33263 L .67624 .33101 L F
0 0 0 r
.29218 .51369 m .29124 .51368 L .29022 .51472 L F
.29218 .51369 m .29388 .51287 L .29124 .51368 L F
0 0 .112 r
.22584 .59622 m .22544 .59462 L .22815 .59427 L F
.22584 .59622 m .22538 .59779 L .22544 .59462 L F
.51 .088 .174 r
.6021 .45739 m .60315 .45943 L .60095 .45956 L F
.6021 .45739 m .60466 .45748 L .60315 .45943 L F
.306 .224 .597 r
.69277 .37366 m .69137 .38005 L .69047 .37443 L F
.995 .758 .444 r
.62733 .41165 m .62793 .40922 L .62628 .40791 L F
.945 .908 .753 r
.62628 .40791 m .62793 .40922 L .62833 .40713 L F
.828 .783 .81 r
.46209 .47348 m .45915 .47282 L .46078 .47062 L F
0 0 .444 r
.46335 .46931 m .46209 .47348 L .46078 .47062 L F
.46335 .46931 m .46357 .47227 L .46209 .47348 L F
.494 .904 .831 r
.46209 .47348 m .46357 .47227 L .46125 .4735 L F
.496 .23 .44 r
.46357 .47227 m .46203 .47389 L .46125 .4735 L F
.46203 .47389 m .46051 .47549 L .46125 .4735 L F
.36 0 0 r
.46052 .47313 m .46125 .4735 L .45915 .47282 L F
.46209 .47348 m .46125 .4735 L .46052 .47313 L F
.112 0 0 r
.39663 .68384 m .39932 .68328 L .40143 .68142 L F
0 .314 .804 r
.40143 .68142 m .4018 .67997 L .39905 .67786 L F
.704 .738 .226 r
.40246 .6779 m .4018 .67997 L .40143 .68142 L F
0 0 0 r
.61089 .45626 m .61109 .45455 L .6125 .45265 L F
.6 .472 .677 r
.45156 .48669 m .45194 .48935 L .44927 .4899 L F
.756 .786 .877 r
.63869 .44212 m .63985 .43782 L .63725 .4403 L F
.63869 .44212 m .64054 .44063 L .63985 .43782 L F
.854 .871 .852 r
.72871 .34145 m .7326 .33972 L .73153 .33806 L F
.925 .571 .134 r
.40204 .57113 m .40254 .56993 L .40153 .56858 L F
.40204 .57113 m .40316 .57226 L .40254 .56993 L F
.476 .87 .689 r
.66818 .39905 m .67162 .397 L .66999 .39742 L F
.829 .982 .88 r
.67162 .397 m .67414 .39318 L .67155 .39632 L F
.75 .99 .792 r
.66999 .39742 m .67162 .397 L .67155 .39632 L F
.557 .298 .478 r
.35847 .53709 m .35597 .53829 L .35972 .53769 L F
.549 .502 .756 r
.36112 .53367 m .35972 .53769 L .35854 .53421 L F
.36112 .53367 m .36216 .53709 L .35972 .53769 L F
.62 .208 .241 r
.36043 .53928 m .35972 .53769 L .36216 .53709 L F
.36043 .53928 m .35847 .53709 L .35972 .53769 L F
.652 .888 .54 r
.3885 .66407 m .38765 .66553 L .39021 .66229 L F
.559 .38 .596 r
.38765 .66553 m .39021 .66537 L .39021 .66229 L F
.435 .766 .997 r
.3885 .66407 m .39021 .66537 L .38765 .66553 L F
.709 .95 .954 r
.38607 .67746 m .38401 .67885 L .3825 .67823 L F
.38607 .67746 m .38401 .67885 L .3825 .67823 L F
0 0 0 r
.35117 .59562 m .35486 .59154 L .35334 .59318 L F
.35117 .59562 m .35334 .59318 L .35201 .59487 L F
.35087 .59706 m .35117 .59562 L .35201 .59487 L F
.85 .805 .807 r
.38001 .63023 m .38072 .63363 L .37902 .63334 L F
.51 .892 .961 r
.37902 .63334 m .38072 .63363 L .38137 .63237 L F
.514 .477 .753 r
.45364 .53046 m .45233 .53543 L .45118 .53109 L F
.45364 .53046 m .45444 .53446 L .45233 .53543 L F
.376 .312 .657 r
.45444 .53446 m .45305 .53733 L .45233 .53543 L F
.736 .979 .916 r
.67542 .39152 m .67781 .39143 L .67972 .38971 L F
.811 .774 .818 r
.62771 .35399 m .62958 .35554 L .62609 .35534 L F
.79 .775 .839 r
.63248 .35259 m .62958 .35554 L .62771 .35399 L F
.973 .684 .416 r
.25653 .5691 m .25677 .5721 L .2549 .56849 L F
.77 .291 .096 r
.39383 .65523 m .39204 .65263 L .38972 .65248 L F
.796 .753 .813 r
.54302 .41514 m .53817 .41723 L .54098 .41429 L F
.912 .821 .744 r
.54351 .41363 m .54302 .41514 L .54098 .41429 L F
.873 .719 .688 r
.35802 .51526 m .35615 .51494 L .35662 .51124 L F
.146 .417 .86 r
.35783 .51665 m .35615 .51494 L .35802 .51526 L F
.006 .433 .863 r
.37171 .60461 m .37003 .60679 L .36931 .60365 L F
.37171 .60461 m .37196 .6036 L .37003 .60679 L F
.37171 .60461 m .37439 .60599 L .37196 .6036 L F
.87 .858 .827 r
.31393 .66597 m .31175 .66871 L .31244 .66727 L F
.377 .706 .985 r
.31175 .66871 m .3141 .6687 L .31244 .66727 L F
.414 .105 .33 r
.46211 .58163 m .45872 .58503 L .4594 .58211 L F
.594 .533 .756 r
.41032 .4982 m .40862 .50143 L .40753 .49913 L F
.376 .312 .657 r
.45444 .53446 m .45497 .53689 L .45305 .53733 L F
.435 .365 .679 r
.45497 .53689 m .45353 .54019 L .45305 .53733 L F
.877 .474 .261 r
.52605 .42495 m .52848 .42573 L .52704 .42711 L F
.874 .47 .258 r
.52704 .42711 m .52848 .42573 L .52928 .42793 L F
0 0 0 r
.57165 .41755 m .57273 .41669 L .56957 .41878 L F
.971 .669 .284 r
.57165 .41755 m .57273 .41669 L .5708 .41267 L F
.501 0 0 r
.5754 .41798 m .57273 .41669 L .57165 .41755 L F
.254 0 0 r
.26873 .63455 m .27024 .63419 L .27231 .63477 L F
0 0 0 r
.55307 .41952 m .55574 .41576 L .55475 .41637 L F
.896 .891 .469 r
.3881 .70037 m .38912 .69776 L .38892 .69633 L F
.542 .918 .937 r
.38917 .58016 m .38985 .57906 L .38721 .57931 L F
.38917 .58016 m .39159 .57921 L .38985 .57906 L F
0 0 .408 r
.20859 .57884 m .20942 .57451 L .2081 .57611 L F
.244 .073 .44 r
.3215 .57847 m .3238 .57821 L .32391 .57539 L F
.282 0 .249 r
.32073 .58096 m .3238 .57821 L .3215 .57847 L F
.792 .94 .924 r
.42057 .48036 m .41709 .48129 L .41951 .47995 L F
.835 .999 .813 r
.42293 .47754 m .42057 .48036 L .42109 .47817 L F
.809 .99 .878 r
.42057 .48036 m .41951 .47995 L .42109 .47817 L F
.383 .002 .187 r
.3413 .57569 m .34278 .57668 L .34368 .57519 L F
.725 .58 .692 r
.34277 .57667 m .33959 .57467 L .34195 .5743 L F
.34278 .57668 m .34276 .57667 L .34277 .57667 L F
.383 .002 .187 r
.3413 .57569 m .34017 .5781 L .34278 .57668 L F
.725 .58 .692 r
.34276 .57667 m .33959 .57467 L .34277 .57667 L F
.376 0 .184 r
.33758 .57877 m .34017 .5781 L .34073 .5769 L F
.33969 .57702 m .34073 .5769 L .3413 .57569 L F
.33758 .57877 m .34073 .5769 L .33969 .57702 L F
.57 .891 .625 r
.64478 .40163 m .64323 .40332 L .64605 .40072 L F
.612 .955 .89 r
.64251 .40302 m .64323 .40332 L .64478 .40163 L F
.211 .108 .512 r
.36458 .58442 m .3627 .58245 L .36464 .58149 L F
.36458 .58442 m .36279 .58519 L .3627 .58245 L F
.876 .612 .537 r
.36061 .69425 m .35854 .69559 L .3596 .69425 L F
.36061 .69425 m .36073 .69727 L .35854 .69559 L F
.312 .176 .53 r
.36061 .69425 m .36073 .69727 L .36245 .69328 L F
.965 .636 .306 r
.58969 .38941 m .59116 .39061 L .59148 .39303 L F
.721 .64 .767 r
.34678 .5566 m .34839 .56012 L .34952 .55785 L F
0 .237 .747 r
.34945 .5594 m .35069 .56246 L .34854 .56028 L F
.5 .364 .627 r
.34839 .56012 m .35069 .56246 L .34828 .56287 L F
.067 0 0 r
.3481 .56078 m .34981 .55906 L .34945 .5594 L F
.261 .564 .935 r
.34952 .55785 m .35318 .55912 L .3516 .55727 L F
.819 .762 .8 r
.35318 .55912 m .34945 .5594 L .3516 .55727 L F
.067 0 0 r
.34981 .55906 m .3516 .55727 L .34945 .5594 L F
0 .237 .747 r
.34945 .5594 m .34854 .56028 L .34839 .56012 L F
.836 .879 .875 r
.64349 .34539 m .64034 .34556 L .64212 .34395 L F
.805 .879 .9 r
.64683 .34242 m .64349 .34539 L .64212 .34395 L F
0 0 0 r
.33494 .57934 m .33283 .58241 L .33192 .57937 L F
.33494 .57934 m .33282 .58302 L .33283 .58241 L F
.33283 .58241 m .33282 .58302 L .33494 .57934 L F
.971 .825 .409 r
.46349 .46407 m .46234 .46633 L .46297 .46673 L F
.92 .948 .798 r
.54476 .41102 m .54351 .41363 L .5436 .41075 L F
.912 .821 .744 r
.54351 .41363 m .54098 .41429 L .5436 .41075 L F
.229 .723 .917 r
.31534 .66534 m .31677 .66588 L .31393 .66597 L F
.31534 .66534 m .31393 .66597 L .31244 .66727 L F
.042 .058 .549 r
.74323 .32919 m .74401 .33208 L .74282 .3321 L F
.565 .923 .949 r
.57607 .40974 m .57844 .40927 L .57601 .40935 L F
.818 .402 .256 r
.57601 .40935 m .57844 .40927 L .57954 .41183 L F
0 .265 .671 r
.38231 .54854 m .38081 .5476 L .38079 .54767 L F
.902 .914 .82 r
.38231 .54854 m .38194 .54996 L .38081 .5476 L F
.797 .886 .909 r
.38175 .54756 m .38194 .54996 L .38441 .54745 L F
.64 .58 .771 r
.38194 .54996 m .38609 .55054 L .38441 .54745 L F
.797 .886 .909 r
.38081 .5476 m .38441 .54745 L .38326 .54569 L F
.468 .644 .934 r
.38441 .54745 m .38559 .54527 L .38326 .54569 L F
.404 .172 .445 r
.38559 .54527 m .3835 .54859 L .38331 .54624 L F
.38413 .54553 m .38331 .54624 L .38326 .54569 L F
.38559 .54527 m .38331 .54624 L .38413 .54553 L F
.797 .886 .909 r
.38081 .5476 m .38107 .54813 L .38175 .54756 L F
.38107 .54813 m .38194 .54996 L .38175 .54756 L F
.023 .202 .71 r
.38194 .54996 m .38442 .55225 L .38609 .55054 L F
.736 .453 .501 r
.36631 .52164 m .36215 .52184 L .36439 .52045 L F
.861 .865 .841 r
.60478 .38035 m .60086 .38228 L .60359 .37927 L F
.909 .949 .814 r
.60598 .37621 m .60478 .38035 L .60359 .37927 L F
.269 .266 .672 r
.34894 .56551 m .34906 .56945 L .34802 .56732 L F
.754 .28 0 r
.60972 .43215 m .60673 .42832 L .60829 .43099 L F
.941 .573 .214 r
.60829 .43099 m .61029 .4344 L .60972 .43215 L F
.193 0 0 r
.23699 .55324 m .23242 .55546 L .23538 .5539 L F
.23699 .55324 m .23442 .55506 L .23242 .55546 L F
.465 0 0 r
.35962 .68449 m .36191 .68506 L .35849 .68379 L F
.475 0 0 r
.3639 .68625 m .36191 .68506 L .35962 .68449 L F
.527 .374 .616 r
.36191 .68506 m .36449 .68431 L .36422 .68135 L F
.447 .179 .414 r
.3639 .68625 m .36449 .68431 L .36191 .68506 L F
.864 .993 .749 r
.33099 .54427 m .33016 .54399 L .33129 .54204 L F
.519 .141 .263 r
.33331 .54594 m .33084 .54692 L .33099 .54427 L F
.491 .158 .33 r
.33352 .5439 m .33331 .54594 L .33099 .54427 L F
.841 .663 .661 r
.64697 .42759 m .64897 .43154 L .6489 .42898 L F
.22 .435 .857 r
.37812 .60884 m .37907 .61128 L .38049 .60986 L F
0 0 .489 r
.37907 .61128 m .38073 .61134 L .38049 .60986 L F
0 .167 .698 r
.37907 .61128 m .38136 .61356 L .38073 .61134 L F
.985 .742 .484 r
.39021 .66229 m .39021 .66537 L .3885 .66407 L F
.943 .691 .525 r
.53178 .43172 m .52927 .43117 L .52928 .42793 L F
.905 .72 .641 r
.53178 .43172 m .52815 .4335 L .52927 .43117 L F
.53178 .43172 m .53025 .43471 L .52815 .4335 L F
.66 .567 .74 r
.69136 .38074 m .68903 .384 L .68895 .38172 L F
.511 .37 .625 r
.69136 .38074 m .69187 .38332 L .68903 .384 L F
.724 .948 .952 r
.69187 .38332 m .68741 .38435 L .68903 .384 L F
.462 .808 .998 r
.37209 .57926 m .3745 .57882 L .37044 .57829 L F
.83 .902 .89 r
.53089 .4128 m .53199 .41461 L .52953 .41638 L F
.76 .914 .942 r
.41182 .4851 m .41293 .48215 L .41411 .48299 L F
.41182 .4851 m .40981 .48414 L .41293 .48215 L F
.985 .902 .633 r
.71136 .31771 m .71241 .32047 L .71304 .31595 L F
0 0 .155 r
.71324 .32038 m .71241 .32047 L .71136 .31771 L F
.71324 .32038 m .71232 .32263 L .71241 .32047 L F
.857 .692 .677 r
.71297 .32916 m .71439 .33291 L .71099 .33231 L F
.86 .845 .829 r
.71439 .33291 m .71012 .33466 L .71099 .33231 L F
.71439 .33291 m .71168 .3361 L .71012 .33466 L F
.743 .642 .747 r
.71488 .32958 m .71439 .33291 L .71297 .32916 L F
.008 0 0 r
.35279 .67055 m .34821 .67117 L .35123 .67173 L F
.665 .265 .279 r
.35123 .67173 m .35461 .67161 L .35279 .67055 L F
.64 .691 .882 r
.62216 .38243 m .62528 .38136 L .62061 .38001 L F
.893 .775 .724 r
.53379 .43537 m .53007 .43735 L .53025 .43471 L F
.53379 .43537 m .53211 .43866 L .53007 .43735 L F
.495 .875 .975 r
.68002 .36378 m .67825 .36532 L .67566 .36533 L F
.68002 .36378 m .68098 .36446 L .67825 .36532 L F
.843 .985 .864 r
.71168 .3361 m .70806 .33805 L .71012 .33466 L F
.774 .268 0 r
.32524 .69425 m .32768 .69658 L .32663 .69605 L F
0 .031 .601 r
.32524 .69425 m .32663 .69605 L .32529 .69268 L F
.133 .125 .582 r
.43839 .57889 m .44017 .57835 L .43953 .57523 L F
0 0 0 r
.43548 .58063 m .44017 .57835 L .43839 .57889 L F
.715 .665 .799 r
.5591 .41042 m .55447 .40927 L .55768 .40876 L F
.753 .499 .549 r
.5591 .41042 m .56235 .41311 L .55762 .41271 L F
.838 .65 .649 r
.43069 .52728 m .43119 .53082 L .43403 .52801 L F
.908 .981 .778 r
.43403 .52801 m .43119 .53082 L .43283 .52792 L F
.304 0 0 r
.43403 .52801 m .43297 .52793 L .43069 .52728 L F
.559 .555 .806 r
.43297 .52793 m .43322 .52732 L .4312 .52322 L F
.43069 .52728 m .42932 .52401 L .4286 .52708 L F
.43061 .52708 m .4312 .52322 L .42932 .52401 L F
.43069 .52728 m .43072 .52704 L .43061 .52708 L F
.43072 .52704 m .4312 .52322 L .43061 .52708 L F
.43069 .52728 m .43297 .52793 L .43239 .52638 L F
.43069 .52728 m .43239 .52638 L .43072 .52704 L F
.897 .65 .139 r
.43009 .52732 m .43119 .53082 L .43069 .52728 L F
.908 .981 .778 r
.43403 .52801 m .43297 .52793 L .43408 .5257 L F
.666 .607 .78 r
.4312 .52322 m .43322 .52732 L .43408 .5257 L F
.908 .981 .778 r
.43297 .52793 m .43334 .52701 L .43408 .5257 L F
.666 .607 .78 r
.43322 .52732 m .43361 .52811 L .43408 .5257 L F
.908 .981 .778 r
.43322 .52732 m .43283 .52792 L .43334 .52701 L F
.43297 .52793 m .43289 .52792 L .43322 .52732 L F
.43289 .52792 m .43283 .52792 L .43322 .52732 L F
.872 .881 .839 r
.43408 .5257 m .43119 .53082 L .43009 .52732 L F
.43364 .52588 m .43306 .52612 L .43403 .52573 L F
.43306 .52612 m .43009 .52732 L .43332 .52602 L F
.43306 .52612 m .43332 .52602 L .43403 .52573 L F
.43403 .52573 m .43009 .52732 L .43371 .52588 L F
.43408 .5257 m .43364 .52588 L .43403 .52573 L F
.559 .555 .806 r
.43072 .52704 m .43239 .52638 L .4312 .52322 L F
.304 0 0 r
.43403 .52801 m .43361 .52811 L .43297 .52793 L F
.559 .555 .806 r
.43297 .52793 m .43361 .52811 L .43322 .52732 L F
.888 .853 .399 r
.43408 .5257 m .43361 .52811 L .43403 .52801 L F
.715 .526 .633 r
.55762 .41271 m .56003 .41602 L .55574 .41576 L F
.671 .517 .667 r
.55762 .41271 m .56235 .41311 L .56003 .41602 L F
.77 .982 .726 r
.69438 .36459 m .69717 .36096 L .69657 .36322 L F
.69438 .36459 m .69657 .36322 L .69454 .36441 L F
.816 .712 .75 r
.64379 .42208 m .64532 .42696 L .64381 .4245 L F
.759 .697 .792 r
.64381 .4245 m .64532 .42696 L .64175 .42847 L F
.632 .609 .809 r
.64758 .42515 m .64532 .42696 L .64379 .42208 L F
.395 .212 .512 r
.64697 .42759 m .64532 .42696 L .64758 .42515 L F
.645 .547 .729 r
.29558 .5616 m .29197 .5632 L .29147 .55983 L F
.274 0 .171 r
.29365 .56383 m .29197 .5632 L .29558 .5616 L F
.29365 .56383 m .2912 .56462 L .29197 .5632 L F
.934 .865 .747 r
.65059 .41946 m .65258 .41608 L .65119 .41462 L F
.792 .871 .907 r
.65119 .41462 m .65258 .41608 L .65557 .41326 L F
.383 .708 .986 r
.63252 .37028 m .63645 .37163 L .63499 .37002 L F
.843 .859 .856 r
.63499 .37002 m .63645 .37163 L .6394 .36834 L F
.332 .082 .377 r
.38367 .59126 m .38422 .58889 L .38639 .58808 L F
.38367 .59126 m .38422 .58889 L .38639 .58808 L F
.28 .566 .934 r
.35455 .67686 m .35524 .67862 L .35372 .67834 L F
0 0 0 r
.70499 .32023 m .7023 .32349 L .70447 .3214 L F
.112 .018 .46 r
.70243 .32589 m .70447 .3214 L .7023 .32349 L F
.825 .719 .748 r
.23642 .54294 m .23841 .54592 L .24051 .54362 L F
.463 0 0 r
.24051 .54362 m .23962 .54481 L .23642 .54294 L F
0 0 .573 r
.23884 .53983 m .24045 .54179 L .24051 .54362 L F
.82 .791 .292 r
.24049 .54304 m .23987 .54435 L .24051 .54362 L F
.23987 .54435 m .23973 .54467 L .23997 .54434 L F
.23987 .54435 m .23997 .54434 L .24051 .54362 L F
.24045 .54179 m .23994 .5438 L .24049 .54304 L F
.23994 .5438 m .23973 .54467 L .24049 .54304 L F
.883 .625 .543 r
.24089 .54457 m .23962 .54481 L .23987 .54391 L F
.718 .186 0 r
.24089 .54457 m .23987 .54391 L .23994 .5438 L F
.24089 .54457 m .23994 .5438 L .24045 .54179 L F
.23994 .5438 m .23683 .54128 L .24045 .54179 L F
.82 .791 .292 r
.24045 .54179 m .23973 .54442 L .23973 .54467 L F
.23973 .54442 m .23962 .54481 L .23971 .54469 L F
.23973 .54442 m .23971 .54469 L .23973 .54467 L F
.883 .625 .543 r
.24089 .54457 m .23987 .54391 L .24045 .54179 L F
.718 .186 0 r
.23994 .5438 m .23987 .54391 L .23683 .54128 L F
.756 .482 .518 r
.23683 .54128 m .23935 .54446 L .23966 .54372 L F
.23935 .54446 m .23973 .54442 L .24045 .54179 L F
0 .223 .739 r
.23642 .54294 m .23934 .54464 L .23683 .54128 L F
.23934 .54464 m .23962 .54481 L .23935 .54446 L F
.23934 .54464 m .23935 .54446 L .23683 .54128 L F
.676 .896 .976 r
.23975 .54408 m .23937 .54411 L .23973 .54436 L F
.23937 .54411 m .23868 .54417 L .23936 .54429 L F
.23937 .54411 m .23936 .54429 L .23973 .54436 L F
.718 .186 0 r
.23987 .54391 m .23975 .54408 L .23683 .54128 L F
.676 .896 .976 r
.23979 .5433 m .23914 .54381 L .23975 .54408 L F
.23914 .54381 m .23868 .54417 L .23975 .54408 L F
.181 0 0 r
.23868 .54417 m .23957 .54437 L .23973 .54436 L F
.382 .287 .623 r
.23914 .54381 m .23967 .5444 L .23868 .54417 L F
.718 .186 0 r
.23975 .54408 m .23958 .5443 L .23914 .54381 L F
.23975 .54408 m .23913 .54381 L .23683 .54128 L F
.756 .482 .518 r
.23683 .54128 m .23966 .54372 L .24045 .54179 L F
.718 .186 0 r
.24089 .54457 m .23975 .54408 L .23987 .54391 L F
.676 .896 .976 r
.23979 .5433 m .23975 .54408 L .24089 .54457 L F
.23975 .54408 m .23973 .54436 L .24089 .54457 L F
.718 .186 0 r
.24089 .54457 m .23958 .5443 L .23975 .54408 L F
.181 0 0 r
.23957 .54437 m .23967 .5444 L .23973 .54436 L F
.382 .287 .623 r
.24073 .54256 m .23967 .5444 L .23914 .54381 L F
.718 .186 0 r
.23914 .54381 m .23958 .5443 L .23913 .54381 L F
.23958 .5443 m .23958 .5443 L .23914 .54381 L F
.756 .482 .518 r
.23935 .54446 m .23962 .54481 L .23973 .54442 L F
0 0 .163 r
.24073 .54256 m .24089 .54457 L .24045 .54179 L F
.676 .896 .976 r
.24073 .54256 m .23979 .5433 L .24067 .54432 L F
.24087 .54429 m .24067 .54432 L .24089 .54457 L F
.24073 .54256 m .24067 .54432 L .24087 .54429 L F
.181 0 0 r
.23973 .54436 m .23967 .5444 L .24089 .54457 L F
.718 .186 0 r
.24089 .54457 m .23967 .5444 L .23958 .5443 L F
.766 .254 0 r
.35803 .71459 m .3588 .71755 L .35757 .7142 L F
.679 .671 .835 r
.4386 .47345 m .43461 .4709 L .43721 .46987 L F
.736 .713 .829 r
.44103 .47069 m .4386 .47345 L .43721 .46987 L F
.877 .458 .036 r
.39582 .54333 m .39836 .54704 L .39815 .54606 L F
.617 .648 .858 r
.42302 .58832 m .42489 .59159 L .42499 .59077 L F
.842 .998 .824 r
.42499 .59077 m .42505 .59071 L .42541 .58925 L F
.42505 .59071 m .42732 .5885 L .42541 .58925 L F
.99 .875 .617 r
.42478 .58591 m .42541 .58925 L .42642 .58539 L F
.17 .292 .747 r
.4259 .58728 m .42541 .58925 L .42478 .58591 L F
.846 .792 .799 r
.42732 .5885 m .42642 .58539 L .42541 .58925 L F
.17 .292 .747 r
.4284 .59034 m .42541 .58925 L .4259 .58728 L F
.842 .998 .824 r
.42499 .59077 m .42541 .58925 L .42302 .58832 L F
.196 .41 .844 r
.42644 .59168 m .42489 .59159 L .42302 .58832 L F
0 0 0 r
.70499 .32023 m .70447 .3214 L .70656 .31808 L F
.892 .73 .222 r
.64382 .41511 m .64414 .41936 L .64493 .41747 L F
.099 .655 .781 r
.32768 .69658 m .3278 .69637 L .32663 .69605 L F
.973 .669 .37 r
.61081 .41153 m .61246 .41264 L .61262 .41529 L F
.098 .36 .827 r
.24829 .53135 m .25005 .52932 L .24659 .53122 L F
.583 .831 .462 r
.35718 .52248 m .35573 .52434 L .35583 .52428 L F
.185 0 .233 r
.707 .32982 m .70667 .33189 L .70458 .33327 L F
.731 .54 .633 r
.71239 .32869 m .70667 .33189 L .707 .32982 L F
.107 0 0 r
.33269 .49503 m .33684 .4953 L .33491 .49513 L F
.019 0 0 r
.33878 .59302 m .33818 .59195 L .33914 .59066 L F
.33878 .59302 m .33671 .59392 L .33818 .59195 L F
.915 .867 .777 r
.56107 .40651 m .55768 .40876 L .55895 .40766 L F
.664 .234 .217 r
.33349 .52343 m .33088 .5253 L .32932 .52396 L F
.739 .562 .653 r
.3311 .52665 m .33334 .52767 L .33349 .52343 L F
.748 .748 .852 r
.33585 .5215 m .33349 .52343 L .3317 .52098 L F
0 0 .074 r
.33349 .52343 m .33334 .52767 L .3338 .52457 L F
.33349 .52343 m .3338 .52457 L .33088 .5253 L F
.4 0 .051 r
.58664 .46441 m .58574 .46617 L .58274 .46643 L F
.107 0 0 r
.58937 .46393 m .58574 .46617 L .58664 .46441 L F
.643 .947 .725 r
.42908 .5034 m .42735 .50422 L .42636 .50576 L F
.985 .79 .559 r
.42444 .50725 m .42636 .50576 L .42735 .50422 L F
.42444 .50725 m .42605 .50858 L .42636 .50576 L F
.724 .665 .791 r
.29199 .54974 m .29611 .55111 L .29403 .54923 L F
.627 .791 .961 r
.29403 .54923 m .29611 .55111 L .29835 .55006 L F
.563 .438 .667 r
.35524 .57913 m .35752 .57565 L .35501 .5767 L F
.35524 .57913 m .35803 .57875 L .35752 .57565 L F
.482 .255 .493 r
.35521 .5819 m .35803 .57875 L .35524 .57913 L F
.657 .627 .808 r
.71095 .3621 m .71481 .36501 L .7136 .36112 L F
.778 .774 .849 r
.71481 .36501 m .71623 .36048 L .7136 .36112 L F
.71481 .36501 m .71801 .36228 L .71623 .36048 L F
.986 .745 .487 r
.3442 .57381 m .34207 .5714 L .34498 .57187 L F
.3442 .57381 m .34195 .5743 L .34207 .5714 L F
.993 .816 .561 r
.3442 .57381 m .34278 .57668 L .34195 .5743 L F
.543 .207 .348 r
.34368 .57519 m .34278 .57668 L .3442 .57381 L F
.834 .721 .739 r
.66642 .34201 m .67 .34268 L .66872 .33877 L F
.738 .616 .722 r
.25855 .54944 m .25525 .54748 L .25744 .54686 L F
.25855 .54944 m .25551 .55032 L .25525 .54748 L F
.147 0 .305 r
.25691 .55161 m .25551 .55032 L .25855 .54944 L F
.668 .658 .831 r
.25744 .54686 m .25855 .54944 L .26212 .54814 L F
.026 .249 .751 r
.25744 .54686 m .25967 .54852 L .25855 .54944 L F
.163 0 0 r
.2592 .55096 m .25855 .54944 L .25967 .54852 L F
.2592 .55096 m .25691 .55161 L .25855 .54944 L F
0 .014 .589 r
.32016 .54368 m .32193 .54615 L .32145 .54673 L F
.677 .334 .385 r
.32415 .54935 m .32145 .54673 L .32193 .54615 L F
.32415 .54935 m .32159 .54938 L .32145 .54673 L F
0 0 .556 r
.39718 .52157 m .39703 .51993 L .39543 .51764 L F
0 0 .47 r
.39718 .52157 m .39842 .52375 L .39703 .51993 L F
.666 .616 .789 r
.44665 .47991 m .44423 .4811 L .44254 .47888 L F
.821 .341 .024 r
.37058 .51045 m .37209 .51306 L .37357 .51261 L F
.621 .058 0 r
.37209 .51306 m .37551 .51436 L .37357 .51261 L F
.871 .925 .859 r
.66088 .32997 m .65694 .332 L .65975 .32865 L F
.911 .909 .807 r
.66088 .32997 m .66201 .32535 L .66336 .32684 L F
.66088 .32997 m .65975 .32865 L .66201 .32535 L F
.175 .198 .645 r
.23384 .569 m .23574 .56908 L .23464 .56504 L F
.347 .12 .42 r
.23384 .569 m .23507 .57141 L .23574 .56908 L F
.23384 .569 m .233 .57233 L .23507 .57141 L F
.814 .671 .705 r
.32085 .66277 m .32119 .65806 L .31967 .65977 L F
.389 .121 .381 r
.37666 .66547 m .37436 .66622 L .37298 .66475 L F
.574 .757 .965 r
.37298 .66475 m .37436 .66622 L .37666 .66547 L F
0 0 .389 r
.32821 .56324 m .32868 .56595 L .32929 .5633 L F
.343 0 0 r
.32556 .53498 m .32624 .53497 L .32389 .53521 L F
.406 .212 .501 r
.2342 .58117 m .2324 .57917 L .23388 .57841 L F
.2342 .58117 m .23204 .58185 L .2324 .57917 L F
.591 .4 .591 r
.33739 .57292 m .33731 .57578 L .33444 .57612 L F
.401 .245 .553 r
.33959 .57467 m .33739 .57292 L .33954 .57223 L F
.33959 .57467 m .33731 .57578 L .33739 .57292 L F
.621 .899 .986 r
.37683 .67064 m .37836 .67166 L .37476 .67176 L F
.927 .611 .146 r
.60673 .42832 m .60544 .42497 L .60573 .42726 L F
.83 .356 .001 r
.60674 .43018 m .60673 .42832 L .60573 .42726 L F
.60674 .43018 m .60829 .43099 L .60673 .42832 L F
.678 .726 .886 r
.2939 .55842 m .29479 .55991 L .29147 .55983 L F
.645 .547 .729 r
.29558 .5616 m .29147 .55983 L .29479 .55991 L F
.839 .782 .796 r
.29705 .55655 m .29479 .55991 L .2939 .55842 L F
.198 .22 .658 r
.29479 .55991 m .29679 .56219 L .29558 .5616 L F
.738 .243 .059 r
.29799 .5618 m .29679 .56219 L .29479 .55991 L F
.739 .245 .063 r
.58755 .38724 m .58768 .38919 L .58589 .38604 L F
.58755 .38724 m .58969 .38941 L .58768 .38919 L F
.741 .672 .783 r
.61805 .44083 m .62209 .44205 L .62019 .44069 L F
0 0 0 r
.62385 .43792 m .62317 .43975 L .62209 .44205 L F
.382 .265 .594 r
.62607 .43674 m .62338 .43505 L .62548 .43387 L F
.62607 .43674 m .62385 .43792 L .62338 .43505 L F
.805 .856 .887 r
.62476 .4356 m .62156 .43837 L .62366 .43861 L F
.488 .137 .296 r
.62507 .43878 m .62385 .43792 L .62607 .43674 L F
.805 .856 .887 r
.6248 .43597 m .62366 .43861 L .62507 .43878 L F
.62476 .4356 m .62366 .43861 L .6248 .43597 L F
0 0 0 r
.62317 .43975 m .62306 .44004 L .62291 .44036 L F
.62317 .43975 m .62291 .44036 L .62209 .44205 L F
.526 .821 .999 r
.62209 .44205 m .62306 .44004 L .62019 .44069 L F
0 0 .199 r
.23971 .59823 m .24022 .60026 L .23948 .59948 L F
.798 .394 0 r
.23818 .59677 m .24022 .60026 L .23971 .59823 L F
.977 .673 .332 r
.57308 .42393 m .57418 .42252 L .57278 .42109 L F
.948 .862 .442 r
.57308 .42393 m .57343 .4259 L .57418 .42252 L F
.739 .314 .24 r
.34312 .56968 m .34498 .57187 L .34207 .5714 L F
0 .014 .575 r
.4032 .53111 m .4054 .53441 L .4047 .53297 L F
.765 .441 0 r
.4061 .53685 m .4047 .53297 L .4054 .53441 L F
0 0 0 r
.33981 .67559 m .33639 .67776 L .33883 .67719 L F
.235 0 .158 r
.34165 .67525 m .33981 .67559 L .33883 .67719 L F
0 0 0 r
.21132 .56299 m .21271 .5616 L .21435 .55964 L F
.713 .956 .681 r
.21435 .55964 m .21499 .5582 L .21711 .55668 L F
.701 .89 .513 r
.21435 .55964 m .21271 .5616 L .21499 .5582 L F
.626 .429 .597 r
.32375 .60738 m .32112 .6048 L .32374 .60438 L F
.32375 .60738 m .32113 .60776 L .32112 .6048 L F
.308 0 0 r
.57631 .41955 m .57793 .42034 L .5754 .41798 L F
.57631 .41955 m .57958 .42102 L .57793 .42034 L F
.84 .485 0 r
.40775 .54066 m .40681 .53965 L .4061 .53685 L F
.681 .325 0 r
.40775 .54066 m .40805 .54159 L .40681 .53965 L F
.40775 .54066 m .40866 .54288 L .40805 .54159 L F
.791 .299 0 r
.35652 .68048 m .35815 .68133 L .35524 .67862 L F
.958 .621 .318 r
.35834 .68312 m .35815 .68133 L .35652 .68048 L F
.842 .588 .043 r
.35834 .68312 m .35849 .68379 L .35815 .68133 L F
.516 .473 .747 r
.45082 .51785 m .45184 .52143 L .44933 .52206 L F
.508 .437 .712 r
.45184 .52143 m .44992 .52466 L .44933 .52206 L F
.394 .12 .376 r
.3617 .71764 m .36459 .71617 L .36315 .71326 L F
0 0 0 r
.32825 .53584 m .325 .53926 L .32711 .53646 L F
.329 .761 .97 r
.32026 .54021 m .3189 .53954 L .31854 .54004 L F
.714 .265 .184 r
.32283 .54025 m .32105 .54183 L .3189 .53954 L F
0 .151 .691 r
.3189 .53954 m .32105 .54183 L .3196 .53857 L F
.3189 .53954 m .3196 .53857 L .31954 .53843 L F
.329 .761 .97 r
.31854 .54004 m .3189 .53954 L .31613 .53981 L F
.196 .192 .627 r
.33077 .54663 m .33084 .54692 L .32892 .54641 L F
.32892 .54641 m .33084 .54692 L .32871 .54682 L F
.184 0 0 r
.33331 .54594 m .3294 .54715 L .33084 .54692 L F
.331 .54665 m .33188 .54685 L .3294 .54715 L F
.33331 .54594 m .33201 .54677 L .331 .54665 L F
.33201 .54677 m .33188 .54685 L .331 .54665 L F
.196 .192 .627 r
.33016 .54399 m .33077 .54663 L .32892 .54641 L F
.731 .328 .286 r
.32656 .54872 m .33085 .54961 L .32871 .54682 L F
.32656 .54872 m .32871 .54682 L .33084 .54692 L F
0 0 .337 r
.41392 .57131 m .41489 .57376 L .414 .57119 L F
0 0 0 r
.41378 .57149 m .41392 .57131 L .41498 .56838 L F
.97 .897 .533 r
.41498 .56838 m .41392 .57131 L .41354 .56985 L F
0 0 .337 r
.41392 .57131 m .414 .57119 L .41354 .56985 L F
0 0 0 r
.41341 .57247 m .41392 .57131 L .41378 .57149 L F
0 0 .531 r
.41341 .57247 m .41489 .57376 L .41392 .57131 L F
.212 .722 .891 r
.31823 .66844 m .31931 .6679 L .31675 .66872 L F
.31823 .66844 m .32074 .66828 L .31931 .6679 L F
.73 .402 .426 r
.33937 .50493 m .34147 .50799 L .34216 .50525 L F
.33937 .50493 m .33861 .50801 L .34147 .50799 L F
.83 .902 .89 r
.53089 .4128 m .52953 .41638 L .52884 .41524 L F
.987 .895 .579 r
.52884 .41524 m .52953 .41638 L .52804 .41766 L F
0 .223 .735 r
.52953 .41638 m .53129 .4169 L .52804 .41766 L F
.83 .775 .8 r
.59986 .3586 m .60085 .36177 L .59919 .36023 L F
.59986 .3586 m .60346 .3584 L .60085 .36177 L F
.299 .635 .964 r
.59919 .36023 m .60085 .36177 L .6029 .36177 L F
.108 .22 .699 r
.60085 .36177 m .60271 .36627 L .6029 .36177 L F
.61 .215 .27 r
.34906 .56945 m .35192 .5711 L .35241 .56884 L F
.363 .128 .418 r
.35241 .56884 m .35517 .56845 L .35542 .56598 L F
.563 .302 .478 r
.35192 .5711 m .35517 .56845 L .35241 .56884 L F
.482 .296 .552 r
.33376 .55674 m .33372 .55965 L .33591 .55863 L F
.395 .189 .478 r
.32131 .60985 m .32171 .61347 L .31935 .61408 L F
.207 .289 .729 r
.32113 .60776 m .32328 .60977 L .32131 .60985 L F
.052 0 .416 r
.32284 .61232 m .32131 .60985 L .32328 .60977 L F
.32284 .61232 m .32171 .61347 L .32131 .60985 L F
0 0 .205 r
.41371 .56309 m .41415 .56455 L .41307 .56227 L F
.41371 .56309 m .414 .5663 L .41415 .56455 L F
.012 .587 .725 r
.53746 .41718 m .53618 .41722 L .53509 .41473 L F
.53746 .41718 m .53817 .41723 L .53618 .41722 L F
.811 .86 .885 r
.38436 .62055 m .37932 .62161 L .38216 .62068 L F
.612 .953 .909 r
.38524 .61915 m .38436 .62055 L .38216 .62068 L F
0 .128 .657 r
.38626 .62282 m .38436 .62055 L .38524 .61915 L F
.704 .369 .407 r
.341 .60464 m .34366 .60731 L .3408 .60661 L F
.631 .384 .527 r
.34453 .60509 m .34366 .60731 L .341 .60464 L F
.686 .21 .115 r
.27119 .51943 m .27196 .52039 L .2741 .51828 L F
.776 .93 .568 r
.2741 .51828 m .27196 .52039 L .27275 .51921 L F
.051 0 0 r
.27278 .5184 m .2741 .51828 L .27452 .51798 L F
.27169 .51866 m .2741 .51828 L .27278 .5184 L F
.808 .764 .812 r
.27169 .51866 m .26765 .51877 L .26981 .51772 L F
.27169 .51866 m .26899 .52128 L .26765 .51877 L F
.686 .21 .115 r
.26981 .51772 m .2741 .51828 L .27169 .51866 L F
.26981 .51772 m .27119 .51943 L .2741 .51828 L F
.776 .93 .568 r
.2741 .51828 m .27275 .51921 L .27388 .51751 L F
.051 0 0 r
.27452 .51798 m .2741 .51828 L .27532 .51779 L F
.776 .93 .568 r
.2741 .51828 m .27388 .51751 L .27511 .51818 L F
.238 0 0 r
.27522 .51819 m .27533 .5183 L .27805 .51798 L F
.2741 .51828 m .27533 .5183 L .27522 .51819 L F
.051 0 0 r
.27532 .51779 m .2741 .51828 L .27654 .5175 L F
.541 .056 .053 r
.27654 .5175 m .2741 .51828 L .27805 .51798 L F
.445 0 .074 r
.27533 .5183 m .28045 .51736 L .27805 .51798 L F
.27533 .5183 m .27675 .52073 L .28045 .51736 L F
0 0 .39 r
.27579 .51701 m .27637 .51926 L .27533 .5183 L F
.27637 .51926 m .27675 .52073 L .27533 .5183 L F
.776 .93 .568 r
.2741 .51828 m .27511 .51818 L .27533 .5183 L F
0 0 0 r
.69205 .31196 m .69167 .3116 L .69263 .31011 L F
.636 .606 .802 r
.23363 .59165 m .23513 .5941 L .23218 .59504 L F
.721 .209 .003 r
.6973 .32992 m .69627 .33072 L .69461 .3287 L F
0 .043 .596 r
.6973 .32992 m .69851 .33192 L .69891 .33037 L F
.6973 .32992 m .69891 .33037 L .69627 .33072 L F
.427 .227 .505 r
.32486 .68667 m .3224 .68785 L .32426 .6911 L F
0 0 0 r
.21711 .55668 m .21773 .55509 L .21836 .55256 L F
.743 .966 .687 r
.21711 .55668 m .21499 .5582 L .21773 .55509 L F
.692 .153 0 r
.38715 .56218 m .38346 .55921 L .38369 .56079 L F
.492 .479 .771 r
.38369 .56079 m .38514 .56327 L .38715 .56218 L F
.844 .777 .787 r
.71801 .36228 m .72096 .35884 L .71682 .35845 L F
.718 .878 .956 r
.71682 .35845 m .72096 .35884 L .72216 .3575 L F
.846 .868 .858 r
.66609 .32375 m .66336 .32684 L .66201 .32535 L F
.693 .636 .788 r
.31163 .54654 m .31483 .54722 L .3138 .54363 L F
.576 .563 .803 r
.3138 .54363 m .31483 .54722 L .31734 .54642 L F
.222 .148 .557 r
.31483 .54722 m .31808 .54694 L .31734 .54642 L F
.31483 .54722 m .31505 .54982 L .31808 .54694 L F
.722 .315 .277 r
.56665 .46757 m .56296 .46875 L .563 .46716 L F
.56665 .46757 m .56696 .46921 L .56296 .46875 L F
.108 0 .333 r
.42505 .53409 m .42475 .53649 L .42319 .53743 L F
.568 .418 .638 r
.44815 .50221 m .44819 .50465 L .44571 .5054 L F
.529 .51 .778 r
.44923 .50887 m .44571 .5054 L .44819 .50465 L F
.775 .624 .693 r
.22164 .6005 m .21843 .6028 L .2186 .60057 L F
0 0 0 r
.25814 .52167 m .26062 .52013 L .26269 .51976 L F
.649 .968 .884 r
.26269 .51976 m .26239 .5187 L .26493 .51925 L F
.26269 .51976 m .26062 .52013 L .26239 .5187 L F
.586 .403 .601 r
.33444 .57612 m .33494 .57934 L .33192 .57937 L F
.622 .444 .621 r
.33731 .57578 m .33494 .57934 L .33444 .57612 L F
.225 .354 .785 r
.39022 .60208 m .39202 .60294 L .39217 .6013 L F
.39022 .60208 m .39172 .60305 L .39202 .60294 L F
.312 .43 .821 r
.38695 .61746 m .38827 .6169 L .38715 .61409 L F
.809 .4 .272 r
.38695 .61746 m .38731 .61933 L .38524 .61915 L F
.695 .253 .198 r
.38695 .61746 m .38954 .61973 L .38731 .61933 L F
0 0 0 r
.38794 .61759 m .38695 .61746 L .38524 .61915 L F
.38794 .61759 m .38827 .6169 L .38695 .61746 L F
.535 .503 .767 r
.39905 .67786 m .4004 .67356 L .39952 .675 L F
.812 .824 .86 r
.60214 .35648 m .60346 .3584 L .59986 .3586 L F
.444 .661 .953 r
.60577 .358 m .60346 .3584 L .60214 .35648 L F
.538 .558 .823 r
.37649 .54594 m .37536 .55005 L .37404 .54654 L F
.37649 .54594 m .37836 .55065 L .37536 .55005 L F
.679 .311 .343 r
.37834 .5524 m .37536 .55005 L .37836 .55065 L F
.37834 .5524 m .37456 .55267 L .37536 .55005 L F
.74 .612 .716 r
.44914 .47906 m .45089 .48071 L .44665 .47991 L F
.589 .597 .827 r
.45063 .48293 m .44665 .47991 L .45089 .48071 L F
.661 .611 .788 r
.45313 .47972 m .45089 .48071 L .44914 .47906 L F
.593 .436 .638 r
.45313 .47972 m .45063 .48293 L .45089 .48071 L F
.144 .029 .452 r
.2405 .55682 m .24002 .55991 L .24216 .5583 L F
.24 .694 .953 r
.3433 .49657 m .34622 .49649 L .34711 .4974 L F
.519 0 0 r
.34622 .49649 m .34971 .4981 L .34711 .4974 L F
.553 .526 .78 r
.42732 .5885 m .43073 .59113 L .43094 .58783 L F
.226 0 0 r
.35025 .54797 m .34838 .5476 L .35078 .54712 L F
.35025 .54797 m .34746 .54883 L .34838 .5476 L F
0 0 .315 r
.21087 .56548 m .21271 .5616 L .21132 .56299 L F
.992 .88 .567 r
.40264 .58535 m .40448 .58581 L .40326 .58447 L F
.40264 .58535 m .40374 .58841 L .40448 .58581 L F
.854 .968 .871 r
.67894 .32794 m .68277 .32607 L .68206 .32543 L F
.948 .947 .634 r
.68357 .32243 m .68277 .32607 L .68545 .32312 L F
.68357 .32243 m .68206 .32543 L .68277 .32607 L F
.463 .309 .586 r
.29166 .54716 m .29403 .54923 L .29403 .54648 L F
.409 .31 .631 r
.29199 .54974 m .29403 .54923 L .29166 .54716 L F
.994 .764 .401 r
.61419 .42154 m .61513 .42565 L .61468 .4245 L F
.974 .853 .456 r
.41593 .57923 m .41475 .58053 L .41502 .57745 L F
.41593 .57923 m .4153 .58181 L .41475 .58053 L F
.839 .782 .796 r
.29705 .55655 m .2939 .55842 L .29502 .55788 L F
.206 0 0 r
.29502 .55788 m .2995 .55604 L .29705 .55655 L F
.342 .201 .539 r
.20807 .59221 m .20994 .59157 L .21034 .58828 L F
.273 .25 .649 r
.20899 .59431 m .20994 .59157 L .20807 .59221 L F
.361 .67 .974 r
.29034 .53963 m .28983 .53911 L .29008 .53916 L F
.956 .839 .688 r
.29034 .53963 m .2889 .53934 L .29008 .53916 L F
.7 .449 .542 r
.29219 .53909 m .29275 .53993 L .29409 .53907 L F
.571 .415 .631 r
.29147 .538 m .29212 .53898 L .29034 .53963 L F
.29268 .53878 m .29275 .53993 L .29116 .53973 L F
.29268 .53878 m .29116 .53973 L .29034 .53963 L F
.7 .449 .542 r
.28983 .53911 m .29275 .53993 L .29219 .53909 L F
.571 .415 .631 r
.29255 .53646 m .29268 .53878 L .29212 .53898 L F
.29255 .53646 m .29212 .53898 L .29147 .538 L F
.877 .881 .834 r
.29008 .53916 m .28983 .53911 L .29255 .53646 L F
.759 .56 .627 r
.29409 .53907 m .29275 .53993 L .29268 .53878 L F
.29409 .53907 m .29268 .53878 L .29255 .53646 L F
.7 .449 .542 r
.28983 .53911 m .29219 .53909 L .29256 .53876 L F
.29117 .53847 m .29256 .53876 L .29486 .53669 L F
.28983 .53911 m .29256 .53876 L .29117 .53847 L F
.29219 .53909 m .29409 .53907 L .29456 .53761 L F
.29219 .53909 m .29456 .53761 L .29486 .53669 L F
.361 .67 .974 r
.29034 .53963 m .29275 .53993 L .28983 .53911 L F
.806 .908 .506 r
.41169 .55141 m .41111 .5525 L .41127 .5512 L F
0 0 .464 r
.41111 .5525 m .41257 .55571 L .41127 .5512 L F
.753 .365 0 r
.41127 .5512 m .41236 .55385 L .41087 .55102 L F
.41127 .5512 m .41087 .55102 L .41068 .55064 L F
.806 .908 .506 r
.41226 .55031 m .41169 .55141 L .41127 .5512 L F
.834 .442 0 r
.41226 .55031 m .41124 .54912 L .41036 .54677 L F
.976 .713 .303 r
.41226 .55031 m .41127 .5512 L .41124 .54912 L F
0 0 .249 r
.38438 .7036 m .38407 .7001 L .38121 .70339 L F
.793 .449 .406 r
.38358 .70532 m .38438 .7036 L .38121 .70339 L F
.953 .885 .488 r
.3835 .70727 m .38438 .7036 L .38358 .70532 L F
.672 .957 .726 r
.39577 .65405 m .39806 .65268 L .39485 .6555 L F
.983 .869 .646 r
.3967 .65163 m .39806 .65268 L .39577 .65405 L F
.217 0 0 r
.40069 .66537 m .39761 .6676 L .39831 .66863 L F
0 0 .492 r
.39761 .6676 m .39746 .67114 L .39831 .66863 L F
.671 .621 .79 r
.44247 .55579 m .44398 .55946 L .44631 .55629 L F
.611 .537 .746 r
.44398 .55946 m .44743 .56006 L .44631 .55629 L F
.746 .651 .756 r
.44507 .56279 m .44743 .56006 L .44398 .55946 L F
.508 .437 .712 r
.45184 .52143 m .45231 .52408 L .44992 .52466 L F
.567 .483 .72 r
.45331 .5277 m .44992 .52466 L .45231 .52408 L F
.45331 .5277 m .45068 .52842 L .44992 .52466 L F
.829 .491 0 r
.61194 .43935 m .61208 .4382 L .61045 .43678 L F
.61194 .43935 m .61284 .44103 L .61208 .4382 L F
.576 .563 .803 r
.3138 .54363 m .31734 .54642 L .31771 .54382 L F
0 0 0 r
.31734 .54642 m .32016 .54368 L .31771 .54382 L F
.23654 .60238 m .23701 .60093 L .23948 .59948 L F
.23654 .60238 m .23599 .60382 L .23701 .60093 L F
.849 .43 0 r
.38576 .52367 m .38664 .5261 L .388 .52689 L F
.931 .551 .231 r
.38664 .5261 m .38924 .52975 L .388 .52689 L F
.647 .886 .984 r
.57391 .39261 m .57125 .39388 L .57241 .39166 L F
.724 .926 .585 r
.57241 .39166 m .57125 .39388 L .56998 .39494 L F
.32 0 .244 r
.24163 .55289 m .24009 .55253 L .24241 .55053 L F
.24163 .55289 m .23933 .55368 L .24009 .55253 L F
.545 .395 .629 r
.30861 .53675 m .3061 .5374 L .30847 .5341 L F
.593 .468 .678 r
.30626 .54042 m .30861 .53675 L .3061 .5374 L F
.545 .395 .629 r
.30847 .5341 m .3061 .5374 L .30861 .53675 L F
.30861 .53675 m .3061 .5374 L .30847 .5341 L F
.162 .07 .496 r
.31981 .55329 m .32127 .55513 L .31926 .5552 L F
.766 .339 .235 r
.6031 .37109 m .60622 .3713 L .60531 .3731 L F
.744 .496 .556 r
.60859 .36965 m .60531 .3731 L .60622 .3713 L F
.577 .423 .635 r
.3741 .59445 m .37636 .59158 L .37471 .59182 L F
0 .017 .529 r
.27236 .62009 m .27517 .62304 L .27439 .62056 L F
.519 .406 .665 r
.45331 .5277 m .45118 .53109 L .45068 .52842 L F
0 .002 .549 r
.31966 .53407 m .31926 .53398 L .31749 .53442 L F
.31966 .53407 m .3214 .53649 L .31926 .53398 L F
.281 .048 .372 r
.32467 .50484 m .32514 .50236 L .32713 .50196 L F
.32467 .50484 m .32514 .50236 L .32713 .50196 L F
0 0 .3 r
.33352 .54072 m .33451 .53629 L .33255 .53728 L F
.33352 .54072 m .33466 .53943 L .33451 .53629 L F
.564 .909 .691 r
.33352 .54072 m .33129 .54204 L .33466 .53943 L F
.567 .173 .254 r
.27973 .56862 m .27829 .57108 L .27622 .56934 L F
.384 0 .138 r
.28233 .56836 m .27829 .57108 L .27973 .56862 L F
.656 .213 .186 r
.55243 .46406 m .55634 .46435 L .55647 .46581 L F
.647 .206 .188 r
.55634 .46435 m .55889 .46621 L .55647 .46581 L F
.643 .802 .361 r
.32565 .64301 m .32416 .64575 L .32472 .64462 L F
0 .06 .618 r
.32472 .64462 m .32416 .64575 L .32574 .64733 L F
.752 .77 .867 r
.37014 .52836 m .36732 .53064 L .371 .53094 L F
.311 .049 .346 r
.36848 .53387 m .37069 .53321 L .371 .53094 L F
.192 .393 .832 r
.371 .53094 m .37218 .52937 L .37014 .52836 L F
.567 0 0 r
.35863 .501 m .35992 .50202 L .36168 .50283 L F
.291 0 0 r
.57734 .46664 m .57316 .46863 L .57364 .46768 L F
.369 0 0 r
.57734 .46664 m .57869 .46809 L .57591 .46826 L F
.525 .752 .979 r
.57591 .46826 m .57869 .46809 L .57854 .46795 L F
.291 0 0 r
.57734 .46664 m .57591 .46826 L .57329 .46858 L F
.525 .752 .979 r
.57591 .46826 m .57854 .46795 L .57709 .46661 L F
.291 0 0 r
.57329 .46858 m .57591 .46826 L .57316 .46863 L F
.369 0 0 r
.57734 .46664 m .57999 .46658 L .57869 .46809 L F
.905 .948 .82 r
.64175 .42847 m .63851 .43107 L .64109 .42782 L F
.759 .697 .792 r
.64381 .4245 m .64175 .42847 L .64109 .42782 L F
.625 .539 .737 r
.31054 .54297 m .31163 .54654 L .3138 .54363 L F
.538 .476 .734 r
.29507 .64324 m .2958 .64616 L .29325 .64641 L F
.464 .161 .366 r
.29325 .64641 m .29521 .6486 L .2927 .64896 L F
.29325 .64641 m .2958 .64616 L .29521 .6486 L F
.956 .82 .383 r
.42535 .54056 m .42481 .54202 L .42593 .53972 L F
.157 0 .124 r
.42593 .53972 m .42844 .5394 L .42901 .53724 L F
.54 .252 .426 r
.42481 .54202 m .42844 .5394 L .42593 .53972 L F
.418 .456 .793 r
.29223 .62736 m .29354 .63044 L .29513 .62946 L F
.108 0 .268 r
.29513 .62946 m .29354 .63044 L .2929 .63284 L F
.406 .231 .528 r
.32391 .57539 m .32607 .57196 L .32404 .57269 L F
.643 .935 .68 r
.38514 .56327 m .3822 .56599 L .38311 .56456 L F
.806 .995 .864 r
.38311 .56456 m .38715 .56218 L .38514 .56327 L F
.721 .255 0 r
.40103 .52718 m .39842 .52375 L .39891 .52584 L F
.635 .117 0 r
.32972 .55288 m .3282 .55331 L .32642 .55218 L F
.857 .809 .802 r
.64889 .41806 m .64955 .42195 L .65059 .41946 L F
.368 0 .074 r
.35486 .59154 m .35587 .5932 L .35334 .59318 L F
.35486 .59154 m .35752 .59116 L .35587 .5932 L F
.434 .041 .192 r
.44514 .59451 m .44401 .5969 L .44141 .59716 L F
.232 0 .098 r
.44632 .59612 m .44514 .59451 L .44745 .59385 L F
.44632 .59612 m .44401 .5969 L .44514 .59451 L F
.759 .772 .863 r
.64978 .35568 m .65328 .35588 L .65195 .35462 L F
.734 .68 .799 r
.65328 .35588 m .65445 .35119 L .65195 .35462 L F
.65328 .35588 m .65516 .35479 L .65445 .35119 L F
.417 .43 .766 r
.37362 .5879 m .37487 .58416 L .37259 .58719 L F
.217 0 0 r
.40069 .66537 m .39948 .66792 L .39761 .6676 L F
.139 0 0 r
.40147 .66664 m .39948 .66792 L .40069 .66537 L F
.436 .131 .348 r
.468 .57891 m .46476 .58129 L .46535 .57974 L F
.981 .733 .331 r
.40054 .55551 m .40062 .55738 L .40167 .55672 L F
.998 .84 .504 r
.39976 .56058 m .40167 .55672 L .40062 .55738 L F
.39976 .56058 m .40062 .562 L .40167 .55672 L F
0 0 0 r
.29929 .56166 m .29799 .5618 L .30104 .55994 L F
.472 .017 .088 r
.30301 .56114 m .30104 .55994 L .3035 .56003 L F
.30301 .56114 m .29929 .56166 L .30104 .55994 L F
.103 .168 .647 r
.47129 .56809 m .47199 .57203 L .47072 .57181 L F
.109 .149 .622 r
.47199 .57203 m .47274 .57467 L .47072 .57181 L F
.12 0 0 r
.36023 .60045 m .36375 .59843 L .35905 .59865 L F
.314 .605 .95 r
.61574 .39138 m .61434 .39244 L .61331 .38965 L F
.61574 .39138 m .61714 .39305 L .61434 .39244 L F
.499 .857 .99 r
.38311 .56456 m .3822 .56599 L .38046 .56515 L F
.466 .176 .388 r
.36746 .53644 m .37069 .53321 L .36848 .53387 L F
.579 .257 .388 r
.36635 .6835 m .36685 .68139 L .36422 .68135 L F
.363 .253 .592 r
.36422 .68135 m .36449 .68431 L .36635 .6835 L F
0 0 0 r
.36185 .69095 m .36488 .68773 L .36476 .69042 L F
.468 .464 .771 r
.36931 .60365 m .36736 .60409 L .36645 .60194 L F
.401 .267 .581 r
.25551 .55032 m .25744 .54686 L .25525 .54748 L F
.25551 .55032 m .25792 .54997 L .25744 .54686 L F
.147 0 .305 r
.25551 .55032 m .25691 .55161 L .25792 .54997 L F
.25551 .55032 m .25513 .55291 L .25691 .55161 L F
.25691 .55161 m .25513 .55291 L .25551 .55032 L F
.75 .949 .944 r
.35155 .57785 m .35501 .5767 L .35464 .57525 L F
.714 .747 .878 r
.35464 .57525 m .35501 .5767 L .35752 .57565 L F
0 .048 .601 r
.40142 .65202 m .40218 .65437 L .40163 .65626 L F
.416 0 0 r
.40256 .657 m .40439 .65802 L .40429 .65796 L F
.40256 .657 m .40429 .65796 L .40163 .65626 L F
.40256 .657 m .40163 .65626 L .40218 .65437 L F
.962 .647 .374 r
.40091 .65609 m .40256 .657 L .40218 .65437 L F
.40087 .65614 m .40256 .657 L .40091 .65609 L F
.7 .756 .257 r
.57958 .42102 m .57808 .42559 L .58068 .42489 L F
.228 0 0 r
.57979 .42671 m .57808 .42559 L .57777 .42741 L F
.57979 .42671 m .58068 .42489 L .57808 .42559 L F
.397 0 0 r
.36519 .52341 m .36215 .52184 L .36631 .52164 L F
.661 .23 .214 r
.38488 .58435 m .38075 .58428 L .3826 .5823 L F
.54 .021 0 r
.38488 .58435 m .38276 .58517 L .38075 .58428 L F
.153 .431 .869 r
.38075 .58428 m .38276 .58517 L .38183 .58342 L F
0 0 0 r
.3826 .5823 m .38075 .58428 L .37962 .58517 L F
.153 .431 .869 r
.38075 .58428 m .38183 .58342 L .38122 .58226 L F
0 0 0 r
.37962 .58517 m .38075 .58428 L .37936 .58541 L F
0 0 .019 r
.38348 .57795 m .38314 .5809 L .3826 .5823 L F
0 0 .52 r
.60871 .40846 m .60904 .40934 L .61081 .41153 L F
.281 .712 .967 r
.23629 .6142 m .23457 .61324 L .23229 .61327 L F
.881 .897 .838 r
.23709 .61025 m .23457 .61324 L .23629 .6142 L F
.146 .279 .744 r
.23629 .6142 m .23869 .61609 L .23842 .61506 L F
.894 .973 .822 r
.61065 .37999 m .61156 .38089 L .61416 .37758 L F
.506 .628 .905 r
.61256 .37893 m .61156 .38089 L .61065 .37999 L F
.701 .577 .713 r
.61156 .38089 m .61436 .38099 L .61416 .37758 L F
.103 0 0 r
.61549 .38111 m .61436 .38099 L .61156 .38089 L F
.569 .475 .708 r
.61436 .38099 m .61911 .3805 L .61416 .37758 L F
.174 0 0 r
.61549 .38111 m .61911 .3805 L .61436 .38099 L F
.506 .628 .905 r
.61256 .37893 m .61549 .38111 L .61156 .38089 L F
0 0 0 r
.38954 .61973 m .39295 .61703 L .39134 .61854 L F
.869 .986 .837 r
.39295 .61703 m .39482 .61329 L .39302 .61545 L F
.39295 .61703 m .39573 .61391 L .39482 .61329 L F
.827 .946 .59 r
.39134 .61854 m .39295 .61703 L .39302 .61545 L F
.199 .43 .859 r
.23363 .59165 m .23037 .58925 L .23264 .59083 L F
.505 0 0 r
.23053 .58988 m .23098 .58967 L .23037 .58925 L F
.297 .282 .673 r
.22972 .58703 m .23053 .58988 L .2287 .5882 L F
.033 .107 .61 r
.23179 .58803 m .23053 .58988 L .22972 .58703 L F
.632 .878 .533 r
.2301 .59009 m .23053 .58988 L .23179 .58803 L F
0 0 .034 r
.22972 .58703 m .2287 .5882 L .2288 .58791 L F
.22972 .58703 m .2288 .58791 L .22959 .58558 L F
0 0 0 r
.23402 .58415 m .22972 .58703 L .232 .58511 L F
.23212 .58556 m .22972 .58703 L .23402 .58415 L F
.537 .793 .992 r
.23134 .58547 m .22972 .58703 L .23212 .58556 L F
.484 .308 .566 r
.23204 .58185 m .232 .58511 L .22959 .58558 L F
0 0 .034 r
.22972 .58703 m .22959 .58558 L .232 .58511 L F
.537 .793 .992 r
.22847 .58517 m .22972 .58703 L .23134 .58547 L F
.848 .803 .807 r
.22546 .58279 m .22806 .58582 L .22812 .57954 L F
.109 .175 .651 r
.22812 .57954 m .22806 .58582 L .23007 .58163 L F
.718 .677 .81 r
.22847 .58517 m .23007 .58163 L .22944 .58294 L F
.22847 .58517 m .22944 .58294 L .22806 .58582 L F
.327 .439 .823 r
.22782 .58554 m .22847 .58517 L .22806 .58582 L F
.22546 .58279 m .22847 .58517 L .22782 .58554 L F
.977 .727 .49 r
.22546 .58279 m .22574 .58661 L .22704 .58652 L F
.419 0 0 r
.22704 .58652 m .22574 .58661 L .22543 .58691 L F
.327 .439 .823 r
.22546 .58279 m .22704 .58652 L .22847 .58517 L F
.842 .682 .684 r
.22543 .58691 m .22847 .58517 L .22704 .58652 L F
.22543 .58691 m .22716 .5882 L .22847 .58517 L F
.22716 .5882 m .23002 .59032 L .22847 .58517 L F
.949 .6 .307 r
.22975 .59117 m .23089 .59227 L .23071 .59109 L F
.2298 .59161 m .23089 .59227 L .22975 .59117 L F
.505 0 0 r
.23053 .58988 m .23264 .59083 L .23098 .58967 L F
.927 .58 .355 r
.23053 .58988 m .23089 .59227 L .23264 .59083 L F
.936 .599 .368 r
.23089 .59227 m .23299 .59326 L .23264 .59083 L F
.663 .376 .475 r
.23248 .59624 m .23299 .59326 L .23089 .59227 L F
.709 .775 .903 r
.22815 .59427 m .22862 .59782 L .23042 .5965 L F
.716 .246 .132 r
.22815 .59427 m .23042 .5965 L .2275 .59577 L F
.242 .69 .955 r
.2275 .59577 m .23248 .59624 L .23089 .59227 L F
0 0 0 r
.22924 .59411 m .2275 .59577 L .23089 .59227 L F
.524 .823 .999 r
.22661 .59189 m .22839 .59205 L .22915 .59123 L F
.22839 .59205 m .23089 .59227 L .2298 .59161 L F
.22839 .59205 m .2298 .59161 L .22915 .59123 L F
.22661 .59189 m .22839 .59205 L .22915 .59123 L F
.22839 .59205 m .23089 .59227 L .2298 .59161 L F
.22839 .59205 m .2298 .59161 L .22915 .59123 L F
.414 .191 .465 r
.23043 .59142 m .23007 .59406 L .22991 .59259 L F
.23107 .58997 m .23074 .59132 L .23043 .59142 L F
.23074 .59132 m .23007 .59406 L .23043 .59142 L F
.23074 .59132 m .23145 .59397 L .23007 .59406 L F
.23107 .58997 m .23119 .59119 L .23074 .59132 L F
.23119 .59119 m .23145 .59397 L .23074 .59132 L F
.22991 .59259 m .23007 .59406 L .22924 .59411 L F
.949 .6 .307 r
.22915 .59123 m .2298 .59161 L .22975 .59117 L F
.22997 .59043 m .23071 .59109 L .23053 .58988 L F
.22915 .59123 m .23071 .59109 L .22997 .59043 L F
.005 .439 .864 r
.22809 .58831 m .2302 .59045 L .22901 .58957 L F
.2269 .58768 m .22901 .58957 L .22543 .58691 L F
.22809 .58831 m .22901 .58957 L .2269 .58768 L F
.842 .682 .684 r
.23002 .59032 m .2302 .59045 L .23012 .59021 L F
.23002 .59032 m .23012 .59021 L .22847 .58517 L F
.986 .772 .53 r
.22809 .58831 m .23004 .59029 L .22915 .59123 L F
.632 .878 .533 r
.22915 .59123 m .22973 .59066 L .22983 .59051 L F
.986 .772 .53 r
.23004 .59029 m .2302 .59045 L .22915 .59123 L F
.22809 .58831 m .2302 .59045 L .22915 .59123 L F
.632 .878 .533 r
.22915 .59123 m .22983 .59051 L .2301 .59009 L F
.22973 .59066 m .23053 .58988 L .2303 .58999 L F
0 0 .387 r
.22847 .58517 m .22873 .58596 L .22916 .58635 L F
.22873 .58596 m .2302 .59045 L .22916 .58635 L F
.893 .862 .802 r
.22916 .58635 m .23013 .59018 L .22809 .58831 L F
.427 0 0 r
.22532 .58712 m .22809 .58831 L .22543 .58691 L F
.173 0 0 r
.22532 .58712 m .22916 .58635 L .22809 .58831 L F
0 0 0 r
.22794 .58701 m .22962 .58677 L .22916 .58635 L F
.033 .107 .61 r
.23179 .58803 m .22972 .58703 L .23212 .58556 L F
0 .211 .736 r
.23038 .58543 m .23179 .58803 L .23212 .58556 L F
.23107 .58671 m .23205 .58644 L .23179 .58803 L F
.23038 .58543 m .23205 .58644 L .23107 .58671 L F
0 0 0 r
.22994 .58673 m .23058 .58676 L .23205 .58644 L F
.22794 .58701 m .23058 .58676 L .22994 .58673 L F
.408 0 0 r
.23058 .58676 m .23259 .58629 L .23205 .58644 L F
0 0 0 r
.22962 .58677 m .23205 .58644 L .22916 .58635 L F
.718 .677 .81 r
.22847 .58517 m .23212 .58556 L .23007 .58163 L F
0 0 .387 r
.22847 .58517 m .23038 .58543 L .23212 .58556 L F
.22847 .58517 m .22916 .58635 L .23038 .58543 L F
.393 .034 .231 r
.22916 .58635 m .23205 .58644 L .23038 .58543 L F
.408 0 0 r
.23259 .58629 m .23441 .58586 L .23205 .58644 L F
0 .074 .635 r
.23205 .58644 m .23372 .59018 L .23179 .58803 L F
.193 .355 .799 r
.23475 .5895 m .23372 .59018 L .23205 .58644 L F
.23475 .5895 m .23205 .58644 L .23441 .58586 L F
.408 0 0 r
.23058 .58676 m .23236 .5875 L .23441 .58586 L F
.711 .174 0 r
.22823 .58446 m .23139 .58679 L .23058 .58676 L F
.23139 .58679 m .23236 .5875 L .23058 .58676 L F
.632 .878 .533 r
.22973 .59066 m .2303 .58999 L .23027 .59 L F
.893 .862 .802 r
.23013 .59018 m .2302 .59045 L .23004 .59029 L F
.23013 .59018 m .23004 .59029 L .22809 .58831 L F
.632 .878 .533 r
.22975 .59063 m .23027 .59 L .2301 .59009 L F
.22973 .59066 m .23027 .59 L .22975 .59063 L F
.739 .626 .733 r
.34678 .5566 m .34952 .55785 L .34929 .55331 L F
.448 .398 .709 r
.34929 .55331 m .34952 .55785 L .35226 .55596 L F
.261 .564 .935 r
.34952 .55785 m .3516 .55727 L .35226 .55596 L F
.529 .148 .262 r
.61298 .38722 m .61631 .38748 L .61331 .38965 L F
.962 .691 .475 r
.2287 .55004 m .22668 .55177 L .22861 .55282 L F
.64 .908 .603 r
.22953 .54868 m .22668 .55177 L .2287 .55004 L F
.556 .861 .997 r
.57562 .42897 m .57171 .42864 L .57467 .42728 L F
.729 .831 .928 r
.57777 .42741 m .57562 .42897 L .57467 .42728 L F
.794 .936 .923 r
.26136 .57708 m .26497 .57615 L .26281 .57599 L F
.623 .256 .325 r
.26636 .57455 m .26281 .57599 L .26497 .57615 L F
.26636 .57455 m .26499 .57689 L .26281 .57599 L F
.441 .495 .819 r
.26281 .57599 m .26499 .57689 L .26423 .57493 L F
.26281 .57599 m .26423 .57493 L .26353 .5731 L F
.794 .936 .923 r
.26123 .57711 m .26136 .57708 L .26281 .57599 L F
.31 .62 .958 r
.58188 .39612 m .57749 .39403 L .58038 .39521 L F
.382 0 0 r
.58038 .39521 m .58444 .39773 L .58188 .39612 L F
.041 .237 .737 r
.3436 .70209 m .34265 .70351 L .3449 .70549 L F
.246 0 .24 r
.23842 .61506 m .24016 .6148 L .24279 .61448 L F
.014 .35 .827 r
.24289 .61276 m .24279 .61448 L .24016 .6148 L F
.24289 .61276 m .24534 .61564 L .24279 .61448 L F
.46 .412 .717 r
.45545 .53945 m .45403 .54386 L .45353 .54019 L F
.45545 .53945 m .45641 .54361 L .45403 .54386 L F
.677 .417 .521 r
.38818 .55159 m .38908 .55 L .38609 .55054 L F
.38818 .55159 m .38849 .55275 L .38908 .55 L F
.468 .644 .934 r
.38441 .54745 m .38602 .54723 L .38559 .54527 L F
.768 .619 .694 r
.38535 .54565 m .38659 .5493 L .3835 .54859 L F
.38559 .54527 m .38575 .54592 L .38535 .54565 L F
.38575 .54592 m .38659 .5493 L .38535 .54565 L F
.274 .562 .933 r
.38602 .54723 m .38908 .55 L .38929 .54836 L F
.38837 .54773 m .38929 .54836 L .38934 .54794 L F
.38602 .54723 m .38929 .54836 L .38837 .54773 L F
.677 .417 .521 r
.38908 .55 m .38818 .55159 L .38934 .54794 L F
.38908 .55 m .38849 .55275 L .38818 .55159 L F
.493 .905 .86 r
.38075 .58428 m .37864 .58531 L .37936 .58541 L F
.724 .772 .89 r
.6209 .35897 m .6173 .35826 L .61902 .35741 L F
.748 .735 .84 r
.61902 .35741 m .62296 .35797 L .6209 .35897 L F
.225 .41 .835 r
.3493 .70756 m .35065 .70997 L .35195 .70944 L F
.56 .534 .783 r
.35065 .70997 m .35415 .71306 L .35195 .70944 L F
.481 .498 .799 r
.25791 .57691 m .25853 .57237 L .25677 .5721 L F
.25791 .57691 m .26019 .57723 L .25853 .57237 L F
.901 .744 .678 r
.71032 .28762 m .71149 .28389 L .70989 .28412 L F
0 .365 .826 r
.28198 .63225 m .28357 .63414 L .2811 .63179 L F
0 .202 .718 r
.28467 .63411 m .28357 .63414 L .28198 .63225 L F
.28467 .63411 m .28584 .63585 L .28357 .63414 L F
.695 .488 .603 r
.34229 .53582 m .34854 .53414 L .34598 .53455 L F
.34229 .53582 m .349 .53701 L .34854 .53414 L F
.668 .469 .607 r
.34854 .53414 m .35229 .53624 L .35121 .53412 L F
.34854 .53414 m .349 .53701 L .35229 .53624 L F
.835 .829 .842 r
.64054 .44063 m .64326 .43753 L .63985 .43782 L F
.593 .577 .804 r
.22678 .60418 m .22821 .60792 L .23073 .60734 L F
0 0 .541 r
.22821 .60792 m .22977 .60906 L .23073 .60734 L F
.22821 .60792 m .22956 .6103 L .22977 .60906 L F
.492 .334 .594 r
.35069 .56246 m .34894 .56551 L .34828 .56287 L F
.788 .919 .926 r
.30023 .51122 m .29661 .51198 L .29856 .51047 L F
.718 .984 .895 r
.30081 .50945 m .30023 .51122 L .29856 .51047 L F
.30081 .50945 m .30353 .50887 L .30023 .51122 L F
.283 .096 .442 r
.30536 .61104 m .30725 .6104 L .30764 .60741 L F
.326 .211 .566 r
.30536 .61104 m .30721 .61274 L .30725 .6104 L F
.30536 .61104 m .30555 .6138 L .30721 .61274 L F
.571 .521 .76 r
.45307 .48232 m .45156 .48669 L .45063 .48293 L F
.45307 .48232 m .45417 .48594 L .45156 .48669 L F
.577 .473 .698 r
.45417 .48594 m .45194 .48935 L .45156 .48669 L F
.186 .552 .931 r
.38885 .58751 m .39029 .58923 L .3928 .5893 L F
.503 .679 .944 r
.70728 .34827 m .70959 .35147 L .71079 .35067 L F
0 0 .366 r
.3094 .62502 m .30824 .62382 L .31012 .62255 L F
.3094 .62502 m .30837 .62661 L .30824 .62382 L F
.461 .458 .769 r
.71872 .32759 m .71971 .3322 L .71488 .32958 L F
.991 .802 .421 r
.34288 .69084 m .34352 .69415 L .34212 .69263 L F
.994 .752 .416 r
.34212 .69263 m .34352 .69415 L .34326 .69672 L F
.79 .775 .839 r
.63248 .35259 m .62771 .35399 L .63103 .35106 L F
.84 .897 .879 r
.63407 .34851 m .63248 .35259 L .63103 .35106 L F
.63407 .34851 m .6354 .34991 L .63248 .35259 L F
.714 .588 .713 r
.68545 .32312 m .68987 .32457 L .68804 .31992 L F
.226 0 .015 r
.36949 .71531 m .37127 .71279 L .37329 .71266 L F
.843 .859 .856 r
.63499 .37002 m .6394 .36834 L .63724 .36729 L F
.787 .741 .811 r
.63724 .36729 m .6394 .36834 L .64199 .3651 L F
.746 .665 .77 r
.39183 .68752 m .39393 .68799 L .39432 .68497 L F
.39393 .68799 m .39499 .68632 L .39432 .68497 L F
.624 .547 .747 r
.39605 .68847 m .39663 .68384 L .39432 .68497 L F
0 0 0 r
.39279 .68634 m .39432 .68497 L .39663 .68384 L F
.39279 .68634 m .39652 .68391 L .39523 .6829 L F
.39652 .68391 m .39663 .68384 L .39658 .68381 L F
.39652 .68391 m .39658 .68381 L .39523 .6829 L F
.746 .665 .77 r
.39393 .68799 m .39605 .68847 L .39499 .68632 L F
.624 .547 .747 r
.39605 .68847 m .39874 .68791 L .39663 .68384 L F
.453 0 .007 r
.22608 .57477 m .22876 .57474 L .23078 .5733 L F
.075 0 0 r
.23078 .5733 m .23361 .57279 L .233 .57233 L F
.406 .234 .533 r
.233 .57233 m .23496 .5742 L .23507 .57141 L F
.233 .57233 m .23496 .5742 L .23507 .57141 L F
0 .085 .627 r
.23361 .57279 m .23496 .5742 L .233 .57233 L F
.075 0 0 r
.23078 .5733 m .22876 .57474 L .23361 .57279 L F
.876 .984 .704 r
.42942 .50126 m .42908 .5034 L .4314 .50202 L F
.42942 .50126 m .42735 .50422 L .42908 .5034 L F
0 0 0 r
.42908 .5034 m .42899 .50439 L .4314 .50202 L F
.409 .066 .269 r
.26886 .57384 m .26706 .57247 L .26946 .57133 L F
.26886 .57384 m .26636 .57455 L .26706 .57247 L F
.575 .562 .802 r
.40198 .48856 m .4063 .49292 L .40469 .4895 L F
.738 .986 .778 r
.40318 .49563 m .40387 .49414 L .4063 .49292 L F
.059 .284 .774 r
.4063 .49292 m .40756 .49158 L .40469 .4895 L F
.618 .615 .826 r
.4063 .49292 m .40955 .49424 L .40812 .49469 L F
.652 .123 0 r
.40955 .49424 m .40812 .49469 L .4063 .49292 L F
0 .141 .666 r
.4063 .49292 m .40812 .49469 L .40756 .49158 L F
.40756 .49158 m .4063 .49292 L .40387 .49414 L F
.40756 .49158 m .40812 .49469 L .4063 .49292 L F
.487 0 0 r
.36611 .50669 m .36538 .50593 L .36426 .50429 L F
.36611 .50669 m .3678 .50795 L .36538 .50593 L F
.869 .87 .427 r
.40198 .48856 m .40291 .48471 L .40479 .48628 L F
.628 .759 .941 r
.40725 .48542 m .40479 .48628 L .40291 .48471 L F
.422 .774 .996 r
.62502 .40173 m .62616 .40284 L .62248 .40212 L F
.022 .589 .784 r
.62504 .40258 m .62616 .40284 L .62502 .40173 L F
.62504 .40258 m .6297 .40308 L .62616 .40284 L F
.768 .702 .79 r
.65516 .35479 m .65826 .35175 L .65445 .35119 L F
.426 0 0 r
.26414 .61876 m .26338 .61814 L .26202 .61666 L F
.26414 .61876 m .2662 .62005 L .26338 .61814 L F
.778 .575 .625 r
.54035 .4542 m .54407 .45736 L .54043 .45671 L F
.824 .588 .581 r
.54043 .45671 m .54407 .45736 L .54255 .45997 L F
.869 .87 .427 r
.40198 .48856 m .40169 .48849 L .40291 .48471 L F
.734 .274 .159 r
.40469 .4895 m .40169 .48849 L .40198 .48856 L F
0 0 .408 r
.36658 .60049 m .36645 .60194 L .36598 .59794 L F
.743 .59 .685 r
.36926 .60196 m .37119 .59976 L .37058 .60145 L F
.36817 .60239 m .36958 .60117 L .36926 .60196 L F
.36958 .60117 m .37119 .59976 L .36926 .60196 L F
.468 .464 .771 r
.36882 .60308 m .36645 .60194 L .36658 .60049 L F
.36931 .60365 m .36873 .6033 L .36882 .60308 L F
.36873 .6033 m .36645 .60194 L .36882 .60308 L F
.688 .943 .961 r
.69639 .30508 m .69865 .30592 L .6975 .30357 L F
.776 .846 .905 r
.6975 .30357 m .69865 .30592 L .70101 .30344 L F
.634 .954 .934 r
.39577 .65405 m .39485 .6555 L .39383 .65523 L F
.764 .719 .81 r
.44914 .47906 m .44502 .47618 L .44758 .47522 L F
.44914 .47906 m .44665 .47991 L .44502 .47618 L F
.692 .712 .864 r
.45168 .47615 m .44914 .47906 L .44758 .47522 L F
.661 .611 .788 r
.45313 .47972 m .44914 .47906 L .45168 .47615 L F
.273 .25 .649 r
.20899 .59431 m .21046 .59437 L .20994 .59157 L F
.567 .231 .359 r
.28838 .56621 m .28495 .56813 L .28582 .56678 L F
.538 .919 .928 r
.3504 .72586 m .35318 .72466 L .35115 .72462 L F
.35115 .72462 m .35318 .72466 L .3504 .72586 L F
.754 .443 0 r
.2867 .64873 m .28797 .65254 L .28735 .65127 L F
.936 .865 .438 r
.28735 .65127 m .28797 .65254 L .2871 .65544 L F
.598 .342 .5 r
.31356 .61734 m .31362 .61982 L .31068 .6199 L F
.696 .491 .606 r
.31624 .61703 m .31362 .61982 L .31356 .61734 L F
.92 .587 .124 r
.61262 .41529 m .61421 .41925 L .61295 .41775 L F
.99 .731 .384 r
.61295 .41775 m .61421 .41925 L .61419 .42154 L F
.265 0 0 r
.24654 .61996 m .24048 .61946 L .24258 .62109 L F
.894 .973 .822 r
.61065 .37999 m .61416 .37758 L .61256 .37893 L F
.708 .307 .285 r
.61416 .37758 m .61911 .3805 L .61256 .37893 L F
.131 0 0 r
.60271 .36627 m .60118 .36772 L .6031 .36837 L F
0 0 .422 r
.6029 .36177 m .60271 .36627 L .60344 .36191 L F
.356 .306 .664 r
.36937 .67489 m .3719 .67718 L .37113 .67452 L F
.993 .747 .438 r
.36937 .67489 m .36934 .67783 L .3719 .67718 L F
0 .359 .825 r
.3678 .50795 m .37058 .51045 L .36933 .50901 L F
.49 .222 .435 r
.29255 .53646 m .29486 .53669 L .29485 .53405 L F
.29255 .53646 m .28983 .53911 L .29486 .53669 L F
.72 .765 .888 r
.62174 .3553 m .62296 .35797 L .61902 .35741 L F
.747 .778 .878 r
.62609 .35534 m .62296 .35797 L .62174 .3553 L F
.892 .982 .81 r
.39482 .61329 m .39573 .61391 L .3983 .61064 L F
0 .245 .732 r
.38312 .50798 m .38293 .50764 L .37946 .50481 L F
.76 .427 0 r
.38312 .50798 m .3826 .50725 L .38293 .50764 L F
.642 .216 0 r
.38312 .50798 m .38372 .50919 L .3826 .50725 L F
.38312 .50798 m .38429 .50993 L .38372 .50919 L F
0 .148 .65 r
.38372 .50919 m .38451 .5094 L .38314 .50844 L F
.788 .331 0 r
.3826 .50725 m .38372 .50919 L .3823 .50785 L F
0 .148 .65 r
.38372 .50919 m .38314 .50844 L .3823 .50785 L F
.642 .216 0 r
.38429 .50993 m .38474 .51069 L .38372 .50919 L F
.519 .406 .665 r
.45331 .5277 m .45364 .53046 L .45118 .53109 L F
.821 .52 .481 r
.53239 .44768 m .5363 .45084 L .53263 .45019 L F
.841 .705 .713 r
.53263 .45019 m .5363 .45084 L .53396 .45376 L F
.712 .508 .611 r
.5363 .45084 m .53645 .45395 L .53396 .45376 L F
0 0 0 r
.39243 .50311 m .39242 .50312 L .39389 .50118 L F
.39243 .50311 m .39048 .5042 L .39242 .50312 L F
0 0 .269 r
.28156 .6391 m .28301 .64295 L .28248 .64143 L F
0 0 .121 r
.28301 .64295 m .28342 .64395 L .28248 .64143 L F
.28301 .64295 m .28298 .64499 L .28342 .64395 L F
.552 .817 .995 r
.33269 .49503 m .33022 .49579 L .32857 .49455 L F
.979 .71 .445 r
.26778 .53102 m .26766 .53364 L .26601 .5299 L F
.429 .218 .489 r
.2702 .53031 m .26766 .53364 L .26778 .53102 L F
.69 .578 .724 r
.24241 .55053 m .23841 .54592 L .24087 .54833 L F
.38 .085 .333 r
.24398 .55203 m .24241 .55053 L .24087 .54833 L F
.24398 .55203 m .24163 .55289 L .24241 .55053 L F
.24241 .55053 m .24163 .55289 L .24398 .55203 L F
.75 .238 0 r
.39177 .59623 m .39014 .59659 L .389 .59361 L F
.39177 .59623 m .39302 .59744 L .39014 .59659 L F
.829 .524 .473 r
.54255 .45997 m .54612 .46076 L .54436 .46293 L F
.76 .425 .418 r
.54612 .46076 m .54823 .46347 L .54436 .46293 L F
.713 .358 .374 r
.35177 .58147 m .3484 .57895 L .35155 .57785 L F
.35177 .58147 m .34814 .58128 L .3484 .57895 L F
.925 .891 .778 r
.649 .40215 m .65058 .40369 L .64916 .40584 L F
.727 .577 .686 r
.69357 .32124 m .69203 .323 L .69384 .31975 L F
.793 .535 .549 r
.70603 .28345 m .70989 .28412 L .70983 .28157 L F
.844 .683 .683 r
.71324 .32691 m .71297 .32916 L .71239 .32869 L F
.226 .28 .71 r
.71505 .32462 m .71324 .32691 L .71232 .32263 L F
.67 .939 .965 r
.71574 .32554 m .71324 .32691 L .71505 .32462 L F
0 0 0 r
.37614 .71243 m .38057 .71039 L .37858 .7119 L F
.637 .919 .637 r
.37858 .7119 m .38057 .71039 L .38212 .70863 L F
0 0 0 r
.38057 .71039 m .3835 .70727 L .38212 .70863 L F
.892 .982 .81 r
.39482 .61329 m .3983 .61064 L .39746 .61024 L F
.971 .919 .592 r
.39876 .60607 m .39746 .61024 L .3983 .61064 L F
.435 .365 .679 r
.45497 .53689 m .45545 .53945 L .45353 .54019 L F
.71 .788 .912 r
.55249 .41038 m .54722 .41093 L .54997 .40951 L F
.741 .957 .943 r
.55279 .40931 m .55249 .41038 L .54997 .40951 L F
.55279 .40931 m .55447 .40927 L .55249 .41038 L F
.407 .256 .563 r
.31263 .60101 m .31531 .5968 L .3128 .59859 L F
.635 .859 .984 r
.29978 .53479 m .29711 .53607 L .29941 .53745 L F
.189 0 .26 r
.27487 .5312 m .27416 .53344 L .2767 .53034 L F
.583 .278 .417 r
.2796 .55889 m .28292 .55671 L .28017 .55702 L F
.806 .99 .881 r
.70243 .32589 m .69916 .3289 L .6988 .32775 L F
.573 .842 .996 r
.28018 .52145 m .27976 .52351 L .28205 .5226 L F
.28018 .52145 m .2773 .52246 L .27976 .52351 L F
.528 .409 .661 r
.32607 .57196 m .32812 .56839 L .32664 .56934 L F
.958 .945 .705 r
.38212 .70863 m .3835 .70727 L .38358 .70532 L F
.867 .423 .116 r
.33573 .69795 m .33827 .70044 L .33681 .70026 L F
.288 .634 .964 r
.33827 .70044 m .339 .69915 L .33681 .70026 L F
.33827 .70044 m .34064 .70078 L .339 .69915 L F
.657 .839 .97 r
.63366 .43694 m .63069 .43821 L .62956 .43675 L F
.63366 .43694 m .63069 .43821 L .62956 .43675 L F
.63 .652 .853 r
.44502 .47618 m .44254 .47888 L .44229 .4767 L F
.44502 .47618 m .44665 .47991 L .44254 .47888 L F
.58 .18 .249 r
.29208 .6353 m .2903 .63343 L .28971 .63529 L F
.455 .184 .411 r
.29208 .6353 m .2929 .63284 L .2903 .63343 L F
.121 .662 .842 r
.23575 .54794 m .24087 .54833 L .23841 .54592 L F
.459 .02 .116 r
.43249 .59813 m .43428 .59946 L .4319 .59847 L F
.43249 .59813 m .43488 .59808 L .43428 .59946 L F
.851 .824 .821 r
.68501 .31948 m .68545 .32312 L .68804 .31992 L F
.68501 .31948 m .68357 .32243 L .68545 .32312 L F
.684 .582 .735 r
.44247 .55579 m .4452 .55265 L .44264 .55334 L F
.702 .7 .845 r
.44746 .56316 m .45205 .56296 L .44958 .55969 L F
.382 .562 .906 r
.44958 .55969 m .45205 .56296 L .45407 .56156 L F
.579 .575 .812 r
.45205 .56296 m .45443 .56269 L .45407 .56156 L F
.616 .951 .923 r
.25632 .52253 m .25638 .52124 L .25866 .52136 L F
.25632 .52253 m .25382 .52265 L .25638 .52124 L F
.884 .768 .729 r
.68696 .31622 m .68501 .31948 L .68804 .31992 L F
.609 .449 .64 r
.6391 .40308 m .64185 .3992 L .63902 .39986 L F
.371 .372 .73 r
.46043 .54906 m .45929 .55343 L .45811 .54959 L F
.46043 .54906 m .46153 .55316 L .45929 .55343 L F
.375 .48 .839 r
.46153 .55316 m .46234 .55528 L .45929 .55343 L F
.463 .267 .528 r
.45313 .47972 m .45307 .48232 L .45063 .48293 L F
.036 .246 .746 r
.39472 .68008 m .39424 .68186 L .39233 .67806 L F
.512 0 0 r
.39523 .6829 m .39663 .68384 L .39424 .68186 L F
.39523 .6829 m .39424 .68186 L .39472 .68008 L F
.916 .594 .119 r
.38924 .52975 m .39068 .53362 L .39027 .53114 L F
.558 .172 .265 r
.26137 .56811 m .26396 .56831 L .26582 .56573 L F
.544 .156 .256 r
.26582 .56573 m .26792 .56693 L .26826 .56621 L F
.26582 .56573 m .26396 .56831 L .26792 .56693 L F
.417 .43 .766 r
.37362 .5879 m .37579 .58769 L .37487 .58416 L F
.878 .965 .636 r
.34359 .55171 m .3434 .55362 L .34539 .55016 L F
.016 0 0 r
.34637 .55081 m .34539 .55016 L .34746 .54883 L F
.34637 .55081 m .34359 .55171 L .34539 .55016 L F
.75 .949 .944 r
.35155 .57785 m .35464 .57525 L .35098 .57574 L F
.814 .412 .289 r
.35574 .57543 m .35573 .57729 L .35518 .57536 L F
.35752 .57565 m .35573 .57729 L .35574 .57543 L F
.492 .364 .634 r
.35803 .57875 m .36002 .57509 L .35752 .57565 L F
.482 .255 .493 r
.35521 .5819 m .35781 .5814 L .35803 .57875 L F
.492 .364 .634 r
.35803 .57875 m .36043 .57821 L .36002 .57509 L F
.349 .147 .458 r
.35803 .57875 m .35983 .58054 L .36043 .57821 L F
.738 .457 .504 r
.35997 .57812 m .3554 .5796 L .35573 .57729 L F
.36043 .57821 m .35987 .57837 L .35997 .57812 L F
.349 .147 .458 r
.35803 .57875 m .35781 .5814 L .35882 .58097 L F
.35803 .57875 m .35882 .58097 L .35923 .57995 L F
.738 .457 .504 r
.35987 .57837 m .3554 .5796 L .35997 .57812 L F
.349 .147 .458 r
.35923 .57995 m .35882 .58097 L .35983 .58054 L F
.906 .984 .746 r
.3554 .5796 m .35573 .57841 L .35573 .57729 L F
.805 .586 .605 r
.36002 .57509 m .35573 .57729 L .35752 .57565 L F
.36002 .57509 m .36043 .57821 L .35573 .57729 L F
.906 .984 .746 r
.35573 .57841 m .35651 .57561 L .35573 .57729 L F
.286 .567 .934 r
.35594 .5755 m .35573 .57729 L .35651 .57561 L F
.888 .466 .177 r
.35518 .57536 m .35154 .57597 L .35464 .57525 L F
0 0 .323 r
.35261 .57572 m .35098 .57574 L .35464 .57525 L F
.35154 .57597 m .35116 .57582 L .35261 .57572 L F
.888 .466 .177 r
.35518 .57536 m .35314 .575 L .35154 .57597 L F
.35518 .57536 m .35573 .57729 L .35314 .575 L F
.286 .567 .934 r
.35314 .575 m .35386 .57564 L .35594 .5755 L F
.35386 .57564 m .35573 .57729 L .35594 .5755 L F
0 0 .323 r
.35116 .57582 m .35098 .57574 L .35261 .57572 L F
.35154 .57597 m .35155 .57785 L .35098 .57574 L F
.667 .796 .943 r
.36752 .64381 m .36634 .64608 L .36476 .64445 L F
.36476 .64445 m .36634 .64608 L .36752 .64381 L F
.846 .868 .858 r
.66609 .32375 m .66201 .32535 L .66492 .32266 L F
.878 .986 .823 r
.66865 .32055 m .66609 .32375 L .667 .32078 L F
.805 .919 .914 r
.667 .32078 m .66609 .32375 L .66492 .32266 L F
.844 .777 .787 r
.71801 .36228 m .71682 .35845 L .71623 .36048 L F
.73 .698 .82 r
.31726 .6315 m .32077 .63361 L .31635 .63254 L F
.748 .342 .282 r
.31635 .63254 m .32077 .63361 L .31842 .63533 L F
.443 .672 .96 r
.32159 .63169 m .32077 .63361 L .31726 .6315 L F
.774 .978 .71 r
.31842 .63533 m .32077 .63361 L .32159 .63169 L F
.799 .857 .408 r
.62731 .42674 m .62798 .42555 L .62744 .4268 L F
0 0 .155 r
.62744 .4268 m .62798 .42555 L .62974 .4239 L F
.192 0 0 r
.39159 .57921 m .39236 .58008 L .38985 .57906 L F
.39159 .57921 m .39402 .57906 L .39236 .58008 L F
.335 .46 .839 r
.30946 .63581 m .30791 .6362 L .30667 .6342 L F
.663 .611 .787 r
.30946 .63581 m .30854 .64025 L .30791 .6362 L F
.555 .567 .821 r
.53069 .44374 m .53239 .44768 L .53062 .44551 L F
.904 .563 .388 r
.53062 .44551 m .53239 .44768 L .53263 .45019 L F
.96 .873 .707 r
.6198 .39618 m .62138 .39399 L .61911 .39428 L F
.79 .733 .8 r
.62385 .39056 m .62138 .39399 L .6203 .39017 L F
.769 .953 .633 r
.62241 .39165 m .62138 .39399 L .62385 .39056 L F
.763 .989 .893 r
.61911 .39428 m .62138 .39399 L .62241 .39165 L F
.615 .48 .675 r
.36598 .59794 m .36413 .59427 L .3642 .59656 L F
.186 0 0 r
.36375 .59843 m .36144 .6002 L .36483 .59897 L F
.653 .239 0 r
.36519 .59819 m .36635 .60042 L .36658 .60049 L F
.186 0 0 r
.36375 .59843 m .36542 .59867 L .3642 .59656 L F
.653 .239 0 r
.3642 .59656 m .36542 .59867 L .36519 .59819 L F
.3642 .59656 m .36519 .59819 L .36549 .59756 L F
.186 0 0 r
.36542 .59867 m .36559 .59869 L .3642 .59656 L F
.922 .671 .54 r
.36036 .6007 m .35961 .60349 L .36023 .60045 L F
.36218 .60434 m .35961 .60349 L .36036 .6007 L F
.792 .464 .433 r
.36218 .60434 m .35886 .60607 L .35961 .60349 L F
0 0 .343 r
.35886 .60607 m .35918 .60512 L .35961 .60349 L F
.35918 .60512 m .36014 .60225 L .35961 .60349 L F
.366 0 .166 r
.36014 .60225 m .36547 .59877 L .36144 .6002 L F
.36547 .59877 m .36559 .59869 L .36546 .59874 L F
.36547 .59877 m .36546 .59874 L .36144 .6002 L F
.36014 .60225 m .36312 .60153 L .36549 .5988 L F
.36547 .59877 m .36549 .5988 L .36559 .59869 L F
.36014 .60225 m .36549 .5988 L .36547 .59877 L F
.653 .239 0 r
.36545 .59872 m .36635 .60042 L .36519 .59819 L F
.243 0 .075 r
.36553 .59888 m .36478 .60117 L .36635 .60042 L F
.653 .239 0 r
.36572 .59929 m .36589 .59959 L .36545 .59872 L F
.36589 .59959 m .36635 .60042 L .36545 .59872 L F
.243 0 .075 r
.36553 .59888 m .36312 .60153 L .36478 .60117 L F
.36559 .59869 m .36549 .5988 L .36553 .59888 L F
.36549 .5988 m .36312 .60153 L .36553 .59888 L F
.36559 .59869 m .36553 .59888 L .36635 .60042 L F
.653 .239 0 r
.3642 .59656 m .36572 .59929 L .36548 .5988 L F
.36543 .5987 m .36548 .5988 L .36546 .59875 L F
.3642 .59656 m .36548 .5988 L .36543 .5987 L F
.36545 .59873 m .36546 .59875 L .36546 .59874 L F
.3642 .59656 m .36546 .59875 L .36545 .59873 L F
.186 0 0 r
.365 .59861 m .36546 .59874 L .36542 .59867 L F
.653 .239 0 r
.36541 .59865 m .36546 .59874 L .36542 .59867 L F
.3642 .59656 m .36546 .59874 L .36541 .59865 L F
.186 0 0 r
.365 .59861 m .36483 .59897 L .36546 .59874 L F
.36542 .59867 m .36546 .59874 L .36559 .59869 L F
.36375 .59843 m .36483 .59897 L .365 .59861 L F
.653 .239 0 r
.36549 .59756 m .36658 .60049 L .36598 .59794 L F
.36519 .59819 m .36658 .60049 L .36549 .59756 L F
.421 .839 .965 r
.35128 .68437 m .35188 .6833 L .34961 .683 L F
.35128 .68437 m .35507 .68365 L .35188 .6833 L F
.804 .467 .417 r
.35336 .68735 m .35128 .68437 L .35131 .6874 L F
.196 .667 .938 r
.37281 .55633 m .37598 .55653 L .37709 .55735 L F
.872 .97 .852 r
.37709 .55735 m .37792 .55482 L .37942 .55628 L F
.37709 .55735 m .37598 .55653 L .37792 .55482 L F
.669 .575 .74 r
.28518 .62682 m .28623 .63008 L .28936 .62786 L F
.348 .596 .939 r
.72323 .3313 m .72054 .33324 L .71971 .3322 L F
.72323 .3313 m .72411 .33464 L .72054 .33324 L F
.59 .598 .829 r
.72519 .33632 m .72054 .33324 L .72411 .33464 L F
0 0 .315 r
.32159 .54938 m .31981 .55329 L .31881 .55084 L F
.32159 .54938 m .3209 .55289 L .31981 .55329 L F
0 .037 .545 r
.3209 .55289 m .32127 .55513 L .31981 .55329 L F
.801 .891 .909 r
.63722 .34817 m .6354 .34991 L .63407 .34851 L F
0 0 0 r
.32527 .51904 m .32622 .51884 L .32751 .51841 L F
.32527 .51904 m .32383 .52008 L .32622 .51884 L F
.313 .154 .498 r
.3461 .54034 m .34414 .54408 L .34585 .54278 L F
0 0 0 r
.34414 .54408 m .34422 .54417 L .34585 .54278 L F
.34414 .54408 m .34103 .5452 L .34422 .54417 L F
.586 .027 0 r
.59248 .40648 m .59378 .40689 L .59043 .4047 L F
.493 0 0 r
.59523 .40801 m .59378 .40689 L .59248 .40648 L F
.571 .43 .651 r
.4505 .4989 m .4508 .5016 L .44815 .50221 L F
.66 .551 .72 r
.4508 .5016 m .44819 .50465 L .44815 .50221 L F
.785 .3 0 r
.58815 .40235 m .58638 .39945 L .58458 .39812 L F
0 .066 .628 r
.5894 .40391 m .58638 .39945 L .58815 .40235 L F
.559 .601 .852 r
.37521 .6091 m .37812 .60884 L .3769 .60608 L F
.506 .606 .886 r
.72676 .33381 m .72519 .33632 L .72411 .33464 L F
.348 0 0 r
.21632 .60112 m .21662 .60186 L .21313 .60118 L F
.667 .898 .979 r
.32771 .53074 m .33072 .52917 L .3311 .52665 L F
.32771 .53074 m .32648 .53005 L .33072 .52917 L F
0 0 0 r
.30148 .64202 m .30124 .64257 L .30272 .6412 L F
.527 .854 .997 r
.29507 .64324 m .29785 .64305 L .29673 .6427 L F
.29673 .6427 m .29785 .64305 L .29507 .64324 L F
.282 0 0 r
.2984 .64326 m .29785 .64305 L .29673 .6427 L F
0 0 0 r
.30124 .64257 m .29987 .64376 L .29673 .6427 L F
.29987 .64376 m .29793 .64543 L .29673 .6427 L F
.282 0 0 r
.29955 .64372 m .2984 .64326 L .29673 .6427 L F
.599 .236 .323 r
.29955 .64372 m .29673 .6427 L .29785 .64305 L F
.29955 .64372 m .30124 .64257 L .29673 .6427 L F
.49 .852 .607 r
.29969 .64339 m .30272 .6412 L .29955 .64372 L F
.466 .435 .74 r
.29993 .64258 m .30005 .64309 L .2994 .64363 L F
.49 .852 .607 r
.2997 .64337 m .2998 .6433 L .29969 .64339 L F
.2998 .6433 m .30272 .6412 L .29969 .64339 L F
.874 .492 .312 r
.29831 .64577 m .29955 .64372 L .29691 .64271 L F
.466 .435 .74 r
.2994 .64363 m .29948 .64376 L .29831 .64577 L F
.624 .8 .37 r
.2997 .64337 m .29969 .64339 L .29831 .64577 L F
.29969 .64339 m .29955 .64372 L .29831 .64577 L F
.466 .435 .74 r
.29948 .64376 m .30065 .64567 L .29831 .64577 L F
0 0 0 r
.30428 .64015 m .30272 .6412 L .2998 .6433 L F
.598 .93 .722 r
.30272 .6412 m .30124 .64257 L .29955 .64372 L F
.466 .435 .74 r
.2998 .6433 m .30065 .64567 L .2994 .64363 L F
0 0 0 r
.29987 .64325 m .2998 .6433 L .2997 .64337 L F
.30428 .64015 m .2998 .6433 L .29987 .64325 L F
.466 .435 .74 r
.30005 .64309 m .30006 .64312 L .2998 .6433 L F
0 0 0 r
.30493 .63969 m .29987 .64325 L .30156 .64384 L F
.466 .435 .74 r
.30012 .6434 m .30065 .64567 L .29987 .64325 L F
0 0 0 r
.29987 .64325 m .2997 .64337 L .30036 .64354 L F
.582 .513 .742 r
.30156 .64384 m .30065 .64567 L .30012 .6434 L F
0 0 0 r
.29987 .64325 m .30012 .6434 L .30156 .64384 L F
.582 .513 .742 r
.30156 .64384 m .30012 .6434 L .29993 .64258 L F
0 0 0 r
.30012 .6434 m .30036 .64354 L .30156 .64384 L F
.466 .435 .74 r
.29987 .64325 m .30065 .64567 L .2998 .6433 L F
.30006 .64312 m .30012 .6434 L .29987 .64325 L F
0 0 0 r
.30493 .63969 m .30272 .6412 L .30428 .64015 L F
.30368 .63717 m .30148 .64202 L .30272 .6412 L F
0 .137 .674 r
.30295 .63588 m .30368 .63717 L .30546 .6383 L F
.22 0 .229 r
.30546 .6383 m .30368 .63717 L .30272 .6412 L F
.49 0 .015 r
.24374 .57307 m .24193 .57467 L .23903 .57445 L F
.039 0 0 r
.24418 .57397 m .24374 .57307 L .24616 .57252 L F
.24418 .57397 m .24193 .57467 L .24374 .57307 L F
.667 .971 .808 r
.41157 .49199 m .40955 .49424 L .4132 .49552 L F
.41157 .49199 m .40812 .49469 L .40955 .49424 L F
.489 .759 .99 r
.55735 .4075 m .55447 .40927 L .55279 .40931 L F
.55735 .4075 m .55768 .40876 L .55447 .40927 L F
.867 .995 .797 r
.31967 .65977 m .32119 .65806 L .32013 .65754 L F
.667 .572 .739 r
.71095 .3621 m .71226 .35717 L .7096 .35784 L F
.71095 .3621 m .7136 .36112 L .71226 .35717 L F
.645 .965 .815 r
.42293 .47754 m .42433 .47587 L .42558 .47639 L F
.42293 .47754 m .42109 .47817 L .42433 .47587 L F
.978 .726 .485 r
.58406 .38187 m .58617 .38302 L .58589 .38604 L F
.746 .651 .756 r
.44507 .56279 m .44746 .56316 L .44743 .56006 L F
.704 .289 .256 r
.44775 .56493 m .44746 .56316 L .44507 .56279 L F
.702 .7 .845 r
.44746 .56316 m .44958 .55969 L .44743 .56006 L F
.112 .366 .829 r
.32852 .64592 m .32565 .64301 L .32763 .64272 L F
.219 0 0 r
.32763 .64272 m .32565 .64301 L .32472 .64462 L F
.639 .96 .92 r
.70076 .2858 m .69699 .28702 L .69865 .28519 L F
.664 .734 .902 r
.70209 .2827 m .70076 .2858 L .69865 .28519 L F
.70209 .2827 m .70369 .28488 L .70076 .2858 L F
.601 .302 .434 r
.29403 .54648 m .29703 .54648 L .29735 .5442 L F
.201 0 .324 r
.29735 .5442 m .29888 .54534 L .29995 .54364 L F
.29735 .5442 m .29703 .54648 L .29888 .54534 L F
.944 .785 .654 r
.34959 .67423 m .35212 .6738 L .35123 .67173 L F
.935 .592 .353 r
.35058 .6761 m .35212 .6738 L .34959 .67423 L F
.35058 .6761 m .35298 .67652 L .35212 .6738 L F
.762 .731 .824 r
.35212 .6738 m .35461 .67161 L .35123 .67173 L F
.725 .48 .555 r
.39148 .58485 m .39564 .58473 L .39577 .58211 L F
0 0 .143 r
.39577 .58211 m .39635 .58312 L .39544 .58057 L F
.39577 .58211 m .39564 .58473 L .39635 .58312 L F
.999 .805 .509 r
.42924 .561 m .43099 .55979 L .43049 .5579 L F
.42924 .561 m .43045 .56237 L .43099 .55979 L F
.376 .837 .898 r
.395 .64414 m .3925 .64496 L .39083 .64477 L F
0 0 .408 r
.20859 .57884 m .2097 .57732 L .20942 .57451 L F
0 0 .502 r
.20859 .57884 m .20986 .58091 L .2097 .57732 L F
.009 0 .494 r
.20882 .58149 m .20986 .58091 L .20859 .57884 L F
0 .043 .569 r
.37824 .51638 m .3771 .51556 L .37551 .51436 L F
.37824 .51638 m .37929 .51775 L .3771 .51556 L F
.756 .737 .835 r
.33585 .5215 m .3317 .52098 L .33486 .5191 L F
.469 .846 .987 r
.33585 .5215 m .33697 .52046 L .33985 .52103 L F
.766 .501 .533 r
.54035 .4542 m .53644 .45632 L .53645 .45395 L F
.54035 .4542 m .54043 .45671 L .53644 .45632 L F
.536 .185 .32 r
.27829 .57108 m .27562 .57148 L .27622 .56934 L F
0 .109 .641 r
.20882 .58149 m .20993 .58521 L .21076 .58358 L F
0 0 .434 r
.20993 .58521 m .211 .58727 L .21076 .58358 L F
0 0 .435 r
.20993 .58521 m .21034 .58828 L .211 .58727 L F
.038 .072 .567 r
.31705 .5885 m .31823 .59013 L .31893 .58707 L F
.31705 .5885 m .31773 .59137 L .31823 .59013 L F
.762 .713 .806 r
.65445 .35119 m .65826 .35175 L .65711 .34798 L F
.774 .719 .802 r
.65711 .34798 m .65826 .35175 L .66095 .34861 L F
0 0 .157 r
.24311 .53611 m .24274 .53444 L .24346 .53323 L F
.677 .417 .521 r
.38818 .55159 m .38609 .55054 L .38442 .55225 L F
.42 .686 .973 r
.72287 .34083 m .72558 .34058 L .72209 .34029 L F
.376 .042 .267 r
.72232 .34291 m .72558 .34058 L .72287 .34083 L F
.673 .813 .368 r
.23355 .54405 m .23397 .54353 L .23642 .54294 L F
.23355 .54405 m .23267 .54584 L .23397 .54353 L F
0 0 0 r
.25814 .52167 m .25866 .52136 L .26062 .52013 L F
.215 .63 .953 r
.57749 .39403 m .57391 .39261 L .57605 .39304 L F
.065 .45 .88 r
.57916 .39356 m .57749 .39403 L .57605 .39304 L F
.57916 .39356 m .58038 .39521 L .57749 .39403 L F
.681 .505 .641 r
.25744 .54686 m .26119 .54773 L .26044 .54339 L F
0 0 0 r
.70172 .30655 m .70615 .30347 L .70101 .30344 L F
.70172 .30655 m .70382 .30545 L .70615 .30347 L F
.778 .408 .356 r
.70382 .30545 m .70643 .30409 L .70615 .30347 L F
.868 .906 .856 r
.67029 .31906 m .66786 .31891 L .66985 .31574 L F
.67029 .31906 m .66865 .32055 L .66786 .31891 L F
.811 .813 .852 r
.67319 .31603 m .67029 .31906 L .66985 .31574 L F
.895 .733 .672 r
.53138 .44117 m .52797 .4436 L .52797 .43853 L F
.878 .665 .611 r
.52894 .43996 m .53138 .44117 L .52797 .43853 L F
.863 .697 .675 r
.53211 .43866 m .52894 .43996 L .53007 .43735 L F
.53211 .43866 m .53138 .44117 L .52894 .43996 L F
.475 .624 .916 r
.24812 .62351 m .24922 .6214 L .24654 .61996 L F
.24812 .62351 m .25049 .62364 L .24922 .6214 L F
0 0 .23 r
.33452 .61641 m .33403 .61695 L .33456 .61343 L F
0 0 .281 r
.33459 .61913 m .33403 .61695 L .33452 .61641 L F
0 0 .279 r
.33459 .61913 m .33385 .62082 L .33403 .61695 L F
.945 .908 .753 r
.62628 .40791 m .62833 .40713 L .62824 .40482 L F
.903 .91 .818 r
.31109 .531 m .31173 .52682 L .31364 .52756 L F
.31109 .531 m .30911 .53066 L .31173 .52682 L F
.592 .433 .635 r
.31364 .52756 m .31387 .53078 L .31109 .531 L F
0 .179 .714 r
.31109 .531 m .31212 .53075 L .30911 .53066 L F
.534 .224 .388 r
.31387 .53078 m .31328 .53288 L .31109 .531 L F
0 .179 .714 r
.31109 .531 m .31328 .53288 L .31212 .53075 L F
.48 .811 1 r
.5471 .4097 m .54476 .41102 L .5436 .41075 L F
.5471 .4097 m .54722 .41093 L .54476 .41102 L F
.124 0 .076 r
.42932 .52401 m .43203 .52107 L .42785 .5212 L F
.843 .941 .575 r
.43373 .51727 m .43203 .52107 L .43176 .52007 L F
.43141 .52069 m .43123 .5211 L .43203 .52107 L F
.768 .44 .432 r
.43164 .52109 m .43134 .52085 L .43198 .52108 L F
.43134 .52085 m .42991 .51967 L .43141 .52069 L F
.43134 .52085 m .43141 .52069 L .43198 .52108 L F
.843 .941 .575 r
.43373 .51727 m .43179 .52013 L .43203 .52107 L F
0 0 0 r
.43203 .52107 m .43123 .5211 L .42785 .5212 L F
.43123 .5211 m .43115 .5211 L .43032 .52113 L F
.768 .44 .432 r
.43075 .52164 m .43021 .52161 L .43134 .52085 L F
0 0 0 r
.43115 .5211 m .43113 .5211 L .43107 .52111 L F
.43115 .5211 m .43107 .52111 L .43032 .52113 L F
.768 .44 .432 r
.43134 .52085 m .43095 .52111 L .42991 .51967 L F
.43095 .52111 m .43021 .52161 L .43013 .52113 L F
0 0 0 r
.43123 .5211 m .43032 .52113 L .42785 .5212 L F
.275 .337 .746 r
.42785 .5212 m .43113 .5211 L .42991 .51967 L F
.768 .44 .432 r
.43095 .52111 m .43013 .52113 L .42991 .51967 L F
.843 .941 .575 r
.43134 .52085 m .43115 .5211 L .43123 .5211 L F
.124 0 .076 r
.42932 .52401 m .4312 .52322 L .43203 .52107 L F
0 0 0 r
.43203 .52107 m .4312 .52322 L .43241 .52172 L F
.768 .44 .432 r
.43241 .52172 m .43075 .52164 L .43134 .52085 L F
.843 .941 .575 r
.43141 .52069 m .43113 .5211 L .43115 .5211 L F
.43141 .52069 m .43115 .5211 L .43134 .52085 L F
.712 .427 .492 r
.43108 .52104 m .43113 .5211 L .43179 .52013 L F
.43176 .52007 m .43179 .52013 L .43373 .51727 L F
.43108 .52104 m .43179 .52013 L .43176 .52007 L F
0 0 0 r
.43203 .52107 m .43241 .52172 L .43218 .52113 L F
.43179 .52013 m .43218 .52113 L .43175 .51999 L F
.43203 .52107 m .43218 .52113 L .43179 .52013 L F
.43203 .52107 m .43175 .51999 L .43171 .51991 L F
.843 .941 .575 r
.43179 .52013 m .43141 .52069 L .43203 .52107 L F
.712 .427 .492 r
.42991 .51967 m .43108 .52104 L .43135 .52065 L F
.42991 .51967 m .43135 .52065 L .43373 .51727 L F
.768 .44 .432 r
.43198 .52108 m .42991 .51967 L .43236 .52107 L F
.843 .941 .575 r
.43373 .51727 m .43176 .52007 L .43171 .51991 L F
.201 0 .059 r
.43373 .51727 m .43171 .51991 L .43474 .51833 L F
.458 .315 .599 r
.43241 .52172 m .43474 .51833 L .43171 .51991 L F
.768 .44 .432 r
.43236 .52107 m .42991 .51967 L .43222 .51882 L F
.43241 .52172 m .43164 .52109 L .43236 .52107 L F
.116 0 .003 r
.32931 .59834 m .32816 .6003 L .32598 .60106 L F
.193 0 .043 r
.33026 .59957 m .32931 .59834 L .33137 .5974 L F
.33026 .59957 m .32816 .6003 L .32931 .59834 L F
.2 0 .307 r
.31893 .58707 m .3211 .58421 L .31838 .5853 L F
.84 .816 .826 r
.63985 .43782 m .64326 .43753 L .64297 .43389 L F
.835 .812 .828 r
.64297 .43389 m .64326 .43753 L .64589 .43457 L F
.849 .679 .672 r
.71239 .32869 m .71297 .32916 L .71099 .33231 L F
.692 .298 .296 r
.60315 .45943 m .60466 .45748 L .60516 .45919 L F
.655 .193 .145 r
.60466 .45748 m .60808 .4597 L .60516 .45919 L F
.413 .201 .479 r
.29746 .63608 m .30039 .63398 L .29963 .63568 L F
.222 0 .208 r
.29658 .6385 m .29746 .63608 L .29963 .63568 L F
.557 .298 .478 r
.35847 .53709 m .35626 .5395 L .35597 .53829 L F
.796 .998 .796 r
.6601 .38175 m .66185 .38121 L .65916 .38402 L F
.392 .38 .726 r
.21316 .60126 m .21662 .60186 L .21246 .5985 L F
0 .462 .748 r
.21153 .60218 m .21662 .60186 L .21316 .60126 L F
.711 .176 0 r
.69461 .3287 m .69348 .32896 L .69494 .3267 L F
.69461 .3287 m .69627 .33072 L .69348 .32896 L F
.595 .571 .797 r
.69137 .38005 m .69416 .38006 L .69136 .38074 L F
.925 .942 .791 r
.69416 .38006 m .69187 .38332 L .69136 .38074 L F
.577 .473 .698 r
.45417 .48594 m .45456 .48876 L .45194 .48935 L F
.548 .45 .696 r
.45441 .49128 m .45194 .48935 L .45456 .48876 L F
.45441 .49128 m .45247 .49214 L .45194 .48935 L F
0 .011 .547 r
.42866 .54773 m .42715 .54773 L .43085 .54575 L F
0 0 0 r
.43292 .54438 m .43085 .54575 L .43047 .54354 L F
.43292 .54438 m .43311 .54562 L .43085 .54575 L F
.4311 .54687 m .43085 .54575 L .43311 .54562 L F
.4311 .54687 m .42866 .54773 L .43085 .54575 L F
.397 .547 .888 r
.29987 .65278 m .29732 .65022 L .29935 .64871 L F
.34 .392 .77 r
.30248 .65118 m .29987 .65278 L .29935 .64871 L F
.076 0 .3 r
.29971 .65454 m .29987 .65278 L .30248 .65118 L F
.381 .84 .777 r
.65411 .391 m .64997 .39245 L .65116 .39105 L F
.808 .945 .914 r
.65581 .38925 m .65411 .391 L .65116 .39105 L F
.375 0 0 r
.33362 .49562 m .33684 .4953 L .33269 .49503 L F
.03 .601 .747 r
.33727 .49519 m .33684 .4953 L .33362 .49562 L F
.33727 .49519 m .33916 .4953 L .33684 .4953 L F
.76 .774 .865 r
.28936 .62786 m .29223 .62736 L .29117 .6263 L F
.472 .457 .761 r
.29223 .62736 m .29374 .62505 L .29117 .6263 L F
.593 .764 .961 r
.29369 .62646 m .29223 .62736 L .29418 .6265 L F
.472 .457 .761 r
.29223 .62736 m .29513 .62946 L .29411 .62621 L F
.29223 .62736 m .29369 .62646 L .29374 .62505 L F
.593 .764 .961 r
.29117 .6263 m .29369 .62646 L .29374 .62505 L F
.29369 .62646 m .29418 .6265 L .29374 .62505 L F
.472 .457 .761 r
.29369 .62646 m .29411 .62621 L .29374 .62505 L F
.593 .764 .961 r
.29117 .6263 m .29223 .62736 L .29369 .62646 L F
.622 .951 .773 r
.26684 .54105 m .26738 .53999 L .26867 .54023 L F
.26684 .54105 m .26457 .54205 L .26738 .53999 L F
.851 .568 .509 r
.41711 .49368 m .41952 .49261 L .41616 .49181 L F
.41711 .49368 m .41858 .49406 L .41876 .49378 L F
.41799 .49329 m .41876 .49378 L .41952 .49261 L F
.41711 .49368 m .41876 .49378 L .41799 .49329 L F
.872 .596 .517 r
.41952 .49261 m .41906 .49399 L .41877 .49377 L F
.499 .373 .64 r
.41858 .49406 m .41859 .49405 L .41877 .49377 L F
.41876 .49378 m .41877 .49377 L .41952 .49261 L F
.41858 .49406 m .41877 .49377 L .41876 .49378 L F
.872 .596 .517 r
.41952 .49261 m .41877 .49377 L .41616 .49181 L F
.656 .684 .865 r
.41616 .49181 m .41877 .49377 L .41537 .48704 L F
.41877 .49377 m .41893 .49389 L .41884 .4937 L F
.41877 .49377 m .41884 .4937 L .41537 .48704 L F
.41893 .49389 m .41905 .49397 L .41888 .49365 L F
.41884 .4937 m .41888 .49365 L .41537 .48704 L F
.41893 .49389 m .41888 .49365 L .41884 .4937 L F
.919 .849 .403 r
.41973 .48847 m .41914 .49335 L .41952 .49261 L F
.41914 .49335 m .41906 .49399 L .41952 .49261 L F
.785 .739 .81 r
.41537 .48704 m .41888 .49365 L .41973 .48847 L F
.41888 .49365 m .41906 .49399 L .41914 .49335 L F
.499 .373 .64 r
.41877 .49377 m .41891 .49362 L .41952 .49261 L F
.785 .739 .81 r
.41888 .49365 m .41914 .49335 L .41973 .48847 L F
.499 .373 .64 r
.41891 .49362 m .41911 .4934 L .41914 .49335 L F
.41891 .49362 m .41914 .49335 L .41952 .49261 L F
.41911 .4934 m .4208 .49156 L .41952 .49261 L F
.41859 .49405 m .41999 .49248 L .41877 .49377 L F
.41999 .49248 m .4208 .49156 L .41877 .49377 L F
.656 .684 .865 r
.41893 .49389 m .41906 .49399 L .41905 .49397 L F
.919 .849 .403 r
.41973 .48847 m .41952 .49261 L .4208 .49156 L F
.387 .274 .602 r
.30847 .5341 m .31071 .53613 L .30861 .53675 L F
.30847 .5341 m .31071 .53613 L .30861 .53675 L F
0 0 .334 r
.36744 .63644 m .3682 .63764 L .36976 .63558 L F
.36744 .63644 m .36854 .63963 L .3682 .63764 L F
.754 .469 .5 r
.2958 .64616 m .29917 .64613 L .29935 .64871 L F
0 0 0 r
.23447 .53316 m .23597 .53302 L .23802 .53136 L F
.776 .969 .676 r
.24068 .52799 m .23802 .53136 L .23936 .52926 L F
.473 .829 .562 r
.23802 .53136 m .23781 .53146 L .23936 .52926 L F
.23802 .53136 m .23597 .53302 L .23781 .53146 L F
.805 .879 .9 r
.64683 .34242 m .64212 .34395 L .64534 .34104 L F
.847 .877 .863 r
.64943 .33958 m .64683 .34242 L .64534 .34104 L F
.878 .864 .821 r
.64432 .36179 m .64683 .35859 L .64546 .35712 L F
.816 .861 .882 r
.64546 .35712 m .64683 .35859 L .64978 .35568 L F
.349 .135 .442 r
.33951 .54023 m .33911 .54341 L .33749 .54371 L F
.151 0 .322 r
.342 .53657 m .34176 .53934 L .33951 .54023 L F
.068 0 .337 r
.34107 .54169 m .33951 .54023 L .34176 .53934 L F
.34107 .54169 m .33911 .54341 L .33951 .54023 L F
.161 0 0 r
.35752 .57565 m .35518 .57536 L .35464 .57525 L F
0 0 .454 r
.33914 .50309 m .33723 .50068 L .3383 .50318 L F
.452 .196 .434 r
.42763 .53346 m .42475 .53649 L .42505 .53409 L F
.754 .932 .583 r
.69669 .34787 m .69424 .35085 L .69681 .34737 L F
0 0 0 r
.33317 .62307 m .33385 .62082 L .33459 .61913 L F
.425 .843 .677 r
.25802 .52839 m .25554 .52969 L .25424 .53061 L F
.437 .873 .807 r
.25554 .52969 m .25181 .53133 L .25424 .53061 L F
.331 0 .183 r
.35192 .55275 m .35429 .55219 L .35521 .55011 L F
.564 .311 .492 r
.35429 .55219 m .35777 .54954 L .35521 .55011 L F
.99 .89 .586 r
.40195 .59616 m .40188 .60053 L .40275 .5982 L F
.42 .216 .494 r
.31034 .60435 m .31273 .60392 L .31263 .60101 L F
.509 .258 .469 r
.31034 .60435 m .31274 .6061 L .31273 .60392 L F
.31034 .60435 m .31021 .60667 L .31274 .6061 L F
.443 .18 .418 r
.27452 .56267 m .27693 .5621 L .27742 .55968 L F
.478 .27 .518 r
.27693 .5621 m .2796 .55889 L .27742 .55968 L F
.798 .998 .799 r
.69424 .35128 m .69107 .3536 L .69424 .35085 L F
.286 0 0 r
.30225 .54298 m .30467 .54273 L .30626 .54042 L F
.593 .468 .678 r
.30626 .54042 m .30885 .54035 L .30861 .53675 L F
0 0 0 r
.30626 .54042 m .3067 .54141 L .30885 .54035 L F
.30626 .54042 m .30467 .54273 L .3067 .54141 L F
.934 .865 .747 r
.65059 .41946 m .65119 .41462 L .64889 .41806 L F
.628 .137 .068 r
.62609 .387 m .62879 .38881 L .62486 .38851 L F
.398 0 0 r
.6275 .38796 m .62609 .387 L .62486 .38851 L F
.6275 .38796 m .62879 .38881 L .62609 .387 L F
.407 .256 .563 r
.31263 .60101 m .31538 .60088 L .31531 .5968 L F
.532 .378 .618 r
.31273 .60392 m .31538 .60088 L .31263 .60101 L F
.528 .485 .753 r
.24086 .56143 m .24216 .5583 L .24002 .55991 L F
.293 .622 .96 r
.37985 .67797 m .3825 .67823 L .38082 .67663 L F
.37985 .67797 m .3825 .67823 L .38082 .67663 L F
.388 .1 .349 r
.28292 .55671 m .28476 .55802 L .28688 .55525 L F
.228 0 .019 r
.28688 .55525 m .28681 .55745 L .28887 .55558 L F
.28688 .55525 m .28476 .55802 L .28681 .55745 L F
.106 .314 .788 r
.21046 .59437 m .21246 .5985 L .213 .59629 L F
.126 .336 .802 r
.21246 .5985 m .21662 .60186 L .213 .59629 L F
.178 .265 .717 r
.42712 .50682 m .42605 .50858 L .42444 .50725 L F
.518 .228 .413 r
.42605 .50858 m .4284 .51041 L .42897 .50824 L F
.178 .265 .717 r
.42712 .50682 m .4284 .51041 L .42605 .50858 L F
.797 .504 .494 r
.70802 .31593 m .70234 .3127 L .70706 .31332 L F
.778 .408 .356 r
.70382 .30545 m .70717 .30625 L .70643 .30409 L F
.617 .913 .981 r
.3803 .66836 m .3815 .66928 L .38354 .66813 L F
.578 .933 .937 r
.38354 .66813 m .3815 .66928 L .37879 .66939 L F
.212 .735 .839 r
.39089 .5143 m .38902 .51416 L .38639 .51454 L F
0 .571 .732 r
.39255 .51435 m .38902 .51416 L .39089 .5143 L F
.437 .262 .545 r
.29486 .53669 m .29759 .53326 L .29485 .53405 L F
.587 .57 .801 r
.45415 .47486 m .45313 .47972 L .45168 .47615 L F
.45415 .47486 m .45577 .47932 L .45313 .47972 L F
.541 .329 .542 r
.45577 .47932 m .45307 .48232 L .45313 .47972 L F
.015 0 .046 r
.74055 .3319 m .74165 .3317 L .74323 .32919 L F
.738 .652 .765 r
.74078 .33495 m .74165 .3317 L .74055 .3319 L F
.741 .941 .95 r
.56736 .41672 m .56633 .41915 L .56961 .41627 L F
.606 .605 .824 r
.56633 .41915 m .56957 .41878 L .56961 .41627 L F
.507 .172 .334 r
.56887 .42066 m .56633 .41915 L .56601 .42016 L F
.56887 .42066 m .56957 .41878 L .56633 .41915 L F
0 0 0 r
.56601 .42016 m .56633 .41915 L .56736 .41672 L F
.875 .515 .364 r
.29793 .64543 m .29507 .64324 L .29673 .6427 L F
.448 .398 .709 r
.34929 .55331 m .35226 .55596 L .35192 .55275 L F
.312 0 .213 r
.45566 .58752 m .4564 .58571 L .45872 .58503 L F
.821 .717 .751 r
.29824 .62384 m .29418 .6265 L .29374 .62505 L F
.29824 .62384 m .29507 .6247 L .29633 .62461 L F
.562 .525 .772 r
.29633 .62461 m .2985 .6225 L .29824 .62384 L F
.29633 .62461 m .29861 .62183 L .2985 .6225 L F
.29633 .62461 m .29958 .62437 L .29861 .62183 L F
.503 .441 .72 r
.29861 .62183 m .29876 .62443 L .29633 .62461 L F
.29881 .62524 m .29881 .62526 L .29633 .62461 L F
.29881 .62526 m .29882 .62549 L .29852 .62539 L F
.29881 .62526 m .29852 .62539 L .29633 .62461 L F
.328 .078 .374 r
.29637 .62814 m .29888 .62776 L .29946 .62497 L F
.29884 .62524 m .29946 .62497 L .29958 .62437 L F
.29634 .62582 m .29865 .62547 L .29633 .62461 L F
.32 .791 .927 r
.29852 .62539 m .29842 .62538 L .29633 .62461 L F
.328 .078 .374 r
.29865 .62547 m .29884 .62524 L .29633 .62461 L F
.304 .349 .743 r
.29374 .62505 m .29637 .62814 L .29633 .62461 L F
.32 .791 .927 r
.29842 .62538 m .29429 .62531 L .29633 .62461 L F
.29868 .62549 m .29429 .62531 L .29852 .62539 L F
.328 .078 .374 r
.29884 .62524 m .29958 .62437 L .29872 .62444 L F
.29881 .62524 m .29872 .62444 L .29633 .62461 L F
.29884 .62524 m .29872 .62444 L .29881 .62524 L F
0 0 .195 r
.29916 .62313 m .29883 .62544 L .29861 .62183 L F
.328 .078 .374 r
.29885 .6256 m .29886 .62558 L .29865 .62547 L F
.29886 .62558 m .29946 .62497 L .29883 .62536 L F
0 0 .195 r
.29883 .62544 m .29882 .62549 L .29881 .62526 L F
.32 .791 .927 r
.29882 .62549 m .29868 .62549 L .29852 .62539 L F
.29882 .62549 m .2988 .62547 L .2987 .62549 L F
.2988 .62547 m .29879 .62546 L .2987 .62549 L F
.328 .078 .374 r
.29868 .62549 m .29883 .62536 L .29865 .62547 L F
.503 .441 .72 r
.29876 .62443 m .29881 .62524 L .29633 .62461 L F
.32 .791 .927 r
.29879 .62546 m .29731 .62428 L .29869 .62548 L F
.29879 .62546 m .29869 .62548 L .2987 .62549 L F
.328 .078 .374 r
.29886 .62558 m .29884 .62545 L .29868 .62549 L F
.29879 .62546 m .29883 .62536 L .29868 .62549 L F
0 0 .195 r
.29881 .62528 m .29881 .62526 L .29881 .62524 L F
.29883 .62544 m .29881 .62524 L .29861 .62183 L F
.919 .743 .647 r
.29916 .62313 m .29731 .62428 L .29879 .62546 L F
.29884 .62541 m .29879 .62546 L .29882 .62549 L F
.328 .078 .374 r
.29884 .62541 m .29883 .62536 L .29879 .62546 L F
0 0 .195 r
.29883 .62544 m .29881 .62526 L .29881 .62528 L F
.919 .743 .647 r
.29916 .62313 m .29879 .62546 L .29884 .62541 L F
.328 .078 .374 r
.29884 .62545 m .29884 .62541 L .29879 .62546 L F
.32 .791 .927 r
.2987 .62549 m .29731 .62428 L .29429 .62531 L F
.328 .078 .374 r
.29637 .62814 m .29862 .6255 L .29634 .62582 L F
.29862 .6255 m .29865 .62547 L .29634 .62582 L F
.29865 .62547 m .29946 .62497 L .29884 .62524 L F
.29637 .62814 m .29885 .6256 L .29865 .62547 L F
.821 .717 .751 r
.29507 .6247 m .29374 .62505 L .29633 .62461 L F
.773 .465 .465 r
.3311 .52665 m .33296 .53027 L .33334 .52767 L F
0 .103 .644 r
.33334 .52767 m .33507 .52899 L .3338 .52457 L F
.286 .038 .353 r
.33334 .52767 m .33296 .53027 L .33507 .52899 L F
.72 .767 .89 r
.64605 .40072 m .64858 .39938 L .64471 .39894 L F
.64605 .40072 m .64858 .39938 L .64471 .39894 L F
0 0 .197 r
.69757 .33878 m .69733 .34241 L .69804 .33997 L F
.802 .644 .089 r
.69733 .34241 m .69703 .34224 L .69804 .33997 L F
.69733 .34241 m .69729 .34472 L .69703 .34224 L F
.67 .945 .685 r
.54098 .41429 m .53817 .41723 L .53746 .41718 L F
.908 .515 .247 r
.37929 .51775 m .38179 .52037 L .38114 .51897 L F
.84 .771 .786 r
.64199 .3651 m .64432 .36179 L .64275 .3601 L F
.878 .864 .821 r
.64432 .36179 m .64546 .35712 L .64275 .3601 L F
.507 .487 .769 r
.29486 .53669 m .29409 .53907 L .29711 .53607 L F
.91 .872 .788 r
.42575 .58116 m .42931 .57891 L .42735 .57887 L F
.42575 .58116 m .42768 .58169 L .42931 .57891 L F
.762 .961 .933 r
.42735 .57887 m .42931 .57891 L .42942 .57721 L F
.366 .165 .469 r
.42931 .57891 m .43067 .58208 L .42942 .57721 L F
.42931 .57891 m .42768 .58169 L .43067 .58208 L F
.546 .526 .784 r
.34229 .53582 m .3484 .53932 L .349 .53701 L F
.34229 .53582 m .3461 .54034 L .3484 .53932 L F
0 0 .055 r
.34229 .53582 m .34357 .53574 L .342 .53657 L F
0 0 .548 r
.34525 .53164 m .34598 .53455 L .34434 .5309 L F
.34525 .53164 m .34434 .5309 L .34411 .53039 L F
.42 .237 .524 r
.34735 .5306 m .34609 .53233 L .34525 .53164 L F
0 0 .201 r
.34525 .53164 m .34229 .53582 L .34598 .53455 L F
.42 .237 .524 r
.34609 .53233 m .34473 .53421 L .34525 .53164 L F
0 0 .201 r
.34525 .53164 m .34357 .53574 L .34229 .53582 L F
.448 .788 .998 r
.2254 .56404 m .22572 .56583 L .22442 .56209 L F
.2254 .56404 m .22747 .56516 L .22572 .56583 L F
.535 .399 .642 r
.61918 .37351 m .61679 .37685 L .61661 .37423 L F
.028 0 0 r
.33377 .68107 m .33049 .68454 L .33249 .68369 L F
.078 0 .176 r
.33639 .67776 m .33377 .68107 L .336 .68059 L F
.238 0 .107 r
.336 .68059 m .33377 .68107 L .33249 .68369 L F
.306 .224 .597 r
.69277 .37366 m .69339 .37632 L .69137 .38005 L F
.595 .571 .797 r
.69137 .38005 m .69339 .37632 L .69416 .38006 L F
.829 .818 .839 r
.64566 .43141 m .64297 .43389 L .64589 .43457 L F
.809 .804 .846 r
.64566 .43141 m .64589 .43457 L .64897 .43154 L F
.861 .643 .605 r
.4078 .50333 m .41167 .50214 L .41032 .50143 L F
.4078 .50333 m .41143 .50495 L .41167 .50214 L F
.871 .942 .861 r
.41313 .4985 m .41032 .50143 L .41167 .50214 L F
.839 .969 .652 r
.70184 .30056 m .70363 .29823 L .70245 .29899 L F
.899 .986 .78 r
.70363 .29823 m .70507 .29807 L .70245 .29899 L F
.70363 .29823 m .70513 .29574 L .70374 .29628 L F
.70363 .29823 m .70374 .29628 L .70507 .29807 L F
.709 .95 .954 r
.38607 .67746 m .3825 .67823 L .38476 .67696 L F
.38607 .67746 m .3825 .67823 L .38476 .67696 L F
.285 0 0 r
.31531 .65876 m .31967 .65977 L .3177 .65834 L F
.867 .995 .797 r
.31967 .65977 m .32013 .65754 L .3177 .65834 L F
0 0 .388 r
.20963 .57194 m .21059 .56818 L .20968 .56923 L F
.597 .579 .804 r
.63725 .4403 m .63985 .43782 L .63602 .43636 L F
.612 .842 .987 r
.59361 .38149 m .59212 .38359 L .59064 .38231 L F
0 .341 .818 r
.59596 .38685 m .59212 .38359 L .59309 .38542 L F
.066 .081 .565 r
.59309 .38542 m .59212 .38359 L .59361 .38149 L F
0 0 0 r
.3438 .5541 m .3434 .55362 L .34359 .55171 L F
.3438 .5541 m .34226 .55603 L .3434 .55362 L F
.527 .66 .92 r
.44507 .54979 m .44577 .54637 L .44342 .54735 L F
.44507 .54979 m .44749 .54923 L .44577 .54637 L F
.492 .351 .616 r
.4452 .55265 m .44749 .54923 L .44507 .54979 L F
.925 .891 .778 r
.649 .40215 m .64916 .40584 L .64694 .4029 L F
.93 .782 .675 r
.64916 .40584 m .64613 .40783 L .64694 .4029 L F
.64916 .40584 m .64806 .40943 L .64613 .40783 L F
.833 .682 .696 r
.33749 .54371 m .33331 .54594 L .33352 .5439 L F
.702 .416 .488 r
.35298 .51021 m .34881 .50856 L .35189 .50852 L F
.57 .646 .886 r
.42901 .53724 m .42959 .53354 L .42763 .53346 L F
.42901 .53724 m .43151 .53664 L .42959 .53354 L F
0 0 0 r
.42901 .53724 m .42961 .53807 L .43151 .53664 L F
.42901 .53724 m .42844 .5394 L .42961 .53807 L F
.461 .774 .997 r
.60859 .36965 m .61332 .37031 L .61122 .36847 L F
.725 .987 .807 r
.61332 .37031 m .6091 .37325 L .61176 .37041 L F
.253 .557 .932 r
.61122 .36847 m .61332 .37031 L .6141 .3691 L F
.597 .948 .905 r
.61332 .37031 m .61176 .37041 L .6141 .3691 L F
.727 .491 .569 r
.52823 .44694 m .53062 .44551 L .5283 .44926 L F
.555 .567 .821 r
.53069 .44374 m .53062 .44551 L .52823 .44694 L F
.741 .509 .577 r
.53062 .44551 m .53263 .45019 L .5283 .44926 L F
.242 0 .068 r
.59202 .46339 m .59557 .46044 L .59459 .46267 L F
.472 .033 .123 r
.59557 .46044 m .59755 .46222 L .59459 .46267 L F
.59557 .46044 m .5985 .46025 L .59755 .46222 L F
.451 .693 .969 r
.27132 .52294 m .27305 .52484 L .27355 .52267 L F
.562 .802 .989 r
.27355 .52267 m .27305 .52484 L .27558 .5241 L F
.892 .688 .173 r
.40324 .58042 m .40367 .57893 L .40276 .57776 L F
.40324 .58042 m .40361 .58092 L .40367 .57893 L F
.491 .144 .307 r
.29679 .56219 m .29365 .56383 L .29558 .5616 L F
.063 0 .388 r
.33648 .604 m .33503 .6079 L .33651 .60706 L F
.707 .519 .632 r
.34383 .55928 m .34226 .55603 L .3438 .5541 L F
.757 .743 .839 r
.33538 .51074 m .33695 .51415 L .33941 .51105 L F
.709 .796 .919 r
.33695 .51415 m .34049 .51315 L .33941 .51105 L F
.636 .816 .969 r
.43737 .54841 m .43826 .54945 L .44056 .54865 L F
0 0 .424 r
.34992 .56761 m .34906 .56945 L .34894 .56551 L F
.841 .718 .728 r
.34992 .56761 m .35192 .5711 L .34906 .56945 L F
.523 0 0 r
.31173 .52682 m .31453 .52749 L .31364 .52756 L F
.495 .461 .748 r
.31453 .52749 m .31387 .53078 L .31364 .52756 L F
.821 .681 .708 r
.30684 .63022 m .30554 .63277 L .30392 .63332 L F
0 0 .185 r
.3074 .63168 m .30684 .63022 L .30783 .62914 L F
.3074 .63168 m .30554 .63277 L .30684 .63022 L F
.551 .156 .248 r
.35338 .53167 m .35698 .53114 L .35469 .53164 L F
.811 .979 .691 r
.65825 .38594 m .65712 .38776 L .65581 .38925 L F
.527 .56 .832 r
.63252 .37028 m .63388 .36628 L .63104 .36828 L F
.63252 .37028 m .63499 .37002 L .63388 .36628 L F
.95 .793 .652 r
.42642 .58539 m .42768 .58169 L .42575 .58116 L F
.332 .346 .725 r
.43067 .58208 m .42768 .58169 L .43222 .58382 L F
.65 .422 .559 r
.33072 .52917 m .33296 .53027 L .3311 .52665 L F
.482 .323 .588 r
.44469 .47282 m .44502 .47618 L .44229 .4767 L F
0 0 0 r
.70458 .33327 m .70667 .33189 L .70355 .33489 L F
.895 .919 .83 r
.62179 .37414 m .62183 .37798 L .623 .37605 L F
.958 .942 .71 r
.62061 .38001 m .62183 .37798 L .62179 .37414 L F
.514 .792 .996 r
.4543 .47007 m .45525 .4682 L .45745 .46966 L F
.53 .264 .456 r
.45745 .46966 m .45679 .47197 L .4543 .47007 L F
.108 .287 .763 r
.4543 .47007 m .45679 .47197 L .45525 .4682 L F
.787 .741 .811 r
.63724 .36729 m .64199 .3651 L .6402 .36361 L F
.84 .771 .786 r
.64199 .3651 m .64018 .36104 L .6402 .36361 L F
.64199 .3651 m .64275 .3601 L .64018 .36104 L F
.969 .903 .699 r
.66786 .31891 m .66865 .32055 L .667 .32078 L F
.282 .053 .379 r
.35542 .56598 m .3574 .56532 L .35791 .56285 L F
.211 0 .33 r
.35517 .56845 m .3574 .56532 L .35542 .56598 L F
.201 0 .159 r
.35847 .53709 m .35815 .53934 L .35626 .5395 L F
.961 .646 .24 r
.35847 .53709 m .35815 .53934 L .35678 .53526 L F
.35847 .53709 m .35815 .53934 L .35678 .53526 L F
.62 .208 .241 r
.36043 .53928 m .35815 .53934 L .35847 .53709 L F
.525 .283 .491 r
.31935 .61408 m .31913 .61655 L .31624 .61703 L F
.248 .058 .416 r
.32089 .61578 m .31935 .61408 L .32171 .61347 L F
.32089 .61578 m .31913 .61655 L .31935 .61408 L F
0 0 .421 r
.57954 .41183 m .5802 .41438 L .57952 .41366 L F
.982 .879 .654 r
.5802 .41438 m .57866 .41537 L .57952 .41366 L F
.5802 .41438 m .57971 .41648 L .57866 .41537 L F
.868 .424 .109 r
.59148 .39303 m .59469 .39654 L .5927 .39604 L F
.426 0 0 r
.5927 .39604 m .59469 .39654 L .59368 .39664 L F
.372 .043 .271 r
.3115 .55274 m .31463 .55335 L .31505 .54982 L F
.201 0 .231 r
.31505 .54982 m .31463 .55335 L .31625 .55188 L F
.821 .953 .904 r
.26024 .5257 m .25664 .52664 L .25802 .52839 L F
0 0 0 r
.25775 .52876 m .25554 .52969 L .25802 .52839 L F
.25775 .52876 m .25802 .52839 L .25664 .52664 L F
.038 0 0 r
.22963 .55837 m .22623 .55951 L .22728 .55904 L F
.469 .326 .604 r
.4516 .50471 m .44923 .50887 L .44819 .50465 L F
.4516 .50471 m .45178 .50886 L .44923 .50887 L F
.448 .36 .664 r
.45178 .50886 m .44985 .51124 L .44923 .50887 L F
.917 .705 .602 r
.2551 .61303 m .25386 .61601 L .25758 .61623 L F
.746 .263 .092 r
.25386 .61601 m .25583 .61821 L .25758 .61623 L F
.624 .418 .583 r
.25583 .61821 m .25939 .61416 L .25758 .61623 L F
.657 .132 0 r
.30989 .64638 m .30867 .64489 L .31101 .64685 L F
.358 .115 .403 r
.30606 .64634 m .30791 .64395 L .30867 .64489 L F
.626 .935 .963 r
.30452 .64586 m .30606 .64634 L .30867 .64489 L F
.30452 .64586 m .30867 .64489 L .30653 .64497 L F
.657 .132 0 r
.30653 .64497 m .30867 .64489 L .30989 .64638 L F
.358 .115 .403 r
.30791 .64395 m .30877 .64283 L .30867 .64489 L F
.645 .555 .739 r
.31071 .63938 m .30877 .64283 L .30854 .64025 L F
.534 .42 .669 r
.31071 .63938 m .31126 .64223 L .30877 .64283 L F
.623 .416 .581 r
.31126 .64223 m .30867 .64489 L .30877 .64283 L F
.837 .384 0 r
.60312 .42128 m .60227 .41959 L .60009 .41739 L F
.808 .791 .837 r
.64806 .35387 m .65195 .35462 L .65076 .35073 L F
.816 .783 .822 r
.64978 .35568 m .65195 .35462 L .64806 .35387 L F
.805 .79 .838 r
.65076 .35073 m .65195 .35462 L .65445 .35119 L F
.972 .75 .545 r
.34366 .60731 m .34502 .61105 L .3429 .60897 L F
.976 .706 .453 r
.34502 .61105 m .34466 .61327 L .3429 .60897 L F
.739 .819 .914 r
.34704 .60829 m .34502 .61105 L .3429 .60897 L F
.591 .596 .826 r
.34704 .60829 m .34977 .61097 L .34502 .61105 L F
.404 .139 .394 r
.34704 .61267 m .34502 .61105 L .34977 .61097 L F
.34704 .61267 m .34466 .61327 L .34502 .61105 L F
.176 0 0 r
.33705 .51076 m .33538 .51074 L .33941 .51105 L F
.233 .151 .554 r
.36465 .5868 m .36279 .58519 L .36458 .58442 L F
.426 .217 .49 r
.30764 .60741 m .30947 .60956 L .31021 .60667 L F
.30764 .60741 m .30725 .6104 L .30947 .60956 L F
.075 .344 .818 r
.35195 .70944 m .35415 .71306 L .35489 .71173 L F
.268 .596 .95 r
.35415 .71306 m .35757 .7142 L .35489 .71173 L F
.714 .901 .53 r
.40318 .49563 m .40192 .49705 L .40387 .49414 L F
.424 .692 .975 r
.5708 .41267 m .56754 .41154 L .57134 .41199 L F
.765 .79 .874 r
.57134 .41199 m .57607 .40974 L .57479 .40995 L F
.204 0 .126 r
.57134 .41199 m .57479 .40995 L .57439 .41142 L F
.114 0 0 r
.5708 .41267 m .57134 .41199 L .57439 .41142 L F
.073 0 0 r
.57971 .41648 m .5754 .41798 L .57866 .41537 L F
.771 .684 .767 r
.64471 .39894 m .64739 .39566 L .64482 .39658 L F
.622 .736 .928 r
.35298 .51021 m .35662 .51124 L .35498 .50996 L F
.972 .82 .633 r
.35662 .51124 m .35615 .51494 L .35498 .50996 L F
.489 .723 .975 r
.35318 .72466 m .3569 .72587 L .35544 .72477 L F
.35318 .72466 m .3569 .72587 L .35544 .72477 L F
.572 .444 .667 r
.45441 .49128 m .45278 .49537 L .45247 .49214 L F
.767 .704 .793 r
.35996 .59127 m .36459 .59162 L .3633 .58842 L F
.332 .548 .911 r
.35996 .59127 m .36413 .59427 L .36459 .59162 L F
.482 .269 .512 r
.36459 .59162 m .36413 .59427 L .36663 .59361 L F
.36459 .59162 m .36413 .59427 L .36663 .59361 L F
.262 .094 .455 r
.31531 .5968 m .31739 .59397 L .31549 .59506 L F
.028 0 0 r
.29494 .65589 m .29816 .65499 L .29698 .65562 L F
0 0 0 r
.29698 .65562 m .29816 .65499 L .29971 .65454 L F
.73 .329 .29 r
.54823 .46347 m .55243 .46406 L .55248 .46571 L F
.656 .213 .186 r
.55243 .46406 m .55647 .46581 L .55248 .46571 L F
.597 .905 .983 r
.43073 .59113 m .42644 .59168 L .42943 .59243 L F
0 0 0 r
.43073 .59113 m .43136 .58789 L .43094 .58783 L F
.43073 .59113 m .43187 .59099 L .43136 .58789 L F
.43073 .59113 m .43381 .59072 L .43187 .59099 L F
.43187 .59099 m .43073 .59113 L .42943 .59243 L F
.43187 .59099 m .43381 .59072 L .43073 .59113 L F
.679 .386 0 r
.41578 .58823 m .41548 .58725 L .41467 .58458 L F
.998 .82 .473 r
.41578 .58823 m .41433 .58988 L .41548 .58725 L F
.41578 .58823 m .41525 .59098 L .41433 .58988 L F
.989 .85 .483 r
.40264 .58535 m .40308 .591 L .40374 .58841 L F
.719 .729 .859 r
.43981 .46872 m .44103 .47069 L .43721 .46987 L F
.585 .622 .856 r
.44224 .46783 m .44103 .47069 L .43981 .46872 L F
.44224 .46783 m .44366 .46993 L .44103 .47069 L F
.743 .279 .146 r
.35405 .51483 m .35616 .51734 L .35783 .51665 L F
.146 .417 .86 r
.35783 .51665 m .3595 .51613 L .35615 .51494 L F
.872 .716 .685 r
.35826 .5191 m .35783 .51665 L .35616 .51734 L F
.35826 .5191 m .3595 .51613 L .35783 .51665 L F
.557 .507 .755 r
.45206 .51064 m .45012 .51591 L .44985 .51124 L F
.45206 .51064 m .45528 .51654 L .45012 .51591 L F
.333 0 .092 r
.45528 .51654 m .45082 .51785 L .45012 .51591 L F
0 .13 .678 r
.29225 .63827 m .29365 .64122 L .29242 .63982 L F
.701 .635 .78 r
.29365 .64122 m .2914 .64234 L .29242 .63982 L F
.78 .766 .256 r
.40291 .67521 m .4018 .67997 L .40246 .6779 L F
.821 .546 .523 r
.70915 .31495 m .71264 .31336 L .70903 .31232 L F
.70915 .31495 m .71238 .31574 L .71264 .31336 L F
.99 .742 .452 r
.71264 .31336 m .71238 .31574 L .71304 .31595 L F
.668 .658 .831 r
.25744 .54686 m .26212 .54814 L .26119 .54773 L F
.657 .755 .922 r
.61303 .35787 m .60977 .3598 L .60859 .35717 L F
.716 .273 .197 r
.24454 .56186 m .2428 .56262 L .24086 .56143 L F
.826 .542 .508 r
.42528 .52365 m .42785 .5212 L .42738 .52063 L F
.42579 .52317 m .42932 .52401 L .42785 .5212 L F
.42598 .52371 m .42932 .52401 L .42579 .52317 L F
.744 .501 .564 r
.42634 .52487 m .42932 .52401 L .42528 .52365 L F
.42634 .52487 m .4286 .52708 L .42932 .52401 L F
.206 0 0 r
.42558 .52658 m .4286 .52708 L .42634 .52487 L F
.303 0 0 r
.42583 .52707 m .42461 .5288 L .42454 .52679 L F
.206 0 0 r
.42461 .5288 m .42633 .52806 L .42583 .52707 L F
.42461 .5288 m .42753 .52826 L .4286 .52708 L F
.303 0 0 r
.42804 .52754 m .42461 .5288 L .42583 .52707 L F
.206 0 0 r
.42461 .5288 m .42583 .52707 L .42558 .52658 L F
.42633 .52806 m .4286 .52708 L .42558 .52658 L F
.576 .414 .626 r
.42639 .52484 m .4273 .52738 L .42583 .52707 L F
.42558 .52658 m .42583 .52707 L .42454 .52679 L F
.488 .182 .372 r
.42454 .52679 m .42461 .5288 L .42558 .52658 L F
.42454 .52679 m .42558 .52658 L .42634 .52487 L F
.576 .414 .626 r
.42529 .526 m .42558 .52658 L .42454 .52679 L F
.42639 .52484 m .42583 .52707 L .42529 .526 L F
.42855 .52255 m .42804 .52754 L .4273 .52738 L F
.42855 .52255 m .4273 .52738 L .42639 .52484 L F
.826 .542 .508 r
.42528 .52365 m .42598 .52371 L .42579 .52317 L F
.275 .337 .746 r
.42785 .5212 m .42991 .51967 L .42738 .52063 L F
.497 .328 .581 r
.32598 .60106 m .32608 .60382 L .32374 .60438 L F
.435 .307 .606 r
.32605 .60654 m .32374 .60438 L .32608 .60382 L F
.32605 .60654 m .32375 .60738 L .32374 .60438 L F
.586 .929 .955 r
.41293 .48215 m .41709 .48129 L .41411 .48299 L F
.565 .923 .949 r
.57607 .40974 m .57601 .40935 L .57479 .40995 L F
0 0 .332 r
.61284 .44103 m .61383 .44306 L .61431 .44417 L F
.955 .819 .381 r
.61336 .44556 m .61431 .44417 L .61383 .44306 L F
.61336 .44556 m .61389 .44664 L .61431 .44417 L F
.614 .66 .872 r
.35815 .53934 m .35703 .54358 L .35626 .5395 L F
.35815 .53934 m .35966 .54349 L .35703 .54358 L F
.157 .416 .857 r
.38498 .67149 m .38582 .67005 L .3841 .67285 L F
.38498 .67149 m .38792 .67332 L .38582 .67005 L F
.365 .546 .899 r
.61805 .44083 m .61741 .43721 L .61697 .43867 L F
.61805 .44083 m .61928 .43871 L .61741 .43721 L F
.61805 .44083 m .62019 .44069 L .61928 .43871 L F
.043 .566 .867 r
.33916 .4953 m .34139 .49567 L .3433 .49657 L F
.375 0 0 r
.34139 .49567 m .34622 .49649 L .3433 .49657 L F
.063 .507 .895 r
.59711 .3988 m .59837 .40006 L .60181 .40107 L F
.524 .904 .952 r
.35021 .51541 m .35296 .51435 L .35405 .51483 L F
.644 .3 .374 r
.35615 .51494 m .35616 .51734 L .35405 .51483 L F
.414 .221 .507 r
.43165 .54991 m .43422 .54937 L .43392 .54653 L F
.867 .882 .845 r
.43155 .55179 m .43206 .55333 L .43348 .5511 L F
.43015 .55229 m .43058 .55252 L .43155 .55179 L F
.43058 .55252 m .43206 .55333 L .43155 .55179 L F
.387 0 .041 r
.43165 .54991 m .43226 .55126 L .43422 .54937 L F
.867 .882 .845 r
.43015 .55229 m .43258 .55142 L .43249 .55176 L F
.43258 .55142 m .43348 .5511 L .43249 .55176 L F
0 0 0 r
.43314 .55102 m .43231 .55239 L .43249 .55176 L F
.43231 .55239 m .43184 .55317 L .43249 .55176 L F
.387 0 .041 r
.43226 .55126 m .43249 .55176 L .43356 .55028 L F
.43226 .55126 m .43356 .55028 L .43422 .54937 L F
.43165 .54991 m .43015 .55229 L .43249 .55176 L F
.546 .663 .913 r
.34571 .70746 m .34743 .70461 L .3449 .70549 L F
.34571 .70746 m .34877 .70723 L .34743 .70461 L F
.637 .709 .899 r
.34571 .70746 m .3493 .70756 L .34877 .70723 L F
.642 .712 .898 r
.33591 .55863 m .33758 .56053 L .33372 .55965 L F
.513 .356 .605 r
.34019 .55974 m .33758 .56053 L .33591 .55863 L F
.34019 .55974 m .33999 .56196 L .33758 .56053 L F
0 0 .479 r
.61686 .43452 m .61697 .43867 L .61741 .43721 L F
.74 .762 .871 r
.38407 .7001 m .3881 .70037 L .38627 .69922 L F
.896 .891 .469 r
.3881 .70037 m .38892 .69633 L .38627 .69922 L F
.731 .54 .633 r
.71239 .32869 m .71099 .33231 L .70667 .33189 L F
.73 .927 .956 r
.41032 .4982 m .41125 .49555 L .4132 .49552 L F
.312 .301 .686 r
.4132 .49552 m .41438 .49116 L .41157 .49199 L F
.4132 .49552 m .41553 .49498 L .41438 .49116 L F
.265 0 0 r
.41125 .49555 m .41553 .49498 L .4132 .49552 L F
.623 .914 .98 r
.54997 .40951 m .54722 .41093 L .5471 .4097 L F
0 0 .39 r
.40041 .55423 m .39941 .55292 L .39765 .55172 L F
.669 .973 .894 r
.24009 .55207 m .23933 .55368 L .24163 .55289 L F
.775 .689 .769 r
.2767 .53034 m .27416 .53344 L .27829 .53397 L F
0 .041 .61 r
.39189 .53557 m .39221 .53723 L .39068 .53362 L F
.562 .063 0 r
.39215 .53736 m .39221 .53723 L .39189 .53557 L F
.39215 .53736 m .3942 .53943 L .39221 .53723 L F
.333 .812 .883 r
.2549 .56849 m .25726 .56791 L .25881 .56804 L F
.797 .713 .771 r
.62242 .38732 m .62385 .39056 L .6203 .39017 L F
.251 .405 .822 r
.62486 .38851 m .62385 .39056 L .62242 .38732 L F
.63 .12 .015 r
.6203 .39017 m .62385 .39056 L .62241 .39165 L F
.747 .949 .632 r
.62241 .39165 m .62385 .39056 L .62486 .38851 L F
0 0 .322 r
.32642 .55218 m .32695 .55158 L .32656 .54872 L F
0 .325 .807 r
.32642 .55218 m .3282 .55331 L .32695 .55158 L F
.408 .104 .335 r
.33833 .67933 m .33639 .67776 L .336 .68059 L F
.33833 .67933 m .33883 .67719 L .33639 .67776 L F
0 0 0 r
.44507 .56279 m .44166 .56594 L .44376 .56534 L F
.704 .289 .256 r
.44775 .56493 m .44507 .56279 L .44376 .56534 L F
.994 .858 .593 r
.40101 .57403 m .40316 .57226 L .40204 .57113 L F
.40101 .57403 m .40208 .5754 L .40316 .57226 L F
.715 .978 .915 r
.30667 .6342 m .30295 .63588 L .30554 .63277 L F
.508 0 0 r
.30711 .63491 m .30667 .6342 L .30554 .63277 L F
.30711 .63491 m .30946 .63581 L .30667 .6342 L F
.358 .422 .791 r
.47019 .56428 m .46881 .56734 L .46706 .56256 L F
.365 .43 .796 r
.47019 .56428 m .47129 .56809 L .46881 .56734 L F
0 0 .203 r
.2165 .5996 m .21662 .60186 L .21632 .60112 L F
.046 0 .127 r
.45269 .59043 m .45094 .59175 L .45354 .58851 L F
.212 0 .217 r
.45481 .58948 m .45354 .58851 L .45566 .58752 L F
.45481 .58948 m .45269 .59043 L .45354 .58851 L F
.784 .997 .798 r
.66335 .37943 m .66185 .38121 L .6601 .38175 L F
.844 .488 0 r
.3858 .5125 m .38639 .51454 L .38474 .51069 L F
.182 0 0 r
.23948 .59948 m .24022 .60026 L .23654 .60238 L F
0 .346 .72 r
.59522 .38635 m .59596 .38685 L .59309 .38542 L F
.711 .902 .964 r
.59797 .38554 m .59596 .38685 L .59684 .38446 L F
.823 1 .826 r
.59684 .38446 m .59596 .38685 L .59522 .38635 L F
.571 .765 .97 r
.33172 .51993 m .32901 .52131 L .32751 .51841 L F
.33172 .51993 m .3317 .52098 L .32901 .52131 L F
.593 .408 .6 r
.3317 .52098 m .32932 .52396 L .32901 .52131 L F
.833 .682 .696 r
.33749 .54371 m .33707 .54696 L .33331 .54594 L F
.485 .363 .639 r
.33976 .54591 m .33707 .54696 L .33749 .54371 L F
.74 .758 .25 r
.32272 .52447 m .32266 .52406 L .32383 .52008 L F
.578 .027 0 r
.32272 .52447 m .32732 .52842 L .3256 .52719 L F
.32278 .52474 m .3256 .52719 L .32291 .52526 L F
.32272 .52447 m .3256 .52719 L .32278 .52474 L F
.525 .371 .614 r
.32669 .52692 m .32757 .52864 L .3273 .52866 L F
.32606 .52758 m .3273 .52866 L .32478 .52892 L F
.576 .392 .595 r
.32553 .5243 m .32732 .52842 L .32272 .52447 L F
.581 .707 .929 r
.32291 .52526 m .32732 .52842 L .32669 .52692 L F
.525 .371 .614 r
.32669 .52692 m .3273 .52866 L .32606 .52758 L F
.578 .027 0 r
.32272 .52447 m .32291 .52526 L .32266 .52406 L F
.622 .444 .621 r
.33731 .57578 m .33758 .57877 L .33494 .57934 L F
.703 .976 .915 r
.33808 .56388 m .33575 .56413 L .33587 .56553 L F
0 0 .536 r
.33575 .56413 m .33764 .56817 L .33587 .56553 L F
.829 .987 .872 r
.33861 .50801 m .33867 .50718 L .3413 .50633 L F
.33867 .50718 m .3402 .50608 L .3413 .50633 L F
.33877 .50577 m .33899 .50574 L .3413 .50633 L F
.349 .792 .959 r
.3413 .50633 m .34023 .50606 L .34082 .50582 L F
.34023 .50606 m .34072 .50581 L .34082 .50582 L F
.829 .987 .872 r
.33867 .50718 m .33877 .50577 L .3402 .50608 L F
.33861 .50801 m .33604 .5083 L .33878 .50569 L F
.719 .63 .758 r
.33878 .50569 m .33867 .5058 L .33546 .50562 L F
.33867 .5058 m .33604 .5083 L .33546 .50564 L F
.33867 .5058 m .33546 .50564 L .33546 .50562 L F
.453 0 0 r
.33737 .50654 m .33975 .50726 L .3407 .50589 L F
.349 .792 .959 r
.34023 .50606 m .33899 .50574 L .34072 .50581 L F
.453 0 0 r
.34033 .50588 m .3407 .50589 L .34079 .50577 L F
.33737 .50654 m .3407 .50589 L .34033 .50588 L F
.34015 .50576 m .34079 .50577 L .34095 .50554 L F
.33737 .50654 m .34079 .50577 L .34015 .50576 L F
.349 .792 .959 r
.33899 .50574 m .33878 .50569 L .33992 .50576 L F
.33899 .50574 m .33992 .50576 L .34072 .50581 L F
.066 .603 .857 r
.34506 .50391 m .34314 .50336 L .33914 .50309 L F
.743 .541 .62 r
.34042 .50394 m .33972 .50468 L .33899 .50285 L F
.33972 .50468 m .33878 .50569 L .33887 .50446 L F
.33972 .50468 m .33887 .50446 L .33899 .50285 L F
.34002 .5054 m .33878 .50569 L .34042 .50394 L F
.34277 .50574 m .34099 .50438 L .34314 .50336 L F
.34099 .50438 m .33899 .50285 L .34077 .50307 L F
.34099 .50438 m .34077 .50307 L .34314 .50336 L F
.296 .692 .975 r
.34018 .5048 m .34104 .50542 L .34109 .50503 L F
.973 .814 .624 r
.34006 .50525 m .34104 .50542 L .34018 .5048 L F
.743 .541 .62 r
.34178 .50498 m .34002 .5054 L .34042 .50394 L F
.453 0 0 r
.34047 .50559 m .34095 .50554 L .34104 .50542 L F
.33992 .50576 m .34104 .50542 L .33878 .50569 L F
.743 .541 .62 r
.3409 .50572 m .33878 .50569 L .34111 .50514 L F
.34116 .5055 m .34111 .50514 L .34178 .50498 L F
0 0 0 r
.34104 .50542 m .34116 .5055 L .34109 .50503 L F
.34108 .50545 m .34087 .50573 L .3409 .50572 L F
.34108 .50545 m .3409 .50572 L .34116 .5055 L F
.34104 .50542 m .34095 .50554 L .34108 .50545 L F
.743 .541 .62 r
.3409 .50572 m .34111 .50514 L .34116 .5055 L F
0 0 0 r
.34109 .50503 m .34119 .50552 L .3411 .50498 L F
.34116 .5055 m .34119 .50552 L .34109 .50503 L F
.3411 .50498 m .34167 .50583 L .34134 .50327 L F
.743 .541 .62 r
.34277 .50574 m .3409 .50572 L .34178 .50498 L F
0 0 0 r
.34119 .50552 m .34167 .50583 L .3411 .50498 L F
.721 .611 .733 r
.33878 .50569 m .33657 .50229 L .33899 .50285 L F
.296 .692 .975 r
.33815 .50332 m .34018 .5048 L .34134 .50327 L F
.34018 .5048 m .34109 .50503 L .34134 .50327 L F
.721 .611 .733 r
.33878 .50569 m .33546 .50562 L .33657 .50229 L F
.973 .814 .624 r
.33797 .5049 m .34006 .50525 L .33815 .50332 L F
.34006 .50525 m .34018 .5048 L .33815 .50332 L F
0 0 0 r
.34116 .5055 m .3409 .50572 L .34123 .50555 L F
.34123 .50555 m .33975 .50726 L .34167 .50583 L F
.34087 .50573 m .33975 .50726 L .34123 .50555 L F
.34095 .50554 m .33975 .50726 L .34108 .50545 L F
.829 .987 .872 r
.33877 .50577 m .33878 .50569 L .33899 .50574 L F
.453 0 0 r
.34015 .50576 m .34095 .50554 L .33992 .50576 L F
.349 .792 .959 r
.34078 .50577 m .33878 .50569 L .34072 .50571 L F
.34082 .50582 m .33992 .50576 L .34078 .50577 L F
.33992 .50576 m .33878 .50569 L .34078 .50577 L F
.453 0 0 r
.33992 .50576 m .34095 .50554 L .34047 .50559 L F
.33737 .50654 m .34015 .50576 L .33992 .50576 L F
.33737 .50654 m .33992 .50576 L .33878 .50569 L F
.959 .856 .442 r
.3413 .50633 m .34177 .50682 L .34216 .50525 L F
.349 .792 .959 r
.3413 .50633 m .34072 .50571 L .34277 .50574 L F
.959 .856 .442 r
.3413 .50633 m .34147 .50799 L .34177 .50682 L F
0 0 .454 r
.33914 .50309 m .33899 .50285 L .33723 .50068 L F
0 0 .158 r
.36934 .67783 m .36685 .68139 L .36873 .68042 L F
0 0 .175 r
.36873 .68042 m .36685 .68139 L .36635 .6835 L F
.555 .591 .844 r
.46501 .55467 m .46307 .55731 L .46234 .55528 L F
.498 .511 .801 r
.46501 .55467 m .46626 .55822 L .46307 .55731 L F
.606 .91 .641 r
.29164 .65894 m .29494 .65589 L .29432 .65801 L F
.028 0 0 r
.29494 .65589 m .29698 .65562 L .29432 .65801 L F
.809 .549 0 r
.62731 .42674 m .62744 .4268 L .62773 .42978 L F
0 0 .155 r
.62744 .4268 m .62974 .4239 L .62965 .4271 L F
.179 0 .289 r
.62773 .42978 m .62744 .4268 L .62965 .4271 L F
.272 0 .09 r
.45094 .59175 m .44983 .59407 L .44745 .59385 L F
.107 0 .017 r
.452 .59304 m .45094 .59175 L .45269 .59043 L F
.452 .59304 m .44983 .59407 L .45094 .59175 L F
.864 .667 .634 r
.378 .62345 m .37942 .62649 L .37745 .62626 L F
.884 .618 .099 r
.37942 .62649 m .37931 .62896 L .37745 .62626 L F
.37942 .62649 m .38001 .63023 L .37931 .62896 L F
0 0 .53 r
.61686 .43452 m .61688 .43309 L .61528 .43058 L F
0 .054 .604 r
.61741 .43721 m .61688 .43309 L .61686 .43452 L F
0 0 0 r
.38246 .65898 m .37887 .66166 L .38052 .66063 L F
.38375 .6583 m .38246 .65898 L .38052 .66063 L F
.681 .186 .062 r
.30502 .51049 m .30353 .50887 L .30081 .50945 L F
.747 .755 .859 r
.65711 .34798 m .66095 .34861 L .66003 .34691 L F
.68 .66 .823 r
.66095 .34861 m .66224 .34388 L .66003 .34691 L F
.66095 .34861 m .66333 .34723 L .66224 .34388 L F
.678 .978 .873 r
.37439 .60599 m .37659 .60429 L .3769 .60608 L F
.302 .629 .962 r
.37196 .6036 m .37439 .60599 L .3769 .60608 L F
.904 .611 .48 r
.73288 .33509 m .73277 .33658 L .73036 .33443 L F
.564 .46 .694 r
.7136 .36112 m .71482 .35775 L .71226 .35717 L F
.7136 .36112 m .71623 .36048 L .71482 .35775 L F
.271 .025 .345 r
.34588 .60643 m .34453 .60509 L .34634 .60364 L F
.34588 .60643 m .34366 .60731 L .34453 .60509 L F
0 0 .226 r
.40062 .562 m .40148 .56485 L .40167 .56592 L F
0 0 .338 r
.40148 .56485 m .40153 .56858 L .40167 .56592 L F
0 .171 .7 r
.62901 .41982 m .62804 .41936 L .62596 .41515 L F
.559 .825 .995 r
.38453 .66091 m .38623 .6621 L .3886 .66135 L F
.38453 .66091 m .38623 .6621 L .3886 .66135 L F
.859 .805 .796 r
.36307 .52564 m .36425 .52306 L .36519 .52341 L F
.64 .478 .648 r
.31808 .54694 m .31625 .55188 L .31953 .55043 L F
.31924 .54941 m .31953 .55043 L .31969 .55036 L F
.31808 .54694 m .31953 .55043 L .31924 .54941 L F
.31808 .54694 m .31916 .54923 L .31848 .54829 L F
.31916 .54923 m .31924 .54941 L .31848 .54829 L F
.592 .27 .393 r
.31808 .54694 m .31848 .54829 L .31862 .54593 L F
.966 .644 .342 r
.3184 .54635 m .31848 .54829 L .31809 .54695 L F
.31809 .54695 m .31848 .54829 L .31785 .54739 L F
.31862 .54593 m .31856 .54693 L .3184 .54635 L F
.31856 .54693 m .31848 .54829 L .3184 .54635 L F
.31785 .54739 m .31848 .54829 L .31782 .54745 L F
0 0 0 r
.31734 .54642 m .31862 .54593 L .31945 .54437 L F
.592 .27 .393 r
.31808 .54694 m .31862 .54593 L .31734 .54642 L F
.966 .644 .342 r
.31862 .54593 m .31782 .54745 L .31668 .54597 L F
.669 .726 .892 r
.3168 .546 m .31848 .54829 L .32075 .54714 L F
.31668 .54597 m .31848 .54829 L .3168 .546 L F
.64 .478 .648 r
.31924 .54941 m .31969 .55036 L .31848 .54829 L F
0 0 0 r
.31945 .54437 m .31862 .54593 L .32016 .54368 L F
.703 .32 .321 r
.32016 .54368 m .31862 .54593 L .32193 .54615 L F
.389 0 0 r
.43728 .59904 m .43488 .59808 L .43881 .59714 L F
.516 .072 .135 r
.44141 .59716 m .43728 .59904 L .43881 .59714 L F
.66 .551 .72 r
.4508 .5016 m .4516 .50471 L .44819 .50465 L F
.792 .878 .91 r
.43461 .4709 m .43028 .47225 L .43318 .46944 L F
.673 .803 .945 r
.43721 .46987 m .43461 .4709 L .43318 .46944 L F
.435 .183 .431 r
.27193 .56525 m .27407 .56507 L .27452 .56267 L F
.479 .234 .464 r
.27407 .56507 m .27693 .5621 L .27452 .56267 L F
.821 .431 .315 r
.35698 .53114 m .36112 .53367 L .3604 .5295 L F
0 0 .189 r
.36112 .53367 m .36181 .52895 L .3604 .5295 L F
.847 .877 .863 r
.64943 .33958 m .64534 .34104 L .6481 .33817 L F
.866 .911 .859 r
.65219 .33639 m .64943 .33958 L .64978 .33639 L F
.846 .895 .873 r
.64978 .33639 m .64943 .33958 L .6481 .33817 L F
.998 .843 .517 r
.64379 .42208 m .64381 .4245 L .64248 .42294 L F
.929 .944 .784 r
.64248 .42294 m .64381 .4245 L .64109 .42782 L F
.44 .137 .353 r
.32655 .68602 m .32755 .68442 L .32486 .68667 L F
.27 0 .239 r
.32823 .68596 m .32755 .68442 L .32655 .68602 L F
.466 .045 .156 r
.32823 .68596 m .33049 .68454 L .32755 .68442 L F
0 0 .448 r
.23566 .59471 m .23513 .5941 L .23363 .59165 L F
.536 .895 .974 r
.26493 .51925 m .26534 .51768 L .26765 .51877 L F
.26493 .51925 m .26239 .5187 L .26534 .51768 L F
.439 .415 .735 r
.32812 .56839 m .32929 .5633 L .32868 .56595 L F
.985 .902 .633 r
.71136 .31771 m .71304 .31595 L .71238 .31574 L F
.654 .271 .306 r
.39061 .49851 m .38637 .50049 L .38889 .49711 L F
.39061 .49851 m .38904 .50053 L .38637 .50049 L F
.548 .783 .986 r
.39193 .49699 m .39061 .49851 L .38889 .49711 L F
.709 .588 .718 r
.39193 .49699 m .38904 .50053 L .39061 .49851 L F
.225 0 0 r
.30276 .64821 m .30606 .64634 L .30452 .64586 L F
.533 .388 .631 r
.45278 .49537 m .45306 .49828 L .4505 .4989 L F
.552 .424 .66 r
.45306 .49828 m .4508 .5016 L .4505 .4989 L F
.569 .606 .85 r
.34049 .51315 m .34186 .51054 L .33941 .51105 L F
.34049 .51315 m .34356 .51297 L .34186 .51054 L F
.588 .315 .47 r
.32375 .60738 m .32328 .60977 L .32113 .60776 L F
.32375 .60738 m .32328 .60977 L .32113 .60776 L F
.531 .707 .951 r
.26023 .61413 m .26202 .61666 L .25974 .61715 L F
.719 .198 0 r
.38293 .50764 m .378 .50352 L .37946 .50481 L F
.354 0 0 r
.26826 .56621 m .27014 .56689 L .27193 .56525 L F
.481 .055 .154 r
.27014 .56689 m .27407 .56507 L .27193 .56525 L F
.792 .871 .907 r
.65119 .41462 m .65557 .41326 L .65405 .4116 L F
.787 .795 .859 r
.65557 .41326 m .65756 .41174 L .65405 .4116 L F
0 0 .508 r
.60297 .40237 m .60404 .40334 L .60181 .40107 L F
0 .061 .561 r
.60297 .40237 m .6067 .40592 L .60505 .40504 L F
0 0 .508 r
.60297 .40237 m .60505 .40504 L .60404 .40334 L F
.698 .654 .802 r
.70214 .29391 m .70645 .29467 L .70512 .29264 L F
.759 .994 .81 r
.70374 .29628 m .70645 .29467 L .70214 .29391 L F
.70374 .29628 m .70513 .29574 L .70645 .29467 L F
.789 .807 .867 r
.70645 .29467 m .70725 .29146 L .70512 .29264 L F
.70645 .29467 m .70832 .29318 L .70725 .29146 L F
0 0 0 r
.70513 .29574 m .70832 .29318 L .70645 .29467 L F
.594 .809 .982 r
.28205 .5226 m .286 .52284 L .28477 .52125 L F
.859 .857 .837 r
.28477 .52125 m .286 .52284 L .28746 .51999 L F
0 0 0 r
.34585 .54278 m .3484 .53932 L .3461 .54034 L F
.414 .105 .33 r
.46211 .58163 m .46121 .58453 L .45872 .58503 L F
.372 .015 .223 r
.46476 .58129 m .46121 .58453 L .46211 .58163 L F
.926 .552 .279 r
.41736 .59612 m .41803 .59811 L .4178 .59726 L F
.83 .382 0 r
.41535 .59405 m .41736 .59612 L .4178 .59726 L F
.601 .117 .077 r
.2995 .55604 m .30248 .55772 L .30341 .55637 L F
.51 0 0 r
.30248 .55772 m .30619 .5563 L .30341 .55637 L F
.711 .359 .379 r
.4314 .50202 m .42735 .50422 L .42942 .50126 L F
.4314 .50202 m .42899 .50439 L .42735 .50422 L F
.539 .866 .994 r
.4314 .50202 m .43223 .50056 L .42942 .50126 L F
.4314 .50202 m .43223 .50056 L .42942 .50126 L F
.521 .245 .436 r
.41032 .4982 m .40812 .49469 L .40847 .49726 L F
.73 .927 .956 r
.41032 .4982 m .40847 .49726 L .41125 .49555 L F
.76 .269 0 r
.35526 .67973 m .35524 .67862 L .35455 .67686 L F
.35526 .67973 m .35652 .68048 L .35524 .67862 L F
.826 .858 .405 r
.33652 .69573 m .33485 .699 L .33302 .69716 L F
.33652 .69573 m .33573 .69795 L .33485 .699 L F
.675 .731 .892 r
.33988 .6947 m .33652 .69573 L .33493 .6933 L F
0 0 .149 r
.22403 .54618 m .22492 .54259 L .22444 .54358 L F
.968 .819 .643 r
.35498 .50996 m .35615 .51494 L .3545 .51281 L F
.644 .3 .374 r
.35615 .51494 m .35296 .51435 L .3545 .51281 L F
.443 .144 .362 r
.3595 .51613 m .35616 .51734 L .35615 .51494 L F
.419 .845 .696 r
.32574 .64733 m .32852 .64592 L .3282 .64822 L F
.038 .196 .699 r
.3295 .64446 m .32852 .64592 L .32763 .64272 L F
0 0 .011 r
.3282 .64822 m .32852 .64592 L .3295 .64446 L F
0 .177 .668 r
.71339 .32293 m .71232 .32263 L .71324 .32038 L F
.71339 .32293 m .71505 .32462 L .71232 .32263 L F
.858 .956 .611 r
.68053 .30525 m .68073 .30616 L .67869 .30961 L F
.785 .997 .796 r
.68369 .30309 m .68073 .30616 L .68053 .30525 L F
.136 0 .155 r
.34798 .60017 m .34882 .59814 L .35087 .59706 L F
.663 .611 .787 r
.30946 .63581 m .31071 .63938 L .30854 .64025 L F
.696 .491 .606 r
.31624 .61703 m .31623 .61983 L .31362 .61982 L F
.553 .374 .593 r
.31913 .61655 m .31623 .61983 L .31624 .61703 L F
.136 .014 .436 r
.3798 .65194 m .37802 .65572 L .38081 .65524 L F
.537 .516 .78 r
.44743 .56006 m .44842 .55585 L .44631 .55629 L F
.44743 .56006 m .44958 .55969 L .44842 .55585 L F
.372 .247 .578 r
.25744 .54686 m .25792 .54997 L .25967 .54852 L F
.477 .49 .793 r
.43392 .54653 m .4358 .54332 L .43292 .54438 L F
.43392 .54653 m .43654 .54621 L .4358 .54332 L F
.673 .406 .509 r
.43392 .54653 m .43737 .54841 L .43654 .54621 L F
.43392 .54653 m .43422 .54937 L .43737 .54841 L F
.246 0 .24 r
.23842 .61506 m .23869 .61609 L .24016 .6148 L F
.783 .841 .896 r
.67319 .31603 m .66985 .31574 L .67199 .31428 L F
.832 .853 .862 r
.67617 .31291 m .67319 .31603 L .67199 .31428 L F
.535 .786 .99 r
.25254 .56907 m .25316 .56712 L .25103 .56751 L F
.25254 .56907 m .2549 .56849 L .25316 .56712 L F
.25316 .56712 m .25254 .56907 L .25103 .56751 L F
.25316 .56712 m .2549 .56849 L .25254 .56907 L F
.769 .687 .772 r
.36245 .69328 m .36073 .69727 L .35854 .69559 L F
0 0 .204 r
.71635 .3533 m .71621 .35214 L .71717 .35053 L F
.676 .617 .782 r
.72122 .35189 m .71635 .3533 L .71717 .35053 L F
.684 .582 .735 r
.44247 .55579 m .44631 .55629 L .4452 .55265 L F
.841 .663 .661 r
.64697 .42759 m .64566 .43141 L .64897 .43154 L F
.757 .814 .898 r
.64337 .41062 m .64478 .41235 L .64224 .41164 L F
.868 .657 .615 r
.64224 .41164 m .64478 .41235 L .64382 .41511 L F
.806 .823 .864 r
.64613 .40783 m .64478 .41235 L .64337 .41062 L F
.64613 .40783 m .64806 .40943 L .64478 .41235 L F
.395 .212 .512 r
.64697 .42759 m .64758 .42515 L .64633 .42638 L F
0 0 .099 r
.64758 .42515 m .64767 .42112 L .6472 .42408 L F
.945 .903 .517 r
.64633 .42638 m .64758 .42515 L .6472 .42408 L F
.358 .404 .773 r
.25677 .5721 m .25726 .56791 L .2549 .56849 L F
.25677 .5721 m .25853 .57237 L .25726 .56791 L F
.229 0 .316 r
.36635 .6835 m .36449 .68431 L .3639 .68625 L F
0 0 0 r
.29467 .5132 m .29388 .51287 L .29218 .51369 L F
.654 .606 .788 r
.36426 .53274 m .36216 .53709 L .36112 .53367 L F
.36426 .53274 m .36512 .53747 L .36216 .53709 L F
0 0 0 r
.36512 .53747 m .36043 .53928 L .36216 .53709 L F
.71966 .34259 m .72209 .34029 L .72122 .33974 L F
.408 .69 .977 r
.72209 .34029 m .72402 .33891 L .72122 .33974 L F
.72209 .34029 m .72558 .34058 L .72402 .33891 L F
0 .271 .766 r
.26074 .62733 m .26284 .62977 L .26262 .62863 L F
.611 .445 .632 r
.22205 .57116 m .21957 .57486 L .21972 .57212 L F
.989 .746 .368 r
.70959 .28912 m .71076 .29081 L .71032 .28762 L F
.868 .908 .857 r
.70832 .29318 m .71076 .29081 L .70959 .28912 L F
.992 .776 .399 r
.70969 .28659 m .71032 .28762 L .70989 .28412 L F
.989 .746 .368 r
.70959 .28912 m .71032 .28762 L .70969 .28659 L F
.757 .376 .332 r
.45002 .56758 m .45112 .56483 L .44775 .56493 L F
.049 0 0 r
.45443 .56269 m .45112 .56483 L .45301 .56475 L F
.064 0 .046 r
.45301 .56475 m .45112 .56483 L .45002 .56758 L F
.755 .492 .535 r
.74165 .3317 m .74401 .33208 L .74323 .32919 L F
.589 .912 .668 r
.33978 .60123 m .33648 .604 L .34 .60088 L F
.442 .222 .483 r
.33648 .604 m .33695 .6045 L .34 .60088 L F
.33695 .6045 m .3388 .60645 L .33996 .60111 L F
.33695 .6045 m .33996 .60111 L .34 .60088 L F
.439 .413 .734 r
.3388 .60645 m .33995 .60221 L .34 .60109 L F
0 0 0 r
.34246 .5982 m .33985 .60115 L .34018 .60085 L F
.33985 .60115 m .33988 .60114 L .34018 .60085 L F
.33985 .60115 m .33978 .60123 L .33988 .60114 L F
.34 .60088 m .34056 .6005 L .33978 .60123 L F
.439 .413 .734 r
.33996 .60111 m .34 .60109 L .34 .60088 L F
.3388 .60645 m .34 .60109 L .33996 .60111 L F
0 0 0 r
.34146 .59941 m .34018 .60085 L .34056 .6005 L F
.34246 .5982 m .34018 .60085 L .34146 .59941 L F
.77 .416 .384 r
.34724 .67385 m .34959 .67423 L .34821 .67117 L F
.944 .785 .654 r
.34959 .67423 m .35123 .67173 L .34821 .67117 L F
.703 .603 .741 r
.32887 .51063 m .32858 .51462 L .32648 .5115 L F
.139 .111 .561 r
.32887 .51063 m .32873 .51257 L .33095 .51013 L F
.32873 .51257 m .32858 .51462 L .32984 .51223 L F
.32873 .51257 m .32984 .51223 L .33095 .51013 L F
.763 .68 .771 r
.32471 .50748 m .32648 .5115 L .32228 .51084 L F
.734 .793 .899 r
.32714 .5105 m .32648 .5115 L .32887 .51063 L F
.595 .596 .823 r
.32877 .50806 m .32714 .5105 L .32471 .50748 L F
.32714 .5105 m .32648 .5115 L .32588 .51014 L F
.32714 .5105 m .32588 .51014 L .32471 .50748 L F
.734 .793 .899 r
.32509 .51035 m .32648 .5115 L .32714 .5105 L F
.566 .555 .801 r
.3275 .51135 m .32858 .51462 L .32662 .51171 L F
.734 .793 .899 r
.32714 .5105 m .32887 .51063 L .32853 .51091 L F
.566 .555 .801 r
.3291 .50811 m .32886 .51108 L .32723 .51053 L F
.32886 .51108 m .32858 .51462 L .32723 .51053 L F
.332 .344 .723 r
.33095 .51013 m .32935 .51317 L .32889 .51078 L F
.32935 .51317 m .32867 .51352 L .32889 .51078 L F
.751 .557 .633 r
.33095 .51013 m .33386 .51154 L .32683 .5123 L F
.95 .595 .263 r
.33228 .51163 m .33177 .51103 L .32911 .51179 L F
.33386 .51154 m .33289 .5113 L .33228 .51163 L F
.33289 .5113 m .33177 .51103 L .33228 .51163 L F
.332 .344 .723 r
.32935 .51317 m .32858 .51462 L .32867 .51352 L F
.751 .557 .633 r
.32983 .5104 m .32889 .51078 L .32887 .51063 L F
.33095 .51013 m .32848 .51095 L .32983 .5104 L F
.332 .344 .723 r
.33095 .51013 m .32889 .51078 L .3291 .50811 L F
.751 .557 .633 r
.32889 .51078 m .32848 .51095 L .32856 .51089 L F
.32889 .51078 m .32856 .51089 L .32887 .51063 L F
.33095 .51013 m .32683 .5123 L .32848 .51095 L F
.566 .555 .801 r
.32723 .51053 m .3275 .51135 L .32648 .5115 L F
.3275 .51135 m .32662 .51171 L .32648 .5115 L F
.666 .78 .934 r
.32228 .51084 m .32648 .5115 L .32509 .51035 L F
.734 .793 .899 r
.32509 .51035 m .32714 .5105 L .32683 .5123 L F
.32714 .5105 m .32853 .51091 L .32683 .5123 L F
.595 .596 .823 r
.3291 .50811 m .32648 .5115 L .32877 .50806 L F
.249 .761 .846 r
.32683 .5123 m .33114 .51183 L .32911 .51179 L F
.33153 .51179 m .33386 .51154 L .33184 .51165 L F
.979 .761 .345 r
.33365 .50943 m .33386 .51154 L .33095 .51013 L F
.95 .595 .263 r
.33386 .51154 m .3335 .51211 L .33177 .51103 L F
.979 .761 .345 r
.3337 .50997 m .3335 .51211 L .33386 .51154 L F
.33365 .50943 m .33362 .51001 L .3337 .50997 L F
.33362 .51001 m .3335 .51211 L .3337 .50997 L F
.84 .869 .865 r
.33861 .50801 m .33505 .50903 L .33604 .5083 L F
.33505 .50903 m .33365 .50943 L .33604 .5083 L F
.776 .698 .777 r
.33941 .51105 m .33538 .51074 L .33861 .50801 L F
.509 .346 .595 r
.33941 .51105 m .34186 .51054 L .34147 .50799 L F
.601 .062 0 r
.34186 .51054 m .33783 .50928 L .33941 .51105 L F
.84 .869 .865 r
.33861 .50801 m .33538 .51074 L .33365 .50943 L F
.798 .869 .901 r
.33783 .50928 m .33365 .50943 L .33604 .5083 L F
0 .062 .571 r
.33783 .50928 m .33883 .50987 L .33604 .5083 L F
.601 .062 0 r
.34186 .51054 m .33997 .51119 L .33783 .50928 L F
.237 .325 .751 r
.33604 .5083 m .33883 .50987 L .33763 .50713 L F
.33604 .5083 m .33763 .50713 L .33737 .50654 L F
.798 .869 .901 r
.33783 .50928 m .33538 .51074 L .33365 .50943 L F
.62 .635 .844 r
.33604 .5083 m .33365 .50943 L .33155 .50538 L F
.984 .732 .468 r
.33177 .51103 m .3335 .51211 L .33365 .50943 L F
.33177 .51103 m .33365 .50943 L .33604 .5083 L F
.62 .635 .844 r
.33604 .5083 m .33155 .50538 L .33546 .50562 L F
.984 .732 .468 r
.33258 .51047 m .33604 .5083 L .3364 .50786 L F
.33177 .51103 m .33278 .51038 L .33258 .51047 L F
.33278 .51038 m .33604 .5083 L .33258 .51047 L F
.151 .621 .927 r
.3335 .51211 m .33607 .51237 L .33261 .51129 L F
.33237 .5114 m .33261 .51129 L .33177 .51103 L F
.3335 .51211 m .33261 .51129 L .33237 .5114 L F
.249 .761 .846 r
.33114 .51183 m .33153 .51179 L .33172 .51165 L F
.33153 .51179 m .33184 .51165 L .33172 .51165 L F
.33114 .51183 m .33172 .51165 L .32911 .51179 L F
.572 .389 .595 r
.34175 .58445 m .33909 .58768 L .33931 .58506 L F
.895 .733 .672 r
.53138 .44117 m .53069 .44374 L .52797 .4436 L F
.734 .22 0 r
.28973 .65788 m .29164 .65894 L .29239 .66 L F
.405 .2 .485 r
.29239 .66 m .29164 .65894 L .29432 .65801 L F
.462 .499 .811 r
.40003 .68632 m .39663 .68384 L .39874 .68791 L F
.383 .227 .543 r
.23402 .58415 m .23204 .58185 L .2342 .58117 L F
.23402 .58415 m .232 .58511 L .23204 .58185 L F
0 .575 .72 r
.33848 .68344 m .34047 .68348 L .33357 .68331 L F
.76 .258 .017 r
.28887 .55558 m .29099 .55809 L .2939 .55842 L F
.288 .778 .9 r
.2939 .55842 m .29099 .55809 L .29502 .55788 L F
.736 .979 .916 r
.67542 .39152 m .67972 .38971 L .67898 .38914 L F
.733 .952 .948 r
.68087 .38738 m .67972 .38971 L .68185 .38811 L F
.773 .991 .885 r
.67898 .38914 m .67972 .38971 L .68087 .38738 L F
.767 .361 .283 r
.55889 .46621 m .563 .46716 L .56296 .46875 L F
0 .192 .7 r
.59052 .40408 m .5894 .40391 L .58815 .40235 L F
.59052 .40408 m .59043 .4047 L .5894 .40391 L F
.806 .99 .881 r
.70243 .32589 m .6988 .32775 L .70146 .32705 L F
.112 .018 .46 r
.70243 .32589 m .70467 .32442 L .70447 .3214 L F
0 0 0 r
.70243 .32589 m .70146 .32705 L .70467 .32442 L F
.743 .234 0 r
.4032 .53111 m .40275 .5316 L .40201 .52961 L F
.4032 .53111 m .4047 .53297 L .40275 .5316 L F
.069 0 .091 r
.30303 .54588 m .30015 .54893 L .3012 .54691 L F
.548 .783 .986 r
.39193 .49699 m .39171 .49487 L .39303 .49549 L F
.47 .806 .999 r
.39464 .49439 m .39303 .49549 L .39171 .49487 L F
.061 0 0 r
.39432 .49574 m .39303 .49549 L .39464 .49439 L F
.39432 .49574 m .39193 .49699 L .39303 .49549 L F
.165 0 0 r
.32366 .54123 m .32283 .54025 L .325 .53926 L F
.32366 .54123 m .32105 .54183 L .32283 .54025 L F
0 0 .284 r
.31155 .62175 m .31068 .6199 L .31362 .61982 L F
.31155 .62175 m .31012 .62255 L .31068 .6199 L F
0 0 .422 r
.69384 .36881 m .69277 .37366 L .69189 .37123 L F
.902 .771 .708 r
.32643 .58774 m .32461 .59007 L .32661 .5889 L F
.741 .418 .436 r
.32461 .59007 m .32625 .59042 L .3263 .59021 L F
.32602 .58924 m .3263 .59021 L .32661 .5889 L F
.32461 .59007 m .3263 .59021 L .32602 .58924 L F
.598 .188 .235 r
.32661 .5889 m .33003 .58889 L .32643 .58774 L F
.32775 .58889 m .32944 .59 L .33003 .58889 L F
.32661 .5889 m .32826 .58954 L .32775 .58889 L F
.32826 .58954 m .32944 .59 L .32775 .58889 L F
.491 .134 .287 r
.3263 .59021 m .32944 .59 L .32661 .5889 L F
.596 .45 .654 r
.32659 .59076 m .32652 .59101 L .32651 .59061 L F
.32652 .59101 m .32633 .59168 L .32636 .59044 L F
.749 .524 .59 r
.32636 .59044 m .32633 .59168 L .32552 .59093 L F
.32625 .59042 m .32552 .59093 L .32461 .59007 L F
.32636 .59044 m .32552 .59093 L .32625 .59042 L F
.826 .46 .361 r
.32633 .59168 m .32566 .59291 L .32461 .59007 L F
.596 .45 .654 r
.32646 .5912 m .32879 .59112 L .32633 .59168 L F
.32659 .59076 m .32812 .59101 L .32646 .5912 L F
.32812 .59101 m .32879 .59112 L .32646 .5912 L F
.491 .134 .287 r
.32812 .59101 m .32904 .59091 L .32944 .59 L F
.32659 .59076 m .32944 .59 L .3263 .59021 L F
.32712 .59178 m .32812 .59101 L .32659 .59076 L F
.32812 .59101 m .32944 .59 L .32659 .59076 L F
.615 .69 .897 r
.32643 .58774 m .33003 .58889 L .32777 .58659 L F
.288 0 .15 r
.33059 .5921 m .32822 .59282 L .32926 .59101 L F
.314 0 .204 r
.32974 .59055 m .32822 .59282 L .33059 .5921 L F
.32944 .59 m .32904 .59091 L .32974 .59055 L F
.596 .45 .654 r
.3292 .59083 m .32926 .59101 L .32877 .59105 L F
.314 0 .204 r
.32921 .59082 m .32944 .591 L .32974 .59055 L F
.3292 .59083 m .3293 .5909 L .32921 .59082 L F
.3293 .5909 m .32944 .591 L .32921 .59082 L F
.288 0 .15 r
.33059 .5921 m .32926 .59101 L .3293 .5909 L F
.585 .475 .695 r
.33003 .58889 m .33264 .58527 L .32858 .5846 L F
.33003 .58889 m .33276 .58813 L .33264 .58527 L F
.316 0 .085 r
.3316 .58952 m .33003 .58889 L .32944 .59 L F
.3316 .58952 m .33276 .58813 L .33003 .58889 L F
.314 0 .204 r
.32944 .59 m .33059 .5921 L .3316 .58952 L F
.288 0 .15 r
.33059 .5921 m .3293 .5909 L .33012 .58868 L F
0 .056 .587 r
.32931 .59088 m .3293 .5909 L .32915 .59067 L F
.3293 .5909 m .32926 .59101 L .3292 .59083 L F
.3293 .5909 m .3292 .59083 L .32915 .59067 L F
.483 .114 .261 r
.32566 .59291 m .32864 .59134 L .32633 .59168 L F
.32864 .59134 m .32926 .59101 L .32849 .59119 L F
.32864 .59134 m .32849 .59119 L .32633 .59168 L F
.32566 .59291 m .32822 .59282 L .32926 .59101 L F
.314 0 .204 r
.32904 .59091 m .32879 .59149 L .32944 .591 L F
.32879 .59149 m .32822 .59282 L .32898 .59169 L F
.32879 .59149 m .32898 .59169 L .32944 .591 L F
.32904 .59091 m .32944 .591 L .3292 .59083 L F
.596 .45 .654 r
.32877 .59105 m .32926 .59101 L .32879 .59112 L F
.32777 .58659 m .3292 .59083 L .32877 .59105 L F
.32777 .58659 m .32879 .59112 L .32659 .59076 L F
.491 .134 .287 r
.32566 .59291 m .32822 .59282 L .32904 .59091 L F
.32566 .59291 m .32904 .59091 L .32812 .59101 L F
.32566 .59291 m .32712 .59178 L .32659 .59076 L F
.32626 .59071 m .32659 .59076 L .32636 .59034 L F
.32566 .59291 m .32659 .59076 L .32626 .59071 L F
.32625 .59042 m .32636 .59034 L .3263 .59021 L F
.32566 .59291 m .32636 .59034 L .32625 .59042 L F
.596 .45 .654 r
.32777 .58659 m .32659 .59076 L .32643 .58774 L F
.32659 .59076 m .32651 .59061 L .32643 .58774 L F
.585 .475 .695 r
.33003 .58889 m .32858 .5846 L .32777 .58659 L F
0 .056 .587 r
.33012 .58868 m .32931 .59088 L .32777 .58659 L F
.32931 .59088 m .32915 .59067 L .32777 .58659 L F
.596 .45 .654 r
.32652 .59101 m .32636 .59044 L .32643 .58774 L F
.749 .524 .59 r
.32643 .58774 m .32636 .59044 L .32461 .59007 L F
.741 .418 .436 r
.32461 .59007 m .32566 .59291 L .32625 .59042 L F
.786 .897 .921 r
.38818 .55159 m .3835 .54859 L .38659 .5493 L F
.38818 .55159 m .3828 .55115 L .3835 .54859 L F
.38818 .55159 m .38442 .55225 L .3828 .55115 L F
.753 .846 .92 r
.38934 .54794 m .38818 .55159 L .38659 .5493 L F
.786 .998 .849 r
.42812 .47386 m .42558 .47639 L .42623 .47434 L F
.729 .965 .938 r
.42558 .47639 m .42433 .47587 L .42623 .47434 L F
.765 .441 0 r
.4061 .53685 m .40542 .5356 L .4047 .53297 L F
.689 .419 0 r
.4061 .53685 m .40635 .53787 L .40542 .5356 L F
.4061 .53685 m .40681 .53965 L .40635 .53787 L F
.726 .204 0 r
.60505 .40504 m .6067 .40592 L .60871 .40846 L F
.597 .663 .885 r
.36459 .71617 m .36539 .71225 L .36315 .71326 L F
.36459 .71617 m .36917 .71576 L .36539 .71225 L F
.801 .891 .909 r
.63722 .34817 m .63407 .34851 L .63595 .34676 L F
.79 .886 .914 r
.64034 .34556 m .63722 .34817 L .63595 .34676 L F
.561 .822 .995 r
.37044 .57829 m .3745 .57882 L .37383 .57756 L F
.672 .181 .076 r
.3745 .57882 m .37269 .58014 L .37383 .57756 L F
.3745 .57882 m .37707 .58082 L .37269 .58014 L F
.566 .865 .557 r
.39183 .68752 m .39432 .68497 L .39279 .68634 L F
.552 .823 .469 r
.39279 .68634 m .39026 .68933 L .39183 .68752 L F
.656 .969 .9 r
.46297 .46673 m .46441 .46481 L .46234 .46633 L F
.46297 .46673 m .46441 .46481 L .46234 .46633 L F
.375 .234 .559 r
.32817 .60307 m .32598 .60106 L .32816 .6003 L F
.32817 .60307 m .32608 .60382 L .32598 .60106 L F
0 0 0 r
.23447 .53316 m .23296 .53548 L .23597 .53302 L F
.219 .717 .913 r
.31901 .66572 m .31677 .66588 L .31534 .66534 L F
.107 0 0 r
.58937 .46393 m .58833 .46542 L .58574 .46617 L F
0 0 0 r
.59058 .46425 m .58937 .46393 L .59202 .46339 L F
.59058 .46425 m .58833 .46542 L .58937 .46393 L F
.505 .265 .484 r
.35966 .54349 m .36228 .54309 L .36279 .54018 L F
.455 .25 .512 r
.36279 .54018 m .36523 .5395 L .36512 .53747 L F
.465 .229 .472 r
.36279 .54018 m .36523 .5423 L .36523 .5395 L F
.36279 .54018 m .36228 .54309 L .36523 .5423 L F
.26 .716 .954 r
.3141 .6687 m .31517 .66785 L .31244 .66727 L F
.3141 .6687 m .31675 .66872 L .31517 .66785 L F
.744 .496 .556 r
.60859 .36965 m .6091 .37325 L .60531 .3731 L F
0 0 0 r
.60859 .36965 m .61122 .36847 L .61093 .3688 L F
.759 .7 .796 r
.61093 .3688 m .6091 .37325 L .60859 .36965 L F
.895 .919 .83 r
.62179 .37414 m .623 .37605 L .62236 .37281 L F
.563 .936 .889 r
.623 .37605 m .62454 .37433 L .62236 .37281 L F
.72 .828 .931 r
.29935 .64871 m .29732 .65022 L .29521 .6486 L F
.448 .36 .664 r
.45178 .50886 m .45206 .51064 L .44985 .51124 L F
.035 0 .132 r
.25136 .5388 m .2495 .54024 L .25206 .537 L F
.672 .868 .973 r
.2477 .53913 m .2495 .54024 L .25136 .5388 L F
.462 .499 .811 r
.40003 .68632 m .39932 .68328 L .39663 .68384 L F
.736 .818 .916 r
.2225 .60414 m .22406 .60513 L .22678 .60418 L F
.842 .381 0 r
.27896 .6366 m .28156 .6391 L .2802 .63885 L F
.822 .347 0 r
.2802 .63885 m .28156 .6391 L .28248 .64143 L F
.865 .417 .06 r
.33485 .699 m .33573 .69795 L .33681 .70026 L F
.044 0 .409 r
.21034 .58828 m .21151 .58996 L .211 .58727 L F
.21034 .58828 m .20994 .59157 L .21151 .58996 L F
0 0 0 r
.44983 .59407 m .44632 .59612 L .44745 .59385 L F
.006 .554 .83 r
.35181 .49852 m .35654 .49959 L .35349 .49946 L F
.238 0 0 r
.57999 .46658 m .58128 .46752 L .57869 .46809 L F
.57999 .46658 m .58274 .46643 L .58128 .46752 L F
0 .311 .796 r
.3493 .70756 m .35128 .70835 L .34877 .70723 L F
.3493 .70756 m .35195 .70944 L .35128 .70835 L F
.688 .469 .583 r
.63602 .43636 m .63985 .43782 L .63903 .43444 L F
.585 .603 .836 r
.63903 .43444 m .64125 .43073 L .63851 .43107 L F
.63903 .43444 m .64297 .43389 L .64125 .43073 L F
.558 .387 .606 r
.63903 .43444 m .63985 .43782 L .64297 .43389 L F
.326 .122 .443 r
.34652 .52719 m .34615 .5298 L .34411 .53039 L F
.673 .132 0 r
.34615 .5298 m .34213 .52787 L .34411 .53039 L F
.512 .873 .642 r
.34411 .53039 m .34449 .52981 L .34615 .5298 L F
.34411 .53039 m .34182 .53188 L .34449 .52981 L F
0 0 .548 r
.34525 .53164 m .34411 .53039 L .34615 .5298 L F
.263 0 .268 r
.30555 .6138 m .30274 .61673 L .30459 .61587 L F
.119 0 .202 r
.30459 .61587 m .30721 .61274 L .30555 .6138 L F
.775 .73 .811 r
.65648 .40818 m .65988 .40829 L .65914 .40499 L F
.786 .688 .757 r
.65648 .40818 m .65756 .41174 L .65988 .40829 L F
.786 .736 .807 r
.65914 .40499 m .65988 .40829 L .66239 .4051 L F
.714 .634 .766 r
.7096 .35784 m .71226 .35717 L .71225 .35494 L F
.546 .506 .763 r
.3569 .55988 m .35791 .56285 L .36057 .56201 L F
.44 .199 .451 r
.3574 .56532 m .36057 .56201 L .35791 .56285 L F
.431 0 0 r
.57719 .42796 m .57777 .42741 L .57467 .42728 L F
0 0 0 r
.57979 .42671 m .57777 .42741 L .57719 .42796 L F
.812 .82 .857 r
.2496 .52487 m .2447 .52548 L .24648 .52466 L F
.2496 .52487 m .24303 .52749 L .2447 .52548 L F
.563 .92 .954 r
.2496 .52487 m .25008 .52356 L .25165 .52362 L F
.2496 .52487 m .24648 .52466 L .25008 .52356 L F
.552 .754 .971 r
.36819 .66848 m .36798 .67071 L .36638 .66928 L F
.27 0 0 r
.36798 .67071 m .36854 .67252 L .36638 .66928 L F
0 0 .512 r
.39543 .51764 m .39497 .51698 L .39255 .51435 L F
0 0 .405 r
.39543 .51764 m .39703 .51993 L .39497 .51698 L F
.234 0 .034 r
.3512 .65102 m .35354 .64917 L .35203 .65048 L F
.3512 .65102 m .35354 .64917 L .35203 .65048 L F
.415 .72 .987 r
.35395 .64747 m .35354 .64917 L .35255 .64816 L F
.026 0 .328 r
.33669 .61249 m .33452 .61641 L .33456 .61343 L F
0 0 .019 r
.30783 .62914 m .30837 .62661 L .3094 .62502 L F
.819 .706 .74 r
.65405 .4116 m .65756 .41174 L .65648 .40818 L F
.82 .75 .786 r
.66224 .34388 m .66555 .34498 L .66642 .34201 L F
.829 .739 .765 r
.66333 .34723 m .66555 .34498 L .66224 .34388 L F
0 .109 .641 r
.20882 .58149 m .21076 .58358 L .20986 .58091 L F
0 0 0 r
.63685 .37955 m .63401 .38025 L .63741 .37936 L F
.63685 .37955 m .63401 .38025 L .63741 .37936 L F
.532 .894 .685 r
.63685 .37955 m .63741 .37936 L .63884 .37802 L F
.63884 .37802 m .63741 .37936 L .63685 .37955 L F
.819 .674 .702 r
.30392 .63332 m .30554 .63277 L .30295 .63588 L F
.508 0 0 r
.30711 .63491 m .30554 .63277 L .3074 .63168 L F
.929 .963 .769 r
.66642 .34201 m .66872 .33877 L .66787 .33787 L F
.847 .99 .85 r
.66872 .33877 m .6693 .33608 L .66787 .33787 L F
.66872 .33877 m .67158 .33571 L .6693 .33608 L F
.915 .967 .794 r
.5291 .41964 m .52776 .42234 L .52773 .41958 L F
.941 .964 .71 r
.52773 .41958 m .52776 .42234 L .52605 .42495 L F
.723 .514 .606 r
.33774 .53396 m .33486 .53523 L .33718 .53031 L F
.33774 .53396 m .33486 .53523 L .33718 .53031 L F
.693 .564 .705 r
.3397 .52768 m .3397 .53057 L .33718 .53031 L F
.437 .316 .616 r
.33718 .53031 m .33987 .53284 L .3397 .53057 L F
.33718 .53031 m .33774 .53396 L .33987 .53284 L F
.33718 .53031 m .33774 .53396 L .33987 .53284 L F
.556 .528 .779 r
.44623 .46901 m .44469 .47282 L .44366 .46993 L F
.44623 .46901 m .44738 .47267 L .44469 .47282 L F
.623 .426 .594 r
.44758 .47522 m .44469 .47282 L .44738 .47267 L F
.44758 .47522 m .44502 .47618 L .44469 .47282 L F
.869 .805 .318 r
.39389 .50118 m .39384 .49921 L .39686 .49976 L F
.39389 .50118 m .39358 .50122 L .39384 .49921 L F
.777 .898 .495 r
.39242 .50312 m .39358 .50122 L .39389 .50118 L F
.206 0 .057 r
.3484 .53932 m .35229 .53624 L .349 .53701 L F
.958 .621 .318 r
.35834 .68312 m .35652 .68048 L .35622 .6837 L F
.701 .276 .234 r
.35866 .686 m .35834 .68312 L .35622 .6837 L F
.35866 .686 m .35962 .68449 L .35834 .68312 L F
.25 .046 .395 r
.69657 .36322 m .69443 .36668 L .69454 .36441 L F
0 0 .53 r
.33605 .68901 m .33475 .68789 L .33622 .68709 L F
.33605 .68901 m .336 .69063 L .33475 .68789 L F
0 0 .149 r
.22403 .54618 m .22462 .5451 L .22492 .54259 L F
.684 .91 .571 r
.22403 .54618 m .22254 .54772 L .22462 .5451 L F
.41 .177 .448 r
.35521 .5819 m .35719 .58376 L .35781 .5814 L F
.35521 .5819 m .35489 .58442 L .35719 .58376 L F
.925 .646 .493 r
.37397 .60235 m .37659 .60429 L .37593 .60114 L F
0 0 .414 r
.33372 .55965 m .33496 .56007 L .33591 .55863 L F
.577 .423 .635 r
.3741 .59445 m .37719 .59409 L .37636 .59158 L F
.736 .818 .916 r
.2225 .60414 m .22678 .60418 L .22496 .6037 L F
.594 .616 .843 r
.22584 .59622 m .22516 .60047 L .22538 .59779 L F
.526 .798 .995 r
.22751 .60229 m .22678 .60418 L .2292 .60365 L F
.66 .93 .971 r
.22751 .60229 m .22496 .6037 L .22678 .60418 L F
.593 .577 .804 r
.22678 .60418 m .23073 .60734 L .2292 .60365 L F
.51 .474 .753 r
.45698 .53264 m .45444 .53446 L .45364 .53046 L F
.399 .305 .632 r
.45698 .53264 m .45497 .53689 L .45444 .53446 L F
.533 .485 .748 r
.38081 .5476 m .37836 .55065 L .37649 .54594 L F
.123 0 0 r
.38115 .55066 m .37834 .5524 L .37836 .55065 L F
.904 .576 .092 r
.3876 .6261 m .38626 .62282 L .38624 .62533 L F
.847 .979 .869 r
.38369 .62836 m .3876 .6261 L .38624 .62533 L F
.38369 .62836 m .38473 .62873 L .3876 .6261 L F
.318 .228 .594 r
.30885 .54035 m .31071 .53613 L .30861 .53675 L F
.666 .578 .747 r
.71226 .35717 m .71514 .35344 L .71225 .35494 L F
.71226 .35717 m .71482 .35775 L .71514 .35344 L F
.627 .791 .961 r
.29403 .54923 m .29835 .55006 L .29595 .54793 L F
.707 .263 .196 r
.30015 .54893 m .29595 .54793 L .29835 .55006 L F
.862 .461 0 r
.41036 .54677 m .41015 .54813 L .40921 .54544 L F
.41036 .54677 m .41124 .54912 L .41015 .54813 L F
.469 .287 .551 r
.34207 .5714 m .33959 .57467 L .33954 .57223 L F
.65 .809 .96 r
.37941 .57746 m .38175 .57923 L .38348 .57795 L F
.37941 .57746 m .38175 .57923 L .38348 .57795 L F
.679 .977 .882 r
.68278 .36291 m .68098 .36446 L .68262 .36225 L F
.658 .95 .953 r
.68262 .36225 m .68098 .36446 L .68002 .36378 L F
.962 .654 .244 r
.60453 .42688 m .60544 .42497 L .60394 .42348 L F
.60453 .42688 m .60573 .42726 L .60544 .42497 L F
.706 .683 .825 r
.70214 .29391 m .70512 .29264 L .70356 .28908 L F
.70214 .29391 m .70356 .28908 L .70488 .29537 L F
.47 .273 .53 r
.70374 .29628 m .70214 .29391 L .70488 .29537 L F
.605 .392 .566 r
.33494 .57934 m .33282 .58302 L .33758 .57877 L F
.33494 .57934 m .33282 .58302 L .33758 .57877 L F
.972 .848 .445 r
.41475 .58053 m .4153 .58181 L .41467 .58458 L F
.375 .798 .973 r
.3177 .65834 m .31531 .65876 L .31382 .65808 L F
.3177 .65834 m .31531 .65876 L .31382 .65808 L F
.339 0 0 r
.2662 .62005 m .26823 .62069 L .27029 .62006 L F
.868 .908 .857 r
.70832 .29318 m .70959 .28912 L .70725 .29146 L F
.346 0 .007 r
.33293 .55145 m .33156 .55217 L .33079 .55266 L F
.399 .834 .95 r
.32991 .55322 m .33079 .55266 L .3282 .55331 L F
.965 .717 .511 r
.33079 .55266 m .32695 .55158 L .3282 .55331 L F
.32914 .5522 m .32884 .5508 L .32695 .55158 L F
.33079 .55266 m .3302 .5521 L .32914 .5522 L F
.3302 .5521 m .32884 .5508 L .32914 .5522 L F
.3302 .5521 m .32879 .55363 L .32884 .5508 L F
.33079 .55266 m .32879 .55363 L .3302 .5521 L F
.346 0 .007 r
.33156 .55217 m .32879 .55363 L .33079 .55266 L F
.399 .834 .95 r
.33225 .55308 m .33079 .55266 L .32991 .55322 L F
.346 0 .007 r
.33204 .55192 m .33146 .55332 L .32879 .55363 L F
.64 .942 .959 r
.33293 .55145 m .33079 .55266 L .33225 .55308 L F
.346 0 .007 r
.33293 .55145 m .3326 .55187 L .33204 .55192 L F
.3326 .55187 m .33146 .55332 L .33204 .55192 L F
.001 .576 .745 r
.35752 .59116 m .35996 .59127 L .35889 .59116 L F
.35752 .59116 m .35889 .59116 L .35587 .5932 L F
.965 .636 .306 r
.58969 .38941 m .59148 .39303 L .58984 .39187 L F
.9 .497 .088 r
.59148 .39303 m .59098 .39443 L .58984 .39187 L F
.59148 .39303 m .5927 .39604 L .59098 .39443 L F
.382 0 .086 r
.43428 .59946 m .43488 .59808 L .43728 .59904 L F
.475 0 .01 r
.29919 .61721 m .30106 .6184 L .30274 .61673 L F
.58 .213 .31 r
.30106 .6184 m .30459 .61587 L .30274 .61673 L F
.51 0 0 r
.30248 .55772 m .30625 .55856 L .30619 .5563 L F
.166 .055 .472 r
.30625 .55856 m .30776 .55871 L .30619 .5563 L F
.30625 .55856 m .30776 .55871 L .30619 .5563 L F
.814 .698 .737 r
.35177 .58147 m .3526 .58515 L .3481 .58435 L F
.239 0 .268 r
.3526 .58515 m .34989 .58822 L .35212 .58748 L F
.821 .536 .506 r
.3481 .58435 m .3526 .58515 L .35212 .58748 L F
.528 .514 .783 r
.35489 .58442 m .3526 .58515 L .35177 .58147 L F
.378 .119 .39 r
.35489 .58442 m .3526 .58515 L .35212 .58748 L F
.35489 .58442 m .3526 .58515 L .35212 .58748 L F
.436 0 0 r
.27461 .63591 m .27714 .63588 L .27896 .6366 L F
.929 .555 .271 r
.4004 .64925 m .39941 .64526 L .3975 .64451 L F
.406 .231 .528 r
.32391 .57539 m .326 .57487 L .32607 .57196 L F
.112 0 .397 r
.32391 .57539 m .32529 .57696 L .326 .57487 L F
.32391 .57539 m .3238 .57821 L .32529 .57696 L F
.478 .483 .785 r
.45934 .5451 m .45733 .54714 L .45641 .54361 L F
.495 .477 .766 r
.45934 .5451 m .45811 .54959 L .45733 .54714 L F
0 0 0 r
.37816 .59012 m .37986 .58817 L .37636 .59158 L F
.522 .201 .364 r
.38211 .59027 m .37986 .58817 L .37816 .59012 L F
.492 .559 .852 r
.38367 .59126 m .37986 .58817 L .38211 .59027 L F
.644 .432 .581 r
.35112 .69022 m .35336 .68735 L .35131 .6874 L F
.771 .684 .767 r
.64471 .39894 m .64858 .39938 L .64739 .39566 L F
.94 .658 .477 r
.64658 .398 m .64858 .39938 L .64731 .40118 L F
.914 .748 .662 r
.64739 .39566 m .64858 .39938 L .64658 .398 L F
.085 0 0 r
.64353 .40264 m .64478 .40163 L .64607 .40157 L F
.85 .508 .406 r
.64731 .40118 m .64755 .40085 L .64776 .40104 L F
.64731 .40118 m .64776 .40104 L .649 .40215 L F
.64755 .40085 m .64872 .40028 L .649 .40215 L F
.849 .499 .39 r
.64731 .40118 m .64741 .40123 L .64694 .4029 L F
.64741 .40123 m .649 .40215 L .64694 .4029 L F
.846 .811 .815 r
.64694 .4029 m .64613 .40783 L .64484 .40602 L F
.64694 .4029 m .64484 .40602 L .64663 .40406 L F
.64694 .4029 m .64663 .40406 L .64901 .40144 L F
.849 .499 .39 r
.64731 .40118 m .64694 .4029 L .64901 .40144 L F
.64731 .40118 m .64901 .40144 L .64607 .40157 L F
.64731 .40118 m .64607 .40157 L .64478 .40163 L F
.085 0 0 r
.64418 .4025 m .64607 .40157 L .64901 .40144 L F
.64353 .40264 m .64607 .40157 L .64418 .4025 L F
.85 .508 .406 r
.64755 .40085 m .64858 .39938 L .64872 .40028 L F
.681 .619 .78 r
.37625 .61978 m .378 .62345 L .37406 .62262 L F
.364 0 0 r
.37406 .62262 m .378 .62345 L .37616 .62336 L F
.42 .264 .562 r
.37406 .62262 m .37616 .62336 L .37625 .61978 L F
.9 .491 .097 r
.39672 .54565 m .39836 .54704 L .39582 .54333 L F
.997 .849 .563 r
.39672 .54565 m .39731 .54932 L .39836 .54704 L F
.363 .011 .227 r
.2912 .56462 m .28757 .5682 L .28838 .56621 L F
.2912 .56462 m .29004 .56762 L .28757 .5682 L F
.371 .041 .27 r
.29365 .56383 m .29004 .56762 L .2912 .56462 L F
0 .427 .806 r
.39302 .59744 m .39304 .59693 L .39014 .59659 L F
.39302 .59744 m .39339 .59732 L .39304 .59693 L F
.919 .784 .695 r
.40135 .6843 m .39932 .68328 L .40003 .68632 L F
.414 .622 .938 r
.37398 .55441 m .37598 .55653 L .37281 .55633 L F
.495 .477 .766 r
.45934 .5451 m .46043 .54906 L .45811 .54959 L F
0 .163 .671 r
.35841 .50023 m .35863 .501 L .35654 .49959 L F
.574 .717 .94 r
.73525 .3393 m .73876 .33867 L .73707 .33681 L F
.12 0 0 r
.36023 .60045 m .36144 .6002 L .36375 .59843 L F
.702 .431 .51 r
.53645 .45395 m .53644 .45632 L .53396 .45376 L F
.937 .773 .653 r
.38972 .65248 m .39072 .64956 L .38832 .64799 L F
0 0 0 r
.44631 .55629 m .44779 .55238 L .4452 .55265 L F
.44631 .55629 m .44709 .55479 L .44779 .55238 L F
.442 .762 .996 r
.44631 .55629 m .44842 .55585 L .44709 .55479 L F
.816 .861 .882 r
.64546 .35712 m .64978 .35568 L .64806 .35387 L F
.428 .351 .667 r
.34213 .52787 m .3397 .53057 L .3397 .52768 L F
0 0 .178 r
.37887 .66166 m .37666 .66547 L .3777 .66371 L F
.467 0 0 r
.37666 .66547 m .3772 .6659 L .37766 .66636 L F
.3772 .6659 m .3803 .66836 L .37766 .66636 L F
.687 .965 .935 r
.37879 .66939 m .37706 .66897 L .37766 .66636 L F
.734 .775 .886 r
.37766 .66636 m .3803 .66836 L .38185 .66689 L F
.754 .752 .851 r
.37766 .66636 m .38185 .66689 L .37879 .66939 L F
0 0 .021 r
.37796 .66666 m .37766 .66636 L .37706 .66897 L F
.281 .744 .948 r
.37766 .66636 m .37834 .66645 L .37998 .66625 L F
.37834 .66645 m .38185 .66689 L .37998 .66625 L F
.617 .913 .981 r
.3803 .66836 m .38354 .66813 L .38185 .66689 L F
.578 .933 .937 r
.38354 .66813 m .37879 .66939 L .38185 .66689 L F
.281 .744 .948 r
.37766 .66636 m .38185 .66689 L .37998 .66625 L F
.938 .954 .758 r
.38312 .66751 m .38365 .66666 L .38225 .66524 L F
.436 .377 .693 r
.37998 .66625 m .38286 .66795 L .38252 .66595 L F
.38286 .66795 m .38342 .66828 L .38312 .66751 L F
.38286 .66795 m .38312 .66751 L .38252 .66595 L F
.897 .8 .744 r
.38148 .66647 m .38365 .66666 L .38342 .66828 L F
.38365 .66666 m .38455 .66674 L .38342 .66828 L F
.938 .954 .758 r
.38365 .66666 m .38456 .66522 L .38387 .66522 L F
.38365 .66666 m .38387 .66522 L .38225 .66524 L F
.38342 .66828 m .38456 .66522 L .38312 .66751 L F
.826 .893 .89 r
.38456 .66522 m .38455 .66674 L .38365 .66666 L F
.38456 .66522 m .38365 .66666 L .38362 .66666 L F
.38443 .66527 m .38362 .66666 L .38148 .66647 L F
.38456 .66522 m .38362 .66666 L .38443 .66527 L F
.436 .377 .693 r
.37998 .66625 m .38252 .66595 L .38225 .66524 L F
0 0 0 r
.38052 .66063 m .37887 .66166 L .3777 .66371 L F
.541 .832 .498 r
.37892 .66231 m .38052 .66063 L .3777 .66371 L F
.546 .542 .802 r
.37766 .66636 m .37998 .66625 L .37892 .66231 L F
0 0 .021 r
.37861 .665 m .37766 .66636 L .37796 .66666 L F
.467 0 0 r
.37666 .66547 m .37766 .66636 L .3777 .66371 L F
0 0 0 r
.36732 .53064 m .36547 .53206 L .36484 .53234 L F
.601 .422 .611 r
.36809 .52885 m .36547 .53206 L .36732 .53064 L F
.726 .989 .865 r
.36809 .52885 m .36732 .53064 L .37014 .52836 L F
.601 .422 .611 r
.36809 .52885 m .36814 .53186 L .36679 .53196 L F
.36761 .52944 m .36679 .53196 L .36547 .53206 L F
.36809 .52885 m .36679 .53196 L .36761 .52944 L F
.518 .779 .991 r
.36547 .53206 m .36679 .53196 L .36598 .53058 L F
.36679 .53196 m .36814 .53186 L .36598 .53058 L F
.986 .897 .63 r
.36598 .53058 m .36598 .53183 L .36547 .53206 L F
.605 .443 .636 r
.36814 .53186 m .36597 .53474 L .36547 .53206 L F
.986 .897 .63 r
.36598 .53183 m .36597 .53474 L .36547 .53206 L F
0 .06 .597 r
.36597 .53474 m .36512 .53747 L .36426 .53274 L F
.36597 .53474 m .36426 .53274 L .36547 .53206 L F
.98 .91 .651 r
.36597 .53474 m .36428 .53585 L .36466 .53645 L F
.36428 .53586 m .36364 .53627 L .36408 .53635 L F
.233 .75 .767 r
.36364 .53627 m .36433 .53618 L .36428 .53586 L F
.36364 .53627 m .36428 .53586 L .3638 .53284 L F
.98 .91 .651 r
.36428 .53585 m .36364 .53627 L .36428 .53586 L F
.36428 .53585 m .36408 .53635 L .36466 .53645 L F
0 0 0 r
.36484 .53234 m .36547 .53206 L .36426 .53274 L F
.934 .807 .696 r
.3638 .53284 m .36428 .53586 L .36428 .53584 L F
.989 .825 .587 r
.3638 .53284 m .36364 .53627 L .36428 .53585 L F
.3638 .53284 m .36428 .53585 L .36597 .53474 L F
.934 .807 .696 r
.3638 .53284 m .36428 .53584 L .36598 .53058 L F
.36428 .53586 m .36433 .53618 L .36428 .53585 L F
.233 .75 .767 r
.36433 .53618 m .36364 .53627 L .36428 .53585 L F
.36433 .53618 m .36428 .53585 L .36597 .53474 L F
.934 .807 .696 r
.36428 .53585 m .36433 .53618 L .36485 .5344 L F
.36428 .53586 m .36485 .5344 L .36598 .53058 L F
.986 .897 .63 r
.36598 .53058 m .36433 .53618 L .36585 .53484 L F
.36597 .53448 m .36585 .53484 L .36597 .53474 L F
.36598 .53058 m .36585 .53484 L .36597 .53448 L F
.681 .285 .289 r
.3582 .54654 m .3532 .54659 L .3531 .546 L F
.649 .729 .907 r
.70603 .28345 m .70369 .28488 L .70209 .2827 L F
.444 .285 .57 r
.70369 .28488 m .70619 .28588 L .70603 .28345 L F
.70369 .28488 m .70619 .28588 L .70603 .28345 L F
.862 .913 .864 r
.65265 .33334 m .65219 .33639 L .64978 .33639 L F
.65265 .33334 m .6538 .33473 L .65219 .33639 L F
.928 .972 .734 r
.71574 .32554 m .71713 .3211 L .7184 .32501 L F
.71574 .32554 m .71505 .32462 L .71713 .3211 L F
.428 .351 .667 r
.34213 .52787 m .34273 .53044 L .3397 .53057 L F
.26 .009 .33 r
.34182 .53188 m .3397 .53057 L .34273 .53044 L F
.34182 .53188 m .33987 .53284 L .3397 .53057 L F
0 0 .016 r
.39728 .67371 m .3968 .67553 L .39746 .67114 L F
0 0 .492 r
.39761 .6676 m .39874 .66997 L .39746 .67114 L F
.314 .223 .59 r
.39874 .66997 m .39728 .67371 L .39746 .67114 L F
0 .009 .569 r
.414 .5663 m .41498 .56838 L .41415 .56455 L F
.206 0 .057 r
.3484 .53932 m .35057 .53863 L .35229 .53624 L F
.083 .001 .455 r
.35229 .53624 m .35338 .53167 L .35121 .53412 L F
.35229 .53624 m .35368 .53615 L .35338 .53167 L F
.026 0 0 r
.35057 .53863 m .35368 .53615 L .35229 .53624 L F
.714 .562 .681 r
.36185 .69095 m .36476 .69042 L .36245 .69328 L F
.998 .845 .512 r
.41374 .5594 m .41307 .56227 L .41225 .56072 L F
.979 .762 .539 r
.41257 .55571 m .41374 .5594 L .41205 .55824 L F
.974 .68 .4 r
.41374 .5594 m .41225 .56072 L .41205 .55824 L F
.412 .639 .949 r
.23073 .60734 m .23291 .60767 L .23215 .60564 L F
.801 .452 0 r
.2292 .60365 m .23073 .60734 L .22989 .60575 L F
.412 .639 .949 r
.23073 .60734 m .23291 .60767 L .23215 .60564 L F
0 0 .082 r
.22977 .60906 m .22989 .60575 L .23073 .60734 L F
.778 .659 .732 r
.22516 .60047 m .22933 .60094 L .22862 .59782 L F
.526 .798 .995 r
.22751 .60229 m .22933 .60094 L .22516 .60047 L F
.22751 .60229 m .2292 .60365 L .22933 .60094 L F
.016 .007 .501 r
.22933 .60094 m .23042 .5965 L .22862 .59782 L F
.22933 .60094 m .23058 .602 L .23042 .5965 L F
.733 .45 .499 r
.22751 .60229 m .22933 .60094 L .2292 .60365 L F
.22751 .60229 m .23058 .602 L .22933 .60094 L F
.733 .655 .772 r
.53263 .45019 m .53396 .45376 L .52996 .45351 L F
.727 .445 .5 r
.52996 .45351 m .53396 .45376 L .534 .45606 L F
.708 .43 .501 r
.53396 .45376 m .53644 .45632 L .534 .45606 L F
.689 .153 0 r
.26699 .63273 m .2669 .63434 L .26467 .63216 L F
.26699 .63273 m .26873 .63455 L .2669 .63434 L F
.571 .513 .751 r
.45587 .52691 m .45331 .5277 L .45231 .52408 L F
.468 .332 .612 r
.45587 .52691 m .45364 .53046 L .45331 .5277 L F
.82 .797 .83 r
.62613 .35341 m .62771 .35399 L .62609 .35534 L F
.769 .82 .893 r
.63103 .35106 m .62771 .35399 L .62613 .35341 L F
.489 .699 .962 r
.62502 .40173 m .62248 .40212 L .62187 .40039 L F
.975 .677 .381 r
.3944 .54233 m .39538 .54049 L .3942 .53943 L F
.3944 .54233 m .39582 .54333 L .39538 .54049 L F
.348 0 .059 r
.26792 .56693 m .27014 .56689 L .26826 .56621 L F
.384 0 .138 r
.28233 .56836 m .28077 .57075 L .27829 .57108 L F
.323 0 .103 r
.2832 .5702 m .28233 .56836 L .28495 .56813 L F
.2832 .5702 m .28077 .57075 L .28233 .56836 L F
.716 .246 .132 r
.22815 .59427 m .2275 .59577 L .22584 .59622 L F
.821 .431 .315 r
.35698 .53114 m .35659 .5327 L .36112 .53367 L F
.233 0 .301 r
.35838 .53623 m .35903 .53543 L .35865 .53439 L F
.691 .173 0 r
.35815 .53304 m .35865 .53439 L .36112 .53367 L F
0 0 .189 r
.36133 .53224 m .36185 .53209 L .36181 .52895 L F
.36112 .53367 m .36185 .53209 L .36133 .53224 L F
.658 .969 .815 r
.36112 .53367 m .35951 .53414 L .36185 .53209 L F
.35951 .53414 m .35865 .53439 L .36185 .53209 L F
.446 .202 .449 r
.36087 .5332 m .36213 .53201 L .36185 .53209 L F
.36213 .53201 m .36371 .53051 L .36185 .53209 L F
.233 0 .301 r
.35903 .53543 m .36087 .5332 L .35865 .53439 L F
.691 .173 0 r
.35659 .5327 m .35865 .53439 L .35815 .53304 L F
.638 .599 .794 r
.37932 .62161 m .378 .62345 L .37625 .61978 L F
0 0 .227 r
.34279 .53818 m .342 .53657 L .34357 .53574 L F
.34279 .53818 m .34176 .53934 L .342 .53657 L F
0 .274 .779 r
.32004 .66624 m .3201 .66734 L .31901 .66572 L F
.436 0 0 r
.32004 .66624 m .31901 .66572 L .31727 .66661 L F
.32004 .66624 m .31727 .66661 L .31997 .66507 L F
.32004 .66624 m .31997 .66507 L .32094 .66451 L F
0 .274 .779 r
.32004 .66624 m .32074 .66828 L .3201 .66734 L F
.938 .941 .768 r
.31931 .6679 m .32074 .66828 L .32004 .66624 L F
0 0 .137 r
.31739 .59397 m .31823 .59013 L .31773 .59137 L F
.627 .578 .779 r
.72386 .32607 m .72565 .33203 L .72242 .32965 L F
0 .242 .707 r
.72242 .32965 m .72565 .33203 L .72536 .33175 L F
.51 .743 .979 r
.72536 .33175 m .72411 .33464 L .72323 .3313 L F
.72536 .33175 m .72676 .33381 L .72411 .33464 L F
.784 .719 .792 r
.3481 .58435 m .34989 .58822 L .3461 .58591 L F
.639 .734 .918 r
.3461 .58591 m .3476 .58683 L .34764 .58549 L F
.3476 .58683 m .34989 .58822 L .34789 .58579 L F
.3476 .58683 m .34789 .58579 L .34764 .58549 L F
.821 .536 .506 r
.3481 .58435 m .35212 .58748 L .34989 .58822 L F
0 0 0 r
.34989 .58822 m .34728 .59105 L .34872 .58965 L F
.34728 .59105 m .34709 .59126 L .34872 .58965 L F
.269 .151 .527 r
.34872 .58965 m .35139 .58744 L .35114 .58729 L F
.955 .746 .58 r
.3475 .58593 m .34989 .58822 L .34872 .58965 L F
.517 .257 .459 r
.34799 .5854 m .3481 .58435 L .34626 .58578 L F
.34647 .58581 m .34626 .58578 L .3461 .58591 L F
.34799 .5854 m .34626 .58578 L .34647 .58581 L F
.955 .746 .58 r
.34764 .58549 m .34989 .58822 L .3475 .58593 L F
.269 .151 .527 r
.34872 .58965 m .35114 .58729 L .34921 .58614 L F
.639 .734 .918 r
.3461 .58591 m .34764 .58549 L .34717 .58492 L F
.955 .746 .58 r
.34717 .58492 m .34764 .58549 L .3475 .58593 L F
.269 .151 .527 r
.34872 .58965 m .34921 .58614 L .34794 .58599 L F
.34776 .58673 m .34794 .58599 L .3475 .58593 L F
.34872 .58965 m .34794 .58599 L .34776 .58673 L F
.814 .698 .737 r
.35177 .58147 m .3481 .58435 L .34814 .58128 L F
0 0 .057 r
.34806 .58545 m .34799 .5854 L .34794 .58599 L F
.34864 .58303 m .34833 .58415 L .34806 .58545 L F
.34833 .58415 m .34799 .5854 L .34806 .58545 L F
.269 .151 .527 r
.34872 .58965 m .35077 .58965 L .35139 .58744 L F
.287 .022 .325 r
.34872 .58965 m .35039 .59194 L .35077 .58965 L F
.34872 .58965 m .34837 .59271 L .35039 .59194 L F
.35 .229 .571 r
.35139 .58744 m .34895 .59014 L .34779 .58676 L F
.517 .257 .459 r
.34682 .58715 m .34764 .58549 L .3461 .58591 L F
.218 0 .112 r
.34709 .59126 m .34796 .59225 L .34851 .59035 L F
.34796 .59225 m .34859 .59081 L .34872 .58965 L F
0 0 0 r
.34473 .59461 m .3461 .59349 L .34709 .59126 L F
.218 0 .112 r
.34709 .59126 m .3461 .59349 L .34837 .59271 L F
0 0 0 r
.34852 .59075 m .34637 .59188 L .3489 .59017 L F
.34894 .59015 m .3489 .59017 L .34895 .59014 L F
.34852 .59075 m .3489 .59017 L .34894 .59015 L F
.218 0 .112 r
.34823 .59048 m .34851 .59035 L .34854 .59027 L F
.34709 .59126 m .34851 .59035 L .34823 .59048 L F
.34791 .59046 m .34854 .59027 L .34872 .58965 L F
.34709 .59126 m .34854 .59027 L .34791 .59046 L F
0 0 0 r
.34887 .59018 m .34637 .59188 L .34408 .59275 L F
.34895 .59014 m .3489 .59017 L .34887 .59018 L F
.3489 .59017 m .34637 .59188 L .34887 .59018 L F
.807 .644 .68 r
.34422 .58933 m .3461 .58591 L .34378 .58658 L F
.517 .257 .459 r
.3445 .58696 m .3461 .58591 L .34378 .58658 L F
.807 .644 .68 r
.34514 .58943 m .34889 .59013 L .34794 .58724 L F
.34508 .58948 m .34516 .58949 L .34514 .58943 L F
.34516 .58949 m .34889 .59013 L .34514 .58943 L F
.34508 .58948 m .34794 .58724 L .34682 .58715 L F
.34455 .58873 m .34574 .58706 L .3461 .58591 L F
.34422 .58933 m .34486 .58837 L .34455 .58873 L F
.34486 .58837 m .34574 .58706 L .34455 .58873 L F
.517 .257 .459 r
.34682 .58715 m .3461 .58591 L .34574 .58706 L F
.807 .644 .68 r
.34574 .58706 m .34717 .58492 L .3461 .58591 L F
.34422 .58933 m .34508 .58948 L .34513 .58938 L F
.34486 .58837 m .34513 .58938 L .34717 .58492 L F
.34422 .58933 m .34513 .58938 L .34486 .58837 L F
.517 .257 .459 r
.34733 .58646 m .34764 .58549 L .34682 .58715 L F
.269 .151 .527 r
.3475 .58593 m .34751 .58594 L .34717 .58492 L F
.807 .644 .68 r
.34508 .58948 m .34758 .58613 L .34717 .58492 L F
.623 .534 .733 r
.34622 .58326 m .34695 .58596 L .3445 .58696 L F
.517 .257 .459 r
.34768 .58863 m .34682 .58715 L .34598 .58708 L F
.34768 .58863 m .34598 .58708 L .3445 .58696 L F
.807 .644 .68 r
.34682 .58715 m .34794 .58724 L .34758 .58613 L F
.517 .257 .459 r
.34701 .58748 m .34733 .58646 L .34682 .58715 L F
.34768 .58863 m .34764 .58549 L .34701 .58748 L F
.623 .534 .733 r
.34695 .58596 m .34768 .58863 L .34559 .58753 L F
.517 .257 .459 r
.34574 .58706 m .3461 .58591 L .3445 .58696 L F
.623 .534 .733 r
.34695 .58596 m .34559 .58753 L .3445 .58696 L F
.34424 .58596 m .3445 .58696 L .34378 .58658 L F
.34622 .58326 m .3445 .58696 L .34424 .58596 L F
.807 .644 .68 r
.34889 .59013 m .34895 .59014 L .34892 .59005 L F
.34889 .59013 m .34892 .59005 L .34758 .58613 L F
.218 0 .112 r
.34796 .59225 m .34837 .59271 L .34859 .59081 L F
.269 .151 .527 r
.34795 .58599 m .34921 .58614 L .34806 .58545 L F
.517 .257 .459 r
.34765 .58613 m .34799 .5854 L .34764 .58549 L F
.35 .229 .571 r
.34792 .58613 m .34779 .58676 L .34758 .58613 L F
.517 .257 .459 r
.34768 .58863 m .34792 .58613 L .34765 .58613 L F
.34792 .58613 m .34799 .5854 L .34765 .58613 L F
.35 .229 .571 r
.34806 .58545 m .34792 .58613 L .34717 .58492 L F
.34792 .58613 m .34758 .58613 L .34717 .58492 L F
.35139 .58744 m .34779 .58676 L .34806 .58545 L F
0 0 .057 r
.34877 .58254 m .34864 .58303 L .34768 .58863 L F
.34864 .58303 m .34794 .58599 L .34768 .58863 L F
.34878 .58252 m .34877 .58254 L .34768 .58863 L F
.34877 .58254 m .3481 .58435 L .34799 .5854 L F
.875 .859 .822 r
.57133 .42969 m .56906 .43036 L .57047 .43022 L F
.56906 .43036 m .5676 .43079 L .57047 .43022 L F
.849 .928 .544 r
.57133 .42969 m .57047 .43022 L .57171 .42864 L F
.995 .843 .579 r
.56748 .42752 m .57171 .42864 L .56985 .4268 L F
.954 .95 .667 r
.57171 .42864 m .57308 .42393 L .56985 .4268 L F
.232 0 0 r
.57171 .42864 m .57317 .42941 L .57467 .42728 L F
.57171 .42864 m .57047 .43022 L .57317 .42941 L F
.873 .851 .818 r
.57308 .42393 m .56901 .42561 L .56985 .4268 L F
.57308 .42393 m .57147 .42777 L .56901 .42561 L F
.142 .553 .925 r
.56901 .42561 m .56966 .42618 L .57111 .42634 L F
.56966 .42618 m .57147 .42777 L .57111 .42634 L F
0 0 .103 r
.57406 .4244 m .573 .42577 L .57308 .42393 L F
.573 .42577 m .57147 .42777 L .57263 .42501 L F
.573 .42577 m .57263 .42501 L .57308 .42393 L F
.654 .945 .958 r
.57111 .42634 m .57147 .42777 L .57406 .4244 L F
.385 0 0 r
.57579 .42839 m .57467 .42728 L .57317 .42941 L F
.57579 .42839 m .57719 .42796 L .57467 .42728 L F
.654 .945 .958 r
.57111 .42634 m .57406 .4244 L .57579 .42839 L F
.271 0 0 r
.57312 .42656 m .57333 .42644 L .57111 .42634 L F
.57333 .42644 m .57384 .42616 L .57322 .4262 L F
.57333 .42644 m .57322 .4262 L .57111 .42634 L F
.472 .202 .422 r
.57047 .43022 m .57292 .43151 L .57317 .42941 L F
.292 .309 .707 r
.57111 .42634 m .5724 .43003 L .57047 .43022 L F
0 0 0 r
.56639 .4317 m .56895 .43093 L .57047 .43022 L F
.951 .681 .489 r
.56573 .42697 m .56748 .42752 L .56649 .42693 L F
.56573 .42697 m .5676 .43079 L .56748 .42752 L F
.966 .645 .341 r
.56573 .42697 m .56639 .4317 L .5676 .43079 L F
.483 .359 .635 r
.56991 .4291 m .56693 .43097 L .56649 .42693 L F
.292 .309 .707 r
.5699 .42942 m .57047 .43022 L .56939 .43073 L F
.57111 .42634 m .57077 .42842 L .5699 .42942 L F
.57077 .42842 m .57047 .43022 L .5699 .42942 L F
.376 .067 .307 r
.56975 .42959 m .56639 .4317 L .56693 .43097 L F
.57028 .42933 m .56964 .42973 L .56975 .42959 L F
.56964 .42973 m .56639 .4317 L .56975 .42959 L F
.483 .359 .635 r
.57028 .42933 m .56975 .42959 L .56991 .4291 L F
.56975 .42959 m .56693 .43097 L .56991 .4291 L F
.292 .309 .707 r
.56963 .42996 m .56939 .43073 L .56931 .43077 L F
.376 .067 .307 r
.56964 .42973 m .56895 .43093 L .56639 .4317 L F
.292 .309 .707 r
.56996 .42915 m .56939 .43073 L .56963 .42996 L F
.376 .067 .307 r
.57028 .42933 m .56895 .43093 L .56964 .42973 L F
.292 .309 .707 r
.57111 .42634 m .5701 .42891 L .56996 .42915 L F
.5701 .42891 m .56939 .43073 L .56996 .42915 L F
.594 .86 .994 r
.56748 .42752 m .56985 .4268 L .56901 .42561 L F
.641 .931 .971 r
.56649 .42693 m .56748 .42752 L .56901 .42561 L F
.483 .359 .635 r
.56991 .4291 m .56649 .42693 L .57006 .42868 L F
.292 .309 .707 r
.57111 .42634 m .56931 .43077 L .57025 .42816 L F
.626 .416 .577 r
.57111 .42634 m .57028 .42933 L .57006 .42868 L F
.57111 .42634 m .57006 .42868 L .56901 .42561 L F
.292 .309 .707 r
.57025 .42816 m .57006 .42868 L .56895 .43093 L F
.57006 .42868 m .56931 .43077 L .56909 .43087 L F
.57006 .42868 m .56909 .43087 L .56895 .43093 L F
.483 .359 .635 r
.56971 .42765 m .56649 .42693 L .56901 .42561 L F
.875 .929 .855 r
.56767 .42659 m .57069 .42637 L .57009 .42383 L F
.57069 .42637 m .57111 .42634 L .57097 .426 L F
.57069 .42637 m .57097 .426 L .57009 .42383 L F
.483 .359 .635 r
.57006 .42868 m .56924 .42828 L .56971 .42765 L F
.56924 .42828 m .56649 .42693 L .56971 .42765 L F
.57028 .42933 m .56991 .4291 L .57006 .42868 L F
.746 .539 .614 r
.57111 .42634 m .56895 .43093 L .57028 .42933 L F
.933 .752 .634 r
.57111 .42634 m .57028 .42933 L .56767 .42659 L F
.361 .111 .393 r
.57317 .42941 m .57292 .43151 L .57579 .42839 L F
.671 .532 .686 r
.57579 .42839 m .57292 .43151 L .57111 .42634 L F
.271 0 0 r
.57025 .42815 m .57312 .42656 L .57111 .42634 L F
.292 .309 .707 r
.5724 .43003 m .57292 .43151 L .57047 .43022 L F
0 0 .07 r
.34473 .59461 m .34246 .5982 L .34473 .59624 L F
.325 .125 .447 r
.34473 .59624 m .3461 .59349 L .34473 .59461 L F
.182 .573 .937 r
.57479 .39163 m .57391 .39261 L .57241 .39166 L F
.57479 .39163 m .57605 .39304 L .57391 .39261 L F
.718 .878 .956 r
.71682 .35845 m .72216 .3575 L .72198 .35654 L F
0 0 0 r
.72216 .3575 m .72446 .35344 L .72457 .35359 L F
.72216 .3575 m .72457 .35359 L .72198 .35654 L F
.719 .198 0 r
.38293 .50764 m .37968 .50572 L .378 .50352 L F
0 .35 .736 r
.38293 .50764 m .3826 .50725 L .37968 .50572 L F
.628 .759 .941 r
.40725 .48542 m .40291 .48471 L .40614 .4835 L F
.647 .757 .929 r
.40981 .48414 m .40725 .48542 L .40614 .4835 L F
.941 .573 .214 r
.60829 .43099 m .60884 .43328 L .61029 .4344 L F
.975 .686 .409 r
.60884 .43568 m .61029 .4344 L .60884 .43328 L F
.60884 .43568 m .61045 .43678 L .61029 .4344 L F
.583 .278 .417 r
.2796 .55889 m .2824 .55873 L .28292 .55671 L F
.388 .1 .349 r
.28292 .55671 m .2824 .55873 L .28476 .55802 L F
.855 .693 .162 r
.38049 .60986 m .38075 .61087 L .38068 .60729 L F
.567 .231 .359 r
.28838 .56621 m .28757 .5682 L .28495 .56813 L F
.808 .905 .909 r
.65694 .332 m .6538 .33473 L .65265 .33334 L F
0 .129 .677 r
.28342 .64395 m .28298 .64499 L .28416 .64606 L F
.01 0 .097 r
.39217 .6013 m .39202 .60294 L .39444 .59995 L F
.673 .16 .013 r
.32683 .5042 m .33152 .50513 L .32937 .50608 L F
.739 .911 .541 r
.3325 .50288 m .33152 .50513 L .33185 .50462 L F
.3325 .50288 m .33185 .50462 L .33404 .50129 L F
.778 .937 .585 r
.3325 .50288 m .3337 .5013 L .33298 .50127 L F
.077 .332 .808 r
.33298 .50127 m .33305 .50139 L .3325 .50288 L F
.739 .911 .541 r
.3325 .50288 m .33404 .50129 L .33403 .50129 L F
.711 .903 .537 r
.33403 .50129 m .3337 .5013 L .3325 .50288 L F
.33404 .50128 m .3337 .5013 L .33403 .50129 L F
.268 0 0 r
.33321 .50133 m .3337 .5013 L .33657 .50229 L F
.33311 .5013 m .3337 .5013 L .33321 .50133 L F
.077 .332 .808 r
.33305 .50139 m .33546 .50562 L .3325 .50288 L F
.268 0 0 r
.33298 .50127 m .33353 .5013 L .33311 .5013 L F
.33353 .5013 m .3337 .5013 L .33311 .5013 L F
.739 .911 .541 r
.33403 .50129 m .33404 .50129 L .33404 .50128 L F
.768 .989 .759 r
.32937 .50608 m .33152 .50513 L .3325 .50288 L F
0 0 .087 r
.39172 .60305 m .39178 .60583 L .39202 .60294 L F
.39172 .60305 m .39117 .60761 L .39178 .60583 L F
.721 .92 .96 r
.39552 .67553 m .3968 .67553 L .39728 .67371 L F
.527 .001 0 r
.33032 .69643 m .33302 .69716 L .33074 .69839 L F
.609 .449 .64 r
.6391 .40308 m .64251 .40302 L .64185 .3992 L F
.602 .399 .578 r
.63923 .40494 m .64251 .40302 L .6391 .40308 L F
.525 .877 .637 r
.23388 .57841 m .23735 .57569 L .23617 .57761 L F
0 0 0 r
.23617 .57761 m .23735 .57569 L .23903 .57445 L F
.23 0 .02 r
.59755 .46222 m .5985 .46025 L .60095 .45956 L F
.442 .222 .483 r
.33648 .604 m .33651 .60706 L .3388 .60645 L F
.644 .734 .914 r
.34531 .68165 m .348 .6851 L .34961 .683 L F
.649 .729 .907 r
.70603 .28345 m .70509 .27912 L .70719 .28239 L F
.656 .668 .849 r
.70861 .28019 m .70719 .28239 L .70509 .27912 L F
.794 .977 .693 r
.70603 .28345 m .70719 .28239 L .70861 .28019 L F
.919 .678 .559 r
.53025 .43471 m .53007 .43735 L .52815 .4335 L F
.724 .948 .952 r
.69187 .38332 m .69102 .38228 L .68741 .38435 L F
.925 .942 .791 r
.69416 .38006 m .69102 .38228 L .69187 .38332 L F
.427 .227 .505 r
.32486 .68667 m .32426 .6911 L .32301 .68919 L F
.343 0 .185 r
.32624 .68866 m .32486 .68667 L .32301 .68919 L F
.32624 .68866 m .32655 .68602 L .32486 .68667 L F
.634 .788 .34 r
.36466 .53645 m .36344 .53877 L .36359 .5385 L F
.101 0 .119 r
.36359 .5385 m .36246 .54062 L .36068 .54137 L F
.634 .788 .34 r
.36344 .53877 m .36246 .54062 L .36359 .5385 L F
0 0 0 r
.36391 .53793 m .36359 .5385 L .36043 .53928 L F
.36512 .53747 m .36359 .5385 L .36391 .53793 L F
.79 .953 .621 r
.36466 .53645 m .36512 .53747 L .36597 .53474 L F
.36466 .53645 m .36359 .5385 L .36512 .53747 L F
.432 .247 .529 r
.36523 .5395 m .36746 .53644 L .36512 .53747 L F
.397 .11 .356 r
.30856 .55635 m .31076 .55622 L .3115 .55274 L F
.355 .074 .342 r
.3115 .55274 m .31345 .55491 L .31463 .55335 L F
.3115 .55274 m .31076 .55622 L .31345 .55491 L F
.048 0 0 r
.35544 .72477 m .35318 .72466 L .35115 .72462 L F
.35544 .72477 m .35318 .72466 L .35115 .72462 L F
.295 .033 .334 r
.44166 .56594 m .44134 .56814 L .44376 .56534 L F
.508 .694 .953 r
.74633 .29889 m .74841 .29799 L .7473 .30047 L F
.74633 .29889 m .74841 .29799 L .7473 .30047 L F
.147 .688 .716 r
.33723 .50068 m .3337 .5013 L .33404 .50128 L F
.874 .803 .777 r
.61911 .3805 m .62061 .38001 L .61985 .37676 L F
.851 .716 .713 r
.61613 .3817 m .62061 .38001 L .61911 .3805 L F
.61613 .3817 m .61953 .38331 L .62061 .38001 L F
.958 .942 .71 r
.62061 .38001 m .62179 .37414 L .61985 .37676 L F
.747 .778 .878 r
.62609 .35534 m .62174 .3553 L .62437 .35353 L F
.82 .797 .83 r
.62613 .35341 m .62609 .35534 L .62437 .35353 L F
.31 .653 .97 r
.45407 .56156 m .45443 .56269 L .45477 .56099 L F
.784 .891 .478 r
.45477 .56099 m .45443 .56269 L .45301 .56475 L F
.973 .669 .37 r
.61081 .41153 m .61262 .41529 L .61149 .41401 L F
.955 .641 .22 r
.61149 .41401 m .61262 .41529 L .61295 .41775 L F
.837 .919 .889 r
.31726 .6315 m .31635 .63254 L .31453 .63191 L F
0 0 .488 r
.31635 .63254 m .31842 .63533 L .31723 .63345 L F
.31635 .63254 m .31723 .63345 L .31453 .63191 L F
.465 0 0 r
.38367 .59126 m .38416 .59162 L .38211 .59027 L F
.808 .945 .914 r
.65581 .38925 m .65116 .39105 L .65528 .38857 L F
.868 .995 .768 r
.65825 .38594 m .65581 .38925 L .65528 .38857 L F
.611 .435 .618 r
.35672 .55601 m .3557 .55768 L .3557 .55881 L F
.443 .752 .994 r
.35318 .55912 m .35569 .55964 L .3557 .55881 L F
0 0 .252 r
.35406 .56039 m .35318 .55912 L .3557 .55881 L F
.988 .821 .588 r
.35484 .55525 m .35406 .56039 L .3557 .55881 L F
.611 .435 .618 r
.3557 .55768 m .35406 .56039 L .3557 .55881 L F
.443 .752 .994 r
.35569 .55964 m .3569 .55988 L .3557 .55881 L F
.49 .776 .995 r
.3569 .55988 m .35962 .55944 L .3557 .55881 L F
.546 .506 .763 r
.3569 .55988 m .36057 .56201 L .35962 .55944 L F
.787 .718 .787 r
.64241 .41834 m .64379 .42208 L .64007 .42074 L F
.998 .843 .517 r
.64379 .42208 m .64248 .42294 L .64007 .42074 L F
0 0 .051 r
.64493 .41747 m .64379 .42208 L .64241 .41834 L F
0 0 0 r
.3596 .69425 m .36185 .69095 L .36225 .6925 L F
.887 .702 .646 r
.35619 .69356 m .3596 .69425 L .35831 .68948 L F
.821 .995 .859 r
.35739 .69478 m .3596 .69425 L .35619 .69356 L F
.552 .507 .759 r
.35831 .68948 m .3596 .69425 L .36098 .69254 L F
.816 .994 .863 r
.36098 .69254 m .35959 .69428 L .35739 .69478 L F
.821 .995 .859 r
.35739 .69478 m .35854 .69559 L .3596 .69425 L F
.816 .994 .863 r
.35959 .69428 m .35854 .69559 L .35809 .69528 L F
.35959 .69428 m .35809 .69528 L .35739 .69478 L F
0 0 0 r
.35968 .69422 m .36225 .6925 L .36245 .69328 L F
.3596 .69425 m .36225 .6925 L .35968 .69422 L F
.833 .781 .802 r
.63388 .36628 m .63724 .36729 L .63637 .36302 L F
.855 .751 .748 r
.63499 .37002 m .63724 .36729 L .63388 .36628 L F
.82 .773 .809 r
.63637 .36302 m .63724 .36729 L .6402 .36361 L F
0 0 .111 r
.35015 .56474 m .34894 .56551 L .35069 .56246 L F
.02 0 .422 r
.35015 .56474 m .34992 .56761 L .34894 .56551 L F
.862 .633 .098 r
.61468 .4245 m .61529 .42814 L .61476 .42603 L F
0 0 .031 r
.61529 .42814 m .6154 .42918 L .61476 .42603 L F
0 0 .423 r
.6154 .42918 m .61664 .43132 L .61545 .42906 L F
0 0 .031 r
.61529 .42814 m .61528 .42943 L .6154 .42918 L F
.726 .467 0 r
.61447 .4251 m .61501 .42747 L .61474 .42771 L F
.61501 .42747 m .6154 .42918 L .61474 .42771 L F
0 0 .423 r
.6154 .42918 m .61545 .42906 L .61474 .42771 L F
.908 .501 .177 r
.61592 .42969 m .61448 .42793 L .61474 .42771 L F
.61448 .42793 m .61329 .42649 L .61474 .42771 L F
0 0 .031 r
.61528 .42943 m .61528 .43058 L .6154 .42918 L F
.77 .791 .87 r
.61759 .35549 m .61902 .35741 L .61528 .35694 L F
.774 .787 .863 r
.61528 .35694 m .61902 .35741 L .6173 .35826 L F
.725 .778 .895 r
.62174 .3553 m .61902 .35741 L .61759 .35549 L F
.441 .123 .33 r
.3531 .546 m .3532 .54659 L .35078 .54712 L F
.466 .07 .203 r
.3532 .54659 m .35025 .54797 L .35078 .54712 L F
0 0 .023 r
.62726 .41325 m .62596 .41515 L .62733 .41165 L F
.052 .103 .597 r
.62781 .41779 m .62596 .41515 L .62726 .41325 L F
0 .171 .7 r
.62901 .41982 m .62596 .41515 L .62781 .41779 L F
.99 .731 .384 r
.61295 .41775 m .61419 .42154 L .61346 .42044 L F
.905 .613 .115 r
.61419 .42154 m .6137 .42292 L .61346 .42044 L F
.61419 .42154 m .61468 .4245 L .6137 .42292 L F
.897 .65 .139 r
.43009 .52732 m .43069 .52728 L .4286 .52708 L F
.992 .867 .602 r
.38967 .69376 m .39024 .69072 L .39112 .69325 L F
.531 .396 .642 r
.64185 .3992 m .64478 .40163 L .64471 .39894 L F
.64185 .3992 m .64251 .40302 L .64478 .40163 L F
.746 .651 .756 r
.35154 .57597 m .35324 .58041 L .35155 .57785 L F
.28 .208 .594 r
.35324 .58041 m .35177 .58147 L .35155 .57785 L F
.281 0 0 r
.24429 .56978 m .24867 .56783 L .24438 .56855 L F
.24429 .56978 m .24712 .57036 L .24867 .56783 L F
.342 .776 .968 r
.24867 .56783 m .2488 .56673 L .25103 .56751 L F
.64 .485 .657 r
.2488 .56673 m .24712 .57036 L .24867 .56783 L F
0 0 0 r
.61331 .38965 m .61631 .38748 L .61496 .38876 L F
.082 .326 .804 r
.61496 .38876 m .61574 .39138 L .61331 .38965 L F
.389 .074 .305 r
.3719 .67718 m .36934 .67783 L .36873 .68042 L F
.582 .696 .92 r
.58068 .42489 m .58067 .42115 L .57958 .42102 L F
.58068 .42489 m .58336 .42428 L .58067 .42115 L F
.399 .612 .936 r
.58067 .42115 m .58336 .42428 L .58505 .42246 L F
.39 .834 .939 r
.58302 .42379 m .58336 .42428 L .58068 .42489 L F
.58302 .42379 m .58068 .42489 L .57979 .42671 L F
0 .011 .547 r
.42866 .54773 m .42762 .54962 L .42715 .54773 L F
.314 .802 .786 r
.25638 .52124 m .26062 .52013 L .25866 .52136 L F
.595 .521 .742 r
.45338 .50087 m .4516 .50471 L .4508 .5016 L F
.45338 .50087 m .45397 .50386 L .4516 .50471 L F
.485 .32 .581 r
.45397 .50386 m .45178 .50886 L .4516 .50471 L F
.682 .766 .915 r
.72558 .34058 m .72871 .34145 L .7273 .33963 L F
.797 .662 .713 r
.72801 .34421 m .72871 .34145 L .72558 .34058 L F
.837 .806 .821 r
.7273 .33963 m .72871 .34145 L .73153 .33806 L F
.908 .968 .804 r
.55768 .4062 m .55895 .40766 L .55768 .40876 L F
.518 .449 .717 r
.71514 .35344 m .71482 .35775 L .71797 .35566 L F
.526 .442 .704 r
.71482 .35775 m .71682 .35845 L .71797 .35566 L F
.71482 .35775 m .71623 .36048 L .71682 .35845 L F
.556 .731 .957 r
.38639 .58808 m .38885 .58751 L .3869 .58463 L F
.88 .634 .561 r
.52928 .42793 m .52672 .42978 L .52704 .42711 L F
.52928 .42793 m .52927 .43117 L .52672 .42978 L F
.206 0 0 r
.29502 .55788 m .29746 .55752 L .2995 .55604 L F
.457 .828 .992 r
.29746 .55752 m .30248 .55772 L .29926 .55621 L F
.29982 .55761 m .30007 .557 L .30248 .55772 L F
.29746 .55752 m .30007 .557 L .29982 .55761 L F
.29926 .55621 m .30248 .55772 L .2995 .55604 L F
.801 .809 .858 r
.3006 .5555 m .3006 .55568 L .30007 .557 L F
.41 0 0 r
.30007 .557 m .30431 .55857 L .30248 .55772 L F
.885 .699 .645 r
.30051 .55919 m .30433 .55858 L .30007 .557 L F
.801 .809 .858 r
.3006 .55568 m .30051 .55919 L .30007 .557 L F
.41 0 0 r
.30431 .55857 m .30433 .55858 L .30248 .55772 L F
.832 .853 .862 r
.67617 .31291 m .67199 .31428 L .67541 .31191 L F
.898 .976 .811 r
.67869 .30961 m .67617 .31291 L .67541 .31191 L F
.728 .336 0 r
.28262 .64293 m .28342 .64395 L .28406 .64538 L F
.016 .275 .774 r
.28342 .64395 m .28416 .64606 L .28627 .6476 L F
.728 .336 0 r
.28336 .64432 m .28406 .64538 L .2847 .64683 L F
.28262 .64293 m .28406 .64538 L .28336 .64432 L F
0 .206 .71 r
.28482 .64654 m .2867 .64873 L .28627 .6476 L F
.28416 .64606 m .28527 .64723 L .28482 .64654 L F
.28527 .64723 m .2867 .64873 L .28482 .64654 L F
.722 .431 0 r
.28627 .6476 m .2867 .64873 L .28735 .65127 L F
.624 .323 .439 r
.42541 .58925 m .42623 .59 L .42302 .58832 L F
.196 .41 .844 r
.42644 .59168 m .42302 .58832 L .42623 .59 L F
.694 .801 .931 r
.6173 .35826 m .61303 .35787 L .61528 .35694 L F
.339 .094 .389 r
.32605 .60654 m .32328 .60977 L .32375 .60738 L F
.208 .388 .822 r
.36068 .54137 m .35966 .54349 L .35815 .53934 L F
.42 .11 .331 r
.35938 .54564 m .36228 .54309 L .35966 .54349 L F
.559 .54 .789 r
.36068 .54137 m .35938 .54564 L .35966 .54349 L F
.273 .535 .916 r
.42184 .60043 m .41803 .59811 L .42275 .59878 L F
.074 0 .128 r
.42184 .60043 m .42275 .59878 L .42432 .59766 L F
.495 .461 .748 r
.31453 .52749 m .31613 .53046 L .31387 .53078 L F
.4 .101 .337 r
.31613 .53046 m .31328 .53288 L .31387 .53078 L F
.572 .444 .667 r
.45441 .49128 m .45563 .49482 L .45278 .49537 L F
.525 .361 .601 r
.45563 .49482 m .45306 .49828 L .45278 .49537 L F
.754 .469 .5 r
.2958 .64616 m .29734 .64732 L .29521 .6486 L F
.2958 .64616 m .29935 .64871 L .29734 .64732 L F
.645 .29 .355 r
.34383 .55928 m .34601 .56148 L .34236 .56144 L F
.144 .246 .712 r
.34621 .55658 m .34383 .55928 L .3438 .5541 L F
0 .172 .707 r
.34597 .55925 m .34383 .55928 L .34621 .55658 L F
.708 .322 .315 r
.35298 .51021 m .34876 .51181 L .34887 .51098 L F
.35298 .51021 m .35058 .51259 L .34876 .51181 L F
.748 .377 .35 r
.3545 .51281 m .35298 .51021 L .35498 .50996 L F
.3545 .51281 m .35058 .51259 L .35298 .51021 L F
.66 .835 .418 r
.68525 .35901 m .68614 .35781 L .68502 .35959 L F
.821 .962 .901 r
.68687 .35509 m .68912 .35526 L .68614 .35781 L F
.552 .424 .66 r
.45306 .49828 m .45338 .50087 L .4508 .5016 L F
.603 .573 .794 r
.4555 .48178 m .45417 .48594 L .45307 .48232 L F
.4555 .48178 m .45682 .48543 L .45417 .48594 L F
.587 .48 .699 r
.45682 .48543 m .45456 .48876 L .45417 .48594 L F
0 0 .561 r
.70717 .30625 m .7086 .30822 L .70917 .30977 L F
.814 .678 .133 r
.70893 .3101 m .70917 .30977 L .7086 .30822 L F
.70893 .3101 m .70903 .31232 L .70917 .30977 L F
.969 .667 .393 r
.24058 .61946 m .23882 .61872 L .23869 .61609 L F
.677 .133 0 r
.24048 .61946 m .23882 .61872 L .24058 .61946 L F
0 0 0 r
.35087 .59706 m .35201 .59487 L .35334 .59318 L F
.926 .544 .157 r
.60002 .41509 m .59792 .41131 L .59821 .4139 L F
.954 .647 .413 r
.60009 .41739 m .60002 .41509 L .59821 .4139 L F
.797 .504 .494 r
.70802 .31593 m .70242 .31504 L .70234 .3127 L F
.789 .481 .467 r
.70802 .31593 m .70276 .31739 L .70242 .31504 L F
.70802 .31593 m .70656 .31808 L .70276 .31739 L F
.211 .733 .847 r
.28477 .52125 m .28018 .52145 L .28205 .5226 L F
.649 .527 .701 r
.37719 .59409 m .37816 .59012 L .37636 .59158 L F
.798 .385 .266 r
.23299 .59326 m .23363 .59165 L .23264 .59083 L F
.23299 .59326 m .23566 .59471 L .23363 .59165 L F
.1 0 .175 r
.69205 .31196 m .69263 .31011 L .69469 .30873 L F
.373 .678 .976 r
.38715 .61409 m .38523 .61423 L .38384 .61274 L F
.38715 .61409 m .38523 .61423 L .38384 .61274 L F
.776 .846 .905 r
.6975 .30357 m .70101 .30344 L .69983 .30172 L F
.899 .814 .755 r
.69983 .30172 m .70101 .30344 L .70184 .30056 L F
.898 .976 .811 r
.67869 .30961 m .67541 .31191 L .67815 .30871 L F
.858 .956 .611 r
.68053 .30525 m .67869 .30961 L .67815 .30871 L F
.793 .543 .56 r
.70969 .28659 m .70989 .28412 L .70603 .28345 L F
.714 .254 .158 r
.35573 .52434 m .3515 .52299 L .35237 .52504 L F
.318 .228 .594 r
.30885 .54035 m .31084 .53943 L .31071 .53613 L F
.192 0 0 r
.30885 .54035 m .31021 .54098 L .31084 .53943 L F
.30885 .54035 m .3067 .54141 L .31021 .54098 L F
.785 .997 .796 r
.68369 .30309 m .68053 .30525 L .6834 .30237 L F
.68 .926 .616 r
.68649 .29985 m .68369 .30309 L .68526 .3007 L F
.719 .988 .871 r
.68526 .3007 m .68369 .30309 L .6834 .30237 L F
.89 .911 .834 r
.59931 .38104 m .60086 .38228 L .59797 .38554 L F
.844 .916 .882 r
.60359 .37927 m .60086 .38228 L .59931 .38104 L F
.837 .799 .815 r
.46078 .47062 m .45915 .47282 L .45679 .47197 L F
.453 .116 .304 r
.46125 .4735 m .45679 .47197 L .45915 .47282 L F
.492 .351 .616 r
.4452 .55265 m .44779 .55238 L .44749 .54923 L F
.183 .036 .435 r
.70091 .30859 m .70177 .30894 L .70172 .30655 L F
0 0 .273 r
.70091 .30859 m .70178 .3109 L .70177 .30894 L F
.70091 .30859 m .70234 .3127 L .70178 .3109 L F
.821 .378 .185 r
.4078 .50333 m .40947 .50578 L .41143 .50495 L F
.526 .905 .737 r
.41143 .50495 m .41294 .50353 L .41324 .50352 L F
.41143 .50495 m .40947 .50578 L .41294 .50353 L F
.701 .635 .78 r
.29365 .64122 m .29507 .64324 L .2914 .64234 L F
.525 .452 .716 r
.29658 .6385 m .29507 .64324 L .29365 .64122 L F
.29658 .6385 m .29673 .6427 L .29507 .64324 L F
0 .017 .529 r
.27236 .62009 m .27443 .62215 L .27517 .62304 L F
0 .114 .605 r
.27443 .62215 m .2772 .62473 L .27517 .62304 L F
0 0 .544 r
.31115 .63856 m .31071 .63938 L .30946 .63581 L F
0 .152 .642 r
.3129 .64083 m .31071 .63938 L .31115 .63856 L F
.3129 .64083 m .31337 .64149 L .3121 .64049 L F
.3129 .64083 m .3121 .64049 L .31071 .63938 L F
0 0 .323 r
.31343 .64106 m .3129 .64083 L .31344 .63932 L F
0 .152 .642 r
.3129 .64083 m .31348 .64158 L .31337 .64149 L F
.464 .372 .666 r
.31348 .64158 m .31126 .64223 L .31071 .63938 L F
.232 .131 .528 r
.31301 .64417 m .31126 .64223 L .31348 .64158 L F
.956 .81 .37 r
.31301 .64417 m .31348 .64158 L .3129 .64083 L F
0 0 .323 r
.31342 .64307 m .3129 .64083 L .31343 .64106 L F
.788 .416 .353 r
.30977 .64233 m .3129 .64083 L .31115 .63856 L F
.784 .999 .832 r
.31243 .64015 m .3129 .64083 L .30977 .64233 L F
.31344 .63932 m .3129 .64083 L .31243 .64015 L F
.752 .971 .7 r
.38121 .70339 m .38407 .7001 L .38185 .70158 L F
0 0 0 r
.38429 .70046 m .38369 .70091 L .38185 .70158 L F
.752 .971 .7 r
.38121 .70339 m .38185 .70158 L .37971 .70236 L F
.793 .449 .406 r
.38358 .70532 m .38121 .70339 L .38378 .70546 L F
.481 0 0 r
.38378 .70546 m .38121 .70339 L .37969 .70234 L F
.685 .161 0 r
.38004 .7036 m .38126 .70419 L .37969 .70234 L F
.481 0 0 r
.38378 .70546 m .37969 .70234 L .38126 .70419 L F
0 0 0 r
.38369 .70091 m .38004 .7036 L .38185 .70158 L F
.752 .971 .7 r
.37971 .70236 m .38185 .70158 L .37969 .70234 L F
.436 .131 .348 r
.468 .57891 m .46722 .58084 L .46476 .58129 L F
.207 0 .233 r
.46999 .5778 m .46722 .58084 L .468 .57891 L F
.556 .498 .746 r
.45425 .52066 m .45184 .52143 L .45082 .51785 L F
.488 .394 .675 r
.45425 .52066 m .45231 .52408 L .45184 .52143 L F
.281 .735 .956 r
.32622 .51884 m .33172 .51993 L .32751 .51841 L F
.797 .662 .713 r
.72801 .34421 m .72558 .34058 L .72657 .34221 L F
.953 .889 .729 r
.72609 .34728 m .72801 .34421 L .72657 .34221 L F
.729 .775 .89 r
.70806 .33805 m .70584 .33963 L .70419 .33745 L F
.032 .55 .867 r
.32942 .53623 m .32938 .53583 L .32825 .53584 L F
.064 0 .444 r
.32825 .53584 m .32938 .53583 L .32932 .533 L F
.611 .943 .754 r
.32938 .53583 m .3284 .53623 L .32933 .53544 L F
.488 .855 .62 r
.32932 .533 m .33296 .53027 L .33072 .52917 L F
.32932 .533 m .32998 .53227 L .33296 .53027 L F
.32998 .53227 m .32998 .53226 L .32998 .53226 L F
.32998 .53227 m .32998 .53226 L .33296 .53027 L F
.798 .668 .72 r
.32998 .53226 m .33076 .53423 L .33439 .52969 L F
.3 .386 .784 r
.33179 .53232 m .33076 .53423 L .33004 .53221 L F
.604 .459 .658 r
.32648 .53005 m .32932 .533 L .33072 .52917 L F
.3 .386 .784 r
.33081 .53157 m .33004 .53221 L .32944 .53053 L F
0 0 0 r
.33296 .53027 m .32998 .53226 L .33439 .52969 L F
.3 .386 .784 r
.33179 .53232 m .33004 .53221 L .33081 .53157 L F
.18 .308 .759 r
.32938 .53583 m .33076 .53423 L .32998 .53226 L F
.611 .943 .754 r
.32938 .53583 m .32933 .53544 L .33076 .53423 L F
.032 .55 .867 r
.33255 .53728 m .32938 .53583 L .32942 .53623 L F
.771 .347 .242 r
.33451 .53629 m .32938 .53583 L .33255 .53728 L F
.314 .053 .349 r
.38346 .55921 m .38287 .56173 L .38068 .56237 L F
.579 .418 .628 r
.38287 .56173 m .38046 .56515 L .38068 .56237 L F
.605 .315 .45 r
.38346 .55921 m .38607 .56194 L .38287 .56173 L F
.692 .153 0 r
.38715 .56218 m .38607 .56194 L .38346 .55921 L F
.867 .826 .805 r
.52649 .44551 m .52823 .44694 L .5255 .44678 L F
.795 .545 .56 r
.52823 .44694 m .52437 .4489 L .5255 .44678 L F
.52823 .44694 m .5283 .44926 L .52437 .4489 L F
.86 .828 .815 r
.53069 .44374 m .52823 .44694 L .52649 .44551 L F
.804 .929 .916 r
.67158 .33571 m .67353 .33416 L .67218 .33302 L F
.874 .983 .834 r
.6693 .33608 m .67158 .33571 L .67218 .33302 L F
.357 .367 .733 r
.34489 .52072 m .34793 .52215 L .34762 .52058 L F
.34489 .52072 m .34635 .52455 L .34793 .52215 L F
.587 .637 .868 r
.60136 .36984 m .6009 .37367 L .59865 .37275 L F
.60136 .36984 m .60276 .37404 L .6009 .37367 L F
.749 .229 0 r
.59865 .37275 m .6009 .37367 L .60206 .37541 L F
.63 .212 .232 r
.6009 .37367 m .60276 .37404 L .60206 .37541 L F
.636 .816 .969 r
.43737 .54841 m .44056 .54865 L .43908 .54711 L F
.327 .788 .942 r
.44342 .54735 m .43908 .54711 L .44056 .54865 L F
.86 .828 .815 r
.53069 .44374 m .52649 .44551 L .52797 .4436 L F
.796 .8 .855 r
.65076 .35073 m .65445 .35119 L .65302 .34953 L F
.813 .803 .842 r
.65302 .34953 m .65445 .35119 L .65711 .34798 L F
.265 .48 .88 r
.27889 .62485 m .27804 .62663 L .2772 .62473 L F
.018 .162 .673 r
.28007 .62894 m .27804 .62663 L .27889 .62485 L F
0 0 .315 r
.21087 .56548 m .21243 .56424 L .21271 .5616 L F
0 0 .344 r
.21087 .56548 m .21224 .56692 L .21243 .56424 L F
.21087 .56548 m .21059 .56818 L .21224 .56692 L F
.77 .893 .486 r
.3288 .61659 m .32686 .62027 L .32757 .6188 L F
.296 .213 .59 r
.32686 .62027 m .32884 .62199 L .32757 .6188 L F
.462 .201 .432 r
.32629 .62259 m .32884 .62199 L .32686 .62027 L F
.32629 .62259 m .32884 .62199 L .32686 .62027 L F
.503 .576 .862 r
.26019 .57723 m .26123 .57711 L .26281 .57599 L F
.734 .908 .535 r
.61496 .38876 m .61631 .38748 L .61773 .38502 L F
.488 .394 .675 r
.45425 .52066 m .45465 .52351 L .45231 .52408 L F
.571 .513 .751 r
.45587 .52691 m .45231 .52408 L .45465 .52351 L F
.468 .314 .587 r
.29403 .54648 m .29403 .54923 L .29595 .54793 L F
.591 .269 .393 r
.29403 .54648 m .29595 .54793 L .29703 .54648 L F
.468 .314 .587 r
.29403 .54648 m .29403 .54923 L .29595 .54793 L F
.925 .942 .791 r
.69416 .38006 m .69327 .37881 L .69102 .38228 L F
0 0 .422 r
.69384 .36881 m .69408 .37152 L .69277 .37366 L F
0 0 .01 r
.69277 .37366 m .69346 .37368 L .69339 .37632 L F
.69277 .37366 m .69408 .37152 L .69346 .37368 L F
.976 .737 .32 r
.69339 .37632 m .69327 .37881 L .69416 .38006 L F
.837 .806 .821 r
.7273 .33963 m .73153 .33806 L .73131 .33574 L F
.931 .958 .646 r
.3682 .63764 m .36854 .63963 L .36712 .64168 L F
0 0 0 r
.3596 .69425 m .36245 .69328 L .36098 .69254 L F
.769 .687 .772 r
.36245 .69328 m .35854 .69559 L .36098 .69254 L F
.328 .142 .469 r
.36663 .58203 m .36464 .58149 L .3632 .58101 L F
.36663 .58203 m .36458 .58442 L .36464 .58149 L F
.775 .761 .84 r
.65914 .40499 m .66239 .4051 L .66196 .40198 L F
.821 .791 .824 r
.66239 .4051 m .66521 .40192 L .66196 .40198 L F
.743 .59 .685 r
.36817 .60239 m .37058 .60145 L .36931 .60365 L F
.262 .094 .455 r
.31531 .5968 m .31705 .59646 L .31739 .59397 L F
.464 .301 .574 r
.31531 .5968 m .31756 .59983 L .31705 .59646 L F
.31531 .5968 m .31538 .60088 L .31756 .59983 L F
.79 .517 .523 r
.22731 .55211 m .22986 .55417 L .22861 .55282 L F
.22986 .55417 m .23005 .55421 L .22861 .55282 L F
.22668 .55177 m .22928 .55376 L .22731 .55211 L F
.22928 .55376 m .23073 .55487 L .22731 .55211 L F
.489 .264 .499 r
.22861 .55282 m .23074 .55488 L .23104 .55228 L F
.742 .405 .412 r
.2305 .55346 m .22928 .55376 L .22668 .55177 L F
.22928 .55376 m .22658 .55441 L .22668 .55177 L F
.79 .517 .523 r
.22668 .55177 m .23074 .55488 L .23073 .55487 L F
.729 .629 .746 r
.22953 .54868 m .2305 .55346 L .22668 .55177 L F
.742 .405 .412 r
.22928 .55376 m .22927 .55378 L .22658 .55441 L F
.79 .517 .523 r
.22857 .55395 m .22658 .55441 L .22923 .55471 L F
.2293 .55377 m .22923 .55471 L .22979 .55415 L F
.742 .405 .412 r
.2293 .55377 m .22927 .55378 L .22928 .55376 L F
.79 .517 .523 r
.22668 .55177 m .22857 .55395 L .2293 .55377 L F
.22857 .55395 m .22923 .55471 L .2293 .55377 L F
.724 .497 .581 r
.22923 .55471 m .22651 .55697 L .22658 .55441 L F
.23074 .55488 m .22821 .55613 L .22923 .55471 L F
.22821 .55613 m .22651 .55697 L .22923 .55471 L F
.742 .405 .412 r
.22974 .55414 m .22895 .55485 L .22927 .55378 L F
.899 .986 .735 r
.22886 .55394 m .22895 .55485 L .22947 .55438 L F
.22966 .55412 m .22947 .55438 L .22974 .55414 L F
.22886 .55394 m .22947 .55438 L .22966 .55412 L F
.742 .405 .412 r
.22974 .55414 m .22927 .55378 L .2293 .55377 L F
.22927 .55378 m .22895 .55485 L .22658 .55441 L F
.79 .517 .523 r
.22668 .55177 m .22658 .55441 L .22857 .55395 L F
.22979 .55415 m .22923 .55471 L .23074 .55488 L F
.899 .986 .735 r
.22938 .55267 m .22886 .55394 L .23049 .55346 L F
.742 .405 .412 r
.2305 .55346 m .22974 .55414 L .22928 .55376 L F
.899 .986 .735 r
.22886 .55394 m .22974 .55414 L .2305 .55346 L F
0 0 0 r
.23085 .55808 m .22963 .55837 L .23242 .55546 L F
.724 .497 .581 r
.23074 .55488 m .23085 .55808 L .22651 .55697 L F
.22651 .55697 m .23085 .55808 L .23074 .55488 L F
.639 .531 .716 r
.2298 .55542 m .22658 .55441 L .22895 .55485 L F
0 .26 .769 r
.22854 .55277 m .22895 .55485 L .2287 .55217 L F
.22854 .55277 m .2298 .55542 L .22895 .55485 L F
.639 .531 .716 r
.2298 .55542 m .22651 .55697 L .22658 .55441 L F
.991 .862 .607 r
.22865 .55301 m .22757 .55595 L .2298 .55542 L F
.22854 .55277 m .22844 .5531 L .22865 .55301 L F
.22844 .5531 m .22757 .55595 L .22865 .55301 L F
.899 .986 .735 r
.22889 .55231 m .22877 .55295 L .22938 .55267 L F
.2287 .55217 m .23049 .55346 L .23049 .55346 L F
0 0 .185 r
.22988 .54983 m .2305 .55346 L .22953 .54868 L F
.899 .986 .735 r
.2287 .55217 m .22889 .55231 L .22988 .54983 L F
.22889 .55231 m .2305 .55346 L .22988 .54983 L F
.22889 .55231 m .22988 .54983 L .22988 .54983 L F
0 0 .179 r
.23102 .55097 m .23033 .55341 L .22868 .55282 L F
.22873 .5527 m .22868 .55282 L .2286 .5528 L F
.23102 .55097 m .22868 .55282 L .22873 .5527 L F
.22867 .55268 m .2286 .5528 L .22854 .55277 L F
.899 .986 .735 r
.22873 .55257 m .22877 .55295 L .22889 .55231 L F
0 0 .179 r
.23102 .55097 m .2286 .5528 L .22867 .55268 L F
.899 .986 .735 r
.2287 .55217 m .22873 .55257 L .22889 .55231 L F
.22877 .55295 m .22886 .55394 L .22938 .55267 L F
.23049 .55346 m .23049 .55346 L .2305 .55346 L F
.79 .517 .523 r
.22986 .55417 m .23073 .55487 L .23005 .55421 L F
0 .359 .825 r
.3678 .50795 m .37042 .50926 L .37058 .51045 L F
0 0 .459 r
.37042 .50926 m .37209 .51306 L .37058 .51045 L F
.819 .774 .811 r
.63637 .36302 m .6402 .36361 L .64018 .36104 L F
.535 .399 .642 r
.61918 .37351 m .61985 .37676 L .61679 .37685 L F
.718 .92 .575 r
.61918 .37351 m .61679 .37685 L .61985 .37676 L F
.619 .521 .722 r
.45724 .48802 m .45456 .48876 L .45682 .48543 L F
.642 .53 .712 r
.45724 .48802 m .45441 .49128 L .45456 .48876 L F
.528 .409 .661 r
.32607 .57196 m .32891 .57134 L .32812 .56839 L F
.477 .278 .531 r
.326 .57487 m .32891 .57134 L .32607 .57196 L F
.404 .283 .6 r
.35192 .55275 m .35424 .55495 L .35429 .55219 L F
.35192 .55275 m .35226 .55596 L .35424 .55495 L F
.674 .96 .736 r
.61842 .39113 m .61714 .39305 L .61574 .39138 L F
.61842 .39113 m .6203 .39017 L .61714 .39305 L F
.969 .674 .409 r
.41803 .59811 m .41945 .60159 L .41777 .60037 L F
.672 .901 .977 r
.41945 .60159 m .42042 .59948 L .41777 .60037 L F
.41945 .60159 m .42184 .60043 L .42042 .59948 L F
.426 .035 .191 r
.3035 .56003 m .30527 .56079 L .30301 .56114 L F
.401 .094 .326 r
.30625 .55856 m .30527 .56079 L .3035 .56003 L F
.585 .474 .694 r
.39112 .69325 m .38892 .69633 L .38967 .69376 L F
.862 .964 .633 r
.33591 .55863 m .33777 .55515 L .33747 .55673 L F
.597 .925 .966 r
.37683 .67064 m .37476 .67176 L .37393 .67147 L F
.819 .762 .8 r
.35318 .55912 m .35069 .56246 L .34945 .5594 L F
.5 .172 .342 r
.35248 .56409 m .35069 .56246 L .35295 .56176 L F
.35248 .56409 m .35015 .56474 L .35069 .56246 L F
.44 .238 .509 r
.35295 .56176 m .35069 .56246 L .35318 .55912 L F
0 0 .11 r
.29513 .62946 m .2929 .63284 L .29399 .63188 L F
0 0 .169 r
.29399 .63188 m .2929 .63284 L .29208 .6353 L F
.715 .541 .652 r
.71514 .35344 m .71079 .35067 L .71225 .35494 L F
.609 .633 .849 r
.70356 .28908 m .70512 .29264 L .70725 .29146 L F
.807 .995 .762 r
.41341 .48046 m .41279 .48156 L .41293 .48215 L F
.586 .929 .955 r
.41293 .48215 m .41279 .48156 L .41283 .48156 L F
.495 0 0 r
.40848 .48271 m .41293 .48215 L .40981 .48414 L F
.40848 .48271 m .41093 .48334 L .41293 .48215 L F
.81 .99 .738 r
.41293 .48215 m .41093 .48334 L .41276 .48121 L F
.41293 .48215 m .41283 .48156 L .41341 .48047 L F
.41283 .48156 m .41283 .48156 L .41284 .48154 L F
.41283 .48156 m .41284 .48154 L .41341 .48047 L F
.785 .944 .928 r
.41797 .47869 m .41284 .48154 L .41341 .48046 L F
.41284 .48154 m .41279 .48156 L .41341 .48046 L F
.41709 .48129 m .41283 .48156 L .41797 .47869 L F
.41283 .48156 m .41279 .48156 L .41284 .48154 L F
.41283 .48156 m .41284 .48154 L .41797 .47869 L F
.81 .99 .738 r
.41341 .48047 m .41276 .48121 L .41341 .48046 L F
.41283 .48156 m .41276 .48121 L .41341 .48047 L F
.586 .929 .955 r
.41293 .48215 m .41283 .48156 L .41709 .48129 L F
.785 .944 .928 r
.41709 .48129 m .41797 .47869 L .41951 .47995 L F
.399 .305 .632 r
.45698 .53264 m .45715 .53635 L .45497 .53689 L F
.433 .437 .764 r
.45715 .53635 m .45806 .53867 L .45497 .53689 L F
.51 .416 .685 r
.45497 .53689 m .45806 .53867 L .45545 .53945 L F
.77 .709 .794 r
.38068 .60729 m .37812 .60884 L .3769 .60608 L F
.527 .24 .422 r
.37812 .60884 m .38068 .60729 L .3769 .60608 L F
.37812 .60884 m .38049 .60986 L .38068 .60729 L F
.256 .026 .36 r
.38068 .60729 m .38049 .60986 L .38257 .60659 L F
.855 .693 .162 r
.38049 .60986 m .38068 .60729 L .38257 .60659 L F
.16 0 .091 r
.33671 .59392 m .33354 .59676 L .33461 .59484 L F
.936 .865 .438 r
.28735 .65127 m .2871 .65544 L .28803 .65375 L F
0 .189 .721 r
.2871 .65544 m .28908 .6563 L .28803 .65375 L F
.2871 .65544 m .28973 .65788 L .28908 .6563 L F
.908 .747 .669 r
.64373 .42968 m .64697 .42759 L .64633 .42638 L F
.64373 .42968 m .64566 .43141 L .64697 .42759 L F
.987 .845 .47 r
.69851 .33192 m .69728 .33247 L .69891 .33037 L F
.69851 .33192 m .69806 .33528 L .69728 .33247 L F
.25 .085 .452 r
.70172 .30655 m .70384 .30755 L .70382 .30545 L F
.70172 .30655 m .70177 .30894 L .70384 .30755 L F
.554 .763 .975 r
.47012 .4669 m .4711 .4649 L .46844 .4654 L F
.535 .39 .631 r
.24627 .5703 m .24616 .57252 L .24712 .57036 L F
.24627 .5703 m .24418 .57397 L .24616 .57252 L F
.567 .083 0 r
.36635 .60042 m .36817 .60239 L .36658 .60049 L F
.468 .464 .771 r
.36931 .60365 m .3672 .60121 L .36817 .60239 L F
.743 .59 .685 r
.36817 .60239 m .37196 .6036 L .37119 .59976 L F
.911 .97 .796 r
.36942 .60483 m .37196 .6036 L .36817 .60239 L F
0 0 .497 r
.36877 .60112 m .36922 .60368 L .36817 .60239 L F
.36922 .60368 m .36942 .60483 L .36817 .60239 L F
.468 .464 .771 r
.3672 .60121 m .36658 .60049 L .36817 .60239 L F
.614 .789 .965 r
.34793 .52215 m .34875 .52387 L .3515 .52299 L F
.76 .536 .593 r
.34793 .52215 m .34862 .52455 L .34875 .52387 L F
.34793 .52215 m .34943 .52404 L .34862 .52455 L F
.34943 .52404 m .35081 .52579 L .34862 .52455 L F
0 0 .021 r
.34862 .52455 m .34652 .52719 L .34806 .5249 L F
.34862 .52455 m .34806 .5249 L .34875 .52387 L F
.511 .91 .911 r
.3469 .52858 m .34652 .52719 L .34862 .52455 L F
.3469 .52858 m .34615 .5298 L .34652 .52719 L F
.837 .799 .815 r
.46078 .47062 m .45679 .47197 L .4593 .46969 L F
.528 .889 .977 r
.4593 .46969 m .46335 .46931 L .46078 .47062 L F
.468 .332 .612 r
.45587 .52691 m .45597 .52986 L .45364 .53046 L F
.51 .474 .753 r
.45698 .53264 m .45364 .53046 L .45597 .52986 L F
.025 .542 .865 r
.60284 .36769 m .6031 .36837 L .60118 .36772 L F
.054 .081 .57 r
.60344 .36191 m .6031 .36837 L .60535 .36534 L F
.681 .97 .774 r
.60535 .36534 m .6031 .36837 L .60284 .36769 L F
.957 .943 .711 r
.36994 .66109 m .36979 .66224 L .36851 .66155 L F
.874 .671 .624 r
.61773 .38502 m .61953 .38331 L .61613 .3817 L F
.638 .929 .972 r
.41792 .51258 m .41871 .51373 L .41757 .51269 L F
.99 .754 .378 r
.41861 .51081 m .41925 .51355 L .4194 .51087 L F
.41925 .51355 m .4193 .51359 L .4194 .51087 L F
.638 .929 .972 r
.41897 .51341 m .41871 .51373 L .41822 .51302 L F
.56 .812 .993 r
.41897 .51341 m .4193 .51376 L .41871 .51373 L F
.998 .781 .474 r
.41897 .51341 m .4193 .51376 L .41925 .51355 L F
.41757 .51269 m .41925 .51355 L .41861 .51081 L F
.99 .754 .378 r
.41925 .51355 m .4193 .51376 L .4193 .51359 L F
.56 .812 .993 r
.42015 .51193 m .4193 .51376 L .41897 .51341 L F
.998 .781 .474 r
.41757 .51269 m .4193 .51376 L .41897 .51341 L F
.638 .929 .972 r
.419 .51337 m .41897 .51341 L .41792 .51258 L F
.41897 .51341 m .41822 .51302 L .41792 .51258 L F
.42015 .51193 m .419 .51337 L .41792 .51258 L F
.752 .994 .821 r
.42026 .5088 m .4194 .51087 L .42194 .5104 L F
.42026 .5088 m .41861 .51081 L .4194 .51087 L F
.87 .995 .782 r
.41985 .51376 m .4193 .51376 L .42194 .5104 L F
.281 .048 .372 r
.32467 .50484 m .32713 .50196 L .32683 .5042 L F
.514 .378 .633 r
.32471 .50748 m .32683 .5042 L .32467 .50484 L F
.281 .048 .372 r
.32467 .50484 m .32713 .50196 L .32683 .5042 L F
.514 .378 .633 r
.32471 .50748 m .32683 .5042 L .32467 .50484 L F
.06 .284 .773 r
.33172 .51993 m .33232 .51978 L .3317 .52098 L F
.662 .972 .886 r
.3317 .52098 m .33232 .51978 L .33486 .5191 L F
.951 .625 .208 r
.39611 .54823 m .39765 .55172 L .39731 .54932 L F
.997 .849 .563 r
.39672 .54565 m .39611 .54823 L .39731 .54932 L F
.437 .194 .446 r
.45577 .47932 m .4555 .48178 L .45307 .48232 L F
.565 .557 .803 r
.45817 .47849 m .45577 .47932 L .45415 .47486 L F
.522 .265 .466 r
.4582 .4806 m .4555 .48178 L .45577 .47932 L F
.478 .305 .568 r
.45817 .47849 m .4582 .4806 L .45577 .47932 L F
.828 .602 .597 r
.51949 .45039 m .51965 .45353 L .51715 .45128 L F
.269 0 0 r
.51805 .45173 m .51949 .45039 L .51715 .45128 L F
.681 .599 .758 r
.52211 .44993 m .51965 .45353 L .51949 .45039 L F
.135 0 0 r
.52211 .44993 m .51949 .45039 L .51805 .45173 L F
.265 0 0 r
.24654 .61996 m .24484 .62024 L .24048 .61946 L F
.151 .434 .871 r
.24654 .61996 m .24709 .61841 L .24484 .62024 L F
.24654 .61996 m .24922 .6214 L .24709 .61841 L F
.727 .762 .881 r
.38442 .55225 m .38186 .5545 L .38035 .55174 L F
.837 .919 .889 r
.31726 .6315 m .31453 .63191 L .31471 .63126 L F
.218 .692 .939 r
.31905 .6309 m .31726 .6315 L .31471 .63126 L F
.31905 .6309 m .32159 .63169 L .31726 .6315 L F
.868 .995 .768 r
.65825 .38594 m .65528 .38857 L .65819 .38559 L F
.683 .796 .333 r
.6601 .38175 m .65825 .38594 L .65819 .38559 L F
.971 .669 .284 r
.57165 .41755 m .56961 .41627 L .56957 .41878 L F
.103 0 .151 r
.57165 .41755 m .56957 .41878 L .56887 .42066 L F
.784 .519 .536 r
.39142 .58708 m .39564 .58473 L .39148 .58485 L F
.39142 .58708 m .3959 .58745 L .39564 .58473 L F
.977 .683 .309 r
.39564 .58473 m .39465 .58667 L .39635 .58312 L F
.39564 .58473 m .3959 .58745 L .39465 .58667 L F
.241 0 .306 r
.42897 .50824 m .4284 .51041 L .43105 .50719 L F
.639 .248 .287 r
.3798 .65194 m .38327 .6517 L .38071 .65218 L F
.735 .552 .645 r
.38081 .65524 m .38365 .65413 L .38327 .6517 L F
.618 .821 .414 r
.38515 .64881 m .38327 .6517 L .38656 .65027 L F
.613 .389 .553 r
.38612 .65396 m .38327 .6517 L .38365 .65413 L F
.38612 .65396 m .38656 .65027 L .38327 .6517 L F
.696 .429 0 r
.62077 .40015 m .62064 .39958 L .6198 .39618 L F
.372 .015 .223 r
.46476 .58129 m .4636 .58391 L .46121 .58453 L F
.488 .127 .278 r
.46676 .58299 m .46476 .58129 L .46722 .58084 L F
.46676 .58299 m .4636 .58391 L .46476 .58129 L F
.744 .978 .731 r
.69838 .35875 m .69717 .36096 L .69874 .35905 L F
0 0 0 r
.69657 .36322 m .69717 .36096 L .69838 .35875 L F
.768 .721 .808 r
.33783 .50928 m .33538 .51074 L .33941 .51105 L F
.333 0 .092 r
.45528 .51654 m .45364 .51748 L .45082 .51785 L F
.556 .498 .746 r
.45425 .52066 m .45082 .51785 L .45364 .51748 L F
.423 .594 .914 r
.25049 .62364 m .25142 .62116 L .24922 .6214 L F
.25049 .62364 m .25224 .62317 L .25142 .62116 L F
.673 .803 .945 r
.43721 .46987 m .43318 .46944 L .43574 .46843 L F
.727 .796 .906 r
.43981 .46872 m .43721 .46987 L .43574 .46843 L F
.59 .487 .705 r
.33959 .57467 m .34017 .5781 L .33758 .57877 L F
.642 .53 .712 r
.45724 .48802 m .45819 .4917 L .45441 .49128 L F
.622 .449 .628 r
.45819 .4917 m .45563 .49482 L .45441 .49128 L F
.675 .731 .892 r
.33988 .6947 m .33493 .6933 L .33745 .69477 L F
.796 .316 .078 r
.33745 .69477 m .34099 .69651 L .33988 .6947 L F
.848 .472 .338 r
.3411 .6989 m .34326 .69672 L .34099 .69651 L F
.34099 .69651 m .34326 .69672 L .3411 .6989 L F
0 0 .239 r
.3413 .69826 m .34099 .69651 L .3411 .6989 L F
.621 .36 .501 r
.34326 .69672 m .34077 .69523 L .34099 .69651 L F
.994 .752 .416 r
.34212 .69263 m .34326 .69672 L .34099 .69651 L F
0 0 .239 r
.34253 .69439 m .34099 .69651 L .3413 .69826 L F
.621 .36 .501 r
.34077 .69523 m .33988 .6947 L .34099 .69651 L F
0 0 .03 r
.33656 .6912 m .336 .69063 L .33605 .68901 L F
.33656 .6912 m .33493 .6933 L .336 .69063 L F
.503 .679 .944 r
.70728 .34827 m .71079 .35067 L .70957 .34691 L F
.67 .655 .827 r
.71079 .35067 m .71338 .34767 L .70957 .34691 L F
.71079 .35067 m .71434 .34975 L .71338 .34767 L F
.475 .26 .507 r
.71768 .35401 m .71727 .3512 L .71514 .35344 L F
.71727 .3512 m .71717 .35053 L .71628 .35181 L F
.715 .541 .652 r
.71514 .35344 m .71621 .35214 L .71079 .35067 L F
.76 .649 .738 r
.71434 .34975 m .71621 .35214 L .71717 .35053 L F
.896 .857 .795 r
.71717 .35053 m .71621 .35214 L .71514 .35344 L F
.475 .26 .507 r
.71727 .3512 m .71628 .35181 L .71514 .35344 L F
.667 .628 .801 r
.71079 .35067 m .7159 .35205 L .71434 .34975 L F
.7159 .35205 m .71621 .35214 L .71606 .35195 L F
.7159 .35205 m .71606 .35195 L .71434 .34975 L F
.759 .648 .739 r
.5283 .44926 m .52996 .45351 L .52589 .45316 L F
.788 .574 .612 r
.52996 .45351 m .52569 .45558 L .52589 .45316 L F
.52996 .45351 m .53016 .45674 L .52569 .45558 L F
.714 .626 .758 r
.53263 .45019 m .52996 .45351 L .5283 .44926 L F
.727 .445 .5 r
.52996 .45351 m .534 .45606 L .53016 .45674 L F
.82 .75 .786 r
.66224 .34388 m .66642 .34201 L .66479 .34047 L F
.929 .963 .769 r
.66642 .34201 m .66787 .33787 L .66479 .34047 L F
.158 .451 .881 r
.34064 .70078 m .3411 .6989 L .339 .69915 L F
.34064 .70078 m .3436 .70209 L .3411 .6989 L F
.734 .274 .159 r
.40469 .4895 m .40308 .49063 L .40169 .48849 L F
.121 .626 .901 r
.40756 .49158 m .40308 .49063 L .40469 .4895 L F
0 0 .388 r
.20963 .57194 m .2106 .57103 L .21059 .56818 L F
0 0 .328 r
.20942 .57451 m .2106 .57103 L .20963 .57194 L F
.214 0 0 r
.30039 .63398 m .30106 .63452 L .29963 .63568 L F
.30039 .63398 m .30392 .63332 L .30106 .63452 L F
.806 .995 .864 r
.38311 .56456 m .38607 .56194 L .38715 .56218 L F
.607 .948 .922 r
.38715 .56218 m .38607 .56194 L .38818 .56072 L F
.38715 .56218 m .38607 .56194 L .38818 .56072 L F
0 .033 .573 r
.34335 .52602 m .34481 .52802 L .34284 .52587 L F
.422 0 .069 r
.34227 .52659 m .3436 .5261 L .34335 .52602 L F
0 0 0 r
.34635 .52455 m .34481 .52802 L .34793 .52215 L F
.896 .845 .786 r
.34793 .52215 m .34481 .52802 L .34335 .52602 L F
.505 .511 .797 r
.3469 .52858 m .34335 .52602 L .34599 .52522 L F
.028 .179 .687 r
.34505 .52648 m .34335 .52602 L .34599 .52522 L F
.422 0 .069 r
.3436 .5261 m .34599 .52522 L .34335 .52602 L F
0 .033 .573 r
.34335 .52602 m .34284 .52587 L .34194 .52489 L F
.771 .347 .242 r
.33451 .53629 m .33243 .53829 L .32938 .53583 L F
.435 .537 .862 r
.33451 .53629 m .33664 .53539 L .33486 .53523 L F
.257 .089 .452 r
.33451 .53629 m .33466 .53943 L .33664 .53539 L F
.879 .822 .788 r
.33664 .53539 m .33243 .53829 L .33451 .53629 L F
.435 .537 .862 r
.33451 .53629 m .33664 .53539 L .33486 .53523 L F
.775 .685 .764 r
.26601 .5299 m .26766 .53364 L .2702 .53031 L F
0 0 0 r
.33163 .61348 m .3288 .61659 L .33068 .61554 L F
.179 0 .29 r
.3288 .61659 m .33044 .61815 L .33068 .61554 L F
.3288 .61659 m .32757 .6188 L .33044 .61815 L F
.984 .724 .452 r
.23605 .56714 m .23785 .56832 L .2377 .56553 L F
.644 .432 .581 r
.35112 .69022 m .35506 .68948 L .35336 .68735 L F
.82 .994 .861 r
.35622 .6837 m .35336 .68735 L .35644 .68622 L F
.673 .611 .778 r
.35506 .68948 m .35644 .68622 L .35336 .68735 L F
0 0 .565 r
.62763 .41073 m .62733 .41165 L .62628 .40791 L F
0 0 0 r
.62726 .41325 m .62733 .41165 L .62763 .41073 L F
0 0 .186 r
.4309 .56371 m .43045 .56237 L .42924 .561 L F
.4309 .56371 m .43094 .56508 L .43045 .56237 L F
.625 .635 .84 r
.46405 .55237 m .46234 .55528 L .46153 .55316 L F
.555 .591 .844 r
.46501 .55467 m .46234 .55528 L .46405 .55237 L F
.767 .508 .542 r
.53644 .45632 m .54043 .45671 L .54027 .45926 L F
.824 .588 .581 r
.54043 .45671 m .54255 .45997 L .54027 .45926 L F
.984 .877 .646 r
.39876 .60607 m .39978 .60399 L .39763 .60531 L F
.928 .964 .769 r
.39885 .60317 m .39978 .60399 L .40188 .60053 L F
.962 .94 .695 r
.39763 .60531 m .39978 .60399 L .39885 .60317 L F
0 0 0 r
.68834 .29802 m .68879 .29644 L .68649 .29985 L F
.475 .843 .601 r
.69095 .29465 m .69214 .29383 L .68879 .29644 L F
0 0 0 r
.69095 .29465 m .68879 .29644 L .68834 .29802 L F
.472 .858 .65 r
.33987 .67629 m .34165 .67525 L .33883 .67719 L F
.914 .591 .418 r
.3446 .67906 m .34493 .67807 L .34308 .67628 L F
.288 0 0 r
.34348 .6761 m .34165 .67525 L .33987 .67629 L F
.34368 .67609 m .34359 .67605 L .34348 .6761 L F
.34368 .67609 m .33987 .67629 L .34254 .67575 L F
.914 .591 .418 r
.34292 .67635 m .34308 .67628 L .34254 .67575 L F
.3446 .67906 m .34308 .67628 L .34292 .67635 L F
.288 0 0 r
.34359 .67605 m .34165 .67525 L .34348 .6761 L F
.347 0 .09 r
.34456 .67478 m .34165 .67525 L .34368 .67609 L F
.706 .387 .434 r
.3408 .60661 m .3429 .60897 L .3405 .60872 L F
.3408 .60661 m .34366 .60731 L .3429 .60897 L F
.899 .814 .755 r
.69983 .30172 m .70184 .30056 L .70245 .29899 L F
.818 .841 .866 r
.60214 .35648 m .59986 .3586 L .59847 .35682 L F
.938 .837 .718 r
.59986 .3586 m .59919 .36023 L .59847 .35682 L F
.825 .778 .808 r
.66196 .40198 m .66521 .40192 L .66433 .39886 L F
.858 .931 .873 r
.66521 .40192 m .66702 .39795 L .66433 .39886 L F
.66521 .40192 m .66818 .39905 L .66702 .39795 L F
.503 .816 1 r
.36249 .57452 m .36073 .57342 L .36002 .57509 L F
.443 .329 .629 r
.36002 .57509 m .3626 .57728 L .36249 .57452 L F
.3626 .57728 m .36002 .57509 L .36073 .57342 L F
.3626 .57728 m .36043 .57821 L .36002 .57509 L F
.36002 .57509 m .36043 .57821 L .3626 .57728 L F
.426 .258 .549 r
.38001 .63023 m .38137 .63237 L .37931 .62896 L F
.38001 .63023 m .37902 .63334 L .38137 .63237 L F
.694 .229 .143 r
.25983 .62799 m .25662 .62844 L .25445 .62627 L F
.599 .94 .939 r
.25961 .62699 m .25983 .62799 L .26074 .62733 L F
.25961 .62699 m .25662 .62844 L .25983 .62799 L F
.083 0 0 r
.31303 .55844 m .31236 .55839 L .31036 .55818 L F
.424 .579 .903 r
.31036 .55818 m .31236 .55839 L .31076 .55622 L F
.272 0 .207 r
.31076 .55622 m .31015 .55807 L .3124 .55592 L F
.31076 .55622 m .3124 .55592 L .31345 .55491 L F
.424 .579 .903 r
.30879 .55659 m .31076 .55622 L .30856 .55635 L F
.31036 .55818 m .31076 .55622 L .30879 .55659 L F
.859 .857 .837 r
.28477 .52125 m .28746 .51999 L .28656 .51895 L F
.877 .768 .737 r
.71099 .33231 m .70705 .33406 L .70667 .33189 L F
.71099 .33231 m .71012 .33466 L .70705 .33406 L F
.928 .964 .769 r
.39885 .60317 m .40188 .60053 L .40086 .59999 L F
.99 .89 .586 r
.40195 .59616 m .40086 .59999 L .40188 .60053 L F
.551 .156 .248 r
.35338 .53167 m .35659 .5327 L .35698 .53114 L F
.622 .394 .55 r
.35338 .53167 m .35678 .53526 L .35659 .5327 L F
.35338 .53167 m .35368 .53615 L .35678 .53526 L F
.925 .873 .447 r
.6126 .44883 m .61389 .44664 L .61336 .44556 L F
.6126 .44883 m .61298 .4502 L .61389 .44664 L F
.452 .196 .434 r
.42763 .53346 m .42716 .53593 L .42475 .53649 L F
.349 .107 .399 r
.4297 .53484 m .42763 .53346 L .42959 .53354 L F
.4297 .53484 m .42716 .53593 L .42763 .53346 L F
.647 .139 .026 r
.39236 .58008 m .39402 .57906 L .39544 .58057 L F
.582 .364 .549 r
.61918 .37351 m .62236 .37281 L .62195 .37033 L F
0 0 0 r
.61918 .37351 m .62195 .37033 L .62126 .37229 L F
.428 .213 .483 r
.62453 .36708 m .62195 .37033 L .62429 .37009 L F
0 0 0 r
.6244 .36841 m .62195 .37033 L .62453 .36708 L F
.457 .61 .913 r
.6244 .36841 m .62195 .37033 L .62429 .37009 L F
.442 .269 .55 r
.62195 .37033 m .62236 .37281 L .62429 .37009 L F
0 0 .303 r
.62195 .37033 m .62236 .37281 L .62277 .37034 L F
.62195 .37033 m .62277 .37034 L .62126 .37229 L F
0 0 .252 r
.35406 .56039 m .35295 .56176 L .35318 .55912 L F
.299 .635 .964 r
.59919 .36023 m .6029 .36177 L .60317 .36201 L F
.102 0 0 r
.60344 .36191 m .60317 .36201 L .6029 .36177 L F
.784 .997 .798 r
.66335 .37943 m .6601 .38175 L .66317 .37904 L F
.813 .999 .844 r
.6644 .37683 m .66335 .37943 L .66317 .37904 L F
.631 .649 .85 r
.71717 .35053 m .72122 .35189 L .72108 .35023 L F
.676 .617 .782 r
.72122 .35189 m .71717 .35053 L .72108 .35023 L F
.454 .59 .898 r
.72122 .35189 m .72172 .34914 L .72108 .35023 L F
.363 .754 .987 r
.72253 .35122 m .72122 .35189 L .72108 .35023 L F
0 0 0 r
.34585 .54278 m .34719 .54152 L .3484 .53932 L F
.752 .518 .577 r
.34422 .54417 m .34719 .54153 L .34585 .54278 L F
.34719 .54153 m .34719 .54152 L .34719 .54153 L F
.34719 .54153 m .34719 .54153 L .34585 .54278 L F
.34422 .54417 m .34756 .54492 L .34719 .54152 L F
.305 .71 .977 r
.34595 .5435 m .34422 .54417 L .34273 .54132 L F
.961 .831 .67 r
.3459 .54231 m .34602 .54392 L .34756 .54492 L F
.449 .439 .755 r
.3459 .54219 m .34595 .5435 L .34273 .54132 L F
.961 .831 .67 r
.34569 .54198 m .34595 .5435 L .3459 .54231 L F
.34595 .5435 m .34602 .54392 L .3459 .54231 L F
.449 .439 .755 r
.34477 .53894 m .3459 .54219 L .34273 .54132 L F
.3459 .54219 m .34647 .54386 L .34595 .5435 L F
.305 .71 .977 r
.34647 .54386 m .34602 .54392 L .34595 .5435 L F
.34602 .54392 m .34422 .54417 L .34595 .5435 L F
.961 .831 .67 r
.34587 .54152 m .3459 .54231 L .34756 .54492 L F
.458 .444 .755 r
.34587 .54152 m .34647 .54386 L .3459 .54219 L F
.34587 .54152 m .3459 .54219 L .34477 .53894 L F
.961 .831 .67 r
.34587 .54152 m .34569 .54198 L .3459 .54231 L F
.34569 .54198 m .34514 .54335 L .34602 .54392 L F
.305 .71 .977 r
.34602 .54392 m .34756 .54492 L .34422 .54417 L F
.448 0 .031 r
.34323 .54597 m .34756 .54492 L .34422 .54417 L F
0 0 0 r
.34459 .54475 m .34422 .54417 L .34756 .54492 L F
.961 .831 .67 r
.34514 .54335 m .34459 .54475 L .34756 .54492 L F
.305 .71 .977 r
.34647 .54386 m .34756 .54492 L .34602 .54392 L F
.972 .69 .282 r
.34611 .54244 m .34756 .54492 L .34647 .54386 L F
.34587 .54152 m .34626 .54231 L .34611 .54244 L F
.34626 .54231 m .34756 .54492 L .34611 .54244 L F
.758 .965 .931 r
.69107 .3536 m .68912 .35526 L .68687 .35509 L F
.89 .911 .834 r
.59931 .38104 m .59797 .38554 L .59684 .38446 L F
.522 .103 .187 r
.34231 .56408 m .3462 .56146 L .34236 .56144 L F
.34231 .56408 m .34552 .56405 L .3462 .56146 L F
0 0 0 r
.3462 .56146 m .3481 .56078 L .34945 .5594 L F
.38 .15 .436 r
.34552 .56405 m .34772 .56092 L .3462 .56146 L F
.336 .069 .353 r
.34552 .56405 m .34601 .56148 L .34673 .56232 L F
.34552 .56405 m .34673 .56232 L .3475 .56321 L F
.38 .15 .436 r
.34552 .56405 m .3481 .56078 L .34772 .56092 L F
.76 .649 .738 r
.71434 .34975 m .71717 .35053 L .71603 .34681 L F
.564 .71 .939 r
.71717 .35053 m .71886 .34785 L .71603 .34681 L F
.71717 .35053 m .72108 .35023 L .71886 .34785 L F
.522 .195 .354 r
.7203 .35261 m .71717 .35053 L .71768 .35401 L F
.7203 .35261 m .72108 .35023 L .71717 .35053 L F
.889 .565 .43 r
.4296 .57073 m .43201 .56864 L .43002 .56761 L F
.4296 .57073 m .43327 .57232 L .43201 .56864 L F
.927 .766 .661 r
.43002 .56761 m .43201 .56864 L .43094 .56508 L F
.885 .95 .846 r
.38914 .59259 m .39083 .59205 L .389 .59361 L F
.838 .979 .876 r
.3928 .5893 m .39083 .59205 L .38914 .59259 L F
.415 .226 .514 r
.72223 .29647 m .72466 .29269 L .72184 .29353 L F
.72223 .29647 m .72466 .29269 L .72184 .29353 L F
0 0 .296 r
.32669 .52692 m .32553 .5243 L .32932 .52396 L F
0 0 0 r
.32953 .52444 m .32932 .52396 L .33088 .5253 L F
.32953 .52444 m .32669 .52692 L .32932 .52396 L F
0 0 .045 r
.31155 .62175 m .3094 .62502 L .31012 .62255 L F
.673 .813 .368 r
.23355 .54405 m .23642 .54294 L .23482 .54269 L F
.698 .966 .936 r
.23683 .54128 m .23482 .54269 L .23642 .54294 L F
.141 .645 .906 r
.43486 .59023 m .43381 .59072 L .43187 .59099 L F
.43486 .59023 m .43638 .59103 L .43381 .59072 L F
.43381 .59072 m .43486 .59023 L .43187 .59099 L F
.43381 .59072 m .43638 .59103 L .43486 .59023 L F
.437 .262 .545 r
.29486 .53669 m .29711 .53607 L .29759 .53326 L F
.309 .166 .519 r
.23617 .57761 m .2342 .58117 L .23388 .57841 L F
.839 .382 0 r
.35489 .71173 m .35757 .7142 L .3588 .71755 L F
.58 .91 .976 r
.27096 .52877 m .26854 .52983 L .2702 .53031 L F
.2702 .53031 m .26854 .52983 L .27096 .52877 L F
.908 .515 .247 r
.37929 .51775 m .37988 .51961 L .38179 .52037 L F
0 0 .308 r
.3824 .52152 m .38179 .52037 L .37988 .51961 L F
.833 .402 .211 r
.38179 .52037 m .38288 .52292 L .38576 .52367 L F
0 0 .308 r
.3824 .52152 m .38288 .52292 L .38179 .52037 L F
.967 .719 .507 r
.23104 .55228 m .23074 .55488 L .23242 .55546 L F
0 0 0 r
.23085 .55808 m .23242 .55546 L .23074 .55488 L F
.56 .545 .795 r
.23242 .55546 m .23357 .55151 L .23104 .55228 L F
.23242 .55546 m .23442 .55506 L .23357 .55151 L F
0 0 0 r
.36023 .60045 m .36014 .60225 L .36144 .6002 L F
.36023 .60045 m .35961 .60349 L .36014 .60225 L F
.916 .968 .666 r
.41553 .49498 m .41608 .49586 L .41679 .49818 L F
0 0 .24 r
.41679 .49818 m .41858 .49406 L .41711 .49368 L F
.41679 .49818 m .41823 .49738 L .41858 .49406 L F
.101 0 0 r
.41679 .49818 m .41519 .50039 L .41759 .49942 L F
.774 .397 .342 r
.31362 .61982 m .31589 .62259 L .31155 .62175 L F
.679 .407 .504 r
.31623 .61983 m .31589 .62259 L .31362 .61982 L F
.721 .255 0 r
.40103 .52718 m .3999 .52618 L .39842 .52375 L F
.718 .357 0 r
.40103 .52718 m .40129 .52824 L .3999 .52618 L F
0 .008 .537 r
.40129 .52824 m .40331 .53038 L .40234 .5291 L F
.40129 .52824 m .40234 .5291 L .40105 .52813 L F
.40129 .52824 m .40105 .52813 L .39948 .52696 L F
.718 .357 0 r
.40103 .52718 m .40149 .52833 L .40129 .52824 L F
.40149 .52833 m .40201 .52961 L .40129 .52824 L F
.823 .607 .61 r
.35025 .54797 m .34637 .55081 L .34746 .54883 L F
.425 .001 .128 r
.6314 .39913 m .63367 .4002 L .63144 .40142 L F
.455 .881 .795 r
.63337 .40032 m .63144 .40142 L .63367 .4002 L F
.263 .095 .455 r
.63144 .40142 m .63008 .40219 L .6314 .39913 L F
.63144 .40142 m .6297 .40308 L .63008 .40219 L F
.702 .803 .928 r
.63144 .40142 m .6297 .40308 L .62504 .40258 L F
.63144 .40142 m .62504 .40258 L .63053 .39813 L F
.455 .881 .795 r
.62965 .40181 m .63144 .40142 L .63337 .40032 L F
.522 .73 .969 r
.63271 .3969 m .63416 .39892 L .6314 .39913 L F
.677 .924 .972 r
.63271 .3969 m .6314 .39913 L .63053 .39813 L F
.425 .001 .128 r
.6314 .39913 m .63416 .39892 L .63367 .4002 L F
.139 .154 .613 r
.20994 .59157 m .212 .59263 L .21151 .58996 L F
.20994 .59157 m .21046 .59437 L .212 .59263 L F
.535 .503 .767 r
.39905 .67786 m .40193 .67715 L .4004 .67356 L F
.506 .389 .655 r
.39905 .67786 m .4018 .67997 L .40193 .67715 L F
.537 .872 .606 r
.68834 .29802 m .68649 .29985 L .68526 .3007 L F
.668 .972 .816 r
.66967 .39709 m .66818 .39905 L .66999 .39742 L F
.576 .848 .996 r
.66702 .39795 m .66818 .39905 L .66967 .39709 L F
.097 .583 .905 r
.33949 .49457 m .33916 .4953 L .33727 .49519 L F
.33949 .49457 m .34139 .49567 L .33916 .4953 L F
.677 .133 0 r
.24048 .61946 m .24065 .62062 L .23882 .61872 L F
.582 .111 .101 r
.24484 .62024 m .24065 .62062 L .24048 .61946 L F
.731 .336 .301 r
.54436 .46293 m .54823 .46347 L .54857 .46524 L F
.73 .329 .29 r
.54823 .46347 m .55248 .46571 L .54857 .46524 L F
.894 .573 .433 r
.38288 .52292 m .38345 .52562 L .38576 .52367 L F
.775 .379 .303 r
.38576 .52367 m .38345 .52562 L .38664 .5261 L F
.582 .532 .764 r
.38587 .58029 m .38829 .58435 L .38488 .58435 L F
.701 .984 .87 r
.38927 .58353 m .38829 .58435 L .38861 .58478 L F
.38829 .58435 m .38794 .58464 L .38801 .58466 L F
.38829 .58435 m .38801 .58466 L .38861 .58478 L F
.38954 .58301 m .38794 .58464 L .38927 .58353 L F
.432 .464 .793 r
.38954 .58301 m .3885 .5847 L .38829 .58435 L F
.38954 .58301 m .38829 .58435 L .38587 .58029 L F
.582 .532 .764 r
.38829 .58435 m .3885 .5847 L .38794 .58464 L F
.38829 .58435 m .38794 .58464 L .38488 .58435 L F
.701 .984 .87 r
.38954 .58301 m .38715 .58448 L .38794 .58464 L F
.573 .045 0 r
.38861 .58478 m .38488 .58435 L .38794 .58464 L F
.701 .984 .87 r
.38715 .58448 m .3869 .58463 L .38861 .58478 L F
.573 .045 0 r
.38861 .58478 m .38794 .58464 L .3885 .5847 L F
.681 .882 .506 r
.38861 .58478 m .3885 .5847 L .38954 .58301 L F
.626 .293 .388 r
.39142 .58708 m .38861 .58478 L .38885 .58751 L F
.39142 .58708 m .39148 .58485 L .38861 .58478 L F
.256 0 .169 r
.32823 .68596 m .32655 .68602 L .32624 .68866 L F
.286 0 0 r
.37719 .59409 m .38049 .59367 L .3798 .59331 L F
.847 .942 .884 r
.38049 .59367 m .38211 .59027 L .3798 .59331 L F
.974 .697 .44 r
.33015 .62849 m .33184 .62948 L .33172 .63255 L F
.125 .603 .916 r
.3333 .62924 m .33184 .62948 L .33015 .62849 L F
.01 0 .353 r
.33172 .63255 m .33184 .62948 L .3333 .62924 L F
.945 .812 .683 r
.6031 .37109 m .60276 .37404 L .60136 .36984 L F
.766 .339 .235 r
.6031 .37109 m .60531 .3731 L .60276 .37404 L F
.55 .259 .426 r
.60531 .3731 m .60206 .37541 L .60276 .37404 L F
.458 .887 .838 r
.38407 .7001 m .38627 .69922 L .38531 .69911 L F
.452 .837 .613 r
.38185 .70158 m .38407 .7001 L .38531 .69911 L F
.754 .946 .943 r
.37008 .64127 m .3741 .63932 L .37224 .63862 L F
.494 .86 .626 r
.37637 .63346 m .37752 .63283 L .37485 .63484 L F
0 0 0 r
.37637 .63346 m .37485 .63484 L .37396 .63573 L F
.004 .217 .728 r
.37482 .63765 m .3724 .63538 L .37485 .63484 L F
0 0 0 r
.37457 .63517 m .37396 .63573 L .37311 .63657 L F
.819 .745 .782 r
.37752 .63283 m .37784 .63492 L .37485 .63484 L F
0 0 0 r
.37637 .63346 m .37396 .63573 L .37457 .63517 L F
.004 .217 .728 r
.37482 .63765 m .3741 .63932 L .37295 .63664 L F
.37336 .63627 m .37295 .63664 L .3724 .63538 L F
.37482 .63765 m .37295 .63664 L .37336 .63627 L F
.592 .905 .983 r
.37224 .63862 m .3741 .63932 L .37482 .63765 L F
.993 .87 .601 r
.40118 .59253 m .40222 .5937 L .40308 .591 L F
.989 .85 .483 r
.40264 .58535 m .40229 .59012 L .40308 .591 L F
.973 .928 .639 r
.40308 .591 m .40229 .59012 L .40118 .59253 L F
.851 .749 .75 r
.71012 .33466 m .70611 .33635 L .70705 .33406 L F
.71012 .33466 m .70806 .33805 L .70611 .33635 L F
.647 .72 .902 r
.32389 .53521 m .3214 .53649 L .31966 .53407 L F
.553 .374 .593 r
.31913 .61655 m .31937 .61933 L .31623 .61983 L F
.588 .364 .544 r
.31937 .61933 m .31589 .62259 L .31623 .61983 L F
.852 .903 .49 r
.70049 .35528 m .70003 .35785 L .70155 .35413 L F
.876 .993 .768 r
.69874 .35905 m .70003 .35785 L .70049 .35528 L F
.546 .568 .828 r
.38656 .65027 m .38832 .64799 L .38515 .64881 L F
.38656 .65027 m .38972 .65248 L .38832 .64799 L F
.781 .313 .128 r
.38801 .65355 m .38656 .65027 L .38612 .65396 L F
.38801 .65355 m .38972 .65248 L .38656 .65027 L F
.875 .932 .856 r
.67218 .33302 m .67353 .33416 L .67624 .33101 L F
.574 .729 .948 r
.45525 .4682 m .4593 .46969 L .45745 .46966 L F
.246 .475 .881 r
.25224 .62317 m .25445 .62627 L .25537 .62465 L F
.046 .206 .707 r
.25445 .62627 m .25662 .62844 L .25537 .62465 L F
.223 .052 .426 r
.22747 .56516 m .22713 .56782 L .22549 .56856 L F
.481 .17 .362 r
.34047 .68348 m .33622 .68709 L .33357 .68331 L F
.34047 .68348 m .33825 .68748 L .33622 .68709 L F
.631 .336 .451 r
.34047 .68348 m .34275 .68617 L .33825 .68748 L F
.658 .336 .416 r
.34047 .68348 m .34405 .68431 L .34275 .68617 L F
.654 .167 .083 r
.33232 .51978 m .33697 .52046 L .33486 .5191 L F
.37 .721 .988 r
.37114 .68284 m .37335 .68384 L .37062 .68353 L F
.37062 .68353 m .37335 .68384 L .37114 .68284 L F
.38 .383 .737 r
.46819 .55813 m .46706 .56256 L .46626 .55822 L F
.46819 .55813 m .46984 .56332 L .46706 .56256 L F
.338 .424 .803 r
.46984 .56332 m .47019 .56428 L .46706 .56256 L F
.221 0 .299 r
.6268 .36629 m .62711 .36382 L .62453 .36708 L F
.388 .38 .729 r
.62453 .36708 m .6276 .36842 L .6268 .36629 L F
.505 .276 .501 r
.62429 .37009 m .6276 .36842 L .62453 .36708 L F
.533 .007 0 r
.62453 .36708 m .6276 .36842 L .6244 .36841 L F
.221 0 .299 r
.6268 .36629 m .62711 .36382 L .62453 .36708 L F
.388 .38 .729 r
.62453 .36708 m .6276 .36842 L .6268 .36629 L F
.44 .227 .493 r
.63851 .43107 m .64125 .43073 L .64109 .42782 L F
.338 0 0 r
.61122 .36847 m .6141 .3691 L .61093 .3688 L F
.679 .844 .427 r
.68609 .31741 m .68501 .31948 L .68696 .31622 L F
.546 .885 .636 r
.68696 .31622 m .69001 .31367 L .68877 .31444 L F
0 0 0 r
.68877 .31444 m .68609 .31741 L .68696 .31622 L F
.95 .793 .652 r
.42642 .58539 m .42575 .58116 L .42493 .58364 L F
.99 .875 .617 r
.42478 .58591 m .42642 .58539 L .42493 .58364 L F
.887 .658 .139 r
.70234 .3127 m .70242 .31504 L .70178 .3109 L F
.804 .869 .895 r
.32608 .52544 m .32669 .52692 L .32953 .52444 L F
0 0 .296 r
.32669 .52692 m .32722 .52818 L .32553 .5243 L F
.804 .869 .895 r
.32548 .52562 m .32669 .52692 L .32608 .52544 L F
0 0 .296 r
.32669 .52692 m .32732 .52842 L .32722 .52818 L F
.732 .991 .852 r
.66651 .37646 m .66976 .37385 L .66704 .37597 L F
.477 .841 .59 r
.66834 .37489 m .66976 .37385 L .66651 .37646 L F
.6 .835 .457 r
.70155 .35413 m .70407 .35077 L .7031 .35193 L F
.745 .972 .927 r
.70486 .34861 m .70407 .35077 L .70728 .34827 L F
.749 .876 .459 r
.7031 .35193 m .70407 .35077 L .70486 .34861 L F
.688 .645 .802 r
.61256 .37893 m .61911 .3805 L .61549 .38111 L F
.713 .491 .587 r
.61515 .38275 m .61613 .3817 L .61565 .38064 L F
.61459 .3852 m .61613 .3817 L .61515 .38275 L F
.373 0 0 r
.61613 .3817 m .61911 .3805 L .6169 .38087 L F
.61613 .3817 m .6169 .38087 L .61549 .38111 L F
.61613 .3817 m .61911 .3805 L .61549 .38111 L F
.619 .871 .99 r
.40291 .48471 m .39914 .48446 L .40337 .4822 L F
.957 .627 .345 r
.40169 .48849 m .39914 .48446 L .40291 .48471 L F
.736 .888 .949 r
.40614 .4835 m .40349 .48236 L .40617 .48068 L F
.79 .922 .925 r
.40349 .48236 m .40524 .47911 L .40617 .48068 L F
.40349 .48236 m .40343 .48234 L .40524 .47911 L F
.40343 .48234 m .40185 .48179 L .40235 .48139 L F
.40343 .48234 m .40235 .48139 L .40524 .47911 L F
.615 .867 .99 r
.40359 .4824 m .40337 .4822 L .40349 .48236 L F
.40614 .4835 m .40517 .48387 L .40337 .4822 L F
.40517 .48387 m .40291 .48471 L .40336 .48228 L F
.40517 .48387 m .40336 .48228 L .40337 .4822 L F
.824 .559 .539 r
.54255 .45997 m .54019 .46196 L .54027 .45926 L F
.54255 .45997 m .54257 .46214 L .54019 .46196 L F
.829 .524 .473 r
.54255 .45997 m .54436 .46293 L .54257 .46214 L F
.529 .458 .72 r
.45863 .54285 m .45545 .53945 L .45806 .53867 L F
.45863 .54285 m .45641 .54361 L .45545 .53945 L F
.444 .661 .953 r
.60577 .358 m .60214 .35648 L .60476 .35555 L F
.588 .635 .865 r
.60725 .35489 m .60577 .358 L .60476 .35555 L F
.60725 .35489 m .60859 .35717 L .60577 .358 L F
.304 .349 .743 r
.29374 .62505 m .29513 .62946 L .29637 .62814 L F
0 0 0 r
.29637 .62814 m .29513 .62946 L .29399 .63188 L F
.383 .46 .816 r
.21153 .60218 m .20988 .60499 L .21203 .60378 L F
.45 .095 .27 r
.27172 .57191 m .26886 .57384 L .26946 .57133 L F
0 0 0 r
.29698 .65562 m .29971 .65454 L .29907 .65468 L F
.076 0 .3 r
.29971 .65454 m .30248 .65118 L .30173 .65377 L F
.269 .766 .716 r
.29907 .65468 m .29971 .65454 L .30173 .65377 L F
0 .532 .707 r
.31609 .55868 m .31236 .55839 L .31303 .55844 L F
.843 .996 .834 r
.42812 .47386 m .42914 .47131 L .43028 .47225 L F
.42812 .47386 m .42623 .47434 L .42914 .47131 L F
.334 .816 .813 r
.29615 .51702 m .29763 .5168 L .29886 .5163 L F
.329 .512 .885 r
.34912 .60949 m .34977 .61097 L .34704 .60829 L F
.851 .759 .761 r
.34445 .60782 m .34704 .60829 L .34588 .60643 L F
0 0 0 r
.34588 .60643 m .34533 .60717 L .34445 .60782 L F
.739 .819 .914 r
.34704 .60829 m .3429 .60897 L .34445 .60782 L F
.682 .162 0 r
.34445 .60782 m .34912 .60949 L .34704 .60829 L F
0 0 0 r
.34453 .60758 m .34445 .60782 L .3429 .60897 L F
.739 .819 .914 r
.34445 .60782 m .3429 .60897 L .34419 .60777 L F
.682 .162 0 r
.34419 .60777 m .34444 .60786 L .34445 .60782 L F
.34444 .60786 m .34912 .60949 L .34445 .60782 L F
0 0 0 r
.34588 .60643 m .34445 .60782 L .34453 .60758 L F
.851 .759 .761 r
.34419 .60777 m .34445 .60782 L .34588 .60643 L F
.682 .162 0 r
.34462 .60785 m .34912 .60949 L .34704 .60829 L F
.34445 .60782 m .34465 .60793 L .34462 .60785 L F
.34419 .60777 m .34444 .60786 L .34445 .60782 L F
.34444 .60786 m .34465 .60793 L .34445 .60782 L F
.34465 .60793 m .34912 .60949 L .34462 .60785 L F
.533 .54 .808 r
.3429 .60897 m .34704 .61267 L .34431 .60798 L F
0 0 0 r
.34445 .60782 m .34444 .60786 L .3429 .60897 L F
.77 .63 .706 r
.34431 .60798 m .34704 .61267 L .34444 .60786 L F
0 0 0 r
.34444 .60786 m .34442 .6079 L .34431 .60798 L F
.34444 .60786 m .34431 .60798 L .3429 .60897 L F
.77 .63 .706 r
.34444 .60786 m .34704 .61267 L .34912 .60949 L F
.34419 .60777 m .34431 .60798 L .34444 .60786 L F
.533 .54 .808 r
.3429 .60897 m .34431 .60798 L .34419 .60777 L F
0 0 0 r
.34442 .6079 m .34417 .60868 L .3429 .60897 L F
.34533 .60717 m .34422 .60866 L .34417 .60868 L F
.34533 .60717 m .34417 .60868 L .34445 .60782 L F
.187 0 .172 r
.3429 .60897 m .34366 .60731 L .34435 .60704 L F
.34453 .60758 m .34435 .60704 L .34588 .60643 L F
.3429 .60897 m .34435 .60704 L .34453 .60758 L F
.67 .945 .685 r
.54098 .41429 m .53746 .41718 L .54006 .41599 L F
.54098 .41429 m .54006 .41599 L .53986 .4134 L F
.885 .976 .83 r
.5436 .41075 m .54098 .41429 L .53986 .4134 L F
.968 .646 .312 r
.59821 .4139 m .59792 .41131 L .59645 .41038 L F
.611 .759 .95 r
.39792 .4971 m .39686 .49976 L .39384 .49921 L F
.601 .766 .958 r
.39686 .49976 m .40046 .49976 L .39991 .49867 L F
.444 0 0 r
.33808 .56388 m .33995 .56463 L .33575 .56413 L F
.615 .856 .493 r
.70049 .35528 m .70155 .35413 L .7031 .35193 L F
.488 .838 .567 r
.36117 .59016 m .35996 .59127 L .3633 .58842 L F
.032 .224 .728 r
.32529 .69268 m .32663 .69605 L .3278 .69637 L F
0 0 0 r
.24885 .61611 m .24896 .61658 L .25149 .61542 L F
.24885 .61611 m .24787 .61739 L .24896 .61658 L F
.232 .645 .958 r
.24992 .61587 m .24896 .61658 L .24724 .61444 L F
.25008 .61596 m .24896 .61658 L .24992 .61587 L F
0 0 0 r
.24787 .61739 m .24709 .61841 L .24896 .61658 L F
.338 0 .135 r
.3405 .60872 m .33684 .61016 L .3375 .60952 L F
.466 .176 .388 r
.36746 .53644 m .3706 .5358 L .37069 .53321 L F
.179 .117 .545 r
.37069 .53321 m .37259 .53217 L .37218 .52937 L F
.012 0 .284 r
.37069 .53321 m .37195 .53465 L .37259 .53217 L F
.37069 .53321 m .3706 .5358 L .37195 .53465 L F
.038 0 0 r
.22963 .55837 m .22848 .55903 L .22623 .55951 L F
0 0 0 r
.23085 .55808 m .22848 .55903 L .22963 .55837 L F
.79 .886 .914 r
.64034 .34556 m .63595 .34676 L .63896 .34402 L F
.828 .865 .873 r
.64212 .34395 m .64034 .34556 L .63896 .34402 L F
.35 0 0 r
.56696 .46921 m .56819 .47024 L .56587 .46931 L F
0 .397 .842 r
.56767 .46987 m .56587 .46931 L .56819 .47024 L F
.281 0 0 r
.56696 .46921 m .56587 .46931 L .56469 .46895 L F
0 .397 .842 r
.56432 .46748 m .56587 .46931 L .56767 .46987 L F
.281 0 0 r
.56469 .46895 m .56587 .46931 L .56296 .46875 L F
.35 0 0 r
.56696 .46921 m .56989 .46969 L .56819 .47024 L F
.969 .674 .409 r
.41803 .59811 m .41777 .60037 L .4178 .59726 L F
.966 .82 .395 r
.69729 .34472 m .69617 .3461 L .69703 .34224 L F
.69729 .34472 m .69681 .34737 L .69617 .3461 L F
.499 .373 .64 r
.41858 .49406 m .42169 .49373 L .4208 .49156 L F
.334 .029 .29 r
.41823 .49738 m .42169 .49373 L .41858 .49406 L F
.938 .955 .645 r
.38124 .70882 m .38212 .70863 L .38358 .70532 L F
.38124 .70882 m .38358 .70532 L .38378 .70546 L F
.32 0 .022 r
.33068 .61554 m .33522 .61274 L .33163 .61348 L F
.615 .049 0 r
.26414 .61876 m .26823 .62069 L .2662 .62005 L F
.362 .535 .891 r
.42959 .53354 m .43151 .53664 L .43289 .53469 L F
.34 .042 .305 r
.42961 .53807 m .43289 .53469 L .43151 .53664 L F
0 0 .497 r
.38715 .61409 m .38827 .6169 L .38827 .61603 L F
.806 .786 .285 r
.38827 .61603 m .38827 .6169 L .38794 .61759 L F
.221 0 .056 r
.29888 .54534 m .30225 .54298 L .29995 .54364 L F
.637 .919 .637 r
.37858 .7119 m .38212 .70863 L .38124 .70882 L F
.893 .613 .506 r
.60118 .36772 m .6031 .37109 L .60284 .36769 L F
.809 .549 0 r
.62731 .42674 m .62773 .42978 L .625 .43122 L F
.556 .512 .762 r
.62773 .42978 m .62548 .43387 L .625 .43122 L F
0 0 .312 r
.24171 .53772 m .24079 .53844 L .24174 .53739 L F
.511 0 0 r
.24355 .53843 m .24079 .53844 L .24167 .53801 L F
0 0 .312 r
.24152 .54015 m .24079 .53844 L .24171 .53772 L F
.462 .865 .696 r
.24079 .53844 m .23884 .53983 L .23982 .53919 L F
.24079 .53844 m .23982 .53919 L .24167 .53801 L F
.191 .123 .546 r
.24079 .53844 m .24045 .54179 L .23884 .53983 L F
.478 .483 .785 r
.45934 .5451 m .45641 .54361 L .45863 .54285 L F
.907 .941 .581 r
.68238 .32232 m .68357 .32243 L .68303 .32028 L F
.68238 .32232 m .68206 .32543 L .68357 .32243 L F
.927 .959 .778 r
.68303 .32028 m .68357 .32243 L .68501 .31948 L F
.752 .528 .593 r
.5708 .41267 m .56736 .41672 L .56961 .41627 L F
.971 .669 .284 r
.57165 .41755 m .5708 .41267 L .56961 .41627 L F
.752 .528 .593 r
.5708 .41267 m .57165 .41755 L .56736 .41672 L F
.114 0 0 r
.5708 .41267 m .57439 .41142 L .57423 .41437 L F
.538 .384 .62 r
.57423 .41437 m .57165 .41755 L .5708 .41267 L F
.818 .982 .7 r
.38965 .60957 m .39178 .60583 L .39117 .60761 L F
.728 .673 .796 r
.45016 .47217 m .45168 .47615 L .44758 .47522 L F
.664 .639 .815 r
.45415 .47486 m .45168 .47615 L .45016 .47217 L F
.925 .596 .397 r
.37397 .60235 m .3769 .60608 L .37659 .60429 L F
.921 .969 .779 r
.31749 .53442 m .31593 .53673 L .31544 .53443 L F
.122 .672 .753 r
.31544 .53443 m .31966 .53407 L .31749 .53442 L F
.929 .944 .784 r
.64248 .42294 m .64109 .42782 L .6412 .4268 L F
.531 .295 .502 r
.64109 .42782 m .64306 .42627 L .6412 .4268 L F
.64109 .42782 m .64373 .42968 L .64306 .42627 L F
.64109 .42782 m .64125 .43073 L .64373 .42968 L F
.564 .809 .991 r
.62847 .36172 m .62711 .36382 L .62989 .36243 L F
.216 0 .298 r
.62989 .36243 m .62711 .36382 L .6268 .36629 L F
0 0 .095 r
.6268 .36629 m .62711 .36382 L .62847 .36172 L F
.558 .828 .996 r
.39048 .5042 m .3879 .50494 L .38632 .50366 L F
.825 .843 .862 r
.36942 .60483 m .37089 .61023 L .37003 .60679 L F
.531 0 0 r
.37014 .52836 m .37218 .52937 L .36809 .52885 L F
.357 .81 .684 r
.57479 .40995 m .57526 .40958 L .57439 .41142 L F
.57479 .40995 m .57601 .40935 L .57526 .40958 L F
.781 .429 0 r
.40066 .56323 m .40062 .562 L .39976 .56058 L F
.40066 .56323 m .40148 .56485 L .40062 .562 L F
.623 .416 .581 r
.31126 .64223 m .31155 .6456 L .30867 .64489 L F
.232 .131 .528 r
.31301 .64417 m .31155 .6456 L .31126 .64223 L F
.722 .218 .033 r
.58768 .38919 m .58969 .38941 L .58878 .39065 L F
.973 .69 .288 r
.58878 .39065 m .58969 .38941 L .58984 .39187 L F
.978 .726 .485 r
.58406 .38187 m .58589 .38604 L .58518 .38494 L F
.851 .398 .008 r
.58589 .38604 m .58537 .38675 L .58518 .38494 L F
.58589 .38604 m .58768 .38919 L .58537 .38675 L F
.999 .832 .531 r
.59919 .36023 m .59795 .35963 L .59907 .35967 L F
.073 .454 .883 r
.59919 .36023 m .60305 .36094 L .59795 .35963 L F
.183 0 0 r
.59795 .35963 m .60156 .36058 L .59648 .35958 L F
.59795 .35963 m .59648 .35958 L .59575 .35944 L F
.999 .832 .531 r
.59907 .35967 m .59795 .35963 L .59847 .35682 L F
.073 .454 .883 r
.59919 .36023 m .60317 .36201 L .60305 .36094 L F
.824 .462 .37 r
.52605 .42495 m .52387 .42648 L .52557 .4233 L F
.52605 .42495 m .52704 .42711 L .52387 .42648 L F
.941 .964 .71 r
.52773 .41958 m .52605 .42495 L .52557 .4233 L F
.504 .215 .407 r
.38934 .54794 m .38659 .5493 L .38602 .54723 L F
.772 .853 .911 r
.27355 .52267 m .27558 .5241 L .2773 .52246 L F
.945 .812 .683 r
.6031 .37109 m .60136 .36984 L .60284 .36769 L F
0 0 .465 r
.38924 .52975 m .39092 .53295 L .39068 .53362 L F
.814 .516 0 r
.39092 .53295 m .39189 .53557 L .39068 .53362 L F
.286 .462 .859 r
.34277 .50574 m .34147 .50799 L .3413 .50633 L F
0 0 .26 r
.34213 .5084 m .34147 .50799 L .34277 .50574 L F
.34213 .5084 m .34186 .51054 L .34147 .50799 L F
.929 .944 .783 r
.34466 .68779 m .34288 .69084 L .3419 .68905 L F
.991 .887 .578 r
.3419 .68905 m .34288 .69084 L .34212 .69263 L F
.528 .514 .783 r
.35489 .58442 m .35177 .58147 L .35324 .58041 L F
.38 0 .087 r
.24216 .5583 m .24478 .55803 L .24543 .5564 L F
.763 .524 .572 r
.24478 .55803 m .24837 .5559 L .24543 .5564 L F
.335 0 0 r
.42811 .59261 m .42943 .59243 L .42644 .59168 L F
.42811 .59261 m .42644 .59168 L .42623 .59 L F
.526 .876 .633 r
.68877 .31444 m .69001 .31367 L .69205 .31196 L F
.853 .408 0 r
.61231 .44186 m .61284 .44103 L .61194 .43935 L F
.61231 .44186 m .61383 .44306 L .61284 .44103 L F
.488 .137 .296 r
.62507 .43878 m .62306 .44004 L .62385 .43792 L F
.879 .871 .825 r
.47157 .45545 m .47388 .45639 L .47108 .45957 L F
.648 .47 .628 r
.47388 .45639 m .47449 .45908 L .47108 .45957 L F
.865 .878 .845 r
.47636 .45311 m .47388 .45639 L .47157 .45545 L F
.646 .524 .701 r
.47672 .45557 m .47388 .45639 L .47636 .45311 L F
.474 .273 .527 r
.47672 .45557 m .47449 .45908 L .47388 .45639 L F
.312 0 .213 r
.45566 .58752 m .45872 .58503 L .458 .58666 L F
.314 0 .094 r
.45872 .58503 m .46066 .58582 L .458 .58666 L F
.45872 .58503 m .46121 .58453 L .46066 .58582 L F
.216 0 0 r
.58128 .46752 m .58274 .46643 L .58418 .46696 L F
.215 0 0 r
.58274 .46643 m .58574 .46617 L .58418 .46696 L F
.915 .967 .794 r
.5291 .41964 m .52773 .41958 L .52804 .41766 L F
.709 .86 .953 r
.53129 .4169 m .5291 .41964 L .52804 .41766 L F
.53129 .4169 m .53216 .41834 L .5291 .41964 L F
.818 .841 .866 r
.60214 .35648 m .59847 .35682 L .60082 .35482 L F
.627 .804 .967 r
.60341 .35396 m .60214 .35648 L .60082 .35482 L F
.60341 .35396 m .60476 .35555 L .60214 .35648 L F
.808 .905 .909 r
.65694 .332 m .65265 .33334 L .65563 .33052 L F
.867 .885 .847 r
.65975 .32865 m .65694 .332 L .65563 .33052 L F
.36 .204 .531 r
.3281 .60572 m .32608 .60382 L .32817 .60307 L F
.3281 .60572 m .32605 .60654 L .32608 .60382 L F
.518 .449 .717 r
.71514 .35344 m .71797 .35566 L .71768 .35401 L F
0 .151 .678 r
.59163 .40506 m .59043 .4047 L .59052 .40408 L F
.59163 .40506 m .59248 .40648 L .59043 .4047 L F
.698 .608 .753 r
.32858 .5846 m .33264 .58527 L .3311 .58397 L F
.016 0 0 r
.3311 .58397 m .32777 .58659 L .32858 .5846 L F
.607 .241 .321 r
.33361 .59947 m .33137 .5974 L .33354 .59676 L F
.33361 .59947 m .33026 .59957 L .33137 .5974 L F
.6 .131 .112 r
.38731 .61933 m .38626 .62282 L .38524 .61915 L F
.38731 .61933 m .38876 .62181 L .38626 .62282 L F
.38731 .61933 m .38954 .61973 L .38876 .62181 L F
.716 .656 .789 r
.33264 .58527 m .3338 .58062 L .3311 .58397 L F
.33264 .58527 m .3354 .58464 L .3338 .58062 L F
.7 .565 .699 r
.33264 .58527 m .33276 .58813 L .3354 .58464 L F
.755 .933 .945 r
.68185 .38811 m .68421 .38503 L .68087 .38738 L F
.68185 .38811 m .68525 .38613 L .68421 .38503 L F
.52 .109 .201 r
.38985 .57906 m .38587 .58029 L .38721 .57931 L F
.818 .402 .256 r
.57601 .40935 m .57954 .41183 L .57683 .41087 L F
.819 .58 .578 r
.57954 .41183 m .57656 .41319 L .57683 .41087 L F
.57954 .41183 m .57952 .41366 L .57656 .41319 L F
.51 .218 .406 r
.70355 .33489 m .70667 .33189 L .70705 .33406 L F
.23 0 .22 r
.30947 .60956 m .31274 .6061 L .31021 .60667 L F
.837 .384 0 r
.60312 .42128 m .60009 .41739 L .60182 .41997 L F
.869 .46 .008 r
.60394 .42348 m .60312 .42128 L .60182 .41997 L F
.638 .644 .84 r
.44623 .46901 m .44366 .46993 L .44224 .46783 L F
.219 0 0 r
.32763 .64272 m .32472 .64462 L .32673 .64262 L F
.57 .021 0 r
.32821 .64371 m .32763 .64272 L .32673 .64262 L F
.32821 .64371 m .3295 .64446 L .32763 .64272 L F
.804 .598 .623 r
.31593 .53673 m .31468 .53928 L .31111 .5372 L F
.773 .559 .609 r
.3189 .53954 m .31468 .53928 L .31593 .53673 L F
.729 .949 .95 r
.64018 .36104 m .64275 .3601 L .6415 .3591 L F
.88 .62 .098 r
.64362 .35577 m .64393 .35552 L .64332 .35447 L F
.853 .969 .871 r
.6415 .3591 m .64469 .35797 L .64451 .3576 L F
.64451 .3576 m .64469 .35797 L .64546 .35712 L F
.6415 .3591 m .64546 .35712 L .64421 .35822 L F
.88 .62 .098 r
.64421 .35822 m .64404 .35664 L .64362 .35577 L F
.64404 .35664 m .64393 .35552 L .64362 .35577 L F
.853 .969 .871 r
.6415 .3591 m .64275 .3601 L .64469 .35797 L F
.453 .116 .304 r
.46125 .4735 m .45763 .47591 L .45679 .47197 L F
.46125 .4735 m .46051 .47549 L .45763 .47591 L F
.903 .654 .147 r
.42473 .53785 m .42535 .54056 L .42475 .53649 L F
.501 .23 .435 r
.42716 .53593 m .42473 .53785 L .42475 .53649 L F
.727 .796 .906 r
.43981 .46872 m .43574 .46843 L .43744 .46723 L F
.658 .776 .936 r
.44075 .46531 m .43981 .46872 L .43744 .46723 L F
.44075 .46531 m .44224 .46783 L .43981 .46872 L F
.516 .072 .135 r
.44141 .59716 m .43992 .59922 L .43728 .59904 L F
.185 0 0 r
.44237 .59847 m .44141 .59716 L .44401 .5969 L F
.44237 .59847 m .43992 .59922 L .44141 .59716 L F
0 0 .338 r
.40148 .56485 m .40192 .56737 L .40153 .56858 L F
.761 .497 0 r
.40148 .56924 m .40153 .56858 L .40192 .56737 L F
.40148 .56924 m .40204 .57113 L .40153 .56858 L F
.421 .265 .563 r
.37625 .61978 m .37616 .62336 L .3784 .62108 L F
.638 .599 .794 r
.37932 .62161 m .37625 .61978 L .3784 .62108 L F
.72 .828 .931 r
.29935 .64871 m .29521 .6486 L .29734 .64732 L F
.34 .392 .77 r
.30248 .65118 m .29935 .64871 L .30276 .64821 L F
.986 .731 .349 r
.41525 .59098 m .41425 .59271 L .41433 .58988 L F
.41525 .59098 m .41535 .59405 L .41425 .59271 L F
.519 0 0 r
.34622 .49649 m .34791 .49756 L .34971 .4981 L F
0 .533 .833 r
.35048 .49772 m .34971 .4981 L .34791 .49756 L F
.35048 .49772 m .35181 .49852 L .34971 .4981 L F
.068 0 .259 r
.67172 .37013 m .66976 .37385 L .67082 .37214 L F
.68 .782 .309 r
.67103 .37155 m .67172 .37013 L .67082 .37214 L F
.887 .991 .772 r
.6736 .36608 m .67422 .36672 L .67172 .37013 L F
.66 .777 .308 r
.6728 .36765 m .67172 .37013 L .67103 .37155 L F
.857 .737 .73 r
.74078 .33495 m .73876 .33867 L .73938 .33678 L F
.738 .652 .765 r
.74078 .33495 m .74401 .33208 L .74165 .3317 L F
.39 .165 .448 r
.3354 .58464 m .33276 .58813 L .33496 .58718 L F
.3354 .58464 m .33276 .58813 L .33496 .58718 L F
0 .179 .702 r
.3338 .58062 m .3354 .58464 L .33601 .58281 L F
0 0 .252 r
.3354 .58464 m .33678 .58571 L .33601 .58281 L F
.3354 .58464 m .33496 .58718 L .33678 .58571 L F
.831 .861 .868 r
.64076 .34234 m .64212 .34395 L .63896 .34402 L F
.802 .857 .891 r
.64534 .34104 m .64212 .34395 L .64076 .34234 L F
.824 .756 .787 r
.65285 .40773 m .65648 .40818 L .65532 .40449 L F
.834 .729 .749 r
.65405 .4116 m .65648 .40818 L .65285 .40773 L F
.776 .731 .811 r
.65532 .40449 m .65648 .40818 L .65914 .40499 L F
.079 0 0 r
.55166 .40971 m .55279 .40931 L .54997 .40951 L F
.272 .76 .673 r
.55735 .4075 m .55279 .40931 L .55166 .40971 L F
.32 0 .022 r
.33068 .61554 m .33319 .61525 L .33522 .61274 L F
.17 0 .349 r
.33522 .61274 m .33669 .61249 L .33684 .61016 L F
.709 .446 .526 r
.33319 .61525 m .33669 .61249 L .33522 .61274 L F
0 .054 .604 r
.61741 .43721 m .61799 .43519 L .61688 .43309 L F
.021 .224 .73 r
.61741 .43721 m .61928 .43871 L .61799 .43519 L F
.666 .912 .977 r
.24217 .55093 m .24163 .55289 L .24398 .55203 L F
.24217 .55093 m .24009 .55207 L .24163 .55289 L F
.222 0 0 r
.22848 .55903 m .22471 .56127 L .22623 .55951 L F
.274 .431 .837 r
.38081 .65524 m .38375 .6583 L .38365 .65413 L F
.455 .317 .604 r
.38365 .65413 m .38639 .65665 L .38612 .65396 L F
.38365 .65413 m .38375 .6583 L .38639 .65665 L F
.749 .786 .883 r
.65711 .34798 m .66003 .34691 L .65874 .34365 L F
.813 .816 .853 r
.65874 .34365 m .66003 .34691 L .66224 .34388 L F
.991 .839 .47 r
.40229 .58287 m .40361 .58092 L .40324 .58042 L F
.40229 .58287 m .40326 .58447 L .40361 .58092 L F
.617 .603 .814 r
.38111 .61841 m .37932 .62161 L .3784 .62108 L F
.38111 .61841 m .38216 .62068 L .37932 .62161 L F
.473 .895 .859 r
.25039 .55817 m .24964 .55906 L .25122 .55775 L F
.937 .57 .276 r
.60674 .43018 m .6071 .43224 L .60829 .43099 L F
.937 .569 .275 r
.60829 .43099 m .6071 .43224 L .60884 .43328 L F
.873 .925 .857 r
.67152 .39316 m .67155 .39632 L .67414 .39318 L F
.909 .944 .815 r
.66999 .39742 m .67155 .39632 L .67152 .39316 L F
.173 .693 .881 r
.31609 .55868 m .31482 .55833 L .31236 .55839 L F
.543 .912 .953 r
.31855 .55758 m .31717 .5574 L .31609 .55868 L F
.533 .9 .965 r
.31717 .5574 m .31482 .55833 L .31609 .55868 L F
.929 .944 .783 r
.34466 .68779 m .3419 .68905 L .34275 .68617 L F
.677 .804 .943 r
.34685 .68659 m .34466 .68779 L .34275 .68617 L F
.098 0 0 r
.3316 .58952 m .33496 .58718 L .33276 .58813 L F
.813 .803 .842 r
.65302 .34953 m .65711 .34798 L .65567 .34647 L F
.749 .786 .883 r
.65711 .34798 m .65874 .34365 L .65567 .34647 L F
.933 .881 .76 r
.64578 .4199 m .64767 .42112 L .64889 .41806 L F
.968 .735 .532 r
.64518 .42257 m .64767 .42112 L .64578 .4199 L F
.64518 .42257 m .6472 .42408 L .64767 .42112 L F
.167 .418 .857 r
.34743 .70461 m .34877 .70723 L .35128 .70835 L F
.666 .973 .829 r
.67566 .36533 m .67422 .36672 L .67578 .3647 L F
.649 .952 .947 r
.67578 .3647 m .67422 .36672 L .6736 .36608 L F
.182 .37 .815 r
.43953 .57523 m .44257 .5773 L .44315 .57635 L F
.44297 .57629 m .44299 .57624 L .44042 .57455 L F
.4404 .57456 m .44042 .57455 L .43889 .57354 L F
.44297 .57629 m .44042 .57455 L .4404 .57456 L F
0 0 .26 r
.4409 .57005 m .44073 .57421 L .44179 .57156 L F
.44073 .57421 m .4407 .57479 L .44099 .57392 L F
.44073 .57421 m .44099 .57392 L .44179 .57156 L F
.182 .37 .815 r
.43953 .57523 m .44297 .57629 L .43889 .57354 L F
.882 .99 .743 r
.4407 .57479 m .43931 .57537 L .43993 .57441 L F
.436 0 0 r
.43889 .57354 m .441 .57493 L .4407 .57479 L F
.882 .99 .743 r
.4407 .57479 m .43993 .57441 L .44179 .57156 L F
.436 0 0 r
.441 .57493 m .44299 .57624 L .4407 .57479 L F
.182 .37 .815 r
.44297 .57629 m .44315 .57635 L .44299 .57624 L F
.436 0 0 r
.44299 .57624 m .44315 .57635 L .44299 .57624 L F
.44299 .57624 m .44299 .57624 L .4407 .57479 L F
0 0 0 r
.44257 .5773 m .43874 .57983 L .44181 .57912 L F
.662 .761 .278 r
.44297 .57628 m .44257 .5773 L .44181 .57912 L F
.487 .362 .635 r
.43953 .57523 m .44017 .57835 L .44257 .5773 L F
.773 .301 .12 r
.44171 .57543 m .44299 .57624 L .44146 .57588 L F
.44299 .57624 m .44297 .5763 L .43931 .57537 L F
.44171 .57543 m .44146 .57588 L .43931 .57537 L F
.472 .752 .991 r
.44315 .57635 m .44257 .5773 L .44298 .57628 L F
.773 .301 .12 r
.44299 .57624 m .44315 .57635 L .44297 .5763 L F
.472 .752 .991 r
.44315 .57635 m .44298 .57628 L .4433 .57548 L F
.773 .301 .12 r
.4399 .57512 m .44275 .57619 L .43931 .57537 L F
.44275 .57619 m .44315 .57635 L .44275 .57624 L F
.44275 .57619 m .44275 .57624 L .43931 .57537 L F
.4407 .57479 m .44315 .57635 L .4399 .57512 L F
.568 .84 .996 r
.43931 .57537 m .44297 .5763 L .4433 .57548 L F
.662 .761 .278 r
.44317 .5758 m .44298 .57628 L .4431 .57598 L F
.44319 .57574 m .4431 .57598 L .44326 .57556 L F
.44317 .5758 m .4431 .57598 L .44319 .57574 L F
.44298 .57628 m .44257 .5773 L .44297 .5763 L F
.44298 .57628 m .44297 .5763 L .44326 .57556 L F
.443 .57623 m .44299 .57625 L .44299 .57625 L F
.568 .84 .996 r
.44297 .5763 m .44315 .57635 L .4433 .57548 L F
.662 .761 .278 r
.44326 .57556 m .443 .57623 L .44297 .57628 L F
.443 .57623 m .44299 .57625 L .44297 .57628 L F
.44299 .57625 m .44257 .5773 L .44297 .57628 L F
.4433 .57548 m .44317 .5758 L .44326 .57556 L F
.4433 .57548 m .44279 .57672 L .44304 .57721 L F
.44279 .57672 m .44181 .57912 L .44285 .5775 L F
.44279 .57672 m .44285 .5775 L .44304 .57721 L F
.971 .778 .349 r
.4433 .57548 m .4423 .57717 L .44059 .57744 L F
.44101 .5767 m .44059 .57744 L .43918 .57767 L F
.4433 .57548 m .44059 .57744 L .44101 .5767 L F
.773 .301 .12 r
.4407 .57479 m .44171 .57543 L .43931 .57537 L F
0 0 0 r
.34687 .51753 m .34492 .52057 L .34475 .52079 L F
.741 .223 0 r
.58458 .39812 m .58444 .39773 L .58038 .39521 L F
.245 .149 .543 r
.3209 .61852 m .31913 .61655 L .32089 .61578 L F
.3209 .61852 m .31937 .61933 L .31913 .61655 L F
.525 .361 .601 r
.45563 .49482 m .45567 .49763 L .45306 .49828 L F
.528 .398 .647 r
.45567 .49763 m .45338 .50087 L .45306 .49828 L F
.47 .774 .997 r
.30106 .63452 m .30295 .63588 L .3035 .6341 L F
0 .236 .745 r
.30295 .63588 m .30546 .6383 L .3035 .6341 L F
.817 .487 .43 r
.37792 .55482 m .37456 .55267 L .37834 .5524 L F
.123 0 0 r
.38115 .55066 m .38035 .55174 L .37834 .5524 L F
0 0 0 r
.23936 .52926 m .24049 .52841 L .24213 .52609 L F
.23936 .52926 m .23781 .53146 L .24049 .52841 L F
.802 .971 .668 r
.62242 .38732 m .6203 .39017 L .6211 .38848 L F
.818 .991 .741 r
.6211 .38848 m .6203 .39017 L .61842 .39113 L F
0 0 .39 r
.27579 .51701 m .27533 .5183 L .27388 .51751 L F
.875 .932 .856 r
.67218 .33302 m .67624 .33101 L .67529 .33006 L F
.866 .974 .855 r
.67529 .33006 m .67624 .33101 L .67894 .32794 L F
0 0 .039 r
.33987 .67629 m .33883 .67719 L .33833 .67933 L F
.887 .839 .792 r
.64889 .41806 m .65119 .41462 L .64958 .41337 L F
.829 .85 .863 r
.64958 .41337 m .65119 .41462 L .65405 .4116 L F
.568 .122 .151 r
.6211 .38848 m .62486 .38851 L .62242 .38732 L F
.528 .485 .753 r
.24086 .56143 m .2428 .56262 L .24216 .5583 L F
.991 .882 .564 r
.69728 .33247 m .69806 .33528 L .69714 .33765 L F
0 0 0 r
.43429 .54447 m .43292 .54438 L .4358 .54332 L F
.43429 .54447 m .43311 .54562 L .43292 .54438 L F
0 0 .363 r
.37113 .67452 m .37208 .67605 L .37263 .67295 L F
.37113 .67452 m .3719 .67718 L .37208 .67605 L F
.897 .955 .829 r
.43028 .47225 m .43168 .46803 L .43318 .46944 L F
.43028 .47225 m .42914 .47131 L .43168 .46803 L F
.772 .962 .656 r
.69495 .29024 m .69214 .29383 L .69343 .29123 L F
.916 .975 .774 r
.69699 .28702 m .69495 .29024 L .69508 .28711 L F
.934 .947 .613 r
.69508 .28711 m .69495 .29024 L .69343 .29123 L F
.677 .334 .385 r
.32415 .54935 m .32313 .54788 L .32313 .54758 L F
.32313 .54788 m .3225 .54696 L .32313 .54758 L F
.3225 .54696 m .32193 .54615 L .32313 .54758 L F
.434 0 0 r
.31862 .54593 m .32313 .54758 L .32193 .54615 L F
.31862 .54593 m .32075 .54714 L .32214 .5474 L F
.32171 .54706 m .32214 .5474 L .32313 .54758 L F
.31862 .54593 m .32214 .5474 L .32171 .54706 L F
0 0 .281 r
.32233 .55092 m .32159 .54938 L .32415 .54935 L F
.712 .244 .136 r
.32313 .54758 m .32287 .54962 L .32481 .54922 L F
0 0 .419 r
.32233 .55092 m .32349 .54845 L .32286 .54796 L F
.712 .244 .136 r
.32287 .54962 m .32285 .54978 L .32293 .54976 L F
.32287 .54962 m .32293 .54976 L .32481 .54922 L F
.736 .653 .097 r
.32317 .54624 m .32313 .54758 L .32313 .54625 L F
.712 .244 .136 r
.32313 .54758 m .32656 .54872 L .32415 .54935 L F
.32313 .54758 m .32481 .54922 L .32656 .54872 L F
.976 .845 .648 r
.32477 .54672 m .32294 .54965 L .32317 .54624 L F
0 0 .419 r
.3229 .54969 m .32294 .54968 L .32294 .54961 L F
.736 .653 .097 r
.32313 .54625 m .32313 .54758 L .32075 .54714 L F
.32317 .54624 m .32285 .54978 L .32287 .54962 L F
.32317 .54624 m .32287 .54962 L .32313 .54758 L F
0 0 .419 r
.32286 .54796 m .32301 .54807 L .32317 .54624 L F
.32301 .54807 m .32349 .54845 L .32317 .54624 L F
.976 .845 .648 r
.32294 .54965 m .32285 .54978 L .32317 .54624 L F
0 0 .419 r
.32294 .54961 m .32364 .5495 L .32349 .54845 L F
.32233 .55092 m .32317 .54624 L .32075 .54714 L F
.63 .79 .959 r
.3191 .5456 m .32075 .54714 L .32317 .54624 L F
.3191 .5456 m .32075 .54714 L .32317 .54624 L F
.3191 .5456 m .32317 .54624 L .32138 .54492 L F
.3191 .5456 m .32317 .54624 L .32138 .54492 L F
0 .002 .579 r
.32364 .5495 m .32183 .54584 L .32317 .54624 L F
.32183 .54584 m .32138 .54492 L .32317 .54624 L F
.976 .845 .648 r
.32562 .54537 m .32477 .54672 L .32317 .54624 L F
0 0 .419 r
.32294 .54968 m .32364 .5495 L .32294 .54961 L F
.32233 .55092 m .32309 .5501 L .3229 .54969 L F
.32309 .5501 m .32364 .5495 L .3229 .54969 L F
.71 .254 .167 r
.32695 .55158 m .32415 .54935 L .32656 .54872 L F
.32695 .55158 m .32233 .55092 L .32415 .54935 L F
.163 0 .329 r
.30721 .61274 m .30947 .60956 L .30725 .6104 L F
.901 .933 .826 r
.65975 .32865 m .66116 .32416 L .66201 .32535 L F
.828 .953 .899 r
.66492 .32266 m .66201 .32535 L .66116 .32416 L F
.273 0 0 r
.3189 .53954 m .31735 .53971 L .31468 .53928 L F
0 .151 .691 r
.3189 .53954 m .31954 .53843 L .31735 .53971 L F
.259 .335 .751 r
.21046 .59437 m .213 .59629 L .212 .59263 L F
.862 .964 .633 r
.33591 .55863 m .33589 .55695 L .33777 .55515 L F
.843 .841 .375 r
.33591 .55863 m .33496 .56007 L .33589 .55695 L F
.851 .553 .483 r
.70915 .31495 m .71136 .31771 L .71238 .31574 L F
.977 .677 .32 r
.32579 .49788 m .32713 .50196 L .3258 .50057 L F
.944 .915 .757 r
.34323 .51446 m .34265 .51448 L .34357 .51484 L F
0 0 0 r
.34079 .51728 m .34272 .51431 L .34278 .51417 L F
.34079 .51728 m .34156 .51618 L .34272 .51431 L F
.364 0 .195 r
.34356 .51297 m .34156 .51618 L .34323 .51446 L F
.944 .915 .757 r
.34323 .51446 m .34156 .51618 L .34057 .51455 L F
.34265 .51448 m .34057 .51455 L .34253 .51474 L F
.34265 .51448 m .34253 .51474 L .34357 .51484 L F
0 0 0 r
.34278 .51417 m .34272 .51431 L .34356 .51297 L F
.479 .234 .464 r
.27407 .56507 m .27659 .5647 L .27693 .5621 L F
.478 .27 .518 r
.27693 .5621 m .27935 .56155 L .2796 .55889 L F
.51 .26 .472 r
.27693 .5621 m .27914 .56409 L .27935 .56155 L F
.27693 .5621 m .27659 .5647 L .27914 .56409 L F
.475 0 0 r
.3639 .68625 m .35962 .68449 L .36284 .68785 L F
.973 .662 .344 r
.36248 .68868 m .3639 .68625 L .36284 .68785 L F
.286 .051 .372 r
.36635 .6835 m .3639 .68625 L .36596 .68524 L F
0 0 0 r
.36596 .68524 m .3639 .68625 L .36248 .68868 L F
.776 .292 0 r
.57526 .40958 m .57601 .40935 L .57683 .41087 L F
0 .418 .722 r
.39286 .65327 m .39255 .6533 L .38972 .65248 L F
.77 .291 .096 r
.39383 .65523 m .38972 .65248 L .39255 .6533 L F
0 .418 .722 r
.39286 .65327 m .38972 .65248 L .38801 .65355 L F
.382 .415 .77 r
.44842 .55585 m .44958 .55969 L .45136 .55768 L F
.382 .562 .906 r
.44958 .55969 m .45407 .56156 L .45136 .55768 L F
.518 .916 .879 r
.26152 .52481 m .26152 .5252 L .262 .52501 L F
.647 .117 0 r
.26611 .52879 m .26152 .52481 L .262 .52501 L F
.26611 .52879 m .26321 .52709 L .26152 .52481 L F
0 0 .49 r
.26152 .52481 m .26321 .52709 L .26149 .52325 L F
.314 .802 .786 r
.25638 .52124 m .25867 .52046 L .25965 .5203 L F
.25952 .52042 m .25965 .5203 L .26062 .52013 L F
.25638 .52124 m .25965 .5203 L .25952 .52042 L F
.497 .906 .842 r
.26062 .52013 m .25867 .52046 L .25989 .51967 L F
0 0 .49 r
.26152 .52481 m .26149 .52325 L .26001 .51994 L F
.25998 .51997 m .26001 .51994 L .25989 .51967 L F
.26152 .52481 m .26001 .51994 L .25998 .51997 L F
.518 .916 .879 r
.26152 .52481 m .26024 .5257 L .26152 .5252 L F
.26152 .52481 m .25664 .52664 L .26024 .5257 L F
.844 .916 .882 r
.60359 .37927 m .59931 .38104 L .60264 .37853 L F
.888 .981 .818 r
.60598 .37621 m .60359 .37927 L .60264 .37853 L F
.59 .873 .994 r
.39255 .51435 m .39069 .51357 L .39078 .51426 L F
.559 .057 0 r
.39255 .51435 m .39358 .51564 L .39069 .51357 L F
.478 0 0 r
.39069 .51357 m .39358 .51564 L .39181 .51464 L F
.39069 .51357 m .39181 .51464 L .39052 .51226 L F
.39069 .51357 m .39052 .51226 L .39016 .5116 L F
.59 .873 .994 r
.39078 .51426 m .39069 .51357 L .38902 .51416 L F
.559 .057 0 r
.39347 .51535 m .39497 .51698 L .39358 .51564 L F
0 .078 .626 r
.39497 .51698 m .396 .51732 L .39358 .51564 L F
.714 .181 0 r
.396 .51732 m .39364 .51581 L .39358 .51564 L F
.39364 .51581 m .39181 .51464 L .39358 .51564 L F
.559 .057 0 r
.39255 .51435 m .39347 .51535 L .39358 .51564 L F
.906 .804 .327 r
.6125 .45265 m .61298 .4502 L .6126 .44883 L F
.761 .432 .428 r
.38453 .66091 m .3886 .66135 L .38659 .66196 L F
.579 .125 .137 r
.38659 .66196 m .3886 .66135 L .38678 .6633 L F
.642 .588 .778 r
.38453 .66091 m .38659 .66196 L .38658 .66166 L F
.703 .275 .229 r
.38787 .66213 m .3886 .66135 L .38662 .66113 L F
.38787 .66213 m .38662 .66113 L .38663 .66134 L F
.38787 .66213 m .38624 .66109 L .38658 .66166 L F
0 0 .162 r
.38667 .66181 m .38659 .66196 L .38678 .6633 L F
0 .028 .549 r
.38658 .66166 m .38659 .66196 L .38667 .66181 L F
.703 .275 .229 r
.38678 .6633 m .38787 .66213 L .38453 .66091 L F
0 0 .162 r
.3881 .65897 m .38667 .66181 L .38678 .6633 L F
.703 .275 .229 r
.38663 .66134 m .38662 .66113 L .38624 .66109 L F
.38658 .66166 m .38624 .66109 L .38453 .66091 L F
0 .028 .549 r
.38639 .65665 m .38658 .66166 L .3881 .65897 L F
.38658 .66166 m .38667 .66181 L .3881 .65897 L F
.642 .588 .778 r
.38453 .66091 m .38658 .66166 L .38639 .65665 L F
.814 .78 .822 r
.56039 .39922 m .56238 .40156 L .55863 .40077 L F
.82 .434 .323 r
.55863 .40077 m .56238 .40156 L .56083 .4046 L F
.757 .859 .925 r
.56354 .3984 m .56238 .40156 L .56039 .39922 L F
.56354 .3984 m .56495 .39988 L .56238 .40156 L F
.835 .371 .099 r
.56238 .40156 m .56246 .40459 L .56083 .4046 L F
.51 0 0 r
.30248 .55772 m .30433 .55858 L .30625 .55856 L F
.175 0 .206 r
.30776 .55871 m .30527 .56079 L .30625 .55856 L F
.30776 .55871 m .30527 .56079 L .30625 .55856 L F
.826 .87 .878 r
.39991 .49867 m .40046 .49976 L .40192 .49705 L F
.762 .948 .621 r
.69343 .29123 m .69214 .29383 L .69095 .29465 L F
.502 .308 .55 r
.5754 .41798 m .57669 .41998 L .57278 .42109 L F
.304 .171 .529 r
.57456 .42256 m .57278 .42109 L .57669 .41998 L F
.57456 .42256 m .57308 .42393 L .57278 .42109 L F
0 0 0 r
.36712 .64168 m .37008 .64127 L .36974 .64134 L F
.754 .946 .943 r
.37008 .64127 m .37224 .63862 L .36974 .64134 L F
.897 .545 .07 r
.40176 .57651 m .40208 .5754 L .40101 .57403 L F
.40176 .57651 m .40276 .57776 L .40208 .5754 L F
.344 0 0 r
.28045 .51736 m .28069 .51991 L .28286 .51685 L F
.28045 .51736 m .27675 .52073 L .28069 .51991 L F
.528 .889 .977 r
.4593 .46969 m .46209 .46871 L .46335 .46931 L F
.177 .286 .738 r
.46434 .46712 m .46335 .46931 L .46209 .46871 L F
.46434 .46712 m .46585 .47123 L .46335 .46931 L F
.425 .28 .579 r
.46335 .46931 m .46585 .47123 L .46357 .47227 L F
.976 .844 .646 r
.64638 .39681 m .64739 .39566 L .64658 .398 L F
.64597 .39428 m .64716 .39544 L .64638 .39681 L F
.64716 .39544 m .64739 .39566 L .64638 .39681 L F
.64597 .39428 m .64658 .398 L .6466 .39718 L F
.836 .647 .102 r
.64471 .39894 m .6466 .39718 L .64658 .398 L F
.64471 .39894 m .64478 .40163 L .64444 .40032 L F
.94 .658 .477 r
.64658 .398 m .64478 .40163 L .64471 .39894 L F
.836 .647 .102 r
.6457 .39801 m .64444 .40032 L .6466 .39718 L F
.64471 .39894 m .64447 .4002 L .6457 .39801 L F
.64447 .4002 m .64444 .40032 L .6457 .39801 L F
.934 .968 .728 r
.55768 .4062 m .55768 .40876 L .55735 .4075 L F
.485 .311 .569 r
.32757 .6188 m .33118 .62154 L .33044 .61815 L F
.32757 .6188 m .32884 .62199 L .33118 .62154 L F
.711 .303 .272 r
.28681 .55745 m .29099 .55809 L .28887 .55558 L F
.016 0 0 r
.3311 .58397 m .33028 .586 L .32777 .58659 L F
0 0 0 r
.33168 .58453 m .3311 .58397 L .3338 .58062 L F
.33117 .58514 m .3311 .58397 L .33168 .58453 L F
.33117 .58514 m .33028 .586 L .3311 .58397 L F
.882 .476 .037 r
.39529 .54411 m .39582 .54333 L .3944 .54233 L F
.39529 .54411 m .39672 .54565 L .39582 .54333 L F
.411 .586 .913 r
.44749 .54923 m .4474 .54615 L .44577 .54637 L F
.44749 .54923 m .44928 .54858 L .4474 .54615 L F
.458 .325 .612 r
.44749 .54923 m .45005 .55157 L .44928 .54858 L F
.44749 .54923 m .44779 .55238 L .45005 .55157 L F
.868 .657 .615 r
.64224 .41164 m .64382 .41511 L .6413 .41438 L F
.605 .407 .587 r
.64382 .41511 m .64104 .41691 L .6413 .41438 L F
.64382 .41511 m .64241 .41834 L .64104 .41691 L F
.64382 .41511 m .64493 .41747 L .64241 .41834 L F
.721 .92 .96 r
.39552 .67553 m .39728 .67371 L .39667 .67607 L F
0 0 0 r
.29703 .54648 m .29595 .54793 L .29888 .54534 L F
.299 0 .166 r
.2592 .55096 m .25792 .54997 L .25967 .54852 L F
.2592 .55096 m .25691 .55161 L .25792 .54997 L F
.302 .633 .964 r
.23363 .60585 m .23291 .60767 L .23215 .60564 L F
.381 0 .103 r
.34337 .58385 m .34519 .58211 L .34814 .58128 L F
.319 .439 .826 r
.37616 .62336 m .37745 .62626 L .37933 .62524 L F
.204 .179 .607 r
.37933 .62524 m .37745 .62626 L .37931 .62896 L F
.812 .485 0 r
.39703 .51993 m .39842 .52375 L .39773 .52247 L F
0 0 .492 r
.39842 .52375 m .39954 .52457 L .39773 .52247 L F
.39842 .52375 m .3999 .52618 L .39954 .52457 L F
.439 .027 .159 r
.33774 .53396 m .33664 .53539 L .33486 .53523 L F
.33774 .53396 m .33664 .53539 L .33486 .53523 L F
0 0 0 r
.33774 .53396 m .33801 .53383 L .33987 .53284 L F
.33774 .53396 m .33664 .53539 L .33801 .53383 L F
.33801 .53383 m .33774 .53396 L .33987 .53284 L F
.33801 .53383 m .33664 .53539 L .33774 .53396 L F
.729 .548 .646 r
.43422 .54937 m .43348 .5511 L .43737 .54841 L F
.366 .445 .809 r
.43654 .54621 m .43737 .54841 L .43908 .54711 L F
.978 .917 .655 r
.61876 .37828 m .61911 .3805 L .61985 .37676 L F
.853 .887 .863 r
.61613 .3817 m .61911 .3805 L .61876 .37828 L F
.44 .288 .577 r
.38637 .50049 m .38632 .50366 L .38394 .50204 L F
.64 .465 .631 r
.35261 .61964 m .35261 .62275 L .35002 .62283 L F
.35002 .62283 m .35261 .62275 L .35261 .61964 L F
.478 .335 .607 r
.3551 .61897 m .35261 .62275 L .35261 .61964 L F
.3551 .61897 m .35261 .62275 L .35261 .61964 L F
.611 .445 .632 r
.22205 .57116 m .22229 .57472 L .21957 .57486 L F
0 0 .43 r
.22313 .57257 m .22205 .57116 L .22405 .57018 L F
.22313 .57257 m .22229 .57472 L .22205 .57116 L F
.712 .427 .492 r
.42991 .51967 m .43373 .51727 L .43222 .51882 L F
.264 0 0 r
.43509 .51799 m .43373 .51727 L .43543 .51636 L F
.757 .639 .73 r
.43474 .51833 m .43509 .51799 L .43484 .51803 L F
.201 0 .059 r
.43373 .51727 m .43474 .51833 L .43484 .51803 L F
.43373 .51727 m .43484 .51803 L .43543 .51636 L F
.264 0 0 r
.43494 .5181 m .43222 .51882 L .43268 .51835 L F
.757 .639 .73 r
.43474 .51833 m .43506 .51811 L .43509 .51799 L F
.264 0 0 r
.43522 .51807 m .43499 .51813 L .43494 .5181 L F
.43499 .51813 m .43222 .51882 L .43494 .5181 L F
.43509 .51799 m .43268 .51835 L .43373 .51727 L F
.43522 .51807 m .43268 .51835 L .43509 .51799 L F
.757 .639 .73 r
.43484 .51803 m .43509 .51799 L .43543 .51636 L F
.43506 .51811 m .43892 .51557 L .43543 .51636 L F
.264 0 0 r
.43522 .51807 m .43509 .51799 L .43543 .51636 L F
.957 .627 .345 r
.40169 .48849 m .39944 .48758 L .39914 .48446 L F
.726 .273 .175 r
.40169 .48849 m .4002 .48933 L .39944 .48758 L F
.40169 .48849 m .40308 .49063 L .4002 .48933 L F
.867 .885 .847 r
.65975 .32865 m .65563 .33052 L .65871 .32733 L F
.901 .933 .826 r
.65975 .32865 m .65871 .32733 L .66116 .32416 L F
.388 .144 .418 r
.56903 .40597 m .56649 .4055 L .56747 .40647 L F
.171 .704 .838 r
.26534 .51768 m .26981 .51772 L .26765 .51877 L F
.748 .757 .86 r
.70611 .33635 m .70806 .33805 L .70419 .33745 L F
.51 .297 .526 r
.2796 .55889 m .28186 .56102 L .2824 .55873 L F
.2796 .55889 m .27935 .56155 L .28186 .56102 L F
.727 .376 .384 r
.37044 .57829 m .36976 .58042 L .3632 .58101 L F
.625 .362 .5 r
.37383 .57756 m .36976 .58042 L .37044 .57829 L F
.764 .75 .84 r
.28973 .65788 m .29239 .66 L .29432 .65801 L F
.52 .249 .445 r
.23785 .56832 m .24011 .56854 L .24181 .56813 L F
.648 .199 .172 r
.24011 .56854 m .24429 .56978 L .24181 .56813 L F
.61 .154 .145 r
.24181 .56813 m .24429 .56978 L .24438 .56855 L F
.352 .605 .944 r
.26284 .61492 m .26202 .61666 L .26023 .61413 L F
.033 .201 .706 r
.26284 .61492 m .26414 .61876 L .26202 .61666 L F
0 0 .527 r
.23464 .56504 m .23605 .56714 L .23725 .56495 L F
.23464 .56504 m .23574 .56908 L .23605 .56714 L F
.895 .919 .83 r
.62179 .37414 m .62236 .37281 L .61918 .37351 L F
.472 .357 .641 r
.62179 .37414 m .61918 .37351 L .62126 .37229 L F
.62179 .37414 m .61985 .37676 L .61918 .37351 L F
.895 .919 .83 r
.62179 .37414 m .61918 .37351 L .61985 .37676 L F
.687 .938 .645 r
.22102 .5496 m .21836 .55256 L .21914 .55139 L F
0 0 .134 r
.21773 .55509 m .21914 .55139 L .21836 .55256 L F
.53 .794 .994 r
.25551 .5666 m .2549 .56849 L .25316 .56712 L F
.25551 .5666 m .25726 .56791 L .2549 .56849 L F
.25551 .5666 m .2549 .56849 L .25316 .56712 L F
.25551 .5666 m .25726 .56791 L .2549 .56849 L F
.532 .378 .618 r
.31273 .60392 m .31513 .60349 L .31538 .60088 L F
.545 .375 .602 r
.31274 .6061 m .31513 .60349 L .31273 .60392 L F
.765 .498 .53 r
.37299 .5963 m .37705 .59711 L .37719 .59409 L F
.722 .627 .752 r
.37487 .58416 m .37579 .58769 L .37864 .58531 L F
.649 .527 .701 r
.37719 .59409 m .3798 .59331 L .37816 .59012 L F
.509 .283 .508 r
.37953 .59621 m .37705 .59711 L .37719 .59409 L F
.37953 .59621 m .37705 .59711 L .37719 .59409 L F
0 .473 .779 r
.57793 .42034 m .57958 .42102 L .58067 .42115 L F
.797 .895 .913 r
.42109 .47817 m .41951 .47995 L .41797 .47869 L F
.886 .812 .77 r
.34912 .60949 m .34704 .61267 L .34977 .61097 L F
.876 .895 .842 r
.64997 .39245 m .64739 .39566 L .64597 .39428 L F
.879 .871 .825 r
.47157 .45545 m .47108 .45957 L .46962 .45782 L F
.433 .198 .456 r
.47449 .45908 m .47138 .46285 L .47108 .45957 L F
.213 .161 .58 r
.46859 .46249 m .46962 .45782 L .47108 .45957 L F
.748 .556 .636 r
.46859 .46249 m .47108 .45957 L .47138 .46285 L F
.916 .975 .774 r
.69699 .28702 m .69508 .28711 L .69598 .28588 L F
.788 .986 .896 r
.69865 .28519 m .69699 .28702 L .69819 .2844 L F
.73 .925 .957 r
.69819 .2844 m .69699 .28702 L .69598 .28588 L F
.572 .389 .595 r
.34175 .58445 m .34187 .58719 L .33909 .58768 L F
.54 .381 .614 r
.34178 .59004 m .33909 .58768 L .34187 .58719 L F
.34178 .59004 m .33914 .59066 L .33909 .58768 L F
0 0 0 r
.34107 .54169 m .33976 .54591 L .33911 .54341 L F
0 0 .549 r
.61528 .43058 m .61664 .43132 L .6154 .42918 L F
.61528 .43058 m .61688 .43309 L .61664 .43132 L F
.457 .814 .997 r
.4166 .48478 m .4147 .4837 L .4141 .48484 L F
.254 .06 .413 r
.4141 .48484 m .41537 .48704 L .4166 .48478 L F
.41537 .48704 m .4141 .48484 L .4147 .4837 L F
.41537 .48704 m .41356 .48804 L .4141 .48484 L F
.4141 .48484 m .41356 .48804 L .41537 .48704 L F
.994 .778 .407 r
.42473 .53785 m .42481 .54202 L .42535 .54056 L F
.129 0 .159 r
.32825 .53584 m .32705 .53835 L .325 .53926 L F
.074 0 0 r
.32705 .53835 m .32366 .54123 L .325 .53926 L F
.853 .574 .516 r
.42602 .57662 m .42967 .57493 L .42755 .5738 L F
.42602 .57662 m .42942 .57721 L .42967 .57493 L F
.654 .152 .042 r
.43167 .57425 m .42755 .5738 L .42967 .57493 L F
.505 .313 .554 r
.42942 .57721 m .43167 .57425 L .42967 .57493 L F
.27 .38 .792 r
.38474 .51069 m .38639 .51454 L .38751 .51232 L F
.515 .684 .943 r
.38639 .51454 m .38902 .51416 L .38751 .51232 L F
.83 .382 0 r
.41535 .59405 m .4178 .59726 L .41606 .59632 L F
.973 .704 .46 r
.4178 .59726 m .4161 .59901 L .41606 .59632 L F
.4178 .59726 m .41777 .60037 L .4161 .59901 L F
.057 0 .102 r
.45394 .59172 m .45269 .59043 L .45481 .58948 L F
.45394 .59172 m .452 .59304 L .45269 .59043 L F
0 0 0 r
.33249 .68369 m .33049 .68454 L .32823 .68596 L F
.454 .013 .109 r
.28592 .56984 m .28495 .56813 L .28757 .5682 L F
.28592 .56984 m .2832 .5702 L .28495 .56813 L F
0 0 0 r
.38954 .61973 m .38942 .62055 L .38876 .62181 L F
.38954 .61973 m .39134 .61854 L .38942 .62055 L F
.59427 .46368 m .59058 .46425 L .59202 .46339 L F
.245 0 0 r
.59459 .46267 m .59427 .46368 L .59202 .46339 L F
.292 .213 .593 r
.34378 .58658 m .34175 .58445 L .34337 .58385 L F
.351 .221 .56 r
.34378 .58658 m .34187 .58719 L .34175 .58445 L F
.715 .418 0 r
.4047 .53297 m .40489 .53403 L .40275 .5316 L F
.4047 .53297 m .40542 .5356 L .40489 .53403 L F
.648 .24 .256 r
.55248 .46571 m .55647 .46581 L .55506 .46774 L F
.691 .33 .358 r
.55647 .46581 m .55904 .46809 L .55506 .46774 L F
.55647 .46581 m .55889 .46621 L .55904 .46809 L F
.485 .32 .581 r
.45397 .50386 m .4545 .50826 L .45178 .50886 L F
.533 .467 .728 r
.45589 .50021 m .45397 .50386 L .45338 .50087 L F
.45589 .50021 m .45617 .50394 L .45397 .50386 L F
.549 .37 .591 r
.45617 .50394 m .4545 .50826 L .45397 .50386 L F
.816 .66 .689 r
.52815 .4335 m .53007 .43735 L .5262 .43671 L F
.784 .658 .724 r
.53007 .43735 m .52581 .43936 L .5262 .43671 L F
.53007 .43735 m .52797 .43853 L .52581 .43936 L F
.53007 .43735 m .52894 .43996 L .52797 .43853 L F
.728 .595 .708 r
.22516 .60047 m .2225 .60414 L .22164 .6005 L F
.565 .262 .412 r
.22229 .57472 m .22168 .57695 L .21957 .57486 L F
.22229 .57472 m .22168 .57695 L .21957 .57486 L F
.594 .616 .843 r
.22584 .59622 m .22685 .60066 L .22516 .60047 L F
.596 .217 .294 r
.22685 .60066 m .22751 .60229 L .22516 .60047 L F
.933 .881 .76 r
.64578 .4199 m .64889 .41806 L .64714 .41672 L F
.887 .839 .792 r
.64889 .41806 m .64958 .41337 L .64714 .41672 L F
.767 .361 .283 r
.55889 .46621 m .56296 .46875 L .55904 .46809 L F
.248 0 .255 r
.52972 .41396 m .52927 .41463 L .52756 .41314 L F
.58 .845 .496 r
.53089 .4128 m .52899 .41506 L .52927 .41463 L F
.3 .615 .957 r
.53509 .41473 m .53089 .4128 L .53357 .41364 L F
.478 .069 .185 r
.52927 .41463 m .53357 .41364 L .53089 .4128 L F
.907 .947 .818 r
.53043 .41552 m .53129 .4169 L .53217 .41564 L F
.53136 .41496 m .53217 .41564 L .53357 .41364 L F
.53043 .41552 m .53217 .41564 L .53136 .41496 L F
.248 0 .255 r
.53054 .41427 m .52927 .41463 L .52972 .41396 L F
.907 .947 .818 r
.53043 .41552 m .53357 .41364 L .52927 .41463 L F
.248 0 .255 r
.53188 .41479 m .53109 .41474 L .53054 .41427 L F
.53109 .41474 m .52927 .41463 L .53054 .41427 L F
.58 .845 .496 r
.52899 .41506 m .52884 .41524 L .52927 .41463 L F
.984 .854 .633 r
.52884 .41524 m .52669 .41617 L .52927 .41463 L F
.52884 .41524 m .52804 .41766 L .52669 .41617 L F
.439 .415 .735 r
.32812 .56839 m .33007 .56789 L .32929 .5633 L F
.677 .738 .234 r
.32891 .57134 m .33007 .56789 L .32812 .56839 L F
.563 .302 .478 r
.35192 .5711 m .3547 .5711 L .35517 .56845 L F
.211 0 .33 r
.35517 .56845 m .35696 .56766 L .3574 .56532 L F
.229 .014 .366 r
.35517 .56845 m .3547 .5711 L .35696 .56766 L F
0 0 0 r
.2319 .53664 m .23087 .53921 L .23296 .53548 L F
.491 .144 .307 r
.29679 .56219 m .29676 .56405 L .29365 .56383 L F
.675 .293 .314 r
.29679 .56219 m .29903 .56445 L .29676 .56405 L F
.567 .312 .488 r
.29929 .56166 m .29903 .56445 L .29679 .56219 L F
.478 .871 .687 r
.24659 .53122 m .2451 .53196 L .24346 .53323 L F
.45 .856 .679 r
.24667 .53088 m .24659 .53122 L .25005 .52932 L F
.688 .897 .536 r
.32471 .50748 m .32228 .51084 L .32301 .50938 L F
.541 .868 .994 r
.32228 .51084 m .32509 .51035 L .32301 .50938 L F
.423 .769 .996 r
.32648 .53005 m .32757 .52864 L .32478 .52892 L F
.32648 .53005 m .32757 .52864 L .32478 .52892 L F
.604 .459 .658 r
.32648 .53005 m .32556 .53498 L .32932 .533 L F
.533 .54 .808 r
.3429 .60897 m .34466 .61327 L .34704 .61267 L F
.066 .081 .565 r
.59309 .38542 m .59361 .38149 L .59342 .38456 L F
.034 .461 .878 r
.59342 .38456 m .59522 .38635 L .59309 .38542 L F
.939 .57 .201 r
.60453 .42688 m .60674 .43018 L .60573 .42726 L F
.972 .848 .445 r
.41475 .58053 m .41467 .58458 L .41443 .58316 L F
.903 .539 .079 r
.41467 .58458 m .41423 .58598 L .41443 .58316 L F
.41467 .58458 m .41548 .58725 L .41423 .58598 L F
.471 .148 .336 r
.34719 .54152 m .35057 .53863 L .3484 .53932 L F
.62 .522 .722 r
.45974 .48709 m .45724 .48802 L .45682 .48543 L F
.612 .511 .716 r
.4609 .49119 m .45724 .48802 L .45974 .48709 L F
.4609 .49119 m .45819 .4917 L .45724 .48802 L F
.909 .647 .531 r
.30614 .63754 m .30946 .63581 L .30711 .63491 L F
.744 .337 .28 r
.31115 .63856 m .30946 .63581 L .30614 .63754 L F
.764 .954 .638 r
.67082 .37214 m .66976 .37385 L .66834 .37489 L F
.623 .914 .98 r
.54997 .40951 m .5471 .4097 L .54931 .41053 L F
.079 0 0 r
.55166 .40971 m .54997 .40951 L .54931 .41053 L F
.776 .866 .915 r
.62605 .34964 m .62613 .35341 L .62437 .35353 L F
.757 .852 .921 r
.62971 .34964 m .62613 .35341 L .62605 .34964 L F
.769 .82 .893 r
.63103 .35106 m .62613 .35341 L .62971 .34964 L F
.957 .943 .711 r
.36994 .66109 m .36851 .66155 L .36983 .66013 L F
.668 .228 0 r
.22989 .60575 m .22751 .60229 L .2292 .60365 L F
.613 .211 .257 r
.30867 .64489 m .31155 .6456 L .31101 .64685 L F
.888 .981 .818 r
.60598 .37621 m .60264 .37853 L .60532 .3753 L F
.746 .668 .775 r
.60531 .3731 m .6091 .37325 L .60598 .37621 L F
.922 .668 .178 r
.60531 .3731 m .60598 .37621 L .60532 .3753 L F
.815 .341 0 r
.61035 .43817 m .61045 .43678 L .60884 .43568 L F
.61035 .43817 m .61194 .43935 L .61045 .43678 L F
.595 .51 .729 r
.44864 .46791 m .44738 .47267 L .44623 .46901 L F
.44864 .46791 m .45016 .47217 L .44738 .47267 L F
.585 .459 .675 r
.45016 .47217 m .44758 .47522 L .44738 .47267 L F
0 0 0 r
.34 .60088 m .33995 .60221 L .34056 .6005 L F
0 .01 .553 r
.389 .59361 m .39014 .59659 L .38914 .59259 L F
.812 .885 .898 r
.6327 .34698 m .63103 .35106 L .62971 .34964 L F
.6327 .34698 m .63407 .34851 L .63103 .35106 L F
.226 0 .015 r
.36949 .71531 m .37329 .71266 L .37175 .71386 L F
.788 .533 0 r
.41415 .56455 m .41498 .56838 L .41449 .56713 L F
.921 .927 .553 r
.41498 .56838 m .41354 .56985 L .41449 .56713 L F
.764 .83 .903 r
.36265 .64246 m .36476 .64445 L .36133 .64392 L F
.486 0 0 r
.36133 .64392 m .36476 .64445 L .36352 .64483 L F
.822 .836 .86 r
.36712 .64168 m .36476 .64445 L .36265 .64246 L F
.259 0 0 r
.36352 .64483 m .36476 .64445 L .36726 .6449 L F
.667 .796 .943 r
.36752 .64381 m .36476 .64445 L .36712 .64168 L F
.36476 .64445 m .36752 .64381 L .36726 .6449 L F
.481 .055 .154 r
.27014 .56689 m .27266 .56708 L .27407 .56507 L F
.225 0 0 r
.27266 .56708 m .27659 .5647 L .27407 .56507 L F
.283 0 .132 r
.26734 .57623 m .26636 .57455 L .26886 .57384 L F
.26734 .57623 m .26499 .57689 L .26636 .57455 L F
0 0 .52 r
.60871 .40846 m .61081 .41153 L .60996 .40998 L F
.927 .556 .147 r
.61081 .41153 m .6101 .41264 L .60996 .40998 L F
.61081 .41153 m .61149 .41401 L .6101 .41264 L F
.364 .378 .742 r
.46725 .55411 m .46626 .55822 L .46501 .55467 L F
.46725 .55411 m .46819 .55813 L .46626 .55822 L F
0 0 .281 r
.32233 .55092 m .3209 .55289 L .32159 .54938 L F
.789 .495 .491 r
.32744 .62605 m .32562 .62873 L .3252 .62534 L F
.32744 .62605 m .32786 .62793 L .32562 .62873 L F
.452 .216 .465 r
.32979 .62575 m .32744 .62605 L .33011 .62441 L F
.598 .466 .673 r
.32979 .62575 m .32786 .62793 L .32744 .62605 L F
.656 .648 .83 r
.71338 .34767 m .71434 .34975 L .71603 .34681 L F
.459 0 0 r
.32711 .56158 m .32483 .56238 L .32511 .56184 L F
.859 .916 .868 r
.32711 .56158 m .32757 .55854 L .32866 .56 L F
.32711 .56158 m .32511 .56184 L .32757 .55854 L F
.213 0 0 r
.32929 .5633 m .32483 .56238 L .32711 .56158 L F
.545 .071 .08 r
.70384 .30755 m .70717 .30625 L .70382 .30545 L F
.70384 .30755 m .7061 .30768 L .70717 .30625 L F
.796 .372 .241 r
.70717 .30625 m .7061 .30768 L .7086 .30822 L F
0 0 .373 r
.41127 .5512 m .41257 .55571 L .41236 .55385 L F
.92 .841 .391 r
.41205 .55824 m .41236 .55385 L .41257 .55571 L F
.708 .615 .75 r
.35021 .51541 m .34647 .51364 L .34812 .5157 L F
.921 .959 .79 r
.35021 .51541 m .35058 .51259 L .35296 .51435 L F
.35021 .51541 m .34812 .5157 L .35058 .51259 L F
.725 .58 .692 r
.34278 .57668 m .34017 .5781 L .33959 .57467 L F
.653 .602 .785 r
.45959 .48482 m .45682 .48543 L .4555 .48178 L F
.62 .522 .722 r
.45974 .48709 m .45682 .48543 L .45959 .48482 L F
.466 .07 .203 r
.3532 .54659 m .35262 .54809 L .35025 .54797 L F
.987 .758 .505 r
.62781 .41779 m .62935 .42077 L .62901 .41982 L F
.582 .68 .908 r
.63125 .41721 m .62935 .42077 L .62781 .41779 L F
.63125 .41721 m .63181 .42017 L .62935 .42077 L F
.459 .395 .698 r
.63165 .42283 m .62935 .42077 L .63181 .42017 L F
.63165 .42283 m .62974 .4239 L .62935 .42077 L F
.501 0 0 r
.5754 .41798 m .57165 .41755 L .57423 .41437 L F
.723 .671 .799 r
.57656 .41319 m .5754 .41798 L .57423 .41437 L F
.57656 .41319 m .57866 .41537 L .5754 .41798 L F
.508 .31 .547 r
.5754 .41798 m .57793 .42034 L .57669 .41998 L F
0 .388 .794 r
.36953 .66909 m .37087 .67016 L .36819 .66848 L F
.55 .483 .733 r
.37816 .59012 m .3798 .59331 L .38211 .59027 L F
.58 .213 .31 r
.30106 .6184 m .3039 .61857 L .30459 .61587 L F
.119 0 .202 r
.30459 .61587 m .30678 .6153 L .30721 .61274 L F
.292 0 .219 r
.30459 .61587 m .30611 .61784 L .30678 .6153 L F
.30459 .61587 m .3039 .61857 L .30611 .61784 L F
.512 .858 .993 r
.31517 .66785 m .31675 .66872 L .31931 .6679 L F
.628 .125 .035 r
.33074 .69839 m .33302 .69716 L .33485 .699 L F
.295 .312 .708 r
.47391 .57026 m .47199 .57203 L .47129 .56809 L F
0 0 .013 r
.47391 .57026 m .47274 .57467 L .47199 .57203 L F
.174 .289 .743 r
.33777 .55515 m .33826 .55061 L .33816 .55253 L F
.872 .926 .858 r
.42042 .59948 m .42184 .60043 L .42432 .59766 L F
.603 .331 .478 r
.25149 .61542 m .25386 .61601 L .2551 .61303 L F
.388 0 0 r
.37065 .63711 m .36976 .63558 L .3682 .63764 L F
.37065 .63711 m .3724 .63538 L .36976 .63558 L F
.292 .79 .827 r
.24213 .52609 m .24323 .52553 L .2447 .52548 L F
0 0 0 r
.24213 .52609 m .24049 .52841 L .24323 .52553 L F
.35 .627 .956 r
.35178 .6881 m .35112 .69022 L .34977 .68827 L F
.599 .311 .452 r
.35392 .69288 m .35112 .69022 L .3508 .69267 L F
.35392 .69288 m .35506 .68948 L .35112 .69022 L F
.578 .594 .833 r
.35178 .6881 m .3508 .69267 L .35112 .69022 L F
.605 .418 .602 r
.63165 .42283 m .62965 .4271 L .62974 .4239 L F
.593 .833 .99 r
.50778 .45958 m .50767 .46096 L .51035 .46162 L F
.50778 .45958 m .50646 .45946 L .50767 .46096 L F
.50778 .45958 m .50876 .45681 L .50646 .45946 L F
.50778 .45958 m .51047 .45892 L .50876 .45681 L F
.545 .31 .51 r
.50778 .45958 m .51047 .45892 L .51035 .46162 L F
.931 .873 .758 r
.38965 .60957 m .38715 .61409 L .38643 .61245 L F
.38965 .60957 m .38958 .60963 L .38893 .61176 L F
.38958 .60963 m .38643 .61245 L .38893 .61176 L F
.117 .028 .469 r
.38643 .61245 m .38838 .6136 L .38893 .61176 L F
.493 .437 .723 r
.38838 .6136 m .38846 .6133 L .38893 .61176 L F
.38846 .6133 m .38941 .60985 L .38893 .61176 L F
.931 .873 .758 r
.38965 .60957 m .38893 .61176 L .3894 .60901 L F
.818 .982 .7 r
.38965 .60957 m .3894 .60901 L .39178 .60583 L F
.691 .883 .969 r
.72558 .34058 m .72725 .33778 L .72402 .33891 L F
.975 .688 .297 r
.72498 .3409 m .72392 .3417 L .72574 .33992 L F
.431 .821 .595 r
.72392 .3417 m .72558 .34058 L .72279 .34257 L F
.743 .253 .073 r
.72657 .34221 m .72558 .34058 L .72392 .3417 L F
.974 .823 .632 r
.72426 .34471 m .72657 .34221 L .72392 .3417 L F
.431 .821 .595 r
.72392 .3417 m .72279 .34257 L .72232 .34291 L F
.72392 .3417 m .72232 .34291 L .7218 .34308 L F
.409 .215 .504 r
.7218 .34308 m .72426 .34471 L .72392 .3417 L F
.975 .688 .297 r
.72392 .3417 m .72426 .34471 L .72311 .34328 L F
.72311 .34328 m .72426 .34471 L .72392 .3417 L F
.72311 .34328 m .72392 .3417 L .72498 .3409 L F
.691 .883 .969 r
.72558 .34058 m .7273 .33963 L .72725 .33778 L F
.98 .74 .503 r
.35453 .68235 m .35652 .68048 L .35526 .67973 L F
.35453 .68235 m .35622 .6837 L .35652 .68048 L F
.99 .756 .487 r
.53467 .4169 m .53509 .41473 L .53357 .41364 L F
.012 .587 .725 r
.53746 .41718 m .53509 .41473 L .53467 .4169 L F
.212 0 .163 r
.458 .58666 m .45481 .58948 L .45566 .58752 L F
.886 .781 .74 r
.42528 .52365 m .42454 .52679 L .42634 .52487 L F
.979 .782 .366 r
.40264 .58535 m .40326 .58447 L .40229 .58287 L F
.761 .935 .942 r
.68421 .38503 m .68525 .38613 L .68741 .38435 L F
.788 .38 0 r
.41307 .56227 m .41288 .56285 L .41225 .56072 L F
.41307 .56227 m .41415 .56455 L .41288 .56285 L F
.614 .344 .485 r
.35261 .62275 m .35191 .62546 L .35002 .62283 L F
.931 .686 .546 r
.35261 .62275 m .35191 .62546 L .35002 .62283 L F
0 .116 .585 r
.36055 .5024 m .35992 .50202 L .35841 .50023 L F
.631 .069 0 r
.35992 .50202 m .36246 .504 L .36426 .50429 L F
0 .116 .585 r
.36055 .5024 m .36246 .504 L .35992 .50202 L F
.648 .596 .782 r
.71682 .35845 m .72198 .35654 L .71797 .35566 L F
.865 .878 .845 r
.47636 .45311 m .47157 .45545 L .47529 .45251 L F
.43 .865 .918 r
.47889 .45226 m .47636 .45311 L .47529 .45251 L F
.6 .532 .75 r
.47889 .45226 m .47672 .45557 L .47636 .45311 L F
.473 .439 .74 r
.3835 .54859 m .38081 .5476 L .38326 .54569 L F
.488 .545 .841 r
.38326 .54569 m .38151 .54208 L .38566 .5426 L F
.766 .703 .792 r
.38151 .54208 m .38326 .54569 L .38566 .5426 L F
.307 .754 .961 r
.38151 .54208 m .38448 .54188 L .38566 .5426 L F
.488 .545 .841 r
.38326 .54569 m .38448 .54188 L .38151 .54208 L F
.424 .232 .514 r
.38326 .54569 m .38559 .54527 L .38566 .5426 L F
.488 .545 .841 r
.38326 .54569 m .38559 .54527 L .38448 .54188 L F
.034 .055 .55 r
.29817 .6406 m .29673 .6427 L .29658 .6385 L F
.282 0 0 r
.29955 .64372 m .29673 .6427 L .29817 .6406 L F
0 0 .064 r
.32284 .61232 m .32089 .61578 L .32171 .61347 L F
.591 .556 .784 r
.45816 .52601 m .45587 .52691 L .45465 .52351 L F
.419 .253 .548 r
.45816 .52601 m .45597 .52986 L .45587 .52691 L F
.896 .703 .192 r
.41503 .57488 m .41502 .57745 L .41459 .57643 L F
.526 .004 0 r
.60516 .45919 m .60348 .46103 L .60315 .45943 L F
.60516 .45919 m .60629 .46088 L .60348 .46103 L F
.60516 .45919 m .60808 .4597 L .60629 .46088 L F
.281 .783 .829 r
.26823 .62069 m .27073 .62011 L .27236 .62009 L F
0 .137 .683 r
.27361 .62006 m .27236 .62009 L .27073 .62011 L F
.27361 .62006 m .27443 .62215 L .27236 .62009 L F
.622 .449 .628 r
.45819 .4917 m .45835 .49445 L .45563 .49482 L F
.591 .426 .626 r
.4609 .49119 m .45835 .49445 L .45819 .4917 L F
.498 .834 .998 r
.41895 .48407 m .4147 .4837 L .4166 .48478 L F
.827 .681 .701 r
.41537 .48704 m .41895 .48407 L .4166 .48478 L F
.346 .441 .816 r
.71102 .31229 m .70903 .31232 L .70893 .3101 L F
.71102 .31229 m .70915 .31495 L .70903 .31232 L F
.58 .544 .779 r
.35607 .60749 m .35692 .60999 L .35359 .60999 L F
0 0 0 r
.35607 .60749 m .35359 .60999 L .35459 .60923 L F
.437 .246 .522 r
.35596 .61194 m .35359 .60999 L .35692 .60999 L F
.35359 .60999 m .35596 .61194 L .35459 .60923 L F
.35359 .60999 m .35367 .61273 L .35596 .61194 L F
.35596 .61194 m .35367 .61273 L .35359 .60999 L F
.706 .597 .732 r
.33331 .54594 m .33363 .54982 L .33085 .54961 L F
.735 .329 .28 r
.32884 .5508 m .33293 .55145 L .33363 .54982 L F
.423 .626 .937 r
.33188 .54685 m .33363 .54982 L .334 .5466 L F
.66 .763 .283 r
.33363 .54982 m .33369 .5496 L .334 .5466 L F
.33363 .54982 m .33293 .55145 L .33369 .5496 L F
.47 .889 .911 r
.25165 .52362 m .25251 .52259 L .25382 .52265 L F
.25165 .52362 m .25008 .52356 L .25251 .52259 L F
.432 .247 .529 r
.36523 .5395 m .36766 .53912 L .36746 .53644 L F
.209 .052 .438 r
.36523 .5395 m .3669 .54121 L .36766 .53912 L F
.36523 .5395 m .36523 .5423 L .3669 .54121 L F
.716 .809 .923 r
.38476 .67696 m .3825 .67823 L .38082 .67663 L F
.38476 .67696 m .3825 .67823 L .38082 .67663 L F
.935 .719 .241 r
.33684 .61016 m .33669 .61249 L .33606 .61142 L F
.388 .136 .407 r
.33899 .61188 m .33684 .61016 L .3405 .60872 L F
.33899 .61188 m .33669 .61249 L .33684 .61016 L F
.885 .905 .837 r
.38889 .49711 m .38977 .4928 L .39171 .49487 L F
.548 .783 .986 r
.39193 .49699 m .38889 .49711 L .39171 .49487 L F
.879 .881 .832 r
.39414 .49099 m .39171 .49487 L .38977 .4928 L F
.47 .806 .999 r
.39464 .49439 m .39171 .49487 L .39414 .49099 L F
0 0 0 r
.32695 .55158 m .33085 .54961 L .32656 .54872 L F
.32695 .55158 m .32884 .5508 L .33085 .54961 L F
.788 .921 .926 r
.64337 .41062 m .64224 .41164 L .64053 .41077 L F
.978 .782 .571 r
.64053 .41077 m .64224 .41164 L .6413 .41438 L F
.876 .895 .842 r
.64997 .39245 m .64597 .39428 L .64924 .39146 L F
.801 .976 .904 r
.65116 .39105 m .64997 .39245 L .64924 .39146 L F
.69 .182 0 r
.36452 .50545 m .36426 .50429 L .36246 .504 L F
.36452 .50545 m .36611 .50669 L .36426 .50429 L F
0 0 0 r
.22873 .54026 m .22717 .54122 L .23087 .53921 L F
.717 .655 .787 r
.52437 .4489 m .52589 .45316 L .5217 .45247 L F
.743 .499 .561 r
.5217 .45247 m .52589 .45316 L .52569 .45558 L F
.79 .692 .756 r
.5283 .44926 m .52589 .45316 L .52437 .4489 L F
.401 .13 .384 r
.35781 .5814 m .35956 .58309 L .35983 .58054 L F
.35781 .5814 m .35719 .58376 L .35956 .58309 L F
.725 .778 .895 r
.62174 .3553 m .61759 .35549 L .62051 .35306 L F
.742 .785 .888 r
.62051 .35306 m .62437 .35353 L .62174 .3553 L F
0 0 .144 r
.3473 .60276 m .34634 .60364 L .34798 .60017 L F
0 0 .122 r
.34681 .6049 m .34634 .60364 L .3473 .60276 L F
.34681 .6049 m .34588 .60643 L .34634 .60364 L F
.864 .876 .844 r
.40203 .66092 m .40256 .657 L .4022 .65975 L F
0 0 0 r
.3284 .53623 m .32705 .53835 L .32825 .53584 L F
.722 .627 .752 r
.37487 .58416 m .37864 .58531 L .37701 .58348 L F
.645 .763 .934 r
.37701 .58348 m .37864 .58531 L .38075 .58428 L F
.661 .739 .908 r
.39577 .65405 m .39383 .65523 L .39255 .6533 L F
.616 .278 .375 r
.26396 .56831 m .26621 .57057 L .26792 .56693 L F
.511 .168 .322 r
.26792 .56693 m .26889 .5702 L .27014 .56689 L F
.26792 .56693 m .26621 .57057 L .26889 .5702 L F
.775 .624 .693 r
.22164 .6005 m .2225 .60414 L .21843 .6028 L F
.278 .777 .873 r
.22306 .60286 m .22044 .60303 L .2207 .60335 L F
0 .501 .816 r
.21843 .6028 m .22091 .60362 L .2207 .60335 L F
.874 .475 .017 r
.2165 .5996 m .21843 .6028 L .2172 .60137 L F
.743 .229 0 r
.2207 .60335 m .2172 .60137 L .21843 .6028 L F
.2207 .60335 m .21827 .60316 L .2172 .60137 L F
.278 .777 .873 r
.22044 .60303 m .21827 .60316 L .2207 .60335 L F
0 .501 .816 r
.22091 .60362 m .2225 .60414 L .2207 .60335 L F
.453 .819 .995 r
.2225 .60414 m .22306 .60286 L .2207 .60335 L F
.2225 .60414 m .22496 .6037 L .22306 .60286 L F
.528 .775 .988 r
.37114 .68284 m .37574 .68323 L .37335 .68384 L F
.37335 .68384 m .37574 .68323 L .37114 .68284 L F
.17 .292 .747 r
.4284 .59034 m .42623 .59 L .42541 .58925 L F
.469 .287 .551 r
.34207 .5714 m .34195 .5743 L .33959 .57467 L F
.898 .931 .829 r
.43222 .58382 m .4352 .58257 L .43383 .58325 L F
.738 .457 .504 r
.36043 .57821 m .35983 .58054 L .3554 .5796 L F
.508 .303 .537 r
.35983 .58054 m .3626 .57728 L .36043 .57821 L F
.35983 .58054 m .3626 .57728 L .36043 .57821 L F
.667 .831 .962 r
.38832 .64799 m .39336 .64799 L .39083 .64477 L F
0 .135 .673 r
.39083 .64477 m .39336 .64799 L .39321 .64704 L F
.762 .524 .573 r
.39378 .6476 m .39146 .64505 L .39342 .64728 L F
0 .135 .673 r
.39291 .6467 m .39321 .64704 L .3932 .64697 L F
.39083 .64477 m .39321 .64704 L .39291 .6467 L F
.762 .524 .573 r
.39378 .6476 m .3975 .64451 L .39146 .64505 L F
0 .135 .673 r
.39083 .64477 m .39291 .6467 L .39095 .6451 L F
.762 .524 .573 r
.39342 .64728 m .39291 .6467 L .39095 .6451 L F
0 .135 .673 r
.39291 .6467 m .3932 .64697 L .39095 .6451 L F
.762 .524 .573 r
.39291 .6467 m .39146 .64505 L .39095 .6451 L F
.376 .837 .898 r
.395 .64414 m .39083 .64477 L .39095 .6451 L F
.401 0 0 r
.39095 .6451 m .3975 .64451 L .395 .64414 L F
.233 .519 .913 r
.36539 .71225 m .36917 .71576 L .36949 .71531 L F
.038 0 .166 r
.38626 .62282 m .38748 .62433 L .38624 .62533 L F
.38626 .62282 m .38876 .62181 L .38748 .62433 L F
.481 .36 .638 r
.4545 .50826 m .45206 .51064 L .45178 .50886 L F
.862 .932 .869 r
.67152 .39316 m .67414 .39318 L .67542 .39152 L F
.309 .166 .519 r
.23617 .57761 m .236 .58039 L .2342 .58117 L F
.213 .07 .46 r
.23562 .58297 m .2342 .58117 L .236 .58039 L F
.163 0 0 r
.2374 .58227 m .23732 .5823 L .23562 .58297 L F
.213 .07 .46 r
.23562 .58297 m .23402 .58415 L .23406 .58358 L F
.689 .943 .66 r
.23324 .58394 m .23402 .58415 L .23562 .58297 L F
.163 0 0 r
.23732 .5823 m .23324 .58394 L .23562 .58297 L F
.213 .07 .46 r
.23562 .58297 m .23406 .58358 L .2342 .58117 L F
.179 .426 .861 r
.34079 .51728 m .34475 .52079 L .34156 .51618 L F
.745 .522 .592 r
.34079 .51728 m .34475 .52079 L .34084 .51989 L F
0 0 .308 r
.34079 .51728 m .34084 .51989 L .34156 .51618 L F
.45 .095 .27 r
.27172 .57191 m .27143 .57344 L .26886 .57384 L F
.449 .02 .131 r
.27562 .57148 m .27143 .57344 L .27172 .57191 L F
.842 .544 .006 r
.40866 .54288 m .40855 .544 L .40805 .54159 L F
.40866 .54288 m .40921 .54544 L .40855 .544 L F
.238 0 .107 r
.336 .68059 m .33249 .68369 L .3349 .68289 L F
.111 0 .051 r
.33833 .67933 m .336 .68059 L .3349 .68289 L F
.14 0 .131 r
.35226 .55596 m .3516 .55727 L .35424 .55495 L F
0 0 .24 r
.24439 .5343 m .24346 .53323 L .2451 .53196 L F
0 .056 .587 r
.33012 .58868 m .32777 .58659 L .33028 .586 L F
.885 .976 .83 r
.5436 .41075 m .53986 .4134 L .5429 .41048 L F
.563 .874 .994 r
.54496 .40892 m .5436 .41075 L .5429 .41048 L F
.54496 .40892 m .5471 .4097 L .5436 .41075 L F
.878 .502 .328 r
.51715 .45128 m .51965 .45353 L .51963 .45553 L F
.681 .599 .758 r
.52211 .44993 m .5217 .45247 L .51965 .45353 L F
.752 .509 .563 r
.5217 .45247 m .51963 .45553 L .51965 .45353 L F
.792 .668 .727 r
.38792 .67332 m .3841 .67285 L .38561 .67337 L F
.365 .601 .938 r
.38792 .67332 m .38841 .6712 L .38582 .67005 L F
.38792 .67332 m .38994 .67319 L .38841 .6712 L F
.38841 .6712 m .38792 .67332 L .38561 .67337 L F
.38841 .6712 m .38994 .67319 L .38792 .67332 L F
.612 .426 .606 r
.45835 .49445 m .45567 .49763 L .45563 .49482 L F
.648 .896 .562 r
.32696 .49608 m .32857 .49455 L .32579 .49788 L F
.39 .214 .519 r
.32579 .49788 m .32769 .50005 L .32696 .49608 L F
.32579 .49788 m .3258 .50057 L .32769 .50005 L F
.459 .186 .411 r
.22598 .57751 m .22876 .57474 L .22608 .57477 L F
.866 .974 .855 r
.67529 .33006 m .67894 .32794 L .67864 .32757 L F
.78 .992 .884 r
.67894 .32794 m .68206 .32543 L .68025 .32516 L F
.782 .974 .69 r
.68025 .32516 m .67864 .32757 L .67894 .32794 L F
.455 .279 .552 r
.29759 .53326 m .29978 .53479 L .3003 .53317 L F
.29759 .53326 m .29711 .53607 L .29978 .53479 L F
.768 .389 .338 r
.52569 .45558 m .53016 .45674 L .53001 .45847 L F
.709 .431 .502 r
.534 .45606 m .53001 .45847 L .53016 .45674 L F
.918 .951 .801 r
.42977 .55365 m .43206 .55333 L .43015 .55229 L F
.42977 .55365 m .43054 .5554 L .43206 .55333 L F
.19 .079 .489 r
.39948 .66792 m .39874 .66997 L .39761 .6676 L F
0 0 0 r
.21914 .55139 m .22254 .54772 L .22102 .5496 L F
.931 .686 .546 r
.35261 .62275 m .35398 .62598 L .35191 .62546 L F
.907 .563 .38 r
.35191 .62546 m .35398 .62598 L .35219 .62769 L F
.931 .686 .546 r
.35191 .62546 m .35398 .62598 L .35261 .62275 L F
.907 .563 .38 r
.35191 .62546 m .35398 .62598 L .35219 .62769 L F
.682 .847 .962 r
.53467 .4169 m .53216 .41834 L .53129 .4169 L F
0 0 0 r
.53467 .4169 m .53216 .41834 L .53072 .41942 L F
.682 .847 .962 r
.53129 .4169 m .53216 .41834 L .53467 .4169 L F
.474 .273 .527 r
.47672 .45557 m .47572 .45916 L .47449 .45908 L F
.6 .532 .75 r
.47889 .45226 m .47974 .45604 L .47672 .45557 L F
.664 .489 .637 r
.47974 .45604 m .47572 .45916 L .47672 .45557 L F
.931 .971 .72 r
.414 .49567 m .41406 .49849 L .41553 .49498 L F
.463 .233 .479 r
.414 .49567 m .41313 .4985 L .41406 .49849 L F
.528 .398 .647 r
.45567 .49763 m .45589 .50021 L .45338 .50087 L F
.722 .302 .247 r
.35866 .686 m .36284 .68785 L .35962 .68449 L F
.44 .199 .451 r
.3574 .56532 m .36003 .56466 L .36057 .56201 L F
.352 .097 .381 r
.3574 .56532 m .35913 .56688 L .36003 .56466 L F
.3574 .56532 m .35696 .56766 L .35913 .56688 L F
.875 .903 .847 r
.23215 .60564 m .23599 .60382 L .23363 .60585 L F
0 0 0 r
.23669 .60223 m .23599 .60382 L .23654 .60238 L F
.616 .353 .496 r
.24022 .60026 m .24033 .60242 L .23656 .60238 L F
.23657 .60237 m .23656 .60238 L .23654 .60238 L F
.24022 .60026 m .23656 .60238 L .23657 .60237 L F
.24022 .60026 m .24033 .60242 L .23654 .60238 L F
.139 .676 .849 r
.23654 .60238 m .24033 .60242 L .23669 .60223 L F
0 0 0 r
.23598 .60462 m .23598 .6043 L .23669 .60223 L F
.23598 .6043 m .23599 .60382 L .23642 .60284 L F
.23598 .6043 m .23642 .60284 L .23669 .60223 L F
.23598 .60462 m .23363 .60585 L .23599 .60382 L F
.649 .729 .907 r
.70603 .28345 m .70209 .2827 L .70509 .27912 L F
.794 .977 .693 r
.70603 .28345 m .70861 .28019 L .70764 .28127 L F
.901 .667 .157 r
.70561 .28502 m .70619 .28588 L .70603 .28345 L F
.793 .543 .56 r
.70969 .28659 m .70603 .28345 L .70619 .28588 L F
.901 .667 .157 r
.70561 .28502 m .70603 .28345 L .70764 .28127 L F
.701 .901 .537 r
.41324 .50352 m .41294 .50353 L .41519 .50039 L F
.562 .539 .787 r
.25726 .56791 m .26096 .57128 L .26137 .56811 L F
.32 .004 .262 r
.26096 .57128 m .26396 .56831 L .26137 .56811 L F
.433 .806 .993 r
.36133 .61848 m .36588 .61911 L .36375 .61806 L F
.36133 .61848 m .36588 .61911 L .36375 .61806 L F
.42 .74 .992 r
.36654 .61719 m .36588 .61911 L .36816 .6188 L F
.36 .768 .982 r
.36816 .6188 m .36588 .61911 L .36375 .61806 L F
.36375 .61806 m .36588 .61911 L .36816 .6188 L F
.657 .755 .922 r
.61303 .35787 m .60859 .35717 L .61131 .35631 L F
.712 .764 .893 r
.61131 .35631 m .61528 .35694 L .61303 .35787 L F
.906 .662 .558 r
.29633 .62461 m .29318 .62204 L .29588 .62204 L F
.29633 .62461 m .29279 .62392 L .29318 .62204 L F
.754 .26 .058 r
.29633 .62461 m .29429 .62531 L .29279 .62392 L F
.503 .441 .72 r
.29861 .62183 m .29633 .62461 L .29588 .62204 L F
.904 .976 .686 r
.72334 .35157 m .72609 .34728 L .72574 .34632 L F
.953 .889 .729 r
.72609 .34728 m .72657 .34221 L .72574 .34632 L F
.026 0 .328 r
.33669 .61249 m .33641 .61505 L .33452 .61641 L F
.119 .034 .475 r
.33641 .61505 m .33459 .61913 L .33452 .61641 L F
0 0 0 r
.33296 .53027 m .33439 .52969 L .33507 .52899 L F
0 0 .115 r
.22808 .56591 m .22713 .56782 L .22747 .56516 L F
.22808 .56591 m .22747 .56516 L .2254 .56404 L F
.214 0 .144 r
.34911 .52592 m .34862 .52455 L .35081 .52579 L F
.34866 .52596 m .34863 .52482 L .34911 .52592 L F
.34863 .52482 m .34862 .52455 L .34911 .52592 L F
.76 .536 .593 r
.34793 .52215 m .34911 .52592 L .35081 .52579 L F
.34911 .52592 m .34936 .52673 L .35081 .52579 L F
0 0 .33 r
.34922 .52619 m .34936 .52673 L .34911 .52592 L F
.614 .789 .965 r
.34793 .52215 m .34993 .51945 L .34762 .52058 L F
.34793 .52215 m .3515 .52299 L .34993 .51945 L F
0 0 .33 r
.3479 .5209 m .34922 .52619 L .34793 .52215 L F
.34922 .52619 m .34911 .52592 L .34793 .52215 L F
.214 0 .144 r
.3487 .52724 m .3469 .52858 L .34862 .52455 L F
.956 .705 .254 r
.3479 .5209 m .34922 .52619 L .34808 .52356 L F
.34922 .52619 m .34936 .52673 L .34919 .52631 L F
.214 0 .144 r
.34925 .52609 m .34866 .52596 L .3493 .52591 L F
.956 .705 .254 r
.34922 .52619 m .34919 .52631 L .34808 .52356 L F
.214 0 .144 r
.34963 .52617 m .34925 .52609 L .35081 .52579 L F
.34925 .52609 m .3493 .52591 L .35081 .52579 L F
.34868 .52648 m .34867 .52621 L .34963 .52617 L F
.34867 .52621 m .34866 .52596 L .34963 .52617 L F
0 .147 .687 r
.3515 .52299 m .35196 .52149 L .34993 .51945 L F
.75 .701 .805 r
.35196 .52149 m .34963 .52617 L .3479 .5209 L F
.34963 .52617 m .34936 .52673 L .34922 .52619 L F
.34963 .52617 m .34922 .52619 L .3479 .5209 L F
.879 .878 .83 r
.35081 .52579 m .34936 .52673 L .34963 .52617 L F
.214 0 .144 r
.3487 .52724 m .34868 .52648 L .35081 .52579 L F
.879 .878 .83 r
.35081 .52579 m .34963 .52617 L .3505 .52443 L F
.714 .254 .158 r
.35461 .52398 m .35248 .52422 L .3515 .52299 L F
.879 .878 .83 r
.35081 .52579 m .3515 .52299 L .35336 .52532 L F
.35081 .52579 m .35196 .52149 L .3515 .52299 L F
.35119 .52436 m .3505 .52443 L .35196 .52149 L F
.35081 .52579 m .3505 .52443 L .35119 .52436 L F
.714 .254 .158 r
.35573 .52434 m .35336 .52532 L .35248 .52422 L F
.35573 .52434 m .35248 .52422 L .35461 .52398 L F
.873 .946 .859 r
.35569 .52174 m .35573 .52434 L .35718 .52248 L F
.924 .965 .777 r
.35569 .52174 m .35336 .52532 L .35573 .52434 L F
.564 .311 .492 r
.35429 .55219 m .35714 .55195 L .35777 .54954 L F
.29 .06 .382 r
.35777 .54954 m .35933 .551 L .35942 .54833 L F
.35777 .54954 m .35714 .55195 L .35933 .551 L F
.261 .331 .746 r
.35962 .55944 m .36057 .56201 L .36149 .56093 L F
0 0 .159 r
.36057 .56201 m .36098 .5634 L .36149 .56093 L F
.36057 .56201 m .36003 .56466 L .36098 .5634 L F
.842 .706 .712 r
.52927 .43117 m .52815 .4335 L .52672 .42978 L F
.99 .726 .385 r
.692 .37744 m .69339 .37632 L .69346 .37368 L F
.692 .37744 m .69327 .37881 L .69339 .37632 L F
.825 .725 .754 r
.65069 .41117 m .65405 .4116 L .65285 .40773 L F
.829 .85 .863 r
.64958 .41337 m .65405 .4116 L .65069 .41117 L F
.872 .926 .858 r
.42042 .59948 m .42432 .59766 L .42284 .59682 L F
.363 .726 .988 r
.42432 .59766 m .42526 .59634 L .42284 .59682 L F
.997 .78 .436 r
.38348 .57795 m .38314 .5809 L .38209 .57962 L F
.38348 .57795 m .38314 .5809 L .38209 .57962 L F
.676 .429 .54 r
.38587 .58029 m .38314 .5809 L .38348 .57795 L F
.646 .508 .68 r
.40291 .67521 m .4018 .67997 L .40193 .67715 L F
0 0 0 r
.40446 .67399 m .40252 .67609 L .40291 .67521 L F
.582 .532 .764 r
.38587 .58029 m .38488 .58435 L .38314 .5809 L F
.985 .769 .531 r
.40292 .67302 m .40252 .67609 L .40446 .67399 L F
.628 .689 .888 r
.38073 .61134 m .38136 .61356 L .38384 .61274 L F
.774 .978 .71 r
.31842 .63533 m .32159 .63169 L .32052 .63495 L F
.048 0 0 r
.31842 .63533 m .32052 .63495 L .3218 .63519 L F
.305 .24 .618 r
.32355 .63407 m .32052 .63495 L .32159 .63169 L F
0 0 0 r
.3218 .63519 m .32052 .63495 L .32355 .63407 L F
.647 .757 .929 r
.40981 .48414 m .40614 .4835 L .40848 .48271 L F
.473 .439 .74 r
.3835 .54859 m .38115 .55066 L .38081 .5476 L F
.496 .319 .571 r
.3835 .54859 m .38035 .55174 L .38115 .55066 L F
.507 .371 .631 r
.23574 .56908 m .23739 .57079 L .23785 .56832 L F
.52 .249 .445 r
.23785 .56832 m .23739 .57079 L .24011 .56854 L F
.481 .898 .839 r
.29886 .5163 m .30326 .5146 L .30239 .51639 L F
.857 .921 .528 r
.30326 .5146 m .30502 .51049 L .30459 .5128 L F
0 0 0 r
.30239 .51639 m .30326 .5146 L .30459 .5128 L F
.556 .512 .762 r
.62773 .42978 m .6281 .43317 L .62548 .43387 L F
.502 .332 .582 r
.6281 .43317 m .62607 .43674 L .62548 .43387 L F
0 .165 .651 r
.35195 .70944 m .35272 .70986 L .35128 .70835 L F
.076 .616 .853 r
.35272 .70986 m .35728 .71045 L .35502 .70981 L F
.35272 .70986 m .35502 .70981 L .35319 .70989 L F
.35272 .70986 m .35319 .70989 L .35156 .70996 L F
0 .165 .651 r
.35195 .70944 m .35248 .70985 L .35272 .70986 L F
.35248 .70985 m .35489 .71173 L .35272 .70986 L F
.558 .367 .578 r
.23709 .61025 m .23832 .61418 L .23457 .61324 L F
.543 .787 .989 r
.239 .60939 m .23709 .61025 L .2366 .6089 L F
.239 .60939 m .23966 .60985 L .23709 .61025 L F
.299 .217 .593 r
.23917 .61222 m .23832 .61418 L .23709 .61025 L F
.507 .215 .405 r
.23966 .60985 m .23917 .61222 L .23709 .61025 L F
.921 .974 .76 r
.3588 .71755 m .36315 .71326 L .36151 .71228 L F
.58 .858 .995 r
.36151 .71228 m .36315 .71326 L .36539 .71225 L F
.42 .11 .331 r
.35938 .54564 m .36186 .54511 L .36228 .54309 L F
.521 .256 .454 r
.36186 .54511 m .36523 .5423 L .36228 .54309 L F
.699 .466 .567 r
.70753 .28922 m .70969 .28659 L .70619 .28588 L F
.70753 .28922 m .70959 .28912 L .70969 .28659 L F
.523 0 0 r
.31173 .52682 m .31457 .52821 L .31453 .52749 L F
.583 .501 .728 r
.31912 .52986 m .31613 .53046 L .31453 .52749 L F
0 .514 .841 r
.31457 .52821 m .31912 .52986 L .31453 .52749 L F
.787 .708 .776 r
.65532 .40449 m .65914 .40499 L .65787 .4012 L F
.73 .678 .8 r
.65787 .4012 m .65914 .40499 L .66196 .40198 L F
.612 .955 .891 r
.58505 .42246 m .58336 .42428 L .58302 .42379 L F
.125 0 0 r
.23832 .61418 m .23262 .61328 L .23457 .61324 L F
.559 .582 .834 r
.3436 .70209 m .3449 .70549 L .34743 .70461 L F
.936 .574 .299 r
.72973 .33622 m .73131 .33574 L .73036 .33443 L F
.707 .424 .493 r
.534 .45606 m .53644 .45632 L .53652 .45872 L F
.767 .508 .542 r
.53644 .45632 m .54027 .45926 L .53652 .45872 L F
.889 .776 .731 r
.73707 .33681 m .73876 .33867 L .73938 .33678 L F
.73938 .33678 m .73876 .33867 L .73707 .33681 L F
.73707 .33681 m .73876 .33867 L .73938 .33678 L F
.759 .7 .796 r
.61093 .3688 m .61176 .37041 L .6091 .37325 L F
.514 .378 .633 r
.32471 .50748 m .32714 .50684 L .32683 .5042 L F
.427 .157 .399 r
.32661 .50914 m .32471 .50748 L .32301 .50938 L F
.595 .596 .823 r
.3291 .50811 m .32471 .50748 L .32714 .50684 L F
.427 .157 .399 r
.32661 .50914 m .32714 .50684 L .32471 .50748 L F
.514 .378 .633 r
.32471 .50748 m .32714 .50684 L .32683 .5042 L F
.897 .957 .829 r
.33016 .54399 m .33012 .54101 L .33129 .54204 L F
.33016 .54399 m .32692 .54442 L .33012 .54101 L F
.378 .119 .39 r
.35489 .58442 m .35212 .58748 L .35331 .58603 L F
.35489 .58442 m .35212 .58748 L .35331 .58603 L F
.532 .551 .82 r
.35719 .58376 m .35489 .58442 L .35324 .58041 L F
.172 0 0 r
.35489 .58442 m .35331 .58603 L .35719 .58376 L F
.887 .975 .674 r
.35328 .58571 m .35331 .58603 L .35489 .58442 L F
.373 0 .068 r
.35719 .58376 m .35328 .58571 L .35489 .58442 L F
0 0 .137 r
.31739 .59397 m .31832 .59268 L .31823 .59013 L F
0 0 0 r
.31823 .59013 m .32043 .58659 L .31893 .58707 L F
.31823 .59013 m .31974 .58872 L .32043 .58659 L F
0 0 .121 r
.31823 .59013 m .31879 .59153 L .31974 .58872 L F
.31823 .59013 m .31832 .59268 L .31879 .59153 L F
.121 .662 .842 r
.23575 .54794 m .23825 .54796 L .24087 .54833 L F
.741 .65 .758 r
.23569 .55102 m .23632 .55117 L .23766 .55108 L F
.23632 .55117 m .24009 .55207 L .23766 .55108 L F
.23569 .55102 m .2347 .55511 L .24009 .55207 L F
.593 .11 .077 r
.24217 .55093 m .23766 .55108 L .24009 .55207 L F
.24217 .55093 m .24015 .55249 L .23766 .55108 L F
.269 .367 .78 r
.23766 .55108 m .24007 .55231 L .23896 .55099 L F
.23766 .55108 m .23896 .55099 L .23801 .54985 L F
.23766 .55108 m .24015 .55249 L .24007 .55231 L F
.787 .32 .129 r
.23739 .5491 m .24087 .54833 L .23825 .54796 L F
.23753 .54927 m .24087 .54833 L .23739 .5491 L F
.23753 .54927 m .24217 .55093 L .24087 .54833 L F
.23719 .54937 m .23783 .54957 L .23753 .54927 L F
.23783 .54957 m .24217 .55093 L .23753 .54927 L F
.269 .367 .78 r
.23801 .54985 m .24007 .55231 L .23968 .55142 L F
.38 .085 .333 r
.24398 .55203 m .24299 .55086 L .24217 .55093 L F
.24299 .55086 m .24087 .54833 L .24217 .55093 L F
.198 .697 .913 r
.23783 .54957 m .24453 .55033 L .24217 .55093 L F
.23794 .54947 m .24453 .55033 L .23783 .54957 L F
.23794 .54947 m .23903 .54956 L .24453 .55033 L F
.23719 .54937 m .23806 .54945 L .23794 .54947 L F
.23719 .54937 m .23794 .54947 L .23783 .54957 L F
.577 .393 .595 r
.23575 .54794 m .23569 .55102 L .23825 .54796 L F
.783 .977 .699 r
.23569 .55102 m .23618 .54932 L .23825 .54796 L F
.269 .367 .78 r
.23766 .55108 m .23813 .54944 L .23618 .54932 L F
.787 .32 .129 r
.23719 .54937 m .23753 .54927 L .23739 .5491 L F
.611 .749 .943 r
.2384 .54849 m .24195 .54981 L .23719 .54937 L F
.269 .367 .78 r
.23813 .54944 m .2384 .54849 L .23646 .54922 L F
.23813 .54944 m .23646 .54922 L .23618 .54932 L F
.198 .697 .913 r
.23903 .54956 m .24195 .54981 L .24397 .55022 L F
.23903 .54956 m .24397 .55022 L .24453 .55033 L F
.23806 .54945 m .24195 .54981 L .23794 .54947 L F
.269 .367 .78 r
.23803 .54978 m .23968 .55142 L .23878 .54935 L F
.23825 .54942 m .23878 .54935 L .23857 .54888 L F
.23803 .54978 m .23878 .54935 L .23825 .54942 L F
.881 .977 .677 r
.24195 .54981 m .24113 .55103 L .24217 .55093 L F
.24113 .55103 m .24015 .55249 L .24217 .55093 L F
.269 .367 .78 r
.23819 .54924 m .23857 .54888 L .2384 .54849 L F
.23803 .54978 m .23857 .54888 L .23819 .54924 L F
.23801 .54985 m .23968 .55142 L .23803 .54978 L F
.556 .618 .869 r
.37651 .70999 m .37614 .71243 L .37858 .7119 L F
.941 .958 .743 r
.3747 .71203 m .37614 .71243 L .37651 .70999 L F
.562 .539 .787 r
.25726 .56791 m .25853 .57237 L .26096 .57128 L F
.51 .517 .799 r
.25853 .57237 m .26218 .57391 L .26096 .57128 L F
.388 0 0 r
.36706 .50795 m .3678 .50795 L .36611 .50669 L F
.36706 .50795 m .37042 .50926 L .3678 .50795 L F
.301 .471 .861 r
.28354 .63206 m .28198 .63225 L .28007 .62894 L F
.297 .346 .744 r
.28354 .63206 m .28467 .63411 L .28198 .63225 L F
.791 .919 .537 r
.34275 .68617 m .34405 .68431 L .34531 .68165 L F
.616 .944 .943 r
.51495 .45126 m .51715 .45128 L .51293 .45308 L F
.989 .727 .426 r
.51293 .45308 m .51293 .45567 L .51147 .45443 L F
.603 .385 .557 r
.51715 .45128 m .51293 .45567 L .51293 .45308 L F
.849 .855 .847 r
.51403 .45104 m .51381 .45258 L .51147 .45443 L F
.989 .727 .426 r
.51293 .45308 m .51147 .45443 L .51356 .45433 L F
.849 .855 .847 r
.51381 .45258 m .51356 .45433 L .51221 .45439 L F
.51381 .45258 m .51221 .45439 L .51147 .45443 L F
0 0 0 r
.51495 .45126 m .51293 .45308 L .51469 .45158 L F
.51495 .45128 m .51469 .45158 L .51495 .45136 L F
.51495 .45126 m .51469 .45158 L .51495 .45128 L F
.989 .727 .426 r
.51293 .45308 m .51356 .45433 L .51495 .45136 L F
.549 .607 .863 r
.27025 .549 m .27051 .54602 L .27291 .54575 L F
.27025 .549 m .26874 .54586 L .27051 .54602 L F
0 .159 .696 r
.29683 .61976 m .29861 .62183 L .29709 .61837 L F
.974 .686 .413 r
.32301 .50938 m .32509 .51035 L .32287 .5116 L F
.626 .072 0 r
.32301 .50938 m .32509 .51035 L .32683 .5123 L F
.938 .678 .206 r
.6137 .42292 m .61468 .4245 L .61476 .42603 L F
0 .188 .664 r
.59098 .39443 m .5927 .39604 L .59368 .39664 L F
0 0 .51 r
.22956 .6103 m .23034 .61258 L .22977 .60906 L F
.381 0 .103 r
.34337 .58385 m .34814 .58128 L .34744 .58143 L F
0 0 .247 r
.34814 .58128 m .34878 .58252 L .34889 .58067 L F
.34814 .58128 m .3481 .58435 L .34878 .58252 L F
.501 .906 .814 r
.34889 .58067 m .34744 .58143 L .34814 .58128 L F
.613 .576 .788 r
.46276 .54861 m .46153 .55316 L .46043 .54906 L F
.46276 .54861 m .46405 .55237 L .46153 .55316 L F
.927 .959 .778 r
.68303 .32028 m .68501 .31948 L .68609 .31741 L F
.693 .18 .009 r
.33723 .50068 m .33657 .50229 L .3337 .5013 L F
.33723 .50068 m .33899 .50285 L .33657 .50229 L F
.176 0 0 r
.57316 .46863 m .57591 .46826 L .57256 .46909 L F
0 0 0 r
.34107 .54169 m .34051 .5442 L .33976 .54591 L F
.766 .68 .768 r
.64125 .43073 m .64566 .43141 L .64373 .42968 L F
.64125 .43073 m .64297 .43389 L .64566 .43141 L F
0 0 .41 r
.21059 .56818 m .21216 .56961 L .21224 .56692 L F
.21059 .56818 m .2106 .57103 L .21216 .56961 L F
.656 .684 .865 r
.41616 .49181 m .41356 .48804 L .41438 .49116 L F
.41616 .49181 m .41537 .48704 L .41356 .48804 L F
.808 .597 .616 r
.41438 .49116 m .41711 .49368 L .41616 .49181 L F
.83 .741 .766 r
.37792 .55482 m .37598 .55653 L .37398 .55441 L F
.689 .201 .084 r
.37398 .55441 m .37604 .55656 L .37792 .55482 L F
.817 .487 .43 r
.37792 .55482 m .37398 .55441 L .37456 .55267 L F
.918 .947 .599 r
.37872 .55064 m .37792 .55482 L .37873 .55371 L F
.236 0 0 r
.37792 .55482 m .37702 .55495 L .37651 .55467 L F
.918 .947 .599 r
.37872 .55064 m .37702 .55495 L .37792 .55482 L F
0 0 0 r
.37873 .55371 m .37737 .55514 L .37702 .55495 L F
.37737 .55514 m .37604 .55656 L .37702 .55495 L F
.236 0 0 r
.37651 .55467 m .37702 .55495 L .37398 .55441 L F
.571 .862 .544 r
.37792 .55482 m .37604 .55656 L .37873 .55371 L F
.582 .318 .482 r
.30254 .53243 m .29978 .53479 L .3003 .53317 L F
.29978 .53479 m .30254 .53243 L .3003 .53317 L F
.699 .853 .956 r
.25005 .53807 m .2477 .53913 L .25136 .5388 L F
.25136 .5388 m .2477 .53913 L .25005 .53807 L F
.411 .757 .995 r
.25136 .5388 m .2526 .53769 L .25005 .53807 L F
.25136 .5388 m .2526 .53769 L .25005 .53807 L F
.656 .668 .849 r
.70861 .28019 m .70509 .27912 L .70801 .27825 L F
.974 .793 .371 r
.70764 .28127 m .70861 .28019 L .70801 .27825 L F
.372 .19 .501 r
.72095 .32136 m .7184 .32501 L .71713 .3211 L F
.72095 .32136 m .72068 .32408 L .7184 .32501 L F
.381 .237 .558 r
.72068 .32408 m .71872 .32759 L .7184 .32501 L F
.709 .431 .502 r
.534 .45606 m .53404 .45849 L .53001 .45847 L F
.707 .424 .493 r
.534 .45606 m .53652 .45872 L .53404 .45849 L F
.981 .713 .323 r
.41124 .54912 m .41007 .54845 L .41015 .54813 L F
.41124 .54912 m .41127 .5512 L .41007 .54845 L F
.822 .903 .897 r
.24016 .6148 m .23869 .61609 L .23702 .61503 L F
.976 .676 .371 r
.23869 .61609 m .23722 .61753 L .23702 .61503 L F
.23869 .61609 m .23882 .61872 L .23722 .61753 L F
.97 .654 .338 r
.64421 .35822 m .64546 .35712 L .64393 .35552 L F
.849 .835 .832 r
.64393 .35552 m .64546 .35712 L .64806 .35387 L F
0 0 .1 r
.31739 .59397 m .31801 .59455 L .31832 .59268 L F
.31739 .59397 m .31705 .59646 L .31801 .59455 L F
.183 .696 .892 r
.32915 .49405 m .32857 .49455 L .32696 .49608 L F
.32915 .49405 m .33085 .49453 L .32857 .49455 L F
.983 .856 .635 r
.25005 .52932 m .25166 .53341 L .25181 .53133 L F
.827 .971 .661 r
.68502 .35959 m .68278 .36291 L .68262 .36225 L F
.698 .605 .749 r
.45679 .47197 m .45763 .47591 L .45415 .47486 L F
.565 .557 .803 r
.45817 .47849 m .45415 .47486 L .45763 .47591 L F
.616 .491 .687 r
.4608 .47769 m .45763 .47591 L .46051 .47549 L F
.4608 .47769 m .45817 .47849 L .45763 .47591 L F
.555 .568 .822 r
.43638 .59103 m .43757 .58677 L .43486 .59023 L F
.43638 .59103 m .43875 .59018 L .43757 .58677 L F
.564 .833 .996 r
.43682 .58889 m .43638 .59103 L .43486 .59023 L F
.43682 .58889 m .43875 .59018 L .43638 .59103 L F
.623 .239 .296 r
.44576 .56715 m .44775 .56493 L .44376 .56534 L F
.734 .383 .385 r
.44576 .56715 m .45002 .56758 L .44775 .56493 L F
.808 .597 .616 r
.41438 .49116 m .41553 .49498 L .41711 .49368 L F
.186 .552 .931 r
.38885 .58751 m .3928 .5893 L .39142 .58708 L F
.415 .262 .564 r
.23357 .55151 m .23575 .54794 L .23446 .54943 L F
.669 .143 0 r
.34566 .51396 m .34647 .51364 L .34323 .51446 L F
.34566 .51396 m .34812 .5157 L .34647 .51364 L F
.784 .859 .906 r
.6276 .36842 m .63104 .36828 L .62948 .36489 L F
.732 .768 .881 r
.62948 .36489 m .63104 .36828 L .63388 .36628 L F
.163 0 .329 r
.30721 .61274 m .30922 .61229 L .30947 .60956 L F
.03 0 .174 r
.30721 .61274 m .30832 .61434 L .30922 .61229 L F
.30721 .61274 m .30678 .6153 L .30832 .61434 L F
.819 .774 .811 r
.63637 .36302 m .64018 .36104 L .63878 .3598 L F
.729 .949 .95 r
.64018 .36104 m .6415 .3591 L .63878 .3598 L F
.828 .953 .899 r
.66492 .32266 m .66116 .32416 L .66373 .32131 L F
.806 .924 .915 r
.667 .32078 m .66492 .32266 L .66373 .32131 L F
.449 .02 .131 r
.27562 .57148 m .27409 .57337 L .27143 .57344 L F
.512 .103 .203 r
.27829 .57108 m .27409 .57337 L .27562 .57148 L F
.136 0 .155 r
.34798 .60017 m .35087 .59706 L .35006 .5995 L F
0 0 0 r
.35087 .59706 m .35334 .59318 L .35296 .59621 L F
.373 .06 .3 r
.35255 .59864 m .35087 .59706 L .35296 .59621 L F
.35255 .59864 m .35006 .5995 L .35087 .59706 L F
.749 .993 .816 r
.32683 .5449 m .32512 .54631 L .32562 .54537 L F
.955 .641 .22 r
.61149 .41401 m .61295 .41775 L .61169 .41634 L F
.953 .634 .216 r
.61295 .41775 m .61217 .41888 L .61169 .41634 L F
.61295 .41775 m .61346 .42044 L .61217 .41888 L F
0 0 .175 r
.36873 .68042 m .36635 .6835 L .36894 .68305 L F
.143 0 0 r
.36694 .68453 m .36635 .6835 L .36596 .68524 L F
0 0 0 r
.36694 .68453 m .36388 .68813 L .36532 .6872 L F
.755 .866 .437 r
.3662 .68544 m .36694 .68453 L .36532 .6872 L F
.143 0 0 r
.36694 .68453 m .36801 .68321 L .36635 .6835 L F
.755 .866 .437 r
.36742 .68304 m .36694 .68453 L .3662 .68544 L F
.143 0 0 r
.36694 .68453 m .36894 .68305 L .36801 .68321 L F
.741 .223 0 r
.58458 .39812 m .58038 .39521 L .58313 .39601 L F
.295 0 0 r
.58163 .39592 m .58313 .39601 L .5812 .39545 L F
.58163 .39592 m .5812 .39545 L .58038 .39521 L F
.58163 .39592 m .58038 .39521 L .57916 .39356 L F
0 0 .502 r
.58207 .3964 m .58163 .39592 L .58022 .39474 L F
.264 .504 .898 r
.58559 .39653 m .58458 .39812 L .58313 .39601 L F
.957 .643 .388 r
.58407 .39852 m .58559 .39653 L .58163 .39592 L F
0 0 .502 r
.58264 .39692 m .58407 .39852 L .58163 .39592 L F
.58264 .39692 m .58163 .39592 L .58207 .3964 L F
.219 .717 .913 r
.31901 .66572 m .31534 .66534 L .31727 .66661 L F
.908 .718 .217 r
.42992 .55402 m .43054 .5554 L .42983 .5538 L F
0 0 .009 r
.43065 .55462 m .43033 .5551 L .42992 .55402 L F
.908 .718 .217 r
.42992 .55402 m .43049 .5579 L .43054 .5554 L F
.939 .829 .709 r
.42734 .56034 m .43049 .5579 L .42992 .55402 L F
.684 .775 .295 r
.42801 .55853 m .42734 .56034 L .42992 .55402 L F
0 0 .009 r
.43033 .5551 m .42801 .55853 L .42992 .55402 L F
.908 .718 .217 r
.42992 .55402 m .42983 .5538 L .42977 .55365 L F
.702 .951 .674 r
.30303 .54588 m .301 .54728 L .30015 .54893 L F
.422 .061 .244 r
.30495 .54388 m .301 .54728 L .30303 .54588 L F
.707 .263 .196 r
.30015 .54893 m .29857 .55068 L .29595 .54793 L F
0 0 0 r
.30013 .54973 m .30015 .54893 L .301 .54728 L F
.30013 .54973 m .29857 .55068 L .30015 .54893 L F
.815 .952 .609 r
.6951 .3644 m .69443 .36668 L .69657 .36322 L F
0 0 0 r
.69384 .36881 m .69443 .36668 L .6951 .3644 L F
.813 .672 .707 r
.57952 .41366 m .57866 .41537 L .57656 .41319 L F
.72 .849 .943 r
.32556 .53498 m .32222 .53383 L .32461 .53306 L F
.32556 .53498 m .32389 .53521 L .32222 .53383 L F
.01 .199 .71 r
.32717 .53192 m .32556 .53498 L .32461 .53306 L F
.32717 .53192 m .32704 .53466 L .32556 .53498 L F
.998 .787 .486 r
.40067 .59518 m .40222 .5937 L .40118 .59253 L F
.40067 .59518 m .40195 .59616 L .40222 .5937 L F
.23 0 .02 r
.59755 .46222 m .60095 .45956 L .60078 .46089 L F
.528 .098 .168 r
.60095 .45956 m .60348 .46103 L .60078 .46089 L F
.516 .123 .234 r
.60095 .45956 m .60315 .45943 L .60348 .46103 L F
.282 0 .249 r
.32073 .58096 m .32284 .58037 L .3238 .57821 L F
.42 .303 .613 r
.32073 .58096 m .32324 .5832 L .32284 .58037 L F
.32073 .58096 m .3211 .58421 L .32324 .5832 L F
0 0 .022 r
.3238 .57821 m .32284 .58037 L .32529 .57696 L F
.613 .56 .772 r
.45692 .5198 m .45425 .52066 L .45364 .51748 L F
.469 .38 .673 r
.45708 .52299 m .45425 .52066 L .45692 .5198 L F
.45708 .52299 m .45465 .52351 L .45425 .52066 L F
.327 .788 .942 r
.44342 .54735 m .44143 .54667 L .44056 .54719 L F
.486 0 0 r
.44577 .54637 m .44143 .54667 L .44342 .54735 L F
.44577 .54637 m .44335 .54761 L .44143 .54667 L F
.488 .877 .694 r
.44627 .54567 m .44335 .54761 L .44577 .54637 L F
.215 .301 .738 r
.44335 .54761 m .44413 .54981 L .44143 .54667 L F
.488 .877 .694 r
.44627 .54567 m .44577 .54637 L .4474 .54615 L F
.759 .693 .789 r
.44627 .54567 m .44413 .54981 L .44335 .54761 L F
.721 .697 .828 r
.44288 .54567 m .44335 .54761 L .44627 .54567 L F
.162 .283 .741 r
.44143 .54667 m .44413 .54981 L .44288 .54567 L F
.44143 .54667 m .44288 .54567 L .44258 .54598 L F
.44143 .54667 m .44258 .54598 L .44 .54867 L F
.327 .788 .942 r
.44056 .54719 m .44143 .54667 L .43908 .54711 L F
.389 .074 .305 r
.3719 .67718 m .36873 .68042 L .37124 .67974 L F
.724 .726 .203 r
.37208 .67605 m .3719 .67718 L .37124 .67974 L F
0 .098 .639 r
.22584 .59622 m .22787 .59884 L .22685 .60066 L F
.244 .337 .76 r
.22787 .59884 m .22751 .60229 L .22685 .60066 L F
.718 .89 .959 r
.3292 .66283 m .32844 .6634 L .32634 .66407 L F
.56 .22 .349 r
.32634 .66407 m .32844 .6634 L .32745 .66563 L F
.291 .069 .394 r
.3306 .66379 m .32844 .6634 L .3292 .66283 L F
.299 0 .221 r
.32745 .66563 m .32844 .6634 L .3306 .66379 L F
.664 .639 .815 r
.45415 .47486 m .45016 .47217 L .45492 .47293 L F
.642 .518 .698 r
.45679 .47197 m .45415 .47486 L .45492 .47293 L F
.366 .554 .905 r
.23598 .60462 m .2366 .6089 L .23363 .60585 L F
.23598 .60462 m .239 .60939 L .2366 .6089 L F
0 .062 .571 r
.33783 .50928 m .33997 .51119 L .33883 .50987 L F
.371 .041 .27 r
.29365 .56383 m .29234 .56708 L .29004 .56762 L F
.57 .234 .361 r
.29525 .5668 m .29365 .56383 L .29676 .56405 L F
.29525 .5668 m .29234 .56708 L .29365 .56383 L F
.694 .839 .953 r
.43574 .46843 m .43318 .46944 L .43168 .46803 L F
.758 .965 .931 r
.69107 .3536 m .68687 .35509 L .69013 .35238 L F
.822 .975 .892 r
.69331 .34984 m .69107 .3536 L .69013 .35238 L F
.69331 .34984 m .69424 .35085 L .69107 .3536 L F
.707 .693 .835 r
.3557 .55881 m .35962 .55944 L .35825 .55609 L F
.694 .687 .839 r
.35825 .55609 m .35962 .55944 L .36218 .55846 L F
.557 .315 .504 r
.35962 .55944 m .36149 .56093 L .36218 .55846 L F
.35962 .55944 m .36149 .56093 L .36218 .55846 L F
.692 .247 .19 r
.54857 .46524 m .55248 .46571 L .55106 .46742 L F
.664 .213 .171 r
.55248 .46571 m .55506 .46774 L .55106 .46742 L F
.876 .993 .768 r
.69874 .35905 m .70049 .35528 L .69838 .35875 L F
.748 .669 .774 r
.29392 .63947 m .29658 .6385 L .29225 .63827 L F
.222 0 .208 r
.29658 .6385 m .29963 .63568 L .2988 .63805 L F
.034 .055 .55 r
.29817 .6406 m .29658 .6385 L .2988 .63805 L F
.481 .36 .638 r
.4545 .50826 m .45456 .51002 L .45206 .51064 L F
.54 .499 .759 r
.45592 .51445 m .45206 .51064 L .45456 .51002 L F
.45592 .51445 m .45528 .51654 L .45206 .51064 L F
.779 .422 .379 r
.54436 .46293 m .54448 .46491 L .54257 .46214 L F
.731 .336 .301 r
.54436 .46293 m .54857 .46524 L .54448 .46491 L F
.966 .872 .693 r
.39588 .60913 m .39876 .60607 L .39763 .60531 L F
.39588 .60913 m .39746 .61024 L .39876 .60607 L F
.464 .46 .769 r
.72242 .32965 m .71971 .3322 L .71872 .32759 L F
.433 .41 .734 r
.72323 .3313 m .71971 .3322 L .72242 .32965 L F
.433 .198 .456 r
.47449 .45908 m .47382 .4621 L .47138 .46285 L F
.668 .47 .608 r
.47572 .45916 m .47382 .4621 L .47449 .45908 L F
.772 .853 .911 r
.27355 .52267 m .2773 .52246 L .2756 .52132 L F
.178 0 0 r
.28018 .52145 m .2756 .52132 L .2773 .52246 L F
0 0 0 r
.36712 .64168 m .36726 .6449 L .36752 .64381 L F
.513 .878 .657 r
.29856 .51047 m .29467 .5132 L .29655 .51182 L F
0 0 0 r
.30081 .50945 m .29856 .51047 L .29655 .51182 L F
.764 .75 .84 r
.28973 .65788 m .29432 .65801 L .29209 .65813 L F
.57 .891 .624 r
.29432 .65801 m .29692 .65567 L .29493 .65731 L F
.557 .927 .93 r
.29307 .65884 m .29493 .65731 L .29465 .65998 L F
.29209 .65813 m .29432 .65801 L .29493 .65731 L F
.29209 .65813 m .29493 .65731 L .29307 .65884 L F
.57 .891 .624 r
.29692 .65567 m .29698 .65562 L .29493 .65731 L F
.477 .278 .531 r
.326 .57487 m .32872 .57423 L .32891 .57134 L F
.408 .082 .299 r
.326 .57487 m .32775 .57633 L .32872 .57423 L F
.326 .57487 m .32529 .57696 L .32775 .57633 L F
.967 .904 .703 r
.26451 .52408 m .26321 .52709 L .26611 .52879 L F
0 .421 .837 r
.56536 .39934 m .56495 .39988 L .56354 .3984 L F
.516 .816 .999 r
.3828 .55115 m .38442 .55225 L .38035 .55174 L F
.519 .347 .589 r
.35006 .5995 m .3473 .60276 L .34798 .60017 L F
.609 .633 .849 r
.70356 .28908 m .70725 .29146 L .70753 .28922 L F
.711 .686 .825 r
.70753 .28922 m .70725 .29146 L .70959 .28912 L F
.495 .468 .757 r
.46181 .54453 m .46043 .54906 L .45934 .5451 L F
.46181 .54453 m .46276 .54861 L .46043 .54906 L F
0 0 .076 r
.23442 .55506 m .23569 .55102 L .23357 .55151 L F
.23442 .55506 m .2347 .55511 L .23569 .55102 L F
0 0 0 r
.26062 .52013 m .26188 .51919 L .26239 .5187 L F
.497 .906 .842 r
.26062 .52013 m .25989 .51967 L .26188 .51919 L F
.849 .477 0 r
.37824 .51638 m .37988 .51961 L .37929 .51775 L F
.313 .309 .695 r
.33745 .69477 m .33493 .6933 L .33656 .6912 L F
0 .276 .736 r
.44842 .55585 m .44953 .55607 L .44709 .55479 L F
.44842 .55585 m .45136 .55768 L .44953 .55607 L F
.49 .692 .958 r
.37923 .49883 m .37962 .50073 L .37784 .49895 L F
.981 .825 .424 r
.378 .50352 m .37784 .49895 L .37962 .50073 L F
.023 .296 .789 r
.37923 .49883 m .38047 .49962 L .37962 .50073 L F
.954 .647 .413 r
.60009 .41739 m .59821 .4139 L .59951 .41717 L F
.702 .237 0 r
.60057 .41865 m .60009 .41739 L .59951 .41717 L F
.60057 .41865 m .60182 .41997 L .60009 .41739 L F
.827 .971 .661 r
.68502 .35959 m .68262 .36225 L .68525 .35901 L F
.662 .116 0 r
.37209 .51306 m .3744 .51499 L .37551 .51436 L F
.625 .069 0 r
.3744 .51499 m .37824 .51638 L .37551 .51436 L F
.359 0 .196 r
.28971 .63529 m .29044 .63766 L .29208 .6353 L F
.28971 .63529 m .28799 .63778 L .29044 .63766 L F
.837 .644 .642 r
.52797 .43853 m .52529 .44188 L .52581 .43936 L F
.52797 .43853 m .52797 .4436 L .52529 .44188 L F
.415 .226 .514 r
.72223 .29647 m .72468 .29522 L .72466 .29269 L F
.72223 .29647 m .72468 .29522 L .72466 .29269 L F
.234 .711 .936 r
.34506 .50391 m .34699 .50404 L .34314 .50336 L F
.861 .752 .742 r
.59865 .37275 m .59931 .37513 L .59682 .37623 L F
.342 .031 .285 r
.59931 .37513 m .59614 .37879 L .59682 .37623 L F
.59931 .37513 m .59852 .37786 L .59614 .37879 L F
.749 .229 0 r
.59865 .37275 m .60206 .37541 L .59931 .37513 L F
.747 .521 .589 r
.60206 .37541 m .59852 .37786 L .59931 .37513 L F
.673 .611 .778 r
.35506 .68948 m .35831 .68948 L .35644 .68622 L F
.739 .457 .503 r
.35392 .69288 m .35619 .69356 L .35506 .68948 L F
.887 .702 .646 r
.35619 .69356 m .35831 .68948 L .35506 .68948 L F
.428 .566 .89 r
.47264 .56583 m .47129 .56809 L .47019 .56428 L F
.47264 .56583 m .47349 .56786 L .47129 .56809 L F
.421 .315 .628 r
.47349 .56786 m .47391 .57026 L .47129 .56809 L F
.771 .944 .605 r
.39302 .61545 m .39482 .61329 L .39303 .61493 L F
.879 .959 .85 r
.394 .61125 m .39482 .61329 L .39746 .61024 L F
.978 .91 .586 r
.39303 .61493 m .39482 .61329 L .394 .61125 L F
.921 .908 .792 r
.66985 .31574 m .66716 .31778 L .66792 .31611 L F
.66985 .31574 m .66786 .31891 L .66716 .31778 L F
.725 .984 .899 r
.67199 .31428 m .66985 .31574 L .67136 .31351 L F
.729 .99 .856 r
.66985 .31574 m .66792 .31611 L .67136 .31351 L F
.802 .857 .891 r
.64534 .34104 m .64076 .34234 L .64394 .33961 L F
.835 .876 .873 r
.6481 .33817 m .64534 .34104 L .64394 .33961 L F
0 0 .328 r
.20942 .57451 m .21045 .57368 L .2106 .57103 L F
0 0 .384 r
.20942 .57451 m .21039 .57653 L .21045 .57368 L F
0 0 .394 r
.2097 .57732 m .21039 .57653 L .20942 .57451 L F
.841 .976 .674 r
.42601 .57961 m .42575 .58116 L .42735 .57887 L F
.538 .892 .668 r
.42601 .57961 m .42735 .57887 L .42942 .57721 L F
.174 .289 .743 r
.33777 .55515 m .33989 .5548 L .33826 .55061 L F
0 0 0 r
.33777 .55515 m .33833 .55568 L .33989 .5548 L F
.33777 .55515 m .33589 .55695 L .33833 .55568 L F
.887 .984 .814 r
.68025 .32516 m .68206 .32543 L .68238 .32232 L F
.717 .894 .96 r
.326 .66289 m .32634 .66407 L .32456 .66381 L F
.326 .66289 m .3292 .66283 L .32634 .66407 L F
.75 .233 0 r
.32456 .66381 m .32634 .66407 L .32745 .66563 L F
.802 .884 .904 r
.63595 .34676 m .63407 .34851 L .6327 .34698 L F
.436 0 0 r
.27461 .63591 m .27896 .6366 L .2773 .6374 L F
.843 .416 .219 r
.27896 .6366 m .2802 .63885 L .2773 .6374 L F
0 0 0 r
.22462 .5451 m .22717 .54122 L .22492 .54259 L F
.573 .527 .765 r
.43654 .54621 m .43793 .54177 L .4358 .54332 L F
.43654 .54621 m .43907 .54555 L .43793 .54177 L F
.366 .445 .809 r
.43654 .54621 m .43908 .54711 L .43907 .54555 L F
.631 .842 .981 r
.58718 .41648 m .58856 .41778 L .58511 .41777 L F
.993 .777 .507 r
.58766 .41409 m .58856 .41778 L .58718 .41648 L F
.45 .319 .61 r
.35909 .64097 m .35663 .6421 L .35676 .63895 L F
.35909 .64097 m .35663 .6421 L .35676 .63895 L F
.466 .661 .946 r
.27132 .52294 m .27355 .52267 L .27234 .52075 L F
.758 .985 .904 r
.27234 .52075 m .26979 .52274 L .27132 .52294 L F
.466 .661 .946 r
.27132 .52294 m .27355 .52267 L .27234 .52075 L F
.489 .699 .962 r
.62502 .40173 m .62187 .40039 L .62378 .40045 L F
.988 .718 .368 r
.62378 .40045 m .62504 .40258 L .62502 .40173 L F
.733 .627 .74 r
.45253 .47117 m .45492 .47293 L .45016 .47217 L F
.688 .634 .79 r
.45679 .47197 m .45492 .47293 L .45253 .47117 L F
.867 .829 .808 r
.6608 .34205 m .66479 .34047 L .66348 .33894 L F
.6608 .34205 m .66224 .34388 L .66479 .34047 L F
.795 .892 .913 r
.66348 .33894 m .66479 .34047 L .66787 .33787 L F
.311 .16 .509 r
.36746 .53644 m .36957 .53817 L .3706 .5358 L F
.36746 .53644 m .36766 .53912 L .36957 .53817 L F
.842 .77 .782 r
.43133 .57696 m .43408 .57786 L .43586 .57455 L F
.872 .527 .394 r
.43453 .58025 m .43408 .57786 L .43133 .57696 L F
0 0 .57 r
.43548 .58063 m .43408 .57786 L .43453 .58025 L F
.537 .34 .561 r
.27291 .54575 m .2729 .54881 L .27025 .549 L F
.547 .346 .559 r
.27507 .54234 m .27414 .54342 L .27321 .54383 L F
0 .092 .642 r
.27321 .54383 m .27291 .54575 L .27233 .54421 L F
.575 .622 .861 r
.27148 .54554 m .27291 .54575 L .27321 .54383 L F
.416 .245 .539 r
.275 .5478 m .2729 .54881 L .27291 .54575 L F
.575 .622 .861 r
.27148 .54554 m .275 .5478 L .27291 .54575 L F
.549 .607 .863 r
.27025 .549 m .2729 .54881 L .27148 .54554 L F
.575 .622 .861 r
.27148 .54554 m .2729 .54881 L .275 .5478 L F
0 .092 .642 r
.27321 .54383 m .27233 .54421 L .27155 .54214 L F
.362 .081 .346 r
.27442 .53933 m .27155 .54214 L .27142 .53937 L F
.27442 .53933 m .27391 .54151 L .27155 .54214 L F
0 .092 .642 r
.27321 .54383 m .27155 .54214 L .27391 .54151 L F
.549 .607 .863 r
.26967 .54779 m .27148 .54554 L .26874 .54586 L F
.27025 .549 m .27148 .54554 L .26967 .54779 L F
.388 0 .117 r
.27245 .54458 m .27205 .54483 L .27148 .54554 L F
.28 0 0 r
.26874 .54586 m .26747 .54577 L .26434 .54493 L F
.203 .33 .771 r
.26899 .53846 m .26945 .54088 L .26738 .53999 L F
.63 .479 .658 r
.26725 .54573 m .26945 .54088 L .26899 .53846 L F
.26723 .54579 m .26726 .54573 L .26725 .54573 L F
.26726 .54573 m .26945 .54088 L .26725 .54573 L F
.628 .14 .073 r
.27148 .54554 m .26901 .54562 L .26874 .54586 L F
.26901 .54562 m .26872 .54563 L .26872 .54565 L F
.26901 .54562 m .26872 .54565 L .26874 .54586 L F
.63 .479 .658 r
.26749 .54575 m .26872 .54563 L .26768 .54526 L F
.26723 .54579 m .26751 .5458 L .26726 .54573 L F
.28 0 0 r
.26726 .54573 m .26732 .54576 L .26722 .54573 L F
.26747 .54577 m .26735 .54576 L .26726 .54573 L F
.26735 .54576 m .26732 .54576 L .26726 .54573 L F
.26747 .54577 m .26725 .54573 L .26434 .54493 L F
.781 .892 .924 r
.26457 .54205 m .26504 .53909 L .26738 .53999 L F
.203 .33 .771 r
.26899 .53846 m .26738 .53999 L .26504 .53909 L F
.63 .479 .658 r
.26721 .54573 m .26899 .53846 L .26544 .54083 L F
.26723 .54579 m .26725 .54573 L .26721 .54573 L F
.26725 .54573 m .26899 .53846 L .26721 .54573 L F
.28 0 0 r
.26725 .54573 m .26722 .54573 L .26721 .54573 L F
.26725 .54573 m .26721 .54573 L .26434 .54493 L F
.628 .14 .073 r
.26872 .54563 m .26664 .54571 L .26735 .54576 L F
.26872 .54563 m .26735 .54576 L .26874 .54586 L F
.63 .479 .658 r
.26749 .54575 m .26914 .54582 L .26916 .54559 L F
.26751 .5458 m .26914 .54582 L .26726 .54573 L F
.623 .128 .054 r
.26664 .54571 m .26914 .54582 L .26723 .54579 L F
.26664 .54571 m .26917 .5466 L .26914 .54582 L F
.628 .14 .073 r
.26872 .54563 m .26917 .5466 L .26664 .54571 L F
.27148 .54554 m .26914 .54579 L .26875 .54563 L F
.388 0 .117 r
.27205 .54483 m .27129 .54529 L .27168 .54528 L F
.628 .14 .073 r
.27148 .54554 m .27015 .54615 L .26919 .5458 L F
.26919 .54578 m .26919 .5458 L .26914 .54579 L F
.27148 .54554 m .26919 .5458 L .26919 .54578 L F
.388 0 .117 r
.27321 .54383 m .27257 .54427 L .27245 .54458 L F
.27257 .54427 m .27107 .5453 L .27245 .54458 L F
.27107 .5453 m .26917 .5466 L .27062 .54571 L F
.27107 .5453 m .27062 .54571 L .27245 .54458 L F
.61 .462 .655 r
.26945 .54088 m .26915 .54572 L .27154 .54487 L F
.388 0 .117 r
.27321 .54383 m .27309 .54402 L .27302 .54396 L F
.27309 .54402 m .27248 .54499 L .27302 .54396 L F
.27302 .54396 m .27248 .54499 L .27107 .5453 L F
.61 .462 .655 r
.27278 .54375 m .27154 .54487 L .27334 .54423 L F
.26945 .54088 m .27154 .54487 L .27278 .54375 L F
.444 .084 .26 r
.26917 .5466 m .26919 .5458 L .26914 .54582 L F
.61 .462 .655 r
.26914 .54579 m .26914 .54582 L .26919 .5458 L F
.628 .14 .073 r
.27015 .54615 m .26917 .5466 L .26872 .54563 L F
.388 0 .117 r
.27129 .54529 m .26917 .5466 L .27168 .54528 L F
.27168 .54528 m .26917 .5466 L .27148 .54554 L F
.2709 .54542 m .27165 .54632 L .26917 .5466 L F
.27232 .54526 m .27165 .54632 L .2709 .54542 L F
.61 .462 .655 r
.26915 .54572 m .2696 .54562 L .27307 .54433 L F
.27307 .54432 m .27307 .54433 L .27334 .54423 L F
.26915 .54572 m .27307 .54433 L .27307 .54432 L F
.547 .346 .559 r
.27315 .54419 m .27301 .5444 L .27287 .54437 L F
.27301 .5444 m .27165 .54632 L .27248 .54499 L F
.27301 .5444 m .27248 .54499 L .27287 .54437 L F
.444 .084 .26 r
.27301 .54442 m .27334 .54423 L .27306 .54433 L F
.61 .462 .655 r
.27324 .54414 m .27334 .54423 L .27327 .54412 L F
.444 .084 .26 r
.27301 .54442 m .27165 .54632 L .27334 .54423 L F
.388 0 .117 r
.27107 .5453 m .27232 .54526 L .2709 .54542 L F
.27248 .54499 m .27232 .54526 L .27107 .5453 L F
.444 .084 .26 r
.26917 .5466 m .27165 .54632 L .27301 .54442 L F
.547 .346 .559 r
.27326 .54422 m .27257 .54513 L .27301 .54442 L F
.27226 .54561 m .27165 .54632 L .27301 .5444 L F
.27306 .54433 m .27301 .5444 L .27315 .54419 L F
.27226 .54561 m .27301 .5444 L .27306 .54433 L F
.61 .462 .655 r
.26914 .54579 m .26919 .5458 L .27306 .54433 L F
.27307 .54433 m .27306 .54433 L .27334 .54423 L F
.26914 .54579 m .27306 .54433 L .27307 .54433 L F
.444 .084 .26 r
.26917 .5466 m .27301 .54442 L .26919 .5458 L F
.27301 .54442 m .27306 .54433 L .26919 .5458 L F
.777 .939 .59 r
.27324 .54424 m .27165 .54632 L .27232 .54438 L F
.27334 .54423 m .27165 .54632 L .27324 .54424 L F
.547 .346 .559 r
.27387 .54374 m .27226 .54561 L .27257 .54513 L F
.27387 .54374 m .27257 .54513 L .27326 .54422 L F
.27319 .54417 m .27301 .54442 L .27315 .54419 L F
.27387 .54374 m .27301 .54442 L .27319 .54417 L F
.61 .462 .655 r
.26915 .54572 m .26914 .54579 L .2696 .54562 L F
.628 .14 .073 r
.26875 .54563 m .26914 .54579 L .26872 .54563 L F
.63 .479 .658 r
.26768 .54526 m .26916 .54559 L .26945 .54088 L F
.26872 .54563 m .26916 .54559 L .26768 .54526 L F
.26726 .54573 m .26749 .54575 L .26945 .54088 L F
.429 .485 .816 r
.26434 .54493 m .26723 .54579 L .26721 .54573 L F
.261 0 0 r
.26434 .54493 m .26664 .54571 L .26723 .54579 L F
.28 0 0 r
.26732 .54576 m .26664 .54571 L .26434 .54493 L F
.429 .485 .816 r
.26434 .54493 m .26721 .54573 L .26544 .54083 L F
.761 .932 .579 r
.27184 .53733 m .26945 .54088 L .27005 .53915 L F
.61 .462 .655 r
.26945 .54088 m .27278 .54375 L .27005 .53915 L F
.27278 .54375 m .27324 .54414 L .27286 .54355 L F
.27278 .54375 m .27286 .54355 L .27005 .53915 L F
.27324 .54414 m .27327 .54412 L .27005 .53915 L F
.547 .346 .559 r
.27414 .54342 m .27387 .54374 L .27321 .54383 L F
.27387 .54374 m .27287 .54437 L .27321 .54383 L F
.11 .585 .913 r
.57769 .39256 m .57605 .39304 L .57479 .39163 L F
.57769 .39256 m .57916 .39356 L .57605 .39304 L F
.163 .294 .752 r
.32512 .54631 m .32656 .54872 L .32562 .54537 L F
.992 .743 .39 r
.38566 .5426 m .38559 .54527 L .38448 .54188 L F
.882 .885 .831 r
.70509 .27912 m .7006 .28104 L .70337 .27746 L F
.70509 .27912 m .70209 .2827 L .7006 .28104 L F
.53 .605 .873 r
.70556 .27466 m .70509 .27912 L .70337 .27746 L F
.70556 .27466 m .70801 .27825 L .70509 .27912 L F
.596 .38 .557 r
.28186 .56102 m .28476 .55802 L .2824 .55873 L F
.125 0 0 r
.2377 .61408 m .23483 .61365 L .23262 .61328 L F
.23832 .61418 m .23772 .61409 L .2377 .61408 L F
.23772 .61409 m .23483 .61365 L .2377 .61408 L F
.648 .303 .373 r
.23917 .61222 m .23483 .61365 L .23832 .61418 L F
.822 .903 .897 r
.24016 .6148 m .23702 .61503 L .23917 .61222 L F
0 0 0 r
.23702 .61503 m .23782 .61425 L .23789 .61413 L F
.23774 .61409 m .23789 .61413 L .23917 .61222 L F
.23702 .61503 m .23789 .61413 L .23774 .61409 L F
.693 .779 .917 r
.24289 .61276 m .24016 .6148 L .23917 .61222 L F
.752 .509 .563 r
.5217 .45247 m .52417 .45633 L .51963 .45553 L F
.717 .655 .787 r
.52437 .4489 m .5217 .45247 L .52211 .44993 L F
.743 .499 .561 r
.5217 .45247 m .52569 .45558 L .52417 .45633 L F
.479 .62 .911 r
.61928 .43871 m .62019 .44069 L .62156 .43837 L F
.575 .744 .957 r
.62019 .44069 m .62306 .44004 L .62156 .43837 L F
.883 .738 .697 r
.62514 .40652 m .62628 .40791 L .62519 .40424 L F
.957 .645 .394 r
.62512 .41006 m .62628 .40791 L .62514 .40652 L F
.778 .687 .763 r
.62519 .40424 m .62628 .40791 L .62824 .40482 L F
.885 .52 .348 r
.62512 .41006 m .62763 .41073 L .62628 .40791 L F
.233 0 .257 r
.46999 .5778 m .46928 .57999 L .46722 .58084 L F
.293 .063 .384 r
.47162 .57665 m .46928 .57999 L .46999 .5778 L F
.956 .663 .44 r
.29496 .66955 m .29683 .67067 L .29554 .67332 L F
.481 .786 .998 r
.29889 .67007 m .29683 .67067 L .29496 .66955 L F
.208 0 .081 r
.29554 .67332 m .29683 .67067 L .29889 .67007 L F
.678 .786 .931 r
.44474 .46609 m .44224 .46783 L .44075 .46531 L F
.638 .644 .84 r
.44623 .46901 m .44224 .46783 L .44474 .46609 L F
.607 .37 .531 r
.7188 .34599 m .7218 .34308 L .71967 .34245 L F
.71845 .34462 m .71967 .34245 L .71774 .34188 L F
.7188 .34599 m .71967 .34245 L .71845 .34462 L F
.661 .82 .388 r
.72101 .34007 m .71966 .34259 L .72122 .33974 L F
.72071 .34051 m .72029 .34135 L .72101 .34007 L F
.72029 .34135 m .71966 .34259 L .72101 .34007 L F
.814 .516 0 r
.39092 .53295 m .39122 .53452 L .39189 .53557 L F
.954 .693 .242 r
.39122 .53452 m .39215 .53736 L .39189 .53557 L F
.841 .718 .728 r
.34992 .56761 m .34993 .57099 L .35192 .5711 L F
.703 .239 .146 r
.34993 .57099 m .34999 .57252 L .35192 .5711 L F
.571 .341 .528 r
.35192 .5711 m .35314 .575 L .3547 .5711 L F
0 0 .258 r
.35245 .57229 m .35314 .575 L .35192 .5711 L F
.35245 .57229 m .35192 .5711 L .34999 .57252 L F
.553 .504 .755 r
.24216 .5583 m .2428 .56262 L .24548 .56148 L F
0 .071 .629 r
.58592 .39871 m .58458 .39812 L .58559 .39653 L F
.58592 .39871 m .5869 .40073 L .58458 .39812 L F
.785 .3 0 r
.58815 .40235 m .58458 .39812 L .5869 .40073 L F
.849 .835 .832 r
.64393 .35552 m .64806 .35387 L .64654 .35233 L F
.822 .819 .846 r
.64654 .35233 m .64806 .35387 L .65076 .35073 L F
.834 .992 .738 r
.27397 .5361 m .27142 .53937 L .27184 .53733 L F
.628 .481 .662 r
.27397 .5361 m .27442 .53933 L .27142 .53937 L F
.773 .84 .903 r
.63691 .3959 m .63416 .39892 L .63271 .3969 L F
.226 0 0 r
.63416 .39892 m .63606 .39979 L .63367 .4002 L F
.63416 .39892 m .6372 .39857 L .63606 .39979 L F
.567 .492 .73 r
.63691 .3959 m .6372 .39857 L .63416 .39892 L F
.703 .652 .796 r
.63849 .41761 m .64007 .42074 L .63573 .42082 L F
.519 .037 .053 r
.63573 .42082 m .64007 .42074 L .6383 .42135 L F
.764 .677 .766 r
.63849 .41761 m .64241 .41834 L .64007 .42074 L F
.746 .331 .263 r
.64007 .42074 m .63961 .4233 L .6383 .42135 L F
.64007 .42074 m .64248 .42294 L .63961 .4233 L F
.64 .485 .657 r
.2488 .56673 m .25103 .56751 L .24712 .57036 L F
.2488 .56673 m .24947 .56904 L .25103 .56751 L F
.457 .817 .996 r
.2488 .56673 m .25316 .56712 L .25103 .56751 L F
.641 .89 .553 r
.25036 .56776 m .25103 .56751 L .25316 .56712 L F
.25036 .56776 m .24947 .56904 L .25103 .56751 L F
.729 .419 .456 r
.54257 .46214 m .54042 .46472 L .54019 .46196 L F
.54257 .46214 m .54448 .46491 L .54042 .46472 L F
.809 .757 .804 r
.31212 .53075 m .31613 .53046 L .31457 .52821 L F
.31212 .53075 m .31328 .53288 L .31613 .53046 L F
0 .218 .741 r
.31613 .53046 m .31704 .52947 L .31457 .52821 L F
.418 .057 .241 r
.31912 .52986 m .31805 .53166 L .31613 .53046 L F
0 .218 .741 r
.31613 .53046 m .31805 .53166 L .31704 .52947 L F
0 0 .171 r
.2988 .63805 m .29963 .63568 L .30106 .63452 L F
.334 .765 .971 r
.35429 .55219 m .3526 .55139 L .35012 .55162 L F
.35429 .55219 m .3526 .55139 L .35012 .55162 L F
.903 .917 .82 r
.35429 .55219 m .3526 .55139 L .35537 .54789 L F
.674 .181 .071 r
.35464 .55217 m .35077 .55254 L .3526 .55139 L F
.456 .27 .539 r
.35429 .55219 m .35668 .55424 L .35714 .55195 L F
.35429 .55219 m .35424 .55495 L .35668 .55424 L F
.264 .011 .331 r
.35714 .55195 m .35687 .55326 L .35933 .551 L F
.35687 .55326 m .35668 .55424 L .3575 .55324 L F
.35687 .55326 m .3575 .55324 L .35933 .551 L F
.804 .741 .794 r
.35668 .55424 m .35804 .55492 L .35933 .551 L F
.97 .735 .526 r
.35933 .551 m .35772 .54701 L .35942 .54833 L F
.35933 .551 m .35756 .55043 L .35772 .54701 L F
.786 .895 .486 r
.35989 .54922 m .3587 .55183 L .35756 .55043 L F
.288 .416 .818 r
.35756 .55043 m .35786 .55323 L .35829 .55301 L F
.3587 .55183 m .35829 .55301 L .35926 .55252 L F
.35756 .55043 m .35829 .55301 L .3587 .55183 L F
.786 .895 .486 r
.3587 .55183 m .35839 .55252 L .35756 .55043 L F
.288 .416 .818 r
.35756 .55043 m .35891 .55123 L .35989 .54922 L F
.786 .895 .486 r
.35989 .54922 m .35939 .54986 L .35891 .55123 L F
.35989 .54922 m .35891 .55123 L .3587 .55183 L F
.288 .416 .818 r
.35891 .55123 m .36026 .55201 L .35989 .54922 L F
.35756 .55043 m .35926 .55252 L .36026 .55201 L F
.786 .895 .486 r
.3587 .55183 m .35858 .55091 L .35839 .55252 L F
.518 .335 .572 r
.35772 .54701 m .35756 .55043 L .35503 .5507 L F
.503 .314 .557 r
.35938 .54564 m .35942 .54833 L .36186 .54511 L F
.881 .887 .832 r
.36186 .54511 m .35942 .54833 L .35772 .54701 L F
.376 .447 .806 r
.35858 .55091 m .3592 .54672 L .3569 .5497 L F
.647 .089 0 r
.3569 .5497 m .35848 .55059 L .35858 .55091 L F
.786 .895 .486 r
.35939 .54986 m .35858 .55091 L .35879 .55159 L F
.514 .368 .62 r
.36026 .55201 m .36255 .54862 L .35989 .54922 L F
.591 .204 .278 r
.36255 .54862 m .35858 .55091 L .35989 .54922 L F
.514 .368 .62 r
.36026 .55201 m .36308 .55194 L .36255 .54862 L F
0 .054 .604 r
.36026 .55201 m .36175 .5537 L .36308 .55194 L F
.591 .204 .278 r
.36127 .5519 m .36121 .55205 L .36105 .55197 L F
.328 .239 .601 r
.36255 .54862 m .36308 .55194 L .36467 .55068 L F
0 0 0 r
.36308 .55194 m .36175 .5537 L .36467 .55068 L F
.03 0 0 r
.36106 .55211 m .36467 .55068 L .36175 .5537 L F
.36103 .55202 m .3612 .55196 L .36106 .55211 L F
.3612 .55196 m .36295 .55132 L .36118 .55206 L F
.591 .204 .278 r
.36255 .54862 m .36127 .5519 L .35858 .55091 L F
.36127 .5519 m .36105 .55197 L .35858 .55091 L F
.36121 .55205 m .36118 .55206 L .35858 .55091 L F
.376 .447 .806 r
.35858 .55091 m .36101 .55199 L .3592 .54672 L F
.36101 .55199 m .36118 .55206 L .36115 .55197 L F
.36101 .55199 m .36115 .55197 L .3592 .54672 L F
.03 0 0 r
.36103 .55202 m .36276 .55182 L .36294 .55171 L F
.36295 .55132 m .36467 .55068 L .36106 .55211 L F
.36121 .55196 m .36294 .55171 L .36452 .55077 L F
.36103 .55202 m .36294 .55171 L .36121 .55196 L F
.3612 .55196 m .36118 .55206 L .36106 .55211 L F
.591 .204 .278 r
.36121 .55205 m .3612 .55207 L .36118 .55206 L F
.376 .447 .806 r
.36118 .55206 m .3612 .55207 L .36119 .55202 L F
.03 0 0 r
.3612 .55196 m .36452 .55077 L .36295 .55132 L F
.36103 .55202 m .36121 .55196 L .3612 .55196 L F
.36121 .55196 m .36452 .55077 L .3612 .55196 L F
.376 .447 .806 r
.36118 .55206 m .36119 .55202 L .36116 .55196 L F
.36115 .55197 m .36116 .55196 L .3592 .54672 L F
.36118 .55206 m .36116 .55196 L .36115 .55197 L F
.03 0 0 r
.36295 .55132 m .36452 .55077 L .36467 .55068 L F
.647 .089 0 r
.35848 .55059 m .36103 .55202 L .35858 .55091 L F
.786 .895 .486 r
.35879 .55159 m .35858 .55091 L .3587 .55183 L F
.726 .595 .71 r
.35668 .55424 m .35815 .55431 L .35804 .55492 L F
.35815 .55431 m .36063 .55443 L .35804 .55492 L F
.35668 .55424 m .35672 .55601 L .35875 .55519 L F
.35815 .55431 m .35832 .55456 L .36063 .55443 L F
0 0 .314 r
.36063 .55443 m .36026 .55201 L .35832 .55456 L F
.36063 .55443 m .35832 .55456 L .35804 .55492 L F
.726 .595 .71 r
.35832 .55456 m .35875 .55519 L .36063 .55443 L F
.288 .416 .818 r
.35815 .55431 m .35804 .55492 L .35832 .55456 L F
.726 .595 .71 r
.35668 .55424 m .35875 .55519 L .35815 .55431 L F
.288 .416 .818 r
.35836 .55321 m .35815 .55431 L .35937 .55317 L F
.35815 .55431 m .35832 .55456 L .35937 .55317 L F
.35786 .55323 m .35804 .55492 L .35836 .55321 L F
.35786 .55323 m .35937 .55317 L .36026 .55201 L F
.674 .181 .071 r
.35736 .55321 m .35468 .55294 L .35464 .55217 L F
.35468 .55294 m .35077 .55254 L .35464 .55217 L F
.903 .917 .82 r
.3546 .55155 m .35537 .54789 L .35503 .5507 L F
.35429 .55219 m .35458 .55104 L .3546 .55155 L F
.35458 .55104 m .35537 .54789 L .3546 .55155 L F
.511 .856 .994 r
.35503 .5507 m .3526 .55139 L .35429 .55219 L F
.429 .698 .977 r
.26601 .5299 m .26854 .52983 L .26665 .52804 L F
.737 .674 .789 r
.63443 .41698 m .63573 .42082 L .63181 .42017 L F
.761 .499 .536 r
.63181 .42017 m .63573 .42082 L .63584 .42348 L F
.707 .658 .799 r
.63849 .41761 m .63573 .42082 L .63443 .41698 L F
.519 .037 .053 r
.63573 .42082 m .6383 .42135 L .63584 .42348 L F
0 0 .169 r
.29399 .63188 m .29208 .6353 L .29342 .63419 L F
0 0 0 r
.29637 .62814 m .29399 .63188 L .29627 .63116 L F
.214 0 .114 r
.29399 .63188 m .29562 .63341 L .29627 .63116 L F
.29399 .63188 m .29342 .63419 L .29562 .63341 L F
.302 0 .142 r
.30301 .56114 m .29903 .56445 L .29929 .56166 L F
.765 .675 .763 r
.64104 .41691 m .64241 .41834 L .63849 .41761 L F
.377 .545 .894 r
.32301 .68919 m .32529 .69268 L .32703 .69232 L F
.032 .224 .728 r
.32529 .69268 m .3278 .69637 L .32703 .69232 L F
.651 .852 .977 r
.33485 .699 m .33681 .70026 L .339 .69915 L F
0 0 0 r
.69657 .36322 m .69838 .35875 L .69805 .3611 L F
.655 .912 .599 r
.6951 .3644 m .69657 .36322 L .69805 .3611 L F
.444 .212 .467 r
.46928 .57999 m .46676 .58299 L .46722 .58084 L F
.39 .795 .983 r
.41871 .51373 m .4193 .51376 L .41757 .51269 L F
.747 .951 .638 r
.42194 .5104 m .4193 .51376 L .42015 .51193 L F
.968 .927 .694 r
.32629 .62259 m .3252 .62534 L .32374 .62444 L F
.288 0 .046 r
.32714 .62438 m .32584 .62292 L .32374 .62444 L F
.461 .766 .996 r
.32501 .62283 m .32714 .62438 L .32374 .62444 L F
.563 .024 0 r
.32823 .6256 m .32714 .62438 L .32501 .62283 L F
.598 .466 .673 r
.32979 .62575 m .33015 .62849 L .32786 .62793 L F
.563 .024 0 r
.32931 .62653 m .32714 .62438 L .32823 .6256 L F
.288 0 .046 r
.32714 .62438 m .32629 .62259 L .32584 .62292 L F
.32714 .62438 m .32884 .62199 L .32629 .62259 L F
.302 .629 .962 r
.37196 .6036 m .3769 .60608 L .37397 .60235 L F
.211 .733 .847 r
.28477 .52125 m .28219 .52116 L .28018 .52145 L F
.645 .942 .961 r
.28547 .51981 m .28477 .52125 L .28656 .51895 L F
.28547 .51981 m .28219 .52116 L .28477 .52125 L F
.362 .122 .41 r
.32558 .60906 m .32328 .60977 L .32605 .60654 L F
.362 .136 .43 r
.32558 .60906 m .32284 .61232 L .32328 .60977 L F
.788 .921 .926 r
.64337 .41062 m .64053 .41077 L .64212 .4089 L F
.815 .842 .87 r
.64613 .40783 m .64337 .41062 L .64212 .4089 L F
.507 .371 .631 r
.23574 .56908 m .23507 .57141 L .23739 .57079 L F
.673 .132 0 r
.34615 .5298 m .34449 .52981 L .34213 .52787 L F
.511 .91 .911 r
.3469 .52858 m .34449 .52981 L .34615 .5298 L F
.309 .023 .306 r
.41157 .49199 m .41062 .49426 L .40812 .49469 L F
.539 .365 .593 r
.41125 .49555 m .40812 .49469 L .41062 .49426 L F
.41125 .49555 m .40847 .49726 L .40812 .49469 L F
.666 .607 .78 r
.4312 .52322 m .43408 .5257 L .43241 .52172 L F
.156 .262 .722 r
.43408 .5257 m .43505 .5222 L .43241 .52172 L F
.43408 .5257 m .43612 .52464 L .43505 .5222 L F
.329 .781 .632 r
.43408 .5257 m .43371 .52588 L .43612 .52464 L F
0 0 0 r
.45606 .51614 m .45528 .51654 L .45592 .51445 L F
.45606 .51614 m .45364 .51748 L .45528 .51654 L F
.342 .09 .378 r
.22876 .57474 m .23058 .5763 L .23361 .57279 L F
.088 0 0 r
.23058 .5763 m .23496 .5742 L .23361 .57279 L F
.415 .253 .552 r
.31513 .60349 m .31756 .59983 L .31538 .60088 L F
.782 .695 .768 r
.3928 .5893 m .3959 .58745 L .39142 .58708 L F
.655 .424 .558 r
.3928 .5893 m .39546 .59012 L .3959 .58745 L F
.952 .727 .562 r
.3959 .58745 m .39346 .58908 L .39465 .58667 L F
.3959 .58745 m .39546 .59012 L .39346 .58908 L F
.469 .281 .542 r
.23496 .5742 m .23739 .57079 L .23507 .57141 L F
.813 .816 .853 r
.65874 .34365 m .66224 .34388 L .6608 .34205 L F
0 0 0 r
.56601 .42016 m .56736 .41672 L .56887 .42066 L F
.764 .965 .67 r
.30284 .64773 m .30276 .64821 L .30452 .64586 L F
0 0 0 r
.30248 .65118 m .30276 .64821 L .30284 .64773 L F
.966 .895 .704 r
.66716 .31778 m .66786 .31891 L .667 .32078 L F
.57 .77 .973 r
.56989 .46969 m .57084 .46703 L .56819 .47024 L F
.56989 .46969 m .57256 .46909 L .57084 .46703 L F
.887 .849 .801 r
.67291 .39149 m .67542 .39152 L .67376 .39063 L F
.862 .932 .869 r
.67152 .39316 m .67542 .39152 L .67291 .39149 L F
.771 .853 .912 r
.67542 .39152 m .67753 .38744 L .67376 .39063 L F
.67542 .39152 m .67898 .38914 L .67753 .38744 L F
.493 0 0 r
.59523 .40801 m .59248 .40648 L .59498 .40665 L F
0 0 .46 r
.59498 .40665 m .59645 .41038 L .59523 .40801 L F
.837 .999 .789 r
.34213 .5084 m .33997 .51119 L .34186 .51054 L F
.597 .925 .966 r
.37683 .67064 m .37393 .67147 L .37593 .67042 L F
.687 .965 .935 r
.37879 .66939 m .37683 .67064 L .37706 .66897 L F
.722 .983 .902 r
.37706 .66897 m .37683 .67064 L .37593 .67042 L F
.711 .764 .894 r
.6136 .35519 m .61528 .35694 L .61131 .35631 L F
.781 .85 .903 r
.61683 .35296 m .61528 .35694 L .6136 .35519 L F
.61683 .35296 m .61759 .35549 L .61528 .35694 L F
.691 .546 .685 r
.4608 .47769 m .4582 .4806 L .45817 .47849 L F
.388 .433 .786 r
.41973 .48847 m .4208 .49156 L .42266 .48996 L F
.64 .62 .814 r
.42169 .49373 m .42266 .48996 L .4208 .49156 L F
.983 .856 .635 r
.25005 .52932 m .25181 .53133 L .25114 .52898 L F
.711 .794 .916 r
.25114 .52898 m .25181 .53133 L .25554 .52969 L F
.717 .694 .827 r
.44864 .46791 m .44623 .46901 L .44474 .46609 L F
0 0 0 r
.29493 .65731 m .29698 .65562 L .29907 .65468 L F
.43187 .56472 m .43002 .56761 L .43094 .56508 L F
0 0 .044 r
.73225 .3323 m .73036 .33443 L .73097 .33404 L F
0 0 0 r
.73176 .33306 m .7313 .33352 L .73225 .3323 L F
.7313 .33352 m .73036 .33443 L .73225 .3323 L F
.645 .755 .929 r
.73225 .3323 m .73097 .33404 L .73092 .33399 L F
0 0 0 r
.73088 .33404 m .73036 .33443 L .73176 .33306 L F
.645 .755 .929 r
.73225 .3323 m .73092 .33399 L .72807 .331 L F
.499 .697 .958 r
.72807 .331 m .73092 .33399 L .72676 .33381 L F
.73092 .33399 m .73097 .33404 L .73088 .33404 L F
.73092 .33399 m .73088 .33404 L .72676 .33381 L F
0 0 0 r
.73137 .33367 m .73088 .33404 L .73176 .33306 L F
.294 .722 .97 r
.73097 .33404 m .73036 .33443 L .73088 .33404 L F
0 0 0 r
.72973 .33622 m .73036 .33443 L .73137 .33367 L F
.294 .722 .97 r
.73088 .33404 m .73036 .33443 L .72676 .33381 L F
.372 .071 .318 r
.47138 .46285 m .47349 .46407 L .4711 .4649 L F
.47138 .46285 m .47382 .4621 L .47349 .46407 L F
.728 .4 .426 r
.47138 .46285 m .4711 .4649 L .46859 .46249 L F
.891 .941 .839 r
.35826 .5191 m .35718 .52248 L .35989 .5204 L F
.35826 .5191 m .35569 .52174 L .35718 .52248 L F
.585 .87 .552 r
.35406 .56039 m .35295 .56176 L .3557 .55881 L F
0 0 .264 r
.35393 .56287 m .35295 .56176 L .35406 .56039 L F
.35393 .56287 m .35248 .56409 L .35295 .56176 L F
0 0 .019 r
.30783 .62914 m .3094 .62502 L .31017 .62858 L F
.479 .199 .411 r
.30783 .62914 m .3103 .62961 L .3074 .63168 L F
.30783 .62914 m .31017 .62858 L .3103 .62961 L F
.394 .839 .934 r
.31015 .55854 m .31015 .55807 L .30776 .55871 L F
.31236 .55839 m .31015 .55807 L .30776 .55871 L F
.75 .914 .542 r
.31015 .55807 m .30911 .55918 L .31016 .55751 L F
.31015 .55807 m .31016 .55751 L .31125 .55577 L F
.394 .839 .934 r
.31236 .55839 m .31015 .55807 L .31015 .55854 L F
.147 0 0 r
.31482 .55833 m .31015 .55807 L .31236 .55839 L F
.836 .703 .717 r
.52815 .4335 m .52457 .43288 L .52672 .42978 L F
.849 .707 .706 r
.52815 .4335 m .52412 .43571 L .52457 .43288 L F
.52815 .4335 m .5262 .43671 L .52412 .43571 L F
.822 .836 .86 r
.36712 .64168 m .36265 .64246 L .3652 .64299 L F
.931 .958 .646 r
.3682 .63764 m .36712 .64168 L .36974 .64134 L F
.5 .299 .539 r
.36726 .6449 m .36712 .64168 L .3652 .64299 L F
.36726 .6449 m .36974 .64134 L .36712 .64168 L F
0 0 0 r
.36712 .64168 m .36974 .64134 L .36726 .6449 L F
.983 .707 .415 r
.28103 .58685 m .28112 .58999 L .2826 .59058 L F
.28103 .58685 m .28112 .58999 L .2826 .59058 L F
.94 .658 .477 r
.64658 .398 m .64731 .40118 L .64478 .40163 L F
.772 .792 .299 r
.42493 .58364 m .42575 .58116 L .42601 .57961 L F
.373 .678 .976 r
.38715 .61409 m .38384 .61274 L .38643 .61245 L F
.38715 .61409 m .38384 .61274 L .38643 .61245 L F
.84 .394 .163 r
.38715 .61409 m .38827 .61603 L .38633 .61482 L F
0 0 .013 r
.47391 .57026 m .47348 .57293 L .47274 .57467 L F
.202 .122 .537 r
.47348 .57293 m .47162 .57665 L .47274 .57467 L F
.254 0 0 r
.26873 .63455 m .27231 .63477 L .27114 .63504 L F
.673 .171 .043 r
.27231 .63477 m .27461 .63591 L .27114 .63504 L F
.302 0 .142 r
.30301 .56114 m .30146 .56385 L .29903 .56445 L F
.43 .047 .21 r
.30527 .56079 m .30146 .56385 L .30301 .56114 L F
.01 0 0 r
.6975 .30357 m .69899 .30361 L .69639 .30508 L F
.6975 .30357 m .69983 .30172 L .69899 .30361 L F
.879 .959 .85 r
.394 .61125 m .39746 .61024 L .39588 .60913 L F
.845 .885 .869 r
.7006 .28104 m .70209 .2827 L .69865 .28519 L F
.653 .654 .838 r
.6141 .3691 m .61176 .37041 L .61093 .3688 L F
.897 .613 .497 r
.40549 .50315 m .4078 .50333 L .406 .50058 L F
.845 .933 .885 r
.4078 .50333 m .40858 .50053 L .406 .50058 L F
.389 .169 .455 r
.406 .50058 m .40746 .50171 L .40549 .50315 L F
.40746 .50171 m .40825 .50231 L .40597 .503 L F
.40746 .50171 m .40597 .503 L .40549 .50315 L F
.845 .933 .885 r
.4078 .50333 m .41032 .50143 L .40872 .50061 L F
.40851 .50079 m .40872 .50061 L .40858 .50053 L F
.4078 .50333 m .40872 .50061 L .40851 .50079 L F
.834 .999 .819 r
.41086 .49924 m .41032 .50143 L .41313 .4985 L F
.778 .666 .739 r
.41086 .49924 m .40858 .50053 L .41032 .50143 L F
.207 0 0 r
.55904 .46809 m .56296 .46875 L .56198 .46869 L F
.311 .644 .967 r
.56296 .46875 m .56432 .46748 L .56198 .46869 L F
.56296 .46875 m .56587 .46931 L .56432 .46748 L F
.653 .602 .785 r
.45959 .48482 m .4555 .48178 L .4582 .4806 L F
.657 .592 .77 r
.46229 .48418 m .45959 .48482 L .4582 .4806 L F
.635 .509 .692 r
.46229 .48418 m .45974 .48709 L .45959 .48482 L F
.807 .699 .745 r
.30842 .53114 m .30739 .52837 L .30911 .53066 L F
.867 .833 .811 r
.31173 .52682 m .30911 .53066 L .30739 .52837 L F
.287 .782 .881 r
.31212 .53075 m .30842 .53114 L .30911 .53066 L F
.178 0 0 r
.43874 .57983 m .44017 .57835 L .43548 .58063 L F
0 0 0 r
.44257 .5773 m .44017 .57835 L .43874 .57983 L F
.445 .784 .998 r
.62519 .40424 m .62824 .40482 L .62772 .40366 L F
.817 .999 .798 r
.62824 .40482 m .63144 .40142 L .62965 .40181 L F
.791 .974 .911 r
.62772 .40366 m .62824 .40482 L .62965 .40181 L F
.961 .654 .241 r
.3252 .62534 m .32424 .62712 L .32374 .62444 L F
.3252 .62534 m .32562 .62873 L .32424 .62712 L F
0 0 0 r
.24837 .5559 m .24857 .55664 L .25065 .55531 L F
.4286 .52708 m .4295 .52736 L .43009 .52732 L F
.4286 .52708 m .42753 .52826 L .4295 .52736 L F
.991 .887 .578 r
.3419 .68905 m .34212 .69263 L .34144 .6918 L F
0 0 .116 r
.34212 .69263 m .34099 .69651 L .34253 .69439 L F
.34212 .69263 m .34253 .69439 L .34144 .6918 L F
.779 .549 .587 r
.54027 .45926 m .5363 .46146 L .53652 .45872 L F
.54027 .45926 m .54019 .46196 L .5363 .46146 L F
.451 .746 .992 r
.42026 .5088 m .42194 .5104 L .42279 .50872 L F
.707 .937 .627 r
.42194 .5104 m .42015 .51193 L .42279 .50872 L F
.623 .533 .733 r
.31084 .53943 m .31111 .5372 L .31071 .53613 L F
.885 .816 .775 r
.38889 .49711 m .38455 .49961 L .38705 .49631 L F
.38889 .49711 m .38637 .50049 L .38455 .49961 L F
.885 .905 .837 r
.38889 .49711 m .38705 .49631 L .38977 .4928 L F
.505 .515 .8 r
.32233 .55092 m .32127 .55513 L .3209 .55289 L F
.096 .65 .796 r
.37485 .63484 m .37784 .63492 L .37747 .63475 L F
.159 .255 .715 r
.37977 .63377 m .37784 .63492 L .37752 .63283 L F
.404 .856 .803 r
.37747 .63475 m .37784 .63492 L .37977 .63377 L F
.23 0 .22 r
.30947 .60956 m .31175 .60885 L .31274 .6061 L F
.545 .375 .602 r
.31274 .6061 m .31515 .60568 L .31513 .60349 L F
.361 .013 .233 r
.31175 .60885 m .31515 .60568 L .31274 .6061 L F
0 0 0 r
.60629 .46088 m .60808 .4597 L .61007 .45856 L F
.60808 .4597 m .61089 .45626 L .61007 .45856 L F
.842 .77 .782 r
.43133 .57696 m .43586 .57455 L .43167 .57425 L F
.603 .385 .557 r
.51715 .45128 m .51567 .45514 L .51293 .45567 L F
.878 .502 .328 r
.51715 .45128 m .51963 .45553 L .51567 .45514 L F
.269 0 0 r
.51805 .45173 m .51715 .45128 L .51495 .45126 L F
.677 .738 .234 r
.32891 .57134 m .32946 .56966 L .33007 .56789 L F
0 0 .029 r
.32891 .57134 m .32913 .57209 L .32946 .56966 L F
.32891 .57134 m .32872 .57423 L .32913 .57209 L F
0 .299 .794 r
.26074 .62733 m .26172 .62679 L .25961 .62699 L F
.26074 .62733 m .26262 .62863 L .26172 .62679 L F
.141 .586 .928 r
.27746 .62366 m .2772 .62473 L .27443 .62215 L F
.27746 .62366 m .27889 .62485 L .2772 .62473 L F
.243 .073 .441 r
.70177 .30894 m .70178 .3109 L .70384 .30755 L F
.335 .167 .499 r
.33026 .59957 m .32817 .60307 L .32816 .6003 L F
.591 .556 .784 r
.45816 .52601 m .45465 .52351 L .45708 .52299 L F
.329 .196 .544 r
.36249 .57452 m .3626 .57728 L .36073 .57342 L F
.36249 .57452 m .36438 .57655 L .3626 .57728 L F
.3626 .57728 m .36438 .57655 L .36249 .57452 L F
.064 .259 .751 r
.62277 .37034 m .62236 .37281 L .62454 .37433 L F
.755 .286 0 r
.36559 .59869 m .36635 .60042 L .3642 .59656 L F
.879 .993 .769 r
.69494 .34809 m .69681 .34737 L .69424 .35085 L F
.845 .977 .873 r
.69494 .34809 m .69424 .35085 L .69331 .34984 L F
.19 .566 .936 r
.32574 .64733 m .32648 .64652 L .32472 .64462 L F
.32574 .64733 m .3282 .64822 L .32648 .64652 L F
.592 .365 .54 r
.34178 .59004 m .33878 .59302 L .33914 .59066 L F
.459 .822 .995 r
.62486 .38851 m .62879 .38881 L .6275 .38796 L F
.589 .884 .992 r
.6275 .38796 m .62879 .38881 L .63025 .3869 L F
.6275 .38796 m .62879 .38881 L .63025 .3869 L F
.262 0 .309 r
.69983 .30172 m .70245 .29899 L .70237 .3008 L F
.088 0 0 r
.69899 .30361 m .69983 .30172 L .70237 .3008 L F
.995 .754 .424 r
.52669 .41617 m .52804 .41766 L .52773 .41958 L F
.176 0 0 r
.37311 .63657 m .3724 .63538 L .37065 .63711 L F
.37311 .63657 m .37485 .63484 L .3724 .63538 L F
0 0 0 r
.58574 .46617 m .58833 .46542 L .58418 .46696 L F
.647 .72 .902 r
.32389 .53521 m .31966 .53407 L .32222 .53383 L F
.449 .439 .755 r
.45597 .52986 m .459 .53198 L .45698 .53264 L F
.505 .419 .692 r
.459 .53198 m .45715 .53635 L .45698 .53264 L F
.274 0 .279 r
.44709 .55479 m .45005 .55157 L .44779 .55238 L F
.481 .223 .445 r
.33622 .68709 m .33859 .68819 L .33605 .68901 L F
.33622 .68709 m .33825 .68748 L .33859 .68819 L F
.681 .186 .062 r
.30502 .51049 m .30081 .50945 L .30426 .5086 L F
.253 .496 .895 r
.3058 .50872 m .30502 .51049 L .30426 .5086 L F
.342 .123 .429 r
.3281 .60572 m .32558 .60906 L .32605 .60654 L F
.969 .667 .391 r
.39215 .53736 m .3944 .54233 L .3942 .53943 L F
.541 .239 .405 r
.35334 .59318 m .35557 .59551 L .35296 .59621 L F
.35334 .59318 m .35587 .5932 L .35557 .59551 L F
.52 .109 .201 r
.38985 .57906 m .38973 .58034 L .38587 .58029 L F
.539 .125 .203 r
.38985 .57906 m .39236 .58008 L .38973 .58034 L F
.459 .186 .411 r
.22598 .57751 m .22845 .57701 L .22876 .57474 L F
.342 .09 .378 r
.22876 .57474 m .22845 .57701 L .23058 .5763 L F
.432 .304 .605 r
.27635 .53549 m .27442 .53933 L .27397 .5361 L F
0 0 0 r
.27397 .5361 m .27451 .536 L .27635 .53549 L F
.27397 .5361 m .27184 .53733 L .27451 .536 L F
.981 .764 .536 r
.41356 .48804 m .412 .48964 L .41438 .49116 L F
.417 .127 .362 r
.41333 .49341 m .41157 .49199 L .41438 .49116 L F
.41333 .49341 m .41438 .49116 L .412 .48964 L F
.635 .509 .692 r
.46229 .48418 m .46345 .48786 L .45974 .48709 L F
.601 .502 .714 r
.46356 .49062 m .45974 .48709 L .46345 .48786 L F
.46356 .49062 m .4609 .49119 L .45974 .48709 L F
.407 .788 .992 r
.59117 .38078 m .59064 .38231 L .58406 .38187 L F
.293 .791 .796 r
.59217 .38169 m .59297 .38167 L .59064 .38231 L F
.59289 .3814 m .59297 .38167 L .59217 .38169 L F
.94 .725 .251 r
.59278 .38404 m .59289 .3814 L .59064 .38231 L F
.59342 .38456 m .59289 .3814 L .59278 .38404 L F
.59255 .38309 m .59064 .38231 L .59117 .38078 L F
.59342 .38456 m .59278 .38404 L .59255 .38309 L F
.59278 .38404 m .59064 .38231 L .59255 .38309 L F
.964 .94 .681 r
.59303 .37793 m .59289 .3814 L .59235 .38229 L F
.59222 .38175 m .59235 .38229 L .59197 .38293 L F
.59303 .37793 m .59235 .38229 L .59222 .38175 L F
.59307 .37773 m .59289 .3814 L .59303 .37793 L F
.94 .725 .251 r
.59342 .38456 m .59172 .38171 L .59197 .38293 L F
.59172 .38171 m .59117 .38078 L .59152 .38172 L F
.59172 .38171 m .59152 .38172 L .59197 .38293 L F
.293 .791 .796 r
.59289 .3814 m .59361 .38149 L .59297 .38167 L F
.75 .991 .884 r
.67199 .31428 m .67316 .31185 L .67541 .31191 L F
.67199 .31428 m .67136 .31351 L .67316 .31185 L F
0 0 .08 r
.29275 .6367 m .29208 .6353 L .29044 .63766 L F
.29275 .6367 m .29342 .63419 L .29208 .6353 L F
.565 .777 .978 r
.60621 .35321 m .60476 .35555 L .60341 .35396 L F
.60621 .35321 m .60725 .35489 L .60476 .35555 L F
.931 .551 .231 r
.38664 .5261 m .38753 .5287 L .38924 .52975 L F
.853 .396 .055 r
.38831 .53067 m .38924 .52975 L .38753 .5287 L F
.38831 .53067 m .39092 .53295 L .38924 .52975 L F
.874 .473 .269 r
.69627 .33072 m .69509 .33238 L .69348 .32896 L F
.862 .716 .7 r
.69891 .33037 m .69509 .33238 L .69627 .33072 L F
.696 .607 .753 r
.70705 .33406 m .70419 .33745 L .70355 .33489 L F
.899 .916 .824 r
.70656 .31808 m .70447 .3214 L .7032 .31973 L F
.592 .05 0 r
.70447 .3214 m .70358 .32275 L .7032 .31973 L F
.395 .223 .526 r
.70447 .3214 m .70467 .32442 L .70679 .32307 L F
.592 .05 0 r
.70447 .3214 m .70679 .32307 L .70358 .32275 L F
.418 .003 .142 r
.29004 .56762 m .28592 .56984 L .28757 .5682 L F
.523 .902 .955 r
.36819 .66848 m .36638 .66928 L .36466 .66889 L F
.789 .29 0 r
.36466 .66889 m .36638 .66928 L .36854 .67252 L F
.494 .68 .949 r
.71886 .34785 m .72108 .35023 L .72172 .34914 L F
.363 .754 .987 r
.72253 .35122 m .72108 .35023 L .72172 .34914 L F
0 0 0 r
.72172 .34914 m .72108 .35023 L .7203 .35261 L F
.588 .364 .544 r
.31937 .61933 m .31858 .6225 L .31589 .62259 L F
.519 .384 .637 r
.3209 .61852 m .31858 .6225 L .31937 .61933 L F
0 .47 .806 r
.34475 .52079 m .34149 .51909 L .34156 .51618 L F
.34475 .52079 m .34492 .52057 L .34149 .51909 L F
.536 .393 .633 r
.33995 .56463 m .33764 .56817 L .33575 .56413 L F
.33995 .56463 m .34013 .56741 L .33764 .56817 L F
.596 .397 .583 r
.33729 .57098 m .34013 .56741 L .33764 .56817 L F
.725 .66 .107 r
.33754 .56842 m .33764 .56817 L .34013 .56741 L F
.33754 .56842 m .33729 .57098 L .33764 .56817 L F
0 0 0 r
.33995 .56463 m .33764 .56817 L .34013 .56741 L F
.823 .607 .61 r
.35025 .54797 m .35012 .55162 L .34637 .55081 L F
.5 .324 .573 r
.35262 .54809 m .35012 .55162 L .35025 .54797 L F
.8 .575 .596 r
.34604 .6746 m .3469 .67726 L .34724 .67385 L F
.34368 .67609 m .34536 .6767 L .34604 .6746 L F
.34536 .6767 m .3469 .67726 L .34604 .6746 L F
.779 .632 .698 r
.34493 .67807 m .3469 .67726 L .34368 .67609 L F
.698 .744 .238 r
.3454 .67641 m .34498 .67789 L .3446 .67906 L F
.34498 .67789 m .34493 .67807 L .34469 .67877 L F
.34498 .67789 m .34469 .67877 L .3446 .67906 L F
.346 .6744 m .34549 .67614 L .3454 .67641 L F
.34549 .67614 m .34493 .67807 L .3454 .67641 L F
.8 .575 .596 r
.34368 .67609 m .34604 .6746 L .34456 .67478 L F
.34604 .6746 m .34724 .67385 L .34618 .67422 L F
.34604 .6746 m .34618 .67422 L .34456 .67478 L F
0 0 0 r
.61876 .37828 m .61985 .37676 L .62179 .37414 L F
.281 .735 .956 r
.32622 .51884 m .32827 .51902 L .33172 .51993 L F
.157 .663 .905 r
.32827 .51902 m .33232 .51978 L .33172 .51993 L F
.677 .804 .943 r
.34685 .68659 m .34275 .68617 L .34538 .68695 L F
0 .363 .82 r
.34805 .68615 m .34685 .68659 L .34538 .68695 L F
.525 .791 .994 r
.19379 .66863 m .19329 .67033 L .19131 .66902 L F
.19379 .66863 m .19329 .67033 L .19131 .66902 L F
.579 .418 .628 r
.38287 .56173 m .38311 .56456 L .38046 .56515 L F
.47 .36 .646 r
.39414 .49099 m .39719 .49331 L .39685 .49049 L F
.39414 .49099 m .39464 .49439 L .39719 .49331 L F
.35 0 0 r
.39232 .49205 m .39685 .49049 L .39414 .49099 L F
.39232 .49205 m .39493 .49217 L .39685 .49049 L F
.306 .699 .978 r
.39323 .49087 m .39423 .49164 L .39232 .49205 L F
.39423 .49164 m .39493 .49217 L .39232 .49205 L F
.879 .881 .832 r
.39414 .49099 m .3908 .49237 L .39232 .49205 L F
.3908 .49237 m .38977 .4928 L .39232 .49205 L F
.526 .876 .633 r
.68877 .31444 m .69205 .31196 L .6907 .31268 L F
.221 0 .192 r
.34174 .60953 m .3405 .60872 L .3429 .60897 L F
.34174 .60953 m .33899 .61188 L .3405 .60872 L F
.535 .008 0 r
.24896 .61658 m .25386 .61601 L .25149 .61542 L F
.985 .79 .559 r
.42444 .50725 m .42735 .50422 L .42712 .50682 L F
0 0 0 r
.38375 .6583 m .38052 .66063 L .38453 .66091 L F
.642 .588 .778 r
.38453 .66091 m .38639 .65665 L .38375 .6583 L F
.323 .44 .825 r
.35644 .68622 m .35831 .68948 L .35973 .68931 L F
.552 .507 .759 r
.35831 .68948 m .36098 .69254 L .35973 .68931 L F
.612 .426 .606 r
.45835 .49445 m .45837 .49721 L .45567 .49763 L F
.596 .432 .63 r
.46096 .49403 m .45835 .49445 L .4609 .49119 L F
.548 .375 .599 r
.46094 .49662 m .45835 .49445 L .46096 .49403 L F
.46094 .49662 m .45837 .49721 L .45835 .49445 L F
0 0 0 r
.44459 .59747 m .44401 .5969 L .44632 .59612 L F
.44459 .59747 m .44237 .59847 L .44401 .5969 L F
.273 .728 .955 r
.38892 .69633 m .39171 .69637 L .3899 .69539 L F
.633 .449 .615 r
.42855 .52255 m .42528 .52365 L .42738 .52063 L F
.391 .356 .7 r
.43021 .52161 m .42738 .52063 L .42991 .51967 L F
.43021 .52161 m .42855 .52255 L .42738 .52063 L F
.375 0 0 r
.34139 .49567 m .34391 .49649 L .34622 .49649 L F
.616 .069 0 r
.34391 .49649 m .34791 .49756 L .34622 .49649 L F
.419 .253 .548 r
.45816 .52601 m .45842 .52925 L .45597 .52986 L F
.474 .438 .737 r
.45842 .52925 m .459 .53198 L .45597 .52986 L F
.512 .103 .203 r
.27829 .57108 m .27576 .57448 L .27409 .57337 L F
.344 0 .085 r
.28077 .57075 m .27576 .57448 L .27829 .57108 L F
.153 0 .202 r
.44376 .56534 m .44134 .56814 L .44385 .56649 L F
.659 .216 .188 r
.44385 .56649 m .44576 .56715 L .44376 .56534 L F
0 0 .358 r
.39611 .54823 m .39755 .55111 L .39765 .55172 L F
.607 .054 0 r
.39832 .553 m .40041 .55423 L .39765 .55172 L F
.39832 .553 m .39765 .55172 L .39755 .55111 L F
0 .276 .727 r
.38474 .51069 m .38592 .51094 L .38372 .50919 L F
.38474 .51069 m .38751 .51232 L .38592 .51094 L F
.289 0 .222 r
.33671 .59392 m .33582 .59628 L .33354 .59676 L F
.282 0 .219 r
.33832 .5951 m .33671 .59392 L .33878 .59302 L F
.33832 .5951 m .33582 .59628 L .33671 .59392 L F
.867 .833 .811 r
.31173 .52682 m .30739 .52837 L .31092 .52659 L F
.651 .144 .027 r
.31092 .52659 m .31457 .52821 L .31173 .52682 L F
.773 .747 .83 r
.62278 .35215 m .62437 .35353 L .62051 .35306 L F
.776 .866 .915 r
.62605 .34964 m .62437 .35353 L .62278 .35215 L F
.122 .416 .862 r
.24289 .61276 m .24588 .61451 L .24534 .61564 L F
.495 .827 .999 r
.23496 .5742 m .23734 .57359 L .23903 .57445 L F
.767 .652 .736 r
.23496 .5742 m .23617 .57761 L .23903 .57445 L F
.525 .067 .108 r
.23903 .57445 m .2384 .57686 L .23734 .57359 L F
.23903 .57445 m .24027 .57614 L .2384 .57686 L F
.23903 .57445 m .24193 .57467 L .24027 .57614 L F
.845 .403 .169 r
.34685 .50666 m .34314 .50336 L .34699 .50404 L F
.797 .671 .726 r
.3841 .67285 m .38476 .67696 L .38082 .67663 L F
.938 .965 .73 r
.69617 .3461 m .69681 .34737 L .69494 .34809 L F
.484 .348 .62 r
.36663 .58203 m .36465 .5868 L .36458 .58442 L F
.364 .28 .626 r
.43944 .56909 m .4409 .57005 L .44134 .56814 L F
.438 .13 .344 r
.44134 .56814 m .44365 .56941 L .44385 .56649 L F
.44134 .56814 m .4409 .57005 L .44365 .56941 L F
.792 .844 .89 r
.70728 .34827 m .70957 .34691 L .70808 .34537 L F
.683 .745 .898 r
.70957 .34691 m .71133 .34261 L .70808 .34537 L F
.70957 .34691 m .71258 .34608 L .71133 .34261 L F
.675 .633 .799 r
.70957 .34691 m .71338 .34767 L .71258 .34608 L F
.945 .59 .204 r
.61714 .38502 m .61773 .38502 L .61613 .3817 L F
.734 .908 .535 r
.61496 .38876 m .61773 .38502 L .61714 .38502 L F
.744 .83 .917 r
.62051 .35306 m .61759 .35549 L .61683 .35296 L F
0 0 .358 r
.33651 .60706 m .3373 .60773 L .3388 .60645 L F
0 .2 .707 r
.59052 .40408 m .58815 .40235 L .5869 .40073 L F
.792 .844 .89 r
.70728 .34827 m .70808 .34537 L .70486 .34861 L F
.811 .823 .859 r
.33055 .66058 m .3292 .66283 L .326 .66289 L F
.291 .069 .394 r
.3306 .66379 m .3292 .66283 L .33055 .66058 L F
.488 .502 .798 r
.46405 .55237 m .46725 .55411 L .46501 .55467 L F
.909 .944 .815 r
.66999 .39742 m .67152 .39316 L .66967 .39709 L F
.798 .815 .865 r
.65076 .35073 m .65302 .34953 L .6523 .34611 L F
.832 .834 .848 r
.6523 .34611 m .65302 .34953 L .65567 .34647 L F
.558 .796 .988 r
.69765 .32631 m .70146 .32705 L .6988 .32775 L F
.313 .195 .554 r
.6966 .3072 m .69469 .30873 L .69639 .30508 L F
0 0 .039 r
.69401 .31025 m .69469 .30873 L .6966 .3072 L F
.736 .888 .949 r
.40614 .4835 m .40617 .48068 L .40848 .48271 L F
.475 .135 .31 r
.33011 .62441 m .33238 .62513 L .32979 .62575 L F
.33011 .62441 m .33317 .62307 L .33238 .62513 L F
.981 .825 .424 r
.378 .50352 m .37703 .50255 L .37784 .49895 L F
.92 .604 .428 r
.37968 .50572 m .37703 .50255 L .378 .50352 L F
.797 .895 .913 r
.42109 .47817 m .41797 .47869 L .41933 .47683 L F
.792 .879 .91 r
.42433 .47587 m .42109 .47817 L .41933 .47683 L F
.708 .647 .787 r
.38111 .61841 m .38524 .61915 L .38216 .62068 L F
.55 .259 .426 r
.60531 .3731 m .60532 .3753 L .60206 .37541 L F
.52 .407 .666 r
.37616 .62336 m .37933 .62524 L .3784 .62108 L F
.921 .613 .137 r
.40238 .57941 m .40276 .57776 L .40176 .57651 L F
.40238 .57941 m .40324 .58042 L .40276 .57776 L F
.975 .69 .294 r
.70245 .29017 m .70356 .28908 L .70234 .28769 L F
.70245 .29017 m .70488 .29537 L .70356 .28908 L F
.88 .931 .851 r
.70234 .28769 m .70356 .28908 L .70619 .28588 L F
.664 .536 .698 r
.70356 .28908 m .70753 .28922 L .70619 .28588 L F
.559 .54 .789 r
.36068 .54137 m .36186 .54511 L .35938 .54564 L F
.881 .887 .832 r
.36186 .54511 m .35772 .54701 L .35938 .54564 L F
.559 .54 .789 r
.36068 .54137 m .36186 .54511 L .35938 .54564 L F
.731 .328 .286 r
.32656 .54872 m .33084 .54692 L .3294 .54715 L F
.859 .805 .796 r
.36307 .52564 m .36236 .52647 L .36425 .52306 L F
.218 .145 .556 r
.42811 .59261 m .42623 .59 L .4284 .59034 L F
.171 .384 .829 r
.26262 .62863 m .26467 .63216 L .26585 .6307 L F
.642 .09 0 r
.26467 .63216 m .2669 .63434 L .26509 .6335 L F
.26467 .63216 m .26509 .6335 L .26585 .6307 L F
.688 .634 .79 r
.45679 .47197 m .45253 .47117 L .45525 .4682 L F
.563 .936 .888 r
.2447 .52548 m .24536 .52432 L .24648 .52466 L F
.694 .687 .839 r
.35825 .55609 m .36218 .55846 L .36062 .55468 L F
.555 .571 .825 r
.36218 .55846 m .36307 .55409 L .36062 .55468 L F
.36218 .55846 m .36459 .55784 L .36307 .55409 L F
0 0 0 r
.36218 .55846 m .36251 .55845 L .36459 .55784 L F
.36218 .55846 m .36149 .56093 L .36251 .55845 L F
.656 .648 .83 r
.71338 .34767 m .7151 .34339 L .71258 .34608 L F
.71338 .34767 m .71603 .34681 L .7151 .34339 L F
.851 .745 .746 r
.4296 .57073 m .43167 .57425 L .43327 .57232 L F
.5 .475 .761 r
.46007 .53832 m .45863 .54285 L .45806 .53867 L F
.46007 .53832 m .46109 .54241 L .45863 .54285 L F
.497 .453 .739 r
.46109 .54241 m .46181 .54453 L .45863 .54285 L F
.507 .449 .726 r
.45863 .54285 m .46181 .54453 L .45934 .5451 L F
.546 .822 .47 r
.37839 .58495 m .37461 .58935 L .37599 .5877 L F
.483 .714 .972 r
.37754 .58885 m .37461 .58935 L .37839 .58495 L F
0 0 .024 r
.37853 .58738 m .37754 .58885 L .37772 .58802 L F
.37853 .58738 m .37772 .58802 L .37839 .58495 L F
.409 .855 .775 r
.37922 .58682 m .37853 .58738 L .3798 .58655 L F
.403 0 0 r
.37599 .5877 m .37853 .58738 L .37839 .58495 L F
.409 .855 .775 r
.37759 .5876 m .37853 .58738 L .37922 .58682 L F
.496 .23 .44 r
.46357 .47227 m .46335 .4748 L .46051 .47549 L F
.533 .261 .448 r
.46576 .47355 m .46335 .4748 L .46357 .47227 L F
.443 .318 .615 r
.46585 .47123 m .46576 .47355 L .46357 .47227 L F
.46585 .47123 m .46576 .47355 L .46357 .47227 L F
.802 .584 .607 r
.39048 .5042 m .38637 .50049 L .38904 .50053 L F
.39048 .5042 m .38632 .50366 L .38637 .50049 L F
.516 .489 .765 r
.39242 .50312 m .39048 .5042 L .38904 .50053 L F
.233 .481 .889 r
.59671 .39692 m .59711 .3988 L .60047 .39993 L F
.063 .507 .895 r
.59711 .3988 m .60181 .40107 L .60047 .39993 L F
.654 .959 .936 r
.3294 .54715 m .32729 .54704 L .32656 .54872 L F
.457 .514 .828 r
.32729 .54704 m .32695 .55158 L .32656 .54872 L F
.706 .583 .715 r
.43105 .50719 m .4284 .51041 L .42712 .50682 L F
.497 .32 .571 r
.34422 .58933 m .34187 .58719 L .34378 .58658 L F
.34422 .58933 m .34178 .59004 L .34187 .58719 L F
.206 0 .193 r
.62954 .40051 m .63053 .39813 L .62504 .40258 L F
.417 .283 .59 r
.62954 .40051 m .62504 .40258 L .62772 .40366 L F
.49 .537 .832 r
.62378 .40045 m .62772 .40366 L .62504 .40258 L F
.802 .886 .906 r
.35672 .55601 m .3557 .55881 L .35825 .55609 L F
.859 .484 0 r
.41606 .59632 m .41425 .59271 L .41535 .59405 L F
.708 .923 .588 r
.51293 .45567 m .51047 .45892 L .51144 .45694 L F
.473 .768 .995 r
.51144 .45694 m .51047 .45892 L .50876 .45681 L F
.633 .512 .697 r
.51293 .45567 m .51335 .45832 L .51047 .45892 L F
.573 .323 .499 r
.51047 .45892 m .51275 .46078 L .51035 .46162 L F
.51047 .45892 m .51335 .45832 L .51275 .46078 L F
.799 .381 0 r
.58878 .39065 m .58984 .39187 L .59098 .39443 L F
0 0 .336 r
.34877 .6727 m .35029 .67554 L .34959 .67423 L F
.35029 .67554 m .35037 .67569 L .34959 .67423 L F
.584 .811 .986 r
.34877 .6727 m .34959 .67423 L .34724 .67385 L F
0 0 .336 r
.35029 .67554 m .35058 .6761 L .35037 .67569 L F
.968 .653 .357 r
.34945 .67577 m .35058 .6761 L .34989 .67481 L F
.34945 .67577 m .34989 .67481 L .34877 .6727 L F
.63 .937 .963 r
.34945 .67577 m .35058 .6761 L .3469 .67726 L F
.745 .328 .259 r
.34835 .67791 m .35058 .6761 L .34945 .67577 L F
0 0 0 r
.34885 .67707 m .34945 .67577 L .35035 .67456 L F
.34835 .67791 m .34945 .67577 L .34885 .67707 L F
.968 .653 .357 r
.34945 .67577 m .34877 .6727 L .35216 .67281 L F
.177 .039 .443 r
.34724 .67385 m .3469 .67726 L .34877 .6727 L F
.805 .729 .78 r
.34877 .6727 m .3469 .67726 L .34493 .67807 L F
.837 .984 .701 r
.34772 .67325 m .34493 .67807 L .346 .6744 L F
.805 .729 .78 r
.34877 .6727 m .34493 .67807 L .34772 .67325 L F
.568 .063 .014 r
.346 .6744 m .34885 .6745 L .34772 .67325 L F
.968 .653 .357 r
.34992 .67485 m .35181 .67281 L .3506 .67351 L F
.34945 .67577 m .35006 .67511 L .34992 .67485 L F
0 0 0 r
.35035 .67456 m .34945 .67577 L .35094 .67282 L F
.568 .063 .014 r
.34885 .6745 m .35035 .67456 L .3495 .67414 L F
.34885 .6745 m .3495 .67414 L .34772 .67325 L F
.968 .653 .357 r
.34992 .67485 m .35216 .67281 L .35181 .67281 L F
.3506 .67351 m .35181 .67281 L .35094 .67282 L F
.35006 .67511 m .35216 .67281 L .34992 .67485 L F
.395 .329 .665 r
.34213 .52787 m .34449 .52981 L .34273 .53044 L F
.795 .819 .34 r
.40123 .5727 m .40204 .57113 L .40148 .56924 L F
.40123 .5727 m .40101 .57403 L .40204 .57113 L F
.086 .638 .818 r
.38282 .66068 m .38453 .66091 L .38052 .66063 L F
.692 .152 0 r
.3844 .66206 m .38453 .66091 L .38282 .66068 L F
.3844 .66206 m .38678 .6633 L .38453 .66091 L F
.408 .422 .763 r
.3258 .50057 m .32683 .5042 L .32848 .50192 L F
.477 .351 .629 r
.32683 .5042 m .32937 .50608 L .32848 .50192 L F
.32683 .5042 m .32714 .50684 L .32937 .50608 L F
.673 .16 .013 r
.32683 .5042 m .32937 .50608 L .32714 .50684 L F
.716 .576 .697 r
.45253 .47117 m .44864 .46791 L .45239 .46899 L F
.45253 .47117 m .45016 .47217 L .44864 .46791 L F
.666 .616 .79 r
.45525 .4682 m .45253 .47117 L .45239 .46899 L F
.717 .694 .827 r
.44864 .46791 m .44474 .46609 L .44768 .46523 L F
.719 .789 .907 r
.45113 .46557 m .44864 .46791 L .44768 .46523 L F
.613 .589 .803 r
.45113 .46557 m .45239 .46899 L .44864 .46791 L F
.861 .632 .097 r
.70178 .3109 m .70242 .31504 L .7019 .31339 L F
.915 .614 .129 r
.70242 .31504 m .70186 .31586 L .7019 .31339 L F
.70242 .31504 m .70276 .31739 L .70186 .31586 L F
.661 .712 .886 r
.60966 .35382 m .60859 .35717 L .60725 .35489 L F
.60966 .35382 m .61131 .35631 L .60859 .35717 L F
.644 .734 .914 r
.34531 .68165 m .34961 .683 L .34775 .68243 L F
.038 .584 .838 r
.34961 .683 m .35188 .6833 L .34775 .68243 L F
.654 .52 .688 r
.46356 .49062 m .46096 .49403 L .4609 .49119 L F
.221 0 .056 r
.29888 .54534 m .30179 .54447 L .30225 .54298 L F
.715 .481 .57 r
.30179 .54447 m .30467 .54273 L .30225 .54298 L F
.364 .28 .626 r
.43944 .56909 m .43912 .5731 L .4409 .57005 L F
.381 .231 .549 r
.43889 .57354 m .4409 .57005 L .43912 .5731 L F
.806 .728 .779 r
.43574 .46843 m .43168 .46803 L .43419 .4647 L F
.605 .627 .847 r
.43744 .46723 m .43574 .46843 L .43419 .4647 L F
.569 .219 .336 r
.27143 .57344 m .26734 .57623 L .26886 .57384 L F
.734 .69 .808 r
.72095 .32136 m .71713 .3211 L .71975 .318 L F
.683 .757 .907 r
.72239 .318 m .72095 .32136 L .71975 .318 L F
.72239 .318 m .72175 .32057 L .72095 .32136 L F
.31 .139 .48 r
.72372 .3224 m .72095 .32136 L .72175 .32057 L F
.72372 .3224 m .72068 .32408 L .72095 .32136 L F
0 .112 .649 r
.60404 .40334 m .60505 .40504 L .60733 .40716 L F
.726 .204 0 r
.60505 .40504 m .60871 .40846 L .60733 .40716 L F
.941 .906 .519 r
.64444 .40032 m .64478 .40163 L .64353 .40264 L F
.621 .45 .629 r
.38287 .56173 m .38607 .56194 L .38311 .56456 L F
0 0 .076 r
.33238 .62513 m .33317 .62307 L .33463 .6219 L F
0 0 0 r
.33317 .62307 m .33459 .61913 L .33463 .6219 L F
.352 .092 .372 r
.29595 .54793 m .29842 .54791 L .29888 .54534 L F
.376 .279 .616 r
.29595 .54793 m .29857 .55068 L .29842 .54791 L F
.717 .763 .889 r
.46724 .46115 m .46859 .46249 L .46504 .46217 L F
.774 .611 .677 r
.46504 .46217 m .46859 .46249 L .46844 .4654 L F
.213 .161 .58 r
.46859 .46249 m .47021 .46055 L .46962 .45782 L F
.599 .729 .936 r
.46724 .46115 m .47021 .46055 L .46859 .46249 L F
.557 .426 .657 r
.46859 .46249 m .4711 .4649 L .46844 .4654 L F
.98 .909 .655 r
.3595 .51613 m .35826 .5191 L .35616 .51734 L F
.835 .876 .873 r
.6481 .33817 m .64394 .33961 L .64671 .33672 L F
.841 .879 .869 r
.64978 .33639 m .6481 .33817 L .64671 .33672 L F
.621 .454 .635 r
.24311 .53611 m .24355 .53843 L .24167 .53801 L F
.501 .374 .639 r
.24616 .53746 m .24355 .53843 L .24311 .53611 L F
.576 .414 .626 r
.42855 .52255 m .42454 .52679 L .42528 .52365 L F
.118 .223 .698 r
.42409 .53954 m .42481 .54202 L .42473 .53785 L F
.501 .23 .435 r
.42716 .53593 m .42409 .53954 L .42473 .53785 L F
.53 .266 .459 r
.42961 .53807 m .42716 .53593 L .4297 .53484 L F
.42961 .53807 m .42409 .53954 L .42716 .53593 L F
.441 .814 .993 r
.3338 .52457 m .32953 .52444 L .33088 .5253 L F
0 0 0 r
.31101 .64685 m .31155 .6456 L .31301 .64417 L F
.585 .807 .984 r
.5704 .44552 m .57453 .44627 L .57311 .4447 L F
.331 0 0 r
.57325 .44618 m .57453 .44627 L .5704 .44552 L F
.933 .88 .759 r
.57311 .4447 m .57453 .44627 L .57325 .44618 L F
0 .068 .61 r
.3338 .58062 m .33601 .58281 L .33532 .5816 L F
.3338 .58062 m .33532 .5816 L .33168 .58453 L F
0 0 .035 r
.36236 .52647 m .36231 .52235 L .36425 .52306 L F
.36236 .52647 m .36237 .52485 L .36233 .52386 L F
.234 .28 .706 r
.36181 .52895 m .36353 .52769 L .36237 .52485 L F
.669 .228 .193 r
.36227 .52619 m .36243 .52625 L .36237 .52485 L F
.068 .179 .672 r
.36353 .52769 m .36441 .52701 L .36237 .52485 L F
.669 .228 .193 r
.36243 .52625 m .36441 .52701 L .36237 .52485 L F
0 0 .035 r
.36233 .52386 m .36237 .52485 L .36231 .52235 L F
.619 .058 0 r
.40549 .50315 m .40947 .50578 L .4078 .50333 L F
.7 .612 .755 r
.42899 .50439 m .42712 .50682 L .42735 .50422 L F
.42899 .50439 m .43105 .50719 L .42712 .50682 L F
.729 .679 .801 r
.65787 .4012 m .66196 .40198 L .66059 .39811 L F
.782 .706 .78 r
.66059 .39811 m .66196 .40198 L .66433 .39886 L F
.416 .444 .781 r
.72708 .32768 m .72565 .33203 L .72386 .32607 L F
.839 .903 .882 r
.72536 .33175 m .72565 .33203 L .72708 .32768 L F
.499 .697 .958 r
.72807 .331 m .72676 .33381 L .72536 .33175 L F
.806 .924 .915 r
.667 .32078 m .66373 .32131 L .66597 .31979 L F
.966 .895 .704 r
.66716 .31778 m .667 .32078 L .66597 .31979 L F
.844 .645 .634 r
.52704 .42711 m .52315 .42914 L .52387 .42648 L F
.52704 .42711 m .52672 .42978 L .52315 .42914 L F
.171 .704 .838 r
.26534 .51768 m .26812 .51729 L .26981 .51772 L F
0 0 .511 r
.27016 .51762 m .26981 .51772 L .26812 .51729 L F
.27016 .51762 m .27196 .52039 L .26981 .51772 L F
.613 .56 .772 r
.45692 .5198 m .45364 .51748 L .45606 .51614 L F
.143 0 0 r
.35147 .65107 m .34916 .65176 L .34814 .65349 L F
.623 .469 .653 r
.45837 .49721 m .45589 .50021 L .45567 .49763 L F
.838 .979 .876 r
.3928 .5893 m .38914 .59259 L .39251 .59277 L F
.546 .5 .756 r
.39014 .59659 m .39251 .59277 L .38914 .59259 L F
.346 .441 .816 r
.71102 .31229 m .71149 .3158 L .70915 .31495 L F
.493 .293 .537 r
.71224 .3165 m .70915 .31495 L .71149 .3158 L F
.851 .553 .483 r
.70915 .31495 m .70947 .31765 L .71136 .31771 L F
.493 .293 .537 r
.71224 .3165 m .70947 .31765 L .70915 .31495 L F
0 0 0 r
.21271 .5616 m .21442 .56026 L .21499 .5582 L F
0 0 .26 r
.21271 .5616 m .21384 .56262 L .21442 .56026 L F
.21271 .5616 m .21243 .56424 L .21384 .56262 L F
.135 0 0 r
.52211 .44993 m .51805 .45173 L .52075 .44847 L F
.687 .631 .787 r
.52269 .44529 m .52211 .44993 L .52075 .44847 L F
.52269 .44529 m .52437 .4489 L .52211 .44993 L F
0 0 0 r
.61212 .45446 m .61089 .45626 L .6125 .45265 L F
.906 .804 .327 r
.6125 .45265 m .6126 .44883 L .61305 .45054 L F
0 0 0 r
.61305 .45054 m .61212 .45446 L .6125 .45265 L F
.249 0 .002 r
.34422 .60866 m .34174 .60953 L .3429 .60897 L F
.2 0 .307 r
.31893 .58707 m .32043 .58659 L .3211 .58421 L F
.671 .12 0 r
.25142 .62116 m .24709 .61841 L .24922 .6214 L F
.637 .608 .804 r
.56708 .4008 m .56932 .3977 L .56772 .39828 L F
.32 .004 .262 r
.26096 .57128 m .26367 .57046 L .26396 .56831 L F
.641 .272 .328 r
.26367 .57046 m .26621 .57057 L .26396 .56831 L F
0 0 0 r
.28745 .51884 m .28547 .51981 L .28656 .51895 L F
.383 .036 .247 r
.46121 .58453 m .46323 .58561 L .46066 .58582 L F
.46121 .58453 m .4636 .58391 L .46323 .58561 L F
.47 .273 .53 r
.70374 .29628 m .70488 .29537 L .70291 .29423 L F
.789 .341 .181 r
.70239 .29716 m .70374 .29628 L .70291 .29423 L F
.70239 .29716 m .70507 .29807 L .70374 .29628 L F
.294 0 0 r
.37269 .58014 m .37707 .58082 L .37524 .58074 L F
.447 .27 .547 r
.37701 .58348 m .37944 .58267 L .37707 .58082 L F
0 .455 .838 r
.37944 .58267 m .37524 .58074 L .37707 .58082 L F
.378 .546 .894 r
.33052 .55854 m .32866 .56 L .32757 .55854 L F
0 0 0 r
.61007 .45856 m .61089 .45626 L .61212 .45446 L F
.911 .97 .796 r
.36942 .60483 m .37003 .60679 L .37196 .6036 L F
.776 .683 .135 r
.41502 .57745 m .4147 .57913 L .41459 .57643 L F
.41502 .57745 m .41475 .58053 L .4147 .57913 L F
.805 .69 .738 r
.37931 .62896 m .38369 .62836 L .38284 .62805 L F
.37931 .62896 m .38137 .63237 L .38369 .62836 L F
.818 .994 .753 r
.38369 .62836 m .3851 .62543 L .38284 .62805 L F
.38369 .62836 m .38624 .62533 L .3851 .62543 L F
.505 .515 .8 r
.32233 .55092 m .32359 .55438 L .32127 .55513 L F
0 0 0 r
.32359 .55438 m .32076 .55705 L .32127 .55513 L F
.003 .519 .857 r
.39346 .58908 m .39546 .59012 L .3928 .5893 L F
0 0 .158 r
.39346 .58908 m .3928 .5893 L .39251 .59277 L F
.733 .628 .742 r
.56736 .41672 m .57165 .41755 L .56887 .42066 L F
.638 .965 .839 r
.31313 .66592 m .31534 .66534 L .31244 .66727 L F
.236 .574 .941 r
.31313 .66592 m .31517 .66785 L .31244 .66727 L F
.741 .399 .403 r
.32562 .62873 m .32786 .62793 L .32589 .63075 L F
.531 .01 0 r
.32786 .62793 m .32868 .62973 L .32589 .63075 L F
.32786 .62793 m .33015 .62849 L .32868 .62973 L F
.006 .554 .83 r
.35181 .49852 m .35454 .49889 L .35654 .49959 L F
0 .363 .676 r
.35454 .49889 m .35841 .50023 L .35654 .49959 L F
.629 .621 .824 r
.71797 .35566 m .7203 .35261 L .71768 .35401 L F
.71797 .35566 m .72198 .35654 L .7203 .35261 L F
.709 .588 .718 r
.39193 .49699 m .39358 .50122 L .38904 .50053 L F
.516 .489 .765 r
.39242 .50312 m .38904 .50053 L .39358 .50122 L F
.497 .473 .761 r
.39384 .49921 m .39358 .50122 L .39193 .49699 L F
.822 .819 .846 r
.64654 .35233 m .65076 .35073 L .64944 .34928 L F
.798 .815 .865 r
.65076 .35073 m .6523 .34611 L .64944 .34928 L F
.953 .664 .453 r
.33488 .5202 m .33697 .52046 L .33232 .51978 L F
.33488 .5202 m .33645 .52231 L .33697 .52046 L F
.633 .296 .383 r
.33697 .52046 m .34095 .52137 L .34084 .51989 L F
.33697 .52046 m .33645 .52231 L .34095 .52137 L F
.558 .191 .301 r
.59755 .46222 m .59427 .46368 L .59459 .46267 L F
.801 .976 .904 r
.65116 .39105 m .64924 .39146 L .65049 .38986 L F
.765 .896 .935 r
.65399 .38725 m .65116 .39105 L .65049 .38986 L F
.65399 .38725 m .65528 .38857 L .65116 .39105 L F
0 .081 .631 r
.39703 .51993 m .39659 .51848 L .39497 .51698 L F
.688 .404 0 r
.39773 .52247 m .39659 .51848 L .39703 .51993 L F
.668 .228 0 r
.22989 .60575 m .22956 .60577 L .22751 .60229 L F
0 0 .003 r
.22989 .60575 m .22991 .60744 L .22956 .60577 L F
.22989 .60575 m .22987 .60866 L .22991 .60744 L F
0 0 .082 r
.22977 .60906 m .22987 .60893 L .22989 .60575 L F
0 0 .098 r
.22969 .60939 m .22995 .6063 L .22991 .60744 L F
.22995 .6063 m .22996 .60612 L .22991 .60744 L F
0 0 .003 r
.22987 .60866 m .22987 .60893 L .22991 .60744 L F
0 .059 .599 r
.60181 .40107 m .60313 .4019 L .60047 .39993 L F
.60181 .40107 m .60404 .40334 L .60313 .4019 L F
0 0 .441 r
.69714 .33765 m .69786 .33778 L .69749 .33509 L F
.973 .662 .316 r
.69749 .33509 m .69786 .33778 L .69773 .33765 L F
.991 .882 .564 r
.69727 .33276 m .69714 .33765 L .69749 .33509 L F
.973 .662 .316 r
.69749 .33509 m .69773 .33765 L .69675 .33665 L F
.991 .882 .564 r
.69728 .33247 m .69727 .33276 L .69749 .33509 L F
0 0 .441 r
.69714 .33765 m .69804 .33997 L .69786 .33778 L F
0 0 .14 r
.32383 .52008 m .32468 .52103 L .32622 .51884 L F
.32383 .52008 m .32266 .52406 L .32468 .52103 L F
.802 .884 .904 r
.63595 .34676 m .6327 .34698 L .63456 .34523 L F
.803 .862 .893 r
.63896 .34402 m .63595 .34676 L .63456 .34523 L F
0 0 .208 r
.34122 .52067 m .34144 .52294 L .34084 .51989 L F
.34122 .52067 m .34084 .51989 L .34095 .52137 L F
.577 .548 .786 r
.2384 .57686 m .23617 .57761 L .23496 .5742 L F
.39 .233 .544 r
.23875 .57885 m .23617 .57761 L .2384 .57686 L F
.23875 .57885 m .236 .58039 L .23617 .57761 L F
0 .422 .771 r
.34213 .49559 m .34139 .49567 L .33949 .49457 L F
.34213 .49559 m .34391 .49649 L .34139 .49567 L F
.968 .646 .312 r
.59821 .4139 m .59645 .41038 L .59672 .41266 L F
.834 .431 0 r
.5982 .41537 m .59821 .4139 L .59672 .41266 L F
.5982 .41537 m .59951 .41717 L .59821 .4139 L F
.415 .253 .552 r
.31513 .60349 m .31715 .60291 L .31756 .59983 L F
.425 .281 .58 r
.31515 .60568 m .31715 .60291 L .31513 .60349 L F
.788 .423 0 r
.39339 .59732 m .39444 .59995 L .39304 .59693 L F
.64 .96 .921 r
.39516 .59552 m .39339 .59732 L .39304 .59693 L F
.39516 .59552 m .39339 .59732 L .39304 .59693 L F
0 0 .433 r
.25266 .554 m .25122 .55775 L .25065 .55531 L F
0 0 0 r
.25274 .55712 m .25039 .55817 L .25122 .55775 L F
.341 .09 .381 r
.30947 .60956 m .3114 .61146 L .31175 .60885 L F
.30947 .60956 m .30922 .61229 L .3114 .61146 L F
.098 0 0 r
.3316 .58952 m .33341 .5895 L .33496 .58718 L F
.113 0 0 r
.33496 .58718 m .33589 .58848 L .33678 .58571 L F
.33496 .58718 m .33341 .5895 L .33589 .58848 L F
.75 .328 .248 r
.35278 .6793 m .35455 .67686 L .35058 .6761 L F
0 0 .279 r
.35526 .67819 m .35526 .67973 L .35455 .67686 L F
.35526 .67819 m .35455 .67686 L .35278 .6793 L F
0 0 .513 r
.2097 .57732 m .20986 .58091 L .21097 .57923 L F
0 0 .439 r
.21076 .58358 m .21097 .57923 L .20986 .58091 L F
.472 .288 .55 r
.70521 .30059 m .70245 .29899 L .70507 .29807 L F
.551 .218 .357 r
.70237 .3008 m .70245 .29899 L .70521 .30059 L F
.369 .076 .331 r
.70237 .3008 m .70245 .29899 L .70507 .29807 L F
.259 .034 .37 r
.39032 .65622 m .3881 .65897 L .38987 .65862 L F
.39042 .65567 m .39002 .65624 L .39032 .65622 L F
.39002 .65624 m .3881 .65897 L .39032 .65622 L F
.097 0 0 r
.39503 .65519 m .39299 .65555 L .39211 .65611 L F
.284 0 0 r
.3894 .6578 m .39042 .65567 L .39023 .65669 L F
.3894 .6578 m .39023 .65669 L .38987 .65862 L F
0 .307 .661 r
.38987 .65862 m .3914 .65925 L .3894 .6578 L F
.72 .188 0 r
.3894 .6578 m .3914 .65925 L .38914 .65814 L F
.111 0 .242 r
.38948 .65733 m .3881 .65897 L .39042 .65567 L F
0 .028 .549 r
.38639 .65665 m .3881 .65897 L .38948 .65733 L F
.72 .188 0 r
.3894 .6578 m .38914 .65814 L .38727 .65723 L F
.097 0 0 r
.39321 .65604 m .39211 .65611 L .3894 .6578 L F
.39503 .65519 m .39211 .65611 L .39321 .65604 L F
.298 .166 .526 r
.38612 .65396 m .38948 .65733 L .38801 .65355 L F
.38612 .65396 m .38639 .65665 L .38948 .65733 L F
.391 .355 .699 r
.45901 .53647 m .45806 .53867 L .45715 .53635 L F
.45901 .53647 m .46007 .53832 L .45806 .53867 L F
.428 .596 .914 r
.61842 .39113 m .61574 .39138 L .61496 .38876 L F
0 .139 .683 r
.40275 .5316 m .40129 .52824 L .40201 .52961 L F
.904 .976 .686 r
.72334 .35157 m .72574 .34632 L .72172 .34914 L F
.997 .832 .488 r
.61245 .44438 m .61383 .44306 L .61231 .44186 L F
.61245 .44438 m .61336 .44556 L .61383 .44306 L F
.72 .96 .944 r
.32521 .64234 m .32472 .64462 L .32673 .64262 L F
0 .094 .642 r
.32521 .64234 m .32472 .64462 L .32648 .64652 L F
.516 .302 .527 r
.27914 .56409 m .28186 .56102 L .27935 .56155 L F
0 0 0 r
.29218 .51369 m .28846 .51689 L .29031 .51647 L F
.358 .011 .232 r
.29467 .5132 m .29218 .51369 L .29031 .51647 L F
0 0 .12 r
.41415 .56455 m .41441 .56556 L .41288 .56285 L F
.41415 .56455 m .41449 .56713 L .41441 .56556 L F
.862 .825 .81 r
.61655 .39328 m .61911 .39428 L .61842 .39113 L F
.907 .572 .096 r
.61919 .39771 m .61911 .39428 L .61655 .39328 L F
.61919 .39771 m .62077 .40015 L .61911 .39428 L F
.793 .867 .904 r
.61911 .39428 m .62099 .39015 L .61842 .39113 L F
.61911 .39428 m .62241 .39165 L .62099 .39015 L F
.664 .489 .637 r
.47974 .45604 m .48003 .45876 L .47572 .45916 L F
.56 .505 .751 r
.48223 .45513 m .47974 .45604 L .47889 .45226 L F
.441 .326 .626 r
.48227 .45787 m .47974 .45604 L .48223 .45513 L F
.48227 .45787 m .48003 .45876 L .47974 .45604 L F
.761 .935 .942 r
.68421 .38503 m .68741 .38435 L .68616 .38333 L F
.743 .799 .898 r
.68741 .38435 m .68916 .38056 L .68616 .38333 L F
.68741 .38435 m .69102 .38228 L .68916 .38056 L F
.596 .76 .957 r
.24616 .53746 m .2477 .53913 L .24355 .53843 L F
.24616 .53746 m .2477 .53913 L .24355 .53843 L F
.702 .798 .924 r
.25005 .53807 m .2477 .53913 L .24616 .53746 L F
.25005 .53807 m .2477 .53913 L .24616 .53746 L F
.603 .224 .296 r
.28069 .51991 m .28549 .51678 L .28286 .51685 L F
.89 .535 .365 r
.4319 .59847 m .43428 .59946 L .43355 .60024 L F
.167 0 0 r
.43428 .59946 m .43621 .59965 L .43355 .60024 L F
.43428 .59946 m .43728 .59904 L .43621 .59965 L F
.156 .466 .89 r
.25224 .62317 m .25279 .62185 L .25142 .62116 L F
.25224 .62317 m .25537 .62465 L .25279 .62185 L F
.549 .37 .591 r
.45617 .50394 m .45712 .50743 L .4545 .50826 L F
.463 .367 .661 r
.45849 .49961 m .45617 .50394 L .45589 .50021 L F
.45849 .49961 m .45863 .50432 L .45617 .50394 L F
.564 .428 .654 r
.45863 .50432 m .45712 .50743 L .45617 .50394 L F
.765 .826 .9 r
.64194 .39332 m .64331 .39499 L .63962 .39459 L F
.784 .397 .322 r
.63962 .39459 m .64331 .39499 L .64235 .39724 L F
.586 .683 .908 r
.64477 .39224 m .64331 .39499 L .64194 .39332 L F
.64477 .39224 m .64597 .39428 L .64331 .39499 L F
.71 .452 .534 r
.64597 .39428 m .64235 .39724 L .64331 .39499 L F
.625 .362 .5 r
.37383 .57756 m .37269 .58014 L .36976 .58042 L F
.878 .497 .025 r
.58406 .38187 m .58276 .38115 L .5857 .38034 L F
.58406 .38187 m .5839 .38329 L .58276 .38115 L F
.58406 .38187 m .58518 .38494 L .5839 .38329 L F
.482 .736 .983 r
.58893 .37895 m .59117 .38078 L .58406 .38187 L F
.712 .834 .94 r
.6244 .36841 m .6276 .36842 L .62429 .37009 L F
.843 .588 .553 r
.37567 .59037 m .37115 .59388 L .37461 .58935 L F
.37567 .59037 m .37556 .59305 L .37115 .59388 L F
.483 .714 .972 r
.37754 .58885 m .37567 .59037 L .37461 .58935 L F
0 0 .367 r
.37727 .59193 m .37567 .59037 L .37754 .58885 L F
.37727 .59193 m .37556 .59305 L .37567 .59037 L F
.78 .8 .869 r
.29588 .62204 m .29318 .62204 L .29695 .61826 L F
.608 .615 .833 r
.29709 .61837 m .29588 .62204 L .29695 .61826 L F
.29709 .61837 m .29861 .62183 L .29588 .62204 L F
0 0 .1 r
.40193 .67715 m .40292 .67302 L .4004 .67356 L F
.40193 .67715 m .40252 .67609 L .40292 .67302 L F
.34279 .53818 m .34107 .54169 L .34176 .53934 L F
.96 .787 .344 r
.7447 .32452 m .74412 .32313 L .74384 .3256 L F
.7447 .32452 m .74412 .32313 L .74384 .3256 L F
.938 .678 .206 r
.6137 .42292 m .61476 .42603 L .61447 .4251 L F
.726 .467 0 r
.61447 .4251 m .61476 .42603 L .6154 .42918 L F
.011 .583 .763 r
.62378 .40045 m .62187 .40039 L .61986 .40014 L F
.88 .931 .851 r
.70234 .28769 m .70619 .28588 L .70561 .28502 L F
.54 .252 .426 r
.42481 .54202 m .42769 .54183 L .42844 .5394 L F
.148 0 .254 r
.42844 .5394 m .42964 .54056 L .42961 .53807 L F
.42844 .5394 m .42769 .54183 L .42964 .54056 L F
.801 .706 .76 r
.52529 .44188 m .52649 .44551 L .5255 .44678 L F
.769 .69 .775 r
.52797 .4436 m .52649 .44551 L .52529 .44188 L F
.696 .607 .753 r
.70705 .33406 m .70611 .33635 L .70419 .33745 L F
.769 .703 .789 r
.63951 .413 m .64104 .41691 L .63849 .41761 L F
.79 .713 .779 r
.6413 .41438 m .64104 .41691 L .63951 .413 L F
.815 .842 .87 r
.64613 .40783 m .64212 .4089 L .64484 .40602 L F
.484 .489 .787 r
.45963 .52227 m .45816 .52601 L .45708 .52299 L F
.45963 .52227 m .46054 .52566 L .45816 .52601 L F
.534 .337 .56 r
.46095 .52859 m .45816 .52601 L .46054 .52566 L F
.46095 .52859 m .45842 .52925 L .45816 .52601 L F
.782 .706 .78 r
.66059 .39811 m .66433 .39886 L .66324 .39689 L F
.666 .793 .942 r
.66433 .39886 m .66571 .39618 L .66324 .39689 L F
.66433 .39886 m .66702 .39795 L .66571 .39618 L F
.786 .517 .53 r
.46234 .46633 m .45779 .46755 L .46016 .46399 L F
.46234 .46633 m .46209 .46871 L .45779 .46755 L F
.59 .58 .81 r
.46296 .46102 m .46234 .46633 L .46016 .46399 L F
.46296 .46102 m .46441 .46481 L .46234 .46633 L F
.469 .238 .48 r
.46234 .46633 m .46434 .46712 L .46209 .46871 L F
.431 .294 .593 r
.46234 .46633 m .46441 .46481 L .46434 .46712 L F
.46234 .46633 m .46441 .46481 L .46434 .46712 L F
.661 .739 .908 r
.39577 .65405 m .39255 .6533 L .39431 .6528 L F
.795 .714 .776 r
.3545 .51281 m .35296 .51435 L .35058 .51259 L F
.812 .854 .88 r
.59684 .38446 m .59522 .38635 L .59342 .38456 L F
.389 .169 .455 r
.406 .50058 m .40858 .50053 L .40825 .50231 L F
.845 .885 .869 r
.7006 .28104 m .69865 .28519 L .69819 .2844 L F
.553 .504 .755 r
.24216 .5583 m .24548 .56148 L .24478 .55803 L F
.964 .695 .475 r
.6071 .43224 m .60884 .43568 L .60884 .43328 L F
.757 .35 .28 r
.31155 .62175 m .31589 .62259 L .314 .6245 L F
.606 .157 .158 r
.314 .6245 m .31589 .62259 L .31795 .62442 L F
.534 .187 .326 r
.31589 .62259 m .31858 .6225 L .31795 .62442 L F
0 0 0 r
.22254 .54772 m .22347 .54701 L .22462 .5451 L F
.22462 .5451 m .22347 .54701 L .22579 .54354 L F
.574 .729 .948 r
.45525 .4682 m .45779 .46755 L .4593 .46969 L F
.615 .749 .941 r
.45779 .46755 m .46209 .46871 L .4593 .46969 L F
.529 0 0 r
.35048 .49772 m .35454 .49889 L .35181 .49852 L F
.434 .872 .807 r
.33012 .54101 m .33466 .53943 L .33129 .54204 L F
.122 .233 .707 r
.71224 .3165 m .71324 .32038 L .71136 .31771 L F
0 0 .103 r
.57406 .4244 m .57308 .42393 L .57456 .42256 L F
.717 .864 .951 r
.40192 .49705 m .39792 .4971 L .40036 .49574 L F
.884 .877 .824 r
.40387 .49414 m .40192 .49705 L .40036 .49574 L F
.961 .625 .287 r
.22183 .57985 m .22318 .58236 L .22336 .58075 L F
.982 .695 .385 r
.22168 .57695 m .22183 .57985 L .22336 .58075 L F
.603 .226 .3 r
.22318 .58236 m .22546 .58279 L .22336 .58075 L F
.535 .341 .564 r
.22336 .58075 m .22591 .58031 L .22598 .57751 L F
.5 .24 .451 r
.22336 .58075 m .22546 .58279 L .22591 .58031 L F
.45 .88 .806 r
.3851 .62543 m .38624 .62533 L .38748 .62433 L F
.899 .916 .824 r
.70656 .31808 m .7032 .31973 L .70276 .31739 L F
.815 .692 .729 r
.62948 .36489 m .63388 .36628 L .6324 .36234 L F
.766 .669 .756 r
.6324 .36234 m .63388 .36628 L .63637 .36302 L F
.282 .662 .97 r
.239 .60939 m .23957 .60833 L .23966 .60985 L F
.287 .666 .972 r
.23957 .60833 m .24154 .60975 L .23966 .60985 L F
.345 .074 .352 r
.24154 .60975 m .23917 .61222 L .23966 .60985 L F
.505 .419 .692 r
.459 .53198 m .45901 .53647 L .45715 .53635 L F
.431 .257 .543 r
.22598 .57751 m .22812 .57954 L .22845 .57701 L F
.22598 .57751 m .22591 .58031 L .22812 .57954 L F
.657 .592 .77 r
.46229 .48418 m .4582 .4806 L .46203 .48161 L F
.694 .612 .76 r
.46477 .48092 m .46229 .48418 L .46203 .48161 L F
.626 .515 .707 r
.46477 .48092 m .46566 .48437 L .46229 .48418 L F
.696 .544 .677 r
.46616 .48717 m .46229 .48418 L .46566 .48437 L F
.46616 .48717 m .46345 .48786 L .46229 .48418 L F
.242 .69 .955 r
.2275 .59577 m .23042 .5965 L .23248 .59624 L F
.291 .221 .603 r
.23042 .5965 m .23241 .59903 L .23248 .59624 L F
.284 .219 .605 r
.23042 .5965 m .23058 .602 L .23241 .59903 L F
0 0 0 r
.21499 .5582 m .21662 .55705 L .21773 .55509 L F
.24 .018 .362 r
.21442 .56026 m .21662 .55705 L .21499 .5582 L F
.256 .039 .381 r
.58718 .41648 m .58511 .41777 L .58766 .41409 L F
.181 0 .263 r
.58718 .41648 m .58511 .41777 L .5846 .41974 L F
.5846 .41974 m .58511 .41777 L .58718 .41648 L F
.334 .816 .813 r
.29615 .51702 m .29886 .5163 L .29809 .51566 L F
.614 .692 .899 r
.29886 .5163 m .29998 .51529 L .29809 .51566 L F
.29886 .5163 m .30239 .51639 L .29998 .51529 L F
.952 .787 .641 r
.64633 .42638 m .6472 .42408 L .64518 .42257 L F
.497 .473 .761 r
.39384 .49921 m .39193 .49699 L .39432 .49574 L F
.526 .544 .817 r
.213 .59629 m .21662 .60186 L .2165 .5996 L F
.645 .763 .934 r
.37701 .58348 m .38075 .58428 L .37944 .58267 L F
.859 .921 .87 r
.38209 .57962 m .38314 .5809 L .3795 .58264 L F
.37948 .58263 m .3795 .58264 L .37944 .58267 L F
.38209 .57962 m .3795 .58264 L .37948 .58263 L F
0 .36 .727 r
.37835 .5821 m .37913 .58244 L .37545 .58076 L F
.37913 .58244 m .37993 .58279 L .37898 .58236 L F
.37913 .58244 m .37898 .58236 L .37545 .58076 L F
.242 0 .33 r
.37948 .58263 m .38057 .5824 L .38209 .57962 L F
.37954 .58265 m .38122 .58226 L .37948 .58263 L F
.381 0 0 r
.38123 .58096 m .38074 .58228 L .38057 .58231 L F
.212 .287 .725 r
.38123 .58096 m .37949 .58263 L .38162 .58015 L F
.37949 .58263 m .37948 .58263 L .38209 .57962 L F
0 .36 .727 r
.37545 .58076 m .37731 .58161 L .37605 .58083 L F
.37731 .58161 m .37955 .58262 L .37788 .58177 L F
.37731 .58161 m .37788 .58177 L .37605 .58083 L F
.242 0 .33 r
.37944 .58267 m .37954 .58265 L .37948 .58263 L F
.212 .287 .725 r
.38123 .58096 m .37993 .58279 L .37944 .58267 L F
.605 .836 .987 r
.37989 .58277 m .37998 .58272 L .38123 .58096 L F
.381 0 0 r
.38123 .58096 m .38057 .58231 L .38009 .58241 L F
0 .36 .727 r
.37955 .58262 m .37958 .58262 L .37605 .58083 L F
.605 .836 .987 r
.37605 .58083 m .37989 .58277 L .38123 .58096 L F
0 .36 .727 r
.37987 .58277 m .37989 .58277 L .37605 .58083 L F
.212 .287 .725 r
.37949 .58263 m .37944 .58267 L .37948 .58263 L F
0 .455 .838 r
.37944 .58267 m .37993 .58279 L .37524 .58074 L F
.381 0 0 r
.37923 .58216 m .38009 .58241 L .3782 .58278 L F
.38123 .58096 m .38009 .58241 L .37923 .58216 L F
.212 .287 .725 r
.38123 .58096 m .38162 .58015 L .38209 .57962 L F
.153 .431 .869 r
.38097 .58331 m .38122 .58226 L .37954 .58265 L F
0 .36 .727 r
.37955 .58262 m .37987 .58277 L .37958 .58262 L F
.605 .836 .987 r
.37989 .58277 m .37993 .58279 L .37998 .58272 L F
.242 0 .33 r
.38057 .5824 m .38122 .58226 L .3813 .58199 L F
.38057 .5824 m .3813 .58199 L .38209 .57962 L F
0 .36 .727 r
.37987 .58277 m .37993 .58279 L .37989 .58277 L F
.37524 .58074 m .37835 .5821 L .37545 .58076 L F
.153 .431 .869 r
.38075 .58428 m .38097 .58331 L .37944 .58267 L F
.38097 .58331 m .37954 .58265 L .37944 .58267 L F
.587 .481 .701 r
.33582 .59628 m .33361 .59947 L .33354 .59676 L F
.827 .681 .701 r
.41537 .48704 m .41973 .48847 L .41895 .48407 L F
.307 .258 .639 r
.41973 .48847 m .42126 .48358 L .41895 .48407 L F
.41973 .48847 m .42216 .48699 L .42126 .48358 L F
.392 .432 .783 r
.41973 .48847 m .42266 .48996 L .42246 .48876 L F
.64 .62 .814 r
.42169 .49373 m .42438 .49416 L .42266 .48996 L F
.78 .689 .764 r
.42266 .48996 m .42438 .49416 L .42692 .49071 L F
.678 .79 .934 r
.42266 .48996 m .42692 .49071 L .42415 .48926 L F
.595 .061 0 r
.42415 .48926 m .42093 .48916 L .42266 .48996 L F
.42339 .48924 m .42353 .49083 L .42093 .48916 L F
.42415 .48926 m .42403 .48957 L .42339 .48924 L F
.42403 .48957 m .42353 .49083 L .42339 .48924 L F
.392 .432 .783 r
.421 .48802 m .42246 .48876 L .42216 .48699 L F
.41973 .48847 m .42246 .48876 L .42072 .48787 L F
0 0 0 r
.42216 .48699 m .42093 .48916 L .42336 .48595 L F
.42216 .48699 m .42336 .48595 L .42366 .48556 L F
.392 .432 .783 r
.42072 .48787 m .421 .48802 L .42216 .48699 L F
.841 .879 .869 r
.64978 .33639 m .64671 .33672 L .64864 .33497 L F
.862 .911 .864 r
.65265 .33334 m .64978 .33639 L .64864 .33497 L F
.801 .706 .76 r
.52529 .44188 m .5255 .44678 L .52269 .44529 L F
.803 .68 .729 r
.5255 .44678 m .52437 .4489 L .52269 .44529 L F
.572 .001 0 r
.36425 .52306 m .36231 .52235 L .35989 .5204 L F
.796 .401 .306 r
.38384 .61274 m .38199 .6149 L .38073 .61134 L F
.457 0 0 r
.38073 .61134 m .38304 .61261 L .38384 .61274 L F
.524 .369 .613 r
.38073 .61134 m .38304 .61261 L .38049 .60986 L F
.99 .884 .559 r
.38304 .61261 m .38199 .6149 L .38384 .61274 L F
.599 .296 .426 r
.38199 .6149 m .38304 .61261 L .38073 .61134 L F
.99 .884 .559 r
.38271 .61255 m .38199 .6149 L .38304 .61261 L F
.599 .296 .426 r
.38199 .6149 m .38354 .61288 L .38304 .61261 L F
.457 0 0 r
.38304 .61261 m .38354 .61288 L .38384 .61274 L F
.524 .369 .613 r
.38304 .61261 m .38354 .61288 L .38308 .61243 L F
.38304 .61261 m .38308 .61243 L .38049 .60986 L F
.99 .884 .559 r
.38315 .61108 m .38271 .61255 L .38304 .61261 L F
.3833 .61144 m .38304 .61261 L .38384 .61274 L F
.38315 .61108 m .38304 .61261 L .3833 .61144 L F
.692 .673 .827 r
.38374 .61575 m .38524 .61915 L .38111 .61841 L F
.865 .592 .062 r
.38384 .61274 m .38354 .61288 L .38315 .61108 L F
.712 .684 .821 r
.38633 .61482 m .38524 .61915 L .38374 .61575 L F
.38633 .61482 m .38794 .61759 L .38524 .61915 L F
.968 .7 .47 r
.38384 .61274 m .38374 .61575 L .38199 .6149 L F
.125 .603 .916 r
.3333 .62924 m .33015 .62849 L .33172 .63255 L F
.906 .984 .756 r
.3333 .62924 m .33172 .63255 L .33126 .63084 L F
.832 .844 .856 r
.63443 .41698 m .63181 .42017 L .63125 .41721 L F
.761 .499 .536 r
.63181 .42017 m .63584 .42348 L .63165 .42283 L F
.863 .486 .332 r
.3411 .6989 m .34099 .69651 L .33745 .69477 L F
.476 .22 .445 r
.26219 .54793 m .2592 .55096 L .25967 .54852 L F
.26219 .54793 m .2592 .55096 L .25967 .54852 L F
.798 .657 .707 r
.52417 .45633 m .52569 .45558 L .52345 .45871 L F
.704 .523 .641 r
.52569 .45558 m .52727 .45853 L .52345 .45871 L F
.768 .389 .338 r
.52569 .45558 m .53001 .45847 L .52727 .45853 L F
.446 .473 .794 r
.46597 .55039 m .46405 .55237 L .46276 .54861 L F
.466 .506 .815 r
.46597 .55039 m .46725 .55411 L .46405 .55237 L F
0 0 0 r
.21914 .55139 m .22091 .55014 L .22254 .54772 L F
.22254 .54772 m .22091 .55014 L .22347 .54701 L F
.774 .611 .677 r
.46504 .46217 m .46844 .4654 L .46441 .46481 L F
.747 .482 .529 r
.46844 .4654 m .46434 .46712 L .46441 .46481 L F
.46844 .4654 m .46885 .469 L .46434 .46712 L F
.414 .197 .472 r
.4711 .4649 m .46885 .469 L .46844 .4654 L F
0 0 0 r
.43662 .54348 m .4358 .54332 L .43793 .54177 L F
.43662 .54348 m .43429 .54447 L .4358 .54332 L F
.772 .853 .911 r
.67753 .38744 m .67898 .38914 L .68087 .38738 L F
.487 .285 .531 r
.32043 .58659 m .32324 .5832 L .3211 .58421 L F
.596 .916 .975 r
.39914 .48446 m .39988 .48251 L .40124 .48259 L F
.39973 .48414 m .40124 .48259 L .40249 .48267 L F
.39914 .48446 m .40124 .48259 L .39973 .48414 L F
.40249 .48267 m .39988 .48251 L .40337 .4822 L F
.713 .917 .964 r
.40337 .4822 m .40185 .48179 L .40349 .48236 L F
.40337 .4822 m .40146 .48237 L .40185 .48179 L F
.003 0 .441 r
.40124 .48259 m .40185 .48179 L .39988 .48251 L F
.713 .917 .964 r
.40146 .48237 m .39988 .48251 L .40185 .48179 L F
.003 0 .441 r
.40114 .48285 m .40251 .48386 L .40189 .48193 L F
.39991 .48436 m .40016 .48431 L .40114 .48285 L F
.40016 .48431 m .40251 .48386 L .40114 .48285 L F
.40124 .48259 m .40189 .48193 L .40185 .48179 L F
.39991 .48436 m .40189 .48193 L .40124 .48259 L F
.39991 .48436 m .40124 .48259 L .39988 .48251 L F
.292 .124 .474 r
.39914 .48446 m .39991 .48436 L .39988 .48251 L F
.39914 .48446 m .39944 .48758 L .39991 .48436 L F
.979 .866 .486 r
.39557 .54669 m .39672 .54565 L .39529 .54411 L F
.39557 .54669 m .39611 .54823 L .39672 .54565 L F
.651 .782 .944 r
.6324 .36234 m .63637 .36302 L .63403 .36119 L F
.835 .795 .813 r
.63403 .36119 m .63637 .36302 L .63878 .3598 L F
0 0 .269 r
.23034 .61258 m .22987 .60893 L .22977 .60906 L F
.23034 .61258 m .2305 .61152 L .22987 .60893 L F
.119 .537 .917 r
.23034 .61258 m .23262 .61328 L .2305 .61152 L F
.935 .805 .345 r
.41433 .58988 m .41423 .58598 L .41548 .58725 L F
.833 .833 .847 r
.6523 .34611 m .65567 .34647 L .65421 .34503 L F
.764 .826 .901 r
.65421 .34503 m .65567 .34647 L .65874 .34365 L F
.91 .704 .611 r
.56838 .39116 m .56998 .39494 L .56787 .39429 L F
.765 .937 .591 r
.56998 .39494 m .56848 .39626 L .56787 .39429 L F
.751 .647 .746 r
.57241 .39166 m .56998 .39494 L .56838 .39116 L F
0 0 .134 r
.21773 .55509 m .21894 .55398 L .21914 .55139 L F
0 0 0 r
.21773 .55509 m .21771 .55589 L .21894 .55398 L F
.21773 .55509 m .21662 .55705 L .21771 .55589 L F
.432 .304 .605 r
.27635 .53549 m .27651 .53872 L .27442 .53933 L F
.328 .052 .334 r
.27651 .53872 m .27391 .54151 L .27442 .53933 L F
.877 .534 .034 r
.41015 .54813 m .40855 .544 L .40921 .54544 L F
0 0 .327 r
.21076 .58358 m .211 .58727 L .21155 .58595 L F
0 0 .472 r
.211 .58727 m .21238 .58816 L .21155 .58595 L F
.211 .58727 m .21151 .58996 L .21238 .58816 L F
.843 .882 .869 r
.2241 .56001 m .22848 .55903 L .22651 .55697 L F
.2241 .56001 m .22471 .56127 L .22848 .55903 L F
.566 .697 .929 r
.22651 .55697 m .22848 .55903 L .23085 .55808 L F
.668 .47 .608 r
.47572 .45916 m .47731 .46205 L .47382 .4621 L F
.598 .444 .643 r
.47996 .4614 m .47572 .45916 L .48003 .45876 L F
.47996 .4614 m .47731 .46205 L .47572 .45916 L F
.792 .879 .91 r
.42433 .47587 m .41933 .47683 L .42268 .47502 L F
.659 .906 .98 r
.42433 .47587 m .42506 .47382 L .42623 .47434 L F
.42433 .47587 m .42268 .47502 L .42506 .47382 L F
.054 .081 .57 r
.60344 .36191 m .60535 .36534 L .60317 .36201 L F
.584 .502 .728 r
.45818 .51373 m .45606 .51614 L .45592 .51445 L F
.45818 .51373 m .45892 .51559 L .45606 .51614 L F
.546 .451 .698 r
.45892 .51559 m .45692 .5198 L .45606 .51614 L F
.265 0 0 r
.41251 .49538 m .414 .49567 L .41553 .49498 L F
.693 .584 .728 r
.41601 .49272 m .414 .49567 L .41333 .49341 L F
.853 .986 .71 r
.41601 .49272 m .41403 .49395 L .414 .49567 L F
.116 .448 .882 r
.41403 .49395 m .4157 .49601 L .414 .49567 L F
.4157 .49601 m .41591 .49626 L .414 .49567 L F
.265 0 0 r
.41125 .49555 m .414 .49567 L .41251 .49538 L F
.216 .435 .859 r
.31705 .59646 m .31855 .5965 L .31801 .59455 L F
.506 .398 .665 r
.31705 .59646 m .31984 .59896 L .31855 .5965 L F
.31705 .59646 m .31756 .59983 L .31984 .59896 L F
.843 .818 .824 r
.62156 .43837 m .62306 .44004 L .62507 .43878 L F
.929 .922 .784 r
.62476 .4356 m .62507 .43878 L .62607 .43674 L F
.647 .881 .984 r
.539 .42602 m .54044 .4274 L .54262 .42619 L F
.539 .42602 m .54044 .4274 L .54262 .42619 L F
.208 .388 .822 r
.36068 .54137 m .35815 .53934 L .36043 .53928 L F
.101 0 .119 r
.36359 .5385 m .36068 .54137 L .36043 .53928 L F
.735 .651 .765 r
.34056 .6005 m .34429 .5999 L .34473 .59624 L F
.468 .055 .173 r
.34056 .6005 m .3433 .60154 L .34429 .5999 L F
0 0 .275 r
.34473 .59624 m .34429 .5999 L .34521 .59837 L F
.605 .793 .366 r
.34429 .5999 m .3433 .60154 L .34521 .59837 L F
.37 .825 .722 r
.57979 .42671 m .57719 .42796 L .57579 .42839 L F
.067 0 0 r
.3481 .56078 m .34992 .55986 L .3516 .55727 L F
.344 .076 .357 r
.35424 .55495 m .3516 .55727 L .35484 .55525 L F
.781 .602 .658 r
.34992 .55986 m .35484 .55525 L .3516 .55727 L F
.713 .491 .587 r
.61459 .3852 m .61714 .38502 L .61613 .3817 L F
.853 .887 .863 r
.61613 .3817 m .61816 .37907 L .61565 .38064 L F
.61613 .3817 m .61876 .37828 L .61816 .37907 L F
.18 .308 .759 r
.32938 .53583 m .32998 .53226 L .32932 .533 L F
.568 .23 .356 r
.33055 .66058 m .33327 .65952 L .33241 .66205 L F
.271 0 0 r
.3331 .66001 m .3348 .66064 L .33241 .66205 L F
.33327 .65952 m .33363 .65978 L .3331 .66001 L F
.33363 .65978 m .3348 .66064 L .3331 .66001 L F
.33574 .66018 m .33679 .65991 L .33327 .65952 L F
.338 0 .018 r
.33457 .65954 m .33327 .65952 L .33394 .6597 L F
.271 0 0 r
.33327 .65952 m .33679 .65991 L .33546 .66025 L F
.521 .891 .97 r
.33385 .65969 m .33457 .65954 L .33394 .6597 L F
.271 0 0 r
.33546 .66025 m .33574 .66018 L .33394 .6597 L F
.33546 .66025 m .33394 .6597 L .33381 .6597 L F
.33546 .66025 m .33381 .6597 L .33457 .65954 L F
.338 0 .018 r
.33394 .6597 m .33327 .65952 L .33363 .65978 L F
.271 0 0 r
.33381 .6597 m .33394 .6597 L .33389 .65968 L F
.33381 .6597 m .33327 .65952 L .33457 .65954 L F
.521 .891 .97 r
.33384 .65969 m .33457 .65954 L .33385 .65969 L F
.33067 .65942 m .33421 .65953 L .33384 .65969 L F
.33421 .65953 m .33457 .65954 L .33384 .65969 L F
.338 0 .018 r
.33363 .65978 m .33327 .65952 L .33055 .66058 L F
.521 .891 .97 r
.33064 .65973 m .33381 .6597 L .33055 .66058 L F
.33381 .6597 m .33394 .6597 L .33363 .65978 L F
.33381 .6597 m .33363 .65978 L .33055 .66058 L F
.271 0 0 r
.33363 .65978 m .33546 .66025 L .3348 .66064 L F
.33327 .65952 m .33381 .6597 L .33363 .65978 L F
.33381 .6597 m .33546 .66025 L .33363 .65978 L F
.521 .891 .97 r
.33067 .65942 m .33394 .6597 L .33064 .65973 L F
.473 .27 .522 r
.34236 .56144 m .34231 .56408 L .33995 .56463 L F
.131 .086 .535 r
.33995 .56463 m .34174 .56631 L .34231 .56408 L F
.33995 .56463 m .34013 .56741 L .34174 .56631 L F
.473 .27 .522 r
.34236 .56144 m .34231 .56408 L .33995 .56463 L F
.131 .086 .535 r
.33995 .56463 m .34174 .56631 L .34231 .56408 L F
.33995 .56463 m .34013 .56741 L .34174 .56631 L F
.565 .1 .109 r
.22751 .60229 m .22306 .60286 L .22496 .6037 L F
.538 .892 .668 r
.42601 .57961 m .42942 .57721 L .42602 .57662 L F
.505 .313 .554 r
.42942 .57721 m .43133 .57696 L .43167 .57425 L F
0 0 .55 r
.42942 .57721 m .43093 .58053 L .43133 .57696 L F
.43009 .57982 m .43067 .58208 L .43093 .58053 L F
.593 .653 .878 r
.43222 .58382 m .43093 .58053 L .43067 .58208 L F
.43222 .58382 m .43145 .58088 L .43093 .58053 L F
.872 .527 .394 r
.43453 .58025 m .43133 .57696 L .43093 .58053 L F
.593 .653 .878 r
.43145 .58088 m .43117 .57978 L .43093 .58053 L F
.43222 .58382 m .43383 .58325 L .43202 .58089 L F
.43222 .58382 m .43202 .58089 L .43145 .58088 L F
.425 0 0 r
.43027 .58166 m .43093 .58053 L .42972 .58188 L F
.43161 .58111 m .43093 .58053 L .43017 .58184 L F
.748 .733 .209 r
.43205 .58088 m .43412 .58029 L .43093 .58053 L F
.425 0 0 r
.43145 .58088 m .43093 .58053 L .43134 .58088 L F
0 0 .55 r
.42942 .57721 m .43009 .57982 L .43093 .58053 L F
.753 .902 .514 r
.42972 .58188 m .43093 .58053 L .43117 .57978 L F
.891 .666 .59 r
.43117 .57978 m .43136 .58123 L .42972 .58188 L F
.43136 .58123 m .43173 .58413 L .42972 .58188 L F
.425 0 0 r
.43017 .58184 m .43027 .58166 L .42972 .58188 L F
.953 .884 .726 r
.43383 .58325 m .43173 .58413 L .43136 .58123 L F
.43383 .58325 m .43136 .58123 L .43145 .58118 L F
.425 0 0 r
.43409 .58151 m .43093 .58053 L .43259 .58164 L F
.953 .884 .726 r
.43202 .58089 m .43134 .58108 L .43202 .58089 L F
.43383 .58325 m .43145 .58118 L .43202 .58089 L F
.425 0 0 r
.43145 .58088 m .43134 .58088 L .43227 .58166 L F
.953 .884 .726 r
.43145 .58118 m .43134 .58108 L .43202 .58089 L F
.425 0 0 r
.43259 .58164 m .43171 .58105 L .43227 .58166 L F
.43171 .58105 m .43145 .58088 L .43166 .58108 L F
.43171 .58105 m .43166 .58108 L .43227 .58166 L F
.43227 .58166 m .43161 .58111 L .43017 .58184 L F
.953 .884 .726 r
.43145 .58118 m .43136 .58123 L .43134 .58108 L F
.593 .653 .878 r
.43145 .58088 m .43202 .58089 L .43202 .58089 L F
.43144 .58084 m .43202 .58089 L .43117 .57978 L F
.43145 .58088 m .43202 .58089 L .43144 .58084 L F
.953 .884 .726 r
.43202 .58089 m .43134 .58108 L .43117 .57978 L F
.748 .733 .209 r
.43211 .5809 m .43453 .58025 L .43412 .58029 L F
.43211 .5809 m .43412 .58029 L .43205 .58088 L F
.43409 .58151 m .43424 .58108 L .43211 .5809 L F
.43424 .58108 m .43453 .58025 L .43211 .5809 L F
.44 .288 .577 r
.38637 .50049 m .38211 .5029 L .38455 .49961 L F
.764 .954 .638 r
.67082 .37214 m .66834 .37489 L .67103 .37155 L F
.381 .237 .558 r
.72068 .32408 m .72093 .32664 L .71872 .32759 L F
.464 .46 .769 r
.72242 .32965 m .71872 .32759 L .72093 .32664 L F
.92 .841 .391 r
.41205 .55824 m .41169 .55679 L .41236 .55385 L F
.829 .622 .072 r
.41225 .56072 m .41169 .55679 L .41205 .55824 L F
0 0 0 r
.22713 .56782 m .22583 .56975 L .22405 .57018 L F
.364 .18 .493 r
.22583 .56975 m .22313 .57257 L .22405 .57018 L F
.691 .546 .685 r
.4608 .47769 m .46203 .48161 L .4582 .4806 L F
.596 .529 .749 r
.46335 .4748 m .4608 .47769 L .46051 .47549 L F
.62 .565 .771 r
.46335 .4748 m .46458 .47834 L .4608 .47769 L F
.629 .544 .74 r
.4608 .47769 m .46477 .48092 L .46203 .48161 L F
.4608 .47769 m .46458 .47834 L .46477 .48092 L F
.23 0 0 r
.26873 .63455 m .27114 .63504 L .2669 .63434 L F
0 0 .566 r
.40681 .53965 m .40805 .54159 L .40635 .53787 L F
.816 .994 .863 r
.36098 .69254 m .35739 .69478 L .35987 .6951 L F
.062 .251 .744 r
.35973 .68931 m .36098 .69254 L .36211 .69144 L F
0 0 0 r
.36211 .69144 m .36098 .69254 L .35987 .6951 L F
.654 .925 .638 r
.36117 .59016 m .36465 .5868 L .36327 .58971 L F
.484 .348 .62 r
.36663 .58203 m .36716 .58668 L .36465 .5868 L F
.741 .574 .666 r
.36716 .58668 m .36327 .58971 L .36465 .5868 L F
.869 .46 .008 r
.60394 .42348 m .60182 .41997 L .60245 .42235 L F
.954 .606 .257 r
.60453 .42688 m .60394 .42348 L .60245 .42235 L F
.119 .034 .475 r
.33641 .61505 m .33651 .61779 L .33459 .61913 L F
0 0 .408 r
.33646 .61815 m .33624 .61827 L .33651 .61779 L F
.33624 .61827 m .33459 .61913 L .33648 .61781 L F
.33624 .61827 m .33648 .61781 L .33651 .61779 L F
.33547 .61985 m .33459 .61913 L .33646 .61815 L F
.33618 .62043 m .33463 .6219 L .33459 .61913 L F
.08 .452 .883 r
.3351 .6205 m .33492 .61809 L .33351 .61849 L F
.33492 .61809 m .33473 .61538 L .33351 .61849 L F
.33351 .61849 m .33372 .61794 L .33302 .61788 L F
.33372 .61794 m .33473 .61538 L .33302 .61788 L F
.33516 .62039 m .33473 .61538 L .3351 .6205 L F
0 0 .333 r
.33756 .61634 m .33651 .61779 L .33641 .61505 L F
.752 .494 .543 r
.33495 .61754 m .33507 .61804 L .33756 .61634 L F
.08 .452 .883 r
.33496 .61808 m .33307 .6184 L .33473 .61538 L F
.33516 .62039 m .33307 .6184 L .33496 .61808 L F
.752 .494 .543 r
.33307 .6184 m .33385 .61826 L .33495 .61754 L F
.33385 .61826 m .33507 .61804 L .33495 .61754 L F
.698 .604 .748 r
.33044 .61815 m .33245 .61919 L .33302 .61788 L F
.33245 .61919 m .33518 .6206 L .33351 .61849 L F
.33245 .61919 m .33351 .61849 L .33302 .61788 L F
.33263 .6177 m .33302 .61788 L .33284 .61766 L F
.33044 .61815 m .33302 .61788 L .33263 .6177 L F
0 0 .408 r
.33618 .62043 m .33547 .61985 L .33646 .61815 L F
.752 .494 .543 r
.33307 .6184 m .33618 .62043 L .33631 .61939 L F
.33401 .61833 m .33631 .61939 L .33646 .61815 L F
.33307 .6184 m .33631 .61939 L .33401 .61833 L F
.33507 .61804 m .33646 .61815 L .33651 .61779 L F
.33307 .6184 m .33646 .61815 L .33507 .61804 L F
.08 .452 .883 r
.33302 .61788 m .33473 .61538 L .33284 .61766 L F
.752 .494 .543 r
.33507 .61804 m .33651 .61779 L .33665 .61759 L F
.33507 .61804 m .33665 .61759 L .33756 .61634 L F
.08 .452 .883 r
.33518 .6206 m .33516 .62039 L .3351 .6205 L F
.33518 .6206 m .3351 .62052 L .33516 .62039 L F
.3351 .62052 m .33307 .6184 L .33516 .62039 L F
.382 .845 .862 r
.57256 .46909 m .57591 .46826 L .57531 .46814 L F
.695 .982 .829 r
.57531 .46814 m .57591 .46826 L .57709 .46661 L F
.525 .752 .979 r
.57591 .46826 m .57869 .46809 L .57709 .46661 L F
.397 0 0 r
.27114 .63504 m .27461 .63591 L .27377 .63624 L F
.491 0 0 r
.27461 .63591 m .2773 .6374 L .27377 .63624 L F
0 0 .175 r
.39667 .67607 m .39618 .67862 L .39472 .68008 L F
.55 .565 .822 r
.39618 .67862 m .39523 .6829 L .39472 .68008 L F
.939 .829 .709 r
.42734 .56034 m .42924 .561 L .43049 .5579 L F
.944 .77 .306 r
.41475 .58053 m .41378 .58164 L .4147 .57913 L F
.41475 .58053 m .41443 .58316 L .41378 .58164 L F
.671 .366 .449 r
.34236 .56144 m .34552 .56405 L .34231 .56408 L F
.34236 .56144 m .34601 .56148 L .34552 .56405 L F
.539 .919 .927 r
.67821 .3636 m .67566 .36533 L .67578 .3647 L F
.67821 .3636 m .68002 .36378 L .67566 .36533 L F
.33 .01 .263 r
.30284 .64773 m .30452 .64586 L .30653 .64497 L F
.744 .616 .715 r
.37711 .70759 m .37834 .70929 L .37718 .70549 L F
.556 .618 .869 r
.37651 .70999 m .37834 .70929 L .37711 .70759 L F
.37651 .70999 m .37858 .7119 L .37834 .70929 L F
.631 .761 .941 r
.37834 .70929 m .37903 .70694 L .37718 .70549 L F
.37834 .70929 m .38124 .70882 L .37903 .70694 L F
.636 .5 .679 r
.37834 .70929 m .37858 .7119 L .38124 .70882 L F
.976 .844 .646 r
.39931 .59925 m .40195 .59616 L .40067 .59518 L F
.39931 .59925 m .40086 .59999 L .40195 .59616 L F
.71 .76 .892 r
.71133 .34261 m .71258 .34608 L .7151 .34339 L F
.795 .892 .913 r
.66348 .33894 m .66787 .33787 L .66682 .33683 L F
.811 .954 .91 r
.66872 .33506 m .66787 .33787 L .6693 .33608 L F
.801 .944 .918 r
.66682 .33683 m .66787 .33787 L .66872 .33506 L F
.598 .265 .377 r
.42959 .53354 m .43289 .53469 L .4297 .53484 L F
.543 .881 .988 r
.72122 .33974 m .72402 .33891 L .72285 .33807 L F
.72122 .33974 m .7218 .33915 L .72071 .34051 L F
.7218 .33915 m .72285 .33807 L .72129 .33985 L F
.7218 .33915 m .72129 .33985 L .72071 .34051 L F
.69 .945 .664 r
.72095 .34007 m .72071 .34051 L .72285 .33807 L F
.673 .517 .665 r
.72095 .34007 m .72215 .34181 L .72225 .34128 L F
.975 .688 .297 r
.72392 .3417 m .72354 .34246 L .7224 .34141 L F
.72392 .3417 m .7224 .34141 L .72216 .34078 L F
.72354 .34246 m .72352 .34248 L .72331 .34228 L F
.72354 .34246 m .72331 .34228 L .72115 .34026 L F
.364 .135 .428 r
.72248 .34163 m .72215 .34181 L .72311 .34328 L F
.585 .588 .822 r
.72206 .3413 m .72215 .34181 L .72248 .34163 L F
.975 .688 .297 r
.72352 .34248 m .72311 .34328 L .72115 .34026 L F
.72392 .3417 m .72103 .3402 L .72108 .34014 L F
.779 .69 .766 r
.72285 .33807 m .72392 .3417 L .72095 .34007 L F
.303 .792 .752 r
.72402 .33891 m .72725 .33778 L .72505 .33839 L F
.599 .223 .301 r
.72285 .33807 m .72574 .33992 L .72392 .3417 L F
.364 .135 .428 r
.72574 .33992 m .72248 .34163 L .72311 .34328 L F
.975 .688 .297 r
.72216 .34078 m .7224 .34141 L .72115 .34026 L F
.72108 .34014 m .72103 .3402 L .72095 .34007 L F
.673 .517 .665 r
.72095 .34007 m .72225 .34128 L .72285 .33807 L F
.012 .569 .816 r
.72285 .33807 m .7214 .33765 L .71908 .33734 L F
.771 .676 .758 r
.71908 .33734 m .72095 .34007 L .72285 .33807 L F
.585 .588 .822 r
.7214 .33765 m .72206 .3413 L .72574 .33992 L F
.72206 .3413 m .72248 .34163 L .72574 .33992 L F
.615 .173 0 r
.72311 .34328 m .72215 .34181 L .72095 .34007 L F
.975 .688 .297 r
.72115 .34026 m .72311 .34328 L .72103 .3402 L F
.455 .642 .938 r
.40817 .48942 m .4097 .49331 L .40756 .49158 L F
.762 .946 .939 r
.40756 .49158 m .40817 .48942 L .4097 .49331 L F
.721 .806 .917 r
.40817 .48942 m .4097 .49331 L .412 .48964 L F
.412 .48964 m .4097 .49331 L .40817 .48942 L F
.651 .774 .939 r
.57202 .38979 m .57241 .39166 L .56838 .39116 L F
.194 .42 .852 r
.57343 .39 m .57241 .39166 L .57202 .38979 L F
.387 .675 .973 r
.57479 .39163 m .57241 .39166 L .57343 .39 L F
.232 .315 .744 r
.32937 .50608 m .3291 .50811 L .32714 .50684 L F
.32937 .50608 m .33095 .51013 L .3291 .50811 L F
.612 .951 .919 r
.25382 .52265 m .2546 .52124 L .25638 .52124 L F
.624 .958 .9 r
.25382 .52265 m .25251 .52259 L .2546 .52124 L F
.319 .644 .967 r
.31471 .63126 m .31453 .63191 L .31716 .63191 L F
.42 .457 .793 r
.31453 .63191 m .31723 .63345 L .31716 .63191 L F
.122 .672 .753 r
.31544 .53443 m .31797 .53413 L .31966 .53407 L F
.218 .741 .793 r
.31966 .53407 m .32189 .53346 L .32188 .53386 L F
.31966 .53407 m .31797 .53413 L .32189 .53346 L F
.636 .381 .516 r
.31797 .53413 m .32079 .53566 L .32189 .53346 L F
0 .051 .618 r
.32189 .53346 m .32057 .53105 L .32314 .5305 L F
.32057 .53105 m .32024 .53044 L .32314 .5305 L F
.32189 .53346 m .32314 .5305 L .32461 .53306 L F
.565 .642 .885 r
.32717 .53192 m .32461 .53306 L .32356 .53122 L F
.32418 .53087 m .32356 .53122 L .32314 .5305 L F
.32717 .53192 m .32356 .53122 L .32418 .53087 L F
.32717 .53192 m .32314 .5305 L .32603 .52946 L F
0 0 0 r
.32202 .53285 m .32449 .53164 L .32562 .53005 L F
.32477 .53053 m .32562 .53005 L .32603 .52946 L F
.32202 .53285 m .32562 .53005 L .32477 .53053 L F
.32202 .53285 m .32536 .53003 L .32314 .5305 L F
.32536 .53003 m .32603 .52946 L .32314 .5305 L F
0 .051 .618 r
.32155 .53283 m .32202 .53285 L .32024 .53044 L F
.32189 .53346 m .32202 .53285 L .32155 .53283 L F
.746 .849 .407 r
.32189 .53346 m .32079 .53566 L .3219 .53313 L F
.32189 .53346 m .3219 .53313 L .32202 .53285 L F
.951 .801 .658 r
.32079 .53566 m .32231 .5373 L .32189 .53346 L F
.931 .764 .288 r
.31797 .53413 m .3187 .53463 L .32079 .53566 L F
.254 0 0 r
.3187 .53463 m .32202 .53285 L .32079 .53566 L F
.73 .845 .935 r
.32052 .53466 m .32284 .53289 L .32202 .53285 L F
.32284 .53289 m .32449 .53164 L .32202 .53285 L F
.218 .741 .793 r
.32188 .53386 m .32189 .53346 L .32222 .53383 L F
.546 .451 .698 r
.45892 .51559 m .45933 .51929 L .45692 .5198 L F
.521 .353 .594 r
.45933 .51929 m .45708 .52299 L .45692 .5198 L F
.819 .741 .218 r
.34552 .56405 m .34601 .56148 L .34597 .55925 L F
.225 0 0 r
.27266 .56708 m .27505 .56651 L .27659 .5647 L F
.103 0 0 r
.27659 .5647 m .27744 .56557 L .27914 .56409 L F
.27659 .5647 m .27505 .56651 L .27744 .56557 L F
.762 .758 .849 r
.70291 .29423 m .70488 .29537 L .70245 .29017 L F
0 0 0 r
.33987 .53284 m .33801 .53383 L .34182 .53188 L F
.33987 .53284 m .33801 .53383 L .34182 .53188 L F
.487 .488 .783 r
.35863 .60883 m .35692 .60999 L .35607 .60749 L F
.032 0 .092 r
.35863 .60883 m .35596 .61194 L .35692 .60999 L F
.158 .385 .833 r
.45136 .55768 m .45407 .56156 L .45477 .56099 L F
.973 .88 .68 r
.59682 .37623 m .59538 .37625 L .59754 .37473 L F
0 0 0 r
.59748 .37483 m .59754 .37473 L .59538 .37625 L F
.59969 .37332 m .59754 .37473 L .59748 .37483 L F
.648 .797 .351 r
.59865 .37275 m .59778 .3744 L .59754 .37473 L F
.59778 .3744 m .59682 .37623 L .59754 .37473 L F
.805 .999 .804 r
.60136 .36984 m .59865 .37275 L .59925 .37076 L F
.744 .828 .368 r
.59925 .37076 m .59865 .37275 L .59754 .37473 L F
.434 .872 .807 r
.33012 .54101 m .3312 .54033 L .33466 .53943 L F
.879 .822 .788 r
.33664 .53539 m .33466 .53943 L .33243 .53829 L F
.251 .085 .452 r
.38561 .67337 m .3841 .67285 L .38582 .67005 L F
.243 0 0 r
.38561 .67337 m .3841 .67285 L .38177 .67217 L F
.233 .519 .913 r
.36539 .71225 m .36949 .71531 L .36832 .71186 L F
.749 .715 .82 r
.36949 .71531 m .37081 .7111 L .36832 .71186 L F
.36949 .71531 m .37175 .71386 L .37081 .7111 L F
.415 .262 .564 r
.23357 .55151 m .23569 .55102 L .23575 .54794 L F
.417 .127 .362 r
.41333 .49341 m .41062 .49426 L .41157 .49199 L F
.077 .344 .818 r
.43197 .57221 m .43167 .57425 L .4296 .57073 L F
.654 .152 .042 r
.43107 .57418 m .43018 .57566 L .42755 .5738 L F
.03 0 0 r
.43008 .57625 m .43018 .57566 L .4288 .57783 L F
0 0 0 r
.4288 .57783 m .42957 .57663 L .42945 .57685 L F
0 0 .036 r
.42615 .57713 m .42601 .57961 L .42602 .57662 L F
.873 .797 .772 r
.42349 .57582 m .42602 .57662 L .42755 .5738 L F
0 0 .036 r
.42598 .57708 m .42602 .57662 L .42349 .57582 L F
.42616 .57715 m .42602 .57662 L .42598 .57708 L F
.42616 .57715 m .42616 .5773 L .42615 .57713 L F
.42616 .57727 m .42616 .5773 L .42616 .57715 L F
.615 .198 .227 r
.42616 .57742 m .42612 .57743 L .42614 .57526 L F
.42612 .57743 m .42552 .57761 L .42579 .5766 L F
.42612 .57743 m .42579 .5766 L .42614 .57526 L F
0 0 .036 r
.42617 .57718 m .42616 .57715 L .42598 .57708 L F
.615 .198 .227 r
.42614 .57526 m .42569 .57697 L .42516 .57501 L F
.23 .197 .613 r
.42617 .57718 m .42598 .57708 L .42516 .57501 L F
.42598 .57708 m .42349 .57582 L .42516 .57501 L F
.615 .198 .227 r
.42569 .57697 m .42552 .57761 L .42542 .57686 L F
.42569 .57697 m .42542 .57686 L .42516 .57501 L F
0 0 0 r
.42957 .57663 m .43018 .57566 L .42977 .57635 L F
.615 .198 .227 r
.43008 .57625 m .42616 .57742 L .42614 .57526 L F
0 0 .036 r
.42617 .57718 m .42616 .57727 L .42616 .57715 L F
.42616 .5773 m .42601 .57961 L .42615 .57713 L F
.615 .198 .227 r
.42979 .57634 m .4288 .57783 L .42617 .57765 L F
.05 0 0 r
.42593 .57764 m .42459 .57991 L .42552 .57761 L F
.689 .163 0 r
.4254 .57858 m .42558 .57888 L .42616 .5773 L F
.42558 .57888 m .42601 .57961 L .42609 .57832 L F
.42558 .57888 m .42609 .57832 L .42616 .5773 L F
.42465 .57991 m .42601 .57961 L .4254 .57858 L F
.42464 .57993 m .42465 .57993 L .42465 .57991 L F
.42465 .57993 m .42601 .57961 L .42465 .57991 L F
.05 0 0 r
.4288 .57783 m .42708 .57918 L .42551 .57964 L F
.42799 .57823 m .42551 .57964 L .42466 .57989 L F
.4288 .57783 m .42551 .57964 L .42799 .57823 L F
.996 .852 .512 r
.42454 .57622 m .42552 .57761 L .42427 .57656 L F
.23 .197 .613 r
.42617 .57718 m .42516 .57501 L .42552 .57761 L F
.996 .852 .512 r
.42454 .57622 m .42454 .5764 L .42552 .57761 L F
.444 .787 .998 r
.42427 .57656 m .42552 .57761 L .42474 .57665 L F
.996 .852 .512 r
.42454 .5764 m .42459 .57991 L .42552 .57761 L F
.444 .787 .998 r
.42474 .57665 m .42552 .57761 L .42586 .57684 L F
.42468 .57643 m .42586 .57684 L .42628 .57589 L F
.42427 .57656 m .42586 .57684 L .42468 .57643 L F
.44 .556 .876 r
.42454 .57622 m .42427 .57656 L .42628 .57589 L F
.248 .263 .68 r
.42182 .58174 m .42447 .57636 L .42126 .5818 L F
.42447 .57636 m .42454 .57622 L .42446 .57635 L F
.42447 .57636 m .42446 .57635 L .42126 .5818 L F
.772 .792 .299 r
.42493 .58364 m .42601 .57961 L .42608 .5829 L F
.211 .112 .518 r
.42753 .5816 m .42608 .5829 L .42601 .57961 L F
.689 .163 0 r
.42463 .57993 m .42753 .5816 L .42601 .57961 L F
0 0 .095 r
.42525 .58467 m .42493 .58364 L .42608 .5829 L F
0 0 0 r
.42753 .5816 m .42525 .58467 L .42608 .5829 L F
.413 .599 .922 r
.42468 .57999 m .4247 .58011 L .42753 .5816 L F
.4247 .58011 m .42525 .58467 L .42644 .58307 L F
.4247 .58011 m .42644 .58307 L .42753 .5816 L F
.887 .527 .359 r
.42467 .58005 m .4246 .57994 L .42459 .57991 L F
.413 .599 .922 r
.4246 .57994 m .42463 .58018 L .42468 .57999 L F
.887 .527 .359 r
.42471 .58013 m .4246 .57994 L .42467 .58005 L F
.413 .599 .922 r
.42471 .58013 m .42951 .58411 L .42717 .58442 L F
.42477 .58008 m .42951 .58411 L .42471 .58013 L F
.248 .263 .68 r
.42538 .58132 m .42472 .58012 L .42485 .58024 L F
.42472 .58012 m .42467 .58003 L .42474 .5801 L F
.887 .527 .359 r
.42538 .58132 m .42708 .58204 L .42477 .58008 L F
.248 .263 .68 r
.42467 .58003 m .42468 .57999 L .42527 .58065 L F
.413 .599 .922 r
.4246 .57994 m .42477 .58008 L .42471 .58013 L F
.42463 .58018 m .42525 .58467 L .42468 .57999 L F
.4246 .57994 m .42717 .58442 L .42525 .58467 L F
.887 .527 .359 r
.42538 .58132 m .4246 .57994 L .42471 .58013 L F
.248 .263 .68 r
.42538 .58132 m .42459 .57991 L .42459 .57988 L F
.887 .527 .359 r
.42538 .58132 m .42477 .58008 L .4246 .57994 L F
.248 .263 .68 r
.42538 .58132 m .42485 .58024 L .42527 .58065 L F
.42472 .58012 m .42474 .5801 L .42527 .58065 L F
.689 .163 0 r
.42468 .57999 m .42753 .5816 L .42463 .57993 L F
.248 .263 .68 r
.42538 .58132 m .42514 .57985 L .42375 .58064 L F
.42538 .58132 m .42375 .58064 L .42182 .58174 L F
.887 .527 .359 r
.42538 .58132 m .42951 .58411 L .42708 .58204 L F
.248 .263 .68 r
.42467 .58003 m .42459 .57988 L .42468 .57999 L F
.689 .163 0 r
.4246 .57994 m .42468 .57999 L .42463 .57993 L F
.05 0 0 r
.4288 .57783 m .42468 .57987 L .42593 .57764 L F
.42468 .57987 m .42459 .57991 L .42593 .57764 L F
.248 .263 .68 r
.42497 .57885 m .42459 .57988 L .42454 .57622 L F
.689 .163 0 r
.42467 .57982 m .42464 .57993 L .4254 .57858 L F
.4246 .57994 m .42616 .5773 L .42574 .57792 L F
.248 .263 .68 r
.4246 .5799 m .42459 .57988 L .42508 .57954 L F
.05 0 0 r
.42468 .57987 m .42466 .57989 L .42459 .57991 L F
.615 .198 .227 r
.42606 .57745 m .42593 .57764 L .42552 .57761 L F
0 0 0 r
.42552 .57761 m .42464 .57984 L .42617 .57718 L F
.535 .846 .999 r
.42459 .57991 m .42466 .57989 L .42466 .57984 L F
0 0 0 r
.42464 .57984 m .4246 .57994 L .42466 .57984 L F
.42464 .57984 m .42466 .57984 L .42617 .57718 L F
.248 .263 .68 r
.42467 .57982 m .42459 .57988 L .42497 .57885 L F
.535 .846 .999 r
.42464 .57984 m .42466 .57984 L .42466 .57981 L F
.42459 .57991 m .42466 .57984 L .42464 .57984 L F
0 0 0 r
.42465 .5798 m .42459 .57991 L .42464 .57984 L F
.42552 .57761 m .42459 .57991 L .42465 .5798 L F
.535 .846 .999 r
.42459 .57991 m .42466 .57981 L .42466 .57972 L F
.689 .163 0 r
.42463 .57993 m .42464 .57993 L .42467 .57982 L F
.05 0 0 r
.4288 .57783 m .42466 .57989 L .42468 .57987 L F
.248 .263 .68 r
.42527 .58065 m .4246 .5799 L .42508 .57954 L F
0 0 0 r
.42464 .57984 m .42459 .57991 L .4246 .57994 L F
.248 .263 .68 r
.42508 .57954 m .42467 .57982 L .4247 .57973 L F
.42503 .5792 m .4247 .57973 L .42497 .57885 L F
.42508 .57954 m .4247 .57973 L .42503 .5792 L F
.689 .163 0 r
.4246 .57994 m .42463 .57993 L .42467 .57982 L F
.248 .263 .68 r
.42514 .57985 m .42508 .57954 L .42182 .58174 L F
.659 .754 .268 r
.42552 .57761 m .42459 .57991 L .42477 .57946 L F
.42542 .57784 m .42477 .57946 L .42528 .57818 L F
.42552 .57761 m .42477 .57946 L .42542 .57784 L F
.248 .263 .68 r
.42477 .57946 m .42454 .57622 L .42313 .57908 L F
.42508 .57954 m .42498 .57892 L .42477 .57946 L F
.42498 .57892 m .42454 .57622 L .42477 .57946 L F
.535 .846 .999 r
.42466 .57972 m .42492 .57966 L .42496 .57951 L F
.42466 .57972 m .42496 .57951 L .42477 .57946 L F
.248 .263 .68 r
.42508 .57954 m .42313 .57908 L .42182 .58174 L F
.535 .846 .999 r
.42477 .57946 m .42496 .57951 L .42528 .57818 L F
.42492 .57966 m .42708 .57918 L .4262 .57869 L F
.42492 .57966 m .4262 .57869 L .42528 .57818 L F
.42466 .57989 m .42708 .57918 L .42466 .57972 L F
.689 .163 0 r
.42574 .57792 m .42616 .5773 L .42617 .57718 L F
.615 .198 .227 r
.42616 .57742 m .42617 .57765 L .42593 .57764 L F
.42616 .57742 m .42593 .57764 L .42606 .57745 L F
.42979 .57634 m .42617 .57765 L .42616 .57742 L F
.43008 .57625 m .4288 .57783 L .42979 .57634 L F
0 0 0 r
.4288 .57783 m .42945 .57685 L .42923 .57726 L F
.42957 .57663 m .42977 .57635 L .42923 .57726 L F
.644 .107 0 r
.42755 .5738 m .43018 .57566 L .43008 .57625 L F
.42755 .5738 m .42994 .57611 L .42873 .57197 L F
.42994 .57611 m .43001 .57603 L .42873 .57197 L F
.754 .592 .676 r
.42873 .57197 m .43001 .57603 L .42851 .57571 L F
.873 .797 .772 r
.42349 .57582 m .42755 .5738 L .42527 .57415 L F
.754 .592 .676 r
.42553 .57469 m .42851 .57571 L .42516 .57501 L F
.492 .504 .797 r
.42527 .57415 m .42755 .5738 L .42628 .56983 L F
.106 .241 .721 r
.42628 .56983 m .42755 .5738 L .42873 .57197 L F
.754 .592 .676 r
.42873 .57197 m .42851 .57571 L .42553 .57469 L F
.644 .107 0 r
.42994 .57611 m .43008 .57625 L .43001 .57603 L F
.754 .592 .676 r
.43001 .57603 m .43008 .57625 L .42988 .5762 L F
.43001 .57603 m .42988 .5762 L .42516 .57501 L F
.654 .152 .042 r
.43167 .57425 m .43018 .57566 L .43107 .57418 L F
.841 .934 .559 r
.43197 .57221 m .43018 .57566 L .43167 .57425 L F
0 0 0 r
.43081 .57515 m .43018 .57566 L .43162 .57407 L F
.9 .709 .636 r
.42753 .57615 m .43001 .57625 L .42835 .57812 L F
0 0 0 r
.4288 .57783 m .43162 .57407 L .43065 .57627 L F
.9 .709 .636 r
.43001 .57625 m .43065 .57627 L .42912 .5775 L F
.43001 .57625 m .42912 .5775 L .42835 .57812 L F
0 0 0 r
.42942 .57831 m .4288 .57783 L .43065 .57627 L F
.42996 .57643 m .43065 .57627 L .43001 .57625 L F
.945 .908 .752 r
.42835 .57812 m .43065 .57627 L .42966 .57649 L F
0 0 0 r
.42923 .57726 m .42988 .57617 L .43042 .57558 L F
.42923 .57726 m .43042 .57558 L .43016 .57601 L F
.042 .226 .727 r
.42753 .57615 m .42835 .57812 L .42825 .5769 L F
0 0 0 r
.42825 .5769 m .43001 .57625 L .42753 .57615 L F
.939 .931 .767 r
.42825 .5769 m .42835 .57812 L .42896 .57672 L F
0 0 0 r
.42829 .57693 m .42858 .57682 L .42825 .5769 L F
.42858 .57682 m .43001 .57625 L .42825 .5769 L F
.939 .931 .767 r
.42808 .5746 m .42825 .5769 L .43036 .5735 L F
.42825 .5769 m .42896 .57672 L .43036 .5735 L F
.042 .226 .727 r
.42753 .57615 m .42825 .5769 L .42808 .5746 L F
0 0 0 r
.42823 .57696 m .42829 .57693 L .42753 .57615 L F
.945 .908 .752 r
.42835 .57812 m .42966 .57649 L .42896 .57672 L F
0 0 0 r
.42902 .57786 m .42991 .57641 L .42823 .57696 L F
.42991 .57641 m .43001 .57625 L .42823 .57696 L F
.43162 .57407 m .43018 .57566 L .43197 .57221 L F
.945 .908 .752 r
.42896 .57672 m .43162 .57407 L .43036 .5735 L F
0 0 0 r
.42988 .57617 m .43018 .57566 L .43081 .57515 L F
.945 .908 .752 r
.42966 .57649 m .43162 .57407 L .42896 .57672 L F
0 0 0 r
.43016 .57601 m .43042 .57558 L .43072 .57525 L F
.43042 .57567 m .43072 .57525 L .43081 .57515 L F
.42923 .57726 m .43072 .57525 L .43042 .57567 L F
.945 .908 .752 r
.42966 .57649 m .43065 .57627 L .43162 .57407 L F
0 0 0 r
.42942 .57831 m .43065 .57627 L .42996 .57643 L F
.42942 .57831 m .43001 .57625 L .42902 .57786 L F
.689 .943 .66 r
.23324 .58394 m .23212 .58556 L .23402 .58415 L F
.933 .886 .764 r
.42526 .59634 m .42943 .59243 L .42811 .59261 L F
.42526 .59634 m .42667 .59752 L .42943 .59243 L F
.551 .931 .841 r
.43187 .59099 m .42943 .59243 L .42811 .59261 L F
0 .15 .643 r
.42943 .59243 m .43182 .59436 L .43037 .59284 L F
.165 .368 .818 r
.42943 .59243 m .43232 .59603 L .43182 .59436 L F
0 .15 .643 r
.42943 .59243 m .43037 .59284 L .42811 .59261 L F
.645 .149 0 r
.58537 .38675 m .58768 .38919 L .58878 .39065 L F
.513 .652 .921 r
.31723 .63345 m .31842 .63533 L .31967 .63315 L F
.355 .449 .819 r
.31967 .63315 m .31842 .63533 L .3218 .63519 L F
.721 .317 .281 r
.35395 .64747 m .35805 .64791 L .35646 .6501 L F
.121 0 0 r
.35636 .64774 m .35805 .64791 L .35395 .64747 L F
.546 .867 .995 r
.35777 .64636 m .35805 .64791 L .35636 .64774 L F
.901 .922 .535 r
.35646 .6501 m .35805 .64791 L .35777 .64636 L F
.113 0 .081 r
.3316 .58952 m .33059 .5921 L .33341 .5895 L F
.726 .785 .9 r
.25114 .52898 m .25554 .52969 L .25375 .52802 L F
.602 .752 .949 r
.25375 .52802 m .25554 .52969 L .25775 .52876 L F
.799 .389 .272 r
.23479 .59595 m .23566 .59471 L .23299 .59326 L F
.734 .303 .228 r
.23479 .59595 m .23818 .59677 L .23566 .59471 L F
.125 0 .039 r
.34449 .52981 m .34182 .53188 L .34273 .53044 L F
.712 .292 .247 r
.31967 .63315 m .32159 .63169 L .31905 .6309 L F
.31967 .63315 m .32355 .63407 L .32159 .63169 L F
.983 .865 .494 r
.40041 .55423 m .39971 .55676 L .40062 .55738 L F
.959 .857 .444 r
.39971 .55676 m .39976 .56058 L .40062 .55738 L F
.703 .564 .695 r
.37119 .59976 m .37397 .60235 L .37403 .59844 L F
.37119 .59976 m .37196 .6036 L .37397 .60235 L F
.746 .651 .756 r
.35154 .57597 m .34889 .58067 L .35324 .58041 L F
.062 0 0 r
.34878 .58252 m .35324 .58041 L .34889 .58067 L F
.489 .344 .61 r
.35045 .58218 m .35349 .58422 L .35268 .58201 L F
.062 0 0 r
.34931 .58227 m .35045 .58218 L .35324 .58041 L F
.62 .933 .701 r
.35324 .58041 m .35045 .58218 L .3541 .57901 L F
.562 .893 .64 r
.3541 .57901 m .35045 .58218 L .3521 .58045 L F
.489 .344 .61 r
.35045 .58218 m .35268 .58201 L .3521 .58045 L F
.062 0 0 r
.34878 .58252 m .35045 .58218 L .34931 .58227 L F
.606 .453 .648 r
.35573 .57729 m .35324 .58041 L .3554 .5796 L F
.3554 .5796 m .35324 .58041 L .35573 .57729 L F
.62 .933 .701 r
.35324 .58041 m .3541 .57901 L .3554 .5796 L F
.532 .551 .82 r
.35719 .58376 m .35324 .58041 L .3554 .5796 L F
0 0 0 r
.36596 .68524 m .36248 .68868 L .36388 .68813 L F
.36694 .68453 m .36596 .68524 L .36388 .68813 L F
.245 .062 .423 r
.22808 .56591 m .22583 .56975 L .22713 .56782 L F
.708 .923 .588 r
.51293 .45567 m .51144 .45694 L .51147 .45443 L F
.635 .509 .692 r
.51567 .45514 m .51335 .45832 L .51293 .45567 L F
0 0 0 r
.35248 .56409 m .34992 .56761 L .35015 .56474 L F
.867 .864 .834 r
.65265 .33334 m .6497 .33331 L .65121 .33184 L F
.862 .911 .864 r
.65265 .33334 m .64864 .33497 L .6497 .33331 L F
.815 .862 .883 r
.65563 .33052 m .65265 .33334 L .65121 .33184 L F
.256 0 .169 r
.32823 .68596 m .32624 .68866 L .327 .6879 L F
0 0 0 r
.33045 .68497 m .33249 .68369 L .32823 .68596 L F
.33045 .68497 m .32823 .68596 L .327 .6879 L F
0 .279 .777 r
.33199 .49418 m .33085 .49453 L .32915 .49405 L F
.395 0 0 r
.33362 .49562 m .33085 .49453 L .33327 .49602 L F
0 .279 .777 r
.33199 .49418 m .33327 .49602 L .33085 .49453 L F
.081 0 0 r
.41777 .60037 m .41883 .60107 L .4161 .59901 L F
.41777 .60037 m .42042 .59948 L .41883 .60107 L F
.701 .276 .234 r
.35866 .686 m .35622 .6837 L .35644 .68622 L F
.323 .44 .825 r
.35644 .68622 m .35973 .68931 L .35866 .686 L F
.591 .518 .741 r
.45716 .50933 m .45592 .51445 L .45456 .51002 L F
.45716 .50933 m .45818 .51373 L .45592 .51445 L F
0 0 .224 r
.43145 .5685 m .43002 .56761 L .43187 .56472 L F
.43145 .5685 m .4296 .57073 L .43002 .56761 L F
.733 .222 0 r
.60871 .40846 m .60829 .40891 L .60733 .40716 L F
.60871 .40846 m .60996 .40998 L .60829 .40891 L F
.408 .422 .763 r
.3258 .50057 m .32848 .50192 L .32769 .50005 L F
.785 .704 .775 r
.53129 .4169 m .53467 .4169 L .53357 .41364 L F
0 0 0 r
.53467 .4169 m .53072 .41942 L .53362 .41966 L F
.508 .061 .124 r
.53741 .41838 m .53467 .4169 L .53362 .41966 L F
.53741 .41838 m .53746 .41718 L .53467 .4169 L F
.765 .554 .612 r
.37259 .53217 m .36809 .52885 L .37218 .52937 L F
.884 .877 .824 r
.40387 .49414 m .40036 .49574 L .40271 .49423 L F
.956 .94 .624 r
.40387 .49414 m .40271 .49423 L .40276 .49407 L F
.812 .52 .495 r
.40308 .49063 m .40366 .4928 L .39883 .49235 L F
.40366 .4928 m .40354 .49296 L .39883 .49235 L F
.956 .94 .624 r
.40387 .49414 m .40281 .49407 L .4035 .49303 L F
.662 .69 .866 r
.40271 .49423 m .39883 .49235 L .4032 .49344 L F
.956 .94 .624 r
.40281 .49407 m .40276 .49407 L .4032 .49344 L F
.40281 .49407 m .4032 .49344 L .4035 .49303 L F
.662 .69 .866 r
.40271 .49423 m .4032 .49344 L .40388 .49361 L F
.812 .52 .495 r
.40371 .49299 m .40388 .49361 L .4024 .49324 L F
.40371 .49299 m .4024 .49324 L .39883 .49235 L F
.956 .94 .624 r
.4035 .49303 m .40276 .49407 L .4033 .49245 L F
.812 .52 .495 r
.40366 .4928 m .40371 .49299 L .40354 .49296 L F
.762 .946 .939 r
.40371 .49299 m .40387 .49414 L .4035 .49303 L F
.873 .535 .03 r
.4033 .49245 m .40388 .49361 L .40371 .49299 L F
.4033 .49245 m .40371 .49299 L .40308 .49063 L F
.762 .946 .939 r
.40625 .49249 m .40434 .49381 L .40371 .49299 L F
.40434 .49381 m .40387 .49414 L .40371 .49299 L F
.40756 .49158 m .40625 .49249 L .4033 .49245 L F
.40625 .49249 m .4035 .49303 L .4033 .49245 L F
.702 .835 .946 r
.68751 .32525 m .68858 .3271 L .68454 .32668 L F
.96 .624 .301 r
.68858 .3271 m .68727 .32811 L .68454 .32668 L F
.68858 .3271 m .68837 .3291 L .68727 .32811 L F
.741 .221 0 r
.68751 .32525 m .69091 .32743 L .68858 .3271 L F
.409 .074 .284 r
.69091 .32743 m .68837 .3291 L .68858 .3271 L F
.719 .354 .357 r
.54448 .46491 m .54857 .46524 L .5472 .46767 L F
.657 .282 .322 r
.54857 .46524 m .55106 .46742 L .5472 .46767 L F
.775 .471 0 r
.40172 .65341 m .40218 .65437 L .40099 .65065 L F
.951 .884 .484 r
.40087 .65614 m .40218 .65437 L .40172 .65341 L F
.857 .978 .677 r
.43136 .58789 m .43282 .58602 L .43161 .58724 L F
0 0 .476 r
.43136 .58789 m .43187 .59099 L .43161 .58724 L F
.972 .812 .625 r
.62369 .40775 m .62514 .40652 L .62519 .40424 L F
.62369 .40775 m .62519 .40424 L .62225 .4032 L F
0 0 .223 r
.62362 .40573 m .62369 .40775 L .62338 .40403 L F
.62396 .40804 m .62369 .40775 L .62362 .40573 L F
.915 .977 .71 r
.62255 .4101 m .62371 .4085 L .62369 .40775 L F
.62371 .4085 m .62514 .40652 L .62369 .40775 L F
.957 .645 .394 r
.62512 .41006 m .62514 .40652 L .62255 .4101 L F
.929 .555 .271 r
.4004 .64925 m .3975 .64451 L .39664 .64727 L F
.859 .413 .134 r
.40099 .65065 m .4004 .64925 L .39664 .64727 L F
.961 .626 .267 r
.40142 .65202 m .4004 .64925 L .40099 .65065 L F
.753 .365 0 r
.41127 .5512 m .41068 .55064 L .41007 .54845 L F
.629 .733 .922 r
.38902 .51416 m .39069 .51357 L .38751 .51232 L F
.078 .508 .9 r
.54718 .40883 m .5471 .4097 L .54496 .40892 L F
.54718 .40883 m .54931 .41053 L .5471 .4097 L F
0 0 0 r
.34895 .59014 m .34408 .59275 L .34422 .58933 L F
.35 .229 .571 r
.35139 .58744 m .35077 .58965 L .34895 .59014 L F
0 0 0 r
.34852 .59075 m .34895 .59014 L .35077 .58965 L F
.835 .795 .813 r
.63403 .36119 m .63878 .3598 L .6378 .35859 L F
.541 .807 .995 r
.6378 .35859 m .63878 .3598 L .6415 .3591 L F
.43 .047 .21 r
.30527 .56079 m .30412 .56353 L .30146 .56385 L F
.215 .174 .594 r
.30679 .55854 m .30527 .56079 L .30433 .55858 L F
.30679 .55854 m .30732 .56004 L .30527 .56079 L F
.292 0 .149 r
.30658 .56274 m .30527 .56079 L .30732 .56004 L F
.885 .699 .645 r
.30051 .55919 m .30535 .56117 L .30433 .55858 L F
.30535 .56117 m .30536 .56118 L .30536 .56116 L F
.30535 .56117 m .30536 .56116 L .30433 .55858 L F
.292 0 .149 r
.30658 .56274 m .30412 .56353 L .30488 .5617 L F
.30545 .56106 m .30488 .5617 L .30527 .56079 L F
.30658 .56274 m .30488 .5617 L .30545 .56106 L F
.526 .339 .569 r
.45837 .49721 m .45849 .49961 L .45589 .50021 L F
.905 .896 .809 r
.34122 .52067 m .3411 .52449 L .34144 .52294 L F
0 .033 .573 r
.34335 .52602 m .34144 .52294 L .3411 .52449 L F
.371 0 0 r
.37977 .63377 m .37752 .63283 L .37637 .63346 L F
.68 .702 .864 r
.4002 .48933 m .39685 .49049 L .39944 .48758 L F
0 0 0 r
.4002 .48933 m .39719 .49331 L .39685 .49049 L F
.44 .34 .644 r
.39685 .49049 m .39869 .49099 L .39944 .48758 L F
.598 .121 .094 r
.39493 .49217 m .39869 .49099 L .39685 .49049 L F
.445 .074 .239 r
.39664 .64727 m .3975 .64451 L .39378 .6476 L F
.587 .444 .654 r
.35459 .60923 m .35863 .60883 L .35607 .60749 L F
.771 .726 .811 r
.35474 .60569 m .35459 .60923 L .35607 .60749 L F
.576 .392 .594 r
.35459 .60923 m .35596 .61194 L .35863 .60883 L F
.334 .029 .29 r
.41823 .49738 m .42078 .49668 L .42169 .49373 L F
.002 0 .144 r
.42169 .49373 m .42248 .49524 L .42438 .49416 L F
.42169 .49373 m .42078 .49668 L .42248 .49524 L F
.505 .223 .419 r
.29888 .54534 m .301 .54728 L .30179 .54447 L F
.29888 .54534 m .29842 .54791 L .301 .54728 L F
.335 .167 .499 r
.33026 .59957 m .33022 .60233 L .32817 .60307 L F
.334 .182 .52 r
.33039 .60437 m .32817 .60307 L .33022 .60233 L F
.33039 .60437 m .3281 .60572 L .32817 .60307 L F
.974 .667 .312 r
.6101 .41264 m .61149 .41401 L .61169 .41634 L F
.43 .865 .918 r
.47889 .45226 m .47529 .45251 L .47743 .45162 L F
.65 .931 .971 r
.47977 .45036 m .47889 .45226 L .47743 .45162 L F
.405 .663 .965 r
.48107 .45207 m .47889 .45226 L .47977 .45036 L F
.56 .505 .751 r
.48223 .45513 m .47889 .45226 L .48107 .45207 L F
.14 0 0 r
.41443 .48893 m .41356 .48804 L .41537 .48704 L F
.41443 .48893 m .412 .48964 L .41356 .48804 L F
.028 0 .373 r
.2106 .57103 m .21212 .57229 L .21216 .56961 L F
.2106 .57103 m .21045 .57368 L .21212 .57229 L F
.106 0 0 r
.34662 .60756 m .34588 .60643 L .34681 .6049 L F
.34662 .60756 m .34422 .60866 L .34588 .60643 L F
.541 0 0 r
.31727 .66661 m .31534 .66534 L .31313 .66592 L F
.945 .616 .19 r
.61217 .41888 m .61346 .42044 L .6137 .42292 L F
0 0 0 r
.3349 .68289 m .33249 .68369 L .33045 .68497 L F
.933 .627 .438 r
.70665 .30962 m .7086 .30822 L .7061 .30768 L F
.70665 .30962 m .70893 .3101 L .7086 .30822 L F
.617 .544 .749 r
.39719 .49331 m .39432 .49574 L .39464 .49439 L F
.471 .148 .336 r
.34719 .54152 m .3502 .54112 L .35057 .53863 L F
.026 0 0 r
.35057 .53863 m .35246 .53799 L .35368 .53615 L F
.261 0 .28 r
.35057 .53863 m .35233 .54025 L .35246 .53799 L F
.35057 .53863 m .3502 .54112 L .35233 .54025 L F
.441 .495 .819 r
.26281 .57599 m .26353 .5731 L .26218 .57391 L F
0 0 .379 r
.36873 .68042 m .36968 .68168 L .37124 .67974 L F
.36873 .68042 m .36894 .68305 L .36968 .68168 L F
.865 .68 .651 r
.5262 .43671 m .52581 .43936 L .52412 .43571 L F
.712 .6 .73 r
.72198 .35654 m .72253 .35122 L .7203 .35261 L F
.72198 .35654 m .72457 .35359 L .72253 .35122 L F
.712 .773 .9 r
.71596 .31951 m .71713 .3211 L .71324 .32038 L F
.893 .838 .785 r
.71713 .3211 m .71339 .32293 L .71324 .32038 L F
.71713 .3211 m .71505 .32462 L .71339 .32293 L F
.795 .797 .853 r
.71975 .318 m .71713 .3211 L .71596 .31951 L F
.255 .437 .849 r
.24121 .59805 m .24022 .60026 L .23818 .59677 L F
.507 .271 .491 r
.24336 .60068 m .24022 .60026 L .24121 .59805 L F
.24336 .60068 m .24033 .60242 L .24022 .60026 L F
.442 .342 .647 r
.35659 .5327 m .35678 .53526 L .35865 .53439 L F
.35659 .5327 m .35678 .53526 L .35865 .53439 L F
.476 .379 .666 r
.33246 .62794 m .32979 .62575 L .33238 .62513 L F
.33246 .62794 m .33015 .62849 L .32979 .62575 L F
.747 .521 .589 r
.60206 .37541 m .60264 .37853 L .59852 .37786 L F
.586 .414 .616 r
.60532 .3753 m .60264 .37853 L .60206 .37541 L F
.877 .883 .835 r
.37947 .61684 m .38111 .61841 L .3784 .62108 L F
0 .248 .72 r
.3191 .5456 m .31862 .54593 L .31668 .54597 L F
.3191 .5456 m .32075 .54714 L .31862 .54593 L F
.228 0 .132 r
.24011 .56854 m .23739 .57079 L .24004 .56975 L F
.648 .199 .172 r
.24011 .56854 m .24004 .56975 L .24429 .56978 L F
.806 .364 0 r
.3411 .6989 m .3436 .70209 L .34244 .70123 L F
.567 .045 0 r
.34244 .70123 m .3436 .70209 L .34522 .70377 L F
.559 .582 .834 r
.3436 .70209 m .34743 .70461 L .34522 .70377 L F
.212 0 .163 r
.458 .58666 m .45723 .58932 L .45481 .58948 L F
.043 0 .1 r
.45915 .58799 m .458 .58666 L .46066 .58582 L F
.45915 .58799 m .45723 .58932 L .458 .58666 L F
.755 .662 .76 r
.56736 .40583 m .56603 .4089 L .56747 .40647 L F
.364 .603 .94 r
.56603 .4089 m .56903 .40597 L .56747 .40647 L F
.458 0 0 r
.35188 .6833 m .35622 .6837 L .35389 .68436 L F
.972 .785 .591 r
.35453 .68235 m .35622 .6837 L .35389 .68436 L F
.247 .154 .548 r
.42026 .5088 m .42015 .51193 L .41861 .51081 L F
.484 .071 .18 r
.42015 .51193 m .41757 .51269 L .41861 .51081 L F
0 0 .076 r
.43317 .59564 m .43232 .59603 L .4319 .59847 L F
.093 .332 .806 r
.43182 .59436 m .43232 .59603 L .43335 .59465 L F
0 0 .061 r
.43335 .59465 m .43232 .59603 L .43317 .59564 L F
0 0 .513 r
.2097 .57732 m .21097 .57923 L .21039 .57653 L F
.892 .686 .618 r
.59847 .35682 m .5953 .35858 L .59686 .35687 L F
.59847 .35682 m .59795 .35963 L .5953 .35858 L F
.815 .968 .902 r
.60082 .35482 m .59847 .35682 L .59935 .35412 L F
.832 .982 .878 r
.59935 .35412 m .59847 .35682 L .59686 .35687 L F
0 0 .011 r
.3282 .64822 m .3295 .64446 L .32955 .64705 L F
.544 .764 .979 r
.32648 .64652 m .3282 .64822 L .32955 .64705 L F
.878 .749 .717 r
.3869 .58463 m .38822 .5886 L .38708 .58754 L F
.025 .208 .715 r
.38958 .5882 m .38874 .59019 L .3869 .58463 L F
.878 .749 .717 r
.38708 .58754 m .38874 .59019 L .38717 .58911 L F
.38822 .5886 m .38874 .59019 L .38708 .58754 L F
.346 .337 .707 r
.3869 .58463 m .38717 .58911 L .38958 .5882 L F
.629 .42 .58 r
.3869 .58463 m .3887 .58757 L .38276 .58517 L F
.208 .545 .929 r
.38376 .58447 m .38828 .58731 L .38638 .58528 L F
.38828 .58731 m .3887 .58757 L .38802 .58689 L F
.38828 .58731 m .38802 .58689 L .38638 .58528 L F
.38587 .58643 m .3887 .58757 L .38376 .58447 L F
0 .146 .667 r
.38838 .58497 m .3869 .58463 L .38954 .58301 L F
.38838 .58497 m .3887 .58757 L .3869 .58463 L F
.78 .781 .853 r
.38481 .58373 m .3887 .58757 L .38838 .58497 L F
.902 .897 .813 r
.3872 .58563 m .38616 .58861 L .38471 .58704 L F
.38838 .58497 m .3876 .58625 L .3872 .58563 L F
.3876 .58625 m .38616 .58861 L .3872 .58563 L F
.787 .708 .777 r
.38958 .5882 m .38616 .58861 L .3876 .58625 L F
.38938 .58766 m .3876 .58625 L .38838 .58497 L F
.38958 .5882 m .3876 .58625 L .38938 .58766 L F
.208 .545 .929 r
.38461 .58387 m .38638 .58528 L .38481 .58373 L F
.38376 .58447 m .38638 .58528 L .38461 .58387 L F
.38276 .58517 m .38587 .58643 L .38376 .58447 L F
.926 .597 .398 r
.38717 .58911 m .38874 .59019 L .38682 .59167 L F
.496 .319 .571 r
.3835 .54859 m .3828 .55115 L .38035 .55174 L F
.752 .958 .656 r
.38682 .59167 m .38874 .59019 L .38958 .5882 L F
.546 .5 .756 r
.39014 .59659 m .39304 .59693 L .39251 .59277 L F
.516 .816 .999 r
.37872 .55064 m .3828 .55115 L .38035 .55174 L F
.744 .626 .728 r
.57683 .41087 m .57656 .41319 L .57423 .41437 L F
.074 0 0 r
.24027 .57614 m .24193 .57467 L .24418 .57397 L F
.432 .464 .793 r
.38954 .58301 m .38587 .58029 L .38973 .58034 L F
.899 .932 .828 r
.62765 .43194 m .62607 .43674 L .6281 .43317 L F
.62765 .43194 m .62476 .4356 L .62607 .43674 L F
.946 .793 .337 r
.37662 .70766 m .37711 .70759 L .37718 .70549 L F
.855 .675 .657 r
.37279 .71072 m .37711 .70759 L .37662 .70766 L F
.37279 .71072 m .37651 .70999 L .37711 .70759 L F
.844 .791 .8 r
.65285 .40773 m .65532 .40449 L .65376 .40284 L F
.836 .791 .809 r
.65376 .40284 m .65532 .40449 L .65787 .4012 L F
.67 .645 .816 r
.45385 .46453 m .45239 .46899 L .45113 .46557 L F
.45385 .46453 m .45525 .4682 L .45239 .46899 L F
.636 .576 .77 r
.37403 .59844 m .37397 .60235 L .3744 .60058 L F
0 0 .078 r
.34473 .53421 m .34357 .53574 L .34525 .53164 L F
.325 .379 .764 r
.3469 .52858 m .34525 .53164 L .34449 .52981 L F
.3469 .52858 m .34735 .5306 L .34525 .53164 L F
.806 .69 .737 r
.37403 .59844 m .37705 .59711 L .37299 .5963 L F
.37403 .59844 m .3744 .60058 L .37705 .59711 L F
.709 .655 .795 r
.63711 .41666 m .63849 .41761 L .63443 .41698 L F
.769 .703 .789 r
.63951 .413 m .63849 .41761 L .63711 .41666 L F
.368 .105 .377 r
.32937 .50608 m .32714 .50684 L .32661 .50914 L F
0 0 .226 r
.33507 .52899 m .33631 .52495 L .3338 .52457 L F
.33507 .52899 m .33613 .52882 L .33631 .52495 L F
.33613 .52882 m .33616 .52874 L .33631 .52495 L F
.482 .257 .496 r
.33631 .52495 m .33619 .52813 L .33751 .52657 L F
.33631 .52495 m .33833 .52768 L .33919 .52469 L F
0 0 0 r
.33675 .52615 m .33631 .52495 L .33919 .52469 L F
.828 .994 .749 r
.33985 .52235 m .33675 .52615 L .339 .5248 L F
.33924 .52453 m .339 .5248 L .33919 .52469 L F
.33985 .52235 m .339 .5248 L .33924 .52453 L F
.482 .257 .496 r
.33751 .52657 m .33616 .52874 L .33833 .52768 L F
.33619 .52813 m .33616 .52874 L .33751 .52657 L F
.832 .994 .748 r
.33612 .52885 m .3371 .52649 L .33833 .52768 L F
.482 .257 .496 r
.33616 .52874 m .33616 .52882 L .33833 .52768 L F
.832 .994 .748 r
.3354 .52912 m .33675 .52615 L .3371 .52649 L F
.3353 .52928 m .33613 .52882 L .33612 .52885 L F
0 0 0 r
.33613 .52882 m .3353 .52928 L .33616 .52882 L F
.33507 .52899 m .3353 .52928 L .33613 .52882 L F
.832 .994 .748 r
.3353 .52928 m .3371 .52649 L .33613 .52882 L F
.3353 .52928 m .33537 .52914 L .3354 .52912 L F
.33537 .52914 m .33675 .52615 L .3354 .52912 L F
0 0 .226 r
.33613 .52882 m .33616 .52882 L .33616 .52874 L F
0 0 0 r
.33507 .52899 m .33439 .52969 L .3353 .52928 L F
.195 .255 .698 r
.31189 .62775 m .31017 .62858 L .3094 .62502 L F
.051 0 .367 r
.3103 .62961 m .31017 .62858 L .31189 .62775 L F
.512 .858 .993 r
.31517 .66785 m .31931 .6679 L .31727 .66661 L F
.889 .857 .804 r
.31727 .66661 m .31931 .6679 L .32004 .66624 L F
.366 .431 .796 r
.72471 .31875 m .72175 .32057 L .72239 .318 L F
.189 .148 .578 r
.72509 .32151 m .72175 .32057 L .72471 .31875 L F
.72509 .32151 m .72372 .3224 L .72175 .32057 L F
.468 .055 .173 r
.34056 .6005 m .33995 .60221 L .3433 .60154 L F
.934 .773 .302 r
.34992 .56761 m .34935 .57037 L .34993 .57099 L F
.859 .56 .032 r
.34935 .57037 m .34999 .57252 L .34993 .57099 L F
.674 .931 .638 r
.36968 .68168 m .36894 .68305 L .36694 .68453 L F
.635 .509 .692 r
.51567 .45514 m .51704 .45861 L .51335 .45832 L F
.702 .521 .639 r
.51704 .45861 m .51275 .46078 L .51335 .45832 L F
.859 .965 .638 r
.39073 .61846 m .39134 .61854 L .39302 .61545 L F
.858 .966 .639 r
.38942 .62055 m .39134 .61854 L .39073 .61846 L F
.178 .707 .852 r
.24616 .53746 m .24174 .53739 L .24355 .53843 L F
.24616 .53746 m .24174 .53739 L .24355 .53843 L F
.982 .727 .469 r
.42367 .57308 m .42349 .57582 L .42527 .57415 L F
.492 .504 .797 r
.42527 .57415 m .42628 .56983 L .42367 .57308 L F
.341 0 .074 r
.35246 .53799 m .35678 .53526 L .35368 .53615 L F
.86 .735 .723 r
.62225 .4032 m .62519 .40424 L .62378 .40045 L F
.49 .537 .832 r
.62378 .40045 m .62519 .40424 L .62772 .40366 L F
.595 .627 .853 r
.37081 .7111 m .37175 .71386 L .3747 .71203 L F
.819 .707 .172 r
.31517 .53949 m .31544 .53443 L .31111 .5372 L F
0 0 .331 r
.39112 .69325 m .39026 .68933 L .3905 .69316 L F
.3 0 0 r
.3905 .69316 m .3929 .69307 L .39112 .69325 L F
.58 .603 .84 r
.3929 .69307 m .39171 .69637 L .39112 .69325 L F
.605 .418 .602 r
.63165 .42283 m .63184 .42654 L .62965 .4271 L F
.567 .064 .019 r
.63165 .42283 m .63484 .42493 L .63184 .42654 L F
.63165 .42283 m .63584 .42348 L .63484 .42493 L F
.837 .766 .783 r
.39056 .59971 m .39202 .60294 L .38815 .603 L F
.489 .446 .736 r
.38954 .60601 m .38815 .603 L .39202 .60294 L F
.816 .758 .799 r
.39444 .59995 m .39202 .60294 L .39056 .59971 L F
.822 .579 .572 r
.39178 .60583 m .38954 .60601 L .39202 .60294 L F
.654 .52 .688 r
.46356 .49062 m .46374 .49383 L .46096 .49403 L F
.626 .403 .559 r
.46374 .49383 m .46094 .49662 L .46096 .49403 L F
0 0 .155 r
.35696 .56766 m .3547 .5711 L .35622 .56984 L F
.986 .875 .635 r
.3547 .5711 m .35533 .57182 L .35622 .56984 L F
.3547 .5711 m .35314 .575 L .35245 .57229 L F
.3547 .5711 m .35245 .57229 L .35533 .57182 L F
.909 .869 .787 r
.65069 .41117 m .65285 .40773 L .65146 .4064 L F
.844 .791 .8 r
.65285 .40773 m .65376 .40284 L .65146 .4064 L F
.759 .961 .661 r
.43009 .52732 m .42972 .52734 L .4321 .52411 L F
.283 .163 .534 r
.43079 .52582 m .42804 .52754 L .42855 .52255 L F
.759 .961 .661 r
.42972 .52734 m .43081 .5258 L .4321 .52411 L F
.423 .253 .545 r
.4321 .52411 m .43081 .5258 L .43021 .52161 L F
.759 .961 .661 r
.43081 .5258 m .43128 .52512 L .4321 .52411 L F
.423 .253 .545 r
.4321 .52411 m .43082 .52586 L .43081 .5258 L F
.283 .163 .534 r
.43082 .52586 m .43073 .52591 L .43079 .52582 L F
.43073 .52591 m .42804 .52754 L .43079 .52582 L F
.759 .961 .661 r
.42972 .52734 m .4295 .52736 L .43124 .52518 L F
.43079 .52582 m .43124 .52518 L .43128 .52512 L F
0 0 0 r
.4295 .52736 m .42804 .52754 L .43073 .52591 L F
.4295 .52736 m .43073 .52591 L .43082 .52586 L F
.759 .961 .661 r
.43072 .52592 m .43124 .52518 L .43079 .52582 L F
.42972 .52734 m .4307 .52594 L .43072 .52592 L F
.4307 .52594 m .43124 .52518 L .43072 .52592 L F
.283 .163 .534 r
.43081 .5258 m .42855 .52255 L .43021 .52161 L F
.43082 .52586 m .43079 .52582 L .43081 .5258 L F
.43079 .52582 m .42855 .52255 L .43081 .5258 L F
.574 .595 .836 r
.7151 .34339 m .71603 .34681 L .7188 .34599 L F
.545 .473 .725 r
.71603 .34681 m .71886 .34785 L .7188 .34599 L F
.949 .954 .663 r
.6293 .42795 m .6281 .43317 L .62773 .42978 L F
.6293 .42795 m .62765 .43194 L .6281 .43317 L F
.444 0 0 r
.29099 .55809 m .29336 .55887 L .29502 .55788 L F
.166 0 0 r
.29336 .55887 m .29746 .55752 L .29502 .55788 L F
.556 .593 .846 r
.34119 .54721 m .34359 .55171 L .34637 .55081 L F
.958 .684 .474 r
.34359 .55171 m .34166 .55368 L .3438 .5541 L F
.528 .181 .323 r
.37662 .70766 m .37718 .70549 L .37903 .70694 L F
.697 .55 .683 r
.46616 .48717 m .46356 .49062 L .46345 .48786 L F
.282 0 0 r
.29955 .64372 m .29817 .6406 L .29691 .64271 L F
.044 0 .261 r
.32284 .61232 m .32224 .61509 L .32089 .61578 L F
0 0 .33 r
.32224 .61509 m .3209 .61852 L .32089 .61578 L F
.193 0 .074 r
.45723 .58932 m .45394 .59172 L .45481 .58948 L F
.302 0 .12 r
.34337 .58385 m .34744 .58143 L .34622 .58326 L F
.374 .052 .285 r
.34878 .58252 m .34744 .58143 L .34889 .58067 L F
.428 .038 .197 r
.34622 .58326 m .34744 .58143 L .34878 .58252 L F
.865 .996 .792 r
.23174 .54673 m .23267 .54584 L .23355 .54405 L F
.37 .132 .418 r
.29637 .62814 m .29846 .63055 L .29888 .62776 L F
.29637 .62814 m .29627 .63116 L .29846 .63055 L F
.94 .725 .251 r
.59342 .38456 m .59361 .38149 L .59289 .3814 L F
.242 0 .277 r
.59594 .3806 m .59361 .38149 L .59614 .37879 L F
.337 .818 .799 r
.59289 .3814 m .59361 .38149 L .59594 .3806 L F
.59289 .3814 m .59361 .38149 L .59594 .3806 L F
.543 .351 .571 r
.46103 .49899 m .45837 .49721 L .46094 .49662 L F
.46103 .49899 m .45849 .49961 L .45837 .49721 L F
.571 .937 .911 r
.2972 .51563 m .29615 .51702 L .29809 .51566 L F
.2972 .51563 m .29316 .51737 L .29615 .51702 L F
.602 .42 .608 r
.46616 .48717 m .4662 .4902 L .46356 .49062 L F
.608 .547 .76 r
.46566 .48437 m .4685 .48397 L .46616 .48717 L F
.656 .615 .796 r
.46616 .48717 m .4685 .48397 L .46861 .48713 L F
.618 .414 .583 r
.46861 .48713 m .4662 .4902 L .46616 .48717 L F
.879 .854 .814 r
.57526 .40958 m .57423 .41437 L .57439 .41142 L F
.63 .955 .928 r
.68262 .36225 m .68002 .36378 L .67821 .3636 L F
.835 .702 .716 r
.52672 .42978 m .52457 .43288 L .52315 .42914 L F
.111 0 .051 r
.33833 .67933 m .3349 .68289 L .33798 .68007 L F
0 0 .039 r
.33987 .67629 m .33833 .67933 L .33975 .67945 L F
0 0 0 r
.33975 .67945 m .33833 .67933 L .33798 .68007 L F
.817 .755 .795 r
.65562 .40002 m .65787 .4012 L .65699 .3978 L F
.836 .791 .809 r
.65376 .40284 m .65787 .4012 L .65562 .40002 L F
.753 .719 .821 r
.65699 .3978 m .65787 .4012 L .66059 .39811 L F
.843 .686 .687 r
.3035 .6341 m .30711 .63491 L .3074 .63168 L F
.3035 .6341 m .3074 .63168 L .30582 .63377 L F
0 0 0 r
.3074 .63168 m .30932 .63099 L .30582 .63377 L F
.3074 .63168 m .3103 .62961 L .30932 .63099 L F
.756 .503 .55 r
.54019 .46196 m .53813 .46382 L .5363 .46146 L F
.54019 .46196 m .54042 .46472 L .53813 .46382 L F
.453 .879 .919 r
.3294 .54715 m .32974 .54623 L .33188 .54685 L F
.3294 .54715 m .32729 .54704 L .32974 .54623 L F
.835 .832 .844 r
.65641 .38377 m .65528 .38857 L .65399 .38725 L F
.65641 .38377 m .65819 .38559 L .65528 .38857 L F
.337 .341 .716 r
.32929 .5633 m .33007 .56789 L .33236 .56605 L F
0 0 0 r
.33007 .56789 m .33103 .5681 L .33236 .56605 L F
.33007 .56789 m .32946 .56966 L .33103 .5681 L F
0 0 .559 r
.37042 .50926 m .37264 .51272 L .37209 .51306 L F
0 .179 .705 r
.37264 .51272 m .3744 .51499 L .37209 .51306 L F
.826 .72 .748 r
.39304 .59693 m .39444 .59995 L .39056 .59971 L F
0 0 .235 r
.47114 .5601 m .47019 .56428 L .46984 .56332 L F
.47114 .5601 m .47111 .5626 L .47019 .56428 L F
.152 .364 .818 r
.47111 .5626 m .47264 .56583 L .47019 .56428 L F
.416 .06 .25 r
.41895 .48407 m .41537 .48704 L .4147 .4837 L F
.41895 .48407 m .41798 .48647 L .41537 .48704 L F
0 0 0 r
.41959 .48501 m .41895 .48407 L .42126 .48358 L F
.41959 .48501 m .41798 .48647 L .41895 .48407 L F
.901 .95 .825 r
.36607 .60697 m .36685 .61077 L .36942 .60483 L F
.549 .024 0 r
.57633 .42104 m .57793 .42034 L .58097 .4219 L F
0 .473 .779 r
.5789 .42084 m .58067 .42115 L .58097 .4219 L F
.57793 .42034 m .57962 .42084 L .5789 .42084 L F
.57962 .42084 m .58067 .42115 L .5789 .42084 L F
.325 .808 .882 r
.57711 .4206 m .57671 .42083 L .57888 .42037 L F
.57671 .42083 m .57633 .42104 L .57714 .42083 L F
.57671 .42083 m .57714 .42083 L .57888 .42037 L F
.46 0 0 r
.57669 .41998 m .57633 .42104 L .57536 .42159 L F
.325 .808 .882 r
.5749 .42088 m .57633 .42104 L .57711 .4206 L F
.46 0 0 r
.57536 .42159 m .57633 .42104 L .57456 .42256 L F
.57669 .41998 m .57793 .42034 L .57633 .42104 L F
.583 .533 .764 r
.43793 .54177 m .43907 .54555 L .44165 .54491 L F
.392 .136 .401 r
.43908 .54711 m .44165 .54491 L .43907 .54555 L F
.473 .351 .633 r
.26096 .57128 m .26353 .5731 L .26367 .57046 L F
.303 .364 .76 r
.26218 .57391 m .26353 .5731 L .26096 .57128 L F
.538 .504 .765 r
.35956 .58309 m .3554 .5796 L .35983 .58054 L F
.508 .303 .537 r
.35983 .58054 m .36244 .58026 L .3626 .57728 L F
.495 .259 .485 r
.35983 .58054 m .35956 .58309 L .36244 .58026 L F
.508 .303 .537 r
.35983 .58054 m .36244 .58026 L .3626 .57728 L F
.495 .259 .485 r
.35983 .58054 m .35956 .58309 L .36244 .58026 L F
.879 .854 .814 r
.57526 .40958 m .57683 .41087 L .57423 .41437 L F
.811 .823 .859 r
.33055 .66058 m .326 .66289 L .32877 .66283 L F
.788 .902 .5 r
.33067 .65942 m .33055 .66058 L .32877 .66283 L F
.568 .23 .356 r
.33055 .66058 m .33241 .66205 L .3306 .66379 L F
.715 .281 .218 r
.58398 .37918 m .58441 .37984 L .58308 .3769 L F
.713 .78 .905 r
.61288 .35261 m .61131 .35631 L .60966 .35382 L F
.61288 .35261 m .6136 .35519 L .61131 .35631 L F
.088 0 0 r
.23058 .5763 m .23291 .57574 L .23496 .5742 L F
.469 .281 .542 r
.23496 .5742 m .23734 .57359 L .23739 .57079 L F
.577 .548 .786 r
.2384 .57686 m .23496 .5742 L .23734 .57359 L F
.318 0 0 r
.23291 .57574 m .23734 .57359 L .23496 .5742 L F
.781 .892 .924 r
.26457 .54205 m .26292 .54098 L .26504 .53909 L F
.322 .297 .675 r
.29958 .62437 m .30085 .62144 L .29861 .62183 L F
.29958 .62437 m .30173 .62461 L .30085 .62144 L F
.364 .117 .4 r
.29888 .62776 m .30173 .62461 L .29958 .62437 L F
.423 .264 .559 r
.23287 .55694 m .23085 .55808 L .23074 .55488 L F
.23074 .55488 m .23085 .55808 L .23287 .55694 L F
.145 0 0 r
.35587 .5932 m .35889 .59116 L .35787 .5927 L F
.141 0 0 r
.35787 .5927 m .35889 .59116 L .36117 .59016 L F
.663 .376 .475 r
.23248 .59624 m .23479 .59595 L .23299 .59326 L F
.528 .273 .472 r
.36976 .58042 m .36663 .58203 L .3632 .58101 L F
.36976 .58042 m .36926 .5816 L .36663 .58203 L F
.513 .348 .594 r
.36926 .5816 m .36716 .58668 L .36663 .58203 L F
0 0 0 r
.36003 .56466 m .35913 .56688 L .36098 .5634 L F
.76 .902 .94 r
.25667 .52545 m .26152 .52481 L .25784 .52403 L F
.25667 .52545 m .25664 .52664 L .26152 .52481 L F
0 0 .49 r
.26152 .52481 m .25989 .51967 L .25784 .52403 L F
.314 .223 .59 r
.39874 .66997 m .39852 .67368 L .39728 .67371 L F
.288 .028 .334 r
.39728 .67371 m .39852 .67368 L .39667 .67607 L F
0 0 0 r
.33362 .49562 m .33573 .49526 L .33727 .49519 L F
.33362 .49562 m .33327 .49602 L .33573 .49526 L F
.702 .798 .924 r
.25005 .53807 m .24616 .53746 L .24834 .53683 L F
.25005 .53807 m .24616 .53746 L .24834 .53683 L F
.256 .71 .955 r
.24834 .53683 m .2526 .53769 L .25005 .53807 L F
.2526 .53769 m .24834 .53683 L .25005 .53807 L F
.912 .897 .8 r
.69102 .38228 m .69327 .37881 L .692 .37744 L F
.721 .573 .688 r
.52417 .45633 m .51939 .45816 L .51963 .45553 L F
.52417 .45633 m .52345 .45871 L .51939 .45816 L F
0 0 0 r
.30081 .50945 m .29655 .51182 L .29894 .5111 L F
.554 .314 .506 r
.30333 .51224 m .30081 .50945 L .29894 .5111 L F
.30333 .51224 m .30426 .5086 L .30081 .50945 L F
.198 0 .232 r
.27014 .56689 m .27097 .56904 L .27266 .56708 L F
.27014 .56689 m .26889 .5702 L .27097 .56904 L F
.361 .013 .233 r
.31175 .60885 m .31403 .6084 L .31515 .60568 L F
.425 .281 .58 r
.31515 .60568 m .31708 .6051 L .31715 .60291 L F
.444 .091 .271 r
.31515 .60568 m .31716 .60777 L .31708 .6051 L F
.31515 .60568 m .31403 .6084 L .31716 .60777 L F
.874 .987 .825 r
.67815 .30871 m .67541 .31191 L .6761 .30899 L F
.847 .969 .877 r
.67541 .31191 m .67316 .31185 L .6761 .30899 L F
.404 .636 .949 r
.28973 .65788 m .29068 .6559 L .28908 .6563 L F
.28973 .65788 m .29209 .65813 L .29068 .6559 L F
.915 .568 .108 r
.32511 .56184 m .32483 .56238 L .32373 .55999 L F
.85 .894 .868 r
.32757 .55854 m .32511 .56184 L .32373 .55999 L F
.582 .318 .482 r
.30254 .53243 m .30258 .53482 L .29978 .53479 L F
.29978 .53479 m .30258 .53482 L .30254 .53243 L F
.325 .124 .446 r
.30382 .53288 m .30254 .53243 L .30432 .53202 L F
.30382 .53288 m .30258 .53482 L .30254 .53243 L F
.30382 .53288 m .30254 .53243 L .30432 .53202 L F
.30382 .53288 m .30258 .53482 L .30254 .53243 L F
.582 .318 .482 r
.30254 .53243 m .30258 .53482 L .29978 .53479 L F
.651 .852 .977 r
.33485 .699 m .339 .69915 L .3373 .69835 L F
.294 .734 .965 r
.3373 .69835 m .339 .69915 L .3411 .6989 L F
.389 .207 .509 r
.3626 .57728 m .36458 .57926 L .36438 .57655 L F
.3626 .57728 m .36244 .58026 L .36458 .57926 L F
.3626 .57728 m .36458 .57926 L .36438 .57655 L F
.3626 .57728 m .36244 .58026 L .36458 .57926 L F
.118 .639 .883 r
.59296 .40606 m .59248 .40648 L .59163 .40506 L F
0 .25 .756 r
.59194 .40431 m .59296 .40606 L .59163 .40506 L F
.951 .671 .221 r
.59234 .40566 m .59296 .40606 L .59194 .40431 L F
.59306 .40811 m .59296 .40606 L .59234 .40566 L F
.118 .639 .883 r
.59296 .40606 m .59498 .40665 L .59378 .40657 L F
.59296 .40606 m .59378 .40657 L .59248 .40648 L F
.872 .716 .685 r
.35826 .5191 m .35989 .5204 L .3595 .51613 L F
.05 .089 .582 r
.3597 .51838 m .35989 .5204 L .36108 .51813 L F
0 .233 .749 r
.35989 .5204 m .36149 .51992 L .36108 .51813 L F
.639 .912 .614 r
.35695 .52002 m .35569 .52174 L .35615 .52127 L F
.35723 .51983 m .35615 .52127 L .35826 .5191 L F
.35695 .52002 m .35615 .52127 L .35723 .51983 L F
.629 .283 .365 r
.35782 .51963 m .36149 .51992 L .35695 .52002 L F
.36108 .51813 m .36146 .51982 L .35782 .51963 L F
.36146 .51982 m .36149 .51992 L .35782 .51963 L F
.05 .089 .582 r
.3595 .51613 m .3597 .51838 L .36108 .51813 L F
.98 .909 .655 r
.3595 .51613 m .3565 .51936 L .35826 .5191 L F
.838 .964 .635 r
.35989 .51417 m .3565 .51936 L .3595 .51613 L F
0 .031 .592 r
.3595 .51613 m .36108 .51813 L .35989 .51417 L F
.606 .42 .604 r
.35989 .51417 m .36085 .51819 L .3565 .51936 L F
.629 .283 .365 r
.35971 .51875 m .35782 .51963 L .35858 .51926 L F
.36108 .51813 m .35934 .51893 L .35971 .51875 L F
.35934 .51893 m .35782 .51963 L .35971 .51875 L F
.434 .17 .412 r
.36108 .51813 m .3643 .51515 L .35989 .51417 L F
.36293 .51642 m .36353 .51751 L .3643 .51515 L F
.36108 .51813 m .36353 .51751 L .36293 .51642 L F
.036 .149 .654 r
.36353 .51751 m .36465 .52015 L .36479 .51957 L F
.714 .264 0 r
.36353 .51751 m .36479 .51957 L .3644 .5191 L F
.175 .559 .932 r
.36107 .51826 m .36149 .51992 L .36353 .51751 L F
.3604 .51841 m .36206 .51796 L .36108 .51813 L F
.315 .235 .604 r
.36112 .51805 m .36107 .51826 L .36085 .51819 L F
.36107 .51826 m .36097 .5187 L .36088 .5183 L F
.36107 .51826 m .36088 .5183 L .36085 .51819 L F
.629 .283 .365 r
.36108 .51813 m .35858 .51926 L .36025 .51847 L F
.606 .42 .604 r
.36025 .51847 m .36082 .51893 L .35858 .51926 L F
.36088 .5183 m .36107 .51913 L .36025 .51847 L F
.175 .559 .932 r
.35989 .51862 m .36062 .51922 L .36107 .51826 L F
.606 .42 .604 r
.36082 .51893 m .36066 .51915 L .35858 .51926 L F
.36085 .51819 m .35858 .51926 L .3565 .51936 L F
.629 .283 .365 r
.36025 .51847 m .35858 .51926 L .35989 .51862 L F
.53 .449 .709 r
.35989 .51862 m .35891 .5191 L .36062 .51913 L F
.175 .559 .932 r
.36066 .51915 m .36083 .51927 L .36097 .5187 L F
.606 .42 .604 r
.36082 .51893 m .36107 .51913 L .36066 .51915 L F
.53 .449 .709 r
.35989 .51862 m .36062 .51913 L .36107 .51913 L F
.175 .559 .932 r
.36062 .51922 m .36081 .51937 L .36083 .51927 L F
.36062 .51922 m .36083 .51927 L .36066 .51915 L F
.36062 .51922 m .36097 .5187 L .36107 .51826 L F
.36025 .51847 m .36088 .5183 L .3604 .51841 L F
.606 .42 .604 r
.36085 .51819 m .36088 .5183 L .36025 .51847 L F
.175 .559 .932 r
.35989 .51862 m .36107 .51826 L .36088 .5183 L F
.35989 .51862 m .36088 .5183 L .36025 .51847 L F
.36107 .51826 m .36206 .51796 L .3604 .51841 L F
.36081 .51937 m .36149 .51992 L .36107 .51826 L F
.315 .235 .604 r
.36158 .51783 m .36107 .51913 L .36097 .5187 L F
.36158 .51783 m .36097 .5187 L .36112 .51805 L F
.698 .512 .632 r
.36149 .51992 m .36465 .52015 L .36353 .51751 L F
.714 .264 0 r
.36353 .51751 m .3644 .5191 L .36304 .51746 L F
.315 .235 .604 r
.36222 .5162 m .36158 .51783 L .35989 .51417 L F
.36158 .51783 m .36085 .51819 L .35989 .51417 L F
.53 .449 .709 r
.3578 .51907 m .35763 .5193 L .36107 .51913 L F
.629 .283 .365 r
.35782 .51963 m .35695 .52002 L .35989 .51862 L F
.53 .449 .709 r
.35989 .51862 m .3578 .51907 L .35891 .5191 L F
.639 .912 .614 r
.35695 .52002 m .35826 .5191 L .3565 .51936 L F
.53 .449 .709 r
.3578 .51907 m .3565 .51936 L .35763 .5193 L F
.175 .559 .932 r
.36206 .51796 m .36353 .51751 L .36108 .51813 L F
0 .233 .749 r
.35989 .5204 m .36231 .52235 L .36149 .51992 L F
.896 .826 .77 r
.6601 .38175 m .65641 .38377 L .65891 .38048 L F
.6601 .38175 m .65819 .38559 L .65641 .38377 L F
.827 .865 .874 r
.66165 .37733 m .6601 .38175 L .65891 .38048 L F
.66165 .37733 m .66317 .37904 L .6601 .38175 L F
.621 .931 .694 r
.2308 .54713 m .22953 .54868 L .23174 .54673 L F
0 0 .185 r
.22988 .54983 m .22953 .54868 L .2308 .54713 L F
.658 .873 .502 r
.22717 .54122 m .22894 .53849 L .23087 .53921 L F
.22717 .54122 m .22783 .53998 L .22894 .53849 L F
.771 .705 .79 r
.38827 .61603 m .38794 .61759 L .38633 .61482 L F
.521 .256 .454 r
.36186 .54511 m .36487 .54483 L .36523 .5423 L F
.147 0 .334 r
.36523 .5423 m .36487 .54483 L .3669 .54121 L F
0 0 0 r
.62726 .41325 m .62763 .41073 L .62878 .41235 L F
.626 .063 0 r
.62878 .41235 m .62763 .41073 L .62512 .41006 L F
.622 .471 .656 r
.45716 .50933 m .4545 .50826 L .45712 .50743 L F
.45716 .50933 m .45456 .51002 L .4545 .50826 L F
.212 0 0 r
.35331 .58603 m .35586 .58577 L .35719 .58376 L F
.373 0 .068 r
.35719 .58376 m .35586 .58577 L .35328 .58571 L F
.538 .504 .765 r
.35956 .58309 m .35719 .58376 L .3554 .5796 L F
.706 .419 0 r
.27963 .62761 m .28007 .62894 L .27889 .62485 L F
0 .28 .663 r
.28108 .62935 m .28288 .63031 L .28007 .62894 L F
.301 .471 .861 r
.28354 .63206 m .28007 .62894 L .28288 .63031 L F
.325 .125 .447 r
.34473 .59624 m .34578 .59623 L .3461 .59349 L F
.355 .15 .457 r
.3461 .59349 m .34796 .59529 L .34837 .59271 L F
.3461 .59349 m .34578 .59623 L .34796 .59529 L F
.083 0 .233 r
.21914 .55139 m .22058 .55279 L .22091 .55014 L F
.21914 .55139 m .21894 .55398 L .22058 .55279 L F
.523 .36 .602 r
.48227 .45787 m .47996 .4614 L .48003 .45876 L F
0 .097 .654 r
.37824 .51638 m .38002 .51824 L .37988 .51961 L F
0 .252 .764 r
.38002 .51824 m .3824 .52152 L .37988 .51961 L F
.61 .502 .706 r
.35484 .55525 m .35668 .55424 L .35424 .55495 L F
.109 .192 .67 r
.32703 .69232 m .3278 .69637 L .3291 .6946 L F
.239 .379 .803 r
.3278 .69637 m .33074 .69839 L .3291 .6946 L F
.684 .882 .503 r
.68053 .30525 m .67815 .30871 L .67943 .30638 L F
.592 .888 .594 r
.6834 .30237 m .68053 .30525 L .68221 .30323 L F
.559 .839 .498 r
.68221 .30323 m .68053 .30525 L .67943 .30638 L F
.893 .974 .671 r
.23296 .53548 m .23087 .53921 L .23097 .53704 L F
.757 .95 .94 r
.23087 .53921 m .22894 .53849 L .23097 .53704 L F
.733 .45 .499 r
.22751 .60229 m .22836 .60332 L .23058 .602 L F
.841 .982 .87 r
.23058 .602 m .22836 .60332 L .23241 .59903 L F
.926 .853 .75 r
.64832 .41188 m .64958 .41337 L .64909 .4097 L F
.888 .86 .807 r
.64714 .41672 m .64958 .41337 L .64832 .41188 L F
.891 .834 .783 r
.64909 .4097 m .64958 .41337 L .65069 .41117 L F
.818 .991 .741 r
.6211 .38848 m .61842 .39113 L .62099 .39015 L F
.702 .571 .705 r
.62241 .39165 m .6211 .38848 L .62099 .39015 L F
.62241 .39165 m .62486 .38851 L .6211 .38848 L F
.642 .486 .656 r
.35787 .5927 m .35557 .59551 L .35587 .5932 L F
.674 .932 .969 r
.31912 .52986 m .32015 .52761 L .32076 .52869 L F
.31912 .52986 m .31724 .52873 L .32015 .52761 L F
.079 0 .041 r
.32024 .53044 m .31805 .53166 L .31912 .52986 L F
.592 .695 .914 r
.31704 .52947 m .32024 .53044 L .32039 .52992 L F
.079 0 .041 r
.32024 .53044 m .31912 .52986 L .32076 .52869 L F
.592 .695 .914 r
.31826 .52921 m .32039 .52992 L .32076 .52869 L F
0 .514 .841 r
.31457 .52821 m .31616 .52852 L .31912 .52986 L F
.31616 .52852 m .31777 .52906 L .31912 .52986 L F
.592 .695 .914 r
.31704 .52947 m .32039 .52992 L .31826 .52921 L F
0 .514 .841 r
.31616 .52852 m .31724 .52873 L .31777 .52906 L F
0 0 0 r
.44983 .59407 m .44837 .59522 L .44632 .59612 L F
.452 .59304 m .44837 .59522 L .44983 .59407 L F
.281 0 0 r
.24429 .56978 m .24627 .5703 L .24712 .57036 L F
.76 .78 .869 r
.46296 .46102 m .46724 .46115 L .46504 .46217 L F
.913 .731 .643 r
.46296 .46102 m .46504 .46217 L .46441 .46481 L F
0 0 0 r
.23725 .56495 m .23605 .56714 L .23845 .56385 L F
0 0 .537 r
.63884 .42121 m .6383 .42135 L .63961 .4233 L F
0 0 0 r
.63584 .42348 m .6383 .42135 L .63884 .42121 L F
.744 .642 .747 r
.29998 .51529 m .30239 .51639 L .30459 .5128 L F
.578 .594 .833 r
.35178 .6881 m .35392 .69288 L .3508 .69267 L F
.57 .222 .34 r
.3508 .69267 m .35299 .69476 L .35055 .69525 L F
.3508 .69267 m .35392 .69288 L .35299 .69476 L F
.35299 .69476 m .3508 .69267 L .35055 .69525 L F
.35299 .69476 m .35392 .69288 L .3508 .69267 L F
.167 .418 .857 r
.34743 .70461 m .34951 .70663 L .34869 .70528 L F
.34951 .70663 m .35128 .70835 L .34869 .70528 L F
.389 0 0 r
.34793 .70406 m .34869 .70528 L .34887 .70415 L F
.34522 .70377 m .34743 .70461 L .34869 .70528 L F
.34522 .70377 m .34869 .70528 L .34793 .70406 L F
.609 .078 0 r
.23882 .61872 m .23896 .61938 L .23722 .61753 L F
.23882 .61872 m .24065 .62062 L .23896 .61938 L F
.978 .782 .571 r
.64053 .41077 m .6413 .41438 L .63951 .413 L F
.799 .554 .568 r
.43383 .58325 m .43548 .58063 L .43453 .58025 L F
.43383 .58325 m .43677 .5837 L .43548 .58063 L F
.445 .382 .693 r
.43548 .58063 m .43876 .58328 L .43874 .57983 L F
.43548 .58063 m .43677 .5837 L .43876 .58328 L F
.973 .88 .68 r
.59682 .37623 m .59485 .37725 L .59538 .37625 L F
.59682 .37623 m .59614 .37879 L .59485 .37725 L F
.635 .525 .712 r
.39792 .4971 m .39384 .49921 L .39432 .49574 L F
.118 .223 .698 r
.42409 .53954 m .42639 .54052 L .42481 .54202 L F
.451 .779 .998 r
.42639 .54052 m .42769 .54183 L .42481 .54202 L F
.975 .689 .297 r
.59485 .37725 m .59614 .37879 L .59594 .3806 L F
.837 .737 .754 r
.59852 .37786 m .59594 .3806 L .59614 .37879 L F
0 0 .202 r
.34473 .53421 m .34279 .53818 L .34357 .53574 L F
.535 .008 0 r
.24896 .61658 m .25181 .61722 L .25386 .61601 L F
0 .03 .582 r
.25472 .61633 m .25583 .61821 L .25386 .61601 L F
.25472 .61633 m .25386 .61601 L .25181 .61722 L F
.586 .562 .795 r
.32619 .55385 m .32233 .55092 L .32695 .55158 L F
.457 .514 .828 r
.32729 .54704 m .32884 .5508 L .32695 .55158 L F
.591 .393 .582 r
.32884 .5508 m .32619 .55385 L .32695 .55158 L F
.799 .498 .48 r
.39544 .58057 m .39227 .58254 L .39236 .58008 L F
.39544 .58057 m .39635 .58312 L .39227 .58254 L F
0 0 0 r
.39431 .6528 m .39255 .6533 L .39286 .65327 L F
0 0 .439 r
.21076 .58358 m .21123 .58317 L .21097 .57923 L F
0 0 .346 r
.21076 .58358 m .21155 .58595 L .21123 .58317 L F
.918 .534 .128 r
.3861 .52742 m .38664 .5261 L .38345 .52562 L F
.3861 .52742 m .38753 .5287 L .38664 .5261 L F
.545 .78 .985 r
.62099 .39015 m .62241 .39165 L .62374 .38958 L F
.685 .161 0 r
.38004 .7036 m .37969 .70234 L .38185 .70158 L F
0 0 0 r
.30248 .65118 m .30284 .64773 L .3032 .64939 L F
.30173 .65377 m .30248 .65118 L .3032 .64939 L F
.36 .768 .982 r
.36816 .6188 m .36375 .61806 L .36654 .61719 L F
.36375 .61806 m .36816 .6188 L .36654 .61719 L F
.467 .27 .529 r
.37054 .61832 m .36816 .6188 L .37065 .61562 L F
.49 .779 .996 r
.36654 .61719 m .36816 .6188 L .37054 .61832 L F
.36654 .61719 m .36816 .6188 L .37054 .61832 L F
.78 .571 .617 r
.53652 .45872 m .53222 .46099 L .53404 .45849 L F
.53652 .45872 m .5363 .46146 L .53222 .46099 L F
.582 .866 .995 r
.36539 .71225 m .36832 .71186 L .36632 .7107 L F
.468 .873 .956 r
.36832 .71186 m .36881 .71065 L .36632 .7107 L F
.36832 .71186 m .37081 .7111 L .36881 .71065 L F
.579 .774 .972 r
.57256 .46909 m .57531 .46814 L .57084 .46703 L F
.45 .246 .511 r
.42692 .49071 m .42438 .49416 L .4269 .49335 L F
.538 .894 .674 r
.42438 .49416 m .4256 .49283 L .4269 .49335 L F
.42438 .49416 m .42248 .49524 L .4256 .49283 L F
.885 .794 .754 r
.59594 .3806 m .59684 .38446 L .59479 .38304 L F
.812 .854 .88 r
.59684 .38446 m .59342 .38456 L .59479 .38304 L F
.826 .763 .793 r
.59931 .38104 m .59684 .38446 L .59594 .3806 L F
.706 .42 .488 r
.53001 .45847 m .53404 .45849 L .53222 .46099 L F
.912 .897 .8 r
.69102 .38228 m .692 .37744 L .68916 .38056 L F
0 0 0 r
.34357 .51484 m .34566 .51396 L .34323 .51446 L F
.564 0 0 r
.35012 .55162 m .34738 .55235 L .34637 .55081 L F
.5 .324 .573 r
.35262 .54809 m .3526 .55139 L .35012 .55162 L F
.324 0 0 r
.35077 .55254 m .35012 .55162 L .3526 .55139 L F
.35077 .55254 m .34738 .55235 L .35012 .55162 L F
.803 .862 .893 r
.63896 .34402 m .63456 .34523 L .63752 .3424 L F
.828 .85 .864 r
.64076 .34234 m .63896 .34402 L .63752 .3424 L F
.39 .232 .543 r
.31756 .59983 m .31962 .60195 L .31984 .59896 L F
.31756 .59983 m .31715 .60291 L .31962 .60195 L F
.845 .704 .707 r
.34793 .52215 m .34373 .52155 L .34492 .52057 L F
.896 .845 .786 r
.34793 .52215 m .34335 .52602 L .34599 .52522 L F
.34793 .52215 m .34599 .52522 L .34373 .52155 L F
.241 .635 .96 r
.34492 .52057 m .3479 .5209 L .34793 .52215 L F
0 0 0 r
.61876 .37828 m .62179 .37414 L .62132 .37699 L F
.064 .259 .751 r
.62277 .37034 m .62179 .37414 L .62126 .37229 L F
.62277 .37034 m .62454 .37433 L .62179 .37414 L F
.455 .025 .133 r
.62179 .37414 m .622 .37651 L .62132 .37699 L F
.62179 .37414 m .62454 .37433 L .622 .37651 L F
.544 .732 .962 r
.62645 .38607 m .62486 .38851 L .6275 .38796 L F
.62645 .38607 m .62486 .38851 L .6275 .38796 L F
.246 .147 .539 r
.699 .30597 m .69639 .30508 L .69899 .30361 L F
.699 .30597 m .6966 .3072 L .69639 .30508 L F
.771 .495 0 r
.3824 .52152 m .38345 .52562 L .38288 .52292 L F
.286 0 .045 r
.33118 .62154 m .32884 .62199 L .32714 .62438 L F
.58 .858 .995 r
.36151 .71228 m .36539 .71225 L .36387 .71117 L F
.51 .779 .993 r
.36387 .71117 m .36539 .71225 L .36632 .7107 L F
0 0 .205 r
.35622 .56984 m .35913 .56688 L .35696 .56766 L F
.596 .38 .557 r
.28186 .56102 m .28451 .56079 L .28476 .55802 L F
.451 .255 .522 r
.28451 .56079 m .28681 .55745 L .28476 .55802 L F
0 0 .343 r
.35886 .60607 m .35988 .60536 L .36014 .60225 L F
0 0 0 r
.35863 .60883 m .35988 .60536 L .35886 .60607 L F
.739 .991 .874 r
.67815 .30871 m .6761 .30899 L .67943 .30638 L F
.516 .361 .61 r
.4662 .4902 m .46374 .49383 L .46356 .49062 L F
.909 .869 .787 r
.65069 .41117 m .65146 .4064 L .64909 .4097 L F
.843 .998 .777 r
.28388 .52658 m .28157 .52974 L .28209 .52726 L F
.583 .483 .707 r
.28388 .52658 m .2844 .52943 L .28157 .52974 L F
.457 .081 .237 r
.2844 .52943 m .28368 .53101 L .28157 .52974 L F
.042 .245 .744 r
.28157 .52974 m .28368 .53101 L .28209 .52726 L F
.593 .322 .475 r
.43892 .51557 m .43522 .51807 L .43543 .51636 L F
.836 .771 .79 r
.38124 .70882 m .38378 .70546 L .38126 .70419 L F
.878 .975 .668 r
.69345 .32745 m .69494 .3267 L .69348 .32896 L F
.317 .786 .933 r
.69642 .32586 m .69494 .3267 L .69345 .32745 L F
.69642 .32586 m .69765 .32631 L .69494 .3267 L F
.832 .72 .741 r
.3035 .6341 m .30546 .6383 L .30711 .63491 L F
.909 .647 .531 r
.30614 .63754 m .30711 .63491 L .30546 .6383 L F
.883 .451 .136 r
.36941 .67128 m .37143 .67096 L .36953 .66909 L F
.562 .818 .993 r
.37593 .67042 m .37143 .67096 L .37353 .67082 L F
.577 .719 .939 r
.39171 .69637 m .39218 .69356 L .3899 .69539 L F
.58 .603 .84 r
.3929 .69307 m .39423 .69579 L .39171 .69637 L F
.577 .719 .939 r
.39171 .69637 m .39423 .69579 L .39218 .69356 L F
0 0 0 r
.69384 .36881 m .6951 .3644 L .69516 .36681 L F
0 0 .376 r
.69511 .36906 m .69384 .36881 L .69516 .36681 L F
.69511 .36906 m .69408 .37152 L .69384 .36881 L F
.53 .876 .627 r
.23296 .53548 m .23407 .53435 L .23597 .53302 L F
.626 .922 .657 r
.23597 .53302 m .23562 .53269 L .23781 .53146 L F
.23597 .53302 m .23407 .53435 L .23562 .53269 L F
.601 .206 .266 r
.52345 .45871 m .52727 .45853 L .52607 .4605 L F
.636 .338 .449 r
.52727 .45853 m .53007 .46084 L .52607 .4605 L F
.52727 .45853 m .53001 .45847 L .53007 .46084 L F
0 0 0 r
.35248 .56409 m .35107 .56707 L .34992 .56761 L F
.543 .211 .354 r
.35496 .56642 m .35248 .56409 L .35393 .56287 L F
.35496 .56642 m .35107 .56707 L .35248 .56409 L F
.826 1 .803 r
.60284 .36769 m .60136 .36984 L .59925 .37076 L F
.832 .844 .856 r
.63443 .41698 m .63125 .41721 L .63257 .4159 L F
.698 .737 .881 r
.63596 .41252 m .63443 .41698 L .63257 .4159 L F
.63596 .41252 m .63711 .41666 L .63443 .41698 L F
.939 .57 .201 r
.60453 .42688 m .60534 .42935 L .60674 .43018 L F
.937 .585 .17 r
.60583 .43094 m .60674 .43018 L .60534 .42935 L F
.60583 .43094 m .6071 .43224 L .60674 .43018 L F
0 0 .428 r
.43022 .56223 m .4309 .56371 L .42924 .561 L F
.43022 .56223 m .42924 .561 L .42734 .56034 L F
.341 0 .074 r
.35246 .53799 m .35478 .53784 L .35678 .53526 L F
.315 0 .058 r
.35678 .53526 m .35838 .53623 L .35865 .53439 L F
.35678 .53526 m .35478 .53784 L .35838 .53623 L F
.66 .937 .967 r
.60082 .35482 m .60198 .35273 L .60341 .35396 L F
.60082 .35482 m .59935 .35412 L .60198 .35273 L F
.538 .655 .911 r
.42692 .49071 m .42787 .48716 L .42415 .48926 L F
.42692 .49071 m .42938 .49022 L .42874 .48893 L F
.468 .26 .514 r
.42692 .49071 m .4269 .49335 L .42938 .49022 L F
.538 .655 .911 r
.42734 .48912 m .42874 .48893 L .42787 .48716 L F
.42692 .49071 m .42874 .48893 L .42734 .48912 L F
.552 .468 .713 r
.42787 .48716 m .4275 .48996 L .42415 .48926 L F
.4275 .48996 m .42727 .49171 L .42544 .49027 L F
.4275 .48996 m .42544 .49027 L .42415 .48926 L F
.854 .802 .799 r
.42787 .48716 m .42938 .49022 L .43182 .48662 L F
.304 .242 .621 r
.4298 .4869 m .42812 .4901 L .42787 .48716 L F
.42812 .4901 m .42727 .49171 L .4275 .48996 L F
.42812 .4901 m .4275 .48996 L .42787 .48716 L F
.52 .397 .653 r
.4298 .4869 m .42729 .49095 L .42727 .49171 L F
.355 0 .099 r
.42729 .49095 m .43 .49064 L .43003 .49054 L F
.42878 .49025 m .43003 .49054 L .43034 .48952 L F
.866 .996 .777 r
.42938 .49022 m .42896 .49076 L .42729 .49095 L F
.355 0 .099 r
.42729 .49095 m .43003 .49054 L .42878 .49025 L F
.866 .996 .777 r
.42896 .49076 m .4269 .49335 L .42729 .49095 L F
0 0 0 r
.43182 .48662 m .43128 .48741 L .43073 .48826 L F
.43128 .48741 m .42938 .49022 L .43073 .48826 L F
.355 0 .099 r
.42729 .49095 m .43073 .48826 L .42938 .49022 L F
.43009 .48875 m .43043 .48871 L .43073 .48826 L F
.43043 .48871 m .4306 .48869 L .43073 .48826 L F
.42909 .48971 m .43034 .48952 L .4306 .48869 L F
.42729 .49095 m .43034 .48952 L .42909 .48971 L F
.42729 .49095 m .4306 .48869 L .43009 .48875 L F
.216 0 .298 r
.62989 .36243 m .6268 .36629 L .62948 .36489 L F
0 0 .095 r
.6268 .36629 m .62847 .36172 L .62948 .36489 L F
.956 .614 .252 r
.62624 .36758 m .6276 .36842 L .6268 .36629 L F
.784 .859 .906 r
.6276 .36842 m .62948 .36489 L .6268 .36629 L F
.956 .614 .252 r
.62624 .36758 m .6268 .36629 L .62948 .36489 L F
.592 .365 .54 r
.34178 .59004 m .34148 .59289 L .33878 .59302 L F
.565 .379 .588 r
.34422 .58933 m .34148 .59289 L .34178 .59004 L F
.736 .525 .607 r
.34275 .68617 m .33859 .68819 L .33825 .68748 L F
.34275 .68617 m .3419 .68905 L .33859 .68819 L F
.482 0 0 r
.34342 .68777 m .34538 .68695 L .34275 .68617 L F
0 0 0 r
.34247 .68672 m .34275 .68617 L .34531 .68165 L F
.482 0 0 r
.34342 .68777 m .34275 .68617 L .34247 .68672 L F
.05 0 0 r
.32868 .62973 m .33015 .62849 L .33246 .62794 L F
.837 .737 .754 r
.59852 .37786 m .59931 .38104 L .59594 .3806 L F
.715 .667 .801 r
.59852 .37786 m .60264 .37853 L .59931 .38104 L F
.706 .567 .695 r
.56039 .39922 m .56098 .40215 L .55863 .40077 L F
.297 .288 .68 r
.56039 .39922 m .56294 .39929 L .56354 .3984 L F
.56039 .39922 m .56098 .40215 L .56294 .39929 L F
.616 .483 .677 r
.23734 .57359 m .24004 .56975 L .23739 .57079 L F
.889 .857 .804 r
.31727 .66661 m .32004 .66624 L .32094 .66451 L F
.437 .617 .926 r
.32094 .66451 m .32393 .66672 L .32004 .66624 L F
.686 .588 .74 r
.46458 .47834 m .4672 .47764 L .46477 .48092 L F
.596 .463 .671 r
.46477 .48092 m .4672 .47764 L .4675 .48032 L F
.601 .497 .708 r
.4675 .48032 m .46566 .48437 L .46477 .48092 L F
.148 0 .2 r
.36766 .53912 m .3669 .54121 L .36957 .53817 L F
.899 .754 .692 r
.56246 .40459 m .56708 .4008 L .56536 .39934 L F
.637 .608 .804 r
.56708 .4008 m .57066 .40078 L .56932 .3977 L F
.305 .252 .632 r
.56708 .4008 m .56924 .40235 L .57066 .40078 L F
.56708 .4008 m .56823 .40381 L .56924 .40235 L F
.897 .613 .498 r
.22325 .57854 m .22183 .57985 L .22168 .57695 L F
0 0 .308 r
.22293 .58102 m .22183 .57985 L .22325 .57854 L F
0 0 .241 r
.22567 .57504 m .22519 .57817 L .22325 .57854 L F
0 0 0 r
.22459 .58012 m .22325 .57854 L .22519 .57817 L F
.22459 .58012 m .22293 .58102 L .22325 .57854 L F
.349 .196 .528 r
.70384 .30755 m .70178 .3109 L .70392 .30989 L F
0 0 .37 r
.70178 .3109 m .70352 .31192 L .70392 .30989 L F
.70178 .3109 m .7019 .31339 L .70352 .31192 L F
.823 .808 .836 r
.63951 .413 m .63711 .41666 L .63596 .41252 L F
.684 .919 .594 r
.6834 .30237 m .68477 .30009 L .68526 .3007 L F
.6834 .30237 m .68221 .30323 L .68477 .30009 L F
.709 .446 .526 r
.33319 .61525 m .33641 .61505 L .33669 .61249 L F
.41 .189 .464 r
.33899 .61188 m .33641 .61505 L .33669 .61249 L F
0 0 0 r
.33764 .61374 m .33641 .61505 L .33899 .61188 L F
0 0 .225 r
.33669 .61249 m .33764 .61374 L .33606 .61142 L F
.33669 .61249 m .33641 .61505 L .33764 .61374 L F
.678 .283 .291 r
.51939 .45816 m .52345 .45871 L .5219 .46043 L F
.607 .196 .237 r
.5219 .46043 m .52345 .45871 L .52607 .4605 L F
.021 0 0 r
.63606 .39979 m .6372 .39857 L .63967 .39773 L F
.559 .486 .73 r
.63967 .39773 m .6372 .39857 L .63691 .3959 L F
0 0 .016 r
.3706 .5358 m .36957 .53817 L .37195 .53465 L F
0 0 0 r
.63484 .42493 m .63584 .42348 L .63884 .42121 L F
.377 0 0 r
.55506 .46774 m .55904 .46809 L .55753 .46846 L F
0 .535 .817 r
.55904 .46809 m .55991 .46791 L .55753 .46846 L F
.55904 .46809 m .56198 .46869 L .55991 .46791 L F
.498 .4 .674 r
.36133 .64392 m .36352 .64483 L .36265 .64246 L F
.722 .431 0 r
.28627 .6476 m .28735 .65127 L .28733 .64986 L F
0 0 .359 r
.28735 .65127 m .28803 .65375 L .28733 .64986 L F
.623 .534 .733 r
.34622 .58326 m .34378 .58658 L .34337 .58385 L F
0 0 0 r
.34247 .68672 m .34531 .68165 L .34338 .68175 L F
.518 .428 .693 r
.34531 .68165 m .34455 .67974 L .34338 .68175 L F
.34531 .68165 m .34718 .67974 L .34455 .67974 L F
.34531 .68165 m .34775 .68243 L .34718 .67974 L F
.594 .598 .826 r
.66702 .39795 m .66844 .3932 L .66571 .39618 L F
.66702 .39795 m .66967 .39709 L .66844 .3932 L F
.363 .754 .987 r
.72253 .35122 m .72172 .34914 L .7203 .35261 L F
.596 .397 .583 r
.33729 .57098 m .33997 .57089 L .34013 .56741 L F
.768 .995 .803 r
.34047 .56562 m .34013 .56741 L .34174 .56631 L F
.34047 .56562 m .33754 .56842 L .34013 .56741 L F
.396 .234 .54 r
.34013 .56741 m .34226 .56977 L .34174 .56631 L F
.34013 .56741 m .33997 .57089 L .34226 .56977 L F
.788 .331 0 r
.3826 .50725 m .3823 .50785 L .37968 .50572 L F
.724 .726 .203 r
.37208 .67605 m .37124 .67974 L .37271 .67912 L F
0 0 0 r
.37271 .67912 m .37124 .67974 L .36968 .68168 L F
.071 0 0 r
.38163 .66084 m .38052 .66063 L .37892 .66231 L F
.38163 .66084 m .38282 .66068 L .38052 .66063 L F
.525 .862 .593 r
.23296 .53548 m .23097 .53704 L .23407 .53435 L F
.99 .76 .495 r
.58397 .37401 m .58519 .37796 L .58543 .37534 L F
.953 .84 .695 r
.64578 .4199 m .64714 .41672 L .64586 .41548 L F
.888 .86 .807 r
.64714 .41672 m .64832 .41188 L .64586 .41548 L F
.829 .355 .043 r
.23598 .60462 m .23957 .60833 L .239 .60939 L F
.787 .43 .381 r
.56083 .4046 m .56098 .40215 L .55863 .40077 L F
0 .09 .62 r
.34869 .70528 m .35128 .70835 L .35101 .70743 L F
.736 .219 0 r
.35128 .70835 m .35156 .70996 L .35101 .70743 L F
.35128 .70835 m .35272 .70986 L .35156 .70996 L F
0 0 .037 r
.32872 .57423 m .32881 .57548 L .32913 .57209 L F
.32872 .57423 m .32775 .57633 L .32881 .57548 L F
.373 .378 .736 r
.47114 .5601 m .46984 .56332 L .46819 .55813 L F
.035 .259 .758 r
.34993 .51945 m .35059 .51778 L .34812 .5157 L F
.674 .208 .139 r
.34993 .51945 m .3479 .5209 L .35059 .51778 L F
.34993 .51945 m .35196 .52149 L .3479 .5209 L F
.774 .854 .91 r
.62202 .34927 m .62278 .35215 L .62051 .35306 L F
.694 .807 .935 r
.62605 .34964 m .62278 .35215 L .62202 .34927 L F
.828 .85 .864 r
.64076 .34234 m .63752 .3424 L .64089 .33918 L F
.794 .865 .901 r
.64394 .33961 m .64076 .34234 L .64089 .33918 L F
.836 .771 .79 r
.38124 .70882 m .38126 .70419 L .37903 .70694 L F
.906 .984 .746 r
.3554 .5796 m .3541 .57901 L .35651 .57561 L F
.822 .347 0 r
.2802 .63885 m .28248 .64143 L .27914 .64133 L F
.124 .668 .829 r
.27914 .64133 m .28248 .64143 L .28134 .64123 L F
.793 .44 0 r
.28248 .64143 m .28262 .64293 L .28134 .64123 L F
.28248 .64143 m .28342 .64395 L .28262 .64293 L F
0 0 .095 r
.42525 .58467 m .42478 .58591 L .42493 .58364 L F
.825 .864 .876 r
.6644 .37683 m .66317 .37904 L .66165 .37733 L F
.362 .136 .43 r
.32558 .60906 m .32527 .61178 L .32284 .61232 L F
.531 .262 .451 r
.32543 .61443 m .32284 .61232 L .32527 .61178 L F
.32543 .61443 m .32224 .61509 L .32284 .61232 L F
.755 .834 .376 r
.69721 .34133 m .69804 .33997 L .69703 .34224 L F
.899 .825 .357 r
.69786 .33778 m .69804 .33997 L .69721 .34133 L F
.361 .563 .914 r
.45033 .54718 m .45178 .54539 L .45144 .54572 L F
.271 .51 .9 r
.44928 .54858 m .45033 .54718 L .4474 .54615 L F
0 .373 .697 r
.4474 .54615 m .45033 .54718 L .44627 .54567 L F
.418 .473 .81 r
.44895 .54813 m .44627 .54567 L .45033 .54718 L F
.361 .563 .914 r
.45033 .54718 m .45144 .54572 L .44895 .54813 L F
.271 .51 .9 r
.44928 .54858 m .45033 .54718 L .44928 .54858 L F
.211 .423 .85 r
.44928 .54858 m .45255 .55086 L .45033 .54718 L F
.528 .443 .703 r
.44928 .54858 m .45005 .55157 L .45255 .55086 L F
.546 .542 .802 r
.37766 .66636 m .37892 .66231 L .3777 .66371 L F
.273 .626 .961 r
.36635 .60042 m .36877 .60112 L .36817 .60239 L F
.344 0 .085 r
.28077 .57075 m .27874 .57343 L .27576 .57448 L F
.754 .385 .357 r
.28112 .57254 m .28077 .57075 L .2832 .5702 L F
.28112 .57254 m .27874 .57343 L .28077 .57075 L F
.569 .219 .336 r
.27143 .57344 m .26993 .57636 L .26734 .57623 L F
.558 .208 .33 r
.27346 .57527 m .27143 .57344 L .27409 .57337 L F
.27346 .57527 m .26993 .57636 L .27143 .57344 L F
.147 0 0 r
.31482 .55833 m .31274 .5584 L .31015 .55807 L F
.363 0 0 r
.31717 .5574 m .31274 .5584 L .31482 .55833 L F
.166 0 .301 r
.23875 .57885 m .23562 .58297 L .236 .58039 L F
.977 .729 .492 r
.29653 .6206 m .29861 .62183 L .29709 .61837 L F
.431 .249 .532 r
.29861 .62183 m .30106 .6184 L .29709 .61837 L F
.29861 .62183 m .30085 .62144 L .30106 .6184 L F
0 0 .195 r
.29916 .62313 m .29861 .62183 L .29653 .6206 L F
.877 .883 .835 r
.37947 .61684 m .3784 .62108 L .38094 .62158 L F
.456 .366 .665 r
.3784 .62108 m .37933 .62524 L .38094 .62158 L F
0 0 0 r
.35154 .57597 m .35021 .57967 L .34889 .58067 L F
.34889 .58067 m .34947 .58084 L .34703 .5815 L F
.34889 .58067 m .35021 .57967 L .34947 .58084 L F
.686 .535 .676 r
.51567 .45514 m .51963 .45553 L .51704 .45861 L F
.519 .347 .589 r
.35006 .5995 m .34994 .60211 L .3473 .60276 L F
.416 .089 .3 r
.34994 .60211 m .34681 .6049 L .3473 .60276 L F
.801 .629 .668 r
.47731 .46205 m .47349 .46407 L .47382 .4621 L F
.744 .642 .747 r
.29998 .51529 m .30459 .5128 L .30333 .51224 L F
0 0 0 r
.30459 .5128 m .3058 .50872 L .30333 .51224 L F
.523 .902 .955 r
.36819 .66848 m .36466 .66889 L .36702 .66885 L F
.52 0 0 r
.36702 .66885 m .36953 .66909 L .36819 .66848 L F
.617 .544 .749 r
.39719 .49331 m .39792 .4971 L .39432 .49574 L F
.689 .979 .888 r
.30739 .52837 m .30833 .52662 L .31092 .52659 L F
.768 .633 .071 r
.31069 .52622 m .31092 .52659 L .30833 .52662 L F
.31069 .52622 m .31078 .52809 L .31092 .52659 L F
.651 .144 .027 r
.31092 .52659 m .31078 .52809 L .31457 .52821 L F
.844 .791 .8 r
.26451 .52408 m .26744 .52837 L .26979 .52274 L F
.633 .786 .955 r
.26665 .52804 m .26854 .52983 L .27096 .52877 L F
.26665 .52804 m .26854 .52983 L .27096 .52877 L F
.178 0 0 r
.28018 .52145 m .27833 .52159 L .2756 .52132 L F
.137 .683 .752 r
.28219 .52116 m .27833 .52159 L .28018 .52145 L F
0 0 .275 r
.34473 .59624 m .34521 .59837 L .34578 .59623 L F
0 0 .197 r
.56294 .39929 m .56098 .40215 L .56083 .4046 L F
.834 .793 .813 r
.64306 .42627 m .64373 .42968 L .64633 .42638 L F
.618 .414 .583 r
.46861 .48713 m .46983 .48972 L .4662 .4902 L F
.668 .543 .704 r
.4685 .48397 m .47151 .48772 L .46861 .48713 L F
.604 .446 .641 r
.47151 .48772 m .46983 .48972 L .46861 .48713 L F
.643 .12 0 r
.34775 .68243 m .35188 .6833 L .34978 .68429 L F
.459 0 0 r
.34978 .68429 m .35188 .6833 L .35389 .68436 L F
.646 .606 .795 r
.25537 .62465 m .25662 .62844 L .25961 .62699 L F
.56 .799 .988 r
.5384 .39162 m .53961 .39162 L .5388 .39194 L F
.608 .763 .954 r
.5388 .39194 m .54363 .39163 L .5434 .38947 L F
.56 .799 .988 r
.53961 .39162 m .54363 .39163 L .5388 .39194 L F
.489 .809 1 r
.54166 .39103 m .54363 .39163 L .53961 .39162 L F
.473 .396 .689 r
.54211 .39063 m .53961 .39162 L .5434 .38947 L F
.53961 .39162 m .53916 .39175 L .5434 .38947 L F
.54166 .39103 m .5388 .39194 L .54211 .39063 L F
.489 .809 1 r
.54166 .39103 m .53961 .39162 L .5384 .39162 L F
.473 .396 .689 r
.53961 .39162 m .5388 .39194 L .53916 .39175 L F
.524 .784 .992 r
.5384 .39162 m .5388 .39194 L .54166 .39103 L F
.346 .366 .739 r
.47017 .5561 m .46819 .55813 L .46725 .55411 L F
.355 .379 .748 r
.47017 .5561 m .47114 .5601 L .46819 .55813 L F
.198 0 0 r
.58559 .39653 m .58313 .39601 L .58163 .39592 L F
.647 .289 .351 r
.2275 .59577 m .22787 .59884 L .22584 .59622 L F
0 0 .322 r
.22973 .59682 m .2275 .59577 L .22924 .59411 L F
.22973 .59682 m .22787 .59884 L .2275 .59577 L F
.176 0 .241 r
.3511 .56919 m .34992 .56761 L .35107 .56707 L F
.3511 .56919 m .34935 .57037 L .34992 .56761 L F
.815 .862 .883 r
.65563 .33052 m .65121 .33184 L .65429 .329 L F
.837 .874 .87 r
.65871 .32733 m .65563 .33052 L .65429 .329 L F
.204 .22 .655 r
.62934 .41518 m .62781 .41779 L .62726 .41325 L F
.555 .67 .915 r
.62934 .41518 m .63125 .41721 L .62781 .41779 L F
.969 .667 .391 r
.39215 .53736 m .39276 .5416 L .3944 .54233 L F
.829 .376 0 r
.39371 .54271 m .3944 .54233 L .39276 .5416 L F
.39371 .54271 m .39529 .54411 L .3944 .54233 L F
.845 .403 .169 r
.34685 .50666 m .34497 .50641 L .34314 .50336 L F
.705 .863 .452 r
.34685 .50666 m .34599 .5078 L .34497 .50641 L F
.34619 .50769 m .3457 .50845 L .34599 .5078 L F
.202 .289 .73 r
.3457 .50845 m .34749 .50749 L .34599 .5078 L F
.803 .474 .433 r
.34749 .50749 m .34562 .50802 L .34599 .5078 L F
.65 .378 .493 r
.34314 .50336 m .34497 .50641 L .34277 .50574 L F
.675 .451 .574 r
.34599 .5078 m .34277 .50574 L .34497 .50641 L F
.34599 .5078 m .34213 .5084 L .34277 .50574 L F
0 0 .02 r
.34332 .50866 m .34213 .5084 L .34512 .50794 L F
.34513 .50808 m .34512 .50794 L .34599 .5078 L F
.34332 .50866 m .34512 .50794 L .34513 .50808 L F
.803 .474 .433 r
.34452 .50832 m .34394 .50846 L .34599 .5078 L F
.3445 .50833 m .34447 .50834 L .34452 .50832 L F
.34447 .50834 m .34394 .50846 L .34452 .50832 L F
.326 .758 .97 r
.34332 .50866 m .34527 .50905 L .34447 .50834 L F
.803 .474 .433 r
.3445 .50833 m .34332 .50866 L .34394 .50846 L F
.326 .758 .97 r
.34332 .50866 m .34447 .50834 L .34167 .50583 L F
.532 .584 .852 r
.34447 .50834 m .34513 .50818 L .3446 .50471 L F
.803 .474 .433 r
.34749 .50749 m .34572 .50943 L .3453 .5093 L F
.532 .584 .852 r
.34447 .50834 m .34527 .50905 L .34524 .50885 L F
.803 .474 .433 r
.34513 .50815 m .34524 .50885 L .3445 .50833 L F
.532 .584 .852 r
.3445 .50833 m .34524 .50885 L .34513 .50818 L F
.34447 .50834 m .34524 .50885 L .3445 .50833 L F
.803 .474 .433 r
.3445 .50833 m .34502 .50895 L .34332 .50866 L F
.34524 .50885 m .3453 .5093 L .3445 .50833 L F
.326 .758 .97 r
.34332 .50866 m .34488 .50807 L .34524 .50899 L F
.34332 .50866 m .34524 .50899 L .34527 .50905 L F
.803 .474 .433 r
.34502 .50895 m .3453 .5093 L .34332 .50866 L F
.54 .906 .962 r
.34527 .50905 m .34526 .50899 L .34524 .50885 L F
.803 .474 .433 r
.34749 .50749 m .3453 .5093 L .34513 .50815 L F
.54 .906 .962 r
.34524 .50885 m .34517 .50847 L .34516 .50833 L F
.34526 .50899 m .34517 .50847 L .34524 .50885 L F
.34516 .50833 m .34498 .50735 L .3446 .50471 L F
.34517 .50847 m .34498 .50735 L .34516 .50833 L F
.532 .584 .852 r
.34167 .50583 m .34447 .50834 L .3446 .50471 L F
.803 .474 .433 r
.34562 .50802 m .3445 .50833 L .34599 .5078 L F
.705 .863 .452 r
.34685 .50666 m .34619 .50769 L .34599 .5078 L F
.096 .65 .796 r
.37485 .63484 m .37747 .63475 L .37482 .63765 L F
.615 .804 .972 r
.60966 .35382 m .60725 .35489 L .60621 .35321 L F
.429 .863 .758 r
.33546 .66025 m .33679 .65991 L .3379 .65907 L F
.33546 .66025 m .33679 .65991 L .3379 .65907 L F
0 0 0 r
.26239 .5187 m .2637 .51797 L .26534 .51768 L F
.26239 .5187 m .26188 .51919 L .2637 .51797 L F
0 0 .341 r
.213 .59629 m .21296 .59207 L .212 .59263 L F
.213 .59629 m .21343 .5947 L .21296 .59207 L F
.526 .544 .817 r
.21636 .59947 m .2165 .5996 L .21668 .59977 L F
.213 .59629 m .2165 .5996 L .21636 .59947 L F
.77 .853 .406 r
.2165 .5996 m .21521 .6019 L .21627 .59939 L F
.875 .516 .366 r
.2172 .60137 m .21521 .6019 L .2165 .5996 L F
.77 .853 .406 r
.2165 .5996 m .21636 .59947 L .21686 .598 L F
.45 .518 .836 r
.21343 .5947 m .21639 .59933 L .21686 .598 L F
0 0 .085 r
.21686 .598 m .21668 .59977 L .2165 .5996 L F
.45 .518 .836 r
.21639 .59933 m .21668 .59977 L .21686 .598 L F
.77 .853 .406 r
.21639 .59933 m .21627 .59939 L .21651 .59882 L F
0 .263 .767 r
.21636 .59947 m .21639 .59933 L .21343 .5947 L F
.77 .853 .406 r
.21636 .59947 m .21635 .59946 L .21639 .59933 L F
.21635 .59946 m .21627 .59939 L .21639 .59933 L F
.374 .23 .554 r
.21695 .59911 m .21521 .6019 L .21707 .60062 L F
.77 .853 .406 r
.21636 .59947 m .21651 .59882 L .21686 .598 L F
.374 .23 .554 r
.21686 .598 m .21651 .59882 L .21695 .59911 L F
0 .263 .767 r
.21365 .59691 m .21636 .59947 L .21558 .59819 L F
.21636 .59947 m .21668 .59977 L .21639 .59933 L F
.374 .23 .554 r
.21651 .59882 m .21521 .6019 L .21695 .59911 L F
0 .263 .767 r
.213 .59629 m .21365 .59691 L .21343 .5947 L F
.21365 .59691 m .21558 .59819 L .21343 .5947 L F
.519 .384 .637 r
.3209 .61852 m .32153 .62165 L .31858 .6225 L F
.59 .35 .52 r
.32153 .62165 m .31795 .62442 L .31858 .6225 L F
0 .015 .556 r
.21151 .58996 m .21296 .59207 L .21238 .58816 L F
.058 .061 .544 r
.212 .59263 m .21296 .59207 L .21151 .58996 L F
.678 .786 .931 r
.44474 .46609 m .44075 .46531 L .44327 .46422 L F
.593 .717 .93 r
.44572 .46314 m .44474 .46609 L .44327 .46422 L F
.44572 .46314 m .44768 .46523 L .44474 .46609 L F
.271 .299 .707 r
.24478 .55803 m .24548 .56148 L .24632 .55967 L F
.804 .661 .705 r
.52412 .43571 m .52581 .43936 L .52192 .43879 L F
.801 .676 .726 r
.52192 .43879 m .52581 .43936 L .52329 .44259 L F
.731 .571 .674 r
.52581 .43936 m .52529 .44188 L .52329 .44259 L F
0 0 .047 r
.30032 .63684 m .2988 .63805 L .30106 .63452 L F
0 0 .207 r
.29817 .6406 m .2988 .63805 L .30032 .63684 L F
.529 .861 .995 r
.62624 .36758 m .6276 .36842 L .6244 .36841 L F
.72 .333 .317 r
.62601 .37043 m .6276 .36842 L .62624 .36758 L F
.62601 .37043 m .62985 .37078 L .6276 .36842 L F
.33 .01 .263 r
.30284 .64773 m .30653 .64497 L .30716 .64612 L F
0 0 0 r
.30173 .65377 m .3032 .64939 L .30273 .65248 L F
0 0 .355 r
.30393 .6518 m .30273 .65248 L .30287 .65154 L F
.30393 .6518 m .30287 .65154 L .3032 .64939 L F
0 0 .233 r
.3036 .65176 m .30296 .64773 L .30016 .65132 L F
.30393 .6518 m .30353 .65012 L .3036 .65176 L F
.053 0 0 r
.30284 .64773 m .30349 .64925 L .3032 .64939 L F
0 0 .233 r
.30393 .6518 m .3032 .64939 L .30296 .64773 L F
.30353 .65012 m .30296 .64773 L .3036 .65176 L F
.026 .075 .576 r
.30519 .65211 m .30393 .6518 L .3027 .6511 L F
.30613 .6525 m .30393 .6518 L .30519 .65211 L F
.053 0 0 r
.30349 .64925 m .30357 .64945 L .3035 .64943 L F
.30349 .64925 m .3035 .64943 L .3032 .64939 L F
.30284 .64773 m .30716 .64612 L .30357 .64945 L F
.483 .474 .772 r
.46397 .54416 m .46276 .54861 L .46181 .54453 L F
.46397 .54416 m .46492 .54798 L .46276 .54861 L F
.481 .467 .765 r
.46492 .54798 m .46597 .55039 L .46276 .54861 L F
.827 .803 .828 r
.56689 .38827 m .56838 .39116 L .56672 .38951 L F
.913 .707 .611 r
.56838 .39116 m .56505 .39256 L .56672 .38951 L F
.56838 .39116 m .56787 .39429 L .56505 .39256 L F
.649 .727 .906 r
.57202 .38979 m .56838 .39116 L .56689 .38827 L F
.538 .535 .8 r
.27845 .53581 m .27651 .53872 L .27635 .53549 L F
.461 .836 .99 r
.27451 .536 m .27845 .53581 L .27635 .53549 L F
.669 .954 .95 r
.2756 .52132 m .27415 .52096 L .27355 .52267 L F
.25 .525 .914 r
.27355 .52267 m .27415 .52096 L .27234 .52075 L F
.074 0 0 r
.32705 .53835 m .3256 .54051 L .32366 .54123 L F
.74 .355 .323 r
.33012 .54101 m .32705 .53835 L .3284 .53623 L F
.33012 .54101 m .3256 .54051 L .32705 .53835 L F
.92 .937 .799 r
.39803 .60105 m .39885 .60317 L .40086 .59999 L F
.962 .901 .715 r
.39627 .60456 m .39885 .60317 L .39803 .60105 L F
.39627 .60456 m .39763 .60531 L .39885 .60317 L F
.232 .035 .394 r
.31126 .62446 m .3094 .62502 L .31155 .62175 L F
.322 .286 .662 r
.31126 .62446 m .31189 .62775 L .3094 .62502 L F
.626 .403 .559 r
.46374 .49383 m .46486 .49618 L .46094 .49662 L F
.516 .361 .61 r
.4662 .4902 m .46622 .49272 L .46374 .49383 L F
.624 .473 .657 r
.46622 .49272 m .46486 .49618 L .46374 .49383 L F
.765 .697 .787 r
.21153 .60218 m .21203 .60378 L .21438 .60299 L F
.419 .821 .981 r
.21229 .60231 m .21521 .6019 L .21438 .60299 L F
.21229 .60231 m .21521 .6019 L .21438 .60299 L F
.729 .651 .771 r
.3682 .63764 m .36974 .64134 L .37224 .63862 L F
.757 .644 .736 r
.51963 .45553 m .51939 .45816 L .51704 .45861 L F
.69 .408 .49 r
.51704 .45861 m .51939 .45816 L .51952 .46092 L F
.678 .283 .291 r
.51939 .45816 m .5219 .46043 L .51952 .46092 L F
0 0 .024 r
.36149 .56093 m .36214 .56153 L .36251 .55845 L F
.36149 .56093 m .36098 .5634 L .36214 .56153 L F
0 0 0 r
.30493 .63969 m .30546 .6383 L .30272 .6412 L F
.607 .184 .214 r
.30756 .64016 m .30546 .6383 L .30493 .63969 L F
.102 .213 .694 r
.30614 .63754 m .30546 .6383 L .30756 .64016 L F
.553 .468 .713 r
.72372 .3224 m .72093 .32664 L .72068 .32408 L F
.268 .544 .923 r
.38969 .67088 m .38994 .67319 L .38841 .6712 L F
.38969 .67088 m .38994 .67319 L .38841 .6712 L F
0 0 0 r
.29493 .65731 m .29907 .65468 L .29719 .65621 L F
.557 .138 .203 r
.29719 .65621 m .29907 .65468 L .30046 .65634 L F
.269 .766 .716 r
.29907 .65468 m .30173 .65377 L .30046 .65634 L F
.771 .681 .764 r
.24154 .60975 m .24289 .61276 L .23917 .61222 L F
.062 .263 .755 r
.2437 .61124 m .24289 .61276 L .24154 .60975 L F
.185 .428 .86 r
.2437 .61124 m .24588 .61451 L .24289 .61276 L F
.585 .391 .585 r
.35537 .54789 m .3526 .55139 L .35262 .54809 L F
.471 .657 .942 r
.61928 .43871 m .61993 .43659 L .61799 .43519 L F
.61928 .43871 m .62156 .43837 L .61993 .43659 L F
0 0 .318 r
.39666 .5493 m .39611 .54823 L .39557 .54669 L F
.39666 .5493 m .39755 .55111 L .39611 .54823 L F
.601 .497 .708 r
.4675 .48032 m .4685 .48397 L .46566 .48437 L F
.617 .93 .694 r
.23203 .5458 m .23174 .54673 L .23355 .54405 L F
.23203 .5458 m .2308 .54713 L .23174 .54673 L F
.418 .003 .142 r
.29004 .56762 m .28863 .56984 L .28592 .56984 L F
.267 0 .053 r
.29234 .56708 m .28863 .56984 L .29004 .56762 L F
.564 .809 .991 r
.62989 .36243 m .6324 .36234 L .62847 .36172 L F
.815 .692 .729 r
.62948 .36489 m .6324 .36234 L .62989 .36243 L F
.225 0 .343 r
.32529 .57696 m .32284 .58037 L .32455 .57946 L F
.049 .04 .524 r
.32284 .58037 m .32422 .58118 L .32455 .57946 L F
.32284 .58037 m .32324 .5832 L .32422 .58118 L F
.605 .627 .847 r
.43744 .46723 m .43419 .4647 L .43692 .46383 L F
.665 .657 .833 r
.44075 .46531 m .43744 .46723 L .43692 .46383 L F
.65 .418 .554 r
.33336 .60194 m .33026 .59957 L .33361 .59947 L F
.33336 .60194 m .33022 .60233 L .33026 .59957 L F
.998 .848 .552 r
.61161 .44745 m .61336 .44556 L .61245 .44438 L F
.61161 .44745 m .6126 .44883 L .61336 .44556 L F
.408 .156 .416 r
.35557 .59551 m .35255 .59864 L .35296 .59621 L F
0 0 0 r
.60629 .46088 m .61007 .45856 L .60928 .46026 L F
.61007 .45856 m .61212 .45446 L .61092 .45625 L F
.693 .785 .308 r
.60928 .46026 m .61007 .45856 L .61092 .45625 L F
0 0 0 r
.61816 .37907 m .61876 .37828 L .62132 .37699 L F
.602 .557 .777 r
.35489 .71173 m .35728 .71045 L .35272 .70986 L F
.35489 .71173 m .35744 .71119 L .35728 .71045 L F
.839 .382 0 r
.35489 .71173 m .3588 .71755 L .35744 .71119 L F
.746 .907 .949 r
.36063 .55443 m .35825 .55609 L .36062 .55468 L F
.36063 .55443 m .35672 .55601 L .35825 .55609 L F
.982 .692 .369 r
.32955 .64705 m .3295 .64446 L .32821 .64371 L F
.768 .857 .917 r
.67753 .38744 m .68087 .38738 L .67944 .38628 L F
.765 .808 .887 r
.68087 .38738 m .68265 .3832 L .67944 .38628 L F
.68087 .38738 m .68421 .38503 L .68265 .3832 L F
.959 .857 .444 r
.39971 .55676 m .39888 .55983 L .39976 .56058 L F
.798 .413 0 r
.39888 .55983 m .40066 .56323 L .39976 .56058 L F
.862 .716 .7 r
.69891 .33037 m .69728 .33247 L .69509 .33238 L F
.978 .897 .549 r
.40229 .58287 m .40324 .58042 L .40164 .58209 L F
.992 .87 .534 r
.40164 .58209 m .40324 .58042 L .40238 .57941 L F
.619 .458 .642 r
.56649 .42693 m .56693 .43097 L .56573 .42697 L F
.944 .625 .402 r
.56693 .43097 m .56639 .4317 L .56573 .42697 L F
.773 .84 .903 r
.63691 .3959 m .63271 .3969 L .63584 .39491 L F
.693 .866 .964 r
.63832 .39358 m .63691 .3959 L .63584 .39491 L F
.63832 .39358 m .63962 .39459 L .63691 .3959 L F
.559 .486 .73 r
.63967 .39773 m .63691 .3959 L .63962 .39459 L F
.754 .894 .494 r
.2353 .5404 m .23482 .54269 L .23683 .54128 L F
.2353 .5404 m .23355 .54405 L .23482 .54269 L F
.913 .541 .104 r
.60245 .42235 m .60182 .41997 L .60057 .41865 L F
.995 .754 .424 r
.52669 .41617 m .52773 .41958 L .52416 .41945 L F
.915 .887 .791 r
.52773 .41958 m .52415 .42202 L .52416 .41945 L F
.52773 .41958 m .52557 .4233 L .52415 .42202 L F
0 0 0 r
.25065 .55531 m .25071 .55573 L .25266 .554 L F
.25065 .55531 m .24857 .55664 L .25071 .55573 L F
.99 .851 .486 r
.40119 .58745 m .40229 .59012 L .40264 .58535 L F
.978 .915 .657 r
.40118 .59253 m .40229 .59012 L .40119 .58745 L F
.907 .8 .73 r
.64248 .42294 m .6412 .4268 L .63864 .42421 L F
.63909 .42391 m .63864 .42421 L .63851 .42408 L F
.64248 .42294 m .63864 .42421 L .63909 .42391 L F
.64248 .42294 m .63909 .42391 L .64129 .42462 L F
.63909 .42391 m .63851 .42408 L .64129 .42462 L F
.64248 .42294 m .64129 .42462 L .63961 .4233 L F
.882 .814 .777 r
.64129 .42462 m .64518 .42257 L .64012 .42323 L F
.6398 .42345 m .64012 .42323 L .63961 .4233 L F
.64129 .42462 m .64012 .42323 L .6398 .42345 L F
.942 .874 .741 r
.52415 .42202 m .52557 .4233 L .52387 .42648 L F
.479 .113 .267 r
.46676 .58299 m .46323 .58561 L .4636 .58391 L F
.637 .404 .548 r
.36976 .58042 m .37242 .58276 L .36926 .5816 L F
.36976 .58042 m .37269 .58014 L .37242 .58276 L F
.555 .195 .313 r
.42961 .53807 m .42639 .54052 L .42409 .53954 L F
.533 .415 .665 r
.45776 .46479 m .45525 .4682 L .45385 .46453 L F
.45776 .46479 m .45779 .46755 L .45525 .4682 L F
.287 .782 .881 r
.31212 .53075 m .30976 .53054 L .30842 .53114 L F
.959 .886 .716 r
.31078 .52809 m .31212 .53075 L .31457 .52821 L F
.31078 .52809 m .30976 .53054 L .31212 .53075 L F
.249 .332 .754 r
.3256 .54051 m .32562 .54537 L .32556 .54319 L F
.3256 .54051 m .32692 .54442 L .32562 .54537 L F
.976 .845 .648 r
.32562 .54537 m .32317 .54624 L .32556 .54319 L F
.765 .969 .926 r
.3177 .53746 m .31735 .53971 L .31954 .53843 L F
.819 .707 .172 r
.31517 .53949 m .31504 .53817 L .31544 .53443 L F
.661 .973 .85 r
.31517 .53949 m .31442 .53972 L .31504 .53817 L F
.31517 .53949 m .3135 .53909 L .31442 .53972 L F
.765 .969 .926 r
.3177 .53746 m .31442 .53972 L .31735 .53971 L F
.272 .76 .673 r
.55735 .4075 m .55166 .40971 L .5543 .40931 L F
.921 .957 .791 r
.55768 .4062 m .55735 .4075 L .5543 .40931 L F
.315 0 0 r
.36307 .55409 m .36063 .55443 L .36064 .55468 L F
.36307 .55409 m .36129 .55565 L .36063 .55443 L F
0 0 .314 r
.36063 .55443 m .36129 .55565 L .36055 .55306 L F
.36063 .55443 m .36055 .55306 L .36026 .55201 L F
.315 0 0 r
.36064 .55468 m .36063 .55443 L .36062 .55468 L F
.479 0 0 r
.38582 .67005 m .38803 .67143 L .38561 .67337 L F
.38582 .67005 m .38841 .6712 L .38803 .67143 L F
.276 0 0 r
.2669 .63434 m .27114 .63504 L .26894 .63487 L F
.402 0 0 r
.26894 .63487 m .27114 .63504 L .27377 .63624 L F
.85 .648 .63 r
.3747 .71203 m .37651 .70999 L .37279 .71072 L F
.92 .937 .799 r
.39803 .60105 m .40086 .59999 L .39931 .59925 L F
0 .082 .628 r
.3625 .54335 m .36186 .54511 L .36068 .54137 L F
.135 0 0 r
.36186 .54511 m .36207 .54524 L .36487 .54483 L F
0 0 .313 r
.3625 .54335 m .36207 .54524 L .36186 .54511 L F
.264 0 .222 r
.63271 .3969 m .63053 .39813 L .62954 .40051 L F
.891 .723 .666 r
.59441 .40988 m .59645 .41038 L .59498 .40665 L F
.869 .507 .362 r
.59478 .41213 m .59645 .41038 L .59441 .40988 L F
.922 .602 .418 r
.59672 .41266 m .59645 .41038 L .59478 .41213 L F
.583 .533 .764 r
.43793 .54177 m .43809 .5419 L .44028 .54144 L F
.43809 .5419 m .44165 .54491 L .44028 .54144 L F
.49 .451 .741 r
.44165 .54491 m .44299 .54061 L .44028 .54144 L F
.246 0 0 r
.44299 .54061 m .44207 .54105 L .44028 .54144 L F
.44207 .54105 m .43907 .54247 L .44028 .54144 L F
.074 0 0 r
.43907 .54247 m .43793 .54177 L .44028 .54144 L F
.43907 .54247 m .43662 .54348 L .43793 .54177 L F
.838 .7 .711 r
.2802 .63885 m .27914 .64133 L .2773 .6374 L F
.727 .72 .844 r
.50646 .45946 m .50767 .46096 L .50369 .46151 L F
.58 .189 .265 r
.50369 .46151 m .50767 .46096 L .50639 .46359 L F
.701 .437 .522 r
.50767 .46096 m .51029 .4641 L .50639 .46359 L F
.50767 .46096 m .51035 .46162 L .51029 .4641 L F
.706 .42 .488 r
.53001 .45847 m .53222 .46099 L .53007 .46084 L F
.736 .98 .749 r
.24948 .56506 m .24904 .56584 L .2488 .56673 L F
.457 .817 .996 r
.2488 .56673 m .24929 .56592 L .25316 .56712 L F
.602 .863 .992 r
.25316 .56712 m .24929 .56592 L .25385 .56519 L F
.102 .147 .623 r
.2488 .56673 m .24929 .56591 L .24948 .56506 L F
.611 .86 .99 r
.25385 .56519 m .24932 .56581 L .24948 .56506 L F
.102 .147 .623 r
.24929 .56591 m .2496 .56541 L .24948 .56506 L F
.611 .86 .99 r
.24932 .56581 m .24904 .56584 L .24948 .56506 L F
.602 .863 .992 r
.24929 .56592 m .24904 .56584 L .24932 .56581 L F
.24929 .56592 m .24932 .56581 L .25385 .56519 L F
.102 .147 .623 r
.24929 .56592 m .25036 .56776 L .2496 .56541 L F
.2488 .56673 m .24905 .56689 L .24929 .56592 L F
.24905 .56689 m .25036 .56776 L .24929 .56592 L F
.457 .817 .996 r
.2488 .56673 m .24904 .56584 L .24929 .56592 L F
.602 .863 .992 r
.25316 .56712 m .25385 .56519 L .25551 .5666 L F
.76 .994 .871 r
.25385 .56519 m .25316 .56712 L .25551 .5666 L F
.25385 .56519 m .25036 .56776 L .25316 .56712 L F
0 0 .088 r
.39944 .48758 m .39998 .48801 L .39991 .48436 L F
0 0 .173 r
.39991 .48436 m .39998 .48801 L .40251 .48386 L F
.199 0 0 r
.55666 .38819 m .55391 .38766 L .55791 .38802 L F
.072 0 0 r
.55391 .38766 m .55725 .38798 L .55791 .38802 L F
.583 .94 .803 r
.55791 .38802 m .55725 .38798 L .55968 .3863 L F
0 0 .146 r
.55791 .38802 m .55914 .38852 L .55666 .38819 L F
.55791 .38802 m .55968 .3863 L .55914 .38852 L F
0 .429 .706 r
.34638 .49712 m .34791 .49756 L .34391 .49649 L F
.107 0 0 r
.34638 .49712 m .35048 .49772 L .34791 .49756 L F
.213 0 0 r
.32929 .5633 m .32753 .56301 L .32483 .56238 L F
.295 .771 .929 r
.33136 .56314 m .32753 .56301 L .32929 .5633 L F
.337 .341 .716 r
.32929 .5633 m .33236 .56605 L .33136 .56314 L F
.943 .671 .494 r
.61035 .43817 m .61231 .44186 L .61194 .43935 L F
.803 .727 .781 r
.64465 .42452 m .64633 .42638 L .64518 .42257 L F
.834 .793 .813 r
.64306 .42627 m .64633 .42638 L .64465 .42452 L F
.227 .099 .489 r
.36181 .52895 m .36371 .53051 L .36353 .52769 L F
.36181 .52895 m .36185 .53209 L .36371 .53051 L F
.481 .786 .998 r
.29889 .67007 m .29496 .66955 L .29771 .66608 L F
.208 0 .081 r
.29554 .67332 m .29889 .67007 L .29747 .67213 L F
.403 .41 .753 r
.30082 .66913 m .29889 .67007 L .29771 .66608 L F
0 0 0 r
.29747 .67213 m .29889 .67007 L .30082 .66913 L F
.715 .667 .801 r
.46585 .47123 m .46885 .469 L .46983 .47156 L F
.733 .556 .653 r
.46585 .47123 m .46983 .47156 L .4698 .47438 L F
.687 .669 .826 r
.46885 .469 m .47253 .47111 L .46983 .47156 L F
.688 .519 .652 r
.46983 .47156 m .47253 .47111 L .4698 .47438 L F
.744 .83 .917 r
.62051 .35306 m .61683 .35296 L .61913 .35147 L F
.774 .854 .91 r
.62202 .34927 m .62051 .35306 L .61913 .35147 L F
.687 .591 .744 r
.46576 .47355 m .46458 .47834 L .46335 .4748 L F
.46576 .47355 m .4672 .47764 L .46458 .47834 L F
.571 .736 .953 r
.38751 .51232 m .39069 .51357 L .39016 .5116 L F
.389 .214 .519 r
.24027 .57614 m .23875 .57885 L .2384 .57686 L F
.147 .309 .771 r
.44576 .56715 m .44973 .5689 L .45002 .56758 L F
.064 0 .046 r
.45301 .56475 m .45002 .56758 L .45216 .56649 L F
.222 0 .258 r
.45002 .56758 m .44973 .5689 L .45216 .56649 L F
0 .47 .853 r
.34876 .51181 m .35058 .51259 L .34832 .51089 L F
.57 .875 .579 r
.29695 .61826 m .29318 .62204 L .29395 .62117 L F
.739 .834 .38 r
.29279 .62392 m .29395 .62117 L .29318 .62204 L F
0 0 0 r
.37784 .49895 m .3774 .49899 L .37923 .49883 L F
.796 .753 .236 r
.37784 .49895 m .37713 .50122 L .3774 .49899 L F
.58 .04 0 r
.3774 .49899 m .38047 .49962 L .37923 .49883 L F
0 0 .247 r
.37766 .49904 m .37929 .49908 L .38047 .49962 L F
.3774 .49899 m .37763 .499 L .37766 .49904 L F
.37763 .499 m .37929 .49908 L .37766 .49904 L F
.559 .866 .996 r
.37713 .50122 m .37452 .50058 L .37717 .49968 L F
.796 .753 .236 r
.37777 .49919 m .37711 .50219 L .37713 .50122 L F
.37778 .49921 m .37703 .50255 L .37777 .49919 L F
.37784 .49895 m .37778 .49921 L .37777 .49919 L F
0 0 .247 r
.3774 .49899 m .37713 .50122 L .37929 .49908 L F
.559 .866 .996 r
.37713 .50122 m .37717 .49968 L .37929 .49897 L F
.796 .753 .236 r
.37711 .50219 m .37703 .50255 L .37713 .50122 L F
0 .188 .664 r
.59098 .39443 m .59368 .39664 L .59133 .39506 L F
.388 .701 .983 r
.59368 .39664 m .59524 .39533 L .59133 .39506 L F
.59368 .39664 m .59671 .39692 L .59524 .39533 L F
.543 .251 .421 r
.29817 .56561 m .29676 .56405 L .29903 .56445 L F
.29817 .56561 m .29525 .5668 L .29676 .56405 L F
0 .139 .683 r
.40275 .5316 m .40331 .53038 L .40129 .52824 L F
0 .109 .66 r
.40275 .5316 m .40489 .53403 L .40331 .53038 L F
.834 .638 .637 r
.38604 .69151 m .39026 .68933 L .38901 .68891 L F
.38604 .69151 m .3905 .69316 L .39026 .68933 L F
.881 .98 .831 r
.38901 .68891 m .39026 .68933 L .39279 .68634 L F
.428 .777 .997 r
.69765 .32631 m .70064 .32596 L .70146 .32705 L F
.861 .966 .866 r
.70146 .32705 m .70358 .32275 L .70467 .32442 L F
.70146 .32705 m .70064 .32596 L .70358 .32275 L F
.004 .383 .844 r
.60305 .36094 m .60317 .36201 L .60331 .36061 L F
.777 .558 .603 r
.60509 .36446 m .60886 .36706 L .60515 .36365 L F
0 0 .566 r
.60317 .36201 m .60535 .36534 L .60453 .36344 L F
.681 .97 .774 r
.60535 .36534 m .60284 .36769 L .60492 .3665 L F
.708 .674 .815 r
.60331 .36061 m .60535 .36534 L .60515 .36365 L F
.777 .558 .603 r
.60492 .3665 m .60515 .36365 L .60535 .36534 L F
.60492 .3665 m .6063 .3667 L .60509 .36446 L F
.6063 .3667 m .60886 .36706 L .60509 .36446 L F
0 0 .566 r
.60326 .36111 m .60453 .36344 L .60331 .36061 L F
.60317 .36201 m .60453 .36344 L .60326 .36111 L F
.76 .78 .869 r
.46296 .46102 m .4673 .45713 L .46724 .46115 L F
.895 .897 .821 r
.46797 .45678 m .46724 .46115 L .4673 .45713 L F
.46797 .45678 m .46962 .45782 L .46724 .46115 L F
.564 .391 .605 r
.46962 .45782 m .47021 .46055 L .46724 .46115 L F
.594 .626 .853 r
.31954 .53843 m .32105 .54183 L .32366 .54123 L F
.439 .413 .734 r
.3388 .60645 m .34075 .60569 L .33995 .60221 L F
.63 .344 .466 r
.3373 .60773 m .34075 .60569 L .3388 .60645 L F
.701 .797 .924 r
.57592 .45786 m .57988 .45839 L .57852 .45657 L F
.431 .33 .639 r
.57592 .45786 m .5786 .45991 L .57988 .45839 L F
.849 .836 .833 r
.57852 .45657 m .57988 .45839 L .58245 .45516 L F
.569 .561 .805 r
.58267 .46287 m .58524 .46214 L .58373 .45917 L F
.04 0 0 r
.57875 .45973 m .58315 .45769 L .57988 .45839 L F
.57903 .4597 m .58315 .45769 L .57875 .45973 L F
.666 .538 .699 r
.58245 .45516 m .57988 .45839 L .58315 .45769 L F
.849 .836 .833 r
.57852 .45657 m .58245 .45516 L .58111 .4554 L F
.04 0 0 r
.58297 .45778 m .58152 .45906 L .58315 .45769 L F
.5786 .45991 m .58152 .45906 L .58297 .45778 L F
.5786 .45991 m .57903 .4597 L .57875 .45973 L F
.584 .918 .97 r
.57717 .45596 m .57852 .45657 L .58111 .4554 L F
.57717 .45596 m .58111 .4554 L .57979 .45528 L F
.62 .629 .838 r
.57937 .45692 m .58152 .45906 L .5786 .45991 L F
.57979 .45528 m .58033 .45646 L .57937 .45692 L F
.58033 .45646 m .58152 .45906 L .57937 .45692 L F
.817 .714 .751 r
.5787 .46264 m .58267 .46287 L .58152 .45906 L F
.5787 .46264 m .58152 .45906 L .5786 .45991 L F
.217 0 0 r
.5786 .45991 m .58152 .45906 L .58007 .46106 L F
.705 .671 .815 r
.58179 .45532 m .58152 .45906 L .57979 .45528 L F
.969 .879 .495 r
.58036 .4601 m .58152 .45906 L .58179 .45532 L F
.58007 .46106 m .58152 .45906 L .58036 .4601 L F
.569 .561 .805 r
.58267 .46287 m .58373 .45917 L .58226 .45934 L F
.415 .768 .995 r
.58179 .45532 m .58315 .45769 L .58152 .45906 L F
.569 .561 .805 r
.58267 .46287 m .58179 .45532 L .58152 .45906 L F
.969 .879 .495 r
.58007 .46106 m .58163 .45583 L .58248 .46024 L F
.58163 .45583 m .58179 .45532 L .58185 .45573 L F
.569 .561 .805 r
.58226 .45934 m .58373 .45917 L .58179 .45532 L F
.969 .879 .495 r
.58163 .45583 m .58185 .45573 L .58248 .46024 L F
0 0 0 r
.30264 .56035 m .30004 .56128 L .30238 .56062 L F
.511 0 0 r
.30283 .56014 m .30264 .56035 L .30536 .56118 L F
.404 .452 .797 r
.30433 .55858 m .30531 .56105 L .30732 .56004 L F
.30531 .56105 m .30536 .56118 L .30732 .56004 L F
.30433 .55858 m .30732 .56004 L .30679 .55854 L F
.342 .245 .598 r
.30679 .55854 m .30732 .56004 L .30911 .55918 L F
.30679 .55854 m .30732 .56004 L .30911 .55918 L F
.105 0 0 r
.30472 .55996 m .30896 .55921 L .30732 .56004 L F
.30896 .55921 m .30911 .55918 L .30732 .56004 L F
.214 .737 .836 r
.30264 .56035 m .30732 .56004 L .30536 .56118 L F
0 0 0 r
.30264 .56035 m .30238 .56062 L .30472 .55996 L F
.511 0 0 r
.30051 .55919 m .30264 .56035 L .30283 .56014 L F
.967 .748 .311 r
.41433 .58988 m .41425 .59271 L .41348 .59138 L F
.935 .805 .345 r
.41433 .58988 m .41386 .58876 L .41423 .58598 L F
.934 .801 .338 r
.41433 .58988 m .41348 .59138 L .41386 .58876 L F
.558 .191 .301 r
.59755 .46222 m .59699 .46388 L .59427 .46368 L F
.101 0 .121 r
.59965 .46187 m .59755 .46222 L .60078 .46089 L F
.59965 .46187 m .59699 .46388 L .59755 .46222 L F
.422 .061 .244 r
.30495 .54388 m .30354 .54682 L .301 .54728 L F
.531 .518 .786 r
.30495 .54388 m .3067 .54141 L .30467 .54273 L F
.30495 .54388 m .30734 .54355 L .3067 .54141 L F
0 0 0 r
.3067 .54141 m .30495 .54388 L .30734 .54355 L F
.104 0 .083 r
.30554 .54568 m .30495 .54388 L .30734 .54355 L F
.30554 .54568 m .30354 .54682 L .30495 .54388 L F
0 0 0 r
.3067 .54141 m .30438 .54509 L .30495 .54388 L F
.859 .965 .638 r
.39073 .61846 m .39302 .61545 L .39303 .61493 L F
.639 .81 .965 r
.334 .5466 m .33824 .54813 L .33669 .5459 L F
0 .036 .568 r
.33824 .54813 m .33883 .54308 L .33669 .5459 L F
.33824 .54813 m .33973 .54654 L .33883 .54308 L F
.878 .975 .668 r
.69345 .32745 m .69348 .32896 L .69137 .32981 L F
0 0 .361 r
.69348 .32896 m .69509 .33238 L .69444 .3306 L F
.69348 .32896 m .69444 .3306 L .69137 .32981 L F
.615 .049 0 r
.26414 .61876 m .26655 .62054 L .26823 .62069 L F
.61 .941 .946 r
.26823 .62069 m .26828 .61952 L .27073 .62011 L F
.26823 .62069 m .26655 .62054 L .26828 .61952 L F
.298 .787 .891 r
.32826 .52106 m .33232 .51978 L .32827 .51902 L F
.32874 .52091 m .33168 .52099 L .33232 .51978 L F
.32885 .52105 m .33168 .52099 L .32874 .52091 L F
.512 0 0 r
.33108 .52449 m .33211 .52517 L .32953 .52444 L F
.3338 .52457 m .33211 .52517 L .33108 .52449 L F
.593 .135 .135 r
.33631 .52495 m .33465 .52753 L .33211 .52517 L F
.187 .168 .604 r
.33211 .52517 m .33465 .52753 L .33453 .52679 L F
.593 .135 .135 r
.33631 .52495 m .33211 .52517 L .3338 .52457 L F
.187 .168 .604 r
.33211 .52517 m .33453 .52679 L .33385 .5226 L F
.298 .787 .891 r
.32826 .52106 m .32885 .52105 L .32874 .52091 L F
.32826 .52106 m .33065 .52064 L .33168 .52099 L F
.465 .502 .812 r
.33006 .52263 m .33211 .52517 L .33065 .52064 L F
.32953 .52444 m .33199 .52514 L .33006 .52263 L F
.33199 .52514 m .33211 .52517 L .33006 .52263 L F
.953 .664 .453 r
.33488 .5202 m .33232 .51978 L .33168 .52099 L F
.259 0 0 r
.36352 .64483 m .36726 .6449 L .3652 .64299 L F
.898 .965 .823 r
.67127 .33175 m .6693 .33608 L .67218 .33302 L F
.838 .975 .88 r
.67218 .33302 m .67446 .32911 L .67127 .33175 L F
.67218 .33302 m .67529 .33006 L .67446 .32911 L F
.758 .706 .803 r
.34095 .52137 m .33488 .5202 L .33743 .51833 L F
.34095 .52137 m .33645 .52231 L .33488 .5202 L F
0 0 .468 r
.33975 .51723 m .34095 .52137 L .33743 .51833 L F
.34032 .5192 m .34122 .52067 L .34095 .52137 L F
.33975 .51723 m .34122 .52067 L .34032 .5192 L F
.975 .898 .68 r
.34156 .51618 m .33975 .51723 L .34057 .51455 L F
.844 .473 .349 r
.34156 .51618 m .34149 .51909 L .33975 .51723 L F
.032 .405 .857 r
.34373 .52155 m .34149 .51909 L .34492 .52057 L F
.34373 .52155 m .34461 .52122 L .34149 .51909 L F
.805 .533 .528 r
.33975 .51723 m .33869 .51478 L .34057 .51455 L F
.33975 .51723 m .33693 .51717 L .33869 .51478 L F
.762 .831 .906 r
.33975 .51723 m .33743 .51833 L .33693 .51717 L F
.639 .506 .685 r
.34149 .51909 m .34122 .52067 L .33975 .51723 L F
.34149 .51909 m .34461 .52122 L .34122 .52067 L F
.705 .656 .798 r
.33808 .51613 m .34473 .51867 L .34161 .51581 L F
.3416 .51747 m .34 .52121 L .34473 .51867 L F
.595 .949 .842 r
.34452 .51848 m .34385 .51868 L .34161 .51581 L F
.34473 .51867 m .34385 .51868 L .34452 .51848 L F
.274 .764 .69 r
.34385 .51868 m .34319 .51891 L .34366 .51874 L F
.34385 .51868 m .34695 .51752 L .3461 .5144 L F
.34385 .51868 m .34366 .51874 L .34695 .51752 L F
.528 .276 .476 r
.34161 .51581 m .34254 .517 L .34551 .51402 L F
.34254 .517 m .34385 .51868 L .34486 .51583 L F
.34254 .517 m .34486 .51583 L .34551 .51402 L F
.705 .656 .798 r
.33808 .51613 m .33907 .51875 L .3416 .51747 L F
.33907 .51875 m .34 .52121 L .3416 .51747 L F
.34 .52121 m .34024 .52185 L .34092 .52137 L F
.667 .22 .181 r
.34213 .52158 m .34174 .52152 L .34155 .52121 L F
.34172 .52117 m .34155 .52121 L .34122 .52067 L F
.34213 .52158 m .34155 .52121 L .34172 .52117 L F
.905 .896 .809 r
.34122 .52067 m .33919 .52469 L .3411 .52449 L F
.804 .916 .525 r
.33985 .52235 m .33919 .52469 L .34122 .52067 L F
.667 .22 .181 r
.34234 .5225 m .33985 .52235 L .34122 .52067 L F
0 .152 .685 r
.34373 .52155 m .34599 .52522 L .34461 .52122 L F
.667 .22 .181 r
.34308 .52254 m .34122 .52067 L .34461 .52122 L F
.705 .656 .798 r
.34 .52121 m .34092 .52137 L .34473 .51867 L F
.257 .211 .614 r
.33376 .52009 m .33743 .51833 L .33488 .5202 L F
.33376 .52009 m .33693 .51717 L .33743 .51833 L F
.82 .712 .745 r
.33557 .51927 m .34024 .52185 L .33808 .51613 L F
.579 .117 .122 r
.33903 .52041 m .34473 .51867 L .34092 .52137 L F
.34002 .5216 m .34092 .52137 L .34024 .52185 L F
.33903 .52041 m .34092 .52137 L .34002 .5216 L F
.667 .22 .181 r
.34308 .52254 m .34234 .5225 L .34174 .52152 L F
.34308 .52254 m .34174 .52152 L .34213 .52158 L F
.859 .484 0 r
.41606 .59632 m .4151 .59524 L .41425 .59271 L F
.97 .689 .443 r
.41606 .59632 m .4161 .59901 L .41439 .59805 L F
.996 .861 .541 r
.41606 .59632 m .41439 .59805 L .4151 .59524 L F
.624 .13 .058 r
.30716 .64612 m .30653 .64497 L .30898 .64675 L F
.657 .132 0 r
.30653 .64497 m .31101 .64685 L .30898 .64675 L F
.633 .122 .013 r
.62847 .36172 m .6324 .36234 L .63082 .36335 L F
.65 .958 .935 r
.63392 .36036 m .6324 .36234 L .63403 .36119 L F
.638 .93 .669 r
.63082 .36335 m .6324 .36234 L .63392 .36036 L F
.417 .2 .475 r
.33068 .61554 m .33284 .61766 L .33319 .61525 L F
.33068 .61554 m .33044 .61815 L .33284 .61766 L F
.494 .168 .343 r
.45005 .55157 m .44956 .55424 L .45243 .55358 L F
.633 .549 .742 r
.45034 .55406 m .44953 .55607 L .45243 .55358 L F
.44896 .55469 m .44953 .55607 L .45056 .5535 L F
.494 .168 .343 r
.44956 .55424 m .44949 .55463 L .45243 .55358 L F
.633 .549 .742 r
.45056 .5535 m .45034 .55406 L .45243 .55358 L F
.274 0 .279 r
.44709 .55479 m .44899 .55467 L .45005 .55157 L F
.44899 .55467 m .44956 .55424 L .45005 .55157 L F
.633 .549 .742 r
.44844 .55341 m .44896 .55469 L .45056 .5535 L F
.274 0 .279 r
.44899 .55467 m .44949 .55463 L .44956 .55424 L F
.494 .168 .343 r
.45005 .55157 m .45243 .55358 L .45255 .55086 L F
0 .043 .61 r
.36307 .55409 m .36459 .55784 L .36503 .55671 L F
.308 0 .153 r
.36251 .55845 m .36503 .55671 L .36459 .55784 L F
.932 .848 .738 r
.37299 .5963 m .37115 .59388 L .37556 .59305 L F
.37299 .5963 m .37556 .59305 L .37388 .5948 L F
.37299 .5963 m .37102 .59608 L .37115 .59388 L F
.576 .914 .97 r
.37388 .5948 m .37102 .59608 L .37299 .5963 L F
0 0 0 r
.4002 .48933 m .39883 .49235 L .39719 .49331 L F
.812 .52 .495 r
.40308 .49063 m .39883 .49235 L .4002 .48933 L F
.784 .891 .478 r
.45477 .56099 m .45301 .56475 L .4553 .56401 L F
.294 0 .212 r
.45216 .56649 m .4553 .56401 L .45301 .56475 L F
.711 .779 .905 r
.61683 .35296 m .6136 .35519 L .61288 .35261 L F
.025 .592 .784 r
.43728 .59904 m .43871 .59898 L .43621 .59965 L F
.43728 .59904 m .43992 .59922 L .43871 .59898 L F
.773 .795 .87 r
.29809 .51566 m .29998 .51529 L .29894 .5111 L F
.687 .742 .893 r
.29894 .5111 m .29998 .51529 L .30333 .51224 L F
.291 .753 .948 r
.19823 .70165 m .20243 .70206 L .20069 .70144 L F
.19823 .70165 m .20243 .70206 L .20069 .70144 L F
.766 .706 .796 r
.47096 .46739 m .47485 .46785 L .47253 .47111 L F
.485 .325 .589 r
.47485 .46785 m .47493 .47047 L .47253 .47111 L F
.559 .469 .709 r
.47493 .47047 m .47284 .47399 L .47253 .47111 L F
.687 .669 .826 r
.46885 .469 m .47096 .46739 L .47253 .47111 L F
.719 .564 .678 r
.4698 .47438 m .47253 .47111 L .47284 .47399 L F
.971 .736 .525 r
.49102 .44359 m .49307 .44242 L .49261 .44584 L F
.799 .754 .811 r
.49515 .4436 m .49261 .44584 L .49307 .44242 L F
0 .321 .779 r
.49376 .44217 m .49307 .44242 L .49102 .44359 L F
.49376 .44217 m .49515 .4436 L .49307 .44242 L F
.617 .539 .744 r
.43187 .59099 m .43282 .58602 L .43161 .58724 L F
.889 .951 .841 r
.47056 .45395 m .46962 .45782 L .46797 .45678 L F
.47056 .45395 m .47157 .45545 L .46962 .45782 L F
.738 .456 .502 r
.54042 .46472 m .54448 .46491 L .54451 .46725 L F
.719 .354 .357 r
.54448 .46491 m .5472 .46767 L .54451 .46725 L F
0 0 .41 r
.21224 .56692 m .21384 .56262 L .21243 .56424 L F
.521 .751 .98 r
.57709 .46661 m .57869 .46809 L .58128 .46752 L F
.179 0 .289 r
.62773 .42978 m .62965 .4271 L .6293 .42795 L F
.387 .055 .275 r
.30032 .63684 m .30106 .63452 L .3035 .6341 L F
.455 .695 .97 r
.63851 .42408 m .6412 .4268 L .64306 .42627 L F
.974 .823 .632 r
.72426 .34471 m .72574 .34632 L .72657 .34221 L F
0 0 0 r
.44837 .59522 m .44459 .59747 L .44632 .59612 L F
.368 .382 .743 r
.28618 .63358 m .28354 .63206 L .28288 .63031 L F
.28618 .63358 m .28467 .63411 L .28354 .63206 L F
.516 .302 .527 r
.27914 .56409 m .28163 .56358 L .28186 .56102 L F
.508 .295 .526 r
.28163 .56358 m .28411 .56313 L .28186 .56102 L F
.569 .289 .451 r
.28186 .56102 m .28411 .56313 L .28451 .56079 L F
.672 .867 .973 r
.70679 .32307 m .70467 .32442 L .70358 .32275 L F
.556 .899 .669 r
.6907 .31268 m .69401 .31025 L .69395 .31028 L F
.288 0 .17 r
.69607 .30806 m .699 .30597 L .69836 .30741 L F
.69607 .30806 m .69836 .30741 L .69683 .30732 L F
.69607 .30806 m .69683 .30732 L .69529 .30722 L F
0 0 .039 r
.69401 .31025 m .69477 .30936 L .69607 .30806 L F
.69477 .30936 m .6966 .3072 L .69607 .30806 L F
.526 .83 .508 r
.69395 .31028 m .69401 .31025 L .69607 .30806 L F
.559 0 0 r
.70665 .30962 m .71102 .31229 L .70893 .3101 L F
.881 .98 .831 r
.38901 .68891 m .39279 .68634 L .38929 .68804 L F
.829 .977 .679 r
.39279 .68634 m .39523 .6829 L .39334 .68425 L F
.8 .997 .859 r
.38929 .68804 m .39279 .68634 L .39334 .68425 L F
.342 .123 .429 r
.3281 .60572 m .32778 .60843 L .32558 .60906 L F
.468 .273 .532 r
.32778 .60843 m .32527 .61178 L .32558 .60906 L F
.55 .565 .822 r
.39618 .67862 m .39763 .68229 L .39523 .6829 L F
.217 0 0 r
.39523 .6829 m .39646 .68464 L .39334 .68425 L F
.39523 .6829 m .39763 .68229 L .39646 .68464 L F
.25 0 .013 r
.30146 .56385 m .29817 .56561 L .29903 .56445 L F
.598 .651 .874 r
.57311 .4447 m .57325 .44618 L .5704 .44552 L F
.799 .754 .811 r
.49515 .4436 m .49698 .44564 L .49261 .44584 L F
.537 .021 0 r
.49261 .44584 m .49698 .44564 L .49552 .44699 L F
.626 .699 .897 r
.49826 .44173 m .49698 .44564 L .49515 .4436 L F
.49826 .44173 m .49969 .44481 L .49698 .44564 L F
.643 .144 .05 r
.49552 .44699 m .49698 .44564 L .49952 .44756 L F
.503 .273 .497 r
.49698 .44564 m .49969 .44481 L .49952 .44756 L F
0 .323 .804 r
.26262 .62863 m .26311 .62785 L .26172 .62679 L F
.26262 .62863 m .26585 .6307 L .26311 .62785 L F
.587 .481 .701 r
.33582 .59628 m .33637 .59908 L .33361 .59947 L F
.532 .295 .501 r
.33361 .59947 m .33594 .60165 L .33336 .60194 L F
.539 .295 .493 r
.33637 .59908 m .33594 .60165 L .33361 .59947 L F
.212 0 .254 r
.29465 .65998 m .29493 .65731 L .29719 .65621 L F
.293 .063 .384 r
.47162 .57665 m .47186 .57924 L .46928 .57999 L F
.202 .122 .537 r
.47348 .57293 m .47378 .57567 L .47162 .57665 L F
.258 .098 .464 r
.47378 .57567 m .47186 .57924 L .47162 .57665 L F
.164 0 .166 r
.67578 .3647 m .6736 .36608 L .6728 .36765 L F
.444 .212 .467 r
.46928 .57999 m .46889 .58232 L .46676 .58299 L F
.265 .041 .376 r
.47186 .57924 m .46889 .58232 L .46928 .57999 L F
.848 .803 .807 r
.22546 .58279 m .22812 .57954 L .22591 .58031 L F
.749 .934 .948 r
.58418 .46696 m .58833 .46542 L .5869 .46416 L F
.611 .885 .99 r
.5869 .46416 m .58833 .46542 L .59058 .46425 L F
.181 0 .189 r
.41823 .49738 m .41949 .49791 L .42078 .49668 L F
.41823 .49738 m .41759 .49942 L .41949 .49791 L F
.824 .488 0 r
.40098 .57565 m .40101 .57403 L .40123 .5727 L F
.40098 .57565 m .40176 .57651 L .40101 .57403 L F
.578 .193 .276 r
.28678 .56018 m .29099 .55809 L .28681 .55745 L F
.28678 .56018 m .28878 .56042 L .29099 .55809 L F
.474 .07 .193 r
.29099 .55809 m .28878 .56042 L .29336 .55887 L F
.592 .234 .33 r
.37702 .55495 m .37604 .55656 L .37398 .55441 L F
0 0 0 r
.37321 .59213 m .37461 .58935 L .37115 .59388 L F
.37599 .5877 m .37461 .58935 L .37321 .59213 L F
.201 0 0 r
.33729 .57098 m .33989 .57132 L .33997 .57089 L F
.904 .559 .381 r
.33738 .57008 m .33989 .57132 L .33729 .57098 L F
.33913 .57039 m .33989 .57132 L .33738 .57008 L F
0 0 0 r
.33997 .57089 m .33989 .57132 L .34226 .56977 L F
.904 .559 .381 r
.33754 .56842 m .33913 .57039 L .33738 .57008 L F
.33754 .56842 m .33811 .57091 L .33989 .57132 L F
.266 0 0 r
.33811 .57091 m .34226 .56977 L .33989 .57132 L F
.33811 .57091 m .34015 .57104 L .34075 .57067 L F
.33966 .57048 m .34075 .57067 L .34226 .56977 L F
.33811 .57091 m .34075 .57067 L .33966 .57048 L F
.851 .942 .88 r
.66597 .31979 m .66792 .31611 L .66716 .31778 L F
.407 .007 .165 r
.62965 .4271 m .63211 .42806 L .6293 .42795 L F
.62965 .4271 m .63184 .42654 L .63211 .42806 L F
.39 0 0 r
.33546 .66025 m .33457 .65954 L .33067 .65942 L F
.455 .642 .938 r
.40817 .48942 m .40756 .49158 L .40565 .49077 L F
.267 0 .148 r
.40817 .48942 m .406 .49077 L .40565 .49077 L F
.121 .626 .901 r
.40756 .49158 m .40565 .49077 L .40365 .49075 L F
.267 0 .148 r
.406 .49077 m .4033 .49245 L .40565 .49077 L F
.121 .626 .901 r
.40365 .49075 m .40565 .49077 L .40308 .49063 L F
.762 .946 .939 r
.40756 .49158 m .4033 .49245 L .40817 .48942 L F
0 0 .435 r
.47264 .56583 m .47391 .57026 L .47349 .56786 L F
.69 .282 .269 r
.24004 .56975 m .24367 .57296 L .24429 .56978 L F
0 0 .089 r
.24429 .56978 m .24432 .57208 L .24627 .5703 L F
.24429 .56978 m .24367 .57296 L .24432 .57208 L F
.805 .937 .575 r
.37472 .59298 m .37556 .59305 L .37727 .59193 L F
.37472 .59298 m .37388 .5948 L .37556 .59305 L F
.607 .37 .531 r
.7188 .34599 m .72181 .3454 L .7218 .34308 L F
.409 .215 .504 r
.7218 .34308 m .72181 .3454 L .72426 .34471 L F
.175 0 0 r
.27744 .56557 m .28163 .56358 L .27914 .56409 L F
.303 .792 .752 r
.72402 .33891 m .72505 .33839 L .72285 .33807 L F
.476 .441 .739 r
.46042 .51373 m .45818 .51373 L .45716 .50933 L F
.429 .376 .698 r
.46042 .51373 m .45892 .51559 L .45818 .51373 L F
.883 .9 .837 r
.64393 .35552 m .64511 .3509 L .64332 .35447 L F
.64393 .35552 m .64654 .35233 L .64511 .3509 L F
.795 .797 .853 r
.71975 .318 m .71596 .31951 L .71834 .31803 L F
.27 .72 .958 r
.72123 .31704 m .71975 .318 L .71834 .31803 L F
.72123 .31704 m .72239 .318 L .71975 .318 L F
.738 .916 .953 r
.47529 .45251 m .47157 .45545 L .47056 .45395 L F
.677 .971 .917 r
.25638 .52124 m .25668 .51983 L .25867 .52046 L F
.25638 .52124 m .2546 .52124 L .25668 .51983 L F
.469 .39 .684 r
.46176 .53409 m .45901 .53647 L .459 .53198 L F
.566 .497 .736 r
.46176 .53409 m .46007 .53832 L .45901 .53647 L F
.964 .695 .475 r
.6071 .43224 m .6071 .43487 L .60884 .43568 L F
.835 .364 .009 r
.60812 .43682 m .60884 .43568 L .6071 .43487 L F
.60812 .43682 m .61035 .43817 L .60884 .43568 L F
.801 .629 .668 r
.47731 .46205 m .47754 .46491 L .47349 .46407 L F
.611 .486 .686 r
.47996 .4614 m .47754 .46491 L .47731 .46205 L F
.814 .532 0 r
.70276 .31739 m .70261 .3182 L .70186 .31586 L F
.70276 .31739 m .7032 .31973 L .70261 .3182 L F
.973 .892 .528 r
.3828 .55115 m .38222 .55015 L .3835 .54859 L F
.801 .706 .76 r
.52529 .44188 m .52269 .44529 L .52329 .44259 L F
.117 .028 .469 r
.38643 .61245 m .38633 .61482 L .38838 .6136 L F
.753 .646 .742 r
.52329 .44259 m .52269 .44529 L .52159 .44543 L F
.687 .631 .787 r
.52269 .44529 m .52075 .44847 L .52159 .44543 L F
.757 .852 .921 r
.62971 .34964 m .62605 .34964 L .62829 .3481 L F
.804 .861 .891 r
.6327 .34698 m .62971 .34964 L .62829 .3481 L F
.837 .9 .883 r
.64511 .3509 m .64654 .35233 L .64944 .34928 L F
.886 .739 .693 r
.68687 .35509 m .68352 .35746 L .68605 .35404 L F
.68687 .35509 m .68525 .35901 L .68352 .35746 L F
.791 .985 .896 r
.6894 .3516 m .68687 .35509 L .68605 .35404 L F
.6894 .3516 m .69013 .35238 L .68687 .35509 L F
.031 0 .244 r
.32529 .57696 m .32661 .57802 L .32775 .57633 L F
.32529 .57696 m .32455 .57946 L .32661 .57802 L F
.807 .699 .745 r
.30842 .53114 m .30432 .53202 L .30739 .52837 L F
.036 0 0 r
.30842 .53114 m .30382 .53288 L .30432 .53202 L F
.30842 .53114 m .30748 .532 L .30382 .53288 L F
0 0 0 r
.30976 .53054 m .30748 .532 L .30842 .53114 L F
.768 .844 .909 r
.50545 .4575 m .50369 .46151 L .50424 .45966 L F
.50545 .4575 m .50646 .45946 L .50369 .46151 L F
.151 .263 .726 r
.50424 .45966 m .50369 .46151 L .50639 .46359 L F
.204 .22 .655 r
.62934 .41518 m .62726 .41325 L .62878 .41235 L F
.453 .202 .442 r
.35077 .58965 m .35331 .58603 L .35328 .58571 L F
.35077 .58965 m .35364 .58905 L .35331 .58603 L F
.023 0 .38 r
.35331 .58603 m .35505 .58737 L .35586 .58577 L F
.35331 .58603 m .35364 .58905 L .35505 .58737 L F
.496 .781 .996 r
.3542 .64569 m .35636 .64774 L .35395 .64747 L F
.35777 .64636 m .35636 .64774 L .3542 .64569 L F
0 .078 .626 r
.39497 .51698 m .39659 .51848 L .396 .51732 L F
0 0 .076 r
.33238 .62513 m .33463 .6219 L .33504 .62462 L F
.566 .553 .799 r
.33618 .62043 m .33504 .62462 L .33463 .6219 L F
.697 .98 .897 r
.23215 .60564 m .23187 .60436 L .23363 .60585 L F
.23215 .60564 m .22956 .60577 L .23187 .60436 L F
.23215 .60564 m .23187 .60436 L .23363 .60585 L F
.23215 .60564 m .22956 .60577 L .23187 .60436 L F
.01 .199 .71 r
.32717 .53192 m .32807 .53448 L .32704 .53466 L F
0 .125 .642 r
.32807 .53448 m .3284 .53623 L .32704 .53466 L F
0 .02 .593 r
.3999 .52618 m .40129 .52824 L .39954 .52457 L F
.956 .663 .44 r
.29496 .66955 m .29554 .67332 L .29257 .67281 L F
0 0 0 r
.29496 .66955 m .29257 .67281 L .2946 .67108 L F
.2946 .67108 m .29257 .67281 L .29333 .6729 L F
0 .49 .724 r
.29257 .67281 m .29554 .67332 L .29333 .6729 L F
.862 .977 .856 r
.42623 .47434 m .42787 .47052 L .42914 .47131 L F
.42623 .47434 m .42506 .47382 L .42787 .47052 L F
.688 .404 0 r
.39773 .52247 m .39729 .52095 L .39659 .51848 L F
0 .021 .586 r
.39773 .52247 m .39954 .52457 L .39729 .52095 L F
0 0 .527 r
.61688 .43309 m .61799 .43519 L .61664 .43132 L F
.744 .683 .793 r
.32478 .52892 m .32076 .52869 L .32291 .52526 L F
.513 .039 .067 r
.32478 .52892 m .32024 .53044 L .32076 .52869 L F
.32478 .52892 m .32314 .5305 L .32024 .53044 L F
.721 .674 .803 r
.32669 .52692 m .32478 .52892 L .32291 .52526 L F
.199 0 0 r
.32603 .52946 m .32478 .52892 L .32757 .52864 L F
.32603 .52946 m .32314 .5305 L .32478 .52892 L F
.547 .22 .364 r
.33878 .59302 m .34095 .59493 L .33832 .5951 L F
.548 .219 .363 r
.34148 .59289 m .34095 .59493 L .33878 .59302 L F
.602 .752 .949 r
.25375 .52802 m .25664 .52664 L .25667 .52545 L F
.25375 .52802 m .25775 .52876 L .25664 .52664 L F
.694 .494 .612 r
.51275 .46078 m .51029 .4641 L .51035 .46162 L F
.392 .136 .401 r
.43908 .54711 m .44143 .54667 L .44165 .54491 L F
.775 .68 .759 r
.47349 .46407 m .47096 .46739 L .4711 .4649 L F
.414 .197 .472 r
.4711 .4649 m .47096 .46739 L .46885 .469 L F
.627 .62 .824 r
.48389 .45114 m .48223 .45513 L .48107 .45207 L F
.48389 .45114 m .48522 .4547 L .48223 .45513 L F
.576 .345 .528 r
.48223 .45513 m .48516 .45725 L .48227 .45787 L F
.48223 .45513 m .48522 .4547 L .48516 .45725 L F
.979 .782 .366 r
.40264 .58535 m .40229 .58287 L .40197 .58548 L F
.99 .851 .486 r
.40119 .58745 m .40264 .58535 L .40197 .58548 L F
.514 .255 .459 r
.30085 .62144 m .3039 .61857 L .30106 .6184 L F
.278 0 .25 r
.35314 .575 m .35399 .57581 L .35154 .57597 L F
.61 .257 .346 r
.3541 .57901 m .35154 .57597 L .35399 .57581 L F
.3541 .57901 m .35021 .57967 L .35154 .57597 L F
.479 .113 .267 r
.46676 .58299 m .4659 .58545 L .46323 .58561 L F
.186 0 .149 r
.46808 .58444 m .46676 .58299 L .46889 .58232 L F
.46808 .58444 m .4659 .58545 L .46676 .58299 L F
.118 .262 .737 r
.26516 .617 m .26414 .61876 L .26284 .61492 L F
.157 .314 .773 r
.26516 .617 m .26655 .62054 L .26414 .61876 L F
.511 .473 .75 r
.41333 .49341 m .41125 .49555 L .41062 .49426 L F
.41333 .49341 m .414 .49567 L .41125 .49555 L F
.546 .763 .978 r
.44953 .55607 m .45136 .55768 L .45244 .55596 L F
.294 .429 .828 r
.45136 .55768 m .45385 .55984 L .45244 .55596 L F
.158 .385 .833 r
.45136 .55768 m .45477 .56099 L .45385 .55984 L F
.702 .521 .639 r
.51704 .45861 m .51679 .46119 L .51275 .46078 L F
.69 .408 .49 r
.51704 .45861 m .51952 .46092 L .51679 .46119 L F
.715 .606 .735 r
.46576 .47355 m .4698 .47438 L .4672 .47764 L F
.638 .496 .673 r
.4672 .47764 m .4698 .47438 L .47007 .47727 L F
.626 .442 .614 r
.4672 .47764 m .46967 .47942 L .4675 .48032 L F
.4672 .47764 m .47007 .47727 L .46967 .47942 L F
.429 .376 .698 r
.46042 .51373 m .46107 .51511 L .45892 .51559 L F
.479 .421 .714 r
.46107 .51511 m .45933 .51929 L .45892 .51559 L F
.998 .851 .529 r
.5297 .41813 m .53129 .4169 L .53043 .41552 L F
.5297 .41813 m .53072 .41942 L .53129 .4169 L F
.38 .053 .28 r
.40565 .49077 m .4033 .49245 L .40308 .49063 L F
.71 .452 .534 r
.64597 .39428 m .6466 .39718 L .64235 .39724 L F
.82 .892 .894 r
.64764 .39018 m .64597 .39428 L .64477 .39224 L F
.64764 .39018 m .64924 .39146 L .64597 .39428 L F
.972 .672 .387 r
.60829 .40891 m .60996 .40998 L .6101 .41264 L F
.377 .163 .457 r
.22845 .57701 m .22812 .57954 L .23058 .5763 L F
.159 0 .236 r
.34422 .54417 m .34119 .54721 L .34218 .5456 L F
.34422 .54417 m .3432 .54596 L .34119 .54721 L F
.357 .218 .551 r
.34218 .5456 m .3432 .54596 L .34422 .54417 L F
.3432 .54596 m .34323 .54597 L .34422 .54417 L F
.159 0 .236 r
.34422 .54417 m .34379 .54559 L .3432 .54596 L F
.357 .218 .551 r
.3432 .54596 m .34119 .54721 L .34323 .54597 L F
.556 .593 .846 r
.34119 .54721 m .34235 .54802 L .34323 .54597 L F
.34235 .54802 m .34637 .55081 L .34341 .54624 L F
.34235 .54802 m .34341 .54624 L .34323 .54597 L F
0 .06 .62 r
.34637 .55081 m .34613 .54739 L .34359 .5461 L F
.34637 .55081 m .34359 .5461 L .34357 .54612 L F
.34637 .55081 m .34355 .54609 L .34341 .54624 L F
.715 .603 .73 r
.34736 .5489 m .34691 .54923 L .34613 .54736 L F
0 .06 .62 r
.34613 .54736 m .34691 .54923 L .3461 .54702 L F
.34637 .55081 m .34691 .54923 L .34613 .54736 L F
.34613 .54739 m .34613 .54736 L .34574 .54689 L F
.34613 .54736 m .34575 .54689 L .34574 .54689 L F
.715 .603 .73 r
.34613 .54736 m .34691 .54923 L .3456 .5467 L F
.784 .627 .687 r
.34691 .54923 m .34277 .54888 L .34337 .54751 L F
.448 0 .031 r
.34363 .54588 m .34574 .54689 L .34691 .54562 L F
.34363 .54588 m .34691 .54562 L .34636 .54521 L F
.34574 .54689 m .34576 .54688 L .34756 .54492 L F
.34575 .54689 m .34624 .54682 L .34756 .54492 L F
.657 .225 .211 r
.34624 .54682 m .34905 .54557 L .34756 .54492 L F
.34651 .54682 m .34905 .54557 L .34624 .54682 L F
.34651 .54682 m .34959 .54727 L .34905 .54557 L F
.715 .603 .73 r
.34959 .54727 m .34736 .5489 L .34599 .54685 L F
.657 .225 .211 r
.3461 .54702 m .34959 .54727 L .34651 .54682 L F
.715 .603 .73 r
.34815 .54654 m .34637 .5468 L .34459 .54475 L F
.34637 .5468 m .34624 .54682 L .3462 .54678 L F
.34637 .5468 m .3462 .54678 L .34459 .54475 L F
.34624 .54682 m .34599 .54685 L .34597 .54682 L F
.34624 .54682 m .34597 .54682 L .34459 .54475 L F
.34959 .54727 m .34599 .54685 L .34815 .54654 L F
.657 .225 .211 r
.3461 .54702 m .34651 .54682 L .34624 .54682 L F
.715 .603 .73 r
.34876 .547 m .34459 .54475 L .34772 .54665 L F
.34959 .54727 m .34815 .54654 L .34876 .547 L F
.34815 .54654 m .34459 .54475 L .34876 .547 L F
.448 0 .031 r
.34636 .54521 m .34691 .54562 L .34756 .54492 L F
.34323 .54597 m .34359 .5461 L .34363 .54588 L F
.34359 .5461 m .34574 .54689 L .34363 .54588 L F
0 0 0 r
.34352 .54658 m .34277 .54888 L .34345 .54669 L F
0 .06 .62 r
.34613 .54739 m .34574 .54689 L .34359 .5461 L F
0 0 0 r
.34423 .54536 m .34339 .54738 L .34352 .54658 L F
.34339 .54738 m .34277 .54888 L .34352 .54658 L F
.784 .627 .687 r
.34551 .54695 m .34337 .54751 L .34441 .54515 L F
.34691 .54923 m .34337 .54751 L .34551 .54695 L F
.448 0 .031 r
.34574 .54689 m .34575 .54689 L .34576 .54688 L F
.34575 .54689 m .3461 .54702 L .34624 .54682 L F
.715 .603 .73 r
.34736 .5489 m .3456 .5467 L .34459 .54475 L F
0 .06 .62 r
.34613 .54736 m .3461 .54702 L .34575 .54689 L F
.784 .627 .687 r
.3456 .5467 m .34441 .54515 L .34459 .54475 L F
.34691 .54923 m .34441 .54515 L .3456 .5467 L F
0 0 0 r
.34459 .54475 m .34441 .54515 L .34423 .54536 L F
.34441 .54515 m .34277 .54888 L .34423 .54536 L F
0 .06 .62 r
.34357 .54612 m .34359 .5461 L .34355 .54609 L F
.34341 .54624 m .34355 .54609 L .34323 .54597 L F
0 0 0 r
.34459 .54475 m .34423 .54536 L .34378 .54562 L F
.34423 .54536 m .34345 .54669 L .34368 .54595 L F
.34423 .54536 m .34368 .54595 L .34378 .54562 L F
.34444 .54452 m .34378 .54562 L .34422 .54417 L F
.34459 .54475 m .34378 .54562 L .34444 .54452 L F
.159 0 .236 r
.34379 .54559 m .34345 .54669 L .34119 .54721 L F
.357 .218 .551 r
.34218 .5456 m .34119 .54721 L .3432 .54596 L F
.34103 .5452 m .34119 .54721 L .34218 .5456 L F
.159 0 .236 r
.34218 .5456 m .34119 .54721 L .34101 .54643 L F
.357 .218 .551 r
.34103 .5452 m .34218 .5456 L .34422 .54417 L F
.159 0 .236 r
.34422 .54417 m .34101 .54643 L .34051 .5442 L F
.521 .353 .594 r
.45933 .51929 m .45963 .52227 L .45708 .52299 L F
.588 .064 0 r
.34345 .55439 m .3438 .5541 L .34166 .55368 L F
.34345 .55439 m .34621 .55658 L .3438 .5541 L F
.784 .679 .749 r
.52315 .42914 m .52457 .43288 L .52076 .43233 L F
.811 .655 .688 r
.52457 .43288 m .5202 .43499 L .52076 .43233 L F
.52457 .43288 m .52412 .43571 L .5202 .43499 L F
.785 .944 .928 r
.41797 .47869 m .41341 .48046 L .41594 .47949 L F
.785 .997 .805 r
.41797 .47869 m .41876 .47674 L .41933 .47683 L F
.41797 .47869 m .41594 .47949 L .41876 .47674 L F
.753 .719 .821 r
.65699 .3978 m .66059 .39811 L .65906 .39635 L F
.745 .752 .858 r
.66059 .39811 m .66194 .39369 L .65906 .39635 L F
.66059 .39811 m .66324 .39689 L .66194 .39369 L F
.35 .051 .309 r
.31463 .55335 m .31571 .55407 L .31625 .55188 L F
.31463 .55335 m .31345 .55491 L .31571 .55407 L F
.745 .328 .259 r
.34835 .67791 m .35278 .6793 L .35058 .6761 L F
.894 .907 .827 r
.66116 .32416 m .65754 .32589 L .66015 .32315 L F
.66116 .32416 m .65871 .32733 L .65754 .32589 L F
.85 .949 .881 r
.66373 .32131 m .66116 .32416 L .66164 .32119 L F
.866 .96 .864 r
.66116 .32416 m .66015 .32315 L .66164 .32119 L F
.779 .286 .038 r
.5953 .35858 m .59795 .35963 L .59575 .35944 L F
.183 0 0 r
.59795 .35963 m .60305 .36094 L .60156 .36058 L F
.931 .59 .149 r
.32424 .62712 m .32562 .62873 L .32589 .63075 L F
.729 .651 .771 r
.3682 .63764 m .37224 .63862 L .37065 .63711 L F
.642 .859 .982 r
.37224 .63862 m .37311 .63657 L .37065 .63711 L F
.37224 .63862 m .37482 .63765 L .37311 .63657 L F
.763 .278 .083 r
.32938 .53583 m .33243 .53829 L .3284 .53623 L F
.564 .499 .741 r
.46155 .53127 m .459 .53198 L .45842 .52925 L F
.469 .39 .684 r
.46176 .53409 m .459 .53198 L .46155 .53127 L F
.476 .22 .445 r
.26219 .54793 m .26164 .5505 L .2592 .55096 L F
.26219 .54793 m .26164 .5505 L .2592 .55096 L F
.37 .125 .407 r
.26432 .54739 m .26164 .5505 L .26219 .54793 L F
.26432 .54739 m .26164 .5505 L .26219 .54793 L F
.73 .747 .866 r
.51495 .45136 m .51356 .45433 L .51403 .45104 L F
.849 .855 .847 r
.51403 .45104 m .51356 .45433 L .51147 .45443 L F
0 0 0 r
.58512 .45461 m .58111 .4554 L .58245 .45516 L F
.45 .316 .605 r
.58315 .45769 m .58512 .45461 L .58245 .45516 L F
.719 .789 .907 r
.45113 .46557 m .44768 .46523 L .44972 .46369 L F
.652 .736 .911 r
.44972 .46369 m .45385 .46453 L .45113 .46557 L F
.855 .922 .874 r
.52927 .41463 m .52537 .41493 L .52756 .41314 L F
.52927 .41463 m .52669 .41617 L .52537 .41493 L F
.248 0 .255 r
.53188 .41479 m .53043 .41552 L .52927 .41463 L F
.829 .622 .072 r
.41225 .56072 m .4118 .55954 L .41169 .55679 L F
0 0 .251 r
.41288 .56285 m .4118 .55954 L .41225 .56072 L F
0 0 .312 r
.24152 .54015 m .24045 .54179 L .24079 .53844 L F
0 0 .163 r
.24073 .54256 m .24045 .54179 L .24152 .54015 L F
.494 .68 .949 r
.71886 .34785 m .72172 .34914 L .72181 .3454 L F
.791 .861 .901 r
.72172 .34914 m .72426 .34471 L .72181 .3454 L F
.72172 .34914 m .72574 .34632 L .72426 .34471 L F
.214 0 .144 r
.3487 .52724 m .35081 .52579 L .35093 .52857 L F
.572 .408 .62 r
.35336 .52532 m .35093 .52857 L .35081 .52579 L F
.883 .856 .81 r
.32468 .6594 m .32546 .66147 L .32461 .66206 L F
.87 .681 .643 r
.32282 .65982 m .32365 .66323 L .32096 .66293 L F
.248 .28 .699 r
.32282 .65982 m .32365 .66323 L .32371 .66314 L F
.859 .663 .637 r
.32282 .65982 m .32415 .66288 L .32364 .66288 L F
.32415 .66288 m .32314 .66346 L .32096 .66293 L F
.883 .856 .81 r
.32468 .6594 m .32456 .66381 L .32282 .65982 L F
.248 .28 .699 r
.32282 .65982 m .32371 .66314 L .32508 .66065 L F
.859 .663 .637 r
.32282 .65982 m .32364 .66288 L .32096 .66293 L F
.807 .62 .649 r
.32314 .66346 m .32094 .66451 L .32096 .66293 L F
.32456 .66381 m .32215 .66428 L .32314 .66346 L F
.32215 .66428 m .32094 .66451 L .32314 .66346 L F
.827 .463 .366 r
.32196 .66389 m .32365 .66323 L .32328 .66319 L F
.32196 .66389 m .32328 .66319 L .32096 .66293 L F
.32064 .66441 m .32096 .66293 L .32094 .66451 L F
.32064 .66441 m .32196 .66389 L .32096 .66293 L F
.806 .998 .851 r
.32411 .6624 m .32384 .66289 L .32196 .66389 L F
.32384 .66289 m .32371 .66314 L .32336 .66328 L F
.32384 .66289 m .32336 .66328 L .32196 .66389 L F
.32371 .66314 m .32365 .66323 L .32331 .66337 L F
.859 .663 .637 r
.32415 .66288 m .32456 .66381 L .32314 .66346 L F
.806 .998 .851 r
.32371 .66314 m .32331 .66337 L .32196 .66389 L F
.32508 .66065 m .32411 .6624 L .32064 .66441 L F
.32411 .6624 m .32196 .66389 L .32064 .66441 L F
.883 .856 .81 r
.32461 .66206 m .326 .66289 L .32456 .66381 L F
.32546 .66147 m .326 .66289 L .32461 .66206 L F
.227 .457 .873 r
.32877 .66283 m .326 .66289 L .32468 .6594 L F
.75 .233 0 r
.32456 .66381 m .32745 .66563 L .32637 .66602 L F
.728 .925 .957 r
.32745 .66563 m .32818 .6643 L .32637 .66602 L F
.32745 .66563 m .3306 .66379 L .32877 .66283 L F
.32745 .66563 m .32877 .66283 L .32818 .6643 L F
0 0 .307 r
.40542 .5356 m .40635 .53787 L .40489 .53403 L F
.837 .874 .87 r
.65871 .32733 m .65429 .329 L .65754 .32589 L F
.898 .965 .823 r
.67127 .33175 m .66872 .33506 L .6693 .33608 L F
.757 .639 .73 r
.43489 .51823 m .44 .51894 L .43892 .51557 L F
.43485 .51834 m .44 .51894 L .43489 .51823 L F
.428 .27 .564 r
.43419 .51833 m .43241 .52172 L .43222 .51882 L F
.757 .639 .73 r
.43474 .51833 m .43485 .51834 L .43489 .51823 L F
.428 .27 .564 r
.43522 .51807 m .43484 .51856 L .43419 .51833 L F
.43484 .51856 m .43241 .52172 L .43476 .51853 L F
.458 .315 .599 r
.43241 .52172 m .43505 .5222 L .43483 .51945 L F
.428 .27 .564 r
.43425 .51999 m .43481 .52112 L .43352 .52144 L F
.43484 .51883 m .43483 .51945 L .43425 .51999 L F
.43483 .51945 m .43481 .52112 L .43425 .51999 L F
.43463 .51884 m .43352 .52144 L .43241 .52172 L F
.435 .044 .197 r
.43486 .51857 m .44 .51894 L .43485 .51834 L F
.43505 .5222 m .43853 .51991 L .43655 .51918 L F
.43498 .52092 m .43655 .51918 L .43486 .51857 L F
.43505 .5222 m .43655 .51918 L .43498 .52092 L F
.787 .624 .679 r
.43481 .52112 m .4321 .52411 L .43241 .52172 L F
.435 .044 .197 r
.43495 .52096 m .43485 .51834 L .43483 .51945 L F
.43505 .5222 m .43498 .52092 L .43495 .52096 L F
.43498 .52092 m .43485 .51834 L .43495 .52096 L F
.285 0 .188 r
.43481 .52112 m .4321 .52411 L .43241 .52172 L F
.43533 .52099 m .43228 .52393 L .43481 .52112 L F
.43228 .52393 m .4321 .52411 L .43481 .52112 L F
.787 .624 .679 r
.43533 .52099 m .43228 .52393 L .43481 .52112 L F
.43228 .52393 m .4321 .52411 L .43481 .52112 L F
.435 .044 .197 r
.43853 .51991 m .44 .51894 L .43486 .51857 L F
.428 .27 .564 r
.43522 .51807 m .43352 .52144 L .43463 .51884 L F
.458 .315 .599 r
.43241 .52172 m .43483 .51945 L .43476 .51853 L F
.43241 .52172 m .43476 .51853 L .43474 .51833 L F
.428 .27 .564 r
.43476 .51853 m .43241 .52172 L .43419 .51833 L F
.435 .044 .197 r
.43483 .51945 m .43485 .51834 L .43474 .51833 L F
.428 .27 .564 r
.43522 .51807 m .43533 .52099 L .43481 .52112 L F
.43522 .51807 m .43481 .52112 L .43484 .51883 L F
.787 .624 .679 r
.4321 .52411 m .43612 .52464 L .4321 .52411 L F
.435 .044 .197 r
.43505 .5222 m .43545 .52214 L .43554 .52207 L F
.43516 .52212 m .43554 .52207 L .44 .51894 L F
.43505 .5222 m .43554 .52207 L .43516 .52212 L F
.588 .496 .718 r
.43846 .5217 m .43612 .52464 L .43557 .52207 L F
.435 .044 .197 r
.43545 .52214 m .43846 .5217 L .43957 .51972 L F
.43545 .52214 m .43957 .51972 L .44 .51894 L F
.588 .496 .718 r
.43846 .5217 m .43557 .52207 L .43533 .52099 L F
.598 .512 .727 r
.43545 .52214 m .43612 .52464 L .43846 .5217 L F
.43505 .5222 m .43612 .52464 L .43545 .52214 L F
.787 .624 .679 r
.43533 .52099 m .43557 .52207 L .43545 .52214 L F
.43518 .52114 m .43545 .52214 L .4321 .52411 L F
.43533 .52099 m .43545 .52214 L .43518 .52114 L F
.43557 .52207 m .43612 .52464 L .4321 .52411 L F
.609 .62 .837 r
.44 .51894 m .44191 .51698 L .43892 .51557 L F
.44 .51894 m .44263 .51904 L .44191 .51698 L F
.79 .438 .39 r
.44 .51894 m .44275 .52188 L .44263 .51904 L F
.44 .51894 m .43846 .5217 L .44275 .52188 L F
.804 .841 .879 r
.36983 .66013 m .36851 .66155 L .36683 .6626 L F
.68 .594 .753 r
.46434 .46712 m .46885 .469 L .46585 .47123 L F
.733 .556 .653 r
.46585 .47123 m .4698 .47438 L .46576 .47355 L F
0 0 0 r
.57406 .4244 m .57456 .42256 L .57633 .42104 L F
.886 .988 .802 r
.43168 .46803 m .42914 .47131 L .42921 .46913 L F
.85 .978 .868 r
.42914 .47131 m .42787 .47052 L .42921 .46913 L F
.331 .382 .764 r
.44844 .55341 m .44949 .55463 L .44709 .55479 L F
.326 .374 .758 r
.44709 .55479 m .44953 .55607 L .44844 .55341 L F
.565 .1 .109 r
.22751 .60229 m .22527 .60416 L .22306 .60286 L F
.244 .337 .76 r
.22787 .59884 m .22836 .60332 L .22751 .60229 L F
.702 .273 .228 r
.22751 .60229 m .22956 .60577 L .22527 .60416 L F
.72 .526 .627 r
.61496 .38876 m .61714 .38502 L .61459 .3852 L F
.354 .103 .388 r
.61503 .3887 m .61714 .38502 L .61706 .387 L F
.615 .38869 m .61714 .38502 L .61503 .3887 L F
.954 .697 .508 r
.61307 .38688 m .61496 .38876 L .61459 .3852 L F
.176 .523 .919 r
.61531 .38882 m .61307 .38688 L .615 .38785 L F
.61532 .38882 m .6153 .38881 L .61531 .38882 L F
.6153 .38881 m .61307 .38688 L .61531 .38882 L F
.354 .103 .388 r
.61496 .38876 m .615 .38869 L .61503 .3887 L F
.919 .609 .132 r
.41354 .56985 m .41489 .57376 L .41402 .57271 L F
.992 .793 .414 r
.41489 .57376 m .41369 .57517 L .41402 .57271 L F
.41489 .57376 m .41459 .57643 L .41369 .57517 L F
.249 .023 .362 r
.35255 .59864 m .34994 .60211 L .35006 .5995 L F
.715 .481 .57 r
.30179 .54447 m .30438 .54509 L .30467 .54273 L F
.459 .219 .463 r
.33076 .60772 m .3281 .60572 L .33039 .60437 L F
.33076 .60772 m .32778 .60843 L .3281 .60572 L F
.719 .287 .222 r
.36248 .68868 m .35866 .686 L .35973 .68931 L F
.36248 .68868 m .35973 .68931 L .36058 .68777 L F
.052 .249 .745 r
.35973 .68931 m .36211 .69144 L .36058 .68777 L F
.559 .469 .709 r
.47493 .47047 m .47554 .47354 L .47284 .47399 L F
.578 .378 .574 r
.47554 .47354 m .47246 .47641 L .47284 .47399 L F
.688 .44 .543 r
.4698 .47438 m .47284 .47399 L .47246 .47641 L F
.377 .545 .894 r
.32301 .68919 m .32703 .69232 L .32624 .68866 L F
.463 .334 .62 r
.33136 .56314 m .33422 .56338 L .33575 .56413 L F
.997 .818 .541 r
.33575 .56413 m .33422 .56338 L .33496 .56007 L F
.646 .479 .644 r
.35147 .65107 m .35416 .65041 L .35395 .64747 L F
.35147 .65107 m .35416 .65041 L .35395 .64747 L F
.973 .732 .307 r
.35395 .64747 m .35322 .64984 L .3542 .64569 L F
.35395 .64747 m .35416 .65041 L .35322 .64984 L F
.721 .317 .281 r
.35395 .64747 m .35646 .6501 L .35416 .65041 L F
.765 .554 .612 r
.37259 .53217 m .36814 .53186 L .36809 .52885 L F
.068 .565 .891 r
.36814 .53186 m .3709 .53248 L .37059 .53236 L F
.322 0 0 r
.37259 .53217 m .37105 .5324 L .36814 .53186 L F
.734 .615 .725 r
.37059 .53236 m .3709 .53248 L .37088 .53238 L F
.322 0 0 r
.37105 .5324 m .3709 .53242 L .37059 .53236 L F
.086 .182 .669 r
.36955 .52736 m .37088 .53238 L .37173 .52967 L F
.37088 .53238 m .3709 .53248 L .37092 .5324 L F
.322 0 0 r
.37097 .53238 m .37088 .53238 L .37079 .53235 L F
.37105 .5324 m .37095 .53239 L .37097 .53238 L F
.37095 .53239 m .37088 .53238 L .37097 .53238 L F
.086 .182 .669 r
.37088 .53238 m .37092 .5324 L .37173 .52967 L F
.496 .618 .902 r
.37088 .53242 m .37173 .52967 L .37092 .5324 L F
.37088 .53242 m .37092 .5324 L .3709 .53248 L F
.322 0 0 r
.37079 .53235 m .37059 .53236 L .36814 .53186 L F
.37088 .53238 m .37059 .53236 L .37079 .53235 L F
.734 .615 .725 r
.36598 .53058 m .37059 .53236 L .36955 .52736 L F
.37059 .53236 m .37088 .53238 L .36955 .52736 L F
.068 .565 .891 r
.36814 .53186 m .37059 .53236 L .36598 .53058 L F
.322 0 0 r
.3709 .53242 m .37088 .53242 L .36814 .53186 L F
0 .284 .779 r
.37259 .53217 m .37361 .53174 L .37088 .53242 L F
.37259 .53217 m .37489 .53364 L .37381 .53204 L F
.501 .25 .465 r
.37259 .53217 m .37195 .53465 L .37489 .53364 L F
.422 .022 .173 r
.37195 .53465 m .37366 .53541 L .37489 .53364 L F
.719 .685 .816 r
.37173 .52967 m .37361 .53174 L .37454 .53104 L F
.37472 .52987 m .37454 .53104 L .376 .52996 L F
.37173 .52967 m .37454 .53104 L .37472 .52987 L F
.696 .813 .938 r
.37361 .53174 m .37405 .53241 L .37428 .53069 L F
.37423 .53267 m .37489 .53364 L .37446 .53157 L F
0 0 .476 r
.37366 .53541 m .37428 .53069 L .37446 .53157 L F
.37392 .53503 m .37446 .53157 L .37489 .53364 L F
.37366 .53541 m .37446 .53157 L .37392 .53503 L F
.37366 .53541 m .37512 .53495 L .37456 .53214 L F
.3741 .53208 m .37456 .53214 L .37428 .53069 L F
.37366 .53541 m .37456 .53214 L .3741 .53208 L F
0 .284 .779 r
.37311 .53195 m .37381 .53204 L .37361 .53174 L F
.37259 .53217 m .37381 .53204 L .37311 .53195 L F
.326 .752 .973 r
.32884 .5508 m .33139 .55063 L .33293 .55145 L F
.611 .891 .989 r
.33369 .5496 m .33139 .55063 L .33293 .55145 L F
.183 0 0 r
.33393 .55258 m .33293 .55145 L .3355 .55148 L F
.33393 .55258 m .33146 .55332 L .33293 .55145 L F
.976 .679 .381 r
.2773 .6374 m .27914 .64133 L .27737 .63979 L F
.2773 .6374 m .27914 .64133 L .27737 .63979 L F
.356 .695 .983 r
.27737 .63979 m .27914 .64133 L .28134 .64123 L F
.957 .679 .47 r
.54885 .41239 m .54931 .41053 L .54718 .40883 L F
.315 .028 .308 r
.55166 .40971 m .54931 .41053 L .54885 .41239 L F
.551 .931 .841 r
.43187 .59099 m .42811 .59261 L .43024 .58946 L F
.617 .539 .744 r
.43187 .59099 m .43486 .59023 L .43282 .58602 L F
.594 .835 .99 r
.43241 .58933 m .43187 .59099 L .43024 .58946 L F
.43241 .58933 m .43486 .59023 L .43187 .59099 L F
.369 .076 .331 r
.70237 .3008 m .70507 .29807 L .70239 .29716 L F
.512 .222 .411 r
.70507 .29807 m .70789 .29966 L .70521 .30059 L F
.70507 .29807 m .7081 .29751 L .70789 .29966 L F
.70789 .29966 m .70507 .29807 L .70521 .30059 L F
.70789 .29966 m .7081 .29751 L .70507 .29807 L F
.92 .572 .121 r
.40635 .53787 m .40805 .54159 L .40691 .54031 L F
0 0 .401 r
.40855 .544 m .40691 .54031 L .40805 .54159 L F
.524 .016 0 r
.37269 .58014 m .37431 .58191 L .37242 .58276 L F
.37269 .58014 m .37524 .58074 L .37431 .58191 L F
0 0 .344 r
.32624 .68866 m .32678 .69116 L .32715 .69128 L F
0 0 .466 r
.327 .6879 m .32624 .68866 L .3275 .69227 L F
.907 .799 .729 r
.33041 .68529 m .33081 .68507 L .33082 .68503 L F
.237 0 0 r
.33054 .68517 m .33113 .68488 L .33045 .68497 L F
.907 .799 .729 r
.33051 .68518 m .33082 .68503 L .33094 .68473 L F
.33041 .68529 m .33082 .68503 L .33051 .68518 L F
.435 .268 .554 r
.33099 .68503 m .32816 .69215 L .33216 .69175 L F
.33094 .68473 m .33082 .68503 L .33099 .68503 L F
.33082 .68503 m .32816 .69215 L .33099 .68503 L F
.237 0 0 r
.33112 .68502 m .33297 .68466 L .33113 .68488 L F
0 0 .466 r
.327 .6879 m .3275 .69227 L .326 .69001 L F
.907 .799 .729 r
.326 .69001 m .33081 .68507 L .33041 .68529 L F
.237 0 0 r
.33101 .68625 m .33113 .68488 L .33054 .68517 L F
.435 .268 .554 r
.33094 .68473 m .33099 .68503 L .33101 .68625 L F
.33099 .68503 m .33216 .69175 L .33101 .68625 L F
.237 0 0 r
.33101 .68625 m .33258 .68498 L .33112 .68502 L F
.33258 .68498 m .33297 .68466 L .33112 .68502 L F
.33101 .68625 m .33054 .68517 L .33094 .68473 L F
.33054 .68517 m .33045 .68497 L .33094 .68473 L F
.907 .799 .729 r
.32818 .68776 m .32816 .69215 L .33081 .68507 L F
.326 .69001 m .32608 .69009 L .32818 .68776 L F
.32608 .69009 m .32816 .69215 L .32818 .68776 L F
0 0 0 r
.3349 .68289 m .33367 .68347 L .33297 .68466 L F
.33367 .68347 m .33045 .68497 L .33113 .68488 L F
.33367 .68347 m .33113 .68488 L .33297 .68466 L F
.383 .086 .331 r
.33216 .69175 m .32816 .69215 L .32984 .69346 L F
0 .112 .609 r
.32984 .69346 m .32816 .69215 L .32735 .69135 L F
.32757 .69142 m .32735 .69135 L .326 .69001 L F
.32984 .69346 m .32735 .69135 L .32757 .69142 L F
0 0 .344 r
.32715 .69128 m .32703 .69232 L .3275 .69227 L F
.32678 .69116 m .32703 .69232 L .32715 .69128 L F
0 .023 .576 r
.3275 .69227 m .32703 .69232 L .3291 .6946 L F
.73 .202 0 r
.36055 .5024 m .36452 .50545 L .36246 .504 L F
.079 .596 .881 r
.53639 .41897 m .53741 .41838 L .53602 .41907 L F
.5389 .41825 m .53741 .41838 L .53639 .41897 L F
.612 .148 .128 r
.53741 .41838 m .54009 .41894 L .5384 .4178 L F
.53741 .41838 m .5384 .4178 L .53746 .41718 L F
.475 .28 .536 r
.53746 .41718 m .54009 .41894 L .54006 .41599 L F
.753 .646 .742 r
.52329 .44259 m .52159 .44543 L .51931 .44464 L F
.913 .743 .657 r
.52159 .44543 m .52075 .44847 L .51931 .44464 L F
.051 0 .367 r
.3103 .62961 m .31189 .62775 L .30932 .63099 L F
.474 .542 .846 r
.46786 .54999 m .46725 .55411 L .46597 .55039 L F
.46786 .54999 m .46948 .55367 L .46725 .55411 L F
.346 .366 .739 r
.47017 .5561 m .46725 .55411 L .46948 .55367 L F
.808 .98 .699 r
.29555 .66736 m .29771 .66608 L .29496 .66955 L F
0 .198 .723 r
.30157 .66492 m .29924 .66345 L .29865 .66246 L F
.732 .578 .681 r
.29775 .65974 m .30105 .65904 L .29865 .66246 L F
.625 .434 .603 r
.30105 .65904 m .30133 .66176 L .29865 .66246 L F
0 .198 .723 r
.30157 .66492 m .29865 .66246 L .30133 .66176 L F
.068 0 .315 r
.29865 .66246 m .299 .66317 L .29897 .66116 L F
.362 .417 .783 r
.30094 .66596 m .29951 .66653 L .29924 .66345 L F
0 .198 .723 r
.30157 .66492 m .30094 .66596 L .29924 .66345 L F
.068 0 .315 r
.299 .66317 m .30004 .66528 L .29927 .66231 L F
.299 .66317 m .29927 .66231 L .29897 .66116 L F
.741 .91 .538 r
.29872 .66404 m .29771 .66608 L .29789 .66499 L F
.29924 .66345 m .29851 .66471 L .29872 .66404 L F
.29851 .66471 m .29771 .66608 L .29872 .66404 L F
.706 .959 .697 r
.29789 .66499 m .29771 .66608 L .29555 .66736 L F
.653 .647 .831 r
.29924 .66345 m .29951 .66653 L .29771 .66608 L F
.403 .41 .753 r
.30082 .66913 m .29771 .66608 L .29951 .66653 L F
.383 .512 .864 r
.34978 .68429 m .34977 .68827 L .34805 .68615 L F
.34978 .68429 m .35178 .6881 L .34977 .68827 L F
.582 .111 .101 r
.24484 .62024 m .24249 .62174 L .24065 .62062 L F
.184 0 0 r
.24665 .62031 m .24484 .62024 L .24709 .61841 L F
.24665 .62031 m .24249 .62174 L .24484 .62024 L F
0 0 .26 r
.4409 .57005 m .44179 .57156 L .44365 .56941 L F
.559 .514 .762 r
.46358 .54155 m .46109 .54241 L .46007 .53832 L F
.422 .328 .643 r
.46358 .54155 m .46181 .54453 L .46109 .54241 L F
.049 0 0 r
.43249 .55176 m .43584 .551 L .4352 .55087 L F
.43249 .55176 m .43584 .551 L .4352 .55087 L F
0 0 .174 r
.43638 .54986 m .43584 .551 L .4352 .55087 L F
.802 .684 .735 r
.43777 .54688 m .43584 .551 L .43777 .54688 L F
0 0 .174 r
.43739 .549 m .43584 .551 L .43668 .54921 L F
.43739 .549 m .43668 .54921 L .43777 .54688 L F
.479 .178 .376 r
.43777 .54688 m .44 .54867 L .43739 .549 L F
.648 .163 .085 r
.44 .54867 m .43828 .54873 L .43739 .549 L F
0 0 .174 r
.43638 .54986 m .43584 .551 L .4352 .55087 L F
.43739 .549 m .43584 .551 L .43638 .54986 L F
.802 .684 .735 r
.43777 .54688 m .43584 .551 L .43369 .5465 L F
.57 .578 .823 r
.43369 .5465 m .43584 .551 L .43249 .55176 L F
.648 .163 .085 r
.43828 .54873 m .434 .54887 L .43739 .549 L F
0 0 .174 r
.43739 .549 m .43584 .551 L .43638 .54986 L F
.49 0 0 r
.25939 .61416 m .26284 .61492 L .26023 .61413 L F
.888 .656 .138 r
.58518 .38494 m .58472 .38598 L .5839 .38329 L F
.58518 .38494 m .58537 .38675 L .58472 .38598 L F
.249 .091 .461 r
.34279 .53818 m .34273 .54132 L .34107 .54169 L F
.683 .594 .75 r
.34273 .54132 m .34051 .5442 L .34107 .54169 L F
.727 .29 0 r
.70706 .27729 m .70801 .27825 L .70556 .27466 L F
.986 .754 .499 r
.70617 .27963 m .70801 .27825 L .70706 .27729 L F
.70617 .27963 m .70764 .28127 L .70801 .27825 L F
.016 .275 .774 r
.28342 .64395 m .28627 .6476 L .2847 .64683 L F
0 .436 .861 r
.37908 .62593 m .37923 .62688 L .37882 .62574 L F
.204 .179 .607 r
.37933 .62524 m .37932 .62738 L .37923 .62688 L F
.376 .108 .374 r
.3811 .62747 m .37933 .62524 L .37923 .62688 L F
.73 .939 .954 r
.3811 .62747 m .38284 .62805 L .38312 .6263 L F
.37973 .62826 m .38152 .62814 L .3811 .62747 L F
.38152 .62814 m .38284 .62805 L .3811 .62747 L F
0 .436 .861 r
.38101 .62734 m .37923 .62688 L .37908 .62593 L F
.376 .108 .374 r
.38127 .62753 m .38118 .62742 L .3811 .62747 L F
.38118 .62742 m .37933 .62524 L .3811 .62747 L F
.38118 .62742 m .38174 .62471 L .37933 .62524 L F
.3813 .62734 m .38174 .62471 L .38118 .62742 L F
.083 0 .271 r
.38321 .62373 m .38174 .62471 L .38132 .62721 L F
.38321 .62373 m .38132 .62721 L .3814 .62716 L F
.38321 .62373 m .3813 .62734 L .38142 .62723 L F
.47 .381 .673 r
.37933 .62524 m .38174 .62471 L .38094 .62158 L F
.317 .282 .66 r
.38094 .62158 m .38174 .62471 L .38321 .62373 L F
.811 .687 .728 r
.38321 .62373 m .38148 .62711 L .37882 .62574 L F
.083 0 .271 r
.3814 .62716 m .38132 .62721 L .3813 .62734 L F
.38142 .62723 m .3813 .62734 L .38127 .62753 L F
.73 .939 .954 r
.37973 .62826 m .38131 .62733 L .38142 .62723 L F
.811 .687 .728 r
.38148 .62711 m .38142 .62723 L .38117 .62729 L F
.73 .939 .954 r
.38132 .62725 m .38142 .62723 L .38154 .62712 L F
.37973 .62826 m .38142 .62723 L .38132 .62725 L F
.811 .687 .728 r
.38117 .62729 m .38127 .62753 L .38105 .62737 L F
.73 .939 .954 r
.38118 .62742 m .38314 .62616 L .38315 .6261 L F
.376 .108 .374 r
.38127 .62753 m .3813 .62734 L .38118 .62742 L F
.811 .687 .728 r
.38142 .62723 m .38127 .62753 L .38117 .62729 L F
.38148 .62711 m .38105 .62737 L .37882 .62574 L F
.609 .841 .464 r
.38088 .62736 m .38104 .62732 L .38195 .62592 L F
.385 .809 .626 r
.38117 .62729 m .38166 .627 L .37986 .62808 L F
.73 .939 .954 r
.37973 .62826 m .38118 .62742 L .38131 .62733 L F
0 .436 .861 r
.3811 .62747 m .37923 .62688 L .38101 .62734 L F
.73 .939 .954 r
.37956 .62827 m .37973 .62826 L .38315 .6261 L F
.379 .839 .903 r
.37931 .62896 m .38284 .62805 L .37956 .62827 L F
.385 .809 .626 r
.37986 .62808 m .38118 .62729 L .38104 .62732 L F
.37956 .62827 m .38117 .62729 L .37986 .62808 L F
0 0 0 r
.37809 .63093 m .37956 .62827 L .38104 .62732 L F
.609 .841 .464 r
.37933 .62944 m .38104 .62732 L .38088 .62736 L F
.385 .809 .626 r
.38118 .62729 m .38166 .627 L .38104 .62732 L F
.38166 .627 m .38315 .6261 L .38261 .62641 L F
.38166 .627 m .38261 .62641 L .38104 .62732 L F
.73 .939 .954 r
.38154 .62712 m .38131 .62733 L .38315 .6261 L F
.38118 .62742 m .38312 .6263 L .38314 .62616 L F
0 .436 .861 r
.38127 .62753 m .3811 .62747 L .38101 .62734 L F
.204 .179 .607 r
.37932 .62738 m .37931 .62896 L .37923 .62688 L F
.379 .839 .903 r
.37931 .62896 m .37956 .62827 L .37923 .62688 L F
.364 .603 .94 r
.56603 .4089 m .56876 .40961 L .56903 .40597 L F
.226 0 0 r
.56903 .40597 m .56924 .40235 L .56823 .40381 L F
.56903 .40597 m .56736 .40583 L .56924 .40235 L F
.563 .363 .569 r
.56876 .40961 m .57127 .40643 L .56903 .40597 L F
.226 0 0 r
.56903 .40597 m .57127 .40643 L .56736 .40583 L F
.303 0 0 r
.42804 .52754 m .42753 .52826 L .42461 .5288 L F
0 0 0 r
.4295 .52736 m .42753 .52826 L .42804 .52754 L F
.403 0 0 r
.60078 .46089 m .60233 .46218 L .59965 .46187 L F
.60078 .46089 m .60348 .46103 L .60233 .46218 L F
.322 0 0 r
.35454 .49889 m .35683 .49978 L .35841 .50023 L F
.738 .218 0 r
.35683 .49978 m .36055 .5024 L .35841 .50023 L F
.899 .897 .817 r
.67291 .39149 m .67376 .39063 L .67257 .38873 L F
.787 .874 .911 r
.67257 .38873 m .67376 .39063 L .67753 .38744 L F
.603 .224 .296 r
.28069 .51991 m .28476 .51988 L .28549 .51678 L F
.202 0 .177 r
.28664 .51878 m .28686 .51851 L .28764 .51559 L F
.643 .756 .931 r
.28996 .51478 m .28846 .51689 L .28764 .51559 L F
.781 .941 .594 r
.28674 .51895 m .28996 .51478 L .28764 .51559 L F
.699 .913 .57 r
.29008 .51454 m .28691 .51788 L .29074 .51319 L F
.28996 .51478 m .28952 .51522 L .29008 .51454 L F
.28952 .51522 m .28691 .51788 L .29008 .51454 L F
.202 0 .177 r
.28549 .51678 m .28664 .51878 L .28764 .51559 L F
.28664 .51878 m .28674 .51895 L .28686 .51851 L F
.28549 .51678 m .28476 .51988 L .28674 .51895 L F
.618 .412 .58 r
.4662 .4902 m .46976 .49324 L .46622 .49272 L F
.4662 .4902 m .46983 .48972 L .46976 .49324 L F
0 0 .545 r
.30099 .66873 m .29951 .66653 L .30094 .66596 L F
.30099 .66873 m .30082 .66913 L .29951 .66653 L F
.895 .84 .783 r
.35058 .51259 m .34566 .51396 L .34832 .51089 L F
.35058 .51259 m .34812 .5157 L .34566 .51396 L F
.764 .826 .901 r
.65421 .34503 m .65874 .34365 L .65712 .3418 L F
.796 .785 .843 r
.65874 .34365 m .6608 .34205 L .65712 .3418 L F
.422 .328 .643 r
.46358 .54155 m .46397 .54416 L .46181 .54453 L F
.749 .574 .659 r
.43282 .58602 m .43677 .5837 L .43383 .58325 L F
.43282 .58602 m .43757 .58677 L .43677 .5837 L F
.478 .406 .697 r
.43677 .5837 m .43966 .58576 L .43876 .58328 L F
.43677 .5837 m .43757 .58677 L .43966 .58576 L F
.628 .533 .727 r
.38815 .603 m .3896 .60811 L .38486 .60606 L F
.567 .435 .661 r
.38486 .60606 m .38778 .60617 L .38815 .603 L F
.544 .577 .838 r
.38486 .60606 m .3896 .60811 L .38778 .60617 L F
.479 .421 .714 r
.46107 .51511 m .46166 .51882 L .45933 .51929 L F
.549 .42 .658 r
.46166 .51882 m .45963 .52227 L .45933 .51929 L F
.762 .758 .849 r
.70291 .29423 m .70269 .29228 L .70269 .29286 L F
0 0 0 r
.7027 .29356 m .70269 .29286 L .70454 .29004 L F
.855 .772 .266 r
.70239 .29716 m .70269 .29286 L .701 .29579 L F
0 0 0 r
.70226 .2944 m .70269 .29286 L .7027 .29356 L F
.762 .758 .849 r
.70269 .29228 m .70245 .29017 L .70269 .29286 L F
.855 .772 .266 r
.70239 .29716 m .70291 .29423 L .70269 .29286 L F
.8 .501 .483 r
.47349 .46407 m .47754 .46491 L .47744 .46721 L F
.601 .473 .678 r
.47996 .4614 m .48028 .46424 L .47754 .46491 L F
.611 .382 .546 r
.48028 .46424 m .47744 .46721 L .47754 .46491 L F
.712 .298 .26 r
.43241 .52172 m .4321 .52411 L .43021 .52161 L F
.811 .948 .912 r
.67529 .33006 m .67632 .32703 L .67446 .32911 L F
.67529 .33006 m .67864 .32757 L .67632 .32703 L F
.455 .881 .795 r
.62965 .40181 m .63367 .4002 L .63193 .4011 L F
0 0 0 r
.63193 .4011 m .63367 .4002 L .63606 .39979 L F
0 .264 .771 r
.42525 .58467 m .42777 .58861 L .42478 .58591 L F
.17 .292 .747 r
.4284 .59034 m .42478 .58591 L .42777 .58861 L F
.853 .994 .834 r
.42121 .59659 m .42042 .59948 L .42284 .59682 L F
.85 .946 .587 r
.41883 .60107 m .42042 .59948 L .42121 .59659 L F
.124 .574 .921 r
.23262 .61328 m .23373 .61265 L .2305 .61152 L F
.23262 .61328 m .23483 .61365 L .23373 .61265 L F
.141 0 0 r
.32076 .55705 m .31977 .55737 L .31717 .5574 L F
0 0 0 r
.32359 .55438 m .32202 .55626 L .32076 .55705 L F
.389 .838 .733 r
.32202 .55626 m .31977 .55737 L .32076 .55705 L F
.783 .667 .736 r
.52192 .43879 m .52329 .44259 L .51947 .44175 L F
.753 .646 .742 r
.52329 .44259 m .51931 .44464 L .51947 .44175 L F
.666 .446 .577 r
.44385 .56649 m .44365 .56941 L .44576 .56715 L F
.176 0 .354 r
.31708 .6051 m .31962 .60195 L .31715 .60291 L F
.565 .652 .894 r
.66194 .39369 m .66324 .39689 L .66571 .39618 L F
.048 0 .032 r
.54191 .41221 m .5429 .41048 L .53986 .4134 L F
0 0 0 r
.54496 .40892 m .5429 .41048 L .54191 .41221 L F
.721 .189 0 r
.36367 .50639 m .36611 .50669 L .36452 .50545 L F
.36367 .50639 m .36706 .50795 L .36611 .50669 L F
.45 .289 .571 r
.36353 .67628 m .36345 .67944 L .36585 .67852 L F
.36353 .67628 m .36345 .67944 L .36585 .67852 L F
.589 .495 .716 r
.45959 .50649 m .45716 .50933 L .45712 .50743 L F
.663 .605 .78 r
.45983 .50854 m .45716 .50933 L .45959 .50649 L F
.476 .441 .739 r
.46042 .51373 m .45716 .50933 L .45983 .50854 L F
.903 .969 .812 r
.43419 .4647 m .43168 .46803 L .43182 .4654 L F
.915 .972 .786 r
.43168 .46803 m .42921 .46913 L .43182 .4654 L F
.779 .531 .561 r
.5363 .46146 m .53223 .46373 L .53222 .46099 L F
.5363 .46146 m .53621 .46442 L .53223 .46373 L F
.789 .54 .561 r
.53813 .46382 m .53621 .46442 L .5363 .46146 L F
.442 .498 .821 r
.56932 .3977 m .57066 .40078 L .57245 .39919 L F
0 0 0 r
.57245 .39919 m .57066 .40078 L .56924 .40235 L F
.45 .316 .605 r
.58315 .45769 m .5856 .45726 L .58512 .45461 L F
.415 .768 .995 r
.58179 .45532 m .5856 .45726 L .58315 .45769 L F
.639 .374 .501 r
.31155 .62175 m .314 .6245 L .31126 .62446 L F
.174 .237 .689 r
.30977 .64233 m .30756 .64016 L .30777 .63962 L F
.788 .416 .353 r
.30977 .64233 m .31115 .63856 L .30798 .63791 L F
.30777 .63962 m .30798 .63791 L .30625 .63756 L F
.30977 .64233 m .30798 .63791 L .30777 .63962 L F
0 0 .009 r
.3076 .64096 m .30756 .64016 L .30716 .64241 L F
.174 .237 .689 r
.30977 .64233 m .30777 .63962 L .30885 .63674 L F
.688 .23 .16 r
.30837 .6359 m .30887 .6365 L .30818 .63607 L F
.174 .237 .689 r
.30977 .64233 m .30885 .63674 L .30904 .63693 L F
.788 .416 .353 r
.30977 .64233 m .30625 .63756 L .30614 .63754 L F
.30977 .64233 m .30776 .63967 L .30756 .64016 L F
.30776 .63967 m .30614 .63754 L .30756 .64016 L F
0 0 .009 r
.30885 .63684 m .30777 .63962 L .30776 .63967 L F
.30865 .63751 m .30776 .63967 L .3076 .64096 L F
.30885 .63684 m .30776 .63967 L .30865 .63751 L F
.30903 .63693 m .30716 .64241 L .30958 .64224 L F
.688 .23 .16 r
.30887 .6365 m .30938 .63711 L .30899 .63683 L F
.30887 .63656 m .30899 .63683 L .30885 .63674 L F
.30887 .6365 m .30899 .63683 L .30887 .63656 L F
.86 .872 .846 r
.31062 .63809 m .30977 .64233 L .30904 .63693 L F
.688 .23 .16 r
.30938 .63711 m .30953 .63729 L .30908 .63696 L F
.30938 .63711 m .30906 .63695 L .30885 .63674 L F
0 0 .39 r
.30918 .63729 m .31003 .64079 L .31062 .63809 L F
.688 .23 .16 r
.30984 .63765 m .31062 .63809 L .31015 .63803 L F
.30837 .6359 m .31062 .63809 L .30984 .63765 L F
.86 .872 .846 r
.31062 .63809 m .30904 .63693 L .30898 .63642 L F
.688 .23 .16 r
.30908 .63696 m .31015 .63803 L .30906 .63695 L F
.30953 .63729 m .31015 .63803 L .30908 .63696 L F
0 0 .39 r
.30898 .63642 m .30918 .63729 L .31062 .63809 L F
.30918 .63729 m .30958 .64224 L .31003 .64079 L F
.30898 .63642 m .30903 .63693 L .30918 .63729 L F
.30903 .63693 m .30958 .64224 L .30918 .63729 L F
.174 .237 .689 r
.30904 .63693 m .30885 .63674 L .30898 .63642 L F
0 0 .009 r
.30898 .63642 m .30885 .63684 L .30903 .63693 L F
.30885 .63684 m .30716 .64241 L .30903 .63693 L F
.688 .23 .16 r
.30887 .6365 m .30885 .63674 L .30818 .63607 L F
0 0 .009 r
.30898 .63642 m .30885 .63674 L .30885 .63684 L F
.30885 .63674 m .30777 .63962 L .30885 .63684 L F
.688 .23 .16 r
.30818 .63607 m .31015 .63803 L .30653 .63756 L F
0 0 .009 r
.30777 .63962 m .30756 .64016 L .3076 .64096 L F
.903 .969 .812 r
.43419 .4647 m .43182 .4654 L .43329 .46432 L F
.583 .871 .994 r
.43692 .46383 m .43419 .4647 L .43516 .46286 L F
.655 .945 .958 r
.43419 .4647 m .43329 .46432 L .43516 .46286 L F
.733 .934 .602 r
.39178 .60583 m .3894 .60901 L .39002 .60748 L F
0 0 0 r
.3894 .60901 m .38941 .60985 L .39002 .60748 L F
.3894 .60901 m .38893 .61176 L .38941 .60985 L F
.37 .825 .722 r
.57979 .42671 m .57579 .42839 L .57862 .42554 L F
.823 .84 .861 r
.58097 .4219 m .57979 .42671 L .57862 .42554 L F
.58097 .4219 m .58302 .42379 L .57979 .42671 L F
.882 .449 .125 r
.27809 .62625 m .27889 .62485 L .27746 .62366 L F
.27809 .62625 m .27963 .62761 L .27889 .62485 L F
.753 .832 .912 r
.65712 .3418 m .6608 .34205 L .65971 .3402 L F
.84 .86 .858 r
.65971 .3402 m .6608 .34205 L .66348 .33894 L F
.553 .43 .666 r
.46103 .49899 m .45863 .50432 L .45849 .49961 L F
.645 .35 .457 r
.34174 .56631 m .34552 .56405 L .34231 .56408 L F
.674 .877 .975 r
.34293 .56437 m .34231 .56408 L .34552 .56405 L F
.34293 .56437 m .34174 .56631 L .34231 .56408 L F
.978 .684 .379 r
.53704 .40541 m .53846 .40699 L .53701 .40816 L F
.583 .761 .963 r
.5405 .40482 m .53846 .40699 L .53704 .40541 L F
.562 .872 .579 r
.53701 .40816 m .53846 .40699 L .5405 .40482 L F
.237 .127 .52 r
.53986 .4134 m .54181 .41503 L .54191 .41221 L F
.53986 .4134 m .54006 .41599 L .54181 .41503 L F
.772 .266 0 r
.26734 .57623 m .26353 .5731 L .26499 .57689 L F
.748 .68 .785 r
.4005 .66932 m .40292 .67302 L .39852 .67368 L F
1 .802 .479 r
.40292 .67302 m .4014 .67478 L .39852 .67368 L F
.40292 .67302 m .40252 .67609 L .4014 .67478 L F
0 0 .514 r
.4016 .67064 m .40292 .67302 L .4005 .66932 L F
1 .802 .479 r
.4014 .67478 m .40292 .67302 L .4016 .67064 L F
.4014 .67478 m .40252 .67609 L .40292 .67302 L F
.97 .681 .276 r
.40079 .56593 m .40148 .56485 L .40066 .56323 L F
.40079 .56593 m .40192 .56737 L .40148 .56485 L F
.647 .881 .984 r
.539 .42602 m .54262 .42619 L .54126 .42495 L F
.539 .42602 m .54262 .42619 L .54126 .42495 L F
.823 .982 .883 r
.29156 .51356 m .29467 .5132 L .29031 .51647 L F
.549 .113 .163 r
.29156 .51356 m .29655 .51182 L .29467 .5132 L F
.564 .499 .741 r
.46155 .53127 m .45842 .52925 L .46095 .52859 L F
.781 .602 .658 r
.34992 .55986 m .35406 .56039 L .35484 .55525 L F
.61 .502 .706 r
.35484 .55525 m .35672 .55601 L .35668 .55424 L F
0 0 .019 r
.35484 .55525 m .35473 .55853 L .35672 .55601 L F
.35484 .55525 m .35406 .56039 L .35473 .55853 L F
.683 .877 .494 r
.6952 .2867 m .69598 .28588 L .69508 .28711 L F
0 0 0 r
.69819 .2844 m .69598 .28588 L .6952 .2867 L F
.344 .088 .374 r
.40147 .66664 m .39874 .66997 L .39948 .66792 L F
.40147 .66664 m .4005 .66932 L .39874 .66997 L F
.709 .888 .504 r
.40273 .66284 m .40066 .66569 L .40147 .66664 L F
0 0 .123 r
.40066 .66569 m .4005 .66932 L .40147 .66664 L F
.34 .042 .305 r
.43289 .53469 m .42961 .53807 L .4297 .53484 L F
.725 .521 .615 r
.36352 .64483 m .3652 .64299 L .36265 .64246 L F
.429 .485 .816 r
.26434 .54493 m .26544 .54083 L .26292 .54098 L F
0 .121 .653 r
.28799 .63778 m .28467 .63411 L .28618 .63358 L F
.399 .612 .936 r
.58067 .42115 m .58505 .42246 L .5846 .41974 L F
.797 .521 .52 r
.5846 .41974 m .58097 .4219 L .58067 .42115 L F
.847 .814 .817 r
.64097 .40576 m .64212 .4089 L .64053 .41077 L F
.819 .802 .835 r
.64097 .40576 m .64484 .40602 L .64212 .4089 L F
.436 .54 .864 r
.4319 .59847 m .43355 .60024 L .43317 .59564 L F
.563 .643 .888 r
.43317 .59564 m .43355 .60024 L .43621 .59965 L F
.628 .468 .646 r
.31301 .64417 m .31383 .64764 L .31101 .64685 L F
.956 .81 .37 r
.31301 .64417 m .3129 .64083 L .31342 .64307 L F
.701 .902 .541 r
.31342 .64307 m .31301 .64417 L .31157 .64573 L F
.232 .21 .627 r
.31438 .646 m .31383 .64764 L .31301 .64417 L F
.739 .308 .227 r
.31157 .64573 m .31438 .646 L .31348 .6448 L F
.648 .362 .471 r
.31101 .64685 m .31383 .64764 L .3129 .64972 L F
0 .073 .625 r
.31101 .64685 m .3129 .64972 L .31157 .64573 L F
.561 .914 .964 r
.30898 .64675 m .31101 .64685 L .31157 .64573 L F
.829 .693 .714 r
.31157 .64573 m .3129 .64972 L .31438 .646 L F
.145 .678 .859 r
.31157 .64573 m .31351 .64591 L .3139 .64564 L F
.31351 .64591 m .31438 .646 L .3139 .64564 L F
0 0 0 r
.3144 .6453 m .3139 .64564 L .31562 .64432 L F
.31188 .64731 m .3139 .64564 L .3144 .6453 L F
.195 0 0 r
.30992 .64654 m .31157 .64573 L .3139 .64564 L F
.30913 .64672 m .31157 .64573 L .30992 .64654 L F
.739 .308 .227 r
.31157 .64573 m .31348 .6448 L .31301 .64417 L F
.698 .473 0 r
.4022 .65975 m .40268 .66256 L .40273 .66284 L F
.709 .888 .504 r
.40273 .66284 m .40268 .66256 L .40066 .66569 L F
.934 .748 .626 r
.33246 .62794 m .3333 .62924 L .33126 .63084 L F
.85 .564 .503 r
.33126 .63084 m .3333 .62924 L .33177 .63292 L F
.486 .454 .747 r
.33523 .62719 m .3333 .62924 L .33246 .62794 L F
.33523 .62719 m .3362 .63126 L .3333 .62924 L F
.802 .634 .673 r
.3362 .63126 m .33177 .63292 L .3333 .62924 L F
.688 .44 .543 r
.4698 .47438 m .47246 .47641 L .47007 .47727 L F
.49 .883 .96 r
.24648 .52466 m .24739 .52352 L .25008 .52356 L F
.24648 .52466 m .24536 .52432 L .24739 .52352 L F
0 0 0 r
.69607 .30806 m .6966 .3072 L .699 .30597 L F
.773 .795 .87 r
.29838 .5141 m .29894 .5111 L .29848 .51359 L F
0 .125 .649 r
.29966 .51238 m .29848 .51359 L .29839 .51113 L F
.519 .916 .838 r
.2986 .51298 m .29848 .51359 L .29966 .51238 L F
.29741 .51365 m .29848 .51359 L .2986 .51298 L F
.773 .795 .87 r
.29809 .51566 m .29838 .5141 L .29848 .51359 L F
.843 .992 .736 r
.29848 .51359 m .2972 .51563 L .29809 .51566 L F
.597 .939 .94 r
.25008 .52356 m .24882 .52254 L .25251 .52259 L F
.25008 .52356 m .24739 .52352 L .24882 .52254 L F
.675 .813 .949 r
.5434 .38947 m .54503 .39149 L .54363 .39163 L F
.5434 .38947 m .54503 .39149 L .54363 .39163 L F
.723 .587 .704 r
.54503 .39149 m .54222 .39406 L .54363 .39163 L F
.591 .777 .969 r
.54769 .39053 m .54503 .39149 L .5434 .38947 L F
.54769 .39053 m .54503 .39149 L .5434 .38947 L F
.847 .814 .817 r
.64097 .40576 m .64053 .41077 L .63872 .40933 L F
.91 .835 .759 r
.64053 .41077 m .63951 .413 L .63872 .40933 L F
.641 .355 .468 r
.38973 .58034 m .39227 .58254 L .38954 .58301 L F
.38973 .58034 m .39236 .58008 L .39227 .58254 L F
.688 .592 .743 r
.43249 .55176 m .43015 .55229 L .42866 .54773 L F
.311 0 .148 r
.43249 .55176 m .42977 .55365 L .43015 .55229 L F
.63 .808 .968 r
.61137 .38387 m .61133 .38168 L .60974 .38318 L F
.61137 .38387 m .61302 .38354 L .61133 .38168 L F
.822 .347 0 r
.61307 .38688 m .61137 .38387 L .60974 .38318 L F
.66 .615 .793 r
.61137 .38387 m .61459 .3852 L .61302 .38354 L F
.954 .697 .508 r
.61307 .38688 m .61459 .3852 L .61137 .38387 L F
.85 .894 .868 r
.32757 .55854 m .32373 .55999 L .32588 .55748 L F
.305 .72 .975 r
.328 .55728 m .32757 .55854 L .32588 .55748 L F
.328 .55728 m .33052 .55854 L .32757 .55854 L F
.487 .294 .545 r
.34756 .54492 m .3502 .54112 L .34719 .54152 L F
.338 .114 .42 r
.3058 .50872 m .30426 .5086 L .30333 .51224 L F
0 0 0 r
.29555 .66736 m .29496 .66955 L .2946 .67108 L F
.513 .348 .594 r
.36926 .5816 m .36963 .58575 L .36716 .58668 L F
.095 .044 .503 r
.37117 .58493 m .36926 .5816 L .37242 .58276 L F
.37117 .58493 m .36963 .58575 L .36926 .5816 L F
.612 .39 .556 r
.46486 .49618 m .46103 .49899 L .46094 .49662 L F
.713 .491 .587 r
.61459 .3852 m .61565 .38064 L .61302 .38354 L F
.848 .924 .534 r
.29746 .55752 m .29703 .55741 L .29853 .55389 L F
.846 .817 .821 r
.29853 .55389 m .29703 .55741 L .29711 .55473 L F
0 .045 .569 r
.29703 .55741 m .29749 .55825 L .29711 .55473 L F
.29749 .55825 m .29792 .55904 L .29779 .55834 L F
.848 .924 .534 r
.29746 .55752 m .29853 .55389 L .30007 .557 L F
0 .045 .569 r
.29749 .55825 m .29779 .55834 L .29711 .55473 L F
.166 0 0 r
.29336 .55887 m .29665 .55849 L .29697 .55811 L F
.29628 .55791 m .29697 .55811 L .29746 .55752 L F
.29336 .55887 m .29697 .55811 L .29628 .55791 L F
.9 .846 .39 r
.29746 .55752 m .29665 .55849 L .29703 .55741 L F
.942 .874 .741 r
.52415 .42202 m .52387 .42648 L .52122 .42538 L F
.847 .66 .649 r
.52387 .42648 m .52315 .42914 L .52122 .42538 L F
.976 .739 .514 r
.40087 .65614 m .4022 .65975 L .40256 .657 L F
0 0 .33 r
.32095 .61839 m .32238 .61862 L .3209 .61852 L F
.32224 .61509 m .32234 .61751 L .32095 .61839 L F
.32234 .61751 m .32238 .61862 L .32095 .61839 L F
.498 .23 .438 r
.32446 .6168 m .32224 .61509 L .32543 .61443 L F
0 0 .104 r
.32623 .6158 m .32446 .6168 L .32543 .61443 L F
.759 .672 .765 r
.32623 .6158 m .32419 .61633 L .32446 .6168 L F
.498 .23 .438 r
.32446 .6168 m .32243 .61977 L .32224 .61509 L F
.759 .672 .765 r
.32419 .61633 m .32039 .61731 L .3232 .61696 L F
.32419 .61633 m .3232 .61696 L .32446 .6168 L F
0 .221 .737 r
.32171 .61957 m .32501 .62283 L .32237 .62069 L F
.672 .186 0 r
.32171 .61957 m .3209 .61852 L .32213 .61953 L F
.006 .038 .543 r
.32237 .62069 m .32153 .62165 L .3209 .61852 L F
.672 .186 0 r
.32123 .61961 m .32237 .62069 L .3218 .61985 L F
.32123 .61961 m .3218 .61985 L .3209 .61852 L F
.738 .753 .864 r
.3171 .61915 m .32123 .61961 L .31927 .61805 L F
.534 0 0 r
.3171 .61915 m .31925 .62048 L .32123 .61961 L F
.69 .968 .753 r
.32123 .61961 m .31925 .62048 L .32058 .61934 L F
.672 .186 0 r
.32197 .61971 m .32213 .61953 L .32243 .61977 L F
0 .221 .737 r
.32171 .61957 m .32199 .62004 L .32123 .61961 L F
.672 .186 0 r
.32123 .61961 m .32171 .61957 L .32197 .61971 L F
.32171 .61957 m .32213 .61953 L .32197 .61971 L F
0 0 .33 r
.32238 .61862 m .32243 .61977 L .32213 .61953 L F
.798 .613 .651 r
.3216 .61929 m .32243 .61977 L .32446 .6168 L F
0 .221 .737 r
.32161 .61939 m .32179 .61951 L .32171 .61957 L F
.32179 .61951 m .32197 .61971 L .32171 .61957 L F
.672 .186 0 r
.32123 .61961 m .32112 .61924 L .32171 .61957 L F
.32112 .61924 m .3209 .61852 L .32171 .61957 L F
0 .221 .737 r
.3205 .61761 m .32171 .61957 L .32123 .61961 L F
.32039 .61731 m .32053 .61756 L .3205 .61761 L F
.32053 .61756 m .32171 .61957 L .3205 .61761 L F
0 0 .33 r
.32238 .61862 m .32213 .61953 L .3209 .61852 L F
0 .221 .737 r
.32053 .61756 m .32055 .61758 L .32161 .61939 L F
.32055 .61758 m .32161 .61932 L .32161 .61939 L F
.798 .613 .651 r
.32123 .61961 m .3216 .61929 L .32054 .61756 L F
.32123 .61961 m .32054 .61756 L .3205 .61761 L F
.3216 .61929 m .32446 .6168 L .32039 .61731 L F
0 .221 .737 r
.32055 .61758 m .32168 .61885 L .32161 .61932 L F
.32067 .61764 m .32168 .61885 L .32053 .61756 L F
0 0 .301 r
.32658 .61893 m .32501 .62283 L .32605 .61887 L F
.32716 .61899 m .32667 .61987 L .32658 .61893 L F
.32667 .61987 m .32501 .62283 L .32658 .61893 L F
.286 0 .045 r
.33118 .62154 m .32714 .62438 L .32995 .62402 L F
.486 .154 .328 r
.32931 .62653 m .32995 .62402 L .32714 .62438 L F
.402 .462 .808 r
.32716 .61899 m .32765 .62016 L .32501 .62283 L F
.32765 .62016 m .32939 .62436 L .32765 .62375 L F
.32765 .62016 m .32765 .62375 L .32501 .62283 L F
.984 .906 .62 r
.32656 .61921 m .32742 .6209 L .32765 .62005 L F
.702 .407 0 r
.33267 .62465 m .32995 .62402 L .32931 .62653 L F
.793 .662 .718 r
.32825 .61781 m .32764 .62008 L .32716 .61899 L F
.984 .906 .62 r
.32799 .61802 m .32765 .62005 L .32825 .61781 L F
.115 .277 .752 r
.3301 .62473 m .32954 .62444 L .32764 .62008 L F
.32762 .61988 m .32764 .62008 L .32716 .61899 L F
.3301 .62473 m .32764 .62008 L .32762 .61988 L F
.32954 .62444 m .32939 .62436 L .32716 .61899 L F
.793 .662 .718 r
.32764 .62008 m .32742 .6209 L .32716 .61899 L F
.115 .277 .752 r
.3301 .62473 m .32762 .61988 L .32742 .6209 L F
.32762 .61988 m .32716 .61899 L .32742 .6209 L F
.984 .906 .62 r
.32765 .61831 m .32765 .61975 L .32799 .61802 L F
.32765 .61975 m .32765 .62005 L .32799 .61802 L F
.511 .601 .88 r
.32716 .61899 m .32689 .61947 L .32691 .61892 L F
.32689 .61947 m .32651 .62017 L .32691 .61892 L F
.759 .672 .765 r
.32623 .6158 m .32605 .61887 L .32039 .61731 L F
.179 .094 .515 r
.32842 .61688 m .32605 .61887 L .32623 .6158 L F
.452 .081 .242 r
.32986 .61298 m .32854 .61682 L .32663 .61598 L F
.32632 .61573 m .32663 .61598 L .32623 .6158 L F
.32986 .61298 m .32663 .61598 L .32632 .61573 L F
.738 .626 .734 r
.32854 .61682 m .32957 .61636 L .33109 .6147 L F
.219 0 .151 r
.33109 .6147 m .32851 .61693 L .32854 .61682 L F
.33109 .6147 m .32854 .61682 L .32986 .61298 L F
.738 .626 .734 r
.32842 .61688 m .32854 .61682 L .33109 .6147 L F
.32836 .61432 m .32842 .61688 L .33109 .6147 L F
.32842 .61688 m .32843 .61761 L .32957 .61636 L F
.452 .081 .242 r
.32854 .61682 m .32851 .61693 L .32842 .61688 L F
.32854 .61682 m .32842 .61688 L .32669 .61603 L F
.32663 .61598 m .32669 .61603 L .32623 .6158 L F
.32854 .61682 m .32669 .61603 L .32663 .61598 L F
.179 .094 .515 r
.32851 .61693 m .32842 .617 L .32842 .61688 L F
.32842 .617 m .32605 .61887 L .32842 .61688 L F
0 0 .104 r
.32623 .6158 m .32543 .61443 L .32796 .61399 L F
.452 .081 .242 r
.32986 .61298 m .32623 .6158 L .32796 .61399 L F
.179 .094 .515 r
.32842 .617 m .32825 .61781 L .32605 .61887 L F
.738 .626 .734 r
.32688 .61412 m .32834 .61739 L .32836 .61432 L F
.32834 .61739 m .32843 .61761 L .32842 .617 L F
.32834 .61739 m .32842 .617 L .32836 .61432 L F
.179 .094 .515 r
.32851 .61693 m .32825 .61781 L .32842 .617 L F
0 .135 .665 r
.32902 .61628 m .32843 .61744 L .32688 .61412 L F
.738 .626 .734 r
.32688 .61412 m .32825 .61781 L .32843 .61761 L F
0 .135 .665 r
.32843 .61744 m .32825 .61781 L .32798 .61708 L F
.32843 .61744 m .32798 .61708 L .32688 .61412 L F
.32902 .61628 m .32843 .61744 L .32688 .61412 L F
.32843 .61744 m .32825 .61781 L .32798 .61708 L F
.32843 .61744 m .32798 .61708 L .32688 .61412 L F
.793 .662 .718 r
.32825 .61781 m .32716 .61899 L .32605 .61887 L F
.511 .601 .88 r
.32716 .61899 m .32039 .61731 L .32605 .61887 L F
.32691 .61892 m .32662 .6198 L .32039 .61731 L F
.701 .937 .633 r
.32902 .61628 m .32656 .61921 L .32766 .6183 L F
.32892 .61647 m .32766 .6183 L .32825 .61781 L F
.794 .722 .784 r
.33109 .6147 m .32825 .61781 L .32851 .61693 L F
.701 .937 .633 r
.32902 .61628 m .32766 .6183 L .32892 .61647 L F
.511 .601 .88 r
.32662 .6198 m .32651 .62017 L .3264 .62012 L F
.32662 .6198 m .3264 .62012 L .32039 .61731 L F
.984 .906 .62 r
.32656 .61921 m .32765 .62005 L .32765 .61831 L F
.741 .382 .371 r
.32681 .62129 m .3283 .62331 L .32742 .6209 L F
.511 .601 .88 r
.32651 .62017 m .32501 .62283 L .32179 .61898 L F
0 .221 .737 r
.32276 .62014 m .32501 .62283 L .32171 .61957 L F
.148 .313 .775 r
.32501 .62283 m .32374 .62444 L .32237 .62069 L F
.563 .024 0 r
.32931 .62653 m .32501 .62283 L .32939 .62436 L F
.741 .382 .371 r
.32408 .62302 m .327 .62322 L .32681 .62129 L F
.327 .62322 m .3283 .62331 L .32681 .62129 L F
.511 .601 .88 r
.32651 .62017 m .32179 .61898 L .32168 .61885 L F
.32225 .61818 m .32168 .61885 L .32039 .61731 L F
.32651 .62017 m .32168 .61885 L .32225 .61818 L F
.359 .64 .961 r
.32161 .61894 m .32123 .61961 L .31982 .61849 L F
.69 .968 .753 r
.32141 .61918 m .32058 .61934 L .32176 .61833 L F
.32123 .61961 m .3211 .61956 L .32141 .61918 L F
.3211 .61956 m .32058 .61934 L .32141 .61918 L F
.359 .64 .961 r
.32214 .618 m .32161 .61894 L .31927 .61805 L F
.32161 .61894 m .31982 .61849 L .31927 .61805 L F
.399 .103 .343 r
.32214 .618 m .31925 .62048 L .31926 .61898 L F
.32012 .61803 m .31926 .61898 L .31927 .61805 L F
.32214 .618 m .31926 .61898 L .32012 .61803 L F
.798 .613 .651 r
.3205 .61761 m .32054 .61756 L .32039 .61731 L F
0 .221 .737 r
.32039 .61731 m .32067 .61764 L .32053 .61756 L F
.399 .103 .343 r
.32023 .61803 m .31925 .62048 L .32176 .61833 L F
.32126 .61802 m .32176 .61833 L .32214 .618 L F
.32023 .61803 m .32176 .61833 L .32126 .61802 L F
.31927 .61805 m .31926 .61957 L .32023 .61803 L F
.31926 .61957 m .31925 .62048 L .32023 .61803 L F
.798 .613 .651 r
.32123 .61961 m .32197 .61971 L .3216 .61929 L F
.32197 .61971 m .32243 .61977 L .3216 .61929 L F
0 .221 .737 r
.32179 .61951 m .32276 .62014 L .32197 .61971 L F
.32168 .61885 m .32276 .62014 L .32161 .61939 L F
.69 .968 .753 r
.32169 .6188 m .32176 .61833 L .32214 .618 L F
.32123 .61961 m .32176 .61833 L .32169 .6188 L F
0 .221 .737 r
.32199 .62004 m .32237 .62069 L .32192 .62027 L F
.32199 .62004 m .32192 .62027 L .32123 .61961 L F
0 .143 .671 r
.22606 .56223 m .2254 .56404 L .2241 .56001 L F
.119 .343 .809 r
.22606 .56223 m .22808 .56591 L .2254 .56404 L F
.809 .668 .708 r
.5202 .43499 m .52412 .43571 L .52192 .43879 L F
.564 .428 .654 r
.45863 .50432 m .45959 .50649 L .45712 .50743 L F
.972 .749 .542 r
.56472 .4091 m .56611 .41296 L .56603 .4089 L F
.755 .662 .76 r
.56736 .40583 m .56472 .4091 L .56603 .4089 L F
.722 .988 .874 r
.37706 .66897 m .37593 .67042 L .37353 .67082 L F
.945 .742 .598 r
.35278 .6793 m .35526 .67973 L .35526 .67819 L F
.35278 .6793 m .35453 .68235 L .35526 .67973 L F
.883 .451 .136 r
.36941 .67128 m .36953 .66909 L .36702 .66885 L F
.586 .562 .795 r
.32619 .55385 m .32359 .55438 L .32233 .55092 L F
.142 0 0 r
.32518 .55468 m .32359 .55438 L .32619 .55385 L F
.32518 .55468 m .32202 .55626 L .32359 .55438 L F
.832 .945 .897 r
.67632 .32703 m .67864 .32757 L .68025 .32516 L F
.561 .721 .949 r
.35744 .71119 m .36096 .71213 L .35758 .71067 L F
.739 .571 .666 r
.3588 .71755 m .36151 .71228 L .35744 .71119 L F
.029 .143 .65 r
.35728 .71045 m .35744 .71119 L .35804 .70895 L F
.494 0 0 r
.35502 .70981 m .35669 .71028 L .35938 .71201 L F
.35669 .71028 m .35728 .71045 L .35756 .71066 L F
.35669 .71028 m .35756 .71066 L .35938 .71201 L F
.561 .721 .949 r
.35758 .71067 m .36151 .71228 L .35804 .70895 L F
.36096 .71213 m .36151 .71228 L .35758 .71067 L F
.662 .895 .98 r
.36151 .71228 m .36377 .71031 L .35804 .70895 L F
.36151 .71228 m .36387 .71117 L .36377 .71031 L F
.548 .348 .561 r
.70392 .30989 m .70665 .30962 L .70384 .30755 L F
.642 .295 .367 r
.70384 .30755 m .70665 .30962 L .7061 .30768 L F
.719 .287 .222 r
.36248 .68868 m .36284 .68785 L .35866 .686 L F
.573 .065 .007 r
.56294 .39929 m .56536 .39934 L .56354 .3984 L F
.953 .84 .695 r
.64578 .4199 m .64586 .41548 L .64381 .41877 L F
.939 .74 .607 r
.64518 .42257 m .64578 .4199 L .64381 .41877 L F
.528 .005 0 r
.58022 .39474 m .57916 .39356 L .57769 .39256 L F
.58022 .39474 m .58163 .39592 L .57916 .39356 L F
.791 .879 .911 r
.38374 .61575 m .37947 .61684 L .38199 .6149 L F
.487 .9 .895 r
.38447 .61489 m .38374 .61575 L .38199 .6149 L F
.38447 .61489 m .38633 .61482 L .38374 .61575 L F
.712 .74 .874 r
.71394 .31647 m .71324 .32038 L .71224 .3165 L F
.71394 .31647 m .71596 .31951 L .71324 .32038 L F
.952 .867 .717 r
.39429 .60791 m .39763 .60531 L .39627 .60456 L F
.39429 .60791 m .39588 .60913 L .39763 .60531 L F
.832 .796 .817 r
.63872 .40933 m .63951 .413 L .63596 .41252 L F
.958 .885 .718 r
.61986 .40014 m .62077 .40015 L .61919 .39771 L F
.712 .839 .943 r
.5434 .38947 m .54363 .39163 L .54166 .39103 L F
0 0 0 r
.33803 .4952 m .33727 .49519 L .33573 .49526 L F
.33803 .4952 m .33949 .49457 L .33727 .49519 L F
.588 .323 .483 r
.35147 .65107 m .35325 .65254 L .35176 .65425 L F
.35325 .65254 m .35395 .65313 L .353 .65361 L F
.35325 .65254 m .353 .65361 L .35176 .65425 L F
.35147 .65107 m .35416 .65041 L .35395 .65313 L F
.245 0 0 r
.35147 .65107 m .35416 .65041 L .35211 .65241 L F
.977 .904 .566 r
.35322 .64984 m .35379 .65018 L .35211 .65241 L F
.35379 .65018 m .35416 .65041 L .35362 .65093 L F
.35379 .65018 m .35362 .65093 L .35211 .65241 L F
.245 0 0 r
.35147 .65107 m .35211 .65241 L .34959 .65248 L F
.766 .808 .887 r
.68265 .3832 m .68421 .38503 L .68616 .38333 L F
.708 .592 .723 r
.33365 .50943 m .33095 .51013 L .32937 .50608 L F
.619 .058 0 r
.40549 .50315 m .40806 .50537 L .40947 .50578 L F
.405 .815 .615 r
.40947 .50578 m .41091 .50479 L .41294 .50353 L F
.39 .833 .941 r
.40947 .50578 m .40806 .50537 L .41091 .50479 L F
.554 .046 0 r
.35486 .69233 m .35619 .69356 L .35392 .69288 L F
.35486 .69233 m .35739 .69478 L .35619 .69356 L F
.787 .334 .17 r
.38815 .69416 m .3905 .69316 L .38604 .69151 L F
.275 0 0 r
.38815 .69416 m .39218 .69356 L .3905 .69316 L F
.3 0 0 r
.3905 .69316 m .39218 .69356 L .3929 .69307 L F
.487 .285 .531 r
.32043 .58659 m .32324 .58617 L .32324 .5832 L F
.424 .111 .328 r
.32043 .58659 m .31974 .58872 L .32324 .58617 L F
.794 .865 .901 r
.64394 .33961 m .64089 .33918 L .64254 .3381 L F
.83 .867 .872 r
.64671 .33672 m .64394 .33961 L .64254 .3381 L F
.119 .016 .452 r
.21045 .57368 m .21223 .57511 L .21212 .57229 L F
.21045 .57368 m .21039 .57653 L .21223 .57511 L F
.859 .413 .134 r
.40099 .65065 m .39664 .64727 L .3997 .64963 L F
.943 .587 .199 r
.3997 .64963 m .40172 .65341 L .40099 .65065 L F
.3997 .64963 m .40172 .65341 L .40099 .65065 L F
.797 .521 .52 r
.5846 .41974 m .58505 .42246 L .58097 .4219 L F
.708 .592 .723 r
.33365 .50943 m .32937 .50608 L .33155 .50538 L F
.632 .554 .749 r
.40036 .49574 m .39792 .4971 L .39719 .49331 L F
.674 .572 .732 r
.46967 .47942 m .4685 .48397 L .4675 .48032 L F
.379 .836 .915 r
.38958 .5882 m .38717 .58911 L .38616 .58861 L F
.168 0 .268 r
.38958 .5882 m .38717 .58911 L .38682 .59167 L F
.388 .813 .968 r
.42284 .59682 m .42331 .59513 L .42121 .59659 L F
.42284 .59682 m .42526 .59634 L .42331 .59513 L F
.761 .671 .762 r
.35144 .66931 m .35216 .67281 L .34877 .6727 L F
.144 .234 .699 r
.35396 .67198 m .35216 .67281 L .35144 .66931 L F
.329 .814 .819 r
.35094 .67282 m .35216 .67281 L .35396 .67198 L F
.139 .322 .786 r
.35486 .69233 m .35392 .69288 L .35178 .6881 L F
0 0 0 r
.35299 .69476 m .35392 .69288 L .35486 .69233 L F
.554 .046 0 r
.35486 .69233 m .35392 .69288 L .35299 .69476 L F
.406 .549 .885 r
.27579 .62001 m .27443 .62215 L .27361 .62006 L F
.301 .408 .805 r
.27579 .62001 m .27746 .62366 L .27443 .62215 L F
0 0 .48 r
.58472 .38598 m .58537 .38675 L .58759 .38922 L F
.645 .149 0 r
.58537 .38675 m .58878 .39065 L .58759 .38922 L F
0 0 .245 r
.23722 .61753 m .23782 .61425 L .23702 .61503 L F
.899 .897 .817 r
.67291 .39149 m .67257 .38873 L .67112 .39016 L F
.873 .83 .801 r
.67152 .39316 m .67291 .39149 L .67112 .39016 L F
.775 .68 .759 r
.47349 .46407 m .47485 .46785 L .47096 .46739 L F
.8 .501 .483 r
.47349 .46407 m .47744 .46721 L .47485 .46785 L F
.626 .499 .688 r
.47744 .46721 m .47493 .47047 L .47485 .46785 L F
.974 .667 .312 r
.6101 .41264 m .61169 .41634 L .6106 .41529 L F
.959 .62 .294 r
.61169 .41634 m .61044 .41736 L .6106 .41529 L F
.61169 .41634 m .61217 .41888 L .61044 .41736 L F
.485 0 0 r
.55106 .46742 m .55506 .46774 L .5535 .46853 L F
0 .428 .748 r
.55506 .46774 m .55628 .4679 L .5535 .46853 L F
.55506 .46774 m .55753 .46846 L .55628 .4679 L F
.147 0 .191 r
.63211 .42806 m .63184 .42654 L .63484 .42493 L F
.49 .451 .741 r
.44165 .54491 m .44385 .54408 L .44299 .54061 L F
.26 0 0 r
.44034 .54596 m .44385 .54408 L .44165 .54491 L F
0 .113 .649 r
.71102 .31229 m .71224 .3165 L .71149 .3158 L F
.553 0 0 r
.3844 .66206 m .38282 .66068 L .38163 .66084 L F
.753 .277 .111 r
.61197 .36674 m .61275 .36522 L .61009 .36481 L F
.144 0 0 r
.61009 .36481 m .61275 .36522 L .61309 .36531 L F
.492 .86 .986 r
.61275 .36522 m .61539 .36448 L .61463 .36378 L F
.61463 .36378 m .61539 .36448 L .61275 .36522 L F
.61275 .36522 m .61463 .36378 L .61309 .36531 L F
.61463 .36378 m .61275 .36522 L .6125 .36571 L F
.509 .741 .979 r
.61009 .36481 m .613 .36529 L .61109 .36234 L F
.61009 .36481 m .61109 .36234 L .61101 .3623 L F
.613 .36529 m .61305 .36525 L .61103 .36225 L F
.61009 .36481 m .61101 .3623 L .60515 .36365 L F
.381 .694 .982 r
.61103 .36225 m .61242 .36305 L .6089 .36114 L F
.509 .741 .979 r
.61101 .3623 m .61103 .36225 L .61096 .36227 L F
.60738 .36314 m .60739 .36312 L .60515 .36365 L F
.748 .566 .65 r
.60886 .36706 m .61009 .36481 L .60515 .36365 L F
.313 .799 .881 r
.60776 .36267 m .60739 .36312 L .61096 .36227 L F
.60745 .36271 m .61096 .36227 L .61092 .36227 L F
.509 .741 .979 r
.61101 .3623 m .61096 .36227 L .60739 .36312 L F
.61101 .3623 m .60739 .36312 L .60738 .36314 L F
.658 .819 .961 r
.61103 .36225 m .61109 .36234 L .61463 .36378 L F
.492 .86 .986 r
.61463 .36378 m .6125 .36571 L .61305 .36525 L F
.658 .819 .961 r
.61451 .36389 m .61309 .36531 L .61452 .36389 L F
.61305 .36525 m .61309 .36531 L .61451 .36389 L F
.492 .86 .986 r
.61463 .36378 m .61305 .36525 L .61406 .36441 L F
.658 .819 .961 r
.61109 .36234 m .61305 .36525 L .61451 .36389 L F
.61109 .36234 m .61452 .36389 L .61463 .36378 L F
.313 .799 .881 r
.60677 .3628 m .61092 .36227 L .6089 .36114 L F
.796 .307 .038 r
.6106 .36208 m .61242 .36305 L .609 .36123 L F
.6089 .36114 m .61202 .36284 L .60898 .36121 L F
.313 .799 .881 r
.61092 .36227 m .61103 .36225 L .6089 .36114 L F
.796 .307 .038 r
.61093 .36227 m .61242 .36305 L .61215 .36295 L F
.61092 .36227 m .61215 .36295 L .61024 .36222 L F
.61093 .36227 m .61215 .36295 L .61092 .36227 L F
.61095 .36227 m .61104 .36232 L .61093 .36227 L F
.61104 .36232 m .61242 .36305 L .61093 .36227 L F
.60931 .36239 m .61283 .36428 L .61002 .36453 L F
.6089 .36114 m .61024 .36222 L .60931 .36239 L F
.61024 .36222 m .61283 .36428 L .60931 .36239 L F
.313 .799 .881 r
.60745 .36271 m .60744 .36273 L .60776 .36267 L F
.60744 .36273 m .60739 .36312 L .60776 .36267 L F
.61092 .36227 m .61096 .36227 L .61103 .36225 L F
.796 .307 .038 r
.61024 .36222 m .61242 .36305 L .61283 .36428 L F
.609 .36123 m .61095 .36227 L .61024 .36222 L F
.67 .608 .777 r
.60745 .3627 m .61002 .36453 L .60584 .36443 L F
.6089 .36114 m .60931 .36239 L .60745 .3627 L F
.60931 .36239 m .61002 .36453 L .60745 .3627 L F
.313 .799 .881 r
.60679 .36281 m .60515 .36365 L .60739 .36312 L F
.60677 .3628 m .60673 .36282 L .60679 .36281 L F
.60673 .36282 m .60515 .36365 L .60679 .36281 L F
.60677 .3628 m .60739 .36312 L .60745 .36271 L F
.635 .913 .62 r
.60752 .36216 m .60584 .36443 L .60742 .36223 L F
.60887 .36117 m .60745 .3627 L .60752 .36216 L F
.60745 .3627 m .60584 .36443 L .60752 .36216 L F
.6089 .36114 m .60883 .36122 L .60887 .36117 L F
.60883 .36122 m .60584 .36443 L .60887 .36117 L F
.796 .307 .038 r
.60898 .36121 m .6106 .36208 L .609 .36123 L F
.61202 .36284 m .61242 .36305 L .60898 .36121 L F
.509 .741 .979 r
.61101 .3623 m .61109 .36234 L .61103 .36225 L F
.613 .36529 m .61309 .36531 L .61305 .36525 L F
.492 .86 .986 r
.61406 .36441 m .6125 .36571 L .61197 .36674 L F
.915 .977 .71 r
.62255 .4101 m .62369 .40775 L .62396 .40804 L F
.482 .703 .967 r
.62396 .40804 m .62512 .41006 L .62255 .4101 L F
0 .121 .653 r
.28799 .63778 m .28618 .63358 L .28563 .63741 L F
.821 .409 .265 r
.28831 .63926 m .28799 .63778 L .28563 .63741 L F
.747 .355 .309 r
.28831 .63926 m .29067 .64029 L .28799 .63778 L F
.449 .402 .713 r
.28799 .63778 m .29067 .64029 L .29044 .63766 L F
.28799 .63778 m .29067 .64029 L .29044 .63766 L F
.658 .203 .159 r
.39178 .60583 m .39002 .60748 L .38954 .60601 L F
.459 .111 .287 r
.2592 .55096 m .25583 .55153 L .2574 .54994 L F
.2592 .55096 m .25539 .55384 L .25583 .55153 L F
.2592 .55096 m .25838 .5536 L .25539 .55384 L F
.568 .627 .87 r
.2605 .54844 m .2592 .55096 L .2574 .54994 L F
.2605 .54844 m .26164 .5505 L .2592 .55096 L F
.125 0 .156 r
.2603 .55259 m .2592 .55096 L .26164 .5505 L F
.25949 .55139 m .25903 .55152 L .2592 .55096 L F
.572 .868 .558 r
.25583 .55153 m .25553 .55157 L .2574 .54994 L F
.241 .757 .825 r
.25553 .55157 m .26127 .55099 L .2574 .54994 L F
.715 .853 .428 r
.26159 .55054 m .2603 .55259 L .26164 .5505 L F
.241 .757 .825 r
.26127 .55099 m .26138 .55098 L .26129 .55095 L F
.26127 .55099 m .26129 .55095 L .2574 .54994 L F
.26086 .55103 m .26101 .55099 L .26127 .55098 L F
.26127 .55099 m .26127 .55098 L .26138 .55098 L F
.26086 .55103 m .26127 .55098 L .26127 .55099 L F
.715 .853 .428 r
.26107 .55091 m .26058 .55197 L .26127 .55099 L F
.601 .188 .232 r
.2605 .54844 m .26329 .54875 L .26164 .5505 L F
.2605 .54844 m .26239 .54963 L .26329 .54875 L F
.715 .853 .428 r
.26243 .54959 m .26164 .5505 L .26329 .54875 L F
.601 .188 .232 r
.26239 .54963 m .26309 .55006 L .26329 .54875 L F
.715 .853 .428 r
.26248 .54954 m .26243 .54959 L .26329 .54875 L F
.372 .337 .689 r
.2616 .55048 m .26239 .54963 L .26206 .54941 L F
.715 .853 .428 r
.26146 .55063 m .26131 .55094 L .26159 .55054 L F
.372 .337 .689 r
.26138 .55098 m .26199 .54958 L .26134 .55086 L F
.26199 .54958 m .26206 .54941 L .26197 .54958 L F
.26199 .54958 m .26197 .54958 L .26134 .55086 L F
0 0 0 r
.26309 .55006 m .26569 .54848 L .26329 .54875 L F
.26309 .55006 m .26515 .54917 L .26569 .54848 L F
.195 0 0 r
.26515 .54917 m .26467 .54937 L .26329 .54875 L F
.638 .49 .665 r
.2574 .54994 m .26129 .55095 L .2605 .54844 L F
.715 .853 .428 r
.2613 .55093 m .26129 .55095 L .26131 .55094 L F
.638 .49 .665 r
.26129 .55095 m .26138 .55098 L .26134 .55086 L F
.26129 .55095 m .26134 .55086 L .2605 .54844 L F
.715 .853 .428 r
.26122 .5508 m .26127 .55099 L .26129 .55095 L F
.26122 .5508 m .26129 .55095 L .2613 .55093 L F
.26107 .55091 m .26146 .55063 L .26248 .54954 L F
.26146 .55063 m .26164 .5505 L .26248 .54954 L F
.372 .337 .689 r
.26138 .55098 m .26309 .55006 L .26239 .54963 L F
.26138 .55098 m .26239 .54963 L .2616 .55048 L F
.26134 .55086 m .26206 .54941 L .2605 .54844 L F
.715 .853 .428 r
.26122 .5508 m .26131 .55094 L .26146 .55063 L F
.26058 .55197 m .2603 .55259 L .26159 .55054 L F
.195 0 0 r
.26467 .54937 m .26107 .55091 L .26248 .54954 L F
.26467 .54937 m .26248 .54954 L .26329 .54875 L F
.715 .853 .428 r
.26107 .55091 m .26127 .55099 L .26122 .5508 L F
.241 .757 .825 r
.25553 .55157 m .25798 .5511 L .26101 .55099 L F
.25553 .55157 m .26101 .55099 L .26086 .55103 L F
.125 0 .156 r
.2603 .55259 m .25838 .5536 L .25903 .55152 L F
.2603 .55259 m .25903 .55152 L .25949 .55139 L F
.63 .955 .928 r
.68262 .36225 m .67821 .3636 L .68127 .36089 L F
.86 .889 .856 r
.68525 .35901 m .68262 .36225 L .68127 .36089 L F
.338 .342 .717 r
.71044 .28418 m .71147 .28521 L .71097 .28222 L F
.71044 .28418 m .71147 .28521 L .71097 .28222 L F
.628 .514 .705 r
.28753 .52781 m .28388 .52658 L .28634 .52593 L F
.28753 .52781 m .2844 .52943 L .28388 .52658 L F
0 0 0 r
.28209 .52726 m .28634 .52593 L .28388 .52658 L F
.674 .813 .95 r
.58505 .42246 m .58302 .42379 L .58097 .4219 L F
.392 .552 .894 r
.40928 .48049 m .40848 .48271 L .40617 .48068 L F
.40928 .48049 m .41093 .48334 L .40848 .48271 L F
.995 .847 .579 r
.42639 .54052 m .42555 .54319 L .42769 .54183 L F
.551 .177 .285 r
.42672 .54245 m .42964 .54056 L .42769 .54183 L F
.42778 .54176 m .42964 .54056 L .42672 .54245 L F
.387 .217 .526 r
.42964 .54056 m .43196 .53758 L .42961 .53807 L F
.551 .177 .285 r
.42555 .54319 m .42778 .54176 L .42672 .54245 L F
.42555 .54319 m .42882 .54367 L .42964 .54056 L F
.138 0 .149 r
.42964 .54056 m .43119 .542 L .43156 .53979 L F
.43003 .54156 m .42882 .54367 L .43041 .54255 L F
.42964 .54056 m .42927 .54195 L .43003 .54156 L F
.42927 .54195 m .42882 .54367 L .43003 .54156 L F
.42964 .54056 m .43041 .54255 L .43073 .54157 L F
.387 .217 .526 r
.42964 .54056 m .43156 .53979 L .43196 .53758 L F
.555 .195 .313 r
.42961 .53807 m .43089 .54109 L .42639 .54052 L F
.43089 .54109 m .43089 .5411 L .42639 .54052 L F
.526 .572 .845 r
.42913 .54088 m .43089 .5411 L .43017 .54019 L F
.555 .195 .313 r
.43089 .54109 m .4309 .5411 L .43089 .5411 L F
.526 .572 .845 r
.43089 .5411 m .4309 .5411 L .43089 .5411 L F
.43089 .5411 m .43089 .5411 L .43017 .54019 L F
.138 0 .149 r
.43073 .54157 m .43041 .54255 L .43119 .542 L F
.526 .572 .845 r
.42639 .54052 m .42913 .54088 L .42685 .53604 L F
.42913 .54088 m .43017 .54019 L .42685 .53604 L F
.787 .75 .819 r
.31716 .63191 m .31723 .63345 L .31905 .6309 L F
.513 .652 .921 r
.31723 .63345 m .31967 .63315 L .31905 .6309 L F
.84 .821 .34 r
.69346 .37368 m .69408 .37152 L .69332 .3729 L F
.689 .805 .346 r
.69332 .3729 m .69408 .37152 L .69511 .36906 L F
.835 .452 .325 r
.36706 .50795 m .36866 .51107 L .37042 .50926 L F
.799 .398 .292 r
.36866 .51107 m .37264 .51272 L .37042 .50926 L F
.907 .967 .808 r
.34455 .67974 m .3469 .67726 L .3446 .67906 L F
.781 .612 .671 r
.34455 .67974 m .34718 .67974 L .3469 .67726 L F
.005 .038 .544 r
.3469 .67726 m .34835 .67791 L .34945 .67577 L F
.3469 .67726 m .34718 .67974 L .34835 .67791 L F
0 0 0 r
.3446 .67906 m .3469 .67726 L .34945 .67577 L F
.861 .996 .798 r
.38231 .54836 m .38183 .54891 L .38222 .55015 L F
.458 .806 .998 r
.38252 .55111 m .38222 .55015 L .37872 .55064 L F
.468 .291 .557 r
.37872 .55064 m .38112 .5529 L .3828 .55115 L F
.37872 .55064 m .37873 .55371 L .37934 .55351 L F
.38037 .55219 m .37934 .55351 L .38112 .5529 L F
.37872 .55064 m .37934 .55351 L .38037 .55219 L F
0 0 .204 r
.37945 .5516 m .37872 .55064 L .38052 .55039 L F
.38178 .55038 m .38178 .55021 L .38222 .55015 L F
.861 .996 .798 r
.38183 .54891 m .37945 .5516 L .38178 .55038 L F
.38214 .54991 m .38178 .55038 L .38222 .55015 L F
.38183 .54891 m .38178 .55038 L .38214 .54991 L F
.458 .806 .998 r
.3828 .55115 m .38222 .55015 L .38252 .55111 L F
.652 .887 .537 r
.3828 .55115 m .38275 .55072 L .38222 .55015 L F
.3828 .55115 m .38112 .5529 L .38275 .55072 L F
.748 .68 .785 r
.4005 .66932 m .39852 .67368 L .39874 .66997 L F
.466 .171 .38 r
.31571 .55407 m .31969 .55036 L .31625 .55188 L F
.987 .735 .458 r
.41443 .58316 m .41265 .58448 L .41378 .58164 L F
.41443 .58316 m .41423 .58598 L .41265 .58448 L F
0 0 0 r
.27512 .54022 m .27391 .54151 L .27651 .53872 L F
.27773 .53884 m .27512 .54022 L .27651 .53872 L F
.538 .535 .8 r
.27845 .53581 m .27896 .5385 L .27651 .53872 L F
.047 0 0 r
.27838 .53855 m .27773 .53884 L .27651 .53872 L F
.077 .189 .68 r
.27935 .53662 m .27896 .5385 L .27845 .53581 L F
.461 .836 .99 r
.27451 .536 m .27685 .53541 L .27845 .53581 L F
0 .347 .726 r
.27685 .53541 m .27886 .53638 L .27845 .53581 L F
.27886 .53638 m .27935 .53662 L .27902 .53632 L F
.27886 .53638 m .27902 .53632 L .27845 .53581 L F
.614 .494 .692 r
.27836 .53659 m .27711 .53911 L .27773 .53884 L F
.27851 .53608 m .27824 .53664 L .27836 .53659 L F
.27824 .53664 m .27711 .53911 L .27836 .53659 L F
0 0 0 r
.277 .53923 m .27701 .53931 L .27512 .54022 L F
.27773 .53884 m .27701 .53931 L .277 .53923 L F
.549 .029 0 r
.27701 .53931 m .27711 .53969 L .27704 .53949 L F
.497 .907 .851 r
.27184 .53733 m .27264 .53644 L .27451 .536 L F
.183 .71 .699 r
.27451 .536 m .27264 .53644 L .27685 .53541 L F
.762 .279 .089 r
.27264 .53644 m .27701 .53931 L .27685 .53541 L F
.549 .029 0 r
.27701 .53931 m .27704 .53949 L .27646 .53786 L F
.614 .494 .692 r
.27711 .53911 m .27701 .53931 L .27773 .53884 L F
.047 0 0 r
.27896 .5385 m .27773 .53884 L .27838 .53855 L F
.497 .498 .788 r
.46284 .52413 m .46054 .52566 L .45963 .52227 L F
.536 .451 .706 r
.46284 .52413 m .46095 .52859 L .46054 .52566 L F
.694 .494 .612 r
.51275 .46078 m .51365 .46329 L .51029 .4641 L F
.666 .307 .354 r
.51275 .46078 m .51688 .46306 L .51365 .46329 L F
.51275 .46078 m .51679 .46119 L .51688 .46306 L F
.688 .592 .743 r
.43249 .55176 m .42866 .54773 L .4311 .54687 L F
.311 0 .148 r
.43249 .55176 m .43184 .55317 L .42977 .55365 L F
.57 .578 .823 r
.43369 .5465 m .43249 .55176 L .4311 .54687 L F
0 0 0 r
.43314 .55102 m .43249 .55176 L .43584 .551 L F
.739 .449 .489 r
.33859 .68819 m .3419 .68905 L .34144 .6918 L F
.895 .876 .809 r
.39304 .59693 m .3892 .59834 L .39119 .59566 L F
.39304 .59693 m .39056 .59971 L .3892 .59834 L F
.551 .504 .756 r
.39251 .59277 m .39304 .59693 L .39516 .59552 L F
.686 .879 .97 r
.39516 .59552 m .39304 .59693 L .39119 .59566 L F
.849 .895 .869 r
.65049 .38986 m .64924 .39146 L .64931 .38835 L F
.846 .892 .871 r
.64931 .38835 m .64924 .39146 L .64764 .39018 L F
.662 .567 .737 r
.71886 .34785 m .72181 .3454 L .7188 .34599 L F
.671 .12 0 r
.25142 .62116 m .24926 .62051 L .24987 .62018 L F
.148 .691 .754 r
.25135 .62062 m .24847 .62094 L .24926 .62051 L F
.24847 .62094 m .24691 .62111 L .24926 .62051 L F
.671 .12 0 r
.24987 .62018 m .24926 .62051 L .24709 .61841 L F
0 .291 .733 r
.25142 .62116 m .25135 .62062 L .24926 .62051 L F
.25142 .62116 m .25279 .62185 L .25135 .62062 L F
.954 .693 .242 r
.39122 .53452 m .3914 .53699 L .39215 .53736 L F
.976 .673 .317 r
.39128 .53984 m .39215 .53736 L .3914 .53699 L F
.39128 .53984 m .39276 .5416 L .39215 .53736 L F
.208 .545 .929 r
.38276 .58517 m .38481 .58373 L .38122 .58226 L F
.576 .416 .626 r
.33859 .68819 m .33656 .6912 L .33605 .68901 L F
.33859 .68819 m .33953 .69205 L .33656 .6912 L F
.452 .334 .629 r
.33953 .69205 m .33745 .69477 L .33656 .6912 L F
.643 .756 .931 r
.28996 .51478 m .29031 .51647 L .28846 .51689 L F
.695 .767 .907 r
.6378 .35859 m .6415 .3591 L .64016 .35706 L F
.629 .62 .823 r
.6415 .3591 m .64332 .35447 L .64016 .35706 L F
.6415 .3591 m .64421 .35822 L .64332 .35447 L F
.989 .833 .455 r
.68187 .32108 m .68238 .32232 L .68303 .32028 L F
.797 .999 .826 r
.68303 .32028 m .68609 .31741 L .68385 .31797 L F
.792 .947 .604 r
.68385 .31797 m .68187 .32108 L .68303 .32028 L F
.776 .665 .741 r
.41519 .50039 m .41086 .49924 L .41335 .4986 L F
.41519 .50039 m .41294 .50353 L .41086 .49924 L F
.594 .788 .973 r
.41759 .49942 m .41519 .50039 L .41335 .4986 L F
.837 .765 .783 r
.64353 .40264 m .64484 .40602 L .64097 .40576 L F
.624 .658 .863 r
.64901 .40144 m .64484 .40602 L .64353 .40264 L F
.746 .595 .689 r
.43486 .59023 m .43757 .58677 L .43282 .58602 L F
.217 0 .251 r
.43682 .58889 m .43757 .58677 L .43486 .59023 L F
.243 0 .264 r
.43966 .58576 m .43757 .58677 L .43682 .58889 L F
.999 .835 .536 r
.22651 .55697 m .22557 .55657 L .22658 .55441 L F
.843 .882 .869 r
.2241 .56001 m .22651 .55697 L .22557 .55657 L F
0 0 0 r
.22495 .55829 m .22557 .55657 L .22651 .55697 L F
.999 .835 .536 r
.22651 .55697 m .22557 .55657 L .22658 .55441 L F
.489 .831 .548 r
.22757 .55595 m .22651 .55697 L .2298 .55542 L F
.22757 .55595 m .22495 .55829 L .22651 .55697 L F
.989 .838 .462 r
.39983 .59429 m .40067 .59518 L .40118 .59253 L F
.978 .915 .657 r
.40118 .59253 m .40119 .58745 L .40105 .59197 L F
.814 .898 .485 r
.39983 .59429 m .40118 .59253 L .40105 .59197 L F
.98 .686 .355 r
.51242 .43095 m .51384 .43249 L .51269 .43391 L F
.762 .619 .701 r
.51625 .45074 m .51805 .45173 L .51495 .45126 L F
.612 .799 .971 r
.51514 .43015 m .51384 .43249 L .51242 .43095 L F
.68 .866 .472 r
.51269 .43391 m .51384 .43249 L .51514 .43015 L F
.728 .641 .761 r
.52075 .44847 m .51805 .45173 L .51625 .45074 L F
.759 .961 .661 r
.43009 .52732 m .4321 .52411 L .43371 .52588 L F
0 0 .062 r
.23759 .60235 m .23669 .60223 L .24033 .60242 L F
.629 .32 .429 r
.2433 .60257 m .24252 .60481 L .24033 .60242 L F
0 .006 .543 r
.24033 .60242 m .24034 .60243 L .24138 .60326 L F
.24034 .60243 m .24252 .60481 L .24138 .60326 L F
.879 .6 .08 r
.24252 .60481 m .24188 .60599 L .24138 .60326 L F
.945 .669 .483 r
.24188 .60599 m .24194 .60371 L .24138 .60326 L F
.24194 .60371 m .24198 .60245 L .24138 .60326 L F
0 .006 .543 r
.24033 .60242 m .24138 .60326 L .23759 .60235 L F
.653 .547 .723 r
.24336 .60068 m .2433 .60257 L .24033 .60242 L F
0 .082 .628 r
.3625 .54335 m .36068 .54137 L .36246 .54062 L F
.784 .97 .917 r
.69115 .34973 m .69331 .34984 L .69013 .35238 L F
.804 .988 .886 r
.69115 .34973 m .69013 .35238 L .6894 .3516 L F
.554 .492 .741 r
.32291 .52526 m .32468 .52103 L .32266 .52406 L F
.194 .444 .87 r
.23992 .59527 m .24121 .59805 L .23818 .59677 L F
.833 .999 .799 r
.68705 .31468 m .68609 .31741 L .68877 .31444 L F
.831 1 .817 r
.68385 .31797 m .68609 .31741 L .68705 .31468 L F
0 0 .353 r
.32324 .5832 m .32424 .58479 L .32422 .58118 L F
.32324 .5832 m .32324 .58617 L .32424 .58479 L F
.916 .518 .205 r
.28627 .6476 m .28733 .64986 L .2847 .64683 L F
0 0 0 r
.35863 .60883 m .35939 .60759 L .35988 .60536 L F
.51 .192 .363 r
.36153 .60855 m .3606 .61083 L .35863 .60883 L F
0 .124 .663 r
.35863 .60883 m .3606 .61083 L .35939 .60759 L F
.784 .554 .588 r
.36854 .67252 m .37263 .67295 L .37208 .67605 L F
.762 .434 .431 r
.53813 .46382 m .54042 .46472 L .54049 .46692 L F
.738 .456 .502 r
.54042 .46472 m .54451 .46725 L .54049 .46692 L F
.571 .408 .622 r
.33504 .62462 m .33246 .62794 L .33238 .62513 L F
.185 .715 .834 r
.36192 .6989 m .36359 .69891 L .36488 .69869 L F
.772 .521 .555 r
.36106 .70161 m .36359 .69891 L .36192 .6989 L F
.36106 .70161 m .36506 .70155 L .36359 .69891 L F
.308 .314 .703 r
.36488 .69869 m .36359 .69891 L .36603 .69748 L F
.896 .475 .117 r
.36359 .69891 m .36506 .70155 L .36353 .70077 L F
.36359 .69891 m .36359 .69911 L .36494 .69812 L F
.36359 .69911 m .36357 .69953 L .36469 .69838 L F
.36359 .69911 m .36469 .69838 L .36494 .69812 L F
.456 .544 .858 r
.36207 .69413 m .36469 .69838 L .36603 .69748 L F
.36469 .69838 m .36488 .69869 L .36603 .69748 L F
.666 .641 .815 r
.36192 .6989 m .36435 .69872 L .36207 .69413 L F
.36435 .69872 m .36488 .69869 L .36469 .69838 L F
.36435 .69872 m .36469 .69838 L .36207 .69413 L F
.896 .475 .117 r
.36494 .69812 m .36353 .70077 L .36603 .69748 L F
.36357 .69953 m .36353 .70077 L .36494 .69812 L F
.799 .381 0 r
.58878 .39065 m .59098 .39443 L .58968 .39327 L F
.703 .227 0 r
.58968 .39327 m .59098 .39443 L .59133 .39506 L F
.654 .766 .932 r
.31313 .66592 m .31517 .66785 L .31727 .66661 L F
.875 .957 .855 r
.70486 .34861 m .70808 .34537 L .70708 .34408 L F
.781 .941 .931 r
.70708 .34408 m .70808 .34537 L .71133 .34261 L F
.396 .059 .272 r
.28753 .52781 m .28368 .53101 L .2844 .52943 L F
.313 .788 .923 r
.36881 .71065 m .37081 .7111 L .37279 .71072 L F
.595 .627 .853 r
.37081 .7111 m .3747 .71203 L .37279 .71072 L F
0 0 .281 r
.32696 .49608 m .32769 .50005 L .32761 .49867 L F
0 .285 .674 r
.32769 .50005 m .3289 .50052 L .32761 .49867 L F
.333 .763 .972 r
.33061 .5015 m .33072 .50055 L .3289 .50052 L F
.082 0 0 r
.3289 .50052 m .33062 .50074 L .32933 .50063 L F
.418 .727 .989 r
.32848 .50192 m .33061 .5015 L .32769 .50005 L F
.082 0 0 r
.3289 .50052 m .32933 .50063 L .32717 .50045 L F
0 .285 .674 r
.32769 .50005 m .3284 .5004 L .3289 .50052 L F
.3284 .5004 m .33061 .5015 L .3289 .50052 L F
.655 .43 .567 r
.31716 .63191 m .31905 .6309 L .31471 .63126 L F
.264 .742 .934 r
.334 .5466 m .32974 .54623 L .33188 .54685 L F
.088 0 0 r
.69899 .30361 m .70237 .3008 L .70222 .30335 L F
.369 .076 .331 r
.70237 .3008 m .70239 .29716 L .70378 .2995 L F
.709 .456 .54 r
.70521 .30059 m .70222 .30335 L .70237 .3008 L F
.553 .43 .666 r
.46103 .49899 m .46289 .50479 L .45863 .50432 L F
.549 .42 .658 r
.46215 .50557 m .45863 .50432 L .46289 .50479 L F
.46215 .50557 m .45959 .50649 L .45863 .50432 L F
.346 0 .049 r
.27266 .56708 m .27329 .56862 L .27505 .56651 L F
.27266 .56708 m .27097 .56904 L .27329 .56862 L F
.787 .633 .689 r
.62225 .4032 m .62378 .40045 L .61986 .40014 L F
.056 .492 .891 r
.57637 .39122 m .57479 .39163 L .57343 .39 L F
.57637 .39122 m .57769 .39256 L .57479 .39163 L F
.779 .773 .847 r
.48623 .44967 m .48782 .45161 L .48389 .45114 L F
.809 .715 .761 r
.48389 .45114 m .48782 .45161 L .48522 .4547 L F
.656 .479 .633 r
.48782 .45161 m .48799 .45438 L .48522 .4547 L F
.625 .695 .895 r
.48906 .4476 m .48782 .45161 L .48623 .44967 L F
.48906 .4476 m .49065 .45089 L .48782 .45161 L F
.553 .401 .629 r
.49026 .45352 m .48782 .45161 L .49065 .45089 L F
.49026 .45352 m .48799 .45438 L .48782 .45161 L F
.593 .322 .475 r
.43892 .51557 m .43808 .51841 L .43522 .51807 L F
.192 0 0 r
.44191 .51698 m .43808 .51841 L .43892 .51557 L F
.531 .27 .466 r
.42753 .52826 m .42705 .5308 L .42461 .5288 L F
.42753 .52826 m .42705 .5308 L .42461 .5288 L F
.581 .707 .929 r
.32291 .52526 m .32669 .52692 L .32548 .52562 L F
.721 .674 .803 r
.32669 .52692 m .32291 .52526 L .32548 .52562 L F
0 0 .328 r
.32687 .52723 m .32669 .52692 L .32548 .52562 L F
.32687 .52723 m .32757 .52864 L .32669 .52692 L F
.761 .96 .934 r
.25002 .52878 m .25005 .52932 L .25114 .52898 L F
.661 .921 .975 r
.25181 .52721 m .25114 .52898 L .25375 .52802 L F
.735 .982 .91 r
.25181 .52721 m .25002 .52878 L .25114 .52898 L F
.751 .931 .947 r
.64078 .39221 m .64194 .39332 L .63962 .39459 L F
.696 .867 .963 r
.64078 .39221 m .63962 .39459 L .63832 .39358 L F
.784 .397 .322 r
.63962 .39459 m .64235 .39724 L .63967 .39773 L F
.604 .387 .56 r
.36063 .55443 m .35754 .55991 L .35672 .55601 L F
.225 0 0 r
.35672 .55601 m .3573 .55793 L .36063 .55443 L F
.604 .387 .56 r
.36063 .55443 m .36007 .55956 L .35754 .55991 L F
.434 .241 .518 r
.36251 .55845 m .36152 .55634 L .36129 .55565 L F
.36152 .55634 m .36063 .55443 L .36129 .55565 L F
.36251 .55845 m .36007 .55956 L .36063 .55443 L F
0 0 0 r
.36063 .55443 m .35923 .55685 L .36129 .55565 L F
.838 .99 .727 r
.36129 .55565 m .35923 .55685 L .36097 .55468 L F
0 .054 .604 r
.36026 .55201 m .36129 .55565 L .36175 .5537 L F
.838 .99 .727 r
.36129 .55565 m .36097 .55468 L .36175 .5537 L F
0 0 0 r
.36063 .55443 m .3573 .55793 L .35923 .55685 L F
.48 .818 .524 r
.33638 .68153 m .33798 .68007 L .3349 .68289 L F
0 0 0 r
.33975 .67945 m .33798 .68007 L .33638 .68153 L F
.141 0 0 r
.35787 .5927 m .36117 .59016 L .3603 .59181 L F
.35 0 .114 r
.36117 .59016 m .36335 .59102 L .3603 .59181 L F
.36117 .59016 m .36327 .58971 L .36335 .59102 L F
.772 .747 .83 r
.23241 .59903 m .22836 .60332 L .22787 .59884 L F
.966 .672 .42 r
.69728 .33247 m .69606 .33398 L .69509 .33238 L F
.69728 .33247 m .69749 .33509 L .69606 .33398 L F
.606 .26 .357 r
.51679 .46119 m .51943 .46323 L .51688 .46306 L F
.555 .287 .463 r
.51679 .46119 m .51952 .46092 L .51943 .46323 L F
0 .051 .618 r
.32189 .53346 m .32461 .53306 L .32222 .53383 L F
.877 .534 .034 r
.41015 .54813 m .40919 .54705 L .40855 .544 L F
0 0 .41 r
.41007 .54845 m .40919 .54705 L .41015 .54813 L F
.074 0 0 r
.24027 .57614 m .24418 .57397 L .2425 .57535 L F
.002 0 0 r
.2425 .57535 m .24418 .57397 L .2451 .57421 L F
.535 .39 .631 r
.24627 .5703 m .24648 .57338 L .24418 .57397 L F
.027 0 0 r
.24418 .57397 m .24648 .57338 L .2451 .57421 L F
.308 0 0 r
.46323 .58561 m .45915 .58799 L .46066 .58582 L F
.518 .335 .572 r
.35772 .54701 m .35503 .5507 L .35537 .54789 L F
.368 .105 .377 r
.32937 .50608 m .32661 .50914 L .32913 .50861 L F
.768 .989 .759 r
.32937 .50608 m .3325 .50288 L .33155 .50538 L F
.743 .483 .537 r
.33155 .50538 m .32848 .50192 L .32937 .50608 L F
.393 .176 .462 r
.33155 .50538 m .32937 .50608 L .32913 .50861 L F
.813 .952 .909 r
.58398 .37918 m .58276 .38115 L .58162 .38028 L F
.79 .331 0 r
.58162 .38028 m .58276 .38115 L .5839 .38329 L F
.741 .574 .666 r
.36716 .58668 m .36758 .58943 L .36327 .58971 L F
0 0 .416 r
.36826 .58777 m .36716 .58668 L .36963 .58575 L F
.36826 .58777 m .36758 .58943 L .36716 .58668 L F
.479 .817 .522 r
.33638 .68153 m .3349 .68289 L .33297 .68466 L F
.598 .121 .094 r
.39493 .49217 m .39883 .49235 L .39869 .49099 L F
0 0 .088 r
.39944 .48758 m .39869 .49099 L .39998 .48801 L F
.796 .998 .793 r
.39869 .49099 m .39713 .49128 L .39998 .48801 L F
.805 .862 .891 r
.61133 .38168 m .61302 .38354 L .61565 .38064 L F
0 0 .435 r
.47264 .56583 m .47413 .56895 L .47391 .57026 L F
.081 .127 .61 r
.47413 .56895 m .47348 .57293 L .47391 .57026 L F
0 0 .202 r
.34473 .53421 m .34442 .53675 L .34279 .53818 L F
.137 .006 .426 r
.34477 .53894 m .34279 .53818 L .34442 .53675 L F
.34477 .53894 m .34273 .54132 L .34279 .53818 L F
0 .203 .691 r
.29209 .65813 m .2928 .65806 L .29068 .6559 L F
.29209 .65813 m .29465 .65998 L .2928 .65806 L F
.451 .255 .522 r
.28451 .56079 m .28678 .56018 L .28681 .55745 L F
.405 .146 .404 r
.28451 .56079 m .28411 .56313 L .28678 .56018 L F
.452 .883 .887 r
.38838 .6136 m .38633 .61482 L .38447 .61489 L F
.161 0 .01 r
.38185 .70158 m .38531 .69911 L .38429 .70046 L F
0 0 0 r
.38429 .70046 m .38531 .69911 L .38708 .69797 L F
.677 .308 .34 r
.53655 .46625 m .53621 .46442 L .53813 .46382 L F
.762 .434 .431 r
.53813 .46382 m .54049 .46692 L .53655 .46625 L F
0 0 .246 r
.27512 .54022 m .27321 .54383 L .27391 .54151 L F
.921 .957 .791 r
.55768 .4062 m .5543 .40931 L .55754 .40871 L F
0 0 0 r
.56083 .4046 m .55768 .4062 L .55977 .40561 L F
.127 0 .205 r
.55977 .40561 m .55768 .4062 L .55754 .40871 L F
.824 .8 .828 r
.66844 .3932 m .67152 .39316 L .67112 .39016 L F
.841 .736 .748 r
.66844 .3932 m .66967 .39709 L .67152 .39316 L F
.739 .449 .489 r
.33859 .68819 m .34144 .6918 L .33953 .69205 L F
.804 .861 .891 r
.6327 .34698 m .62829 .3481 L .63112 .34536 L F
.819 .86 .878 r
.63456 .34523 m .6327 .34698 L .63112 .34536 L F
.499 .507 .797 r
.24896 .61658 m .24709 .61841 L .24588 .61451 L F
.587 .253 .371 r
.24709 .61841 m .24926 .62051 L .24665 .62031 L F
.24709 .61841 m .24926 .62051 L .24665 .62031 L F
.336 .256 .616 r
.24896 .61658 m .24926 .62051 L .24709 .61841 L F
.494 .306 .555 r
.40825 .50231 m .40806 .50537 L .40549 .50315 L F
.646 .606 .795 r
.25537 .62465 m .25961 .62699 L .25957 .62627 L F
.229 0 0 r
.26172 .62679 m .25957 .62627 L .25961 .62699 L F
0 .239 .753 r
.24307 .60986 m .24154 .60975 L .23957 .60833 L F
.24307 .60986 m .2437 .61124 L .24154 .60975 L F
.54 .665 .918 r
.71834 .31803 m .71596 .31951 L .71394 .31647 L F
.637 .486 .661 r
.47246 .47641 m .46967 .47942 L .47007 .47727 L F
.743 .483 .537 r
.33155 .50538 m .3325 .50288 L .32848 .50192 L F
.434 .734 .99 r
.33061 .5015 m .3325 .50288 L .33298 .50127 L F
.708 .775 .287 r
.33298 .50127 m .3325 .50288 L .33155 .50538 L F
.702 .437 .521 r
.3325 .50288 m .33546 .50562 L .33155 .50538 L F
.708 .775 .287 r
.33298 .50131 m .33155 .50538 L .3326 .50394 L F
.33298 .50127 m .33296 .50133 L .33298 .50131 L F
.33296 .50133 m .33155 .50538 L .33298 .50131 L F
.418 .727 .989 r
.32848 .50192 m .33187 .50273 L .33061 .5015 L F
.33187 .50273 m .3325 .50288 L .33202 .50253 L F
.33187 .50273 m .33202 .50253 L .33061 .5015 L F
.754 .894 .494 r
.2353 .5404 m .23336 .5439 L .23355 .54405 L F
.742 .901 .516 r
.23336 .5439 m .23203 .5458 L .23355 .54405 L F
0 0 0 r
.70019 .35691 m .69838 .35875 L .70049 .35528 L F
0 0 .24 r
.69805 .3611 m .69838 .35875 L .70019 .35691 L F
.112 .44 .878 r
.25537 .62465 m .25567 .62314 L .25279 .62185 L F
.131 .461 .889 r
.25537 .62465 m .25957 .62627 L .25567 .62314 L F
.674 .572 .732 r
.46967 .47942 m .47115 .4833 L .4685 .48397 L F
.668 .543 .704 r
.4685 .48397 m .47115 .4833 L .47151 .48772 L F
0 0 .229 r
.5848 .37662 m .58519 .37796 L .58397 .37401 L F
.881 .563 .055 r
.58484 .37916 m .5857 .38034 L .58519 .37796 L F
.825 .864 .876 r
.6644 .37683 m .66165 .37733 L .66423 .37428 L F
.749 .792 .887 r
.66665 .37302 m .6644 .37683 L .66423 .37428 L F
.66665 .37302 m .66834 .37489 L .6644 .37683 L F
.459 .389 .69 r
.34718 .67974 m .35016 .68173 L .34835 .67791 L F
.34718 .67974 m .34775 .68243 L .35016 .68173 L F
.268 .395 .807 r
.34718 .67974 m .35016 .68173 L .34835 .67791 L F
.592 .827 .989 r
.3446 .67906 m .34718 .67974 L .34835 .67791 L F
.999 .786 .465 r
.42522 .56839 m .42628 .56983 L .42654 .56703 L F
.42522 .56839 m .42628 .56983 L .42654 .56703 L F
.537 .821 .998 r
.60466 .35195 m .60341 .35396 L .60198 .35273 L F
.60466 .35195 m .60621 .35321 L .60341 .35396 L F
.837 .9 .883 r
.64511 .3509 m .64944 .34928 L .64825 .34796 L F
.852 .911 .874 r
.64825 .34796 m .64944 .34928 L .6523 .34611 L F
.877 .45 .177 r
.56505 .39256 m .56787 .39429 L .56848 .39626 L F
.778 .666 .739 r
.41086 .49924 m .41294 .50353 L .40825 .50231 L F
.73 .271 .159 r
.41294 .50353 m .41091 .50479 L .40825 .50231 L F
.349 .348 .717 r
.31457 .52821 m .31704 .52947 L .31724 .52873 L F
.377 .186 .49 r
.27409 .57337 m .27593 .57522 L .27346 .57527 L F
.27409 .57337 m .27576 .57448 L .27593 .57522 L F
.954 .728 .558 r
.39218 .69356 m .39423 .69579 L .3929 .69307 L F
.665 .443 .574 r
.33975 .67945 m .34254 .67575 L .33987 .67629 L F
.566 .497 .736 r
.46176 .53409 m .46264 .53768 L .46007 .53832 L F
.559 .514 .762 r
.46358 .54155 m .46007 .53832 L .46264 .53768 L F
.694 .982 .835 r
.68705 .31468 m .68877 .31444 L .6907 .31268 L F
.648 .303 .373 r
.23917 .61222 m .23782 .61425 L .23483 .61365 L F
0 0 0 r
.23825 .54796 m .2384 .54849 L .23719 .54937 L F
.23825 .54796 m .23618 .54932 L .2384 .54849 L F
.092 .174 .658 r
.28733 .64986 m .28803 .65375 L .28938 .65234 L F
.179 .315 .766 r
.28803 .65375 m .29068 .6559 L .28938 .65234 L F
.347 .333 .702 r
.28803 .65375 m .28908 .6563 L .29068 .6559 L F
.437 0 .034 r
.35314 .575 m .35651 .57561 L .35399 .57581 L F
.316 .614 .955 r
.23569 .55102 m .23766 .55108 L .23618 .54932 L F
.178 .707 .852 r
.24616 .53746 m .24428 .53729 L .24174 .53739 L F
.24616 .53746 m .24428 .53729 L .24174 .53739 L F
.394 .836 .939 r
.24616 .53746 m .24428 .53729 L .24834 .53683 L F
.24616 .53746 m .24428 .53729 L .24834 .53683 L F
.836 .713 .728 r
.39635 .58312 m .39212 .58547 L .39227 .58254 L F
.39635 .58312 m .39465 .58667 L .39212 .58547 L F
.758 .585 .662 r
.44365 .56941 m .44771 .57037 L .44576 .56715 L F
.147 .309 .771 r
.44576 .56715 m .44771 .57037 L .44846 .56881 L F
.627 .104 0 r
.44578 .57039 m .44771 .57037 L .44365 .56941 L F
.667 .927 .972 r
.44846 .56881 m .44771 .57037 L .44578 .57039 L F
.804 .594 .618 r
.4469 .57079 m .44909 .56949 L .44846 .56881 L F
.147 .309 .771 r
.44771 .56801 m .44846 .56881 L .44973 .5689 L F
.273 0 0 r
.44846 .56881 m .45216 .56649 L .44973 .5689 L F
.804 .594 .618 r
.44909 .56949 m .45097 .56838 L .44846 .56881 L F
.147 .309 .771 r
.44576 .56715 m .44846 .56881 L .44771 .56801 L F
.592 .695 .914 r
.31704 .52947 m .32076 .52869 L .32015 .52761 L F
.743 .913 .543 r
.32076 .52869 m .32125 .52699 L .32291 .52526 L F
.607 .721 .926 r
.32024 .53044 m .32125 .52699 L .32076 .52869 L F
.809 .998 .79 r
.31345 .55491 m .31015 .55807 L .31125 .55577 L F
0 0 0 r
.31345 .55491 m .31426 .55473 L .31571 .55407 L F
.809 .998 .79 r
.31345 .55491 m .31015 .55807 L .31125 .55577 L F
0 0 0 r
.31345 .55491 m .31125 .55577 L .31426 .55473 L F
.505 .511 .797 r
.3469 .52858 m .34449 .52981 L .34335 .52602 L F
.028 .179 .687 r
.34505 .52648 m .34449 .52981 L .34335 .52602 L F
.578 .743 .955 r
.3469 .52858 m .34449 .52981 L .34505 .52648 L F
.626 .903 .985 r
.23757 .53965 m .2353 .5404 L .23683 .54128 L F
.039 .204 .707 r
.23683 .54128 m .23967 .5444 L .23757 .53965 L F
.621 .778 .956 r
.5194 .42366 m .51903 .42609 L .51757 .4247 L F
.5194 .42366 m .52122 .42538 L .51903 .42609 L F
.73 .226 .029 r
.51903 .42609 m .51787 .42723 L .51757 .4247 L F
.51903 .42609 m .52064 .42757 L .51787 .42723 L F
.823 .653 .673 r
.52122 .42538 m .52064 .42757 L .51903 .42609 L F
.574 .595 .836 r
.7151 .34339 m .7188 .34599 L .71774 .34188 L F
.452 .334 .629 r
.33953 .69205 m .33947 .69501 L .33745 .69477 L F
.863 .486 .332 r
.3411 .6989 m .33745 .69477 L .33947 .69501 L F
.404 .852 .912 r
.43871 .59898 m .43992 .59922 L .44237 .59847 L F
.732 .988 .798 r
.6867 .29844 m .68834 .29802 L .68526 .3007 L F
.735 .992 .843 r
.6867 .29844 m .68526 .3007 L .68477 .30009 L F
.771 .73 .815 r
.33012 .63469 m .33155 .63775 L .32728 .63725 L F
.78 .466 .456 r
.32728 .63725 m .33155 .63775 L .33082 .6399 L F
.423 .544 .874 r
.33395 .63625 m .33155 .63775 L .33012 .63469 L F
0 0 .121 r
.33082 .6399 m .33155 .63775 L .33395 .63625 L F
.767 .702 .79 r
.71133 .34261 m .7151 .34339 L .71432 .33938 L F
.724 .674 .801 r
.71432 .33938 m .7151 .34339 L .71774 .34188 L F
.318 0 0 r
.23291 .57574 m .23537 .57553 L .23734 .57359 L F
.616 .483 .677 r
.23734 .57359 m .24295 .57453 L .24004 .56975 L F
.191 .723 .783 r
.23537 .57553 m .24295 .57453 L .23734 .57359 L F
.15 .665 .893 r
.33074 .69839 m .33485 .699 L .33289 .6983 L F
.502 .862 .988 r
.33485 .699 m .33527 .69759 L .33289 .6983 L F
.33485 .699 m .3373 .69835 L .33527 .69759 L F
.599 .901 .986 r
.55991 .46791 m .56198 .46869 L .56432 .46748 L F
.264 0 .222 r
.63271 .3969 m .62954 .40051 L .6315 .39831 L F
.405 .818 .623 r
.6348 .39552 m .63584 .39491 L .63271 .3969 L F
0 0 0 r
.6348 .39552 m .63271 .3969 L .6315 .39831 L F
0 .437 .861 r
.43037 .59284 m .43182 .59436 L .43335 .59465 L F
.893 .883 .816 r
.65332 .39963 m .65562 .40002 L .65699 .3978 L F
.901 .875 .801 r
.65332 .39963 m .65376 .40284 L .65562 .40002 L F
.837 .796 .301 r
.69703 .34224 m .69639 .34348 L .69721 .34133 L F
.69703 .34224 m .69617 .3461 L .69639 .34348 L F
0 0 0 r
.30046 .65634 m .30173 .65377 L .30273 .65248 L F
.748 .836 .918 r
.50876 .45681 m .50646 .45946 L .50545 .4575 L F
.34 .042 .305 r
.43289 .53469 m .43196 .53758 L .42961 .53807 L F
.42961 .53807 m .43196 .53758 L .43289 .53469 L F
.816 .516 .481 r
.43289 .53469 m .43643 .53806 L .43531 .5364 L F
.43289 .53469 m .43196 .53758 L .43643 .53806 L F
.548 .236 .39 r
.43531 .5364 m .43196 .53758 L .43289 .53469 L F
.688 .247 0 r
.3861 .52742 m .38831 .53067 L .38753 .5287 L F
.956 .614 .252 r
.62624 .36758 m .62948 .36489 L .62912 .36502 L F
.633 .122 .013 r
.62847 .36172 m .63082 .36335 L .62948 .36489 L F
.622 .923 .663 r
.62912 .36502 m .62948 .36489 L .63082 .36335 L F
.829 .991 .733 r
.35106 .58689 m .34852 .59075 L .35077 .58965 L F
.71 .272 .209 r
.34964 .58641 m .35108 .58664 L .35123 .5848 L F
.782 .619 .679 r
.35099 .58649 m .351 .58663 L .34964 .58641 L F
.351 .58663 m .35103 .58699 L .34964 .58641 L F
.71 .272 .209 r
.34964 .58641 m .35107 .5868 L .35108 .58664 L F
.829 .991 .733 r
.35107 .5868 m .35088 .5871 L .35106 .58689 L F
.35088 .5871 m .34852 .59075 L .35106 .58689 L F
.795 .806 .318 r
.35108 .58682 m .35078 .58954 L .35139 .58744 L F
.35078 .58954 m .3508 .58954 L .35139 .58744 L F
.35106 .58689 m .35077 .58965 L .35108 .58682 L F
.496 .426 .707 r
.35119 .5888 m .34852 .59075 L .35088 .5871 L F
.782 .619 .679 r
.35103 .58699 m .35093 .58735 L .35089 .58714 L F
.453 .202 .442 r
.35077 .58965 m .35328 .58571 L .35139 .58744 L F
.782 .619 .679 r
.35195 .58801 m .35119 .5888 L .35099 .58649 L F
.795 .806 .318 r
.35107 .5868 m .35106 .58689 L .35108 .58682 L F
.782 .619 .679 r
.35103 .58699 m .35119 .5888 L .35071 .58806 L F
.496 .426 .707 r
.35119 .5888 m .35088 .5871 L .35107 .5868 L F
.782 .619 .679 r
.35089 .58714 m .35071 .58806 L .35042 .58761 L F
.35093 .58735 m .35071 .58806 L .35089 .58714 L F
.35099 .58697 m .35042 .58761 L .34964 .58641 L F
.35103 .58699 m .35042 .58761 L .35099 .58697 L F
.526 .832 .513 r
.34918 .59001 m .34852 .59075 L .35018 .58954 L F
.394 .108 .356 r
.35039 .59194 m .35364 .58905 L .35077 .58965 L F
.35039 .59194 m .35285 .59132 L .35364 .58905 L F
.796 .459 .419 r
.34852 .59075 m .3442 .59194 L .34637 .59188 L F
.187 0 .17 r
.34637 .59188 m .34348 .59463 L .34408 .59275 L F
.814 1 .831 r
.3442 .59194 m .34348 .59463 L .34637 .59188 L F
.796 .459 .419 r
.34852 .59075 m .34554 .59374 L .3442 .59194 L F
.526 .832 .513 r
.34886 .59037 m .34554 .59374 L .34852 .59075 L F
.34918 .59001 m .34609 .59317 L .34886 .59037 L F
.34609 .59317 m .34554 .59374 L .34886 .59037 L F
.565 .379 .588 r
.34422 .58933 m .34408 .59275 L .34148 .59289 L F
.439 .086 .268 r
.34408 .59275 m .34095 .59493 L .34148 .59289 L F
.34408 .59275 m .34348 .59463 L .34095 .59493 L F
.816 .708 .746 r
.34348 .59463 m .34521 .59837 L .34112 .59764 L F
0 0 .466 r
.34348 .59463 m .34501 .59697 L .34521 .59837 L F
.512 .284 .504 r
.34348 .59463 m .34112 .59764 L .34095 .59493 L F
0 0 .533 r
.3442 .59194 m .34501 .59697 L .34348 .59463 L F
.689 .399 .478 r
.3442 .59194 m .34278 .59512 L .34339 .5951 L F
.3442 .59194 m .34339 .5951 L .34422 .595 L F
.862 .869 .843 r
.34573 .59072 m .34554 .59374 L .34918 .59001 L F
.34528 .59081 m .34549 .59312 L .34573 .59072 L F
.34549 .59312 m .34554 .59374 L .34573 .59072 L F
.219 .282 .716 r
.34545 .59352 m .34501 .59697 L .3442 .59194 L F
.34629 .59498 m .34511 .59682 L .34529 .59505 L F
.34511 .59682 m .34501 .59697 L .34545 .59352 L F
.34648 .59512 m .34501 .59697 L .34643 .59476 L F
.42 .171 .429 r
.34521 .59837 m .34796 .59529 L .34578 .59623 L F
.34521 .59837 m .3475 .59778 L .34796 .59529 L F
.945 .623 .389 r
.34501 .59697 m .3475 .59778 L .34521 .59837 L F
.34501 .59697 m .34569 .59941 L .3475 .59778 L F
0 0 .506 r
.34644 .59775 m .34501 .59697 L .3466 .59497 L F
.34644 .59775 m .34569 .59941 L .34501 .59697 L F
.786 .56 .593 r
.34229 .5972 m .34644 .59775 L .3466 .59497 L F
.066 0 0 r
.3466 .59496 m .34446 .59692 L .34229 .5972 L F
.34708 .59471 m .3468 .59494 L .3466 .59496 L F
.3468 .59494 m .34446 .59692 L .3466 .59496 L F
.219 .282 .716 r
.34643 .59476 m .34629 .59498 L .34545 .59352 L F
.34629 .59498 m .34529 .59505 L .34545 .59352 L F
.3466 .59497 m .34648 .59512 L .34643 .59476 L F
.689 .399 .478 r
.3442 .59194 m .34422 .59506 L .34558 .59369 L F
.679 .774 .922 r
.34212 .5905 m .34032 .59292 L .3442 .59194 L F
.731 .448 .5 r
.34095 .59493 m .33707 .59735 L .33832 .5951 L F
.34095 .59493 m .34112 .59764 L .33707 .59735 L F
.453 .15 .36 r
.34045 .59551 m .3442 .59194 L .34032 .59292 L F
.34045 .59551 m .34278 .59512 L .3442 .59194 L F
.096 .257 .74 r
.3442 .59194 m .34528 .59081 L .34212 .5905 L F
.3442 .59194 m .34554 .59374 L .34528 .59081 L F
.744 .678 .788 r
.34528 .59081 m .34616 .59271 L .34066 .59396 L F
.34616 .59271 m .34708 .59469 L .34641 .59462 L F
.689 .399 .478 r
.34643 .59476 m .34422 .59506 L .3466 .59497 L F
.34558 .59369 m .34429 .595 L .34643 .59476 L F
.34429 .595 m .34422 .59506 L .34643 .59476 L F
.744 .678 .788 r
.34616 .59271 m .34641 .59462 L .34066 .59396 L F
.34708 .59469 m .34708 .59471 L .34703 .5947 L F
.34708 .59469 m .34703 .5947 L .34066 .59396 L F
.689 .399 .478 r
.34422 .595 m .34339 .5951 L .34422 .59506 L F
.582 .081 .028 r
.35192 .59117 m .34778 .59067 L .34918 .59001 L F
.34778 .59067 m .34749 .59064 L .34918 .59001 L F
.526 .832 .513 r
.34918 .59001 m .35018 .58954 L .35038 .58939 L F
.35028 .58935 m .35038 .58939 L .35119 .5888 L F
.34918 .59001 m .35038 .58939 L .35028 .58935 L F
.795 .806 .318 r
.35078 .58954 m .35077 .58965 L .3508 .58954 L F
.35116 .58675 m .35139 .58744 L .35328 .58571 L F
.35107 .5868 m .35108 .58682 L .35116 .58675 L F
.35108 .58682 m .35139 .58744 L .35116 .58675 L F
.782 .619 .679 r
.35327 .58663 m .35195 .58801 L .35116 .58675 L F
.795 .806 .318 r
.35109 .58665 m .35328 .58571 L .35133 .58485 L F
.782 .619 .679 r
.35142 .58652 m .35116 .58675 L .35099 .58649 L F
.35327 .58663 m .35116 .58675 L .35142 .58652 L F
.795 .806 .318 r
.35109 .58669 m .35111 .58668 L .35109 .58665 L F
.35111 .58668 m .35328 .58571 L .35109 .58665 L F
.35107 .5868 m .35113 .58677 L .35109 .58669 L F
.35113 .58677 m .35328 .58571 L .35109 .58669 L F
.276 .677 .97 r
.35328 .58571 m .35349 .58422 L .35123 .5848 L F
.778 .549 .588 r
.35349 .58422 m .35327 .58663 L .35099 .58649 L F
.35066 .58583 m .35099 .58649 L .34964 .58641 L F
.795 .806 .318 r
.35107 .5868 m .35133 .58485 L .35121 .58502 L F
.778 .549 .588 r
.35349 .58422 m .35099 .58649 L .35066 .58583 L F
.35349 .58422 m .35066 .58583 L .3515 .58576 L F
.35066 .58583 m .34964 .58641 L .35045 .58613 L F
.35066 .58583 m .35045 .58613 L .3515 .58576 L F
.795 .806 .318 r
.35121 .58502 m .35133 .58485 L .35123 .5848 L F
.276 .677 .97 r
.35328 .58571 m .35586 .58577 L .35349 .58422 L F
.689 .898 .972 r
.68607 .32404 m .68751 .32525 L .68454 .32668 L F
.306 .404 .799 r
.68454 .32668 m .68727 .32811 L .68607 .32404 L F
.531 .826 .999 r
.38751 .51232 m .38847 .51049 L .38592 .51094 L F
.38751 .51232 m .38997 .51165 L .38847 .51049 L F
.464 .78 .998 r
.38592 .51094 m .38847 .51049 L .38694 .50929 L F
0 0 .44 r
.38847 .51049 m .38922 .5114 L .38703 .50937 L F
.38847 .51049 m .38703 .50937 L .38694 .50929 L F
.531 .826 .999 r
.38997 .51165 m .39016 .5116 L .38847 .51049 L F
.523 .36 .602 r
.48227 .45787 m .48254 .4607 L .47996 .4614 L F
.597 .498 .712 r
.48254 .4607 m .48028 .46424 L .47996 .4614 L F
.801 .96 .914 r
.66373 .32131 m .66486 .31869 L .66597 .31979 L F
.66373 .32131 m .66164 .32119 L .66486 .31869 L F
.786 .69 .759 r
.38455 .49961 m .38047 .49962 L .38312 .49871 L F
.38455 .49961 m .38211 .5029 L .38047 .49962 L F
0 0 0 r
.38455 .49961 m .38576 .49801 L .38705 .49631 L F
.498 .835 .998 r
.38312 .49871 m .38576 .49801 L .38455 .49961 L F
.412 .178 .447 r
.35395 .65313 m .35416 .65041 L .35646 .6501 L F
.35395 .65313 m .35416 .65041 L .35646 .6501 L F
0 0 0 r
.39431 .6528 m .39286 .65327 L .3935 .6523 L F
.072 0 .228 r
.24667 .53088 m .24439 .5343 L .2451 .53196 L F
.84 .86 .858 r
.65971 .3402 m .66348 .33894 L .66257 .33814 L F
.725 .962 .942 r
.66257 .33814 m .66348 .33894 L .66682 .33683 L F
.828 .924 .898 r
.6523 .34611 m .65421 .34503 L .65282 .34325 L F
.83 .925 .896 r
.65282 .34325 m .65421 .34503 L .65712 .3418 L F
.646 .642 .831 r
.44191 .51698 m .44263 .51904 L .44539 .51869 L F
.127 .313 .782 r
.44275 .52188 m .44539 .51869 L .44263 .51904 L F
.021 0 0 r
.63606 .39979 m .63967 .39773 L .63832 .39896 L F
.471 0 0 r
.63832 .39896 m .63967 .39773 L .64297 .39903 L F
.464 .15 .347 r
.63967 .39773 m .64235 .39724 L .64297 .39903 L F
.273 0 0 r
.58816 .40128 m .5869 .40073 L .58592 .39871 L F
0 .2 .707 r
.59052 .40408 m .5869 .40073 L .58998 .40189 L F
.273 0 0 r
.58816 .40128 m .58834 .40127 L .5869 .40073 L F
.489 0 0 r
.58804 .40129 m .58816 .40128 L .58661 .40017 L F
.59043 .40317 m .58816 .40128 L .58804 .40129 L F
.273 0 0 r
.58816 .40128 m .58998 .40189 L .58834 .40127 L F
.514 .255 .459 r
.30085 .62144 m .30345 .62096 L .3039 .61857 L F
.439 .208 .466 r
.30345 .62096 m .30611 .61784 L .3039 .61857 L F
.768 .618 .692 r
.2832 .5702 m .28292 .57345 L .28112 .57254 L F
.581 .413 .618 r
.28592 .56984 m .28292 .57345 L .2832 .5702 L F
0 0 .467 r
.33707 .59735 m .33582 .59628 L .33832 .5951 L F
.33707 .59735 m .33637 .59908 L .33582 .59628 L F
.553 .468 .713 r
.72372 .3224 m .72386 .32607 L .72093 .32664 L F
.627 .578 .779 r
.72386 .32607 m .72242 .32965 L .72093 .32664 L F
.884 .7 .649 r
.22183 .57985 m .22122 .58288 L .22318 .58236 L F
.675 .239 .206 r
.22122 .58288 m .22136 .58378 L .22318 .58236 L F
.821 .607 .613 r
.22136 .58378 m .22546 .58279 L .22318 .58236 L F
.662 .89 .537 r
.68977 .29572 m .69095 .29465 L .68834 .29802 L F
.713 .983 .799 r
.68977 .29572 m .68834 .29802 L .6867 .29844 L F
.057 .248 .743 r
.31984 .59896 m .32068 .5984 L .31855 .5965 L F
.23 .07 .447 r
.31984 .59896 m .32147 .60096 L .32068 .5984 L F
.31984 .59896 m .31962 .60195 L .32147 .60096 L F
0 0 0 r
.59427 .46368 m .59309 .46395 L .59058 .46425 L F
.25 0 0 r
.59699 .46388 m .59309 .46395 L .59427 .46368 L F
.751 .952 .638 r
.70049 .35528 m .7031 .35193 L .70175 .35281 L F
0 0 0 r
.70019 .35691 m .70049 .35528 L .70175 .35281 L F
.587 .918 .971 r
.64341 .39148 m .64194 .39332 L .64078 .39221 L F
.64341 .39148 m .64477 .39224 L .64194 .39332 L F
.364 .18 .493 r
.22583 .56975 m .22576 .57232 L .22313 .57257 L F
.774 .959 .646 r
.39667 .67607 m .39852 .67368 L .39711 .67444 L F
.407 0 0 r
.39852 .67368 m .4014 .67478 L .39711 .67444 L F
.757 .882 .468 r
.7041 .34937 m .70486 .34861 L .70448 .34742 L F
.7041 .34937 m .7031 .35193 L .70486 .34861 L F
.875 .957 .855 r
.70486 .34861 m .70708 .34408 L .70448 .34742 L F
.807 .62 .649 r
.32456 .66381 m .32393 .66672 L .32094 .66451 L F
.75 .233 0 r
.32456 .66381 m .32637 .66602 L .32393 .66672 L F
.532 .467 .728 r
.46215 .50557 m .45983 .50854 L .45959 .50649 L F
.46215 .50557 m .46237 .50807 L .45983 .50854 L F
.577 .466 .691 r
.46237 .50807 m .46042 .51373 L .45983 .50854 L F
.762 .321 .204 r
.3744 .51499 m .37676 .51778 L .37824 .51638 L F
.675 .206 .132 r
.37676 .51778 m .38002 .51824 L .37824 .51638 L F
.855 .503 0 r
.61229 .44957 m .6126 .44883 L .61161 .44745 L F
.61229 .44957 m .61305 .45054 L .6126 .44883 L F
.328 .807 .897 r
.33168 .52099 m .33376 .52009 L .33488 .5202 L F
.33168 .52099 m .33065 .52064 L .33376 .52009 L F
.626 .072 0 r
.32301 .50938 m .32683 .5123 L .32661 .50914 L F
.385 .274 .604 r
.32661 .50914 m .32911 .51179 L .32913 .50861 L F
.32661 .50914 m .32683 .5123 L .32911 .51179 L F
.722 .647 .774 r
.45622 .46335 m .45776 .46479 L .45385 .46453 L F
.7 .673 .821 r
.45622 .46335 m .46016 .46399 L .45776 .46479 L F
.683 .536 .679 r
.46016 .46399 m .45779 .46755 L .45776 .46479 L F
.176 0 .354 r
.31708 .6051 m .31938 .60437 L .31962 .60195 L F
.166 0 .344 r
.31708 .6051 m .3188 .60692 L .31938 .60437 L F
.31708 .6051 m .31716 .60777 L .3188 .60692 L F
.367 .138 .429 r
.31175 .60885 m .31349 .61064 L .31403 .6084 L F
.31175 .60885 m .3114 .61146 L .31349 .61064 L F
0 .148 .65 r
.38372 .50919 m .38592 .51094 L .38451 .5094 L F
0 0 0 r
.34805 .68615 m .34538 .68695 L .34342 .68777 L F
.739 .834 .38 r
.29279 .62392 m .29276 .6235 L .29395 .62117 L F
0 .108 .625 r
.29279 .62392 m .29429 .62531 L .29276 .6235 L F
.847 .673 .666 r
.39227 .58254 m .38838 .58497 L .38954 .58301 L F
.809 .822 .861 r
.65024 .40247 m .65376 .40284 L .65332 .39963 L F
.851 .742 .742 r
.65146 .4064 m .65376 .40284 L .65024 .40247 L F
.166 0 .301 r
.23875 .57885 m .2374 .58227 L .23562 .58297 L F
.216 0 0 r
.58128 .46752 m .58418 .46696 L .58366 .46644 L F
.749 .934 .948 r
.58418 .46696 m .5869 .46416 L .58366 .46644 L F
.995 .848 .583 r
.59306 .40811 m .59498 .40665 L .59296 .40606 L F
.59306 .40811 m .59441 .40988 L .59498 .40665 L F
.636 .914 .98 r
.25406 .52605 m .25375 .52802 L .25667 .52545 L F
.25406 .52605 m .25181 .52721 L .25375 .52802 L F
.624 .473 .657 r
.46622 .49272 m .46719 .49593 L .46486 .49618 L F
.581 .449 .665 r
.46622 .49272 m .46987 .49566 L .46719 .49593 L F
.46622 .49272 m .46976 .49324 L .46987 .49566 L F
0 0 .51 r
.3824 .52152 m .38381 .52406 L .38345 .52562 L F
0 .266 .762 r
.38504 .52587 m .38345 .52562 L .38381 .52406 L F
.38504 .52587 m .3861 .52742 L .38345 .52562 L F
.029 .143 .65 r
.35728 .71045 m .35804 .70895 L .35938 .71201 L F
.363 0 0 r
.31717 .5574 m .31513 .55856 L .31274 .5584 L F
0 0 0 r
.31751 .55785 m .31717 .5574 L .31977 .55737 L F
.31751 .55785 m .31513 .55856 L .31717 .5574 L F
.594 .664 .887 r
.33594 .63629 m .33802 .64026 L .33538 .64078 L F
.33572 .63805 m .33538 .64078 L .33591 .63892 L F
.529 .314 .532 r
.33538 .64078 m .33789 .64342 L .33524 .6419 L F
.33538 .64078 m .33802 .64026 L .33789 .64342 L F
0 0 0 r
.33591 .63892 m .33538 .64078 L .33524 .6419 L F
.33591 .63892 m .33524 .6419 L .33473 .64215 L F
.917 .931 .559 r
.33591 .63892 m .33473 .64215 L .33386 .64108 L F
.382 0 .129 r
.33642 .64119 m .33591 .63892 L .33386 .64108 L F
.33679 .6412 m .33591 .63892 L .33642 .64119 L F
.594 .664 .887 r
.33594 .63629 m .33572 .63805 L .33591 .63892 L F
.698 .604 .748 r
.33044 .61815 m .33118 .62154 L .33518 .6206 L F
.494 .103 .228 r
.33518 .6206 m .33118 .62154 L .32995 .62402 L F
.741 .465 .512 r
.21827 .60316 m .21521 .6019 L .2172 .60137 L F
.456 .208 .448 r
.30678 .6153 m .30868 .61712 L .30832 .61434 L F
.30678 .6153 m .30611 .61784 L .30868 .61712 L F
.632 .554 .749 r
.40036 .49574 m .39719 .49331 L .39883 .49235 L F
.486 .821 .999 r
.39493 .49217 m .39883 .49235 L .39719 .49331 L F
.586 .818 .43 r
.69343 .29123 m .69095 .29465 L .69261 .2923 L F
.628 .879 .537 r
.69261 .2923 m .69095 .29465 L .68977 .29572 L F
.996 .802 .442 r
.40079 .56593 m .40148 .56924 L .40192 .56737 L F
.515 .585 .864 r
.55514 .3857 m .55725 .38798 L .55391 .38766 L F
.322 .334 .718 r
.55514 .3857 m .55391 .38766 L .55666 .38819 L F
.755 .71 .809 r
.30596 .5301 m .30748 .532 L .30976 .53054 L F
.834 .544 .498 r
.30976 .53054 m .30791 .53134 L .30596 .5301 L F
.30976 .53054 m .30925 .5325 L .30791 .53134 L F
.784 .4 .328 r
.30791 .53134 m .30935 .53253 L .30902 .53205 L F
.30596 .5301 m .30893 .53222 L .30791 .53134 L F
.30893 .53222 m .30935 .53253 L .30791 .53134 L F
.553 .645 .895 r
.30382 .53288 m .30748 .532 L .30596 .5301 L F
.834 .544 .498 r
.30865 .53221 m .30908 .53272 L .30607 .53213 L F
.578 .256 .386 r
.30544 .53544 m .30909 .53272 L .30607 .53213 L F
.834 .544 .498 r
.30909 .53273 m .30917 .53282 L .30906 .5328 L F
.576 .246 .374 r
.30906 .5328 m .30544 .53544 L .30607 .53213 L F
.30917 .53282 m .30544 .53544 L .30906 .5328 L F
.834 .544 .498 r
.30925 .5325 m .30917 .53282 L .30791 .53134 L F
.578 .256 .386 r
.30909 .53272 m .30906 .5328 L .30935 .53253 L F
.576 .246 .374 r
.30917 .53282 m .30796 .53555 L .30544 .53544 L F
.578 .256 .386 r
.30906 .5328 m .30796 .53555 L .30931 .53261 L F
.354 .078 .349 r
.31027 .53102 m .30936 .53251 L .30976 .53054 L F
.31108 .53178 m .30937 .53251 L .31027 .53102 L F
.30937 .53251 m .30936 .53251 L .31027 .53102 L F
.31143 .53211 m .30931 .53278 L .30936 .53251 L F
.31143 .53211 m .30936 .53251 L .31108 .53178 L F
.612 .705 .911 r
.31089 .53057 m .31129 .53077 L .31081 .53004 L F
.354 .078 .349 r
.31081 .53005 m .31081 .53005 L .31081 .53004 L F
.31081 .53005 m .30976 .53054 L .31081 .53004 L F
.31096 .53101 m .30976 .53054 L .31081 .53005 L F
0 0 0 r
.30739 .52837 m .30513 .53106 L .30596 .5301 L F
.673 .873 .493 r
.30739 .52837 m .30596 .5301 L .30833 .52662 L F
0 0 .314 r
.31069 .52622 m .30976 .53054 L .31078 .52809 L F
.31069 .52622 m .31081 .53004 L .30976 .53054 L F
.798 .959 .636 r
.30596 .5301 m .30639 .52835 L .30833 .52662 L F
.612 .705 .911 r
.30639 .52835 m .31089 .53057 L .31081 .53004 L F
.354 .078 .349 r
.31027 .53102 m .30976 .53054 L .31112 .53107 L F
.499 .281 .513 r
.30932 .53259 m .30937 .53251 L .30935 .53253 L F
.612 .705 .911 r
.30935 .53252 m .30935 .53253 L .30937 .53251 L F
.578 .256 .386 r
.30933 .53255 m .30932 .53259 L .30935 .53253 L F
.354 .078 .349 r
.30931 .53278 m .30935 .53211 L .30976 .53054 L F
.612 .705 .911 r
.30639 .52835 m .30935 .53252 L .31097 .53106 L F
.31089 .53057 m .31097 .53106 L .31129 .53077 L F
.30639 .52835 m .31097 .53106 L .31089 .53057 L F
.354 .078 .349 r
.31112 .53107 m .31096 .53101 L .31081 .53005 L F
.612 .705 .911 r
.30935 .53252 m .30937 .53251 L .31097 .53106 L F
.31097 .53106 m .31097 .53106 L .31129 .53077 L F
.30935 .53252 m .31097 .53106 L .31097 .53106 L F
.354 .078 .349 r
.31143 .53211 m .31108 .53178 L .31112 .53112 L F
.31143 .53211 m .31112 .53112 L .31114 .53116 L F
.31108 .53178 m .31027 .53102 L .31097 .53106 L F
.691 .371 .429 r
.31205 .53531 m .30918 .53283 L .31143 .53211 L F
.30918 .53283 m .30917 .53282 L .30919 .53282 L F
.30918 .53283 m .30919 .53282 L .31143 .53211 L F
.31205 .53531 m .30796 .53555 L .30917 .53282 L F
.499 .281 .513 r
.30796 .53555 m .31108 .53107 L .30995 .53202 L F
.30927 .53273 m .30995 .53202 L .30937 .53251 L F
.30796 .53555 m .30995 .53202 L .30927 .53273 L F
.267 0 0 r
.31084 .53566 m .30852 .53552 L .31205 .53531 L F
.853 .787 .786 r
.31709 .52877 m .3132 .52889 L .3147 .52511 L F
.197 .356 .798 r
.31391 .53043 m .31383 .52917 L .3132 .52889 L F
.349 .43 .803 r
.31576 .53002 m .31383 .52917 L .31709 .52877 L F
.31383 .52917 m .3132 .52889 L .31346 .52888 L F
.31383 .52917 m .31346 .52888 L .31709 .52877 L F
.31539 .53036 m .3132 .52889 L .31576 .53002 L F
.895 .935 .562 r
.3147 .52511 m .3132 .52889 L .31365 .52649 L F
.197 .356 .798 r
.31383 .52917 m .31539 .53036 L .31365 .52649 L F
.31391 .53043 m .31539 .53036 L .31383 .52917 L F
.31383 .52917 m .31365 .52649 L .3132 .52889 L F
.349 .43 .803 r
.31539 .53036 m .31446 .53116 L .3132 .52889 L F
.477 .526 .829 r
.31199 .53109 m .31374 .53179 L .31143 .53211 L F
.31359 .53096 m .31374 .53179 L .31199 .53109 L F
.524 .43 .691 r
.31437 .53468 m .31143 .53211 L .31374 .53179 L F
.31437 .53468 m .31205 .53531 L .31143 .53211 L F
.349 .43 .803 r
.31446 .53116 m .31438 .53123 L .31384 .53104 L F
.49 .286 .53 r
.31363 .53097 m .31384 .53104 L .31391 .53043 L F
.349 .43 .803 r
.31388 .53102 m .31384 .53104 L .31363 .53097 L F
.31446 .53116 m .31384 .53104 L .31388 .53102 L F
.343 .193 .528 r
.31384 .53104 m .31539 .53036 L .31391 .53043 L F
.349 .43 .803 r
.31438 .53123 m .31374 .53179 L .31363 .53097 L F
.49 .286 .53 r
.31272 .53076 m .31391 .53043 L .31225 .53064 L F
.3113 .53115 m .31391 .53043 L .31127 .53116 L F
.31363 .53094 m .31391 .53043 L .31127 .53116 L F
.489 .605 .895 r
.31129 .53077 m .31391 .53043 L .3132 .52889 L F
.349 .43 .803 r
.31446 .53116 m .31359 .53096 L .3132 .52889 L F
.633 .537 .728 r
.31683 .533 m .31437 .53468 L .31374 .53179 L F
.31683 .533 m .31374 .53179 L .31539 .53036 L F
.343 .193 .528 r
.31336 .53497 m .31539 .53036 L .31384 .53104 L F
.541 .313 .517 r
.31544 .53443 m .3177 .53746 L .31797 .53413 L F
.31544 .53443 m .31504 .53817 L .3177 .53746 L F
0 .152 .693 r
.31621 .53739 m .31437 .53468 L .31734 .53605 L F
0 .036 .548 r
.31437 .53468 m .31517 .53528 L .31482 .53495 L F
0 .152 .693 r
.31621 .53739 m .31664 .53686 L .31437 .53468 L F
.343 .193 .528 r
.3133 .53551 m .31493 .53506 L .31482 .53495 L F
0 .036 .548 r
.31437 .53468 m .31482 .53495 L .31476 .53496 L F
.31437 .53468 m .31484 .53501 L .31326 .53509 L F
.343 .193 .528 r
.31348 .53508 m .31482 .53495 L .31389 .53406 L F
.3133 .53551 m .31482 .53495 L .31348 .53508 L F
.042 0 0 r
.31485 .53499 m .31493 .53506 L .3133 .53551 L F
0 .036 .548 r
.31482 .53495 m .31491 .53501 L .31476 .53496 L F
.31482 .53495 m .31517 .53528 L .31491 .53501 L F
.931 .764 .288 r
.31797 .53413 m .31794 .53452 L .31734 .53605 L F
.31794 .53452 m .3177 .53746 L .31734 .53605 L F
.817 .453 .367 r
.32079 .53566 m .31734 .53605 L .3177 .53746 L F
.32079 .53566 m .31693 .53712 L .31734 .53605 L F
.31693 .53712 m .31621 .53739 L .31734 .53605 L F
.931 .764 .288 r
.31797 .53413 m .31734 .53605 L .3187 .53463 L F
.705 .828 .941 r
.3187 .53463 m .31437 .53468 L .31683 .533 L F
.343 .193 .528 r
.31493 .53506 m .31554 .53489 L .31389 .53406 L F
.254 0 0 r
.31892 .53451 m .32052 .53466 L .32202 .53285 L F
.3187 .53463 m .32052 .53466 L .31892 .53451 L F
.73 .845 .935 r
.32052 .53466 m .32284 .53613 L .32529 .53469 L F
.32052 .53466 m .32529 .53469 L .32449 .53164 L F
.251 .432 .846 r
.32163 .53285 m .32249 .53484 L .32052 .53466 L F
.493 .721 .973 r
.32231 .5373 m .32456 .53676 L .32079 .53566 L F
0 .457 .752 r
.32456 .53676 m .32284 .53613 L .32079 .53566 L F
.71 .943 .958 r
.32529 .53469 m .32284 .53613 L .32456 .53676 L F
.32529 .53469 m .32284 .53613 L .32456 .53676 L F
.786 .892 .92 r
.32079 .53566 m .31954 .53843 L .32231 .5373 L F
.32079 .53566 m .3177 .53746 L .31954 .53843 L F
.498 .126 .265 r
.32284 .53613 m .31901 .53866 L .32079 .53566 L F
.594 .626 .853 r
.31954 .53843 m .32366 .54123 L .32231 .5373 L F
.443 .455 .776 r
.32366 .54123 m .32456 .53676 L .32231 .5373 L F
.498 .126 .265 r
.32284 .53613 m .3223 .53893 L .31901 .53866 L F
.251 .432 .846 r
.32249 .53484 m .32348 .53713 L .32052 .53466 L F
.705 .828 .941 r
.3187 .53463 m .31734 .53605 L .31437 .53468 L F
.302 .58 .939 r
.31594 .53122 m .3187 .53463 L .31683 .533 L F
.102 .373 .835 r
.31539 .53036 m .31594 .53122 L .31683 .533 L F
.608 .74 .939 r
.31544 .53511 m .31991 .53597 L .31684 .53243 L F
.302 .58 .939 r
.31594 .53122 m .32052 .53466 L .3187 .53463 L F
.592 .695 .914 r
.31704 .52947 m .31805 .53166 L .32024 .53044 L F
.607 .721 .926 r
.32024 .53044 m .32104 .52852 L .32125 .52699 L F
.32024 .53044 m .32314 .5305 L .32104 .52852 L F
.426 .063 .244 r
.31951 .52816 m .31594 .53122 L .3209 .52982 L F
.31951 .52816 m .31594 .53122 L .3209 .52982 L F
.389 .615 .941 r
.32163 .53285 m .32052 .53466 L .31594 .53122 L F
.644 .36 .473 r
.32024 .53044 m .32202 .53285 L .32314 .5305 L F
.389 .615 .941 r
.32163 .53285 m .31594 .53122 L .3209 .52982 L F
.155 0 0 r
.31747 .53124 m .3209 .52982 L .31594 .53122 L F
.102 .373 .835 r
.31539 .53036 m .31747 .53124 L .31594 .53122 L F
.386 .224 .536 r
.31539 .53036 m .31561 .53474 L .31747 .53124 L F
.608 .74 .939 r
.31561 .53474 m .31684 .53243 L .31674 .53231 L F
.31544 .53511 m .31684 .53243 L .31561 .53474 L F
.31674 .53231 m .31991 .53597 L .31747 .53124 L F
.386 .224 .536 r
.31561 .53474 m .31562 .53487 L .31747 .53124 L F
.343 .193 .528 r
.31554 .53489 m .31562 .53487 L .31556 .53484 L F
.31554 .53489 m .31556 .53484 L .31389 .53406 L F
.042 0 0 r
.31487 .53498 m .31546 .53489 L .31493 .53506 L F
.343 .193 .528 r
.31389 .53406 m .31562 .53487 L .31539 .53036 L F
.608 .74 .939 r
.31498 .5349 m .31554 .53489 L .31674 .53231 L F
.042 0 0 r
.31546 .53489 m .31562 .53487 L .31554 .53489 L F
.31546 .53489 m .31554 .53489 L .31493 .53506 L F
.608 .74 .939 r
.31491 .53501 m .31544 .53511 L .31554 .53489 L F
.31491 .53501 m .31554 .53489 L .31498 .5349 L F
.042 0 0 r
.31487 .53498 m .31487 .53499 L .31485 .53499 L F
.31487 .53499 m .31493 .53506 L .31485 .53499 L F
0 .036 .548 r
.31481 .53499 m .31491 .53501 L .31484 .53501 L F
.31476 .53496 m .31485 .53499 L .31481 .53499 L F
.31485 .53499 m .31491 .53501 L .31481 .53499 L F
.343 .193 .528 r
.3133 .53551 m .31348 .53508 L .31335 .53508 L F
.042 0 0 r
.31265 .53531 m .31487 .53498 L .3133 .53551 L F
0 .036 .548 r
.31502 .53517 m .31664 .53686 L .31517 .53528 L F
.31437 .53468 m .31545 .53572 L .31502 .53517 L F
.31545 .53572 m .31664 .53686 L .31502 .53517 L F
.31326 .53509 m .31484 .53501 L .31265 .53531 L F
.49 .286 .53 r
.31102 .53597 m .3129 .53517 L .31127 .53554 L F
0 0 0 r
.31247 .53521 m .31254 .53525 L .31165 .53544 L F
.31326 .53509 m .31265 .53531 L .31247 .53521 L F
.49 .286 .53 r
.3129 .53517 m .31336 .53497 L .31165 .53544 L F
.3129 .53517 m .31165 .53544 L .31127 .53554 L F
0 0 0 r
.31165 .53544 m .31082 .53566 L .31205 .53531 L F
.349 .43 .803 r
.31363 .53097 m .31374 .53179 L .31359 .53096 L F
.49 .286 .53 r
.31102 .53597 m .31384 .53104 L .31363 .53097 L F
0 0 0 r
.31165 .53544 m .31265 .53531 L .31019 .53585 L F
.31254 .53525 m .31265 .53531 L .31165 .53544 L F
.31437 .53468 m .31326 .53509 L .31247 .53521 L F
.343 .193 .528 r
.31335 .53507 m .31354 .53492 L .31336 .53497 L F
.31335 .53508 m .31337 .53507 L .31335 .53507 L F
.31337 .53507 m .31354 .53492 L .31335 .53507 L F
.31348 .53508 m .31354 .53492 L .31335 .53508 L F
.31354 .53492 m .31539 .53036 L .31336 .53497 L F
0 0 0 r
.31437 .53468 m .31247 .53521 L .31205 .53531 L F
.31247 .53521 m .31165 .53544 L .31185 .53538 L F
.31247 .53521 m .31185 .53538 L .31205 .53531 L F
.267 0 0 r
.31082 .53566 m .30796 .53555 L .30852 .53552 L F
.31082 .53566 m .30852 .53552 L .31084 .53566 L F
.499 .281 .513 r
.30796 .53555 m .31104 .53567 L .31126 .53132 L F
0 0 0 r
.31165 .53544 m .31019 .53585 L .31082 .53566 L F
.49 .286 .53 r
.31102 .53597 m .3133 .53551 L .31336 .53497 L F
.31127 .53554 m .31336 .53497 L .31384 .53104 L F
.31127 .53116 m .31272 .53076 L .31129 .53077 L F
.31272 .53076 m .31225 .53064 L .31129 .53077 L F
.31127 .53116 m .3113 .53115 L .31127 .53116 L F
.477 .526 .829 r
.3132 .52889 m .31359 .53096 L .31199 .53109 L F
.489 .605 .895 r
.31129 .53077 m .3132 .52889 L .31081 .53004 L F
.477 .526 .829 r
.3132 .52889 m .31199 .53109 L .31081 .53004 L F
.31199 .53109 m .31143 .53211 L .31115 .53117 L F
.499 .281 .513 r
.31108 .53107 m .31114 .53116 L .31129 .53077 L F
.477 .526 .829 r
.31127 .53116 m .31115 .53117 L .31114 .53116 L F
.499 .281 .513 r
.31114 .53116 m .31126 .53132 L .31127 .53116 L F
.31114 .53116 m .31127 .53116 L .31129 .53077 L F
.477 .526 .829 r
.31199 .53109 m .31127 .53116 L .31081 .53004 L F
.499 .281 .513 r
.31108 .53107 m .31129 .53077 L .31097 .53106 L F
.477 .526 .829 r
.31127 .53116 m .31114 .53116 L .31081 .53004 L F
.49 .286 .53 r
.31104 .53567 m .31363 .53094 L .31127 .53116 L F
.31102 .53597 m .31118 .53568 L .31104 .53567 L F
.31118 .53568 m .31391 .53043 L .31104 .53567 L F
.499 .281 .513 r
.30796 .53555 m .31102 .53597 L .31104 .53567 L F
.267 0 0 r
.31019 .53585 m .30796 .53555 L .31082 .53566 L F
.354 .078 .349 r
.31108 .53178 m .31097 .53106 L .31112 .53107 L F
.499 .281 .513 r
.30796 .53555 m .31126 .53132 L .31108 .53107 L F
.354 .078 .349 r
.31114 .53116 m .31112 .53112 L .31112 .53107 L F
.499 .281 .513 r
.31108 .53107 m .31097 .53106 L .30937 .53251 L F
.30796 .53555 m .30937 .53251 L .30932 .53259 L F
.578 .256 .386 r
.30909 .53272 m .30933 .53255 L .30607 .53213 L F
.30933 .53255 m .30935 .53253 L .30934 .53253 L F
.30933 .53255 m .30934 .53253 L .30607 .53213 L F
.354 .078 .349 r
.30931 .53278 m .30917 .53282 L .30919 .53274 L F
.30933 .53255 m .30919 .53274 L .30935 .53211 L F
.30931 .53278 m .30919 .53274 L .30933 .53255 L F
.578 .256 .386 r
.30906 .5328 m .30931 .53261 L .30932 .53259 L F
.30906 .5328 m .30932 .53259 L .30933 .53255 L F
.30544 .53544 m .30789 .53555 L .30909 .53272 L F
.30789 .53555 m .30796 .53555 L .30909 .53272 L F
.834 .544 .498 r
.30908 .53272 m .30909 .53273 L .30607 .53213 L F
.30909 .53273 m .30906 .5328 L .30607 .53213 L F
.784 .4 .328 r
.30893 .53222 m .30607 .53213 L .30935 .53253 L F
.30596 .5301 m .30607 .53213 L .30893 .53222 L F
.834 .544 .498 r
.30791 .53134 m .30865 .53221 L .30607 .53213 L F
.30791 .53134 m .30607 .53213 L .30596 .5301 L F
.784 .4 .328 r
.30596 .5301 m .30902 .53205 L .30687 .52904 L F
.30596 .5301 m .30687 .52904 L .30639 .52835 L F
0 0 0 r
.30513 .53106 m .30432 .53202 L .30596 .5301 L F
.611 .435 .618 r
.35672 .55601 m .35754 .55991 L .35406 .56039 L F
.225 0 0 r
.35672 .55601 m .35473 .55853 L .3573 .55793 L F
.178 0 0 r
.35093 .52857 m .3469 .52858 L .3487 .52724 L F
.35093 .52857 m .34735 .5306 L .3469 .52858 L F
.35093 .52857 m .35005 .53001 L .34735 .5306 L F
0 0 0 r
.35382 .52877 m .35005 .53001 L .35093 .52857 L F
.58 .418 .626 r
.35336 .52532 m .35382 .52877 L .35093 .52857 L F
.549 .122 .182 r
.3625 .54335 m .36487 .54483 L .36207 .54524 L F
.311 0 .09 r
.41798 .48647 m .41443 .48893 L .41537 .48704 L F
.826 1 .803 r
.60284 .36769 m .59925 .37076 L .60348 .37066 L F
.647 .617 .805 r
.60348 .37066 m .60492 .3665 L .60284 .36769 L F
.605 .769 .958 r
.47977 .45036 m .48389 .45114 L .48107 .45207 L F
0 .515 .848 r
.34519 .49616 m .34391 .49649 L .34213 .49559 L F
.34519 .49616 m .34638 .49712 L .34391 .49649 L F
.011 .576 .797 r
.2756 .52132 m .27833 .52159 L .27415 .52096 L F
.589 .08 0 r
.35645 .69404 m .35689 .6943 L .35486 .69233 L F
0 .117 .66 r
.35608 .69268 m .35645 .69404 L .35486 .69233 L F
.912 .536 .297 r
.35577 .69364 m .35645 .69404 L .35608 .69268 L F
.35494 .69617 m .35645 .69404 L .35577 .69364 L F
.589 .08 0 r
.35645 .69404 m .35739 .69478 L .35689 .6943 L F
.522 .219 .395 r
.3596 .69727 m .35739 .69478 L .35645 .69404 L F
.3596 .69727 m .35987 .6951 L .35739 .69478 L F
.022 0 .162 r
.34763 .5183 m .34492 .52057 L .34812 .5157 L F
.622 .26 .334 r
.35059 .51778 m .34763 .5183 L .34812 .5157 L F
.177 0 .162 r
.30922 .61229 m .31054 .61349 L .3114 .61146 L F
.30922 .61229 m .30832 .61434 L .31054 .61349 L F
.629 .778 .953 r
.62645 .38607 m .6275 .38796 L .63025 .3869 L F
.63025 .3869 m .6275 .38796 L .62645 .38607 L F
.839 .842 .848 r
.51671 .44787 m .51625 .45074 L .51403 .45104 L F
.762 .619 .701 r
.51625 .45074 m .51495 .45126 L .51495 .45136 L F
.51625 .45074 m .51495 .45136 L .51403 .45104 L F
.839 .842 .848 r
.51895 .44722 m .51625 .45074 L .51671 .44787 L F
.728 .641 .761 r
.52075 .44847 m .51625 .45074 L .51895 .44722 L F
.369 0 0 r
.26719 .51744 m .26834 .51783 L .27016 .51762 L F
.462 .844 .985 r
.26741 .5174 m .26767 .51735 L .26534 .51768 L F
.2637 .51797 m .26741 .5174 L .26534 .51768 L F
.26741 .5174 m .26812 .51729 L .26767 .51735 L F
.2637 .51797 m .26605 .51737 L .26812 .51729 L F
.369 0 0 r
.26605 .51737 m .26678 .51751 L .26719 .51744 L F
.26678 .51751 m .26834 .51783 L .26719 .51744 L F
.494 .738 .981 r
.27091 .61825 m .27073 .62011 L .26828 .61952 L F
.27091 .61825 m .27361 .62006 L .27073 .62011 L F
.608 .038 0 r
.32521 .64234 m .32821 .64371 L .32673 .64262 L F
.674 .181 .071 r
.35736 .55321 m .3526 .55139 L .35503 .5507 L F
.343 .282 .643 r
.42126 .48358 m .42366 .48556 L .42406 .48283 L F
.42126 .48358 m .42216 .48699 L .42366 .48556 L F
.783 .51 .524 r
.42406 .48283 m .41959 .48501 L .42126 .48358 L F
.762 .524 .573 r
.39378 .6476 m .39095 .6451 L .3932 .64697 L F
.452 .766 .996 r
.69973 .32465 m .69765 .32631 L .69642 .32586 L F
.69973 .32465 m .70064 .32596 L .69765 .32631 L F
0 .242 .707 r
.72242 .32965 m .72536 .33175 L .72323 .3313 L F
.793 .483 0 r
.22987 .60893 m .22969 .60939 L .22991 .60744 L F
.22987 .60893 m .2305 .61152 L .22969 .60939 L F
.541 .005 0 r
.42729 .49095 m .42415 .48926 L .42727 .49171 L F
.828 .988 .871 r
.4269 .49335 m .4256 .49283 L .42729 .49095 L F
.416 .089 .3 r
.34994 .60211 m .34935 .60465 L .34681 .6049 L F
.249 .023 .362 r
.35255 .59864 m .3523 .60143 L .34994 .60211 L F
.305 0 .264 r
.35174 .60403 m .34994 .60211 L .3523 .60143 L F
.35174 .60403 m .34935 .60465 L .34994 .60211 L F
.462 .112 .286 r
.34345 .54669 m .33965 .54898 L .34119 .54721 L F
.428 .596 .914 r
.61842 .39113 m .61496 .38876 L .61532 .38882 L F
.757 .633 .723 r
.61655 .39328 m .61842 .39113 L .61532 .38882 L F
.768 .596 .665 r
.48799 .45438 m .48516 .45725 L .48522 .4547 L F
.506 .237 .441 r
.29695 .61826 m .29653 .6206 L .29709 .61837 L F
.882 .991 .798 r
.38977 .4928 m .38705 .49631 L .38723 .49403 L F
.882 .896 .477 r
.38705 .49631 m .38576 .49801 L .38723 .49403 L F
.7 .673 .821 r
.45622 .46335 m .45894 .46054 L .46016 .46399 L F
.772 .711 .795 r
.45894 .46054 m .46296 .46102 L .46016 .46399 L F
.809 .96 .632 r
.70175 .35281 m .7031 .35193 L .7041 .34937 L F
.998 .844 .514 r
.52918 .42101 m .53072 .41942 L .5297 .41813 L F
.41 0 0 r
.53299 .4202 m .53072 .41942 L .52918 .42101 L F
.403 0 0 r
.53299 .4202 m .53362 .41966 L .53072 .41942 L F
.926 .549 .148 r
.38991 .53332 m .39092 .53295 L .38831 .53067 L F
.38991 .53332 m .39122 .53452 L .39092 .53295 L F
.929 .689 .204 r
.36758 .58943 m .36735 .59213 L .36327 .58971 L F
.36735 .59213 m .36733 .59216 L .36327 .58971 L F
.837 .988 .718 r
.36618 .59319 m .36772 .59234 L .36779 .59174 L F
.929 .689 .204 r
.36735 .59213 m .36772 .59234 L .36735 .59217 L F
.36758 .58943 m .36772 .59234 L .36735 .59213 L F
.837 .988 .718 r
.367 .59193 m .36779 .59174 L .36795 .59047 L F
.663 .181 .095 r
.36327 .58971 m .36733 .59216 L .36335 .59102 L F
.36733 .59216 m .36735 .59217 L .36732 .59216 L F
.36733 .59216 m .36732 .59216 L .36335 .59102 L F
.711 .309 .285 r
.36335 .59102 m .36732 .59216 L .36562 .5935 L F
.837 .988 .718 r
.36618 .59319 m .36732 .59216 L .36636 .59292 L F
.711 .309 .285 r
.36732 .59216 m .36735 .59217 L .36562 .5935 L F
.837 .988 .718 r
.36618 .59319 m .36733 .59216 L .36732 .59216 L F
.36636 .59292 m .36732 .59216 L .36653 .59266 L F
.36653 .59266 m .36735 .59213 L .367 .59193 L F
.36733 .59216 m .36735 .59213 L .36653 .59266 L F
.36735 .59213 m .36779 .59174 L .367 .59193 L F
0 0 .123 r
.36795 .59047 m .36772 .59234 L .36758 .58943 L F
.837 .988 .718 r
.36562 .5935 m .36618 .59319 L .36795 .59047 L F
.929 .689 .204 r
.36735 .59213 m .36735 .59217 L .36733 .59216 L F
0 0 .123 r
.36795 .59047 m .36758 .58943 L .36826 .58777 L F
0 0 0 r
.36185 .53209 m .35865 .53439 L .36087 .5332 L F
.604 .446 .641 r
.47151 .48772 m .4723 .48952 L .46983 .48972 L F
.562 .353 .554 r
.4723 .48952 m .46976 .49324 L .46983 .48972 L F
.83 .867 .872 r
.64671 .33672 m .64254 .3381 L .64541 .33528 L F
.813 .883 .896 r
.64864 .33497 m .64671 .33672 L .64541 .33528 L F
.775 .862 .915 r
.65261 .38575 m .65049 .38986 L .64931 .38835 L F
.65261 .38575 m .65399 .38725 L .65049 .38986 L F
.665 .657 .833 r
.44075 .46531 m .43692 .46383 L .43921 .46347 L F
.652 .774 .938 r
.44327 .46422 m .44075 .46531 L .43921 .46347 L F
.446 .854 .682 r
.452 .59304 m .44992 .59408 L .44837 .59522 L F
0 0 0 r
.45241 .59338 m .452 .59304 L .45394 .59172 L F
.45241 .59338 m .44992 .59408 L .452 .59304 L F
.505 .122 .246 r
.60348 .46103 m .60577 .46209 L .60233 .46218 L F
.60348 .46103 m .60629 .46088 L .60577 .46209 L F
.624 .418 .583 r
.25583 .61821 m .25887 .61809 L .25939 .61416 L F
.416 .235 .526 r
.25939 .61416 m .26146 .61678 L .26284 .61492 L F
.25939 .61416 m .25887 .61809 L .26146 .61678 L F
.39 .195 .492 r
.35016 .68173 m .34775 .68243 L .34978 .68429 L F
.415 .456 .795 r
.34979 .55406 m .3476 .55266 L .35077 .55254 L F
.3476 .55266 m .34665 .55206 L .34739 .55214 L F
.3476 .55266 m .34739 .55214 L .35077 .55254 L F
0 0 .373 r
.34637 .55081 m .34738 .55235 L .34732 .55197 L F
.3466 .55014 m .34732 .55197 L .34691 .54923 L F
.34637 .55081 m .34732 .55197 L .3466 .55014 L F
.817 .875 .439 r
.35461 .52146 m .35336 .52532 L .35569 .52174 L F
.815 .38 .211 r
.35842 .52409 m .35569 .52174 L .35695 .52002 L F
.35842 .52409 m .35461 .52146 L .35569 .52174 L F
.466 .171 .38 r
.31571 .55407 m .31839 .55373 L .31969 .55036 L F
.654 .622 .805 r
.31969 .55036 m .32075 .54714 L .31848 .54829 L F
.31969 .55036 m .32233 .55092 L .32075 .54714 L F
.32 .031 .309 r
.31969 .55036 m .32063 .5527 L .32233 .55092 L F
.31969 .55036 m .31839 .55373 L .32063 .5527 L F
.67 .338 .403 r
.32622 .51884 m .32826 .52106 L .32827 .51902 L F
.32622 .51884 m .32468 .52103 L .32826 .52106 L F
.829 .934 .899 r
.32877 .66283 m .3306 .66379 L .33241 .66205 L F
.893 .883 .816 r
.65332 .39963 m .65699 .3978 L .65562 .39627 L F
.791 .859 .901 r
.65699 .3978 m .65906 .39635 L .65562 .39627 L F
.86 .889 .856 r
.68525 .35901 m .68127 .36089 L .68352 .35746 L F
.741 .672 .783 r
.51931 .44464 m .52075 .44847 L .51895 .44722 L F
.609 .086 0 r
.4296 .57073 m .42873 .57197 L .43197 .57221 L F
.43197 .57221 m .4296 .57073 L .43145 .5685 L F
.43197 .57221 m .42873 .57197 L .4296 .57073 L F
0 .079 .585 r
.59524 .39533 m .59671 .39692 L .59883 .3988 L F
.233 .481 .889 r
.59671 .39692 m .60047 .39993 L .59883 .3988 L F
.819 .86 .878 r
.63456 .34523 m .63112 .34536 L .6334 .34384 L F
.826 .911 .896 r
.63752 .3424 m .63456 .34523 L .6334 .34384 L F
.839 .538 0 r
.4008 .57514 m .40176 .57651 L .40098 .57565 L F
.4008 .57514 m .40238 .57941 L .40176 .57651 L F
.57 .547 .789 r
.45477 .56099 m .45623 .5566 L .45385 .55984 L F
.45477 .56099 m .45749 .56026 L .45623 .5566 L F
.533 .423 .674 r
.4553 .56401 m .45749 .56026 L .45477 .56099 L F
0 0 0 r
.70014 .28258 m .7006 .28104 L .69819 .2844 L F
.763 .961 .659 r
.70337 .27746 m .7006 .28104 L .70146 .27874 L F
0 0 0 r
.70146 .27874 m .7006 .28104 L .70014 .28258 L F
0 0 .205 r
.35622 .56984 m .35767 .56593 L .35913 .56688 L F
.915 .895 .794 r
.36098 .5634 m .35913 .56688 L .35767 .56593 L F
.988 .78 .534 r
.40053 .58481 m .40229 .58287 L .40164 .58209 L F
.40053 .58481 m .40197 .58548 L .40229 .58287 L F
.887 .989 .797 r
.52669 .41617 m .52416 .41945 L .52344 .41866 L F
.954 .726 .27 r
.52416 .41945 m .52415 .42202 L .52344 .41866 L F
.443 .455 .776 r
.32366 .54123 m .3256 .54051 L .32456 .53676 L F
0 0 .051 r
.33707 .59735 m .33594 .60165 L .33637 .59908 L F
.881 .977 .677 r
.24195 .54981 m .24217 .55093 L .24453 .55033 L F
.421 .699 .979 r
.56548 .40431 m .56483 .40592 L .56332 .40474 L F
.75 .254 .049 r
.28112 .57254 m .28292 .57345 L .28338 .57494 L F
.581 .413 .618 r
.28592 .56984 m .28551 .5736 L .28292 .57345 L F
.629 .257 .319 r
.28551 .5736 m .28338 .57494 L .28292 .57345 L F
.801 .754 .237 r
.33473 .61538 m .33443 .61582 L .33447 .61565 L F
.16 0 .329 r
.33319 .61525 m .33473 .61538 L .33497 .61514 L F
.801 .754 .237 r
.33473 .61538 m .33447 .61565 L .335 .61315 L F
.16 0 .329 r
.33497 .61514 m .33473 .61538 L .33641 .61505 L F
.585 .945 .84 r
.33641 .61505 m .33473 .61538 L .33764 .61374 L F
0 0 .333 r
.33756 .61634 m .33641 .61505 L .33764 .61374 L F
.882 .814 .777 r
.64129 .42462 m .64465 .42452 L .64518 .42257 L F
.886 .797 .756 r
.64306 .42627 m .64465 .42452 L .64129 .42462 L F
.665 .933 .652 r
.622 .37651 m .62454 .37433 L .62577 .3727 L F
.295 .359 .758 r
.62454 .37433 m .62741 .37647 L .62577 .3727 L F
.83 .966 .644 r
.30432 .53202 m .30258 .53482 L .30382 .53288 L F
.64 .485 .657 r
.2488 .56673 m .24627 .5703 L .24947 .56904 L F
.2488 .56673 m .24627 .5703 L .24947 .56904 L F
.102 .147 .623 r
.2488 .56673 m .24947 .56904 L .25036 .56776 L F
.492 .621 .906 r
.50206 .44435 m .49969 .44481 L .49826 .44173 L F
.412 .199 .477 r
.49952 .44756 m .49969 .44481 L .50206 .44435 L F
.771 .986 .746 r
.37482 .63765 m .37541 .63594 L .37311 .63657 L F
.37482 .63765 m .37747 .63475 L .37541 .63594 L F
0 .134 .664 r
.31855 .5965 m .3197 .59688 L .31801 .59455 L F
.756 .935 .591 r
.32003 .59549 m .31966 .59602 L .3197 .59688 L F
0 .134 .664 r
.31855 .5965 m .31973 .59756 L .3197 .59688 L F
.782 .525 .548 r
.3197 .59688 m .31721 .59438 L .31801 .59455 L F
.3197 .59688 m .31546 .59658 L .31721 .59438 L F
.147 0 0 r
.3197 .59688 m .31511 .59947 L .31546 .59658 L F
.3197 .59688 m .31774 .59882 L .31511 .59947 L F
.756 .935 .591 r
.31966 .59602 m .31774 .59882 L .3197 .59688 L F
0 .134 .664 r
.31973 .59756 m .32068 .5984 L .3197 .59688 L F
.844 .791 .8 r
.26451 .52408 m .26979 .52274 L .2656 .52345 L F
.8 .957 .916 r
.27 .52038 m .26979 .52274 L .27234 .52075 L F
.27 .52038 m .2656 .52345 L .26979 .52274 L F
.823 .982 .883 r
.29156 .51356 m .29031 .51647 L .28996 .51478 L F
0 0 0 r
.23781 .53146 m .23907 .53074 L .24049 .52841 L F
.351 .79 .62 r
.23781 .53146 m .23562 .53269 L .23907 .53074 L F
.805 .315 .005 r
.59866 .41783 m .59951 .41717 L .5982 .41537 L F
.59866 .41783 m .60057 .41865 L .59951 .41717 L F
.616 .54 .746 r
.46967 .47942 m .47338 .48024 L .47115 .4833 L F
.644 .58 .768 r
.47115 .4833 m .47338 .48024 L .47398 .48258 L F
.574 .45 .674 r
.47398 .48258 m .47151 .48772 L .47115 .4833 L F
.612 .39 .556 r
.46486 .49618 m .46437 .4987 L .46103 .49899 L F
.593 .368 .544 r
.46719 .49593 m .46437 .4987 L .46486 .49618 L F
.495 .293 .534 r
.24947 .56904 m .24648 .57338 L .24627 .5703 L F
.625 .275 .356 r
.24432 .57208 m .24947 .56904 L .24627 .5703 L F
.369 .146 .439 r
.34837 .59271 m .35014 .59453 L .35039 .59194 L F
.34837 .59271 m .34796 .59529 L .35014 .59453 L F
.832 .431 0 r
.58759 .38922 m .58878 .39065 L .58968 .39327 L F
.854 .802 .799 r
.42787 .48716 m .43182 .48662 L .43036 .48589 L F
.719 .935 .612 r
.43276 .48468 m .43182 .48662 L .43434 .48339 L F
.624 .917 .979 r
.43036 .48589 m .43182 .48662 L .43276 .48468 L F
.263 .752 .66 r
.43073 .48826 m .43471 .48668 L .43182 .48662 L F
.543 .379 .608 r
.43182 .48662 m .43471 .48668 L .43434 .48339 L F
.645 .35 .457 r
.34174 .56631 m .34477 .5663 L .34552 .56405 L F
.38 .15 .436 r
.34552 .56405 m .3475 .56321 L .3481 .56078 L F
.819 .741 .218 r
.34552 .56405 m .34597 .55925 L .3475 .56321 L F
.265 .772 .79 r
.34528 .56374 m .34552 .56405 L .3475 .56321 L F
.34528 .56374 m .34293 .56437 L .34552 .56405 L F
.396 .182 .467 r
.34552 .56405 m .34724 .56578 L .3475 .56321 L F
.515 .281 .498 r
.34477 .5663 m .3475 .56321 L .34552 .56405 L F
.779 .632 .698 r
.34493 .67807 m .34368 .67609 L .34254 .67575 L F
.506 .237 .441 r
.29695 .61826 m .29395 .62117 L .29653 .6206 L F
.606 .341 .49 r
.33336 .60194 m .33039 .60437 L .33022 .60233 L F
0 0 .205 r
.35622 .56984 m .35742 .56857 L .35767 .56593 L F
0 0 0 r
.35622 .56984 m .35533 .57182 L .35742 .56857 L F
.408 .173 .444 r
.39873 .6781 m .39667 .67607 L .39711 .67444 L F
.39873 .6781 m .39618 .67862 L .39667 .67607 L F
.614 .956 .892 r
.41933 .47683 m .42066 .47523 L .42268 .47502 L F
.62 .955 .804 r
.41933 .47683 m .41876 .47674 L .42066 .47523 L F
.571 .42 .638 r
.42279 .50872 m .42015 .51193 L .42026 .5088 L F
.624 .69 .891 r
.7182 .34164 m .72095 .34007 L .71908 .33734 L F
0 .471 .765 r
.7186 .34141 m .72071 .34051 L .72091 .34014 L F
.71791 .3418 m .72071 .34051 L .7186 .34141 L F
.71774 .34188 m .72091 .34014 L .72095 .34007 L F
.624 .69 .891 r
.71816 .34183 m .72095 .34007 L .7182 .34164 L F
0 .471 .765 r
.71774 .34188 m .71791 .3418 L .7186 .34141 L F
.724 .674 .801 r
.71801 .34173 m .71774 .34188 L .71816 .34183 L F
.71432 .33938 m .71774 .34188 L .71801 .34173 L F
.624 .69 .891 r
.71816 .34183 m .71774 .34188 L .72095 .34007 L F
.047 0 0 r
.43184 .55317 m .42992 .55402 L .42977 .55365 L F
.891 .943 .839 r
.66989 .37042 m .66834 .37489 L .66665 .37302 L F
.66989 .37042 m .67103 .37155 L .66834 .37489 L F
.267 0 .053 r
.29234 .56708 m .29078 .56943 L .28863 .56984 L F
.407 0 .133 r
.29406 .56823 m .29234 .56708 L .29525 .5668 L F
.29406 .56823 m .29078 .56943 L .29234 .56708 L F
.766 .808 .887 r
.68265 .3832 m .68616 .38333 L .68586 .38051 L F
.814 .838 .868 r
.68616 .38333 m .68779 .3789 L .68586 .38051 L F
.68616 .38333 m .68916 .38056 L .68779 .3789 L F
.817 .875 .439 r
.35461 .52146 m .35335 .52418 L .35336 .52532 L F
.856 .425 0 r
.35335 .52418 m .35597 .52775 L .35336 .52532 L F
.439 .318 .617 r
.35597 .52775 m .35382 .52877 L .35336 .52532 L F
.887 .989 .797 r
.52669 .41617 m .52344 .41866 L .52537 .41493 L F
.245 .178 .58 r
.29842 .54791 m .30013 .54973 L .301 .54728 L F
.29842 .54791 m .29857 .55068 L .30013 .54973 L F
.543 .362 .585 r
.3475 .56321 m .34992 .55986 L .3481 .56078 L F
.937 .608 .385 r
.38456 .66522 m .38678 .6633 L .3844 .66206 L F
.8 .954 .62 r
.38702 .66209 m .38678 .6633 L .38536 .66453 L F
.38553 .66399 m .38536 .66453 L .38456 .66522 L F
.38702 .66209 m .38536 .66453 L .38553 .66399 L F
.67 .856 .971 r
.38599 .66252 m .3844 .66206 L .38541 .66171 L F
.38639 .66308 m .38589 .66282 L .38599 .66252 L F
.38589 .66282 m .3844 .66206 L .38599 .66252 L F
.8 .954 .62 r
.38702 .66209 m .38456 .66522 L .38597 .66485 L F
.38702 .66209 m .38597 .66485 L .38763 .6644 L F
0 0 .162 r
.3881 .65897 m .38769 .66032 L .38702 .66209 L F
.38769 .66032 m .38678 .6633 L .38702 .66209 L F
.548 .378 .603 r
.48516 .45725 m .48254 .4607 L .48227 .45787 L F
.99 .728 .412 r
.60574 .43362 m .6071 .43224 L .60583 .43094 L F
.60574 .43362 m .6071 .43487 L .6071 .43224 L F
.943 .671 .494 r
.61035 .43817 m .61046 .44103 L .61231 .44186 L F
.97 .676 .41 r
.61083 .44326 m .61231 .44186 L .61046 .44103 L F
.61083 .44326 m .61245 .44438 L .61231 .44186 L F
.142 0 0 r
.28219 .52116 m .28089 .52157 L .27833 .52159 L F
0 0 0 r
.28547 .51981 m .28335 .52079 L .28219 .52116 L F
.212 .724 .676 r
.28335 .52079 m .28089 .52157 L .28219 .52116 L F
.649 .727 .906 r
.57202 .38979 m .56689 .38827 L .5692 .38731 L F
.105 .501 .904 r
.57219 .38851 m .57202 .38979 L .5692 .38731 L F
.57219 .38851 m .57343 .39 L .57202 .38979 L F
.654 .66 .844 r
.45244 .55596 m .45385 .55984 L .45623 .5566 L F
.954 .755 .595 r
.39832 .553 m .39971 .55676 L .40041 .55423 L F
.737 .835 .925 r
.34759 .65529 m .35176 .65425 L .34959 .65248 L F
.62 .804 .97 r
.34959 .65248 m .35176 .65425 L .35395 .65313 L F
.269 .136 .508 r
.37873 .55371 m .37702 .55495 L .37872 .55064 L F
.92 .604 .428 r
.37968 .50572 m .37748 .50522 L .37703 .50255 L F
.561 0 0 r
.3823 .50785 m .37748 .50522 L .37968 .50572 L F
.068 .565 .891 r
.36814 .53186 m .37088 .53242 L .3709 .53248 L F
.659 .466 .613 r
.43196 .53758 m .43531 .5364 L .43643 .53806 L F
.811 .669 .707 r
.5202 .43499 m .52192 .43879 L .51817 .43835 L F
.804 .702 .753 r
.51817 .43835 m .52192 .43879 L .51947 .44175 L F
.63 .528 .72 r
.24668 .60119 m .2433 .60257 L .24336 .60068 L F
.567 .258 .404 r
.24539 .60451 m .2433 .60257 L .24668 .60119 L F
.24539 .60451 m .24252 .60481 L .2433 .60257 L F
.702 .451 .541 r
.33919 .52469 m .34335 .52602 L .3411 .52449 L F
.703 .739 .879 r
.57084 .46703 m .57531 .46814 L .57247 .46419 L F
.713 .742 .875 r
.57247 .46419 m .57531 .46814 L .57709 .46661 L F
0 0 .41 r
.21224 .56692 m .21316 .56632 L .21384 .56262 L F
0 0 .298 r
.21216 .56961 m .21316 .56632 L .21224 .56692 L F
.611 .382 .546 r
.48028 .46424 m .48004 .46658 L .47744 .46721 L F
.597 .498 .712 r
.48254 .4607 m .48295 .46327 L .48028 .46424 L F
.676 .521 .668 r
.48295 .46327 m .48004 .46658 L .48028 .46424 L F
0 0 0 r
.3669 .54121 m .36487 .54483 L .36613 .5426 L F
.549 .122 .182 r
.3625 .54335 m .36613 .5426 L .36487 .54483 L F
0 0 .41 r
.41007 .54845 m .41045 .54894 L .40919 .54705 L F
0 0 .264 r
.41007 .54845 m .41068 .55064 L .41045 .54894 L F
.56 .855 .537 r
.24049 .52841 m .24165 .52704 L .24323 .52553 L F
0 0 0 r
.24049 .52841 m .24073 .52925 L .24165 .52704 L F
.24049 .52841 m .23907 .53074 L .24073 .52925 L F
.423 .064 .249 r
.301 .54728 m .30438 .54509 L .30179 .54447 L F
.574 .45 .674 r
.47398 .48258 m .47598 .48822 L .47151 .48772 L F
.579 .368 .559 r
.47151 .48772 m .47493 .4892 L .4723 .48952 L F
.47151 .48772 m .47598 .48822 L .47493 .4892 L F
0 0 .537 r
.62338 .40403 m .62369 .40775 L .62225 .4032 L F
.494 .103 .228 r
.33518 .6206 m .32995 .62402 L .3323 .6234 L F
.08 .452 .883 r
.33518 .6206 m .33618 .62043 L .33307 .6184 L F
.636 .363 .488 r
.3323 .6234 m .33618 .62043 L .33518 .6206 L F
.719 .804 .917 r
.62715 .3571 m .63106 .35845 L .63015 .35666 L F
.62715 .3571 m .63106 .35845 L .63015 .35666 L F
.385 .61 .939 r
.63015 .35666 m .63106 .35845 L .63177 .35587 L F
.63177 .35587 m .63106 .35845 L .63015 .35666 L F
0 0 0 r
.58512 .45461 m .58372 .45492 L .58111 .4554 L F
.275 .765 .69 r
.58372 .45492 m .58694 .4537 L .58665 .45382 L F
.518 .184 .341 r
.58372 .45492 m .58665 .45382 L .58665 .45384 L F
.32 .729 .978 r
.58512 .45461 m .58669 .45383 L .58372 .45492 L F
.58512 .45461 m .58787 .45479 L .58701 .45379 L F
.5867 .45382 m .58701 .45379 L .58694 .4537 L F
.58512 .45461 m .58701 .45379 L .5867 .45382 L F
.394 .278 .601 r
.58512 .45461 m .58779 .4565 L .58787 .45479 L F
.58512 .45461 m .5856 .45726 L .58779 .4565 L F
.857 .968 .869 r
.58773 .45304 m .58787 .45479 L .58984 .45236 L F
.58764 .45307 m .58764 .45311 L .58773 .45304 L F
.58764 .45311 m .58787 .45479 L .58773 .45304 L F
.896 .977 .812 r
.58694 .4537 m .58701 .45379 L .58764 .45307 L F
.58701 .45379 m .58787 .45479 L .58764 .45311 L F
.58701 .45379 m .58764 .45311 L .58764 .45307 L F
.676 .613 .777 r
.58787 .45479 m .59118 .45428 L .58984 .45236 L F
.787 .574 .612 r
.58779 .4565 m .59118 .45428 L .58787 .45479 L F
.493 .802 .999 r
.58779 .4565 m .5856 .45726 L .58356 .45622 L F
.58473 .4559 m .58356 .45622 L .58179 .45532 L F
.58779 .4565 m .58356 .45622 L .58473 .4559 L F
.325 .012 .271 r
.58833 .45492 m .58652 .45431 L .589 .4545 L F
.493 .802 .999 r
.58779 .4565 m .58179 .45532 L .58594 .45638 L F
.325 .012 .271 r
.58594 .45638 m .58618 .4555 L .58833 .45492 L F
.58618 .4555 m .58652 .45431 L .58833 .45492 L F
.58652 .45431 m .58659 .45406 L .58672 .45409 L F
.58652 .45431 m .58672 .45409 L .589 .4545 L F
.58659 .45406 m .58665 .45383 L .5868 .45387 L F
.58659 .45406 m .5868 .45387 L .589 .4545 L F
.58665 .45383 m .58665 .45382 L .58667 .45383 L F
.58665 .45383 m .58667 .45383 L .589 .4545 L F
.518 .184 .341 r
.58372 .45492 m .58665 .45384 L .58594 .45638 L F
.32 .729 .978 r
.58669 .45383 m .58694 .4537 L .58372 .45492 L F
.823 .653 .673 r
.52122 .42538 m .52315 .42914 L .52064 .42757 L F
.887 .864 .812 r
.52315 .42914 m .5193 .43106 L .52064 .42757 L F
.52315 .42914 m .52076 .43233 L .5193 .43106 L F
.746 .303 .199 r
.36307 .55409 m .36503 .55671 L .36278 .55607 L F
.36307 .55409 m .36278 .55607 L .36238 .55469 L F
0 0 .334 r
.3633 .55536 m .36129 .55565 L .36503 .55671 L F
.308 0 .153 r
.36251 .55845 m .3657 .55874 L .36503 .55671 L F
.3657 .55874 m .36619 .55849 L .36503 .55671 L F
.479 0 .019 r
.36626 .55859 m .36679 .55848 L .36503 .55671 L F
.36679 .55848 m .36714 .55752 L .36503 .55671 L F
.692 .624 .775 r
.36668 .55843 m .36358 .55818 L .3662 .55713 L F
.308 0 .153 r
.3657 .55874 m .36587 .55875 L .36619 .55849 L F
.36587 .55875 m .36626 .55859 L .36619 .55849 L F
.692 .624 .775 r
.36497 .55911 m .36358 .55818 L .36626 .55839 L F
.36587 .55875 m .36626 .55839 L .36668 .55843 L F
.51 .465 .743 r
.36441 .56008 m .36526 .55931 L .36251 .55845 L F
.36526 .55931 m .36587 .55875 L .3657 .55874 L F
.36526 .55931 m .3657 .55874 L .36251 .55845 L F
.692 .624 .775 r
.36761 .56089 m .36482 .56107 L .36486 .56036 L F
.36761 .56089 m .36449 .56029 L .36487 .5598 L F
.36761 .56089 m .36497 .55911 L .36626 .55859 L F
.36526 .55931 m .36416 .55952 L .36497 .55911 L F
.36761 .56089 m .36487 .5598 L .36526 .55931 L F
.51 .465 .743 r
.36441 .56008 m .3649 .55976 L .36526 .55931 L F
.692 .624 .775 r
.36487 .5598 m .36416 .55952 L .36526 .55931 L F
.51 .465 .743 r
.36526 .55931 m .36639 .5588 L .36587 .55875 L F
.3649 .55976 m .36639 .5588 L .36526 .55931 L F
.3649 .55976 m .36482 .56107 L .36639 .5588 L F
.36214 .56153 m .36482 .56107 L .3649 .55976 L F
.692 .624 .775 r
.36486 .56036 m .36482 .56107 L .36449 .56029 L F
.36487 .5598 m .36449 .56029 L .36416 .55952 L F
.36497 .55911 m .36626 .55839 L .36587 .55875 L F
.51 .465 .743 r
.36214 .56153 m .36441 .56008 L .36251 .55845 L F
.958 .656 .231 r
.36649 .55916 m .36653 .55921 L .3662 .55713 L F
.692 .624 .775 r
.36761 .56089 m .36626 .55859 L .36675 .5586 L F
.958 .656 .231 r
.36671 .5587 m .36761 .56089 L .36675 .5586 L F
.681 .7 .862 r
.36671 .5587 m .36761 .56089 L .36863 .55808 L F
.36639 .5588 m .36761 .56089 L .36671 .5587 L F
.958 .656 .231 r
.36653 .55921 m .36761 .56089 L .36671 .5587 L F
.479 0 .019 r
.36639 .5588 m .367 .5586 L .36626 .55859 L F
.367 .5586 m .36863 .55808 L .36626 .55859 L F
.692 .624 .775 r
.36675 .5586 m .36626 .55859 L .36668 .55843 L F
.958 .656 .231 r
.36653 .55921 m .36675 .5586 L .3662 .55713 L F
.479 0 .019 r
.36679 .55848 m .36863 .55808 L .36714 .55752 L F
.308 0 .153 r
.36587 .55875 m .36639 .5588 L .36626 .55859 L F
.692 .624 .775 r
.36497 .55911 m .36416 .55952 L .36358 .55818 L F
0 0 .334 r
.3633 .55536 m .36358 .55818 L .36339 .55822 L F
.36296 .5567 m .36339 .55822 L .36251 .55845 L F
.3633 .55536 m .36339 .55822 L .36296 .5567 L F
.746 .303 .199 r
.36238 .55469 m .36278 .55607 L .36129 .55565 L F
.175 0 0 r
.27744 .56557 m .2798 .56515 L .28163 .56358 L F
.13 0 0 r
.2798 .56515 m .28411 .56313 L .28163 .56358 L F
.943 .95 .632 r
.69508 .28711 m .69343 .29123 L .69323 .28969 L F
.911 .824 .359 r
.69323 .28969 m .69343 .29123 L .69261 .2923 L F
.194 .412 .846 r
.34887 .70415 m .34869 .70528 L .34985 .70368 L F
.054 .207 .705 r
.34985 .70368 m .34869 .70528 L .35101 .70743 L F
.782 .962 .924 r
.63403 .36119 m .63674 .35777 L .63392 .36036 L F
.63403 .36119 m .6378 .35859 L .63674 .35777 L F
.831 .371 0 r
.59637 .41372 m .59672 .41266 L .59478 .41213 L F
.59637 .41372 m .5982 .41537 L .59672 .41266 L F
.615 .804 .972 r
.60966 .35382 m .60621 .35321 L .60855 .35258 L F
.626 .88 .988 r
.6107 .35169 m .60966 .35382 L .60855 .35258 L F
.6107 .35169 m .61288 .35261 L .60966 .35382 L F
.49 .84 .572 r
.34174 .60953 m .34045 .61055 L .33899 .61188 L F
.147 0 0 r
.3397 .61322 m .33899 .61188 L .34045 .61055 L F
.3397 .61322 m .33764 .61374 L .33899 .61188 L F
.882 .734 .694 r
.38832 .48933 m .38977 .4928 L .38709 .49219 L F
.882 .991 .798 r
.38977 .4928 m .38723 .49403 L .38709 .49219 L F
.408 .284 .598 r
.38891 .48858 m .38628 .49094 L .3875 .48853 L F
.39023 .48863 m .38923 .48922 L .38891 .48858 L F
.515 .855 .995 r
.38998 .49072 m .38977 .4928 L .38832 .48933 L F
.974 .925 .645 r
.38832 .48933 m .38709 .49219 L .38628 .49094 L F
.408 .284 .598 r
.39023 .48863 m .39068 .4913 L .38832 .48933 L F
.39023 .48863 m .38832 .48933 L .38628 .49094 L F
.38923 .48922 m .38628 .49094 L .38891 .48858 L F
.515 .855 .995 r
.39068 .4913 m .39046 .49167 L .38998 .49072 L F
.39046 .49167 m .38977 .4928 L .38998 .49072 L F
.39068 .4913 m .39232 .49205 L .38977 .4928 L F
.792 .968 .915 r
.74318 .33031 m .74156 .3319 L .74239 .33279 L F
.74239 .33279 m .74156 .3319 L .74318 .33031 L F
.986 .851 .622 r
.61931 .37215 m .62126 .37229 L .6197 .37062 L F
.812 .904 .905 r
.6197 .37062 m .62126 .37229 L .62277 .37034 L F
.834 .987 .868 r
.62277 .37034 m .62126 .37229 L .61931 .37215 L F
.915 .962 .798 r
.39333 .61031 m .394 .61125 L .39588 .60913 L F
.953 .867 .716 r
.39429 .60791 m .39333 .61031 L .39588 .60913 L F
.553 .645 .895 r
.30382 .53288 m .30596 .5301 L .30432 .53202 L F
.295 .771 .929 r
.33136 .56314 m .32994 .5627 L .32753 .56301 L F
.361 .811 .945 r
.33292 .56242 m .32994 .5627 L .33136 .56314 L F
.463 .334 .62 r
.33136 .56314 m .33236 .56605 L .33422 .56338 L F
.702 .847 .952 r
.43682 .58889 m .43486 .59023 L .43241 .58933 L F
.659 .248 .253 r
.26146 .61678 m .26516 .617 L .26284 .61492 L F
.79 .439 0 r
.41425 .59271 m .4151 .59524 L .41348 .59138 L F
.757 .633 .723 r
.61655 .39328 m .61532 .38882 L .61483 .39287 L F
.77 .429 .409 r
.61412 .39608 m .61655 .39328 L .61483 .39287 L F
.61412 .39608 m .61919 .39771 L .61655 .39328 L F
.44 .499 .823 r
.56932 .3977 m .57245 .39919 L .57109 .39544 L F
.846 .701 .702 r
.39212 .58547 m .39465 .58667 L .39346 .58908 L F
.605 .449 .643 r
.35988 .60536 m .36312 .60153 L .36014 .60225 L F
.988 .895 .588 r
.33084 .6296 m .33246 .62794 L .33126 .63084 L F
.05 0 0 r
.32868 .62973 m .33246 .62794 L .33084 .6296 L F
.571 .408 .622 r
.33504 .62462 m .33523 .62719 L .33246 .62794 L F
.65 .888 .541 r
.56876 .40961 m .56611 .41296 L .56871 .41226 L F
.573 .576 .818 r
.56871 .41226 m .56611 .41296 L .56472 .4091 L F
.699 .543 .672 r
.26367 .57046 m .26353 .5731 L .26621 .57057 L F
.4 0 .098 r
.44023 .58129 m .43874 .57983 L .43876 .58328 L F
.44023 .58129 m .44181 .57912 L .43874 .57983 L F
.974 .672 .37 r
.57459 .45922 m .5766 .46121 L .57592 .45786 L F
.646 .941 .961 r
.57592 .45786 m .57852 .45657 L .57717 .45596 L F
.777 .693 .77 r
.57717 .45596 m .57459 .45922 L .57592 .45786 L F
.431 .33 .639 r
.57592 .45786 m .5766 .46121 L .5786 .45991 L F
.696 .704 .854 r
.4522 .4627 m .45385 .46453 L .44972 .46369 L F
.742 .713 .825 r
.45622 .46335 m .45385 .46453 L .4522 .4627 L F
.882 .52 .037 r
.39371 .54271 m .39557 .54669 L .39529 .54411 L F
.448 .238 .501 r
.67464 .37447 m .67722 .3712 L .67716 .374 L F
.67464 .37447 m .67722 .3712 L .67716 .374 L F
.316 .08 .389 r
.35144 .66931 m .34877 .6727 L .35094 .67282 L F
.164 0 0 r
.35094 .67282 m .34877 .6727 L .34772 .67325 L F
.9 .985 .778 r
.39056 .59971 m .38815 .603 L .38832 .60094 L F
.968 .837 .659 r
.3892 .59834 m .39056 .59971 L .38832 .60094 L F
.417 .283 .59 r
.62954 .40051 m .62772 .40366 L .62965 .40181 L F
0 0 0 r
.32233 .55092 m .3228 .55179 L .32364 .5495 L F
.32233 .55092 m .32063 .5527 L .3228 .55179 L F
.738 .759 .87 r
.44972 .46369 m .44768 .46523 L .44572 .46314 L F
.954 .606 .257 r
.60453 .42688 m .60245 .42235 L .60264 .42478 L F
.902 .503 .091 r
.60264 .42478 m .60534 .42935 L .60453 .42688 L F
.953 .884 .726 r
.43383 .58325 m .43282 .58602 L .43173 .58413 L F
.43173 .58413 m .43383 .58325 L .43409 .58151 L F
.43173 .58413 m .43282 .58602 L .43383 .58325 L F
.192 0 .095 r
.32661 .57802 m .32881 .57548 L .32775 .57633 L F
.644 .813 .964 r
.25274 .55712 m .25039 .55817 L .24857 .55664 L F
.775 .839 .38 r
.3129 .64972 m .31383 .64764 L .31438 .646 L F
.145 .346 .805 r
.58998 .40189 m .59163 .40506 L .59052 .40408 L F
.641 .23 0 r
.60313 .4019 m .60404 .40334 L .60499 .40502 L F
0 .112 .649 r
.60404 .40334 m .60733 .40716 L .60499 .40502 L F
.47 .455 .759 r
.34763 .5183 m .3479 .5209 L .34492 .52057 L F
.952 .923 .74 r
.6728 .36765 m .67103 .37155 L .66989 .37042 L F
.787 .633 .689 r
.62225 .4032 m .61986 .40014 L .62251 .4019 L F
0 0 .537 r
.62338 .40403 m .62225 .4032 L .62251 .4019 L F
.778 .666 .739 r
.41086 .49924 m .40825 .50231 L .40858 .50053 L F
.256 .71 .955 r
.24834 .53683 m .25062 .53679 L .2526 .53769 L F
.2526 .53769 m .25062 .53679 L .24834 .53683 L F
.393 .787 .987 r
.25062 .53679 m .25479 .5373 L .2526 .53769 L F
.25062 .53679 m .25479 .5373 L .2526 .53769 L F
.791 .683 .745 r
.32728 .63725 m .32866 .64063 L .32511 .64016 L F
.827 .614 .615 r
.32866 .64063 m .32521 .64234 L .32511 .64016 L F
.32866 .64063 m .32821 .64371 L .32521 .64234 L F
.78 .466 .456 r
.32728 .63725 m .33082 .6399 L .32866 .64063 L F
.07 0 .385 r
.3307 .64202 m .32866 .64063 L .33082 .6399 L F
.3307 .64202 m .32821 .64371 L .32866 .64063 L F
.423 .064 .249 r
.301 .54728 m .30354 .54682 L .30438 .54509 L F
0 0 0 r
.3067 .54141 m .30438 .54509 L .30577 .54359 L F
.104 0 .083 r
.30438 .54509 m .30554 .54568 L .30577 .54359 L F
.30438 .54509 m .30354 .54682 L .30554 .54568 L F
.848 .388 .073 r
.60733 .40716 m .60642 .40798 L .60499 .40502 L F
.60733 .40716 m .60829 .40891 L .60642 .40798 L F
.851 .942 .88 r
.66597 .31979 m .66794 .3159 L .66792 .31611 L F
.66597 .31979 m .66486 .31869 L .66794 .3159 L F
.952 .923 .74 r
.6728 .36765 m .66989 .37042 L .6714 .36858 L F
.164 0 .166 r
.67578 .3647 m .6728 .36765 L .67486 .36619 L F
.417 .816 .597 r
.67486 .36619 m .6728 .36765 L .6714 .36858 L F
.44 0 0 r
.2669 .63434 m .26721 .63589 L .26509 .6335 L F
.2669 .63434 m .26894 .63487 L .26721 .63589 L F
0 0 0 r
.69819 .2844 m .6952 .2867 L .6968 .28486 L F
.556 .918 .739 r
.70014 .28258 m .69819 .2844 L .6968 .28486 L F
.637 .486 .661 r
.47246 .47641 m .47338 .48024 L .46967 .47942 L F
.284 0 .246 r
.26353 .5731 m .26622 .57259 L .26621 .57057 L F
.573 .183 .266 r
.26622 .57259 m .26813 .5724 L .26621 .57057 L F
.522 .193 .351 r
.26621 .57057 m .26813 .5724 L .26889 .5702 L F
.499 .896 .757 r
.24393 .59963 m .24336 .60068 L .24121 .59805 L F
.24393 .59963 m .24539 .5994 L .24336 .60068 L F
.63 .528 .72 r
.24668 .60119 m .24336 .60068 L .24539 .5994 L F
.241 .319 .744 r
.24004 .56975 m .24295 .57453 L .24367 .57296 L F
.583 .008 0 r
.60047 .39993 m .60112 .40119 L .59883 .3988 L F
.60047 .39993 m .60313 .4019 L .60112 .40119 L F
.811 .839 .872 r
.65562 .39627 m .65906 .39635 L .65841 .3934 L F
.752 .805 .895 r
.65841 .3934 m .65906 .39635 L .66194 .39369 L F
0 .241 .737 r
.61799 .43519 m .61882 .43502 L .61771 .43376 L F
.03 .594 .794 r
.61825 .4345 m .61771 .43376 L .61882 .43502 L F
0 0 .397 r
.61729 .43319 m .61799 .43519 L .61771 .43376 L F
.03 .594 .794 r
.6171 .43345 m .61771 .43376 L .61825 .4345 L F
0 0 .397 r
.61664 .43132 m .61729 .43319 L .61771 .43376 L F
0 .241 .737 r
.61799 .43519 m .61993 .43659 L .61882 .43502 L F
.331 .077 .369 r
.70789 .29966 m .7081 .29751 L .71048 .29649 L F
.70789 .29966 m .7081 .29751 L .71048 .29649 L F
.253 .13 .512 r
.28792 .5718 m .28592 .56984 L .28863 .56984 L F
.28792 .5718 m .28551 .5736 L .28592 .56984 L F
.71 .788 .913 r
.46112 .45945 m .46296 .46102 L .45894 .46054 L F
.784 .841 .895 r
.46463 .4561 m .46296 .46102 L .46112 .45945 L F
.46463 .4561 m .4673 .45713 L .46296 .46102 L F
.662 .558 .726 r
.34622 .58326 m .34768 .58863 L .34878 .58252 L F
.045 0 0 r
.33653 .5519 m .3355 .55148 L .33813 .55069 L F
.33653 .5519 m .33393 .55258 L .3355 .55148 L F
.265 .041 .376 r
.47186 .57924 m .4714 .58193 L .46889 .58232 L F
.176 0 .051 r
.46889 .58232 m .4714 .58193 L .46808 .58444 L F
.662 .69 .866 r
.40271 .49423 m .40036 .49574 L .39883 .49235 L F
.865 .982 .847 r
.72725 .33778 m .72973 .33622 L .72952 .33814 L F
0 0 0 r
.72973 .33622 m .73225 .3323 L .7323 .33553 L F
.465 .163 .368 r
.7323 .33553 m .72952 .33814 L .72973 .33622 L F
.489 .446 .736 r
.38954 .60601 m .3896 .60811 L .38815 .603 L F
.543 .132 .212 r
.38954 .60601 m .38778 .60617 L .3896 .60811 L F
.65 .112 0 r
.4161 .59901 m .41507 .59999 L .41439 .59805 L F
.4161 .59901 m .41883 .60107 L .41507 .59999 L F
.176 .523 .919 r
.61532 .38882 m .61496 .38876 L .61307 .38688 L F
0 0 .158 r
.39346 .58908 m .39251 .59277 L .39276 .5922 L F
.551 .504 .756 r
.39251 .59277 m .39516 .59552 L .39315 .59428 L F
.39251 .59277 m .39315 .59428 L .39276 .5922 L F
.87 .681 .643 r
.32282 .65982 m .32096 .66293 L .32055 .65951 L F
.859 .663 .637 r
.32282 .65982 m .32096 .66293 L .32055 .65951 L F
.39 0 0 r
.32055 .65951 m .32282 .65982 L .31833 .65939 L F
.248 .28 .699 r
.32282 .65982 m .32508 .66065 L .32468 .6594 L F
.804 .869 .895 r
.32548 .52562 m .32953 .52444 L .32826 .52106 L F
.465 .502 .812 r
.32953 .52444 m .33065 .52064 L .32826 .52106 L F
.59 .35 .52 r
.32153 .62165 m .32078 .62446 L .31795 .62442 L F
.762 .524 .572 r
.32374 .62444 m .32153 .62165 L .32237 .62069 L F
.32374 .62444 m .32078 .62446 L .32153 .62165 L F
0 .36 .727 r
.37524 .58074 m .37605 .58083 L .37431 .58191 L F
.219 .004 .36 r
.29757 .64356 m .29691 .64271 L .29817 .6406 L F
0 0 .207 r
.29817 .6406 m .30032 .63684 L .30045 .63978 L F
.215 .001 .358 r
.29757 .64356 m .29817 .6406 L .30045 .63978 L F
.539 .844 .529 r
.24323 .52553 m .24284 .52578 L .24536 .52432 L F
.24323 .52553 m .24165 .52704 L .24284 .52578 L F
.369 .141 .431 r
.68014 .37027 m .67722 .3712 L .67981 .36793 L F
.459 .365 .661 r
.68014 .37027 m .67989 .37249 L .67722 .3712 L F
.53 .303 .515 r
.67716 .374 m .67989 .37249 L .67722 .3712 L F
.369 .141 .431 r
.67981 .36793 m .67722 .3712 L .68014 .37027 L F
.459 .365 .661 r
.68014 .37027 m .67989 .37249 L .67722 .3712 L F
.53 .303 .515 r
.67722 .3712 m .67989 .37249 L .67716 .374 L F
0 0 .512 r
.29757 .64356 m .29831 .64577 L .29691 .64271 L F
.852 .911 .874 r
.64825 .34796 m .6523 .34611 L .64986 .34626 L F
.856 .947 .875 r
.64986 .34626 m .6523 .34611 L .65282 .34325 L F
.915 .895 .794 r
.36098 .5634 m .35767 .56593 L .35969 .56521 L F
.727 .638 .758 r
.35969 .56521 m .36214 .56153 L .36098 .5634 L F
.018 0 0 r
.67821 .3636 m .67578 .3647 L .67486 .36619 L F
.968 .806 .627 r
.52076 .43233 m .5202 .43499 L .5193 .43106 L F
.945 .616 .19 r
.61217 .41888 m .6137 .42292 L .61271 .4214 L F
.924 .534 .204 r
.6137 .42292 m .61291 .4241 L .61271 .4214 L F
.6137 .42292 m .61447 .4251 L .61291 .4241 L F
.72 .649 .778 r
.32648 .64652 m .32955 .64705 L .32821 .64371 L F
.982 .692 .369 r
.32955 .64705 m .32821 .64371 L .32648 .64652 L F
.956 .683 .48 r
.32955 .64705 m .32822 .64942 L .32648 .64652 L F
.32955 .64705 m .3301 .65 L .32822 .64942 L F
.022 .214 .721 r
.33031 .64577 m .32955 .64705 L .32821 .64371 L F
0 0 .249 r
.33014 .64837 m .32955 .64705 L .33031 .64577 L F
0 0 .1 r
.3308 .6467 m .33014 .64837 L .33031 .64577 L F
.667 .766 .285 r
.33036 .64775 m .33014 .64837 L .3308 .6467 L F
0 0 .249 r
.33014 .64837 m .32991 .64901 L .32955 .64705 L F
.33014 .64837 m .3301 .65 L .32991 .64901 L F
.599 .895 .988 r
.32822 .64942 m .3301 .65 L .33014 .64837 L F
0 0 0 r
.32655 .6508 m .33014 .64837 L .32938 .65013 L F
.667 .766 .285 r
.32938 .65013 m .33014 .64837 L .33036 .64775 L F
.529 0 0 r
.35048 .49772 m .35264 .4987 L .35454 .49889 L F
.518 0 0 r
.35264 .4987 m .35683 .49978 L .35454 .49889 L F
.711 .779 .905 r
.61683 .35296 m .61288 .35261 L .61534 .3513 L F
.737 .815 .913 r
.61913 .35147 m .61683 .35296 L .61534 .3513 L F
0 0 .21 r
.70186 .31586 m .70352 .31192 L .7019 .31339 L F
.653 .171 .095 r
.35281 .56216 m .35406 .56039 L .34992 .55986 L F
.726 .862 .44 r
.35473 .55853 m .35406 .56039 L .35281 .56216 L F
.563 .365 .571 r
.35754 .55991 m .35393 .56287 L .35406 .56039 L F
.742 .713 .825 r
.45622 .46335 m .4522 .4627 L .45498 .46026 L F
.766 .797 .879 r
.45727 .45886 m .45622 .46335 L .45498 .46026 L F
.45727 .45886 m .45894 .46054 L .45622 .46335 L F
.815 .853 .877 r
.68727 .32811 m .68837 .3291 L .69018 .32791 L F
.68987 .32762 m .69018 .32791 L .69091 .32743 L F
.68727 .32811 m .69018 .32791 L .68987 .32762 L F
.592 .079 0 r
.68607 .32404 m .68795 .32592 L .68751 .32525 L F
.811 .94 .912 r
.69091 .32743 m .68837 .3291 L .68896 .32783 L F
.565 .64 .884 r
.68837 .3291 m .68945 .32777 L .68896 .32783 L F
.878 .975 .668 r
.69345 .32745 m .69137 .32981 L .69091 .32743 L F
.449 .326 .621 r
.69137 .32981 m .69345 .32745 L .69171 .32745 L F
.815 .853 .877 r
.68896 .32783 m .69091 .32743 L .69021 .32768 L F
.811 .94 .912 r
.69091 .32743 m .68896 .32783 L .68914 .32745 L F
.741 .221 0 r
.68751 .32525 m .689 .32688 L .69091 .32743 L F
.449 .326 .621 r
.69031 .32765 m .68996 .32745 L .68914 .32745 L F
.815 .853 .877 r
.68727 .32811 m .69091 .32743 L .68801 .32802 L F
.741 .221 0 r
.689 .32688 m .68985 .32781 L .69031 .32765 L F
.689 .32688 m .69031 .32765 L .69091 .32743 L F
.449 .326 .621 r
.68945 .32777 m .69031 .32765 L .68914 .32745 L F
.69031 .32765 m .69171 .32745 L .68996 .32745 L F
.669 .483 .624 r
.69091 .32743 m .69137 .32981 L .68837 .3291 L F
.449 .326 .621 r
.69137 .32981 m .69171 .32745 L .68945 .32777 L F
.815 .853 .877 r
.68801 .32802 m .68875 .32787 L .68985 .32781 L F
.68875 .32787 m .68896 .32783 L .68906 .32783 L F
.68875 .32787 m .68906 .32783 L .68985 .32781 L F
.68896 .32783 m .69021 .32768 L .68985 .32781 L F
.565 .64 .884 r
.68837 .3291 m .69137 .32981 L .68945 .32777 L F
.68896 .32783 m .68945 .32777 L .68914 .32745 L F
.016 0 0 r
.68962 .32744 m .69345 .32745 L .69091 .32743 L F
.68914 .32745 m .68958 .32745 L .68962 .32744 L F
.68958 .32745 m .69345 .32745 L .68962 .32744 L F
.592 .079 0 r
.68795 .32592 m .6895 .32746 L .68886 .32673 L F
.6895 .32746 m .68985 .32781 L .68953 .32745 L F
.6895 .32746 m .68953 .32745 L .68886 .32673 L F
.68795 .32592 m .68886 .32673 L .68751 .32525 L F
.64 .593 .785 r
.3932 .64697 m .39507 .65022 L .39378 .6476 L F
.53 .297 .506 r
.30085 .62144 m .30315 .62359 L .30345 .62096 L F
.309 .289 .673 r
.30085 .62144 m .30173 .62461 L .30315 .62359 L F
0 0 .062 r
.23759 .60235 m .23598 .60462 L .23669 .60223 L F
.591 .393 .582 r
.32884 .5508 m .32879 .55363 L .32619 .55385 L F
.525 .516 .788 r
.32974 .54623 m .32884 .5508 L .32729 .54704 L F
.32974 .54623 m .33139 .55063 L .32884 .5508 L F
.483 .803 1 r
.36387 .71117 m .36488 .70963 L .36377 .71031 L F
.36387 .71117 m .36632 .7107 L .36488 .70963 L F
.58 .446 .663 r
.46467 .50284 m .46103 .49899 L .46437 .4987 L F
.615 .499 .697 r
.46467 .50284 m .46477 .50484 L .46215 .50557 L F
.46467 .50284 m .46215 .50557 L .46289 .50479 L F
.58 .446 .663 r
.46467 .50284 m .46289 .50479 L .46103 .49899 L F
.943 .95 .632 r
.69508 .28711 m .69323 .28969 L .6952 .2867 L F
.75 .505 .561 r
.53222 .46099 m .53006 .46342 L .53007 .46084 L F
.53222 .46099 m .53223 .46373 L .53006 .46342 L F
.768 .596 .665 r
.48799 .45438 m .48942 .45796 L .48516 .45725 L F
.731 .641 .759 r
.49026 .45352 m .48942 .45796 L .48799 .45438 L F
.544 .825 .48 r
.36957 .53817 m .3669 .54121 L .36817 .53973 L F
.149 0 .383 r
.36613 .5426 m .36817 .53973 L .3669 .54121 L F
0 0 .212 r
.38815 .603 m .38882 .60248 L .38832 .60094 L F
.38815 .603 m .38778 .60617 L .38882 .60248 L F
.753 .631 .725 r
.33243 .53829 m .33012 .54101 L .3284 .53623 L F
0 0 0 r
.33012 .54101 m .3312 .54033 L .33243 .53829 L F
.392 .066 .288 r
.33477 .53787 m .3312 .54033 L .33243 .53829 L F
.3312 .54033 m .33477 .53787 L .33243 .53829 L F
.606 .341 .49 r
.33336 .60194 m .33273 .60525 L .33039 .60437 L F
.468 .217 .449 r
.33516 .60428 m .3347 .60179 L .33594 .60165 L F
.906 .835 .374 r
.33491 .60117 m .33516 .60428 L .33594 .60165 L F
.412 .508 .847 r
.33491 .60117 m .33545 .60588 L .33516 .60428 L F
.33545 .60588 m .33558 .60708 L .33516 .60428 L F
.468 .217 .449 r
.33516 .60428 m .33336 .60194 L .3347 .60179 L F
.33516 .60428 m .33273 .60525 L .33336 .60194 L F
.294 .734 .965 r
.3373 .69835 m .3411 .6989 L .33964 .69864 L F
0 0 .239 r
.34253 .69439 m .3411 .6989 L .33947 .69501 L F
0 .029 .599 r
.3411 .6989 m .34244 .70123 L .34243 .69971 L F
.3411 .6989 m .34243 .69971 L .33964 .69864 L F
.936 .734 .257 r
.39791 .68581 m .39845 .68827 L .39758 .68917 L F
.874 .834 .365 r
.39758 .68917 m .39845 .68827 L .39739 .69063 L F
.003 0 .349 r
.40078 .68429 m .39845 .68827 L .39791 .68581 L F
.40078 .68429 m .40039 .68773 L .39845 .68827 L F
0 0 0 r
.39845 .68827 m .40039 .68773 L .39739 .69063 L F
.463 .605 .906 r
.45255 .55086 m .45484 .54902 L .45033 .54718 L F
.45255 .55086 m .45443 .55006 L .45484 .54902 L F
.237 .034 .389 r
.45255 .55086 m .45243 .55358 L .45443 .55006 L F
.482 0 0 r
.33803 .4952 m .34213 .49559 L .33949 .49457 L F
.144 .234 .699 r
.35396 .67198 m .35144 .66931 L .35441 .67008 L F
.598 .195 .25 r
.35401 .67138 m .35144 .66931 L .35094 .67282 L F
.35401 .67138 m .35441 .67008 L .35144 .66931 L F
.549 .42 .658 r
.46166 .51882 m .4622 .52154 L .45963 .52227 L F
.568 .481 .716 r
.4622 .52154 m .46284 .52413 L .45963 .52227 L F
.643 .521 .7 r
.25266 .554 m .25539 .55384 L .25583 .55153 L F
0 0 0 r
.25266 .554 m .2541 .55314 L .25583 .55153 L F
.481 .322 .588 r
.25505 .55636 m .25266 .554 L .25539 .55384 L F
.25505 .55636 m .25274 .55712 L .25266 .554 L F
.456 .171 .391 r
.25071 .55573 m .2541 .55314 L .25266 .554 L F
.374 .772 .986 r
.43516 .46286 m .43921 .46347 L .43692 .46383 L F
.518 .237 .427 r
.51365 .46329 m .51031 .46675 L .51029 .4641 L F
.51365 .46329 m .51296 .46607 L .51031 .46675 L F
.549 .277 .456 r
.51688 .46306 m .51296 .46607 L .51365 .46329 L F
.872 .973 .85 r
.65121 .33184 m .6497 .33331 L .65033 .33069 L F
.821 .968 .898 r
.65429 .329 m .65121 .33184 L .65033 .33069 L F
.626 .499 .688 r
.47744 .46721 m .47737 .46983 L .47493 .47047 L F
.583 .461 .679 r
.47737 .46983 m .47554 .47354 L .47493 .47047 L F
0 0 .226 r
.33601 .58281 m .33644 .58392 L .33532 .5816 L F
.33601 .58281 m .33678 .58571 L .33644 .58392 L F
.912 .794 .718 r
.69033 .37595 m .69346 .37368 L .69332 .3729 L F
.69033 .37595 m .692 .37744 L .69346 .37368 L F
.973 .791 .367 r
.7432 .32374 m .74412 .32313 L .74384 .3256 L F
.7432 .32374 m .74412 .32313 L .74384 .3256 L F
.367 .401 .765 r
.46786 .54999 m .46597 .55039 L .46492 .54798 L F
.612 .422 .6 r
.43808 .51841 m .43533 .52099 L .43522 .51807 L F
.558 .569 .821 r
.40037 .68169 m .39763 .68229 L .39618 .67862 L F
.507 .884 .686 r
.3944 .68584 m .39646 .68464 L .39422 .68596 L F
.625 .16 .131 r
.39763 .68229 m .39901 .68316 L .39646 .68464 L F
.419 .5 .836 r
.39334 .68425 m .39646 .68464 L .39457 .68121 L F
.279 .42 .825 r
.39457 .68121 m .39646 .68464 L .39758 .68369 L F
.507 .884 .686 r
.39758 .68369 m .39646 .68464 L .3944 .68584 L F
.625 .16 .131 r
.39901 .68316 m .40078 .68429 L .39646 .68464 L F
.497 .314 .563 r
.40037 .68169 m .40078 .68429 L .39763 .68229 L F
.842 .998 .819 r
.39339 .653 m .39042 .65567 L .39299 .65555 L F
.3935 .6523 m .39282 .65305 L .39339 .653 L F
.423 .767 .996 r
.38801 .65355 m .39286 .65327 L .39222 .65309 L F
.38811 .65341 m .39222 .65309 L .38897 .65217 L F
.38801 .65355 m .39222 .65309 L .38811 .65341 L F
.807 .713 .761 r
.39042 .65567 m .39286 .65327 L .38897 .65217 L F
.842 .998 .819 r
.3935 .6523 m .39286 .65327 L .39042 .65567 L F
.39282 .65305 m .39042 .65567 L .39339 .653 L F
.047 .252 .749 r
.38801 .65355 m .39042 .65567 L .38897 .65217 L F
.513 .299 .526 r
.38948 .65733 m .39042 .65567 L .38801 .65355 L F
0 .113 .649 r
.71102 .31229 m .71303 .3149 L .71224 .3165 L F
.315 .609 .952 r
.71303 .3149 m .71394 .31647 L .71224 .3165 L F
.69 .863 .964 r
.38546 .68252 m .38789 .68236 L .38508 .68083 L F
.663 .399 .511 r
.38461 .68514 m .38789 .68236 L .38546 .68252 L F
.38461 .68514 m .38765 .68525 L .38789 .68236 L F
.799 .87 .9 r
.38508 .68083 m .38789 .68236 L .38983 .67889 L F
.422 .383 .71 r
.38789 .68236 m .38992 .68182 L .38983 .67889 L F
.126 0 .373 r
.38789 .68236 m .38911 .68424 L .38992 .68182 L F
.38789 .68236 m .38765 .68525 L .38911 .68424 L F
.527 .384 .629 r
.71412 .28103 m .71147 .28521 L .71097 .28222 L F
.71412 .28103 m .71475 .28398 L .71147 .28521 L F
.71412 .28103 m .71147 .28521 L .71097 .28222 L F
.71412 .28103 m .71475 .28398 L .71147 .28521 L F
.536 .451 .706 r
.46284 .52413 m .46346 .52797 L .46095 .52859 L F
.517 .437 .704 r
.46346 .52797 m .46155 .53127 L .46095 .52859 L F
.33 .186 .53 r
.32422 .58118 m .32661 .57802 L .32455 .57946 L F
.974 .697 .44 r
.39954 .52457 m .40129 .52824 L .39948 .52696 L F
.814 .806 .316 r
.41354 .56985 m .41441 .56556 L .41449 .56713 L F
.41354 .56985 m .4136 .56828 L .41441 .56556 L F
.931 .616 .157 r
.41354 .56985 m .41283 .57134 L .4136 .56828 L F
.41354 .56985 m .41402 .57271 L .41283 .57134 L F
.847 .961 .88 r
.69494 .34809 m .69331 .34984 L .69115 .34973 L F
.709 .456 .54 r
.70521 .30059 m .70548 .30318 L .70222 .30335 L F
.884 .991 .756 r
.70534 .30185 m .70521 .30059 L .70378 .2995 L F
.449 .269 .543 r
.70789 .29966 m .70548 .30318 L .70521 .30059 L F
.884 .991 .756 r
.70534 .30185 m .70789 .29966 L .70521 .30059 L F
.787 .874 .911 r
.67257 .38873 m .67753 .38744 L .67613 .38585 L F
.763 .824 .9 r
.67753 .38744 m .67896 .38332 L .67613 .38585 L F
.67753 .38744 m .67944 .38628 L .67896 .38332 L F
.904 .97 .809 r
.37903 .70694 m .38126 .70419 L .38004 .7036 L F
.16 0 .329 r
.33319 .61525 m .33284 .61766 L .33473 .61538 L F
.659 .466 .613 r
.43196 .53758 m .43156 .53979 L .43516 .53654 L F
.43196 .53758 m .43516 .53654 L .43531 .5364 L F
.43196 .53758 m .43156 .53979 L .43531 .5364 L F
0 0 .435 r
.43215 .53828 m .43028 .53812 L .43196 .53758 L F
.43028 .53812 m .42961 .53807 L .43196 .53758 L F
.43215 .53828 m .4309 .5411 L .42961 .53807 L F
.955 .652 .223 r
.7032 .31973 m .70251 .32141 L .70261 .3182 L F
.7032 .31973 m .70358 .32275 L .70251 .32141 L F
.783 .676 .746 r
.56736 .40583 m .57127 .40643 L .56876 .40961 L F
.717 .574 .693 r
.23248 .59624 m .23241 .59903 L .23479 .59595 L F
0 0 0 r
.23479 .59595 m .23241 .59903 L .23365 .59774 L F
.23365 .59774 m .23698 .59687 L .23479 .59595 L F
.323 .784 .653 r
.28555 .51972 m .28547 .51981 L .28745 .51884 L F
.28555 .51972 m .28335 .52079 L .28547 .51981 L F
.94 .94 .764 r
.3477 .63191 m .34966 .63095 L .34731 .63383 L F
.753 .542 .61 r
.34966 .63095 m .35022 .63438 L .34731 .63383 L F
0 .175 .71 r
.3503 .62987 m .34966 .63095 L .3477 .63191 L F
.3503 .62987 m .35205 .63324 L .34966 .63095 L F
.599 .874 .993 r
.35205 .63324 m .35022 .63438 L .34966 .63095 L F
.961 .75 .573 r
.40489 .53403 m .40635 .53787 L .40443 .53679 L F
.40489 .53403 m .40635 .53787 L .40443 .53679 L F
0 .244 .759 r
.40691 .54031 m .40443 .53679 L .40635 .53787 L F
.504 0 0 r
.28338 .57494 m .27874 .57343 L .28112 .57254 L F
.627 .95 .763 r
.66792 .31611 m .6696 .31416 L .67136 .31351 L F
.583 .885 .595 r
.66792 .31611 m .66794 .3159 L .6696 .31416 L F
.847 .553 .491 r
.27377 .63624 m .2773 .6374 L .27737 .63979 L F
.84 .707 .717 r
.59485 .37725 m .59594 .3806 L .59289 .3814 L F
.876 .78 .753 r
.59594 .3806 m .59197 .38293 L .59289 .3814 L F
.59594 .3806 m .59479 .38304 L .59197 .38293 L F
.973 .711 .295 r
.41459 .57643 m .41372 .57796 L .41369 .57517 L F
.41459 .57643 m .4147 .57913 L .41372 .57796 L F
.92 .581 .122 r
.59478 .41213 m .59441 .40988 L .59306 .40811 L F
.408 .156 .416 r
.35557 .59551 m .35492 .59814 L .35255 .59864 L F
.216 0 .352 r
.35412 .60052 m .35255 .59864 L .35492 .59814 L F
.35412 .60052 m .3523 .60143 L .35255 .59864 L F
.517 .437 .704 r
.46346 .52797 m .46399 .53066 L .46155 .53127 L F
.502 .367 .63 r
.46399 .53066 m .46176 .53409 L .46155 .53127 L F
.66 .202 .153 r
.54049 .46692 m .54451 .46725 L .54309 .46895 L F
.584 .113 .102 r
.54451 .46725 m .54721 .4689 L .54309 .46895 L F
.578 .137 .164 r
.54451 .46725 m .5472 .46767 L .54721 .4689 L F
0 0 .401 r
.40855 .544 m .40818 .54267 L .40691 .54031 L F
.856 .525 .005 r
.40855 .544 m .40828 .54536 L .40818 .54267 L F
.40855 .544 m .40919 .54705 L .40828 .54536 L F
.638 .875 .986 r
.37747 .63475 m .37637 .63346 L .37541 .63594 L F
.37747 .63475 m .37977 .63377 L .37637 .63346 L F
.642 .486 .656 r
.35787 .5927 m .35827 .59544 L .35557 .59551 L F
.162 0 .016 r
.35827 .59544 m .35492 .59814 L .35557 .59551 L F
.418 .43 .765 r
.46704 .54592 m .46492 .54798 L .46397 .54416 L F
.367 .401 .765 r
.46786 .54999 m .46492 .54798 L .46704 .54592 L F
.808 .966 .907 r
.70234 .28769 m .70561 .28502 L .70328 .28495 L F
0 0 .278 r
.70245 .29017 m .70234 .28769 L .70328 .28495 L F
.768 .756 .842 r
.61993 .43659 m .62156 .43837 L .62476 .4356 L F
.063 0 0 r
.45417 .56608 m .4553 .56401 L .45216 .56649 L F
.533 .423 .674 r
.4553 .56401 m .45796 .56314 L .45749 .56026 L F
.38 .077 .321 r
.45787 .5649 m .4553 .56401 L .45417 .56608 L F
.45787 .5649 m .45796 .56314 L .4553 .56401 L F
.813 .883 .896 r
.64864 .33497 m .64541 .33528 L .64748 .33364 L F
.904 .911 .817 r
.6497 .33331 m .64864 .33497 L .64748 .33364 L F
.731 .641 .759 r
.49026 .45352 m .49192 .45706 L .48942 .45796 L F
.705 .487 .59 r
.49192 .45706 m .48915 .46046 L .48942 .45796 L F
.49192 .45706 m .49174 .46012 L .48915 .46046 L F
.692 .624 .775 r
.49433 .45406 m .49192 .45706 L .49026 .45352 L F
.63 .533 .725 r
.49433 .45406 m .49451 .45679 L .49192 .45706 L F
.659 .475 .624 r
.49451 .45679 m .49174 .46012 L .49192 .45706 L F
.728 .603 .718 r
.33995 .60221 m .34402 .60528 L .3433 .60154 L F
.33995 .60221 m .34075 .60569 L .34402 .60528 L F
.269 .026 .349 r
.34075 .60569 m .34251 .60693 L .34402 .60528 L F
.983 .719 .444 r
.3452 .61692 m .34682 .61811 L .34541 .62067 L F
0 0 .554 r
.3433 .60154 m .34402 .60528 L .34481 .60374 L F
.678 .888 .522 r
.34402 .60528 m .34251 .60693 L .34481 .60374 L F
.983 .719 .444 r
.34541 .62067 m .34682 .61811 L .3452 .61692 L F
.972 .674 .395 r
.34024 .60826 m .34045 .61055 L .34174 .60953 L F
.111 .248 .726 r
.34174 .60953 m .34251 .60693 L .34024 .60826 L F
.249 0 .002 r
.34422 .60866 m .34363 .60997 L .34174 .60953 L F
.111 .248 .726 r
.34174 .60953 m .34363 .60997 L .34251 .60693 L F
.646 .642 .831 r
.44191 .51698 m .44539 .51869 L .44377 .51745 L F
.127 .313 .782 r
.44275 .52188 m .44243 .52103 L .44539 .51869 L F
.467 .786 .999 r
.44539 .51869 m .44813 .51829 L .44377 .51745 L F
.454 .151 .36 r
.44539 .51869 m .44243 .52103 L .44813 .51829 L F
.541 .868 .994 r
.25989 .51967 m .25867 .52046 L .25668 .51983 L F
.737 .658 .772 r
.63961 .4233 m .64518 .42257 L .64381 .41877 L F
.387 .055 .275 r
.30032 .63684 m .3035 .6341 L .30354 .63657 L F
.468 .246 .493 r
.3035 .6341 m .30582 .63377 L .30354 .63657 L F
0 0 0 r
.44837 .59522 m .44815 .59552 L .44459 .59747 L F
.44992 .59408 m .44815 .59552 L .44837 .59522 L F
.578 .378 .574 r
.47554 .47354 m .47575 .47657 L .47246 .47641 L F
.554 .416 .648 r
.47575 .47657 m .47338 .48024 L .47246 .47641 L F
.763 .961 .659 r
.70337 .27746 m .70146 .27874 L .70263 .2766 L F
.844 .836 .838 r
.70409 .27163 m .70337 .27746 L .70263 .2766 L F
.70418 .27153 m .70337 .27746 L .70409 .27163 L F
.70418 .27153 m .70556 .27466 L .70337 .27746 L F
.70423 .27116 m .70431 .27139 L .70418 .27153 L F
.70431 .27139 m .70556 .27466 L .70418 .27153 L F
.979 .745 .333 r
.70479 .27073 m .70556 .27466 L .70423 .27116 L F
0 0 0 r
.70479 .27073 m .70654 .2706 L .70556 .27466 L F
.70479 .27073 m .70691 .26938 L .70658 .27057 L F
.70696 .26882 m .70591 .2699 L .70654 .2706 L F
.834 .495 .415 r
.70935 .26933 m .70658 .27059 L .70691 .26938 L F
.828 .491 .417 r
.70667 .27054 m .70935 .26933 L .70696 .26882 L F
.821 .65 .67 r
.70688 .27076 m .70689 .27082 L .7066 .27066 L F
.70689 .27082 m .70795 .27489 L .70662 .27073 L F
.70689 .27082 m .70662 .27073 L .7066 .27066 L F
.828 .491 .417 r
.70694 .27083 m .7096 .27172 L .70935 .26933 L F
.821 .65 .67 r
.7096 .27172 m .70895 .27297 L .70688 .27076 L F
.70895 .27297 m .70795 .27489 L .70688 .27076 L F
.025 .153 .661 r
.70657 .27063 m .70706 .27729 L .70556 .27466 L F
.70657 .27063 m .70706 .27729 L .70657 .27063 L F
.70658 .27066 m .70706 .27729 L .70657 .27063 L F
0 0 0 r
.70654 .2706 m .70657 .27063 L .70556 .27466 L F
.025 .153 .661 r
.70658 .27065 m .70795 .27489 L .70706 .27729 L F
0 0 0 r
.70667 .27052 m .70654 .2706 L .70657 .27063 L F
.025 .153 .661 r
.7066 .27066 m .70795 .27489 L .70658 .27065 L F
0 0 0 r
.7066 .27067 m .70657 .27063 L .7066 .27067 L F
.834 .495 .415 r
.70935 .26933 m .70679 .27068 L .70663 .27061 L F
.70935 .26933 m .70663 .27061 L .70663 .27057 L F
.828 .491 .417 r
.70679 .27068 m .70935 .26933 L .70667 .27054 L F
.70694 .27083 m .70935 .26933 L .70679 .27068 L F
.834 .495 .415 r
.70935 .26933 m .7096 .27172 L .70679 .27068 L F
0 0 0 r
.70663 .27057 m .70657 .27063 L .70663 .27061 L F
.834 .495 .415 r
.70663 .27057 m .70663 .27061 L .70658 .27059 L F
0 0 0 r
.70663 .27061 m .70657 .27063 L .7066 .27067 L F
.70667 .27052 m .70663 .27057 L .70663 .27061 L F
.025 .153 .661 r
.70658 .27059 m .70658 .27065 L .70657 .27063 L F
.70658 .27065 m .70658 .27066 L .70657 .27064 L F
.70658 .27065 m .70657 .27064 L .70657 .27063 L F
.70658 .27059 m .7066 .27066 L .70658 .27065 L F
0 0 .112 r
.7042 .27156 m .70263 .2766 L .70406 .27403 L F
.844 .836 .838 r
.70423 .27116 m .70418 .27153 L .70409 .27163 L F
0 0 .112 r
.70423 .27116 m .70409 .27163 L .70418 .27158 L F
.979 .734 .324 r
.7039 .27197 m .70418 .27158 L .70423 .27116 L F
.70418 .27158 m .70479 .27073 L .70423 .27116 L F
0 0 .112 r
.70423 .27116 m .70418 .27158 L .7042 .27156 L F
.70409 .27163 m .70263 .2766 L .7042 .27156 L F
0 0 0 r
.70479 .27073 m .70658 .27057 L .70654 .2706 L F
.733 .627 .741 r
.70752 .26757 m .70691 .26938 L .70479 .27073 L F
0 0 0 r
.70696 .26882 m .70597 .26969 L .70435 .27147 L F
.70443 .27143 m .70435 .27147 L .7039 .27197 L F
.70696 .26882 m .70435 .27147 L .70443 .27143 L F
0 0 .112 r
.70423 .27116 m .70406 .27403 L .7039 .27197 L F
0 0 0 r
.70658 .27064 m .7039 .27197 L .70664 .27072 L F
.70657 .27063 m .70657 .27063 L .70658 .27064 L F
.70657 .27063 m .7039 .27197 L .70658 .27064 L F
.70591 .2699 m .7059 .26992 L .70657 .27063 L F
.7059 .26992 m .7039 .27197 L .70657 .27063 L F
.025 .153 .661 r
.70657 .27063 m .70657 .27063 L .70657 .27063 L F
.828 .491 .417 r
.70674 .27096 m .7096 .27172 L .70694 .27083 L F
.70658 .27106 m .70681 .27111 L .70674 .27096 L F
.70681 .27111 m .7096 .27172 L .70674 .27096 L F
.70658 .27106 m .70694 .27083 L .70667 .27054 L F
.821 .65 .67 r
.70663 .27061 m .7066 .27066 L .70658 .27059 L F
.7096 .27172 m .7066 .27066 L .70663 .27061 L F
0 0 0 r
.70667 .27054 m .7066 .27067 L .70664 .27072 L F
.70667 .27052 m .7066 .27067 L .70667 .27054 L F
.70696 .26882 m .70654 .2706 L .70667 .27052 L F
.70654 .2706 m .70658 .27057 L .70658 .27059 L F
.70654 .2706 m .70658 .27059 L .70657 .27063 L F
.70664 .27072 m .7039 .27197 L .70658 .27106 L F
.70597 .26969 m .70509 .27046 L .70456 .27114 L F
.70597 .26969 m .70456 .27114 L .7039 .27197 L F
.70509 .27046 m .70479 .27073 L .70441 .27126 L F
.70509 .27046 m .70441 .27126 L .7039 .27197 L F
.533 .865 .994 r
.36353 .70077 m .36506 .70155 L .36106 .70161 L F
0 0 .512 r
.47111 .5626 m .47289 .56518 L .47264 .56583 L F
0 0 .399 r
.47289 .56518 m .47413 .56895 L .47264 .56583 L F
.179 .017 .41 r
.54181 .41503 m .54006 .41599 L .54155 .41564 L F
.195 .067 .469 r
.54006 .41599 m .54009 .41894 L .54155 .41564 L F
.54006 .41599 m .54009 .41894 L .54155 .41564 L F
.484 0 0 r
.35736 .55321 m .35206 .5537 L .35077 .55254 L F
.222 .311 .745 r
.35756 .55043 m .35736 .55321 L .35503 .5507 L F
.35756 .55043 m .35839 .55252 L .35736 .55321 L F
.143 .688 .751 r
.35553 .55323 m .35736 .55321 L .35839 .55252 L F
.35553 .55323 m .35206 .5537 L .35736 .55321 L F
.88 .85 .809 r
.32877 .66283 m .33241 .66205 L .33067 .66038 L F
.677 .823 .953 r
.33067 .66038 m .33241 .66205 L .33546 .66025 L F
0 0 0 r
.34388 .68145 m .34338 .68175 L .34455 .67974 L F
.34391 .68138 m .34455 .67974 L .34391 .68136 L F
.34391 .68136 m .34455 .67974 L .3446 .67906 L F
.34388 .68145 m .34391 .68138 L .34391 .68136 L F
.34388 .68145 m .3446 .67906 L .34506 .68102 L F
.212 0 0 r
.34464 .6802 m .34506 .68102 L .34392 .68096 L F
.585 .295 .443 r
.33974 .68066 m .34388 .68145 L .34235 .67998 L F
.212 0 0 r
.34412 .68105 m .34235 .67998 L .34388 .68145 L F
.34464 .6802 m .3437 .68011 L .34412 .68105 L F
.3437 .68011 m .34235 .67998 L .34412 .68105 L F
.012 .554 .839 r
.33974 .68066 m .34338 .68175 L .34388 .68145 L F
.86 .547 .457 r
.34247 .68672 m .34338 .68175 L .33974 .68066 L F
.832 .552 .513 r
.34094 .6808 m .34409 .68097 L .34438 .68339 L F
.34409 .68097 m .34506 .68102 L .34469 .68232 L F
.34409 .68097 m .34469 .68232 L .34438 .68339 L F
.212 0 0 r
.34394 .68031 m .34392 .68096 L .34094 .6808 L F
.34464 .6802 m .34392 .68096 L .34394 .68031 L F
.927 .973 .712 r
.69639 .34348 m .69617 .3461 L .69494 .34809 L F
.432 .298 .598 r
.43434 .48339 m .43471 .48668 L .43684 .48535 L F
.657 .16 .057 r
.43434 .48339 m .43684 .48535 L .43276 .48468 L F
.495 .86 .987 r
.44275 .52188 m .43899 .52172 L .4412 .52115 L F
.673 .314 .356 r
.44372 .52011 m .44813 .51829 L .44243 .52103 L F
.127 .313 .782 r
.44275 .52188 m .44372 .52011 L .44243 .52103 L F
.547 .388 .617 r
.4412 .52115 m .44372 .52011 L .44275 .52188 L F
.4412 .52115 m .44371 .52323 L .44372 .52051 L F
.4412 .52115 m .44372 .52051 L .44372 .52011 L F
.495 .86 .987 r
.43899 .52172 m .43846 .5217 L .4412 .52115 L F
0 0 0 r
.37195 .53465 m .36957 .53817 L .37096 .53658 L F
.328 .054 .337 r
.36817 .53973 m .37096 .53658 L .36957 .53817 L F
.882 .693 .642 r
.38315 .61108 m .38354 .61288 L .38199 .6149 L F
.913 .541 .104 r
.60245 .42235 m .60057 .41865 L .60106 .42107 L F
.974 .664 .321 r
.60264 .42478 m .60245 .42235 L .60106 .42107 L F
.313 .253 .628 r
.35992 .59397 m .35787 .5927 L .3603 .59181 L F
.35992 .59397 m .35827 .59544 L .35787 .5927 L F
0 0 0 r
.37117 .58493 m .37242 .58276 L .37431 .58191 L F
.566 .553 .799 r
.33618 .62043 m .33806 .62446 L .33504 .62462 L F
.559 .399 .621 r
.33806 .62446 m .33523 .62719 L .33504 .62462 L F
.33806 .62446 m .33523 .62719 L .33504 .62462 L F
.396 .059 .272 r
.28753 .52781 m .28617 .53047 L .28368 .53101 L F
.716 .653 .787 r
.28785 .52609 m .28753 .52781 L .28634 .52593 L F
.311 .445 .835 r
.28836 .52515 m .2913 .52681 L .28785 .52609 L F
.108 0 .111 r
.2879 .52738 m .28753 .52781 L .28785 .52609 L F
.431 .14 .368 r
.2913 .52681 m .28798 .52952 L .28785 .52609 L F
.395 .803 .981 r
.28674 .52634 m .2913 .52681 L .28836 .52515 L F
.28854 .52652 m .28941 .52597 L .2913 .52681 L F
.28674 .52634 m .28891 .52603 L .28854 .52652 L F
.28891 .52603 m .28941 .52597 L .28854 .52652 L F
.108 0 .111 r
.28798 .52952 m .28754 .52785 L .2879 .52738 L F
.28754 .52785 m .28753 .52781 L .2879 .52738 L F
.28798 .52952 m .28617 .53047 L .28753 .52781 L F
.759 .554 .619 r
.51947 .44175 m .51517 .44407 L .51734 .44092 L F
.51947 .44175 m .51931 .44464 L .51517 .44407 L F
.804 .702 .753 r
.51817 .43835 m .51947 .44175 L .51734 .44092 L F
.473 .842 .6 r
.38803 .67143 m .38841 .6712 L .38561 .67337 L F
0 .452 .823 r
.72471 .31875 m .72239 .318 L .72123 .31704 L F
.25 0 .013 r
.30146 .56385 m .30003 .56563 L .29817 .56561 L F
.338 0 .069 r
.30339 .56456 m .30146 .56385 L .30412 .56353 L F
.30339 .56456 m .30003 .56563 L .30146 .56385 L F
.965 .728 .53 r
.32483 .56238 m .3234 .56264 L .32373 .55999 L F
.427 0 0 r
.32483 .56238 m .32753 .56301 L .3234 .56264 L F
.9 .912 .822 r
.6466 .39718 m .64444 .40032 L .64297 .39903 L F
.984 .849 .629 r
.64297 .39903 m .64444 .40032 L .64353 .40264 L F
.79 .726 .792 r
.62934 .41518 m .63257 .4159 L .63125 .41721 L F
.541 .005 0 r
.42729 .49095 m .42353 .49083 L .42415 .48926 L F
.998 .854 .553 r
.41169 .55679 m .41057 .55592 L .41236 .55385 L F
0 0 .364 r
.41236 .55385 m .41197 .55302 L .41068 .55064 L F
.925 .938 .58 r
.41236 .55385 m .41057 .55592 L .41197 .55302 L F
.355 0 0 r
.72725 .33778 m .72952 .33814 L .72505 .33839 L F
.705 .944 .959 r
.63908 .35627 m .6378 .35859 L .64016 .35706 L F
.704 .942 .96 r
.63674 .35777 m .6378 .35859 L .63908 .35627 L F
.295 0 0 r
.70582 .31091 m .70392 .30989 L .70352 .31192 L F
.70582 .31091 m .70665 .30962 L .70392 .30989 L F
.626 .063 0 r
.62878 .41235 m .62512 .41006 L .62815 .41132 L F
.684 .609 .766 r
.62815 .41132 m .62934 .41518 L .62878 .41235 L F
.636 .581 .776 r
.63135 .41175 m .62934 .41518 L .62815 .41132 L F
.63132 .41224 m .62934 .41518 L .63135 .41175 L F
.593 .377 .557 r
.63135 .41176 m .63132 .4122 L .6313 .41198 L F
.63443 .40849 m .63132 .41219 L .63156 .40846 L F
.636 .581 .776 r
.63163 .41179 m .63132 .41224 L .63135 .41175 L F
.593 .377 .557 r
.63132 .4122 m .6313 .41222 L .63129 .41217 L F
.6313 .41222 m .63122 .41231 L .63121 .41216 L F
.643 .56 .746 r
.63135 .41175 m .63122 .41231 L .63163 .41179 L F
.62815 .41132 m .63122 .41231 L .63135 .41175 L F
.593 .377 .557 r
.63156 .40846 m .63135 .41176 L .63093 .40845 L F
.63135 .41176 m .6313 .41198 L .63093 .40845 L F
.63132 .41219 m .63132 .4122 L .63156 .40846 L F
.63443 .40849 m .63163 .41179 L .63122 .41231 L F
.752 .754 .854 r
.63596 .41252 m .63402 .41444 L .63163 .41179 L F
.63402 .41444 m .63257 .4159 L .63181 .41261 L F
.63402 .41444 m .63181 .41261 L .63163 .41179 L F
.593 .377 .557 r
.63132 .4122 m .63129 .41217 L .63093 .40845 L F
.6313 .41222 m .63121 .41216 L .63093 .40845 L F
.761 .759 .851 r
.63132 .41224 m .63257 .4159 L .62934 .41518 L F
.63163 .41179 m .63181 .41261 L .63132 .41224 L F
.63181 .41261 m .63257 .4159 L .63132 .41224 L F
.729 .265 0 r
.70378 .2995 m .70239 .29716 L .701 .29579 L F
.637 .239 .273 r
.5472 .46767 m .55106 .46742 L .55021 .46966 L F
.501 .104 .22 r
.55021 .46966 m .55106 .46742 L .5535 .46853 L F
.096 .137 .615 r
.21097 .57923 m .21123 .58317 L .21272 .58135 L F
.09 .024 .481 r
.21123 .58317 m .21327 .5841 L .21272 .58135 L F
.21123 .58317 m .21155 .58595 L .21327 .5841 L F
.583 .461 .679 r
.47737 .46983 m .47871 .47317 L .47554 .47354 L F
.581 .392 .589 r
.47871 .47317 m .47575 .47657 L .47554 .47354 L F
.4 0 .063 r
.44365 .56941 m .44449 .57117 L .44578 .57039 L F
.44365 .56941 m .44179 .57156 L .44449 .57117 L F
.772 .266 0 r
.26734 .57623 m .26541 .57562 L .26353 .5731 L F
.38 .243 .566 r
.26353 .5731 m .26541 .57562 L .26622 .57259 L F
0 0 0 r
.31832 .59268 m .31801 .59455 L .31879 .59153 L F
.663 .419 .541 r
.48942 .45796 m .48513 .46001 L .48516 .45725 L F
.48942 .45796 m .48915 .46046 L .48513 .46001 L F
.009 .351 .827 r
.2847 .64683 m .28733 .64986 L .28756 .64855 L F
0 .068 .631 r
.28733 .64986 m .28938 .65234 L .28756 .64855 L F
.156 0 .262 r
.22812 .57954 m .22981 .57885 L .23058 .5763 L F
.297 .21 .586 r
.22812 .57954 m .23007 .58163 L .22981 .57885 L F
.834 .841 .851 r
.68779 .3789 m .68916 .38056 L .692 .37744 L F
.879 .79 .758 r
.64514 .41171 m .64832 .41188 L .64909 .4097 L F
.869 .816 .794 r
.64514 .41171 m .64586 .41548 L .64832 .41188 L F
.849 .842 .837 r
.59197 .38293 m .59479 .38304 L .59342 .38456 L F
.893 .76 .708 r
.64952 .40514 m .65146 .4064 L .65024 .40247 L F
.85 .788 .791 r
.64909 .4097 m .65146 .4064 L .64952 .40514 L F
.221 0 0 r
.31153 .55851 m .31015 .55807 L .31274 .5584 L F
.31153 .55851 m .30911 .55918 L .31015 .55807 L F
.567 .045 0 r
.34244 .70123 m .34522 .70377 L .34324 .7026 L F
.36 .69 .981 r
.34522 .70377 m .34565 .70233 L .34324 .7026 L F
.34522 .70377 m .34887 .70415 L .34565 .70233 L F
.521 .751 .98 r
.57709 .46661 m .58128 .46752 L .5799 .46388 L F
.646 .618 .808 r
.58128 .46752 m .58267 .46287 L .5799 .46388 L F
.58128 .46752 m .58366 .46644 L .58267 .46287 L F
.682 .463 .583 r
.51029 .4641 m .50775 .4672 L .50639 .46359 L F
.51029 .4641 m .51031 .46675 L .50775 .4672 L F
0 0 .251 r
.41288 .56285 m .41263 .56194 L .4118 .55954 L F
0 0 .409 r
.41288 .56285 m .41441 .56556 L .41263 .56194 L F
.786 .659 .722 r
.33012 .54101 m .32692 .54442 L .3256 .54051 L F
.67 .48 .619 r
.33078 .54324 m .3312 .54033 L .33012 .54101 L F
.33078 .54324 m .3312 .54033 L .33012 .54101 L F
.554 .492 .741 r
.32291 .52526 m .32548 .52562 L .32468 .52103 L F
.09 0 0 r
.32291 .52526 m .32383 .52606 L .32548 .52562 L F
.32291 .52526 m .32125 .52699 L .32383 .52606 L F
.273 0 0 r
.44846 .56881 m .45097 .56838 L .45216 .56649 L F
.639 .402 .543 r
.45097 .56838 m .45417 .56608 L .45216 .56649 L F
.479 .817 .522 r
.33638 .68153 m .33297 .68466 L .33553 .68426 L F
0 0 0 r
.33975 .67945 m .33638 .68153 L .33974 .68066 L F
.292 0 .156 r
.33974 .68066 m .33638 .68153 L .33553 .68426 L F
.737 .835 .925 r
.34759 .65529 m .34959 .65248 L .34814 .65349 L F
.278 .777 .873 r
.22306 .60286 m .22052 .60272 L .21827 .60316 L F
0 .227 .655 r
.22306 .60286 m .22354 .60296 L .22052 .60272 L F
.22306 .60286 m .22527 .60416 L .22354 .60296 L F
.543 .132 .212 r
.38954 .60601 m .39002 .60748 L .38778 .60617 L F
.881 .7 .652 r
.39002 .60748 m .38882 .60248 L .38778 .60617 L F
.789 .29 0 r
.36466 .66889 m .36854 .67252 L .36702 .66885 L F
.246 0 .317 r
.35465 .6299 m .35241 .63251 L .35205 .63324 L F
0 0 .149 r
.35205 .63324 m .35241 .63251 L .35244 .63267 L F
.599 .874 .993 r
.35205 .63324 m .35354 .6342 L .35054 .63436 L F
.35022 .63438 m .35354 .6342 L .35205 .63324 L F
0 0 .161 r
.35285 .63458 m .35244 .63267 L .35381 .63192 L F
.35244 .63267 m .35241 .63251 L .35256 .63244 L F
.35244 .63267 m .35256 .63244 L .35381 .63192 L F
.897 .922 .829 r
.35344 .62866 m .35412 .62935 L .35205 .63324 L F
.35412 .62935 m .35448 .62973 L .35244 .63267 L F
.35412 .62935 m .35244 .63267 L .35205 .63324 L F
.35448 .62973 m .35465 .6299 L .35205 .63324 L F
0 0 .149 r
.35205 .63324 m .35244 .63267 L .3525 .63291 L F
.35205 .63324 m .3525 .63291 L .35285 .63458 L F
.599 .874 .993 r
.35205 .63324 m .35054 .63436 L .35022 .63438 L F
.495 .293 .534 r
.24947 .56904 m .24914 .5729 L .24648 .57338 L F
.625 .275 .356 r
.24432 .57208 m .24757 .57239 L .24947 .56904 L F
.34 .164 .491 r
.25109 .57176 m .24947 .56904 L .25036 .56776 L F
.25109 .57176 m .24914 .5729 L .24947 .56904 L F
.708 .515 .626 r
.24757 .57239 m .25036 .56776 L .24947 .56904 L F
.972 .926 .627 r
.56689 .38827 m .56672 .38951 L .56572 .3884 L F
.749 .868 .442 r
.56672 .38951 m .56557 .39098 L .56572 .3884 L F
.56672 .38951 m .56505 .39256 L .56557 .39098 L F
.902 .907 .817 r
.33496 .56007 m .33566 .55679 L .33589 .55695 L F
.419 .865 .814 r
.33589 .55695 m .3377 .55584 L .33833 .55568 L F
.33589 .55695 m .33566 .55679 L .3377 .55584 L F
0 0 0 r
.32879 .55363 m .32518 .55468 L .32619 .55385 L F
.674 .846 .965 r
.49826 .44173 m .49515 .4436 L .49376 .44217 L F
.904 .911 .817 r
.6497 .33331 m .64748 .33364 L .65033 .33069 L F
.54 .478 .735 r
.46522 .53697 m .46358 .54155 L .46264 .53768 L F
.46522 .53697 m .46608 .54099 L .46358 .54155 L F
.48 .347 .621 r
.46608 .54099 m .46397 .54416 L .46358 .54155 L F
0 0 0 r
.38969 .67088 m .38841 .6712 L .38803 .67143 L F
.38969 .67088 m .38841 .6712 L .38803 .67143 L F
.988 .733 .359 r
.4014 .67478 m .40252 .67609 L .40148 .67767 L F
.40148 .67767 m .40252 .67609 L .4014 .67478 L F
0 0 0 r
.22495 .55829 m .2241 .56001 L .22557 .55657 L F
.009 .158 .672 r
.22495 .55829 m .22606 .56223 L .2241 .56001 L F
0 0 0 r
.63832 .39358 m .63584 .39491 L .6348 .39552 L F
.482 .569 .866 r
.32829 .52914 m .32757 .52864 L .32687 .52723 L F
.32829 .52914 m .32603 .52946 L .32757 .52864 L F
.422 .022 .173 r
.37195 .53465 m .37096 .53658 L .37366 .53541 L F
.833 .634 .634 r
.3218 .63519 m .32355 .63407 L .31967 .63315 L F
.3218 .63519 m .32342 .63716 L .32355 .63407 L F
0 0 0 r
.3218 .63519 m .32355 .63407 L .32342 .63716 L F
.706 .641 .782 r
.3257 .63347 m .32342 .63716 L .32355 .63407 L F
.3257 .63347 m .32728 .63725 L .32342 .63716 L F
0 0 .432 r
.32355 .63407 m .3251 .63551 L .3257 .63347 L F
.32355 .63407 m .32342 .63716 L .3251 .63551 L F
.846 .413 .197 r
.32094 .66451 m .32393 .66672 L .32114 .66696 L F
.311 .803 .828 r
.32114 .66696 m .32393 .66672 L .32637 .66602 L F
.692 .466 .574 r
.5219 .46043 m .51943 .46323 L .51952 .46092 L F
.904 .832 .765 r
.4033 .49245 m .40271 .49423 L .40388 .49361 L F
.611 .885 .99 r
.5869 .46416 m .59058 .46425 L .58885 .46258 L F
.54 .739 .967 r
.58885 .46258 m .59058 .46425 L .59189 .46192 L F
.515 .707 .958 r
.59058 .46425 m .59309 .46395 L .59189 .46192 L F
.973 .664 .35 r
.49102 .44359 m .49261 .44584 L .49137 .44622 L F
.468 0 0 r
.49261 .44584 m .49552 .44699 L .49137 .44622 L F
.855 .675 .657 r
.37279 .71072 m .37662 .70766 L .37589 .7083 L F
.528 .181 .323 r
.37662 .70766 m .37903 .70694 L .37807 .70726 L F
0 0 0 r
.37589 .7083 m .37662 .70766 L .37807 .70726 L F
.002 .05 .558 r
.21039 .57653 m .21224 .57766 L .21223 .57511 L F
.21039 .57653 m .21097 .57923 L .21224 .57766 L F
.821 .607 .613 r
.22136 .58378 m .22574 .58661 L .22546 .58279 L F
.473 0 0 r
.24249 .62174 m .23896 .61938 L .24065 .62062 L F
.763 .995 .808 r
.32915 .49405 m .32696 .49608 L .32749 .49436 L F
.943 .59 .19 r
.32696 .49608 m .32584 .49733 L .32749 .49436 L F
.32696 .49608 m .32761 .49867 L .32584 .49733 L F
.812 .733 .778 r
.30582 .63377 m .30614 .63754 L .30354 .63657 L F
.295 .334 .732 r
.30837 .6359 m .30614 .63754 L .30582 .63377 L F
0 .473 .794 r
.30354 .63657 m .30614 .63754 L .30646 .63743 L F
0 0 0 r
.30837 .6359 m .30614 .63754 L .30646 .63743 L F
.199 0 0 r
.29671 .56753 m .29406 .56823 L .29525 .5668 L F
.2 0 0 r
.29817 .56561 m .29671 .56753 L .29525 .5668 L F
.119 0 0 r
.29119 .5178 m .28945 .51875 L .28745 .51884 L F
0 0 0 r
.2928 .51762 m .29119 .5178 L .29316 .51737 L F
.2928 .51762 m .28945 .51875 L .29119 .5178 L F
.159 0 .346 r
.35246 .53799 m .35405 .53892 L .35478 .53784 L F
.35246 .53799 m .35233 .54025 L .35405 .53892 L F
.22 .131 .536 r
.30013 .54973 m .30058 .55245 L .29857 .55068 L F
.30013 .54973 m .30058 .55245 L .29857 .55068 L F
.904 .968 .812 r
.59686 .35687 m .5953 .35858 L .59544 .35609 L F
.833 .978 .882 r
.59935 .35412 m .59686 .35687 L .59544 .35609 L F
.842 .767 .779 r
.51931 .44464 m .51895 .44722 L .51671 .44787 L F
.755 .662 .76 r
.56736 .40583 m .56876 .40961 L .56472 .4091 L F
.573 .576 .818 r
.56871 .41226 m .56472 .4091 L .56876 .40961 L F
.755 .662 .76 r
.56736 .40583 m .56876 .40961 L .56472 .4091 L F
.709 .985 .824 r
.67136 .31351 m .67282 .31135 L .67316 .31185 L F
.703 .975 .767 r
.67136 .31351 m .6696 .31416 L .67282 .31135 L F
.335 .056 .332 r
.29627 .63116 m .29562 .63341 L .29846 .63055 L F
.577 .466 .691 r
.46237 .50807 m .46404 .51446 L .46042 .51373 L F
.549 .436 .678 r
.46359 .51442 m .46042 .51373 L .46404 .51446 L F
.46359 .51442 m .46107 .51511 L .46042 .51373 L F
.6 .948 .914 r
.26188 .51919 m .25989 .51967 L .2637 .51797 L F
0 0 .308 r
.22293 .58102 m .22122 .58288 L .22183 .57985 L F
.879 .79 .758 r
.64514 .41171 m .64909 .4097 L .64747 .40835 L F
.85 .788 .791 r
.64909 .4097 m .64952 .40514 L .64747 .40835 L F
.772 .747 .83 r
.23241 .59903 m .22787 .59884 L .23031 .60106 L F
.07 0 0 r
.23241 .59903 m .23266 .59987 L .23365 .59774 L F
.47 .514 .821 r
.23266 .59987 m .23592 .60267 L .23438 .60021 L F
.144 0 0 r
.23438 .60021 m .23396 .60014 L .23266 .59987 L F
.731 .827 .924 r
.23435 .60547 m .23363 .60585 L .23187 .60436 L F
.852 .785 .786 r
.23187 .60436 m .2334 .60505 L .23266 .59987 L F
.731 .827 .924 r
.23598 .60462 m .23363 .60585 L .2332 .60548 L F
.47 .514 .821 r
.23266 .59987 m .2334 .60505 L .2349 .6018 L F
.731 .827 .924 r
.23367 .60447 m .2332 .60548 L .23187 .60436 L F
.23598 .60462 m .2332 .60548 L .23367 .60447 L F
.23598 .60462 m .23435 .60547 L .23187 .60436 L F
.47 .514 .821 r
.23411 .60352 m .2334 .60505 L .23454 .60397 L F
.589 .922 .703 r
.2334 .60505 m .23378 .60427 L .23592 .60267 L F
.828 .353 .031 r
.23378 .60427 m .2377 .60757 L .23731 .60689 L F
.23501 .60447 m .23731 .60689 L .23598 .60462 L F
.23378 .60427 m .23731 .60689 L .23501 .60447 L F
.47 .514 .821 r
.2349 .6018 m .23411 .60352 L .23592 .60267 L F
.23411 .60352 m .23454 .60397 L .23592 .60267 L F
.2334 .60505 m .2334 .60505 L .2349 .6018 L F
.852 .785 .786 r
.23187 .60436 m .2334 .60505 L .2334 .60505 L F
.23187 .60436 m .23266 .59987 L .23031 .60106 L F
.144 0 0 r
.23396 .60014 m .23142 .59977 L .23266 .59987 L F
.07 0 0 r
.23241 .59903 m .23175 .59967 L .23266 .59987 L F
.23175 .59967 m .23031 .60106 L .23266 .59987 L F
.761 .717 .811 r
.35016 .68173 m .35453 .68235 L .35278 .6793 L F
0 .003 .576 r
.35226 .68763 m .34978 .68429 L .35389 .68436 L F
.738 .34 .296 r
.35302 .68467 m .35453 .68235 L .35016 .68173 L F
.984 .874 .513 r
.35389 .68436 m .35453 .68235 L .35302 .68467 L F
.047 0 0 r
.43184 .55317 m .43065 .55462 L .42992 .55402 L F
.756 .699 .797 r
.32521 .64234 m .32648 .64652 L .32821 .64371 L F
.869 .986 .711 r
.32821 .64371 m .32648 .64652 L .32586 .64549 L F
.608 .2 0 r
.32586 .64549 m .32648 .64652 L .32822 .64942 L F
.614 .798 .97 r
.38094 .62158 m .38244 .61928 L .37947 .61684 L F
.38094 .62158 m .38351 .62085 L .38244 .61928 L F
.041 0 0 r
.38164 .6221 m .38094 .62158 L .38321 .62373 L F
.38164 .6221 m .38351 .62085 L .38094 .62158 L F
.906 .835 .765 r
.64327 .41518 m .64586 .41548 L .64514 .41171 L F
.912 .819 .742 r
.64381 .41877 m .64586 .41548 L .64327 .41518 L F
.73 .657 .776 r
.50999 .4506 m .51147 .45443 L .5088 .45332 L F
.8 .526 .524 r
.5088 .45332 m .51147 .45443 L .51144 .45694 L F
.849 .855 .847 r
.51403 .45104 m .51147 .45443 L .50999 .4506 L F
.972 .672 .387 r
.60829 .40891 m .6101 .41264 L .60907 .41131 L F
.956 .621 .232 r
.6101 .41264 m .60917 .41363 L .60907 .41131 L F
.6101 .41264 m .6106 .41529 L .60917 .41363 L F
.605 .196 .24 r
.34213 .5084 m .33883 .50987 L .33997 .51119 L F
.237 .325 .751 r
.33604 .5083 m .33737 .50654 L .3364 .50786 L F
.593 .368 .544 r
.46719 .49593 m .46735 .49862 L .46437 .4987 L F
.571 .385 .59 r
.46719 .49593 m .4699 .49842 L .46735 .49862 L F
.46719 .49593 m .46987 .49566 L .4699 .49842 L F
.839 .903 .882 r
.72536 .33175 m .72708 .32768 L .72807 .331 L F
.74 .353 .318 r
.53223 .46373 m .53621 .46442 L .53655 .46625 L F
.269 .026 .349 r
.34075 .60569 m .34024 .60826 L .34251 .60693 L F
.9 .912 .822 r
.6466 .39718 m .64297 .39903 L .64235 .39724 L F
.725 .962 .942 r
.66257 .33814 m .66682 .33683 L .66455 .3361 L F
.801 .939 .919 r
.66455 .3361 m .66682 .33683 L .66872 .33506 L F
.841 .998 .821 r
.38315 .6261 m .38284 .62805 L .3851 .62543 L F
.755 .991 .885 r
.42268 .47502 m .42353 .47297 L .42506 .47382 L F
.42268 .47502 m .42066 .47523 L .42353 .47297 L F
.184 .364 .809 r
.24607 .61151 m .24588 .61451 L .2437 .61124 L F
.24607 .61151 m .24724 .61444 L .24588 .61451 L F
.499 .507 .797 r
.24896 .61658 m .24588 .61451 L .24724 .61444 L F
.99 .779 .525 r
.61343 .39144 m .61532 .38882 L .615 .38785 L F
0 .122 .59 r
.61205 .39218 m .61343 .39144 L .61164 .39206 L F
.99 .779 .525 r
.61343 .39144 m .61483 .39287 L .61511 .39052 L F
.999 .814 .524 r
.61412 .39608 m .61483 .39287 L .61321 .39412 L F
.991 .759 .483 r
.61321 .39412 m .61483 .39287 L .61343 .39144 L F
0 .122 .59 r
.61589 .39332 m .61586 .39332 L .61343 .39144 L F
.61589 .39332 m .61343 .39144 L .61205 .39218 L F
.99 .779 .525 r
.61343 .39144 m .61511 .39052 L .61532 .38882 L F
.804 .849 .884 r
.67896 .38332 m .67944 .38628 L .68265 .3832 L F
.709 .962 .944 r
.64764 .39018 m .64477 .39224 L .64341 .39148 L F
.616 .83 .434 r
.44304 .57721 m .44181 .57912 L .44023 .58129 L F
.444 .128 .334 r
.43429 .54447 m .4311 .54687 L .43311 .54562 L F
.982 .909 .608 r
.39889 .5963 m .40067 .59518 L .39983 .59429 L F
.39889 .5963 m .39931 .59925 L .40067 .59518 L F
.289 .497 .886 r
.62675 .40792 m .62512 .41006 L .62396 .40804 L F
.62675 .40792 m .62815 .41132 L .62512 .41006 L F
.487 .294 .545 r
.34756 .54492 m .34905 .54557 L .3502 .54112 L F
.904 .97 .809 r
.37903 .70694 m .38004 .7036 L .37807 .70726 L F
.42 .237 .524 r
.34735 .5306 m .34727 .53351 L .34473 .53421 L F
.336 .062 .341 r
.34727 .53351 m .34442 .53675 L .34473 .53421 L F
.616 .639 .851 r
.49137 .44622 m .49065 .45089 L .48906 .4476 L F
.49137 .44622 m .49288 .44996 L .49065 .45089 L F
.699 .602 .744 r
.49288 .44996 m .49026 .45352 L .49065 .45089 L F
.329 .437 .819 r
.3291 .6946 m .33074 .69839 L .33215 .69727 L F
.341 .459 .835 r
.33215 .69727 m .33074 .69839 L .33289 .6983 L F
.468 .273 .532 r
.32778 .60843 m .32758 .61141 L .32527 .61178 L F
.585 .466 .683 r
.32758 .61141 m .32543 .61443 L .32527 .61178 L F
.741 .91 .538 r
.29924 .66345 m .29789 .66499 L .29865 .66246 L F
.851 .731 .731 r
.27388 .51751 m .27196 .52039 L .27016 .51762 L F
.27388 .51751 m .27016 .51762 L .27266 .51809 L F
0 0 0 r
.27388 .51751 m .27491 .51705 L .27579 .51701 L F
.27388 .51751 m .27266 .51809 L .27491 .51705 L F
0 0 .204 r
.37945 .5516 m .37873 .55371 L .37872 .55064 L F
0 0 .187 r
.30058 .55245 m .30007 .557 L .29853 .55389 L F
.30058 .55245 m .3006 .5555 L .30007 .557 L F
.389 .214 .519 r
.24027 .57614 m .23989 .5786 L .23875 .57885 L F
.149 0 .29 r
.23945 .5812 m .23875 .57885 L .23989 .5786 L F
.23945 .5812 m .2374 .58227 L .23875 .57885 L F
0 .518 .729 r
.27234 .52075 m .27415 .52096 L .27 .52038 L F
.4 .155 .424 r
.42753 .52826 m .42942 .53 L .4295 .52736 L F
.42753 .52826 m .42705 .5308 L .42942 .53 L F
.42753 .52826 m .42942 .53 L .4295 .52736 L F
.42753 .52826 m .42705 .5308 L .42942 .53 L F
.942 .925 .762 r
.7047 .28339 m .70764 .28127 L .70617 .27963 L F
.7047 .28339 m .70561 .28502 L .70764 .28127 L F
.278 0 0 r
.25583 .61821 m .25755 .61886 L .25887 .61809 L F
.592 .055 0 r
.25472 .61633 m .25755 .61886 L .25583 .61821 L F
.641 .869 .984 r
.29333 .6729 m .29554 .67332 L .29747 .67213 L F
.366 .181 .493 r
.3502 .54112 m .35218 .54287 L .35233 .54025 L F
.3502 .54112 m .34905 .54557 L .35218 .54287 L F
.826 .911 .896 r
.63752 .3424 m .6334 .34384 L .63663 .34153 L F
.818 .965 .901 r
.64089 .33918 m .63752 .3424 L .6381 .33982 L F
.826 .97 .893 r
.63752 .3424 m .63663 .34153 L .6381 .33982 L F
.822 .82 .848 r
.52415 .42202 m .52122 .42538 L .5194 .42366 L F
.724 .638 .762 r
.49696 .45085 m .5001 .4549 L .49433 .45406 L F
.734 .445 .49 r
.49433 .45406 m .5001 .4549 L .49914 .45694 L F
.465 .551 .859 r
.50115 .45405 m .5001 .4549 L .49696 .45085 L F
.736 .604 .71 r
.50115 .45405 m .49914 .45694 L .5001 .4549 L F
.702 .451 .541 r
.33919 .52469 m .34227 .52659 L .34335 .52602 L F
.882 .901 .839 r
.42214 .57201 m .42367 .57308 L .42628 .56983 L F
.136 0 .409 r
.42516 .57501 m .42349 .57582 L .42367 .57308 L F
.42516 .57501 m .42367 .57308 L .42214 .57201 L F
.484 0 0 r
.314 .6245 m .31795 .62442 L .31632 .62585 L F
.546 .026 0 r
.31632 .62585 m .31795 .62442 L .32003 .62588 L F
.503 .083 .175 r
.31795 .62442 m .32078 .62446 L .32003 .62588 L F
.36 0 .177 r
.29276 .6235 m .29653 .6206 L .29395 .62117 L F
.192 0 0 r
.44191 .51698 m .44107 .51788 L .43808 .51841 L F
.34 0 0 r
.44377 .51745 m .44107 .51788 L .44191 .51698 L F
.814 .687 .725 r
.39212 .58547 m .39346 .58908 L .38958 .5882 L F
.986 .819 .594 r
.39346 .58908 m .39149 .59102 L .38958 .5882 L F
.39346 .58908 m .39276 .5922 L .39149 .59102 L F
.69 .457 .565 r
.53007 .46084 m .52596 .46354 L .52607 .4605 L F
.53007 .46084 m .53006 .46342 L .52596 .46354 L F
.715 .988 .85 r
.23183 .57759 m .23537 .57553 L .23291 .57574 L F
.23403 .57631 m .23211 .57635 L .23537 .57553 L F
.23183 .57759 m .23211 .57635 L .23403 .57631 L F
.053 0 .213 r
.23072 .57645 m .23183 .57759 L .23272 .57607 L F
.104 .06 .518 r
.23183 .57759 m .23332 .57936 L .23211 .57635 L F
.753 .769 .264 r
.23332 .57936 m .23166 .57636 L .23211 .57635 L F
.053 0 .213 r
.23072 .57645 m .23272 .57607 L .23291 .57574 L F
.23058 .5763 m .23072 .57645 L .23291 .57574 L F
.23058 .5763 m .22981 .57885 L .23183 .57759 L F
.59 .415 .613 r
.23211 .57635 m .22975 .57683 L .2296 .5735 L F
0 0 0 r
.23141 .57592 m .22975 .57683 L .23211 .57635 L F
.753 .769 .264 r
.23166 .57636 m .23141 .57592 L .23211 .57635 L F
0 0 0 r
.23443 .57579 m .23211 .57635 L .23425 .57591 L F
.2349 .57565 m .23211 .57635 L .23536 .57556 L F
.59 .415 .613 r
.23211 .57635 m .2296 .5735 L .23141 .57592 L F
0 0 0 r
.23536 .57556 m .23443 .57579 L .23533 .57569 L F
.23443 .57579 m .23425 .57591 L .23533 .57569 L F
.536 .854 .997 r
.23211 .57635 m .23434 .57524 L .23533 .57569 L F
.23211 .57635 m .23141 .57592 L .23434 .57524 L F
.753 .769 .264 r
.23332 .57936 m .23434 .57524 L .23141 .57592 L F
.23332 .57936 m .23357 .57778 L .23411 .57601 L F
.23416 .57597 m .23411 .57601 L .23434 .57524 L F
.23332 .57936 m .23411 .57601 L .23416 .57597 L F
0 0 0 r
.23537 .57553 m .2349 .57565 L .23536 .57556 L F
.395 .057 .27 r
.3067 .54141 m .30577 .54359 L .3084 .54277 L F
.626 .935 .963 r
.25251 .52259 m .25299 .52104 L .2546 .52124 L F
.25251 .52259 m .24882 .52254 L .25299 .52104 L F
.322 .05 .336 r
.29562 .63341 m .29342 .63419 L .29275 .6367 L F
0 0 0 r
.38748 .62433 m .38876 .62181 L .38942 .62055 L F
.364 .117 .4 r
.29888 .62776 m .30101 .62713 L .30173 .62461 L F
.301 .093 .421 r
.29888 .62776 m .30042 .62956 L .30101 .62713 L F
.29888 .62776 m .29846 .63055 L .30042 .62956 L F
.315 .802 .77 r
.25621 .52527 m .25667 .52545 L .25784 .52403 L F
.651 .893 .555 r
.25698 .52392 m .256 .52503 L .25621 .52527 L F
.315 .802 .77 r
.25621 .52527 m .25406 .52605 L .25642 .52551 L F
0 0 0 r
.25478 .52639 m .25406 .52605 L .25621 .52527 L F
.651 .893 .555 r
.256 .52503 m .25478 .52639 L .25621 .52527 L F
.315 .802 .77 r
.25621 .52527 m .25642 .52551 L .25667 .52545 L F
.952 .641 .408 r
.35988 .60536 m .36153 .60855 L .36156 .60703 L F
.35988 .60536 m .35939 .60759 L .36153 .60855 L F
.961 .728 .539 r
.35939 .60759 m .3606 .61083 L .36153 .60855 L F
.455 .695 .97 r
.63851 .42408 m .64306 .42627 L .64129 .42462 L F
.463 .233 .479 r
.414 .49567 m .41335 .4986 L .41086 .49924 L F
.742 .71 .821 r
.41591 .49626 m .41335 .4986 L .414 .49567 L F
.694 .807 .935 r
.62605 .34964 m .62202 .34927 L .62453 .34791 L F
.755 .832 .911 r
.62829 .3481 m .62605 .34964 L .62453 .34791 L F
.855 .839 .829 r
.62577 .3727 m .62985 .37078 L .62601 .37043 L F
.702 .492 .6 r
.3335 .51211 m .33869 .51478 L .33607 .51237 L F
.3335 .51211 m .33318 .51497 L .33869 .51478 L F
.656 .592 .771 r
.33318 .51497 m .33607 .51237 L .3335 .51211 L F
0 0 0 r
.33675 .52615 m .33465 .52753 L .33631 .52495 L F
.683 .594 .75 r
.34273 .54132 m .34422 .54417 L .34051 .5442 L F
.883 .451 .136 r
.36941 .67128 m .36702 .66885 L .36854 .67252 L F
.126 .259 .732 r
.36854 .67252 m .37091 .67469 L .36941 .67128 L F
.784 .554 .588 r
.36854 .67252 m .37208 .67605 L .37091 .67469 L F
.565 .652 .894 r
.66194 .39369 m .66571 .39618 L .66441 .3925 L F
.727 .66 .783 r
.66441 .3925 m .66571 .39618 L .66844 .3932 L F
.996 .802 .442 r
.40079 .56593 m .40042 .56866 L .40148 .56924 L F
.962 .8 .363 r
.40039 .57086 m .40148 .56924 L .40042 .56866 L F
.40039 .57086 m .40123 .5727 L .40148 .56924 L F
.562 .353 .554 r
.4723 .48952 m .47248 .49252 L .46976 .49324 L F
.599 .423 .615 r
.47493 .4892 m .47248 .49252 L .4723 .48952 L F
0 0 .324 r
.40087 .65614 m .40198 .65887 L .4022 .65975 L F
.879 .788 .295 r
.4022 .65975 m .40151 .6613 L .40268 .66256 L F
.4022 .65975 m .40198 .65887 L .40151 .6613 L F
.444 .128 .334 r
.43429 .54447 m .43369 .5465 L .4311 .54687 L F
.783 .463 .447 r
.43777 .54688 m .43429 .54447 L .43662 .54348 L F
.43777 .54688 m .43369 .5465 L .43429 .54447 L F
.066 0 0 r
.26734 .57623 m .26798 .57635 L .26541 .57562 L F
.26734 .57623 m .26993 .57636 L .26798 .57635 L F
.594 .135 0 r
.37264 .51272 m .3748 .51562 L .3744 .51499 L F
.882 .449 .094 r
.3748 .51562 m .37676 .51778 L .3744 .51499 L F
.703 .227 0 r
.58968 .39327 m .59133 .39506 L .59144 .39435 L F
.119 .644 .878 r
.59133 .39506 m .59332 .3948 L .59144 .39435 L F
.59133 .39506 m .59524 .39533 L .59332 .3948 L F
.821 .753 .788 r
.41341 .48046 m .40928 .48049 L .41195 .47962 L F
.41341 .48046 m .41093 .48334 L .40928 .48049 L F
.65 .925 .975 r
.41341 .48046 m .41427 .47829 L .41594 .47949 L F
.41341 .48046 m .41195 .47962 L .41427 .47829 L F
.199 .07 .47 r
.33166 .58774 m .33028 .586 L .33117 .58514 L F
.33166 .58774 m .33012 .58868 L .33028 .586 L F
.863 .883 .85 r
.26292 .54098 m .26345 .53698 L .26504 .53909 L F
.26292 .54098 m .26111 .5399 L .26345 .53698 L F
.343 .703 .984 r
.26292 .54098 m .2635 .5396 L .26111 .5399 L F
.26292 .54098 m .26544 .54083 L .2635 .5396 L F
.57 .519 .759 r
.47609 .4795 m .47398 .48258 L .47338 .48024 L F
.47609 .4795 m .47649 .48197 L .47398 .48258 L F
.518 .419 .682 r
.4771 .48641 m .47398 .48258 L .47649 .48197 L F
.4771 .48641 m .47598 .48822 L .47398 .48258 L F
.847 .961 .88 r
.69494 .34809 m .69115 .34973 L .69419 .34697 L F
.927 .973 .712 r
.69639 .34348 m .69494 .34809 L .69419 .34697 L F
.958 .885 .718 r
.61986 .40014 m .61919 .39771 L .61842 .39908 L F
0 .17 .611 r
.62251 .4019 m .61986 .40014 L .61842 .39908 L F
.04 .601 .801 r
.32985 .4938 m .32915 .49405 L .32749 .49436 L F
.32985 .4938 m .33199 .49418 L .32915 .49405 L F
0 0 0 r
.42248 .49524 m .42078 .49668 L .41949 .49791 L F
.805 .862 .891 r
.61133 .38168 m .61565 .38064 L .61305 .3797 L F
.696 .94 .962 r
.61682 .37842 m .61565 .38064 L .61816 .37907 L F
.651 .89 .983 r
.61305 .3797 m .61565 .38064 L .61682 .37842 L F
.442 .024 .149 r
.30003 .56563 m .29671 .56753 L .29817 .56561 L F
.563 .643 .888 r
.43317 .59564 m .43621 .59965 L .43429 .59797 L F
.511 .769 .99 r
.43429 .59797 m .43621 .59965 L .43871 .59898 L F
.011 0 0 r
.24648 .57338 m .24827 .57346 L .2451 .57421 L F
.24648 .57338 m .24914 .5729 L .24827 .57346 L F
.664 .118 0 r
.40087 .67046 m .4005 .66932 L .4007 .66845 L F
.962 .893 .512 r
.4007 .66845 m .39901 .67054 L .40081 .67046 L F
.664 .118 0 r
.40087 .67046 m .4016 .67064 L .4005 .66932 L F
.962 .893 .512 r
.4007 .66845 m .40081 .67046 L .40087 .67046 L F
0 0 .123 r
.40061 .66683 m .4007 .66845 L .4005 .66932 L F
.40066 .66569 m .4007 .66845 L .40061 .66683 L F
.727 .77 .887 r
.44801 .4622 m .44972 .46369 L .44572 .46314 L F
.704 .767 .901 r
.4522 .4627 m .44972 .46369 L .44801 .4622 L F
.802 .634 .673 r
.3362 .63126 m .33663 .63397 L .33177 .63292 L F
0 0 .459 r
.33635 .62999 m .3362 .63126 L .33523 .62719 L F
.504 .168 .331 r
.33916 .6331 m .33897 .63058 L .3362 .63126 L F
.288 .271 .666 r
.33916 .6331 m .3362 .63126 L .33897 .63058 L F
.504 .168 .331 r
.33916 .6331 m .3362 .63126 L .33635 .62999 L F
.288 .271 .666 r
.33916 .6331 m .33663 .63397 L .3362 .63126 L F
.957 .679 .47 r
.54885 .41239 m .54718 .40883 L .54758 .41191 L F
0 0 0 r
.54948 .41298 m .55166 .40971 L .54885 .41239 L F
.407 0 0 r
.54948 .41298 m .54885 .41239 L .54758 .41191 L F
.357 .809 .943 r
.59699 .46388 m .59601 .4634 L .59309 .46395 L F
.678 .977 .888 r
.59832 .46195 m .59699 .46388 L .59965 .46187 L F
.662 .96 .937 r
.59832 .46195 m .59601 .4634 L .59699 .46388 L F
.811 .977 .685 r
.42625 .59365 m .42526 .59634 L .42811 .59261 L F
.675 .555 .711 r
.43024 .58946 m .42811 .59261 L .4284 .59034 L F
.616 .14 .101 r
.43037 .59284 m .42625 .59365 L .42811 .59261 L F
.675 .555 .711 r
.43024 .58946 m .42811 .59261 L .4284 .59034 L F
.73 .726 .847 r
.65553 .38019 m .65641 .38377 L .65245 .38309 L F
.894 .872 .809 r
.65641 .38377 m .65261 .38575 L .65245 .38309 L F
.65641 .38377 m .65399 .38725 L .65261 .38575 L F
.875 .859 .821 r
.65748 .37897 m .65641 .38377 L .65553 .38019 L F
.65748 .37897 m .65891 .38048 L .65641 .38377 L F
.639 .827 .973 r
.44143 .54667 m .43777 .54688 L .44034 .54596 L F
.573 .133 .167 r
.44143 .54667 m .44 .54867 L .43777 .54688 L F
.882 .901 .839 r
.42214 .57201 m .42628 .56983 L .42522 .56839 L F
0 .09 .597 r
.42628 .56983 m .4273 .57062 L .42522 .56839 L F
.584 .85 .503 r
.42305 .57094 m .42214 .57201 L .42522 .56839 L F
.705 .559 .685 r
.42511 .56852 m .4273 .57062 L .42305 .57094 L F
.42522 .56839 m .4273 .57062 L .42511 .56852 L F
0 .09 .597 r
.42628 .56983 m .42844 .57171 L .4273 .57062 L F
.42844 .57171 m .42873 .57197 L .4273 .57062 L F
.308 0 0 r
.46323 .58561 m .46175 .58757 L .45915 .58799 L F
.353 0 0 r
.4659 .58545 m .46175 .58757 L .46323 .58561 L F
.838 .691 .699 r
.3993 .65295 m .40172 .65341 L .3997 .64963 L F
.845 .643 .629 r
.40087 .65614 m .40172 .65341 L .3993 .65295 L F
.563 .365 .571 r
.35754 .55991 m .35731 .5633 L .35393 .56287 L F
.635 .461 .63 r
.35767 .56593 m .35393 .56287 L .35731 .5633 L F
.35767 .56593 m .35496 .56642 L .35393 .56287 L F
.643 .504 .678 r
.48004 .46658 m .47737 .46983 L .47744 .46721 L F
.849 .859 .85 r
.66165 .37733 m .65891 .38048 L .65748 .37897 L F
.9 .929 .827 r
.70328 .28495 m .70561 .28502 L .7047 .28339 L F
.535 .328 .547 r
.33042 .61059 m .32778 .60843 L .33076 .60772 L F
.33042 .61059 m .32758 .61141 L .32778 .60843 L F
.356 .695 .983 r
.27737 .63979 m .28134 .64123 L .27967 .64174 L F
.715 .199 0 r
.27967 .64174 m .28134 .64123 L .28262 .64293 L F
.903 .858 .412 r
.38209 .57962 m .38122 .58226 L .38123 .58096 L F
.673 .947 .959 r
.61463 .36378 m .61539 .36448 L .61673 .36237 L F
.61463 .36378 m .61539 .36448 L .61673 .36237 L F
.587 .745 .952 r
.33573 .49526 m .33327 .49602 L .33199 .49418 L F
.045 0 .229 r
.2425 .57535 m .23989 .5786 L .24027 .57614 L F
.016 0 .233 r
.30173 .62461 m .30259 .62601 L .30315 .62359 L F
.30173 .62461 m .30101 .62713 L .30259 .62601 L F
0 0 .246 r
.27512 .54022 m .27507 .54234 L .27321 .54383 L F
.5 .183 .36 r
.34738 .58447 m .34878 .58252 L .34703 .5815 L F
.34738 .58447 m .34863 .58437 L .34878 .58252 L F
.644 .435 .584 r
.34863 .58437 m .35045 .58218 L .34878 .58252 L F
0 0 0 r
.36826 .58777 m .36963 .58575 L .37117 .58493 L F
.629 .426 .589 r
.36211 .69144 m .36388 .68813 L .36248 .68868 L F
.36211 .69144 m .36588 .69107 L .36388 .68813 L F
.001 .301 .795 r
.36532 .6872 m .36388 .68813 L .36729 .69046 L F
.324 .323 .704 r
.36388 .68813 m .36588 .69107 L .36729 .69046 L F
.645 .755 .929 r
.73225 .3323 m .72807 .331 L .73115 .33063 L F
.275 .609 .955 r
.7342 .3315 m .73225 .3323 L .73115 .33063 L F
.674 .752 .909 r
.7342 .3315 m .7323 .33553 L .73225 .3323 L F
.666 .641 .815 r
.36192 .6989 m .35987 .6951 L .3596 .69727 L F
.36192 .6989 m .36207 .69413 L .35987 .6951 L F
.96 .815 .656 r
.36037 .69832 m .36192 .6989 L .3596 .69727 L F
0 .04 .593 r
.35984 .69748 m .36037 .69832 L .3596 .69727 L F
.537 .435 .686 r
.36252 .69853 m .36287 .69999 L .36255 .70009 L F
.96 .815 .656 r
.36037 .69832 m .36106 .70161 L .36153 .70015 L F
.36037 .69832 m .36153 .70015 L .36192 .6989 L F
.567 .582 .828 r
.36037 .69832 m .36106 .70161 L .35858 .70016 L F
.35858 .70016 m .36106 .70161 L .36037 .69832 L F
.566 .581 .828 r
.36353 .70077 m .36106 .70161 L .36037 .69832 L F
.36353 .70077 m .36203 .69961 L .36157 .70054 L F
.36203 .69961 m .36037 .69832 L .36074 .699 L F
.36203 .69961 m .36074 .699 L .36157 .70054 L F
0 0 .495 r
.36168 .70021 m .36037 .69832 L .36195 .69937 L F
.36157 .70054 m .3614 .70022 L .36168 .70021 L F
.3614 .70022 m .36037 .69832 L .36168 .70021 L F
.119 .664 .825 r
.36347 .70039 m .36353 .70077 L .36157 .70054 L F
0 0 0 r
.36347 .70039 m .36157 .70054 L .36043 .70076 L F
.36347 .70039 m .36043 .70076 L .36287 .69999 L F
.617 .587 .797 r
.3612 .70326 m .36287 .69999 L .36043 .70076 L F
0 0 0 r
.36043 .70076 m .36222 .70019 L .36102 .70091 L F
.36222 .70019 m .36287 .69999 L .36248 .70018 L F
.36222 .70019 m .36248 .70018 L .36102 .70091 L F
0 .04 .593 r
.36195 .69937 m .36037 .69832 L .36191 .69932 L F
.658 .953 .73 r
.36037 .69832 m .35858 .70016 L .3569 .70119 L F
.3569 .70119 m .35858 .70016 L .36037 .69832 L F
.79 .682 .746 r
.35536 .69974 m .36037 .69832 L .3569 .70119 L F
.35536 .69974 m .36037 .69832 L .3569 .70119 L F
0 .04 .593 r
.36152 .6992 m .3596 .69727 L .35759 .69754 L F
.537 .435 .686 r
.36189 .69931 m .36195 .69937 L .36194 .69938 L F
.36191 .69932 m .36195 .69937 L .36189 .69931 L F
.36185 .69925 m .36194 .69938 L .36179 .69932 L F
.36252 .69853 m .36255 .70009 L .36185 .69925 L F
0 .04 .593 r
.36201 .6994 m .36195 .69937 L .36191 .69932 L F
.36201 .6994 m .36191 .69932 L .36181 .69929 L F
.537 .435 .686 r
.36185 .69925 m .36191 .69932 L .36189 .69931 L F
.36252 .69853 m .36181 .69929 L .36201 .6994 L F
.36179 .69932 m .36194 .69938 L .36043 .70076 L F
.36195 .69937 m .36255 .70009 L .36222 .70019 L F
0 0 .495 r
.36198 .69947 m .36195 .69937 L .36201 .6994 L F
.537 .435 .686 r
.36181 .69929 m .36043 .70076 L .36201 .6994 L F
0 .04 .593 r
.36201 .6994 m .36181 .69929 L .36152 .6992 L F
.36191 .69932 m .36037 .69832 L .35984 .69748 L F
.36191 .69932 m .3596 .69727 L .36152 .6992 L F
.912 .536 .297 r
.35494 .69617 m .35759 .69754 L .35645 .69404 L F
.522 .219 .395 r
.3596 .69727 m .35645 .69404 L .35759 .69754 L F
0 .329 .693 r
.36201 .6994 m .36152 .6992 L .35634 .69687 L F
.36152 .6992 m .35807 .69774 L .3575 .69746 L F
.36152 .6992 m .3575 .69746 L .35634 .69687 L F
.35807 .69774 m .35759 .69754 L .35723 .69735 L F
.35807 .69774 m .35723 .69735 L .35634 .69687 L F
0 0 .495 r
.36157 .70054 m .36195 .69937 L .36198 .69947 L F
.36157 .70054 m .36198 .69947 L .36043 .70076 L F
.537 .435 .686 r
.36195 .69937 m .36198 .69947 L .36043 .70076 L F
0 0 .495 r
.36198 .69947 m .36201 .6994 L .36043 .70076 L F
.537 .435 .686 r
.36198 .69947 m .36222 .70019 L .36043 .70076 L F
.945 .583 .235 r
.61044 .41736 m .61217 .41888 L .61271 .4214 L F
.692 .579 .724 r
.41601 .49272 m .41333 .49341 L .412 .48964 L F
.143 0 0 r
.60629 .46088 m .60787 .46166 L .60577 .46209 L F
.60629 .46088 m .60928 .46026 L .60787 .46166 L F
.587 .384 .574 r
.31942 .66851 m .32094 .66451 L .31727 .66661 L F
.956 .683 .48 r
.60815 .43911 m .61035 .43817 L .60812 .43682 L F
.60815 .43911 m .61046 .44103 L .61035 .43817 L F
.395 0 .139 r
.55413 .41098 m .55166 .40971 L .54948 .41298 L F
.55413 .41098 m .5543 .40931 L .55166 .40971 L F
.761 .96 .934 r
.25002 .52878 m .24667 .53088 L .25005 .52932 L F
.112 .277 .754 r
.42777 .58861 m .42899 .58895 L .4284 .59034 L F
.606 .116 0 r
.42525 .58467 m .42899 .58895 L .42777 .58861 L F
.81 .658 .694 r
.42347 .58348 m .42951 .58411 L .42538 .58132 L F
.4218 .58537 m .42482 .58487 L .42347 .58348 L F
.647 .146 0 r
.42579 .58588 m .4275 .58764 L .42525 .58467 L F
.42761 .58779 m .42831 .58832 L .42525 .58467 L F
.606 .116 0 r
.42525 .58467 m .42831 .58832 L .42899 .58895 L F
.42831 .58832 m .42945 .58969 L .42899 .58895 L F
.675 .555 .711 r
.42926 .58907 m .4292 .58915 L .42899 .58895 L F
.4292 .58915 m .4284 .59034 L .42899 .58895 L F
.647 .146 0 r
.42581 .58591 m .42525 .58467 L .42951 .58411 L F
.81 .658 .694 r
.42482 .58487 m .42951 .58411 L .42347 .58348 L F
.647 .146 0 r
.42581 .58591 m .42761 .58779 L .4275 .58764 L F
.42581 .58591 m .4275 .58764 L .42579 .58588 L F
.675 .555 .711 r
.42995 .5896 m .4284 .59034 L .42926 .58907 L F
.647 .146 0 r
.42761 .58779 m .42945 .58969 L .42831 .58832 L F
.675 .555 .711 r
.43024 .58946 m .42995 .5896 L .42926 .58907 L F
.126 .622 .909 r
.3373 .69835 m .33766 .69762 L .33527 .69759 L F
.3373 .69835 m .33964 .69864 L .33766 .69762 L F
0 0 .565 r
.43876 .58328 m .4399 .5835 L .44023 .58129 L F
.43876 .58328 m .43966 .58576 L .4399 .5835 L F
.834 .841 .851 r
.68779 .3789 m .692 .37744 L .69033 .37595 L F
.441 0 0 r
.28457 .63145 m .28288 .63031 L .28108 .62935 L F
.368 .382 .743 r
.28618 .63358 m .28288 .63031 L .28457 .63145 L F
.504 .148 .297 r
.69899 .30361 m .70164 .30517 L .699 .30597 L F
.69899 .30361 m .70222 .30335 L .70164 .30517 L F
.212 0 .254 r
.29465 .65998 m .29719 .65621 L .29775 .65974 L F
.71 .499 .601 r
.30046 .65634 m .29775 .65974 L .29719 .65621 L F
.95 .843 .703 r
.39138 .6139 m .394 .61125 L .39333 .61031 L F
.39138 .6139 m .39303 .61493 L .394 .61125 L F
0 0 0 r
.54496 .40892 m .54191 .41221 L .54507 .41118 L F
.704 .44 .523 r
.54507 .41118 m .54718 .40883 L .54496 .40892 L F
.423 .544 .874 r
.33395 .63625 m .33012 .63469 L .33177 .63292 L F
0 0 .121 r
.33082 .6399 m .33339 .6369 L .33223 .63888 L F
.33339 .6369 m .33395 .63625 L .33223 .63888 L F
0 0 .071 r
.3307 .64202 m .33082 .6399 L .33223 .63888 L F
.997 .838 .562 r
.33129 .64048 m .33223 .63888 L .33118 .63727 L F
0 0 .071 r
.3307 .64202 m .33223 .63888 L .3313 .64103 L F
.997 .838 .562 r
.3313 .64103 m .33223 .63888 L .33129 .64048 L F
.786 .427 .378 r
.33177 .63292 m .33594 .63629 L .33395 .63625 L F
.813 .924 .541 r
.33223 .63888 m .33395 .63625 L .33433 .6354 L F
.33402 .6358 m .33433 .6354 L .33455 .63489 L F
.33223 .63888 m .33433 .6354 L .33402 .6358 L F
.786 .427 .378 r
.33452 .63515 m .33663 .63397 L .33594 .63629 L F
.33177 .63292 m .33558 .63374 L .33452 .63515 L F
.33558 .63374 m .33663 .63397 L .33452 .63515 L F
.78 .773 .846 r
.33916 .6331 m .33594 .63629 L .33663 .63397 L F
.892 .985 .802 r
.27935 .53662 m .27773 .53884 L .27896 .5385 L F
0 .25 .756 r
.59194 .40431 m .59163 .40506 L .58998 .40189 L F
.841 .751 .763 r
.5202 .43499 m .51688 .43475 L .5193 .43106 L F
.848 .723 .726 r
.5202 .43499 m .51817 .43835 L .51688 .43475 L F
.556 .525 .776 r
.33826 .55061 m .33989 .5548 L .34166 .55368 L F
.432 .846 .674 r
.33989 .5548 m .33833 .55568 L .34166 .55368 L F
.591 .777 .969 r
.54769 .39053 m .5434 .38947 L .54599 .38875 L F
.54769 .39053 m .5434 .38947 L .54599 .38875 L F
.66 .813 .957 r
.54599 .38875 m .54769 .39053 L .54985 .38914 L F
.54599 .38875 m .54769 .39053 L .54985 .38914 L F
.65 .372 .484 r
.30716 .64241 m .30493 .63969 L .30156 .64384 L F
.30716 .64241 m .30756 .64016 L .30493 .63969 L F
0 0 .537 r
.63884 .42121 m .63961 .4233 L .63908 .42061 L F
.831 .841 .854 r
.63908 .42061 m .63961 .4233 L .64381 .41877 L F
.67 .633 .804 r
.33496 .56007 m .33052 .55854 L .33299 .55963 L F
.361 .811 .945 r
.33292 .56242 m .33496 .56007 L .33299 .55963 L F
.902 .907 .817 r
.33496 .56007 m .33299 .55963 L .33566 .55679 L F
.882 .659 .595 r
.33292 .56242 m .33496 .56007 L .33299 .55963 L F
.33292 .56242 m .33422 .56338 L .33496 .56007 L F
.986 .747 .49 r
.34935 .57037 m .34857 .57241 L .34999 .57252 L F
.561 .548 .798 r
.3511 .56919 m .34999 .57252 L .34935 .57037 L F
.3511 .56919 m .35245 .57229 L .34999 .57252 L F
.525 .914 .922 r
.34999 .57252 m .34857 .57241 L .35086 .57137 L F
.34999 .57252 m .34857 .57241 L .35086 .57137 L F
.973 .662 .316 r
.69749 .33509 m .69675 .33665 L .69606 .33398 L F
.957 .643 .388 r
.58407 .39852 m .58592 .39871 L .58559 .39653 L F
.397 .144 .41 r
.25737 .55566 m .25539 .55384 L .25838 .5536 L F
.25737 .55566 m .25505 .55636 L .25539 .55384 L F
.24 .018 .362 r
.21442 .56026 m .21596 .55969 L .21662 .55705 L F
0 0 0 r
.21384 .56262 m .21596 .55969 L .21442 .56026 L F
.987 .756 .501 r
.29276 .6235 m .29429 .62531 L .292 .62591 L F
.306 .494 .878 r
.29429 .62531 m .29516 .62311 L .29276 .6235 L F
.29429 .62531 m .29731 .62428 L .29516 .62311 L F
.531 0 0 r
.37208 .67605 m .37334 .67425 L .37091 .67469 L F
.494 .313 .564 r
.37208 .67605 m .37271 .67912 L .37486 .67793 L F
.531 0 0 r
.37208 .67605 m .37486 .67793 L .3723 .67673 L F
.37208 .67605 m .3723 .67673 L .37334 .67425 L F
.63 .767 .945 r
.32589 .63075 m .3268 .62755 L .32424 .62712 L F
.32589 .63075 m .32868 .62973 L .3268 .62755 L F
.686 .879 .97 r
.39516 .59552 m .39119 .59566 L .39315 .59428 L F
.957 .631 .229 r
.32374 .62444 m .32003 .62588 L .32078 .62446 L F
.32374 .62444 m .32303 .62535 L .32003 .62588 L F
.32374 .62444 m .32424 .62712 L .32303 .62535 L F
.918 .536 .124 r
.42801 .55853 m .43022 .56223 L .42734 .56034 L F
.781 .941 .931 r
.70708 .34408 m .71133 .34261 L .71013 .3412 L F
.853 .885 .862 r
.71013 .3412 m .71133 .34261 L .71432 .33938 L F
.716 .653 .787 r
.28785 .52609 m .28634 .52593 L .28836 .52515 L F
0 0 0 r
.38063 .61708 m .37947 .61684 L .37791 .61667 L F
.38063 .61708 m .38199 .6149 L .37947 .61684 L F
0 .192 .713 r
.37947 .61684 m .38063 .61708 L .37791 .61667 L F
.37947 .61684 m .38244 .61928 L .38063 .61708 L F
.901 .881 .805 r
.39073 .61846 m .39303 .61493 L .39138 .6139 L F
.563 .481 .72 r
.46359 .51442 m .46166 .51882 L .46107 .51511 L F
.46359 .51442 m .46434 .51818 L .46166 .51882 L F
.553 .427 .662 r
.46434 .51818 m .4622 .52154 L .46166 .51882 L F
.866 .84 .817 r
.62306 .43395 m .62765 .43194 L .62553 .43064 L F
.62306 .43395 m .62476 .4356 L .62765 .43194 L F
.889 .816 .77 r
.62553 .43064 m .62765 .43194 L .6293 .42795 L F
.832 .945 .897 r
.67632 .32703 m .68025 .32516 L .67916 .32418 L F
.869 .88 .842 r
.67916 .32418 m .68025 .32516 L .68238 .32232 L F
.783 .51 .524 r
.42406 .48283 m .42366 .48556 L .41959 .48501 L F
.366 .137 .429 r
.42406 .48283 m .42366 .48556 L .42623 .48229 L F
.42406 .48283 m .42366 .48556 L .42623 .48229 L F
.901 .881 .805 r
.39073 .61846 m .39138 .6139 L .38976 .6168 L F
.932 .908 .774 r
.38797 .6196 m .39073 .61846 L .38976 .6168 L F
.38797 .6196 m .38942 .62055 L .39073 .61846 L F
.738 .931 .953 r
.47613 .45069 m .47743 .45162 L .47529 .45251 L F
.666 .909 .978 r
.47977 .45036 m .47743 .45162 L .47613 .45069 L F
.512 .854 .586 r
.30013 .54973 m .30354 .54682 L .301 .54728 L F
.71 .529 .642 r
.30354 .54682 m .30013 .54973 L .301 .54728 L F
.355 .639 .961 r
.27371 .6178 m .27361 .62006 L .27091 .61825 L F
.27371 .6178 m .27579 .62001 L .27361 .62006 L F
.626 .094 0 r
.56767 .42659 m .57025 .42815 L .57111 .42634 L F
.531 .489 .754 r
.57111 .42634 m .57266 .42291 L .57009 .42383 L F
.57111 .42634 m .57406 .4244 L .57266 .42291 L F
.57111 .42634 m .57384 .42616 L .57406 .4244 L F
.643 .504 .678 r
.48004 .46658 m .48116 .47026 L .47737 .46983 L F
.67 .53 .685 r
.48116 .47026 m .47871 .47317 L .47737 .46983 L F
.549 .113 .163 r
.29156 .51356 m .29461 .51531 L .29655 .51182 L F
0 0 0 r
.29655 .51182 m .29839 .51113 L .29894 .5111 L F
.842 .994 .746 r
.29869 .5118 m .29741 .51365 L .29966 .51238 L F
.29795 .51135 m .29767 .51256 L .29869 .5118 L F
.29767 .51256 m .29741 .51365 L .29869 .5118 L F
0 0 0 r
.29655 .51182 m .29504 .51453 L .29839 .51113 L F
.29504 .51453 m .29461 .51531 L .29588 .5139 L F
.29504 .51453 m .29588 .5139 L .29839 .51113 L F
.162 0 .016 r
.35827 .59544 m .35701 .59773 L .35492 .59814 L F
.103 0 0 r
.35911 .59681 m .35827 .59544 L .35992 .59397 L F
.35911 .59681 m .35701 .59773 L .35827 .59544 L F
0 0 .465 r
.38142 .52008 m .3824 .52152 L .38002 .51824 L F
.708 .268 0 r
.38265 .52259 m .3824 .52152 L .38142 .52008 L F
.38265 .52259 m .38381 .52406 L .3824 .52152 L F
0 0 0 r
.29747 .67213 m .30082 .66913 L .30099 .66873 L F
.987 .754 .495 r
.40119 .58745 m .40197 .58548 L .40053 .58481 L F
.311 0 .09 r
.41798 .48647 m .41736 .48835 L .41443 .48893 L F
.817 .707 .744 r
.41959 .48501 m .41736 .48835 L .41798 .48647 L F
.584 .532 .762 r
.46423 .53346 m .46264 .53768 L .46176 .53409 L F
.46423 .53346 m .46522 .53697 L .46264 .53768 L F
.55 .246 .404 r
.27329 .56862 m .27744 .56557 L .27505 .56651 L F
.572 .868 .558 r
.25583 .55153 m .2541 .55314 L .25553 .55157 L F
.713 .742 .875 r
.57247 .46419 m .57709 .46661 L .5758 .46357 L F
.72 .755 .881 r
.5758 .46357 m .57709 .46661 L .5799 .46388 L F
0 0 .222 r
.37853 .58738 m .37727 .59193 L .37754 .58885 L F
.658 .515 .678 r
.314 .6245 m .31189 .62775 L .31126 .62446 L F
.771 .977 .915 r
.42331 .59513 m .42526 .59634 L .42625 .59365 L F
.961 .943 .66 r
.33797 .5049 m .33737 .50654 L .33878 .50569 L F
.721 .767 .889 r
.43612 .52464 m .43371 .52588 L .4321 .52411 L F
.243 0 .269 r
.34935 .60465 m .34662 .60756 L .34681 .6049 L F
.947 .689 .515 r
.28991 .64295 m .29188 .64356 L .29067 .64029 L F
.545 .512 .77 r
.29188 .64356 m .29333 .63921 L .29067 .64029 L F
.29188 .64356 m .29428 .64303 L .29333 .63921 L F
.437 .169 .408 r
.29397 .64647 m .29188 .64356 L .28991 .64295 L F
.29397 .64647 m .29428 .64303 L .29188 .64356 L F
.655 .52 .686 r
.34144 .6918 m .33947 .69501 L .33953 .69205 L F
.849 .977 .674 r
.69642 .36226 m .69871 .35894 L .69873 .35779 L F
0 0 0 r
.69755 .36029 m .69642 .36226 L .69774 .35984 L F
.697 .94 .642 r
.69534 .36413 m .69805 .3611 L .69642 .36226 L F
.824 .966 .646 r
.69642 .36226 m .69805 .3611 L .69871 .35894 L F
0 0 .325 r
.69516 .36681 m .69642 .36226 L .69611 .36466 L F
.714 .657 .104 r
.69622 .36358 m .69611 .36466 L .69642 .36226 L F
0 0 0 r
.69622 .36358 m .69642 .36226 L .69755 .36029 L F
.697 .94 .642 r
.6951 .3644 m .69534 .36413 L .69642 .36226 L F
0 0 .325 r
.69516 .36681 m .6951 .3644 L .69642 .36226 L F
.43 .447 .776 r
.62965 .40181 m .6315 .39831 L .62954 .40051 L F
.409 .478 .82 r
.47007 .54957 m .46948 .55367 L .46786 .54999 L F
.47007 .54957 m .47132 .5528 L .46948 .55367 L F
.286 .185 .561 r
.47132 .5528 m .47156 .55569 L .46948 .55367 L F
.156 .172 .626 r
.46948 .55367 m .47156 .55569 L .47017 .5561 L F
.443 .328 .628 r
.71689 .28266 m .71475 .28398 L .71412 .28103 L F
.524 .282 .491 r
.71412 .28103 m .71706 .28039 L .71689 .28266 L F
.443 .328 .628 r
.71412 .28103 m .71475 .28398 L .71689 .28266 L F
.524 .282 .491 r
.71689 .28266 m .71706 .28039 L .71412 .28103 L F
.449 .326 .621 r
.69137 .32981 m .69444 .3306 L .69345 .32745 L F
.8 .755 .812 r
.33594 .63629 m .3409 .63763 L .33802 .64026 L F
.03 0 .385 r
.33789 .64342 m .33945 .63909 L .33929 .64148 L F
.68 .428 .534 r
.33945 .63909 m .33947 .63958 L .33923 .63933 L F
0 0 0 r
.33802 .64026 m .33994 .63851 L .33945 .63909 L F
.33994 .63851 m .34039 .6381 L .33945 .63909 L F
.68 .428 .534 r
.33945 .63909 m .33923 .63933 L .33849 .6386 L F
0 0 0 r
.33802 .64026 m .3409 .63763 L .33945 .63909 L F
.822 .706 .17 r
.33862 .64008 m .33945 .63909 L .33849 .6386 L F
.03 0 .385 r
.33789 .64342 m .33802 .64026 L .33945 .63909 L F
.822 .706 .17 r
.33876 .6416 m .33945 .63909 L .33862 .64008 L F
0 0 0 r
.34039 .6381 m .3409 .63763 L .33945 .63909 L F
.83 .925 .896 r
.65282 .34325 m .65712 .3418 L .65582 .34023 L F
.757 .869 .93 r
.65582 .34023 m .65712 .3418 L .65971 .3402 L F
.737 .815 .913 r
.61913 .35147 m .61534 .3513 L .61782 .35002 L F
.769 .877 .925 r
.62202 .34927 m .61913 .35147 L .61782 .35002 L F
.768 .756 .842 r
.61993 .43659 m .62476 .4356 L .62306 .43395 L F
.729 .404 .429 r
.26889 .5702 m .27231 .57248 L .27097 .56904 L F
.26889 .5702 m .26813 .5724 L .27231 .57248 L F
.78 .773 .846 r
.33916 .6331 m .3409 .63763 L .33594 .63629 L F
.566 .654 .895 r
.34306 .63681 m .3409 .63763 L .33916 .6331 L F
.034 0 0 r
.33945 .63909 m .3409 .63763 L .34306 .63681 L F
0 0 .496 r
.47156 .55569 m .47114 .5601 L .47017 .5561 L F
.47156 .55569 m .47209 .55827 L .47114 .5601 L F
.216 .229 .658 r
.47209 .55827 m .47111 .5626 L .47114 .5601 L F
.692 .579 .724 r
.41601 .49272 m .412 .48964 L .41443 .48893 L F
.662 .157 .036 r
.37929 .49908 m .38312 .49871 L .38047 .49962 L F
.79 .637 .692 r
.56246 .40459 m .56536 .39934 L .56294 .39929 L F
0 .351 .767 r
.33082 .55819 m .33052 .55854 L .328 .55728 L F
.33082 .55819 m .33299 .55963 L .33052 .55854 L F
.771 .61 .044 r
.30079 .66742 m .30094 .66596 L .30157 .66492 L F
0 0 .014 r
.30079 .66742 m .30157 .66492 L .30227 .66403 L F
.137 0 .381 r
.30291 .6662 m .30079 .66742 L .30227 .66403 L F
.387 .828 .692 r
.30064 .66734 m .30079 .66742 L .30291 .6662 L F
.424 .796 .994 r
.29733 .66724 m .30099 .66873 L .30079 .66742 L F
.309 0 0 r
.29783 .66745 m .30079 .66742 L .29921 .66804 L F
.29733 .66724 m .29942 .66735 L .29783 .66745 L F
.29942 .66735 m .30079 .66742 L .29783 .66745 L F
.85 .869 .855 r
.29747 .67213 m .30099 .66873 L .29733 .66724 L F
.205 0 .2 r
.29733 .66724 m .29789 .66499 L .29555 .66736 L F
.083 0 .155 r
.30004 .66528 m .29789 .66499 L .29733 .66724 L F
.309 0 0 r
.29733 .66724 m .29921 .66804 L .29733 .66755 L F
.083 0 .155 r
.30004 .66528 m .29733 .66724 L .29733 .66755 L F
.792 .921 .924 r
.29936 .66585 m .29741 .66748 L .29748 .66484 L F
.29741 .66748 m .29733 .66748 L .29748 .66484 L F
.29741 .66748 m .29733 .66755 L .29733 .66748 L F
.145 .34 .799 r
.29748 .66484 m .29733 .66755 L .29921 .66804 L F
0 .053 .619 r
.29748 .66484 m .29921 .66804 L .29954 .66729 L F
.7 .172 0 r
.29593 .66402 m .29748 .66484 L .29954 .66729 L F
.29566 .66377 m .29748 .66484 L .29593 .66402 L F
.792 .921 .924 r
.30004 .66528 m .29936 .66585 L .29748 .66484 L F
.387 .828 .692 r
.29921 .66804 m .30079 .66742 L .30064 .66734 L F
.771 .61 .044 r
.30079 .66742 m .30099 .66873 L .30096 .66752 L F
.30079 .66742 m .30096 .66752 L .30094 .66596 L F
.813 .952 .909 r
.58398 .37918 m .58162 .38028 L .58441 .37984 L F
.832 .627 .625 r
.58397 .37401 m .58441 .37984 L .58004 .37593 L F
.58397 .37401 m .58004 .37593 L .5822 .37536 L F
.935 .967 .701 r
.58347 .37299 m .5822 .37536 L .58397 .37401 L F
.58397 .37401 m .5822 .37536 L .58347 .37299 L F
.866 .526 .405 r
.58225 .37532 m .5848 .37662 L .58397 .37401 L F
.58225 .37538 m .5848 .37662 L .58225 .37532 L F
.73 .651 .771 r
.58441 .37984 m .58162 .38028 L .58004 .37593 L F
.56 .556 .806 r
.58004 .37593 m .58162 .38028 L .58484 .37916 L F
.869 .564 .468 r
.5822 .37536 m .58367 .37748 L .5848 .37662 L F
.58367 .37748 m .58484 .37916 L .58481 .37754 L F
.58367 .37748 m .58481 .37754 L .5848 .37662 L F
.866 .526 .405 r
.5822 .37536 m .58225 .37538 L .58225 .37532 L F
.56 .556 .806 r
.58004 .37593 m .58484 .37916 L .5822 .37536 L F
.883 .804 .767 r
.58128 .37131 m .5822 .37536 L .58347 .37299 L F
.58128 .37131 m .5822 .37536 L .58347 .37299 L F
0 0 .122 r
.58319 .3745 m .5822 .37739 L .5808 .37628 L F
.5822 .37739 m .58197 .37807 L .58149 .37735 L F
.5822 .37739 m .58149 .37735 L .5808 .37628 L F
.58319 .3745 m .58277 .37688 L .58224 .37766 L F
.58224 .37727 m .58224 .37766 L .58197 .37807 L F
.58319 .3745 m .58224 .37766 L .58224 .37727 L F
.76 .801 .886 r
.59845 .45705 m .60219 .45744 L .60003 .45505 L F
.214 0 0 r
.59848 .45969 m .60219 .45744 L .59845 .45705 L F
.59848 .45969 m .60124 .45904 L .60219 .45744 L F
.494 .704 .963 r
.60219 .45744 m .6038 .4554 L .60003 .45505 L F
0 0 0 r
.60286 .45783 m .60219 .45744 L .60124 .45904 L F
.60286 .45783 m .6038 .4554 L .60219 .45744 L F
0 0 .24 r
.69805 .3611 m .70019 .35691 L .69871 .35894 L F
.942 .785 .657 r
.38291 .68445 m .38546 .68252 L .38508 .68083 L F
.38291 .68445 m .38461 .68514 L .38546 .68252 L F
0 0 .245 r
.23722 .61753 m .23793 .61669 L .23782 .61425 L F
0 .191 .707 r
.23722 .61753 m .23896 .61938 L .23793 .61669 L F
.544 .036 0 r
.31426 .55473 m .31839 .55373 L .31571 .55407 L F
.821 .968 .898 r
.65429 .329 m .65033 .33069 L .65321 .32778 L F
.833 .934 .895 r
.65754 .32589 m .65429 .329 L .65321 .32778 L F
.761 .932 .579 r
.27184 .53733 m .27005 .53915 L .27074 .53754 L F
.497 .907 .851 r
.27184 .53733 m .27074 .53754 L .27264 .53644 L F
.368 .135 .425 r
.54181 .41503 m .54507 .41118 L .54191 .41221 L F
0 0 .103 r
.41736 .48835 m .41601 .49272 L .41443 .48893 L F
.669 .17 .052 r
.41688 .49148 m .41916 .4932 L .417 .49255 L F
0 0 .103 r
.41675 .49032 m .41688 .49148 L .41601 .49272 L F
.604 .921 .681 r
.41688 .49148 m .41403 .49395 L .41601 .49272 L F
.746 .993 .828 r
.4153 .49204 m .41403 .49395 L .41688 .49148 L F
.669 .17 .052 r
.41688 .49148 m .417 .49255 L .4153 .49204 L F
0 0 .103 r
.41736 .48835 m .41688 .49148 L .41675 .49032 L F
0 0 .46 r
.69444 .3306 m .69509 .33238 L .69606 .33398 L F
.999 .827 .496 r
.41423 .58598 m .41287 .58753 L .41265 .58448 L F
.41423 .58598 m .41386 .58876 L .41287 .58753 L F
.617 .668 .876 r
.24761 .59871 m .24668 .60119 L .24539 .5994 L F
.24761 .59871 m .24923 .60183 L .24668 .60119 L F
.497 .146 .302 r
.24923 .60183 m .24539 .60451 L .24668 .60119 L F
0 0 0 r
.28209 .52726 m .28443 .52666 L .28634 .52593 L F
.111 0 0 r
.28443 .52666 m .28836 .52515 L .28634 .52593 L F
.923 .896 .489 r
.5953 .35858 m .5942 .36047 L .59544 .35609 L F
.5942 .36047 m .59414 .36029 L .59544 .35609 L F
.673 .955 .949 r
.59442 .36116 m .59446 .36117 L .5942 .36047 L F
.92 .808 .72 r
.59366 .35746 m .59421 .36006 L .59032 .36002 L F
.59544 .35609 m .59496 .35763 L .59366 .35746 L F
.59496 .35763 m .59421 .36006 L .59366 .35746 L F
.59544 .35609 m .59089 .35959 L .59438 .35708 L F
.59089 .35959 m .59032 .36002 L .59091 .3596 L F
.59089 .35959 m .59091 .3596 L .59438 .35708 L F
.59414 .36029 m .59212 .36044 L .59181 .36037 L F
.59194 .36014 m .59181 .36037 L .59032 .36002 L F
.59414 .36029 m .59181 .36037 L .59194 .36014 L F
.146 .668 .881 r
.59212 .36044 m .59221 .36047 L .59017 .36079 L F
.59221 .36047 m .59323 .36085 L .59274 .36084 L F
.59221 .36047 m .59274 .36084 L .59017 .36079 L F
.477 0 0 r
.59221 .36047 m .59172 .36054 L .59164 .36068 L F
.59233 .36042 m .59218 .36045 L .59221 .36047 L F
.59218 .36045 m .59172 .36054 L .59221 .36047 L F
.112 .651 .85 r
.59323 .36085 m .59446 .36117 L .59017 .36079 L F
.673 .955 .949 r
.59221 .36047 m .59442 .36116 L .59414 .36029 L F
.112 .651 .85 r
.59397 .36086 m .59446 .36117 L .59323 .36085 L F
.673 .955 .949 r
.59379 .36105 m .59442 .36116 L .59435 .36114 L F
.59323 .36085 m .59435 .36114 L .59221 .36047 L F
.59379 .36105 m .59435 .36114 L .59323 .36085 L F
0 0 .362 r
.59164 .36068 m .59017 .36079 L .59148 .3609 L F
.59164 .36068 m .59148 .3609 L .59446 .36117 L F
0 0 0 r
.59172 .36054 m .59165 .36066 L .59164 .36068 L F
.59165 .36066 m .59043 .36289 L .59164 .36068 L F
.59194 .36016 m .59152 .36092 L .59172 .36054 L F
.59152 .36092 m .59043 .36289 L .59172 .36054 L F
.477 0 0 r
.59232 .36033 m .59194 .36016 L .59172 .36054 L F
.92 .808 .72 r
.59421 .36006 m .59332 .36023 L .59032 .36002 L F
.923 .896 .489 r
.5953 .35858 m .59446 .36117 L .5942 .36047 L F
.477 0 0 r
.59584 .3591 m .59194 .36016 L .59232 .36033 L F
.59584 .3591 m .59172 .36054 L .59233 .36042 L F
.673 .955 .949 r
.59221 .36047 m .59414 .36029 L .59233 .36042 L F
.92 .808 .72 r
.59414 .36029 m .59397 .36086 L .59212 .36044 L F
.146 .668 .881 r
.59032 .36002 m .59212 .36044 L .59017 .36079 L F
.772 .43 .408 r
.59017 .36079 m .59043 .36289 L .58643 .36222 L F
0 0 .362 r
.59164 .36068 m .59043 .36289 L .59017 .36079 L F
.694 .899 .97 r
.58912 .36175 m .59043 .36289 L .59194 .36016 L F
.51 0 0 r
.59423 .36149 m .59125 .35986 L .59194 .36016 L F
.772 .43 .408 r
.59017 .36079 m .58643 .36222 L .58902 .35895 L F
.146 .668 .881 r
.59032 .36002 m .59017 .36079 L .58902 .35895 L F
.652 .887 .539 r
.58712 .36135 m .58771 .36021 L .58902 .35895 L F
.58643 .36222 m .58771 .36021 L .58712 .36135 L F
0 .045 .605 r
.58952 .35696 m .59032 .36002 L .58902 .35895 L F
.878 .781 .751 r
.59438 .35708 m .59047 .35991 L .58952 .35696 L F
.59047 .35991 m .59032 .36002 L .59029 .35991 L F
.59047 .35991 m .59029 .35991 L .58952 .35696 L F
.487 .879 .963 r
.58803 .3596 m .58787 .35992 L .59034 .35936 L F
.58787 .35992 m .58771 .36021 L .58863 .35991 L F
.58787 .35992 m .58863 .35991 L .59034 .35936 L F
.92 .961 .79 r
.58952 .35696 m .58771 .36021 L .58654 .35976 L F
.487 .879 .963 r
.58654 .35976 m .58771 .36021 L .58803 .3596 L F
.698 .837 .949 r
.58771 .36021 m .59194 .36016 L .59034 .35936 L F
.51 0 0 r
.59125 .35986 m .59118 .35982 L .59194 .36016 L F
.59118 .35982 m .59034 .35936 L .59106 .35972 L F
.59118 .35982 m .59106 .35972 L .59194 .36016 L F
.703 .953 .68 r
.59669 .35386 m .5947 .35567 L .598 .35176 L F
.878 .781 .751 r
.59438 .35627 m .59007 .35697 L .59438 .35559 L F
.59395 .35707 m .59007 .35697 L .59438 .35627 L F
.933 .864 .749 r
.59438 .35559 m .59669 .35386 L .59438 .35708 L F
.59438 .35559 m .59365 .35662 L .59669 .35386 L F
.703 .953 .68 r
.5947 .35567 m .59365 .35662 L .595 .35512 L F
.5947 .35567 m .595 .35512 L .598 .35176 L F
.878 .781 .751 r
.59438 .35708 m .59395 .35707 L .59438 .35627 L F
.59007 .35697 m .58952 .35696 L .58966 .35692 L F
.59007 .35697 m .58966 .35692 L .59438 .35559 L F
.92 .808 .72 r
.59421 .36006 m .59414 .36029 L .59332 .36023 L F
.673 .955 .949 r
.59233 .36042 m .59414 .36029 L .59398 .3598 L F
.59164 .36068 m .59379 .36105 L .59221 .36047 L F
.146 .668 .881 r
.59212 .36044 m .59397 .36086 L .59323 .36085 L F
.923 .896 .489 r
.5942 .36047 m .59446 .36117 L .59397 .36086 L F
.673 .955 .949 r
.5942 .36047 m .59446 .36117 L .59398 .3598 L F
.59398 .3598 m .59446 .36117 L .59584 .3591 L F
.923 .896 .489 r
.5942 .36047 m .59397 .36086 L .59414 .36029 L F
.412 0 .049 r
.37783 .69059 m .38187 .68845 L .38003 .6875 L F
.37783 .69059 m .3824 .6889 L .38187 .68845 L F
.566 .596 .842 r
.38187 .68845 m .38291 .68445 L .38003 .6875 L F
.38187 .68845 m .38457 .6882 L .38291 .68445 L F
.69 .52 .651 r
.3824 .6889 m .38457 .6882 L .38187 .68845 L F
.705 .592 .727 r
.48516 .45725 m .48513 .46001 L .48254 .4607 L F
.671 .531 .686 r
.48513 .46001 m .48295 .46327 L .48254 .4607 L F
.481 .816 .999 r
.58893 .37895 m .5857 .38034 L .58484 .37916 L F
.101 0 0 r
.32324 .58617 m .31974 .58872 L .32196 .58773 L F
0 0 .023 r
.32196 .58773 m .32424 .58479 L .32324 .58617 L F
.625 .132 .061 r
.30716 .64612 m .30636 .64846 L .30357 .64945 L F
.30636 .64846 m .30559 .64885 L .30357 .64945 L F
0 0 .337 r
.30296 .64773 m .3032 .64939 L .30357 .64945 L F
.883 .905 .839 r
.29846 .65039 m .30016 .65132 L .30296 .64773 L F
.625 .132 .061 r
.30636 .64846 m .3063 .64864 L .30559 .64885 L F
.696 .51 .633 r
.30357 .64945 m .3063 .64864 L .30296 .64773 L F
.727 .42 .459 r
.30296 .64773 m .30476 .64927 L .30122 .64976 L F
.30476 .64927 m .30567 .65005 L .3035 .64991 L F
.30476 .64927 m .3035 .64991 L .30122 .64976 L F
.625 .132 .061 r
.30716 .64612 m .30898 .64675 L .3063 .64864 L F
.981 .728 .474 r
.5758 .46357 m .5766 .46121 L .57459 .45922 L F
.12 0 .167 r
.5758 .46357 m .5766 .46121 L .5786 .45991 L F
.378 0 0 r
.42899 .58895 m .43241 .58933 L .43024 .58946 L F
.629 .257 .319 r
.28551 .5736 m .28515 .57569 L .28338 .57494 L F
0 0 .144 r
.28731 .5736 m .28551 .5736 L .28792 .5718 L F
.28731 .5736 m .28515 .57569 L .28551 .5736 L F
.313 .788 .923 r
.36881 .71065 m .37279 .71072 L .3712 .70905 L F
.781 .95 .929 r
.37279 .71072 m .37294 .70805 L .3712 .70905 L F
.37279 .71072 m .37589 .7083 L .37294 .70805 L F
.659 .475 .624 r
.49451 .45679 m .4966 .46042 L .49174 .46012 L F
.734 .445 .49 r
.49433 .45406 m .49914 .45694 L .49451 .45679 L F
.654 .496 .658 r
.49914 .45694 m .4966 .46042 L .49451 .45679 L F
.994 .865 .532 r
.28446 .63581 m .28563 .63741 L .28618 .63358 L F
.341 .574 .926 r
.28457 .63145 m .28801 .6328 L .28618 .63358 L F
.048 0 .219 r
.28618 .63358 m .28704 .6355 L .28446 .63581 L F
.28618 .63358 m .28801 .6328 L .28704 .6355 L F
.637 .239 .273 r
.5472 .46767 m .55021 .46966 L .54721 .4689 L F
0 0 0 r
.35382 .52877 m .35128 .5299 L .35005 .53001 L F
.76 .991 .779 r
.35453 .52671 m .35382 .52877 L .35597 .52775 L F
.35453 .52671 m .35128 .5299 L .35382 .52877 L F
0 .397 .842 r
.56432 .46748 m .56819 .47024 L .56693 .46619 L F
.74 .646 .755 r
.56693 .46619 m .56819 .47024 L .57084 .46703 L F
.7 .749 .889 r
.44173 .46224 m .44327 .46422 L .43921 .46347 L F
.666 .737 .903 r
.44572 .46314 m .44327 .46422 L .44173 .46224 L F
.692 .466 .574 r
.5219 .46043 m .52194 .4631 L .51943 .46323 L F
.738 .549 .638 r
.52607 .4605 m .52194 .4631 L .5219 .46043 L F
.48 .347 .621 r
.46608 .54099 m .46637 .54354 L .46397 .54416 L F
.418 .43 .765 r
.46704 .54592 m .46397 .54416 L .46637 .54354 L F
.522 .333 .566 r
.46735 .49862 m .46467 .50284 L .46437 .4987 L F
.742 .71 .821 r
.41591 .49626 m .41759 .49942 L .41335 .4986 L F
.707 .695 .837 r
.41949 .49791 m .41759 .49942 L .41591 .49626 L F
.261 .353 .769 r
.34497 .50641 m .34749 .50749 L .34599 .5078 L F
.34497 .50641 m .34749 .50749 L .34599 .5078 L F
.605 .449 .643 r
.35988 .60536 m .36156 .60703 L .36312 .60153 L F
.676 .521 .668 r
.48295 .46327 m .48386 .46684 L .48004 .46658 L F
.671 .531 .686 r
.48513 .46001 m .48646 .46375 L .48295 .46327 L F
.663 .505 .66 r
.48646 .46375 m .48386 .46684 L .48295 .46327 L F
.502 .367 .63 r
.46399 .53066 m .46423 .53346 L .46176 .53409 L F
.011 0 .252 r
.21662 .55705 m .21732 .55846 L .21771 .55589 L F
.21662 .55705 m .21596 .55969 L .21732 .55846 L F
.835 .364 .026 r
.36367 .50639 m .36866 .51107 L .36706 .50795 L F
.497 .146 .302 r
.24923 .60183 m .24848 .60461 L .24539 .60451 L F
0 0 .572 r
.24899 .60054 m .24923 .60183 L .24761 .59871 L F
0 0 0 r
.24909 .60308 m .24923 .60183 L .24899 .60054 L F
.24909 .60308 m .24848 .60461 L .24923 .60183 L F
.625 .598 .803 r
.44034 .54596 m .43777 .54688 L .43662 .54348 L F
.694 .982 .835 r
.68705 .31468 m .6907 .31268 L .69082 .3121 L F
.799 .828 .874 r
.6907 .31268 m .69395 .31028 L .69233 .30827 L F
.6907 .31268 m .69233 .30827 L .69175 .3104 L F
.729 .911 .546 r
.69175 .3104 m .69082 .3121 L .6907 .31268 L F
.245 .062 .423 r
.22808 .56591 m .22757 .56893 L .22583 .56975 L F
.054 0 .299 r
.22757 .56893 m .22576 .57232 L .22583 .56975 L F
.356 .085 .358 r
.28411 .56313 m .28644 .56247 L .28678 .56018 L F
.61 .304 .426 r
.28644 .56247 m .28878 .56042 L .28678 .56018 L F
0 0 .263 r
.37703 .50255 m .37748 .50522 L .37713 .50122 L F
.551 .354 .567 r
.41091 .50479 m .40806 .50537 L .40825 .50231 L F
.43 .447 .776 r
.62965 .40181 m .63193 .4011 L .6315 .39831 L F
.768 .557 .613 r
.52064 .42757 m .51552 .43027 L .51787 .42723 L F
.52064 .42757 m .5193 .43106 L .51552 .43027 L F
.081 .127 .61 r
.47413 .56895 m .47504 .57119 L .47348 .57293 L F
0 0 .472 r
.47541 .5739 m .47348 .57293 L .47504 .57119 L F
.47541 .5739 m .47378 .57567 L .47348 .57293 L F
.727 .439 0 r
.37882 .62574 m .37923 .62688 L .37956 .62827 L F
.821 .409 .265 r
.28831 .63926 m .28563 .63741 L .28564 .6396 L F
.894 .618 .512 r
.28655 .64094 m .28831 .63926 L .28564 .6396 L F
.28655 .64094 m .29067 .64029 L .28831 .63926 L F
.589 .573 .803 r
.33076 .53423 m .3284 .53623 L .32807 .53448 L F
.628 .479 .66 r
.48915 .46046 m .48646 .46375 L .48513 .46001 L F
.393 .176 .462 r
.33155 .50538 m .32913 .50861 L .3314 .50788 L F
.594 .431 .63 r
.32911 .51179 m .3314 .50788 L .32913 .50861 L F
.738 .916 .953 r
.47529 .45251 m .47056 .45395 L .47306 .45301 L F
.738 .931 .953 r
.47613 .45069 m .47529 .45251 L .47306 .45301 L F
.772 .981 .723 r
.4377 .58698 m .43966 .58576 L .43682 .58889 L F
.888 .986 .72 r
.4399 .5835 m .43966 .58576 L .4377 .58698 L F
0 0 .197 r
.56294 .39929 m .56083 .4046 L .56246 .40459 L F
0 0 0 r
.56824 .38804 m .56689 .38827 L .56572 .3884 L F
.56824 .38804 m .5692 .38731 L .56689 .38827 L F
.819 .882 .89 r
.71432 .33938 m .7167 .33774 L .71505 .33617 L F
.43 .737 .991 r
.71505 .33617 m .7167 .33774 L .71908 .33734 L F
.26 0 0 r
.44034 .54596 m .44288 .54567 L .44385 .54408 L F
.528 .476 .742 r
.44299 .54061 m .44385 .54408 L .44673 .54333 L F
.587 .135 .144 r
.44385 .54408 m .44627 .54567 L .44673 .54333 L F
.44385 .54408 m .44288 .54567 L .44627 .54567 L F
.738 .549 .638 r
.52607 .4605 m .52596 .46354 L .52194 .4631 L F
.827 .73 .757 r
.33657 .50229 m .33546 .50562 L .33298 .50127 L F
.676 .915 .975 r
.3851 .62543 m .38625 .62337 L .38315 .6261 L F
.3851 .62543 m .38748 .62433 L .38625 .62337 L F
.774 .782 .859 r
.65493 .37967 m .65748 .37897 L .65553 .38019 L F
0 0 0 r
.65851 .37852 m .65551 .37948 L .65599 .37959 L F
.65551 .37948 m .65493 .37967 L .65518 .37965 L F
.65551 .37948 m .65518 .37965 L .65599 .37959 L F
.849 .859 .85 r
.66165 .37733 m .65748 .37897 L .65882 .37777 L F
.66105 .37662 m .65882 .37777 L .66064 .37615 L F
.66165 .37733 m .65882 .37777 L .66105 .37662 L F
.869 .941 .863 r
.66423 .37428 m .66165 .37733 L .66064 .37615 L F
.759 .58 .654 r
.50724 .45407 m .50757 .4554 L .50346 .45072 L F
.74 .58 .676 r
.50346 .45072 m .5069 .45463 L .50115 .45405 L F
.5069 .45463 m .50757 .4554 L .50628 .45513 L F
.5069 .45463 m .50628 .45513 L .50115 .45405 L F
.711 .504 .607 r
.50628 .45513 m .50082 .45661 L .50115 .45405 L F
.50757 .4554 m .50448 .45596 L .50628 .45513 L F
.50448 .45596 m .50082 .45661 L .50628 .45513 L F
.684 .483 .608 r
.5088 .45332 m .50842 .45414 L .50723 .45436 L F
.711 .504 .607 r
.50757 .4554 m .50545 .4575 L .50082 .45661 L F
.63 .385 .528 r
.50719 .45683 m .50545 .4575 L .50757 .4554 L F
.50719 .45683 m .50757 .4554 L .5073 .45432 L F
.50719 .45683 m .5073 .45432 L .50724 .45407 L F
.684 .483 .608 r
.50842 .45414 m .50719 .45683 L .50723 .45469 L F
.50842 .45414 m .50723 .45469 L .50723 .45436 L F
.50814 .45364 m .50723 .45436 L .50724 .45407 L F
.5088 .45332 m .50723 .45436 L .50814 .45364 L F
.697 .559 .695 r
.50601 .4474 m .50847 .4519 L .50346 .45072 L F
.50847 .4519 m .50872 .45235 L .50813 .45217 L F
.50847 .4519 m .50813 .45217 L .50346 .45072 L F
.73 .657 .776 r
.50976 .45089 m .5088 .45332 L .50724 .45407 L F
.50999 .4506 m .50992 .45077 L .50976 .45089 L F
.50992 .45077 m .5088 .45332 L .50976 .45089 L F
.211 0 0 r
.50719 .45683 m .51144 .45694 L .50876 .45681 L F
.8 .526 .524 r
.5088 .45332 m .51144 .45694 L .50719 .45683 L F
0 0 0 r
.33612 .62662 m .33523 .62719 L .33806 .62446 L F
.816 .451 .366 r
.33319 .62907 m .33635 .62999 L .33523 .62719 L F
.33319 .62907 m .33523 .62719 L .33612 .62662 L F
.404 .852 .912 r
.43871 .59898 m .44237 .59847 L .44076 .59794 L F
.569 .898 .983 r
.44076 .59794 m .44237 .59847 L .44459 .59747 L F
.594 .057 0 r
.42993 .56482 m .4309 .56371 L .43022 .56223 L F
.609 .162 .165 r
.4309 .56371 m .43386 .5654 L .43187 .56472 L F
.596 .416 .608 r
.43386 .5654 m .43145 .5685 L .43187 .56472 L F
.594 .057 0 r
.42993 .56482 m .43386 .5654 L .4309 .56371 L F
0 0 0 r
.3446 .67906 m .34945 .67577 L .34835 .67791 L F
.784 .612 .667 r
.36231 .52235 m .35842 .52409 L .36149 .51992 L F
.36231 .52235 m .36237 .52485 L .35842 .52409 L F
.889 .816 .77 r
.62553 .43064 m .6293 .42795 L .6283 .42782 L F
.613 .954 .905 r
.63059 .42648 m .6283 .42782 L .6293 .42795 L F
.451 .714 .98 r
.6293 .42795 m .63211 .42806 L .63059 .42648 L F
.713 .567 .688 r
.32342 .63716 m .32728 .63725 L .32511 .64016 L F
.785 .998 .847 r
.32793 .63478 m .32728 .63725 L .32659 .6356 L F
.32793 .63478 m .33012 .63469 L .32728 .63725 L F
.775 .997 .85 r
.33177 .63292 m .33012 .63469 L .32793 .63478 L F
.33177 .63292 m .33021 .63368 L .33085 .63488 L F
.33021 .63368 m .32793 .63478 L .33085 .63488 L F
.862 .812 .799 r
.33085 .63488 m .33471 .633 L .33177 .63292 L F
.359 0 .012 r
.33471 .633 m .33177 .63292 L .33085 .63488 L F
.862 .812 .799 r
.33085 .63488 m .33455 .63489 L .33471 .633 L F
.877 .746 .714 r
.33223 .63888 m .33455 .63489 L .33085 .63488 L F
.142 .09 .533 r
.33166 .6364 m .33085 .63488 L .33092 .63403 L F
.33216 .63801 m .33085 .63488 L .33166 .6364 L F
.656 .615 .797 r
.3289 .63139 m .33085 .63488 L .32793 .63478 L F
0 0 0 r
.32863 .63434 m .32793 .63478 L .32664 .63745 L F
.32932 .63327 m .32793 .63478 L .32863 .63434 L F
.785 .998 .847 r
.32793 .63478 m .32659 .6356 L .3257 .63347 L F
.336 .682 .979 r
.23483 .61365 m .23557 .61211 L .23373 .61265 L F
.23483 .61365 m .23782 .61425 L .23557 .61211 L F
.726 .509 .597 r
.34662 .60756 m .34363 .60997 L .34422 .60866 L F
.557 .826 .996 r
.37968 .65246 m .37749 .6533 L .3772 .65207 L F
.37968 .65246 m .37749 .6533 L .3772 .65207 L F
.388 0 0 r
.73309 .33583 m .73594 .33542 L .73494 .33652 L F
.7323 .33553 m .73395 .33548 L .73309 .33583 L F
.73395 .33548 m .73594 .33542 L .73309 .33583 L F
.465 .163 .368 r
.7323 .33553 m .73242 .33747 L .72952 .33814 L F
.161 0 0 r
.72505 .33839 m .72952 .33814 L .72782 .33862 L F
.594 .538 .761 r
.72952 .33814 m .73222 .33618 L .72782 .33862 L F
.388 0 0 r
.7323 .33553 m .73494 .33652 L .73242 .33747 L F
.594 .538 .761 r
.73222 .33618 m .73332 .33538 L .73136 .33653 L F
.73222 .33618 m .73136 .33653 L .72782 .33862 L F
.784 .805 .87 r
.73718 .33046 m .73594 .33542 L .7342 .3315 L F
.674 .752 .909 r
.73558 .33461 m .73594 .33542 L .73526 .33544 L F
.871 .89 .465 r
.73494 .33652 m .73594 .33542 L .73718 .33046 L F
0 0 0 r
.7359 .3342 m .73494 .33652 L .73669 .33176 L F
.73697 .33107 m .73669 .33176 L .73718 .33046 L F
.7359 .3342 m .73669 .33176 L .73697 .33107 L F
.674 .752 .909 r
.7342 .3315 m .73558 .33461 L .7323 .33553 L F
.73558 .33461 m .73526 .33544 L .7323 .33553 L F
.554 .416 .648 r
.47575 .47657 m .47609 .4795 L .47338 .48024 L F
.885 .884 .827 r
.34521 .59837 m .3433 .60154 L .34104 .60013 L F
.736 .214 0 r
.3433 .60154 m .34258 .60231 L .34104 .60013 L F
.3433 .60154 m .34481 .60374 L .34258 .60231 L F
.485 .311 .57 r
.35005 .53001 m .34727 .53351 L .34735 .5306 L F
.052 .125 .622 r
.21097 .57923 m .21272 .58135 L .21224 .57766 L F
.665 .443 .574 r
.33975 .67945 m .34235 .67998 L .34254 .67575 L F
.914 .591 .418 r
.3446 .67906 m .34254 .67575 L .34235 .67998 L F
.882 .789 .753 r
.56924 .40235 m .56548 .40431 L .56892 .4019 L F
.56924 .40235 m .56736 .40583 L .56548 .40431 L F
.844 .962 .883 r
.57245 .39919 m .56924 .40235 L .5698 .39889 L F
.862 .887 .458 r
.5698 .39889 m .56924 .40235 L .56892 .4019 L F
.212 0 0 r
.34464 .6802 m .3446 .67906 L .34235 .67998 L F
.698 .744 .238 r
.346 .6744 m .3446 .67906 L .34559 .67616 L F
.256 0 .029 r
.3446 .67906 m .34692 .68014 L .34506 .68102 L F
.3446 .67906 m .34835 .67791 L .34692 .68014 L F
0 0 0 r
.34559 .67616 m .3446 .67906 L .34464 .6802 L F
.499 .802 .999 r
.60855 .35258 m .60621 .35321 L .60466 .35195 L F
.545 .35 .568 r
.35977 .56243 m .35754 .55991 L .36007 .55956 L F
.35977 .56243 m .35731 .5633 L .35754 .55991 L F
0 .003 .576 r
.35226 .68763 m .35178 .6881 L .34978 .68429 L F
0 .505 .848 r
.35226 .68763 m .35402 .68864 L .35178 .6881 L F
.139 .322 .786 r
.35486 .69233 m .35178 .6881 L .35402 .68864 L F
.734 .608 .718 r
.33273 .60525 m .33076 .60772 L .33039 .60437 L F
.55 .813 .995 r
.37861 .665 m .37998 .66625 L .38225 .66524 L F
0 .308 .771 r
.38148 .66647 m .37998 .66625 L .37861 .665 L F
.38148 .66647 m .38342 .66828 L .37998 .66625 L F
.812 .904 .905 r
.6197 .37062 m .62277 .37034 L .62207 .36942 L F
.834 .987 .868 r
.62277 .37034 m .61931 .37215 L .62207 .36942 L F
.798 .986 .891 r
.62277 .37034 m .62387 .3682 L .62207 .36942 L F
.62277 .37034 m .62624 .36758 L .62387 .3682 L F
.76 .296 .147 r
.62209 .37214 m .62277 .37034 L .62207 .36942 L F
.62209 .37214 m .62577 .3727 L .62277 .37034 L F
.664 .516 .673 r
.62277 .37034 m .62601 .37043 L .62624 .36758 L F
.66 .45 .589 r
.62277 .37034 m .62577 .3727 L .62601 .37043 L F
.736 .646 .76 r
.51266 .44735 m .51403 .45104 L .50999 .4506 L F
.839 .842 .848 r
.51671 .44787 m .51403 .45104 L .51266 .44735 L F
.94 .88 .468 r
.61184 .45216 m .61305 .45054 L .61229 .44957 L F
.61184 .45216 m .61212 .45446 L .61305 .45054 L F
.791 .704 .769 r
.34724 .56578 m .35107 .56707 L .35038 .56259 L F
.534 .272 .465 r
.34724 .56578 m .34952 .56788 L .35107 .56707 L F
0 .018 .567 r
.35038 .56259 m .35107 .56707 L .35196 .56438 L F
.475 .317 .586 r
.34952 .56788 m .35196 .56438 L .35107 .56707 L F
.646 .411 .549 r
.35496 .56642 m .3511 .56919 L .35107 .56707 L F
0 0 0 r
.38748 .62433 m .38942 .62055 L .39002 .62361 L F
.946 .587 .224 r
.39002 .62361 m .38942 .62055 L .38797 .6196 L F
0 0 .217 r
.3326 .50394 m .33155 .50538 L .3314 .50788 L F
.675 .332 .386 r
.60195 .37279 m .60348 .37066 L .59925 .37076 L F
.647 .617 .805 r
.60348 .37066 m .60625 .37033 L .60492 .3665 L F
.282 0 0 r
.605 .37158 m .60348 .37066 L .60195 .37279 L F
.605 .37158 m .60625 .37033 L .60348 .37066 L F
.902 .503 .091 r
.60264 .42478 m .60398 .42839 L .60534 .42935 L F
.859 .475 0 r
.6047 .42953 m .60534 .42935 L .60398 .42839 L F
.6047 .42953 m .60583 .43094 L .60534 .42935 L F
.068 0 0 r
.53299 .4202 m .53741 .41838 L .53362 .41966 L F
.699 .602 .744 r
.49288 .44996 m .49433 .45406 L .49026 .45352 L F
.608 .43 .616 r
.48386 .46684 m .48116 .47026 L .48004 .46658 L F
.869 .986 .711 r
.32821 .64371 m .32586 .64549 L .32521 .64234 L F
.243 .265 .684 r
.3307 .64202 m .33031 .64577 L .32821 .64371 L F
0 0 0 r
.38429 .70046 m .38708 .69797 L .38542 .70011 L F
.38708 .69797 m .3899 .69539 L .38851 .69706 L F
.38542 .70011 m .38708 .69797 L .38851 .69706 L F
.629 .778 .953 r
.62645 .38607 m .63025 .3869 L .62915 .38637 L F
.63025 .3869 m .62645 .38607 L .62915 .38637 L F
.542 .902 .969 r
.62915 .38637 m .63025 .3869 L .63194 .38548 L F
.62915 .38637 m .63025 .3869 L .63194 .38548 L F
.894 .618 .512 r
.28655 .64094 m .28991 .64295 L .29067 .64029 L F
.516 .453 .725 r
.29044 .63766 m .29067 .64029 L .29333 .63921 L F
.713 .567 .688 r
.32342 .63716 m .32511 .64016 L .32324 .64011 L F
0 0 .317 r
.3251 .63551 m .32342 .63716 L .32324 .64011 L F
.979 .913 .654 r
.36854 .5985 m .3688 .59492 L .37102 .59608 L F
.36854 .5985 m .37102 .59608 L .36964 .59712 L F
.861 .79 .779 r
.37115 .59388 m .37102 .59608 L .3688 .59492 L F
.569 .88 .593 r
.37277 .59411 m .37102 .59608 L .37388 .5948 L F
.37277 .59411 m .36964 .59712 L .37102 .59608 L F
.853 .885 .862 r
.71013 .3412 m .71432 .33938 L .71233 .33909 L F
.857 .917 .871 r
.71233 .33909 m .71432 .33938 L .71505 .33617 L F
.861 .996 .806 r
.43182 .4654 m .43096 .46481 L .43329 .46432 L F
.713 .987 .842 r
.43329 .46432 m .43412 .46235 L .43516 .46286 L F
.43329 .46432 m .43096 .46481 L .43412 .46235 L F
.702 .604 .744 r
.49696 .45085 m .49433 .45406 L .49288 .44996 L F
.726 .62 .739 r
.50206 .44435 m .50384 .4483 L .49952 .44756 L F
.688 .538 .677 r
.50384 .4483 m .50203 .4512 L .49952 .44756 L F
.50384 .4483 m .50346 .45072 L .50203 .4512 L F
.712 .642 .778 r
.50453 .4435 m .50384 .4483 L .50206 .44435 L F
.50453 .4435 m .50601 .4474 L .50384 .4483 L F
.67 .521 .673 r
.50601 .4474 m .50346 .45072 L .50384 .4483 L F
.753 .308 0 r
.39016 .5116 m .39043 .51306 L .38847 .51049 L F
.39016 .5116 m .39181 .51464 L .39043 .51306 L F
.702 .847 .952 r
.43682 .58889 m .43241 .58933 L .43479 .58984 L F
.771 .997 .824 r
.4377 .58698 m .43682 .58889 L .43479 .58984 L F
.829 .762 .788 r
.52344 .41866 m .52415 .42202 L .52067 .42148 L F
.822 .82 .848 r
.52415 .42202 m .5194 .42366 L .52067 .42148 L F
.901 .95 .825 r
.36607 .60697 m .36942 .60483 L .36913 .60906 L F
.132 .228 .698 r
.371 .60334 m .36942 .60483 L .36877 .60112 L F
.262 .184 .576 r
.37271 .60433 m .36942 .60483 L .371 .60334 L F
.37271 .60433 m .36913 .60906 L .36942 .60483 L F
.214 .737 .836 r
.30264 .56035 m .30472 .55996 L .30732 .56004 L F
.317 .067 .368 r
.30872 .56182 m .30732 .56004 L .30911 .55918 L F
.30872 .56182 m .30658 .56274 L .30732 .56004 L F
.964 .94 .687 r
.59485 .37725 m .59289 .3814 L .59307 .37773 L F
0 0 0 r
.59538 .37625 m .59485 .37725 L .5959 .37501 L F
.767 .995 .804 r
.5959 .37501 m .59485 .37725 L .59307 .37773 L F
.601 .307 .442 r
.31403 .6084 m .31415 .60994 L .31716 .60777 L F
.31403 .6084 m .31349 .61064 L .31415 .60994 L F
.263 .752 .66 r
.43073 .48826 m .43272 .48746 L .43471 .48668 L F
0 0 0 r
.43073 .48826 m .43 .49064 L .43272 .48746 L F
.799 .974 .906 r
.43468 .54966 m .43314 .55102 L .43584 .551 L F
.434 .54887 m .43384 .54928 L .43468 .54966 L F
.43384 .54928 m .43314 .55102 L .43468 .54966 L F
.422 .367 .692 r
.434 .54887 m .43216 .54809 L .43314 .55102 L F
.515 0 0 r
.43371 .54923 m .43372 .54923 L .43273 .54879 L F
.43372 .54923 m .43646 .55124 L .43274 .54879 L F
.43646 .55124 m .43637 .55118 L .43274 .54879 L F
.43273 .54879 m .43653 .55129 L .4361 .55103 L F
.729 .638 .757 r
.42951 .5516 m .43065 .55462 L .43314 .55102 L F
.73 .65 .77 r
.43007 .54968 m .43314 .55102 L .43216 .54809 L F
.43007 .54968 m .42951 .5516 L .43314 .55102 L F
.655 .863 .481 r
.43314 .55102 m .43065 .55462 L .43184 .55317 L F
.839 .708 .718 r
.43305 .54917 m .4345 .55296 L .4297 .55105 L F
.067 0 .441 r
.43218 .55148 m .43305 .54944 L .43305 .54917 L F
.515 0 0 r
.43305 .54905 m .4361 .55103 L .43305 .54917 L F
.43273 .54879 m .4361 .55103 L .43284 .54891 L F
.43216 .54809 m .43371 .54923 L .43273 .54879 L F
.799 .974 .906 r
.434 .54887 m .43468 .54966 L .43739 .549 L F
.43468 .54966 m .43631 .55039 L .43739 .549 L F
.422 .367 .692 r
.434 .54887 m .43646 .55123 L .43216 .54809 L F
.43646 .55123 m .43653 .55129 L .43646 .55124 L F
.43646 .55123 m .43646 .55124 L .43216 .54809 L F
.799 .974 .906 r
.43468 .54966 m .43584 .551 L .43631 .55039 L F
.648 .163 .085 r
.44 .54867 m .43776 .54994 L .434 .54887 L F
.501 .375 .64 r
.43689 .54952 m .434 .54887 L .43776 .54994 L F
.43689 .54952 m .43653 .55129 L .434 .54887 L F
.823 .701 .73 r
.43649 .54949 m .43592 .55091 L .43305 .54917 L F
.43689 .54952 m .43648 .55011 L .43649 .54949 L F
.43648 .55011 m .43592 .55091 L .43649 .54949 L F
.515 0 0 r
.43646 .55124 m .43653 .55129 L .43637 .55118 L F
.825 .691 .716 r
.43305 .54917 m .43653 .55129 L .43689 .54952 L F
.733 .763 .877 r
.42791 .54782 m .43007 .54968 L .43216 .54809 L F
.772 .533 .573 r
.42837 .54507 m .43216 .54809 L .43022 .54476 L F
.42837 .54507 m .42791 .54782 L .43216 .54809 L F
.02 .308 .799 r
.43216 .54809 m .43258 .54666 L .43022 .54476 L F
.515 0 0 r
.43284 .54891 m .43305 .54905 L .43305 .54917 L F
.43216 .54809 m .43305 .54917 L .43258 .54666 L F
.955 .611 .294 r
.43258 .54666 m .43305 .54917 L .43097 .54567 L F
.515 0 0 r
.43372 .54923 m .43274 .54879 L .43273 .54879 L F
.147 .357 .814 r
.43097 .54567 m .43305 .54917 L .43391 .54741 L F
.939 .618 .402 r
.42791 .54782 m .42829 .55025 L .43007 .54968 L F
.42791 .54782 m .42829 .55025 L .43007 .54968 L F
.651 .164 .082 r
.424 .54452 m .42837 .54507 L .42555 .54319 L F
.902 .667 .573 r
.42421 .54432 m .42837 .54507 L .42448 .54458 L F
.42421 .54432 m .42448 .54458 L .424 .54452 L F
.999 .801 .503 r
.42439 .54187 m .424 .54452 L .42555 .54319 L F
.42439 .54187 m .424 .54452 L .42555 .54319 L F
.862 .829 .355 r
.42474 .53978 m .42404 .54424 L .42439 .54187 L F
.42404 .54424 m .424 .54452 L .42404 .54424 L F
.42404 .54424 m .42404 .54424 L .42439 .54187 L F
.902 .667 .573 r
.42421 .54432 m .42791 .54782 L .428 .54725 L F
.42421 .54432 m .428 .54725 L .42837 .54507 L F
0 .137 .594 r
.42407 .54418 m .42534 .54511 L .42421 .54432 L F
.862 .829 .355 r
.42404 .54424 m .42352 .54373 L .424 .54452 L F
.42474 .53978 m .42352 .54373 L .42404 .54424 L F
0 .137 .594 r
.42388 .544 m .42409 .54416 L .42407 .54418 L F
.42409 .54416 m .42534 .54511 L .42407 .54418 L F
.42352 .54373 m .42388 .544 L .42421 .54432 L F
.702 .732 .874 r
.432 .54704 m .42866 .54858 L .42741 .54593 L F
0 0 0 r
.42989 .54793 m .42866 .54858 L .42931 .54828 L F
.42989 .54793 m .42931 .54828 L .432 .54704 L F
.823 .701 .73 r
.43592 .55091 m .4345 .55296 L .43305 .54917 L F
.067 0 .441 r
.43218 .55148 m .43398 .55007 L .43391 .54741 L F
.452 0 0 r
.43328 .54899 m .42989 .54793 L .432 .54704 L F
0 .279 .781 r
.42989 .54793 m .43198 .54807 L .43058 .5475 L F
.42989 .54793 m .43058 .5475 L .42803 .54645 L F
.452 0 0 r
.43398 .55007 m .43307 .54959 L .43328 .54899 L F
.067 0 .441 r
.43305 .54944 m .43342 .54857 L .43305 .54917 L F
.965 .928 .704 r
.43007 .54968 m .42829 .55025 L .42869 .5507 L F
.42996 .55006 m .42869 .5507 L .42951 .5516 L F
.43007 .54968 m .42869 .5507 L .42996 .55006 L F
.946 .875 .734 r
.42806 .5509 m .42951 .5516 L .42829 .55025 L F
0 0 0 r
.43057 .55055 m .4297 .55105 L .42826 .55091 L F
.42839 .55085 m .42826 .55091 L .42806 .5509 L F
.43057 .55055 m .42826 .55091 L .42839 .55085 L F
.43057 .55055 m .42806 .5509 L .42829 .55025 L F
.945 .682 .505 r
.4286 .54885 m .43057 .55055 L .42829 .55025 L F
.42866 .54858 m .42929 .54923 L .4286 .54885 L F
.42929 .54923 m .43057 .55055 L .4286 .54885 L F
.872 .701 .667 r
.42761 .55388 m .43065 .55462 L .42951 .5516 L F
.637 .841 .445 r
.42916 .55659 m .43065 .55462 L .42761 .55388 L F
.946 .875 .734 r
.42806 .5509 m .42761 .55388 L .42951 .5516 L F
.643 .679 .869 r
.4297 .55105 m .42916 .55659 L .42806 .5509 L F
.637 .841 .445 r
.42916 .55659 m .42801 .55853 L .43065 .55462 L F
.643 .679 .869 r
.4297 .55105 m .43181 .55631 L .42916 .55659 L F
.792 .755 .819 r
.4345 .55296 m .43181 .55631 L .4297 .55105 L F
.725 .426 .472 r
.42876 .55127 m .43218 .55148 L .43239 .55092 L F
.839 .708 .718 r
.43305 .54917 m .4297 .55105 L .43057 .55055 L F
.725 .426 .472 r
.43101 .55017 m .43239 .55092 L .43305 .54917 L F
.945 .682 .505 r
.42866 .54858 m .42876 .55127 L .43057 .55055 L F
.725 .426 .472 r
.42876 .55127 m .43113 .55023 L .43057 .55055 L F
.42876 .55127 m .43305 .54917 L .43113 .55023 L F
.42876 .55127 m .43239 .55092 L .43101 .55017 L F
.452 0 0 r
.43307 .54959 m .42989 .54793 L .43328 .54899 L F
.067 0 .441 r
.43342 .54857 m .43391 .54741 L .43359 .54807 L F
.43342 .54857 m .43359 .54807 L .43305 .54917 L F
.747 .588 .679 r
.43773 .55168 m .43734 .55183 L .43689 .54952 L F
.43734 .55183 m .4345 .55296 L .43592 .55091 L F
.43734 .55183 m .43592 .55091 L .43689 .54952 L F
.847 .673 .666 r
.39227 .58254 m .39212 .58547 L .38838 .58497 L F
0 0 .49 r
.39241 .54095 m .39276 .5416 L .39128 .53984 L F
.39241 .54095 m .39371 .54271 L .39276 .5416 L F
.842 .767 .779 r
.51931 .44464 m .51671 .44787 L .51517 .44407 L F
.925 .566 .328 r
.5991 .42007 m .60057 .41865 L .59866 .41783 L F
.93 .577 .335 r
.60106 .42107 m .60057 .41865 L .5991 .42007 L F
0 0 .222 r
.31962 .60195 m .32034 .60323 L .32147 .60096 L F
.31962 .60195 m .31938 .60437 L .32034 .60323 L F
0 0 .298 r
.21216 .56961 m .21351 .56826 L .21316 .56632 L F
0 0 .35 r
.21212 .57229 m .21351 .56826 L .21216 .56961 L F
.358 0 .178 r
.28917 .5625 m .29336 .55887 L .28878 .56042 L F
.28917 .5625 m .29143 .5623 L .29336 .55887 L F
.516 .14 .266 r
.29336 .55887 m .2953 .56115 L .29665 .55849 L F
.29336 .55887 m .29143 .5623 L .2953 .56115 L F
.704 .767 .901 r
.4522 .4627 m .44801 .4622 L .45096 .45966 L F
.711 .773 .901 r
.45096 .45966 m .45498 .46026 L .4522 .4627 L F
.977 .75 .529 r
.39794 .55561 m .39971 .55676 L .39832 .553 L F
.996 .823 .552 r
.39763 .55857 m .39971 .55676 L .39794 .55561 L F
.39763 .55857 m .39888 .55983 L .39971 .55676 L F
.869 .88 .842 r
.67916 .32418 m .68238 .32232 L .68187 .32108 L F
.819 .838 .864 r
.53621 .40295 m .53704 .40541 L .53341 .40536 L F
.738 .448 .49 r
.53704 .40541 m .53316 .40773 L .53341 .40536 L F
.53704 .40541 m .53701 .40816 L .53316 .40773 L F
.826 .842 .859 r
.53964 .40242 m .53704 .40541 L .53621 .40295 L F
.583 .761 .963 r
.5405 .40482 m .53704 .40541 L .53964 .40242 L F
.548 .539 .797 r
.72509 .32151 m .72386 .32607 L .72372 .3224 L F
.72509 .32151 m .72606 .32578 L .72386 .32607 L F
.529 .391 .638 r
.72606 .32578 m .72708 .32768 L .72386 .32607 L F
.81 .986 .721 r
.36735 .59217 m .36772 .59234 L .36562 .5935 L F
0 0 .481 r
.34243 .69971 m .34244 .70123 L .34324 .7026 L F
.742 .497 .559 r
.23845 .53917 m .24174 .53739 L .23934 .53831 L F
.23757 .53965 m .24152 .54015 L .24174 .53739 L F
.64 .487 .66 r
.24439 .5343 m .24428 .53729 L .24174 .53739 L F
0 0 0 r
.24362 .5373 m .24174 .53739 L .24428 .53729 L F
.24362 .5373 m .23934 .53831 L .24174 .53739 L F
.501 .889 .959 r
.24362 .5373 m .24052 .53718 L .23934 .53831 L F
.24052 .53718 m .24015 .53716 L .23934 .53831 L F
.742 .497 .559 r
.23757 .53965 m .23845 .53917 L .23934 .53831 L F
.167 0 .271 r
.50999 .4506 m .50724 .45407 L .50872 .45235 L F
.759 .58 .654 r
.50724 .45407 m .50346 .45072 L .50872 .45235 L F
0 0 0 r
.38542 .70011 m .38614 .70032 L .38345 .70141 L F
.609 .802 .974 r
.38345 .70141 m .38614 .70032 L .38587 .70016 L F
0 0 0 r
.38429 .70046 m .38345 .70141 L .38198 .70217 L F
.38542 .70011 m .38345 .70141 L .38429 .70046 L F
.38542 .70011 m .38851 .69706 L .38614 .70032 L F
.609 .802 .974 r
.38345 .70141 m .38587 .70016 L .38385 .69891 L F
0 0 0 r
.38198 .70217 m .38345 .70141 L .38004 .7036 L F
.526 .14 .253 r
.30032 .63684 m .30231 .63892 L .30045 .63978 L F
.30032 .63684 m .30354 .63657 L .30231 .63892 L F
.722 .697 .825 r
.48192 .44943 m .48389 .45114 L .47977 .45036 L F
.785 .796 .861 r
.48497 .44673 m .48389 .45114 L .48192 .44943 L F
.48497 .44673 m .48623 .44967 L .48389 .45114 L F
.777 .681 .757 r
.51817 .43835 m .51734 .44092 L .51343 .44013 L F
.79 .644 .701 r
.51343 .44013 m .51734 .44092 L .51517 .44407 L F
.439 .208 .466 r
.30345 .62096 m .30578 .62039 L .30611 .61784 L F
.496 .269 .5 r
.30578 .62039 m .30868 .61712 L .30611 .61784 L F
.541 .422 .667 r
.46477 .50484 m .46237 .50807 L .46215 .50557 L F
.46477 .50484 m .46485 .50969 L .46237 .50807 L F
.49 .411 .695 r
.46636 .51232 m .46237 .50807 L .46485 .50969 L F
.46562 .51153 m .46404 .51446 L .46237 .50807 L F
.523 .432 .694 r
.46527 .51402 m .46434 .51818 L .46359 .51442 L F
.46618 .51379 m .46484 .51701 L .46527 .51402 L F
.46484 .51701 m .46434 .51818 L .46527 .51402 L F
.49 .411 .695 r
.46636 .51232 m .46538 .51322 L .46562 .51153 L F
.46538 .51322 m .46404 .51446 L .46562 .51153 L F
.929 .637 .164 r
.28564 .6396 m .28563 .63741 L .28446 .63581 L F
.882 .52 .037 r
.39371 .54271 m .39477 .5467 L .39557 .54669 L F
0 0 .304 r
.39624 .54801 m .39557 .54669 L .39477 .5467 L F
.39624 .54801 m .39666 .5493 L .39557 .54669 L F
.676 .904 .976 r
.6142 .35025 m .61288 .35261 L .6107 .35169 L F
.6142 .35025 m .61534 .3513 L .61288 .35261 L F
.738 .629 .738 r
.33341 .5895 m .33012 .58868 L .33166 .58774 L F
.33341 .5895 m .33059 .5921 L .33012 .58868 L F
.678 .213 .141 r
.33166 .58774 m .33589 .58848 L .33341 .5895 L F
0 0 0 r
.63484 .42493 m .63884 .42121 L .63851 .42408 L F
.11 .453 .884 r
.63806 .4189 m .63884 .42121 L .63908 .42061 L F
.007 0 0 r
.63484 .42493 m .63851 .42408 L .63778 .42442 L F
.967 .85 .442 r
.63778 .42442 m .63884 .42121 L .63806 .4189 L F
1 .818 .495 r
.63778 .42442 m .63851 .42408 L .63884 .42121 L F
.808 .326 0 r
.60652 .43572 m .6071 .43487 L .60574 .43362 L F
.60652 .43572 m .60812 .43682 L .6071 .43487 L F
0 0 0 r
.31879 .59153 m .31899 .5914 L .31974 .58872 L F
0 0 .003 r
.31974 .58872 m .32037 .58979 L .32196 .58773 L F
.31974 .58872 m .31899 .5914 L .32037 .58979 L F
.239 0 0 r
.44449 .57117 m .44846 .56881 L .44578 .57039 L F
.281 0 0 r
.27346 .57527 m .2719 .57724 L .26993 .57636 L F
.762 .43 .423 r
.27593 .57522 m .2719 .57724 L .27346 .57527 L F
.975 .779 .576 r
.33678 .58571 m .33412 .58719 L .33644 .58392 L F
.33678 .58571 m .33589 .58848 L .33412 .58719 L F
.602 .754 .951 r
.56693 .46619 m .57084 .46703 L .56951 .46527 L F
.757 .814 .897 r
.56951 .46527 m .57084 .46703 L .57247 .46419 L F
.515 .281 .498 r
.34477 .5663 m .34724 .56578 L .3475 .56321 L F
.543 .362 .585 r
.3475 .56321 m .35038 .56259 L .34992 .55986 L F
0 .132 .669 r
.34852 .56217 m .3475 .56321 L .34597 .55925 L F
.332 .81 .757 r
.34775 .56276 m .3475 .56321 L .34852 .56217 L F
.34775 .56276 m .34528 .56374 L .3475 .56321 L F
.791 .704 .769 r
.34724 .56578 m .35038 .56259 L .3475 .56321 L F
.246 0 0 r
.44299 .54061 m .44183 .54194 L .43907 .54247 L F
0 0 .302 r
.44144 .53684 m .44299 .54061 L .44566 .5402 L F
.44144 .53684 m .44262 .53961 L .44299 .54061 L F
.408 .223 .516 r
.44262 .53961 m .44183 .54194 L .44299 .54061 L F
.528 .476 .742 r
.44299 .54061 m .44673 .54333 L .44566 .5402 L F
.546 .763 .978 r
.44953 .55607 m .45244 .55596 L .45243 .55358 L F
.685 .24 .189 r
.34731 .63383 m .35022 .63438 L .34863 .63525 L F
.599 .874 .993 r
.35022 .63438 m .35205 .63324 L .34863 .63525 L F
.751 .816 .903 r
.69233 .30827 m .69395 .31028 L .69607 .30806 L F
.68 .64 .803 r
.58267 .46287 m .58366 .46644 L .5869 .46416 L F
.729 .657 .777 r
.66441 .3925 m .66844 .3932 L .66705 .3894 L F
.824 .798 .828 r
.66844 .3932 m .66998 .38841 L .66705 .3894 L F
.66844 .3932 m .67112 .39016 L .66998 .38841 L F
.46 .887 .822 r
.31751 .55785 m .31977 .55737 L .32202 .55626 L F
.977 .869 .664 r
.31781 .66753 m .32094 .66451 L .31942 .66851 L F
0 0 .23 r
.31942 .66851 m .32094 .66451 L .32114 .66696 L F
.601 .199 .253 r
.32114 .66696 m .32094 .66451 L .31781 .66753 L F
.852 .56 .026 r
.32064 .66441 m .32094 .66451 L .32114 .66696 L F
.798 .413 0 r
.39888 .55983 m .39988 .56223 L .40066 .56323 L F
.952 .68 .485 r
.39897 .56461 m .40066 .56323 L .39988 .56223 L F
.39897 .56461 m .40079 .56593 L .40066 .56323 L F
.755 .832 .911 r
.62829 .3481 m .62453 .34791 L .62686 .34637 L F
.793 .826 .878 r
.63112 .34536 m .62829 .3481 L .62686 .34637 L F
.161 0 .267 r
.32373 .55999 m .32569 .55947 L .32588 .55748 L F
.52 .43 .695 r
.3234 .56264 m .32569 .55947 L .32373 .55999 L F
.371 .319 .669 r
.22293 .58102 m .22136 .58378 L .22122 .58288 L F
.669 .726 .892 r
.31668 .54597 m .32075 .54714 L .3191 .5456 L F
.807 .61 .051 r
.41169 .55679 m .41152 .55809 L .41057 .55592 L F
.41169 .55679 m .4118 .55954 L .41152 .55809 L F
0 0 0 r
.21894 .55398 m .21771 .55589 L .22058 .55279 L F
.445 .225 .484 r
.30345 .62096 m .30315 .62359 L .30578 .62039 L F
.668 .738 .902 r
.48906 .4476 m .48623 .44967 L .48497 .44673 L F
.787 .574 .612 r
.58779 .4565 m .59176 .45695 L .59118 .45428 L F
.196 .393 .831 r
.58984 .45236 m .59118 .45428 L .59143 .45242 L F
.871 .578 .055 r
.59118 .45428 m .59117 .45612 L .59143 .45242 L F
.59118 .45428 m .59176 .45695 L .59117 .45612 L F
.603 .471 .674 r
.46976 .49324 m .47252 .4951 L .46987 .49566 L F
.46976 .49324 m .47248 .49252 L .47252 .4951 L F
.251 .758 .734 r
.24738 .59877 m .24539 .5994 L .24393 .59963 L F
.24761 .59871 m .24747 .59876 L .24738 .59877 L F
.24747 .59876 m .24539 .5994 L .24738 .59877 L F
.24761 .59871 m .24393 .59963 L .24558 .6001 L F
0 .192 .713 r
.24221 .59708 m .24393 .59963 L .24121 .59805 L F
0 0 .448 r
.24159 .59389 m .24121 .59805 L .23992 .59527 L F
.24159 .59389 m .24221 .59708 L .24121 .59805 L F
.609 .471 .668 r
.23922 .59979 m .24265 .59967 L .24221 .59708 L F
.24265 .59967 m .24393 .59963 L .24297 .59821 L F
.24265 .59967 m .24297 .59821 L .24221 .59708 L F
.193 .386 .825 r
.23922 .59979 m .24198 .60245 L .24393 .59963 L F
0 0 .349 r
.24198 .60245 m .24335 .59921 L .24393 .59963 L F
.24212 .60212 m .24357 .60136 L .24335 .59921 L F
.24198 .60245 m .24206 .60239 L .24212 .60212 L F
.24206 .60239 m .24357 .60136 L .24212 .60212 L F
.535 .824 .999 r
.24642 .59824 m .24558 .6001 L .24335 .59921 L F
.811 .379 .22 r
.24357 .60136 m .24558 .6001 L .2461 .59896 L F
.24571 .59901 m .2461 .59896 L .24642 .59824 L F
.24357 .60136 m .2461 .59896 L .24571 .59901 L F
.687 .97 .765 r
.2541 .55314 m .25108 .55563 L .25553 .55157 L F
.644 .813 .964 r
.25091 .55587 m .24857 .55664 L .25071 .55573 L F
.25274 .55712 m .25023 .55683 L .25091 .55587 L F
.25023 .55683 m .24857 .55664 L .25091 .55587 L F
.612 .445 .631 r
.25132 .55834 m .24857 .55664 L .25071 .55573 L F
.456 .171 .391 r
.25071 .55573 m .25063 .556 L .2541 .55314 L F
.687 .97 .765 r
.25108 .55563 m .25063 .556 L .25115 .55553 L F
.25108 .55563 m .25115 .55553 L .25553 .55157 L F
0 0 0 r
.25505 .55636 m .25132 .55834 L .25274 .55712 L F
.722 .722 .849 r
.34785 .55615 m .34992 .55986 L .34597 .55925 L F
0 .132 .669 r
.34852 .56217 m .34597 .55925 L .34992 .55986 L F
0 .188 .72 r
.35011 .55805 m .34992 .55986 L .34785 .55615 L F
.722 .722 .849 r
.34785 .55615 m .34992 .55986 L .34597 .55925 L F
.771 .709 .793 r
.35011 .55805 m .34852 .56217 L .34992 .55986 L F
.653 .171 .095 r
.35281 .56216 m .34992 .55986 L .35038 .56259 L F
.13 0 0 r
.2798 .56515 m .2822 .56465 L .28411 .56313 L F
.733 .461 .517 r
.2822 .56465 m .28644 .56247 L .28411 .56313 L F
.901 .653 .553 r
.33606 .61142 m .33364 .60782 L .3373 .60773 L F
.33606 .61142 m .33303 .61053 L .33364 .60782 L F
.8 .363 .209 r
.33606 .61142 m .335 .61315 L .33303 .61053 L F
.33606 .61142 m .33764 .61374 L .335 .61315 L F
.978 .69 .313 r
.39994 .57443 m .40123 .5727 L .40039 .57086 L F
.39994 .57443 m .40098 .57565 L .40123 .5727 L F
0 0 0 r
.32879 .55363 m .3271 .55422 L .32518 .55468 L F
.33146 .55332 m .3271 .55422 L .32879 .55363 L F
.31066 .62958 m .30932 .63099 L .31189 .62775 L F
.31339 .62615 m .31189 .62775 L .314 .6245 L F
.31066 .62958 m .31189 .62775 L .31339 .62615 L F
.31339 .62615 m .31189 .62775 L .314 .6245 L F
.36211 .69144 m .35987 .6951 L .36207 .69413 L F
.948 .954 .659 r
.61092 .45625 m .61212 .45446 L .61184 .45216 L F
.594 .913 .664 r
.38695 .69034 m .38604 .69151 L .38901 .68891 L F
.69 .185 0 r
.38633 .69257 m .38815 .69416 L .38604 .69151 L F
.38633 .69257 m .38604 .69151 L .38695 .69034 L F
.762 .624 .707 r
.50082 .45661 m .50424 .45966 L .49827 .45983 L F
.689 .428 .523 r
.50424 .45966 m .49829 .4626 L .49827 .45983 L F
.826 .837 .857 r
.50639 .46359 m .50189 .4655 L .50422 .46211 L F
0 0 0 r
.50422 .46211 m .50189 .4655 L .50332 .46358 L F
.689 .428 .523 r
.50424 .45966 m .50332 .46358 L .49829 .4626 L F
.673 .629 .796 r
.50545 .4575 m .50424 .45966 L .50082 .45661 L F
.74 .479 .535 r
.50422 .46211 m .50332 .46358 L .50424 .45966 L F
.151 .263 .726 r
.50424 .45966 m .50639 .46359 L .50422 .46211 L F
.655 .52 .686 r
.34144 .6918 m .34253 .69439 L .33947 .69501 L F
.719 .865 .951 r
.37637 .63346 m .37977 .63377 L .37802 .63262 L F
.448 .252 .521 r
.57703 .43464 m .5771 .43749 L .57951 .43398 L F
.57703 .43464 m .5771 .43749 L .57951 .43398 L F
.189 0 .076 r
.30582 .63377 m .30932 .63099 L .30781 .63319 L F
0 0 0 r
.30781 .63319 m .30932 .63099 L .31066 .62958 L F
.793 .999 .842 r
.62624 .36758 m .62912 .36502 L .62722 .36526 L F
.776 .988 .895 r
.62387 .3682 m .62624 .36758 L .62722 .36526 L F
.663 .185 .107 r
.34057 .51455 m .34161 .51581 L .34357 .51484 L F
0 0 0 r
.34357 .51484 m .34551 .51402 L .34566 .51396 L F
.34357 .51484 m .34161 .51581 L .34551 .51402 L F
.401 0 .133 r
.25755 .61886 m .26146 .61678 L .25887 .61809 L F
.759 .995 .851 r
.62722 .36526 m .62912 .36502 L .63082 .36335 L F
.937 .664 .497 r
.32511 .64016 m .32301 .64171 L .32324 .64011 L F
.32511 .64016 m .32521 .64234 L .32301 .64171 L F
.801 .939 .919 r
.66455 .3361 m .66872 .33506 L .6672 .33384 L F
.873 .866 .828 r
.6672 .33384 m .66872 .33506 L .67127 .33175 L F
.645 .592 .78 r
.45749 .56026 m .4593 .55569 L .45623 .5566 L F
.45749 .56026 m .46006 .55961 L .4593 .55569 L F
.345 .29 .652 r
.45749 .56026 m .4598 .56242 L .46006 .55961 L F
.45749 .56026 m .45796 .56314 L .4598 .56242 L F
0 0 .195 r
.32946 .56966 m .33021 .57031 L .33103 .5681 L F
.32946 .56966 m .32913 .57209 L .33021 .57031 L F
.995 .777 .414 r
.61083 .44326 m .61161 .44745 L .61245 .44438 L F
0 .29 .779 r
.26311 .62785 m .26585 .6307 L .26542 .6293 L F
.145 0 .322 r
.26585 .6307 m .26686 .63224 L .26542 .6293 L F
.26585 .6307 m .26509 .6335 L .26686 .63224 L F
0 .535 .753 r
.27833 .52159 m .27656 .52125 L .27415 .52096 L F
.472 .826 .996 r
.28089 .52157 m .27656 .52125 L .27833 .52159 L F
.24 .094 .472 r
.36312 .60153 m .3647 .60354 L .36478 .60117 L F
.36312 .60153 m .36156 .60703 L .3647 .60354 L F
.804 .959 .631 r
.24484 .5325 m .24439 .5343 L .24667 .53088 L F
.895 .74 .236 r
.24367 .53523 m .24439 .5343 L .24484 .5325 L F
.24367 .53523 m .24428 .53729 L .24439 .5343 L F
.948 .84 .702 r
.68243 .35451 m .68352 .35746 L .68214 .3571 L F
.921 .884 .78 r
.68214 .3571 m .68352 .35746 L .68127 .36089 L F
.837 .809 .823 r
.68605 .35404 m .68352 .35746 L .68243 .35451 L F
.612 .422 .6 r
.43808 .51841 m .43846 .5217 L .43533 .52099 L F
.046 .018 .499 r
.43987 .51966 m .43808 .51841 L .44107 .51788 L F
.43987 .51966 m .43846 .5217 L .43808 .51841 L F
.03 .597 .784 r
.32753 .56301 m .32602 .56276 L .3234 .56264 L F
.482 .888 .939 r
.32805 .56198 m .32753 .56301 L .32994 .5627 L F
.32805 .56198 m .32602 .56276 L .32753 .56301 L F
.979 .913 .654 r
.36854 .5985 m .36742 .59838 L .3688 .59492 L F
.579 .941 .905 r
.36964 .59712 m .36742 .59838 L .36854 .5985 L F
.428 .058 .232 r
.31339 .62615 m .314 .6245 L .31632 .62585 L F
.728 .65 .772 r
.50866 .44422 m .50601 .4474 L .50453 .4435 L F
.678 .574 .732 r
.50866 .44422 m .51086 .44878 L .50601 .4474 L F
.692 .557 .698 r
.50999 .4506 m .50601 .4474 L .51086 .44878 L F
.50999 .4506 m .50872 .45235 L .50601 .4474 L F
.972 .717 .489 r
.34695 .56835 m .34857 .57241 L .34935 .57037 L F
.89 .731 .677 r
.36248 .68868 m .36211 .69144 L .36058 .68777 L F
.736 .314 .247 r
.53655 .46625 m .54049 .46692 L .54082 .4685 L F
.634 .242 .285 r
.54049 .46692 m .54309 .46895 L .54082 .4685 L F
.068 0 0 r
.53299 .4202 m .53602 .41907 L .53741 .41838 L F
.079 .596 .881 r
.5389 .41825 m .54009 .41894 L .53741 .41838 L F
.722 .594 .712 r
.49952 .44756 m .50203 .4512 L .49696 .45085 L F
.465 .551 .859 r
.50115 .45405 m .49696 .45085 L .50203 .4512 L F
.668 .482 .625 r
.50203 .4512 m .50346 .45072 L .50115 .45405 L F
.674 .877 .975 r
.34293 .56437 m .34047 .56562 L .34174 .56631 L F
.504 .321 .566 r
.34226 .56977 m .34477 .5663 L .34174 .56631 L F
.636 .458 .626 r
.45243 .55358 m .44949 .55463 L .44844 .55341 L F
.39 0 0 r
.33546 .66025 m .33067 .65942 L .33393 .65858 L F
.691 .397 .471 r
.33067 .66038 m .33393 .65858 L .33067 .65942 L F
.677 .823 .953 r
.33067 .66038 m .33546 .66025 L .33393 .65858 L F
0 .488 .865 r
.33604 .65889 m .33393 .65858 L .33483 .65777 L F
.33604 .65889 m .33393 .65858 L .33483 .65777 L F
.68 .952 .953 r
.33604 .65889 m .33546 .66025 L .33393 .65858 L F
.33604 .65889 m .33546 .66025 L .33393 .65858 L F
.134 .442 .878 r
.25279 .62185 m .25471 .62141 L .25135 .62062 L F
.25279 .62185 m .25567 .62314 L .25471 .62141 L F
.758 .242 0 r
.26516 .617 m .26828 .61952 L .26655 .62054 L F
.938 .917 .767 r
.39672 .60021 m .39803 .60105 L .39931 .59925 L F
.936 .923 .773 r
.39672 .60021 m .39931 .59925 L .39889 .5963 L F
.985 .704 .383 r
.38991 .53332 m .3914 .53699 L .39122 .53452 L F
.599 .901 .986 r
.55991 .46791 m .56432 .46748 L .56322 .46688 L F
.66 .952 .95 r
.56432 .46748 m .56559 .46576 L .56322 .46688 L F
.56432 .46748 m .56693 .46619 L .56559 .46576 L F
.68 .446 .562 r
.36227 .52619 m .35842 .52409 L .36237 .52485 L F
.645 .622 .812 r
.55968 .3863 m .55725 .38798 L .55514 .3857 L F
.526 .242 .425 r
.21229 .60231 m .2145 .60388 L .21521 .6019 L F
.814 .534 .514 r
.34104 .60013 m .33672 .60087 L .33668 .60014 L F
0 0 .051 r
.33662 .59903 m .33668 .60014 L .33594 .60165 L F
.906 .835 .374 r
.33491 .60117 m .33594 .60165 L .33668 .60014 L F
.814 .534 .514 r
.33672 .60087 m .33491 .60117 L .33668 .60014 L F
0 0 .051 r
.33707 .59735 m .33668 .60014 L .33662 .59903 L F
.572 .629 .87 r
.4079 .47852 m .40617 .48068 L .40524 .47911 L F
.4079 .47852 m .40928 .48049 L .40617 .48068 L F
.704 .44 .523 r
.54507 .41118 m .54758 .41191 L .54718 .40883 L F
0 .525 .798 r
.3469 .49688 m .34638 .49712 L .34519 .49616 L F
.107 0 0 r
.34638 .49712 m .34873 .49747 L .35048 .49772 L F
0 .525 .798 r
.3469 .49688 m .34873 .49747 L .34638 .49712 L F
.722 .988 .874 r
.37706 .66897 m .37353 .67082 L .37501 .67038 L F
0 0 .021 r
.37861 .665 m .37706 .66897 L .37665 .66863 L F
.79 .992 .76 r
.37665 .66863 m .37706 .66897 L .37501 .67038 L F
.585 .466 .683 r
.32758 .61141 m .32796 .61399 L .32543 .61443 L F
.518 0 0 r
.35264 .4987 m .35514 .50012 L .35683 .49978 L F
.738 .219 0 r
.35514 .50012 m .35894 .50229 L .35683 .49978 L F
.738 .218 0 r
.35683 .49978 m .35894 .50229 L .36055 .5024 L F
.579 .548 .784 r
.33369 .5496 m .32974 .54623 L .334 .5466 L F
.658 .706 .883 r
.33669 .5459 m .334 .5466 L .3316 .54354 L F
.33669 .5459 m .334 .5466 L .3316 .54354 L F
.468 .21 .439 r
.33669 .5459 m .33369 .5496 L .334 .5466 L F
.516 .453 .725 r
.29044 .63766 m .29333 .63921 L .29275 .6367 L F
0 .044 .595 r
.33236 .56605 m .33292 .56242 L .33422 .56338 L F
.33236 .56605 m .32994 .5627 L .33292 .56242 L F
.33222 .56586 m .33119 .56387 L .32994 .5627 L F
0 .049 .607 r
.32994 .5627 m .33064 .56289 L .32805 .56198 L F
.32994 .5627 m .33162 .56428 L .33131 .56374 L F
.615 .455 .642 r
.33099 .56334 m .33174 .56369 L .33064 .56289 L F
.129 .503 .908 r
.33085 .56295 m .33174 .56369 L .33099 .56334 L F
0 .049 .607 r
.33064 .56289 m .33099 .56334 L .33085 .56295 L F
.129 .503 .908 r
.33085 .56295 m .33099 .56334 L .33088 .56329 L F
0 .049 .607 r
.33099 .56334 m .33131 .56374 L .33085 .56295 L F
.32994 .5627 m .33131 .56374 L .33064 .56289 L F
.615 .455 .642 r
.33064 .56289 m .33174 .56369 L .33167 .56326 L F
.32805 .56198 m .33099 .56334 L .33064 .56289 L F
.32805 .56198 m .33167 .56326 L .33082 .55819 L F
0 .049 .607 r
.33064 .56289 m .33085 .56295 L .32805 .56198 L F
.129 .503 .908 r
.33067 .56289 m .33088 .56329 L .32805 .56198 L F
.33085 .56295 m .33088 .56329 L .33067 .56289 L F
0 .044 .595 r
.33236 .56605 m .33162 .56428 L .33119 .56387 L F
.33236 .56605 m .33119 .56387 L .33222 .56586 L F
.517 .581 .858 r
.33103 .5681 m .33162 .56428 L .33236 .56605 L F
.614 .386 .548 r
.37271 .60433 m .37015 .60889 L .36913 .60906 L F
0 .353 .777 r
.36913 .60906 m .37015 .60889 L .36607 .60697 L F
.727 .774 .89 r
.45727 .45886 m .46112 .45945 L .45894 .46054 L F
0 0 0 r
.45616 .59059 m .45394 .59172 L .45723 .58932 L F
.379 .063 .298 r
.45915 .58799 m .45616 .59059 L .45723 .58932 L F
.675 .127 0 r
.22543 .58691 m .22574 .58661 L .22136 .58378 L F
.831 .841 .854 r
.63908 .42061 m .64381 .41877 L .64212 .41719 L F
.912 .819 .742 r
.64381 .41877 m .64327 .41518 L .64212 .41719 L F
.854 .799 .796 r
.64178 .40105 m .64353 .40264 L .64097 .40576 L F
.984 .849 .629 r
.64297 .39903 m .64353 .40264 L .64178 .40105 L F
.605 .196 .24 r
.34213 .5084 m .34175 .51031 L .33883 .50987 L F
0 0 .02 r
.34332 .50866 m .34175 .51031 L .34213 .5084 L F
.982 .718 .447 r
.38871 .67132 m .39075 .66903 L .38925 .6677 L F
.437 .738 .991 r
.38925 .6677 m .39075 .66903 L .39175 .66746 L F
.634 .868 .506 r
.39175 .66746 m .39075 .66903 L .38871 .67132 L F
.873 .866 .828 r
.6672 .33384 m .67127 .33175 L .67027 .33054 L F
.812 .896 .902 r
.67127 .33175 m .67318 .32766 L .67027 .33054 L F
.67127 .33175 m .67446 .32911 L .67318 .32766 L F
.669 .439 .563 r
.31054 .61349 m .31349 .61064 L .3114 .61146 L F
.753 .277 .111 r
.61197 .36674 m .61009 .36481 L .60886 .36706 L F
0 0 0 r
.30046 .65634 m .30273 .65248 L .30203 .65625 L F
.181 .018 .41 r
.30476 .65468 m .30273 .65248 L .30393 .6518 L F
.30476 .65468 m .30203 .65625 L .30273 .65248 L F
.804 .849 .884 r
.67896 .38332 m .68265 .3832 L .6814 .38176 L F
.798 .924 .92 r
.68265 .3832 m .68494 .37935 L .6814 .38176 L F
.68265 .3832 m .68586 .38051 L .68494 .37935 L F
.423 .863 .912 r
.24295 .57453 m .24006 .57432 L .24367 .57296 L F
.191 .723 .783 r
.23829 .57515 m .23941 .57492 L .24295 .57453 L F
.423 .863 .912 r
.24295 .57453 m .2378 .5751 L .24006 .57432 L F
.002 0 0 r
.2425 .57535 m .2451 .57421 L .24483 .57495 L F
.791 .524 .534 r
.24006 .57432 m .24432 .57208 L .24367 .57296 L F
.24006 .57432 m .24483 .57495 L .24432 .57208 L F
.339 .768 .972 r
.24228 .57414 m .24269 .57427 L .24006 .57432 L F
.24269 .57427 m .24483 .57495 L .24149 .57451 L F
.24269 .57427 m .24149 .57451 L .24006 .57432 L F
.191 .723 .783 r
.23537 .57553 m .2378 .5751 L .23941 .57492 L F
.23537 .57553 m .23941 .57492 L .23829 .57515 L F
.631 .865 .502 r
.59584 .3591 m .59446 .36117 L .59575 .35944 L F
.855 .687 .673 r
.38773 .54995 m .38723 .55314 L .38922 .55306 L F
.806 .478 .433 r
.38723 .55314 m .38745 .55559 L .38922 .55306 L F
.996 .858 .527 r
.38668 .55128 m .38723 .55314 L .38773 .54995 L F
.965 .682 .446 r
.38773 .54995 m .38922 .55306 L .38668 .55128 L F
.855 .602 .064 r
.38723 .55314 m .38745 .55559 L .38668 .55128 L F
.964 .742 .553 r
.38922 .55306 m .38745 .55559 L .38668 .55128 L F
.713 .353 0 r
.39666 .5493 m .39832 .553 L .39755 .55111 L F
.258 .098 .464 r
.47378 .57567 m .47365 .57837 L .47186 .57924 L F
.101 0 .311 r
.47295 .58055 m .47186 .57924 L .47365 .57837 L F
.47295 .58055 m .4714 .58193 L .47186 .57924 L F
.974 .666 .341 r
.61447 .4251 m .61329 .42649 L .61291 .4241 L F
.61447 .4251 m .61474 .42771 L .61329 .42649 L F
.565 .587 .835 r
.28368 .53101 m .28443 .52666 L .28209 .52726 L F
.28368 .53101 m .28617 .53047 L .28443 .52666 L F
.441 .27 .552 r
.39873 .6781 m .39869 .68007 L .39618 .67862 L F
.558 .569 .821 r
.40037 .68169 m .39618 .67862 L .39869 .68007 L F
.355 .115 .406 r
.34796 .59529 m .3475 .59778 L .35014 .59453 L F
.787 .775 .842 r
.46894 .45207 m .46797 .45678 L .46624 .45539 L F
.46894 .45207 m .47056 .45395 L .46797 .45678 L F
.809 .8 .843 r
.46624 .45539 m .46797 .45678 L .4673 .45713 L F
.993 .84 .584 r
.40043 .58097 m .40238 .57941 L .4008 .57514 L F
.40043 .58097 m .40164 .58209 L .40238 .57941 L F
.553 .427 .662 r
.46434 .51818 m .46475 .5209 L .4622 .52154 L F
.473 .364 .65 r
.46475 .5209 m .46284 .52413 L .4622 .52154 L F
.306 .699 .978 r
.39323 .49087 m .39232 .49205 L .39068 .4913 L F
.303 .72 .974 r
.35989 .51417 m .3643 .51515 L .36145 .51411 L F
.893 .656 .573 r
.3643 .51515 m .36353 .51751 L .36145 .51411 L F
.8 .973 .907 r
.64016 .35706 m .641 .3546 L .63908 .35627 L F
.64016 .35706 m .64332 .35447 L .641 .3546 L F
.981 .723 .466 r
.43471 .48668 m .43276 .48468 L .43684 .48535 L F
.43471 .48668 m .43272 .48746 L .43276 .48468 L F
.982 .905 .647 r
.74384 .3256 m .7432 .32374 L .74199 .32663 L F
.74384 .3256 m .7432 .32374 L .74199 .32663 L F
.385 .805 .612 r
.34226 .56977 m .34219 .56977 L .34407 .57027 L F
.34226 .56977 m .34015 .57104 L .34219 .56977 L F
.504 .321 .566 r
.34226 .56977 m .34484 .56916 L .34477 .5663 L F
.364 .003 .212 r
.34226 .56977 m .34407 .57027 L .34484 .56916 L F
.43 .837 .645 r
.24536 .52432 m .24619 .52366 L .24739 .52352 L F
.24536 .52432 m .24284 .52578 L .24619 .52366 L F
.755 .58 .659 r
.49829 .4626 m .50143 .46702 L .49575 .46576 L F
.62 .546 .75 r
.50189 .4655 m .50143 .46702 L .49829 .4626 L F
.698 .575 .713 r
.49987 .4689 m .49575 .46576 L .50143 .46702 L F
.936 .897 .764 r
.49987 .4689 m .50143 .46702 L .50189 .4655 L F
.818 .58 .578 r
.50371 .46681 m .49987 .4689 L .50189 .4655 L F
.50371 .46681 m .50366 .46945 L .49987 .4689 L F
.826 .837 .857 r
.50639 .46359 m .50371 .46681 L .50189 .4655 L F
.696 .614 .76 r
.50639 .46359 m .50775 .4672 L .50371 .46681 L F
.762 .603 .682 r
.50775 .4672 m .50366 .46945 L .50371 .46681 L F
.71 .499 .601 r
.30046 .65634 m .30105 .65904 L .29775 .65974 L F
0 0 .497 r
.30217 .65809 m .30046 .65634 L .30203 .65625 L F
.30217 .65809 m .30105 .65904 L .30046 .65634 L F
.229 0 0 r
.26172 .62679 m .25958 .62629 L .25957 .62627 L F
.473 0 0 r
.26172 .62679 m .26122 .62663 L .25958 .62629 L F
.26172 .62679 m .26311 .62785 L .26122 .62663 L F
.663 .505 .66 r
.48646 .46375 m .48654 .46648 L .48386 .46684 L F
.628 .479 .66 r
.48915 .46046 m .48915 .46318 L .48646 .46375 L F
.628 .478 .659 r
.48915 .46318 m .48654 .46648 L .48646 .46375 L F
.873 .785 .289 r
.35396 .67198 m .35441 .67008 L .35401 .67138 L F
0 0 0 r
.30898 .64675 m .30913 .64672 L .3063 .64864 L F
.30898 .64675 m .31157 .64573 L .30913 .64672 L F
.042 0 0 r
.24665 .62031 m .24436 .62157 L .24249 .62174 L F
0 0 0 r
.24926 .62051 m .24436 .62157 L .24665 .62031 L F
.757 .869 .93 r
.65582 .34023 m .65971 .3402 L .65841 .3387 L F
.751 .913 .947 r
.65841 .3387 m .65971 .3402 L .66257 .33814 L F
.707 .558 .683 r
.50775 .4672 m .51031 .46675 L .50771 .46986 L F
.623 .439 .612 r
.51031 .46675 m .5104 .46973 L .50771 .46986 L F
.639 .477 .647 r
.51296 .46607 m .5104 .46973 L .51031 .46675 L F
.752 .805 .895 r
.65841 .3934 m .66194 .39369 L .66049 .39185 L F
.735 .762 .875 r
.66194 .39369 m .66441 .3925 L .66049 .39185 L F
.708 .535 .652 r
.39507 .65022 m .3997 .64963 L .39664 .64727 L F
.847 .996 .765 r
.35395 .65313 m .35646 .6501 L .35431 .651 L F
.901 .922 .535 r
.35646 .6501 m .35777 .64636 L .35784 .64727 L F
.738 .346 .309 r
.35784 .64727 m .35777 .64636 L .3542 .64569 L F
.885 .991 .753 r
.35431 .651 m .35634 .65015 L .35654 .64864 L F
.35431 .651 m .35666 .64852 L .3571 .64824 L F
.35654 .64864 m .35646 .6501 L .35784 .64727 L F
.35666 .64852 m .35784 .64727 L .3571 .64824 L F
.738 .346 .309 r
.35784 .64727 m .35482 .64596 L .3571 .64824 L F
.35482 .64596 m .3542 .64569 L .3571 .64824 L F
0 .173 .705 r
.35819 .64754 m .3571 .64824 L .35497 .64407 L F
.3584 .64777 m .3571 .64824 L .35819 .64754 L F
.079 .274 .76 r
.35497 .64407 m .35671 .64746 L .3542 .64569 L F
.35671 .64746 m .3571 .64824 L .35665 .64784 L F
.35671 .64746 m .35665 .64784 L .3542 .64569 L F
.885 .991 .753 r
.35634 .65015 m .35646 .6501 L .35654 .64864 L F
.413 .832 .966 r
.55628 .4679 m .55753 .46846 L .55991 .46791 L F
.862 .947 .87 r
.70358 .32275 m .70064 .32596 L .69973 .32465 L F
.913 .524 .116 r
.39729 .52095 m .39954 .52457 L .3981 .52334 L F
.985 .733 .345 r
.39954 .52457 m .39849 .52541 L .3981 .52334 L F
.39954 .52457 m .39948 .52696 L .39849 .52541 L F
.297 0 0 r
.26993 .57636 m .2702 .57661 L .26798 .57635 L F
.26993 .57636 m .2719 .57724 L .2702 .57661 L F
.665 .474 .616 r
.49174 .46012 m .48915 .46318 L .48915 .46046 L F
.49174 .46012 m .49441 .46356 L .48915 .46318 L F
.647 .47 .63 r
.49578 .46292 m .49174 .46012 L .4966 .46042 L F
.49578 .46292 m .49441 .46356 L .49174 .46012 L F
0 0 .21 r
.70186 .31586 m .70334 .31414 L .70352 .31192 L F
.886 .509 .042 r
.70186 .31586 m .70261 .3182 L .70123 .31691 L F
.70186 .31586 m .70123 .31691 L .70334 .31414 L F
.782 .787 .856 r
.67257 .38873 m .67613 .38585 L .67548 .3859 L F
.67257 .38873 m .67548 .3859 L .67109 .38623 L F
0 .028 .588 r
.67241 .3879 m .67257 .38873 L .67109 .38623 L F
.759 .994 .807 r
.67241 .3879 m .67115 .39011 L .67257 .38873 L F
.67115 .39011 m .67112 .39016 L .67257 .38873 L F
.482 .654 .935 r
.66998 .38841 m .67112 .39016 L .67241 .3879 L F
.018 0 0 r
.67821 .3636 m .67486 .36619 L .67694 .36424 L F
.637 .94 .704 r
.67967 .36176 m .68127 .36089 L .67821 .3636 L F
.635 .936 .693 r
.67967 .36176 m .67821 .3636 L .67694 .36424 L F
.743 .451 .488 r
.53006 .46342 m .53223 .46373 L .53244 .4662 L F
.74 .353 .318 r
.53223 .46373 m .53655 .46625 L .53244 .4662 L F
.688 .247 0 r
.3861 .52742 m .38782 .53037 L .38831 .53067 L F
.691 .248 0 r
.38867 .53177 m .38831 .53067 L .38782 .53037 L F
.38867 .53177 m .38991 .53332 L .38831 .53067 L F
.772 .688 .771 r
.51688 .43475 m .51817 .43835 L .51397 .4377 L F
.777 .681 .757 r
.51817 .43835 m .51343 .44013 L .51397 .4377 L F
.833 .978 .882 r
.59935 .35412 m .59544 .35609 L .59906 .35394 L F
.588 .944 .91 r
.59935 .35412 m .60096 .35244 L .60198 .35273 L F
.584 .936 .776 r
.59935 .35412 m .59906 .35394 L .60096 .35244 L F
.192 0 .095 r
.32661 .57802 m .32848 .57758 L .32881 .57548 L F
0 0 .34 r
.32881 .57548 m .32941 .57511 L .32913 .57209 L F
0 0 0 r
.32881 .57548 m .32848 .57758 L .32941 .57511 L F
.837 .73 .747 r
.38838 .58497 m .39212 .58547 L .38958 .5882 L F
.08 0 0 r
.45483 .59263 m .45394 .59172 L .45616 .59059 L F
.45483 .59263 m .45241 .59338 L .45394 .59172 L F
.762 .603 .682 r
.50775 .4672 m .50771 .46986 L .50366 .46945 L F
0 0 .031 r
.35364 .58905 m .35285 .59132 L .35505 .58737 L F
.993 .837 .582 r
.38244 .61928 m .38351 .62085 L .38164 .6221 L F
.393 .51 .858 r
.23007 .58163 m .23212 .58556 L .23324 .58394 L F
.101 .09 .557 r
.36364 .53627 m .36246 .54062 L .36466 .53645 L F
.36364 .53627 m .36402 .53939 L .36246 .54062 L F
0 0 .354 r
.36362 .54127 m .36246 .54062 L .36402 .53939 L F
.36362 .54127 m .3625 .54335 L .36246 .54062 L F
.62 .804 .97 r
.34959 .65248 m .35395 .65313 L .35211 .65241 L F
.706 .93 .964 r
.35211 .65241 m .35395 .65313 L .35431 .651 L F
.748 .836 .918 r
.50876 .45681 m .50545 .4575 L .50719 .45683 L F
.706 .984 .826 r
.67316 .31185 m .67432 .30989 L .6761 .30899 L F
.67316 .31185 m .67282 .31135 L .67432 .30989 L F
.358 0 .015 r
.30412 .56353 m .30582 .56442 L .30339 .56456 L F
.31 0 .184 r
.30658 .56274 m .30582 .56442 L .30412 .56353 L F
.566 .182 .274 r
.33322 .51738 m .33654 .51598 L .33318 .51497 L F
.33322 .51738 m .33693 .51717 L .33654 .51598 L F
.604 .273 .383 r
.33869 .51478 m .33687 .51564 L .33656 .51558 L F
.33869 .51478 m .33656 .51558 L .33656 .51555 L F
.33869 .51478 m .33649 .51557 L .33616 .51487 L F
.33687 .51564 m .3369 .51625 L .3366 .51579 L F
.33659 .51577 m .3366 .51579 L .33659 .51578 L F
.33687 .51564 m .3366 .51579 L .33659 .51577 L F
.185 .222 .667 r
.33693 .51717 m .3366 .51579 L .33659 .5158 L F
.604 .273 .383 r
.3369 .51625 m .33693 .51717 L .33659 .51578 L F
.33869 .51478 m .33807 .51562 L .33687 .51564 L F
.33807 .51562 m .33693 .51717 L .33687 .51564 L F
0 .068 .59 r
.33649 .51557 m .3365 .51565 L .33651 .51561 L F
.656 .592 .771 r
.33318 .51497 m .33547 .51566 L .33649 .51557 L F
.33547 .51566 m .3365 .51565 L .33649 .51557 L F
.604 .273 .383 r
.33649 .51557 m .33322 .51738 L .33318 .51497 L F
.33687 .51564 m .33659 .51578 L .33649 .51557 L F
0 .068 .59 r
.3365 .51565 m .33659 .51578 L .33651 .51561 L F
.656 .592 .771 r
.33547 .51566 m .33654 .51598 L .3365 .51565 L F
.604 .273 .383 r
.33659 .51578 m .33322 .51738 L .33649 .51557 L F
.33656 .51555 m .33656 .51558 L .33649 .51557 L F
.582 .569 .804 r
.33883 .50987 m .33869 .51478 L .33607 .51237 L F
0 .068 .59 r
.33651 .51561 m .3366 .51579 L .33745 .51262 L F
.33659 .51578 m .3366 .51579 L .33651 .51561 L F
.185 .222 .667 r
.33693 .51717 m .33745 .51262 L .3366 .51579 L F
.33669 .51643 m .33659 .5158 L .33654 .51598 L F
.33693 .51717 m .33659 .5158 L .33669 .51643 L F
.604 .273 .383 r
.33616 .51487 m .33649 .51557 L .33318 .51497 L F
0 .068 .59 r
.33607 .51237 m .33649 .51557 L .33745 .51262 L F
.33649 .51557 m .33651 .51561 L .33745 .51262 L F
.3365 .51565 m .33654 .51598 L .3366 .51579 L F
.604 .273 .383 r
.33659 .51578 m .33693 .51717 L .33322 .51738 L F
.656 .592 .771 r
.33318 .51497 m .33649 .51557 L .33607 .51237 L F
.582 .569 .804 r
.33883 .50987 m .34057 .51455 L .33869 .51478 L F
.48 .844 .991 r
.3373 .60773 m .33364 .60782 L .33558 .60708 L F
.473 .364 .65 r
.46475 .5209 m .46516 .52358 L .46284 .52413 L F
.5 .431 .71 r
.46516 .52358 m .46346 .52797 L .46284 .52413 L F
.776 .676 .753 r
.49952 .44756 m .49696 .45085 L .49552 .44699 L F
.79 .331 0 r
.58162 .38028 m .5839 .38329 L .58278 .38212 L F
.816 .467 0 r
.5839 .38329 m .58379 .38428 L .58278 .38212 L F
.5839 .38329 m .58472 .38598 L .58379 .38428 L F
.744 .828 .368 r
.59925 .37076 m .59754 .37473 L .59969 .37332 L F
.675 .332 .386 r
.60195 .37279 m .59925 .37076 L .59969 .37332 L F
.662 .162 .05 r
.70582 .31091 m .70926 .31157 L .70665 .30962 L F
.559 0 0 r
.70665 .30962 m .70926 .31157 L .71102 .31229 L F
.809 .8 .843 r
.46624 .45539 m .4673 .45713 L .46463 .4561 L F
.867 .422 .112 r
.71102 .31229 m .70926 .31157 L .70993 .31332 L F
.774 .275 .021 r
.70993 .31332 m .71303 .3149 L .71102 .31229 L F
.594 .021 0 r
.33524 .6419 m .33619 .64322 L .33473 .64215 L F
.33524 .6419 m .33789 .64342 L .33619 .64322 L F
.156 .207 .664 r
.21238 .58816 m .21296 .59207 L .21441 .59041 L F
.279 .28 .681 r
.21343 .5947 m .21441 .59041 L .21296 .59207 L F
.734 .611 .72 r
.51517 .44407 m .51671 .44787 L .51266 .44735 L F
0 0 .439 r
.61474 .42771 m .61664 .43132 L .61592 .42969 L F
0 0 .468 r
.61771 .43376 m .61592 .42969 L .61664 .43132 L F
.045 0 .229 r
.2425 .57535 m .2418 .5778 L .23989 .5786 L F
.093 0 .204 r
.24106 .58034 m .23989 .5786 L .2418 .5778 L F
.24106 .58034 m .23945 .5812 L .23989 .5786 L F
0 0 .53 r
.22606 .56223 m .22777 .56447 L .22808 .56591 L F
0 .001 .543 r
.22777 .56447 m .22757 .56893 L .22808 .56591 L F
.765 .955 .935 r
.24653 .52887 m .24667 .53088 L .25002 .52878 L F
.915 .959 .634 r
.24653 .52887 m .24484 .5325 L .24667 .53088 L F
0 0 0 r
.63832 .39358 m .6348 .39552 L .63693 .3943 L F
.362 .801 .64 r
.64078 .39221 m .63832 .39358 L .63693 .3943 L F
.608 .43 .616 r
.48386 .46684 m .48389 .46974 L .48116 .47026 L F
.655 .467 .619 r
.48386 .46684 m .48654 .46648 L .48389 .46974 L F
0 .003 .576 r
.35226 .68763 m .35389 .68436 L .35302 .68467 L F
.914 .522 .125 r
.60829 .40891 m .60751 .41 L .60642 .40798 L F
.60829 .40891 m .60907 .41131 L .60751 .41 L F
.733 .669 .787 r
.57862 .42554 m .57579 .42839 L .57455 .42552 L F
.57862 .42554 m .57455 .42552 L .5754 .42473 L F
0 0 0 r
.57385 .42616 m .57268 .42803 L .57556 .42526 L F
.57384 .42616 m .57383 .42618 L .57385 .42616 L F
.57383 .42618 m .57268 .42803 L .57385 .42616 L F
.733 .669 .787 r
.5754 .42473 m .57455 .42552 L .57406 .4244 L F
.869 .941 .863 r
.66423 .37428 m .66064 .37615 L .66302 .37371 L F
.651 .959 .931 r
.66586 .37242 m .66423 .37428 L .66302 .37371 L F
.789 .997 .792 r
.66244 .37413 m .66302 .37371 L .66064 .37615 L F
.105 0 0 r
.66256 .37411 m .66302 .37371 L .66244 .37413 L F
.651 .959 .931 r
.66569 .37261 m .66665 .37302 L .66423 .37428 L F
.105 0 0 r
.66527 .37376 m .66338 .37372 L .66256 .37411 L F
.66338 .37372 m .66302 .37371 L .66256 .37411 L F
.651 .959 .931 r
.66586 .37242 m .66594 .37249 L .66569 .37261 L F
.66594 .37249 m .66665 .37302 L .66569 .37261 L F
.612 .914 .648 r
.22783 .53998 m .23097 .53704 L .22894 .53849 L F
.758 .471 0 r
.33126 .63084 m .33177 .63292 L .33084 .6296 L F
.232 .645 .958 r
.25008 .61596 m .25181 .61722 L .24896 .61658 L F
.599 .414 .603 r
.47252 .4951 m .4699 .49842 L .46987 .49566 L F
.752 .754 .854 r
.63596 .41252 m .63163 .41179 L .63468 .41117 L F
.781 .701 .776 r
.63634 .40842 m .63596 .41252 L .63468 .41117 L F
.63634 .40842 m .63872 .40933 L .63596 .41252 L F
.819 .788 .823 r
.38901 .68891 m .38911 .68424 L .38683 .68732 L F
.38901 .68891 m .38929 .68804 L .38911 .68424 L F
.957 .72 .537 r
.38683 .68732 m .38695 .69034 L .38901 .68891 L F
.38683 .68732 m .38695 .69034 L .38901 .68891 L F
.594 .311 .456 r
.36407 .69246 m .36588 .69107 L .36211 .69144 L F
.559 .354 .559 r
.36207 .69413 m .36407 .69246 L .36211 .69144 L F
.194 .702 .901 r
.36632 .7107 m .36686 .71014 L .36488 .70963 L F
.36632 .7107 m .36881 .71065 L .36686 .71014 L F
0 0 0 r
.28945 .51875 m .28555 .51972 L .28745 .51884 L F
.175 .32 .773 r
.57109 .39544 m .57245 .39919 L .57373 .39727 L F
.648 .948 .953 r
.57373 .39727 m .57245 .39919 L .5698 .39889 L F
.442 .292 .582 r
.23203 .5458 m .22988 .54983 L .2308 .54713 L F
.943 .588 .304 r
.39276 .5922 m .39133 .59311 L .39149 .59102 L F
.39276 .5922 m .39315 .59428 L .39133 .59311 L F
.993 .878 .591 r
.41372 .57796 m .4147 .57913 L .41378 .58164 L F
.957 .634 .227 r
.4151 .59524 m .41391 .59425 L .41348 .59138 L F
.994 .838 .579 r
.4151 .59524 m .41315 .59682 L .41391 .59425 L F
.4151 .59524 m .41439 .59805 L .41315 .59682 L F
.36 0 .177 r
.29276 .6235 m .29516 .62311 L .29653 .6206 L F
.702 .341 .361 r
.29653 .6206 m .29516 .62311 L .29916 .62313 L F
.638 .107 0 r
.26345 .53698 m .26899 .53846 L .26504 .53909 L F
.833 .934 .895 r
.65754 .32589 m .65321 .32778 L .65643 .32477 L F
.813 .999 .802 r
.66015 .32315 m .65754 .32589 L .65846 .32362 L F
.734 .935 .953 r
.65846 .32362 m .65754 .32589 L .65643 .32477 L F
.549 .277 .456 r
.51688 .46306 m .51548 .46561 L .51296 .46607 L F
.655 .41 .536 r
.51943 .46323 m .51548 .46561 L .51688 .46306 L F
.581 .392 .589 r
.47871 .47317 m .47869 .47609 L .47575 .47657 L F
.67 .53 .685 r
.48116 .47026 m .4814 .473 L .47871 .47317 L F
.664 .462 .601 r
.4814 .473 m .47869 .47609 L .47871 .47317 L F
.402 0 0 r
.26894 .63487 m .27377 .63624 L .2716 .63556 L F
.392 0 0 r
.26721 .63589 m .26894 .63487 L .2716 .63556 L F
.687 .631 .787 r
.49552 .44699 m .49696 .45085 L .49288 .44996 L F
.882 .914 .843 r
.64089 .33918 m .64119 .33642 L .64254 .3381 L F
.64089 .33918 m .6381 .33982 L .64119 .33642 L F
.94 .94 .764 r
.3477 .63191 m .34731 .63383 L .34622 .63351 L F
.715 .186 0 r
.34731 .63383 m .34544 .63604 L .34622 .63351 L F
.967 .902 .703 r
.34622 .63351 m .34601 .6344 L .3463 .63324 L F
.87 .662 .619 r
.34631 .6332 m .3477 .63191 L .34622 .63351 L F
.967 .902 .703 r
.34622 .63351 m .3463 .63324 L .34631 .6332 L F
.715 .186 0 r
.34544 .63604 m .3453 .63621 L .34622 .63351 L F
.34731 .63383 m .34769 .63539 L .3453 .63621 L F
.34731 .63383 m .34863 .63525 L .34769 .63539 L F
.352 .414 .785 r
.34665 .55206 m .34621 .55658 L .34345 .55439 L F
.34665 .55206 m .34785 .55615 L .34621 .55658 L F
.722 .722 .849 r
.34785 .55615 m .34597 .55925 L .34621 .55658 L F
.715 .604 .731 r
.32468 .52103 m .32548 .52562 L .32826 .52106 L F
.754 .246 0 r
.32383 .52606 m .32687 .52723 L .32548 .52562 L F
.589 .568 .799 r
.32944 .53053 m .32807 .53448 L .32717 .53192 L F
.32944 .53053 m .33076 .53423 L .32807 .53448 L F
.779 .277 0 r
.35706 .61246 m .35675 .61161 L .35533 .6099 L F
.772 .411 .373 r
.35533 .6099 m .35794 .61123 L .35675 .61161 L F
.615 .584 .796 r
.35691 .61136 m .35794 .61123 L .35675 .61161 L F
.756 .313 .199 r
.35533 .6099 m .35697 .61073 L .35637 .61144 L F
.35697 .61073 m .35794 .61123 L .35691 .61136 L F
.35697 .61073 m .35691 .61136 L .35637 .61144 L F
.615 .584 .796 r
.35939 .60759 m .35794 .61123 L .35691 .61136 L F
.35939 .60759 m .3606 .61083 L .35794 .61123 L F
0 0 .078 r
.35939 .60759 m .35691 .61136 L .35892 .60978 L F
.35691 .61136 m .35675 .61161 L .3569 .61148 L F
.35691 .61136 m .3569 .61148 L .35892 .60978 L F
.756 .313 .199 r
.35688 .61137 m .35794 .61123 L .35706 .61246 L F
.353 .267 .618 r
.35706 .61246 m .35892 .60978 L .3569 .61148 L F
.35706 .61246 m .3569 .61148 L .35675 .61161 L F
.756 .313 .199 r
.35637 .61144 m .35688 .61137 L .35706 .61246 L F
.366 .159 .461 r
.35039 .59194 m .35225 .59361 L .35285 .59132 L F
.35039 .59194 m .35014 .59453 L .35225 .59361 L F
.885 .884 .827 r
.34521 .59837 m .34104 .60013 L .34112 .59764 L F
.595 .828 .988 r
.35349 .58422 m .35586 .58577 L .35811 .58486 L F
.649 .415 .551 r
.35505 .58737 m .35811 .58486 L .35586 .58577 L F
.356 0 0 r
.70222 .30335 m .70548 .30318 L .70427 .30418 L F
.884 .991 .756 r
.70534 .30185 m .70548 .30318 L .70789 .29966 L F
.911 .925 .543 r
.70427 .30418 m .70548 .30318 L .70534 .30185 L F
.864 .97 .861 r
.42787 .47052 m .42506 .47382 L .42542 .47107 L F
.81 .934 .913 r
.42506 .47382 m .42353 .47297 L .42542 .47107 L F
.002 0 0 r
.25926 .52292 m .25859 .52322 L .25904 .52186 L F
0 0 0 r
.25904 .52186 m .25784 .52403 L .25945 .5206 L F
.701 .934 .622 r
.25904 .52186 m .25621 .52527 L .25784 .52403 L F
.652 .899 .567 r
.25904 .52186 m .25698 .52392 L .25621 .52527 L F
.002 0 0 r
.25859 .52322 m .25698 .52392 L .25904 .52186 L F
0 0 0 r
.25904 .52186 m .25945 .5206 L .25989 .51967 L F
.877 .45 .177 r
.56505 .39256 m .56848 .39626 L .56673 .39517 L F
.145 0 0 r
.56848 .39626 m .57109 .39544 L .5694 .39696 L F
.981 .691 .378 r
.40489 .53403 m .40341 .53293 L .40331 .53038 L F
1 .818 .503 r
.40489 .53403 m .40335 .53544 L .40341 .53293 L F
.40489 .53403 m .40443 .53679 L .40335 .53544 L F
.413 .467 .807 r
.33065 .52064 m .33211 .52517 L .33385 .5226 L F
.953 .941 .731 r
.57406 .4244 m .57633 .42104 L .5749 .42088 L F
.467 .198 .421 r
.57406 .4244 m .57633 .42104 L .57673 .42371 L F
.549 .024 0 r
.57633 .42104 m .58097 .4219 L .57888 .42037 L F
.119 0 0 r
.58984 .45236 m .59143 .45242 L .58764 .45307 L F
.407 .247 .549 r
.34477 .5663 m .34695 .56835 L .34724 .56578 L F
.34477 .5663 m .34484 .56916 L .34695 .56835 L F
.813 .49 0 r
.39659 .51848 m .39729 .52095 L .396 .51732 L F
.789 .693 .759 r
.64097 .40576 m .63872 .40933 L .63634 .40842 L F
.633 .494 .675 r
.51266 .44735 m .50999 .4506 L .51086 .44878 L F
.365 .82 .934 r
.60156 .36058 m .60305 .36094 L .60331 .36061 L F
.61 .304 .426 r
.28644 .56247 m .28917 .5625 L .28878 .56042 L F
.5 .431 .71 r
.46516 .52358 m .46589 .52733 L .46346 .52797 L F
.461 .379 .677 r
.46589 .52733 m .46399 .53066 L .46346 .52797 L F
.956 .939 .723 r
.64254 .35312 m .64511 .3509 L .64411 .34963 L F
.64254 .35312 m .64332 .35447 L .64511 .3509 L F
.832 .911 .891 r
.64511 .3509 m .64702 .34665 L .64411 .34963 L F
.64511 .3509 m .64825 .34796 L .64702 .34665 L F
.729 .699 .823 r
.49552 .44699 m .49288 .44996 L .49137 .44622 L F
.688 .579 .728 r
.3487 .52724 m .3469 .52858 L .34599 .52522 L F
.787 .811 .871 r
.3487 .52724 m .3469 .52858 L .34505 .52648 L F
.33 .186 .53 r
.32422 .58118 m .32631 .58209 L .32661 .57802 L F
.034 0 .226 r
.32424 .58479 m .32631 .58209 L .32422 .58118 L F
0 0 .278 r
.70245 .29017 m .70281 .28793 L .70394 .28864 L F
.28 .161 .534 r
.70454 .29004 m .70245 .29017 L .70394 .28864 L F
.243 .46 .871 r
.70685 .28962 m .70454 .29004 L .70394 .28864 L F
.386 0 0 r
.70264 .28897 m .70504 .28934 L .70394 .28864 L F
.70504 .28934 m .70685 .28962 L .70394 .28864 L F
0 0 .278 r
.70281 .28793 m .70328 .28495 L .70394 .28864 L F
.28 .161 .534 r
.70454 .29004 m .70269 .29286 L .70245 .29017 L F
.73 .202 0 r
.36055 .5024 m .36254 .50457 L .36452 .50545 L F
.902 .509 .26 r
.36254 .50457 m .36307 .50663 L .36452 .50545 L F
.519 0 0 r
.36452 .50545 m .36307 .50663 L .36367 .50639 L F
.812 .847 .876 r
.64541 .33528 m .64254 .3381 L .64119 .33642 L F
.792 .757 .821 r
.42785 .50631 m .42608 .50836 L .42917 .50864 L F
.784 .563 .601 r
.42512 .51068 m .42917 .50864 L .42608 .50836 L F
.42512 .51068 m .42952 .51158 L .42917 .50864 L F
.626 .688 .889 r
.42785 .50631 m .42917 .50864 L .43185 .50799 L F
0 0 .259 r
.42917 .50864 m .4297 .50903 L .43185 .50799 L F
.42917 .50864 m .42952 .51158 L .4297 .50903 L F
.673 .565 .725 r
.51111 .44325 m .51086 .44878 L .50866 .44422 L F
.51111 .44325 m .51266 .44735 L .51086 .44878 L F
.796 .579 .608 r
.3606 .61083 m .35706 .61246 L .35794 .61123 L F
.707 .695 .837 r
.41949 .49791 m .41591 .49626 L .4189 .49527 L F
.791 .831 .882 r
.42248 .49524 m .41949 .49791 L .4189 .49527 L F
.612 .468 .662 r
.47869 .47609 m .47609 .4795 L .47575 .47657 L F
.769 .724 .81 r
.64037 .40278 m .64097 .40576 L .63724 .40544 L F
.789 .693 .759 r
.64097 .40576 m .63634 .40842 L .63724 .40544 L F
.854 .799 .796 r
.64178 .40105 m .64097 .40576 L .64037 .40278 L F
.349 .415 .789 r
.35695 .69031 m .35486 .69233 L .35402 .68864 L F
0 .117 .66 r
.35608 .69268 m .35486 .69233 L .35695 .69031 L F
.837 .809 .823 r
.68605 .35404 m .68243 .35451 L .68531 .35334 L F
.757 .981 .912 r
.68731 .35147 m .68605 .35404 L .68531 .35334 L F
.68731 .35147 m .6894 .3516 L .68605 .35404 L F
.625 .497 .686 r
.48389 .46974 m .4814 .473 L .48116 .47026 L F
.839 .466 0 r
.33702 .62299 m .33806 .62446 L .33618 .62043 L F
.991 .872 .613 r
.33612 .62662 m .33806 .62446 L .33702 .62299 L F
.98 .819 .414 r
.41386 .58876 m .4128 .59022 L .41287 .58753 L F
.41386 .58876 m .41348 .59138 L .4128 .59022 L F
.726 .987 .807 r
.65553 .38019 m .65245 .38309 L .65374 .38089 L F
.976 .69 .301 r
.65245 .38309 m .65145 .38449 L .65374 .38089 L F
.793 .913 .921 r
.65145 .38449 m .64931 .38835 L .64865 .38757 L F
0 0 0 r
.65056 .38566 m .65145 .38449 L .65041 .38584 L F
.976 .69 .301 r
.65245 .38319 m .65261 .38575 L .65145 .38449 L F
0 0 0 r
.65318 .38258 m .65145 .38449 L .65056 .38566 L F
.976 .69 .301 r
.65245 .38309 m .65245 .38319 L .65145 .38449 L F
.579 .548 .784 r
.33369 .5496 m .33139 .55063 L .32974 .54623 L F
.505 0 0 r
.34873 .49747 m .35264 .4987 L .35048 .49772 L F
.966 .657 .26 r
.41197 .55302 m .41045 .54894 L .41068 .55064 L F
.504 .84 .998 r
.38625 .62337 m .38748 .62433 L .39002 .62361 L F
.95 .745 .591 r
.38291 .68445 m .38457 .6882 L .38461 .68514 L F
.636 .298 .382 r
.38683 .68732 m .38765 .68525 L .38461 .68514 L F
.42 .306 .617 r
.38461 .68514 m .38457 .6882 L .38683 .68732 L F
.754 .48 .519 r
.50366 .46945 m .50771 .46986 L .5075 .47226 L F
.539 .294 .492 r
.50771 .46986 m .51022 .47189 L .5075 .47226 L F
.582 .279 .419 r
.50771 .46986 m .5104 .46973 L .51022 .47189 L F
.43 .216 .485 r
.36214 .56153 m .36007 .55956 L .36251 .55845 L F
.36214 .56153 m .35977 .56243 L .36007 .55956 L F
.187 0 .282 r
.4598 .56242 m .45796 .56314 L .45787 .5649 L F
.4598 .56242 m .45796 .56314 L .45787 .5649 L F
.246 0 0 r
.23785 .61271 m .23557 .61211 L .23782 .61425 L F
0 0 .317 r
.23782 .61425 m .23894 .61578 L .23785 .61271 L F
.23782 .61425 m .23793 .61669 L .23894 .61578 L F
.37 0 0 r
.38341 .61524 m .38199 .6149 L .38063 .61708 L F
.38341 .61524 m .38447 .61489 L .38199 .6149 L F
.759 .678 .772 r
.60492 .3665 m .60625 .37033 L .60886 .36706 L F
.406 .826 .968 r
.60636 .36858 m .60625 .37033 L .605 .37158 L F
.539 .365 .593 r
.60625 .37033 m .60903 .36982 L .60886 .36706 L F
.406 .826 .968 r
.60636 .36858 m .60903 .36982 L .60625 .37033 L F
.492 .621 .906 r
.50206 .44435 m .49826 .44173 L .50064 .44043 L F
.651 .591 .774 r
.50319 .4394 m .50206 .44435 L .50064 .44043 L F
.50319 .4394 m .50453 .4435 L .50206 .44435 L F
.745 .229 0 r
.35894 .50229 m .35945 .50303 L .36055 .5024 L F
.748 .233 0 r
.35945 .50303 m .36254 .50457 L .36055 .5024 L F
.847 .553 .491 r
.27377 .63624 m .27737 .63979 L .27539 .63914 L F
.593 .029 0 r
.27737 .63979 m .2779 .64097 L .27539 .63914 L F
.27737 .63979 m .27967 .64174 L .2779 .64097 L F
.781 .941 .594 r
.28674 .51895 m .28691 .51788 L .28996 .51478 L F
.64 .953 .94 r
.28996 .51478 m .29074 .51319 L .29156 .51356 L F
.548 .814 .449 r
.22091 .55014 m .22198 .54882 L .22347 .54701 L F
0 0 .234 r
.22058 .55279 m .22198 .54882 L .22091 .55014 L F
.293 .78 .71 r
.33833 .55568 m .3401 .55491 L .34166 .55368 L F
.33833 .55568 m .3377 .55584 L .3401 .55491 L F
.673 .83 .959 r
.33616 .54916 m .33813 .55069 L .33965 .54898 L F
.873 .637 .579 r
.35162 .53902 m .34658 .53611 L .34917 .53551 L F
.35162 .53902 m .34631 .53881 L .34658 .53611 L F
.035 0 0 r
.35162 .53902 m .34649 .54154 L .34631 .53881 L F
.35162 .53902 m .34863 .54115 L .34649 .54154 L F
.34863 .54115 m .34723 .54149 L .34649 .54154 L F
.758 .682 .134 r
.35185 .53537 m .35162 .53902 L .34917 .53551 L F
.688 .935 .635 r
.3515 .53809 m .34823 .54143 L .35162 .53902 L F
0 0 .183 r
.35233 .54025 m .353 .54116 L .35405 .53892 L F
.655 .916 .61 r
.35027 .53928 m .34823 .54143 L .3515 .53809 L F
.53 .359 .594 r
.3535 .53943 m .35302 .54006 L .35027 .53928 L F
0 0 .183 r
.35233 .54025 m .35218 .54287 L .353 .54116 L F
.53 .359 .594 r
.35302 .54006 m .35103 .54269 L .35058 .54066 L F
.35302 .54006 m .35058 .54066 L .35027 .53928 L F
.035 0 0 r
.34863 .54115 m .34823 .54143 L .34723 .54149 L F
.758 .682 .134 r
.3518 .5362 m .3515 .53809 L .35162 .53902 L F
.47 .077 .213 r
.3515 .53809 m .3535 .53943 L .3513 .53933 L F
.3515 .53809 m .3513 .53933 L .35027 .53928 L F
.758 .682 .134 r
.35185 .53537 m .3515 .53809 L .3518 .5362 L F
.926 .815 .353 r
.24367 .53523 m .24362 .5373 L .24428 .53729 L F
.87 .856 .826 r
.44389 .51001 m .44649 .51147 L .44518 .50979 L F
.44518 .50979 m .44649 .51147 L .44389 .51001 L F
.368 .649 .964 r
.44518 .50979 m .44741 .50979 L .44649 .51147 L F
.44649 .51147 m .44741 .50979 L .44518 .50979 L F
.902 .986 .762 r
.66015 .32315 m .6608 .3202 L .66164 .32119 L F
.66015 .32315 m .65846 .32362 L .6608 .3202 L F
.658 .299 .352 r
.36478 .60117 m .36877 .60112 L .36635 .60042 L F
.131 .529 .917 r
.2305 .61152 m .23091 .61032 L .22969 .60939 L F
.2305 .61152 m .23373 .61265 L .23091 .61032 L F
.748 .946 .623 r
.33439 .52969 m .33179 .53232 L .32944 .53053 L F
.489 0 0 r
.32944 .53053 m .33251 .53126 L .33439 .52969 L F
.748 .946 .623 r
.33439 .52969 m .33076 .53423 L .33179 .53232 L F
.601 .892 .595 r
.33439 .52969 m .33297 .53076 L .3353 .52928 L F
.33439 .52969 m .33259 .53119 L .33297 .53076 L F
.832 .994 .748 r
.3353 .52928 m .33297 .53076 L .33675 .52615 L F
.409 .845 .721 r
.33616 .52882 m .3353 .52928 L .33833 .52768 L F
.784 .997 .799 r
.33546 .52794 m .33297 .53076 L .33712 .52957 L F
.865 .996 .788 r
.33675 .52615 m .33297 .53076 L .33307 .52905 L F
.784 .997 .799 r
.33499 .52747 m .33297 .53076 L .33546 .52794 L F
.601 .892 .595 r
.33259 .53119 m .33251 .53126 L .33297 .53076 L F
0 0 0 r
.40066 .66569 m .40268 .66256 L .40117 .66534 L F
.951 .855 .432 r
.40117 .66534 m .4007 .66845 L .40066 .66569 L F
0 .244 .759 r
.40691 .54031 m .40702 .53885 L .40443 .53679 L F
0 0 .485 r
.40691 .54031 m .40818 .54267 L .40702 .53885 L F
0 0 .067 r
.53095 .41658 m .53043 .41552 L .53188 .41479 L F
.53095 .41658 m .5297 .41813 L .53043 .41552 L F
.819 .791 .826 r
.3899 .69539 m .39218 .69356 L .38815 .69416 L F
.724 .427 .475 r
.52194 .4631 m .52596 .46354 L .52597 .46586 L F
.681 .422 .524 r
.52596 .46354 m .53007 .4657 L .52597 .46586 L F
.52596 .46354 m .53006 .46342 L .53007 .4657 L F
.486 .365 .639 r
.70752 .26757 m .70935 .26933 L .70691 .26938 L F
.301 .733 .969 r
.44813 .51829 m .44707 .51752 L .44377 .51745 L F
.673 .314 .356 r
.44372 .52011 m .44706 .52059 L .44813 .51829 L F
.827 .961 .897 r
.4485 .51676 m .44707 .51752 L .44813 .51829 L F
.346 0 .198 r
.44813 .51829 m .44941 .51973 L .4485 .51676 L F
.44813 .51829 m .44706 .52059 L .44941 .51973 L F
.254 .607 .954 r
.39869 .68007 m .40063 .68033 L .40037 .68169 L F
.961 .645 .244 r
.39925 .68306 m .40037 .68169 L .40063 .68033 L F
.39925 .68306 m .40078 .68429 L .40037 .68169 L F
.496 .618 .902 r
.37088 .53242 m .37361 .53174 L .37173 .52967 L F
.845 .643 .629 r
.40087 .65614 m .3993 .65295 L .39902 .65566 L F
.908 .502 .125 r
.40036 .65792 m .40087 .65614 L .39902 .65566 L F
.40036 .65792 m .40198 .65887 L .40087 .65614 L F
.42 .341 .662 r
.30781 .63319 m .30837 .6359 L .30582 .63377 L F
.935 .95 .77 r
.54155 .41564 m .54009 .41894 L .5389 .41825 L F
0 0 0 r
.54155 .41564 m .54009 .41894 L .54107 .417 L F
.139 .208 .674 r
.21155 .58595 m .21342 .58585 L .21327 .5841 L F
.21155 .58595 m .21238 .58816 L .21342 .58585 L F
.751 .941 .946 r
.23592 .60267 m .23598 .60462 L .23759 .60235 L F
.828 .353 .031 r
.23378 .60427 m .23598 .60462 L .23592 .60267 L F
.829 .355 .043 r
.23598 .60462 m .2377 .60757 L .23957 .60833 L F
.333 .763 .972 r
.33061 .5015 m .33298 .50127 L .33072 .50055 L F
.369 .246 .579 r
.34456 .69132 m .34253 .69439 L .34479 .69407 L F
.34456 .69132 m .34253 .69439 L .34479 .69407 L F
.739 .731 .845 r
.34214 .69066 m .34253 .69439 L .34456 .69132 L F
.728 .336 0 r
.28262 .64293 m .2847 .64683 L .28341 .64539 L F
.481 0 0 r
.2847 .64683 m .28538 .64776 L .28341 .64539 L F
.2847 .64683 m .28756 .64855 L .28538 .64776 L F
.719 .453 .523 r
.53006 .46342 m .53244 .4662 L .53007 .4657 L F
.126 .234 .706 r
.3256 .54051 m .32712 .53934 L .32456 .53676 L F
0 0 .04 r
.3256 .54051 m .32576 .54078 L .32712 .53934 L F
.574 .28 .431 r
.32712 .53934 m .32575 .54096 L .3287 .53944 L F
0 0 .04 r
.3256 .54051 m .32556 .54319 L .32573 .54107 L F
.32566 .54064 m .32573 .54107 L .32575 .54083 L F
.3256 .54051 m .32573 .54107 L .32566 .54064 L F
0 0 .12 r
.32575 .54119 m .32627 .54169 L .3287 .53944 L F
.32627 .54169 m .32683 .54144 L .3287 .53944 L F
.574 .28 .431 r
.32575 .54096 m .32575 .54119 L .3287 .53944 L F
.055 .215 .713 r
.32456 .53676 m .32712 .53934 L .32529 .53469 L F
.785 .651 .714 r
.32529 .53469 m .32712 .53934 L .32918 .53553 L F
.022 0 .208 r
.32918 .53553 m .32712 .53934 L .3292 .53714 L F
.524 .143 .26 r
.3292 .53714 m .32921 .53812 L .33045 .53718 L F
.041 .23 .731 r
.32952 .53715 m .32918 .53814 L .32972 .5366 L F
.3287 .53944 m .32918 .53814 L .32952 .53715 L F
.524 .143 .26 r
.32918 .53553 m .3292 .53714 L .32954 .537 L F
.32918 .53553 m .32954 .537 L .32957 .53697 L F
.32918 .53553 m .32958 .53698 L .33004 .53562 L F
.022 0 .208 r
.32918 .53553 m .3292 .53678 L .32972 .5366 L F
.3292 .53678 m .3292 .53714 L .32972 .5366 L F
.524 .143 .26 r
.33004 .53562 m .32958 .53698 L .33221 .53586 L F
.766 .969 .682 r
.33179 .53232 m .32918 .53553 L .33076 .53423 L F
.56 .389 .607 r
.32918 .53553 m .33179 .53232 L .33076 .53423 L F
.87 .888 .846 r
.32757 .53403 m .32918 .53553 L .33179 .53232 L F
.56 .389 .607 r
.32918 .53553 m .33221 .53586 L .33179 .53232 L F
.87 .888 .846 r
.32757 .53403 m .33179 .53232 L .33037 .53183 L F
.701 .928 .966 r
.32877 .53199 m .32757 .53403 L .33037 .53183 L F
.406 .517 .858 r
.32877 .53199 m .3306 .53633 L .32972 .5366 L F
.775 .997 .811 r
.33043 .53634 m .32972 .5366 L .3306 .53633 L F
.574 .28 .431 r
.32712 .53934 m .3287 .53944 L .32952 .53715 L F
.32712 .53934 m .32952 .53715 L .3292 .53714 L F
.524 .143 .26 r
.3292 .53733 m .32918 .53814 L .32921 .53812 L F
.32918 .53553 m .32918 .53733 L .3292 .53733 L F
.32918 .53733 m .32918 .53814 L .3292 .53733 L F
.32957 .53697 m .32954 .537 L .32958 .53698 L F
.574 .28 .431 r
.3292 .53714 m .32952 .53715 L .32972 .5366 L F
.032 0 .204 r
.32972 .5366 m .32918 .53814 L .32918 .53553 L F
.816 1 .813 r
.32972 .5366 m .329 .53739 L .32348 .53713 L F
0 0 .04 r
.32575 .54077 m .32575 .54083 L .32576 .54078 L F
.3256 .54051 m .32575 .54083 L .32575 .54077 L F
.903 .985 .738 r
.32556 .54319 m .32469 .54288 L .32576 .54078 L F
.811 .609 .629 r
.32576 .54078 m .32535 .54143 L .32712 .53934 L F
.215 0 .17 r
.32434 .54319 m .32576 .54078 L .32469 .54288 L F
.853 .857 .844 r
.32556 .54319 m .32138 .54492 L .32469 .54288 L F
0 0 0 r
.32157 .54481 m .3231 .54426 L .32469 .54288 L F
.853 .857 .844 r
.32556 .54319 m .32317 .54624 L .32138 .54492 L F
0 0 0 r
.32138 .54492 m .3231 .54426 L .32157 .54481 L F
.215 0 .17 r
.32351 .5439 m .32524 .54145 L .32434 .54319 L F
.3231 .54426 m .3238 .54334 L .32351 .5439 L F
.3238 .54334 m .32524 .54145 L .32351 .5439 L F
.669 .516 .668 r
.32458 .54183 m .31975 .54431 L .3182 .54053 L F
.32514 .54195 m .32434 .5423 L .32458 .54183 L F
.32434 .5423 m .31975 .54431 L .32458 .54183 L F
.215 0 .17 r
.32524 .54145 m .3253 .54137 L .32434 .54319 L F
.3253 .54137 m .32576 .54078 L .32543 .54133 L F
.3253 .54137 m .32543 .54133 L .32434 .54319 L F
.88 .445 .123 r
.32535 .54143 m .32514 .54195 L .32475 .54154 L F
.32528 .54138 m .32475 .54154 L .3223 .53893 L F
.32535 .54143 m .32475 .54154 L .32528 .54138 L F
.215 0 .17 r
.32535 .54143 m .32539 .54353 L .3231 .54426 L F
.3231 .54426 m .32539 .54353 L .32535 .54143 L F
.807 .564 .571 r
.32539 .54353 m .32433 .54382 L .3231 .54426 L F
.215 0 .17 r
.3231 .54426 m .32535 .54143 L .32576 .54078 L F
.32535 .54143 m .3231 .54426 L .32514 .54195 L F
.669 .516 .668 r
.32514 .54195 m .3231 .54426 L .31975 .54431 L F
.325 .759 .969 r
.31497 .54497 m .3191 .5456 L .31668 .54597 L F
.31555 .54506 m .3174 .54475 L .3191 .5456 L F
.31497 .54497 m .3174 .54475 L .31555 .54506 L F
.67 .776 .302 r
.31944 .5444 m .3174 .54475 L .31975 .54431 L F
.31715 .54513 m .3174 .54475 L .31944 .5444 L F
.629 .861 .495 r
.3174 .54475 m .31668 .54597 L .3191 .5456 L F
.5 .852 .993 r
.32138 .54492 m .3174 .54475 L .3191 .5456 L F
.32138 .54492 m .3174 .54475 L .3191 .5456 L F
.98 .737 .494 r
.31668 .54597 m .31477 .54822 L .31497 .54497 L F
.629 .861 .495 r
.3174 .54475 m .31477 .54822 L .31668 .54597 L F
0 0 0 r
.3174 .54475 m .3163 .54719 L .31477 .54822 L F
.67 .776 .302 r
.31715 .54513 m .3163 .54719 L .3174 .54475 L F
.108 0 0 r
.31844 .54494 m .32033 .54493 L .31715 .54513 L F
.3231 .54426 m .32033 .54493 L .31978 .54474 L F
.807 .564 .571 r
.32433 .54382 m .32033 .54493 L .3231 .54426 L F
.108 0 0 r
.3231 .54426 m .31715 .54513 L .31975 .54431 L F
0 .002 .579 r
.32364 .5495 m .32367 .548 L .32138 .54492 L F
.132 .158 .621 r
.32138 .54492 m .32367 .548 L .3231 .54426 L F
0 0 .431 r
.3231 .54426 m .32417 .54593 L .32539 .54353 L F
.3231 .54426 m .32367 .548 L .32417 .54593 L F
.807 .564 .571 r
.32539 .54353 m .32417 .54593 L .32033 .54493 L F
.384 .65 .962 r
.32033 .54493 m .32254 .54492 L .32185 .54399 L F
.215 0 0 r
.32129 .54526 m .32033 .54493 L .32185 .54399 L F
.32087 .5462 m .32033 .54493 L .32129 .54526 L F
.108 0 0 r
.31978 .54474 m .32033 .54493 L .31844 .54494 L F
.384 .65 .962 r
.32033 .54493 m .32265 .54508 L .32254 .54492 L F
.816 1 .813 r
.329 .53739 m .32535 .54143 L .3253 .54133 L F
.32702 .53803 m .3253 .54133 L .32426 .53893 L F
.329 .53739 m .3253 .54133 L .32702 .53803 L F
.329 .53739 m .32426 .53893 L .32348 .53713 L F
.517 .788 .994 r
.32529 .53469 m .32918 .53553 L .32757 .53403 L F
.482 .569 .866 r
.32829 .52914 m .32944 .53053 L .32603 .52946 L F
.577 .496 .727 r
.32944 .53053 m .32717 .53192 L .32603 .52946 L F
.654 .96 .763 r
.32449 .53164 m .32829 .52914 L .32603 .52946 L F
.32449 .53164 m .32519 .53053 L .32829 .52914 L F
.32519 .53053 m .32539 .53022 L .32573 .53009 L F
.32519 .53053 m .32573 .53009 L .32829 .52914 L F
.476 .428 .725 r
.32603 .52946 m .32687 .52723 L .32383 .52606 L F
.32603 .52946 m .32829 .52914 L .32687 .52723 L F
.711 .476 .567 r
.32838 .52792 m .32524 .52753 L .32852 .5274 L F
.139 0 0 r
.32829 .52914 m .32539 .53022 L .32784 .52995 L F
.711 .476 .567 r
.32784 .52995 m .32693 .52911 L .32838 .52792 L F
.32693 .52911 m .32524 .52753 L .32838 .52792 L F
.533 .638 .9 r
.32529 .53469 m .32539 .53022 L .32449 .53164 L F
.32529 .53469 m .32757 .53403 L .32539 .53022 L F
.762 .747 .839 r
.32972 .5366 m .32348 .53713 L .32578 .53337 L F
.701 .928 .966 r
.32877 .53199 m .32578 .53337 L .32757 .53403 L F
.406 .517 .858 r
.32877 .53199 m .32972 .5366 L .32578 .53337 L F
.775 .997 .811 r
.32691 .53668 m .32972 .5366 L .33043 .53634 L F
.816 1 .813 r
.32972 .5366 m .32548 .53869 L .32541 .54001 L F
.329 .53739 m .32541 .54001 L .32535 .54143 L F
.32972 .5366 m .32541 .54001 L .329 .53739 L F
.524 .143 .26 r
.3292 .53714 m .33045 .53718 L .33221 .53586 L F
.877 .597 .511 r
.33039 .54189 m .3287 .53944 L .32644 .54185 L F
.775 .997 .811 r
.32691 .53668 m .32548 .53869 L .32972 .5366 L F
.76 .704 .8 r
.32934 .54032 m .32548 .53869 L .32691 .53668 L F
.33039 .54189 m .32853 .54068 L .32934 .54032 L F
.32853 .54068 m .32548 .53869 L .32934 .54032 L F
0 0 .12 r
.32627 .54169 m .32644 .54185 L .32683 .54144 L F
.32535 .54143 m .32582 .54161 L .32575 .54119 L F
.32582 .54161 m .32644 .54185 L .32575 .54119 L F
.574 .28 .431 r
.32575 .54096 m .32535 .54143 L .32575 .54119 L F
.643 .46 .621 r
.35651 .57561 m .3541 .57901 L .35399 .57581 L F
.724 .645 .77 r
.34835 .67791 m .35016 .68173 L .35278 .6793 L F
.592 .373 .552 r
.34978 .68429 m .35302 .68467 L .35016 .68173 L F
.044 0 .123 r
.28984 .57083 m .28863 .56984 L .29078 .56943 L F
.28984 .57083 m .28792 .5718 L .28863 .56984 L F
0 0 0 r
.70752 .26757 m .70479 .27073 L .70696 .26882 L F
.724 .771 .89 r
.66049 .39185 m .66441 .3925 L .66299 .39059 L F
.808 .793 .838 r
.66299 .39059 m .66441 .3925 L .66705 .3894 L F
0 .023 .576 r
.3275 .69227 m .3291 .6946 L .3283 .693 L F
.075 .404 .858 r
.3283 .693 m .3291 .6946 L .32984 .69346 L F
.024 .332 .815 r
.3291 .6946 m .33215 .69727 L .32984 .69346 L F
.636 .941 .959 r
.62306 .43395 m .61882 .43502 L .61993 .43659 L F
.461 .379 .677 r
.46589 .52733 m .46631 .53003 L .46399 .53066 L F
.514 .409 .673 r
.46631 .53003 m .46423 .53346 L .46399 .53066 L F
.799 .963 .644 r
.6761 .30899 m .67837 .30486 L .67943 .30638 L F
.6761 .30899 m .676 .30836 L .67837 .30486 L F
.764 .981 .729 r
.6761 .30899 m .67432 .30989 L .676 .30836 L F
.816 .548 .533 r
.51242 .43095 m .50865 .43352 L .51103 .43 L F
.51242 .43095 m .51269 .43391 L .50865 .43352 L F
.552 .87 .994 r
.51242 .43095 m .51363 .42913 L .51514 .43015 L F
.595 .918 .973 r
.51242 .43095 m .51103 .43 L .51363 .42913 L F
.354 .217 .552 r
.30832 .61434 m .31011 .61652 L .31054 .61349 L F
.259 .196 .593 r
.30868 .61712 m .31011 .61652 L .30832 .61434 L F
.726 .555 .659 r
.3646 .52774 m .3669 .52783 L .36441 .52701 L F
.36353 .52769 m .36598 .53058 L .3669 .52783 L F
.708 .651 .791 r
.36955 .52736 m .3669 .52783 L .36914 .52486 L F
0 0 0 r
.36914 .52486 m .3685 .52664 L .3669 .52783 L F
.539 .305 .509 r
.3685 .52664 m .36441 .52701 L .3669 .52783 L F
.734 .615 .725 r
.36598 .53058 m .36955 .52736 L .3669 .52783 L F
.539 .305 .509 r
.3685 .52664 m .3672 .52853 L .36441 .52701 L F
.832 .497 .422 r
.3672 .52853 m .3642 .52623 L .36441 .52701 L F
.3642 .52623 m .36316 .52544 L .36441 .52701 L F
.726 .555 .659 r
.36353 .52769 m .3646 .52774 L .36441 .52701 L F
.36353 .52769 m .36371 .53051 L .36598 .53058 L F
.599 .95 .831 r
.2546 .52124 m .25534 .52004 L .25668 .51983 L F
.532 .912 .941 r
.2546 .52124 m .25299 .52104 L .25534 .52004 L F
0 0 0 r
.33094 .68473 m .33045 .68497 L .327 .6879 L F
.826 .842 .859 r
.53964 .40242 m .53621 .40295 L .53769 .40199 L F
.634 .111 0 r
.54025 .40409 m .53964 .40242 L .53769 .40199 L F
.347 .313 .679 r
.54222 .40427 m .5405 .40482 L .53964 .40242 L F
.634 .111 0 r
.54025 .40409 m .54222 .40427 L .53964 .40242 L F
.921 .884 .78 r
.68214 .3571 m .68127 .36089 L .68159 .35778 L F
.942 .958 .664 r
.68159 .35778 m .68127 .36089 L .67967 .36176 L F
.584 .94 .92 r
.2972 .51563 m .29433 .5159 L .29316 .51737 L F
.58 .864 .541 r
.29433 .5159 m .2928 .51762 L .29316 .51737 L F
.463 .806 .999 r
.59309 .46395 m .59452 .46225 L .59189 .46192 L F
.59309 .46395 m .59601 .4634 L .59452 .46225 L F
.742 .23 0 r
.32761 .49867 m .32717 .50045 L .32584 .49733 L F
.32761 .49867 m .3289 .50052 L .32717 .50045 L F
.571 .817 .991 r
.38112 .5529 m .37873 .55371 L .37945 .5516 L F
.901 .773 .281 r
.41402 .57271 m .41326 .57372 L .41283 .57134 L F
.41402 .57271 m .41369 .57517 L .41326 .57372 L F
.974 .664 .321 r
.60264 .42478 m .60106 .42107 L .60132 .42371 L F
.915 .523 .237 r
.60148 .42572 m .60264 .42478 L .60132 .42371 L F
.60148 .42572 m .60398 .42839 L .60264 .42478 L F
.683 .784 .927 r
.61816 .37907 m .62012 .37563 L .61682 .37842 L F
0 0 0 r
.61816 .37907 m .62132 .37699 L .62096 .37771 L F
.683 .784 .927 r
.61816 .37907 m .62096 .37771 L .62012 .37563 L F
.646 .411 .549 r
.35496 .56642 m .35482 .56928 L .3511 .56919 L F
.581 .357 .541 r
.35742 .56857 m .35496 .56642 L .35767 .56593 L F
.35742 .56857 m .35482 .56928 L .35496 .56642 L F
.879 .6 .08 r
.24252 .60481 m .24273 .60755 L .24188 .60599 L F
.71 .354 .371 r
.24486 .60757 m .24252 .60481 L .24539 .60451 L F
.24486 .60757 m .24273 .60755 L .24252 .60481 L F
.422 0 .069 r
.34227 .52659 m .34505 .52648 L .34599 .52522 L F
.821 .734 .769 r
.34461 .52122 m .34599 .52522 L .3479 .5209 L F
.495 .046 .113 r
.34505 .52648 m .34779 .52665 L .34599 .52522 L F
.436 .29 .584 r
.3479 .5209 m .34599 .52522 L .34808 .52356 L F
.495 .046 .113 r
.34505 .52648 m .34779 .52665 L .34599 .52522 L F
.688 .579 .728 r
.3487 .52724 m .34599 .52522 L .34808 .52356 L F
.522 .293 .509 r
.32569 .55947 m .328 .55728 L .32588 .55748 L F
0 .2 .728 r
.57939 .39286 m .57769 .39256 L .57637 .39122 L F
.57939 .39286 m .58022 .39474 L .57769 .39256 L F
0 0 .13 r
.40151 .6613 m .40117 .66534 L .40268 .66256 L F
.769 .877 .925 r
.62202 .34927 m .61782 .35002 L .61986 .34827 L F
.685 .888 .972 r
.62453 .34791 m .62202 .34927 L .61986 .34827 L F
.474 .432 .731 r
.46857 .53915 m .46608 .54099 L .46522 .53697 L F
.413 .309 .627 r
.46857 .53915 m .46637 .54354 L .46608 .54099 L F
.373 .065 .309 r
.34905 .54557 m .35194 .54583 L .35218 .54287 L F
.34905 .54557 m .34959 .54727 L .35194 .54583 L F
.392 .791 .986 r
.59117 .45612 m .59176 .45695 L .58779 .4565 L F
.498 .887 .96 r
.56559 .46576 m .56693 .46619 L .56951 .46527 L F
.707 .686 .827 r
.50714 .4405 m .50866 .44422 L .50453 .4435 L F
.737 .701 .817 r
.51169 .44136 m .50866 .44422 L .50714 .4405 L F
.715 .659 .793 r
.51169 .44136 m .51111 .44325 L .50866 .44422 L F
.745 .956 .941 r
.2482 .52684 m .25002 .52878 L .25181 .52721 L F
.2482 .52684 m .24653 .52887 L .25002 .52878 L F
.896 .954 .611 r
.39625 .60268 m .39803 .60105 L .39672 .60021 L F
.39625 .60268 m .39627 .60456 L .39803 .60105 L F
.498 .068 .153 r
.55691 .41059 m .5543 .40931 L .55413 .41098 L F
.473 .133 .308 r
.55691 .41059 m .55754 .40871 L .5543 .40931 L F
.741 .22 0 r
.58816 .40128 m .58592 .39871 L .58407 .39852 L F
.896 .746 .687 r
.39596 .652 m .3997 .64963 L .39507 .65022 L F
.39596 .652 m .3993 .65295 L .3997 .64963 L F
.166 .674 .902 r
.34505 .52648 m .34779 .52665 L .3487 .52724 L F
.91 .982 .743 r
.3487 .52724 m .35016 .52299 L .34808 .52356 L F
.3487 .52724 m .34779 .52665 L .35016 .52299 L F
.661 .623 .801 r
.28069 .51991 m .27675 .52073 L .27579 .51701 L F
.577 .574 .813 r
.36156 .60703 m .36607 .60697 L .3647 .60354 L F
.641 .23 0 r
.60313 .4019 m .60499 .40502 L .60337 .40423 L F
.887 .461 .162 r
.60499 .40502 m .60456 .40702 L .60337 .40423 L F
.60499 .40502 m .60642 .40798 L .60456 .40702 L F
.557 .847 .998 r
.62012 .37563 m .62132 .37699 L .622 .37651 L F
.998 .811 .463 r
.62096 .37771 m .62132 .37699 L .62012 .37563 L F
.948 .605 .202 r
.27579 .62001 m .27559 .62245 L .27746 .62366 L F
.829 .51 0 r
.27736 .62514 m .27746 .62366 L .27559 .62245 L F
.27736 .62514 m .27809 .62625 L .27746 .62366 L F
.232 0 0 r
.30354 .63657 m .30397 .63685 L .30231 .63892 L F
.30397 .63685 m .30397 .63685 L .30394 .63689 L F
.30397 .63685 m .30394 .63689 L .30231 .63892 L F
.136 .174 .638 r
.30342 .6361 m .30231 .63892 L .30397 .63685 L F
0 0 .266 r
.30335 .64041 m .30231 .63892 L .30342 .6361 L F
.419 .269 .569 r
.30242 .63638 m .3029 .63847 L .30342 .6361 L F
.3029 .63847 m .30335 .64041 L .30339 .63772 L F
.3029 .63847 m .30339 .63772 L .30342 .6361 L F
.232 0 0 r
.30354 .63657 m .30646 .63743 L .30397 .63685 L F
.556 .911 .965 r
.37294 .70805 m .37589 .7083 L .37807 .70726 L F
.182 .449 .876 r
.57558 .38931 m .57343 .39 L .57219 .38851 L F
.57558 .38931 m .57637 .39122 L .57343 .39 L F
0 0 .039 r
.22579 .54354 m .22347 .54701 L .22566 .54385 L F
0 0 0 r
.22347 .54701 m .22338 .54776 L .22566 .54385 L F
.22347 .54701 m .22198 .54882 L .22338 .54776 L F
.711 .61 .743 r
.51343 .44013 m .51517 .44407 L .51111 .44325 L F
.719 .588 .708 r
.51111 .44325 m .51517 .44407 L .51266 .44735 L F
.775 .756 .835 r
.38911 .68424 m .38929 .68804 L .39334 .68425 L F
.75 .705 .81 r
.38616 .58861 m .38682 .59167 L .38292 .59119 L F
.409 .289 .604 r
.38544 .59347 m .38292 .59119 L .38682 .59167 L F
.295 .066 .386 r
.38941 .59082 m .38682 .59167 L .38958 .5882 L F
.455 .504 .82 r
.38941 .59082 m .38682 .59167 L .38616 .58861 L F
0 0 0 r
.38834 .59146 m .38682 .59167 L .38941 .59082 L F
.38834 .59146 m .38544 .59347 L .38682 .59167 L F
.71 .546 .664 r
.48654 .46648 m .48668 .4692 L .48389 .46974 L F
.669 .535 .692 r
.48915 .46318 m .49278 .46718 L .48654 .46648 L F
.653 .467 .62 r
.49278 .46718 m .48668 .4692 L .48654 .46648 L F
.353 0 0 r
.4659 .58545 m .46437 .58733 L .46175 .58757 L F
.502 .146 .295 r
.46808 .58444 m .46437 .58733 L .4659 .58545 L F
.599 .223 .301 r
.72285 .33807 m .72505 .33839 L .72574 .33992 L F
.63 .879 .988 r
.61084 .3764 m .61425 .3767 L .61462 .37563 L F
.849 .607 .573 r
.61305 .3797 m .61425 .3767 L .61084 .3764 L F
.398 .635 .951 r
.61462 .37563 m .61425 .3767 L .61563 .37473 L F
0 0 0 r
.61563 .37473 m .61425 .3767 L .61305 .3797 L F
.569 .474 .707 r
.47878 .47885 m .47649 .48197 L .47609 .4795 L F
.47878 .47885 m .48017 .48288 L .47649 .48197 L F
.551 .409 .64 r
.48017 .48288 m .4771 .48641 L .47649 .48197 L F
.795 .99 .746 r
.36742 .68304 m .36797 .68346 L .36694 .68453 L F
.922 .833 .74 r
.36742 .68304 m .36532 .6872 L .36379 .68611 L F
.36742 .68304 m .36379 .68611 L .36727 .68552 L F
.912 .697 .197 r
.36703 .68274 m .36742 .68304 L .36727 .68552 L F
.36685 .68064 m .36742 .68304 L .36703 .68274 L F
.795 .99 .746 r
.36742 .68304 m .36968 .68168 L .36797 .68346 L F
.772 .994 .873 r
.36816 .68091 m .37271 .67912 L .36968 .68168 L F
.92 .977 .731 r
.36816 .68091 m .36968 .68168 L .36742 .68304 L F
.861 .79 .779 r
.37115 .59388 m .37277 .59411 L .37321 .59213 L F
.37115 .59388 m .3688 .59492 L .37277 .59411 L F
.476 .055 .16 r
.29465 .65998 m .29775 .65974 L .29701 .66093 L F
0 .398 .839 r
.2928 .65806 m .29465 .65998 L .29701 .66093 L F
.673 .405 .507 r
.55914 .38852 m .55514 .3857 L .55666 .38819 L F
.55914 .38852 m .55968 .3863 L .55514 .3857 L F
.958 .705 .513 r
.36344 .62924 m .36571 .63034 L .36515 .6332 L F
.494 .818 1 r
.36741 .62909 m .36571 .63034 L .36344 .62924 L F
0 0 .235 r
.36515 .6332 m .36571 .63034 L .36741 .62909 L F
.827 .898 .89 r
.67318 .32766 m .67446 .32911 L .67632 .32703 L F
.862 .947 .87 r
.70358 .32275 m .69973 .32465 L .70103 .32302 L F
.873 .923 .856 r
.70358 .32275 m .70103 .32302 L .70251 .32141 L F
.315 0 .156 r
.27874 .57343 m .27593 .57522 L .27576 .57448 L F
.884 .779 .741 r
.69959 .30153 m .70222 .30335 L .70065 .29826 L F
.941 .635 .433 r
.70164 .30517 m .70222 .30335 L .69959 .30153 L F
.528 .578 .849 r
.70065 .29826 m .70222 .30335 L .70534 .30185 L F
.356 0 0 r
.70222 .30335 m .70427 .30418 L .70164 .30517 L F
.169 0 .165 r
.70534 .30185 m .70222 .30335 L .70164 .30517 L F
.559 .576 .828 r
.68727 .32811 m .68985 .32781 L .68607 .32404 L F
.977 .919 .616 r
.31879 .59153 m .31801 .59455 L .31721 .59438 L F
.664 .462 .601 r
.4814 .473 m .48137 .47563 L .47869 .47609 L F
.676 .568 .726 r
.48389 .46974 m .48628 .47199 L .4814 .473 L F
.651 .466 .621 r
.4814 .473 m .48412 .47515 L .48137 .47563 L F
.4814 .473 m .48628 .47199 L .48412 .47515 L F
.286 .656 .97 r
.34565 .70233 m .34887 .70415 L .34985 .70368 L F
.931 .806 .7 r
.64731 .40444 m .65024 .40247 L .64913 .40131 L F
.64731 .40444 m .64952 .40514 L .65024 .40247 L F
.823 .863 .876 r
.65024 .40247 m .65185 .39814 L .64913 .40131 L F
.65024 .40247 m .65332 .39963 L .65185 .39814 L F
.746 .25 .051 r
.70696 .26882 m .70935 .26933 L .70752 .26757 L F
.097 0 .145 r
.35593 .59938 m .35492 .59814 L .35701 .59773 L F
.35593 .59938 m .35412 .60052 L .35492 .59814 L F
.549 .122 .182 r
.3625 .54335 m .36548 .54375 L .36613 .5426 L F
.149 0 .383 r
.36613 .5426 m .36793 .54289 L .36817 .53973 L F
.173 0 0 r
.36613 .5426 m .36548 .54375 L .36793 .54289 L F
.559 .357 .563 r
.31504 .53817 m .31442 .53972 L .3177 .53746 L F
.452 .741 .99 r
.35804 .70895 m .36377 .71031 L .36298 .70928 L F
.396 .707 .985 r
.36298 .70928 m .36377 .71031 L .36488 .70963 L F
.666 .737 .903 r
.44572 .46314 m .44173 .46224 L .44423 .46031 L F
.726 .765 .884 r
.44801 .4622 m .44572 .46314 L .44423 .46031 L F
.936 .636 .447 r
.38851 .69706 m .3899 .69539 L .38815 .69416 L F
.708 .674 .815 r
.60331 .36061 m .60515 .36365 L .60677 .3628 L F
.692 .589 .735 r
.45244 .55596 m .45503 .55278 L .45243 .55358 L F
.45244 .55596 m .45623 .5566 L .45503 .55278 L F
.215 .001 .358 r
.29757 .64356 m .30045 .63978 L .29993 .64258 L F
.466 .435 .74 r
.29993 .64258 m .29831 .64577 L .29757 .64356 L F
.522 .333 .566 r
.46735 .49862 m .4672 .50184 L .46467 .50284 L F
.498 .26 .483 r
.4699 .49842 m .4672 .50184 L .46735 .49862 L F
0 .391 .821 r
.71438 .31603 m .71394 .31647 L .71303 .3149 L F
.54 .665 .918 r
.71834 .31803 m .71394 .31647 L .71735 .31811 L F
0 .391 .821 r
.71438 .31603 m .71735 .31811 L .71394 .31647 L F
.311 .803 .828 r
.32114 .66696 m .32637 .66602 L .3231 .66574 L F
.769 .956 .933 r
.3231 .66574 m .32637 .66602 L .32818 .6643 L F
.624 .8 .37 r
.2997 .64337 m .29831 .64577 L .30065 .64567 L F
.485 .424 .714 r
.36955 .52736 m .37157 .52335 L .36914 .52486 L F
.36955 .52736 m .37203 .52695 L .37157 .52335 L F
.086 .182 .669 r
.36955 .52736 m .37173 .52967 L .37203 .52695 L F
.218 .194 .617 r
.22973 .59682 m .23031 .60106 L .22787 .59884 L F
.741 .218 0 r
.59194 .40431 m .58998 .40189 L .58816 .40128 L F
.853 .883 .86 r
.47493 .4892 m .47598 .48822 L .4771 .48641 L F
.512 .854 .586 r
.30013 .54973 m .30124 .54863 L .30354 .54682 L F
.71 .529 .642 r
.30354 .54682 m .30383 .55004 L .30013 .54973 L F
.469 .36 .647 r
.30554 .54568 m .30383 .55004 L .30354 .54682 L F
.185 0 0 r
.30124 .54863 m .30554 .54568 L .30354 .54682 L F
0 0 .362 r
.27377 .63624 m .27463 .63767 L .2716 .63556 L F
0 .137 .675 r
.27463 .63767 m .27539 .63914 L .27572 .6384 L F
.427 0 0 r
.27482 .63795 m .27463 .63767 L .27572 .6384 L F
.27205 .63658 m .27463 .63767 L .27482 .63795 L F
0 0 .362 r
.27377 .63624 m .27433 .63723 L .27463 .63767 L F
.27433 .63723 m .27539 .63914 L .27463 .63767 L F
.216 0 0 r
.35405 .53892 m .35838 .53623 L .35478 .53784 L F
.35405 .53892 m .35644 .53841 L .35838 .53623 L F
.233 0 .301 r
.35838 .53623 m .36066 .53564 L .36087 .5332 L F
.624 .353 .487 r
.35644 .53841 m .36066 .53564 L .35838 .53623 L F
.809 .399 .272 r
.56505 .39256 m .56347 .3943 L .56557 .39098 L F
.56505 .39256 m .56673 .39517 L .56347 .3943 L F
.666 .909 .978 r
.47977 .45036 m .47613 .45069 L .47829 .44921 L F
.738 .812 .91 r
.48141 .44639 m .47977 .45036 L .47829 .44921 L F
.48141 .44639 m .48192 .44943 L .47977 .45036 L F
.968 .921 .591 r
.34166 .55368 m .34254 .55229 L .34345 .55439 L F
.34166 .55368 m .3411 .55227 L .34254 .55229 L F
.34166 .55368 m .3401 .55491 L .3411 .55227 L F
.99 .731 .423 r
.60917 .41363 m .6106 .41529 L .61044 .41736 L F
.649 .961 .782 r
.66989 .37042 m .66665 .37302 L .66821 .37102 L F
.635 .953 .936 r
.66821 .37102 m .66665 .37302 L .66586 .37242 L F
.289 .337 .739 r
.4593 .55569 m .46006 .55961 L .46214 .5583 L F
.065 0 .336 r
.46214 .5583 m .46006 .55961 L .4598 .56242 L F
.87 .952 .861 r
.641 .3546 m .64332 .35447 L .64254 .35312 L F
.736 .604 .71 r
.50115 .45405 m .50082 .45661 L .49914 .45694 L F
.727 .774 .89 r
.45727 .45886 m .45998 .45607 L .46112 .45945 L F
.738 .79 .894 r
.46245 .45527 m .46112 .45945 L .45998 .45607 L F
.46245 .45527 m .46463 .4561 L .46112 .45945 L F
.625 .598 .803 r
.44034 .54596 m .43662 .54348 L .43907 .54247 L F
.458 .442 .752 r
.44183 .54194 m .44034 .54596 L .43907 .54247 L F
.44183 .54194 m .44288 .54567 L .44034 .54596 L F
.897 .586 .45 r
.39902 .65566 m .3993 .65295 L .39596 .652 L F
.74 .75 .86 r
.31724 .52873 m .31704 .52947 L .32015 .52761 L F
.731 .577 .683 r
.50082 .45661 m .49827 .45983 L .49914 .45694 L F
.947 .591 .283 r
.60918 .44215 m .61046 .44103 L .60815 .43911 L F
.60918 .44215 m .61083 .44326 L .61046 .44103 L F
.736 .883 .478 r
.39488 .60638 m .39429 .60791 L .39627 .60456 L F
.889 .908 .501 r
.39625 .60268 m .39488 .60638 L .39627 .60456 L F
.656 .791 .947 r
.43753 .46177 m .43921 .46347 L .43516 .46286 L F
.708 .808 .927 r
.44173 .46224 m .43921 .46347 L .43753 .46177 L F
.68 .952 .953 r
.33604 .65889 m .3379 .65907 L .33546 .66025 L F
.33604 .65889 m .3379 .65907 L .33546 .66025 L F
.595 .516 .736 r
.35482 .56928 m .35245 .57229 L .3511 .56919 L F
.35482 .56928 m .35533 .57182 L .35245 .57229 L F
.361 .563 .914 r
.45033 .54718 m .45484 .54902 L .45178 .54539 L F
.853 .883 .86 r
.47493 .4892 m .4771 .48641 L .47756 .48853 L F
.531 .371 .609 r
.47493 .4892 m .47756 .48853 L .47506 .4918 L F
.599 .423 .615 r
.47493 .4892 m .47506 .4918 L .47248 .49252 L F
.594 .538 .761 r
.72952 .33814 m .73242 .33747 L .73332 .33538 L F
.579 .395 .596 r
.60903 .36982 m .61197 .36674 L .60886 .36706 L F
.60903 .36982 m .61197 .36674 L .60886 .36706 L F
.163 0 0 r
.2374 .58227 m .23654 .5833 L .23324 .58394 L F
.633 .361 .488 r
.23945 .5812 m .23654 .5833 L .2374 .58227 L F
.541 .868 .994 r
.25989 .51967 m .25668 .51983 L .25941 .51885 L F
.732 .919 .956 r
.2637 .51797 m .25989 .51967 L .25941 .51885 L F
.712 .547 .665 r
.25989 .51967 m .26321 .52709 L .26451 .52408 L F
.506 .001 0 r
.25989 .51967 m .26142 .5218 L .25904 .52186 L F
.712 .547 .665 r
.26233 .52173 m .26451 .52408 L .26253 .52189 L F
.374 0 0 r
.26236 .52176 m .26253 .52189 L .26517 .52163 L F
.26142 .5218 m .26253 .52189 L .26236 .52176 L F
.712 .547 .665 r
.25989 .51967 m .26087 .52061 L .26233 .52173 L F
.26087 .52061 m .26307 .52271 L .26236 .52176 L F
.26087 .52061 m .26236 .52176 L .26233 .52173 L F
.26307 .52271 m .26451 .52408 L .26233 .52173 L F
.374 0 0 r
.26222 .52158 m .26517 .52163 L .26375 .52117 L F
.506 .001 0 r
.25989 .51967 m .26233 .52173 L .26142 .5218 L F
.374 0 0 r
.26142 .5218 m .26236 .52176 L .26233 .52173 L F
.506 .001 0 r
.26233 .52173 m .26253 .52189 L .26142 .5218 L F
.374 0 0 r
.26142 .5218 m .26233 .52173 L .26222 .52158 L F
.26236 .52176 m .26517 .52163 L .26222 .52158 L F
0 0 .059 r
.38911 .68424 m .38765 .68525 L .38683 .68732 L F
.45 0 0 r
.63851 .42408 m .64129 .42462 L .63778 .42442 L F
.049 0 .238 r
.22579 .54354 m .22733 .54309 L .22783 .53998 L F
0 0 0 r
.22648 .54482 m .22579 .54354 L .22566 .54385 L F
.22648 .54482 m .22733 .54309 L .22579 .54354 L F
0 .349 .694 r
.37172 .51225 m .37264 .51272 L .36866 .51107 L F
.725 .24 0 r
.37172 .51225 m .3748 .51562 L .37264 .51272 L F
.822 .347 0 r
.61307 .38688 m .60974 .38318 L .60913 .38578 L F
.628 .088 0 r
.61178 .38761 m .61298 .38686 L .60913 .38578 L F
0 .256 .753 r
.61118 .38642 m .61178 .38761 L .60913 .38578 L F
.973 .896 .536 r
.6104 .38849 m .61178 .38761 L .61118 .38642 L F
.61034 .38863 m .61178 .38761 L .6104 .38849 L F
.628 .088 0 r
.61178 .38761 m .61307 .38688 L .61298 .38686 L F
.537 0 0 r
.615 .38785 m .61307 .38688 L .61178 .38761 L F
.4 .171 .447 r
.37157 .52335 m .36914 .52486 L .37115 .52136 L F
.37157 .52335 m .36914 .52486 L .37115 .52136 L F
.93 .612 .152 r
.62674 .42102 m .62817 .42483 L .62718 .42364 L F
.62672 .42095 m .62817 .42483 L .62718 .42364 L F
.82 .566 .555 r
.62718 .42364 m .63059 .42648 L .62817 .42483 L F
0 .22 .7 r
.62817 .42483 m .62861 .42486 L .62718 .42364 L F
.62861 .42486 m .6289 .42488 L .62718 .42364 L F
.62861 .42486 m .63059 .42648 L .6289 .42488 L F
.62817 .42483 m .63059 .42648 L .62861 .42486 L F
.82 .566 .555 r
.62861 .42486 m .62708 .4265 L .63051 .42648 L F
.62718 .42364 m .62718 .42369 L .62861 .42486 L F
.62718 .42369 m .62708 .4265 L .62861 .42486 L F
.62718 .42364 m .63051 .42648 L .63059 .42648 L F
.523 .315 .54 r
.6289 .42488 m .62759 .42605 L .62718 .42364 L F
.62759 .42605 m .62708 .4265 L .62718 .42364 L F
.93 .612 .152 r
.62672 .42095 m .62674 .42102 L .62718 .42364 L F
.718 .911 .552 r
.39402 .65094 m .39507 .65022 L .3935 .6523 L F
0 0 .375 r
.21384 .56262 m .21316 .56632 L .21472 .56455 L F
0 0 .304 r
.21316 .56632 m .21449 .56728 L .21472 .56455 L F
.21316 .56632 m .21351 .56826 L .21449 .56728 L F
.581 .529 .762 r
.46636 .51232 m .46359 .51442 L .46404 .51446 L F
.688 .846 .959 r
.62715 .3571 m .63015 .35666 L .62865 .35499 L F
.243 0 0 r
.62802 .3579 m .63015 .35666 L .62715 .3571 L F
.415 .714 .985 r
.62865 .35499 m .63015 .35666 L .63177 .35587 L F
0 0 0 r
.63177 .35587 m .63015 .35666 L .62975 .35689 L F
.63177 .35587 m .62975 .35689 L .63008 .35678 L F
.415 .714 .985 r
.62865 .35499 m .63066 .35556 L .63125 .3548 L F
.63066 .35556 m .63177 .35587 L .63125 .3548 L F
0 0 0 r
.63008 .35678 m .62975 .35689 L .62802 .3579 L F
.63177 .35587 m .62802 .3579 L .63125 .3548 L F
.696 .604 .75 r
.63048 .35665 m .63231 .35346 L .63125 .3548 L F
.63231 .35346 m .63277 .35266 L .63125 .3548 L F
.63033 .357 m .63054 .35663 L .63048 .35665 L F
.63054 .35663 m .63277 .35266 L .63048 .35665 L F
.181 .707 .861 r
.26813 .5724 m .27049 .57225 L .27231 .57248 L F
.542 .494 .752 r
.27231 .57248 m .27329 .56862 L .27097 .56904 L F
.27231 .57248 m .27469 .57189 L .27329 .56862 L F
.395 0 0 r
.27049 .57225 m .27469 .57189 L .27231 .57248 L F
.653 .326 .406 r
.29665 .55849 m .29792 .55904 L .29703 .55741 L F
.29665 .55849 m .29792 .55904 L .29703 .55741 L F
.397 .346 .684 r
.46685 .53272 m .46522 .53697 L .46423 .53346 L F
.46685 .53272 m .46731 .53684 L .46522 .53697 L F
.474 .432 .731 r
.46857 .53915 m .46522 .53697 L .46731 .53684 L F
0 0 0 r
.29555 .66736 m .2946 .67108 L .29558 .67103 L F
.648 .865 .981 r
.29333 .6729 m .29558 .67103 L .2946 .67108 L F
.612 .914 .648 r
.22783 .53998 m .22882 .5386 L .23097 .53704 L F
0 0 .189 r
.22783 .53998 m .22895 .54144 L .22882 .5386 L F
.22783 .53998 m .22733 .54309 L .22895 .54144 L F
.279 .776 .738 r
.71834 .31803 m .72059 .31716 L .72123 .31704 L F
.299 .795 .803 r
.71735 .31811 m .72059 .31716 L .71834 .31803 L F
.702 .451 .541 r
.33919 .52469 m .33833 .52768 L .34227 .52659 L F
.711 .61 .743 r
.51343 .44013 m .51111 .44325 L .51169 .44136 L F
.132 .68 .761 r
.73076 .33055 m .72807 .331 L .72708 .32768 L F
.275 .609 .955 r
.7342 .3315 m .73115 .33063 L .73351 .33118 L F
.231 0 0 r
.73204 .33111 m .73351 .33118 L .73328 .33113 L F
.73186 .33102 m .73328 .33113 L .73115 .33063 L F
.73204 .33111 m .73328 .33113 L .73186 .33102 L F
.133 .164 .627 r
.73204 .33111 m .73076 .33055 L .73289 .33372 L F
.162 .142 .586 r
.73076 .33055 m .73076 .33252 L .73204 .33111 L F
.231 0 0 r
.73204 .33111 m .73115 .33063 L .73137 .32906 L F
.813 .894 .476 r
.73137 .32906 m .73115 .33063 L .73076 .33055 L F
0 0 .324 r
.73117 .33044 m .73117 .33046 L .73076 .33055 L F
.73145 .33036 m .73117 .33046 L .73117 .33044 L F
.082 .297 .78 r
.72782 .32548 m .73076 .33055 L .72708 .32768 L F
.651 .603 .787 r
.73137 .32906 m .73076 .33055 L .72782 .32548 L F
0 0 .324 r
.73148 .33028 m .73076 .33055 L .72846 .32819 L F
0 .297 .776 r
.72846 .32819 m .73122 .33045 L .73122 .33016 L F
.637 .466 .635 r
.7314 .33029 m .73148 .33028 L .73105 .32998 L F
.73111 .33009 m .73105 .32998 L .72846 .32819 L F
.7314 .33029 m .73105 .32998 L .73111 .33009 L F
0 0 .324 r
.73148 .33028 m .73145 .33036 L .73076 .33055 L F
.702 .45 .54 r
.73144 .33033 m .73148 .33028 L .7314 .33029 L F
0 .297 .776 r
.73122 .33045 m .73204 .33111 L .7315 .33035 L F
0 0 .324 r
.73145 .33036 m .73145 .33037 L .73117 .33046 L F
.73145 .33037 m .73122 .33045 L .73117 .33046 L F
0 .297 .776 r
.73122 .33045 m .7315 .33035 L .73121 .32994 L F
.72846 .32819 m .73076 .33055 L .73122 .33045 L F
.637 .466 .635 r
.7261 .33132 m .7314 .33029 L .72846 .32819 L F
0 .297 .776 r
.73122 .33045 m .73076 .33055 L .73204 .33111 L F
0 0 .324 r
.73144 .33039 m .73076 .33252 L .73076 .33055 L F
.132 .68 .761 r
.73076 .33055 m .73115 .33063 L .72998 .33077 L F
.73076 .33055 m .72998 .33077 L .72807 .331 L F
.702 .45 .54 r
.72737 .33486 m .73144 .33033 L .7261 .33132 L F
.73144 .33033 m .7314 .33029 L .7261 .33132 L F
.356 .138 .438 r
.73076 .33252 m .73289 .33372 L .73204 .33111 L F
.876 .524 .029 r
.73204 .33111 m .73289 .33372 L .73121 .32994 L F
.73204 .33111 m .73289 .33372 L .73121 .32994 L F
0 0 .555 r
.73121 .32994 m .73186 .3314 L .73242 .33184 L F
.73186 .3314 m .73289 .33372 L .73266 .3328 L F
.73186 .3314 m .73266 .3328 L .73242 .33184 L F
0 .297 .776 r
.72846 .32819 m .73122 .33016 L .73122 .33014 L F
.73035 .32939 m .73122 .33014 L .73121 .32994 L F
.72846 .32819 m .73122 .33014 L .73035 .32939 L F
0 0 .324 r
.73145 .33037 m .73144 .33039 L .73122 .33045 L F
.702 .45 .54 r
.72737 .33486 m .73076 .33252 L .73126 .33097 L F
.73089 .33094 m .73126 .33097 L .73148 .33028 L F
.72737 .33486 m .73126 .33097 L .73089 .33094 L F
0 .388 .794 r
.23944 .60754 m .23957 .60833 L .2377 .60757 L F
.23944 .60754 m .24307 .60986 L .23957 .60833 L F
.41 .341 .668 r
.32986 .61298 m .32758 .61141 L .33042 .61059 L F
.32986 .61298 m .32796 .61399 L .32758 .61141 L F
.658 .706 .883 r
.33669 .5459 m .3316 .54354 L .33475 .54274 L F
.33669 .5459 m .3316 .54354 L .33475 .54274 L F
.468 .21 .439 r
.33669 .5459 m .33616 .54916 L .33369 .5496 L F
.536 .433 .684 r
.33883 .54308 m .33973 .54654 L .33669 .5459 L F
.368 .023 .242 r
.33973 .54654 m .33616 .54916 L .33669 .5459 L F
.635 .556 .748 r
.45503 .55278 m .45623 .5566 L .4593 .55569 L F
.544 .512 .771 r
.49361 .46623 m .48915 .46318 L .49441 .46356 L F
.49361 .46623 m .49278 .46718 L .48915 .46318 L F
.709 .962 .944 r
.64764 .39018 m .64341 .39148 L .64576 .3906 L F
.829 .999 .825 r
.64931 .38835 m .64764 .39018 L .64576 .3906 L F
.378 0 0 r
.42899 .58895 m .43137 .58981 L .43241 .58933 L F
.054 0 0 r
.43137 .58981 m .43479 .58984 L .43241 .58933 L F
.905 .634 .131 r
.38709 .49219 m .38663 .4933 L .38628 .49094 L F
.38709 .49219 m .38723 .49403 L .38663 .4933 L F
.793 .826 .878 r
.63112 .34536 m .62686 .34637 L .62981 .344 L F
.769 .877 .925 r
.6334 .34384 m .63112 .34536 L .62981 .344 L F
.808 .997 .855 r
.23407 .53435 m .23097 .53704 L .23128 .53502 L F
.735 .991 .865 r
.23407 .53435 m .23445 .53267 L .23562 .53269 L F
.23407 .53435 m .23128 .53502 L .23445 .53267 L F
.645 .681 .87 r
.47208 .45007 m .47056 .45395 L .46894 .45207 L F
.47208 .45007 m .47306 .45301 L .47056 .45395 L F
.216 .229 .658 r
.47209 .55827 m .47287 .561 L .47111 .5626 L F
.166 .148 .591 r
.47287 .561 m .47289 .56518 L .47111 .5626 L F
.959 .773 .326 r
.34673 .58424 m .34738 .58447 L .34703 .5815 L F
.945 .697 .231 r
.34673 .58424 m .34698 .58701 L .34738 .58447 L F
.455 .073 .225 r
.34738 .58447 m .34698 .58701 L .34863 .58437 L F
.509 .628 .904 r
.32868 .62973 m .32931 .62653 L .3268 .62755 L F
.32868 .62973 m .33084 .6296 L .32931 .62653 L F
.064 0 .465 r
.47541 .5739 m .47365 .57837 L .47378 .57567 L F
.962 .865 .462 r
.69786 .33778 m .69676 .33961 L .69675 .33665 L F
.69786 .33778 m .69721 .34133 L .69676 .33961 L F
.446 .202 .449 r
.36087 .5332 m .3638 .53284 L .36371 .53051 L F
.757 .621 .709 r
.36066 .53564 m .3638 .53284 L .36087 .5332 L F
.934 .807 .696 r
.3638 .53284 m .36598 .53058 L .36371 .53051 L F
.583 .945 .871 r
.28747 .65523 m .28899 .65504 L .28732 .65531 L F
.979 .736 .496 r
.28938 .65234 m .29031 .65487 L .28899 .65504 L F
0 0 .246 r
.29061 .65079 m .28938 .65234 L .28899 .65504 L F
.29061 .65079 m .28899 .65504 L .28962 .65405 L F
.583 .945 .871 r
.28962 .65405 m .28899 .65504 L .28747 .65523 L F
.979 .736 .496 r
.29031 .65487 m .29068 .6559 L .28899 .65504 L F
.647 .101 0 r
.28899 .65504 m .29068 .6559 L .2928 .65806 L F
.733 .669 .787 r
.57862 .42554 m .57406 .4244 L .57673 .42371 L F
.857 .798 .793 r
.58097 .4219 m .57862 .42554 L .57673 .42371 L F
0 0 .554 r
.59123 .37939 m .59117 .38078 L .58893 .37895 L F
.59123 .37939 m .59197 .38293 L .59117 .38078 L F
.587 .745 .952 r
.33573 .49526 m .33199 .49418 L .33396 .49439 L F
.034 .583 .832 r
.33396 .49439 m .33803 .4952 L .33573 .49526 L F
.644 .435 .584 r
.34863 .58437 m .35123 .5848 L .35045 .58218 L F
.489 .344 .61 r
.35045 .58218 m .35123 .5848 L .35349 .58422 L F
.499 0 0 r
.56824 .38804 m .57219 .38851 L .5692 .38731 L F
0 0 .195 r
.43145 .5685 m .43196 .57131 L .43197 .57221 L F
.761 .683 .136 r
.43196 .57131 m .43162 .57407 L .43197 .57221 L F
.732 .919 .956 r
.2637 .51797 m .25941 .51885 L .2621 .51764 L F
.519 .9 .956 r
.2637 .51797 m .26424 .51676 L .26605 .51737 L F
.2637 .51797 m .2621 .51764 L .26424 .51676 L F
.648 .865 .981 r
.29333 .6729 m .29747 .67213 L .29558 .67103 L F
.85 .869 .855 r
.29747 .67213 m .29733 .66724 L .29558 .67103 L F
.857 .798 .793 r
.58097 .4219 m .57673 .42371 L .57888 .42037 L F
.619 .484 .676 r
.47248 .49252 m .47506 .4918 L .47252 .4951 L F
.887 .942 .843 r
.63211 .42806 m .63484 .42493 L .63352 .42393 L F
.433 .8 .995 r
.63352 .42393 m .63484 .42493 L .63778 .42442 L F
.519 .419 .682 r
.33473 .61538 m .33307 .6184 L .33756 .61634 L F
0 0 .227 r
.69511 .36906 m .69516 .36681 L .69611 .36466 L F
.954 .622 .345 r
.59699 .41672 m .5982 .41537 L .59637 .41372 L F
.59699 .41672 m .59866 .41783 L .5982 .41537 L F
.734 .608 .718 r
.33273 .60525 m .33364 .60782 L .33076 .60772 L F
.617 .359 .504 r
.33364 .60782 m .33042 .61059 L .33076 .60772 L F
.33364 .60782 m .33303 .61053 L .33042 .61059 L F
.447 .444 .763 r
.33558 .60708 m .33364 .60782 L .33273 .60525 L F
.229 .528 .919 r
.32303 .62535 m .32424 .62712 L .3268 .62755 L F
0 0 .413 r
.38222 .55015 m .38275 .55072 L .38231 .54836 L F
.368 .006 .213 r
.32793 .63478 m .3257 .63347 L .3251 .63551 L F
.759 .693 .789 r
.44627 .54567 m .44744 .54996 L .44413 .54981 L F
.726 .383 .398 r
.44744 .54996 m .4459 .55139 L .44413 .54981 L F
.418 .473 .81 r
.44895 .54813 m .44744 .54996 L .44627 .54567 L F
.625 .903 .603 r
.44895 .54813 m .4459 .55139 L .44744 .54996 L F
.581 .529 .762 r
.46636 .51232 m .46618 .51379 L .46359 .51442 L F
.908 .845 .77 r
.64747 .40835 m .64952 .40514 L .64731 .40444 L F
.523 .432 .694 r
.46618 .51379 m .46684 .51746 L .46434 .51818 L F
.479 .358 .637 r
.46684 .51746 m .46475 .5209 L .46434 .51818 L F
.92 .581 .122 r
.59478 .41213 m .59306 .40811 L .59358 .4106 L F
0 .038 .565 r
.59637 .41372 m .59478 .41213 L .59358 .4106 L F
.364 .648 .964 r
.59575 .35944 m .59865 .35774 L .59584 .3591 L F
.59575 .35944 m .60156 .36058 L .59865 .35774 L F
.346 .321 .688 r
.38983 .67889 m .38992 .68182 L .39169 .68091 L F
.104 0 .213 r
.38992 .68182 m .38911 .68424 L .39169 .68091 L F
.414 .179 .446 r
.32877 .66283 m .33067 .66038 L .33067 .65942 L F
.752 .53 .594 r
.52194 .4631 m .51954 .46586 L .51943 .46323 L F
.52194 .4631 m .52329 .46572 L .51954 .46586 L F
.724 .427 .475 r
.52194 .4631 m .52597 .46586 L .52329 .46572 L F
0 0 0 r
.24827 .57346 m .24914 .5729 L .25109 .57176 L F
.36 .012 .233 r
.69345 .32745 m .69621 .3273 L .69642 .32586 L F
.32 .187 .539 r
.69444 .3306 m .69621 .3273 L .69345 .32745 L F
.678 .977 .888 r
.59832 .46195 m .59965 .46187 L .59848 .45969 L F
.523 .539 .814 r
.59965 .46187 m .60124 .45904 L .59848 .45969 L F
.59965 .46187 m .60233 .46218 L .60124 .45904 L F
.133 .201 .669 r
.21238 .58816 m .21441 .59041 L .21342 .58585 L F
.628 .539 .735 r
.4672 .50184 m .46477 .50484 L .46467 .50284 L F
.805 .907 .912 r
.64702 .34665 m .64825 .34796 L .64986 .34626 L F
.655 .41 .536 r
.51943 .46323 m .51954 .46586 L .51548 .46561 L F
.654 .496 .658 r
.49914 .45694 m .49827 .45983 L .4966 .46042 L F
.783 .849 .901 r
.34623 .51883 m .34461 .52122 L .3479 .5209 L F
.754 .668 .766 r
.35059 .51778 m .3479 .5209 L .34763 .5183 L F
.332 .634 .962 r
.3479 .5209 m .34831 .51916 L .34623 .51883 L F
.945 .713 .556 r
.35016 .52299 m .34831 .51916 L .3479 .5209 L F
.392 .258 .576 r
.34808 .52356 m .35016 .52299 L .3479 .5209 L F
.55 .246 .404 r
.27329 .56862 m .27838 .5687 L .27744 .56557 L F
.54 .24 .407 r
.27744 .56557 m .27951 .56792 L .2798 .56515 L F
.27744 .56557 m .27838 .5687 L .27951 .56792 L F
.887 .942 .843 r
.63211 .42806 m .63352 .42393 L .63059 .42648 L F
.139 .489 .903 r
.33964 .69864 m .34026 .69733 L .33766 .69762 L F
.33964 .69864 m .34243 .69971 L .34026 .69733 L F
.632 .878 .533 r
.22915 .59123 m .23179 .58803 L .23107 .58997 L F
.414 .191 .465 r
.23107 .58997 m .22924 .59411 L .22915 .59123 L F
.281 .187 .568 r
.23179 .58803 m .23372 .59018 L .23107 .58997 L F
.284 .102 .449 r
.23372 .59018 m .23145 .59397 L .23107 .58997 L F
.156 0 0 r
.23187 .60436 m .23378 .60427 L .2334 .60505 L F
.195 0 0 r
.26515 .54917 m .26329 .54875 L .26569 .54848 L F
0 0 0 r
.23563 .59728 m .23541 .59774 L .23573 .59735 L F
.23558 .59724 m .23563 .59728 L .23698 .59687 L F
.774 .998 .837 r
.23698 .59687 m .23563 .59728 L .23758 .59512 L F
0 0 0 r
.23563 .59728 m .23573 .59735 L .23758 .59512 L F
.23365 .59774 m .23563 .59728 L .23558 .59724 L F
.026 0 .032 r
.23365 .59774 m .23266 .59987 L .23563 .59728 L F
.783 .979 .909 r
.29741 .51365 m .2972 .51563 L .29848 .51359 L F
.29741 .51365 m .29433 .5159 L .2972 .51563 L F
.464 .78 .998 r
.38592 .51094 m .38694 .50929 L .38451 .5094 L F
.68 .202 0 r
.58162 .38028 m .58197 .37807 L .58484 .37916 L F
.58162 .38028 m .5812 .38031 L .58197 .37807 L F
.58162 .38028 m .58278 .38212 L .5812 .38031 L F
0 0 0 r
.27701 .53931 m .27507 .54234 L .27512 .54022 L F
.977 .919 .616 r
.31879 .59153 m .31721 .59438 L .31754 .59322 L F
.31879 .59153 m .31754 .59322 L .31899 .5914 L F
.186 0 .184 r
.29846 .63055 m .29562 .63341 L .29709 .6332 L F
.43 .113 .326 r
.29846 .63055 m .29833 .6292 L .30042 .62956 L F
.29846 .63055 m .30003 .63225 L .29833 .6292 L F
.29846 .63055 m .29709 .6332 L .30003 .63225 L F
.795 .845 .889 r
.63193 .4011 m .63606 .39979 L .63402 .39771 L F
.412 .118 .353 r
.63606 .39979 m .63832 .39896 L .63849 .40087 L F
0 .346 .803 r
.63402 .39771 m .63606 .39979 L .63849 .40087 L F
.739 .813 .91 r
.48497 .44673 m .48192 .44943 L .48141 .44639 L F
.737 .751 .863 r
.32104 .52852 m .32314 .5305 L .32603 .52946 L F
.85 .982 .693 r
.23097 .53704 m .22882 .5386 L .23128 .53502 L F
0 0 0 r
.21384 .56262 m .21486 .56184 L .21596 .55969 L F
0 0 .375 r
.21384 .56262 m .21472 .56455 L .21486 .56184 L F
.865 .996 .787 r
.4321 .52411 m .4295 .52736 L .43082 .52586 L F
.256 .766 .843 r
.58111 .4554 m .58372 .45492 L .57979 .45528 L F
.916 .921 .804 r
.65332 .39963 m .65562 .39627 L .65446 .39515 L F
.838 .927 .89 r
.65446 .39515 m .65562 .39627 L .65841 .3934 L F
.812 .934 .565 r
.23377 .54214 m .23336 .5439 L .2353 .5404 L F
0 0 0 r
.23377 .54214 m .23203 .5458 L .23336 .5439 L F
.69 .52 .651 r
.3824 .6889 m .38563 .68959 L .38457 .6882 L F
.189 .117 .539 r
.38563 .68959 m .38683 .68732 L .38457 .6882 L F
.015 0 .231 r
.30101 .62713 m .30042 .62956 L .30259 .62601 L F
.726 .765 .884 r
.44801 .4622 m .44423 .46031 L .44674 .45918 L F
.72 .812 .922 r
.4493 .45808 m .44801 .4622 L .44674 .45918 L F
.4493 .45808 m .45096 .45966 L .44801 .4622 L F
.692 .946 .959 r
.5194 .42366 m .51757 .4247 L .51861 .42263 L F
.886 .573 .45 r
.51757 .4247 m .51524 .42592 L .51861 .42263 L F
.51757 .4247 m .51787 .42723 L .51524 .42592 L F
.866 .513 .01 r
.32068 .5984 m .32147 .60096 L .3197 .59688 L F
.628 .539 .735 r
.4672 .50184 m .46731 .50424 L .46477 .50484 L F
.593 .465 .674 r
.46808 .50741 m .46477 .50484 L .46731 .50424 L F
.46808 .50741 m .46485 .50969 L .46477 .50484 L F
.546 .147 .237 r
.37951 .69212 m .3824 .6889 L .37783 .69059 L F
.652 .219 .208 r
.38241 .69203 m .3824 .6889 L .37951 .69212 L F
.38241 .69203 m .38563 .68959 L .3824 .6889 L F
.759 .995 .851 r
.62722 .36526 m .63082 .36335 L .63004 .36217 L F
.838 .928 .89 r
.63082 .36335 m .63271 .35916 L .63004 .36217 L F
.63082 .36335 m .63392 .36036 L .63271 .35916 L F
.9 .524 .309 r
.32301 .64171 m .32521 .64234 L .32586 .64549 L F
.638 .107 0 r
.26345 .53698 m .26593 .53876 L .26899 .53846 L F
.825 .836 .857 r
.2635 .5396 m .26899 .53846 L .26593 .53876 L F
.2635 .5396 m .26544 .54083 L .26899 .53846 L F
0 .437 .861 r
.43037 .59284 m .43335 .59465 L .43296 .59393 L F
.841 .566 .522 r
.43335 .59465 m .43068 .59703 L .43296 .59393 L F
0 0 .061 r
.43335 .59465 m .43317 .59564 L .43429 .59797 L F
.841 .566 .522 r
.43335 .59465 m .43429 .59797 L .43068 .59703 L F
.801 .809 .858 r
.3006 .5555 m .29792 .55904 L .30051 .55919 L F
.041 0 0 r
.298 .56159 m .30051 .55919 L .29792 .55904 L F
.298 .56159 m .30264 .56035 L .30051 .55919 L F
.089 .647 .745 r
.26138 .55098 m .26107 .55091 L .26309 .55006 L F
.26138 .55098 m .25798 .5511 L .26107 .55091 L F
.639 .477 .647 r
.51296 .46607 m .51453 .4682 L .5104 .46973 L F
.658 .52 .684 r
.51548 .46561 m .51453 .4682 L .51296 .46607 L F
.322 .05 .336 r
.29562 .63341 m .29275 .6367 L .29527 .63607 L F
.284 .267 .664 r
.29562 .63341 m .29783 .63581 L .29709 .6332 L F
.535 .305 .512 r
.29527 .63607 m .29783 .63581 L .29562 .63341 L F
.29527 .63607 m .29783 .63581 L .29562 .63341 L F
.398 .834 .698 r
.38163 .66084 m .37892 .66231 L .37956 .66181 L F
0 0 .121 r
.37956 .66181 m .37892 .66231 L .37861 .665 L F
.965 .643 .348 r
.55124 .40096 m .55278 .4022 L .55166 .40361 L F
.793 .86 .9 r
.5543 .39932 m .55278 .4022 L .55124 .40096 L F
.723 .879 .475 r
.55166 .40361 m .55278 .4022 L .5543 .39932 L F
0 .08 .615 r
.29333 .63921 m .29428 .64303 L .29521 .64153 L F
.437 .169 .408 r
.29365 .64638 m .28991 .64295 L .29042 .64551 L F
.29397 .64647 m .2937 .64623 L .29365 .64638 L F
.2937 .64623 m .28991 .64295 L .29365 .64638 L F
.684 .667 .827 r
.29042 .64551 m .29291 .64767 L .29397 .64647 L F
0 0 .109 r
.29421 .64552 m .29406 .64549 L .29397 .64647 L F
.29521 .64153 m .29397 .64647 L .29521 .64453 L F
0 0 0 r
.29291 .64767 m .29361 .64671 L .29397 .64647 L F
.29361 .64671 m .29521 .64453 L .29403 .64638 L F
.29361 .64671 m .29403 .64638 L .29397 .64647 L F
.29291 .64767 m .29334 .64729 L .29345 .64697 L F
.466 .419 .721 r
.29005 .64792 m .2934 .65025 L .29291 .64767 L F
0 0 .44 r
.29291 .64767 m .29442 .64972 L .29347 .64718 L F
.29291 .64767 m .2934 .65025 L .29442 .64972 L F
.822 .382 .192 r
.29213 .64789 m .29347 .64718 L .29442 .64972 L F
.684 .667 .827 r
.29042 .64551 m .29005 .64792 L .29291 .64767 L F
.822 .382 .192 r
.29043 .64653 m .29312 .64711 L .29213 .64789 L F
.29312 .64711 m .29347 .64718 L .29213 .64789 L F
0 0 0 r
.29345 .64697 m .29347 .64718 L .29453 .64557 L F
.29334 .64729 m .29347 .64718 L .29345 .64697 L F
.29446 .64556 m .29453 .64557 L .29521 .64453 L F
.29291 .64767 m .29453 .64557 L .29446 .64556 L F
0 0 .109 r
.29521 .64153 m .29428 .64303 L .29406 .64549 L F
.29521 .64153 m .29406 .64549 L .29421 .64552 L F
0 .186 .705 r
.38122 .58226 m .38221 .58144 L .38123 .58096 L F
.117 .428 .87 r
.38122 .58226 m .38481 .58373 L .38221 .58144 L F
.506 0 0 r
.37676 .51778 m .37913 .51908 L .38002 .51824 L F
.816 .334 .027 r
.38002 .51824 m .37913 .51908 L .38142 .52008 L F
.753 .282 0 r
.38618 .52866 m .3861 .52742 L .38504 .52587 L F
.38618 .52866 m .38782 .53037 L .3861 .52742 L F
.718 .733 .863 r
.39713 .49128 m .39883 .49235 L .39493 .49217 L F
.315 0 .156 r
.27874 .57343 m .27845 .5746 L .27593 .57522 L F
.53 .124 .216 r
.27874 .57343 m .281 .57467 L .27845 .5746 L F
.504 0 0 r
.28338 .57494 m .281 .57467 L .27874 .57343 L F
0 .452 .823 r
.72471 .31875 m .72123 .31704 L .72502 .31719 L F
0 0 .302 r
.72529 .31932 m .72471 .31875 L .72502 .31719 L F
.72529 .31932 m .72509 .32151 L .72471 .31875 L F
0 0 0 r
.24926 .62051 m .24691 .62111 L .24436 .62157 L F
.455 .504 .82 r
.38941 .59082 m .38616 .58861 L .38958 .5882 L F
.754 .443 .457 r
.38958 .5882 m .39149 .59102 L .38941 .59082 L F
.629 .434 .6 r
.4966 .46042 m .49827 .45983 L .49578 .46292 L F
.597 .457 .662 r
.48668 .4692 m .48628 .47199 L .48389 .46974 L F
.48668 .4692 m .4894 .47352 L .48628 .47199 L F
.653 .467 .62 r
.49278 .46718 m .49197 .47141 L .48668 .4692 L F
.539 .125 .204 r
.49717 .47363 m .49041 .47514 L .49064 .47274 L F
.808 .788 .834 r
.49185 .47136 m .4894 .47352 L .48668 .4692 L F
.49193 .47139 m .49152 .47173 L .49185 .47136 L F
.49152 .47173 m .4894 .47352 L .49185 .47136 L F
.763 .647 .734 r
.48871 .47496 m .49041 .47514 L .48845 .47529 L F
.49068 .47229 m .49064 .47274 L .48871 .47496 L F
.49064 .47274 m .49041 .47514 L .48871 .47496 L F
.808 .788 .834 r
.4917 .47163 m .4894 .47352 L .49193 .47139 L F
.49197 .47141 m .49068 .47229 L .4894 .47352 L F
.539 .125 .204 r
.491 .47236 m .49064 .47274 L .49068 .47229 L F
.49717 .47363 m .49064 .47274 L .491 .47236 L F
.808 .788 .834 r
.49197 .47141 m .4917 .47163 L .49193 .47139 L F
.68 .64 .803 r
.58267 .46287 m .5869 .46416 L .58524 .46214 L F
.774 .751 .833 r
.58524 .46214 m .5869 .46416 L .58885 .46258 L F
.744 .493 .551 r
.49102 .44359 m .48807 .44382 L .48946 .4423 L F
.49102 .44359 m .48731 .4453 L .48807 .44382 L F
.49102 .44359 m .49137 .44622 L .48731 .4453 L F
.726 .83 .929 r
.49296 .43997 m .49102 .44359 L .48946 .4423 L F
.49296 .43997 m .49376 .44217 L .49102 .44359 L F
0 0 .302 r
.44144 .53684 m .44566 .5402 L .44459 .53669 L F
.585 .596 .83 r
.44566 .5402 m .44674 .53541 L .44459 .53669 L F
.44566 .5402 m .44874 .53999 L .44746 .53706 L F
.44566 .5402 m .44746 .53706 L .44638 .537 L F
.569 .221 .339 r
.44695 .5388 m .44524 .53973 L .44463 .5369 L F
.44483 .53691 m .44463 .5369 L .44459 .53669 L F
.44695 .5388 m .44463 .5369 L .44483 .53691 L F
.585 .596 .83 r
.44638 .537 m .44746 .53706 L .44674 .53541 L F
.693 .607 .756 r
.44673 .54333 m .44874 .53999 L .44566 .5402 L F
.693 .561 .701 r
.45443 .55006 m .45243 .55358 L .45503 .55278 L F
.616 .14 .101 r
.43037 .59284 m .42899 .59402 L .42625 .59365 L F
.522 .029 .027 r
.43296 .59393 m .42899 .59402 L .43037 .59284 L F
.667 .901 .979 r
.61782 .35002 m .61534 .3513 L .6142 .35025 L F
.74 .903 .951 r
.41594 .47949 m .4162 .47688 L .41876 .47674 L F
.41594 .47949 m .41427 .47829 L .4162 .47688 L F
.737 .751 .863 r
.32104 .52852 m .32603 .52946 L .32383 .52606 L F
.185 .605 .943 r
.24431 .61018 m .2437 .61124 L .24307 .60986 L F
.24431 .61018 m .24607 .61151 L .2437 .61124 L F
0 0 .35 r
.21212 .57229 m .21301 .5715 L .21351 .56826 L F
0 0 .478 r
.21212 .57229 m .21331 .57419 L .21301 .5715 L F
.054 0 .461 r
.21212 .57229 m .21223 .57511 L .21331 .57419 L F
0 0 0 r
.22566 .54385 m .22338 .54776 L .22648 .54482 L F
.839 .979 .875 r
.42787 .47052 m .42847 .46816 L .42921 .46913 L F
.42787 .47052 m .42542 .47107 L .42847 .46816 L F
.807 .983 .893 r
.69115 .34973 m .6894 .3516 L .68731 .35147 L F
.907 .799 .729 r
.326 .69001 m .33094 .68473 L .327 .6879 L F
.612 .468 .662 r
.47869 .47609 m .47878 .47885 L .47609 .4795 L F
.546 .517 .774 r
.33921 .65478 m .3379 .65907 L .33604 .65889 L F
.33921 .65478 m .3404 .6586 L .3379 .65907 L F
.246 .759 .839 r
.3379 .65907 m .33932 .65848 L .33604 .65889 L F
.3379 .65907 m .3404 .6586 L .33932 .65848 L F
0 0 0 r
.25898 .55414 m .25838 .5536 L .2603 .55259 L F
.25898 .55414 m .25737 .55566 L .25838 .5536 L F
.078 .153 .641 r
.45443 .55006 m .45577 .54853 L .45484 .54902 L F
.281 .465 .864 r
.45443 .55006 m .45796 .55222 L .45577 .54853 L F
.534 .457 .715 r
.45503 .55278 m .45796 .55222 L .45443 .55006 L F
.674 .846 .965 r
.49826 .44173 m .49376 .44217 L .49667 .43993 L F
.737 .778 .886 r
.49667 .43993 m .50064 .44043 L .49826 .44173 L F
.447 .444 .763 r
.33558 .60708 m .33273 .60525 L .33516 .60428 L F
.111 0 0 r
.28443 .52666 m .28674 .52634 L .28836 .52515 L F
.812 .847 .876 r
.64541 .33528 m .64119 .33642 L .64421 .33415 L F
.694 .891 .97 r
.64541 .33528 m .64667 .3328 L .64748 .33364 L F
.64541 .33528 m .64421 .33415 L .64667 .3328 L F
.312 0 0 r
.60577 .46209 m .60503 .46254 L .60233 .46218 L F
0 0 0 r
.60577 .46209 m .60787 .46166 L .60503 .46254 L F
.995 .777 .414 r
.61083 .44326 m .61057 .44593 L .61161 .44745 L F
.896 .512 .066 r
.61107 .44833 m .61161 .44745 L .61057 .44593 L F
.61107 .44833 m .61229 .44957 L .61161 .44745 L F
0 0 0 r
.38871 .67132 m .38969 .67088 L .38829 .67135 L F
.634 .868 .506 r
.39175 .66746 m .38871 .67132 L .39164 .6704 L F
0 0 .055 r
.38883 .67118 m .38881 .67131 L .38871 .67132 L F
.382 .845 .837 r
.39033 .67027 m .39164 .6704 L .38871 .67132 L F
.39033 .67027 m .38871 .67132 L .38831 .67413 L F
0 0 .055 r
.38881 .67131 m .38831 .67413 L .38871 .67132 L F
0 0 0 r
.38871 .67132 m .38829 .67135 L .38803 .67143 L F
.662 .157 .036 r
.37929 .49908 m .38132 .49982 L .38312 .49871 L F
.397 0 0 r
.38132 .49982 m .38576 .49801 L .38312 .49871 L F
.826 .919 .899 r
.68586 .38051 m .68653 .37761 L .68494 .37935 L F
.68586 .38051 m .68779 .3789 L .68653 .37761 L F
.728 .902 .525 r
.6952 .2867 m .69323 .28969 L .69415 .28765 L F
.725 .983 .781 r
.6968 .28486 m .6952 .2867 L .69641 .28454 L F
.682 .892 .529 r
.6952 .2867 m .69415 .28765 L .69641 .28454 L F
.854 .72 .714 r
.36633 .69394 m .36588 .69107 L .36407 .69246 L F
.36633 .69394 m .36729 .69046 L .36588 .69107 L F
.304 .242 .621 r
.4298 .4869 m .42787 .48716 L .43036 .48589 L F
.059 0 0 r
.25008 .61596 m .25472 .61633 L .25181 .61722 L F
.916 .921 .804 r
.65332 .39963 m .65446 .39515 L .65185 .39814 L F
.259 0 .172 r
.35858 .55091 m .35553 .55323 L .35839 .55252 L F
.64 .904 .983 r
.31781 .66753 m .31942 .66851 L .32114 .66696 L F
.561 0 0 r
.3823 .50785 m .3802 .50713 L .37748 .50522 L F
0 .207 .688 r
.3823 .50785 m .38241 .50745 L .3802 .50713 L F
.3823 .50785 m .38451 .5094 L .38241 .50745 L F
0 0 0 r
.34175 .51031 m .34057 .51455 L .33883 .50987 L F
.34175 .51031 m .34107 .51373 L .34057 .51455 L F
0 .026 .596 r
.34107 .51373 m .34161 .51581 L .34057 .51455 L F
.431 .384 .705 r
.35969 .56521 m .35767 .56593 L .35731 .5633 L F
.494 .263 .492 r
.35994 .568 m .35767 .56593 L .35969 .56521 L F
.35994 .568 m .35742 .56857 L .35767 .56593 L F
.35994 .568 m .35767 .56593 L .35969 .56521 L F
.35994 .568 m .35742 .56857 L .35767 .56593 L F
.984 .7 .379 r
.39646 .68464 m .39791 .68581 L .39758 .68917 L F
.72 .894 .959 r
.39646 .68464 m .40078 .68429 L .39791 .68581 L F
.544 .036 0 r
.31426 .55473 m .31657 .55507 L .31839 .55373 L F
0 0 0 r
.31839 .55373 m .31842 .5538 L .32063 .5527 L F
.31839 .55373 m .31657 .55507 L .31842 .5538 L F
.054 0 .299 r
.22757 .56893 m .2271 .57146 L .22642 .57108 L F
.989 .811 .424 r
.22619 .57018 m .2271 .57146 L .22757 .56893 L F
.812 .607 .625 r
.22619 .57018 m .22808 .57202 L .2271 .57146 L F
.22808 .57202 m .2296 .5735 L .2271 .57146 L F
.054 0 .299 r
.22642 .57108 m .2271 .57146 L .22576 .57232 L F
.264 .128 .501 r
.22736 .57412 m .22576 .57232 L .2271 .57146 L F
.22736 .57412 m .22567 .57504 L .22576 .57232 L F
.4 .165 .437 r
.31415 .60994 m .3188 .60692 L .31716 .60777 L F
.688 .846 .959 r
.62715 .3571 m .62865 .35499 L .62583 .35633 L F
.243 0 0 r
.62802 .3579 m .62715 .3571 L .62583 .35633 L F
.899 .981 .799 r
.42921 .46913 m .43096 .46481 L .43182 .4654 L F
.517 .761 .985 r
.41443 .48893 m .41736 .48835 L .41577 .48698 L F
.41443 .48893 m .41736 .48835 L .41577 .48698 L F
.808 .793 .838 r
.66299 .39059 m .66705 .3894 L .66573 .38774 L F
.677 .72 .881 r
.66705 .3894 m .66866 .3853 L .66573 .38774 L F
.66705 .3894 m .66998 .38841 L .66866 .3853 L F
0 0 0 r
.61092 .45625 m .61047 .45823 L .60928 .46026 L F
.674 .895 .541 r
.60928 .46026 m .61047 .45823 L .60787 .46166 L F
.127 0 .205 r
.55977 .40561 m .55754 .40871 L .55974 .4075 L F
.147 0 .173 r
.55974 .4075 m .55754 .40871 L .55691 .41059 L F
0 0 0 r
.5584 .40935 m .55974 .4075 L .55691 .41059 L F
.821 .934 .562 r
.56005 .40598 m .55974 .4075 L .5584 .40935 L F
0 0 0 r
.56175 .40543 m .55977 .40561 L .55974 .4075 L F
.821 .934 .562 r
.56049 .4051 m .56025 .40587 L .56005 .40598 L F
.56025 .40587 m .55974 .4075 L .56005 .40598 L F
0 0 0 r
.56175 .40543 m .56332 .40474 L .56141 .40521 L F
.56087 .40551 m .56141 .40521 L .55977 .40561 L F
.56175 .40543 m .56141 .40521 L .56087 .40551 L F
.335 .808 .91 r
.56514 .40358 m .56332 .40474 L .56175 .40543 L F
.56514 .40358 m .56548 .40431 L .56332 .40474 L F
.526 .572 .845 r
.42639 .54052 m .42685 .53604 L .42538 .53949 L F
.993 .839 .585 r
.42439 .54187 m .42639 .54052 L .42538 .53949 L F
.42439 .54187 m .42555 .54319 L .42639 .54052 L F
.095 .637 .847 r
.33926 .49476 m .34052 .49526 L .33803 .4952 L F
.36 0 0 r
.3395 .49492 m .34052 .49526 L .33926 .49476 L F
.061 .618 .81 r
.34052 .49526 m .34123 .4955 L .33803 .4952 L F
.36 0 0 r
.34096 .4959 m .34052 .49526 L .3395 .49492 L F
.061 .618 .81 r
.34052 .49526 m .34213 .49559 L .34123 .4955 L F
0 .464 .701 r
.34519 .49616 m .34213 .49559 L .34052 .49526 L F
.599 .414 .603 r
.47252 .4951 m .4728 .498 L .4699 .49842 L F
.634 .504 .687 r
.47506 .4918 m .47563 .49517 L .47252 .4951 L F
.606 .309 .44 r
.47252 .4951 m .47526 .49709 L .4728 .498 L F
.47252 .4951 m .47563 .49517 L .47526 .49709 L F
.94 .668 .494 r
.29897 .66116 m .30133 .66176 L .30105 .65904 L F
.29897 .66116 m .30105 .65904 L .30217 .65809 L F
.903 .979 .797 r
.39119 .59566 m .3892 .59834 L .38877 .5965 L F
.758 .864 .927 r
.39133 .59311 m .39119 .59566 L .38877 .5965 L F
.39133 .59311 m .39315 .59428 L .39119 .59566 L F
.979 .685 .327 r
.39003 .53576 m .3914 .53699 L .38991 .53332 L F
.994 .756 .404 r
.39018 .53808 m .3914 .53699 L .39003 .53576 L F
.39018 .53808 m .39128 .53984 L .3914 .53699 L F
.976 .804 .388 r
.39976 .56728 m .40079 .56593 L .39897 .56461 L F
.39976 .56728 m .40042 .56866 L .40079 .56593 L F
.968 .897 .531 r
.69676 .33961 m .69721 .34133 L .69639 .34348 L F
.299 0 .175 r
.69836 .30741 m .699 .30597 L .70164 .30517 L F
.566 .654 .895 r
.34306 .63681 m .33916 .6331 L .34117 .63378 L F
.68 .428 .534 r
.33945 .63909 m .34306 .63681 L .33947 .63958 L F
.514 .624 .897 r
.3453 .63621 m .34252 .63594 L .34375 .6353 L F
.34375 .6353 m .34252 .63594 L .34117 .63378 L F
.3453 .63621 m .34502 .63605 L .34386 .63574 L F
.34502 .63605 m .34117 .63378 L .34386 .63574 L F
.967 .902 .703 r
.34622 .63351 m .3453 .63621 L .34386 .63574 L F
.34609 .63407 m .34528 .63468 L .34601 .6344 L F
.34528 .63468 m .34386 .63574 L .34601 .6344 L F
0 0 0 r
.34897 .63192 m .34601 .6344 L .34793 .63459 L F
.279 .499 .89 r
.34715 .63397 m .34601 .6344 L .34793 .63459 L F
.967 .902 .703 r
.34622 .63351 m .34505 .63461 L .34609 .63407 L F
.34505 .63461 m .34386 .63574 L .34609 .63407 L F
0 0 0 r
.34897 .63192 m .34631 .6332 L .34601 .6344 L F
.279 .499 .89 r
.34372 .63126 m .34601 .6344 L .34715 .63397 L F
.274 .332 .741 r
.34276 .63023 m .34381 .6355 L .34117 .63378 L F
.34381 .6355 m .34386 .63574 L .34367 .6356 L F
.34381 .6355 m .34367 .6356 L .34117 .63378 L F
.514 .624 .897 r
.3453 .63621 m .34306 .63681 L .34252 .63594 L F
.671 .727 .891 r
.33935 .63455 m .33947 .63958 L .34386 .63574 L F
.33935 .63455 m .34386 .63574 L .34291 .63566 L F
.611 .574 .788 r
.34601 .6344 m .34386 .63574 L .34276 .63023 L F
.647 .96 .928 r
.34291 .63566 m .34458 .63498 L .34415 .63479 L F
.34458 .63498 m .34601 .6344 L .34519 .63457 L F
.34458 .63498 m .34519 .63457 L .34415 .63479 L F
.34317 .63555 m .34386 .63574 L .34601 .6344 L F
.34291 .63566 m .34386 .63574 L .34317 .63555 L F
.212 0 .034 r
.33947 .63958 m .34306 .63681 L .3453 .63621 L F
0 0 0 r
.70714 .27738 m .70706 .27729 L .70795 .27489 L F
.70714 .27738 m .70617 .27963 L .70706 .27729 L F
.585 .295 .443 r
.33974 .68066 m .34235 .67998 L .33975 .67945 L F
.645 .587 .775 r
.50714 .4405 m .50453 .4435 L .50319 .4394 L F
.563 .307 .486 r
.5104 .46973 m .5129 .4716 L .51022 .47189 L F
.5104 .46973 m .51453 .4682 L .5129 .4716 L F
.829 .999 .825 r
.64931 .38835 m .64576 .3906 L .64865 .38757 L F
.793 .913 .921 r
.65145 .38449 m .65261 .38575 L .64931 .38835 L F
.883 .822 .783 r
.51501 .43311 m .5193 .43106 L .51552 .43027 L F
.51501 .43311 m .51688 .43475 L .5193 .43106 L F
.635 .556 .748 r
.45503 .55278 m .4593 .55569 L .45796 .55222 L F
.993 .768 .493 r
.37713 .50122 m .37724 .50375 L .37522 .50176 L F
.37724 .50375 m .37724 .50386 L .37522 .50176 L F
.37713 .50122 m .37522 .50176 L .37452 .50058 L F
.734 .256 0 r
.37452 .50058 m .37522 .50176 L .37366 .50027 L F
0 .111 .656 r
.37522 .50176 m .37646 .5021 L .3738 .50036 L F
.37522 .50176 m .3738 .50036 L .37366 .50027 L F
0 .009 .518 r
.37724 .50386 m .37749 .50399 L .37654 .50305 L F
.37724 .50386 m .37654 .50305 L .37522 .50176 L F
.885 .689 .171 r
.37713 .50122 m .37737 .50402 L .37724 .50386 L F
.37737 .50402 m .37748 .50522 L .37724 .50386 L F
0 .247 .743 r
.37748 .50522 m .37888 .50547 L .37724 .50386 L F
.37748 .50522 m .3802 .50713 L .37888 .50547 L F
.753 .659 .758 r
.60974 .38318 m .60833 .37986 L .60775 .38186 L F
.60974 .38318 m .61079 .3784 L .60833 .37986 L F
.60974 .38318 m .61133 .38168 L .61079 .3784 L F
.994 .875 .562 r
.60842 .38397 m .60974 .38318 L .60775 .38186 L F
.60842 .38397 m .60913 .38578 L .60974 .38318 L F
.775 .953 .931 r
.66164 .32119 m .66383 .31815 L .66486 .31869 L F
.66164 .32119 m .6608 .3202 L .66383 .31815 L F
.815 .38 .211 r
.35842 .52409 m .35595 .52378 L .35461 .52146 L F
.972 .891 .686 r
.35597 .52775 m .35595 .52378 L .35842 .52409 L F
.495 .295 .538 r
.35831 .52718 m .35597 .52775 L .35842 .52409 L F
.692 .617 .768 r
.36149 .51992 m .35842 .52409 L .35695 .52002 L F
.68 .446 .562 r
.36227 .52619 m .35831 .52718 L .35842 .52409 L F
.183 0 .354 r
.36478 .60117 m .36639 .6029 L .36877 .60112 L F
0 .003 .502 r
.36947 .60182 m .36877 .60112 L .36639 .6029 L F
.36947 .60182 m .371 .60334 L .36877 .60112 L F
.153 .254 .716 r
.72769 .32352 m .72606 .32578 L .72509 .32151 L F
0 .089 .631 r
.72782 .32548 m .72606 .32578 L .72769 .32352 L F
.72782 .32548 m .72708 .32768 L .72606 .32578 L F
.261 .1 .464 r
.34031 .60606 m .34032 .6084 L .33938 .60812 L F
.45 0 0 r
.34032 .60868 m .34024 .60826 L .33938 .60812 L F
.261 .1 .464 r
.34032 .6084 m .34032 .60868 L .33938 .60812 L F
.215 0 0 r
.33744 .60755 m .33938 .60812 L .34024 .60826 L F
.33558 .60708 m .33938 .60812 L .33744 .60755 L F
.298 .167 .528 r
.34233 .60968 m .34045 .61055 L .34024 .60826 L F
.45 0 0 r
.34032 .60868 m .34233 .60968 L .34024 .60826 L F
.817 .707 .744 r
.41959 .48501 m .42093 .48916 L .41736 .48835 L F
.732 .422 .456 r
.42093 .48916 m .41688 .49148 L .41736 .48835 L F
.556 0 0 r
.4206 .49366 m .41916 .4932 L .41688 .49148 L F
.4206 .49366 m .41688 .49148 L .41951 .49306 L F
.732 .422 .456 r
.42093 .48916 m .41951 .49306 L .41688 .49148 L F
.773 .685 .766 r
.42366 .48556 m .42093 .48916 L .41959 .48501 L F
.538 .221 .378 r
.42353 .49083 m .41951 .49306 L .42093 .48916 L F
.467 .448 .754 r
.47007 .54957 m .46786 .54999 L .46704 .54592 L F
.908 .887 .465 r
.3892 .59834 m .38796 .5996 L .38877 .5965 L F
.3892 .59834 m .38832 .60094 L .38796 .5996 L F
.431 .384 .705 r
.35969 .56521 m .35731 .5633 L .35977 .56243 L F
.561 .525 .773 r
.61079 .3784 m .61133 .38168 L .61305 .3797 L F
.227 .457 .873 r
.32877 .66283 m .32468 .6594 L .32723 .65871 L F
.547 .341 .552 r
.32508 .66065 m .32723 .65871 L .32468 .6594 L F
.271 0 0 r
.57025 .42815 m .57268 .42803 L .57384 .42616 L F
0 0 .422 r
.57406 .4244 m .57384 .42616 L .57556 .42526 L F
.823 .725 .756 r
.51397 .4377 m .51343 .44013 L .5097 .43958 L F
.808 .759 .807 r
.5097 .43958 m .51343 .44013 L .51169 .44136 L F
.844 .802 .811 r
.622 .37651 m .62577 .3727 L .62209 .37214 L F
.331 .035 .303 r
.36335 .59102 m .35992 .59397 L .3603 .59181 L F
.741 .465 .512 r
.21827 .60316 m .2145 .60388 L .21521 .6019 L F
.503 .307 .548 r
.2145 .60388 m .21707 .60062 L .21521 .6019 L F
.315 .235 .604 r
.36222 .5162 m .35989 .51417 L .36145 .51411 L F
0 0 0 r
.53447 .41976 m .53602 .41907 L .53299 .4202 L F
.5389 .41825 m .53602 .41907 L .53447 .41976 L F
.791 .831 .882 r
.42248 .49524 m .4189 .49527 L .4206 .49366 L F
.763 .766 .855 r
.4256 .49283 m .42248 .49524 L .4206 .49366 L F
.827 .364 .108 r
.27902 .62882 m .27963 .62761 L .27809 .62625 L F
.27902 .62882 m .28108 .62935 L .27963 .62761 L F
.392 .066 .288 r
.33477 .53787 m .33455 .53965 L .3312 .54033 L F
.3312 .54033 m .33455 .53965 L .33477 .53787 L F
.67 .302 .339 r
.33477 .53787 m .33731 .53976 L .33455 .53965 L F
.33477 .53787 m .33731 .53976 L .33455 .53965 L F
.781 .79 .86 r
.67109 .38623 m .67613 .38585 L .67443 .38402 L F
.755 .785 .878 r
.67443 .38402 m .67613 .38585 L .67896 .38332 L F
.273 .198 .586 r
.23007 .58163 m .23183 .57759 L .22981 .57885 L F
.993 .839 .478 r
.40012 .5891 m .40105 .59197 L .40119 .58745 L F
.977 .917 .663 r
.39885 .59334 m .40105 .59197 L .40012 .5891 L F
.39885 .59334 m .39983 .59429 L .40105 .59197 L F
.279 .28 .681 r
.21343 .5947 m .21497 .59502 L .21441 .59041 L F
.157 .43 .867 r
.21343 .5947 m .21648 .59651 L .21497 .59502 L F
.45 .518 .836 r
.21343 .5947 m .21686 .598 L .21648 .59651 L F
.473 0 0 r
.24249 .62174 m .24098 .62093 L .23896 .61938 L F
.574 .017 0 r
.24436 .62157 m .24098 .62093 L .24249 .62174 L F
.726 .509 .597 r
.34662 .60756 m .34632 .61079 L .34363 .60997 L F
.243 0 .269 r
.34935 .60465 m .34867 .60685 L .34662 .60756 L F
.386 .217 .526 r
.34884 .60966 m .34662 .60756 L .34867 .60685 L F
.34884 .60966 m .34632 .61079 L .34662 .60756 L F
.877 .966 .849 r
.41876 .47674 m .41921 .4739 L .42066 .47523 L F
.41876 .47674 m .4162 .47688 L .41921 .4739 L F
.336 .062 .341 r
.34727 .53351 m .34658 .53611 L .34442 .53675 L F
.485 .311 .57 r
.35005 .53001 m .34965 .53293 L .34727 .53351 L F
.497 .206 .403 r
.34917 .53551 m .34727 .53351 L .34965 .53293 L F
.34917 .53551 m .34658 .53611 L .34727 .53351 L F
.576 .614 .854 r
.62916 .40661 m .62815 .41132 L .62675 .40792 L F
.62916 .40661 m .63122 .41231 L .62815 .41132 L F
0 0 0 r
.44459 .59747 m .44815 .59552 L .44627 .59702 L F
.455 .821 .56 r
.44627 .59702 m .44815 .59552 L .44992 .59408 L F
.459 .481 .794 r
.33084 .6296 m .33177 .63292 L .33471 .633 L F
.72 .755 .881 r
.5758 .46357 m .5799 .46388 L .5787 .46264 L F
.741 .835 .923 r
.5787 .46264 m .5799 .46388 L .58267 .46287 L F
.879 .914 .847 r
.68221 .30323 m .67943 .30638 L .67837 .30486 L F
.68221 .30323 m .67837 .30486 L .67984 .3032 L F
.874 .985 .83 r
.68477 .30009 m .68221 .30323 L .68281 .30046 L F
.827 .953 .899 r
.68221 .30323 m .67984 .3032 L .68281 .30046 L F
.451 .289 .569 r
.3139 .64564 m .31157 .64573 L .31342 .64307 L F
.562 .872 .579 r
.53701 .40816 m .5405 .40482 L .53981 .40777 L F
.225 0 .344 r
.54222 .40427 m .53981 .40777 L .5405 .40482 L F
.475 .889 .781 r
.37486 .67793 m .37271 .67912 L .36816 .68091 L F
.916 .538 .116 r
.39321 .54473 m .39371 .54271 L .39241 .54095 L F
.39321 .54473 m .39477 .5467 L .39371 .54271 L F
.647 .475 .637 r
.24573 .55942 m .24834 .55936 L .24857 .55664 L F
.24857 .55664 m .24834 .55936 L .24573 .55942 L F
.612 .445 .631 r
.25132 .55834 m .24834 .55936 L .24857 .55664 L F
0 0 0 r
.24857 .55664 m .24865 .55713 L .25071 .55573 L F
.24857 .55664 m .24834 .55936 L .24865 .55713 L F
.647 .475 .637 r
.24573 .55942 m .24834 .55936 L .24857 .55664 L F
.861 .58 .511 r
.4349 .50023 m .43693 .50409 L .4375 .50186 L F
.399 0 0 r
.4349 .50023 m .4375 .50186 L .43537 .50057 L F
.577 .866 .995 r
.43537 .50057 m .4375 .50186 L .43951 .50083 L F
.226 0 .304 r
.4375 .50186 m .43693 .50409 L .43951 .50083 L F
.511 .769 .99 r
.43429 .59797 m .43871 .59898 L .43666 .59803 L F
.395 .84 .729 r
.43871 .59898 m .43924 .5984 L .43666 .59803 L F
.43871 .59898 m .44076 .59794 L .43924 .5984 L F
.611 .86 .99 r
.25385 .56519 m .24948 .56506 L .25186 .56466 L F
.786 .728 .798 r
.24948 .56506 m .25385 .56519 L .25186 .56466 L F
.24948 .56506 m .25036 .56776 L .25385 .56519 L F
.945 .583 .235 r
.61044 .41736 m .61271 .4214 L .61128 .42041 L F
.984 .704 .345 r
.61271 .4214 m .61159 .42262 L .61128 .42041 L F
.61271 .4214 m .61291 .4241 L .61159 .42262 L F
0 .018 .567 r
.35038 .56259 m .35196 .56438 L .35281 .56216 L F
.684 .51 .645 r
.49827 .45983 m .49829 .4626 L .49578 .46292 L F
.366 .203 .523 r
.31349 .61064 m .31549 .61247 L .31415 .60994 L F
.4 .165 .437 r
.31415 .60994 m .3183 .60947 L .3188 .60692 L F
.395 .146 .415 r
.31415 .60994 m .31549 .61247 L .3183 .60947 L F
.94 .662 .484 r
.3044 .66747 m .30643 .66863 L .30449 .67082 L F
.30449 .67082 m .30643 .66863 L .3044 .66747 L F
0 .517 .709 r
.33313 .5542 m .32955 .55381 L .33146 .55332 L F
.28 .591 .947 r
.32955 .55381 m .33142 .55401 L .33106 .55359 L F
0 0 0 r
.33146 .55332 m .32955 .55381 L .32797 .55404 L F
.28 .591 .947 r
.32955 .55381 m .33106 .55359 L .32946 .55178 L F
0 0 0 r
.32797 .55404 m .32955 .55381 L .3271 .55422 L F
.451 .203 .445 r
.33393 .55258 m .33313 .5542 L .33146 .55332 L F
.514 .409 .673 r
.46631 .53003 m .46685 .53272 L .46423 .53346 L F
.036 .594 .811 r
.27415 .52096 m .27229 .52056 L .27 .52038 L F
.008 .571 .801 r
.27656 .52125 m .27229 .52056 L .27415 .52096 L F
.636 .363 .488 r
.3323 .6234 m .33702 .62299 L .33618 .62043 L F
.979 .916 .615 r
.40053 .58481 m .40164 .58209 L .39981 .5836 L F
.996 .825 .554 r
.39981 .5836 m .40164 .58209 L .40043 .58097 L F
.833 .975 .884 r
.33619 .64322 m .33789 .64342 L .33929 .64148 L F
.899 .981 .799 r
.42921 .46913 m .42847 .46816 L .43096 .46481 L F
.808 .696 .741 r
.49987 .4689 m .50366 .46945 L .50115 .47278 L F
.711 .55 .669 r
.50366 .46945 m .50371 .47198 L .50115 .47278 L F
.754 .48 .519 r
.50366 .46945 m .5075 .47226 L .50371 .47198 L F
.634 .459 .629 r
.4894 .47352 m .48412 .47515 L .48628 .47199 L F
.948 .954 .659 r
.61092 .45625 m .61184 .45216 L .61113 .45586 L F
0 0 0 r
.61092 .45625 m .61113 .45586 L .61047 .45823 L F
.629 .834 .979 r
.58763 .46107 m .58524 .46214 L .58885 .46258 L F
.109 .629 .884 r
.59189 .46192 m .58763 .46107 L .58885 .46258 L F
0 0 0 r
.21596 .55969 m .21486 .56184 L .21732 .55846 L F
0 0 .385 r
.32913 .57209 m .3304 .57349 L .33021 .57031 L F
.32913 .57209 m .32941 .57511 L .3304 .57349 L F
.569 .898 .983 r
.44076 .59794 m .44459 .59747 L .44221 .59852 L F
0 0 0 r
.44221 .59852 m .44459 .59747 L .44627 .59702 L F
.618 .371 .521 r
.2486 .60659 m .24539 .60451 L .24848 .60461 L F
.2486 .60659 m .24486 .60757 L .24539 .60451 L F
.819 .78 .816 r
.6355 .40398 m .63443 .40849 L .63093 .40845 L F
.593 .377 .557 r
.63443 .40849 m .63468 .41117 L .63163 .41179 L F
.827 .797 .824 r
.63192 .40333 m .63532 .40395 L .63093 .40845 L F
.63532 .40395 m .6355 .40398 L .63513 .40435 L F
.63532 .40395 m .63513 .40435 L .63093 .40845 L F
.828 .795 .821 r
.63537 .40382 m .6355 .40398 L .63192 .40333 L F
.799 .761 .818 r
.63537 .40382 m .63443 .40849 L .6355 .40398 L F
.63536 .40386 m .63724 .40544 L .63443 .40849 L F
.63537 .40382 m .63537 .40382 L .63536 .40386 L F
.63537 .40382 m .63724 .40544 L .63536 .40386 L F
.697 .586 .727 r
.63724 .40544 m .63634 .40842 L .63443 .40849 L F
.781 .701 .776 r
.63634 .40842 m .63468 .41117 L .63443 .40849 L F
.88 .964 .847 r
.68779 .3789 m .68942 .37472 L .68653 .37761 L F
.68779 .3789 m .69033 .37595 L .68942 .37472 L F
.762 .43 .423 r
.27593 .57522 m .27477 .57788 L .2719 .57724 L F
.354 .009 .235 r
.27845 .5746 m .27477 .57788 L .27593 .57522 L F
.52 .43 .695 r
.3234 .56264 m .32602 .56276 L .32569 .55947 L F
.893 .798 .314 r
.7041 .34937 m .70448 .34742 L .70377 .34871 L F
.761 .957 .646 r
.70448 .34742 m .70708 .34408 L .70569 .34494 L F
.65 .793 .342 r
.70377 .34871 m .70448 .34742 L .70569 .34494 L F
.189 .117 .539 r
.38563 .68959 m .38695 .69034 L .38683 .68732 L F
.44 0 0 r
.38531 .69106 m .38563 .68959 L .38241 .69203 L F
.38531 .69106 m .38695 .69034 L .38563 .68959 L F
.994 .75 .415 r
.60452 .43228 m .60574 .43362 L .60583 .43094 L F
.997 .77 .428 r
.6047 .42953 m .60452 .43228 L .60583 .43094 L F
.971 .778 .349 r
.4433 .57548 m .43918 .57767 L .43931 .57537 L F
.4433 .57548 m .44304 .57721 L .4423 .57717 L F
.193 0 .308 r
.35412 .60052 m .35174 .60403 L .3523 .60143 L F
.67 .48 .619 r
.33078 .54324 m .3316 .54354 L .3312 .54033 L F
.33078 .54324 m .3316 .54354 L .3312 .54033 L F
.558 .4 .623 r
.3312 .54033 m .33475 .54274 L .33455 .53965 L F
.3312 .54033 m .3316 .54354 L .33475 .54274 L F
.3312 .54033 m .33475 .54274 L .33455 .53965 L F
.3312 .54033 m .3316 .54354 L .33475 .54274 L F
.161 0 0 r
.72505 .33839 m .72782 .33862 L .72574 .33992 L F
.32 .028 .303 r
.35174 .60403 m .34867 .60685 L .34935 .60465 L F
.556 .88 .991 r
.69529 .30722 m .69233 .30827 L .69607 .30806 L F
.496 .269 .5 r
.30578 .62039 m .30839 .62 L .30868 .61712 L F
.177 .009 .4 r
.30868 .61712 m .30839 .62 L .31011 .61652 L F
.616 .799 .97 r
.4412 .52115 m .43846 .5217 L .43987 .51966 L F
0 0 .385 r
.42512 .51068 m .426 .51107 L .42952 .51158 L F
.798 .911 .918 r
.4297 .50903 m .42952 .51158 L .426 .51107 L F
.62 .098 0 r
.26291 .61883 m .26507 .62062 L .26711 .61953 L F
.834 .624 .619 r
.26507 .62062 m .26616 .61995 L .26711 .61953 L F
.758 .242 0 r
.26516 .617 m .26711 .61953 L .26787 .61919 L F
.72 .287 .22 r
.26291 .61883 m .26711 .61953 L .26516 .617 L F
.834 .624 .619 r
.26616 .61995 m .26912 .61814 L .26711 .61953 L F
.758 .242 0 r
.26787 .61919 m .26711 .61953 L .26828 .61952 L F
.599 .951 .865 r
.26828 .61952 m .26912 .61814 L .27091 .61825 L F
.26828 .61952 m .26711 .61953 L .26912 .61814 L F
.684 .977 .892 r
.60198 .35273 m .60326 .35072 L .60466 .35195 L F
.60198 .35273 m .60096 .35244 L .60326 .35072 L F
.46 .887 .822 r
.31751 .55785 m .32202 .55626 L .31929 .557 L F
.729 .939 .955 r
.32242 .55417 m .32202 .55626 L .32518 .55468 L F
.824 .997 .848 r
.32242 .55417 m .31929 .557 L .32202 .55626 L F
.964 .94 .681 r
.59307 .37773 m .59197 .38293 L .59123 .37939 L F
.505 .02 .037 r
.26065 .61838 m .26516 .617 L .26146 .61678 L F
.26065 .61838 m .26291 .61883 L .26516 .617 L F
.764 .403 0 r
.39753 .55166 m .39832 .553 L .39666 .5493 L F
.821 .732 .206 r
.39784 .55448 m .39832 .553 L .39753 .55166 L F
.39784 .55448 m .39794 .55561 L .39832 .553 L F
.465 .309 .585 r
.52391 .40847 m .52658 .41051 L .5264 .40751 L F
.52391 .40847 m .52658 .41051 L .5264 .40751 L F
.5 .258 .48 r
.29275 .6367 m .29487 .63873 L .29527 .63607 L F
.252 .245 .656 r
.29275 .6367 m .29333 .63921 L .29487 .63873 L F
.006 .463 .868 r
.59403 .39473 m .59652 .3959 L .59525 .39462 L F
.59332 .3948 m .59471 .39527 L .59403 .39473 L F
0 .062 .62 r
.59524 .39533 m .59652 .3959 L .59332 .3948 L F
.006 .463 .868 r
.59471 .39527 m .59652 .3959 L .59403 .39473 L F
0 .079 .585 r
.59641 .39664 m .59883 .3988 L .59734 .39769 L F
.59524 .39533 m .59756 .39757 L .59641 .39664 L F
.59756 .39757 m .59883 .3988 L .59641 .39664 L F
0 .11 .658 r
.59883 .3988 m .60027 .39931 L .59734 .39769 L F
.59883 .3988 m .60112 .40119 L .60027 .39931 L F
.492 .208 .411 r
.24552 .56208 m .24834 .55936 L .24573 .55942 L F
.24552 .56208 m .24834 .55936 L .24573 .55942 L F
.573 .522 .759 r
.23757 .53965 m .24073 .54256 L .24152 .54015 L F
.807 .622 .652 r
.59431 .45888 m .59845 .45705 L .59721 .45721 L F
.59431 .45888 m .59848 .45969 L .59845 .45705 L F
.61 .862 .51 r
.59954 .45552 m .59845 .45705 L .60003 .45505 L F
.674 .977 .865 r
.59721 .45721 m .59845 .45705 L .59954 .45552 L F
.006 0 .003 r
.27074 .53754 m .27005 .53915 L .27264 .53644 L F
.802 .997 .859 r
.70708 .34408 m .71013 .3412 L .70804 .34158 L F
.803 .962 .64 r
.70569 .34494 m .70708 .34408 L .70804 .34158 L F
.769 .877 .925 r
.6334 .34384 m .62981 .344 L .6322 .34258 L F
.807 .917 .912 r
.6334 .34384 m .63517 .33988 L .63663 .34153 L F
.6334 .34384 m .6322 .34258 L .63517 .33988 L F
.498 .26 .483 r
.4699 .49842 m .46982 .50103 L .4672 .50184 L F
.581 .353 .535 r
.4699 .49842 m .47246 .50031 L .46982 .50103 L F
.4699 .49842 m .4728 .498 L .47246 .50031 L F
.598 .854 .992 r
.26253 .52189 m .26451 .52408 L .2656 .52345 L F
.202 0 0 r
.21827 .60316 m .217 .60383 L .2145 .60388 L F
.219 .742 .804 r
.22052 .60272 m .21919 .60276 L .21827 .60316 L F
0 0 0 r
.21919 .60276 m .217 .60383 L .21827 .60316 L F
.796 .579 .608 r
.3606 .61083 m .36086 .61355 L .35706 .61246 L F
.307 .395 .789 r
.36232 .6091 m .3606 .61083 L .35939 .60759 L F
.429 .309 .614 r
.36245 .61265 m .3606 .61083 L .36232 .6091 L F
.36245 .61265 m .36086 .61355 L .3606 .61083 L F
.657 .652 .833 r
.38756 .67782 m .38983 .67889 L .38841 .67603 L F
.799 .87 .9 r
.38508 .68083 m .38983 .67889 L .38756 .67782 L F
.569 .592 .836 r
.39018 .67909 m .38841 .67603 L .38983 .67889 L F
.543 .355 .576 r
.38983 .67889 m .39169 .68091 L .39018 .67909 L F
.462 0 0 r
.28338 .57494 m .28351 .57594 L .281 .57467 L F
.28338 .57494 m .28515 .57569 L .28351 .57594 L F
0 0 0 r
.23572 .54039 m .2353 .5404 L .23757 .53965 L F
.23572 .54039 m .23377 .54214 L .2353 .5404 L F
.413 .309 .627 r
.46857 .53915 m .46821 .54348 L .46637 .54354 L F
.415 .34 .664 r
.46821 .54348 m .46903 .54559 L .46637 .54354 L F
.392 .341 .681 r
.46637 .54354 m .46903 .54559 L .46704 .54592 L F
.536 .803 .995 r
.3857 .61252 m .38447 .61489 L .38341 .61524 L F
.452 .883 .887 r
.38838 .6136 m .38447 .61489 L .38778 .61406 L F
.536 .803 .995 r
.3857 .61252 m .38778 .61406 L .38447 .61489 L F
.185 0 .19 r
.69642 .32586 m .6971 .32666 L .69973 .32465 L F
.69642 .32586 m .69621 .3273 L .6971 .32666 L F
0 .062 .62 r
.59524 .39533 m .59734 .39769 L .59652 .3959 L F
.615 .556 .765 r
.38702 .66209 m .38987 .65862 L .3881 .65897 L F
.179 .017 .41 r
.54181 .41503 m .54155 .41564 L .54107 .417 L F
.935 .95 .77 r
.54155 .41564 m .53938 .41778 L .54107 .417 L F
.53 .234 .409 r
.54107 .417 m .54451 .41407 L .54181 .41503 L F
.54107 .417 m .54385 .41668 L .54451 .41407 L F
.562 .747 .964 r
.5396 .41515 m .54267 .41626 L .54107 .417 L F
.54267 .41626 m .54385 .41668 L .54107 .417 L F
.935 .95 .77 r
.53938 .41778 m .5389 .41825 L .54107 .417 L F
.751 .913 .947 r
.65841 .3387 m .66257 .33814 L .6617 .3372 L F
.779 .91 .93 r
.6634 .33502 m .66257 .33814 L .66455 .3361 L F
.852 .974 .869 r
.6617 .3372 m .66257 .33814 L .6634 .33502 L F
.868 .465 .006 r
.41315 .59682 m .41439 .59805 L .41507 .59999 L F
.753 .454 .477 r
.53655 .46625 m .53257 .46821 L .53244 .4662 L F
.53655 .46625 m .53656 .46842 L .53257 .46821 L F
.736 .314 .247 r
.53655 .46625 m .54082 .4685 L .53656 .46842 L F
0 .46 .762 r
.34873 .49747 m .35092 .49804 L .35264 .4987 L F
0 .278 .653 r
.35092 .49804 m .35514 .50012 L .35264 .4987 L F
.777 .693 .77 r
.57717 .45596 m .5786 .45991 L .57459 .45922 L F
.79 .652 .71 r
.57459 .45922 m .5786 .45991 L .5758 .46357 L F
.62 .629 .838 r
.57979 .45528 m .5786 .45991 L .57717 .45596 L F
0 0 0 r
.5809 .46097 m .58007 .46106 L .58248 .46024 L F
.57859 .46203 m .58007 .46106 L .5809 .46097 L F
.217 0 0 r
.57865 .46122 m .58007 .46106 L .5787 .46264 L F
.5786 .45991 m .58007 .46106 L .57865 .46122 L F
.537 .306 .512 r
.5758 .46357 m .5786 .45991 L .5787 .46264 L F
.553 0 0 r
.3844 .66206 m .38163 .66084 L .38451 .66121 L F
.442 .21 .465 r
.38225 .66524 m .3844 .66206 L .38456 .66522 L F
.937 .608 .385 r
.38456 .66522 m .3844 .66206 L .38225 .66524 L F
0 .194 .72 r
.38541 .66171 m .3844 .66206 L .38451 .66121 L F
.67 .856 .971 r
.38639 .66308 m .38456 .66522 L .3844 .66206 L F
.452 .741 .99 r
.35804 .70895 m .36298 .70928 L .35938 .71201 L F
.368 .135 .425 r
.54181 .41503 m .54451 .41407 L .54507 .41118 L F
.856 .425 0 r
.35335 .52418 m .35453 .52671 L .35597 .52775 L F
.972 .891 .686 r
.35597 .52775 m .35453 .52671 L .35595 .52378 L F
.701 .921 .967 r
.35708 .52541 m .35597 .52775 L .35831 .52718 L F
.35708 .52541 m .35453 .52671 L .35597 .52775 L F
.945 .594 .309 r
.69606 .33398 m .69475 .33548 L .69506 .33286 L F
0 0 .145 r
.69519 .33402 m .69506 .33286 L .69475 .33548 L F
0 0 .46 r
.69493 .33163 m .69606 .33398 L .69506 .33286 L F
0 0 .145 r
.69589 .33167 m .69506 .33286 L .69519 .33402 L F
0 0 .46 r
.69444 .3306 m .69493 .33163 L .69506 .33286 L F
.945 .594 .309 r
.69606 .33398 m .69675 .33665 L .69475 .33548 L F
.164 0 0 r
.35094 .67282 m .34772 .67325 L .35035 .67456 L F
.827 .898 .89 r
.67318 .32766 m .67632 .32703 L .67594 .32442 L F
.851 .866 .852 r
.67594 .32442 m .67632 .32703 L .67916 .32418 L F
.551 .409 .64 r
.48017 .48288 m .48021 .48638 L .4771 .48641 L F
.609 .499 .703 r
.48021 .48638 m .47756 .48853 L .4771 .48641 L F
.362 .801 .64 r
.64078 .39221 m .63693 .3943 L .63895 .39265 L F
.208 .727 .705 r
.64341 .39148 m .64078 .39221 L .63895 .39265 L F
.538 .373 .605 r
.39169 .68091 m .39196 .68382 L .39457 .68121 L F
.009 .217 .727 r
.39271 .68228 m .39304 .68306 L .39196 .68382 L F
.775 .756 .835 r
.39135 .68424 m .39334 .68425 L .39196 .68382 L F
.419 .5 .836 r
.39334 .68425 m .39457 .68121 L .39196 .68382 L F
.009 .217 .727 r
.39304 .68306 m .39422 .68596 L .39196 .68382 L F
.775 .756 .835 r
.38911 .68424 m .39135 .68424 L .39196 .68382 L F
.845 .773 .782 r
.37517 .59104 m .37727 .59193 L .37853 .58738 L F
.871 .743 .718 r
.37472 .59298 m .37727 .59193 L .37517 .59104 L F
.832 .431 0 r
.58759 .38922 m .58968 .39327 L .58877 .39182 L F
.021 .407 .857 r
.58968 .39327 m .59144 .39435 L .58877 .39182 L F
.614 .647 .86 r
.41195 .47962 m .40928 .48049 L .4079 .47852 L F
.92 .744 .646 r
.35312 .52194 m .35335 .52418 L .35461 .52146 L F
.769 .375 .307 r
.35461 .52146 m .35595 .52378 L .35312 .52194 L F
.016 .301 .794 r
.27236 .54272 m .27334 .54423 L .27308 .54285 L F
.27236 .54272 m .27308 .54285 L .27283 .54153 L F
.777 .939 .59 r
.27334 .54423 m .27232 .54438 L .27283 .54153 L F
.547 .346 .559 r
.27507 .54234 m .27444 .54589 L .27165 .54632 L F
.519 .32 .551 r
.27751 .5433 m .27444 .54589 L .27507 .54234 L F
.176 0 0 r
.27232 .54438 m .27467 .54381 L .27504 .54322 L F
.2744 .5431 m .27504 .54322 L .27559 .54237 L F
.27232 .54438 m .27504 .54322 L .2744 .5431 L F
.016 .301 .794 r
.27005 .53915 m .27236 .54272 L .27283 .54153 L F
.84 .883 .873 r
.67793 .32257 m .67594 .32442 L .67916 .32418 L F
.852 .884 .862 r
.67793 .32257 m .67916 .32418 L .68187 .32108 L F
.479 .358 .637 r
.46684 .51746 m .46712 .52022 L .46475 .5209 L F
.417 .293 .602 r
.46712 .52022 m .46516 .52358 L .46475 .5209 L F
.371 .319 .669 r
.22293 .58102 m .22333 .58525 L .22136 .58378 L F
.464 .261 .518 r
.22571 .58384 m .22536 .58677 L .22333 .58525 L F
.559 .018 0 r
.22333 .58525 m .22532 .58712 L .22543 .58691 L F
.464 .261 .518 r
.22536 .58677 m .22532 .58712 L .22333 .58525 L F
.675 .127 0 r
.22543 .58691 m .22166 .58401 L .22333 .58525 L F
.22166 .58401 m .22136 .58378 L .22333 .58525 L F
.71 .272 .209 r
.34964 .58641 m .34863 .58437 L .34698 .58701 L F
.34964 .58641 m .35123 .5848 L .34863 .58437 L F
.737 .701 .817 r
.51169 .44136 m .50714 .4405 L .5097 .43958 L F
.626 .688 .889 r
.42785 .50631 m .43185 .50799 L .42991 .50417 L F
.852 .92 .876 r
.42646 .50519 m .42785 .50631 L .42991 .50417 L F
.42646 .50519 m .42991 .50417 L .42828 .50315 L F
.775 .388 0 r
.42991 .50417 m .43185 .50799 L .42954 .50397 L F
.969 .806 .624 r
.43185 .50799 m .4297 .50903 L .42954 .50397 L F
.594 .431 .63 r
.32911 .51179 m .33177 .51103 L .3314 .50788 L F
0 0 .217 r
.3326 .50394 m .3314 .50788 L .33269 .50653 L F
.784 .774 .844 r
.33177 .51103 m .33269 .50653 L .3314 .50788 L F
.679 .521 .665 r
.47869 .47609 m .48137 .47563 L .47878 .47885 L F
.779 .408 .353 r
.37907 .65373 m .37968 .65246 L .3772 .65207 L F
.747 .227 0 r
.37839 .65392 m .37907 .65373 L .37895 .65362 L F
.37839 .65392 m .37895 .65362 L .3772 .65207 L F
.765 .372 .309 r
.37839 .65392 m .37607 .65633 L .37727 .6545 L F
.695 .216 .109 r
.3772 .65207 m .37968 .65246 L .37839 .65392 L F
.765 .372 .309 r
.37839 .65392 m .37727 .6545 L .37843 .65272 L F
.227 0 .093 r
.38156 .65222 m .37968 .65246 L .37907 .65373 L F
.576 .941 .886 r
.37843 .65272 m .37894 .65351 L .37839 .65392 L F
.37894 .65351 m .37907 .65373 L .37839 .65392 L F
.227 0 .093 r
.38156 .65222 m .37907 .65373 L .38141 .65254 L F
.812 .612 .632 r
.38141 .65254 m .3823 .65484 L .38051 .65442 L F
.38156 .65222 m .38163 .65246 L .38141 .65254 L F
.38163 .65246 m .3823 .65484 L .38141 .65254 L F
.576 .941 .886 r
.37894 .65351 m .38064 .65281 L .37907 .65373 L F
.38064 .65281 m .38141 .65254 L .37907 .65373 L F
.812 .612 .632 r
.38007 .65302 m .38051 .65442 L .37839 .65392 L F
.38156 .65222 m .38141 .65254 L .38007 .65302 L F
.38141 .65254 m .38051 .65442 L .38007 .65302 L F
.227 0 .093 r
.38156 .65222 m .38141 .65254 L .38181 .65234 L F
.576 .941 .886 r
.38158 .65237 m .38181 .65234 L .38064 .65281 L F
.38007 .65302 m .38064 .65281 L .37894 .65351 L F
.38158 .65237 m .38064 .65281 L .38007 .65302 L F
.38064 .65281 m .38181 .65234 L .38141 .65254 L F
.812 .612 .632 r
.38049 .65236 m .37894 .65351 L .37968 .65246 L F
.37894 .65351 m .37863 .65364 L .37968 .65246 L F
.38156 .65222 m .37839 .65392 L .38049 .65236 L F
.576 .941 .886 r
.37843 .65272 m .38158 .65237 L .37894 .65351 L F
.812 .612 .632 r
.37894 .65351 m .37839 .65392 L .37863 .65364 L F
.89 .852 .798 r
.64514 .41171 m .64747 .40835 L .64595 .40693 L F
.908 .845 .77 r
.64747 .40835 m .64731 .40444 L .64595 .40693 L F
0 0 0 r
.25505 .55636 m .25301 .55806 L .25132 .55834 L F
.25528 .55716 m .25505 .55636 L .25737 .55566 L F
.25528 .55716 m .25301 .55806 L .25505 .55636 L F
.748 .693 .799 r
.40185 .48179 m .39807 .47984 L .40091 .47977 L F
.40185 .48179 m .39988 .48251 L .39807 .47984 L F
.596 .167 .196 r
.40251 .48386 m .39988 .48251 L .40185 .48179 L F
.768 .813 .888 r
.40524 .47911 m .40185 .48179 L .40091 .47977 L F
.625 .404 .561 r
.30321 .55214 m .30013 .54973 L .30383 .55004 L F
.469 .36 .647 r
.30554 .54568 m .3061 .54945 L .30383 .55004 L F
.345 .046 .306 r
.3061 .54945 m .30321 .55214 L .30383 .55004 L F
.543 .398 .634 r
.46808 .50741 m .46636 .51232 L .46485 .50969 L F
.625 .404 .561 r
.30013 .54973 m .30321 .55214 L .30124 .54863 L F
.30013 .54973 m .30058 .55245 L .30321 .55214 L F
.30321 .55214 m .30058 .55245 L .30013 .54973 L F
.183 0 .354 r
.36478 .60117 m .3647 .60354 L .36639 .6029 L F
.292 0 .156 r
.33974 .68066 m .33553 .68426 L .33784 .68347 L F
.86 .547 .457 r
.34247 .68672 m .33974 .68066 L .34175 .68374 L F
.689 .333 .368 r
.33784 .68347 m .34175 .68374 L .33974 .68066 L F
.708 .515 .626 r
.24757 .57239 m .25109 .57176 L .25036 .56776 L F
.985 .724 .346 r
.37321 .59213 m .37388 .5948 L .37472 .59298 L F
.37321 .59213 m .37277 .59411 L .37388 .5948 L F
.435 .264 .55 r
.49351 .46919 m .49197 .47141 L .49278 .46718 L F
.795 .748 .81 r
.49351 .46919 m .49068 .47229 L .49197 .47141 L F
.744 .659 .766 r
.49351 .46919 m .49717 .47363 L .49068 .47229 L F
.539 .125 .204 r
.49717 .47363 m .49621 .47438 L .49041 .47514 L F
.015 0 .341 r
.499 .46969 m .49717 .47363 L .49351 .46919 L F
.499 .46969 m .49821 .47255 L .49717 .47363 L F
.291 .039 .349 r
.49821 .47255 m .49621 .47438 L .49717 .47363 L F
.928 .569 .322 r
.43173 .58413 m .43002 .58436 L .42972 .58188 L F
.723 .679 .807 r
.42972 .58188 m .43173 .58413 L .43409 .58151 L F
.614 .125 0 r
.58472 .38598 m .58703 .38859 L .58633 .38798 L F
0 .044 .601 r
.58633 .38798 m .58704 .38806 L .58549 .38724 L F
.728 .209 0 r
.58472 .38598 m .58633 .38798 L .58434 .38662 L F
0 .044 .601 r
.58633 .38798 m .58549 .38724 L .58434 .38662 L F
.614 .125 0 r
.58703 .38859 m .58759 .38922 L .58633 .38798 L F
0 0 .337 r
.58759 .38922 m .58808 .38994 L .58633 .38798 L F
.58759 .38922 m .58877 .39182 L .58808 .38994 L F
0 0 0 r
.34805 .68615 m .34342 .68777 L .34581 .68701 L F
.858 .98 .857 r
.34978 .68429 m .34805 .68615 L .34581 .68701 L F
.493 .045 .113 r
.34947 .58084 m .3541 .57901 L .3521 .58045 L F
.34947 .58084 m .35021 .57967 L .3541 .57901 L F
.499 .644 .921 r
.36362 .54127 m .36548 .54375 L .3625 .54335 L F
.718 .714 .185 r
.69323 .28969 m .69317 .28956 L .69415 .28765 L F
.69323 .28969 m .69261 .2923 L .69317 .28956 L F
.206 0 .268 r
.30315 .62359 m .305 .62292 L .30578 .62039 L F
.352 .126 .425 r
.30259 .62601 m .305 .62292 L .30315 .62359 L F
.661 .623 .801 r
.28069 .51991 m .27579 .51701 L .27818 .51639 L F
.656 .701 .879 r
.28114 .51551 m .28069 .51991 L .27818 .51639 L F
.28114 .51551 m .28476 .51988 L .28069 .51991 L F
.843 .961 .884 r
.68942 .37472 m .69033 .37595 L .69332 .3729 L F
.239 0 0 r
.44449 .57117 m .4469 .57079 L .44846 .56881 L F
.534 .272 .465 r
.34724 .56578 m .34695 .56835 L .34952 .56788 L F
.675 .19 .089 r
.41403 .49395 m .4189 .49527 L .41591 .49626 L F
.84 .829 .837 r
.51501 .43311 m .51688 .43475 L .51397 .4377 L F
.965 .841 .426 r
.52869 .41932 m .52918 .42101 L .5297 .41813 L F
.85 .624 .083 r
.52875 .4209 m .52918 .42101 L .52869 .41932 L F
.237 .753 .768 r
.52875 .4209 m .53299 .4202 L .52918 .42101 L F
.299 .794 .8 r
.53447 .41976 m .53299 .4202 L .52875 .4209 L F
.823 .725 .756 r
.51397 .4377 m .5097 .43958 L .51237 .43641 L F
.84 .829 .837 r
.51501 .43311 m .51397 .4377 L .51237 .43641 L F
.151 0 .243 r
.30578 .62039 m .30717 .62181 L .30839 .62 L F
.30578 .62039 m .305 .62292 L .30717 .62181 L F
.708 .808 .927 r
.44173 .46224 m .43753 .46177 L .44005 .46047 L F
.692 .808 .937 r
.44423 .46031 m .44173 .46224 L .44005 .46047 L F
.472 .826 .996 r
.28089 .52157 m .27877 .52062 L .27656 .52125 L F
.481 .843 .992 r
.28335 .52079 m .27877 .52062 L .28089 .52157 L F
.69 .642 .797 r
.35094 .67282 m .35396 .67198 L .35401 .67138 L F
.922 .587 .387 r
.60112 .40119 m .60313 .4019 L .60337 .40423 L F
.875 .896 .475 r
.41249 .58346 m .41378 .58164 L .41265 .58448 L F
.993 .878 .591 r
.41372 .57796 m .41378 .58164 L .41338 .5808 L F
.935 .886 .476 r
.41338 .5808 m .41378 .58164 L .41249 .58346 L F
.755 .823 .905 r
.74014 .32997 m .74156 .3319 L .74318 .33031 L F
.74014 .32997 m .74156 .3319 L .74318 .33031 L F
0 0 0 r
.3503 .62987 m .3477 .63191 L .34631 .6332 L F
.732 .578 .681 r
.29775 .65974 m .29865 .66246 L .29897 .66116 L F
.29775 .65974 m .29897 .66116 L .29701 .66093 L F
.826 .849 .865 r
.33825 .56433 m .33757 .56448 L .34047 .56562 L F
.33758 .56395 m .33757 .56429 L .33825 .56433 L F
.33757 .56429 m .33757 .56448 L .33825 .56433 L F
.33757 .56448 m .33754 .56842 L .33923 .56681 L F
.33757 .56448 m .33923 .56681 L .34047 .56562 L F
.667 .641 .815 r
.33162 .56428 m .33393 .56764 L .33648 .56418 L F
.57 .013 0 r
.33743 .56428 m .33618 .5641 L .33679 .56367 L F
.33743 .56428 m .33679 .56367 L .33708 .56378 L F
.33743 .56428 m .33701 .56425 L .33635 .56415 L F
.782 .822 .883 r
.33393 .56764 m .33754 .56842 L .33701 .56425 L F
.57 .013 0 r
.33743 .56428 m .33635 .56415 L .33618 .5641 L F
.782 .822 .883 r
.3366 .5642 m .33701 .56425 L .33695 .56374 L F
.33393 .56764 m .33701 .56425 L .3366 .5642 L F
.826 .849 .865 r
.3371 .56379 m .33754 .56842 L .33758 .56395 L F
.33695 .56374 m .33697 .56394 L .3371 .56379 L F
.33697 .56394 m .33754 .56842 L .3371 .56379 L F
.667 .641 .815 r
.33162 .56428 m .33648 .56418 L .33515 .56381 L F
.805 .329 .088 r
.3348 .56136 m .33874 .56446 L .33817 .56161 L F
.642 .343 .45 r
.33817 .56161 m .3378 .5634 L .3348 .56136 L F
.667 .641 .815 r
.33162 .56428 m .3367 .5636 L .33536 .56367 L F
.33515 .56381 m .33618 .5641 L .33679 .56367 L F
.805 .329 .088 r
.3348 .56136 m .33631 .56347 L .33693 .56373 L F
.667 .641 .815 r
.3367 .5636 m .33679 .56367 L .33693 .56357 L F
.33515 .56381 m .33679 .56367 L .3367 .5636 L F
.805 .329 .088 r
.33693 .56373 m .33681 .56368 L .33695 .56374 L F
.57 .013 0 r
.33618 .5641 m .3366 .5636 L .33678 .56368 L F
.3366 .5636 m .3366 .56359 L .33678 .56368 L F
.33678 .56368 m .3366 .56359 L .33679 .56367 L F
.805 .329 .088 r
.33681 .56368 m .33633 .5635 L .33684 .5637 L F
.33681 .56368 m .33684 .5637 L .33695 .56374 L F
.33631 .56347 m .33633 .5635 L .33693 .56373 L F
.667 .641 .815 r
.33306 .56392 m .33311 .56391 L .33372 .56375 L F
.33311 .56391 m .33536 .56367 L .33372 .56375 L F
.3367 .5636 m .3366 .56359 L .33372 .56375 L F
.57 .013 0 r
.33618 .5641 m .33372 .56375 L .3366 .56359 L F
.667 .641 .815 r
.33162 .56428 m .33536 .56367 L .33306 .56392 L F
.57 .013 0 r
.33701 .56425 m .33582 .56411 L .33574 .56405 L F
.782 .822 .883 r
.33474 .56654 m .33659 .5642 L .33648 .56418 L F
.33475 .56658 m .33695 .56374 L .33474 .56654 L F
.826 .849 .865 r
.33772 .56401 m .33869 .56458 L .33874 .56446 L F
.33869 .56458 m .34047 .56562 L .33874 .56446 L F
.805 .329 .088 r
.3377 .56404 m .33868 .56444 L .33869 .56444 L F
.33844 .56433 m .33869 .56444 L .3387 .56443 L F
.3377 .56404 m .33869 .56444 L .33844 .56433 L F
.33844 .56423 m .33708 .56378 L .3387 .56443 L F
.3348 .56136 m .33695 .56374 L .33844 .56423 L F
.826 .849 .865 r
.33717 .56371 m .33758 .56395 L .3372 .5637 L F
.33758 .56395 m .34047 .56562 L .33772 .56401 L F
.33758 .56395 m .33772 .56401 L .3372 .5637 L F
.805 .329 .088 r
.33708 .56378 m .3377 .56404 L .33844 .56433 L F
.33841 .56432 m .33844 .56433 L .3387 .56443 L F
.33708 .56378 m .33844 .56433 L .33841 .56432 L F
.57 .013 0 r
.33874 .56446 m .33743 .56428 L .33708 .56378 L F
.805 .329 .088 r
.33708 .56378 m .33695 .56374 L .3377 .56404 L F
.826 .849 .865 r
.3372 .5637 m .33772 .56401 L .33874 .56446 L F
.33693 .56357 m .33717 .56371 L .3372 .5637 L F
.33693 .56357 m .33695 .56374 L .33758 .56395 L F
.57 .013 0 r
.33874 .56446 m .33708 .56378 L .33693 .56357 L F
.33874 .56446 m .33465 .56408 L .33701 .56425 L F
.33874 .56446 m .33701 .56425 L .3383 .5644 L F
.33874 .56446 m .33746 .56509 L .33687 .56429 L F
.3383 .5644 m .33701 .56425 L .33743 .56428 L F
.805 .329 .088 r
.33719 .56384 m .33746 .56509 L .33868 .56444 L F
.33719 .56384 m .33746 .56509 L .33719 .56384 L F
.337 .56396 m .33746 .56509 L .33719 .56384 L F
.57 .013 0 r
.33687 .56429 m .33746 .56509 L .33465 .56408 L F
.805 .329 .088 r
.33633 .5635 m .33868 .56444 L .3377 .56404 L F
.573 .53 .77 r
.33817 .56161 m .33874 .56446 L .34151 .56253 L F
.189 0 .3 r
.33908 .56334 m .33746 .56509 L .33777 .56359 L F
.57 .013 0 r
.33701 .56425 m .33465 .56408 L .33417 .56391 L F
.474 .612 .907 r
.33411 .56365 m .33594 .56444 L .33477 .56348 L F
.33594 .56444 m .33746 .56509 L .33626 .56437 L F
.57 .013 0 r
.33618 .5641 m .33635 .56415 L .33372 .56375 L F
.474 .612 .907 r
.33594 .56444 m .33626 .56437 L .33477 .56348 L F
.805 .329 .088 r
.3369 .56373 m .337 .56396 L .33719 .56384 L F
.782 .822 .883 r
.33648 .56418 m .33695 .56374 L .33684 .5637 L F
.667 .641 .815 r
.3367 .5636 m .33693 .56357 L .3366 .56359 L F
.57 .013 0 r
.33679 .56367 m .3366 .56359 L .33693 .56357 L F
.805 .329 .088 r
.33641 .56356 m .33746 .56509 L .3369 .56373 L F
.33637 .56356 m .33746 .56509 L .33641 .56356 L F
.33633 .5635 m .33637 .56355 L .3369 .56373 L F
.57 .013 0 r
.33708 .56378 m .33679 .56367 L .33693 .56357 L F
.782 .822 .883 r
.33684 .5637 m .33695 .56374 L .33693 .56357 L F
.642 .343 .45 r
.3378 .5634 m .33746 .56509 L .33637 .56356 L F
.17 0 0 r
.3365 .56431 m .33874 .56367 L .33664 .56424 L F
.474 .612 .907 r
.33417 .56391 m .33746 .56509 L .33411 .56365 L F
.453 .343 .639 r
.33082 .55819 m .33174 .56369 L .33397 .56244 L F
.607 .71 .917 r
.33397 .56244 m .33174 .56369 L .33085 .56295 L F
.474 .612 .907 r
.33372 .56375 m .33477 .56348 L .33322 .56255 L F
.969 .767 .577 r
.33746 .56509 m .33526 .56503 L .33322 .56255 L F
.17 0 0 r
.3357 .56478 m .33765 .56407 L .3365 .56431 L F
.33765 .56407 m .33874 .56367 L .3365 .56431 L F
.33526 .56503 m .33536 .565 L .3357 .56478 L F
.33536 .565 m .33874 .56367 L .3357 .56478 L F
.141 0 .25 r
.33953 .56285 m .33766 .56536 L .33746 .56509 L F
.33766 .56536 m .33708 .56615 L .33746 .56509 L F
.691 .904 .551 r
.33874 .56446 m .33708 .56615 L .33766 .56536 L F
.805 .329 .088 r
.3387 .56443 m .33746 .56509 L .33874 .56446 L F
.691 .904 .551 r
.33874 .56446 m .33766 .56536 L .33919 .56331 L F
.33874 .56446 m .33919 .56331 L .33953 .56285 L F
.189 0 .3 r
.33953 .56285 m .33908 .56334 L .33793 .56281 L F
.33908 .56334 m .33777 .56359 L .33793 .56281 L F
.782 .822 .883 r
.33659 .5642 m .33695 .56374 L .33648 .56418 L F
.33393 .56764 m .33475 .56658 L .33474 .56654 L F
.474 .612 .907 r
.33372 .56375 m .33417 .56391 L .33411 .56365 L F
.805 .329 .088 r
.33637 .56355 m .33637 .56356 L .33641 .56356 L F
.642 .343 .45 r
.3378 .5634 m .33637 .56356 L .3348 .56136 L F
.189 0 .3 r
.33861 .56201 m .33793 .56281 L .33817 .56161 L F
.33953 .56285 m .33793 .56281 L .33861 .56201 L F
.667 .641 .815 r
.33618 .5641 m .33648 .56418 L .33693 .56357 L F
.072 0 0 r
.33571 .56891 m .33482 .56977 L .33584 .56885 L F
.33253 .57049 m .33482 .56977 L .33571 .56891 L F
.301 .003 .281 r
.33184 .57267 m .33401 .57208 L .33482 .56977 L F
.971 .734 .522 r
.33482 .56977 m .33401 .57208 L .33361 .57094 L F
.39 .068 .295 r
.33021 .57031 m .33393 .56764 L .33103 .5681 L F
.33021 .57031 m .33253 .57049 L .33393 .56764 L F
.072 0 0 r
.33253 .57049 m .33584 .56885 L .33393 .56764 L F
.301 .003 .281 r
.33184 .57267 m .33482 .56977 L .33253 .57049 L F
.971 .734 .522 r
.33482 .56977 m .33361 .57094 L .33268 .56831 L F
.849 .975 .669 r
.33584 .56885 m .33482 .56977 L .33528 .56904 L F
.947 .588 .25 r
.33584 .56885 m .33728 .56837 L .33393 .56764 L F
.849 .975 .669 r
.33584 .56885 m .33528 .56904 L .33708 .56615 L F
.947 .588 .25 r
.33584 .56885 m .33754 .56842 L .33728 .56837 L F
.33584 .56885 m .33811 .57091 L .33754 .56842 L F
0 .068 .59 r
.33607 .51237 m .33745 .51262 L .33883 .50987 L F
.435 .264 .55 r
.49351 .46919 m .49278 .46718 L .49361 .46623 L F
.857 .776 .772 r
.33566 .55679 m .33082 .55819 L .33313 .5542 L F
.33566 .55679 m .33299 .55963 L .33082 .55819 L F
.574 .675 .908 r
.3377 .55584 m .33566 .55679 L .33313 .5542 L F
.18 .694 .893 r
.35211 .65241 m .34959 .65248 L .35062 .65194 L F
.35062 .65194 m .34959 .65248 L .35211 .65241 L F
.753 .652 .75 r
.26812 .51729 m .26605 .51737 L .27016 .51762 L F
.02 .591 .76 r
.26834 .51783 m .27266 .51809 L .27016 .51762 L F
.873 .472 .015 r
.39763 .55857 m .39988 .56223 L .39888 .55983 L F
.265 0 0 r
.31274 .5584 m .31513 .55856 L .31153 .55851 L F
0 0 .023 r
.32196 .58773 m .3235 .58728 L .32424 .58479 L F
0 0 0 r
.32196 .58773 m .32037 .58979 L .3235 .58728 L F
0 .104 .605 r
.40702 .53885 m .40335 .53544 L .40443 .53679 L F
0 0 .41 r
.396 .51732 m .39729 .52095 L .39698 .51935 L F
.725 .44 0 r
.3981 .52334 m .39698 .51935 L .39729 .52095 L F
.499 .802 .999 r
.60855 .35258 m .60466 .35195 L .60721 .35123 L F
.613 .802 .972 r
.61018 .35 m .60855 .35258 L .60721 .35123 L F
.61018 .35 m .6107 .35169 L .60855 .35258 L F
.118 .217 .692 r
.26509 .6335 m .26756 .63413 L .26686 .63224 L F
.26509 .6335 m .26721 .63589 L .26756 .63413 L F
.937 .625 .17 r
.41348 .59138 m .4122 .59221 L .4128 .59022 L F
.41348 .59138 m .41391 .59425 L .4122 .59221 L F
0 .347 .726 r
.27685 .53541 m .27851 .53608 L .27935 .53662 L F
.614 .494 .692 r
.27851 .53608 m .27773 .53884 L .27935 .53662 L F
.427 .197 .461 r
.30554 .54568 m .3084 .54277 L .30577 .54359 L F
.674 .976 .831 r
.25668 .51983 m .25744 .51828 L .25941 .51885 L F
.25668 .51983 m .25534 .52004 L .25744 .51828 L F
.644 .495 .666 r
.44402 .53358 m .44459 .53669 L .44144 .53684 L F
.319 .068 .368 r
.44459 .53669 m .44262 .53961 L .44144 .53684 L F
.644 .495 .666 r
.44144 .53684 m .44459 .53669 L .44402 .53358 L F
.44144 .53684 m .44459 .53669 L .44402 .53358 L F
.201 .412 .844 r
.27618 .61759 m .27579 .62001 L .27371 .6178 L F
.27618 .61759 m .27692 .61963 L .27579 .62001 L F
.757 .332 .241 r
.27338 .62168 m .27559 .62245 L .27579 .62001 L F
.27338 .62168 m .27579 .62001 L .27692 .61963 L F
.953 .752 .596 r
.3228 .55179 m .32518 .55468 L .3271 .55422 L F
.3228 .55179 m .32242 .55417 L .32518 .55468 L F
.383 .558 .902 r
.21648 .59651 m .21686 .598 L .21811 .59609 L F
.495 .485 .776 r
.21707 .60062 m .21811 .59609 L .21686 .598 L F
.688 .674 .832 r
.39807 .47984 m .39988 .48251 L .39583 .48208 L F
.192 0 0 r
.39988 .48251 m .39582 .48488 L .39583 .48208 L F
.39988 .48251 m .39796 .48455 L .39582 .48488 L F
.596 .167 .196 r
.40251 .48386 m .39796 .48455 L .39988 .48251 L F
.793 .742 .806 r
.5245 .41256 m .52537 .41493 L .523 .4136 L F
.925 .883 .774 r
.52537 .41493 m .52189 .41719 L .523 .4136 L F
.52537 .41493 m .52344 .41866 L .52189 .41719 L F
.724 .708 .834 r
.52756 .41314 m .52537 .41493 L .5245 .41256 L F
.836 .916 .89 r
.63392 .36036 m .63569 .35599 L .63271 .35916 L F
.63392 .36036 m .63674 .35777 L .63569 .35599 L F
.976 .674 .321 r
.59989 .4223 m .60106 .42107 L .5991 .42007 L F
.59989 .4223 m .60132 .42371 L .60106 .42107 L F
.767 .742 .83 r
.49895 .43852 m .50064 .44043 L .49667 .43993 L F
.71 .74 .874 r
.50182 .43607 m .50064 .44043 L .49895 .43852 L F
.50182 .43607 m .50319 .4394 L .50064 .44043 L F
.511 .557 .839 r
.28443 .52666 m .28617 .53047 L .28798 .52952 L F
0 0 0 r
.36963 .5252 m .36914 .52486 L .37157 .52335 L F
.36963 .5252 m .3685 .52664 L .36914 .52486 L F
.441 0 0 r
.28262 .63027 m .28108 .62935 L .28299 .63017 L F
.453 0 0 r
.28094 .63052 m .28299 .63017 L .28108 .62935 L F
.157 .695 .717 r
.28341 .63006 m .28299 .63017 L .28094 .63052 L F
.28521 .62972 m .28299 .63017 L .28341 .63006 L F
.441 0 0 r
.28457 .63145 m .28262 .63027 L .28299 .63017 L F
.273 .568 .936 r
.28521 .62972 m .28457 .63145 L .28299 .63017 L F
.28521 .62972 m .28801 .6328 L .28457 .63145 L F
.711 .888 .503 r
.43156 .53979 m .43215 .53828 L .43261 .5376 L F
0 0 0 r
.43156 .53979 m .43119 .542 L .43261 .5376 L F
.795 .991 .881 r
.36207 .69413 m .36407 .69246 L .36244 .69229 L F
.456 .544 .858 r
.36207 .69413 m .36603 .69748 L .36407 .69246 L F
0 0 0 r
.36207 .69413 m .36407 .69246 L .36324 .6953 L F
.687 .59 .742 r
.36374 .69546 m .36164 .69658 L .36323 .6953 L F
.36513 .69589 m .36469 .69597 L .36374 .69546 L F
.36469 .69597 m .36164 .69658 L .36374 .69546 L F
0 0 0 r
.36207 .69413 m .36324 .6953 L .36323 .6953 L F
.36305 .69536 m .36323 .6953 L .36309 .69541 L F
.36207 .69413 m .36323 .6953 L .36305 .69536 L F
.36207 .69413 m .36305 .69536 L .36244 .69229 L F
.687 .59 .742 r
.36309 .69525 m .36164 .69658 L .36071 .69452 L F
.36323 .6953 m .36309 .69541 L .36309 .69525 L F
0 0 0 r
.36305 .69536 m .36309 .69541 L .36309 .69525 L F
.687 .59 .742 r
.36309 .69541 m .36164 .69658 L .36309 .69525 L F
0 0 0 r
.36309 .69525 m .36317 .69551 L .3631 .69521 L F
.36309 .69541 m .36324 .6953 L .36317 .69551 L F
.36309 .69541 m .36317 .69551 L .36309 .69525 L F
.36305 .69536 m .3631 .69521 L .36244 .69229 L F
.778 .363 .264 r
.35917 .69213 m .36244 .69229 L .36308 .6951 L F
.35917 .69213 m .36308 .6951 L .36197 .69449 L F
.585 .01 0 r
.36407 .69246 m .36244 .69229 L .3631 .69521 L F
.36324 .6953 m .3631 .69521 L .36317 .69551 L F
.36407 .69246 m .3631 .69521 L .36324 .6953 L F
.838 .789 .805 r
.36603 .69748 m .36633 .69394 L .36407 .69246 L F
.585 .01 0 r
.36407 .69246 m .36633 .69394 L .36244 .69229 L F
.36407 .69246 m .36633 .69394 L .36244 .69229 L F
0 0 .344 r
.36325 .6951 m .36244 .69229 L .36394 .69111 L F
.687 .59 .742 r
.36323 .6953 m .36305 .69524 L .3641 .69504 L F
0 0 .344 r
.36317 .69551 m .3631 .69521 L .36325 .6951 L F
.3631 .69521 m .36244 .69229 L .36325 .6951 L F
.778 .363 .264 r
.36197 .69449 m .36308 .6951 L .3631 .69521 L F
.687 .59 .742 r
.36305 .69524 m .36177 .69468 L .3631 .69521 L F
.778 .363 .264 r
.36255 .69499 m .3631 .69521 L .36317 .69551 L F
.36197 .69449 m .3631 .69521 L .36255 .69499 L F
.35917 .69213 m .36255 .69499 L .36071 .69452 L F
.687 .59 .742 r
.36305 .69524 m .36071 .69452 L .36236 .69494 L F
.778 .363 .264 r
.36255 .69499 m .36317 .69551 L .36071 .69452 L F
.687 .59 .742 r
.36236 .69494 m .36071 .69452 L .36177 .69468 L F
.3631 .69521 m .36327 .69491 L .36325 .6951 L F
0 0 .344 r
.36317 .69551 m .36325 .6951 L .36335 .69441 L F
.36325 .6951 m .36394 .69111 L .36335 .69441 L F
.687 .59 .742 r
.3631 .69521 m .36177 .69468 L .36327 .69491 L F
.36325 .6951 m .36327 .69491 L .36347 .69494 L F
.36305 .69524 m .36347 .69494 L .3641 .69504 L F
.36339 .69445 m .36205 .69448 L .36335 .69441 L F
.36205 .69448 m .36071 .69452 L .36203 .69447 L F
.36205 .69448 m .36203 .69447 L .36335 .69441 L F
.3641 .69504 m .36322 .6949 L .36339 .69445 L F
.36322 .6949 m .36071 .69452 L .36339 .69445 L F
.36513 .69589 m .36323 .6953 L .3641 .69504 L F
.36513 .69589 m .36252 .69853 L .36164 .69658 L F
.248 0 .255 r
.53188 .41479 m .52756 .41314 L .53069 .41116 L F
.556 .501 .749 r
.53348 .40998 m .53188 .41479 L .53069 .41116 L F
.53348 .40998 m .53446 .41408 L .53188 .41479 L F
.218 .736 .725 r
.53188 .41479 m .53293 .41438 L .53095 .41658 L F
.53188 .41479 m .53446 .41408 L .53293 .41438 L F
0 0 .317 r
.3251 .63551 m .32324 .64011 L .32473 .63903 L F
0 0 .146 r
.32473 .63903 m .32324 .64011 L .32301 .64171 L F
.557 .336 .536 r
.33532 .5816 m .33117 .58514 L .33168 .58453 L F
.33532 .5816 m .3354 .58501 L .33117 .58514 L F
.384 .116 .378 r
.3354 .58501 m .33166 .58774 L .33117 .58514 L F
.295 .137 .49 r
.33644 .58392 m .3354 .58501 L .33532 .5816 L F
.284 0 0 r
.3894 .6578 m .39299 .65555 L .39042 .65567 L F
.233 .75 .767 r
.36364 .53627 m .36609 .53566 L .36433 .53618 L F
.36433 .53618 m .36609 .53566 L .36364 .53627 L F
.878 .894 .839 r
.52189 .41719 m .52344 .41866 L .52067 .42148 L F
0 .338 .67 r
.36503 .55671 m .3662 .55713 L .3633 .55536 L F
.36503 .55671 m .36863 .55808 L .3662 .55713 L F
.857 .832 .822 r
.50115 .47278 m .49881 .47589 L .49685 .4748 L F
.937 .745 .619 r
.49881 .47589 m .49831 .47838 L .49685 .4748 L F
.687 .562 .708 r
.50115 .47278 m .5006 .47613 L .49881 .47589 L F
.644 .417 .56 r
.5006 .47613 m .49831 .47838 L .49881 .47589 L F
.573 .522 .759 r
.23757 .53965 m .23967 .5444 L .24073 .54256 L F
.878 .958 .851 r
.23955 .54174 m .23967 .5444 L .24073 .54256 L F
.288 .124 .477 r
.34658 .53611 m .34477 .53894 L .34442 .53675 L F
.893 .985 .719 r
.39488 .60638 m .39333 .61031 L .39429 .60791 L F
.593 .453 .66 r
.47756 .48853 m .47776 .49119 L .47506 .4918 L F
.53 .398 .645 r
.47776 .49119 m .47563 .49517 L .47506 .4918 L F
0 0 0 r
.35381 .63192 m .35241 .63251 L .35465 .6299 L F
.769 .733 .82 r
.35156 .70996 m .35502 .70981 L .35306 .70568 L F
.638 .671 .865 r
.35306 .70568 m .35502 .70981 L .35652 .70632 L F
.494 0 0 r
.35502 .70981 m .35938 .71201 L .35652 .70632 L F
.041 0 0 r
.298 .56159 m .30004 .56128 L .30264 .56035 L F
0 0 0 r
.34835 .67791 m .35035 .67456 L .34909 .6767 L F
.606 .802 .385 r
.34692 .68014 m .34835 .67791 L .34909 .6767 L F
.915 .978 .769 r
.52067 .42148 m .5194 .42366 L .51861 .42263 L F
.044 0 .155 r
.30217 .65809 m .30203 .65625 L .30476 .65468 L F
.707 .572 .7 r
.50371 .47198 m .5006 .47613 L .50115 .47278 L F
.50371 .47198 m .50477 .47545 L .5006 .47613 L F
.493 .443 .73 r
.5075 .47495 m .50371 .47198 L .5075 .47226 L F
.5075 .47495 m .50477 .47545 L .50371 .47198 L F
.805 .81 .856 r
.63849 .40087 m .63724 .40544 L .63537 .40382 L F
.63849 .40087 m .64037 .40278 L .63724 .40544 L F
.729 .265 0 r
.70378 .2995 m .701 .29579 L .70065 .29826 L F
.528 .578 .849 r
.70065 .29826 m .70534 .30185 L .70378 .2995 L F
.717 .978 .763 r
.66794 .3159 m .66486 .31869 L .66633 .31643 L F
.7 .962 .943 r
.66486 .31869 m .66383 .31815 L .66633 .31643 L F
.693 .607 .756 r
.44673 .54333 m .44944 .54329 L .44874 .53999 L F
.531 .231 .403 r
.44627 .54567 m .44944 .54329 L .44673 .54333 L F
.897 .98 .804 r
.38629 .67682 m .38756 .67782 L .38841 .67603 L F
.911 .976 .785 r
.38508 .68083 m .38756 .67782 L .38629 .67682 L F
.181 0 .089 r
.34484 .56916 m .34407 .57027 L .34695 .56835 L F
0 .129 .675 r
.24736 .61288 m .24724 .61444 L .24607 .61151 L F
.918 .615 .455 r
.24736 .61288 m .25008 .61596 L .24724 .61444 L F
.597 .423 .617 r
.38292 .59119 m .38334 .59458 L .38037 .5946 L F
.38292 .59119 m .38334 .59458 L .38037 .5946 L F
.604 .933 .723 r
.38616 .58861 m .38304 .5911 L .38412 .58968 L F
.38304 .5911 m .38292 .59119 L .38412 .58968 L F
.409 .289 .604 r
.38292 .59119 m .38544 .59347 L .38412 .58968 L F
.99 .83 .589 r
.38471 .58704 m .38616 .58861 L .38412 .58968 L F
.879 .564 .054 r
.38412 .58968 m .38463 .59114 L .38469 .59235 L F
.38463 .59114 m .38544 .59347 L .38469 .59235 L F
.409 .289 .604 r
.38292 .59119 m .38334 .59458 L .38544 .59347 L F
.38544 .59347 m .38334 .59458 L .38292 .59119 L F
.577 .359 .548 r
.38544 .59347 m .38276 .59613 L .38334 .59458 L F
.38276 .59613 m .38544 .59347 L .38334 .59458 L F
.522 .248 .44 r
.38834 .59146 m .38993 .59305 L .38544 .59347 L F
.907 .983 .764 r
.39133 .59311 m .38951 .59399 L .39012 .59262 L F
.522 .248 .44 r
.38993 .59305 m .38997 .59309 L .38991 .59309 L F
.38993 .59305 m .38991 .59309 L .38544 .59347 L F
.907 .983 .764 r
.39012 .59262 m .38988 .59292 L .38971 .59246 L F
0 .144 .688 r
.38971 .59246 m .38997 .59309 L .38993 .59305 L F
.38971 .59246 m .38993 .59305 L .38834 .59146 L F
.64 .165 .11 r
.38989 .59308 m .38725 .5946 L .38469 .59235 L F
.38997 .59309 m .38725 .5946 L .38989 .59308 L F
0 0 0 r
.38853 .59398 m .38971 .59246 L .3892 .59347 L F
.38867 .59422 m .3892 .59347 L .38875 .59436 L F
.38853 .59398 m .3892 .59347 L .38867 .59422 L F
.64 .165 .11 r
.38915 .59354 m .38726 .5946 L .38725 .5946 L F
.907 .983 .764 r
.38966 .59321 m .38875 .59436 L .3892 .59347 L F
.64 .165 .11 r
.38997 .59309 m .38915 .59355 L .38915 .59354 L F
.38915 .59355 m .38726 .5946 L .38915 .59354 L F
.907 .983 .764 r
.38988 .59292 m .38966 .59321 L .38971 .59246 L F
.38966 .59321 m .3892 .59347 L .38971 .59246 L F
.38951 .59399 m .38875 .59436 L .39012 .59262 L F
.577 .359 .548 r
.38544 .59347 m .38527 .59625 L .38276 .59613 L F
.38276 .59613 m .38527 .59625 L .38544 .59347 L F
.617 .186 .201 r
.38469 .59235 m .38726 .5946 L .38478 .59431 L F
.38469 .59235 m .38478 .59431 L .38192 .59398 L F
.961 .912 .719 r
.38469 .59235 m .38505 .58848 L .38412 .58968 L F
.38505 .58848 m .38509 .58803 L .38412 .58968 L F
.679 .521 .664 r
.48137 .47563 m .48142 .47839 L .47878 .47885 L F
.638 .462 .628 r
.48412 .47515 m .48142 .47839 L .48137 .47563 L F
.569 .592 .836 r
.39018 .67909 m .39129 .67694 L .38841 .67603 L F
.252 .211 .616 r
.39286 .6768 m .39129 .67694 L .39018 .67909 L F
.511 .512 .794 r
.39169 .68091 m .39286 .6768 L .39018 .67909 L F
.85 .991 .733 r
.66794 .3159 m .6689 .313 L .6696 .31416 L F
.66794 .3159 m .66633 .31643 L .6689 .313 L F
.965 .841 .426 r
.52869 .41932 m .5297 .41813 L .53095 .41658 L F
.804 .594 .618 r
.4469 .57079 m .44987 .57171 L .4475 .57043 L F
.44987 .57171 m .45101 .57206 L .45018 .57167 L F
.44987 .57171 m .45018 .57167 L .4475 .57043 L F
.797 .37 .232 r
.45219 .57126 m .45101 .57206 L .45018 .57167 L F
.134 0 0 r
.451 .57157 m .45219 .57126 L .45018 .57167 L F
.981 .747 .508 r
.451 .57157 m .45101 .57206 L .45219 .57126 L F
.134 0 0 r
.45274 .57137 m .45219 .57126 L .451 .57157 L F
.981 .747 .508 r
.45097 .56838 m .451 .57157 L .45219 .57126 L F
.804 .594 .618 r
.4475 .57043 m .45101 .57206 L .45097 .56838 L F
.721 .236 .091 r
.44796 .57212 m .45101 .57206 L .4469 .57079 L F
.63 .067 0 r
.44703 .57197 m .44806 .57234 L .4469 .57079 L F
.797 .37 .232 r
.45018 .57167 m .45101 .57206 L .44796 .57212 L F
.134 0 0 r
.44843 .57207 m .44846 .57204 L .44796 .57212 L F
.721 .236 .091 r
.44796 .57212 m .4469 .57079 L .44843 .57207 L F
.44796 .57212 m .44843 .57207 L .44926 .57277 L F
.134 0 0 r
.44842 .57208 m .44843 .57207 L .44796 .57212 L F
.63 .067 0 r
.44839 .5721 m .44926 .57277 L .44843 .57207 L F
.335 0 0 r
.45228 .57212 m .44842 .57212 L .44926 .57277 L F
.44842 .57212 m .44796 .57212 L .44926 .57277 L F
.63 .067 0 r
.44806 .57234 m .44926 .57277 L .44839 .5721 L F
.44806 .57234 m .44843 .57207 L .4469 .57079 L F
.134 0 0 r
.45368 .57156 m .45274 .57137 L .44846 .57204 L F
.45368 .57156 m .44846 .57204 L .44842 .57208 L F
.45274 .57137 m .45018 .57167 L .44796 .57212 L F
.537 .496 .757 r
.45219 .57126 m .45422 .56827 L .45097 .56838 L F
.45219 .57126 m .45496 .57155 L .45422 .56827 L F
.134 0 0 r
.45368 .57156 m .45496 .57155 L .45219 .57126 L F
0 0 .407 r
.45073 .56293 m .44865 .5687 L .448 .56395 L F
0 0 .241 r
.44865 .5687 m .44863 .56713 L .448 .56395 L F
0 0 0 r
.44865 .5687 m .44552 .5696 L .44863 .56713 L F
.44865 .5687 m .44852 .56918 L .44552 .5696 L F
0 0 .407 r
.45073 .56293 m .45104 .56641 L .44865 .5687 L F
.167 .09 .517 r
.45284 .56519 m .45104 .56641 L .45101 .56612 L F
.4523 .56461 m .45101 .56612 L .45073 .56293 L F
.45284 .56519 m .45101 .56612 L .4523 .56461 L F
0 0 0 r
.45171 .56539 m .44865 .5687 L .45104 .56641 L F
.45171 .56539 m .44852 .56918 L .44859 .56894 L F
.45065 .56653 m .44859 .56894 L .44865 .5687 L F
.45171 .56539 m .44859 .56894 L .45065 .56653 L F
.885 .6 .085 r
.40341 .53293 m .40234 .5291 L .40331 .53038 L F
.721 .414 .458 r
.51954 .46586 m .52329 .46572 L .52206 .46806 L F
.615 .31 .43 r
.52329 .46572 m .52612 .46805 L .52206 .46806 L F
.52329 .46572 m .52597 .46586 L .52612 .46805 L F
.984 .752 .505 r
.41883 .60107 m .41696 .60272 L .41507 .59999 L F
.41883 .60107 m .41854 .60375 L .41696 .60272 L F
.929 .972 .714 r
.4181 .60033 m .41883 .60107 L .42121 .59659 L F
.984 .752 .505 r
.41696 .60272 m .41883 .60107 L .4181 .60033 L F
.41696 .60272 m .41854 .60375 L .41883 .60107 L F
0 .153 .629 r
.39948 .52696 m .40101 .52786 L .39849 .52541 L F
.39948 .52696 m .40234 .5291 L .40101 .52786 L F
.931 .809 .703 r
.3542 .64569 m .35322 .64984 L .35063 .6485 L F
.3542 .64569 m .35063 .6485 L .35192 .64813 L F
.713 .917 .569 r
.35497 .64407 m .3542 .64569 L .35192 .64813 L F
0 0 0 r
.37096 .53658 m .37324 .53609 L .37366 .53541 L F
.37366 .53541 m .37324 .53609 L .37512 .53495 L F
.595 .399 .585 r
.49578 .46292 m .49361 .46623 L .49441 .46356 L F
0 .396 .833 r
.22527 .60416 m .22556 .60338 L .22354 .60296 L F
.646 .13 .002 r
.22956 .60577 m .22977 .60655 L .22527 .60416 L F
0 .396 .833 r
.22527 .60416 m .22977 .60655 L .22556 .60338 L F
.975 .771 .566 r
.35471 .66739 m .35637 .6685 L .35365 .66978 L F
.551 .826 .997 r
.35724 .66675 m .35637 .6685 L .35471 .66739 L F
.736 .986 .782 r
.35365 .66978 m .35637 .6685 L .35724 .66675 L F
.851 .982 .694 r
.23187 .60436 m .22991 .60744 L .22996 .60612 L F
.76 .994 .87 r
.6867 .29844 m .68477 .30009 L .68281 .30046 L F
.737 .75 .863 r
.45336 .45832 m .45498 .46026 L .45096 .45966 L F
.707 .778 .908 r
.45336 .45832 m .45727 .45886 L .45498 .46026 L F
.557 .847 .998 r
.62012 .37563 m .622 .37651 L .62209 .37214 L F
.678 .213 .141 r
.33166 .58774 m .33373 .58988 L .33589 .58848 L F
.977 .766 .552 r
.33589 .58848 m .33373 .58988 L .33412 .58719 L F
.941 .927 .567 r
.7047 .28339 m .70617 .27963 L .70491 .28038 L F
.79 .959 .637 r
.70491 .28038 m .70617 .27963 L .70714 .27738 L F
.827 .989 .87 r
.64748 .33364 m .64963 .33005 L .65033 .33069 L F
.64748 .33364 m .64667 .3328 L .64963 .33005 L F
.041 .076 .571 r
.4463 .53448 m .44402 .53358 L .44674 .53541 L F
.442 .357 .665 r
.44402 .53358 m .44459 .53669 L .44674 .53541 L F
.041 .076 .571 r
.4463 .53448 m .44459 .53669 L .44402 .53358 L F
.655 .188 .132 r
.54701 .41325 m .54507 .41118 L .54451 .41407 L F
.54701 .41325 m .54758 .41191 L .54507 .41118 L F
.944 .6 .189 r
.41263 .56194 m .41441 .56556 L .41318 .56442 L F
.954 .762 .307 r
.4136 .56828 m .41318 .56442 L .41441 .56556 L F
.657 .434 .57 r
.43276 .48468 m .4298 .4869 L .43036 .48589 L F
.331 .035 .303 r
.36335 .59102 m .36217 .59402 L .35992 .59397 L F
.362 .034 .268 r
.36156 .59618 m .35992 .59397 L .36217 .59402 L F
.36156 .59618 m .35911 .59681 L .35992 .59397 L F
.748 .826 .363 r
.34566 .51396 m .34599 .51271 L .34832 .51089 L F
0 0 0 r
.701 .29579 m .70269 .29286 L .70226 .2944 L F
.415 .458 .797 r
.44288 .54567 m .44413 .54981 L .44588 .54835 L F
.387 .411 .763 r
.44413 .54981 m .4459 .55139 L .44588 .54835 L F
.856 .8 .795 r
.37294 .62872 m .37475 .63237 L .37252 .63301 L F
.756 .443 .455 r
.37475 .63237 m .37637 .63346 L .37252 .63301 L F
.593 .684 .905 r
.37691 .62984 m .37475 .63237 L .37294 .62872 L F
.707 .738 .875 r
.37691 .62984 m .37637 .63346 L .37475 .63237 L F
.85 .748 .75 r
.64101 .41358 m .64514 .41171 L .6435 .41012 L F
.64101 .41358 m .64327 .41518 L .64514 .41171 L F
.89 .852 .798 r
.64514 .41171 m .64595 .40693 L .6435 .41012 L F
.987 .754 .495 r
.40119 .58745 m .40053 .58481 L .40052 .58714 L F
.993 .839 .478 r
.40012 .5891 m .40119 .58745 L .40052 .58714 L F
.706 .884 .963 r
.39713 .49128 m .39493 .49217 L .39323 .49087 L F
.988 .736 .361 r
.39583 .48208 m .39582 .48488 L .39468 .48309 L F
.918 .964 .792 r
.39583 .48208 m .39689 .47787 L .39807 .47984 L F
.39583 .48208 m .395 .48102 L .39689 .47787 L F
.988 .805 .414 r
.39583 .48208 m .39468 .48309 L .395 .48102 L F
.992 .737 .409 r
.70261 .3182 m .7003 .31611 L .70123 .31691 L F
.70261 .3182 m .70251 .32141 L .7003 .31611 L F
.068 0 .315 r
.29865 .66246 m .29789 .66499 L .30004 .66528 L F
.774 .782 .859 r
.65493 .37967 m .65553 .38019 L .65374 .38089 L F
.851 .435 0 r
.36145 .51411 m .36353 .51751 L .36222 .5162 L F
.714 .264 0 r
.36353 .51751 m .36304 .51746 L .36222 .5162 L F
.519 .136 .255 r
.38334 .59458 m .38276 .59613 L .38037 .5946 L F
.38037 .5946 m .38276 .59613 L .38334 .59458 L F
.38334 .59458 m .38276 .59613 L .38037 .5946 L F
0 .537 .752 r
.32985 .4938 m .33396 .49439 L .33199 .49418 L F
.217 .048 .425 r
.30197 .64158 m .30045 .63978 L .30231 .63892 L F
.30197 .64158 m .29993 .64258 L .30045 .63978 L F
.817 .453 .367 r
.32079 .53566 m .31901 .53866 L .31621 .53739 L F
.858 .98 .857 r
.34978 .68429 m .34581 .68701 L .34839 .68665 L F
.59 .345 .514 r
.35226 .68763 m .34978 .68429 L .34839 .68665 L F
.35226 .68763 m .35302 .68467 L .34978 .68429 L F
.185 0 .124 r
.30872 .56182 m .30582 .56442 L .30658 .56274 L F
.669 .439 .563 r
.31054 .61349 m .31353 .61357 L .31349 .61064 L F
.366 .203 .523 r
.31349 .61064 m .31353 .61357 L .31549 .61247 L F
.618 .299 .407 r
.5006 .47613 m .50477 .47545 L .50486 .47794 L F
.659 .475 .624 r
.5075 .47495 m .50486 .47794 L .50477 .47545 L F
0 .08 .615 r
.29333 .63921 m .29521 .64153 L .29487 .63873 L F
.413 .832 .966 r
.55628 .4679 m .55991 .46791 L .5589 .4674 L F
.304 .796 .775 r
.55991 .46791 m .56146 .46717 L .5589 .4674 L F
.55991 .46791 m .56322 .46688 L .56146 .46717 L F
.782 .988 .743 r
.6714 .36858 m .66989 .37042 L .6711 .36805 L F
.786 .995 .78 r
.6711 .36805 m .66989 .37042 L .66821 .37102 L F
.442 .024 .149 r
.30003 .56563 m .29922 .56747 L .29671 .56753 L F
.528 .161 .288 r
.30339 .56456 m .29922 .56747 L .30003 .56563 L F
.838 .927 .89 r
.65446 .39515 m .65841 .3934 L .65617 .39326 L F
.808 .922 .913 r
.65841 .3934 m .65928 .39062 L .65617 .39326 L F
.65841 .3934 m .66049 .39185 L .65928 .39062 L F
.616 .194 .22 r
.57109 .39544 m .57373 .39727 L .5694 .39696 L F
.644 .417 .56 r
.5006 .47613 m .50089 .47815 L .49831 .47838 L F
.618 .299 .407 r
.5006 .47613 m .50486 .47794 L .50089 .47815 L F
.362 .138 .433 r
.51501 .43311 m .51269 .43391 L .51514 .43015 L F
.503 .536 .824 r
.51524 .42592 m .51514 .43015 L .51345 .42668 L F
.51524 .42592 m .51552 .43027 L .51514 .43015 L F
.986 .708 .366 r
.51514 .43015 m .51501 .43311 L .51363 .42913 L F
.883 .822 .783 r
.51501 .43311 m .51552 .43027 L .51514 .43015 L F
.979 .682 .328 r
.51514 .43015 m .51363 .42913 L .51345 .42668 L F
.912 .977 .698 r
.34451 .61657 m .3452 .61692 L .34356 .61945 L F
.983 .719 .444 r
.3452 .61692 m .34541 .62067 L .34356 .61945 L F
.755 .995 .851 r
.34586 .61541 m .3452 .61692 L .34451 .61657 L F
.133 .306 .774 r
.34586 .61541 m .34769 .61892 L .3452 .61692 L F
.983 .719 .444 r
.34541 .62067 m .3452 .61692 L .34769 .61892 L F
.749 .899 .945 r
.36881 .71065 m .3712 .70905 L .36972 .70748 L F
.794 .94 .923 r
.36686 .71014 m .36881 .71065 L .36972 .70748 L F
.158 .276 .736 r
.4593 .55569 m .4595 .55173 L .45796 .55222 L F
.4593 .55569 m .46049 .55426 L .4595 .55173 L F
.183 .313 .763 r
.4593 .55569 m .46214 .5583 L .46049 .55426 L F
0 0 .252 r
.26622 .57259 m .26704 .57354 L .26813 .5724 L F
.26622 .57259 m .26541 .57562 L .26704 .57354 L F
0 .001 .543 r
.22777 .56447 m .22859 .56767 L .22757 .56893 L F
.989 .811 .424 r
.22619 .57018 m .22757 .56893 L .22859 .56767 L F
0 0 .434 r
.23896 .61938 m .23894 .61578 L .23793 .61669 L F
.23896 .61938 m .2396 .6186 L .23894 .61578 L F
0 .152 .694 r
.23896 .61938 m .24098 .62093 L .2396 .6186 L F
.595 .399 .585 r
.49578 .46292 m .49575 .46576 L .49361 .46623 L F
.755 .58 .659 r
.49829 .4626 m .49575 .46576 L .49578 .46292 L F
.438 0 .021 r
.30579 .64448 m .30716 .64241 L .30156 .64384 L F
.333 0 0 r
.30788 .64399 m .30716 .64241 L .30579 .64448 L F
.30788 .64399 m .30958 .64224 L .30716 .64241 L F
.91 .697 .196 r
.41369 .57517 m .41301 .57628 L .41326 .57372 L F
.41369 .57517 m .41372 .57796 L .41301 .57628 L F
0 0 0 r
.24739 .52352 m .24874 .52275 L .24882 .52254 L F
.364 .835 .821 r
.24739 .52352 m .24619 .52366 L .24874 .52275 L F
.757 .353 .286 r
.24558 .6001 m .24899 .60054 L .24761 .59871 L F
.537 .131 .22 r
.33833 .52768 m .34114 .52866 L .34227 .52659 L F
.352 0 .052 r
.34114 .52866 m .34505 .52648 L .34227 .52659 L F
.531 .231 .403 r
.44627 .54567 m .44907 .54594 L .44944 .54329 L F
.555 .515 .766 r
.44874 .53999 m .44944 .54329 L .45199 .54259 L F
.545 .243 .406 r
.44944 .54329 m .45178 .54539 L .45199 .54259 L F
.44944 .54329 m .44907 .54594 L .45178 .54539 L F
.838 .754 .771 r
.63093 .40845 m .63122 .41231 L .62916 .40661 L F
.593 .511 .732 r
.4672 .50184 m .46982 .50103 L .46731 .50424 L F
.607 .531 .743 r
.46731 .50424 m .46982 .50103 L .46999 .5046 L F
.554 .385 .607 r
.46999 .5046 m .46808 .50741 L .46731 .50424 L F
.75 .843 .921 r
.49667 .43993 m .49376 .44217 L .49296 .43997 L F
0 0 .148 r
.31938 .60437 m .3188 .60692 L .32034 .60323 L F
.987 .727 .356 r
.59724 .4607 m .59848 .45969 L .59431 .45888 L F
.59724 .4607 m .59832 .46195 L .59848 .45969 L F
.653 .88 .52 r
.36347 .70039 m .36603 .69748 L .36353 .70077 L F
.838 .789 .805 r
.36603 .69748 m .3687 .69404 L .36633 .69394 L F
.205 0 0 r
.36842 .69688 m .36603 .69748 L .36347 .70039 L F
.47 .264 .517 r
.36842 .69688 m .3687 .69404 L .36603 .69748 L F
.754 .849 .922 r
.39023 .48863 m .3875 .48853 L .39026 .48712 L F
.288 .445 .843 r
.39165 .48684 m .39023 .48863 L .39026 .48712 L F
.502 .513 .8 r
.39165 .48684 m .39068 .4913 L .39023 .48863 L F
0 .256 .753 r
.61118 .38642 m .60913 .38578 L .60842 .38397 L F
.118 0 0 r
.44231 .51824 m .44107 .51788 L .44377 .51745 L F
.44231 .51824 m .43987 .51966 L .44107 .51788 L F
.881 .7 .652 r
.39002 .60748 m .38754 .607 L .38882 .60248 L F
.761 .502 .542 r
.39002 .60748 m .38568 .60984 L .38754 .607 L F
.39002 .60748 m .38941 .60985 L .38568 .60984 L F
.934 .816 .705 r
.40087 .67046 m .4014 .67478 L .4016 .67064 L F
.43 .737 .991 r
.71505 .33617 m .71908 .33734 L .71796 .33537 L F
.51 .562 .845 r
.71908 .33734 m .72107 .33346 L .71796 .33537 L F
.71908 .33734 m .7214 .33765 L .72107 .33346 L F
.953 .941 .731 r
.57406 .4244 m .5749 .42088 L .57266 .42291 L F
0 0 .422 r
.57406 .4244 m .57556 .42526 L .57673 .42371 L F
.757 .587 .667 r
.61842 .39908 m .61919 .39771 L .61412 .39608 L F
.716 .979 .913 r
.30397 .63685 m .30646 .63743 L .3074 .63668 L F
.30397 .63685 m .3074 .63668 L .30652 .6363 L F
.30652 .6363 m .3074 .63668 L .30837 .6359 L F
.30397 .63685 m .30624 .63636 L .30653 .63756 L F
.30624 .63636 m .30837 .6359 L .30653 .63756 L F
.87 .45 .017 r
.30687 .63903 m .30653 .63756 L .30698 .63919 L F
.755 .674 .772 r
.30397 .63685 m .30653 .63756 L .30454 .63397 L F
.806 .7 .748 r
.30698 .63919 m .30614 .64068 L .3051 .63904 L F
.582 .513 .742 r
.30156 .64384 m .29993 .64258 L .30197 .64158 L F
.569 .396 .608 r
.30114 .64259 m .3018 .64339 L .30194 .64178 L F
.29586 .64258 m .30082 .64333 L .29882 .63978 L F
.29542 .643 m .3001 .64328 L .29586 .64258 L F
.3001 .64328 m .30082 .64333 L .29586 .64258 L F
0 .544 .803 r
.30087 .64341 m .30579 .64448 L .30156 .64384 L F
.30062 .64325 m .30224 .64364 L .30087 .64341 L F
.30224 .64364 m .30579 .64448 L .30087 .64341 L F
.569 .396 .608 r
.30082 .64333 m .3018 .64339 L .29882 .63978 L F
0 0 0 r
.30194 .64178 m .30197 .64158 L .30304 .64067 L F
.30122 .6425 m .30304 .64067 L .30335 .64041 L F
0 0 .266 r
.30335 .64041 m .30197 .64158 L .30231 .63892 L F
.419 .269 .569 r
.30242 .63638 m .30194 .64178 L .30335 .64041 L F
.30194 .64178 m .3018 .64339 L .30335 .64041 L F
0 0 0 r
.30122 .6425 m .30132 .64238 L .30194 .64178 L F
.30132 .64238 m .30197 .64158 L .30194 .64178 L F
.864 .82 .804 r
.30335 .64041 m .3018 .64339 L .30073 .64312 L F
0 0 0 r
.30069 .64317 m .30122 .6425 L .30335 .64041 L F
.569 .396 .608 r
.29882 .63978 m .30114 .64259 L .30242 .63638 L F
.30114 .64259 m .30194 .64178 L .30242 .63638 L F
.864 .82 .804 r
.30335 .64041 m .30073 .64312 L .30012 .64297 L F
0 0 0 r
.30062 .64325 m .30069 .64317 L .30335 .64041 L F
.598 .532 .752 r
.2997 .64337 m .30065 .64567 L .30156 .64384 L F
0 .544 .803 r
.30111 .64384 m .30156 .64384 L .30156 .64437 L F
.30062 .64325 m .30087 .64341 L .30111 .64384 L F
.30087 .64341 m .30156 .64384 L .30111 .64384 L F
.744 .683 .792 r
.3051 .63904 m .30614 .64068 L .3009 .64312 L F
.145 .661 .891 r
.29995 .64298 m .30066 .64313 L .29542 .643 L F
.30066 .64313 m .3018 .64339 L .30013 .64328 L F
.30066 .64313 m .30013 .64328 L .29542 .643 L F
.744 .683 .792 r
.3051 .63904 m .30078 .6431 L .30335 .64041 L F
.30078 .6431 m .30062 .64325 L .30076 .64311 L F
.30078 .6431 m .30076 .64311 L .30335 .64041 L F
.30078 .6431 m .3009 .64312 L .30062 .64325 L F
.3051 .63904 m .3009 .64312 L .30078 .6431 L F
.145 .661 .891 r
.30012 .64297 m .3004 .64304 L .30009 .643 L F
.3004 .64304 m .3018 .64339 L .29995 .64298 L F
.681 .717 .877 r
.30614 .64068 m .30579 .64448 L .30062 .64325 L F
.981 .849 .637 r
.29923 .64661 m .30156 .64437 L .30012 .64297 L F
.30012 .64297 m .30156 .64437 L .29923 .64661 L F
0 .034 .605 r
.30012 .64297 m .30197 .64539 L .30066 .64255 L F
.864 .82 .804 r
.30335 .64041 m .30012 .64297 L .30025 .64167 L F
0 .034 .605 r
.30012 .64297 m .30066 .64255 L .30025 .64167 L F
.145 .661 .891 r
.30012 .64297 m .30009 .643 L .29995 .64298 L F
.143 0 0 r
.30619 .63938 m .3051 .63904 L .30292 .64154 L F
.87 .45 .017 r
.30544 .63697 m .30698 .63919 L .3051 .63904 L F
.143 0 0 r
.307 .63885 m .30626 .63892 L .30619 .63938 L F
.30626 .63892 m .3051 .63904 L .30619 .63938 L F
.87 .45 .017 r
.30635 .63828 m .30653 .63756 L .30687 .63903 L F
.30544 .63697 m .30646 .63753 L .30635 .63828 L F
.30646 .63753 m .30653 .63756 L .30635 .63828 L F
.923 .553 .135 r
.30505 .63566 m .30653 .63756 L .30544 .63697 L F
.30454 .63397 m .30561 .63591 L .30505 .63566 L F
.30561 .63591 m .30653 .63756 L .30505 .63566 L F
.8 .692 .746 r
.49987 .4689 m .50115 .47278 L .49899 .47144 L F
.857 .832 .822 r
.50115 .47278 m .49685 .4748 L .49899 .47144 L F
.95 .767 .62 r
.35063 .6485 m .35322 .64984 L .35211 .65241 L F
.849 .855 .847 r
.59879 .37135 m .59969 .37332 L .59538 .37625 L F
.462 0 0 r
.60083 .37434 m .60229 .37505 L .59969 .37332 L F
.564 .28 .443 r
.60229 .37505 m .60195 .37279 L .59969 .37332 L F
.462 0 0 r
.60083 .37434 m .59969 .37332 L .59879 .37135 L F
.685 .888 .972 r
.62453 .34791 m .61986 .34827 L .62324 .34635 L F
.773 .85 .909 r
.62686 .34637 m .62453 .34791 L .62324 .34635 L F
.951 .855 .432 r
.40117 .66534 m .4003 .66643 L .4007 .66845 L F
.962 .893 .512 r
.4007 .66845 m .4003 .66643 L .39901 .67054 L F
.748 .826 .363 r
.34566 .51396 m .34551 .51402 L .34599 .51271 L F
.244 .218 .63 r
.31545 .64078 m .31342 .64307 L .31344 .63932 L F
.077 .041 .511 r
.31562 .64432 m .31342 .64307 L .31545 .64078 L F
.31562 .64432 m .3139 .64564 L .31342 .64307 L F
.658 .52 .684 r
.51548 .46561 m .51673 .46897 L .51453 .4682 L F
.6 .432 .626 r
.51954 .46586 m .51673 .46897 L .51548 .46561 L F
.805 .907 .912 r
.64702 .34665 m .64986 .34626 L .649 .34513 L F
.856 .955 .874 r
.649 .34513 m .64986 .34626 L .65282 .34325 L F
.69 .885 .97 r
.61882 .43502 m .6208 .43194 L .61795 .4331 L F
0 0 .468 r
.61771 .43376 m .61809 .43357 L .61592 .42969 L F
.69 .885 .97 r
.61809 .43357 m .61795 .4331 L .6171 .43345 L F
.03 .594 .794 r
.6171 .43345 m .61821 .4335 L .61809 .43357 L F
.6171 .43345 m .61809 .43357 L .61771 .43376 L F
.69 .885 .97 r
.61841 .43464 m .61809 .43357 L .6171 .43345 L F
.61882 .43502 m .61795 .4331 L .61841 .43464 L F
0 0 .468 r
.61809 .43357 m .61821 .4335 L .61794 .43304 L F
.943 .917 .759 r
.62101 .42853 m .61851 .4324 L .6208 .43194 L F
0 0 0 r
.61993 .43018 m .61909 .43177 L .61851 .4324 L F
.61851 .4324 m .61828 .43265 L .6208 .43194 L F
.61811 .4327 m .61795 .4331 L .6208 .43194 L F
.61909 .43177 m .6179 .43404 L .61851 .4324 L F
.61851 .4324 m .61811 .4327 L .61828 .43265 L F
0 0 .468 r
.6179 .43323 m .61794 .43304 L .61778 .43278 L F
.61766 .43281 m .61778 .43278 L .61592 .42969 L F
.6179 .43323 m .61778 .43278 L .61766 .43281 L F
0 0 0 r
.61769 .43312 m .6171 .43345 L .61796 .43308 L F
.74 .242 0 r
.6171 .43345 m .61457 .43086 L .61769 .43312 L F
0 0 0 r
.61749 .43316 m .6171 .43345 L .61769 .43312 L F
.61796 .43308 m .6171 .43345 L .61795 .4331 L F
.74 .242 0 r
.6171 .43345 m .61769 .43312 L .61821 .4335 L F
0 0 0 r
.61811 .4327 m .61688 .43393 L .6171 .43345 L F
.61851 .4324 m .61822 .43268 L .61811 .4327 L F
.794 .318 .097 r
.61796 .43308 m .61769 .43312 L .61457 .43086 L F
.61592 .42969 m .61796 .43308 L .61457 .43086 L F
0 0 0 r
.61811 .4327 m .61749 .43316 L .61796 .43308 L F
.61822 .43268 m .61688 .43393 L .61811 .4327 L F
0 0 .468 r
.61809 .43357 m .61795 .4331 L .6179 .43323 L F
.61795 .4331 m .61794 .43304 L .6179 .43323 L F
.794 .318 .097 r
.61796 .43308 m .61821 .4335 L .61769 .43312 L F
.614 .573 .784 r
.33289 .6983 m .33527 .69759 L .33215 .69727 L F
.401 0 .133 r
.25755 .61886 m .26065 .61838 L .26146 .61678 L F
.869 .955 .862 r
.42465 .50766 m .42608 .50836 L .42785 .50631 L F
.96 .846 .685 r
.42362 .5094 m .42608 .50836 L .42465 .50766 L F
.42362 .5094 m .42512 .51068 L .42608 .50836 L F
.178 0 0 r
.55021 .46966 m .5535 .46853 L .55207 .46997 L F
.146 0 0 r
.5535 .46853 m .55496 .46935 L .55207 .46997 L F
.5535 .46853 m .55628 .4679 L .55496 .46935 L F
.98 .767 .546 r
.27053 .62198 m .27064 .62549 L .27284 .62347 L F
.554 .836 .998 r
.27053 .62198 m .27284 .62347 L .27338 .62168 L F
.501 .302 .543 r
.27064 .62549 m .27338 .62168 L .27284 .62347 L F
.733 .461 .517 r
.2822 .56465 m .28589 .56519 L .28644 .56247 L F
.567 .303 .476 r
.28644 .56247 m .28589 .56519 L .28855 .56457 L F
.609 .299 .419 r
.28644 .56247 m .28855 .56457 L .28917 .5625 L F
0 0 .468 r
.40919 .54705 m .41045 .54894 L .40828 .54536 L F
0 0 0 r
.26704 .57354 m .27049 .57225 L .26813 .5724 L F
.854 .72 .714 r
.36633 .69394 m .3687 .69404 L .36729 .69046 L F
.14 .302 .767 r
.36729 .69046 m .3687 .69404 L .37019 .69339 L F
0 0 .337 r
.37019 .69339 m .3687 .69404 L .36842 .69688 L F
0 0 0 r
.65915 .37748 m .65748 .37897 L .65887 .37777 L F
.682 .924 .971 r
.65887 .37777 m .65748 .37897 L .65493 .37967 L F
.65887 .37777 m .65493 .37967 L .65802 .37867 L F
.65887 .37777 m .65802 .37867 L .65851 .37852 L F
0 0 0 r
.66064 .37615 m .65915 .37748 L .65887 .37777 L F
.638 .462 .628 r
.48412 .47515 m .48586 .48096 L .48142 .47839 L F
.634 .459 .629 r
.4894 .47352 m .48845 .47529 L .48412 .47515 L F
.593 .435 .637 r
.48808 .47823 m .48412 .47515 L .48845 .47529 L F
.48808 .47823 m .48586 .48096 L .48412 .47515 L F
.468 .078 .217 r
.23934 .53831 m .23572 .54039 L .23757 .53965 L F
.5 .749 .984 r
.589 .4545 m .58779 .4565 L .58594 .45638 L F
.589 .4545 m .59117 .45612 L .58779 .4565 L F
.695 .405 .478 r
.51453 .4682 m .51672 .47111 L .5129 .4716 L F
.51453 .4682 m .51673 .46897 L .51672 .47111 L F
.649 .415 .551 r
.35811 .58486 m .35505 .58737 L .35349 .58422 L F
.35811 .58486 m .35776 .58773 L .35505 .58737 L F
.35505 .58737 m .35776 .58773 L .35811 .58486 L F
.591 .433 .636 r
.35776 .58773 m .36031 .58414 L .35811 .58486 L F
0 0 .203 r
.35915 .58576 m .35811 .58486 L .36031 .58414 L F
.35915 .58576 m .35776 .58773 L .35811 .58486 L F
.763 .766 .855 r
.4256 .49283 m .4206 .49366 L .42353 .49083 L F
.769 .787 .868 r
.42729 .49095 m .4256 .49283 L .42353 .49083 L F
.467 .448 .754 r
.47007 .54957 m .46704 .54592 L .46903 .54559 L F
.462 .112 .286 r
.34345 .54669 m .34277 .54888 L .33965 .54898 L F
.702 .407 0 r
.33267 .62465 m .3323 .6234 L .32995 .62402 L F
.591 .663 .888 r
.3947 .69112 m .39547 .68866 L .39504 .6877 L F
.39663 .68981 m .39664 .68862 L .39758 .68917 L F
.3947 .69112 m .3961 .68931 L .39663 .68981 L F
.3961 .68931 m .39664 .68862 L .39663 .68981 L F
.874 .834 .365 r
.39758 .68917 m .39739 .69063 L .3947 .69112 L F
.591 .663 .888 r
.3947 .69112 m .39739 .69063 L .3961 .68931 L F
.3947 .69112 m .3961 .68931 L .39547 .68866 L F
.833 .882 .878 r
.3961 .68931 m .39547 .68871 L .39547 .68866 L F
.995 .78 .417 r
.39504 .6877 m .39547 .68866 L .39541 .68866 L F
.591 .663 .888 r
.39541 .68866 m .39504 .6877 L .39572 .68809 L F
.3947 .69112 m .39476 .69052 L .39581 .68969 L F
.39476 .69052 m .39504 .6877 L .39545 .68876 L F
.39476 .69052 m .39545 .68876 L .39581 .68969 L F
.39581 .68969 m .39541 .68866 L .39664 .68862 L F
0 0 0 r
.39547 .68866 m .39547 .68871 L .39568 .68817 L F
.39547 .68866 m .39568 .68817 L .39541 .68866 L F
.591 .663 .888 r
.39541 .68866 m .39572 .68809 L .39664 .68862 L F
.833 .882 .878 r
.39739 .69063 m .39542 .68927 L .39547 .68871 L F
.39739 .69063 m .39547 .68871 L .3961 .68931 L F
.984 .7 .379 r
.39646 .68464 m .39658 .68511 L .39504 .6877 L F
.39658 .68511 m .39703 .68693 L .39571 .68808 L F
.39658 .68511 m .39571 .68808 L .39504 .6877 L F
.995 .78 .417 r
.39504 .6877 m .39541 .68866 L .39412 .68872 L F
0 0 0 r
.39506 .68868 m .39679 .68553 L .39412 .68872 L F
.39541 .68866 m .39562 .68818 L .39506 .68868 L F
.39562 .68818 m .39679 .68553 L .39506 .68868 L F
.984 .7 .379 r
.39703 .68693 m .39758 .68917 L .39572 .68809 L F
.39703 .68693 m .39572 .68809 L .39571 .68808 L F
0 0 0 r
.39571 .6881 m .39542 .68927 L .39679 .68553 L F
.39568 .68817 m .39564 .68832 L .39571 .6881 L F
.39564 .68832 m .39542 .68927 L .39571 .6881 L F
.39547 .68871 m .39542 .68927 L .39568 .68817 L F
.39568 .68817 m .39679 .68553 L .39541 .68866 L F
.326 0 0 r
.25406 .52605 m .2482 .52684 L .25181 .52721 L F
0 0 0 r
.61079 .36855 m .61085 .36792 L .60903 .36982 L F
.659 .941 .963 r
.61079 .36855 m .60903 .36982 L .60671 .36874 L F
.60713 .36858 m .60671 .36874 L .60636 .36858 L F
.61079 .36855 m .60671 .36874 L .60713 .36858 L F
.61079 .36855 m .60636 .36858 L .61063 .37038 L F
.61079 .36855 m .61063 .37038 L .61072 .37042 L F
0 0 0 r
.61079 .36855 m .61197 .36674 L .61085 .36792 L F
.784 .91 .519 r
.61283 .36428 m .61197 .36674 L .61079 .36855 L F
.82 .998 .781 r
.61463 .36378 m .61197 .36674 L .61283 .36428 L F
.784 .91 .519 r
.61283 .36428 m .61079 .36855 L .61288 .36682 L F
0 0 .002 r
.61288 .36682 m .61079 .36855 L .61072 .37042 L F
.673 .503 .647 r
.61027 .36734 m .61288 .36682 L .61072 .37042 L F
.61022 .36701 m .61127 .36694 L .61027 .36734 L F
.61127 .36694 m .61288 .36682 L .61027 .36734 L F
0 0 .535 r
.39402 .65094 m .3935 .6523 L .39503 .65519 L F
.444 .264 .541 r
.3935 .6523 m .39299 .65555 L .39503 .65519 L F
.575 .672 .905 r
.28674 .51895 m .28476 .51988 L .28114 .51551 L F
.53 .449 .709 r
.35989 .51862 m .35695 .52002 L .3565 .51936 L F
.569 .616 .86 r
.34324 .7026 m .34478 .69929 L .34243 .69971 L F
.34324 .7026 m .34565 .70233 L .34478 .69929 L F
.929 .972 .714 r
.4181 .60033 m .42121 .59659 L .42004 .59736 L F
.639 .93 .668 r
.42174 .59558 m .42121 .59659 L .42331 .59513 L F
.42174 .59558 m .42004 .59736 L .42121 .59659 L F
0 0 0 r
.44471 .51745 m .44377 .51745 L .44707 .51752 L F
.44471 .51745 m .44231 .51824 L .44377 .51745 L F
0 0 .13 r
.40151 .6613 m .40148 .6646 L .40117 .66534 L F
.677 .858 .457 r
.40148 .6646 m .4003 .66643 L .40117 .66534 L F
.452 .283 .559 r
.35197 .53201 m .35005 .53001 L .35128 .5299 L F
.35197 .53201 m .34965 .53293 L .35005 .53001 L F
0 .282 .769 r
.26311 .62785 m .26425 .62777 L .26122 .62663 L F
.26311 .62785 m .26542 .6293 L .26425 .62777 L F
.668 .738 .902 r
.48906 .4476 m .48497 .44673 L .48731 .4453 L F
.699 .653 .801 r
.48731 .4453 m .49137 .44622 L .48906 .4476 L F
.929 .589 .145 r
.32772 .66093 m .32877 .66283 L .32723 .65871 L F
.911 .926 .547 r
.32789 .66309 m .32877 .66283 L .32772 .66093 L F
.32789 .66309 m .32818 .6643 L .32877 .66283 L F
.492 .208 .411 r
.24552 .56208 m .24816 .56179 L .24834 .55936 L F
.24552 .56208 m .24816 .56179 L .24834 .55936 L F
.336 .085 .377 r
.25026 .5609 m .24834 .55936 L .25132 .55834 L F
.24834 .55936 m .25026 .5609 L .24865 .55713 L F
.24834 .55936 m .24816 .56179 L .25026 .5609 L F
.25026 .5609 m .24816 .56179 L .24834 .55936 L F
.159 0 .17 r
.22058 .55279 m .21771 .55589 L .21968 .55476 L F
0 0 .234 r
.22058 .55279 m .22159 .55162 L .22198 .54882 L F
.661 .777 .307 r
.22058 .55279 m .22014 .55373 L .22159 .55162 L F
.22058 .55279 m .21968 .55476 L .22014 .55373 L F
.711 .309 .285 r
.36335 .59102 m .36562 .5935 L .36217 .59402 L F
.584 .85 .503 r
.42305 .57094 m .42522 .56839 L .42315 .56767 L F
.705 .559 .685 r
.42522 .56839 m .42305 .57094 L .42315 .56767 L F
.599 .452 .653 r
.48142 .47839 m .48017 .48288 L .47878 .47885 L F
.672 .385 .478 r
.2953 .56115 m .29792 .55904 L .29665 .55849 L F
.768 .779 .862 r
.47423 .44853 m .47306 .45301 L .47208 .45007 L F
.47423 .44853 m .47613 .45069 L .47306 .45301 L F
.62 .546 .75 r
.50189 .4655 m .49829 .4626 L .50332 .46358 L F
.495 .513 .805 r
.34985 .70368 m .35101 .70743 L .35306 .70568 L F
.769 .733 .82 r
.35156 .70996 m .35306 .70568 L .35101 .70743 L F
.811 .687 .728 r
.38321 .62373 m .37882 .62574 L .38164 .6221 L F
.612 .445 .631 r
.29711 .55473 m .30058 .55245 L .29853 .55389 L F
.801 .754 .237 r
.33473 .61538 m .335 .61315 L .33764 .61374 L F
.519 .419 .682 r
.33473 .61538 m .33519 .61724 L .33443 .61582 L F
.33473 .61538 m .33756 .61634 L .33519 .61724 L F
.412 .185 .457 r
.35014 .59453 m .3475 .59778 L .3497 .59701 L F
.598 .215 .288 r
.34569 .59941 m .3497 .59701 L .3475 .59778 L F
.727 .439 0 r
.37882 .62574 m .37956 .62827 L .37691 .62984 L F
.58 .144 .177 r
.37691 .62984 m .37956 .62827 L .37809 .63093 L F
.615 .556 .765 r
.38702 .66209 m .39101 .66081 L .38987 .65862 L F
.69 .508 .636 r
.38763 .6644 m .39101 .66081 L .38702 .66209 L F
.158 .411 .853 r
.35484 .68706 m .35402 .68864 L .35226 .68763 L F
.35484 .68706 m .35695 .69031 L .35402 .68864 L F
.316 .414 .804 r
.26541 .57562 m .26798 .57635 L .26704 .57354 L F
.677 .863 .97 r
.33874 .56446 m .34047 .56562 L .34293 .56437 L F
.413 .467 .807 r
.33065 .52064 m .33385 .5226 L .33376 .52009 L F
.427 0 0 r
.33536 .68547 m .33297 .68466 L .33101 .68625 L F
.433 .074 .253 r
.33536 .68547 m .33553 .68426 L .33297 .68466 L F
.796 .691 .748 r
.36158 .56857 m .36415 .56929 L .36401 .56611 L F
.808 .446 .372 r
.36158 .56857 m .36398 .57118 L .36415 .56929 L F
.508 .464 .743 r
.36401 .56611 m .36415 .56929 L .36667 .5677 L F
.474 .261 .509 r
.36667 .5677 m .36398 .57118 L .36415 .56929 L F
.914 .969 .666 r
.39127 .61194 m .39138 .6139 L .39333 .61031 L F
.893 .985 .719 r
.39488 .60638 m .39271 .60973 L .39333 .61031 L F
.92 .967 .665 r
.39271 .60973 m .39127 .61194 L .39333 .61031 L F
0 0 0 r
.35381 .63192 m .35465 .6299 L .35344 .62866 L F
.558 .67 .913 r
.33215 .69727 m .33221 .69299 L .32984 .69346 L F
.33215 .69727 m .33583 .69675 L .33221 .69299 L F
.56 .662 .905 r
.33215 .69727 m .33527 .69759 L .33583 .69675 L F
.493 .437 .723 r
.38838 .6136 m .3914 .61174 L .38941 .60985 L F
0 0 0 r
.38778 .61406 m .3914 .61174 L .38838 .6136 L F
.789 .758 .825 r
.51787 .42723 m .51552 .43027 L .51524 .42592 L F
.316 0 .002 r
.53701 .40816 m .53348 .40998 L .53316 .40773 L F
.53701 .40816 m .53612 .4098 L .53348 .40998 L F
0 0 0 r
.53819 .40869 m .53701 .40816 L .53981 .40777 L F
.53819 .40869 m .53612 .4098 L .53701 .40816 L F
.835 .364 .026 r
.36367 .50639 m .3668 .51015 L .36866 .51107 L F
.732 .322 .271 r
.3668 .51015 m .37172 .51225 L .36866 .51107 L F
.83 .812 .833 r
.64178 .40105 m .64037 .40278 L .63849 .40087 L F
.056 0 .173 r
.3497 .59701 m .35225 .59361 L .35014 .59453 L F
.105 0 0 r
.30472 .55996 m .30729 .55977 L .30911 .55918 L F
.671 .559 .719 r
.31125 .55577 m .30911 .55918 L .31153 .55851 L F
.559 .304 .486 r
.31153 .55851 m .30872 .56182 L .30911 .55918 L F
0 0 0 r
.30729 .55977 m .31153 .55851 L .30911 .55918 L F
.992 .799 .42 r
.39938 .68464 m .40078 .68429 L .39925 .68306 L F
.39938 .68464 m .40039 .68773 L .40078 .68429 L F
.758 .761 .855 r
.66866 .3853 m .66998 .38841 L .67109 .38623 L F
.459 .394 .697 r
.67109 .38623 m .66998 .38841 L .67241 .3879 L F
.648 .869 .982 r
.43753 .46177 m .43516 .46286 L .43591 .46067 L F
.78 .986 .897 r
.43516 .46286 m .43412 .46235 L .43591 .46067 L F
.2 0 0 r
.27491 .51705 m .27818 .51639 L .27579 .51701 L F
.852 .884 .862 r
.67793 .32257 m .68187 .32108 L .68108 .32074 L F
0 0 0 r
.68385 .31797 m .68362 .31937 L .68187 .32108 L F
.57 .937 .905 r
.68362 .31937 m .68108 .32074 L .68187 .32108 L F
.627 .788 .344 r
.70146 .27874 m .70195 .27783 L .70263 .2766 L F
0 0 0 r
.70263 .2766 m .70195 .27783 L .70406 .27403 L F
.454 .118 .306 r
.34863 .63525 m .35205 .63324 L .3506 .63563 L F
.897 .922 .829 r
.35344 .62866 m .35205 .63324 L .3503 .62987 L F
0 0 .149 r
.35205 .63324 m .35285 .63458 L .3506 .63563 L F
0 0 .326 r
.4118 .55954 m .41263 .56194 L .41152 .55809 L F
.379 .063 .298 r
.45915 .58799 m .45844 .59 L .45616 .59059 L F
.252 0 .105 r
.46175 .58757 m .45844 .59 L .45915 .58799 L F
.966 .657 .26 r
.41197 .55302 m .4107 .55184 L .41045 .54894 L F
.975 .922 .659 r
.41197 .55302 m .40994 .55432 L .4107 .55184 L F
.41197 .55302 m .41057 .55592 L .40994 .55432 L F
.806 .998 .851 r
.32508 .66065 m .32064 .66441 L .32395 .6634 L F
.547 .341 .552 r
.32508 .66065 m .32772 .66093 L .32723 .65871 L F
.515 .145 .275 r
.32497 .66298 m .32508 .66065 L .32395 .6634 L F
.32497 .66298 m .32772 .66093 L .32508 .66065 L F
.717 .911 .962 r
.66049 .39185 m .66168 .38926 L .65928 .39062 L F
.66049 .39185 m .66299 .39059 L .66168 .38926 L F
.716 .874 .955 r
.63569 .35599 m .63674 .35777 L .63908 .35627 L F
0 0 .309 r
.22495 .55829 m .226 .56114 L .22606 .56223 L F
0 0 .543 r
.226 .56114 m .22777 .56447 L .22606 .56223 L F
.906 .563 .09 r
.38832 .60094 m .38745 .6018 L .38723 .60063 L F
.38745 .6018 m .38723 .60159 L .38723 .60063 L F
.38832 .60094 m .38882 .60248 L .3876 .60213 L F
.939 .771 .648 r
.38882 .60248 m .38527 .60529 L .38698 .60243 L F
.815 .643 .091 r
.38527 .60529 m .38498 .60157 L .38698 .60243 L F
.702 .269 .218 r
.38751 .6027 m .38751 .60266 L .38498 .60157 L F
.38751 .60266 m .38747 .60185 L .38498 .60157 L F
.815 .643 .091 r
.38698 .60243 m .38498 .60157 L .38723 .60203 L F
.939 .771 .648 r
.38748 .6021 m .38698 .60243 L .38723 .60203 L F
.38882 .60248 m .38698 .60243 L .38748 .6021 L F
.702 .269 .218 r
.38619 .60325 m .38751 .6027 L .38696 .60245 L F
.38605 .60305 m .38696 .60245 L .38498 .60157 L F
.38619 .60325 m .38696 .60245 L .38605 .60305 L F
.906 .563 .09 r
.38747 .60185 m .3876 .60213 L .38748 .6021 L F
.702 .269 .218 r
.38751 .6027 m .38908 .60204 L .38747 .60185 L F
.906 .563 .09 r
.38745 .6018 m .38747 .60185 L .38723 .60203 L F
.38747 .60185 m .38748 .6021 L .38723 .60203 L F
.38832 .60094 m .3876 .60213 L .38745 .6018 L F
.784 .995 .872 r
.38796 .5996 m .38832 .60094 L .38723 .60063 L F
.811 .79 .291 r
.38877 .5965 m .38796 .5996 L .38805 .5983 L F
.771 .696 .78 r
.38498 .60157 m .38796 .5996 L .38723 .60063 L F
.38498 .60157 m .38805 .5983 L .38796 .5996 L F
.38659 .59985 m .38908 .60204 L .38805 .5983 L F
.38604 .60044 m .38709 .601 L .38659 .59985 L F
.38709 .601 m .38908 .60204 L .38659 .59985 L F
.492 0 0 r
.38723 .60063 m .38723 .60159 L .38498 .60157 L F
.771 .696 .78 r
.38498 .60157 m .38751 .60186 L .38723 .60159 L F
.492 0 0 r
.38723 .60159 m .38723 .60203 L .38498 .60157 L F
.771 .696 .78 r
.38498 .60157 m .38723 .60159 L .38604 .60044 L F
.38751 .60186 m .38908 .60204 L .38604 .60044 L F
.906 .563 .09 r
.38745 .6018 m .38723 .60203 L .38723 .60159 L F
.797 .651 .701 r
.2384 .54849 m .24015 .55249 L .24195 .54981 L F
.838 .774 .791 r
.36795 .59047 m .3688 .59492 L .36562 .5935 L F
.808 .858 .407 r
.3688 .59492 m .36787 .59611 L .36562 .5935 L F
.3688 .59492 m .36742 .59838 L .36787 .59611 L F
.53 .527 .797 r
.37079 .58986 m .3688 .59492 L .36795 .59047 L F
.37079 .58986 m .37277 .59411 L .3688 .59492 L F
.38 .135 .412 r
.2451 .57421 m .24757 .57239 L .24432 .57208 L F
.2451 .57421 m .24827 .57346 L .24757 .57239 L F
.77 .659 .74 r
.4014 .67478 m .39873 .6781 L .39711 .67444 L F
.202 0 0 r
.39711 .67444 m .39936 .67476 L .4014 .67478 L F
.39711 .67444 m .39936 .67476 L .4014 .67478 L F
.988 .733 .359 r
.4014 .67478 m .40148 .67767 L .39873 .6781 L F
.934 .816 .705 r
.40087 .67046 m .39936 .67476 L .4014 .67478 L F
.984 .733 .339 r
.39963 .67603 m .4014 .67478 L .39936 .67476 L F
.39963 .67603 m .40148 .67767 L .4014 .67478 L F
.793 .574 .605 r
.33471 .633 m .33635 .62999 L .33319 .62907 L F
.33471 .633 m .337 .63228 L .33635 .62999 L F
.504 .168 .331 r
.33916 .6331 m .33635 .62999 L .337 .63228 L F
.189 .333 .779 r
.47263 .55144 m .47132 .5528 L .47007 .54957 L F
.178 .106 .532 r
.47351 .55385 m .47132 .5528 L .47263 .55144 L F
.47351 .55385 m .47156 .55569 L .47132 .5528 L F
.374 0 0 r
.25957 .62627 m .25777 .62536 L .25567 .62314 L F
.25957 .62627 m .25958 .62629 L .25777 .62536 L F
0 0 0 r
.23208 .54934 m .2287 .55217 L .22988 .54983 L F
.442 .292 .582 r
.23203 .5458 m .23208 .54934 L .22988 .54983 L F
.645 .55 .732 r
.35742 .56857 m .35533 .57182 L .35482 .56928 L F
.701 .395 .455 r
.53007 .4657 m .52612 .46805 L .52597 .46586 L F
.53007 .4657 m .52853 .46845 L .52612 .46805 L F
.706 .358 .384 r
.53007 .4657 m .53257 .46821 L .52853 .46845 L F
.53007 .4657 m .53244 .4662 L .53257 .46821 L F
.862 .793 .782 r
.60833 .37986 m .61079 .3784 L .61084 .3764 L F
.849 .607 .573 r
.61305 .3797 m .61084 .3764 L .61079 .3784 L F
.328 .054 .337 r
.36817 .53973 m .37049 .53903 L .37096 .53658 L F
.379 0 0 r
.37148 .53571 m .3688 .5376 L .36848 .53507 L F
.37324 .53609 m .37127 .53676 L .37148 .53571 L F
0 0 0 r
.37096 .53658 m .37049 .53903 L .37106 .53777 L F
.379 0 0 r
.37127 .53676 m .3688 .5376 L .37148 .53571 L F
0 0 0 r
.37119 .53714 m .37106 .53777 L .37127 .53733 L F
.37096 .53658 m .37106 .53777 L .37119 .53714 L F
.379 0 0 r
.37324 .53609 m .37127 .53776 L .37127 .53729 L F
0 0 0 r
.37127 .53729 m .37127 .53733 L .37127 .53731 L F
.37096 .53658 m .37127 .53733 L .37127 .53729 L F
.379 0 0 r
.37127 .53729 m .37127 .53733 L .37118 .53734 L F
0 0 0 r
.37096 .53658 m .37127 .53729 L .37324 .53609 L F
.379 0 0 r
.37324 .53609 m .37057 .53772 L .3688 .5376 L F
.664 .614 .789 r
.37127 .53731 m .37127 .53733 L .3688 .5376 L F
.371 .155 .452 r
.36817 .53973 m .37018 .54161 L .37049 .53903 L F
0 0 .095 r
.37049 .53903 m .37018 .54161 L .37127 .53731 L F
.664 .614 .789 r
.37127 .53733 m .37018 .54161 L .3688 .5376 L F
.379 0 0 r
.37118 .53734 m .37126 .53776 L .37057 .53772 L F
.37127 .53733 m .37126 .53776 L .37118 .53734 L F
.37127 .53776 m .37126 .53776 L .37127 .53729 L F
0 0 0 r
.37127 .53729 m .37127 .53731 L .37324 .53609 L F
.53 .398 .645 r
.47776 .49119 m .47819 .49441 L .47563 .49517 L F
.484 .227 .449 r
.47819 .49441 m .47526 .49709 L .47563 .49517 L F
0 .308 .771 r
.38148 .66647 m .37861 .665 L .38225 .66524 L F
.826 .893 .89 r
.38456 .66522 m .38148 .66647 L .38225 .66524 L F
.788 .669 .733 r
.34214 .69066 m .34456 .69132 L .34342 .68777 L F
.47 0 0 r
.34214 .69066 m .34456 .69132 L .34267 .69109 L F
.656 .624 .806 r
.34456 .69132 m .34485 .69033 L .34421 .69021 L F
.34456 .69132 m .34693 .69054 L .34581 .68701 L F
.56 .083 .078 r
.34267 .69109 m .34693 .69054 L .34456 .69132 L F
.34267 .69109 m .34614 .69153 L .34681 .6907 L F
.34636 .69061 m .34681 .6907 L .34693 .69054 L F
.34267 .69109 m .34681 .6907 L .34636 .69061 L F
.656 .624 .806 r
.34421 .69021 m .34581 .68701 L .34342 .68777 L F
.34485 .69033 m .34581 .68701 L .34421 .69021 L F
.517 .581 .858 r
.33103 .5681 m .33393 .56764 L .33162 .56428 L F
.602 .145 .14 r
.54309 .46895 m .54721 .4689 L .54571 .4707 L F
.7 .262 .207 r
.54721 .4689 m .54959 .47114 L .54571 .4707 L F
.677 .28 .287 r
.54721 .4689 m .55021 .46966 L .54959 .47114 L F
.433 .872 .89 r
.27091 .61825 m .27177 .61722 L .27371 .6178 L F
.27091 .61825 m .26912 .61814 L .27177 .61722 L F
.821 .991 .87 r
.71013 .3412 m .71233 .33909 L .71126 .33856 L F
.826 .996 .851 r
.70804 .34158 m .71013 .3412 L .71126 .33856 L F
.11 .453 .884 r
.63806 .4189 m .63908 .42061 L .63901 .4169 L F
.848 .829 .828 r
.63908 .42061 m .64212 .41719 L .63901 .4169 L F
.482 .286 .538 r
.37091 .67469 m .37353 .67082 L .36941 .67128 L F
.37091 .67469 m .37334 .67425 L .37353 .67082 L F
.457 .17 .388 r
.37628 .67278 m .37353 .67082 L .37334 .67425 L F
.37628 .67278 m .37501 .67038 L .37353 .67082 L F
.593 .123 .107 r
.54701 .41325 m .5498 .41327 L .54758 .41191 L F
.407 0 0 r
.54948 .41298 m .54758 .41191 L .5498 .41327 L F
.616 .461 .649 r
.42305 .57094 m .42516 .57501 L .42214 .57201 L F
.981 .691 .371 r
.60751 .41 m .60907 .41131 L .60917 .41363 L F
.882 .449 .094 r
.3748 .51562 m .3747 .51678 L .37676 .51778 L F
.523 0 0 r
.3747 .51678 m .37913 .51908 L .37676 .51778 L F
.274 .022 .338 r
.24383 .57689 m .2425 .57535 L .24483 .57495 L F
.24383 .57689 m .2418 .5778 L .2425 .57535 L F
.416 .098 .315 r
.33303 .61053 m .32986 .61298 L .33042 .61059 L F
.769 .956 .933 r
.3231 .66574 m .32818 .6643 L .3258 .66472 L F
.812 .998 .85 r
.3258 .66472 m .32818 .6643 L .32789 .66309 L F
.883 .865 .817 r
.35505 .58737 m .35285 .59132 L .35119 .5888 L F
.29 .043 .356 r
.35285 .59132 m .35292 .59018 L .35119 .5888 L F
.35285 .59132 m .3544 .59216 L .35292 .59018 L F
.35285 .59132 m .35225 .59361 L .3544 .59216 L F
.63 .407 .56 r
.292 .62591 m .29516 .62311 L .29276 .6235 L F
.292 .62591 m .29731 .62428 L .29516 .62311 L F
.465 .307 .582 r
.2944 .62813 m .292 .62591 L .29731 .62428 L F
.387 .038 .247 r
.29419 .6253 m .29276 .6235 L .292 .62591 L F
.29419 .6253 m .29516 .62311 L .29276 .6235 L F
.404 .484 .828 r
.28756 .64855 m .28938 .65234 L .29061 .65079 L F
.874 .771 .745 r
.63901 .4169 m .64212 .41719 L .64101 .41358 L F
.836 .754 .773 r
.64101 .41358 m .64212 .41719 L .64327 .41518 L F
.85 .878 .861 r
.46737 .45073 m .46624 .45539 L .46542 .45253 L F
.46737 .45073 m .46894 .45207 L .46624 .45539 L F
.791 .83 .882 r
.46245 .45527 m .46542 .45253 L .46624 .45539 L F
.837 .725 .741 r
.46245 .45527 m .46624 .45539 L .46463 .4561 L F
.757 .814 .897 r
.56951 .46527 m .57247 .46419 L .57182 .46476 L F
.494 .875 .973 r
.57247 .46419 m .5758 .46357 L .57464 .46322 L F
.57247 .46419 m .57464 .46322 L .57182 .46476 L F
.878 .894 .839 r
.52189 .41719 m .52067 .42148 L .52107 .41921 L F
.915 .978 .769 r
.52067 .42148 m .51861 .42263 L .52107 .41921 L F
.905 .975 .8 r
.62349 .43079 m .62553 .43064 L .62461 .42954 L F
.62349 .43079 m .62306 .43395 L .62553 .43064 L F
.888 .96 .839 r
.62708 .4265 m .62553 .43064 L .6283 .42782 L F
.62708 .4265 m .62461 .42954 L .62553 .43064 L F
.257 .211 .614 r
.33376 .52009 m .33322 .51738 L .33693 .51717 L F
.55 .148 .233 r
.33322 .51738 m .33557 .51927 L .33693 .51717 L F
.257 .211 .614 r
.33376 .52009 m .33557 .51927 L .33322 .51738 L F
.316 .29 .671 r
.34109 .54498 m .33973 .54654 L .33883 .54308 L F
.34109 .54498 m .33973 .54654 L .33883 .54308 L F
.706 .884 .963 r
.39713 .49128 m .39323 .49087 L .39555 .48826 L F
.702 .283 .248 r
.39555 .48826 m .39998 .48801 L .39713 .49128 L F
0 0 .334 r
.3633 .55536 m .36251 .55845 L .36129 .55565 L F
.517 .531 .809 r
.36358 .55818 m .36214 .56153 L .36251 .55845 L F
.849 .769 .773 r
.64297 .39903 m .63849 .40087 L .63832 .39896 L F
.934 .968 .698 r
.37807 .70726 m .38004 .7036 L .37919 .70313 L F
.761 .97 .926 r
.38004 .7036 m .37994 .70166 L .37919 .70313 L F
.38004 .7036 m .38345 .70141 L .37994 .70166 L F
.383 .191 .493 r
.39138 .6139 m .39011 .61585 L .38976 .6168 L F
0 0 0 r
.38976 .6168 m .39011 .61585 L .39072 .61536 L F
.701 .883 .498 r
.3907 .61432 m .39011 .61585 L .39138 .6139 L F
0 .02 .591 r
.39072 .61536 m .39011 .61585 L .3907 .61432 L F
.706 .738 .876 r
.50594 .43668 m .50319 .4394 L .50182 .43607 L F
.631 .603 .803 r
.50594 .43668 m .50714 .4405 L .50319 .4394 L F
.417 .293 .602 r
.46712 .52022 m .46738 .523 L .46516 .52358 L F
.587 .544 .773 r
.46738 .523 m .46589 .52733 L .46516 .52358 L F
.22 0 .099 r
.46808 .58444 m .4714 .58193 L .47019 .58362 L F
.148 0 .187 r
.47295 .58055 m .47019 .58362 L .4714 .58193 L F
.626 .418 .581 r
.51022 .47189 m .5075 .47495 L .5075 .47226 L F
.273 .198 .586 r
.23007 .58163 m .23172 .58258 L .23183 .57759 L F
.393 .51 .858 r
.23007 .58163 m .23324 .58394 L .23226 .58375 L F
.151 .238 .701 r
.23007 .58163 m .23226 .58375 L .23172 .58258 L F
.823 .724 .755 r
.68243 .35451 m .68214 .3571 L .67852 .35556 L F
.823 .383 .195 r
.67852 .35556 m .68214 .3571 L .68159 .35778 L F
.468 .28 .542 r
.26111 .5399 m .2635 .5396 L .26345 .53698 L F
.799 .636 .679 r
.37637 .63346 m .37165 .63564 L .37252 .63301 L F
.37637 .63346 m .37541 .63594 L .37165 .63564 L F
.707 .738 .875 r
.37691 .62984 m .37802 .63262 L .37637 .63346 L F
0 0 0 r
.37637 .63346 m .376 .63423 L .37541 .63594 L F
.37637 .63346 m .37802 .63262 L .376 .63423 L F
.559 .866 .996 r
.37713 .50122 m .37929 .49897 L .37929 .49908 L F
.828 .361 .092 r
.288 .64259 m .28991 .64295 L .28655 .64094 L F
.862 .423 .161 r
.29042 .64551 m .28991 .64295 L .288 .64259 L F
.562 .838 .997 r
.73242 .33747 m .73472 .33536 L .73332 .33538 L F
.73242 .33747 m .73494 .33652 L .73472 .33536 L F
.6 .218 .29 r
.29406 .56823 m .28984 .57083 L .29078 .56943 L F
.29406 .56823 m .29267 .57068 L .28984 .57083 L F
.574 .189 .275 r
.29594 .57021 m .29406 .56823 L .29671 .56753 L F
.29594 .57021 m .29267 .57068 L .29406 .56823 L F
.594 .408 .599 r
.32661 .57802 m .32828 .5808 L .32848 .57758 L F
.32661 .57802 m .32631 .58209 L .32828 .5808 L F
.694 .492 .609 r
.4273 .57062 m .42516 .57501 L .42305 .57094 L F
.754 .592 .676 r
.42873 .57197 m .42516 .57501 L .4273 .57062 L F
.073 0 .383 r
.33891 .61519 m .33764 .61374 L .3397 .61322 L F
.33891 .61519 m .33756 .61634 L .33764 .61374 L F
.599 .452 .653 r
.48142 .47839 m .48395 .48218 L .48017 .48288 L F
.635 .464 .635 r
.48142 .47839 m .48535 .48141 L .48395 .48218 L F
.48142 .47839 m .48586 .48096 L .48535 .48141 L F
.817 .554 .541 r
.50865 .43352 m .51269 .43391 L .51237 .43641 L F
.371 .157 .454 r
.51237 .43641 m .51269 .43391 L .51501 .43311 L F
.849 .769 .773 r
.64297 .39903 m .64178 .40105 L .63849 .40087 L F
0 0 0 r
.37599 .5877 m .37321 .59213 L .37517 .59104 L F
.985 .724 .346 r
.37321 .59213 m .37472 .59298 L .37517 .59104 L F
0 0 0 r
.37117 .58493 m .37431 .58191 L .37333 .58392 L F
.615 .419 .594 r
.37605 .58083 m .37333 .58392 L .37431 .58191 L F
.72 .292 .231 r
.43958 .52247 m .44371 .52323 L .4412 .52115 L F
.984 .797 .572 r
.43987 .51966 m .43958 .52247 L .4412 .52115 L F
.81 .808 .848 r
.37607 .68693 m .38003 .6875 L .37917 .68465 L F
.845 .75 .758 r
.37783 .69059 m .38003 .6875 L .37607 .68693 L F
.81 .808 .849 r
.37917 .68465 m .38003 .6875 L .38291 .68445 L F
.865 .578 .5 r
.49312 .4845 m .49101 .48696 L .49157 .48361 L F
.49312 .4845 m .49332 .4876 L .49101 .48696 L F
.57 .379 .584 r
.49013 .48231 m .4905 .48352 L .48912 .48436 L F
.49473 .48096 m .49453 .48115 L .48912 .48436 L F
.49192 .47865 m .49013 .48231 L .48808 .47823 L F
.49013 .48231 m .48912 .48436 L .4889 .48308 L F
.49013 .48231 m .4889 .48308 L .48808 .47823 L F
.757 .676 .772 r
.48535 .48141 m .48586 .48096 L .48808 .47823 L F
.711 .602 .733 r
.48808 .47823 m .48912 .48436 L .48535 .48141 L F
.629 .795 .962 r
.48912 .48436 m .48507 .48394 L .48535 .48141 L F
.48912 .48436 m .49078 .48395 L .49022 .48395 L F
.384 .077 .316 r
.49022 .48395 m .49445 .48121 L .4942 .48143 L F
.4915 .48348 m .4942 .48143 L .49192 .48332 L F
.49022 .48395 m .4942 .48143 L .4915 .48348 L F
.825 .892 .89 r
.4942 .48143 m .49598 .48187 L .49312 .4845 L F
.57 .379 .584 r
.49192 .47865 m .49473 .48096 L .4905 .48352 L F
.49473 .48096 m .49476 .48099 L .49453 .48115 L F
.825 .892 .89 r
.49485 .48093 m .49598 .48187 L .4942 .48143 L F
.57 .379 .584 r
.49476 .48099 m .49478 .481 L .49467 .48107 L F
.49476 .48099 m .49467 .48107 L .49453 .48115 L F
.825 .892 .89 r
.49448 .48062 m .49484 .48092 L .4942 .48143 L F
.49484 .48092 m .49485 .48093 L .49467 .48107 L F
.4942 .48143 m .49417 .48149 L .49157 .48361 L F
.384 .077 .316 r
.49445 .48121 m .49478 .481 L .49192 .48332 L F
.825 .892 .89 r
.49484 .48092 m .49467 .48107 L .4942 .48143 L F
.384 .077 .316 r
.49051 .48354 m .49478 .481 L .49022 .48395 L F
.533 .274 .467 r
.49192 .47865 m .49448 .48062 L .49478 .481 L F
.825 .892 .89 r
.49448 .48062 m .4942 .48143 L .49157 .48361 L F
.384 .077 .316 r
.49192 .48332 m .49478 .481 L .49193 .48332 L F
.48912 .48436 m .49051 .48354 L .49022 .48395 L F
.616 .512 .713 r
.48983 .48692 m .48868 .4862 L .49064 .48395 L F
.629 .795 .962 r
.48912 .48436 m .49022 .48395 L .48507 .48394 L F
.616 .512 .713 r
.48868 .4862 m .4863 .48471 L .49017 .48404 L F
.48868 .4862 m .49017 .48404 L .49064 .48395 L F
.384 .077 .316 r
.48912 .48436 m .49193 .48332 L .49157 .48361 L F
.616 .512 .713 r
.4863 .48471 m .48507 .48394 L .48751 .48395 L F
.384 .077 .316 r
.48912 .48436 m .49016 .48404 L .49078 .48395 L F
.49016 .48404 m .49157 .48361 L .49078 .48395 L F
.616 .512 .713 r
.48991 .48408 m .48751 .48395 L .49064 .48395 L F
.4863 .48471 m .48652 .48457 L .48991 .48408 L F
.48652 .48457 m .48751 .48395 L .48991 .48408 L F
.49071 .48418 m .49064 .48395 L .49078 .48395 L F
.48983 .48692 m .49064 .48395 L .49071 .48418 L F
.57 .379 .584 r
.49192 .47865 m .4905 .48352 L .49013 .48231 L F
.825 .892 .89 r
.49417 .48149 m .49312 .4845 L .49181 .48375 L F
.49417 .48149 m .49181 .48375 L .49157 .48361 L F
.639 .508 .688 r
.49598 .48187 m .49614 .48482 L .49312 .4845 L F
.636 .396 .538 r
.49614 .48482 m .49332 .4876 L .49312 .4845 L F
0 0 0 r
.30781 .63319 m .31066 .62958 L .31007 .63247 L F
.127 0 0 r
.31339 .62615 m .31434 .62647 L .31197 .62844 L F
0 0 0 r
.31179 .62816 m .31339 .62615 L .31197 .62844 L F
.675 .964 .755 r
.31197 .62844 m .31434 .62647 L .31243 .62718 L F
0 0 .011 r
.31214 .6287 m .31197 .62844 L .31243 .62718 L F
.31168 .6311 m .31197 .62844 L .31214 .6287 L F
0 0 0 r
.31066 .62958 m .31179 .62816 L .31197 .62844 L F
0 0 .116 r
.31007 .63247 m .31066 .62958 L .31197 .62844 L F
.021 .089 .595 r
.62548 .40631 m .62396 .40804 L .62338 .40403 L F
.388 .657 .965 r
.62675 .40792 m .62396 .40804 L .62548 .40631 L F
.636 .941 .959 r
.62306 .43395 m .62237 .43326 L .61882 .43502 L F
.922 .976 .73 r
.62349 .43079 m .62237 .43326 L .62306 .43395 L F
.773 .869 .436 r
.69421 .3702 m .69332 .3729 L .69511 .36906 L F
0 0 .227 r
.69511 .36906 m .69611 .36466 L .6955 .36864 L F
0 0 0 r
.69421 .3702 m .69511 .36906 L .6955 .36864 L F
.21732 .55846 m .21968 .55476 L .21771 .55589 L F
.993 .782 .518 r
.40151 .6613 m .40198 .65887 L .40036 .65792 L F
.034 0 .226 r
.32424 .58479 m .32617 .58395 L .32631 .58209 L F
0 0 .053 r
.32424 .58479 m .3235 .58728 L .32617 .58395 L F
.797 .876 .905 r
.38275 .55072 m .38112 .5529 L .37945 .5516 L F
.339 .148 .468 r
.36214 .56153 m .35969 .56521 L .35977 .56243 L F
.804 .888 .905 r
.6381 .33982 m .63663 .34153 L .63517 .33988 L F
0 .178 .706 r
.3275 .69227 m .3283 .693 L .326 .69001 L F
.99 .731 .423 r
.60917 .41363 m .61044 .41736 L .61004 .41592 L F
.938 .577 .18 r
.61044 .41736 m .60991 .4192 L .61004 .41592 L F
.61044 .41736 m .61128 .42041 L .60991 .4192 L F
.795 .845 .889 r
.63193 .4011 m .63402 .39771 L .6315 .39831 L F
.92 .964 .654 r
.27701 .53931 m .27851 .53608 L .27685 .53541 L F
.946 .587 .224 r
.39002 .62361 m .38797 .6196 L .38625 .62337 L F
.365 .82 .934 r
.60156 .36058 m .60331 .36061 L .60311 .35852 L F
.195 .358 .8 r
.60311 .35852 m .60331 .36061 L .60476 .35894 L F
.188 .348 .793 r
.60331 .36061 m .60677 .3628 L .60476 .35894 L F
.807 .983 .893 r
.69115 .34973 m .68731 .35147 L .69063 .34909 L F
.805 .997 .856 r
.69371 .34616 m .69115 .34973 L .69063 .34909 L F
.69371 .34616 m .69419 .34697 L .69115 .34973 L F
.856 .955 .874 r
.649 .34513 m .65282 .34325 L .65205 .34234 L F
.771 .992 .778 r
.65282 .34325 m .65533 .33988 L .65205 .34234 L F
.65282 .34325 m .65582 .34023 L .65533 .33988 L F
.753 .879 .937 r
.6197 .37062 m .62207 .36942 L .6201 .36872 L F
.633 .453 .621 r
.6197 .37062 m .62207 .36942 L .61931 .37215 L F
.753 .879 .937 r
.6197 .37062 m .62207 .36942 L .6201 .36872 L F
.02 .591 .76 r
.26834 .51783 m .27072 .51786 L .27266 .51809 L F
.399 .852 .898 r
.27266 .51809 m .27291 .5172 L .27491 .51705 L F
.27266 .51809 m .27072 .51786 L .27291 .5172 L F
.929 .555 .159 r
.28262 .64293 m .28192 .64277 L .27967 .64174 L F
.28262 .64293 m .28341 .64539 L .28192 .64277 L F
.757 .587 .667 r
.61842 .39908 m .61412 .39608 L .61712 .39726 L F
0 .398 .699 r
.61934 .39928 m .61842 .39908 L .61712 .39726 L F
.61934 .39928 m .62013 .39961 L .61842 .39908 L F
0 .17 .611 r
.62251 .4019 m .61842 .39908 L .62013 .39961 L F
.453 0 0 r
.28094 .63052 m .28108 .62935 L .27902 .62882 L F
.608 .2 0 r
.32586 .64549 m .32822 .64942 L .32625 .64814 L F
.964 .661 .404 r
.32625 .64814 m .32822 .64942 L .32655 .6508 L F
0 0 0 r
.32655 .6508 m .32822 .64942 L .33014 .64837 L F
.707 .778 .908 r
.45336 .45832 m .45632 .45594 L .45727 .45886 L F
.766 .857 .918 r
.45875 .45495 m .45727 .45886 L .45632 .45594 L F
.45875 .45495 m .45998 .45607 L .45727 .45886 L F
.929 .694 .563 r
.33298 .50127 m .3326 .50394 L .33072 .50055 L F
.609 .499 .703 r
.48021 .48638 m .48022 .48795 L .47756 .48853 L F
.574 .425 .641 r
.48022 .48795 m .47776 .49119 L .47756 .48853 L F
0 0 0 r
.6348 .39552 m .6315 .39831 L .63402 .39771 L F
.164 0 .211 r
.63693 .3943 m .6348 .39552 L .63402 .39771 L F
0 0 .24 r
.70065 .29826 m .701 .29579 L .70226 .2944 L F
.658 .819 .961 r
.61103 .36225 m .61463 .36378 L .61242 .36305 L F
.82 .998 .781 r
.61463 .36378 m .61283 .36428 L .61242 .36305 L F
0 .274 .776 r
.38063 .61708 m .38256 .6181 L .38341 .61524 L F
.536 .803 .995 r
.3857 .61252 m .38341 .61524 L .38448 .61474 L F
0 0 0 r
.38448 .61474 m .38341 .61524 L .38256 .6181 L F
.845 .773 .782 r
.37517 .59104 m .37853 .58738 L .37599 .5877 L F
0 0 0 r
.37759 .5876 m .37853 .58738 L .37599 .5877 L F
.498 .887 .96 r
.56559 .46576 m .56951 .46527 L .56817 .46523 L F
.257 .767 .835 r
.56817 .46523 m .56951 .46527 L .57182 .46476 L F
.869 .955 .862 r
.42465 .50766 m .42785 .50631 L .42646 .50519 L F
.475 .296 .559 r
.39873 .6781 m .40063 .68033 L .39869 .68007 L F
.546 .306 .503 r
.39873 .6781 m .40148 .67767 L .40063 .68033 L F
.587 .544 .773 r
.46738 .523 m .46811 .52639 L .46589 .52733 L F
.347 .213 .552 r
.46811 .52639 m .46631 .53003 L .46589 .52733 L F
.311 0 0 r
.35706 .61246 m .36086 .61355 L .35878 .61312 L F
.613 .148 .124 r
.36245 .61265 m .35878 .61312 L .36086 .61355 L F
.843 .961 .884 r
.68942 .37472 m .69332 .3729 L .69269 .37218 L F
.834 .998 .834 r
.69269 .37218 m .69332 .3729 L .69421 .3702 L F
.938 .954 .758 r
.38342 .66828 m .38455 .66674 L .38456 .66522 L F
.243 .398 .819 r
.38456 .66522 m .38455 .66674 L .38719 .66694 L F
.975 .728 .498 r
.38719 .66694 m .38456 .66522 L .38455 .66674 L F
.76 .994 .87 r
.6867 .29844 m .68281 .30046 L .68538 .29705 L F
.807 .888 .902 r
.68977 .29572 m .6867 .29844 L .68538 .29705 L F
.615 .523 .727 r
.46636 .51232 m .46881 .51316 L .46618 .51379 L F
.542 .446 .695 r
.46911 .51675 m .46618 .51379 L .46881 .51316 L F
.46911 .51675 m .46684 .51746 L .46618 .51379 L F
.701 .883 .498 r
.3907 .61432 m .39138 .6139 L .39127 .61194 L F
.769 .992 .78 r
.65321 .32778 m .65033 .33069 L .65157 .32828 L F
.754 .987 .898 r
.65157 .32828 m .65033 .33069 L .64963 .33005 L F
.963 .759 .581 r
.33319 .62907 m .32931 .62653 L .33084 .6296 L F
.459 .481 .794 r
.33084 .6296 m .33471 .633 L .33319 .62907 L F
0 0 .445 r
.30227 .66403 m .30157 .66492 L .30133 .66176 L F
.818 .349 .097 r
.30227 .66403 m .30133 .66176 L .29897 .66116 L F
.163 .55 .928 r
.59144 .39435 m .59198 .39321 L .58877 .39182 L F
.59144 .39435 m .59332 .3948 L .59198 .39321 L F
.034 0 .299 r
.70352 .31192 m .70561 .31178 L .70582 .31091 L F
.70352 .31192 m .70334 .31414 L .70561 .31178 L F
.499 .893 .948 r
.5758 .46357 m .57773 .46225 L .57464 .46322 L F
.5758 .46357 m .5787 .46264 L .57773 .46225 L F
0 0 0 r
.23537 .57553 m .23533 .57569 L .2378 .5751 L F
.581 .448 .665 r
.43931 .57537 m .44443 .57523 L .44179 .57156 L F
.518 .178 .33 r
.4423 .57717 m .43931 .57537 L .43918 .57767 L F
.4423 .57717 m .44443 .57523 L .43931 .57537 L F
.86 .872 .846 r
.31062 .63809 m .31344 .63932 L .30977 .64233 L F
.496 .825 .999 r
.31484 .63855 m .31344 .63932 L .31062 .63809 L F
.244 .218 .63 r
.31545 .64078 m .31344 .63932 L .31484 .63855 L F
.722 .775 .895 r
.36843 .66678 m .36878 .66891 L .36653 .6678 L F
.67 .118 0 r
.36653 .6678 m .36878 .66891 L .36739 .66862 L F
.321 .472 .854 r
.37029 .66688 m .36878 .66891 L .36843 .66678 L F
.659 .951 .952 r
.36739 .66862 m .36878 .66891 L .37029 .66688 L F
.127 0 0 r
.31339 .62615 m .31632 .62585 L .31434 .62647 L F
.069 .26 .75 r
.3197 .59688 m .32147 .60096 L .32233 .59929 L F
0 0 .27 r
.32034 .60323 m .32233 .59929 L .32147 .60096 L F
.657 .517 .681 r
.60229 .37505 m .605 .37158 L .60195 .37279 L F
.768 .688 .775 r
.55319 .42407 m .55694 .42412 L .55566 .42014 L F
.736 .219 0 r
.55319 .42407 m .55699 .42665 L .55694 .42412 L F
.676 .637 .803 r
.55566 .42014 m .55694 .42412 L .55975 .42162 L F
.687 .658 .815 r
.55694 .42412 m .55958 .42379 L .55975 .42162 L F
.686 .46 .574 r
.55699 .42665 m .55958 .42379 L .55694 .42412 L F
0 0 .17 r
.21224 .57766 m .21331 .57419 L .21223 .57511 L F
.174 .323 .775 r
.2929 .51205 m .29156 .51356 L .29074 .51319 L F
.2929 .51205 m .29461 .51531 L .29156 .51356 L F
.792 .83 .881 r
.62686 .34637 m .62324 .34635 L .62609 .34373 L F
.75 .807 .898 r
.62981 .344 m .62686 .34637 L .62609 .34373 L F
.575 .2 .293 r
.35892 .60978 m .36232 .6091 L .35939 .60759 L F
.726 .988 .876 r
.68705 .31468 m .69082 .3121 L .68848 .31237 L F
.81 .997 .857 r
.68848 .31237 m .69082 .3121 L .69175 .3104 L F
.454 .118 .306 r
.34863 .63525 m .3506 .63563 L .34769 .63539 L F
.43 0 0 r
.42737 .58979 m .43137 .58981 L .42899 .58895 L F
.646 .811 .962 r
.42945 .58969 m .42737 .58979 L .42899 .58895 L F
.707 .98 .903 r
.22989 .60526 m .22956 .60577 L .23187 .60436 L F
0 0 .19 r
.22989 .60526 m .22977 .60655 L .22956 .60577 L F
0 0 0 r
.38976 .6168 m .38664 .6186 L .38797 .6196 L F
.38976 .6168 m .39072 .61536 L .38664 .6186 L F
.319 .068 .368 r
.44459 .53669 m .44524 .53973 L .44262 .53961 L F
.569 .221 .339 r
.44695 .5388 m .44459 .53669 L .4463 .53448 L F
.341 .223 .571 r
.24432 .57208 m .24474 .57445 L .24652 .57387 L F
.24432 .57208 m .24483 .57495 L .24652 .57387 L F
.438 0 .033 r
.24462 .5742 m .24819 .57332 L .24652 .57387 L F
.24819 .57332 m .24923 .57306 L .24652 .57387 L F
.341 .223 .571 r
.24474 .57445 m .24483 .57495 L .24652 .57387 L F
.609 .802 .974 r
.38345 .70141 m .38385 .69891 L .37994 .70166 L F
.475 .889 .781 r
.37486 .67793 m .36816 .68091 L .3723 .67673 L F
.941 .704 .233 r
.40052 .58714 m .40053 .58481 L .39981 .5836 L F
0 0 .418 r
.23027 .59601 m .22924 .59411 L .23145 .59397 L F
.23027 .59601 m .22973 .59682 L .22924 .59411 L F
.863 .532 .016 r
.58379 .38428 m .58472 .38598 L .58434 .38662 L F
.556 .911 .965 r
.37294 .70805 m .37807 .70726 L .37636 .70569 L F
.934 .968 .698 r
.37807 .70726 m .37919 .70313 L .37636 .70569 L F
.612 .447 .635 r
.47526 .49709 m .47246 .50031 L .4728 .498 L F
.724 .708 .834 r
.52756 .41314 m .5245 .41256 L .52658 .41051 L F
.674 .707 .872 r
.53069 .41116 m .52756 .41314 L .52658 .41051 L F
.059 0 0 r
.25008 .61596 m .25224 .61613 L .25472 .61633 L F
.59 .054 0 r
.25473 .61692 m .25472 .61633 L .25224 .61613 L F
.166 0 0 r
.25284 .61662 m .25447 .61691 L .25473 .61692 L F
.59 .054 0 r
.25473 .61692 m .2567 .61835 L .2553 .61692 L F
.592 .055 0 r
.25472 .61633 m .2567 .61835 L .25755 .61886 L F
.161 .591 .935 r
.25596 .61781 m .25694 .61736 L .2567 .61835 L F
.25473 .61692 m .25694 .61736 L .25596 .61781 L F
.503 0 0 r
.25284 .61662 m .25554 .61784 L .25694 .61736 L F
.214 0 0 r
.25554 .61784 m .25771 .617 L .25694 .61736 L F
.223 0 .303 r
.25952 .61409 m .25694 .61736 L .2588 .61657 L F
.25952 .61409 m .25694 .61736 L .2588 .61657 L F
.214 0 0 r
.25771 .617 m .2588 .61657 L .25694 .61736 L F
.166 0 0 r
.25447 .61691 m .25694 .61736 L .25473 .61692 L F
.59 .054 0 r
.25473 .61692 m .2553 .61692 L .25472 .61633 L F
.319 .133 .464 r
.22714 .57713 m .22567 .57504 L .22736 .57412 L F
.22714 .57713 m .22519 .57817 L .22567 .57504 L F
0 0 0 r
.30729 .55977 m .3093 .55945 L .31153 .55851 L F
.559 .304 .486 r
.31153 .55851 m .31151 .55921 L .31088 .55928 L F
.279 0 .119 r
.31513 .55856 m .31145 .56178 L .31153 .55851 L F
.31513 .55856 m .31375 .56119 L .31145 .56178 L F
.089 .646 .709 r
.3093 .55945 m .31494 .5588 L .31153 .55851 L F
.31041 .55932 m .31161 .55917 L .31473 .55883 L F
.3093 .55945 m .31473 .55883 L .31456 .55885 L F
.243 0 0 r
.31161 .55917 m .31242 .56078 L .31326 .55897 L F
.585 .556 .788 r
.31153 .55851 m .31494 .5588 L .31426 .55473 L F
.823 .992 .866 r
.31494 .5588 m .31161 .55917 L .31416 .55712 L F
.243 0 0 r
.31161 .55917 m .31326 .55897 L .31404 .55732 L F
.089 .646 .709 r
.3093 .55945 m .31161 .55917 L .31041 .55932 L F
.31456 .55885 m .31473 .55883 L .31494 .5588 L F
.559 .304 .486 r
.31088 .55928 m .31145 .56178 L .30872 .56182 L F
.31151 .55921 m .31145 .56178 L .31088 .55928 L F
.585 .556 .788 r
.31153 .55851 m .31426 .55473 L .31125 .55577 L F
.588 .573 .805 r
.34695 .56835 m .34857 .57241 L .35086 .57137 L F
0 .136 .674 r
.34896 .57062 m .34832 .57178 L .34695 .56835 L F
.762 .939 .941 r
.34407 .57027 m .3447 .56747 L .34695 .56835 L F
.821 .352 .097 r
.3447 .56747 m .34896 .57062 L .34695 .56835 L F
.588 .573 .805 r
.34695 .56835 m .35086 .57137 L .34952 .56788 L F
.821 .352 .097 r
.3447 .56747 m .34702 .57016 L .34896 .57062 L F
.349 0 0 r
.34702 .57016 m .34931 .56997 L .34896 .57062 L F
0 0 .065 r
.35086 .57137 m .35216 .56719 L .34952 .56788 L F
.35086 .57137 m .35177 .56977 L .35216 .56719 L F
.349 0 0 r
.34931 .56997 m .35177 .56977 L .34896 .57062 L F
0 .136 .674 r
.34896 .57062 m .34857 .57241 L .34832 .57178 L F
.62 .883 .989 r
.35086 .57137 m .34857 .57241 L .34896 .57062 L F
.942 .581 .283 r
.5991 .42007 m .59866 .41783 L .59699 .41672 L F
.422 .201 .47 r
.34947 .58084 m .34673 .58424 L .34703 .5815 L F
.939 .771 .648 r
.38882 .60248 m .38754 .607 L .38527 .60529 L F
.628 .185 .179 r
.53656 .46842 m .54082 .4685 L .53927 .47034 L F
.612 .177 .189 r
.54082 .4685 m .54167 .47088 L .53927 .47034 L F
.54082 .4685 m .54309 .46895 L .54167 .47088 L F
.371 .155 .452 r
.36817 .53973 m .36793 .54289 L .37018 .54161 L F
.6 .432 .626 r
.51954 .46586 m .51946 .46858 L .51673 .46897 L F
.559 .296 .474 r
.51673 .46897 m .51943 .47095 L .51672 .47111 L F
.51673 .46897 m .51946 .46858 L .51943 .47095 L F
.395 0 0 r
.27049 .57225 m .27247 .57318 L .27469 .57189 L F
0 0 0 r
.27469 .57189 m .27838 .5687 L .27329 .56862 L F
.27469 .57189 m .27622 .57105 L .27838 .5687 L F
.471 .109 .27 r
.27247 .57318 m .27622 .57105 L .27469 .57189 L F
.086 0 0 r
.68876 .31534 m .68649 .31615 L .68613 .31612 L F
0 0 0 r
.68568 .31609 m .68613 .31612 L .68385 .31797 L F
.68613 .31612 m .68362 .31937 L .68385 .31797 L F
.776 .962 .654 r
.68489 .31672 m .68362 .31937 L .68613 .31612 L F
.086 0 0 r
.68649 .31615 m .68489 .31672 L .68613 .31612 L F
0 0 0 r
.68705 .31468 m .68613 .31612 L .68568 .31609 L F
.499 .332 .586 r
.68848 .31237 m .68613 .31612 L .68705 .31468 L F
.698 .768 .277 r
.38723 .49403 m .38659 .49549 L .38663 .4933 L F
.962 .627 .292 r
.38663 .4933 m .38659 .49549 L .38497 .49197 L F
0 .179 .71 r
.38667 .49507 m .38659 .49549 L .38434 .49701 L F
.698 .768 .277 r
.38723 .49403 m .38647 .49608 L .38659 .49549 L F
.375 .093 .351 r
.38663 .4933 m .38659 .49549 L .38896 .49274 L F
0 .179 .71 r
.38727 .49456 m .38659 .49549 L .38667 .49507 L F
.698 .768 .277 r
.38647 .49608 m .38576 .49801 L .38659 .49549 L F
.667 .901 .979 r
.61782 .35002 m .6142 .35025 L .6166 .34885 L F
.756 .913 .944 r
.61782 .35002 m .6189 .3471 L .61986 .34827 L F
.61782 .35002 m .6166 .34885 L .6189 .3471 L F
.704 .885 .964 r
.62708 .4265 m .6283 .42782 L .63059 .42648 L F
.707 .98 .903 r
.22989 .60526 m .23187 .60436 L .23031 .60106 L F
.156 0 0 r
.23187 .60436 m .22996 .60612 L .23378 .60427 L F
.558 .92 .745 r
.56761 .40237 m .56892 .4019 L .56548 .40431 L F
.583 .944 .841 r
.56761 .40237 m .56548 .40431 L .56514 .40358 L F
.607 .436 .625 r
.49575 .46576 m .49351 .46919 L .49361 .46623 L F
.064 0 .465 r
.47541 .5739 m .47546 .5769 L .47365 .57837 L F
.062 0 .317 r
.47546 .5769 m .47295 .58055 L .47365 .57837 L F
.365 .136 .428 r
.36222 .5162 m .35989 .51862 L .36107 .51913 L F
.175 .559 .932 r
.35989 .51862 m .36146 .51879 L .36149 .51992 L F
.544 .316 .52 r
.36243 .5231 m .36465 .52015 L .36149 .51992 L F
.921 .688 .195 r
.36146 .51879 m .36243 .5231 L .36149 .51992 L F
.951 .671 .221 r
.59306 .40811 m .59194 .40431 L .59227 .40667 L F
.869 .558 .039 r
.59227 .40667 m .59358 .4106 L .59306 .40811 L F
.705 .671 .815 r
.58179 .45532 m .57979 .45528 L .58372 .45492 L F
.518 .184 .341 r
.58372 .45492 m .58594 .45638 L .58179 .45532 L F
.6 .038 0 r
.43068 .59703 m .43429 .59797 L .43223 .59838 L F
.18 0 0 r
.43429 .59797 m .43519 .59857 L .43223 .59838 L F
.43429 .59797 m .43666 .59803 L .43519 .59857 L F
0 0 0 r
.65599 .37959 m .65493 .37967 L .65374 .38089 L F
.834 .908 .888 r
.53621 .40295 m .53341 .40536 L .53251 .4044 L F
.992 .836 .585 r
.53341 .40536 m .53316 .40773 L .53251 .4044 L F
.703 .909 .967 r
.59452 .46225 m .59601 .4634 L .59832 .46195 L F
0 0 .48 r
.43537 .50057 m .43693 .50409 L .4349 .50023 L F
.399 0 0 r
.4349 .50023 m .43537 .50057 L .43295 .50093 L F
0 0 .48 r
.43537 .50057 m .4349 .50023 L .43295 .50093 L F
.667 .946 .959 r
.65729 .33811 m .65582 .34023 L .65841 .3387 L F
.699 .983 .829 r
.65533 .33988 m .65582 .34023 L .65729 .33811 L F
.369 .748 .989 r
.26424 .51676 m .26834 .51783 L .26605 .51737 L F
.755 .785 .878 r
.67443 .38402 m .67896 .38332 L .67784 .38195 L F
.769 .905 .935 r
.67896 .38332 m .68017 .38051 L .67784 .38195 L F
.67896 .38332 m .6814 .38176 L .68017 .38051 L F
.977 .918 .619 r
.39794 .59593 m .39889 .5963 L .39983 .59429 L F
.99 .889 .601 r
.39794 .59593 m .39983 .59429 L .39885 .59334 L F
.528 .161 .288 r
.30339 .56456 m .30183 .56743 L .29922 .56747 L F
.481 .125 .284 r
.30582 .56442 m .30183 .56743 L .30339 .56456 L F
.849 .395 .114 r
.37913 .51908 m .38265 .52259 L .38142 .52008 L F
0 0 .193 r
.41287 .58753 m .41249 .58346 L .41265 .58448 L F
.785 .946 .605 r
.7029 .35002 m .7041 .34937 L .70377 .34871 L F
.7029 .35002 m .70175 .35281 L .7041 .34937 L F
.178 0 0 r
.55021 .46966 m .55207 .46997 L .54959 .47114 L F
.848 .99 .848 r
.71126 .33856 m .71233 .33909 L .71505 .33617 L F
.865 .977 .674 r
.69639 .34348 m .69419 .34697 L .6949 .34431 L F
.864 .996 .783 r
.6949 .34431 m .69419 .34697 L .69371 .34616 L F
.799 .726 .784 r
.30124 .54863 m .30321 .55214 L .3061 .54945 L F
.30124 .54863 m .30533 .54932 L .30566 .54949 L F
.30533 .54932 m .3061 .54945 L .30566 .54949 L F
.494 .377 .649 r
.30842 .54872 m .3061 .54945 L .30554 .54568 L F
.071 0 0 r
.30842 .54872 m .30566 .54949 L .3061 .54945 L F
.30842 .54872 m .3063 .54983 L .30566 .54949 L F
0 0 .283 r
.30566 .54949 m .3063 .54983 L .3063 .54981 L F
.30566 .54949 m .3063 .54981 L .30624 .54708 L F
.694 .611 .759 r
.30406 .54744 m .30566 .54949 L .30483 .54711 L F
.30149 .54868 m .30566 .54949 L .30406 .54744 L F
0 0 .283 r
.30566 .54949 m .30624 .54708 L .30482 .54707 L F
.12 0 0 r
.30406 .54744 m .30339 .54823 L .30596 .54652 L F
0 0 .283 r
.30482 .54707 m .30624 .54708 L .30461 .54648 L F
.12 0 0 r
.30596 .54652 m .30513 .54707 L .30624 .54708 L F
.30513 .54707 m .30339 .54823 L .30624 .54708 L F
.30554 .54568 m .30406 .54744 L .30596 .54652 L F
.694 .611 .759 r
.30124 .54863 m .30149 .54868 L .30406 .54744 L F
.185 0 0 r
.30124 .54863 m .30406 .54744 L .30554 .54568 L F
.694 .611 .759 r
.30124 .54863 m .30483 .54711 L .30461 .54648 L F
.185 0 0 r
.30124 .54863 m .30339 .54823 L .30406 .54744 L F
.427 .197 .461 r
.30554 .54568 m .30802 .54534 L .3084 .54277 L F
.494 .377 .649 r
.30842 .54872 m .30554 .54568 L .30802 .54534 L F
.12 0 0 r
.30554 .54568 m .30624 .54708 L .30802 .54534 L F
.427 .197 .461 r
.3084 .54277 m .30802 .54534 L .30554 .54568 L F
.756 .507 .556 r
.34104 .60013 m .33707 .59735 L .34112 .59764 L F
.364 .78 .978 r
.34112 .59764 m .33794 .5967 L .33707 .59735 L F
.987 .736 .461 r
.60233 .46218 m .60093 .46154 L .60124 .45904 L F
.2 .645 .947 r
.60233 .46218 m .60341 .46144 L .60093 .46154 L F
.60233 .46218 m .60503 .46254 L .60341 .46144 L F
.758 .396 0 r
.27736 .62514 m .27902 .62882 L .27809 .62625 L F
.416 .748 .994 r
.23373 .61265 m .23407 .61084 L .23091 .61032 L F
.23373 .61265 m .23557 .61211 L .23407 .61084 L F
.531 .566 .835 r
.45082 .53899 m .44874 .53999 L .44674 .53541 L F
.555 .515 .766 r
.44874 .53999 m .45199 .54259 L .45082 .53899 L F
.529 .35 .583 r
.48395 .48218 m .48021 .48638 L .48017 .48288 L F
.864 .437 .196 r
.62084 .37067 m .62207 .36942 L .6201 .36872 L F
.634 .962 .828 r
.62207 .36942 m .62362 .36772 L .6201 .36872 L F
.62362 .36772 m .62269 .36764 L .6201 .36872 L F
.593 .803 .98 r
.61966 .36679 m .6201 .36872 L .62431 .36697 L F
0 0 .311 r
.62084 .37067 m .6201 .36872 L .61966 .36679 L F
.812 .711 .754 r
.6173 .37048 m .62084 .37067 L .61984 .3674 L F
.6193 .36735 m .61984 .3674 L .61966 .36679 L F
.6173 .37048 m .61984 .3674 L .6193 .36735 L F
.634 .962 .828 r
.62362 .36772 m .62431 .36697 L .62269 .36764 L F
.62207 .36942 m .62387 .3682 L .62431 .36697 L F
.987 .714 .371 r
.62209 .37214 m .62207 .36942 L .62084 .37067 L F
.034 .583 .832 r
.33396 .49439 m .33638 .49467 L .33803 .4952 L F
.095 .637 .847 r
.33926 .49476 m .33803 .4952 L .33638 .49467 L F
.912 .977 .698 r
.34451 .61657 m .34356 .61945 L .34116 .61928 L F
.912 .521 .114 r
.34356 .61945 m .34332 .62156 L .34116 .61928 L F
.34356 .61945 m .34415 .62255 L .34332 .62156 L F
.73 .349 .328 r
.34356 .61945 m .34541 .62067 L .34415 .62255 L F
.639 .402 .543 r
.45097 .56838 m .45422 .56827 L .45417 .56608 L F
.503 .296 .532 r
.45417 .56608 m .45636 .56756 L .45787 .5649 L F
.45417 .56608 m .45422 .56827 L .45636 .56756 L F
.497 .333 .588 r
.34233 .60968 m .3397 .61322 L .34045 .61055 L F
.784 .774 .844 r
.33177 .51103 m .3364 .50786 L .33269 .50653 L F
.656 .55 .723 r
.33594 .63629 m .337 .63228 L .33455 .63489 L F
.33594 .63629 m .33916 .6331 L .337 .63228 L F
.33594 .63629 m .33836 .63592 L .33916 .6331 L F
.523 .324 .553 r
.33591 .63892 m .33836 .63592 L .33594 .63629 L F
.968 .697 .466 r
.38669 .69532 m .38815 .69416 L .38633 .69257 L F
.446 .815 .556 r
.38843 .69392 m .38815 .69416 L .38669 .69532 L F
0 0 .204 r
.38851 .69706 m .38815 .69416 L .38843 .69392 L F
.663 .967 .785 r
.28351 .57594 m .28515 .57569 L .28731 .5736 L F
.822 .706 .17 r
.33876 .6416 m .33929 .64148 L .33945 .63909 L F
.167 .297 .753 r
.58665 .45382 m .58694 .4537 L .589 .4545 L F
.612 .445 .631 r
.29711 .55473 m .3006 .5555 L .30058 .55245 L F
.595 .497 .713 r
.29711 .55473 m .29792 .55904 L .3006 .5555 L F
.918 .536 .124 r
.42801 .55853 m .42889 .56128 L .43022 .56223 L F
.946 .688 .513 r
.42809 .56373 m .43022 .56223 L .42889 .56128 L F
.42809 .56373 m .42993 .56482 L .43022 .56223 L F
.32 .187 .539 r
.69444 .3306 m .69607 .32963 L .69621 .3273 L F
0 0 .417 r
.69444 .3306 m .69589 .33167 L .69607 .32963 L F
.69444 .3306 m .69506 .33286 L .69589 .33167 L F
.968 .897 .531 r
.69676 .33961 m .69639 .34348 L .69623 .34259 L F
.857 .978 .677 r
.6949 .34431 m .69623 .34259 L .69639 .34348 L F
.503 .248 .46 r
.34136 .6516 m .34192 .64908 L .34393 .65119 L F
.34136 .6516 m .34192 .64908 L .34393 .65119 L F
.862 .918 .866 r
.6634 .33502 m .6672 .33384 L .66559 .33222 L F
.6634 .33502 m .66455 .3361 L .6672 .33384 L F
.842 .886 .872 r
.66559 .33222 m .6672 .33384 L .67027 .33054 L F
.502 .146 .295 r
.46808 .58444 m .46734 .5871 L .46437 .58733 L F
.267 0 .205 r
.47019 .58362 m .46734 .5871 L .46808 .58444 L F
.975 .671 .366 r
.60652 .43572 m .60815 .43911 L .60812 .43682 L F
.899 .829 .363 r
.33006 .6446 m .33031 .64577 L .3307 .64202 L F
0 0 .1 r
.3308 .6467 m .33031 .64577 L .33006 .6446 L F
.325 .808 .882 r
.5749 .42088 m .57888 .42037 L .57828 .41904 L F
0 0 0 r
.57861 .42227 m .57888 .42037 L .57673 .42371 L F
.887 .65 .13 r
.57828 .41904 m .57888 .42037 L .57861 .42227 L F
.697 .983 .872 r
.67263 .36643 m .6714 .36858 L .6711 .36805 L F
.67263 .36643 m .67486 .36619 L .6714 .36858 L F
.772 .619 .69 r
.34691 .54923 m .34738 .55235 L .35077 .55254 L F
.34691 .54923 m .35077 .55254 L .34665 .55206 L F
.305 .792 .894 r
.35206 .5537 m .34979 .55406 L .35077 .55254 L F
.408 .109 .343 r
.28917 .5625 m .28855 .56457 L .29143 .5623 L F
.9 .946 .827 r
.70328 .28495 m .7047 .28339 L .70491 .28038 L F
.341 .733 .984 r
.37853 .58738 m .38143 .58761 L .3798 .58655 L F
.409 .855 .775 r
.37759 .5876 m .37853 .58738 L .3798 .58655 L F
.341 .733 .984 r
.37853 .58738 m .38143 .58761 L .3798 .58655 L F
.814 .63 .653 r
.49041 .47514 m .49192 .47865 L .48808 .47823 L F
.538 .329 .545 r
.49621 .47438 m .49192 .47865 L .49041 .47514 L F
.49621 .47438 m .49591 .47901 L .49192 .47865 L F
.533 .274 .467 r
.49192 .47865 m .49591 .47901 L .49448 .48062 L F
.305 .263 .646 r
.31018 .63546 m .30781 .63319 L .31007 .63247 L F
.31018 .63546 m .30837 .6359 L .30781 .63319 L F
.658 .875 .98 r
.4079 .47852 m .40524 .47911 L .40596 .47693 L F
.008 0 0 r
.40596 .47693 m .40866 .47596 L .4079 .47852 L F
.52 .684 .941 r
.40866 .47596 m .41195 .47962 L .4079 .47852 L F
.544 .316 .52 r
.36243 .5231 m .36429 .5234 L .36465 .52015 L F
0 0 0 r
.36465 .52015 m .36456 .52174 L .36479 .51957 L F
.36465 .52015 m .36429 .5234 L .36456 .52174 L F
.902 .897 .813 r
.38838 .58497 m .38471 .58704 L .38481 .58373 L F
.768 .813 .888 r
.40524 .47911 m .40091 .47977 L .40342 .47792 L F
.647 .864 .981 r
.40524 .47911 m .40342 .47792 L .40596 .47693 L F
.493 .299 .546 r
.26345 .53698 m .2635 .5396 L .26593 .53876 L F
.788 .69 .757 r
.24021 .59009 m .24159 .59389 L .23783 .59332 L F
.774 .998 .837 r
.23698 .59687 m .23705 .59667 L .23992 .59527 L F
.23705 .59667 m .2383 .59516 L .23992 .59527 L F
.418 0 0 r
.24159 .59389 m .23758 .59512 L .23992 .59527 L F
.24159 .59389 m .2398 .59541 L .23758 .59512 L F
.71 .259 .179 r
.24159 .59389 m .2398 .59541 L .23783 .59332 L F
.231 .248 .671 r
.23783 .59332 m .23889 .59445 L .23913 .59166 L F
.23889 .59445 m .2398 .59541 L .2395 .59373 L F
.23889 .59445 m .2395 .59373 L .23913 .59166 L F
.774 .998 .837 r
.23705 .59667 m .23758 .59512 L .2383 .59516 L F
.299 .794 .8 r
.53447 .41976 m .52875 .4209 L .535 .41985 L F
0 0 0 r
.5389 .41825 m .53447 .41976 L .5362 .41629 L F
0 0 .11 r
.5362 .41629 m .53447 .41976 L .535 .41985 L F
0 0 0 r
.24165 .52704 m .24073 .52925 L .24284 .52578 L F
.986 .711 .401 r
.49685 .4748 m .49831 .47838 L .49687 .47723 L F
.251 .096 .466 r
.49687 .47723 m .49591 .47901 L .49621 .47438 L F
.915 .945 .806 r
.49448 .48062 m .49591 .47901 L .49687 .47723 L F
.905 .883 .801 r
.49831 .47838 m .49448 .48062 L .49687 .47723 L F
.49831 .47838 m .49598 .48187 L .49448 .48062 L F
.653 .494 .656 r
.49831 .47838 m .49864 .48108 L .49598 .48187 L F
.563 .368 .575 r
.50089 .47815 m .49864 .48108 L .49831 .47838 L F
.598 .854 .992 r
.26253 .52189 m .2656 .52345 L .26517 .52163 L F
.811 .877 .895 r
.26517 .52163 m .2656 .52345 L .27 .52038 L F
.196 0 0 r
.36044 .52748 m .3603 .52752 L .35831 .52718 L F
.3603 .52752 m .36003 .5276 L .35926 .52742 L F
.3603 .52752 m .35926 .52742 L .35831 .52718 L F
.36227 .52619 m .36044 .52748 L .35831 .52718 L F
.459 .835 .597 r
.36316 .52544 m .3605 .52742 L .36227 .52619 L F
.54 .546 .81 r
.36192 .52768 m .36181 .53036 L .3603 .52752 L F
.691 .602 .751 r
.36181 .53036 m .35684 .5286 L .3603 .52752 L F
.196 0 0 r
.36044 .52748 m .3602 .52765 L .36003 .5276 L F
.459 .835 .597 r
.3605 .52742 m .3602 .52765 L .36037 .52753 L F
.3605 .52742 m .36037 .52753 L .36227 .52619 L F
.54 .546 .81 r
.36196 .52679 m .36192 .52768 L .36062 .52733 L F
.36072 .52756 m .3603 .52752 L .36013 .52719 L F
0 0 0 r
.3605 .52742 m .36013 .52719 L .3602 .52765 L F
.36316 .52544 m .36013 .52719 L .3605 .52742 L F
.54 .546 .81 r
.36192 .52768 m .36072 .52756 L .36013 .52719 L F
.36104 .52699 m .36062 .52733 L .36013 .52719 L F
.36196 .52679 m .36062 .52733 L .36104 .52699 L F
.126 0 .324 r
.35831 .52718 m .36003 .5276 L .36013 .52719 L F
.691 .602 .751 r
.3603 .52752 m .36003 .52759 L .36013 .52719 L F
.126 0 .324 r
.36003 .5276 m .3602 .52765 L .36013 .52719 L F
.691 .602 .751 r
.36003 .52759 m .35651 .52848 L .36013 .52719 L F
.35684 .5286 m .35651 .52848 L .3603 .52752 L F
.459 .835 .597 r
.36316 .52544 m .36227 .52619 L .36441 .52701 L F
.591 .628 .857 r
.33883 .50987 m .33975 .50726 L .33737 .50654 L F
.33883 .50987 m .34175 .51031 L .33975 .50726 L F
.757 .519 .572 r
.33745 .51262 m .34175 .51031 L .33883 .50987 L F
.79 .694 .759 r
.42993 .56482 m .43145 .5685 L .43386 .5654 L F
.971 .71 .479 r
.34363 .60997 m .34233 .60968 L .34251 .60693 L F
.657 .318 .386 r
.34363 .60997 m .34203 .61275 L .34233 .60968 L F
.34363 .60997 m .34443 .61305 L .34285 .61132 L F
.593 .097 .045 r
.34203 .61275 m .34443 .61438 L .34471 .6134 L F
.586 .125 .126 r
.34443 .61305 m .34443 .61438 L .34203 .61275 L F
.028 .206 .712 r
.34233 .60968 m .34454 .61313 L .34301 .60811 L F
.657 .318 .386 r
.34285 .61132 m .34443 .61305 L .34203 .61275 L F
0 0 .129 r
.34251 .60693 m .34237 .60909 L .34301 .60811 L F
.34237 .60909 m .34233 .60968 L .34301 .60811 L F
.547 .455 .702 r
.34301 .60811 m .34577 .60762 L .34515 .60443 L F
0 0 0 r
.34515 .60443 m .34413 .60669 L .34301 .60811 L F
.579 .938 .797 r
.34413 .60669 m .34378 .6069 L .34301 .60811 L F
0 0 .129 r
.34251 .60693 m .34301 .60811 L .34032 .60868 L F
.847 .736 .742 r
.34061 .61155 m .34233 .60968 L .34032 .60868 L F
.554 .834 .997 r
.34301 .60811 m .34233 .60968 L .34032 .60868 L F
.34032 .60868 m .34233 .60968 L .34301 .60811 L F
.968 .654 .357 r
.33907 .61056 m .34061 .61155 L .34032 .60868 L F
.33907 .61056 m .34032 .60868 L .34301 .60811 L F
.579 .938 .797 r
.34378 .6069 m .33964 .60944 L .34301 .60811 L F
.497 .333 .588 r
.3402 .61254 m .34203 .61275 L .3397 .61322 L F
.34233 .60968 m .34203 .61275 L .3402 .61254 L F
.593 .097 .045 r
.34203 .61275 m .34471 .6134 L .34372 .61295 L F
.34203 .61275 m .34372 .61295 L .34061 .61155 L F
.847 .736 .742 r
.34061 .61155 m .34301 .60811 L .34233 .60968 L F
.34061 .61155 m .34442 .61327 L .34301 .60811 L F
.028 .206 .712 r
.3446 .61322 m .34471 .6134 L .34468 .61332 L F
.847 .736 .742 r
.34442 .61327 m .34471 .6134 L .34465 .61322 L F
.028 .206 .712 r
.34454 .61313 m .3446 .61322 L .34458 .61316 L F
.657 .318 .386 r
.34363 .60997 m .34602 .61324 L .34443 .61305 L F
.028 .206 .712 r
.34454 .61313 m .34458 .61316 L .34301 .60811 L F
.3446 .61322 m .34468 .61332 L .34301 .60811 L F
.847 .736 .742 r
.34442 .61327 m .34465 .61322 L .34301 .60811 L F
.586 .125 .126 r
.34602 .61324 m .34531 .61375 L .34489 .61341 L F
.34602 .61324 m .34489 .61341 L .34498 .61323 L F
.34602 .61324 m .34465 .61322 L .34509 .61313 L F
.716 .322 .301 r
.34632 .61079 m .34602 .61324 L .34363 .60997 L F
.22 0 .211 r
.34884 .60966 m .34602 .61324 L .34632 .61079 L F
0 0 0 r
.34443 .61438 m .34699 .61204 L .34497 .61324 L F
.34443 .61438 m .34497 .61324 L .34471 .6134 L F
.586 .125 .126 r
.34509 .61313 m .34465 .61322 L .34443 .61305 L F
.42 .137 .375 r
.34783 .61269 m .34602 .61324 L .34884 .60966 L F
.693 .656 .809 r
.34301 .60811 m .34465 .61322 L .34699 .61204 L F
.34465 .61322 m .34471 .6134 L .34497 .61324 L F
.586 .125 .126 r
.34498 .61323 m .34497 .61324 L .34465 .61322 L F
.693 .656 .809 r
.34465 .61322 m .34497 .61324 L .34699 .61204 L F
.586 .125 .126 r
.34497 .61324 m .34489 .61341 L .34465 .61322 L F
.34531 .61375 m .34443 .61438 L .34443 .61305 L F
.452 .882 .817 r
.56146 .46717 m .56322 .46688 L .56559 .46576 L F
.698 .762 .901 r
.47829 .44921 m .47613 .45069 L .47423 .44853 L F
.552 .843 .998 r
.43274 .5034 m .42828 .50315 L .42991 .50417 L F
.775 .388 0 r
.42991 .50417 m .42954 .50397 L .43274 .5034 L F
.385 .438 .793 r
.62534 .40362 m .62338 .40403 L .62251 .4019 L F
.021 .089 .595 r
.62548 .40631 m .62338 .40403 L .62534 .40362 L F
0 0 0 r
.22757 .55595 m .22547 .55807 L .22495 .55829 L F
.022 0 .122 r
.22854 .55277 m .22547 .55807 L .22757 .55595 L F
.22854 .55277 m .22792 .55671 L .22547 .55807 L F
0 0 .179 r
.23102 .55097 m .22854 .55277 L .2287 .55217 L F
0 0 .104 r
.2294 .55562 m .22854 .55277 L .23033 .55341 L F
.2294 .55562 m .22792 .55671 L .22854 .55277 L F
.777 .56 .605 r
.23618 .54932 m .23203 .5458 L .23419 .54583 L F
.23618 .54932 m .23208 .54934 L .23203 .5458 L F
.355 .806 .947 r
.23618 .54932 m .23439 .54889 L .23208 .54934 L F
.096 .351 .82 r
.23671 .54761 m .23618 .54932 L .23419 .54583 L F
.642 .93 .971 r
.23671 .54761 m .23439 .54889 L .23618 .54932 L F
0 .009 .518 r
.37724 .50386 m .37888 .50547 L .37749 .50399 L F
.83 .935 .898 r
.3462 .51883 m .34461 .52122 L .34623 .51883 L F
.3436 .51958 m .34461 .52122 L .3462 .51883 L F
.579 .117 .122 r
.34216 .51945 m .34247 .51958 L .34473 .51867 L F
.34271 .51948 m .3432 .5197 L .34473 .51867 L F
.33952 .52077 m .34316 .51971 L .34271 .51948 L F
.34316 .51971 m .3432 .5197 L .34271 .51948 L F
.212 .396 .828 r
.34562 .52184 m .34661 .52206 L .34523 .52078 L F
.83 .935 .898 r
.34355 .51949 m .3436 .51958 L .344 .51922 L F
.212 .396 .828 r
.34438 .52034 m .34523 .52078 L .34378 .51945 L F
0 0 0 r
.344 .51922 m .34339 .51962 L .34359 .51953 L F
.83 .935 .898 r
.34319 .51891 m .34355 .51949 L .344 .51922 L F
0 0 0 r
.34473 .51867 m .3432 .5197 L .34355 .51949 L F
.34433 .51897 m .34355 .51949 L .344 .51922 L F
.34473 .51867 m .34355 .51949 L .34433 .51897 L F
.38 .469 .826 r
.34355 .51949 m .34308 .52254 L .34461 .52122 L F
.34319 .51891 m .34317 .51975 L .34355 .51949 L F
.34317 .51975 m .34308 .52254 L .34355 .51949 L F
0 0 0 r
.3432 .5197 m .34304 .51981 L .344 .51922 L F
.34304 .51981 m .34051 .52151 L .34331 .51968 L F
.34304 .51981 m .34331 .51968 L .344 .51922 L F
.38 .469 .826 r
.34357 .51955 m .34438 .52034 L .34395 .52017 L F
0 0 0 r
.344 .51922 m .34357 .51955 L .34319 .51891 L F
.38 .469 .826 r
.34319 .51891 m .34367 .51949 L .34357 .51955 L F
.34367 .51949 m .34438 .52034 L .34357 .51955 L F
0 0 0 r
.34357 .51955 m .34051 .52151 L .34269 .52021 L F
.34359 .51953 m .34356 .51955 L .34357 .51955 L F
.34356 .51955 m .34051 .52151 L .34357 .51955 L F
.38 .469 .826 r
.34317 .51975 m .34395 .52017 L .34316 .51986 L F
.34319 .51891 m .34357 .51955 L .34317 .51975 L F
.34357 .51955 m .34395 .52017 L .34317 .51975 L F
0 0 0 r
.34357 .51955 m .34269 .52021 L .34319 .51891 L F
.212 .396 .828 r
.34367 .51949 m .34378 .51945 L .34319 .51891 L F
.34438 .52034 m .34378 .51945 L .34367 .51949 L F
0 0 0 r
.34339 .51962 m .34051 .52151 L .34359 .51953 L F
.83 .935 .898 r
.344 .51922 m .3436 .51958 L .34437 .51936 L F
0 0 0 r
.34473 .51867 m .344 .51922 L .34319 .51891 L F
.83 .935 .898 r
.34319 .51891 m .34437 .51936 L .3462 .51883 L F
.212 .396 .828 r
.34562 .52184 m .34523 .52078 L .34438 .52034 L F
.38 .469 .826 r
.34316 .51986 m .34562 .52184 L .34308 .52254 L F
.34438 .52034 m .34562 .52184 L .34316 .51986 L F
.579 .117 .122 r
.33903 .52041 m .33952 .52077 L .34247 .51958 L F
.33903 .52041 m .34247 .51958 L .34216 .51945 L F
.33952 .52077 m .34051 .52151 L .3432 .5197 L F
.686 .46 .574 r
.55699 .42665 m .56018 .42576 L .55958 .42379 L F
.613 .563 .774 r
.55958 .42379 m .56219 .42018 L .55975 .42162 L F
.55958 .42379 m .56344 .42338 L .56219 .42018 L F
.582 .39 .587 r
.56018 .42576 m .56344 .42338 L .55958 .42379 L F
.347 .213 .552 r
.46811 .52639 m .46842 .52939 L .46631 .53003 L F
.398 .363 .703 r
.46842 .52939 m .46903 .53198 L .46631 .53003 L F
.44 .359 .669 r
.46631 .53003 m .46903 .53198 L .46685 .53272 L F
.672 .385 .478 r
.2953 .56115 m .298 .56159 L .29792 .55904 L F
.437 .293 .586 r
.32064 .66441 m .3231 .66574 L .32395 .6634 L F
.32064 .66441 m .32114 .66696 L .3231 .66574 L F
.574 .308 .476 r
.42555 .54319 m .42837 .54507 L .42882 .54367 L F
.873 .804 .78 r
.38143 .68278 m .38508 .68083 L .38246 .6816 L F
.38143 .68278 m .38291 .68445 L .38508 .68083 L F
.911 .976 .785 r
.38508 .68083 m .38629 .67682 L .38367 .67839 L F
.952 .942 .733 r
.38246 .6816 m .38394 .67887 L .38352 .67879 L F
.476 .713 .973 r
.3798 .68113 m .38143 .68278 L .38246 .6816 L F
.3798 .68113 m .38246 .6816 L .38146 .68186 L F
.901 .935 .564 r
.38146 .68186 m .38352 .67879 L .38339 .67883 L F
.952 .942 .733 r
.38246 .6816 m .38508 .68083 L .38394 .67887 L F
.901 .935 .564 r
.38185 .68129 m .38277 .68077 L .38352 .67879 L F
.38339 .67883 m .38352 .67879 L .38367 .67839 L F
.38146 .68186 m .38367 .67839 L .38378 .67926 L F
.962 .871 .7 r
.38146 .68186 m .38378 .67926 L .38207 .67874 L F
.901 .935 .564 r
.38146 .68186 m .38246 .6816 L .38277 .68077 L F
.38146 .68186 m .38277 .68077 L .38185 .68129 L F
.962 .871 .7 r
.38146 .68186 m .38441 .68109 L .38181 .68143 L F
.38146 .68186 m .38181 .68143 L .38046 .6816 L F
.38146 .68186 m .38181 .68143 L .38306 .68172 L F
.154 0 0 r
.38181 .68143 m .38292 .68128 L .38234 .68146 L F
.38292 .68128 m .38441 .68109 L .38294 .68135 L F
.38292 .68128 m .38294 .68135 L .38234 .68146 L F
.962 .871 .7 r
.38146 .68186 m .38306 .68172 L .38441 .68109 L F
0 .025 .557 r
.38495 .68143 m .38689 .68369 L .3848 .6815 L F
.38495 .68143 m .3848 .6815 L .38441 .68109 L F
.673 .654 .824 r
.38608 .68057 m .38689 .68369 L .38495 .68143 L F
.092 0 0 r
.38506 .68139 m .38495 .68143 L .38608 .68057 L F
.38436 .68194 m .38495 .68143 L .38506 .68139 L F
.067 0 0 r
.38495 .68143 m .38441 .68109 L .38306 .68172 L F
.154 0 0 r
.38234 .68146 m .38441 .68109 L .3844 .68124 L F
.067 0 0 r
.38495 .68143 m .3846 .68148 L .38536 .67758 L F
.092 0 0 r
.38436 .68194 m .38439 .68149 L .38495 .68143 L F
.38439 .68149 m .38441 .68109 L .38495 .68143 L F
.067 0 0 r
.3846 .68148 m .38306 .68172 L .38312 .68161 L F
.38439 .68149 m .38312 .68161 L .38319 .68149 L F
.3846 .68148 m .38312 .68161 L .38439 .68149 L F
.154 0 0 r
.38319 .68149 m .3844 .68124 L .38439 .68149 L F
.38234 .68146 m .3844 .68124 L .38316 .6815 L F
.067 0 0 r
.3846 .68148 m .38319 .68149 L .38536 .67758 L F
.154 0 0 r
.38316 .6815 m .38319 .68149 L .38438 .68157 L F
.38319 .68149 m .38439 .68149 L .38438 .68157 L F
.71 .384 .424 r
.38367 .67839 m .38179 .67736 L .38378 .67926 L F
.878 .891 .838 r
.38536 .67758 m .38319 .68149 L .38247 .67995 L F
.962 .871 .7 r
.38181 .68143 m .38299 .68149 L .38306 .68172 L F
.672 .367 0 r
.383 .68153 m .38306 .68172 L .38299 .68149 L F
.878 .891 .838 r
.38319 .68149 m .38306 .68172 L .383 .68153 L F
.962 .871 .7 r
.38181 .68143 m .38207 .67874 L .38263 .68042 L F
.672 .367 0 r
.38247 .67995 m .383 .68153 L .38207 .67874 L F
.962 .871 .7 r
.38181 .68143 m .38263 .68042 L .38299 .68149 L F
.672 .367 0 r
.383 .68153 m .38299 .68149 L .38207 .67874 L F
.878 .891 .838 r
.38319 .68149 m .383 .68153 L .38247 .67995 L F
.154 0 0 r
.38153 .68146 m .38181 .68143 L .38117 .68167 L F
.962 .871 .7 r
.38146 .68186 m .38155 .68141 L .38181 .68143 L F
.154 0 0 r
.38181 .68143 m .38234 .68146 L .38117 .68167 L F
.38117 .68167 m .38234 .68146 L .38436 .68194 L F
.38234 .68146 m .38438 .68157 L .38436 .68194 L F
.962 .871 .7 r
.38155 .68141 m .38207 .67874 L .38181 .68143 L F
.154 0 0 r
.38046 .6816 m .38153 .68146 L .38117 .68167 L F
.705 .168 0 r
.38207 .67874 m .38288 .67898 L .38324 .67874 L F
.38288 .67898 m .38378 .67926 L .38334 .67884 L F
.38288 .67898 m .38334 .67884 L .38324 .67874 L F
.38203 .67852 m .38324 .67874 L .38179 .67736 L F
.38207 .67874 m .38324 .67874 L .38203 .67852 L F
.952 .942 .733 r
.38352 .67879 m .38394 .67887 L .38367 .67839 L F
.839 .792 .807 r
.33455 .63489 m .337 .63228 L .33471 .633 L F
.721 .414 .458 r
.51954 .46586 m .52206 .46806 L .51946 .46858 L F
.307 0 0 r
.43924 .5984 m .44076 .59794 L .44221 .59852 L F
.8 .753 .81 r
.53251 .4044 m .53316 .40773 L .52973 .40729 L F
.831 .554 .52 r
.53348 .40998 m .52973 .40729 L .53316 .40773 L F
.534 .345 .57 r
.62326 .35973 m .62622 .35946 L .62583 .35633 L F
0 0 0 r
.62326 .35973 m .62583 .35633 L .62446 .3594 L F
.62326 .35973 m .62446 .3594 L .62175 .35857 L F
.079 0 0 r
.6248 .36011 m .62622 .35946 L .62326 .35973 L F
.6248 .36011 m .62326 .35973 L .62175 .35857 L F
.983 .739 .488 r
.60913 .44488 m .61083 .44326 L .60918 .44215 L F
.60913 .44488 m .61057 .44593 L .61083 .44326 L F
0 0 0 r
.37861 .665 m .37665 .66863 L .37661 .66888 L F
.37861 .665 m .37661 .66888 L .37698 .66405 L F
0 0 .121 r
.37956 .66181 m .37861 .665 L .37698 .66405 L F
.852 .969 .65 r
.69871 .35894 m .70019 .35691 L .69873 .35779 L F
.748 .814 .342 r
.70096 .3543 m .70019 .35691 L .70175 .35281 L F
.842 .97 .653 r
.69873 .35779 m .70019 .35691 L .70096 .3543 L F
0 .403 .821 r
.32829 .52914 m .33251 .53126 L .32944 .53053 L F
.647 .905 .982 r
.62714 .35412 m .62583 .35633 L .62865 .35499 L F
.243 0 0 r
.62802 .3579 m .62583 .35633 L .62622 .35946 L F
0 0 0 r
.62446 .3594 m .62583 .35633 L .62714 .35412 L F
.834 .908 .888 r
.53621 .40295 m .53251 .4044 L .53384 .40226 L F
.702 .928 .965 r
.53621 .40295 m .53736 .40085 L .53769 .40199 L F
.53531 .40269 m .53384 .40226 L .53736 .40085 L F
0 0 0 r
.53384 .40226 m .53571 .40177 L .53736 .40085 L F
.246 0 .002 r
.53571 .40177 m .53896 .39941 L .53736 .40085 L F
.53896 .39941 m .53941 .39908 L .53736 .40085 L F
.702 .928 .965 r
.53621 .40295 m .53531 .40269 L .53736 .40085 L F
.625 .579 .782 r
.42114 .51019 m .4223 .51346 L .42412 .51038 L F
.985 .715 .42 r
.42386 .50961 m .42513 .51333 L .42512 .51068 L F
.625 .579 .782 r
.42411 .51033 m .42412 .51038 L .42415 .51034 L F
.42114 .51019 m .42412 .51038 L .42411 .51033 L F
.709 .626 .762 r
.42114 .51019 m .41885 .51422 L .4223 .51346 L F
.354 .046 .298 r
.41885 .51422 m .42183 .51366 L .4223 .51346 L F
.985 .715 .42 r
.42403 .51047 m .42513 .51335 L .42513 .51333 L F
.42402 .51047 m .42513 .51335 L .42403 .51047 L F
.778 .938 .586 r
.4223 .51346 m .42229 .51347 L .42411 .51039 L F
.42229 .51347 m .42387 .51074 L .42411 .51039 L F
.4223 .51346 m .42411 .51039 L .42412 .51038 L F
.985 .715 .42 r
.42362 .5094 m .42397 .51008 L .42386 .50961 L F
.595 .654 .878 r
.42362 .5094 m .42415 .51034 L .42411 .51033 L F
.42362 .5094 m .42411 .51033 L .42114 .51019 L F
.985 .715 .42 r
.42362 .5094 m .42413 .51073 L .42397 .51008 L F
.42413 .51073 m .42513 .51333 L .42411 .51033 L F
.42413 .51073 m .42411 .51033 L .42386 .50961 L F
.632 .425 .583 r
.42411 .51033 m .42183 .51366 L .42114 .51019 L F
.42415 .51034 m .42411 .51039 L .42411 .51033 L F
.42411 .51039 m .42183 .51366 L .42411 .51033 L F
0 0 .385 r
.42512 .51068 m .42513 .51335 L .426 .51107 L F
.629 .603 .805 r
.426 .51107 m .42513 .51335 L .42402 .51047 L F
.985 .715 .42 r
.42362 .5094 m .42402 .51047 L .42403 .51047 L F
.629 .603 .805 r
.42435 .50991 m .42402 .51047 L .42362 .5094 L F
.778 .938 .586 r
.42412 .51038 m .42411 .51039 L .42415 .51034 L F
.629 .603 .805 r
.426 .51107 m .42402 .51047 L .42435 .50991 L F
.778 .938 .586 r
.42229 .51347 m .42183 .51366 L .42387 .51074 L F
.836 .938 .893 r
.66168 .38926 m .66299 .39059 L .66573 .38774 L F
.065 .208 .703 r
.35218 .54287 m .35426 .54492 L .353 .54116 L F
.453 .263 .532 r
.35218 .54287 m .35194 .54583 L .35426 .54492 L F
.372 0 0 r
.60003 .45505 m .6038 .4554 L .59954 .45552 L F
.454 .309 .594 r
.46911 .51675 m .46712 .52022 L .46684 .51746 L F
.228 0 0 r
.45844 .59 m .45483 .59263 L .45616 .59059 L F
.702 .407 0 r
.33267 .62465 m .33369 .628 L .3323 .6234 L F
.963 .759 .581 r
.33319 .62907 m .33369 .628 L .33267 .62465 L F
0 .074 .614 r
.3323 .6234 m .33369 .628 L .33405 .62487 L F
.885 .892 .47 r
.33405 .62487 m .33369 .628 L .33319 .62907 L F
.505 .27 .492 r
.2798 .56515 m .282 .5674 L .2822 .56465 L F
.2798 .56515 m .27951 .56792 L .282 .5674 L F
.575 .887 .608 r
.37867 .63007 m .37809 .63093 L .37933 .62944 L F
0 .122 .672 r
.37809 .63093 m .37762 .63161 L .37691 .62984 L F
.575 .887 .608 r
.37678 .63188 m .37809 .63093 L .37867 .63007 L F
0 .122 .672 r
.37809 .63093 m .37802 .63262 L .37762 .63161 L F
.858 .974 .664 r
.376 .63423 m .37802 .63262 L .37809 .63093 L F
.054 0 0 r
.43137 .58981 m .43403 .5899 L .43479 .58984 L F
.826 .763 .793 r
.4399 .5835 m .4377 .58698 L .43695 .58498 L F
.43763 .58362 m .43695 .58498 L .43646 .58368 L F
.4399 .5835 m .43695 .58498 L .43763 .58362 L F
0 .045 .613 r
.43646 .58368 m .43695 .58498 L .43702 .58369 L F
.43695 .58498 m .4377 .58698 L .43702 .58369 L F
.852 .943 .579 r
.43551 .58786 m .43403 .5899 L .43702 .58369 L F
.43479 .58984 m .43451 .58986 L .43551 .58786 L F
.43451 .58986 m .43403 .5899 L .43551 .58786 L F
.43479 .58984 m .43702 .58369 L .4377 .58698 L F
.185 .222 .667 r
.33693 .51717 m .33808 .51613 L .33745 .51262 L F
0 0 0 r
.33693 .51717 m .33557 .51927 L .33808 .51613 L F
.818 .81 .843 r
.54861 .40481 m .54947 .40512 L .54805 .4054 L F
.7 .342 .365 r
.54269 .40648 m .54805 .4054 L .54482 .40869 L F
.54805 .4054 m .54947 .40512 L .54841 .40593 L F
.54805 .4054 m .54841 .40593 L .54482 .40869 L F
.818 .81 .843 r
.54511 .40355 m .54861 .40481 L .54269 .40648 L F
.54861 .40481 m .54805 .4054 L .54269 .40648 L F
.785 .472 .459 r
.54482 .40869 m .54947 .40512 L .54876 .40736 L F
.899 .608 .487 r
.54876 .40736 m .54947 .40512 L .54511 .40355 L F
.492 .293 .538 r
.55166 .40361 m .54909 .40694 L .54901 .40437 L F
.54909 .40694 m .54876 .40736 L .54883 .40656 L F
.54909 .40694 m .54883 .40656 L .54901 .40437 L F
.54958 .40377 m .54901 .40437 L .54906 .40381 L F
.55166 .40361 m .54901 .40437 L .54958 .40377 L F
.811 .877 .895 r
.26517 .52163 m .27 .52038 L .26851 .52018 L F
.811 .984 .888 r
.27072 .51786 m .27 .52038 L .27229 .52056 L F
.27072 .51786 m .26851 .52018 L .27 .52038 L F
.49 .171 .353 r
.29714 .63767 m .29527 .63607 L .29487 .63873 L F
.29714 .63767 m .29783 .63581 L .29527 .63607 L F
.144 .45 .881 r
.25567 .62314 m .25616 .62163 L .25471 .62141 L F
0 .143 .683 r
.25567 .62314 m .25777 .62536 L .25616 .62163 L F
.174 .255 .708 r
.72767 .32125 m .72509 .32151 L .72529 .31932 L F
0 0 .276 r
.7294 .31828 m .72891 .32059 L .72767 .32125 L F
.72965 .31786 m .72954 .31826 L .7294 .31828 L F
.72954 .31826 m .72891 .32059 L .7294 .31828 L F
.006 0 .286 r
.73119 .31821 m .73087 .31813 L .73245 .31753 L F
0 0 0 r
.72954 .31826 m .73155 .31787 L .73245 .31753 L F
.006 0 .286 r
.73119 .31821 m .72905 .32052 L .72956 .31826 L F
0 0 0 r
.72956 .31826 m .7319 .31781 L .72954 .31826 L F
.72967 .31825 m .7319 .31781 L .72956 .31826 L F
.72954 .31826 m .73245 .31753 L .72965 .31786 L F
.006 0 .286 r
.73152 .31788 m .72965 .31786 L .73245 .31753 L F
.73001 .31794 m .72965 .31786 L .73152 .31788 L F
0 0 0 r
.7319 .31781 m .73255 .31768 L .73191 .3178 L F
.7319 .31781 m .73191 .3178 L .72954 .31826 L F
.46 .558 .868 r
.73181 .31626 m .73242 .31742 L .72967 .31825 L F
0 0 0 r
.73155 .31787 m .73255 .31768 L .73245 .31753 L F
.46 .558 .868 r
.73242 .31742 m .73255 .31768 L .7319 .31781 L F
.73242 .31742 m .7319 .31781 L .72967 .31825 L F
.465 .854 .649 r
.73425 .31611 m .73314 .31691 L .73245 .31753 L F
.73328 .31678 m .7319 .31781 L .73245 .31753 L F
0 0 0 r
.73245 .31753 m .73425 .31611 L .73519 .31675 L F
.465 .854 .649 r
.73425 .31611 m .73245 .31753 L .73519 .31675 L F
0 0 0 r
.73245 .31753 m .73255 .31768 L .73425 .31611 L F
.618 .642 .852 r
.73425 .31611 m .73255 .31768 L .73242 .31742 L F
.73425 .31611 m .73242 .31742 L .73017 .3131 L F
.465 .854 .649 r
.73425 .31611 m .73328 .31678 L .73314 .31691 L F
.73328 .31678 m .73142 .31805 L .7319 .31781 L F
.006 0 .286 r
.73087 .31813 m .73001 .31794 L .73152 .31788 L F
.46 .558 .868 r
.73178 .3162 m .73181 .31626 L .73 .31794 L F
.006 0 .286 r
.72967 .31825 m .72956 .31826 L .73001 .31794 L F
.46 .558 .868 r
.72998 .31794 m .73 .31794 L .72966 .31825 L F
.73178 .3162 m .73 .31794 L .72998 .31794 L F
.73181 .31626 m .72967 .31825 L .72966 .31825 L F
.006 0 .286 r
.73001 .31794 m .72956 .31826 L .72965 .31786 L F
.73087 .31813 m .72967 .31825 L .73001 .31794 L F
.73119 .31821 m .72956 .31826 L .73087 .31813 L F
0 0 0 r
.72966 .31825 m .72967 .31825 L .72956 .31826 L F
.465 .854 .649 r
.73142 .31805 m .73119 .31821 L .73245 .31753 L F
0 0 0 r
.72929 .31833 m .72966 .31825 L .72954 .31826 L F
.72929 .31833 m .72954 .31826 L .72965 .31786 L F
.17 .387 .832 r
.7261 .31492 m .72889 .31796 L .72585 .31517 L F
.7268 .31423 m .72881 .31781 L .7261 .31492 L F
.72881 .31781 m .72889 .31796 L .7261 .31492 L F
0 0 .276 r
.72965 .31786 m .72923 .31857 L .72881 .31781 L F
.722 .541 .646 r
.72929 .31833 m .72965 .31786 L .72881 .31781 L F
.72889 .31796 m .72583 .31765 L .72585 .31517 L F
0 0 .276 r
.72881 .31781 m .72876 .31795 L .72583 .31765 L F
.72876 .31795 m .72767 .32125 L .72583 .31765 L F
.72923 .31857 m .72767 .32125 L .72881 .31781 L F
.722 .541 .646 r
.72929 .31833 m .72583 .31765 L .72889 .31796 L F
.72929 .31833 m .72881 .31781 L .72583 .31765 L F
.17 .387 .832 r
.72731 .31371 m .72929 .31833 L .72889 .31796 L F
.72731 .31371 m .72889 .31796 L .7268 .31423 L F
.46 .558 .868 r
.73017 .3131 m .73178 .3162 L .72929 .31833 L F
0 0 .276 r
.72965 .31786 m .72953 .31838 L .7295 .31841 L F
.46 .558 .868 r
.73178 .3162 m .72966 .31825 L .72929 .31833 L F
0 0 .276 r
.7295 .31841 m .72905 .32052 L .72891 .32059 L F
.72953 .31838 m .72905 .32052 L .7295 .31841 L F
.605 .953 .837 r
.72905 .32052 m .72902 .32053 L .72767 .32125 L F
.174 .255 .708 r
.72767 .32125 m .72594 .32216 L .72509 .32151 L F
.605 .953 .837 r
.72902 .32053 m .72566 .32228 L .72767 .32125 L F
.174 .255 .708 r
.72767 .32125 m .72769 .32352 L .72594 .32216 L F
0 0 0 r
.23377 .54214 m .23273 .54444 L .2327 .5444 L F
.883 .892 .47 r
.23253 .54359 m .23273 .54444 L .23377 .54214 L F
.85 .46 .305 r
.23277 .54449 m .23273 .54444 L .23253 .54359 L F
.31 .633 .964 r
.23273 .54444 m .23419 .54583 L .23203 .5458 L F
0 .271 .764 r
.23389 .54469 m .23419 .54583 L .23273 .54444 L F
.85 .46 .305 r
.23313 .5459 m .23389 .54469 L .23273 .54444 L F
.23313 .5459 m .23273 .54444 L .23277 .54449 L F
0 0 0 r
.2327 .5444 m .23273 .54444 L .23203 .5458 L F
.288 .124 .477 r
.34658 .53611 m .34631 .53881 L .34477 .53894 L F
.458 .444 .755 r
.34587 .54152 m .34477 .53894 L .34631 .53881 L F
.823 .724 .755 r
.68243 .35451 m .67852 .35556 L .68118 .35218 L F
.672 .784 .934 r
.68388 .3514 m .68243 .35451 L .68118 .35218 L F
.68388 .3514 m .68531 .35334 L .68243 .35451 L F
.703 .976 .771 r
.65643 .32477 m .65321 .32778 L .6546 .32569 L F
.705 .979 .787 r
.6546 .32569 m .65321 .32778 L .65157 .32828 L F
.728 .66 .106 r
.33811 .50321 m .33797 .5049 L .33815 .50332 L F
.045 .613 .755 r
.33811 .50321 m .33815 .50332 L .34134 .50327 L F
.818 .747 .786 r
.33269 .50653 m .3364 .50786 L .33737 .50654 L F
.814 .63 .653 r
.49041 .47514 m .48808 .47823 L .48845 .47529 L F
.946 .617 .374 r
.38265 .52259 m .38504 .52587 L .38381 .52406 L F
.949 .614 .204 r
.61159 .42262 m .61291 .4241 L .61329 .42649 L F
.687 .8 .338 r
.70096 .3543 m .70175 .35281 L .7029 .35002 L F
.063 0 0 r
.32063 .5527 m .32125 .55325 L .32242 .55417 L F
.32063 .5527 m .31842 .5538 L .32125 .55325 L F
.373 .201 .515 r
.32063 .5527 m .32242 .55417 L .3228 .55179 L F
.415 .456 .795 r
.34979 .55406 m .34785 .55615 L .34665 .55206 L F
.277 .249 .646 r
.34979 .55406 m .35011 .55805 L .34785 .55615 L F
.291 .039 .349 r
.49821 .47255 m .49685 .4748 L .49621 .47438 L F
.251 .096 .466 r
.49687 .47723 m .49621 .47438 L .49685 .4748 L F
.512 .87 .986 r
.33269 .50653 m .33737 .50654 L .33519 .5058 L F
.941 .881 .747 r
.33519 .5058 m .33737 .50654 L .33797 .5049 L F
.543 .398 .634 r
.46808 .50741 m .4684 .51078 L .46636 .51232 L F
.554 .385 .607 r
.46999 .5046 m .47062 .50717 L .46808 .50741 L F
.552 .402 .63 r
.47062 .50717 m .4684 .51078 L .46808 .50741 L F
.788 .542 .566 r
.30639 .52835 m .31069 .52622 L .30833 .52662 L F
.934 .7 .22 r
.39976 .56728 m .40039 .57086 L .40042 .56866 L F
0 .199 .713 r
.36607 .60697 m .36692 .60557 L .3647 .60354 L F
.154 .415 .857 r
.36607 .60697 m .37015 .60889 L .36692 .60557 L F
0 0 0 r
.26718 .54792 m .26515 .54917 L .26569 .54848 L F
.26718 .54792 m .26515 .54917 L .26569 .54848 L F
.989 .726 .373 r
.23934 .53831 m .23955 .54174 L .24073 .54256 L F
.396 .454 .803 r
.61586 .39332 m .61412 .39608 L .61321 .39412 L F
.61586 .39332 m .61712 .39726 L .61412 .39608 L F
.591 .288 .425 r
.45787 .5649 m .45636 .56756 L .45902 .56692 L F
.587 .425 .629 r
.45787 .5649 m .46083 .56378 L .4598 .56242 L F
.511 .26 .472 r
.45787 .5649 m .45902 .56692 L .46083 .56378 L F
.727 .638 .758 r
.35969 .56521 m .36401 .56611 L .36214 .56153 L F
.827 .752 .78 r
.35994 .568 m .36401 .56611 L .35969 .56521 L F
.35994 .568 m .36158 .56857 L .36401 .56611 L F
.023 .207 .715 r
.36214 .56153 m .36401 .56611 L .3645 .56389 L F
.254 .466 .872 r
.36401 .56611 m .36667 .5677 L .3645 .56389 L F
.636 .516 .701 r
.50967 .43701 m .50714 .4405 L .50594 .43668 L F
.50967 .43701 m .5097 .43958 L .50714 .4405 L F
0 .159 .636 r
.33386 .64108 m .33473 .64215 L .33599 .64307 L F
.33386 .64108 m .33599 .64307 L .3359 .64294 L F
.833 .975 .884 r
.33619 .64322 m .33929 .64148 L .33827 .64419 L F
0 .346 .789 r
.33566 .64234 m .33619 .64322 L .33827 .64419 L F
.33386 .64108 m .3359 .64294 L .33566 .64234 L F
.3359 .64294 m .33619 .64322 L .33566 .64234 L F
0 .159 .636 r
.3359 .64294 m .33599 .64307 L .33619 .64322 L F
0 .346 .789 r
.33386 .64108 m .33827 .64419 L .33412 .64362 L F
.33386 .64108 m .33412 .64362 L .33679 .6412 L F
.759 .993 .8 r
.33493 .64169 m .33535 .64158 L .33547 .64239 L F
.33535 .64158 m .33679 .6412 L .33562 .64226 L F
.33535 .64158 m .33562 .64226 L .33547 .64239 L F
.33486 .64171 m .33493 .64169 L .33412 .64362 L F
.33493 .64169 m .33547 .64239 L .33412 .64362 L F
.976 .688 .299 r
.38867 .53177 m .39003 .53576 L .38991 .53332 L F
.38867 .53177 m .39003 .53576 L .38991 .53332 L F
.272 .611 .956 r
.33836 .52667 m .34165 .52724 L .34114 .52866 L F
.187 0 0 r
.33752 .52672 m .34004 .52704 L .33836 .52667 L F
.34004 .52704 m .34165 .52724 L .33836 .52667 L F
.038 .477 .882 r
.33836 .52667 m .33833 .52768 L .33696 .52636 L F
.33836 .52667 m .33696 .52636 L .33675 .52615 L F
.33836 .52667 m .34114 .52866 L .33833 .52768 L F
.845 .75 .758 r
.37783 .69059 m .37607 .68693 L .37596 .69021 L F
.624 .06 0 r
.37951 .69212 m .37783 .69059 L .37596 .69021 L F
.458 .444 .755 r
.34587 .54152 m .34631 .53881 L .34649 .54154 L F
.983 .884 .649 r
.34391 .54362 m .34459 .54475 L .34587 .54152 L F
.34391 .54362 m .34587 .54152 L .34649 .54154 L F
.975 .728 .498 r
.38719 .66694 m .38925 .6677 L .38763 .6644 L F
.971 .7 .457 r
.38871 .67132 m .38925 .6677 L .38719 .66694 L F
.514 .581 .86 r
.38763 .6644 m .38925 .6677 L .39175 .66746 L F
.098 .247 .73 r
.28665 .63779 m .28564 .6396 L .28446 .63581 L F
.634 .177 0 r
.28622 .64075 m .28655 .64094 L .28564 .6396 L F
.28622 .64075 m .28564 .6396 L .28665 .63779 L F
.972 .83 .418 r
.69222 .30868 m .69127 .3095 L .69175 .3104 L F
.81 .997 .857 r
.68848 .31237 m .69175 .3104 L .69127 .3095 L F
.589 .88 .575 r
.69127 .3095 m .69015 .31038 L .68848 .31237 L F
.567 .012 0 r
.69398 .31102 m .69023 .31039 L .69127 .3095 L F
.69023 .31039 m .69015 .31038 L .69127 .3095 L F
.972 .83 .418 r
.69233 .30827 m .69127 .3095 L .69222 .30868 L F
.134 0 0 r
.69529 .30722 m .69127 .3095 L .69233 .30827 L F
.984 .711 .415 r
.58197 .37807 m .57962 .37918 L .5808 .37628 L F
.58197 .37807 m .5812 .38031 L .57962 .37918 L F
.358 .728 .988 r
.58277 .37688 m .58484 .37916 L .58197 .37807 L F
.789 .983 .9 r
.44833 .51569 m .44707 .51752 L .4485 .51676 L F
0 0 0 r
.4485 .51676 m .45127 .515 L .44833 .51569 L F
0 0 .464 r
.4485 .51676 m .45027 .51683 L .4512 .51513 L F
.342 .407 .784 r
.44901 .52228 m .45216 .52206 L .45032 .51691 L F
.669 .333 .396 r
.45031 .5169 m .45029 .51689 L .45041 .5166 L F
.342 .407 .784 r
.45028 .51688 m .45032 .51691 L .45029 .51683 L F
.44901 .52228 m .45032 .51691 L .45028 .51688 L F
.669 .333 .396 r
.45374 .51473 m .45031 .5169 L .45041 .5166 L F
.45031 .5169 m .45028 .51692 L .45029 .51689 L F
0 0 .464 r
.4485 .51676 m .44941 .51973 L .45028 .51686 L F
.669 .333 .396 r
.45028 .51686 m .45027 .51683 L .45029 .5168 L F
0 0 .464 r
.45027 .51683 m .45028 .51686 L .45029 .51683 L F
.4485 .51676 m .45028 .51686 L .45027 .51683 L F
.669 .333 .396 r
.45028 .51692 m .45018 .51698 L .45027 .51683 L F
.45028 .51692 m .45027 .51683 L .45028 .51686 L F
.45028 .51692 m .45029 .5168 L .45041 .5166 L F
.342 .407 .784 r
.44901 .52228 m .45028 .51688 L .44941 .51973 L F
.45028 .51688 m .45029 .51683 L .45028 .51686 L F
.45028 .51688 m .45028 .51686 L .44941 .51973 L F
0 0 .464 r
.45027 .51683 m .45028 .51683 L .45041 .5166 L F
.45027 .51683 m .45041 .5166 L .4512 .51513 L F
.608 .571 .787 r
.45045 .51697 m .45216 .52206 L .45415 .52021 L F
.45042 .51696 m .45216 .52206 L .45045 .51697 L F
.45032 .51691 m .45216 .52206 L .45041 .51693 L F
.669 .333 .396 r
.45374 .51473 m .45306 .51742 L .45115 .51707 L F
.45374 .51473 m .45109 .51712 L .4503 .51691 L F
.608 .571 .787 r
.45029 .51683 m .45041 .51693 L .45306 .51742 L F
.681 .585 .741 r
.45306 .51742 m .45415 .52021 L .45609 .51704 L F
.907 .944 .818 r
.45609 .51704 m .45586 .5172 L .45306 .51742 L F
.608 .571 .787 r
.45113 .51757 m .45415 .52021 L .45306 .51742 L F
.907 .944 .818 r
.45586 .5172 m .45305 .51908 L .45306 .51742 L F
.608 .571 .787 r
.45041 .51693 m .45113 .51757 L .45306 .51742 L F
.669 .333 .396 r
.45115 .51707 m .45306 .51742 L .45109 .51712 L F
.63 .208 .223 r
.45109 .51712 m .45305 .51908 L .44981 .51693 L F
.45306 .51742 m .45306 .51758 L .45109 .51712 L F
.45306 .51758 m .45305 .51908 L .45109 .51712 L F
.608 .571 .787 r
.45041 .51693 m .45042 .51696 L .45045 .51697 L F
.45029 .51683 m .45032 .51691 L .45041 .51693 L F
.669 .333 .396 r
.4503 .51691 m .45109 .51712 L .45018 .51698 L F
.45041 .5166 m .45018 .51698 L .44981 .51693 L F
.077 .637 .704 r
.45374 .51473 m .44986 .51515 L .45127 .515 L F
.669 .333 .396 r
.45374 .51473 m .44984 .51605 L .45133 .51504 L F
0 0 0 r
.45127 .515 m .45133 .51504 L .45374 .51473 L F
.669 .333 .396 r
.45374 .51473 m .45133 .51504 L .45142 .51498 L F
0 0 0 r
.45133 .51504 m .45134 .51505 L .45374 .51473 L F
0 0 .464 r
.4512 .51513 m .45029 .51683 L .45134 .51505 L F
.669 .333 .396 r
.45374 .51473 m .45041 .5166 L .4509 .51569 L F
0 0 .464 r
.45028 .51683 m .45029 .51683 L .4512 .51513 L F
.669 .333 .396 r
.4509 .51569 m .44981 .51693 L .44984 .51605 L F
.45041 .5166 m .44981 .51693 L .4509 .51569 L F
0 0 0 r
.4485 .51676 m .4512 .51513 L .45127 .515 L F
.4512 .51513 m .45133 .51504 L .45127 .515 L F
.669 .333 .396 r
.45142 .51498 m .44984 .51605 L .44986 .51515 L F
0 0 0 r
.4512 .51513 m .45134 .51505 L .45133 .51504 L F
.15 .321 .781 r
.45484 .54902 m .45417 .54469 L .45178 .54539 L F
.45484 .54902 m .45577 .54853 L .45417 .54469 L F
.068 0 .085 r
.25301 .55806 m .25026 .5609 L .25132 .55834 L F
.889 .73 .679 r
.42878 .56665 m .43145 .5685 L .42993 .56482 L F
.923 .657 .515 r
.42878 .56665 m .42959 .56864 L .43145 .5685 L F
.626 .138 0 r
.42959 .56864 m .43196 .57131 L .43145 .5685 L F
.551 .08 .089 r
.37956 .66181 m .38451 .66121 L .38163 .66084 L F
.287 0 .123 r
.31609 .56039 m .31513 .55856 L .31751 .55785 L F
.31609 .56039 m .31375 .56119 L .31513 .55856 L F
.584 .834 .992 r
.36972 .70748 m .3712 .70905 L .37294 .70805 L F
0 0 .378 r
.33985 .65577 m .3404 .6586 L .33921 .65478 L F
.975 .924 .636 r
.33932 .65848 m .3404 .6586 L .33985 .65577 L F
.153 0 .135 r
.36826 .58777 m .37117 .58493 L .37036 .58721 L F
.182 0 .147 r
.37036 .58721 m .37117 .58493 L .37333 .58392 L F
.662 .973 .879 r
.23562 .53269 m .23639 .53117 L .23907 .53074 L F
.23562 .53269 m .23445 .53267 L .23639 .53117 L F
.574 .425 .641 r
.48022 .48795 m .48026 .49074 L .47776 .49119 L F
.506 .38 .644 r
.48031 .49351 m .47776 .49119 L .48026 .49074 L F
.48031 .49351 m .47819 .49441 L .47776 .49119 L F
.952 .607 .227 r
.42972 .58188 m .43002 .58436 L .42839 .58265 L F
.416 .098 .315 r
.33303 .61053 m .33292 .61266 L .32986 .61298 L F
.821 .444 .341 r
.33303 .61053 m .335 .61315 L .33292 .61266 L F
.743 .977 .731 r
.66244 .37413 m .66064 .37615 L .65887 .37777 L F
.583 .185 .253 r
.34931 .5091 m .34572 .50943 L .34749 .50749 L F
.701 .267 .215 r
.37165 .63564 m .37541 .63594 L .37406 .63806 L F
.73 .854 .423 r
.37406 .63806 m .37541 .63594 L .376 .63423 L F
.998 .8 .509 r
.61184 .45216 m .61229 .44957 L .61107 .44833 L F
.218 .341 .775 r
.47289 .56518 m .47556 .56694 L .47413 .56895 L F
0 .011 .561 r
.47592 .5696 m .47413 .56895 L .47556 .56694 L F
.47592 .5696 m .47504 .57119 L .47413 .56895 L F
.384 .116 .378 r
.3354 .58501 m .33412 .58719 L .33166 .58774 L F
.433 .24 .518 r
.33412 .58719 m .33373 .58988 L .33166 .58774 L F
.862 .539 .438 r
.39018 .53808 m .39241 .54095 L .39128 .53984 L F
.415 .458 .797 r
.44288 .54567 m .44588 .54835 L .44627 .54567 L F
.74 .482 .54 r
.44627 .54567 m .44895 .54813 L .44907 .54594 L F
.44627 .54567 m .44588 .54835 L .44895 .54813 L F
.802 .576 .595 r
.24827 .57346 m .25109 .57176 L .24757 .57239 L F
0 0 0 r
.24827 .57346 m .25109 .57176 L .25075 .57454 L F
.802 .576 .595 r
.24827 .57346 m .24923 .57306 L .25109 .57176 L F
.646 .606 .794 r
.25245 .57154 m .25075 .57454 L .25109 .57176 L F
0 0 0 r
.25245 .57154 m .25109 .57176 L .24923 .57306 L F
.494 .313 .564 r
.49864 .48108 m .49614 .48482 L .49598 .48187 L F
.368 .023 .242 r
.33973 .54654 m .33832 .54881 L .33616 .54916 L F
.534 .501 .765 r
.33967 .54838 m .34109 .54498 L .33973 .54654 L F
.33965 .54898 m .33984 .54844 L .33967 .54838 L F
.33984 .54844 m .34109 .54498 L .33967 .54838 L F
.33965 .54898 m .34277 .54888 L .34121 .54526 L F
.34087 .5456 m .34121 .54526 L .34109 .54498 L F
.33965 .54898 m .34121 .54526 L .34087 .5456 L F
0 0 0 r
.3404 .54724 m .33832 .54881 L .33942 .54703 L F
.33982 .54663 m .33942 .54703 L .33973 .54654 L F
.3404 .54724 m .33942 .54703 L .33982 .54663 L F
.721 .632 .757 r
.34277 .54888 m .3411 .55227 L .33832 .54881 L F
.34196 .54924 m .33832 .54881 L .34114 .54961 L F
.34277 .54888 m .34092 .54885 L .34196 .54924 L F
.34092 .54885 m .33832 .54881 L .34196 .54924 L F
0 0 0 r
.3404 .54724 m .33973 .54654 L .34109 .54498 L F
.615 .523 .727 r
.46636 .51232 m .4684 .51078 L .46881 .51316 L F
.042 0 .119 r
.28731 .5736 m .28792 .5718 L .28984 .57083 L F
.896 .977 .812 r
.58694 .4537 m .58764 .45307 L .589 .4545 L F
.936 .744 .618 r
.59143 .45242 m .589 .4545 L .58764 .45307 L F
0 0 0 r
.28945 .51875 m .28797 .51917 L .28555 .51972 L F
.29038 .51856 m .28945 .51875 L .2928 .51762 L F
.29038 .51856 m .28797 .51917 L .28945 .51875 L F
.44 .878 .847 r
.23907 .53074 m .23892 .53012 L .24073 .52925 L F
.23907 .53074 m .23639 .53117 L .23892 .53012 L F
.997 .767 .449 r
.29555 .66736 m .29558 .67103 L .295 .66997 L F
.205 0 .2 r
.29733 .66724 m .29555 .66736 L .295 .66997 L F
.451 0 0 r
.3385 .64223 m .33679 .6412 L .33486 .64171 L F
.79 .796 .302 r
.33827 .64419 m .33929 .64148 L .33893 .64156 L F
.597 .732 .939 r
.33876 .64201 m .33876 .6416 L .33679 .6412 L F
.79 .796 .302 r
.33871 .6419 m .33876 .64182 L .33876 .6416 L F
.33876 .64182 m .33893 .64156 L .33876 .6416 L F
.33868 .64203 m .33893 .64156 L .33871 .6419 L F
.33827 .64419 m .33882 .642 L .33868 .64203 L F
.33882 .642 m .33893 .64156 L .33868 .64203 L F
.597 .732 .939 r
.34113 .64298 m .33827 .64419 L .33868 .64203 L F
.34113 .64298 m .33876 .64201 L .33894 .64213 L F
.34113 .64298 m .33876 .6416 L .33876 .64201 L F
.34113 .64298 m .33868 .64203 L .33876 .6416 L F
.34113 .64298 m .33894 .64213 L .33927 .64234 L F
.33876 .64201 m .33679 .6412 L .33862 .64204 L F
.33876 .64201 m .33862 .64204 L .33927 .64234 L F
.451 0 0 r
.33927 .64234 m .33862 .64204 L .3385 .64223 L F
.33862 .64204 m .33679 .6412 L .3385 .64223 L F
0 0 0 r
.37661 .66888 m .37501 .67038 L .3771 .66934 L F
.37661 .66888 m .37665 .66863 L .37501 .67038 L F
.027 .006 .493 r
.3771 .66934 m .37501 .67038 L .37628 .67278 L F
.441 .392 .707 r
.37157 .52335 m .37203 .52695 L .37418 .52589 L F
.729 .654 .774 r
.37173 .52967 m .37418 .52589 L .37203 .52695 L F
.616 .139 .098 r
.31632 .62585 m .32003 .62588 L .31827 .62737 L F
.308 0 0 r
.32003 .62588 m .32055 .6274 L .31827 .62737 L F
.32003 .62588 m .32303 .62535 L .32055 .6274 L F
.81 .808 .849 r
.37917 .68465 m .38291 .68445 L .38143 .68278 L F
.702 .605 .745 r
.33653 .5519 m .33313 .5542 L .33393 .55258 L F
.52 .397 .653 r
.4298 .4869 m .43 .49064 L .42729 .49095 L F
.714 .181 0 r
.396 .51732 m .39416 .51692 L .39181 .51464 L F
.627 .063 0 r
.396 .51732 m .39514 .51785 L .39416 .51692 L F
.847 .391 0 r
.396 .51732 m .39698 .51935 L .39514 .51785 L F
0 0 0 r
.44304 .57721 m .44023 .58129 L .44184 .57972 L F
.44304 .57721 m .44184 .57972 L .4423 .57717 L F
.996 .76 .433 r
.60452 .43228 m .60443 .4351 L .60574 .43362 L F
.865 .458 .258 r
.60443 .4351 m .60652 .43572 L .60574 .43362 L F
.996 .76 .433 r
.60452 .43228 m .60443 .4351 L .60574 .43362 L F
.549 .421 .659 r
.47246 .50031 m .46999 .5046 L .46982 .50103 L F
.47246 .50031 m .47289 .50419 L .46999 .5046 L F
.522 .354 .594 r
.47289 .50419 m .47062 .50717 L .46999 .5046 L F
.514 0 0 r
.29916 .62313 m .29516 .62311 L .29695 .62461 L F
.919 .743 .647 r
.29916 .62313 m .2987 .62607 L .29731 .62428 L F
.427 .276 .573 r
.29916 .62313 m .30139 .62599 L .2987 .62607 L F
.819 .542 .52 r
.2987 .62607 m .2944 .62813 L .29731 .62428 L F
.772 .293 .098 r
.29948 .6254 m .29916 .62313 L .29695 .62461 L F
.29948 .6254 m .30139 .62599 L .29916 .62313 L F
.077 .233 .724 r
.34581 .68701 m .34693 .69054 L .34829 .68948 L F
0 0 0 r
.34693 .69054 m .34614 .69153 L .34829 .68948 L F
.764 .723 .815 r
.63288 .38427 m .63546 .38533 L .63194 .38548 L F
.768 .593 .661 r
.63194 .38548 m .63546 .38533 L .6335 .38812 L F
.89 .788 .741 r
.63546 .38533 m .63499 .38663 L .6335 .38812 L F
.597 .726 .934 r
.63633 .38187 m .63546 .38533 L .63288 .38427 L F
.63633 .38187 m .6385 .3853 L .63546 .38533 L F
.606 .287 .404 r
.63546 .38533 m .63845 .38759 L .63499 .38663 L F
.63546 .38533 m .6385 .3853 L .63845 .38759 L F
.503 .307 .548 r
.2145 .60388 m .217 .60383 L .21707 .60062 L F
.941 .881 .747 r
.33519 .5058 m .33797 .5049 L .33811 .50321 L F
.57 .677 .912 r
.36793 .54289 m .36548 .54375 L .36362 .54127 L F
0 0 0 r
.61563 .37473 m .61305 .3797 L .61682 .37842 L F
.457 .792 .999 r
.58643 .36222 m .59043 .36289 L .58912 .36175 L F
.849 .491 0 r
.36344 .62924 m .36515 .6332 L .36439 .63308 L F
0 0 .235 r
.36515 .6332 m .36741 .62909 L .36439 .63308 L F
.789 .836 .888 r
.42353 .47297 m .42066 .47523 L .41921 .4739 L F
.785 .736 .807 r
.35938 .71201 m .36298 .70928 L .35904 .70575 L F
.356 .614 .948 r
.35904 .70575 m .36298 .70928 L .36384 .70832 L F
.396 .707 .985 r
.36298 .70928 m .36488 .70963 L .36384 .70832 L F
0 0 .44 r
.38847 .51049 m .39043 .51306 L .38922 .5114 L F
.548 .897 .978 r
.25941 .51885 m .26001 .51728 L .2621 .51764 L F
.25941 .51885 m .25744 .51828 L .26001 .51728 L F
.834 .85 .858 r
.33849 .6386 m .33947 .63958 L .33935 .63455 L F
.212 0 .034 r
.33947 .63958 m .3453 .63621 L .34386 .63574 L F
.936 .702 .559 r
.35349 .58422 m .35505 .58737 L .35327 .58663 L F
.883 .865 .817 r
.35505 .58737 m .35119 .5888 L .35327 .58663 L F
.644 .364 .479 r
.35505 .58737 m .35753 .59009 L .35776 .58773 L F
.35776 .58773 m .35753 .59009 L .35505 .58737 L F
.829 .355 .025 r
.60456 .40702 m .60642 .40798 L .60562 .40894 L F
.827 .351 .023 r
.60562 .40894 m .60642 .40798 L .60751 .41 L F
0 0 0 r
.3979 .55689 m .39794 .55561 L .39784 .55448 L F
.3979 .55689 m .39763 .55857 L .39794 .55561 L F
.896 .49 .077 r
.39607 .55039 m .39666 .5493 L .39624 .54801 L F
.39607 .55039 m .39753 .55166 L .39666 .5493 L F
.805 .72 .771 r
.48313 .44495 m .48497 .44673 L .48141 .44639 L F
.819 .836 .862 r
.48618 .44229 m .48497 .44673 L .48313 .44495 L F
.48618 .44229 m .48807 .44382 L .48497 .44673 L F
.75 .684 .788 r
.48807 .44382 m .48731 .4453 L .48497 .44673 L F
.664 .963 .762 r
.62431 .36697 m .62387 .3682 L .62722 .36526 L F
.37 .023 .241 r
.6335 .38812 m .63499 .38663 L .6338 .38874 L F
.515 .172 .324 r
.63499 .38663 m .63845 .38759 L .6338 .38874 L F
.734 .861 .94 r
.4705 .44869 m .46894 .45207 L .46737 .45073 L F
.4705 .44869 m .47208 .45007 L .46894 .45207 L F
.585 .402 .599 r
.4894 .47352 m .49068 .47229 L .48845 .47529 L F
.838 .692 .702 r
.61178 .38761 m .61343 .39144 L .615 .38785 L F
.005 .525 .856 r
.25958 .62629 m .25976 .62578 L .25777 .62536 L F
.25958 .62629 m .26122 .62663 L .25976 .62578 L F
.532 .681 .934 r
.72422 .31504 m .72123 .31704 L .72059 .31716 L F
.72422 .31504 m .72502 .31719 L .72123 .31704 L F
.37 .635 .957 r
.38841 .67603 m .38831 .67413 L .38629 .67682 L F
.38841 .67603 m .39129 .67694 L .38831 .67413 L F
.645 .733 .913 r
.41427 .47829 m .41195 .47962 L .40866 .47596 L F
.888 .594 .084 r
.70302 .28652 m .70328 .28495 L .70293 .28396 L F
.70302 .28652 m .70394 .28864 L .70328 .28495 L F
.9 .946 .827 r
.70328 .28495 m .70491 .28038 L .70293 .28396 L F
.964 .901 .71 r
.38625 .62337 m .38797 .6196 L .38664 .6186 L F
.762 .939 .941 r
.34407 .57027 m .34219 .56977 L .3447 .56747 L F
.065 0 .336 r
.46214 .5583 m .4598 .56242 L .46213 .56114 L F
0 0 .554 r
.4598 .56242 m .46122 .56338 L .46213 .56114 L F
.475 .22 .448 r
.46083 .56378 m .45902 .56692 L .46122 .56497 L F
.834 .422 .261 r
.46083 .56378 m .46122 .56497 L .4598 .56242 L F
0 0 .554 r
.4598 .56242 m .46122 .56497 L .46122 .56338 L F
.126 0 .324 r
.35831 .52718 m .36013 .52719 L .35708 .52541 L F
0 .274 .776 r
.38063 .61708 m .38244 .61928 L .38256 .6181 L F
.996 .846 .574 r
.38244 .61928 m .3803 .62163 L .38256 .6181 L F
.38244 .61928 m .38164 .6221 L .3803 .62163 L F
.916 .726 .631 r
.28899 .65504 m .29012 .65715 L .28838 .65821 L F
.647 .101 0 r
.28899 .65504 m .2928 .65806 L .29012 .65715 L F
.644 .238 .26 r
.29012 .65715 m .29076 .6604 L .28838 .65821 L F
.29012 .65715 m .2928 .65806 L .29076 .6604 L F
.613 .522 .728 r
.37036 .58721 m .36795 .59047 L .36826 .58777 L F
.582 .568 .803 r
.58179 .45532 m .58524 .46214 L .58763 .46107 L F
.819 .337 .018 r
.35945 .50303 m .36307 .50663 L .36254 .50457 L F
.536 .339 .561 r
.35197 .53201 m .34917 .53551 L .34965 .53293 L F
.654 .835 .97 r
.62979 .38337 m .63194 .38548 L .62915 .38637 L F
.239 .745 .7 r
.62915 .38637 m .63031 .38592 L .62979 .38337 L F
.62915 .38637 m .63194 .38548 L .63031 .38592 L F
.936 .665 .5 r
.2987 .62607 m .30042 .62956 L .29833 .6292 L F
.69 .601 .751 r
.30259 .62601 m .30042 .62956 L .2987 .62607 L F
.785 .736 .807 r
.35938 .71201 m .35904 .70575 L .35652 .70632 L F
.721 .98 .912 r
.59906 .35394 m .59544 .35609 L .59669 .35386 L F
.671 .969 .92 r
.60096 .35244 m .59906 .35394 L .59669 .35386 L F
.75 .724 .827 r
.63352 .42393 m .63778 .42442 L .63565 .42248 L F
.967 .85 .442 r
.63778 .42442 m .63806 .4189 L .63565 .42248 L F
.931 .749 .634 r
.34156 .6867 m .34342 .68777 L .34247 .68672 L F
.942 .955 .648 r
.34151 .68945 m .34342 .68777 L .34156 .6867 L F
.34151 .68945 m .34214 .69066 L .34342 .68777 L F
.848 .99 .848 r
.71126 .33856 m .71505 .33617 L .71393 .33539 L F
.638 .763 .938 r
.71505 .33617 m .71655 .33253 L .71393 .33539 L F
.71505 .33617 m .71796 .33537 L .71655 .33253 L F
0 0 .098 r
.22969 .60939 m .23 .60845 L .22996 .60612 L F
0 .124 .674 r
.22969 .60939 m .23091 .61032 L .23 .60845 L F
.666 .881 .978 r
.36787 .59611 m .36742 .59838 L .36964 .59712 L F
.397 0 0 r
.38132 .49982 m .38436 .49973 L .38576 .49801 L F
.782 .908 .514 r
.38576 .49801 m .38436 .49973 L .38659 .49549 L F
.219 .707 .927 r
.37418 .52589 m .36963 .5252 L .37157 .52335 L F
.473 0 0 r
.39133 .59311 m .38941 .59082 L .39149 .59102 L F
.293 .552 .923 r
.33221 .69299 m .33583 .69675 L .33644 .69583 L F
.592 .805 .399 r
.33583 .69675 m .33527 .69759 L .33644 .69583 L F
.438 .64 .942 r
.33527 .69759 m .33766 .69762 L .33644 .69583 L F
.495 .485 .776 r
.21707 .60062 m .21921 .60005 L .21811 .59609 L F
.45 .265 .538 r
.21707 .60062 m .21919 .60276 L .21921 .60005 L F
.21707 .60062 m .217 .60383 L .21919 .60276 L F
.978 .904 .667 r
.39767 .56363 m .39897 .56461 L .39988 .56223 L F
.857 .452 0 r
.39763 .55857 m .3988 .56128 L .39988 .56223 L F
.976 .912 .673 r
.39988 .56223 m .3988 .56128 L .39767 .56363 L F
.913 .906 .803 r
.60833 .37986 m .61084 .3764 L .60861 .37651 L F
.447 .868 .94 r
.61084 .3764 m .61118 .37559 L .60861 .37651 L F
.61084 .3764 m .61462 .37563 L .61118 .37559 L F
0 .426 .706 r
.34958 .49763 m .34873 .49747 L .3469 .49688 L F
.34958 .49763 m .35092 .49804 L .34873 .49747 L F
.5 .905 .81 r
.62386 .39741 m .62013 .39961 L .61934 .39928 L F
.593 .646 .872 r
.62386 .39741 m .62539 .40113 L .62013 .39961 L F
.674 .57 .729 r
.62013 .39961 m .62539 .40113 L .62251 .4019 L F
.327 .2 .55 r
.44524 .53973 m .4442 .54186 L .44262 .53961 L F
.408 .223 .516 r
.44262 .53961 m .4442 .54186 L .44183 .54194 L F
.768 .899 .934 r
.6814 .38176 m .68416 .37746 L .68017 .38051 L F
.6814 .38176 m .68494 .37935 L .68416 .37746 L F
.596 .159 .179 r
.54167 .47088 m .54309 .46895 L .54571 .4707 L F
.568 .838 .996 r
.60466 .35195 m .60596 .3499 L .60721 .35123 L F
.60466 .35195 m .60326 .35072 L .60596 .3499 L F
.546 .909 .961 r
.61118 .37559 m .61462 .37563 L .61563 .37473 L F
.563 .368 .575 r
.50089 .47815 m .5014 .48088 L .49864 .48108 L F
.567 .353 .549 r
.50486 .47794 m .5014 .48088 L .50089 .47815 L F
.739 .875 .943 r
.33653 .53438 m .33798 .53669 L .34059 .5356 L F
.484 .555 .853 r
.33653 .53438 m .33731 .53976 L .33798 .53669 L F
.266 .003 .316 r
.33731 .53976 m .34059 .5356 L .33798 .53669 L F
.455 .821 .56 r
.44627 .59702 m .44992 .59408 L .44845 .59586 L F
.144 0 0 r
.44845 .59586 m .44992 .59408 L .45241 .59338 L F
.763 .722 .814 r
.44588 .54835 m .4459 .55139 L .44895 .54813 L F
.105 0 0 r
.66527 .37376 m .66586 .37242 L .66302 .37371 L F
.879 .898 .841 r
.64119 .33642 m .63715 .33832 L .64025 .33559 L F
.64119 .33642 m .6381 .33982 L .63715 .33832 L F
.67 .944 .961 r
.64119 .33642 m .64258 .33408 L .64421 .33415 L F
.64119 .33642 m .64025 .33559 L .64258 .33408 L F
0 .095 .627 r
.39181 .51464 m .39266 .51482 L .39043 .51306 L F
.39181 .51464 m .39416 .51692 L .39266 .51482 L F
.399 .333 .667 r
.33385 .5226 m .33542 .51954 L .33376 .52009 L F
.33385 .5226 m .33564 .52202 L .33557 .51927 L F
.777 .618 .683 r
.33518 .52182 m .33183 .5224 L .33096 .51996 L F
.33564 .52202 m .33515 .52207 L .33518 .52182 L F
.33515 .52207 m .33183 .5224 L .33518 .52182 L F
.399 .333 .667 r
.33542 .51954 m .33557 .51927 L .33545 .51932 L F
.33542 .51954 m .33545 .51932 L .33376 .52009 L F
.599 .903 .985 r
.4399 .5835 m .43946 .58253 L .44023 .58129 L F
.599 .406 .592 r
.43946 .58253 m .44184 .57972 L .44023 .58129 L F
.994 .747 .41 r
.50206 .43312 m .50182 .43607 L .50088 .43294 L F
.678 .976 .894 r
.50206 .43312 m .50088 .43294 L .5029 .43137 L F
.351 .642 .964 r
.5029 .43137 m .5043 .43285 L .50206 .43312 L F
.329 .124 .443 r
.5043 .43285 m .50182 .43607 L .50206 .43312 L F
.394 .386 .732 r
.44179 .57156 m .44409 .57415 L .44449 .57117 L F
.44179 .57156 m .44443 .57523 L .44409 .57415 L F
.684 .704 .863 r
.32125 .52699 m .32104 .52852 L .32383 .52606 L F
.823 .439 .327 r
.56347 .3943 m .56673 .39517 L .56723 .3975 L F
.684 .344 .393 r
.56673 .39517 m .5694 .39696 L .56723 .3975 L F
.523 .324 .553 r
.33591 .63892 m .33849 .6386 L .33836 .63592 L F
.382 0 .129 r
.33679 .6412 m .33849 .6386 L .33591 .63892 L F
.522 .293 .509 r
.32569 .55947 m .3293 .55924 L .328 .55728 L F
.598 .314 .457 r
.328 .55728 m .3293 .55924 L .33082 .55819 L F
0 0 .215 r
.21272 .58135 m .21289 .577 L .21224 .57766 L F
.21272 .58135 m .21312 .5798 L .21289 .577 L F
.211 .325 .763 r
.21327 .5841 m .21312 .5798 L .21272 .58135 L F
.148 .691 .754 r
.25135 .62062 m .24956 .62073 L .24691 .62111 L F
.221 0 0 r
.25471 .62141 m .24956 .62073 L .25135 .62062 L F
0 .074 .614 r
.3323 .6234 m .33405 .62487 L .33702 .62299 L F
0 .065 .603 r
.34267 .69109 m .34214 .69066 L .34151 .68945 L F
.42 0 0 r
.33564 .52202 m .34024 .52185 L .33557 .51927 L F
.33564 .52202 m .33985 .52235 L .34024 .52185 L F
.579 .117 .122 r
.33903 .52041 m .34024 .52185 L .33985 .52235 L F
.636 .396 .538 r
.49614 .48482 m .49589 .48772 L .49332 .4876 L F
.494 .313 .564 r
.49864 .48108 m .4985 .484 L .49614 .48482 L F
.567 .337 .526 r
.49935 .4867 m .49614 .48482 L .4985 .484 L F
.49935 .4867 m .49589 .48772 L .49614 .48482 L F
0 0 .088 r
.33916 .6331 m .33836 .63592 L .33935 .63455 L F
.834 .85 .858 r
.33849 .6386 m .33935 .63455 L .33836 .63592 L F
.71 .93 .605 r
.59544 .35609 m .59438 .35708 L .59669 .35386 L F
.839 .695 .703 r
.49899 .47144 m .499 .46969 L .49987 .4689 L F
.49899 .47144 m .49821 .47255 L .499 .46969 L F
.882 .767 .73 r
.49899 .47144 m .49685 .4748 L .49821 .47255 L F
.412 .508 .847 r
.33491 .60117 m .33791 .6066 L .33558 .60708 L F
.413 .514 .852 r
.33791 .6066 m .33938 .60812 L .33558 .60708 L F
.326 .009 .266 r
.31011 .61652 m .31353 .61357 L .31054 .61349 L F
0 .112 .609 r
.32984 .69346 m .326 .69001 L .3283 .693 L F
.941 .635 .433 r
.70164 .30517 m .69959 .30153 L .69972 .30411 L F
.299 0 .175 r
.69836 .30741 m .70164 .30517 L .70079 .3061 L F
.851 .392 .078 r
.70079 .3061 m .70164 .30517 L .69972 .30411 L F
.169 0 .165 r
.70534 .30185 m .70164 .30517 L .70427 .30418 L F
0 0 0 r
.3503 .62987 m .34631 .6332 L .34897 .63192 L F
.516 .428 .694 r
.32569 .55947 m .32805 .56198 L .3293 .55924 L F
.32569 .55947 m .32602 .56276 L .32805 .56198 L F
.102 .131 .606 r
.35312 .52194 m .35453 .52671 L .35335 .52418 L F
.385 .438 .793 r
.62534 .40362 m .62251 .4019 L .62539 .40113 L F
.447 .661 .953 r
.2895 .63195 m .28801 .6328 L .28521 .62972 L F
.047 0 .218 r
.28704 .6355 m .28801 .6328 L .2895 .63195 L F
.791 .316 0 r
.27144 .51905 m .27217 .52026 L .27096 .51975 L F
.27217 .52026 m .27116 .5199 L .27096 .51975 L F
.83 .377 .148 r
.27393 .52064 m .27072 .51786 L .27229 .52056 L F
.008 .571 .801 r
.27368 .52079 m .27316 .5206 L .27229 .52056 L F
.83 .377 .148 r
.27393 .52064 m .27265 .52105 L .27072 .51786 L F
.791 .316 0 r
.27217 .52026 m .27265 .52105 L .27116 .5199 L F
.008 .571 .801 r
.27378 .52072 m .27393 .52064 L .27316 .5206 L F
.27656 .52125 m .27393 .52064 L .27378 .52072 L F
.269 .762 .694 r
.27523 .5201 m .27426 .52046 L .27393 .52064 L F
.008 .571 .801 r
.27656 .52125 m .27316 .5206 L .27368 .52079 L F
.269 .762 .694 r
.27426 .52046 m .27265 .52105 L .27393 .52064 L F
.366 .791 .972 r
.27523 .5201 m .27096 .51975 L .27265 .52105 L F
.27523 .5201 m .27361 .51939 L .27138 .51969 L F
.27143 .51979 m .27138 .51969 L .27096 .51975 L F
.27523 .5201 m .27138 .51969 L .27143 .51979 L F
.227 .599 .95 r
.26825 .51552 m .27072 .51786 L .26834 .51783 L F
.561 .894 .984 r
.26909 .51858 m .26851 .52018 L .27072 .51786 L F
.579 .002 0 r
.26825 .51552 m .27291 .5172 L .27072 .51786 L F
.791 .316 0 r
.27072 .51786 m .27096 .51975 L .26909 .51858 L F
.579 .002 0 r
.27082 .51645 m .27156 .51715 L .27291 .5172 L F
.26825 .51552 m .27156 .51715 L .27082 .51645 L F
.285 .042 .359 r
.27156 .51715 m .27096 .51975 L .27234 .51789 L F
.466 .89 .891 r
.27291 .5172 m .27156 .51715 L .27361 .5162 L F
.285 .042 .359 r
.27156 .51715 m .27234 .51789 L .27361 .5162 L F
.791 .316 0 r
.27072 .51786 m .27144 .51905 L .27096 .51975 L F
.461 .197 .426 r
.27156 .51715 m .27096 .51975 L .26909 .51858 L F
.667 .579 .747 r
.27156 .51715 m .26909 .51858 L .26825 .51552 L F
.136 .535 .92 r
.2697 .51534 m .27156 .51715 L .26825 .51552 L F
.227 .599 .95 r
.26825 .51552 m .26834 .51783 L .26662 .51645 L F
.479 .896 .818 r
.26662 .51645 m .26809 .51525 L .26825 .51552 L F
.26662 .51645 m .26743 .51557 L .26786 .51544 L F
.369 .748 .989 r
.26424 .51676 m .26662 .51645 L .26834 .51783 L F
.125 0 0 r
.26214 .51699 m .26662 .51645 L .26424 .51676 L F
.26554 .51658 m .26464 .51693 L .26662 .51645 L F
.26214 .51699 m .26464 .51693 L .26554 .51658 L F
.106 .659 .718 r
.26001 .51728 m .26424 .51676 L .2621 .51764 L F
.26001 .51728 m .26214 .51699 L .26424 .51676 L F
.035 .603 .767 r
.25809 .51679 m .26214 .51699 L .26001 .51728 L F
.104 .656 .808 r
.26214 .51699 m .26026 .51683 L .26464 .51693 L F
.643 .197 .175 r
.26026 .51683 m .26187 .51824 L .26464 .51693 L F
.388 .828 .69 r
.26464 .51693 m .26187 .51824 L .26352 .51737 L F
.465 .194 .417 r
.26809 .51525 m .26464 .51693 L .26644 .51571 L F
.388 .828 .69 r
.26464 .51693 m .26568 .51623 L .26644 .51571 L F
.26464 .51693 m .26352 .51737 L .26568 .51623 L F
.35 .827 .844 r
.26568 .51623 m .2697 .51534 L .26732 .51561 L F
.266 .51601 m .26732 .51561 L .26644 .51571 L F
.26568 .51623 m .26732 .51561 L .266 .51601 L F
.479 .896 .818 r
.26662 .51645 m .26464 .51693 L .26743 .51557 L F
.26786 .51544 m .26743 .51557 L .26809 .51525 L F
.35 .827 .844 r
.26568 .51623 m .26724 .51571 L .2697 .51534 L F
.713 .377 0 r
.27011 .51688 m .2697 .51534 L .26724 .51571 L F
.507 .853 .994 r
.27011 .51688 m .26808 .5161 L .26955 .51573 L F
.713 .377 0 r
.27011 .51688 m .27052 .51775 L .2697 .51534 L F
.2708 .51856 m .27103 .519 L .2697 .51534 L F
.572 .782 .978 r
.27361 .5162 m .27156 .51715 L .2697 .51534 L F
.27361 .5162 m .27156 .51715 L .2697 .51534 L F
.103 0 0 r
.27361 .51939 m .27064 .52021 L .27096 .51975 L F
.382 .846 .847 r
.27491 .51705 m .27291 .5172 L .27567 .51626 L F
.466 .89 .891 r
.27291 .5172 m .27361 .5162 L .27567 .51626 L F
.285 .042 .359 r
.27156 .51715 m .27096 .51975 L .27361 .5162 L F
.787 .486 .479 r
.2697 .51534 m .27134 .51986 L .27361 .5162 L F
.507 .853 .994 r
.27011 .51688 m .26955 .51573 L .27075 .51543 L F
.713 .377 0 r
.27011 .51688 m .2708 .51856 L .27052 .51775 L F
.2708 .51856 m .27134 .51986 L .27103 .519 L F
.103 0 0 r
.27064 .52021 m .2689 .5207 L .27096 .51975 L F
.553 .895 .981 r
.27653 .51984 m .27656 .52125 L .27877 .52062 L F
.27653 .51984 m .27393 .52064 L .27656 .52125 L F
.502 .513 .8 r
.39165 .48684 m .39323 .49087 L .39068 .4913 L F
.956 .689 .489 r
.69675 .33665 m .69455 .33781 L .69475 .33548 L F
.69675 .33665 m .69676 .33961 L .69455 .33781 L F
.301 .196 .564 r
.3782 .58278 m .37605 .58083 L .38123 .58096 L F
.381 0 0 r
.38123 .58096 m .38221 .58144 L .38074 .58228 L F
.884 .99 .795 r
.4189 .49527 m .41916 .4932 L .4206 .49366 L F
.806 .922 .914 r
.4206 .49366 m .41951 .49306 L .42353 .49083 L F
.707 .98 .791 r
.67694 .36424 m .67486 .36619 L .67627 .36406 L F
.707 .985 .871 r
.67627 .36406 m .67486 .36619 L .67263 .36643 L F
.678 .857 .968 r
.61283 .34878 m .6107 .35169 L .61018 .35 L F
.61283 .34878 m .6142 .35025 L .6107 .35169 L F
.025 .416 .861 r
.32852 .5274 m .3321 .53058 L .32829 .52914 L F
.139 0 0 r
.32829 .52914 m .32784 .52995 L .32852 .5274 L F
0 .403 .821 r
.32829 .52914 m .3321 .53058 L .33251 .53126 L F
.557 .807 .992 r
.70799 .28859 m .71076 .28792 L .70945 .28633 L F
.70945 .28633 m .71076 .28792 L .70799 .28859 L F
.727 .253 0 r
.60331 .42819 m .60398 .42839 L .60148 .42572 L F
.60331 .42819 m .6047 .42953 L .60398 .42839 L F
.548 .38 .605 r
.38911 .68424 m .39196 .68382 L .39169 .68091 L F
.822 .925 .903 r
.44518 .50979 m .44352 .50924 L .44389 .51001 L F
.44389 .51001 m .44352 .50924 L .44518 .50979 L F
.17 .675 .905 r
.44518 .50979 m .44741 .50979 L .44352 .50924 L F
.44352 .50924 m .44741 .50979 L .44518 .50979 L F
.822 .925 .903 r
.44518 .50979 m .44352 .50924 L .44389 .51001 L F
.715 .577 .699 r
.49575 .46576 m .499 .46969 L .49351 .46919 L F
.698 .575 .713 r
.49987 .4689 m .499 .46969 L .49575 .46576 L F
.008 0 .358 r
.32848 .57758 m .3304 .57349 L .32941 .57511 L F
.29 .779 .903 r
.23535 .58318 m .23451 .58369 L .23654 .5833 L F
.142 0 0 r
.23654 .5833 m .23881 .58366 L .23535 .58318 L F
.683 .519 .657 r
.23663 .58522 m .23535 .58318 L .23881 .58366 L F
.23535 .58318 m .23663 .58522 L .23582 .58289 L F
.23535 .58318 m .23582 .58289 L .23531 .58143 L F
.29 .779 .903 r
.23535 .58318 m .23324 .58394 L .23451 .58369 L F
.23535 .58318 m .23226 .58375 L .23324 .58394 L F
.824 .711 .74 r
.59701 .36526 m .59838 .36915 L .59452 .36819 L F
.779 .506 .522 r
.59838 .36915 m .59447 .37112 L .59452 .36819 L F
.59838 .36915 m .59879 .37135 L .59447 .37112 L F
.698 .818 .939 r
.6002 .364 m .59701 .36526 L .59579 .36352 L F
.6002 .364 m .59579 .36352 L .59831 .36308 L F
.777 .48 .484 r
.59755 .36412 m .6002 .364 L .59831 .36308 L F
0 .04 .605 r
.59788 .36623 m .5983 .36894 L .59701 .36526 L F
.699 .776 .911 r
.6002 .364 m .60097 .36588 L .59701 .36526 L F
0 .04 .605 r
.59884 .36731 m .59701 .36526 L .60097 .36588 L F
.947 .925 .751 r
.59452 .36819 m .59579 .36352 L .59701 .36526 L F
.777 .48 .484 r
.59588 .36639 m .59774 .36536 L .59755 .36412 L F
.59774 .36536 m .6002 .364 L .59755 .36412 L F
0 .04 .605 r
.59884 .36731 m .59838 .36915 L .5983 .36894 L F
.59884 .36731 m .5983 .36894 L .59788 .36623 L F
0 0 .389 r
.59967 .36996 m .59838 .36915 L .59884 .36731 L F
.59967 .36996 m .59879 .37135 L .59838 .36915 L F
.752 .358 .306 r
.70993 .31332 m .70926 .31157 L .70582 .31091 L F
.929 .683 .544 r
.335 .59758 m .33668 .60014 L .33707 .59735 L F
.869 .951 .862 r
.33793 .59355 m .33707 .59735 L .33794 .5967 L F
.33793 .59355 m .335 .59758 L .33707 .59735 L F
.714 .925 .589 r
.33581 .59631 m .33564 .5967 L .33793 .59355 L F
.33571 .59644 m .33569 .59649 L .33581 .59631 L F
.33569 .59649 m .33564 .5967 L .33581 .59631 L F
.929 .683 .544 r
.33569 .59649 m .335 .59758 L .33543 .59633 L F
.714 .925 .589 r
.33571 .59644 m .335 .59758 L .33564 .5967 L F
.929 .683 .544 r
.33707 .59735 m .335 .59758 L .33569 .59649 L F
.33707 .59735 m .33569 .59649 L .33794 .5967 L F
.33569 .59649 m .33572 .59637 L .33794 .5967 L F
.33569 .59649 m .33543 .59633 L .33571 .59644 L F
.765 .948 .938 r
.33543 .59633 m .335 .59758 L .33571 .59644 L F
.33543 .59633 m .33571 .59644 L .33649 .59518 L F
.929 .683 .544 r
.33571 .59644 m .33543 .59633 L .33572 .59637 L F
.451 .452 .768 r
.33793 .59355 m .33794 .5967 L .34045 .59551 L F
.714 .925 .589 r
.33594 .59607 m .33571 .59644 L .33664 .59523 L F
.597 .32 .466 r
.33543 .59633 m .34045 .59551 L .33794 .5967 L F
.34045 .59551 m .33987 .59788 L .33566 .59641 L F
.33577 .59627 m .33566 .59641 L .33543 .59633 L F
.34045 .59551 m .33566 .59641 L .33577 .59627 L F
.714 .925 .589 r
.33649 .59518 m .33594 .59607 L .33793 .59355 L F
.33594 .59607 m .33664 .59523 L .33793 .59355 L F
.929 .683 .544 r
.33707 .59735 m .33668 .60014 L .335 .59758 L F
.756 .507 .556 r
.34104 .60013 m .33668 .60014 L .33707 .59735 L F
.839 .82 .83 r
.72737 .33486 m .73332 .33538 L .73033 .33491 L F
.72737 .33486 m .72782 .33862 L .73332 .33538 L F
.01 .455 .869 r
.73332 .33538 m .73289 .33372 L .73033 .33491 L F
.73332 .33538 m .73472 .33536 L .73289 .33372 L F
.601 .682 .899 r
.39945 .47699 m .39807 .47984 L .39689 .47787 L F
.39945 .47699 m .40091 .47977 L .39807 .47984 L F
.622 .955 .8 r
.69873 .2828 m .6968 .28486 L .69641 .28454 L F
.69873 .2828 m .70014 .28258 L .6968 .28486 L F
.676 .964 .753 r
.38315 .6261 m .38625 .62337 L .38403 .62457 L F
.677 .96 .731 r
.38104 .62732 m .38315 .6261 L .38403 .62457 L F
.266 .003 .316 r
.33731 .53976 m .33983 .53883 L .34059 .5356 L F
.179 .674 .917 r
.34101 .53548 m .33653 .53438 L .34059 .5356 L F
0 0 .167 r
.34101 .53548 m .33983 .53883 L .34059 .5356 L F
.894 .948 .834 r
.69052 .2924 m .69261 .2923 L .68977 .29572 L F
.842 .971 .88 r
.69317 .28956 m .69261 .2923 L .69052 .2924 L F
.58 .793 .98 r
.58991 .37774 m .59123 .37939 L .58893 .37895 L F
.782 .872 .915 r
.59307 .37773 m .59123 .37939 L .58991 .37774 L F
.641 .468 .633 r
.30321 .55214 m .3006 .5555 L .30058 .55245 L F
.30321 .55214 m .3006 .5555 L .30058 .55245 L F
.354 .009 .235 r
.27845 .5746 m .2774 .57736 L .27477 .57788 L F
0 0 .068 r
.27911 .57609 m .27845 .5746 L .281 .57467 L F
.27911 .57609 m .2774 .57736 L .27845 .5746 L F
.849 .855 .847 r
.59879 .37135 m .59538 .37625 L .5959 .37501 L F
.936 .744 .618 r
.59143 .45242 m .59117 .45612 L .589 .4545 L F
.208 .727 .705 r
.64341 .39148 m .63895 .39265 L .64241 .39141 L F
.411 .861 .867 r
.64576 .3906 m .64341 .39148 L .64241 .39141 L F
.69 .209 .103 r
.24865 .55713 m .25063 .556 L .25071 .55573 L F
.752 .839 .917 r
.45181 .45664 m .45096 .45966 L .4493 .45808 L F
.45181 .45664 m .45336 .45832 L .45096 .45966 L F
.681 .94 .657 r
.44288 .54567 m .44089 .54718 L .44 .54867 L F
0 .002 .565 r
.44332 .54375 m .44288 .54567 L .44183 .54194 L F
.834 .979 .686 r
.44332 .54375 m .44089 .54718 L .44288 .54567 L F
.827 .92 .898 r
.5245 .41256 m .523 .4136 L .52138 .41266 L F
.628 .935 .964 r
.5245 .41256 m .52539 .41049 L .52658 .41051 L F
.5245 .41256 m .52138 .41266 L .52539 .41049 L F
.757 .621 .709 r
.36066 .53564 m .36364 .53627 L .3638 .53284 L F
.232 0 0 r
.35925 .5385 m .36364 .53627 L .36066 .53564 L F
.35925 .5385 m .36216 .53798 L .36364 .53627 L F
.564 .829 .471 r
.36364 .53627 m .36448 .53518 L .36609 .53566 L F
.36364 .53627 m .36216 .53798 L .36448 .53518 L F
.547 .414 .652 r
.36673 .53854 m .36364 .53627 L .36609 .53566 L F
.36673 .53854 m .36402 .53939 L .36364 .53627 L F
.377 .428 .787 r
.46731 .53684 m .4703 .53848 L .46857 .53915 L F
.401 .3 .623 r
.47104 .54113 m .46857 .53915 L .4703 .53848 L F
.47104 .54113 m .46821 .54348 L .46857 .53915 L F
.811 .743 .789 r
.56347 .3943 m .5643 .39794 L .5607 .39699 L F
.734 .242 .072 r
.5643 .39794 m .56343 .39937 L .5607 .39699 L F
.823 .439 .327 r
.56347 .3943 m .56723 .3975 L .5643 .39794 L F
.862 .894 .856 r
.56723 .3975 m .56343 .39937 L .5643 .39794 L F
.444 .38 .692 r
.46903 .53198 m .46731 .53684 L .46685 .53272 L F
.287 .395 .799 r
.45796 .55222 m .45815 .54811 L .45577 .54853 L F
.45796 .55222 m .4595 .55173 L .45815 .54811 L F
.481 .843 .992 r
.28335 .52079 m .28164 .51993 L .27877 .52062 L F
.719 .93 .96 r
.28371 .51854 m .28335 .52079 L .28555 .51972 L F
.28371 .51854 m .28164 .51993 L .28335 .52079 L F
.56 .025 0 r
.69836 .30741 m .69775 .30864 L .69529 .30722 L F
.416 .126 .361 r
.70079 .3061 m .69775 .30864 L .69836 .30741 L F
.49 .288 .533 r
.56572 .3884 m .56557 .39098 L .56824 .38804 L F
.47 .74 .987 r
.41736 .48835 m .41793 .48754 L .41577 .48698 L F
.41736 .48835 m .41793 .48754 L .41577 .48698 L F
.149 .293 .756 r
.41736 .48835 m .41873 .48772 L .41793 .48754 L F
.306 .267 .65 r
.31018 .63546 m .31062 .63809 L .30837 .6359 L F
.406 .814 .979 r
.22354 .60296 m .21919 .60276 L .22052 .60272 L F
.217 .367 .8 r
.36241 .56746 m .36158 .56857 L .35994 .568 L F
.36241 .56746 m .36398 .57118 L .36158 .56857 L F
.444 .38 .692 r
.46903 .53198 m .46967 .53734 L .46731 .53684 L F
.423 .419 .75 r
.46967 .53734 m .4703 .53848 L .46731 .53684 L F
.501 .883 .968 r
.34386 .63574 m .3453 .63621 L .34769 .63539 L F
.581 .394 .594 r
.5014 .48088 m .4985 .484 L .49864 .48108 L F
.352 0 .052 r
.34114 .52866 m .34347 .52866 L .34505 .52648 L F
0 0 0 r
.34505 .52648 m .34596 .52561 L .34779 .52665 L F
.34505 .52648 m .34347 .52866 L .34596 .52561 L F
.543 .588 .85 r
.72107 .33346 m .7214 .33765 L .72442 .33675 L F
.585 .588 .822 r
.7214 .33765 m .72574 .33992 L .72442 .33675 L F
.978 .748 .333 r
.38683 .68732 m .38695 .69034 L .38608 .69006 L F
0 0 .447 r
.38778 .68963 m .38683 .68732 L .38758 .68599 L F
.38778 .68963 m .38695 .69034 L .38683 .68732 L F
.978 .748 .333 r
.38683 .68732 m .38608 .69006 L .38758 .68599 L F
.206 .569 .939 r
.36384 .70832 m .36488 .70963 L .36548 .70845 L F
.18 .537 .925 r
.36488 .70963 m .36686 .71014 L .36548 .70845 L F
.842 .886 .872 r
.66559 .33222 m .67027 .33054 L .66927 .3293 L F
.844 .93 .885 r
.67027 .33054 m .67204 .32641 L .66927 .3293 L F
.67027 .33054 m .67318 .32766 L .67204 .32641 L F
.813 .647 .676 r
.37008 .62913 m .37252 .63301 L .36845 .6313 L F
.941 .895 .497 r
.37015 .63555 m .3706 .63485 L .36968 .63752 L F
.825 .443 .329 r
.36845 .6313 m .37196 .63278 L .3706 .63485 L F
.279 .268 .668 r
.36845 .6313 m .3706 .63485 L .3712 .63119 L F
.941 .895 .497 r
.3712 .63119 m .3706 .63485 L .37015 .63555 L F
.825 .443 .329 r
.37196 .63278 m .37252 .63301 L .3706 .63485 L F
.856 .8 .795 r
.37294 .62872 m .37252 .63301 L .37008 .62913 L F
.992 .882 .594 r
.3706 .63485 m .37252 .63301 L .37165 .63564 L F
.361 .538 .895 r
.63151 .41574 m .63686 .41787 L .63165 .41292 L F
.581 .432 .645 r
.63186 .41765 m .63686 .41787 L .63151 .41574 L F
0 0 .338 r
.63165 .41292 m .63186 .41765 L .63151 .41574 L F
.445 .302 .592 r
.42114 .51019 m .42183 .51366 L .41885 .51422 L F
.354 .046 .298 r
.42183 .51366 m .41848 .51609 L .41885 .51422 L F
.41885 .51422 m .41848 .51609 L .42183 .51366 L F
.807 .888 .902 r
.68977 .29572 m .68538 .29705 L .6884 .29407 L F
.894 .948 .834 r
.69052 .2924 m .68977 .29572 L .6884 .29407 L F
.71 .293 0 r
.41045 .54894 m .40966 .54793 L .40828 .54536 L F
.957 .656 .229 r
.41045 .54894 m .40939 .55007 L .40966 .54793 L F
.41045 .54894 m .4107 .55184 L .40939 .55007 L F
0 0 .449 r
.22547 .55807 m .226 .56114 L .22495 .55829 L F
0 .269 .775 r
.32364 .5495 m .32584 .55103 L .32367 .548 L F
.51 .244 .447 r
.32364 .5495 m .3228 .55179 L .32584 .55103 L F
.683 .786 .928 r
.55819 .41691 m .56195 .4172 L .56069 .41578 L F
.796 .547 .562 r
.55846 .4196 m .56195 .4172 L .55819 .41691 L F
.55846 .4196 m .56219 .42018 L .56195 .4172 L F
.584 .687 .912 r
.56195 .4172 m .56359 .41477 L .56069 .41578 L F
.56195 .4172 m .56471 .41678 L .56359 .41477 L F
.556 .367 .581 r
.56219 .42018 m .56471 .41678 L .56195 .4172 L F
.358 .728 .988 r
.58277 .37688 m .58672 .37865 L .58484 .37916 L F
.481 .816 .999 r
.58893 .37895 m .58484 .37916 L .58672 .37865 L F
.804 .888 .905 r
.6381 .33982 m .63517 .33988 L .63715 .33832 L F
.679 .57 .726 r
.31011 .61652 m .30839 .62 L .31002 .61868 L F
.019 0 0 r
.30839 .62 m .30921 .62088 L .31002 .61868 L F
.30839 .62 m .30717 .62181 L .30921 .62088 L F
.597 .409 .597 r
.52973 .40729 m .52658 .41051 L .5264 .40751 L F
.5264 .40751 m .52658 .41051 L .52973 .40729 L F
.5264 .40751 m .52658 .41051 L .52973 .40729 L F
.935 .646 .468 r
.34251 .60693 m .34032 .60868 L .34031 .60606 L F
.893 .827 .775 r
.34251 .60693 m .34258 .60231 L .34481 .60374 L F
.34251 .60693 m .34031 .60606 L .34258 .60231 L F
.25 .215 .623 r
.47351 .55385 m .47209 .55827 L .47156 .55569 L F
0 .04 .605 r
.59884 .36731 m .60097 .36588 L .6002 .364 L F
.388 .582 .918 r
.6002 .364 m .60097 .36588 L .60228 .36378 L F
.584 .836 .993 r
.60228 .36378 m .60097 .36588 L .60359 .36505 L F
.388 .582 .918 r
.6002 .364 m .60097 .36588 L .60228 .36378 L F
.584 .836 .993 r
.60228 .36378 m .60097 .36588 L .60359 .36505 L F
.705 .499 .607 r
.35595 .52378 m .35453 .52671 L .35312 .52194 L F
.376 0 .185 r
.35405 .53892 m .35555 .54062 L .35644 .53841 L F
.35405 .53892 m .353 .54116 L .35555 .54062 L F
.848 .891 .869 r
.54773 .40102 m .54511 .40355 L .54847 .40136 L F
.835 .847 .855 r
.54805 .40169 m .54906 .40381 L .54511 .40355 L F
.899 .608 .487 r
.54876 .40736 m .54511 .40355 L .54906 .40381 L F
.859 .854 .836 r
.55124 .40096 m .54906 .40381 L .54816 .40191 L F
.55124 .40096 m .54816 .40191 L .54836 .40162 L F
.55124 .40096 m .54805 .40169 L .54841 .40145 L F
.54913 .401 m .54841 .40145 L .54906 .401 L F
.55124 .40096 m .54841 .40145 L .54913 .401 L F
.965 .643 .348 r
.55124 .40096 m .55166 .40361 L .54906 .40381 L F
.706 .495 .6 r
.54677 .40406 m .55084 .40188 L .54853 .40137 L F
.54841 .40145 m .54853 .40137 L .54847 .40136 L F
.54677 .40406 m .54853 .40137 L .54841 .40145 L F
.859 .854 .836 r
.55124 .40096 m .54773 .40102 L .5507 .39937 L F
.55111 .39934 m .5507 .39937 L .55109 .39915 L F
.55124 .40096 m .5507 .39937 L .55111 .39934 L F
.793 .86 .9 r
.5543 .39932 m .55124 .40096 L .55441 .39798 L F
.723 .879 .475 r
.55166 .40361 m .5526 .40208 L .554 .40274 L F
.5526 .40208 m .5543 .39932 L .55413 .40123 L F
.5526 .40208 m .55413 .40123 L .554 .40274 L F
.361 .197 .519 r
.55664 .3972 m .5543 .39932 L .55441 .39798 L F
.55664 .3972 m .55719 .39983 L .5543 .39932 L F
.371 .092 .355 r
.55719 .39983 m .554 .40274 L .5543 .39932 L F
.882 .756 .718 r
.55683 .39456 m .55441 .39798 L .55251 .3968 L F
.622 .384 .536 r
.55683 .39456 m .55664 .3972 L .55441 .39798 L F
.804 .96 .913 r
.55441 .39798 m .55124 .40096 L .55117 .4001 L F
.55169 .39919 m .55117 .4001 L .55111 .39934 L F
.55193 .39913 m .55187 .3992 L .55169 .39919 L F
.55187 .3992 m .55117 .4001 L .55169 .39919 L F
.55193 .39913 m .55111 .39934 L .55109 .39915 L F
.55441 .39798 m .55223 .39875 L .55175 .39899 L F
.55223 .39875 m .55109 .39915 L .55175 .39899 L F
.619 .633 .843 r
.55257 .39832 m .55286 .39843 L .55508 .39625 L F
.804 .96 .913 r
.55441 .39798 m .55343 .39862 L .55301 .39847 L F
.55343 .39862 m .55117 .4001 L .55301 .39847 L F
.55301 .39847 m .55117 .4001 L .55201 .39903 L F
.666 .516 .671 r
.55201 .39903 m .554 .40274 L .55719 .39983 L F
.55175 .39899 m .55185 .39915 L .55201 .39903 L F
.55185 .39915 m .554 .40274 L .55201 .39903 L F
.804 .96 .913 r
.55254 .39864 m .55201 .39903 L .55223 .39875 L F
.55301 .39847 m .55201 .39903 L .55254 .39864 L F
.619 .633 .843 r
.55286 .39843 m .55676 .39976 L .55548 .39709 L F
.55286 .39843 m .55548 .39709 L .55508 .39625 L F
.838 .557 .511 r
.55084 .40188 m .55169 .39919 L .55109 .39915 L F
.55169 .39919 m .55175 .39899 L .55109 .39915 L F
.55166 .39929 m .55192 .39927 L .55185 .39915 L F
.55169 .39919 m .55185 .39915 L .55175 .39899 L F
.55166 .39929 m .55185 .39915 L .55169 .39919 L F
.804 .96 .913 r
.55223 .39875 m .55193 .39913 L .55109 .39915 L F
.619 .633 .843 r
.55175 .39899 m .55201 .39903 L .55257 .39832 L F
.55201 .39903 m .55676 .39976 L .55257 .39832 L F
.55676 .39976 m .55719 .39983 L .55706 .39959 L F
.55676 .39976 m .55706 .39959 L .55508 .39625 L F
.838 .557 .511 r
.55084 .40188 m .554 .40274 L .55192 .39927 L F
.55084 .40188 m .55192 .39927 L .55166 .39929 L F
.37 .181 .49 r
.54865 .4012 m .55084 .40188 L .55109 .39915 L F
.54847 .40136 m .54853 .40137 L .54865 .4012 L F
.54853 .40137 m .55084 .40188 L .54865 .4012 L F
.859 .854 .836 r
.54836 .40162 m .54816 .40191 L .54805 .40169 L F
.37 .181 .49 r
.54847 .40136 m .54865 .4012 L .54773 .40102 L F
.859 .854 .836 r
.54906 .401 m .54874 .40122 L .54773 .40102 L F
.37 .181 .49 r
.54865 .4012 m .55109 .39915 L .54773 .40102 L F
.859 .854 .836 r
.54874 .40122 m .54805 .40169 L .54773 .40102 L F
.308 0 0 r
.54805 .40169 m .54677 .40406 L .54839 .40148 L F
.54511 .40355 m .54527 .40359 L .54805 .40169 L F
.54527 .40359 m .54677 .40406 L .54805 .40169 L F
.54511 .40355 m .54839 .40148 L .54847 .40136 L F
.835 .847 .855 r
.54773 .40102 m .54805 .40169 L .54511 .40355 L F
.229 .528 .919 r
.32303 .62535 m .3268 .62755 L .32506 .6255 L F
.303 0 0 r
.32055 .6274 m .32303 .62535 L .32506 .6255 L F
.75 .843 .921 r
.49667 .43993 m .49296 .43997 L .4949 .43824 L F
.791 .844 .892 r
.49805 .43588 m .49667 .43993 L .4949 .43824 L F
.49805 .43588 m .49895 .43852 L .49667 .43993 L F
.796 .952 .616 r
.26107 .55091 m .25898 .55414 L .2603 .55259 L F
.99 .827 .587 r
.60609 .38074 m .60775 .38186 L .60668 .37851 L F
.918 .826 .74 r
.60668 .37851 m .60775 .38186 L .60833 .37986 L F
.876 .499 .021 r
.60729 .38264 m .60775 .38186 L .60609 .38074 L F
.60729 .38264 m .60842 .38397 L .60775 .38186 L F
.286 .656 .97 r
.34565 .70233 m .34985 .70368 L .3483 .70053 L F
.491 .563 .856 r
.34985 .70368 m .3507 .69992 L .3483 .70053 L F
.34985 .70368 m .35223 .70355 L .3507 .69992 L F
.495 .513 .805 r
.34985 .70368 m .35306 .70568 L .35223 .70355 L F
.975 .704 .297 r
.40702 .53885 m .40818 .54267 L .40713 .54145 L F
.981 .714 .324 r
.40818 .54267 m .4072 .54406 L .40713 .54145 L F
.40818 .54267 m .40828 .54536 L .4072 .54406 L F
.81 .747 .794 r
.43951 .50083 m .43693 .50409 L .43537 .50057 L F
.976 .672 .317 r
.60148 .42572 m .60132 .42371 L .59989 .4223 L F
0 0 .312 r
.41057 .55592 m .41152 .55809 L .40994 .55432 L F
.429 .322 .631 r
.24984 .60588 m .24848 .60461 L .24909 .60308 L F
.24984 .60588 m .2486 .60659 L .24848 .60461 L F
.6 .637 .859 r
.34478 .69929 m .34565 .70233 L .3483 .70053 L F
.812 .785 .283 r
.4136 .56828 m .41283 .57134 L .41294 .56981 L F
.954 .762 .307 r
.4136 .56828 m .41294 .56711 L .41318 .56442 L F
.94 .726 .252 r
.4136 .56828 m .41294 .56981 L .41294 .56711 L F
0 0 .544 r
.39771 .52228 m .39912 .52395 L .39753 .52181 L F
.865 .514 .009 r
.39698 .51935 m .39771 .52228 L .39671 .5207 L F
0 0 .544 r
.39771 .52228 m .39753 .52181 L .39671 .5207 L F
.725 .44 0 r
.39804 .52312 m .39771 .52228 L .39698 .51935 L F
.3981 .52334 m .39771 .52228 L .39804 .52312 L F
0 .17 .701 r
.39849 .52541 m .39771 .52228 L .3981 .52334 L F
.219 0 .151 r
.33109 .6147 m .32986 .61298 L .33292 .61266 L F
.61 .516 .723 r
.48312 .48504 m .48022 .48795 L .48021 .48638 L F
.48312 .48504 m .48286 .48737 L .48022 .48795 L F
.571 .412 .627 r
.48286 .48737 m .48026 .49074 L .48022 .48795 L F
.489 .683 .952 r
.34243 .69971 m .34269 .69696 L .34026 .69733 L F
.34243 .69971 m .34478 .69929 L .34269 .69696 L F
.161 .227 .685 r
.53608 .41239 m .53446 .41408 L .53348 .40998 L F
.602 .947 .796 r
.53293 .41438 m .53446 .41408 L .53608 .41239 L F
.758 .761 .855 r
.66866 .3853 m .67109 .38623 L .67101 .38387 L F
.797 .91 .918 r
.67109 .38623 m .67342 .38259 L .67101 .38387 L F
.67109 .38623 m .67443 .38402 L .67342 .38259 L F
.692 .283 .266 r
.53257 .46821 m .53656 .46842 L .53508 .47048 L F
.621 .199 .22 r
.53656 .46842 m .53927 .47034 L .53508 .47048 L F
.677 .863 .97 r
.33874 .56446 m .34293 .56437 L .34151 .56253 L F
.327 0 0 r
.34528 .56374 m .34151 .56253 L .34293 .56437 L F
.529 .35 .583 r
.48395 .48218 m .48312 .48504 L .48021 .48638 L F
.511 .557 .839 r
.28443 .52666 m .28798 .52952 L .28674 .52634 L F
.253 .644 .963 r
.39782 .67331 m .39936 .67476 L .39711 .67444 L F
.39782 .67331 m .39936 .67476 L .39711 .67444 L F
.868 .465 .006 r
.41315 .59682 m .41507 .59999 L .41401 .59927 L F
.741 .249 0 r
.41507 .59999 m .41516 .60123 L .41401 .59927 L F
.41507 .59999 m .41627 .60171 L .41516 .60123 L F
.78 .277 0 r
.41401 .59927 m .41516 .60123 L .41395 .60101 L F
.608 .948 .925 r
.41435 .60086 m .41516 .60123 L .41865 .59924 L F
.41395 .60101 m .41516 .60123 L .41435 .60086 L F
.741 .249 0 r
.41627 .60171 m .41696 .60272 L .41516 .60123 L F
.494 .376 .648 r
.25553 .55157 m .25814 .55441 L .25798 .5511 L F
.723 .958 .678 r
.25795 .55457 m .25737 .55566 L .25898 .55414 L F
.494 .376 .648 r
.25553 .55157 m .2564 .55594 L .25716 .55527 L F
0 .032 .544 r
.25996 .55102 m .25898 .55414 L .26107 .55091 L F
.25989 .55102 m .25983 .55124 L .25996 .55102 L F
.25983 .55124 m .25898 .55414 L .25996 .55102 L F
.25989 .55102 m .26043 .5535 L .25898 .55414 L F
.434 .314 .617 r
.25921 .55231 m .25841 .55437 L .26043 .5535 L F
.25798 .5511 m .25834 .55383 L .25921 .55231 L F
.25834 .55383 m .25841 .55437 L .25921 .55231 L F
.285 .763 .655 r
.26029 .55356 m .25863 .55428 L .25898 .55414 L F
.25863 .55428 m .25799 .55455 L .25898 .55414 L F
.26043 .5535 m .25795 .55457 L .26029 .55356 L F
.434 .314 .617 r
.25841 .55437 m .25847 .55477 L .26043 .5535 L F
.494 .376 .648 r
.25814 .55441 m .25819 .55447 L .25839 .55419 L F
.25819 .55447 m .25847 .55477 L .25841 .55437 L F
.25819 .55447 m .25841 .55437 L .25839 .55419 L F
.285 .763 .655 r
.25841 .55437 m .25795 .55457 L .25799 .55455 L F
.25863 .55428 m .25819 .55447 L .25841 .55437 L F
.25819 .55447 m .25795 .55457 L .25841 .55437 L F
.26043 .5535 m .257 .55497 L .25795 .55457 L F
.494 .376 .648 r
.258 .55426 m .25762 .55471 L .25814 .55441 L F
.25762 .55471 m .25716 .55527 L .25795 .55457 L F
.25762 .55471 m .25795 .55457 L .25814 .55441 L F
.25553 .55157 m .25716 .55527 L .258 .55426 L F
.25553 .55157 m .25599 .55618 L .2564 .55594 L F
.579 .439 .655 r
.25063 .556 m .25599 .55618 L .25553 .55157 L F
.784 .878 .916 r
.2534 .55594 m .25702 .5551 L .25599 .55618 L F
.723 .958 .678 r
.25704 .55505 m .25678 .55572 L .25716 .55527 L F
.25793 .55459 m .25737 .55566 L .25795 .55457 L F
.25715 .55525 m .25737 .55566 L .25794 .55458 L F
.494 .376 .648 r
.25814 .55441 m .2564 .55594 L .25847 .55477 L F
.784 .878 .916 r
.25702 .5551 m .25847 .55477 L .25678 .55572 L F
.25702 .5551 m .25678 .55572 L .25599 .55618 L F
.723 .958 .678 r
.257 .55497 m .25715 .55525 L .25794 .55458 L F
.784 .878 .916 r
.2534 .55594 m .257 .55497 L .25847 .55477 L F
.723 .958 .678 r
.257 .55497 m .25607 .55659 L .25678 .55572 L F
.257 .55497 m .25678 .55572 L .25704 .55505 L F
.257 .55497 m .25528 .55716 L .25607 .55659 L F
.25716 .55527 m .25607 .55659 L .25737 .55566 L F
.25794 .55458 m .25793 .55459 L .25795 .55457 L F
.494 .376 .648 r
.25814 .55441 m .25839 .55419 L .25798 .5511 L F
.833 .882 .878 r
.39739 .69063 m .40039 .68773 L .39542 .68927 L F
.845 .833 .835 r
.48946 .4423 m .48807 .44382 L .48618 .44229 L F
.29 .767 .662 r
.26309 .55006 m .26107 .55091 L .26515 .54917 L F
.908 .501 .177 r
.61592 .42969 m .61402 .42866 L .61329 .42649 L F
.794 .318 .097 r
.61592 .42969 m .61457 .43086 L .61402 .42866 L F
.921 .688 .195 r
.36146 .51879 m .36157 .52222 L .36243 .5231 L F
.8 .431 0 r
.36157 .52222 m .36316 .52544 L .36243 .5231 L F
.54 .234 .397 r
.36243 .5231 m .36316 .52544 L .36429 .5234 L F
.716 .874 .955 r
.63569 .35599 m .63908 .35627 L .6375 .35453 L F
.761 .805 .888 r
.6375 .35453 m .63908 .35627 L .641 .3546 L F
.961 .79 .625 r
.523 .4136 m .52018 .41594 L .52138 .41266 L F
.523 .4136 m .52189 .41719 L .52018 .41594 L F
.687 .964 .736 r
.44089 .54718 m .43776 .54994 L .44 .54867 L F
.13 .114 .57 r
.24365 .60878 m .24431 .61018 L .24307 .60986 L F
.719 .377 .4 r
.24486 .60757 m .24431 .61018 L .24307 .60755 L F
.13 .114 .57 r
.24393 .60825 m .24431 .61018 L .24365 .60878 L F
.24393 .60825 m .24431 .61018 L .24307 .60986 L F
.719 .377 .4 r
.24307 .60755 m .24431 .61018 L .24273 .60755 L F
.345 .041 .298 r
.24667 .60936 m .24486 .60757 L .2486 .60659 L F
.24667 .60936 m .24431 .61018 L .24486 .60757 L F
.897 .586 .45 r
.39902 .65566 m .39596 .652 L .39503 .65519 L F
.596 .068 0 r
.39775 .65685 m .39902 .65566 L .39503 .65519 L F
.822 .364 .137 r
.39775 .65685 m .40036 .65792 L .39902 .65566 L F
0 0 .136 r
.70146 .27874 m .70014 .28258 L .70159 .28033 L F
.732 .986 .786 r
.70159 .28033 m .70014 .28258 L .69873 .2828 L F
0 0 0 r
.57861 .42227 m .57673 .42371 L .57556 .42526 L F
.725 .24 0 r
.37172 .51225 m .37353 .51483 L .3748 .51562 L F
.907 .556 .091 r
.37358 .51483 m .3748 .51562 L .37353 .51483 L F
.37358 .51483 m .3747 .51678 L .3748 .51562 L F
.369 .404 .766 r
.47212 .54755 m .47007 .54957 L .46903 .54559 L F
.329 .341 .721 r
.47212 .54755 m .47263 .55144 L .47007 .54957 L F
.657 .434 .57 r
.43276 .48468 m .43272 .48746 L .4298 .4869 L F
.339 .148 .468 r
.36214 .56153 m .36248 .56436 L .35969 .56521 L F
.54 .464 .718 r
.36248 .56436 m .35994 .568 L .35969 .56521 L F
.427 .847 .959 r
.26721 .63589 m .2716 .63556 L .26889 .63494 L F
.548 0 0 r
.2716 .63556 m .27205 .63658 L .26889 .63494 L F
.2716 .63556 m .27463 .63767 L .27205 .63658 L F
.946 .587 .268 r
.39994 .57443 m .4008 .57514 L .40098 .57565 L F
.891 .603 .093 r
.41152 .55809 m .41263 .56194 L .41191 .56064 L F
.955 .661 .224 r
.41318 .56442 m .41191 .56064 L .41263 .56194 L F
.736 .816 .914 r
.50182 .43607 m .49895 .43852 L .49805 .43588 L F
.413 .567 .897 r
.36532 .6872 m .36729 .69046 L .36938 .6901 L F
.14 .302 .767 r
.36729 .69046 m .37019 .69339 L .36938 .6901 L F
.47 .413 .712 r
.34163 .65466 m .33864 .6522 L .34136 .6516 L F
.34163 .65466 m .33921 .65478 L .33864 .6522 L F
.34163 .65466 m .33864 .6522 L .34136 .6516 L F
.34163 .65466 m .33921 .65478 L .33864 .6522 L F
.675 .19 .089 r
.41403 .49395 m .41676 .49614 L .4189 .49527 L F
.884 .99 .795 r
.4189 .49527 m .41676 .49614 L .41916 .4932 L F
.766 .896 .934 r
.43753 .46177 m .4388 .45839 L .44005 .46047 L F
.43753 .46177 m .43591 .46067 L .4388 .45839 L F
.82 .867 .882 r
.48906 .4398 m .48946 .4423 L .48618 .44229 L F
.717 .803 .918 r
.49296 .43997 m .48946 .4423 L .48906 .4398 L F
0 .038 .565 r
.59637 .41372 m .59358 .4106 L .59559 .41319 L F
.962 .63 .312 r
.59539 .41577 m .59637 .41372 L .59559 .41319 L F
.59539 .41577 m .59699 .41672 L .59637 .41372 L F
.793 .732 .796 r
.28674 .52634 m .2913 .52681 L .28941 .52597 L F
.28674 .52634 m .28798 .52952 L .2913 .52681 L F
.678 .92 .973 r
.2913 .52681 m .28941 .52597 L .29169 .52476 L F
.2913 .52681 m .28941 .52597 L .29169 .52476 L F
.261 0 .151 r
.31721 .59438 m .3177 .59593 L .31754 .59322 L F
.31721 .59438 m .31546 .59658 L .3177 .59593 L F
.765 .935 .584 r
.31003 .64079 m .30958 .64224 L .30788 .64399 L F
.27 0 .216 r
.33784 .68347 m .33553 .68426 L .33536 .68547 L F
.757 .519 .572 r
.33745 .51262 m .34107 .51373 L .34175 .51031 L F
.432 .553 .877 r
.33975 .50726 m .34175 .51031 L .34332 .50866 L F
.407 .192 .473 r
.34306 .51301 m .34175 .51031 L .34332 .50866 L F
.34306 .51301 m .34107 .51373 L .34175 .51031 L F
0 0 0 r
.34175 .51031 m .34182 .5117 L .34332 .50866 L F
.34175 .51031 m .34107 .51373 L .34182 .5117 L F
.432 .553 .877 r
.33975 .50726 m .34175 .51031 L .34332 .50866 L F
.454 .309 .594 r
.46911 .51675 m .46953 .51957 L .46712 .52022 L F
.492 .364 .633 r
.46953 .51957 m .46738 .523 L .46712 .52022 L F
.418 .676 .969 r
.39582 .48488 m .39796 .48455 L .39468 .48309 L F
0 0 0 r
.34415 .62255 m .34541 .62067 L .34769 .61892 L F
.913 .906 .803 r
.60833 .37986 m .60861 .37651 L .60668 .37851 L F
.326 0 0 r
.25406 .52605 m .25355 .52755 L .2482 .52684 L F
0 0 0 r
.25478 .52639 m .25355 .52755 L .25406 .52605 L F
.419 .825 .978 r
.25755 .61886 m .2567 .61835 L .26065 .61838 L F
.577 .866 .995 r
.43537 .50057 m .43951 .50083 L .43796 .49965 L F
.81 .747 .794 r
.43951 .50083 m .43537 .50057 L .43796 .49965 L F
.717 .525 .63 r
.44372 .52011 m .44676 .5224 L .44706 .52059 L F
.44372 .52011 m .44371 .52323 L .44676 .5224 L F
.549 .487 .738 r
.45496 .57155 m .45636 .56756 L .45422 .56827 L F
.45496 .57155 m .45743 .5709 L .45636 .56756 L F
.368 .831 .907 r
.45622 .57068 m .45496 .57155 L .45368 .57156 L F
.45622 .57068 m .45743 .5709 L .45496 .57155 L F
.479 .005 .051 r
.73351 .33118 m .73718 .33046 L .7342 .3315 L F
.73351 .33118 m .73664 .33199 L .73718 .33046 L F
.612 .925 .682 r
.73694 .33107 m .73664 .33199 L .73623 .33162 L F
0 0 0 r
.7365 .33243 m .73718 .33046 L .73664 .33199 L F
.612 .925 .682 r
.73846 .32988 m .73664 .33199 L .73694 .33107 L F
0 0 0 r
.7359 .3342 m .7365 .33243 L .73664 .33199 L F
.375 .497 .854 r
.21648 .59651 m .21629 .59253 L .21497 .59502 L F
.21648 .59651 m .21811 .59609 L .21629 .59253 L F
.109 .629 .884 r
.59189 .46192 m .5903 .46128 L .58763 .46107 L F
.385 0 0 r
.59452 .46225 m .5903 .46128 L .59189 .46192 L F
.584 .456 .671 r
.29709 .6332 m .29783 .63581 L .30003 .63225 L F
0 .224 .732 r
.27539 .63914 m .2779 .64097 L .27572 .6384 L F
.424 .456 .789 r
.33758 .56619 m .33811 .57091 L .33584 .56885 L F
.33758 .56619 m .34015 .57104 L .33811 .57091 L F
.746 .652 .757 r
.50865 .43352 m .50967 .43701 L .50594 .43668 L F
.817 .554 .541 r
.50865 .43352 m .51237 .43641 L .50967 .43701 L F
.663 .539 .702 r
.51237 .43641 m .5097 .43958 L .50967 .43701 L F
.223 0 0 r
.55628 .4679 m .55748 .46923 L .55496 .46935 L F
.55628 .4679 m .5589 .4674 L .55748 .46923 L F
.614 .945 .941 r
.57773 .46225 m .5787 .46264 L .58007 .46106 L F
.764 .704 .795 r
.56723 .3975 m .56892 .4019 L .56527 .39992 L F
.779 .286 .037 r
.56527 .39992 m .56892 .4019 L .56761 .40237 L F
.703 .673 .818 r
.5698 .39889 m .56892 .4019 L .56723 .3975 L F
.34 .679 .978 r
.34481 .60374 m .34505 .6019 L .34258 .60231 L F
.69 .209 .103 r
.24865 .55713 m .25301 .55806 L .25063 .556 L F
.035 .259 .758 r
.25063 .556 m .2534 .55594 L .25599 .55618 L F
.25063 .556 m .25301 .55806 L .2534 .55594 L F
.513 .847 .997 r
.28538 .64776 m .28756 .64855 L .29005 .64792 L F
.404 .484 .828 r
.28756 .64855 m .29061 .65079 L .29005 .64792 L F
.702 .605 .745 r
.33653 .5519 m .3377 .55584 L .33313 .5542 L F
.56 .519 .766 r
.3401 .55491 m .3377 .55584 L .33653 .5519 L F
.885 .6 .085 r
.40341 .53293 m .40254 .53169 L .40234 .5291 L F
.959 .744 .295 r
.40341 .53293 m .40267 .53313 L .40254 .53169 L F
.40341 .53293 m .40335 .53544 L .40267 .53313 L F
.816 .807 .842 r
.34107 .51373 m .33808 .51613 L .34161 .51581 L F
.762 .256 0 r
.70993 .31332 m .71262 .31612 L .71303 .3149 L F
.669 .139 0 r
.71303 .3149 m .71262 .31612 L .71438 .31603 L F
.502 0 0 r
.27967 .64174 m .28058 .64315 L .2779 .64097 L F
.27967 .64174 m .28192 .64277 L .28058 .64315 L F
.67 .443 .567 r
.52206 .46806 m .51943 .47095 L .51946 .46858 L F
.326 .009 .266 r
.31011 .61652 m .31256 .61772 L .31353 .61357 L F
.139 0 .2 r
.31353 .61357 m .3149 .61497 L .31549 .61247 L F
.31353 .61357 m .31256 .61772 L .3149 .61497 L F
.609 .551 .764 r
.47104 .54113 m .46903 .54559 L .46821 .54348 L F
0 .383 .694 r
.33888 .63296 m .34117 .63378 L .33916 .6331 L F
0 0 .088 r
.33916 .6331 m .33935 .63455 L .33888 .63296 L F
.626 .418 .581 r
.51022 .47189 m .51024 .47457 L .5075 .47495 L F
.621 .402 .564 r
.5129 .4716 m .51024 .47457 L .51022 .47189 L F
.195 0 0 r
.30913 .64672 m .3139 .64564 L .31188 .64731 L F
.826 .806 .832 r
.70103 .32302 m .69973 .32465 L .69795 .32285 L F
0 0 0 r
.69973 .32465 m .69893 .32533 L .69795 .32285 L F
0 0 .25 r
.69893 .32533 m .69985 .32573 L .69962 .32494 L F
0 0 0 r
.69973 .32465 m .69852 .32557 L .69893 .32533 L F
0 0 .25 r
.69893 .32533 m .69962 .32494 L .69914 .32326 L F
0 0 0 r
.69852 .32557 m .6971 .32666 L .69893 .32533 L F
.888 .99 .761 r
.3373 .65596 m .33921 .65478 L .33604 .65889 L F
0 0 .378 r
.33985 .65577 m .33921 .65478 L .34163 .65466 L F
.228 0 0 r
.34163 .65466 m .33921 .65478 L .3373 .65596 L F
.879 .863 .82 r
.55165 .42273 m .55319 .42407 L .55566 .42014 L F
.73 .203 0 r
.55319 .42407 m .55488 .42215 L .55165 .42273 L F
.55319 .42407 m .55182 .4246 L .55488 .42215 L F
.55319 .42407 m .555 .42618 L .55182 .4246 L F
.736 .219 0 r
.55319 .42407 m .555 .42618 L .55699 .42665 L F
.138 0 .049 r
.35593 .59938 m .35701 .59773 L .35911 .59681 L F
.827 .797 .824 r
.63192 .40333 m .63093 .40845 L .62916 .40661 L F
.586 .012 0 r
.22989 .60526 m .22556 .60338 L .22977 .60655 L F
.22989 .60526 m .22795 .60516 L .22556 .60338 L F
.892 .805 .324 r
.22963 .60187 m .22989 .60526 L .23031 .60106 L F
.116 0 .075 r
.23 .60845 m .23378 .60427 L .22996 .60612 L F
.23 .60845 m .23155 .60814 L .23378 .60427 L F
.585 .01 0 r
.23238 .6064 m .23074 .60561 L .23023 .60425 L F
.421 .868 .86 r
.23023 .60425 m .22989 .60526 L .2297 .60282 L F
.23023 .60425 m .22795 .60516 L .22989 .60526 L F
.503 0 0 r
.23023 .60425 m .22621 .60359 L .22795 .60516 L F
.585 .01 0 r
.23074 .60561 m .22819 .60438 L .23023 .60425 L F
.421 .868 .86 r
.23023 .60425 m .2297 .60282 L .22963 .60187 L F
.274 .332 .741 r
.34276 .63023 m .34117 .63378 L .33888 .63296 L F
.023 0 0 r
.44833 .51569 m .44471 .51745 L .44707 .51752 L F
.511 .512 .794 r
.39169 .68091 m .39457 .68121 L .39286 .6768 L F
.799 .941 .92 r
.6696 .31416 m .6708 .31133 L .67282 .31135 L F
.6696 .31416 m .6689 .313 L .6708 .31133 L F
.685 .624 .782 r
.33832 .54881 m .33653 .5519 L .33616 .54916 L F
.918 .699 .204 r
.36456 .52174 m .36417 .52166 L .36479 .51957 L F
.399 .679 .974 r
.36479 .51957 m .36696 .51765 L .36304 .51746 L F
.18 0 0 r
.36479 .51957 m .36715 .52068 L .36696 .51765 L F
.36479 .51957 m .36417 .52166 L .36715 .52068 L F
.789 .836 .888 r
.42353 .47297 m .41921 .4739 L .4224 .47111 L F
.811 .937 .912 r
.42542 .47107 m .42353 .47297 L .4224 .47111 L F
.728 .571 .677 r
.33731 .53976 m .33475 .54274 L .33455 .53965 L F
.33731 .53976 m .33475 .54274 L .33455 .53965 L F
.484 .555 .853 r
.33653 .53438 m .33983 .53883 L .33731 .53976 L F
.777 .947 .612 r
.54099 .40519 m .54222 .40427 L .54025 .40409 L F
0 0 .45 r
.5397 .40059 m .54099 .40519 L .54025 .40409 L F
.122 .375 .834 r
.5397 .40059 m .54025 .40409 L .53769 .40199 L F
.984 .814 .594 r
.5397 .40059 m .53915 .40372 L .54099 .40519 L F
.437 .77 .997 r
.53915 .40372 m .54124 .40423 L .54099 .40519 L F
.777 .947 .612 r
.54099 .40519 m .54064 .40657 L .54222 .40427 L F
.801 .778 .832 r
.54511 .40355 m .54269 .40648 L .54099 .40519 L F
.54511 .40355 m .54099 .40519 L .54342 .40476 L F
.437 .77 .997 r
.54124 .40423 m .54342 .40476 L .54099 .40519 L F
.777 .947 .612 r
.54099 .40519 m .53981 .40777 L .54064 .40657 L F
.381 .128 .4 r
.54099 .40519 m .53819 .40869 L .53981 .40777 L F
.904 .519 .084 r
.39767 .56363 m .39976 .56728 L .39897 .56461 L F
.69 .624 .778 r
.34665 .55206 m .34277 .54888 L .34691 .54923 L F
.743 .661 .769 r
.3461 .54702 m .34691 .54923 L .34959 .54727 L F
.738 .92 .953 r
.3893 .48761 m .3875 .48853 L .38786 .48639 L F
.442 .225 .487 r
.38786 .48639 m .38752 .48894 L .38993 .48827 L F
.671 .139 0 r
.38993 .48827 m .3865 .48523 L .38786 .48639 L F
.3865 .48523 m .38614 .48492 L .38786 .48639 L F
.738 .92 .953 r
.39026 .48712 m .3893 .48761 L .38786 .48639 L F
0 0 0 r
.3875 .48853 m .38752 .48894 L .38786 .48639 L F
.3875 .48853 m .38628 .49094 L .38752 .48894 L F
0 .226 .667 r
.71585 .31695 m .71735 .31811 L .71438 .31603 L F
.531 .859 .996 r
.71956 .31618 m .71735 .31811 L .71585 .31695 L F
.71956 .31618 m .72059 .31716 L .71735 .31811 L F
.996 .867 .559 r
.40063 .68033 m .40148 .67767 L .39963 .67603 L F
.702 .283 .248 r
.39555 .48826 m .39843 .49057 L .39998 .48801 L F
.285 .099 .444 r
.40251 .48386 m .39998 .48801 L .40188 .48701 L F
.232 0 .003 r
.39998 .48801 m .40126 .48856 L .40188 .48701 L F
.39998 .48801 m .39843 .49057 L .40126 .48856 L F
0 0 0 r
.26704 .57354 m .26852 .57325 L .27049 .57225 L F
.396 0 0 r
.27049 .57225 m .26852 .57325 L .27247 .57318 L F
.819 .542 .52 r
.2987 .62607 m .29833 .6292 L .2944 .62813 L F
.04 .61 .736 r
.30139 .62599 m .30131 .62603 L .2987 .62607 L F
.836 .435 .287 r
.29863 .62702 m .30139 .62599 L .29948 .6254 L F
.256 .749 .668 r
.30147 .62595 m .30139 .62599 L .29863 .62702 L F
.30323 .6253 m .30139 .62599 L .30147 .62595 L F
.04 .61 .736 r
.30139 .62599 m .30259 .62601 L .30131 .62603 L F
.122 .375 .834 r
.5397 .40059 m .53769 .40199 L .53736 .40085 L F
.852 .73 .728 r
.64014 .35153 m .64411 .34963 L .64263 .34811 L F
.64014 .35153 m .64254 .35312 L .64411 .34963 L F
.844 .899 .876 r
.64411 .34963 m .64572 .34533 L .64263 .34811 L F
.64411 .34963 m .64702 .34665 L .64572 .34533 L F
.392 .68 .975 r
.63972 .38302 m .6385 .3853 L .63633 .38187 L F
.515 .193 .36 r
.64143 .38547 m .64204 .38453 L .6385 .3853 L F
.234 0 0 r
.6385 .3853 m .64204 .38453 L .64134 .38506 L F
.854 .892 .863 r
.64323 .38112 m .64166 .38493 L .63972 .38302 L F
.64166 .38493 m .64143 .38547 L .6412 .38514 L F
.643 .725 .908 r
.64167 .38489 m .64204 .38453 L .64143 .38547 L F
.64323 .38112 m .64204 .38453 L .64167 .38489 L F
.392 .68 .975 r
.6412 .38513 m .6412 .38514 L .6385 .3853 L F
.6412 .38514 m .64143 .38547 L .64016 .38539 L F
.6412 .38514 m .64016 .38539 L .6385 .3853 L F
.076 .637 .77 r
.64134 .38506 m .64154 .38502 L .64146 .38508 L F
.64127 .38512 m .64146 .38508 L .64056 .38567 L F
.64134 .38506 m .64146 .38508 L .64127 .38512 L F
.643 .725 .908 r
.64323 .38112 m .64471 .38448 L .64204 .38453 L F
.371 .557 .905 r
.64612 .38241 m .64471 .38448 L .64323 .38112 L F
0 0 0 r
.64514 .38425 m .64471 .38448 L .64612 .38241 L F
.076 .637 .77 r
.64154 .38502 m .64514 .38425 L .64103 .38552 L F
.64154 .38502 m .64103 .38552 L .64056 .38567 L F
.64204 .38453 m .64241 .38449 L .64134 .38506 L F
.854 .892 .863 r
.64166 .38493 m .6412 .38514 L .64134 .38506 L F
.076 .637 .77 r
.64204 .38453 m .64471 .38448 L .64514 .38425 L F
.64241 .38449 m .64514 .38425 L .64134 .38506 L F
.854 .892 .863 r
.64134 .38506 m .6412 .38514 L .6412 .38513 L F
.64166 .38493 m .6412 .38513 L .63972 .38302 L F
.234 0 0 r
.6412 .38513 m .64134 .38506 L .64127 .38512 L F
.6385 .3853 m .64134 .38506 L .6412 .38513 L F
.6385 .3853 m .64127 .38512 L .64056 .38567 L F
.392 .68 .975 r
.63972 .38302 m .6412 .38513 L .6385 .3853 L F
.234 0 0 r
.6385 .3853 m .64056 .38567 L .63845 .38759 L F
.742 .987 .895 r
.67432 .30989 m .67282 .31135 L .67423 .30893 L F
.733 .978 .919 r
.67423 .30893 m .67282 .31135 L .6708 .31133 L F
.722 .925 .96 r
.67443 .38402 m .67671 .38096 L .67342 .38259 L F
.67443 .38402 m .67784 .38195 L .67671 .38096 L F
.237 0 .324 r
.21486 .56184 m .21666 .56108 L .21732 .55846 L F
0 0 0 r
.21732 .55846 m .21888 .55714 L .21968 .55476 L F
.197 .053 .448 r
.21666 .56108 m .21888 .55714 L .21732 .55846 L F
.205 0 0 r
.36786 .69747 m .36347 .70039 L .36665 .69874 L F
.36842 .69688 m .36772 .69738 L .36786 .69747 L F
.36772 .69738 m .36347 .70039 L .36786 .69747 L F
.36842 .69688 m .36665 .69874 L .36676 .69683 L F
.376 0 0 r
.36868 .69799 m .36676 .69683 L .36513 .69589 L F
.36912 .69825 m .36853 .6979 L .36868 .69799 L F
.36853 .6979 m .36676 .69683 L .36868 .69799 L F
0 0 .337 r
.37019 .69339 m .36842 .69688 L .37088 .69639 L F
.211 0 0 r
.36912 .69825 m .36842 .69688 L .36676 .69683 L F
.36912 .69825 m .37088 .69639 L .36842 .69688 L F
.132 .41 .857 r
.57738 .38995 m .57637 .39122 L .57558 .38931 L F
.118 .389 .844 r
.57738 .38995 m .57939 .39286 L .57637 .39122 L F
.971 .8 .375 r
.41372 .57796 m .41248 .57889 L .41301 .57628 L F
.41372 .57796 m .41338 .5808 L .41248 .57889 L F
.353 .267 .618 r
.35706 .61246 m .35878 .61312 L .35892 .60978 L F
.419 .799 .992 r
.57077 .38758 m .57219 .38851 L .56824 .38804 L F
.058 .555 .887 r
.57077 .38758 m .57558 .38931 L .57219 .38851 L F
.135 .66 .877 r
.44069 .49113 m .43964 .49068 L .43666 .49056 L F
.43666 .49056 m .43964 .49068 L .44069 .49113 L F
.252 0 .105 r
.46175 .58757 m .46067 .59006 L .45844 .59 L F
.676 .965 .933 r
.44166 .48929 m .43964 .49068 L .44069 .49113 L F
.44166 .48929 m .43964 .49068 L .44069 .49113 L F
.16 0 0 r
.46437 .58733 m .46067 .59006 L .46175 .58757 L F
.135 .66 .877 r
.44069 .49113 m .43964 .49068 L .43666 .49056 L F
.733 .419 .448 r
.38941 .60985 m .3857 .61252 L .38568 .60984 L F
.38941 .60985 m .3914 .61174 L .3857 .61252 L F
.794 .831 .881 r
.63349 .4022 m .63537 .40382 L .63192 .40333 L F
.788 .831 .886 r
.63849 .40087 m .63537 .40382 L .63349 .4022 L F
.944 .956 .739 r
.64731 .40444 m .64913 .40131 L .64722 .40205 L F
.867 .988 .835 r
.64851 .40037 m .64913 .40131 L .65185 .39814 L F
.911 .98 .768 r
.64722 .40205 m .64913 .40131 L .64851 .40037 L F
0 0 0 r
.31002 .61868 m .31256 .61772 L .31011 .61652 L F
.31002 .61868 m .3119 .61845 L .31256 .61772 L F
.02 0 0 r
.30921 .62088 m .3119 .61845 L .31002 .61868 L F
.529 .608 .876 r
.6276 .40016 m .62539 .40113 L .62386 .39741 L F
.348 .161 .48 r
.62534 .40362 m .62539 .40113 L .6276 .40016 L F
.351 .408 .78 r
.45082 .53899 m .45199 .54259 L .45352 .54187 L F
.501 .374 .64 r
.45178 .54539 m .45352 .54187 L .45199 .54259 L F
.882 .756 .718 r
.55683 .39456 m .55251 .3968 L .55485 .39307 L F
.57 .82 .992 r
.55937 .39364 m .55683 .39456 L .55485 .39307 L F
.669 .424 .541 r
.5607 .39699 m .55683 .39456 L .55937 .39364 L F
.5607 .39699 m .55664 .3972 L .55683 .39456 L F
.323 0 0 r
.38216 .66251 m .38451 .66121 L .37956 .66181 L F
.42 0 0 r
.38541 .66171 m .38451 .66121 L .38216 .66251 L F
0 .002 .565 r
.44332 .54375 m .44183 .54194 L .4442 .54186 L F
0 0 0 r
.27701 .53931 m .27559 .54237 L .27507 .54234 L F
.519 .32 .551 r
.27751 .5433 m .27507 .54234 L .27559 .54237 L F
.922 .587 .387 r
.60112 .40119 m .60337 .40423 L .60219 .40273 L F
0 0 .434 r
.60337 .40423 m .6043 .40504 L .60219 .40273 L F
.60337 .40423 m .60456 .40702 L .6043 .40504 L F
0 0 .168 r
.24667 .60936 m .24607 .61151 L .24431 .61018 L F
.24667 .60936 m .24736 .61288 L .24607 .61151 L F
.501 .563 .85 r
.42685 .53604 m .4309 .5411 L .43215 .53828 L F
.473 0 0 r
.39133 .59311 m .38834 .59146 L .38941 .59082 L F
.691 .19 0 r
.3579 .50174 m .35894 .50229 L .35514 .50012 L F
.3579 .50174 m .35945 .50303 L .35894 .50229 L F
.591 .433 .636 r
.35776 .58773 m .36059 .58751 L .36031 .58414 L F
.405 .084 .304 r
.35753 .59009 m .36059 .58751 L .35776 .58773 L F
.548 .529 .786 r
.35915 .58576 m .35753 .59009 L .35776 .58773 L F
.991 .872 .613 r
.33612 .62662 m .33702 .62299 L .33837 .62546 L F
.755 .394 .37 r
.33405 .62487 m .33837 .62546 L .33702 .62299 L F
.401 0 0 r
.34772 .54665 m .35194 .54583 L .34959 .54727 L F
.676 .628 .794 r
.23759 .60235 m .23922 .59979 L .23592 .60267 L F
.23759 .60235 m .24138 .60326 L .23922 .59979 L F
0 0 .107 r
.3188 .60692 m .32008 .60576 L .32034 .60323 L F
0 0 .013 r
.3188 .60692 m .31913 .60795 L .32008 .60576 L F
.3188 .60692 m .3183 .60947 L .31913 .60795 L F
.215 .041 .417 r
.21472 .56455 m .21666 .56108 L .21486 .56184 L F
.743 .977 .731 r
.66244 .37413 m .65887 .37777 L .6625 .3766 L F
.213 0 .248 r
.66527 .37376 m .66244 .37413 L .6625 .3766 L F
.016 0 0 r
.34985 .60627 m .34867 .60685 L .35174 .60403 L F
0 0 .16 r
.34985 .60627 m .34884 .60966 L .34867 .60685 L F
.771 .709 .793 r
.35011 .55805 m .35281 .56216 L .34852 .56217 L F
.064 0 0 r
.35281 .56216 m .34775 .56276 L .34852 .56217 L F
.35281 .56216 m .35101 .56259 L .34775 .56276 L F
.726 .862 .44 r
.35473 .55853 m .35281 .56216 L .35448 .56108 L F
.52 .61 .883 r
.35448 .56108 m .35281 .56216 L .35011 .55805 L F
.882 .888 .832 r
.35448 .56108 m .35101 .56259 L .35281 .56216 L F
.089 0 .194 r
.35281 .56216 m .35196 .56438 L .35448 .56108 L F
.986 .707 .368 r
.32398 .49637 m .32551 .49763 L .32375 .49683 L F
.495 .025 .067 r
.32372 .49681 m .32486 .49661 L .32398 .49637 L F
.32372 .49681 m .32398 .49637 L .32141 .49567 L F
.986 .707 .368 r
.32479 .49473 m .32483 .49489 L .32398 .49637 L F
.32483 .49489 m .32551 .49763 L .32398 .49637 L F
.877 .442 .062 r
.32398 .49637 m .32479 .49473 L .32141 .49567 L F
.986 .707 .368 r
.32479 .49473 m .32375 .49683 L .32372 .49681 L F
.877 .442 .062 r
.32485 .49645 m .32479 .49473 L .32458 .49654 L F
.687 .833 .4 r
.32587 .49686 m .32584 .49733 L .32479 .49473 L F
.736 .965 .937 r
.32567 .49617 m .3259 .49696 L .32638 .49592 L F
.687 .833 .4 r
.3259 .49693 m .3259 .49696 L .32587 .49686 L F
.3259 .49696 m .32584 .49733 L .32587 .49686 L F
.868 .472 .005 r
.32584 .49733 m .32551 .49763 L .32479 .49473 L F
.736 .965 .937 r
.32376 .49682 m .32565 .49749 L .3259 .49696 L F
.32376 .49682 m .32587 .49686 L .32485 .49645 L F
.877 .442 .062 r
.32486 .49661 m .3259 .49693 L .32587 .49686 L F
.32485 .49641 m .32564 .49641 L .32479 .49473 L F
.687 .833 .4 r
.3259 .49696 m .32749 .49436 L .32584 .49733 L F
.32595 .49686 m .32749 .49436 L .3259 .49696 L F
.868 .472 .005 r
.32584 .49733 m .32717 .50045 L .32551 .49763 L F
.516 .546 .825 r
.32717 .50045 m .3279 .49616 L .32551 .49763 L F
.225 0 0 r
.32652 .49644 m .32595 .49686 L .32607 .49679 L F
.251 .367 .787 r
.32929 .49611 m .32985 .5006 L .33061 .49713 L F
.32807 .49516 m .32836 .49606 L .32929 .49611 L F
.32836 .49606 m .32985 .5006 L .32929 .49611 L F
.225 0 0 r
.32708 .496 m .32647 .49645 L .32652 .49644 L F
.32985 .4938 m .32705 .496 L .32708 .496 L F
.32705 .496 m .32647 .49645 L .32708 .496 L F
.32647 .49645 m .32595 .49686 L .32652 .49644 L F
.516 .546 .825 r
.32717 .50045 m .32985 .5006 L .32836 .49606 L F
.3279 .49616 m .32836 .49606 L .32807 .49516 L F
.32717 .50045 m .32836 .49606 L .3279 .49616 L F
.225 0 0 r
.32985 .4938 m .3259 .49693 L .32807 .49516 L F
.516 .546 .825 r
.3279 .49616 m .32807 .49516 L .3267 .49648 L F
.3279 .49616 m .3267 .49648 L .32551 .49763 L F
.225 0 0 r
.32985 .4938 m .32749 .49436 L .32608 .49665 L F
.32629 .49659 m .32608 .49665 L .32595 .49686 L F
.32985 .4938 m .32608 .49665 L .32629 .49659 L F
.736 .965 .937 r
.32595 .49686 m .32565 .49749 L .3267 .49648 L F
.687 .833 .4 r
.3259 .49693 m .32595 .49686 L .3259 .49696 L F
.225 0 0 r
.32607 .49679 m .32595 .49686 L .3259 .49693 L F
.736 .965 .937 r
.32645 .49578 m .32595 .49686 L .32807 .49516 L F
.32595 .49686 m .3267 .49648 L .32807 .49516 L F
.32448 .49641 m .32536 .49611 L .32454 .49639 L F
.32536 .49611 m .32807 .49516 L .32538 .4961 L F
.32536 .49611 m .32538 .4961 L .32454 .49639 L F
.738 .981 .912 r
.32807 .49516 m .32538 .4961 L .32725 .49422 L F
0 0 0 r
.32606 .49559 m .32725 .49422 L .32538 .4961 L F
.736 .965 .937 r
.32477 .49641 m .32807 .49516 L .32448 .49641 L F
.877 .442 .062 r
.32485 .49645 m .32564 .49641 L .32485 .49641 L F
.736 .965 .937 r
.32376 .49682 m .32638 .49592 L .32645 .49578 L F
.738 .981 .912 r
.32807 .49516 m .32486 .49661 L .32538 .4961 L F
0 0 0 r
.32606 .49559 m .32538 .4961 L .32486 .49661 L F
.736 .965 .937 r
.32454 .49639 m .32807 .49516 L .32606 .49559 L F
.32372 .49681 m .32477 .49641 L .32448 .49641 L F
.877 .442 .062 r
.32485 .49645 m .32587 .49686 L .32564 .49641 L F
.32486 .49661 m .32587 .49686 L .32485 .49645 L F
.736 .965 .937 r
.32376 .49682 m .3259 .49696 L .32587 .49686 L F
.32485 .49645 m .32587 .49686 L .32567 .49617 L F
.32372 .49681 m .32376 .49682 L .32645 .49578 L F
.877 .442 .062 r
.32458 .49654 m .32479 .49473 L .32398 .49637 L F
.32486 .49661 m .32485 .49645 L .32458 .49654 L F
.736 .965 .937 r
.32372 .49681 m .32551 .49763 L .32565 .49749 L F
0 0 .193 r
.41287 .58753 m .41291 .58611 L .41249 .58346 L F
.799 .653 .1 r
.41287 .58753 m .41259 .58879 L .41291 .58611 L F
.41287 .58753 m .4128 .59022 L .41259 .58879 L F
0 .517 .709 r
.33313 .5542 m .33142 .55401 L .32955 .55381 L F
0 0 0 r
.33313 .5542 m .33173 .55662 L .33226 .55622 L F
.33173 .55662 m .33082 .55819 L .33226 .55622 L F
0 .072 .633 r
.33226 .55622 m .33432 .55863 L .33282 .55579 L F
0 0 0 r
.33313 .5542 m .33226 .55622 L .33142 .55401 L F
.559 .431 .662 r
.33142 .55401 m .33226 .55622 L .33416 .55332 L F
.33142 .55401 m .33226 .55622 L .33416 .55332 L F
.881 .992 .759 r
.33226 .55622 m .33188 .55401 L .33416 .55332 L F
0 .072 .633 r
.33226 .55622 m .33282 .55579 L .33188 .55401 L F
.46 .261 .522 r
.44676 .5224 m .44941 .51973 L .44706 .52059 L F
.58 .499 .728 r
.4684 .51078 m .47105 .51013 L .46881 .51316 L F
.581 .5 .729 r
.46881 .51316 m .47105 .51013 L .47143 .51279 L F
.43 .278 .573 r
.47143 .51279 m .46911 .51675 L .46881 .51316 L F
.751 .869 .934 r
.3857 .61252 m .3914 .61174 L .38778 .61406 L F
.381 .783 .985 r
.31766 .63815 m .31889 .63899 L .31484 .63855 L F
.637 .157 .096 r
.31484 .63855 m .31889 .63899 L .31654 .64041 L F
.984 .881 .647 r
.31654 .64041 m .31889 .63899 L .31766 .63815 L F
.474 .466 .768 r
.47065 .52484 m .46811 .52639 L .46738 .523 L F
.487 .372 .648 r
.47065 .52484 m .46842 .52939 L .46811 .52639 L F
.692 .808 .937 r
.44423 .46031 m .44005 .46047 L .44254 .45904 L F
.668 .885 .978 r
.44521 .45821 m .44423 .46031 L .44254 .45904 L F
.44521 .45821 m .44674 .45918 L .44423 .46031 L F
.082 0 0 r
.3289 .50052 m .33072 .50055 L .33062 .50074 L F
.809 .872 .894 r
.63059 .42648 m .63215 .42235 L .6289 .42488 L F
.63059 .42648 m .63352 .42393 L .63215 .42235 L F
.193 .386 .825 r
.23922 .59979 m .24138 .60326 L .24198 .60245 L F
.739 .878 .468 r
.39728 .59854 m .39889 .5963 L .39794 .59593 L F
.39728 .59854 m .39672 .60021 L .39889 .5963 L F
0 0 0 r
.70226 .2944 m .70454 .29004 L .70378 .2925 L F
.079 0 .053 r
.70378 .2925 m .70454 .29004 L .70685 .28962 L F
.125 .161 .628 r
.21441 .59041 m .21497 .59502 L .21629 .59253 L F
.987 .886 .549 r
.41391 .59425 m .41252 .59542 L .4122 .59221 L F
.41391 .59425 m .41315 .59682 L .41252 .59542 L F
.981 .691 .371 r
.60751 .41 m .60917 .41363 L .60759 .41231 L F
.876 .449 .04 r
.60759 .41231 m .60917 .41363 L .61004 .41592 L F
0 0 0 r
.59721 .45721 m .59632 .45783 L .59431 .45888 L F
.312 .362 .754 r
.59632 .45783 m .59724 .4607 L .59431 .45888 L F
.45 .221 .474 r
.31167 .54039 m .30901 .54438 L .3135 .53909 L F
.836 .938 .893 r
.66168 .38926 m .66573 .38774 L .66475 .38684 L F
.781 .971 .918 r
.66475 .38684 m .66573 .38774 L .66866 .3853 L F
.466 .32 .598 r
.2271 .57146 m .2296 .5735 L .22736 .57412 L F
.814 .534 .514 r
.34104 .60013 m .3405 .60324 L .33491 .60117 L F
.646 .371 .488 r
.34258 .60231 m .3405 .60324 L .34104 .60013 L F
.975 .915 .675 r
.69878 .29922 m .69959 .30153 L .70065 .29826 L F
.889 .653 .136 r
.69902 .30206 m .69959 .30153 L .69878 .29922 L F
.69902 .30206 m .69972 .30411 L .69959 .30153 L F
.975 .671 .366 r
.60652 .43572 m .60681 .43836 L .60815 .43911 L F
.926 .561 .311 r
.6069 .44108 m .60815 .43911 L .60681 .43836 L F
.6069 .44108 m .60918 .44215 L .60815 .43911 L F
.18 .694 .893 r
.35211 .65241 m .35062 .65194 L .35063 .6485 L F
.692 .951 .954 r
.35062 .65194 m .35211 .65241 L .35431 .651 L F
.732 .851 .937 r
.45535 .45438 m .45336 .45832 L .45181 .45664 L F
.45535 .45438 m .45632 .45594 L .45336 .45832 L F
.212 0 0 r
.34464 .6802 m .34388 .68145 L .34506 .68102 L F
.198 0 .282 r
.34438 .68339 m .34506 .68102 L .34692 .68014 L F
0 0 .095 r
.35337 .6023 m .35174 .60403 L .35412 .60052 L F
.483 .187 .387 r
.3563 .60024 m .35412 .60052 L .35593 .59938 L F
.3563 .60024 m .35337 .6023 L .35412 .60052 L F
.484 .227 .449 r
.47819 .49441 m .47777 .49652 L .47526 .49709 L F
.568 .37 .573 r
.48031 .49351 m .47777 .49652 L .47819 .49441 L F
.766 .982 .729 r
.27264 .53644 m .27005 .53915 L .27066 .53742 L F
.761 .28 .095 r
.27066 .53742 m .27436 .53856 L .27264 .53644 L F
.762 .279 .089 r
.27264 .53644 m .27436 .53856 L .27701 .53931 L F
.598 .215 .288 r
.34569 .59941 m .34876 .59933 L .3497 .59701 L F
.056 0 .173 r
.3497 .59701 m .35153 .59635 L .35225 .59361 L F
.368 .107 .381 r
.34876 .59933 m .35153 .59635 L .3497 .59701 L F
.633 .361 .488 r
.23945 .5812 m .23881 .58366 L .23654 .5833 L F
.492 .325 .582 r
.24106 .58034 m .23881 .58366 L .23945 .5812 L F
.154 0 .361 r
.60124 .45904 m .60093 .46154 L .60286 .45783 L F
.793 .803 .861 r
.59865 .35774 m .60156 .36058 L .60311 .35852 L F
.271 .001 .307 r
.35337 .6023 m .34985 .60627 L .35174 .60403 L F
0 0 .24 r
.70065 .29826 m .70226 .2944 L .70139 .29598 L F
.834 .996 .76 r
.69878 .29922 m .70065 .29826 L .70139 .29598 L F
.963 .759 .581 r
.33319 .62907 m .33267 .62465 L .32931 .62653 L F
.885 .892 .47 r
.33405 .62487 m .33319 .62907 L .33612 .62662 L F
.324 0 0 r
.27444 .54589 m .27365 .54704 L .27165 .54632 L F
.056 .26 .754 r
.27165 .54632 m .27365 .54704 L .27232 .54438 L F
0 0 0 r
.24882 .52254 m .25093 .52173 L .25299 .52104 L F
.24882 .52254 m .24874 .52275 L .25093 .52173 L F
.087 0 .24 r
.32631 .58209 m .32763 .58251 L .32828 .5808 L F
.32631 .58209 m .32617 .58395 L .32763 .58251 L F
.02 .266 .766 r
.28192 .64277 m .28341 .64539 L .28404 .64388 L F
.628 .126 0 r
.28341 .64539 m .28538 .64776 L .28398 .64653 L F
.28341 .64539 m .28398 .64653 L .28404 .64388 L F
.666 .402 .51 r
.55705 .42905 m .56018 .42576 L .55699 .42665 L F
.55705 .42905 m .56017 .4289 L .56018 .42576 L F
.582 .39 .587 r
.56018 .42576 m .56387 .42606 L .56344 .42338 L F
.605 .373 .538 r
.56017 .4289 m .56387 .42606 L .56018 .42576 L F
.906 .728 .65 r
.24273 .60755 m .24307 .60986 L .23944 .60754 L F
.109 .156 .63 r
.24273 .60755 m .24431 .61018 L .24307 .60986 L F
.333 .71 .983 r
.38451 .5094 m .38533 .50805 L .38241 .50745 L F
.38451 .5094 m .38694 .50929 L .38533 .50805 L F
.732 .519 .603 r
.34897 .63192 m .35344 .62866 L .3503 .62987 L F
0 0 0 r
.39629 .60246 m .39625 .60268 L .39672 .60021 L F
.39629 .60246 m .39672 .60021 L .39728 .59854 L F
.239 .565 .937 r
.38831 .67413 m .39129 .67694 L .39286 .6768 L F
0 0 0 r
.6625 .3766 m .65887 .37777 L .65851 .37852 L F
.75 .807 .898 r
.62981 .344 m .62609 .34373 L .62843 .3424 L F
.727 .814 .919 r
.6322 .34258 m .62981 .344 L .62843 .3424 L F
.575 .672 .905 r
.28674 .51895 m .28114 .51551 L .28313 .51533 L F
0 0 .212 r
.28666 .51536 m .28674 .51895 L .28313 .51533 L F
.28666 .51536 m .28691 .51788 L .28674 .51895 L F
.83 .356 .036 r
.23571 .60589 m .23599 .60839 L .2377 .60757 L F
.23556 .60759 m .23599 .60839 L .23571 .60589 L F
.051 0 0 r
.2377 .60757 m .23599 .60839 L .23846 .60795 L F
.689 .324 .35 r
.2344 .60758 m .23599 .60839 L .23378 .60427 L F
.679 .365 .436 r
.23846 .60795 m .23599 .60839 L .2344 .60758 L F
0 0 0 r
.23846 .60795 m .23561 .61153 L .23685 .61015 L F
0 .005 .566 r
.23555 .60768 m .23685 .61015 L .23846 .60795 L F
.2344 .60758 m .23546 .60869 L .23555 .60768 L F
.23546 .60869 m .23685 .61015 L .23555 .60768 L F
.83 .356 .036 r
.23378 .60427 m .23556 .60759 L .23571 .60589 L F
.651 .841 .435 r
.23846 .60795 m .23685 .61015 L .23786 .60859 L F
.051 0 0 r
.2377 .60757 m .23846 .60795 L .23884 .60755 L F
.651 .841 .435 r
.23846 .60795 m .23786 .60859 L .23918 .60654 L F
.051 0 0 r
.23884 .60755 m .23846 .60795 L .23944 .60754 L F
.581 .477 .701 r
.22571 .58384 m .22293 .58102 L .22459 .58012 L F
.22571 .58384 m .22333 .58525 L .22293 .58102 L F
.552 .402 .63 r
.47062 .50717 m .47105 .51013 L .4684 .51078 L F
.796 .968 .662 r
.24984 .60588 m .24667 .60936 L .2486 .60659 L F
.384 .221 .534 r
.69607 .32963 m .6971 .32666 L .69621 .3273 L F
.964 .901 .71 r
.38625 .62337 m .38664 .6186 L .38521 .62237 L F
.967 .921 .701 r
.38403 .62457 m .38625 .62337 L .38521 .62237 L F
.484 .216 .432 r
.30872 .56182 m .30826 .56422 L .30582 .56442 L F
.311 .067 .374 r
.31038 .56302 m .30826 .56422 L .30872 .56182 L F
.449 .006 .104 r
.31145 .56178 m .31038 .56302 L .30872 .56182 L F
.241 0 0 r
.29433 .5159 m .29038 .51856 L .2928 .51762 L F
.826 .806 .832 r
.70103 .32302 m .69795 .32285 L .70011 .32138 L F
.874 .929 .857 r
.70251 .32141 m .70103 .32302 L .70011 .32138 L F
.73 .686 .807 r
.61682 .37842 m .61797 .37426 L .61563 .37473 L F
.61682 .37842 m .62012 .37563 L .61797 .37426 L F
.831 .554 .52 r
.53348 .40998 m .52855 .40926 L .52973 .40729 L F
.785 .789 .856 r
.53348 .40998 m .53069 .41116 L .52855 .40926 L F
.161 .227 .685 r
.53608 .41239 m .53348 .40998 L .53612 .4098 L F
.755 .659 .755 r
.60923 .39089 m .61343 .39144 L .61178 .38761 L F
.581 .056 0 r
.61164 .39206 m .61343 .39144 L .60923 .39089 L F
.641 .319 .411 r
.32789 .66309 m .32772 .66093 L .32497 .66298 L F
0 0 .456 r
.33072 .50055 m .3326 .50394 L .3317 .50209 L F
.506 .304 .54 r
.3326 .50394 m .33331 .50269 L .3317 .50209 L F
.3326 .50394 m .33519 .5058 L .33331 .50269 L F
.3326 .50394 m .33269 .50653 L .33519 .5058 L F
.812 .753 .797 r
.37165 .63564 m .36928 .6396 L .37038 .63717 L F
.418 .252 .547 r
.37147 .63875 m .36928 .6396 L .36935 .63948 L F
.37147 .63875 m .36935 .63948 L .37165 .63564 L F
.701 .267 .215 r
.37165 .63564 m .37406 .63806 L .37147 .63875 L F
.527 .815 .998 r
.37365 .63801 m .37147 .63875 L .37406 .63806 L F
.451 .329 .622 r
.37038 .63717 m .36928 .6396 L .37147 .63875 L F
.37038 .63717 m .37147 .63875 L .36968 .63752 L F
.527 .815 .998 r
.36968 .63752 m .37147 .63875 L .37365 .63801 L F
.612 .447 .635 r
.47526 .49709 m .47553 .49995 L .47246 .50031 L F
.519 .351 .593 r
.47553 .49995 m .47289 .50419 L .47246 .50031 L F
.676 .637 .803 r
.55566 .42014 m .55975 .42162 L .55846 .4196 L F
.712 .777 .903 r
.55975 .42162 m .56219 .42018 L .55846 .4196 L F
.729 .654 .774 r
.37173 .52967 m .376 .52996 L .37418 .52589 L F
.644 .546 .729 r
.37121 .53179 m .36841 .53271 L .3672 .52853 L F
.37121 .53179 m .3672 .52853 L .36833 .52952 L F
.37115 .53174 m .36833 .52952 L .36942 .53047 L F
.37121 .53179 m .36833 .52952 L .37115 .53174 L F
.832 .497 .422 r
.3672 .52853 m .36387 .52802 L .36316 .52544 L F
0 0 0 r
.36963 .5252 m .3672 .52853 L .3685 .52664 L F
0 0 .081 r
.3672 .52853 m .36799 .52833 L .36758 .52829 L F
0 0 0 r
.36963 .5252 m .36942 .52556 L .3672 .52853 L F
.36942 .52556 m .3676 .52828 L .36753 .52832 L F
.36732 .52836 m .36753 .52832 L .3672 .52853 L F
.36942 .52556 m .36753 .52832 L .36732 .52836 L F
.92 .549 .301 r
.36316 .52544 m .36387 .52802 L .36196 .52679 L F
.801 .646 .69 r
.36758 .52829 m .36196 .52679 L .36387 .52802 L F
.36799 .52833 m .36763 .52823 L .36758 .52829 L F
0 0 .081 r
.3672 .52853 m .36758 .52829 L .36387 .52802 L F
.801 .646 .69 r
.36763 .52823 m .36731 .52871 L .36626 .52788 L F
.741 .603 .703 r
.3672 .52853 m .36841 .53271 L .36475 .5319 L F
0 .142 .685 r
.36783 .52884 m .36798 .52921 L .36788 .52913 L F
.3678 .52882 m .36788 .52913 L .3672 .52853 L F
.36783 .52884 m .36788 .52913 L .3678 .52882 L F
.36767 .52868 m .36783 .52884 L .3672 .52853 L F
.628 .116 .011 r
.36841 .53271 m .36606 .53315 L .36475 .5319 L F
.976 .916 .667 r
.36606 .53315 m .36781 .52879 L .36475 .5319 L F
.36781 .52879 m .36767 .52868 L .36475 .5319 L F
0 0 .081 r
.3672 .52853 m .36475 .5319 L .36767 .52868 L F
.801 .646 .69 r
.36763 .52823 m .36196 .52679 L .36758 .52829 L F
.36741 .52879 m .36448 .53117 L .36626 .52788 L F
.65 .417 .553 r
.36448 .53117 m .36547 .53266 L .36314 .53179 L F
.36547 .53266 m .36525 .53304 L .36314 .53179 L F
.826 .436 .313 r
.36676 .53011 m .36448 .53117 L .36766 .52859 L F
.516 0 0 r
.36448 .53518 m .36848 .53507 L .36609 .53566 L F
.419 .347 .669 r
.3688 .5376 m .36609 .53566 L .36848 .53507 L F
.3688 .5376 m .36673 .53854 L .36609 .53566 L F
.516 0 0 r
.36448 .53518 m .36688 .53634 L .36848 .53507 L F
.664 .828 .401 r
.36448 .53518 m .36488 .53349 L .36688 .53634 L F
.715 .552 .667 r
.36601 .53349 m .3652 .53374 L .36534 .53309 L F
.664 .828 .401 r
.36488 .53349 m .36517 .53375 L .36548 .53421 L F
.36488 .53349 m .36548 .53421 L .36546 .53431 L F
.715 .552 .667 r
.36519 .53377 m .3636 .53653 L .36517 .53375 L F
0 0 0 r
.36216 .53798 m .3636 .53653 L .36448 .53518 L F
.664 .828 .401 r
.36448 .53518 m .3636 .53653 L .36458 .53482 L F
.715 .552 .667 r
.36549 .53414 m .3636 .53653 L .36519 .53377 L F
.624 .353 .487 r
.35644 .53841 m .35925 .5385 L .36066 .53564 L F
.715 .552 .667 r
.36479 .53386 m .3636 .53653 L .35911 .5356 L F
.36517 .53375 m .36459 .53477 L .36479 .53386 L F
.664 .828 .401 r
.36448 .53518 m .36458 .53482 L .36479 .53386 L F
.715 .552 .667 r
.36479 .53386 m .36493 .53325 L .36534 .53309 L F
.664 .828 .401 r
.36488 .53349 m .36479 .53386 L .3649 .5334 L F
.36448 .53518 m .36479 .53386 L .36488 .53349 L F
.715 .552 .667 r
.36493 .53382 m .36479 .53386 L .36534 .53309 L F
.36479 .53386 m .35911 .5356 L .36493 .53325 L F
.36459 .53477 m .3636 .53653 L .36479 .53386 L F
.664 .828 .401 r
.3649 .5334 m .36462 .53468 L .36497 .53311 L F
.36458 .53482 m .36462 .53468 L .3649 .5334 L F
.36458 .53482 m .3636 .53653 L .36462 .53468 L F
.868 .992 .745 r
.36462 .53468 m .3636 .53653 L .36549 .53414 L F
.715 .552 .667 r
.36601 .53349 m .36549 .53414 L .36517 .53375 L F
.868 .992 .745 r
.36552 .53403 m .3655 .53413 L .36601 .53349 L F
.09 .309 .788 r
.36727 .53467 m .36707 .53553 L .36555 .53378 L F
.664 .828 .401 r
.36517 .53375 m .36584 .53458 L .36688 .53634 L F
.715 .552 .667 r
.3652 .53374 m .36493 .53382 L .36505 .5336 L F
.3652 .53374 m .36505 .5336 L .36534 .53309 L F
.09 .309 .788 r
.36592 .53443 m .36553 .53405 L .36497 .53311 L F
.664 .828 .401 r
.36488 .53349 m .36497 .53311 L .36553 .53405 L F
.868 .992 .745 r
.36462 .53468 m .36554 .5339 L .36497 .53311 L F
.36554 .5339 m .36601 .53349 L .36497 .53311 L F
.09 .309 .788 r
.36707 .53553 m .36592 .53443 L .36497 .53311 L F
.36559 .53353 m .36555 .53378 L .36497 .53311 L F
.868 .992 .745 r
.36555 .53389 m .36552 .53403 L .36601 .53349 L F
.09 .309 .788 r
.36727 .53467 m .36555 .53378 L .36559 .53353 L F
.868 .992 .745 r
.36552 .53403 m .36549 .53414 L .3655 .53413 L F
.36462 .53468 m .36549 .53414 L .36555 .53389 L F
.664 .828 .401 r
.36546 .53431 m .36548 .53421 L .36688 .53634 L F
.36517 .53375 m .36553 .53405 L .36584 .53458 L F
.09 .309 .788 r
.36707 .53553 m .36688 .53634 L .36553 .53405 L F
.715 .552 .667 r
.36249 .53141 m .35911 .5356 L .36242 .53137 L F
.36534 .53309 m .36471 .53334 L .36249 .53141 L F
.36471 .53334 m .35911 .5356 L .36249 .53141 L F
.976 .916 .667 r
.36606 .53315 m .36532 .53312 L .36554 .53272 L F
.36532 .53312 m .36532 .53312 L .36534 .53309 L F
.36532 .53312 m .36534 .53309 L .36554 .53272 L F
.65 .417 .553 r
.36547 .53266 m .36552 .53274 L .36525 .53304 L F
.36552 .53274 m .36534 .53309 L .36525 .53304 L F
.826 .436 .313 r
.36497 .53311 m .36552 .53274 L .36448 .53117 L F
.976 .916 .667 r
.36781 .52879 m .36497 .53311 L .36606 .53315 L F
.36781 .52879 m .36799 .52833 L .36767 .52868 L F
.36799 .52833 m .36776 .52869 L .36781 .52879 L F
0 .142 .685 r
.36781 .52879 m .36783 .52884 L .36767 .52868 L F
.976 .916 .667 r
.36776 .52869 m .36497 .53311 L .36781 .52879 L F
.36799 .52833 m .36781 .52879 L .36942 .53047 L F
0 .142 .685 r
.36793 .52892 m .36942 .53047 L .36783 .52884 L F
.36783 .52884 m .36942 .53047 L .36798 .52921 L F
.976 .916 .667 r
.36781 .52879 m .36606 .53315 L .36942 .53047 L F
0 .142 .685 r
.36881 .52961 m .36942 .53047 L .36793 .52892 L F
.36881 .52961 m .36783 .52884 L .36781 .52879 L F
.65 .417 .553 r
.36552 .53274 m .36601 .53349 L .36534 .53309 L F
.826 .436 .313 r
.36497 .53311 m .36601 .53349 L .36552 .53274 L F
.976 .916 .667 r
.36646 .53211 m .36554 .53272 L .36768 .5289 L F
.36606 .53315 m .36554 .53272 L .36646 .53211 L F
.36768 .5289 m .36497 .53311 L .36776 .52869 L F
.36532 .53312 m .36497 .53311 L .36768 .5289 L F
.826 .436 .313 r
.36497 .53311 m .36448 .53117 L .36676 .53011 L F
.36497 .53311 m .36766 .52859 L .36776 .52869 L F
.28 .25 .645 r
.3663 .52813 m .36497 .53311 L .36691 .53003 L F
.36767 .52865 m .36691 .53003 L .36776 .52869 L F
.3663 .52813 m .36691 .53003 L .36767 .52865 L F
.65 .417 .553 r
.36448 .53117 m .36314 .53179 L .36242 .53137 L F
.826 .436 .313 r
.36776 .52869 m .36766 .52859 L .36799 .52833 L F
0 .142 .685 r
.36827 .52887 m .36881 .52961 L .36833 .52922 L F
.3678 .52872 m .36833 .52922 L .36767 .52868 L F
.36827 .52887 m .36833 .52922 L .3678 .52872 L F
0 0 .081 r
.3672 .52853 m .36767 .52868 L .36799 .52833 L F
.801 .646 .69 r
.36762 .52853 m .36741 .52879 L .36731 .52871 L F
.36799 .52833 m .36766 .52859 L .36762 .52853 L F
0 .142 .685 r
.36752 .52839 m .36774 .5287 L .3672 .52853 L F
.801 .646 .69 r
.36766 .52859 m .36741 .52879 L .36762 .52853 L F
.28 .25 .645 r
.36766 .52829 m .36776 .52869 L .36799 .52833 L F
.976 .916 .667 r
.36781 .52879 m .36776 .52869 L .36799 .52833 L F
.801 .646 .69 r
.36799 .52833 m .36731 .52871 L .36758 .52831 L F
.36799 .52833 m .36758 .52831 L .36763 .52823 L F
.04 .608 .757 r
.36784 .52826 m .3677 .52829 L .36799 .52833 L F
0 .142 .685 r
.36784 .52826 m .36827 .52887 L .36774 .5287 L F
.36784 .52826 m .36774 .5287 L .36752 .52839 L F
.28 .25 .645 r
.3663 .52813 m .36776 .52869 L .36766 .52829 L F
.976 .916 .667 r
.36606 .53315 m .36776 .52869 L .36781 .52879 L F
0 0 0 r
.36771 .52821 m .36784 .52826 L .3672 .52853 L F
.36796 .52806 m .36784 .52826 L .36771 .52821 L F
.143 0 0 r
.36784 .52826 m .37038 .52871 L .36818 .5284 L F
.04 .608 .757 r
.36784 .52826 m .3663 .52813 L .3677 .52829 L F
.143 0 0 r
.36784 .52826 m .36818 .5284 L .3663 .52813 L F
0 0 0 r
.36763 .52823 m .36796 .52806 L .3676 .52828 L F
.36942 .52556 m .36827 .52753 L .36763 .52823 L F
.36827 .52753 m .36796 .52806 L .36763 .52823 L F
.374 .704 .985 r
.36387 .52802 m .36395 .52757 L .36196 .52679 L F
.801 .646 .69 r
.36626 .52788 m .366 .52837 L .36196 .52679 L F
.374 .704 .985 r
.36395 .52757 m .3641 .52681 L .36196 .52679 L F
.801 .646 .69 r
.366 .52837 m .36448 .53117 L .36196 .52679 L F
.836 .873 .87 r
.37408 .52883 m .37121 .53179 L .36942 .53047 L F
.37408 .52883 m .37162 .5297 L .37195 .53003 L F
.37162 .5297 m .36942 .53047 L .37195 .53003 L F
.85 .93 .88 r
.37428 .53069 m .37121 .53179 L .37408 .52883 L F
.571 .578 .822 r
.37512 .53495 m .37121 .53179 L .37428 .53069 L F
.37512 .53495 m .37324 .53609 L .37121 .53179 L F
0 0 .286 r
.37195 .53003 m .37226 .53302 L .37287 .5309 L F
.37195 .53003 m .37287 .5309 L .37269 .53074 L F
.37195 .53003 m .37269 .53074 L .37038 .52871 L F
.81 .994 .76 r
.37408 .52883 m .37195 .53003 L .37239 .52951 L F
.975 .696 .434 r
.37528 .52836 m .37408 .52883 L .37418 .52589 L F
0 0 .114 r
.37418 .52589 m .37408 .52883 L .3747 .52676 L F
.81 .994 .76 r
.37408 .52883 m .37239 .52951 L .3747 .52676 L F
.975 .696 .434 r
.376 .52996 m .37408 .52883 L .37528 .52836 L F
.807 .907 .91 r
.376 .52996 m .37428 .53069 L .37408 .52883 L F
.876 .544 .419 r
.24701 .60248 m .24899 .60054 L .24558 .6001 L F
.24701 .60248 m .24909 .60308 L .24899 .60054 L F
.613 .148 .124 r
.36245 .61265 m .36156 .61469 L .35878 .61312 L F
.582 .44 .653 r
.36232 .6091 m .36729 .61024 L .36245 .61265 L F
.911 .85 .77 r
.36897 .60843 m .36924 .60964 L .36704 .6105 L F
.582 .44 .653 r
.36729 .61024 m .36729 .61024 L .36727 .61025 L F
.36729 .61024 m .36727 .61025 L .36245 .61265 L F
.911 .85 .77 r
.36704 .6105 m .36924 .60964 L .36702 .61055 L F
.582 .44 .653 r
.36729 .61024 m .36722 .61032 L .36245 .61265 L F
.911 .85 .77 r
.3671 .61039 m .36721 .61032 L .36704 .6105 L F
.594 .128 .116 r
.3627 .61301 m .36245 .61265 L .3671 .61039 L F
.582 .44 .653 r
.36729 .61024 m .36735 .61025 L .36722 .61032 L F
.36729 .61024 m .36468 .61179 L .36735 .61025 L F
.257 .64 .963 r
.37015 .60889 m .36873 .60732 L .36692 .60557 L F
.911 .85 .77 r
.36873 .60732 m .36897 .60843 L .36729 .61024 L F
.36724 .61025 m .36729 .61024 L .36721 .61032 L F
.36873 .60732 m .36729 .61024 L .36724 .61025 L F
.582 .44 .653 r
.36232 .6091 m .36387 .61086 L .36716 .61027 L F
.36729 .61024 m .36716 .61027 L .36729 .61024 L F
.36232 .6091 m .36716 .61027 L .36729 .61024 L F
.911 .85 .77 r
.36873 .60732 m .36716 .61027 L .3667 .60865 L F
.36716 .61027 m .36708 .61029 L .3667 .60865 L F
.3671 .61039 m .36703 .61043 L .3667 .60865 L F
.582 .44 .653 r
.36387 .61086 m .36698 .61032 L .36716 .61027 L F
.594 .128 .116 r
.3671 .61039 m .36245 .61265 L .36721 .61032 L F
.911 .85 .77 r
.36704 .6105 m .36701 .61053 L .367 .61045 L F
.36703 .61043 m .367 .61045 L .3667 .60865 L F
.36704 .6105 m .367 .61045 L .36703 .61043 L F
.594 .128 .116 r
.36272 .61305 m .3671 .61039 L .36735 .61025 L F
.3671 .61039 m .36721 .61032 L .36722 .61032 L F
.3671 .61039 m .36722 .61032 L .36735 .61025 L F
.699 .715 .862 r
.36735 .61025 m .3667 .60865 L .36698 .61032 L F
.911 .85 .77 r
.36716 .61027 m .3671 .61039 L .36708 .61029 L F
.3671 .61039 m .36704 .6105 L .36703 .61043 L F
.36716 .61027 m .36721 .61032 L .3671 .61039 L F
.36873 .60732 m .36724 .61025 L .36716 .61027 L F
.36724 .61025 m .36721 .61032 L .36716 .61027 L F
.582 .44 .653 r
.36716 .61027 m .36468 .61179 L .36729 .61024 L F
.36403 .61105 m .3641 .61113 L .36716 .61027 L F
.3641 .61113 m .36468 .61179 L .36716 .61027 L F
.911 .85 .77 r
.36704 .6105 m .36702 .61055 L .36701 .61053 L F
.699 .715 .862 r
.36735 .61025 m .36698 .61032 L .36702 .61055 L F
.582 .44 .653 r
.36387 .61086 m .36403 .61105 L .36698 .61032 L F
.594 .128 .116 r
.36272 .61305 m .3627 .61301 L .3671 .61039 L F
.1 0 .155 r
.36702 .61055 m .36661 .6137 L .36365 .6144 L F
0 0 .107 r
.36878 .61032 m .36702 .61055 L .36924 .60964 L F
.36773 .61186 m .36707 .61065 L .36878 .61032 L F
.36707 .61065 m .36702 .61055 L .36878 .61032 L F
.594 .128 .116 r
.36365 .6144 m .36272 .61305 L .36652 .61076 L F
.36698 .61067 m .36652 .61076 L .36735 .61025 L F
0 0 .107 r
.36773 .61186 m .36661 .6137 L .36702 .61055 L F
.1 0 .155 r
.36702 .61055 m .36365 .6144 L .36735 .61025 L F
.594 .128 .116 r
.36365 .6144 m .36652 .61076 L .36698 .61067 L F
.36365 .6144 m .36156 .61469 L .36245 .61265 L F
.975 .719 .305 r
.30291 .6662 m .30449 .67082 L .3044 .66747 L F
.898 .805 .748 r
.30291 .6662 m .3062 .66743 L .3044 .66747 L F
.94 .662 .484 r
.30449 .67082 m .3044 .66747 L .3062 .66743 L F
0 .099 .618 r
.58145 .39541 m .58022 .39474 L .57939 .39286 L F
.58145 .39541 m .58264 .39692 L .58022 .39474 L F
.826 .977 .68 r
.67837 .30486 m .676 .30836 L .67686 .30584 L F
.829 .997 .767 r
.67432 .30989 m .67686 .30584 L .676 .30836 L F
.992 .739 .417 r
.62237 .39028 m .62366 .39467 L .62239 .39302 L F
.663 .619 .795 r
.62366 .39467 m .62623 .39531 L .62673 .39252 L F
.532 .493 .758 r
.62673 .39252 m .62623 .39531 L .63017 .39367 L F
.591 .823 .988 r
.63017 .39367 m .62623 .39531 L .62596 .39479 L F
.63017 .39367 m .62596 .39479 L .6264 .39458 L F
.588 .312 .467 r
.62658 .3945 m .62912 .39565 L .62641 .3967 L F
.62673 .39252 m .62779 .39391 L .62658 .3945 L F
.535 .378 .615 r
.62673 .39252 m .62658 .3945 L .62366 .39467 L F
.588 .312 .467 r
.62673 .39252 m .62972 .39361 L .62942 .39366 L F
.62739 .39338 m .62942 .39366 L .62779 .39391 L F
.62673 .39252 m .62942 .39366 L .62739 .39338 L F
.591 .823 .988 r
.62919 .3937 m .62592 .3947 L .62568 .39424 L F
.62919 .3937 m .62568 .39424 L .62538 .39363 L F
.63017 .39367 m .62592 .3947 L .62931 .39366 L F
.588 .312 .467 r
.62826 .39453 m .63015 .39377 L .62912 .39565 L F
.62779 .39391 m .62991 .39379 L .62826 .39453 L F
.62991 .39379 m .63015 .39377 L .62826 .39453 L F
.62779 .39391 m .62826 .39453 L .62658 .3945 L F
.62826 .39453 m .62912 .39565 L .62745 .39489 L F
.62826 .39453 m .62745 .39489 L .62658 .3945 L F
0 0 0 r
.6294 .39402 m .62954 .39396 L .62768 .39481 L F
.62954 .39396 m .63003 .39373 L .62948 .39398 L F
.62954 .39396 m .62948 .39398 L .62768 .39481 L F
.63003 .39373 m .63017 .39367 L .63001 .39374 L F
.63003 .39373 m .63001 .39374 L .62768 .39481 L F
.398 0 0 r
.63001 .39374 m .63017 .39367 L .62942 .39366 L F
.588 .312 .467 r
.62972 .39361 m .63015 .39377 L .62779 .39391 L F
.398 0 0 r
.62768 .39481 m .63001 .39374 L .62538 .39363 L F
.591 .823 .988 r
.62931 .39366 m .62919 .3937 L .62538 .39363 L F
.398 0 0 r
.63001 .39374 m .62942 .39366 L .62538 .39363 L F
.591 .823 .988 r
.6264 .39458 m .62596 .39479 L .62592 .3947 L F
.535 .378 .615 r
.62658 .3945 m .62656 .39471 L .62592 .3947 L F
.62658 .3945 m .62592 .3947 L .62366 .39467 L F
.404 .702 .982 r
.62592 .3947 m .62623 .39531 L .62366 .39467 L F
.535 .378 .615 r
.62656 .39471 m .62641 .3967 L .62366 .39467 L F
.404 .702 .982 r
.62538 .39363 m .62592 .3947 L .62366 .39467 L F
0 .209 .695 r
.62366 .39467 m .62495 .39506 L .62538 .39363 L F
.62366 .39467 m .62641 .3967 L .62495 .39506 L F
0 .398 .839 r
.2928 .65806 m .29701 .66093 L .29302 .66057 L F
.777 .373 .286 r
.29302 .66057 m .29701 .66093 L .295 .66301 L F
.766 .474 .491 r
.29897 .66116 m .295 .66301 L .29701 .66093 L F
.69 .508 .636 r
.38763 .6644 m .39157 .66491 L .39101 .66081 L F
.424 .478 .812 r
.39101 .66081 m .3931 .66002 L .38987 .65862 L F
.39101 .66081 m .39238 .66206 L .3931 .66002 L F
.707 .53 .647 r
.39157 .66491 m .39238 .66206 L .39101 .66081 L F
.352 .126 .425 r
.30259 .62601 m .30421 .62563 L .305 .62292 L F
.357 .803 .953 r
.30323 .6253 m .30259 .62601 L .30139 .62599 L F
.30323 .6253 m .30421 .62563 L .30259 .62601 L F
.875 .71 .674 r
.70334 .31414 m .70123 .31691 L .70085 .31663 L F
.70122 .31491 m .70085 .31663 L .6994 .31557 L F
.70334 .31414 m .70085 .31663 L .70122 .31491 L F
.874 .929 .857 r
.70251 .32141 m .70011 .32138 L .70017 .31975 L F
.839 .6 .577 r
.7003 .31611 m .6994 .31557 L .70123 .31691 L F
.874 .929 .857 r
.70074 .31715 m .70017 .31975 L .7003 .31611 L F
.70251 .32141 m .70017 .31975 L .70074 .31715 L F
.629 .241 .291 r
.37945 .5516 m .38181 .55367 L .38275 .55072 L F
.787 .978 .7 r
.38275 .55072 m .38454 .54779 L .38231 .54836 L F
.38275 .55072 m .38186 .55092 L .38454 .54779 L F
.986 .772 .375 r
.38275 .55072 m .38181 .55367 L .38186 .55092 L F
.869 .98 .846 r
.67396 .32455 m .67318 .32766 L .67594 .32442 L F
.8 .923 .919 r
.67204 .32641 m .67318 .32766 L .67396 .32455 L F
.993 .782 .518 r
.40151 .6613 m .40036 .65792 L .39968 .66049 L F
.955 .704 .518 r
.39929 .66332 m .40151 .6613 L .39968 .66049 L F
.39929 .66332 m .40148 .6646 L .40151 .6613 L F
.717 .986 .814 r
.25299 .52104 m .25223 .52032 L .25534 .52004 L F
.25299 .52104 m .25093 .52173 L .25223 .52032 L F
.7 .704 .85 r
.57054 .41832 m .5749 .42088 L .57418 .41616 L F
.792 .671 .73 r
.57266 .42291 m .5749 .42088 L .57054 .41832 L F
.604 .635 .855 r
.57418 .41616 m .5749 .42088 L .57828 .41904 L F
.655 .605 .787 r
.44907 .54594 m .44895 .54813 L .45178 .54539 L F
0 0 .385 r
.21351 .56826 m .21447 .56999 L .21449 .56728 L F
.21351 .56826 m .21301 .5715 L .21447 .56999 L F
.773 .697 .779 r
.34254 .55229 m .3411 .55227 L .34277 .54888 L F
.69 .624 .778 r
.34665 .55206 m .34254 .55229 L .34277 .54888 L F
.659 .397 .513 r
.34665 .55206 m .34345 .55439 L .34254 .55229 L F
.664 .699 .872 r
.72574 .33992 m .72737 .33486 L .72442 .33675 L F
.72574 .33992 m .72782 .33862 L .72737 .33486 L F
.644 .886 .542 r
.36154 .58219 m .36031 .58414 L .36296 .58086 L F
.612 .821 .419 r
.35915 .58576 m .36031 .58414 L .36154 .58219 L F
.558 .384 .602 r
.36031 .58414 m .36312 .5837 L .36296 .58086 L F
.434 .253 .535 r
.36059 .58751 m .36312 .5837 L .36031 .58414 L F
.203 0 0 r
.43519 .59857 m .43666 .59803 L .43924 .5984 L F
.807 .69 .736 r
.54385 .41668 m .54701 .41325 L .54451 .41407 L F
.843 .847 .847 r
.39542 .68927 m .40039 .68773 L .39938 .68464 L F
.55 .6 .857 r
.63165 .41292 m .63686 .41787 L .63186 .41765 L F
.956 .658 .228 r
.54804 .4196 m .54898 .42026 L .54765 .41586 L F
.041 .176 .679 r
.54765 .41586 m .54858 .41892 L .54983 .41791 L F
.54765 .41586 m .54983 .41791 L .55034 .4158 L F
.198 0 0 r
.55155 .41656 m .55034 .4158 L .54983 .41791 L F
.466 .88 .752 r
.55118 .41682 m .54983 .41791 L .54823 .41839 L F
0 0 0 r
.55155 .41656 m .54983 .41791 L .55171 .41654 L F
.466 .88 .752 r
.55171 .41654 m .54983 .41791 L .55118 .41682 L F
.041 .176 .679 r
.54858 .41892 m .54898 .42026 L .54983 .41791 L F
.774 .983 .905 r
.54983 .41791 m .54898 .42026 L .54804 .4196 L F
.473 .211 .436 r
.29871 .56951 m .29671 .56753 L .29922 .56747 L F
.29871 .56951 m .29594 .57021 L .29671 .56753 L F
0 0 .045 r
.33644 .58392 m .33412 .58719 L .3354 .58501 L F
.378 .029 .242 r
.29695 .62461 m .29516 .62311 L .29419 .6253 L F
.849 .879 .862 r
.63288 .38427 m .63194 .38548 L .62979 .38337 L F
.768 .593 .661 r
.63194 .38548 m .6335 .38812 L .63438 .38648 L F
.361 0 0 r
.63031 .38592 m .63194 .38548 L .63438 .38648 L F
.688 .866 .966 r
.54107 .417 m .5389 .41825 L .5362 .41629 L F
.91 .933 .561 r
.37825 .62527 m .37882 .62574 L .37691 .62984 L F
.823 .99 .731 r
.38164 .6221 m .37882 .62574 L .37825 .62527 L F
.75 .987 .898 r
.3301 .62473 m .33267 .62465 L .32931 .62653 L F
.32931 .62653 m .33267 .62465 L .3301 .62473 L F
.805 .658 .7 r
.56387 .42606 m .56767 .42659 L .56619 .42323 L F
.786 .521 .536 r
.56387 .42606 m .56721 .42886 L .56767 .42659 L F
.73 .627 .743 r
.56767 .42659 m .57009 .42383 L .56619 .42323 L F
.592 .306 .452 r
.56767 .42659 m .56721 .42886 L .57025 .42815 L F
.756 .935 .591 r
.32003 .59549 m .3197 .59688 L .32233 .59929 L F
.096 0 .172 r
.21888 .55714 m .22014 .55373 L .21968 .55476 L F
.21888 .55714 m .22052 .55637 L .22014 .55373 L F
0 0 .093 r
.22014 .55373 m .2235 .55052 L .22159 .55162 L F
.22014 .55373 m .22248 .55291 L .2235 .55052 L F
0 0 .173 r
.22014 .55373 m .22052 .55637 L .22248 .55291 L F
.708 .755 .889 r
.47675 .44732 m .47829 .44921 L .47423 .44853 L F
.774 .772 .851 r
.48141 .44639 m .47829 .44921 L .47675 .44732 L F
.917 .977 .712 r
.31494 .5588 m .31657 .55507 L .31426 .55473 L F
.31494 .5588 m .31416 .55712 L .31657 .55507 L F
.9 .879 .806 r
.39026 .48712 m .39034 .48273 L .39165 .48684 L F
.39026 .48712 m .38786 .48639 L .39034 .48273 L F
.2 0 0 r
.27491 .51705 m .27792 .51679 L .27818 .51639 L F
0 0 0 r
.27818 .51639 m .27988 .51562 L .28114 .51551 L F
.27818 .51639 m .27792 .51679 L .27988 .51562 L F
.957 .948 .693 r
.2398 .59541 m .23922 .59979 L .23992 .59527 L F
.609 .471 .668 r
.23922 .59979 m .24221 .59708 L .23992 .59527 L F
.957 .948 .693 r
.2398 .59541 m .23992 .59527 L .24221 .59708 L F
.874 .897 .845 r
.52189 .41719 m .52107 .41921 L .51788 .41902 L F
.918 .825 .738 r
.51788 .41902 m .52107 .41921 L .51861 .42263 L F
.703 .909 .967 r
.59452 .46225 m .59832 .46195 L .59724 .4607 L F
0 0 .377 r
.63438 .38648 m .6335 .38812 L .6338 .38874 L F
.177 .052 .46 r
.44449 .57117 m .44567 .57339 L .4469 .57079 L F
.44449 .57117 m .44409 .57415 L .44567 .57339 L F
.04 .023 .507 r
.21301 .5715 m .21482 .57271 L .21447 .56999 L F
.21301 .5715 m .21331 .57419 L .21482 .57271 L F
.741 .81 .906 r
.68731 .35147 m .68531 .35334 L .68388 .3514 L F
.346 .068 .342 r
.35153 .59635 m .3544 .59216 L .35225 .59361 L F
.714 .617 .748 r
.47777 .49652 m .47553 .49995 L .47526 .49709 L F
0 0 0 r
.65643 .32477 m .6572 .32467 L .65846 .32362 L F
.65643 .32477 m .6546 .32569 L .6572 .32467 L F
0 0 .17 r
.21224 .57766 m .21289 .577 L .21331 .57419 L F
.072 0 0 r
.3268 .62755 m .32492 .62783 L .32506 .6255 L F
.3268 .62755 m .32819 .62781 L .32492 .62783 L F
.3268 .62755 m .32931 .62653 L .32819 .62781 L F
0 0 0 r
.23208 .54934 m .23102 .55097 L .2287 .55217 L F
.419 .17 .427 r
.26756 .63413 m .26854 .63197 L .26686 .63224 L F
0 0 0 r
.26686 .63224 m .26854 .63197 L .26943 .63184 L F
.262 .253 .661 r
.26943 .63184 m .26854 .63197 L .2707 .6306 L F
.147 0 .403 r
.269 .63168 m .26922 .63172 L .2707 .6306 L F
0 .375 .837 r
.26542 .6293 m .26924 .63172 L .26608 .6284 L F
.26924 .63172 m .26943 .63184 L .26933 .63174 L F
.147 0 .403 r
.26872 .6321 m .27009 .63111 L .2707 .6306 L F
.516 .67 .933 r
.26933 .63174 m .26943 .63184 L .2707 .6306 L F
.147 0 .403 r
.27009 .63111 m .2707 .63067 L .2707 .6306 L F
.516 .67 .933 r
.26608 .6284 m .26933 .63174 L .2707 .6306 L F
0 .375 .837 r
.26924 .63172 m .26933 .63174 L .26608 .6284 L F
.147 0 .403 r
.26854 .63197 m .26872 .6321 L .26922 .63172 L F
.26854 .63197 m .26922 .63172 L .269 .63168 L F
0 0 0 r
.26898 .63191 m .26943 .63184 L .26924 .63172 L F
.147 0 .403 r
.26872 .6321 m .27046 .63338 L .2707 .63067 L F
0 0 0 r
.26686 .63224 m .26898 .63191 L .26542 .6293 L F
.26898 .63191 m .26924 .63172 L .26542 .6293 L F
.906 .728 .65 r
.24273 .60755 m .23944 .60754 L .24188 .60599 L F
.751 .907 .946 r
.62324 .34635 m .61986 .34827 L .6189 .3471 L F
.58 .793 .98 r
.58991 .37774 m .58893 .37895 L .58672 .37865 L F
.452 .882 .817 r
.56146 .46717 m .56559 .46576 L .56419 .46675 L F
0 0 0 r
.56559 .46576 m .56658 .46566 L .56419 .46675 L F
.348 .796 .648 r
.5661 .46586 m .56658 .46566 L .56846 .46463 L F
.307 .778 .663 r
.56249 .46747 m .56419 .46675 L .56658 .46566 L F
.56249 .46747 m .56658 .46566 L .56494 .46646 L F
.348 .796 .648 r
.56494 .46646 m .56658 .46566 L .5661 .46586 L F
0 0 0 r
.56559 .46576 m .56712 .46544 L .56658 .46566 L F
.56712 .46544 m .56817 .46523 L .56658 .46566 L F
.532 .854 .997 r
.35086 .57137 m .34896 .57062 L .35177 .56977 L F
.844 .935 .886 r
.37171 .67635 m .36869 .67907 L .36728 .67824 L F
.37171 .67635 m .36728 .67824 L .37104 .67698 L F
.911 .969 .798 r
.3723 .67673 m .36869 .67907 L .37171 .67635 L F
.844 .935 .886 r
.37171 .67635 m .37104 .67698 L .37264 .67644 L F
.887 .926 .54 r
.37334 .67425 m .37294 .6752 L .37171 .67635 L F
.37294 .6752 m .3723 .67673 L .37171 .67635 L F
0 0 0 r
.37628 .67278 m .37334 .67425 L .37171 .67635 L F
.621 .402 .564 r
.5129 .4716 m .51294 .47445 L .51024 .47457 L F
.633 .361 .489 r
.5129 .4716 m .5165 .47354 L .51294 .47445 L F
.5129 .4716 m .51672 .47111 L .5165 .47354 L F
.173 0 0 r
.22532 .58712 m .22794 .58701 L .22916 .58635 L F
.449 0 0 r
.59954 .45552 m .6038 .4554 L .60271 .45656 L F
.925 .883 .464 r
.60271 .45656 m .6038 .4554 L .60286 .45783 L F
.292 .243 .629 r
.3647 .60354 m .36692 .60557 L .36639 .6029 L F
.801 .308 0 r
.36307 .50663 m .3668 .51015 L .36367 .50639 L F
.512 .282 .502 r
.35708 .52541 m .35453 .52671 L .35595 .52378 L F
.741 .22 0 r
.58816 .40128 m .58407 .39852 L .58661 .40017 L F
.741 .218 0 r
.59194 .40431 m .58816 .40128 L .59043 .40317 L F
0 0 .146 r
.32473 .63903 m .32301 .64171 L .32508 .64183 L F
.9 .524 .309 r
.32301 .64171 m .32635 .64477 L .32508 .64183 L F
.32301 .64171 m .32586 .64549 L .32635 .64477 L F
.517 .531 .809 r
.36358 .55818 m .36482 .56107 L .36214 .56153 L F
.54 .286 .479 r
.3645 .56389 m .36214 .56153 L .36482 .56107 L F
.3645 .56389 m .36248 .56436 L .36214 .56153 L F
.023 .207 .715 r
.36214 .56153 m .3645 .56389 L .36482 .56107 L F
.604 .435 .626 r
.36673 .53854 m .36362 .54127 L .36402 .53939 L F
.563 .236 .373 r
.44359 .5254 m .44676 .5224 L .44371 .52323 L F
.44359 .5254 m .44675 .52513 L .44676 .5224 L F
.46 .261 .522 r
.44676 .5224 m .44901 .52228 L .44941 .51973 L F
.362 .084 .35 r
.44676 .5224 m .45042 .52249 L .44901 .52228 L F
.44676 .5224 m .44675 .52513 L .45042 .52249 L F
.867 .988 .835 r
.64851 .40037 m .65185 .39814 L .65083 .3972 L F
.876 .982 .834 r
.65185 .39814 m .65446 .39515 L .65219 .39555 L F
.832 .956 .895 r
.65083 .3972 m .65185 .39814 L .65219 .39555 L F
0 .097 .648 r
.3521 .58045 m .35349 .58422 L .35432 .58298 L F
.6 .907 .639 r
.35432 .58298 m .35349 .58422 L .3515 .58576 L F
.571 .412 .627 r
.48286 .48737 m .48205 .49198 L .48026 .49074 L F
.675 .536 .688 r
.48205 .49198 m .48031 .49351 L .48026 .49074 L F
.827 .828 .849 r
.295 .66997 m .29558 .67103 L .29733 .66724 L F
.162 0 0 r
.33223 .49421 m .33396 .49439 L .32985 .4938 L F
.115 0 0 r
.33451 .49459 m .33396 .49439 L .33223 .49421 L F
.33451 .49459 m .33638 .49467 L .33396 .49439 L F
.498 .274 .505 r
.35448 .56108 m .3573 .55793 L .35473 .55853 L F
0 .082 .64 r
.3914 .65925 m .39212 .65834 L .39066 .6589 L F
0 .307 .661 r
.38987 .65862 m .39211 .65959 L .3914 .65925 L F
.94 .643 .451 r
.38762 .65755 m .3914 .65925 L .38955 .65932 L F
.38727 .65723 m .38753 .65735 L .38762 .65755 L F
.38753 .65735 m .3914 .65925 L .38762 .65755 L F
.72 .188 0 r
.3894 .6578 m .38727 .65723 L .38741 .65608 L F
.862 .436 .002 r
.38598 .6545 m .38741 .65608 L .38727 .65723 L F
0 0 .481 r
.38597 .65412 m .38783 .65776 L .38597 .65393 L F
.38598 .6545 m .3871 .65647 L .38597 .65412 L F
.3871 .65647 m .38783 .65776 L .38597 .65412 L F
0 .082 .64 r
.3914 .65925 m .39066 .6589 L .38955 .65932 L F
0 .307 .661 r
.39211 .65959 m .3931 .66002 L .3914 .65925 L F
.932 .889 .767 r
.64482 .40531 m .64731 .40444 L .64722 .40205 L F
.64482 .40531 m .64595 .40693 L .64731 .40444 L F
.133 0 .316 r
.305 .62292 m .30623 .62504 L .30717 .62181 L F
.305 .62292 m .30421 .62563 L .30623 .62504 L F
.874 .804 .777 r
.43296 .59393 m .4287 .5961 L .42899 .59402 L F
.43296 .59393 m .43068 .59703 L .4287 .5961 L F
.317 .397 .786 r
.3832 .65057 m .38156 .65222 L .38181 .65234 L F
.701 .982 .89 r
.3832 .65057 m .38181 .65234 L .38177 .65234 L F
.19 .225 .668 r
.38172 .65241 m .38156 .65222 L .3832 .65057 L F
.38347 .65446 m .3823 .65484 L .38164 .6525 L F
.38172 .65241 m .38164 .6525 L .38156 .65222 L F
.38347 .65446 m .38164 .6525 L .38172 .65241 L F
.701 .982 .89 r
.3832 .65057 m .38177 .65234 L .38176 .65234 L F
.3831 .65062 m .38176 .65234 L .37843 .65272 L F
.3832 .65057 m .38176 .65234 L .3831 .65062 L F
.19 .225 .668 r
.38347 .65446 m .38172 .65241 L .3832 .65057 L F
.911 .969 .798 r
.3723 .67673 m .36816 .68091 L .36869 .67907 L F
.965 .636 .309 r
.59227 .40667 m .59194 .40431 L .59043 .40317 L F
.506 .864 .624 r
.3655 .62758 m .36344 .62924 L .36464 .62812 L F
.494 .818 1 r
.36741 .62909 m .36344 .62924 L .3655 .62758 L F
0 0 .396 r
.36464 .62812 m .36344 .62924 L .36439 .63308 L F
.674 .506 .65 r
.48535 .48141 m .48312 .48504 L .48395 .48218 L F
.615 .877 .99 r
.24652 .57387 m .24483 .57495 L .24228 .57414 L F
.019 0 .058 r
.24483 .57495 m .24383 .57689 L .24652 .57387 L F
.24652 .57387 m .24383 .57689 L .24483 .57495 L F
.24652 .57387 m .24383 .57689 L .24483 .57495 L F
.4 0 .122 r
.282 .5674 m .28589 .56519 L .2822 .56465 L F
.282 .5674 m .28464 .56708 L .28589 .56519 L F
.124 0 0 r
.28589 .56519 m .28682 .56623 L .28855 .56457 L F
.28589 .56519 m .28464 .56708 L .28682 .56623 L F
.781 .598 .652 r
.23213 .59901 m .22973 .59682 L .23027 .59601 L F
.23266 .59987 m .23192 .59909 L .23213 .59901 L F
.23192 .59909 m .22973 .59682 L .23213 .59901 L F
.23266 .59987 m .23031 .60106 L .22973 .59682 L F
.23266 .59987 m .23027 .59601 L .2298 .59938 L F
.892 .805 .324 r
.22963 .60187 m .23031 .60106 L .23266 .59987 L F
.22963 .60187 m .23266 .59987 L .2298 .59938 L F
.637 .947 .732 r
.23266 .59987 m .23238 .59985 L .23563 .59728 L F
.643 .822 .402 r
.23266 .59183 m .23145 .59397 L .23372 .59018 L F
.644 .587 .776 r
.23266 .59183 m .23027 .59601 L .23145 .59397 L F
.23266 .59183 m .23373 .59864 L .23027 .59601 L F
.23373 .59864 m .23355 .5988 L .23027 .59601 L F
.162 0 0 r
.23355 .5988 m .2298 .59938 L .23027 .59601 L F
.23379 .599 m .23322 .59906 L .23355 .5988 L F
.23322 .59906 m .2298 .59938 L .23355 .5988 L F
.23322 .59906 m .23142 .59977 L .2298 .59938 L F
.637 .947 .732 r
.23222 .59983 m .23142 .59977 L .23355 .5988 L F
.162 0 0 r
.23379 .599 m .23142 .59977 L .23322 .59906 L F
.637 .947 .732 r
.23354 .59893 m .23453 .59793 L .23563 .59728 L F
.23238 .59985 m .2333 .59903 L .23354 .59893 L F
.23373 .59864 m .23453 .59793 L .2335 .59895 L F
.466 .882 .76 r
.23541 .59774 m .23379 .599 L .23394 .59825 L F
0 0 0 r
.23563 .59728 m .23406 .59821 L .23541 .59774 L F
.466 .882 .76 r
.23541 .59774 m .23394 .59825 L .23478 .594 L F
0 0 0 r
.23406 .59821 m .23406 .59821 L .23541 .59774 L F
.043 .135 .636 r
.23394 .59825 m .2339 .59841 L .23388 .59827 L F
0 0 0 r
.23406 .59821 m .23377 .59838 L .23533 .59777 L F
.23406 .59821 m .23533 .59777 L .23541 .59774 L F
.043 .135 .636 r
.23478 .594 m .23394 .59825 L .23266 .59183 L F
.23394 .59825 m .23388 .59827 L .23266 .59183 L F
.637 .947 .732 r
.2335 .59895 m .23453 .59793 L .23354 .59893 L F
.043 .135 .636 r
.2339 .59841 m .23379 .599 L .23373 .59864 L F
.2339 .59841 m .23373 .59864 L .23266 .59183 L F
.637 .947 .732 r
.2333 .59903 m .23373 .59864 L .2335 .59895 L F
.23355 .5988 m .23142 .59977 L .23453 .59793 L F
.23238 .59985 m .23222 .59983 L .23355 .5988 L F
.644 .587 .776 r
.23373 .59864 m .23379 .599 L .23355 .5988 L F
0 0 0 r
.23377 .59838 m .23142 .59977 L .2353 .59779 L F
.23377 .59838 m .2353 .59779 L .23541 .59774 L F
.879 .863 .82 r
.55165 .42273 m .55566 .42014 L .55488 .42215 L F
.263 0 .012 r
.55488 .42215 m .55566 .42014 L .55846 .4196 L F
.612 .926 .97 r
.65988 .33685 m .65841 .3387 L .6617 .3372 L F
.65988 .33685 m .65729 .33811 L .65841 .3387 L F
0 0 0 r
.33849 .52075 m .33564 .52202 L .33903 .52041 L F
.632 .48 .659 r
.33398 .52276 m .33675 .52615 L .33564 .52202 L F
.726 .617 .735 r
.33564 .52202 m .33675 .52615 L .33985 .52235 L F
0 0 0 r
.33548 .52265 m .33564 .52202 L .33849 .52075 L F
.632 .48 .659 r
.33385 .5226 m .33398 .52276 L .33564 .52202 L F
.33385 .5226 m .33465 .52753 L .33675 .52615 L F
.698 .854 .957 r
.34391 .54362 m .34109 .54498 L .34459 .54475 L F
.777 .62 .685 r
.34109 .54498 m .34277 .54888 L .34459 .54475 L F
0 0 0 r
.34459 .54475 m .34277 .54888 L .34378 .54746 L F
.191 0 0 r
.34378 .54746 m .34772 .54665 L .34459 .54475 L F
0 .533 .752 r
.28505 .65485 m .28732 .65531 L .28483 .65482 L F
.937 .75 .624 r
.28899 .65504 m .28838 .65821 L .28622 .65708 L F
.28899 .65504 m .28834 .65552 L .28732 .65531 L F
.583 .945 .871 r
.28962 .65405 m .28732 .65531 L .28887 .65538 L F
0 .533 .752 r
.28887 .65538 m .28732 .65531 L .28505 .65485 L F
.937 .75 .624 r
.28834 .65552 m .28622 .65708 L .28732 .65531 L F
.813 .749 .792 r
.641 .3546 m .64254 .35312 L .64014 .35153 L F
.257 .316 .733 r
.4153 .49204 m .41676 .49614 L .41403 .49395 L F
.505 .27 .492 r
.36653 .6678 m .36739 .66862 L .36843 .66678 L F
.024 .018 .51 r
.32828 .5808 m .32921 .5807 L .32848 .57758 L F
0 0 0 r
.32763 .58251 m .32921 .5807 L .32828 .5808 L F
.662 .713 .886 r
.40342 .47792 m .40091 .47977 L .39945 .47699 L F
.824 .37 .15 r
.555 .42618 m .55572 .42785 L .55699 .42665 L F
.979 .681 .35 r
.55572 .42785 m .55705 .42905 L .55699 .42665 L F
.112 .021 .463 r
.3251 .63551 m .32664 .63745 L .32793 .63478 L F
.3251 .63551 m .32473 .63903 L .32664 .63745 L F
.866 .856 .83 r
.6406 .40998 m .6435 .41012 L .64206 .40862 L F
.877 .839 .804 r
.64101 .41358 m .6435 .41012 L .6406 .40998 L F
.868 .856 .828 r
.64206 .40862 m .6435 .41012 L .64595 .40693 L F
.599 .903 .985 r
.4399 .5835 m .43646 .58368 L .43946 .58253 L F
.69 .885 .97 r
.61882 .43502 m .62237 .43326 L .6208 .43194 L F
.669 .857 .459 r
.38754 .607 m .38658 .60807 L .38527 .60529 L F
.38754 .607 m .38568 .60984 L .38658 .60807 L F
.733 .618 .73 r
.56619 .42323 m .57009 .42383 L .56876 .41994 L F
.695 .629 .779 r
.57009 .42383 m .57054 .41832 L .56876 .41994 L F
.57009 .42383 m .57266 .42291 L .57054 .41832 L F
.25 .215 .623 r
.47351 .55385 m .47377 .55786 L .47209 .55827 L F
.26 .254 .663 r
.47377 .55786 m .47438 .56048 L .47209 .55827 L F
.254 .253 .665 r
.47209 .55827 m .47438 .56048 L .47287 .561 L F
.946 .617 .374 r
.38265 .52259 m .38299 .52501 L .38504 .52587 L F
.857 .419 .169 r
.38346 .52721 m .38504 .52587 L .38299 .52501 L F
.38346 .52721 m .38618 .52866 L .38504 .52587 L F
.288 .783 .748 r
.24006 .57432 m .2378 .5751 L .23533 .57569 L F
.841 .927 .888 r
.68416 .37746 m .68494 .37935 L .68653 .37761 L F
.386 .168 .457 r
.22714 .57713 m .22459 .58012 L .22519 .57817 L F
.685 .624 .782 r
.33832 .54881 m .3411 .55227 L .33653 .5519 L F
.56 .519 .766 r
.3401 .55491 m .33653 .5519 L .3411 .55227 L F
.737 .972 .715 r
.65574 .39295 m .65446 .39515 L .65617 .39326 L F
.742 .991 .879 r
.65219 .39555 m .65446 .39515 L .65574 .39295 L F
.649 .496 .663 r
.43272 .48746 m .43 .49064 L .4298 .4869 L F
.755 .884 .937 r
.64572 .34533 m .64702 .34665 L .649 .34513 L F
.211 .325 .763 r
.21327 .5841 m .21436 .58352 L .21312 .5798 L F
.121 .117 .579 r
.21327 .5841 m .21488 .58604 L .21436 .58352 L F
.195 .133 .555 r
.21342 .58585 m .21488 .58604 L .21327 .5841 L F
0 0 0 r
.23245 .54983 m .23208 .54934 L .23439 .54889 L F
.23245 .54983 m .23102 .55097 L .23208 .54934 L F
.847 .773 .78 r
.59201 .37435 m .59307 .37773 L .58991 .37774 L F
.774 .737 .819 r
.59201 .37435 m .5959 .37501 L .59307 .37773 L F
.697 .187 .018 r
.33519 .61724 m .33756 .61634 L .33917 .61833 L F
.183 .119 .546 r
.33917 .61833 m .33756 .61634 L .33891 .61519 L F
.632 .434 .596 r
.29714 .63767 m .30017 .63523 L .29783 .63581 L F
.487 .336 .602 r
.29783 .63581 m .30017 .63523 L .30003 .63225 L F
.217 0 .314 r
.24284 .57921 m .2418 .5778 L .24383 .57689 L F
.24284 .57921 m .24106 .58034 L .2418 .5778 L F
.675 .851 .967 r
.51416 .42437 m .51524 .42592 L .51345 .42668 L F
.827 .989 .87 r
.51345 .42668 m .51258 .42607 L .51416 .42437 L F
.965 .682 .258 r
.51345 .42668 m .51363 .42913 L .51258 .42607 L F
.075 0 0 r
.3063 .64864 m .30913 .64672 L .3092 .64737 L F
.322 0 0 r
.3092 .64737 m .30913 .64672 L .31188 .64731 L F
.835 .495 .412 r
.29076 .6604 m .2928 .65806 L .29302 .66057 L F
.407 .271 .581 r
.36296 .58086 m .36525 .58306 L .36526 .5803 L F
.36296 .58086 m .36312 .5837 L .36525 .58306 L F
.834 .586 .563 r
.36526 .5803 m .36154 .58219 L .36296 .58086 L F
.329 .782 .953 r
.36837 .62859 m .37008 .62913 L .36741 .62909 L F
.728 .522 .612 r
.36741 .62909 m .37008 .62913 L .36845 .6313 L F
.487 .824 .999 r
.37088 .62761 m .37294 .62872 L .37008 .62913 L F
.552 .89 .984 r
.37088 .62761 m .37008 .62913 L .36837 .62859 L F
.745 .608 .705 r
.5498 .41327 m .5542 .41375 L .55413 .41098 L F
.71 .345 .355 r
.55363 .41543 m .5542 .41375 L .5498 .41327 L F
.298 0 0 r
.55737 .41141 m .55413 .41098 L .5542 .41375 L F
0 0 .067 r
.55737 .41141 m .5542 .41375 L .55363 .41543 L F
.745 .608 .705 r
.5498 .41327 m .55413 .41098 L .54948 .41298 L F
.298 0 0 r
.55737 .41141 m .55691 .41059 L .55413 .41098 L F
.085 .324 .801 r
.27005 .53915 m .27283 .54153 L .27066 .53742 L F
.966 .867 .689 r
.39782 .67331 m .40087 .67046 L .39901 .67054 L F
.39782 .67331 m .39936 .67476 L .40087 .67046 L F
.953 .752 .596 r
.3228 .55179 m .3271 .55422 L .32584 .55103 L F
.697 .157 0 r
.32955 .55381 m .32584 .55103 L .3271 .55422 L F
.568 .832 .995 r
.31497 .54497 m .31111 .54485 L .3126 .54404 L F
.748 .509 .57 r
.31477 .54822 m .31111 .54485 L .31497 .54497 L F
.501 .607 .89 r
.31575 .54181 m .31497 .54497 L .3126 .54404 L F
.31575 .54181 m .3174 .54475 L .31497 .54497 L F
.959 .625 .248 r
.60991 .4192 m .61128 .42041 L .61159 .42262 L F
.006 .463 .868 r
.59332 .3948 m .59525 .39462 L .59198 .39321 L F
.46 0 0 r
.281 .57467 m .28351 .57594 L .27911 .57609 L F
.522 .354 .594 r
.47289 .50419 m .4733 .50672 L .47062 .50717 L F
.567 .433 .657 r
.4733 .50672 m .47105 .51013 L .47062 .50717 L F
.481 .125 .284 r
.30582 .56442 m .30446 .56722 L .30183 .56743 L F
.43 .074 .257 r
.30826 .56422 m .30446 .56722 L .30582 .56442 L F
.849 .977 .674 r
.69642 .36226 m .69873 .35779 L .69774 .35984 L F
.667 .778 .932 r
.71655 .33253 m .71796 .33537 L .72107 .33346 L F
.93 .776 .67 r
.39402 .65094 m .39503 .65519 L .39596 .652 L F
0 0 .425 r
.32586 .64549 m .32625 .64814 L .32635 .64477 L F
.384 0 0 r
.43395 .58371 m .43246 .58533 L .43002 .58436 L F
.131 0 0 r
.43395 .58371 m .43332 .58411 L .43002 .58436 L F
.549 .878 .61 r
.43395 .58371 m .43332 .58411 L .43497 .58256 L F
.645 .85 .979 r
.43946 .58253 m .43646 .58368 L .43497 .58256 L F
.165 0 0 r
.43702 .58369 m .43497 .58256 L .43646 .58368 L F
.43702 .58369 m .43395 .58371 L .43497 .58256 L F
.43702 .58369 m .43246 .58533 L .43395 .58371 L F
.226 .281 .711 r
.21441 .59041 m .21488 .58604 L .21342 .58585 L F
.21441 .59041 m .21571 .58989 L .21488 .58604 L F
.187 .175 .611 r
.21441 .59041 m .21629 .59253 L .21571 .58989 L F
0 0 .475 r
.59324 .40874 m .59358 .4106 L .59227 .40667 L F
.819 .338 0 r
.59445 .41312 m .59559 .41319 L .59358 .4106 L F
.59445 .41312 m .59358 .4106 L .59324 .40874 L F
.43 .278 .573 r
.47143 .51279 m .47166 .51552 L .46911 .51675 L F
.507 .376 .637 r
.47166 .51552 m .46953 .51957 L .46911 .51675 L F
.659 .475 .624 r
.5075 .47495 m .50755 .47764 L .50486 .47794 L F
.636 .456 .623 r
.5075 .47495 m .51024 .47457 L .50755 .47764 L F
.931 .749 .634 r
.34156 .6867 m .34247 .68672 L .34175 .68374 L F
.674 .506 .65 r
.48535 .48141 m .48507 .48394 L .48312 .48504 L F
.462 .695 .968 r
.62865 .35499 m .62993 .35305 L .62714 .35412 L F
.62865 .35499 m .63125 .3548 L .62993 .35305 L F
.888 .99 .761 r
.3373 .65596 m .33604 .65889 L .33483 .65777 L F
.553 .573 .829 r
.33604 .65889 m .3373 .65596 L .33483 .65777 L F
.33604 .65889 m .33932 .65848 L .3373 .65596 L F
0 0 .281 r
.24105 .59221 m .24159 .59389 L .24021 .59009 L F
.946 .948 .632 r
.24105 .59221 m .2398 .59541 L .24159 .59389 L F
.946 .644 .433 r
.2398 .59541 m .24221 .59708 L .24159 .59389 L F
.941 .704 .233 r
.40052 .58714 m .39981 .5836 L .39964 .58629 L F
.994 .83 .467 r
.39917 .58885 m .40052 .58714 L .39964 .58629 L F
.39917 .58885 m .40012 .5891 L .40052 .58714 L F
.674 .707 .872 r
.53069 .41116 m .52658 .41051 L .52855 .40926 L F
.267 0 .205 r
.47019 .58362 m .46973 .58622 L .46734 .5871 L F
.148 0 .187 r
.47295 .58055 m .47254 .58314 L .47019 .58362 L F
.124 0 .152 r
.47254 .58314 m .46973 .58622 L .47019 .58362 L F
.746 .682 .789 r
.5043 .43285 m .50594 .43668 L .50182 .43607 L F
.824 .788 .819 r
.5068 .43197 m .50594 .43668 L .5043 .43285 L F
.5068 .43197 m .50865 .43352 L .50594 .43668 L F
0 0 .186 r
.47592 .5696 m .47541 .5739 L .47504 .57119 L F
.675 .581 .742 r
.56344 .42338 m .56502 .41925 L .56219 .42018 L F
.56344 .42338 m .56619 .42323 L .56502 .41925 L F
.658 .443 .58 r
.56387 .42606 m .56619 .42323 L .56344 .42338 L F
.401 0 0 r
.34772 .54665 m .34998 .547 L .35194 .54583 L F
.152 0 0 r
.34998 .547 m .35426 .54492 L .35194 .54583 L F
0 0 0 r
.22895 .54144 m .22733 .54309 L .22648 .54482 L F
.777 .955 .929 r
.56175 .40543 m .55974 .4075 L .56049 .4051 L F
0 0 .414 r
.4291 .55921 m .42801 .55853 L .42916 .55659 L F
.548 .311 .508 r
.43181 .55631 m .4291 .55921 L .42916 .55659 L F
.53 .835 .516 r
.43012 .55808 m .42964 .55858 L .4291 .55921 L F
0 0 .414 r
.4291 .55921 m .42846 .55995 L .42801 .55853 L F
.53 .835 .516 r
.42964 .55858 m .42743 .56086 L .4291 .55921 L F
0 0 .414 r
.4291 .55921 m .42889 .56128 L .42846 .55995 L F
0 0 0 r
.31899 .5914 m .31754 .59322 L .32037 .58979 L F
.469 .892 .843 r
.64258 .33408 m .64667 .3328 L .64421 .33415 L F
.761 .805 .888 r
.6375 .35453 m .641 .3546 L .64014 .35153 L F
.918 .615 .455 r
.24736 .61288 m .24797 .61562 L .25008 .61596 L F
.283 0 0 r
.24797 .61562 m .25224 .61613 L .25008 .61596 L F
.766 .825 .898 r
.40008 .48309 m .39796 .48455 L .40251 .48386 L F
.632 .59 .789 r
.40251 .48386 m .4045 .47756 L .40008 .48309 L F
.40251 .48386 m .40493 .48386 L .4045 .47756 L F
.439 .235 .505 r
.40251 .48386 m .40446 .48618 L .40493 .48386 L F
.40251 .48386 m .40188 .48701 L .40446 .48618 L F
.831 .76 .784 r
.38614 .70032 m .38851 .69706 L .38669 .69532 L F
.744 .758 .864 r
.38669 .69532 m .38851 .69706 L .38843 .69392 L F
.849 .879 .862 r
.63288 .38427 m .62979 .38337 L .63306 .38281 L F
.62 .955 .911 r
.63633 .38187 m .63288 .38427 L .63301 .38321 L F
.63424 .3825 m .63301 .38321 L .63306 .38285 L F
.63633 .38187 m .63301 .38321 L .63424 .3825 L F
.63633 .38187 m .63306 .38285 L .63333 .38273 L F
.63633 .38187 m .63306 .38281 L .6353 .38168 L F
.651 .63 .816 r
.63553 .38175 m .63663 .38575 L .63972 .38302 L F
.6353 .38168 m .63535 .38185 L .63553 .38175 L F
.63535 .38185 m .63663 .38575 L .63553 .38175 L F
.772 .698 .781 r
.63438 .38648 m .63663 .38575 L .63535 .38185 L F
.63526 .38189 m .63535 .38185 L .6353 .38168 L F
.63438 .38648 m .63535 .38185 L .63526 .38189 L F
.62 .955 .911 r
.63333 .38273 m .63306 .38285 L .63306 .38281 L F
.67 .443 .567 r
.52206 .46806 m .52201 .47128 L .51943 .47095 L F
.654 .408 .534 r
.52206 .46806 m .52581 .47027 L .52201 .47128 L F
.52206 .46806 m .52612 .46805 L .52581 .47027 L F
.905 .825 .757 r
.63901 .4169 m .64101 .41358 L .63927 .41218 L F
.877 .839 .804 r
.64101 .41358 m .6406 .40998 L .63927 .41218 L F
0 .3 .705 r
.38241 .50745 m .37888 .50547 L .3802 .50713 L F
.062 0 .317 r
.47546 .5769 m .47502 .57959 L .47295 .58055 L F
.077 0 .167 r
.47436 .58195 m .47295 .58055 L .47502 .57959 L F
.47436 .58195 m .47254 .58314 L .47295 .58055 L F
.613 .145 .119 r
.31434 .62647 m .31632 .62585 L .31827 .62737 L F
.787 .405 .331 r
.42954 .50397 m .42828 .50315 L .43274 .5034 L F
.868 .856 .828 r
.64206 .40862 m .64595 .40693 L .64482 .40531 L F
.687 .92 .971 r
.73472 .33536 m .73494 .33652 L .7359 .3342 L F
.325 0 .084 r
.59954 .45552 m .59632 .45783 L .59721 .45721 L F
0 0 .489 r
.60027 .39931 m .60112 .40119 L .60219 .40273 L F
0 0 0 r
.67865 .36275 m .67967 .36176 L .67694 .36424 L F
.67865 .36275 m .67694 .36424 L .67627 .36406 L F
.384 .221 .534 r
.69607 .32963 m .69732 .32798 L .6971 .32666 L F
.158 .055 .478 r
.69732 .32798 m .69893 .32533 L .6971 .32666 L F
.858 .532 .435 r
.49101 .48696 m .49332 .4876 L .49323 .49023 L F
.595 .302 .442 r
.49332 .4876 m .49584 .4897 L .49323 .49023 L F
.614 .295 .406 r
.49589 .48772 m .49584 .4897 L .49332 .4876 L F
.605 .933 .959 r
.55819 .41691 m .56069 .41578 L .55908 .41502 L F
0 0 .276 r
.55846 .4196 m .55819 .41691 L .55908 .41502 L F
.998 .8 .509 r
.61184 .45216 m .61107 .44833 L .61049 .45115 L F
.991 .882 .562 r
.61022 .45372 m .61184 .45216 L .61049 .45115 L F
.61022 .45372 m .61113 .45586 L .61184 .45216 L F
.203 .054 .444 r
.22198 .54882 m .2235 .55052 L .22338 .54776 L F
.22198 .54882 m .22159 .55162 L .2235 .55052 L F
.382 .846 .847 r
.27491 .51705 m .27567 .51626 L .27792 .51679 L F
.755 .495 .539 r
.34909 .6767 m .35035 .67456 L .346 .6744 L F
.809 .993 .871 r
.35096 .67301 m .35035 .67456 L .35034 .67262 L F
.751 .877 .461 r
.34909 .6767 m .35035 .67456 L .35096 .67301 L F
.809 .993 .871 r
.35034 .67262 m .35035 .67456 L .35096 .67301 L F
.751 .877 .461 r
.34909 .6767 m .35035 .67456 L .35096 .67301 L F
0 0 .136 r
.70146 .27874 m .70159 .28033 L .70195 .27783 L F
.509 .875 .981 r
.60503 .46254 m .60688 .46092 L .60341 .46144 L F
.60503 .46254 m .60787 .46166 L .60688 .46092 L F
.755 .865 .929 r
.47423 .44853 m .47208 .45007 L .4705 .44869 L F
.67 .856 .971 r
.38639 .66308 m .38763 .6644 L .38456 .66522 L F
.243 .398 .819 r
.38456 .66522 m .38719 .66694 L .38763 .6644 L F
.975 .728 .498 r
.38719 .66694 m .38763 .6644 L .38456 .66522 L F
.707 .53 .647 r
.39157 .66491 m .39429 .66438 L .39238 .66206 L F
0 .252 .763 r
.39238 .66206 m .39458 .66284 L .3931 .66002 L F
.39238 .66206 m .39429 .66438 L .39458 .66284 L F
.735 .484 .549 r
.27283 .54153 m .27701 .53931 L .27436 .53856 L F
.27283 .54153 m .27559 .54237 L .27701 .53931 L F
.92 .964 .654 r
.27701 .53931 m .27646 .53786 L .27851 .53608 L F
.549 .029 0 r
.27701 .53931 m .27884 .54118 L .27711 .53969 L F
.614 .494 .692 r
.27851 .53608 m .27912 .53917 L .27701 .53931 L F
.528 .177 .316 r
.27912 .53917 m .27884 .54118 L .27701 .53931 L F
.802 .576 .595 r
.24827 .57346 m .25075 .57454 L .24652 .57387 L F
.72 .496 .585 r
.25031 .57633 m .24652 .57387 L .25075 .57454 L F
.646 .606 .794 r
.25245 .57154 m .25343 .57446 L .25075 .57454 L F
.662 .347 .429 r
.25343 .57446 m .25031 .57633 L .25075 .57454 L F
0 0 .029 r
.5584 .40935 m .55691 .41059 L .55737 .41141 L F
.626 .138 0 r
.42959 .56864 m .43082 .57022 L .43196 .57131 L F
.999 .786 .474 r
.43036 .5735 m .43196 .57131 L .43082 .57022 L F
.43036 .5735 m .43162 .57407 L .43196 .57131 L F
.454 0 .043 r
.30004 .56128 m .30258 .56238 L .30472 .55996 L F
.548 .126 .192 r
.30258 .56238 m .30729 .55977 L .30472 .55996 L F
.228 0 0 r
.45844 .59 m .45718 .59197 L .45483 .59263 L F
.193 0 0 r
.45844 .59 m .45973 .59101 L .45718 .59197 L F
.45844 .59 m .46067 .59006 L .45973 .59101 L F
0 .267 .647 r
.35634 .69687 m .35759 .69754 L .35494 .69617 L F
.452 .884 .858 r
.31929 .557 m .31759 .55702 L .31751 .55785 L F
.31929 .557 m .31759 .55702 L .31751 .55785 L F
.442 .048 .197 r
.31923 .55989 m .31751 .55785 L .31759 .55702 L F
.31923 .55989 m .31609 .56039 L .31751 .55785 L F
.501 .751 .985 r
.58643 .36222 m .58912 .36175 L .58771 .36021 L F
.257 .767 .835 r
.56817 .46523 m .57182 .46476 L .5709 .46478 L F
.372 .81 .655 r
.57182 .46476 m .57464 .46322 L .57342 .46379 L F
.377 .842 .816 r
.5709 .46478 m .57182 .46476 L .57342 .46379 L F
.788 .542 .566 r
.30639 .52835 m .31081 .53004 L .31069 .52622 L F
.077 .233 .724 r
.34581 .68701 m .34829 .68948 L .34839 .68665 L F
.595 .949 .842 r
.34473 .51867 m .34319 .51891 L .34385 .51868 L F
.831 .76 .784 r
.38614 .70032 m .38669 .69532 L .38385 .69891 L F
.639 .807 .964 r
.33405 .62487 m .33612 .62662 L .33837 .62546 L F
.823 .383 .195 r
.67852 .35556 m .68159 .35778 L .67905 .35744 L F
.941 .958 .661 r
.68159 .35778 m .67891 .35924 L .67905 .35744 L F
.68159 .35778 m .67967 .36176 L .67891 .35924 L F
0 .274 .765 r
.58541 .39856 m .58407 .39852 L .58264 .39692 L F
.58541 .39856 m .58661 .40017 L .58407 .39852 L F
0 0 0 r
.42993 .56482 m .429 .56638 L .42878 .56665 L F
.926 .56 .307 r
.42809 .56373 m .429 .56638 L .42993 .56482 L F
.42809 .56373 m .429 .56638 L .42993 .56482 L F
.708 .844 .948 r
.45875 .45495 m .46245 .45527 L .45998 .45607 L F
.812 .753 .797 r
.37165 .63564 m .37038 .63717 L .36968 .63752 L F
.551 .266 .437 r
.51672 .47111 m .51947 .47336 L .5165 .47354 L F
.51672 .47111 m .51943 .47095 L .51947 .47336 L F
.942 .581 .283 r
.5991 .42007 m .59699 .41672 L .59724 .41961 L F
.779 .284 .031 r
.59818 .4212 m .5991 .42007 L .59724 .41961 L F
.899 .482 .143 r
.59989 .4223 m .5991 .42007 L .59818 .4212 L F
.877 .746 .714 r
.33223 .63888 m .33085 .63488 L .33118 .63727 L F
.577 .272 .415 r
.28446 .63581 m .28704 .6355 L .28665 .63779 L F
.28446 .63581 m .28704 .6355 L .28665 .63779 L F
.98 .738 .498 r
.3823 .65484 m .38038 .65698 L .37839 .65392 L F
.3823 .65484 m .38211 .65773 L .38038 .65698 L F
.201 .261 .702 r
.38347 .65446 m .3847 .65709 L .3823 .65484 L F
.48 .285 .538 r
.3823 .65484 m .3847 .65709 L .38211 .65773 L F
.815 .832 .863 r
.34599 .51271 m .34551 .51402 L .34306 .51301 L F
.422 .201 .47 r
.34947 .58084 m .34908 .58369 L .34673 .58424 L F
.582 .422 .63 r
.34964 .58641 m .34673 .58424 L .34908 .58369 L F
.34964 .58641 m .34698 .58701 L .34673 .58424 L F
.108 .445 .88 r
.58877 .39182 m .59108 .3915 L .58808 .38994 L F
.58877 .39182 m .59198 .39321 L .59108 .3915 L F
.957 .613 .277 r
.60955 .44708 m .61057 .44593 L .60913 .44488 L F
.60955 .44708 m .61107 .44833 L .61057 .44593 L F
.57 .318 .495 r
.34562 .52184 m .34372 .52321 L .34308 .52254 L F
.34372 .52321 m .34179 .52459 L .3423 .52378 L F
.34372 .52321 m .3423 .52378 L .34308 .52254 L F
.815 .606 .62 r
.34795 .5233 m .34562 .52184 L .34781 .52185 L F
.34795 .5233 m .34442 .5243 L .34562 .52184 L F
.57 .318 .495 r
.34562 .52184 m .34518 .52276 L .34317 .5236 L F
.34317 .5236 m .34442 .5243 L .34179 .52459 L F
.618 .583 .792 r
.34179 .52459 m .34442 .5243 L .34392 .52312 L F
.697 .284 .259 r
.34308 .52254 m .34179 .52459 L .33985 .52235 L F
.618 .583 .792 r
.3419 .52407 m .34392 .52312 L .34269 .52021 L F
.34179 .52459 m .34392 .52312 L .3419 .52407 L F
0 0 .406 r
.34392 .52312 m .34661 .52206 L .34269 .52021 L F
.473 .895 .843 r
.34661 .52206 m .34556 .52247 L .34623 .52231 L F
.57 .318 .495 r
.34518 .52276 m .34442 .5243 L .34317 .5236 L F
0 0 .406 r
.3465 .52217 m .34661 .52206 L .34522 .52261 L F
.473 .895 .843 r
.34661 .52206 m .34505 .52259 L .34556 .52247 L F
.34505 .52259 m .34384 .52301 L .34469 .52276 L F
0 0 .406 r
.3465 .52217 m .34384 .52301 L .34661 .52206 L F
.567 .243 .38 r
.34518 .52262 m .34554 .52247 L .34632 .52223 L F
.34554 .52247 m .34625 .52225 L .34632 .52223 L F
.473 .895 .843 r
.34505 .52259 m .34469 .52276 L .34623 .52231 L F
.567 .243 .38 r
.34518 .52262 m .34632 .52223 L .34522 .52261 L F
0 0 .406 r
.34442 .5243 m .3465 .52217 L .34392 .52312 L F
.3465 .52217 m .34522 .52261 L .34392 .52312 L F
.567 .243 .38 r
.34384 .52301 m .34583 .52236 L .34518 .52262 L F
0 0 .406 r
.34442 .5243 m .34384 .52301 L .3465 .52217 L F
.567 .243 .38 r
.34554 .52247 m .34583 .52236 L .34625 .52225 L F
.473 .895 .843 r
.347 .52199 m .34623 .52231 L .34781 .52185 L F
.567 .243 .38 r
.34522 .52261 m .34632 .52223 L .34781 .52185 L F
.473 .895 .843 r
.34661 .52206 m .34623 .52231 L .347 .52199 L F
.567 .243 .38 r
.34384 .52301 m .34549 .52244 L .34583 .52236 L F
.945 .713 .556 r
.34941 .52144 m .34781 .52185 L .34831 .51916 L F
.157 .023 .435 r
.34781 .52185 m .34989 .51769 L .34831 .51916 L F
.34781 .52185 m .34968 .521 L .34989 .51769 L F
.567 .243 .38 r
.34549 .52244 m .34968 .521 L .34781 .52185 L F
.945 .713 .556 r
.35016 .52299 m .34781 .52185 L .34941 .52144 L F
.918 .913 .798 r
.35016 .52299 m .34795 .5233 L .34781 .52185 L F
.35016 .52299 m .34779 .52665 L .34795 .5233 L F
.365 .136 .428 r
.36222 .5162 m .36146 .51879 L .35989 .51862 L F
.964 .837 .67 r
.39422 .68596 m .39646 .68464 L .39504 .6877 L F
.664 .963 .762 r
.62431 .36697 m .62722 .36526 L .62641 .36727 L F
0 0 0 r
.6273 .36517 m .63004 .36217 L .62863 .36418 L F
.758 .977 .716 r
.63109 .35998 m .63004 .36217 L .63271 .35916 L F
.71 .886 .499 r
.62863 .36418 m .63004 .36217 L .63109 .35998 L F
.62863 .36418 m .63109 .35998 L .63135 .36213 L F
.62863 .36418 m .63135 .36213 L .6314 .36257 L F
0 0 0 r
.62722 .36526 m .6273 .36517 L .62863 .36418 L F
.62641 .36727 m .62722 .36526 L .62863 .36418 L F
.772 .605 .673 r
.49157 .48361 m .48983 .48692 L .49078 .48395 L F
.773 .793 .869 r
.63352 .42393 m .63508 .41911 L .63215 .42235 L F
.63352 .42393 m .63565 .42248 L .63508 .41911 L F
.752 .358 .306 r
.70993 .31332 m .70582 .31091 L .70561 .31178 L F
.757 .332 .241 r
.27338 .62168 m .27692 .61963 L .27562 .62085 L F
.405 .561 .896 r
.27861 .61787 m .27692 .61963 L .27618 .61759 L F
.524 .838 .528 r
.27861 .61787 m .27562 .62085 L .27692 .61963 L F
.609 .551 .764 r
.47104 .54113 m .47176 .54476 L .46903 .54559 L F
.369 .404 .766 r
.47212 .54755 m .46903 .54559 L .47176 .54476 L F
.779 .74 .817 r
.36667 .5677 m .36241 .56746 L .3645 .56389 L F
.474 .261 .509 r
.36667 .5677 m .36398 .57118 L .36241 .56746 L F
.36667 .5677 m .36644 .5706 L .36398 .57118 L F
.36667 .5677 m .36644 .5706 L .36398 .57118 L F
.451 .242 .503 r
.36901 .56733 m .36644 .5706 L .36667 .5677 L F
.36667 .5677 m .36644 .5706 L .36901 .56733 L F
.785 .666 .733 r
.61797 .37426 m .62209 .37214 L .62084 .37067 L F
.61797 .37426 m .62012 .37563 L .62209 .37214 L F
.992 .883 .596 r
.3706 .63485 m .37165 .63564 L .36968 .63752 L F
.849 .838 .834 r
.48218 .44183 m .48313 .44495 L .48141 .44639 L F
.731 .777 .89 r
.48618 .44229 m .48313 .44495 L .48218 .44183 L F
.755 .803 .322 r
.33993 .61166 m .3397 .61322 L .34203 .61275 L F
.33993 .61166 m .33891 .61519 L .3397 .61322 L F
.699 .865 .961 r
.6166 .34885 m .6142 .35025 L .61283 .34878 L F
.837 .98 .876 r
.67689 .3217 m .67594 .32442 L .67793 .32257 L F
.844 .986 .862 r
.67689 .3217 m .67396 .32455 L .67594 .32442 L F
.615 .419 .594 r
.37605 .58083 m .37641 .58385 L .37333 .58392 L F
.301 .196 .564 r
.3782 .58278 m .37641 .58385 L .37605 .58083 L F
.616 .829 .432 r
.6608 .3202 m .65846 .32362 L .65987 .32143 L F
.669 .907 .576 r
.65846 .32362 m .6572 .32467 L .65987 .32143 L F
.173 .153 .594 r
.47488 .56314 m .47289 .56518 L .47287 .561 L F
.293 .339 .739 r
.47488 .56314 m .47556 .56694 L .47289 .56518 L F
.896 .663 .578 r
.335 .61315 m .33109 .6147 L .33292 .61266 L F
.335 .61315 m .33443 .61582 L .33109 .6147 L F
.823 .99 .731 r
.38164 .6221 m .37825 .62527 L .3803 .62163 L F
.725 .62 .74 r
.48507 .48394 m .48286 .48737 L .48312 .48504 L F
.657 .529 .696 r
.48507 .48394 m .488 .48934 L .48286 .48737 L F
.618 .455 .64 r
.48701 .48976 m .48286 .48737 L .488 .48934 L F
.48701 .48976 m .48205 .49198 L .48286 .48737 L F
0 0 .27 r
.32034 .60323 m .32194 .60196 L .32233 .59929 L F
0 0 .181 r
.32034 .60323 m .3215 .60459 L .32194 .60196 L F
.32034 .60323 m .32008 .60576 L .3215 .60459 L F
.609 .315 .445 r
.44076 .52536 m .44371 .52323 L .43958 .52247 L F
.44076 .52536 m .44359 .5254 L .44371 .52323 L F
.214 .513 .912 r
.36837 .62859 m .36741 .62909 L .3655 .62758 L F
.728 .522 .612 r
.36741 .62909 m .36845 .6313 L .36439 .63308 L F
.816 .789 .827 r
.51103 .43 m .50865 .43352 L .5068 .43197 L F
0 .361 .832 r
.59734 .39769 m .59957 .39776 L .59652 .3959 L F
.59734 .39769 m .60027 .39931 L .59957 .39776 L F
0 0 0 r
.6608 .3202 m .66275 .31889 L .66383 .31815 L F
.6608 .3202 m .65987 .32143 L .66275 .31889 L F
.397 .113 .362 r
.3521 .58045 m .34908 .58369 L .34947 .58084 L F
.971 .657 .337 r
.38628 .49094 m .38663 .4933 L .38497 .49197 L F
.516 .54 .819 r
.38663 .4933 m .38752 .48894 L .38628 .49094 L F
.792 .925 .549 r
.58902 .35895 m .58771 .36021 L .58952 .35696 L F
.862 .652 .617 r
.34101 .53548 m .33983 .53883 L .33653 .53438 L F
.284 .185 .563 r
.34323 .65281 m .34163 .65466 L .34136 .6516 L F
.34323 .65281 m .34163 .65466 L .34136 .6516 L F
.447 .11 .299 r
.34136 .6516 m .34393 .65119 L .34323 .65281 L F
.995 .844 .496 r
.39919 .57886 m .40043 .58097 L .4008 .57514 L F
.981 .855 .471 r
.39864 .58103 m .40043 .58097 L .39919 .57886 L F
.39864 .58103 m .39981 .5836 L .40043 .58097 L F
.441 .799 .997 r
.43424 .49373 m .4366 .49323 L .43249 .49267 L F
.43424 .49373 m .4366 .49323 L .43249 .49267 L F
.158 .54 .925 r
.73623 .33162 m .73351 .33118 L .73204 .33111 L F
.73623 .33162 m .73664 .33199 L .73351 .33118 L F
.813 .982 .702 r
.36467 .55068 m .36276 .55182 L .36396 .55014 L F
.232 0 .13 r
.36425 .55035 m .36255 .54862 L .36467 .55068 L F
.36425 .55036 m .3612 .55207 L .36255 .54862 L F
.661 .617 .795 r
.3592 .54672 m .36424 .55035 L .36224 .5458 L F
.813 .982 .702 r
.36467 .55068 m .36425 .55035 L .36476 .54968 L F
.661 .617 .795 r
.36424 .55035 m .36425 .55036 L .36425 .55035 L F
.36424 .55035 m .36425 .55035 L .36224 .5458 L F
.198 .313 .756 r
.36224 .5458 m .36425 .55035 L .36483 .54893 L F
.813 .982 .702 r
.36425 .55035 m .36396 .55014 L .36476 .54968 L F
.198 .313 .756 r
.36425 .55035 m .36425 .55036 L .36483 .54893 L F
.813 .982 .702 r
.36476 .54968 m .36445 .54986 L .36483 .54893 L F
.36445 .54986 m .36396 .55014 L .36483 .54893 L F
.232 0 .13 r
.36425 .55036 m .36425 .55035 L .36467 .55068 L F
0 0 0 r
.66821 .37102 m .66586 .37242 L .66527 .37376 L F
.492 .364 .633 r
.46953 .51957 m .4698 .52239 L .46738 .523 L F
.474 .466 .768 r
.47065 .52484 m .46738 .523 L .4698 .52239 L F
.211 0 0 r
.29143 .5623 m .29374 .56249 L .2953 .56115 L F
.69 .263 .23 r
.29374 .56249 m .298 .56159 L .2953 .56115 L F
.62 .861 .989 r
.61018 .35 m .60721 .35123 L .60596 .3499 L F
.706 .372 .408 r
.42899 .59402 m .4287 .5961 L .42625 .59365 L F
.799 .524 .521 r
.6248 .36011 m .62802 .3579 L .62622 .35946 L F
.638 .796 .958 r
.44254 .45904 m .44005 .46047 L .4388 .45839 L F
.269 0 0 r
.34831 .51916 m .34319 .51891 L .34623 .51883 L F
.54 .464 .718 r
.36248 .56436 m .36241 .56746 L .35994 .568 L F
.574 .017 0 r
.24436 .62157 m .24306 .62181 L .24098 .62093 L F
.14 0 0 r
.24691 .62111 m .24306 .62181 L .24436 .62157 L F
.875 .71 .674 r
.70334 .31414 m .6994 .31557 L .70186 .31239 L F
.662 .829 .964 r
.70561 .31178 m .70334 .31414 L .70186 .31239 L F
.911 .908 .807 r
.34779 .52665 m .34596 .52561 L .34795 .5233 L F
.995 .76 .457 r
.6032 .431 m .6047 .42953 L .60331 .42819 L F
.6032 .431 m .60452 .43228 L .6047 .42953 L F
.889 .971 .83 r
.63512 .39457 m .63693 .3943 L .63402 .39771 L F
.612 .951 .801 r
.63895 .39265 m .63693 .3943 L .63852 .39253 L F
.615 .956 .89 r
.63852 .39253 m .63693 .3943 L .63512 .39457 L F
.559 .84 .501 r
.67984 .3032 m .67837 .30486 L .67988 .30308 L F
.588 .908 .655 r
.67837 .30486 m .67867 .30413 L .67988 .30308 L F
.67837 .30486 m .67686 .30584 L .67867 .30413 L F
.539 .811 .996 r
.37177 .60151 m .371 .60334 L .36947 .60182 L F
.37177 .60151 m .37352 .60281 L .371 .60334 L F
.682 .627 .788 r
.37352 .60281 m .37271 .60433 L .371 .60334 L F
.791 .371 .251 r
.3506 .63563 m .34806 .63601 L .34769 .63539 L F
.3506 .63563 m .35354 .63861 L .34806 .63601 L F
.9 .731 .664 r
.35285 .63458 m .35354 .63861 L .3506 .63563 L F
.385 .58 .918 r
.72585 .31517 m .72502 .31719 L .72422 .31504 L F
0 0 .128 r
.72585 .31517 m .72529 .31932 L .72502 .31719 L F
.104 .06 .518 r
.23183 .57759 m .23172 .58258 L .23332 .57936 L F
.991 .855 .497 r
.61047 .45823 m .61113 .45586 L .61022 .45372 L F
.786 .695 .764 r
.59447 .37112 m .59879 .37135 L .5959 .37501 L F
0 .075 .623 r
.59967 .36996 m .60083 .37434 L .59879 .37135 L F
.284 .034 .347 r
.42882 .54367 m .42837 .54507 L .43119 .542 L F
.63 .25 .305 r
.52853 .46845 m .53257 .46821 L .53109 .47035 L F
.671 .299 .332 r
.53257 .46821 m .53508 .47048 L .53109 .47035 L F
.706 .953 .952 r
.67689 .3217 m .67793 .32257 L .68108 .32074 L F
.728 .767 .884 r
.42398 .47097 m .4224 .47111 L .42307 .46845 L F
.858 .828 .817 r
.42696 .46697 m .42398 .47097 L .42307 .46845 L F
.273 .452 .855 r
.42398 .47097 m .42528 .46862 L .42352 .47065 L F
.221 .742 .839 r
.42415 .47108 m .4224 .47111 L .42398 .47097 L F
.273 .452 .855 r
.42398 .47097 m .42352 .47065 L .42269 .4716 L F
.221 .742 .839 r
.42542 .47107 m .42415 .47108 L .42398 .47097 L F
.9 .974 .81 r
.42542 .47107 m .42696 .46697 L .42847 .46816 L F
.42542 .47107 m .42398 .47097 L .42696 .46697 L F
.653 .957 .752 r
.65617 .39326 m .6577 .39119 L .65574 .39295 L F
.65617 .39326 m .65928 .39062 L .6577 .39119 L F
.497 .265 .492 r
.3662 .55713 m .36358 .55818 L .3633 .55536 L F
.085 0 .096 r
.69607 .32963 m .69802 .33022 L .69732 .32798 L F
.69607 .32963 m .69589 .33167 L .69802 .33022 L F
.837 .899 .883 r
.36787 .59611 m .36964 .59712 L .37277 .59411 L F
.021 0 .172 r
.3304 .57349 m .33253 .57049 L .33021 .57031 L F
.264 .666 .967 r
.44674 .53541 m .44801 .5352 L .4463 .53448 L F
.531 .566 .835 r
.45082 .53899 m .44674 .53541 L .44801 .5352 L F
.765 .808 .887 r
.46066 .45365 m .46245 .45527 L .45875 .45495 L F
.806 .875 .897 r
.46389 .45118 m .46245 .45527 L .46066 .45365 L F
.46389 .45118 m .46542 .45253 L .46245 .45527 L F
.531 .566 .835 r
.45082 .53899 m .44801 .5352 L .44892 .53767 L F
.541 .781 .987 r
.45082 .53899 m .45138 .53673 L .44892 .53767 L F
.45082 .53899 m .45305 .53818 L .45138 .53673 L F
.351 .408 .78 r
.45082 .53899 m .45352 .54187 L .45305 .53818 L F
.796 .631 .677 r
.29839 .51113 m .29461 .51531 L .2929 .51205 L F
.29839 .51113 m .2929 .51205 L .29446 .51206 L F
0 0 0 r
.29839 .51113 m .29795 .51135 L .29966 .51238 L F
.29839 .51113 m .29446 .51206 L .29795 .51135 L F
.937 .745 .618 r
.38867 .53177 m .38803 .53521 L .39003 .53576 L F
.986 .716 .35 r
.38888 .5368 m .39003 .53576 L .38803 .53521 L F
.38888 .5368 m .39018 .53808 L .39003 .53576 L F
.581 .394 .594 r
.5014 .48088 m .50188 .48398 L .4985 .484 L F
.598 .43 .624 r
.50188 .48398 m .49935 .4867 L .4985 .484 L F
.73 .613 .727 r
.56619 .42323 m .56876 .41994 L .56502 .41925 L F
0 .17 .701 r
.39849 .52541 m .39912 .52395 L .39771 .52228 L F
0 .179 .708 r
.39849 .52541 m .40101 .52786 L .39912 .52395 L F
.008 0 .358 r
.32848 .57758 m .3301 .57668 L .3304 .57349 L F
0 0 .332 r
.32848 .57758 m .32935 .57871 L .3301 .57668 L F
.32848 .57758 m .32921 .5807 L .32935 .57871 L F
.014 0 .022 r
.52973 .40729 m .52658 .41051 L .52855 .40926 L F
.52973 .40729 m .52658 .41051 L .52855 .40926 L F
.826 1 .819 r
.53164 .4053 m .52973 .40729 L .53022 .40504 L F
.473 .443 .744 r
.52855 .40926 m .53022 .40504 L .52973 .40729 L F
.52855 .40926 m .53178 .40822 L .53022 .40504 L F
.312 0 .011 r
.52855 .40926 m .53121 .40986 L .53178 .40822 L F
.948 .601 .212 r
.53022 .40504 m .53148 .40851 L .5293 .40487 L F
.53022 .40504 m .5293 .40487 L .52909 .40453 L F
.826 1 .819 r
.53251 .4044 m .53164 .4053 L .53022 .40504 L F
.794 .698 .759 r
.59447 .37112 m .5959 .37501 L .59201 .37435 L F
.519 .351 .593 r
.47553 .49995 m .47588 .50416 L .47289 .50419 L F
.52 .365 .611 r
.47289 .50419 m .47599 .50618 L .4733 .50672 L F
.47289 .50419 m .47588 .50416 L .47599 .50618 L F
.569 0 0 r
.4287 .5961 m .43068 .59703 L .43223 .59838 L F
.714 .617 .748 r
.47777 .49652 m .47916 .50049 L .47553 .49995 L F
.368 .043 .277 r
.47916 .50049 m .47588 .50416 L .47553 .49995 L F
.47916 .50049 m .47845 .5033 L .47588 .50416 L F
.35 .289 .648 r
.48048 .49598 m .47916 .50049 L .47777 .49652 L F
.48048 .49598 m .48276 .49945 L .47916 .50049 L F
.543 .373 .602 r
.48276 .49945 m .47845 .5033 L .47916 .50049 L F
.134 0 0 r
.69529 .30722 m .69381 .30874 L .69127 .3095 L F
.564 .083 .073 r
.69775 .30864 m .69381 .30874 L .69529 .30722 L F
.468 .078 .217 r
.23934 .53831 m .2373 .54059 L .23572 .54039 L F
.595 .858 .514 r
.24015 .53716 m .2373 .54059 L .23934 .53831 L F
.876 .626 .557 r
.2373 .54059 m .23955 .54174 L .23934 .53831 L F
.889 .971 .83 r
.63512 .39457 m .63489 .39524 L .63513 .39503 L F
.447 .825 .584 r
.63574 .39451 m .63513 .39503 L .63408 .39577 L F
.133 0 .037 r
.63852 .39253 m .63512 .39457 L .63513 .39503 L F
.447 .825 .584 r
.63709 .39349 m .63513 .39503 L .63574 .39451 L F
.889 .971 .83 r
.63489 .39524 m .63402 .39771 L .63513 .39503 L F
.692 .179 .009 r
.63402 .39771 m .63317 .39888 L .63513 .39503 L F
0 .346 .803 r
.63402 .39771 m .63849 .40087 L .63604 .3988 L F
.692 .179 .009 r
.63402 .39771 m .63604 .3988 L .63317 .39888 L F
.988 .821 .437 r
.39923 .57282 m .39994 .57443 L .40039 .57086 L F
.912 .677 .177 r
.39976 .56728 m .39991 .57023 L .40039 .57086 L F
.957 .858 .443 r
.39991 .57023 m .39923 .57282 L .40039 .57086 L F
.793 .803 .861 r
.59865 .35774 m .60126 .35819 L .60094 .35818 L F
.502 .904 .79 r
.60247 .35685 m .60001 .35814 L .60094 .35818 L F
0 0 .148 r
.59949 .35841 m .59865 .35774 L .60094 .35818 L F
.502 .904 .79 r
.60001 .35814 m .59949 .35841 L .60094 .35818 L F
.793 .803 .861 r
.60126 .35819 m .60311 .35852 L .60094 .35818 L F
.209 0 0 r
.60311 .35852 m .60476 .35894 L .60094 .35818 L F
.517 .057 .1 r
.52539 .41049 m .52855 .40926 L .52658 .41051 L F
.696 .679 .83 r
.56502 .41925 m .56876 .41994 L .56732 .41619 L F
.662 .661 .838 r
.56732 .41619 m .56876 .41994 L .57054 .41832 L F
.704 .59 .726 r
.29521 .64153 m .29714 .63767 L .29487 .63873 L F
.796 .976 .906 r
.37294 .70805 m .37636 .70569 L .37479 .70516 L F
.801 .894 .91 r
.37636 .70569 m .37731 .7021 L .37479 .70516 L F
.37636 .70569 m .37919 .70313 L .37731 .7021 L F
.819 .752 .789 r
.43071 .52833 m .42979 .52937 L .43196 .53203 L F
.698 .664 .813 r
.42685 .53604 m .43045 .5367 L .42857 .53076 L F
.43045 .5367 m .43042 .53639 L .42857 .53076 L F
.724 .679 .806 r
.42857 .53076 m .43053 .53671 L .43251 .53551 L F
.42857 .53076 m .43251 .53551 L .43196 .53203 L F
.575 .532 .769 r
.42539 .53209 m .42685 .53604 L .42857 .53076 L F
.84 .583 .551 r
.43196 .53203 m .42794 .53144 L .42857 .53076 L F
.819 .752 .789 r
.42979 .52937 m .42794 .53144 L .43 .53175 L F
.42979 .52937 m .43 .53175 L .43196 .53203 L F
.698 .664 .813 r
.43045 .5367 m .43053 .53671 L .43042 .53639 L F
.501 .563 .85 r
.42685 .53604 m .43215 .53828 L .43053 .53671 L F
.531 .283 .485 r
.43053 .53671 m .43261 .5376 L .43251 .53551 L F
.43053 .53671 m .43215 .53828 L .43261 .5376 L F
.582 .568 .803 r
.58179 .45532 m .58763 .46107 L .58622 .46079 L F
0 .57 .775 r
.58763 .46107 m .5903 .46128 L .58622 .46079 L F
.36 .111 .395 r
.36843 .66678 m .36739 .66862 L .37029 .66688 L F
.465 .307 .582 r
.292 .62591 m .2944 .62813 L .29419 .6253 L F
.292 .62591 m .29212 .62865 L .2944 .62813 L F
.2944 .62813 m .29212 .62865 L .292 .62591 L F
0 0 0 r
.29143 .5623 m .28855 .56457 L .29067 .56309 L F
.083 0 0 r
.29067 .56309 m .29374 .56249 L .29143 .5623 L F
.682 .627 .788 r
.37352 .60281 m .37499 .60651 L .37271 .60433 L F
.22 0 .333 r
.37269 .60742 m .37271 .60433 L .37499 .60651 L F
0 0 0 r
.37745 .6029 m .37499 .60651 L .37352 .60281 L F
.37745 .6029 m .37711 .6034 L .37688 .60374 L F
.65 .378 .494 r
.37711 .6034 m .37745 .6029 L .37352 .60281 L F
.37715 .6034 m .37745 .6029 L .37711 .6034 L F
.397 .849 .903 r
.37715 .6034 m .38022 .6028 L .37745 .6029 L F
.35 .642 .964 r
.37714 .60336 m .3784 .60274 L .37715 .6034 L F
0 0 0 r
.37745 .6029 m .37717 .60331 L .37712 .60338 L F
.37745 .6029 m .37712 .60338 L .37712 .60339 L F
.35 .642 .964 r
.37649 .60086 m .3779 .60225 L .37714 .60336 L F
.3779 .60225 m .3784 .60274 L .37714 .60336 L F
0 0 0 r
.37712 .60339 m .37712 .60338 L .37711 .6034 L F
.475 .693 .963 r
.37406 .6003 m .37712 .60338 L .37352 .60281 L F
.37712 .60338 m .37715 .6034 L .37711 .6034 L F
.37712 .60338 m .37711 .6034 L .37352 .60281 L F
0 0 0 r
.37688 .60374 m .37596 .60509 L .37499 .60651 L F
.37717 .60331 m .37596 .60509 L .37688 .60374 L F
.625 .955 .795 r
.37596 .60509 m .37269 .60742 L .37499 .60651 L F
.996 .771 .467 r
.38719 .66694 m .38763 .6644 L .38639 .66308 L F
.514 .581 .86 r
.38763 .6644 m .39175 .66746 L .39157 .66491 L F
.706 .646 .787 r
.42213 .59362 m .42625 .59365 L .42468 .59032 L F
.691 .421 .509 r
.42213 .59362 m .42331 .59513 L .42625 .59365 L F
.646 .811 .962 r
.42945 .58969 m .42859 .5898 L .42737 .58979 L F
.42859 .5898 m .42468 .59032 L .42737 .58979 L F
.63 .827 .976 r
.42736 .58982 m .42721 .58998 L .42859 .5898 L F
.42736 .58982 m .42859 .5898 L .42768 .5898 L F
.046 .028 .511 r
.42738 .5898 m .42909 .59146 L .43134 .58983 L F
.42859 .5898 m .43134 .58983 L .43137 .58981 L F
.42738 .5898 m .43134 .58983 L .42859 .5898 L F
.63 .827 .976 r
.42768 .5898 m .42859 .5898 L .42945 .58969 L F
.046 .028 .511 r
.42737 .58979 m .42738 .5898 L .43137 .58981 L F
.42738 .5898 m .43137 .58981 L .43137 .58981 L F
.154 .096 .534 r
.42625 .59365 m .42805 .59281 L .42737 .58981 L F
.42736 .58982 m .42737 .58981 L .42737 .58979 L F
.42625 .59365 m .42737 .58981 L .42736 .58982 L F
.63 .827 .976 r
.42849 .58961 m .42736 .58982 L .42945 .58969 L F
.42736 .58982 m .42468 .59032 L .42721 .58998 L F
.154 .096 .534 r
.42736 .58982 m .42737 .58979 L .42468 .59032 L F
.63 .827 .976 r
.42322 .58918 m .42468 .59032 L .42849 .58961 L F
.154 .096 .534 r
.42625 .59365 m .42736 .58982 L .42468 .59032 L F
.734 .358 .34 r
.42625 .59365 m .4287 .5961 L .42603 .59538 L F
.691 .232 .157 r
.42603 .59538 m .4287 .5961 L .42713 .59769 L F
.42669 .5969 m .42713 .59769 L .42706 .59776 L F
.42603 .59538 m .42713 .59769 L .42669 .5969 L F
.567 .177 .263 r
.42603 .59538 m .42482 .59628 L .42174 .59558 L F
.42603 .59538 m .42482 .59628 L .42174 .59558 L F
.734 .358 .34 r
.42625 .59365 m .42603 .59538 L .42482 .59628 L F
.42625 .59365 m .42557 .59491 L .4264 .59626 L F
.691 .232 .157 r
.42603 .59538 m .42706 .59776 L .42482 .59628 L F
.734 .358 .34 r
.42557 .59491 m .42482 .59628 L .42633 .59626 L F
.42557 .59491 m .42633 .59626 L .4264 .59626 L F
.42625 .59365 m .4264 .59626 L .42805 .59281 L F
.645 .733 .913 r
.41142 .4771 m .40866 .47596 L .4123 .47524 L F
0 0 0 r
.40866 .47596 m .41021 .47584 L .4123 .47524 L F
.849 .992 .844 r
.4123 .47524 m .41021 .47584 L .41343 .47287 L F
.4123 .47524 m .41343 .47287 L .41368 .47264 L F
.645 .733 .913 r
.41427 .47829 m .41142 .4771 L .4123 .47524 L F
.705 .759 .894 r
.4162 .47688 m .41427 .47829 L .4123 .47524 L F
.298 .498 .884 r
.35777 .68842 m .35695 .69031 L .35484 .68706 L F
.537 .503 .765 r
.35777 .68842 m .35608 .69268 L .35695 .69031 L F
.751 .907 .946 r
.62324 .34635 m .6189 .3471 L .62192 .345 L F
.813 .896 .902 r
.62609 .34373 m .62324 .34635 L .62192 .345 L F
.946 .587 .268 r
.39994 .57443 m .40037 .57629 L .4008 .57514 L F
.995 .844 .496 r
.39919 .57886 m .4008 .57514 L .40037 .57629 L F
.727 .814 .919 r
.6322 .34258 m .62843 .3424 L .63102 .34137 L F
.745 .906 .949 r
.6322 .34258 m .63317 .33977 L .63517 .33988 L F
.6322 .34258 m .63102 .34137 L .63317 .33977 L F
.992 .814 .439 r
.67832 .35267 m .67852 .35556 L .67816 .35309 L F
.752 .668 .768 r
.68118 .35218 m .67852 .35556 L .67832 .35267 L F
.18 .286 .737 r
.67816 .35309 m .67852 .35556 L .68014 .35374 L F
0 0 .369 r
.68014 .35374 m .67852 .35556 L .67905 .35744 L F
.937 .957 .652 r
.42514 .53727 m .42538 .53949 L .42685 .53604 L F
.815 .861 .413 r
.42474 .53978 m .42538 .53949 L .42514 .53727 L F
.42474 .53978 m .42439 .54187 L .42538 .53949 L F
.622 .684 .887 r
.35306 .70568 m .35451 .70394 L .35223 .70355 L F
.35306 .70568 m .35652 .70632 L .35451 .70394 L F
.567 .353 .549 r
.50486 .47794 m .50451 .48063 L .5014 .48088 L F
.551 .359 .573 r
.50451 .48063 m .50188 .48398 L .5014 .48088 L F
.949 .614 .204 r
.61159 .42262 m .61329 .42649 L .61158 .42553 L F
.874 .432 .1 r
.61329 .42649 m .61247 .42757 L .61158 .42553 L F
.908 .5 .138 r
.61402 .42866 m .61247 .42757 L .61329 .42649 L F
.428 0 0 r
.28058 .64315 m .28192 .64277 L .28404 .64388 L F
.62 .335 .463 r
.27838 .5687 m .27912 .56945 L .27951 .56792 L F
.052 0 0 r
.27912 .56945 m .282 .5674 L .27951 .56792 L F
.911 .93 .555 r
.36429 .5234 m .36316 .52544 L .36456 .52174 L F
.434 .024 .159 r
.33876 .6416 m .33849 .6386 L .33679 .6412 L F
0 0 .182 r
.24073 .52925 m .24269 .52836 L .24284 .52578 L F
.216 0 0 r
.24073 .52925 m .24234 .52972 L .24269 .52836 L F
.24073 .52925 m .23892 .53012 L .24234 .52972 L F
.239 .343 .769 r
.26756 .63413 m .26721 .63589 L .26889 .63494 L F
.538 .796 .993 r
.37999 .67463 m .3823 .67429 L .37843 .67334 L F
.745 .255 0 r
.38179 .67736 m .37999 .67463 L .37843 .67334 L F
.541 .284 .474 r
.38179 .67736 m .3823 .67429 L .37999 .67463 L F
.674 .523 .673 r
.56219 .42018 m .56502 .41925 L .56471 .41678 L F
.526 .655 .917 r
.56359 .41477 m .56471 .41678 L .56732 .41619 L F
.696 .679 .83 r
.56502 .41925 m .56732 .41619 L .56471 .41678 L F
.726 .617 .736 r
.39175 .66746 m .39429 .66438 L .39157 .66491 L F
.659 .901 .568 r
.39248 .66612 m .39429 .66438 L .39175 .66746 L F
.994 .754 .408 r
.39175 .66746 m .39034 .66913 L .39248 .66612 L F
.39175 .66746 m .39164 .6704 L .39034 .66913 L F
.173 .153 .594 r
.47488 .56314 m .47287 .561 L .47438 .56048 L F
.047 0 .218 r
.28704 .6355 m .2895 .63195 L .2891 .6334 L F
.403 .129 .379 r
.28704 .6355 m .2891 .6334 L .28916 .63718 L F
.24 .238 .655 r
.29156 .63452 m .2891 .6334 L .2895 .63195 L F
.381 .112 .376 r
.28916 .63718 m .2891 .6334 L .29156 .63452 L F
.874 .853 .818 r
.63508 .41911 m .63565 .42248 L .63806 .4189 L F
.914 .516 .142 r
.58278 .38212 m .58227 .38309 L .5812 .38031 L F
.58278 .38212 m .58379 .38428 L .58227 .38309 L F
.841 .927 .888 r
.68416 .37746 m .68653 .37761 L .68546 .37637 L F
.797 .999 .821 r
.68653 .37761 m .68786 .37486 L .68546 .37637 L F
.68653 .37761 m .68942 .37472 L .68786 .37486 L F
.611 .316 .444 r
.50486 .47794 m .5074 .47987 L .50451 .48063 L F
.50486 .47794 m .50755 .47764 L .5074 .47987 L F
.877 .993 .784 r
.34415 .62255 m .34769 .61892 L .34615 .61917 L F
0 .122 .671 r
.34822 .6177 m .34769 .61892 L .34586 .61541 L F
.626 .961 .84 r
.34615 .61917 m .34769 .61892 L .34822 .6177 L F
.75 .407 0 r
.41315 .59682 m .413 .59761 L .41252 .59542 L F
.41315 .59682 m .41401 .59927 L .413 .59761 L F
.355 0 .2 r
.24284 .52578 m .24498 .52608 L .24619 .52366 L F
.658 .788 .329 r
.24619 .52366 m .24615 .52357 L .24874 .52275 L F
.24619 .52366 m .24498 .52608 L .24615 .52357 L F
.845 .742 .75 r
.56557 .39098 m .56169 .39237 L .56446 .38971 L F
.062 0 0 r
.56446 .38971 m .56322 .39157 L .56362 .39139 L F
.979 .708 .315 r
.5649 .38883 m .56557 .39098 L .56446 .38971 L F
.867 .93 .864 r
.56824 .38804 m .56557 .39098 L .56446 .38971 L F
.062 0 0 r
.56446 .38971 m .56362 .39139 L .56595 .39038 L F
.979 .708 .315 r
.56435 .38707 m .5649 .38883 L .56446 .38971 L F
.845 .742 .75 r
.56557 .39098 m .56347 .3943 L .56169 .39237 L F
.575 .084 0 r
.28622 .64075 m .288 .64259 L .28655 .64094 L F
.779 .45 .431 r
.58179 .45532 m .58622 .46079 L .58248 .46024 L F
0 0 .246 r
.41283 .57134 m .41326 .57372 L .41294 .56981 L F
.255 .728 .94 r
.3027 .6511 m .30393 .6518 L .30016 .65132 L F
.026 .075 .576 r
.30613 .6525 m .30476 .65468 L .30393 .6518 L F
.616 .512 .713 r
.48983 .48692 m .488 .48934 L .48507 .48394 L F
.515 .845 .558 r
.68281 .30046 m .67984 .3032 L .67988 .30308 L F
.639 .93 .668 r
.42174 .59558 m .42331 .59513 L .42213 .59362 L F
.868 .953 .864 r
.42122 .59219 m .42213 .59362 L .42468 .59032 L F
0 .11 .636 r
.42122 .59219 m .42174 .59558 L .42213 .59362 L F
.678 .841 .961 r
.44767 .45667 m .44674 .45918 L .44521 .45821 L F
.44767 .45667 m .4493 .45808 L .44674 .45918 L F
.774 .772 .851 r
.48141 .44639 m .47675 .44732 L .47946 .44483 L F
.849 .838 .834 r
.48218 .44183 m .48141 .44639 L .47946 .44483 L F
.99 .808 .566 r
.35312 .66862 m .35471 .66739 L .35365 .66978 L F
.521 .847 .998 r
.3554 .66586 m .35724 .66675 L .35471 .66739 L F
.718 .951 .66 r
.3554 .66586 m .35471 .66739 L .35312 .66862 L F
0 0 0 r
.28855 .56457 m .28903 .56538 L .29067 .56309 L F
.28855 .56457 m .28682 .56623 L .28903 .56538 L F
.496 .825 .999 r
.31484 .63855 m .31062 .63809 L .31327 .63713 L F
.444 .758 .995 r
.31766 .63815 m .31484 .63855 L .31327 .63713 L F
.637 .157 .096 r
.31484 .63855 m .31654 .64041 L .31545 .64078 L F
.561 .458 .694 r
.27851 .53608 m .28254 .53854 L .27912 .53917 L F
.427 .805 .992 r
.27646 .53786 m .28254 .53854 L .27851 .53608 L F
.646 .959 .929 r
.39271 .68228 m .39196 .68382 L .39056 .68365 L F
.665 .249 .246 r
.39196 .68382 m .39422 .68596 L .39087 .68561 L F
.985 .73 .458 r
.39056 .68365 m .39196 .68382 L .39087 .68561 L F
.473 0 0 r
.39133 .59311 m .38971 .59246 L .38834 .59146 L F
.907 .983 .764 r
.39133 .59311 m .38877 .5965 L .38875 .59436 L F
.764 .44 .438 r
.27477 .57788 m .27414 .57993 L .2719 .57724 L F
.927 .827 .372 r
.27387 .57778 m .27477 .57788 L .2774 .57736 L F
.27387 .57778 m .27414 .57993 L .27477 .57788 L F
.406 .814 .979 r
.22354 .60296 m .22158 .6023 L .21919 .60276 L F
.542 .874 .991 r
.22419 .60147 m .22158 .6023 L .22354 .60296 L F
.217 .512 .912 r
.22354 .60296 m .22556 .60338 L .22419 .60147 L F
.542 .874 .991 r
.22419 .60147 m .22158 .6023 L .22354 .60296 L F
.092 0 .282 r
.33251 .53126 m .33179 .53232 L .33297 .53076 L F
.82 .997 .773 r
.33297 .53076 m .33203 .53048 L .33179 .53232 L F
.715 .965 .939 r
.33203 .53048 m .33037 .53183 L .33179 .53232 L F
.656 .604 .784 r
.33297 .53076 m .33179 .53232 L .3344 .53177 L F
.4 .275 .592 r
.33179 .53232 m .33407 .53483 L .3344 .53177 L F
.33179 .53232 m .33221 .53586 L .33407 .53483 L F
.94 .843 .405 r
.67891 .35924 m .67967 .36176 L .67865 .36275 L F
.807 .69 .736 r
.54385 .41668 m .54765 .41586 L .54701 .41325 L F
.746 .471 .514 r
.54804 .4196 m .54765 .41586 L .54385 .41668 L F
.755 .659 .756 r
.54701 .41325 m .54765 .41586 L .5498 .41327 L F
.687 .557 .701 r
.54765 .41586 m .55034 .4158 L .5498 .41327 L F
.807 .752 .801 r
.24256 .53084 m .24484 .5325 L .24274 .53089 L F
.958 .811 .655 r
.24223 .53402 m .24484 .5325 L .24256 .53084 L F
.24223 .53402 m .24367 .53523 L .24484 .5325 L F
.831 .745 .769 r
.24274 .53089 m .24484 .5325 L .24653 .52887 L F
.808 .728 .198 r
.69539 .33927 m .69481 .34358 L .69489 .34075 L F
.69539 .33927 m .69489 .34075 L .69506 .34029 L F
.69539 .33927 m .69506 .34029 L .69566 .33866 L F
.997 .838 .494 r
.69559 .33866 m .69539 .33927 L .69455 .33781 L F
.69676 .33961 m .69539 .33927 L .69559 .33866 L F
.69676 .33961 m .69623 .34259 L .69539 .33927 L F
.921 .595 .408 r
.38568 .60984 m .3857 .61252 L .3837 .61164 L F
.694 .923 .599 r
.38568 .60984 m .3837 .61164 L .38658 .60807 L F
.577 .772 .971 r
.71076 .28792 m .71224 .28519 L .70945 .28633 L F
.71076 .28792 m .7135 .28705 L .71224 .28519 L F
.71224 .28519 m .71076 .28792 L .70945 .28633 L F
.71224 .28519 m .7135 .28705 L .71076 .28792 L F
.976 .672 .317 r
.60148 .42572 m .59989 .4223 L .60007 .42426 L F
.902 .5 .231 r
.60007 .42426 m .60331 .42819 L .60148 .42572 L F
0 .274 .645 r
.35171 .4984 m .35092 .49804 L .34958 .49763 L F
.35171 .4984 m .3534 .49923 L .35092 .49804 L F
0 .278 .653 r
.35092 .49804 m .3534 .49923 L .35514 .50012 L F
.492 .282 .523 r
.31111 .54485 m .30842 .54872 L .30802 .54534 L F
.409 0 0 r
.30802 .54534 m .30901 .54682 L .31111 .54485 L F
.30802 .54534 m .30624 .54708 L .30901 .54682 L F
.382 .489 .843 r
.29833 .6292 m .30003 .63225 L .30176 .63032 L F
.318 .391 .78 r
.30003 .63225 m .3031 .63483 L .30176 .63032 L F
.575 .404 .612 r
.30017 .63523 m .3031 .63483 L .30003 .63225 L F
.273 .774 .752 r
.57464 .46322 m .57588 .46262 L .57342 .46379 L F
.57464 .46322 m .57773 .46225 L .57588 .46262 L F
.536 .339 .561 r
.35197 .53201 m .35185 .53537 L .34917 .53551 L F
.537 .529 .793 r
.35355 .52962 m .35197 .53201 L .35128 .5299 L F
.35355 .52962 m .35434 .53134 L .35197 .53201 L F
.511 .339 .584 r
.35434 .53134 m .35185 .53537 L .35197 .53201 L F
.477 0 0 r
.59584 .3591 m .59342 .36087 L .59194 .36016 L F
.508 .009 .007 r
.59781 .36044 m .59584 .3591 L .59865 .35774 L F
.59781 .36044 m .59342 .36087 L .59584 .3591 L F
.536 .172 .296 r
.53022 .40504 m .53384 .40226 L .53251 .4044 L F
.9 .821 .76 r
.74306 .31342 m .74393 .31698 L .74225 .31616 L F
.917 .542 .292 r
.74393 .31698 m .74278 .31831 L .74225 .31616 L F
0 0 .315 r
.74581 .31212 m .74393 .31698 L .74306 .31342 L F
.74581 .31212 m .74568 .31479 L .74393 .31698 L F
.568 .831 .473 r
.74568 .31479 m .74278 .31831 L .74393 .31698 L F
.615 .455 .642 r
.32805 .56198 m .33082 .55819 L .3293 .55924 L F
.788 .831 .886 r
.63849 .40087 m .63349 .4022 L .63604 .3988 L F
.996 .85 .508 r
.46274 .55724 m .46049 .55426 L .46214 .5583 L F
0 0 .22 r
.46214 .5583 m .46256 .55962 L .46274 .55724 L F
.46214 .5583 m .46213 .56114 L .46256 .55962 L F
.839 .674 .678 r
.70658 .27106 m .70795 .27489 L .7096 .27172 L F
.899 .829 .363 r
.33006 .6446 m .3307 .64202 L .3313 .64103 L F
.522 .363 .607 r
.2296 .5735 m .22714 .57713 L .22736 .57412 L F
.602 .409 .593 r
.51024 .47457 m .51037 .47739 L .50755 .47764 L F
.499 .259 .481 r
.51294 .47445 m .51037 .47739 L .51024 .47457 L F
.657 .517 .681 r
.60229 .37505 m .60594 .37525 L .605 .37158 L F
.345 0 0 r
.60508 .3756 m .60594 .37525 L .60229 .37505 L F
0 .529 .838 r
.60508 .3756 m .60229 .37505 L .60083 .37434 L F
.556 .787 .985 r
.35652 .70632 m .35638 .70275 L .35451 .70394 L F
.35652 .70632 m .35904 .70575 L .35638 .70275 L F
.401 0 0 r
.3534 .49923 m .3579 .50174 L .35514 .50012 L F
0 .044 .601 r
.58633 .38798 m .58808 .38994 L .58704 .38806 L F
.041 .463 .88 r
.26122 .62663 m .26296 .6264 L .25976 .62578 L F
.26122 .62663 m .26425 .62777 L .26296 .6264 L F
.182 0 .147 r
.37036 .58721 m .37333 .58392 L .3729 .58642 L F
.518 .22 .4 r
.3729 .58642 m .37333 .58392 L .37562 .58589 L F
.556 .208 .334 r
.37333 .58392 m .37641 .58385 L .37562 .58589 L F
.852 .975 .868 r
.65988 .33685 m .6617 .3372 L .6634 .33502 L F
.802 .807 .856 r
.51528 .42226 m .51524 .42592 L .51416 .42437 L F
.51528 .42226 m .51861 .42263 L .51524 .42592 L F
.94 .748 .616 r
.61034 .38863 m .61118 .38642 L .60915 .38549 L F
.61034 .38863 m .61118 .38642 L .60915 .38549 L F
.084 .321 .799 r
.61077 .38759 m .61034 .38863 L .61072 .38753 L F
.738 .944 .623 r
.61034 .38863 m .60963 .39039 L .61178 .38761 L F
.632 .072 0 r
.60915 .38549 m .61118 .38642 L .60842 .38397 L F
0 0 .427 r
.61097 .38556 m .61072 .38753 L .61094 .38537 L F
.084 .321 .799 r
.61297 .3902 m .61056 .38876 L .61077 .38759 L F
.332 .651 .969 r
.61297 .3902 m .61164 .39206 L .61034 .38863 L F
.084 .321 .799 r
.61297 .3902 m .61072 .38753 L .61169 .38993 L F
0 0 .427 r
.61169 .38993 m .61072 .38753 L .61097 .38556 L F
.084 .321 .799 r
.61056 .38876 m .61034 .38863 L .61068 .3878 L F
.61056 .38876 m .61068 .3878 L .61077 .38759 L F
.738 .944 .623 r
.61034 .38863 m .60923 .39089 L .60963 .39039 L F
.263 .444 .852 r
.61034 .38863 m .61164 .39206 L .60923 .39089 L F
.294 0 .277 r
.36425 .59486 m .36217 .59402 L .36562 .5935 L F
.36425 .59486 m .36156 .59618 L .36217 .59402 L F
.475 .317 .586 r
.34952 .56788 m .35216 .56719 L .35196 .56438 L F
.658 .57 .745 r
.67768 .3512 m .67832 .35267 L .67458 .35235 L F
.621 .249 .316 r
.67832 .35267 m .67816 .35309 L .67458 .35235 L F
.625 .477 .66 r
.67458 .35235 m .67816 .35309 L .67768 .3512 L F
.613 .522 .728 r
.37036 .58721 m .37079 .58986 L .36795 .59047 L F
.599 .108 .058 r
.23922 .59979 m .23438 .60021 L .23592 .60267 L F
.23922 .59979 m .23701 .60145 L .23438 .60021 L F
.957 .948 .693 r
.2398 .59541 m .23809 .59915 L .23922 .59979 L F
.98 .915 .623 r
.23809 .59915 m .23701 .60145 L .23922 .59979 L F
.42 .73 .99 r
.34397 .68963 m .34267 .69109 L .34151 .68945 L F
.34397 .68963 m .34614 .69153 L .34267 .69109 L F
.367 .771 .984 r
.27427 .61673 m .27371 .6178 L .27177 .61722 L F
.27427 .61673 m .27618 .61759 L .27371 .6178 L F
0 .149 .671 r
.40335 .53544 m .40315 .53455 L .40267 .53313 L F
.40335 .53544 m .40603 .53772 L .40315 .53455 L F
0 .104 .605 r
.40702 .53885 m .40603 .53772 L .40335 .53544 L F
0 0 .466 r
.32473 .63903 m .32626 .64009 L .32664 .63745 L F
.32473 .63903 m .32508 .64183 L .32626 .64009 L F
.029 .589 .808 r
.24861 .53832 m .25107 .53851 L .25299 .53896 L F
.25299 .53896 m .25107 .53851 L .24861 .53832 L F
.621 .929 .969 r
.25299 .53896 m .25107 .53851 L .25382 .5372 L F
.226 0 .102 r
.25382 .5372 m .25107 .53851 L .25299 .53896 L F
.029 .589 .808 r
.24861 .53832 m .25107 .53851 L .25299 .53896 L F
.466 .419 .721 r
.29005 .64792 m .29061 .65079 L .2934 .65025 L F
.477 .181 .383 r
.29061 .65079 m .29387 .6516 L .2934 .65025 L F
.29061 .65079 m .28962 .65405 L .29387 .6516 L F
.57 .677 .912 r
.36793 .54289 m .36362 .54127 L .36679 .54235 L F
.657 .886 .981 r
.36793 .54289 m .36679 .54235 L .37018 .54161 L F
.578 .34 .518 r
.52612 .46805 m .52853 .47027 L .52581 .47027 L F
.681 .309 .335 r
.52612 .46805 m .52853 .46845 L .52853 .47027 L F
.415 .172 .434 r
.35453 .52671 m .35355 .52962 L .35128 .5299 L F
.405 .084 .304 r
.35753 .59009 m .36002 .58958 L .36059 .58751 L F
.434 .253 .535 r
.36059 .58751 m .36318 .58679 L .36312 .5837 L F
.17 0 .214 r
.36059 .58751 m .36236 .58764 L .36318 .58679 L F
.36059 .58751 m .36002 .58958 L .36236 .58764 L F
.971 .679 .278 r
.39649 .55294 m .39753 .55166 L .39607 .55039 L F
.39649 .55294 m .39784 .55448 L .39753 .55166 L F
.36 0 0 r
.34096 .4959 m .34285 .49611 L .34052 .49526 L F
0 .464 .701 r
.34519 .49616 m .34052 .49526 L .34285 .49611 L F
.501 .883 .968 r
.34386 .63574 m .34769 .63539 L .34601 .6344 L F
.453 .343 .639 r
.33082 .55819 m .33397 .56244 L .33226 .55622 L F
.014 .279 .778 r
.34806 .63601 m .34601 .6344 L .34769 .63539 L F
.806 .949 .604 r
.39458 .66284 m .39429 .66438 L .39248 .66612 L F
0 0 .302 r
.39793 .55912 m .39763 .55857 L .3979 .55689 L F
.39793 .55912 m .3988 .56128 L .39763 .55857 L F
.581 .039 0 r
.39427 .54668 m .39477 .5467 L .39321 .54473 L F
.39427 .54668 m .39624 .54801 L .39477 .5467 L F
.781 .971 .918 r
.66475 .38684 m .66866 .3853 L .66755 .38421 L F
.725 .915 .959 r
.66866 .3853 m .66989 .38277 L .66755 .38421 L F
.66866 .3853 m .67101 .38387 L .66989 .38277 L F
.411 .861 .867 r
.64576 .3906 m .64241 .39141 L .64516 .39034 L F
0 0 0 r
.64767 .38907 m .64865 .38757 L .64576 .3906 L F
.522 .919 .876 r
.64767 .38907 m .64576 .3906 L .64516 .39034 L F
.734 .271 0 r
.35971 .50433 m .35945 .50303 L .3579 .50174 L F
.35971 .50433 m .36103 .50567 L .35945 .50303 L F
.819 .337 .018 r
.35945 .50303 m .36103 .50567 L .36307 .50663 L F
.71 .345 .355 r
.55363 .41543 m .5498 .41327 L .55034 .4158 L F
0 .375 .837 r
.26542 .6293 m .26608 .6284 L .26425 .62777 L F
.828 .638 .646 r
.44409 .57415 m .44443 .57523 L .4423 .57717 L F
.781 .574 .62 r
.4423 .57717 m .44525 .57662 L .44409 .57415 L F
0 0 .548 r
.44409 .57415 m .44585 .57633 L .44567 .57339 L F
.44409 .57415 m .44525 .57662 L .44585 .57633 L F
.703 .673 .818 r
.5698 .39889 m .56723 .3975 L .5694 .39696 L F
.697 .558 .693 r
.5694 .39696 m .57373 .39727 L .5698 .39889 L F
.597 .121 .095 r
.2567 .61835 m .25896 .61922 L .26065 .61838 L F
.177 0 0 r
.25896 .61922 m .26291 .61883 L .26065 .61838 L F
.484 .778 .996 r
.33766 .69762 m .33872 .69608 L .33644 .69583 L F
.33766 .69762 m .34026 .69733 L .33872 .69608 L F
.144 0 0 r
.44845 .59586 m .45241 .59338 L .44976 .59466 L F
0 0 0 r
.45483 .59263 m .44976 .59466 L .45241 .59338 L F
.462 .801 .999 r
.28797 .51917 m .28371 .51854 L .28555 .51972 L F
.933 .59 .155 r
.35461 .63885 m .35467 .64083 L .35436 .63866 L F
.538 .46 .715 r
.35671 .63479 m .35461 .63885 L .35436 .63866 L F
.35671 .63479 m .3574 .63799 L .35461 .63885 L F
0 0 .19 r
.35538 .63931 m .35461 .63885 L .3574 .63799 L F
.35538 .63931 m .35467 .64083 L .35461 .63885 L F
.943 .73 .26 r
.4128 .59022 m .41192 .59147 L .41259 .58879 L F
.4128 .59022 m .4122 .59221 L .41192 .59147 L F
.643 .839 .437 r
.41859 .5993 m .4181 .60033 L .42004 .59736 L F
0 0 0 r
.41859 .5993 m .42004 .59736 L .42174 .59558 L F
.732 .415 0 r
.39922 .6749 m .39936 .67476 L .39782 .67331 L F
.39922 .6749 m .39963 .67603 L .39936 .67476 L F
.584 .834 .992 r
.36972 .70748 m .37294 .70805 L .3721 .70848 L F
.796 .976 .906 r
.37294 .70805 m .37479 .70516 L .3721 .70848 L F
.842 .904 .88 r
.42847 .46816 m .42978 .4643 L .43096 .46481 L F
.42847 .46816 m .42696 .46697 L .42978 .4643 L F
.927 .548 .255 r
.38618 .52866 m .38867 .53177 L .38782 .53037 L F
.651 .605 .789 r
.4045 .47756 m .40493 .48386 L .40796 .48301 L F
.486 .163 .343 r
.40493 .48386 m .40446 .48618 L .40725 .4855 L F
.484 .164 .347 r
.40493 .48386 m .40725 .4855 L .40796 .48301 L F
.998 .818 .533 r
.3228 .55179 m .32125 .55325 L .32242 .55417 L F
.902 .851 .783 r
.24223 .53402 m .24362 .5373 L .24367 .53523 L F
.24223 .53402 m .24015 .53716 L .24362 .5373 L F
.63 .25 .305 r
.52853 .46845 m .53109 .47035 L .52853 .47027 L F
.69 .263 .23 r
.29374 .56249 m .29601 .56351 L .298 .56159 L F
.417 0 .021 r
.298 .56159 m .29972 .56271 L .30004 .56128 L F
.298 .56159 m .29601 .56351 L .29972 .56271 L F
.571 .26 .403 r
.49841 .48921 m .49589 .48772 L .49935 .4867 L F
.49841 .48921 m .49584 .4897 L .49589 .48772 L F
.513 .847 .997 r
.28538 .64776 m .29005 .64792 L .28822 .64684 L F
.949 .912 .746 r
.28822 .64684 m .29005 .64792 L .29042 .64551 L F
0 0 0 r
.66383 .31815 m .6651 .31735 L .66633 .31643 L F
.66383 .31815 m .66275 .31889 L .6651 .31735 L F
.474 0 0 r
.36464 .62812 m .36837 .62859 L .3655 .62758 L F
.662 .347 .429 r
.25343 .57446 m .253 .57691 L .25031 .57633 L F
.557 .552 .804 r
.25628 .57333 m .25343 .57446 L .25245 .57154 L F
.515 .284 .502 r
.25628 .57333 m .253 .57691 L .25343 .57446 L F
.492 .282 .523 r
.31111 .54485 m .31073 .54824 L .30842 .54872 L F
.748 .509 .57 r
.31477 .54822 m .31073 .54824 L .31111 .54485 L F
.554 .184 .293 r
.30901 .54682 m .3126 .54404 L .31111 .54485 L F
.91 .513 .118 r
.40966 .54793 m .4072 .54406 L .40828 .54536 L F
.633 .377 .513 r
.34114 .54961 m .34378 .54746 L .34277 .54888 L F
.725 .971 .721 r
.63415 .35686 m .63271 .35916 L .63569 .35599 L F
.725 .969 .716 r
.63109 .35998 m .63271 .35916 L .63415 .35686 L F
.996 .814 .541 r
.43805 .52108 m .43958 .52247 L .43987 .51966 L F
.691 .962 .943 r
.44064 .51781 m .43987 .51966 L .44231 .51824 L F
.648 .501 .669 r
.44064 .51781 m .43805 .52108 L .43987 .51966 L F
.62 .335 .463 r
.27838 .5687 m .27622 .57105 L .27912 .56945 L F
.632 .072 0 r
.60915 .38549 m .60842 .38397 L .60729 .38264 L F
.952 .631 .212 r
.40994 .55432 m .41152 .55809 L .41032 .55677 L F
.918 .586 .119 r
.41191 .56064 m .41032 .55677 L .41152 .55809 L F
.696 .175 0 r
.36562 .5935 m .36623 .59504 L .36425 .59486 L F
.36562 .5935 m .36787 .59611 L .36623 .59504 L F
.18 .088 .508 r
.21289 .577 m .21482 .57271 L .21331 .57419 L F
.671 .969 .92 r
.60096 .35244 m .59669 .35386 L .59925 .35235 L F
.601 .945 .789 r
.60326 .35072 m .60096 .35244 L .6025 .35077 L F
.603 .95 .903 r
.6025 .35077 m .60096 .35244 L .59925 .35235 L F
.403 .129 .379 r
.28704 .6355 m .28916 .63718 L .28665 .63779 L F
.692 .951 .954 r
.35062 .65194 m .35431 .651 L .35293 .65071 L F
.783 .997 .798 r
.35431 .651 m .35485 .6491 L .35293 .65071 L F
.35431 .651 m .3571 .64824 L .35485 .6491 L F
0 0 0 r
.43096 .46481 m .43204 .46043 L .43412 .46235 L F
.43096 .46481 m .43171 .46262 L .43204 .46043 L F
.746 .975 .923 r
.43096 .46481 m .42978 .4643 L .43171 .46262 L F
.753 .828 .91 r
.62548 .40631 m .62916 .40661 L .62675 .40792 L F
.405 .412 .754 r
.43251 .53551 m .43369 .53064 L .43196 .53203 L F
.43251 .53551 m .43506 .53504 L .43369 .53064 L F
.056 0 .164 r
.43261 .5376 m .43506 .53504 L .43251 .53551 L F
.718 .61 .735 r
.42271 .53543 m .42685 .53604 L .42539 .53209 L F
.937 .957 .652 r
.42514 .53727 m .42685 .53604 L .42271 .53543 L F
.981 .693 .388 r
.40702 .53885 m .40561 .54022 L .40603 .53772 L F
.40702 .53885 m .40713 .54145 L .40561 .54022 L F
.706 .92 .966 r
.67671 .38096 m .67784 .38195 L .68017 .38051 L F
.35 .081 .358 r
.38231 .54836 m .38186 .55092 L .37945 .5516 L F
.351 .082 .359 r
.38454 .54779 m .38186 .55092 L .38231 .54836 L F
.212 0 .29 r
.35494 .60445 m .35337 .6023 L .3563 .60024 L F
0 0 .016 r
.35916 .59798 m .3563 .60024 L .35593 .59938 L F
.35916 .59798 m .35738 .60124 L .3563 .60024 L F
.075 0 .108 r
.3567 .6036 m .3563 .60024 L .35738 .60124 L F
.3567 .6036 m .35494 .60445 L .3563 .60024 L F
.888 .812 .768 r
.63508 .41911 m .63901 .4169 L .63777 .41585 L F
.63508 .41911 m .63806 .4189 L .63901 .4169 L F
.905 .825 .757 r
.63901 .4169 m .63927 .41218 L .63777 .41585 L F
.796 .968 .662 r
.24984 .60588 m .24685 .60843 L .24667 .60936 L F
.237 .34 .767 r
.24909 .60308 m .25174 .60502 L .24984 .60588 L F
0 0 0 r
.25174 .60502 m .24685 .60843 L .24984 .60588 L F
.198 0 0 r
.55155 .41656 m .55363 .41543 L .55034 .4158 L F
.327 0 0 r
.34528 .56374 m .34367 .56335 L .34151 .56253 L F
.504 .89 .959 r
.34775 .56276 m .34367 .56335 L .34528 .56374 L F
.766 .64 .722 r
.70406 .27403 m .70658 .27106 L .7039 .27197 L F
.499 .468 .754 r
.21921 .60005 m .2207 .59557 L .21811 .59609 L F
.21921 .60005 m .22112 .59951 L .2207 .59557 L F
.499 .345 .602 r
.21919 .60276 m .22112 .59951 L .21921 .60005 L F
.452 .386 .693 r
.605 .37158 m .60785 .37515 L .60636 .36858 L F
.605 .37158 m .60594 .37525 L .60785 .37515 L F
.664 .605 .779 r
.36304 .51746 m .36146 .51879 L .36222 .5162 L F
.831 .745 .769 r
.24274 .53089 m .24653 .52887 L .2449 .52776 L F
.698 .859 .959 r
.2449 .52776 m .24653 .52887 L .2482 .52684 L F
.447 .738 .99 r
.32765 .52158 m .32897 .52269 L .32637 .52276 L F
.32765 .52158 m .32897 .52269 L .32637 .52276 L F
.888 .976 .826 r
.33814 .57973 m .33902 .58066 L .34159 .5774 L F
.601 .111 .063 r
.3373 .58225 m .33902 .58066 L .33814 .57973 L F
.3373 .58225 m .34116 .58225 L .33902 .58066 L F
.614 .463 .653 r
.33902 .58066 m .34215 .58084 L .34159 .5774 L F
.556 .171 .267 r
.33902 .58066 m .34116 .58225 L .34215 .58084 L F
0 0 0 r
.65041 .38584 m .65145 .38449 L .64865 .38757 L F
.65041 .38584 m .64865 .38757 L .64767 .38907 L F
.542 .374 .603 r
.3231 .66574 m .32497 .66298 L .32395 .6634 L F
.571 .483 .717 r
.47366 .50943 m .47143 .51279 L .47105 .51013 L F
.47366 .50943 m .47452 .5123 L .47143 .51279 L F
.53 .318 .536 r
.47143 .51279 m .47426 .51499 L .47166 .51552 L F
.47143 .51279 m .47452 .5123 L .47426 .51499 L F
.984 .89 .553 r
.41248 .57889 m .41338 .5808 L .41249 .58346 L F
.553 0 0 r
.34285 .49611 m .3469 .49688 L .34519 .49616 L F
.876 .445 .048 r
.60443 .4351 m .60681 .43836 L .60652 .43572 L F
.797 .935 .572 r
.33758 .56619 m .33708 .56615 L .33874 .56446 L F
.691 .904 .551 r
.33874 .56446 m .33953 .56285 L .34151 .56253 L F
.139 0 .186 r
.33975 .56468 m .33874 .56446 L .34151 .56253 L F
.33975 .56468 m .33758 .56619 L .33874 .56446 L F
.16 0 0 r
.46437 .58733 m .4628 .58937 L .46067 .59006 L F
.515 .068 .127 r
.46648 .58872 m .4628 .58937 L .46437 .58733 L F
.483 .103 .242 r
.46734 .5871 m .46648 .58872 L .46437 .58733 L F
0 0 .116 r
.31007 .63247 m .31197 .62844 L .31168 .6311 L F
.379 .255 .583 r
.31244 .63472 m .31007 .63247 L .31168 .6311 L F
.31244 .63472 m .31018 .63546 L .31007 .63247 L F
.722 .538 0 r
.40234 .5291 m .40238 .53016 L .40101 .52786 L F
.40234 .5291 m .40254 .53169 L .40238 .53016 L F
.701 .858 .957 r
.68004 .35068 m .68118 .35218 L .67832 .35267 L F
.577 .801 .984 r
.68004 .35068 m .68388 .3514 L .68118 .35218 L F
.955 .661 .224 r
.41318 .56442 m .41193 .56346 L .41191 .56064 L F
.973 .715 .48 r
.41318 .56442 m .41122 .56594 L .41193 .56346 L F
.41318 .56442 m .41294 .56711 L .41122 .56594 L F
.316 .806 .83 r
.28114 .51551 m .28237 .5149 L .28313 .51533 L F
.112 .651 .851 r
.28313 .51533 m .28237 .5149 L .28666 .51536 L F
.802 .576 .595 r
.24827 .57346 m .24652 .57387 L .24923 .57306 L F
.787 .741 .81 r
.34294 .61333 m .34116 .61928 L .33917 .61833 L F
.34294 .61333 m .34451 .61657 L .34116 .61928 L F
.572 .307 .477 r
.34116 .61928 m .34051 .62163 L .33917 .61833 L F
.34116 .61928 m .34332 .62156 L .34051 .62163 L F
.829 .997 .767 r
.67432 .30989 m .67423 .30893 L .67686 .30584 L F
.756 .993 .872 r
.37607 .68693 m .37917 .68465 L .37658 .68547 L F
.821 .829 .855 r
.37917 .68465 m .37758 .68298 L .37658 .68547 L F
.37917 .68465 m .38143 .68278 L .37758 .68298 L F
.435 .515 .841 r
.26798 .57635 m .26819 .5751 L .26732 .57439 L F
.26798 .57635 m .2702 .57661 L .26852 .57325 L F
.721 .19 0 r
.26974 .57636 m .26839 .57678 L .26702 .57485 L F
.2702 .57661 m .27007 .57663 L .26974 .57636 L F
.27007 .57663 m .26839 .57678 L .26974 .57636 L F
.435 .515 .841 r
.26732 .57439 m .26852 .57325 L .26704 .57354 L F
.26819 .5751 m .26852 .57325 L .26732 .57439 L F
.753 .727 .828 r
.34586 .61541 m .34451 .61657 L .34294 .61333 L F
.867 .93 .864 r
.56824 .38804 m .56446 .38971 L .56706 .38733 L F
.485 .751 .988 r
.5695 .38603 m .56824 .38804 L .56706 .38733 L F
.5695 .38603 m .57077 .38758 L .56824 .38804 L F
0 .477 .841 r
.23557 .61211 m .23561 .61153 L .23407 .61084 L F
.246 0 0 r
.23785 .61271 m .23737 .61264 L .23557 .61211 L F
0 .477 .841 r
.23557 .61211 m .23737 .61264 L .23561 .61153 L F
.097 0 0 r
.39503 .65519 m .3894 .6578 L .39376 .65367 L F
.569 .001 0 r
.39398 .65597 m .39503 .65519 L .39376 .65367 L F
.39398 .65597 m .39775 .65685 L .39503 .65519 L F
0 .03 .596 r
.33072 .50055 m .3317 .50209 L .33206 .50054 L F
.33072 .50055 m .33206 .50054 L .33062 .50074 L F
.823 .823 .849 r
.37758 .68298 m .38143 .68278 L .3798 .68113 L F
.432 .553 .877 r
.33975 .50726 m .34332 .50866 L .34167 .50583 L F
.801 .83 .873 r
.36816 .68091 m .36742 .68304 L .36685 .68064 L F
0 .271 .764 r
.23389 .54469 m .23671 .54761 L .23419 .54583 L F
.602 .158 .168 r
.3961 .68061 m .40063 .68033 L .39925 .68306 L F
.3961 .68061 m .3987 .68212 L .40063 .68033 L F
.996 .867 .559 r
.40063 .68033 m .39963 .67603 L .39911 .67615 L F
.584 .621 .855 r
.3961 .68061 m .39944 .68029 L .39803 .67629 L F
.991 .854 .606 r
.40063 .68033 m .39989 .67916 L .39961 .68128 L F
.39989 .67916 m .399 .67774 L .39944 .68029 L F
.39989 .67916 m .39944 .68029 L .39961 .68128 L F
.538 .277 .468 r
.3987 .68212 m .39944 .68029 L .3961 .68061 L F
.584 .621 .855 r
.39944 .68029 m .39903 .67791 L .39803 .67629 L F
.991 .854 .606 r
.39915 .68171 m .399 .67774 L .3987 .68212 L F
.39961 .68128 m .39903 .67791 L .39915 .68171 L F
.39903 .67791 m .399 .67774 L .39915 .68171 L F
.779 .688 .763 r
.40043 .6802 m .39911 .67615 L .39963 .67603 L F
.40043 .6802 m .39922 .6749 L .39895 .67522 L F
.39903 .67791 m .39895 .67522 L .39803 .67629 L F
.991 .854 .606 r
.40063 .68033 m .39911 .67615 L .399 .67774 L F
.779 .688 .763 r
.40043 .6802 m .39902 .6775 L .39903 .67791 L F
.538 .277 .468 r
.3987 .68212 m .40043 .6802 L .39944 .68029 L F
.584 .621 .855 r
.39944 .68029 m .40043 .6802 L .39903 .67791 L F
.835 .716 .733 r
.3987 .68212 m .39902 .6775 L .40043 .6802 L F
.39902 .6775 m .39911 .67615 L .40043 .6802 L F
.779 .688 .763 r
.40043 .6802 m .39895 .67522 L .39902 .6775 L F
.843 .999 .794 r
.33251 .53126 m .33307 .52905 L .33297 .53076 L F
.33251 .53126 m .3321 .53058 L .33307 .52905 L F
.677 .282 .291 r
.24284 .52578 m .2449 .52776 L .24498 .52608 L F
.24284 .52578 m .24271 .52802 L .2449 .52776 L F
.24271 .52802 m .24294 .52829 L .2449 .52776 L F
.849 .868 .855 r
.24269 .52836 m .24274 .53089 L .2449 .52776 L F
.172 .209 .659 r
.24387 .5272 m .24565 .52883 L .24425 .52981 L F
.24342 .52885 m .24425 .52981 L .2429 .53076 L F
.24387 .5272 m .24425 .52981 L .24342 .52885 L F
.677 .282 .291 r
.24271 .52802 m .24269 .52836 L .24294 .52829 L F
.378 0 0 r
.54571 .4707 m .54959 .47114 L .54882 .47178 L F
0 0 0 r
.54882 .47178 m .54959 .47114 L .55207 .46997 L F
.803 .311 0 r
.36319 .50892 m .36307 .50663 L .36103 .50567 L F
.36319 .50892 m .3651 .50954 L .36307 .50663 L F
.801 .308 0 r
.36307 .50663 m .3651 .50954 L .3668 .51015 L F
.999 .825 .495 r
.70264 .28897 m .70394 .28864 L .70302 .28652 L F
.70264 .28897 m .70394 .28864 L .70302 .28652 L F
.48 .42 .712 r
.23172 .58258 m .23535 .58318 L .23332 .57936 L F
.23172 .58258 m .23226 .58375 L .23535 .58318 L F
.766 .709 .173 r
.69575 .36586 m .69611 .36466 L .69622 .36358 L F
.69575 .36586 m .6955 .36864 L .69611 .36466 L F
.58 .29 .44 r
.50755 .47764 m .51016 .4797 L .5074 .47987 L F
.57 .294 .458 r
.50755 .47764 m .51037 .47739 L .51016 .4797 L F
.215 .041 .417 r
.21472 .56455 m .21636 .56371 L .21666 .56108 L F
.018 0 .37 r
.21472 .56455 m .21619 .56569 L .21636 .56371 L F
.21472 .56455 m .21449 .56728 L .21619 .56569 L F
.754 .383 .351 r
.28297 .54162 m .27912 .53917 L .28254 .53854 L F
.28297 .54162 m .27884 .54118 L .27912 .53917 L F
.578 .021 0 r
.3651 .50954 m .36953 .51273 L .3668 .51015 L F
.732 .322 .271 r
.3668 .51015 m .36953 .51273 L .37172 .51225 L F
0 0 .128 r
.72585 .31517 m .72583 .31765 L .72529 .31932 L F
0 .249 .758 r
.72583 .31765 m .72767 .32125 L .72529 .31932 L F
.75 .987 .898 r
.3301 .62473 m .32931 .62653 L .32939 .62436 L F
.32931 .62653 m .3301 .62473 L .32819 .62781 L F
.874 .897 .845 r
.52189 .41719 m .51788 .41902 L .52018 .41594 L F
.036 .153 .657 r
.45636 .56756 m .45743 .5709 L .45869 .56957 L F
.45743 .5709 m .45743 .5709 L .45869 .56957 L F
.538 .919 .928 r
.45869 .56957 m .45743 .5709 L .45622 .57068 L F
0 0 0 r
.45869 .56957 m .45706 .57056 L .45722 .57099 L F
.45706 .57056 m .45506 .57178 L .45722 .57099 L F
0 0 .006 r
.45739 .57144 m .45722 .57099 L .45685 .57359 L F
0 0 0 r
.45869 .56957 m .45622 .57068 L .45506 .57178 L F
.036 .153 .657 r
.45636 .56756 m .45869 .56957 L .45902 .56692 L F
0 0 .127 r
.45902 .56692 m .45869 .56957 L .46028 .56794 L F
.75 .964 .675 r
.45722 .57099 m .45978 .56789 L .46028 .56794 L F
0 0 .006 r
.45785 .56958 m .45722 .57099 L .45739 .57144 L F
.75 .964 .675 r
.45722 .57099 m .45939 .56882 L .45869 .56957 L F
.45939 .56882 m .46028 .56794 L .45869 .56957 L F
.978 .687 .314 r
.59579 .41796 m .59699 .41672 L .59539 .41577 L F
.59579 .41796 m .59724 .41961 L .59699 .41672 L F
0 0 .566 r
.22622 .5822 m .22571 .58384 L .22459 .58012 L F
0 0 .166 r
.22647 .58441 m .22571 .58384 L .22622 .5822 L F
.22647 .58441 m .22532 .58712 L .22571 .58384 L F
.977 .725 .485 r
.37641 .58385 m .37759 .5876 L .37562 .58589 L F
.642 .817 .967 r
.37562 .58589 m .37759 .5876 L .3798 .58655 L F
0 0 .16 r
.34985 .60627 m .34899 .61012 L .34884 .60966 L F
.439 .202 .456 r
.34899 .61012 m .34783 .61269 L .34884 .60966 L F
.19 0 0 r
.31375 .56119 m .31038 .56302 L .31145 .56178 L F
.837 .899 .883 r
.36787 .59611 m .37277 .59411 L .37158 .5936 L F
.962 .668 .429 r
.37079 .58986 m .37158 .5936 L .37277 .59411 L F
.895 .889 .466 r
.53262 .39388 m .53147 .39544 L .53239 .39347 L F
.646 .967 .887 r
.53262 .39388 m .53239 .39347 L .53407 .39206 L F
0 0 0 r
.53407 .39206 m .53147 .39544 L .53262 .39388 L F
.604 .435 .626 r
.36673 .53854 m .36679 .54235 L .36362 .54127 L F
.279 .268 .668 r
.36845 .6313 m .36499 .63388 L .36439 .63308 L F
.36845 .6313 m .3712 .63119 L .36499 .63388 L F
.865 .514 .009 r
.39698 .51935 m .39671 .5207 L .39514 .51785 L F
.755 .884 .937 r
.64572 .34533 m .649 .34513 L .64803 .34388 L F
.664 .872 .977 r
.65034 .34241 m .649 .34513 L .65205 .34234 L F
.65034 .34241 m .64803 .34388 L .649 .34513 L F
.547 .349 .564 r
.43666 .49056 m .4366 .49323 L .43964 .49068 L F
.43666 .49056 m .4366 .49323 L .43964 .49068 L F
.714 .669 .805 r
.34094 .6808 m .34175 .68374 L .33784 .68347 L F
.828 .669 .686 r
.33786 .68529 m .34175 .68374 L .33784 .68347 L F
.33887 .68488 m .34156 .6867 L .34175 .68374 L F
.33786 .68529 m .33915 .68578 L .33887 .68488 L F
.33915 .68578 m .34156 .6867 L .33887 .68488 L F
.849 .564 .506 r
.34151 .68945 m .34156 .6867 L .33786 .68529 L F
.698 .363 .406 r
.33784 .68347 m .34175 .68374 L .34071 .68725 L F
.062 .188 .684 r
.33831 .68312 m .34071 .68725 L .33901 .68259 L F
.33784 .68347 m .33884 .68478 L .33831 .68312 L F
.33884 .68478 m .34071 .68725 L .33831 .68312 L F
.832 .552 .513 r
.34094 .6808 m .34297 .68233 L .34175 .68374 L F
.404 0 0 r
.34121 .68227 m .34464 .6802 L .34094 .6808 L F
.888 .99 .755 r
.34414 .67856 m .34442 .67948 L .34121 .68227 L F
.34442 .67948 m .34464 .6802 L .34379 .68071 L F
.34442 .67948 m .34379 .68071 L .34121 .68227 L F
.832 .552 .513 r
.34297 .68233 m .34438 .68339 L .34228 .68367 L F
.34297 .68233 m .34228 .68367 L .34175 .68374 L F
.349 0 0 r
.34175 .68374 m .34245 .68517 L .34071 .68725 L F
.34175 .68374 m .34438 .68339 L .34245 .68517 L F
.32 .783 .942 r
.28164 .51993 m .27653 .51984 L .27877 .52062 L F
.932 .59 .36 r
.28622 .65708 m .28838 .65821 L .28677 .65989 L F
.682 .215 .135 r
.28838 .65821 m .29076 .6604 L .28677 .65989 L F
.532 .493 .758 r
.62673 .39252 m .63017 .39367 L .63015 .39377 L F
.582 .609 .844 r
.27884 .54118 m .27751 .5433 L .27559 .54237 L F
.757 .302 .171 r
.27559 .54237 m .27753 .54338 L .27884 .54118 L F
.582 .609 .844 r
.27884 .54118 m .28048 .5449 L .27751 .5433 L F
.757 .302 .171 r
.27753 .54338 m .27893 .5441 L .27887 .54234 L F
.27753 .54338 m .27887 .54234 L .27884 .54118 L F
.65 .397 .524 r
.2761 .54449 m .27365 .54704 L .27444 .54589 L F
.27751 .5433 m .27699 .5438 L .2761 .54449 L F
.27699 .5438 m .27365 .54704 L .2761 .54449 L F
.771 .847 .909 r
.36548 .70845 m .36686 .71014 L .36972 .70748 L F
.221 0 0 r
.25471 .62141 m .25198 .62117 L .24956 .62073 L F
.133 0 0 r
.25471 .62141 m .25616 .62163 L .25198 .62117 L F
.841 .882 .871 r
.49157 .48361 m .49478 .481 L .49448 .48062 L F
.634 .869 .986 r
.37452 .50058 m .3757 .49799 L .37929 .49897 L F
.37452 .50058 m .37256 .4995 L .3757 .49799 L F
.734 .256 0 r
.37452 .50058 m .37366 .50027 L .37256 .4995 L F
.325 0 .084 r
.59954 .45552 m .59837 .45758 L .59632 .45783 L F
.489 .068 .167 r
.60271 .45656 m .59837 .45758 L .59954 .45552 L F
.485 .9 .832 r
.34391 .54362 m .34257 .54379 L .34109 .54498 L F
0 0 0 r
.34146 .54587 m .34109 .54498 L .34257 .54379 L F
.34146 .54587 m .3404 .54724 L .34109 .54498 L F
.785 .472 .459 r
.54482 .40869 m .54876 .40736 L .54757 .41057 L F
.827 .987 .718 r
.54976 .40456 m .54876 .40736 L .55166 .40361 L F
.674 .747 .251 r
.54757 .41057 m .54876 .40736 L .54976 .40456 L F
.663 .967 .785 r
.28351 .57594 m .28731 .5736 L .2849 .57552 L F
.042 0 .119 r
.28731 .5736 m .28984 .57083 L .28984 .57295 L F
0 0 0 r
.28755 .57438 m .28731 .5736 L .28984 .57295 L F
.28755 .57438 m .2849 .57552 L .28731 .5736 L F
.756 .993 .872 r
.37607 .68693 m .37658 .68547 L .37452 .68635 L F
.934 .752 .632 r
.37452 .68635 m .37596 .69021 L .37607 .68693 L F
.445 .201 .448 r
.35651 .52848 m .35453 .52671 L .35708 .52541 L F
.35651 .52848 m .35355 .52962 L .35453 .52671 L F
.849 .695 .69 r
.29074 .51319 m .28666 .51536 L .28836 .51383 L F
.29074 .51319 m .28691 .51788 L .28666 .51536 L F
.443 .875 .793 r
.29074 .51319 m .29084 .51246 L .2929 .51205 L F
.454 0 0 r
.29084 .51246 m .29446 .51206 L .2929 .51205 L F
.29084 .51246 m .29379 .51289 L .29446 .51206 L F
.881 .989 .809 r
.29517 .51231 m .29446 .51206 L .29379 .51289 L F
.178 0 0 r
.29176 .51209 m .29517 .51231 L .29379 .51289 L F
.676 .478 .61 r
.29176 .51209 m .29344 .51308 L .29517 .51231 L F
.178 0 0 r
.295 .5123 m .2946 .51242 L .29517 .51231 L F
.29176 .51209 m .29391 .51234 L .295 .5123 L F
.29391 .51234 m .2946 .51242 L .295 .5123 L F
.443 .875 .793 r
.29074 .51319 m .28883 .5137 L .29084 .51246 L F
.28883 .5137 m .28935 .51328 L .29084 .51246 L F
.328 0 0 r
.28688 .51273 m .29084 .51246 L .28836 .51383 L F
.28688 .51273 m .29184 .51277 L .29084 .51246 L F
.044 .349 .825 r
.29141 .51254 m .29176 .51209 L .29379 .51289 L F
.29084 .51246 m .29176 .51209 L .29141 .51254 L F
.676 .478 .61 r
.29176 .51209 m .29517 .51231 L .2946 .51242 L F
.178 0 0 r
.29176 .51209 m .2946 .51242 L .29517 .51231 L F
.223 .651 .955 r
.29186 .51189 m .29293 .51009 L .2946 .51242 L F
.29125 .51091 m .29293 .51009 L .29107 .51173 L F
0 0 .128 r
.2912 .51109 m .29293 .51009 L .29125 .51091 L F
.223 .651 .955 r
.28999 .51152 m .29125 .51091 L .29107 .51173 L F
0 0 .128 r
.2912 .51109 m .29125 .51091 L .28999 .51152 L F
.223 .651 .955 r
.29107 .51173 m .29293 .51009 L .29186 .51189 L F
.28999 .51152 m .2946 .51242 L .29176 .51209 L F
.773 .991 .885 r
.29293 .51009 m .29176 .51209 L .2946 .51242 L F
.29293 .51009 m .29263 .51094 L .29258 .51101 L F
.29256 .51072 m .29258 .51101 L .29176 .51209 L F
.29293 .51009 m .29258 .51101 L .29256 .51072 L F
.044 .349 .825 r
.29084 .51246 m .29184 .51277 L .29176 .51209 L F
.568 .815 .991 r
.29176 .51209 m .29184 .51277 L .28746 .51147 L F
.676 .478 .61 r
.29176 .51209 m .29143 .51438 L .29344 .51308 L F
.773 .991 .885 r
.29263 .51094 m .29229 .51193 L .29176 .51209 L F
.29229 .51193 m .29143 .51438 L .29164 .51292 L F
.29229 .51193 m .29164 .51292 L .29176 .51209 L F
.29229 .51193 m .29117 .51246 L .29212 .51242 L F
.29293 .51009 m .29224 .51102 L .29229 .51193 L F
0 .21 .735 r
.29285 .51107 m .2926 .51145 L .2912 .51109 L F
.773 .991 .885 r
.29226 .51136 m .29117 .51246 L .29229 .51193 L F
.29212 .51242 m .28988 .51421 L .29143 .51438 L F
.29117 .51246 m .28988 .51421 L .29212 .51242 L F
.317 .733 .976 r
.29048 .51237 m .29184 .51277 L .29001 .51275 L F
.568 .815 .991 r
.29176 .51209 m .28746 .51147 L .28999 .51152 L F
0 0 .128 r
.2912 .51109 m .28988 .51421 L .29153 .51198 L F
0 .21 .735 r
.29224 .51102 m .29285 .51107 L .29224 .51108 L F
0 0 .128 r
.2912 .51109 m .29224 .51102 L .29293 .51009 L F
0 .21 .735 r
.29219 .51013 m .29279 .51099 L .29224 .51102 L F
.29279 .51099 m .29285 .51107 L .29224 .51102 L F
.064 0 .049 r
.29226 .51136 m .29079 .5126 L .2912 .51109 L F
0 0 .128 r
.2912 .51109 m .29153 .51198 L .29224 .51102 L F
.064 0 .049 r
.29158 .5121 m .2903 .51444 L .29079 .5126 L F
.2926 .51145 m .29175 .51255 L .29158 .5121 L F
.29175 .51255 m .2903 .51444 L .29158 .5121 L F
.773 .991 .885 r
.29153 .51198 m .29117 .51246 L .29226 .51136 L F
.064 0 .049 r
.2926 .51145 m .29079 .5126 L .29226 .51136 L F
.773 .991 .885 r
.29224 .51102 m .29153 .51198 L .29226 .51136 L F
0 .21 .735 r
.2916 .5093 m .29219 .51013 L .2912 .51109 L F
.29219 .51013 m .29224 .51108 L .2912 .51109 L F
.29285 .51107 m .29324 .51162 L .2926 .51145 L F
.064 0 .049 r
.29324 .51162 m .29264 .51219 L .2926 .51145 L F
.29264 .51219 m .2903 .51444 L .2926 .51145 L F
0 0 .128 r
.2912 .51109 m .28999 .51152 L .28952 .51167 L F
0 0 .092 r
.28746 .51147 m .28791 .51219 L .28999 .51152 L F
0 0 .128 r
.29091 .51119 m .28952 .51167 L .28791 .51219 L F
.2912 .51109 m .28952 .51167 L .29091 .51119 L F
.317 .733 .976 r
.28696 .51256 m .29048 .51237 L .28688 .51273 L F
.28888 .51189 m .29048 .51237 L .28696 .51256 L F
.29048 .51237 m .29001 .51275 L .28688 .51273 L F
.658 .23 .219 r
.2912 .51109 m .28791 .51219 L .28988 .51421 L F
.2912 .51109 m .2903 .51444 L .28791 .51219 L F
0 0 .128 r
.2912 .51109 m .28791 .51219 L .29114 .51122 L F
.739 .633 .741 r
.29121 .51082 m .2903 .51444 L .29324 .51162 L F
.317 .733 .976 r
.28746 .51147 m .28888 .51189 L .28696 .51256 L F
.28746 .51147 m .28688 .51273 L .28517 .51219 L F
.674 .799 .942 r
.28836 .51383 m .28666 .51536 L .28464 .51373 L F
.28836 .51383 m .28464 .51373 L .28688 .51273 L F
.576 .918 .966 r
.28464 .51373 m .28517 .51219 L .28688 .51273 L F
.514 .243 .442 r
.28517 .51219 m .28724 .5146 L .28746 .51147 L F
0 0 .092 r
.28746 .51147 m .28724 .5146 L .28791 .51219 L F
.684 .837 .957 r
.29114 .51122 m .28791 .51219 L .28618 .51081 L F
.29114 .51122 m .28618 .51081 L .28855 .50978 L F
.739 .633 .741 r
.28855 .50978 m .29028 .51439 L .29121 .51082 L F
.29028 .51439 m .2903 .51444 L .29121 .51082 L F
.28855 .50978 m .29121 .51082 L .29057 .51146 L F
0 .21 .735 r
.29132 .51047 m .2912 .51109 L .29114 .51122 L F
.739 .633 .741 r
.29121 .51082 m .29324 .51162 L .29101 .51148 L F
.29121 .51082 m .29101 .51148 L .29057 .51146 L F
0 .21 .735 r
.29155 .5095 m .29139 .51022 L .29132 .51047 L F
.29139 .51022 m .2912 .51109 L .29132 .51047 L F
.2916 .50931 m .29158 .5094 L .29155 .5095 L F
.29158 .5094 m .2912 .51109 L .29155 .5095 L F
.2916 .5093 m .29159 .50936 L .2916 .50931 L F
.29159 .50936 m .2912 .51109 L .2916 .50931 L F
.443 .875 .793 r
.28883 .5137 m .28836 .51383 L .28935 .51328 L F
.921 .871 .771 r
.63317 .39888 m .63604 .3988 L .63349 .4022 L F
0 0 0 r
.35485 .6491 m .3571 .64824 L .3584 .64777 L F
.567 .433 .657 r
.4733 .50672 m .47366 .50943 L .47105 .51013 L F
0 0 0 r
.3959 .47812 m .39556 .47946 L .39558 .47669 L F
.75 .907 .526 r
.39528 .48054 m .39556 .47946 L .39689 .47787 L F
0 0 0 r
.39617 .47931 m .39556 .47946 L .3959 .47812 L F
.75 .907 .526 r
.395 .48102 m .39556 .47946 L .39528 .48054 L F
.033 .253 .753 r
.395 .48102 m .3967 .48248 L .39556 .47946 L F
.523 .293 .507 r
.395 .48102 m .39468 .48309 L .3967 .48248 L F
.717 .803 .918 r
.49296 .43997 m .48906 .4398 L .4912 .43818 L F
.792 .818 .872 r
.4949 .43824 m .49296 .43997 L .4912 .43818 L F
.568 .37 .573 r
.48031 .49351 m .48048 .49598 L .47777 .49652 L F
.675 .536 .688 r
.48205 .49198 m .48561 .49439 L .48031 .49351 L F
.55 .558 .815 r
.48722 .49266 m .48561 .49439 L .48205 .49198 L F
.551 .7 .938 r
.48031 .49351 m .48561 .49439 L .48457 .49326 L F
.48031 .49351 m .48457 .49326 L .48048 .49598 L F
.75 .497 .548 r
.35555 .54062 m .35925 .5385 L .35644 .53841 L F
.755 .865 .929 r
.47423 .44853 m .4705 .44869 L .47261 .44712 L F
.715 .812 .925 r
.47541 .4451 m .47423 .44853 L .47261 .44712 L F
.47541 .4451 m .47675 .44732 L .47423 .44853 L F
.688 .866 .966 r
.54107 .417 m .5362 .41629 L .5396 .41515 L F
.158 .055 .478 r
.69732 .32798 m .69905 .32829 L .69893 .32533 L F
.191 0 .198 r
.69802 .33022 m .69905 .32829 L .69732 .32798 L F
.219 .707 .927 r
.37418 .52589 m .37202 .52529 L .36963 .5252 L F
0 0 .114 r
.37418 .52589 m .3747 .52676 L .37202 .52529 L F
0 .225 .718 r
.38221 .58144 m .38481 .58373 L .38364 .58227 L F
.919 .729 .63 r
.38481 .58373 m .38217 .58551 L .38364 .58227 L F
.38481 .58373 m .38471 .58704 L .38217 .58551 L F
.815 .832 .863 r
.34599 .51271 m .34332 .50866 L .34572 .50943 L F
.34599 .51271 m .34306 .51301 L .34332 .50866 L F
.717 .629 .758 r
.34931 .5091 m .34599 .51271 L .34572 .50943 L F
.728 .591 .702 r
.56347 .3943 m .55937 .39364 L .56169 .39237 L F
.56347 .3943 m .5607 .39699 L .55937 .39364 L F
.164 .348 .801 r
.3507 .69992 m .35223 .70355 L .3531 .7019 L F
.382 .627 .95 r
.35223 .70355 m .35451 .70394 L .3531 .7019 L F
.809 .717 .763 r
.50088 .43294 m .50182 .43607 L .49996 .43393 L F
.736 .816 .914 r
.50182 .43607 m .49805 .43588 L .49996 .43393 L F
.949 .603 .215 r
.23785 .61271 m .23894 .61578 L .23737 .61264 L F
.814 .733 .775 r
.41921 .4739 m .41517 .47637 L .41739 .47264 L F
.41921 .4739 m .4162 .47688 L .41517 .47637 L F
.819 .907 .9 r
.41921 .4739 m .41989 .46978 L .4224 .47111 L F
.41921 .4739 m .41739 .47264 L .41989 .46978 L F
.665 .969 .798 r
.68942 .37472 m .69269 .37218 L .69098 .37271 L F
.668 .975 .849 r
.68786 .37486 m .68942 .37472 L .69098 .37271 L F
.271 .001 .307 r
.35337 .6023 m .35298 .60547 L .34985 .60627 L F
.245 .078 .447 r
.35246 .60765 m .34985 .60627 L .35298 .60547 L F
.35246 .60765 m .34899 .61012 L .34985 .60627 L F
.706 .645 .786 r
.37121 .53179 m .37324 .53609 L .36848 .53507 L F
.424 0 0 r
.37127 .53731 m .37126 .53776 L .37324 .53609 L F
0 0 0 r
.42435 .53391 m .42271 .53543 L .42539 .53209 L F
.286 .221 .606 r
.42435 .53391 m .42514 .53727 L .42271 .53543 L F
.614 .386 .548 r
.37271 .60433 m .37077 .60902 L .37015 .60889 L F
.22 0 .333 r
.37269 .60742 m .37077 .60902 L .37271 .60433 L F
.838 .813 .826 r
.4297 .50903 m .42626 .50892 L .4289 .50538 L F
.803 .858 .89 r
.4297 .50903 m .426 .51107 L .42626 .50892 L F
.991 .812 .433 r
.42954 .50397 m .4297 .50903 L .4289 .50538 L F
.984 .708 .406 r
.38488 .69491 m .38669 .69532 L .38633 .69257 L F
.247 .544 .926 r
.38776 .69244 m .38633 .69257 L .38531 .69106 L F
.125 0 0 r
.38488 .69491 m .38633 .69257 L .38776 .69244 L F
.551 .801 .991 r
.55166 .40361 m .55084 .40188 L .54976 .40456 L F
.55166 .40361 m .554 .40274 L .55084 .40188 L F
.193 0 0 r
.35095 .68731 m .35226 .68763 L .34839 .68665 L F
.228 0 0 r
.35329 .68915 m .35226 .68763 L .35095 .68731 L F
.35329 .68915 m .35484 .68706 L .35226 .68763 L F
.455 .46 .774 r
.37019 .69339 m .37088 .69639 L .37179 .69391 L F
.867 .947 .588 r
.37179 .69391 m .37088 .69639 L .36912 .69825 L F
.593 .684 .905 r
.37691 .62984 m .37294 .62872 L .37513 .62789 L F
.91 .933 .561 r
.37825 .62527 m .37691 .62984 L .37513 .62789 L F
.212 0 .29 r
.35494 .60445 m .35298 .60547 L .35337 .6023 L F
.022 0 .357 r
.45902 .56692 m .46122 .56338 L .46122 .56497 L F
0 .484 .768 r
.3413 .5461 m .3404 .54724 L .34146 .54587 L F
.308 .362 .755 r
.3404 .54724 m .34114 .54961 L .33901 .549 L F
0 .484 .768 r
.33925 .54901 m .34114 .54961 L .34075 .54837 L F
.33925 .54901 m .34075 .54837 L .3404 .54724 L F
.344 0 0 r
.33672 .54996 m .33502 .54902 L .33505 .55092 L F
.33502 .54902 m .33307 .54794 L .33377 .54899 L F
.33502 .54902 m .33377 .54899 L .33505 .55092 L F
.33502 .54902 m .33526 .54915 L .33307 .54794 L F
.33672 .54996 m .33568 .54938 L .33502 .54902 L F
.33568 .54938 m .33526 .54915 L .33502 .54902 L F
.283 0 0 r
.33591 .54951 m .33796 .54956 L .33906 .54909 L F
.787 .867 .908 r
.33307 .54794 m .33018 .55115 L .33505 .55092 L F
.593 .756 .956 r
.32946 .55178 m .33505 .55092 L .33018 .55115 L F
.32946 .55178 m .33416 .55332 L .33505 .55092 L F
.913 .814 .346 r
.33526 .54915 m .33495 .55045 L .33525 .5496 L F
.33495 .55045 m .33479 .55116 L .33496 .55059 L F
.33495 .55045 m .33496 .55059 L .33525 .5496 L F
.799 .896 .912 r
.33113 .54842 m .33018 .55115 L .33307 .54795 L F
.33113 .54842 m .33307 .54795 L .33307 .54794 L F
.805 .564 .574 r
.32674 .54783 m .32847 .54907 L .33113 .54842 L F
0 0 .298 r
.33113 .54842 m .32946 .55178 L .33018 .55115 L F
.33113 .54842 m .3308 .55075 L .32946 .55178 L F
.805 .564 .574 r
.32847 .54907 m .3308 .55075 L .33113 .54842 L F
0 .353 .763 r
.33301 .54817 m .33525 .5496 L .33526 .54915 L F
.894 .637 .544 r
.33526 .54915 m .33517 .5495 L .33301 .54817 L F
.283 0 0 r
.33525 .5496 m .3354 .5496 L .33543 .54957 L F
.811 .812 .851 r
.33526 .54915 m .33525 .5496 L .33543 .54957 L F
.789 .97 .67 r
.33568 .54938 m .33543 .54957 L .33526 .54915 L F
.811 .812 .851 r
.33526 .54915 m .33543 .54957 L .33925 .54901 L F
.789 .97 .67 r
.33543 .54957 m .33534 .54964 L .33526 .54915 L F
0 .353 .763 r
.33301 .54817 m .33517 .5495 L .33525 .5496 L F
.913 .814 .346 r
.33525 .5496 m .3352 .54954 L .33526 .54915 L F
0 .353 .763 r
.33517 .5495 m .33529 .54957 L .33525 .5496 L F
.913 .814 .346 r
.33525 .5496 m .33515 .54994 L .3352 .54954 L F
.593 .756 .956 r
.32946 .55178 m .33142 .55401 L .33416 .55332 L F
.697 .157 0 r
.32955 .55381 m .32726 .55283 L .32584 .55103 L F
.28 .591 .947 r
.32955 .55381 m .32946 .55178 L .32726 .55283 L F
.562 .487 .729 r
.3308 .55075 m .32914 .5546 L .32946 .55178 L F
.3308 .55075 m .33188 .55401 L .32914 .5546 L F
.544 .342 .556 r
.33479 .55116 m .33188 .55401 L .3308 .55075 L F
.161 0 0 r
.32958 .55283 m .33209 .55249 L .33459 .55109 L F
.913 .814 .346 r
.33495 .55061 m .33479 .55116 L .3349 .55068 L F
.33515 .54994 m .33495 .55061 L .33498 .55036 L F
.33495 .55061 m .3349 .55068 L .33498 .55036 L F
.144 0 .244 r
.33505 .55092 m .33416 .55332 L .33672 .54996 L F
.58 .318 .485 r
.33468 .55267 m .33719 .5536 L .3345 .55368 L F
.789 .97 .67 r
.33672 .54996 m .33618 .55067 L .33497 .5511 L F
.58 .318 .485 r
.33502 .55036 m .33497 .5511 L .33479 .55116 L F
.789 .97 .67 r
.33618 .55067 m .33416 .55332 L .33472 .55139 L F
.33497 .5511 m .33472 .55139 L .33479 .55116 L F
.33618 .55067 m .33472 .55139 L .33497 .5511 L F
.58 .318 .485 r
.33506 .55099 m .33719 .5536 L .33468 .55267 L F
.789 .97 .67 r
.33672 .54996 m .33532 .55083 L .33521 .55033 L F
.58 .318 .485 r
.33534 .54978 m .33561 .55035 L .33506 .55099 L F
.789 .97 .67 r
.33672 .54996 m .33497 .5511 L .33506 .55099 L F
.58 .318 .485 r
.33561 .55035 m .33719 .5536 L .33506 .55099 L F
.33525 .5496 m .33492 .55137 L .33479 .55116 L F
.33492 .55137 m .3345 .55368 L .33477 .55134 L F
.33492 .55137 m .33477 .55134 L .33479 .55116 L F
.33525 .5496 m .33534 .54978 L .33506 .55099 L F
.33525 .5496 m .33506 .55099 L .33497 .5511 L F
.789 .97 .67 r
.33672 .54996 m .33521 .55033 L .33532 .54984 L F
.58 .318 .485 r
.33468 .55267 m .33719 .5536 L .3345 .55368 L F
.33525 .5496 m .33534 .54978 L .33468 .55267 L F
.789 .97 .67 r
.33532 .55083 m .33506 .55099 L .33516 .55054 L F
.58 .318 .485 r
.33534 .54978 m .33719 .5536 L .33468 .55267 L F
.33508 .5505 m .33497 .5511 L .33502 .55036 L F
.789 .97 .67 r
.33516 .55054 m .33479 .55116 L .335 .55025 L F
.33506 .55099 m .33479 .55116 L .33516 .55054 L F
.33532 .54984 m .33521 .55033 L .3351 .54983 L F
.58 .318 .485 r
.33525 .5496 m .33508 .5505 L .33502 .55036 L F
.789 .97 .67 r
.33532 .55083 m .335 .55025 L .3351 .54983 L F
.913 .814 .346 r
.33515 .54994 m .33498 .55036 L .33526 .54915 L F
.789 .97 .67 r
.33534 .54964 m .3351 .54983 L .33517 .5495 L F
.33534 .54964 m .33517 .5495 L .33526 .54915 L F
0 .353 .763 r
.33517 .5495 m .33564 .54933 L .33529 .54957 L F
.33411 .54866 m .33564 .54933 L .33517 .5495 L F
.633 .377 .513 r
.34114 .54961 m .3434 .55016 L .34378 .54746 L F
0 .484 .768 r
.33925 .54901 m .3434 .55016 L .34114 .54961 L F
0 .526 .811 r
.33925 .54901 m .34183 .54951 L .3434 .55016 L F
.283 0 0 r
.33696 .54957 m .33959 .55029 L .34183 .54951 L F
.33525 .5496 m .3364 .54978 L .33696 .54957 L F
.3364 .54978 m .33959 .55029 L .33696 .54957 L F
.161 0 0 r
.33477 .55085 m .33459 .55109 L .33557 .55054 L F
.33477 .55085 m .33557 .55054 L .33489 .55057 L F
.685 .467 .585 r
.33113 .54842 m .3308 .55075 L .33467 .55058 L F
.33466 .55011 m .33467 .55058 L .33557 .55054 L F
.33113 .54842 m .33467 .55058 L .33466 .55011 L F
.894 .637 .544 r
.33517 .5495 m .33495 .55045 L .33466 .55011 L F
.33463 .54917 m .33466 .55011 L .33301 .54817 L F
.33517 .5495 m .33466 .55011 L .33463 .54917 L F
.199 0 .049 r
.33429 .55126 m .33495 .55031 L .33557 .55054 L F
.073 .405 .859 r
.33557 .55054 m .3356 .55008 L .33531 .55018 L F
.33518 .54999 m .33564 .54933 L .33431 .54874 L F
.199 0 .049 r
.33495 .55031 m .33564 .54933 L .3356 .55008 L F
.073 .405 .859 r
.33557 .55054 m .33431 .54874 L .33478 .54981 L F
.685 .467 .585 r
.33495 .55025 m .33557 .55054 L .33495 .54997 L F
.199 0 .049 r
.33495 .55031 m .3356 .55008 L .33557 .55054 L F
.894 .637 .544 r
.33495 .55045 m .33479 .55116 L .33451 .5507 L F
.682 .593 .749 r
.33451 .5507 m .33479 .55116 L .3308 .55075 L F
.161 0 0 r
.33477 .55085 m .33484 .5507 L .3308 .55075 L F
.33484 .5507 m .33489 .55057 L .3308 .55075 L F
.685 .467 .585 r
.33113 .54842 m .33466 .55011 L .33301 .54817 L F
.682 .593 .749 r
.33301 .54817 m .33451 .5507 L .3308 .55075 L F
.894 .637 .544 r
.33491 .5504 m .33451 .5507 L .33301 .54817 L F
.33495 .55045 m .33451 .5507 L .33491 .5504 L F
.161 0 0 r
.32958 .55283 m .33382 .55121 L .3308 .55075 L F
.33382 .55121 m .33477 .55085 L .33433 .55084 L F
.33382 .55121 m .33433 .55084 L .3308 .55075 L F
.32958 .55283 m .33459 .55109 L .33477 .55085 L F
.199 0 .049 r
.33209 .55249 m .33362 .55113 L .33429 .55126 L F
.685 .467 .585 r
.33466 .55011 m .33495 .55025 L .33301 .54817 L F
.33495 .55025 m .33495 .54997 L .33301 .54817 L F
.283 0 0 r
.33525 .5496 m .33906 .54909 L .33874 .54908 L F
.789 .97 .67 r
.33672 .54996 m .3351 .54983 L .33568 .54938 L F
.283 0 0 r
.33543 .54957 m .33605 .54959 L .33591 .54951 L F
.3354 .5496 m .33605 .54959 L .33543 .54957 L F
.33605 .54959 m .33796 .54956 L .33591 .54951 L F
.33796 .54956 m .34183 .54951 L .33925 .54901 L F
0 0 0 r
.33806 .54906 m .33526 .54915 L .33925 .54901 L F
.62 .804 .97 r
.3335 .54786 m .33791 .54902 L .33706 .54563 L F
.33791 .54902 m .33806 .54906 L .33804 .54899 L F
.33791 .54902 m .33804 .54899 L .33706 .54563 L F
.33426 .54839 m .33806 .54906 L .3335 .54786 L F
.482 0 0 r
.33307 .54794 m .33526 .54915 L .33301 .54817 L F
.62 .804 .97 r
.33301 .54817 m .33526 .54915 L .33806 .54906 L F
.228 .553 .932 r
.33778 .54885 m .33577 .54944 L .33564 .54933 L F
.33577 .54944 m .33525 .5496 L .33535 .54953 L F
.33577 .54944 m .33535 .54953 L .33564 .54933 L F
.33778 .54885 m .33959 .55029 L .33621 .54975 L F
.33577 .54944 m .33621 .54975 L .33525 .5496 L F
.33778 .54885 m .33621 .54975 L .33577 .54944 L F
.62 .804 .97 r
.33301 .54817 m .33426 .54839 L .3335 .54786 L F
.199 0 .049 r
.33362 .55113 m .33564 .54933 L .33429 .55126 L F
.789 .97 .67 r
.33506 .55099 m .33497 .5511 L .33479 .55116 L F
.58 .318 .485 r
.33497 .5511 m .33506 .55099 L .33468 .55267 L F
0 .353 .763 r
.33301 .54817 m .33411 .54866 L .33517 .5495 L F
.073 .405 .859 r
.33478 .54981 m .33431 .54874 L .33301 .54817 L F
.58 .318 .485 r
.33497 .5511 m .3345 .55368 L .33479 .55116 L F
.283 0 0 r
.33874 .54908 m .33906 .54909 L .33925 .54901 L F
0 .484 .768 r
.33925 .54901 m .3404 .54724 L .3413 .5461 L F
.308 .362 .755 r
.3404 .54724 m .33901 .549 L .33832 .54881 L F
.888 .976 .826 r
.33814 .57973 m .34159 .5774 L .33995 .57601 L F
.485 .787 .998 r
.34159 .5774 m .3421 .57564 L .33995 .57601 L F
.34159 .5774 m .34448 .57738 L .3421 .57564 L F
.424 .33 .645 r
.34159 .5774 m .34408 .57966 L .34448 .57738 L F
.34159 .5774 m .34215 .58084 L .34408 .57966 L F
.704 .961 .945 r
.26602 .51933 m .26517 .52163 L .26851 .52018 L F
.26602 .51933 m .26375 .52117 L .26517 .52163 L F
.898 .805 .748 r
.30291 .6662 m .30449 .67082 L .3062 .66743 L F
0 .347 .825 r
.71564 .31525 m .71438 .31603 L .71262 .31612 L F
.71564 .31525 m .71585 .31695 L .71438 .31603 L F
.632 .228 .26 r
.44379 .57913 m .44525 .57662 L .4423 .57717 L F
0 0 0 r
.44585 .57633 m .44525 .57662 L .44379 .57913 L F
.674 .966 .93 r
.25534 .52004 m .25603 .51833 L .25744 .51828 L F
.25534 .52004 m .25223 .52032 L .25603 .51833 L F
.948 .821 .685 r
.41516 .60123 m .4181 .60033 L .41859 .5993 L F
.41516 .60123 m .41696 .60272 L .4181 .60033 L F
.741 .81 .906 r
.68731 .35147 m .68388 .3514 L .68657 .35073 L F
.722 .988 .87 r
.68845 .34944 m .68731 .35147 L .68657 .35073 L F
.68845 .34944 m .69063 .34909 L .68731 .35147 L F
.334 .18 .518 r
.561 .39869 m .55664 .3972 L .5607 .39699 L F
.56101 .39877 m .56092 .39874 L .561 .39869 L F
.56092 .39874 m .55664 .3972 L .561 .39869 L F
.949 .943 .741 r
.55978 .40117 m .55767 .40207 L .55857 .40003 L F
.334 .18 .518 r
.56085 .39885 m .55664 .3972 L .56101 .39877 L F
.56085 .39885 m .55719 .39983 L .55664 .3972 L F
.934 .939 .775 r
.55981 .39934 m .56079 .39888 L .55978 .40117 L F
.56079 .39888 m .56157 .3985 L .56078 .39968 L F
.56079 .39888 m .56078 .39968 L .55978 .40117 L F
.334 .18 .518 r
.56079 .39898 m .55719 .39983 L .56085 .39885 L F
.416 .531 .866 r
.55508 .39625 m .55719 .39983 L .56079 .39898 L F
.334 .18 .518 r
.56104 .39892 m .56079 .39898 L .56085 .39885 L F
.416 .531 .866 r
.56079 .39881 m .56079 .39898 L .56104 .39892 L F
.55508 .39625 m .56079 .39898 L .56079 .39881 L F
.55508 .39625 m .56079 .39881 L .55781 .3956 L F
.48 0 0 r
.5607 .39699 m .56187 .39806 L .56101 .39877 L F
.934 .939 .775 r
.56118 .39818 m .56145 .39841 L .56085 .39885 L F
.56145 .39841 m .56157 .3985 L .56101 .39877 L F
.56145 .39841 m .56101 .39877 L .56085 .39885 L F
.48 0 0 r
.56101 .39877 m .56187 .39806 L .56104 .39892 L F
.416 .531 .866 r
.56079 .39881 m .56104 .39892 L .56082 .3987 L F
.56079 .39881 m .56082 .3987 L .55781 .3956 L F
.977 .835 .636 r
.56078 .3981 m .56187 .39806 L .56013 .39566 L F
.56078 .3981 m .56013 .39566 L .56004 .39576 L F
0 .269 .766 r
.5599 .39534 m .56187 .39806 L .56139 .39691 L F
.934 .939 .775 r
.56076 .39788 m .56103 .39805 L .561 .39809 L F
.977 .835 .636 r
.56047 .39834 m .56004 .39576 L .55781 .3956 L F
.56082 .3987 m .56061 .3979 L .56047 .39834 L F
.56061 .3979 m .56004 .39576 L .56047 .39834 L F
.753 .958 .938 r
.56139 .39691 m .56187 .39806 L .56074 .3975 L F
.977 .835 .636 r
.56078 .3981 m .56004 .39576 L .56082 .3987 L F
.753 .958 .938 r
.56091 .39696 m .56074 .3975 L .55986 .39707 L F
.56139 .39691 m .56074 .3975 L .56091 .39696 L F
.934 .939 .775 r
.55986 .39707 m .56076 .39783 L .56076 .39788 L F
.56076 .39783 m .56103 .39805 L .56076 .39788 L F
.56118 .39818 m .56085 .39885 L .55981 .39934 L F
.334 .18 .518 r
.56104 .39892 m .56085 .39885 L .56101 .39877 L F
.977 .835 .636 r
.56104 .39892 m .56078 .3981 L .56082 .3987 L F
.56004 .39576 m .5599 .39534 L .55975 .39536 L F
.56004 .39576 m .55975 .39536 L .55781 .3956 L F
.884 .608 .514 r
.5594 .39642 m .56076 .39676 L .55986 .39707 L F
.56076 .39676 m .56139 .39691 L .56091 .39696 L F
.56076 .39676 m .56091 .39696 L .55986 .39707 L F
.5587 .39542 m .55979 .39602 L .5594 .39642 L F
.55979 .39602 m .56139 .39691 L .5594 .39642 L F
.977 .835 .636 r
.56004 .39576 m .56013 .39566 L .5599 .39534 L F
.934 .939 .775 r
.56103 .39805 m .56118 .39818 L .56092 .39841 L F
.977 .835 .636 r
.56104 .39892 m .56187 .39806 L .56078 .3981 L F
.934 .939 .775 r
.55984 .39814 m .561 .39809 L .55981 .39934 L F
.55986 .39707 m .561 .39809 L .55984 .39814 L F
.56103 .39805 m .56092 .39841 L .55981 .39934 L F
.949 .943 .741 r
.55981 .39934 m .55857 .40003 L .55986 .39707 L F
.55978 .40117 m .55857 .40003 L .55981 .39934 L F
.934 .939 .775 r
.55986 .39707 m .56187 .39806 L .56157 .3985 L F
.185 .351 .798 r
.28017 .62728 m .27902 .62882 L .27736 .62514 L F
.046 .147 .648 r
.28094 .63052 m .27902 .62882 L .28017 .62728 L F
0 0 .238 r
.36312 .5837 m .36368 .58521 L .36525 .58306 L F
.36312 .5837 m .36318 .58679 L .36368 .58521 L F
.487 .372 .648 r
.47065 .52484 m .47075 .52875 L .46842 .52939 L F
.45 .368 .673 r
.47075 .52875 m .46903 .53198 L .46842 .52939 L F
.532 .843 .999 r
.37513 .62789 m .37294 .62872 L .37088 .62761 L F
.022 0 .357 r
.45902 .56692 m .46098 .56601 L .46122 .56338 L F
0 0 .127 r
.45902 .56692 m .46028 .56794 L .46098 .56601 L F
.974 .672 .295 r
.62548 .40631 m .62534 .40362 L .62395 .40221 L F
.348 .161 .48 r
.62534 .40362 m .6276 .40016 L .62787 .40281 L F
.553 .816 .995 r
.62395 .40221 m .62534 .40362 L .62787 .40281 L F
.993 .741 .409 r
.62237 .39028 m .62239 .39302 L .6211 .38905 L F
.648 .865 .981 r
.62491 .38909 m .62237 .39028 L .6211 .38905 L F
.488 .311 .566 r
.62491 .38909 m .62239 .39302 L .62237 .39028 L F
.732 .519 .603 r
.34897 .63192 m .35381 .63192 L .35344 .62866 L F
.816 .789 .827 r
.51103 .43 m .5068 .43197 L .50945 .42871 L F
.705 .75 .887 r
.51363 .42913 m .51103 .43 L .50945 .42871 L F
.505 .744 .981 r
.4317 .58279 m .43002 .58436 L .42839 .58265 L F
.4317 .58279 m .43332 .58411 L .43002 .58436 L F
.194 .215 .655 r
.43002 .58436 m .4317 .58279 L .42839 .58265 L F
.43002 .58436 m .43246 .58533 L .4317 .58279 L F
.25 0 0 r
.5589 .4674 m .56009 .46861 L .55748 .46923 L F
.5589 .4674 m .56146 .46717 L .56009 .46861 L F
.434 .283 .577 r
.38186 .55092 m .38181 .55367 L .37945 .5516 L F
.55 .558 .815 r
.48722 .49266 m .48205 .49198 L .48701 .48976 L F
.395 .086 .319 r
.37966 .66474 m .37956 .66181 L .37698 .66405 L F
.341 .048 .314 r
.38216 .66251 m .37956 .66181 L .37966 .66474 L F
.281 0 .282 r
.23475 .5895 m .23266 .59183 L .23372 .59018 L F
.241 0 0 r
.29433 .5159 m .29285 .51798 L .29038 .51856 L F
.998 .793 .443 r
.29344 .51308 m .29425 .51497 L .29559 .51449 L F
.578 .925 .733 r
.29688 .51404 m .29559 .51449 L .29433 .5159 L F
.209 0 0 r
.29527 .51731 m .29433 .5159 L .29559 .51449 L F
.998 .793 .443 r
.29425 .51497 m .29527 .51731 L .29559 .51449 L F
.578 .925 .733 r
.29741 .51365 m .29559 .51449 L .29688 .51404 L F
.209 0 0 r
.29527 .51731 m .29285 .51798 L .29433 .5159 L F
.415 .787 .994 r
.61586 .39332 m .61708 .39602 L .61712 .39726 L F
0 .13 .678 r
.61934 .39928 m .61712 .39726 L .61708 .39602 L F
.46 .884 .911 r
.56069 .41578 m .56215 .41456 L .55908 .41502 L F
.56207 .4153 m .56359 .41477 L .56215 .41456 L F
.786 .994 .876 r
.56215 .41456 m .56359 .41477 L .56603 .41231 L F
.56215 .41456 m .56603 .41231 L .56439 .41341 L F
.526 .655 .917 r
.56359 .41477 m .56732 .41619 L .56603 .41231 L F
.452 .224 .477 r
.56215 .41456 m .56439 .41341 L .5647 .41606 L F
0 .284 .768 r
.56221 .41401 m .56215 .41456 L .5647 .41606 L F
.56059 .41267 m .56215 .41456 L .56221 .41401 L F
.46 .884 .911 r
.56069 .41578 m .56207 .4153 L .56215 .41456 L F
.695 .62 .769 r
.39555 .48826 m .39323 .49087 L .39165 .48684 L F
.799 .989 .741 r
.30901 .54682 m .30842 .54872 L .31073 .54824 L F
.30901 .54682 m .3063 .54983 L .30842 .54872 L F
0 0 0 r
.65374 .38089 m .65145 .38449 L .65318 .38258 L F
.65599 .37959 m .65374 .38089 L .65318 .38258 L F
.862 .894 .856 r
.56723 .3975 m .56527 .39992 L .56343 .39937 L F
.734 .386 .39 r
.56527 .39992 m .56234 .40135 L .56343 .39937 L F
.56527 .39992 m .56761 .40237 L .56234 .40135 L F
.497 .161 .327 r
.30183 .56743 m .29871 .56951 L .29922 .56747 L F
.453 .144 .349 r
.31927 .61805 m .31925 .62048 L .3171 .61915 L F
0 0 .377 r
.63438 .38648 m .6338 .38874 L .63346 .38863 L F
.671 .804 .946 r
.6338 .38874 m .63438 .38648 L .63346 .38863 L F
.6338 .38874 m .63845 .38759 L .63438 .38648 L F
.815 .724 .765 r
.43442 .52635 m .43187 .52903 L .43442 .52938 L F
.731 .282 .185 r
.43187 .52903 m .43369 .53064 L .43442 .52938 L F
.591 .419 .617 r
.43442 .52938 m .43733 .52558 L .43442 .52635 L F
.43442 .52938 m .43753 .52892 L .43733 .52558 L F
.692 .392 .461 r
.43369 .53064 m .43753 .52892 L .43442 .52938 L F
.982 .909 .604 r
.39792 .59141 m .40012 .5891 L .39917 .58885 L F
.39792 .59141 m .39885 .59334 L .40012 .5891 L F
.457 0 0 r
.33127 .49541 m .32985 .4938 L .32807 .49516 L F
.33127 .49541 m .33223 .49421 L .32985 .4938 L F
.487 .465 .759 r
.33101 .68625 m .33423 .68848 L .33536 .68547 L F
.448 .183 .418 r
.33786 .68529 m .33784 .68347 L .33536 .68547 L F
.414 .081 .289 r
.33694 .68779 m .33536 .68547 L .33423 .68848 L F
.33694 .68779 m .33786 .68529 L .33536 .68547 L F
.974 .907 .683 r
.34602 .61324 m .34586 .61541 L .34443 .61438 L F
.753 .727 .828 r
.34586 .61541 m .34294 .61333 L .3441 .61724 L F
.34586 .61541 m .3441 .61724 L .34443 .61438 L F
.525 .527 .8 r
.34602 .61324 m .34873 .61495 L .34586 .61541 L F
0 .122 .671 r
.34822 .6177 m .34586 .61541 L .34873 .61495 L F
.707 .872 .959 r
.4335 .52508 m .43733 .52558 L .43676 .52345 L F
.782 .845 .899 r
.4335 .52508 m .43442 .52635 L .43733 .52558 L F
.902 .955 .823 r
.43676 .52345 m .43733 .52558 L .43958 .52247 L F
.68 .558 .71 r
.43733 .52558 m .44076 .52536 L .43958 .52247 L F
.634 .451 .618 r
.43733 .52558 m .44083 .52837 L .44076 .52536 L F
.43733 .52558 m .43753 .52892 L .44083 .52837 L F
.604 .84 .465 r
.68442 .29816 m .68538 .29705 L .68281 .30046 L F
.732 .981 .759 r
.6867 .29473 m .6884 .29407 L .68538 .29705 L F
.66 .857 .465 r
.6867 .29473 m .68538 .29705 L .68442 .29816 L F
.415 .787 .994 r
.61875 .39296 m .61981 .39392 L .61586 .39332 L F
.61586 .39332 m .61981 .39392 L .61875 .39296 L F
.9 .824 .763 r
.39929 .66332 m .4003 .66643 L .40148 .6646 L F
.616 .953 .913 r
.66089 .38881 m .65928 .39062 L .66168 .38926 L F
.609 .941 .75 r
.6577 .39119 m .65928 .39062 L .66089 .38881 L F
.82 .725 .76 r
.62787 .40281 m .62916 .40661 L .62548 .40631 L F
.742 .685 .796 r
.63192 .40333 m .62916 .40661 L .62787 .40281 L F
.772 .605 .673 r
.49157 .48361 m .49101 .48696 L .48983 .48692 L F
0 0 .029 r
.3183 .60947 m .31549 .61247 L .31729 .61119 L F
.081 0 .153 r
.31549 .61247 m .3166 .61408 L .31729 .61119 L F
.31549 .61247 m .3149 .61497 L .3166 .61408 L F
0 0 .466 r
.429 .56638 m .42959 .56864 L .42878 .56665 L F
.654 .103 0 r
.70561 .31178 m .70902 .31404 L .70993 .31332 L F
.752 .235 0 r
.70902 .31404 m .71262 .31612 L .70993 .31332 L F
.497 .046 .108 r
.30796 .53555 m .30723 .53663 L .30544 .53544 L F
.30796 .53555 m .30723 .53663 L .30544 .53544 L F
.935 .931 .572 r
.39473 .60425 m .39625 .60268 L .39629 .60246 L F
.39473 .60425 m .39488 .60638 L .39625 .60268 L F
0 0 0 r
.42646 .50519 m .42579 .50619 L .42465 .50766 L F
.502 .441 .721 r
.42579 .50619 m .42362 .5094 L .42465 .50766 L F
0 .139 .685 r
.2719 .57724 m .27325 .57798 L .2702 .57661 L F
.2719 .57724 m .27414 .57993 L .27325 .57798 L F
.501 .374 .64 r
.45178 .54539 m .45417 .54469 L .45352 .54187 L F
.71 .191 0 r
.42911 .56923 m .42959 .56864 L .429 .56638 L F
.42911 .56923 m .43082 .57022 L .42959 .56864 L F
.449 0 0 r
.38221 .58144 m .38364 .58227 L .38074 .58228 L F
.728 .608 .723 r
.33745 .51262 m .33808 .51613 L .34107 .51373 L F
.548 .848 .998 r
.34182 .5117 m .34107 .51373 L .34306 .51301 L F
.731 .644 .762 r
.41577 .48698 m .41793 .48754 L .418 .48547 L F
0 .448 .725 r
.41577 .48698 m .41873 .48772 L .41793 .48754 L F
.391 .355 .698 r
.418 .48547 m .41793 .48754 L .42058 .48596 L F
.245 .08 .449 r
.41793 .48754 m .41873 .48772 L .42058 .48596 L F
.285 .575 .938 r
.34269 .69696 m .34478 .69929 L .34677 .69936 L F
.6 .637 .859 r
.34478 .69929 m .3483 .70053 L .34677 .69936 L F
.498 .538 .828 r
.45577 .54853 m .45678 .54414 L .45417 .54469 L F
.45577 .54853 m .45815 .54811 L .45678 .54414 L F
.755 .495 .539 r
.34909 .6767 m .346 .6744 L .34559 .67616 L F
.991 .732 .403 r
.35489 .64236 m .35367 .64327 L .35467 .64083 L F
.35489 .64236 m .35497 .64407 L .35367 .64327 L F
.585 .692 .916 r
.35538 .63931 m .35489 .64236 L .35467 .64083 L F
.35538 .63931 m .35798 .64174 L .35489 .64236 L F
.678 .609 .771 r
.35798 .64174 m .35497 .64407 L .35489 .64236 L F
.612 .628 .843 r
.3344 .53177 m .33712 .52957 L .33297 .53076 L F
.3344 .53177 m .33773 .5322 L .33712 .52957 L F
.68 .393 .48 r
.3344 .53177 m .33653 .53438 L .33773 .5322 L F
.3344 .53177 m .33407 .53483 L .33653 .53438 L F
.965 .686 .455 r
.60751 .41 m .60586 .41131 L .60562 .40894 L F
.60751 .41 m .60759 .41231 L .60586 .41131 L F
.883 .892 .47 r
.23253 .54359 m .23377 .54214 L .23572 .54039 L F
.469 .892 .843 r
.64258 .33408 m .64448 .33312 L .64667 .3328 L F
.616 .918 .657 r
.64667 .3328 m .64827 .33086 L .64963 .33005 L F
.648 .969 .868 r
.64667 .3328 m .64448 .33312 L .64827 .33086 L F
.515 .845 .558 r
.68281 .30046 m .67988 .30308 L .68204 .30158 L F
0 0 0 r
.68442 .29816 m .68281 .30046 L .68204 .30158 L F
.332 .677 .978 r
.34165 .52724 m .34347 .52866 L .34114 .52866 L F
.067 0 .415 r
.31729 .61119 m .31913 .60795 L .3183 .60947 L F
.45 .368 .673 r
.47075 .52875 m .47128 .53145 L .46903 .53198 L F
.529 .464 .727 r
.47128 .53145 m .46967 .53734 L .46903 .53198 L F
0 0 .4 r
.35892 .60978 m .35974 .61156 L .36232 .6091 L F
.768 .437 .426 r
.35974 .61156 m .36468 .61179 L .36232 .6091 L F
.232 0 .151 r
.35593 .59938 m .35911 .59681 L .35916 .59798 L F
.776 .63 .7 r
.36156 .59618 m .35916 .59798 L .35911 .59681 L F
.987 .762 .511 r
.31546 .59658 m .31511 .59947 L .31358 .59824 L F
.777 .54 .576 r
.31358 .59824 m .3177 .59593 L .31546 .59658 L F
.701 .927 .966 r
.72422 .31504 m .72059 .31716 L .72186 .31474 L F
.711 .938 .96 r
.72186 .31474 m .72059 .31716 L .71956 .31618 L F
.857 .792 .297 r
.38877 .5965 m .38805 .5983 L .38875 .59436 L F
0 0 .186 r
.47592 .5696 m .47598 .57215 L .47541 .5739 L F
0 0 .496 r
.47598 .57215 m .47662 .57592 L .47541 .5739 L F
.108 .033 .482 r
.47541 .5739 m .47662 .57592 L .47546 .5769 L F
.608 .564 .779 r
.39457 .68121 m .39568 .67598 L .39286 .6768 L F
.39457 .68121 m .3961 .68061 L .39568 .67598 L F
.279 .42 .825 r
.39457 .68121 m .39758 .68369 L .3961 .68061 L F
.939 .571 .266 r
.58379 .38428 m .58263 .38551 L .58227 .38309 L F
.58379 .38428 m .58434 .38662 L .58263 .38551 L F
0 .273 .744 r
.2902 .64382 m .288 .64259 L .28622 .64075 L F
.862 .423 .161 r
.29042 .64551 m .288 .64259 L .2902 .64382 L F
.346 .068 .342 r
.35153 .59635 m .35405 .59554 L .3544 .59216 L F
0 .08 .619 r
.3544 .59216 m .35474 .59187 L .35292 .59018 L F
.127 0 .281 r
.3544 .59216 m .35573 .59449 L .35474 .59187 L F
.3544 .59216 m .35405 .59554 L .35573 .59449 L F
.701 .858 .957 r
.68004 .35068 m .67832 .35267 L .67768 .3512 L F
0 0 .177 r
.32635 .64477 m .32625 .64814 L .32667 .64684 L F
0 0 .23 r
.32625 .64814 m .3268 .64892 L .32667 .64684 L F
.32625 .64814 m .32655 .6508 L .3268 .64892 L F
0 0 .506 r
.22742 .55901 m .22547 .55807 L .22792 .55671 L F
.22742 .55901 m .226 .56114 L .22547 .55807 L F
.743 .782 .885 r
.43591 .46067 m .43412 .46235 L .43204 .46043 L F
.562 .36 .564 r
.42794 .53144 m .42435 .53391 L .42539 .53209 L F
.575 .532 .769 r
.42539 .53209 m .42857 .53076 L .42794 .53144 L F
.657 .568 .743 r
.34219 .56977 m .34015 .57104 L .33758 .56619 L F
.725 .854 .943 r
.34829 .68948 m .34614 .69153 L .34397 .68963 L F
0 0 0 r
.34094 .6808 m .33784 .68347 L .33901 .68259 L F
.678 .362 .432 r
.33786 .68529 m .34071 .68725 L .33784 .68347 L F
.865 .996 .788 r
.33675 .52615 m .33307 .52905 L .33499 .52747 L F
.784 .997 .799 r
.33499 .52747 m .33203 .53048 L .33297 .53076 L F
.929 .664 .514 r
.6066 .44334 m .60918 .44215 L .6069 .44108 L F
.6066 .44334 m .60913 .44488 L .60918 .44215 L F
.858 .767 .761 r
.59277 .37184 m .59452 .36819 L .59447 .37112 L F
.59277 .37184 m .59415 .36838 L .59452 .36819 L F
.947 .925 .751 r
.59452 .36819 m .59415 .36838 L .59579 .36352 L F
.718 .665 .796 r
.37125 .68925 m .37596 .69021 L .37452 .68635 L F
.507 0 0 r
.37516 .69076 m .37596 .69021 L .37125 .68925 L F
.624 .06 0 r
.37951 .69212 m .37762 .6911 L .37866 .69134 L F
.37762 .6911 m .37596 .69021 L .37866 .69134 L F
.176 0 0 r
.37966 .69157 m .37866 .69134 L .3769 .69141 L F
.215 .724 .892 r
.38086 .69165 m .37951 .69212 L .37866 .69134 L F
.176 0 0 r
.38086 .69165 m .37866 .69134 L .37966 .69157 L F
.481 0 0 r
.37866 .69134 m .37596 .69021 L .37516 .69076 L F
.852 .532 .446 r
.60792 .36448 m .60686 .36637 L .60584 .36443 L F
.61002 .36453 m .60686 .36637 L .60792 .36448 L F
.989 .889 .618 r
.60686 .36637 m .60533 .36973 L .60638 .36723 L F
0 0 .341 r
.60742 .36223 m .60584 .36443 L .60686 .36637 L F
.989 .889 .618 r
.60686 .36637 m .60638 .36723 L .60742 .36475 L F
.811 .379 .22 r
.24357 .60136 m .24701 .60248 L .24558 .6001 L F
.48 0 0 r
.5607 .39699 m .56343 .39937 L .56187 .39806 L F
.316 .806 .83 r
.28114 .51551 m .27988 .51562 L .28237 .5149 L F
.193 0 0 r
.35095 .68731 m .34839 .68665 L .34829 .68948 L F
.507 .376 .637 r
.47166 .51552 m .47197 .51884 L .46953 .51957 L F
.444 .299 .589 r
.47197 .51884 m .4698 .52239 L .46953 .51957 L F
.948 .922 .75 r
.62461 .42954 m .6222 .43038 L .62349 .43079 L F
.902 .949 .824 r
.62464 .42659 m .62461 .42954 L .62708 .4265 L F
.62464 .42659 m .6235 .42849 L .62461 .42954 L F
.94 .937 .765 r
.6235 .42849 m .6222 .43038 L .62461 .42954 L F
.601 .305 .439 r
.51943 .47095 m .52194 .47315 L .51947 .47336 L F
.643 .288 .354 r
.51943 .47095 m .52201 .47128 L .52194 .47315 L F
.923 .968 .776 r
.3922 .60773 m .39271 .60973 L .39488 .60638 L F
.904 .981 .787 r
.3922 .60773 m .39488 .60638 L .39473 .60425 L F
.775 .67 .747 r
.32485 .59315 m .32791 .59391 L .32803 .59248 L F
.764 .603 .678 r
.32485 .59315 m .32847 .59622 L .32791 .59391 L F
.482 .411 .7 r
.32803 .59248 m .32791 .59391 L .33015 .59324 L F
.465 .379 .674 r
.32791 .59391 m .32968 .59451 L .33015 .59324 L F
.32791 .59391 m .32847 .59622 L .32968 .59451 L F
.701 .513 .631 r
.37018 .54161 m .36673 .53854 L .3688 .5376 L F
.37018 .54161 m .36679 .54235 L .36673 .53854 L F
.574 .367 .562 r
.48983 .48692 m .48701 .48976 L .488 .48934 L F
.237 0 .3 r
.42837 .54507 m .43022 .54476 L .43119 .542 L F
.706 .953 .952 r
.67689 .3217 m .68108 .32074 L .67938 .32041 L F
.674 .971 .915 r
.68299 .31871 m .68108 .32074 L .68362 .31937 L F
.68299 .31871 m .67938 .32041 L .68108 .32074 L F
.296 .766 .937 r
.30623 .62504 m .30421 .62563 L .30323 .6253 L F
.813 .896 .902 r
.62609 .34373 m .62192 .345 L .62433 .34321 L F
.139 .68 .695 r
.62433 .34321 m .62843 .3424 L .62609 .34373 L F
.109 0 0 r
.60785 .37515 m .60594 .37525 L .60508 .3756 L F
.269 .775 .787 r
.45127 .515 m .44986 .51515 L .44833 .51569 L F
.499 .259 .481 r
.51294 .47445 m .51285 .47673 L .51037 .47739 L F
.594 .345 .508 r
.5165 .47354 m .51285 .47673 L .51294 .47445 L F
.595 .806 .981 r
.61795 .35779 m .62175 .35857 L .62076 .35682 L F
.876 .834 .802 r
.62175 .35857 m .61938 .36206 L .6195 .35772 L F
.502 .464 .747 r
.62175 .35857 m .62426 .35472 L .62076 .35682 L F
.62175 .35857 m .62446 .3594 L .62426 .35472 L F
0 .348 .822 r
.6248 .36011 m .62175 .35857 L .62076 .35682 L F
.823 .877 .884 r
.46389 .45118 m .46737 .45073 L .46542 .45253 L F
.826 .772 .801 r
.51678 .421 m .51861 .42263 L .51528 .42226 L F
.918 .825 .738 r
.51788 .41902 m .51861 .42263 L .51678 .421 L F
.557 .909 .701 r
.65533 .33988 m .65381 .34062 L .65205 .34234 L F
.586 .946 .867 r
.65381 .34062 m .65034 .34241 L .65205 .34234 L F
0 0 0 r
.56658 .46566 m .56817 .46523 L .5709 .46478 L F
.732 .626 .741 r
.61563 .37473 m .61797 .37426 L .61825 .37179 L F
.785 .666 .733 r
.61797 .37426 m .62084 .37067 L .61825 .37179 L F
.54 .906 .962 r
.34527 .50905 m .34488 .50807 L .34498 .50735 L F
.397 .113 .362 r
.3521 .58045 m .35155 .58317 L .34908 .58369 L F
0 .097 .648 r
.3521 .58045 m .35432 .58298 L .35441 .57975 L F
.566 .343 .536 r
.35441 .57975 m .35155 .58317 L .3521 .58045 L F
.842 .994 .746 r
.29795 .51135 m .29559 .51449 L .29741 .51365 L F
.897 .907 .823 r
.6208 .43194 m .62237 .43326 L .62349 .43079 L F
.547 .038 0 r
.36953 .51273 m .36942 .51362 L .37172 .51225 L F
0 .454 .743 r
.36942 .51362 m .37353 .51483 L .37172 .51225 L F
.026 0 0 r
.33675 .52615 m .33752 .52672 L .33836 .52667 L F
.33675 .52615 m .33499 .52747 L .33752 .52672 L F
0 0 0 r
.42716 .50448 m .42646 .50519 L .42828 .50315 L F
.42716 .50448 m .42579 .50619 L .42646 .50519 L F
.75 .99 .788 r
.69371 .34616 m .69063 .34909 L .69196 .34675 L F
.747 .993 .867 r
.69196 .34675 m .69063 .34909 L .68845 .34944 L F
.782 .92 .542 r
.39119 .61145 m .39271 .60973 L .3922 .60773 L F
.39119 .61145 m .39127 .61194 L .39271 .60973 L F
.777 .48 .484 r
.59588 .36639 m .59884 .36731 L .6002 .364 L F
.266 .722 .955 r
.6002 .364 m .60228 .36378 L .59831 .36308 L F
.6002 .364 m .60228 .36378 L .59831 .36308 L F
.529 .464 .727 r
.47128 .53145 m .47206 .53453 L .46967 .53734 L F
.329 .24 .601 r
.47206 .53453 m .4703 .53848 L .46967 .53734 L F
.57 .82 .992 r
.55937 .39364 m .55485 .39307 L .55737 .391 L F
.657 .722 .897 r
.56169 .39237 m .55937 .39364 L .55737 .391 L F
.383 .086 .331 r
.33216 .69175 m .32984 .69346 L .33221 .69299 L F
.929 .937 .582 r
.34559 .67616 m .34464 .6802 L .34414 .67856 L F
0 0 0 r
.43137 .58981 m .43183 .58996 L .43403 .5899 L F
.43137 .58981 m .42909 .59146 L .43183 .58996 L F
.303 0 0 r
.32055 .6274 m .32506 .6255 L .32492 .62783 L F
0 0 .49 r
.6043 .40504 m .60456 .40702 L .60562 .40894 L F
0 0 .42 r
.22703 .56291 m .22777 .56447 L .226 .56114 L F
.803 .344 0 r
.22703 .56291 m .22946 .5665 L .22777 .56447 L F
.061 .11 .6 r
.22946 .5665 m .22859 .56767 L .22777 .56447 L F
.882 .888 .832 r
.35448 .56108 m .35196 .56438 L .35101 .56259 L F
0 0 .364 r
.35196 .56438 m .35308 .565 L .35101 .56259 L F
.35196 .56438 m .35216 .56719 L .35308 .565 L F
.605 .373 .538 r
.56017 .4289 m .56387 .42862 L .56387 .42606 L F
.786 .521 .536 r
.56387 .42606 m .56387 .42862 L .56721 .42886 L F
0 0 0 r
.60286 .45783 m .60093 .46154 L .60198 .45973 L F
.421 .687 .973 r
.60093 .46154 m .60341 .46144 L .60198 .45973 L F
.849 .395 .114 r
.37913 .51908 m .38078 .52194 L .38265 .52259 L F
.866 .436 .015 r
.38078 .52194 m .38299 .52501 L .38265 .52259 L F
.428 .352 .668 r
.67768 .3512 m .67816 .35309 L .68004 .35068 L F
.498 .274 .505 r
.35448 .56108 m .35708 .56056 L .3573 .55793 L F
.312 .122 .454 r
.3573 .55793 m .35708 .56056 L .35923 .55685 L F
.42 0 0 r
.38541 .66171 m .38529 .6622 L .38639 .66308 L F
.38541 .66171 m .38216 .66251 L .38529 .6622 L F
.596 .272 .391 r
.24117 .58308 m .23663 .58522 L .23881 .58366 L F
.492 .325 .582 r
.24106 .58034 m .24117 .58308 L .23881 .58366 L F
0 0 0 r
.24021 .59009 m .23783 .59332 L .23913 .59166 L F
.707 .3 .273 r
.24105 .59221 m .24021 .59009 L .23913 .59166 L F
.991 .869 .611 r
.4107 .55184 m .40891 .55271 L .40939 .55007 L F
.4107 .55184 m .40994 .55432 L .40891 .55271 L F
0 0 .422 r
.69902 .30206 m .70079 .3061 L .69972 .30411 L F
.689 .324 .35 r
.2344 .60758 m .23378 .60427 L .23155 .60814 L F
.704 .59 .726 r
.29521 .64153 m .29542 .643 L .29714 .63767 L F
.86 .842 .826 r
.29508 .64459 m .29198 .64686 L .29179 .64596 L F
.29281 .64556 m .29043 .64653 L .29287 .64596 L F
.29508 .64459 m .29043 .64653 L .29498 .64467 L F
.29508 .64459 m .29347 .64718 L .29198 .64686 L F
.488 .31 .566 r
.29287 .64596 m .29043 .64653 L .2902 .64382 L F
.638 .088 0 r
.29298 .64668 m .29287 .64596 L .2921 .64526 L F
.29332 .64724 m .29287 .64596 L .29298 .64668 L F
.86 .842 .826 r
.29498 .64467 m .29281 .64556 L .29287 .64596 L F
.29521 .64453 m .29512 .64468 L .29508 .64459 L F
.29521 .64453 m .29508 .64459 L .29507 .6446 L F
.29521 .64453 m .29507 .6446 L .2951 .64459 L F
.29512 .64468 m .29347 .64718 L .29508 .64459 L F
.145 .661 .891 r
.2951 .64459 m .29507 .6446 L .29504 .64472 L F
.87 .608 .54 r
.29505 .64462 m .29504 .64472 L .29507 .6446 L F
.29505 .64462 m .2951 .64459 L .29504 .64472 L F
.2951 .64459 m .29521 .64453 L .29504 .64472 L F
.145 .661 .891 r
.29598 .6444 m .2951 .64459 L .29504 .64472 L F
.86 .842 .826 r
.29521 .64453 m .2951 .64459 L .29513 .64458 L F
.87 .608 .54 r
.29505 .64453 m .29505 .64462 L .29507 .64458 L F
.29505 .64462 m .29507 .6446 L .29507 .64458 L F
.29521 .64153 m .29505 .64453 L .29542 .643 L F
.29505 .64453 m .29507 .64458 L .29542 .643 L F
.29521 .64153 m .29521 .64453 L .29505 .64462 L F
.145 .661 .891 r
.30012 .64297 m .29542 .643 L .29507 .6446 L F
.30012 .64297 m .29507 .6446 L .29598 .6444 L F
.86 .842 .826 r
.29513 .64458 m .29507 .6446 L .29498 .64467 L F
.488 .31 .566 r
.29287 .64596 m .29158 .64493 L .29126 .64229 L F
.29158 .64493 m .2902 .64382 L .29109 .64253 L F
.29158 .64493 m .29109 .64253 L .29126 .64229 L F
.86 .842 .826 r
.29179 .64596 m .29198 .64686 L .29043 .64653 L F
.569 .396 .608 r
.29542 .643 m .30242 .63638 L .29714 .63767 L F
.548 .529 .786 r
.35915 .58576 m .36002 .58958 L .35753 .59009 L F
.386 .168 .457 r
.22714 .57713 m .22673 .57976 L .22459 .58012 L F
0 0 .566 r
.22622 .5822 m .22459 .58012 L .22673 .57976 L F
.629 .603 .805 r
.426 .51107 m .42362 .5094 L .42626 .50892 L F
.512 .825 1 r
.3483 .70053 m .34939 .69923 L .34677 .69936 L F
.3483 .70053 m .3507 .69992 L .34939 .69923 L F
.456 .478 .793 r
.4727 .54047 m .47176 .54476 L .47104 .54113 L F
.4727 .54047 m .47341 .54394 L .47176 .54476 L F
.224 .135 .538 r
.47361 .54819 m .47176 .54476 L .47341 .54394 L F
.47361 .54819 m .47212 .54755 L .47176 .54476 L F
.571 .272 .421 r
.31416 .55712 m .31842 .5538 L .31657 .55507 L F
.902 .955 .823 r
.43676 .52345 m .43958 .52247 L .43805 .52108 L F
0 .032 .544 r
.25989 .55102 m .26107 .55091 L .25798 .5511 L F
.413 .306 .623 r
.34047 .56049 m .33817 .56161 L .33982 .5575 L F
.573 .53 .77 r
.33817 .56161 m .34151 .56253 L .34047 .56049 L F
.189 0 .3 r
.33911 .56246 m .33817 .56161 L .33958 .56092 L F
.413 .306 .623 r
.34047 .56049 m .33817 .56161 L .33982 .5575 L F
0 .111 .659 r
.33687 .55801 m .33743 .5597 L .33901 .56032 L F
.33787 .56103 m .33874 .56367 L .3389 .5617 L F
.758 .938 .596 r
.33874 .56365 m .33848 .56291 L .33901 .56032 L F
.664 .568 .737 r
.34367 .56335 m .33975 .56468 L .34151 .56253 L F
.34367 .56335 m .3447 .56747 L .33975 .56468 L F
.094 0 .41 r
.33848 .56291 m .34068 .56477 L .3416 .56346 L F
.541 0 0 r
.34151 .56253 m .33953 .56285 L .34367 .56335 L F
.786 .518 .532 r
.34367 .56335 m .34047 .56049 L .34151 .56253 L F
.34367 .56335 m .33953 .56285 L .34047 .56049 L F
.094 0 .41 r
.34071 .56288 m .3416 .56346 L .34203 .56287 L F
.33848 .56291 m .3416 .56346 L .34071 .56288 L F
0 .111 .659 r
.33743 .5597 m .33787 .56103 L .33901 .56032 L F
.33787 .56103 m .3389 .5617 L .33901 .56032 L F
.372 .406 .767 r
.33848 .56291 m .33949 .56051 L .33901 .56032 L F
.33949 .56051 m .34008 .55912 L .33901 .56032 L F
.34008 .55912 m .34002 .55899 L .33901 .56032 L F
0 0 .15 r
.33944 .55787 m .33901 .56032 L .34002 .55899 L F
.33998 .55836 m .34002 .55899 L .34029 .55863 L F
.33944 .55787 m .34002 .55899 L .33998 .55836 L F
.189 0 .3 r
.33953 .56285 m .33911 .56246 L .34047 .56049 L F
.33911 .56246 m .33958 .56092 L .34047 .56049 L F
.372 .406 .767 r
.33848 .56291 m .34203 .56287 L .34068 .55959 L F
.724 .272 .176 r
.34259 .56046 m .34058 .55951 L .34029 .55863 L F
.372 .406 .767 r
.34008 .55912 m .34058 .55951 L .34029 .55863 L F
.34008 .55912 m .34029 .55863 L .34002 .55899 L F
.724 .272 .176 r
.34058 .55951 m .3393 .55891 L .34029 .55863 L F
.372 .406 .767 r
.34058 .55951 m .34068 .55959 L .34029 .55863 L F
.33848 .56291 m .34068 .55959 L .34008 .55912 L F
.724 .272 .176 r
.34058 .55951 m .34092 .56086 L .34018 .55932 L F
.34259 .56046 m .34068 .55959 L .34058 .55951 L F
.662 .568 .738 r
.34029 .55863 m .34068 .55959 L .34259 .56046 L F
.34068 .55959 m .34203 .56287 L .34259 .56046 L F
.724 .272 .176 r
.34259 .56046 m .34198 .56061 L .34068 .55959 L F
.34198 .56061 m .34092 .56086 L .34058 .55951 L F
.34004 .55925 m .33984 .56112 L .3393 .55891 L F
.34018 .55932 m .34007 .55988 L .34004 .55925 L F
.34007 .55988 m .33984 .56112 L .34004 .55925 L F
.34092 .56086 m .33984 .56112 L .34018 .55932 L F
.758 .938 .596 r
.33874 .56367 m .33874 .56366 L .33874 .56365 L F
.63 .635 .836 r
.33432 .55863 m .33874 .56367 L .33687 .55801 L F
.758 .938 .596 r
.33874 .56366 m .33848 .56291 L .33874 .56365 L F
.542 .374 .603 r
.3231 .66574 m .3258 .66472 L .32497 .66298 L F
.795 .979 .7 r
.34458 .6492 m .34656 .648 L .34393 .65119 L F
.516 .302 .527 r
.34393 .65119 m .34656 .648 L .34625 .65096 L F
.683 .641 .802 r
.34843 .64481 m .35063 .6485 L .34656 .648 L F
.654 .604 .786 r
.34843 .64481 m .3498 .64707 L .34656 .648 L F
.738 .531 .613 r
.35063 .6485 m .34625 .65096 L .34656 .648 L F
.35063 .6485 m .35062 .65194 L .34625 .65096 L F
.51 0 0 r
.34625 .65096 m .35062 .65194 L .34836 .65223 L F
.453 .106 .286 r
.34594 .65256 m .34625 .65096 L .34836 .65223 L F
.489 .34 .605 r
.34661 .64898 m .34755 .65216 L .3484 .65095 L F
.34661 .64898 m .34774 .65151 L .34676 .64969 L F
.06 0 0 r
.34661 .64898 m .34642 .64809 L .34458 .6492 L F
.745 .984 .906 r
.34458 .6492 m .34393 .65119 L .34261 .65091 L F
.446 .1 .284 r
.34393 .65119 m .34594 .65256 L .34323 .65281 L F
.34393 .65119 m .34625 .65096 L .34594 .65256 L F
.999 .814 .525 r
.34261 .65091 m .34393 .65119 L .34323 .65281 L F
.72 .474 .554 r
.34331 .65212 m .34661 .64898 L .34458 .6492 L F
.34331 .65212 m .34755 .65216 L .34661 .64898 L F
.489 .34 .605 r
.34661 .64898 m .34676 .64969 L .34581 .64792 L F
.06 0 0 r
.34661 .64898 m .34656 .648 L .34642 .64809 L F
.34661 .64898 m .3498 .64707 L .34656 .648 L F
.914 .977 .705 r
.69421 .3702 m .6955 .36864 L .69575 .36586 L F
.745 .255 0 r
.38179 .67736 m .37843 .67334 L .38035 .67612 L F
.759 .319 .205 r
.37843 .67334 m .3823 .67429 L .38035 .67612 L F
.169 0 0 r
.3823 .67429 m .38174 .67421 L .38035 .67612 L F
.781 .63 .693 r
.38179 .67736 m .38519 .67496 L .3823 .67429 L F
.169 0 0 r
.3823 .67429 m .38519 .67496 L .38174 .67421 L F
.041 .23 .731 r
.3287 .53944 m .33078 .54027 L .32918 .53814 L F
.877 .597 .511 r
.33039 .54189 m .33078 .54027 L .3287 .53944 L F
.791 .819 .874 r
.4949 .43824 m .4912 .43818 L .4942 .43583 L F
.755 .825 .906 r
.49632 .43419 m .4949 .43824 L .4942 .43583 L F
.49632 .43419 m .49805 .43588 L .4949 .43824 L F
0 0 0 r
.24871 .61078 m .2473 .61233 L .24728 .61232 L F
0 0 .168 r
.24725 .61231 m .24728 .61232 L .24736 .61288 L F
.962 .638 .353 r
.24602 .61375 m .24736 .61288 L .24728 .61232 L F
0 0 0 r
.2473 .61233 m .24602 .61375 L .24728 .61232 L F
0 0 .168 r
.24667 .60936 m .24728 .61232 L .24725 .61231 L F
.962 .638 .353 r
.24602 .61375 m .24797 .61562 L .24736 .61288 L F
.073 0 .199 r
.37121 .53179 m .37034 .5346 L .36848 .53507 L F
.502 .443 .723 r
.3688 .5376 m .36848 .53507 L .36688 .53634 L F
.3688 .5376 m .37034 .5346 L .36848 .53507 L F
.766 .474 .491 r
.29897 .66116 m .30004 .66528 L .295 .66301 L F
.733 .98 .753 r
.29897 .66116 m .30217 .65809 L .29982 .65935 L F
.221 .459 .875 r
.29982 .65935 m .30236 .66323 L .29897 .66116 L F
.818 .349 .097 r
.30227 .66403 m .29897 .66116 L .30236 .66323 L F
.617 .893 .988 r
.39945 .47699 m .39689 .47787 L .39789 .47605 L F
.221 0 0 r
.39689 .47787 m .39847 .47835 L .39789 .47605 L F
.39689 .47787 m .39556 .47946 L .39847 .47835 L F
.819 .346 .08 r
.37929 .49897 m .38132 .49982 L .37929 .49908 L F
.9 .731 .664 r
.35285 .63458 m .35436 .63866 L .35354 .63861 L F
.903 .534 .324 r
.35436 .63866 m .34984 .6384 L .35354 .63861 L F
.35436 .63866 m .35246 .6387 L .34984 .6384 L F
.35436 .63866 m .35467 .64083 L .35246 .6387 L F
.728 .657 .778 r
.35534 .63472 m .35436 .63866 L .35285 .63458 L F
.35671 .63479 m .35621 .63561 L .35534 .63472 L F
.35621 .63561 m .35436 .63866 L .35534 .63472 L F
0 0 .161 r
.35285 .63458 m .35434 .63622 L .35671 .63479 L F
.35285 .63458 m .35381 .63192 L .35434 .63622 L F
.9 .598 .466 r
.35091 .63332 m .35434 .63622 L .35398 .63331 L F
.35301 .6323 m .35398 .63331 L .35381 .63192 L F
.35091 .63332 m .35398 .63331 L .35301 .6323 L F
.656 .615 .797 r
.3289 .63139 m .32793 .63478 L .32932 .63327 L F
.543 .588 .85 r
.72107 .33346 m .72442 .33675 L .72355 .33407 L F
.577 .583 .822 r
.72442 .33675 m .7261 .33132 L .72355 .33407 L F
.72442 .33675 m .72737 .33486 L .7261 .33132 L F
.872 .444 .029 r
.39 .53998 m .39018 .53808 L .38888 .5368 L F
.39 .53998 m .39256 .54241 L .39018 .53808 L F
.862 .539 .438 r
.39018 .53808 m .39256 .54241 L .39241 .54095 L F
.449 .865 .949 r
.44471 .51745 m .44064 .51781 L .44231 .51824 L F
.787 .894 .92 r
.37731 .7021 m .37919 .70313 L .37994 .70166 L F
.699 .865 .961 r
.6166 .34885 m .61283 .34878 L .61529 .34745 L F
.739 .972 .929 r
.6189 .3471 m .6166 .34885 L .6179 .34644 L F
.619 .831 .982 r
.6179 .34644 m .6166 .34885 L .61529 .34745 L F
.228 0 0 r
.34163 .65466 m .3373 .65596 L .33985 .65577 L F
.691 .96 .716 r
.34167 .65393 m .34163 .65466 L .34323 .65281 L F
.982 .694 .357 r
.59539 .41577 m .59559 .41319 L .59445 .41312 L F
.523 0 0 r
.3747 .51678 m .37738 .51843 L .37913 .51908 L F
.633 .224 0 r
.37971 .5202 m .37913 .51908 L .37738 .51843 L F
.37971 .5202 m .38078 .52194 L .37913 .51908 L F
0 0 .547 r
.59174 .40506 m .59227 .40667 L .59043 .40317 L F
.753 .353 0 r
.59232 .40751 m .59227 .40667 L .59174 .40506 L F
.59232 .40751 m .59324 .40874 L .59227 .40667 L F
.685 .778 .922 r
.45683 .45335 m .45632 .45594 L .45535 .45438 L F
.45683 .45335 m .45875 .45495 L .45632 .45594 L F
0 0 .055 r
.38471 .58704 m .38412 .58968 L .38509 .58803 L F
.38471 .58704 m .38509 .58803 L .38217 .58551 L F
.606 .915 .656 r
.64963 .33005 m .65113 .32826 L .65157 .32828 L F
.64963 .33005 m .64827 .33086 L .65113 .32826 L F
.705 .759 .894 r
.4162 .47688 m .4123 .47524 L .41517 .47637 L F
.578 .725 .943 r
.3513 .64603 m .35063 .6485 L .34843 .64481 L F
.3513 .64603 m .35192 .64813 L .35063 .6485 L F
.546 .909 .961 r
.61118 .37559 m .61563 .37473 L .61454 .37364 L F
.877 .934 .854 r
.61563 .37473 m .6173 .37048 L .61454 .37364 L F
.61563 .37473 m .61825 .37179 L .6173 .37048 L F
.515 .289 .51 r
.23758 .59512 m .2398 .59541 L .23783 .59332 L F
.763 .63 .714 r
.34258 .60231 m .34031 .60606 L .3405 .60324 L F
.266 .014 .333 r
.34569 .59941 m .34505 .6019 L .34258 .60231 L F
.313 .17 .52 r
.34505 .6019 m .34515 .60443 L .34258 .60231 L F
.266 .014 .333 r
.34569 .59941 m .34505 .6019 L .34258 .60231 L F
.313 .17 .52 r
.34505 .6019 m .34515 .60443 L .34258 .60231 L F
0 0 .4 r
.35892 .60978 m .35878 .61312 L .35974 .61156 L F
.057 0 0 r
.40126 .48856 m .40446 .48618 L .40188 .48701 L F
.419 .17 .427 r
.26756 .63413 m .26887 .63433 L .26854 .63197 L F
.147 0 .403 r
.26854 .63197 m .26887 .63433 L .27046 .63338 L F
.627 .413 .572 r
.44083 .52837 m .44359 .5254 L .44076 .52536 L F
.732 .867 .944 r
.45013 .45515 m .4493 .45808 L .44767 .45667 L F
.45013 .45515 m .45181 .45664 L .4493 .45808 L F
0 0 0 r
.22882 .5386 m .23023 .53713 L .23128 .53502 L F
0 0 .138 r
.22882 .5386 m .22922 .53952 L .23023 .53713 L F
.22888 .54006 m .22895 .54144 L .22922 .53952 L F
.838 .911 .507 r
.22895 .54144 m .22759 .54316 L .22922 .53952 L F
0 0 0 r
.228 .54218 m .22942 .53918 L .22922 .53952 L F
.22942 .53918 m .23004 .53788 L .22922 .53952 L F
0 0 .138 r
.22882 .5386 m .22888 .54006 L .22922 .53952 L F
.741 .693 .805 r
.51258 .42607 m .51363 .42913 L .50945 .42871 L F
.502 .441 .721 r
.42579 .50619 m .42626 .50892 L .42362 .5094 L F
.283 0 0 r
.24797 .61562 m .25038 .61609 L .25224 .61613 L F
.168 0 0 r
.25038 .61609 m .25473 .61692 L .25224 .61613 L F
.447 .661 .953 r
.2895 .63195 m .28521 .62972 L .28895 .63063 L F
.755 .24 0 r
.28964 .63362 m .2895 .63195 L .28895 .63063 L F
.28964 .63362 m .29156 .63452 L .2895 .63195 L F
0 .088 .647 r
.33985 .52235 m .34051 .52151 L .33903 .52041 L F
.33985 .52235 m .34179 .52459 L .34051 .52151 L F
.755 .848 .921 r
.32596 .59108 m .32485 .59315 L .32803 .59248 L F
.368 .736 .989 r
.32803 .59248 m .32818 .59047 L .32596 .59108 L F
.32803 .59248 m .33036 .5923 L .32818 .59047 L F
.482 .411 .7 r
.32803 .59248 m .33015 .59324 L .33036 .5923 L F
0 .024 .589 r
.32508 .64183 m .3263 .64251 L .32626 .64009 L F
.32508 .64183 m .32682 .64395 L .3263 .64251 L F
.059 .186 .683 r
.32508 .64183 m .32635 .64477 L .32682 .64395 L F
.426 .446 .777 r
.46049 .55426 m .46274 .55385 L .4595 .55173 L F
.996 .85 .508 r
.46274 .55724 m .46274 .55385 L .46049 .55426 L F
.475 .812 .999 r
.24068 .61356 m .23998 .61429 L .24218 .61374 L F
.178 .348 .797 r
.23737 .61264 m .23881 .61552 L .23998 .61429 L F
.423 0 0 r
.23737 .61264 m .23998 .61429 L .23801 .61324 L F
.475 .812 .999 r
.23801 .61324 m .23998 .61429 L .24068 .61356 L F
.178 .348 .797 r
.23881 .61552 m .23894 .61578 L .23998 .61429 L F
0 0 .319 r
.23894 .61578 m .23981 .61721 L .23998 .61429 L F
.23894 .61578 m .2396 .6186 L .23981 .61721 L F
0 0 0 r
.30354 .65661 m .30217 .65809 L .30476 .65468 L F
.631 .945 .733 r
.29982 .65935 m .30217 .65809 L .30354 .65661 L F
.638 .684 .877 r
.39468 .48309 m .39796 .48455 L .3967 .48248 L F
.751 .97 .929 r
.3992 .48227 m .39796 .48455 L .40008 .48309 L F
.438 .583 .9 r
.3967 .48248 m .39796 .48455 L .3992 .48227 L F
.52 .61 .883 r
.35448 .56108 m .35011 .55805 L .3552 .56003 L F
0 0 .31 r
.35485 .55358 m .35507 .55574 L .3552 .56003 L F
.392 0 0 r
.3552 .56003 m .35708 .56056 L .35522 .56093 L F
.3552 .56003 m .35554 .56042 L .35708 .56056 L F
0 0 .31 r
.35507 .55574 m .35554 .56042 L .3552 .56003 L F
.392 0 0 r
.3552 .56003 m .35522 .56093 L .35448 .56108 L F
.81 .608 .63 r
.37698 .66405 m .37661 .66888 L .37597 .66768 L F
.465 .259 .515 r
.37698 .66405 m .37961 .66567 L .37966 .66474 L F
.37698 .66405 m .37597 .66768 L .37961 .66567 L F
.787 .997 .857 r
.62821 .42412 m .62708 .4265 L .6289 .42488 L F
.761 .974 .922 r
.62821 .42412 m .62464 .42659 L .62708 .4265 L F
.849 .975 .669 r
.33584 .56885 m .33708 .56615 L .33758 .56619 L F
.657 .568 .743 r
.34219 .56977 m .33758 .56619 L .33975 .56468 L F
.626 .96 .89 r
.63317 .33977 m .63715 .33832 L .63517 .33988 L F
.963 .837 .671 r
.39837 .66593 m .4003 .66643 L .39929 .66332 L F
.968 .816 .639 r
.39901 .67054 m .4003 .66643 L .39837 .66593 L F
0 0 .336 r
.31633 .64365 m .31545 .64078 L .31654 .64041 L F
.31633 .64365 m .31562 .64432 L .31545 .64078 L F
.329 .24 .601 r
.47206 .53453 m .47232 .53825 L .4703 .53848 L F
.336 .287 .655 r
.47232 .53825 m .4727 .54047 L .4703 .53848 L F
.31 .287 .671 r
.4703 .53848 m .4727 .54047 L .47104 .54113 L F
.197 .053 .448 r
.21666 .56108 m .2188 .56 L .21888 .55714 L F
.032 0 .27 r
.21636 .56371 m .2188 .56 L .21666 .56108 L F
.894 .479 .196 r
.42828 .50315 m .4289 .50538 L .42716 .50448 L F
.787 .405 .331 r
.42954 .50397 m .4289 .50538 L .42828 .50315 L F
.999 .81 .466 r
.41497 .48905 m .41577 .48698 L .41362 .48587 L F
.41497 .48905 m .41535 .4897 L .41577 .48698 L F
.799 .848 .888 r
.41362 .48587 m .41577 .48698 L .418 .48547 L F
.408 .829 .657 r
.41535 .4897 m .41873 .48772 L .41577 .48698 L F
.658 .861 .977 r
.33811 .50321 m .34134 .50327 L .34019 .50195 L F
.33811 .50321 m .34134 .50327 L .34019 .50195 L F
0 .403 .821 r
.34134 .50327 m .34294 .50332 L .34019 .50195 L F
.34134 .50327 m .3446 .50471 L .34294 .50332 L F
.532 .584 .852 r
.34167 .50583 m .3446 .50471 L .34134 .50327 L F
.494 .358 .625 r
.24393 .60825 m .24431 .61018 L .24667 .60936 L F
.24393 .60825 m .24431 .61018 L .24667 .60936 L F
.516 .54 .819 r
.38663 .4933 m .38896 .49274 L .38752 .48894 L F
.548 .126 .192 r
.30258 .56238 m .30506 .56269 L .30729 .55977 L F
.462 .099 .264 r
.30506 .56269 m .3093 .55945 L .30729 .55977 L F
.832 .892 .884 r
.63569 .35599 m .63613 .35306 L .63415 .35686 L F
.63569 .35599 m .6375 .35453 L .63613 .35306 L F
.289 0 .092 r
.27507 .57287 m .27912 .56945 L .27622 .57105 L F
.27507 .57287 m .27743 .5723 L .27912 .56945 L F
.052 0 0 r
.27912 .56945 m .28037 .56979 L .282 .5674 L F
.042 0 0 r
.27912 .56945 m .27743 .5723 L .28037 .56979 L F
.906 .592 .44 r
.70406 .27403 m .70714 .27738 L .70795 .27489 L F
.70406 .27403 m .70438 .27659 L .70714 .27738 L F
.915 .911 .802 r
.70368 .27909 m .70714 .27738 L .70438 .27659 L F
.70368 .27909 m .70491 .28038 L .70714 .27738 L F
.811 .998 .786 r
.69098 .37271 m .69269 .37218 L .69421 .3702 L F
.43 .074 .257 r
.30826 .56422 m .30698 .56687 L .30446 .56722 L F
.248 0 .164 r
.30915 .56606 m .30826 .56422 L .31038 .56302 L F
.30915 .56606 m .30698 .56687 L .30826 .56422 L F
.892 .782 .734 r
.43071 .52833 m .43196 .53203 L .43187 .52903 L F
.374 .37 .727 r
.43187 .52903 m .43196 .53203 L .43369 .53064 L F
.626 .891 .988 r
.43269 .53007 m .43196 .53203 L .43369 .53064 L F
.982 .707 .421 r
.43369 .53064 m .43269 .53007 L .43196 .53203 L F
.865 .895 .854 r
.63613 .35306 m .6375 .35453 L .64014 .35153 L F
0 0 0 r
.23128 .53502 m .23265 .53425 L .23445 .53267 L F
.23128 .53502 m .23023 .53713 L .23265 .53425 L F
.585 .921 .705 r
.65561 .33905 m .65533 .33988 L .65729 .33811 L F
.65561 .33905 m .65381 .34062 L .65533 .33988 L F
.963 .762 .319 r
.39895 .58518 m .39981 .5836 L .39864 .58103 L F
.39895 .58518 m .39964 .58629 L .39981 .5836 L F
.487 .465 .759 r
.33101 .68625 m .33216 .69175 L .33423 .68848 L F
0 0 .318 r
.33423 .68848 m .33216 .69175 L .33221 .69299 L F
.607 .71 .917 r
.33397 .56244 m .33085 .56295 L .33322 .56255 L F
.513 .658 .925 r
.33085 .56295 m .33162 .56428 L .33322 .56255 L F
.491 .622 .908 r
.33162 .56428 m .33372 .56375 L .33322 .56255 L F
0 .563 .715 r
.33926 .49476 m .33638 .49467 L .33451 .49459 L F
.002 0 0 r
.25926 .52292 m .25904 .52186 L .26142 .5218 L F
.802 .865 .896 r
.36076 .6911 m .36244 .69229 L .35917 .69213 L F
.331 .701 .982 r
.36394 .69111 m .36244 .69229 L .36076 .6911 L F
.65 .397 .524 r
.27642 .54435 m .27613 .54764 L .27365 .54704 L F
.27712 .54367 m .27697 .5443 L .27642 .54435 L F
.27697 .5443 m .27613 .54764 L .27642 .54435 L F
.27737 .54373 m .27613 .54764 L .27712 .54367 L F
.292 0 .015 r
.28048 .5449 m .27613 .54764 L .27751 .5433 L F
.661 .651 .829 r
.28191 .54215 m .28048 .5449 L .27884 .54118 L F
0 0 0 r
.28138 .54405 m .281 .5439 L .28191 .54215 L F
.661 .651 .829 r
.28191 .54215 m .27884 .54118 L .28297 .54162 L F
.359 .501 .864 r
.27893 .5441 m .28131 .54402 L .27952 .53963 L F
.087 0 .172 r
.2836 .54246 m .28276 .54304 L .28191 .54215 L F
.556 .607 .859 r
.28186 .54368 m .28204 .544 L .2836 .54246 L F
.087 0 .172 r
.28283 .54311 m .28144 .54384 L .28191 .54215 L F
.867 .858 .83 r
.28174 .54402 m .2836 .54246 L .28204 .544 L F
.087 0 .172 r
.28296 .54325 m .28239 .54347 L .28283 .54311 L F
.28239 .54347 m .28144 .54384 L .28283 .54311 L F
.012 .09 .6 r
.28206 .54032 m .28191 .54215 L .28297 .54162 L F
.28206 .54032 m .2836 .54246 L .28191 .54215 L F
.556 .607 .859 r
.27952 .53963 m .28186 .54368 L .2836 .54246 L F
.359 .501 .864 r
.28131 .54402 m .28204 .544 L .28186 .54368 L F
.28131 .54402 m .28186 .54368 L .28144 .54384 L F
.087 0 .172 r
.28296 .54325 m .2823 .54408 L .28144 .54384 L F
.2823 .54408 m .28089 .54584 L .28138 .54405 L F
.199 .728 .78 r
.28138 .54405 m .28204 .544 L .28131 .54402 L F
.2816 .54406 m .28204 .544 L .28138 .54405 L F
.087 0 .172 r
.2823 .54408 m .28138 .54405 L .28144 .54384 L F
.199 .728 .78 r
.28145 .54408 m .2816 .54406 L .28138 .54405 L F
.359 .501 .864 r
.28144 .54384 m .28186 .54368 L .28172 .54344 L F
.28131 .54402 m .28172 .54344 L .27952 .53963 L F
.199 .728 .78 r
.28145 .54408 m .28131 .54402 L .27907 .5441 L F
.867 .858 .83 r
.27933 .54422 m .2836 .54246 L .28174 .54402 L F
.087 0 .172 r
.2836 .54246 m .28296 .54325 L .28276 .54304 L F
0 0 0 r
.28096 .54452 m .28048 .5449 L .281 .5439 L F
.28089 .54584 m .28056 .54509 L .28096 .54452 L F
.28056 .54509 m .28048 .5449 L .28096 .54452 L F
.28098 .54428 m .281 .5439 L .28137 .54411 L F
.199 .728 .78 r
.2781 .54435 m .28145 .54408 L .27907 .5441 L F
.27667 .54472 m .27889 .54442 L .2781 .54435 L F
.27889 .54442 m .28145 .54408 L .2781 .54435 L F
.292 0 .015 r
.28048 .5449 m .27902 .54702 L .27613 .54764 L F
0 0 0 r
.28089 .54584 m .27902 .54702 L .28048 .5449 L F
.199 .728 .78 r
.27667 .54472 m .27933 .54422 L .28154 .54404 L F
.28145 .54408 m .28154 .54404 L .28204 .544 L F
.27667 .54472 m .28154 .54404 L .28145 .54408 L F
0 0 0 r
.28137 .54411 m .281 .5439 L .28138 .54405 L F
.28089 .54584 m .28098 .54428 L .28137 .54411 L F
.867 .858 .83 r
.27933 .54422 m .28089 .54584 L .2836 .54246 L F
.079 .154 .641 r
.28124 .54512 m .28065 .54559 L .27958 .54448 L F
.27995 .54452 m .27958 .54448 L .27933 .54422 L F
.28124 .54512 m .27958 .54448 L .27995 .54452 L F
.165 0 0 r
.27933 .54422 m .27942 .54559 L .28124 .54512 L F
0 .394 .827 r
.28186 .54462 m .28124 .54512 L .27942 .54559 L F
.28187 .54462 m .28124 .54512 L .28186 .54462 L F
.079 .154 .641 r
.28124 .54512 m .28089 .54584 L .28065 .54559 L F
.199 .728 .78 r
.27888 .54412 m .27907 .5441 L .27893 .5441 L F
.27667 .54472 m .27907 .5441 L .27888 .54412 L F
.411 0 0 r
.27467 .54381 m .27667 .54472 L .27888 .54412 L F
.27879 .54409 m .27888 .54412 L .27893 .5441 L F
.27467 .54381 m .27888 .54412 L .27879 .54409 L F
.65 .397 .524 r
.27751 .5433 m .27737 .54373 L .27712 .54367 L F
.023 0 0 r
.44833 .51569 m .44747 .51664 L .44471 .51745 L F
.487 .137 .299 r
.44986 .51515 m .44747 .51664 L .44833 .51569 L F
.032 0 .096 r
.37562 .58589 m .37641 .58385 L .3782 .58278 L F
.744 .81 .904 r
.34695 .51752 m .34319 .51891 L .34831 .51916 L F
.514 .718 .965 r
.34695 .51752 m .34831 .51916 L .34989 .51769 L F
.669 .944 .961 r
.67101 .38387 m .67249 .38169 L .66989 .38277 L F
.67101 .38387 m .67342 .38259 L .67249 .38169 L F
.667 .428 .55 r
.3258 .66472 m .32789 .66309 L .32497 .66298 L F
.891 .982 .812 r
.34484 .68038 m .34438 .68339 L .34692 .68014 L F
.908 .96 .631 r
.34245 .68517 m .34438 .68339 L .34484 .68038 L F
.554 .648 .897 r
.21811 .59609 m .21819 .59231 L .21629 .59253 L F
.21811 .59609 m .2207 .59557 L .21819 .59231 L F
.274 .779 .816 r
.32122 .55636 m .31929 .557 L .32242 .55417 L F
.422 .79 .995 r
.32125 .55325 m .32343 .55282 L .32242 .55417 L F
.274 0 .07 r
.3236 .5557 m .32242 .55417 L .32343 .55282 L F
.3236 .5557 m .32122 .55636 L .32242 .55417 L F
.529 .608 .876 r
.6276 .40016 m .62386 .39741 L .62641 .3967 L F
.798 .547 .558 r
.62395 .40221 m .6276 .40016 L .62685 .39934 L F
.62395 .40221 m .62787 .40281 L .6276 .40016 L F
.896 .565 .075 r
.6267 .3984 m .62723 .39907 L .62641 .3967 L F
.695 .881 .967 r
.62495 .39506 m .62641 .3967 L .62386 .39741 L F
.896 .565 .075 r
.62685 .39934 m .62723 .39907 L .6267 .3984 L F
.62685 .39934 m .62641 .3967 L .62912 .39565 L F
.891 .841 .789 r
.62566 .39712 m .62912 .39565 L .62768 .39481 L F
.62523 .39762 m .62582 .39732 L .62566 .39712 L F
.62582 .39732 m .62912 .39565 L .62566 .39712 L F
.896 .565 .075 r
.62685 .39934 m .6276 .40016 L .62723 .39907 L F
0 .056 .594 r
.39416 .51692 m .39514 .51785 L .39266 .51482 L F
.533 .399 .644 r
.47599 .50618 m .47366 .50943 L .4733 .50672 L F
.384 .593 .928 r
.23091 .61032 m .23155 .60814 L .23 .60845 L F
.23091 .61032 m .23407 .61084 L .23155 .60814 L F
.651 .605 .789 r
.4045 .47756 m .40796 .48301 L .40603 .47934 L F
.708 .726 .864 r
.40603 .47934 m .40796 .48301 L .40994 .48023 L F
.481 .411 .7 r
.40796 .48301 m .41032 .48319 L .40994 .48023 L F
.553 .268 .437 r
.40725 .4855 m .41032 .48319 L .40796 .48301 L F
.868 .953 .864 r
.42122 .59219 m .42468 .59032 L .42322 .58918 L F
.659 .754 .268 r
.42552 .57761 m .42528 .57818 L .42628 .57589 L F
.152 0 0 r
.35049 .54675 m .35245 .54649 L .35426 .54492 L F
.502 .001 0 r
.35245 .54649 m .35643 .54661 L .35426 .54492 L F
.44 .604 .916 r
.35348 .54431 m .35453 .54622 L .35245 .54649 L F
.368 0 0 r
.35245 .54649 m .35487 .54684 L .35643 .54661 L F
.44 .604 .916 r
.35453 .54622 m .35487 .54684 L .35245 .54649 L F
.152 0 0 r
.34998 .547 m .35245 .54649 L .35049 .54675 L F
.598 .559 .782 r
.353 .54116 m .35426 .54492 L .35675 .54407 L F
.379 .051 .278 r
.35426 .54492 m .35643 .54661 L .35675 .54407 L F
.662 .661 .838 r
.56732 .41619 m .57054 .41832 L .57004 .41554 L F
.69 .674 .829 r
.57054 .41832 m .57418 .41616 L .57004 .41554 L F
.471 .244 .487 r
.29493 .57281 m .29267 .57068 L .29594 .57021 L F
.084 0 .097 r
.29695 .57159 m .29594 .57021 L .29871 .56951 L F
.29695 .57159 m .29493 .57281 L .29594 .57021 L F
.356 .614 .948 r
.35904 .70575 m .36384 .70832 L .36215 .70552 L F
.303 .458 .85 r
.36215 .70552 m .36384 .70832 L .36548 .70845 L F
.475 .693 .963 r
.37406 .6003 m .37352 .60281 L .37177 .60151 L F
.819 .346 .08 r
.37929 .49897 m .37937 .49923 L .38132 .49982 L F
.46 0 0 r
.37937 .49923 m .38436 .49973 L .38132 .49982 L F
.28 .011 .315 r
.31754 .59322 m .31984 .5927 L .32037 .58979 L F
0 0 0 r
.3235 .58728 m .32037 .58979 L .32224 .5885 L F
.423 .13 .36 r
.32037 .58979 m .32278 .59165 L .32224 .5885 L F
.32037 .58979 m .31984 .5927 L .32278 .59165 L F
.632 .434 .596 r
.29714 .63767 m .30242 .63638 L .30017 .63523 L F
.513 .505 .784 r
.30017 .63523 m .30242 .63638 L .30342 .6361 L F
.136 .174 .638 r
.30342 .6361 m .3031 .63483 L .30017 .63523 L F
0 0 .296 r
.30291 .6662 m .30227 .66403 L .30236 .66323 L F
.288 .783 .748 r
.24006 .57432 m .23533 .57569 L .23784 .57533 L F
.456 0 0 r
.23784 .57533 m .24228 .57414 L .24006 .57432 L F
.469 .84 .99 r
.38211 .65773 m .3847 .65709 L .38038 .65698 L F
.59 .82 .987 r
.36379 .68611 m .36532 .6872 L .3677 .68648 L F
.413 .567 .897 r
.36532 .6872 m .36938 .6901 L .3677 .68648 L F
.081 .64 .775 r
.31477 .54822 m .31232 .54805 L .31073 .54824 L F
.6 .184 .225 r
.3163 .54719 m .31232 .54805 L .31477 .54822 L F
.586 .34 .51 r
.29267 .57068 m .28984 .57295 L .28984 .57083 L F
.648 .863 .981 r
.61825 .37179 m .62084 .37067 L .6173 .37048 L F
0 0 0 r
.25245 .57154 m .24923 .57306 L .25149 .57322 L F
.557 .552 .804 r
.25628 .57333 m .25245 .57154 L .25531 .57055 L F
.494 .181 .364 r
.25149 .57322 m .25531 .57055 L .25245 .57154 L F
.788 .882 .914 r
.3421 .57564 m .34448 .57738 L .3465 .5746 L F
.525 .487 .756 r
.34448 .57738 m .34715 .57676 L .3465 .5746 L F
.231 0 .322 r
.34448 .57738 m .34606 .5787 L .34715 .57676 L F
.34448 .57738 m .34408 .57966 L .34606 .5787 L F
.852 .975 .868 r
.65988 .33685 m .6634 .33502 L .66278 .33444 L F
.879 .992 .758 r
.66527 .33102 m .6634 .33502 L .66559 .33222 L F
.66527 .33102 m .66278 .33444 L .6634 .33502 L F
0 0 0 r
.44221 .59852 m .44627 .59702 L .44427 .59802 L F
.342 .791 .642 r
.44427 .59802 m .44627 .59702 L .44845 .59586 L F
.946 .588 .219 r
.39823 .5661 m .39976 .56728 L .39767 .56363 L F
.971 .707 .287 r
.39869 .56787 m .39976 .56728 L .39823 .5661 L F
.39869 .56787 m .39991 .57023 L .39976 .56728 L F
.799 .848 .888 r
.41362 .48587 m .418 .48547 L .41648 .48274 L F
.362 .409 .775 r
.418 .48547 m .41914 .4817 L .41648 .48274 L F
.418 .48547 m .42058 .48596 L .41914 .4817 L F
.985 .899 .579 r
.39794 .59593 m .39885 .59334 L .39792 .59141 L F
.891 .692 .627 r
.39968 .66049 m .40036 .65792 L .39775 .65685 L F
.584 .743 .952 r
.40236 .47624 m .40342 .47792 L .39945 .47699 L F
.664 .782 .937 r
.40596 .47693 m .40342 .47792 L .40236 .47624 L F
.995 .78 .417 r
.39504 .6877 m .39412 .68872 L .39422 .68596 L F
.702 .2 .044 r
.2944 .62813 m .29833 .6292 L .29676 .63028 L F
.173 0 0 r
.29833 .6292 m .29917 .62974 L .29676 .63028 L F
.382 .489 .843 r
.29833 .6292 m .30176 .63032 L .30085 .6294 L F
.173 0 0 r
.29833 .6292 m .30085 .6294 L .29917 .62974 L F
0 0 0 r
.23466 .54917 m .23439 .54889 L .23671 .54761 L F
.23466 .54917 m .23245 .54983 L .23439 .54889 L F
.811 .62 .644 r
.56385 .43149 m .56721 .42886 L .56387 .42862 L F
.56385 .43149 m .56729 .43191 L .56721 .42886 L F
.489 .272 .511 r
.56729 .43191 m .57025 .42815 L .56721 .42886 L F
.9 .821 .35 r
.60286 .45783 m .60198 .45973 L .60271 .45656 L F
.858 .767 .761 r
.59277 .37184 m .59095 .3714 L .59415 .36838 L F
.902 .98 .796 r
.59447 .37112 m .59095 .3714 L .59277 .37184 L F
.355 .341 .706 r
.36938 .6901 m .37266 .69051 L .37125 .68925 L F
0 0 0 r
.36938 .6901 m .37125 .68925 L .37104 .68942 L F
.36938 .6901 m .36962 .69 L .3677 .68648 L F
.36962 .69 m .36947 .68804 L .3677 .68648 L F
.475 .82 .536 r
.37104 .68942 m .37281 .68786 L .37187 .68773 L F
.516 .323 .557 r
.37187 .68774 m .37104 .68942 L .37216 .68782 L F
.3677 .68648 m .37104 .68942 L .37187 .68774 L F
.3677 .68648 m .37185 .68773 L .366 .68623 L F
.37185 .68773 m .37175 .68772 L .366 .68623 L F
.514 .659 .926 r
.3694 .68711 m .37184 .68774 L .36925 .68516 L F
.516 .323 .557 r
.37185 .68773 m .37216 .68782 L .37175 .68772 L F
.475 .82 .536 r
.37281 .68786 m .37452 .68635 L .37187 .68773 L F
.514 .659 .926 r
.37184 .68774 m .37216 .68782 L .37189 .68758 L F
.37184 .68774 m .37189 .68758 L .36925 .68516 L F
.809 .898 .485 r
.37181 .68785 m .3731 .68527 L .37305 .68533 L F
.37104 .68942 m .3718 .68788 L .37181 .68785 L F
.3718 .68788 m .3731 .68527 L .37181 .68785 L F
0 .116 .606 r
.36783 .68386 m .37189 .68758 L .37167 .68719 L F
.809 .898 .485 r
.37192 .68763 m .37305 .68533 L .37167 .68719 L F
0 .116 .606 r
.37189 .68758 m .37216 .68782 L .37167 .68719 L F
.809 .898 .485 r
.37104 .68942 m .37192 .68763 L .37167 .68719 L F
.475 .82 .536 r
.37187 .68773 m .37452 .68635 L .3731 .68527 L F
.978 .767 .55 r
.36685 .68064 m .36727 .68552 L .36526 .68155 L F
.745 .735 .843 r
.36526 .68155 m .36727 .68552 L .36379 .68611 L F
.514 .659 .926 r
.366 .68623 m .3694 .68711 L .36783 .68386 L F
.3694 .68711 m .36925 .68516 L .36783 .68386 L F
0 0 0 r
.36962 .69 m .37104 .68942 L .36947 .68804 L F
.355 .341 .706 r
.36938 .6901 m .37019 .69339 L .37258 .6906 L F
.455 .46 .774 r
.37019 .69339 m .37179 .69391 L .37266 .69051 L F
.784 .527 .548 r
.37277 .69102 m .37279 .69102 L .37417 .6945 L F
.37279 .69102 m .37516 .69076 L .3743 .69398 L F
.37279 .69102 m .3743 .69398 L .37417 .6945 L F
.355 .341 .706 r
.36938 .6901 m .37258 .6906 L .37253 .6905 L F
.507 0 0 r
.37516 .69076 m .37125 .68925 L .37266 .69051 L F
.811 .756 .801 r
.37276 .68804 m .37294 .68825 L .37015 .69131 L F
.204 .223 .658 r
.37266 .69051 m .37278 .69084 L .37516 .69076 L F
.811 .756 .801 r
.37278 .69084 m .37516 .69076 L .37277 .69102 L F
.204 .223 .658 r
.37278 .69084 m .37417 .6945 L .37516 .69076 L F
.811 .756 .801 r
.37294 .68825 m .37516 .69076 L .37278 .69084 L F
.204 .223 .658 r
.37266 .69051 m .37262 .69065 L .37277 .69102 L F
.37266 .69051 m .37277 .69102 L .37278 .69084 L F
.37262 .69065 m .37179 .69391 L .37417 .6945 L F
.355 .341 .706 r
.37253 .6905 m .37258 .6906 L .37266 .69051 L F
.811 .756 .801 r
.37294 .68825 m .37277 .69102 L .37015 .69131 L F
.204 .223 .658 r
.37278 .69084 m .37277 .69102 L .37417 .6945 L F
.784 .527 .548 r
.37015 .69131 m .37277 .69102 L .37417 .6945 L F
.976 .795 .594 r
.61049 .45115 m .61107 .44833 L .60955 .44708 L F
.75 .497 .548 r
.35555 .54062 m .35916 .54122 L .35925 .5385 L F
.501 .29 .526 r
.35925 .5385 m .35916 .54122 L .36216 .53798 L F
.25 .763 .809 r
.27567 .51626 m .27988 .51562 L .27792 .51679 L F
.835 .858 .863 r
.46567 .44952 m .46737 .45073 L .46389 .45118 L F
.737 .853 .935 r
.46888 .44724 m .46737 .45073 L .46567 .44952 L F
.46888 .44724 m .4705 .44869 L .46737 .45073 L F
.66 .739 .909 r
.48457 .49326 m .48561 .49439 L .48722 .49266 L F
.401 .371 .71 r
.3728 .58913 m .37079 .58986 L .37036 .58721 L F
.125 .128 .59 r
.37269 .59195 m .37079 .58986 L .3728 .58913 L F
.37269 .59195 m .37158 .5936 L .37079 .58986 L F
0 0 0 r
.66821 .37102 m .66527 .37376 L .66734 .37252 L F
.67019 .36916 m .6711 .36805 L .66821 .37102 L F
.67019 .36916 m .66821 .37102 L .66734 .37252 L F
.769 .833 .901 r
.47946 .44483 m .47675 .44732 L .47541 .4451 L F
.263 0 .196 r
.45042 .52249 m .45216 .52206 L .44901 .52228 L F
.598 .43 .624 r
.50188 .48398 m .50174 .48635 L .49935 .4867 L F
.577 .327 .501 r
.50174 .48635 m .49841 .48921 L .49935 .4867 L F
.959 .625 .248 r
.60991 .4192 m .61159 .42262 L .61051 .42121 L F
.983 .728 .467 r
.61159 .42262 m .61003 .42401 L .61051 .42121 L F
.61159 .42262 m .61158 .42553 L .61003 .42401 L F
.302 .729 .971 r
.3027 .6511 m .30016 .65132 L .29846 .65039 L F
.079 .5 .899 r
.25694 .61736 m .25896 .61922 L .2567 .61835 L F
.927 .548 .255 r
.38618 .52866 m .38687 .53089 L .38867 .53177 L F
.97 .781 .592 r
.38687 .53089 m .38803 .53521 L .38867 .53177 L F
.897 .984 .72 r
.3461 .67981 m .34692 .68014 L .34909 .6767 L F
.666 .974 .881 r
.34484 .68038 m .34692 .68014 L .3461 .67981 L F
.599 .797 .377 r
.30354 .65661 m .30476 .65468 L .30613 .6525 L F
.586 .34 .51 r
.29267 .57068 m .29245 .57341 L .28984 .57295 L F
.471 .244 .487 r
.29493 .57281 m .29245 .57341 L .29267 .57068 L F
.785 .857 .904 r
.63935 .34756 m .64263 .34811 L .641 .34696 L F
.852 .797 .796 r
.63935 .34756 m .64014 .35153 L .64263 .34811 L F
.806 .951 .914 r
.64263 .34811 m .64455 .34448 L .641 .34696 L F
.64263 .34811 m .64572 .34533 L .64455 .34448 L F
0 0 0 r
.70139 .29598 m .70226 .2944 L .70378 .2925 L F
.983 .707 .416 r
.3945 .54901 m .39624 .54801 L .39427 .54668 L F
.3945 .54901 m .39607 .55039 L .39624 .54801 L F
.693 .797 .929 r
.5068 .43197 m .5043 .43285 L .5029 .43137 L F
0 .038 .531 r
.38694 .50929 m .38777 .51 L .38533 .50805 L F
.38694 .50929 m .38922 .5114 L .38777 .51 L F
.262 .395 .809 r
.35878 .61312 m .36156 .61469 L .35974 .61156 L F
.767 .545 .598 r
.49101 .48696 m .48939 .48987 L .48983 .48692 L F
.858 .532 .435 r
.49101 .48696 m .49323 .49023 L .48939 .48987 L F
.708 .421 .488 r
.36013 .52719 m .35651 .52848 L .35708 .52541 L F
.78 .952 .623 r
.23445 .53267 m .23488 .53103 L .23639 .53117 L F
.23445 .53267 m .23363 .53254 L .23488 .53103 L F
.23445 .53267 m .23265 .53425 L .23363 .53254 L F
.822 .647 .666 r
.55302 .43119 m .55705 .42905 L .55572 .42785 L F
.55302 .43119 m .5571 .43225 L .55705 .42905 L F
.62 .485 .676 r
.55705 .42905 m .5608 .4317 L .56017 .4289 L F
.55705 .42905 m .5571 .43225 L .5608 .4317 L F
.579 .275 .418 r
.52201 .47128 m .52476 .4732 L .52194 .47315 L F
.52201 .47128 m .52581 .47027 L .52476 .4732 L F
.289 .113 .46 r
.53819 .40869 m .53608 .41239 L .53612 .4098 L F
.938 .877 .75 r
.69539 .33927 m .69623 .34259 L .6949 .34431 L F
.856 .996 .765 r
.6949 .34431 m .69371 .34616 L .69196 .34675 L F
.995 .758 .443 r
.60308 .43364 m .60452 .43228 L .6032 .431 L F
.60308 .43364 m .60443 .4351 L .60452 .43228 L F
.947 .588 .239 r
.39897 .57551 m .39994 .57443 L .39923 .57282 L F
.39897 .57551 m .40037 .57629 L .39994 .57443 L F
.783 .982 .905 r
.36942 .53047 m .36841 .53271 L .37121 .53179 L F
.36942 .53047 m .36606 .53315 L .36841 .53271 L F
.868 .994 .761 r
.60787 .46166 m .61047 .45823 L .60843 .45916 L F
.83 .984 .876 r
.60787 .46166 m .60843 .45916 L .60688 .46092 L F
.697 .58 .721 r
.34031 .60606 m .33938 .60812 L .33791 .6066 L F
.976 .817 .619 r
.7003 .31611 m .7002 .31905 L .69931 .31821 L F
.7002 .31905 m .70011 .32138 L .69979 .32011 L F
.7002 .31905 m .69979 .32011 L .69931 .31821 L F
0 0 .29 r
.69931 .31821 m .69995 .32073 L .70006 .32062 L F
.69931 .31821 m .70005 .32111 L .70006 .32062 L F
.70005 .32111 m .70011 .32138 L .70006 .32062 L F
0 0 .522 r
.69931 .31821 m .70006 .32062 L .70101 .31844 L F
.743 .929 .581 r
.70006 .32062 m .69889 .32145 L .70007 .31977 L F
.70006 .32062 m .70007 .31977 L .70101 .31844 L F
.67 .971 .909 r
.70011 .32138 m .69795 .32285 L .70006 .32062 L F
0 0 .487 r
.69929 .32143 m .69914 .32326 L .70006 .32062 L F
.69795 .32285 m .69866 .32309 L .69929 .32143 L F
0 0 .294 r
.69914 .32326 m .69985 .32573 L .6994 .32372 L F
0 0 .487 r
.69882 .32268 m .69914 .32326 L .69929 .32143 L F
.954 .876 .472 r
.70006 .32062 m .69956 .32204 L .69889 .32145 L F
.69956 .32204 m .69914 .32326 L .69889 .32145 L F
0 0 .561 r
.69889 .32145 m .69985 .32573 L .70029 .32316 L F
.58 .088 0 r
.69826 .3209 m .69889 .32145 L .70029 .32316 L F
.69735 .31989 m .69889 .32145 L .69826 .3209 L F
0 0 .294 r
.69914 .32326 m .6994 .32372 L .69889 .32145 L F
0 0 .487 r
.69866 .32309 m .69914 .32326 L .69882 .32268 L F
.69795 .32285 m .69893 .32533 L .69914 .32326 L F
.691 .151 0 r
.33443 .61582 m .33339 .61686 L .33109 .6147 L F
.33443 .61582 m .33519 .61724 L .33339 .61686 L F
.636 .929 .971 r
.56514 .40358 m .56175 .40543 L .56049 .4051 L F
.983 .908 .618 r
.4469 .57079 m .44493 .57223 L .44552 .5696 L F
.4469 .57079 m .44588 .57294 L .44582 .57158 L F
.63 .067 0 r
.44703 .57197 m .4469 .57079 L .44552 .5696 L F
.754 .991 .79 r
.44863 .56713 m .44552 .5696 L .4463 .56781 L F
.561 .325 .515 r
.44552 .5696 m .44703 .57197 L .44852 .56918 L F
0 .093 .625 r
.44571 .56916 m .44703 .57197 L .4463 .56781 L F
.44552 .5696 m .44575 .56996 L .44571 .56916 L F
.44575 .56996 m .44703 .57197 L .44571 .56916 L F
.983 .908 .618 r
.44582 .57158 m .44567 .57339 L .44493 .57223 L F
.44588 .57294 m .44567 .57339 L .44582 .57158 L F
0 0 0 r
.42942 .57831 m .42708 .57918 L .4288 .57783 L F
.755 .495 .539 r
.34909 .6767 m .34559 .67616 L .34723 .67507 L F
.897 .984 .72 r
.3461 .67981 m .34909 .6767 L .34723 .67507 L F
0 .13 .667 r
.38146 .68995 m .38086 .69165 L .37931 .68763 L F
.687 .251 .21 r
.38062 .69113 m .38086 .69165 L .38146 .68995 L F
.215 .724 .892 r
.38086 .69165 m .38106 .69207 L .37951 .69212 L F
.481 0 0 r
.37866 .69134 m .37516 .69076 L .3769 .69141 L F
.176 0 0 r
.38086 .69165 m .3769 .69141 L .37931 .68763 L F
.687 .251 .21 r
.37897 .69345 m .38086 .69165 L .38062 .69113 L F
.215 .724 .892 r
.38086 .69165 m .38241 .69203 L .38106 .69207 L F
.766 .64 .722 r
.70406 .27403 m .70795 .27489 L .70658 .27106 L F
.547 .589 .848 r
.3182 .54053 m .3174 .54475 L .31575 .54181 L F
.3182 .54053 m .31975 .54431 L .3174 .54475 L F
.615 .877 .99 r
.24652 .57387 m .24228 .57414 L .24462 .5742 L F
.569 .369 .571 r
.24652 .57387 m .24641 .57685 L .24383 .57689 L F
.72 .496 .585 r
.25031 .57633 m .24641 .57685 L .24652 .57387 L F
.765 .411 0 r
.25616 .62163 m .25777 .62536 L .25713 .62428 L F
.236 0 0 r
.25777 .62536 m .25804 .62587 L .25713 .62428 L F
.25777 .62536 m .25976 .62578 L .25804 .62587 L F
.708 .652 .792 r
.34031 .60606 m .33791 .6066 L .33491 .60117 L F
.312 0 .224 r
.30124 .54863 m .30339 .54823 L .30461 .54648 L F
.516 .1 .19 r
.282 .5674 m .28383 .56901 L .28464 .56708 L F
.282 .5674 m .28037 .56979 L .28383 .56901 L F
.732 .986 .896 r
.62821 .42412 m .6289 .42488 L .63215 .42235 L F
.789 .962 .92 r
.68953 .29134 m .69052 .2924 L .6884 .29407 L F
.83 .993 .745 r
.68953 .29134 m .6884 .29407 L .6867 .29473 L F
.834 .586 .563 r
.36526 .5803 m .36525 .58306 L .36154 .58219 L F
.561 .894 .984 r
.26909 .51858 m .26602 .51933 L .26851 .52018 L F
.003 .472 .868 r
.24098 .62093 m .24148 .6205 L .2396 .6186 L F
.24098 .62093 m .24306 .62181 L .24148 .6205 L F
.264 0 0 r
.34517 .49685 m .3469 .49688 L .34285 .49611 L F
.255 0 0 r
.34958 .49763 m .3469 .49688 L .34517 .49685 L F
.945 .669 .483 r
.24188 .60599 m .24098 .60572 L .24198 .60245 L F
.556 .234 .377 r
.24198 .60245 m .24447 .60479 L .24357 .60136 L F
.24198 .60245 m .24098 .60572 L .24447 .60479 L F
.764 .603 .678 r
.32485 .59315 m .3242 .59628 L .32847 .59622 L F
.416 0 0 r
.3242 .59628 m .3257 .59695 L .32847 .59622 L F
.251 .757 .725 r
.32847 .59622 m .32991 .59567 L .32968 .59451 L F
.32847 .59622 m .3257 .59695 L .32991 .59567 L F
.304 .359 .754 r
.39034 .66913 m .38871 .67132 L .38719 .66694 L F
0 0 0 r
.39034 .66913 m .38871 .67132 L .38883 .67118 L F
.38883 .67118 m .38871 .67132 L .39034 .66913 L F
.822 .981 .885 r
.66831 .32818 m .66559 .33222 L .66927 .3293 L F
.66831 .32818 m .66527 .33102 L .66559 .33222 L F
.755 .803 .322 r
.33993 .61166 m .34203 .61275 L .34061 .61155 L F
.96 .845 .685 r
.63859 .35007 m .64014 .35153 L .63935 .34756 L F
.865 .895 .854 r
.63613 .35306 m .64014 .35153 L .63859 .35007 L F
.63 .824 .413 r
.7029 .35002 m .70377 .34871 L .70293 .3499 L F
.865 .946 .586 r
.70437 .34599 m .70377 .34871 L .70569 .34494 L F
.812 .858 .407 r
.70293 .3499 m .70377 .34871 L .70437 .34599 L F
.991 .855 .497 r
.61047 .45823 m .61022 .45372 L .60985 .45724 L F
.922 .976 .736 r
.61047 .45823 m .60985 .45724 L .60843 .45916 L F
.623 .407 .568 r
.51285 .47673 m .51016 .4797 L .51037 .47739 L F
.852 .532 .446 r
.61002 .36453 m .61022 .36701 L .60686 .36637 L F
.656 .42 .551 r
.61283 .36428 m .61022 .36701 L .61002 .36453 L F
.626 .96 .89 r
.63317 .33977 m .63635 .33792 L .63715 .33832 L F
0 0 0 r
.63715 .33832 m .63909 .33684 L .64025 .33559 L F
.483 .896 .911 r
.63715 .33832 m .63635 .33792 L .63909 .33684 L F
.765 .372 .309 r
.37839 .65392 m .38038 .65698 L .37607 .65633 L F
.544 .435 .68 r
.31327 .63713 m .31018 .63546 L .31244 .63472 L F
.31327 .63713 m .31062 .63809 L .31018 .63546 L F
.496 .426 .707 r
.35119 .5888 m .35107 .5868 L .34964 .58641 L F
.419 0 0 r
.35292 .59018 m .34918 .59001 L .35119 .5888 L F
.551 .359 .573 r
.50451 .48063 m .50474 .48309 L .50188 .48398 L F
.617 .439 .619 r
.5074 .47987 m .50474 .48309 L .50451 .48063 L F
0 0 0 r
.59415 .36838 m .59095 .3714 L .59307 .36949 L F
.048 0 .411 r
.59579 .36352 m .59415 .36838 L .59588 .36639 L F
.557 .843 .51 r
.59415 .36838 m .59307 .36949 L .59588 .36639 L F
.969 .678 .42 r
.39256 .54241 m .39321 .54473 L .39241 .54095 L F
.046 0 .462 r
.24272 .58175 m .24106 .58034 L .24284 .57921 L F
.24272 .58175 m .24117 .58308 L .24106 .58034 L F
.401 .371 .71 r
.3728 .58913 m .37036 .58721 L .3729 .58642 L F
0 0 0 r
.67263 .36643 m .6711 .36805 L .67277 .36646 L F
.67277 .36646 m .6711 .36805 L .67019 .36916 L F
.566 .862 .55 r
.60668 .37851 m .60723 .37773 L .60609 .38074 L F
.60668 .37851 m .60861 .37651 L .60723 .37773 L F
.512 .513 .794 r
.4595 .55173 m .46085 .54732 L .45815 .54811 L F
.4595 .55173 m .46193 .55116 L .46085 .54732 L F
.496 .438 .722 r
.4595 .55173 m .46274 .55385 L .46193 .55116 L F
.18 .286 .737 r
.67816 .35309 m .68014 .35374 L .68004 .35068 L F
.845 .818 .822 r
.44695 .5388 m .4442 .54186 L .44524 .53973 L F
.581 .859 .528 r
.44611 .53969 m .4442 .54186 L .44695 .5388 L F
.809 .548 .544 r
.4463 .53448 m .44892 .53767 L .44695 .5388 L F
0 0 0 r
.44892 .53767 m .44611 .53969 L .44695 .5388 L F
.292 .299 .695 r
.45305 .53818 m .45352 .54187 L .45544 .54013 L F
.505 .479 .762 r
.45417 .54469 m .45544 .54013 L .45352 .54187 L F
.858 .86 .407 r
.42814 .56199 m .42889 .56128 L .4291 .55921 L F
.42814 .56199 m .42809 .56373 L .42889 .56128 L F
.126 0 .096 r
.63033 .357 m .63125 .3548 L .62802 .3579 L F
.557 .745 .965 r
.62993 .35305 m .63125 .3548 L .63277 .35266 L F
.65 .468 .625 r
.5608 .4317 m .56387 .42862 L .56017 .4289 L F
.609 .587 .803 r
.3447 .56747 m .34219 .56977 L .33975 .56468 L F
.533 .342 .567 r
.36482 .56107 m .36693 .56315 L .36761 .56089 L F
.36482 .56107 m .3645 .56389 L .36693 .56315 L F
.681 .7 .862 r
.36639 .5588 m .36482 .56107 L .36761 .56089 L F
.533 .342 .567 r
.36693 .56315 m .36482 .56107 L .36761 .56089 L F
.36693 .56315 m .3645 .56389 L .36482 .56107 L F
.806 .52 .504 r
.27338 .62168 m .27736 .62514 L .27559 .62245 L F
.695 .62 .769 r
.39555 .48826 m .39165 .48684 L .39416 .48635 L F
.403 .38 .72 r
.39664 .48594 m .39555 .48826 L .39416 .48635 L F
.39664 .48594 m .39843 .49057 L .39555 .48826 L F
.522 .363 .607 r
.2296 .5735 m .22975 .57683 L .22714 .57713 L F
0 0 .193 r
.22782 .57793 m .22714 .57713 L .22975 .57683 L F
.22782 .57793 m .22673 .57976 L .22714 .57713 L F
.789 .378 0 r
.31709 .52877 m .31619 .52778 L .3147 .52511 L F
.994 .874 .558 r
.31619 .52778 m .31539 .53036 L .31709 .52877 L F
.902 .985 .769 r
.70569 .34494 m .70804 .34158 L .70756 .34062 L F
.849 .884 .864 r
.70804 .34158 m .70996 .33711 L .70756 .34062 L F
.70804 .34158 m .71126 .33856 L .70996 .33711 L F
.876 .449 .04 r
.60759 .41231 m .61004 .41592 L .60872 .41507 L F
.997 .776 .469 r
.61004 .41592 m .60872 .41798 L .60872 .41507 L F
.61004 .41592 m .60991 .4192 L .60872 .41798 L F
0 0 .004 r
.43261 .5376 m .43119 .542 L .43223 .54015 L F
0 0 .317 r
.43022 .54476 m .43223 .54015 L .43119 .542 L F
.87 .885 .843 r
.70996 .33711 m .71126 .33856 L .71393 .33539 L F
.918 .962 .793 r
.38385 .69891 m .38669 .69532 L .38488 .69491 L F
.62 .531 .732 r
.3645 .56389 m .36241 .56746 L .36248 .56436 L F
.915 .943 .806 r
.35367 .64327 m .35497 .64407 L .35192 .64813 L F
.678 .609 .771 r
.35798 .64174 m .35913 .64332 L .35497 .64407 L F
0 .173 .705 r
.3584 .64777 m .35497 .64407 L .35913 .64332 L F
.9 .981 .798 r
.69641 .28454 m .69415 .28765 L .69455 .28452 L F
.901 .924 .539 r
.69455 .28452 m .69415 .28765 L .69317 .28956 L F
.012 0 .087 r
.52869 .41932 m .53095 .41658 L .53033 .41889 L F
.02 0 .122 r
.52894 .4201 m .52869 .41932 L .53033 .41889 L F
.85 .624 .083 r
.52875 .4209 m .52869 .41932 L .52894 .4201 L F
.865 .946 .586 r
.70437 .34599 m .70569 .34494 L .70551 .34421 L F
.902 .985 .769 r
.70569 .34494 m .70756 .34062 L .70551 .34421 L F
0 0 .036 r
.53033 .41889 m .53095 .41658 L .53293 .41438 L F
.274 .779 .816 r
.32122 .55636 m .31759 .55702 L .31929 .557 L F
.136 .117 .57 r
.42806 .5509 m .42916 .55659 L .42761 .55388 L F
.322 0 .219 r
.35365 .66978 m .35724 .66675 L .35612 .6689 L F
.326 .75 .974 r
.3585 .66635 m .35724 .66675 L .3554 .66586 L F
.35962 .66653 m .3554 .66586 L .35795 .66558 L F
.388 .044 .255 r
.35612 .6689 m .35788 .66571 L .35563 .66789 L F
.35788 .66571 m .35795 .66558 L .35785 .66568 L F
.35788 .66571 m .35785 .66568 L .35563 .66789 L F
.326 .75 .974 r
.35962 .66653 m .35875 .66661 L .3585 .66635 L F
.35875 .66661 m .35724 .66675 L .3585 .66635 L F
.388 .044 .255 r
.35612 .6689 m .35724 .66675 L .35962 .66653 L F
.777 .618 .683 r
.33564 .52202 m .33096 .51996 L .3339 .51971 L F
.409 0 .019 r
.33564 .52202 m .33113 .52418 L .33183 .5224 L F
.33564 .52202 m .33424 .52413 L .33113 .52418 L F
.582 .121 .123 r
.3339 .51971 m .33903 .52041 L .33564 .52202 L F
.3339 .51971 m .3372 .52141 L .33903 .52041 L F
0 .29 .703 r
.33343 .51912 m .3372 .52141 L .3339 .51971 L F
.624 .537 .736 r
.32897 .52269 m .33183 .5224 L .33096 .51996 L F
0 0 0 r
.33096 .51996 m .33158 .51954 L .3339 .51971 L F
0 .29 .703 r
.33435 .51956 m .3372 .52141 L .33343 .51912 L F
.744 .859 .933 r
.33855 .51964 m .33364 .5191 L .33371 .51899 L F
.33855 .51964 m .3334 .51894 L .33351 .51885 L F
.33855 .51964 m .33377 .51889 L .33694 .51563 L F
.471 .351 .634 r
.3334 .5188 m .33342 .51893 L .33351 .51885 L F
.744 .859 .933 r
.33377 .51889 m .33351 .51885 L .33368 .51837 L F
.471 .351 .634 r
.33352 .51877 m .33351 .51885 L .33363 .51874 L F
.3334 .5188 m .33351 .51885 L .33352 .51877 L F
.744 .859 .933 r
.33351 .51885 m .33356 .51847 L .33368 .51837 L F
.33377 .51889 m .33368 .51837 L .3354 .51692 L F
.33587 .51672 m .3354 .51692 L .33694 .51563 L F
.33377 .51889 m .3354 .51692 L .33587 .51672 L F
.735 .477 .538 r
.33694 .51563 m .33356 .51847 L .33326 .51776 L F
.471 .351 .634 r
.33326 .51776 m .33327 .51787 L .3333 .51786 L F
.33327 .51787 m .3334 .5188 L .33337 .51784 L F
.521 .386 .638 r
.33298 .51872 m .3334 .51894 L .33326 .51776 L F
0 0 .315 r
.33326 .51776 m .33317 .51879 L .33293 .51891 L F
.33326 .51776 m .33293 .51891 L .33158 .51954 L F
.521 .386 .638 r
.33283 .51864 m .33298 .51872 L .33326 .51776 L F
.744 .859 .933 r
.33342 .51893 m .3334 .51894 L .3334 .51894 L F
.521 .386 .638 r
.3334 .51894 m .33342 .51895 L .33342 .51893 L F
.3334 .51894 m .33342 .51893 L .33326 .51776 L F
.744 .859 .933 r
.33351 .51885 m .33342 .51893 L .33317 .51879 L F
.33342 .51893 m .3334 .51894 L .33317 .51879 L F
.735 .477 .538 r
.33356 .51847 m .33317 .51879 L .33326 .51776 L F
.471 .351 .634 r
.33326 .51776 m .3333 .51786 L .33337 .51784 L F
.33337 .51784 m .3334 .5188 L .33438 .51855 L F
.33357 .51769 m .33408 .51834 L .33458 .51746 L F
.33326 .51776 m .33362 .51801 L .33357 .51769 L F
.33362 .51801 m .33408 .51834 L .33357 .51769 L F
.33458 .51746 m .33551 .51934 L .33516 .51733 L F
.33408 .51834 m .33551 .51934 L .33458 .51746 L F
0 .29 .703 r
.33289 .51893 m .3339 .51971 L .33158 .51954 L F
.521 .386 .638 r
.33104 .5224 m .33326 .51776 L .33158 .51954 L F
.358 0 0 r
.33516 .51733 m .33068 .51921 L .33284 .51799 L F
.33357 .51769 m .33284 .51799 L .33326 .51776 L F
.33516 .51733 m .33284 .51799 L .33357 .51769 L F
.744 .859 .933 r
.33351 .51885 m .33317 .51879 L .33356 .51847 L F
.33855 .51964 m .3372 .52141 L .33364 .5191 L F
.33371 .51899 m .33364 .5191 L .3334 .51894 L F
0 .29 .703 r
.33321 .51884 m .33435 .51956 L .33343 .51912 L F
.3334 .51894 m .33435 .51956 L .33321 .51884 L F
.471 .351 .634 r
.33363 .51874 m .3338 .52173 L .33438 .51855 L F
.33342 .51893 m .3338 .52173 L .33363 .51874 L F
.33438 .51855 m .3338 .52173 L .33551 .51934 L F
0 .29 .703 r
.33293 .51891 m .33294 .51891 L .33289 .51893 L F
.33294 .51891 m .3339 .51971 L .33289 .51893 L F
.521 .386 .638 r
.33268 .51897 m .33321 .51884 L .33283 .51864 L F
0 .29 .703 r
.33317 .51879 m .33321 .51884 L .33293 .51891 L F
.33321 .51884 m .3339 .51971 L .33293 .51891 L F
.521 .386 .638 r
.33104 .5224 m .33342 .51895 L .33321 .51884 L F
.33104 .5224 m .33321 .51884 L .33268 .51897 L F
.33104 .5224 m .3338 .52173 L .33342 .51895 L F
0 .29 .703 r
.33317 .51879 m .3334 .51894 L .33321 .51884 L F
.859 .968 .867 r
.33551 .51934 m .33548 .52265 L .33855 .51964 L F
.707 .252 .169 r
.33656 .52154 m .33548 .52265 L .3355 .52011 L F
.33599 .52035 m .3355 .52011 L .33551 .51934 L F
.33656 .52154 m .3355 .52011 L .33599 .52035 L F
0 .157 .649 r
.33855 .51964 m .33903 .52041 L .3372 .52141 L F
.788 .997 .798 r
.33855 .51964 m .33548 .52265 L .33903 .52041 L F
.707 .252 .169 r
.33822 .52501 m .33548 .52265 L .33656 .52154 L F
0 0 0 r
.33548 .52265 m .33424 .52413 L .33467 .52348 L F
.33548 .52265 m .33467 .52348 L .33564 .52202 L F
.731 .777 .89 r
.48618 .44229 m .48218 .44183 L .48417 .44062 L F
.811 .836 .87 r
.48726 .43787 m .48618 .44229 L .48417 .44062 L F
.48726 .43787 m .48906 .4398 L .48618 .44229 L F
0 0 0 r
.34215 .58084 m .34116 .58225 L .34408 .57966 L F
.708 .652 .792 r
.34031 .60606 m .33491 .60117 L .3405 .60324 L F
.446 .032 .159 r
.29972 .56271 m .30258 .56238 L .30004 .56128 L F
.295 .022 .318 r
.24507 .5782 m .24383 .57689 L .24641 .57685 L F
.24507 .5782 m .24284 .57921 L .24383 .57689 L F
.103 .263 .744 r
.54269 .40648 m .54089 .40789 L .54099 .40519 L F
.54269 .40648 m .54342 .40476 L .54089 .40789 L F
.54269 .40648 m .54482 .40869 L .54342 .40476 L F
.058 .555 .887 r
.57077 .38758 m .5737 .38814 L .57558 .38931 L F
0 .401 .793 r
.57619 .38904 m .57558 .38931 L .5737 .38814 L F
.57619 .38904 m .57738 .38995 L .57558 .38931 L F
.357 .127 .422 r
.36901 .56733 m .36878 .56987 L .36644 .5706 L F
.417 .271 .574 r
.36644 .5706 m .36872 .57271 L .36878 .56987 L F
.357 .127 .422 r
.36901 .56733 m .36878 .56987 L .36644 .5706 L F
.417 .271 .574 r
.36644 .5706 m .36872 .57271 L .36878 .56987 L F
.512 .415 .682 r
.3177 .59593 m .31984 .5927 L .31754 .59322 L F
.46 .255 .514 r
.50474 .48309 m .50174 .48635 L .50188 .48398 L F
.797 .872 .903 r
.44227 .54042 m .4442 .54186 L .44611 .53969 L F
.902 .613 .112 r
.44227 .54042 m .44332 .54375 L .4442 .54186 L F
.873 .532 .402 r
.24701 .60248 m .24759 .60467 L .24909 .60308 L F
.65 .22 .213 r
.24759 .60467 m .25174 .60502 L .24909 .60308 L F
.63 .827 .976 r
.42322 .58918 m .42945 .58969 L .42581 .58591 L F
0 0 .558 r
.33092 .63403 m .33085 .63488 L .32987 .63313 L F
.142 .09 .533 r
.33216 .63801 m .33118 .63727 L .33085 .63488 L F
.402 .446 .792 r
.33423 .63609 m .33216 .63801 L .33092 .63403 L F
.423 0 0 r
.33073 .63526 m .33092 .63403 L .32933 .63532 L F
.663 .851 .451 r
.32932 .63327 m .32664 .63745 L .32683 .63708 L F
.32775 .63549 m .32683 .63708 L .32737 .63604 L F
.32932 .63327 m .32683 .63708 L .32775 .63549 L F
.938 .588 .33 r
.3289 .63139 m .32932 .63327 L .32748 .63329 L F
0 0 .558 r
.33092 .63403 m .32987 .63313 L .3289 .63139 L F
.938 .588 .33 r
.3289 .63139 m .32748 .63329 L .32827 .63066 L F
.663 .851 .451 r
.32932 .63327 m .32737 .63604 L .32748 .63329 L F
.579 .116 0 r
.33092 .63403 m .32827 .63066 L .32748 .63329 L F
.217 .243 .674 r
.32922 .63203 m .32925 .63292 L .32748 .63329 L F
.728 .263 .147 r
.32933 .63532 m .33092 .63403 L .32748 .63329 L F
.217 .243 .674 r
.32925 .63292 m .32933 .63532 L .32843 .63433 L F
.32925 .63292 m .32843 .63433 L .32748 .63329 L F
.783 .394 .317 r
.32352 .63216 m .32748 .63329 L .32518 .63486 L F
.392 .279 .604 r
.32748 .63329 m .32737 .63604 L .32933 .63532 L F
.705 .279 .233 r
.32748 .63329 m .32933 .63532 L .32518 .63486 L F
.328 .131 .453 r
.32933 .63532 m .32737 .63604 L .32708 .63867 L F
0 0 .06 r
.32737 .63604 m .32664 .63745 L .32626 .64009 L F
.32737 .63604 m .32683 .638 L .32708 .63867 L F
.32683 .638 m .32626 .64009 L .32708 .63867 L F
.46 .283 .553 r
.32708 .63867 m .32694 .64129 L .3294 .6409 L F
.645 .092 0 r
.32708 .63867 m .3294 .6409 L .32755 .63992 L F
0 0 .22 r
.32626 .64009 m .32694 .64129 L .32708 .63867 L F
.645 .092 0 r
.32708 .63867 m .32755 .63992 L .32608 .63916 L F
.906 .953 .817 r
.32933 .63532 m .32708 .63867 L .32518 .6376 L F
.32851 .63523 m .32518 .6376 L .32518 .63486 L F
.32933 .63532 m .32518 .6376 L .32851 .63523 L F
.622 .299 .402 r
.3213 .63512 m .32518 .6376 L .32175 .63798 L F
.3213 .63512 m .32518 .63486 L .32518 .6376 L F
.283 .119 .474 r
.32352 .63888 m .32175 .63798 L .32518 .6376 L F
.826 .997 .775 r
.3257 .63603 m .32369 .63866 L .32518 .6376 L F
.32369 .63866 m .32352 .63888 L .32518 .6376 L F
.503 .479 .763 r
.33035 .63494 m .32933 .63532 L .32922 .63203 L F
.997 .838 .562 r
.3313 .64103 m .33118 .63727 L .33329 .63964 L F
.701 .187 .003 r
.32974 .63739 m .33163 .63752 L .32933 .63532 L F
.57 .274 .427 r
.33163 .63752 m .33255 .63519 L .32933 .63532 L F
.746 .474 .519 r
.32236 .63063 m .32827 .63066 L .32748 .63329 L F
.717 .38 .406 r
.32492 .62783 m .32827 .63066 L .32236 .63063 L F
.938 .691 .217 r
.32819 .62781 m .32827 .63066 L .32492 .62783 L F
.969 .855 .454 r
.32748 .63329 m .32827 .63066 L .32741 .6292 L F
.746 .474 .519 r
.32236 .63063 m .32748 .63329 L .32352 .63216 L F
.969 .855 .454 r
.32748 .63329 m .32741 .6292 L .32922 .63203 L F
.772 .693 .776 r
.32922 .63203 m .32933 .63532 L .32518 .63486 L F
.926 .556 .291 r
.32926 .63677 m .33035 .63494 L .3267 .63349 L F
.701 .187 .003 r
.32974 .63739 m .32933 .63532 L .33035 .63494 L F
.926 .556 .291 r
.32974 .63739 m .33011 .6359 L .32926 .63677 L F
.33011 .6359 m .33035 .63494 L .32926 .63677 L F
.423 0 0 r
.33228 .6352 m .33147 .63451 L .33073 .63526 L F
.33147 .63451 m .33092 .63403 L .33073 .63526 L F
.33255 .63519 m .33092 .63403 L .33228 .6352 L F
.779 .757 .833 r
.63438 .38648 m .63845 .38759 L .63663 .38575 L F
.707 .746 .882 r
.63663 .38575 m .63845 .38759 L .64056 .38567 L F
.892 .978 .818 r
.59039 .37548 m .59195 .37185 L .59224 .3716 L F
.902 .98 .796 r
.59262 .37127 m .59224 .3716 L .59095 .3714 L F
.124 0 .26 r
.59307 .36949 m .59095 .3714 L .59224 .3716 L F
.892 .978 .818 r
.59195 .37185 m .59224 .37118 L .59224 .3716 L F
.902 .98 .796 r
.59447 .37112 m .59224 .3716 L .59262 .37127 L F
.59447 .37112 m .59201 .37435 L .59224 .3716 L F
.491 .753 .988 r
.59307 .36949 m .59568 .36928 L .59447 .37112 L F
.305 .792 .894 r
.35206 .5537 m .35129 .55354 L .34979 .55406 L F
.461 .455 .765 r
.35129 .55354 m .35011 .55805 L .34979 .55406 L F
.35129 .55354 m .35216 .55768 L .35011 .55805 L F
.466 .628 .923 r
.35216 .55768 m .3552 .56003 L .35011 .55805 L F
.91 .506 .187 r
.5812 .38031 m .58057 .38209 L .57962 .37918 L F
.5812 .38031 m .58227 .38309 L .58057 .38209 L F
.343 .437 .813 r
.33712 .52957 m .33773 .5322 L .33934 .53051 L F
.543 .465 .717 r
.33653 .53438 m .33934 .53051 L .33773 .5322 L F
.993 .78 .405 r
.28206 .54032 m .28297 .54162 L .28254 .53854 L F
.342 .187 .522 r
.70406 .27403 m .70195 .27783 L .70438 .27659 L F
.325 .155 .491 r
.70438 .27659 m .70195 .27783 L .70368 .27909 L F
.655 .864 .979 r
.70159 .28033 m .70368 .27909 L .70195 .27783 L F
0 .111 .583 r
.39043 .51306 m .39131 .51364 L .38922 .5114 L F
.39043 .51306 m .39266 .51482 L .39131 .51364 L F
.385 0 0 r
.59452 .46225 m .59318 .46238 L .5903 .46128 L F
.546 0 0 r
.59452 .46225 m .59719 .46373 L .59318 .46238 L F
.703 .909 .967 r
.59452 .46225 m .59724 .4607 L .59719 .46373 L F
.139 .68 .695 r
.62433 .34321 m .62699 .34268 L .62843 .3424 L F
.044 0 0 r
.62699 .34268 m .63102 .34137 L .62843 .3424 L F
0 .312 .803 r
.32367 .548 m .32584 .55103 L .32574 .54919 L F
.774 .685 .765 r
.32726 .55283 m .32574 .54919 L .32584 .55103 L F
.883 .905 .839 r
.29846 .65039 m .30296 .64773 L .30122 .64976 L F
.706 .432 .506 r
.30296 .64773 m .3063 .64864 L .30567 .65005 L F
.263 0 .012 r
.55488 .42215 m .55846 .4196 L .55645 .42025 L F
0 0 .276 r
.55846 .4196 m .55908 .41502 L .55929 .41733 L F
.811 1 .808 r
.55645 .42025 m .55846 .4196 L .55929 .41733 L F
.614 .936 .72 r
.38664 .6186 m .39072 .61536 L .38769 .61718 L F
.899 .987 .764 r
.38769 .61718 m .39072 .61536 L .3907 .61432 L F
.166 0 0 r
.24615 .52357 m .25093 .52173 L .24874 .52275 L F
.744 .681 .79 r
.6305 .39997 m .63192 .40333 L .62787 .40281 L F
.78 .781 .854 r
.63317 .39888 m .63192 .40333 L .6305 .39997 L F
.63317 .39888 m .63349 .4022 L .63192 .40333 L F
.706 .92 .966 r
.67671 .38096 m .68017 .38051 L .6792 .37942 L F
.771 .941 .936 r
.6792 .37942 m .68017 .38051 L .68416 .37746 L F
.998 .782 .473 r
.2695 .62382 m .27064 .62549 L .27053 .62198 L F
.415 .831 .97 r
.27338 .62168 m .27175 .62113 L .27053 .62198 L F
0 0 0 r
.27175 .62113 m .2695 .62382 L .27053 .62198 L F
.33221 .53586 m .32918 .53814 L .33407 .53483 L F
.846 .693 .693 r
.37087 .55632 m .36911 .55712 L .36887 .55748 L F
.093 .566 .907 r
.3685 .55803 m .36887 .55748 L .3662 .55713 L F
.846 .693 .693 r
.36911 .55712 m .36678 .55819 L .36887 .55748 L F
.093 .566 .907 r
.36863 .55808 m .36887 .55748 L .3685 .55803 L F
.36863 .55808 m .37029 .55855 L .36887 .55748 L F
.428 .195 .456 r
.36761 .56089 m .37029 .55855 L .36863 .55808 L F
.499 .345 .602 r
.21919 .60276 m .22158 .6023 L .22112 .59951 L F
.449 .761 .995 r
.33872 .69608 m .34026 .69733 L .34269 .69696 L F
.179 .04 .442 r
.3314 .64409 m .33006 .6446 L .3313 .64103 L F
.177 .036 .438 r
.3308 .6467 m .33006 .6446 L .3314 .64409 L F
.663 .607 .782 r
.3373 .65596 m .33932 .65848 L .33985 .65577 L F
0 0 .177 r
.32635 .64477 m .32667 .64684 L .32682 .64395 L F
.999 .799 .459 r
.37167 .68719 m .3731 .68527 L .37278 .68788 L F
.37267 .68797 m .37278 .68788 L .37276 .68804 L F
.37167 .68719 m .37278 .68788 L .37267 .68797 L F
.475 .82 .536 r
.37104 .68942 m .37125 .68925 L .37414 .68669 L F
.37389 .68691 m .37414 .68669 L .37452 .68635 L F
.37104 .68942 m .37414 .68669 L .37389 .68691 L F
.698 .837 .949 r
.58771 .36021 m .58912 .36175 L .59194 .36016 L F
.235 .268 .693 r
.47435 .54952 m .47263 .55144 L .47212 .54755 L F
.244 .281 .702 r
.47435 .54952 m .47522 .55338 L .47263 .55144 L F
.271 .281 .687 r
.47263 .55144 m .47522 .55338 L .47351 .55385 L F
.805 .877 .899 r
.35638 .70275 m .35904 .70575 L .3612 .70326 L F
.647 .596 .783 r
.35904 .70575 m .36215 .70552 L .3612 .70326 L F
.698 .983 .84 r
.34443 .54207 m .34391 .54362 L .34649 .54154 L F
.34443 .54207 m .34257 .54379 L .34391 .54362 L F
.62 .861 .989 r
.61018 .35 m .60596 .3499 L .60849 .34907 L F
.622 .918 .978 r
.61127 .34782 m .61018 .35 L .60849 .34907 L F
.61127 .34782 m .61283 .34878 L .61018 .35 L F
.307 0 0 r
.43924 .5984 m .44221 .59852 L .44175 .59851 L F
0 0 0 r
.44221 .59852 m .44427 .59802 L .44175 .59851 L F
.584 .621 .855 r
.3961 .68061 m .39803 .67629 L .39568 .67598 L F
.602 .158 .168 r
.3961 .68061 m .39925 .68306 L .39758 .68369 L F
.449 .879 .901 r
.58739 .37786 m .58672 .37865 L .58277 .37688 L F
.58739 .37786 m .58991 .37774 L .58672 .37865 L F
.61 .33 .468 r
.52853 .47027 m .52476 .4732 L .52581 .47027 L F
.56 .935 .846 r
.61054 .37528 m .61454 .37364 L .61258 .37343 L F
0 0 0 r
.61164 .37439 m .61054 .37528 L .6122 .37382 L F
.429 .871 .867 r
.60933 .37625 m .61118 .37559 L .61054 .37528 L F
.56 .935 .846 r
.61054 .37528 m .61118 .37559 L .61454 .37364 L F
0 0 0 r
.60948 .37659 m .61054 .37528 L .61164 .37439 L F
.429 .871 .867 r
.60861 .37651 m .60933 .37625 L .61054 .37528 L F
0 0 0 r
.60723 .37773 m .60861 .37651 L .61054 .37528 L F
.489 .272 .511 r
.56729 .43191 m .57019 .43127 L .57025 .42815 L F
.496 .277 .512 r
.57025 .42815 m .57019 .43127 L .57268 .42803 L F
.655 .864 .979 r
.70159 .28033 m .70491 .28038 L .70368 .27909 L F
.802 .68 .73 r
.70293 .28396 m .70491 .28038 L .70159 .28033 L F
.686 .914 .579 r
.32617 .58395 m .3235 .58728 L .32456 .58578 L F
.354 .08 .352 r
.32456 .58578 m .32763 .58251 L .32617 .58395 L F
.855 .806 .802 r
.43071 .52833 m .43442 .52635 L .4335 .52508 L F
.43071 .52833 m .43187 .52903 L .43442 .52635 L F
.681 .613 .774 r
.60476 .35894 m .60677 .3628 L .6089 .36114 L F
.883 .892 .47 r
.23253 .54359 m .23572 .54039 L .23404 .54081 L F
.242 .63 .959 r
.23572 .54039 m .2373 .54059 L .23564 .53885 L F
.797 .998 .796 r
.23404 .54081 m .23572 .54039 L .23564 .53885 L F
.765 .681 .77 r
.24865 .55713 m .25026 .5609 L .25301 .55806 L F
.7 .223 .114 r
.26098 .61947 m .26396 .62238 L .26507 .62062 L F
0 .042 .562 r
.26096 .61916 m .26173 .61998 L .26098 .61947 L F
.26173 .61998 m .26396 .62238 L .26098 .61947 L F
.177 0 0 r
.26041 .61908 m .26098 .61947 L .26291 .61883 L F
.25896 .61922 m .26098 .61947 L .26041 .61908 L F
.622 .082 0 r
.26098 .61947 m .26507 .62062 L .26291 .61883 L F
.628 .943 .953 r
.64074 .39079 m .64241 .39141 L .63895 .39265 L F
.519 .897 .96 r
.64516 .39034 m .64241 .39141 L .64074 .39079 L F
.5 .905 .81 r
.62386 .39741 m .61934 .39928 L .62257 .39863 L F
.695 .881 .967 r
.62495 .39506 m .62386 .39741 L .62257 .39863 L F
.949 .912 .746 r
.28822 .64684 m .29042 .64551 L .2902 .64382 L F
.574 .367 .562 r
.48983 .48692 m .48939 .48987 L .48701 .48976 L F
.935 .589 .162 r
.39034 .66913 m .39164 .6704 L .39033 .67027 L F
.889 .781 .736 r
.71273 .33359 m .71393 .33539 L .71275 .33158 L F
.87 .885 .843 r
.70996 .33711 m .71393 .33539 L .71273 .33359 L F
.693 .681 .833 r
.71275 .33158 m .71393 .33539 L .71655 .33253 L F
.523 .589 .862 r
.36845 .56026 m .36761 .56089 L .36649 .55916 L F
.428 .195 .456 r
.36761 .56089 m .37146 .56 L .37029 .55855 L F
.402 .118 .364 r
.36693 .56315 m .37146 .56 L .36761 .56089 L F
.523 .589 .862 r
.36845 .56026 m .36693 .56315 L .36761 .56089 L F
.352 0 0 r
.31243 .62718 m .31434 .62647 L .3168 .62734 L F
.613 .145 .119 r
.31434 .62647 m .31827 .62737 L .3168 .62734 L F
.448 .391 .702 r
.3967 .48248 m .3992 .48227 L .39847 .47835 L F
.3967 .48248 m .39847 .47835 L .39556 .47946 L F
.425 .301 .607 r
.3992 .48227 m .39664 .48594 L .3967 .48248 L F
.507 .882 .973 r
.39451 .48268 m .3992 .48227 L .3967 .48248 L F
.39619 .48253 m .39738 .48189 L .3992 .48227 L F
.39451 .48268 m .39738 .48189 L .39619 .48253 L F
.498 .33 .583 r
.3992 .48227 m .40269 .47814 L .39847 .47835 L F
.421 .5 .835 r
.39859 .47907 m .39955 .48072 L .39738 .48189 L F
.457 .886 .87 r
.39783 .48212 m .3992 .48227 L .39738 .48189 L F
.425 .301 .607 r
.3992 .48227 m .39964 .48507 L .39664 .48594 L F
.343 0 .207 r
.40061 .48242 m .3992 .48227 L .40008 .48309 L F
.4045 .47756 m .3992 .48227 L .40061 .48242 L F
.508 .359 .613 r
.40169 .48162 m .39964 .48507 L .3992 .48227 L F
.457 .886 .87 r
.40141 .48392 m .39964 .48507 L .40169 .48162 L F
.40141 .48392 m .3992 .48227 L .39783 .48212 L F
.343 0 .207 r
.4045 .47756 m .40169 .48162 L .3992 .48227 L F
.498 .33 .583 r
.3992 .48227 m .40169 .48162 L .40269 .47814 L F
.457 .886 .87 r
.40141 .48392 m .40169 .48162 L .3992 .48227 L F
.579 .475 .699 r
.40411 .48595 m .40366 .48571 L .40278 .48237 L F
.421 .5 .835 r
.39938 .48081 m .40141 .48392 L .39738 .48189 L F
.40007 .4816 m .40141 .48392 L .39938 .48081 L F
.623 .83 .431 r
.40407 .47816 m .40169 .48162 L .4045 .47756 L F
.40361 .47878 m .40278 .48 L .40407 .47816 L F
.40278 .48 m .40169 .48162 L .40407 .47816 L F
.82 .414 .277 r
.40505 .47675 m .40603 .47934 L .40596 .47693 L F
.40236 .47624 m .40428 .47786 L .40505 .47675 L F
.40428 .47786 m .40603 .47934 L .40505 .47675 L F
.738 .574 .671 r
.40269 .47814 m .40169 .48162 L .40361 .47878 L F
.446 .513 .834 r
.40278 .48237 m .40141 .48392 L .40135 .48381 L F
.40231 .482 m .40135 .48381 L .39859 .47907 L F
.40278 .48237 m .40135 .48381 L .40231 .482 L F
.40278 .48237 m .39859 .47907 L .40286 .48039 L F
0 0 0 r
.40337 .48051 m .40203 .4832 L .40249 .48165 L F
.40312 .48045 m .40249 .48165 L .40286 .48039 L F
.40337 .48051 m .40249 .48165 L .40312 .48045 L F
.502 .6 .884 r
.40278 .48237 m .40084 .4842 L .40141 .48392 L F
.579 .475 .699 r
.40366 .48571 m .40084 .4842 L .40166 .48343 L F
.40366 .48571 m .40166 .48343 L .40278 .48237 L F
.421 .5 .835 r
.39955 .48072 m .40007 .4816 L .39938 .48081 L F
.978 .682 .369 r
.36513 .69589 m .36676 .69683 L .36665 .69874 L F
.984 .89 .553 r
.41248 .57889 m .41249 .58346 L .41236 .58252 L F
.949 .638 .202 r
.41249 .58346 m .41184 .58491 L .41236 .58252 L F
.41249 .58346 m .41291 .58611 L .41184 .58491 L F
.212 0 .101 r
.46973 .58622 m .46648 .58872 L .46734 .5871 L F
0 .3 .705 r
.38241 .50745 m .38124 .5066 L .37888 .50547 L F
0 .528 .844 r
.38241 .50745 m .38347 .50719 L .38124 .5066 L F
.38241 .50745 m .38533 .50805 L .38347 .50719 L F
.594 .345 .508 r
.5165 .47354 m .51559 .47644 L .51285 .47673 L F
.586 .364 .546 r
.51947 .47336 m .51559 .47644 L .5165 .47354 L F
.444 .299 .589 r
.47197 .51884 m .47218 .52171 L .4698 .52239 L F
.481 .411 .701 r
.47218 .52171 m .47275 .52436 L .4698 .52239 L F
.453 .415 .726 r
.4698 .52239 m .47275 .52436 L .47065 .52484 L F
.9 .981 .798 r
.69641 .28454 m .69455 .28452 L .69492 .28391 L F
.711 .957 .948 r
.69873 .2828 m .69641 .28454 L .69492 .28391 L F
0 0 .489 r
.60027 .39931 m .60219 .40273 L .6014 .40161 L F
.651 .12 0 r
.60219 .40273 m .60265 .40392 L .6014 .40161 L F
.60219 .40273 m .6043 .40504 L .60265 .40392 L F
.046 .028 .511 r
.42737 .58979 m .42805 .59281 L .42909 .59146 L F
0 0 0 r
.35072 .68834 m .35095 .68731 L .34829 .68948 L F
.228 0 0 r
.35329 .68915 m .35095 .68731 L .35072 .68834 L F
.605 .404 .583 r
.35608 .69268 m .35634 .69687 L .35494 .69617 L F
.537 .503 .765 r
.35777 .68842 m .35917 .69213 L .35608 .69268 L F
.39 .243 .558 r
.35861 .69554 m .35608 .69268 L .35917 .69213 L F
.35861 .69554 m .35634 .69687 L .35608 .69268 L F
.506 .364 .622 r
.47166 .51552 m .47432 .51826 L .47197 .51884 L F
.47166 .51552 m .47426 .51499 L .47432 .51826 L F
.17 0 .13 r
.32224 .5885 m .32456 .58578 L .3235 .58728 L F
.566 .482 .719 r
.3515 .58576 m .34908 .58369 L .35155 .58317 L F
.3515 .58576 m .34964 .58641 L .34908 .58369 L F
.869 .975 .668 r
.59201 .37435 m .58991 .37774 L .59039 .37548 L F
.924 .963 .653 r
.59224 .3716 m .59201 .37435 L .59039 .37548 L F
.869 .554 .451 r
.55316 .43234 m .5571 .43225 L .55302 .43119 L F
.55381 .43333 m .5571 .43225 L .55316 .43234 L F
.55669 .43238 m .55708 .43453 L .5571 .43225 L F
.5533 .4335 m .55582 .43419 L .55669 .43238 L F
.55582 .43419 m .55708 .43453 L .55669 .43238 L F
.643 .415 .559 r
.55708 .43453 m .5608 .4317 L .5571 .43225 L F
.8 .533 .535 r
.55306 .4364 m .55708 .43453 L .5533 .4335 L F
.55306 .4364 m .55707 .43708 L .55708 .43453 L F
.81 .533 .519 r
.55307 .43894 m .55707 .43708 L .55306 .4364 L F
0 0 0 r
.55482 .43724 m .55473 .43645 L .55754 .43387 L F
.55473 .43645 m .5547 .43618 L .55496 .43597 L F
.55473 .43645 m .55496 .43597 L .55754 .43387 L F
.223 .245 .673 r
.55754 .43387 m .55534 .43566 L .55528 .43216 L F
.55534 .43566 m .5547 .43618 L .55488 .43495 L F
.55534 .43566 m .55488 .43495 L .55528 .43216 L F
.869 .554 .451 r
.5533 .4335 m .55381 .43333 L .55316 .43234 L F
.267 0 0 r
.30796 .53555 m .31019 .53585 L .31102 .53597 L F
.30796 .53555 m .30723 .53663 L .31019 .53585 L F
.31019 .53585 m .30723 .53663 L .30796 .53555 L F
.753 .654 .752 r
.39468 .48309 m .39165 .48684 L .39034 .48273 L F
.481 .811 1 r
.39034 .48273 m .39274 .48209 L .39468 .48309 L F
0 0 .416 r
.39274 .48209 m .39165 .48684 L .39468 .48309 L F
.39274 .48209 m .3932 .48533 L .39165 .48684 L F
.891 .966 .832 r
.3932 .48533 m .39416 .48635 L .39165 .48684 L F
.667 .778 .932 r
.71655 .33253 m .72107 .33346 L .71937 .33167 L F
.55 .602 .858 r
.72107 .33346 m .72204 .33047 L .71937 .33167 L F
.72107 .33346 m .72355 .33407 L .72204 .33047 L F
.78 .277 0 r
.41401 .59927 m .41396 .60089 L .413 .59761 L F
.41396 .60089 m .41383 .60059 L .413 .59761 L F
.807 .341 0 r
.41252 .59542 m .413 .59761 L .41237 .59683 L F
.788 .741 .81 r
.41682 .59745 m .41392 .60035 L .41865 .59924 L F
.63 .595 .796 r
.413 .59761 m .41395 .60101 L .41237 .59683 L F
.705 .75 .887 r
.41381 .60063 m .41392 .60035 L .41237 .59683 L F
.788 .741 .81 r
.41392 .60035 m .41358 .60069 L .41394 .60058 L F
.41392 .60035 m .41394 .60058 L .41865 .59924 L F
.958 .88 .715 r
.4153 .5968 m .41868 .5943 L .41781 .59313 L F
0 0 0 r
.41641 .59543 m .4153 .5968 L .41677 .59465 L F
.41641 .59543 m .41677 .59465 L .41781 .59313 L F
.857 .94 .875 r
.4153 .5968 m .41403 .60006 L .41682 .59745 L F
.958 .88 .715 r
.4153 .5968 m .41682 .59745 L .41868 .5943 L F
.763 .985 .746 r
.4153 .59782 m .41641 .59543 L .41596 .59771 L F
.41605 .59572 m .4153 .5968 L .41641 .59543 L F
.705 .75 .887 r
.4138 .59898 m .4153 .5968 L .4136 .59682 L F
.41392 .60035 m .4136 .59682 L .41237 .59683 L F
.27 0 0 r
.41237 .59683 m .4153 .5968 L .41301 .59821 L F
.763 .985 .746 r
.41301 .59821 m .4153 .5968 L .41605 .59572 L F
.705 .75 .887 r
.41392 .60035 m .4153 .5968 L .4138 .59898 L F
.857 .94 .875 r
.41373 .60035 m .41379 .60048 L .41682 .59745 L F
.78 .277 0 r
.41396 .60089 m .41395 .60101 L .41383 .60059 L F
.608 .948 .925 r
.41395 .60101 m .41865 .59924 L .41394 .60058 L F
.705 .75 .887 r
.41395 .60101 m .4153 .5968 L .41393 .60031 L F
.41395 .60101 m .41393 .60031 L .41381 .60063 L F
.608 .948 .925 r
.41395 .60101 m .41394 .60058 L .41358 .60069 L F
.857 .94 .875 r
.4153 .5968 m .41373 .60035 L .41403 .60006 L F
.41373 .60035 m .41358 .60069 L .41379 .60048 L F
.705 .75 .887 r
.41395 .60101 m .41358 .60069 L .4153 .5968 L F
.763 .985 .746 r
.41301 .59821 m .41641 .59543 L .4153 .59782 L F
.604 .635 .855 r
.57418 .41616 m .57828 .41904 L .57793 .41649 L F
.027 .122 .628 r
.57793 .41649 m .57828 .41904 L .57924 .4173 L F
.118 .243 .719 r
.57924 .4173 m .57828 .41904 L .58062 .42102 L F
.887 .65 .13 r
.57828 .41904 m .57861 .42227 L .58062 .42102 L F
.957 .775 .326 r
.41326 .57372 m .41301 .57628 L .41242 .57532 L F
.747 .569 0 r
.41294 .56981 m .41326 .57372 L .41311 .57272 L F
.862 .824 .347 r
.41326 .57372 m .41242 .57532 L .41311 .57272 L F
.829 .731 .756 r
.27066 .53742 m .27283 .54153 L .27436 .53856 L F
.589 .835 .991 r
.2534 .55594 m .25301 .55806 L .25528 .55716 L F
.678 .605 .767 r
.33329 .63964 m .3314 .64409 L .3313 .64103 L F
.471 .889 .795 r
.60326 .35072 m .60478 .34952 L .60596 .3499 L F
.60326 .35072 m .6025 .35077 L .60478 .34952 L F
.682 .733 .889 r
.54269 .41416 m .54385 .41668 L .5396 .41515 L F
.506 .634 .91 r
.54544 .41393 m .54385 .41668 L .54269 .41416 L F
.746 .471 .514 r
.54804 .4196 m .54385 .41668 L .54628 .41868 L F
.184 .221 .666 r
.54628 .41868 m .54385 .41668 L .54544 .41393 L F
.799 .524 .521 r
.6248 .36011 m .63044 .36061 L .62802 .3579 L F
.155 .365 .818 r
.62802 .3579 m .63109 .35998 L .63033 .357 L F
.62802 .3579 m .63044 .36061 L .63109 .35998 L F
0 .205 .625 r
.37443 .51656 m .3747 .51678 L .37358 .51483 L F
.37443 .51656 m .37738 .51843 L .3747 .51678 L F
0 0 0 r
.62641 .36727 m .62863 .36418 L .62943 .36639 L F
.136 0 .341 r
.6314 .36257 m .62943 .36639 L .62863 .36418 L F
.975 .705 .454 r
.32897 .52269 m .32695 .52364 L .32765 .52158 L F
0 0 0 r
.32765 .52158 m .33096 .51996 L .32897 .52269 L F
.578 .042 0 r
.33113 .52418 m .32695 .52364 L .32897 .52269 L F
.516 .158 .299 r
.33183 .5224 m .33113 .52418 L .32897 .52269 L F
.809 .975 .901 r
.59039 .37548 m .58991 .37774 L .58739 .37786 L F
.497 .161 .327 r
.30183 .56743 m .30122 .56936 L .29871 .56951 L F
.385 .058 .284 r
.30183 .56743 m .30362 .56893 L .30122 .56936 L F
.446 .045 .185 r
.30446 .56722 m .30362 .56893 L .30183 .56743 L F
.825 .864 .415 r
.38521 .62237 m .38664 .6186 L .38544 .62065 L F
0 0 0 r
.38544 .62065 m .38664 .6186 L .38769 .61718 L F
0 0 .01 r
.6689 .313 m .66633 .31643 L .66816 .31439 L F
.509 .852 .583 r
.66633 .31643 m .66815 .31472 L .66816 .31439 L F
.66633 .31643 m .6651 .31735 L .66815 .31472 L F
.283 .627 .962 r
.27681 .61631 m .27618 .61759 L .27427 .61673 L F
.27681 .61631 m .27861 .61787 L .27618 .61759 L F
.99 .726 .385 r
.39648 .55595 m .39784 .55448 L .39649 .55294 L F
.39648 .55595 m .3979 .55689 L .39784 .55448 L F
0 0 .145 r
.69589 .33167 m .69475 .33548 L .69319 .3344 L F
.995 .786 .419 r
.69475 .33548 m .69375 .33587 L .69319 .3344 L F
.69465 .33658 m .69455 .33781 L .69375 .33587 L F
0 0 .432 r
.69375 .33587 m .69455 .33781 L .69539 .33927 L F
.69375 .33587 m .69539 .33927 L .69566 .33866 L F
.7 .217 0 r
.69276 .3351 m .69375 .33587 L .69566 .33866 L F
.69254 .33482 m .69375 .33587 L .69276 .3351 L F
.995 .786 .419 r
.69475 .33548 m .69465 .33658 L .69375 .33587 L F
.474 .475 .778 r
.24954 .53378 m .25107 .53851 L .24861 .53832 L F
.24954 .53378 m .24861 .53832 L .24922 .53671 L F
.327 .644 .967 r
.24922 .53671 m .25107 .53851 L .24861 .53832 L F
.88 .445 .123 r
.32535 .54143 m .3223 .53893 L .32348 .53713 L F
0 0 .12 r
.32644 .54185 m .32535 .54143 L .32548 .53869 L F
.877 .597 .511 r
.33039 .54189 m .33107 .54309 L .33078 .54027 L F
.544 .351 .57 r
.33078 .54027 m .33107 .54309 L .33366 .54239 L F
0 0 .12 r
.32637 .54197 m .32539 .54353 L .32536 .54198 L F
.32535 .54143 m .32539 .54353 L .32644 .54185 L F
0 0 0 r
.32644 .54185 m .32417 .54593 L .32539 .54353 L F
.32644 .54185 m .32417 .54593 L .32539 .54353 L F
.978 .838 .636 r
.32608 .542 m .32818 .54477 L .33039 .54189 L F
0 0 0 r
.3329 .54186 m .32779 .54196 L .33039 .54189 L F
.32779 .54196 m .32608 .542 L .32738 .54197 L F
.32779 .54196 m .32738 .54197 L .33039 .54189 L F
0 0 .12 r
.32644 .54185 m .32637 .54197 L .32535 .54143 L F
.32637 .54197 m .32536 .54198 L .32535 .54143 L F
0 0 .507 r
.32548 .53869 m .32644 .54185 L .32535 .54143 L F
.975 .901 .68 r
.39767 .56363 m .3988 .56128 L .39793 .55912 L F
.335 0 0 r
.45228 .57212 m .45368 .57156 L .44796 .57212 L F
.001 0 0 r
.45506 .57178 m .45368 .57156 L .45228 .57212 L F
.45506 .57178 m .45622 .57068 L .45368 .57156 L F
.176 0 0 r
.27232 .54438 m .27559 .54237 L .27283 .54153 L F
.757 .302 .171 r
.27559 .54237 m .27467 .54381 L .27893 .5441 L F
.553 .082 .09 r
.54167 .47088 m .54571 .4707 L .54432 .47241 L F
.459 0 .032 r
.54432 .47241 m .54571 .4707 L .54882 .47178 L F
0 0 0 r
.36316 .52544 m .36196 .52679 L .36013 .52719 L F
.847 .754 .76 r
.36456 .52174 m .36316 .52544 L .36157 .52222 L F
.985 .709 .394 r
.36316 .52544 m .36196 .52679 L .36157 .52222 L F
.619 .633 .843 r
.55175 .39899 m .55508 .39625 L .55251 .3968 L F
.989 .811 .424 r
.22619 .57018 m .22859 .56767 L .22773 .56944 L F
0 0 0 r
.22946 .5665 m .22773 .56944 L .22859 .56767 L F
.511 .339 .584 r
.35434 .53134 m .35435 .53482 L .35185 .53537 L F
.47 .228 .465 r
.35403 .53729 m .35185 .53537 L .35435 .53482 L F
.35403 .53729 m .3515 .53809 L .35185 .53537 L F
.718 .581 .7 r
.48939 .48987 m .48722 .49266 L .48701 .48976 L F
.849 .992 .844 r
.4123 .47524 m .41368 .47264 L .41517 .47637 L F
.776 .806 .877 r
.41739 .47264 m .41517 .47637 L .41368 .47264 L F
.359 .501 .864 r
.27893 .5441 m .27711 .53969 L .27884 .54118 L F
.27893 .5441 m .27952 .53963 L .27711 .53969 L F
0 0 0 r
.3784 .60274 m .37745 .6029 L .38022 .6028 L F
.397 .849 .903 r
.37715 .6034 m .3784 .60274 L .38022 .6028 L F
0 0 0 r
.3784 .60274 m .37596 .60509 L .37745 .6029 L F
.328 .81 .881 r
.38162 .6021 m .3784 .60274 L .38022 .6028 L F
.499 .158 .32 r
.38162 .6021 m .3784 .60274 L .38022 .6028 L F
.664 .605 .779 r
.36304 .51746 m .36529 .51924 L .36146 .51879 L F
.581 .359 .543 r
.36417 .52166 m .36146 .51879 L .36529 .51924 L F
.36417 .52166 m .36157 .52222 L .36146 .51879 L F
.405 0 0 r
.28984 .57295 m .29049 .57431 L .28755 .57438 L F
.28984 .57295 m .29245 .57341 L .29049 .57431 L F
.792 .575 .607 r
.30653 .63756 m .31062 .63809 L .31003 .64079 L F
.789 .666 .727 r
.36567 .70569 m .36883 .70686 L .36835 .70361 L F
.728 .469 .537 r
.36548 .70845 m .36883 .70686 L .36567 .70569 L F
.36548 .70845 m .36972 .70748 L .36883 .70686 L F
.522 .477 .747 r
.36835 .70361 m .36883 .70686 L .37142 .70471 L F
.497 .46 .746 r
.36972 .70748 m .37142 .70471 L .36883 .70686 L F
.239 .565 .937 r
.38831 .67413 m .39286 .6768 L .39135 .67527 L F
.569 .87 .995 r
.39286 .6768 m .39439 .67499 L .39135 .67527 L F
.39286 .6768 m .39568 .67598 L .39439 .67499 L F
0 .087 .646 r
.23981 .61721 m .2396 .6186 L .24148 .6205 L F
.533 .399 .644 r
.47599 .50618 m .47621 .50876 L .47366 .50943 L F
.415 .314 .631 r
.47621 .50876 m .47452 .5123 L .47366 .50943 L F
0 0 .029 r
.5584 .40935 m .55737 .41141 L .55813 .41102 L F
.821 .934 .562 r
.56049 .4051 m .5584 .40935 L .55899 .40863 L F
0 0 0 r
.55899 .40863 m .5584 .40935 L .55813 .41102 L F
.487 .813 1 r
.62496 .37886 m .6266 .38015 L .62911 .37939 L F
.62496 .37886 m .6266 .38015 L .62911 .37939 L F
.598 .395 .577 r
.48457 .49326 m .48276 .49945 L .48048 .49598 L F
.322 .17 .514 r
.4423 .57717 m .44184 .57972 L .44379 .57913 L F
.4423 .57717 m .44184 .57972 L .44379 .57913 L F
0 0 0 r
.41859 .5993 m .42174 .59558 L .42047 .59785 L F
.152 .594 .932 r
.42174 .59558 m .42482 .59628 L .42284 .59515 L F
0 .11 .636 r
.42122 .59219 m .42284 .59515 L .42174 .59558 L F
.152 .594 .932 r
.42174 .59558 m .42482 .59628 L .42284 .59515 L F
0 0 0 r
.42174 .59558 m .42284 .59515 L .42047 .59785 L F
.702 .45 .54 r
.72737 .33486 m .73033 .33491 L .73076 .33252 L F
.356 .138 .438 r
.73076 .33252 m .73033 .33491 L .73289 .33372 L F
.829 .554 .521 r
.39679 .68553 m .39925 .68306 L .39758 .68369 L F
.39679 .68553 m .39938 .68464 L .39925 .68306 L F
.869 .586 .06 r
.40994 .55432 m .40956 .55576 L .40891 .55271 L F
.40994 .55432 m .41032 .55677 L .40956 .55576 L F
.404 0 0 r
.34121 .68227 m .34094 .6808 L .33901 .68259 L F
.707 .814 .931 r
.43591 .46067 m .43204 .46043 L .43506 .4597 L F
.75 .826 .911 r
.4388 .45839 m .43591 .46067 L .43506 .4597 L F
.813 .365 .173 r
.55238 .42653 m .555 .42618 L .55182 .4246 L F
.55238 .42653 m .55572 .42785 L .555 .42618 L F
.781 .63 .693 r
.38179 .67736 m .38629 .67682 L .38519 .67496 L F
.71 .384 .424 r
.38367 .67839 m .38629 .67682 L .38179 .67736 L F
.697 .604 .748 r
.38519 .67496 m .38629 .67682 L .38831 .67413 L F
.466 .882 .76 r
.23541 .59774 m .23142 .59977 L .23379 .599 L F
.165 .049 .466 r
.21449 .56728 m .21583 .56936 L .21619 .56569 L F
.21449 .56728 m .21447 .56999 L .21583 .56936 L F
.462 .801 .999 r
.28797 .51917 m .28602 .51809 L .28371 .51854 L F
.198 0 0 r
.29038 .51856 m .28602 .51809 L .28797 .51917 L F
0 0 0 r
.66816 .31439 m .6708 .31133 L .6689 .313 L F
0 0 .067 r
.55737 .41141 m .55363 .41543 L .55661 .41463 L F
0 0 0 r
.55661 .41463 m .55363 .41543 L .55155 .41656 L F
.778 .593 .65 r
.34806 .63601 m .35354 .63861 L .34984 .6384 L F
.627 .413 .572 r
.44083 .52837 m .44356 .52807 L .44359 .5254 L F
.587 .381 .569 r
.44359 .5254 m .44627 .52752 L .44675 .52513 L F
.44359 .5254 m .44356 .52807 L .44627 .52752 L F
.458 .349 .643 r
.4734 .5268 m .47065 .52484 L .47275 .52436 L F
.4734 .5268 m .47075 .52875 L .47065 .52484 L F
.719 .848 .943 r
.5332 .41811 m .535 .41985 L .52875 .4209 L F
.854 .869 .851 r
.5362 .41629 m .535 .41985 L .5332 .41811 L F
.691 .98 .828 r
.66168 .38926 m .66313 .38711 L .66089 .38881 L F
.66168 .38926 m .66475 .38684 L .66313 .38711 L F
.876 .445 .048 r
.60443 .4351 m .60527 .43725 L .60681 .43836 L F
.959 .647 .39 r
.60518 .43985 m .60681 .43836 L .60527 .43725 L F
.60518 .43985 m .6069 .44108 L .60681 .43836 L F
.793 .344 0 r
.3931 .66002 m .39345 .6619 L .3914 .65925 L F
.3931 .66002 m .39458 .66284 L .39345 .6619 L F
.722 .818 .925 r
.4912 .43818 m .48906 .4398 L .48726 .43787 L F
.716 .425 .484 r
.56365 .4342 m .56729 .43191 L .56385 .43149 L F
.56365 .4342 m .5672 .43494 L .56729 .43191 L F
.529 .272 .469 r
.56729 .43191 m .5703 .43402 L .57019 .43127 L F
.56729 .43191 m .5672 .43494 L .5703 .43402 L F
.511 .848 .997 r
.39945 .47699 m .39789 .47605 L .40236 .47624 L F
.638 .796 .958 r
.44254 .45904 m .4388 .45839 L .44103 .45724 L F
.627 .823 .976 r
.4436 .45681 m .44254 .45904 L .44103 .45724 L F
.4436 .45681 m .44521 .45821 L .44254 .45904 L F
.897 .907 .823 r
.6208 .43194 m .62349 .43079 L .6222 .43038 L F
.439 .202 .456 r
.34899 .61012 m .34997 .61227 L .34783 .61269 L F
.324 .183 .53 r
.35246 .60765 m .34997 .61227 L .34899 .61012 L F
.78 .71 .787 r
.50823 .428 m .5068 .43197 L .5029 .43137 L F
.8 .733 .791 r
.50945 .42871 m .5068 .43197 L .50823 .428 L F
.958 .634 .361 r
.60007 .42426 m .59989 .4223 L .59818 .4212 L F
.692 .392 .461 r
.43369 .53064 m .43691 .53114 L .43753 .52892 L F
.687 .386 .46 r
.43753 .52892 m .44085 .53114 L .44083 .52837 L F
.43753 .52892 m .43691 .53114 L .44085 .53114 L F
.79 .701 .765 r
.3782 .58278 m .3798 .58655 L .37562 .58589 L F
.332 0 0 r
.37562 .58589 m .3798 .58655 L .37814 .58645 L F
.554 .58 .835 r
.38217 .58551 m .3798 .58655 L .3782 .58278 L F
.525 .902 .956 r
.37814 .58645 m .3798 .58655 L .38217 .58551 L F
.704 .198 0 r
.29302 .66057 m .29349 .6619 L .29076 .6604 L F
.29302 .66057 m .295 .66301 L .29349 .6619 L F
.513 .004 0 r
.35091 .63332 m .35381 .63192 L .34897 .63192 L F
.726 .818 .922 r
.45683 .45335 m .46066 .45365 L .45875 .45495 L F
.553 .501 .752 r
.35651 .52848 m .35434 .53134 L .35355 .52962 L F
.35651 .52848 m .35681 .53081 L .35434 .53134 L F
.719 .505 .6 r
.35798 .53443 m .35434 .53134 L .35681 .53081 L F
.35798 .53443 m .35435 .53482 L .35434 .53134 L F
.918 .586 .119 r
.41191 .56064 m .41071 .55932 L .41032 .55677 L F
.958 .66 .234 r
.41191 .56064 m .41104 .56207 L .41071 .55932 L F
.41191 .56064 m .41193 .56346 L .41104 .56207 L F
.341 0 .177 r
.3063 .64864 m .30805 .64981 L .30567 .65005 L F
.3063 .64864 m .3092 .64737 L .30805 .64981 L F
.18 .088 .508 r
.21289 .577 m .21497 .57573 L .21482 .57271 L F
.081 .025 .488 r
.21289 .577 m .21457 .57765 L .21497 .57573 L F
.21289 .577 m .21312 .5798 L .21457 .57765 L F
.501 .302 .543 r
.27064 .62549 m .27402 .6267 L .27338 .62168 L F
.712 .944 .957 r
.27389 .61976 m .27338 .62168 L .27562 .62085 L F
.27389 .61976 m .27175 .62113 L .27338 .62168 L F
.806 .52 .504 r
.27338 .62168 m .27402 .6267 L .27736 .62514 L F
.633 .223 .249 r
.53508 .47048 m .53927 .47034 L .5377 .47244 L F
.643 .235 .256 r
.53927 .47034 m .54169 .47242 L .5377 .47244 L F
.645 .234 .249 r
.53927 .47034 m .54167 .47088 L .54169 .47242 L F
.996 .771 .467 r
.38719 .66694 m .38639 .66308 L .38867 .66519 L F
.643 .228 .242 r
.38862 .66987 m .39034 .66913 L .38719 .66694 L F
.38862 .66987 m .38719 .66694 L .38867 .66519 L F
.569 .521 .761 r
.34783 .61269 m .34873 .61495 L .34602 .61324 L F
.956 .811 .659 r
.52138 .41266 m .51854 .41444 L .52188 .41144 L F
.52138 .41266 m .52018 .41594 L .51854 .41444 L F
.604 .941 .943 r
.52539 .41049 m .52138 .41266 L .52188 .41144 L F
.854 .957 .876 r
.66831 .32818 m .66927 .3293 L .67204 .32641 L F
.857 .815 .807 r
.50088 .43294 m .49632 .43419 L .49936 .43155 L F
.50088 .43294 m .49996 .43393 L .49632 .43419 L F
.719 .885 .957 r
.5029 .43137 m .50088 .43294 L .49936 .43155 L F
.915 .943 .806 r
.35367 .64327 m .35192 .64813 L .3513 .64603 L F
.797 .712 .771 r
.6211 .38905 m .62239 .39302 L .62491 .38909 L F
.628 .943 .953 r
.64074 .39079 m .63895 .39265 L .63852 .39253 L F
.471 .109 .27 r
.27247 .57318 m .27507 .57287 L .27622 .57105 L F
.967 .668 .406 r
.72647 .32419 m .72769 .32352 L .72767 .32125 L F
.72647 .32419 m .72782 .32548 L .72769 .32352 L F
.633 .828 .976 r
.24234 .52972 m .24274 .53089 L .24256 .53084 L F
.775 .823 .351 r
.46213 .56114 m .46122 .56338 L .46256 .55962 L F
.056 0 .164 r
.43261 .5376 m .43448 .53721 L .43506 .53504 L F
.058 0 .174 r
.43261 .5376 m .43223 .54015 L .43448 .53721 L F
.842 .971 .88 r
.69317 .28956 m .69052 .2924 L .68953 .29134 L F
.255 .546 .926 r
.3531 .7019 m .35451 .70394 L .35638 .70275 L F
.619 .443 .621 r
.34294 .61333 m .33891 .61519 L .33993 .61166 L F
.34294 .61333 m .33917 .61833 L .33891 .61519 L F
.908 .931 .556 r
.32596 .59108 m .3242 .59628 L .32485 .59315 L F
.982 .696 .344 r
.28398 .64653 m .28538 .64776 L .28545 .65033 L F
.385 .191 .49 r
.28545 .65033 m .28538 .64776 L .28822 .64684 L F
.718 .859 .948 r
.45346 .45323 m .45181 .45664 L .45013 .45515 L F
.45346 .45323 m .45535 .45438 L .45181 .45664 L F
.812 .607 .625 r
.22619 .57018 m .22535 .573 L .2296 .5735 L F
.733 .731 .209 r
.22573 .5715 m .22491 .5748 L .22484 .5753 L F
.22508 .57444 m .22484 .5753 L .22478 .57579 L F
.652 .443 .587 r
.22535 .573 m .22478 .57579 L .22808 .57535 L F
.733 .731 .209 r
.22573 .5715 m .22478 .57579 L .22535 .573 L F
.22573 .5715 m .22484 .5753 L .22508 .57444 L F
.652 .443 .587 r
.22547 .57302 m .22808 .57535 L .2296 .5735 L F
.22535 .573 m .22545 .57309 L .22547 .57302 L F
.22545 .57309 m .22808 .57535 L .22547 .57302 L F
.666 .254 .254 r
.22808 .57535 m .23141 .57592 L .2296 .5735 L F
.832 .487 0 r
.4072 .54406 m .40561 .54022 L .40713 .54145 L F
.484 .898 .818 r
.57588 .46262 m .57773 .46225 L .58007 .46106 L F
.365 .468 .832 r
.34843 .64481 m .3498 .64707 L .3513 .64603 L F
.428 .834 .638 r
.3513 .64603 m .3498 .64707 L .34661 .64898 L F
.81 .658 .694 r
.4218 .58537 m .42581 .58591 L .42951 .58411 L F
.063 .343 .819 r
.33206 .50054 m .3317 .50209 L .33331 .50269 L F
.801 .83 .873 r
.36816 .68091 m .36685 .68064 L .36869 .67907 L F
0 0 0 r
.45483 .59263 m .45387 .59315 L .44976 .59466 L F
.45718 .59197 m .45387 .59315 L .45483 .59263 L F
.847 .754 .76 r
.36456 .52174 m .36157 .52222 L .36417 .52166 L F
0 .058 .578 r
.2207 .59557 m .22112 .59951 L .22226 .59789 L F
.525 .362 .603 r
.22112 .59951 m .22419 .60147 L .22226 .59789 L F
.22112 .59951 m .22158 .6023 L .22419 .60147 L F
.519 .741 .975 r
.71224 .28519 m .7135 .28705 L .7149 .28473 L F
.71224 .28519 m .7135 .28705 L .7149 .28473 L F
0 0 0 r
.36692 .60557 m .36947 .60182 L .36639 .6029 L F
.536 .172 .296 r
.53022 .40504 m .53366 .40484 L .53384 .40226 L F
0 0 .171 r
.53384 .40226 m .53498 .40327 L .53571 .40177 L F
.53384 .40226 m .53366 .40484 L .53498 .40327 L F
.426 .297 .601 r
.29419 .6253 m .29664 .62749 L .29695 .62461 L F
.29419 .6253 m .2944 .62813 L .29664 .62749 L F
.834 .624 .619 r
.26507 .62062 m .27045 .62216 L .26912 .61814 L F
0 0 0 r
.26912 .61814 m .27041 .61781 L .27177 .61722 L F
.94 .905 .761 r
.27045 .62216 m .27044 .62075 L .26986 .62038 L F
.656 .117 0 r
.26507 .62062 m .26746 .62237 L .27045 .62216 L F
.94 .905 .761 r
.26986 .62038 m .27041 .61781 L .26912 .61814 L F
.27044 .62075 m .27041 .61781 L .26986 .62038 L F
.27045 .62216 m .26861 .62098 L .27041 .61781 L F
.956 .891 .725 r
.26861 .62098 m .26746 .62237 L .27045 .62216 L F
.841 .836 .84 r
.26774 .62229 m .2695 .62382 L .27175 .62113 L F
.26746 .62237 m .26756 .62244 L .26774 .62229 L F
.26756 .62244 m .2695 .62382 L .26774 .62229 L F
.26746 .62237 m .27125 .62127 L .26936 .62297 L F
.392 .075 .303 r
.26939 .62095 m .26936 .62297 L .27076 .62088 L F
.26861 .62098 m .26878 .62144 L .26939 .62095 L F
.26878 .62144 m .26936 .62297 L .26939 .62095 L F
.841 .836 .84 r
.27125 .62127 m .27175 .62113 L .27142 .62138 L F
.27125 .62127 m .27142 .62138 L .26936 .62297 L F
.514 .769 .989 r
.45138 .53673 m .45305 .53818 L .45548 .53742 L F
.429 .298 .6 r
.45305 .53818 m .45544 .54013 L .45548 .53742 L F
.361 .028 .258 r
.30624 .54708 m .30339 .54823 L .30461 .54648 L F
.489 .637 .92 r
.35768 .63151 m .35671 .63479 L .35434 .63622 L F
.35768 .63151 m .35996 .63513 L .35671 .63479 L F
.581 .367 .555 r
.35671 .63479 m .35713 .63762 L .3574 .63799 L F
.35671 .63479 m .35996 .63513 L .35713 .63762 L F
.895 .988 .761 r
.32935 .57871 m .32921 .5807 L .32763 .58251 L F
.415 .314 .631 r
.47621 .50876 m .47666 .51144 L .47452 .5123 L F
.49 .336 .599 r
.47666 .51144 m .47426 .51499 L .47452 .5123 L F
.802 .68 .73 r
.70293 .28396 m .70159 .28033 L .702 .28224 L F
0 0 .07 r
.70304 .28266 m .70293 .28396 L .702 .28224 L F
.70304 .28266 m .70302 .28652 L .70293 .28396 L F
.728 .293 .217 r
.68305 .35345 m .68388 .3514 L .68004 .35068 L F
.754 .498 .544 r
.68305 .35345 m .68657 .35073 L .68388 .3514 L F
0 0 .28 r
.47662 .57592 m .47502 .57959 L .47546 .5769 L F
.434 .314 .617 r
.25798 .5511 m .26043 .5535 L .25989 .55102 L F
.507 .165 .322 r
.32717 .50045 m .33062 .50074 L .32985 .5006 L F
.307 .391 .785 r
.21312 .5798 m .21436 .58352 L .21593 .58174 L F
.308 .304 .692 r
.21488 .58604 m .21593 .58174 L .21436 .58352 L F
.027 .006 .493 r
.3771 .66934 m .37628 .67278 L .37843 .67334 L F
.783 .668 .736 r
.3771 .66934 m .37807 .67226 L .37475 .67287 L F
.37807 .67226 m .37843 .67334 L .37684 .67313 L F
0 0 0 r
.37494 .674 m .37171 .67635 L .37261 .67613 L F
.37628 .67278 m .37484 .67391 L .37494 .674 L F
.37484 .67391 m .37171 .67635 L .37494 .674 L F
.37628 .67278 m .37261 .67613 L .37514 .67433 L F
.62 .207 .239 r
.37628 .67278 m .37619 .67527 L .37411 .67575 L F
.37628 .67278 m .37843 .67334 L .37619 .67527 L F
.783 .668 .736 r
.37807 .67226 m .37684 .67313 L .37475 .67287 L F
.756 .394 .368 r
.37475 .67287 m .37843 .67334 L .37619 .67527 L F
.809 .954 .617 r
.3771 .66934 m .37475 .67287 L .37504 .67136 L F
0 .007 .579 r
.37475 .67287 m .37599 .67494 L .37504 .67136 L F
.37599 .67494 m .37619 .67527 L .37613 .67506 L F
.37599 .67494 m .37613 .67506 L .37504 .67136 L F
0 0 0 r
.37514 .67433 m .37261 .67613 L .37411 .67575 L F
.926 .555 .289 r
.61402 .42866 m .61274 .42995 L .61247 .42757 L F
.61402 .42866 m .61457 .43086 L .61274 .42995 L F
.88 .72 .679 r
.69775 .30864 m .699 .31287 L .69822 .31203 L F
.835 .582 .557 r
.699 .31287 m .69568 .31412 L .69822 .31203 L F
.699 .31287 m .6994 .31557 L .69568 .31412 L F
.619 .607 .817 r
.70022 .30813 m .699 .31287 L .69775 .30864 L F
.70022 .30813 m .70186 .31239 L .699 .31287 L F
.584 .408 .608 r
.70186 .31239 m .6994 .31557 L .699 .31287 L F
.583 .143 .17 r
.36692 .60557 m .36873 .60732 L .36647 .60712 L F
0 0 0 r
.36692 .60557 m .36647 .60712 L .36947 .60182 L F
0 0 .004 r
.36947 .60182 m .37163 .60176 L .37177 .60151 L F
.36947 .60182 m .36647 .60712 L .37163 .60176 L F
.521 .364 .609 r
.47845 .5033 m .47599 .50618 L .47588 .50416 L F
.053 .405 .858 r
.27572 .6384 m .2779 .64097 L .2782 .6397 L F
0 .209 .735 r
.2782 .6397 m .2779 .64097 L .28058 .64315 L F
.999 .811 .47 r
.42814 .56199 m .429 .56638 L .42809 .56373 L F
.877 .993 .784 r
.34415 .62255 m .34615 .61917 L .34332 .62156 L F
.598 .559 .782 r
.353 .54116 m .35675 .54407 L .35555 .54062 L F
.558 .732 .957 r
.71789 .31407 m .71585 .31695 L .71564 .31525 L F
.71789 .31407 m .71956 .31618 L .71585 .31695 L F
.517 .263 .469 r
.27317 .62756 m .27402 .6267 L .27064 .62549 L F
0 .134 .64 r
.27181 .62607 m .27064 .62549 L .2695 .62382 L F
.27181 .62607 m .27317 .62756 L .27064 .62549 L F
.554 .184 .293 r
.30901 .54682 m .31224 .54748 L .3126 .54404 L F
.164 0 .134 r
.3126 .54404 m .31403 .54491 L .31575 .54181 L F
.065 0 .19 r
.3126 .54404 m .31408 .54572 L .31403 .54491 L F
.3126 .54404 m .31224 .54748 L .31408 .54572 L F
.592 .949 .868 r
.64258 .33408 m .64025 .33559 L .64164 .33394 L F
.548 .83 .487 r
.64025 .33559 m .63909 .33684 L .64164 .33394 L F
.8 .733 .791 r
.50945 .42871 m .50823 .428 L .50826 .42742 L F
.858 .93 .872 r
.50945 .42871 m .51103 .42448 L .51258 .42607 L F
.50945 .42871 m .50826 .42742 L .51103 .42448 L F
.122 .375 .834 r
.5397 .40059 m .53736 .40085 L .53941 .39908 L F
.897 .749 .249 r
.24234 .52972 m .24223 .53402 L .24256 .53084 L F
.554 .895 .981 r
.25744 .51828 m .25809 .51679 L .26001 .51728 L F
.661 .972 .882 r
.25744 .51828 m .25603 .51833 L .25809 .51679 L F
.497 .46 .746 r
.36972 .70748 m .3721 .70848 L .37142 .70471 L F
.185 .692 .904 r
.5903 .46128 m .58964 .46078 L .58622 .46079 L F
.17 .427 .863 r
.5903 .46128 m .59132 .45887 L .58964 .46078 L F
.5903 .46128 m .59318 .46238 L .59132 .45887 L F
.908 .499 .145 r
.60759 .41231 m .60708 .41389 L .60586 .41131 L F
.60759 .41231 m .60872 .41507 L .60708 .41389 L F
.517 .057 .1 r
.52539 .41049 m .52763 .41101 L .52855 .40926 L F
.312 0 .011 r
.52855 .40926 m .52763 .41101 L .53121 .40986 L F
.456 .831 .99 r
.28123 .62929 m .28285 .63001 L .28094 .63052 L F
.98 .742 .505 r
.28117 .63017 m .28285 .63001 L .28123 .62929 L F
.157 .695 .717 r
.28458 .62984 m .28094 .63052 L .28285 .63001 L F
.98 .742 .505 r
.28106 .63186 m .28285 .63001 L .28117 .63017 L F
.157 .695 .717 r
.28521 .62972 m .28458 .62984 L .28285 .63001 L F
.383 0 0 r
.28679 .63094 m .28521 .62972 L .28285 .63001 L F
.28679 .63094 m .28895 .63063 L .28521 .62972 L F
.677 .765 .917 r
.4463 .53448 m .44801 .5352 L .44793 .53326 L F
.386 .523 .872 r
.44793 .53326 m .44801 .5352 L .44999 .53325 L F
.529 .367 .606 r
.44801 .5352 m .45138 .53673 L .44999 .53325 L F
.44801 .5352 m .44892 .53767 L .45138 .53673 L F
.747 .989 .892 r
.29674 .53969 m .29608 .54163 L .29835 .53938 L F
.549 .52 .775 r
.29608 .54163 m .2988 .54158 L .29844 .53981 L F
.29753 .54019 m .29844 .53981 L .29835 .53938 L F
.29608 .54163 m .29844 .53981 L .29753 .54019 L F
.449 .713 .98 r
.29608 .54163 m .2988 .54158 L .29788 .54073 L F
.29625 .54113 m .29788 .54073 L .29674 .53969 L F
.29608 .54163 m .29788 .54073 L .29625 .54113 L F
.467 .296 .564 r
.30107 .53755 m .2988 .54158 L .29835 .53938 L F
.30107 .53755 m .30114 .54062 L .2988 .54158 L F
.433 0 0 r
.30114 .54062 m .29912 .54019 L .2988 .54158 L F
0 0 .418 r
.30255 .53893 m .30114 .54062 L .30112 .54 L F
.30255 .53893 m .30112 .54 L .30107 .53755 L F
.433 0 0 r
.29912 .54019 m .29788 .54073 L .2988 .54158 L F
0 0 .418 r
.29961 .53995 m .29872 .54025 L .29804 .54104 L F
.433 0 0 r
.29857 .54043 m .29674 .53969 L .29788 .54073 L F
.845 .683 .681 r
.29674 .53969 m .30107 .53755 L .29835 .53938 L F
.29674 .53969 m .29857 .54043 L .30107 .53755 L F
.433 0 0 r
.29912 .54019 m .29674 .53969 L .29857 .54043 L F
.845 .683 .681 r
.29674 .53969 m .29804 .54104 L .29857 .54043 L F
.433 0 0 r
.29912 .54019 m .29849 .54069 L .29674 .53969 L F
.634 .856 .984 r
.29877 .5407 m .29804 .54104 L .29817 .54067 L F
.433 0 0 r
.29849 .54069 m .29835 .5408 L .29817 .54067 L F
.29849 .54069 m .29817 .54067 L .29674 .53969 L F
.30114 .54062 m .29812 .54167 L .29912 .54019 L F
0 0 .418 r
.29961 .54031 m .29882 .5405 L .29804 .54104 L F
.433 0 0 r
.29812 .54167 m .29655 .54222 L .29912 .54019 L F
0 0 .418 r
.29931 .5399 m .2995 .53936 L .29872 .54025 L F
.30192 .53834 m .29975 .53926 L .29931 .5399 L F
.29975 .53926 m .2995 .53936 L .29931 .5399 L F
.30192 .53834 m .29872 .54025 L .29961 .53995 L F
.30255 .53893 m .30238 .53877 L .29882 .5405 L F
.30238 .53877 m .30192 .53834 L .2995 .54003 L F
.30238 .53877 m .2995 .54003 L .29882 .5405 L F
.30255 .53893 m .29882 .5405 L .29961 .54031 L F
.30192 .53834 m .30107 .53755 L .2995 .53936 L F
.006 0 .347 r
.29674 .53969 m .29823 .53884 L .29887 .53864 L F
.271 .759 .916 r
.29823 .53884 m .29864 .53885 L .29887 .53864 L F
.29864 .53885 m .30255 .53893 L .29887 .53864 L F
.29823 .53884 m .30006 .53848 L .30022 .53851 L F
.29864 .53885 m .29881 .53881 L .30255 .53893 L F
.634 .856 .984 r
.30066 .53982 m .29877 .5407 L .29885 .53912 L F
.368 .569 .915 r
.29864 .53885 m .29817 .54067 L .29728 .54006 L F
.29881 .53881 m .29817 .54067 L .29864 .53885 L F
.29887 .53864 m .29728 .54006 L .29674 .53969 L F
.634 .856 .984 r
.29877 .5407 m .29817 .54067 L .29885 .53869 L F
.29887 .53868 m .29885 .53869 L .29887 .53864 L F
.29877 .5407 m .29885 .53869 L .29887 .53868 L F
.368 .569 .915 r
.29817 .54067 m .29804 .54104 L .29674 .53969 L F
.433 0 0 r
.29835 .5408 m .29655 .54222 L .29674 .53969 L F
.30114 .54062 m .29909 .54234 L .29655 .54222 L F
.571 .529 .769 r
.29655 .54222 m .29909 .54234 L .29827 .53896 L F
.29814 .53902 m .29827 .53896 L .29823 .53884 L F
.29655 .54222 m .29827 .53896 L .29814 .53902 L F
.079 0 0 r
.30171 .54156 m .29909 .54234 L .30114 .54062 L F
.724 .194 0 r
.30171 .54156 m .29823 .53884 L .29909 .54234 L F
.30171 .54156 m .2996 .54108 L .29827 .5389 L F
.29834 .53893 m .29827 .5389 L .29823 .53884 L F
.30171 .54156 m .29827 .5389 L .29834 .53893 L F
.634 .856 .984 r
.30255 .53893 m .30066 .53982 L .29886 .53881 L F
.30066 .53982 m .29885 .53912 L .29886 .53881 L F
.30255 .53893 m .29886 .53881 L .29887 .53864 L F
.271 .759 .916 r
.29881 .53881 m .30022 .53851 L .30255 .53893 L F
.368 .569 .915 r
.29887 .53864 m .29881 .53881 L .29864 .53885 L F
.271 .759 .916 r
.29823 .53884 m .30022 .53851 L .29864 .53885 L F
.082 .642 .731 r
.30006 .53848 m .30349 .53823 L .30255 .53893 L F
.30349 .53823 m .30433 .53817 L .30255 .53893 L F
.851 .833 .829 r
.49996 .43393 m .49805 .43588 L .49632 .43419 L F
.14 0 0 r
.24691 .62111 m .24556 .62158 L .24306 .62181 L F
0 0 0 r
.24956 .62073 m .24556 .62158 L .24691 .62111 L F
0 .063 .614 r
.57941 .39188 m .57939 .39286 L .57738 .38995 L F
0 0 .56 r
.58145 .39541 m .57939 .39286 L .57941 .39188 L F
.941 .718 .572 r
.33917 .61833 m .34051 .62163 L .33883 .62176 L F
.94 .812 .358 r
.34332 .62156 m .33883 .62176 L .34051 .62163 L F
.247 .544 .926 r
.38776 .69244 m .38608 .69006 L .38778 .68963 L F
.589 .479 .697 r
.39087 .68561 m .38778 .68963 L .38758 .68608 L F
.39087 .68561 m .38758 .68608 L .38773 .68597 L F
.648 .513 .685 r
.39056 .68365 m .39087 .68561 L .38758 .68599 L F
.589 .479 .697 r
.39087 .68561 m .39223 .6894 L .38778 .68963 L F
.57 .356 .551 r
.39422 .68596 m .39223 .6894 L .39087 .68561 L F
.712 .652 .789 r
.38869 .68766 m .39274 .68797 L .39143 .68505 L F
.085 0 .037 r
.39271 .68228 m .39218 .68262 L .3899 .68626 L F
.39271 .68228 m .3899 .68626 L .38992 .68624 L F
.105 0 .042 r
.38977 .68634 m .39056 .68365 L .38758 .68599 L F
.712 .652 .789 r
.38869 .68766 m .39117 .68529 L .38933 .68671 L F
.39117 .68529 m .39143 .68505 L .38986 .68629 L F
.39117 .68529 m .38986 .68629 L .38933 .68671 L F
.105 0 .042 r
.38979 .68634 m .38986 .68627 L .38977 .68634 L F
.38984 .68635 m .38986 .68629 L .38979 .68634 L F
.38986 .68629 m .38986 .68627 L .38979 .68634 L F
.38986 .68627 m .39056 .68365 L .38977 .68634 L F
.38974 .68633 m .38758 .68599 L .38743 .68585 L F
.38976 .68634 m .38975 .68633 L .38974 .68633 L F
.38975 .68633 m .38758 .68599 L .38974 .68633 L F
.085 0 .037 r
.39218 .68262 m .3905 .68388 L .38984 .68635 L F
.086 .451 .883 r
.38974 .68633 m .38743 .68585 L .38699 .68409 L F
.38965 .68624 m .38699 .68409 L .38689 .68369 L F
.38974 .68633 m .38699 .68409 L .38965 .68624 L F
.085 0 .037 r
.39271 .68228 m .38992 .68624 L .39104 .68419 L F
.712 .652 .789 r
.38965 .68624 m .39008 .68595 L .39104 .68419 L F
.085 0 .037 r
.38992 .68624 m .3899 .68626 L .38984 .68635 L F
.38992 .68624 m .38984 .68635 L .39104 .68419 L F
.712 .652 .789 r
.39008 .68595 m .39143 .68505 L .39104 .68419 L F
.38961 .68629 m .38966 .68626 L .38965 .68624 L F
.38966 .68626 m .39143 .68505 L .38965 .68624 L F
.753 .712 .814 r
.38782 .68575 m .38941 .68623 L .39104 .68419 L F
.38853 .68732 m .38935 .68668 L .38961 .68629 L F
.38941 .68623 m .38961 .68629 L .39104 .68419 L F
.38853 .68732 m .38961 .68629 L .38941 .68623 L F
.105 0 .042 r
.38979 .68634 m .38977 .68634 L .38976 .68634 L F
.38977 .68634 m .38758 .68599 L .38975 .68633 L F
.38977 .68634 m .38975 .68633 L .38976 .68634 L F
.712 .652 .789 r
.38979 .68634 m .39143 .68505 L .38966 .68626 L F
.086 .451 .883 r
.38976 .68634 m .38974 .68633 L .38965 .68624 L F
.712 .652 .789 r
.38976 .68634 m .38966 .68626 L .38961 .68629 L F
.38979 .68634 m .38966 .68626 L .38976 .68634 L F
.086 .451 .883 r
.38984 .68635 m .38976 .68634 L .38689 .68369 L F
.38976 .68634 m .38965 .68624 L .38689 .68369 L F
.753 .712 .814 r
.38689 .68369 m .38782 .68575 L .38867 .68534 L F
.38689 .68369 m .38867 .68534 L .39104 .68419 L F
.38782 .68575 m .38853 .68732 L .38941 .68623 L F
.38853 .68732 m .38869 .68766 L .38935 .68668 L F
.105 0 .042 r
.38984 .68635 m .38979 .68634 L .38976 .68634 L F
.712 .652 .789 r
.38933 .68671 m .38979 .68634 L .38961 .68629 L F
.085 0 .037 r
.39218 .68262 m .39056 .68365 L .3905 .68388 L F
.589 .479 .697 r
.38773 .68597 m .38758 .68608 L .38758 .68599 L F
.68 .596 .755 r
.39223 .6894 m .38776 .69244 L .38778 .68963 L F
.876 .956 .854 r
.6406 .40998 m .64206 .40862 L .64089 .40738 L F
.878 .956 .852 r
.64089 .40738 m .64206 .40862 L .64482 .40531 L F
.859 .774 .766 r
.33277 .65635 m .3373 .65596 L .33483 .65777 L F
.33277 .65635 m .3373 .65596 L .33483 .65777 L F
.955 .839 .41 r
.3907 .61432 m .39127 .61194 L .39018 .61387 L F
.802 .85 .395 r
.39018 .61387 m .39127 .61194 L .39119 .61145 L F
0 0 0 r
.54882 .47178 m .55207 .46997 L .55085 .47169 L F
.255 0 0 r
.55207 .46997 m .5535 .47133 L .55085 .47169 L F
.55207 .46997 m .55496 .46935 L .5535 .47133 L F
.547 .551 .81 r
.6172 .38871 m .61875 .39296 L .61586 .39332 L F
.6172 .38871 m .61586 .39332 L .61589 .39332 L F
.415 .787 .994 r
.61586 .39332 m .61875 .39296 L .61708 .39602 L F
.559 .933 .9 r
.67342 .38259 m .67513 .38086 L .67249 .38169 L F
.67342 .38259 m .67671 .38096 L .67513 .38086 L F
.779 .749 .826 r
.33331 .50269 m .33519 .5058 L .33811 .50321 L F
.852 .998 .803 r
.35538 .63931 m .3574 .63799 L .35713 .63762 L F
.648 .865 .981 r
.62491 .38909 m .6211 .38905 L .6237 .38796 L F
.797 .712 .771 r
.6211 .38905 m .62491 .38909 L .6237 .38796 L F
.613 .402 .572 r
.34182 .5117 m .34488 .50807 L .34332 .50866 L F
.807 .95 .914 r
.38174 .67421 m .38519 .67496 L .38704 .67215 L F
.697 .604 .748 r
.38519 .67496 m .38831 .67413 L .38704 .67215 L F
.627 .659 .862 r
.36083 .64112 m .35913 .64332 L .35798 .64174 L F
.36083 .64112 m .36191 .64408 L .35913 .64332 L F
.694 .267 .231 r
.35913 .64332 m .36039 .64625 L .3584 .64777 L F
.35913 .64332 m .36191 .64408 L .36039 .64625 L F
.643 .509 .685 r
.56732 .41619 m .5696 .41282 L .56603 .41231 L F
.56732 .41619 m .57004 .41554 L .5696 .41282 L F
.871 .927 .859 r
.39679 .68553 m .39542 .68927 L .39938 .68464 L F
0 .054 .576 r
.31073 .54824 m .31224 .54748 L .30901 .54682 L F
.31073 .54824 m .31232 .54805 L .31224 .54748 L F
.308 0 0 r
.54511 .40355 m .54342 .40476 L .54677 .40406 L F
.35 .642 .964 r
.37649 .60086 m .37715 .6034 L .37406 .6003 L F
.021 0 .172 r
.3304 .57349 m .33184 .57267 L .33253 .57049 L F
.277 .11 .466 r
.3304 .57349 m .33188 .57553 L .33184 .57267 L F
.3304 .57349 m .3301 .57668 L .33188 .57553 L F
.503 .295 .531 r
.30623 .62504 m .30921 .62088 L .30717 .62181 L F
.639 .951 .944 r
.27911 .57609 m .27387 .57778 L .2774 .57736 L F
.577 .327 .501 r
.50174 .48635 m .50199 .48914 L .49841 .48921 L F
.46 .255 .514 r
.50474 .48309 m .50455 .48596 L .50174 .48635 L F
.563 .317 .501 r
.50466 .48857 m .50174 .48635 L .50455 .48596 L F
.50466 .48857 m .50199 .48914 L .50174 .48635 L F
.208 .735 .801 r
.25031 .57633 m .24883 .5764 L .24641 .57685 L F
.478 .673 .95 r
.25031 .57633 m .253 .57691 L .25118 .57502 L F
.705 .975 .918 r
.25118 .57502 m .24883 .5764 L .25031 .57633 L F
.423 0 0 r
.23737 .61264 m .23801 .61324 L .23561 .61153 L F
.91 .513 .118 r
.40966 .54793 m .40789 .54662 L .4072 .54406 L F
.98 .685 .353 r
.40939 .55007 m .40789 .54662 L .40966 .54793 L F
.19 .225 .668 r
.38347 .65446 m .3832 .65057 L .38343 .65391 L F
0 0 .427 r
.38343 .65391 m .3847 .65709 L .38347 .65446 L F
.701 .982 .89 r
.3832 .65057 m .38251 .6513 L .38343 .65391 L F
.38251 .6513 m .38146 .65242 L .38343 .65391 L F
0 0 .346 r
.38318 .65253 m .38335 .6537 L .38343 .65391 L F
.38335 .6537 m .38347 .65446 L .38343 .65391 L F
.38318 .65253 m .38347 .65446 L .38343 .65391 L F
0 0 .427 r
.38343 .65391 m .3847 .65709 L .38347 .65446 L F
.877 .782 .752 r
.23541 .59774 m .2398 .59541 L .23758 .59512 L F
.987 .792 .556 r
.23478 .594 m .23541 .59774 L .23758 .59512 L F
.78 .42 0 r
.41294 .56981 m .41122 .56594 L .41294 .56711 L F
0 0 0 r
.35216 .56719 m .35242 .56803 L .35308 .565 L F
.35216 .56719 m .35177 .56977 L .35242 .56803 L F
.25 .215 .623 r
.47564 .55612 m .47351 .55385 L .47522 .55338 L F
.47564 .55612 m .47377 .55786 L .47351 .55385 L F
.312 .343 .733 r
.21488 .58604 m .21571 .58989 L .21739 .58814 L F
.394 .375 .719 r
.21629 .59253 m .21739 .58814 L .21571 .58989 L F
0 0 .411 r
.22742 .55901 m .22703 .56291 L .226 .56114 L F
0 0 0 r
.36039 .64625 m .36191 .64408 L .36337 .6435 L F
0 .149 .688 r
.36315 .64328 m .36191 .64408 L .36083 .64112 L F
.36337 .64348 m .36217 .64398 L .36315 .64328 L F
.36217 .64398 m .36191 .64408 L .36315 .64328 L F
.36337 .6435 m .36191 .64408 L .36337 .64348 L F
.743 .609 .709 r
.36326 .63468 m .36401 .63809 L .35723 .63813 L F
.733 .698 .818 r
.35723 .63813 m .36401 .63809 L .36148 .63785 L F
0 .149 .688 r
.36333 .64332 m .36083 .64112 L .36148 .63785 L F
.36327 .64338 m .36083 .64112 L .36333 .64332 L F
.52 .259 .459 r
.36148 .63785 m .36478 .6419 L .36338 .64347 L F
.83 .996 .763 r
.36343 .64308 m .36337 .64348 L .36478 .6419 L F
.36337 .64348 m .36334 .64367 L .36478 .6419 L F
.52 .259 .459 r
.36338 .64347 m .36478 .6419 L .36338 .64349 L F
.83 .996 .763 r
.36343 .64308 m .36478 .6419 L .36378 .64283 L F
.52 .259 .459 r
.36148 .63785 m .36591 .63984 L .36478 .6419 L F
.517 .836 .53 r
.36321 .64336 m .36456 .64211 L .36589 .64075 L F
.36456 .64211 m .36478 .6419 L .36498 .6417 L F
.359 .353 .716 r
.36658 .63555 m .36401 .63809 L .36326 .63468 L F
.622 .796 .965 r
.36148 .63785 m .36401 .63809 L .36658 .63555 L F
.36148 .63785 m .36658 .63555 L .36591 .63984 L F
.858 .925 .536 r
.36478 .6419 m .36591 .63984 L .36609 .63796 L F
.36478 .6419 m .36609 .63796 L .36589 .64075 L F
.517 .836 .53 r
.36456 .64211 m .36498 .6417 L .36589 .64075 L F
0 .149 .688 r
.36338 .64347 m .36327 .64338 L .36333 .64332 L F
.36338 .64349 m .36337 .64348 L .36338 .64347 L F
.36337 .64348 m .36083 .64112 L .36338 .64347 L F
.83 .996 .763 r
.36135 .64489 m .36311 .64381 L .36343 .64308 L F
.36311 .64381 m .36334 .64367 L .36337 .64348 L F
.36311 .64381 m .36337 .64348 L .36343 .64308 L F
.36135 .64489 m .36343 .64308 L .36321 .64336 L F
.36343 .64308 m .36378 .64283 L .36321 .64336 L F
0 0 0 r
.36331 .64355 m .36337 .6435 L .36338 .64349 L F
.36039 .64625 m .36337 .6435 L .36331 .64355 L F
.83 .996 .763 r
.36302 .64386 m .36223 .64502 L .36334 .64367 L F
0 0 0 r
.36039 .64625 m .36338 .64349 L .36223 .64502 L F
.83 .996 .763 r
.36135 .64489 m .36197 .64498 L .36302 .64386 L F
.36197 .64498 m .36223 .64502 L .36302 .64386 L F
0 .149 .688 r
.36338 .64349 m .36337 .6435 L .36337 .64348 L F
.766 .996 .851 r
.27317 .62756 m .27736 .62514 L .27402 .6267 L F
.27317 .62756 m .27614 .6252 L .27736 .62514 L F
.125 .339 .805 r
.27778 .62289 m .27736 .62514 L .27614 .6252 L F
.27778 .62289 m .28017 .62728 L .27736 .62514 L F
.74 .581 .677 r
.49323 .49023 m .48893 .49275 L .48939 .48987 L F
.49323 .49023 m .49323 .49295 L .48893 .49275 L F
.673 .527 .677 r
.49584 .4897 m .49323 .49295 L .49323 .49023 L F
.549 .662 .911 r
.22647 .58441 m .22794 .58701 L .22532 .58712 L F
.239 .343 .769 r
.26756 .63413 m .26889 .63494 L .26887 .63433 L F
.027 .167 .675 r
.59865 .45929 m .59724 .4607 L .59632 .45783 L F
.129 .339 .803 r
.59865 .45929 m .59818 .46065 L .59724 .4607 L F
.116 .009 .444 r
.59818 .46065 m .59719 .46373 L .59724 .4607 L F
.694 .237 0 r
.59818 .4212 m .59724 .41961 L .59579 .41796 L F
.568 .195 .294 r
.62912 .41485 m .63079 .41259 L .6288 .41256 L F
.62912 .41485 m .63165 .41292 L .63079 .41259 L F
.632 .672 .87 r
.63079 .41259 m .63162 .40938 L .6288 .41256 L F
.63079 .41259 m .63299 .41213 L .63162 .40938 L F
.135 0 0 r
.63221 .41379 m .63165 .41292 L .62912 .41485 L F
.311 0 0 r
.63221 .41379 m .63079 .41259 L .63165 .41292 L F
.63221 .41379 m .63299 .41213 L .63079 .41259 L F
.655 .187 .13 r
.42706 .59776 m .4287 .5961 L .43115 .59807 L F
.569 0 0 r
.4287 .5961 m .43157 .59796 L .43115 .59807 L F
.273 .735 .95 r
.43115 .59807 m .43262 .59726 L .43029 .59828 L F
.53 0 0 r
.42706 .59776 m .43115 .59807 L .42891 .59888 L F
.273 .735 .95 r
.43115 .59807 m .43029 .59828 L .42891 .59888 L F
.569 0 0 r
.43157 .59796 m .43223 .59838 L .43115 .59807 L F
.007 0 0 r
.35548 .68778 m .35484 .68706 L .35329 .68915 L F
.298 .498 .884 r
.35777 .68842 m .35484 .68706 L .35727 .68594 L F
.007 0 0 r
.35548 .68778 m .35727 .68594 L .35484 .68706 L F
.008 0 0 r
.40596 .47693 m .40789 .47659 L .40866 .47596 L F
0 0 0 r
.40866 .47596 m .40789 .47659 L .41021 .47584 L F
.046 0 0 r
.6179 .34644 m .62192 .345 L .6189 .3471 L F
.957 .852 .696 r
.63777 .41585 m .63927 .41218 L .63777 .41076 L F
.898 .881 .809 r
.63777 .41076 m .63927 .41218 L .6406 .40998 L F
.656 .42 .551 r
.61283 .36428 m .61288 .36682 L .61022 .36701 L F
.32 .783 .942 r
.28164 .51993 m .27867 .51938 L .27653 .51984 L F
.635 .911 .982 r
.28199 .51832 m .28164 .51993 L .28371 .51854 L F
.28199 .51832 m .27867 .51938 L .28164 .51993 L F
.453 .075 .231 r
.2697 .54761 m .2691 .54926 L .26718 .54792 L F
.2697 .54761 m .2691 .54926 L .26718 .54792 L F
.477 0 0 r
.2691 .54926 m .2675 .54862 L .26718 .54792 L F
.869 .994 .757 r
.64906 .39795 m .64851 .40037 L .65083 .3972 L F
.871 .989 .724 r
.64722 .40205 m .64851 .40037 L .64906 .39795 L F
.408 .829 .657 r
.41535 .4897 m .41706 .48857 L .41731 .48855 L F
.776 .939 .591 r
.4153 .49204 m .41706 .48857 L .41535 .4897 L F
.642 .873 .511 r
.41706 .48857 m .41575 .49015 L .41695 .48858 L F
.41706 .48857 m .41695 .48858 L .41863 .48637 L F
.408 .829 .657 r
.41731 .48855 m .41706 .48857 L .41873 .48772 L F
.683 .585 .739 r
.41283 .48258 m .41362 .48587 L .41648 .48274 L F
.621 .727 .923 r
.41283 .48258 m .41648 .48274 L .41558 .48071 L F
.699 .861 .96 r
.41645 .48015 m .41648 .48274 L .41914 .4817 L F
.301 .522 .901 r
.41558 .48071 m .41648 .48274 L .41645 .48015 L F
.726 .607 .724 r
.41645 .48015 m .42008 .48547 L .41477 .48403 L F
.42008 .48547 m .42071 .4864 L .41948 .48591 L F
.42008 .48547 m .41948 .48591 L .41477 .48403 L F
.124 .671 .813 r
.41859 .48636 m .41863 .48637 L .41471 .4863 L F
.758 .975 .709 r
.41982 .48668 m .4189 .48644 L .42058 .48596 L F
.555 .356 .566 r
.41987 .48635 m .41863 .48637 L .42071 .4864 L F
.758 .975 .709 r
.41864 .48651 m .41892 .48631 L .41918 .48626 L F
.419 .48641 m .41918 .48626 L .42058 .48596 L F
.41864 .48651 m .41918 .48626 L .419 .48641 L F
.549 .527 .783 r
.41914 .4817 m .42058 .48596 L .42301 .48519 L F
.41914 .4817 m .42219 .48445 L .42175 .48243 L F
.669 .672 .843 r
.41748 .4781 m .41914 .4817 L .42093 .47803 L F
0 0 0 r
.4203 .4775 m .42066 .47734 L .42022 .47743 L F
.436 .442 .767 r
.42182 .48 m .42252 .48264 L .42203 .48283 L F
0 0 0 r
.4209 .47723 m .42394 .47587 L .42087 .47715 L F
.42022 .47743 m .42394 .47587 L .4201 .47484 L F
.436 .442 .767 r
.4216 .47702 m .42235 .48157 L .42182 .48 L F
.42163 .47701 m .42235 .48157 L .4216 .47702 L F
0 0 0 r
.4209 .47723 m .4216 .47702 L .42394 .47587 L F
.4216 .47702 m .42163 .47701 L .42164 .477 L F
.4216 .47702 m .42164 .477 L .42394 .47587 L F
.655 .614 .796 r
.42158 .47703 m .42203 .48283 L .42154 .48139 L F
.42158 .47671 m .4216 .47702 L .42158 .47703 L F
.4216 .47702 m .42203 .48283 L .42158 .47703 L F
.548 .524 .781 r
.42093 .47803 m .42155 .47959 L .42158 .47708 L F
.436 .442 .767 r
.42158 .47671 m .42163 .47701 L .4216 .47702 L F
.548 .524 .781 r
.42139 .47709 m .42163 .47701 L .42158 .47671 L F
.42093 .47803 m .42163 .47701 L .42139 .47709 L F
.436 .442 .767 r
.42235 .48157 m .42252 .48264 L .42182 .48 L F
.548 .524 .781 r
.41946 .48104 m .42155 .48143 L .42089 .47812 L F
.41914 .4817 m .42031 .48165 L .41946 .48104 L F
.42031 .48165 m .42235 .48157 L .41946 .48104 L F
.42158 .4816 m .42252 .48264 L .42235 .48157 L F
.41914 .4817 m .42175 .48243 L .42158 .4816 L F
.798 .69 .746 r
.42154 .48139 m .42203 .48283 L .42175 .48243 L F
.548 .524 .781 r
.42175 .48243 m .42252 .48264 L .42158 .4816 L F
.798 .69 .746 r
.42175 .48243 m .42203 .48283 L .42181 .48273 L F
.42149 .48123 m .42154 .48139 L .42175 .48243 L F
.952 .763 .612 r
.41645 .48015 m .41914 .4817 L .41748 .4781 L F
.798 .69 .746 r
.42149 .48123 m .42175 .48243 L .41645 .48015 L F
.42175 .48243 m .42181 .48273 L .42181 .48272 L F
.42175 .48243 m .42181 .48272 L .41645 .48015 L F
.548 .524 .781 r
.42089 .47812 m .42235 .48157 L .42093 .47803 L F
.42155 .48143 m .42235 .48157 L .42089 .47812 L F
.611 .571 .784 r
.42195 .4838 m .41645 .48015 L .42181 .48272 L F
.42181 .48273 m .42181 .48272 L .42181 .48273 L F
.42195 .4838 m .42181 .48272 L .42181 .48273 L F
0 0 0 r
.42066 .47734 m .42062 .47726 L .42022 .47743 L F
.669 .672 .843 r
.41748 .4781 m .42093 .47803 L .42 .47724 L F
.645 .528 .706 r
.42022 .47743 m .41748 .4781 L .42022 .47753 L F
.4201 .47484 m .41748 .4781 L .42022 .47743 L F
.669 .672 .843 r
.42 .47724 m .42022 .47743 L .42158 .47671 L F
.42022 .47743 m .4203 .4775 L .42054 .47735 L F
.42022 .47743 m .42054 .47735 L .42158 .47671 L F
.4203 .4775 m .42093 .47803 L .42139 .47709 L F
0 0 0 r
.4203 .4775 m .42151 .47704 L .4209 .47723 L F
.42066 .47734 m .4209 .47723 L .42062 .47726 L F
.4209 .47723 m .42087 .47715 L .42062 .47726 L F
.669 .672 .843 r
.4203 .4775 m .42139 .47709 L .42158 .47671 L F
0 0 0 r
.42022 .47753 m .4216 .47702 L .42151 .47704 L F
.42022 .47753 m .42151 .47704 L .4203 .4775 L F
.655 .614 .796 r
.42158 .47703 m .42154 .48139 L .42022 .47753 L F
0 0 0 r
.42022 .47753 m .42279 .47666 L .4216 .47702 L F
.655 .614 .796 r
.42158 .47671 m .42158 .47703 L .42022 .47753 L F
.548 .524 .781 r
.42158 .47708 m .42235 .48157 L .42163 .47701 L F
.42155 .47959 m .42235 .48157 L .42158 .47708 L F
0 0 0 r
.42163 .47701 m .42279 .47666 L .42292 .47658 L F
.42163 .47701 m .42292 .47658 L .42394 .47587 L F
.42022 .47753 m .42249 .47687 L .42279 .47666 L F
.42022 .47753 m .4203 .4775 L .42022 .47743 L F
.611 .571 .784 r
.42203 .48288 m .42181 .48273 L .42203 .48283 L F
.549 .527 .783 r
.42219 .48445 m .42301 .48519 L .42197 .48291 L F
.42186 .48296 m .42197 .48291 L .42175 .48243 L F
.42219 .48445 m .42197 .48291 L .42186 .48296 L F
.42192 .4828 m .42301 .48519 L .42265 .48332 L F
.054 0 0 r
.42211 .48284 m .42203 .48288 L .42203 .48283 L F
.549 .527 .783 r
.42192 .4828 m .42265 .48332 L .42252 .48264 L F
.579 .55 .786 r
.42255 .48264 m .42301 .48519 L .42563 .48275 L F
.42252 .48264 m .42252 .48266 L .42255 .48264 L F
.42252 .48266 m .42301 .48519 L .42255 .48264 L F
.054 0 0 r
.4236 .48307 m .42195 .4838 L .42203 .4829 L F
.42205 .48288 m .42203 .4829 L .42203 .48288 L F
.4236 .48307 m .42203 .4829 L .42205 .48288 L F
.4236 .48307 m .42203 .48288 L .42211 .48284 L F
.611 .571 .784 r
.42195 .4838 m .42181 .48273 L .42203 .48288 L F
.549 .527 .783 r
.42175 .48243 m .42192 .4828 L .42252 .48264 L F
.798 .69 .746 r
.42022 .47753 m .42149 .48123 L .41645 .48015 L F
.611 .571 .784 r
.42195 .4838 m .42193 .48385 L .41645 .48015 L F
.397 0 0 r
.42101 .48633 m .42058 .48596 L .41918 .48626 L F
.611 .571 .784 r
.4208 .48622 m .42075 .48633 L .42047 .48604 L F
.42075 .48633 m .42071 .4864 L .42067 .48633 L F
.42075 .48633 m .42067 .48633 L .42047 .48604 L F
.397 0 0 r
.42075 .48633 m .41918 .48626 L .41863 .48637 L F
.42101 .48633 m .41918 .48626 L .42075 .48633 L F
.124 .671 .813 r
.41987 .48635 m .41875 .48628 L .42054 .48633 L F
.41875 .48628 m .41471 .48605 L .41872 .48624 L F
.41875 .48628 m .41872 .48624 L .42054 .48633 L F
.555 .356 .566 r
.4208 .48622 m .41863 .48637 L .42075 .48633 L F
.428 .195 .457 r
.42058 .48596 m .42287 .48732 L .42301 .48519 L F
.611 .571 .784 r
.42193 .48385 m .4208 .48622 L .42008 .48547 L F
.4208 .48622 m .42047 .48604 L .42008 .48547 L F
.42193 .48385 m .42008 .48547 L .41645 .48015 L F
.555 .356 .566 r
.42195 .4838 m .41961 .48561 L .4208 .48622 L F
.124 .671 .813 r
.42054 .48633 m .41471 .48605 L .41477 .48403 L F
.555 .356 .566 r
.41961 .48561 m .41863 .48637 L .4208 .48622 L F
.124 .671 .813 r
.42071 .4864 m .41987 .48635 L .42054 .48633 L F
.555 .356 .566 r
.42075 .48633 m .41987 .48635 L .42071 .4864 L F
.397 0 0 r
.42106 .48637 m .42101 .48633 L .41987 .48635 L F
.41916 .48637 m .41987 .48635 L .41863 .48637 L F
.555 .356 .566 r
.41875 .48628 m .41879 .48638 L .41863 .48637 L F
.124 .671 .813 r
.42071 .4864 m .41471 .4863 L .41471 .48605 L F
.397 0 0 r
.42106 .48637 m .41987 .48635 L .41916 .48637 L F
.124 .671 .813 r
.42071 .4864 m .41863 .48637 L .41916 .48637 L F
.397 0 0 r
.42128 .48656 m .42106 .48637 L .41863 .48637 L F
.555 .356 .566 r
.41882 .48636 m .42128 .48656 L .41879 .48638 L F
.42195 .4838 m .42135 .48626 L .41882 .48636 L F
.42135 .48626 m .42128 .48656 L .41882 .48636 L F
.758 .975 .709 r
.41864 .48651 m .41863 .48637 L .41892 .48631 L F
.124 .671 .813 r
.41878 .48637 m .41863 .48637 L .41859 .48636 L F
.41916 .48637 m .41863 .48637 L .41878 .48637 L F
.555 .356 .566 r
.42195 .4838 m .41882 .48636 L .41875 .48628 L F
.41882 .48636 m .41879 .48638 L .41878 .48637 L F
.41882 .48636 m .41878 .48637 L .41875 .48628 L F
.397 0 0 r
.42103 .48635 m .42287 .48732 L .42246 .48707 L F
.42101 .48633 m .42246 .48707 L .42058 .48596 L F
.42103 .48635 m .42246 .48707 L .42101 .48633 L F
.42128 .48656 m .42238 .48708 L .42103 .48635 L F
.42238 .48708 m .42287 .48732 L .42103 .48635 L F
.758 .975 .709 r
.41873 .48772 m .41864 .48651 L .4189 .48644 L F
.41873 .48772 m .4189 .48644 L .41982 .48668 L F
.41873 .48772 m .41706 .48857 L .41863 .48637 L F
.856 .996 .765 r
.6949 .34431 m .69196 .34675 L .69481 .34358 L F
.938 .877 .75 r
.69539 .33927 m .6949 .34431 L .69481 .34358 L F
.495 .588 .877 r
.36696 .51765 m .36529 .51924 L .36304 .51746 L F
.685 .791 .323 r
.36504 .51944 m .36529 .51924 L .36696 .51765 L F
.36504 .51944 m .36417 .52166 L .36529 .51924 L F
.083 0 0 r
.29067 .56309 m .29193 .56325 L .29374 .56249 L F
.065 0 0 r
.29067 .56309 m .28903 .56538 L .29193 .56325 L F
.311 0 0 r
.31552 .63785 m .31766 .63815 L .31327 .63713 L F
.954 .802 .654 r
.31654 .64041 m .31766 .63815 L .31552 .63785 L F
.158 0 0 r
.31321 .56214 m .31038 .56302 L .31375 .56119 L F
.519 .038 .053 r
.31375 .56119 m .31565 .56255 L .31321 .56214 L F
.406 .112 .349 r
.31609 .56039 m .31565 .56255 L .31375 .56119 L F
.264 .301 .714 r
.34613 .56553 m .34367 .56335 L .34775 .56276 L F
.089 0 0 r
.35101 .56259 m .34613 .56553 L .34775 .56276 L F
.332 .651 .969 r
.61297 .3902 m .61589 .39332 L .61164 .39206 L F
.498 0 0 r
.36887 .55748 m .37029 .55855 L .37142 .55957 L F
0 .071 .615 r
.37029 .55855 m .37146 .56 L .37142 .55957 L F
.775 .682 .76 r
.26852 .57325 m .2702 .57661 L .26702 .57485 L F
.566 0 0 r
.27325 .57798 m .26839 .57678 L .2702 .57661 L F
.226 0 0 r
.2485 .61609 m .24797 .61562 L .24602 .61375 L F
.2485 .61609 m .25038 .61609 L .24797 .61562 L F
.293 .552 .923 r
.33221 .69299 m .33644 .69583 L .3346 .69282 L F
.379 .54 .889 r
.3346 .69282 m .33644 .69583 L .33872 .69608 L F
.657 .722 .897 r
.56169 .39237 m .55737 .391 L .56088 .39113 L F
0 .479 .806 r
.55919 .39008 m .56006 .3904 L .56088 .39113 L F
.527 .07 .112 r
.56088 .39113 m .56446 .38971 L .56196 .39211 L F
.56088 .39113 m .56322 .39157 L .56446 .38971 L F
0 .479 .806 r
.56006 .3904 m .56322 .39157 L .56088 .39113 L F
.527 .07 .112 r
.56088 .39113 m .56196 .39211 L .56169 .39237 L F
.681 .613 .774 r
.60476 .35894 m .6089 .36114 L .60824 .35985 L F
.984 .892 .554 r
.6089 .36114 m .60742 .36223 L .60824 .35985 L F
0 0 .085 r
.62822 .36462 m .62846 .36295 L .62811 .36486 L F
.325 .432 .817 r
.62882 .36047 m .62846 .36295 L .63044 .36061 L F
.978 .679 .335 r
.63004 .36058 m .63044 .36061 L .63039 .36068 L F
.63004 .36058 m .63039 .36068 L .62846 .36295 L F
.63004 .36058 m .63109 .35998 L .63044 .36061 L F
.63004 .36058 m .6314 .36257 L .63109 .35998 L F
.399 .617 .939 r
.63297 .36078 m .6314 .36257 L .63004 .36058 L F
.63004 .36058 m .6314 .36257 L .63297 .36078 L F
.226 0 0 r
.63004 .36058 m .63093 .36142 L .62973 .36049 L F
.63004 .36058 m .62973 .36049 L .62904 .35995 L F
0 0 .085 r
.63004 .36058 m .62846 .36295 L .62822 .36462 L F
.325 .432 .817 r
.6248 .36011 m .62846 .36295 L .62882 .36047 L F
.317 0 .203 r
.37092 .52702 m .36963 .5252 L .37202 .52529 L F
.37092 .52702 m .36784 .52826 L .36963 .5252 L F
.78 .704 .78 r
.32938 .65013 m .33069 .65411 L .32597 .65389 L F
.993 .752 .452 r
.32925 .65344 m .33069 .65411 L .32938 .65013 L F
.077 0 .421 r
.33083 .65149 m .32925 .65344 L .32934 .65102 L F
.33083 .65149 m .32934 .65102 L .32938 .65013 L F
.163 0 0 r
.33083 .65149 m .33276 .65169 L .33197 .65185 L F
.736 .992 .842 r
.32899 .6528 m .32925 .65344 L .33083 .65149 L F
.163 0 0 r
.33083 .65149 m .33197 .65185 L .32977 .6523 L F
.373 .803 .967 r
.32597 .65389 m .32949 .65405 L .32925 .65344 L F
.182 0 0 r
.32597 .65389 m .32925 .65344 L .32593 .65497 L F
.736 .992 .842 r
.32593 .65497 m .32925 .65344 L .32899 .6528 L F
.373 .803 .967 r
.32949 .65405 m .33069 .65411 L .32925 .65344 L F
.683 .804 .939 r
.43497 .58256 m .43332 .58411 L .4317 .58279 L F
.339 .431 .809 r
.34306 .51301 m .34441 .51036 L .34182 .5117 L F
.34306 .51301 m .3461 .5144 L .34441 .51036 L F
.451 .384 .691 r
.34306 .51301 m .34385 .51868 L .3461 .5144 L F
.489 0 0 r
.59043 .40317 m .58678 .4003 L .58858 .40186 L F
0 .131 .663 r
.58781 .40046 m .58981 .40293 L .58858 .40186 L F
.601 .065 0 r
.59027 .40349 m .59043 .40317 L .58858 .40186 L F
0 .131 .663 r
.58981 .40293 m .59027 .40349 L .58858 .40186 L F
.489 0 0 r
.58678 .4003 m .58661 .40017 L .58858 .40186 L F
.687 .215 0 r
.59027 .40349 m .59174 .40506 L .59043 .40317 L F
.945 .82 .374 r
.32561 .65293 m .32655 .6508 L .32597 .65389 L F
.811 .819 .339 r
.3268 .64892 m .32655 .6508 L .32561 .65293 L F
.78 .704 .78 r
.32938 .65013 m .32597 .65389 L .32655 .6508 L F
.286 0 0 r
.33451 .49459 m .33223 .49421 L .33127 .49541 L F
.499 .332 .586 r
.68848 .31237 m .68876 .31534 L .68613 .31612 L F
.815 .827 .859 r
.37994 .70166 m .38385 .69891 L .38184 .6979 L F
.918 .962 .793 r
.38385 .69891 m .38488 .69491 L .38184 .6979 L F
.853 .834 .827 r
.36567 .70569 m .36835 .70361 L .36634 .70191 L F
.425 .715 .985 r
.36634 .70191 m .36835 .70361 L .36987 .70295 L F
.522 .477 .747 r
.36835 .70361 m .37142 .70471 L .36987 .70295 L F
.487 .898 .804 r
.35062 .65194 m .35055 .65135 L .34836 .65223 L F
.35062 .65194 m .35293 .65071 L .35055 .65135 L F
.726 .818 .922 r
.45683 .45335 m .45959 .45134 L .46066 .45365 L F
.763 .888 .933 r
.46237 .44996 m .46066 .45365 L .45959 .45134 L F
.46237 .44996 m .46389 .45118 L .46066 .45365 L F
.811 .998 .786 r
.69098 .37271 m .69421 .3702 L .69416 .36967 L F
.914 .977 .705 r
.69421 .3702 m .69575 .36586 L .69416 .36967 L F
.635 .369 .499 r
.40596 .47693 m .40892 .47848 L .40789 .47659 L F
.40596 .47693 m .40603 .47934 L .40892 .47848 L F
0 .111 .656 r
.37522 .50176 m .37749 .50399 L .37646 .5021 L F
.666 .511 .665 r
.2782 .53636 m .27914 .53696 L .28202 .5361 L F
.484 .544 .842 r
.2782 .53636 m .2794 .53713 L .27646 .53786 L F
.666 .511 .665 r
.27852 .53715 m .28027 .5371 L .28202 .5361 L F
.765 .936 .94 r
.28254 .53854 m .28027 .5371 L .28202 .5361 L F
.666 .511 .665 r
.28027 .5371 m .28133 .53707 L .28202 .5361 L F
.765 .936 .94 r
.28027 .5371 m .28005 .53696 L .28202 .5361 L F
.484 .544 .842 r
.2782 .53636 m .28005 .53696 L .2794 .53713 L F
.666 .511 .665 r
.2782 .53636 m .27852 .53715 L .27914 .53696 L F
.427 .805 .992 r
.27646 .53786 m .2794 .53713 L .28254 .53854 L F
.2794 .53713 m .28027 .5371 L .28254 .53854 L F
.666 .511 .665 r
.27852 .53715 m .27952 .53963 L .28133 .53707 L F
.427 .805 .992 r
.2794 .53713 m .28005 .53696 L .28027 .5371 L F
.765 .936 .94 r
.28254 .53854 m .28202 .5361 L .28382 .53726 L F
.993 .78 .405 r
.28206 .54032 m .28254 .53854 L .28382 .53726 L F
.619 .665 .873 r
.36215 .70552 m .36494 .70518 L .3612 .70326 L F
.36215 .70552 m .36567 .70569 L .36494 .70518 L F
.303 .458 .85 r
.36215 .70552 m .36548 .70845 L .36567 .70569 L F
.248 .746 .904 r
.24306 .62181 m .24347 .62121 L .24148 .6205 L F
.24306 .62181 m .24556 .62158 L .24347 .62121 L F
.526 .806 .997 r
.31511 .59947 m .31774 .59882 L .31358 .59824 L F
.731 .597 .707 r
.41916 .4932 m .41676 .49614 L .4153 .49204 L F
.274 .007 .314 r
.41916 .4932 m .4192 .49544 L .41676 .49614 L F
.41676 .49614 m .4192 .49544 L .41916 .4932 L F
.525 .189 .34 r
.41916 .4932 m .4192 .49544 L .42176 .49486 L F
.41916 .4932 m .4192 .49544 L .42176 .49486 L F
.274 .007 .314 r
.41676 .49614 m .4192 .49544 L .41916 .4932 L F
.714 .72 .195 r
.39794 .59593 m .39738 .59789 L .39728 .59854 L F
.985 .899 .579 r
.39794 .59593 m .39792 .59141 L .39754 .59483 L F
.885 .716 .202 r
.39754 .59483 m .39738 .59789 L .39794 .59593 L F
.529 0 0 r
.5695 .38603 m .5737 .38814 L .57077 .38758 L F
.305 .793 .75 r
.38377 .69138 m .38241 .69203 L .38086 .69165 L F
.38377 .69138 m .38531 .69106 L .38241 .69203 L F
.353 .342 .708 r
.47564 .55612 m .47438 .56048 L .47377 .55786 L F
0 .123 .672 r
.32233 .59929 m .32238 .59783 L .32003 .59549 L F
0 0 .014 r
.32233 .59929 m .32266 .59947 L .32238 .59783 L F
.32233 .59929 m .32194 .60196 L .32266 .59947 L F
.902 .823 .76 r
.74306 .31342 m .74225 .31616 L .73974 .3149 L F
.755 .438 .448 r
.74225 .31616 m .73909 .31801 L .73974 .3149 L F
.74225 .31616 m .74278 .31831 L .73909 .31801 L F
.727 .882 .952 r
.36091 .6342 m .36326 .63468 L .35996 .63513 L F
.045 0 0 r
.36162 .63649 m .36326 .63468 L .3577 .63786 L F
.359 .353 .716 r
.36658 .63555 m .36326 .63468 L .36499 .63388 L F
0 0 0 r
.36499 .63388 m .36326 .63468 L .36162 .63649 L F
.36499 .63388 m .36162 .63649 L .36394 .63588 L F
.535 .629 .891 r
.36359 .63581 m .36162 .63649 L .35998 .63503 L F
.36394 .63588 m .36162 .63649 L .36359 .63581 L F
.045 0 0 r
.36162 .63649 m .3577 .63786 L .35723 .63813 L F
.19 .093 .507 r
.36439 .63308 m .36326 .63468 L .36499 .63388 L F
.36499 .63388 m .36326 .63468 L .36439 .63308 L F
0 .137 .594 r
.42352 .54373 m .42421 .54432 L .424 .54452 L F
.451 .452 .768 r
.33793 .59355 m .34045 .59551 L .34032 .59292 L F
.712 .425 .489 r
.34032 .59292 m .33649 .59518 L .33793 .59355 L F
.34032 .59292 m .34045 .59551 L .33649 .59518 L F
.68 .922 .607 r
.34212 .5905 m .34098 .59167 L .34032 .59292 L F
0 0 .149 r
.34066 .59396 m .34032 .59292 L .34098 .59167 L F
.34066 .59396 m .34045 .59551 L .34032 .59292 L F
.95 .831 .691 r
.38704 .67215 m .38831 .67413 L .38883 .67118 L F
.461 .519 .832 r
.38831 .67413 m .39135 .67527 L .39033 .67027 L F
.886 .543 .051 r
.33888 .63296 m .33935 .63455 L .33788 .63123 L F
.756 .954 .939 r
.3402 .63044 m .33888 .63296 L .33788 .63123 L F
.3402 .63044 m .34276 .63023 L .33888 .63296 L F
.976 .795 .594 r
.61049 .45115 m .60955 .44708 L .60845 .44998 L F
.958 .708 .515 r
.60836 .4527 m .61049 .45115 L .60845 .44998 L F
.60836 .4527 m .61022 .45372 L .61049 .45115 L F
.85 .928 .544 r
.38403 .62457 m .38521 .62237 L .38544 .62065 L F
.841 .965 .639 r
.36368 .58521 m .36318 .58679 L .36236 .58764 L F
0 .345 .822 r
.37888 .50547 m .37792 .5037 L .37749 .50399 L F
.37888 .50547 m .38124 .5066 L .37792 .5037 L F
.659 .377 .481 r
.34505 .6019 m .34876 .59933 L .34569 .59941 L F
0 0 .072 r
.34631 .6005 m .34569 .59941 L .34644 .59775 L F
.34631 .6005 m .34505 .6019 L .34569 .59941 L F
.891 .692 .627 r
.39968 .66049 m .39775 .65685 L .39767 .6596 L F
.97 .752 .553 r
.39929 .66332 m .39968 .66049 L .39767 .6596 L F
0 0 .31 r
.35485 .55358 m .3552 .56003 L .35216 .55768 L F
.364 .828 .908 r
.35386 .55294 m .35206 .5537 L .35553 .55323 L F
.35386 .55294 m .35129 .55354 L .35206 .5537 L F
.934 .585 .343 r
.60772 .44604 m .60913 .44488 L .6066 .44334 L F
.60772 .44604 m .60955 .44708 L .60913 .44488 L F
.49 0 0 r
.63015 .39377 m .63017 .39367 L .6294 .39402 L F
0 0 0 r
.6294 .39402 m .63017 .39367 L .62768 .39481 L F
.971 .694 .282 r
.35312 .66862 m .35365 .66978 L .35325 .67221 L F
.326 0 .226 r
.35325 .67221 m .35365 .66978 L .35612 .6689 L F
.205 .449 .872 r
.27325 .57798 m .27414 .57993 L .27387 .57778 L F
.82 .481 .415 r
.31901 .53866 m .3182 .54053 L .31621 .53739 L F
.748 .654 .756 r
.3223 .53893 m .3182 .54053 L .31901 .53866 L F
0 0 0 r
.22338 .54776 m .22524 .54647 L .22648 .54482 L F
.611 .838 .456 r
.22794 .54281 m .22648 .54482 L .22759 .54316 L F
0 0 0 r
.22648 .54482 m .22647 .54548 L .22759 .54316 L F
.22647 .54548 m .22752 .54323 L .22759 .54316 L F
.22752 .54323 m .228 .54218 L .22759 .54316 L F
.611 .838 .456 r
.22895 .54144 m .22794 .54281 L .22759 .54316 L F
0 0 0 r
.22648 .54482 m .22524 .54647 L .22647 .54548 L F
.475 .104 .254 r
.39843 .49057 m .40051 .49135 L .40126 .48856 L F
.057 0 0 r
.40126 .48856 m .40316 .48869 L .40446 .48618 L F
.053 0 .11 r
.40126 .48856 m .40051 .49135 L .40316 .48869 L F
0 0 .215 r
.2235 .55052 m .22524 .54647 L .22338 .54776 L F
.515 .284 .502 r
.25628 .57333 m .25594 .5766 L .253 .57691 L F
.357 .396 .765 r
.25788 .57264 m .25628 .57333 L .25531 .57055 L F
0 0 0 r
.25619 .5749 m .25628 .57333 L .25788 .57264 L F
.25619 .5749 m .25594 .5766 L .25628 .57333 L F
0 .173 .708 r
.35974 .61156 m .36236 .61403 L .36468 .61179 L F
.699 .715 .862 r
.36735 .61025 m .36468 .61179 L .3667 .60865 L F
0 0 0 r
.3667 .60865 m .36468 .61179 L .36587 .61084 L F
.7 .51 .627 r
.36236 .61403 m .36587 .61084 L .36468 .61179 L F
.024 0 0 r
.56146 .46717 m .56249 .46747 L .56009 .46861 L F
.56146 .46717 m .56419 .46675 L .56249 .46747 L F
0 0 0 r
.65352 .32673 m .6546 .32569 L .65157 .32828 L F
.495 .892 .742 r
.65352 .32673 m .65157 .32828 L .65113 .32826 L F
.967 .642 .308 r
.42668 .54782 m .42791 .54782 L .42421 .54432 L F
.42668 .54782 m .42829 .55025 L .42791 .54782 L F
.736 .961 .677 r
.63785 .40996 m .63937 .40867 L .63851 .40847 L F
.63937 .40867 m .64089 .40738 L .63901 .40824 L F
.63937 .40867 m .63901 .40824 L .63851 .40847 L F
.63937 .40867 m .63938 .40842 L .64089 .40738 L F
.898 .881 .809 r
.63928 .40856 m .63937 .40866 L .63938 .40842 L F
.736 .961 .677 r
.63785 .40996 m .63777 .41076 L .63938 .40842 L F
.63785 .40996 m .63938 .40842 L .63937 .40867 L F
.898 .881 .809 r
.63937 .40866 m .6406 .40998 L .63938 .40842 L F
.63777 .41076 m .64045 .41002 L .63928 .40856 L F
.64045 .41002 m .6406 .40998 L .63928 .40856 L F
.876 .956 .854 r
.6406 .40998 m .64089 .40738 L .63938 .40842 L F
0 .161 .637 r
.22556 .60338 m .22621 .60359 L .22419 .60147 L F
.22556 .60338 m .22795 .60516 L .22621 .60359 L F
.776 .63 .7 r
.36156 .59618 m .36201 .59603 L .35916 .59798 L F
.252 0 .194 r
.35955 .60047 m .35916 .59798 L .36201 .59603 L F
.439 .318 .618 r
.36425 .59486 m .36201 .59603 L .36156 .59618 L F
.36425 .59486 m .36181 .59789 L .36201 .59603 L F
.375 0 0 r
.36181 .59789 m .35955 .60047 L .36201 .59603 L F
.928 .674 .532 r
.48893 .49275 m .49064 .49621 L .48862 .49546 L F
.913 .573 .383 r
.48862 .49546 m .49064 .49621 L .48907 .4978 L F
.549 .539 .796 r
.4932 .49551 m .49064 .49621 L .48893 .49275 L F
.763 .53 .581 r
.4932 .49551 m .48907 .4978 L .49064 .49621 L F
.953 .609 .231 r
.59214 .40997 m .59324 .40874 L .59232 .40751 L F
.59214 .40997 m .59445 .41312 L .59324 .40874 L F
.763 .668 .757 r
.56603 .41231 m .5696 .41282 L .56818 .40895 L F
0 .094 .644 r
.56818 .40895 m .5696 .41282 L .56875 .41025 L F
.701 .654 .8 r
.57004 .41554 m .57275 .41204 L .5696 .41282 L F
.17 0 0 r
.5696 .41282 m .57275 .41204 L .57108 .41301 L F
.5696 .41282 m .57108 .41301 L .56875 .41025 L F
.553 .082 .09 r
.54167 .47088 m .54432 .47241 L .54169 .47242 L F
0 0 0 r
.26375 .52117 m .25926 .52292 L .26142 .5218 L F
.449 .259 .53 r
.55251 .3968 m .55508 .39625 L .55485 .39307 L F
.908 .931 .556 r
.32596 .59108 m .32378 .5947 L .3242 .59628 L F
.847 .419 0 r
.32378 .5947 m .32553 .59676 L .3242 .59628 L F
.32553 .59676 m .3257 .59695 L .32532 .59679 L F
.32553 .59676 m .32532 .59679 L .3242 .59628 L F
.32378 .5947 m .32501 .59702 L .3257 .59695 L F
0 0 0 r
.32501 .59702 m .32991 .59567 L .3257 .59695 L F
0 0 .295 r
.32745 .59645 m .32857 .59776 L .32864 .59627 L F
0 0 0 r
.32662 .59657 m .32745 .59645 L .32991 .59567 L F
.32968 .59451 m .33261 .59223 L .33015 .59324 L F
.32968 .59451 m .33122 .59364 L .33261 .59223 L F
.885 .986 .811 r
.33007 .59476 m .32745 .59645 L .3304 .59287 L F
.32991 .59567 m .32874 .59604 L .33007 .59476 L F
.32874 .59604 m .32745 .59645 L .33007 .59476 L F
0 0 0 r
.33122 .59364 m .33134 .59358 L .33184 .59304 L F
.33122 .59364 m .33184 .59304 L .33261 .59223 L F
.794 .98 .704 r
.3304 .59287 m .32745 .59645 L .32872 .59455 L F
0 0 .295 r
.32745 .59645 m .32864 .59627 L .32872 .59455 L F
0 0 0 r
.32621 .59669 m .32745 .59645 L .32662 .59657 L F
.32501 .59702 m .32661 .59664 L .32621 .59669 L F
.32661 .59664 m .32745 .59645 L .32621 .59669 L F
.073 .242 .733 r
.47361 .54819 m .47435 .54952 L .47212 .54755 L F
.854 .957 .876 r
.66831 .32818 m .67204 .32641 L .67019 .32624 L F
.79 .989 .889 r
.67019 .32624 m .67204 .32641 L .67396 .32455 L F
.665 .972 .819 r
.36787 .59611 m .37158 .5936 L .36875 .59465 L F
.073 .059 .535 r
.37298 .5949 m .37158 .5936 L .37269 .59195 L F
.551 .021 0 r
.36875 .59465 m .37158 .5936 L .37298 .5949 L F
.737 .944 .95 r
.68299 .31871 m .68362 .31937 L .68489 .31672 L F
.847 .699 .699 r
.3555 .63958 m .35737 .63993 L .35737 .6396 L F
.733 .698 .818 r
.35723 .63813 m .36148 .63785 L .36083 .64112 L F
.245 .454 .865 r
.35723 .63813 m .36149 .6392 L .36162 .63649 L F
.35723 .63813 m .36083 .64112 L .36149 .6392 L F
.817 .995 .859 r
.35713 .63762 m .35996 .63513 L .35737 .63592 L F
.659 .861 .977 r
.35312 .63745 m .35713 .63762 L .35583 .63666 L F
.632 .652 .851 r
.35246 .6387 m .35713 .63762 L .35312 .63745 L F
.35246 .6387 m .35538 .63931 L .35713 .63762 L F
.594 .839 .991 r
.35583 .63666 m .35713 .63762 L .35737 .63592 L F
.847 .699 .699 r
.35608 .63844 m .35737 .6396 L .35737 .63592 L F
.3555 .63958 m .35737 .6396 L .35608 .63844 L F
.361 .82 .926 r
.35825 .64039 m .35798 .64174 L .35538 .63931 L F
.3593 .64079 m .35896 .64103 L .35825 .64039 L F
.35896 .64103 m .35798 .64174 L .35825 .64039 L F
.3593 .64079 m .36083 .64112 L .35798 .64174 L F
.692 .961 .944 r
.64709 .34321 m .64572 .34533 L .64803 .34388 L F
.654 .912 .979 r
.64455 .34448 m .64572 .34533 L .64709 .34321 L F
.505 .479 .762 r
.45417 .54469 m .45678 .54414 L .45544 .54013 L F
.063 .351 .825 r
.58471 .3966 m .58264 .39692 L .58145 .39541 L F
.58471 .3966 m .58541 .39856 L .58264 .39692 L F
0 .062 .626 r
.60685 .37966 m .60609 .38074 L .60723 .37773 L F
.60685 .37966 m .60729 .38264 L .60609 .38074 L F
.508 .42 .691 r
.4734 .5268 m .47128 .53145 L .47075 .52875 L F
.613 .443 .628 r
.49584 .4897 m .49581 .49267 L .49323 .49295 L F
.592 .397 .586 r
.49841 .48921 m .49581 .49267 L .49584 .4897 L F
.624 .946 .748 r
.55485 .39307 m .55653 .39112 L .55737 .391 L F
0 0 .231 r
.55485 .39307 m .55564 .39398 L .55653 .39112 L F
.55564 .39398 m .55584 .3942 L .55609 .39309 L F
.55564 .39398 m .55609 .39309 L .55653 .39112 L F
.945 .791 .333 r
.55653 .39112 m .55642 .39158 L .55571 .39285 L F
.55642 .39158 m .55584 .3942 L .55571 .39285 L F
0 0 .231 r
.55485 .39307 m .55508 .39625 L .55563 .39476 L F
.55527 .39356 m .55563 .39476 L .55584 .3942 L F
.55485 .39307 m .55563 .39476 L .55527 .39356 L F
.493 .82 1 r
.55508 .39625 m .55781 .3956 L .55584 .3942 L F
.781 .588 .639 r
.55591 .39569 m .55223 .3981 L .5533 .39574 L F
.5565 .39567 m .556 .39596 L .55591 .39569 L F
.556 .39596 m .55223 .3981 L .55591 .39569 L F
.189 .64 .943 r
.55584 .3942 m .55781 .3956 L .5599 .39534 L F
.55584 .3942 m .5599 .39534 L .5587 .39542 L F
.713 .423 .483 r
.5587 .39542 m .5565 .39567 L .55584 .3942 L F
0 0 .538 r
.55584 .3942 m .5565 .39567 L .55571 .39285 L F
.501 .446 .727 r
.55571 .39285 m .5565 .39567 L .5533 .39574 L F
0 0 0 r
.55571 .39285 m .55448 .39445 L .55514 .39387 L F
.55571 .39285 m .55514 .39387 L .55643 .39271 L F
.945 .791 .333 r
.55653 .39112 m .55571 .39285 L .55719 .39118 L F
.873 .975 .667 r
.5571 .39108 m .55571 .39285 L .55624 .39014 L F
.55719 .39118 m .55685 .39157 L .5571 .39108 L F
.55685 .39157 m .55571 .39285 L .5571 .39108 L F
0 0 .06 r
.32968 .59451 m .32991 .59567 L .33134 .59358 L F
.405 .468 .812 r
.31862 .62671 m .3188 .62737 L .32084 .62597 L F
0 .571 .709 r
.31827 .62737 m .32055 .6274 L .31827 .62736 L F
.31744 .62735 m .31827 .62736 L .3168 .62734 L F
.31827 .62737 m .31827 .62736 L .31744 .62735 L F
.694 .657 .809 r
.3168 .62734 m .31898 .62799 L .31892 .62778 L F
.707 .314 .3 r
.31909 .62782 m .32055 .6274 L .32012 .62803 L F
.3191 .62774 m .32055 .6274 L .31909 .62782 L F
.31827 .62736 m .32055 .6274 L .31892 .62778 L F
0 0 .187 r
.31909 .62789 m .31898 .62799 L .31902 .62962 L F
.405 .468 .812 r
.31892 .62778 m .31898 .62799 L .31909 .62789 L F
.727 .301 .236 r
.31902 .62962 m .31898 .62799 L .3168 .62734 L F
.707 .314 .3 r
.3168 .62734 m .32012 .62803 L .31902 .62962 L F
0 0 .187 r
.321 .62611 m .31909 .62789 L .31902 .62962 L F
.707 .314 .3 r
.31892 .62778 m .3191 .62774 L .31909 .62782 L F
.3168 .62734 m .31827 .62736 L .31892 .62778 L F
.405 .468 .812 r
.3188 .62737 m .31892 .62778 L .31963 .62738 L F
.31892 .62778 m .31909 .62789 L .31963 .62738 L F
.694 .657 .809 r
.3168 .62734 m .31892 .62778 L .3176 .62311 L F
.405 .468 .812 r
.3176 .62311 m .321 .62611 L .31995 .62243 L F
.677 .209 .133 r
.32118 .62593 m .32084 .62496 L .321 .62611 L F
.32084 .62496 m .32049 .62433 L .321 .62611 L F
0 0 0 r
.32157 .62554 m .32171 .6254 L .32129 .62582 L F
.32171 .6254 m .32408 .62302 L .32148 .62562 L F
.32171 .6254 m .32148 .62562 L .32129 .62582 L F
.015 .227 .735 r
.32245 .62468 m .32196 .6256 L .32179 .62533 L F
0 0 0 r
.32245 .62468 m .32297 .62415 L .32157 .62554 L F
.015 .227 .735 r
.32245 .62468 m .32179 .62533 L .31995 .62243 L F
.549 .445 .688 r
.32168 .62543 m .32132 .62581 L .32196 .6256 L F
0 0 0 r
.32159 .62552 m .32129 .62582 L .32131 .6258 L F
.549 .445 .688 r
.32084 .62496 m .32131 .6258 L .32168 .62543 L F
.32131 .6258 m .32132 .62581 L .32168 .62543 L F
0 0 0 r
.32131 .6258 m .32129 .62582 L .32129 .62582 L F
.549 .445 .688 r
.32168 .62543 m .32196 .6256 L .32179 .62533 L F
0 0 0 r
.32245 .62468 m .32159 .62552 L .32131 .6258 L F
.549 .445 .688 r
.32084 .62496 m .32168 .62543 L .31995 .62243 L F
.32168 .62543 m .32179 .62533 L .31995 .62243 L F
0 0 0 r
.32129 .62582 m .32129 .62582 L .321 .62611 L F
.677 .209 .133 r
.32245 .62468 m .31995 .62243 L .32116 .62586 L F
.32129 .62582 m .32116 .62586 L .32118 .62593 L F
.32245 .62468 m .32116 .62586 L .32129 .62582 L F
0 0 0 r
.32166 .6257 m .32177 .62566 L .32191 .62561 L F
.31805 .62698 m .32156 .62573 L .32166 .6257 L F
.32156 .62573 m .32177 .62566 L .32166 .6257 L F
.405 .468 .812 r
.3176 .62311 m .31862 .62671 L .32084 .62597 L F
.549 .445 .688 r
.3176 .62311 m .31758 .62708 L .32132 .62581 L F
.3176 .62311 m .32132 .62581 L .32084 .62496 L F
.677 .209 .133 r
.32084 .62496 m .31995 .62243 L .32049 .62433 L F
.549 .445 .688 r
.3176 .62311 m .32084 .62496 L .31995 .62243 L F
0 0 0 r
.32297 .62415 m .32408 .62302 L .32157 .62554 L F
.31805 .62698 m .31758 .62708 L .32128 .62582 L F
0 0 .175 r
.321 .62611 m .32192 .62737 L .32229 .62551 L F
0 0 0 r
.32148 .62576 m .3213 .62582 L .32177 .62566 L F
.32191 .62561 m .32177 .62566 L .32196 .6256 L F
0 0 .175 r
.32129 .62582 m .32155 .62574 L .32245 .62468 L F
.321 .62611 m .32229 .62551 L .32129 .62582 L F
0 0 0 r
.32128 .62583 m .32128 .62582 L .3213 .62582 L F
.32128 .62583 m .3213 .62582 L .32148 .62576 L F
.31805 .62698 m .32128 .62582 L .32128 .62583 L F
.662 .973 .847 r
.31805 .62698 m .32155 .62574 L .32245 .62468 L F
.32155 .62574 m .32196 .6256 L .32245 .62468 L F
0 0 .175 r
.32155 .62574 m .32229 .62551 L .32245 .62468 L F
.405 .468 .812 r
.32084 .62597 m .3188 .62737 L .321 .62611 L F
.3188 .62737 m .31963 .62738 L .321 .62611 L F
.701 .654 .8 r
.57004 .41554 m .57418 .41616 L .57275 .41204 L F
.775 .693 .773 r
.57275 .41204 m .57418 .41616 L .57668 .41282 L F
.702 .585 .721 r
.57418 .41616 m .57793 .41649 L .57668 .41282 L F
.257 .64 .963 r
.37015 .60889 m .37077 .60902 L .36873 .60732 L F
.598 .395 .577 r
.48457 .49326 m .48642 .49998 L .48276 .49945 L F
.66 .739 .909 r
.48457 .49326 m .48722 .49266 L .48685 .49586 L F
.508 .341 .589 r
.48706 .49828 m .48457 .49326 L .48685 .49586 L F
.48706 .49828 m .48642 .49998 L .48457 .49326 L F
.067 0 .415 r
.31729 .61119 m .31906 .6108 L .31913 .60795 L F
.007 0 .125 r
.31729 .61119 m .3166 .61408 L .31906 .6108 L F
.779 .749 .826 r
.33331 .50269 m .33811 .50321 L .33602 .50293 L F
.634 .939 .961 r
.33602 .50293 m .33811 .50321 L .34019 .50195 L F
0 .559 .754 r
.72186 .31474 m .72585 .31517 L .72422 .31504 L F
0 0 0 r
.62736 .40469 m .62787 .40281 L .62548 .40631 L F
.669 .932 .645 r
.6305 .39997 m .62787 .40281 L .62924 .40078 L F
0 0 0 r
.62924 .40078 m .62787 .40281 L .62736 .40469 L F
.758 .994 .806 r
.38704 .67215 m .38883 .67118 L .39034 .66913 L F
.632 .648 .848 r
.72204 .33047 m .72355 .33407 L .7261 .33132 L F
.598 .854 .992 r
.3731 .68527 m .37452 .68635 L .37658 .68547 L F
.549 .539 .796 r
.4932 .49551 m .48893 .49275 L .49323 .49295 L F
.631 .408 .56 r
.49581 .49267 m .4932 .49551 L .49323 .49295 L F
.136 .174 .638 r
.30342 .6361 m .30397 .63685 L .3031 .63483 L F
.389 .439 .792 r
.30176 .63032 m .3031 .63483 L .30454 .63397 L F
.755 .674 .772 r
.30397 .63685 m .30454 .63397 L .3031 .63483 L F
0 0 0 r
.65599 .37959 m .65318 .38258 L .6537 .38075 L F
.65851 .37852 m .65599 .37959 L .65816 .37861 L F
.65816 .37861 m .65599 .37959 L .6537 .38075 L F
.732 .645 .762 r
.35555 .54062 m .35675 .54407 L .35916 .54122 L F
.613 .608 .821 r
.36044 .53956 m .35796 .5421 L .35608 .53616 L F
0 0 0 r
.36216 .53798 m .35916 .54122 L .36084 .53996 L F
.115 0 0 r
.35916 .54122 m .35984 .54157 L .36084 .53996 L F
.35984 .54157 m .36041 .54186 L .36064 .54084 L F
.35984 .54157 m .36064 .54084 L .36084 .53996 L F
.346 .157 .476 r
.3628 .53878 m .36041 .54186 L .36134 .54026 L F
.717 .654 .786 r
.36041 .54186 m .3628 .53878 L .36221 .53914 L F
.36123 .54017 m .36178 .5394 L .36084 .53996 L F
.36125 .54018 m .36128 .54013 L .36123 .54017 L F
.36128 .54013 m .36178 .5394 L .36123 .54017 L F
.437 .453 .778 r
.3628 .53878 m .36134 .54026 L .36128 .54013 L F
.717 .654 .786 r
.36125 .54018 m .36221 .53914 L .36178 .5394 L F
0 0 .111 r
.36344 .53669 m .36084 .53996 L .36216 .53798 L F
.3636 .53653 m .36311 .53714 L .36344 .53669 L F
.36311 .53714 m .36084 .53996 L .36344 .53669 L F
.3636 .53653 m .3628 .53878 L .36084 .53996 L F
.613 .608 .821 r
.36113 .53981 m .35608 .53616 L .35911 .5356 L F
.36128 .54013 m .36104 .53994 L .36113 .53981 L F
.36104 .53994 m .35608 .53616 L .36113 .53981 L F
.437 .453 .778 r
.3628 .53878 m .36128 .54013 L .35911 .5356 L F
.613 .608 .821 r
.36134 .54026 m .36125 .54018 L .36128 .54013 L F
.36125 .54018 m .35608 .53616 L .36128 .54013 L F
.717 .654 .786 r
.36064 .54084 m .36125 .54018 L .36084 .53996 L F
.613 .608 .821 r
.36131 .54023 m .36108 .54037 L .36125 .54018 L F
.36134 .54026 m .36121 .54033 L .36131 .54023 L F
.717 .654 .786 r
.36041 .54186 m .36101 .54044 L .36064 .54084 L F
.584 .849 .501 r
.35675 .54407 m .35706 .54367 L .35916 .54122 L F
.35706 .54367 m .3584 .54204 L .35916 .54122 L F
.115 0 0 r
.35916 .54122 m .3578 .54269 L .36041 .54186 L F
.167 0 0 r
.36041 .54186 m .35796 .5421 L .36101 .54044 L F
.36041 .54186 m .36101 .54044 L .36134 .54026 L F
.717 .654 .786 r
.36041 .54186 m .36221 .53914 L .36101 .54044 L F
.613 .608 .821 r
.36125 .54018 m .35867 .54172 L .36044 .53956 L F
.36108 .54037 m .35867 .54172 L .36125 .54018 L F
.36121 .54033 m .35867 .54172 L .36131 .54023 L F
.35867 .54172 m .35796 .5421 L .36044 .53956 L F
.584 .849 .501 r
.35706 .54367 m .3578 .54269 L .3584 .54204 L F
.197 .08 .485 r
.35643 .54661 m .3578 .54269 L .35675 .54407 L F
.681 .717 .877 r
.30614 .64068 m .30788 .64399 L .30579 .64448 L F
.599 .406 .592 r
.43946 .58253 m .44203 .58295 L .44184 .57972 L F
.4 .257 .568 r
.44184 .57972 m .44414 .58194 L .44379 .57913 L F
.44184 .57972 m .44203 .58295 L .44414 .58194 L F
.623 .83 .431 r
.40361 .47878 m .4045 .47756 L .40603 .47934 L F
.782 .993 .774 r
.64906 .39795 m .65083 .3972 L .65219 .39555 L F
.649 .811 .961 r
.36103 .55202 m .36175 .5537 L .35794 .55247 L F
.962 .695 .258 r
.35923 .55685 m .35794 .55247 L .36175 .5537 L F
.59 .82 .987 r
.36379 .68611 m .3677 .68648 L .366 .68623 L F
.352 .376 .746 r
.57668 .41282 m .57793 .41649 L .5797 .41454 L F
.027 .122 .628 r
.57793 .41649 m .57924 .4173 L .5797 .41454 L F
.97 .781 .592 r
.38687 .53089 m .38627 .53473 L .38803 .53521 L F
.663 .109 0 r
.38627 .53473 m .38713 .53567 L .38803 .53521 L F
.82 .344 0 r
.38713 .53567 m .38888 .5368 L .38803 .53521 L F
0 0 .318 r
.33423 .68848 m .33221 .69299 L .3346 .69282 L F
.592 .814 .984 r
.61672 .35635 m .61795 .35779 L .62076 .35682 L F
.368 .107 .381 r
.34876 .59933 m .35104 .59878 L .35153 .59635 L F
.385 .122 .387 r
.35153 .59635 m .35348 .59797 L .35405 .59554 L F
.35153 .59635 m .35104 .59878 L .35348 .59797 L F
.507 .884 .686 r
.39758 .68369 m .39422 .68596 L .39679 .68553 L F
.513 .004 0 r
.35091 .63332 m .34897 .63192 L .34793 .63459 L F
.524 .381 .629 r
.47432 .51826 m .47218 .52171 L .47197 .51884 L F
.65 .468 .625 r
.5608 .4317 m .56385 .43149 L .56387 .42862 L F
0 0 0 r
.322 .52672 m .31951 .52816 L .32131 .52722 L F
.32131 .52722 m .31951 .52816 L .322 .52672 L F
.055 0 0 r
.32131 .52722 m .3239 .52544 L .322 .52672 L F
.732 .683 .802 r
.3239 .52544 m .32131 .52722 L .322 .52672 L F
.231 .089 .473 r
.43702 .58369 m .43403 .5899 L .43566 .58836 L F
.309 0 0 r
.43183 .58996 m .43566 .58836 L .43403 .5899 L F
.815 .643 .091 r
.38527 .60529 m .385 .60441 L .38498 .60157 L F
0 0 .344 r
.38527 .60529 m .38658 .60807 L .385 .60441 L F
.369 .734 .989 r
.60094 .35818 m .60476 .35894 L .60385 .35788 L F
.463 0 0 r
.60476 .35894 m .60824 .35985 L .60798 .3603 L F
.60476 .35894 m .60798 .3603 L .60385 .35788 L F
.617 .439 .619 r
.5074 .47987 m .50748 .4828 L .50474 .48309 L F
.587 .397 .591 r
.51016 .4797 m .50748 .4828 L .5074 .47987 L F
.954 .901 .733 r
.28483 .65482 m .28732 .65531 L .28622 .65708 L F
.878 .956 .852 r
.64089 .40738 m .64482 .40531 L .64367 .40427 L F
.904 .952 .821 r
.64367 .40427 m .64482 .40531 L .64722 .40205 L F
.191 0 0 r
.34378 .54746 m .34625 .54731 L .34772 .54665 L F
.408 0 0 r
.34772 .54665 m .34625 .54731 L .34998 .547 L F
.898 .783 .725 r
.3857 .61252 m .38448 .61474 L .3837 .61164 L F
.3857 .61252 m .38448 .61474 L .3837 .61164 L F
.938 .691 .217 r
.32819 .62781 m .3289 .63139 L .32827 .63066 L F
.32819 .62781 m .3289 .63139 L .32827 .63066 L F
.579 .116 0 r
.33092 .63403 m .3289 .63139 L .32827 .63066 L F
.766 .859 .919 r
.47261 .44712 m .4705 .44869 L .46888 .44724 L F
0 .039 .609 r
.37597 .66768 m .37661 .66888 L .3771 .66934 L F
.524 .368 .612 r
.37597 .66768 m .3771 .66934 L .37961 .66567 L F
.787 .894 .92 r
.37731 .7021 m .37994 .70166 L .3794 .70055 L F
.815 .827 .859 r
.37994 .70166 m .38184 .6979 L .3794 .70055 L F
.832 .734 .757 r
.41497 .48905 m .4153 .49204 L .41535 .4897 L F
.353 .193 .521 r
.41676 .49614 m .4187 .49828 L .4192 .49544 L F
.41676 .49614 m .4187 .49828 L .4192 .49544 L F
.359 .194 .517 r
.41656 .49878 m .4187 .49828 L .41676 .49614 L F
.651 .603 .787 r
.73137 .32906 m .72782 .32548 L .7317 .32738 L F
0 0 .432 r
.7317 .32738 m .73204 .33111 L .73137 .32906 L F
.71 .306 .28 r
.36617 .63032 m .36837 .62859 L .36464 .62812 L F
.78 .408 .352 r
.36875 .63072 m .36837 .62859 L .36617 .63032 L F
.552 .89 .984 r
.37088 .62761 m .36837 .62859 L .36875 .63072 L F
.867 .947 .588 r
.37179 .69391 m .36937 .69784 L .37176 .69562 L F
.299 0 .129 r
.37417 .6945 m .37179 .69391 L .37176 .69562 L F
.71 .726 .863 r
.3699 .69402 m .3731 .69438 L .37176 .69562 L F
.3731 .69438 m .37417 .6945 L .37176 .69562 L F
.867 .947 .588 r
.36937 .69784 m .36912 .69825 L .37176 .69562 L F
.313 .576 .934 r
.58704 .38806 m .58808 .38994 L .58916 .38817 L F
.181 .399 .839 r
.58808 .38994 m .59108 .3915 L .58916 .38817 L F
.639 .808 .964 r
.73289 .33372 m .73472 .33536 L .7359 .3342 L F
.633 .436 .598 r
.44083 .52837 m .44085 .53114 L .44356 .52807 L F
.622 .922 .975 r
.65988 .33685 m .65877 .33616 L .65729 .33811 L F
.646 .939 .692 r
.65877 .33616 m .65561 .33905 L .65729 .33811 L F
.987 .727 .442 r
.39006 .54233 m .39256 .54241 L .39 .53998 L F
.39006 .54233 m .39156 .54383 L .39256 .54241 L F
.969 .678 .42 r
.39256 .54241 m .39156 .54383 L .39321 .54473 L F
.456 0 0 r
.23784 .57533 m .2407 .57565 L .24228 .57414 L F
0 0 0 r
.24228 .57414 m .2427 .57456 L .24462 .5742 L F
.24228 .57414 m .2407 .57565 L .2427 .57456 L F
.596 .272 .391 r
.24117 .58308 m .24035 .58567 L .23663 .58522 L F
.123 0 .196 r
.24169 .58445 m .24117 .58308 L .24272 .58175 L F
.24169 .58445 m .24035 .58567 L .24117 .58308 L F
.659 .377 .481 r
.34505 .6019 m .3485 .60185 L .34876 .59933 L F
0 0 .233 r
.34876 .59933 m .34989 .60012 L .35104 .59878 L F
.34876 .59933 m .34868 .60008 L .34989 .60012 L F
0 .54 .737 r
.34841 .59993 m .35024 .60014 L .34989 .60012 L F
.671 .398 .498 r
.34989 .60012 m .35291 .60044 L .35348 .59797 L F
0 .54 .737 r
.35024 .60014 m .35291 .60044 L .34989 .60012 L F
0 0 .233 r
.34868 .60008 m .3485 .60185 L .34989 .60012 L F
0 0 0 r
.66816 .31439 m .67032 .31319 L .6708 .31133 L F
.67032 .31319 m .6721 .31132 L .67315 .31013 L F
.55 .823 .47 r
.67315 .31013 m .6721 .31132 L .67211 .31131 L F
0 0 0 r
.6708 .31133 m .67315 .31013 L .67417 .30897 L F
.55 .823 .47 r
.67315 .31013 m .67211 .31131 L .67486 .30808 L F
0 0 0 r
.67417 .30897 m .67315 .31013 L .67423 .30893 L F
.6708 .31133 m .67032 .31319 L .67315 .31013 L F
.027 .167 .675 r
.59865 .45929 m .59632 .45783 L .59837 .45758 L F
.67 .742 .244 r
.70011 .35556 m .70011 .3556 L .70103 .353 L F
0 0 0 r
.69774 .35984 m .70011 .3556 L .69931 .3578 L F
.67 .742 .244 r
.69931 .3578 m .70011 .3556 L .70011 .35556 L F
.606 .805 .391 r
.70011 .3556 m .69873 .35779 L .7001 .35565 L F
.70011 .3556 m .7001 .35565 L .70096 .3543 L F
0 0 0 r
.69774 .35984 m .69873 .35779 L .70011 .3556 L F
.57861 .42227 m .57556 .42526 L .57811 .42452 L F
.141 0 .263 r
.58062 .42102 m .57861 .42227 L .57811 .42452 L F
0 0 .238 r
.2315 .59999 m .2298 .59938 L .23142 .59977 L F
.2315 .59999 m .22963 .60187 L .2298 .59938 L F
.072 .322 .802 r
.3507 .69992 m .35149 .69923 L .34939 .69923 L F
.3507 .69992 m .3531 .7019 L .35149 .69923 L F
.375 0 0 r
.36181 .59789 m .36227 .60037 L .35955 .60047 L F
.162 0 .348 r
.3645 .59709 m .36181 .59789 L .36425 .59486 L F
.207 0 .028 r
.36471 .59946 m .36181 .59789 L .3645 .59709 L F
.36471 .59946 m .36227 .60037 L .36181 .59789 L F
.647 .171 .109 r
.37288 .62936 m .37513 .62789 L .37088 .62761 L F
.503 .853 .594 r
.37614 .62687 m .37825 .62527 L .37513 .62789 L F
.501 .867 .639 r
.37614 .62687 m .37513 .62789 L .37288 .62936 L F
.126 0 0 r
.28665 .63779 m .28739 .63877 L .28622 .64075 L F
.28665 .63779 m .28916 .63718 L .28739 .63877 L F
0 .123 .673 r
.33216 .63801 m .33329 .63964 L .33118 .63727 L F
.849 .564 .506 r
.34151 .68945 m .33786 .68529 L .34071 .68725 L F
0 .239 .75 r
.34223 .6881 m .34151 .68945 L .34071 .68725 L F
.299 .644 .967 r
.34223 .6881 m .34397 .68963 L .34151 .68945 L F
.769 .833 .901 r
.47946 .44483 m .47541 .4451 L .47775 .44325 L F
.831 .826 .843 r
.48218 .44183 m .47946 .44483 L .47775 .44325 L F
.866 .436 .015 r
.38078 .52194 m .38155 .52388 L .38299 .52501 L F
.887 .49 .265 r
.38149 .5264 m .38299 .52501 L .38155 .52388 L F
.38149 .5264 m .38346 .52721 L .38299 .52501 L F
.623 .407 .568 r
.51285 .47673 m .51293 .47938 L .51016 .4797 L F
.566 .338 .528 r
.51559 .47644 m .51293 .47938 L .51285 .47673 L F
.439 .64 .942 r
.69015 .31038 m .69146 .31207 L .68848 .31237 L F
.575 .471 .699 r
.69146 .31207 m .68876 .31534 L .68848 .31237 L F
.966 .65 .263 r
.60308 .43364 m .6034 .43614 L .60443 .4351 L F
.882 .45 .132 r
.6034 .43614 m .60527 .43725 L .60443 .4351 L F
.419 0 0 r
.35292 .59018 m .35192 .59117 L .34918 .59001 L F
.644 .094 0 r
.35292 .59018 m .35474 .59187 L .35192 .59117 L F
.092 0 0 r
.34823 .54143 m .34443 .54207 L .34649 .54154 L F
.678 .949 .957 r
.35708 .56056 m .3575 .55867 L .35923 .55685 L F
.35708 .56056 m .35554 .56042 L .3575 .55867 L F
.64 .59 .783 r
.36236 .58764 m .36002 .58958 L .35915 .58576 L F
.761 .995 .81 r
.66475 .38684 m .66755 .38421 L .66595 .38455 L F
.761 .995 .817 r
.66313 .38711 m .66475 .38684 L .66595 .38455 L F
.815 .874 .889 r
.51416 .42437 m .51258 .42607 L .51103 .42448 L F
.46 0 0 r
.37937 .49923 m .38136 .50006 L .38436 .49973 L F
.922 .973 .764 r
.38659 .49549 m .38436 .49973 L .38434 .49701 L F
.847 .947 .883 r
.38436 .49973 m .38136 .50006 L .38434 .49701 L F
0 .146 .675 r
.58781 .40046 m .58661 .40017 L .58541 .39856 L F
.58781 .40046 m .58858 .40186 L .58661 .40017 L F
.693 .656 .809 r
.34301 .60811 m .34699 .61204 L .34577 .60762 L F
0 0 0 r
.34443 .61438 m .34559 .61349 L .34699 .61204 L F
0 0 .431 r
.34577 .60762 m .34699 .61204 L .34697 .60967 L F
0 0 0 r
.34699 .61204 m .34754 .61234 L .34697 .60967 L F
.34699 .61204 m .34559 .61349 L .34754 .61234 L F
.309 0 0 r
.3092 .64737 m .31054 .64837 L .30805 .64981 L F
.3092 .64737 m .31188 .64731 L .31054 .64837 L F
.972 .909 .566 r
.39864 .57805 m .40037 .57629 L .39897 .57551 L F
.39864 .57805 m .39919 .57886 L .40037 .57629 L F
.74 .242 0 r
.6171 .43345 m .61688 .43393 L .61457 .43086 L F
.659 .268 .294 r
.53109 .47035 m .53508 .47048 L .53486 .47231 L F
.623 .236 .29 r
.53508 .47048 m .5377 .47244 L .53486 .47231 L F
.583 .944 .841 r
.56761 .40237 m .56514 .40358 L .56751 .40466 L F
.74 .41 .425 r
.56234 .40135 m .56761 .40237 L .56751 .40466 L F
0 .328 .773 r
.58434 .38662 m .58555 .38669 L .58263 .38551 L F
.58434 .38662 m .58704 .38806 L .58555 .38669 L F
.949 .946 .737 r
.39416 .48635 m .39451 .48268 L .3967 .48248 L F
.722 .552 .659 r
.39664 .48594 m .39416 .48635 L .3967 .48248 L F
.871 .594 .516 r
.38346 .52721 m .38687 .53089 L .38618 .52866 L F
.619 .443 .621 r
.34294 .61333 m .33993 .61166 L .33918 .6154 L F
.901 .509 .082 r
.34266 .61541 m .34294 .61333 L .33918 .6154 L F
.75 .968 .932 r
.3417 .61483 m .34266 .61541 L .34105 .61505 L F
.901 .509 .082 r
.34266 .61541 m .34375 .61606 L .34294 .61333 L F
.75 .968 .932 r
.34559 .61349 m .34266 .61541 L .3417 .61483 L F
.901 .509 .082 r
.34266 .61541 m .3441 .61724 L .34375 .61606 L F
0 0 0 r
.37809 .63093 m .38104 .62732 L .37933 .62944 L F
.629 .93 .68 r
.38104 .62732 m .38403 .62457 L .38195 .62592 L F
0 0 0 r
.6572 .32467 m .6546 .32569 L .65352 .32673 L F
.788 .947 .605 r
.22773 .56944 m .22535 .573 L .22619 .57018 L F
.996 .85 .508 r
.46274 .55724 m .46201 .55639 L .46274 .55385 L F
0 0 .148 r
.46256 .55962 m .46201 .55639 L .46274 .55724 L F
.848 .428 .235 r
.61158 .42553 m .61038 .42675 L .61003 .42401 L F
.61158 .42553 m .61247 .42757 L .61038 .42675 L F
.896 .51 .064 r
.60872 .41798 m .60991 .4192 L .61051 .42121 L F
.445 .214 .469 r
.37562 .58589 m .3728 .58913 L .3729 .58642 L F
.975 .901 .68 r
.39767 .56363 m .39793 .55912 L .3972 .56261 L F
.886 .554 .056 r
.39742 .56471 m .39767 .56363 L .3972 .56261 L F
.39742 .56471 m .39823 .5661 L .39767 .56363 L F
.955 .794 .347 r
.39895 .58518 m .39917 .58885 L .39964 .58629 L F
.818 .998 .779 r
.38608 .69006 m .38531 .69106 L .38377 .69138 L F
.247 .544 .926 r
.38776 .69244 m .38531 .69106 L .38608 .69006 L F
.776 .903 .93 r
.54983 .41791 m .54804 .4196 L .54628 .41868 L F
.506 .243 .449 r
.28383 .56901 m .28682 .56623 L .28464 .56708 L F
.904 .952 .821 r
.64367 .40427 m .64722 .40205 L .64644 .40118 L F
.871 .989 .724 r
.64722 .40205 m .64906 .39795 L .64644 .40118 L F
.421 .432 .766 r
.60636 .36858 m .60785 .37515 L .60862 .37395 L F
.109 0 0 r
.60785 .37515 m .60508 .3756 L .60799 .37422 L F
.803 .999 .808 r
.60862 .37395 m .60785 .37515 L .60799 .37422 L F
.502 .279 .508 r
.69381 .30874 m .69398 .31102 L .69127 .3095 L F
.854 .703 .694 r
.69775 .30864 m .69822 .31203 L .69398 .31102 L F
.86 .675 .651 r
.69822 .31203 m .69568 .31412 L .69398 .31102 L F
.549 .329 .533 r
.50723 .48538 m .50474 .48309 L .50748 .4828 L F
.50723 .48538 m .50455 .48596 L .50474 .48309 L F
0 0 .25 r
.69893 .32533 m .69905 .32829 L .69985 .32573 L F
.732 .986 .896 r
.62821 .42412 m .63215 .42235 L .63122 .42159 L F
.862 .977 .856 r
.63122 .42159 m .63215 .42235 L .63508 .41911 L F
.69 .167 0 r
.33786 .68529 m .3383 .68741 L .33694 .68779 L F
.33786 .68529 m .34071 .68725 L .3383 .68741 L F
.747 .734 .84 r
.57275 .41204 m .57668 .41282 L .57557 .40996 L F
.572 .805 .987 r
.57668 .41282 m .57856 .41085 L .57557 .40996 L F
.57668 .41282 m .57829 .41235 L .57852 .41107 L F
.57668 .41282 m .57852 .41107 L .57835 .41107 L F
.352 .376 .746 r
.57668 .41282 m .5797 .41454 L .57829 .41235 L F
.656 .44 .579 r
.5742 .41107 m .57773 .41328 L .57414 .41285 L F
.754 .984 .906 r
.57275 .41204 m .57557 .40996 L .57422 .41046 L F
.656 .44 .579 r
.57422 .41046 m .57497 .41107 L .5742 .41107 L F
.57497 .41107 m .57773 .41328 L .5742 .41107 L F
.572 .805 .987 r
.57835 .41107 m .57852 .41107 L .57856 .41085 L F
.545 .342 .555 r
.44627 .52752 m .45042 .52249 L .44675 .52513 L F
.612 .925 .682 r
.73846 .32988 m .73825 .33051 L .73664 .33199 L F
.809 .974 .675 r
.73846 .32988 m .73664 .33199 L .73825 .33051 L F
.73846 .32988 m .7359 .3342 L .73664 .33199 L F
.763 .752 .843 r
.42794 .53468 m .42919 .53796 L .42514 .53727 L F
.548 0 0 r
.42919 .53796 m .4277 .53873 L .42514 .53727 L F
0 .084 .643 r
.42794 .53468 m .42955 .53666 L .42919 .53796 L F
.732 .96 .676 r
.42955 .53666 m .4277 .53873 L .42919 .53796 L F
.968 .816 .639 r
.39901 .67054 m .39837 .66593 L .39896 .66879 L F
.907 .919 .529 r
.39782 .67331 m .39901 .67054 L .39896 .66879 L F
.167 0 0 r
.30122 .56936 m .29695 .57159 L .29871 .56951 L F
.725 .831 .38 r
.70185 .3519 m .70096 .3543 L .7029 .35002 L F
.732 .842 .398 r
.70011 .3556 m .70096 .3543 L .70185 .3519 L F
.263 .766 .738 r
.27653 .51984 m .27523 .5201 L .27393 .52064 L F
.521 .364 .609 r
.47845 .5033 m .47859 .50553 L .47599 .50618 L F
.478 .329 .6 r
.47859 .50553 m .47621 .50876 L .47599 .50618 L F
.798 .697 .754 r
.62426 .35472 m .62446 .3594 L .62714 .35412 L F
.17 .446 .876 r
.2588 .61657 m .25896 .61922 L .25694 .61736 L F
.2588 .61657 m .26098 .61947 L .25896 .61922 L F
.353 .342 .708 r
.47564 .55612 m .47588 .55945 L .47438 .56048 L F
0 0 .296 r
.47588 .55945 m .47488 .56314 L .47438 .56048 L F
.686 .759 .266 r
.38758 .68599 m .38608 .69006 L .38665 .68837 L F
.831 .809 .321 r
.38743 .68585 m .38758 .68599 L .38665 .68837 L F
.969 .926 .688 r
.29504 .64472 m .29521 .64453 L .29287 .64596 L F
.032 0 .27 r
.21636 .56371 m .21818 .56258 L .2188 .56 L F
.033 0 .238 r
.21619 .56569 m .21818 .56258 L .21636 .56371 L F
.241 .522 .914 r
.23724 .54589 m .23671 .54761 L .23389 .54469 L F
.778 .968 .673 r
.23724 .54589 m .23466 .54917 L .23671 .54761 L F
.832 .734 .757 r
.41497 .48905 m .41118 .49169 L .4153 .49204 L F
.849 .955 .88 r
.41268 .4956 m .4153 .49204 L .41118 .49169 L F
.41268 .4956 m .41432 .49203 L .4153 .49204 L F
.776 .939 .591 r
.41596 .49073 m .41575 .49015 L .41706 .48857 L F
0 .074 .628 r
.41406 .48436 m .41497 .48905 L .41362 .48587 L F
.781 .488 .491 r
.41032 .48319 m .41362 .48587 L .41283 .48258 L F
.41032 .48319 m .40982 .48561 L .41362 .48587 L F
0 .074 .628 r
.41406 .48436 m .41362 .48587 L .40982 .48561 L F
.857 .814 .807 r
.41005 .4885 m .41497 .48905 L .41406 .48436 L F
.898 .96 .826 r
.41863 .48637 m .41575 .49015 L .41472 .4889 L F
.648 .118 0 r
.41871 .49248 m .41559 .48968 L .41575 .49015 L F
.41559 .48968 m .41472 .4889 L .41575 .49015 L F
.776 .939 .591 r
.4153 .49204 m .41575 .49015 L .41596 .49073 L F
.766 .981 .726 r
.4153 .49204 m .41432 .49203 L .41575 .49015 L F
.911 .85 .77 r
.36873 .60732 m .37077 .60902 L .36924 .60964 L F
.721 .852 .944 r
.36873 .60732 m .37077 .60902 L .37269 .60742 L F
.911 .85 .77 r
.36924 .60964 m .37077 .60902 L .36873 .60732 L F
.777 .54 .576 r
.31358 .59824 m .31774 .59882 L .3177 .59593 L F
.512 .415 .682 r
.3177 .59593 m .32003 .59549 L .31984 .5927 L F
.483 .305 .563 r
.3177 .59593 m .31774 .59882 L .32003 .59549 L F
.1 0 0 r
.34052 .49588 m .34285 .49611 L .34096 .4959 L F
.254 0 0 r
.34517 .49685 m .34285 .49611 L .34052 .49588 L F
0 0 0 r
.32765 .52158 m .33001 .52091 L .33096 .51996 L F
.33096 .51996 m .33001 .52091 L .33158 .51954 L F
.974 .791 .596 r
.62496 .36387 m .62603 .36405 L .6248 .36011 L F
.853 .405 .133 r
.62513 .36513 m .62603 .36405 L .62496 .36387 L F
.325 .432 .817 r
.6248 .36011 m .62603 .36405 L .62846 .36295 L F
0 0 0 r
.62846 .36295 m .62603 .36405 L .62513 .36513 L F
.593 .547 .772 r
.35432 .58298 m .3515 .58576 L .35155 .58317 L F
.918 .862 .77 r
.37229 .63687 m .376 .63423 L .3748 .63367 L F
.37229 .63687 m .37406 .63806 L .376 .63423 L F
.823 .957 .619 r
.376 .63423 m .37678 .63188 L .3748 .63367 L F
.376 .63423 m .37809 .63093 L .37678 .63188 L F
.829 .75 .777 r
.39034 .48273 m .38647 .48229 L .3887 .47936 L F
.904 .889 .806 r
.39034 .48273 m .38614 .48492 L .38647 .48229 L F
.39034 .48273 m .38786 .48639 L .38614 .48492 L F
.66 .605 .782 r
.3887 .47936 m .39274 .48209 L .39034 .48273 L F
.231 .089 .473 r
.43702 .58369 m .43545 .58646 L .43246 .58533 L F
.43702 .58369 m .43566 .58836 L .43545 .58646 L F
.665 .249 .244 r
.43497 .58256 m .43738 .58474 L .43946 .58253 L F
.652 .232 .234 r
.43946 .58253 m .43738 .58474 L .44122 .58475 L F
.584 .227 .329 r
.43946 .58253 m .44122 .58475 L .44203 .58295 L F
.834 .573 .546 r
.36154 .58219 m .36525 .58306 L .36368 .58521 L F
.902 .823 .76 r
.74306 .31342 m .73974 .3149 L .74228 .31267 L F
.73 .881 .95 r
.74581 .31212 m .74306 .31342 L .74437 .31078 L F
.786 .95 .926 r
.74437 .31078 m .74306 .31342 L .74228 .31267 L F
.797 .872 .903 r
.44227 .54042 m .44611 .53969 L .44527 .53757 L F
.768 .822 .895 r
.44527 .53757 m .44611 .53969 L .44892 .53767 L F
0 .2 .619 r
.59652 .3959 m .59765 .39653 L .59525 .39462 L F
.59652 .3959 m .59957 .39776 L .59765 .39653 L F
0 0 .36 r
.21888 .55714 m .21982 .55899 L .22052 .55637 L F
.21888 .55714 m .2188 .56 L .21982 .55899 L F
0 0 0 r
.24677 .57497 m .24641 .57685 L .24883 .5764 L F
.24677 .57497 m .24507 .5782 L .24641 .57685 L F
.974 .672 .295 r
.62548 .40631 m .62395 .40221 L .62131 .40545 L F
.997 .775 .438 r
.62255 .40906 m .62409 .41027 L .62351 .4081 L F
.616 .099 0 r
.62406 .40762 m .62548 .40631 L .62131 .40545 L F
.567 0 0 r
.62406 .40762 m .62131 .40545 L .6231 .4074 L F
.62336 .40752 m .6231 .4074 L .6232 .4075 L F
.62406 .40762 m .6231 .4074 L .62336 .40752 L F
.616 .099 0 r
.6248 .40821 m .62544 .40643 L .62406 .40762 L F
.62544 .40643 m .62548 .40631 L .62406 .40762 L F
0 0 0 r
.62736 .40469 m .62548 .40631 L .6248 .40821 L F
.62736 .40469 m .6248 .40821 L .62684 .40672 L F
.567 0 0 r
.6248 .40821 m .62432 .40799 L .62312 .40662 L F
.773 .716 .799 r
.62312 .40662 m .62336 .40752 L .62382 .40742 L F
.567 0 0 r
.6248 .40821 m .62406 .40762 L .6232 .4075 L F
.767 .734 .822 r
.62312 .40662 m .62684 .40672 L .6248 .40821 L F
.773 .716 .799 r
.62336 .40752 m .62543 .40854 L .62684 .40672 L F
.567 0 0 r
.6232 .4075 m .62311 .4074 L .62303 .40743 L F
.6232 .4075 m .62231 .40711 L .62312 .40662 L F
.997 .775 .438 r
.62292 .40746 m .6232 .4075 L .62312 .40662 L F
.6232 .4075 m .62336 .40752 L .62312 .40662 L F
.567 0 0 r
.62432 .40799 m .6232 .4075 L .62312 .40662 L F
.773 .716 .799 r
.62312 .40662 m .62382 .40742 L .62684 .40672 L F
.62336 .40752 m .62409 .41027 L .62543 .40854 L F
.935 .803 .342 r
.62265 .40755 m .62312 .40662 L .62271 .40673 L F
.62255 .40906 m .62292 .40746 L .62265 .40755 L F
.567 0 0 r
.62311 .4074 m .62131 .40545 L .62303 .40743 L F
.935 .803 .342 r
.62292 .40746 m .62312 .40662 L .62265 .40755 L F
.567 0 0 r
.62303 .40743 m .62131 .40545 L .62231 .40711 L F
.997 .775 .438 r
.62259 .4089 m .62351 .4081 L .62336 .40752 L F
.62259 .4089 m .62336 .40752 L .62292 .40746 L F
.62255 .40906 m .62351 .4081 L .62259 .4089 L F
.005 .428 .861 r
.59198 .39321 m .59426 .39325 L .59108 .3915 L F
.59198 .39321 m .59525 .39462 L .59426 .39325 L F
.61 .33 .468 r
.52853 .47027 m .52859 .47248 L .52476 .4732 L F
.654 .365 .469 r
.52853 .47027 m .53113 .47276 L .52859 .47248 L F
.653 .365 .469 r
.53109 .47035 m .53113 .47276 L .52853 .47027 L F
.839 .6 .577 r
.7003 .31611 m .69931 .31821 L .6994 .31557 L F
.71 .973 .748 r
.23944 .60754 m .24098 .60572 L .24188 .60599 L F
.23944 .60754 m .23846 .60795 L .24098 .60572 L F
.454 .122 .312 r
.31295 .56472 m .31038 .56302 L .31321 .56214 L F
.31295 .56472 m .30915 .56606 L .31038 .56302 L F
.494 .181 .364 r
.25149 .57322 m .25402 .57291 L .25531 .57055 L F
.637 .378 .509 r
.25788 .57264 m .25531 .57055 L .25402 .57291 L F
.25788 .57264 m .25834 .57009 L .25531 .57055 L F
.357 .396 .765 r
.25788 .57264 m .25531 .57055 L .25834 .57009 L F
0 0 .278 r
.253 .57691 m .25356 .57502 L .25118 .57502 L F
.24 0 0 r
.25594 .5766 m .25399 .5782 L .253 .57691 L F
0 0 .278 r
.253 .57691 m .25399 .5782 L .25356 .57502 L F
.32 .389 .777 r
.29387 .6516 m .29442 .64972 L .2934 .65025 L F
.559 .529 .778 r
.45815 .54811 m .45943 .54344 L .45678 .54414 L F
.45815 .54811 m .46085 .54732 L .45943 .54344 L F
.382 .3 .638 r
.33015 .59324 m .33261 .59223 L .33036 .5923 L F
.926 .586 .137 r
.62912 .41485 m .6288 .41256 L .6274 .41105 L F
.807 .936 .915 r
.6274 .41105 m .6288 .41256 L .63162 .40938 L F
.902 .5 .231 r
.60007 .42426 m .6016 .42762 L .60331 .42819 L F
.97 .697 .457 r
.6016 .42762 m .6032 .431 L .60331 .42819 L F
.842 .683 .146 r
.40267 .53313 m .40238 .53016 L .40254 .53169 L F
.40267 .53313 m .40228 .53281 L .40238 .53016 L F
.744 .392 0 r
.40267 .53313 m .40315 .53455 L .40228 .53281 L F
0 0 .551 r
.47488 .56314 m .47638 .56517 L .47556 .56694 L F
0 0 .33 r
.47662 .56791 m .47556 .56694 L .47638 .56517 L F
.47662 .56791 m .47592 .5696 L .47556 .56694 L F
.748 .366 .328 r
.33412 .64362 m .33827 .64419 L .336 .64622 L F
0 0 0 r
.336 .64622 m .33827 .64419 L .34113 .64298 L F
.222 0 0 r
.59781 .36044 m .59651 .36135 L .59423 .36149 L F
.199 .715 .881 r
.59651 .36135 m .59443 .36123 L .59423 .36149 L F
0 .228 .732 r
.59342 .36087 m .59412 .36164 L .59423 .36149 L F
.08 .328 .805 r
.59342 .36087 m .59423 .36149 L .59194 .36016 L F
.199 .715 .881 r
.59443 .36123 m .59301 .36115 L .59423 .36149 L F
0 .228 .732 r
.59412 .36164 m .59579 .36352 L .59423 .36149 L F
.477 .267 .515 r
.59579 .36352 m .59588 .36639 L .59831 .36308 L F
.502 .473 .757 r
.34997 .61227 m .34873 .61495 L .34783 .61269 L F
.34997 .61227 m .35108 .61433 L .34873 .61495 L F
.491 .27 .506 r
.35108 .61433 m .34822 .6177 L .34873 .61495 L F
.842 .971 .88 r
.69317 .28956 m .68953 .29134 L .69263 .28854 L F
.901 .924 .539 r
.69455 .28452 m .69317 .28956 L .69263 .28854 L F
.844 .825 .829 r
.51599 .41763 m .51678 .421 L .51528 .42226 L F
.858 .831 .82 r
.51788 .41902 m .51678 .421 L .51599 .41763 L F
0 0 .369 r
.68014 .35374 m .67905 .35744 L .67811 .35657 L F
.928 .567 .145 r
.67811 .35657 m .67905 .35744 L .67891 .35924 L F
.702 .316 .315 r
.38035 .67612 m .37843 .67334 L .37619 .67527 L F
.37619 .67527 m .37843 .67334 L .38035 .67612 L F
.981 .882 .658 r
.62912 .39565 m .63015 .39377 L .6294 .39402 L F
.609 .904 .985 r
.23639 .53117 m .23701 .52947 L .23892 .53012 L F
.697 .974 .92 r
.23639 .53117 m .23488 .53103 L .23701 .52947 L F
.773 .859 .914 r
.62426 .35472 m .62714 .35412 L .62576 .3525 L F
.651 .831 .969 r
.62714 .35412 m .62861 .35119 L .62576 .3525 L F
.62714 .35412 m .62993 .35305 L .62861 .35119 L F
.975 .767 .56 r
.53239 .39347 m .53147 .39544 L .53008 .39178 L F
.653 .849 .975 r
.53407 .39206 m .53239 .39347 L .53008 .39178 L F
.292 .105 .447 r
.29921 .66804 m .29733 .66755 L .29694 .6693 L F
0 0 0 r
.38853 .59398 m .38997 .59309 L .38971 .59246 L F
.38853 .59398 m .38726 .5946 L .38997 .59309 L F
.643 .415 .559 r
.55708 .43453 m .56096 .43442 L .5608 .4317 L F
.688 .45 .557 r
.5608 .4317 m .56365 .4342 L .56385 .43149 L F
.5608 .4317 m .56096 .43442 L .56365 .4342 L F
0 .529 .838 r
.60508 .3756 m .60083 .37434 L .604 .37431 L F
.609 .853 .99 r
.60799 .37422 m .60508 .3756 L .604 .37431 L F
.679 .223 .164 r
.25616 .62163 m .25419 .62332 L .25198 .62117 L F
.887 .532 .37 r
.25616 .62163 m .25713 .62428 L .25419 .62332 L F
.846 .747 .754 r
.34795 .5233 m .34596 .52561 L .34442 .5243 L F
.402 .811 .979 r
.60341 .46144 m .60322 .46019 L .60198 .45973 L F
.60341 .46144 m .60688 .46092 L .60322 .46019 L F
.566 .343 .536 r
.35441 .57975 m .35432 .58298 L .35155 .58317 L F
.533 .316 .531 r
.35441 .57975 m .35685 .58207 L .35698 .57922 L F
.35441 .57975 m .35432 .58298 L .35685 .58207 L F
.35685 .58207 m .35441 .57975 L .35698 .57922 L F
.35685 .58207 m .35432 .58298 L .35441 .57975 L F
.527 .815 .998 r
.36968 .63752 m .37406 .63806 L .37229 .63687 L F
.778 .998 .849 r
.37758 .68298 m .3798 .68113 L .37773 .681 L F
.292 0 0 r
.37773 .681 m .3798 .68113 L .38146 .68186 L F
.533 .343 .569 r
.44031 .54625 m .43776 .54994 L .44089 .54718 L F
.869 .984 .839 r
.44272 .54334 m .44089 .54718 L .44332 .54375 L F
.44272 .54334 m .44031 .54625 L .44089 .54718 L F
.816 .852 .875 r
.50823 .428 m .50118 .43 L .50442 .42674 L F
.50823 .428 m .5029 .43137 L .50118 .43 L F
.36 .769 .982 r
.50823 .428 m .50442 .42674 L .50826 .42742 L F
.592 .397 .586 r
.49841 .48921 m .49832 .4926 L .49581 .49267 L F
.602 .405 .587 r
.50187 .49166 m .49841 .48921 L .50199 .48914 L F
.50187 .49166 m .49832 .4926 L .49841 .48921 L F
.962 .695 .258 r
.35923 .55685 m .35861 .55696 L .35794 .55247 L F
.896 .941 .576 r
.35923 .55685 m .3575 .55867 L .35861 .55696 L F
0 0 0 r
.70139 .29598 m .70194 .29709 L .69878 .29922 L F
.268 .258 .662 r
.70194 .29709 m .69902 .30206 L .69878 .29922 L F
.834 .838 .85 r
.34596 .52561 m .34347 .52866 L .34165 .52724 L F
.902 .613 .112 r
.44227 .54042 m .44272 .54334 L .44331 .54369 L F
0 0 .271 r
.44301 .54123 m .44272 .54334 L .44227 .54042 L F
.927 .958 .639 r
.4419 .54284 m .44272 .54334 L .44301 .54123 L F
.4409 .54428 m .44272 .54334 L .4419 .54284 L F
.902 .613 .112 r
.44331 .54369 m .44272 .54334 L .44332 .54375 L F
.998 .837 .549 r
.3981 .57152 m .39991 .57023 L .39869 .56787 L F
.3981 .57152 m .39923 .57282 L .39991 .57023 L F
.838 .779 .795 r
.31003 .64079 m .30788 .64399 L .30614 .64068 L F
.245 .041 .393 r
.35608 .53616 m .35435 .53482 L .35798 .53443 L F
.641 .571 .76 r
.36242 .53137 m .35798 .53443 L .35681 .53081 L F
.391 0 0 r
.35911 .5356 m .35798 .53443 L .36242 .53137 L F
.35911 .5356 m .35608 .53616 L .35798 .53443 L F
.725 .854 .943 r
.34829 .68948 m .34397 .68963 L .34646 .6891 L F
.528 .894 .971 r
.35072 .68834 m .34829 .68948 L .34646 .6891 L F
.855 .402 .108 r
.39214 .54565 m .39321 .54473 L .39156 .54383 L F
.39214 .54565 m .39427 .54668 L .39321 .54473 L F
.308 .304 .692 r
.21488 .58604 m .21649 .58601 L .21593 .58174 L F
.306 .342 .735 r
.21488 .58604 m .21739 .58814 L .21649 .58601 L F
.354 .08 .352 r
.32456 .58578 m .32708 .58559 L .32763 .58251 L F
.895 .988 .761 r
.32935 .57871 m .32763 .58251 L .32938 .58121 L F
.338 .067 .347 r
.32763 .58251 m .32975 .58459 L .32938 .58121 L F
.32763 .58251 m .32708 .58559 L .32975 .58459 L F
.286 .514 .9 r
.21819 .59231 m .2207 .59557 L .22122 .59373 L F
0 .019 .573 r
.2207 .59557 m .22226 .59789 L .22122 .59373 L F
.657 .662 .843 r
.35495 .70177 m .35623 .7018 L .35434 .69999 L F
.805 .877 .899 r
.35677 .70255 m .3612 .70326 L .36043 .70076 L F
0 0 0 r
.35638 .70275 m .36043 .70076 L .35881 .70185 L F
.657 .662 .843 r
.35623 .7018 m .35881 .70185 L .35516 .70033 L F
.35623 .7018 m .35516 .70033 L .35434 .69999 L F
.805 .877 .899 r
.35638 .70275 m .35696 .70281 L .35677 .70255 L F
.35696 .70281 m .3612 .70326 L .35677 .70255 L F
.617 .587 .797 r
.3612 .70326 m .36494 .70518 L .36287 .69999 L F
.834 .91 .889 r
.23564 .53885 m .2373 .54059 L .24015 .53716 L F
.502 .904 .79 r
.60247 .35685 m .60094 .35818 L .60385 .35788 L F
.619 .168 .159 r
.36365 .6144 m .36405 .61634 L .36156 .61469 L F
.995 .784 .506 r
.36661 .6137 m .36405 .61634 L .36365 .6144 L F
.575 .107 .107 r
.26852 .57325 m .2714 .57515 L .27247 .57318 L F
.781 .484 .485 r
.2714 .57515 m .27507 .57287 L .27247 .57318 L F
.823 .861 .412 r
.37658 .68547 m .37758 .68298 L .37773 .681 L F
.738 .263 .118 r
.38487 .6648 m .38639 .66308 L .38529 .6622 L F
.38487 .6648 m .38867 .66519 L .38639 .66308 L F
.707 .746 .882 r
.63663 .38575 m .64056 .38567 L .63972 .38302 L F
.514 .621 .895 r
.63972 .38302 m .64056 .38567 L .64514 .38425 L F
.769 .562 .618 r
.44471 .51745 m .44066 .5212 L .44064 .51781 L F
.44471 .51745 m .44699 .52283 L .44066 .5212 L F
.369 .359 .717 r
.4476 .51751 m .44471 .51745 L .44747 .51664 L F
.4476 .51751 m .44699 .52283 L .44471 .51745 L F
.99 .778 .524 r
.43036 .5735 m .43082 .57022 L .42911 .56923 L F
.246 0 0 r
.24824 .52617 m .24498 .52608 L .2449 .52776 L F
.698 .859 .959 r
.2449 .52776 m .2482 .52684 L .24824 .52617 L F
0 0 .324 r
.59957 .39776 m .60027 .39931 L .6014 .40161 L F
.398 0 0 r
.62768 .39481 m .62538 .39363 L .62495 .39506 L F
.963 .684 .256 r
.44567 .57339 m .44495 .57479 L .44493 .57223 L F
.44567 .57339 m .44585 .57633 L .44495 .57479 L F
.377 .352 .704 r
.47519 .53996 m .47341 .54394 L .4727 .54047 L F
.47519 .53996 m .47598 .54265 L .47341 .54394 L F
.469 .348 .632 r
.47598 .54265 m .47361 .54819 L .47341 .54394 L F
.508 .42 .691 r
.4734 .5268 m .47372 .53086 L .47128 .53145 L F
.526 .466 .732 r
.47372 .53086 m .47206 .53453 L .47128 .53145 L F
0 .187 .717 r
.30222 .66141 m .30236 .66323 L .29982 .65935 L F
0 .155 .695 r
.30439 .66485 m .30236 .66323 L .30222 .66141 L F
0 0 .296 r
.30291 .6662 m .30236 .66323 L .30439 .66485 L F
.484 .898 .818 r
.57588 .46262 m .58007 .46106 L .57859 .46203 L F
.416 .126 .361 r
.70079 .3061 m .70022 .30813 L .69775 .30864 L F
0 .109 .66 r
.69902 .30206 m .70141 .30494 L .70079 .3061 L F
0 0 .113 r
.7023 .30604 m .70079 .3061 L .70141 .30494 L F
.7023 .30604 m .70022 .30813 L .70079 .3061 L F
.777 .717 .796 r
.38038 .65698 m .3847 .65709 L .38343 .65391 L F
.976 .71 .46 r
.37114 .65702 m .37106 .66075 L .36971 .65896 L F
.561 .404 .625 r
.37347 .65645 m .37106 .66075 L .37114 .65702 L F
.75 .538 .608 r
.36971 .65896 m .37347 .65645 L .37114 .65702 L F
0 0 0 r
.61127 .34782 m .61529 .34745 L .61283 .34878 L F
.259 0 .172 r
.35858 .55091 m .35794 .55247 L .35553 .55323 L F
.342 .791 .642 r
.44427 .59802 m .44845 .59586 L .44599 .59705 L F
0 0 0 r
.44973 .59486 m .44845 .59586 L .44976 .59466 L F
.448 .859 .694 r
.44599 .59705 m .44845 .59586 L .44973 .59486 L F
.394 .375 .719 r
.21629 .59253 m .21819 .59231 L .21739 .58814 L F
.718 .581 .7 r
.48939 .48987 m .48893 .49275 L .48722 .49266 L F
.796 .558 0 r
.63453 .39194 m .63512 .39457 L .63513 .39503 L F
.269 0 .231 r
.57556 .42526 m .57268 .42803 L .57436 .42731 L F
.5 .869 .645 r
.57436 .42731 m .57811 .42452 L .57556 .42526 L F
.428 .303 .607 r
.2944 .62813 m .29676 .63028 L .29664 .62749 L F
.526 .466 .732 r
.47372 .53086 m .47492 .53385 L .47206 .53453 L F
.525 .4 .652 r
.47492 .53385 m .47232 .53825 L .47206 .53453 L F
.578 .021 0 r
.3651 .50954 m .36754 .51171 L .36953 .51273 L F
.864 .418 .048 r
.36754 .51171 m .36942 .51362 L .36953 .51273 L F
.43 .852 .953 r
.35794 .55247 m .35386 .55294 L .35553 .55323 L F
0 0 0 r
.31188 .64731 m .31562 .64432 L .31482 .647 L F
0 0 .048 r
.31482 .647 m .31562 .64432 L .31633 .64365 L F
.482 .805 1 r
.36623 .59504 m .36787 .59611 L .36875 .59465 L F
0 0 0 r
.66816 .31439 m .66815 .31472 L .67032 .31319 L F
.713 .956 .68 r
.42269 .4716 m .42169 .47345 L .42398 .47097 L F
.732 .256 .114 r
.4201 .47484 m .42169 .47345 L .42269 .4716 L F
.4201 .47484 m .42394 .47587 L .42169 .47345 L F
.656 .515 .68 r
.42169 .47345 m .42504 .47365 L .42398 .47097 L F
.7 .162 0 r
.42169 .47345 m .42569 .47662 L .42504 .47365 L F
.257 0 0 r
.42249 .47687 m .42342 .4763 L .42394 .47587 L F
.7 .162 0 r
.42434 .47555 m .42394 .47587 L .42569 .47662 L F
.607 .885 .991 r
.42569 .47662 m .42723 .47258 L .42504 .47365 L F
.42569 .47662 m .42394 .47587 L .42622 .47457 L F
.257 0 0 r
.42342 .4763 m .42622 .47457 L .42394 .47587 L F
.7 .162 0 r
.42169 .47345 m .42394 .47587 L .42434 .47555 L F
.503 .053 .114 r
.33407 .53483 m .3362 .5362 L .33653 .53438 L F
.543 .465 .717 r
.33653 .53438 m .33987 .53369 L .33934 .53051 L F
.435 .052 .211 r
.3362 .5362 m .33987 .53369 L .33653 .53438 L F
.014 .279 .778 r
.34806 .63601 m .34984 .6384 L .34793 .63459 L F
.539 .621 .882 r
.34793 .63459 m .34984 .6384 L .35312 .63745 L F
.535 .591 .857 r
.34984 .6384 m .35246 .6387 L .35312 .63745 L F
.969 .926 .688 r
.29504 .64472 m .29287 .64596 L .29601 .6486 L F
.712 .543 .659 r
.29601 .6486 m .30012 .64297 L .29504 .64472 L F
0 .06 .565 r
.26296 .6264 m .26425 .62777 L .26381 .62713 L F
0 .396 .779 r
.26381 .62713 m .26425 .62777 L .26608 .6284 L F
.256 .749 .668 r
.30323 .6253 m .29921 .6268 L .30134 .62566 L F
.29921 .6268 m .29863 .62702 L .30034 .62616 L F
.29921 .6268 m .30034 .62616 L .30134 .62566 L F
.267 .062 .405 r
.30073 .62594 m .30054 .6293 L .303 .62831 L F
.30029 .62549 m .30034 .62616 L .30073 .62594 L F
.30034 .62616 m .30054 .6293 L .30073 .62594 L F
.145 .127 .578 r
.29863 .62702 m .30054 .6293 L .30034 .62616 L F
.29863 .62702 m .30034 .62616 L .30029 .62549 L F
0 0 0 r
.3041 .62536 m .30323 .6253 L .30129 .62567 L F
.267 .062 .405 r
.30183 .62561 m .303 .62831 L .3041 .62536 L F
.30073 .62594 m .303 .62831 L .30176 .62544 L F
0 0 0 r
.3041 .62536 m .30129 .62567 L .30069 .62578 L F
.267 .062 .405 r
.30176 .62544 m .30183 .62561 L .3041 .62536 L F
.30029 .62549 m .30073 .62594 L .30176 .62544 L F
.256 .749 .668 r
.30134 .62566 m .29863 .62702 L .29916 .6267 L F
.30129 .62567 m .29916 .6267 L .30069 .62578 L F
.30134 .62566 m .29916 .6267 L .30129 .62567 L F
0 0 0 r
.3041 .62536 m .30623 .62504 L .30323 .6253 L F
.238 0 0 r
.43773 .59865 m .44175 .59851 L .44047 .59886 L F
.187 .669 .929 r
.43773 .59865 m .44047 .59886 L .44027 .59877 L F
.187 0 0 r
.43924 .5984 m .44175 .59851 L .43773 .59865 L F
.187 .669 .929 r
.43773 .59865 m .44027 .59877 L .4381 .59777 L F
.203 0 0 r
.43519 .59857 m .43564 .59855 L .43773 .59865 L F
.43564 .59855 m .43924 .5984 L .43773 .59865 L F
.549 .24 .396 r
.60129 .35701 m .60091 .35719 L .59949 .35841 L F
.60091 .35719 m .59817 .3585 L .59949 .35841 L F
0 0 .148 r
.59949 .35841 m .59781 .36044 L .59806 .35964 L F
.59949 .35841 m .59806 .35964 L .59865 .35774 L F
.831 .826 .843 r
.48218 .44183 m .47775 .44325 L .48059 .44035 L F
.766 .852 .915 r
.48059 .44035 m .48417 .44062 L .48218 .44183 L F
.972 .664 .297 r
.39793 .55912 m .3979 .55689 L .39648 .55595 L F
.701 .982 .89 r
.3832 .65057 m .37843 .65272 L .38146 .65242 L F
.498 .318 .567 r
.3832 .65057 m .38567 .65005 L .38343 .65391 L F
.808 .379 .225 r
.33261 .59223 m .32818 .59047 L .33036 .5923 L F
.207 0 .038 r
.40446 .48618 m .4056 .48754 L .40725 .4855 L F
.40446 .48618 m .40316 .48869 L .4056 .48754 L F
.64 .887 .985 r
.4436 .45681 m .44767 .45667 L .44521 .45821 L F
.125 0 0 r
.38488 .69491 m .38776 .69244 L .38718 .69365 L F
.68 .596 .755 r
.39223 .6894 m .38959 .69041 L .38776 .69244 L F
0 0 0 r
.38776 .69244 m .38794 .69292 L .38718 .69365 L F
.38776 .69244 m .38959 .69041 L .38794 .69292 L F
.353 .511 .875 r
.63162 .40938 m .63299 .41213 L .63466 .4104 L F
0 0 0 r
.63466 .4104 m .63299 .41213 L .63221 .41379 L F
.56658 .46566 m .5709 .46478 L .56904 .46439 L F
.5 .892 .951 r
.56904 .46439 m .5709 .46478 L .57342 .46379 L F
.303 .631 .963 r
.2482 .52684 m .25054 .52642 L .24824 .52617 L F
.2482 .52684 m .25355 .52755 L .25054 .52642 L F
.792 .575 .607 r
.30653 .63756 m .31003 .64079 L .30698 .63919 L F
.838 .779 .795 r
.31003 .64079 m .30614 .64068 L .30698 .63919 L F
.311 0 0 r
.6353 .38168 m .63972 .38302 L .63633 .38187 L F
.046 0 0 r
.6179 .34644 m .62057 .34589 L .62192 .345 L F
.328 0 .057 r
.62057 .34589 m .62433 .34321 L .62192 .345 L F
.107 .584 .911 r
.39439 .67499 m .39568 .67598 L .39803 .67629 L F
.239 0 0 r
.30698 .56687 m .30362 .56893 L .30446 .56722 L F
.9 .675 .589 r
.33917 .61833 m .33528 .61911 L .33519 .61724 L F
.33917 .61833 m .33883 .62176 L .33528 .61911 L F
.613 .934 .713 r
.36869 .67907 m .36685 .68064 L .36526 .68155 L F
.716 .98 .772 r
.7001 .28074 m .70159 .28033 L .69873 .2828 L F
.921 .529 .217 r
.702 .28224 m .70159 .28033 L .7001 .28074 L F
.562 .36 .564 r
.42794 .53144 m .42794 .53468 L .42435 .53391 L F
.555 .393 .617 r
.42794 .53468 m .42514 .53727 L .42435 .53391 L F
.014 .279 .778 r
.34806 .63601 m .34793 .63459 L .34601 .6344 L F
.75 .574 .658 r
.30122 .64976 m .30567 .65005 L .3027 .6511 L F
.026 .075 .576 r
.30613 .6525 m .3027 .6511 L .30567 .65005 L F
.314 .102 .423 r
.30613 .6525 m .30567 .65005 L .30805 .64981 L F
.903 .64 .529 r
.44357 .53085 m .4463 .53448 L .44793 .53326 L F
.44357 .53085 m .44336 .53358 L .4463 .53448 L F
.948 .727 .569 r
.44306 .5356 m .4463 .53448 L .44336 .53358 L F
.44306 .5356 m .44527 .53757 L .4463 .53448 L F
.809 .548 .544 r
.4463 .53448 m .44527 .53757 L .44892 .53767 L F
.29 .434 .833 r
.33788 .63123 m .33935 .63455 L .34068 .63272 L F
.435 .638 .942 r
.33935 .63455 m .34291 .63566 L .34068 .63272 L F
.373 .822 .698 r
.66061 .37733 m .6625 .3766 L .65851 .37852 L F
0 0 0 r
.66474 .37577 m .6625 .3766 L .66061 .37733 L F
.213 0 .248 r
.66527 .37376 m .6625 .3766 L .66474 .37577 L F
.71 .531 .645 r
.38659 .49549 m .38898 .49582 L .38896 .49274 L F
.508 .855 .993 r
.39163 .49209 m .39028 .49154 L .38896 .49274 L F
.04 .051 .542 r
.38896 .49274 m .38993 .48827 L .38752 .48894 L F
.38896 .49274 m .39028 .49154 L .38993 .48827 L F
.632 .468 .642 r
.38896 .49274 m .39271 .49487 L .39163 .49209 L F
.38896 .49274 m .38898 .49582 L .39271 .49487 L F
.341 .114 .418 r
.25788 .57264 m .25834 .57009 L .2604 .56933 L F
.25788 .57264 m .25834 .57009 L .2604 .56933 L F
.719 .848 .943 r
.5332 .41811 m .52875 .4209 L .52894 .4201 L F
.957 .837 .683 r
.34261 .65091 m .34323 .65281 L .34167 .65393 L F
.313 0 0 r
.34167 .65393 m .34323 .65281 L .34181 .6546 L F
.389 0 .148 r
.34323 .65281 m .34436 .6552 L .34181 .6546 L F
.34323 .65281 m .34594 .65256 L .34436 .6552 L F
.558 .915 .959 r
.63245 .39829 m .6305 .39997 L .62924 .40078 L F
.63245 .39829 m .63317 .39888 L .6305 .39997 L F
.853 .834 .827 r
.36567 .70569 m .36634 .70191 L .36494 .70518 L F
.709 .459 .544 r
.48722 .49266 m .48893 .49275 L .48862 .49546 L F
.31 .446 .836 r
.33712 .52957 m .33752 .52672 L .33499 .52747 L F
.33712 .52957 m .33934 .53051 L .33752 .52672 L F
.426 .063 .244 r
.31951 .52816 m .3209 .52982 L .32131 .52722 L F
.31951 .52816 m .3209 .52982 L .32131 .52722 L F
.502 .443 .723 r
.3688 .5376 m .37126 .53776 L .37034 .5346 L F
.279 .673 .971 r
.36945 .53625 m .3688 .5376 L .36688 .53634 L F
.36945 .53625 m .37126 .53776 L .3688 .5376 L F
.602 .947 .796 r
.53293 .41438 m .53608 .41239 L .53578 .41437 L F
.91 .982 .733 r
.53603 .40986 m .53608 .41239 L .53819 .40869 L F
.806 .708 .172 r
.53578 .41437 m .53608 .41239 L .53603 .40986 L F
.659 .268 .294 r
.53109 .47035 m .53486 .47231 L .53113 .47276 L F
.25 .763 .809 r
.27567 .51626 m .27777 .51574 L .27988 .51562 L F
.233 .751 .777 r
.27777 .51574 m .28237 .5149 L .27988 .51562 L F
.875 .857 .82 r
.6172 .38871 m .61589 .39332 L .61297 .3902 L F
.056 0 0 r
.46067 .59006 m .4628 .58937 L .45973 .59101 L F
.927 .549 .258 r
.39514 .51785 m .39327 .51704 L .39266 .51482 L F
.669 .255 0 r
.39514 .51785 m .39578 .5193 L .39327 .51704 L F
.39514 .51785 m .39671 .5207 L .39578 .5193 L F
.689 .254 .211 r
.42622 .47457 m .42497 .47639 L .4252 .47641 L F
.607 .885 .991 r
.42569 .47662 m .42622 .47457 L .42699 .47319 L F
.689 .254 .211 r
.42622 .47457 m .4252 .47641 L .42906 .47671 L F
.607 .885 .991 r
.42699 .47319 m .42622 .47457 L .42723 .47258 L F
.79 .701 .767 r
.44379 .57913 m .4482 .57968 L .44585 .57633 L F
.693 .231 .151 r
.44379 .57913 m .4466 .58131 L .4482 .57968 L F
.304 .29 .678 r
.4482 .57968 m .44915 .57532 L .44585 .57633 L F
.4482 .57968 m .44958 .57789 L .44915 .57532 L F
.418 .098 .315 r
.4466 .58131 m .44958 .57789 L .4482 .57968 L F
.129 .659 .87 r
.43223 .59838 m .43519 .59857 L .43115 .59807 L F
.746 .32 .239 r
.29863 .62702 m .29948 .6254 L .29695 .62461 L F
.738 .696 .81 r
.40603 .47934 m .40994 .48023 L .40892 .47848 L F
.67 .669 .84 r
.40892 .47848 m .40994 .48023 L .41285 .47926 L F
.608 .503 .709 r
.40994 .48023 m .41283 .48258 L .41285 .47926 L F
.40994 .48023 m .41032 .48319 L .41283 .48258 L F
.949 .763 .303 r
.41252 .59542 m .41192 .59147 L .4122 .59221 L F
.41252 .59542 m .41167 .5946 L .41192 .59147 L F
.807 .341 0 r
.41252 .59542 m .41237 .59683 L .41167 .5946 L F
.844 .825 .829 r
.51599 .41763 m .51528 .42226 L .51369 .42114 L F
.922 .861 .763 r
.51528 .42226 m .51416 .42437 L .51369 .42114 L F
.356 .214 .547 r
.30342 .6361 m .30335 .64041 L .3051 .63904 L F
.30342 .6361 m .30335 .64041 L .3051 .63904 L F
.854 .703 .694 r
.69775 .30864 m .69398 .31102 L .69381 .30874 L F
.771 .941 .936 r
.6792 .37942 m .68416 .37746 L .68274 .37649 L F
.8 .986 .89 r
.68416 .37746 m .68467 .37566 L .68274 .37649 L F
.68416 .37746 m .68546 .37637 L .68467 .37566 L F
.73 .639 .757 r
.27365 .54704 m .2697 .54761 L .27232 .54438 L F
.52 .106 .197 r
.27365 .54704 m .2691 .54926 L .2697 .54761 L F
.27365 .54704 m .27181 .54941 L .2691 .54926 L F
.177 0 0 r
.27411 .54864 m .27181 .54941 L .27365 .54704 L F
.206 .035 .415 r
.27241 .54756 m .27382 .54845 L .27385 .54832 L F
.177 0 0 r
.27425 .54858 m .27365 .54704 L .27613 .54764 L F
.27419 .54861 m .27416 .54851 L .27425 .54858 L F
.27416 .54851 m .27365 .54704 L .27425 .54858 L F
.27407 .54851 m .27365 .54704 L .27419 .54861 L F
.343 .153 .472 r
.27467 .54381 m .27385 .54832 L .27667 .54472 L F
.27385 .54832 m .27382 .54845 L .2739 .54835 L F
.27385 .54832 m .2739 .54835 L .27667 .54472 L F
.206 .035 .415 r
.27259 .54726 m .27385 .54832 L .27467 .54381 L F
.27241 .54756 m .27385 .54832 L .27259 .54726 L F
.177 0 0 r
.27411 .54864 m .27407 .54851 L .27419 .54861 L F
.679 .741 .898 r
.24387 .5272 m .2429 .53076 L .24234 .52972 L F
0 0 .258 r
.24303 .5318 m .24234 .52972 L .2429 .53076 L F
0 0 0 r
.24565 .52883 m .24303 .5318 L .2429 .53076 L F
.899 .974 .676 r
.3803 .62163 m .37825 .62527 L .3783 .62318 L F
.899 .973 .672 r
.3783 .62318 m .37825 .62527 L .37614 .62687 L F
0 0 .097 r
.22782 .57793 m .22622 .5822 L .22673 .57976 L F
.549 .927 .813 r
.66595 .38455 m .66755 .38421 L .66989 .38277 L F
.815 .979 .691 r
.36483 .54893 m .36425 .55036 L .36467 .55068 L F
.57 .356 .551 r
.39422 .68596 m .39412 .68872 L .39223 .6894 L F
.426 .788 .996 r
.39354 .68491 m .39422 .68596 L .39271 .68228 L F
.39354 .68491 m .39679 .68553 L .39422 .68596 L F
0 0 0 r
.23141 .57592 m .22782 .57793 L .22975 .57683 L F
.163 0 .294 r
.24439 .58083 m .24284 .57921 L .24507 .5782 L F
.24439 .58083 m .24272 .58175 L .24284 .57921 L F
.197 .34 .783 r
.70022 .30813 m .70338 .31095 L .70186 .31239 L F
.524 .885 .979 r
.70186 .31239 m .70338 .31095 L .70456 .31148 L F
.70186 .31239 m .70338 .31095 L .70456 .31148 L F
.662 .829 .964 r
.70561 .31178 m .70186 .31239 L .70456 .31148 L F
.044 0 0 r
.62699 .34268 m .62964 .34219 L .63102 .34137 L F
.699 .979 .904 r
.63317 .33977 m .63102 .34137 L .63244 .33922 L F
.683 .94 .656 r
.63102 .34137 m .62964 .34219 L .63244 .33922 L F
.836 .892 .88 r
.27389 .61976 m .27562 .62085 L .27861 .61787 L F
.571 .272 .421 r
.31416 .55712 m .31759 .55702 L .31842 .5538 L F
.71 .408 .463 r
.31842 .5538 m .32122 .55636 L .32125 .55325 L F
.31842 .5538 m .31759 .55702 L .32122 .55636 L F
.201 0 0 r
.25976 .62578 m .26055 .62617 L .25804 .62587 L F
.25976 .62578 m .26296 .6264 L .26055 .62617 L F
0 0 0 r
.67019 .36916 m .66734 .37252 L .66916 .37093 L F
.67277 .36646 m .67019 .36916 L .67272 .36888 L F
.106 0 0 r
.67272 .36888 m .67019 .36916 L .66916 .37093 L F
.709 .459 .544 r
.48722 .49266 m .48862 .49546 L .48685 .49586 L F
.709 .188 0 r
.6994 .31557 m .69848 .31648 L .69568 .31412 L F
.978 .763 .346 r
.69938 .31608 m .69931 .31821 L .69848 .31648 L F
.6994 .31557 m .69931 .31821 L .69848 .31648 L F
0 0 .522 r
.69931 .31821 m .70101 .31844 L .69848 .31648 L F
.699 .562 .697 r
.70101 .31844 m .69781 .31677 L .69848 .31648 L F
.69781 .31677 m .6972 .31645 L .69848 .31648 L F
.978 .763 .346 r
.6994 .31557 m .69938 .31608 L .69848 .31648 L F
.553 .268 .437 r
.40725 .4855 m .40982 .48561 L .41032 .48319 L F
.075 0 0 r
.67565 .36551 m .67627 .36406 L .67263 .36643 L F
0 0 0 r
.67865 .36275 m .67627 .36406 L .67565 .36551 L F
.818 .998 .779 r
.38608 .69006 m .38532 .69014 L .38665 .68837 L F
.38608 .69006 m .38377 .69138 L .38532 .69014 L F
.789 .513 .518 r
.72478 .32753 m .72782 .32548 L .72647 .32419 L F
.72478 .32753 m .72846 .32819 L .72782 .32548 L F
0 .427 .852 r
.72985 .32566 m .7317 .32738 L .73089 .32698 L F
.72985 .32566 m .73089 .32698 L .72782 .32548 L F
.72985 .32566 m .72782 .32548 L .72846 .32819 L F
.936 .677 .521 r
.72985 .32566 m .72782 .32664 L .72893 .32448 L F
.72985 .32566 m .72893 .32448 L .72896 .32442 L F
.501 0 0 r
.35395 .5003 m .3534 .49923 L .35171 .4984 L F
.35395 .5003 m .35596 .50076 L .3534 .49923 L F
.401 0 0 r
.3534 .49923 m .35596 .50076 L .3579 .50174 L F
.722 .818 .925 r
.4912 .43818 m .48726 .43787 L .48946 .43642 L F
.779 .783 .856 r
.4942 .43583 m .4912 .43818 L .48946 .43642 L F
.858 .667 .643 r
.34414 .67856 m .34723 .67507 L .34559 .67616 L F
.34414 .67856 m .3461 .67981 L .34723 .67507 L F
.17 0 .13 r
.32224 .5885 m .32386 .58786 L .32456 .58578 L F
.65 .447 .596 r
.32386 .58786 m .32708 .58559 L .32456 .58578 L F
.586 .143 .164 r
.29493 .57281 m .29049 .57431 L .29245 .57341 L F
.977 .692 .305 r
.6043 .40504 m .60562 .40894 L .60446 .40763 L F
.967 .666 .264 r
.60446 .40763 m .60562 .40894 L .60586 .41131 L F
.504 .037 .077 r
.3747 .52676 m .37092 .52702 L .37202 .52529 L F
.044 0 0 r
.24789 .62109 m .24847 .62125 L .2477 .62115 L F
0 0 0 r
.24796 .62107 m .24789 .62109 L .24556 .62158 L F
.318 .799 .901 r
.24556 .62158 m .24789 .62109 L .24596 .62092 L F
.044 0 0 r
.24789 .62109 m .2477 .62115 L .24596 .62092 L F
0 0 0 r
.24956 .62073 m .24789 .62109 L .24796 .62107 L F
.424 0 0 r
.25198 .62117 m .24789 .62109 L .24956 .62073 L F
.862 .977 .856 r
.63122 .42159 m .63508 .41911 L .63392 .41786 L F
.89 .928 .839 r
.63508 .41911 m .63652 .41475 L .63392 .41786 L F
.63508 .41911 m .63777 .41585 L .63652 .41475 L F
.285 .575 .938 r
.34269 .69696 m .34677 .69936 L .34573 .69744 L F
.459 .621 .921 r
.34573 .69744 m .34677 .69936 L .34792 .69733 L F
.511 .688 .947 r
.34677 .69936 m .34939 .69923 L .34792 .69733 L F
.273 .452 .855 r
.42398 .47097 m .42723 .47258 L .42528 .46862 L F
.463 .411 .715 r
.42504 .47365 m .42723 .47258 L .42398 .47097 L F
.75 .826 .911 r
.4388 .45839 m .43506 .4597 L .43718 .45634 L F
.645 .941 .961 r
.43964 .45688 m .4388 .45839 L .43718 .45634 L F
.43964 .45688 m .44103 .45724 L .4388 .45839 L F
.974 .691 .291 r
.74256 .29914 m .74276 .3019 L .74147 .29793 L F
.535 .818 .998 r
.74147 .29793 m .74564 .29834 L .74256 .29914 L F
.488 .294 .542 r
.74256 .29914 m .74564 .29834 L .74276 .3019 L F
.398 .453 .801 r
.60309 .37206 m .60083 .37434 L .59967 .36996 L F
.443 .525 .847 r
.604 .37431 m .60083 .37434 L .60309 .37206 L F
.148 .67 .882 r
.60605 .37429 m .604 .37431 L .60257 .37388 L F
.609 .853 .99 r
.60799 .37422 m .604 .37431 L .60627 .37432 L F
.148 .67 .882 r
.60627 .37432 m .604 .37431 L .60605 .37429 L F
.443 .525 .847 r
.604 .37431 m .60083 .37434 L .60083 .37434 L F
.438 0 .033 r
.24462 .5742 m .24677 .57497 L .24923 .57306 L F
.75 .362 .319 r
.24923 .57306 m .24677 .57497 L .25118 .57502 L F
.651 .397 .522 r
.24923 .57306 m .25118 .57502 L .25149 .57322 L F
.745 .731 .839 r
.36252 .69853 m .36665 .69874 L .36347 .70039 L F
.911 .982 .744 r
.38256 .6181 m .3803 .62163 L .38027 .61938 L F
0 0 .258 r
.3837 .61164 m .38448 .61474 L .38434 .61376 L F
.878 .969 .649 r
.38434 .61376 m .38256 .6181 L .38181 .6177 L F
.38434 .61376 m .38448 .61474 L .38256 .6181 L F
.849 .995 .758 r
.38181 .6177 m .38256 .6181 L .38027 .61938 L F
.891 .798 .313 r
.41301 .57628 m .41224 .57798 L .41242 .57532 L F
.41301 .57628 m .41248 .57889 L .41224 .57798 L F
.65 .46 .613 r
.44356 .52807 m .44085 .53114 L .44357 .53085 L F
.652 .491 .653 r
.44357 .53085 m .44627 .52752 L .44356 .52807 L F
.957 .852 .696 r
.63777 .41585 m .63777 .41076 L .63652 .41475 L F
.85 .928 .544 r
.38403 .62457 m .38544 .62065 L .38411 .623 L F
.855 .986 .71 r
.38195 .62592 m .38403 .62457 L .38411 .623 L F
.68 .566 .719 r
.4289 .50538 m .42626 .50892 L .42579 .50619 L F
.381 .128 .4 r
.54099 .40519 m .54089 .40789 L .53819 .40869 L F
.079 .623 .842 r
.58248 .46024 m .58622 .46079 L .58496 .46038 L F
.345 .717 .985 r
.58622 .46079 m .58826 .45957 L .58496 .46038 L F
.58622 .46079 m .58964 .46078 L .58826 .45957 L F
.725 .831 .38 r
.70185 .3519 m .7029 .35002 L .70293 .3499 L F
0 0 .296 r
.34378 .54746 m .34493 .54865 L .34625 .54731 L F
.34378 .54746 m .3434 .55016 L .34493 .54865 L F
0 0 .156 r
.23158 .55215 m .23102 .55097 L .23245 .54983 L F
.23158 .55215 m .23033 .55341 L .23102 .55097 L F
0 0 .123 r
.33946 .57842 m .33814 .57973 L .33995 .57601 L F
.601 .372 .542 r
.3421 .57564 m .33946 .57842 L .33995 .57601 L F
.982 .797 .39 r
.41291 .58611 m .41182 .58775 L .41184 .58491 L F
.41291 .58611 m .41259 .58879 L .41182 .58775 L F
.611 .574 .788 r
.34601 .6344 m .34276 .63023 L .34372 .63126 L F
.173 0 0 r
.34793 .63459 m .34601 .6344 L .34415 .63479 L F
.106 .104 .571 r
.359 .68864 m .35777 .68842 L .35727 .68594 L F
.359 .68864 m .35727 .68594 L .35548 .68778 L F
.447 .437 .755 r
.3465 .5746 m .34715 .57676 L .34895 .57567 L F
0 0 0 r
.34715 .57676 m .34606 .5787 L .34895 .57567 L F
.346 .452 .826 r
.23438 .60021 m .23541 .59774 L .23142 .59977 L F
.23438 .60021 m .23701 .60145 L .23541 .59774 L F
.678 .946 .96 r
.59925 .35235 m .59669 .35386 L .598 .35176 L F
.95 .597 .239 r
.39507 .55185 m .39607 .55039 L .3945 .54901 L F
.39507 .55185 m .39649 .55294 L .39607 .55039 L F
.735 .747 .862 r
.73381 .32658 m .73623 .33162 L .73204 .33111 L F
.416 .57 .899 r
.73846 .32988 m .73623 .33162 L .73381 .32658 L F
.807 .318 0 r
.35596 .50076 m .35971 .50433 L .3579 .50174 L F
.08 .018 .479 r
.21482 .57271 m .21583 .56936 L .21447 .56999 L F
.73 .881 .95 r
.74581 .31212 m .74437 .31078 L .74424 .30821 L F
.982 .691 .354 r
.74424 .30821 m .74437 .31078 L .74581 .31212 L F
.974 .756 .331 r
.74485 .3133 m .74581 .31212 L .74437 .31078 L F
.74485 .3133 m .74568 .31479 L .74581 .31212 L F
.865 .829 .81 r
.52018 .41594 m .51599 .41763 L .51854 .41444 L F
.52018 .41594 m .51788 .41902 L .51599 .41763 L F
0 0 0 r
.29387 .6516 m .28962 .65405 L .28887 .65538 L F
.36 .392 .759 r
.21312 .5798 m .21593 .58174 L .21457 .57765 L F
.94 .812 .358 r
.34332 .62156 m .34259 .62387 L .33883 .62176 L F
.34332 .62156 m .34281 .62471 L .34259 .62387 L F
.683 .972 .784 r
.34424 .61998 m .34332 .62156 L .34615 .61917 L F
0 0 .251 r
.34435 .62279 m .34332 .62156 L .34424 .61998 L F
.34435 .62279 m .34281 .62471 L .34332 .62156 L F
.533 .343 .569 r
.44031 .54625 m .43689 .54952 L .43776 .54994 L F
.922 .968 .672 r
.38027 .61938 m .3803 .62163 L .3783 .62318 L F
.632 .652 .851 r
.35246 .6387 m .35467 .64083 L .35538 .63931 L F
0 0 0 r
.35538 .63931 m .35467 .64083 L .35367 .64327 L F
.77 .28 .06 r
.31188 .64731 m .31457 .65024 L .31054 .64837 L F
.595 .361 .532 r
.31188 .64731 m .31482 .647 L .31457 .65024 L F
.764 .996 .829 r
.56706 .38733 m .56446 .38971 L .56559 .38744 L F
.062 0 0 r
.56446 .38971 m .56595 .39038 L .56559 .38744 L F
0 0 0 r
.27177 .61722 m .27297 .61725 L .27427 .61673 L F
.27177 .61722 m .27041 .61781 L .27297 .61725 L F
.586 .364 .546 r
.51947 .47336 m .51921 .47583 L .51559 .47644 L F
.613 .342 .482 r
.51947 .47336 m .52188 .47557 L .51921 .47583 L F
.51947 .47336 m .52194 .47315 L .52188 .47557 L F
.482 .848 .99 r
.70456 .31148 m .70729 .31079 L .70561 .31178 L F
.345 .453 .828 r
.70729 .31079 m .70902 .31404 L .70561 .31178 L F
.687 .802 .936 r
.28666 .51536 m .28237 .5149 L .28464 .51373 L F
.907 .585 .101 r
.28622 .65708 m .28677 .65989 L .28483 .65482 L F
.658 .417 .544 r
.64612 .38241 m .64617 .37976 L .64323 .38112 L F
.64612 .38241 m .64617 .37976 L .64323 .38112 L F
.401 .847 .92 r
.60478 .34952 m .60849 .34907 L .60596 .3499 L F
0 .091 .646 r
.31621 .53739 m .3182 .54053 L .31664 .53686 L F
.618 .898 .987 r
.43204 .46043 m .43299 .45845 L .43506 .4597 L F
.027 0 .282 r
.43204 .46043 m .43431 .45946 L .43299 .45845 L F
.43204 .46043 m .43171 .46262 L .43431 .45946 L F
.619 .951 .929 r
.26043 .5535 m .257 .55497 L .25847 .55477 L F
.902 .921 .822 r
.70139 .29598 m .70335 .29313 L .70292 .29294 L F
.70335 .29313 m .70378 .2925 L .70292 .29294 L F
.72 .193 0 r
.70105 .29212 m .70292 .29294 L .6994 .29071 L F
.902 .921 .822 r
.70139 .29598 m .70247 .29383 L .70318 .29393 L F
.70247 .29383 m .70292 .29294 L .70318 .29393 L F
.764 .489 .519 r
.70318 .29393 m .7037 .29657 L .70194 .29709 L F
0 0 .478 r
.70411 .29406 m .70318 .29393 L .70231 .29421 L F
.70499 .29399 m .7037 .29657 L .70318 .29393 L F
.70499 .29399 m .70318 .29393 L .70411 .29406 L F
.72 .193 0 r
.70318 .29393 m .70292 .29294 L .70105 .29212 L F
.764 .489 .519 r
.70318 .29393 m .70194 .29709 L .70139 .29598 L F
0 0 0 r
.36043 .70076 m .36102 .70091 L .35881 .70185 L F
.252 0 .194 r
.35955 .60047 m .35738 .60124 L .35916 .59798 L F
.68 .566 .719 r
.4289 .50538 m .42579 .50619 L .42716 .50448 L F
.617 .778 .958 r
.42311 .50377 m .42579 .50619 L .42716 .50448 L F
.246 0 0 r
.24824 .52617 m .24615 .52357 L .24498 .52608 L F
.797 .741 .801 r
.53819 .41167 m .5396 .41515 L .53578 .41437 L F
.786 .755 .824 r
.53578 .41437 m .5396 .41515 L .5362 .41629 L F
.68 .699 .861 r
.54084 .41062 m .5396 .41515 L .53819 .41167 L F
.54084 .41062 m .54269 .41416 L .5396 .41515 L F
.733 .617 .728 r
.24357 .60136 m .24759 .60467 L .24701 .60248 L F
.919 .86 .766 r
.56187 .39806 m .56343 .39937 L .56156 .40224 L F
.941 .927 .764 r
.56343 .39937 m .56234 .40135 L .56156 .40224 L F
.693 .681 .833 r
.71275 .33158 m .71655 .33253 L .71588 .33086 L F
.65 .61 .796 r
.71655 .33253 m .71937 .33167 L .71588 .33086 L F
.88 .774 .74 r
.7091 .33345 m .71273 .33359 L .71275 .33158 L F
.876 .792 .764 r
.70996 .33711 m .71273 .33359 L .7091 .33345 L F
.56 0 0 r
.71128 .31582 m .71262 .31612 L .70902 .31404 L F
.457 .605 .91 r
.71404 .31309 m .71262 .31612 L .71128 .31582 L F
.71404 .31309 m .71564 .31525 L .71262 .31612 L F
.777 .304 0 r
.35971 .50433 m .36319 .50892 L .36103 .50567 L F
.705 .168 0 r
.38207 .67874 m .38179 .67736 L .38035 .67612 L F
.602 .579 .8 r
.36287 .69999 m .36494 .70518 L .36634 .70191 L F
0 0 0 r
.24335 .59921 m .24485 .5945 L .24642 .59824 L F
.24335 .59921 m .24397 .5977 L .24485 .5945 L F
.399 .154 .423 r
.24335 .59921 m .24642 .59824 L .24397 .5977 L F
.24335 .59921 m .24357 .60136 L .24642 .59824 L F
.715 .857 .949 r
.6952 .28282 m .69455 .28452 L .69427 .28387 L F
.69736 .28037 m .69815 .28234 L .69492 .28391 L F
.69736 .28037 m .69492 .28391 L .69455 .28452 L F
.69736 .28037 m .69539 .28329 L .6952 .28282 L F
.69539 .28329 m .69455 .28452 L .6952 .28282 L F
.711 .957 .948 r
.69873 .2828 m .69556 .28373 L .69815 .28234 L F
.69556 .28373 m .69492 .28391 L .69552 .28362 L F
.69556 .28373 m .69552 .28362 L .69815 .28234 L F
.718 .985 .889 r
.7001 .28074 m .69873 .2828 L .69815 .28234 L F
.631 .408 .56 r
.49581 .49267 m .49592 .49535 L .4932 .49551 L F
.522 .286 .499 r
.49832 .4926 m .49592 .49535 L .49581 .49267 L F
.661 .958 .94 r
.68695 .37432 m .68546 .37637 L .68786 .37486 L F
.648 .942 .961 r
.68467 .37566 m .68546 .37637 L .68695 .37432 L F
0 .454 .743 r
.36942 .51362 m .37358 .51483 L .37353 .51483 L F
.933 .652 .484 r
.33277 .65635 m .33483 .65777 L .33292 .65941 L F
.33277 .65635 m .33483 .65777 L .33292 .65941 L F
.34 .344 .718 r
.39965 .48682 m .39664 .48594 L .39964 .48507 L F
.39965 .48682 m .39843 .49057 L .39664 .48594 L F
.849 .822 .822 r
.51416 .42437 m .51103 .42448 L .51369 .42114 L F
.653 .97 .836 r
.35055 .65135 m .35293 .65071 L .35485 .6491 L F
.689 .531 .668 r
.57019 .43127 m .57317 .43117 L .57268 .42803 L F
.52 .413 .673 r
.57268 .42803 m .57605 .43019 L .57436 .42731 L F
.57268 .42803 m .57317 .43117 L .57605 .43019 L F
.534 .407 .654 r
.43506 .53504 m .43691 .53114 L .43369 .53064 L F
.43506 .53504 m .43764 .53439 L .43691 .53114 L F
.304 0 .261 r
.43506 .53504 m .43679 .5363 L .43764 .53439 L F
.43506 .53504 m .43448 .53721 L .43679 .5363 L F
.245 .041 .393 r
.35608 .53616 m .35403 .53729 L .35435 .53482 L F
.844 .945 .887 r
.43506 .4597 m .43574 .45597 L .43718 .45634 L F
.43506 .4597 m .43299 .45845 L .43574 .45597 L F
.858 .828 .817 r
.42696 .46697 m .42307 .46845 L .42557 .46674 L F
.737 .985 .776 r
.42978 .4643 m .42696 .46697 L .42795 .46514 L F
.558 .256 .412 r
.42557 .46674 m .42795 .46514 L .42696 .46697 L F
.766 .859 .919 r
.47261 .44712 m .46888 .44724 L .47106 .44573 L F
.755 .862 .927 r
.47541 .4451 m .47261 .44712 L .47106 .44573 L F
.478 .329 .6 r
.47859 .50553 m .47871 .50806 L .47621 .50876 L F
.461 .283 .552 r
.47871 .50806 m .47871 .51076 L .47621 .50876 L F
.383 .291 .627 r
.47621 .50876 m .47871 .51076 L .47666 .51144 L F
.832 .487 0 r
.4072 .54406 m .4065 .54314 L .40561 .54022 L F
.965 .644 .269 r
.40789 .54662 m .4065 .54314 L .4072 .54406 L F
.738 .408 .424 r
.32055 .6274 m .32492 .62783 L .32236 .63063 L F
.791 .834 .885 r
.48264 .43888 m .48417 .44062 L .48059 .44035 L F
.762 .827 .903 r
.48726 .43787 m .48417 .44062 L .48264 .43888 L F
.784 .878 .916 r
.2534 .55594 m .25528 .55716 L .257 .55497 L F
.426 .765 .996 r
.25405 .55636 m .25593 .55571 L .25528 .55716 L F
.365 0 0 r
.25377 .55691 m .25593 .55571 L .25797 .55742 L F
.436 .222 .488 r
.25826 .55479 m .25797 .55742 L .25593 .55571 L F
.365 0 0 r
.25377 .55691 m .25743 .55518 L .25593 .55571 L F
.25743 .55518 m .25826 .55479 L .25593 .55571 L F
.426 .765 .996 r
.2534 .55594 m .25593 .55571 L .25405 .55636 L F
0 0 .011 r
.31168 .6311 m .31243 .62718 L .31409 .6309 L F
.405 .347 .679 r
.31437 .6341 m .31168 .6311 L .31409 .6309 L F
.31437 .6341 m .31244 .63472 L .31168 .6311 L F
.986 .707 .368 r
.32479 .49473 m .32372 .49681 L .32141 .49567 L F
.186 0 .016 r
.33407 .53483 m .32918 .53814 L .33335 .53674 L F
0 0 0 r
.33407 .53483 m .33465 .53532 L .3362 .5362 L F
.33407 .53483 m .33335 .53674 L .33465 .53532 L F
.398 .835 .948 r
.28602 .51809 m .28199 .51832 L .28371 .51854 L F
.958 .634 .361 r
.60007 .42426 m .59818 .4212 L .5983 .4233 L F
.913 .525 .258 r
.5983 .4233 m .6016 .42762 L .60007 .42426 L F
.527 .307 .524 r
.70978 .305 m .71251 .30205 L .7097 .30257 L F
.70978 .305 m .71251 .30205 L .7097 .30257 L F
.993 .802 .543 r
.70264 .28897 m .70302 .28652 L .70142 .28689 L F
.962 .939 .699 r
.70142 .28689 m .70302 .28652 L .70304 .28266 L F
.264 .301 .714 r
.34613 .56553 m .3447 .56747 L .34367 .56335 L F
0 .062 .612 r
.34584 .56812 m .3447 .56747 L .34613 .56553 L F
.34584 .56812 m .34702 .57016 L .3447 .56747 L F
.748 .654 .756 r
.3223 .53893 m .32514 .54195 L .3182 .54053 L F
.872 .547 .035 r
.31239 .63583 m .31327 .63713 L .31244 .63472 L F
0 .399 .72 r
.31363 .63707 m .31327 .63713 L .31239 .63583 L F
.31363 .63707 m .31552 .63785 L .31327 .63713 L F
.728 .293 .217 r
.68305 .35345 m .68004 .35068 L .68014 .35374 L F
.787 .694 .762 r
.39843 .49057 m .39624 .49263 L .39876 .49257 L F
.693 .3 .297 r
.39624 .49263 m .39747 .49364 L .39876 .49257 L F
.313 .354 .744 r
.39876 .49257 m .40051 .49135 L .39843 .49057 L F
0 0 0 r
.39747 .49364 m .40051 .49135 L .39876 .49257 L F
.313 .354 .744 r
.39876 .49257 m .40051 .49135 L .39843 .49057 L F
.328 .807 .753 r
.55737 .391 m .55919 .39008 L .56088 .39113 L F
.55737 .391 m .55653 .39112 L .55919 .39008 L F
0 0 0 r
.39185 .65604 m .39376 .65367 L .3894 .6578 L F
.834 .5 .423 r
.39398 .65597 m .39376 .65367 L .39185 .65604 L F
.987 .771 .526 r
.448 .56395 m .44863 .56713 L .44601 .56518 L F
.754 .991 .79 r
.44863 .56713 m .4463 .56781 L .44601 .56518 L F
.778 .663 .736 r
.61701 .40462 m .62131 .40545 L .61971 .40147 L F
.478 0 0 r
.62231 .40711 m .62131 .40545 L .61701 .40462 L F
.72 .636 .763 r
.61971 .40147 m .62131 .40545 L .62395 .40221 L F
.502 .337 .589 r
.31913 .60795 m .3215 .60459 L .32008 .60576 L F
.93 .554 .169 r
.32049 .53472 m .3223 .53893 L .32052 .53466 L F
.32082 .5371 m .3223 .53893 L .32049 .53472 L F
.626 .483 .668 r
.32348 .53713 m .3223 .53893 L .32052 .53466 L F
.61 .726 .928 r
.31664 .53686 m .3223 .53893 L .31991 .53597 L F
.353 .442 .813 r
.31664 .53686 m .31924 .53902 L .3223 .53893 L F
.342 .816 .897 r
.3223 .53893 m .32106 .53618 L .31991 .53597 L F
.3223 .53893 m .32267 .53826 L .32106 .53618 L F
.3223 .53893 m .31924 .53902 L .32267 .53826 L F
.325 .177 .521 r
.32103 .53863 m .32143 .54111 L .32267 .53826 L F
.31924 .53902 m .32136 .54104 L .32103 .53863 L F
.32136 .54104 m .32143 .54111 L .32103 .53863 L F
.93 .554 .169 r
.31991 .53597 m .32082 .5371 L .32049 .53472 L F
.636 .929 .971 r
.56514 .40358 m .56156 .40224 L .56234 .40135 L F
.74 .41 .425 r
.56234 .40135 m .56751 .40466 L .56514 .40358 L F
.587 .397 .591 r
.51016 .4797 m .51022 .48253 L .50748 .4828 L F
.58 .363 .551 r
.51293 .47938 m .51022 .48253 L .51016 .4797 L F
0 .131 .676 r
.23332 .57936 m .23535 .58318 L .23531 .58143 L F
.683 .519 .657 r
.23535 .58318 m .23441 .58586 L .23663 .58522 L F
.23663 .58522 m .23441 .58586 L .23535 .58318 L F
.307 0 .265 r
.34408 .57966 m .34116 .58225 L .34336 .58157 L F
.164 0 .197 r
.34606 .5787 m .34408 .57966 L .34336 .58157 L F
.655 .205 0 r
.36799 .52833 m .36942 .53047 L .36784 .52826 L F
.767 .299 .133 r
.3757 .49799 m .37937 .49923 L .37929 .49897 L F
.604 .457 .655 r
.2697 .54761 m .27241 .54756 L .27232 .54438 L F
0 0 0 r
.2697 .54761 m .27024 .54778 L .27241 .54756 L F
.2697 .54761 m .2675 .54862 L .27024 .54778 L F
.198 0 0 r
.29038 .51856 m .28873 .51853 L .28602 .51809 L F
.446 .878 .9 r
.29124 .51754 m .29038 .51856 L .29285 .51798 L F
.29124 .51754 m .28873 .51853 L .29038 .51856 L F
.075 0 0 r
.67565 .36551 m .67263 .36643 L .67277 .36646 L F
.519 .897 .96 r
.64516 .39034 m .64074 .39079 L .64191 .38794 L F
.663 .835 .966 r
.64767 .38907 m .64516 .39034 L .64191 .38794 L F
.796 .379 .258 r
.34269 .52021 m .34661 .52206 L .34319 .51891 L F
.752 .791 .885 r
.42307 .46845 m .4224 .47111 L .41989 .46978 L F
.17 0 .253 r
.66734 .37252 m .66527 .37376 L .66474 .37577 L F
.415 .077 .282 r
.31575 .54181 m .31742 .54315 L .3182 .54053 L F
.31575 .54181 m .31403 .54491 L .31742 .54315 L F
.743 .758 .248 r
.42892 .52755 m .42794 .53144 L .43071 .52833 L F
.826 .997 .768 r
.43125 .52638 m .43071 .52833 L .4335 .52508 L F
.66 .889 .981 r
.43125 .52638 m .42892 .52755 L .43071 .52833 L F
.836 .769 .787 r
.56271 .41105 m .56603 .41231 L .5651 .40862 L F
.873 .509 .356 r
.56439 .41341 m .56603 .41231 L .56271 .41105 L F
.828 .764 .792 r
.5651 .40862 m .56603 .41231 L .56818 .40895 L F
.545 .535 .794 r
.46085 .54732 m .46193 .55116 L .46415 .54981 L F
.859 .906 .495 r
.46274 .55385 m .46415 .54981 L .46193 .55116 L F
.566 .338 .528 r
.51559 .47644 m .51572 .47899 L .51293 .47938 L F
.568 .33 .515 r
.51921 .47583 m .51572 .47899 L .51559 .47644 L F
.788 .882 .914 r
.3421 .57564 m .3465 .5746 L .34439 .57491 L F
.353 .47 .839 r
.3465 .5746 m .34731 .57452 L .34439 .57491 L F
.3465 .5746 m .34895 .57567 L .34731 .57452 L F
.795 .311 .06 r
.30085 .6294 m .30176 .63032 L .29917 .62974 L F
.813 .412 .291 r
.60686 .36637 m .61022 .36701 L .6093 .36881 L F
.673 .503 .647 r
.61022 .36701 m .61072 .37042 L .6093 .36881 L F
.337 .347 .723 r
.23407 .61084 m .2344 .60758 L .23155 .60814 L F
.23407 .61084 m .23561 .61153 L .2344 .60758 L F
.782 .993 .774 r
.64906 .39795 m .65219 .39555 L .65132 .3967 L F
0 0 0 r
.65219 .39555 m .65574 .39295 L .65468 .39427 L F
.65132 .3967 m .65219 .39555 L .65468 .39427 L F
.488 0 0 r
.36319 .50892 m .36411 .50949 L .3651 .50954 L F
.604 .042 0 r
.36411 .50949 m .36754 .51171 L .3651 .50954 L F
.49 .336 .599 r
.47666 .51144 m .47685 .51426 L .47426 .51499 L F
.451 .301 .586 r
.47685 .51426 m .47432 .51826 L .47426 .51499 L F
.719 .885 .957 r
.5029 .43137 m .49936 .43155 L .50118 .43 L F
.281 0 .282 r
.23475 .5895 m .23498 .59114 L .23266 .59183 L F
.673 .559 .718 r
.23663 .58522 m .23475 .5895 L .23441 .58586 L F
.23663 .58522 m .23839 .58904 L .23475 .5895 L F
0 0 .247 r
.23566 .59038 m .23506 .58946 L .23839 .58904 L F
0 .105 .651 r
.23892 .58741 m .23839 .58904 L .23663 .58522 L F
.746 .991 .806 r
.23892 .58741 m .23566 .59038 L .23839 .58904 L F
0 0 .227 r
.23717 .58914 m .23615 .59112 L .23566 .59038 L F
.23615 .59112 m .23526 .59283 L .23566 .59038 L F
0 0 .247 r
.23566 .59038 m .23475 .5895 L .23506 .58946 L F
.23566 .59038 m .23498 .59114 L .23475 .5895 L F
.79 .989 .889 r
.67019 .32624 m .67396 .32455 L .67358 .32458 L F
0 0 0 r
.67689 .3217 m .67613 .3233 L .67396 .32455 L F
.391 .837 .725 r
.67396 .32455 m .67613 .3233 L .67358 .32458 L F
.691 .602 .751 r
.36181 .53036 m .35681 .53081 L .35651 .52848 L F
.641 .571 .76 r
.36242 .53137 m .35681 .53081 L .36181 .53036 L F
.166 0 0 r
.24615 .52357 m .2476 .52362 L .25093 .52173 L F
.702 .978 .782 r
.25093 .52173 m .25159 .52024 L .25223 .52032 L F
.705 .975 .765 r
.25093 .52173 m .2476 .52362 L .25159 .52024 L F
.449 .761 .995 r
.33872 .69608 m .34269 .69696 L .34102 .69564 L F
.374 .65 .964 r
.34269 .69696 m .34379 .69528 L .34102 .69564 L F
.34269 .69696 m .34573 .69744 L .34379 .69528 L F
.784 .284 0 r
.37443 .51656 m .37635 .51938 L .37738 .51843 L F
.602 .044 0 r
.37635 .51938 m .37971 .5202 L .37738 .51843 L F
.643 .943 .958 r
.64709 .34321 m .64803 .34388 L .65034 .34241 L F
0 0 .036 r
.53033 .41889 m .53293 .41438 L .53182 .41348 L F
.51 .581 .863 r
.53293 .41438 m .53466 .41129 L .53182 .41348 L F
.53293 .41438 m .53578 .41437 L .53466 .41129 L F
.388 .044 .255 r
.35612 .6689 m .35962 .66653 L .35795 .66558 L F
.978 .682 .369 r
.36513 .69589 m .36665 .69874 L .36252 .69853 L F
.483 .705 .967 r
.22823 .58446 m .22794 .58701 L .22647 .58441 L F
.22823 .58446 m .23058 .58676 L .22794 .58701 L F
.678 .694 .858 r
.3327 .52892 m .3321 .53058 L .32852 .5274 L F
.33307 .52905 m .32852 .5274 L .33113 .52418 L F
.624 .55 .75 r
.33499 .52747 m .33307 .52905 L .33113 .52418 L F
.947 .94 .609 r
.33303 .52713 m .33154 .52951 L .33203 .53048 L F
.624 .55 .75 r
.33499 .52747 m .33113 .52418 L .33424 .52413 L F
.947 .94 .609 r
.33351 .52556 m .33322 .52613 L .33303 .52713 L F
.33322 .52613 m .33154 .52951 L .33303 .52713 L F
.678 .694 .858 r
.33307 .52905 m .33251 .52994 L .3327 .52892 L F
.33251 .52994 m .3321 .53058 L .3327 .52892 L F
.75 .649 .749 r
.70378 .2925 m .70685 .28962 L .70264 .28897 L F
.474 .231 .465 r
.34276 .63023 m .34487 .62803 L .34372 .63126 L F
.981 .892 .545 r
.34372 .63126 m .34487 .62803 L .34347 .62953 L F
.87 .887 .844 r
.34326 .62683 m .34487 .62803 L .34276 .63023 L F
.982 .716 .447 r
.34347 .62953 m .34487 .62803 L .34326 .62683 L F
.786 .721 .791 r
.3461 .5144 m .34695 .51752 L .34939 .51495 L F
.514 .718 .965 r
.34695 .51752 m .34989 .51769 L .34939 .51495 L F
.194 0 0 r
.2485 .61609 m .25284 .61662 L .25038 .61609 L F
.168 0 0 r
.25038 .61609 m .25284 .61662 L .25473 .61692 L F
.842 .636 .624 r
.72335 .32345 m .72647 .32419 L .72767 .32125 L F
.72523 .32249 m .72767 .32125 L .72566 .32228 L F
.546 .922 .785 r
.72566 .32228 m .72962 .31989 L .72768 .32047 L F
.791 .697 .761 r
.72768 .32047 m .72654 .32185 L .72566 .32228 L F
.72654 .32185 m .72526 .32339 L .72566 .32228 L F
.842 .636 .624 r
.72335 .32345 m .72523 .32249 L .72566 .32228 L F
.626 .959 .899 r
.67513 .38086 m .67671 .38096 L .6792 .37942 L F
.124 0 .152 r
.47254 .58314 m .47171 .5851 L .46973 .58622 L F
.041 0 .109 r
.47436 .58195 m .47171 .5851 L .47254 .58314 L F
0 0 .396 r
.36464 .62812 m .36439 .63308 L .36484 .63118 L F
.71 .306 .28 r
.36617 .63032 m .36464 .62812 L .36484 .63118 L F
.543 .373 .602 r
.48276 .49945 m .48308 .50346 L .47845 .5033 L F
.529 .352 .586 r
.48308 .50346 m .47859 .50553 L .47845 .5033 L F
.013 0 0 r
.33676 .58488 m .34116 .58225 L .3373 .58225 L F
.33676 .58488 m .33936 .58414 L .34116 .58225 L F
.357 0 0 r
.34116 .58225 m .34194 .58383 L .34336 .58157 L F
.34116 .58225 m .33936 .58414 L .34194 .58383 L F
.118 .315 .786 r
.32367 .548 m .32574 .54919 L .32417 .54593 L F
.803 .367 .211 r
.606 .38433 m .60729 .38264 L .60685 .37966 L F
.606 .38433 m .60915 .38549 L .60729 .38264 L F
.515 .493 .77 r
.35485 .55358 m .35216 .55768 L .35129 .55354 L F
0 0 0 r
.29387 .6516 m .28887 .65538 L .29171 .65551 L F
.32 .389 .777 r
.29387 .6516 m .2954 .65294 L .29442 .64972 L F
.797 .58 .608 r
.29171 .65551 m .2954 .65294 L .29387 .6516 L F
.886 .654 .134 r
.41294 .56981 m .41238 .5707 L .41197 .56836 L F
.899 .696 .186 r
.41238 .5707 m .4122 .56923 L .41197 .56836 L F
.78 .42 0 r
.41294 .56981 m .41197 .56836 L .41149 .56655 L F
.899 .696 .186 r
.4122 .56923 m .41196 .5672 L .41197 .56836 L F
.78 .42 0 r
.41149 .56655 m .41197 .56836 L .41122 .56594 L F
.886 .654 .134 r
.41294 .56981 m .41311 .57272 L .41238 .5707 L F
.826 .529 .486 r
.39767 .6596 m .39775 .65685 L .39398 .65597 L F
.463 .172 .385 r
.51022 .48253 m .50723 .48538 L .50748 .4828 L F
0 0 .122 r
.41032 .55677 m .41057 .55813 L .40956 .55576 L F
.41032 .55677 m .41071 .55932 L .41057 .55813 L F
.886 .714 .663 r
.70292 .29294 m .70378 .2925 L .70264 .28897 L F
.526 .296 .509 r
.35325 .67221 m .35312 .66862 L .35034 .67262 L F
.971 .694 .282 r
.35312 .66862 m .35325 .67221 L .35034 .67262 L F
.326 0 .226 r
.35325 .67221 m .35612 .6689 L .35562 .6699 L F
.473 .33 .605 r
.35312 .66862 m .35562 .6699 L .3554 .66586 L F
.519 .291 .508 r
.35325 .67221 m .35562 .6699 L .35312 .66862 L F
.834 .838 .85 r
.34596 .52561 m .34165 .52724 L .34442 .5243 L F
.56 .496 .741 r
.55661 .41463 m .55813 .41102 L .55737 .41141 L F
0 0 0 r
.45718 .59197 m .45637 .59244 L .45387 .59315 L F
.45973 .59101 m .45869 .59185 L .45718 .59197 L F
.005 0 0 r
.45718 .59197 m .45828 .59282 L .45637 .59244 L F
.45718 .59197 m .45869 .59185 L .45828 .59282 L F
0 0 .411 r
.22742 .55901 m .22782 .56171 L .22703 .56291 L F
.803 .344 0 r
.22703 .56291 m .22837 .56562 L .22946 .5665 L F
0 0 .507 r
.22782 .56171 m .22837 .56562 L .22703 .56291 L F
.938 .866 .742 r
.24703 .60754 m .24367 .60826 L .24667 .60936 L F
.24759 .60467 m .24475 .60727 L .24703 .60754 L F
.24475 .60727 m .24367 .60826 L .24703 .60754 L F
.24759 .60467 m .24667 .60936 L .24685 .60843 L F
0 .27 .777 r
.24699 .60849 m .24667 .60936 L .24367 .60826 L F
.871 .68 .642 r
.2432 .60671 m .24367 .60826 L .24759 .60467 L F
.718 .193 0 r
.2432 .60671 m .24699 .60849 L .24367 .60826 L F
.24428 .60722 m .24534 .60894 L .24699 .60849 L F
.2432 .60671 m .24361 .60714 L .24428 .60722 L F
.24361 .60714 m .24534 .60894 L .24428 .60722 L F
0 .27 .777 r
.24699 .60849 m .24871 .61078 L .24667 .60936 L F
.355 .827 .794 r
.25134 .61044 m .24996 .61085 L .24871 .61078 L F
.296 .294 .688 r
.24871 .61078 m .24728 .61232 L .24694 .61068 L F
.812 .867 .888 r
.24449 .61244 m .24602 .61375 L .24871 .61078 L F
.355 .827 .794 r
.24996 .61085 m .24713 .61169 L .24871 .61078 L F
.296 .294 .688 r
.24871 .61078 m .24694 .61068 L .24667 .60936 L F
.597 .32 .466 r
.34045 .59551 m .33543 .59633 L .33649 .59518 L F
.33543 .59633 m .33987 .59788 L .34045 .59551 L F
.554 .58 .835 r
.38217 .58551 m .3782 .58278 L .38074 .58228 L F
.999 .811 .47 r
.42814 .56199 m .42773 .56558 L .429 .56638 L F
.964 .636 .273 r
.42721 .56641 m .429 .56638 L .42773 .56558 L F
.42721 .56641 m .42911 .56923 L .429 .56638 L F
.531 .408 .657 r
.62979 .38337 m .63031 .38592 L .63306 .38281 L F
.925 .738 .251 r
.32682 .64395 m .32667 .64684 L .3263 .64251 L F
.62 .359 .501 r
.31923 .55989 m .31565 .56255 L .31609 .56039 L F
.584 .094 0 r
.40315 .53455 m .40603 .53772 L .40475 .53643 L F
.957 .715 .264 r
.40561 .54022 m .40475 .53643 L .40603 .53772 L F
0 0 .317 r
.43022 .54476 m .43198 .54282 L .43223 .54015 L F
.974 .821 .631 r
.43258 .54666 m .43198 .54282 L .43022 .54476 L F
.934 .769 .654 r
.42134 .58791 m .42322 .58918 L .4218 .58537 L F
.948 .876 .731 r
.42134 .58791 m .42122 .59219 L .42322 .58918 L F
.793 .719 .782 r
.4218 .58537 m .42322 .58918 L .42581 .58591 L F
.567 .233 .362 r
.39847 .47835 m .40236 .47624 L .39789 .47605 L F
.39847 .47835 m .40269 .47814 L .40236 .47624 L F
.818 .413 .283 r
.40269 .47814 m .40361 .47878 L .40236 .47624 L F
.82 .414 .277 r
.40236 .47624 m .40361 .47878 L .40603 .47934 L F
.891 .966 .832 r
.3932 .48533 m .39038 .48652 L .39416 .48635 L F
.949 .946 .737 r
.39416 .48635 m .3932 .48533 L .39451 .48268 L F
.891 .966 .832 r
.39416 .48635 m .39038 .48652 L .3932 .48533 L F
0 0 0 r
.67844 .32189 m .67689 .3217 L .67938 .32041 L F
.67844 .32189 m .67613 .3233 L .67689 .3217 L F
.28 0 .175 r
.46973 .58622 m .46869 .58807 L .46648 .58872 L F
.124 0 .111 r
.47171 .5851 m .46869 .58807 L .46973 .58622 L F
.495 .098 .216 r
.43676 .52345 m .43125 .52638 L .4335 .52508 L F
.473 .807 .999 r
.34939 .51495 m .34788 .51359 L .3461 .5144 L F
.281 .69 .971 r
.34939 .51495 m .35116 .51464 L .34788 .51359 L F
.449 .417 .731 r
.34989 .51769 m .35116 .51464 L .34939 .51495 L F
.901 .73 .661 r
.35005 .61705 m .35238 .6181 L .35108 .61433 L F
.636 .929 .971 r
.56514 .40358 m .56049 .4051 L .56156 .40224 L F
.613 .934 .713 r
.36869 .67907 m .36526 .68155 L .36728 .67824 L F
.686 .94 .651 r
.26702 .57485 m .26658 .57478 L .26852 .57325 L F
.576 .102 .093 r
.26658 .57478 m .2714 .57515 L .26852 .57325 L F
.859 .906 .495 r
.46274 .55385 m .46281 .55203 L .46314 .55271 L F
0 0 .475 r
.46201 .55639 m .46281 .55203 L .46274 .55385 L F
.46201 .55639 m .46332 .55462 L .46281 .55203 L F
.769 .504 0 r
.46281 .55203 m .46332 .55462 L .46251 .55144 L F
.46281 .55203 m .46251 .55144 L .46171 .5483 L F
.859 .906 .495 r
.46314 .55271 m .46281 .55203 L .46415 .54981 L F
.961 .627 .272 r
.58227 .38309 m .58114 .38424 L .58057 .38209 L F
.58227 .38309 m .58263 .38551 L .58114 .38424 L F
.6 .862 .52 r
.67423 .30893 m .67578 .30689 L .67686 .30584 L F
.585 .841 .483 r
.67423 .30893 m .67315 .31013 L .67578 .30689 L F
0 .079 .634 r
.56818 .40895 m .56875 .41025 L .56994 .40962 L F
.864 .71 .69 r
.57108 .41301 m .56994 .40962 L .56875 .41025 L F
.626 .871 .988 r
.70945 .28633 m .71224 .28519 L .711 .28405 L F
.70945 .28633 m .71224 .28519 L .711 .28405 L F
.745 .735 .843 r
.36526 .68155 m .36379 .68611 L .366 .68623 L F
.875 .887 .839 r
.3721 .70848 m .37299 .70421 L .37142 .70471 L F
.3721 .70848 m .37479 .70516 L .37299 .70421 L F
.617 .907 .984 r
.39223 .6894 m .39079 .69167 L .38959 .69041 L F
.352 0 .092 r
.38794 .69292 m .38959 .69041 L .39079 .69167 L F
.301 .79 .749 r
.27756 .51926 m .27653 .51984 L .27867 .51938 L F
.27756 .51926 m .27523 .5201 L .27653 .51984 L F
.648 .716 .897 r
.36091 .6342 m .35996 .63513 L .35768 .63151 L F
.719 .988 .866 r
.35737 .63592 m .35996 .63513 L .36091 .6342 L F
.59 .072 0 r
.35737 .63592 m .35996 .63513 L .36162 .63649 L F
.593 .803 .98 r
.61966 .36679 m .62431 .36697 L .6215 .36545 L F
.853 .405 .133 r
.62513 .36513 m .6215 .36545 L .62431 .36697 L F
.525 0 0 r
.62431 .36697 m .62641 .36727 L .62548 .36811 L F
0 .01 .535 r
.62513 .36513 m .62431 .36697 L .62548 .36811 L F
.246 0 .002 r
.53571 .40177 m .53833 .40116 L .53941 .39908 L F
.433 .409 .732 r
.54192 .39832 m .54224 .39914 L .53941 .39908 L F
.401 .079 .3 r
.54224 .39914 m .5397 .40059 L .53941 .39908 L F
.34 0 .043 r
.54224 .39914 m .53833 .40116 L .53941 .39908 L F
.433 .409 .732 r
.53941 .39908 m .54224 .39914 L .54192 .39832 L F
.54192 .39832 m .54224 .39914 L .53941 .39908 L F
.34 0 .043 r
.53941 .39908 m .53833 .40116 L .54224 .39914 L F
.746 .32 .239 r
.29863 .62702 m .29695 .62461 L .29664 .62749 L F
.467 .191 .411 r
.25118 .57502 m .25402 .57291 L .25149 .57322 L F
.909 .544 .093 r
.40101 .52786 m .39975 .5268 L .39912 .52395 L F
.915 .641 .507 r
.40238 .53016 m .39975 .5268 L .40101 .52786 L F
.779 .783 .856 r
.4942 .43583 m .48946 .43642 L .49245 .43386 L F
.726 .823 .925 r
.49632 .43419 m .4942 .43583 L .49245 .43386 L F
.779 .688 .763 r
.40043 .6802 m .39963 .67603 L .39922 .6749 L F
.377 0 .021 r
.33203 .53048 m .32877 .53199 L .33037 .53183 L F
0 0 0 r
.42978 .4643 m .43101 .46427 L .43171 .46262 L F
.42978 .4643 m .42795 .46514 L .43101 .46427 L F
.67988 .30308 m .67867 .30413 L .68204 .30158 L F
0 .123 .672 r
.23332 .57936 m .23531 .58143 L .23357 .57778 L F
.961 .935 .711 r
.42805 .59281 m .42789 .59359 L .42909 .59146 L F
.42805 .59281 m .4264 .59626 L .42556 .59376 L F
.42805 .59281 m .42556 .59376 L .42789 .59359 L F
.743 .758 .248 r
.42892 .52755 m .42786 .53134 L .42794 .53144 L F
.616 .402 .569 r
.43042 .53356 m .42794 .53468 L .42794 .53144 L F
0 .208 .72 r
.42921 .53178 m .42794 .53144 L .42786 .53134 L F
.42921 .53178 m .43042 .53356 L .42794 .53144 L F
.4 .53 .872 r
.31842 .63986 m .31654 .64041 L .31552 .63785 L F
.263 .072 .423 r
.31633 .64365 m .31654 .64041 L .31842 .63986 L F
.84 .73 .743 r
.5651 .40862 m .56818 .40895 L .56751 .40466 L F
.515 .911 .914 r
.57194 .40638 m .57044 .4073 L .57245 .40622 L F
.372 .398 .758 r
.56751 .40466 m .56814 .40871 L .57044 .4073 L F
0 0 .063 r
.56669 .40804 m .5651 .40862 L .56751 .40466 L F
.56668 .40809 m .56657 .40812 L .56669 .40804 L F
.56657 .40812 m .5651 .40862 L .56669 .40804 L F
.74 .356 .325 r
.56751 .40466 m .57044 .4073 L .56668 .40809 L F
.515 .911 .914 r
.56689 .40789 m .57044 .4073 L .57194 .40638 L F
.56649 .40801 m .5668 .40796 L .56689 .40789 L F
.5668 .40796 m .57044 .4073 L .56689 .40789 L F
.372 .398 .758 r
.56814 .40871 m .56818 .40895 L .57044 .4073 L F
0 .079 .634 r
.56818 .40895 m .56994 .40962 L .57044 .4073 L F
.899 .987 .764 r
.38769 .61718 m .3907 .61432 L .39018 .61387 L F
.537 .754 .976 r
.42556 .59376 m .42482 .59628 L .42284 .59515 L F
.42556 .59376 m .4264 .59626 L .42482 .59628 L F
.586 .048 0 r
.42282 .59716 m .42482 .59628 L .42706 .59776 L F
.909 .539 .316 r
.42284 .59515 m .42482 .59628 L .42282 .59716 L F
.996 .766 .452 r
.38805 .5983 m .38908 .60204 L .38779 .60102 L F
.931 .92 .78 r
.38779 .60102 m .38908 .60204 L .38619 .60325 L F
.87 .887 .844 r
.34326 .62683 m .34276 .63023 L .3402 .63044 L F
.982 .694 .357 r
.59539 .41577 m .59445 .41312 L .59397 .41403 L F
.937 .584 .169 r
.59579 .41796 m .59539 .41577 L .59397 .41403 L F
0 0 .215 r
.2235 .55052 m .22493 .54906 L .22524 .54647 L F
0 0 .251 r
.22248 .55291 m .22493 .54906 L .2235 .55052 L F
.631 .386 .529 r
.55707 .43708 m .56096 .43442 L .55708 .43453 L F
.707 .451 .534 r
.57019 .43127 m .57303 .43396 L .57317 .43117 L F
.57019 .43127 m .5703 .43402 L .57303 .43396 L F
0 .329 .693 r
.36201 .6994 m .35634 .69687 L .35861 .69554 L F
.474 .541 .845 r
.26889 .63494 m .27046 .63338 L .26887 .63433 L F
.925 .71 .593 r
.37971 .5202 m .38155 .52388 L .38078 .52194 L F
.685 .204 .104 r
.53819 .40869 m .53603 .40986 L .53482 .40842 L F
.91 .982 .733 r
.53603 .40986 m .53819 .40869 L .53482 .40842 L F
.823 .994 .752 r
.53885 .40642 m .53603 .40986 L .53819 .40869 L F
.459 .317 .6 r
.54089 .40789 m .54084 .41062 L .53819 .40869 L F
.54089 .40789 m .54084 .41062 L .53819 .40869 L F
.66 .163 0 r
.26702 .57485 m .26839 .57678 L .26658 .57478 L F
.445 .214 .469 r
.37562 .58589 m .37515 .58851 L .3728 .58913 L F
.625 .177 .169 r
.37562 .58589 m .37766 .58774 L .37515 .58851 L F
.37562 .58589 m .37814 .58645 L .37766 .58774 L F
.887 .833 .787 r
.55978 .40117 m .56049 .4051 L .55781 .40329 L F
.932 .798 .69 r
.55781 .40329 m .56049 .4051 L .55899 .40863 L F
.909 .844 .768 r
.56156 .40224 m .56049 .4051 L .55978 .40117 L F
.788 .812 .33 r
.57856 .41085 m .57829 .41235 L .57773 .41328 L F
.825 .348 .018 r
.57829 .41235 m .5797 .41454 L .57773 .41328 L F
.754 .498 .544 r
.68305 .35345 m .68673 .35331 L .68657 .35073 L F
0 0 .388 r
.68657 .35073 m .68828 .35115 L .68845 .34944 L F
.68657 .35073 m .68673 .35331 L .68828 .35115 L F
.948 .876 .731 r
.42134 .58791 m .4195 .59156 L .42122 .59219 L F
.782 .46 .443 r
.41868 .5943 m .42122 .59219 L .4195 .59156 L F
.41868 .5943 m .42284 .59515 L .42122 .59219 L F
.41868 .5943 m .42284 .59515 L .42122 .59219 L F
.666 .903 .566 r
.55421 .42925 m .55572 .42785 L .55238 .42653 L F
.6 .029 0 r
.55454 .42825 m .55421 .42925 L .55457 .42656 L F
.666 .903 .566 r
.55421 .42925 m .55393 .43006 L .55572 .42785 L F
0 0 .267 r
.5533 .4335 m .55421 .42925 L .55528 .43216 L F
.371 .358 .715 r
.55696 .43115 m .55528 .43216 L .55421 .42925 L F
.6 .029 0 r
.55451 .43068 m .55696 .43115 L .55421 .42925 L F
.55451 .43068 m .55421 .42925 L .55454 .42825 L F
.666 .903 .566 r
.55421 .42925 m .55302 .43119 L .55393 .43006 L F
0 0 .267 r
.5533 .4335 m .55302 .43119 L .55421 .42925 L F
.674 .148 0 r
.36942 .51362 m .3719 .51508 L .37358 .51483 L F
.517 0 0 r
.3719 .51508 m .37443 .51656 L .37358 .51483 L F
.861 .982 .691 r
.3265 .62743 m .32819 .62781 L .3301 .62473 L F
.916 .681 .183 r
.32741 .6292 m .32819 .62781 L .3265 .62743 L F
.32741 .6292 m .32827 .63066 L .32819 .62781 L F
.345 .578 .929 r
.32985 .5006 m .33206 .50054 L .33061 .49713 L F
.32985 .5006 m .33062 .50074 L .33206 .50054 L F
.045 .603 .811 r
.28756 .65999 m .29076 .6604 L .28826 .65995 L F
.489 0 0 r
.28826 .65995 m .29076 .6604 L .29349 .6619 L F
.28826 .65995 m .29349 .6619 L .28924 .66132 L F
.036 .068 .564 r
.28937 .65989 m .28826 .65995 L .28924 .66132 L F
.28973 .65611 m .28826 .65995 L .28937 .65989 L F
.045 .603 .811 r
.28677 .65989 m .28756 .65999 L .28826 .65995 L F
.854 .892 .863 r
.64323 .38112 m .63972 .38302 L .64213 .38174 L F
.673 .225 .18 r
.64213 .38174 m .64612 .38241 L .64323 .38112 L F
.818 .705 .741 r
.38364 .58227 m .38217 .58551 L .38074 .58228 L F
.59 .416 .615 r
.36872 .57271 m .37136 .56942 L .36878 .56987 L F
.097 .018 .468 r
.37033 .57027 m .36878 .56987 L .37136 .56942 L F
.37033 .57027 m .36872 .57271 L .36878 .56987 L F
.466 .273 .534 r
.37515 .58851 m .37269 .59195 L .3728 .58913 L F
.732 .8 .906 r
.61975 .38633 m .6211 .38905 L .6172 .38871 L F
.628 .126 .039 r
.6172 .38871 m .6211 .38905 L .61979 .39046 L F
.632 .75 .933 r
.6237 .38796 m .6211 .38905 L .61975 .38633 L F
0 0 0 r
.61979 .39046 m .6211 .38905 L .6237 .38796 L F
.976 .672 .318 r
.37256 .4995 m .37129 .50033 L .371 .49775 L F
.64 .813 .966 r
.3757 .49799 m .37256 .4995 L .371 .49775 L F
.606 .056 0 r
.37366 .50027 m .37129 .50033 L .37256 .4995 L F
.524 .381 .629 r
.47432 .51826 m .47469 .52104 L .47218 .52171 L F
.48 .374 .656 r
.47469 .52104 m .47275 .52436 L .47218 .52171 L F
.878 .717 .678 r
.39837 .66593 m .39929 .66332 L .39727 .66239 L F
.97 .752 .553 r
.39929 .66332 m .39767 .6596 L .39727 .66239 L F
.961 .912 .719 r
.38469 .59235 m .38313 .59192 L .38509 .58803 L F
.617 .186 .201 r
.38469 .59235 m .38192 .59398 L .38313 .59192 L F
.907 .919 .529 r
.39782 .67331 m .39896 .66879 L .39638 .67206 L F
0 .095 .652 r
.3981 .67233 m .39782 .67331 L .39638 .67206 L F
.3981 .67233 m .39922 .6749 L .39782 .67331 L F
0 0 .148 r
.46256 .55962 m .4625 .55906 L .46201 .55639 L F
0 0 0 r
.46256 .55962 m .46214 .56149 L .4625 .55906 L F
.46256 .55962 m .46122 .56338 L .46214 .56149 L F
.604 .948 .921 r
.64164 .33394 m .64448 .33312 L .64258 .33408 L F
.531 .26 .449 r
.43764 .53439 m .44085 .53114 L .43691 .53114 L F
.43764 .53439 m .44069 .53382 L .44085 .53114 L F
.678 .383 .467 r
.44085 .53114 m .44069 .53382 L .44336 .53358 L F
.632 .392 .537 r
.44085 .53114 m .44336 .53358 L .44357 .53085 L F
0 .499 .812 r
.59318 .46238 m .59719 .46373 L .59589 .46306 L F
.962 .923 .715 r
.59589 .46306 m .59719 .46373 L .59818 .46065 L F
.613 .56 .772 r
.25382 .5372 m .25107 .53851 L .24954 .53378 L F
.226 0 .102 r
.25107 .53851 m .25382 .5372 L .24922 .53671 L F
.25107 .53851 m .25267 .53826 L .25382 .5372 L F
.25382 .5372 m .25267 .53826 L .25107 .53851 L F
.836 .892 .88 r
.27389 .61976 m .27861 .61787 L .27681 .61631 L F
.094 .41 .861 r
.27764 .61484 m .27861 .61787 L .27681 .61631 L F
.27764 .61484 m .27947 .61692 L .27861 .61787 L F
.211 .584 .944 r
.27681 .61631 m .27947 .61692 L .27861 .61787 L F
0 .109 .659 r
.35685 .58207 m .35915 .58576 L .36154 .58219 L F
.35685 .58207 m .35893 .58407 L .35915 .58576 L F
.944 .686 .518 r
.35904 .5849 m .36117 .58583 L .35915 .58576 L F
.3601 .585 m .36117 .58583 L .35904 .5849 L F
.64 .59 .783 r
.36236 .58764 m .36201 .58743 L .36117 .58583 L F
.36201 .58743 m .35915 .58576 L .36117 .58583 L F
.944 .686 .518 r
.35893 .58407 m .3601 .585 L .35904 .5849 L F
.35893 .58407 m .35912 .58683 L .36117 .58583 L F
.347 0 .196 r
.35912 .58683 m .36068 .5849 L .36117 .58583 L F
.36068 .5849 m .36177 .58355 L .36117 .58583 L F
.847 .866 .855 r
.36368 .58521 m .36117 .58583 L .36177 .58355 L F
.347 0 .196 r
.35912 .58683 m .36158 .58625 L .36166 .58514 L F
.36057 .58504 m .36166 .58514 L .36177 .58355 L F
.35912 .58683 m .36166 .58514 L .36057 .58504 L F
.628 .798 .362 r
.33946 .57842 m .3373 .58225 L .33814 .57973 L F
0 0 0 r
.65468 .39427 m .65574 .39295 L .6577 .39119 L F
.474 .541 .845 r
.26889 .63494 m .27205 .63658 L .27046 .63338 L F
.626 .328 .445 r
.52194 .47315 m .52455 .47532 L .52188 .47557 L F
.52194 .47315 m .52476 .4732 L .52455 .47532 L F
.636 .952 .941 r
.63935 .34756 m .641 .34696 L .64071 .3461 L F
.688 .974 .913 r
.64071 .3461 m .641 .34696 L .64455 .34448 L F
.982 .707 .421 r
.43369 .53064 m .43273 .53294 L .43269 .53007 L F
.411 .794 .991 r
.43269 .53007 m .43532 .52967 L .43369 .53064 L F
0 0 0 r
.43532 .52967 m .43273 .53294 L .43369 .53064 L F
.153 .229 .69 r
.33226 .55622 m .33397 .56244 L .33432 .55863 L F
.633 .636 .836 r
.33322 .56255 m .33432 .55863 L .33397 .56244 L F
.019 0 0 r
.62548 .36811 m .62641 .36727 L .62943 .36639 L F
.843 .888 .872 r
.46403 .44817 m .46389 .45118 L .46237 .44996 L F
.46403 .44817 m .46567 .44952 L .46389 .45118 L F
.471 .381 .672 r
.54482 .40869 m .54677 .40406 L .54342 .40476 L F
.54482 .40869 m .54757 .41057 L .54677 .40406 L F
.815 .706 .745 r
.54089 .40789 m .54482 .40869 L .54342 .40476 L F
.565 .888 .622 r
.67686 .30584 m .67883 .30379 L .67867 .30413 L F
0 0 0 r
.67686 .30584 m .67798 .30565 L .67883 .30379 L F
.67686 .30584 m .67578 .30689 L .67798 .30565 L F
.964 .696 .478 r
.28404 .64388 m .2821 .64564 L .28058 .64315 L F
.28404 .64388 m .28398 .64653 L .2821 .64564 L F
.34 .136 .45 r
.28795 .64944 m .28545 .65033 L .28822 .64684 L F
0 .196 .712 r
.28398 .64653 m .28545 .65033 L .28651 .64975 L F
.324 .81 .803 r
.28651 .64975 m .28545 .65033 L .28795 .64944 L F
.778 .845 .902 r
.45491 .45177 m .45535 .45438 L .45346 .45323 L F
.45491 .45177 m .45683 .45335 L .45535 .45438 L F
.414 .113 .344 r
.35403 .53729 m .3535 .53943 L .3515 .53809 L F
.545 .342 .555 r
.44627 .52752 m .4487 .52725 L .45042 .52249 L F
.263 0 .196 r
.45042 .52249 m .45115 .52366 L .45216 .52206 L F
.616 .55 .757 r
.4487 .52725 m .45115 .52366 L .45042 .52249 L F
.857 .814 .807 r
.41005 .4885 m .41118 .49169 L .41497 .48905 L F
.094 0 0 r
.56559 .38744 m .5695 .38603 L .56706 .38733 L F
.716 .6 .726 r
.36076 .6911 m .35917 .69213 L .35777 .68842 L F
.71 .468 .557 r
.35917 .69213 m .36071 .69452 L .35861 .69554 L F
.089 0 0 r
.35101 .56259 m .34843 .56485 L .34613 .56553 L F
.746 .354 .311 r
.35308 .565 m .34843 .56485 L .35101 .56259 L F
.626 .104 0 r
.61688 .43393 m .61274 .42995 L .61457 .43086 L F
.699 .387 .445 r
.38659 .49549 m .3888 .49809 L .38898 .49582 L F
0 .179 .71 r
.38727 .49456 m .3888 .49809 L .38659 .49549 L F
.115 0 0 r
.37411 .67575 m .37171 .67635 L .37264 .67644 L F
.331 0 0 r
.28351 .57594 m .28149 .57634 L .27911 .57609 L F
.049 0 0 r
.2849 .57552 m .28149 .57634 L .28351 .57594 L F
.771 .799 .876 r
.38196 .55746 m .37909 .55981 L .38305 .55936 L F
.198 0 0 r
.37909 .55981 m .3819 .55985 L .38305 .55936 L F
0 .229 .622 r
.38569 .55952 m .38196 .55746 L .38305 .55936 L F
.385 .825 .685 r
.38305 .55936 m .38412 .55865 L .38569 .55952 L F
.38305 .55936 m .3819 .55985 L .38412 .55865 L F
.982 .699 .337 r
.41524 .49769 m .41659 .5014 L .41656 .49878 L F
.344 .15 .467 r
.41656 .49878 m .41659 .5014 L .4187 .49828 L F
.868 .89 .848 r
.37299 .70421 m .37479 .70516 L .37731 .7021 L F
0 0 .041 r
.46122 .56338 m .46157 .56396 L .46214 .56149 L F
.46122 .56338 m .46098 .56601 L .46157 .56396 L F
.402 .118 .364 r
.36693 .56315 m .37014 .56252 L .37146 .56 L F
.523 .589 .862 r
.36845 .56026 m .37014 .56252 L .36693 .56315 L F
.302 .729 .971 r
.3027 .6511 m .29846 .65039 L .30122 .64976 L F
.691 .272 .246 r
.29374 .56249 m .29193 .56325 L .29601 .56351 L F
.043 .135 .636 r
.23478 .594 m .23266 .59183 L .23498 .59114 L F
.716 .6 .726 r
.36076 .6911 m .35777 .68842 L .359 .68864 L F
.399 .67 .969 r
.36254 .68944 m .36076 .6911 L .359 .68864 L F
.36254 .68944 m .36394 .69111 L .36076 .6911 L F
.117 0 .32 r
.38898 .49582 m .39035 .49666 L .39271 .49487 L F
.38898 .49582 m .3888 .49809 L .39035 .49666 L F
.873 .893 .844 r
.56353 .43928 m .56528 .44072 L .56784 .43764 L F
.398 .174 .454 r
.56784 .43764 m .56528 .44072 L .56771 .44006 L F
.5 .794 .998 r
.56771 .44006 m .56528 .44072 L .56353 .43928 L F
.703 .839 .948 r
.53033 .41889 m .5332 .41811 L .52894 .4201 L F
.542 .123 .195 r
.29764 .65215 m .30122 .64976 L .29846 .65039 L F
.361 0 0 r
.63031 .38592 m .63438 .38648 L .63306 .38281 L F
.772 .698 .781 r
.63438 .38648 m .6353 .38168 L .63306 .38281 L F
0 0 .172 r
.47662 .57592 m .47618 .57797 L .47502 .57959 L F
0 0 .031 r
.47618 .57797 m .47436 .58195 L .47502 .57959 L F
.308 .018 .298 r
.3301 .57668 m .33152 .57805 L .33188 .57553 L F
.3301 .57668 m .32935 .57871 L .33152 .57805 L F
.631 .945 .733 r
.29982 .65935 m .30354 .65661 L .30366 .6595 L F
.599 .797 .377 r
.30354 .65661 m .30613 .6525 L .30556 .65517 L F
.693 .542 .677 r
.30556 .65517 m .30366 .6595 L .30354 .65661 L F
.557 .922 .758 r
.34424 .61998 m .34615 .61917 L .34822 .6177 L F
.722 .767 .888 r
.71275 .33158 m .71588 .33086 L .71395 .32793 L F
.63 .762 .942 r
.71588 .33086 m .71789 .32765 L .71395 .32793 L F
.71588 .33086 m .71849 .32963 L .71789 .32765 L F
.607 .652 .869 r
.71588 .33086 m .71937 .33167 L .71849 .32963 L F
.525 .902 .956 r
.37814 .58645 m .38217 .58551 L .38028 .58691 L F
.557 .01 0 r
.38217 .58551 m .38271 .58642 L .38028 .58691 L F
.38217 .58551 m .38509 .58803 L .38271 .58642 L F
.54 .546 .81 r
.36196 .52679 m .36448 .53117 L .36181 .53036 L F
.65 .417 .553 r
.36448 .53117 m .36242 .53137 L .36181 .53036 L F
.206 .035 .415 r
.27241 .54756 m .27467 .54381 L .27232 .54438 L F
.862 .869 .843 r
.34528 .59081 m .34918 .59001 L .34749 .59064 L F
.935 .932 .775 r
.61575 .39477 m .61708 .39602 L .61875 .39296 L F
.996 .766 .418 r
.61655 .39798 m .61708 .39602 L .61575 .39477 L F
0 .13 .678 r
.61934 .39928 m .61708 .39602 L .61655 .39798 L F
0 0 0 r
.23441 .58586 m .23492 .58627 L .23663 .58522 L F
.23441 .58586 m .23236 .5875 L .23492 .58627 L F
.877 .782 .752 r
.23541 .59774 m .23809 .59915 L .2398 .59541 L F
.7 .579 .716 r
.23913 .59166 m .2398 .59541 L .24105 .59221 L F
.769 .944 .607 r
.37961 .66567 m .3771 .66934 L .37746 .66786 L F
.37746 .66786 m .3771 .66934 L .37504 .67136 L F
.237 0 .199 r
.32765 .52158 m .32695 .52364 L .33001 .52091 L F
.88 .774 .74 r
.7091 .33345 m .71275 .33158 L .71145 .32997 L F
.722 .767 .888 r
.71275 .33158 m .71395 .32793 L .71145 .32997 L F
.632 .418 .575 r
.57317 .43117 m .57596 .43321 L .57605 .43019 L F
.57317 .43117 m .57303 .43396 L .57596 .43321 L F
.776 .903 .93 r
.54983 .41791 m .54628 .41868 L .54823 .41839 L F
.318 .799 .901 r
.24556 .62158 m .24596 .62092 L .24347 .62121 L F
.742 .877 .942 r
.46888 .44724 m .46567 .44952 L .46403 .44817 L F
.517 0 0 r
.57941 .39188 m .57738 .38995 L .57619 .38904 L F
.792 .921 .924 r
.30004 .66528 m .29748 .66484 L .295 .66301 L F
.799 .33 .116 r
.3757 .49799 m .37866 .50055 L .37937 .49923 L F
.367 .833 .892 r
.37866 .50055 m .38136 .50006 L .37937 .49923 L F
.102 0 0 r
.62076 .35682 m .62426 .35472 L .62411 .35664 L F
.774 .973 .691 r
.62528 .3525 m .62426 .35472 L .62576 .3525 L F
.54 .918 .776 r
.62705 .35133 m .62576 .3525 L .62861 .35119 L F
.62705 .35133 m .62528 .3525 L .62576 .3525 L F
.507 .122 .245 r
.62755 .35324 m .62528 .3525 L .62705 .35133 L F
.62764 .3536 m .62729 .35343 L .62755 .35324 L F
.62729 .35343 m .62528 .3525 L .62755 .35324 L F
.503 .797 .998 r
.62993 .35305 m .6312 .35109 L .62861 .35119 L F
.011 0 0 r
.6312 .35109 m .62705 .35133 L .62861 .35119 L F
.571 .327 .507 r
.62958 .35228 m .62705 .35133 L .6312 .35109 L F
.62958 .35228 m .62764 .3536 L .62705 .35133 L F
.816 .87 .887 r
.62591 .35183 m .62898 .35221 L .62924 .34963 L F
.62898 .35221 m .62958 .35228 L .62952 .35181 L F
.62898 .35221 m .62952 .35181 L .62924 .34963 L F
0 0 0 r
.62466 .35468 m .62426 .35472 L .62528 .3525 L F
.62411 .35664 m .62528 .3525 L .62469 .35406 L F
.507 .122 .245 r
.62764 .3536 m .62469 .35406 L .62528 .3525 L F
.618 .814 .976 r
.62591 .35183 m .62469 .35406 L .62496 .35402 L F
.62592 .35185 m .62496 .35402 L .62764 .3536 L F
.62591 .35183 m .62496 .35402 L .62592 .35185 L F
0 0 0 r
.62411 .35664 m .62418 .35577 L .62466 .35468 L F
.62418 .35577 m .62426 .35472 L .62466 .35468 L F
.362 0 0 r
.55496 .46935 m .55631 .4709 L .5535 .47133 L F
.55496 .46935 m .55748 .46923 L .55631 .4709 L F
.788 .947 .605 r
.22773 .56944 m .22573 .5715 L .22535 .573 L F
.872 .547 .035 r
.31239 .63583 m .31244 .63472 L .31437 .6341 L F
0 0 .066 r
.69777 .36158 m .69622 .36358 L .69774 .35984 L F
0 0 .118 r
.69575 .36586 m .69622 .36358 L .69777 .36158 L F
.847 .866 .855 r
.36368 .58521 m .36236 .58764 L .36117 .58583 L F
.222 0 0 r
.59781 .36044 m .59423 .36149 L .59342 .36087 L F
.625 .915 .637 r
.59949 .35841 m .59651 .36135 L .59781 .36044 L F
.525 .4 .652 r
.47492 .53385 m .47567 .53967 L .47232 .53825 L F
.516 .409 .671 r
.47232 .53825 m .47519 .53996 L .4727 .54047 L F
.47232 .53825 m .47567 .53967 L .47519 .53996 L F
.678 .605 .767 r
.33329 .63964 m .33412 .64362 L .3314 .64409 L F
.538 .179 .307 r
.3314 .64409 m .33307 .64611 L .3308 .6467 L F
.3314 .64409 m .33412 .64362 L .33307 .64611 L F
0 0 0 r
.42989 .54793 m .42984 .54796 L .42866 .54858 L F
.069 .369 .836 r
.42757 .54916 m .42866 .54858 L .42829 .55025 L F
.972 .706 .47 r
.42699 .55013 m .42876 .55127 L .42866 .54858 L F
0 0 0 r
.42984 .54796 m .42699 .55013 L .42866 .54858 L F
.069 .369 .836 r
.42668 .54782 m .42866 .54858 L .42757 .54916 L F
0 .176 .707 r
.23663 .58522 m .23753 .58364 L .23531 .58143 L F
.77 .681 .764 r
.23492 .58627 m .23753 .58364 L .23663 .58522 L F
0 .105 .651 r
.23892 .58741 m .23663 .58522 L .24035 .58567 L F
.958 .83 .4 r
.35563 .66789 m .35562 .6699 L .35612 .6689 L F
.342 0 0 r
.278 .54838 m .27411 .54864 L .27613 .54764 L F
.32 0 .072 r
.27902 .54702 m .278 .54838 L .27613 .54764 L F
.927 .966 .768 r
.39629 .60246 m .39371 .6035 L .39473 .60425 L F
.887 .858 .407 r
.39627 .60023 m .39629 .60246 L .39728 .59854 L F
.888 .989 .794 r
.39627 .60023 m .39371 .6035 L .39629 .60246 L F
.476 .817 .999 r
.72443 .31421 m .72585 .31517 L .72186 .31474 L F
.17 .387 .832 r
.72731 .31371 m .72585 .31517 L .72443 .31421 L F
.373 .822 .698 r
.66061 .37733 m .65851 .37852 L .65816 .37861 L F
.576 .448 .668 r
.22946 .5665 m .2304 .5695 L .22773 .56944 L F
.073 0 0 r
.23033 .56932 m .22773 .56944 L .2304 .5695 L F
.23033 .56932 m .22573 .5715 L .22773 .56944 L F
.859 .42 .006 r
.34294 .50332 m .3446 .50471 L .34435 .50596 L F
.884 .514 .039 r
.34435 .50596 m .3446 .50471 L .34498 .50735 L F
.154 0 .122 r
.44203 .58295 m .44122 .58475 L .44414 .58194 L F
.935 .932 .775 r
.61575 .39477 m .61875 .39296 L .61792 .39225 L F
0 0 0 r
.61979 .39046 m .6237 .38796 L .61988 .39025 L F
.62134 .38943 m .61979 .39046 L .62174 .38911 L F
.211 .334 .772 r
.61979 .39046 m .61875 .39296 L .61822 .39151 L F
.785 .984 .9 r
.61792 .39225 m .61875 .39296 L .61979 .39046 L F
0 0 0 r
.61859 .39162 m .61979 .39046 L .62134 .38943 L F
.211 .334 .772 r
.61979 .39046 m .61822 .39151 L .6172 .38871 L F
.48 .374 .656 r
.47469 .52104 m .47517 .52378 L .47275 .52436 L F
.466 .362 .652 r
.47517 .52378 m .4734 .5268 L .47275 .52436 L F
.97 .778 .588 r
.60791 .45531 m .61022 .45372 L .60836 .4527 L F
.60791 .45531 m .60985 .45724 L .61022 .45372 L F
.674 .463 .592 r
.36499 .63388 m .3712 .63119 L .36658 .63555 L F
.04 0 .39 r
.36653 .63261 m .36499 .63388 L .36533 .6341 L F
.777 .637 .706 r
.36484 .63118 m .36527 .63375 L .36617 .63032 L F
.36527 .63375 m .36533 .6341 L .36547 .63349 L F
0 0 0 r
.36548 .63347 m .36499 .63388 L .36547 .63348 L F
.777 .637 .706 r
.36527 .63375 m .36547 .63349 L .36617 .63032 L F
0 0 0 r
.36547 .63348 m .36499 .63388 L .36498 .63389 L F
.36653 .63261 m .36548 .63347 L .36547 .63348 L F
.19 .093 .507 r
.36509 .63384 m .36533 .6341 L .36527 .63375 L F
0 0 0 r
.36584 .63348 m .36498 .63389 L .36394 .63588 L F
.056 0 .409 r
.36653 .63261 m .36533 .6341 L .36547 .63349 L F
0 0 0 r
.36653 .63261 m .36498 .63389 L .36499 .63388 L F
.056 0 .409 r
.36653 .63261 m .36547 .63349 L .36617 .63032 L F
0 0 0 r
.36653 .63261 m .36499 .63388 L .36584 .63348 L F
.19 .093 .507 r
.36439 .63308 m .36509 .63384 L .36484 .63118 L F
.36509 .63384 m .36527 .63375 L .36484 .63118 L F
.36439 .63308 m .36499 .63388 L .36533 .6341 L F
.442 0 .004 r
.46511 .59049 m .4628 .58937 L .46648 .58872 L F
.408 0 .122 r
.46869 .58807 m .46511 .59049 L .46648 .58872 L F
.375 .605 .938 r
.34068 .63272 m .34291 .63566 L .34415 .63479 L F
.062 0 0 r
.4056 .48754 m .40982 .48561 L .40725 .4855 L F
.776 .677 .755 r
.40859 .49506 m .41268 .4956 L .41118 .49169 L F
.348 .769 .976 r
.40859 .49506 m .41138 .49481 L .41268 .4956 L F
.849 .955 .88 r
.41268 .4956 m .41138 .49481 L .41432 .49203 L F
0 0 .296 r
.47588 .55945 m .47622 .56186 L .47488 .56314 L F
0 .028 .539 r
.47622 .56186 m .47638 .56517 L .47488 .56314 L F
0 0 0 r
.26375 .52117 m .26169 .52228 L .25926 .52292 L F
.26602 .51933 m .26462 .52064 L .26375 .52117 L F
.583 .187 .257 r
.26462 .52064 m .26169 .52228 L .26375 .52117 L F
.67 .669 .84 r
.40892 .47848 m .41285 .47926 L .41153 .47808 L F
.455 .646 .94 r
.41153 .47808 m .41285 .47926 L .41342 .47719 L F
.227 .397 .824 r
.41285 .47926 m .41558 .48071 L .41342 .47719 L F
.621 .727 .923 r
.41283 .48258 m .41558 .48071 L .41285 .47926 L F
.971 .703 .466 r
.60872 .41507 m .60681 .41669 L .60708 .41389 L F
.60872 .41507 m .60872 .41798 L .60681 .41669 L F
0 0 0 r
.24223 .53402 m .24138 .5362 L .24015 .53716 L F
0 0 .258 r
.24303 .5318 m .24223 .53402 L .24234 .52972 L F
.675 .754 .262 r
.24303 .5318 m .24138 .5362 L .24223 .53402 L F
0 0 .187 r
.32194 .60196 m .32288 .60308 L .32266 .59947 L F
.32194 .60196 m .3215 .60459 L .32288 .60308 L F
.83 .603 .595 r
.60271 .45656 m .59865 .45929 L .59837 .45758 L F
.60271 .45656 m .60198 .45973 L .59865 .45929 L F
.81 .998 .848 r
.28843 .62937 m .28895 .63063 L .28679 .63094 L F
.755 .468 0 r
.28964 .63362 m .28895 .63063 L .28843 .62937 L F
.64 .887 .985 r
.4436 .45681 m .44625 .45565 L .44767 .45667 L F
.717 .895 .96 r
.44834 .45421 m .44767 .45667 L .44625 .45565 L F
.44834 .45421 m .45013 .45515 L .44767 .45667 L F
.182 0 0 r
.32597 .65389 m .32593 .65497 L .32561 .65293 L F
.349 0 0 r
.34702 .57016 m .34965 .57093 L .35177 .56977 L F
.498 .253 .473 r
.34965 .57093 m .35242 .56803 L .35177 .56977 L F
.462 .099 .264 r
.30506 .56269 m .30814 .56231 L .3093 .55945 L F
.078 0 .09 r
.3093 .55945 m .30994 .56137 L .31161 .55917 L F
.3093 .55945 m .30814 .56231 L .30994 .56137 L F
.772 .446 .435 r
.3731 .68527 m .37658 .68547 L .37673 .68832 L F
.823 .861 .412 r
.37658 .68547 m .37686 .68439 L .37716 .68466 L F
0 0 .517 r
.37753 .685 m .37716 .68466 L .37611 .68372 L F
.779 .741 .817 r
.38193 .6847 m .37931 .68763 L .37716 .68466 L F
.38193 .6847 m .37716 .68466 L .37903 .68685 L F
0 0 .517 r
.37817 .68558 m .37903 .68685 L .379 .68682 L F
.37817 .68558 m .379 .68682 L .37716 .68466 L F
.823 .861 .412 r
.37686 .68439 m .37773 .681 L .37716 .68466 L F
.993 .857 .597 r
.37611 .68372 m .37716 .68466 L .37731 .6837 L F
.37611 .68372 m .37731 .6837 L .37773 .681 L F
0 .16 .698 r
.3748 .68375 m .37611 .68372 L .37421 .6836 L F
0 0 .517 r
.37817 .68558 m .37716 .68466 L .37753 .685 L F
0 .16 .698 r
.37772 .68442 m .37817 .68558 L .37611 .68372 L F
.974 .82 .406 r
.37772 .68442 m .37817 .68558 L .37776 .68441 L F
.67 .257 .252 r
.37218 .67772 m .37647 .67792 L .37411 .67575 L F
.744 .475 .522 r
.37659 .68064 m .37647 .67792 L .37218 .67772 L F
.993 .857 .597 r
.37611 .68372 m .37773 .681 L .37659 .68064 L F
.744 .475 .522 r
.37659 .68064 m .37218 .67772 L .37229 .68025 L F
.783 .546 .577 r
.37206 .68293 m .37659 .68064 L .37229 .68025 L F
.37206 .68293 m .37611 .68372 L .37659 .68064 L F
.637 .371 .5 r
.37229 .68025 m .37218 .67772 L .36967 .67776 L F
.741 .688 .8 r
.37378 .67791 m .37293 .68104 L .37155 .67774 L F
.37572 .67806 m .37428 .6796 L .37378 .67791 L F
.37428 .6796 m .37293 .68104 L .37378 .67791 L F
0 .16 .698 r
.37763 .68443 m .37611 .68372 L .3748 .68375 L F
0 0 .564 r
.37756 .68386 m .37817 .68558 L .37793 .68451 L F
0 .16 .698 r
.37793 .68451 m .37817 .68558 L .37772 .68442 L F
.37793 .68451 m .37772 .68442 L .37763 .68443 L F
.37772 .68442 m .37611 .68372 L .37763 .68443 L F
.417 .482 .819 r
.37756 .68386 m .37763 .68443 L .37556 .68393 L F
0 0 .489 r
.3773 .68312 m .37793 .68451 L .37756 .6838 L F
.489 .814 1 r
.37302 .67735 m .37572 .67806 L .37155 .67774 L F
.815 .832 .863 r
.37441 .67779 m .37293 .68104 L .37569 .67809 L F
.37441 .67779 m .37569 .67809 L .37572 .67806 L F
0 0 .489 r
.3773 .68312 m .37756 .6838 L .3772 .68313 L F
.3773 .68312 m .3772 .68313 L .37441 .67779 L F
0 0 0 r
.3773 .68312 m .37757 .68304 L .37752 .6831 L F
.375 0 0 r
.37421 .6836 m .37611 .68372 L .37206 .68293 L F
.417 .482 .819 r
.37439 .67824 m .37756 .68386 L .37556 .68393 L F
.37441 .67779 m .37793 .68451 L .37439 .67824 L F
.734 .729 .846 r
.37716 .68466 m .37673 .68832 L .37658 .68547 L F
.772 .446 .435 r
.3731 .68527 m .37673 .68832 L .37276 .68804 L F
.734 .729 .846 r
.37716 .68466 m .37931 .68763 L .37673 .68832 L F
0 .347 .821 r
.3769 .69141 m .37276 .68804 L .37673 .68832 L F
.765 .694 .784 r
.37817 .68558 m .37822 .68717 L .37605 .68858 L F
.708 .171 0 r
.37822 .68717 m .37817 .68558 L .37605 .68858 L F
0 0 0 r
.3773 .68312 m .37521 .686 L .37688 .68776 L F
.3773 .68312 m .37752 .6831 L .37521 .686 L F
.417 .482 .819 r
.37439 .67824 m .37556 .68393 L .37434 .6798 L F
.929 .629 .455 r
.37659 .68064 m .37773 .681 L .37647 .67792 L F
.417 .482 .819 r
.37441 .67779 m .37421 .6836 L .37293 .68104 L F
.292 0 0 r
.37773 .681 m .38146 .68186 L .38046 .6816 L F
.71 .6 .731 r
.37773 .681 m .37928 .67764 L .37647 .67792 L F
.37773 .681 m .38046 .6816 L .37928 .67764 L F
.744 .266 .11 r
.37634 .67886 m .37441 .67779 L .37572 .67806 L F
0 0 .489 r
.3773 .68312 m .37441 .67779 L .37503 .67814 L F
.3773 .68312 m .37502 .67811 L .38002 .68094 L F
.744 .266 .11 r
.37757 .68046 m .37441 .67779 L .37634 .67886 L F
0 0 .489 r
.37503 .67814 m .37441 .67779 L .37502 .67811 L F
.38002 .68094 m .37502 .67811 L .38017 .68082 L F
.861 .616 .566 r
.37307 .67985 m .37441 .67779 L .37302 .67735 L F
.833 .574 .548 r
.37411 .68261 m .37441 .67779 L .37307 .67985 L F
.417 .482 .819 r
.37434 .6798 m .37556 .68393 L .37421 .6836 L F
.739 .6 .702 r
.37411 .68261 m .37757 .68046 L .37441 .67779 L F
.742 .248 .058 r
.37757 .68046 m .37328 .67753 L .37441 .67779 L F
.37757 .68046 m .37634 .67886 L .37534 .67841 L F
.744 .266 .11 r
.37757 .68046 m .38017 .68082 L .37502 .67811 L F
.37757 .68046 m .37502 .67811 L .37441 .67779 L F
.742 .248 .058 r
.37757 .68046 m .37534 .67841 L .37302 .67735 L F
.37634 .67886 m .37572 .67806 L .37423 .67767 L F
.37328 .67753 m .37302 .67735 L .37441 .67779 L F
.37634 .67886 m .37423 .67767 L .37302 .67735 L F
.974 .82 .406 r
.37743 .68447 m .37763 .68443 L .3773 .68312 L F
.37763 .68443 m .37776 .68441 L .37756 .68386 L F
.37763 .68443 m .37756 .68386 L .3773 .68312 L F
.417 .482 .819 r
.37756 .68386 m .37793 .68451 L .37763 .68443 L F
0 0 .564 r
.3773 .68312 m .37756 .68386 L .37793 .68451 L F
.974 .82 .406 r
.37743 .68447 m .37817 .68558 L .37772 .68442 L F
.37721 .68415 m .37743 .68447 L .3773 .68312 L F
.37688 .68776 m .37817 .68558 L .37721 .68415 L F
.336 .282 .648 r
.33423 .68848 m .33644 .69051 L .33694 .68779 L F
.33423 .68848 m .3346 .69282 L .33644 .69051 L F
.618 .583 .792 r
.34179 .52459 m .34269 .52021 L .34051 .52151 L F
.797 .303 0 r
.30176 .63032 m .30125 .6321 L .29917 .62974 L F
.30176 .63032 m .30322 .63289 L .30125 .6321 L F
.389 .439 .792 r
.30176 .63032 m .30454 .63397 L .30322 .63289 L F
.688 .689 .845 r
.61971 .40147 m .62395 .40221 L .62257 .39863 L F
.831 .843 .855 r
.62395 .40221 m .62523 .39762 L .62257 .39863 L F
.62395 .40221 m .62685 .39934 L .62523 .39762 L F
.26 .731 .942 r
.43115 .59807 m .43519 .59857 L .43362 .59795 L F
.275 .71 .965 r
.43519 .59857 m .43604 .59766 L .43362 .59795 L F
.43519 .59857 m .43773 .59865 L .43604 .59766 L F
.919 .86 .766 r
.56187 .39806 m .56156 .40224 L .55978 .40117 L F
.887 .858 .407 r
.39627 .60023 m .39728 .59854 L .39738 .59789 L F
.855 .694 .682 r
.56398 .43553 m .56784 .43764 L .5672 .43494 L F
.873 .893 .844 r
.56353 .43928 m .56784 .43764 L .56398 .43553 L F
.541 .498 .758 r
.5672 .43494 m .56784 .43764 L .57039 .43701 L F
.45 .215 .465 r
.57039 .43701 m .56784 .43764 L .56771 .44006 L F
.48 0 0 r
.295 .66301 m .29566 .66377 L .29349 .6619 L F
.295 .66301 m .29748 .66484 L .29566 .66377 L F
.086 0 0 r
.68876 .31534 m .68765 .31623 L .68489 .31672 L F
0 0 0 r
.69144 .31508 m .68765 .31623 L .68876 .31534 L F
.575 .471 .699 r
.69146 .31207 m .69144 .31508 L .68876 .31534 L F
.8 .567 .585 r
.32224 .5885 m .32596 .59108 L .32386 .58786 L F
.32224 .5885 m .32278 .59165 L .32596 .59108 L F
.788 .495 .493 r
.32219 .59406 m .32596 .59108 L .32278 .59165 L F
.32303 .5934 m .32378 .5947 L .32596 .59108 L F
.281 .301 .704 r
.32422 .59358 m .32494 .59672 L .32378 .5947 L F
.32494 .59672 m .32501 .59702 L .32378 .5947 L F
.788 .495 .493 r
.32219 .59406 m .32378 .5947 L .32303 .5934 L F
.285 .405 .809 r
.32596 .59108 m .32652 .58878 L .32489 .58944 L F
.32596 .59108 m .32818 .59047 L .32652 .58878 L F
0 0 0 r
.32603 .58993 m .32894 .58781 L .32652 .58878 L F
.32894 .58781 m .32944 .58744 L .32652 .58878 L F
.285 .405 .809 r
.32489 .58944 m .32652 .58878 L .32386 .58786 L F
.911 .78 .703 r
.5808 .37628 m .57769 .37805 L .5806 .37459 L F
.5808 .37628 m .57962 .37918 L .57769 .37805 L F
.054 .62 .737 r
.5806 .37459 m .58319 .3745 L .5808 .37628 L F
0 .173 .708 r
.35974 .61156 m .36156 .61469 L .36236 .61403 L F
0 .307 .8 r
.36156 .61469 m .36405 .61634 L .36236 .61403 L F
.947 .595 .302 r
.35974 .61156 m .36156 .61469 L .35984 .61379 L F
.21 .672 .944 r
.35984 .61379 m .36156 .61469 L .36236 .61403 L F
.167 0 0 r
.30122 .56936 m .29957 .57099 L .29695 .57159 L F
.499 .08 .176 r
.30362 .56893 m .29957 .57099 L .30122 .56936 L F
.835 .997 .84 r
.3968 .49114 m .39624 .49263 L .39843 .49057 L F
.335 .338 .715 r
.39965 .48682 m .40051 .49135 L .39843 .49057 L F
.453 0 0 r
.39843 .49057 m .40051 .49135 L .3968 .49114 L F
.971 .758 .559 r
.60502 .44249 m .6069 .44108 L .60518 .43985 L F
.60502 .44249 m .6066 .44334 L .6069 .44108 L F
.934 .763 .645 r
.60845 .44998 m .60955 .44708 L .60772 .44604 L F
.58 .363 .551 r
.51293 .47938 m .51318 .48233 L .51022 .48253 L F
.432 .185 .437 r
.51572 .47899 m .51318 .48233 L .51293 .47938 L F
.631 .892 .568 r
.61454 .37364 m .6173 .37048 L .61597 .37167 L F
.676 .968 .925 r
.61258 .37343 m .61454 .37364 L .61597 .37167 L F
.476 .232 .464 r
.29086 .63529 m .29156 .63452 L .29159 .63564 L F
.499 .249 .467 r
.29167 .63854 m .29156 .63452 L .294 .63687 L F
.635 .079 0 r
.294 .63687 m .29156 .63452 L .28964 .63362 L F
.29394 .63679 m .29072 .63442 L .29231 .63491 L F
.29384 .63675 m .28964 .63362 L .29394 .63679 L F
.476 .232 .464 r
.28916 .63718 m .29086 .63529 L .29159 .63824 L F
.29136 .63837 m .29159 .63824 L .29167 .63854 L F
.28916 .63718 m .29159 .63824 L .29136 .63837 L F
.29086 .63529 m .29159 .63564 L .29167 .63854 L F
.493 .216 .422 r
.29039 .63896 m .28916 .63718 L .29167 .63854 L F
.535 .304 .512 r
.29167 .63854 m .294 .63687 L .29039 .63896 L F
.058 0 0 r
.29039 .63896 m .29212 .63796 L .29234 .6389 L F
.29212 .63796 m .294 .63687 L .2939 .63699 L F
.29212 .63796 m .2939 .63699 L .29234 .6389 L F
.468 .684 .96 r
.29467 .63475 m .294 .63687 L .29231 .63491 L F
.795 .558 .579 r
.29028 .63691 m .29356 .63529 L .29231 .63491 L F
.29356 .63529 m .29467 .63475 L .29231 .63491 L F
.635 .079 0 r
.29072 .63442 m .28964 .63362 L .29231 .63491 L F
.294 .63687 m .29384 .63675 L .29394 .63679 L F
.721 .799 .913 r
.458 .44946 m .45683 .45335 L .45491 .45177 L F
.458 .44946 m .45959 .45134 L .45683 .45335 L F
0 0 .05 r
.6173 .37048 m .61966 .36679 L .61883 .36865 L F
.789 .83 .884 r
.6215 .36545 m .62496 .36387 L .62187 .36188 L F
.6215 .36545 m .62187 .36188 L .62142 .36486 L F
0 0 .263 r
.62225 .3627 m .62142 .36486 L .62187 .36188 L F
.678 .768 .284 r
.6216 .36436 m .62142 .36486 L .62225 .3627 L F
.628 .961 .833 r
.62142 .36486 m .61966 .36679 L .62111 .36573 L F
0 0 0 r
.61883 .36865 m .62142 .36486 L .62066 .36671 L F
.678 .768 .284 r
.62066 .36671 m .62142 .36486 L .6216 .36436 L F
.628 .961 .833 r
.62142 .36486 m .62111 .36573 L .6215 .36545 L F
0 0 0 r
.61883 .36865 m .61966 .36679 L .62142 .36486 L F
.75 .767 .866 r
.44637 .56148 m .448 .56395 L .44405 .56317 L F
.987 .771 .526 r
.448 .56395 m .44601 .56518 L .44405 .56317 L F
.726 .759 .878 r
.45073 .56293 m .448 .56395 L .44637 .56148 L F
.281 0 .27 r
.4432 .52177 m .44066 .5212 L .44699 .52283 L F
.506 .167 .326 r
.4476 .51751 m .4432 .52177 L .44699 .52283 L F
0 0 0 r
.61127 .34782 m .61378 .34761 L .61529 .34745 L F
.61378 .34761 m .6179 .34644 L .61529 .34745 L F
.714 .985 .81 r
.55182 .4246 m .55488 .42215 L .55289 .42272 L F
.771 .996 .805 r
.55289 .42272 m .55488 .42215 L .55645 .42025 L F
.911 .735 .651 r
.23541 .59774 m .23701 .60145 L .23809 .59915 L F
.842 .786 .798 r
.53578 .41437 m .5362 .41629 L .5332 .41811 L F
.503 .797 .998 r
.62993 .35305 m .63277 .35266 L .6312 .35109 L F
.421 .432 .766 r
.60636 .36858 m .60862 .37395 L .61072 .37042 L F
.922 .932 .796 r
.61072 .37042 m .60862 .37395 L .60813 .37128 L F
.954 .934 .732 r
.60813 .37128 m .60862 .37395 L .60799 .37422 L F
.652 .491 .653 r
.44357 .53085 m .44669 .53096 L .44627 .52752 L F
.428 .329 .641 r
.44627 .52752 m .45028 .5293 L .4487 .52725 L F
.44627 .52752 m .44669 .53096 L .45028 .5293 L F
.709 .952 .953 r
.66141 .33449 m .65988 .33685 L .66278 .33444 L F
.66141 .33449 m .65877 .33616 L .65988 .33685 L F
.379 .333 .68 r
.4317 .58279 m .43364 .58442 L .43497 .58256 L F
.63 .269 .339 r
.43364 .58442 m .43738 .58474 L .43497 .58256 L F
0 .273 .744 r
.2902 .64382 m .28622 .64075 L .28903 .6409 L F
.57 .37 .571 r
.2902 .64382 m .29043 .64653 L .28822 .64684 L F
.155 .363 .817 r
.29126 .64229 m .2902 .64382 L .28903 .6409 L F
.752 .73 .833 r
.54482 .41126 m .54269 .41416 L .54084 .41062 L F
.506 .634 .91 r
.54544 .41393 m .54269 .41416 L .54482 .41126 L F
.868 .89 .848 r
.37299 .70421 m .37731 .7021 L .37562 .70104 L F
.747 .792 .889 r
.37731 .7021 m .37843 .69801 L .37562 .70104 L F
.37731 .7021 m .3794 .70055 L .37843 .69801 L F
.509 .554 .838 r
.39033 .67027 m .39135 .67527 L .39439 .67499 L F
.617 .907 .984 r
.39223 .6894 m .39274 .68797 L .39079 .69167 L F
.39223 .6894 m .39412 .68872 L .39274 .68797 L F
.941 .574 .215 r
.59064 .40617 m .59174 .40506 L .59027 .40349 L F
.59064 .40617 m .59232 .40751 L .59174 .40506 L F
0 0 .216 r
.33047 .6494 m .32938 .65013 L .3308 .6467 L F
.077 0 .421 r
.33083 .65149 m .32938 .65013 L .33047 .6494 L F
.635 .683 .878 r
.40892 .47848 m .41021 .47584 L .40789 .47659 L F
.40892 .47848 m .41153 .47808 L .41021 .47584 L F
.781 .484 .485 r
.2714 .57515 m .27482 .57558 L .27507 .57287 L F
.544 .275 .458 r
.27507 .57287 m .2776 .57492 L .27743 .5723 L F
.27507 .57287 m .27482 .57558 L .2776 .57492 L F
0 0 .159 r
.55289 .42272 m .55238 .42653 L .55182 .4246 L F
.792 .64 .693 r
.63537 .34931 m .63935 .34756 L .63783 .34822 L F
.63537 .34931 m .63859 .35007 L .63935 .34756 L F
.614 .942 .748 r
.63783 .34822 m .63935 .34756 L .64071 .3461 L F
.891 .841 .789 r
.62523 .39762 m .62685 .39934 L .62912 .39565 L F
0 0 0 r
.6294 .39402 m .62957 .39442 L .62912 .39565 L F
.429 .825 .983 r
.62768 .39481 m .62912 .39565 L .62957 .39442 L F
.164 0 0 r
.34625 .54731 m .34894 .54678 L .34998 .547 L F
.552 .556 .811 r
.35103 .54269 m .35245 .54649 L .34998 .547 L F
.35103 .54269 m .34998 .547 L .35154 .54548 L F
.639 .963 .901 r
.34998 .547 m .34894 .54678 L .35154 .54548 L F
.633 .636 .836 r
.33322 .56255 m .33664 .56424 L .33432 .55863 L F
.73 .234 .056 r
.33322 .56255 m .33526 .56503 L .33664 .56424 L F
.63 .635 .836 r
.33432 .55863 m .33664 .56424 L .33874 .56367 L F
.25 .321 .742 r
.32918 .53814 m .33247 .5385 L .33335 .53674 L F
.32918 .53814 m .33078 .54027 L .33247 .5385 L F
.721 .856 .946 r
.41739 .47264 m .41368 .47264 L .4148 .4715 L F
.796 .85 .891 r
.41989 .46978 m .41739 .47264 L .4148 .4715 L F
.354 .804 .948 r
.23701 .52947 m .24234 .52972 L .23892 .53012 L F
.984 .9 .638 r
.39917 .58885 m .39698 .59059 L .39792 .59141 L F
.955 .794 .347 r
.39895 .58518 m .39858 .58824 L .39917 .58885 L F
.915 .972 .681 r
.39858 .58824 m .39698 .59059 L .39917 .58885 L F
.264 0 .24 r
.31256 .61772 m .31426 .61762 L .3149 .61497 L F
.31256 .61772 m .3119 .61845 L .31426 .61762 L F
.346 .526 .89 r
.36987 .70295 m .37142 .70471 L .37299 .70421 L F
.461 .35 .641 r
.25989 .55102 m .26043 .5535 L .26254 .55257 L F
.25989 .55102 m .26043 .5535 L .26254 .55257 L F
.949 .801 .663 r
.2714 .57515 m .27362 .57713 L .27482 .57558 L F
.429 .201 .464 r
.27874 .5758 m .27387 .57778 L .27911 .57609 L F
.27528 .5767 m .27387 .57778 L .27874 .5758 L F
.2776 .57492 m .27528 .5767 L .27874 .5758 L F
.2776 .57492 m .27468 .57808 L .27387 .57778 L F
.949 .801 .663 r
.27362 .57713 m .27468 .57808 L .27475 .57684 L F
.27362 .57713 m .27475 .57684 L .27482 .57558 L F
.054 .6 .841 r
.27911 .57609 m .27925 .57572 L .2776 .57492 L F
.27911 .57609 m .28149 .57634 L .27925 .57572 L F
.634 .939 .961 r
.33602 .50293 m .34019 .50195 L .33758 .50226 L F
0 .327 .753 r
.34019 .50195 m .34294 .50332 L .34139 .5021 L F
.34019 .50195 m .34139 .5021 L .33758 .50226 L F
.974 .761 .336 r
.44824 .57446 m .44926 .57277 L .44703 .57197 L F
.44824 .57446 m .44915 .57532 L .44926 .57277 L F
.657 .428 .561 r
.44915 .57532 m .45228 .57212 L .44926 .57277 L F
.874 .968 .851 r
.69464 .33096 m .69589 .33167 L .69319 .3344 L F
.673 .94 .964 r
.69802 .33022 m .69589 .33167 L .69464 .33096 L F
0 0 .048 r
.31482 .647 m .31633 .64365 L .31706 .64637 L F
.408 .206 .491 r
.31457 .65024 m .31482 .647 L .31706 .64637 L F
.726 .989 .83 r
.57108 .41301 m .57275 .41204 L .57422 .41046 L F
.771 .506 .535 r
.73909 .31801 m .74278 .31831 L .74289 .32081 L F
.619 .872 .529 r
.74568 .31479 m .74457 .31584 L .74278 .31831 L F
0 0 0 r
.74278 .31831 m .74234 .31918 L .74289 .32081 L F
.74278 .31831 m .74457 .31584 L .74234 .31918 L F
.354 .804 .948 r
.23701 .52947 m .23937 .52903 L .24234 .52972 L F
.826 .943 .901 r
.24234 .52972 m .24257 .52621 L .24387 .5272 L F
.24234 .52972 m .23937 .52903 L .24257 .52621 L F
.45 .341 .638 r
.47871 .51076 m .47685 .51426 L .47666 .51144 L F
.677 .341 .398 r
.45029 .51683 m .45374 .51473 L .45134 .51505 L F
.45029 .51683 m .45306 .51742 L .45374 .51473 L F
.626 .353 .485 r
.45306 .51742 m .4564 .51434 L .45374 .51473 L F
.45306 .51742 m .4564 .51434 L .45374 .51473 L F
0 0 0 r
.55661 .41463 m .55155 .41656 L .5557 .41517 L F
.56 .496 .741 r
.55661 .41463 m .55908 .41502 L .55813 .41102 L F
.287 .66 .971 r
.55809 .41407 m .55908 .41502 L .55661 .41463 L F
.55809 .41407 m .55661 .41463 L .5557 .41517 L F
.903 .64 .529 r
.44357 .53085 m .44793 .53326 L .44669 .53096 L F
.744 .974 .924 r
.36149 .6392 m .36083 .64112 L .3593 .64079 L F
.552 .863 .996 r
.43964 .45688 m .4436 .45681 L .44103 .45724 L F
.434 .836 .977 r
.31019 .53585 m .3133 .53551 L .31102 .53597 L F
.775 .554 .599 r
.59568 .36928 m .59884 .36731 L .59588 .36639 L F
.59568 .36928 m .59967 .36996 L .59884 .36731 L F
.772 .935 .582 r
.32122 .55636 m .32343 .55282 L .32125 .55325 L F
.81 .782 .826 r
.62162 .42668 m .6235 .42849 L .62464 .42659 L F
.876 .774 .745 r
.62162 .42668 m .6222 .43038 L .6235 .42849 L F
.796 .74 .216 r
.33097 .53232 m .3306 .53633 L .32877 .53199 L F
.33097 .53232 m .33045 .53488 L .3306 .53633 L F
.771 .705 .789 r
.33045 .53488 m .32691 .53668 L .3306 .53633 L F
.733 .767 .88 r
.71937 .33167 m .72112 .32723 L .71849 .32963 L F
.71937 .33167 m .72204 .33047 L .72112 .32723 L F
.252 0 .04 r
.37766 .58774 m .37814 .58645 L .38028 .58691 L F
.853 .936 .562 r
.63513 .39503 m .63317 .39888 L .63408 .39577 L F
.133 0 .037 r
.63852 .39253 m .63513 .39503 L .63709 .39349 L F
.946 .726 .26 r
.63453 .39194 m .63513 .39503 L .6343 .39418 L F
.969 .767 .577 r
.33746 .56509 m .33708 .56615 L .33526 .56503 L F
.763 .53 .581 r
.4932 .49551 m .49317 .49823 L .48907 .4978 L F
.598 .372 .545 r
.49592 .49535 m .49317 .49823 L .4932 .49551 L F
.657 .428 .561 r
.44915 .57532 m .45243 .57524 L .45228 .57212 L F
.33 .145 .472 r
.45243 .57524 m .45506 .57178 L .45228 .57212 L F
.503 .295 .531 r
.30623 .62504 m .30911 .62455 L .30921 .62088 L F
.02 0 0 r
.30921 .62088 m .31075 .62033 L .3119 .61845 L F
.252 .099 .47 r
.30921 .62088 m .31075 .62293 L .31075 .62033 L F
.30921 .62088 m .30911 .62455 L .31075 .62293 L F
.713 .962 .943 r
.42628 .57589 m .42753 .57615 L .42808 .5746 L F
0 .167 .685 r
.42808 .5746 m .42942 .57831 L .42753 .57615 L F
.713 .962 .943 r
.42628 .57589 m .42753 .57615 L .42808 .5746 L F
.146 0 .277 r
.3149 .61497 m .31426 .61762 L .3166 .61408 L F
.721 .852 .944 r
.36873 .60732 m .37269 .60742 L .37166 .60647 L F
.788 .952 .925 r
.37166 .60647 m .37269 .60742 L .37596 .60509 L F
.645 .205 .191 r
.59837 .45758 m .59865 .45929 L .59459 .45877 L F
.018 .592 .735 r
.25198 .62117 m .24948 .6211 L .24789 .62109 L F
.698 .175 0 r
.25198 .62117 m .2504 .62205 L .24948 .6211 L F
.25198 .62117 m .25419 .62332 L .2504 .62205 L F
.679 .272 .266 r
.3695 .6114 m .36773 .61186 L .36924 .60964 L F
.911 .85 .77 r
.36924 .60964 m .36873 .60732 L .3695 .6114 L F
.08 .018 .479 r
.21482 .57271 m .21602 .57195 L .21583 .56936 L F
.057 0 .434 r
.21482 .57271 m .21597 .57482 L .21602 .57195 L F
0 0 .443 r
.21497 .57573 m .21597 .57482 L .21482 .57271 L F
.552 .89 .984 r
.37088 .62761 m .36875 .63072 L .37142 .63114 L F
.647 .171 .109 r
.37288 .62936 m .37088 .62761 L .37142 .63114 L F
0 0 0 r
.44175 .59851 m .44253 .59846 L .44047 .59886 L F
.44175 .59851 m .44427 .59802 L .44253 .59846 L F
.871 .594 .516 r
.38346 .52721 m .38462 .53026 L .38687 .53089 L F
.889 .689 .627 r
.38337 .53222 m .38687 .53089 L .38462 .53026 L F
.38337 .53222 m .38627 .53473 L .38687 .53089 L F
.514 .769 .989 r
.45138 .53673 m .45548 .53742 L .45393 .53637 L F
.659 .718 .892 r
.45548 .53742 m .45626 .53379 L .45393 .53637 L F
.45548 .53742 m .45858 .53757 L .45626 .53379 L F
.738 .581 .679 r
.45544 .54013 m .45858 .53757 L .45548 .53742 L F
0 0 .37 r
.47662 .56791 m .47598 .57215 L .47592 .5696 L F
.775 .694 .774 r
.63277 .35266 m .63613 .35306 L .63537 .34931 L F
.786 .652 .715 r
.63277 .35266 m .63415 .35686 L .63613 .35306 L F
.77 .691 .776 r
.63537 .34931 m .63613 .35306 L .63859 .35007 L F
.328 0 .057 r
.62057 .34589 m .62337 .34538 L .62433 .34321 L F
.008 0 0 r
.62433 .34321 m .62562 .34397 L .62699 .34268 L F
.62433 .34321 m .62337 .34538 L .62562 .34397 L F
0 .157 .649 r
.33855 .51964 m .34051 .52151 L .33903 .52041 L F
.788 .997 .798 r
.33855 .51964 m .33903 .52041 L .34051 .52151 L F
.442 0 .062 r
.29601 .56351 m .29822 .56452 L .29972 .56271 L F
.46 .019 .113 r
.29822 .56452 m .30258 .56238 L .29972 .56271 L F
.253 .215 .621 r
.31984 .5927 m .32219 .59406 L .32278 .59165 L F
.31984 .5927 m .32003 .59549 L .32219 .59406 L F
.959 .87 .705 r
.3712 .63119 m .36968 .63752 L .36827 .63601 L F
.392 .837 .935 r
.36968 .63752 m .37104 .63644 L .36827 .63601 L F
.36968 .63752 m .37229 .63687 L .37104 .63644 L F
.738 .581 .679 r
.45544 .54013 m .45937 .54066 L .45858 .53757 L F
0 .514 .761 r
.45997 .5345 m .45626 .53379 L .45858 .53757 L F
.546 .607 .865 r
.45858 .53757 m .4618 .53742 L .45997 .5345 L F
.636 .577 .771 r
.45937 .54066 m .4618 .53742 L .45858 .53757 L F
.487 .137 .299 r
.44986 .51515 m .44981 .51693 L .44747 .51664 L F
.712 .796 .917 r
.72186 .31474 m .71956 .31618 L .71789 .31407 L F
.115 .277 .752 r
.3301 .62473 m .32742 .6209 L .3283 .62331 L F
.861 .982 .691 r
.3265 .62743 m .3301 .62473 L .3283 .62331 L F
.252 .358 .778 r
.3968 .49114 m .39747 .49364 L .39624 .49263 L F
.543 .37 .597 r
.39624 .49263 m .39547 .49532 L .39747 .49364 L F
.882 .73 .687 r
.39364 .49176 m .39547 .49532 L .39624 .49263 L F
.275 .044 .371 r
.35494 .60445 m .35246 .60765 L .35298 .60547 L F
.691 .252 .203 r
.62076 .35682 m .61938 .35736 L .61672 .35635 L F
.637 .147 .072 r
.61868 .35773 m .61937 .35821 L .62009 .35749 L F
.6196 .35733 m .62009 .35749 L .62076 .35682 L F
.61868 .35773 m .62009 .35749 L .6196 .35733 L F
.832 .408 .231 r
.61937 .35821 m .62148 .35874 L .62131 .3583 L F
.62009 .35749 m .62131 .3583 L .62076 .35682 L F
.61937 .35821 m .62131 .3583 L .62009 .35749 L F
.446 .629 .932 r
.61934 .35724 m .61938 .35736 L .6196 .35733 L F
.102 0 0 r
.62076 .35682 m .6196 .35733 L .61938 .35736 L F
.441 .626 .931 r
.61672 .35635 m .61938 .35736 L .61934 .35724 L F
.637 .147 .072 r
.61672 .35635 m .61868 .35773 L .6196 .35733 L F
.61672 .35635 m .6196 .35733 L .62076 .35682 L F
.441 .626 .931 r
.61672 .35635 m .61934 .35724 L .61818 .35404 L F
.446 .629 .932 r
.62399 .35658 m .61923 .35692 L .62411 .35664 L F
.61865 .35533 m .61923 .35692 L .62399 .35658 L F
.102 0 0 r
.62076 .35682 m .62411 .35664 L .62073 .35683 L F
0 .348 .822 r
.6248 .36011 m .62076 .35682 L .62131 .3583 L F
.62315 .35943 m .62131 .3583 L .62148 .35874 L F
.6248 .36011 m .62131 .3583 L .62315 .35943 L F
.446 .629 .932 r
.61934 .35724 m .6196 .35733 L .6197 .35731 L F
.102 0 0 r
.61999 .35716 m .62411 .35664 L .6196 .35733 L F
.446 .629 .932 r
.61955 .35721 m .6197 .35731 L .62411 .35664 L F
.61934 .35724 m .6197 .35731 L .61955 .35721 L F
.61923 .35692 m .61965 .3572 L .62411 .35664 L F
.609 .475 .673 r
.62292 .35633 m .62501 .35708 L .62209 .3574 L F
.738 .606 .71 r
.62404 .35659 m .62411 .35664 L .62469 .35406 L F
.609 .475 .673 r
.62469 .35406 m .62498 .35678 L .62404 .35658 L F
.62469 .35406 m .62404 .35658 L .62292 .35633 L F
.446 .629 .932 r
.62399 .35658 m .62411 .35664 L .62404 .35659 L F
.609 .475 .673 r
.62469 .35406 m .62501 .35708 L .62209 .3574 L F
.738 .606 .71 r
.62083 .35463 m .62404 .35659 L .62469 .35406 L F
.186 .711 .692 r
.62371 .35387 m .62083 .35463 L .62422 .35373 L F
.446 .629 .932 r
.61818 .35404 m .61865 .35533 L .62399 .35658 L F
.186 .711 .692 r
.61985 .35486 m .62083 .35463 L .62371 .35387 L F
.446 .629 .932 r
.61818 .35404 m .62002 .35484 L .62083 .35463 L F
.62002 .35484 m .62399 .35658 L .62083 .35463 L F
.609 .475 .673 r
.62498 .35678 m .62399 .35658 L .62292 .35633 L F
.446 .629 .932 r
.62399 .35658 m .62404 .35659 L .62083 .35463 L F
.609 .475 .673 r
.62498 .35678 m .62498 .35682 L .62399 .35658 L F
.62498 .35682 m .62501 .35708 L .62292 .35633 L F
.446 .629 .932 r
.61923 .35692 m .61934 .35724 L .61965 .3572 L F
.41 .407 .746 r
.44793 .53326 m .45028 .5293 L .44669 .53096 L F
.44793 .53326 m .44999 .53325 L .45028 .5293 L F
.632 .893 .568 r
.61597 .37167 m .6173 .37048 L .61883 .36865 L F
0 0 0 r
.6572 .32467 m .65352 .32673 L .65627 .32363 L F
.889 .964 .836 r
.65987 .32143 m .6572 .32467 L .65627 .32363 L F
.922 .932 .796 r
.61072 .37042 m .60813 .37128 L .6093 .36881 L F
.962 .923 .715 r
.59589 .46306 m .59818 .46065 L .59872 .46237 L F
.21 0 0 r
.60198 .45973 m .59818 .46065 L .59865 .45929 L F
.60198 .45973 m .60116 .46107 L .59818 .46065 L F
.227 0 .165 r
.59818 .46065 m .60116 .46107 L .59872 .46237 L F
.778 .523 0 r
.3981 .57152 m .39897 .57551 L .39923 .57282 L F
0 .347 .821 r
.3769 .69141 m .37516 .69076 L .37276 .68804 L F
.777 .872 .441 r
.69985 .32573 m .69905 .32829 L .69802 .33022 L F
.372 0 0 r
.24462 .5742 m .2427 .57456 L .24677 .57497 L F
.529 .352 .586 r
.48308 .50346 m .4814 .50511 L .47859 .50553 L F
.535 .373 .608 r
.4814 .50511 m .47871 .50806 L .47859 .50553 L F
.704 .98 .902 r
.63317 .33977 m .63465 .33744 L .63635 .33792 L F
.63317 .33977 m .63244 .33922 L .63465 .33744 L F
.973 .662 .329 r
.59397 .41403 m .59445 .41312 L .59214 .40997 L F
.854 .518 .415 r
.37163 .60176 m .37406 .6003 L .37177 .60151 L F
.976 .827 .631 r
.7086 .33565 m .70996 .33711 L .7091 .33345 L F
.901 .873 .8 r
.70756 .34062 m .70996 .33711 L .7086 .33565 L F
.596 .296 .432 r
.52476 .4732 m .52891 .4748 L .52455 .47532 L F
.52476 .4732 m .52859 .47248 L .52891 .4748 L F
.273 0 0 r
.23434 .57524 m .23784 .57533 L .23533 .57569 L F
.759 .993 .8 r
.33486 .64171 m .33412 .64362 L .33334 .63991 L F
.641 .245 .279 r
.33314 .6441 m .3358 .64281 L .33486 .64171 L F
.3358 .64281 m .33708 .64219 L .33486 .64171 L F
.759 .993 .8 r
.33486 .64171 m .33334 .63991 L .33329 .63964 L F
.714 .365 .385 r
.33412 .64362 m .336 .64622 L .33307 .64611 L F
.532 .557 .825 r
.3346 .69282 m .33798 .69415 L .33644 .69051 L F
.379 .54 .889 r
.3346 .69282 m .33872 .69608 L .33798 .69415 L F
.97 .697 .457 r
.6016 .42762 m .60154 .43032 L .6032 .431 L F
.919 .527 .229 r
.60154 .43032 m .60205 .43229 L .6032 .431 L F
.989 .76 .374 r
.60205 .43229 m .60308 .43364 L .6032 .431 L F
.60205 .43229 m .60308 .43364 L .6032 .431 L F
.913 .733 .646 r
.6994 .29071 m .70292 .29294 L .70264 .28897 L F
.506 .777 .993 r
.30546 .50374 m .30716 .50513 L .30796 .50324 L F
.30546 .50374 m .30716 .50513 L .30796 .50324 L F
.713 .687 .823 r
.32688 .61412 m .33109 .6147 L .32855 .61129 L F
.423 .197 .464 r
.32995 .6134 m .32902 .61628 L .32688 .61412 L F
.995 .869 .58 r
.32995 .6134 m .32799 .61517 L .32953 .6133 L F
.699 .245 0 r
.32855 .61129 m .33017 .61346 L .32995 .6134 L F
0 .145 .682 r
.32855 .61129 m .32995 .6134 L .33051 .6121 L F
.995 .869 .58 r
.32995 .6134 m .32953 .6133 L .33051 .6121 L F
.699 .245 0 r
.33017 .61346 m .33109 .6147 L .32995 .6134 L F
.681 .224 .16 r
.33109 .6147 m .32902 .61628 L .32995 .6134 L F
.33109 .6147 m .33339 .61686 L .32902 .61628 L F
.451 .301 .586 r
.47685 .51426 m .47708 .51704 L .47432 .51826 L F
.464 .328 .611 r
.47432 .51826 m .47705 .52022 L .47469 .52104 L F
.47432 .51826 m .47708 .51704 L .47705 .52022 L F
.522 .286 .499 r
.49832 .4926 m .49856 .49479 L .49592 .49535 L F
.481 .201 .412 r
.50187 .49166 m .49856 .49479 L .49832 .4926 L F
.185 0 .08 r
.3119 .61845 m .31075 .62033 L .31426 .61762 L F
0 0 .376 r
.47598 .57215 m .4768 .57502 L .47662 .57592 L F
0 0 .175 r
.4768 .57502 m .47618 .57797 L .47662 .57592 L F
.549 .927 .813 r
.66595 .38455 m .66989 .38277 L .66894 .38263 L F
.469 .892 .888 r
.66894 .38263 m .66989 .38277 L .67249 .38169 L F
0 0 0 r
.6294 .39402 m .62768 .39481 L .62957 .39442 L F
.283 .092 .436 r
.56096 .43442 m .56268 .43629 L .56365 .4342 L F
.668 .236 .214 r
.56268 .43629 m .56398 .43553 L .56365 .4342 L F
.855 .694 .682 r
.56398 .43553 m .5672 .43494 L .56365 .4342 L F
.726 .759 .878 r
.45073 .56293 m .44637 .56148 L .44914 .55909 L F
.747 .452 .483 r
.44897 .5618 m .45073 .56293 L .44914 .55909 L F
.44897 .5618 m .45308 .55967 L .45073 .56293 L F
.209 0 .347 r
.45308 .55967 m .45276 .56201 L .45073 .56293 L F
.167 .09 .517 r
.45284 .56519 m .45073 .56293 L .45276 .56201 L F
.791 .421 .356 r
.32055 .6274 m .32236 .63063 L .31902 .62962 L F
.587 .906 .649 r
.65987 .32143 m .66163 .31952 L .66275 .31889 L F
.592 .907 .649 r
.66275 .31889 m .66333 .3178 L .6651 .31735 L F
.66275 .31889 m .66163 .31952 L .66333 .3178 L F
.466 .236 .481 r
.50466 .48857 m .50187 .49166 L .50199 .48914 L F
.737 .529 .611 r
.24759 .60467 m .24685 .60843 L .25174 .60502 L F
.882 .992 .781 r
.63408 .39577 m .63317 .39888 L .63245 .39829 L F
.317 .758 .965 r
.39163 .49209 m .39364 .49176 L .39028 .49154 L F
.65 .646 .833 r
.39271 .49487 m .39364 .49176 L .39163 .49209 L F
.968 .654 .357 r
.33981 .61009 m .34301 .60811 L .33964 .60944 L F
.456 .826 .993 r
.34266 .60886 m .33964 .60944 L .34401 .60676 L F
.34266 .60886 m .34401 .60676 L .34413 .60669 L F
.537 .497 .759 r
.34216 .61135 m .34147 .61071 L .34266 .60886 L F
.456 .826 .993 r
.34266 .60886 m .33944 .60873 L .33964 .60944 L F
.537 .497 .759 r
.34147 .61071 m .33931 .60873 L .34266 .60886 L F
.456 .826 .993 r
.33944 .60873 m .33931 .60873 L .33964 .60944 L F
.968 .654 .357 r
.33907 .61056 m .33981 .61009 L .33964 .60944 L F
.162 0 .348 r
.3645 .59709 m .36425 .59486 L .36623 .59504 L F
.554 .814 .994 r
.7359 .3342 m .73627 .33291 L .73289 .33372 L F
.809 .974 .675 r
.73846 .32988 m .73627 .33291 L .7359 .3342 L F
.674 .572 .732 r
.36606 .53315 m .37034 .5346 L .36942 .53047 L F
.514 .328 .566 r
.50723 .48538 m .50466 .48857 L .50455 .48596 L F
.703 .258 .192 r
.28739 .63877 m .28916 .63718 L .29039 .63896 L F
.706 .495 .6 r
.54677 .40406 m .54976 .40456 L .55084 .40188 L F
.564 .055 0 r
.38922 .5114 m .38988 .51235 L .38777 .51 L F
.38922 .5114 m .39131 .51364 L .38988 .51235 L F
.913 .733 .646 r
.6994 .29071 m .70264 .28897 L .70142 .28689 L F
.497 0 0 r
.38533 .50805 m .38609 .50891 L .38347 .50719 L F
.38533 .50805 m .38777 .51 L .38609 .50891 L F
.563 .748 .964 r
.73813 .31531 m .73909 .31801 L .73633 .31818 L F
.237 0 0 r
.73633 .31818 m .73909 .31801 L .73945 .31851 L F
.984 .902 .638 r
.73974 .3149 m .73909 .31801 L .73813 .31531 L F
.771 .506 .535 r
.73909 .31801 m .74289 .32081 L .73945 .31851 L F
.31 .412 .805 r
.73813 .31531 m .73633 .31818 L .73945 .31851 L F
.943 .917 .759 r
.62101 .42853 m .6208 .43194 L .6222 .43038 L F
.456 .831 .99 r
.28123 .62929 m .28094 .63052 L .28017 .62728 L F
.541 .498 .758 r
.5672 .43494 m .57039 .43701 L .5703 .43402 L F
.834 .91 .889 r
.23564 .53885 m .24015 .53716 L .23848 .53745 L F
.308 .797 .768 r
.24057 .53659 m .24015 .53716 L .24138 .5362 L F
.24057 .53659 m .23848 .53745 L .24015 .53716 L F
.631 .386 .529 r
.55707 .43708 m .56067 .43703 L .56096 .43442 L F
.283 .092 .436 r
.56096 .43442 m .56067 .43703 L .56268 .43629 L F
.449 .417 .731 r
.34989 .51769 m .3526 .51685 L .35116 .51464 L F
.358 .183 .502 r
.34989 .51769 m .35237 .51993 L .3526 .51685 L F
.34989 .51769 m .34968 .521 L .35237 .51993 L F
.062 .605 .847 r
.58374 .35948 m .58771 .36021 L .58654 .35976 L F
.58374 .35948 m .58771 .36021 L .58654 .35976 L F
.896 .51 .064 r
.60872 .41798 m .61051 .42121 L .60951 .41995 L F
.989 .846 .476 r
.61051 .42121 m .6093 .42239 L .60951 .41995 L F
.61051 .42121 m .61003 .42401 L .6093 .42239 L F
0 0 .464 r
.37966 .66474 m .37961 .66567 L .3808 .66581 L F
0 .102 .653 r
.37961 .66567 m .3817 .66851 L .3808 .66581 L F
.3808 .66581 m .3817 .66851 L .37961 .66567 L F
.3808 .66581 m .37961 .66567 L .37746 .66786 L F
.86 .487 .342 r
.29764 .65215 m .29846 .65039 L .2979 .65059 L F
.558 .357 .563 r
.35685 .58207 m .35949 .58166 L .35698 .57922 L F
.35698 .57922 m .35949 .58166 L .35685 .58207 L F
.379 .333 .68 r
.4317 .58279 m .43246 .58533 L .43364 .58442 L F
.889 .964 .836 r
.65987 .32143 m .65627 .32363 L .65807 .32194 L F
.632 .959 .805 r
.65987 .32143 m .65807 .32194 L .66163 .31952 L F
.523 .582 .856 r
.33798 .69415 m .33872 .69608 L .34102 .69564 L F
.608 .951 .809 r
.36649 .55916 m .36887 .55748 L .36678 .55819 L F
0 .304 .793 r
.36678 .55819 m .36845 .56026 L .36649 .55916 L F
.899 .882 .808 r
.42018 .58472 m .42538 .58132 L .42126 .5818 L F
.42018 .58472 m .4218 .58537 L .42538 .58132 L F
.874 .968 .851 r
.69464 .33096 m .69319 .3344 L .69167 .333 L F
.892 .501 .058 r
.69319 .3344 m .69254 .33482 L .69167 .333 L F
.69319 .3344 m .69375 .33587 L .69254 .33482 L F
.741 .382 .371 r
.32408 .62302 m .32742 .6209 L .32656 .61921 L F
.568 .281 .439 r
.34515 .60443 m .3485 .60185 L .34505 .6019 L F
0 0 .261 r
.34597 .60262 m .34505 .6019 L .34631 .6005 L F
.34597 .60262 m .34515 .60443 L .34505 .6019 L F
.271 .25 .652 r
.32003 .59549 m .32238 .59783 L .32219 .59406 L F
.405 .142 .399 r
.34045 .59551 m .34229 .5972 L .34278 .59512 L F
.34229 .5972 m .34045 .59551 L .34066 .59396 L F
.34229 .5972 m .33987 .59788 L .34045 .59551 L F
.34045 .59551 m .33987 .59788 L .34229 .5972 L F
0 0 .066 r
.69777 .36158 m .69774 .35984 L .69931 .3578 L F
.151 .186 .644 r
.23115 .56794 m .2304 .5695 L .22946 .5665 L F
.23115 .56794 m .22946 .5665 L .22837 .56562 L F
.891 .719 .662 r
.61655 .40069 m .61971 .40147 L .61934 .39928 L F
.855 .803 .799 r
.61701 .40462 m .61971 .40147 L .61655 .40069 L F
.688 .689 .845 r
.61971 .40147 m .62257 .39863 L .61934 .39928 L F
.089 .528 .906 r
.27205 .63658 m .27572 .6384 L .2746 .63727 L F
.342 .416 .793 r
.27572 .6384 m .27667 .63599 L .2746 .63727 L F
.27572 .6384 m .2782 .6397 L .27667 .63599 L F
.515 .493 .77 r
.35485 .55358 m .35129 .55354 L .35386 .55294 L F
.875 .862 .823 r
.33708 .56615 m .33482 .56977 L .33268 .56831 L F
.397 0 0 r
.27024 .54778 m .27382 .54845 L .27241 .54756 L F
.284 0 0 r
.52426 .41137 m .52539 .41049 L .52188 .41144 L F
.121 .574 .92 r
.52638 .40987 m .52539 .41049 L .52426 .41137 L F
.52638 .40987 m .52763 .41101 L .52539 .41049 L F
.608 .795 .971 r
.43408 .48241 m .43428 .48027 L .43189 .48141 L F
.43408 .48241 m .43642 .48234 L .43428 .48027 L F
.722 .218 0 r
.43394 .48326 m .43408 .48241 L .43189 .48141 L F
.43394 .48326 m .43613 .48496 L .43408 .48241 L F
.67 .406 .513 r
.43408 .48241 m .43613 .48496 L .43642 .48234 L F
.411 .796 .991 r
.37607 .65633 m .38038 .65698 L .37873 .65604 L F
.858 .928 .873 r
.37873 .65604 m .38038 .65698 L .38343 .65391 L F
.931 .562 .285 r
.38713 .53567 m .39 .53998 L .38888 .5368 L F
0 0 0 r
.35538 .63931 m .35408 .64233 L .35464 .64198 L F
.436 0 0 r
.35505 .64172 m .35464 .64198 L .35403 .64192 L F
.35868 .64103 m .3555 .63958 L .35464 .64198 L F
.35868 .64103 m .35464 .64198 L .35505 .64172 L F
0 0 0 r
.35408 .64233 m .35367 .64327 L .35464 .64198 L F
.327 0 0 r
.3555 .63958 m .35538 .63931 L .35464 .64198 L F
.35755 .64023 m .3593 .64079 L .35696 .63991 L F
.777 .607 .668 r
.35737 .63592 m .3593 .64079 L .35755 .64023 L F
0 0 .429 r
.35751 .63964 m .35737 .63993 L .35754 .64007 L F
.327 0 0 r
.3555 .63958 m .35755 .64023 L .35538 .63931 L F
.35755 .64023 m .35696 .63991 L .35538 .63931 L F
0 0 .399 r
.35737 .63592 m .35737 .63993 L .35751 .63964 L F
.756 .497 .541 r
.35797 .63743 m .36149 .6392 L .3593 .64079 L F
.35737 .63592 m .35851 .63682 L .35797 .63743 L F
.35851 .63682 m .36149 .6392 L .35797 .63743 L F
.719 .988 .866 r
.35737 .63592 m .35998 .63503 L .36162 .63649 L F
.756 .497 .541 r
.35737 .63592 m .36162 .63649 L .36149 .6392 L F
.535 .629 .891 r
.36394 .63588 m .36022 .63508 L .36249 .63224 L F
.36022 .63508 m .35998 .63503 L .36008 .63492 L F
.648 .716 .897 r
.36054 .63405 m .35768 .63151 L .35866 .63331 L F
.36091 .6342 m .3606 .63394 L .36054 .63405 L F
.3606 .63394 m .35768 .63151 L .36054 .63405 L F
.36091 .6342 m .35866 .63331 L .3589 .63358 L F
.719 .988 .866 r
.35737 .63592 m .36091 .6342 L .35879 .63354 L F
.535 .629 .891 r
.36022 .63508 m .36008 .63492 L .36249 .63224 L F
0 0 0 r
.36132 .63422 m .35877 .63715 L .3606 .63673 L F
.923 .842 .394 r
.36074 .63526 m .36132 .63422 L .3606 .63673 L F
0 0 0 r
.36227 .63248 m .36008 .63492 L .36132 .63422 L F
.36008 .63492 m .36004 .635 L .36132 .63422 L F
.36132 .63422 m .36019 .6349 L .35877 .63715 L F
.648 .716 .897 r
.3589 .63358 m .35866 .63331 L .35879 .63354 L F
.661 .47 .616 r
.36014 .63005 m .35879 .63354 L .35768 .63151 L F
.762 .35 .269 r
.35893 .63264 m .36057 .63305 L .36074 .63347 L F
.923 .842 .394 r
.36097 .63299 m .36132 .63422 L .36074 .63526 L F
.36112 .63145 m .36119 .63251 L .36097 .63299 L F
.36119 .63251 m .36132 .63422 L .36097 .63299 L F
0 0 .27 r
.36112 .63145 m .36067 .63604 L .36138 .63508 L F
.36067 .63604 m .3606 .63673 L .36138 .63508 L F
0 0 .429 r
.35877 .63715 m .35808 .64053 L .35868 .64086 L F
.35877 .63715 m .35868 .64103 L .35976 .64099 L F
.964 .678 .256 r
.35877 .63715 m .35976 .64099 L .35829 .63936 L F
.35877 .63715 m .35829 .63936 L .3606 .63673 L F
.936 .946 .769 r
.35905 .63645 m .3606 .63673 L .35829 .63936 L F
.646 .955 .938 r
.36138 .63508 m .3606 .63673 L .35905 .63645 L F
0 0 0 r
.362 .63424 m .36138 .63508 L .3601 .63709 L F
.36259 .63336 m .36138 .63508 L .362 .63424 L F
.762 .35 .269 r
.36042 .63413 m .36074 .63347 L .36138 .63508 L F
.35893 .63264 m .36074 .63347 L .36042 .63413 L F
0 0 0 r
.36249 .63224 m .36227 .63248 L .36132 .63422 L F
.36008 .63492 m .35998 .63503 L .36004 .635 L F
.36019 .6349 m .35998 .63503 L .35979 .63536 L F
.36019 .6349 m .35979 .63536 L .35877 .63715 L F
0 0 .399 r
.35737 .63592 m .35751 .63964 L .35877 .63715 L F
.777 .607 .668 r
.35729 .63609 m .35751 .63964 L .3555 .63958 L F
.35751 .63964 m .35755 .64023 L .35753 .64023 L F
.35751 .63964 m .35753 .64023 L .3555 .63958 L F
.35737 .63592 m .35755 .64023 L .35729 .63609 L F
0 0 .429 r
.35877 .63715 m .35751 .63964 L .35808 .64053 L F
.35751 .63964 m .35754 .64007 L .35808 .64053 L F
.35868 .64086 m .35808 .64053 L .35868 .64103 L F
.244 .009 .345 r
.33047 .6494 m .3308 .6467 L .33307 .64611 L F
.917 .593 .416 r
.33528 .61911 m .33883 .62176 L .33729 .62343 L F
.694 .262 .22 r
.33883 .62176 m .34259 .62387 L .33729 .62343 L F
.755 .862 .927 r
.47541 .4451 m .47106 .44573 L .47404 .44363 L F
.782 .842 .897 r
.47603 .44183 m .47541 .4451 L .47404 .44363 L F
.47603 .44183 m .47775 .44325 L .47541 .4451 L F
.943 .607 .184 r
.39742 .56471 m .39869 .56787 L .39823 .5661 L F
.738 .644 .755 r
.36252 .69853 m .36201 .6994 L .35861 .69554 L F
.239 0 0 r
.30698 .56687 m .306 .56838 L .30362 .56893 L F
.139 0 0 r
.30915 .56606 m .306 .56838 L .30698 .56687 L F
.168 0 .336 r
.2188 .56 m .21984 .56167 L .21982 .55899 L F
.2188 .56 m .21818 .56258 L .21984 .56167 L F
.891 .862 .805 r
.28202 .5361 m .28206 .54032 L .28382 .53726 L F
.28202 .5361 m .27952 .53963 L .28206 .54032 L F
.556 .607 .859 r
.27952 .53963 m .2836 .54246 L .28206 .54032 L F
.878 .717 .678 r
.39837 .66593 m .39727 .66239 L .39572 .66516 L F
.827 .514 .461 r
.39523 .66821 m .39837 .66593 L .39572 .66516 L F
.39523 .66821 m .39896 .66879 L .39837 .66593 L F
.986 .754 .502 r
.35325 .67221 m .35452 .67573 L .35282 .6745 L F
.897 .891 .815 r
.35282 .6745 m .35452 .67573 L .35204 .67873 L F
.728 .578 .686 r
.35452 .67573 m .35527 .67932 L .35204 .67873 L F
.986 .754 .502 r
.35282 .6745 m .35452 .67573 L .35325 .67221 L F
.529 .039 0 r
.35475 .67601 m .35452 .67573 L .35282 .6745 L F
.304 .292 .68 r
.35727 .67872 m .35527 .67932 L .35452 .67573 L F
.529 .039 0 r
.35475 .67601 m .35727 .67872 L .35452 .67573 L F
.309 0 0 r
.43183 .58996 m .43427 .59041 L .43566 .58836 L F
0 .079 .629 r
.43566 .58836 m .43674 .58703 L .43545 .58646 L F
0 0 0 r
.43566 .58836 m .43427 .59041 L .43674 .58703 L F
.464 .26 .517 r
.4277 .53873 m .42474 .53978 L .42514 .53727 L F
.387 .828 .692 r
.29921 .66804 m .30291 .6662 L .30104 .66906 L F
0 0 0 r
.30104 .66906 m .30291 .6662 L .30439 .66485 L F
.902 .488 .143 r
.36593 .54362 m .36457 .54454 L .36407 .54252 L F
.751 .939 .604 r
.66396 .33201 m .66278 .33444 L .66527 .33102 L F
.78 .998 .823 r
.66141 .33449 m .66278 .33444 L .66396 .33201 L F
.622 .457 .637 r
.45678 .54414 m .45937 .54066 L .45544 .54013 L F
.45678 .54414 m .45943 .54344 L .45937 .54066 L F
.636 .577 .771 r
.45937 .54066 m .46205 .54008 L .4618 .53742 L F
.605 .444 .636 r
.45937 .54066 m .45943 .54344 L .46205 .54008 L F
.224 0 0 r
.34731 .57452 m .34414 .57769 L .34439 .57491 L F
.34731 .57452 m .34655 .57706 L .34414 .57769 L F
.411 .476 .817 r
.34731 .57452 m .3502 .57405 L .34965 .57093 L F
0 0 .115 r
.34965 .57093 m .34907 .57347 L .34731 .57452 L F
.411 .476 .817 r
.34731 .57452 m .34895 .57567 L .3502 .57405 L F
.44 .251 .527 r
.34907 .57347 m .34655 .57706 L .34731 .57452 L F
.681 .138 0 r
.25713 .62428 m .25638 .62547 L .25419 .62332 L F
.25713 .62428 m .25804 .62587 L .25638 .62547 L F
.501 .405 .678 r
.35768 .63151 m .35434 .63622 L .35879 .63354 L F
.439 .289 .579 r
.35879 .63354 m .35434 .63622 L .35583 .63666 L F
.137 .489 .903 r
.35583 .63666 m .35434 .63622 L .35091 .63332 L F
.721 .857 .946 r
.64074 .39079 m .63852 .39253 L .63705 .39072 L F
.993 .744 .408 r
.63705 .39072 m .63852 .39253 L .63709 .39349 L F
.937 .95 .625 r
.25619 .5749 m .25399 .5782 L .25594 .5766 L F
.697 .952 .954 r
.60054 .35029 m .59925 .35235 L .598 .35176 L F
.60054 .35029 m .6025 .35077 L .59925 .35235 L F
.566 0 0 r
.27325 .57798 m .27059 .57783 L .26881 .57698 L F
.27325 .57798 m .26881 .57698 L .26873 .57687 L F
.949 .801 .663 r
.2714 .57515 m .27059 .57783 L .27325 .57798 L F
.566 0 0 r
.26873 .57687 m .26881 .57698 L .26839 .57678 L F
.718 .404 .446 r
.2714 .57515 m .27059 .57783 L .26839 .57678 L F
.2714 .57515 m .26839 .57678 L .26658 .57478 L F
.2714 .57515 m .26666 .5766 L .27059 .57783 L F
.214 0 .107 r
.2714 .57515 m .27211 .57685 L .27059 .57783 L F
.782 .362 .253 r
.27059 .57783 m .26862 .57944 L .26666 .5766 L F
.214 0 .107 r
.2714 .57515 m .26947 .57791 L .27211 .57685 L F
.26947 .57791 m .26936 .57808 L .26953 .578 L F
.26947 .57791 m .26953 .578 L .27211 .57685 L F
.205 .449 .872 r
.27325 .57798 m .27387 .57778 L .27468 .57808 L F
.949 .801 .663 r
.2714 .57515 m .27325 .57798 L .27468 .57808 L F
.878 .519 .03 r
.39266 .51482 m .39232 .5158 L .39131 .51364 L F
.39266 .51482 m .39327 .51704 L .39232 .5158 L F
.556 .47 .713 r
.4378 .50401 m .43729 .50618 L .44044 .50384 L F
.342 .122 .428 r
.43729 .50618 m .43775 .50756 L .44044 .50384 L F
.03 0 .437 r
.4378 .50401 m .43775 .50756 L .43729 .50618 L F
.85 .868 .854 r
.37843 .69801 m .38184 .6979 L .38101 .69528 L F
.865 .843 .821 r
.3794 .70055 m .38184 .6979 L .37843 .69801 L F
.792 .841 .889 r
.38101 .69528 m .38184 .6979 L .38488 .69491 L F
.506 .243 .449 r
.28383 .56901 m .28647 .56862 L .28682 .56623 L F
.52 .312 .537 r
.28647 .56862 m .28903 .56538 L .28682 .56623 L F
.992 .773 .398 r
.39819 .58076 m .39919 .57886 L .39864 .57805 L F
.39819 .58076 m .39864 .58103 L .39919 .57886 L F
.735 .747 .862 r
.73381 .32658 m .73204 .33111 L .7317 .32738 L F
.925 .611 .429 r
.56821 .41715 m .56976 .41748 L .56845 .41943 L F
.271 .752 .928 r
.57227 .41711 m .56976 .41748 L .56821 .41715 L F
.229 0 .005 r
.56845 .41943 m .56976 .41748 L .57227 .41711 L F
.696 .604 .75 r
.63033 .357 m .63415 .35686 L .63277 .35266 L F
.695 .565 .704 r
.63109 .35998 m .63415 .35686 L .63033 .357 L F
.537 .589 .854 r
.43642 .48234 m .4375 .47874 L .43428 .48027 L F
.43642 .48234 m .43881 .48166 L .4375 .47874 L F
.65 .496 .662 r
.43613 .48496 m .43881 .48166 L .43642 .48234 L F
.591 .518 .741 r
.33901 .68259 m .34071 .68725 L .34245 .68517 L F
.457 0 0 r
.3383 .68741 m .34071 .68725 L .34223 .6881 L F
.348 0 .016 r
.46254 .59075 m .45973 .59101 L .4628 .58937 L F
.43 0 .113 r
.46254 .59075 m .4628 .58937 L .46511 .59049 L F
.39 0 0 r
.28711 .64225 m .28903 .6409 L .28622 .64075 L F
.28711 .64225 m .28622 .64075 L .28739 .63877 L F
.98 .685 .353 r
.40939 .55007 m .4079 .54903 L .40789 .54662 L F
.908 .656 .154 r
.40891 .55271 m .4079 .54903 L .40939 .55007 L F
.678 .959 .728 r
.66831 .32818 m .66679 .3289 L .66527 .33102 L F
.645 .909 .601 r
.66679 .3289 m .66396 .33201 L .66527 .33102 L F
.99 .778 .524 r
.43036 .5735 m .42911 .56923 L .42848 .57172 L F
.939 .931 .767 r
.42808 .5746 m .43036 .5735 L .42848 .57172 L F
.678 .596 .757 r
.45943 .54344 m .46085 .54732 L .46352 .5467 L F
.545 .535 .794 r
.46085 .54732 m .46415 .54981 L .46352 .5467 L F
.506 0 0 r
.29193 .56325 m .29406 .56451 L .29601 .56351 L F
.439 0 0 r
.29601 .56351 m .29406 .56451 L .29822 .56452 L F
.084 0 0 r
.30674 .62576 m .30623 .62504 L .3041 .62536 L F
.30674 .62576 m .30911 .62455 L .30623 .62504 L F
.855 .957 .614 r
.70616 .34162 m .70551 .34421 L .70756 .34062 L F
.901 .873 .8 r
.70756 .34062 m .7086 .33565 L .70735 .33956 L F
.9 .95 .6 r
.70616 .34162 m .70756 .34062 L .70735 .33956 L F
.738 .644 .755 r
.36252 .69853 m .35861 .69554 L .36071 .69452 L F
.343 .307 .674 r
.36493 .70018 m .36287 .69999 L .36252 .69853 L F
.223 .539 .926 r
.36287 .69999 m .36493 .70018 L .36252 .69853 L F
.552 .313 .506 r
.28822 .64684 m .29043 .64653 L .28795 .64944 L F
.972 .674 .397 r
.60265 .40392 m .6043 .40504 L .60446 .40763 L F
.576 .87 .995 r
.31795 .52436 m .31628 .52348 L .31866 .52259 L F
.31795 .52436 m .31628 .52348 L .31866 .52259 L F
.515 .264 .472 r
.35282 .6745 m .35325 .67221 L .35034 .67262 L F
.986 .754 .502 r
.35325 .67221 m .35282 .6745 L .35034 .67262 L F
.766 .785 .869 r
.72112 .32723 m .72204 .33047 L .72478 .32753 L F
.664 .607 .781 r
.72204 .33047 m .7261 .33132 L .72478 .32753 L F
.568 .33 .515 r
.51921 .47583 m .51953 .47824 L .51572 .47899 L F
.612 .393 .56 r
.52188 .47557 m .51953 .47824 L .51921 .47583 L F
.356 .099 .381 r
.67531 .36779 m .67277 .36646 L .67272 .36888 L F
.67531 .36779 m .67565 .36551 L .67277 .36646 L F
.476 .412 .705 r
.27711 .53969 m .2782 .53636 L .27646 .53786 L F
.694 .237 0 r
.59818 .4212 m .59579 .41796 L .59666 .42 L F
.974 .67 .369 r
.5983 .4233 m .59818 .4212 L .59666 .42 L F
.875 .695 .655 r
.44005 .55922 m .44125 .5552 L .4425 .55659 L F
.775 .614 .68 r
.4425 .55659 m .44333 .56024 L .44005 .55922 L F
.139 0 0 r
.44341 .55757 m .4425 .55659 L .44125 .5552 L F
0 .05 .58 r
.44486 .55722 m .44333 .56024 L .4425 .55659 L F
.139 0 0 r
.44341 .55757 m .44486 .55722 L .4425 .55659 L F
.463 .172 .385 r
.51022 .48253 m .50992 .48474 L .50723 .48538 L F
.49 .195 .392 r
.51022 .48253 m .51264 .48424 L .50992 .48474 L F
.52 .177 .327 r
.51318 .48233 m .51264 .48424 L .51022 .48253 L F
.511 .627 .902 r
.33331 .50269 m .3346 .50008 L .33206 .50054 L F
.33331 .50269 m .33602 .50293 L .3346 .50008 L F
.5 .869 .645 r
.57436 .42731 m .57659 .42542 L .57811 .42452 L F
0 0 .544 r
.57436 .42731 m .57564 .42807 L .57659 .42542 L F
.57515 .42866 m .57605 .43019 L .57574 .42857 L F
.716 .212 .036 r
.57605 .43019 m .57529 .43168 L .57564 .42807 L F
0 0 .113 r
.57529 .43168 m .57599 .43025 L .57624 .4285 L F
.57607 .42853 m .57624 .4285 L .57645 .42702 L F
.57529 .43168 m .57624 .4285 L .57607 .42853 L F
0 0 .544 r
.57436 .42731 m .57515 .42866 L .57564 .42807 L F
.57515 .42866 m .57574 .42857 L .57564 .42807 L F
.268 .258 .662 r
.70194 .29709 m .70164 .30016 L .69902 .30206 L F
0 .148 .678 r
.70102 .30229 m .69902 .30206 L .70164 .30016 L F
.019 0 .257 r
.70247 .30123 m .70102 .30229 L .70296 .29871 L F
.988 .726 .426 r
.7017 .3017 m .70102 .30229 L .70247 .30123 L F
0 .148 .678 r
.70102 .30229 m .69996 .30319 L .69902 .30206 L F
.988 .726 .426 r
.6995 .30305 m .70102 .30229 L .7017 .3017 L F
0 .148 .678 r
.70102 .30229 m .70141 .30494 L .69996 .30319 L F
.254 .749 .673 r
.44976 .59466 m .45387 .59315 L .45201 .59381 L F
0 0 0 r
.45387 .59315 m .45446 .59332 L .45201 .59381 L F
.45387 .59315 m .45637 .59244 L .45446 .59332 L F
.791 .882 .456 r
.37146 .56 m .37031 .56206 L .37142 .55957 L F
.37146 .56 m .37014 .56252 L .37031 .56206 L F
.847 .94 .572 r
.70437 .34599 m .70551 .34421 L .70616 .34162 L F
.883 .863 .814 r
.43364 .50669 m .43526 .50805 L .4378 .50401 L F
.494 .328 .585 r
.43526 .50805 m .43775 .50756 L .4378 .50401 L F
.612 .08 0 r
.43364 .50669 m .43775 .50756 L .43526 .50805 L F
.65 .646 .833 r
.39271 .49487 m .39547 .49532 L .39364 .49176 L F
0 0 0 r
.39271 .49487 m .39427 .49461 L .39547 .49532 L F
.39271 .49487 m .39035 .49666 L .39427 .49461 L F
.57859 .46203 m .58248 .46024 L .58205 .46022 L F
.191 .668 .933 r
.58248 .46024 m .58465 .4598 L .58205 .46022 L F
.58248 .46024 m .58496 .46038 L .58465 .4598 L F
.613 .56 .772 r
.25382 .5372 m .24954 .53378 L .24922 .53671 L F
.484 .316 .577 r
.33184 .57267 m .33428 .5749 L .33401 .57208 L F
.33184 .57267 m .33188 .57553 L .33428 .5749 L F
.122 0 .134 r
.36873 .60732 m .3667 .60865 L .36587 .61084 L F
.366 .502 .862 r
.35149 .69923 m .3531 .7019 L .35434 .69999 L F
.325 .447 .831 r
.35434 .69999 m .3531 .7019 L .35495 .70177 L F
.255 .546 .926 r
.3531 .7019 m .35638 .70275 L .35495 .70177 L F
.324 .183 .53 r
.35246 .60765 m .35253 .61099 L .34997 .61227 L F
.038 .219 .721 r
.35183 .61221 m .34997 .61227 L .35253 .61099 L F
.35183 .61221 m .35108 .61433 L .34997 .61227 L F
.89 .528 .351 r
.39104 .68419 m .39354 .68491 L .39271 .68228 L F
.782 .727 .801 r
.39412 .68872 m .39354 .68491 L .39274 .68797 L F
.39412 .68872 m .39679 .68553 L .39354 .68491 L F
.901 .976 .685 r
.38343 .65391 m .38567 .65005 L .38318 .65253 L F
0 0 .13 r
.35405 .59554 m .35452 .59671 L .35573 .59449 L F
.35405 .59554 m .35348 .59797 L .35452 .59671 L F
.398 0 0 r
.28549 .53572 m .28202 .5361 L .28382 .53726 L F
.28549 .53572 m .28202 .5361 L .28382 .53726 L F
.881 .989 .809 r
.29517 .51231 m .29795 .51135 L .29446 .51206 L F
.417 .166 .423 r
.34113 .64298 m .34326 .64041 L .34296 .64347 L F
.34113 .64298 m .34326 .64041 L .34296 .64347 L F
.559 .283 .455 r
.34296 .64347 m .34561 .64259 L .34326 .64041 L F
.34296 .64347 m .34561 .64259 L .34326 .64041 L F
0 0 0 r
.68173 .31941 m .67938 .32041 L .68299 .31871 L F
.68489 .31672 m .68173 .31941 L .68299 .31871 L F
.591 .518 .741 r
.33918 .68272 m .34245 .68517 L .34121 .68227 L F
.815 .708 .747 r
.34121 .68227 m .34245 .68517 L .34484 .68038 L F
.881 .73 .69 r
.34121 .68227 m .34245 .68517 L .33912 .68427 L F
.348 .455 .828 r
.3442 .68398 m .34245 .68517 L .34121 .68227 L F
.3442 .68398 m .34124 .68229 L .34342 .68178 L F
.34124 .68229 m .34121 .68227 L .34342 .68178 L F
.473 .473 .777 r
.34601 .68332 m .3442 .68398 L .34342 .68178 L F
.34601 .68332 m .34342 .68178 L .34487 .68139 L F
.121 0 0 r
.34477 .68146 m .34342 .68178 L .34259 .68293 L F
.34487 .68139 m .34342 .68178 L .34477 .68146 L F
.129 0 0 r
.34342 .68178 m .34121 .68227 L .33994 .68375 L F
.34342 .68178 m .34121 .68227 L .34342 .68178 L F
.591 .518 .741 r
.33901 .68259 m .33918 .68272 L .34121 .68227 L F
.466 .362 .652 r
.47517 .52378 m .47555 .52635 L .4734 .5268 L F
.474 .395 .686 r
.4734 .5268 m .47606 .53027 L .47372 .53086 L F
.4734 .5268 m .47555 .52635 L .47606 .53027 L F
.487 .67 .944 r
.34939 .69923 m .35037 .69701 L .34792 .69733 L F
.34939 .69923 m .35149 .69923 L .35037 .69701 L F
.928 .758 .651 r
.62187 .36188 m .62496 .36387 L .6248 .36011 L F
.853 .405 .133 r
.62513 .36513 m .62496 .36387 L .6215 .36545 L F
.776 .665 .741 r
.39556 .47946 m .39135 .47672 L .39367 .47528 L F
.709 .97 .736 r
.39556 .47946 m .39274 .48209 L .39345 .48225 L F
.776 .665 .741 r
.39556 .47946 m .3932 .48161 L .39135 .47672 L F
.66 .605 .782 r
.3887 .47936 m .39291 .48192 L .39274 .48209 L F
.39291 .48192 m .39345 .48225 L .39274 .48209 L F
.658 .605 .784 r
.39135 .47672 m .3932 .48161 L .3887 .47936 L F
.3932 .48161 m .39345 .48225 L .39291 .48192 L F
.3932 .48161 m .39291 .48192 L .3887 .47936 L F
.709 .97 .736 r
.3932 .48161 m .39349 .48051 L .39279 .48199 L F
.39321 .4816 m .39321 .4816 L .3932 .48161 L F
.39321 .4816 m .39349 .48051 L .3932 .48161 L F
.39556 .47946 m .395 .47974 L .39321 .4816 L F
.395 .47974 m .39349 .48051 L .39321 .4816 L F
.39556 .47946 m .39279 .48199 L .39274 .48209 L F
.776 .665 .741 r
.39556 .47946 m .39345 .48225 L .3932 .48161 L F
0 .223 .735 r
.39558 .47669 m .39556 .47946 L .39367 .47528 L F
0 0 0 r
.39617 .47931 m .39349 .48051 L .39556 .47946 L F
.917 .782 .696 r
.34261 .65091 m .34167 .65393 L .34044 .64913 L F
0 0 .156 r
.34261 .65091 m .34331 .65212 L .34458 .6492 L F
.34261 .65091 m .34167 .65393 L .34331 .65212 L F
.777 .831 .894 r
.24677 .57497 m .24883 .5764 L .25118 .57502 L F
.671 .398 .498 r
.34989 .60012 m .35348 .59797 L .35104 .59878 L F
.929 .638 .471 r
.31365 .52649 m .31619 .52778 L .3147 .52511 L F
.92 .727 .624 r
.31365 .52649 m .31539 .53036 L .31619 .52778 L F
0 0 .172 r
.3554 .66586 m .35563 .66789 L .35795 .66558 L F
.3554 .66586 m .35562 .6699 L .35563 .66789 L F
.751 .731 .834 r
.32578 .53337 m .32348 .53713 L .32163 .53285 L F
.887 .843 .796 r
.39458 .66284 m .39109 .66452 L .39345 .6619 L F
.39458 .66284 m .39248 .66612 L .39109 .66452 L F
.724 .463 0 r
.34259 .62387 m .34281 .62471 L .34326 .62683 L F
0 0 .46 r
.34326 .62683 m .34281 .62471 L .34435 .62279 L F
.797 .58 .608 r
.29171 .65551 m .29583 .65617 L .2954 .65294 L F
.727 .346 .328 r
.2979 .65059 m .29442 .64972 L .2954 .65294 L F
0 0 .428 r
.2954 .65294 m .29677 .65499 L .2979 .65059 L F
.2954 .65294 m .29583 .65617 L .29677 .65499 L F
.124 0 .26 r
.59307 .36949 m .59224 .3716 L .59224 .37118 L F
.553 .359 .572 r
.59307 .36949 m .59568 .36928 L .59588 .36639 L F
.292 .764 .937 r
.5947 .36866 m .59568 .36928 L .59307 .36949 L F
.5947 .36866 m .59307 .36949 L .59224 .37118 L F
.976 .738 .512 r
.34443 .61438 m .34266 .61541 L .34559 .61349 L F
.34443 .61438 m .3441 .61724 L .34266 .61541 L F
.391 .027 .221 r
.31565 .56255 m .31295 .56472 L .31321 .56214 L F
.568 .281 .439 r
.34515 .60443 m .34777 .6042 L .3485 .60185 L F
0 0 .036 r
.3485 .60185 m .34777 .6042 L .34989 .60012 L F
.911 .838 .381 r
.41259 .58879 m .41163 .59049 L .41182 .58775 L F
.41259 .58879 m .41192 .59147 L .41163 .59049 L F
.246 0 0 r
.24824 .52617 m .24387 .5272 L .24615 .52357 L F
.24824 .52617 m .24691 .52693 L .24679 .52651 L F
.572 .913 .695 r
.24871 .52535 m .24691 .52693 L .24824 .52617 L F
0 0 0 r
.24871 .52535 m .24701 .52728 L .24691 .52693 L F
.24701 .52728 m .24565 .52883 L .24691 .52693 L F
.246 0 0 r
.24679 .52651 m .24691 .52693 L .24387 .5272 L F
.572 .913 .695 r
.24871 .52535 m .24824 .52617 L .25054 .52642 L F
.891 .719 .662 r
.61655 .40069 m .61934 .39928 L .61655 .39798 L F
.438 .192 .442 r
.36417 .52166 m .36643 .52305 L .36715 .52068 L F
.095 .281 .762 r
.36504 .51944 m .36643 .52305 L .36417 .52166 L F
.84 .574 .535 r
.44333 .56024 m .44194 .56243 L .44005 .55922 L F
.44333 .56024 m .44405 .56317 L .44194 .56243 L F
.15 .14 .59 r
.44478 .56195 m .44333 .56024 L .44486 .55722 L F
.44478 .56195 m .44405 .56317 L .44333 .56024 L F
.98 .696 .319 r
.74424 .30821 m .74437 .31078 L .74302 .30688 L F
.74302 .30688 m .74437 .31078 L .74424 .30821 L F
.59 .416 .615 r
.36872 .57271 m .37159 .57256 L .37136 .56942 L F
.583 .649 .881 r
.37033 .57027 m .37159 .57256 L .36872 .57271 L F
.029 0 0 r
.27427 .61673 m .27297 .61725 L .27681 .61631 L F
0 .1 .656 r
.22419 .60147 m .2243 .60007 L .22226 .59789 L F
0 .103 .658 r
.22419 .60147 m .22621 .60359 L .2243 .60007 L F
.637 .466 .635 r
.7261 .33132 m .72846 .32819 L .72478 .32753 L F
.587 .012 0 r
.72846 .32819 m .73121 .32994 L .7304 .3301 L F
.72846 .32819 m .7304 .3301 L .72985 .32566 L F
.251 .73 .934 r
.70456 .31148 m .70577 .3106 L .70729 .31079 L F
.70456 .31148 m .70338 .31095 L .70577 .3106 L F
.052 0 .261 r
.2294 .55562 m .22742 .55901 L .22792 .55671 L F
.858 .928 .873 r
.37873 .65604 m .38343 .65391 L .38146 .65242 L F
.353 .697 .983 r
.38146 .65242 m .38343 .65391 L .38318 .65253 L F
.38146 .65242 m .38343 .65391 L .38318 .65253 L F
.495 .098 .216 r
.43676 .52345 m .43384 .52636 L .43125 .52638 L F
.56 .175 .27 r
.43781 .52519 m .43676 .52345 L .43804 .52387 L F
.43781 .52519 m .43384 .52636 L .43676 .52345 L F
.902 .955 .823 r
.43676 .52345 m .43805 .52108 L .43804 .52387 L F
0 0 .372 r
.30454 .63397 m .30548 .63497 L .30322 .63289 L F
.456 .778 .998 r
.30548 .63497 m .30606 .63328 L .30567 .63336 L F
0 0 .372 r
.30454 .63397 m .30529 .63647 L .30548 .63497 L F
.584 .036 0 r
.30322 .63289 m .3044 .63398 L .30365 .63383 L F
.3044 .63398 m .30548 .63497 L .30365 .63383 L F
.30322 .63289 m .30365 .63383 L .30125 .6321 L F
.623 .137 .08 r
.30125 .6321 m .30365 .63383 L .29951 .63363 L F
.249 .763 .81 r
.30319 .63374 m .30365 .63383 L .30606 .63328 L F
.176 0 0 r
.29951 .63363 m .30365 .63383 L .30207 .63392 L F
.249 .763 .81 r
.30207 .63392 m .30365 .63383 L .30319 .63374 L F
.456 .778 .998 r
.30548 .63497 m .30567 .63336 L .30365 .63383 L F
0 0 .372 r
.30529 .63647 m .30544 .63697 L .30548 .63497 L F
.948 .821 .685 r
.41516 .60123 m .41859 .5993 L .41865 .59924 L F
.788 .952 .925 r
.37205 .60635 m .37596 .60509 L .3737 .60585 L F
.599 .901 .622 r
.3784 .60274 m .37698 .60379 L .37596 .60509 L F
.498 .171 .343 r
.37698 .60379 m .3737 .60585 L .37596 .60509 L F
.37698 .60379 m .37653 .60618 L .3737 .60585 L F
.41 .583 .911 r
.3737 .60585 m .37653 .60618 L .37579 .60522 L F
.3737 .60585 m .37579 .60522 L .3751 .60434 L F
.788 .952 .925 r
.37166 .60647 m .37205 .60635 L .3737 .60585 L F
.86 .433 0 r
.39214 .54565 m .3945 .54901 L .39427 .54668 L F
.632 .276 .348 r
.52859 .47248 m .53116 .47466 L .52891 .4748 L F
.52859 .47248 m .53113 .47276 L .53116 .47466 L F
.648 .501 .669 r
.44064 .51781 m .44066 .5212 L .43805 .52108 L F
.463 .279 .544 r
.44045 .52308 m .43805 .52108 L .44066 .5212 L F
.44045 .52308 m .43804 .52387 L .43805 .52108 L F
.766 .732 .206 r
.44399 .53642 m .44227 .54042 L .44527 .53757 L F
.44289 .53665 m .44227 .54042 L .44399 .53642 L F
.44306 .5356 m .44289 .53665 L .44399 .53642 L F
.854 .618 .581 r
.44256 .53686 m .44237 .53889 L .44276 .53705 L F
.44256 .53686 m .44276 .53705 L .44306 .5356 L F
.766 .732 .206 r
.44306 .5356 m .44276 .53705 L .44289 .53665 L F
.44276 .53705 m .44243 .53861 L .44267 .53758 L F
.44276 .53705 m .44267 .53758 L .44289 .53665 L F
.768 .474 .489 r
.44128 .53566 m .44256 .53686 L .44283 .53662 L F
.766 .732 .206 r
.44255 .53873 m .44245 .53855 L .44227 .54042 L F
.44289 .53665 m .44262 .53781 L .44255 .53873 L F
.44262 .53781 m .44245 .53855 L .44255 .53873 L F
0 0 .161 r
.44294 .53803 m .44301 .54123 L .44263 .53762 L F
.44267 .5372 m .44263 .53762 L .44256 .53686 L F
.44294 .53803 m .44263 .53762 L .44267 .5372 L F
.174 0 0 r
.44584 .53541 m .44256 .53686 L .44306 .5356 L F
.768 .474 .489 r
.44294 .53594 m .44283 .53662 L .44351 .53603 L F
.44128 .53566 m .44283 .53662 L .44294 .53594 L F
.43922 .53531 m .44256 .53686 L .44128 .53566 L F
.446 0 0 r
.4425 .53555 m .44351 .53603 L .44306 .5356 L F
.43922 .53531 m .4431 .53596 L .4425 .53555 L F
.4431 .53596 m .44351 .53603 L .4425 .53555 L F
.766 .732 .206 r
.44243 .53861 m .44237 .53889 L .44289 .53665 L F
.174 0 0 r
.44584 .53541 m .44469 .53725 L .44256 .53686 L F
.122 .024 .46 r
.44284 .53651 m .44469 .53725 L .4447 .53705 L F
0 0 .35 r
.44306 .5356 m .44473 .53417 L .44584 .53541 L F
.44306 .5356 m .44351 .53603 L .44473 .53417 L F
.122 .024 .46 r
.44256 .53686 m .44473 .53417 L .44351 .53603 L F
.44322 .53604 m .4447 .53705 L .44473 .53417 L F
.44284 .53651 m .4447 .53705 L .44322 .53604 L F
.44256 .53686 m .44276 .5369 L .44284 .53651 L F
.44276 .5369 m .44469 .53725 L .44284 .53651 L F
.766 .732 .206 r
.44245 .53855 m .44237 .53889 L .44236 .539 L F
.44245 .53855 m .44236 .539 L .44227 .54042 L F
0 0 .271 r
.44301 .54123 m .44227 .54042 L .44237 .53889 L F
.452 .126 .321 r
.43886 .54188 m .44056 .53956 L .44261 .53994 L F
.676 .326 .373 r
.43871 .53751 m .43722 .53894 L .44056 .53956 L F
.44068 .53892 m .44056 .53956 L .44192 .53982 L F
.43871 .53751 m .44056 .53956 L .44068 .53892 L F
.44217 .53967 m .44211 .53995 L .44261 .53994 L F
.43871 .53751 m .44211 .53995 L .44217 .53967 L F
.43679 .5363 m .44071 .53876 L .43797 .53582 L F
.44071 .53876 m .44208 .53961 L .4412 .53869 L F
.44208 .53961 m .44261 .53994 L .44211 .5395 L F
.44208 .53961 m .44211 .5395 L .4412 .53869 L F
.452 .126 .321 r
.44056 .53956 m .4412 .53869 L .44261 .53994 L F
.4412 .53869 m .44256 .53686 L .44261 .53994 L F
.4412 .53869 m .44165 .53864 L .44256 .53686 L F
.768 .474 .489 r
.44165 .53864 m .44261 .53994 L .44256 .53686 L F
.452 .126 .321 r
.44165 .53864 m .44238 .53855 L .44256 .53686 L F
.768 .474 .489 r
.43922 .53531 m .44165 .53864 L .44256 .53686 L F
.676 .326 .373 r
.43797 .53582 m .44261 .53994 L .43922 .53531 L F
.769 .539 .585 r
.44256 .53686 m .44301 .54123 L .44237 .53889 L F
.452 .126 .321 r
.43886 .54188 m .44049 .53997 L .44042 .53976 L F
.72 .467 .542 r
.44049 .53997 m .43886 .54188 L .44261 .53994 L F
.43609 .54002 m .43886 .54188 L .44049 .53997 L F
.755 .536 .6 r
.44055 .54014 m .43886 .54188 L .44261 .53994 L F
.44055 .54014 m .44261 .53994 L .44049 .53997 L F
.676 .326 .373 r
.44192 .53982 m .43609 .54002 L .44211 .53995 L F
.452 .126 .321 r
.44177 .53889 m .44213 .54088 L .44238 .53855 L F
.44109 .53927 m .44121 .53946 L .44177 .53889 L F
.44042 .53976 m .44049 .53997 L .44056 .53956 L F
.676 .326 .373 r
.43722 .53894 m .43609 .54002 L .44192 .53982 L F
.452 .126 .321 r
.44121 .53946 m .44213 .54088 L .44177 .53889 L F
.44056 .53956 m .44072 .5397 L .44109 .53927 L F
.44072 .5397 m .44213 .54088 L .44109 .53927 L F
.43886 .54188 m .44022 .54146 L .44044 .54026 L F
.43886 .54188 m .44044 .54026 L .44049 .53997 L F
.755 .536 .6 r
.43496 .54067 m .43886 .54188 L .44055 .54014 L F
.43496 .54067 m .44055 .54014 L .43609 .54002 L F
.44055 .54014 m .44049 .53997 L .43609 .54002 L F
0 0 .059 r
.44272 .53735 m .44213 .54088 L .44294 .53803 L F
.44256 .53686 m .44238 .53855 L .44272 .53735 L F
.44238 .53855 m .44213 .54088 L .44272 .53735 L F
.676 .326 .373 r
.44071 .53876 m .4412 .53869 L .43797 .53582 L F
.452 .126 .321 r
.44056 .53956 m .44238 .53855 L .4412 .53869 L F
.44022 .54146 m .44213 .54088 L .44056 .53956 L F
.676 .326 .373 r
.43679 .5363 m .43647 .53797 L .43871 .53751 L F
.43647 .53797 m .43609 .54002 L .43871 .53751 L F
.692 .287 .274 r
.35204 .67873 m .35527 .67932 L .35401 .68052 L F
0 0 0 r
.35401 .68052 m .35527 .67932 L .35727 .67872 L F
.621 .432 .605 r
.48659 .50242 m .48276 .49945 L .48642 .49998 L F
.927 .744 .636 r
.48646 .49987 m .48659 .50242 L .48642 .49998 L F
.48706 .49828 m .48689 .49976 L .48646 .49987 L F
.48689 .49976 m .48659 .50242 L .48646 .49987 L F
.48706 .49828 m .48658 .50094 L .48659 .50242 L F
.588 .384 .572 r
.48767 .49957 m .48907 .50028 L .48658 .50094 L F
.48907 .4978 m .48907 .49922 L .48767 .49957 L F
.48907 .49922 m .48907 .50028 L .48767 .49957 L F
.725 .634 .757 r
.48907 .50028 m .48703 .50275 L .48658 .50094 L F
.48703 .50275 m .4863 .50365 L .48639 .50273 L F
.438 .136 .354 r
.48566 .5027 m .4814 .50511 L .48308 .50346 L F
.48659 .50242 m .48486 .50332 L .48566 .5027 L F
.48486 .50332 m .4814 .50511 L .48566 .5027 L F
.725 .634 .757 r
.48703 .50275 m .48639 .50273 L .48646 .50207 L F
.4868 .50181 m .48646 .50207 L .48658 .50094 L F
.48703 .50275 m .48646 .50207 L .4868 .50181 L F
.621 .432 .605 r
.48659 .50242 m .48566 .5027 L .48276 .49945 L F
.48566 .5027 m .48308 .50346 L .48301 .50259 L F
.48566 .5027 m .48301 .50259 L .48276 .49945 L F
.451 .826 .991 r
.35685 .58207 m .35788 .5821 L .35949 .58166 L F
.35788 .5821 m .36154 .58219 L .35949 .58166 L F
.826 .379 .167 r
.35949 .58166 m .36154 .58219 L .36177 .58355 L F
.834 .573 .546 r
.36154 .58219 m .36168 .58238 L .36177 .58355 L F
.36168 .58238 m .36368 .58521 L .36177 .58355 L F
.364 0 .198 r
.36177 .58355 m .36158 .58625 L .36198 .58609 L F
.36177 .58355 m .36198 .58609 L .36454 .58506 L F
.826 .379 .167 r
.35949 .58166 m .36177 .58355 L .36183 .58085 L F
.342 .068 .345 r
.36183 .58085 m .36163 .58107 L .35949 .58166 L F
.36163 .58107 m .35893 .58407 L .35949 .58166 L F
.62 .359 .501 r
.31923 .55989 m .31871 .56241 L .31565 .56255 L F
.548 .6 .858 r
.32099 .55923 m .31923 .55989 L .31759 .55702 L F
.432 .188 .442 r
.3211 .56174 m .31923 .55989 L .32099 .55923 L F
.3211 .56174 m .31871 .56241 L .31923 .55989 L F
.732 .683 .802 r
.3239 .52544 m .32524 .52753 L .32131 .52722 L F
.751 .507 .563 r
.32524 .52753 m .3209 .52982 L .32131 .52722 L F
.32524 .52753 m .32539 .53022 L .3209 .52982 L F
.634 .583 .78 r
.32695 .52364 m .32524 .52753 L .3239 .52544 L F
.32695 .52364 m .32852 .5274 L .32524 .52753 L F
.711 .476 .567 r
.32784 .52995 m .32539 .53022 L .32524 .52753 L F
.54 .813 .996 r
.34472 .68783 m .34397 .68963 L .34223 .6881 L F
.34472 .68783 m .34646 .6891 L .34397 .68963 L F
.428 .834 .638 r
.3513 .64603 m .34661 .64898 L .34978 .64658 L F
0 0 0 r
.35217 .6454 m .35367 .64327 L .3513 .64603 L F
.381 .831 .723 r
.35217 .6454 m .3513 .64603 L .34978 .64658 L F
.723 .985 .895 r
.68786 .37486 m .69048 .37203 L .68695 .37432 L F
.68786 .37486 m .69098 .37271 L .69048 .37203 L F
.663 .491 .642 r
.30624 .54708 m .3063 .54983 L .30901 .54682 L F
.662 .56 .73 r
.53178 .40822 m .53366 .40484 L .53022 .40504 L F
.965 .819 .649 r
.62101 .42853 m .6222 .43038 L .62162 .42668 L F
.941 .574 .245 r
.57962 .37918 m .57877 .38078 L .57769 .37805 L F
.57962 .37918 m .58057 .38209 L .57877 .38078 L F
.81 .782 .826 r
.62162 .42668 m .62464 .42659 L .62355 .42522 L F
.789 .912 .924 r
.62355 .42522 m .62464 .42659 L .62821 .42412 L F
.616 .371 .524 r
.48862 .49546 m .48706 .49828 L .48685 .49586 L F
.48862 .49546 m .48907 .4978 L .48706 .49828 L F
.656 .216 0 r
.40475 .53643 m .40228 .53281 L .40315 .53455 L F
.907 .552 .356 r
.61274 .42995 m .61038 .42675 L .61247 .42757 L F
.967 .666 .264 r
.60446 .40763 m .60586 .41131 L .60438 .4102 L F
.885 .455 .096 r
.60586 .41131 m .60489 .4121 L .60438 .4102 L F
.60586 .41131 m .60708 .41389 L .60489 .4121 L F
.233 .751 .777 r
.27777 .51574 m .28009 .5152 L .28237 .5149 L F
.635 .963 .896 r
.28237 .5149 m .28305 .51347 L .28464 .51373 L F
.28237 .5149 m .28009 .5152 L .28305 .51347 L F
.586 .143 .164 r
.29493 .57281 m .29287 .57486 L .29049 .57431 L F
.392 .018 .205 r
.29695 .57159 m .29287 .57486 L .29493 .57281 L F
0 0 0 r
.35464 .64198 m .35367 .64327 L .35217 .6454 L F
.519 .736 .973 r
.39109 .66452 m .39016 .66556 L .38867 .66519 L F
.735 .591 .695 r
.38867 .66519 m .39248 .66612 L .39034 .66913 L F
.38867 .66519 m .39034 .66913 L .38862 .66987 L F
.207 0 .023 r
.38912 .6667 m .39109 .66452 L .38867 .66519 L F
.529 .819 .479 r
.39171 .66384 m .39109 .66452 L .38912 .6667 L F
.39345 .6619 m .39109 .66452 L .39171 .66384 L F
.519 .736 .973 r
.39109 .66452 m .39248 .66612 L .39016 .66556 L F
.456 .316 .602 r
.37136 .56942 m .37159 .57256 L .3739 .57169 L F
.699 .223 .116 r
.37136 .56942 m .3739 .57169 L .37033 .57027 L F
.798 .957 .63 r
.67941 .35335 m .68014 .35374 L .67811 .35657 L F
.031 0 0 r
.68161 .35393 m .68014 .35374 L .67941 .35335 L F
.68161 .35393 m .68305 .35345 L .68014 .35374 L F
.466 .362 .653 r
.47606 .53027 m .47651 .53286 L .47372 .53086 L F
.361 .371 .736 r
.47372 .53086 m .47651 .53286 L .47492 .53385 L F
0 0 .464 r
.37966 .66474 m .3808 .66581 L .38216 .66251 L F
.791 .531 .543 r
.37503 .54032 m .37066 .54242 L .37242 .54353 L F
.476 .266 .515 r
.37242 .54353 m .37491 .54305 L .37503 .54032 L F
.467 .803 .999 r
.37242 .54353 m .37491 .54305 L .37066 .54242 L F
.29 .434 .833 r
.33788 .63123 m .34068 .63272 L .3402 .63044 L F
0 .09 .625 r
.26936 .62297 m .2695 .62382 L .26746 .62237 L F
.26936 .62297 m .27181 .62607 L .2695 .62382 L F
.29 .31 .709 r
.36942 .53047 m .37034 .5346 L .37226 .53302 L F
.522 .456 .723 r
.37034 .5346 m .37342 .53656 L .37226 .53302 L F
.37034 .5346 m .37126 .53776 L .37342 .53656 L F
.168 .432 .867 r
.39349 .48051 m .39451 .48268 L .39274 .48209 L F
.414 .24 .535 r
.39451 .48268 m .3932 .48533 L .39274 .48209 L F
.747 .628 .064 r
.41248 .57889 m .41236 .58252 L .41233 .58072 L F
.826 .767 .257 r
.41233 .58072 m .41236 .58252 L .41184 .58491 L F
.656 .646 .829 r
.45138 .53673 m .45271 .53235 L .44999 .53325 L F
.45138 .53673 m .45393 .53637 L .45271 .53235 L F
.658 .938 .966 r
.60843 .45916 m .60322 .46019 L .60688 .46092 L F
.557 .1 .125 r
.57557 .40996 m .57856 .41085 L .57422 .41046 L F
.491 .27 .506 r
.35108 .61433 m .35005 .61705 L .34822 .6177 L F
.976 .91 .579 r
.34919 .61614 m .35108 .61433 L .35183 .61221 L F
.34919 .61614 m .35005 .61705 L .35108 .61433 L F
.255 0 0 r
.34958 .49763 m .34517 .49685 L .34748 .49776 L F
.492 0 0 r
.34748 .49776 m .35171 .4984 L .34958 .49763 L F
.631 .226 0 r
.57965 .42206 m .57976 .42222 L .57811 .42452 L F
.542 .889 .654 r
.57811 .42452 m .57997 .42269 L .57965 .42206 L F
.631 .226 0 r
.57965 .42206 m .57997 .42269 L .57937 .42162 L F
.57965 .42206 m .57937 .42162 L .57884 .42067 L F
.57965 .42206 m .58062 .42102 L .57976 .42222 L F
.542 .889 .654 r
.57811 .42452 m .57659 .42542 L .57997 .42269 L F
.626 .959 .899 r
.67513 .38086 m .6792 .37942 L .67761 .37928 L F
.608 .937 .732 r
.68086 .37759 m .6792 .37942 L .68274 .37649 L F
.63 .962 .883 r
.67761 .37928 m .6792 .37942 L .68086 .37759 L F
.836 .69 .701 r
.34484 .68038 m .3461 .67981 L .34414 .67856 L F
.747 .628 .064 r
.41248 .57889 m .41233 .58072 L .41224 .57798 L F
.927 .907 .783 r
.38805 .5983 m .38853 .59398 L .38875 .59436 L F
.83 .388 0 r
.39671 .5207 m .39912 .52395 L .39774 .52277 L F
.914 .546 .106 r
.39912 .52395 m .39854 .5255 L .39774 .52277 L F
.39912 .52395 m .39975 .5268 L .39854 .5255 L F
.987 .798 .405 r
.74485 .3133 m .74457 .31584 L .74568 .31479 L F
.598 .372 .545 r
.49592 .49535 m .4959 .49808 L .49317 .49823 L F
.514 .295 .52 r
.49856 .49479 m .4959 .49808 L .49592 .49535 L F
0 0 .486 r
.38689 .68369 m .38743 .68585 L .38869 .68766 L F
.831 .809 .321 r
.38743 .68585 m .38665 .68837 L .38869 .68766 L F
.794 .905 .505 r
.42126 .5818 m .42454 .57622 L .42167 .58054 L F
.44 .556 .876 r
.42454 .57622 m .42628 .57589 L .42528 .57818 L F
.494 .119 .257 r
.42167 .58054 m .42454 .57622 L .42528 .57818 L F
.337 .471 .848 r
.28152 .6266 m .28017 .62728 L .27778 .62289 L F
.11 0 .378 r
.28152 .6266 m .28123 .62929 L .28017 .62728 L F
.89 .721 .665 r
.38264 .60765 m .3837 .61164 L .38106 .60756 L F
.948 .592 .239 r
.38106 .60756 m .38313 .61075 L .38228 .61098 L F
.721 .628 .754 r
.38658 .60807 m .3837 .61164 L .38264 .60765 L F
.946 .609 .351 r
.38106 .60756 m .38228 .61098 L .38054 .6118 L F
.767 .983 .734 r
.38097 .61134 m .38228 .61098 L .38339 .60872 L F
.38054 .6118 m .38228 .61098 L .38097 .61134 L F
.948 .592 .239 r
.38313 .61075 m .3837 .61164 L .38228 .61098 L F
0 0 .283 r
.3837 .61164 m .38339 .60872 L .38228 .61098 L F
.3837 .61164 m .38434 .61376 L .38339 .60872 L F
.738 .981 .912 r
.32807 .49516 m .3259 .49693 L .32486 .49661 L F
.529 .249 .435 r
.38371 .66637 m .38216 .66251 L .3808 .66581 L F
.38371 .66637 m .38529 .6622 L .38216 .66251 L F
.791 .531 .543 r
.37503 .54032 m .37491 .54305 L .37066 .54242 L F
.451 .246 .51 r
.3776 .53974 m .37491 .54305 L .37503 .54032 L F
.37503 .54032 m .37491 .54305 L .3776 .53974 L F
.223 .539 .926 r
.36287 .69999 m .36634 .70191 L .36493 .70018 L F
.214 0 0 r
.36102 .70091 m .36287 .69999 L .36493 .70018 L F
.425 .715 .985 r
.36634 .70191 m .36987 .70295 L .3682 .70168 L F
0 .379 .746 r
.36987 .70295 m .37135 .70332 L .3682 .70168 L F
.36987 .70295 m .37299 .70421 L .37135 .70332 L F
.678 .419 .522 r
.25619 .5749 m .25788 .57264 L .25402 .57291 L F
0 .563 .715 r
.33926 .49476 m .33451 .49459 L .33704 .49465 L F
.752 .287 .145 r
.33704 .49465 m .34096 .4959 L .33926 .49476 L F
.467 .191 .411 r
.25118 .57502 m .25356 .57502 L .25402 .57291 L F
.953 .616 .224 r
.39547 .49532 m .39427 .49461 L .39364 .49176 L F
.855 .803 .799 r
.61701 .40462 m .61655 .40069 L .61607 .40357 L F
0 .355 .793 r
.62231 .40711 m .61701 .40462 L .61607 .40357 L F
.615 .929 .967 r
.60478 .34952 m .6025 .35077 L .60054 .35029 L F
.59 .94 .782 r
.3051 .63904 m .30335 .64041 L .30025 .64167 L F
.928 .758 .651 r
.62187 .36188 m .6248 .36011 L .62148 .35874 L F
.761 .677 .769 r
.74276 .3019 m .74564 .29834 L .74147 .29793 L F
.561 .3 .478 r
.36658 .63555 m .3712 .63119 L .36827 .63601 L F
0 .163 .701 r
.33391 .63864 m .33216 .63801 L .33423 .63609 L F
.33391 .63864 m .33329 .63964 L .33216 .63801 L F
.5 .892 .951 r
.56904 .46439 m .57342 .46379 L .5722 .46254 L F
.663 .872 .977 r
.5722 .46254 m .57342 .46379 L .57588 .46262 L F
0 .082 .64 r
.3914 .65925 m .39345 .6619 L .39212 .65834 L F
0 .276 .778 r
.70263 .30871 m .70022 .30813 L .7023 .30604 L F
.70263 .30871 m .70338 .31095 L .70022 .30813 L F
.214 0 0 r
.34594 .65256 m .34594 .65388 L .34436 .6552 L F
.34594 .65256 m .34836 .65223 L .34594 .65388 L F
.913 .831 .751 r
.60843 .45916 m .60985 .45724 L .60791 .45531 L F
.733 .617 .728 r
.24357 .60136 m .24447 .60479 L .24759 .60467 L F
.871 .68 .642 r
.2432 .60671 m .24759 .60467 L .24447 .60479 L F
.796 .721 .781 r
.53008 .39178 m .53147 .39544 L .53407 .39206 L F
.678 .419 .522 r
.25619 .5749 m .25402 .57291 L .25356 .57502 L F
.736 .603 .709 r
.69568 .31412 m .69146 .31207 L .69398 .31102 L F
.69568 .31412 m .69144 .31508 L .69146 .31207 L F
.412 0 .013 r
.69568 .31412 m .69428 .31584 L .69144 .31508 L F
.714 .275 .206 r
.69568 .31412 m .69848 .31648 L .69428 .31584 L F
.932 .798 .69 r
.55843 .40611 m .55899 .40863 L .55916 .40642 L F
.693 .759 .264 r
.55899 .40863 m .55884 .40881 L .55916 .40642 L F
0 0 .268 r
.55991 .40675 m .55916 .40642 L .55884 .40881 L F
.56104 .40456 m .55916 .40642 L .55991 .40675 L F
.932 .798 .69 r
.55781 .40329 m .55843 .40611 L .55916 .40642 L F
.693 .759 .264 r
.55899 .40863 m .55813 .41102 L .55884 .40881 L F
.785 .706 .776 r
.35608 .53616 m .35796 .5421 L .3535 .53943 L F
.811 .565 .568 r
.3578 .54269 m .3535 .53943 L .35796 .5421 L F
.167 0 0 r
.36041 .54186 m .3578 .54269 L .35796 .5421 L F
.934 .659 .494 r
.60325 .43884 m .60527 .43725 L .6034 .43614 L F
.60325 .43884 m .60518 .43985 L .60527 .43725 L F
.731 .392 .406 r
.64514 .38425 m .64612 .38241 L .64213 .38174 L F
.959 .717 .527 r
.64612 .38241 m .64608 .38524 L .64514 .38425 L F
.64612 .38241 m .64608 .38524 L .64514 .38425 L F
.807 .95 .914 r
.38174 .67421 m .38704 .67215 L .38601 .67439 L F
.758 .994 .806 r
.38704 .67215 m .39034 .66913 L .38862 .66987 L F
.38704 .67215 m .38862 .66987 L .38857 .67136 L F
0 0 0 r
.38601 .67439 m .38704 .67215 L .38857 .67136 L F
.85 .46 .305 r
.23313 .5459 m .23576 .54701 L .23389 .54469 L F
.478 .445 .743 r
.23389 .54469 m .23576 .54701 L .23724 .54589 L F
.974 .698 .441 r
.27046 .63338 m .27205 .63658 L .27071 .63512 L F
.058 .521 .893 r
.27205 .63658 m .27248 .63585 L .27071 .63512 L F
.27205 .63658 m .2746 .63727 L .27248 .63585 L F
.663 .835 .966 r
.64767 .38907 m .64191 .38794 L .64627 .38784 L F
.702 .935 .624 r
.64912 .38672 m .65041 .38584 L .64767 .38907 L F
.637 .866 .985 r
.64912 .38672 m .64767 .38907 L .64627 .38784 L F
.268 0 .148 r
.43764 .53439 m .43922 .53531 L .44069 .53382 L F
.43764 .53439 m .43679 .5363 L .43922 .53531 L F
.762 .827 .903 r
.48726 .43787 m .48264 .43888 L .48564 .43622 L F
.772 .819 .89 r
.48564 .43622 m .48946 .43642 L .48726 .43787 L F
.497 .829 .534 r
.41368 .47264 m .41021 .47584 L .41277 .47344 L F
.37 .396 .758 r
.41153 .47808 m .41277 .47344 L .41021 .47584 L F
.41153 .47808 m .41342 .47719 L .41277 .47344 L F
.659 .947 .704 r
.23846 .60795 m .23918 .60654 L .24098 .60572 L F
.407 0 0 r
.24098 .60572 m .23918 .60654 L .2432 .60671 L F
.409 0 .106 r
.24098 .60572 m .2432 .60671 L .24447 .60479 L F
.631 .77 .947 r
.38162 .6021 m .3784 .60274 L .37649 .60086 L F
.328 0 0 r
.3784 .60274 m .3793 .60325 L .37698 .60379 L F
.3784 .60274 m .38139 .60417 L .3793 .60325 L F
.499 .158 .32 r
.38162 .6021 m .38166 .60398 L .3784 .60274 L F
.8 .649 .695 r
.38254 .60391 m .38202 .60445 L .38139 .60417 L F
.499 .158 .32 r
.38166 .60398 m .38166 .6043 L .38139 .60417 L F
.38166 .60398 m .38139 .60417 L .3784 .60274 L F
.699 .316 .319 r
.38254 .60391 m .38166 .6043 L .38166 .60398 L F
.38254 .60391 m .38166 .60398 L .38162 .6021 L F
.8 .649 .695 r
.38192 .60379 m .38166 .60398 L .3793 .60325 L F
.38166 .60398 m .38139 .60417 L .38106 .60402 L F
.38166 .60398 m .38106 .60402 L .3793 .60325 L F
.38254 .60391 m .38139 .60417 L .38192 .60379 L F
.38202 .60445 m .38031 .60622 L .3793 .60325 L F
.328 0 0 r
.38139 .60417 m .38166 .6043 L .3793 .60325 L F
.164 0 0 r
.34625 .54731 m .34493 .54865 L .34894 .54678 L F
.774 .685 .765 r
.32726 .55283 m .32343 .55282 L .32574 .54919 L F
.631 .489 .671 r
.32661 .55531 m .32343 .55282 L .32726 .55283 L F
.424 .13 .36 r
.32914 .5546 m .32726 .55283 L .32946 .55178 L F
.32914 .5546 m .32661 .55531 L .32726 .55283 L F
.726 .823 .925 r
.49632 .43419 m .49245 .43386 L .49465 .43234 L F
.773 .739 .821 r
.49936 .43155 m .49632 .43419 L .49465 .43234 L F
.502 .361 .621 r
.44379 .57913 m .44502 .58171 L .44576 .58066 L F
.879 .657 .597 r
.44585 .57633 m .44673 .57988 L .44347 .57801 L F
0 .019 .562 r
.44765 .57696 m .44673 .57988 L .44585 .57633 L F
.954 .606 .25 r
.44673 .57988 m .44509 .58026 L .44347 .57801 L F
.491 .821 1 r
.44509 .58026 m .44623 .57999 L .44765 .57696 L F
.44623 .57999 m .44673 .57988 L .44707 .57879 L F
.44623 .57999 m .44707 .57879 L .44765 .57696 L F
.502 .361 .621 r
.44379 .57913 m .44414 .58194 L .44502 .58171 L F
.44576 .58066 m .44502 .58171 L .4466 .58131 L F
.996 .838 .569 r
.44552 .5696 m .44493 .57223 L .44371 .57108 L F
.79 .372 .256 r
.44371 .57108 m .44703 .57197 L .44552 .5696 L F
.646 .861 .981 r
.37342 .53656 m .37126 .53776 L .36945 .53625 L F
.544 .342 .556 r
.33188 .55401 m .33479 .55116 L .33416 .55332 L F
.353 .442 .813 r
.31664 .53686 m .3182 .54053 L .31924 .53902 L F
.317 .172 .52 r
.31742 .54315 m .31924 .53902 L .3182 .54053 L F
.957 .715 .264 r
.40561 .54022 m .40485 .5392 L .40475 .53643 L F
.926 .556 .144 r
.40561 .54022 m .40485 .54167 L .40485 .5392 L F
.40561 .54022 m .4065 .54314 L .40485 .54167 L F
.866 .991 .733 r
.32703 .61221 m .32688 .61412 L .32855 .61129 L F
0 .001 .511 r
.32799 .61517 m .32688 .61412 L .32703 .61221 L F
.32799 .61517 m .32902 .61628 L .32688 .61412 L F
.879 .657 .597 r
.44585 .57633 m .44347 .57801 L .44495 .57479 L F
0 .019 .562 r
.44765 .57696 m .44585 .57633 L .44915 .57532 L F
.423 .419 .751 r
.3575 .55867 m .35554 .56042 L .35485 .55358 L F
.19 0 .176 r
.34442 .5243 m .34165 .52724 L .34376 .52627 L F
0 0 .406 r
.34442 .5243 m .34519 .52526 L .34384 .52301 L F
.458 .779 .998 r
.34376 .52627 m .34519 .52526 L .34442 .5243 L F
.995 .869 .58 r
.32995 .6134 m .32902 .61628 L .32799 .61517 L F
.587 .571 .803 r
.33314 .61867 m .32902 .61628 L .33339 .61686 L F
.566 0 0 r
.33269 .61801 m .32799 .61517 L .32902 .61628 L F
.862 .48 .322 r
.33519 .61724 m .3334 .61849 L .33339 .61686 L F
.3334 .61849 m .33319 .61835 L .33339 .61686 L F
.33519 .61724 m .33528 .61911 L .33314 .61867 L F
.566 0 0 r
.33432 .61878 m .33129 .61705 L .33269 .61801 L F
.33129 .61705 m .32799 .61517 L .33269 .61801 L F
.862 .48 .322 r
.3334 .61849 m .33314 .61867 L .33319 .61835 L F
0 0 0 r
.31416 .55712 m .31161 .55917 L .31404 .55732 L F
.186 0 0 r
.31404 .55732 m .31678 .55736 L .31416 .55712 L F
.161 0 0 r
.31416 .55712 m .31678 .55736 L .31759 .55702 L F
.807 .936 .915 r
.6274 .41105 m .63162 .40938 L .63065 .40723 L F
.666 .936 .658 r
.63606 .40838 m .63466 .4104 L .63449 .41033 L F
0 .373 .686 r
.63443 .4103 m .63466 .4104 L .63463 .41036 L F
.63162 .40938 m .63466 .4104 L .63443 .4103 L F
.666 .936 .658 r
.63449 .41033 m .63466 .4104 L .63426 .41062 L F
0 .373 .686 r
.63162 .40938 m .63443 .4103 L .63065 .40723 L F
.63443 .4103 m .63447 .41023 L .63065 .40723 L F
.705 .758 .893 r
.63187 .40764 m .63446 .4102 L .63606 .40838 L F
.666 .936 .658 r
.63477 .40968 m .63453 .41013 L .63445 .41001 L F
.63453 .41013 m .63447 .41023 L .63446 .4102 L F
.63453 .41013 m .63446 .4102 L .63445 .41001 L F
.63606 .40838 m .63426 .41062 L .63477 .40968 L F
.705 .758 .893 r
.63446 .4102 m .63463 .41036 L .63606 .40838 L F
.603 .835 .454 r
.63463 .41036 m .63466 .4104 L .63606 .40838 L F
.527 .3 .513 r
.63566 .41083 m .63606 .40838 L .63445 .41001 L F
0 .186 .68 r
.63447 .41023 m .63463 .41036 L .63446 .4102 L F
.666 .936 .658 r
.63445 .41001 m .63426 .41062 L .63337 .41109 L F
.63447 .41023 m .63426 .41062 L .63445 .41001 L F
0 .373 .686 r
.63443 .4103 m .63463 .41036 L .63447 .41023 L F
.905 .93 .82 r
.63466 .4104 m .63221 .41379 L .63094 .41272 L F
.527 .3 .513 r
.63556 .41084 m .63445 .41001 L .63337 .41109 L F
.63566 .41083 m .63445 .41001 L .63556 .41084 L F
0 .186 .68 r
.63065 .40723 m .63447 .41023 L .63364 .40941 L F
.705 .758 .893 r
.63187 .40764 m .63606 .40838 L .63398 .40623 L F
0 0 0 r
.63256 .40785 m .63187 .40764 L .63359 .40673 L F
0 .186 .68 r
.63086 .40732 m .63364 .40941 L .63187 .40764 L F
.63065 .40723 m .63364 .40941 L .6308 .40728 L F
.63447 .41023 m .63446 .4102 L .63187 .40764 L F
0 0 0 r
.63106 .40947 m .63187 .40764 L .63256 .40785 L F
0 .186 .68 r
.6308 .40728 m .63086 .40732 L .63187 .40764 L F
.275 .28 .683 r
.47564 .55612 m .47816 .55832 L .47588 .55945 L F
0 0 .112 r
.47816 .55832 m .47622 .56186 L .47588 .55945 L F
.908 .656 .154 r
.40891 .55271 m .40813 .55196 L .4079 .54903 L F
.743 .47 0 r
.40891 .55271 m .40909 .55418 L .40813 .55196 L F
.40891 .55271 m .40956 .55576 L .40909 .55418 L F
.699 .75 .891 r
.649 .38217 m .65041 .38584 L .64608 .38524 L F
.526 0 0 r
.64608 .38524 m .65041 .38584 L .64912 .38672 L F
.831 .8 .821 r
.65127 .38089 m .65041 .38584 L .649 .38217 L F
.65127 .38089 m .65318 .38258 L .65041 .38584 L F
.897 .891 .815 r
.35282 .6745 m .35204 .67873 L .35146 .67666 L F
0 .184 .714 r
.35204 .67873 m .35261 .67818 L .35146 .67666 L F
.35204 .67873 m .35401 .68052 L .35261 .67818 L F
.516 .67 .933 r
.26608 .6284 m .2707 .6306 L .26903 .62924 L F
0 0 0 r
.2707 .6306 m .27069 .63187 L .26903 .62924 L F
0 0 .307 r
.27046 .63338 m .27127 .63399 L .27069 .63187 L F
.727 .436 0 r
.27069 .63187 m .27093 .63323 L .27069 .63296 L F
0 0 0 r
.27069 .63072 m .27046 .63338 L .27069 .63187 L F
.727 .436 0 r
.27069 .63187 m .27069 .63296 L .26904 .63105 L F
0 0 0 r
.2707 .6306 m .27069 .63072 L .27069 .63187 L F
.557 .922 .758 r
.34424 .61998 m .34822 .6177 L .3467 .6174 L F
.555 .894 .982 r
.34822 .6177 m .34919 .61614 L .3467 .6174 L F
.34822 .6177 m .35005 .61705 L .34919 .61614 L F
.728 .855 .941 r
.24218 .61374 m .24602 .61375 L .24449 .61244 L F
.681 .504 .64 r
.24218 .61374 m .2459 .61603 L .24602 .61375 L F
.531 .204 .358 r
.2459 .61603 m .2485 .61609 L .24602 .61375 L F
.17 0 0 r
.33526 .56503 m .33706 .56505 L .33874 .56367 L F
.758 .938 .596 r
.33874 .56367 m .33706 .56505 L .33848 .56291 L F
.653 .849 .975 r
.53407 .39206 m .53008 .39178 L .53258 .3907 L F
.796 .721 .781 r
.53008 .39178 m .53407 .39206 L .53258 .3907 L F
.747 .452 .483 r
.44897 .5618 m .45276 .56201 L .45308 .55967 L F
.543 .313 .516 r
.45276 .56201 m .45561 .55907 L .45308 .55967 L F
.45561 .55907 m .45276 .56201 L .45308 .55967 L F
.392 .767 .992 r
.59853 .36821 m .59967 .36996 L .59568 .36928 L F
.677 .14 0 r
.59853 .36821 m .60308 .36951 L .59967 .36996 L F
.398 .453 .801 r
.60309 .37206 m .59967 .36996 L .60308 .36951 L F
0 0 0 r
.2466 .57531 m .24608 .57735 L .24507 .5782 L F
.4 .289 .611 r
.24608 .57735 m .24439 .58083 L .24507 .5782 L F
.24608 .57735 m .2465 .58028 L .24439 .58083 L F
.974 .688 .421 r
.24483 .5771 m .24571 .57878 L .24608 .57735 L F
.24571 .57878 m .2465 .58028 L .24608 .57735 L F
0 0 0 r
.24677 .57497 m .24608 .57735 L .2466 .57531 L F
.965 .683 .45 r
.36696 .51765 m .36715 .52068 L .36504 .51944 L F
.786 .656 .719 r
.33113 .52418 m .32852 .5274 L .32695 .52364 L F
.498 0 0 r
.36887 .55748 m .37142 .55957 L .37152 .55912 L F
.289 .101 .443 r
.37031 .56206 m .37152 .55912 L .37142 .55957 L F
.979 .906 .662 r
.41193 .56346 m .41122 .56594 L .41057 .56391 L F
0 0 .295 r
.41122 .56594 m .41196 .5672 L .41057 .56391 L F
.41122 .56594 m .41197 .56836 L .41196 .5672 L F
.777 .953 .627 r
.39206 .60721 m .39473 .60425 L .39371 .6035 L F
.39206 .60721 m .3922 .60773 L .39473 .60425 L F
.826 .871 .878 r
.38647 .48229 m .38717 .47899 L .3887 .47936 L F
.789 .995 .869 r
.39135 .47672 m .3887 .47936 L .38945 .4772 L F
.751 .969 .93 r
.3887 .47936 m .38717 .47899 L .38945 .4772 L F
.678 .596 .757 r
.45943 .54344 m .46352 .5467 L .4615 .54253 L F
.418 .358 .684 r
.46352 .5467 m .46492 .54332 L .4615 .54253 L F
.46352 .5467 m .46568 .54601 L .46492 .54332 L F
.307 .239 .615 r
.46415 .54981 m .46568 .54601 L .46352 .5467 L F
0 0 0 r
.336 .64622 m .34113 .64298 L .33977 .64648 L F
0 .431 .731 r
.33927 .64234 m .34296 .64347 L .34113 .64298 L F
.953 .767 .615 r
.33977 .64648 m .34113 .64298 L .33927 .64234 L F
.883 .863 .814 r
.43364 .50669 m .4378 .50401 L .43678 .50476 L F
.254 0 0 r
.44044 .50384 m .43678 .50476 L .4378 .50401 L F
.979 .906 .662 r
.41193 .56346 m .41057 .56391 L .41104 .56207 L F
.317 .199 .557 r
.34975 .56837 m .34702 .57016 L .34584 .56812 L F
.34975 .56837 m .34965 .57093 L .34702 .57016 L F
.398 .835 .948 r
.28602 .51809 m .2844 .51773 L .28199 .51832 L F
.433 .779 .997 r
.28873 .51853 m .2844 .51773 L .28602 .51809 L F
.899 .546 .365 r
.605 .44516 m .6066 .44334 L .60502 .44249 L F
.605 .44516 m .60772 .44604 L .6066 .44334 L F
.568 .918 .961 r
.29356 .51644 m .29285 .51798 L .29527 .51731 L F
.29356 .51644 m .29124 .51754 L .29285 .51798 L F
.513 .144 .277 r
.34528 .59081 m .34098 .59167 L .34212 .5905 L F
.875 .862 .823 r
.33708 .56615 m .33268 .56831 L .33526 .56503 L F
0 0 .344 r
.36317 .69551 m .36335 .69441 L .36071 .69452 L F
.388 .319 .658 r
.47651 .53286 m .47567 .53967 L .47492 .53385 L F
.769 .763 .847 r
.38342 .60029 m .38498 .60157 L .38162 .6021 L F
.699 .316 .319 r
.38254 .60391 m .38498 .60157 L .385 .60441 L F
.38254 .60391 m .38162 .6021 L .38498 .60157 L F
.558 .587 .839 r
.38641 .59743 m .38498 .60157 L .38342 .60029 L F
.38641 .59743 m .38779 .60102 L .38498 .60157 L F
.472 .229 .464 r
.38779 .60102 m .38619 .60325 L .38498 .60157 L F
.344 .196 .531 r
.38619 .60325 m .385 .60441 L .38498 .60157 L F
.38619 .60325 m .385 .60441 L .38498 .60157 L F
.548 .6 .858 r
.32099 .55923 m .31759 .55702 L .32122 .55636 L F
.286 0 0 r
.31678 .55736 m .32122 .55636 L .31759 .55702 L F
.31678 .55736 m .31889 .5575 L .32122 .55636 L F
.772 .935 .582 r
.32122 .55636 m .32174 .5545 L .32343 .55282 L F
.764 .985 .744 r
.32122 .55636 m .31889 .5575 L .32174 .5545 L F
.573 .381 .582 r
.32368 .55841 m .32122 .55636 L .3236 .5557 L F
.32368 .55841 m .32099 .55923 L .32122 .55636 L F
.485 .523 .821 r
.43246 .58533 m .43545 .58646 L .43364 .58442 L F
.638 .87 .985 r
.43364 .58442 m .43083 .58476 L .43246 .58533 L F
.792 .973 .911 r
.25159 .52024 m .25603 .51833 L .25223 .52032 L F
.377 0 .021 r
.33203 .53048 m .33097 .53232 L .32877 .53199 L F
.947 .94 .609 r
.33351 .52556 m .33203 .53048 L .33499 .52747 L F
.951 .845 .417 r
.33154 .52951 m .33097 .53232 L .33203 .53048 L F
.434 .037 .185 r
.44981 .51693 m .4476 .51751 L .44747 .51664 L F
.983 .699 .381 r
.60533 .36973 m .60648 .3698 L .60505 .37067 L F
.989 .889 .618 r
.60686 .36637 m .60648 .3698 L .60533 .36973 L F
.643 .111 0 r
.60505 .37067 m .60648 .3698 L .60813 .37128 L F
.424 .202 .47 r
.60813 .37128 m .60648 .3698 L .6093 .36881 L F
.533 .473 .735 r
.6093 .36881 m .60648 .3698 L .60686 .36637 L F
.681 .323 .36 r
.5377 .47244 m .54169 .47242 L .5405 .47489 L F
.551 .194 .315 r
.54169 .47242 m .54415 .47435 L .5405 .47489 L F
.54169 .47242 m .54432 .47241 L .54415 .47435 L F
.774 .644 .718 r
.311 .60423 m .3089 .60441 L .31097 .60154 L F
.509 .232 .429 r
.311 .60423 m .30826 .60749 L .3089 .60441 L F
.475 .117 .278 r
.30981 .60645 m .31199 .605 L .31073 .60476 L F
.407 .403 .742 r
.31199 .605 m .31399 .60452 L .31097 .60154 L F
.495 .418 .699 r
.31097 .60154 m .31399 .60452 L .31117 .60424 L F
.31097 .60154 m .31117 .60424 L .311 .60423 L F
.755 .616 .705 r
.31117 .60425 m .31199 .605 L .31168 .60396 L F
.31119 .60451 m .31199 .605 L .31117 .60425 L F
.475 .117 .278 r
.30826 .60749 m .3109 .6075 L .31199 .605 L F
.226 0 .16 r
.31199 .605 m .31318 .60641 L .31399 .60452 L F
.31199 .605 m .3109 .6075 L .31318 .60641 L F
.37 .124 .405 r
.31318 .60641 m .31107 .6043 L .31399 .60452 L F
.31107 .6043 m .311 .60423 L .31117 .60424 L F
.31107 .6043 m .31117 .60424 L .31399 .60452 L F
.755 .616 .705 r
.31119 .60423 m .31168 .60396 L .31165 .60384 L F
.31117 .60425 m .31168 .60396 L .31119 .60423 L F
.31099 .6044 m .31119 .60451 L .31117 .60425 L F
.3106 .60473 m .31073 .60476 L .31099 .6044 L F
.31073 .60476 m .31199 .605 L .31099 .6044 L F
.37 .124 .405 r
.31318 .60641 m .3109 .6075 L .31099 .6044 L F
.31105 .60432 m .31099 .6044 L .311 .60426 L F
.31318 .60641 m .31099 .6044 L .31105 .60432 L F
.31101 .60424 m .311 .60426 L .311 .60423 L F
.31318 .60641 m .311 .60426 L .31101 .60424 L F
.475 .117 .278 r
.30826 .60749 m .30981 .60645 L .3106 .60473 L F
.30981 .60645 m .31073 .60476 L .3106 .60473 L F
.509 .232 .429 r
.31051 .60481 m .31051 .60483 L .30826 .60749 L F
.475 .117 .278 r
.30826 .60749 m .3106 .60473 L .3089 .60441 L F
.509 .232 .429 r
.31051 .60483 m .3109 .6075 L .30826 .60749 L F
.311 .60423 m .31099 .6044 L .31051 .60481 L F
.31099 .6044 m .3109 .6075 L .31051 .60481 L F
.755 .616 .705 r
.3089 .60441 m .3106 .60473 L .31097 .60154 L F
.3106 .60473 m .31165 .60384 L .31097 .60154 L F
.049 0 0 r
.2849 .57552 m .28434 .57588 L .28149 .57634 L F
.284 .763 .657 r
.28755 .57438 m .28628 .57492 L .2849 .57552 L F
0 0 0 r
.28628 .57492 m .28434 .57588 L .2849 .57552 L F
.43171 .46262 m .43208 .46238 L .43431 .45946 L F
.43171 .46262 m .43101 .46427 L .43208 .46238 L F
.78 .429 .392 r
.22478 .57579 m .22782 .57793 L .22808 .57535 L F
0 0 .438 r
.22578 .57667 m .22478 .57579 L .22491 .5748 L F
.78 .429 .392 r
.22478 .57579 m .22572 .57794 L .22782 .57793 L F
0 0 .438 r
.22578 .57667 m .22572 .57794 L .22478 .57579 L F
0 .097 .653 r
.42534 .54511 m .42668 .54782 L .42448 .54471 L F
.108 .358 .823 r
.42741 .54593 m .42668 .54782 L .42534 .54511 L F
.75 .32 .228 r
.42293 .54448 m .42628 .54556 L .42534 .54511 L F
.42628 .54556 m .42741 .54593 L .42534 .54511 L F
0 .097 .653 r
.42534 .54511 m .42448 .54471 L .42421 .54432 L F
.952 .901 .519 r
.39081 .60926 m .39119 .61145 L .3922 .60773 L F
.806 .919 .532 r
.39081 .60926 m .3922 .60773 L .39206 .60721 L F
.755 .343 .269 r
.3686 .63227 m .36875 .63072 L .36617 .63032 L F
.577 .18 .254 r
.3686 .63227 m .37142 .63114 L .36875 .63072 L F
.401 .847 .92 r
.60478 .34952 m .60744 .34878 L .60849 .34907 L F
.406 .851 .921 r
.60849 .34907 m .61006 .34803 L .61127 .34782 L F
.60849 .34907 m .60744 .34878 L .61006 .34803 L F
.118 .243 .719 r
.57924 .4173 m .58062 .42102 L .57884 .42067 L F
.631 .226 0 r
.57965 .42206 m .57884 .42067 L .58062 .42102 L F
.833 .684 .698 r
.72335 .32345 m .72478 .32753 L .72647 .32419 L F
.921 .529 .217 r
.702 .28224 m .70286 .27954 L .703 .28025 L F
.702 .28224 m .7001 .28074 L .70286 .27954 L F
.117 .108 .571 r
.70304 .28266 m .702 .28224 L .703 .28025 L F
.392 .455 .806 r
.3461 .5144 m .34636 .50978 L .34441 .51036 L F
.3461 .5144 m .34788 .51359 L .34636 .50978 L F
.659 .487 .641 r
.23981 .61721 m .24218 .61374 L .23998 .61429 L F
.628 .798 .362 r
.33946 .57842 m .3381 .58077 L .3373 .58225 L F
.435 .462 .788 r
.3381 .58077 m .33676 .58488 L .3373 .58225 L F
.647 .266 .309 r
.35794 .55247 m .35485 .55358 L .35386 .55294 L F
.35794 .55247 m .35613 .55501 L .35485 .55358 L F
.751 .526 0 r
.35794 .55247 m .35805 .55424 L .35613 .55501 L F
.35794 .55247 m .35861 .55696 L .35805 .55424 L F
.657 .938 .966 r
.3434 .55016 m .34408 .54821 L .34493 .54865 L F
.3434 .55016 m .34183 .54951 L .34408 .54821 L F
.306 .066 .377 r
.34443 .54207 m .34146 .54587 L .34257 .54379 L F
.874 .994 .774 r
.61055 .35704 m .60824 .35985 L .60848 .35896 L F
0 0 0 r
.60843 .35974 m .60824 .35985 L .61055 .35704 L F
0 0 .096 r
.60824 .35985 m .60742 .36223 L .60889 .36053 L F
0 0 0 r
.60798 .3603 m .60824 .35985 L .60843 .35974 L F
0 0 .096 r
.60824 .35985 m .60889 .36053 L .60865 .3596 L F
.568 .552 .796 r
.60848 .35896 m .6086 .35881 L .60901 .35674 L F
0 0 0 r
.60874 .35814 m .61055 .35704 L .60901 .35674 L F
.568 .552 .796 r
.60848 .35896 m .60859 .35894 L .6086 .35881 L F
0 0 0 r
.60843 .35974 m .60856 .35957 L .60858 .35823 L F
.60856 .35957 m .61055 .35704 L .61013 .3573 L F
.60856 .35957 m .61013 .3573 L .60859 .35894 L F
.629 .422 .583 r
.60889 .36053 m .61381 .35785 L .60859 .35894 L F
.6085 .35904 m .60859 .35894 L .60848 .35896 L F
.60889 .36053 m .60859 .35894 L .6085 .35904 L F
0 0 0 r
.60859 .35894 m .61013 .3573 L .60864 .3582 L F
.60856 .35957 m .60864 .3582 L .60858 .35823 L F
.64 .928 .973 r
.60901 .35674 m .61055 .35704 L .61276 .35572 L F
.60901 .35674 m .61055 .35704 L .61276 .35572 L F
.568 .552 .796 r
.6086 .35881 m .61381 .35785 L .61174 .35498 L F
.60859 .35894 m .61381 .35785 L .6086 .35881 L F
.6086 .35881 m .61174 .35498 L .60901 .35674 L F
0 0 0 r
.60858 .35823 m .60874 .35814 L .60901 .35674 L F
0 0 .096 r
.60824 .35985 m .60843 .35974 L .60848 .35896 L F
.60843 .35974 m .6085 .35904 L .60848 .35896 L F
0 0 0 r
.60798 .3603 m .60843 .35974 L .60858 .35823 L F
0 0 .096 r
.60843 .35974 m .60865 .3596 L .6085 .35904 L F
.267 .305 .716 r
.36526 .68155 m .366 .68623 L .36783 .68386 L F
0 0 .001 r
.23158 .55215 m .2294 .55562 L .23033 .55341 L F
0 0 0 r
.22693 .58048 m .22622 .5822 L .22782 .57793 L F
0 .142 .666 r
.22693 .58048 m .22823 .58446 L .22622 .5822 L F
.312 .224 .592 r
.22622 .5822 m .22823 .58446 L .22647 .58441 L F
.41 .46 .802 r
.47435 .54952 m .47713 .55236 L .47522 .55338 L F
.283 .161 .531 r
.47713 .55236 m .47564 .55612 L .47522 .55338 L F
.468 .597 .898 r
.34573 .69744 m .34614 .69423 L .34379 .69528 L F
.34573 .69744 m .34792 .69733 L .34614 .69423 L F
.51 .372 .629 r
.29676 .63028 m .29863 .62702 L .29664 .62749 L F
.435 .052 .211 r
.3362 .5362 m .33884 .53586 L .33987 .53369 L F
.338 .429 .807 r
.33987 .53369 m .33969 .52825 L .33934 .53051 L F
.33987 .53369 m .342 .53326 L .33969 .52825 L F
.152 0 .076 r
.33987 .53369 m .33884 .53586 L .342 .53326 L F
.468 .794 .999 r
.711 .28405 m .71224 .28519 L .7149 .28473 L F
.711 .28405 m .71224 .28519 L .7149 .28473 L F
.376 0 0 r
.36912 .69825 m .36513 .69589 L .36795 .69538 L F
.733 .722 .841 r
.37176 .69562 m .36912 .69825 L .36795 .69538 L F
.571 .196 .292 r
.28037 .56979 m .28236 .57159 L .28383 .56901 L F
.672 .395 .493 r
.28236 .57159 m .28647 .56862 L .28383 .56901 L F
0 0 .036 r
.53033 .41889 m .53182 .41348 L .5332 .41811 L F
.29 .31 .709 r
.36942 .53047 m .37226 .53302 L .37195 .53003 L F
.925 .554 .291 r
.38149 .5264 m .38462 .53026 L .38346 .52721 L F
.881 .989 .809 r
.29517 .51231 m .29559 .51449 L .29795 .51135 L F
.998 .793 .443 r
.29344 .51308 m .29559 .51449 L .29517 .51231 L F
0 .215 .734 r
.33752 .52672 m .33944 .52821 L .34165 .52724 L F
.624 .617 .823 r
.34284 .52665 m .34277 .52668 L .33822 .52501 L F
.34277 .52668 m .33944 .52821 L .33927 .52777 L F
.34277 .52668 m .33927 .52777 L .33822 .52501 L F
.34284 .52665 m .33822 .52501 L .343 .52659 L F
.34284 .52665 m .343 .52659 L .34334 .5267 L F
.309 .777 .66 r
.34165 .52724 m .34287 .52664 L .34334 .52646 L F
.34287 .52664 m .34287 .52663 L .343 .52659 L F
.366 0 0 r
.34128 .52608 m .34299 .52659 L .33822 .52501 L F
.34299 .52659 m .343 .52659 L .33822 .52501 L F
.609 .92 .669 r
.34376 .52627 m .3431 .52654 L .34486 .52486 L F
.729 .791 .902 r
.34486 .52486 m .34341 .52625 L .34128 .52608 L F
.3437 .52627 m .34299 .52659 L .34128 .52608 L F
.609 .92 .669 r
.3431 .52654 m .34284 .52665 L .34486 .52486 L F
.729 .791 .902 r
.34486 .52486 m .3437 .52627 L .34341 .52625 L F
.309 .777 .66 r
.34298 .5266 m .343 .52659 L .34334 .52646 L F
.34298 .52659 m .343 .52659 L .34298 .5266 L F
.366 0 0 r
.34299 .52659 m .34334 .5267 L .343 .52659 L F
.309 .777 .66 r
.34334 .52646 m .34287 .52663 L .34376 .52627 L F
.729 .791 .902 r
.3437 .52627 m .34334 .5267 L .34299 .52659 L F
.309 .777 .66 r
.34287 .52664 m .34298 .52659 L .34298 .5266 L F
.34165 .52724 m .34284 .52665 L .34287 .52663 L F
.39 .849 .873 r
.34276 .52617 m .34065 .52689 L .34252 .52676 L F
.612 .428 .609 r
.34284 .52665 m .34286 .52665 L .34486 .52486 L F
.39 .849 .873 r
.34319 .52656 m .34252 .52676 L .34334 .5267 L F
.34289 .52664 m .34252 .52676 L .34319 .52656 L F
.612 .428 .609 r
.34286 .52665 m .34489 .52764 L .34488 .52607 L F
.458 .779 .998 r
.34376 .52627 m .34486 .52486 L .34519 .52526 L F
.34376 .52627 m .34486 .52486 L .34519 .52526 L F
.612 .428 .609 r
.34286 .52665 m .34488 .52607 L .34486 .52486 L F
.39 .849 .873 r
.34318 .52655 m .34289 .52664 L .34319 .52656 L F
.34276 .52617 m .34252 .52676 L .34318 .52655 L F
.493 .868 .98 r
.34065 .52689 m .34008 .52706 L .33944 .52821 L F
0 .215 .734 r
.33752 .52672 m .33879 .52937 L .33944 .52821 L F
.989 .724 .415 r
.33944 .52821 m .33813 .52762 L .33822 .52501 L F
.493 .868 .98 r
.34008 .52706 m .33813 .52762 L .33944 .52821 L F
0 .215 .734 r
.33879 .52937 m .33934 .53051 L .33944 .52821 L F
.737 .933 .953 r
.33944 .52821 m .33934 .53051 L .33969 .52825 L F
0 .175 .699 r
.61072 .38753 m .61034 .38863 L .60915 .38549 L F
.775 .723 .804 r
.30833 .65631 m .30978 .65903 L .30633 .65898 L F
.536 .012 0 r
.30633 .65898 m .30978 .65903 L .30904 .65972 L F
.409 .541 .878 r
.31187 .65821 m .30978 .65903 L .30833 .65631 L F
.84 .667 .668 r
.31187 .65821 m .30904 .65972 L .30978 .65903 L F
.695 .96 .945 r
.27228 .61935 m .27175 .62113 L .27389 .61976 L F
.791 .973 .682 r
.27228 .61935 m .26936 .62297 L .27175 .62113 L F
0 0 0 r
.22052 .55637 m .22167 .55506 L .22248 .55291 L F
.21982 .55899 m .22167 .55506 L .22052 .55637 L F
.82 .843 .867 r
.48059 .44035 m .47775 .44325 L .47603 .44183 L F
.432 .185 .437 r
.51572 .47899 m .51549 .48154 L .51318 .48233 L F
.558 .295 .473 r
.51953 .47824 m .51549 .48154 L .51572 .47899 L F
.529 0 0 r
.5695 .38603 m .57213 .38771 L .5737 .38814 L F
.285 0 0 r
.57213 .38771 m .57619 .38904 L .5737 .38814 L F
.653 .97 .836 r
.35074 .65126 m .35485 .6491 L .35191 .65062 L F
.048 0 0 r
.35191 .65062 m .35666 .64925 L .35437 .65035 L F
.35191 .65062 m .35437 .65035 L .35275 .65015 L F
.35191 .65062 m .35275 .65015 L .35199 .65006 L F
.653 .97 .836 r
.35055 .65135 m .35074 .65126 L .35191 .65062 L F
.105 0 0 r
.35666 .64925 m .35485 .6491 L .35711 .64855 L F
.094 0 0 r
.35191 .65062 m .35485 .6491 L .35666 .64925 L F
0 0 0 r
.35485 .6491 m .3584 .64777 L .35711 .64855 L F
.498 0 0 r
.37366 .50027 m .37419 .50124 L .37129 .50033 L F
.37366 .50027 m .37597 .50178 L .37419 .50124 L F
.958 .916 .727 r
.37711 .50151 m .37792 .5037 L .37689 .50165 L F
.37866 .50055 m .3782 .50253 L .37711 .50151 L F
.3782 .50253 m .37792 .5037 L .37711 .50151 L F
.498 0 0 r
.37597 .50178 m .37646 .5021 L .37419 .50124 L F
.72 .918 .961 r
.37419 .50124 m .37646 .5021 L .37734 .50172 L F
.37711 .50151 m .37734 .50172 L .37851 .50122 L F
.499 .02 .048 r
.37851 .50122 m .37689 .50165 L .37711 .50151 L F
.37851 .50122 m .37711 .50151 L .37866 .50055 L F
.72 .918 .961 r
.37419 .50124 m .37734 .50172 L .37681 .50123 L F
.498 .711 .966 r
.37646 .5021 m .37749 .50399 L .37689 .50165 L F
.755 .88 .936 r
.37749 .50399 m .37792 .5037 L .37689 .50165 L F
.603 .89 .99 r
.37646 .5021 m .37689 .50165 L .37419 .50124 L F
.675 .9 .977 r
.37419 .50124 m .37689 .50165 L .37545 .50116 L F
.37419 .50124 m .37689 .50165 L .37545 .50116 L F
.722 .215 0 r
.37607 .50137 m .37824 .5043 L .37545 .50116 L F
.37689 .50165 m .37698 .50184 L .37607 .50137 L F
.37698 .50184 m .37824 .5043 L .37607 .50137 L F
.112 0 .176 r
.37246 .49933 m .37461 .50065 L .3744 .49983 L F
.72 .918 .961 r
.37458 .50054 m .37766 .50122 L .3744 .49983 L F
.3758 .50123 m .37766 .50122 L .37444 .50051 L F
.112 0 .176 r
.37246 .49933 m .37288 .49917 L .37461 .50065 L F
.72 .918 .961 r
.37456 .5006 m .37444 .50051 L .3743 .50047 L F
.3758 .50123 m .37444 .50051 L .37456 .5006 L F
.112 0 .176 r
.37461 .50065 m .37545 .50116 L .3744 .49983 L F
.72 .918 .961 r
.37766 .50122 m .37797 .50104 L .3744 .49983 L F
.562 .052 0 r
.371 .49775 m .3744 .49983 L .3757 .49799 L F
.799 .338 .142 r
.3744 .49983 m .37797 .50104 L .3757 .49799 L F
.37797 .50104 m .37851 .50122 L .37821 .50087 L F
.37797 .50104 m .37821 .50087 L .3757 .49799 L F
.799 .33 .116 r
.3757 .49799 m .37821 .50087 L .37866 .50055 L F
.37821 .50087 m .37851 .50122 L .37866 .50055 L F
0 0 0 r
.37866 .50055 m .37711 .50151 L .37788 .50111 L F
.367 .833 .892 r
.37866 .50055 m .38067 .49968 L .38136 .50006 L F
0 0 0 r
.37866 .50055 m .37788 .50111 L .38034 .49982 L F
.38034 .49982 m .37776 .50118 L .38067 .49968 L F
.72 .918 .961 r
.37766 .50122 m .37711 .50151 L .37851 .50122 L F
0 0 0 r
.37776 .50118 m .37738 .50139 L .37774 .5012 L F
.37776 .50118 m .37774 .5012 L .38067 .49968 L F
.112 0 .176 r
.37461 .50065 m .37473 .49849 L .37545 .50116 L F
.72 .918 .961 r
.3743 .50047 m .37458 .50054 L .3744 .49983 L F
.542 0 0 r
.37246 .49933 m .3744 .49983 L .3715 .49805 L F
.37246 .49933 m .3715 .49805 L .371 .49775 L F
.213 .422 .849 r
.37129 .50033 m .37419 .50124 L .37246 .49933 L F
.87 .537 .419 r
.37419 .50124 m .37196 .50115 L .37246 .49933 L F
.112 0 .176 r
.37246 .49933 m .37196 .50115 L .37304 .50011 L F
.37288 .49917 m .37473 .49849 L .37461 .50065 L F
.37246 .49933 m .37304 .50011 L .37473 .49849 L F
.72 .918 .961 r
.37419 .50124 m .3758 .50123 L .3743 .50047 L F
.37766 .50122 m .37851 .50122 L .37797 .50104 L F
0 0 0 r
.37738 .50139 m .37689 .50165 L .37732 .50142 L F
.37738 .50139 m .37732 .50142 L .38067 .49968 L F
.37711 .50151 m .37689 .50165 L .38034 .49982 L F
.72 .918 .961 r
.37681 .50123 m .37711 .50151 L .37766 .50122 L F
.465 0 0 r
.37545 .50116 m .37391 .50116 L .37419 .50124 L F
.37391 .50116 m .37196 .50115 L .37419 .50124 L F
.517 0 0 r
.3719 .51508 m .37314 .51615 L .37443 .51656 L F
.898 .507 .272 r
.37314 .51615 m .37635 .51938 L .37443 .51656 L F
.735 .991 .859 r
.38003 .55784 m .37909 .55981 L .38196 .55746 L F
.435 .681 .968 r
.38003 .55784 m .3819 .55985 L .37909 .55981 L F
.661 .617 .795 r
.3592 .54672 m .3612 .55207 L .36425 .55036 L F
.327 .052 .333 r
.3063 .54983 m .30848 .54922 L .30901 .54682 L F
.3063 .54983 m .30848 .54922 L .30901 .54682 L F
.315 .041 .329 r
.30848 .54922 m .31069 .54849 L .30901 .54682 L F
.30848 .54922 m .31069 .54849 L .30901 .54682 L F
.972 .664 .297 r
.39793 .55912 m .39648 .55595 L .39658 .55823 L F
.996 .844 .571 r
.39594 .56085 m .39793 .55912 L .39658 .55823 L F
.39594 .56085 m .3972 .56261 L .39793 .55912 L F
.971 .734 .522 r
.37106 .66075 m .37123 .66267 L .36971 .65896 L F
.561 .404 .625 r
.37347 .65645 m .37387 .6595 L .37106 .66075 L F
.58 .446 .663 r
.37387 .6595 m .37123 .66267 L .37106 .66075 L F
.343 .701 .983 r
.58628 .37694 m .58277 .37688 L .58319 .3745 L F
.58628 .37694 m .58739 .37786 L .58277 .37688 L F
.662 .56 .73 r
.53178 .40822 m .53482 .40842 L .53366 .40484 L F
.577 .147 .188 r
.53105 .41052 m .53178 .40822 L .53121 .40986 L F
.961 .803 .64 r
.53021 .41143 m .53182 .41348 L .53121 .40986 L F
.52896 .4134 m .52926 .41341 L .53021 .41143 L F
.52926 .41341 m .53182 .41348 L .53021 .41143 L F
.59 .569 .798 r
.53121 .40986 m .53182 .41348 L .5336 .41211 L F
.53333 .41074 m .5336 .41211 L .53466 .41129 L F
.53121 .40986 m .5336 .41211 L .53333 .41074 L F
.873 .467 .253 r
.53021 .41538 m .53182 .41348 L .52896 .4134 L F
.695 .567 .707 r
.53578 .41437 m .5332 .41811 L .53182 .41348 L F
.351 0 0 r
.53411 .41401 m .53182 .41348 L .53021 .41538 L F
.729 .444 .496 r
.53121 .40986 m .5319 .41429 L .52896 .4134 L F
.695 .567 .707 r
.53578 .41437 m .53182 .41348 L .53411 .41401 L F
.003 0 .448 r
.53272 .41245 m .5319 .41429 L .53165 .41269 L F
.53185 .41095 m .53182 .4112 L .53121 .40986 L F
.53182 .4112 m .53154 .41195 L .53121 .40986 L F
.53182 .4112 m .53165 .41269 L .53154 .41195 L F
.53272 .41245 m .53167 .41066 L .53105 .41052 L F
.59 .569 .798 r
.53121 .40986 m .53466 .41129 L .53105 .41052 L F
.767 .802 .881 r
.53213 .41038 m .53466 .41129 L .53603 .40986 L F
.53105 .41052 m .532 .41072 L .53213 .41038 L F
.532 .41072 m .53466 .41129 L .53213 .41038 L F
.003 0 .448 r
.53272 .41245 m .53165 .41269 L .53185 .41095 L F
.577 .147 .188 r
.53105 .41052 m .53482 .40842 L .53178 .40822 L F
.916 .774 .69 r
.53269 .40739 m .53307 .4094 L .53195 .41002 L F
.53213 .40846 m .53195 .41002 L .53105 .41052 L F
.53269 .40739 m .53195 .41002 L .53213 .40846 L F
.53295 .40687 m .53482 .40842 L .53307 .4094 L F
.53295 .40687 m .53307 .4094 L .53269 .40739 L F
.806 .508 .485 r
.53148 .40851 m .53121 .40986 L .52638 .40987 L F
.709 .69 .151 r
.53105 .41052 m .53121 .40986 L .53148 .40851 L F
.53105 .41052 m .53138 .409 L .53295 .40687 L F
.53138 .409 m .53148 .40851 L .53176 .4082 L F
.53138 .409 m .53176 .4082 L .53295 .40687 L F
.502 .337 .589 r
.31913 .60795 m .32168 .60744 L .3215 .60459 L F
.376 .202 .514 r
.31913 .60795 m .32106 .60991 L .32168 .60744 L F
.31913 .60795 m .31906 .6108 L .32106 .60991 L F
.694 .269 .232 r
.39034 .66913 m .38857 .67136 L .38862 .66987 L F
.935 .589 .162 r
.39034 .66913 m .39033 .67027 L .39232 .67128 L F
.509 .554 .838 r
.39033 .67027 m .39439 .67499 L .39232 .67128 L F
.694 .269 .232 r
.39034 .66913 m .39232 .67128 L .38857 .67136 L F
.785 .706 .776 r
.35608 .53616 m .3535 .53943 L .35403 .53729 L F
.039 .014 .498 r
.2315 .59999 m .23023 .60425 L .22963 .60187 L F
.92 .961 .79 r
.58952 .35696 m .58654 .35976 L .58891 .35535 L F
.707 .811 .929 r
.59438 .35559 m .58952 .35696 L .58891 .35535 L F
.826 .61 .61 r
.38432 .66799 m .38867 .66519 L .38487 .6648 L F
.38432 .66799 m .38862 .66987 L .38867 .66519 L F
.529 .819 .479 r
.39345 .6619 m .38912 .6667 L .39356 .66456 L F
.682 .484 .612 r
.391 .66733 m .39356 .66456 L .38912 .6667 L F
0 0 .176 r
.38867 .66519 m .38937 .66678 L .38912 .6667 L F
.38867 .66519 m .38862 .66987 L .38937 .66678 L F
.769 .799 .877 r
.6537 .38075 m .65318 .38258 L .65127 .38089 L F
.981 .84 .63 r
.33907 .61056 m .33993 .61166 L .34061 .61155 L F
.397 .81 .977 r
.36635 .6947 m .36513 .69589 L .36335 .69441 L F
.36635 .6947 m .36795 .69538 L .36513 .69589 L F
.672 .19 .098 r
.26507 .62062 m .26396 .62238 L .26746 .62237 L F
.954 .934 .732 r
.60813 .37128 m .60799 .37422 L .60627 .37432 L F
.74 .88 .944 r
.44834 .45421 m .45346 .45323 L .45013 .45515 L F
.286 .582 .942 r
.43807 .45473 m .43718 .45634 L .43574 .45597 L F
.43807 .45473 m .43964 .45688 L .43718 .45634 L F
0 0 0 r
.67865 .36275 m .67565 .36551 L .67779 .36431 L F
.491 .47 .761 r
.67891 .35924 m .67865 .36275 L .68046 .36112 L F
0 0 0 r
.68046 .36112 m .67865 .36275 L .67779 .36431 L F
.554 .854 .998 r
.42528 .57818 m .42708 .57918 L .42942 .57831 L F
0 .005 .566 r
.2344 .60758 m .23561 .61153 L .23685 .61015 L F
.466 .273 .534 r
.37515 .58851 m .37492 .59146 L .37269 .59195 L F
.544 .409 .646 r
.37554 .59409 m .37269 .59195 L .37492 .59146 L F
.37554 .59409 m .37298 .5949 L .37269 .59195 L F
.005 .09 .602 r
.21739 .58814 m .21819 .59231 L .21912 .59024 L F
.35 .516 .88 r
.21819 .59231 m .22122 .59373 L .21912 .59024 L F
.601 .053 0 r
.34014 .65488 m .34167 .65393 L .34181 .6546 L F
.578 .899 .639 r
.34331 .65212 m .34167 .65393 L .34014 .65488 L F
.786 .934 .573 r
.7091 .33345 m .71145 .32997 L .71025 .33072 L F
0 0 0 r
.71358 .32858 m .71145 .32997 L .71395 .32793 L F
.39 .805 .604 r
.71025 .33072 m .71145 .32997 L .71358 .32858 L F
.528 .294 .504 r
.57039 .43701 m .57303 .43396 L .5703 .43402 L F
.57039 .43701 m .57309 .43659 L .57303 .43396 L F
.437 .143 .367 r
.57309 .43659 m .57596 .43321 L .57303 .43396 L F
.532 .907 .954 r
.63909 .33684 m .63635 .33792 L .63465 .33744 L F
.531 .887 .663 r
.69047 .34758 m .69196 .34675 L .68845 .34944 L F
0 0 0 r
.69047 .34758 m .68845 .34944 L .68828 .35115 L F
.007 0 0 r
.74233 .31447 m .74228 .31267 L .73974 .3149 L F
0 0 0 r
.74437 .31078 m .74228 .31267 L .74233 .31447 L F
.927 .907 .783 r
.38805 .5983 m .38641 .59743 L .38853 .59398 L F
.987 .746 .482 r
.38805 .5983 m .38779 .60102 L .38641 .59743 L F
.28 .422 .827 r
.63094 .41272 m .62912 .41485 L .6274 .41105 L F
.168 .43 .865 r
.63001 .41061 m .63094 .41272 L .6274 .41105 L F
.969 .709 .283 r
.63021 .41185 m .63094 .41272 L .63001 .41061 L F
.565 .854 .997 r
.63191 .41389 m .62912 .41485 L .63094 .41272 L F
.969 .709 .283 r
.63096 .4164 m .63094 .41272 L .63021 .41185 L F
.565 .854 .997 r
.63221 .41379 m .63191 .41389 L .63094 .41272 L F
.535 .373 .608 r
.4814 .50511 m .48132 .50745 L .47871 .50806 L F
.507 .313 .552 r
.48132 .50745 m .47871 .51076 L .47871 .50806 L F
0 0 0 r
.68527 .35369 m .6852 .35353 L .68493 .35394 L F
.069 0 0 r
.6852 .35353 m .68673 .35331 L .68512 .35337 L F
.694 .981 .824 r
.68828 .35115 m .68673 .35331 L .6852 .35353 L F
0 0 0 r
.68711 .35233 m .6852 .35353 L .68527 .35369 L F
.069 0 0 r
.6852 .35353 m .68512 .35337 L .68305 .35345 L F
.466 .236 .481 r
.50466 .48857 m .5045 .49101 L .50187 .49166 L F
.514 .328 .566 r
.50723 .48538 m .50722 .48798 L .50466 .48857 L F
.477 .241 .477 r
.50722 .48798 m .5045 .49101 L .50466 .48857 L F
.61 .289 .401 r
.53113 .47276 m .5337 .47488 L .53116 .47466 L F
.53113 .47276 m .53486 .47231 L .5337 .47488 L F
.826 .871 .878 r
.38647 .48229 m .38438 .4813 L .38717 .47899 L F
.95 .73 .569 r
.38647 .48229 m .38614 .48492 L .38438 .4813 L F
0 0 0 r
.67941 .35335 m .67811 .35657 L .67789 .35714 L F
.928 .567 .145 r
.67811 .35657 m .67891 .35924 L .67789 .35714 L F
.647 .949 .726 r
.66987 .32626 m .66831 .32818 L .67019 .32624 L F
.66987 .32626 m .66679 .3289 L .66831 .32818 L F
.714 .985 .808 r
.27372 .6262 m .27614 .6252 L .27317 .62756 L F
.834 1 .807 r
.27778 .62289 m .27614 .6252 L .27372 .6262 L F
.364 .832 .888 r
.27567 .51626 m .276 .51552 L .27777 .51574 L F
.27567 .51626 m .27361 .5162 L .276 .51552 L F
.807 .999 .844 r
.69098 .37271 m .69416 .36967 L .69205 .37019 L F
.81 1 .825 r
.69048 .37203 m .69098 .37271 L .69205 .37019 L F
.396 .478 .827 r
.28483 .65482 m .28677 .65989 L .28826 .65995 L F
.092 0 0 r
.34823 .54143 m .34696 .54187 L .34443 .54207 L F
.799 .531 .531 r
.35027 .53928 m .34696 .54187 L .34823 .54143 L F
.35027 .53928 m .35103 .54269 L .34696 .54187 L F
.231 .626 .956 r
.58555 .38669 m .58704 .38806 L .58916 .38817 L F
.81 .533 .519 r
.55307 .43894 m .55734 .43964 L .55707 .43708 L F
.52 .087 .156 r
.55955 .43832 m .55707 .43708 L .55734 .43964 L F
.55955 .43832 m .56067 .43703 L .55707 .43708 L F
.615 .846 .47 r
.67867 .30413 m .68011 .30199 L .68204 .30158 L F
.67867 .30413 m .67883 .30379 L .68011 .30199 L F
.704 .582 .715 r
.46205 .54008 m .45943 .54344 L .4615 .54253 L F
0 .278 .779 r
.23561 .61153 m .23801 .61324 L .23685 .61015 L F
.964 .872 .475 r
.41311 .57272 m .41192 .57299 L .41238 .5707 L F
.41311 .57272 m .41242 .57532 L .41192 .57299 L F
0 0 .565 r
.33486 .64171 m .33329 .63964 L .33391 .63864 L F
.181 .236 .685 r
.3263 .64251 m .32667 .64684 L .32856 .64516 L F
0 0 .362 r
.32667 .64684 m .32796 .64828 L .32856 .64516 L F
.32667 .64688 m .3268 .64892 L .32796 .64828 L F
0 0 0 r
.32796 .64828 m .3268 .64892 L .32637 .65119 L F
.3268 .64892 m .3266 .6496 L .32637 .65119 L F
.3266 .6496 m .32561 .65293 L .32637 .65119 L F
.498 .877 .676 r
.32593 .65497 m .32793 .65332 L .32637 .65119 L F
.754 .247 .005 r
.32623 .65214 m .32637 .65119 L .32793 .65332 L F
0 0 .228 r
.32637 .65119 m .32561 .65293 L .32593 .65497 L F
.754 .247 .005 r
.3234 .65019 m .32637 .65119 L .32623 .65214 L F
.856 .785 .78 r
.32796 .64828 m .32637 .65119 L .3234 .65019 L F
.32796 .64828 m .3234 .65019 L .32641 .64812 L F
.506 0 0 r
.32883 .64922 m .32796 .64828 L .32641 .64812 L F
.564 .415 .638 r
.33273 .64868 m .33083 .65149 L .33047 .6494 L F
.506 0 0 r
.33099 .65019 m .32796 .64828 L .32883 .64922 L F
0 0 .362 r
.32667 .64684 m .32667 .64688 L .32796 .64828 L F
.357 .239 .579 r
.47705 .52022 m .47517 .52378 L .47469 .52104 L F
.992 .878 .556 r
.23115 .56794 m .23033 .56932 L .2304 .5695 L F
.481 .201 .412 r
.50187 .49166 m .50131 .49479 L .49856 .49479 L F
.458 .19 .419 r
.5045 .49101 m .50131 .49479 L .50187 .49166 L F
.978 .904 .568 r
.6363 .41161 m .63777 .41076 L .63785 .40996 L F
.6363 .41161 m .63652 .41475 L .63777 .41076 L F
.632 .75 .933 r
.6237 .38796 m .61975 .38633 L .62266 .38565 L F
.148 .442 .876 r
.62377 .38632 m .6237 .38796 L .62266 .38565 L F
.553 .879 .609 r
.61975 .38633 m .6172 .38871 L .61875 .38709 L F
.327 .404 .789 r
.61875 .38709 m .61979 .39046 L .62047 .38999 L F
.85 .998 .793 r
.62071 .38941 m .6237 .38796 L .62377 .38632 L F
.62052 .38986 m .6237 .38796 L .62071 .38941 L F
.866 .795 .779 r
.62058 .38852 m .62377 .38632 L .62143 .38643 L F
.62071 .38941 m .62377 .38632 L .62058 .38852 L F
.327 .404 .789 r
.62058 .38852 m .62047 .38999 L .62096 .38881 L F
.61916 .38778 m .62047 .38999 L .62058 .38852 L F
.866 .795 .779 r
.61988 .39025 m .62071 .38941 L .62058 .38852 L F
.327 .404 .789 r
.62103 .38863 m .62071 .38941 L .62174 .38911 L F
.62071 .38941 m .62047 .38999 L .62077 .38979 L F
.62071 .38941 m .62077 .38979 L .62174 .38911 L F
.85 .998 .793 r
.61988 .39025 m .62052 .38986 L .62071 .38941 L F
.478 .348 .624 r
.62174 .38911 m .61988 .39025 L .62058 .38852 L F
.62174 .38911 m .62058 .38852 L .62143 .38643 L F
.327 .404 .789 r
.61875 .38709 m .61916 .38778 L .62058 .38852 L F
0 0 .342 r
.61875 .38709 m .62058 .38852 L .62143 .38643 L F
.327 .404 .789 r
.61875 .38709 m .62096 .38881 L .62103 .38863 L F
0 0 .342 r
.61875 .38709 m .61988 .39025 L .62058 .38852 L F
.752 .73 .833 r
.54482 .41126 m .54084 .41062 L .54353 .41187 L F
0 .208 .726 r
.54611 .41138 m .5466 .41263 L .54482 .41126 L F
.351 .29 .648 r
.5466 .41263 m .54544 .41393 L .54482 .41126 L F
0 .208 .726 r
.54611 .41138 m .54482 .41126 L .54353 .41187 L F
.079 0 0 r
.30171 .54156 m .30114 .54062 L .30255 .53893 L F
.75 .538 .608 r
.36971 .65896 m .37387 .6595 L .37347 .65645 L F
.581 .418 .625 r
.37347 .65645 m .37607 .65633 L .37387 .6595 L F
.37347 .65645 m .37607 .65633 L .37387 .6595 L F
.781 .81 .876 r
.48854 .43363 m .48946 .43642 L .48564 .43622 L F
.742 .79 .891 r
.49245 .43386 m .48946 .43642 L .48854 .43363 L F
.199 .222 .659 r
.21593 .58174 m .21649 .58601 L .21793 .5838 L F
.446 .485 .806 r
.21739 .58814 m .21793 .5838 L .21649 .58601 L F
.792 .668 .727 r
.53915 .40372 m .54089 .40789 L .54342 .40476 L F
.087 0 0 r
.55748 .46923 m .55861 .46991 L .55631 .4709 L F
.55748 .46923 m .56009 .46861 L .55861 .46991 L F
.273 .735 .95 r
.43115 .59807 m .43362 .59795 L .43262 .59726 L F
.062 0 0 r
.4056 .48754 m .40718 .48739 L .40982 .48561 L F
.395 0 .056 r
.40718 .48739 m .41406 .48436 L .40982 .48561 L F
.45 .341 .638 r
.47871 .51076 m .47906 .51355 L .47685 .51426 L F
.42 .274 .575 r
.47906 .51355 m .47708 .51704 L .47685 .51426 L F
.863 .817 .802 r
.41005 .4885 m .40821 .49148 L .41118 .49169 L F
.977 .88 .669 r
.40821 .49148 m .40859 .49506 L .41118 .49169 L F
.786 .56 .593 r
.34229 .5972 m .3466 .59497 L .34278 .59512 L F
.066 0 0 r
.34708 .59471 m .34229 .5972 L .34066 .59396 L F
.019 .087 .593 r
.34749 .59064 m .34708 .59471 L .34528 .59081 L F
.34719 .59364 m .34954 .59495 L .34708 .59471 L F
.34885 .59349 m .34954 .59495 L .34719 .59364 L F
.469 .305 .576 r
.34998 .5929 m .34954 .59495 L .34749 .59064 L F
.356 0 0 r
.34728 .59653 m .34708 .59471 L .34954 .59495 L F
.681 .979 .849 r
.34951 .59495 m .34954 .59495 L .34998 .5929 L F
.784 .602 .654 r
.34998 .5929 m .3498 .59521 L .34946 .59516 L F
.34846 .59403 m .34946 .59516 L .34736 .59484 L F
0 .491 .707 r
.34736 .59484 m .34819 .59495 L .34921 .59512 L F
.681 .979 .849 r
.34819 .59495 m .34728 .59653 L .34928 .59513 L F
.34819 .59495 m .34928 .59513 L .34954 .59495 L F
0 .491 .707 r
.34921 .59512 m .34819 .59495 L .3498 .59521 L F
.79 .291 0 r
.3498 .59521 m .34819 .59495 L .34951 .59495 L F
.3498 .59521 m .34951 .59495 L .34954 .59495 L F
.784 .602 .654 r
.34998 .5929 m .34951 .59495 L .34846 .59403 L F
.34951 .59495 m .34946 .59516 L .34846 .59403 L F
.681 .979 .849 r
.34819 .59495 m .34951 .59495 L .34998 .5929 L F
.34819 .59495 m .34952 .59342 L .34736 .59484 L F
.34952 .59342 m .34998 .5929 L .34924 .59345 L F
.34952 .59342 m .34924 .59345 L .34736 .59484 L F
.019 .087 .593 r
.34749 .59064 m .34885 .59349 L .34719 .59364 L F
.356 0 0 r
.34728 .59653 m .34446 .59692 L .34708 .59471 L F
.575 .735 .951 r
.36493 .70018 m .36634 .70191 L .36784 .69976 L F
.437 .544 .867 r
.36784 .69976 m .36634 .70191 L .3682 .70168 L F
0 .234 .749 r
.34442 .63011 m .34372 .63126 L .34347 .62953 L F
.279 .499 .89 r
.34372 .63126 m .34718 .634 L .34671 .63416 L F
.34718 .634 m .34793 .63459 L .34671 .63416 L F
0 .234 .749 r
.34442 .63011 m .34671 .63416 L .34372 .63126 L F
.255 .424 .838 r
.34687 .63124 m .34671 .63416 L .34442 .63011 L F
.908 .882 .457 r
.34626 .63432 m .34671 .63416 L .34687 .63124 L F
.173 0 0 r
.34793 .63459 m .34415 .63479 L .34671 .63416 L F
.324 0 .117 r
.34415 .63479 m .34671 .63416 L .34605 .6354 L F
.908 .882 .457 r
.34605 .6354 m .34671 .63416 L .34626 .63432 L F
.914 .872 .441 r
.46028 .56794 m .45978 .56789 L .46098 .56601 L F
.762 .859 .421 r
.46098 .56601 m .45978 .56789 L .46157 .56396 L F
.853 .747 .746 r
.52909 .40453 m .53148 .40851 L .52835 .40687 L F
.806 .508 .485 r
.53148 .40851 m .52638 .40987 L .52835 .40687 L F
.502 .608 .891 r
.53295 .40687 m .53148 .40851 L .52909 .40453 L F
0 0 0 r
.65468 .39427 m .6577 .39119 L .65641 .3924 L F
.6577 .39119 m .66089 .38881 L .65978 .39022 L F
.65641 .3924 m .6577 .39119 L .65978 .39022 L F
.567 .308 .484 r
.43042 .53356 m .42955 .53666 L .42794 .53468 L F
.43042 .53356 m .42955 .53666 L .42794 .53468 L F
.528 .006 0 r
.24131 .61954 m .24081 .61897 L .23991 .61831 L F
0 .428 .806 r
.24148 .6205 m .242 .62015 L .24081 .61897 L F
.528 .006 0 r
.242 .62015 m .24081 .61897 L .24131 .61954 L F
0 0 .428 r
.23981 .61721 m .24055 .61867 L .24081 .61897 L F
.24055 .61867 m .24148 .6205 L .24081 .61897 L F
0 .428 .806 r
.24148 .6205 m .24347 .62121 L .242 .62015 L F
.533 .343 .569 r
.44031 .54625 m .43993 .54879 L .43689 .54952 L F
.564 .48 .719 r
.43993 .54879 m .43773 .55168 L .43689 .54952 L F
.557 .545 .797 r
.4615 .54253 m .46411 .54003 L .46205 .54008 L F
.4615 .54253 m .46492 .54332 L .46411 .54003 L F
.954 .606 .25 r
.44673 .57988 m .4466 .58131 L .44509 .58026 L F
.491 .821 1 r
.44509 .58026 m .4466 .58131 L .44673 .57988 L F
.954 .913 .547 r
.39018 .61387 m .39119 .61145 L .39081 .60926 L F
0 0 .448 r
.46201 .55639 m .46347 .55683 L .46332 .55462 L F
.46201 .55639 m .4625 .55906 L .46347 .55683 L F
.469 .348 .632 r
.47598 .54265 m .47611 .5487 L .47361 .54819 L F
.404 .373 .71 r
.47611 .5487 m .47435 .54952 L .47361 .54819 L F
.46 .019 .113 r
.29822 .56452 m .30065 .56464 L .30258 .56238 L F
.301 0 0 r
.30065 .56464 m .30506 .56269 L .30258 .56238 L F
.514 .621 .895 r
.63972 .38302 m .64514 .38425 L .64213 .38174 L F
.544 .351 .57 r
.33078 .54027 m .33366 .54239 L .33247 .5385 L F
.707 .274 .219 r
.39367 .47528 m .39611 .47664 L .39789 .47605 L F
.917 .903 .796 r
.39789 .47605 m .39611 .47664 L .39626 .47629 L F
0 .223 .735 r
.39626 .47629 m .39367 .47528 L .39789 .47605 L F
.74 .67 .782 r
.39834 .47149 m .39626 .47629 L .39467 .47077 L F
.39626 .47629 m .39611 .47664 L .39601 .47624 L F
.39626 .47629 m .39601 .47624 L .39467 .47077 L F
0 .223 .735 r
.39616 .4763 m .39601 .47624 L .39626 .47629 L F
.39601 .47624 m .39367 .47528 L .39626 .47629 L F
.499 .513 .802 r
.39601 .47624 m .3961 .47661 L .39367 .47528 L F
.3961 .47661 m .39611 .47664 L .39607 .47662 L F
.3961 .47661 m .39607 .47662 L .39367 .47528 L F
.917 .903 .796 r
.39789 .47605 m .39626 .47629 L .39834 .47149 L F
.39789 .47605 m .39834 .47149 L .40028 .47516 L F
.365 .83 .766 r
.39876 .4754 m .39558 .47669 L .39649 .47644 L F
.39867 .47547 m .39649 .47644 L .39789 .47605 L F
.39876 .4754 m .39649 .47644 L .39867 .47547 L F
0 .223 .735 r
.39523 .47644 m .39367 .47528 L .39616 .4763 L F
.499 .513 .802 r
.39467 .47077 m .39601 .47624 L .39367 .47528 L F
0 .223 .735 r
.39558 .47669 m .39523 .47644 L .39789 .47605 L F
.365 .83 .766 r
.39876 .4754 m .39789 .47605 L .40028 .47516 L F
.734 .41 .434 r
.28398 .64653 m .2837 .64897 L .2821 .64564 L F
.28398 .64653 m .28651 .64975 L .2837 .64897 L F
.647 .089 0 r
.3569 .5497 m .35951 .55201 L .36039 .55166 L F
.719 .94 .627 r
.35818 .54772 m .3569 .5497 L .3592 .54672 L F
.35767 .54821 m .35709 .54932 L .35818 .54772 L F
.35709 .54932 m .3569 .5497 L .35818 .54772 L F
.819 .625 .641 r
.3578 .54269 m .3592 .54672 L .36224 .5458 L F
.467 .382 .677 r
.35732 .54701 m .36078 .54793 L .36034 .54763 L F
.184 .294 .744 r
.36002 .55026 m .35767 .54821 L .3602 .54766 L F
.36033 .54771 m .3602 .54766 L .36034 .54763 L F
.36002 .55026 m .3602 .54766 L .36033 .54771 L F
.467 .382 .677 r
.35732 .54701 m .36034 .54763 L .3602 .54766 L F
.427 .437 .767 r
.35851 .54728 m .36014 .54775 L .35845 .54731 L F
.36014 .54775 m .36078 .54793 L .36011 .54775 L F
.36014 .54775 m .36011 .54775 L .35845 .54731 L F
.819 .625 .641 r
.3578 .54269 m .36224 .5458 L .36041 .54186 L F
.717 .654 .786 r
.36041 .54186 m .36224 .5458 L .36407 .54252 L F
.47 .382 .674 r
.36034 .54763 m .36078 .54793 L .36229 .54407 L F
.729 .669 .792 r
.36229 .54407 m .36106 .54723 L .36104 .54718 L F
.47 .382 .674 r
.36097 .54734 m .36229 .54407 L .3623 .54673 L F
.36034 .54763 m .36229 .54407 L .36097 .54734 L F
.729 .669 .792 r
.36229 .54407 m .36104 .54718 L .36063 .54605 L F
.36106 .54723 m .36078 .54793 L .36076 .54762 L F
.36106 .54723 m .36076 .54762 L .36063 .54605 L F
.431 .257 .542 r
.3623 .54673 m .36187 .54739 L .36081 .54756 L F
.36097 .54734 m .36081 .54756 L .36034 .54763 L F
.3623 .54673 m .36081 .54756 L .36097 .54734 L F
.36187 .54739 m .36002 .55026 L .36033 .54771 L F
.36187 .54739 m .36033 .54771 L .36034 .54763 L F
.427 .437 .767 r
.35989 .54759 m .36078 .54793 L .35851 .54728 L F
.36078 .54786 m .36078 .54793 L .35873 .54715 L F
.467 .382 .677 r
.35732 .54701 m .3602 .54766 L .35767 .54821 L F
.427 .437 .767 r
.35873 .54715 m .35989 .54759 L .35851 .54728 L F
.36063 .54605 m .36078 .54786 L .35873 .54715 L F
.35898 .54653 m .35845 .54731 L .35732 .54701 L F
.819 .625 .641 r
.3578 .54269 m .35732 .54701 L .3592 .54672 L F
.427 .437 .767 r
.36063 .54605 m .35845 .54731 L .35898 .54653 L F
.084 .233 .721 r
.35767 .54821 m .35951 .55201 L .3569 .5497 L F
.184 .294 .744 r
.36002 .55026 m .35951 .55201 L .35767 .54821 L F
.274 .137 .505 r
.36002 .55026 m .35907 .55219 L .35951 .55201 L F
.35907 .55219 m .35805 .55424 L .35951 .55201 L F
.647 .089 0 r
.36039 .55166 m .35951 .55201 L .36103 .55202 L F
.114 .666 .763 r
.36103 .55202 m .35951 .55201 L .36276 .55182 L F
.773 .739 .821 r
.49936 .43155 m .49465 .43234 L .49745 .42961 L F
.755 .802 .89 r
.50118 .43 m .49936 .43155 L .49745 .42961 L F
.616 .55 .757 r
.4487 .52725 m .45256 .5267 L .45115 .52366 L F
0 0 0 r
.45028 .5293 m .45256 .5267 L .4487 .52725 L F
.977 .88 .669 r
.40821 .49148 m .40725 .4939 L .40859 .49506 L F
.284 .757 .936 r
.40979 .49424 m .40859 .49506 L .40725 .4939 L F
.40979 .49424 m .41138 .49481 L .40859 .49506 L F
.434 .836 .977 r
.31019 .53585 m .31265 .53531 L .3133 .53551 L F
.788 .717 .785 r
.50826 .42742 m .50442 .42674 L .5065 .42391 L F
.767 .709 .798 r
.51103 .42448 m .50826 .42742 L .5065 .42391 L F
.875 .857 .82 r
.6172 .38871 m .61297 .3902 L .61544 .38984 L F
.228 .335 .766 r
.6172 .38871 m .61979 .39046 L .61875 .38709 L F
.61875 .38709 m .6172 .38871 L .61544 .38984 L F
.61875 .38709 m .61979 .39046 L .6172 .38871 L F
0 0 .087 r
.2979 .65059 m .29677 .65499 L .29764 .65215 L F
.727 .346 .328 r
.2979 .65059 m .29764 .65215 L .29442 .64972 L F
.254 0 .252 r
.34895 .57567 m .34606 .5787 L .3479 .57801 L F
0 0 0 r
.3479 .57801 m .3502 .57405 L .34895 .57567 L F
.958 .8 .643 r
.61038 .42675 m .6093 .42239 L .61003 .42401 L F
.281 0 .27 r
.4432 .52177 m .44045 .52308 L .44066 .5212 L F
.528 .894 .971 r
.35072 .68834 m .34646 .6891 L .34919 .68872 L F
0 .155 .697 r
.35145 .68789 m .35072 .68834 L .34919 .68872 L F
.517 .416 .679 r
.35072 .68834 m .35258 .69055 L .35329 .68915 L F
0 .155 .697 r
.35145 .68789 m .35258 .69055 L .35072 .68834 L F
.633 .448 .615 r
.4192 .49544 m .4187 .49828 L .42176 .49486 L F
.42176 .49486 m .4187 .49828 L .4192 .49544 L F
.4192 .49544 m .4187 .49828 L .42176 .49486 L F
0 0 0 r
.53819 .41167 m .53578 .41437 L .537 .41305 L F
.806 .708 .172 r
.53578 .41437 m .53603 .40986 L .53466 .41129 L F
.496 .883 .964 r
.537 .41305 m .53578 .41437 L .53411 .41401 L F
.307 .239 .615 r
.46415 .54981 m .46638 .54914 L .46568 .54601 L F
.09 0 .012 r
.46415 .54981 m .46281 .55203 L .46638 .54914 L F
.298 .135 .484 r
.37706 .59042 m .37515 .58851 L .37766 .58774 L F
.37706 .59042 m .37492 .59146 L .37515 .58851 L F
.718 .638 .768 r
.385 .60441 m .38658 .60807 L .38264 .60765 L F
.789 .912 .924 r
.62355 .42522 m .62821 .42412 L .62621 .42397 L F
.625 .939 .719 r
.62821 .42412 m .63122 .42159 L .62971 .4223 L F
.633 .959 .913 r
.62971 .4223 m .62621 .42397 L .62821 .42412 L F
.712 .796 .917 r
.72186 .31474 m .71789 .31407 L .72076 .31331 L F
.515 .788 .995 r
.72076 .31331 m .72443 .31421 L .72186 .31474 L F
.41 0 0 r
.69022 .31559 m .68961 .31616 L .6896 .31593 L F
0 0 0 r
.69079 .31528 m .69022 .31559 L .68765 .31623 L F
.674 .959 .732 r
.68947 .31386 m .68765 .31623 L .69022 .31559 L F
.41 0 0 r
.69022 .31559 m .6896 .31593 L .68947 .31386 L F
0 0 0 r
.69144 .31508 m .69022 .31559 L .69079 .31528 L F
.313 0 0 r
.69428 .31584 m .69022 .31559 L .69144 .31508 L F
0 0 0 r
.25698 .52392 m .25539 .5259 L .25478 .52639 L F
.25757 .52345 m .25698 .52392 L .25926 .52292 L F
.25757 .52345 m .25539 .5259 L .25698 .52392 L F
0 .424 .848 r
.58263 .38551 m .58431 .38538 L .58114 .38424 L F
.58263 .38551 m .58555 .38669 L .58431 .38538 L F
.033 0 .238 r
.21619 .56569 m .21753 .56503 L .21818 .56258 L F
.083 .018 .477 r
.21619 .56569 m .21756 .56773 L .21753 .56503 L F
.21619 .56569 m .21583 .56936 L .21756 .56773 L F
.399 .347 .684 r
.71024 .31027 m .70902 .31404 L .70729 .31079 L F
.71024 .31027 m .7113 .3139 L .70902 .31404 L F
.395 .303 .632 r
.7113 .3139 m .71128 .31582 L .70902 .31404 L F
.311 .524 .9 r
.59132 .45887 m .59318 .46238 L .5945 .46084 L F
.346 .577 .927 r
.59318 .46238 m .59589 .46306 L .5945 .46084 L F
.283 0 0 r
.34052 .49588 m .34096 .4959 L .33704 .49465 L F
.701 .548 .676 r
.54677 .40406 m .54757 .41057 L .54976 .40456 L F
.61 .618 .834 r
.45271 .53235 m .45393 .53637 L .45626 .53379 L F
.52 .762 .985 r
.73381 .32658 m .7317 .32738 L .72985 .32566 L F
.668 .5 .648 r
.43773 .55168 m .43637 .55707 L .4345 .55296 L F
.43773 .55168 m .43853 .55621 L .43637 .55707 L F
.564 .48 .719 r
.43993 .54879 m .44131 .55527 L .43773 .55168 L F
.588 .446 .655 r
.44125 .5552 m .43773 .55168 L .44131 .55527 L F
.44125 .5552 m .43853 .55621 L .43773 .55168 L F
.366 .475 .838 r
.46205 .54008 m .46411 .54003 L .46393 .53817 L F
0 .359 .772 r
.46411 .54003 m .46351 .53821 L .46393 .53817 L F
.46401 .53971 m .46565 .54034 L .46351 .53821 L F
.46411 .54003 m .46472 .54015 L .46401 .53971 L F
.46472 .54015 m .46565 .54034 L .46401 .53971 L F
.232 .262 .687 r
.4618 .53742 m .46189 .53843 L .46393 .53817 L F
.46189 .53843 m .46205 .54008 L .46301 .5391 L F
.46189 .53843 m .46301 .5391 L .46393 .53817 L F
0 0 0 r
.24143 .58593 m .24035 .58567 L .24169 .58445 L F
.24143 .58593 m .23892 .58741 L .24035 .58567 L F
.306 .617 .957 r
.27372 .6262 m .27286 .62722 L .27181 .62607 L F
.368 .568 .915 r
.27372 .6262 m .27181 .62607 L .26936 .62297 L F
.27372 .6262 m .26936 .62297 L .27134 .62525 L F
.862 .427 .176 r
.27183 .62702 m .27372 .6262 L .27134 .62525 L F
.577 .923 .726 r
.27474 .625 m .27372 .6262 L .27183 .62702 L F
.27523 .62466 m .27372 .6262 L .27474 .625 L F
.306 .617 .957 r
.27372 .6262 m .27317 .62756 L .27286 .62722 L F
.48 .611 .904 r
.38666 .65499 m .3894 .6578 L .38741 .65608 L F
.767 .727 .816 r
.38661 .65417 m .38666 .65499 L .38741 .65608 L F
0 .55 .815 r
.38884 .65523 m .39185 .65604 L .38687 .65503 L F
.38677 .655 m .38687 .65503 L .38666 .65499 L F
.38884 .65523 m .38687 .65503 L .38677 .655 L F
.767 .727 .816 r
.38694 .65505 m .38741 .65608 L .38725 .6559 L F
.38661 .65417 m .38699 .65507 L .38694 .65505 L F
.38699 .65507 m .38741 .65608 L .38694 .65505 L F
0 0 0 r
.38687 .65503 m .38701 .65535 L .38666 .65499 L F
.767 .727 .816 r
.38652 .65422 m .38725 .6559 L .38598 .6545 L F
.38661 .65417 m .38725 .6559 L .3867 .65463 L F
0 .55 .815 r
.38884 .65523 m .38677 .655 L .38661 .65417 L F
.38677 .655 m .38666 .65499 L .38661 .65417 L F
.767 .727 .816 r
.38661 .65417 m .3867 .65463 L .38652 .65422 L F
0 0 0 r
.39185 .65604 m .3894 .6578 L .38701 .65535 L F
.39185 .65604 m .38701 .65535 L .38687 .65503 L F
.643 .943 .958 r
.64709 .34321 m .65034 .34241 L .64958 .34192 L F
.504 .891 .958 r
.65217 .34094 m .65034 .34241 L .65381 .34062 L F
.65217 .34094 m .64958 .34192 L .65034 .34241 L F
.733 .767 .88 r
.69398 .31102 m .69146 .31207 L .69015 .31038 L F
.548 .311 .508 r
.43181 .55631 m .43177 .55891 L .4291 .55921 L F
.65 .534 .709 r
.4345 .55296 m .43637 .55707 L .43181 .55631 L F
.68 .418 .519 r
.43586 .5582 m .43181 .55631 L .43637 .55707 L F
.43586 .5582 m .43177 .55891 L .43181 .55631 L F
0 0 .56 r
.58145 .39541 m .57941 .39188 L .58051 .39318 L F
.194 .49 .901 r
.5821 .39369 m .58145 .39541 L .58051 .39318 L F
.5821 .39369 m .58471 .3966 L .58145 .39541 L F
.094 0 0 r
.56559 .38744 m .56825 .38695 L .5695 .38603 L F
.63 .106 0 r
.56825 .38695 m .57213 .38771 L .5695 .38603 L F
.164 0 .197 r
.34606 .5787 m .34336 .58157 L .34419 .58055 L F
0 0 0 r
.34336 .58157 m .34194 .58383 L .34419 .58055 L F
.691 .658 .812 r
.3968 .49114 m .40051 .49135 L .39747 .49364 L F
.985 .739 .477 r
.39485 .5548 m .39649 .55294 L .39507 .55185 L F
.39485 .5548 m .39648 .55595 L .39649 .55294 L F
0 .229 .622 r
.38569 .55952 m .38412 .55865 L .38196 .55746 L F
.601 .372 .542 r
.3421 .57564 m .34191 .57801 L .33946 .57842 L F
.403 .185 .465 r
.34439 .57491 m .34191 .57801 L .3421 .57564 L F
.613 .402 .572 r
.34182 .5117 m .34441 .51036 L .34488 .50807 L F
.307 .123 .46 r
.34488 .50807 m .34636 .50978 L .34498 .50735 L F
.34488 .50807 m .34441 .51036 L .34636 .50978 L F
.055 0 0 r
.32131 .52722 m .32377 .52644 L .3239 .52544 L F
0 0 .229 r
.32131 .52722 m .32233 .52836 L .32377 .52644 L F
.32131 .52722 m .3209 .52982 L .32233 .52836 L F
.792 .973 .911 r
.25159 .52024 m .25129 .51947 L .25603 .51833 L F
.695 .973 .92 r
.25603 .51833 m .25643 .51674 L .25809 .51679 L F
.368 .81 .662 r
.24757 .52109 m .24673 .52151 L .24668 .52162 L F
.794 .991 .883 r
.2511 .51928 m .24757 .52109 L .25089 .51887 L F
.24757 .52109 m .24673 .52151 L .2476 .52097 L F
.24757 .52109 m .2476 .52097 L .25089 .51887 L F
.247 .755 .724 r
.24668 .52162 m .25159 .52024 L .2476 .52362 L F
.023 .216 .723 r
.24668 .52162 m .24729 .52222 L .24751 .52131 L F
.24668 .52162 m .24751 .52131 L .24757 .52109 L F
.247 .755 .724 r
.24668 .52162 m .24673 .52151 L .24751 .52131 L F
.24668 .52162 m .24751 .52131 L .25159 .52024 L F
.794 .991 .883 r
.25159 .52024 m .24673 .52151 L .2511 .51928 L F
.023 .216 .723 r
.24757 .52109 m .24909 .52394 L .24799 .52083 L F
.24729 .52222 m .24909 .52394 L .24757 .52109 L F
.368 .81 .662 r
.24799 .52083 m .24673 .52151 L .24757 .52109 L F
.794 .991 .883 r
.25185 .5191 m .25089 .51887 L .25207 .51812 L F
.695 .973 .92 r
.25235 .51922 m .25129 .51947 L .25195 .51912 L F
.742 .963 .938 r
.25643 .51674 m .25129 .51947 L .25207 .51812 L F
.732 .95 .949 r
.25207 .51812 m .25129 .51947 L .25159 .52024 L F
.794 .991 .883 r
.25159 .52024 m .25089 .51887 L .25185 .5191 L F
.695 .973 .92 r
.25603 .51833 m .25235 .51922 L .25643 .51674 L F
.25235 .51922 m .25195 .51912 L .25643 .51674 L F
.604 .948 .921 r
.64164 .33394 m .64429 .33254 L .64448 .33312 L F
.724 .989 .838 r
.64448 .33312 m .64612 .33077 L .64827 .33086 L F
.64448 .33312 m .64429 .33254 L .64612 .33077 L F
.46 .558 .868 r
.73017 .3131 m .72929 .31833 L .72731 .31371 L F
.115 0 0 r
.37411 .67575 m .37264 .67644 L .3726 .67469 L F
.913 .645 .518 r
.36841 .67144 m .36968 .67294 L .36828 .67424 L F
.36968 .67294 m .37264 .67644 L .37016 .67519 L F
.36968 .67294 m .37016 .67519 L .36828 .67424 L F
.765 .808 .887 r
.36828 .67424 m .37264 .67644 L .36728 .67824 L F
.33 .523 .893 r
.3726 .67469 m .37264 .67644 L .36841 .67144 L F
.658 .487 .641 r
.37052 .67686 m .37218 .67772 L .3726 .67469 L F
.36967 .67776 m .37071 .67774 L .37052 .67686 L F
.37071 .67774 m .37218 .67772 L .37052 .67686 L F
.987 .816 .585 r
.37218 .67772 m .37411 .67575 L .3726 .67469 L F
.531 .299 .508 r
.37411 .67575 m .37647 .67792 L .37619 .67527 L F
.387 0 .142 r
.42909 .59146 m .4319 .59105 L .43183 .58996 L F
.32 0 .143 r
.4319 .59105 m .43427 .59041 L .43183 .58996 L F
.742 .877 .942 r
.46888 .44724 m .46403 .44817 L .46727 .44576 L F
.759 .854 .921 r
.46727 .44576 m .47106 .44573 L .46888 .44724 L F
.587 .833 .463 r
.63277 .35266 m .63386 .35116 L .6312 .35109 L F
.63277 .35266 m .63537 .34931 L .63386 .35116 L F
.839 .722 .735 r
.39345 .6619 m .39727 .66239 L .39767 .6596 L F
.847 .645 .629 r
.39572 .66516 m .39727 .66239 L .39345 .6619 L F
.498 0 0 r
.36887 .55748 m .37152 .55912 L .37087 .55632 L F
.947 .665 .47 r
.33277 .65635 m .33292 .65941 L .33005 .65789 L F
.326 .18 .523 r
.33468 .65758 m .33292 .65941 L .33277 .65635 L F
.528 .011 0 r
.33468 .65758 m .33277 .65635 L .33005 .65789 L F
0 0 0 r
.66303 .38721 m .66089 .38881 L .66313 .38711 L F
.65978 .39022 m .66089 .38881 L .66303 .38721 L F
0 0 .22 r
.32626 .64009 m .3263 .64251 L .32694 .64129 L F
.934 .763 .645 r
.60845 .44998 m .60772 .44604 L .60683 .44896 L F
.959 .72 .531 r
.6065 .45161 m .60845 .44998 L .60683 .44896 L F
.6065 .45161 m .60836 .4527 L .60845 .44998 L F
0 0 0 r
.68442 .29816 m .68204 .30158 L .68363 .29942 L F
.686 .978 .817 r
.68204 .30158 m .68011 .30199 L .68363 .29942 L F
0 0 0 r
.66474 .37577 m .66061 .37733 L .66322 .37624 L F
.66693 .37369 m .66734 .37252 L .66474 .37577 L F
.584 .932 .755 r
.66693 .37369 m .66474 .37577 L .66322 .37624 L F
.404 .373 .71 r
.47611 .5487 m .47648 .54927 L .47435 .54952 L F
.41 .46 .802 r
.47435 .54952 m .47648 .54927 L .47713 .55236 L F
.706 .56 .687 r
.22808 .57535 m .22782 .57793 L .23141 .57592 L F
.446 .485 .806 r
.21739 .58814 m .21935 .58759 L .21793 .5838 L F
.005 .09 .602 r
.21739 .58814 m .21912 .59024 L .21935 .58759 L F
.208 0 .135 r
.28037 .56979 m .27743 .5723 L .27961 .57143 L F
.563 .199 .309 r
.27961 .57143 m .28236 .57159 L .28037 .56979 L F
.653 .321 .399 r
.53486 .47231 m .53766 .47452 L .5337 .47488 L F
.53486 .47231 m .5377 .47244 L .53766 .47452 L F
0 0 .251 r
.22248 .55291 m .22426 .55182 L .22493 .54906 L F
0 0 0 r
.22248 .55291 m .223 .55367 L .22426 .55182 L F
.22248 .55291 m .22167 .55506 L .223 .55367 L F
.859 .52 .409 r
.39212 .65834 m .39627 .65831 L .39398 .65597 L F
.905 .766 .697 r
.39345 .6619 m .39627 .65831 L .39212 .65834 L F
.826 .529 .486 r
.39767 .6596 m .39398 .65597 L .39627 .65831 L F
.839 .722 .735 r
.39345 .6619 m .39767 .6596 L .39627 .65831 L F
.564 .351 .55 r
.62257 .39863 m .62523 .39762 L .62495 .39506 L F
.442 .646 .945 r
.62768 .39481 m .62495 .39506 L .62654 .39299 L F
.445 .267 .544 r
.62495 .39506 m .62768 .39481 L .62654 .39299 L F
.62495 .39506 m .62523 .39762 L .62768 .39481 L F
.346 0 .088 r
.68173 .31941 m .67844 .32189 L .67938 .32041 L F
.27 .299 .707 r
.55813 .41102 m .55908 .41502 L .56059 .41267 L F
.68 .523 .666 r
.55908 .41502 m .56215 .41456 L .55929 .41733 L F
.854 .866 .849 r
.55929 .41733 m .56059 .41267 L .55908 .41502 L F
.243 0 0 r
.31161 .55917 m .30994 .56137 L .31242 .56078 L F
.859 .52 .409 r
.39212 .65834 m .39398 .65597 L .39185 .65604 L F
.61 .883 .562 r
.69356 .34468 m .69481 .34358 L .69196 .34675 L F
.647 .936 .679 r
.69356 .34468 m .69196 .34675 L .69047 .34758 L F
.441 .626 .931 r
.61672 .35635 m .61818 .35404 L .61538 .35505 L F
.633 .172 .14 r
.61529 .35794 m .61672 .35635 L .61538 .35505 L F
.61529 .35794 m .61937 .35821 L .61672 .35635 L F
.309 .777 .66 r
.34165 .52724 m .33944 .52821 L .34284 .52665 L F
.729 .667 .789 r
.36971 .65896 m .37123 .66267 L .37387 .6595 L F
.44 .223 .486 r
.50992 .48474 m .50722 .48798 L .50723 .48538 L F
.773 .997 .82 r
.65113 .32826 m .64827 .33086 L .64951 .32843 L F
.754 .984 .907 r
.64951 .32843 m .64827 .33086 L .64612 .33077 L F
.854 .716 .71 r
.36405 .61634 m .3654 .62071 L .36247 .62014 L F
.855 .709 .7 r
.36247 .62014 m .3654 .62071 L .36394 .62306 L F
.715 .514 .616 r
.3654 .62071 m .3657 .62373 L .36394 .62306 L F
.756 .666 .762 r
.36795 .61744 m .3654 .62071 L .36405 .61634 L F
.555 .383 .603 r
.36795 .61744 m .36821 .62029 L .3654 .62071 L F
.421 .298 .607 r
.36781 .62296 m .3654 .62071 L .36821 .62029 L F
.36781 .62296 m .3657 .62373 L .3654 .62071 L F
.626 .353 .485 r
.45306 .51742 m .45609 .51704 L .4564 .51434 L F
.45306 .51742 m .45609 .51704 L .4564 .51434 L F
.431 .247 .528 r
.45888 .51322 m .45609 .51704 L .4564 .51434 L F
.45888 .51322 m .45609 .51704 L .4564 .51434 L F
.554 .814 .994 r
.73289 .33372 m .73517 .33138 L .73242 .33184 L F
.73289 .33372 m .73627 .33291 L .73517 .33138 L F
.514 .747 .98 r
.42921 .53178 m .43273 .53294 L .43042 .53356 L F
0 0 0 r
.43078 .53457 m .43042 .53356 L .43273 .53294 L F
.43078 .53457 m .42955 .53666 L .43042 .53356 L F
.694 .395 .464 r
.49317 .49823 m .48907 .50028 L .48907 .4978 L F
.49317 .49823 m .493 .50094 L .48907 .50028 L F
.546 .27 .448 r
.49317 .49823 m .4957 .50021 L .493 .50094 L F
.566 .261 .411 r
.4959 .49808 m .4957 .50021 L .49317 .49823 L F
0 0 0 r
.69117 .37133 m .69205 .37019 L .69331 .36964 L F
.873 .99 .819 r
.69205 .37019 m .69416 .36967 L .69468 .36699 L F
0 0 0 r
.69266 .37036 m .69331 .36964 L .69472 .36903 L F
.69117 .37133 m .69331 .36964 L .69266 .37036 L F
.858 .908 .499 r
.69468 .36699 m .69439 .36845 L .69575 .36586 L F
.69439 .36845 m .69416 .36967 L .6949 .36789 L F
.69439 .36845 m .6949 .36789 L .69575 .36586 L F
0 0 .118 r
.69575 .36586 m .69777 .36158 L .6968 .3635 L F
.735 .897 .509 r
.69468 .36699 m .69575 .36586 L .6968 .3635 L F
0 .019 .562 r
.44765 .57696 m .44915 .57532 L .44824 .57446 L F
.31 .294 .679 r
.44915 .57532 m .45212 .57781 L .45243 .57524 L F
.44915 .57532 m .44958 .57789 L .45212 .57781 L F
.632 .893 .568 r
.61597 .37167 m .61883 .36865 L .619 .36854 L F
0 0 0 r
.619 .36854 m .61883 .36865 L .62066 .36671 L F
.6 .184 .225 r
.3163 .54719 m .31461 .54885 L .31232 .54805 L F
.815 .966 .648 r
.31715 .54513 m .31461 .54885 L .3163 .54719 L F
0 .239 .755 r
.58781 .40046 m .58541 .39856 L .58471 .3966 L F
.82 .995 .759 r
.23265 .53425 m .23023 .53713 L .23061 .53524 L F
0 0 0 r
.22922 .53952 m .23061 .53524 L .23023 .53713 L F
.187 .669 .929 r
.43773 .59865 m .4381 .59777 L .43604 .59766 L F
0 0 0 r
.53898 .41149 m .53819 .41167 L .537 .41305 L F
.53898 .41149 m .54084 .41062 L .53819 .41167 L F
.659 .456 .599 r
.29043 .64653 m .29027 .64977 L .28795 .64944 L F
.822 .382 .192 r
.29043 .64653 m .29442 .64972 L .29027 .64977 L F
.913 .525 .258 r
.5983 .4233 m .60049 .42722 L .6016 .42762 L F
.978 .706 .444 r
.60024 .4293 m .6016 .42762 L .60049 .42722 L F
.60024 .4293 m .60154 .43032 L .6016 .42762 L F
.544 0 0 r
.38347 .50719 m .37792 .5037 L .38124 .5066 L F
.38347 .50719 m .38159 .50642 L .37792 .5037 L F
.759 .249 0 r
.38159 .50642 m .37689 .50165 L .37792 .5037 L F
0 0 0 r
.65561 .33905 m .65217 .34094 L .65381 .34062 L F
.287 .786 .853 r
.31527 .63737 m .3178 .63737 L .31552 .63785 L F
.4 .53 .872 r
.31842 .63986 m .31552 .63785 L .3178 .63737 L F
.307 .353 .746 r
.32034 .63857 m .31842 .63986 L .3178 .63737 L F
.464 0 0 r
.32034 .63857 m .3178 .63737 L .31527 .63737 L F
.32034 .63857 m .31527 .63737 L .31839 .63529 L F
0 0 .066 r
.31527 .63737 m .31458 .64 L .31642 .63738 L F
.31527 .63737 m .31642 .63738 L .31706 .63645 L F
.287 .786 .853 r
.31527 .63737 m .31552 .63785 L .31432 .63736 L F
.31527 .63737 m .31432 .63736 L .31363 .63707 L F
.707 .811 .929 r
.59438 .35559 m .58891 .35535 L .59105 .35429 L F
.945 .952 .743 r
.59316 .35344 m .59438 .35559 L .59105 .35429 L F
.59316 .35344 m .59365 .35662 L .59438 .35559 L F
.852 .755 .756 r
.57773 .41328 m .57924 .4173 L .57505 .41684 L F
.807 .575 .586 r
.57924 .4173 m .57524 .41986 L .57505 .41684 L F
.57924 .4173 m .57884 .42067 L .57524 .41986 L F
.884 .767 .727 r
.5797 .41454 m .57924 .4173 L .57773 .41328 L F
.957 .797 .641 r
.42018 .58472 m .42134 .58791 L .4218 .58537 L F
.888 .99 .755 r
.34414 .67856 m .34121 .68227 L .34484 .68038 L F
.509 0 0 r
.26055 .62617 m .26296 .6264 L .26381 .62713 L F
.692 .828 .948 r
.46061 .44846 m .45959 .45134 L .458 .44946 L F
.46061 .44846 m .46237 .44996 L .45959 .45134 L F
0 0 0 r
.28089 .54584 m .278 .54838 L .27902 .54702 L F
.726 .207 0 r
.38337 .53222 m .38713 .53567 L .38627 .53473 L F
.14 .135 .59 r
.23313 .5459 m .23245 .54983 L .23466 .54917 L F
.23313 .5459 m .23344 .54961 L .23245 .54983 L F
0 0 0 r
.23344 .54961 m .23158 .55215 L .23245 .54983 L F
.779 .682 .757 r
.33351 .52556 m .33499 .52747 L .33424 .52413 L F
.518 .531 .808 r
.33798 .69415 m .33886 .68986 L .33644 .69051 L F
.33798 .69415 m .34068 .6937 L .33886 .68986 L F
.523 .582 .856 r
.33798 .69415 m .34102 .69564 L .34068 .6937 L F
.688 .974 .913 r
.64071 .3461 m .64455 .34448 L .64342 .34513 L F
0 0 0 r
.64342 .34513 m .64455 .34448 L .64709 .34321 L F
.123 .468 .893 r
.60385 .35788 m .60429 .35617 L .60247 .35685 L F
.60385 .35788 m .60798 .3603 L .60429 .35617 L F
.418 .098 .315 r
.4466 .58131 m .44919 .58076 L .44958 .57789 L F
.269 0 .276 r
.44958 .57789 m .44919 .58076 L .45212 .57781 L F
.883 .451 .093 r
.60681 .41669 m .60872 .41798 L .60951 .41995 L F
.875 .695 .655 r
.44005 .55922 m .43853 .55621 L .44125 .5552 L F
.44005 .55922 m .43827 .55953 L .43853 .55621 L F
.886 .499 .293 r
.44005 .55922 m .43959 .56191 L .43827 .55953 L F
.44005 .55922 m .44194 .56243 L .43959 .56191 L F
.741 .628 .734 r
.45115 .52366 m .45415 .52021 L .45216 .52206 L F
.655 .872 .98 r
.58826 .45957 m .58964 .46078 L .59132 .45887 L F
.864 .71 .69 r
.57108 .41301 m .56771 .41122 L .56994 .40962 L F
.57108 .41301 m .5695 .4148 L .56771 .41122 L F
.937 .946 .767 r
.57108 .41301 m .56821 .41715 L .5695 .4148 L F
.271 .752 .928 r
.57227 .41711 m .56821 .41715 L .57108 .41301 L F
.726 .989 .83 r
.57108 .41301 m .57422 .41046 L .57414 .41285 L F
.564 .43 .656 r
.57414 .41285 m .57227 .41711 L .57108 .41301 L F
.891 .977 .821 r
.68876 .29032 m .68953 .29134 L .6867 .29473 L F
.806 .993 .873 r
.69023 .28891 m .68953 .29134 L .68876 .29032 L F
.69023 .28891 m .69263 .28854 L .68953 .29134 L F
0 0 0 r
.61378 .34761 m .61635 .34708 L .6179 .34644 L F
.046 0 0 r
.61635 .34708 m .62057 .34589 L .6179 .34644 L F
.724 .706 .833 r
.41677 .46869 m .41989 .46978 L .41694 .46934 L F
.796 .85 .891 r
.41989 .46978 m .4148 .4715 L .41694 .46934 L F
.738 .697 .812 r
.42307 .46845 m .41989 .46978 L .41677 .46869 L F
0 .059 .566 r
.36754 .51171 m .36877 .51287 L .36942 .51362 L F
.735 .21 0 r
.36877 .51287 m .3719 .51508 L .36942 .51362 L F
.937 .584 .169 r
.59579 .41796 m .59397 .41403 L .59441 .41719 L F
.888 .466 .173 r
.59486 .41916 m .59579 .41796 L .59441 .41719 L F
.59486 .41916 m .59666 .42 L .59579 .41796 L F
.82 .883 .889 r
.59039 .37548 m .58739 .37786 L .58628 .37694 L F
.437 .143 .367 r
.57309 .43659 m .5761 .43607 L .57596 .43321 L F
.038 .03 .517 r
.57596 .43321 m .57737 .43217 L .57605 .43019 L F
0 0 .132 r
.57596 .43321 m .57642 .43267 L .57737 .43217 L F
.57596 .43321 m .5761 .43607 L .57642 .43267 L F
.785 .805 .869 r
.70214 .26882 m .69906 .26946 L .70028 .26658 L F
.706 .403 .461 r
.70214 .26882 m .70169 .27129 L .69906 .26946 L F
.466 .681 .959 r
.70028 .26658 m .70389 .26789 L .70214 .26882 L F
.111 0 .277 r
.70214 .26882 m .70389 .26789 L .70169 .27129 L F
.044 0 0 r
.24789 .62109 m .24948 .6211 L .24847 .62125 L F
.213 0 0 r
.34419 .58055 m .3479 .57801 L .34606 .5787 L F
.707 .985 .835 r
.65113 .32826 m .65265 .32594 L .65352 .32673 L F
.65113 .32826 m .64951 .32843 L .65265 .32594 L F
.862 .876 .846 r
.24397 .5977 m .24357 .60136 L .24642 .59824 L F
.387 .34 .684 r
.21457 .57765 m .21597 .57482 L .21497 .57573 L F
.725 .82 .924 r
.71789 .32765 m .71849 .32963 L .72112 .32723 L F
.124 0 .111 r
.47171 .5851 m .47099 .58753 L .46869 .58807 L F
.173 0 .233 r
.47436 .58195 m .4735 .58399 L .47171 .5851 L F
0 0 .021 r
.47262 .58604 m .47171 .5851 L .4735 .58399 L F
.47262 .58604 m .47099 .58753 L .47171 .5851 L F
.687 .251 .21 r
.37897 .69345 m .38324 .69398 L .38086 .69165 L F
.548 .289 .475 r
.38324 .69398 m .38377 .69138 L .38086 .69165 L F
.351 .8 .659 r
.56846 .46463 m .56658 .46566 L .56904 .46439 L F
.282 0 0 r
.60198 .45973 m .60194 .46015 L .60116 .46107 L F
.60198 .45973 m .60322 .46019 L .60194 .46015 L F
.537 .464 .721 r
.33644 .69051 m .3383 .68741 L .33694 .68779 L F
0 0 0 r
.66916 .37093 m .66734 .37252 L .66693 .37369 L F
.539 .621 .882 r
.34793 .63459 m .35312 .63745 L .35091 .63332 L F
.137 .489 .903 r
.35583 .63666 m .35091 .63332 L .35312 .63745 L F
.107 .584 .911 r
.39439 .67499 m .39679 .67584 L .39538 .67602 L F
.592 .037 0 r
.39246 .67399 m .39439 .67499 L .39538 .67602 L F
.39246 .67399 m .39538 .67602 L .3941 .67653 L F
.701 .812 .934 r
.39538 .67602 m .39683 .67329 L .39443 .67613 L F
.39538 .67602 m .39443 .67613 L .3941 .67653 L F
.107 .584 .911 r
.39679 .67584 m .39803 .67629 L .39538 .67602 L F
0 0 .382 r
.39923 .67454 m .39922 .6749 L .3981 .67233 L F
.643 .898 .573 r
.39803 .67629 m .39923 .67454 L .39538 .67602 L F
.39803 .67629 m .39922 .6749 L .39923 .67454 L F
.83 .969 .654 r
.6867 .29473 m .68442 .29816 L .68534 .29533 L F
.748 .834 .378 r
.68534 .29533 m .68442 .29816 L .68363 .29942 L F
.283 .161 .531 r
.47713 .55236 m .47752 .55551 L .47564 .55612 L F
.328 .284 .656 r
.47752 .55551 m .47816 .55832 L .47564 .55612 L F
.839 .38 0 r
.43222 .53711 m .43289 .53798 L .43265 .53887 L F
.737 .942 .619 r
.43234 .54 m .43265 .53887 L .43448 .53721 L F
.591 .247 .355 r
.43265 .53887 m .43679 .5363 L .43448 .53721 L F
.43265 .53887 m .43609 .54002 L .43679 .5363 L F
.583 .156 .195 r
.43265 .53887 m .43496 .54067 L .43609 .54002 L F
.839 .38 0 r
.43289 .53798 m .43496 .54067 L .43265 .53887 L F
.737 .942 .619 r
.43223 .54015 m .43265 .53887 L .43234 .54 L F
.5 .855 .992 r
.43223 .54015 m .43043 .5394 L .43265 .53887 L F
.975 .774 .351 r
.43223 .54015 m .43105 .54002 L .43265 .53887 L F
.43223 .54015 m .43198 .54282 L .43105 .54002 L F
.571 .171 .245 r
.54432 .47241 m .54882 .47178 L .54692 .47413 L F
.452 .065 .213 r
.54882 .47178 m .54973 .47412 L .54692 .47413 L F
.54882 .47178 m .55085 .47169 L .54973 .47412 L F
0 0 .361 r
.54626 .41608 m .54628 .41868 L .54544 .41393 L F
.337 .515 .885 r
.54823 .41839 m .54628 .41868 L .54626 .41608 L F
.974 .821 .631 r
.43258 .54666 m .43097 .54567 L .43198 .54282 L F
0 0 .411 r
.3215 .60459 m .32306 .60553 L .32288 .60308 L F
.3215 .60459 m .32168 .60744 L .32306 .60553 L F
0 0 0 r
.29935 .50942 m .29913 .50988 L .29795 .51135 L F
.63386 .35116 m .63537 .34931 L .63783 .34822 L F
.634 .931 .969 r
.34671 .63416 m .35091 .63332 L .34793 .63459 L F
.34671 .63416 m .35091 .63332 L .34793 .63459 L F
.847 .906 .877 r
.55448 .44542 m .55517 .44704 L .55894 .44287 L F
.55877 .44281 m .55894 .44287 L .55928 .4425 L F
.55448 .44542 m .55894 .44287 L .55877 .44281 L F
.709 .631 .768 r
.55517 .44704 m .55947 .44651 L .55928 .4425 L F
.157 .187 .641 r
.55931 .44312 m .55947 .44651 L .56072 .44539 L F
.55997 .44389 m .56072 .44539 L .56103 .44511 L F
.55931 .44312 m .56072 .44539 L .55997 .44389 L F
.858 .479 .329 r
.55928 .4425 m .561 .44454 L .55997 .44389 L F
.847 .906 .877 r
.55448 .44542 m .55928 .4425 L .55718 .4421 L F
.858 .479 .329 r
.55928 .4425 m .55997 .44389 L .55718 .4421 L F
.715 .18 0 r
.55766 .44241 m .561 .44454 L .5575 .44235 L F
.157 .187 .641 r
.55928 .4425 m .55931 .44312 L .56103 .44511 L F
.715 .18 0 r
.5575 .44235 m .56 .44392 L .56103 .44511 L F
.56 .44392 m .561 .44454 L .56103 .44511 L F
.55718 .4421 m .55766 .44241 L .5575 .44235 L F
.568 .179 .264 r
.55849 .44901 m .55517 .44704 L .55668 .44882 L F
.55821 .44884 m .55947 .44651 L .55517 .44704 L F
.55849 .44901 m .5585 .44897 L .55821 .44884 L F
.5585 .44897 m .55947 .44651 L .55821 .44884 L F
.268 .449 .855 r
.55758 .44766 m .55705 .44834 L .55448 .44542 L F
.55705 .44834 m .55668 .44882 L .5561 .44793 L F
.55705 .44834 m .5561 .44793 L .55448 .44542 L F
0 .092 .646 r
.55448 .44542 m .55668 .44882 L .55517 .44704 L F
.546 .438 .682 r
.29088 .62342 m .28885 .62696 L .28878 .62392 L F
.28885 .62696 m .29088 .62342 L .28878 .62392 L F
.636 .196 .187 r
.29027 .64977 m .29442 .64972 L .2926 .6518 L F
.38 0 0 r
.29456 .65629 m .29583 .65617 L .29171 .65551 L F
.56 0 0 r
.29442 .64972 m .2948 .65061 L .2926 .6518 L F
.29442 .64972 m .29764 .65215 L .29559 .65104 L F
0 .372 .745 r
.2948 .65061 m .29764 .65215 L .29681 .65153 L F
.712 .743 .232 r
.29764 .65215 m .29713 .65345 L .29681 .65153 L F
.29764 .65215 m .29724 .65346 L .29713 .65345 L F
.29724 .65346 m .29677 .65499 L .29713 .65345 L F
.86 .878 .85 r
.29527 .65237 m .29713 .65345 L .29449 .65622 L F
.38 0 0 r
.29708 .65345 m .29713 .65345 L .29527 .65237 L F
.29909 .65466 m .29713 .65345 L .29708 .65345 L F
.569 .172 .25 r
.30096 .65321 m .29681 .65153 L .29692 .65219 L F
.29831 .65338 m .29692 .65219 L .29713 .65345 L F
.30096 .65321 m .29692 .65219 L .29831 .65338 L F
.56 0 0 r
.29464 .65022 m .29559 .65104 L .2948 .65061 L F
.29442 .64972 m .29559 .65104 L .29464 .65022 L F
.56 .936 .866 r
.29677 .65499 m .29583 .65617 L .29456 .65629 L F
.658 .938 .966 r
.60843 .45916 m .60773 .45823 L .60322 .46019 L F
.913 .831 .751 r
.60843 .45916 m .60791 .45531 L .60773 .45823 L F
0 0 0 r
.24762 .59405 m .24642 .59824 L .24485 .5945 L F
.814 .765 .253 r
.24773 .59281 m .24699 .59679 L .24762 .59405 L F
0 0 .206 r
.24766 .59316 m .24782 .59591 L .24699 .59679 L F
.91 .906 .503 r
.24773 .59281 m .24762 .59405 L .2476 .59228 L F
0 0 .206 r
.24773 .59281 m .24773 .59304 L .24766 .59316 L F
.24773 .59304 m .24782 .59591 L .24766 .59316 L F
.52 .749 .979 r
.2476 .59228 m .24761 .59325 L .24485 .5945 L F
.24761 .59325 m .24762 .59405 L .24707 .59414 L F
.24761 .59325 m .24707 .59414 L .24485 .5945 L F
.447 .051 .193 r
.24782 .59591 m .24731 .59608 L .24699 .59679 L F
0 0 0 r
.24762 .59405 m .24699 .59679 L .24657 .5977 L F
.988 .853 .485 r
.24485 .5945 m .24397 .5977 L .24347 .5956 L F
.579 .008 0 r
.24699 .59679 m .24347 .5956 L .24397 .5977 L F
.24699 .59679 m .24511 .59678 L .24347 .5956 L F
.447 .051 .193 r
.24731 .59608 m .24511 .59678 L .24699 .59679 L F
0 0 0 r
.24657 .5977 m .24699 .59679 L .24642 .59824 L F
.524 .869 .991 r
.24699 .59679 m .24397 .5977 L .24642 .59824 L F
.783 .64 .703 r
.42047 .59785 m .42284 .59515 L .41868 .5943 L F
.364 .075 .333 r
.42282 .59716 m .42284 .59515 L .42047 .59785 L F
.222 0 .308 r
.42556 .59376 m .42284 .59515 L .42282 .59716 L F
.371 .218 .54 r
.32935 .57871 m .33143 .58075 L .33152 .57805 L F
.32935 .57871 m .32938 .58121 L .33143 .58075 L F
0 0 .031 r
.47618 .57797 m .47581 .58046 L .47436 .58195 L F
0 0 .142 r
.47436 .58195 m .47528 .58293 L .4735 .58399 L F
.47436 .58195 m .47581 .58046 L .47528 .58293 L F
0 0 0 r
.22693 .58048 m .22782 .57793 L .22572 .57794 L F
0 0 .37 r
.47662 .56791 m .47692 .57056 L .47598 .57215 L F
0 0 .444 r
.47692 .57056 m .4768 .57502 L .47598 .57215 L F
.955 .694 .501 r
.53366 .40484 m .53482 .40842 L .53295 .40687 L F
.738 .697 .812 r
.42307 .46845 m .41677 .46869 L .42149 .46598 L F
.731 .765 .88 r
.42557 .46674 m .42307 .46845 L .42149 .46598 L F
0 0 0 r
.56271 .41105 m .5651 .40862 L .56371 .41016 L F
.56371 .41016 m .5651 .40862 L .56668 .40809 L F
0 .396 .779 r
.26381 .62713 m .26608 .6284 L .26486 .62812 L F
.77 .323 .19 r
.26695 .62955 m .26903 .62924 L .27069 .63187 L F
0 .14 .589 r
.26523 .62825 m .26695 .62955 L .26904 .63105 L F
.26456 .62776 m .26519 .62823 L .26523 .62825 L F
.831 .436 .3 r
.26486 .62812 m .26903 .62924 L .26695 .62955 L F
0 .14 .589 r
.26519 .62823 m .26695 .62955 L .26523 .62825 L F
.209 0 0 r
.26608 .6284 m .26903 .62924 L .26506 .62817 L F
.26503 .62816 m .26506 .62817 L .26486 .62812 L F
.26608 .6284 m .26506 .62817 L .26503 .62816 L F
.429 .809 .991 r
.28149 .57634 m .28256 .57489 L .27925 .57572 L F
.28149 .57634 m .28434 .57588 L .28256 .57489 L F
.134 .057 .496 r
.21583 .56936 m .21778 .57049 L .21756 .56773 L F
.21583 .56936 m .21602 .57195 L .21778 .57049 L F
.988 .85 .479 r
.39655 .59305 m .39792 .59141 L .39698 .59059 L F
.39655 .59305 m .39754 .59483 L .39792 .59141 L F
.984 .902 .638 r
.73974 .3149 m .73813 .31531 L .74233 .31447 L F
.832 .725 .746 r
.29165 .53 m .28739 .52951 L .29033 .52579 L F
.532 0 0 r
.29165 .53 m .28884 .53051 L .28739 .52951 L F
.521 .544 .82 r
.29379 .52731 m .29272 .52866 L .29033 .52579 L F
.622 .695 .896 r
.29464 .5291 m .29165 .53 L .29379 .52731 L F
.231 .038 .4 r
.2964 .52643 m .29464 .5291 L .29379 .52731 L F
.2964 .52643 m .29627 .52886 L .29464 .5291 L F
.775 .926 .935 r
.29279 .52769 m .29423 .52878 L .29627 .52886 L F
.29423 .52878 m .29464 .5291 L .29584 .52892 L F
.29423 .52878 m .29584 .52892 L .29627 .52886 L F
.521 .544 .82 r
.29272 .52866 m .29165 .53 L .29119 .52852 L F
.29272 .52866 m .29119 .52852 L .29033 .52579 L F
.854 .993 .837 r
.28995 .5285 m .29165 .53 L .29464 .5291 L F
.28995 .5285 m .28884 .53051 L .29165 .53 L F
.944 .876 .738 r
.38106 .60756 m .38031 .60622 L .38264 .60765 L F
.854 .862 .847 r
.385 .60441 m .38264 .60765 L .38031 .60622 L F
.925 .71 .593 r
.37971 .5202 m .37945 .52313 L .38155 .52388 L F
.912 .578 .398 r
.37945 .52313 m .3796 .5254 L .38155 .52388 L F
.958 .68 .468 r
.38155 .52388 m .3796 .5254 L .38149 .5264 L F
0 .18 .715 r
.58916 .38817 m .59108 .3915 L .5913 .39011 L F
0 .319 .778 r
.59108 .3915 m .59253 .39159 L .5913 .39011 L F
.59108 .3915 m .59426 .39325 L .59253 .39159 L F
.254 .749 .673 r
.44976 .59466 m .45201 .59381 L .44973 .59486 L F
.808 .379 .225 r
.33261 .59223 m .32876 .59164 L .32818 .59047 L F
.751 .537 .606 r
.32923 .5916 m .32603 .58993 L .32818 .59047 L F
.774 .739 .821 r
.3292 .59163 m .33134 .59358 L .32876 .59164 L F
.709 .345 .357 r
.32876 .59164 m .3304 .59287 L .32925 .59162 L F
.32876 .59164 m .32925 .59162 L .32818 .59047 L F
.648 .891 .984 r
.32917 .59159 m .32876 .59164 L .3307 .59193 L F
.774 .739 .821 r
.32917 .59159 m .3292 .59163 L .32876 .59164 L F
.751 .537 .606 r
.32925 .59162 m .32917 .59159 L .32923 .5916 L F
.648 .891 .984 r
.33432 .59095 m .32917 .59159 L .33261 .59223 L F
.32917 .59159 m .3307 .59193 L .33261 .59223 L F
0 0 0 r
.33261 .59223 m .33134 .59358 L .33432 .59095 L F
.774 .739 .821 r
.33432 .59095 m .33214 .59287 L .32917 .59159 L F
.33214 .59287 m .33134 .59358 L .32917 .59159 L F
0 .118 .569 r
.33134 .59358 m .3304 .59287 L .32876 .59164 L F
.751 .537 .606 r
.3304 .59287 m .32817 .59136 L .3285 .59144 L F
.3304 .59287 m .3285 .59144 L .32917 .59159 L F
.3304 .59287 m .32917 .59159 L .32925 .59162 L F
.32817 .59136 m .32603 .58993 L .32923 .5916 L F
.681 .323 .36 r
.5377 .47244 m .5405 .47489 L .53766 .47452 L F
.516 .745 .978 r
.3641 .52681 m .36784 .52826 L .36716 .52604 L F
.171 0 0 r
.36374 .52767 m .36784 .52826 L .3641 .52681 L F
.36374 .52767 m .3663 .52813 L .36784 .52826 L F
.964 .939 .69 r
.36784 .52826 m .3663 .52813 L .36716 .52604 L F
.325 0 .216 r
.37092 .52702 m .37038 .52871 L .36784 .52826 L F
.771 .996 .805 r
.55289 .42272 m .55645 .42025 L .5568 .42048 L F
.303 .03 .323 r
.55645 .42025 m .55929 .41733 L .55931 .41989 L F
.509 .44 .715 r
.55931 .41989 m .5568 .42048 L .55645 .42025 L F
.436 .623 .931 r
.58521 .35731 m .58654 .35976 L .58374 .35948 L F
.58521 .35731 m .58654 .35976 L .58374 .35948 L F
.891 .635 .545 r
.33912 .68427 m .34245 .68517 L .34223 .6881 L F
.081 0 .39 r
.34223 .6881 m .34245 .68517 L .3442 .68398 L F
0 0 0 r
.56103 .44511 m .55947 .44651 L .55849 .44901 L F
.255 .275 .69 r
.21593 .58174 m .21683 .57743 L .21457 .57765 L F
.21593 .58174 m .2174 .58126 L .21683 .57743 L F
.199 .222 .659 r
.21593 .58174 m .21793 .5838 L .2174 .58126 L F
.83 .969 .654 r
.6867 .29473 m .68534 .29533 L .68655 .29375 L F
.891 .977 .821 r
.68876 .29032 m .6867 .29473 L .68655 .29375 L F
.352 .662 .972 r
.74289 .32081 m .74234 .31918 L .73945 .31851 L F
.273 0 0 r
.23434 .57524 m .23567 .57557 L .23645 .57529 L F
.036 .453 .876 r
.23399 .57384 m .23567 .57557 L .23434 .57524 L F
.23399 .57384 m .23567 .57557 L .23434 .57524 L F
.961 .624 .277 r
.23399 .57384 m .23514 .57576 L .23567 .57557 L F
.566 .401 .617 r
.23357 .57778 m .23567 .57557 L .23434 .57524 L F
.23357 .57778 m .23614 .57743 L .23567 .57557 L F
.961 .624 .277 r
.23514 .57576 m .23614 .57743 L .23567 .57557 L F
.273 0 0 r
.23645 .57529 m .23567 .57557 L .23784 .57533 L F
.441 0 .057 r
.23614 .57743 m .23784 .57533 L .23567 .57557 L F
.23614 .57743 m .2407 .57565 L .23784 .57533 L F
.854 .866 .849 r
.55929 .41733 m .56215 .41456 L .56059 .41267 L F
.778 .523 0 r
.3981 .57152 m .39861 .57445 L .39897 .57551 L F
.864 .744 .23 r
.39843 .57586 m .39897 .57551 L .39861 .57445 L F
.39843 .57586 m .39864 .57805 L .39897 .57551 L F
.95 .641 .413 r
.39006 .54233 m .39214 .54565 L .39156 .54383 L F
.352 0 0 r
.31243 .62718 m .3168 .62734 L .31415 .627 L F
.689 .535 .673 r
.3168 .62734 m .31243 .62718 L .31415 .627 L F
.3168 .62734 m .31409 .6309 L .31243 .62718 L F
.3168 .62734 m .31689 .6301 L .31409 .6309 L F
.694 .657 .809 r
.3168 .62734 m .3176 .62311 L .31415 .627 L F
.707 .314 .3 r
.3168 .62734 m .31902 .62962 L .31689 .6301 L F
.727 .301 .236 r
.31902 .62962 m .3168 .62734 L .31415 .627 L F
.686 .745 .896 r
.42563 .48275 m .42301 .48519 L .42633 .48508 L F
.553 .206 .334 r
.42287 .48732 m .42633 .48508 L .42301 .48519 L F
.42287 .48732 m .42588 .48771 L .42633 .48508 L F
.285 .204 .585 r
.42633 .48508 m .42804 .4812 L .42563 .48275 L F
.42633 .48508 m .42875 .48422 L .42804 .4812 L F
0 0 .017 r
.42588 .48771 m .42875 .48422 L .42633 .48508 L F
.612 .393 .56 r
.52188 .47557 m .52186 .47821 L .51953 .47824 L F
.608 .379 .544 r
.52455 .47532 m .52186 .47821 L .52188 .47557 L F
0 .184 .718 r
.26141 .51638 m .26149 .51671 L .26026 .51683 L F
.035 .603 .767 r
.25979 .51688 m .26026 .51683 L .26214 .51699 L F
0 .184 .718 r
.26149 .51671 m .26187 .51824 L .26026 .51683 L F
.035 .603 .767 r
.25809 .51679 m .26026 .51683 L .25979 .51688 L F
.408 0 .122 r
.46869 .58807 m .46776 .59022 L .46511 .59049 L F
.328 0 .248 r
.47099 .58753 m .46776 .59022 L .46869 .58807 L F
.923 .922 .543 r
.69489 .34075 m .69481 .34358 L .69356 .34468 L F
.764 .682 .773 r
.4125 .50087 m .41659 .5014 L .41524 .49769 L F
.652 .17 .095 r
.4125 .50087 m .41497 .50277 L .41659 .5014 L F
.993 .77 .493 r
.41497 .50277 m .41646 .50441 L .41659 .5014 L F
.544 .393 .626 r
.41659 .5014 m .42038 .50124 L .4187 .49828 L F
.461 .299 .574 r
.41659 .5014 m .419 .50341 L .42038 .50124 L F
.41659 .5014 m .41646 .50441 L .419 .50341 L F
.108 .3 .776 r
.55884 .40881 m .55813 .41102 L .56059 .41267 L F
.999 .844 .526 r
.42289 .54141 m .42474 .53978 L .42342 .54004 L F
.42289 .54141 m .42352 .54373 L .42474 .53978 L F
0 0 0 r
.4277 .53873 m .42342 .54004 L .42474 .53978 L F
.995 .784 .506 r
.36661 .6137 m .36795 .61744 L .36648 .61613 L F
.756 .666 .762 r
.36795 .61744 m .36405 .61634 L .36648 .61613 L F
.235 .353 .781 r
.35348 .54431 m .35245 .54649 L .35103 .54269 L F
.995 .784 .506 r
.36648 .61613 m .36795 .61744 L .36661 .6137 L F
.881 .644 .121 r
.36743 .61821 m .36795 .61744 L .36648 .61613 L F
.36743 .61821 m .36821 .62029 L .36795 .61744 L F
.72 .951 .657 r
.56885 .43798 m .57039 .43701 L .56771 .44006 L F
0 0 0 r
.57152 .43697 m .57039 .43701 L .56885 .43798 L F
.57152 .43697 m .57309 .43659 L .57039 .43701 L F
.767 .709 .798 r
.51103 .42448 m .5065 .42391 L .50924 .42291 L F
.859 .844 .828 r
.51369 .42114 m .51103 .42448 L .50924 .42291 L F
.796 .993 .761 r
.23265 .53425 m .23306 .53247 L .23363 .53254 L F
.23265 .53425 m .23061 .53524 L .23306 .53247 L F
.82 .843 .867 r
.48059 .44035 m .47603 .44183 L .47902 .43893 L F
.798 .871 .902 r
.48201 .43646 m .48059 .44035 L .47902 .43893 L F
.48201 .43646 m .48264 .43888 L .48059 .44035 L F
0 0 .194 r
.27743 .5723 m .27802 .57339 L .27961 .57143 L F
.27743 .5723 m .2776 .57492 L .27802 .57339 L F
.487 .288 .535 r
.43269 .53007 m .43273 .53294 L .43532 .52967 L F
0 .187 .717 r
.30222 .66141 m .29982 .65935 L .30366 .6595 L F
.943 .641 .19 r
.60205 .43229 m .6034 .43614 L .60308 .43364 L F
.60205 .43229 m .6034 .43614 L .60308 .43364 L F
.714 .652 .787 r
.37983 .59526 m .38096 .59966 L .37911 .59739 L F
.631 .77 .947 r
.38162 .6021 m .37911 .59739 L .38096 .59966 L F
.513 .522 .803 r
.38364 .59907 m .38096 .59966 L .37983 .59526 L F
.632 .523 .713 r
.38342 .60029 m .38096 .59966 L .38364 .59907 L F
.38342 .60029 m .38162 .6021 L .38096 .59966 L F
.476 .412 .705 r
.27711 .53969 m .27952 .53963 L .2782 .53636 L F
.792 .841 .889 r
.38101 .69528 m .38488 .69491 L .38324 .69398 L F
.696 .898 .969 r
.38324 .69398 m .38488 .69491 L .38718 .69365 L F
.82 .883 .889 r
.59039 .37548 m .58628 .37694 L .58957 .37437 L F
.892 .978 .818 r
.59039 .37548 m .58957 .37437 L .59224 .37118 L F
.787 .906 .509 r
.23343 .54072 m .23404 .54081 L .23564 .53885 L F
.23343 .54072 m .23253 .54359 L .23404 .54081 L F
.14 .135 .59 r
.23313 .5459 m .23466 .54917 L .23576 .54701 L F
.056 0 .151 r
.23724 .54589 m .23466 .54917 L .23576 .54701 L F
0 0 0 r
.34597 .60262 m .34413 .60669 L .34515 .60443 L F
.622 .505 .7 r
.34515 .60443 m .34577 .60762 L .34777 .6042 L F
.693 .542 .677 r
.30556 .65517 m .30633 .65898 L .30366 .6595 L F
.539 .545 .809 r
.30678 .65261 m .30556 .65517 L .30613 .6525 L F
.30678 .65261 m .30833 .65631 L .30556 .65517 L F
.616 .491 .688 r
.30833 .65631 m .30633 .65898 L .30556 .65517 L F
.534 .261 .448 r
.51549 .48154 m .51264 .48424 L .51318 .48233 L F
.716 .212 .036 r
.57605 .43019 m .57737 .43217 L .57529 .43168 L F
.955 .694 .501 r
.53366 .40484 m .53295 .40687 L .53498 .40327 L F
.51 .22 .409 r
.35949 .58166 m .35893 .58407 L .35685 .58207 L F
.37 0 0 r
.3239 .52544 m .32612 .52613 L .32695 .52364 L F
.3239 .52544 m .32377 .52644 L .32612 .52613 L F
.786 .929 .928 r
.62548 .36811 m .62943 .36639 L .62811 .36486 L F
.939 .931 .767 r
.62811 .36486 m .62943 .36639 L .6314 .36257 L F
.524 .606 .877 r
.42528 .46862 m .42723 .47258 L .42911 .47132 L F
0 0 .009 r
.42723 .47258 m .42622 .47457 L .42911 .47132 L F
.499 .08 .176 r
.30362 .56893 m .30199 .5711 L .29957 .57099 L F
.541 .126 .203 r
.30593 .57021 m .30362 .56893 L .306 .56838 L F
.30593 .57021 m .30199 .5711 L .30362 .56893 L F
.801 .89 .471 r
.70185 .3519 m .70293 .3499 L .70191 .35109 L F
.822 .866 .42 r
.70353 .34711 m .70293 .3499 L .70437 .34599 L F
.839 .891 .466 r
.70191 .35109 m .70293 .3499 L .70353 .34711 L F
.211 .661 .949 r
.58807 .36819 m .58915 .36909 L .59272 .36882 L F
.58807 .36819 m .59272 .36882 L .59271 .36881 L F
.58807 .36819 m .58915 .36909 L .59275 .36882 L F
.586 .416 .617 r
.59085 .36469 m .59273 .36878 L .58807 .36819 L F
.59273 .36878 m .59275 .36882 L .59271 .36881 L F
.59273 .36878 m .59271 .36881 L .58807 .36819 L F
.394 .67 .97 r
.58807 .36819 m .59271 .36881 L .58647 .36636 L F
.59271 .36881 m .59275 .36882 L .5927 .3688 L F
.59271 .36881 m .5927 .3688 L .58647 .36636 L F
.58647 .36636 m .59275 .36882 L .58807 .36819 L F
.768 .493 .518 r
.59085 .36469 m .59273 .36878 L .58647 .36636 L F
.59273 .36878 m .59275 .36882 L .5927 .3688 L F
.59273 .36878 m .5927 .3688 L .58647 .36636 L F
.928 .953 .781 r
.59131 .36999 m .59218 .36963 L .59121 .3702 L F
.519 .682 .94 r
.58647 .36636 m .59275 .36882 L .58997 .36627 L F
.928 .953 .781 r
.59214 .36831 m .59217 .36926 L .59131 .36999 L F
.59217 .36926 m .59218 .36963 L .59131 .36999 L F
.59218 .36963 m .59224 .37118 L .59159 .37056 L F
.59218 .36963 m .59159 .37056 L .59121 .3702 L F
.913 .516 .224 r
.58997 .36627 m .59269 .36877 L .59085 .36469 L F
.59269 .36877 m .59275 .36882 L .59273 .36878 L F
.59269 .36877 m .59273 .36878 L .59085 .36469 L F
.889 .877 .817 r
.59232 .36793 m .59104 .36827 L .59135 .36653 L F
.59104 .36827 m .58938 .36869 L .59004 .36797 L F
.59104 .36827 m .59004 .36797 L .59135 .36653 L F
.928 .953 .781 r
.59232 .36793 m .59231 .36846 L .59214 .36831 L F
.59231 .36846 m .59224 .37118 L .59214 .36831 L F
.211 .661 .949 r
.59271 .36881 m .59272 .36882 L .59275 .36882 L F
.237 0 .102 r
.28903 .56538 m .29145 .56488 L .29193 .56325 L F
.472 .059 .175 r
.29145 .56488 m .29406 .56451 L .29193 .56325 L F
.551 .908 .707 r
.35711 .64855 m .3584 .64777 L .36039 .64625 L F
.391 .027 .221 r
.31565 .56255 m .31468 .56503 L .31295 .56472 L F
.165 0 0 r
.31871 .56241 m .31468 .56503 L .31565 .56255 L F
.621 .95 .934 r
.28464 .51373 m .28305 .51347 L .28517 .51219 L F
.552 .863 .996 r
.43964 .45688 m .4421 .45595 L .4436 .45681 L F
.659 .817 .959 r
.44462 .45414 m .4436 .45681 L .4421 .45595 L F
.44462 .45414 m .44625 .45565 L .4436 .45681 L F
.348 0 .016 r
.46254 .59075 m .45869 .59185 L .45973 .59101 L F
0 .209 .735 r
.2782 .6397 m .28058 .64315 L .27797 .64257 L F
.738 .378 .369 r
.28058 .64315 m .2779 .64528 L .27797 .64257 L F
.28058 .64315 m .2821 .64564 L .2779 .64528 L F
.489 .264 .499 r
.33152 .57805 m .33428 .5749 L .33188 .57553 L F
.735 .584 .687 r
.32784 .52995 m .32578 .53337 L .32539 .53022 L F
.32784 .52995 m .32578 .53337 L .32539 .53022 L F
.435 .869 .777 r
.44253 .59846 m .44427 .59802 L .44599 .59705 L F
.886 .991 .778 r
.63188 .41867 m .63122 .42159 L .63392 .41786 L F
.89 .98 .692 r
.62971 .4223 m .63122 .42159 L .63188 .41867 L F
.469 .892 .888 r
.66894 .38263 m .67249 .38169 L .671 .38197 L F
.261 .765 .737 r
.671 .38197 m .67249 .38169 L .67513 .38086 L F
0 0 0 r
.33292 .49515 m .33451 .49459 L .33219 .49518 L F
.018 .565 .834 r
.33431 .49509 m .33292 .49515 L .33153 .49442 L F
.209 0 0 r
.33516 .4953 m .33451 .49459 L .33292 .49515 L F
.018 .565 .834 r
.33516 .4953 m .33292 .49515 L .33431 .49509 L F
0 0 0 r
.33292 .49515 m .33219 .49518 L .33127 .49541 L F
.209 0 0 r
.33516 .4953 m .33704 .49465 L .33451 .49459 L F
.314 .102 .423 r
.30613 .6525 m .30805 .64981 L .30678 .65261 L F
.471 .127 .3 r
.3641 .52681 m .36374 .52767 L .36196 .52679 L F
0 0 .175 r
.4768 .57502 m .47658 .57795 L .47618 .57797 L F
0 0 .009 r
.47658 .57795 m .47581 .58046 L .47618 .57797 L F
.554 .111 .151 r
.36975 .54971 m .36531 .55154 L .36956 .55239 L F
.283 0 0 r
.36531 .55154 m .36826 .55233 L .36956 .55239 L F
.554 .111 .151 r
.36975 .54971 m .36826 .55233 L .36531 .55154 L F
.701 .544 .672 r
.36956 .55239 m .3722 .54895 L .36975 .54971 L F
0 0 0 r
.37051 .5503 m .36975 .54971 L .3722 .54895 L F
.37051 .5503 m .36826 .55233 L .36975 .54971 L F
.209 .362 .799 r
.56075 .41532 m .55929 .41733 L .55809 .41407 L F
0 0 .187 r
.55931 .41989 m .55929 .41733 L .56075 .41532 L F
.446 0 0 r
.43922 .53531 m .44336 .53358 L .44069 .53382 L F
.43922 .53531 m .44306 .5356 L .44336 .53358 L F
.877 .833 .799 r
.51599 .41763 m .51187 .41959 L .51416 .41609 L F
.51599 .41763 m .51369 .42114 L .51187 .41959 L F
.834 .793 .812 r
.51854 .41444 m .51599 .41763 L .51416 .41609 L F
.994 .749 .406 r
.33017 .49851 m .33061 .49713 L .33038 .49921 L F
.251 .367 .787 r
.32807 .49516 m .33061 .49713 L .33115 .4954 L F
.994 .749 .406 r
.32924 .49544 m .33061 .49713 L .33017 .49851 L F
.251 .367 .787 r
.33115 .4954 m .33061 .49713 L .33127 .49541 L F
0 0 0 r
.33292 .49515 m .33127 .49541 L .33061 .49713 L F
.612 .882 .557 r
.64089 .40738 m .64367 .40427 L .64238 .40541 L F
.666 .968 .789 r
.63851 .40847 m .64089 .40738 L .64238 .40541 L F
.63 .619 .821 r
.36873 .60732 m .37163 .60176 L .36647 .60712 L F
.108 .358 .823 r
.42741 .54593 m .42866 .54858 L .42668 .54782 L F
.5 .794 .998 r
.56771 .44006 m .56353 .43928 L .5663 .44134 L F
.699 .912 .566 r
.56885 .43798 m .56771 .44006 L .5663 .44134 L F
0 0 .324 r
.59957 .39776 m .6014 .40161 L .60039 .4005 L F
.877 .439 .111 r
.6014 .40161 m .60094 .40304 L .60039 .4005 L F
.6014 .40161 m .60265 .40392 L .60094 .40304 L F
.314 .526 .9 r
.35149 .69923 m .35245 .6967 L .35037 .69701 L F
.35149 .69923 m .35434 .69999 L .35245 .6967 L F
.949 .71 .543 r
.53885 .40642 m .54089 .40789 L .53915 .40372 L F
.847 .94 .572 r
.70437 .34599 m .70616 .34162 L .70471 .34557 L F
0 0 0 r
.70353 .34711 m .70437 .34599 L .70471 .34557 L F
0 0 .101 r
.35786 .55727 m .35861 .55696 L .3575 .55867 L F
.35786 .55727 m .35805 .55424 L .35861 .55696 L F
.673 .94 .964 r
.69802 .33022 m .69464 .33096 L .69781 .32953 L F
.777 .872 .441 r
.69985 .32573 m .69802 .33022 L .69781 .32953 L F
.631 .77 .947 r
.38162 .6021 m .37649 .60086 L .37911 .59739 L F
.4 0 .116 r
.27181 .54941 m .2675 .54862 L .2691 .54926 L F
.548 .918 .944 r
.55399 .41455 m .5557 .41517 L .55155 .41656 L F
.55399 .41455 m .55155 .41656 L .55171 .41654 L F
.994 .816 .448 r
.39769 .5833 m .39895 .58518 L .39864 .58103 L F
.988 .803 .413 r
.3974 .5857 m .39895 .58518 L .39769 .5833 L F
.3974 .5857 m .39858 .58824 L .39895 .58518 L F
.795 .541 .554 r
.35474 .59187 m .35162 .59384 L .35192 .59117 L F
.35474 .59187 m .35573 .59449 L .35162 .59384 L F
.993 .746 .434 r
.39602 .59687 m .39754 .59483 L .39655 .59305 L F
.39602 .59687 m .39738 .59789 L .39754 .59483 L F
0 0 0 r
.44272 .54334 m .44099 .54596 L .44057 .54593 L F
.927 .958 .639 r
.4409 .54428 m .44099 .54596 L .44272 .54334 L F
.997 .778 .43 r
.4409 .54428 m .44138 .54599 L .44099 .54596 L F
.44138 .54599 m .44207 .54843 L .44099 .54596 L F
0 0 0 r
.44057 .54593 m .44099 .54596 L .44031 .54625 L F
0 .092 .627 r
.44099 .54596 m .44207 .54843 L .44031 .54625 L F
.373 .202 .517 r
.44031 .54625 m .44207 .54843 L .43993 .54879 L F
.749 .979 .917 r
.4148 .4715 m .41368 .47264 L .41462 .47044 L F
.347 .228 .572 r
.41277 .47344 m .41462 .47044 L .41368 .47264 L F
.656 .44 .579 r
.57422 .41046 m .57856 .41085 L .57773 .41328 L F
.561 .638 .884 r
.3739 .57169 m .37159 .57256 L .37033 .57027 L F
.606 .108 .044 r
.36875 .59465 m .37298 .5949 L .37116 .59638 L F
.928 .585 .363 r
.37116 .59638 m .37298 .5949 L .37317 .59714 L F
.736 .579 .679 r
.37554 .59409 m .37317 .59714 L .37298 .5949 L F
.82 .753 .789 r
.56353 .42331 m .56484 .42711 L .56111 .42663 L F
.646 .354 .46 r
.56484 .42711 m .5608 .42986 L .56111 .42663 L F
.56484 .42711 m .56394 .42985 L .5608 .42986 L F
.324 .279 .652 r
.56612 .42265 m .56484 .42711 L .56353 .42331 L F
.56612 .42265 m .56686 .42645 L .56484 .42711 L F
.058 0 .197 r
.56659 .42812 m .56484 .42711 L .56686 .42645 L F
.56659 .42812 m .56394 .42985 L .56484 .42711 L F
.859 .844 .828 r
.51369 .42114 m .50924 .42291 L .51187 .41959 L F
.642 .776 .944 r
.44194 .56243 m .44405 .56317 L .44478 .56195 L F
.505 .297 .531 r
.44405 .56317 m .44601 .56518 L .44637 .56148 L F
.51 .372 .629 r
.29676 .63028 m .29917 .62974 L .29863 .62702 L F
.421 .146 .388 r
.44414 .58194 m .44122 .58475 L .44376 .58387 L F
.558 .588 .84 r
.44376 .58387 m .4466 .58131 L .44414 .58194 L F
0 .163 .674 r
.59426 .39325 m .59525 .39462 L .59765 .39653 L F
.357 .239 .579 r
.47705 .52022 m .47727 .52312 L .47517 .52378 L F
.408 .389 .727 r
.47727 .52312 m .47807 .52592 L .47517 .52378 L F
.495 .382 .654 r
.47517 .52378 m .47807 .52592 L .47555 .52635 L F
.886 .989 .799 r
.37229 .63687 m .3748 .63367 L .37231 .63471 L F
.874 .988 .825 r
.37104 .63644 m .37229 .63687 L .37231 .63471 L F
.77 .849 .398 r
.60742 .36475 m .60533 .36973 L .60628 .36677 L F
.436 0 .096 r
.60742 .36475 m .60628 .36677 L .608 .36649 L F
.60742 .36475 m .608 .36649 L .61063 .36606 L F
0 0 .341 r
.60742 .36223 m .60718 .36403 L .60742 .36475 L F
.60718 .36403 m .60686 .36637 L .60742 .36475 L F
.925 .554 .291 r
.38149 .5264 m .3824 .52984 L .38462 .53026 L F
.878 .567 .054 r
.3824 .52984 m .38337 .53222 L .38462 .53026 L F
0 0 .373 r
.23362 .54366 m .23253 .54359 L .23343 .54072 L F
.23362 .54366 m .23313 .5459 L .23253 .54359 L F
.438 .136 .354 r
.48659 .50242 m .48419 .50421 L .4814 .50511 L F
.619 .481 .671 r
.48419 .50421 m .48132 .50745 L .4814 .50511 L F
.744 .993 .854 r
.37548 .63188 m .3748 .63367 L .37678 .63188 L F
.755 .994 .818 r
.37231 .63471 m .3748 .63367 L .37548 .63188 L F
.977 .703 .443 r
.44493 .57223 m .44326 .57381 L .44371 .57108 L F
.44493 .57223 m .44495 .57479 L .44326 .57381 L F
.487 .879 .963 r
.58654 .35976 m .59034 .35936 L .58938 .35915 L F
.51 0 0 r
.59318 .36091 m .59301 .36115 L .59034 .35936 L F
.59423 .36149 m .59301 .36115 L .59318 .36091 L F
.494 .772 .993 r
.59301 .36115 m .59581 .3607 L .59457 .35923 L F
.59301 .36115 m .59457 .35923 L .59277 .36152 L F
.877 .824 .792 r
.59301 .36115 m .59085 .36469 L .58964 .3626 L F
.673 .85 .442 r
.59199 .3625 m .59085 .36469 L .59301 .36115 L F
.494 .772 .993 r
.59301 .36115 m .59277 .36152 L .59199 .3625 L F
0 .222 .7 r
.59034 .35936 m .59301 .36115 L .59167 .35978 L F
.59034 .35936 m .59167 .35978 L .58938 .35915 L F
.65 .447 .596 r
.32386 .58786 m .32652 .58878 L .32708 .58559 L F
.343 .17 .497 r
.32708 .58559 m .32944 .58744 L .32975 .58459 L F
.32708 .58559 m .32652 .58878 L .32944 .58744 L F
.552 .194 .315 r
.54415 .47435 m .54432 .47241 L .54692 .47413 L F
.432 .075 .257 r
.36623 .59504 m .36918 .59608 L .3645 .59709 L F
.36623 .59504 m .36875 .59465 L .36918 .59608 L F
.057 .623 .747 r
.33758 .50226 m .33891 .5021 L .33709 .50138 L F
.313 0 0 r
.33709 .50138 m .33891 .5021 L .33843 .50194 L F
.555 .923 .939 r
.33602 .50293 m .33709 .50138 L .33477 .50042 L F
.313 0 0 r
.33709 .50138 m .33843 .50194 L .33509 .5008 L F
.555 .923 .939 r
.33477 .50042 m .33709 .50138 L .3346 .50008 L F
.33602 .50293 m .33758 .50226 L .33709 .50138 L F
.785 .712 .783 r
.28106 .63186 m .28679 .63094 L .28285 .63001 L F
.33 .145 .472 r
.45243 .57524 m .45497 .57489 L .45506 .57178 L F
.282 0 .283 r
.45425 .57687 m .45243 .57524 L .45212 .57781 L F
.45425 .57687 m .45497 .57489 L .45243 .57524 L F
.907 .713 .629 r
.72341 .32539 m .72478 .32753 L .72335 .32345 L F
.766 .785 .869 r
.72112 .32723 m .72478 .32753 L .72341 .32539 L F
.542 0 0 r
.38196 .55746 m .38412 .55865 L .38003 .55784 L F
.839 .922 .889 r
.598 .35176 m .59365 .35662 L .59316 .35344 L F
.685 .748 .899 r
.42311 .50377 m .42716 .50448 L .42569 .50272 L F
.409 .274 .585 r
.42311 .50377 m .4256 .50607 L .42716 .50448 L F
.334 .587 .937 r
.42569 .50272 m .42716 .50448 L .42796 .50258 L F
.74 .92 .56 r
.42716 .50448 m .4256 .50607 L .42796 .50258 L F
.431 .224 .495 r
.26861 .62098 m .27076 .62088 L .27041 .61781 L F
.309 .14 .482 r
.27041 .61781 m .27076 .62088 L .27228 .61935 L F
.695 .96 .945 r
.27228 .61935 m .27297 .61725 L .27041 .61781 L F
.939 .931 .767 r
.62811 .36486 m .6314 .36257 L .63004 .36058 L F
.983 .714 .432 r
.59214 .40997 m .59232 .40751 L .59064 .40617 L F
.745 .715 .824 r
.45284 .56519 m .45171 .56539 L .45104 .56641 L F
.82 .804 .836 r
.51951 .40969 m .52188 .41144 L .51854 .41444 L F
.505 .647 .921 r
.52169 .40838 m .52188 .41144 L .51951 .40969 L F
.52169 .40838 m .52426 .41137 L .52188 .41144 L F
.963 .931 .609 r
.4291 .55921 m .42743 .56086 L .42814 .56199 L F
.53 .835 .516 r
.43012 .55808 m .4291 .55921 L .43177 .55891 L F
.848 .997 .82 r
.64367 .40427 m .64468 .40138 L .64344 .40344 L F
.64367 .40427 m .64644 .40118 L .64468 .40138 L F
.886 .932 .552 r
.64238 .40541 m .64367 .40427 L .64344 .40344 L F
.275 .044 .371 r
.35494 .60445 m .35438 .60692 L .35246 .60765 L F
.371 .219 .541 r
.35446 .60975 m .35246 .60765 L .35438 .60692 L F
.35446 .60975 m .35253 .61099 L .35246 .60765 L F
.658 .766 .288 r
.22493 .54906 m .22647 .54548 L .22524 .54647 L F
.503 .419 .694 r
.31687 .6333 m .31409 .6309 L .31689 .6301 L F
.31687 .6333 m .31437 .6341 L .31409 .6309 L F
.834 .793 .812 r
.51854 .41444 m .51416 .41609 L .51738 .41356 L F
.82 .804 .836 r
.51951 .40969 m .51854 .41444 L .51863 .41151 L F
.911 .944 .812 r
.51863 .41151 m .51854 .41444 L .51738 .41356 L F
.965 .644 .269 r
.40789 .54662 m .40657 .5457 L .4065 .54314 L F
.833 .644 .097 r
.40789 .54662 m .40761 .54779 L .40657 .5457 L F
.40789 .54662 m .4079 .54903 L .40761 .54779 L F
.563 .605 .853 r
.39035 .49666 m .3888 .49809 L .38727 .49456 L F
.979 .687 .376 r
.41071 .55932 m .4094 .56037 L .41057 .55813 L F
.41071 .55932 m .41104 .56207 L .4094 .56037 L F
.814 .756 .798 r
.34269 .52021 m .34051 .52151 L .33855 .51964 L F
.34269 .52021 m .34051 .52151 L .33855 .51964 L F
0 0 .361 r
.54626 .41608 m .54544 .41393 L .5466 .41263 L F
.719 .724 .201 r
.26174 .61612 m .26098 .61947 L .2588 .61657 L F
.26174 .61612 m .26096 .61916 L .26098 .61947 L F
.829 .821 .841 r
.42912 .4889 m .42766 .49162 L .43112 .49115 L F
.603 .272 .382 r
.4273 .49306 m .43112 .49115 L .42766 .49162 L F
.4273 .49306 m .43023 .49363 L .43112 .49115 L F
.176 0 .266 r
.43112 .49115 m .43139 .48673 L .42912 .4889 L F
.43112 .49115 m .43352 .4882 L .43139 .48673 L F
.43112 .49115 m .43274 .49064 L .43352 .4882 L F
.584 .381 .571 r
.43023 .49363 m .43274 .49064 L .43112 .49115 L F
.78 .862 .91 r
.48564 .43622 m .48264 .43888 L .48201 .43646 L F
.729 .444 .496 r
.53121 .40986 m .52763 .41101 L .52638 .40987 L F
.53121 .40986 m .52896 .4134 L .52763 .41101 L F
.961 .803 .64 r
.52896 .4134 m .53121 .40986 L .52763 .41101 L F
.371 .815 .95 r
.59853 .36821 m .59568 .36928 L .5947 .36866 L F
.696 .823 .376 r
.42015 .58997 m .4195 .59156 L .42113 .58832 L F
.975 .916 .596 r
.41781 .59313 m .41868 .5943 L .4195 .59156 L F
.674 .187 .087 r
.42015 .58997 m .42235 .59203 L .41853 .59269 L F
.75 .939 .604 r
.42015 .58997 m .41781 .59313 L .4195 .59156 L F
.62 .848 .472 r
.41812 .59239 m .41781 .59313 L .42015 .58997 L F
.41776 .59282 m .41777 .59287 L .41812 .59239 L F
.41777 .59287 m .41781 .59313 L .41812 .59239 L F
.743 .622 .725 r
.41984 .58778 m .41804 .5908 L .41929 .59082 L F
.674 .187 .087 r
.42015 .58997 m .41853 .59269 L .41776 .59282 L F
.743 .622 .725 r
.4203 .58945 m .41929 .59082 L .42068 .59084 L F
.41984 .58778 m .41929 .59082 L .4203 .58945 L F
.696 .823 .376 r
.42015 .58997 m .42113 .58832 L .42134 .58791 L F
.112 .306 .78 r
.42254 .5866 m .42134 .58791 L .42018 .58472 L F
0 0 0 r
.42015 .58997 m .42134 .58791 L .42254 .5866 L F
.263 .072 .423 r
.31633 .64365 m .31842 .63986 L .31844 .64301 L F
.464 .419 .724 r
.31926 .64569 m .31633 .64365 L .31844 .64301 L F
.31926 .64569 m .31706 .64637 L .31633 .64365 L F
.495 .784 .997 r
.34732 .68724 m .34646 .6891 L .34472 .68783 L F
.34732 .68724 m .34919 .68872 L .34646 .6891 L F
0 0 0 r
.649 .38217 m .64608 .38524 L .64822 .38334 L F
.306 .366 .761 r
.64822 .38334 m .64608 .38524 L .64912 .38672 L F
.947 .958 .695 r
.69455 .28452 m .69202 .28741 L .69427 .28387 L F
.69455 .28452 m .69263 .28854 L .69202 .28741 L F
.743 .991 .873 r
.27942 .51748 m .27867 .51938 L .28199 .51832 L F
.27942 .51748 m .27756 .51926 L .27867 .51938 L F
.931 .95 .778 r
.32606 .49559 m .32807 .49516 L .32725 .49422 L F
.981 .84 .63 r
.33907 .61056 m .33806 .61278 L .33993 .61166 L F
.972 .701 .46 r
.33806 .61278 m .33918 .6154 L .33993 .61166 L F
.92 .526 .208 r
.59765 .39653 m .59957 .39776 L .60039 .4005 L F
0 0 .132 r
.34577 .60762 m .34703 .60674 L .34777 .6042 L F
.046 0 .429 r
.34577 .60762 m .34697 .60967 L .34703 .60674 L F
.974 .669 .368 r
.63277 .38995 m .63453 .39194 L .6343 .39418 L F
.614 .759 .948 r
.63705 .39072 m .63453 .39194 L .63277 .38995 L F
.312 .045 .338 r
.6343 .39418 m .63453 .39194 L .63705 .39072 L F
.426 .051 .223 r
.2685 .51907 m .26602 .51933 L .26909 .51858 L F
.2685 .51907 m .26462 .52064 L .26602 .51933 L F
0 .397 .844 r
.29921 .66804 m .30104 .66906 L .29954 .66729 L F
.902 .741 .241 r
.41192 .59147 m .41167 .5946 L .41134 .59308 L F
.881 .751 .244 r
.41163 .59049 m .41192 .59147 L .41134 .59308 L F
.423 0 0 r
.33255 .63519 m .33423 .63609 L .33092 .63403 L F
.579 .55 .786 r
.42252 .48264 m .4236 .48307 L .42203 .48283 L F
0 0 0 r
.37843 .65272 m .37607 .65633 L .37724 .65465 L F
.548 .354 .57 r
.37873 .65604 m .37843 .65272 L .37724 .65465 L F
.37873 .65604 m .38146 .65242 L .37843 .65272 L F
.974 .67 .369 r
.5983 .4233 m .59666 .42 L .59697 .42244 L F
.913 .521 .245 r
.59709 .4248 m .5983 .4233 L .59697 .42244 L F
.59709 .4248 m .60049 .42722 L .5983 .4233 L F
.007 0 0 r
.56268 .43629 m .56067 .43703 L .55955 .43832 L F
.197 .08 .485 r
.35643 .54661 m .35732 .54701 L .3578 .54269 L F
.362 0 0 r
.35487 .54684 m .35732 .54701 L .35643 .54661 L F
.517 .452 .722 r
.47567 .53967 m .47758 .53953 L .47519 .53996 L F
.444 .352 .658 r
.47758 .53953 m .47598 .54265 L .47519 .53996 L F
.682 .574 .727 r
.35242 .56803 m .34843 .56485 L .35308 .565 L F
.027 0 .201 r
.35532 .56201 m .35451 .56445 L .35308 .565 L F
.645 .359 .47 r
.35535 .56771 m .35308 .565 L .35451 .56445 L F
.001 0 .231 r
.35466 .56641 m .35308 .565 L .35451 .56445 L F
.645 .359 .47 r
.35535 .56771 m .35242 .56803 L .35308 .565 L F
.001 0 .231 r
.35466 .56641 m .35242 .56803 L .35308 .565 L F
.027 0 .201 r
.35308 .565 m .35451 .56445 L .35532 .56201 L F
.35532 .56201 m .35451 .56445 L .35308 .565 L F
.477 .491 .794 r
.37225 .60297 m .37166 .60647 L .3737 .60585 L F
.37163 .60176 m .37164 .60361 L .37225 .60297 L F
.37164 .60361 m .37166 .60647 L .37225 .60297 L F
.549 .431 .671 r
.37694 .59804 m .37649 .60086 L .37406 .6003 L F
0 0 0 r
.37406 .6003 m .37247 .60274 L .37512 .59957 L F
.477 .491 .794 r
.37163 .60176 m .37269 .60384 L .37218 .60318 L F
.37269 .60384 m .3737 .60585 L .37218 .60318 L F
0 0 0 r
.37247 .60274 m .37218 .60318 L .37298 .6022 L F
.37247 .60274 m .37298 .6022 L .37512 .59957 L F
.854 .518 .415 r
.37163 .60176 m .37218 .60318 L .37406 .6003 L F
.63 .619 .821 r
.36873 .60732 m .37166 .60647 L .37163 .60176 L F
.549 .431 .671 r
.37694 .59804 m .37406 .6003 L .37512 .59957 L F
.775 .681 .76 r
.37512 .59957 m .37218 .60318 L .371 .5991 L F
.992 .754 .471 r
.371 .5991 m .37154 .60098 L .37087 .60166 L F
.37154 .60098 m .37218 .60318 L .37087 .60166 L F
.396 .487 .835 r
.37218 .60318 m .37398 .60142 L .371 .60165 L F
.37218 .60318 m .371 .60165 L .37087 .60166 L F
.629 .53 .722 r
.37364 .59948 m .37398 .60142 L .37087 .60166 L F
0 0 0 r
.37203 .60093 m .36912 .60344 L .37087 .60166 L F
.36912 .60344 m .36909 .60347 L .37087 .60166 L F
.734 .979 .749 r
.31239 .63583 m .31437 .6341 L .31234 .63517 L F
0 0 0 r
.31234 .63517 m .31437 .6341 L .31687 .6333 L F
.616 .435 .614 r
.54224 .39914 m .53915 .40372 L .5397 .40059 L F
0 0 0 r
.32343 .55282 m .32467 .55178 L .32574 .54919 L F
.631 .489 .671 r
.32661 .55531 m .3236 .5557 L .32343 .55282 L F
0 0 0 r
.32343 .55282 m .32174 .5545 L .32467 .55178 L F
.514 .295 .52 r
.49856 .49479 m .49898 .49739 L .4959 .49808 L F
.381 .207 .516 r
.50105 .49643 m .49856 .49479 L .50131 .49479 L F
.50105 .49643 m .49898 .49739 L .49856 .49479 L F
.35 .504 .871 r
.45997 .5345 m .4618 .53742 L .46253 .53587 L F
.232 .262 .687 r
.4618 .53742 m .46393 .53817 L .46253 .53587 L F
0 0 .112 r
.31708 .63349 m .31689 .6301 L .31902 .62962 L F
.31708 .63349 m .31687 .6333 L .31689 .6301 L F
.408 .206 .491 r
.31457 .65024 m .31706 .64637 L .31704 .64926 L F
0 0 .362 r
.31805 .64848 m .31706 .64637 L .31926 .64569 L F
.31805 .64848 m .31704 .64926 L .31706 .64637 L F
.712 .543 .659 r
.29601 .6486 m .29923 .64661 L .30012 .64297 L F
.981 .849 .637 r
.30012 .64297 m .29923 .64661 L .30197 .64539 L F
.868 .982 .844 r
.69202 .28741 m .69263 .28854 L .69023 .28891 L F
.723 .924 .58 r
.23488 .53103 m .23518 .5285 L .23701 .52947 L F
.23488 .53103 m .23453 .53062 L .23518 .5285 L F
.23488 .53103 m .23363 .53254 L .23453 .53062 L F
.663 .872 .977 r
.5722 .46254 m .57588 .46262 L .57466 .46103 L F
.508 .739 .978 r
.57466 .46103 m .57588 .46262 L .57711 .46057 L F
.536 .774 .986 r
.57588 .46262 m .57859 .46203 L .57711 .46057 L F
.968 .806 .378 r
.42689 .56351 m .42814 .56199 L .42743 .56086 L F
.42689 .56351 m .42773 .56558 L .42814 .56199 L F
.721 .857 .946 r
.64074 .39079 m .63705 .39072 L .6377 .39069 L F
.788 .836 .889 r
.64191 .38794 m .64074 .39079 L .6377 .39069 L F
.528 .246 .43 r
.2588 .61657 m .26174 .61612 L .25952 .61409 L F
.25952 .61409 m .26174 .61612 L .2588 .61657 L F
.875 .989 .821 r
.63392 .41786 m .63652 .41475 L .6344 .41526 L F
.887 .991 .778 r
.63188 .41867 m .63392 .41786 L .6344 .41526 L F
.781 .772 .844 r
.50118 .43 m .49745 .42961 L .50104 .42681 L F
.777 .769 .845 r
.50442 .42674 m .50118 .43 L .50104 .42681 L F
.695 .96 .945 r
.27228 .61935 m .27389 .61976 L .27297 .61725 L F
.783 .702 .775 r
.27297 .61725 m .27389 .61976 L .27681 .61631 L F
.439 .289 .579 r
.35879 .63354 m .35583 .63666 L .35737 .63592 L F
.754 .857 .926 r
.4463 .56781 m .44852 .56918 L .45171 .56539 L F
.927 .802 .701 r
.4463 .56781 m .44703 .57197 L .44852 .56918 L F
.144 0 .292 r
.21818 .56258 m .21753 .56503 L .21984 .56167 L F
.553 0 0 r
.31193 .64907 m .31527 .65121 L .31305 .65057 L F
.31193 .64907 m .31305 .65057 L .31276 .64958 L F
.339 0 0 r
.31155 .64884 m .31457 .65024 L .31193 .64907 L F
.359 0 0 r
.31193 .64907 m .31457 .65024 L .31662 .6514 L F
.31193 .64907 m .31662 .6514 L .31527 .65121 L F
.553 0 0 r
.31193 .64907 m .31276 .64958 L .31214 .64744 L F
.339 0 0 r
.31054 .64837 m .31155 .64884 L .31193 .64907 L F
.237 0 .113 r
.31662 .6514 m .31457 .65024 L .31704 .64926 L F
.608 .74 .939 r
.31491 .53501 m .31664 .53686 L .31991 .53597 L F
.776 .506 .527 r
.34191 .57801 m .3381 .58077 L .33946 .57842 L F
.567 .243 .38 r
.34384 .52301 m .34919 .52306 L .34968 .521 L F
.247 0 .27 r
.34968 .521 m .34919 .52306 L .35237 .51993 L F
.786 .621 .676 r
.32539 .53022 m .32163 .53285 L .3209 .52982 L F
.32539 .53022 m .32578 .53337 L .32163 .53285 L F
.219 .341 .775 r
.56371 .41016 m .56439 .41341 L .56271 .41105 L F
.431 .326 .635 r
.24439 .58083 m .24169 .58445 L .24272 .58175 L F
.24439 .58083 m .24498 .58441 L .24169 .58445 L F
.639 .342 .45 r
.24498 .58441 m .24143 .58593 L .24169 .58445 L F
.391 .851 .837 r
.34755 .65216 m .34836 .65223 L .35055 .65135 L F
.869 .986 .713 r
.34594 .65388 m .34836 .65223 L .34755 .65216 L F
.649 .872 .982 r
.308 .64768 m .30805 .64981 L .31054 .64837 L F
.905 .909 .507 r
.30724 .6516 m .30805 .64981 L .30711 .65128 L F
.30678 .65261 m .308 .64768 L .3069 .65077 L F
0 0 .311 r
.30678 .65036 m .30801 .65317 L .30695 .65088 L F
.30688 .65072 m .30695 .65088 L .3069 .65077 L F
.854 .773 .771 r
.30412 .64859 m .3069 .65077 L .308 .64768 L F
0 0 .311 r
.30678 .65036 m .30695 .65088 L .30688 .65072 L F
.905 .909 .507 r
.30711 .65128 m .30805 .64981 L .308 .64768 L F
.30678 .65261 m .30724 .6516 L .30711 .65128 L F
.86 .433 0 r
.39214 .54565 m .39303 .54798 L .3945 .54901 L F
.94 .586 .316 r
.39316 .55064 m .3945 .54901 L .39303 .54798 L F
.39316 .55064 m .39507 .55185 L .3945 .54901 L F
.777 .838 .898 r
.46939 .44418 m .47106 .44573 L .46727 .44576 L F
.738 .81 .909 r
.47238 .44177 m .47106 .44573 L .46939 .44418 L F
.47238 .44177 m .47404 .44363 L .47106 .44573 L F
.823 .923 .902 r
.37288 .62936 m .37142 .63114 L .3686 .63227 L F
.584 .907 .658 r
.66815 .31472 m .6651 .31735 L .66677 .31551 L F
.613 .951 .794 r
.6651 .31735 m .66333 .3178 L .66677 .31551 L F
.671 .139 0 r
.38993 .48827 m .38954 .48845 L .38614 .48492 L F
.988 .739 .361 r
.38993 .48827 m .38886 .48933 L .38954 .48845 L F
.38993 .48827 m .39028 .49154 L .38886 .48933 L F
.139 0 0 r
.30915 .56606 m .30832 .56766 L .306 .56838 L F
.59 .249 .361 r
.31295 .56472 m .30832 .56766 L .30915 .56606 L F
.702 .316 .315 r
.37619 .67527 m .38035 .67612 L .37844 .67353 L F
.461 .024 .121 r
.37647 .67792 m .38035 .67612 L .37619 .67527 L F
.37647 .67792 m .37928 .67764 L .38035 .67612 L F
.613 .637 .85 r
.37844 .67353 m .38035 .67612 L .38174 .67421 L F
.791 .407 .327 r
.37928 .67764 m .38207 .67874 L .38035 .67612 L F
0 0 0 r
.44045 .52308 m .43781 .52519 L .43804 .52387 L F
0 0 .112 r
.23526 .59283 m .23498 .59114 L .23566 .59038 L F
.23526 .59283 m .23478 .594 L .23498 .59114 L F
.378 .059 .293 r
.53571 .40177 m .53498 .40327 L .53833 .40116 L F
.31 .025 .307 r
.32368 .55841 m .3211 .56174 L .32099 .55923 L F
.975 .9 .551 r
.42814 .52879 m .42786 .53134 L .42892 .52755 L F
.467 .837 .591 r
.43125 .52638 m .42814 .52879 L .42892 .52755 L F
.524 .794 .995 r
.41524 .49769 m .4187 .49828 L .41928 .49791 L F
.265 .202 .597 r
.4187 .49828 m .4209 .5006 L .42063 .49682 L F
.197 .086 .494 r
.41928 .49791 m .4187 .49828 L .42063 .49682 L F
.033 .158 .664 r
.42038 .50124 m .4209 .5006 L .4187 .49828 L F
.134 .04 .473 r
.32048 .64161 m .31842 .63986 L .32034 .63857 L F
.32048 .64161 m .31844 .64301 L .31842 .63986 L F
.885 .986 .811 r
.32991 .59567 m .3304 .59287 L .33134 .59358 L F
0 0 .091 r
.27681 .61631 m .27774 .61513 L .27764 .61484 L F
.254 .584 .945 r
.27681 .61631 m .27947 .61692 L .27774 .61513 L F
.65 .467 .623 r
.48907 .4978 m .48658 .50094 L .48706 .49828 L F
.457 .886 .87 r
.40141 .48392 m .40084 .4842 L .39964 .48507 L F
.068 .125 .614 r
.40084 .4842 m .40147 .48701 L .39964 .48507 L F
.29 .156 .519 r
.39964 .48507 m .40147 .48701 L .39965 .48682 L F
.996 .766 .418 r
.61655 .39798 m .61575 .39477 L .61466 .39712 L F
.969 .72 .503 r
.61496 .39957 m .61655 .39798 L .61466 .39712 L F
.61496 .39957 m .61655 .40069 L .61655 .39798 L F
.387 .34 .684 r
.21457 .57765 m .21683 .57743 L .21597 .57482 L F
.868 .424 .064 r
.39671 .5207 m .39583 .52157 L .39578 .5193 L F
.39671 .5207 m .39774 .52277 L .39583 .52157 L F
.812 .867 .888 r
.24449 .61244 m .24871 .61078 L .24713 .61169 L F
.578 .002 0 r
.24699 .60849 m .25134 .61044 L .24871 .61078 L F
.557 .932 .826 r
.62562 .34397 m .62964 .34219 L .62699 .34268 L F
.226 .354 .785 r
.34068 .6937 m .34102 .69564 L .34204 .69348 L F
.501 .688 .951 r
.34102 .69564 m .34379 .69528 L .34204 .69348 L F
.267 .048 .384 r
.33676 .58488 m .33447 .58825 L .33619 .58796 L F
.301 .167 .526 r
.33619 .58796 m .33447 .58825 L .336 .58943 L F
.267 .048 .384 r
.33619 .58796 m .33447 .58825 L .33676 .58488 L F
.301 .167 .526 r
.33619 .58796 m .33447 .58825 L .336 .58943 L F
.122 0 .134 r
.36873 .60732 m .36587 .61084 L .36814 .60916 L F
.978 .691 .31 r
.36814 .60916 m .3695 .6114 L .36873 .60732 L F
.473 .043 .142 r
.30366 .6595 m .30478 .66116 L .30222 .66141 L F
.30366 .6595 m .30633 .65898 L .30478 .66116 L F
.972 .674 .397 r
.60265 .40392 m .60446 .40763 L .60332 .40625 L F
.993 .75 .392 r
.60332 .40625 m .60446 .40763 L .60438 .4102 L F
.996 .782 .427 r
.41677 .46869 m .41694 .46934 L .41568 .46767 L F
.902 .913 .514 r
.4148 .4715 m .41568 .46767 L .41694 .46934 L F
.943 .607 .184 r
.39742 .56471 m .3976 .56719 L .39869 .56787 L F
.999 .834 .529 r
.39708 .57025 m .39869 .56787 L .3976 .56719 L F
.39708 .57025 m .3981 .57152 L .39869 .56787 L F
.114 0 .295 r
.36728 .67824 m .36526 .68155 L .36684 .6816 L F
.096 .271 .752 r
.36526 .68155 m .36783 .68386 L .36684 .6816 L F
.547 .044 .011 r
.43738 .58474 m .43999 .58613 L .44122 .58475 L F
.563 .179 .27 r
.43999 .58613 m .44376 .58387 L .44122 .58475 L F
.921 .623 .143 r
.39594 .56085 m .39742 .56471 L .3972 .56261 L F
.34 0 .139 r
.31242 .56078 m .31678 .55736 L .31404 .55732 L F
.786 .464 0 r
.58057 .38209 m .58037 .38251 L .57877 .38078 L F
.58057 .38209 m .58114 .38424 L .58037 .38251 L F
.134 .5 .908 r
.36444 .68994 m .36394 .69111 L .36254 .68944 L F
.49 .488 .782 r
.36444 .68994 m .36335 .69441 L .36394 .69111 L F
.809 .898 .485 r
.37104 .68942 m .37167 .68719 L .37216 .68782 L F
.385 .183 .479 r
.43428 .48027 m .43394 .48326 L .43189 .48141 L F
.674 .268 .268 r
.42909 .59146 m .43184 .59351 L .4319 .59105 L F
.42909 .59146 m .42789 .59359 L .43184 .59351 L F
.564 .925 .943 r
.55809 .41407 m .5557 .41517 L .55399 .41455 L F
.302 0 0 r
.35045 .49861 m .35171 .4984 L .34748 .49776 L F
.635 .072 0 r
.35045 .49861 m .35395 .5003 L .35171 .4984 L F
.755 .343 .269 r
.3686 .63227 m .36617 .63032 L .36653 .63261 L F
.642 .885 .541 r
.64644 .40118 m .64906 .39795 L .64783 .39912 L F
.697 .983 .861 r
.64468 .40138 m .64644 .40118 L .64783 .39912 L F
.733 .722 .841 r
.37176 .69562 m .36795 .69538 L .3699 .69402 L F
.593 .315 .464 r
.38487 .6648 m .38529 .6622 L .38371 .66637 L F
.206 0 0 r
.45446 .59332 m .45637 .59244 L .45828 .59282 L F
.429 .49 .821 r
.37031 .56206 m .37014 .56252 L .37155 .56163 L F
.289 .101 .443 r
.37031 .56206 m .37155 .56163 L .37152 .55912 L F
.462 .562 .871 r
.37155 .56163 m .37014 .56252 L .36845 .56026 L F
.52 .312 .537 r
.28647 .56862 m .28888 .56817 L .28903 .56538 L F
.397 .211 .509 r
.28903 .56538 m .29124 .56722 L .29145 .56488 L F
.28903 .56538 m .28888 .56817 L .29124 .56722 L F
.554 .01 0 r
.39327 .51704 m .394 .51807 L .39232 .5158 L F
.39327 .51704 m .39578 .5193 L .394 .51807 L F
.75 .875 .937 r
.7001 .28074 m .69815 .28234 L .69736 .28037 L F
.6 .951 .881 r
.67019 .32624 m .67358 .32458 L .67185 .32456 L F
.486 .901 .841 r
.67358 .32458 m .67486 .32333 L .67185 .32456 L F
.67358 .32458 m .67613 .3233 L .67486 .32333 L F
0 0 .307 r
.27046 .63338 m .27071 .63512 L .27127 .63399 L F
.416 .825 .629 r
.66815 .31472 m .669 .31405 L .67032 .31319 L F
.66815 .31472 m .66677 .31551 L .669 .31405 L F
.507 .579 .862 r
.33061 .49713 m .33206 .50054 L .3346 .50008 L F
.742 .693 .151 r
.36609 .63796 m .36591 .63984 L .36658 .63555 L F
.36609 .63796 m .36658 .63555 L .36827 .63601 L F
.102 0 0 r
.6852 .35353 m .68305 .35345 L .68161 .35393 L F
.491 0 0 r
.30633 .65898 m .30685 .66062 L .30478 .66116 L F
.30633 .65898 m .30904 .65972 L .30685 .66062 L F
.846 .693 .693 r
.37087 .55632 m .37152 .55912 L .36678 .55819 L F
.678 .397 .49 r
.37152 .55912 m .36845 .56026 L .36678 .55819 L F
.37152 .55912 m .37155 .56163 L .36845 .56026 L F
.379 .324 .67 r
.37152 .55912 m .37306 .55547 L .37087 .55632 L F
0 .1 .622 r
.37207 .55641 m .37152 .55912 L .37087 .55632 L F
.379 .324 .67 r
.37152 .55912 m .37401 .55814 L .37306 .55547 L F
.239 .045 .404 r
.37155 .56163 m .37401 .55814 L .37152 .55912 L F
.378 .355 .707 r
.37207 .55641 m .37155 .56163 L .37152 .55912 L F
.394 .643 .956 r
.36727 .53467 m .36945 .53625 L .36688 .53634 L F
.021 .578 .815 r
.28795 .64944 m .2892 .64942 L .28651 .64975 L F
.28795 .64944 m .29027 .64977 L .2892 .64942 L F
.915 .641 .507 r
.40238 .53016 m .39968 .52937 L .39975 .5268 L F
.993 .743 .426 r
.40238 .53016 m .40096 .53156 L .39968 .52937 L F
.40238 .53016 m .40228 .53281 L .40096 .53156 L F
.799 .306 0 r
.35584 .50241 m .35596 .50076 L .35395 .5003 L F
.35584 .50241 m .35773 .5034 L .35596 .50076 L F
.807 .318 0 r
.35596 .50076 m .35773 .5034 L .35971 .50433 L F
.866 .991 .733 r
.32703 .61221 m .32855 .61129 L .32807 .61105 L F
0 .145 .682 r
.32855 .61129 m .32933 .60943 L .32807 .61105 L F
.32855 .61129 m .33051 .6121 L .32933 .60943 L F
.867 .976 .67 r
.38136 .50006 m .38291 .49614 L .38434 .49701 L F
.38136 .50006 m .38067 .49968 L .38291 .49614 L F
.608 .379 .544 r
.52455 .47532 m .52466 .47791 L .52186 .47821 L F
.608 .337 .482 r
.52455 .47532 m .52732 .47771 L .52466 .47791 L F
.52455 .47532 m .52891 .4748 L .52732 .47771 L F
.897 .732 .227 r
.41192 .57299 m .41242 .57532 L .41224 .57798 L F
.953 .927 .738 r
.6344 .41526 m .63652 .41475 L .6363 .41161 L F
.622 .157 .129 r
.28711 .64225 m .29126 .64229 L .28903 .6409 L F
.699 .399 .465 r
.25356 .57502 m .25399 .5782 L .25619 .5749 L F
.744 .678 .788 r
.34528 .59081 m .34066 .59396 L .34098 .59167 L F
.248 .239 .651 r
.22226 .59789 m .22326 .59343 L .22122 .59373 L F
.22226 .59789 m .22378 .59788 L .22326 .59343 L F
.248 .226 .637 r
.22226 .59789 m .2243 .60007 L .22378 .59788 L F
.693 .684 .837 r
.28111 .62143 m .28158 .62355 L .27778 .62289 L F
.337 .471 .848 r
.28152 .6266 m .27778 .62289 L .28158 .62355 L F
.632 .644 .844 r
.2841 .6221 m .28158 .62355 L .28111 .62143 L F
0 0 .377 r
.28287 .62515 m .28158 .62355 L .28338 .62251 L F
.28287 .62515 m .28152 .6266 L .28158 .62355 L F
0 0 .249 r
.28264 .62783 m .28152 .6266 L .28287 .62515 L F
.891 .737 .23 r
.28257 .62665 m .28287 .62515 L .28237 .62285 L F
.28264 .62783 m .28287 .62515 L .28257 .62665 L F
0 0 .377 r
.28287 .62515 m .28338 .62251 L .2841 .6221 L F
.831 .858 .866 r
.39367 .47528 m .39115 .47531 L .39374 .47281 L F
.926 .942 .789 r
.39135 .47672 m .39115 .47531 L .39367 .47528 L F
.499 .513 .802 r
.39467 .47077 m .39367 .47528 L .39374 .47281 L F
0 0 0 r
.74437 .31078 m .74233 .31447 L .74316 .30938 L F
.897 .585 .088 r
.74395 .31187 m .74437 .31078 L .74316 .30938 L F
.74395 .31187 m .74485 .3133 L .74437 .31078 L F
.531 .832 .507 r
.38217 .59194 m .38348 .59063 L .38112 .59304 L F
.866 .932 .552 r
.38509 .58803 m .38409 .59002 L .38348 .59063 L F
0 0 0 r
.38509 .58803 m .38348 .59063 L .38517 .58881 L F
.531 .832 .507 r
.38517 .58881 m .38348 .59063 L .38217 .59194 L F
.866 .932 .552 r
.38409 .59002 m .38313 .59192 L .38348 .59063 L F
.266 .665 .968 r
.38271 .58642 m .38509 .58803 L .38556 .58648 L F
0 0 0 r
.38509 .58803 m .38517 .58881 L .38556 .58648 L F
.678 .66 .825 r
.37504 .67136 m .37619 .67527 L .37844 .67353 L F
.796 .628 .674 r
.33107 .54309 m .3263 .54595 L .33165 .54663 L F
.769 .425 .404 r
.3263 .54595 m .33113 .54842 L .33165 .54663 L F
.914 .81 .731 r
.32814 .54478 m .32818 .54477 L .32608 .542 L F
.32938 .54645 m .32847 .54692 L .32818 .54477 L F
.413 .829 .646 r
.32818 .54477 m .3263 .54595 L .32833 .54473 L F
.793 .644 .697 r
.32662 .54575 m .32846 .54682 L .3263 .54595 L F
.32841 .54643 m .32846 .54682 L .32662 .54575 L F
.32846 .54682 m .32823 .54694 L .3263 .54595 L F
.32818 .54477 m .32841 .54643 L .32662 .54575 L F
.32846 .54682 m .32849 .54707 L .32823 .54694 L F
.914 .81 .731 r
.32847 .54692 m .32674 .54783 L .32818 .54477 L F
.615 .07 0 r
.32938 .54645 m .32887 .54661 L .32855 .54648 L F
.428 .862 .757 r
.32924 .54642 m .32887 .54661 L .32938 .54645 L F
.914 .81 .731 r
.32938 .54645 m .32818 .54477 L .32848 .54523 L F
.508 .43 .704 r
.33107 .54309 m .3338 .54567 L .33366 .54239 L F
.33107 .54309 m .33165 .54663 L .3338 .54567 L F
.585 .833 .465 r
.32853 .54519 m .32938 .54645 L .32848 .54523 L F
.3329 .54186 m .33029 .54526 L .32853 .54519 L F
.33029 .54526 m .32938 .54645 L .32853 .54519 L F
.793 .644 .697 r
.32848 .54523 m .32943 .54632 L .32925 .54641 L F
.32852 .54519 m .32943 .54632 L .32848 .54523 L F
.32818 .54477 m .33027 .54798 L .32849 .54707 L F
.32852 .54519 m .32766 .54647 L .32943 .54632 L F
.32766 .54647 m .32704 .54739 L .32859 .5467 L F
.615 .07 0 r
.32855 .54648 m .32822 .54661 L .32783 .54651 L F
.32887 .54661 m .32859 .5467 L .32855 .54648 L F
.793 .644 .697 r
.32741 .54641 m .32674 .54783 L .32766 .54647 L F
.086 .293 .775 r
.32539 .54847 m .32651 .54765 L .32417 .54593 L F
0 .136 .595 r
.32486 .54644 m .32651 .54765 L .32524 .54662 L F
.32651 .54765 m .32647 .54761 L .32524 .54662 L F
.615 .07 0 r
.32783 .54651 m .32527 .54772 L .32524 .54662 L F
0 0 0 r
.32524 .54662 m .32527 .54772 L .32558 .54677 L F
.32524 .54662 m .32558 .54677 L .32597 .54557 L F
0 .136 .595 r
.32417 .54593 m .32486 .54644 L .32524 .54662 L F
.32651 .54765 m .32674 .54783 L .32647 .54761 L F
.615 .07 0 r
.32859 .5467 m .32527 .54772 L .32822 .54661 L F
.32822 .54661 m .32527 .54772 L .32783 .54651 L F
.428 .862 .757 r
.32846 .54623 m .32621 .54728 L .32726 .54711 L F
.32621 .54728 m .32527 .54772 L .32631 .5474 L F
.32621 .54728 m .32631 .5474 L .32726 .54711 L F
.615 .07 0 r
.32859 .5467 m .32822 .54661 L .32855 .54648 L F
.793 .644 .697 r
.32799 .54517 m .32741 .54641 L .32852 .54519 L F
.32741 .54641 m .32766 .54647 L .32852 .54519 L F
.32766 .54647 m .32859 .5467 L .32943 .54632 L F
.428 .862 .757 r
.32993 .54555 m .32846 .54623 L .32922 .54641 L F
.32926 .54639 m .32922 .54641 L .32924 .54642 L F
.32993 .54555 m .32922 .54641 L .32926 .54639 L F
.32948 .54629 m .32924 .54642 L .32938 .54645 L F
.793 .644 .697 r
.32925 .54641 m .33113 .54842 L .33027 .54798 L F
.32943 .54632 m .32945 .54633 L .32925 .54641 L F
.32945 .54633 m .33113 .54842 L .32932 .54649 L F
.32945 .54633 m .32932 .54649 L .32925 .54641 L F
.32943 .54632 m .32674 .54783 L .32812 .54801 L F
.32945 .54633 m .32812 .54801 L .33113 .54842 L F
.32943 .54632 m .32812 .54801 L .32945 .54633 L F
.585 .833 .465 r
.3329 .54186 m .3327 .54211 L .33021 .54537 L F
.33029 .54526 m .33021 .54537 L .32938 .54645 L F
.3329 .54186 m .33021 .54537 L .33029 .54526 L F
.793 .644 .697 r
.32818 .54477 m .32852 .54519 L .32848 .54523 L F
.32818 .54477 m .32799 .54517 L .32845 .54519 L F
.914 .81 .731 r
.32845 .54519 m .32818 .54477 L .32814 .54478 L F
.32848 .54523 m .32818 .54477 L .32845 .54519 L F
.793 .644 .697 r
.32818 .54477 m .32845 .54519 L .32852 .54519 L F
.413 .829 .646 r
.32818 .54477 m .32833 .54473 L .33107 .54309 L F
.32818 .54477 m .33107 .54309 L .33039 .54189 L F
.585 .833 .465 r
.3321 .54188 m .32848 .54523 L .32608 .542 L F
.3329 .54186 m .32848 .54523 L .3321 .54188 L F
.76 .704 .8 r
.33039 .54189 m .32644 .54185 L .32548 .53869 L F
.334 .263 .626 r
.33247 .5385 m .33039 .54189 L .32691 .53668 L F
0 .055 .559 r
.33593 .54184 m .33247 .5385 L .33366 .54239 L F
.334 .263 .626 r
.33247 .5385 m .33358 .54097 L .33039 .54189 L F
0 0 0 r
.3329 .54186 m .33039 .54189 L .33358 .54097 L F
.496 .421 .701 r
.32872 .54292 m .33154 .54346 L .33114 .54098 L F
.585 .833 .465 r
.3327 .54211 m .33032 .54506 L .32948 .54629 L F
.3327 .54211 m .32948 .54629 L .32938 .54645 L F
.33032 .54506 m .32993 .54555 L .32985 .54568 L F
0 0 0 r
.33251 .54365 m .32993 .54555 L .3329 .54186 L F
.496 .421 .701 r
.33154 .54346 m .33251 .54365 L .33206 .54278 L F
.33154 .54346 m .33206 .54278 L .33114 .54098 L F
.585 .833 .465 r
.33032 .54506 m .32985 .54568 L .32948 .54629 L F
.793 .644 .697 r
.32704 .54739 m .32674 .54783 L .32943 .54632 L F
.428 .862 .757 r
.32993 .54555 m .32924 .54642 L .32948 .54629 L F
.32846 .54623 m .32726 .54711 L .32887 .54661 L F
.32846 .54623 m .32887 .54661 L .32924 .54642 L F
.086 .293 .775 r
.32574 .54919 m .32674 .54783 L .32651 .54765 L F
.32574 .54919 m .32651 .54765 L .32539 .54847 L F
0 0 0 r
.32574 .54919 m .32622 .5505 L .32674 .54783 L F
.32574 .54919 m .32467 .55178 L .32622 .5505 L F
.926 .942 .789 r
.39135 .47672 m .38945 .4772 L .39115 .47531 L F
.876 .994 .769 r
.70981 .30734 m .70729 .31079 L .70844 .30712 L F
.628 .489 .673 r
.71024 .31027 m .70729 .31079 L .70981 .30734 L F
.569 .447 .674 r
.71302 .30941 m .70981 .30734 L .71262 .30672 L F
.71302 .30941 m .71024 .31027 L .70981 .30734 L F
.872 .993 .801 r
.70729 .31079 m .70674 .30933 L .708 .30853 L F
.542 .108 .166 r
.70858 .30841 m .70746 .30984 L .71135 .30916 L F
.872 .993 .801 r
.708 .30853 m .70674 .30933 L .70844 .30712 L F
.876 .994 .769 r
.70981 .30734 m .70844 .30712 L .70777 .30869 L F
0 0 0 r
.70991 .3073 m .70777 .30869 L .70997 .30752 L F
.70981 .30734 m .71142 .30675 L .71262 .30672 L F
.71086 .30695 m .70997 .30752 L .71142 .30675 L F
.70991 .3073 m .70997 .30752 L .71086 .30695 L F
.70981 .30734 m .7085 .3082 L .70991 .3073 L F
.7085 .3082 m .70777 .30869 L .70991 .3073 L F
.87 .976 .673 r
.70844 .30712 m .70758 .30813 L .70777 .30869 L F
.515 .086 .163 r
.70528 .30946 m .70844 .30712 L .70577 .3106 L F
.608 .935 .956 r
.70777 .30869 m .70758 .30813 L .71142 .30675 L F
.542 .108 .166 r
.70758 .30813 m .70751 .30909 L .70858 .30841 L F
.70751 .30909 m .70746 .30984 L .70858 .30841 L F
.872 .993 .801 r
.70729 .31079 m .70577 .3106 L .70674 .30933 L F
.301 0 0 r
.30065 .56464 m .30322 .56428 L .30506 .56269 L F
.203 0 0 r
.30506 .56269 m .30632 .56364 L .30814 .56231 L F
.30506 .56269 m .30322 .56428 L .30632 .56364 L F
.589 .801 .981 r
.43139 .48673 m .43352 .4882 L .43591 .4871 L F
.422 .186 .449 r
.43274 .49064 m .43591 .4871 L .43352 .4882 L F
.612 .08 0 r
.43364 .50669 m .4359 .50859 L .43775 .50756 L F
0 0 .125 r
.44044 .50384 m .43775 .50756 L .43961 .50617 L F
.498 .107 .23 r
.4359 .50859 m .43961 .50617 L .43775 .50756 L F
.444 .352 .658 r
.47758 .53953 m .47808 .54239 L .47598 .54265 L F
.404 .183 .461 r
.47598 .54265 m .47777 .54448 L .47611 .5487 L F
.47598 .54265 m .47808 .54239 L .47777 .54448 L F
.659 .959 .753 r
.31075 .62293 m .30911 .62455 L .30674 .62576 L F
0 0 .159 r
.55289 .42272 m .55285 .42535 L .55238 .42653 L F
0 .103 .649 r
.55285 .42535 m .55421 .42925 L .55238 .42653 L F
.626 .104 0 r
.61688 .43393 m .61657 .43395 L .61652 .43391 L F
.61611 .43319 m .61652 .43391 L .61274 .42995 L F
.61688 .43393 m .61652 .43391 L .61611 .43319 L F
.153 0 0 r
.61851 .4324 m .6179 .43404 L .61681 .43442 L F
.61655 .43396 m .61529 .43495 L .61688 .43393 L F
.402 .809 .6 r
.61688 .43393 m .61529 .43495 L .61666 .43405 L F
.153 0 0 r
.61655 .43396 m .61681 .43442 L .61529 .43495 L F
.61851 .4324 m .61655 .43396 L .61688 .43393 L F
.626 .104 0 r
.61688 .43393 m .61666 .43405 L .61657 .43395 L F
.153 0 0 r
.61851 .4324 m .61681 .43442 L .61655 .43396 L F
.656 .533 .701 r
.5446 .39765 m .54224 .39914 L .54192 .39832 L F
.5446 .39765 m .54224 .39914 L .54192 .39832 L F
0 0 0 r
.64783 .39912 m .64906 .39795 L .65132 .3967 L F
.823 .834 .363 r
.62162 .42668 m .62071 .42835 L .62101 .42853 L F
0 0 0 r
.62355 .42522 m .62383 .42552 L .62162 .42668 L F
.62383 .42552 m .62071 .42835 L .62162 .42668 L F
.388 .319 .658 r
.47651 .53286 m .47709 .53494 L .47567 .53967 L F
.517 .452 .722 r
.47567 .53967 m .47709 .53494 L .47758 .53953 L F
.78 .471 .464 r
.38857 .67136 m .39232 .67128 L .39246 .67399 L F
0 .198 .721 r
.39246 .67399 m .39367 .67368 L .39114 .67421 L F
.387 0 0 r
.38804 .67414 m .3892 .6741 L .3885 .67477 L F
.3892 .6741 m .39246 .67399 L .3885 .67477 L F
.78 .471 .464 r
.38857 .67136 m .39246 .67399 L .38804 .67414 L F
.913 .914 .521 r
.38839 .67486 m .3885 .67477 L .38898 .67235 L F
.387 0 0 r
.38804 .67414 m .3885 .67477 L .38796 .67672 L F
.913 .914 .521 r
.38796 .67672 m .3885 .67477 L .38839 .67486 L F
0 .198 .721 r
.39246 .67399 m .39114 .67421 L .3885 .67477 L F
.967 .646 .339 r
.39232 .67128 m .39372 .67378 L .39246 .67399 L F
.39372 .67378 m .39439 .67499 L .39246 .67399 L F
.578 .438 .654 r
.3567 .6036 m .35438 .60692 L .35494 .60445 L F
.435 0 0 r
.60816 .38545 m .60915 .38549 L .606 .38433 L F
0 .169 .697 r
.61094 .38537 m .60915 .38549 L .60816 .38545 L F
.61094 .38537 m .61072 .38753 L .60915 .38549 L F
0 0 0 r
.38367 .48651 m .38381 .48434 L .38278 .48263 L F
.977 .879 .668 r
.38614 .48492 m .38367 .48651 L .38384 .48387 L F
0 0 0 r
.38437 .48528 m .38378 .48372 L .38278 .48263 L F
.868 .502 .353 r
.38438 .4813 m .38378 .48372 L .38278 .48263 L F
0 0 0 r
.38378 .48372 m .38337 .48263 L .38278 .48263 L F
.868 .502 .353 r
.38378 .48372 m .38375 .48383 L .38278 .48263 L F
.977 .879 .668 r
.38384 .48387 m .38367 .48651 L .38375 .48383 L F
0 0 0 r
.38367 .48651 m .38437 .48528 L .38381 .48434 L F
.977 .678 .359 r
.38508 .48273 m .38384 .48387 L .38438 .4813 L F
.38384 .48387 m .38384 .48387 L .38438 .4813 L F
.38384 .48387 m .38378 .48372 L .38438 .4813 L F
.691 .693 .847 r
.38302 .47942 m .38438 .4813 L .38037 .48053 L F
.654 .193 .145 r
.38438 .4813 m .37986 .48163 L .38037 .48053 L F
.38438 .4813 m .38278 .48263 L .37986 .48163 L F
.771 .716 .801 r
.38717 .47899 m .38438 .4813 L .38302 .47942 L F
.38717 .47899 m .38302 .47942 L .38536 .47772 L F
.589 .55 .778 r
.38311 .48196 m .38591 .48261 L .38472 .47861 L F
.38278 .48263 m .38337 .48263 L .38311 .48196 L F
.38337 .48263 m .38591 .48261 L .38311 .48196 L F
.977 .678 .359 r
.38384 .48387 m .38384 .48387 L .38384 .48387 L F
.38614 .48492 m .38466 .48424 L .38508 .48273 L F
.38466 .48424 m .38384 .48387 L .38508 .48273 L F
0 0 0 r
.38437 .48528 m .38514 .48479 L .38591 .48261 L F
.38367 .48651 m .38421 .48588 L .38437 .48528 L F
.38421 .48588 m .38514 .48479 L .38437 .48528 L F
.38437 .48528 m .38591 .48261 L .38337 .48263 L F
.977 .678 .359 r
.38384 .48387 m .38375 .48383 L .38378 .48372 L F
.755 .344 .27 r
.38614 .48492 m .38954 .48845 L .38367 .48651 L F
.901 .687 .604 r
.60465 .448 m .60772 .44604 L .605 .44516 L F
.60465 .448 m .60683 .44896 L .60772 .44604 L F
.815 .335 0 r
.35972 .50645 m .35971 .50433 L .35773 .5034 L F
.35972 .50645 m .36178 .50784 L .35971 .50433 L F
.777 .304 0 r
.35971 .50433 m .36178 .50784 L .36319 .50892 L F
.648 .782 .945 r
.3402 .63044 m .34144 .62759 L .34255 .62767 L F
.874 .99 .817 r
.34144 .62759 m .34326 .62683 L .3402 .63044 L F
.648 .782 .945 r
.3402 .63044 m .34239 .62793 L .34144 .62759 L F
.378 0 0 r
.34144 .62759 m .34239 .62793 L .33988 .62747 L F
.34144 .62759 m .33988 .62747 L .33951 .6274 L F
.648 .782 .945 r
.34255 .62767 m .34144 .62759 L .34326 .62683 L F
.3402 .63044 m .34347 .62953 L .34239 .62793 L F
.432 .216 .483 r
.34068 .63272 m .34347 .62953 L .3402 .63044 L F
.892 .931 .837 r
.39541 .67068 m .39638 .67206 L .39896 .66879 L F
.37 0 0 r
.39683 .67329 m .39638 .67206 L .39541 .67068 L F
.39683 .67329 m .3981 .67233 L .39638 .67206 L F
.607 .443 .634 r
.27482 .57558 m .27468 .57808 L .2776 .57492 L F
.889 .931 .841 r
.24387 .5272 m .245 .52332 L .24615 .52357 L F
.223 .466 .88 r
.24668 .52162 m .2476 .52362 L .24615 .52357 L F
.772 .993 .879 r
.24615 .52357 m .245 .52332 L .24668 .52162 L F
.854 .862 .847 r
.385 .60441 m .38031 .60622 L .38254 .60391 L F
.855 .709 .7 r
.36247 .62014 m .36394 .62306 L .36391 .62309 L F
.631 .231 0 r
.36394 .62306 m .36594 .62662 L .36391 .62309 L F
.728 .472 .54 r
.3657 .62373 m .36594 .62662 L .36394 .62306 L F
.907 .552 .356 r
.61274 .42995 m .61081 .42949 L .61038 .42675 L F
.755 .238 0 r
.61274 .42995 m .61215 .43091 L .61081 .42949 L F
.61274 .42995 m .61666 .43405 L .61215 .43091 L F
.558 .295 .473 r
.51953 .47824 m .51832 .4813 L .51549 .48154 L F
.579 .264 .399 r
.51953 .47824 m .52188 .48032 L .51832 .4813 L F
.51953 .47824 m .52186 .47821 L .52188 .48032 L F
.632 .417 .573 r
.43637 .55707 m .43853 .55621 L .43586 .5582 L F
.702 .738 .879 r
.34788 .51359 m .35116 .51464 L .34888 .5114 L F
.481 .64 .926 r
.34888 .5114 m .35116 .51464 L .35277 .51235 L F
.878 .864 .822 r
.3526 .51685 m .35277 .51235 L .35116 .51464 L F
.592 .896 .988 r
.28214 .51618 m .28199 .51832 L .2844 .51773 L F
.28214 .51618 m .27942 .51748 L .28199 .51832 L F
.434 .095 .29 r
.26746 .62237 m .26936 .62297 L .26861 .62098 L F
.218 .041 .414 r
.34384 .52301 m .34755 .51901 L .34919 .52306 L F
.34384 .52301 m .34519 .52526 L .34755 .51901 L F
.435 .462 .788 r
.3381 .58077 m .33936 .58414 L .33676 .58488 L F
.555 .399 .624 r
.33619 .58796 m .33936 .58414 L .33676 .58488 L F
.33619 .58796 m .33936 .58414 L .33676 .58488 L F
.826 .566 .545 r
.34259 .62387 m .33711 .62539 L .33729 .62343 L F
.34259 .62387 m .34144 .62759 L .33711 .62539 L F
.724 .463 0 r
.34259 .62387 m .34326 .62683 L .34144 .62759 L F
.552 .093 .118 r
.26909 .51858 m .27096 .51975 L .2685 .51907 L F
.589 .801 .981 r
.43139 .48673 m .43613 .48496 L .43394 .48326 L F
.43139 .48673 m .43591 .4871 L .43613 .48496 L F
.637 .338 .447 r
.43591 .4871 m .43881 .48749 L .43613 .48496 L F
.65 .496 .662 r
.43613 .48496 m .43968 .48516 L .43881 .48166 L F
.631 .339 .457 r
.43613 .48496 m .43881 .48749 L .43968 .48516 L F
.575 .332 .51 r
.49898 .49739 m .4957 .50021 L .4959 .49808 L F
.931 .962 .765 r
.38163 .61515 m .38434 .61376 L .38181 .6177 L F
.957 .919 .729 r
.38339 .60872 m .38434 .61376 L .38163 .61515 L F
.831 .655 .664 r
.41682 .59745 m .42047 .59785 L .41868 .5943 L F
.788 .741 .81 r
.41682 .59745 m .41865 .59924 L .42047 .59785 L F
.537 .889 .66 r
.41865 .59924 m .41859 .5993 L .42047 .59785 L F
.778 .896 .49 r
.38411 .623 m .38544 .62065 L .38394 .62256 L F
.853 .976 .671 r
.38574 .61867 m .38544 .62065 L .38769 .61718 L F
.837 .907 .498 r
.38394 .62256 m .38544 .62065 L .38574 .61867 L F
.824 .722 .753 r
.53833 .40116 m .53915 .40372 L .54224 .39914 L F
.352 .322 .685 r
.47895 .54856 m .47713 .55236 L .47648 .54927 L F
.47895 .54856 m .47976 .55151 L .47713 .55236 L F
.029 0 .308 r
.47976 .55151 m .47752 .55551 L .47713 .55236 L F
0 0 .129 r
.35348 .59797 m .35291 .60044 L .35452 .59671 L F
0 0 .46 r
.34326 .62683 m .34435 .62279 L .34439 .62636 L F
0 0 .079 r
.34347 .62858 m .34326 .62683 L .34439 .62636 L F
0 0 .044 r
.34347 .62953 m .34388 .63141 L .34442 .63011 L F
.561 .057 .015 r
.34388 .63141 m .34687 .63124 L .34442 .63011 L F
.811 .669 .706 r
.34651 .62799 m .34388 .63141 L .34347 .62858 L F
0 0 .284 r
.34347 .62858 m .34388 .63141 L .34435 .62945 L F
.34347 .62858 m .34435 .62945 L .34358 .62904 L F
0 0 .079 r
.34347 .62858 m .34347 .62953 L .34336 .62817 L F
0 .207 .724 r
.34239 .62793 m .34347 .62953 L .34347 .62858 L F
0 0 .284 r
.34347 .62858 m .34358 .62904 L .34163 .62799 L F
0 0 .079 r
.34347 .62858 m .34336 .62817 L .34326 .62683 L F
.509 .76 .987 r
.37607 .65633 m .37873 .65604 L .37724 .65465 L F
.333 .304 .677 r
.43881 .48166 m .44011 .47904 L .4375 .47874 L F
.43881 .48166 m .44056 .48114 L .44011 .47904 L F
.359 .395 .762 r
.43881 .48166 m .44206 .48384 L .44056 .48114 L F
.471 .382 .674 r
.43881 .48166 m .43968 .48516 L .44206 .48384 L F
0 0 0 r
.33001 .52091 m .32695 .52364 L .32873 .52266 L F
.361 .068 .326 r
.32873 .52266 m .33158 .51954 L .33001 .52091 L F
.902 .744 .676 r
.32875 .52778 m .33351 .52556 L .33168 .52505 L F
.32875 .52778 m .33154 .52951 L .33351 .52556 L F
0 0 .14 r
.33548 .52265 m .33351 .52556 L .33424 .52413 L F
.191 0 0 r
.33548 .52265 m .33168 .52505 L .33351 .52556 L F
.74 .88 .944 r
.44834 .45421 m .45178 .45204 L .45346 .45323 L F
.753 .924 .946 r
.45178 .45204 m .45491 .45177 L .45346 .45323 L F
.836 .602 .054 r
.29935 .50942 m .29913 .50988 L .29878 .50649 L F
0 0 .517 r
.29979 .50768 m .29935 .50942 L .29878 .50649 L F
.713 .755 .251 r
.29979 .50768 m .29913 .50988 L .29935 .50942 L F
.462 .888 .822 r
.68274 .37649 m .68284 .37595 L .68086 .37759 L F
.68274 .37649 m .68467 .37566 L .68284 .37595 L F
.432 .203 .464 r
.32612 .52613 m .32873 .52266 L .32695 .52364 L F
.417 .839 .961 r
.58465 .4598 m .58496 .46038 L .58826 .45957 L F
.42 .274 .575 r
.47906 .51355 m .47926 .51618 L .47708 .51704 L F
.49 .37 .644 r
.47926 .51618 m .47705 .52022 L .47708 .51704 L F
.506 .167 .326 r
.4476 .51751 m .44548 .52169 L .4432 .52177 L F
.434 .037 .185 r
.44981 .51693 m .44872 .51932 L .4476 .51751 L F
.316 0 .222 r
.44884 .51966 m .4476 .51751 L .44872 .51932 L F
.44884 .51966 m .44548 .52169 L .4476 .51751 L F
0 0 .182 r
.6073 .3778 m .60685 .37966 L .60723 .37773 L F
0 0 0 r
.60723 .37773 m .60948 .37659 L .6073 .3778 L F
.60723 .37773 m .61054 .37528 L .60948 .37659 L F
.826 .767 .257 r
.41233 .58072 m .41184 .58491 L .41142 .58337 L F
.913 .713 .215 r
.41184 .58491 m .41111 .58596 L .41142 .58337 L F
.41184 .58491 m .41182 .58775 L .41111 .58596 L F
.757 .855 .923 r
.38641 .59743 m .38342 .60029 L .38364 .59907 L F
.754 .746 .845 r
.55528 .43216 m .5547 .43618 L .55306 .4364 L F
.333 0 0 r
.55306 .4364 m .5547 .43618 L .55482 .43724 L F
.59 .94 .782 r
.3051 .63904 m .30025 .64167 L .30292 .64154 L F
.3 .209 .582 r
.30544 .63697 m .3051 .63904 L .307 .63885 L F
.471 .325 .6 r
.37491 .54305 m .37745 .5453 L .37724 .54232 L F
.37491 .54305 m .37745 .5453 L .37724 .54232 L F
.611 .304 .425 r
.37491 .54305 m .37452 .54562 L .37745 .5453 L F
.958 .8 .643 r
.61038 .42675 m .60827 .42553 L .6093 .42239 L F
.941 .58 .28 r
.61081 .42949 m .60827 .42553 L .61038 .42675 L F
.672 .395 .493 r
.28236 .57159 m .285 .57165 L .28647 .56862 L F
.319 0 .232 r
.285 .57165 m .28888 .56817 L .28647 .56862 L F
.43 .334 .645 r
.47807 .52592 m .47606 .53027 L .47555 .52635 L F
.533 .335 .558 r
.32661 .55531 m .32368 .55841 L .3236 .5557 L F
0 0 0 r
.29863 .62702 m .30029 .62549 L .30069 .62578 L F
.145 .127 .578 r
.29863 .62702 m .29917 .62974 L .30054 .6293 L F
.534 .923 .835 r
.68284 .37595 m .68467 .37566 L .68695 .37432 L F
.973 .662 .329 r
.59397 .41403 m .59214 .40997 L .5928 .41222 L F
.946 .658 .205 r
.59316 .41491 m .59397 .41403 L .5928 .41222 L F
.59316 .41491 m .59441 .41719 L .59397 .41403 L F
.568 .902 .98 r
.45271 .53235 m .45107 .53147 L .44999 .53325 L F
.435 .75 .994 r
.44999 .53325 m .45107 .53147 L .44823 .53174 L F
.165 0 0 r
.31871 .56241 m .31716 .56433 L .31468 .56503 L F
0 0 0 r
.31915 .56315 m .31871 .56241 L .3211 .56174 L F
.31915 .56315 m .31716 .56433 L .31871 .56241 L F
.561 .902 .671 r
.67185 .32456 m .66987 .32626 L .67019 .32624 L F
.956 .773 .615 r
.42848 .57172 m .42911 .56923 L .42721 .56641 L F
0 0 0 r
.62924 .40078 m .62736 .40469 L .6293 .40335 L F
.095 0 .185 r
.6293 .40335 m .62736 .40469 L .62684 .40672 L F
.811 .795 .837 r
.4934 .42912 m .49465 .43234 L .49073 .43216 L F
.812 .794 .836 r
.49073 .43216 m .49465 .43234 L .49245 .43386 L F
.741 .762 .87 r
.49745 .42961 m .49465 .43234 L .4934 .42912 L F
.78 .963 .654 r
.38769 .61718 m .39018 .61387 L .3882 .6155 L F
.78 .967 .666 r
.38574 .61867 m .38769 .61718 L .3882 .6155 L F
.892 .931 .837 r
.39541 .67068 m .39896 .66879 L .39523 .66821 L F
.705 .543 .665 r
.43853 .55621 m .43827 .55953 L .43586 .5582 L F
.663 .933 .969 r
.439 .50326 m .43678 .50476 L .44044 .50384 L F
.352 .792 .961 r
.44257 .50334 m .439 .50326 L .44044 .50384 L F
.991 .776 .515 r
.44044 .50384 m .43961 .50617 L .439 .50326 L F
0 0 0 r
.22876 .55723 m .22742 .55901 L .2294 .55562 L F
0 0 .465 r
.22876 .55723 m .22858 .56132 L .22742 .55901 L F
.22742 .55901 m .22858 .56132 L .22782 .56171 L F
.507 .313 .552 r
.48132 .50745 m .4813 .51013 L .47871 .51076 L F
.522 .384 .634 r
.4813 .51013 m .47906 .51355 L .47871 .51076 L F
.3 .159 .516 r
.36759 .62561 m .3657 .62373 L .36781 .62296 L F
.36759 .62561 m .36594 .62662 L .3657 .62373 L F
.736 .757 .87 r
.57863 .37225 m .5806 .37459 L .5759 .3743 L F
.888 .869 .813 r
.5806 .37459 m .57602 .37698 L .5759 .3743 L F
.5806 .37459 m .57769 .37805 L .57602 .37698 L F
.344 .589 .936 r
.58122 .37271 m .5806 .37459 L .57863 .37225 L F
.29 .528 .909 r
.58122 .37271 m .5825 .37448 L .5806 .37459 L F
.054 .62 .737 r
.5806 .37459 m .5825 .37448 L .58319 .3745 L F
.57 .358 .553 r
.44637 .56148 m .44897 .5618 L .44914 .55909 L F
.553 .329 .53 r
.44601 .56518 m .44897 .5618 L .44637 .56148 L F
.663 .568 .737 r
.43545 .58646 m .43738 .58474 L .43364 .58442 L F
.995 .773 .485 r
.60365 .44135 m .60518 .43985 L .60325 .43884 L F
.60365 .44135 m .60502 .44249 L .60518 .43985 L F
0 0 .418 r
.62263 .36017 m .62148 .35874 L .62209 .3574 L F
.62263 .36017 m .62187 .36188 L .62169 .3605 L F
0 0 0 r
.62355 .35984 m .62263 .36017 L .6209 .3611 L F
.726 .735 .858 r
.62493 .35918 m .62225 .3627 L .62263 .36017 L F
0 0 0 r
.62493 .35918 m .62263 .36017 L .62355 .35984 L F
0 0 .418 r
.62263 .36017 m .62169 .3605 L .62148 .35874 L F
.553 .85 .998 r
.62209 .3574 m .62148 .35874 L .61937 .35821 L F
0 0 0 r
.3166 .61408 m .31426 .61762 L .31549 .61623 L F
.021 0 .138 r
.31906 .6108 m .3166 .61408 L .31826 .61296 L F
0 0 .039 r
.31549 .61623 m .31826 .61296 L .3166 .61408 L F
.963 .765 .589 r
.36715 .52068 m .36643 .52305 L .36504 .51944 L F
.915 .723 .628 r
.39274 .68797 m .39354 .68491 L .39104 .68419 L F
.019 0 0 r
.31075 .62033 m .31256 .61959 L .31426 .61762 L F
0 0 0 r
.31256 .61959 m .31549 .61623 L .31426 .61762 L F
.731 .765 .88 r
.42557 .46674 m .42149 .46598 L .42366 .46446 L F
.558 .256 .412 r
.42557 .46674 m .42755 .46712 L .42795 .46514 L F
0 0 .024 r
.42619 .46657 m .42557 .46674 L .42366 .46446 L F
.558 .256 .412 r
.42557 .46674 m .42528 .46862 L .42755 .46712 L F
0 0 .024 r
.42619 .46657 m .42528 .46862 L .42557 .46674 L F
.755 .825 .907 r
.39332 .48987 m .3968 .49114 L .39394 .4885 L F
.329 0 0 r
.39332 .48987 m .39472 .49047 L .3968 .49114 L F
.398 .689 .978 r
.39394 .4885 m .3968 .49114 L .39693 .48862 L F
.722 .952 .951 r
.3968 .49114 m .39472 .49047 L .39693 .48862 L F
.847 .803 .312 r
.70842 .33486 m .7086 .33565 L .7091 .33345 L F
.671 .78 .309 r
.70842 .33486 m .7091 .33345 L .71025 .33072 L F
.52 .749 .979 r
.2476 .59228 m .24485 .5945 L .24389 .59345 L F
.994 .83 .466 r
.24485 .5945 m .24347 .5956 L .24389 .59345 L F
.652 .56 .739 r
.40316 .48869 m .40051 .49135 L .39965 .48682 L F
.315 .038 .324 r
.35955 .60047 m .3567 .6036 L .35738 .60124 L F
.615 .929 .967 r
.60478 .34952 m .60054 .35029 L .60375 .34954 L F
.4 .849 .914 r
.60375 .34954 m .60744 .34878 L .60478 .34952 L F
.499 .757 .987 r
.32886 .51212 m .33089 .51374 L .32815 .51415 L F
.966 .706 .489 r
.33089 .51374 m .32886 .51212 L .32815 .51415 L F
.889 .931 .841 r
.24387 .5272 m .24257 .52621 L .245 .52332 L F
.541 .209 .354 r
.24691 .52693 m .24565 .52883 L .24387 .5272 L F
.769 .799 .877 r
.6537 .38075 m .65127 .38089 L .65325 .37935 L F
0 0 0 r
.65353 .37918 m .65029 .38216 L .65323 .37999 L F
.65358 .37903 m .65325 .37935 L .65353 .37918 L F
.769 .799 .877 r
.6537 .38075 m .65325 .37935 L .6539 .37894 L F
.729 .93 .956 r
.65665 .37778 m .6537 .38075 L .65391 .37884 L F
.65665 .37778 m .65816 .37861 L .6537 .38075 L F
.019 0 0 r
.65593 .37893 m .65386 .37902 L .65323 .37999 L F
.65386 .37902 m .65358 .37903 L .65353 .37918 L F
.65386 .37902 m .65353 .37918 L .65323 .37999 L F
.078 0 0 r
.65386 .37902 m .65391 .37884 L .65358 .37903 L F
.769 .799 .877 r
.6539 .37894 m .65388 .37895 L .65391 .37884 L F
.078 0 0 r
.65593 .37893 m .65391 .37884 L .65386 .37902 L F
.769 .799 .877 r
.65388 .37895 m .65353 .37918 L .65391 .37884 L F
.65353 .37918 m .65325 .37935 L .6534 .37924 L F
.65353 .37918 m .6534 .37924 L .65391 .37884 L F
0 0 0 r
.65391 .37884 m .65325 .37935 L .65358 .37903 L F
.65325 .37935 m .65127 .38089 L .65358 .37903 L F
.65358 .37903 m .65322 .37937 L .65325 .37935 L F
.65322 .37937 m .65029 .38216 L .65353 .37918 L F
.503 0 0 r
.23023 .60425 m .22819 .60438 L .22621 .60359 L F
.039 .014 .498 r
.2315 .59999 m .23174 .603 L .23023 .60425 L F
.585 .01 0 r
.23238 .6064 m .23023 .60425 L .23174 .603 L F
.398 0 0 r
.28549 .53572 m .28439 .53637 L .28202 .5361 L F
.28549 .53572 m .28439 .53637 L .28202 .5361 L F
.767 .979 .717 r
.28726 .53303 m .28549 .53572 L .28693 .53452 L F
.28726 .53303 m .28439 .53637 L .28549 .53572 L F
.418 .057 .242 r
.28693 .53452 m .28439 .53637 L .28549 .53572 L F
.761 .864 .43 r
.70028 .26658 m .69906 .26946 L .7001 .26683 L F
.43 .48 .811 r
.69906 .26946 m .70169 .27129 L .7001 .26683 L F
.129 0 .139 r
.43545 .58646 m .43674 .58703 L .43738 .58474 L F
.43545 .58646 m .43674 .58703 L .43738 .58474 L F
.142 0 0 r
.30069 .62578 m .30029 .62549 L .3041 .62536 L F
.3 .209 .582 r
.30544 .63697 m .307 .63885 L .30548 .63497 L F
.958 .733 .554 r
.60791 .45531 m .60836 .4527 L .6065 .45161 L F
.568 .248 .386 r
.39202 .49314 m .39028 .49154 L .39364 .49176 L F
.866 .566 .478 r
.39364 .49176 m .39427 .49461 L .39202 .49314 L F
.974 .864 .667 r
.29344 .51308 m .29356 .51644 L .29527 .51731 L F
.741 .628 .734 r
.45115 .52366 m .45299 .52491 L .45415 .52021 L F
.71 .56 .683 r
.45256 .5267 m .45299 .52491 L .45115 .52366 L F
.45256 .5267 m .45531 .52679 L .45299 .52491 L F
.371 .263 .599 r
.45415 .52021 m .45299 .52491 L .4563 .52244 L F
.052 .401 .856 r
.45299 .52491 m .45484 .52463 L .4563 .52244 L F
.45299 .52491 m .45531 .52679 L .45484 .52463 L F
.812 .729 .773 r
.37342 .53656 m .36945 .53625 L .37226 .53302 L F
.754 .746 .845 r
.55528 .43216 m .55306 .4364 L .5533 .4335 L F
.966 .908 .707 r
.4236 .48307 m .42109 .48375 L .42116 .4836 L F
.579 .55 .786 r
.42252 .48264 m .42517 .48273 L .4236 .48307 L F
.966 .908 .707 r
.4236 .48307 m .42116 .4836 L .42222 .48136 L F
.579 .55 .786 r
.42517 .48273 m .42563 .48275 L .4236 .48307 L F
.288 .788 .833 r
.34198 .54813 m .33925 .54901 L .34146 .54587 L F
.306 .066 .377 r
.34443 .54207 m .34384 .54532 L .34146 .54587 L F
.671 .212 .155 r
.34408 .54821 m .34146 .54587 L .34384 .54532 L F
.34408 .54821 m .34198 .54813 L .34146 .54587 L F
.765 .808 .887 r
.36828 .67424 m .36728 .67824 L .36967 .67776 L F
.365 .102 .376 r
.36967 .67776 m .36728 .67824 L .36684 .6816 L F
.812 .77 .813 r
.44045 .49131 m .43769 .4942 L .44152 .49455 L F
.296 0 .092 r
.43794 .4973 m .44152 .49455 L .43769 .4942 L F
.43794 .4973 m .44067 .49672 L .44152 .49455 L F
.543 .313 .516 r
.45276 .56201 m .45555 .56165 L .45561 .55907 L F
.45561 .55907 m .45555 .56165 L .45276 .56201 L F
.444 .548 .868 r
.44045 .49131 m .44152 .49455 L .44227 .49363 L F
0 0 0 r
.44152 .49455 m .44185 .49537 L .44227 .49363 L F
.44152 .49455 m .44067 .49672 L .44185 .49537 L F
.451 .704 .975 r
.45561 .55907 m .45747 .5577 L .45873 .5592 L F
.45561 .55907 m .45747 .5577 L .45873 .5592 L F
.569 .334 .519 r
.45873 .5592 m .45555 .56165 L .45561 .55907 L F
.45873 .5592 m .45555 .56165 L .45561 .55907 L F
.782 .948 .929 r
.41677 .46869 m .42009 .46435 L .42149 .46598 L F
.41677 .46869 m .41568 .46767 L .42009 .46435 L F
.447 0 .074 r
.31403 .54491 m .31715 .54513 L .31742 .54315 L F
.524 .461 .727 r
.31232 .54805 m .31461 .54885 L .31408 .54572 L F
.31232 .54805 m .31408 .54572 L .31224 .54748 L F
.77 .63 .706 r
.31461 .54885 m .31069 .54849 L .31408 .54572 L F
.416 .163 .419 r
.31315 .54754 m .31411 .54654 L .31408 .54572 L F
.447 0 .074 r
.31406 .54491 m .31408 .54572 L .31715 .54513 L F
.714 .593 .719 r
.31408 .54572 m .31461 .54885 L .31715 .54513 L F
.634 .538 .728 r
.31677 .54766 m .31461 .54885 L .31408 .54572 L F
.31677 .54766 m .31408 .54572 L .316 .54457 L F
.416 .163 .419 r
.31411 .54654 m .316 .54457 L .31408 .54572 L F
.447 0 .074 r
.31403 .54491 m .31408 .54572 L .31406 .54491 L F
.831 .751 .775 r
.5695 .4148 m .56821 .41715 L .5647 .41606 L F
.876 .571 .468 r
.56821 .41715 m .56438 .41819 L .5647 .41606 L F
.56821 .41715 m .56845 .41943 L .56438 .41819 L F
.954 .913 .547 r
.39018 .61387 m .39081 .60926 L .38905 .61309 L F
.992 .877 .604 r
.3882 .6155 m .39018 .61387 L .38905 .61309 L F
.431 .227 .5 r
.36149 .6392 m .36162 .63649 L .36394 .63588 L F
.36149 .6392 m .36162 .63649 L .36394 .63588 L F
.057 .623 .747 r
.33758 .50226 m .34139 .5021 L .33891 .5021 L F
.491 .47 .761 r
.67891 .35924 m .67934 .35922 L .67789 .35714 L F
.67891 .35924 m .68046 .36112 L .67934 .35922 L F
.275 .198 .585 r
.60742 .36475 m .60889 .36053 L .60742 .36223 L F
.709 .617 .753 r
.3747 .52676 m .37195 .53003 L .37092 .52702 L F
.982 .707 .418 r
.37092 .52702 m .37195 .53003 L .37038 .52871 L F
0 0 0 r
.30104 .66906 m .30439 .66485 L .30319 .66693 L F
.045 .331 .813 r
.30638 .66519 m .30222 .66141 L .30478 .66116 L F
.30638 .66519 m .30439 .66485 L .30275 .66226 L F
.30638 .66519 m .30275 .66226 L .3034 .66249 L F
.30638 .66519 m .30501 .66174 L .30432 .66382 L F
.30501 .66174 m .30478 .66116 L .30432 .66382 L F
.185 0 .099 r
.30319 .66693 m .30439 .66485 L .30638 .66519 L F
.659 .704 .88 r
.30319 .66693 m .30638 .66519 L .30432 .66382 L F
.893 .82 .769 r
.30685 .66062 m .30638 .66519 L .30432 .66382 L F
.88 .765 .731 r
.30861 .66381 m .31022 .6652 L .30638 .66519 L F
.893 .82 .769 r
.30685 .66062 m .30861 .66381 L .30638 .66519 L F
.088 .502 .901 r
.30432 .66382 m .30638 .66519 L .30704 .6652 L F
.30665 .66485 m .30704 .6652 L .30747 .66521 L F
.30432 .66382 m .30704 .6652 L .30665 .66485 L F
.893 .82 .769 r
.30685 .66062 m .30494 .66304 L .30478 .66116 L F
.30494 .66304 m .30432 .66382 L .30448 .66288 L F
.016 0 0 r
.30638 .66519 m .30695 .66519 L .30747 .66521 L F
.30695 .66519 m .31022 .6652 L .30756 .66521 L F
.30695 .66519 m .30756 .66521 L .30747 .66521 L F
.575 .738 .953 r
.31229 .66419 m .31022 .6652 L .30861 .66381 L F
.488 .9 .898 r
.30747 .66521 m .31022 .6652 L .31229 .66419 L F
.30771 .66529 m .31229 .66419 L .31056 .66622 L F
.30747 .66521 m .30757 .66519 L .30771 .66529 L F
.30757 .66519 m .31229 .66419 L .30771 .66529 L F
0 .278 .768 r
.30855 .66524 m .30811 .66557 L .30909 .66568 L F
.30811 .66557 m .30805 .66561 L .30817 .66562 L F
.30811 .66557 m .30817 .66562 L .30909 .66568 L F
.30498 .66228 m .30769 .66522 L .30855 .66524 L F
.30769 .66522 m .30805 .66561 L .30855 .66524 L F
.088 .502 .901 r
.30432 .66382 m .30747 .66521 L .30805 .66561 L F
.258 .547 .926 r
.30432 .66382 m .30676 .66499 L .30498 .66228 L F
.30676 .66499 m .30805 .66561 L .30778 .66531 L F
.30676 .66499 m .30778 .66531 L .30498 .66228 L F
0 .391 .7 r
.30747 .66521 m .31056 .66622 L .31005 .66604 L F
.30748 .66522 m .31005 .66604 L .30909 .66568 L F
.30747 .66521 m .31005 .66604 L .30748 .66522 L F
.153 0 .258 r
.30372 .66563 m .30432 .66382 L .30577 .66365 L F
.659 .704 .88 r
.30319 .66693 m .30432 .66382 L .30192 .66738 L F
.153 0 .258 r
.30192 .66738 m .30432 .66382 L .30372 .66563 L F
.30192 .66738 m .30556 .66385 L .29991 .66609 L F
.30556 .66385 m .30577 .66365 L .30547 .66377 L F
.30556 .66385 m .30547 .66377 L .29991 .66609 L F
.893 .82 .769 r
.30494 .66304 m .30448 .66288 L .30478 .66116 L F
.045 .331 .813 r
.3034 .66249 m .30275 .66226 L .30222 .66141 L F
.996 .788 .506 r
.37015 .69131 m .3699 .69402 L .3684 .69317 L F
.641 .882 .534 r
.37276 .68804 m .37015 .69131 L .37099 .6899 L F
.64 .879 .527 r
.37099 .6899 m .37015 .69131 L .3684 .69317 L F
.784 .527 .548 r
.37015 .69131 m .37417 .6945 L .3699 .69402 L F
0 0 0 r
.6122 .37382 m .61054 .37528 L .61258 .37343 L F
.708 .587 .718 r
.34843 .56485 m .34584 .56812 L .34613 .56553 L F
.788 .605 .653 r
.37911 .59739 m .37807 .59346 L .37983 .59526 L F
.37911 .59739 m .37554 .59409 L .37807 .59346 L F
.37911 .59739 m .37694 .59804 L .37554 .59409 L F
.806 .673 .717 r
.37911 .59739 m .37649 .60086 L .37694 .59804 L F
0 .408 .853 r
.54205 .41011 m .54084 .41062 L .53898 .41149 L F
.54205 .41011 m .54353 .41187 L .54084 .41062 L F
.949 .777 .634 r
.56268 .43629 m .56353 .43928 L .56398 .43553 L F
.619 .481 .671 r
.48419 .50421 m .48397 .50679 L .48132 .50745 L F
.543 .341 .557 r
.48387 .50944 m .48132 .50745 L .48397 .50679 L F
.48387 .50944 m .4813 .51013 L .48132 .50745 L F
.388 .137 .407 r
.28843 .62937 m .28885 .62696 L .28679 .63094 L F
.546 .438 .682 r
.29088 .62342 m .29134 .62644 L .28885 .62696 L F
.467 .2 .425 r
.28885 .62696 m .29089 .62891 L .28843 .62937 L F
.28885 .62696 m .29134 .62644 L .29089 .62891 L F
.546 .438 .682 r
.28885 .62696 m .29134 .62644 L .29088 .62342 L F
.467 .2 .425 r
.28885 .62696 m .29089 .62891 L .28843 .62937 L F
.28885 .62696 m .29134 .62644 L .29089 .62891 L F
.692 .517 .646 r
.37673 .68832 m .37931 .68763 L .3769 .69141 L F
.358 .133 .43 r
.38209 .68748 m .37931 .68763 L .38193 .6847 L F
0 .13 .667 r
.38146 .68995 m .37931 .68763 L .38209 .68748 L F
.721 .66 .789 r
.34989 .60012 m .34777 .6042 L .34631 .6005 L F
.028 .223 .728 r
.34777 .6042 m .34863 .60264 L .34631 .6005 L F
0 0 0 r
.34777 .6042 m .34832 .60498 L .34863 .60264 L F
.34777 .6042 m .34703 .60674 L .34832 .60498 L F
.973 .677 .393 r
.39485 .5548 m .39658 .55823 L .39648 .55595 L F
.521 .523 .798 r
.27667 .63599 m .2782 .6397 L .2804 .63818 L F
0 0 .244 r
.2782 .6397 m .27903 .64137 L .2804 .63818 L F
.2782 .6397 m .27797 .64257 L .27903 .64137 L F
.959 .694 .489 r
.60489 .4121 m .60708 .41389 L .60681 .41669 L F
.006 0 .347 r
.29674 .53969 m .29655 .54222 L .29823 .53884 L F
.966 .646 .272 r
.40657 .5457 m .40485 .54167 L .4065 .54314 L F
.433 .779 .997 r
.28873 .51853 m .28705 .51729 L .2844 .51773 L F
.646 .874 .983 r
.28937 .51604 m .28873 .51853 L .29124 .51754 L F
.28937 .51604 m .28705 .51729 L .28873 .51853 L F
.605 .953 .837 r
.72905 .32052 m .72962 .31989 L .72566 .32228 L F
.538 .839 .517 r
.73119 .31821 m .72962 .31989 L .72905 .32052 L F
.002 0 .024 r
.31826 .61296 m .32106 .60991 L .31906 .6108 L F
.179 .385 .828 r
.40116 .47329 m .40028 .47516 L .39834 .47149 L F
.731 .991 .833 r
.40116 .47329 m .39876 .4754 L .40028 .47516 L F
.699 .246 .172 r
.42282 .59716 m .42706 .59776 L .42549 .59972 L F
.524 .045 .06 r
.42549 .59972 m .42706 .59776 L .42891 .59888 L F
.977 .707 .448 r
.39028 .49154 m .38979 .49362 L .38806 .49142 L F
.982 .863 .643 r
.38886 .48933 m .39028 .49154 L .38806 .49142 L F
.568 .248 .386 r
.39202 .49314 m .38979 .49362 L .39028 .49154 L F
.656 .216 0 r
.40475 .53643 m .40368 .5351 L .40228 .53281 L F
.859 .657 .122 r
.40475 .53643 m .40431 .53749 L .40368 .5351 L F
.40475 .53643 m .40485 .5392 L .40431 .53749 L F
.88 .992 .792 r
.55781 .40329 m .55767 .40207 L .55978 .40117 L F
0 0 0 r
.35711 .64855 m .36039 .64625 L .35852 .64791 L F
.598 .951 .854 r
.36135 .64489 m .36039 .64625 L .36223 .64502 L F
.61 .89 .581 r
.35852 .64791 m .36039 .64625 L .36135 .64489 L F
.672 .639 .808 r
.56771 .41122 m .5695 .4148 L .56439 .41341 L F
.831 .751 .775 r
.5695 .4148 m .5647 .41606 L .56439 .41341 L F
.477 .241 .477 r
.50722 .48798 m .50706 .49043 L .5045 .49101 L F
.44 .223 .486 r
.50992 .48474 m .50983 .48723 L .50722 .48798 L F
.482 .269 .513 r
.50983 .48723 m .50706 .49043 L .50722 .48798 L F
.735 .21 0 r
.36877 .51287 m .37014 .5148 L .3719 .51508 L F
.535 0 0 r
.37014 .5148 m .37314 .51615 L .3719 .51508 L F
.532 .285 .486 r
.34696 .54187 m .34384 .54532 L .34443 .54207 L F
.692 .627 .779 r
.35329 .68915 m .35258 .69055 L .35548 .68778 L F
.785 .81 .873 r
.35548 .68778 m .35258 .69055 L .35145 .68789 L F
.78 .62 .682 r
.38857 .67136 m .38804 .67414 L .38601 .67439 L F
.38857 .67136 m .38804 .67414 L .38601 .67439 L F
.084 0 .352 r
.38852 .67135 m .38731 .66989 L .38839 .67208 L F
.603 .032 0 r
.38731 .66989 m .38862 .66987 L .38653 .66896 L F
.847 .998 .804 r
.38937 .66678 m .38862 .66987 L .38731 .66989 L F
.89 .465 .133 r
.38857 .67136 m .38862 .66987 L .38731 .66989 L F
.084 0 .352 r
.38937 .66678 m .38731 .66989 L .38852 .67135 L F
.603 .032 0 r
.38731 .66989 m .38653 .66896 L .38432 .66799 L F
.876 .906 .847 r
.37135 .70332 m .37299 .70421 L .37562 .70104 L F
.288 .788 .833 r
.34198 .54813 m .33806 .54906 L .33925 .54901 L F
.848 .885 .865 r
.46359 .44566 m .46237 .44996 L .46061 .44846 L F
.46359 .44566 m .46403 .44817 L .46237 .44996 L F
.604 .577 .797 r
.33268 .56831 m .33576 .57169 L .33613 .57106 L F
.33268 .56831 m .33667 .57149 L .33484 .57011 L F
.86 .84 .824 r
.33484 .57011 m .33726 .56913 L .33743 .56754 L F
.33726 .56913 m .33957 .5682 L .33808 .56774 L F
.33726 .56913 m .33808 .56774 L .33743 .56754 L F
.604 .577 .797 r
.33268 .56831 m .33401 .57208 L .33576 .57169 L F
.33613 .57106 m .33576 .57169 L .33667 .57149 L F
.451 .271 .545 r
.33428 .5749 m .33667 .57149 L .33401 .57208 L F
.532 .907 .954 r
.63909 .33684 m .63465 .33744 L .63799 .33617 L F
.649 .909 .595 r
.64164 .33394 m .63909 .33684 L .64056 .33474 L F
.662 .941 .963 r
.63909 .33684 m .63799 .33617 L .64056 .33474 L F
.723 .635 .759 r
.41342 .47719 m .41558 .48071 L .41748 .4781 L F
0 0 0 r
.41558 .48071 m .41645 .48015 L .41748 .4781 L F
.588 .017 0 r
.24948 .6211 m .2504 .62205 L .24847 .62125 L F
.834 1 .807 r
.27778 .62289 m .27372 .6262 L .2768 .62314 L F
.814 .988 .724 r
.27778 .62289 m .27826 .62118 L .28111 .62143 L F
.27778 .62289 m .2768 .62314 L .27826 .62118 L F
.811 .565 .568 r
.3578 .54269 m .35344 .54214 L .3535 .53943 L F
.833 .639 .64 r
.3578 .54269 m .35348 .54431 L .35344 .54214 L F
.3578 .54269 m .35732 .54701 L .35348 .54431 L F
.325 .13 .454 r
.36041 .54186 m .35732 .54701 L .3578 .54269 L F
.444 .548 .868 r
.44045 .49131 m .44295 .49129 L .44214 .48997 L F
.44295 .49129 m .44411 .49127 L .44323 .4907 L F
.44295 .49129 m .44323 .4907 L .44214 .48997 L F
.44045 .49131 m .44227 .49363 L .44411 .49127 L F
0 0 .277 r
.44227 .49363 m .44323 .4907 L .44411 .49127 L F
.44323 .4907 m .44351 .48987 L .44411 .49127 L F
.444 .548 .868 r
.44214 .48997 m .44411 .49127 L .44232 .48983 L F
.904 .748 .677 r
.44232 .48983 m .44328 .4906 L .44351 .48987 L F
.44328 .4906 m .44411 .49127 L .44351 .48987 L F
0 0 .277 r
.44281 .49212 m .44464 .49179 L .44358 .48999 L F
.44227 .49363 m .44237 .49355 L .44281 .49212 L F
.44237 .49355 m .44464 .49179 L .44281 .49212 L F
.44323 .4907 m .44358 .48999 L .44351 .48987 L F
.44227 .49363 m .44358 .48999 L .44323 .4907 L F
.408 0 0 r
.34229 .5972 m .34541 .59806 L .34644 .59775 L F
.413 .237 .53 r
.34841 .59993 m .34631 .6005 L .34644 .59775 L F
.34841 .59993 m .34644 .59775 L .34541 .59806 L F
.931 .562 .285 r
.38713 .53567 m .38834 .53947 L .39 .53998 L F
.961 .653 .397 r
.38834 .53947 m .39006 .54233 L .39 .53998 L F
.132 .185 .652 r
.36457 .54454 m .36483 .54893 L .36621 .54646 L F
.674 .538 .691 r
.36621 .54646 m .36533 .54592 L .36457 .54454 L F
.189 .029 .42 r
.36224 .5458 m .36457 .54454 L .36376 .54307 L F
.198 .313 .756 r
.36224 .5458 m .36483 .54893 L .36457 .54454 L F
.674 .538 .691 r
.36533 .54592 m .36229 .54407 L .36457 .54454 L F
.189 .029 .42 r
.36376 .54307 m .36457 .54454 L .36407 .54252 L F
.891 .591 .473 r
.55718 .4421 m .55928 .4425 L .55734 .43964 L F
.858 .479 .329 r
.55928 .4425 m .55718 .4421 L .55734 .43964 L F
.157 .187 .641 r
.55928 .4425 m .56103 .44511 L .561 .44454 L F
.392 .018 .205 r
.29695 .57159 m .29531 .57517 L .29287 .57486 L F
.347 0 .179 r
.29957 .57099 m .29531 .57517 L .29695 .57159 L F
0 .1 .622 r
.37207 .55641 m .37087 .55632 L .37306 .55547 L F
.703 .326 .331 r
.45256 .5267 m .45463 .52874 L .45531 .52679 L F
.525 .563 .836 r
.45463 .52874 m .45484 .52463 L .45531 .52679 L F
.742 .79 .891 r
.49245 .43386 m .48854 .43363 L .49073 .43216 L F
.725 .634 .757 r
.48907 .50028 m .49054 .50406 L .4863 .50365 L F
.725 .45 .51 r
.4863 .50365 m .49054 .50406 L .49043 .50677 L F
.675 .609 .774 r
.493 .50094 m .49054 .50406 L .48907 .50028 L F
.636 .552 .743 r
.493 .50094 m .49355 .50319 L .49054 .50406 L F
.555 .32 .514 r
.49054 .50406 m .49311 .50619 L .49043 .50677 L F
.49054 .50406 m .49355 .50319 L .49311 .50619 L F
0 .472 .855 r
.25054 .52642 m .25062 .52575 L .24871 .52535 L F
.645 .6 .789 r
.25054 .52642 m .25355 .52755 L .25478 .52639 L F
.598 .265 .377 r
.25478 .52639 m .25329 .52742 L .25054 .52642 L F
0 .472 .855 r
.25054 .52642 m .25329 .52742 L .25062 .52575 L F
.728 .716 .839 r
.71789 .31407 m .71564 .31525 L .71404 .31309 L F
.375 .605 .938 r
.34068 .63272 m .34415 .63479 L .34236 .6357 L F
.324 0 .117 r
.34415 .63479 m .34605 .6354 L .34236 .6357 L F
.776 .506 .527 r
.34191 .57801 m .34011 .581 L .3381 .58077 L F
.403 .185 .465 r
.34439 .57491 m .34414 .57769 L .34191 .57801 L F
.584 .274 .409 r
.34419 .58055 m .34191 .57801 L .34414 .57769 L F
.34419 .58055 m .34011 .581 L .34191 .57801 L F
0 0 0 r
.45028 .5293 m .45102 .52861 L .45256 .5267 L F
.703 .326 .331 r
.45256 .5267 m .45102 .52861 L .45463 .52874 L F
.406 .441 .785 r
.46492 .54332 m .46718 .54148 L .46411 .54003 L F
0 0 .435 r
.46568 .54601 m .46718 .54148 L .46492 .54332 L F
.423 .036 .198 r
.55085 .47169 m .55242 .47376 L .54973 .47412 L F
.55085 .47169 m .5535 .47133 L .55242 .47376 L F
.43 .334 .645 r
.47807 .52592 m .47853 .5295 L .47606 .53027 L F
.418 .301 .612 r
.47606 .53027 m .47867 .5321 L .47651 .53286 L F
.47606 .53027 m .47853 .5295 L .47867 .5321 L F
.396 .478 .827 r
.28483 .65482 m .28826 .65995 L .28769 .65544 L F
.27 .337 .748 r
.28769 .65544 m .28826 .65995 L .28973 .65611 L F
.806 .509 .487 r
.55718 .4421 m .55734 .43964 L .55307 .43894 L F
.34 .117 .423 r
.55955 .43832 m .55734 .43964 L .55718 .4421 L F
.042 0 0 r
.31265 .53531 m .31491 .53501 L .31562 .53487 L F
.268 .133 .505 r
.31075 .62033 m .31282 .62169 L .31256 .61959 L F
.31075 .62033 m .31075 .62293 L .31282 .62169 L F
.691 .684 .838 r
.56771 .41122 m .56439 .41341 L .56371 .41016 L F
.911 .96 .806 r
.38163 .61515 m .38181 .6177 L .38027 .61938 L F
.333 0 0 r
.55306 .4364 m .55127 .43796 L .55167 .4351 L F
.983 .696 .356 r
.55307 .43894 m .55306 .4364 L .55246 .43727 L F
.909 .725 .641 r
.55127 .43796 m .55307 .43894 L .55246 .43727 L F
.333 0 0 r
.55306 .4364 m .55209 .4378 L .55127 .43796 L F
.909 .725 .641 r
.55127 .43796 m .55246 .43727 L .55167 .4351 L F
.333 0 0 r
.55246 .43727 m .55482 .43724 L .55209 .4378 L F
.55306 .4364 m .55355 .43663 L .55246 .43727 L F
.55355 .43663 m .55482 .43724 L .55246 .43727 L F
.983 .696 .356 r
.55246 .43727 m .55306 .4364 L .55167 .4351 L F
.738 .838 .389 r
.22922 .53952 m .22759 .54316 L .228 .54218 L F
.49 .169 .35 r
.30192 .64757 m .29923 .64661 L .29601 .6486 L F
.498 .077 .173 r
.30065 .64773 m .29923 .64661 L .30192 .64757 L F
.353 .124 .42 r
.30197 .64539 m .29923 .64661 L .30065 .64773 L F
.49 .169 .35 r
.3014 .64764 m .3 .6479 L .30065 .64773 L F
.30192 .64757 m .3014 .64766 L .3014 .64764 L F
.3014 .64766 m .3 .6479 L .3014 .64764 L F
0 0 .53 r
.30025 .64167 m .30197 .64539 L .302 .64414 L F
.785 .774 .267 r
.302 .64414 m .30197 .64539 L .30139 .64753 L F
0 .372 .745 r
.30079 .64805 m .30049 .64868 L .30192 .64757 L F
.498 .077 .173 r
.30122 .64818 m .30084 .64788 L .30192 .64757 L F
.30084 .64788 m .30065 .64773 L .30192 .64757 L F
0 .372 .745 r
.2948 .65061 m .30192 .64757 L .29494 .6496 L F
.353 .124 .42 r
.30139 .64753 m .30099 .64764 L .30122 .64818 L F
.597 .056 0 r
.29514 .64819 m .29601 .6486 L .29287 .64596 L F
.49 .169 .35 r
.30065 .64773 m .29601 .6486 L .29555 .64838 L F
.3 .6479 m .29601 .6486 L .30065 .64773 L F
0 .372 .745 r
.29494 .6496 m .30084 .64788 L .29514 .64819 L F
.30084 .64788 m .30192 .64757 L .30092 .64766 L F
.353 .124 .42 r
.30092 .64766 m .30065 .64773 L .30084 .64788 L F
.30197 .64539 m .30065 .64773 L .30139 .64753 L F
.49 .169 .35 r
.30192 .64757 m .29555 .64838 L .29514 .64819 L F
0 .372 .745 r
.30084 .64788 m .30092 .64766 L .29514 .64819 L F
.353 .124 .42 r
.30099 .64764 m .30092 .64766 L .30086 .6479 L F
.30092 .64766 m .30084 .64788 L .30086 .6479 L F
.30099 .64764 m .30086 .6479 L .30122 .64818 L F
0 .372 .745 r
.2948 .65061 m .29681 .65153 L .30049 .64868 L F
.2948 .65061 m .30049 .64868 L .30079 .64805 L F
.785 .774 .267 r
.30138 .64736 m .30139 .64753 L .30122 .64818 L F
.302 .64414 m .30139 .64753 L .30138 .64736 L F
.644 .085 0 r
.29027 .64977 m .29021 .6512 L .2892 .64942 L F
.29027 .64977 m .2926 .6518 L .29021 .6512 L F
.136 .535 .92 r
.2697 .51534 m .26825 .51552 L .26809 .51525 L F
0 .337 .818 r
.27127 .63399 m .27071 .63512 L .27248 .63585 L F
.56 .523 .771 r
.37706 .59042 m .37554 .59409 L .37492 .59146 L F
.921 .623 .143 r
.39594 .56085 m .39636 .5637 L .39742 .56471 L F
.993 .742 .416 r
.39636 .5637 m .3976 .56719 L .39742 .56471 L F
.253 0 0 r
.43586 .5582 m .43433 .55884 L .43177 .55891 L F
0 .276 .68 r
.43586 .5582 m .43673 .55854 L .43433 .55884 L F
.43586 .5582 m .43827 .55953 L .43673 .55854 L F
.985 .706 .372 r
.41576 .50364 m .41582 .50507 L .41646 .50441 L F
.41497 .50277 m .41549 .50417 L .41576 .50364 L F
.41549 .50417 m .41582 .50507 L .41576 .50364 L F
.827 .417 .268 r
.41232 .50445 m .41267 .50727 L .41462 .50589 L F
.985 .706 .372 r
.41582 .50507 m .41644 .50551 L .41646 .50441 L F
.18 .017 .409 r
.41646 .50441 m .41741 .50664 L .419 .50341 L F
.41646 .50441 m .41641 .50669 L .41741 .50664 L F
.985 .706 .372 r
.41582 .50507 m .41641 .50669 L .41644 .50551 L F
.102 .263 .743 r
.417 .50609 m .41641 .50669 L .41582 .50507 L F
.41591 .50471 m .41582 .50507 L .41552 .50425 L F
.417 .50609 m .41582 .50507 L .41591 .50471 L F
.74 .926 .953 r
.41401 .50368 m .41391 .50372 L .41594 .5046 L F
.41594 .50459 m .41594 .5046 L .41624 .50473 L F
.827 .417 .268 r
.41591 .50471 m .41604 .50487 L .41624 .50473 L F
.543 0 0 r
.41594 .50459 m .41627 .50486 L .41624 .50473 L F
0 0 0 r
.41624 .50473 m .41604 .50487 L .41627 .50486 L F
.102 .263 .743 r
.417 .50609 m .41549 .50417 L .41497 .50277 L F
0 0 0 r
.41627 .50486 m .41267 .50727 L .41644 .50548 L F
.41604 .50487 m .41267 .50727 L .41627 .50486 L F
.827 .417 .268 r
.41524 .50466 m .41462 .50589 L .41604 .50487 L F
.41524 .50466 m .41604 .50487 L .41591 .50471 L F
.74 .926 .953 r
.41391 .50372 m .41524 .50466 L .41624 .50473 L F
.543 0 0 r
.41401 .50368 m .41644 .50548 L .41627 .50486 L F
.74 .926 .953 r
.41401 .50368 m .41594 .5046 L .41594 .50459 L F
.543 0 0 r
.41401 .50368 m .41627 .50486 L .41594 .50459 L F
.102 .263 .743 r
.41561 .50433 m .41552 .50425 L .41549 .50417 L F
.41591 .50471 m .41552 .50425 L .41561 .50433 L F
.969 .723 .509 r
.41592 .50072 m .41769 .50277 L .41497 .50277 L F
.41592 .50072 m .41592 .50075 L .41769 .50277 L F
.102 .263 .743 r
.41758 .50525 m .417 .50609 L .41624 .50486 L F
.41768 .50528 m .41761 .50536 L .41758 .50525 L F
.41761 .50536 m .417 .50609 L .41758 .50525 L F
.4172 .50479 m .41624 .50486 L .41497 .50277 L F
.41777 .50531 m .41624 .50486 L .4172 .50479 L F
.41777 .50531 m .41497 .50277 L .41769 .50277 L F
.969 .723 .509 r
.41592 .50075 m .41644 .50548 L .41716 .50393 L F
.973 .719 .299 r
.41577 .50228 m .41644 .50548 L .41592 .50072 L F
.989 .769 .514 r
.4167 .50252 m .41644 .50548 L .41577 .50228 L F
.969 .723 .509 r
.41592 .50075 m .41716 .50393 L .41769 .50277 L F
.989 .769 .514 r
.41769 .50277 m .41716 .50393 L .4167 .50252 L F
.41716 .50393 m .41644 .50548 L .4167 .50252 L F
.102 .263 .743 r
.41777 .50531 m .41772 .50537 L .41768 .50528 L F
.41772 .50537 m .417 .50609 L .41768 .50528 L F
.827 .417 .268 r
.41232 .50445 m .41462 .50589 L .41524 .50466 L F
.74 .926 .953 r
.41391 .50372 m .41232 .50445 L .41524 .50466 L F
.125 .285 .757 r
.30935 .65472 m .30833 .65631 L .30678 .65261 L F
.304 .531 .907 r
.30935 .65472 m .31187 .65821 L .30833 .65631 L F
0 0 .366 r
.32106 .60991 m .32306 .60553 L .32168 .60744 L F
.254 0 0 r
.34517 .49685 m .34052 .49588 L .34349 .49684 L F
.581 .023 0 r
.34349 .49684 m .34748 .49776 L .34517 .49685 L F
.36 .251 .592 r
.32938 .58121 m .3318 .58367 L .33143 .58075 L F
.32938 .58121 m .32975 .58459 L .3318 .58367 L F
.032 .603 .749 r
.25643 .51674 m .26026 .51683 L .25809 .51679 L F
.72 .463 .537 r
.336 .64622 m .33273 .64868 L .33307 .64611 L F
.336 .64622 m .33617 .64884 L .33273 .64868 L F
.766 .596 .667 r
.33977 .64648 m .33617 .64884 L .336 .64622 L F
0 .158 .688 r
.3263 .64251 m .32856 .64516 L .32694 .64129 L F
.696 .898 .969 r
.38324 .69398 m .38718 .69365 L .38532 .69014 L F
.524 .605 .877 r
.38532 .69014 m .38718 .69365 L .38794 .69292 L F
.998 .851 .547 r
.37167 .68719 m .37276 .68804 L .37099 .6899 L F
.956 .938 .616 r
.36405 .61634 m .36247 .62014 L .36183 .61851 L F
.995 .784 .506 r
.36661 .6137 m .36648 .61613 L .36405 .61634 L F
.455 .591 .899 r
.36236 .61403 m .36405 .61634 L .36648 .61613 L F
.242 0 0 r
.36648 .61613 m .36405 .61634 L .36183 .61851 L F
.659 .487 .641 r
.23981 .61721 m .24244 .61756 L .24218 .61374 L F
.731 .332 .294 r
.24218 .61374 m .24079 .61591 L .23801 .61324 L F
.58 .909 .977 r
.24274 .61222 m .24218 .61374 L .24449 .61244 L F
.24274 .61222 m .2412 .61305 L .24218 .61374 L F
.681 .504 .64 r
.24218 .61374 m .24244 .61756 L .2459 .61603 L F
0 0 0 r
.24264 .61495 m .24079 .61591 L .24218 .61374 L F
.24264 .61495 m .24218 .61374 L .2412 .61305 L F
.247 .261 .678 r
.44274 .55129 m .43993 .54879 L .44207 .54843 L F
.44274 .55129 m .44131 .55527 L .43993 .54879 L F
.335 .091 .389 r
.71913 .30409 m .71652 .30732 L .7194 .30588 L F
.71913 .30409 m .71652 .30732 L .7194 .30588 L F
.73 .63 .747 r
.71506 .30718 m .71652 .30732 L .7194 .30588 L F
.646 .6 .788 r
.71349 .30889 m .71678 .31001 L .71302 .30941 L F
.715 .30725 m .71555 .30799 L .71349 .30889 L F
.71555 .30799 m .71678 .31001 L .71349 .30889 L F
.71506 .30718 m .71302 .30941 L .71262 .30672 L F
.73 .63 .747 r
.71506 .30718 m .71678 .31001 L .72002 .30878 L F
.691 .186 .037 r
.71142 .30675 m .71429 .30929 L .71612 .30774 L F
.71589 .30764 m .71612 .30774 L .71617 .3077 L F
.646 .6 .788 r
.71514 .30732 m .71555 .30799 L .715 .30725 L F
.691 .186 .037 r
.71142 .30675 m .71612 .30774 L .71589 .30764 L F
.646 .6 .788 r
.71506 .30718 m .71514 .30732 L .715 .30725 L F
0 0 0 r
.71429 .30929 m .71629 .30815 L .71617 .30772 L F
.71612 .30774 m .71617 .30772 L .71617 .3077 L F
.71429 .30929 m .71617 .30772 L .71612 .30774 L F
.73 .63 .747 r
.71639 .30731 m .72002 .30878 L .71652 .30732 L F
.71636 .3076 m .72002 .30878 L .71639 .30731 L F
.521 .458 .726 r
.7194 .30588 m .72002 .30878 L .71652 .30732 L F
0 0 0 r
.71629 .30815 m .71828 .30701 L .71635 .30764 L F
.71629 .30815 m .71635 .30764 L .71617 .3077 L F
.73 .63 .747 r
.71506 .30718 m .71636 .3076 L .71639 .30731 L F
.429 .863 .761 r
.64545 .34364 m .64709 .34321 L .64958 .34192 L F
.64545 .34364 m .64958 .34192 L .64801 .34258 L F
.407 .594 .921 r
.64699 .34187 m .64545 .34364 L .64801 .34258 L F
0 0 0 r
.64699 .34187 m .64668 .34236 L .64545 .34364 L F
.64462 .3445 m .64709 .34321 L .64545 .34364 L F
.64668 .34236 m .64482 .34533 L .64545 .34364 L F
.64342 .34513 m .64462 .3445 L .64545 .34364 L F
.512 .622 .897 r
.34614 .69423 m .34792 .69733 L .35037 .69701 L F
.542 0 0 r
.37246 .49933 m .371 .49775 L .37129 .50033 L F
.561 .24 .381 r
.7194 .30588 m .72199 .3058 L .71913 .30409 L F
.71913 .30409 m .72199 .3058 L .7194 .30588 L F
.589 .804 .982 r
.711 .28405 m .7149 .28473 L .71377 .28319 L F
.711 .28405 m .7149 .28473 L .71377 .28319 L F
.988 .779 .386 r
.72228 .32411 m .72338 .32421 L .72335 .32345 L F
0 0 0 r
.72335 .32345 m .72526 .32339 L .72228 .32411 L F
.095 0 0 r
.72526 .32339 m .72149 .32404 L .72228 .32411 L F
.72149 .32404 m .72118 .32409 L .72228 .32411 L F
.988 .779 .386 r
.72228 .32411 m .72341 .32539 L .72338 .32421 L F
0 0 0 r
.72335 .32345 m .72566 .32228 L .72526 .32339 L F
.318 .315 .698 r
.42814 .52879 m .42921 .53178 L .42786 .53134 L F
.21 .318 .757 r
.4625 .55906 m .4648 .56098 L .46347 .55683 L F
.577 .319 .489 r
.46214 .56149 m .4648 .56098 L .4625 .55906 L F
.46214 .56149 m .4648 .56098 L .4625 .55906 L F
0 0 .186 r
.23531 .58143 m .23614 .57743 L .23357 .57778 L F
.23531 .58143 m .23608 .57994 L .23614 .57743 L F
.005 .198 .711 r
.23531 .58143 m .23753 .58364 L .23608 .57994 L F
.548 .32 .521 r
.51264 .48424 m .50983 .48723 L .50992 .48474 L F
0 0 0 r
.66313 .38711 m .66479 .38571 L .66303 .38721 L F
.66313 .38711 m .66595 .38455 L .66479 .38571 L F
.344 .803 .937 r
.45305 .51908 m .44872 .51932 L .44981 .51693 L F
.656 .158 .055 r
.35573 .59449 m .35307 .59583 L .35193 .59389 L F
.988 .858 .62 r
.35452 .59671 m .35307 .59583 L .35573 .59449 L F
.819 .995 .76 r
.35608 .59264 m .35307 .59583 L .35573 .59449 L F
.595 .364 .536 r
.35608 .59264 m .35307 .59583 L .35573 .59449 L F
0 0 .28 r
.35291 .60044 m .35305 .59623 L .35452 .59671 L F
.35305 .59623 m .35307 .59583 L .35324 .59593 L F
.35305 .59623 m .35324 .59593 L .35452 .59671 L F
0 0 0 r
.34863 .60264 m .35291 .60044 L .34841 .59993 L F
.34863 .60264 m .35097 .60206 L .35291 .60044 L F
0 0 .28 r
.35291 .60044 m .35343 .59883 L .35307 .59583 L F
.634 .454 .623 r
.35097 .60206 m .35343 .59883 L .35132 .59906 L F
.3509 .59974 m .35132 .59906 L .35088 .59911 L F
.35097 .60206 m .35132 .59906 L .3509 .59974 L F
.773 .98 .718 r
.35391 .59414 m .35307 .59583 L .35608 .59264 L F
.595 .364 .536 r
.35608 .59264 m .35513 .59727 L .35362 .59622 L F
.35368 .59518 m .35362 .59622 L .35307 .59583 L F
.35608 .59264 m .35362 .59622 L .35368 .59518 L F
.601 .419 .607 r
.35307 .59583 m .35617 .59844 L .35513 .59727 L F
.35307 .59583 m .35343 .59883 L .35617 .59844 L F
0 0 .025 r
.35391 .59414 m .35359 .5982 L .35347 .59866 L F
.35351 .59804 m .35347 .59866 L .35343 .59883 L F
.35391 .59414 m .35347 .59866 L .35351 .59804 L F
.35391 .59414 m .35364 .5968 L .35307 .59583 L F
.35364 .5968 m .35343 .59883 L .35307 .59583 L F
.656 .158 .055 r
.35193 .59389 m .35307 .59583 L .35162 .59384 L F
.449 .574 .888 r
.22122 .59373 m .22122 .58991 L .21912 .59024 L F
.22122 .59373 m .22326 .59343 L .22122 .58991 L F
0 .213 .656 r
.36255 .5083 m .36319 .50892 L .36178 .50784 L F
.36255 .5083 m .36411 .50949 L .36319 .50892 L F
0 0 0 r
.55861 .46991 m .56009 .46861 L .56249 .46747 L F
.09 0 .299 r
.38532 .69014 m .38377 .69138 L .38324 .69398 L F
0 0 0 r
.23268 .59891 m .23142 .59977 L .23541 .59774 L F
0 0 .175 r
.23524 .59673 m .23557 .59768 L .23541 .59774 L F
.981 .714 .446 r
.23569 .59833 m .23616 .59926 L .23557 .59768 L F
.278 .446 .848 r
.23545 .59785 m .23616 .59926 L .23268 .59891 L F
.981 .714 .446 r
.23582 .59906 m .23616 .59926 L .23569 .59833 L F
.278 .446 .848 r
.23561 .59779 m .23616 .59926 L .23545 .59785 L F
0 0 .175 r
.23557 .59768 m .23561 .59779 L .23559 .59778 L F
.23557 .59768 m .23559 .59778 L .23541 .59774 L F
0 0 0 r
.23541 .59774 m .23559 .59778 L .23268 .59891 L F
.23559 .59778 m .23554 .59781 L .23268 .59891 L F
.23554 .59781 m .23545 .59785 L .23535 .59789 L F
.23554 .59781 m .23535 .59789 L .23268 .59891 L F
.756 .678 .775 r
.23616 .59926 m .23312 .60209 L .23193 .59933 L F
0 0 0 r
.23268 .59891 m .2315 .59999 L .23142 .59977 L F
.837 .994 .749 r
.23268 .59891 m .23149 .59833 L .2315 .59999 L F
.756 .678 .775 r
.2334 .59871 m .23193 .59933 L .23149 .59833 L F
0 .554 .804 r
.23268 .59891 m .23616 .59926 L .23149 .59833 L F
.756 .678 .775 r
.23616 .59926 m .23193 .59933 L .2334 .59871 L F
.981 .714 .446 r
.23582 .59906 m .23557 .59768 L .23466 .59521 L F
0 0 0 r
.23559 .59778 m .23561 .59779 L .23545 .59785 L F
.981 .714 .446 r
.23418 .59808 m .23452 .59828 L .23466 .59521 L F
.23452 .59828 m .23582 .59906 L .23545 .59785 L F
.23452 .59828 m .23545 .59785 L .23466 .59521 L F
.668 .345 0 r
.23466 .59521 m .23557 .59768 L .23561 .59779 L F
.23557 .59768 m .23616 .59926 L .23561 .59779 L F
0 0 .175 r
.23478 .594 m .23497 .59485 L .23494 .59496 L F
.23494 .59496 m .23561 .59779 L .23524 .59673 L F
.23497 .59485 m .23561 .59779 L .23494 .59496 L F
.812 .468 0 r
.23466 .59521 m .23561 .59779 L .23498 .59491 L F
.23466 .59521 m .23498 .59491 L .23478 .594 L F
0 0 .047 r
.23667 .59176 m .23466 .59521 L .23526 .59283 L F
.869 .751 .241 r
.23477 .59475 m .23466 .59521 L .23534 .59386 L F
.23422 .5956 m .23466 .59521 L .23477 .59475 L F
.23393 .59606 m .23466 .59521 L .23422 .5956 L F
.647 .82 .395 r
.23667 .59176 m .23534 .59386 L .23509 .59436 L F
.23504 .59454 m .23509 .59436 L .23466 .59521 L F
.23667 .59176 m .23509 .59436 L .23504 .59454 L F
.168 .682 .893 r
.37994 .53638 m .37821 .53589 L .37583 .53587 L F
.37994 .53638 m .37821 .53589 L .37583 .53587 L F
.637 .905 .984 r
.66061 .37733 m .65816 .37861 L .65665 .37778 L F
.498 .269 .498 r
.36781 .62296 m .36821 .62029 L .36743 .61821 L F
.36781 .62296 m .37035 .62257 L .36821 .62029 L F
.36821 .62029 m .37035 .62257 L .36781 .62296 L F
0 0 .458 r
.22578 .57667 m .22693 .58048 L .22572 .57794 L F
.537 .464 .721 r
.33644 .69051 m .33886 .68986 L .3383 .68741 L F
.253 .428 .842 r
.55849 .44901 m .55668 .44882 L .55758 .44766 L F
0 0 0 r
.62846 .36295 m .62513 .36513 L .62811 .36486 L F
.426 .613 .927 r
.62811 .36486 m .62513 .36513 L .62592 .36401 L F
.62592 .36401 m .62513 .36513 L .62811 .36486 L F
.786 .929 .928 r
.62548 .36811 m .62811 .36486 L .62513 .36513 L F
.759 .995 .817 r
.37678 .63188 m .37863 .62909 L .37548 .63188 L F
.37678 .63188 m .37933 .62944 L .37863 .62909 L F
.423 .419 .751 r
.3575 .55867 m .35485 .55358 L .35613 .55501 L F
.106 .104 .571 r
.359 .68864 m .35548 .68778 L .35896 .68545 L F
.044 .087 .582 r
.36032 .68626 m .35897 .68651 L .35896 .68545 L F
.78 .964 .923 r
.35434 .68684 m .35896 .68545 L .35548 .68778 L F
.394 0 0 r
.36032 .68626 m .35896 .68545 L .35434 .68684 L F
.141 .681 .837 r
.35857 .68611 m .36095 .68614 L .36032 .68626 L F
.36095 .68614 m .36286 .68616 L .36032 .68626 L F
.044 .087 .582 r
.36032 .68626 m .359 .68864 L .35897 .68651 L F
.437 .593 .908 r
.36032 .68626 m .36254 .68944 L .359 .68864 L F
0 0 0 r
.33994 .68375 m .34121 .68227 L .33912 .68427 L F
.103 .008 .452 r
.21602 .57195 m .21783 .57319 L .21778 .57049 L F
.21602 .57195 m .21597 .57482 L .21783 .57319 L F
.706 .975 .761 r
.44186 .55374 m .44131 .55527 L .44274 .55129 L F
.44186 .55374 m .44125 .5552 L .44131 .55527 L F
.854 .415 0 r
.34294 .50332 m .34435 .50596 L .34139 .5021 L F
.426 .146 .383 r
.38028 .58691 m .37706 .59042 L .37766 .58774 L F
.646 .775 .942 r
.38412 .55865 m .3819 .55985 L .38003 .55784 L F
.755 .468 0 r
.28964 .63362 m .28843 .62937 L .28612 .63293 L F
.719 .282 .213 r
.29008 .63494 m .28964 .63362 L .28612 .63293 L F
.506 .159 .312 r
.29231 .63491 m .28964 .63362 L .29008 .63494 L F
.554 .854 .998 r
.42528 .57818 m .42942 .57831 L .42821 .57745 L F
0 0 0 r
.41456 .49909 m .4125 .50087 L .41524 .49769 L F
.401 .304 .629 r
.41456 .49909 m .41497 .50277 L .4125 .50087 L F
.588 .467 .682 r
.42007 .52393 m .42122 .52649 L .41814 .52668 L F
.546 .269 .447 r
.42122 .52649 m .42056 .52872 L .41814 .52668 L F
.588 .467 .682 r
.41814 .52668 m .42122 .52649 L .42007 .52393 L F
.546 .269 .447 r
.41814 .52668 m .42056 .52872 L .42122 .52649 L F
.254 0 0 r
.42528 .57818 m .42821 .57745 L .42657 .57941 L F
.783 .929 .563 r
.42719 .57822 m .42821 .57745 L .4283 .57611 L F
.42657 .57941 m .42821 .57745 L .42719 .57822 L F
.971 .664 .282 r
.42821 .57745 m .42942 .57831 L .42891 .57692 L F
.42821 .57745 m .42891 .57692 L .42808 .5746 L F
.546 .269 .447 r
.42122 .52649 m .42056 .52872 L .41814 .52668 L F
.761 .967 .929 r
.69334 .33001 m .69167 .333 L .69166 .33201 L F
.69334 .33001 m .69464 .33096 L .69167 .333 L F
.877 .443 .146 r
.69167 .333 m .69068 .33414 L .69166 .33201 L F
.69167 .333 m .69254 .33482 L .69068 .33414 L F
.876 .906 .847 r
.37135 .70332 m .37562 .70104 L .37372 .70212 L F
.72 .964 .703 r
.37634 .69949 m .37562 .70104 L .37843 .69801 L F
.719 .972 .731 r
.37372 .70212 m .37562 .70104 L .37634 .69949 L F
.458 .19 .419 r
.5045 .49101 m .50389 .49415 L .50131 .49479 L F
.495 .223 .43 r
.50719 .49276 m .5045 .49101 L .50706 .49043 L F
.50719 .49276 m .50389 .49415 L .5045 .49101 L F
.704 .557 .685 r
.48658 .50094 m .48419 .50421 L .48659 .50242 L F
.48658 .50094 m .4863 .50365 L .48419 .50421 L F
.317 .172 .52 r
.31742 .54315 m .31974 .54264 L .31924 .53902 L F
.665 .625 .8 r
.31715 .54513 m .31974 .54264 L .31742 .54315 L F
.283 0 0 r
.39038 .48652 m .39089 .48655 L .3932 .48533 L F
.39038 .48652 m .39089 .48655 L .3932 .48533 L F
.646 .676 .864 r
.39617 .47931 m .39451 .48268 L .39349 .48051 L F
.39617 .47931 m .39738 .48189 L .39451 .48268 L F
0 .035 .595 r
.31363 .63707 m .31239 .63583 L .31234 .63517 L F
0 0 0 r
.21982 .55899 m .22067 .55739 L .22167 .55506 L F
0 0 .339 r
.21982 .55899 m .22107 .56006 L .22067 .55739 L F
.21982 .55899 m .21984 .56167 L .22107 .56006 L F
.61 .913 .98 r
.23564 .53885 m .23848 .53745 L .23645 .53702 L F
.73 .946 .635 r
.23343 .54072 m .23564 .53885 L .23645 .53702 L F
.474 .254 .499 r
.38823 .6902 m .38665 .68837 L .38532 .69014 L F
.38823 .6902 m .38869 .68766 L .38665 .68837 L F
.617 .607 .819 r
.54108 .40243 m .53915 .40372 L .53833 .40116 L F
.084 0 .264 r
.54108 .40243 m .53885 .40642 L .53915 .40372 L F
.338 0 0 r
.26169 .52228 m .25757 .52345 L .25926 .52292 L F
.705 .358 .385 r
.33165 .54663 m .33113 .54842 L .33307 .54794 L F
.482 0 0 r
.33307 .54794 m .3338 .54567 L .33165 .54663 L F
.895 .607 .49 r
.44194 .56243 m .43854 .56398 L .43959 .56191 L F
.44194 .56243 m .44038 .56629 L .43854 .56398 L F
0 0 .001 r
.44314 .56308 m .44194 .56243 L .44478 .56195 L F
.44314 .56308 m .44038 .56629 L .44194 .56243 L F
.487 .858 .986 r
.44194 .56243 m .44478 .56195 L .43959 .56191 L F
.804 .643 .684 r
.42038 .50124 m .42311 .50377 L .4209 .5006 L F
.42038 .50124 m .419 .50341 L .42311 .50377 L F
.782 .544 .575 r
.41741 .50664 m .42311 .50377 L .419 .50341 L F
.41741 .50664 m .4235 .50728 L .42311 .50377 L F
.684 .734 .889 r
.4209 .5006 m .42311 .50377 L .42569 .50272 L F
.409 .274 .585 r
.42311 .50377 m .4235 .50728 L .4256 .50607 L F
.315 .778 .942 r
.71395 .32793 m .71789 .32765 L .71555 .32698 L F
.71395 .32793 m .71555 .32698 L .71358 .32858 L F
.556 .932 .824 r
.56904 .46439 m .57038 .46297 L .56846 .46463 L F
.56904 .46439 m .5722 .46254 L .57038 .46297 L F
.846 .946 .884 r
.38434 .49701 m .38553 .49322 L .38727 .49456 L F
.38434 .49701 m .38291 .49614 L .38553 .49322 L F
.907 .944 .818 r
.45609 .51704 m .45415 .52021 L .45305 .51908 L F
0 0 .5 r
.45415 .52021 m .45482 .52086 L .45305 .51908 L F
.45415 .52021 m .4563 .52244 L .45482 .52086 L F
.77 .711 .797 r
.62409 .41027 m .6274 .41105 L .62684 .40672 L F
.796 .729 .789 r
.6274 .41105 m .63065 .40723 L .62684 .40672 L F
.112 .627 .89 r
.62762 .41061 m .6274 .41105 L .62409 .41027 L F
.168 .43 .865 r
.63001 .41061 m .6274 .41105 L .62762 .41061 L F
.592 .526 .749 r
.2309 .56471 m .22837 .56562 L .22782 .56171 L F
.151 .186 .644 r
.23115 .56794 m .22837 .56562 L .2309 .56471 L F
.753 .924 .946 r
.45178 .45204 m .45366 .45068 L .45491 .45177 L F
.767 .858 .918 r
.45645 .44797 m .45491 .45177 L .45366 .45068 L F
.45645 .44797 m .458 .44946 L .45491 .45177 L F
.679 .7 .862 r
.33188 .55401 m .33432 .55863 L .33686 .55587 L F
.559 .507 .754 r
.33432 .55863 m .33687 .55801 L .33686 .55587 L F
.755 .831 .91 r
.46727 .44576 m .46403 .44817 L .46359 .44566 L F
.757 .431 .433 r
.3265 .62743 m .3283 .62331 L .32408 .62302 L F
.794 .506 .502 r
.45027 .56441 m .45276 .56201 L .44897 .5618 L F
.45027 .56441 m .45284 .56519 L .45276 .56201 L F
.596 .348 .512 r
.45507 .56441 m .45276 .56201 L .45555 .56165 L F
.45507 .56441 m .45284 .56519 L .45276 .56201 L F
.45507 .56441 m .45276 .56201 L .45555 .56165 L F
.45507 .56441 m .45284 .56519 L .45276 .56201 L F
.131 .414 .86 r
.59092 .40199 m .59027 .40349 L .58781 .40046 L F
0 0 .287 r
.59064 .40617 m .59027 .40349 L .59092 .40199 L F
.852 .571 .512 r
.35154 .54548 m .34696 .54187 L .35103 .54269 L F
.474 .288 .547 r
.3535 .53943 m .35344 .54214 L .35103 .54269 L F
.235 .353 .781 r
.35348 .54431 m .35103 .54269 L .35344 .54214 L F
.155 0 0 r
.31747 .53124 m .31979 .5308 L .3209 .52982 L F
.524 .846 .549 r
.3209 .52982 m .31979 .5308 L .32233 .52836 L F
.687 .777 .92 r
.72357 .31198 m .72443 .31421 L .72076 .31331 L F
.465 .639 .932 r
.72604 .31169 m .72443 .31421 L .72357 .31198 L F
.509 .698 .954 r
.72731 .31371 m .72443 .31421 L .72604 .31169 L F
0 0 0 r
.23158 .55215 m .23097 .55443 L .2294 .55562 L F
.23097 .55443 m .22876 .55723 L .2294 .55562 L F
.867 .838 .815 r
.36814 .60916 m .36773 .61186 L .3695 .6114 L F
.436 0 0 r
.3659 .51073 m .36754 .51171 L .36411 .50949 L F
.617 .073 0 r
.3664 .51137 m .36754 .51171 L .3659 .51073 L F
.3664 .51137 m .36877 .51287 L .36754 .51171 L F
.652 .56 .739 r
.40316 .48869 m .39965 .48682 L .40147 .48701 L F
.864 .776 .763 r
.60429 .35617 m .60798 .3603 L .60901 .35674 L F
.583 .733 .946 r
.44061 .45385 m .43964 .45688 L .43807 .45473 L F
.44061 .45385 m .4421 .45595 L .43964 .45688 L F
.301 .49 .877 r
.58526 .37361 m .58319 .3745 L .5825 .37448 L F
.58526 .37361 m .58628 .37694 L .58319 .3745 L F
.375 0 0 r
.33763 .49565 m .33704 .49465 L .33516 .4953 L F
.283 0 0 r
.34052 .49588 m .33704 .49465 L .34021 .49564 L F
.375 0 0 r
.33763 .49565 m .34021 .49564 L .33704 .49465 L F
.331 .773 .963 r
.43362 .59795 m .43604 .59766 L .43262 .59726 L F
.286 .744 .954 r
.33465 .53532 m .33884 .53586 L .3362 .5362 L F
.881 .667 .608 r
.37636 .52122 m .37971 .5202 L .37635 .51938 L F
.37636 .52122 m .37945 .52313 L .37971 .5202 L F
.56 .02 0 r
.28739 .63877 m .29039 .63896 L .28977 .63972 L F
.036 0 0 r
.28977 .63972 m .29039 .63896 L .29234 .6389 L F
.23 0 .339 r
.67779 .36431 m .67565 .36551 L .67531 .36779 L F
0 0 0 r
.67941 .35335 m .67789 .35714 L .67633 .35851 L F
0 .009 .578 r
.67789 .35714 m .67829 .35771 L .67906 .3581 L F
.67829 .35771 m .67934 .35922 L .67906 .3581 L F
0 .132 .665 r
.67934 .35922 m .68096 .35855 L .67906 .3581 L F
.232 0 0 r
.67971 .35843 m .67906 .3581 L .68096 .35855 L F
.67793 .35826 m .67906 .3581 L .67971 .35843 L F
0 .009 .578 r
.67789 .35714 m .67906 .3581 L .67633 .35851 L F
.957 .949 .69 r
.6994 .29071 m .70142 .28689 L .70049 .28593 L F
.96 .945 .68 r
.70049 .28593 m .70142 .28689 L .70304 .28266 L F
.432 .432 .758 r
.36177 .58355 m .36402 .57989 L .36183 .58085 L F
.36177 .58355 m .36478 .58306 L .36402 .57989 L F
.364 0 .198 r
.36177 .58355 m .36454 .58506 L .36478 .58306 L F
0 0 0 r
.68489 .31672 m .68383 .31803 L .68173 .31941 L F
.68627 .31668 m .68489 .31672 L .68765 .31623 L F
.68627 .31668 m .68383 .31803 L .68489 .31672 L F
.244 .009 .345 r
.33047 .6494 m .33307 .64611 L .33273 .64868 L F
.577 .621 .859 r
.3808 .66581 m .3817 .66851 L .38432 .66799 L F
0 .188 .71 r
.38254 .66706 m .3817 .66851 L .3808 .66581 L F
.517 .879 .981 r
.38254 .66706 m .3817 .66851 L .37967 .66779 L F
.293 0 .006 r
.38432 .66799 m .3817 .66851 L .38029 .67052 L F
.4 0 .116 r
.27181 .54941 m .26751 .55196 L .2675 .54862 L F
.27181 .54941 m .27052 .55161 L .26751 .55196 L F
.057 0 0 r
.27269 .55051 m .27181 .54941 L .27411 .54864 L F
.27269 .55051 m .27052 .55161 L .27181 .54941 L F
.661 .162 .051 r
.28924 .66132 m .29349 .6619 L .2913 .66287 L F
.667 .17 .057 r
.2913 .66287 m .29349 .6619 L .29566 .66377 L F
.777 .769 .845 r
.50442 .42674 m .50104 .42681 L .50234 .42557 L F
.839 .803 .816 r
.5065 .42391 m .50442 .42674 L .50234 .42557 L F
0 0 0 r
.62071 .42835 m .61851 .4324 L .62101 .42853 L F
.682 .255 0 r
.43827 .55953 m .4384 .56023 L .43673 .55854 L F
.43827 .55953 m .43959 .56191 L .4384 .56023 L F
0 0 0 r
.22922 .53952 m .23004 .53788 L .23061 .53524 L F
.877 .464 .028 r
.57769 .37805 m .57716 .37905 L .57602 .37698 L F
.57769 .37805 m .57877 .38078 L .57716 .37905 L F
.308 0 0 r
.7304 .3301 m .73121 .32994 L .73096 .33036 L F
.746 .279 0 r
.73121 .32994 m .73242 .33184 L .73096 .33036 L F
.079 0 0 r
.62143 .38643 m .61975 .38633 L .61875 .38709 L F
.62143 .38643 m .62266 .38565 L .61975 .38633 L F
.914 .889 .471 r
.70742 .33681 m .7086 .33565 L .70842 .33486 L F
.70742 .33681 m .70735 .33956 L .7086 .33565 L F
.902 .913 .514 r
.4148 .4715 m .41462 .47044 L .41568 .46767 L F
.67 .145 0 r
.31902 .62962 m .32236 .63063 L .32135 .63172 L F
.767 .272 .045 r
.32135 .63172 m .32236 .63063 L .32352 .63216 L F
.853 .967 .873 r
.72112 .32723 m .72341 .32539 L .72228 .32411 L F
.441 0 .057 r
.23614 .57743 m .23846 .57731 L .2407 .57565 L F
.283 0 0 r
.2407 .57565 m .24321 .57603 L .2427 .57456 L F
.2407 .57565 m .23846 .57731 L .24321 .57603 L F
.704 .664 .808 r
.35401 .68052 m .35475 .67601 L .35261 .67818 L F
.35401 .68052 m .35727 .67872 L .35475 .67601 L F
.313 .11 .437 r
.45685 .57359 m .45506 .57178 L .45497 .57489 L F
.45685 .57359 m .45722 .57099 L .45506 .57178 L F
.623 .333 .457 r
.28202 .5361 m .28005 .53696 L .2782 .53636 L F
.501 .725 .973 r
.24347 .62121 m .24408 .61877 L .242 .62015 L F
.24347 .62121 m .24596 .62092 L .24408 .61877 L F
.854 .582 .527 r
.62924 .40078 m .6263 .40269 L .62888 .39948 L F
.62924 .40078 m .6293 .40335 L .6263 .40269 L F
.806 .894 .906 r
.63121 .39674 m .62924 .40078 L .62888 .39948 L F
.63121 .39674 m .63245 .39829 L .62924 .40078 L F
.806 .704 .752 r
.62684 .40672 m .63065 .40723 L .6293 .40335 L F
.914 .604 .122 r
.63026 .4061 m .63065 .40723 L .62972 .40575 L F
0 .186 .68 r
.63065 .40723 m .63187 .40764 L .62972 .40575 L F
.504 0 0 r
.62906 .40532 m .62972 .40575 L .63187 .40764 L F
.62827 .40466 m .62972 .40575 L .62906 .40532 L F
.914 .604 .122 r
.6293 .40335 m .63026 .4061 L .62972 .40575 L F
0 0 0 r
.57152 .43697 m .5761 .43607 L .57309 .43659 L F
.432 .216 .483 r
.34068 .63272 m .34118 .63319 L .34347 .62953 L F
.349 .216 .555 r
.34068 .63272 m .34236 .6357 L .34118 .63319 L F
.763 .947 .938 r
.3684 .69317 m .36795 .69538 L .36635 .6947 L F
.3684 .69317 m .3699 .69402 L .36795 .69538 L F
.31 .025 .307 r
.32368 .55841 m .32307 .56123 L .3211 .56174 L F
.533 .335 .558 r
.32661 .55531 m .32642 .55844 L .32368 .55841 L F
.613 .345 .489 r
.32642 .55844 m .32307 .56123 L .32368 .55841 L F
.346 0 .088 r
.68173 .31941 m .68125 .32136 L .67844 .32189 L F
0 0 0 r
.68383 .31803 m .68125 .32136 L .68173 .31941 L F
.945 .644 .437 r
.33005 .65789 m .33292 .65941 L .33092 .66101 L F
.595 .895 .608 r
.33092 .66101 m .33292 .65941 L .33468 .65758 L F
.441 .277 .562 r
.70219 .27393 m .69922 .275 L .70169 .27129 L F
.333 .172 .507 r
.69922 .275 m .70151 .27678 L .70219 .27393 L F
.69922 .275 m .69964 .27689 L .70151 .27678 L F
.441 .277 .562 r
.70219 .27393 m .69922 .275 L .70169 .27129 L F
.333 .172 .507 r
.69922 .275 m .70151 .27678 L .70219 .27393 L F
.69922 .275 m .69964 .27689 L .70151 .27678 L F
.518 .856 .585 r
.64164 .33394 m .64237 .3331 L .64429 .33254 L F
.64164 .33394 m .64056 .33474 L .64237 .3331 L F
.847 .645 .629 r
.39572 .66516 m .39345 .6619 L .39356 .66456 L F
.922 .691 .571 r
.39523 .66821 m .39572 .66516 L .39356 .66456 L F
0 0 .201 r
.41608 .49344 m .41524 .49769 L .41928 .49791 L F
.742 .754 .862 r
.41608 .49344 m .41928 .49791 L .4206 .49425 L F
.197 .086 .494 r
.41928 .49791 m .42063 .49682 L .4206 .49425 L F
.375 .841 .848 r
.43674 .58703 m .43999 .58613 L .43714 .58559 L F
.43674 .58703 m .43837 .5863 L .43999 .58613 L F
.298 0 0 r
.43999 .58613 m .43837 .5863 L .442 .58652 L F
.43999 .58613 m .442 .58652 L .44245 .58654 L F
.375 .841 .848 r
.43714 .58559 m .43999 .58613 L .43738 .58474 L F
.944 .876 .738 r
.38106 .60756 m .37877 .61084 L .38031 .60622 L F
.976 .745 .523 r
.37653 .60618 m .37826 .60977 L .37611 .60867 L F
.37826 .60977 m .37877 .61084 L .37804 .61024 L F
.37826 .60977 m .37804 .61024 L .37611 .60867 L F
.976 .746 .524 r
.37611 .60867 m .37877 .61084 L .37742 .61154 L F
.84 .744 .758 r
.38031 .60622 m .37932 .60919 L .37653 .60618 L F
.37932 .60919 m .37877 .61084 L .37826 .60977 L F
.37932 .60919 m .37826 .60977 L .37653 .60618 L F
.939 .965 .717 r
.37743 .61153 m .37877 .61084 L .37989 .60924 L F
.37743 .61153 m .37989 .60924 L .38106 .60756 L F
.37742 .61154 m .37743 .61153 L .38106 .60756 L F
.946 .609 .351 r
.37981 .60893 m .38054 .6118 L .37742 .61154 L F
.38106 .60756 m .38097 .6083 L .37981 .60893 L F
.38097 .6083 m .38054 .6118 L .37981 .60893 L F
.37743 .61152 m .37742 .61154 L .37742 .61154 L F
.38106 .60756 m .37742 .61154 L .37743 .61152 L F
.746 .697 .804 r
.71678 .31001 m .71789 .31407 L .71404 .31309 L F
.587 .514 .74 r
.72002 .30878 m .71789 .31407 L .71678 .31001 L F
.72002 .30878 m .72076 .31331 L .71789 .31407 L F
.289 .733 .963 r
.4381 .59777 m .44047 .59886 L .44253 .59846 L F
.601 .321 .464 r
.52891 .4748 m .53116 .47688 L .52732 .47771 L F
.52891 .4748 m .53116 .47466 L .53116 .47688 L F
.741 .87 .94 r
.44711 .45282 m .44625 .45565 L .44462 .45414 L F
.44711 .45282 m .44834 .45421 L .44625 .45565 L F
.775 .926 .935 r
.29279 .52769 m .28995 .5285 L .29464 .5291 L F
.549 .215 .355 r
.52186 .47821 m .5244 .47993 L .52188 .48032 L F
.52186 .47821 m .52466 .47791 L .5244 .47993 L F
.28 .25 .645 r
.3663 .52813 m .367 .53302 L .36497 .53311 L F
.281 .315 .719 r
.367 .53302 m .36727 .53467 L .36497 .53311 L F
.994 .816 .448 r
.39769 .5833 m .39864 .58103 L .39819 .58076 L F
.455 .858 .967 r
.59589 .46306 m .5973 .46159 L .5945 .46084 L F
.59589 .46306 m .59872 .46237 L .5973 .46159 L F
.437 .453 .778 r
.3628 .53878 m .35911 .5356 L .3636 .53653 L F
0 0 0 r
.36462 .53468 m .3628 .53878 L .3636 .53653 L F
.36462 .53468 m .3628 .53878 L .3636 .53653 L F
.392 .805 .604 r
.66595 .38455 m .66894 .38263 L .66794 .38325 L F
0 0 0 r
.66479 .38571 m .66595 .38455 L .66794 .38325 L F
.59 .249 .361 r
.31295 .56472 m .31117 .56746 L .30832 .56766 L F
.477 .15 .333 r
.31468 .56503 m .31117 .56746 L .31295 .56472 L F
.594 .895 .61 r
.3576 .56148 m .35451 .56445 L .35532 .56201 L F
.74 .623 .728 r
.35451 .56445 m .3576 .56148 L .35532 .56201 L F
.443 0 0 r
.28769 .65544 m .29171 .65551 L .28887 .65538 L F
.373 0 0 r
.28973 .65611 m .29171 .65551 L .28769 .65544 L F
.495 0 0 r
.29212 .65712 m .29171 .65551 L .28973 .65611 L F
.29212 .65712 m .29456 .65629 L .29171 .65551 L F
.675 .695 .861 r
.41342 .47719 m .41748 .4781 L .41615 .47467 L F
.792 .755 .819 r
.41615 .47467 m .41748 .4781 L .4201 .47484 L F
0 0 0 r
.41645 .48015 m .42022 .47753 L .41748 .4781 L F
.669 .672 .843 r
.41748 .4781 m .42158 .47671 L .42022 .47753 L F
.798 .69 .746 r
.42022 .47753 m .41645 .48015 L .41748 .4781 L F
.806 .999 .838 r
.41432 .49203 m .41138 .49481 L .41159 .49289 L F
.698 .949 .956 r
.41159 .49289 m .41138 .49481 L .40979 .49424 L F
.404 .711 .986 r
.57471 .38757 m .57619 .38904 L .57213 .38771 L F
0 .135 .62 r
.57471 .38757 m .57714 .38975 L .57619 .38904 L F
.517 0 0 r
.57941 .39188 m .57619 .38904 L .57714 .38975 L F
.473 .816 .998 r
.38026 .59333 m .38192 .59398 L .37807 .59346 L F
.783 .733 .807 r
.38192 .59398 m .37983 .59526 L .37807 .59346 L F
.513 .522 .803 r
.38364 .59907 m .37983 .59526 L .38192 .59398 L F
.885 .839 .794 r
.38313 .59192 m .38192 .59398 L .38026 .59333 L F
.641 .51 .688 r
.38641 .59743 m .38192 .59398 L .38726 .5946 L F
.38641 .59743 m .38364 .59907 L .38192 .59398 L F
.898 .551 .073 r
.2921 .64526 m .29287 .64596 L .29126 .64229 L F
0 0 .412 r
.29332 .64724 m .2921 .64526 L .29154 .64388 L F
0 .215 .736 r
.29353 .64554 m .29332 .64724 L .29154 .64388 L F
.863 .499 .359 r
.29247 .64724 m .29332 .64724 L .29353 .64554 L F
.29145 .64887 m .29332 .64724 L .29247 .64724 L F
.638 .088 0 r
.29332 .64724 m .29514 .64819 L .29417 .64724 L F
.29332 .64724 m .29417 .64724 L .29287 .64596 L F
.766 .502 .535 r
.57997 .42269 m .57524 .41986 L .57884 .42067 L F
.878 .864 .822 r
.3526 .51685 m .34973 .51608 L .35277 .51235 L F
.926 .674 .538 r
.3526 .51685 m .35054 .51821 L .34973 .51608 L F
.3526 .51685 m .35237 .51993 L .35054 .51821 L F
.658 .505 .666 r
.71404 .31309 m .71024 .31027 L .71302 .30941 L F
.71404 .31309 m .7113 .3139 L .71024 .31027 L F
.852 .571 .512 r
.35154 .54548 m .34668 .54498 L .34696 .54187 L F
.788 .847 .895 r
.35154 .54548 m .34894 .54678 L .34668 .54498 L F
0 0 0 r
.68046 .36112 m .67779 .36431 L .68081 .36134 L F
0 0 .512 r
.67934 .35922 m .68046 .36112 L .68081 .36134 L F
0 0 .201 r
.41608 .49344 m .41604 .4963 L .41524 .49769 L F
.409 .468 .809 r
.41604 .4963 m .41456 .49909 L .41524 .49769 L F
.599 .036 0 r
.24534 .60894 m .25017 .61059 L .24699 .60849 L F
.578 .002 0 r
.24699 .60849 m .25017 .61059 L .25134 .61044 L F
0 0 0 r
.65561 .33905 m .65457 .3399 L .65217 .34094 L F
.65877 .33616 m .65761 .33727 L .65561 .33905 L F
.476 .826 .549 r
.65761 .33727 m .65457 .3399 L .65561 .33905 L F
.703 .554 .682 r
.4863 .50365 m .48397 .50679 L .48419 .50421 L F
.645 .474 .638 r
.4863 .50365 m .48744 .50724 L .48397 .50679 L F
.725 .45 .51 r
.4863 .50365 m .49043 .50677 L .48744 .50724 L F
.746 .852 .413 r
.70103 .353 m .70011 .3556 L .70185 .3519 L F
.229 0 .005 r
.56845 .41943 m .57227 .41711 L .57273 .41975 L F
.564 .43 .656 r
.57414 .41285 m .57505 .41684 L .57227 .41711 L F
.683 .562 .712 r
.57505 .41684 m .57273 .41975 L .57227 .41711 L F
.35 .441 .814 r
.3682 .70168 m .36989 .69963 L .36784 .69976 L F
.3682 .70168 m .37135 .70332 L .36989 .69963 L F
.905 .517 .269 r
.60032 .43111 m .60154 .43032 L .60024 .4293 L F
.60032 .43111 m .60205 .43229 L .60154 .43032 L F
.768 .982 .727 r
.65475 .3243 m .65627 .32363 L .65352 .32673 L F
.741 .972 .928 r
.65475 .3243 m .65352 .32673 L .65265 .32594 L F
.664 .972 .823 r
.37197 .62934 m .37288 .62936 L .3686 .63227 L F
.785 .969 .918 r
.37483 .62623 m .37288 .62936 L .37197 .62934 L F
.37483 .62623 m .37614 .62687 L .37288 .62936 L F
.403 .728 .99 r
.43177 .55891 m .43249 .55723 L .43012 .55808 L F
.43177 .55891 m .43433 .55884 L .43249 .55723 L F
.767 .929 .939 r
.2746 .63727 m .27491 .63501 L .27248 .63585 L F
.2746 .63727 m .27667 .63599 L .27491 .63501 L F
.683 .972 .779 r
.30192 .66738 m .30104 .66906 L .30319 .66693 L F
.344 .658 .971 r
.29954 .66729 m .30104 .66906 L .30192 .66738 L F
.29954 .66729 m .30104 .66906 L .30192 .66738 L F
.766 .596 .667 r
.33977 .64648 m .34044 .64913 L .33617 .64884 L F
.953 .767 .615 r
.33977 .64648 m .33927 .64234 L .34024 .64384 L F
0 0 .524 r
.34119 .64763 m .33977 .64648 L .34024 .64384 L F
.34119 .64763 m .34044 .64913 L .33977 .64648 L F
.885 .839 .794 r
.38313 .59192 m .38026 .59333 L .38112 .59304 L F
.38313 .59192 m .38112 .59304 L .38348 .59063 L F
.742 .958 .941 r
.56668 .40809 m .57044 .4073 L .56649 .40801 L F
.212 0 .304 r
.57245 .40622 m .57044 .4073 L .56994 .40962 L F
.653 .404 .531 r
.36918 .59608 m .36471 .59946 L .3645 .59709 L F
.882 .99 .802 r
.61575 .39477 m .61792 .39225 L .61607 .39263 L F
.75 .994 .847 r
.61607 .39263 m .61792 .39225 L .61979 .39046 L F
.046 0 0 r
.61635 .34708 m .61909 .34663 L .62057 .34589 L F
0 0 0 r
.62057 .34589 m .6214 .3456 L .62337 .34538 L F
.62057 .34589 m .61909 .34663 L .6214 .3456 L F
.965 .662 .4 r
.5978 .42621 m .60049 .42722 L .59709 .4248 L F
.5978 .42621 m .60024 .4293 L .60049 .42722 L F
.42 .128 .362 r
.43968 .48516 m .4417 .48577 L .44206 .48384 L F
.43968 .48516 m .43881 .48749 L .4417 .48577 L F
.905 .93 .82 r
.63466 .4104 m .63094 .41272 L .63337 .41109 L F
.57 .678 .913 r
.35348 .54431 m .35732 .54701 L .35487 .54684 L F
.779 .741 .817 r
.38193 .6847 m .37903 .68685 L .38209 .68748 L F
.945 .791 .333 r
.55653 .39112 m .55719 .39118 L .55919 .39008 L F
0 0 0 r
.35638 .70275 m .35881 .70185 L .35495 .70177 L F
.534 .261 .448 r
.51549 .48154 m .51537 .48381 L .51264 .48424 L F
.527 .241 .424 r
.51832 .4813 m .51537 .48381 L .51549 .48154 L F
0 0 .444 r
.47692 .57056 m .47758 .57352 L .4768 .57502 L F
0 0 0 r
.47758 .57352 m .47658 .57795 L .4768 .57502 L F
.61127 .34782 m .61006 .34803 L .61378 .34761 L F
.522 .384 .634 r
.4813 .51013 m .48138 .51303 L .47906 .51355 L F
.484 .321 .584 r
.48134 .51536 m .47906 .51355 L .48138 .51303 L F
.48134 .51536 m .47926 .51618 L .47906 .51355 L F
.983 .699 .381 r
.60533 .36973 m .60309 .37206 L .60308 .36951 L F
.60533 .36973 m .60505 .37067 L .60309 .37206 L F
.12 0 .241 r
.60461 .37098 m .60257 .37388 L .60309 .37206 L F
.60501 .3707 m .60419 .37177 L .60461 .37098 L F
.60419 .37177 m .60257 .37388 L .60461 .37098 L F
.616 .244 .313 r
.60364 .37204 m .60503 .37018 L .60308 .36951 L F
.12 0 .241 r
.60501 .37072 m .60257 .37388 L .60501 .3707 L F
.768 .965 .668 r
.60338 .37229 m .60257 .37388 L .60311 .37318 L F
.60356 .37212 m .60311 .37318 L .60501 .37072 L F
.60338 .37229 m .60311 .37318 L .60356 .37212 L F
.616 .244 .313 r
.60411 .37159 m .60503 .37018 L .60364 .37204 L F
.60503 .37018 m .60533 .36973 L .60505 .3697 L F
.60503 .37018 m .60505 .3697 L .60308 .36951 L F
.815 .909 .507 r
.60628 .36677 m .60542 .36947 L .6041 .37157 L F
.60628 .36677 m .6041 .37157 L .60407 .37143 L F
.768 .965 .668 r
.60442 .37091 m .60442 .37092 L .60505 .37067 L F
.60399 .37109 m .6041 .37159 L .60505 .37067 L F
.12 0 .241 r
.60505 .37067 m .60501 .37072 L .60501 .3707 L F
.768 .965 .668 r
.60338 .37229 m .60501 .37072 L .60505 .37067 L F
.811 .716 .76 r
.60813 .37128 m .60627 .37432 L .60505 .37067 L F
.921 .621 .141 r
.60505 .37067 m .60627 .37432 L .60542 .37313 L F
0 0 .383 r
.60505 .37067 m .60542 .37313 L .60643 .37112 L F
.60505 .37067 m .60643 .37112 L .60563 .37111 L F
.1 0 .353 r
.60628 .36677 m .6046 .3703 L .60661 .36776 L F
.6046 .3703 m .60407 .37143 L .60476 .37043 L F
.6046 .3703 m .60476 .37043 L .60661 .36776 L F
.60453 .37093 m .60376 .37211 L .60471 .37096 L F
.60376 .37211 m .60369 .37223 L .60379 .37209 L F
.60376 .37211 m .60379 .37209 L .60471 .37096 L F
.413 .642 .951 r
.60643 .37112 m .60542 .37313 L .60445 .37174 L F
0 0 .383 r
.60505 .37067 m .60531 .37086 L .60442 .37091 L F
.60531 .37086 m .60563 .37111 L .60471 .37096 L F
.60531 .37086 m .60471 .37096 L .60442 .37091 L F
.815 .909 .507 r
.60542 .36947 m .60533 .36973 L .60503 .37018 L F
.1 0 .353 r
.60493 .37018 m .60519 .36993 L .60661 .36776 L F
.60407 .37143 m .60519 .36993 L .60493 .37018 L F
.815 .909 .507 r
.60407 .37143 m .6041 .37157 L .60369 .37223 L F
.60542 .36947 m .60503 .37018 L .60369 .37223 L F
.1 0 .353 r
.60407 .37143 m .60369 .37223 L .60519 .36993 L F
.60661 .36776 m .60453 .37093 L .60681 .36837 L F
.60453 .37093 m .60471 .37096 L .60681 .36837 L F
.768 .965 .668 r
.60399 .37108 m .60399 .37109 L .60442 .37092 L F
.60399 .37108 m .60442 .37092 L .60442 .37091 L F
.493 .346 .609 r
.60399 .37108 m .60681 .36837 L .60471 .37096 L F
.616 .244 .313 r
.60369 .37223 m .60411 .37159 L .60364 .37204 L F
.493 .346 .609 r
.60399 .37108 m .60471 .37096 L .60369 .37223 L F
.413 .642 .951 r
.60563 .37111 m .60445 .37174 L .60399 .37108 L F
.60643 .37112 m .60445 .37174 L .60563 .37111 L F
.768 .965 .668 r
.60399 .37109 m .60338 .37229 L .6041 .37159 L F
.107 .278 .756 r
.60399 .37108 m .60369 .37223 L .60362 .37196 L F
.60399 .37108 m .60362 .37196 L .60334 .37085 L F
.677 .14 0 r
.59853 .36821 m .60264 .37101 L .60308 .36951 L F
.107 .278 .756 r
.60399 .37108 m .60334 .37085 L .60254 .36768 L F
.616 .244 .313 r
.60369 .37223 m .60308 .36951 L .60264 .371 L F
.6029 .37131 m .60264 .371 L .60264 .37101 L F
.60369 .37223 m .60264 .371 L .6029 .37131 L F
.541 .713 .951 r
.60542 .37313 m .60454 .37336 L .60399 .37108 L F
.60454 .37336 m .60257 .37388 L .60349 .37206 L F
.60454 .37336 m .60349 .37206 L .60399 .37108 L F
.936 .83 .715 r
.60263 .37083 m .60369 .37223 L .60264 .37101 L F
.60254 .36768 m .60327 .37056 L .60263 .37083 L F
.60327 .37056 m .60369 .37223 L .60263 .37083 L F
.603 .136 .119 r
.60199 .37111 m .60249 .37305 L .60399 .37108 L F
.59947 .37114 m .60045 .37176 L .60199 .37111 L F
.60045 .37176 m .60249 .37305 L .60199 .37111 L F
.009 0 0 r
.60249 .37305 m .60545 .3716 L .60399 .37108 L F
.60545 .3716 m .60595 .37135 L .60399 .37108 L F
.60595 .37135 m .60643 .37112 L .60563 .37111 L F
.60595 .37135 m .60563 .37111 L .60399 .37108 L F
0 0 .383 r
.60442 .37091 m .60563 .37111 L .60399 .37108 L F
.12 .416 .863 r
.27802 .57339 m .27925 .57572 L .2776 .57492 L F
.746 .662 .767 r
.35737 .63592 m .35998 .63503 L .35879 .63354 L F
0 0 .399 r
.35737 .63592 m .35877 .63715 L .35998 .63503 L F
.719 .988 .866 r
.35737 .63592 m .35879 .63354 L .35998 .63503 L F
.746 .852 .413 r
.70103 .353 m .70185 .3519 L .70191 .35109 L F
.522 .234 .418 r
.5568 .42048 m .55285 .42535 L .55289 .42272 L F
.5568 .42048 m .55596 .42503 L .55285 .42535 L F
.509 .44 .715 r
.55931 .41989 m .55949 .42252 L .5568 .42048 L F
.183 0 .305 r
.55787 .42341 m .5568 .42048 L .55949 .42252 L F
.55787 .42341 m .55596 .42503 L .5568 .42048 L F
0 0 .225 r
.41057 .56391 m .4094 .56037 L .41104 .56207 L F
.279 0 0 r
.45828 .59282 m .45869 .59185 L .46254 .59075 L F
.583 .187 .257 r
.26462 .52064 m .2643 .52231 L .26169 .52228 L F
.518 .17 .318 r
.2685 .51907 m .2643 .52231 L .26462 .52064 L F
.701 .544 .672 r
.36956 .55239 m .37312 .5525 L .3722 .54895 L F
.555 .48 .725 r
.3722 .54895 m .37526 .54857 L .37452 .54562 L F
0 0 0 r
.37334 .54764 m .3722 .54895 L .37452 .54562 L F
.804 .576 .593 r
.37334 .54764 m .37051 .5503 L .3722 .54895 L F
.556 .454 .694 r
.3722 .54895 m .37394 .55165 L .37526 .54857 L F
.3722 .54895 m .37312 .5525 L .37394 .55165 L F
.419 .473 .809 r
.56625 .43887 m .56353 .43928 L .56268 .43629 L F
.4 .326 .658 r
.56625 .43887 m .5663 .44134 L .56353 .43928 L F
.738 .214 0 r
.2427 .57456 m .24608 .57735 L .24677 .57497 L F
.49 .37 .644 r
.47926 .51618 m .47963 .51957 L .47705 .52022 L F
.491 .345 .61 r
.47963 .51957 m .47727 .52312 L .47705 .52022 L F
.669 .968 .92 r
.66141 .33449 m .66034 .33409 L .65877 .33616 L F
.603 .867 .528 r
.66034 .33409 m .65761 .33727 L .65877 .33616 L F
.9 .753 .69 r
.33528 .61911 m .3348 .62341 L .33314 .61867 L F
.917 .593 .416 r
.33528 .61911 m .33729 .62343 L .3348 .62341 L F
.315 0 0 r
.33565 .61945 m .33528 .61911 L .33314 .61867 L F
.33565 .61945 m .33528 .61911 L .33314 .61867 L F
0 0 0 r
.33565 .61945 m .33528 .61911 L .33691 .61939 L F
.33691 .61939 m .33528 .61911 L .33565 .61945 L F
.33691 .61939 m .33528 .61911 L .33565 .61945 L F
.724 .216 .02 r
.38609 .50891 m .38159 .50642 L .38347 .50719 L F
0 0 0 r
.47528 .58293 m .47262 .58604 L .4735 .58399 L F
.984 .895 .563 r
.43198 .54282 m .43024 .54438 L .43105 .54002 L F
.43198 .54282 m .43097 .54567 L .43024 .54438 L F
0 0 0 r
.67143 .36971 m .67272 .36888 L .66916 .37093 L F
.67531 .36779 m .67272 .36888 L .67143 .36971 L F
.22647 .54548 m .22748 .54407 L .228 .54218 L F
.228 .54218 m .22928 .5403 L .23004 .53788 L F
.228 .54218 m .22748 .54407 L .22928 .5403 L F
.728 .987 .801 r
.38598 .6545 m .38597 .65393 L .38661 .65417 L F
.321 0 0 r
.38597 .65393 m .38884 .65523 L .38661 .65417 L F
.736 .579 .679 r
.37554 .59409 m .37694 .59804 L .37317 .59714 L F
.56 .523 .771 r
.37706 .59042 m .37807 .59346 L .37554 .59409 L F
.899 .54 .072 r
.38121 .52828 m .38149 .5264 L .3796 .5254 L F
.38121 .52828 m .3824 .52984 L .38149 .5264 L F
.64 .302 .383 r
.242 .62015 m .24244 .61756 L .23981 .61721 L F
.812 .382 0 r
.44577 .57107 m .44703 .57197 L .44371 .57108 L F
.44577 .57107 m .44824 .57446 L .44703 .57197 L F
.763 .945 .612 r
.38235 .62461 m .38411 .623 L .38394 .62256 L F
.38235 .62461 m .38195 .62592 L .38411 .623 L F
.581 .161 .21 r
.36875 .59465 m .37116 .59638 L .36918 .59608 L F
0 0 .249 r
.28264 .62783 m .28123 .62929 L .28152 .6266 L F
.839 .803 .816 r
.5065 .42391 m .50234 .42557 L .50489 .42193 L F
.647 .742 .918 r
.50924 .42291 m .5065 .42391 L .50489 .42193 L F
.561 .411 .635 r
.36716 .52604 m .36374 .52767 L .3641 .52681 L F
.371 .829 .917 r
.27777 .51574 m .27855 .51493 L .28009 .5152 L F
.27777 .51574 m .276 .51552 L .27855 .51493 L F
.898 .933 .83 r
.73517 .33138 m .73627 .33291 L .73846 .32988 L F
.542 .804 .994 r
.59333 .37718 m .59765 .3779 L .59573 .37661 L F
.773 .678 .757 r
.59333 .37718 m .59461 .38126 L .59765 .3779 L F
.966 .721 .516 r
.59765 .3779 m .59725 .38053 L .59573 .37661 L F
.59573 .37661 m .59725 .38053 L .59765 .3779 L F
.74 .397 .4 r
.38783 .65776 m .39185 .65604 L .38884 .65523 L F
.38783 .65776 m .39212 .65834 L .39185 .65604 L F
0 .479 .806 r
.55919 .39008 m .56148 .3907 L .56322 .39157 L F
.599 .887 .991 r
.56148 .3907 m .56595 .39038 L .56322 .39157 L F
.436 0 0 r
.35868 .64103 m .35737 .63993 L .3555 .63958 L F
.738 .975 .726 r
.23363 .53254 m .23306 .53247 L .23453 .53062 L F
0 0 .435 r
.46568 .54601 m .46743 .54439 L .46718 .54148 L F
.907 .86 .417 r
.46694 .54784 m .46743 .54439 L .46568 .54601 L F
.115 .112 .576 r
.46568 .54601 m .46638 .54914 L .46694 .54784 L F
.333 .171 .507 r
.32887 .55738 m .32661 .55531 L .32914 .5546 L F
.32887 .55738 m .32642 .55844 L .32661 .55531 L F
.313 0 .101 r
.26644 .51571 m .2697 .51534 L .26809 .51525 L F
0 0 0 r
.23344 .54961 m .23297 .55137 L .23158 .55215 L F
.103 0 .071 r
.23246 .5538 m .23158 .55215 L .23297 .55137 L F
.23246 .5538 m .23097 .55443 L .23158 .55215 L F
.762 .693 .786 r
.33314 .61867 m .3348 .62341 L .33106 .62271 L F
.711 .262 .183 r
.33106 .62271 m .3348 .62341 L .33256 .62511 L F
.643 .172 .121 r
.33256 .62511 m .3348 .62341 L .33711 .62539 L F
.565 .224 .35 r
.3348 .62341 m .33729 .62343 L .33711 .62539 L F
.964 .651 .254 r
.5958 .42138 m .59666 .42 L .59486 .41916 L F
.5958 .42138 m .59697 .42244 L .59666 .42 L F
.726 .207 0 r
.38337 .53222 m .38545 .53473 L .38713 .53567 L F
.934 .557 .196 r
.38626 .5376 m .38713 .53567 L .38545 .53473 L F
.38626 .5376 m .38834 .53947 L .38713 .53567 L F
.974 .802 .608 r
.61453 .40229 m .61655 .40069 L .61496 .39957 L F
.61453 .40229 m .61607 .40357 L .61655 .40069 L F
.355 .827 .794 r
.25134 .61044 m .25017 .61059 L .24792 .61145 L F
.52 .431 .695 r
.25017 .61059 m .25259 .61145 L .25216 .60982 L F
.73 .989 .815 r
.25134 .61044 m .25017 .61059 L .25191 .60885 L F
.52 .431 .695 r
.25191 .60885 m .25017 .61059 L .25134 .61044 L F
.25017 .61059 m .25216 .60982 L .25191 .60885 L F
.355 .827 .794 r
.24792 .61145 m .25017 .61059 L .24713 .61169 L F
.646 .537 .716 r
.42755 .46712 m .43101 .46427 L .42795 .46514 L F
.78 .862 .91 r
.48564 .43622 m .48201 .43646 L .48411 .43488 L F
.804 .879 .901 r
.48854 .43363 m .48564 .43622 L .48411 .43488 L F
.614 .942 .748 r
.63783 .34822 m .64071 .3461 L .64025 .34791 L F
.304 0 .26 r
.64071 .3461 m .64342 .34513 L .64025 .34791 L F
0 0 0 r
.66794 .38325 m .66894 .38263 L .671 .38197 L F
.891 .635 .545 r
.33912 .68427 m .34223 .6881 L .3383 .68741 L F
.679 .206 .122 r
.3383 .68741 m .34223 .6881 L .34131 .68935 L F
.34131 .68935 m .34223 .6881 L .3383 .68741 L F
.081 0 .39 r
.34223 .6881 m .3442 .68398 L .34472 .68783 L F
.977 .825 .418 r
.39752 .57986 m .39819 .58076 L .39864 .57805 L F
.93 .861 .428 r
.39843 .57586 m .39752 .57986 L .39864 .57805 L F
.213 0 0 r
.34419 .58055 m .34666 .57998 L .3479 .57801 L F
0 0 0 r
.3479 .57801 m .34916 .57645 L .3502 .57405 L F
.496 .344 .603 r
.34666 .57998 m .34916 .57645 L .3479 .57801 L F
.894 .831 .777 r
.58891 .35535 m .58521 .35731 L .58793 .35512 L F
.58891 .35535 m .58654 .35976 L .58521 .35731 L F
.538 .923 .91 r
.58891 .35535 m .59037 .35392 L .59105 .35429 L F
.58891 .35535 m .58793 .35512 L .59037 .35392 L F
.623 .896 .987 r
.28256 .57489 m .28434 .57588 L .28628 .57492 L F
.593 .912 .978 r
.73813 .31531 m .73519 .31675 L .73425 .31611 L F
.27 0 0 r
.73813 .31531 m .73425 .31611 L .73519 .31675 L F
.117 .108 .571 r
.70304 .28266 m .703 .28025 L .70331 .28281 L F
.96 .945 .68 r
.70049 .28593 m .70304 .28266 L .70331 .28281 L F
.738 .44 .477 r
.41159 .49289 m .41575 .49015 L .41432 .49203 L F
.697 .173 0 r
.25419 .62332 m .2521 .62319 L .2504 .62205 L F
.639 .089 0 r
.25419 .62332 m .25453 .62452 L .2521 .62319 L F
.25419 .62332 m .25638 .62547 L .25453 .62452 L F
.875 .966 .851 r
.34493 .54865 m .34668 .54498 L .34894 .54678 L F
.7 .51 .627 r
.36236 .61403 m .36661 .6137 L .36587 .61084 L F
.606 .452 .647 r
.36587 .61084 m .36773 .61186 L .36814 .60916 L F
.36587 .61084 m .36661 .6137 L .36773 .61186 L F
.346 0 0 r
.25085 .61663 m .25284 .61662 L .2485 .61609 L F
.355 0 0 r
.25337 .61713 m .25284 .61662 L .25085 .61663 L F
.25337 .61713 m .25554 .61784 L .25284 .61662 L F
0 0 0 r
.24257 .52621 m .23937 .52903 L .24139 .52737 L F
.443 .801 .997 r
.23617 .52863 m .23937 .52903 L .23554 .52869 L F
.168 0 0 r
.23518 .5285 m .23741 .52886 L .23937 .52903 L F
.331 0 0 r
.23741 .52886 m .24139 .52737 L .23937 .52903 L F
.23741 .52886 m .23934 .52936 L .24054 .52819 L F
.23871 .52837 m .24054 .52819 L .24139 .52737 L F
.23741 .52886 m .24054 .52819 L .23871 .52837 L F
.443 .801 .997 r
.23554 .52869 m .23937 .52903 L .23701 .52947 L F
.23518 .5285 m .23617 .52863 L .23554 .52869 L F
.809 .825 .863 r
.47238 .44177 m .47603 .44183 L .47404 .44363 L F
.387 .219 .529 r
.32266 .59947 m .32501 .59702 L .32238 .59783 L F
.32266 .59947 m .32518 .60046 L .32501 .59702 L F
.393 .211 .512 r
.32266 .59947 m .32288 .60308 L .32518 .60046 L F
.814 .765 .807 r
.43336 .49371 m .43085 .49698 L .43495 .49742 L F
.666 .438 .566 r
.43225 .50016 m .43495 .49742 L .43085 .49698 L F
.43225 .50016 m .43514 .50016 L .43495 .49742 L F
.745 .739 .846 r
.43495 .49742 m .43562 .49274 L .43336 .49371 L F
.43495 .49742 m .43769 .4942 L .43562 .49274 L F
.594 .504 .722 r
.43495 .49742 m .43794 .4973 L .43769 .4942 L F
.426 .26 .551 r
.43495 .49742 m .43745 .49922 L .43794 .4973 L F
.43495 .49742 m .43514 .50016 L .43745 .49922 L F
0 0 0 r
.33335 .53674 m .33247 .5385 L .33465 .53532 L F
.35711 .64855 m .35852 .64791 L .35666 .64925 L F
0 0 .021 r
.28739 .52951 m .28856 .5295 L .29033 .52579 L F
0 0 0 r
.29033 .52579 m .29024 .52716 L .29172 .52635 L F
.29033 .52579 m .28856 .5295 L .29024 .52716 L F
.521 .544 .82 r
.29379 .52731 m .29033 .52579 L .29172 .52635 L F
.655 .565 .741 r
.4206 .49425 m .42422 .49431 L .42244 .49295 L F
.4206 .49425 m .42417 .49612 L .42422 .49431 L F
.792 .842 .89 r
.42244 .49295 m .42422 .49431 L .42766 .49162 L F
.472 .129 .302 r
.42417 .49612 m .426 .49627 L .42422 .49431 L F
.74 .702 .815 r
.42766 .49162 m .42422 .49431 L .4273 .49306 L F
.48 .129 .292 r
.42422 .49431 m .426 .49627 L .4273 .49306 L F
.845 .914 .513 r
.44495 .57479 m .44326 .57703 L .44326 .57381 L F
.44495 .57479 m .44347 .57801 L .44326 .57703 L F
.525 .859 .995 r
.55501 .38461 m .55409 .38366 L .55861 .38371 L F
.55501 .38461 m .55409 .38366 L .55861 .38371 L F
.678 .66 .825 r
.37504 .67136 m .37844 .67353 L .3779 .6709 L F
.4 .431 .777 r
.37844 .67353 m .38029 .67052 L .3779 .6709 L F
.613 .637 .85 r
.37844 .67353 m .38174 .67421 L .38135 .67438 L F
.4 .431 .777 r
.37844 .67353 m .38135 .67438 L .38029 .67052 L F
.913 .614 .126 r
.39758 .57301 m .3981 .57152 L .39708 .57025 L F
.39758 .57301 m .39861 .57445 L .3981 .57152 L F
.874 .895 .473 r
.43456 .50303 m .43364 .50669 L .43678 .50476 L F
.43456 .50303 m .43329 .50626 L .43364 .50669 L F
.861 .923 .531 r
.43329 .50626 m .43205 .50863 L .43364 .50669 L F
.585 .119 .114 r
.43364 .50669 m .43205 .50863 L .4359 .50859 L F
.904 .748 .677 r
.44232 .48983 m .44351 .48987 L .44501 .48713 L F
.399 .469 .816 r
.44351 .48987 m .44677 .48587 L .44501 .48713 L F
.44351 .48987 m .44786 .48902 L .44677 .48587 L F
.229 0 .162 r
.44351 .48987 m .44464 .49179 L .44786 .48902 L F
.91 .504 .15 r
.23033 .56932 m .22948 .56883 L .22629 .5697 L F
.22948 .56883 m .2269 .56738 L .22632 .5696 L F
.22948 .56883 m .22632 .5696 L .22629 .5697 L F
.23033 .56932 m .22897 .56938 L .2269 .56738 L F
.992 .878 .556 r
.23115 .56794 m .22897 .56938 L .23033 .56932 L F
.25 0 0 r
.23198 .56909 m .22897 .56938 L .22999 .56871 L F
.23145 .56836 m .22999 .56871 L .23115 .56794 L F
.23198 .56909 m .22999 .56871 L .23145 .56836 L F
.304 .423 .818 r
.2318 .56499 m .23115 .56794 L .2309 .56471 L F
.2318 .56499 m .23346 .56757 L .23115 .56794 L F
.25 0 0 r
.23198 .56909 m .23115 .56794 L .23346 .56757 L F
.365 .252 .589 r
.47867 .5321 m .47887 .53504 L .47651 .53286 L F
.271 .245 .645 r
.47651 .53286 m .47887 .53504 L .47709 .53494 L F
.385 0 0 r
.34181 .6546 m .34436 .6552 L .34014 .65488 L F
.92 .85 .405 r
.3974 .5857 m .39698 .59059 L .39858 .58824 L F
.95 .641 .413 r
.39006 .54233 m .39024 .54486 L .39214 .54565 L F
.878 .441 .104 r
.39151 .547 m .39214 .54565 L .39024 .54486 L F
.39151 .547 m .39303 .54798 L .39214 .54565 L F
.369 .804 .963 r
.59651 .36135 m .59581 .3607 L .59301 .36115 L F
.764 .991 .886 r
.59817 .3585 m .59651 .36135 L .59949 .35841 L F
.59817 .3585 m .59581 .3607 L .59651 .36135 L F
.985 .706 .359 r
.45102 .52861 m .45271 .53235 L .45463 .52874 L F
.45102 .52861 m .45107 .53147 L .45271 .53235 L F
.653 .595 .777 r
.45271 .53235 m .45626 .53379 L .45463 .52874 L F
.868 .423 .09 r
.60094 .40304 m .60265 .40392 L .60179 .40497 L F
.926 .544 .163 r
.60265 .40392 m .60332 .40625 L .60179 .40497 L F
.981 .751 .517 r
.59301 .38037 m .59461 .38126 L .59333 .37718 L F
.59333 .37718 m .59461 .38126 L .59301 .38037 L F
.813 .332 .042 r
.38988 .51235 m .38609 .50891 L .38777 .51 L F
.253 0 0 r
.69428 .31584 m .69848 .31648 L .6972 .31645 L F
.516 .769 .988 r
.59459 .45877 m .59865 .45929 L .59727 .45786 L F
.59727 .45786 m .59865 .45929 L .59459 .45877 L F
.43 0 0 r
.29049 .57431 m .28628 .57492 L .28755 .57438 L F
.471 0 0 r
.33617 .64884 m .34044 .64913 L .33884 .65029 L F
.33617 .64884 m .33884 .65029 L .33862 .65027 L F
.33617 .64884 m .3383 .65009 L .33616 .65143 L F
.731 .537 .629 r
.33699 .65003 m .33896 .6489 L .33938 .64713 L F
.33896 .6489 m .34119 .64763 L .33988 .64727 L F
.33896 .6489 m .33988 .64727 L .33938 .64713 L F
.471 0 0 r
.3383 .65009 m .33862 .65027 L .33805 .65054 L F
.3383 .65009 m .33805 .65054 L .33616 .65143 L F
.33862 .65027 m .33858 .65043 L .33616 .65143 L F
.731 .537 .629 r
.33884 .65029 m .34116 .65164 L .34117 .65054 L F
.33722 .65012 m .33854 .65063 L .33884 .65029 L F
.768 .74 .827 r
.33858 .65043 m .33622 .65455 L .33616 .65143 L F
.33876 .65035 m .33854 .65071 L .33858 .65043 L F
.33854 .65071 m .33622 .65455 L .3385 .65056 L F
.107 .016 .46 r
.33616 .65143 m .33708 .65233 L .33699 .65003 L F
.768 .74 .827 r
.33857 .65066 m .3369 .65461 L .33701 .65324 L F
.107 .016 .46 r
.33708 .65233 m .33762 .65286 L .33719 .65094 L F
.33708 .65233 m .33719 .65094 L .33699 .65003 L F
.768 .74 .827 r
.33857 .65066 m .34014 .65488 L .3369 .65461 L F
.33701 .65324 m .3369 .65461 L .33622 .65455 L F
.731 .537 .629 r
.33855 .65062 m .33869 .65068 L .33884 .65029 L F
.768 .74 .827 r
.33885 .65064 m .33887 .65071 L .33867 .65068 L F
.477 .51 .814 r
.34116 .65164 m .34014 .65488 L .33885 .65064 L F
.731 .537 .629 r
.33885 .65064 m .34116 .65164 L .33926 .65054 L F
.33869 .65068 m .33926 .65054 L .33884 .65029 L F
.477 .51 .814 r
.34116 .65164 m .33885 .65064 L .33876 .65035 L F
.731 .537 .629 r
.33869 .65068 m .34116 .65164 L .33885 .65064 L F
.768 .74 .827 r
.33876 .65035 m .33885 .65064 L .33857 .65066 L F
.33885 .65064 m .33867 .65068 L .33857 .65066 L F
.33887 .65071 m .34014 .65488 L .33857 .65066 L F
.721 .272 .183 r
.33982 .65314 m .34008 .65285 L .33748 .65048 L F
.33738 .65047 m .33748 .65048 L .33699 .65003 L F
.33982 .65314 m .33748 .65048 L .33738 .65047 L F
.34008 .65285 m .34116 .65164 L .33855 .65064 L F
.768 .74 .827 r
.33854 .65071 m .3385 .65056 L .33855 .65064 L F
.721 .272 .183 r
.34008 .65285 m .33855 .65064 L .33699 .65003 L F
.768 .74 .827 r
.33855 .65064 m .3385 .65056 L .33858 .65043 L F
.731 .537 .629 r
.33854 .65063 m .33855 .65064 L .33855 .65062 L F
.33855 .65064 m .34116 .65164 L .33855 .65062 L F
.691 .925 .606 r
.33884 .65029 m .34044 .64913 L .34119 .64763 L F
.731 .537 .629 r
.33722 .65012 m .34117 .65054 L .34119 .64763 L F
.691 .925 .606 r
.33876 .65035 m .33884 .65029 L .34119 .64763 L F
.471 0 0 r
.33862 .65027 m .33876 .65035 L .33858 .65043 L F
.731 .537 .629 r
.33699 .65003 m .33722 .65012 L .33893 .64905 L F
.33896 .6489 m .33893 .64905 L .34119 .64763 L F
.33699 .65003 m .33893 .64905 L .33896 .6489 L F
.471 0 0 r
.33862 .65027 m .33884 .65029 L .33876 .65035 L F
.868 .755 .736 r
.69964 .27689 m .7001 .28074 L .69736 .28037 L F
.726 .791 .904 r
.70151 .27678 m .7001 .28074 L .69964 .27689 L F
.70151 .27678 m .70286 .27954 L .7001 .28074 L F
0 0 .044 r
.34347 .62953 m .34118 .63319 L .34388 .63141 L F
.621 .693 .895 r
.52638 .40987 m .52426 .41137 L .52169 .40838 L F
.84 .738 .752 r
.28301 .65277 m .28483 .65482 L .28264 .65511 L F
.799 .522 .518 r
.28264 .65511 m .28483 .65482 L .28228 .65835 L F
.326 .631 .961 r
.2862 .65378 m .28483 .65482 L .28301 .65277 L F
0 .533 .752 r
.28887 .65538 m .28483 .65482 L .28769 .65544 L F
.326 .631 .961 r
.2862 .65378 m .28769 .65544 L .28483 .65482 L F
.595 .317 .465 r
.28483 .65482 m .28724 .65776 L .28228 .65835 L F
.28483 .65482 m .28769 .65544 L .28724 .65776 L F
.952 .76 .607 r
.60172 .435 m .6034 .43614 L .60205 .43229 L F
.968 .727 .52 r
.60144 .43779 m .6034 .43614 L .60172 .435 L F
.60144 .43779 m .60325 .43884 L .6034 .43614 L F
0 .549 .814 r
.36827 .63601 m .37104 .63644 L .36913 .63583 L F
.36827 .63601 m .36913 .63583 L .36609 .63796 L F
.711 .606 .738 r
.3576 .56148 m .36182 .56195 L .36019 .56097 L F
.3576 .56148 m .36169 .56493 L .36182 .56195 L F
.695 .901 .97 r
.36318 .55979 m .36019 .56097 L .36182 .56195 L F
.23 .282 .71 r
.36182 .56195 m .36418 .56404 L .36318 .55979 L F
.695 .901 .97 r
.36318 .55979 m .36019 .56097 L .36182 .56195 L F
.442 .296 .586 r
.36182 .56195 m .36169 .56493 L .36418 .56404 L F
0 0 0 r
.43078 .53457 m .43273 .53294 L .42921 .53178 L F
.734 .564 .662 r
.48744 .50724 m .48387 .50944 L .48397 .50679 L F
.386 .039 .25 r
.4273 .49306 m .42933 .49393 L .43023 .49363 L F
.4273 .49306 m .426 .49627 L .42933 .49393 L F
0 0 .443 r
.55781 .40329 m .55916 .40642 L .55767 .40207 L F
.467 .837 .591 r
.43125 .52638 m .42946 .52768 L .42872 .52834 L F
0 0 0 r
.43212 .52617 m .42946 .52768 L .43125 .52638 L F
.605 .596 .816 r
.42824 .52459 m .42946 .52768 L .43212 .52617 L F
.582 .547 .78 r
.4308 .52611 m .4302 .52703 L .42946 .52768 L F
.4302 .52703 m .42931 .52837 L .42946 .52768 L F
.467 .837 .591 r
.42872 .52834 m .42946 .52768 L .42814 .52879 L F
0 0 0 r
.43212 .52617 m .43125 .52638 L .43384 .52636 L F
.941 .964 .71 r
.38027 .61938 m .37744 .62255 L .37932 .61892 L F
.38027 .61938 m .3783 .62318 L .37744 .62255 L F
.911 .96 .806 r
.38163 .61515 m .38027 .61938 L .37932 .61892 L F
.459 .523 .837 r
.70598 .2793 m .703 .28025 L .70286 .27954 L F
.279 .024 .337 r
.70331 .28281 m .703 .28025 L .70598 .2793 L F
.591 .017 0 r
.58938 .35915 m .58521 .35731 L .58654 .35976 L F
.851 .419 0 r
.39232 .5158 m .38988 .51235 L .39131 .51364 L F
.437 .319 .62 r
.30848 .54922 m .31085 .55134 L .31069 .54849 L F
.30848 .54922 m .31085 .55134 L .31069 .54849 L F
.259 .666 .966 r
.42397 .48632 m .42287 .48732 L .42128 .48656 L F
.42397 .48632 m .42588 .48771 L .42287 .48732 L F
.543 .301 .499 r
.28089 .54584 m .28045 .54832 L .278 .54838 L F
.079 .154 .641 r
.28124 .54512 m .28045 .54832 L .28089 .54584 L F
.929 .686 .551 r
.25057 .58092 m .2523 .58463 L .25004 .58443 L F
.405 .46 .804 r
.25359 .58335 m .2523 .58463 L .25057 .58092 L F
.662 .934 .969 r
.25004 .58443 m .2523 .58463 L .25359 .58335 L F
.883 .451 .093 r
.60681 .41669 m .60951 .41995 L .60639 .41823 L F
.95 .718 .553 r
.60951 .41995 m .60746 .42119 L .60639 .41823 L F
.60951 .41995 m .6093 .42239 L .60746 .42119 L F
0 .542 .806 r
.3457 .49719 m .34748 .49776 L .34349 .49684 L F
0 .403 .697 r
.35045 .49861 m .34748 .49776 L .3457 .49719 L F
.864 .776 .763 r
.60429 .35617 m .60901 .35674 L .60693 .35542 L F
.629 .928 .971 r
.60693 .35542 m .60901 .35674 L .61174 .35498 L F
.528 .799 .995 r
.35145 .68789 m .34919 .68872 L .34732 .68724 L F
.692 .79 .926 r
.4056 .48754 m .40316 .48869 L .40147 .48701 L F
0 0 0 r
.65029 .38216 m .65127 .38089 L .649 .38217 L F
.65358 .37903 m .65127 .38089 L .65029 .38216 L F
.489 .264 .499 r
.33152 .57805 m .33402 .57753 L .33428 .5749 L F
.451 .271 .545 r
.33428 .5749 m .33659 .57431 L .33667 .57149 L F
.428 .213 .483 r
.33428 .5749 m .33402 .57753 L .33659 .57431 L F
.325 .177 .521 r
.31924 .53902 m .31974 .54264 L .32143 .54111 L F
.279 0 0 r
.45828 .59282 m .46254 .59075 L .461 .59244 L F
.348 0 0 r
.46254 .59075 m .46353 .59216 L .461 .59244 L F
.46254 .59075 m .46511 .59049 L .46353 .59216 L F
.596 .868 .993 r
.27667 .63599 m .27716 .6334 L .27491 .63501 L F
.505 .504 .789 r
.28013 .63586 m .28304 .63554 L .28106 .63186 L F
.28013 .63586 m .28106 .63186 L .28033 .63517 L F
.596 .868 .993 r
.27667 .63599 m .28033 .63517 L .27716 .6334 L F
.677 .72 .881 r
.27667 .63599 m .28013 .63586 L .28033 .63517 L F
.521 .523 .798 r
.27667 .63599 m .2804 .63818 L .28013 .63586 L F
.518 .17 .318 r
.2685 .51907 m .26689 .52226 L .2643 .52231 L F
0 0 0 r
.2689 .5207 m .2685 .51907 L .27096 .51975 L F
.103 0 0 r
.27361 .51939 m .27145 .52036 L .2689 .5207 L F
0 0 0 r
.27145 .52036 m .26962 .52052 L .2689 .5207 L F
.2689 .5207 m .2675 .52105 L .2685 .51907 L F
.26962 .52052 m .26714 .52073 L .2689 .5207 L F
.2689 .5207 m .26689 .52226 L .2675 .52105 L F
0 0 .1 r
.23333 .54635 m .23313 .5459 L .23362 .54366 L F
.23333 .54635 m .23344 .54961 L .23313 .5459 L F
.996 .822 .463 r
.42675 .5659 m .42773 .56558 L .42689 .56351 L F
.42675 .5659 m .42721 .56641 L .42773 .56558 L F
.691 .51 .638 r
.57414 .41285 m .57773 .41328 L .57505 .41684 L F
.5 .344 .6 r
.30832 .56766 m .30593 .57021 L .306 .56838 L F
.172 .212 .663 r
.30054 .6293 m .29917 .62974 L .30125 .6321 L F
.261 .765 .737 r
.671 .38197 m .67513 .38086 L .67378 .38118 L F
.445 .856 .689 r
.67698 .37952 m .67513 .38086 L .67761 .37928 L F
.46 .878 .754 r
.67378 .38118 m .67513 .38086 L .67698 .37952 L F
.861 .942 .871 r
.27545 .51738 m .27523 .5201 L .27756 .51926 L F
.27545 .51738 m .27361 .51939 L .27523 .5201 L F
.214 0 0 r
.36102 .70091 m .36493 .70018 L .36357 .70027 L F
.477 .817 .999 r
.36493 .70018 m .36784 .69976 L .36526 .69876 L F
.732 .991 .842 r
.36357 .70027 m .36493 .70018 L .36526 .69876 L F
.857 .728 .207 r
.54626 .41608 m .5466 .41263 L .54601 .41453 L F
.522 .823 1 r
.54887 .41077 m .5466 .41263 L .54611 .41138 L F
0 0 0 r
.54601 .41453 m .5466 .41263 L .54887 .41077 L F
.425 .867 .803 r
.69594 .32991 m .69464 .33096 L .69334 .33001 L F
.69594 .32991 m .69781 .32953 L .69464 .33096 L F
.977 .742 .515 r
.24794 .54901 m .24764 .55197 L .24577 .55054 L F
.444 .244 .514 r
.25006 .55112 m .24794 .54901 L .25018 .54837 L F
.25006 .55112 m .24764 .55197 L .24794 .54901 L F
.785 .539 .565 r
.24577 .55054 m .25018 .54837 L .24794 .54901 L F
.763 .359 .286 r
.26396 .62238 m .26476 .6248 L .26746 .62237 L F
.792 .974 .91 r
.26476 .6248 m .26936 .62297 L .26746 .62237 L F
0 0 0 r
.44599 .59705 m .44973 .59486 L .44799 .59608 L F
.44799 .59608 m .44973 .59486 L .45201 .59381 L F
.549 .431 .671 r
.37694 .59804 m .37512 .59957 L .37317 .59714 L F
.654 .952 .73 r
.65807 .32194 m .65627 .32363 L .65475 .3243 L F
.777 .8 .872 r
.43959 .56191 m .44478 .56195 L .44486 .55722 L F
0 0 .001 r
.44314 .56308 m .44478 .56195 L .43959 .56191 L F
0 .012 .554 r
.44163 .55525 m .44125 .5552 L .44186 .55374 L F
.44163 .55525 m .44341 .55757 L .44125 .5552 L F
0 0 0 r
.35282 .6745 m .35146 .67666 L .35133 .67701 L F
.697 .183 0 r
.35133 .67701 m .35146 .67666 L .35261 .67818 L F
.94 .936 .765 r
.3783 .62318 m .37614 .62687 L .37418 .62415 L F
.839 .994 .848 r
.37744 .62255 m .3783 .62318 L .37418 .62415 L F
.231 .626 .956 r
.58555 .38669 m .58916 .38817 L .58802 .38656 L F
0 .181 .716 r
.58916 .38817 m .59074 .38833 L .58802 .38656 L F
.58916 .38817 m .5913 .39011 L .59074 .38833 L F
0 0 .292 r
.22944 .55939 m .22941 .56087 L .22858 .56132 L F
.592 .526 .749 r
.2309 .56471 m .22783 .56172 L .22858 .56132 L F
.2309 .56471 m .22858 .56132 L .22936 .56319 L F
0 0 .292 r
.22941 .56087 m .22936 .56319 L .22858 .56132 L F
.592 .526 .749 r
.22783 .56172 m .22782 .56171 L .22858 .56132 L F
.52 .762 .985 r
.73381 .32658 m .72985 .32566 L .73488 .32355 L F
.105 .199 .679 r
.73511 .32461 m .73381 .32658 L .73488 .32355 L F
.268 .424 .833 r
.73511 .32461 m .73729 .32832 L .73381 .32658 L F
0 0 .464 r
.73655 .32684 m .73729 .32832 L .73511 .32461 L F
.994 .837 .479 r
.7365 .32709 m .73729 .32832 L .73655 .32684 L F
.416 .57 .899 r
.73813 .32964 m .73381 .32658 L .73729 .32832 L F
.994 .837 .479 r
.73603 .32931 m .73729 .32832 L .7365 .32709 L F
.416 .57 .899 r
.73846 .32988 m .73813 .32964 L .73729 .32832 L F
.545 .49 .745 r
.47777 .54448 m .47648 .54927 L .47611 .5487 L F
.956 .773 .615 r
.42824 .57073 m .42721 .56641 L .42862 .57077 L F
.824 .466 0 r
.42764 .56892 m .42862 .57077 L .42721 .56641 L F
.632 .497 .68 r
.42764 .56892 m .42885 .57079 L .42862 .57077 L F
.42885 .57079 m .42945 .57172 L .42862 .57077 L F
.956 .773 .615 r
.42848 .57172 m .42824 .57073 L .42862 .57077 L F
0 0 0 r
.4287 .57124 m .42848 .57172 L .42862 .57077 L F
.4287 .57124 m .42808 .5746 L .42848 .57172 L F
.364 .574 .92 r
.70577 .3106 m .70338 .31095 L .70263 .30871 L F
.898 .933 .83 r
.73517 .33138 m .73846 .32988 L .73729 .32832 L F
.399 .796 .986 r
.45735 .53382 m .46173 .53184 L .45753 .5314 L F
0 .514 .761 r
.45997 .5345 m .45903 .53415 L .45626 .53379 L F
.399 .796 .986 r
.45903 .53415 m .46158 .53462 L .4578 .53391 L F
.006 .427 .861 r
.45997 .5345 m .46158 .53462 L .45903 .53415 L F
.399 .796 .986 r
.46106 .53456 m .46158 .53462 L .45903 .53415 L F
.4578 .53391 m .46158 .53462 L .46173 .53184 L F
.006 .427 .861 r
.45903 .53415 m .46158 .53462 L .4588 .53407 L F
0 .514 .761 r
.45903 .53415 m .459 .53414 L .45893 .53413 L F
.45903 .53415 m .45893 .53413 L .45626 .53379 L F
.459 .53414 m .45842 .53403 L .45626 .53379 L F
.399 .796 .986 r
.45732 .53416 m .46106 .53456 L .4578 .53391 L F
.106 0 0 r
.45626 .53379 m .4588 .53407 L .45732 .53416 L F
.399 .796 .986 r
.45732 .53416 m .4578 .53391 L .45735 .53382 L F
.4578 .53391 m .46173 .53184 L .45735 .53382 L F
0 .514 .761 r
.459 .53414 m .4588 .53407 L .45842 .53403 L F
.006 .427 .861 r
.45997 .5345 m .46253 .53587 L .46158 .53462 L F
.966 .938 .675 r
.6136 .39725 m .61575 .39477 L .61607 .39263 L F
.6136 .39725 m .61466 .39712 L .61575 .39477 L F
0 0 .339 r
.36183 .61851 m .36247 .62014 L .36391 .62309 L F
0 0 .497 r
.44347 .57801 m .44509 .58026 L .44326 .57703 L F
.823 .747 .78 r
.41798 .47325 m .42269 .4716 L .42123 .4706 L F
.41798 .47325 m .4201 .47484 L .42269 .4716 L F
.853 .931 .877 r
.42123 .4706 m .42269 .4716 L .42528 .46862 L F
.558 .588 .84 r
.44376 .58387 m .44509 .58026 L .4466 .58131 L F
.491 .821 1 r
.44509 .58026 m .44919 .58076 L .4466 .58131 L F
.736 .744 .858 r
.42828 .51567 m .4325 .51676 L .43091 .51391 L F
.782 .386 .305 r
.42828 .51567 m .43112 .52041 L .4325 .51676 L F
.865 .496 .003 r
.4325 .51676 m .43177 .51621 L .43091 .51391 L F
.976 .793 .373 r
.4325 .51676 m .43112 .52041 L .43177 .51621 L F
.724 .92 .959 r
.28111 .62143 m .28087 .61965 L .28276 .62022 L F
.28111 .62143 m .27826 .62118 L .28087 .61965 L F
.632 .644 .844 r
.2841 .6221 m .28111 .62143 L .28276 .62022 L F
.564 .925 .943 r
.55809 .41407 m .55399 .41455 L .55688 .41441 L F
.434 .859 .725 r
.56059 .41267 m .55809 .41407 L .55688 .41441 L F
.209 .362 .799 r
.56075 .41532 m .55809 .41407 L .56059 .41267 L F
.602 .42 .609 r
.42955 .53666 m .43043 .5394 L .4277 .53873 L F
.42955 .53666 m .43043 .5394 L .4277 .53873 L F
.559 .397 .617 r
.43265 .53887 m .42955 .53666 L .43078 .53457 L F
.43265 .53887 m .43043 .5394 L .42955 .53666 L F
.613 .412 .585 r
.35446 .60975 m .35183 .61221 L .35253 .61099 L F
.227 .36 .791 r
.33886 .68986 m .34068 .6937 L .34204 .69348 L F
.915 .545 .312 r
.30685 .66062 m .30904 .65972 L .30927 .66202 L F
.84 .667 .668 r
.31187 .65821 m .30927 .66202 L .30904 .65972 L F
.816 .701 .738 r
.53498 .40327 m .53137 .40309 L .53398 .40262 L F
.53498 .40327 m .53295 .40687 L .53137 .40309 L F
.111 .47 .893 r
.53758 .40114 m .53787 .40138 L .53657 .40223 L F
.389 .806 .61 r
.53541 .403 m .53657 .40223 L .53833 .40116 L F
.617 .607 .819 r
.54108 .40243 m .53833 .40116 L .54038 .40012 L F
.764 .507 .545 r
.53657 .40223 m .54038 .40012 L .53833 .40116 L F
.084 0 .264 r
.54108 .40243 m .5412 .40526 L .53885 .40642 L F
.085 .285 .769 r
.54038 .40012 m .54239 .40143 L .54108 .40243 L F
.096 0 .266 r
.54259 .40462 m .5412 .40526 L .54108 .40243 L F
.764 .507 .545 r
.53657 .40223 m .5418 .40251 L .54038 .40012 L F
.5418 .40251 m .54217 .40253 L .54178 .40199 L F
.5418 .40251 m .54178 .40199 L .54038 .40012 L F
.096 0 .266 r
.54259 .40462 m .54187 .40358 L .54239 .40143 L F
.54181 .40334 m .54108 .40243 L .54149 .40212 L F
.54187 .40358 m .54177 .40344 L .54181 .40334 L F
.54177 .40344 m .54108 .40243 L .54181 .40334 L F
.54178 .40199 m .54177 .4019 L .54239 .40143 L F
.109 .286 .762 r
.54038 .40012 m .54178 .40199 L .54239 .40143 L F
.54178 .40199 m .54217 .40253 L .54239 .40143 L F
.833 .883 .451 r
.54239 .40143 m .54217 .40253 L .54199 .40273 L F
.491 0 0 r
.54199 .40273 m .54217 .40253 L .5418 .40251 L F
.096 0 .266 r
.54187 .40358 m .54178 .40199 L .54239 .40143 L F
.54187 .40358 m .54149 .40212 L .5418 .40251 L F
.491 0 0 r
.54098 .40389 m .54199 .40273 L .53657 .40223 L F
.54199 .40273 m .5418 .40251 L .53657 .40223 L F
.833 .883 .451 r
.54239 .40143 m .54199 .40273 L .54098 .40389 L F
.096 0 .266 r
.5418 .40251 m .54149 .40212 L .54177 .4019 L F
.111 .47 .893 r
.53787 .40138 m .54098 .40389 L .53657 .40223 L F
.389 .806 .61 r
.53498 .40327 m .53657 .40223 L .53541 .403 L F
.373 .805 .965 r
.53398 .40262 m .53657 .40223 L .53498 .40327 L F
.87 .903 .852 r
.63408 .39577 m .63245 .39829 L .63121 .39674 L F
.805 .763 .815 r
.37843 .69801 m .37897 .69345 L .37666 .69671 L F
.37843 .69801 m .38101 .69528 L .37897 .69345 L F
.97 .77 .58 r
.37634 .69949 m .37843 .69801 L .37666 .69671 L F
.755 .343 .269 r
.3686 .63227 m .36653 .63261 L .36942 .63242 L F
.664 .972 .823 r
.37197 .62934 m .3686 .63227 L .36942 .63242 L F
0 0 .364 r
.31927 .64413 m .31844 .64301 L .32048 .64161 L F
.31927 .64413 m .31926 .64569 L .31844 .64301 L F
.718 .404 .446 r
.2714 .57515 m .26936 .57808 L .26666 .5766 L F
.987 .716 .389 r
.60365 .44135 m .605 .44516 L .60502 .44249 L F
.062 0 0 r
.27961 .57143 m .28095 .57235 L .28236 .57159 L F
.27961 .57143 m .27802 .57339 L .28095 .57235 L F
.535 .386 .626 r
.2804 .63818 m .28304 .63554 L .28013 .63586 L F
.262 .285 .697 r
.21935 .58759 m .22019 .58328 L .21793 .5838 L F
.21935 .58759 m .22064 .58716 L .22019 .58328 L F
.409 .283 .596 r
.21912 .59024 m .22064 .58716 L .21935 .58759 L F
0 0 0 r
.4277 .53873 m .42562 .53937 L .42342 .54004 L F
.299 0 0 r
.43043 .5394 m .42562 .53937 L .4277 .53873 L F
.89 .976 .824 r
.24534 .60894 m .24449 .61244 L .24713 .61169 L F
.24534 .60894 m .24274 .61222 L .24449 .61244 L F
.462 .403 .705 r
.42315 .52544 m .42122 .52649 L .42007 .52393 L F
.42007 .52393 m .42122 .52649 L .42315 .52544 L F
.721 .777 .897 r
.58957 .37437 m .58628 .37694 L .58526 .37361 L F
.488 .292 .539 r
.38853 .59398 m .38641 .59743 L .38726 .5946 L F
.431 .247 .528 r
.45888 .51322 m .45875 .51646 L .45609 .51704 L F
.44 .273 .557 r
.45875 .51646 m .45914 .51827 L .45609 .51704 L F
.45914 .51827 m .45824 .51891 L .45609 .51704 L F
.45875 .51646 m .45953 .52004 L .45609 .51704 L F
.578 .361 .549 r
.45875 .51646 m .45953 .52004 L .46089 .51563 L F
.45875 .51646 m .45953 .52004 L .46089 .51563 L F
.654 .965 .918 r
.4586 .51703 m .45764 .51843 L .46078 .5171 L F
.46086 .51704 m .46078 .5171 L .46092 .51704 L F
.4586 .51703 m .46078 .5171 L .46086 .51704 L F
.44 .273 .557 r
.45914 .51827 m .45953 .52004 L .45824 .51891 L F
.431 .247 .528 r
.45888 .51322 m .45875 .51646 L .45609 .51704 L F
.744 .426 .445 r
.59132 .45887 m .59459 .45877 L .5945 .46084 L F
.311 .524 .9 r
.59132 .45887 m .5945 .46084 L .59459 .45877 L F
.328 .088 .391 r
.59727 .45786 m .59459 .45877 L .5945 .46084 L F
.516 .769 .988 r
.59727 .45786 m .59459 .45877 L .5945 .46084 L F
.944 .729 .26 r
.39975 .5268 m .39904 .52792 L .39854 .5255 L F
.39975 .5268 m .39968 .52937 L .39904 .52792 L F
.825 .713 .18 r
.34765 .5167 m .34744 .51535 L .34788 .51359 L F
.721 .843 .404 r
.34843 .51208 m .34788 .51359 L .34888 .5114 L F
0 0 0 r
.34787 .50902 m .34734 .50962 L .34954 .50736 L F
0 .18 .7 r
.34673 .51019 m .34788 .51359 L .34843 .51208 L F
.34658 .51033 m .34788 .51359 L .34673 .51019 L F
.34636 .50978 m .34658 .51033 L .34673 .51019 L F
.443 .039 .176 r
.34449 .51129 m .34636 .50978 L .34843 .51208 L F
0 0 0 r
.34734 .50962 m .34591 .51124 L .34799 .50902 L F
.34734 .50962 m .34799 .50902 L .34954 .50736 L F
.34788 .51359 m .34842 .5143 L .34843 .51208 L F
.31 .218 .586 r
.34788 .51359 m .34973 .51608 L .34765 .5167 L F
0 0 0 r
.34788 .51359 m .34744 .51535 L .34842 .5143 L F
0 0 .427 r
.34842 .5143 m .34788 .51359 L .34843 .51208 L F
.34842 .5143 m .34973 .51608 L .34788 .51359 L F
0 0 0 r
.34461 .61978 m .34424 .61998 L .3467 .6174 L F
0 0 .18 r
.34486 .62128 m .34424 .61998 L .34461 .61978 L F
.34486 .62128 m .34435 .62279 L .34424 .61998 L F
0 0 .101 r
.35786 .55727 m .3575 .55867 L .35613 .55501 L F
.993 .75 .392 r
.60332 .40625 m .60438 .4102 L .60343 .40881 L F
.854 .497 0 r
.60343 .40881 m .60438 .4102 L .60489 .4121 L F
.727 .591 .704 r
.3176 .62311 m .31758 .62708 L .31415 .627 L F
.16 .658 .912 r
.55861 .38371 m .56055 .38363 L .56159 .3844 L F
.55861 .38371 m .56055 .38363 L .56159 .3844 L F
.692 .967 .933 r
.56159 .3844 m .56055 .38363 L .56283 .38232 L F
.56283 .38232 m .56055 .38363 L .56159 .3844 L F
.725 .82 .924 r
.71789 .32765 m .72112 .32723 L .71973 .3257 L F
.853 .967 .873 r
.72112 .32723 m .72228 .32411 L .71973 .3257 L F
.557 .932 .826 r
.62562 .34397 m .62887 .34217 L .62964 .34219 L F
0 0 0 r
.63244 .33922 m .62964 .34219 L .63159 .34048 L F
.487 .901 .828 r
.62964 .34219 m .63144 .34082 L .63159 .34048 L F
.62964 .34219 m .62887 .34217 L .63144 .34082 L F
.647 .778 .943 r
.43456 .50303 m .43678 .50476 L .439 .50326 L F
.603 .565 .785 r
.41277 .47344 m .41342 .47719 L .41615 .47467 L F
.995 .761 .416 r
.66941 .3392 m .66927 .34195 L .6681 .3401 L F
0 .468 .751 r
.67116 .33943 m .67292 .34004 L .66941 .3392 L F
.307 0 0 r
.66941 .3392 m .67274 .34035 L .66927 .34195 L F
.66941 .3392 m .67292 .34004 L .67274 .34035 L F
0 .468 .751 r
.67116 .33943 m .66941 .3392 L .6681 .3401 L F
.563 .179 .27 r
.43999 .58613 m .44245 .58654 L .44376 .58387 L F
.558 .588 .84 r
.44376 .58387 m .44635 .58359 L .44509 .58026 L F
.258 0 .122 r
.44376 .58387 m .44502 .58574 L .44635 .58359 L F
.44376 .58387 m .44245 .58654 L .44502 .58574 L F
0 0 0 r
.32606 .49559 m .32486 .49661 L .32372 .49681 L F
.975 .891 .677 r
.39602 .59687 m .39627 .60023 L .39738 .59789 L F
.503 .303 .541 r
.33152 .57805 m .33143 .58075 L .33402 .57753 L F
.78 .959 .644 r
.37933 .62944 m .38123 .62605 L .37863 .62909 L F
.37933 .62944 m .38195 .62592 L .38123 .62605 L F
.813 .889 .899 r
.34793 .64528 m .34661 .64898 L .34581 .64792 L F
.34793 .64528 m .34978 .64658 L .34661 .64898 L F
.489 .34 .605 r
.34661 .64898 m .3484 .65095 L .34774 .65151 L F
.198 .668 .938 r
.32417 .54593 m .32265 .54508 L .32033 .54493 L F
0 .136 .595 r
.32417 .54593 m .32524 .54662 L .32265 .54508 L F
.858 .418 .162 r
.39683 .67329 m .39923 .67454 L .3981 .67233 L F
0 0 0 r
.63386 .35116 m .63783 .34822 L .63707 .35099 L F
.42 .125 .355 r
.63707 .35099 m .63783 .34822 L .64025 .34791 L F
.108 0 0 r
.23498 .55019 m .23344 .54961 L .23333 .54635 L F
.23498 .55019 m .23297 .55137 L .23344 .54961 L F
.647 .172 0 r
.36988 .5533 m .36956 .55239 L .36826 .55233 L F
0 0 0 r
.36988 .5533 m .36826 .55461 L .36993 .55376 L F
.647 .172 0 r
.36988 .5533 m .37175 .55539 L .36983 .55275 L F
.974 .764 .56 r
.37175 .55539 m .37312 .5525 L .36956 .55239 L F
.37175 .55539 m .37306 .55547 L .37312 .5525 L F
.364 .252 .591 r
.37312 .5525 m .37306 .55547 L .37504 .55364 L F
.727 .972 .929 r
.37504 .55364 m .37306 .55547 L .37175 .55539 L F
.37504 .55364 m .37175 .55539 L .37496 .55431 L F
.503 0 0 r
.36988 .5533 m .37496 .55431 L .37175 .55539 L F
0 0 0 r
.36988 .5533 m .36993 .55376 L .37051 .55346 L F
.647 .172 0 r
.36988 .5533 m .36983 .55275 L .36956 .55239 L F
.763 .959 .653 r
.38123 .62605 m .38195 .62592 L .38235 .62461 L F
.839 .922 .889 r
.598 .35176 m .59316 .35344 L .59548 .3522 L F
.47 .88 .741 r
.598 .35176 m .59967 .3505 L .60054 .35029 L F
.479 .893 .794 r
.598 .35176 m .59548 .3522 L .59967 .3505 L F
.808 .825 .864 r
.47523 .43873 m .47603 .44183 L .47238 .44177 L F
.794 .817 .87 r
.47902 .43893 m .47603 .44183 L .47523 .43873 L F
.704 .419 .489 r
.31758 .62708 m .31632 .62803 L .31415 .627 L F
0 0 0 r
.31805 .62698 m .31632 .62803 L .31758 .62708 L F
.267 .348 .762 r
.45463 .52874 m .45626 .53379 L .45753 .5314 L F
.106 0 0 r
.45626 .53379 m .45732 .53416 L .45753 .5314 L F
.785 .81 .873 r
.35548 .68778 m .35145 .68789 L .3537 .6867 L F
.78 .964 .923 r
.35434 .68684 m .35548 .68778 L .3537 .6867 L F
.454 .842 .625 r
.25539 .5259 m .25329 .52742 L .25478 .52639 L F
.578 .303 .463 r
.53116 .47466 m .53367 .47672 L .53116 .47688 L F
.633 .277 .349 r
.53116 .47466 m .5337 .47488 L .53367 .47672 L F
.279 0 0 r
.33708 .64219 m .33927 .64234 L .33486 .64171 L F
.82 .341 0 r
.33884 .6436 m .33927 .64234 L .33708 .64219 L F
.33884 .6436 m .34024 .64384 L .33927 .64234 L F
.635 .669 .865 r
.35434 .69999 m .35881 .70185 L .35713 .69944 L F
.563 .602 .851 r
.35881 .70185 m .35912 .69678 L .35713 .69944 L F
.35881 .70185 m .36102 .70091 L .35912 .69678 L F
.801 .929 .555 r
.29234 .6389 m .294 .63687 L .29467 .63475 L F
.395 0 0 r
.42804 .4812 m .4236 .48307 L .42563 .48275 L F
.42804 .4812 m .42687 .48331 L .4236 .48307 L F
.968 .795 .365 r
.42673 .4812 m .42687 .48331 L .42804 .4812 L F
.42673 .4812 m .42804 .4812 L .42875 .48422 L F
.484 .452 .747 r
.4959 .50295 m .49355 .50319 L .493 .50094 L F
.628 .47 .649 r
.4959 .50295 m .49311 .50619 L .49355 .50319 L F
.811 .48 .429 r
.31653 .65207 m .31908 .65138 L .31841 .65335 L F
.31527 .65121 m .3168 .65128 L .31653 .65207 L F
0 0 0 r
.31662 .6514 m .31704 .64926 L .31763 .6488 L F
.31662 .6514 m .31763 .6488 L .31706 .6505 L F
.791 .597 .639 r
.31805 .64848 m .31908 .65138 L .31662 .6514 L F
.384 .82 .956 r
.31662 .6514 m .31908 .65138 L .31527 .65121 L F
.811 .48 .429 r
.3168 .65128 m .31908 .65138 L .31653 .65207 L F
0 0 0 r
.31706 .6505 m .31763 .6488 L .31805 .64848 L F
.819 .729 .765 r
.38823 .6902 m .39079 .69167 L .39274 .68797 L F
.771 .749 .833 r
.38794 .69292 m .39079 .69167 L .38823 .6902 L F
.693 .364 .415 r
.35133 .67701 m .35475 .67601 L .35282 .6745 L F
.979 .726 .479 r
.28943 .62244 m .29134 .62644 L .29088 .62342 L F
.454 .456 .771 r
.47887 .53504 m .47758 .53953 L .47709 .53494 L F
.47887 .53504 m .4801 .5396 L .47758 .53953 L F
.45 .475 .793 r
.47758 .53953 m .4801 .5396 L .48032 .54113 L F
.572 .441 .664 r
.47758 .53953 m .48032 .54113 L .47808 .54239 L F
.717 .654 .786 r
.36041 .54186 m .36407 .54252 L .3628 .53878 L F
.987 .714 .366 r
.36407 .54252 m .36278 .54139 L .3628 .53878 L F
.998 .808 .526 r
.36407 .54252 m .36229 .54407 L .36278 .54139 L F
.83 .423 .273 r
.36457 .54454 m .36229 .54407 L .36407 .54252 L F
.878 .567 .054 r
.3824 .52984 m .38277 .53214 L .38337 .53222 L F
.664 .155 0 r
.38277 .53214 m .38545 .53473 L .38337 .53222 L F
.683 .225 .159 r
.2837 .64897 m .28651 .64975 L .28402 .65091 L F
.262 0 0 r
.28651 .64975 m .28778 .65102 L .28402 .65091 L F
.28651 .64975 m .2892 .64942 L .28778 .65102 L F
0 0 .204 r
.42821 .57745 m .42808 .5746 L .4287 .57124 L F
.97 .742 .535 r
.27701 .54838 m .2769 .54617 L .27543 .54722 L F
.611 .09 0 r
.28045 .54832 m .27547 .5485 L .278 .54838 L F
.073 .635 .728 r
.278 .54838 m .27595 .54847 L .27411 .54864 L F
.611 .09 0 r
.28045 .54832 m .27838 .54939 L .27547 .5485 L F
.97 .742 .535 r
.27838 .54939 m .27789 .54831 L .27701 .54838 L F
.27789 .54831 m .2769 .54617 L .27701 .54838 L F
.073 .635 .728 r
.27595 .54847 m .27547 .5485 L .2748 .54857 L F
.27595 .54847 m .2748 .54857 L .27411 .54864 L F
0 0 0 r
.63159 .34048 m .63465 .33744 L .63244 .33922 L F
.397 0 0 r
.27024 .54778 m .27411 .54864 L .27382 .54845 L F
0 0 0 r
.27411 .54864 m .27667 .54472 L .27382 .54845 L F
.319 0 0 r
.43781 .52519 m .43693 .52622 L .43384 .52636 L F
0 0 0 r
.44045 .52308 m .43899 .52521 L .43781 .52519 L F
.43899 .52521 m .43693 .52622 L .43781 .52519 L F
0 .184 .711 r
.31747 .53124 m .31991 .53597 L .3199 .53399 L F
.087 .332 .807 r
.31991 .53597 m .32106 .53618 L .3199 .53399 L F
.836 .536 .483 r
.29279 .52769 m .2964 .52643 L .29379 .52731 L F
.29279 .52769 m .29627 .52886 L .2964 .52643 L F
.811 .61 .63 r
.24408 .61877 m .2485 .61609 L .2459 .61603 L F
.24408 .61877 m .24559 .61725 L .2485 .61609 L F
.543 .05 .035 r
.24889 .6181 m .2485 .61609 L .24758 .61646 L F
.24889 .6181 m .24758 .61646 L .24559 .61725 L F
0 .494 .858 r
.24889 .6181 m .24559 .61725 L .24557 .61723 L F
.24889 .6181 m .24557 .61723 L .24683 .61726 L F
.518 .193 .355 r
.2459 .61603 m .24478 .61721 L .24511 .61722 L F
.2459 .61603 m .24244 .61756 L .242 .62015 L F
0 .494 .858 r
.24889 .6181 m .24792 .6177 L .24669 .61679 L F
.24792 .6177 m .24379 .61602 L .24669 .61679 L F
0 .427 .722 r
.24669 .61679 m .24495 .61626 L .2452 .61565 L F
.24495 .61626 m .24292 .61565 L .2452 .61565 L F
0 .494 .858 r
.24683 .61726 m .24557 .61723 L .24379 .61602 L F
.518 .193 .355 r
.24511 .61722 m .242 .62015 L .24408 .61877 L F
.24478 .61721 m .242 .62015 L .24511 .61722 L F
.929 .883 .767 r
.24379 .61602 m .24559 .61725 L .24408 .61877 L F
.593 .505 .725 r
.24408 .61877 m .24079 .61591 L .24264 .61495 L F
.929 .883 .767 r
.24379 .61602 m .24408 .61877 L .24264 .61495 L F
0 .427 .722 r
.24669 .61679 m .24379 .61602 L .24292 .61565 L F
.224 0 0 r
.24245 .61704 m .2452 .61565 L .24292 .61565 L F
.088 .236 .722 r
.24565 .6145 m .2452 .61565 L .24245 .61704 L F
.24629 .61399 m .2452 .61565 L .24565 .6145 L F
.473 0 0 r
.24541 .61584 m .24669 .61679 L .2452 .61565 L F
.2475 .61774 m .24669 .61679 L .24541 .61584 L F
.617 .068 0 r
.24919 .61888 m .24889 .6181 L .24669 .61679 L F
.25078 .62021 m .24889 .6181 L .25013 .61966 L F
.529 .094 .158 r
.25078 .62021 m .25337 .61713 L .24889 .6181 L F
.617 .068 0 r
.25013 .61966 m .24967 .61909 L .24919 .61888 L F
.24967 .61909 m .24889 .6181 L .24919 .61888 L F
.355 0 0 r
.25337 .61713 m .25085 .61663 L .24889 .6181 L F
.617 .068 0 r
.25078 .62021 m .24669 .61679 L .24976 .61853 L F
.838 .982 .873 r
.24745 .61812 m .24976 .61853 L .2475 .61774 L F
.2472 .61994 m .24915 .61886 L .24745 .61812 L F
.24915 .61886 m .24976 .61853 L .24745 .61812 L F
.364 .252 .591 r
.37312 .5525 m .37504 .55364 L .37394 .55165 L F
.303 .302 .692 r
.47751 .56058 m .47638 .56517 L .47622 .56186 L F
.47751 .56058 m .47925 .56306 L .47638 .56517 L F
.093 0 .441 r
.47925 .56306 m .47662 .56791 L .47638 .56517 L F
.756 .266 0 r
.40228 .53281 m .40243 .53418 L .40096 .53156 L F
.40228 .53281 m .40368 .5351 L .40243 .53418 L F
.86 .84 .824 r
.33484 .57011 m .33667 .57149 L .33957 .5682 L F
.637 .464 .633 r
.33667 .57149 m .33992 .57133 L .33957 .5682 L F
.663 .115 0 r
.33957 .5682 m .33978 .56949 L .33743 .56754 L F
.34 .249 .604 r
.33992 .57133 m .3419 .57059 L .33957 .5682 L F
.663 .115 0 r
.33957 .5682 m .3419 .57059 L .33978 .56949 L F
.699 .755 .895 r
.38101 .69528 m .38324 .69398 L .37897 .69345 L F
.524 .606 .877 r
.42528 .46862 m .42911 .47132 L .42755 .46712 L F
.646 .537 .716 r
.42755 .46712 m .42976 .46926 L .43101 .46427 L F
.577 .453 .674 r
.42911 .47132 m .42976 .46926 L .42755 .46712 L F
.792 .754 .818 r
.41798 .47325 m .41615 .47467 L .4201 .47484 L F
.319 0 .232 r
.285 .57165 m .28772 .571 L .28888 .56817 L F
.258 0 .212 r
.28772 .571 m .29124 .56722 L .28888 .56817 L F
.985 .814 .419 r
.73564 .3205 m .73511 .32461 L .73618 .32275 L F
.468 .607 .906 r
.73564 .3205 m .73861 .32083 L .73618 .32275 L F
0 0 0 r
.73511 .32461 m .73861 .32083 L .73618 .32275 L F
.508 .333 .578 r
.43184 .59351 m .43427 .59041 L .4319 .59105 L F
0 0 0 r
.30632 .56364 m .30994 .56137 L .30814 .56231 L F
.522 .34 .574 r
.56559 .38744 m .56595 .39038 L .56825 .38695 L F
.829 .651 .105 r
.3222 .59424 m .32238 .59783 L .32216 .59658 L F
.818 .638 .658 r
.32501 .59702 m .32216 .59658 L .32238 .59783 L F
.32501 .59702 m .32092 .59914 L .32216 .59658 L F
.554 .557 .812 r
.32648 .59359 m .32622 .5942 L .32422 .59358 L F
.32622 .5942 m .32501 .59702 L .32457 .59508 L F
.32622 .5942 m .32457 .59508 L .32422 .59358 L F
.32648 .59359 m .32745 .59645 L .32501 .59702 L F
.482 .898 .889 r
.3279 .59333 m .3259 .59416 L .32648 .59359 L F
.3304 .59287 m .32805 .59354 L .3279 .59333 L F
.32805 .59354 m .3259 .59416 L .3279 .59333 L F
.3304 .59287 m .3281 .5932 L .32677 .59391 L F
.751 .537 .606 r
.3304 .59287 m .32648 .59359 L .32603 .58993 L F
.931 .853 .742 r
.3304 .59287 m .32872 .59455 L .32804 .5932 L F
0 0 .514 r
.32867 .59447 m .32905 .5939 L .32804 .5932 L F
.32872 .59455 m .32872 .59454 L .32867 .59447 L F
.32872 .59454 m .32905 .5939 L .32867 .59447 L F
.482 .898 .889 r
.32677 .59391 m .32804 .5932 L .3259 .59416 L F
.3281 .5932 m .32804 .5932 L .32677 .59391 L F
.4 .129 .383 r
.32216 .59658 m .32342 .59666 L .32422 .59358 L F
.479 .277 .528 r
.32501 .59702 m .3258 .59449 L .32408 .59613 L F
.32408 .5975 m .32408 .59613 L .32092 .59914 L F
.32501 .59702 m .32408 .59613 L .32408 .5975 L F
.4 .129 .383 r
.32342 .59666 m .32408 .59606 L .32422 .59358 L F
.479 .277 .528 r
.3258 .59449 m .32588 .59422 L .32342 .59666 L F
.3258 .59449 m .32342 .59666 L .32092 .59914 L F
.753 .634 .072 r
.32422 .59358 m .32408 .59606 L .32408 .59598 L F
.3242 .59368 m .32408 .59598 L .32407 .59415 L F
.32422 .59358 m .32408 .59598 L .3242 .59368 L F
.4 .129 .383 r
.32342 .59666 m .32404 .5967 L .32408 .59606 L F
.405 .166 .435 r
.32214 .59793 m .32092 .59914 L .32214 .59819 L F
.32216 .59658 m .32214 .59819 L .32404 .5967 L F
.429 .201 .465 r
.32404 .5967 m .32092 .59914 L .32408 .59598 L F
.479 .277 .528 r
.32588 .59422 m .3259 .59416 L .32578 .59432 L F
.32408 .59601 m .32408 .59598 L .32092 .59914 L F
.429 .201 .465 r
.32404 .5967 m .32408 .59598 L .3259 .59416 L F
.753 .634 .072 r
.32407 .59415 m .32404 .5967 L .32402 .59435 L F
.32408 .59606 m .32404 .5967 L .32407 .59415 L F
.405 .166 .435 r
.32216 .59658 m .32092 .59914 L .32214 .59793 L F
.829 .651 .105 r
.32219 .59406 m .3222 .59424 L .32216 .59658 L F
.684 .734 .889 r
.4209 .5006 m .42569 .50272 L .42409 .50069 L F
.799 .826 .872 r
.42409 .50069 m .42569 .50272 L .42804 .50028 L F
.336 .112 .419 r
.42804 .50028 m .42569 .50272 L .42796 .50258 L F
.563 .605 .853 r
.39035 .49666 m .38727 .49456 L .38979 .49362 L F
.724 .661 .787 r
.39427 .49461 m .39035 .49666 L .38979 .49362 L F
.508 .907 .795 r
.60247 .35685 m .60129 .35701 L .59949 .35841 L F
0 0 0 r
.60429 .35617 m .60129 .35701 L .60247 .35685 L F
.798 .639 .685 r
.2821 .64564 m .2837 .64897 L .27984 .64832 L F
.801 .552 .562 r
.27984 .64832 m .2837 .64897 L .28162 .65058 L F
.683 .225 .159 r
.2837 .64897 m .28402 .65091 L .28162 .65058 L F
0 0 0 r
.41645 .48015 m .41859 .4795 L .42022 .47753 L F
.155 0 0 r
.42022 .47753 m .42046 .47896 L .42249 .47687 L F
.42022 .47753 m .41859 .4795 L .42046 .47896 L F
.983 .714 .432 r
.59214 .40997 m .59064 .40617 L .59091 .40877 L F
.883 .48 .038 r
.5928 .41222 m .59214 .40997 L .59091 .40877 L F
.587 .636 .867 r
.35475 .67601 m .35727 .67872 L .35911 .67755 L F
.35475 .67601 m .35727 .67872 L .35911 .67755 L F
.742 .743 .853 r
.32161 .51983 m .32281 .52312 L .31866 .52259 L F
.591 .477 .692 r
.31866 .52259 m .32091 .52338 L .32097 .52305 L F
.283 0 0 r
.32281 .52312 m .32097 .52305 L .31961 .52271 L F
.088 .306 .786 r
.32353 .52134 m .32281 .52312 L .32161 .51983 L F
0 0 0 r
.32125 .52312 m .32144 .52324 L .32353 .52134 L F
.32091 .52338 m .32144 .52324 L .32125 .52312 L F
.283 0 0 r
.32281 .52312 m .32177 .52321 L .32122 .5231 L F
.32115 .52306 m .32122 .5231 L .32097 .52305 L F
.32281 .52312 m .32122 .5231 L .32115 .52306 L F
.31961 .52271 m .32097 .52305 L .31866 .52259 L F
.446 .34 .64 r
.32161 .51983 m .32097 .52305 L .32353 .52134 L F
.32097 .52305 m .32091 .52338 L .32125 .52312 L F
.32097 .52305 m .32125 .52312 L .32353 .52134 L F
.591 .477 .692 r
.31866 .52259 m .32097 .52305 L .32161 .51983 L F
.283 0 0 r
.32177 .52321 m .32144 .52324 L .31866 .52259 L F
.942 .801 .675 r
.3297 .56509 m .33067 .56811 L .33268 .56831 L F
.33268 .56831 m .33067 .56811 L .3297 .56509 L F
.735 .991 .837 r
.32353 .52134 m .32144 .52324 L .32281 .52312 L F
.656 .937 .966 r
.33268 .56831 m .33356 .56677 L .33526 .56503 L F
.33268 .56831 m .33067 .56811 L .33356 .56677 L F
.125 .27 .742 r
.33268 .56831 m .33356 .56677 L .33067 .56811 L F
.33268 .56831 m .33484 .57011 L .33356 .56677 L F
.536 .925 .844 r
.67486 .32333 m .67613 .3233 L .67844 .32189 L F
.819 .729 .765 r
.38823 .6902 m .39274 .68797 L .38869 .68766 L F
.044 .314 .801 r
.28484 .62124 m .2841 .6221 L .28276 .62022 L F
0 0 0 r
.28484 .62124 m .28287 .62515 L .2841 .6221 L F
.682 .968 .927 r
.57859 .46203 m .5817 .45995 L .57711 .46057 L F
.57859 .46203 m .58205 .46022 L .5817 .45995 L F
0 0 .253 r
.27903 .64137 m .27797 .64257 L .2779 .64528 L F
.72 .193 0 r
.70318 .29393 m .6994 .29071 L .69912 .29338 L F
.294 0 0 r
.70231 .29421 m .70318 .29393 L .69912 .29338 L F
.897 .732 .227 r
.41192 .57299 m .41224 .57798 L .41056 .57693 L F
.98 .716 .321 r
.41224 .57798 m .41125 .57951 L .41056 .57693 L F
.41224 .57798 m .41233 .58072 L .41125 .57951 L F
.545 .49 .745 r
.47777 .54448 m .47895 .54856 L .47648 .54927 L F
.494 0 0 r
.38727 .65723 m .38955 .65932 L .38783 .65776 L F
.585 .795 .979 r
.38955 .65932 m .39212 .65834 L .38783 .65776 L F
0 0 .121 r
.3502 .57405 m .35224 .57072 L .34965 .57093 L F
.3502 .57405 m .35172 .57317 L .35224 .57072 L F
.601 .441 .637 r
.34916 .57645 m .35172 .57317 L .3502 .57405 L F
0 .359 .772 r
.46411 .54003 m .46718 .54148 L .46565 .54034 L F
0 .132 .665 r
.67934 .35922 m .68081 .36134 L .68096 .35855 L F
.705 .395 .45 r
.35805 .55424 m .36276 .55182 L .35951 .55201 L F
.35805 .55424 m .362 .55449 L .36276 .55182 L F
.546 .417 .656 r
.36276 .55182 m .36531 .55154 L .36483 .54893 L F
.471 .168 .37 r
.36276 .55182 m .36485 .55393 L .36531 .55154 L F
.36276 .55182 m .362 .55449 L .36485 .55393 L F
.601 .9 .986 r
.4432 .52177 m .44085 .52106 L .44045 .52308 L F
.226 0 0 r
.44164 .52442 m .44045 .52308 L .44085 .52106 L F
.44164 .52442 m .43899 .52521 L .44045 .52308 L F
0 0 .282 r
.41167 .5946 m .41237 .59683 L .41134 .59308 L F
.602 .667 .885 r
.70374 .26537 m .70389 .26789 L .70028 .26658 L F
.70374 .26537 m .70028 .26658 L .7001 .26683 L F
.295 .778 .694 r
.70261 .2658 m .70374 .26537 L .7001 .26683 L F
.886 .88 .823 r
.70169 .27129 m .70261 .2658 L .7001 .26683 L F
.70169 .27129 m .70389 .26789 L .70261 .2658 L F
.812 .468 0 r
.23466 .59521 m .23478 .594 L .23526 .59283 L F
.503 .808 1 r
.60542 .37313 m .60627 .37432 L .60257 .37388 L F
.875 .966 .851 r
.34493 .54865 m .34408 .54821 L .34668 .54498 L F
.658 .766 .288 r
.22493 .54906 m .2253 .54818 L .22647 .54548 L F
0 0 .212 r
.22493 .54906 m .22542 .55063 L .2253 .54818 L F
.22493 .54906 m .22426 .55182 L .22542 .55063 L F
.496 .17 .344 r
.5244 .47993 m .52466 .47791 L .52707 .47962 L F
.506 .164 .321 r
.52466 .47791 m .52732 .47771 L .52707 .47962 L F
0 0 .569 r
.22621 .60359 m .22624 .60256 L .2243 .60007 L F
.032 .469 .879 r
.22621 .60359 m .22819 .60438 L .22624 .60256 L F
0 .185 .713 r
.57961 .39125 m .58051 .39318 L .57941 .39188 L F
.002 .369 .837 r
.58085 .39214 m .58051 .39318 L .57961 .39125 L F
.013 .383 .845 r
.5821 .39369 m .58051 .39318 L .58085 .39214 L F
.957 .928 .729 r
.37418 .62415 m .37614 .62687 L .37483 .62623 L F
.555 .688 .928 r
.62921 .39227 m .62768 .39481 L .62654 .39299 L F
.62921 .39227 m .62957 .39442 L .62768 .39481 L F
.62921 .39227 m .62768 .39481 L .62654 .39299 L F
.62921 .39227 m .62957 .39442 L .62768 .39481 L F
.346 .548 .907 r
.40878 .4875 m .41005 .4885 L .41406 .48436 L F
.40875 .48761 m .40718 .48739 L .41005 .4885 L F
.762 .672 .762 r
.40867 .48784 m .40875 .48761 L .40718 .48739 L F
.40875 .48761 m .40878 .4875 L .40718 .48739 L F
.346 .548 .907 r
.40868 .48756 m .40718 .48739 L .40875 .48761 L F
.40868 .48756 m .40875 .48761 L .40878 .4875 L F
.40875 .48761 m .41005 .4885 L .40878 .4875 L F
.762 .672 .762 r
.41075 .48848 m .40881 .4875 L .40878 .4875 L F
.41075 .48848 m .40878 .4875 L .40867 .48784 L F
.763 .517 .561 r
.40885 .48753 m .41075 .48848 L .40868 .48756 L F
.41471 .4863 m .41075 .48848 L .40885 .48753 L F
.762 .672 .762 r
.41075 .48848 m .41032 .48761 L .40881 .4875 L F
.395 0 .056 r
.40718 .48739 m .40878 .4875 L .41406 .48436 L F
.765 .638 .72 r
.41471 .4863 m .40885 .48753 L .41292 .48268 L F
.40885 .48753 m .40868 .48756 L .40879 .48743 L F
.40885 .48753 m .40879 .48743 L .41292 .48268 L F
.892 .894 .823 r
.41292 .48268 m .40879 .48743 L .40894 .48477 L F
.762 .672 .762 r
.40883 .4867 m .40894 .48477 L .40799 .48618 L F
.41032 .48761 m .40799 .48618 L .40884 .48751 L F
.892 .894 .823 r
.40879 .48743 m .40868 .48756 L .40894 .48477 L F
.762 .672 .762 r
.40952 .48595 m .40894 .48477 L .40884 .48653 L F
.40884 .48751 m .40799 .48618 L .40718 .48739 L F
.395 0 .056 r
.40718 .48739 m .40868 .48756 L .40878 .4875 L F
.922 .946 .795 r
.40753 .48972 m .41005 .4885 L .40718 .48739 L F
.259 .604 .953 r
.40411 .48595 m .40718 .48739 L .4056 .48754 L F
.551 .061 0 r
.40624 .48837 m .40753 .48972 L .4056 .48754 L F
.407 .465 .808 r
.40894 .48477 m .40868 .48756 L .40718 .48739 L F
.346 .548 .907 r
.40868 .48756 m .41075 .48848 L .40718 .48739 L F
.766 .677 .765 r
.40894 .48477 m .40624 .48837 L .40868 .48667 L F
.762 .672 .762 r
.40878 .48658 m .40624 .48837 L .40952 .48595 L F
.82 .943 .905 r
.40868 .48667 m .40624 .48837 L .40865 .48668 L F
.40868 .48667 m .40865 .48668 L .40868 .48667 L F
.762 .672 .762 r
.40668 .48838 m .40624 .48837 L .40865 .48668 L F
.463 .817 .541 r
.40868 .48667 m .40871 .48664 L .40894 .48477 L F
.762 .672 .762 r
.40871 .48664 m .40871 .48663 L .40878 .48658 L F
.40952 .48595 m .40848 .48672 L .40894 .48477 L F
.463 .817 .541 r
.40871 .48664 m .4115 .48426 L .40894 .48477 L F
.762 .672 .762 r
.40868 .48667 m .40865 .48668 L .40871 .48663 L F
.40868 .48667 m .40871 .48663 L .40871 .48664 L F
.433 .856 .716 r
.40868 .48667 m .40759 .48698 L .40981 .48569 L F
.40868 .48667 m .40868 .48667 L .40868 .48667 L F
.762 .672 .762 r
.40868 .48667 m .40865 .48668 L .40868 .48667 L F
.40848 .48672 m .40624 .48837 L .40726 .48701 L F
.692 .79 .926 r
.4056 .48754 m .40147 .48701 L .40411 .48595 L F
.551 .061 0 r
.40624 .48837 m .4056 .48754 L .40545 .48738 L F
.40541 .48743 m .40545 .48738 L .40411 .48595 L F
.40624 .48837 m .40545 .48738 L .40541 .48743 L F
.735 .225 .007 r
.40311 .48739 m .40624 .48837 L .40411 .48595 L F
.667 .121 0 r
.40328 .48799 m .40624 .48837 L .40311 .48739 L F
.82 .943 .905 r
.40865 .48668 m .40624 .48837 L .40328 .48799 L F
.762 .672 .762 r
.40668 .48838 m .40865 .48668 L .40868 .48667 L F
.82 .943 .905 r
.40868 .48667 m .40865 .48668 L .40865 .48668 L F
.40865 .48668 m .40538 .48748 L .40865 .48668 L F
.40865 .48668 m .40538 .48748 L .40759 .48698 L F
.40538 .48748 m .40328 .48799 L .40536 .4875 L F
.40538 .48748 m .40536 .4875 L .40759 .48698 L F
.433 .856 .716 r
.40868 .48667 m .40759 .48698 L .40868 .48667 L F
.762 .672 .762 r
.40868 .48667 m .40868 .48667 L .40868 .48667 L F
.82 .943 .905 r
.40865 .48668 m .40328 .48799 L .40868 .48667 L F
.762 .672 .762 r
.40848 .48672 m .40726 .48701 L .40894 .48477 L F
.463 .817 .541 r
.40868 .48667 m .40868 .48667 L .4087 .48665 L F
.762 .672 .762 r
.41032 .48761 m .40952 .48595 L .40883 .4867 L F
.40952 .48595 m .40884 .48653 L .40883 .4867 L F
.41075 .48848 m .40668 .48838 L .40952 .48595 L F
.351 .819 .747 r
.40981 .48569 m .40642 .48675 L .41032 .48524 L F
.463 .817 .541 r
.40918 .48624 m .40981 .48569 L .41121 .4845 L F
.40868 .48667 m .41121 .4845 L .41015 .48541 L F
.41015 .48541 m .41121 .4845 L .4115 .48426 L F
.765 .638 .72 r
.41471 .4863 m .41292 .48268 L .41477 .48403 L F
.409 0 0 r
.41419 .48434 m .41409 .48519 L .41445 .48435 L F
.4115 .48426 m .41409 .48519 L .41419 .48434 L F
.828 .537 .497 r
.4126 .48442 m .414 .48585 L .41409 .48519 L F
.898 .96 .826 r
.41863 .48637 m .41472 .4889 L .41471 .4863 L F
.763 .517 .561 r
.41471 .4863 m .41472 .4889 L .41075 .48848 L F
.165 .243 .699 r
.41291 .49074 m .41075 .48848 L .41472 .4889 L F
0 .207 .733 r
.41472 .4889 m .41507 .48684 L .41291 .49074 L F
.648 .118 0 r
.41871 .49248 m .41575 .49015 L .41608 .49344 L F
.742 .754 .862 r
.41608 .49344 m .4206 .49425 L .41871 .49248 L F
.648 .118 0 r
.41871 .49248 m .41818 .49239 L .41472 .4889 L F
.742 .758 .865 r
.41534 .48707 m .41821 .49219 L .41953 .49063 L F
.41507 .48684 m .41524 .48713 L .41534 .48707 L F
.41524 .48713 m .41821 .49219 L .41534 .48707 L F
0 .207 .733 r
.41472 .4889 m .41818 .49239 L .41507 .48684 L F
.973 .717 .486 r
.41871 .49248 m .41812 .49282 L .41818 .49239 L F
.648 .118 0 r
.41871 .49248 m .41853 .49274 L .41818 .49239 L F
0 .207 .733 r
.41818 .49239 m .41853 .49274 L .41821 .49219 L F
.41818 .49239 m .41821 .49219 L .41507 .48684 L F
.973 .717 .486 r
.41818 .49239 m .41729 .49329 L .41807 .49237 L F
.41812 .49282 m .41729 .49329 L .41818 .49239 L F
.789 .758 .825 r
.41953 .49063 m .41686 .49353 L .41507 .48684 L F
.458 .161 .373 r
.41673 .48633 m .41635 .48823 L .41833 .48743 L F
.41648 .48615 m .41646 .48647 L .41673 .48633 L F
.41646 .48647 m .41635 .48823 L .41673 .48633 L F
.973 .717 .486 r
.41871 .49248 m .41795 .49235 L .41953 .49063 L F
.742 .758 .865 r
.41821 .49219 m .41853 .49274 L .41953 .49063 L F
.973 .717 .486 r
.41807 .49237 m .41686 .49353 L .41795 .49235 L F
.41729 .49329 m .41686 .49353 L .41807 .49237 L F
.738 .44 .477 r
.41159 .49289 m .41608 .49344 L .41575 .49015 L F
.663 .606 .78 r
.41686 .49353 m .41291 .49074 L .41507 .48684 L F
.828 .537 .497 r
.414 .48585 m .41635 .48823 L .41409 .48519 L F
0 0 0 r
.4115 .48426 m .4126 .48442 L .41409 .48519 L F
.4115 .48426 m .40981 .48569 L .4126 .48442 L F
.351 .819 .747 r
.40981 .48569 m .41032 .48524 L .41128 .48487 L F
.463 .817 .541 r
.4087 .48665 m .40981 .48569 L .40918 .48624 L F
.40868 .48667 m .40981 .48569 L .4087 .48665 L F
.962 .668 .428 r
.34765 .5167 m .34545 .51767 L .34744 .51535 L F
.34765 .5167 m .34755 .51901 L .34545 .51767 L F
.566 .305 .479 r
.35054 .51821 m .34765 .5167 L .34973 .51608 L F
.35054 .51821 m .34755 .51901 L .34765 .5167 L F
.979 .687 .323 r
.5759 .3743 m .57602 .37698 L .57452 .37293 L F
.769 .87 .922 r
.57673 .37081 m .5759 .3743 L .57452 .37293 L F
.57673 .37081 m .57863 .37225 L .5759 .3743 L F
.963 .829 .663 r
.56111 .42663 m .5608 .42986 L .55855 .42779 L F
.92 .533 .141 r
.55855 .42779 m .5608 .42986 L .56093 .43149 L F
.809 .573 .581 r
.56394 .42985 m .56093 .43149 L .5608 .42986 L F
.213 .729 .7 r
.60054 .35029 m .59967 .3505 L .6024 .3497 L F
.846 .63 .609 r
.59967 .3505 m .59555 .3518 L .59887 .35023 L F
.59967 .3505 m .59548 .3522 L .59555 .3518 L F
.612 .14 .109 r
.59887 .35023 m .6024 .3497 L .59967 .3505 L F
.59887 .35023 m .5991 .3516 L .6024 .3497 L F
.632 .946 .736 r
.6024 .3497 m .5991 .3516 L .60133 .34982 L F
.6024 .3497 m .60133 .34982 L .60357 .34802 L F
.213 .729 .7 r
.60356 .34958 m .6024 .3497 L .60375 .34954 L F
.60054 .35029 m .6024 .3497 L .60356 .34958 L F
.291 .787 .773 r
.6024 .3497 m .60668 .3487 L .60375 .34954 L F
.4 .849 .914 r
.60375 .34954 m .60668 .3487 L .60744 .34878 L F
.722 .314 .274 r
.37317 .59714 m .371 .5991 L .37116 .59638 L F
.37317 .59714 m .37512 .59957 L .371 .5991 L F
0 .152 .664 r
.30801 .65317 m .30678 .65261 L .3069 .65077 L F
.30801 .65317 m .30935 .65472 L .30678 .65261 L F
.56 .887 .625 r
.67032 .31319 m .669 .31405 L .6721 .31132 L F
.862 .758 .746 r
.52909 .40453 m .52835 .40687 L .52482 .40591 L F
.875 .728 .696 r
.52835 .40687 m .52638 .40987 L .52482 .40591 L F
.988 .78 .388 r
.41182 .58775 m .41041 .58887 L .41111 .58596 L F
.41182 .58775 m .41163 .59049 L .41041 .58887 L F
.434 .626 .934 r
.70598 .2793 m .70286 .27954 L .70151 .27678 L F
.884 .642 .121 r
.4079 .54903 m .40759 .55047 L .40761 .54779 L F
.4079 .54903 m .40813 .55196 L .40759 .55047 L F
.144 0 0 r
.38174 .67421 m .38601 .67439 L .38135 .67438 L F
.651 .867 .492 r
.42282 .59716 m .42039 .60055 L .42132 .59895 L F
.208 0 .325 r
.42258 .6003 m .42039 .60055 L .42282 .59716 L F
.264 .278 .688 r
.42258 .6003 m .42282 .60273 L .42039 .60055 L F
.053 .241 .738 r
.42039 .60055 m .42282 .60273 L .42132 .59895 L F
.325 .13 .454 r
.36041 .54186 m .36063 .54605 L .35732 .54701 L F
0 0 0 r
.62587 .42422 m .62355 .42522 L .62621 .42397 L F
.62587 .42422 m .62383 .42552 L .62355 .42522 L F
.798 .985 .723 r
.36478 .6419 m .36223 .64502 L .36338 .64349 L F
.484 .452 .747 r
.4959 .50295 m .493 .50094 L .4957 .50021 L F
.524 .743 .975 r
.58205 .46022 m .58267 .45723 L .5817 .45995 L F
.58205 .46022 m .58465 .4598 L .58267 .45723 L F
.649 .859 .979 r
.38979 .49362 m .38727 .49456 L .38553 .49322 L F
.571 .938 .827 r
.57038 .46297 m .5722 .46254 L .57466 .46103 L F
0 0 .432 r
.34118 .63319 m .34229 .63398 L .34388 .63141 L F
.34118 .63319 m .34236 .6357 L .34229 .63398 L F
.937 .954 .637 r
.70616 .34162 m .70735 .33956 L .70742 .33681 L F
.607 .839 .988 r
.4068 .48839 m .40753 .48972 L .40624 .48837 L F
.922 .946 .795 r
.40753 .48972 m .40836 .49124 L .41005 .4885 L F
.607 .839 .988 r
.41075 .48848 m .40753 .48972 L .4068 .48839 L F
.922 .946 .795 r
.40753 .48972 m .40821 .49148 L .40836 .49124 L F
.675 .762 .275 r
.40784 .49232 m .40821 .49148 L .40753 .48972 L F
.40784 .49232 m .40725 .4939 L .40821 .49148 L F
0 0 .225 r
.41057 .56391 m .41039 .56334 L .4094 .56037 L F
0 0 .289 r
.41057 .56391 m .41196 .5672 L .41039 .56334 L F
.663 .522 .682 r
.71404 .31309 m .71128 .31582 L .7113 .3139 L F
.654 .86 .978 r
.35217 .6454 m .34978 .64658 L .34793 .64528 L F
.696 .982 .832 r
.65132 .3967 m .65468 .39427 L .65258 .39479 L F
.723 .989 .832 r
.65258 .39479 m .65468 .39427 L .65641 .3924 L F
.892 .504 .055 r
.39774 .52277 m .39726 .52418 L .39583 .52157 L F
.39774 .52277 m .39854 .5255 L .39726 .52418 L F
.741 .548 .633 r
.33356 .56677 m .33706 .56505 L .33526 .56503 L F
.519 .258 .459 r
.33659 .57431 m .33992 .57133 L .33667 .57149 L F
.828 .373 .14 r
.36255 .5083 m .3659 .51073 L .36411 .50949 L F
0 0 0 r
.21984 .56167 m .21753 .56503 L .2191 .56346 L F
0 0 .355 r
.21753 .56503 m .21886 .566 L .2191 .56346 L F
.21753 .56503 m .21756 .56773 L .21886 .566 L F
.553 .329 .53 r
.44601 .56518 m .44891 .56482 L .44897 .5618 L F
.611 .376 .537 r
.44897 .5618 m .44891 .56482 L .45027 .56441 L F
.785 .712 .783 r
.28106 .63186 m .28612 .63293 L .28679 .63094 L F
.813 .532 .514 r
.28567 .63542 m .28612 .63293 L .28106 .63186 L F
.737 .657 .771 r
.28679 .63094 m .28612 .63293 L .28843 .62937 L F
.719 .282 .213 r
.29008 .63494 m .28612 .63293 L .28567 .63542 L F
.718 .784 .905 r
.49571 .42792 m .49745 .42961 L .4934 .42912 L F
.79 .795 .857 r
.50104 .42681 m .49745 .42961 L .49571 .42792 L F
.727 .301 .236 r
.31902 .62962 m .31415 .627 L .31632 .62803 L F
.524 .605 .877 r
.38532 .69014 m .38794 .69292 L .38823 .6902 L F
.614 .759 .948 r
.63705 .39072 m .63277 .38995 L .63471 .38874 L F
.312 .045 .338 r
.6343 .39418 m .63705 .39072 L .63709 .39349 L F
.674 .722 .885 r
.63865 .38716 m .63705 .39072 L .63471 .38874 L F
.63865 .38716 m .6377 .39069 L .63705 .39072 L F
0 0 0 r
.67315 .31013 m .67486 .30808 L .67578 .30689 L F
.67578 .30689 m .67621 .30635 L .67798 .30565 L F
.67578 .30689 m .67486 .30808 L .67621 .30635 L F
.502 .608 .891 r
.53295 .40687 m .52909 .40453 L .53137 .40309 L F
.993 .773 .498 r
.7432 .31434 m .74485 .3133 L .74395 .31187 L F
.7432 .31434 m .74457 .31584 L .74485 .3133 L F
.93 .907 .778 r
.51273 .4147 m .51416 .41609 L .51187 .41959 L F
.784 .91 .927 r
.51738 .41356 m .51416 .41609 L .51273 .4147 L F
.421 .5 .835 r
.39859 .47907 m .39738 .48189 L .39617 .47931 L F
.534 .923 .835 r
.68284 .37595 m .68695 .37432 L .68653 .37416 L F
.499 .887 .711 r
.68695 .37432 m .69048 .37203 L .68883 .37278 L F
.524 .917 .823 r
.68653 .37416 m .68695 .37432 L .68883 .37278 L F
.066 .249 .741 r
.70102 .30229 m .7023 .30604 L .70141 .30494 L F
.8 .995 .867 r
.33931 .60873 m .33907 .61056 L .33964 .60944 L F
.224 0 .278 r
.34001 .61207 m .33907 .61056 L .33931 .60873 L F
.34001 .61207 m .33806 .61278 L .33907 .61056 L F
.857 .517 .001 r
.59486 .41916 m .59441 .41719 L .59316 .41491 L F
0 0 0 r
.31348 .6347 m .31687 .6333 L .31462 .63492 L F
.76 .355 .285 r
.31687 .6333 m .31839 .63529 L .31458 .63494 L F
.79 .55 .574 r
.31708 .63349 m .31632 .62803 L .3146 .63176 L F
.826 .712 .739 r
.31481 .63574 m .31839 .63529 L .31527 .63737 L F
.31546 .6351 m .31839 .63529 L .31481 .63574 L F
.31463 .63495 m .31839 .63529 L .31462 .63505 L F
0 0 .454 r
.31708 .63349 m .31839 .63529 L .31687 .6333 L F
.595 .51 .728 r
.32135 .63172 m .31839 .63529 L .31708 .63349 L F
.049 0 0 r
.31907 .6336 m .31712 .63349 L .31602 .63581 L F
.31712 .63349 m .31708 .63349 L .31704 .63357 L F
.31712 .63349 m .31704 .63357 L .31602 .63581 L F
.826 .712 .739 r
.31462 .63505 m .31546 .6351 L .31481 .63574 L F
.31458 .63494 m .31463 .63495 L .31462 .63505 L F
.83 .443 .32 r
.31602 .63581 m .31708 .63349 L .3146 .63176 L F
.168 .094 .522 r
.31607 .63032 m .31603 .63518 L .31502 .63277 L F
.31533 .63104 m .31502 .63277 L .3146 .63176 L F
.31607 .63032 m .31502 .63277 L .31533 .63104 L F
.31603 .63518 m .31602 .63581 L .31579 .63514 L F
.31603 .63518 m .31579 .63514 L .3146 .63176 L F
0 0 0 r
.31234 .63517 m .31348 .6347 L .31458 .63494 L F
.31348 .6347 m .31462 .63492 L .31458 .63494 L F
.862 .758 .746 r
.52909 .40453 m .52482 .40591 L .5275 .40388 L F
.671 .951 .954 r
.53137 .40309 m .52909 .40453 L .5275 .40388 L F
.017 0 0 r
.4375 .47874 m .43634 .47986 L .43428 .48027 L F
.012 0 0 r
.44011 .47904 m .43634 .47986 L .4375 .47874 L F
.654 .581 .761 r
.3338 .54567 m .33593 .54184 L .33366 .54239 L F
.418 .057 .242 r
.28693 .53452 m .28738 .53587 L .28439 .53637 L F
.284 .232 .621 r
.28884 .53051 m .28693 .53452 L .28726 .53303 L F
.28884 .53051 m .28968 .53467 L .28693 .53452 L F
.277 0 .276 r
.28968 .53467 m .28738 .53587 L .28693 .53452 L F
.816 .97 .9 r
.64103 .38595 m .6377 .39069 L .63865 .38716 L F
.64103 .38595 m .64238 .38669 L .6377 .39069 L F
.788 .836 .889 r
.64191 .38794 m .6377 .39069 L .64238 .38669 L F
.391 .851 .837 r
.34755 .65216 m .35055 .65135 L .3484 .65095 L F
.409 .806 .985 r
.3484 .65095 m .35055 .65135 L .35191 .65062 L F
.84 .667 .668 r
.31187 .65821 m .31262 .6618 L .30927 .66202 L F
.575 .738 .953 r
.31229 .66419 m .30927 .66202 L .31262 .6618 L F
.346 .338 .707 r
.31466 .66061 m .31262 .6618 L .31187 .65821 L F
.156 0 .367 r
.31229 .66419 m .31262 .6618 L .31466 .66061 L F
0 0 0 r
.66916 .37093 m .66693 .37369 L .66915 .37114 L F
.66916 .37093 m .66915 .37114 L .67143 .36971 L F
.47 .786 .999 r
.57086 .38647 m .57213 .38771 L .56825 .38695 L F
.418 .701 .98 r
.57322 .38596 m .57213 .38771 L .57086 .38647 L F
.57322 .38596 m .57471 .38757 L .57213 .38771 L F
.641 .315 .405 r
.5337 .47488 m .53766 .47452 L .5374 .47659 L F
.57 .253 .392 r
.53766 .47452 m .5403 .47634 L .5374 .47659 L F
.62 .193 .21 r
.53766 .47452 m .5405 .47489 L .5403 .47634 L F
.954 .732 .563 r
.60471 .45051 m .60683 .44896 L .60465 .448 L F
.60471 .45051 m .6065 .45161 L .60683 .44896 L F
.561 0 0 r
.26055 .62617 m .26381 .62713 L .26486 .62812 L F
.605 .828 .985 r
.38009 .57686 m .38204 .57831 L .38419 .5773 L F
.38009 .57686 m .38204 .57831 L .38419 .5773 L F
.935 .63 .438 r
.42814 .52879 m .42686 .53112 L .42921 .53178 L F
.42814 .52879 m .42686 .53112 L .42921 .53178 L F
0 0 0 r
.42946 .52768 m .42686 .53112 L .42814 .52879 L F
.881 .776 .278 r
.69881 .29197 m .69912 .29338 L .6994 .29071 L F
.957 .949 .69 r
.6994 .29071 m .70049 .28593 L .699 .28933 L F
.915 .753 .264 r
.69881 .29197 m .6994 .29071 L .699 .28933 L F
.74 .664 .775 r
.56612 .42265 m .56353 .42331 L .56623 .42004 L F
.653 .51 .676 r
.56845 .41943 m .56612 .42265 L .56623 .42004 L F
.56845 .41943 m .57018 .42263 L .56612 .42265 L F
0 0 0 r
.57018 .42263 m .56686 .42645 L .56612 .42265 L F
.844 .705 .709 r
.60588 .45461 m .60791 .45531 L .6065 .45161 L F
.863 .639 .598 r
.60773 .45823 m .60791 .45531 L .60588 .45461 L F
.687 .576 .725 r
.48387 .50944 m .48138 .51303 L .4813 .51013 L F
.767 .802 .881 r
.53105 .41052 m .53603 .40986 L .53548 .41108 L F
0 0 0 r
.53832 .40811 m .53603 .40986 L .53885 .40642 L F
.82 .752 .789 r
.53832 .40811 m .53548 .41108 L .53603 .40986 L F
.575 .332 .51 r
.49898 .49739 m .49859 .49992 L .4957 .50021 L F
.458 .228 .477 r
.50103 .49922 m .49898 .49739 L .50105 .49643 L F
.50103 .49922 m .49859 .49992 L .49898 .49739 L F
.968 .645 .3 r
.37812 .52421 m .37945 .52313 L .37636 .52122 L F
.37812 .52421 m .3796 .5254 L .37945 .52313 L F
.477 .737 .984 r
.2844 .51773 m .28466 .51524 L .28214 .51618 L F
.2844 .51773 m .28705 .51729 L .28466 .51524 L F
.137 .683 .733 r
.29049 .57431 m .28844 .57452 L .28628 .57492 L F
.572 .009 0 r
.29287 .57486 m .28844 .57452 L .29049 .57431 L F
0 0 0 r
.64783 .39912 m .65132 .3967 L .65 .39712 L F
.692 .968 .75 r
.65 .39712 m .65132 .3967 L .65258 .39479 L F
.811 .997 .854 r
.33153 .49442 m .33292 .49515 L .33061 .49713 L F
.659 .959 .753 r
.31075 .62293 m .30674 .62576 L .30917 .62488 L F
0 0 0 r
.31075 .62293 m .31048 .62381 L .31282 .62169 L F
.31075 .62293 m .30917 .62488 L .31048 .62381 L F
.49 .488 .782 r
.36444 .68994 m .36635 .6947 L .36335 .69441 L F
0 0 0 r
.42109 .58273 m .42018 .58472 L .42126 .5818 L F
.134 .311 .778 r
.42109 .58273 m .42254 .5866 L .42018 .58472 L F
.698 .159 0 r
.6139 .39794 m .61466 .39712 L .6136 .39725 L F
.946 .644 .198 r
.61496 .39957 m .61466 .39712 L .6139 .39794 L F
.163 .584 .935 r
.61995 .40413 m .61607 .40357 L .61453 .40229 L F
0 .355 .793 r
.62231 .40711 m .61607 .40357 L .61995 .40413 L F
.915 .887 .468 r
.69871 .2936 m .69912 .29338 L .69881 .29197 L F
.74 .931 .589 r
.69871 .2936 m .69912 .29338 L .69674 .2965 L F
.69871 .2936 m .69912 .29338 L .69674 .2965 L F
.294 0 0 r
.70231 .29421 m .69912 .29338 L .69871 .2936 L F
.429 .28 .576 r
.34841 .59993 m .34863 .60264 L .34631 .6005 L F
.592 .265 .384 r
.34631 .6005 m .34863 .60264 L .34597 .60262 L F
.429 .28 .576 r
.34841 .59993 m .34863 .60264 L .34631 .6005 L F
0 0 0 r
.62071 .42835 m .61993 .43018 L .61851 .4324 L F
.928 .674 .189 r
.40485 .5392 m .40408 .54015 L .40431 .53749 L F
.40485 .5392 m .40485 .54167 L .40408 .54015 L F
.446 .142 .354 r
.50364 .49579 m .50131 .49479 L .50389 .49415 L F
.50364 .49579 m .50105 .49643 L .50131 .49479 L F
.435 .869 .777 r
.44253 .59846 m .44599 .59705 L .4451 .59793 L F
0 0 0 r
.4451 .59793 m .44599 .59705 L .44799 .59608 L F
0 .185 .713 r
.57961 .39125 m .57941 .39188 L .57714 .38975 L F
.297 .593 .947 r
.34446 .59692 m .34541 .59806 L .34229 .5972 L F
.582 .081 .028 r
.35192 .59117 m .34998 .59114 L .34749 .59064 L F
.933 .554 .221 r
.35162 .59384 m .34998 .59114 L .35192 .59117 L F
.776 .356 .25 r
.71142 .30675 m .71506 .30718 L .71262 .30672 L F
.336 .07 .353 r
.42622 .47457 m .42881 .4738 L .42911 .47132 L F
.577 .453 .674 r
.42911 .47132 m .4318 .47085 L .42976 .46926 L F
.433 .148 .379 r
.42911 .47132 m .43108 .47288 L .4318 .47085 L F
.42911 .47132 m .42881 .4738 L .43108 .47288 L F
.715 .891 .96 r
.43299 .45845 m .4337 .45744 L .43574 .45597 L F
.43299 .45845 m .43138 .45721 L .4337 .45744 L F
.357 .522 .883 r
.43431 .45946 m .43478 .4586 L .43299 .45845 L F
.56 .235 .375 r
.43478 .4586 m .43208 .46048 L .43299 .45845 L F
.735 .924 .955 r
.45065 .45107 m .44834 .45421 L .44711 .45282 L F
.45065 .45107 m .45178 .45204 L .44834 .45421 L F
.634 .822 .973 r
.45903 .44702 m .458 .44946 L .45645 .44797 L F
.45903 .44702 m .46061 .44846 L .458 .44946 L F
.641 .315 .405 r
.5337 .47488 m .5374 .47659 L .53367 .47672 L F
0 0 0 r
.23892 .58741 m .23717 .58914 L .23646 .58965 L F
.764 .342 .247 r
.23492 .58627 m .23717 .58914 L .23892 .58741 L F
.546 .536 .795 r
.23818 .58745 m .23773 .58875 L .23717 .58914 L F
.23773 .58875 m .23667 .59176 L .23717 .58914 L F
0 0 0 r
.23646 .58965 m .23717 .58914 L .23566 .59038 L F
.264 0 .11 r
.32955 .5882 m .33192 .58754 L .33178 .58524 L F
.33137 .58508 m .33178 .58524 L .33173 .58445 L F
.118 0 .356 r
.32975 .58459 m .33093 .58609 L .3313 .58505 L F
.32975 .58459 m .32944 .58744 L .33093 .58609 L F
0 0 0 r
.32603 .58993 m .32653 .58985 L .32944 .58744 L F
.525 .867 .606 r
.32944 .58744 m .32653 .58985 L .33093 .58609 L F
0 0 0 r
.32653 .58985 m .32955 .5882 L .33093 .58609 L F
.264 0 .11 r
.32955 .5882 m .33173 .58445 L .33093 .58609 L F
.32955 .5882 m .33178 .58524 L .33137 .58508 L F
.118 0 .356 r
.32993 .58451 m .3313 .58505 L .3318 .58367 L F
.32975 .58459 m .3313 .58505 L .32993 .58451 L F
.792 .842 .89 r
.42244 .49295 m .42766 .49162 L .4258 .49075 L F
.91 .978 .783 r
.42773 .48905 m .42766 .49162 L .42912 .4889 L F
.778 .91 .931 r
.42773 .48905 m .4258 .49075 L .42766 .49162 L F
0 0 0 r
.60663 .38222 m .606 .38433 L .60685 .37966 L F
.216 .402 .832 r
.60663 .38222 m .60816 .38545 L .606 .38433 L F
.4 .129 .383 r
.32216 .59658 m .32422 .59358 L .32219 .59406 L F
.967 .714 .501 r
.42289 .54141 m .42534 .54511 L .42352 .54373 L F
.42289 .54141 m .42293 .54448 L .42534 .54511 L F
.659 .701 .877 r
.64573 .38543 m .64627 .38784 L .64238 .38669 L F
.718 .655 .786 r
.64238 .38669 m .64627 .38784 L .64191 .38794 L F
.312 .448 .838 r
.64767 .38559 m .64627 .38784 L .64573 .38543 L F
.634 .872 .986 r
.64767 .38559 m .64912 .38672 L .64627 .38784 L F
.719 .988 .831 r
.32691 .61768 m .32545 .61919 L .32656 .61921 L F
.33 .124 .442 r
.32691 .61768 m .32641 .61859 L .32545 .61919 L F
.87 .801 .78 r
.32428 .61992 m .32656 .61921 L .32545 .61919 L F
.32266 .62043 m .32408 .62302 L .32656 .61921 L F
.33 .124 .442 r
.32641 .61859 m .3246 .62185 L .32545 .61919 L F
.87 .801 .78 r
.32266 .62043 m .32428 .61992 L .32545 .61919 L F
.719 .988 .831 r
.32691 .61768 m .32656 .61921 L .32902 .61628 L F
.413 .802 .989 r
.308 .64768 m .31054 .64837 L .31159 .64744 L F
.114 .305 .778 r
.31159 .64744 m .31054 .64837 L .31193 .64907 L F
.177 .687 .9 r
.3122 .65759 m .31187 .65821 L .30935 .65472 L F
.3122 .65759 m .3145 .65821 L .31187 .65821 L F
.346 .338 .707 r
.31466 .66061 m .31187 .65821 L .3145 .65821 L F
.557 .185 .291 r
.29389 .56719 m .29822 .56452 L .29406 .56451 L F
.29389 .56719 m .29643 .56721 L .29822 .56452 L F
.548 .175 .286 r
.29822 .56452 m .30032 .56673 L .30065 .56464 L F
.29822 .56452 m .29643 .56721 L .30032 .56673 L F
0 .135 .62 r
.57471 .38757 m .57711 .38942 L .57714 .38975 L F
0 .23 .69 r
.57815 .38995 m .57714 .38975 L .57711 .38942 L F
.57815 .38995 m .57961 .39125 L .57714 .38975 L F
.654 .8 .953 r
.46068 .55788 m .45747 .5577 L .45873 .5592 L F
.45873 .5592 m .45747 .5577 L .46068 .55788 L F
.46068 .55788 m .45747 .5577 L .45873 .5592 L F
.454 .111 .293 r
.5535 .47133 m .55592 .47205 L .55242 .47376 L F
.5535 .47133 m .55631 .4709 L .55592 .47205 L F
.7 .752 .892 r
.56994 .40962 m .56771 .41122 L .56604 .40893 L F
.56994 .40962 m .56604 .40893 L .56642 .40966 L F
.515 .911 .914 r
.56649 .40801 m .57245 .40622 L .56994 .40962 L F
.56649 .40801 m .56994 .40962 L .57111 .40749 L F
.606 .854 .991 r
.57111 .40749 m .57049 .40861 L .56642 .40966 L F
.57049 .40861 m .56994 .40962 L .56774 .40964 L F
.57049 .40861 m .56774 .40964 L .56642 .40966 L F
.691 .684 .838 r
.56681 .40999 m .56371 .41016 L .56604 .40893 L F
.56771 .41122 m .56526 .41057 L .56681 .40999 L F
.56526 .41057 m .56371 .41016 L .56681 .40999 L F
.165 0 0 r
.32123 .56266 m .3211 .56174 L .32307 .56123 L F
.32123 .56266 m .31915 .56315 L .3211 .56174 L F
.789 .808 .867 r
.56438 .41819 m .56845 .41943 L .56623 .42004 L F
.681 .501 .637 r
.57273 .41975 m .57018 .42263 L .56845 .41943 L F
.275 .198 .585 r
.60742 .36475 m .60945 .36358 L .60889 .36053 L F
.436 0 .096 r
.60742 .36475 m .61063 .36606 L .60945 .36358 L F
.607 .949 .92 r
.38598 .6545 m .38597 .65393 L .38379 .65475 L F
.862 .436 .002 r
.38598 .6545 m .38727 .65723 L .38783 .65776 L F
.548 .32 .521 r
.51264 .48424 m .51257 .48678 L .50983 .48723 L F
.566 .334 .523 r
.51264 .48424 m .51535 .48644 L .51257 .48678 L F
.56 .336 .532 r
.51537 .48381 m .51535 .48644 L .51264 .48424 L F
.578 .438 .654 r
.3567 .6036 m .35713 .60657 L .35438 .60692 L F
.461 .244 .497 r
.35713 .60657 m .35446 .60975 L .35438 .60692 L F
0 .271 .771 r
.27906 .61581 m .27947 .61692 L .27764 .61484 L F
.125 .501 .907 r
.27774 .61513 m .27947 .61692 L .27906 .61581 L F
.55 .833 .998 r
.27906 .61581 m .27947 .61692 L .2797 .61499 L F
.202 .018 .394 r
.43634 .47986 m .43394 .48326 L .43428 .48027 L F
.214 0 0 r
.25554 .61784 m .25752 .61771 L .2588 .61657 L F
.39 0 0 r
.25752 .61771 m .26174 .61612 L .2588 .61657 L F
.802 .5 .478 r
.3793 .60325 m .38166 .6043 L .38254 .60391 L F
.724 .661 .787 r
.39427 .49461 m .38979 .49362 L .39202 .49314 L F
0 0 .36 r
.40956 .55576 m .41057 .55813 L .40909 .55418 L F
.482 0 0 r
.33307 .54794 m .33301 .54817 L .3338 .54567 L F
.963 .829 .663 r
.56111 .42663 m .55855 .42779 L .56 .42498 L F
.878 .859 .819 r
.56353 .42331 m .56111 .42663 L .56 .42498 L F
.352 .821 .901 r
.60744 .34878 m .60843 .34782 L .61006 .34803 L F
.60744 .34878 m .60668 .3487 L .60843 .34782 L F
.274 0 0 r
.38536 .47772 m .38945 .4772 L .38717 .47899 L F
.674 .842 .963 r
.34379 .69528 m .34449 .69299 L .34204 .69348 L F
.34379 .69528 m .34614 .69423 L .34449 .69299 L F
.887 .883 .451 r
.31805 .64848 m .31926 .64569 L .31825 .64732 L F
.841 .878 .442 r
.31825 .64732 m .31926 .64569 L .31927 .64413 L F
.735 .218 0 r
.3664 .51137 m .37014 .5148 L .36877 .51287 L F
.786 .989 .891 r
.68011 .30199 m .67883 .30379 L .67989 .30115 L F
0 0 .201 r
.67798 .30565 m .67989 .30115 L .67883 .30379 L F
.647 .423 .565 r
.34919 .61614 m .34461 .61978 L .3467 .6174 L F
.346 .157 .476 r
.3628 .53878 m .36278 .54139 L .36041 .54186 L F
.353 .15 .459 r
.36229 .54407 m .36041 .54186 L .36278 .54139 L F
.36229 .54407 m .36063 .54605 L .36041 .54186 L F
0 0 0 r
.44227 .49363 m .44185 .49537 L .44464 .49179 L F
.361 .068 .326 r
.32873 .52266 m .33104 .5224 L .33158 .51954 L F
.723 .847 .94 r
.42366 .46446 m .42149 .46598 L .42009 .46435 L F
.663 .955 .73 r
.61642 .37132 m .6177 .36991 L .61675 .37115 L F
.632 .893 .568 r
.61597 .37167 m .61821 .36935 L .6177 .36991 L F
.663 .955 .73 r
.61438 .37236 m .61597 .37167 L .6177 .36991 L F
.61438 .37236 m .6177 .36991 L .61642 .37132 L F
.632 .893 .568 r
.61821 .36935 m .619 .36854 L .6177 .36991 L F
.54 .833 .502 r
.6177 .36991 m .619 .36854 L .62066 .36671 L F
0 0 .462 r
.21683 .57743 m .21783 .57319 L .21597 .57482 L F
0 0 .112 r
.47816 .55832 m .47751 .56058 L .47622 .56186 L F
.673 .94 .965 r
.22629 .5697 m .22573 .5715 L .23033 .56932 L F
0 0 .148 r
.22653 .5724 m .22573 .5715 L .22629 .5697 L F
.22653 .5724 m .22491 .5748 L .22573 .5715 L F
.325 .095 .402 r
.42556 .59376 m .42282 .59716 L .42459 .59663 L F
.699 .246 .172 r
.42282 .59716 m .42549 .59972 L .42258 .6003 L F
.255 0 0 r
.42132 .59895 m .42459 .59663 L .42282 .59716 L F
.528 .006 0 r
.23991 .61831 m .24081 .61897 L .242 .62015 L F
.901 .892 .811 r
.27716 .6334 m .28033 .63517 L .28106 .63186 L F
.55 .302 .493 r
.46146 .51308 m .45875 .51646 L .45888 .51322 L F
.45875 .51646 m .46146 .51308 L .45888 .51322 L F
0 0 0 r
.42109 .58273 m .42126 .5818 L .42167 .58054 L F
.284 .182 .559 r
.43101 .46427 m .42976 .46926 L .433 .46636 L F
.165 .398 .842 r
.42976 .46926 m .43285 .46927 L .433 .46636 L F
.42976 .46926 m .4318 .47085 L .43285 .46927 L F
.596 .779 .968 r
.711 .28405 m .71377 .28319 L .71254 .28148 L F
.722 .986 .804 r
.342 .53326 m .33884 .53586 L .33966 .53418 L F
.6 .576 .799 r
.33969 .52825 m .342 .53326 L .34293 .53093 L F
.368 0 .179 r
.33966 .53418 m .34293 .53093 L .342 .53326 L F
.79 .55 .574 r
.31708 .63349 m .31902 .62962 L .31632 .62803 L F
0 0 .187 r
.321 .62611 m .31902 .62962 L .32004 .6294 L F
.349 .251 .601 r
.32004 .6294 m .31902 .62962 L .32135 .63172 L F
.726 .671 .796 r
.56202 .4194 m .56353 .42331 L .55949 .42252 L F
.845 .91 .505 r
.56 .42498 m .55855 .42779 L .55871 .42725 L F
.878 .859 .819 r
.5612 .42285 m .56 .42498 L .55949 .42252 L F
0 0 .482 r
.55949 .42252 m .56 .42498 L .56164 .42032 L F
.753 .685 .786 r
.56623 .42004 m .56353 .42331 L .56202 .4194 L F
.56623 .42004 m .56202 .4194 L .56438 .41819 L F
.687 .924 .607 r
.56202 .4194 m .55949 .42252 L .56066 .42061 L F
0 0 0 r
.56438 .41819 m .56263 .41933 L .56358 .41963 L F
.56438 .41819 m .56358 .41963 L .56368 .41958 L F
.56438 .41819 m .56202 .4194 L .56078 .4205 L F
.56438 .41819 m .56078 .4205 L .56085 .42048 L F
0 .284 .768 r
.56059 .41267 m .5647 .41606 L .56347 .41212 L F
.344 .069 .344 r
.56202 .4194 m .5647 .41606 L .56438 .41819 L F
.56202 .4194 m .5647 .41606 L .56438 .41819 L F
.214 .319 .756 r
.56347 .41212 m .5647 .41606 L .56613 .41326 L F
0 0 .049 r
.56613 .41326 m .5647 .41606 L .56438 .41819 L F
.56613 .41326 m .56438 .41819 L .56661 .41781 L F
.491 .257 .487 r
.56657 .42019 m .56438 .41819 L .56368 .41958 L F
.56657 .42019 m .56661 .41781 L .56438 .41819 L F
.784 .756 .827 r
.56581 .41837 m .56657 .42019 L .56352 .41967 L F
.491 .257 .487 r
.56657 .42019 m .56368 .41958 L .56364 .41965 L F
.258 .295 .709 r
.56613 .41326 m .56661 .41781 L .56854 .41595 L F
0 0 .356 r
.56854 .41595 m .56661 .41781 L .56657 .42019 L F
.746 .738 .845 r
.56854 .41595 m .56748 .41823 L .56453 .41536 L F
.56748 .41823 m .56657 .42019 L .56596 .41873 L F
.215 0 0 r
.56373 .41947 m .56661 .41781 L .56438 .41819 L F
.56401 .41937 m .56661 .41781 L .56373 .41947 L F
.56387 .41951 m .56661 .41781 L .56368 .41958 L F
.746 .738 .845 r
.56748 .41823 m .56596 .41873 L .56453 .41536 L F
.215 0 0 r
.56368 .41958 m .56401 .41937 L .56373 .41947 L F
.56364 .41965 m .56387 .41951 L .56368 .41958 L F
.784 .756 .827 r
.56581 .41837 m .56368 .41958 L .56139 .41931 L F
0 0 0 r
.56263 .41933 m .56184 .42023 L .56349 .4197 L F
.56356 .41962 m .56349 .4197 L .56364 .41965 L F
.56263 .41933 m .56349 .4197 L .56356 .41962 L F
.56263 .41933 m .56066 .42061 L .56184 .42023 L F
.56085 .42048 m .56078 .4205 L .56066 .42061 L F
.706 .424 .495 r
.56196 .41942 m .56302 .41957 L .56066 .42061 L F
.842 .514 .433 r
.56352 .41967 m .56349 .4197 L .56318 .41961 L F
.784 .756 .827 r
.56368 .41958 m .56346 .41966 L .56318 .41961 L F
.706 .424 .495 r
.56302 .41957 m .5631 .41958 L .56318 .41961 L F
.784 .756 .827 r
.56288 .41948 m .56318 .41961 L .56139 .41931 L F
.56368 .41958 m .56318 .41961 L .56288 .41948 L F
.706 .424 .495 r
.56318 .41961 m .56364 .41965 L .56349 .4197 L F
.5631 .41958 m .56364 .41965 L .56318 .41961 L F
.56302 .41957 m .56349 .4197 L .56066 .42061 L F
0 0 .482 r
.55949 .42252 m .56196 .41942 L .56066 .42061 L F
.706 .424 .495 r
.56376 .42153 m .56458 .42249 L .56432 .42173 L F
.56196 .41942 m .56376 .42153 L .56389 .42041 L F
.56376 .42153 m .56432 .42173 L .56389 .42041 L F
.824 .487 .417 r
.56657 .42019 m .56458 .42249 L .56389 .42041 L F
.845 .91 .505 r
.56 .42498 m .5599 .42328 L .56105 .42113 L F
.56 .42498 m .56105 .42113 L .56156 .42055 L F
.878 .859 .819 r
.56353 .42331 m .56 .42498 L .5612 .42285 L F
.633 .666 .864 r
.5599 .42328 m .56458 .42249 L .56376 .42153 L F
0 0 .482 r
.55949 .42252 m .56164 .42032 L .56116 .42042 L F
.845 .91 .505 r
.56156 .42055 m .56105 .42113 L .56196 .41942 L F
.633 .666 .864 r
.56135 .42056 m .56376 .42153 L .56196 .41942 L F
.5599 .42328 m .56376 .42153 L .56135 .42056 L F
.842 .514 .433 r
.56657 .42019 m .56509 .4219 L .56194 .42125 L F
.56509 .4219 m .56458 .42249 L .56194 .42125 L F
.923 .869 .767 r
.56458 .42249 m .56488 .42642 L .56679 .42307 L F
.633 .666 .864 r
.5599 .42328 m .56488 .42642 L .56458 .42249 L F
.481 0 0 r
.56684 .42237 m .56194 .42125 L .56458 .42249 L F
.56454 .42185 m .56465 .42264 L .56194 .42125 L F
.56496 .42194 m .56493 .422 L .56454 .42185 L F
.56493 .422 m .56465 .42264 L .56454 .42185 L F
.842 .514 .433 r
.56657 .42019 m .5627 .42052 L .56352 .41967 L F
.824 .487 .417 r
.56657 .42019 m .56389 .42041 L .56364 .41965 L F
.842 .514 .433 r
.56657 .42019 m .562 .42124 L .5627 .42052 L F
.481 0 0 r
.56684 .42237 m .56638 .42243 L .56496 .42194 L F
.56638 .42243 m .56465 .42264 L .56496 .42194 L F
.842 .514 .433 r
.56318 .41961 m .56313 .41967 L .56304 .41959 L F
.706 .424 .495 r
.56302 .41957 m .56389 .42041 L .56364 .41965 L F
.56196 .41942 m .56389 .42041 L .56302 .41957 L F
.842 .514 .433 r
.56304 .41959 m .563 .41985 L .56238 .41948 L F
.56313 .41967 m .563 .41985 L .56304 .41959 L F
.56238 .41948 m .56194 .42125 L .56139 .41931 L F
.563 .41985 m .56194 .42125 L .56238 .41948 L F
.56349 .4197 m .56194 .42125 L .56318 .41961 L F
.562 .42124 m .56194 .42125 L .56352 .41967 L F
.784 .756 .827 r
.56368 .41958 m .56352 .41967 L .56346 .41966 L F
.56453 .41536 m .56581 .41837 L .56189 .4192 L F
.56154 .41913 m .56189 .4192 L .56139 .41931 L F
.56453 .41536 m .56189 .4192 L .56154 .41913 L F
0 0 0 r
.56368 .41958 m .56358 .41963 L .56364 .41965 L F
0 0 .482 r
.56116 .42042 m .56164 .42032 L .56196 .41942 L F
.845 .91 .505 r
.56 .42498 m .55871 .42725 L .5599 .42328 L F
.357 .522 .883 r
.43431 .45946 m .43665 .46115 L .43478 .4586 L F
.235 0 .098 r
.43431 .45946 m .43208 .46238 L .4355 .46058 L F
.56 .235 .375 r
.43383 .45926 m .43527 .46063 L .43208 .46048 L F
.43478 .4586 m .4352 .46034 L .43383 .45926 L F
.4352 .46034 m .43527 .46063 L .43383 .45926 L F
.235 0 .098 r
.43431 .45946 m .43548 .46056 L .43665 .46115 L F
.43548 .46056 m .4355 .46058 L .4355 .46058 L F
.43548 .46056 m .4355 .46058 L .43665 .46115 L F
.796 .998 .854 r
.63278 .35806 m .63004 .36058 L .62904 .35995 L F
.399 .617 .939 r
.63297 .36078 m .63004 .36058 L .63278 .35806 L F
.265 .292 .703 r
.63093 .36142 m .62929 .36339 L .62904 .35995 L F
.886 .96 .623 r
.6297 .36202 m .63093 .36142 L .63076 .36043 L F
.62957 .36222 m .63093 .36142 L .6297 .36202 L F
.226 0 0 r
.63004 .36058 m .63231 .36073 L .63093 .36142 L F
.63231 .36073 m .63297 .36078 L .63093 .36142 L F
.755 .831 .91 r
.46727 .44576 m .46359 .44566 L .46556 .44399 L F
.785 .874 .913 r
.46784 .44272 m .46727 .44576 L .46556 .44399 L F
.46784 .44272 m .46939 .44418 L .46727 .44576 L F
.855 .752 .748 r
.54704 .44158 m .55047 .44224 L .549 .43859 L F
.785 .34 .192 r
.5482 .44292 m .55047 .44224 L .54704 .44158 L F
.78 .721 .797 r
.549 .43859 m .55047 .44224 L .55307 .43894 L F
.202 .376 .814 r
.55179 .44036 m .55047 .44224 L .5482 .44292 L F
.618 .48 .671 r
.55047 .44224 m .55409 .44253 L .55307 .43894 L F
.613 .366 .519 r
.55255 .44381 m .55409 .44253 L .55047 .44224 L F
.202 .376 .814 r
.55179 .44036 m .55255 .44381 L .55047 .44224 L F
.781 .612 .671 r
.2779 .64528 m .2821 .64564 L .27984 .64832 L F
.156 0 .396 r
.37394 .55165 m .37701 .54767 L .37526 .54857 L F
.37394 .55165 m .37553 .55097 L .37701 .54767 L F
0 0 .056 r
.37504 .55364 m .37553 .55097 L .37394 .55165 L F
.795 .775 .835 r
.25057 .58092 m .2465 .58028 L .24854 .57775 L F
.766 .517 .559 r
.25057 .58092 m .24682 .58317 L .2465 .58028 L F
.25057 .58092 m .25004 .58443 L .24682 .58317 L F
.57 .685 .918 r
.25358 .58024 m .25057 .58092 L .24854 .57775 L F
.405 .46 .804 r
.25359 .58335 m .25057 .58092 L .25358 .58024 L F
.808 .999 .836 r
.43574 .45597 m .43652 .45353 L .43807 .45473 L F
.43574 .45597 m .4337 .45744 L .43652 .45353 L F
.804 .879 .901 r
.48854 .43363 m .48411 .43488 L .48726 .43245 L F
.763 .892 .935 r
.49073 .43216 m .48854 .43363 L .48726 .43245 L F
.821 .483 .416 r
.22936 .56319 m .2318 .56499 L .2309 .56471 L F
.442 .303 .596 r
.37724 .54232 m .37745 .5453 L .3797 .5445 L F
0 0 .216 r
.37789 .54333 m .37724 .54232 L .3797 .5445 L F
.37789 .54333 m .37745 .5453 L .37724 .54232 L F
0 .201 .711 r
.58359 .39497 m .58471 .3966 L .5821 .39369 L F
0 .049 .586 r
.58691 .39882 m .58471 .3966 L .58359 .39497 L F
0 .239 .755 r
.58781 .40046 m .58471 .3966 L .58691 .39882 L F
.763 .95 .938 r
.71555 .32698 m .71789 .32765 L .71973 .3257 L F
.377 .819 .679 r
.61258 .37343 m .61438 .37236 L .6122 .37382 L F
.61258 .37343 m .61597 .37167 L .61438 .37236 L F
.809 .573 .581 r
.56394 .42985 m .56488 .43228 L .56093 .43149 L F
.672 .34 0 r
.56451 .43139 m .56488 .43228 L .56394 .42985 L F
.56451 .43139 m .56394 .42985 L .56659 .42812 L F
.455 .591 .899 r
.36236 .61403 m .36648 .61613 L .36661 .6137 L F
0 .2 .721 r
.28739 .52951 m .28884 .53051 L .28856 .5295 L F
.414 .512 .849 r
.70374 .26537 m .70586 .26553 L .70389 .26789 L F
.58 .764 .966 r
.70389 .26789 m .70586 .26553 L .70261 .2658 L F
.973 .708 .47 r
.39316 .55064 m .39485 .5548 L .39507 .55185 L F
.268 .517 .906 r
.33117 .5297 m .33154 .52951 L .32875 .52778 L F
.33117 .5297 m .33097 .53232 L .33154 .52951 L F
.533 .632 .895 r
.36391 .62309 m .36594 .62662 L .36759 .62561 L F
.105 0 .195 r
.36759 .62561 m .36594 .62662 L .365 .62888 L F
.36759 .62561 m .36594 .62662 L .365 .62888 L F
.257 0 0 r
.42249 .47687 m .42497 .47639 L .42622 .47457 L F
.689 .254 .211 r
.42622 .47457 m .42906 .47671 L .42881 .4738 L F
.029 0 .308 r
.47976 .55151 m .47949 .55375 L .47752 .55551 L F
.257 .224 .629 r
.47752 .55551 m .47917 .55732 L .47816 .55832 L F
.47752 .55551 m .47949 .55375 L .47917 .55732 L F
.557 .435 .669 r
.23801 .61324 m .2401 .60989 L .23685 .61015 L F
.23801 .61324 m .2412 .61305 L .2401 .60989 L F
0 .106 .632 r
.23801 .61324 m .23882 .61341 L .2412 .61305 L F
.23801 .61324 m .24079 .61591 L .23882 .61341 L F
.75 .994 .847 r
.61607 .39263 m .61979 .39046 L .61859 .39162 L F
0 0 .342 r
.61875 .38709 m .61979 .39046 L .61988 .39025 L F
.634 .687 .882 r
.35434 .69999 m .35509 .69602 L .35245 .6967 L F
.35434 .69999 m .35713 .69944 L .35509 .69602 L F
.811 .997 .854 r
.33153 .49442 m .33061 .49713 L .32924 .49544 L F
.507 .579 .862 r
.33061 .49713 m .3346 .50008 L .33038 .49921 L F
.57 .887 .613 r
.64612 .33077 m .64429 .33254 L .64599 .3307 L F
.621 .954 .799 r
.64429 .33254 m .64237 .3331 L .64599 .3307 L F
.966 .706 .489 r
.33089 .51374 m .32858 .51466 L .32886 .51212 L F
.536 .772 .985 r
.33162 .51195 m .33089 .51374 L .32886 .51212 L F
0 0 0 r
.33114 .51411 m .33089 .51374 L .33162 .51195 L F
.33114 .51411 m .32858 .51466 L .33089 .51374 L F
.884 .514 .039 r
.34435 .50596 m .34498 .50735 L .34464 .50621 L F
0 0 .538 r
.34498 .50735 m .34636 .50978 L .34464 .50621 L F
.239 .045 .404 r
.37155 .56163 m .37357 .56076 L .37401 .55814 L F
.378 .355 .707 r
.37207 .55641 m .37357 .56076 L .37155 .56163 L F
.126 0 .165 r
.37357 .56076 m .37065 .56397 L .37155 .56163 L F
.37357 .56076 m .37065 .56397 L .37155 .56163 L F
.337 .648 .968 r
.6254 .40861 m .62409 .41027 L .62255 .40906 L F
.6254 .40861 m .62762 .41061 L .62409 .41027 L F
.708 .587 .718 r
.34843 .56485 m .34975 .56837 L .34584 .56812 L F
.682 .574 .727 r
.35242 .56803 m .34975 .56837 L .34843 .56485 L F
.498 .253 .473 r
.35242 .56803 m .34965 .57093 L .34975 .56837 L F
.558 .857 .997 r
.33464 .63526 m .33423 .63609 L .33255 .63519 L F
0 0 .084 r
.33464 .63526 m .33391 .63864 L .33423 .63609 L F
.275 .733 .953 r
.58555 .38669 m .5863 .38588 L .58431 .38538 L F
.58555 .38669 m .58802 .38656 L .5863 .38588 L F
.286 .744 .954 r
.33465 .53532 m .33728 .53516 L .33884 .53586 L F
.978 .691 .401 r
.33884 .53586 m .33788 .53751 L .33728 .53516 L F
.608 .905 .984 r
.33884 .53586 m .33728 .53516 L .33966 .53418 L F
.33884 .53586 m .33728 .53516 L .33966 .53418 L F
.248 .097 .47 r
.33788 .53751 m .33966 .53418 L .33884 .53586 L F
.634 .454 .623 r
.35097 .60206 m .35343 .59883 L .35291 .60044 L F
.321 0 0 r
.29531 .57517 m .29691 .57556 L .29739 .57548 L F
.29531 .57517 m .29739 .57548 L .29695 .57544 L F
.347 0 .179 r
.29698 .57545 m .29691 .57556 L .29531 .57517 L F
.321 0 0 r
.29531 .57517 m .29695 .57544 L .29504 .57527 L F
.347 0 .179 r
.29957 .57099 m .29698 .57545 L .29531 .57517 L F
.511 .14 .272 r
.30164 .57276 m .29957 .57099 L .30199 .5711 L F
.419 0 0 r
.29688 .57544 m .2933 .57563 L .29504 .57527 L F
.689 .415 .503 r
.29739 .57548 m .29691 .57556 L .29706 .57547 L F
.419 0 0 r
.29739 .57548 m .29706 .57547 L .29688 .57544 L F
.689 .415 .503 r
.29739 .57548 m .29706 .57547 L .30164 .57276 L F
.419 0 0 r
.29739 .57548 m .29713 .57549 L .29706 .57547 L F
.511 .14 .272 r
.29706 .57547 m .29691 .57556 L .29697 .57546 L F
.419 0 0 r
.29713 .57549 m .2933 .57563 L .29688 .57544 L F
.511 .14 .272 r
.30164 .57276 m .29706 .57547 L .29957 .57099 L F
.29706 .57547 m .29697 .57546 L .29957 .57099 L F
1 .825 .515 r
.45398 .56289 m .45507 .56441 L .45555 .56165 L F
.238 0 .315 r
.42315 .52544 m .42056 .52872 L .42122 .52649 L F
.42122 .52649 m .42056 .52872 L .42315 .52544 L F
.711 .174 0 r
.22823 .58446 m .23035 .58672 L .23236 .5875 L F
.485 0 0 r
.23035 .58672 m .23492 .58627 L .23236 .5875 L F
.012 .089 .599 r
.21683 .57743 m .2174 .58126 L .21848 .57945 L F
.499 .547 .837 r
.21793 .5838 m .21848 .57945 L .2174 .58126 L F
.561 .411 .635 r
.36716 .52604 m .3663 .52813 L .36374 .52767 L F
.662 .561 .73 r
.71678 .31001 m .71404 .31309 L .71302 .30941 L F
.681 .501 .637 r
.57273 .41975 m .57283 .42261 L .57018 .42263 L F
.683 .562 .712 r
.57505 .41684 m .57524 .41986 L .57273 .41975 L F
.639 .292 .367 r
.57273 .41975 m .57524 .41986 L .5753 .42173 L F
.487 .35 .62 r
.5753 .42173 m .57283 .42261 L .57273 .41975 L F
.85 .993 .746 r
.39359 .6022 m .39627 .60023 L .39499 .59934 L F
.39359 .6022 m .39371 .6035 L .39627 .60023 L F
.975 .891 .677 r
.39602 .59687 m .39499 .59934 L .39627 .60023 L F
.615 .318 .443 r
.5405 .47489 m .54329 .47671 L .5403 .47634 L F
.5405 .47489 m .54415 .47435 L .54329 .47671 L F
.33 .523 .893 r
.3726 .67469 m .36841 .67144 L .36828 .67424 L F
.711 .606 .738 r
.3576 .56148 m .35877 .56523 L .36169 .56493 L F
.7 .526 .649 r
.35877 .56523 m .35901 .56783 L .36169 .56493 L F
.53 .288 .492 r
.35901 .56783 m .36171 .56751 L .36169 .56493 L F
.392 .182 .471 r
.36169 .56493 m .36171 .56751 L .36418 .56404 L F
0 0 .182 r
.6073 .3778 m .60718 .38003 L .60685 .37966 L F
0 0 0 r
.60663 .38222 m .60685 .37966 L .60718 .38003 L F
.69 .576 .723 r
.31562 .53487 m .31491 .53501 L .31747 .53124 L F
0 0 0 r
.45028 .5293 m .44823 .53174 L .45102 .52861 L F
.74 .623 .728 r
.35451 .56445 m .35877 .56523 L .3576 .56148 L F
.69 .519 .65 r
.35535 .56771 m .35877 .56523 L .35451 .56445 L F
.35535 .56771 m .35901 .56783 L .35877 .56523 L F
.797 .702 .76 r
.37226 .53302 m .36727 .53467 L .37067 .53264 L F
.37226 .53302 m .36945 .53625 L .36727 .53467 L F
.752 .969 .93 r
.37226 .53302 m .37067 .53264 L .37287 .5309 L F
.769 .944 .607 r
.37746 .66786 m .37504 .67136 L .3779 .6709 L F
.273 .354 .764 r
.22998 .58282 m .22823 .58446 L .22693 .58048 L F
.208 .246 .682 r
.22998 .58282 m .23035 .58672 L .22823 .58446 L F
.192 0 0 r
.33038 .49921 m .3346 .50008 L .33245 .49969 L F
.462 0 0 r
.33245 .49969 m .3346 .50008 L .33709 .50138 L F
.825 .994 .859 r
.39374 .47281 m .39115 .47531 L .39127 .47352 L F
.858 .987 .714 r
.38945 .4772 m .39127 .47352 L .39115 .47531 L F
.722 .757 .88 r
.60322 .46019 m .60573 .45698 L .60194 .46015 L F
.60322 .46019 m .60773 .45823 L .60573 .45698 L F
.646 .47 .631 r
.48032 .54113 m .47777 .54448 L .47808 .54239 L F
.672 .367 0 r
.38247 .67995 m .38207 .67874 L .37928 .67764 L F
.768 .957 .645 r
.26493 .55197 m .26549 .55026 L .2675 .54862 L F
.584 .408 .609 r
.26493 .55197 m .26751 .55196 L .2675 .54862 L F
.08 0 0 r
.2675 .54862 m .26795 .54962 L .27024 .54778 L F
.2675 .54862 m .26549 .55026 L .26795 .54962 L F
.79 .795 .857 r
.50104 .42681 m .49571 .42792 L .49945 .42519 L F
.762 .863 .923 r
.50234 .42557 m .50104 .42681 L .49945 .42519 L F
.427 .263 .555 r
.54694 .39888 m .5471 .40197 L .5446 .40022 L F
.54694 .39888 m .5471 .40197 L .5446 .40022 L F
.847 .906 .877 r
.55448 .44542 m .55718 .4421 L .55689 .44493 L F
.268 .449 .855 r
.55758 .44766 m .55448 .44542 L .55689 .44493 L F
.92 .526 .208 r
.59765 .39653 m .60039 .4005 L .59984 .399 L F
.949 .594 .243 r
.60039 .4005 m .59926 .4009 L .59984 .399 L F
.60039 .4005 m .60094 .40304 L .59926 .4009 L F
.652 .121 0 r
.28087 .61965 m .28484 .62124 L .28276 .62022 L F
.498 .373 .64 r
.24682 .58317 m .24439 .58083 L .2465 .58028 L F
.24682 .58317 m .24498 .58441 L .24439 .58083 L F
.032 .603 .749 r
.25643 .51674 m .25852 .5167 L .26026 .51683 L F
0 .184 .718 r
.26141 .51638 m .26026 .51683 L .25852 .5167 L F
.933 .554 .221 r
.35162 .59384 m .34998 .5929 L .34998 .59114 L F
.616 .15 .125 r
.35162 .59384 m .3498 .59521 L .34998 .5929 L F
.35162 .59384 m .35307 .59583 L .3498 .59521 L F
.438 .744 .992 r
.26493 .55197 m .26751 .55196 L .26549 .55026 L F
.817 .815 .848 r
.65002 .34181 m .65229 .33752 L .64811 .34069 L F
0 0 0 r
.64801 .34258 m .65217 .34094 L .65113 .34246 L F
.817 .815 .848 r
.65113 .34246 m .65141 .34128 L .65002 .34181 L F
.65141 .34128 m .65229 .33752 L .65002 .34181 L F
0 0 0 r
.64807 .34256 m .64958 .34192 L .65217 .34094 L F
.64801 .34258 m .64802 .34258 L .64807 .34256 L F
.64802 .34258 m .64958 .34192 L .64807 .34256 L F
.734 .564 .662 r
.48744 .50724 m .48799 .50999 L .48387 .50944 L F
.671 .524 .675 r
.49043 .50677 m .48799 .50999 L .48744 .50724 L F
.426 .146 .383 r
.38028 .58691 m .37977 .5899 L .37706 .59042 L F
.582 .331 .502 r
.37977 .5899 m .38271 .58642 L .38028 .58691 L F
0 0 .336 r
.345 .55435 m .34319 .5557 L .34549 .55466 L F
.34369 .55355 m .34355 .55415 L .345 .55435 L F
.34355 .55415 m .34319 .5557 L .345 .55435 L F
.846 .648 .635 r
.33959 .55029 m .34262 .55402 L .33963 .55312 L F
0 0 .336 r
.34369 .55355 m .34368 .55531 L .34319 .5557 L F
.846 .648 .635 r
.34262 .55402 m .34368 .55531 L .34081 .55376 L F
.34262 .55402 m .34081 .55376 L .33963 .55312 L F
.146 .652 .903 r
.34319 .5557 m .34368 .55531 L .33912 .55502 L F
.386 .223 .534 r
.33912 .55502 m .34155 .55708 L .34319 .5557 L F
0 0 0 r
.34319 .5557 m .34346 .5563 L .34549 .55466 L F
.34319 .5557 m .34155 .55708 L .34346 .5563 L F
.584 .381 .571 r
.43023 .49363 m .43336 .49371 L .43274 .49064 L F
.422 .186 .449 r
.43274 .49064 m .43568 .49013 L .43591 .4871 L F
.704 .611 .75 r
.43336 .49371 m .43568 .49013 L .43274 .49064 L F
.491 .345 .61 r
.47963 .51957 m .4799 .52243 L .47727 .52312 L F
.504 .438 .716 r
.4799 .52243 m .47807 .52592 L .47727 .52312 L F
.527 .241 .424 r
.51832 .4813 m .51803 .48349 L .51537 .48381 L F
.548 .26 .429 r
.52132 .48216 m .51832 .4813 L .52188 .48032 L F
.52132 .48216 m .51803 .48349 L .51832 .4813 L F
0 0 0 r
.27058 .57833 m .27059 .57783 L .27211 .57685 L F
.27058 .57833 m .26862 .57944 L .27059 .57783 L F
.873 .467 .253 r
.52989 .41549 m .52896 .4134 L .52766 .41628 L F
.53021 .41538 m .53011 .41523 L .52989 .41549 L F
.53011 .41523 m .52896 .4134 L .52989 .41549 L F
.84 .939 .89 r
.53213 .41281 m .5319 .41429 L .53272 .41245 L F
.685 .23 .167 r
.52896 .4134 m .53134 .41412 L .52952 .41476 L F
.53134 .41412 m .5319 .41429 L .531 .41446 L F
.53134 .41412 m .531 .41446 L .52952 .41476 L F
.84 .939 .89 r
.53069 .41453 m .5319 .41429 L .53213 .41281 L F
.351 0 0 r
.53349 .41423 m .53089 .41458 L .53272 .41245 L F
.596 .864 .528 r
.53089 .41458 m .53021 .41538 L .53082 .41465 L F
.351 0 0 r
.53349 .41423 m .53021 .41538 L .53089 .41458 L F
.548 .877 .991 r
.53021 .41538 m .52766 .41628 L .52842 .41524 L F
.52901 .41504 m .52842 .41524 L .52864 .41493 L F
.53021 .41538 m .52842 .41524 L .52901 .41504 L F
.603 .871 .537 r
.53211 .41396 m .52882 .41671 L .53136 .41592 L F
.596 .864 .528 r
.53272 .41245 m .53089 .41458 L .53248 .4127 L F
.53089 .41458 m .53082 .41465 L .5327 .41244 L F
.548 .877 .991 r
.53021 .41538 m .52864 .41493 L .52882 .41671 L F
.685 .23 .167 r
.52865 .41487 m .52952 .41476 L .52864 .41493 L F
.52896 .4134 m .52952 .41476 L .52865 .41487 L F
.84 .939 .89 r
.52864 .41493 m .53069 .41453 L .53213 .41281 L F
.52864 .41493 m .53272 .41245 L .53247 .4127 L F
.53191 .41325 m .53247 .4127 L .53193 .41324 L F
.52864 .41493 m .53247 .4127 L .53191 .41325 L F
.603 .871 .537 r
.5327 .41244 m .53247 .4127 L .53235 .41282 L F
.53247 .4127 m .53237 .41282 L .53235 .41282 L F
.53247 .4127 m .53235 .41282 L .53235 .41282 L F
.728 .803 .911 r
.52864 .41493 m .53191 .41325 L .53034 .41222 L F
.603 .871 .537 r
.53232 .41286 m .53143 .41384 L .53259 .41272 L F
.53143 .41384 m .52989 .41569 L .52882 .41671 L F
.53235 .41282 m .52989 .41569 L .53143 .41384 L F
.53143 .41384 m .52882 .41671 L .53165 .41372 L F
.53237 .41282 m .53021 .41538 L .53235 .41282 L F
.53143 .41384 m .53165 .41372 L .53259 .41272 L F
.84 .939 .89 r
.53193 .41324 m .53232 .41285 L .53259 .41291 L F
.728 .803 .911 r
.53191 .41325 m .53259 .41291 L .53228 .41281 L F
.53191 .41325 m .53228 .41281 L .53034 .41222 L F
.603 .871 .537 r
.53235 .41282 m .53021 .41538 L .52989 .41569 L F
.351 0 0 r
.53411 .41401 m .53349 .41423 L .53272 .41245 L F
0 0 0 r
.53539 .41393 m .537 .41305 L .53411 .41401 L F
.53539 .41393 m .53411 .41401 L .53272 .41245 L F
.569 .912 .695 r
.53778 .4123 m .537 .41305 L .53539 .41393 L F
.53898 .41149 m .53842 .41192 L .53778 .4123 L F
.53842 .41192 m .537 .41305 L .53778 .4123 L F
.53898 .41149 m .53539 .41393 L .53547 .41125 L F
.5356 .41109 m .53547 .41125 L .53548 .41108 L F
.53898 .41149 m .53547 .41125 L .5356 .41109 L F
.444 .093 .274 r
.53206 .41563 m .5327 .41244 L .53136 .41592 L F
.53 .335 .561 r
.53548 .41108 m .53539 .41393 L .53272 .41245 L F
.444 .093 .274 r
.53575 .41412 m .53405 .41308 L .53206 .41563 L F
.53592 .41398 m .53405 .41308 L .53575 .41412 L F
.53405 .41308 m .5327 .41244 L .53206 .41563 L F
.474 0 0 r
.53259 .41291 m .5327 .41244 L .53537 .41371 L F
.53259 .41291 m .53537 .41371 L .53526 .41377 L F
.233 0 0 r
.53369 .41326 m .5359 .41398 L .53473 .41361 L F
.719 .398 .435 r
.53575 .41412 m .53799 .41322 L .53747 .41274 L F
.53506 .41467 m .53548 .41446 L .53575 .41412 L F
.53548 .41446 m .53799 .41322 L .53575 .41412 L F
.603 .871 .537 r
.53253 .41288 m .53108 .41431 L .53211 .41396 L F
.53246 .41285 m .53108 .41431 L .53253 .41288 L F
.53108 .41431 m .52882 .41671 L .53211 .41396 L F
.64 .46 .624 r
.53034 .41222 m .53586 .41397 L .53136 .41592 L F
.444 .093 .274 r
.536 .41401 m .53592 .41398 L .53575 .41412 L F
.64 .46 .624 r
.53586 .41397 m .536 .41401 L .53575 .41412 L F
.53586 .41397 m .53575 .41412 L .53136 .41592 L F
.233 0 0 r
.5359 .41398 m .536 .41401 L .53586 .41397 L F
.5359 .41398 m .53586 .41397 L .53473 .41361 L F
.719 .398 .435 r
.53544 .41384 m .53747 .41274 L .5364 .41176 L F
.53506 .41467 m .53591 .41398 L .53544 .41384 L F
.474 0 0 r
.53526 .41377 m .53537 .41371 L .53592 .41398 L F
.719 .398 .435 r
.53591 .41398 m .53592 .41398 L .5359 .41398 L F
.474 0 0 r
.5359 .41398 m .53592 .41398 L .536 .41401 L F
.53526 .41377 m .53592 .41398 L .5359 .41398 L F
.719 .398 .435 r
.5359 .41398 m .53747 .41274 L .53544 .41384 L F
.53592 .41398 m .53747 .41274 L .5359 .41398 L F
.174 0 0 r
.53396 .41521 m .536 .41401 L .53575 .41412 L F
.53396 .41521 m .53575 .41412 L .53136 .41592 L F
.719 .398 .435 r
.53396 .41521 m .53506 .41467 L .53514 .41449 L F
.53396 .41521 m .53514 .41449 L .5364 .41176 L F
.233 0 0 r
.53259 .41291 m .53369 .41326 L .53223 .41281 L F
.53228 .41281 m .53223 .41281 L .53034 .41222 L F
.603 .871 .537 r
.53259 .41272 m .53246 .41285 L .53253 .41288 L F
.84 .939 .89 r
.53232 .41285 m .53265 .41269 L .53259 .41291 L F
.233 0 0 r
.53259 .41291 m .53223 .41281 L .53228 .41281 L F
.53369 .41326 m .53473 .41361 L .53034 .41222 L F
.84 .939 .89 r
.53232 .41285 m .53272 .41245 L .53265 .41269 L F
.596 .864 .528 r
.53272 .41245 m .53248 .4127 L .5327 .41244 L F
.603 .871 .537 r
.5327 .41244 m .53232 .41286 L .53259 .41272 L F
.125 0 0 r
.54067 .40741 m .53885 .40642 L .5412 .40526 L F
.54067 .40741 m .53832 .40811 L .53885 .40642 L F
.736 .657 .772 r
.35237 .51993 m .34919 .52306 L .34755 .51901 L F
.658 .265 .29 r
.34998 .59114 m .34998 .5929 L .34749 .59064 L F
.87 .833 .808 r
.55072 .39513 m .54877 .39779 L .55026 .39623 L F
.377 .061 .297 r
.55072 .39513 m .54694 .39888 L .54877 .39779 L F
.54762 .3982 m .54956 .39855 L .54694 .39888 L F
.712 .811 .927 r
.55287 .39414 m .552 .39484 L .54996 .39472 L F
.509 .408 .676 r
.55072 .39513 m .55287 .39414 L .5533 .39574 L F
.55072 .39513 m .55026 .39623 L .55119 .39548 L F
.37 0 .106 r
.5533 .39574 m .55243 .3964 L .55119 .39548 L F
.55188 .39541 m .55119 .39548 L .55072 .39513 L F
.5533 .39574 m .55119 .39548 L .55188 .39541 L F
.712 .811 .927 r
.55057 .39555 m .55026 .39623 L .55016 .39576 L F
.509 .408 .676 r
.55072 .39513 m .55119 .39548 L .55287 .39414 L F
.712 .811 .927 r
.552 .39484 m .55119 .39548 L .55057 .39555 L F
.55119 .39548 m .55026 .39623 L .55057 .39555 L F
.37 0 .106 r
.55119 .39548 m .55057 .39555 L .55072 .39513 L F
.377 .061 .297 r
.55072 .39513 m .55067 .39528 L .55016 .39576 L F
.712 .811 .927 r
.552 .39484 m .55057 .39555 L .54996 .39472 L F
.892 .91 .831 r
.55026 .39623 m .54877 .39779 L .5492 .39669 L F
.55026 .39623 m .5492 .39669 L .55016 .39576 L F
.436 .238 .511 r
.54694 .39888 m .5492 .39669 L .54877 .39779 L F
.377 .061 .297 r
.55067 .39528 m .54956 .39855 L .54764 .3982 L F
.5492 .39669 m .54764 .3982 L .54762 .3982 L F
.55067 .39528 m .54764 .3982 L .5492 .39669 L F
.436 .238 .511 r
.54694 .39888 m .54996 .39472 L .5492 .39669 L F
.712 .811 .927 r
.55057 .39555 m .55016 .39576 L .55013 .3956 L F
.377 .061 .297 r
.55072 .39513 m .55016 .39576 L .55 .39584 L F
.712 .811 .927 r
.55057 .39555 m .55013 .3956 L .54996 .39472 L F
.37 0 .106 r
.55243 .3964 m .54956 .39855 L .55057 .39555 L F
.55243 .3964 m .55057 .39555 L .55119 .39548 L F
.377 .061 .297 r
.55 .39584 m .55016 .39576 L .54762 .3982 L F
.892 .91 .831 r
.55016 .39576 m .5492 .39669 L .54996 .39472 L F
.805 .884 .458 r
.3924 .60542 m .39206 .60721 L .39371 .6035 L F
.877 .893 .47 r
.39359 .6022 m .3924 .60542 L .39371 .6035 L F
.716 .984 .797 r
.72768 .32047 m .72962 .31989 L .73119 .31821 L F
.563 .442 .673 r
.48134 .51536 m .47963 .51957 L .47926 .51618 L F
0 0 0 r
.21984 .56167 m .2191 .56346 L .22107 .56006 L F
.979 .686 .374 r
.29878 .50649 m .29913 .50988 L .29709 .5083 L F
.603 .055 0 r
.29918 .50753 m .29878 .50649 L .29709 .5083 L F
.29918 .50753 m .29979 .50768 L .29878 .50649 L F
.973 .677 .393 r
.39485 .5548 m .39498 .55739 L .39658 .55823 L F
.978 .727 .319 r
.39498 .55739 m .39594 .56085 L .39658 .55823 L F
0 0 0 r
.27076 .62088 m .26936 .62297 L .27228 .61935 L F
.853 .931 .877 r
.42123 .4706 m .42528 .46862 L .42396 .46788 L F
.67 .894 .978 r
.42619 .46657 m .42396 .46788 L .42528 .46862 L F
.504 .438 .716 r
.4799 .52243 m .48027 .52528 L .47807 .52592 L F
.552 .447 .689 r
.48027 .52528 m .47853 .5295 L .47807 .52592 L F
.099 .482 .897 r
.58114 .38424 m .58324 .38383 L .58037 .38251 L F
.58114 .38424 m .58431 .38538 L .58324 .38383 L F
0 0 .263 r
.62225 .3627 m .62187 .36188 L .62263 .36017 L F
.82 .926 .544 r
.39081 .60926 m .39206 .60721 L .3924 .60542 L F
.91 .772 .696 r
.38371 .66637 m .38432 .66799 L .38487 .6648 L F
.494 .119 .257 r
.42167 .58054 m .42528 .57818 L .42407 .57994 L F
.254 0 0 r
.42528 .57818 m .42657 .57941 L .42407 .57994 L F
.337 .515 .885 r
.54814 .41829 m .54626 .41608 L .54731 .4189 L F
0 0 .353 r
.54601 .41453 m .54731 .4189 L .54626 .41608 L F
.2 .34 .781 r
.54864 .41629 m .54731 .4189 L .54601 .41453 L F
.743 .953 .646 r
.54864 .41629 m .54557 .42018 L .54731 .4189 L F
.54557 .42018 m .54549 .42029 L .54731 .4189 L F
.337 .515 .885 r
.54823 .41839 m .54814 .41829 L .54731 .4189 L F
.389 .028 .225 r
.55055 .41868 m .54823 .41839 L .54731 .4189 L F
.55055 .41868 m .55171 .41654 L .54823 .41839 L F
.89 .591 .474 r
.37306 .55547 m .37401 .55814 L .37207 .55641 L F
.975 .791 .593 r
.37207 .55641 m .37306 .55547 L .37175 .55539 L F
.594 .328 .483 r
.43591 .4871 m .4385 .48965 L .43881 .48749 L F
.43591 .4871 m .43568 .49013 L .4385 .48965 L F
.725 .754 .875 r
.31995 .62243 m .32408 .62302 L .32266 .62043 L F
.015 .227 .735 r
.32245 .62468 m .31995 .62243 L .32325 .62386 L F
.654 .884 .529 r
.32327 .62382 m .32245 .62468 L .32325 .62386 L F
.677 .209 .133 r
.32329 .6238 m .32404 .62301 L .32209 .62274 L F
.32323 .62378 m .32209 .62274 L .31995 .62243 L F
.32331 .62381 m .32209 .62274 L .32323 .62378 L F
.247 .266 .684 r
.3246 .62185 m .32327 .62382 L .32266 .62043 L F
.32327 .62382 m .32325 .62386 L .32323 .62378 L F
.32327 .62382 m .32323 .62378 L .32266 .62043 L F
.625 .537 .735 r
.32266 .62043 m .32323 .62378 L .31995 .62243 L F
.32323 .62378 m .32325 .62386 L .31995 .62243 L F
.677 .209 .133 r
.32245 .62468 m .32331 .62381 L .31995 .62243 L F
.654 .884 .529 r
.3246 .62185 m .32245 .62468 L .32327 .62382 L F
.677 .209 .133 r
.32331 .62381 m .32408 .62302 L .32404 .62301 L F
.32331 .62381 m .32404 .62301 L .32329 .6238 L F
.757 .431 .433 r
.3265 .62743 m .32615 .6268 L .32551 .62558 L F
0 0 0 r
.3269 .62333 m .32553 .62554 L .32551 .62558 L F
.757 .431 .433 r
.32615 .6268 m .3255 .6256 L .32551 .62558 L F
0 0 .419 r
.32662 .62755 m .3265 .62743 L .32551 .62558 L F
.635 .15 .084 r
.32431 .62932 m .32662 .62755 L .32192 .62737 L F
.359 0 0 r
.3242 .6277 m .32662 .62755 L .32547 .62751 L F
.3242 .6277 m .32547 .62751 L .32398 .62745 L F
.849 .499 .39 r
.3242 .6277 m .32662 .62755 L .32551 .62558 L F
0 0 0 r
.32553 .62554 m .3242 .6277 L .32551 .62558 L F
.757 .431 .433 r
.3255 .6256 m .32408 .62302 L .32551 .62558 L F
.754 .308 .193 r
.32551 .62558 m .32408 .62302 L .32245 .62468 L F
.759 .698 .794 r
.32396 .62269 m .32551 .62558 L .32245 .62468 L F
.3246 .62185 m .32551 .62558 L .32396 .62269 L F
.219 .325 .76 r
.3269 .62333 m .32551 .62558 L .32489 .62304 L F
.3269 .62333 m .32489 .62304 L .3246 .62185 L F
.6 .378 .551 r
.32979 .62262 m .32821 .62351 L .3269 .62333 L F
.736 .903 .523 r
.32568 .62495 m .3242 .6277 L .3269 .62333 L F
.6 .378 .551 r
.32821 .62351 m .32568 .62495 L .3269 .62333 L F
0 0 .17 r
.32465 .62821 m .3242 .6277 L .32568 .62495 L F
.32431 .62932 m .3242 .6277 L .32465 .62821 L F
.359 0 0 r
.3242 .6277 m .32398 .62745 L .32192 .62737 L F
.81 .366 .188 r
.32271 .62793 m .3242 .6277 L .32431 .62932 L F
0 0 .175 r
.321 .62611 m .32004 .6294 L .32192 .62737 L F
.81 .366 .188 r
.32057 .62605 m .3242 .6277 L .32271 .62793 L F
.719 .982 .905 r
.66245 .33249 m .66141 .33449 L .66396 .33201 L F
.66245 .33249 m .66034 .33409 L .66141 .33449 L F
.107 0 .329 r
.60911 .37886 m .6073 .3778 L .60948 .37659 L F
.60911 .37886 m .60718 .38003 L .6073 .3778 L F
.218 .728 .888 r
.34105 .61505 m .34266 .61541 L .33918 .6154 L F
0 0 0 r
.32977 .6523 m .32984 .65275 L .32917 .65295 L F
.736 .992 .842 r
.32593 .65497 m .32991 .65214 L .32977 .6523 L F
.498 .877 .676 r
.32593 .65497 m .32977 .6523 L .32793 .65332 L F
0 0 0 r
.32977 .6523 m .32917 .65295 L .32793 .65332 L F
.736 .992 .842 r
.32991 .65214 m .33083 .65149 L .32977 .6523 L F
.564 .415 .638 r
.33273 .64868 m .33337 .65128 L .33083 .65149 L F
.163 0 0 r
.33083 .65149 m .33337 .65128 L .33276 .65169 L F
.806 .509 .487 r
.55718 .4421 m .55589 .44111 L .55409 .44253 L F
.55589 .44111 m .55307 .43894 L .55409 .44253 L F
.785 .999 .823 r
.55279 .44355 m .55409 .44253 L .55543 .4408 L F
.55255 .44381 m .55409 .44253 L .55279 .44355 L F
.243 .368 .791 r
.55991 .4367 m .55847 .43851 L .55946 .43553 L F
.34 .117 .423 r
.55955 .43832 m .55779 .43938 L .55847 .43851 L F
.55955 .43832 m .55718 .4421 L .55543 .4408 L F
.136 0 0 r
.56192 .43809 m .56268 .43629 L .55955 .43832 L F
.127 0 0 r
.56095 .43942 m .55955 .43832 L .55847 .43851 L F
.56095 .43942 m .56192 .43809 L .56154 .43813 L F
.56095 .43942 m .56154 .43813 L .55955 .43832 L F
.243 .368 .791 r
.56095 .43942 m .55847 .43851 L .55991 .4367 L F
.936 .571 .283 r
.56063 .44011 m .56095 .43942 L .55967 .43755 L F
.5611 .44137 m .56095 .43942 L .56063 .44011 L F
.34 .117 .423 r
.55779 .43938 m .55543 .4408 L .55847 .43851 L F
.98 .85 .64 r
.6343 .39418 m .63408 .39577 L .63267 .3947 L F
.87 .903 .852 r
.63408 .39577 m .63121 .39674 L .63267 .3947 L F
.642 .523 .703 r
.6343 .39418 m .63709 .39349 L .63408 .39577 L F
.191 0 0 r
.33548 .52265 m .33422 .52443 L .33168 .52505 L F
.707 .252 .169 r
.33822 .52501 m .33422 .52443 L .33548 .52265 L F
.936 .677 .521 r
.72985 .32566 m .7304 .3301 L .72782 .32664 L F
.589 .848 .994 r
.73488 .32355 m .72985 .32566 L .72896 .32442 L F
0 0 0 r
.22647 .54548 m .22622 .54641 L .22748 .54407 L F
.22647 .54548 m .2253 .54818 L .22622 .54641 L F
.674 .961 .939 r
.55399 .41455 m .55171 .41654 L .55096 .4145 L F
.914 .906 .504 r
.55096 .4145 m .55171 .41654 L .55055 .41868 L F
.392 .133 .396 r
.35955 .60047 m .35914 .60359 L .3567 .6036 L F
.393 .133 .397 r
.36165 .60243 m .35955 .60047 L .36227 .60037 L F
.36165 .60243 m .35914 .60359 L .35955 .60047 L F
0 0 0 r
.33963 .51412 m .33855 .51964 L .33694 .51563 L F
.802 .674 .723 r
.34545 .51767 m .33927 .51738 L .34176 .51723 L F
0 0 0 r
.33963 .51412 m .33934 .51673 L .33933 .51677 L F
.3396 .51431 m .33933 .51677 L .33855 .51964 L F
.33963 .51412 m .33933 .51677 L .3396 .51431 L F
.684 .485 .611 r
.33791 .51691 m .33918 .51737 L .33927 .51737 L F
.33931 .51702 m .33927 .51737 L .34176 .51723 L F
0 0 0 r
.33934 .51673 m .33928 .51728 L .33925 .51738 L F
.684 .485 .611 r
.33791 .51691 m .33927 .51737 L .33931 .51702 L F
.625 .936 .962 r
.33694 .51563 m .33764 .51415 L .33963 .51412 L F
.33694 .51563 m .33764 .51415 L .33963 .51412 L F
.739 .493 .558 r
.33791 .51691 m .33945 .51601 L .33764 .51415 L F
.72 .373 .39 r
.34176 .51723 m .33963 .51412 L .3419 .51457 L F
.802 .674 .723 r
.33927 .51738 m .33927 .51737 L .34176 .51723 L F
0 0 0 r
.33934 .51673 m .33925 .51738 L .33855 .51964 L F
.739 .493 .558 r
.33791 .51691 m .34176 .51723 L .33836 .51665 L F
0 0 0 r
.33928 .51732 m .33921 .51765 L .33855 .51964 L F
.33928 .51729 m .33927 .51735 L .33855 .51964 L F
.773 .74 .823 r
.34366 .52133 m .33899 .51921 L .33926 .51744 L F
.533 .356 .587 r
.33924 .51756 m .33885 .51774 L .33855 .51964 L F
.33885 .51774 m .33594 .51938 L .33855 .51964 L F
.594 .639 .865 r
.33884 .51914 m .33883 .51922 L .33551 .51934 L F
.33883 .51922 m .33822 .52501 L .33591 .52019 L F
.33883 .51922 m .33591 .52019 L .33551 .51934 L F
.33883 .51922 m .34128 .52608 L .33822 .52501 L F
.33884 .51914 m .33886 .5192 L .33883 .51922 L F
.33886 .5192 m .34128 .52608 L .33883 .51922 L F
.773 .74 .823 r
.33899 .51921 m .33884 .51914 L .33926 .51744 L F
.432 .259 .545 r
.3389 .51918 m .33923 .51753 L .33915 .51757 L F
.773 .74 .823 r
.34366 .52133 m .34128 .52608 L .33892 .51937 L F
.339 .51922 m .33892 .51937 L .33884 .51914 L F
.34366 .52133 m .33892 .51937 L .339 .51922 L F
.802 .674 .723 r
.34545 .51767 m .34366 .52133 L .33926 .51744 L F
.541 .424 .669 r
.34063 .52233 m .34281 .51781 L .34004 .51747 L F
.773 .74 .823 r
.33926 .51744 m .33923 .51756 L .33918 .51737 L F
.802 .674 .723 r
.33927 .51738 m .33926 .51744 L .33918 .51737 L F
.214 .057 .44 r
.33927 .51737 m .33926 .51749 L .34176 .51723 L F
.541 .424 .669 r
.33949 .51841 m .33927 .51738 L .33924 .51757 L F
0 0 0 r
.33927 .51741 m .33926 .51749 L .33925 .51752 L F
.33927 .51737 m .33926 .51743 L .33921 .51765 L F
.33927 .51741 m .33925 .51752 L .33921 .51765 L F
.541 .424 .669 r
.33924 .51757 m .33926 .51745 L .33918 .51737 L F
.802 .674 .723 r
.33927 .51738 m .33918 .51737 L .33927 .51737 L F
.214 .057 .44 r
.33918 .51737 m .33926 .51745 L .33927 .51737 L F
.802 .674 .723 r
.34545 .51767 m .33926 .51744 L .33927 .51738 L F
0 0 0 r
.33928 .51732 m .33927 .51741 L .33926 .51743 L F
.541 .424 .669 r
.33926 .51745 m .33927 .51738 L .33918 .51737 L F
.214 .057 .44 r
.33918 .51737 m .33926 .51749 L .33926 .51745 L F
0 0 0 r
.33928 .51732 m .33926 .51743 L .33927 .51737 L F
.541 .424 .669 r
.33949 .51841 m .34004 .51747 L .33927 .51738 L F
.34063 .52233 m .34004 .51747 L .33949 .51841 L F
.432 .259 .545 r
.33837 .52267 m .33896 .51915 L .3389 .51918 L F
.33896 .51915 m .33923 .51753 L .3389 .51918 L F
.33837 .52267 m .34063 .52233 L .33964 .51895 L F
.33895 .51918 m .33964 .51895 L .33923 .51753 L F
.33837 .52267 m .33964 .51895 L .33895 .51918 L F
.773 .74 .823 r
.33923 .51756 m .33914 .51758 L .33918 .51737 L F
.432 .259 .545 r
.33915 .51757 m .33923 .51753 L .33918 .51737 L F
.533 .356 .587 r
.33885 .51774 m .33551 .51934 L .33594 .51938 L F
.214 .057 .44 r
.33918 .51737 m .33914 .51758 L .33926 .51749 L F
.533 .356 .587 r
.33926 .51749 m .33914 .51758 L .33924 .51756 L F
.773 .74 .823 r
.33923 .51756 m .33884 .51914 L .33914 .51758 L F
.214 .057 .44 r
.33914 .51758 m .33884 .51914 L .33926 .51749 L F
.432 .259 .545 r
.33837 .52267 m .33915 .51757 L .33884 .51914 L F
.33915 .51757 m .33918 .51737 L .33914 .51758 L F
.33915 .51757 m .33914 .51758 L .33884 .51914 L F
.533 .356 .587 r
.33914 .51758 m .33551 .51934 L .33924 .51756 L F
.684 .485 .611 r
.33791 .51691 m .33831 .51788 L .33918 .51737 L F
.533 .356 .587 r
.33894 .51765 m .33551 .51934 L .33914 .51758 L F
.33894 .51765 m .33884 .51914 L .33551 .51934 L F
.684 .485 .611 r
.33894 .51765 m .33884 .51914 L .33914 .51758 L F
.33831 .51788 m .33914 .51758 L .33918 .51737 L F
.533 .356 .587 r
.33901 .51762 m .33894 .51765 L .33914 .51758 L F
.33906 .51759 m .33901 .51762 L .33914 .51758 L F
.33926 .51749 m .33906 .51759 L .33914 .51758 L F
.33926 .51749 m .33884 .51914 L .33894 .51765 L F
.684 .485 .611 r
.33831 .51788 m .33884 .51914 L .33894 .51765 L F
0 0 0 r
.33928 .51728 m .33927 .51734 L .33927 .51735 L F
.33928 .51728 m .33927 .51735 L .33928 .51729 L F
.357 .111 .397 r
.33918 .51737 m .33925 .51735 L .34176 .51723 L F
.72 .373 .39 r
.34176 .51723 m .33928 .51734 L .33934 .51681 L F
.34176 .51723 m .33934 .51681 L .33963 .51412 L F
.739 .493 .558 r
.33836 .51665 m .34176 .51723 L .3419 .51457 L F
.817 .562 .554 r
.34499 .51727 m .34176 .51723 L .3419 .51457 L F
.34545 .51767 m .34176 .51723 L .34499 .51727 L F
.357 .111 .397 r
.33925 .51735 m .33963 .5172 L .34176 .51723 L F
.33963 .5172 m .34307 .5159 L .34176 .51723 L F
.72 .373 .39 r
.34176 .51723 m .33926 .51749 L .33928 .51734 L F
.781 .768 .841 r
.34545 .51767 m .34176 .51723 L .3441 .51491 L F
.511 .827 .516 r
.34176 .51723 m .34307 .5159 L .3441 .51491 L F
.357 .111 .397 r
.33925 .51735 m .34281 .51781 L .34307 .5159 L F
.33918 .51737 m .33925 .51738 L .33925 .51735 L F
.33925 .51738 m .34281 .51781 L .33925 .51735 L F
.72 .373 .39 r
.33926 .51749 m .33926 .51749 L .33926 .51747 L F
.33926 .51749 m .33926 .51747 L .33928 .51734 L F
.739 .493 .558 r
.33945 .51601 m .3419 .51457 L .33968 .51435 L F
.33945 .51601 m .33968 .51435 L .33764 .51415 L F
0 0 0 r
.33928 .51728 m .33928 .51732 L .33927 .51734 L F
.782 .7 .774 r
.36249 .63224 m .36653 .63261 L .36394 .63588 L F
.787 .607 .657 r
.31461 .54885 m .31085 .55134 L .31069 .54849 L F
.31461 .54885 m .31514 .55181 L .31085 .55134 L F
.699 .783 .302 r
.31677 .54766 m .31514 .55181 L .31461 .54885 L F
.964 .723 .522 r
.73813 .31531 m .73945 .31851 L .73763 .31643 L F
.44 .656 .952 r
.73945 .31851 m .74234 .31918 L .73763 .31643 L F
.832 .916 .892 r
.46638 .54914 m .46281 .55203 L .46171 .5483 L F
.314 .197 .556 r
.33912 .68427 m .3383 .68741 L .34017 .68734 L F
.314 .426 .816 r
.3383 .68741 m .34131 .68935 L .34017 .68734 L F
.679 .206 .122 r
.34131 .68935 m .3383 .68741 L .33886 .68986 L F
.236 0 0 r
.61465 .39117 m .61297 .3902 L .61169 .38993 L F
.61465 .39117 m .61544 .38984 L .61297 .3902 L F
.717 .448 .518 r
.33273 .64868 m .33617 .64884 L .33616 .65143 L F
.974 .669 .368 r
.63277 .38995 m .6343 .39418 L .62957 .39442 L F
.863 .995 .809 r
.63267 .3947 m .62922 .39728 L .63097 .39525 L F
.98 .85 .64 r
.63428 .39418 m .63267 .3947 L .62957 .39442 L F
.121 .63 .898 r
.62957 .39442 m .63002 .39446 L .63195 .39412 L F
.63002 .39446 m .63267 .3947 L .63195 .39412 L F
.863 .995 .809 r
.63267 .3947 m .63097 .39525 L .63195 .39412 L F
.63267 .3947 m .63121 .39674 L .62922 .39728 L F
0 0 .005 r
.63278 .39397 m .63195 .39412 L .6316 .39572 L F
.63371 .39258 m .63195 .39412 L .63278 .39397 L F
.98 .85 .64 r
.6343 .39418 m .63267 .3947 L .63428 .39418 L F
0 0 0 r
.55861 .46991 m .56249 .46747 L .56102 .46903 L F
.56102 .46903 m .56249 .46747 L .56494 .46646 L F
.532 .285 .486 r
.34696 .54187 m .34668 .54498 L .34384 .54532 L F
.578 .429 .643 r
.44601 .56518 m .4463 .56781 L .44891 .56482 L F
.248 0 0 r
.46511 .59049 m .466 .5916 L .46353 .59216 L F
.46511 .59049 m .46776 .59022 L .466 .5916 L F
.693 .534 .668 r
.28269 .63663 m .28693 .6391 L .28567 .63542 L F
.146 .233 .697 r
.28567 .63542 m .28715 .63893 L .28787 .63741 L F
.176 .511 .913 r
.28739 .63877 m .28759 .6382 L .28715 .63893 L F
.28739 .63877 m .28715 .63893 L .28703 .63919 L F
.28759 .6382 m .28787 .63741 L .28697 .63921 L F
.28702 .63915 m .28697 .63921 L .28692 .63932 L F
.28759 .6382 m .28697 .63921 L .28702 .63915 L F
.978 .794 .38 r
.28692 .63932 m .28711 .64225 L .28739 .63877 L F
.758 .312 .191 r
.28662 .63967 m .28732 .63933 L .28702 .63915 L F
.28662 .63967 m .28702 .63915 L .28269 .63663 L F
.146 .233 .697 r
.28715 .63893 m .28732 .63933 L .28787 .63741 L F
.176 .511 .913 r
.28703 .63919 m .28715 .63893 L .28692 .63932 L F
.28692 .63932 m .28787 .63741 L .28662 .63967 L F
.693 .534 .668 r
.28693 .6391 m .28702 .63915 L .28694 .63843 L F
.28702 .63915 m .28732 .63933 L .28715 .63893 L F
.28702 .63915 m .28715 .63893 L .28694 .63843 L F
.28693 .6391 m .28694 .63843 L .28567 .63542 L F
.978 .794 .38 r
.28662 .63967 m .28688 .64104 L .28692 .63932 L F
.28688 .64104 m .28711 .64225 L .28692 .63932 L F
.176 .511 .913 r
.28739 .63877 m .28977 .63972 L .28787 .63741 L F
.355 .281 .634 r
.41741 .50664 m .41848 .5068 L .42041 .50695 L F
.198 .234 .673 r
.41641 .50669 m .41829 .50774 L .41741 .50664 L F
.355 .281 .634 r
.41741 .50664 m .41829 .50774 L .42012 .50705 L F
.1 .258 .74 r
.41777 .50531 m .41829 .50774 L .41641 .50669 L F
.914 .829 .749 r
.41808 .50677 m .41595 .50872 L .41829 .50774 L F
.41777 .50531 m .41704 .50669 L .41808 .50677 L F
.41704 .50669 m .41595 .50872 L .41808 .50677 L F
.355 .281 .634 r
.42041 .50695 m .42012 .50705 L .4235 .50728 L F
.41848 .5068 m .42012 .50705 L .42041 .50695 L F
.592 .932 .952 r
.4256 .50607 m .4235 .50728 L .42012 .50705 L F
0 0 .51 r
.34139 .5021 m .34435 .50596 L .34464 .50621 L F
.482 .269 .513 r
.50983 .48723 m .50974 .48998 L .50706 .49043 L F
.62 .436 .612 r
.50974 .48998 m .50719 .49276 L .50706 .49043 L F
0 0 .011 r
.69929 .35937 m .69777 .36158 L .69931 .3578 L F
0 0 0 r
.6968 .3635 m .69777 .36158 L .69929 .35937 L F
.419 .473 .809 r
.56625 .43887 m .56268 .43629 L .56435 .43539 L F
.752 .516 .575 r
.56192 .43809 m .56435 .43539 L .56268 .43629 L F
.733 .38 .382 r
.61575 .35968 m .61937 .35821 L .61529 .35794 L F
.61575 .35968 m .61909 .3594 L .61937 .35821 L F
.657 .484 .638 r
.61909 .3594 m .62209 .3574 L .61937 .35821 L F
.227 .36 .791 r
.33886 .68986 m .34204 .69348 L .34131 .68935 L F
.083 .622 .854 r
.25804 .62587 m .26055 .62617 L .25638 .62547 L F
.74 .23 .004 r
.69254 .33482 m .69115 .3358 L .69068 .33414 L F
.7 .217 0 r
.69254 .33482 m .69566 .33866 L .69475 .33729 L F
.74 .23 .004 r
.69254 .33482 m .69475 .33729 L .69115 .3358 L F
.71 .659 .798 r
.43085 .49698 m .42804 .50028 L .43225 .50016 L F
.443 .195 .442 r
.42804 .50028 m .4303 .50128 L .43225 .50016 L F
.42804 .50028 m .42796 .50258 L .43052 .50138 L F
.698 .927 .967 r
.42835 .50164 m .4274 .50142 L .429 .5001 L F
.42796 .50258 m .42758 .50179 L .42835 .50164 L F
.42758 .50179 m .4274 .50142 L .42835 .50164 L F
.443 .195 .442 r
.4303 .50128 m .43052 .50138 L .43078 .50119 L F
.4303 .50128 m .43078 .50119 L .43225 .50016 L F
.987 .801 .57 r
.43331 .50069 m .43225 .50016 L .43052 .50138 L F
.43331 .50069 m .43514 .50016 L .43225 .50016 L F
0 0 0 r
.59872 .46237 m .60116 .46107 L .5997 .46225 L F
.59872 .46237 m .5997 .46225 L .5973 .46159 L F
.577 .621 .859 r
.3808 .66581 m .38432 .66799 L .38371 .66637 L F
.293 0 .006 r
.38432 .66799 m .38029 .67052 L .38286 .67062 L F
.698 .307 .304 r
.38286 .67062 m .38731 .66989 L .38432 .66799 L F
.961 .653 .397 r
.38834 .53947 m .38826 .54142 L .39006 .54233 L F
.974 .668 .354 r
.38869 .54368 m .39006 .54233 L .38826 .54142 L F
.38869 .54368 m .39024 .54486 L .39006 .54233 L F
.498 .301 .544 r
.33687 .55801 m .33912 .55502 L .33686 .55587 L F
.33687 .55801 m .33944 .55787 L .33912 .55502 L F
0 .111 .659 r
.33687 .55801 m .33901 .56032 L .33944 .55787 L F
.533 .632 .895 r
.36391 .62309 m .36781 .62296 L .36611 .62156 L F
.36391 .62309 m .36759 .62561 L .36781 .62296 L F
.498 .269 .498 r
.36781 .62296 m .36743 .61821 L .36611 .62156 L F
.5 .275 .505 r
.36781 .62296 m .37035 .62257 L .36759 .62561 L F
.36781 .62296 m .37035 .62257 L .36759 .62561 L F
.002 0 .024 r
.31826 .61296 m .32109 .61206 L .32106 .60991 L F
0 0 .366 r
.32106 .60991 m .32286 .60895 L .32306 .60553 L F
0 0 .023 r
.32106 .60991 m .32177 .61112 L .32286 .60895 L F
.32106 .60991 m .32109 .61206 L .32177 .61112 L F
0 0 .085 r
.33314 .61867 m .33106 .62271 L .33238 .62152 L F
.052 .057 .543 r
.33238 .62152 m .33106 .62271 L .33256 .62511 L F
0 .12 .66 r
.55457 .42656 m .55421 .42925 L .55285 .42535 L F
.452 .736 .988 r
.42518 .59257 m .42789 .59359 L .42556 .59376 L F
.967 .889 .512 r
.42518 .59257 m .42556 .59376 L .42459 .59663 L F
.647 .742 .918 r
.50924 .42291 m .50489 .42193 L .50821 .41955 L F
.802 .729 .784 r
.51187 .41959 m .50924 .42291 L .50821 .41955 L F
.619 .537 .74 r
.72357 .31198 m .72076 .31331 L .72002 .30878 L F
.674 .959 .732 r
.68947 .31386 m .68627 .31668 L .68765 .31623 L F
0 0 0 r
.65029 .38216 m .649 .38217 L .64822 .38334 L F
.382 .812 .643 r
.29449 .65622 m .29456 .65629 L .29212 .65712 L F
.29449 .65622 m .29677 .65499 L .29456 .65629 L F
.832 .916 .892 r
.46638 .54914 m .46171 .5483 L .46483 .55036 L F
.837 .951 .601 r
.46638 .54914 m .46641 .54748 L .46694 .54784 L F
.46638 .54914 m .46483 .55036 L .46641 .54748 L F
.752 .991 .794 r
.42236 .51654 m .41965 .51808 L .41923 .5196 L F
.542 .378 .608 r
.41923 .5196 m .42185 .5194 L .42236 .51654 L F
.945 .611 .36 r
.41965 .51808 m .42185 .5194 L .41923 .5196 L F
.637 .905 .984 r
.66061 .37733 m .65879 .37754 L .65959 .37731 L F
0 0 0 r
.66073 .37699 m .65959 .37731 L .65854 .3778 L F
.441 .878 .861 r
.66322 .37624 m .65959 .37731 L .6626 .3763 L F
0 0 0 r
.6626 .3763 m .65959 .37731 L .66073 .37699 L F
.637 .905 .984 r
.65879 .37754 m .65665 .37778 L .65959 .37731 L F
.441 .878 .861 r
.66322 .37624 m .66061 .37733 L .65959 .37731 L F
.627 .832 .979 r
.28937 .51604 m .29124 .51754 L .29356 .51644 L F
.55 .926 .92 r
.38037 .48053 m .38186 .47936 L .38302 .47942 L F
.628 .535 .73 r
.37986 .48163 m .38186 .47936 L .38037 .48053 L F
.794 .778 .839 r
.3345 .55368 m .33686 .55587 L .33912 .55502 L F
.351 .668 .975 r
.33912 .55502 m .33963 .55312 L .33719 .5536 L F
.33912 .55502 m .34368 .55531 L .33963 .55312 L F
.386 .223 .534 r
.33912 .55502 m .33944 .55787 L .34155 .55708 L F
.407 .331 .659 r
.33964 .55336 m .33719 .5536 L .33963 .55312 L F
.42 .777 .996 r
.33495 .55381 m .33912 .55502 L .33719 .5536 L F
.407 .331 .659 r
.33966 .5558 m .33719 .5536 L .33964 .55336 L F
.42 .777 .996 r
.3345 .55368 m .33495 .55381 L .33719 .5536 L F
0 0 .014 r
.31607 .63032 m .3146 .63176 L .31632 .62803 L F
0 0 .042 r
.31788 .62972 m .31632 .62803 L .31805 .62698 L F
.31788 .62972 m .31607 .63032 L .31632 .62803 L F
.766 .502 .535 r
.57997 .42269 m .5753 .42173 L .57524 .41986 L F
.693 .226 .14 r
.62143 .38643 m .62377 .38632 L .62266 .38565 L F
.498 0 0 r
.5878 .40136 m .58781 .40046 L .58691 .39882 L F
.5878 .40136 m .59092 .40199 L .58781 .40046 L F
.634 .538 .728 r
.31677 .54766 m .316 .54457 L .31715 .54513 L F
.665 .625 .8 r
.31715 .54513 m .32033 .54493 L .31974 .54264 L F
.501 .83 .999 r
.316 .54457 m .32033 .54493 L .31715 .54513 L F
0 0 0 r
.32033 .54493 m .31677 .54766 L .31715 .54513 L F
.77 .681 .764 r
.23492 .58627 m .23892 .58741 L .23753 .58364 L F
.588 .582 .814 r
.23753 .58364 m .23892 .58741 L .24143 .58593 L F
.72 .811 .921 r
.25062 .52575 m .25329 .52742 L .25539 .5259 L F
.794 .817 .87 r
.47902 .43893 m .47523 .43873 L .4773 .43731 L F
.794 .866 .902 r
.48035 .435 m .47902 .43893 L .4773 .43731 L F
.48035 .435 m .48201 .43646 L .47902 .43893 L F
0 0 0 r
.42562 .53937 m .42289 .54141 L .42342 .54004 L F
.959 .694 .489 r
.60489 .4121 m .60681 .41669 L .60597 .41453 L F
.998 .836 .498 r
.60597 .41453 m .60681 .41669 L .60639 .41823 L F
.658 .487 .641 r
.36967 .67776 m .3726 .67469 L .36828 .67424 L F
.977 .831 .633 r
.6093 .42239 m .60684 .42425 L .60746 .42119 L F
.6093 .42239 m .60827 .42553 L .60684 .42425 L F
.708 .203 .033 r
.6263 .40269 m .6293 .40335 L .62827 .40466 L F
.961 .628 .268 r
.6293 .40335 m .62972 .40575 L .62827 .40466 L F
.997 .853 .535 r
.69475 .33729 m .69566 .33866 L .69489 .34075 L F
.758 .983 .744 r
.68883 .37278 m .69048 .37203 L .69205 .37019 L F
.784 .692 .762 r
.365 .62888 m .36653 .63261 L .36249 .63224 L F
0 .074 .634 r
.36689 .63126 m .36653 .63261 L .365 .62888 L F
.316 0 0 r
.36755 .6341 m .36942 .63242 L .36653 .63261 L F
.36755 .6341 m .36653 .63261 L .36689 .63126 L F
.498 .253 .473 r
.35242 .56803 m .35224 .57072 L .34965 .57093 L F
.34965 .57093 m .35224 .57072 L .35242 .56803 L F
0 0 .12 r
.35312 .56798 m .35242 .56803 L .35466 .56641 L F
.664 .398 .508 r
.35224 .57072 m .35535 .56771 L .35242 .56803 L F
0 0 .12 r
.35312 .56798 m .35224 .57072 L .35242 .56803 L F
.908 .788 .306 r
.39622 .59233 m .39698 .59059 L .39669 .58961 L F
.39622 .59233 m .39655 .59305 L .39698 .59059 L F
.92 .85 .405 r
.3974 .5857 m .39669 .58961 L .39698 .59059 L F
.54 .316 .523 r
.5124 .48931 m .50983 .48723 L .51257 .48678 L F
.5124 .48931 m .50974 .48998 L .50983 .48723 L F
.802 .729 .784 r
.51187 .41959 m .50821 .41955 L .50981 .41781 L F
.93 .907 .778 r
.51273 .4147 m .51187 .41959 L .50981 .41781 L F
.437 .202 .458 r
.49859 .49992 m .4959 .50295 L .4957 .50021 L F
.314 .197 .556 r
.33912 .68427 m .34017 .68734 L .33994 .68375 L F
0 0 0 r
.46157 .56396 m .4648 .56098 L .46214 .56149 L F
.47745 .57557 m .47715 .57618 L .47799 .57449 L F
.47684 .57681 m .47715 .57618 L .47658 .57795 L F
.731 .837 .389 r
.47658 .57795 m .47715 .57618 L .47592 .57867 L F
0 0 0 r
.47592 .57867 m .47715 .57618 L .47745 .57557 L F
.47758 .57352 m .47715 .57618 L .47684 .57681 L F
.731 .837 .389 r
.47658 .57795 m .47592 .57867 L .47581 .58046 L F
.555 .399 .624 r
.33619 .58796 m .33933 .58718 L .33936 .58414 L F
.55 .386 .611 r
.33933 .58718 m .336 .58943 L .33619 .58796 L F
.555 .399 .624 r
.33619 .58796 m .33933 .58718 L .33936 .58414 L F
.55 .386 .611 r
.33933 .58718 m .336 .58943 L .33619 .58796 L F
.654 .581 .761 r
.3338 .54567 m .33706 .54563 L .33593 .54184 L F
.62 .804 .97 r
.33301 .54817 m .33706 .54563 L .3338 .54567 L F
0 0 0 r
.31256 .61959 m .31369 .61994 L .31549 .61623 L F
.08 0 .027 r
.31826 .61296 m .31951 .61422 L .32109 .61206 L F
.845 .761 .77 r
.32177 .61112 m .31951 .61422 L .31936 .61413 L F
0 0 .039 r
.31549 .61623 m .31838 .61538 L .31826 .61296 L F
.31838 .61538 m .31854 .61518 L .31826 .61296 L F
.08 0 .027 r
.31826 .61296 m .31856 .61533 L .31951 .61422 L F
.845 .761 .77 r
.32164 .61118 m .31936 .61413 L .31757 .61298 L F
.32177 .61112 m .31936 .61413 L .32164 .61118 L F
0 0 .039 r
.31838 .61538 m .31856 .61533 L .31854 .61518 L F
.66 .589 .765 r
.31369 .61994 m .31856 .61533 L .31549 .61623 L F
.828 .507 .446 r
.43881 .48749 m .44232 .48983 L .4417 .48577 L F
.43881 .48749 m .4385 .48965 L .44232 .48983 L F
.833 .807 .825 r
.4385 .48965 m .44045 .49131 L .44232 .48983 L F
.611 .57 .783 r
.4417 .48577 m .44232 .48983 L .44501 .48713 L F
.535 .014 0 r
.29086 .64368 m .29126 .64229 L .28711 .64225 L F
.735 .434 0 r
.29154 .64388 m .29126 .64229 L .29092 .64346 L F
.29154 .64388 m .2921 .64526 L .29189 .64452 L F
.29154 .64388 m .29189 .64452 L .29126 .64229 L F
0 .108 .608 r
.29136 .64354 m .29154 .64388 L .29006 .64236 L F
.29223 .64434 m .29154 .64388 L .29136 .64354 L F
.29353 .64554 m .29154 .64388 L .29223 .64434 L F
.735 .434 0 r
.29154 .64388 m .29092 .64346 L .29086 .64368 L F
.029 .601 .737 r
.43693 .52622 m .43212 .52617 L .43384 .52636 L F
.342 0 .227 r
.31408 .54572 m .31069 .54849 L .31315 .54754 L F
.799 .826 .872 r
.42409 .50069 m .42804 .50028 L .42613 .49873 L F
.835 .896 .883 r
.42613 .49873 m .42804 .50028 L .43085 .49698 L F
0 0 .552 r
.34603 .62494 m .34435 .62279 L .34486 .62128 L F
.116 .054 .504 r
.34603 .62494 m .34439 .62636 L .34435 .62279 L F
.996 .81 .447 r
.39687 .5825 m .39819 .58076 L .39752 .57986 L F
.39687 .5825 m .39769 .5833 L .39819 .58076 L F
0 .028 .559 r
.43094 .53285 m .43078 .53457 L .42921 .53178 L F
.43094 .53285 m .42921 .53178 L .42686 .53112 L F
.45 .763 .996 r
.73242 .33184 m .73473 .33038 L .73096 .33036 L F
.73242 .33184 m .73517 .33138 L .73473 .33038 L F
.461 .011 .094 r
.54415 .47435 m .54571 .47613 L .54329 .47671 L F
.54415 .47435 m .54692 .47413 L .54571 .47613 L F
.398 .328 .661 r
.43097 .54567 m .43391 .54741 L .432 .54704 L F
0 0 .498 r
.43097 .54567 m .432 .54704 L .43024 .54438 L F
.5 0 0 r
.28277 .57218 m .28236 .57159 L .28095 .57235 L F
.28277 .57218 m .28452 .57341 L .28236 .57159 L F
.587 .161 .2 r
.28236 .57159 m .28452 .57341 L .285 .57165 L F
0 0 0 r
.65807 .32194 m .66024 .32085 L .66163 .31952 L F
.66163 .31952 m .66278 .31948 L .66333 .3178 L F
.66163 .31952 m .66024 .32085 L .66278 .31948 L F
.528 .011 0 r
.33468 .65758 m .33005 .65789 L .33398 .65588 L F
.063 0 0 r
.33308 .65943 m .337 .65684 L .335 .65853 L F
.505 .544 .83 r
.33478 .65837 m .33308 .65943 L .335 .65853 L F
.595 .895 .608 r
.33172 .66028 m .33468 .65758 L .33308 .65943 L F
.063 0 0 r
.33308 .65943 m .33468 .65758 L .337 .65684 L F
.505 .544 .83 r
.33243 .65675 m .33308 .65943 L .33478 .65837 L F
.595 .895 .608 r
.33092 .66101 m .33172 .66028 L .33308 .65943 L F
.497 .656 .931 r
.337 .65684 m .33468 .65758 L .33398 .65588 L F
.672 .367 0 r
.38247 .67995 m .37928 .67764 L .38046 .6816 L F
.259 .259 .669 r
.38247 .67995 m .38046 .6816 L .38436 .68194 L F
.759 .7 .796 r
.39104 .68419 m .38984 .68635 L .38689 .68369 L F
.429 .035 .188 r
.39127 .47352 m .39467 .47077 L .39374 .47281 L F
.512 .622 .897 r
.34614 .69423 m .35037 .69701 L .34866 .6933 L F
.383 .485 .84 r
.34866 .6933 m .35037 .69701 L .35245 .6967 L F
.654 .952 .73 r
.65807 .32194 m .65475 .3243 L .65683 .32262 L F
0 0 0 r
.65683 .32262 m .66024 .32085 L .65807 .32194 L F
.796 .998 .854 r
.63278 .35806 m .62904 .35995 L .6313 .35731 L F
.562 .559 .808 r
.63399 .35319 m .63278 .35806 L .6313 .35731 L F
.63399 .35319 m .6356 .35741 L .63278 .35806 L F
.183 .06 .467 r
.63448 .35892 m .63278 .35806 L .63491 .3586 L F
.63467 .35902 m .63297 .36078 L .63278 .35806 L F
.756 .994 .81 r
.63093 .36142 m .63132 .3613 L .63418 .35841 L F
.63132 .3613 m .63297 .36078 L .63356 .35961 L F
.63132 .3613 m .63356 .35961 L .63418 .35841 L F
.183 .06 .467 r
.63491 .3586 m .63278 .35806 L .6356 .35741 L F
.63467 .35902 m .63448 .35892 L .63491 .3586 L F
.204 .551 .932 r
.24408 .61877 m .24596 .62092 L .24847 .62125 L F
.792 .571 .6 r
.40267 .4959 m .40725 .4939 L .4054 .49268 L F
.40267 .4959 m .40705 .49672 L .40725 .4939 L F
.403 .581 .912 r
.40784 .49232 m .40979 .49424 L .40725 .4939 L F
.859 .72 .197 r
.40725 .4939 m .40701 .49455 L .4054 .49268 L F
.40725 .4939 m .40705 .49672 L .40701 .49455 L F
.012 0 0 r
.44011 .47904 m .43987 .47932 L .43634 .47986 L F
.831 .554 .007 r
.44011 .47904 m .44056 .48114 L .43987 .47932 L F
.29 .486 .877 r
.43665 .46115 m .43817 .45976 L .43478 .4586 L F
.534 .909 .952 r
.43665 .46115 m .4355 .46058 L .43817 .45976 L F
.484 .502 .8 r
.36531 .55154 m .36621 .54646 L .36483 .54893 L F
.972 .701 .46 r
.33806 .61278 m .33827 .61575 L .33918 .6154 L F
.218 .728 .888 r
.34105 .61505 m .33918 .6154 L .33827 .61575 L F
.372 .839 .825 r
.59105 .35429 m .59336 .35311 L .59316 .35344 L F
.388 .842 .913 r
.59037 .35392 m .59336 .35311 L .59105 .35429 L F
.389 .839 .923 r
.28009 .5152 m .28102 .51436 L .28305 .51347 L F
.28009 .5152 m .27855 .51493 L .28102 .51436 L F
.417 .839 .961 r
.58465 .4598 m .58826 .45957 L .58679 .45865 L F
.649 .883 .983 r
.58679 .45865 m .58826 .45957 L .58994 .45873 L F
.655 .872 .98 r
.58826 .45957 m .59132 .45887 L .58994 .45873 L F
.419 .122 .352 r
.43745 .49922 m .44067 .49672 L .43794 .4973 L F
.911 .845 .766 r
.41645 .48015 m .41477 .48403 L .41292 .48268 L F
.664 .398 .508 r
.35224 .57072 m .35546 .57065 L .35535 .56771 L F
.047 0 .4 r
.35535 .56771 m .35705 .56988 L .35901 .56783 L F
.35535 .56771 m .35546 .57065 L .35705 .56988 L F
.845 .67 .665 r
.3793 .60325 m .37653 .60618 L .37698 .60379 L F
.484 .798 .999 r
.70091 .30472 m .7023 .30604 L .70102 .30229 L F
.70091 .30472 m .70482 .30539 L .7023 .30604 L F
.43 .248 .531 r
.70482 .30539 m .70263 .30871 L .7023 .30604 L F
0 0 0 r
.34183 .54951 m .34198 .54813 L .3424 .54918 L F
.586 .519 .746 r
.33706 .54563 m .33806 .54906 L .34198 .54813 L F
.33706 .54563 m .34198 .54813 L .33878 .54526 L F
.406 .518 .859 r
.33878 .54526 m .34198 .54813 L .34038 .54324 L F
.627 .698 .896 r
.34223 .54971 m .34125 .54627 L .34198 .54813 L F
.34125 .54627 m .34038 .54324 L .34198 .54813 L F
0 0 0 r
.3424 .54918 m .34198 .54813 L .34408 .54821 L F
.34183 .54951 m .34223 .54971 L .34198 .54813 L F
.34183 .54951 m .33959 .55029 L .34223 .54971 L F
.416 .371 .7 r
.35914 .60359 m .3595 .60592 L .3567 .6036 L F
.483 .371 .65 r
.3567 .6036 m .3595 .60592 L .35713 .60657 L F
.933 .587 .348 r
.60189 .44016 m .60325 .43884 L .60144 .43779 L F
.60189 .44016 m .60365 .44135 L .60325 .43884 L F
.447 .186 .423 r
.2401 .60989 m .2432 .60671 L .23918 .60654 L F
.2401 .60989 m .24247 .60952 L .2432 .60671 L F
.548 .279 .461 r
.24247 .60952 m .24534 .60894 L .2432 .60671 L F
.687 .576 .725 r
.48387 .50944 m .48524 .51302 L .48138 .51303 L F
.684 .472 .594 r
.48524 .51302 m .48134 .51536 L .48138 .51303 L F
.899 .987 .757 r
.632 .3895 m .63277 .38995 L .62957 .39442 L F
.601 .942 .936 r
.63471 .38874 m .63277 .38995 L .632 .3895 L F
.871 .937 .861 r
.51863 .41151 m .51873 .40918 L .51951 .40969 L F
.443 .234 .499 r
.52218 .40641 m .51951 .40969 L .52169 .40838 L F
.52169 .40838 m .51951 .40969 L .52218 .40641 L F
.651 .967 .904 r
.51951 .40969 m .52074 .40787 L .52169 .40838 L F
.51951 .40969 m .51873 .40918 L .52074 .40787 L F
.78 .721 .797 r
.549 .43859 m .55307 .43894 L .55127 .43796 L F
.836 .536 .483 r
.29279 .52769 m .29379 .52731 L .29172 .52635 L F
.769 .687 .772 r
.34808 .55134 m .35219 .55184 L .35049 .5481 L F
.453 .304 .587 r
.34808 .55134 m .35075 .55364 L .35219 .55184 L F
.062 .27 .761 r
.35049 .5481 m .35219 .55184 L .35297 .55012 L F
.7 .877 .484 r
.35219 .55184 m .35075 .55364 L .35297 .55012 L F
.4 .169 .444 r
.35715 .61942 m .35422 .62325 L .35667 .62261 L F
.35667 .62261 m .35422 .62325 L .35715 .61942 L F
.237 .033 .387 r
.35818 .62222 m .35667 .62261 L .35715 .61942 L F
.35818 .62222 m .35667 .62261 L .35715 .61942 L F
.4 .169 .444 r
.35667 .62261 m .35422 .62325 L .35715 .61942 L F
.623 .896 .987 r
.28256 .57489 m .28628 .57492 L .28452 .57341 L F
.179 .41 .849 r
.28628 .57492 m .28687 .57271 L .28452 .57341 L F
.28628 .57492 m .28844 .57452 L .28687 .57271 L F
.74 .67 .782 r
.39834 .47149 m .39467 .47077 L .3971 .47006 L F
.258 .392 .808 r
.39954 .46941 m .39834 .47149 L .3971 .47006 L F
.39954 .46941 m .40116 .47329 L .39834 .47149 L F
.68 .863 .466 r
.69964 .27689 m .69736 .28037 L .69844 .27835 L F
.158 0 0 r
.70151 .27678 m .69964 .27689 L .69844 .27835 L F
.352 0 .216 r
.37967 .66779 m .3808 .66581 L .37746 .66786 L F
.482 .39 .675 r
.37746 .66786 m .38029 .67052 L .37967 .66779 L F
.37746 .66786 m .3779 .6709 L .38029 .67052 L F
.708 .575 .703 r
.49043 .50677 m .49115 .5101 L .48799 .50999 L F
.508 .443 .719 r
.49328 .50937 m .49043 .50677 L .49311 .50619 L F
.49328 .50937 m .49115 .5101 L .49043 .50677 L F
.754 .338 .262 r
.27024 .54778 m .27269 .55051 L .27411 .54864 L F
0 0 0 r
.27411 .54864 m .27543 .54722 L .27667 .54472 L F
0 0 .427 r
.27411 .54864 m .27547 .5485 L .27543 .54722 L F
.55 .302 .493 r
.46146 .51308 m .46089 .51563 L .45875 .51646 L F
.45875 .51646 m .46089 .51563 L .46146 .51308 L F
.45875 .51646 m .46089 .51563 L .46146 .51308 L F
.499 .547 .837 r
.21793 .5838 m .22019 .58328 L .21848 .57945 L F
.922 .691 .571 r
.39523 .66821 m .39356 .66456 L .39275 .66825 L F
.977 .726 .486 r
.3937 .66989 m .39523 .66821 L .39275 .66825 L F
.3937 .66989 m .39541 .67068 L .39523 .66821 L F
.451 .097 .273 r
.37967 .66779 m .3808 .66581 L .38254 .66706 L F
.578 .191 .271 r
.30429 .57294 m .30199 .5711 L .30593 .57021 L F
.5 .344 .6 r
.30832 .56766 m .30833 .57005 L .30593 .57021 L F
.479 .109 .259 r
.30833 .57005 m .30429 .57294 L .30593 .57021 L F
.284 .182 .559 r
.43101 .46427 m .433 .46636 L .43208 .46238 L F
.998 .79 .443 r
.59333 .37718 m .59301 .38037 L .59193 .37856 L F
.59333 .37718 m .59301 .38037 L .59193 .37856 L F
.833 .732 .752 r
.28301 .65277 m .28264 .65511 L .27912 .65463 L F
.838 .56 .517 r
.27912 .65463 m .28264 .65511 L .28228 .65835 L F
.427 0 0 r
.43201 .4951 m .43023 .49363 L .42933 .49393 L F
.43201 .4951 m .43336 .49371 L .43023 .49363 L F
.37 .836 .797 r
.64368 .3858 m .64238 .38669 L .64103 .38595 L F
.64368 .3858 m .64573 .38543 L .64238 .38669 L F
.519 .258 .459 r
.33659 .57431 m .33954 .57397 L .33992 .57133 L F
.244 .028 .374 r
.33992 .57133 m .33954 .57397 L .3419 .57059 L F
.78 .756 .831 r
.42507 .45783 m .42642 .46142 L .4223 .46062 L F
.81 .703 .746 r
.42642 .46142 m .42366 .46446 L .4223 .46062 L F
.691 .51 .638 r
.42688 .46428 m .42366 .46446 L .42642 .46142 L F
.744 .738 .846 r
.42876 .45818 m .42642 .46142 L .42507 .45783 L F
.614 .549 .758 r
.42876 .45818 m .42945 .46136 L .42642 .46142 L F
.313 .065 .369 r
.42945 .46136 m .42688 .46428 L .42642 .46142 L F
.898 .507 .272 r
.37314 .51615 m .3741 .51841 L .37635 .51938 L F
.881 .451 .07 r
.3741 .51841 m .37636 .52122 L .37635 .51938 L F
.405 .504 .847 r
.34464 .50621 m .34636 .50978 L .34787 .50902 L F
.443 .039 .176 r
.34449 .51129 m .34787 .50902 L .34636 .50978 L F
.69 .278 .261 r
.24321 .57603 m .24483 .5771 L .2427 .57456 L F
.738 .214 0 r
.2427 .57456 m .24483 .5771 L .24608 .57735 L F
0 0 0 r
.56371 .41016 m .56668 .40809 L .56604 .40893 L F
.57018 .42263 m .56934 .42463 L .56686 .42645 L F
0 0 .058 r
.56934 .42463 m .56659 .42812 L .56686 .42645 L F
.796 .609 .649 r
.61381 .35785 m .61538 .35505 L .61409 .35354 L F
.61381 .35785 m .61529 .35794 L .61538 .35505 L F
.632 .807 .966 r
.61409 .35354 m .61538 .35505 L .61818 .35404 L F
.61409 .35354 m .61538 .35505 L .61818 .35404 L F
.571 .938 .827 r
.57038 .46297 m .57466 .46103 L .57333 .46027 L F
.407 .81 .982 r
.57466 .46103 m .57527 .46019 L .57333 .46027 L F
.57466 .46103 m .57711 .46057 L .57527 .46019 L F
.523 .351 .589 r
.31747 .53124 m .3199 .53399 L .31979 .5308 L F
.745 .715 .824 r
.45171 .56539 m .45272 .56618 L .45284 .56519 L F
.45284 .56519 m .45272 .56618 L .45171 .56539 L F
.713 .686 .822 r
.45507 .56441 m .45272 .56618 L .45284 .56519 L F
.45507 .56441 m .45272 .56618 L .45284 .56519 L F
.771 .872 .922 r
.47238 .44177 m .46939 .44418 L .46784 .44272 L F
.719 .988 .831 r
.32691 .61768 m .32902 .61628 L .32799 .61517 L F
.587 .571 .803 r
.33314 .61867 m .33432 .61878 L .32902 .61628 L F
.558 .445 .681 r
.49092 .51249 m .48799 .50999 L .49115 .5101 L F
.408 .179 .451 r
.49323 .51158 m .49115 .5101 L .49328 .50937 L F
.49323 .51158 m .49092 .51249 L .49115 .5101 L F
.315 .006 .272 r
.33188 .55401 m .32887 .55738 L .32914 .5546 L F
.347 .228 .572 r
.41277 .47344 m .41409 .47345 L .41462 .47044 L F
.603 .565 .785 r
.41277 .47344 m .41615 .47467 L .41409 .47345 L F
.724 .588 .704 r
.48799 .50999 m .48524 .51302 L .48387 .50944 L F
.48799 .50999 m .48778 .51326 L .48524 .51302 L F
.558 .445 .681 r
.49092 .51249 m .48778 .51326 L .48799 .50999 L F
.62 .959 .872 r
.62337 .34538 m .62497 .34353 L .62562 .34397 L F
.62337 .34538 m .6214 .3456 L .62497 .34353 L F
.652 .225 .218 r
.42789 .59359 m .43071 .59571 L .43184 .59351 L F
.508 .333 .578 r
.43184 .59351 m .43429 .59366 L .43427 .59041 L F
.886 .82 .778 r
.43071 .59571 m .43429 .59366 L .43184 .59351 L F
.732 .83 .925 r
.55543 .4408 m .55718 .4421 L .55409 .44253 L F
.715 .18 0 r
.55718 .4421 m .56103 .44511 L .55689 .44493 L F
.744 .426 .445 r
.59132 .45887 m .59293 .46 L .58994 .45873 L F
.59132 .45887 m .5945 .46084 L .59293 .46 L F
.26 0 .286 r
.30383 .54053 m .30255 .53893 L .30433 .53817 L F
.30383 .54053 m .30171 .54156 L .30255 .53893 L F
.705 .279 .232 r
.31514 .55181 m .31281 .55382 L .31085 .55134 L F
.783 .4 .33 r
.31195 .55038 m .31152 .55226 L .31504 .5518 L F
.699 .783 .302 r
.3161 .54934 m .31544 .55087 L .31514 .55181 L F
0 0 0 r
.31536 .55176 m .31514 .55181 L .31573 .55001 L F
.783 .4 .33 r
.3151 .55165 m .31504 .5518 L .31536 .55176 L F
.31195 .55038 m .31504 .5518 L .3151 .55165 L F
.699 .783 .302 r
.31677 .54766 m .31573 .55001 L .31544 .55087 L F
.31677 .54766 m .31544 .55087 L .3161 .54934 L F
0 0 0 r
.31536 .55176 m .31281 .55382 L .31514 .55181 L F
.479 .277 .528 r
.32501 .59702 m .32745 .59645 L .3259 .59416 L F
.32501 .59702 m .3273 .59916 L .32745 .59645 L F
.465 .277 .541 r
.32501 .59702 m .32518 .60046 L .3273 .59916 L F
.802 .707 .76 r
.43262 .59726 m .43604 .59766 L .43429 .59366 L F
0 .116 .666 r
.43429 .59366 m .43604 .59766 L .43616 .59564 L F
.281 .575 .939 r
.43616 .59564 m .43604 .59766 L .4381 .59777 L F
0 0 0 r
.27667 .54472 m .2769 .54617 L .27933 .54422 L F
.27667 .54472 m .27543 .54722 L .2769 .54617 L F
.277 0 .112 r
.285 .57165 m .28687 .57271 L .28772 .571 L F
.285 .57165 m .28452 .57341 L .28687 .57271 L F
.613 .345 .489 r
.32642 .55844 m .32619 .56115 L .32307 .56123 L F
.41 .178 .448 r
.32871 .56031 m .32642 .55844 L .32887 .55738 L F
.32871 .56031 m .32619 .56115 L .32642 .55844 L F
.587 .365 .546 r
.29124 .56722 m .29406 .56451 L .29145 .56488 L F
.762 .802 .885 r
.32796 .64828 m .33273 .64868 L .33072 .64542 L F
.552 .004 0 r
.33099 .65019 m .33273 .64868 L .32796 .64828 L F
.042 .373 .84 r
.33072 .64542 m .33273 .64868 L .33488 .64958 L F
.708 .568 .695 r
.33276 .65169 m .33273 .64868 L .33099 .65019 L F
.717 .448 .518 r
.33273 .64868 m .33616 .65143 L .33337 .65128 L F
.708 .568 .695 r
.33276 .65169 m .33488 .64958 L .33273 .64868 L F
0 0 0 r
.24203 .53455 m .24138 .5362 L .24303 .5318 L F
.24132 .53653 m .24138 .5362 L .24203 .53455 L F
.24132 .53653 m .24057 .53659 L .24138 .5362 L F
.807 .779 .827 r
.42519 .51414 m .42236 .51654 L .42532 .51498 L F
.513 .351 .599 r
.42438 .51547 m .42523 .51537 L .42532 .51498 L F
.42236 .51654 m .42513 .51542 L .42438 .51547 L F
.42513 .51542 m .42523 .51537 L .42438 .51547 L F
.641 .587 .778 r
.42532 .51498 m .42677 .51233 L .42519 .51414 L F
.42532 .51498 m .42828 .51567 L .42677 .51233 L F
.168 0 .319 r
.42564 .51505 m .4256 .5152 L .42828 .51567 L F
0 0 0 r
.4256 .5152 m .42552 .51539 L .42547 .51518 L F
.168 0 .319 r
.4281 .51572 m .42635 .51708 L .42818 .51574 L F
.42541 .51517 m .42575 .51585 L .4281 .51572 L F
.42575 .51585 m .42635 .51708 L .4281 .51572 L F
.42541 .51517 m .42818 .51574 L .42828 .51567 L F
.42575 .51585 m .42451 .51875 L .42635 .51708 L F
0 0 0 r
.4256 .5152 m .42553 .51542 L .42508 .51649 L F
.168 0 .319 r
.42553 .51542 m .42527 .51612 L .42575 .51585 L F
0 0 0 r
.42553 .51542 m .4254 .51587 L .42527 .51612 L F
.42553 .51542 m .42527 .51612 L .42508 .51649 L F
.42552 .51539 m .42508 .51649 L .42512 .51555 L F
.42523 .51541 m .42512 .51555 L .42513 .51542 L F
.42552 .51539 m .42512 .51555 L .42523 .51541 L F
.168 0 .319 r
.4253 .51531 m .42505 .51625 L .42527 .51612 L F
.42532 .51498 m .42523 .51541 L .4253 .51531 L F
.42523 .51541 m .42505 .51625 L .4253 .51531 L F
.42532 .51498 m .42527 .51612 L .42553 .51542 L F
.753 .659 .758 r
.42508 .51649 m .42236 .51654 L .42513 .51542 L F
.439 .179 .422 r
.42527 .51612 m .42483 .51637 L .42508 .51649 L F
.168 0 .319 r
.42505 .51625 m .42451 .51875 L .42575 .51585 L F
.475 .869 .684 r
.42472 .51632 m .42236 .51654 L .42508 .51649 L F
.513 .351 .599 r
.42236 .51654 m .42316 .51647 L .42523 .51537 L F
.42258 .51677 m .42505 .51625 L .42523 .51537 L F
.753 .659 .758 r
.42513 .51542 m .42236 .51654 L .42519 .51414 L F
.475 .869 .684 r
.42338 .51568 m .42236 .51654 L .42472 .51632 L F
.513 .351 .599 r
.42236 .51654 m .42258 .51677 L .42316 .51647 L F
.439 .179 .422 r
.42494 .51627 m .42472 .51632 L .42483 .51637 L F
.513 .351 .599 r
.42258 .51677 m .42451 .51875 L .42505 .51625 L F
.439 .179 .422 r
.4254 .51587 m .42395 .51595 L .42472 .51632 L F
.4254 .51587 m .42472 .51632 L .42494 .51627 L F
.4254 .51587 m .42483 .51637 L .42527 .51612 L F
0 0 0 r
.42677 .51233 m .42599 .51477 L .4254 .51587 L F
.42677 .51233 m .4254 .51587 L .4256 .5152 L F
.42677 .51233 m .4256 .5152 L .42519 .51414 L F
.168 0 .319 r
.42532 .51498 m .42541 .51517 L .4256 .5152 L F
0 0 0 r
.42552 .51539 m .42513 .51542 L .42519 .51414 L F
.439 .179 .422 r
.42599 .51477 m .42338 .51568 L .42395 .51595 L F
.168 0 .319 r
.42532 .51498 m .4256 .5152 L .42564 .51505 L F
.439 .179 .422 r
.42599 .51477 m .42395 .51595 L .4254 .51587 L F
0 0 0 r
.4256 .5152 m .42547 .51518 L .42519 .51414 L F
.365 .102 .376 r
.36967 .67776 m .36684 .6816 L .3695 .68028 L F
.637 .371 .5 r
.37229 .68025 m .36967 .67776 L .3695 .68028 L F
.908 .961 .635 r
.68501 .29474 m .68655 .29375 L .68534 .29533 L F
.407 .835 .679 r
.68778 .29169 m .68642 .29227 L .68776 .29148 L F
.637 .832 .425 r
.68876 .29032 m .68779 .29182 L .68778 .29169 L F
0 0 0 r
.69023 .28891 m .68778 .29169 L .69042 .29052 L F
.407 .835 .679 r
.68778 .29169 m .68776 .29148 L .68887 .29083 L F
.637 .832 .425 r
.68779 .29182 m .68655 .29375 L .68778 .29169 L F
.72 .952 .662 r
.68778 .29169 m .68655 .29375 L .68501 .29474 L F
.309 .43 .822 r
.36286 .68616 m .36254 .68944 L .36032 .68626 L F
.36286 .68616 m .36444 .68994 L .36254 .68944 L F
.911 .845 .766 r
.41645 .48015 m .41292 .48268 L .41586 .48039 L F
.342 0 .14 r
.41586 .48039 m .41859 .4795 L .41645 .48015 L F
.245 .701 .952 r
.36526 .69876 m .36784 .69976 L .36989 .69963 L F
.404 .756 .994 r
.43433 .55884 m .43464 .55706 L .43249 .55723 L F
.43433 .55884 m .43673 .55854 L .43464 .55706 L F
.34 0 .139 r
.31278 .56049 m .31487 .56029 L .31678 .55736 L F
.412 .008 .159 r
.31487 .56029 m .31889 .5575 L .31678 .55736 L F
.31487 .56029 m .31743 .5602 L .31889 .5575 L F
.664 .122 0 r
.31297 .55853 m .31707 .56007 L .31487 .56029 L F
.31707 .56007 m .31743 .5602 L .31487 .56029 L F
.34 0 .139 r
.31242 .56078 m .31487 .56029 L .31278 .56049 L F
.574 .244 .372 r
.32233 .52836 m .32612 .52613 L .32377 .52644 L F
.539 .24 .409 r
.48778 .51326 m .4851 .51577 L .48524 .51302 L F
.48778 .51326 m .48787 .51536 L .4851 .51577 L F
.544 .295 .488 r
.49092 .51249 m .48787 .51536 L .48778 .51326 L F
.736 .657 .772 r
.35237 .51993 m .34755 .51901 L .35054 .51821 L F
.594 .895 .61 r
.3576 .56148 m .35567 .563 L .35451 .56445 L F
.419 0 .046 r
.36019 .56097 m .35567 .563 L .3576 .56148 L F
.342 .068 .345 r
.36183 .58085 m .36114 .5835 L .35893 .58407 L F
.026 0 .209 r
.36306 .582 m .36183 .58085 L .36402 .57989 L F
.36306 .582 m .36114 .5835 L .36183 .58085 L F
.701 .812 .934 r
.39538 .67602 m .39923 .67454 L .39683 .67329 L F
.451 0 0 r
.34149 .49654 m .34349 .49684 L .34052 .49588 L F
.175 0 0 r
.34419 .4972 m .34349 .49684 L .34149 .49654 L F
.34419 .4972 m .3457 .49719 L .34349 .49684 L F
0 0 .462 r
.21683 .57743 m .21772 .57714 L .21783 .57319 L F
0 .084 .601 r
.21683 .57743 m .21848 .57945 L .21772 .57714 L F
.656 .654 .837 r
.37977 .5899 m .37807 .59346 L .37706 .59042 L F
.37977 .5899 m .38026 .59333 L .37807 .59346 L F
.987 .801 .57 r
.43331 .50069 m .43456 .50303 L .43514 .50016 L F
.729 .644 .764 r
.43456 .50303 m .4361 .501 L .43514 .50018 L F
.43456 .50303 m .439 .50326 L .43745 .49922 L F
.759 .786 .876 r
.43775 .50151 m .43456 .50303 L .43331 .50069 L F
.629 .093 0 r
.43775 .50151 m .43331 .50069 L .43456 .50303 L F
.4364 .50126 m .43585 .50298 L .43331 .50069 L F
.43775 .50151 m .4372 .50194 L .4364 .50126 L F
.4372 .50194 m .43585 .50298 L .4364 .50126 L F
.729 .644 .764 r
.43514 .50018 m .43745 .49922 L .43514 .50016 L F
.4361 .501 m .43745 .49922 L .43514 .50018 L F
.793 .731 .795 r
.43562 .49274 m .43769 .4942 L .44045 .49131 L F
.364 .809 .953 r
.23645 .53702 m .23848 .53745 L .24057 .53659 L F
.498 .107 .23 r
.4359 .50859 m .4387 .50844 L .43961 .50617 L F
.203 .273 .713 r
.439 .50326 m .43961 .50617 L .44124 .50511 L F
0 0 0 r
.43961 .50617 m .4387 .50844 L .44124 .50511 L F
.57213 .42194 m .57018 .42263 L .57283 .42261 L F
.57213 .42194 m .56934 .42463 L .57018 .42263 L F
.743 .799 .897 r
.44061 .45385 m .44462 .45414 L .4421 .45595 L F
.481 .311 .573 r
.34655 .57706 m .34419 .58055 L .34414 .57769 L F
0 0 0 r
.69023 .28891 m .68876 .29032 L .68778 .29169 L F
.941 .58 .28 r
.61081 .42949 m .60917 .42876 L .60827 .42553 L F
.658 .109 0 r
.61002 .42981 m .60917 .42876 L .61081 .42949 L F
.649 .098 0 r
.61081 .42949 m .61215 .43091 L .61002 .42981 L F
.742 .307 .218 r
.56093 .43149 m .56488 .43228 L .56252 .43308 L F
.802 .996 .864 r
.56252 .43308 m .56488 .43228 L .56451 .43139 L F
.998 .793 .492 r
.27925 .57572 m .27781 .57686 L .27802 .57339 L F
.013 0 0 r
.2805 .57608 m .27925 .57572 L .28256 .57489 L F
.2805 .57608 m .27781 .57686 L .27925 .57572 L F
.246 .237 .651 r
.22326 .59343 m .22378 .59788 L .22551 .59556 L F
.191 .175 .609 r
.2243 .60007 m .22551 .59556 L .22378 .59788 L F
0 0 .239 r
.34703 .60674 m .34799 .6074 L .34832 .60498 L F
.34703 .60674 m .34697 .60967 L .34799 .6074 L F
.581 .682 .91 r
.58122 .37271 m .58526 .37361 L .5825 .37448 L F
.347 0 0 r
.57755 .37115 m .58122 .37271 L .57701 .37102 L F
.57755 .37115 m .57987 .37225 L .58122 .37271 L F
.57673 .37081 m .57987 .37225 L .57755 .37115 L F
.554 .062 .041 r
.57987 .37225 m .5828 .37376 L .58286 .37366 L F
.347 0 0 r
.57701 .37102 m .58122 .37271 L .57863 .37225 L F
.554 .062 .041 r
.57987 .37225 m .58406 .37171 L .58122 .37271 L F
.637 .642 .839 r
.58406 .37171 m .58526 .37361 L .58122 .37271 L F
.554 .062 .041 r
.57987 .37225 m .58286 .37366 L .5835 .37262 L F
.58125 .37207 m .5835 .37262 L .58406 .37171 L F
.57987 .37225 m .5835 .37262 L .58125 .37207 L F
.347 0 0 r
.57673 .37081 m .57755 .37115 L .57701 .37102 L F
.535 .386 .626 r
.2804 .63818 m .28269 .63663 L .28304 .63554 L F
.327 .056 .34 r
.28163 .64093 m .2804 .63818 L .27903 .64137 L F
.28163 .64093 m .28269 .63663 L .2804 .63818 L F
0 0 .101 r
.35805 .55424 m .35786 .55727 L .35613 .55501 L F
.299 .388 .787 r
.55767 .40207 m .55916 .40642 L .56104 .40456 L F
.948 .687 .226 r
.39843 .57586 m .39861 .57445 L .39758 .57301 L F
.763 .892 .935 r
.49073 .43216 m .48726 .43245 L .48913 .43073 L F
.844 .867 .859 r
.4934 .42912 m .49073 .43216 L .48913 .43073 L F
.299 0 0 r
.43043 .5394 m .42855 .53999 L .42562 .53937 L F
.524 0 0 r
.43105 .54002 m .42855 .53999 L .43043 .5394 L F
.105 0 .314 r
.47917 .55732 m .47751 .56058 L .47816 .55832 L F
.692 .512 .64 r
.56103 .44511 m .55758 .44766 L .55689 .44493 L F
.649 .859 .979 r
.38979 .49362 m .38553 .49322 L .38806 .49142 L F
.564 .628 .874 r
.22326 .59343 m .22364 .58927 L .22122 .58991 L F
.22326 .59343 m .22608 .59345 L .22364 .58927 L F
.246 .237 .651 r
.22326 .59343 m .22551 .59556 L .22608 .59345 L F
.463 0 0 r
.69428 .31584 m .69324 .31676 L .69022 .31559 L F
.302 0 0 r
.6972 .31645 m .69324 .31676 L .69428 .31584 L F
.405 .148 .407 r
.28724 .65776 m .28769 .65544 L .28973 .65611 L F
.025 .43 .866 r
.28973 .65611 m .28769 .65544 L .2862 .65378 L F
.108 .3 .776 r
.55884 .40881 m .56059 .41267 L .55773 .41271 L F
.369 .828 .919 r
.55773 .41271 m .56059 .41267 L .55984 .41229 L F
.434 .859 .725 r
.56059 .41267 m .55688 .41441 L .56075 .41532 L F
.587 .719 .935 r
.56059 .41267 m .56347 .41212 L .56223 .41008 L F
.778 .998 .839 r
.55984 .41229 m .56059 .41267 L .56223 .41008 L F
.95 .673 .221 r
.56075 .41532 m .56059 .41267 L .55984 .41229 L F
.525 .563 .836 r
.45463 .52874 m .45572 .52537 L .45484 .52463 L F
.45463 .52874 m .45736 .52881 L .45572 .52537 L F
.543 .38 .61 r
.45463 .52874 m .45753 .5314 L .45736 .52881 L F
.523 .62 .89 r
.35422 .62325 m .35864 .62374 L .35667 .62261 L F
.35422 .62325 m .35864 .62374 L .35667 .62261 L F
0 0 .446 r
.44056 .48114 m .44066 .4806 L .43987 .47932 L F
.44056 .48114 m .44206 .48384 L .44066 .4806 L F
.995 .767 .411 r
.46253 .53587 m .46156 .53778 L .46158 .53462 L F
.508 .07 .143 r
.46253 .53587 m .46351 .53821 L .46156 .53778 L F
.74 .306 0 r
.46393 .53817 m .46351 .53821 L .46253 .53587 L F
0 0 .306 r
.28257 .63051 m .28123 .62929 L .28264 .62783 L F
.28257 .63051 m .28106 .63186 L .28123 .62929 L F
.491 .781 .996 r
.35982 .56616 m .36171 .56751 L .35901 .56783 L F
.706 .906 .546 r
.35901 .56783 m .35705 .56988 L .35982 .56616 L F
.745 .678 .786 r
.44183 .50027 m .439 .50326 L .44257 .50334 L F
.637 .203 .201 r
.439 .50326 m .44124 .50511 L .44257 .50334 L F
.585 .406 .606 r
.44257 .50334 m .44544 .50013 L .44183 .50027 L F
.44257 .50334 m .4454 .50291 L .44544 .50013 L F
0 0 0 r
.44257 .50334 m .44393 .50342 L .4454 .50291 L F
.44257 .50334 m .44124 .50511 L .44393 .50342 L F
.601 .065 0 r
.25638 .62547 m .26055 .62617 L .25919 .62719 L F
.561 0 0 r
.26055 .62617 m .26486 .62812 L .26299 .62676 L F
.381 0 0 r
.25919 .62719 m .26055 .62617 L .26299 .62676 L F
.944 .736 .592 r
.5958 .42138 m .59709 .4248 L .59697 .42244 L F
.793 .731 .795 r
.43562 .49274 m .44045 .49131 L .4385 .48965 L F
.499 .862 .624 r
.52169 .40838 m .52482 .40591 L .52218 .40641 L F
.696 .648 .798 r
.52482 .40591 m .52169 .40838 L .52218 .40641 L F
0 0 .059 r
.44256 .53686 m .44294 .53803 L .44469 .53725 L F
0 0 .161 r
.44294 .53803 m .44256 .53686 L .44469 .53725 L F
.093 0 .441 r
.47925 .56306 m .47902 .56653 L .47662 .56791 L F
0 0 .123 r
.47902 .56653 m .47692 .57056 L .47662 .56791 L F
0 .012 .53 r
.56066 .42061 m .55949 .42252 L .55931 .41989 L F
.71 .964 .709 r
.56066 .42061 m .55787 .42341 L .55949 .42252 L F
0 0 0 r
.69985 .32573 m .69781 .32953 L .6992 .32719 L F
.777 .789 .293 r
.70029 .32316 m .69985 .32573 L .6992 .32719 L F
.825 .932 .557 r
.32603 .58993 m .32422 .59358 L .32439 .59158 L F
.753 .634 .072 r
.32422 .59358 m .32402 .59435 L .32439 .59158 L F
.408 .292 .609 r
.32603 .58993 m .32648 .59359 L .32422 .59358 L F
.75 .968 .932 r
.34559 .61349 m .34105 .61505 L .34362 .61396 L F
.485 .898 .811 r
.34754 .61234 m .34559 .61349 L .34362 .61396 L F
.744 .252 0 r
.59617 .39537 m .59592 .39611 L .59582 .39546 L F
0 .163 .674 r
.59426 .39325 m .59639 .39532 L .59617 .39537 L F
.571 .068 0 r
.59253 .39159 m .59426 .39325 L .59617 .39537 L F
.59253 .39159 m .59617 .39537 L .59557 .3939 L F
.744 .252 0 r
.59617 .39537 m .59582 .39546 L .59557 .3939 L F
0 .163 .674 r
.59639 .39532 m .59765 .39653 L .59617 .39537 L F
.707 .176 0 r
.59765 .39653 m .59796 .39792 L .59617 .39537 L F
.59765 .39653 m .59984 .399 L .59796 .39792 L F
.223 .245 .673 r
.55754 .43387 m .55528 .43216 L .55696 .43115 L F
.908 .92 .532 r
.70497 .34267 m .70471 .34557 L .70616 .34162 L F
.922 .972 .692 r
.70353 .34711 m .70471 .34557 L .70497 .34267 L F
.436 .15 .379 r
.34907 .57347 m .35224 .57072 L .34965 .57093 L F
.319 .227 .591 r
.35567 .563 m .35466 .56641 L .35451 .56445 L F
.97 .662 .374 r
.41946 .5017 m .42076 .49919 L .41999 .50138 L F
.409 .468 .809 r
.41522 .49785 m .41912 .50233 L .41456 .49909 L F
.41822 .50058 m .41912 .50233 L .41522 .49785 L F
.582 .012 0 r
.41456 .49909 m .41912 .50233 L .4184 .50196 L F
.711 .616 .749 r
.42076 .49919 m .41912 .50233 L .41604 .4963 L F
.97 .662 .374 r
.41839 .50195 m .41912 .50233 L .42076 .49919 L F
.41769 .50277 m .41912 .50233 L .41839 .50195 L F
.582 .012 0 r
.4184 .50196 m .41912 .50233 L .41842 .50198 L F
.41504 .49967 m .41842 .50198 L .41592 .50072 L F
.41456 .49909 m .41842 .50198 L .41504 .49967 L F
.97 .662 .374 r
.4187 .50216 m .41898 .50126 L .41946 .5017 L F
.41769 .50277 m .41839 .50195 L .41842 .50198 L F
.41769 .50277 m .41592 .50072 L .41842 .50198 L F
.41769 .50277 m .41842 .50198 L .41912 .50233 L F
.41769 .50277 m .41842 .50198 L .4187 .50216 L F
.41839 .50195 m .41898 .50126 L .4187 .50216 L F
.41898 .50126 m .42076 .49919 L .41946 .5017 L F
.409 .468 .809 r
.41604 .4963 m .41822 .50058 L .41522 .49785 L F
.582 .012 0 r
.41456 .49909 m .41592 .50072 L .41497 .50277 L F
.627 .887 .558 r
.28726 .53303 m .28439 .53637 L .28605 .53418 L F
.558 .723 .951 r
.28439 .53637 m .28738 .53587 L .28605 .53418 L F
.803 .995 .769 r
.66527 .32933 m .66396 .33201 L .66679 .3289 L F
.66527 .32933 m .66245 .33249 L .66396 .33201 L F
.851 .845 .837 r
.27446 .51579 m .27011 .51688 L .272 .51538 L F
.078 .584 .89 r
.272 .51538 m .27357 .51586 L .27446 .51579 L F
0 0 0 r
.27361 .5162 m .27446 .51579 L .27526 .51573 L F
.27361 .5162 m .27134 .51986 L .27446 .51579 L F
.895 .732 .672 r
.27545 .51738 m .27756 .51926 L .276 .51552 L F
.621 .612 .82 r
.276 .51552 m .27756 .51926 L .27942 .51748 L F
0 .361 .831 r
.27446 .51579 m .27677 .51685 L .27545 .51738 L F
.851 .845 .837 r
.27446 .51579 m .27134 .51986 L .27011 .51688 L F
.078 .584 .89 r
.27357 .51586 m .27677 .51685 L .27446 .51579 L F
0 0 0 r
.27526 .51573 m .27446 .51579 L .276 .51552 L F
.684 .472 .594 r
.48524 .51302 m .4851 .51577 L .48134 .51536 L F
.293 .123 .471 r
.72199 .3058 m .72002 .30878 L .7194 .30588 L F
.72199 .3058 m .72206 .30859 L .72002 .30878 L F
.619 .537 .74 r
.72357 .31198 m .72002 .30878 L .72206 .30859 L F
.937 .954 .637 r
.70616 .34162 m .70742 .33681 L .70632 .34082 L F
.752 .923 .562 r
.70497 .34267 m .70616 .34162 L .70632 .34082 L F
.432 .203 .464 r
.32612 .52613 m .32891 .52573 L .32873 .52266 L F
0 0 .373 r
.32873 .52266 m .33023 .52439 L .33104 .5224 L F
.32873 .52266 m .32891 .52573 L .33023 .52439 L F
.4 .377 .718 r
.37452 .54562 m .37526 .54857 L .37701 .54767 L F
.636 .347 .464 r
.37452 .54562 m .37701 .54767 L .37334 .54764 L F
.628 .351 .479 r
.37452 .54562 m .37701 .54767 L .37745 .5453 L F
.37452 .54562 m .37701 .54767 L .37745 .5453 L F
.036 .068 .564 r
.28973 .65611 m .28924 .66132 L .28746 .66071 L F
.652 .115 0 r
.28924 .66132 m .28938 .66302 L .28746 .66071 L F
.28924 .66132 m .2913 .66287 L .28938 .66302 L F
.99 .726 .405 r
.33365 .64119 m .33486 .64171 L .33391 .63864 L F
.641 .245 .279 r
.33314 .6441 m .33486 .64171 L .33365 .64119 L F
.529 .447 .707 r
.34732 .68724 m .3442 .68398 L .34601 .68332 L F
.34732 .68724 m .34472 .68783 L .3442 .68398 L F
.242 0 0 r
.36648 .61613 m .36183 .61851 L .36502 .61803 L F
.8 .386 .264 r
.36502 .61803 m .36743 .61821 L .36648 .61613 L F
.117 .196 .671 r
.31282 .62169 m .31369 .61994 L .31256 .61959 L F
.97 .717 .495 r
.60032 .43111 m .60172 .435 L .60205 .43229 L F
.572 .009 0 r
.29287 .57486 m .29098 .57543 L .28844 .57452 L F
.33 0 0 r
.29504 .57527 m .29098 .57543 L .29287 .57486 L F
.167 0 0 r
.29531 .57517 m .29504 .57527 L .29287 .57486 L F
.451 0 0 r
.34149 .49654 m .34052 .49588 L .34021 .49564 L F
.272 .573 .939 r
.55887 .38185 m .56055 .38363 L .55861 .38371 L F
.55887 .38185 m .56055 .38363 L .55861 .38371 L F
.668 .96 .94 r
.34261 .65505 m .34436 .6552 L .34594 .65388 L F
0 0 0 r
.34261 .65505 m .3452 .65447 L .34392 .65511 L F
0 .546 .721 r
.34188 .65501 m .34436 .6552 L .34261 .65505 L F
0 0 0 r
.34261 .65505 m .34392 .65511 L .34324 .65546 L F
0 .546 .721 r
.34014 .65488 m .34188 .65501 L .34261 .65505 L F
.617 .216 .261 r
.28787 .63741 m .29008 .63494 L .28567 .63542 L F
.398 0 0 r
.29028 .63691 m .29008 .63494 L .28787 .63741 L F
.29028 .63691 m .29231 .63491 L .29008 .63494 L F
.877 .824 .792 r
.59301 .36115 m .58964 .3626 L .59167 .35978 L F
.645 .365 .48 r
.32352 .63216 m .3213 .63512 L .32135 .63172 L F
.32352 .63216 m .32518 .63486 L .3213 .63512 L F
.888 .836 .788 r
.6363 .41161 m .63785 .40996 L .63606 .40838 L F
.825 .844 .862 r
.63606 .40838 m .63785 .40996 L .63851 .40847 L F
.543 .209 .352 r
.52732 .47771 m .52975 .47953 L .52707 .47962 L F
.52732 .47771 m .53116 .47688 L .52975 .47953 L F
.079 .154 .641 r
.28124 .54512 m .28192 .54753 L .28045 .54832 L F
0 0 0 r
.28066 .54853 m .28045 .54832 L .28192 .54753 L F
.28066 .54853 m .27838 .54939 L .28045 .54832 L F
.713 .431 0 r
.41134 .59308 m .41237 .59683 L .41201 .59566 L F
.27 0 0 r
.41237 .59683 m .41301 .59821 L .41201 .59566 L F
.409 .283 .596 r
.21912 .59024 m .22122 .58991 L .22064 .58716 L F
.73 .63 .747 r
.71506 .30718 m .7194 .30588 L .71828 .30701 L F
.978 .701 .31 r
.72098 .30674 m .7194 .30588 L .71828 .30701 L F
.72098 .30674 m .72199 .3058 L .7194 .30588 L F
.992 .789 .53 r
.44371 .57108 m .44326 .57381 L .44256 .57425 L F
.189 0 0 r
.44377 .57193 m .44577 .57107 L .44371 .57108 L F
.747 .625 .724 r
.44446 .56744 m .44577 .57107 L .44297 .56987 L F
.762 .606 .684 r
.44297 .56987 m .44577 .57107 L .44377 .57193 L F
.342 .388 .765 r
.44722 .56882 m .44577 .57107 L .44446 .56744 L F
.752 .923 .947 r
.44541 .56945 m .44377 .57193 L .44722 .56882 L F
.189 0 0 r
.44377 .57193 m .44371 .57108 L .44296 .57315 L F
.958 .663 .434 r
.44297 .56987 m .44377 .57193 L .44107 .57096 L F
.752 .923 .947 r
.44107 .57096 m .44377 .57193 L .44541 .56945 L F
.189 0 0 r
.44377 .57193 m .44296 .57315 L .44256 .57425 L F
.773 .591 .653 r
.44402 .49952 m .44183 .50027 L .44544 .50013 L F
.686 .67 .828 r
.44402 .49952 m .44629 .49625 L .44651 .49599 L F
.44402 .49952 m .44544 .50013 L .44629 .49625 L F
.71 .693 .832 r
.44544 .50013 m .44815 .49978 L .44629 .49625 L F
.36 .067 .324 r
.4454 .50291 m .44815 .49978 L .44544 .50013 L F
.815 .692 .729 r
.35261 .67818 m .35475 .67601 L .35133 .67701 L F
.768 .493 .518 r
.59085 .36469 m .58647 .36636 L .58964 .3626 L F
.913 .516 .224 r
.58997 .36627 m .59085 .36469 L .59199 .3625 L F
.85 .648 .629 r
.33571 .6468 m .33938 .64713 L .33889 .64391 L F
.33571 .6468 m .33889 .64391 L .33848 .64409 L F
.242 .344 .769 r
.33314 .6441 m .33571 .6468 L .33848 .64409 L F
.85 .648 .629 r
.33571 .6468 m .33848 .64409 L .33829 .64417 L F
.842 .503 .411 r
.33938 .64713 m .34024 .64384 L .339 .64363 L F
.33938 .64713 m .339 .64363 L .33889 .64391 L F
.242 .344 .769 r
.33848 .64409 m .33571 .6468 L .33942 .64408 L F
.641 .245 .279 r
.33882 .64408 m .33897 .64371 L .33708 .64219 L F
.85 .648 .629 r
.33829 .64417 m .33889 .64391 L .33884 .6436 L F
.641 .245 .279 r
.33314 .6441 m .33848 .64409 L .33708 .64219 L F
.33848 .64409 m .33882 .64408 L .33872 .64398 L F
.33848 .64409 m .33872 .64398 L .33708 .64219 L F
.33882 .64408 m .33942 .64408 L .33897 .64371 L F
.842 .503 .411 r
.33889 .64391 m .339 .64363 L .33884 .6436 L F
.33938 .64713 m .34119 .64763 L .34024 .64384 L F
.679 .7 .862 r
.33188 .55401 m .33686 .55587 L .3345 .55368 L F
.67 .742 .244 r
.69931 .3578 m .70103 .353 L .69985 .35695 L F
0 0 .007 r
.69929 .35937 m .69931 .3578 L .69985 .35695 L F
0 0 0 r
.67531 .36779 m .67143 .36971 L .67389 .36855 L F
0 0 .13 r
.67779 .36431 m .67531 .36779 L .67757 .36573 L F
.575 .908 .672 r
.67757 .36573 m .67531 .36779 L .67389 .36855 L F
.36 .067 .324 r
.4454 .50291 m .44869 .50078 L .44815 .49978 L F
.576 .517 .752 r
.44815 .49978 m .44989 .49564 L .44629 .49625 L F
.44815 .49978 m .45028 .49995 L .44989 .49564 L F
.81 .616 .64 r
.44869 .50078 m .45028 .49995 L .44815 .49978 L F
.982 .758 .523 r
.24219 .54201 m .2419 .54504 L .24015 .54356 L F
.24219 .54201 m .2419 .54504 L .24015 .54356 L F
.702 .802 .927 r
.57387 .43395 m .5761 .43607 L .57152 .43697 L F
.885 .813 .773 r
.57642 .43267 m .5761 .43607 L .57387 .43395 L F
.899 .987 .757 r
.632 .3895 m .62957 .39442 L .62921 .39227 L F
.121 .63 .898 r
.62957 .39442 m .63195 .39412 L .62921 .39227 L F
0 0 0 r
.57152 .43697 m .56885 .43798 L .57306 .4369 L F
.702 .802 .927 r
.57387 .43395 m .57152 .43697 L .57306 .4369 L F
.784 .91 .927 r
.51738 .41356 m .51273 .4147 L .51602 .41222 L F
.894 .9 .824 r
.51863 .41151 m .51738 .41356 L .51602 .41222 L F
.501 .83 .999 r
.316 .54457 m .31843 .54386 L .32033 .54493 L F
.307 0 .043 r
.31951 .5477 m .31677 .54766 L .31823 .54684 L F
.31951 .5477 m .31573 .55001 L .31677 .54766 L F
.736 .499 .571 r
.31732 .54742 m .31573 .55001 L .31951 .5477 L F
0 0 0 r
.32033 .54493 m .31948 .5457 L .31677 .54766 L F
.736 .499 .571 r
.31557 .5472 m .31566 .54875 L .31732 .54742 L F
.31566 .54875 m .31573 .55001 L .31732 .54742 L F
0 0 0 r
.31948 .5457 m .31823 .54684 L .31763 .54718 L F
.31948 .5457 m .31763 .54718 L .31677 .54766 L F
.135 .112 .565 r
.32033 .54493 m .32143 .54111 L .31974 .54264 L F
.32033 .54493 m .32185 .54399 L .32143 .54111 L F
.44 .801 .996 r
.32033 .54493 m .32185 .54399 L .31843 .54386 L F
.215 0 0 r
.32087 .5462 m .31823 .54684 L .32033 .54493 L F
.576 .814 .989 r
.24577 .55054 m .24764 .55197 L .25006 .55112 L F
.266 .013 .332 r
.33402 .57753 m .33143 .58075 L .33341 .57988 L F
.082 .042 .509 r
.33143 .58075 m .33242 .58244 L .33341 .57988 L F
.33143 .58075 m .3318 .58367 L .33242 .58244 L F
0 0 .017 r
.42588 .48771 m .42806 .48723 L .42875 .48422 L F
.864 .989 .836 r
.42883 .48633 m .42773 .48905 L .43049 .486 L F
0 0 .017 r
.42807 .48722 m .42817 .4871 L .42818 .48706 L F
.864 .989 .836 r
.42821 .48645 m .42807 .48722 L .42883 .48633 L F
.42807 .48722 m .42773 .48905 L .42883 .48633 L F
0 0 .017 r
.42806 .48723 m .42815 .48721 L .42817 .4871 L F
.42806 .48723 m .42817 .4871 L .42807 .48722 L F
.43 .871 .823 r
.43199 .48493 m .42958 .4859 L .43049 .486 L F
.42958 .4859 m .42821 .48645 L .42883 .48633 L F
.42958 .4859 m .42883 .48633 L .43049 .486 L F
0 0 .017 r
.42806 .48723 m .42818 .48706 L .42826 .48665 L F
.42818 .4867 m .42826 .48665 L .42875 .48422 L F
.42806 .48723 m .42826 .48665 L .42818 .4867 L F
.136 .586 .926 r
.42397 .48632 m .42805 .48719 L .42588 .48771 L F
.42805 .48719 m .42815 .48721 L .42806 .48723 L F
.42805 .48719 m .42806 .48723 L .42588 .48771 L F
.938 .566 .227 r
.42875 .48422 m .42818 .48706 L .42687 .48331 L F
.42818 .48706 m .42815 .48721 L .42811 .48708 L F
.42818 .48706 m .42811 .48708 L .42687 .48331 L F
.889 .974 .669 r
.42821 .48645 m .42793 .48692 L .42802 .48711 L F
.535 .369 .603 r
.42687 .48331 m .42811 .48708 L .42397 .48632 L F
.889 .974 .669 r
.42809 .48712 m .42805 .48718 L .42807 .48722 L F
.535 .369 .603 r
.42811 .48708 m .42815 .48721 L .42805 .48719 L F
.42811 .48708 m .42805 .48719 L .42397 .48632 L F
.889 .974 .669 r
.42809 .48709 m .42802 .48711 L .42805 .48718 L F
.42809 .48709 m .42805 .48718 L .42809 .48712 L F
.42821 .48645 m .42802 .48711 L .42809 .48709 L F
.03 0 0 r
.42773 .48905 m .4237 .49127 L .4258 .49075 L F
.42773 .48905 m .42542 .49091 L .4237 .49127 L F
.889 .974 .669 r
.42793 .48692 m .42571 .49067 L .42806 .48723 L F
.42793 .48692 m .42806 .48723 L .42807 .48722 L F
.42821 .48645 m .42542 .49091 L .42571 .49067 L F
.42807 .48722 m .42571 .49067 L .42773 .48905 L F
.774 .271 0 r
.35813 .50556 m .35773 .5034 L .35584 .50241 L F
.35813 .50556 m .35972 .50645 L .35773 .5034 L F
.882 .763 .726 r
.23685 .61015 m .2401 .60989 L .23918 .60654 L F
.443 .369 .679 r
.2401 .60989 m .24274 .61222 L .24247 .60952 L F
.2401 .60989 m .2412 .61305 L .24274 .61222 L F
.58 .788 .978 r
.57322 .42059 m .57283 .42261 L .5753 .42173 L F
.859 .997 .787 r
.57322 .42059 m .57213 .42194 L .57283 .42261 L F
.845 .67 .665 r
.3793 .60325 m .38031 .60622 L .37653 .60618 L F
.685 .23 .167 r
.52896 .4134 m .52864 .41493 L .52766 .41628 L F
.763 .709 .801 r
.59167 .35978 m .58964 .3626 L .58769 .35915 L F
.359 .679 .978 r
.58867 .36152 m .58964 .3626 L .58769 .35915 L F
.139 .248 .715 r
.58769 .35915 m .58867 .36152 L .58898 .36015 L F
.591 .017 0 r
.58938 .35915 m .58769 .35915 L .58545 .35742 L F
.261 0 0 r
.58938 .35915 m .59167 .35978 L .58769 .35915 L F
.139 .248 .715 r
.58769 .35915 m .58898 .36015 L .58949 .35795 L F
.591 .017 0 r
.58545 .35742 m .58769 .35915 L .58521 .35731 L F
.543 .05 .035 r
.24889 .6181 m .25085 .61663 L .2485 .61609 L F
0 0 0 r
.44799 .59608 m .45201 .59381 L .45034 .59481 L F
.128 0 0 r
.45201 .59381 m .45288 .59469 L .45034 .59481 L F
.45201 .59381 m .45446 .59332 L .45288 .59469 L F
.972 .69 .284 r
.6681 .3401 m .66927 .34195 L .66852 .34344 L F
.627 .132 .056 r
.66852 .34344 m .66927 .34195 L .6729 .3447 L F
.36 .271 .618 r
.6729 .3447 m .66927 .34195 L .67274 .34035 L F
.677 .491 .627 r
.33557 .60008 m .33869 .60266 L .33819 .59889 L F
.33557 .60008 m .33525 .60342 L .33869 .60266 L F
0 0 .352 r
.33674 .60154 m .33557 .60008 L .33819 .59889 L F
.33674 .60154 m .33525 .60342 L .33557 .60008 L F
.756 .995 .835 r
.6992 .32719 m .69781 .32953 L .69594 .32991 L F
.107 0 .196 r
.45685 .57359 m .45497 .57489 L .45425 .57687 L F
0 0 .287 r
.59064 .40617 m .59092 .40199 L .5892 .40477 L F
.959 .675 .241 r
.58946 .40679 m .59064 .40617 L .5892 .40477 L F
.58946 .40679 m .59091 .40877 L .59064 .40617 L F
.854 .995 .824 r
.43049 .486 m .42912 .4889 L .43139 .48673 L F
.43049 .486 m .42773 .48905 L .42912 .4889 L F
.833 .732 .752 r
.28301 .65277 m .27912 .65463 L .28162 .65058 L F
.425 .494 .827 r
.28402 .65091 m .28301 .65277 L .28162 .65058 L F
.28402 .65091 m .2862 .65378 L .28301 .65277 L F
.509 .754 .984 r
.72923 .3115 m .72731 .31371 L .72604 .31169 L F
.72923 .3115 m .73017 .3131 L .72731 .31371 L F
0 0 0 r
.63159 .34048 m .63349 .33903 L .63465 .33744 L F
.63159 .34048 m .63144 .34082 L .63349 .33903 L F
.189 0 0 r
.55792 .38975 m .55919 .39008 L .55719 .39118 L F
.55792 .38975 m .56148 .3907 L .55919 .39008 L F
.863 .639 .598 r
.60773 .45823 m .60588 .45461 L .60573 .45698 L F
.369 .099 .368 r
.44635 .58359 m .44919 .58076 L .44509 .58026 L F
.44635 .58359 m .44845 .58284 L .44919 .58076 L F
0 0 0 r
.44635 .58359 m .44695 .58415 L .44845 .58284 L F
.44635 .58359 m .44502 .58574 L .44695 .58415 L F
.595 .914 .977 r
.43271 .48489 m .43139 .48673 L .43394 .48326 L F
.43271 .48489 m .43049 .486 L .43139 .48673 L F
.562 .841 .501 r
.24565 .52883 m .24402 .53056 L .24303 .5318 L F
0 0 0 r
.24402 .53056 m .24203 .53455 L .24303 .5318 L F
.181 .236 .684 r
.45105 .57907 m .45274 .57867 L .45224 .57807 L F
0 0 0 r
.45212 .57781 m .44991 .58003 L .45105 .57907 L F
.181 .236 .684 r
.45105 .57907 m .45053 .576 L .45212 .57781 L F
.45105 .57907 m .45224 .57807 L .45053 .576 L F
0 0 0 r
.44991 .58003 m .44919 .58076 L .45105 .57907 L F
.44845 .58284 m .45105 .57907 L .44919 .58076 L F
.738 .991 .814 r
.66814 .32661 m .66679 .3289 L .66987 .32626 L F
.737 .986 .782 r
.66814 .32661 m .66527 .32933 L .66679 .3289 L F
.851 .419 0 r
.39232 .5158 m .39089 .51475 L .38988 .51235 L F
.696 .19 0 r
.39232 .5158 m .39244 .51686 L .39089 .51475 L F
.39232 .5158 m .394 .51807 L .39244 .51686 L F
.682 .593 .749 r
.33301 .54817 m .3308 .55075 L .33113 .54842 L F
.5 0 0 r
.35218 .49974 m .35395 .5003 L .35045 .49861 L F
.574 .073 0 r
.35451 .50114 m .35395 .5003 L .35218 .49974 L F
.35451 .50114 m .35584 .50241 L .35395 .5003 L F
.855 .814 .809 r
.59224 .37118 m .58785 .3728 L .59121 .3702 L F
.59224 .37118 m .58957 .37437 L .58785 .3728 L F
.831 .897 .887 r
.5947 .36866 m .59224 .37118 L .59232 .36793 L F
0 0 .187 r
.55931 .41989 m .56075 .41532 L .5607 .41804 L F
0 .012 .53 r
.56066 .42061 m .55931 .41989 L .5607 .41804 L F
0 0 .056 r
.33659 .57431 m .33402 .57753 L .33598 .57623 L F
.131 0 .272 r
.33402 .57753 m .33472 .57776 L .33598 .57623 L F
.33402 .57753 m .33341 .57988 L .33472 .57776 L F
.565 .937 .837 r
.67761 .37928 m .68086 .37759 L .67892 .37796 L F
.658 .972 .844 r
.67892 .37796 m .68086 .37759 L .68284 .37595 L F
0 .202 .717 r
.36684 .6816 m .36783 .68386 L .36922 .68319 L F
0 .116 .606 r
.36783 .68386 m .36976 .68554 L .36905 .68536 L F
.36976 .68554 m .37167 .68719 L .36905 .68536 L F
.881 .963 .845 r
.36753 .68497 m .36905 .68536 L .36614 .68644 L F
0 .116 .606 r
.36783 .68386 m .36905 .68536 L .36922 .68319 L F
.881 .963 .845 r
.36922 .68319 m .36905 .68536 L .36753 .68497 L F
.215 .569 .939 r
.31866 .52259 m .32144 .52324 L .32091 .52338 L F
.522 .404 .66 r
.36114 .5835 m .35912 .58683 L .35893 .58407 L F
.765 .789 .873 r
.41871 .49248 m .4206 .49425 L .42244 .49295 L F
.655 .565 .741 r
.4206 .49425 m .42061 .49519 L .42115 .49453 L F
.698 .226 .125 r
.42244 .49295 m .42076 .49482 L .41871 .49248 L F
.585 .844 .49 r
.4237 .49127 m .42076 .49482 L .42239 .49301 L F
.42249 .49289 m .42239 .49301 L .42244 .49295 L F
.4237 .49127 m .42239 .49301 L .42249 .49289 L F
.655 .565 .741 r
.42115 .49453 m .42063 .49682 L .42417 .49612 L F
.42061 .49519 m .42063 .49682 L .42115 .49453 L F
.74 .561 0 r
.42063 .49682 m .42281 .49667 L .42417 .49612 L F
.42063 .49682 m .4209 .5006 L .42076 .49919 L F
.42063 .49682 m .42076 .49919 L .42281 .49667 L F
.642 .832 .974 r
.34614 .69423 m .34866 .6933 L .34449 .69299 L F
.997 .778 .43 r
.4409 .54428 m .44073 .54703 L .44207 .54843 L F
.958 .617 .276 r
.44102 .54986 m .44207 .54843 L .44073 .54703 L F
.44102 .54986 m .44274 .55129 L .44207 .54843 L F
.754 .857 .926 r
.4463 .56781 m .45171 .56539 L .44891 .56482 L F
0 0 .425 r
.39968 .52937 m .40096 .53156 L .39904 .52792 L F
.552 .447 .689 r
.48027 .52528 m .48098 .52879 L .47853 .5295 L F
.576 .444 .664 r
.48098 .52879 m .47867 .5321 L .47853 .5295 L F
.378 0 0 r
.34059 .62716 m .33951 .6274 L .33711 .62539 L F
.673 .152 0 r
.33711 .62539 m .33951 .6274 L .33618 .62716 L F
.849 .479 .35 r
.33618 .62716 m .33951 .6274 L .33738 .62906 L F
.838 .979 .684 r
.33849 .62763 m .33951 .6274 L .33995 .62574 L F
.33738 .62906 m .33951 .6274 L .33849 .62763 L F
.378 0 0 r
.34144 .62759 m .33951 .6274 L .34059 .62716 L F
.673 .893 .538 r
.43674 .58703 m .43427 .59041 L .43504 .589 L F
0 0 .206 r
.43427 .59041 m .43491 .59168 L .43504 .589 L F
.43427 .59041 m .43429 .59366 L .43491 .59168 L F
.898 .975 .676 r
.26029 .60979 m .25817 .61164 L .25994 .60908 L F
.907 .763 .271 r
.25994 .60908 m .25977 .60914 L .26029 .60979 L F
0 0 0 r
.25913 .61116 m .26029 .60979 L .25977 .60914 L F
.25913 .61116 m .25817 .61164 L .26029 .60979 L F
.563 .442 .673 r
.48134 .51536 m .48243 .51913 L .47963 .51957 L F
.644 .458 .617 r
.48269 .52194 m .47963 .51957 L .48243 .51913 L F
.48269 .52194 m .4799 .52243 L .47963 .51957 L F
.929 .796 .693 r
.60588 .45461 m .6065 .45161 L .60471 .45051 L F
.659 .698 .875 r
.35509 .69602 m .35713 .69944 L .35912 .69678 L F
.867 .743 .229 r
.41163 .59049 m .41089 .59261 L .41041 .58887 L F
.41163 .59049 m .41134 .59308 L .41089 .59261 L F
.762 .863 .923 r
.50234 .42557 m .49945 .42519 L .5007 .42393 L F
.859 .827 .815 r
.50489 .42193 m .50234 .42557 L .5007 .42393 L F
.596 .797 .976 r
.45425 .57687 m .45212 .57781 L .45053 .576 L F
.901 .877 .803 r
.74234 .31918 m .74457 .31584 L .7432 .31434 L F
0 .051 .618 r
.74169 .30639 m .74316 .30938 L .74279 .30788 L F
.74169 .30639 m .74316 .30938 L .74279 .30788 L F
.902 .687 .602 r
.74316 .30938 m .74034 .31068 L .74279 .30788 L F
.74316 .30938 m .74233 .31447 L .74034 .31068 L F
.728 .408 0 r
.7432 .30999 m .74316 .30938 L .74279 .30788 L F
.7432 .30999 m .74395 .31187 L .74316 .30938 L F
.54 .712 .951 r
.54444 .4091 m .54353 .41187 L .54205 .41011 L F
.54444 .4091 m .54611 .41138 L .54353 .41187 L F
.636 .829 .419 r
.69427 .28387 m .69202 .28741 L .69349 .28493 L F
.787 .989 .747 r
.69736 .28037 m .69427 .28387 L .69545 .2814 L F
.692 .843 .418 r
.69545 .2814 m .69427 .28387 L .69349 .28493 L F
.434 .173 .417 r
.51803 .48349 m .51535 .48644 L .51537 .48381 L F
0 0 .55 r
.38112 .59304 m .38026 .59333 L .37977 .5899 L F
.392 .37 .715 r
.70296 .29871 m .70164 .30016 L .70194 .29709 L F
0 0 .208 r
.70296 .29871 m .70102 .30229 L .70164 .30016 L F
0 0 0 r
.68026 .36263 m .68081 .36134 L .67779 .36431 L F
0 0 .121 r
.68026 .36263 m .67779 .36431 L .67757 .36573 L F
.824 .466 0 r
.42764 .56892 m .42721 .56641 L .42675 .5659 L F
.985 .709 .353 r
.60332 .40625 m .60212 .40743 L .60179 .40497 L F
.60332 .40625 m .60343 .40881 L .60212 .40743 L F
.143 0 0 r
.307 .63885 m .30292 .64154 L .30567 .64098 L F
0 .173 .697 r
.30548 .63497 m .307 .63885 L .3078 .63742 L F
.626 .807 .382 r
.3078 .63742 m .307 .63885 L .30567 .64098 L F
.776 .7 .779 r
.48145 .53159 m .48329 .53572 L .47887 .53504 L F
.648 .581 .766 r
.48184 .53599 m .48052 .5353 L .48329 .53572 L F
.348 .465 .837 r
.48466 .53394 m .48329 .53572 L .48145 .53159 L F
.525 .389 .639 r
.48466 .53394 m .48184 .53599 L .48329 .53572 L F
.48466 .53394 m .4842 .53723 L .48184 .53599 L F
.4842 .53723 m .48417 .53742 L .48184 .53599 L F
.648 .581 .766 r
.48184 .53599 m .47887 .53504 L .48052 .5353 L F
.37 0 .106 r
.5533 .39574 m .55223 .3981 L .54956 .39855 L F
.501 .446 .727 r
.55571 .39285 m .5533 .39574 L .55287 .39414 L F
.788 .398 0 r
.39583 .52157 m .394 .51807 L .39578 .5193 L F
.114 0 0 r
.38186 .47936 m .38536 .47772 L .38302 .47942 L F
.745 .715 .824 r
.45171 .56539 m .45284 .56519 L .45027 .56441 L F
.5 .492 .779 r
.33706 .54563 m .33795 .54156 L .33593 .54184 L F
.33706 .54563 m .33878 .54526 L .33795 .54156 L F
.874 .719 .686 r
.44383 .48511 m .44066 .4806 L .44206 .48384 L F
.334 .174 .51 r
.44206 .48384 m .4417 .48577 L .44383 .48511 L F
.637 .695 .887 r
.32267 .53826 m .32341 .5355 L .32106 .53618 L F
.32267 .53826 m .32548 .53869 L .32341 .5355 L F
.467 .069 .2 r
.32143 .54111 m .32548 .53869 L .32267 .53826 L F
.041 .357 .83 r
.58037 .38251 m .57716 .37905 L .57877 .38078 L F
.857 .728 .207 r
.54626 .41608 m .54601 .41453 L .54345 .41525 L F
0 0 .353 r
.54601 .41453 m .54626 .41608 L .54345 .41525 L F
.268 .517 .906 r
.33117 .5297 m .33192 .53189 L .33097 .53232 L F
.633 .935 .965 r
.33145 .53319 m .33097 .53232 L .33192 .53189 L F
.33145 .53319 m .33045 .53488 L .33097 .53232 L F
0 0 0 r
.57133 .43741 m .57089 .4375 L .57041 .43916 L F
.57089 .4375 m .57306 .4369 L .57026 .43761 L F
.91 .979 .78 r
.57387 .43395 m .57306 .4369 L .57089 .4375 L F
0 0 0 r
.57253 .43515 m .57089 .4375 L .57133 .43741 L F
.57089 .4375 m .57026 .43761 L .56885 .43798 L F
.681 .367 .437 r
.63386 .35116 m .62958 .35228 L .6312 .35109 L F
.726 .735 .858 r
.62493 .35918 m .62592 .36401 L .62225 .3627 L F
.829 .553 .521 r
.62225 .3627 m .62592 .36401 L .62354 .3661 L F
.426 .613 .927 r
.62592 .36401 m .62721 .36648 L .62354 .3661 L F
.62592 .36401 m .62811 .36486 L .62721 .36648 L F
.678 .703 .866 r
.62493 .35918 m .62592 .36401 L .62904 .35995 L F
.561 .585 .835 r
.62929 .36339 m .62592 .36401 L .62904 .35995 L F
.62929 .36339 m .62811 .36486 L .62592 .36401 L F
.678 .703 .866 r
.62904 .35995 m .62592 .36401 L .62493 .35918 L F
.62904 .35995 m .62592 .36401 L .62493 .35918 L F
.717 .906 .962 r
.38067 .49968 m .37689 .50165 L .37545 .50116 L F
.722 .215 0 r
.37689 .50165 m .37992 .50555 L .37824 .5043 L F
.759 .249 0 r
.38159 .50642 m .37992 .50555 L .37689 .50165 L F
.712 .497 .596 r
.67832 .35348 m .67934 .35362 L .67941 .35335 L F
.67934 .35362 m .68161 .35393 L .67941 .35335 L F
.49 .386 .663 r
.68031 .3497 m .68046 .35274 L .67832 .35348 L F
.68046 .35274 m .68052 .3539 L .67978 .35376 L F
.098 0 .325 r
.67941 .35335 m .67633 .35851 L .67686 .35813 L F
.67927 .35386 m .67686 .35813 L .67894 .35501 L F
.549 .028 0 r
.68068 .35523 m .68161 .35393 L .67934 .35362 L F
.098 0 .325 r
.67934 .35362 m .67913 .35388 L .67927 .35386 L F
.6793 .35356 m .67913 .35388 L .67934 .35362 L F
.67913 .35388 m .67686 .35813 L .67927 .35386 L F
.67941 .35335 m .67837 .35705 L .67875 .35677 L F
.549 .028 0 r
.67936 .35364 m .67934 .35362 L .67832 .35348 L F
.098 0 .325 r
.67941 .35335 m .6793 .35356 L .67934 .35362 L F
.67941 .35335 m .67936 .35364 L .67832 .35348 L F
.67894 .35501 m .67686 .35813 L .67837 .35705 L F
.67936 .35364 m .67875 .35677 L .67832 .35348 L F
.549 .028 0 r
.6803 .35495 m .67936 .35364 L .67832 .35348 L F
.68068 .35523 m .67934 .35362 L .6803 .35495 L F
.49 .386 .663 r
.68046 .35274 m .67978 .35376 L .67832 .35348 L F
.208 .591 .946 r
.67832 .35348 m .67978 .35376 L .67968 .3523 L F
.67978 .35376 m .68052 .3539 L .68039 .35365 L F
.67978 .35376 m .68039 .35365 L .67968 .3523 L F
.519 .692 .946 r
.67875 .35677 m .67633 .35851 L .67906 .3581 L F
.918 .909 .512 r
.2778 .64937 m .27851 .64838 L .27756 .65069 L F
.27836 .64643 m .27851 .64838 L .2778 .64937 L F
.781 .612 .671 r
.2779 .64528 m .27923 .64736 L .27851 .64838 L F
.27923 .64736 m .27984 .64832 L .27851 .64838 L F
.834 .546 .502 r
.27984 .64832 m .27756 .65069 L .27851 .64838 L F
.27984 .64832 m .28162 .65058 L .27756 .65069 L F
.627 .894 .577 r
.32807 .61105 m .32681 .61212 L .32703 .61221 L F
.744 .411 0 r
.32681 .61212 m .32799 .61517 L .32703 .61221 L F
.477 .15 .333 r
.31468 .56503 m .31381 .56704 L .31117 .56746 L F
.421 .115 .338 r
.31716 .56433 m .31381 .56704 L .31468 .56503 L F
.938 .566 .227 r
.42875 .48422 m .42687 .48331 L .42673 .4812 L F
0 0 0 r
.57737 .43217 m .57387 .43395 L .57529 .43168 L F
.57737 .43217 m .57642 .43267 L .57387 .43395 L F
.052 .109 .604 r
.21756 .56773 m .21923 .56971 L .21886 .566 L F
.221 .146 .555 r
.21778 .57049 m .21923 .56971 L .21756 .56773 L F
.469 .027 .114 r
.54692 .47413 m .5482 .47618 L .54571 .47613 L F
.54692 .47413 m .54973 .47412 L .5482 .47618 L F
.43 .061 .235 r
.33598 .57623 m .3384 .57539 L .33659 .57431 L F
.436 .055 .216 r
.33659 .57431 m .3384 .57539 L .33954 .57397 L F
.544 .324 .531 r
.38723 .47788 m .39041 .48104 L .38829 .47876 L F
.38723 .47788 m .38829 .47876 L .38723 .47762 L F
.274 0 0 r
.38682 .47753 m .38723 .47788 L .38945 .4772 L F
.38536 .47772 m .38723 .47788 L .38682 .47753 L F
.858 .987 .714 r
.38945 .4772 m .38896 .47667 L .39127 .47352 L F
.706 .985 .866 r
.38945 .4772 m .38723 .47788 L .38896 .47667 L F
.272 .512 .902 r
.4488 .57254 m .44824 .57446 L .44577 .57107 L F
.986 .793 .56 r
.44632 .57358 m .44824 .57446 L .4488 .57254 L F
.44632 .57358 m .44765 .57696 L .44824 .57446 L F
.439 0 0 r
.43091 .51391 m .42677 .51233 L .42828 .51567 L F
.005 .107 .621 r
.42962 .5139 m .42828 .51567 L .42635 .51708 L F
.42962 .5139 m .43112 .52041 L .42828 .51567 L F
.887 .969 .835 r
.6435 .40075 m .64344 .40344 L .64468 .40138 L F
.934 .942 .599 r
.64238 .40541 m .64344 .40344 L .6435 .40075 L F
.467 .069 .2 r
.32143 .54111 m .32391 .54109 L .32548 .53869 L F
.6 .678 .896 r
.32341 .5355 m .32548 .53869 L .32691 .53668 L F
.025 0 0 r
.32548 .53869 m .3266 .5395 L .32691 .53668 L F
.32548 .53869 m .32391 .54109 L .3266 .5395 L F
0 0 0 r
.57564 .42807 m .57645 .42702 L .57659 .42542 L F
.766 .502 .535 r
.57997 .42269 m .57911 .42368 L .57905 .42365 L F
0 0 0 r
.57905 .42365 m .57659 .42542 L .57866 .42406 L F
.57997 .42269 m .57784 .42441 L .57905 .42365 L F
.57784 .42441 m .57659 .42542 L .57905 .42365 L F
.766 .502 .535 r
.57997 .42269 m .57905 .42365 L .5753 .42173 L F
.55 .631 .884 r
.5753 .42173 m .57905 .42365 L .57645 .4182 L F
.57905 .42365 m .57911 .42368 L .57908 .42363 L F
.57905 .42365 m .57908 .42363 L .57645 .4182 L F
.656 .687 .868 r
.57645 .4182 m .57908 .42363 L .58171 .42051 L F
.57908 .42363 m .57911 .42368 L .57925 .42351 L F
0 0 0 r
.57997 .42269 m .57904 .42366 L .57927 .4235 L F
.656 .687 .868 r
.57908 .42363 m .57925 .42351 L .58171 .42051 L F
0 0 0 r
.57927 .4235 m .57866 .42406 L .57895 .42387 L F
.57904 .42366 m .57866 .42406 L .57927 .4235 L F
.162 0 .138 r
.57645 .42702 m .57895 .42387 L .57659 .42542 L F
0 0 0 r
.46157 .56396 m .4635 .56292 L .4648 .56098 L F
.266 .338 .752 r
.4648 .56098 m .46558 .55689 L .46347 .55683 L F
0 0 0 r
.4648 .56098 m .4668 .559 L .46625 .56022 L F
.266 .338 .752 r
.4648 .56098 m .46625 .56022 L .46614 .55965 L F
0 0 0 r
.46614 .55965 m .46655 .55929 L .46678 .55902 L F
.002 .135 .65 r
.46558 .55689 m .46614 .55965 L .46647 .55935 L F
.46653 .55923 m .46647 .55935 L .46655 .55928 L F
.46558 .55689 m .46647 .55935 L .46653 .55923 L F
.46558 .55689 m .46655 .55928 L .46685 .55813 L F
0 0 0 r
.4648 .56098 m .46678 .55902 L .4668 .559 L F
.266 .338 .752 r
.4648 .56098 m .46614 .55965 L .46558 .55689 L F
0 0 .257 r
.46701 .55763 m .46558 .55689 L .46731 .55858 L F
.726 .98 .76 r
.46685 .55862 m .46387 .56064 L .46701 .55763 L F
.4668 .559 m .4666 .55911 L .46685 .55862 L F
.4666 .55911 m .46387 .56064 L .46685 .55862 L F
0 0 0 r
.4648 .56098 m .4635 .56292 L .46655 .55929 L F
.4648 .56098 m .46655 .55929 L .46614 .55965 L F
.859 .996 .769 r
.4666 .55911 m .4635 .56292 L .46387 .56064 L F
.4668 .559 m .46655 .55929 L .4666 .55911 L F
.46655 .55929 m .4635 .56292 L .4666 .55911 L F
.726 .98 .76 r
.4668 .559 m .46685 .55862 L .46731 .55858 L F
.002 .135 .65 r
.46685 .55813 m .46672 .55863 L .46731 .55858 L F
.726 .98 .76 r
.46685 .55862 m .46701 .55763 L .46731 .55858 L F
.002 .135 .65 r
.46672 .55863 m .46655 .55928 L .46731 .55858 L F
0 0 .104 r
.46731 .55858 m .46625 .56022 L .4668 .559 L F
.002 .135 .65 r
.46614 .55965 m .46625 .56022 L .46725 .55867 L F
.46614 .55965 m .46725 .55867 L .46731 .55858 L F
.531 .617 .883 r
.22723 .57648 m .22693 .58048 L .22578 .57667 L F
.22723 .57648 m .22926 .57996 L .22693 .58048 L F
.273 .354 .764 r
.22998 .58282 m .22693 .58048 L .22926 .57996 L F
.522 0 0 r
.2504 .62205 m .25022 .62234 L .24847 .62125 L F
.2504 .62205 m .2521 .62319 L .25022 .62234 L F
.696 .648 .798 r
.52482 .40591 m .52638 .40987 L .52169 .40838 L F
.493 .432 .717 r
.48184 .53599 m .48032 .54113 L .4801 .5396 L F
.48184 .53599 m .48285 .5388 L .48032 .54113 L F
.577 .571 .81 r
.48285 .5388 m .48299 .54126 L .48032 .54113 L F
.348 .138 .447 r
.48299 .54126 m .48062 .54494 L .48032 .54113 L F
.646 .47 .631 r
.48032 .54113 m .48062 .54494 L .47777 .54448 L F
.297 .781 .709 r
.63465 .33744 m .63664 .33657 L .63799 .33617 L F
0 0 0 r
.63465 .33744 m .63349 .33903 L .63664 .33657 L F
.966 .646 .272 r
.40657 .5457 m .40535 .54469 L .40485 .54167 L F
.692 .297 0 r
.40657 .5457 m .40693 .5467 L .40535 .54469 L F
.40657 .5457 m .40761 .54779 L .40693 .5467 L F
.574 .244 .372 r
.32233 .52836 m .32488 .52921 L .32612 .52613 L F
.659 .332 .409 r
.32612 .52613 m .32875 .52778 L .32891 .52573 L F
.32612 .52613 m .32488 .52921 L .32875 .52778 L F
.928 .743 .631 r
.60325 .44408 m .605 .44516 L .60365 .44135 L F
.975 .795 .597 r
.60301 .44689 m .605 .44516 L .60325 .44408 L F
.60301 .44689 m .60465 .448 L .605 .44516 L F
.771 .705 .789 r
.33045 .53488 m .33247 .5385 L .32691 .53668 L F
.781 .708 .782 r
.33465 .53532 m .33247 .5385 L .33045 .53488 L F
0 .055 .559 r
.33593 .54184 m .33531 .54112 L .33247 .5385 L F
.356 .274 .625 r
.33247 .5385 m .33531 .54112 L .33358 .54097 L F
.69 .609 .761 r
.34194 .58383 m .33936 .58414 L .3381 .58077 L F
.673 .495 .636 r
.33936 .58414 m .33933 .58718 L .34194 .58383 L F
.33936 .58414 m .33933 .58718 L .34194 .58383 L F
.484 .502 .8 r
.36531 .55154 m .36826 .55233 L .36621 .54646 L F
.395 0 .137 r
.36485 .55393 m .36826 .55233 L .36531 .55154 L F
.785 .539 .565 r
.24577 .55054 m .25006 .55112 L .25018 .54837 L F
.871 .624 .562 r
.37401 .55814 m .37357 .56076 L .37207 .55641 L F
.599 .887 .991 r
.56148 .3907 m .56461 .38943 L .56595 .39038 L F
.899 .987 .749 r
.56825 .38695 m .56595 .39038 L .5665 .3874 L F
.825 .948 .901 r
.56595 .39038 m .56461 .38943 L .5665 .3874 L F
.39 0 0 r
.25752 .61771 m .26069 .61757 L .26174 .61612 L F
.213 .683 .94 r
.25803 .61649 m .26008 .61695 L .26069 .61757 L F
.976 .852 .458 r
.26069 .61757 m .26123 .61811 L .26174 .61612 L F
.213 .683 .94 r
.26008 .61695 m .2621 .6174 L .26069 .61757 L F
.976 .852 .458 r
.26069 .61757 m .26096 .61916 L .26123 .61811 L F
.38 .808 .967 r
.56935 .38592 m .56825 .38695 L .5665 .3874 L F
.56935 .38592 m .57086 .38647 L .56825 .38695 L F
.654 .86 .978 r
.35217 .6454 m .34793 .64528 L .35059 .64533 L F
0 0 0 r
.35464 .64198 m .35217 .6454 L .35406 .64412 L F
.065 .629 .748 r
.35403 .64192 m .35464 .64198 L .35047 .64209 L F
.743 .455 .494 r
.35047 .64209 m .35464 .64198 L .35406 .64412 L F
.462 .674 .956 r
.35174 .63989 m .35403 .64192 L .35047 .64209 L F
.603 .948 .919 r
.35406 .64412 m .35217 .6454 L .35162 .64538 L F
.35406 .64412 m .35162 .64538 L .35212 .6448 L F
.35212 .6448 m .35162 .64538 L .35059 .64533 L F
.35406 .64412 m .35059 .64533 L .35303 .6449 L F
.743 .455 .494 r
.35047 .64209 m .35406 .64412 L .35303 .6449 L F
.126 .234 .707 r
.35047 .64209 m .35252 .64434 L .35174 .63989 L F
.35252 .64434 m .35303 .6449 L .3528 .64401 L F
.35252 .64434 m .3528 .64401 L .35174 .63989 L F
.837 .998 .78 r
.34668 .54498 m .34408 .54821 L .34384 .54532 L F
.674 .975 .82 r
.67123 .32435 m .66987 .32626 L .67185 .32456 L F
.67123 .32435 m .66814 .32661 L .66987 .32626 L F
.354 .109 .397 r
.3797 .5445 m .37745 .5453 L .37789 .54333 L F
.3797 .5445 m .37701 .54767 L .37745 .5453 L F
.37745 .5453 m .37701 .54767 L .3797 .5445 L F
.129 0 0 r
.34342 .68178 m .33994 .68375 L .34259 .68293 L F
.887 .979 .822 r
.43108 .47288 m .43285 .46927 L .4318 .47085 L F
.971 .697 .452 r
.40826 .47115 m .40776 .47318 L .40592 .46963 L F
.568 .71 .937 r
.4083 .46862 m .40826 .47115 L .40592 .46963 L F
.4083 .46862 m .41132 .47077 L .40826 .47115 L F
.423 .078 .274 r
.41132 .47077 m .40776 .47318 L .40826 .47115 L F
.755 .937 .945 r
.44262 .49824 m .44183 .50027 L .44402 .49952 L F
.723 .641 .766 r
.43745 .49922 m .439 .50326 L .44183 .50027 L F
0 0 .068 r
.44067 .49672 m .44013 .49857 L .44185 .49537 L F
.353 0 .08 r
.43745 .49922 m .43992 .49888 L .43957 .49941 L F
.43992 .49888 m .44073 .49877 L .43957 .49941 L F
.44073 .49877 m .44172 .49864 L .44075 .49899 L F
.44073 .49877 m .44075 .49899 L .43957 .49941 L F
.43957 .49941 m .44172 .49864 L .44041 .49949 L F
.502 .311 .553 r
.44138 .49875 m .43993 .49923 L .44041 .49949 L F
.353 0 .08 r
.44073 .49877 m .43993 .49923 L .44172 .49864 L F
.502 .311 .553 r
.44236 .498 m .43993 .49923 L .44138 .49875 L F
.353 0 .08 r
.44172 .49864 m .43993 .49923 L .44195 .49861 L F
.43745 .49922 m .43993 .49923 L .44073 .49877 L F
.419 .122 .352 r
.43745 .49922 m .43993 .49923 L .44067 .49672 L F
.83 .724 .748 r
.44059 .49595 m .43993 .49923 L .43915 .49661 L F
0 0 .068 r
.44013 .49857 m .44068 .49773 L .44185 .49537 L F
.83 .724 .748 r
.44185 .49537 m .44068 .49773 L .44059 .49595 L F
0 0 .068 r
.44013 .49857 m .43993 .49923 L .44068 .49773 L F
.83 .724 .748 r
.44068 .49773 m .43993 .49923 L .44059 .49595 L F
.723 .641 .766 r
.43745 .49922 m .43919 .49964 L .44041 .49949 L F
.43919 .49964 m .44183 .50027 L .44048 .49953 L F
.43919 .49964 m .44048 .49953 L .44041 .49949 L F
.616 .077 0 r
.43955 .5034 m .43775 .50151 L .44064 .49951 L F
.502 .311 .553 r
.4423 .49826 m .44041 .49949 L .44183 .50027 L F
.616 .077 0 r
.44154 .49943 m .44064 .49951 L .44195 .49861 L F
.43955 .5034 m .44064 .49951 L .44154 .49943 L F
.353 0 .08 r
.43745 .49922 m .44041 .49949 L .43772 .50125 L F
.723 .641 .766 r
.43745 .49922 m .44041 .49949 L .43993 .49923 L F
.502 .311 .553 r
.44236 .498 m .44041 .49949 L .4423 .49826 L F
.353 0 .08 r
.43772 .50125 m .44195 .49861 L .43775 .50151 L F
.44172 .49864 m .44195 .49861 L .43772 .50125 L F
.375 .158 .451 r
.44228 .5007 m .43955 .5034 L .44195 .49861 L F
.555 .277 .449 r
.44187 .49863 m .44228 .5007 L .44195 .49861 L F
.43993 .49923 m .44028 .49945 L .44187 .49863 L F
.44028 .49945 m .44228 .5007 L .44187 .49863 L F
.755 .937 .945 r
.44236 .498 m .44225 .49843 L .44262 .49824 L F
.44225 .49843 m .44183 .50027 L .44262 .49824 L F
.559 .861 .997 r
.44492 .4974 m .44402 .49952 L .44651 .49599 L F
.44492 .4974 m .44236 .498 L .44402 .49952 L F
.613 .412 .585 r
.35446 .60975 m .35411 .61259 L .35183 .61221 L F
.461 .244 .497 r
.35713 .60657 m .35695 .60924 L .35446 .60975 L F
.331 .166 .502 r
.3562 .61166 m .35446 .60975 L .35695 .60924 L F
.3562 .61166 m .35411 .61259 L .35446 .60975 L F
.901 .877 .803 r
.74234 .31918 m .7432 .31434 L .73763 .31643 L F
0 .193 .7 r
.22819 .60438 m .22897 .60418 L .22624 .60256 L F
.585 .01 0 r
.23052 .6055 m .23018 .60584 L .22819 .60438 L F
.23238 .6064 m .23018 .60584 L .23052 .6055 L F
.909 .571 .099 r
.23018 .60584 m .23053 .60791 L .22981 .6062 L F
0 .193 .7 r
.22819 .60438 m .23018 .60584 L .22897 .60418 L F
.909 .571 .099 r
.23018 .60584 m .22981 .6062 L .22897 .60418 L F
.673 .939 .965 r
.45065 .45107 m .45366 .45068 L .45178 .45204 L F
.708 .646 .785 r
.33869 .60266 m .34454 .60485 L .3411 .59855 L F
.295 .783 .902 r
.33952 .60493 m .34454 .60485 L .33912 .60282 L F
.33789 .60496 m .33952 .60493 L .33869 .60266 L F
.33952 .60493 m .33912 .60282 L .33869 .60266 L F
.33941 .60493 m .34037 .60449 L .34454 .60485 L F
.33789 .60496 m .34037 .60449 L .33941 .60493 L F
0 .073 .635 r
.3411 .59855 m .34454 .60485 L .34366 .60176 L F
.486 .213 .424 r
.34037 .60449 m .34366 .60176 L .34454 .60485 L F
.34037 .60449 m .34334 .60439 L .34366 .60176 L F
0 0 .379 r
.34182 .60062 m .34156 .60395 L .34037 .60449 L F
.511 .32 .558 r
.34037 .60449 m .34064 .60753 L .34334 .60439 L F
0 0 .379 r
.34156 .60395 m .34147 .60505 L .34037 .60449 L F
0 0 .406 r
.33983 .60662 m .34064 .60753 L .34037 .60449 L F
.33931 .60873 m .3401 .60802 L .33983 .60662 L F
.3401 .60802 m .34064 .60753 L .33983 .60662 L F
.899 .696 .186 r
.41238 .5707 m .41195 .57003 L .41196 .5672 L F
1 .828 .523 r
.41238 .5707 m .41078 .57242 L .41195 .57003 L F
.41238 .5707 m .41192 .57299 L .41078 .57242 L F
.584 .01 0 r
.27764 .61484 m .27906 .61581 L .27774 .61513 L F
.929 .796 .693 r
.60588 .45461 m .60471 .45051 L .60442 .45284 L F
.935 .683 .533 r
.60312 .45661 m .60588 .45461 L .60442 .45284 L F
.60312 .45661 m .60573 .45698 L .60588 .45461 L F
.668 .96 .94 r
.34261 .65505 m .34594 .65388 L .3452 .65447 L F
.632 .22 .244 r
.34516 .65442 m .34755 .65216 L .34331 .65212 L F
.578 .899 .639 r
.34331 .65212 m .34014 .65488 L .34261 .65505 L F
.632 .22 .244 r
.3452 .65447 m .34331 .65212 L .34261 .65505 L F
.589 .567 .797 r
.34482 .65167 m .34331 .65399 L .34116 .65164 L F
.34331 .65399 m .34261 .65505 L .34203 .65368 L F
.34331 .65399 m .34203 .65368 L .34116 .65164 L F
.632 .22 .244 r
.3452 .65447 m .34523 .65444 L .34516 .65442 L F
.34523 .65444 m .34755 .65216 L .34516 .65442 L F
.669 .864 .974 r
.39386 .47533 m .39197 .47667 L .39558 .47669 L F
.39386 .47533 m .39197 .47667 L .39558 .47669 L F
.674 .866 .972 r
.39386 .47533 m .39558 .47669 L .39876 .4754 L F
.582 .037 0 r
.39386 .47533 m .39859 .47907 L .39558 .47669 L F
.505 .417 .69 r
.39558 .47669 m .39859 .47907 L .39617 .47931 L F
.837 .809 .823 r
.30927 .66202 m .30861 .66381 L .30685 .66062 L F
.575 .738 .953 r
.31229 .66419 m .30861 .66381 L .30927 .66202 L F
.598 .395 .577 r
.61381 .35785 m .61575 .35968 L .61529 .35794 L F
.566 .058 .005 r
.35277 .51235 m .34843 .51208 L .34888 .5114 L F
.721 .777 .897 r
.58957 .37437 m .58526 .37361 L .58785 .3728 L F
.848 .695 .692 r
.5599 .39534 m .56139 .39691 L .5587 .39542 L F
.587 .365 .546 r
.29124 .56722 m .29389 .56719 L .29406 .56451 L F
.966 .664 .4 r
.5986 .42933 m .60024 .4293 L .5978 .42621 L F
.5986 .42933 m .60032 .43111 L .60024 .4293 L F
.41 .583 .911 r
.3737 .60585 m .3751 .60434 L .37218 .60318 L F
0 0 .571 r
.23149 .59833 m .23312 .60209 L .2315 .59999 L F
.205 .137 .554 r
.23312 .60209 m .23174 .603 L .2315 .59999 L F
.671 .951 .954 r
.53137 .40309 m .5275 .40388 L .52996 .40169 L F
.504 .037 .079 r
.52999 .40411 m .53137 .40309 L .52996 .40169 L F
.52999 .40411 m .53398 .40262 L .53137 .40309 L F
.69 .609 .761 r
.34194 .58383 m .3381 .58077 L .34011 .581 L F
.658 .55 .722 r
.34419 .58055 m .34194 .58383 L .34011 .581 L F
.968 .916 .701 r
.40819 .55934 m .41057 .55813 L .4094 .56037 L F
.985 .706 .361 r
.40909 .55418 m .41057 .55813 L .40928 .55718 L F
.976 .883 .671 r
.40928 .55718 m .41057 .55813 L .40819 .55934 L F
.64 .298 .376 r
.61378 .34761 m .61006 .34803 L .61289 .34789 L F
0 0 0 r
.61378 .34761 m .61589 .347 L .61635 .34708 L F
.61378 .34761 m .61289 .34789 L .61589 .347 L F
.22167 .55506 m .22067 .55739 L .223 .55367 L F
.992 .753 .463 r
.64822 .38334 m .64912 .38672 L .64767 .38559 L F
.994 .866 .592 r
.41125 .57951 m .41233 .58072 L .41142 .58337 L F
.745 .715 .824 r
.45171 .56539 m .45027 .56441 L .44891 .56482 L F
.812 .704 .745 r
.4223 .46062 m .42366 .46446 L .42009 .46435 L F
0 0 .024 r
.42619 .46657 m .42366 .46446 L .42688 .46428 L F
.326 .135 .461 r
.35899 .60831 m .35713 .60657 L .3595 .60592 L F
.35899 .60831 m .35695 .60924 L .35713 .60657 L F
.764 .861 .921 r
.48411 .43488 m .48201 .43646 L .48035 .435 L F
.328 0 .248 r
.47099 .58753 m .47019 .58945 L .46776 .59022 L F
0 0 .02 r
.47262 .58604 m .47019 .58945 L .47099 .58753 L F
.765 .993 .786 r
.69349 .28493 m .69202 .28741 L .69023 .28891 L F
.179 0 0 r
.68493 .35394 m .6852 .35353 L .68161 .35393 L F
0 0 0 r
.68711 .35233 m .68828 .35115 L .6852 .35353 L F
.56103 .44511 m .55849 .44901 L .56109 .44795 L F
.692 .512 .64 r
.56103 .44511 m .56109 .44795 L .55758 .44766 L F
.494 .294 .537 r
.5637 .44463 m .56109 .44795 L .56103 .44511 L F
.5637 .44463 m .56109 .44795 L .56103 .44511 L F
.91 .843 .39 r
.42109 .48375 m .42195 .4838 L .4236 .48307 L F
.42109 .48375 m .42128 .48656 L .42195 .4838 L F
.605 .873 .541 r
.24871 .52535 m .24673 .52733 L .24565 .52883 L F
.598 .859 .513 r
.24673 .52733 m .24402 .53056 L .24565 .52883 L F
.582 .399 .598 r
.34105 .61505 m .33806 .61278 L .34001 .61207 L F
.34105 .61505 m .33827 .61575 L .33806 .61278 L F
.982 .723 .46 r
.24385 .58655 m .24346 .58896 L .24341 .58883 L F
.639 .342 .45 r
.2442 .58474 m .24385 .58655 L .24143 .58593 L F
.181 .611 .942 r
.24143 .58593 m .24385 .58655 L .24193 .58509 L F
.982 .723 .46 r
.24385 .58655 m .24341 .58883 L .24193 .58509 L F
.639 .342 .45 r
.24498 .58441 m .24385 .58655 L .2442 .58474 L F
.472 .16 .355 r
.24595 .58489 m .24498 .58441 L .24682 .58317 L F
.24595 .58489 m .24385 .58655 L .24498 .58441 L F
.475 .869 .684 r
.42338 .51568 m .41965 .51808 L .42236 .51654 L F
.513 .351 .599 r
.42236 .51654 m .42185 .5194 L .42451 .51875 L F
.509 .892 .717 r
.35437 .65035 m .35666 .64925 L .35852 .64791 L F
.566 0 0 r
.33432 .61878 m .32971 .61658 L .32799 .61517 L F
.235 .578 .943 r
.33348 .61838 m .33419 .61774 L .33432 .61878 L F
.33348 .61838 m .33565 .61945 L .33419 .61774 L F
.33314 .61867 m .33348 .61838 L .33432 .61878 L F
.33314 .61867 m .33496 .61924 L .33348 .61838 L F
.566 0 0 r
.33432 .61878 m .33385 .61859 L .33348 .61838 L F
.235 .578 .943 r
.33496 .61924 m .33565 .61945 L .33348 .61838 L F
.566 0 0 r
.33348 .61838 m .33059 .6173 L .32971 .61658 L F
.33385 .61859 m .33059 .6173 L .33348 .61838 L F
.592 .143 .154 r
.33446 .62115 m .33314 .61867 L .33238 .62152 L F
.33446 .62115 m .33565 .61945 L .33314 .61867 L F
.828 .902 .891 r
.46098 .44539 m .46061 .44846 L .45903 .44702 L F
.46098 .44539 m .46359 .44566 L .46061 .44846 L F
.844 .867 .859 r
.4934 .42912 m .48913 .43073 L .49209 .42803 L F
.715 .9 .962 r
.49571 .42792 m .4934 .42912 L .49209 .42803 L F
.514 .83 .519 r
.27523 .62466 m .2768 .62314 L .27372 .6262 L F
.563 .695 .929 r
.36102 .70091 m .36199 .6993 L .35912 .69678 L F
.36102 .70091 m .36357 .70027 L .36199 .6993 L F
.078 0 0 r
.65593 .37893 m .65665 .37778 L .65391 .37884 L F
.565 .937 .837 r
.67761 .37928 m .67892 .37796 L .67698 .37952 L F
.678 .917 .593 r
.45785 .56958 m .45978 .56789 L .45722 .57099 L F
0 0 0 r
.22426 .55182 m .223 .55367 L .22542 .55063 L F
.848 .392 .103 r
.39441 .67111 m .39541 .67068 L .3937 .66989 L F
.39441 .67111 m .39683 .67329 L .39541 .67068 L F
.871 .937 .861 r
.51863 .41151 m .51602 .41222 L .51873 .40918 L F
.191 .175 .609 r
.2243 .60007 m .22605 .59896 L .22551 .59556 L F
.2 .192 .625 r
.2243 .60007 m .22624 .60256 L .22605 .59896 L F
.994 .755 .4 r
.44473 .53417 m .44469 .53725 L .44584 .53541 L F
.58 .19 .267 r
.30164 .57276 m .30199 .5711 L .30429 .57294 L F
0 0 0 r
.64025 .34791 m .64342 .34513 L .64228 .34753 L F
.64228 .34753 m .64342 .34513 L .64545 .34364 L F
.392 .37 .715 r
.70296 .29871 m .70194 .29709 L .7037 .29657 L F
.174 .079 .499 r
.70499 .29399 m .70296 .29871 L .7037 .29657 L F
.89 .944 .583 r
.32866 .60819 m .32807 .61105 L .32933 .60943 L F
.32866 .60819 m .32681 .61212 L .32807 .61105 L F
.674 .479 .614 r
.61544 .38984 m .61913 .39066 L .61875 .38709 L F
.327 .404 .789 r
.61875 .38709 m .62174 .38911 L .62143 .38643 L F
0 0 .448 r
.61875 .38709 m .62054 .38825 L .62143 .38643 L F
.61875 .38709 m .61913 .39066 L .62054 .38825 L F
.859 .827 .815 r
.50489 .42193 m .5007 .42393 L .50384 .42113 L F
.782 .926 .931 r
.50686 .41851 m .50489 .42193 L .50384 .42113 L F
.50686 .41851 m .50821 .41955 L .50489 .42193 L F
.745 .806 .901 r
.57711 .46057 m .5817 .45995 L .57849 .45643 L F
.595 .756 .955 r
.57849 .45643 m .5817 .45995 L .58267 .45723 L F
.365 0 0 r
.25377 .55691 m .25606 .55693 L .25826 .55479 L F
.541 .352 .573 r
.26058 .55411 m .25797 .55742 L .25826 .55479 L F
0 0 0 r
.25826 .55479 m .2586 .55583 L .26058 .55411 L F
.25826 .55479 m .25606 .55693 L .2586 .55583 L F
.693 .407 .484 r
.28102 .51436 m .28517 .51219 L .28305 .51347 L F
.499 .392 .664 r
.48062 .54494 m .47895 .54856 L .47777 .54448 L F
.48062 .54494 m .48124 .54782 L .47895 .54856 L F
.48 .34 .613 r
.48124 .54782 m .48164 .55053 L .47895 .54856 L F
.397 .351 .69 r
.47895 .54856 m .48164 .55053 L .47976 .55151 L F
.595 .868 .537 r
.24917 .52456 m .24871 .52535 L .25062 .52575 L F
.24917 .52456 m .24673 .52733 L .24871 .52535 L F
.863 .771 .759 r
.4337 .45744 m .42991 .45441 L .43262 .45327 L F
.4337 .45744 m .43138 .45721 L .42991 .45441 L F
.727 .81 .916 r
.43652 .45353 m .4337 .45744 L .43262 .45327 L F
.506 .222 .417 r
.5244 .47993 m .52132 .48216 L .52188 .48032 L F
.983 .696 .363 r
.57068 .44836 m .57146 .44803 L .57033 .44453 L F
.549 .383 .608 r
.57146 .44803 m .57352 .44491 L .57033 .44453 L F
.57146 .44803 m .57404 .4475 L .57352 .44491 L F
.503 .834 .999 r
.57323 .44644 m .57146 .44803 L .57068 .44836 L F
.57323 .44644 m .57404 .4475 L .57146 .44803 L F
.854 .497 0 r
.60343 .40881 m .60489 .4121 L .60391 .41121 L F
.885 .46 .172 r
.60489 .4121 m .60402 .41386 L .60391 .41121 L F
.60489 .4121 m .60597 .41453 L .60402 .41386 L F
.758 .983 .744 r
.68883 .37278 m .69205 .37019 L .69117 .37133 L F
.027 0 .12 r
.69205 .37019 m .69468 .36699 L .69472 .36903 L F
0 0 0 r
.31085 .55134 m .31315 .54754 L .31069 .54849 L F
0 .087 .609 r
.32004 .6294 m .32239 .63049 L .32192 .62737 L F
.32004 .6294 m .32135 .63172 L .32239 .63049 L F
.659 .706 .882 r
.24713 .61169 m .25017 .61059 L .24534 .60894 L F
.586 .575 .808 r
.33969 .52825 m .34284 .52665 L .33944 .52821 L F
.33969 .52825 m .34293 .53093 L .34284 .52665 L F
0 0 0 r
.65978 .39022 m .66303 .38721 L .66231 .38918 L F
0 0 .117 r
.66231 .38918 m .66303 .38721 L .66479 .38571 L F
.755 .695 .794 r
.48516 .51858 m .48684 .52256 L .48269 .52194 L F
.535 .206 .358 r
.48684 .52256 m .48315 .52519 L .48269 .52194 L F
.48684 .52256 m .48653 .52493 L .48315 .52519 L F
.322 .233 .597 r
.48848 .51791 m .48684 .52256 L .48516 .51858 L F
.48848 .51791 m .48867 .52179 L .48684 .52256 L F
.346 .291 .652 r
.48867 .52179 m .48923 .52455 L .48684 .52256 L F
.589 .253 .369 r
.48923 .52455 m .48653 .52493 L .48684 .52256 L F
.705 .392 .444 r
.38954 .48845 m .38337 .48898 L .38367 .48651 L F
.38954 .48845 m .38886 .48933 L .38337 .48898 L F
.905 .833 .765 r
.45424 .56565 m .45398 .56289 L .45507 .56441 L F
0 .401 .848 r
.45398 .56289 m .45536 .56318 L .45507 .56441 L F
.15 .266 .729 r
.45536 .56318 m .45424 .56565 L .45507 .56441 L F
.694 .807 .348 r
.34481 .60502 m .34413 .60669 L .34597 .60262 L F
.147 0 .109 r
.34504 .60789 m .34413 .60669 L .34481 .60502 L F
.34504 .60789 m .34266 .60886 L .34413 .60669 L F
.004 .228 .738 r
.26751 .55196 m .26795 .54962 L .26549 .55026 L F
.291 0 0 r
.27052 .55161 m .26928 .5526 L .26751 .55196 L F
.004 .228 .738 r
.26751 .55196 m .26928 .5526 L .26795 .54962 L F
.573 .92 .961 r
.58465 .4598 m .58603 .45757 L .58267 .45723 L F
.58465 .4598 m .58679 .45865 L .58603 .45757 L F
.593 .912 .978 r
.73813 .31531 m .73425 .31611 L .73677 .31226 L F
.27 0 0 r
.73813 .31531 m .73714 .31636 L .73425 .31611 L F
.6 .546 .766 r
.73677 .31226 m .74233 .31447 L .73813 .31531 L F
0 .484 .699 r
.73763 .31643 m .73714 .31636 L .73813 .31531 L F
0 0 .253 r
.27855 .64305 m .2779 .64528 L .27764 .64325 L F
0 0 .202 r
.2779 .64528 m .27836 .64643 L .27764 .64325 L F
.2779 .64528 m .2784 .64779 L .27836 .64643 L F
.2784 .64779 m .27851 .64838 L .27836 .64643 L F
.282 .662 .97 r
.27833 .64516 m .27836 .64643 L .27917 .6454 L F
.862 .482 .324 r
.27577 .64365 m .27764 .64325 L .27836 .64643 L F
.27485 .64266 m .27836 .64643 L .27658 .64468 L F
.282 .662 .97 r
.27658 .64468 m .27836 .64643 L .27833 .64516 L F
.862 .482 .324 r
.27485 .64266 m .27764 .64325 L .27577 .64365 L F
0 0 .253 r
.27903 .64137 m .27855 .64305 L .27764 .64325 L F
.294 .739 .962 r
.67718 .33733 m .67873 .33832 L .6748 .33768 L F
.607 .077 0 r
.6748 .33768 m .67873 .33832 L .6776 .33944 L F
.457 .769 .997 r
.68011 .3363 m .67873 .33832 L .67718 .33733 L F
.68011 .3363 m .68151 .33807 L .67873 .33832 L F
.088 0 0 r
.67873 .33832 m .68031 .33868 L .6776 .33944 L F
.67873 .33832 m .68151 .33807 L .68031 .33868 L F
.628 .47 .649 r
.4959 .50295 m .49603 .50586 L .49311 .50619 L F
.535 .337 .559 r
.49603 .50586 m .49328 .50937 L .49311 .50619 L F
.615 .507 .708 r
.42876 .55127 m .43224 .55432 L .43218 .55148 L F
.285 .21 .594 r
.43224 .55432 m .43398 .55007 L .43218 .55148 L F
.655 .299 .358 r
.30032 .56673 m .30281 .567 L .30065 .56464 L F
.561 .303 .482 r
.30065 .56464 m .30281 .567 L .30322 .56428 L F
.429 .035 .188 r
.39127 .47352 m .3931 .4734 L .39467 .47077 L F
.611 .227 .29 r
.39467 .47077 m .39706 .47273 L .3971 .47006 L F
.39467 .47077 m .3931 .4734 L .39706 .47273 L F
.677 .622 .787 r
.55758 .44766 m .56109 .44795 L .55849 .44901 L F
.313 .065 .369 r
.42945 .46136 m .429 .46352 L .42688 .46428 L F
.305 0 .244 r
.42861 .4656 m .42688 .46428 L .429 .46352 L F
.42861 .4656 m .42619 .46657 L .42688 .46428 L F
.76 .604 .684 r
.391 .66733 m .39275 .66825 L .39356 .66456 L F
.528 .267 .463 r
.23608 .57994 m .23846 .57731 L .23614 .57743 L F
.867 .988 .718 r
.39348 .48814 m .39332 .48987 L .39394 .4885 L F
.202 .473 .889 r
.39348 .48814 m .39472 .49047 L .39332 .48987 L F
.237 0 .204 r
.55592 .47205 m .55631 .4709 L .55861 .46991 L F
.42 .125 .355 r
.63707 .35099 m .64025 .34791 L .64027 .34991 L F
.63707 .35099 m .64027 .34991 L .64008 .35009 L F
.711 .473 .563 r
.63707 .35099 m .63688 .3536 L .63399 .35319 L F
.084 0 .397 r
.63888 .35164 m .63707 .35099 L .64024 .35004 L F
0 0 0 r
.64037 .34991 m .64228 .34753 L .64196 .34842 L F
.856 .925 .873 r
.64142 .34865 m .64027 .35 L .64196 .34842 L F
.64027 .35 m .63888 .35164 L .64196 .34842 L F
0 0 0 r
.64027 .35003 m .64037 .34991 L .64196 .34842 L F
.084 0 .397 r
.63888 .35164 m .64024 .35004 L .64027 .35003 L F
.42 .125 .355 r
.64008 .35009 m .64027 .34991 L .64027 .35001 L F
.64024 .35004 m .64027 .35001 L .64027 .35003 L F
.64008 .35009 m .64027 .35001 L .64024 .35004 L F
0 0 0 r
.64057 .34966 m .64025 .34791 L .64228 .34753 L F
.64027 .35003 m .64027 .34997 L .64057 .34966 L F
.64027 .34997 m .64025 .34791 L .64057 .34966 L F
.155 0 .217 r
.64196 .34842 m .64228 .34753 L .64482 .34533 L F
.815 .813 .848 r
.64474 .34535 m .64196 .34842 L .64482 .34533 L F
0 0 0 r
.64228 .34753 m .64545 .34364 L .64482 .34533 L F
.815 .813 .848 r
.64044 .34668 m .64187 .34832 L .64474 .34535 L F
.64187 .34832 m .64196 .34842 L .64474 .34535 L F
.856 .925 .873 r
.63789 .35019 m .63872 .35141 L .64142 .34865 L F
.63872 .35141 m .63888 .35164 L .64024 .35004 L F
.63872 .35141 m .64024 .35004 L .64142 .34865 L F
.084 0 .397 r
.63888 .35164 m .63688 .3536 L .63707 .35099 L F
.443 .487 .81 r
.63727 .35493 m .63399 .35319 L .63688 .3536 L F
.897 .866 .8 r
.63523 .35357 m .63799 .35211 L .63789 .35019 L F
.63799 .35211 m .63888 .35164 L .63872 .35141 L F
.63799 .35211 m .63872 .35141 L .63789 .35019 L F
.449 .373 .678 r
.36868 .5305 m .3663 .52813 L .37038 .52871 L F
.624 .254 .321 r
.37038 .52871 m .37287 .5309 L .36868 .5305 L F
.866 .916 .862 r
.36913 .63583 m .37104 .63644 L .37231 .63471 L F
.579 .475 .699 r
.40411 .48595 m .40147 .48701 L .40084 .4842 L F
.487 .191 .389 r
.50628 .49501 m .50389 .49415 L .50719 .49276 L F
.50628 .49501 m .50364 .49579 L .50389 .49415 L F
.956 .913 .731 r
.38795 .61186 m .39081 .60926 L .38983 .60882 L F
.38795 .61186 m .38905 .61309 L .39081 .60926 L F
.82 .926 .544 r
.39081 .60926 m .3924 .60542 L .38983 .60882 L F
.524 .045 .06 r
.42549 .59972 m .42891 .59888 L .42764 .59834 L F
.718 .823 .93 r
.42891 .59888 m .43071 .59571 L .42764 .59834 L F
.42891 .59888 m .43262 .59726 L .43071 .59571 L F
.533 .34 .565 r
.53105 .41052 m .53548 .41108 L .53272 .41245 L F
.368 0 .179 r
.33966 .53418 m .34215 .5337 L .34293 .53093 L F
.27 .22 .616 r
.34293 .53093 m .34489 .52764 L .34284 .52665 L F
.34293 .53093 m .34551 .5308 L .34489 .52764 L F
.483 .207 .418 r
.34215 .5337 m .34551 .5308 L .34293 .53093 L F
.762 .684 .776 r
.41409 .47345 m .41798 .47325 L .41618 .47076 L F
.41409 .47345 m .41615 .47467 L .41798 .47325 L F
.76 .805 .889 r
.41618 .47076 m .41798 .47325 L .42123 .4706 L F
.25 0 0 r
.26053 .52345 m .26241 .52399 L .26142 .52374 L F
.338 0 0 r
.25917 .523 m .26053 .52345 L .25757 .52345 L F
.079 .621 .848 r
.26053 .52345 m .25819 .52292 L .25656 .52283 L F
.25 0 0 r
.26053 .52345 m .26142 .52374 L .25819 .52292 L F
.338 0 0 r
.26169 .52228 m .26053 .52345 L .25917 .523 L F
.529 .034 .025 r
.2643 .52231 m .26053 .52345 L .26169 .52228 L F
0 0 0 r
.35018 .61519 m .34919 .61614 L .35183 .61221 L F
.35561 .61245 m .35411 .61259 L .3562 .61166 L F
.071 .596 .872 r
.35183 .61221 m .35411 .61259 L .35561 .61245 L F
.35183 .61221 m .35561 .61245 L .35018 .61519 L F
.608 .952 .903 r
.55719 .39118 m .55783 .38904 L .55792 .38975 L F
.55719 .39118 m .55624 .39014 L .55783 .38904 L F
.659 .568 .741 r
.34603 .62494 m .34347 .62858 L .34439 .62636 L F
.847 .995 .836 r
.61666 .43405 m .61458 .43458 L .61215 .43091 L F
.483 .883 .953 r
.61569 .43465 m .6179 .43404 L .61719 .4335 L F
.61529 .43495 m .61609 .43467 L .61569 .43465 L F
.61609 .43467 m .6179 .43404 L .61569 .43465 L F
.847 .995 .836 r
.61458 .43458 m .61416 .43469 L .61409 .43455 L F
.61458 .43458 m .61409 .43455 L .61215 .43091 L F
.61666 .43405 m .61529 .43495 L .61416 .43469 L F
0 .462 .803 r
.59293 .46 m .5945 .46084 L .5973 .46159 L F
.618 .15 .121 r
.28778 .65102 m .2892 .64942 L .29021 .6512 L F
.86 .726 .713 r
.27756 .65069 m .28162 .65058 L .27912 .65463 L F
.776 .356 .25 r
.71142 .30675 m .71617 .3077 L .71506 .30718 L F
.419 .656 .958 r
.71828 .30701 m .71617 .3077 L .71506 .30718 L F
.835 .782 .279 r
.68096 .35855 m .68081 .36134 L .68026 .36263 L F
.291 .787 .773 r
.6024 .3497 m .605 .34887 L .60668 .3487 L F
.37 .835 .789 r
.60668 .3487 m .60753 .34784 L .60843 .34782 L F
.60668 .3487 m .605 .34887 L .60753 .34784 L F
.156 0 .367 r
.31229 .66419 m .31466 .66061 L .31466 .6633 L F
0 0 0 r
.31056 .66622 m .31229 .66419 L .31466 .6633 L F
.735 .62 .731 r
.57033 .44453 m .57352 .44491 L .57393 .44158 L F
.774 .704 .164 r
.57393 .44158 m .57352 .44491 L .57356 .44376 L F
.906 .601 .109 r
.57352 .44491 m .57323 .44644 L .57356 .44376 L F
.57352 .44491 m .57404 .4475 L .57323 .44644 L F
.474 .19 .402 r
.28605 .53418 m .28884 .53051 L .28726 .53303 L F
.57 .278 .433 r
.53116 .47688 m .53385 .47884 L .52975 .47953 L F
.53116 .47688 m .53367 .47672 L .53385 .47884 L F
.885 .98 .825 r
.245 .52332 m .24257 .52621 L .24237 .52405 L F
.279 0 0 r
.245 .52332 m .24909 .52394 L .24668 .52162 L F
.245 .52332 m .24237 .52405 L .24909 .52394 L F
.754 .692 .792 r
.34998 .6867 m .35145 .68789 L .34732 .68724 L F
.285 0 .175 r
.35208 .68792 m .3537 .6867 L .35145 .68789 L F
.35208 .68792 m .35145 .68789 L .34998 .6867 L F
.437 .202 .458 r
.49859 .49992 m .49835 .50237 L .4959 .50295 L F
.514 .294 .518 r
.50103 .49922 m .49835 .50237 L .49859 .49992 L F
0 0 .326 r
.40813 .55196 m .40909 .55418 L .40759 .55047 L F
.888 .836 .788 r
.6363 .41161 m .63606 .40838 L .63566 .41083 L F
.906 .959 .628 r
.63484 .41231 m .6363 .41161 L .63566 .41083 L F
.63484 .41231 m .6344 .41526 L .6363 .41161 L F
0 0 .418 r
.24139 .52737 m .24237 .52405 L .24257 .52621 L F
.998 .836 .498 r
.60597 .41453 m .60639 .41823 L .6051 .41763 L F
.939 .568 .216 r
.60639 .41823 m .60597 .42037 L .6051 .41763 L F
.60639 .41823 m .60746 .42119 L .60597 .42037 L F
.522 .401 .656 r
.49835 .50237 m .49603 .50586 L .4959 .50295 L F
.409 .806 .985 r
.3484 .65095 m .35191 .65062 L .35199 .65006 L F
.152 .687 .846 r
.35303 .65007 m .35437 .65035 L .35309 .65007 L F
0 0 0 r
.35102 .65039 m .34999 .65056 L .35199 .65006 L F
.34774 .65151 m .3484 .65095 L .34999 .65056 L F
.34846 .65127 m .34999 .65056 L .35102 .65039 L F
.34774 .65151 m .34809 .65136 L .34846 .65127 L F
.34809 .65136 m .34999 .65056 L .34846 .65127 L F
.34774 .65151 m .35131 .65029 L .34981 .65027 L F
.313 0 0 r
.35199 .65006 m .35437 .65035 L .34981 .65027 L F
.152 .687 .846 r
.3516 .6503 m .35437 .65035 L .35303 .65007 L F
.34986 .6509 m .35309 .65007 L .34998 .65252 L F
.34981 .65027 m .3516 .6503 L .35303 .65007 L F
.34981 .65027 m .35303 .65007 L .34986 .6509 L F
.35303 .65007 m .35309 .65007 L .34986 .6509 L F
.884 .512 .333 r
.23238 .6064 m .23053 .60791 L .23018 .60584 L F
.984 .742 .488 r
.23238 .6064 m .23217 .60912 L .23053 .60791 L F
.21 .265 .701 r
.23397 .60447 m .23238 .6064 L .23174 .603 L F
.439 .241 .513 r
.23461 .60663 m .23238 .6064 L .23397 .60447 L F
.23461 .60663 m .23217 .60912 L .23238 .6064 L F
.754 .983 .745 r
.69844 .27835 m .69736 .28037 L .69545 .2814 L F
.478 .574 .873 r
.72355 .30799 m .72357 .31198 L .72206 .30859 L F
.72355 .30799 m .72604 .31169 L .72357 .31198 L F
.647 .423 .565 r
.34919 .61614 m .34886 .61885 L .34461 .61978 L F
.122 0 .398 r
.35092 .61644 m .34919 .61614 L .35018 .61519 L F
.35092 .61644 m .34886 .61885 L .34919 .61614 L F
.973 .68 .406 r
.38626 .5376 m .38826 .54142 L .38834 .53947 L F
.754 .76 .857 r
.33465 .53532 m .33045 .53488 L .33282 .5333 L F
.493 .639 .92 r
.33554 .53317 m .33465 .53532 L .33282 .5333 L F
.33554 .53317 m .33728 .53516 L .33465 .53532 L F
.63 .61 .811 r
.36989 .69963 m .37135 .70332 L .37372 .70212 L F
.573 .344 .53 r
.31117 .56746 m .30833 .57005 L .30832 .56766 L F
.424 .853 .943 r
.60843 .34782 m .61289 .34789 L .61006 .34803 L F
.60843 .34782 m .61113 .34708 L .61289 .34789 L F
.436 .868 .921 r
.61113 .34708 m .61589 .347 L .61289 .34789 L F
.708 .646 .785 r
.33869 .60266 m .3411 .59855 L .33819 .59889 L F
.132 0 .018 r
.33894 .6007 m .33819 .59889 L .3411 .59855 L F
.33894 .6007 m .33674 .60154 L .33819 .59889 L F
.194 .348 .791 r
.32175 .63798 m .32034 .63857 L .31839 .63529 L F
.075 .03 .497 r
.32258 .63976 m .32034 .63857 L .32175 .63798 L F
.102 .012 .457 r
.32258 .63976 m .32048 .64161 L .32034 .63857 L F
.763 .986 .902 r
.65641 .3924 m .65978 .39022 L .65803 .39 L F
.491 .897 .925 r
.65803 .39 m .65978 .39022 L .66231 .38918 L F
.649 .883 .983 r
.58679 .45865 m .58994 .45873 L .58904 .4598 L F
.506 0 0 r
.58994 .45873 m .59293 .46 L .58904 .4598 L F
.645 .092 0 r
.32708 .63867 m .32463 .63966 L .32518 .6376 L F
.32509 .63947 m .32608 .63916 L .32495 .63953 L F
.32708 .63867 m .32608 .63916 L .32509 .63947 L F
.834 .518 .454 r
.32698 .63949 m .32608 .63916 L .32694 .63887 L F
.32698 .63949 m .32688 .63921 L .32608 .63916 L F
.037 .222 .725 r
.32694 .64129 m .32881 .64158 L .3294 .6409 L F
.714 .213 .043 r
.33127 .64313 m .3294 .6409 L .32881 .64158 L F
.704 .168 0 r
.32608 .63916 m .3294 .6409 L .33127 .64313 L F
.037 .222 .725 r
.32694 .64129 m .32856 .64516 L .32881 .64158 L F
.834 .677 .689 r
.32608 .63916 m .32881 .64158 L .32416 .64318 L F
.704 .168 0 r
.32608 .63916 m .33127 .64313 L .32881 .64158 L F
0 0 .445 r
.32608 .63916 m .32727 .64094 L .32705 .63922 L F
.834 .518 .454 r
.32689 .63889 m .32608 .63916 L .32678 .63811 L F
0 0 .445 r
.32608 .63916 m .32688 .63921 L .32678 .63811 L F
.834 .518 .454 r
.32688 .63921 m .32652 .63631 L .3257 .63603 L F
.32698 .63949 m .32678 .63811 L .32688 .63921 L F
.32678 .63811 m .32652 .63631 L .32688 .63921 L F
.32698 .63949 m .32974 .63739 L .32652 .63631 L F
.32694 .63887 m .32689 .63889 L .32689 .63795 L F
.32689 .63889 m .32678 .63811 L .32689 .63795 L F
0 0 .445 r
.32678 .63811 m .32692 .6387 L .32689 .63795 L F
.84 .63 .085 r
.32695 .6394 m .32698 .63949 L .32689 .63795 L F
0 0 .445 r
.32688 .63921 m .32703 .63922 L .32678 .63811 L F
.562 .578 .827 r
.32732 .63849 m .32698 .63949 L .32695 .6394 L F
0 0 .445 r
.32703 .63922 m .32705 .63922 L .32704 .63918 L F
.32703 .63922 m .32704 .63918 L .32678 .63811 L F
.304 .359 .754 r
.33022 .63104 m .32922 .63203 L .32741 .6292 L F
.503 .479 .763 r
.33035 .63494 m .32922 .63203 L .33022 .63104 L F
.927 .853 .749 r
.3267 .63349 m .33035 .63494 L .33022 .63104 L F
.926 .556 .291 r
.32974 .63739 m .3267 .63349 L .3257 .63603 L F
.562 .578 .827 r
.32888 .63399 m .32732 .63849 L .32642 .63728 L F
.834 .518 .454 r
.32688 .63921 m .32677 .63893 L .32608 .63916 L F
.891 .594 .086 r
.32689 .63795 m .3265 .63987 L .32642 .63728 L F
.84 .63 .085 r
.32642 .63728 m .32695 .6394 L .32689 .63795 L F
0 0 .445 r
.32692 .6387 m .32705 .63922 L .32689 .63795 L F
.891 .594 .086 r
.32674 .63869 m .32727 .64094 L .3265 .63987 L F
.32689 .63795 m .32704 .63917 L .32674 .63869 L F
.562 .578 .827 r
.32704 .63917 m .32695 .6394 L .3268 .63878 L F
.891 .594 .086 r
.32704 .63917 m .32727 .64094 L .32674 .63869 L F
.562 .578 .827 r
.32732 .63849 m .32704 .63917 L .32642 .63728 L F
.32704 .63917 m .3268 .63878 L .32642 .63728 L F
.834 .518 .454 r
.32677 .63893 m .3257 .63603 L .32608 .63916 L F
.645 .092 0 r
.32495 .63953 m .32608 .63916 L .32463 .63966 L F
.978 .727 .319 r
.39498 .55739 m .39491 .55995 L .39594 .56085 L F
.967 .642 .315 r
.39487 .56269 m .39594 .56085 L .39491 .55995 L F
.39487 .56269 m .39636 .5637 L .39594 .56085 L F
.436 .868 .921 r
.61113 .34708 m .61363 .34625 L .61589 .347 L F
.439 .588 .904 r
.6194 .34457 m .61589 .347 L .61363 .34625 L F
.6194 .34457 m .61951 .34624 L .61589 .347 L F
.356 .778 .975 r
.61589 .347 m .61909 .34663 L .61635 .34708 L F
.61589 .347 m .61951 .34624 L .61909 .34663 L F
.72 .811 .921 r
.25062 .52575 m .25539 .5259 L .2533 .5245 L F
.752 .857 .928 r
.2533 .5245 m .25539 .5259 L .25757 .52345 L F
.443 0 0 r
.33951 .6274 m .34239 .62793 L .34347 .62858 L F
.41 .455 .796 r
.31458 .63494 m .31363 .63707 L .31234 .63517 L F
.31458 .63494 m .31527 .63737 L .31363 .63707 L F
.993 .742 .416 r
.39636 .5637 m .39628 .56631 L .3976 .56719 L F
.991 .858 .506 r
.39596 .56912 m .3976 .56719 L .39628 .56631 L F
.39596 .56912 m .39708 .57025 L .3976 .56719 L F
.347 0 0 r
.33337 .65128 m .33616 .65143 L .33276 .65169 L F
.906 .787 .719 r
.34755 .51901 m .34366 .52133 L .34545 .51767 L F
.34755 .51901 m .34519 .52526 L .34366 .52133 L F
.426 .156 .399 r
.38271 .58642 m .3856 .58376 L .38556 .58648 L F
.266 .665 .968 r
.38271 .58642 m .38556 .58648 L .3856 .58376 L F
.655 .336 .42 r
.38556 .58648 m .38738 .58554 L .3856 .58376 L F
.3856 .58376 m .38738 .58554 L .38556 .58648 L F
.973 .708 .47 r
.39316 .55064 m .3931 .55387 L .39485 .5548 L F
.977 .681 .383 r
.39336 .55631 m .39485 .5548 L .3931 .55387 L F
.39336 .55631 m .39498 .55739 L .39485 .5548 L F
.662 .934 .969 r
.25004 .58443 m .25359 .58335 L .25327 .58355 L F
.449 .806 .997 r
.25418 .57861 m .25542 .5796 L .25358 .58024 L F
.979 .89 .667 r
.25359 .57985 m .25542 .5796 L .25418 .57861 L F
0 0 .136 r
.25396 .57977 m .25393 .57981 L .25542 .5796 L F
.25393 .57981 m .25358 .58024 L .25542 .5796 L F
.25393 .57981 m .25359 .58335 L .25358 .58024 L F
.979 .89 .667 r
.25392 .58039 m .25542 .5796 L .25393 .57981 L F
0 0 .136 r
.25396 .57977 m .25392 .58016 L .25393 .57981 L F
.25392 .58016 m .25359 .58335 L .25393 .57981 L F
.802 .853 .889 r
.25101 .58212 m .25327 .58355 L .25384 .58047 L F
.979 .89 .667 r
.25382 .58043 m .25392 .58039 L .25367 .57999 L F
.25392 .58039 m .25393 .57981 L .25359 .57985 L F
.934 .968 .736 r
.25396 .57977 m .25542 .5796 L .25382 .58043 L F
.802 .853 .889 r
.25368 .58 m .25382 .58043 L .25396 .57977 L F
.57 .685 .918 r
.25358 .58024 m .24854 .57775 L .25075 .57721 L F
.449 .806 .997 r
.25418 .57861 m .25358 .58024 L .25075 .57721 L F
.802 .853 .889 r
.25101 .58212 m .25384 .58047 L .25368 .58 L F
.979 .89 .667 r
.25316 .58078 m .25382 .58043 L .25359 .57985 L F
.934 .968 .736 r
.25396 .57977 m .25382 .58043 L .25316 .58078 L F
.802 .853 .889 r
.25382 .58043 m .25384 .58047 L .25396 .57977 L F
.25101 .58212 m .25368 .58 L .25316 .58078 L F
.25368 .58 m .25396 .57977 L .25316 .58078 L F
.979 .89 .667 r
.25366 .58002 m .25367 .57999 L .25359 .57985 L F
.25382 .58043 m .25368 .58 L .25366 .58002 L F
.25368 .58 m .25367 .57999 L .25366 .58002 L F
.843 .837 .367 r
.25327 .58355 m .25359 .58335 L .25396 .57977 L F
.821 .689 .718 r
.63013 .35388 m .6313 .35731 L .62727 .35675 L F
.825 .574 .559 r
.62715 .35708 m .6313 .35731 L .62904 .35995 L F
.553 .279 .455 r
.62498 .35781 m .62721 .35681 L .62501 .35708 L F
.62493 .35909 m .62683 .35719 L .62498 .35781 L F
.62683 .35719 m .62721 .35681 L .62498 .35781 L F
.825 .574 .559 r
.6269 .35669 m .62727 .35675 L .62715 .35708 L F
.62727 .35675 m .6313 .35731 L .62715 .35708 L F
.62715 .35708 m .62904 .35995 L .6284 .35666 L F
.553 .279 .455 r
.62691 .35774 m .6284 .35666 L .62725 .3568 L F
.825 .574 .559 r
.6269 .35669 m .62715 .35708 L .6284 .35666 L F
.553 .279 .455 r
.62493 .35918 m .62691 .35774 L .62721 .35681 L F
.62691 .35774 m .62725 .3568 L .62721 .35681 L F
.62493 .35918 m .62721 .35681 L .62493 .35909 L F
.821 .689 .718 r
.62958 .35228 m .63013 .35388 L .6269 .35669 L F
.63013 .35388 m .62727 .35675 L .6269 .35669 L F
.646 .596 .785 r
.63399 .35319 m .6313 .35731 L .62958 .35228 L F
.683 .485 .613 r
.29681 .65153 m .30122 .64818 L .30192 .64757 L F
1 .82 .514 r
.6139 .39794 m .61453 .40229 L .61496 .39957 L F
.934 .616 .163 r
.54625 .42805 m .54772 .43191 L .54674 .4309 L F
.54625 .42805 m .54772 .43191 L .54674 .4309 L F
.399 .838 .712 r
.64612 .33077 m .64825 .32947 L .64951 .32843 L F
.64612 .33077 m .64599 .3307 L .64825 .32947 L F
0 0 0 r
.32288 .60308 m .32367 .6022 L .32518 .60046 L F
.32306 .60553 m .32367 .6022 L .32288 .60308 L F
.932 .68 .534 r
.31318 .60641 m .31091 .60859 L .31295 .60908 L F
.681 .367 .437 r
.63386 .35116 m .63399 .35319 L .62958 .35228 L F
.711 .473 .563 r
.63707 .35099 m .63399 .35319 L .63386 .35116 L F
.207 .226 .66 r
.22653 .5724 m .22578 .57667 L .22491 .5748 L F
.625 .48 .664 r
.48516 .51858 m .48134 .51536 L .4851 .51577 L F
.48516 .51858 m .48243 .51913 L .48134 .51536 L F
0 0 .429 r
.57452 .37293 m .57602 .37698 L .57581 .3757 L F
.648 .245 0 r
.57602 .37698 m .57593 .37701 L .57581 .3757 L F
.57602 .37698 m .57716 .37905 L .57593 .37701 L F
.357 .831 .819 r
.27248 .63585 m .27399 .63493 L .27127 .63399 L F
.27248 .63585 m .27491 .63501 L .27399 .63493 L F
.433 .153 .387 r
.51535 .48644 m .5124 .48931 L .51257 .48678 L F
.702 .732 .874 r
.432 .54704 m .42741 .54593 L .43024 .54438 L F
.452 0 0 r
.43398 .55007 m .432 .54704 L .43391 .54741 L F
.97 .717 .495 r
.60032 .43111 m .60091 .43551 L .60172 .435 L F
.932 .693 .553 r
.59714 .43272 m .60091 .43551 L .60032 .43111 L F
.986 .742 .479 r
.59994 .43588 m .60172 .435 L .60091 .43551 L F
.59994 .43588 m .60144 .43779 L .60172 .435 L F
.442 .829 .986 r
.68473 .3374 m .68535 .3382 L .68151 .33807 L F
.68473 .3374 m .68535 .3382 L .68151 .33807 L F
.795 .99 .885 r
.68638 .33589 m .68535 .3382 L .68473 .3374 L F
.68473 .3374 m .68535 .3382 L .68638 .33589 L F
.536 .925 .844 r
.67486 .32333 m .67844 .32189 L .67697 .32241 L F
.491 .824 .999 r
.67844 .32189 m .68016 .32032 L .67697 .32241 L F
.67844 .32189 m .68125 .32136 L .68016 .32032 L F
.819 .779 .816 r
.37708 .69233 m .37897 .69345 L .37749 .69064 L F
.856 .76 .756 r
.37666 .69671 m .37897 .69345 L .37708 .69233 L F
.824 .781 .812 r
.37749 .69064 m .37897 .69345 L .38146 .68995 L F
.495 .28 .517 r
.44823 .53174 m .45107 .53147 L .45102 .52861 L F
0 0 0 r
.42562 .53937 m .42445 .54081 L .42289 .54141 L F
.383 0 0 r
.42855 .53999 m .42445 .54081 L .42562 .53937 L F
.258 0 .212 r
.28772 .571 m .28975 .57031 L .29124 .56722 L F
.562 .236 .374 r
.29124 .56722 m .29399 .56903 L .29389 .56719 L F
.29124 .56722 m .28975 .57031 L .29399 .56903 L F
0 .202 .717 r
.36684 .6816 m .36922 .68319 L .3695 .68028 L F
.449 .373 .678 r
.36868 .5305 m .367 .53302 L .3663 .52813 L F
.874 .976 .674 r
.69047 .34758 m .68828 .35115 L .68815 .35008 L F
.885 .914 .513 r
.68815 .35008 m .68828 .35115 L .68711 .35233 L F
.667 .841 .967 r
.44306 .45273 m .44462 .45414 L .44061 .45385 L F
.7 .862 .959 r
.4455 .45147 m .44462 .45414 L .44306 .45273 L F
.4455 .45147 m .44711 .45282 L .44462 .45414 L F
0 .177 .708 r
.72782 .32664 m .7304 .3301 L .73096 .33036 L F
.594 .536 .759 r
.43208 .46048 m .42945 .46136 L .42876 .45818 L F
.601 .32 .463 r
.43208 .46238 m .42945 .46136 L .43208 .46048 L F
.43208 .46238 m .429 .46352 L .42945 .46136 L F
0 0 0 r
.69637 .36504 m .69468 .36699 L .6968 .3635 L F
0 0 .091 r
.69472 .36903 m .69468 .36699 L .69637 .36504 L F
0 0 0 r
.46776 .59022 m .46798 .5908 L .466 .5916 L F
.46776 .59022 m .47019 .58945 L .46798 .5908 L F
.792 .999 .844 r
.6254 .41798 m .62557 .41896 L .6281 .41652 L F
.842 .403 .182 r
.62433 .42025 m .62557 .41896 L .6254 .41798 L F
.62433 .42025 m .62628 .42125 L .62557 .41896 L F
.688 .597 .749 r
.62557 .41896 m .63001 .41972 L .6281 .41652 L F
.827 .392 .203 r
.62557 .41896 m .62971 .4223 L .63001 .41972 L F
.62557 .41896 m .62628 .42125 L .62971 .4223 L F
0 0 0 r
.62721 .36648 m .62811 .36486 L .62929 .36339 L F
.835 .896 .883 r
.42613 .49873 m .43085 .49698 L .42968 .49661 L F
.675 .899 .551 r
.43201 .4951 m .43085 .49698 L .43336 .49371 L F
.702 .965 .939 r
.43201 .4951 m .42968 .49661 L .43085 .49698 L F
.472 .282 .541 r
.40267 .4959 m .40548 .49789 L .40705 .49672 L F
.988 .873 .525 r
.40705 .49672 m .40548 .49789 L .40701 .49455 L F
.552 .757 .973 r
.71377 .28319 m .71548 .28088 L .71254 .28148 L F
.71377 .28319 m .71548 .28088 L .71254 .28148 L F
.661 .778 .936 r
.34728 .59653 m .34541 .59806 L .34446 .59692 L F
.413 .237 .53 r
.34841 .59993 m .34541 .59806 L .34728 .59653 L F
.267 .454 .859 r
.32881 .64158 m .32856 .64516 L .33072 .64542 L F
.762 .802 .885 r
.32796 .64828 m .33072 .64542 L .32856 .64516 L F
.611 .57 .783 r
.4417 .48577 m .44501 .48713 L .44383 .48511 L F
.499 .862 .624 r
.52169 .40838 m .52267 .40739 L .52482 .40591 L F
.365 .818 .937 r
.52169 .40838 m .52074 .40787 L .52267 .40739 L F
.511 .823 1 r
.45918 .5568 m .45747 .5577 L .46068 .55788 L F
.931 .958 .771 r
.73677 .31226 m .7331 .31486 L .73426 .31151 L F
.73677 .31226 m .73425 .31611 L .7331 .31486 L F
.603 .853 .991 r
.73828 .30978 m .74034 .31068 L .73677 .31226 L F
.69 .958 .948 r
.73828 .30978 m .73677 .31226 L .73426 .31151 L F
.564 .567 .815 r
.74034 .31068 m .74233 .31447 L .73677 .31226 L F
.629 .422 .583 r
.60889 .36053 m .61344 .36132 L .61381 .35785 L F
.701 .586 .724 r
.60945 .36358 m .61344 .36132 L .60889 .36053 L F
.934 .577 .317 r
.60827 .42553 m .60671 .42662 L .60684 .42425 L F
.60827 .42553 m .60917 .42876 L .60671 .42662 L F
.849 .664 .652 r
.54785 .43704 m .55167 .4351 L .55029 .43375 L F
.54785 .43704 m .55127 .43796 L .55167 .4351 L F
0 0 .148 r
.55167 .4351 m .55248 .43543 L .55029 .43375 L F
.55167 .4351 m .55127 .43796 L .55248 .43543 L F
.582 .331 .502 r
.37977 .5899 m .38281 .59005 L .38271 .58642 L F
.754 .647 .743 r
.38281 .59005 m .38556 .58648 L .38271 .58642 L F
.263 .739 .937 r
.44548 .52169 m .44085 .52106 L .4432 .52177 L F
.493 .868 .98 r
.34065 .52689 m .33944 .52821 L .34284 .52665 L F
.991 .87 .612 r
.3882 .6155 m .38905 .61309 L .38795 .61186 L F
.874 .976 .674 r
.69047 .34758 m .68815 .35008 L .68908 .34782 L F
.842 .978 .874 r
.69292 .3435 m .69047 .34758 L .69119 .34495 L F
.69292 .3435 m .69356 .34468 L .69047 .34758 L F
.874 .99 .737 r
.69119 .34495 m .69047 .34758 L .68908 .34782 L F
0 0 .342 r
.33449 .63759 m .33391 .63864 L .33464 .63526 L F
0 0 .175 r
.33365 .64119 m .33391 .63864 L .33449 .63759 L F
.813 .532 .514 r
.28567 .63542 m .28106 .63186 L .28304 .63554 L F
.693 .534 .668 r
.28269 .63663 m .28567 .63542 L .28304 .63554 L F
.272 .293 .7 r
.22019 .58328 m .22064 .58716 L .22248 .5854 L F
.514 .351 .598 r
.22064 .58716 m .22364 .58927 L .22248 .5854 L F
.22064 .58716 m .22122 .58991 L .22364 .58927 L F
.735 .477 .538 r
.33694 .51563 m .33326 .51776 L .33516 .51733 L F
.306 0 0 r
.33694 .51563 m .33791 .51691 L .33764 .51415 L F
.33694 .51563 m .33516 .51733 L .33791 .51691 L F
.854 .971 .87 r
.6748 .33768 m .67292 .34004 L .67116 .33943 L F
0 0 0 r
.67274 .34035 m .67292 .34004 L .6748 .33768 L F
.391 0 0 r
.28755 .64306 m .29086 .64368 L .28711 .64225 L F
.28755 .64306 m .28711 .64225 L .28662 .63967 L F
.675 .791 .326 r
.45978 .56789 m .46063 .56584 L .46157 .56396 L F
0 0 .044 r
.46022 .56822 m .45978 .56789 L .45785 .56958 L F
.46022 .56822 m .46063 .56584 L .45978 .56789 L F
0 0 .418 r
.24139 .52737 m .24271 .52671 L .24237 .52405 L F
0 0 0 r
.24139 .52737 m .23934 .52936 L .24271 .52671 L F
.368 .799 .967 r
.33419 .61774 m .33059 .6173 L .33432 .61878 L F
.566 .39 .602 r
.34549 .55466 m .34822 .55447 L .34808 .55134 L F
.34549 .55466 m .34822 .55447 L .34808 .55134 L F
.22 .149 .56 r
.62476 .42066 m .62628 .42125 L .62433 .42025 L F
.881 .798 .311 r
.62628 .42125 m .62621 .42397 L .62938 .42246 L F
.62622 .42353 m .62587 .42422 L .62621 .42397 L F
.62628 .42125 m .62587 .42422 L .62622 .42353 L F
.22 .149 .56 r
.62722 .42302 m .62587 .42422 L .62628 .42125 L F
.62689 .4227 m .62628 .42125 L .62476 .42066 L F
.62722 .42302 m .62697 .42255 L .62689 .4227 L F
.62697 .42255 m .62628 .42125 L .62689 .4227 L F
0 0 0 r
.62686 .42276 m .62514 .42563 L .62587 .42422 L F
.22 .149 .56 r
.62722 .42302 m .62433 .42025 L .62756 .42174 L F
0 0 0 r
.62756 .42174 m .62587 .42422 L .62722 .42302 L F
.62756 .42174 m .62653 .42339 L .62686 .42276 L F
.62653 .42339 m .62514 .42563 L .62686 .42276 L F
.62514 .42563 m .62502 .42583 L .62587 .42422 L F
.881 .798 .311 r
.62628 .42125 m .62938 .42246 L .62971 .4223 L F
.707 .585 .717 r
.63001 .41972 m .62971 .4223 L .63188 .41867 L F
.643 .895 .984 r
.59725 .3674 m .5947 .36866 L .59232 .36793 L F
.371 .815 .95 r
.59853 .36821 m .5947 .36866 L .59725 .3674 L F
0 0 .26 r
.46332 .55462 m .46483 .55036 L .46171 .5483 L F
.46332 .55462 m .46459 .55253 L .46483 .55036 L F
.118 .202 .676 r
.46332 .55462 m .46558 .55689 L .46459 .55253 L F
.339 .236 .589 r
.46347 .55683 m .46558 .55689 L .46332 .55462 L F
.582 .407 .609 r
.50364 .49579 m .50103 .49922 L .50105 .49643 L F
.994 .749 .406 r
.32924 .49544 m .33038 .49921 L .32903 .49852 L F
.508 .039 .075 r
.33038 .49921 m .32864 .50105 L .32903 .49852 L F
.33038 .49921 m .33113 .50115 L .32864 .50105 L F
.33038 .49921 m .33245 .49969 L .33113 .50115 L F
.861 .879 .442 r
.42849 .55694 m .42743 .56086 L .43012 .55808 L F
.42849 .55694 m .42705 .56067 L .42743 .56086 L F
.738 .709 .174 r
.42712 .56169 m .42743 .56086 L .42705 .56067 L F
.42712 .56169 m .42689 .56351 L .42743 .56086 L F
0 0 0 r
.30632 .56364 m .30834 .56294 L .30994 .56137 L F
.30994 .56137 m .31011 .56167 L .31242 .56078 L F
.30994 .56137 m .30834 .56294 L .31011 .56167 L F
.716 .279 .21 r
.3809 .68867 m .38209 .68748 L .37903 .68685 L F
.987 .896 .582 r
.3809 .68867 m .38146 .68995 L .38209 .68748 L F
.3809 .68867 m .38146 .68995 L .38209 .68748 L F
.202 .018 .394 r
.43634 .47986 m .4363 .48266 L .43394 .48326 L F
.273 0 .1 r
.4363 .48266 m .43271 .48489 L .43394 .48326 L F
.576 .444 .664 r
.48098 .52879 m .48145 .53159 L .47867 .5321 L F
.565 .403 .62 r
.47867 .5321 m .48145 .53159 L .47887 .53504 L F
.536 .22 .38 r
.43817 .45976 m .43527 .46063 L .43478 .4586 L F
.776 .794 .867 r
.55543 .4408 m .55255 .44381 L .55179 .44036 L F
.825 .844 .862 r
.63606 .40838 m .63851 .40847 L .63717 .40729 L F
.806 .96 .911 r
.63851 .40847 m .64142 .40446 L .63717 .40729 L F
.63851 .40847 m .64238 .40541 L .64142 .40446 L F
.847 .415 .202 r
.37014 .5148 m .3741 .51841 L .37314 .51615 L F
.906 .864 .787 r
.41572 .46342 m .41568 .46767 L .41389 .46631 L F
.729 .72 .842 r
.41462 .47044 m .41389 .46631 L .41568 .46767 L F
.741 .737 .848 r
.42009 .46435 m .41568 .46767 L .41572 .46342 L F
.576 .841 .489 r
.58171 .42051 m .57997 .42269 L .5811 .42134 L F
.58171 .42051 m .57911 .42368 L .57997 .42269 L F
.481 .332 .601 r
.57895 .42387 m .5811 .42134 L .57997 .42269 L F
.837 .956 .89 r
.57033 .44453 m .57393 .44158 L .57139 .4406 L F
.57033 .44453 m .57139 .4406 L .57129 .4407 L F
.564 .899 .981 r
.57151 .44058 m .57393 .44158 L .57555 .44055 L F
.707 .616 .754 r
.5728 .43927 m .5709 .44107 L .57041 .43916 L F
.564 .899 .981 r
.57132 .44058 m .57139 .4406 L .57151 .44058 L F
.57139 .4406 m .57393 .44158 L .57151 .44058 L F
.707 .616 .754 r
.57434 .43935 m .57134 .44065 L .5728 .43927 L F
.564 .899 .981 r
.57132 .44058 m .57151 .44058 L .57434 .43935 L F
.57151 .44058 m .57555 .44055 L .57434 .43935 L F
.837 .956 .89 r
.57033 .44453 m .57129 .4407 L .57126 .44248 L F
.707 .616 .754 r
.57129 .44087 m .57129 .4407 L .57134 .44065 L F
.57222 .44041 m .57126 .44248 L .5709 .44107 L F
.837 .956 .89 r
.57129 .4407 m .57132 .44058 L .57126 .44248 L F
.707 .616 .754 r
.57434 .43935 m .57129 .44087 L .57134 .44065 L F
.57129 .44087 m .5709 .44107 L .57129 .4407 L F
.57434 .43935 m .57362 .44008 L .57222 .44041 L F
.57362 .44008 m .57126 .44248 L .57222 .44041 L F
.837 .956 .89 r
.57129 .4407 m .57139 .4406 L .57132 .44058 L F
.774 .704 .164 r
.57393 .44158 m .57356 .44376 L .57555 .44055 L F
.967 .924 .598 r
.4209 .5006 m .41999 .50138 L .42076 .49919 L F
.332 0 0 r
.42409 .50069 m .41999 .50138 L .4209 .5006 L F
.944 .953 .646 r
.33593 .54184 m .33416 .54299 L .33531 .54112 L F
.33531 .54112 m .33593 .54184 L .33795 .54156 L F
.33531 .54112 m .33416 .54299 L .33593 .54184 L F
.758 .312 .191 r
.28662 .63967 m .28269 .63663 L .28163 .64093 L F
.872 .564 .046 r
.38187 .53007 m .3824 .52984 L .38121 .52828 L F
.38187 .53007 m .38277 .53214 L .3824 .52984 L F
.621 .959 .848 r
.4258 .49075 m .4237 .49127 L .42244 .49295 L F
.133 .288 .757 r
.23608 .57994 m .23753 .58364 L .23846 .58233 L F
.226 .421 .845 r
.23753 .58364 m .24006 .58465 L .23846 .58233 L F
.588 .582 .814 r
.23753 .58364 m .24143 .58593 L .24006 .58465 L F
.909 .873 .79 r
.31464 .65497 m .3145 .65821 L .3122 .65759 L F
.427 .466 .798 r
.31653 .65722 m .3145 .65821 L .31464 .65497 L F
.69 .65 .805 r
.31653 .65722 m .31466 .66061 L .3145 .65821 L F
.702 .912 .968 r
.60194 .46015 m .60116 .45932 L .60116 .46107 L F
.905 .943 .583 r
.60116 .46107 m .60116 .45932 L .5997 .46225 L F
0 0 .53 r
.43222 .53711 m .43265 .53887 L .43078 .53457 L F
.419 .293 .602 r
.33994 .68375 m .34241 .68658 L .34259 .68293 L F
.33994 .68375 m .34017 .68734 L .34241 .68658 L F
.857 .517 .001 r
.59486 .41916 m .59316 .41491 L .59316 .41776 L F
.874 .44 .051 r
.5958 .42138 m .59486 .41916 L .59316 .41776 L F
.621 .564 .769 r
.37067 .53264 m .36727 .53467 L .367 .53302 L F
.595 .51 .728 r
.32135 .63172 m .3213 .63512 L .31839 .63529 L F
.194 .348 .791 r
.32174 .63791 m .3214 .63765 L .3213 .63512 L F
.3214 .63765 m .31839 .63529 L .32048 .63517 L F
.3214 .63765 m .32048 .63517 L .3213 .63512 L F
.32169 .63793 m .32165 .6379 L .32174 .63791 L F
.32165 .6379 m .31839 .63529 L .32167 .63786 L F
.32165 .6379 m .32167 .63786 L .32174 .63791 L F
.735 .725 .842 r
.31986 .6375 m .32142 .63808 L .3212 .63765 L F
.31986 .6375 m .3212 .63765 L .31907 .6336 L F
.31706 .63645 m .31986 .6375 L .31907 .6336 L F
.32142 .63808 m .32162 .63815 L .32154 .63802 L F
.723 .216 .022 r
.31902 .63902 m .32162 .63815 L .31706 .63645 L F
.981 .91 .647 r
.32034 .63663 m .32157 .6381 L .31902 .63902 L F
.32157 .6381 m .32162 .63815 L .32154 .63818 L F
.32157 .6381 m .32154 .63818 L .31902 .63902 L F
.735 .725 .842 r
.32142 .63808 m .32154 .63802 L .31907 .6336 L F
.831 .447 0 r
.31907 .6336 m .32154 .63802 L .32034 .63663 L F
.32154 .63802 m .32162 .63815 L .32157 .6381 L F
.32154 .63802 m .32157 .6381 L .32034 .63663 L F
.194 .348 .791 r
.32175 .63798 m .32169 .63793 L .32174 .63791 L F
.549 .919 .759 r
.63799 .33617 m .63882 .33501 L .64056 .33474 L F
.63799 .33617 m .63664 .33657 L .63882 .33501 L F
.602 .648 .868 r
.62125 .37166 m .6197 .3769 L .61872 .37608 L F
.62125 .37166 m .62246 .3762 L .6197 .3769 L F
.633 .298 .386 r
.6197 .3769 m .61962 .3787 L .61872 .37608 L F
.6197 .3769 m .62238 .37922 L .61962 .3787 L F
.523 .326 .554 r
.62246 .3762 m .62238 .37922 L .6197 .3769 L F
.796 .609 .649 r
.61381 .35785 m .61409 .35354 L .61174 .35498 L F
.598 .395 .577 r
.61381 .35785 m .61344 .36132 L .61575 .35968 L F
.766 .986 .746 r
.29713 .65345 m .29677 .65499 L .29449 .65622 L F
.799 .98 .703 r
.27826 .62118 m .2768 .62314 L .27632 .62197 L F
.833 .959 .624 r
.27632 .62197 m .2768 .62314 L .27523 .62466 L F
.907 .86 .417 r
.46694 .54784 m .46641 .54748 L .46743 .54439 L F
.682 .484 .612 r
.391 .66733 m .38912 .6667 L .38937 .66678 L F
.584 .932 .755 r
.66693 .37369 m .66322 .37624 L .66577 .37481 L F
.62 .883 .555 r
.66851 .37162 m .66915 .37114 L .66693 .37369 L F
.635 .903 .593 r
.66851 .37162 m .66693 .37369 L .66577 .37481 L F
.91 .906 .503 r
.24773 .59281 m .2476 .59228 L .2478 .59204 L F
.494 .234 .45 r
.25032 .59567 m .25055 .59556 L .25026 .5956 L F
.25032 .59567 m .24782 .59591 L .24773 .59281 L F
.25032 .59567 m .25026 .5956 L .24782 .59591 L F
.285 0 .12 r
.24944 .59688 m .24782 .59591 L .25026 .5956 L F
.642 .952 .943 r
.25039 .59562 m .25055 .59556 L .25032 .59567 L F
.25253 .59397 m .25055 .59556 L .25039 .59562 L F
.285 0 .12 r
.25041 .59572 m .25032 .59565 L .25055 .59556 L F
.25039 .59562 m .25026 .5956 L .25055 .59556 L F
.867 .912 .858 r
.25039 .59562 m .25032 .59085 L .25253 .59397 L F
.25032 .59567 m .25032 .59563 L .25039 .59562 L F
.25032 .59563 m .25032 .59085 L .25039 .59562 L F
.285 0 .12 r
.25032 .59565 m .25031 .59564 L .25039 .59562 L F
.25031 .59564 m .25026 .5956 L .25035 .59562 L F
.494 .234 .45 r
.25026 .5956 m .24773 .59281 L .24774 .59263 L F
.25032 .59567 m .25024 .59558 L .25026 .5956 L F
.25024 .59558 m .24773 .59281 L .25026 .5956 L F
.25032 .59567 m .24774 .59263 L .2478 .59204 L F
.62 .834 .982 r
.2476 .59228 m .24389 .59345 L .24087 .59226 L F
.2476 .59228 m .24087 .59226 L .24346 .58896 L F
0 .028 .6 r
.24613 .58844 m .2476 .59228 L .24346 .58896 L F
.889 .499 .284 r
.24571 .59106 m .24985 .59519 L .2478 .59204 L F
.24985 .59519 m .25032 .59567 L .2478 .59204 L F
0 .028 .6 r
.24708 .59094 m .2478 .59204 L .2476 .59228 L F
.24613 .58844 m .2478 .59204 L .24708 .59094 L F
.889 .499 .284 r
.24571 .59106 m .24715 .59511 L .25032 .59567 L F
.867 .912 .858 r
.25032 .59563 m .24715 .59511 L .25032 .59085 L F
.25032 .59567 m .25027 .59566 L .25032 .59563 L F
.25027 .59566 m .24715 .59511 L .25032 .59563 L F
.285 0 .12 r
.25032 .59563 m .25035 .59562 L .25039 .59562 L F
.25031 .59564 m .25035 .59562 L .25032 .59563 L F
.24944 .59688 m .25026 .5956 L .25041 .59572 L F
.792 .974 .91 r
.26476 .6248 m .26775 .62296 L .26936 .62297 L F
.757 .241 0 r
.26856 .62385 m .26936 .62297 L .26775 .62296 L F
.26856 .62385 m .27134 .62525 L .26936 .62297 L F
.779 .601 .659 r
.38597 .65393 m .38783 .65776 L .38884 .65523 L F
.978 .701 .31 r
.72098 .30674 m .72206 .30859 L .72199 .3058 L F
.706 .481 .58 r
.371 .5991 m .37087 .60166 L .36962 .59991 L F
.653 .404 .531 r
.36918 .59608 m .36972 .5998 L .36471 .59946 L F
.706 .481 .58 r
.36994 .59957 m .36962 .59991 L .36951 .59976 L F
.371 .5991 m .36962 .59991 L .36972 .5998 L F
.672 .418 .528 r
.371 .5991 m .36976 .60007 L .36972 .5998 L F
.371 .5991 m .36972 .5998 L .36918 .59608 L F
.706 .481 .58 r
.371 .5991 m .36972 .5998 L .36994 .59957 L F
.653 .404 .531 r
.36972 .5998 m .36976 .60007 L .3695 .60004 L F
.36972 .5998 m .3695 .60004 L .36471 .59946 L F
.672 .418 .528 r
.371 .5991 m .36918 .59608 L .37116 .59638 L F
.81 .616 .64 r
.44869 .50078 m .45198 .5029 L .45028 .49995 L F
.499 .013 .035 r
.44835 .50399 m .45198 .5029 L .44869 .50078 L F
.44835 .50399 m .45025 .50467 L .45198 .5029 L F
.899 .494 .085 r
.45028 .49995 m .45198 .5029 L .45076 .50192 L F
.514 .264 .474 r
.45025 .50467 m .45007 .50136 L .45198 .5029 L F
.45124 .50347 m .45423 .50461 L .45311 .50121 L F
.45025 .50467 m .4516 .50465 L .45124 .50347 L F
.4516 .50465 m .45423 .50461 L .45124 .50347 L F
.899 .494 .085 r
.45024 .50022 m .45076 .50192 L .45007 .50136 L F
.45028 .49995 m .45076 .50192 L .45024 .50022 L F
.233 .029 .385 r
.47976 .55151 m .48164 .55053 L .47949 .55375 L F
.463 .408 .711 r
.3498 .59521 m .34841 .59993 L .34728 .59653 L F
.3498 .59521 m .35088 .59911 L .34841 .59993 L F
.35 .194 .524 r
.35088 .59911 m .34863 .60264 L .34841 .59993 L F
.178 .7 .876 r
.25554 .61733 m .25554 .61784 L .25337 .61713 L F
.25554 .61733 m .25752 .61771 L .25554 .61784 L F
.596 .949 .835 r
.29313 .6627 m .29351 .66312 L .29419 .66192 L F
.667 .17 .057 r
.2913 .66287 m .29374 .66337 L .29351 .66312 L F
.596 .949 .835 r
.29246 .66319 m .29351 .66312 L .29313 .6627 L F
.667 .17 .057 r
.29374 .66337 m .29566 .66377 L .29351 .66312 L F
0 .413 .701 r
.29351 .66312 m .29566 .66377 L .29644 .66398 L F
.7 .172 0 r
.29566 .66377 m .29954 .66729 L .29741 .66683 L F
.179 .161 .599 r
.29566 .66377 m .29741 .66683 L .29644 .66398 L F
.095 .476 .894 r
.26715 .57567 m .26936 .57808 L .26666 .5766 L F
0 .043 .61 r
.26666 .5766 m .26862 .57944 L .26715 .57567 L F
.648 .581 .766 r
.48184 .53599 m .4801 .5396 L .47887 .53504 L F
0 .12 .66 r
.55457 .42656 m .55285 .42535 L .55596 .42503 L F
.986 .833 .605 r
.43959 .56191 m .43804 .56223 L .4384 .56023 L F
.43959 .56191 m .43854 .56398 L .43804 .56223 L F
.856 .896 .864 r
.4384 .56023 m .43959 .56191 L .44341 .55757 L F
.777 .8 .872 r
.43959 .56191 m .44486 .55722 L .44341 .55757 L F
.687 .147 0 r
.4384 .56023 m .44314 .56308 L .43959 .56191 L F
.529 .034 .025 r
.2643 .52231 m .26241 .52399 L .26053 .52345 L F
.478 .82 .532 r
.26403 .52253 m .2643 .52231 L .26689 .52226 L F
.26403 .52253 m .26241 .52399 L .2643 .52231 L F
.742 .963 .938 r
.25643 .51674 m .25207 .51812 L .25413 .51693 L F
.341 0 0 r
.25413 .51693 m .25852 .5167 L .25643 .51674 L F
.476 .867 .971 r
.42281 .49667 m .426 .49627 L .42417 .49612 L F
0 .214 .739 r
.57606 .38733 m .57471 .38757 L .57322 .38596 L F
.57606 .38733 m .57711 .38942 L .57471 .38757 L F
.54 .833 .502 r
.6177 .36991 m .62066 .36671 L .61963 .36856 L F
0 0 0 r
.61675 .37115 m .6177 .36991 L .61963 .36856 L F
.76 .73 .824 r
.63001 .41972 m .63015 .41688 L .6281 .41652 L F
.63001 .41972 m .63188 .41867 L .63015 .41688 L F
.439 0 0 r
.42983 .5135 m .42962 .5139 L .42677 .51233 L F
.43091 .51391 m .42962 .5139 L .42983 .5135 L F
.746 .555 .637 r
.42773 .51583 m .42946 .51418 L .42962 .5139 L F
.982 .735 .485 r
.43177 .51621 m .43112 .52041 L .42962 .5139 L F
.746 .555 .637 r
.42946 .51418 m .43104 .51268 L .42962 .5139 L F
0 0 0 r
.42804 .51079 m .42677 .51233 L .42962 .5139 L F
.42804 .51079 m .42599 .51477 L .42677 .51233 L F
.951 .702 .525 r
.39123 .54955 m .39303 .54798 L .39151 .547 L F
.39123 .54955 m .39316 .55064 L .39303 .54798 L F
.975 .684 .404 r
.60471 .45051 m .60465 .448 L .60301 .44689 L F
.485 0 0 r
.23035 .58672 m .23204 .58769 L .23492 .58627 L F
0 0 .563 r
.23544 .58618 m .23717 .58914 L .23492 .58627 L F
.23544 .58618 m .23492 .58627 L .23204 .58769 L F
.936 .565 .184 r
.43091 .51391 m .43177 .51621 L .42962 .5139 L F
0 0 0 r
.32977 .6523 m .33276 .65169 L .32984 .65275 L F
.888 .46 .129 r
.37812 .52421 m .38121 .52828 L .3796 .5254 L F
.619 .473 .662 r
.34808 .55134 m .35186 .55125 L .35049 .5481 L F
.453 .304 .587 r
.34955 .55262 m .34822 .55447 L .35075 .55364 L F
.34808 .55134 m .34818 .55367 L .34955 .55262 L F
.34818 .55367 m .34822 .55447 L .34955 .55262 L F
.292 .3 .697 r
.35297 .55012 m .35186 .55125 L .35049 .5481 L F
.882 .843 .802 r
.35297 .55012 m .35245 .55039 L .35186 .55125 L F
0 0 .198 r
.3487 .55229 m .34808 .55134 L .35186 .55125 L F
.882 .843 .802 r
.35245 .55039 m .3487 .55229 L .35093 .55155 L F
.35245 .55039 m .35093 .55155 L .35186 .55125 L F
0 0 .198 r
.3487 .55229 m .34822 .55447 L .34808 .55134 L F
.778 .695 .772 r
.42563 .59034 m .42789 .59359 L .42518 .59257 L F
.072 .352 .824 r
.42844 .59213 m .42789 .59359 L .42573 .59048 L F
.031 .3 .792 r
.42844 .59213 m .43071 .59571 L .42789 .59359 L F
.158 .38 .83 r
.43148 .59392 m .43071 .59571 L .42844 .59213 L F
.598 .057 0 r
.4277 .59331 m .43134 .59389 L .42844 .59213 L F
.43134 .59389 m .43148 .59392 L .42844 .59213 L F
.072 .352 .824 r
.42844 .59213 m .42573 .59048 L .42563 .59034 L F
.529 .018 0 r
.61575 .35968 m .61793 .36021 L .61909 .3594 L F
.657 .484 .638 r
.61909 .3594 m .62263 .36017 L .62209 .3574 L F
.475 0 0 r
.6209 .3611 m .61909 .3594 L .61793 .36021 L F
.6209 .3611 m .62263 .36017 L .61909 .3594 L F
.73 .99 .856 r
.65265 .32594 m .64951 .32843 L .65088 .32617 L F
.685 .913 .578 r
.64951 .32843 m .64825 .32947 L .65088 .32617 L F
.763 .281 .093 r
.391 .66733 m .3937 .66989 L .39275 .66825 L F
.576 .31 .476 r
.36471 .59946 m .36165 .60243 L .36227 .60037 L F
.716 .984 .797 r
.72768 .32047 m .73119 .31821 L .7303 .31717 L F
.79 .952 .924 r
.7303 .31717 m .73119 .31821 L .73425 .31611 L F
.805 .732 .783 r
.63015 .41688 m .63188 .41867 L .6344 .41526 L F
.716 .193 0 r
.24072 .61384 m .2412 .61305 L .23882 .61341 L F
.24072 .61384 m .24264 .61495 L .2412 .61305 L F
.446 .343 .644 r
.62209 .3574 m .62493 .35918 L .62501 .35708 L F
.62209 .3574 m .62263 .36017 L .62493 .35918 L F
.62209 .3574 m .62493 .35918 L .62501 .35708 L F
.62209 .3574 m .62263 .36017 L .62493 .35918 L F
.752 .988 .775 r
.56931 .4445 m .57033 .44453 L .57126 .44248 L F
.56931 .4445 m .57126 .44248 L .57132 .44259 L F
.818 .56 .549 r
.56676 .44691 m .57033 .44453 L .56931 .4445 L F
.56628 .44723 m .57068 .44836 L .57033 .44453 L F
.752 .988 .775 r
.56931 .4445 m .57132 .44259 L .57323 .44644 L F
.818 .56 .549 r
.56628 .44723 m .56676 .44691 L .56931 .4445 L F
.771 .872 .922 r
.47238 .44177 m .46784 .44272 L .47097 .44066 L F
.84 .911 .885 r
.47523 .43873 m .47238 .44177 L .47097 .44066 L F
.171 .496 .906 r
.44725 .50215 m .4454 .50291 L .44393 .50342 L F
.527 .327 .553 r
.4454 .50291 m .44835 .50399 L .44869 .50078 L F
.171 .496 .906 r
.44725 .50215 m .44835 .50399 L .4454 .50291 L F
.783 .307 .103 r
.29172 .52635 m .29024 .52716 L .29279 .52769 L F
.837 .998 .78 r
.34408 .54821 m .34413 .54621 L .34668 .54498 L F
.34668 .54498 m .34413 .54621 L .34408 .54821 L F
.864 .97 .653 r
.34408 .54821 m .34223 .54971 L .34413 .54621 L F
0 0 .201 r
.67798 .30565 m .6795 .30364 L .67989 .30115 L F
.678 .969 .774 r
.67798 .30565 m .67621 .30635 L .6795 .30364 L F
.964 .937 .634 r
.69489 .34075 m .69356 .34468 L .69292 .3435 L F
.602 .874 .546 r
.23061 .53524 m .2316 .53391 L .23306 .53247 L F
0 0 .009 r
.23004 .53788 m .2316 .53391 L .23061 .53524 L F
.719 .676 .807 r
.46173 .53184 m .46524 .53212 L .46405 .52881 L F
.705 .467 .562 r
.46158 .53462 m .46524 .53212 L .46173 .53184 L F
.46158 .53462 m .46522 .53464 L .46524 .53212 L F
.634 .586 .782 r
.46524 .53212 m .46678 .52803 L .46405 .52881 L F
.46524 .53212 m .46784 .53169 L .46678 .52803 L F
.648 .455 .609 r
.46522 .53464 m .46784 .53169 L .46524 .53212 L F
.901 .589 .447 r
.26096 .61916 m .26177 .62184 L .26396 .62238 L F
.69 .316 .334 r
.26034 .6249 m .26396 .62238 L .26177 .62184 L F
.26034 .6249 m .26476 .6248 L .26396 .62238 L F
.255 0 0 r
.42132 .59895 m .42383 .59838 L .42459 .59663 L F
.967 .889 .512 r
.42473 .59568 m .42459 .59663 L .42543 .59622 L F
.157 0 0 r
.42306 .59644 m .42539 .59627 L .4255 .59628 L F
.754 .995 .843 r
.42654 .59828 m .42764 .59834 L .43071 .59571 L F
.42654 .59828 m .43071 .59571 L .42875 .59711 L F
.059 .588 .866 r
.42539 .59627 m .42825 .59698 L .42753 .59649 L F
.42825 .59698 m .42875 .59711 L .42753 .59649 L F
.881 .97 .842 r
.42753 .59649 m .43148 .59392 L .4277 .59331 L F
0 0 .08 r
.42801 .59442 m .42753 .59649 L .4277 .59331 L F
.804 .998 .851 r
.42651 .59577 m .42753 .59649 L .42801 .59442 L F
.157 0 0 r
.42574 .59647 m .4255 .59628 L .42753 .59649 L F
.489 .671 .944 r
.42383 .59838 m .42654 .59828 L .42539 .59627 L F
.637 .752 .931 r
.42539 .59627 m .42654 .59828 L .42875 .59711 L F
0 0 0 r
.42459 .59663 m .42383 .59838 L .42546 .5963 L F
.42543 .59622 m .42546 .5963 L .42557 .59615 L F
.42459 .59663 m .42546 .5963 L .42543 .59622 L F
.157 0 0 r
.42553 .59646 m .4255 .59628 L .42574 .59647 L F
.42543 .59628 m .42545 .59628 L .42546 .5963 L F
0 0 .15 r
.42557 .59615 m .42546 .5963 L .42539 .59627 L F
.42546 .5963 m .42383 .59838 L .42539 .59627 L F
.157 0 0 r
.42306 .59644 m .42543 .59628 L .42553 .59646 L F
.42543 .59628 m .42546 .5963 L .42553 .59646 L F
.42545 .59628 m .4255 .59628 L .42553 .59646 L F
.42306 .59644 m .42504 .59646 L .42531 .59685 L F
.42504 .59646 m .42753 .59649 L .42531 .59685 L F
.804 .998 .851 r
.42531 .59685 m .42753 .59649 L .42651 .59577 L F
0 0 0 r
.42787 .59617 m .42546 .59707 L .42531 .59685 L F
.42546 .59707 m .42421 .59754 L .42531 .59685 L F
.967 .889 .512 r
.42518 .59257 m .42473 .59568 L .42557 .59615 L F
.42473 .59568 m .42543 .59622 L .42557 .59615 L F
.61 .79 .968 r
.28977 .63972 m .29028 .63691 L .28787 .63741 L F
.28977 .63972 m .29234 .6389 L .29028 .63691 L F
.945 .611 .36 r
.41965 .51808 m .42008 .52048 L .42185 .5194 L F
.776 .973 .69 r
.42185 .5194 m .4224 .51739 L .42451 .51875 L F
.42185 .5194 m .42008 .52048 L .4224 .51739 L F
.883 .99 .745 r
.68011 .30199 m .68225 .2978 L .68363 .29942 L F
.915 .87 .779 r
.68534 .29533 m .68363 .29942 L .68225 .2978 L F
.954 .876 .719 r
.42699 .55013 m .42674 .55356 L .42876 .55127 L F
.808 .621 .65 r
.42674 .55356 m .42973 .5549 L .42876 .55127 L F
.615 .507 .708 r
.42876 .55127 m .42973 .5549 L .43224 .55432 L F
.814 .561 .556 r
.45484 .52463 m .45572 .52537 L .4563 .52244 L F
.555 .603 .856 r
.4563 .52244 m .45764 .51843 L .45482 .52086 L F
.4563 .52244 m .45875 .52157 L .45764 .51843 L F
.452 .293 .574 r
.4563 .52244 m .45868 .5243 L .45875 .52157 L F
.519 .277 .489 r
.4563 .52244 m .45572 .52537 L .45868 .5243 L F
.54 .575 .839 r
.32106 .53618 m .32247 .53341 L .3199 .53399 L F
.32106 .53618 m .32341 .5355 L .32247 .53341 L F
.145 0 0 r
.64767 .38559 m .64573 .38543 L .64368 .3858 L F
.866 .916 .862 r
.36913 .63583 m .37231 .63471 L .37144 .6345 L F
.787 .998 .849 r
.37231 .63471 m .37441 .6317 L .37144 .6345 L F
.37231 .63471 m .37548 .63188 L .37441 .6317 L F
.723 .989 .832 r
.65258 .39479 m .65641 .3924 L .65563 .39171 L F
.763 .986 .902 r
.65641 .3924 m .65803 .39 L .65563 .39171 L F
.874 .993 .757 r
.3639 .62898 m .365 .62888 L .36249 .63224 L F
.757 .241 0 r
.36689 .63126 m .365 .62888 L .3639 .62898 L F
.874 .993 .757 r
.3639 .62898 m .36249 .63224 L .36243 .63048 L F
.919 .88 .457 r
.36243 .63048 m .36249 .63224 L .36132 .63422 L F
.905 .863 .789 r
.61207 .39393 m .6136 .39725 L .61607 .39263 L F
0 0 0 r
.61423 .39441 m .61607 .39263 L .61859 .39162 L F
.61423 .39441 m .61825 .39183 L .61664 .39398 L F
.61825 .39183 m .61859 .39162 L .61664 .39398 L F
.636 .083 0 r
.61859 .39162 m .62008 .39368 L .61726 .39387 L F
.659 .453 .594 r
.62134 .39362 m .61726 .39387 L .62008 .39368 L F
.636 .083 0 r
.61859 .39162 m .62134 .39362 L .62008 .39368 L F
.383 .157 .443 r
.62417 .39043 m .62134 .39166 L .62174 .38911 L F
.603 .276 .389 r
.61859 .39162 m .62134 .39166 L .62134 .39362 L F
.34 .077 .361 r
.62134 .39362 m .62134 .39166 L .62417 .39043 L F
.605 .658 .875 r
.62134 .39362 m .62286 .39002 L .62033 .39366 L F
.659 .453 .594 r
.62134 .39362 m .62008 .39368 L .62046 .39366 L F
.62134 .39362 m .61858 .39657 L .61726 .39387 L F
.636 .083 0 r
.62008 .39368 m .62134 .39362 L .6202 .39385 L F
.605 .658 .875 r
.62134 .39362 m .62033 .39366 L .6202 .39385 L F
.659 .453 .594 r
.62134 .39362 m .62046 .39366 L .62081 .39363 L F
.636 .083 0 r
.62008 .39368 m .6202 .39385 L .61726 .39387 L F
.659 .453 .594 r
.62081 .39363 m .61726 .39387 L .62015 .39367 L F
.62074 .39364 m .62015 .39367 L .62071 .39364 L F
.62081 .39363 m .62015 .39367 L .62074 .39364 L F
.581 .077 .019 r
.6179 .39221 m .61913 .39066 L .61544 .38984 L F
.655 .854 .46 r
.62054 .38825 m .61916 .39062 L .6179 .39221 L F
0 0 0 r
.61859 .39162 m .62174 .38911 L .62134 .39166 L F
.855 .807 .802 r
.62054 .38825 m .6179 .39221 L .616 .3891 L F
.62054 .38825 m .616 .3891 L .61852 .3878 L F
.68 .572 .727 r
.61852 .3878 m .62015 .39367 L .62286 .39002 L F
.62015 .39367 m .6202 .39385 L .62033 .39366 L F
.62015 .39367 m .62033 .39366 L .62286 .39002 L F
.614 .532 .738 r
.61726 .39387 m .6202 .39385 L .62015 .39367 L F
0 0 0 r
.6167 .39391 m .61859 .39162 L .61726 .39387 L F
.655 .854 .46 r
.61916 .39062 m .61913 .39066 L .619 .39083 L F
.61916 .39062 m .619 .39083 L .6179 .39221 L F
.581 .077 .019 r
.6179 .39221 m .61544 .38984 L .61465 .39117 L F
.395 .598 .927 r
.61575 .38949 m .6179 .39221 L .61465 .39117 L F
.616 .3891 m .6164 .38976 L .61575 .38949 L F
.6164 .38976 m .6179 .39221 L .61575 .38949 L F
.614 .532 .738 r
.61726 .39387 m .62015 .39367 L .6194 .39095 L F
.61798 .39039 m .6194 .39095 L .61852 .3878 L F
.61726 .39387 m .6194 .39095 L .61798 .39039 L F
.659 .453 .594 r
.62071 .39364 m .61726 .39387 L .62063 .39364 L F
0 0 0 r
.61506 .39402 m .61979 .3937 L .61726 .39387 L F
.61979 .3937 m .62063 .39364 L .61726 .39387 L F
.61664 .39398 m .6167 .39391 L .61726 .39387 L F
.6968 .3635 m .69929 .35937 L .69827 .36111 L F
.69637 .36504 m .6968 .3635 L .69827 .36111 L F
.669 .587 .755 r
.44989 .49564 m .45028 .49995 L .45203 .49788 L F
.899 .494 .085 r
.45028 .49995 m .45007 .50136 L .45203 .49788 L F
.795 .915 .921 r
.46556 .44399 m .46359 .44566 L .46098 .44539 L F
.827 .964 .639 r
.29517 .51231 m .29709 .5083 L .29913 .50988 L F
.29517 .51231 m .29913 .50988 L .29672 .51091 L F
.891 .989 .777 r
.29918 .50753 m .29913 .50988 L .29979 .50768 L F
.29918 .50753 m .29672 .51091 L .29913 .50988 L F
.836 .624 .615 r
.37167 .68719 m .37099 .6899 L .36905 .68536 L F
.733 .271 0 r
.34139 .5021 m .34151 .50317 L .33891 .5021 L F
.34139 .5021 m .34302 .50487 L .34151 .50317 L F
0 0 .51 r
.34139 .5021 m .34464 .50621 L .34302 .50487 L F
0 0 .147 r
.47592 .57867 m .47528 .58293 L .47581 .58046 L F
.576 .891 .989 r
.45324 .47941 m .45166 .47814 L .45034 .48023 L F
.589 .379 .564 r
.45034 .48023 m .45296 .48214 L .45324 .47941 L F
.999 .823 .526 r
.45166 .47814 m .45296 .48214 L .45034 .48023 L F
.436 .238 .511 r
.54694 .39888 m .54956 .39855 L .54996 .39472 L F
.514 .362 .613 r
.5471 .40197 m .54956 .39855 L .54694 .39888 L F
.5471 .40197 m .54956 .39855 L .54694 .39888 L F
.594 .847 .992 r
.43906 .45269 m .43807 .45473 L .43652 .45353 L F
.43906 .45269 m .44061 .45385 L .43807 .45473 L F
.92 .673 .549 r
.24347 .5956 m .24087 .59226 L .24389 .59345 L F
0 0 0 r
.65854 .3778 m .65665 .37778 L .65593 .37893 L F
.65854 .3778 m .65732 .37849 L .65714 .37863 L F
.65732 .37849 m .65474 .37994 L .65714 .37863 L F
.65714 .37863 m .65331 .38072 L .65606 .37994 L F
.587 .832 .46 r
.65692 .37882 m .65714 .37863 L .65606 .37994 L F
0 0 0 r
.65854 .3778 m .65944 .37734 L .65665 .37778 L F
.65854 .3778 m .65593 .37893 L .65474 .37994 L F
.587 .832 .46 r
.65862 .37663 m .65714 .37863 L .65692 .37882 L F
.474 .854 .634 r
.65776 .37821 m .65854 .3778 L .65714 .37863 L F
.66069 .37619 m .65854 .3778 L .65776 .37821 L F
0 0 0 r
.65854 .3778 m .65959 .37731 L .65944 .37734 L F
.561 .135 .189 r
.32307 .56123 m .32526 .56294 L .32123 .56266 L F
.542 .148 .244 r
.32619 .56115 m .32526 .56294 L .32307 .56123 L F
.646 .803 .958 r
.28466 .51524 m .28705 .51729 L .28937 .51604 L F
.867 .717 .693 r
.43053 .50465 m .43456 .50303 L .43331 .50069 L F
.43053 .50465 m .43329 .50626 L .43456 .50303 L F
.567 .224 .346 r
.33525 .60342 m .33789 .60496 L .33869 .60266 L F
.268 .363 .776 r
.33674 .60154 m .33789 .60496 L .33525 .60342 L F
.382 0 0 r
.36073 .50728 m .36178 .50784 L .35972 .50645 L F
.36073 .50728 m .36255 .5083 L .36178 .50784 L F
.703 .422 0 r
.38029 .67052 m .38135 .67438 L .38123 .67399 L F
.518 0 0 r
.38135 .67438 m .38384 .67629 L .38226 .67556 L F
.38135 .67438 m .38226 .67556 L .38123 .67399 L F
.586 .206 .288 r
.38601 .67439 m .38384 .67629 L .38135 .67438 L F
.774 .996 .805 r
.65457 .3399 m .65113 .34246 L .65217 .34094 L F
0 0 0 r
.46157 .56396 m .46063 .56584 L .4635 .56292 L F
.754 .338 .262 r
.26795 .54962 m .27269 .55051 L .27024 .54778 L F
.403 .179 .456 r
.31979 .5308 m .32177 .53225 L .32233 .52836 L F
.537 .361 .591 r
.31979 .5308 m .32247 .53341 L .32177 .53225 L F
.31979 .5308 m .3199 .53399 L .32247 .53341 L F
.828 .373 .14 r
.36255 .5083 m .36426 .51123 L .3659 .51073 L F
.601 .049 0 r
.3659 .51073 m .36426 .51123 L .3664 .51137 L F
.926 .614 .43 r
.29021 .6512 m .2926 .6518 L .29128 .65506 L F
.173 0 .115 r
.29171 .65451 m .2926 .6518 L .2948 .65061 L F
.29128 .65506 m .2948 .65061 L .29298 .65274 L F
.86 .878 .85 r
.29527 .65237 m .29517 .65287 L .29298 .65274 L F
.29517 .65287 m .29449 .65622 L .2934 .65371 L F
.29517 .65287 m .2934 .65371 L .29298 .65274 L F
.173 0 .115 r
.29128 .65506 m .29145 .65464 L .29171 .65451 L F
.29145 .65464 m .2926 .6518 L .29171 .65451 L F
.667 .557 .721 r
.48269 .52194 m .48027 .52528 L .4799 .52243 L F
.621 .493 .686 r
.48269 .52194 m .48315 .52519 L .48027 .52528 L F
.516 .364 .614 r
.48315 .52519 m .48098 .52879 L .48027 .52528 L F
.853 .511 .405 r
.32439 .59158 m .32653 .58985 L .32603 .58993 L F
.715 .9 .962 r
.49571 .42792 m .49209 .42803 L .49416 .42654 L F
.767 .883 .929 r
.49945 .42519 m .49571 .42792 L .49416 .42654 L F
.573 .344 .53 r
.31117 .56746 m .31096 .57008 L .30833 .57005 L F
.507 .288 .517 r
.31117 .56746 m .31349 .5696 L .31096 .57008 L F
.531 .286 .489 r
.31381 .56704 m .31349 .5696 L .31117 .56746 L F
.704 .611 .75 r
.43336 .49371 m .43562 .49274 L .43568 .49013 L F
.281 .034 .35 r
.29823 .53884 m .2996 .54108 L .30006 .53848 L F
.539 0 0 r
.61818 .35404 m .61694 .35518 L .61409 .35354 L F
.292 0 0 r
.61818 .35404 m .61985 .35486 L .61694 .35518 L F
.61818 .35404 m .62083 .35463 L .61985 .35486 L F
.827 .395 0 r
.59926 .4009 m .60094 .40304 L .60179 .40497 L F
.786 .854 .405 r
.70253 .34863 m .70353 .34711 L .70299 .3463 L F
.70253 .34863 m .70191 .35109 L .70353 .34711 L F
.922 .972 .692 r
.70353 .34711 m .70497 .34267 L .70299 .3463 L F
.231 .301 .73 r
.34754 .61234 m .34799 .6074 L .34697 .60967 L F
.805 .732 .783 r
.63015 .41688 m .6344 .41526 L .63408 .41483 L F
.877 .901 .486 r
.63408 .41483 m .6344 .41526 L .63484 .41231 L F
0 0 .517 r
.22608 .59345 m .22558 .59186 L .22364 .58927 L F
.189 .314 .761 r
.22551 .59556 m .22558 .59186 L .22608 .59345 L F
.89 .973 .826 r
.62264 .40447 m .62146 .40604 L .61995 .40413 L F
.62359 .40459 m .62273 .40517 L .62264 .40447 L F
.62273 .40517 m .62146 .40604 L .62264 .40447 L F
.62359 .40459 m .62231 .40711 L .62146 .40604 L F
.62285 .40605 m .62312 .40662 L .62231 .40711 L F
.941 .743 .272 r
.62293 .40667 m .62312 .40662 L .62273 .40517 L F
.713 .813 .927 r
.62273 .40517 m .62312 .40662 L .62359 .40459 L F
.89 .973 .826 r
.62359 .40459 m .62312 .40662 L .62285 .40605 L F
.941 .743 .272 r
.62271 .40673 m .62293 .40667 L .62277 .40588 L F
.612 .178 .193 r
.62086 .4064 m .62238 .40539 L .61995 .40413 L F
.941 .743 .272 r
.62252 .40536 m .62254 .4048 L .62248 .40505 L F
.612 .178 .193 r
.62238 .40539 m .62248 .40505 L .61995 .40413 L F
.62248 .40505 m .62264 .40447 L .62174 .40435 L F
.62248 .40505 m .62174 .40435 L .61995 .40413 L F
.941 .743 .272 r
.62252 .40536 m .62277 .40588 L .62254 .4048 L F
.62271 .40673 m .62277 .40588 L .62252 .40536 L F
.62293 .40667 m .62273 .40517 L .62224 .40337 L F
.947 .777 .639 r
.62224 .40337 m .62273 .40516 L .62265 .40521 L F
.612 .178 .193 r
.62259 .40464 m .62359 .40459 L .62264 .40447 L F
.713 .813 .927 r
.62259 .40464 m .62273 .40517 L .62359 .40459 L F
.75 .617 .712 r
.62386 .40635 m .6254 .40861 L .62407 .40673 L F
.612 .178 .193 r
.62324 .40482 m .62316 .40461 L .62259 .40464 L F
.713 .813 .927 r
.62224 .40337 m .62259 .40464 L .62359 .40459 L F
.612 .178 .193 r
.62238 .40539 m .62324 .40482 L .62259 .40464 L F
.62324 .40482 m .62359 .40459 L .62316 .40461 L F
.947 .777 .639 r
.62224 .40337 m .62359 .40459 L .62273 .40516 L F
.75 .617 .712 r
.62224 .40337 m .62349 .40544 L .62386 .40635 L F
.62349 .40544 m .6254 .40861 L .62386 .40635 L F
.941 .743 .272 r
.62248 .40505 m .62254 .4048 L .62224 .40337 L F
.947 .777 .639 r
.62224 .40337 m .62265 .40521 L .62086 .4064 L F
.941 .743 .272 r
.62271 .40673 m .62248 .40505 L .62265 .40524 L F
.62298 .40673 m .62265 .40524 L .62407 .40673 L F
.62271 .40673 m .62265 .40524 L .62298 .40673 L F
.62248 .40505 m .62224 .40337 L .62386 .40635 L F
.62248 .40505 m .62386 .40635 L .62407 .40673 L F
0 0 .101 r
.35805 .55424 m .35806 .55703 L .35786 .55727 L F
.903 .489 .147 r
.35839 .55978 m .36019 .56097 L .35786 .55727 L F
0 0 .233 r
.35806 .55703 m .35839 .55978 L .35786 .55727 L F
0 0 .101 r
.35786 .55727 m .35806 .55703 L .35805 .55424 L F
0 0 .233 r
.35806 .55703 m .35839 .55978 L .35786 .55727 L F
.552 .586 .841 r
.34204 .69348 m .34286 .68934 L .34131 .68935 L F
.34204 .69348 m .34449 .69299 L .34286 .68934 L F
.494 .294 .537 r
.5637 .44463 m .56372 .44723 L .56109 .44795 L F
.5637 .44463 m .56372 .44723 L .56109 .44795 L F
.226 .654 .956 r
.7009 .29301 m .69871 .2936 L .69881 .29197 L F
.7009 .29301 m .70231 .29421 L .69871 .2936 L F
.645 .1 0 r
.38159 .50642 m .38199 .50767 L .37992 .50555 L F
.38159 .50642 m .38396 .50878 L .38199 .50767 L F
.724 .216 .02 r
.38609 .50891 m .38396 .50878 L .38159 .50642 L F
.593 .396 .584 r
.48787 .51536 m .48516 .51858 L .4851 .51577 L F
0 0 0 r
.28009 .63307 m .28257 .63051 L .28223 .6336 L F
.248 .444 .857 r
.28215 .63353 m .28009 .63307 L .28223 .6336 L F
.901 .892 .811 r
.27876 .63277 m .28106 .63186 L .28009 .63307 L F
0 0 0 r
.28009 .63307 m .28106 .63186 L .28257 .63051 L F
.248 .444 .857 r
.27826 .63032 m .28009 .63307 L .28215 .63353 L F
.901 .892 .811 r
.27716 .6334 m .27876 .63277 L .28009 .63307 L F
.513 0 0 r
.58928 .38833 m .58862 .38766 L .58993 .38892 L F
.53 0 0 r
.58718 .38623 m .58862 .38766 L .5863 .38588 L F
0 .134 .615 r
.5863 .38588 m .58862 .38766 L .5862 .38548 L F
.513 0 0 r
.5862 .38548 m .58862 .38766 L .58928 .38833 L F
.53 0 0 r
.58802 .38656 m .58862 .38766 L .58718 .38623 L F
.58802 .38656 m .59074 .38833 L .58862 .38766 L F
.773 .993 .878 r
.58793 .35512 m .58521 .35731 L .58603 .35503 L F
.628 .098 0 r
.58521 .35731 m .58346 .3581 L .58603 .35503 L F
.58521 .35731 m .58769 .35915 L .58346 .3581 L F
.372 0 0 r
.25022 .62234 m .2521 .62319 L .25453 .62452 L F
.742 .958 .941 r
.56668 .40809 m .56649 .40801 L .56604 .40893 L F
.779 .523 .548 r
.73564 .3205 m .7317 .32289 L .734 .31969 L F
.73564 .3205 m .73489 .32351 L .73435 .32128 L F
.983 .773 .543 r
.73564 .3205 m .73511 .32461 L .73488 .32355 L F
.518 .536 .814 r
.73714 .31636 m .73861 .32083 L .73564 .3205 L F
.869 .982 .842 r
.73524 .32438 m .73861 .32083 L .73768 .31999 L F
.73511 .32461 m .73525 .32446 L .73524 .32438 L F
.73525 .32446 m .73861 .32083 L .73524 .32438 L F
.73511 .32461 m .73768 .31999 L .73488 .32262 L F
0 0 .212 r
.73508 .32289 m .73562 .32551 L .73499 .32305 L F
.73492 .32268 m .73499 .32305 L .73488 .32262 L F
.73508 .32289 m .73499 .32305 L .73492 .32268 L F
.615 .184 0 r
.73562 .32551 m .73519 .32477 L .73488 .32262 L F
.73519 .32477 m .73511 .32461 L .73506 .32421 L F
.73519 .32477 m .73506 .32421 L .73488 .32262 L F
.779 .523 .548 r
.73435 .32128 m .73488 .32355 L .7317 .32289 L F
.73489 .32351 m .73488 .32355 L .73435 .32128 L F
.518 .536 .814 r
.73714 .31636 m .73564 .3205 L .734 .31969 L F
.469 0 0 r
.30446 .62677 m .3041 .62536 L .303 .62831 L F
.30446 .62677 m .30674 .62576 L .3041 .62536 L F
.893 .508 .058 r
.4094 .56037 m .41039 .56334 L .40819 .55934 L F
.333 0 0 r
.45446 .59332 m .45828 .59282 L .45672 .59415 L F
.254 0 0 r
.45828 .59282 m .45922 .59401 L .45672 .59415 L F
.45828 .59282 m .461 .59244 L .45922 .59401 L F
.034 0 .433 r
.36478 .58306 m .36635 .57935 L .36402 .57989 L F
.29 .196 .572 r
.36454 .58506 m .36661 .58271 L .36478 .58306 L F
.288 .112 .461 r
.36635 .57935 m .36683 .58153 L .3671 .58056 L F
.776 .595 .654 r
.3671 .58056 m .36658 .58467 L .36683 .58151 L F
.3671 .58056 m .36694 .58192 L .36692 .58197 L F
.288 .112 .461 r
.36683 .58153 m .367 .58228 L .3671 .58056 L F
.776 .595 .654 r
.3671 .58056 m .36683 .58151 L .3669 .58068 L F
.29 .196 .572 r
.36454 .58506 m .36657 .58514 L .36661 .58271 L F
.776 .595 .654 r
.36658 .58467 m .36653 .58499 L .36658 .58447 L F
.36658 .58467 m .36658 .58447 L .3669 .58068 L F
.36692 .58197 m .36657 .58514 L .36653 .58499 L F
.36694 .58192 m .36657 .58514 L .36692 .58197 L F
0 0 .173 r
.367 .58228 m .36657 .58514 L .3671 .58056 L F
.29 .196 .572 r
.36661 .58271 m .36657 .58514 L .367 .58228 L F
.36661 .58271 m .367 .58228 L .36676 .58236 L F
.36661 .58271 m .36676 .58236 L .36478 .58306 L F
.034 0 .433 r
.36478 .58306 m .36676 .58236 L .36635 .57935 L F
.36676 .58236 m .36683 .58153 L .36635 .57935 L F
.776 .595 .654 r
.3669 .58068 m .36653 .58499 L .36574 .58134 L F
.034 0 .433 r
.36676 .58236 m .367 .58228 L .36683 .58153 L F
.545 .929 .858 r
.66577 .37481 m .66322 .37624 L .66486 .37475 L F
.534 .912 .756 r
.66486 .37475 m .66322 .37624 L .6626 .3763 L F
.553 0 0 r
.31193 .64907 m .31214 .64744 L .31159 .64744 L F
.629 .928 .971 r
.60693 .35542 m .61174 .35498 L .61045 .35465 L F
.60693 .35542 m .61045 .35465 L .61009 .3547 L F
.571 .065 .013 r
.61409 .35354 m .61063 .35457 L .61174 .35498 L F
.61063 .35457 m .61039 .35463 L .61045 .35465 L F
.61063 .35457 m .61045 .35465 L .61174 .35498 L F
.748 .457 .49 r
.61247 .35743 m .60949 .3551 L .61273 .35486 L F
.60949 .3551 m .60917 .35484 L .61002 .35485 L F
.60949 .3551 m .61002 .35485 L .61273 .35486 L F
.027 0 0 r
.60907 .35476 m .60693 .35542 L .61039 .35463 L F
.748 .457 .49 r
.60917 .35484 m .60907 .35476 L .60959 .35478 L F
.60917 .35484 m .60959 .35478 L .61273 .35486 L F
.629 .928 .971 r
.61009 .3547 m .61045 .35465 L .61039 .35463 L F
.289 .733 .963 r
.4381 .59777 m .44253 .59846 L .44061 .59737 L F
.503 .814 1 r
.44253 .59846 m .44411 .59757 L .44061 .59737 L F
.44253 .59846 m .4451 .59793 L .44411 .59757 L F
0 0 .155 r
.42873 .57448 m .4287 .57124 L .42945 .57172 L F
0 0 .204 r
.42821 .57745 m .42846 .57434 L .4283 .57611 L F
.42846 .57434 m .42843 .57463 L .4283 .57611 L F
0 0 .155 r
.4283 .57611 m .42843 .57463 L .42873 .57448 L F
0 0 .204 r
.42846 .57434 m .4287 .57124 L .42843 .57463 L F
0 0 .155 r
.42843 .57463 m .4287 .57124 L .42873 .57448 L F
.846 .825 .347 r
.42946 .57413 m .43079 .57287 L .42975 .57391 L F
.4283 .57502 m .4283 .57611 L .42942 .57183 L F
.42938 .5719 m .42942 .57183 L .42945 .57172 L F
.4283 .57502 m .42942 .57183 L .42938 .5719 L F
.42919 .57426 m .43079 .57287 L .42946 .57413 L F
.4283 .57502 m .42945 .57172 L .43079 .57287 L F
.783 .416 .363 r
.42916 .57234 m .42975 .57391 L .43079 .57287 L F
.42555 .57117 m .42872 .57324 L .42916 .57234 L F
.42872 .57324 m .42975 .57391 L .42916 .57234 L F
.846 .825 .347 r
.42839 .57495 m .42919 .57426 L .42946 .57413 L F
.4283 .57502 m .42839 .57494 L .42839 .57495 L F
.42839 .57494 m .43079 .57287 L .42839 .57495 L F
.638 .106 0 r
.33763 .49565 m .34149 .49654 L .34021 .49564 L F
.763 .95 .938 r
.71555 .32698 m .71973 .3257 L .71802 .32543 L F
.674 .969 .921 r
.71802 .32543 m .71973 .3257 L .72228 .32411 L F
.627 .832 .979 r
.28937 .51604 m .29356 .51644 L .29143 .51438 L F
.796 .741 .802 r
.29143 .51438 m .29356 .51644 L .29344 .51308 L F
.765 .993 .786 r
.69349 .28493 m .69023 .28891 L .69273 .28704 L F
0 0 .053 r
.69273 .28704 m .69023 .28891 L .69042 .29052 L F
.522 .404 .66 r
.36114 .5835 m .36158 .58625 L .35912 .58683 L F
.033 0 0 r
.56494 .46646 m .56846 .46463 L .56703 .46624 L F
0 0 0 r
.56703 .46624 m .56846 .46463 L .57038 .46297 L F
.481 .311 .573 r
.34655 .57706 m .34666 .57998 L .34419 .58055 L F
.495 .354 .619 r
.34666 .57998 m .34685 .58267 L .34419 .58055 L F
.34666 .57998 m .34685 .58267 L .34419 .58055 L F
.673 .939 .965 r
.45065 .45107 m .45245 .44994 L .45366 .45068 L F
.773 .997 .818 r
.45439 .44866 m .45366 .45068 L .45245 .44994 L F
.45439 .44866 m .45645 .44797 L .45366 .45068 L F
.805 .564 .574 r
.32674 .54783 m .32622 .5505 L .3308 .55075 L F
.651 .405 .533 r
.32622 .5505 m .32958 .55283 L .3308 .55075 L F
.764 .861 .921 r
.48411 .43488 m .48035 .435 L .48257 .43347 L F
.788 .871 .909 r
.48726 .43245 m .48411 .43488 L .48257 .43347 L F
0 0 0 r
.31085 .55134 m .31195 .55038 L .31315 .54754 L F
.57 .103 0 r
.31085 .55134 m .31152 .55226 L .31195 .55038 L F
.31085 .55134 m .31281 .55382 L .31152 .55226 L F
.824 .781 .812 r
.37749 .69064 m .38146 .68995 L .3809 .68867 L F
.872 .941 .86 r
.44949 .5163 m .44896 .51902 L .44992 .51904 L F
.344 .803 .937 r
.45283 .51909 m .44992 .51904 L .4497 .51913 L F
.45283 .51909 m .44951 .51913 L .45003 .51925 L F
.45305 .51908 m .44992 .51904 L .45283 .51909 L F
.634 .087 0 r
.45305 .51908 m .45315 .51998 L .44992 .51904 L F
.242 .409 .829 r
.44992 .51904 m .45315 .51998 L .45223 .51804 L F
.44992 .51904 m .45223 .51804 L .45143 .51635 L F
.344 .803 .937 r
.4497 .51913 m .44992 .51904 L .44951 .51913 L F
.45003 .51925 m .44951 .51913 L .44872 .51932 L F
.872 .941 .86 r
.44896 .51902 m .44569 .52024 L .44884 .51966 L F
.44949 .5163 m .44722 .51865 L .44896 .51902 L F
.44722 .51865 m .44569 .52024 L .44896 .51902 L F
.229 0 .073 r
.44992 .51904 m .44884 .51966 L .44872 .51932 L F
.872 .941 .86 r
.44896 .51902 m .44884 .51966 L .44992 .51904 L F
.634 .087 0 r
.45305 .51908 m .45482 .52086 L .45315 .51998 L F
.41 0 0 r
.69022 .31559 m .69324 .31676 L .68961 .31616 L F
.997 .852 .523 r
.39513 .59463 m .39655 .59305 L .39622 .59233 L F
.39513 .59463 m .39602 .59687 L .39655 .59305 L F
.712 .811 .927 r
.55287 .39414 m .54996 .39472 L .55105 .39394 L F
.489 .063 .159 r
.55105 .39394 m .55571 .39285 L .55287 .39414 L F
.759 .786 .876 r
.43775 .50151 m .43572 .49806 L .43745 .49922 L F
.43775 .50151 m .43331 .50069 L .43572 .49806 L F
.616 .077 0 r
.43955 .5034 m .43585 .50298 L .43775 .50151 L F
0 0 0 r
.67143 .36971 m .66915 .37114 L .66851 .37162 L F
.39 .849 .873 r
.34276 .52617 m .34334 .5267 L .34486 .52486 L F
.977 .73 .316 r
.38804 .67414 m .38388 .67628 L .38601 .67439 L F
.38388 .67628 m .38384 .67629 L .38386 .67628 L F
.38388 .67628 m .3871 .67407 L .38384 .67629 L F
.38804 .67414 m .3871 .67407 L .38388 .67628 L F
.38804 .67414 m .38796 .67672 L .3871 .67407 L F
.913 .914 .521 r
.38777 .67613 m .3888 .67289 L .3871 .67407 L F
.3888 .67289 m .38898 .67235 L .3871 .67407 L F
.38796 .67672 m .3881 .67612 L .38777 .67613 L F
.3881 .67612 m .38898 .67235 L .38777 .67613 L F
.977 .73 .316 r
.38388 .67628 m .38386 .67628 L .38601 .67439 L F
.593 .197 .26 r
.34236 .6357 m .34605 .6354 L .34471 .63754 L F
.908 .882 .457 r
.34605 .6354 m .34687 .63124 L .34698 .63384 L F
.614 .804 .383 r
.34471 .63754 m .34605 .6354 L .34698 .63384 L F
.837 .379 0 r
.38869 .54368 m .39151 .547 L .39024 .54486 L F
0 0 .169 r
.21783 .57319 m .21923 .56971 L .21778 .57049 L F
0 0 .123 r
.47902 .56653 m .4784 .56891 L .47692 .57056 L F
0 0 .322 r
.47692 .57056 m .47837 .57166 L .47758 .57352 L F
.47692 .57056 m .4784 .56891 L .47837 .57166 L F
.881 .451 .07 r
.3741 .51841 m .37511 .5211 L .37636 .52122 L F
.905 .524 .293 r
.37511 .5211 m .37812 .52421 L .37636 .52122 L F
.872 .705 .671 r
.38291 .49614 m .37984 .49606 L .3811 .49234 L F
.868 .805 .787 r
.38291 .49614 m .37861 .498 L .37984 .49606 L F
.38291 .49614 m .38067 .49968 L .37861 .498 L F
.705 .643 .785 r
.38553 .49322 m .38291 .49614 L .3811 .49234 L F
0 0 0 r
.56102 .46903 m .56494 .46646 L .56351 .46797 L F
.02 0 0 r
.56351 .46797 m .56494 .46646 L .56703 .46624 L F
0 .102 .578 r
.33708 .64219 m .33942 .64408 L .33884 .6436 L F
0 .198 .721 r
.39246 .67399 m .3941 .67653 L .39367 .67368 L F
.374 .774 .985 r
.56649 .40801 m .57111 .40749 L .56711 .40689 L F
.178 .353 .801 r
.56711 .40689 m .56642 .40966 L .56604 .40893 L F
.611 .809 .976 r
.57111 .40749 m .56642 .40966 L .56711 .40689 L F
.832 .931 .896 r
.50981 .41781 m .50821 .41955 L .50686 .41851 L F
.629 .247 .301 r
.53367 .47672 m .5374 .47659 L .5363 .47877 L F
.563 .236 .372 r
.5374 .47659 m .53929 .47894 L .5363 .47877 L F
.5374 .47659 m .5403 .47634 L .53929 .47894 L F
.751 .785 .881 r
.30149 .65115 m .3069 .65077 L .30412 .64859 L F
.559 .082 .079 r
.30329 .65271 m .3069 .65077 L .30149 .65115 L F
0 0 .311 r
.30678 .65036 m .3069 .65077 L .30329 .65271 L F
.637 .57 .763 r
.3684 .69317 m .36635 .6947 L .36444 .68994 L F
.618 .642 .852 r
.73425 .31611 m .73017 .3131 L .7331 .31486 L F
.79 .952 .924 r
.7303 .31717 m .73425 .31611 L .7331 .31486 L F
.211 .597 .947 r
.73425 .31611 m .73495 .31606 L .7331 .31486 L F
.73495 .31606 m .73619 .31596 L .73395 .31516 L F
.73495 .31606 m .73395 .31516 L .7331 .31486 L F
.256 .364 .783 r
.73019 .31307 m .7331 .31486 L .73017 .3131 L F
.73151 .31015 m .73277 .3139 L .73019 .31307 L F
.73277 .3139 m .7331 .31486 L .73019 .31307 L F
.774 .969 .922 r
.73135 .31464 m .7303 .31717 L .7331 .31486 L F
.712 .653 .789 r
.73426 .31151 m .7331 .31486 L .73151 .31015 L F
.73426 .31151 m .7331 .31486 L .73151 .31015 L F
.595 .673 .894 r
.7331 .31486 m .73452 .31164 L .73135 .31464 L F
.726 .92 .959 r
.73306 .31437 m .7303 .31717 L .73135 .31464 L F
.595 .673 .894 r
.73411 .31257 m .73666 .31592 L .73452 .31164 L F
.786 .751 .821 r
.73714 .31636 m .73585 .31547 L .73666 .31592 L F
.595 .673 .894 r
.73342 .31413 m .73585 .31547 L .73411 .31257 L F
.736 .31572 m .73666 .31592 L .73411 .31257 L F
.786 .751 .821 r
.73585 .31547 m .73401 .31422 L .73666 .31592 L F
.595 .673 .894 r
.7331 .31486 m .736 .31572 L .73585 .31547 L F
.7331 .31486 m .73585 .31547 L .73342 .31413 L F
.211 .597 .947 r
.73619 .31596 m .73537 .31554 L .7331 .31486 L F
.73648 .31594 m .73714 .31636 L .73666 .31592 L F
.73425 .31611 m .73714 .31636 L .73648 .31594 L F
.786 .751 .821 r
.73585 .31547 m .73583 .31552 L .73401 .31422 L F
.73583 .31552 m .734 .31969 L .73401 .31437 L F
.73583 .31552 m .73401 .31437 L .73401 .31422 L F
.211 .597 .947 r
.73619 .31596 m .73648 .31594 L .73537 .31554 L F
.786 .751 .821 r
.73661 .316 m .736 .31572 L .73585 .31547 L F
.211 .597 .947 r
.73648 .31594 m .73666 .31592 L .736 .31572 L F
.73648 .31594 m .736 .31572 L .73537 .31554 L F
.786 .751 .821 r
.73714 .31636 m .73668 .31685 L .736 .31572 L F
.73714 .31636 m .736 .31572 L .73661 .316 L F
.73668 .31685 m .734 .31969 L .73585 .31547 L F
.726 .92 .959 r
.73401 .31422 m .73342 .31469 L .73306 .31437 L F
.73342 .31469 m .7303 .31717 L .73306 .31437 L F
.837 .791 .807 r
.73372 .31469 m .734 .31969 L .73073 .3195 L F
.73401 .31422 m .73401 .31484 L .73372 .31469 L F
.73401 .31484 m .734 .31969 L .73372 .31469 L F
.569 .008 0 r
.73506 .31551 m .73411 .31433 L .73135 .31464 L F
.73411 .31433 m .73401 .31422 L .73384 .31424 L F
.73411 .31433 m .73384 .31424 L .73135 .31464 L F
.528 .267 .463 r
.23608 .57994 m .23832 .57972 L .23846 .57731 L F
.488 .175 .361 r
.23832 .57972 m .24321 .57603 L .23846 .57731 L F
.234 .368 .795 r
.46743 .54439 m .46565 .54034 L .46718 .54148 L F
.786 .949 .927 r
.64468 .40138 m .64695 .398 L .6435 .40075 L F
.64468 .40138 m .64783 .39912 L .64695 .398 L F
.517 .538 .817 r
.60909 .38121 m .60816 .38545 L .60663 .38222 L F
.60909 .38121 m .61094 .38537 L .60816 .38545 L F
.728 .515 .603 r
.41462 .47044 m .41132 .47077 L .41151 .47059 L F
.85 .554 .488 r
.41409 .47345 m .41132 .47077 L .41462 .47044 L F
.729 .72 .842 r
.41462 .47044 m .41151 .47059 L .41389 .46631 L F
.867 .966 .86 r
.41511 .46947 m .41462 .47044 L .41618 .47076 L F
.762 .684 .776 r
.41409 .47345 m .41618 .47076 L .41462 .47044 L F
.867 .966 .86 r
.41511 .46947 m .41409 .47345 L .41462 .47044 L F
.781 .835 .893 r
.33276 .65169 m .33616 .65143 L .33601 .65003 L F
.297 .456 .85 r
.33601 .65003 m .33616 .65143 L .33699 .65003 L F
.107 .016 .46 r
.33616 .65143 m .33622 .65455 L .33762 .65286 L F
.886 .805 .764 r
.54704 .44158 m .549 .43859 L .54737 .43723 L F
.696 .814 .938 r
.549 .43859 m .55127 .43796 L .548 .43708 L F
.54791 .43711 m .548 .43708 L .54785 .43704 L F
.549 .43859 m .548 .43708 L .54791 .43711 L F
.549 .43859 m .54919 .43819 L .55179 .44036 L F
.54919 .43819 m .54942 .43769 L .55179 .44036 L F
.54919 .43819 m .54785 .43704 L .54942 .43769 L F
.549 .43859 m .54791 .43711 L .54919 .43819 L F
.54791 .43711 m .54785 .43704 L .54919 .43819 L F
.549 .43859 m .55176 .44035 L .54792 .4377 L F
.55176 .44035 m .55179 .44036 L .54792 .4377 L F
.54792 .4377 m .55179 .44036 L .54737 .43723 L F
.649 .549 .728 r
.54738 .43732 m .55176 .44035 L .5482 .44292 L F
.55176 .44035 m .55179 .44036 L .55179 .44037 L F
.55176 .44035 m .55179 .44037 L .5482 .44292 L F
.54737 .43723 m .54745 .43729 L .54738 .43732 L F
.54745 .43729 m .55179 .44036 L .54738 .43732 L F
.878 .859 .819 r
.36418 .56404 m .36171 .56751 L .35982 .56616 L F
.997 .853 .535 r
.69475 .33729 m .69489 .34075 L .69505 .34003 L F
.964 .937 .634 r
.69489 .34075 m .69292 .3435 L .69505 .34003 L F
.324 0 0 r
.56726 .43782 m .56637 .43742 L .56618 .43762 L F
.243 .361 .784 r
.56667 .43843 m .56625 .43887 L .56549 .43749 L F
.56667 .43843 m .56549 .43749 L .56573 .43753 L F
.56667 .43843 m .56528 .4371 L .56595 .43749 L F
.585 .15 .181 r
.56618 .43762 m .56637 .43742 L .56595 .43749 L F
.752 .516 .575 r
.56595 .43749 m .56637 .43742 L .56435 .43539 L F
0 .252 .763 r
.56435 .43539 m .56637 .43742 L .56726 .43782 L F
.243 .361 .784 r
.56726 .43782 m .56667 .43843 L .56435 .43539 L F
.324 0 0 r
.56726 .43782 m .56618 .43762 L .56416 .43969 L F
.243 .361 .784 r
.56573 .43753 m .56549 .43749 L .56528 .4371 L F
.56595 .43749 m .56528 .4371 L .56435 .43539 L F
.585 .15 .181 r
.56416 .43969 m .56618 .43762 L .56192 .43809 L F
.56618 .43762 m .56595 .43749 L .56192 .43809 L F
.752 .516 .575 r
.56192 .43809 m .56595 .43749 L .56435 .43539 L F
.592 .928 .959 r
.56726 .43782 m .56885 .43798 L .56625 .43887 L F
.689 .557 .7 r
.56625 .43887 m .5663 .44134 L .56885 .43798 L F
.592 .928 .959 r
.56726 .43782 m .56885 .43798 L .56625 .43887 L F
.165 0 0 r
.27933 .54422 m .2769 .54617 L .27942 .54559 L F
0 0 .302 r
.22944 .55939 m .22858 .56132 L .22876 .55723 L F
0 0 0 r
.37017 .63169 m .37197 .62934 L .36942 .63242 L F
.42 .289 .596 r
.36876 .63298 m .36689 .63126 L .36648 .62998 L F
.491 .826 .532 r
.37017 .63169 m .36942 .63242 L .36838 .63335 L F
.36855 .63319 m .36838 .63335 L .36755 .6341 L F
.37017 .63169 m .36838 .63335 L .36855 .63319 L F
.37017 .63169 m .36755 .6341 L .36949 .63394 L F
.42 .289 .596 r
.36949 .63394 m .36866 .63308 L .36876 .63298 L F
.36866 .63308 m .36689 .63126 L .36876 .63298 L F
.736 .78 .888 r
.34449 .69299 m .34866 .6933 L .34685 .69183 L F
.576 .664 .898 r
.34866 .6933 m .34947 .68994 L .34685 .69183 L F
.34866 .6933 m .35117 .69273 L .34947 .68994 L F
.383 .485 .84 r
.34866 .6933 m .35245 .6967 L .35117 .69273 L F
.62 .436 .612 r
.50974 .48998 m .50971 .49256 L .50719 .49276 L F
.398 .174 .453 r
.5124 .48931 m .50971 .49256 L .50974 .48998 L F
.453 .645 .94 r
.56223 .41008 m .56347 .41212 L .56479 .40984 L F
.205 .323 .763 r
.56479 .40984 m .56347 .41212 L .56613 .41326 L F
.891 .986 .799 r
.62643 .40044 m .62888 .39948 L .6263 .40269 L F
.851 .997 .814 r
.63121 .39674 m .62888 .39948 L .62922 .39728 L F
.851 .997 .815 r
.62922 .39728 m .62888 .39948 L .62643 .40044 L F
.906 .699 .611 r
.42849 .55694 m .42973 .5549 L .42674 .55356 L F
.42849 .55694 m .43012 .55808 L .42973 .5549 L F
.518 .423 .686 r
.42973 .5549 m .43249 .55723 L .43224 .55432 L F
.42973 .5549 m .43012 .55808 L .43249 .55723 L F
.557 .072 .06 r
.38549 .67259 m .38731 .66989 L .38286 .67062 L F
.832 .536 .49 r
.38549 .67259 m .38839 .67208 L .38731 .66989 L F
.121 .672 .742 r
.25004 .58443 m .24595 .58489 L .24682 .58317 L F
.635 .819 .4 r
.24855 .58321 m .24777 .5845 L .2478 .5846 L F
.121 .672 .742 r
.24783 .58468 m .2478 .5846 L .24595 .58489 L F
.103 0 .335 r
.2478 .5846 m .24613 .58844 L .24595 .58489 L F
.458 .169 .386 r
.24595 .58489 m .24346 .58896 L .24385 .58655 L F
.24595 .58489 m .24613 .58844 L .24346 .58896 L F
.906 .82 .752 r
.24423 .58701 m .24613 .58844 L .2478 .5846 L F
.24423 .58701 m .2478 .5846 L .2464 .58675 L F
.635 .819 .4 r
.24777 .5845 m .2464 .58675 L .2478 .5846 L F
.121 .672 .742 r
.25004 .58443 m .2478 .5846 L .24783 .58468 L F
.746 .989 .888 r
.25101 .58212 m .25004 .58443 L .25327 .58355 L F
.25101 .58212 m .2478 .5846 L .25004 .58443 L F
.744 .738 .846 r
.42876 .45818 m .42507 .45783 L .42727 .4563 L F
.657 .702 .879 r
.43138 .45721 m .42876 .45818 L .42727 .4563 L F
.594 .536 .759 r
.43208 .46048 m .42876 .45818 L .43138 .45721 L F
.621 .564 .769 r
.37067 .53264 m .367 .53302 L .36868 .5305 L F
.535 .337 .559 r
.49603 .50586 m .49631 .50883 L .49328 .50937 L F
.522 .401 .656 r
.49835 .50237 m .4985 .50547 L .49603 .50586 L F
.433 .263 .55 r
.49874 .5077 m .49603 .50586 L .4985 .50547 L F
.49874 .5077 m .49631 .50883 L .49603 .50586 L F
.715 .18 0 r
.39195 .66938 m .391 .66733 L .38937 .66678 L F
.39195 .66938 m .3937 .66989 L .391 .66733 L F
.662 .576 .748 r
.43568 .49013 m .43562 .49274 L .4385 .48965 L F
.992 .753 .463 r
.64822 .38334 m .64767 .38559 L .65029 .38216 L F
.315 .006 .272 r
.33188 .55401 m .33085 .55681 L .32887 .55738 L F
.544 .342 .556 r
.33479 .55116 m .3345 .55368 L .33188 .55401 L F
.493 .173 .352 r
.33313 .55578 m .33188 .55401 L .3345 .55368 L F
.33313 .55578 m .33085 .55681 L .33188 .55401 L F
.544 .342 .556 r
.33188 .55401 m .3345 .55368 L .33479 .55116 L F
.506 .222 .417 r
.5244 .47993 m .52414 .48198 L .52132 .48216 L F
.482 .18 .377 r
.52707 .47962 m .52414 .48198 L .5244 .47993 L F
.831 .757 .781 r
.55767 .40207 m .55412 .40171 L .55673 .39852 L F
.624 .26 .332 r
.55767 .40207 m .55382 .40444 L .55412 .40171 L F
.55767 .40207 m .5562 .40484 L .55382 .40444 L F
.831 .757 .781 r
.55986 .39707 m .55767 .40207 L .55673 .39852 L F
.669 .31 .355 r
.55767 .40207 m .56104 .40456 L .5562 .40484 L F
.782 .848 .394 r
.70103 .353 m .70191 .35109 L .70253 .34863 L F
.302 0 0 r
.6972 .31645 m .69729 .31679 L .69324 .31676 L F
.976 .717 .476 r
.69923 .32076 m .69735 .31989 L .69729 .31679 L F
.897 .904 .823 r
.69873 .32052 m .69889 .32145 L .69735 .31989 L F
.6993 .32088 m .69889 .32145 L .69873 .32052 L F
.976 .717 .476 r
.69923 .32076 m .69735 .31989 L .69729 .31679 L F
.897 .904 .823 r
.69923 .32076 m .69873 .32052 L .69853 .31942 L F
.6993 .32088 m .69873 .32052 L .69923 .32076 L F
.976 .717 .476 r
.69928 .32085 m .69735 .31989 L .69923 .32076 L F
.69928 .32085 m .69735 .31989 L .69923 .32076 L F
.897 .904 .823 r
.69853 .31942 m .69873 .32052 L .69735 .31989 L F
.693 .319 0 r
.6972 .31645 m .69925 .32079 L .69729 .31679 L F
.69925 .32079 m .69923 .32076 L .69729 .31679 L F
.897 .904 .823 r
.70101 .31844 m .6993 .32088 L .69925 .32079 L F
.699 .562 .697 r
.70101 .31844 m .69928 .32085 L .69925 .32079 L F
.70101 .31844 m .69925 .32079 L .6972 .31645 L F
.897 .904 .823 r
.70101 .31844 m .69925 .32079 L .69923 .32076 L F
.693 .319 0 r
.69925 .32079 m .69928 .32085 L .69923 .32076 L F
.8 .71 .766 r
.70101 .31844 m .69928 .32085 L .69923 .32076 L F
.70101 .31844 m .69923 .32076 L .69729 .31679 L F
.897 .904 .823 r
.70101 .31844 m .69923 .32076 L .69853 .31942 L F
.675 .765 .919 r
.63337 .41109 m .63094 .41272 L .63001 .41061 L F
.256 0 .315 r
.69166 .33201 m .69247 .33292 L .69334 .33001 L F
.69166 .33201 m .69068 .33414 L .69247 .33292 L F
0 0 .15 r
.33944 .55787 m .34029 .55863 L .34155 .55708 L F
.53 .021 0 r
.38403 .5334 m .38545 .53473 L .38277 .53214 L F
.911 .517 .117 r
.38488 .53621 m .38545 .53473 L .38403 .5334 L F
.38488 .53621 m .38626 .5376 L .38545 .53473 L F
.883 .99 .745 r
.68011 .30199 m .67989 .30115 L .68225 .2978 L F
.755 .403 .386 r
.33622 .65455 m .34014 .65488 L .33933 .6568 L F
.477 .51 .814 r
.34116 .65164 m .34261 .65505 L .34014 .65488 L F
0 0 0 r
.34261 .65505 m .34324 .65546 L .34078 .65588 L F
.405 .806 .984 r
.34166 .65534 m .34078 .65588 L .34324 .65546 L F
.268 0 0 r
.34014 .65488 m .34078 .65588 L .33935 .65677 L F
.34014 .65488 m .34261 .65505 L .34078 .65588 L F
.405 .806 .984 r
.3391 .65514 m .34078 .65588 L .34166 .65534 L F
.268 0 0 r
.33935 .65677 m .34078 .65588 L .33933 .6568 L F
0 0 .419 r
.32662 .62755 m .32741 .6292 L .3265 .62743 L F
0 .168 .594 r
.32799 .62958 m .32741 .6292 L .32662 .62755 L F
.32799 .62958 m .33022 .63104 L .32741 .6292 L F
.883 .48 .038 r
.5928 .41222 m .59091 .40877 L .5916 .41208 L F
.977 .685 .309 r
.59212 .41404 m .5928 .41222 L .5916 .41208 L F
.59212 .41404 m .59316 .41491 L .5928 .41222 L F
.717 .906 .962 r
.38067 .49968 m .37545 .50116 L .37861 .498 L F
.562 .407 .629 r
.54956 .39855 m .55105 .39394 L .54996 .39472 L F
.329 .067 .356 r
.32174 .5545 m .31889 .5575 L .32064 .55677 L F
.381 .017 .216 r
.31743 .5602 m .32064 .55677 L .31889 .5575 L F
0 0 0 r
.29485 .65032 m .2948 .65061 L .29514 .64819 L F
.29485 .65032 m .29514 .64819 L .29332 .64724 L F
.935 .577 .168 r
.39626 .5718 m .39708 .57025 L .39596 .56912 L F
.39626 .5718 m .39758 .57301 L .39708 .57025 L F
.3 .673 .974 r
.29954 .66729 m .30192 .66738 L .29991 .66609 L F
.499 .865 .985 r
.29741 .66683 m .29954 .66729 L .29991 .66609 L F
.592 .932 .952 r
.4256 .50607 m .42012 .50705 L .42426 .50505 L F
.907 .93 .817 r
.42796 .50258 m .4256 .50607 L .42426 .50505 L F
.959 .622 .255 r
.46092 .51704 m .46089 .51563 L .46035 .5137 L F
.46092 .51704 m .46134 .51863 L .46089 .51563 L F
.318 .328 .713 r
.46089 .51563 m .46233 .5113 L .46035 .5137 L F
.46089 .51563 m .46327 .51435 L .46233 .5113 L F
.557 .321 .513 r
.46089 .51563 m .46402 .51772 L .46327 .51435 L F
.46089 .51563 m .46134 .51863 L .46402 .51772 L F
.21 .265 .701 r
.23397 .60447 m .23174 .603 L .23312 .60209 L F
.723 .962 .942 r
.62693 .34162 m .62887 .34217 L .62562 .34397 L F
.756 .995 .848 r
.62562 .34397 m .62497 .34353 L .62693 .34162 L F
.181 .611 .942 r
.24143 .58593 m .24193 .58509 L .24006 .58465 L F
.886 .82 .778 r
.43071 .59571 m .43262 .59726 L .43429 .59366 L F
.519 .846 .555 r
.34793 .50888 m .34787 .50902 L .34954 .50736 L F
.958 .945 .65 r
.34782 .50848 m .34689 .50647 L .34954 .50736 L F
.81 .876 .894 r
.34762 .50861 m .34793 .50888 L .34954 .50736 L F
.958 .945 .65 r
.34662 .50776 m .34689 .50647 L .34804 .50897 L F
.443 .039 .176 r
.34449 .51129 m .34591 .51124 L .34787 .50902 L F
.958 .945 .65 r
.34591 .51124 m .34489 .51068 L .34632 .50766 L F
.969 .913 .698 r
.34638 .50754 m .34638 .50754 L .3463 .50747 L F
0 .097 .57 r
.3463 .50747 m .34635 .50751 L .34631 .50748 L F
.34635 .50751 m .34761 .5086 L .34633 .5075 L F
.969 .913 .698 r
.34689 .50647 m .34638 .50754 L .34628 .50745 L F
.91 .76 .682 r
.34419 .50552 m .34628 .50745 L .34689 .50647 L F
.969 .913 .698 r
.34689 .50647 m .34628 .50745 L .34597 .5072 L F
.91 .76 .682 r
.34628 .50745 m .34631 .50748 L .34689 .50647 L F
0 .097 .57 r
.34635 .50751 m .34633 .5075 L .34631 .50748 L F
.405 .504 .847 r
.34464 .50621 m .34787 .50902 L .34793 .50888 L F
.958 .945 .65 r
.34627 .50949 m .34632 .50766 L .34638 .50754 L F
.34662 .50776 m .34638 .50754 L .34689 .50647 L F
.34627 .50949 m .34638 .50754 L .34662 .50776 L F
.34591 .51124 m .34632 .50766 L .34627 .50949 L F
.81 .876 .894 r
.34633 .50748 m .34762 .50861 L .34954 .50736 L F
.34631 .50748 m .34633 .5075 L .34633 .50748 L F
.34633 .5075 m .34762 .50861 L .34633 .50748 L F
.958 .945 .65 r
.34804 .50897 m .34782 .50848 L .34954 .50736 L F
0 .097 .57 r
.34761 .5086 m .34793 .50888 L .34762 .50861 L F
.34751 .50854 m .34793 .50888 L .3463 .50747 L F
.958 .945 .65 r
.34591 .51124 m .34662 .50776 L .34804 .50897 L F
0 .097 .57 r
.34761 .5086 m .34762 .50861 L .34631 .50748 L F
.34464 .50621 m .34751 .50854 L .3463 .50747 L F
.969 .913 .698 r
.3463 .50747 m .34489 .51068 L .34597 .5072 L F
.34638 .50754 m .34489 .51068 L .3463 .50747 L F
.34597 .5072 m .34489 .51068 L .34443 .50842 L F
0 .097 .57 r
.34464 .50621 m .3463 .50747 L .34302 .50487 L F
.3463 .50747 m .34631 .50748 L .3463 .50747 L F
.3463 .50747 m .3463 .50747 L .34302 .50487 L F
.741 .548 .633 r
.33356 .56677 m .33743 .56754 L .33706 .56505 L F
.029 0 .404 r
.33743 .56754 m .33848 .56291 L .33706 .56505 L F
0 0 0 r
.23097 .55443 m .2293 .55676 L .22876 .55723 L F
0 0 .302 r
.22944 .55939 m .22876 .55723 L .2293 .55676 L F
.827 .964 .639 r
.29517 .51231 m .2946 .51242 L .29709 .5083 L F
.531 .906 .734 r
.29672 .51091 m .2946 .51242 L .29517 .51231 L F
.396 .095 .332 r
.42109 .58273 m .42167 .58054 L .42407 .57994 L F
.79 .993 .878 r
.37548 .63188 m .37863 .62909 L .37576 .62977 L F
.815 .999 .835 r
.37441 .6317 m .37548 .63188 L .37576 .62977 L F
0 .219 .742 r
.34229 .63398 m .34236 .6357 L .34471 .63754 L F
.878 .859 .819 r
.36418 .56404 m .36096 .56561 L .3626 .56495 L F
.399 0 0 r
.3626 .56495 m .36653 .56347 L .36418 .56404 L F
.294 .33 .729 r
.36283 .56017 m .36392 .56443 L .3626 .56495 L F
.399 0 0 r
.3626 .56495 m .36417 .56541 L .36653 .56347 L F
.294 .33 .729 r
.36392 .56443 m .36417 .56541 L .3626 .56495 L F
.878 .859 .819 r
.36096 .56561 m .35982 .56616 L .3626 .56495 L F
.525 .523 .796 r
.36418 .56404 m .36523 .55959 L .36318 .55979 L F
.36418 .56404 m .36653 .56347 L .36523 .55959 L F
.569 .01 0 r
.38792 .51168 m .38396 .50878 L .38609 .50891 L F
.813 .332 .042 r
.38988 .51235 m .38792 .51168 L .38609 .50891 L F
.354 .02 .253 r
.35434 .68684 m .3537 .6867 L .35208 .68792 L F
0 0 .295 r
.32745 .59645 m .3273 .59916 L .32857 .59776 L F
.792 .999 .844 r
.6254 .41798 m .6281 .41652 L .62706 .41454 L F
.419 .625 .938 r
.6281 .41652 m .63096 .4164 L .62706 .41454 L F
.6281 .41652 m .63015 .41688 L .63096 .4164 L F
.993 .785 .411 r
.39657 .58511 m .39769 .5833 L .39687 .5825 L F
.39657 .58511 m .3974 .5857 L .39769 .5833 L F
.434 .173 .417 r
.51803 .48349 m .51789 .48575 L .51535 .48644 L F
.535 .246 .422 r
.52132 .48216 m .51789 .48575 L .51803 .48349 L F
.988 .731 .363 r
.44326 .57381 m .44211 .57545 L .44256 .57425 L F
.44326 .57381 m .44326 .57703 L .44211 .57545 L F
.674 .866 .972 r
.39386 .47533 m .39876 .4754 L .39706 .47273 L F
.744 .74 .849 r
.39706 .47273 m .39876 .4754 L .40116 .47329 L F
.463 .683 .961 r
.42109 .48375 m .42397 .48632 L .42128 .48656 L F
.754 .738 .837 r
.34895 .68555 m .34998 .6867 L .34732 .68724 L F
.509 .598 .878 r
.35058 .68224 m .34998 .6867 L .34895 .68555 L F
.35058 .68224 m .35208 .68792 L .34998 .6867 L F
0 0 0 r
.63779 .35331 m .63688 .3536 L .63888 .35164 L F
.443 .487 .81 r
.63727 .35493 m .63688 .3536 L .6367 .35497 L F
0 0 0 r
.6367 .35497 m .63679 .35432 L .63779 .35331 L F
.63679 .35432 m .63688 .3536 L .63779 .35331 L F
.443 .487 .81 r
.63727 .35493 m .6356 .35741 L .63508 .35605 L F
.63656 .35456 m .63508 .35605 L .63399 .35319 L F
.63727 .35493 m .63508 .35605 L .63656 .35456 L F
0 0 0 r
.63467 .35902 m .6356 .35741 L .63727 .35493 L F
0 0 .056 r
.37504 .55364 m .37544 .55301 L .37553 .55097 L F
0 0 0 r
.37504 .55364 m .37496 .55431 L .37544 .55301 L F
.95 .647 .207 r
.30054 .6293 m .30101 .6301 L .303 .62831 L F
.30054 .6293 m .30125 .6321 L .30024 .63081 L F
.30054 .6293 m .30024 .63081 L .30101 .6301 L F
0 0 0 r
.23453 .53062 m .23741 .52886 L .23518 .5285 L F
.485 .245 .475 r
.49582 .51098 m .49328 .50937 L .49631 .50883 L F
.49582 .51098 m .49323 .51158 L .49328 .50937 L F
.518 .272 .481 r
.30281 .567 m .30632 .56364 L .30322 .56428 L F
.405 0 0 r
.25638 .62547 m .25732 .6262 L .25453 .62452 L F
.25638 .62547 m .25919 .62719 L .25732 .6262 L F
0 0 0 r
.2316 .53391 m .23453 .53062 L .23306 .53247 L F
.951 .745 .589 r
.3318 .58367 m .33173 .58445 L .33242 .58244 L F
.3318 .58367 m .33093 .58609 L .33173 .58445 L F
0 0 0 r
.43674 .58703 m .43504 .589 L .43837 .5863 L F
.69 .558 .7 r
.38806 .49142 m .38337 .48898 L .38886 .48933 L F
.97 .927 .615 r
.41192 .57299 m .41026 .57522 L .41078 .57242 L F
.41192 .57299 m .41056 .57693 L .41026 .57522 L F
.36 0 .049 r
.5482 .47618 m .54973 .47412 L .55184 .47489 L F
.359 0 .055 r
.54973 .47412 m .55242 .47376 L .55184 .47489 L F
.735 .219 0 r
.56762 .4388 m .56885 .43798 L .56726 .43782 L F
0 0 0 r
.57089 .4375 m .56885 .43798 L .56762 .4388 L F
.573 .267 .411 r
.34863 .60264 m .34481 .60502 L .34597 .60262 L F
.934 .942 .599 r
.64238 .40541 m .6435 .40075 L .64142 .40446 L F
.757 .402 .381 r
.37242 .6962 m .37666 .69671 L .37503 .69725 L F
.622 .644 .851 r
.37242 .6962 m .37503 .69725 L .37499 .69712 L F
.731 .33 .289 r
.37498 .69712 m .37666 .69671 L .37242 .6962 L F
.622 .644 .851 r
.37242 .6962 m .37499 .69712 L .37358 .69244 L F
.731 .33 .289 r
.3736 .69745 m .37498 .69712 L .37242 .6962 L F
.37362 .69747 m .3751 .6971 L .3736 .69745 L F
.3751 .6971 m .37666 .69671 L .3736 .69745 L F
.891 .79 .742 r
.37358 .69244 m .37499 .69712 L .37708 .69233 L F
.37499 .69712 m .37503 .69725 L .3751 .6971 L F
.37499 .69712 m .3751 .6971 L .37708 .69233 L F
.856 .76 .756 r
.37666 .69671 m .37708 .69233 L .3751 .6971 L F
.37666 .69671 m .3751 .6971 L .37503 .69725 L F
.731 .33 .289 r
.3748 .69872 m .37666 .69671 L .37362 .69747 L F
.988 .793 .555 r
.3748 .69872 m .37634 .69949 L .37666 .69671 L F
.3748 .69872 m .37634 .69949 L .37666 .69671 L F
.348 .138 .447 r
.48299 .54126 m .48364 .54353 L .48062 .54494 L F
.359 .394 .762 r
.48285 .5388 m .48533 .54015 L .48299 .54126 L F
.106 0 .369 r
.48533 .54015 m .48364 .54353 L .48299 .54126 L F
0 0 .493 r
.22542 .55063 m .22622 .54641 L .2253 .54818 L F
.342 .142 .458 r
.35805 .55424 m .36043 .55546 L .362 .55449 L F
.636 .235 .267 r
.36043 .55546 m .36485 .55393 L .362 .55449 L F
0 .095 .652 r
.5913 .39011 m .59253 .39159 L .59074 .38833 L F
.906 .498 .189 r
.70091 .30472 m .69983 .30578 L .70157 .3068 L F
.11 .255 .733 r
.70031 .30594 m .70157 .3068 L .69983 .30578 L F
.905 .925 .82 r
.70157 .3068 m .70316 .30789 L .70482 .30539 L F
.70157 .3068 m .70482 .30539 L .70091 .30472 L F
.11 .255 .733 r
.70417 .3072 m .70157 .3068 L .70031 .30594 L F
.905 .925 .82 r
.70157 .3068 m .70263 .30871 L .70316 .30789 L F
.796 .33 .129 r
.70157 .3068 m .70528 .30946 L .70263 .30871 L F
.364 .574 .92 r
.70577 .3106 m .70263 .30871 L .70528 .30946 L F
.756 .67 .766 r
.45753 .5314 m .46173 .53184 L .46014 .52819 L F
.697 .642 .791 r
.46014 .52819 m .46173 .53184 L .46405 .52881 L F
.374 .265 .6 r
.48364 .54353 m .48124 .54782 L .48062 .54494 L F
0 0 0 r
.56711 .40689 m .56604 .40893 L .56649 .40801 L F
.528 .22 .39 r
.50971 .49256 m .50628 .49501 L .50719 .49276 L F
.574 .281 .433 r
.53367 .47672 m .5363 .47877 L .53385 .47884 L F
.562 .857 .997 r
.33442 .63419 m .33464 .63526 L .33255 .63519 L F
0 0 .342 r
.33449 .63759 m .33464 .63526 L .33442 .63419 L F
.82 .752 .789 r
.53832 .40811 m .53898 .41149 L .53548 .41108 L F
.615 .618 .831 r
.54205 .41011 m .53898 .41149 L .53832 .40811 L F
.479 .109 .259 r
.30833 .57005 m .30686 .57279 L .30429 .57294 L F
.574 .208 .31 r
.31046 .57196 m .30833 .57005 L .31096 .57008 L F
.31046 .57196 m .30686 .57279 L .30833 .57005 L F
.721 .971 .93 r
.63418 .35841 m .63297 .36078 L .63467 .35902 L F
.92 .533 .141 r
.55855 .42779 m .56093 .43149 L .55696 .43115 L F
.618 .136 .088 r
.55696 .43115 m .56093 .43149 L .55951 .43302 L F
0 .039 .556 r
.56093 .43149 m .56169 .4321 L .55951 .43302 L F
.56093 .43149 m .56252 .43308 L .56169 .4321 L F
0 0 .53 r
.30025 .64167 m .302 .64414 L .30292 .64154 L F
0 0 0 r
.37483 .62623 m .37197 .62934 L .37347 .62788 L F
.37347 .62788 m .37197 .62934 L .37017 .63169 L F
.601 .942 .936 r
.63471 .38874 m .632 .3895 L .63459 .38837 L F
.358 .824 .754 r
.63717 .38752 m .63471 .38874 L .63459 .38837 L F
.63717 .38752 m .63865 .38716 L .63471 .38874 L F
.968 .646 .298 r
.40485 .54167 m .40385 .54347 L .40408 .54015 L F
.40485 .54167 m .40535 .54469 L .40385 .54347 L F
.85 .554 .488 r
.41409 .47345 m .41035 .47275 L .41132 .47077 L F
.844 .993 .745 r
.41341 .46983 m .41304 .4703 L .413 .47191 L F
.537 .839 .999 r
.41296 .47324 m .413 .47191 L .41035 .47275 L F
0 0 0 r
.41093 .47305 m .41035 .47275 L .41174 .47231 L F
.41093 .47305 m .41174 .47231 L .413 .47191 L F
.41035 .47275 m .40944 .47454 L .40712 .47542 L F
.41093 .47305 m .40944 .47454 L .41035 .47275 L F
.703 .985 .852 r
.41093 .47305 m .40803 .47518 L .40944 .47454 L F
.423 .078 .274 r
.41132 .47077 m .41035 .47275 L .40776 .47318 L F
.891 .519 .052 r
.40776 .47318 m .40677 .47236 L .40592 .46963 L F
0 0 0 r
.41035 .47275 m .40677 .47236 L .40776 .47318 L F
.41035 .47275 m .40712 .47542 L .40677 .47236 L F
.658 .568 .742 r
.40712 .47542 m .40488 .47644 L .404 .47468 L F
.541 .91 .955 r
.404 .47468 m .40576 .47275 L .40603 .47265 L F
.40488 .47394 m .40603 .47265 L .40677 .47236 L F
.404 .47468 m .40603 .47265 L .40488 .47394 L F
.579 .835 .994 r
.40592 .46963 m .40178 .46885 L .40442 .46806 L F
.026 0 0 r
.40592 .46963 m .40205 .4714 L .40178 .46885 L F
.40344 .47077 m .40456 .47073 L .40205 .4714 L F
.40592 .46963 m .40456 .47073 L .40344 .47077 L F
.927 .554 .28 r
.40592 .46963 m .40677 .47236 L .40456 .47073 L F
.843 .75 .76 r
.40637 .47226 m .40602 .47069 L .40456 .47073 L F
.40602 .47069 m .40565 .4691 L .40456 .47073 L F
.516 .316 .548 r
.40576 .47275 m .40456 .47073 L .40677 .47236 L F
.843 .75 .76 r
.407 .47278 m .40668 .47191 L .40637 .47226 L F
.77 .908 .935 r
.4083 .46862 m .40681 .4684 L .40702 .46735 L F
.40681 .4684 m .40442 .46806 L .40702 .46735 L F
.4083 .46862 m .40592 .46963 L .40442 .46806 L F
.604 .833 .449 r
.40456 .47073 m .40702 .46735 L .40442 .46806 L F
.781 .897 .49 r
.40702 .46735 m .40565 .4691 L .40654 .46748 L F
.40702 .46735 m .40654 .46748 L .40725 .4662 L F
.40702 .46735 m .40725 .4662 L .40762 .46553 L F
.604 .833 .449 r
.40456 .47073 m .40565 .4691 L .40702 .46735 L F
.843 .75 .76 r
.40668 .47191 m .40565 .4691 L .40637 .47226 L F
.658 .568 .742 r
.40712 .47542 m .404 .47468 L .40677 .47236 L F
0 0 0 r
.40944 .47454 m .40604 .4757 L .40712 .47542 L F
.40944 .47454 m .40803 .47518 L .40604 .4757 L F
.949 .639 .204 r
.40803 .47518 m .40662 .47367 L .40604 .4757 L F
.40662 .47367 m .40576 .47275 L .40585 .47365 L F
.40662 .47367 m .40585 .47365 L .40604 .4757 L F
.385 0 0 r
.41093 .47305 m .40932 .47372 L .40943 .47416 L F
.949 .639 .204 r
.40803 .47518 m .407 .47278 L .40576 .47275 L F
.40786 .47478 m .407 .47469 L .407 .47278 L F
.40803 .47518 m .407 .47469 L .40786 .47478 L F
.631 .264 .328 r
.404 .47468 m .40184 .475 L .40116 .47329 L F
.404 .47468 m .40184 .475 L .40116 .47329 L F
.541 .91 .955 r
.404 .47468 m .40228 .4744 L .40576 .47275 L F
.672 .634 .804 r
.40184 .475 m .40286 .48039 L .39859 .47907 L F
.598 .583 .807 r
.40286 .47754 m .40286 .48039 L .40184 .475 L F
.40286 .47754 m .40184 .475 L .40488 .47644 L F
.749 .606 .698 r
.404 .47468 m .40404 .47477 L .40184 .475 L F
.40404 .47477 m .40488 .47644 L .40372 .47589 L F
.40404 .47477 m .40372 .47589 L .40184 .475 L F
.235 .092 .473 r
.40604 .4757 m .40442 .47848 L .40318 .47773 L F
.40331 .47727 m .40318 .47773 L .40286 .47754 L F
.40536 .47613 m .40286 .47754 L .40488 .47644 L F
.40604 .4757 m .40479 .47642 L .40536 .47613 L F
.40479 .47642 m .40286 .47754 L .40536 .47613 L F
.326 .042 .32 r
.40442 .47848 m .40337 .48051 L .40286 .47754 L F
.914 .73 .641 r
.4029 .47739 m .40337 .48051 L .40442 .47848 L F
.40173 .47655 m .40222 .47773 L .4029 .47739 L F
0 0 0 r
.40337 .48051 m .40286 .48039 L .40286 .47754 L F
.914 .73 .641 r
.40222 .47773 m .40337 .48051 L .4029 .47739 L F
.235 .092 .473 r
.40604 .4757 m .40318 .47773 L .40331 .47727 L F
.432 .859 .941 r
.40184 .475 m .40228 .4744 L .404 .47468 L F
.799 .792 .846 r
.40173 .47655 m .40576 .47275 L .40228 .4744 L F
.40173 .47655 m .40604 .4757 L .40576 .47275 L F
.709 .572 .699 r
.407 .47469 m .4035 .47246 L .407 .47278 L F
.407 .47469 m .40392 .47569 L .4035 .47246 L F
.683 .975 .803 r
.4084 .47304 m .40636 .47463 L .407 .47469 L F
.40636 .47463 m .40598 .47492 L .407 .47469 L F
.385 0 0 r
.40855 .4748 m .407 .47469 L .40803 .47518 L F
.40932 .47372 m .4096 .47487 L .407 .47469 L F
.41093 .47305 m .41042 .47375 L .40932 .47372 L F
.41042 .47375 m .4096 .47487 L .40932 .47372 L F
.798 .879 .449 r
.4115 .47083 m .4101 .47381 L .41093 .47305 L F
.4101 .47381 m .4096 .47487 L .41093 .47305 L F
.844 .993 .745 r
.41304 .4703 m .41093 .47305 L .413 .47191 L F
.537 .839 .999 r
.41409 .47345 m .413 .47191 L .41296 .47324 L F
.867 .966 .86 r
.41511 .46947 m .413 .47191 L .41409 .47345 L F
.428 0 0 r
.44677 .48587 m .44383 .48511 L .44501 .48713 L F
.46 .886 .893 r
.58793 .35512 m .591 .35362 L .59037 .35392 L F
.58793 .35512 m .58603 .35503 L .591 .35362 L F
0 0 0 r
.55884 .40881 m .55798 .41185 L .55813 .4116 L F
.55798 .41185 m .55773 .41271 L .55798 .41202 L F
.55798 .41185 m .55798 .41202 L .55813 .4116 L F
.088 .646 .766 r
.55096 .4145 m .55688 .41441 L .55399 .41455 L F
.53 .462 .725 r
.55055 .41868 m .55151 .42138 L .55439 .41836 L F
.55348 .41929 m .55439 .41836 L .55539 .4197 L F
.55055 .41868 m .55439 .41836 L .55348 .41929 L F
.8 .607 .641 r
.54746 .42081 m .55151 .42138 L .55055 .41868 L F
.578 .28 .427 r
.55386 .41885 m .55425 .41895 L .55439 .41836 L F
.55348 .41929 m .55439 .41836 L .55336 .41944 L F
.914 .906 .504 r
.5547 .41888 m .55348 .41929 L .55539 .4197 L F
.627 .422 .586 r
.55439 .41836 m .5557 .41799 L .55539 .4197 L F
.593 .384 .567 r
.55539 .4197 m .55623 .41592 L .55529 .41958 L F
.55552 .41911 m .55674 .41493 L .55623 .41592 L F
.55539 .4197 m .55555 .41913 L .55552 .41911 L F
.55555 .41913 m .55674 .41493 L .55552 .41911 L F
.55555 .41913 m .55755 .41747 L .55688 .41441 L F
.55539 .4197 m .55578 .41929 L .55555 .41913 L F
.55578 .41929 m .55755 .41747 L .55555 .41913 L F
.627 .422 .586 r
.5557 .41799 m .55755 .41747 L .55578 .41929 L F
.5555 .4191 m .55578 .41929 L .55539 .4197 L F
.5557 .41799 m .55578 .41929 L .5555 .4191 L F
.313 .043 .334 r
.55542 .41906 m .55612 .41997 L .55671 .41995 L F
.55643 .41974 m .55671 .41995 L .55672 .41994 L F
.55542 .41906 m .55671 .41995 L .55643 .41974 L F
.55439 .41836 m .55478 .41872 L .55542 .41906 L F
.627 .422 .586 r
.55439 .41836 m .55542 .41906 L .5557 .41799 L F
.593 .384 .567 r
.55529 .41958 m .55623 .41592 L .5547 .41888 L F
.313 .043 .334 r
.55478 .41872 m .55612 .41997 L .55542 .41906 L F
.627 .422 .586 r
.5557 .41799 m .55672 .41994 L .55755 .41747 L F
.55542 .41906 m .55672 .41994 L .5557 .41799 L F
.313 .043 .334 r
.55439 .41836 m .5547 .41888 L .55478 .41871 L F
.55478 .41871 m .5547 .41888 L .55478 .41872 L F
.914 .906 .504 r
.55315 .41867 m .55055 .41868 L .55348 .41929 L F
.55096 .4145 m .55348 .41929 L .55426 .41837 L F
.567 .019 0 r
.54746 .42081 m .55005 .42236 L .55151 .42138 L F
.578 .28 .427 r
.55005 .42236 m .55439 .41836 L .55136 .42148 L F
.593 .384 .567 r
.5547 .41888 m .55602 .41617 L .55096 .4145 L F
.55602 .41617 m .55688 .41441 L .55633 .41442 L F
.55602 .41617 m .55633 .41442 L .55096 .4145 L F
.55674 .41493 m .55688 .41441 L .5547 .41888 L F
.313 .043 .334 r
.55439 .41836 m .55425 .41895 L .5547 .41888 L F
.55478 .41872 m .5547 .41888 L .55491 .41884 L F
.914 .906 .504 r
.55426 .41837 m .55369 .41905 L .5547 .41888 L F
.55369 .41905 m .55348 .41929 L .5547 .41888 L F
.313 .043 .334 r
.55491 .41884 m .55337 .42264 L .55612 .41997 L F
.55425 .41895 m .55337 .42264 L .55491 .41884 L F
.578 .28 .427 r
.55136 .42148 m .55348 .41929 L .55151 .42138 L F
.55005 .42236 m .55337 .42264 L .55425 .41895 L F
.55348 .41929 m .55336 .41944 L .55151 .42138 L F
.55005 .42236 m .55425 .41895 L .55386 .41885 L F
.914 .906 .504 r
.55096 .4145 m .55061 .418 L .55315 .41867 L F
.55061 .418 m .55055 .41868 L .55315 .41867 L F
.464 0 0 r
.55419 .41383 m .55624 .41458 L .55403 .41406 L F
0 0 0 r
.55096 .4145 m .55459 .41325 L .55419 .41383 L F
.814 .757 .8 r
.55389 .40988 m .55809 .41174 L .55096 .4145 L F
.55809 .41174 m .55798 .41209 L .55096 .4145 L F
.508 .318 .558 r
.55128 .41038 m .55096 .4145 L .54863 .41377 L F
.814 .757 .8 r
.55389 .40988 m .55096 .4145 L .55128 .41038 L F
0 0 0 r
.55096 .4145 m .55419 .41383 L .55087 .41394 L F
.464 0 0 r
.55419 .41383 m .55403 .41406 L .55247 .41368 L F
0 0 0 r
.55459 .41325 m .55798 .41209 L .55419 .41383 L F
.571 .825 .993 r
.55825 .41127 m .55984 .41229 L .55773 .41271 L F
0 0 0 r
.55798 .41209 m .55849 .41192 L .55798 .41214 L F
.55798 .41209 m .55798 .41214 L .55419 .41383 L F
.814 .757 .8 r
.55809 .41174 m .55849 .41192 L .55798 .41209 L F
0 0 0 r
.55832 .41096 m .55813 .4116 L .55825 .41127 L F
.55884 .40881 m .55813 .4116 L .55832 .41096 L F
0 0 .268 r
.56104 .40456 m .55884 .40881 L .56105 .40705 L F
.833 .78 .801 r
.55825 .41127 m .56105 .40705 L .55884 .40881 L F
.311 0 0 r
.70261 .2658 m .70586 .26553 L .70374 .26537 L F
.462 .867 .703 r
.27826 .62118 m .27928 .62021 L .28087 .61965 L F
.27826 .62118 m .27632 .62197 L .27928 .62021 L F
.539 .121 .197 r
.42249 .47687 m .4247 .47863 L .42497 .47639 L F
.42249 .47687 m .42046 .47896 L .4247 .47863 L F
.948 .6 .211 r
.39854 .5255 m .39766 .52669 L .39726 .52418 L F
.39854 .5255 m .39904 .52792 L .39766 .52669 L F
0 0 0 r
.32467 .55178 m .32174 .5545 L .32416 .55261 L F
.534 .317 .531 r
.32416 .55261 m .32622 .5505 L .32467 .55178 L F
.87 .433 .043 r
.38988 .51235 m .38917 .51342 L .38792 .51168 L F
.38988 .51235 m .39089 .51475 L .38917 .51342 L F
.013 .383 .845 r
.5821 .39369 m .58085 .39214 L .58144 .39454 L F
.743 .228 0 r
.58144 .39454 m .58359 .39497 L .5821 .39369 L F
.829 .658 .671 r
.55482 .43724 m .55179 .44036 L .55127 .43796 L F
0 0 .358 r
.55248 .43543 m .55127 .43796 L .55179 .44036 L F
.745 .806 .901 r
.57711 .46057 m .57849 .45643 L .57527 .46019 L F
.112 0 .197 r
.32064 .55677 m .32416 .55261 L .32174 .5545 L F
0 .208 .652 r
.26486 .62812 m .26695 .62955 L .26456 .62776 L F
.77 .323 .19 r
.26695 .62955 m .27069 .63187 L .26904 .63105 L F
.906 .572 .093 r
.5916 .41208 m .59091 .40877 L .58946 .40679 L F
.544 .295 .488 r
.49092 .51249 m .49054 .51492 L .48787 .51536 L F
.596 .418 .611 r
.49323 .51158 m .49054 .51492 L .49092 .51249 L F
.58 .49 .718 r
.60911 .37886 m .60663 .38222 L .60718 .38003 L F
.241 0 0 r
.34419 .4972 m .34835 .49784 L .3457 .49719 L F
0 .403 .697 r
.35045 .49861 m .3457 .49719 L .34835 .49784 L F
0 0 0 r
.62383 .42552 m .62259 .42691 L .62071 .42835 L F
.62587 .42422 m .62259 .42691 L .62383 .42552 L F
.897 .904 .823 r
.70101 .31844 m .69735 .31989 L .69928 .32085 L F
.615 .611 .823 r
.45572 .52537 m .45736 .52881 L .46014 .52819 L F
.569 .4 .612 r
.45736 .52881 m .45753 .5314 L .46014 .52819 L F
.992 .8 .547 r
.38147 .48956 m .3811 .49234 L .37965 .49111 L F
.824 .977 .681 r
.38367 .48651 m .38147 .48956 L .38214 .48767 L F
.819 .966 .648 r
.38147 .48956 m .37965 .49111 L .38214 .48767 L F
.642 .492 .664 r
.38337 .48898 m .38147 .48956 L .38367 .48651 L F
.731 .574 .678 r
.38337 .48898 m .3811 .49234 L .38147 .48956 L F
0 .187 .706 r
.62643 .40044 m .6263 .40269 L .62827 .40466 L F
.62 .653 .861 r
.41159 .49289 m .40979 .49424 L .40784 .49232 L F
.632 .682 .879 r
.35471 .68362 m .35208 .68792 L .35058 .68224 L F
.354 .02 .253 r
.35434 .68684 m .35208 .68792 L .35471 .68362 L F
.419 0 .046 r
.36019 .56097 m .35866 .5627 L .35567 .563 L F
.712 .868 .955 r
.35839 .55978 m .36019 .56097 L .36318 .55979 L F
0 0 0 r
.36078 .56144 m .36019 .56097 L .35839 .55978 L F
.36078 .56144 m .35866 .5627 L .36019 .56097 L F
.456 .778 .998 r
.30548 .63497 m .30812 .6346 L .30606 .63328 L F
0 .173 .697 r
.30548 .63497 m .3078 .63742 L .30812 .6346 L F
.718 .632 .761 r
.33356 .56677 m .33484 .57011 L .33743 .56754 L F
.621 .612 .82 r
.276 .51552 m .27942 .51748 L .27855 .51493 L F
.574 .604 .845 r
.27855 .51493 m .27942 .51748 L .28214 .51618 L F
.197 .254 .697 r
.31825 .64732 m .31908 .65138 L .31805 .64848 L F
.988 .726 .426 r
.6995 .30305 m .70091 .30472 L .70102 .30229 L F
.843 .789 .799 r
.35277 .51235 m .34842 .5143 L .34843 .51208 L F
.35277 .51235 m .34973 .51608 L .34842 .5143 L F
0 0 .312 r
.41134 .59308 m .41201 .59566 L .41212 .5941 L F
.41134 .59308 m .41212 .5941 L .41089 .59261 L F
0 0 0 r
.42015 .58997 m .42254 .5866 L .42256 .58931 L F
.753 .703 .805 r
.425 .58351 m .42254 .5866 L .42109 .58273 L F
.659 .56 .732 r
.425 .58351 m .42728 .58774 L .42254 .5866 L F
.759 .62 .705 r
.42728 .58774 m .42464 .58861 L .4235 .58683 L F
.42728 .58774 m .42563 .59034 L .42256 .58931 L F
.922 .976 .729 r
.42489 .58813 m .42563 .59034 L .42728 .58774 L F
.466 0 0 r
.42673 .59136 m .42844 .59213 L .42563 .59034 L F
.42673 .59136 m .42594 .59063 L .42489 .58813 L F
.42594 .59063 m .42563 .59034 L .42549 .58994 L F
.42594 .59063 m .42549 .58994 L .42489 .58813 L F
.759 .62 .705 r
.4235 .58683 m .42256 .58931 L .42254 .5866 L F
.42464 .58861 m .42256 .58931 L .4235 .58683 L F
.887 .991 .767 r
.28787 .63741 m .28732 .63933 L .28662 .63967 L F
0 .152 .673 r
.43491 .59168 m .43429 .59366 L .43616 .59564 L F
.738 .68 .795 r
.24854 .57775 m .2465 .58028 L .24483 .5771 L F
.416 .163 .419 r
.31315 .54754 m .31557 .5472 L .316 .54457 L F
.471 .241 .483 r
.31557 .5472 m .31843 .54386 L .316 .54457 L F
.981 .69 .332 r
.56305 .39855 m .56454 .40239 L .56322 .40116 L F
.56305 .39855 m .56454 .40239 L .56322 .40116 L F
.516 .364 .614 r
.48315 .52519 m .48394 .52804 L .48098 .52879 L F
.687 .52 .655 r
.48445 .53045 m .48098 .52879 L .48394 .52804 L F
.48445 .53045 m .48145 .53159 L .48098 .52879 L F
.332 0 0 r
.42384 .50074 m .42274 .50158 L .41999 .50138 L F
.61 .407 .581 r
.41999 .50138 m .41777 .50531 L .41769 .50277 L F
.839 .935 .56 r
.41817 .5034 m .41777 .50531 L .41937 .50248 L F
.41817 .5034 m .41937 .50248 L .41999 .50138 L F
.798 .988 .888 r
.41644 .50548 m .41777 .50531 L .41817 .5034 L F
.666 .954 .723 r
.41644 .50548 m .41705 .50556 L .41817 .5034 L F
.677 .721 .882 r
.41445 .50188 m .41644 .50548 L .41817 .5034 L F
.666 .954 .723 r
.41644 .50548 m .41664 .50418 L .41675 .50427 L F
.308 .124 .46 r
.41817 .5034 m .41703 .50545 L .41705 .50556 L F
.41817 .5034 m .41662 .5064 L .41777 .50531 L F
.886 .952 .602 r
.41637 .50663 m .41595 .50872 L .41777 .50531 L F
.666 .954 .723 r
.41705 .50556 m .4186 .50577 L .41817 .5034 L F
.41705 .50556 m .41703 .50545 L .4186 .50577 L F
.308 .124 .46 r
.41705 .50556 m .41637 .50663 L .41662 .5064 L F
.41703 .50545 m .41637 .50663 L .41705 .50556 L F
.41703 .50545 m .4186 .50577 L .41637 .50663 L F
.41817 .5034 m .4186 .50577 L .41703 .50545 L F
.666 .954 .723 r
.41703 .50545 m .41675 .50427 L .4186 .50577 L F
.41644 .50548 m .41675 .50427 L .41705 .50556 L F
.937 .564 .226 r
.41817 .5034 m .4186 .50577 L .41689 .50438 L F
.41817 .5034 m .41689 .50438 L .41664 .50418 L F
.379 0 0 r
.42274 .50158 m .41817 .5034 L .41999 .50138 L F
.42274 .50158 m .42103 .50309 L .41817 .5034 L F
.716 .648 .781 r
.42415 .49925 m .42147 .50255 L .42274 .50158 L F
.42147 .50255 m .42103 .50309 L .42274 .50158 L F
.332 0 0 r
.42409 .50069 m .42274 .50158 L .42384 .50074 L F
.541 .885 .641 r
.42481 .49976 m .42409 .50069 L .42613 .49873 L F
.42481 .49976 m .42274 .50158 L .42409 .50069 L F
.996 .786 .5 r
.32917 .56653 m .33027 .56687 L .3297 .56509 L F
.32917 .56653 m .33067 .56811 L .3297 .56509 L F
.32917 .56653 m .3297 .56509 L .32683 .56672 L F
.32917 .56653 m .3297 .56509 L .32683 .56672 L F
.747 .229 0 r
.32526 .56294 m .32917 .56653 L .32683 .56672 L F
.32526 .56294 m .32756 .56604 L .32917 .56653 L F
.931 .949 .777 r
.32917 .56653 m .33026 .5619 L .3302 .56518 L F
.32917 .56653 m .32756 .56604 L .33026 .5619 L F
.768 .452 .452 r
.3302 .56518 m .32759 .56603 L .32917 .56653 L F
.32759 .56603 m .32756 .56604 L .32917 .56653 L F
.996 .786 .5 r
.32917 .56653 m .33067 .56811 L .33027 .56687 L F
.708 .868 .958 r
.32917 .56653 m .33067 .56811 L .33356 .56677 L F
.32917 .56653 m .33067 .56811 L .33356 .56677 L F
0 0 0 r
.33243 .65675 m .33398 .65588 L .33005 .65789 L F
.374 .803 .626 r
.33622 .65455 m .33398 .65588 L .33243 .65675 L F
.497 .656 .931 r
.337 .65684 m .33398 .65588 L .33622 .65455 L F
.804 .576 .593 r
.37334 .54764 m .37553 .55097 L .37051 .5503 L F
.664 .545 .709 r
.37701 .54767 m .37553 .55097 L .37334 .54764 L F
.678 .768 .284 r
.62066 .36671 m .62225 .3627 L .62354 .3661 L F
.488 .235 .457 r
.62066 .36671 m .62373 .3689 L .61963 .36856 L F
.62066 .36671 m .62354 .3661 L .62373 .3689 L F
.907 .93 .817 r
.42796 .50258 m .42426 .50505 L .4274 .50142 L F
.698 .927 .967 r
.42796 .50258 m .429 .5001 L .43052 .50138 L F
.623 .137 .08 r
.30125 .6321 m .29951 .63363 L .30024 .63081 L F
.207 .226 .66 r
.22653 .5724 m .22723 .57648 L .22578 .57667 L F
.333 0 0 r
.45288 .59469 m .45446 .59332 L .45672 .59415 L F
.915 .87 .779 r
.68534 .29533 m .68225 .2978 L .68501 .29474 L F
.029 .601 .737 r
.43693 .52622 m .43515 .52615 L .43496 .5262 L F
.744 .363 .332 r
.43899 .52521 m .43515 .52615 L .43693 .52622 L F
.43899 .52521 m .43841 .52677 L .43515 .52615 L F
.463 .052 .173 r
.43841 .52677 m .43455 .52862 L .43515 .52615 L F
.9 .986 .771 r
.43455 .52862 m .43534 .52609 L .43515 .52615 L F
.676 .909 .575 r
.43515 .52615 m .43732 .52347 L .43364 .52392 L F
.43515 .52615 m .43568 .52499 L .43732 .52347 L F
.9 .986 .771 r
.43534 .52609 m .43568 .52499 L .43515 .52615 L F
.029 .601 .737 r
.43496 .5262 m .43515 .52615 L .43212 .52617 L F
.162 .701 .808 r
.26141 .51638 m .26568 .51623 L .26187 .51824 L F
.5 .488 .776 r
.38375 .48383 m .38367 .48651 L .38278 .48263 L F
.824 .977 .681 r
.38367 .48651 m .38214 .48767 L .38321 .48637 L F
.619 .952 .787 r
.38367 .48651 m .38321 .48637 L .38514 .48479 L F
.896 .947 .832 r
.60312 .45661 m .60194 .46015 L .60573 .45698 L F
.361 .56 .912 r
.27774 .61513 m .27906 .61581 L .2797 .61499 L F
.354 .823 .902 r
.62422 .35373 m .62083 .35463 L .62469 .35406 L F
.77 .991 .773 r
.62422 .35373 m .62469 .35406 L .62591 .35183 L F
.536 .352 .578 r
.62764 .3536 m .62501 .35708 L .62469 .35406 L F
.62764 .3536 m .62501 .35708 L .62469 .35406 L F
0 0 0 r
.42906 .47671 m .43108 .47288 L .42881 .4738 L F
.639 .759 .935 r
.28968 .53467 m .28738 .53587 L .28605 .53418 L F
.28968 .53467 m .28605 .53418 L .28889 .53388 L F
.64 .889 .985 r
.28889 .53388 m .28738 .53587 L .28968 .53467 L F
.615 .957 .861 r
.65265 .32594 m .65294 .32473 L .65475 .3243 L F
.65265 .32594 m .65088 .32617 L .65294 .32473 L F
.436 .15 .379 r
.34907 .57347 m .35172 .57317 L .35224 .57072 L F
.543 .246 .412 r
.35224 .57072 m .35453 .57274 L .35546 .57065 L F
.35453 .57274 m .35224 .57072 L .35312 .56798 L F
.35453 .57274 m .35172 .57317 L .35224 .57072 L F
.35224 .57072 m .35172 .57317 L .35453 .57274 L F
.932 .693 .553 r
.59714 .43272 m .60032 .43111 L .5986 .42933 L F
.54 .371 .6 r
.34486 .52486 m .34489 .52764 L .34748 .527 L F
0 0 0 r
.34581 .52446 m .34403 .52546 L .34486 .52486 L F
.34403 .52546 m .34276 .52617 L .34486 .52486 L F
.729 .791 .902 r
.34486 .52486 m .34366 .52133 L .345 .52476 L F
.34486 .52486 m .345 .52476 L .34519 .52526 L F
.44 .251 .527 r
.34907 .57347 m .34916 .57645 L .34655 .57706 L F
.496 .344 .603 r
.34916 .57645 m .34666 .57998 L .34655 .57706 L F
.62 .653 .861 r
.308 .64768 m .31159 .64744 L .3091 .64379 L F
.308 .64768 m .3091 .64379 L .30863 .64721 L F
.317 .801 .754 r
.3072 .64781 m .308 .64768 L .30863 .64721 L F
.113 0 .264 r
.3085 .64742 m .3072 .64781 L .30863 .64721 L F
.30678 .65036 m .3072 .64781 L .3085 .64742 L F
.854 .773 .771 r
.30412 .64859 m .30614 .64812 L .3072 .64781 L F
.30614 .64812 m .308 .64768 L .3072 .64781 L F
.543 .009 0 r
.33256 .62511 m .33711 .62539 L .33618 .62716 L F
.832 .9 .888 r
.39367 .67368 m .3941 .67653 L .39683 .67329 L F
.535 .246 .422 r
.52132 .48216 m .52064 .48542 L .51789 .48575 L F
.526 .246 .433 r
.52414 .48198 m .52064 .48542 L .52132 .48216 L F
.613 .932 .963 r
.63144 .34082 m .62887 .34217 L .62693 .34162 L F
.886 .858 .809 r
.33419 .61774 m .33565 .61945 L .33648 .61828 L F
.33419 .61774 m .33648 .61828 L .33827 .61575 L F
.33419 .61774 m .33827 .61575 L .33684 .61751 L F
.3 .763 .947 r
.33684 .61751 m .33202 .61723 L .33419 .61774 L F
.33202 .61723 m .33202 .61723 L .33419 .61774 L F
0 0 0 r
.33565 .61945 m .33691 .61939 L .33778 .61706 L F
.33565 .61945 m .33778 .61706 L .33814 .61594 L F
.777 .557 .601 r
.33937 .61548 m .33691 .61939 L .33827 .61575 L F
.34105 .61505 m .3378 .61846 L .33937 .61548 L F
.3378 .61846 m .33691 .61939 L .33937 .61548 L F
.415 0 0 r
.33628 .62028 m .33828 .6207 L .33565 .61945 L F
0 0 0 r
.33691 .61939 m .33565 .61945 L .33828 .6207 L F
.95 .734 .576 r
.33644 .6195 m .3368 .61954 L .33684 .61751 L F
.905 .637 .522 r
.33691 .61939 m .33828 .6207 L .33781 .61856 L F
.813 .693 .733 r
.33927 .61913 m .33828 .6207 L .33813 .61968 L F
.34102 .61829 m .33982 .61934 L .33927 .61913 L F
.33982 .61934 m .33828 .6207 L .33927 .61913 L F
.272 0 0 r
.33842 .61881 m .33951 .61922 L .33879 .61895 L F
.33789 .6186 m .3387 .61891 L .33842 .61881 L F
.33787 .61859 m .3387 .61891 L .33789 .6186 L F
0 0 .375 r
.33828 .6207 m .33811 .61957 L .33783 .61866 L F
.33782 .61864 m .33783 .61866 L .33781 .61856 L F
.33828 .6207 m .33783 .61866 L .33782 .61864 L F
.272 0 0 r
.33781 .61856 m .33787 .61859 L .33789 .6186 L F
.3387 .61891 m .33951 .61922 L .33842 .61881 L F
.813 .693 .733 r
.33864 .61909 m .33752 .61997 L .33748 .61948 L F
.272 0 0 r
.34347 .62078 m .34486 .62128 L .33951 .61922 L F
.33879 .61895 m .33951 .61922 L .33781 .61856 L F
.813 .693 .733 r
.34102 .61829 m .33748 .61948 L .33767 .61928 L F
.272 0 0 r
.34347 .62078 m .33951 .61922 L .33879 .61895 L F
.813 .693 .733 r
.33891 .619 m .33785 .61981 L .33864 .61909 L F
.34102 .61829 m .33927 .61913 L .33891 .619 L F
.33927 .61913 m .33785 .61981 L .33891 .619 L F
.33785 .61981 m .33752 .61997 L .33864 .61909 L F
.272 0 0 r
.34347 .62078 m .33879 .61895 L .33929 .62344 L F
.33879 .61895 m .33781 .61856 L .33811 .61957 L F
.33879 .61895 m .33811 .61957 L .33929 .62344 L F
.813 .693 .733 r
.33746 .61925 m .33752 .61997 L .33691 .61939 L F
.996 .777 .426 r
.33712 .61914 m .3372 .61959 L .33699 .61956 L F
.678 .94 .964 r
.33689 .61955 m .33723 .61979 L .33749 .61963 L F
.95 .734 .576 r
.33679 .62039 m .33703 .62044 L .33731 .61961 L F
.905 .637 .522 r
.33691 .61939 m .33781 .61856 L .33904 .61846 L F
.33691 .61939 m .33904 .61846 L .33746 .61925 L F
.889 .748 .7 r
.33748 .61948 m .33723 .61979 L .33724 .61951 L F
.272 0 0 r
.33781 .61856 m .33879 .61895 L .34102 .61829 L F
.777 .557 .601 r
.34105 .61505 m .33746 .61925 L .33691 .61939 L F
.889 .748 .7 r
.33746 .61925 m .33724 .61951 L .33731 .61724 L F
.33748 .61948 m .33724 .61951 L .33746 .61925 L F
0 0 .399 r
.33797 .61887 m .33801 .61893 L .33779 .61916 L F
.33781 .61907 m .33779 .61916 L .33748 .61948 L F
.33797 .61887 m .33779 .61916 L .33781 .61907 L F
.905 .637 .522 r
.33779 .61916 m .33904 .61846 L .34102 .61829 L F
.889 .748 .7 r
.33781 .61907 m .33748 .61948 L .33746 .61925 L F
.905 .637 .522 r
.33746 .61925 m .33781 .61907 L .33779 .61916 L F
.33781 .61907 m .33904 .61846 L .33779 .61916 L F
0 0 .399 r
.34105 .61505 m .33815 .6187 L .33812 .61869 L F
.889 .748 .7 r
.34105 .61505 m .33812 .61869 L .33731 .61724 L F
.33812 .61869 m .3374 .61842 L .33731 .61724 L F
.777 .557 .601 r
.34105 .61505 m .33779 .61916 L .33746 .61925 L F
.95 .734 .576 r
.33721 .61959 m .33731 .61961 L .33752 .619 L F
.33679 .62039 m .33731 .61961 L .33721 .61959 L F
.813 .693 .733 r
.33813 .61968 m .33828 .6207 L .33752 .61997 L F
.95 .734 .576 r
.33703 .62044 m .33828 .6207 L .33766 .61933 L F
0 0 .399 r
.33748 .61948 m .33761 .61943 L .33723 .61979 L F
.33761 .61943 m .33749 .61963 L .33723 .61979 L F
.813 .693 .733 r
.33767 .61928 m .33748 .61948 L .33747 .61934 L F
.95 .734 .576 r
.33703 .62044 m .33766 .61933 L .33752 .619 L F
0 0 .399 r
.33761 .61943 m .3382 .6192 L .33749 .61963 L F
.813 .693 .733 r
.34102 .61829 m .33747 .61934 L .33746 .61925 L F
0 0 .399 r
.33801 .61893 m .3382 .6192 L .33748 .61948 L F
.272 0 0 r
.33879 .61895 m .34486 .62128 L .34347 .62078 L F
.33951 .61922 m .34486 .62128 L .33879 .61895 L F
.33879 .61895 m .34347 .62078 L .34102 .61829 L F
.889 .748 .7 r
.33812 .61869 m .33781 .61907 L .3374 .61842 L F
.33781 .61907 m .33746 .61925 L .3374 .61842 L F
.777 .557 .601 r
.34105 .61505 m .34102 .61829 L .33779 .61916 L F
0 0 .399 r
.33812 .61869 m .33866 .61891 L .3382 .6192 L F
.33812 .61869 m .3382 .6192 L .33797 .61887 L F
.34105 .61505 m .33866 .61891 L .33815 .6187 L F
.34105 .61505 m .34148 .61589 L .34261 .61649 L F
.34148 .61589 m .34239 .61767 L .34261 .61649 L F
0 0 .45 r
.34261 .61649 m .34239 .61767 L .34352 .61696 L F
.326 0 0 r
.34261 .61649 m .34352 .61696 L .34341 .6169 L F
0 0 .399 r
.34105 .61505 m .34102 .61829 L .34239 .61767 L F
.34105 .61505 m .34261 .61649 L .33866 .61891 L F
.889 .748 .7 r
.33731 .61724 m .33723 .61979 L .33684 .61751 L F
.95 .734 .576 r
.33679 .62039 m .3369 .62017 L .33684 .61751 L F
.996 .777 .426 r
.33684 .61751 m .33712 .61914 L .33688 .61903 L F
.368 .799 .967 r
.33419 .61774 m .33202 .61723 L .33059 .6173 L F
.808 .575 .586 r
.33684 .61751 m .33241 .61977 L .33202 .61723 L F
.415 0 0 r
.33628 .62028 m .33565 .61945 L .33446 .62115 L F
.808 .575 .586 r
.33684 .61751 m .33644 .6195 L .33241 .61977 L F
.996 .777 .426 r
.33712 .61914 m .33708 .61927 L .33668 .61906 L F
.33712 .61914 m .33668 .61906 L .33669 .61895 L F
.95 .734 .576 r
.33628 .62028 m .3368 .61954 L .33644 .6195 L F
.464 .247 .499 r
.33655 .62025 m .33628 .62028 L .33644 .6195 L F
.33664 .61938 m .33644 .6195 L .33684 .61751 L F
.33655 .62025 m .33644 .6195 L .33664 .61938 L F
.996 .777 .426 r
.33708 .61927 m .33697 .61961 L .33689 .61955 L F
.33688 .61916 m .33689 .61955 L .33467 .61802 L F
.33708 .61927 m .33689 .61955 L .33688 .61916 L F
.95 .734 .576 r
.3369 .62017 m .33752 .619 L .33684 .61751 L F
.678 .94 .964 r
.33786 .61878 m .33673 .61944 L .33799 .61881 L F
.33664 .61938 m .33673 .61944 L .34124 .61681 L F
.34123 .61681 m .34124 .61681 L .34139 .61672 L F
.33664 .61938 m .34124 .61681 L .34123 .61681 L F
.464 .247 .499 r
.33691 .61761 m .33683 .61762 L .33684 .61751 L F
.678 .94 .964 r
.33673 .61944 m .3373 .61934 L .34261 .61649 L F
.33689 .61955 m .33749 .61963 L .34261 .61649 L F
.464 .247 .499 r
.33867 .61999 m .33683 .61762 L .33691 .61761 L F
.678 .94 .964 r
.33673 .61944 m .33689 .61955 L .3373 .61934 L F
.996 .777 .426 r
.33684 .61751 m .33688 .61903 L .33467 .61802 L F
0 0 .375 r
.33828 .6207 m .33929 .62344 L .33811 .61957 L F
.95 .734 .576 r
.33628 .62028 m .33679 .62039 L .3368 .61954 L F
.464 .247 .499 r
.33867 .61999 m .33655 .62025 L .33683 .61762 L F
.33776 .61876 m .33684 .61751 L .33467 .61802 L F
0 0 0 r
.33814 .61594 m .33778 .61706 L .33827 .61575 L F
.889 .748 .7 r
.34105 .61505 m .33684 .61751 L .33827 .61575 L F
.53 .482 .747 r
.33971 .61511 m .33927 .61717 L .33467 .61802 L F
.996 .777 .426 r
.33669 .61895 m .33668 .61906 L .33467 .61802 L F
.678 .94 .964 r
.33927 .61717 m .33664 .61938 L .34123 .61681 L F
.34139 .61672 m .33786 .61878 L .34261 .61649 L F
.33786 .61878 m .33799 .61881 L .34261 .61649 L F
.53 .482 .747 r
.33927 .61717 m .34155 .62014 L .33867 .61999 L F
.33971 .61511 m .33935 .61712 L .33927 .61717 L F
.678 .94 .964 r
.33467 .61802 m .33935 .61712 L .33971 .61511 L F
.33935 .61712 m .34261 .61649 L .33971 .61511 L F
.53 .482 .747 r
.33971 .61511 m .34022 .61651 L .33935 .61712 L F
.678 .94 .964 r
.33921 .61714 m .34123 .61681 L .34139 .61672 L F
.33467 .61802 m .33912 .6172 L .33921 .61714 L F
.33912 .6172 m .34123 .61681 L .33921 .61714 L F
.045 .172 .674 r
.34102 .61829 m .34347 .62078 L .34239 .61767 L F
.634 .388 .528 r
.34461 .61978 m .34852 .62162 L .34486 .62128 L F
.34461 .61978 m .34886 .61885 L .34852 .62162 L F
.523 .478 .748 r
.34239 .61767 m .34347 .62078 L .34536 .61955 L F
.57 .505 .743 r
.34368 .61907 m .34155 .62014 L .34022 .61651 L F
.34077 .61617 m .34022 .61651 L .33971 .61511 L F
.34368 .61907 m .34022 .61651 L .34077 .61617 L F
.53 .482 .747 r
.34022 .61651 m .34155 .62014 L .33927 .61717 L F
.678 .94 .964 r
.33467 .61802 m .33637 .61919 L .33927 .61717 L F
.33637 .61919 m .33664 .61938 L .33927 .61717 L F
.464 .247 .499 r
.33867 .61999 m .33776 .61876 L .33467 .61802 L F
.53 .482 .747 r
.33927 .61717 m .33867 .61999 L .33467 .61802 L F
.808 .575 .586 r
.33644 .6195 m .33628 .62028 L .33393 .61997 L F
.33644 .6195 m .33393 .61997 L .33241 .61977 L F
.326 0 0 r
.34261 .61649 m .34341 .6169 L .33971 .61511 L F
.048 0 .28 r
.33173 .58445 m .33508 .58177 L .33242 .58244 L F
.33173 .58445 m .33451 .58448 L .33508 .58177 L F
0 0 .104 r
.33173 .58445 m .33383 .58615 L .33451 .58448 L F
.33302 .58654 m .33192 .58754 L .33311 .58668 L F
.33173 .58445 m .33189 .58709 L .33302 .58654 L F
.33189 .58709 m .33192 .58754 L .33302 .58654 L F
.33342 .58581 m .33311 .58668 L .33383 .58615 L F
.347 .793 .957 r
.33264 .5865 m .33323 .58644 L .33383 .58615 L F
.33323 .58644 m .33663 .58611 L .33383 .58615 L F
.378 .513 .867 r
.33383 .58615 m .33323 .58659 L .33264 .5865 L F
.33323 .58659 m .33192 .58754 L .33264 .5865 L F
0 0 .104 r
.33173 .58445 m .33311 .58668 L .33324 .58631 L F
.33326 .58569 m .33324 .58631 L .33342 .58581 L F
.33173 .58445 m .33324 .58631 L .33326 .58569 L F
.409 .168 .434 r
.33323 .58659 m .3359 .58775 L .33621 .58706 L F
.33264 .5865 m .33322 .58672 L .33323 .58659 L F
.33322 .58672 m .3359 .58775 L .33323 .58659 L F
.33264 .5865 m .33621 .58706 L .33663 .58611 L F
.602 .305 .437 r
.33124 .58928 m .33213 .58945 L .33264 .5865 L F
.33213 .58945 m .33294 .58961 L .33275 .58768 L F
.33213 .58945 m .33275 .58768 L .33264 .5865 L F
.892 .515 .317 r
.54731 .4189 m .54549 .42029 L .54746 .42081 L F
.8 .607 .641 r
.54746 .42081 m .55055 .41868 L .54731 .4189 L F
.589 .275 .404 r
.31315 .54754 m .31573 .55001 L .31557 .5472 L F
.31315 .54754 m .31195 .55038 L .31573 .55001 L F
.635 .522 .707 r
.48516 .51858 m .48269 .52194 L .48243 .51913 L F
.925 .74 .632 r
.60325 .44408 m .60365 .44135 L .60189 .44016 L F
.52 .431 .695 r
.25191 .60885 m .25259 .61145 L .25017 .61059 L F
.856 .896 .864 r
.4384 .56023 m .44341 .55757 L .44163 .55525 L F
.778 .75 .828 r
.44326 .57703 m .44765 .57696 L .44632 .57358 L F
.789 .696 .762 r
.44326 .57703 m .44509 .58026 L .44765 .57696 L F
.683 .485 .613 r
.29681 .65153 m .30149 .65115 L .30122 .64818 L F
.785 .774 .267 r
.302 .64414 m .30122 .64818 L .30282 .64607 L F
.424 .502 .835 r
.30122 .64818 m .30412 .64859 L .30282 .64607 L F
.751 .785 .881 r
.30149 .65115 m .30412 .64859 L .30122 .64818 L F
.948 .955 .721 r
.37932 .61892 m .37744 .62255 L .37628 .62007 L F
.74 .899 .511 r
.38163 .61515 m .37932 .61892 L .37991 .61727 L F
.74 .989 .796 r
.37991 .61727 m .37932 .61892 L .37628 .62007 L F
0 0 .113 r
.57529 .43168 m .57645 .42702 L .57564 .42807 L F
0 0 0 r
.57529 .43168 m .57569 .43263 L .57599 .43025 L F
.57529 .43168 m .57387 .43395 L .57569 .43263 L F
.44845 .58284 m .44984 .58158 L .45105 .57907 L F
.478 .822 .536 r
.44845 .58284 m .44695 .58415 L .44984 .58158 L F
.858 .863 .414 r
.38339 .60872 m .38163 .61515 L .38128 .61508 L F
.801 .917 .528 r
.38128 .61508 m .38163 .61515 L .37991 .61727 L F
.456 .8 .998 r
.53608 .44661 m .53725 .44766 L .53324 .44709 L F
.53608 .44661 m .53725 .44766 L .53324 .44709 L F
.834 .702 .717 r
.41151 .47059 m .4083 .46862 L .41135 .46536 L F
.41151 .47059 m .41132 .47077 L .4083 .46862 L F
.77 .775 .857 r
.41389 .46631 m .41151 .47059 L .41135 .46536 L F
.466 0 0 r
.5403 .47634 m .54329 .47671 L .54362 .47694 L F
.271 0 .281 r
.54362 .47694 m .54329 .47671 L .54571 .47613 L F
.708 .171 0 r
.37822 .68717 m .37903 .68685 L .37817 .68558 L F
.37822 .68717 m .3809 .68867 L .37903 .68685 L F
.146 .664 .888 r
.39394 .4885 m .39693 .48862 L .39348 .48814 L F
.673 .764 .919 r
.39693 .48862 m .39472 .49047 L .39348 .48814 L F
0 .075 .611 r
.33905 .54225 m .33878 .54526 L .3398 .54272 L F
.33884 .54212 m .33883 .54233 L .33905 .54225 L F
.33883 .54233 m .33878 .54526 L .33905 .54225 L F
.3381 .54222 m .33878 .54526 L .33884 .54212 L F
0 .047 .557 r
.33795 .54156 m .3398 .54272 L .33965 .54198 L F
.372 .402 .762 r
.34038 .54324 m .3426 .54107 L .33965 .54198 L F
.34038 .54324 m .34338 .54509 L .3426 .54107 L F
.787 .689 .756 r
.3426 .54107 m .34338 .54509 L .34651 .54531 L F
.353 0 0 r
.34352 .54225 m .34246 .54294 L .33982 .54261 L F
.656 .155 .046 r
.34246 .54294 m .34019 .54261 L .33982 .54261 L F
0 0 0 r
.33982 .54261 m .33904 .54262 L .33959 .54204 L F
.437 0 0 r
.33953 .54202 m .33475 .54399 L .33679 .54296 L F
.33956 .54202 m .33475 .54399 L .33953 .54202 L F
0 .075 .611 r
.33795 .54156 m .3381 .54222 L .33884 .54212 L F
.832 .681 .695 r
.33788 .53751 m .33531 .54112 L .33795 .54156 L F
.105 .095 .561 r
.33796 .53762 m .33795 .54156 L .33947 .53969 L F
.33788 .53751 m .33788 .53766 L .33796 .53762 L F
.33788 .53766 m .33795 .54156 L .33796 .53762 L F
.932 .97 .735 r
.33597 .53895 m .33531 .54112 L .33788 .53751 L F
.105 .095 .561 r
.33788 .53751 m .33947 .53969 L .3396 .53682 L F
0 0 0 r
.33897 .53719 m .33756 .5383 L .33597 .53895 L F
.3396 .53682 m .33926 .53706 L .33897 .53719 L F
.33926 .53706 m .33756 .5383 L .33897 .53719 L F
0 .047 .557 r
.33795 .54156 m .33965 .54198 L .33947 .53969 L F
.632 .472 .648 r
.33965 .54198 m .33679 .54296 L .33597 .53895 L F
.437 0 0 r
.33965 .54198 m .33759 .54416 L .33475 .54399 L F
.656 .155 .046 r
.34019 .54261 m .33784 .54227 L .33982 .54261 L F
0 0 0 r
.33982 .54261 m .33759 .54416 L .33904 .54262 L F
.33966 .54202 m .33959 .54204 L .33965 .54198 L F
.33982 .54261 m .33959 .54204 L .33966 .54202 L F
.437 0 0 r
.33965 .54198 m .33956 .54202 L .33953 .54202 L F
.406 .518 .859 r
.33878 .54526 m .34038 .54324 L .3398 .54272 L F
.983 .729 .467 r
.35786 .52695 m .35769 .52988 L .35959 .52846 L F
.464 .754 .992 r
.35786 .52695 m .35959 .52846 L .36039 .5267 L F
.134 0 0 r
.35959 .52846 m .36027 .52937 L .36039 .5267 L F
.35959 .52846 m .35769 .52988 L .36027 .52937 L F
.97 .733 .303 r
.44102 .54986 m .44186 .55374 L .44274 .55129 L F
.235 .311 .738 r
.22019 .58328 m .22165 .58141 L .21848 .57945 L F
.22019 .58328 m .22155 .58365 L .22165 .58141 L F
.252 .29 .708 r
.22019 .58328 m .22248 .5854 L .22155 .58365 L F
.944 .6 .189 r
.60343 .40881 m .60263 .41001 L .60212 .40743 L F
.60343 .40881 m .60391 .41121 L .60263 .41001 L F
.216 .37 .803 r
.34017 .68734 m .34131 .68935 L .34286 .68934 L F
.44 .488 .813 r
.43915 .49661 m .43745 .49922 L .43572 .49806 L F
.43915 .49661 m .43993 .49923 L .43745 .49922 L F
.494 .445 .731 r
.59981 .36607 m .59853 .36821 L .59725 .3674 L F
.59981 .36607 m .60264 .37101 L .59853 .36821 L F
.42 .078 .276 r
.36635 .57935 m .36306 .582 L .36402 .57989 L F
.77 .854 .408 r
.69969 .28704 m .699 .28933 L .70049 .28593 L F
.775 .986 .74 r
.70049 .28593 m .70331 .28281 L .70175 .28338 L F
.68 .839 .415 r
.69969 .28704 m .70049 .28593 L .70175 .28338 L F
.396 .487 .835 r
.37218 .60318 m .3751 .60434 L .37398 .60142 L F
.937 .777 .309 r
.41111 .58596 m .41064 .58511 L .41142 .58337 L F
.994 .866 .592 r
.41125 .57951 m .41142 .58337 L .41123 .58246 L F
.871 .802 .314 r
.41142 .58337 m .41064 .58511 L .41123 .58246 L F
.779 .516 .537 r
.36922 .68319 m .37229 .68025 L .3695 .68028 L F
0 0 0 r
.24402 .53056 m .24324 .53286 L .24203 .53455 L F
.24324 .53286 m .24132 .53653 L .24203 .53455 L F
.117 .196 .671 r
.31282 .62169 m .31428 .62132 L .31369 .61994 L F
0 0 0 r
.31048 .62381 m .31428 .62132 L .31282 .62169 L F
.993 .744 .4 r
.43532 .55797 m .43402 .55811 L .43413 .5575 L F
.639 .094 0 r
.43666 .5585 m .43532 .55797 L .43464 .55706 L F
.413 .342 .668 r
.43249 .55723 m .43464 .55706 L .43449 .55299 L F
.993 .744 .4 r
.43532 .55797 m .43446 .55564 L .43464 .55706 L F
.43532 .55797 m .43413 .5575 L .43446 .55564 L F
.639 .094 0 r
.43673 .55854 m .43532 .55797 L .43666 .5585 L F
.43673 .55854 m .4384 .56023 L .43532 .55797 L F
.669 .587 .755 r
.44989 .49564 m .45203 .49788 L .45229 .49617 L F
.935 .846 .73 r
.45229 .49617 m .45203 .49788 L .45045 .49585 L F
.391 .843 .915 r
.44629 .49625 m .44989 .49564 L .44908 .49548 L F
.743 .487 .544 r
.44908 .49548 m .44927 .49823 L .44492 .4974 L F
.44927 .49823 m .44932 .49909 L .44873 .49886 L F
.44927 .49823 m .44873 .49886 L .44492 .4974 L F
.857 .603 .554 r
.45203 .49788 m .44865 .50025 L .44968 .49773 L F
.45084 .49635 m .44968 .49773 L .45045 .49585 L F
.45203 .49788 m .44968 .49773 L .45084 .49635 L F
.45203 .49788 m .45007 .50136 L .44865 .50025 L F
.434 .626 .934 r
.70598 .2793 m .70151 .27678 L .70498 .27718 L F
.828 .982 .698 r
.70331 .28281 m .70598 .2793 L .70422 .28025 L F
.418 .633 .944 r
.70498 .27718 m .70598 .2793 L .70735 .2771 L F
.702 .96 .704 r
.70422 .28025 m .70598 .2793 L .70735 .2771 L F
.771 .942 .601 r
.73603 .32931 m .73517 .33138 L .73729 .32832 L F
.747 .738 .844 r
.48373 .5314 m .48145 .53159 L .48445 .53045 L F
.348 .465 .837 r
.48466 .53394 m .48145 .53159 L .48373 .5314 L F
.485 .377 .656 r
.48657 .52774 m .48373 .5314 L .48445 .53045 L F
.48657 .52774 m .48715 .53076 L .48373 .5314 L F
.289 .074 .403 r
.48715 .53076 m .48466 .53394 L .48373 .5314 L F
.357 .645 .964 r
.4236 .48307 m .42687 .48331 L .42475 .48156 L F
.783 .769 .84 r
.42687 .48331 m .4236 .48307 L .42475 .48156 L F
.42687 .48331 m .42109 .48375 L .4236 .48307 L F
.483 .883 .953 r
.61529 .43495 m .61719 .4335 L .61416 .43469 L F
.778 .467 0 r
.41056 .57693 m .41049 .57787 L .41026 .57522 L F
.41056 .57693 m .41125 .57951 L .41049 .57787 L F
.827 .684 .705 r
.43886 .54188 m .44301 .54123 L .44213 .54088 L F
.43886 .54188 m .4409 .54428 L .44301 .54123 L F
.968 .926 .608 r
.44294 .53803 m .44213 .54088 L .44301 .54123 L F
.973 .671 .293 r
.41039 .56334 m .41196 .5672 L .41067 .56604 L F
.989 .722 .404 r
.41196 .5672 m .41049 .56894 L .41067 .56604 L F
.41196 .5672 m .41195 .57003 L .41049 .56894 L F
0 0 0 r
.66333 .3178 m .66571 .31637 L .66677 .31551 L F
.515 .846 .56 r
.66677 .31551 m .66852 .31378 L .669 .31405 L F
.66677 .31551 m .66571 .31637 L .66852 .31378 L F
0 0 0 r
.32367 .6022 m .3273 .59916 L .32518 .60046 L F
.678 .786 .317 r
.70944 .33238 m .70842 .33486 L .71025 .33072 L F
0 0 0 r
.71025 .33072 m .71358 .32858 L .71249 .32951 L F
.71025 .33072 m .71249 .32951 L .70944 .33238 L F
.216 .338 .774 r
.32265 .54508 m .32375 .54296 L .32185 .54399 L F
.3232 .5454 m .32524 .54662 L .32437 .54447 L F
.493 .511 .804 r
.32375 .54296 m .32524 .54662 L .3238 .54484 L F
.32375 .54296 m .3238 .54484 L .32573 .54344 L F
.501 .902 .781 r
.3238 .54484 m .32406 .5439 L .3256 .54348 L F
.32488 .54406 m .3256 .54348 L .32573 .54344 L F
.3238 .54484 m .3256 .54348 L .32488 .54406 L F
.216 .338 .774 r
.32265 .54508 m .3232 .5454 L .32375 .54296 L F
.3232 .5454 m .32437 .54447 L .32375 .54296 L F
0 0 .505 r
.42945 .57172 m .4287 .57124 L .42862 .57077 L F
.788 .78 .845 r
.34842 .5143 m .34973 .51608 L .34744 .51535 L F
0 0 0 r
.71249 .32951 m .71358 .32858 L .71555 .32698 L F
.795 .915 .921 r
.46556 .44399 m .46098 .44539 L .46422 .44312 L F
.694 .926 .968 r
.46784 .44272 m .46556 .44399 L .46422 .44312 L F
.467 .257 .509 r
.42256 .58931 m .42235 .59203 L .42015 .58997 L F
.121 0 0 r
.34487 .68139 m .34259 .68293 L .34448 .68219 L F
.54 .541 .805 r
.34823 .68126 m .34601 .68332 L .34487 .68139 L F
0 0 0 r
.34682 .68136 m .34487 .68139 L .34448 .68219 L F
.34682 .68136 m .34823 .68126 L .34487 .68139 L F
.614 .115 0 r
.28746 .66071 m .28776 .66143 L .28601 .65976 L F
0 .086 .614 r
.28601 .65976 m .28776 .66143 L .28731 .66089 L F
.53 .09 .147 r
.28413 .65813 m .28724 .65776 L .28601 .65976 L F
.937 .907 .767 r
.28973 .65611 m .28601 .65976 L .28724 .65776 L F
.28973 .65611 m .28746 .66071 L .28601 .65976 L F
0 .086 .614 r
.28601 .65976 m .28731 .66089 L .28551 .65871 L F
.53 .09 .147 r
.28228 .65835 m .28413 .65813 L .28601 .65976 L F
.76 .805 .889 r
.41618 .47076 m .42123 .4706 L .41971 .46988 L F
.786 .996 .788 r
.42205 .46854 m .42123 .4706 L .42396 .46788 L F
.688 .93 .968 r
.42205 .46854 m .41971 .46988 L .42123 .4706 L F
.628 .535 .73 r
.37986 .48163 m .38278 .48263 L .38186 .47936 L F
.769 .97 .683 r
.34793 .64528 m .34581 .64792 L .3461 .64657 L F
0 0 .51 r
.3461 .64657 m .34581 .64792 L .34774 .65151 L F
.605 .446 .639 r
.24247 .60952 m .24274 .61222 L .24534 .60894 L F
.551 .918 .747 r
.27326 .51901 m .27361 .51939 L .27545 .51738 L F
.27326 .51901 m .27145 .52036 L .27361 .51939 L F
0 0 .427 r
.61169 .38993 m .61121 .38697 L .6104 .3877 L F
.887 .555 .058 r
.61179 .39158 m .61169 .38993 L .6104 .3877 L F
.61179 .39158 m .6104 .3877 L .6097 .3911 L F
.979 .904 .573 r
.60865 .38915 m .6097 .3911 L .6104 .3877 L F
0 0 0 r
.60907 .38892 m .6104 .3877 L .61298 .38671 L F
.60865 .38915 m .6104 .3877 L .60907 .38892 L F
0 0 .427 r
.61121 .38697 m .61094 .38537 L .6104 .3877 L F
.513 .11 .214 r
.61465 .39117 m .61169 .38993 L .61179 .39158 L F
.669 .9 .978 r
.73473 .33038 m .73517 .33138 L .73603 .32931 L F
.98 .763 .538 r
.23882 .61341 m .24079 .61591 L .23991 .61831 L F
.528 .006 0 r
.242 .62015 m .23991 .61831 L .24079 .61591 L F
.593 .505 .725 r
.24408 .61877 m .242 .62015 L .24079 .61591 L F
.954 .932 .595 r
.39433 .59871 m .39602 .59687 L .39513 .59463 L F
.39433 .59871 m .39499 .59934 L .39602 .59687 L F
.839 .994 .846 r
.74149 .31498 m .73956 .31673 L .73763 .31643 L F
.7432 .31434 m .73956 .31673 L .74149 .31498 L F
0 .484 .699 r
.73763 .31643 m .73956 .31673 L .73714 .31636 L F
.934 .968 .702 r
.73842 .31776 m .73956 .31673 L .73946 .31463 L F
.947 .652 .204 r
.73768 .31999 m .73861 .32083 L .73854 .32064 L F
.73768 .31999 m .73854 .32064 L .73714 .31636 L F
.921 .976 .75 r
.73666 .31923 m .73768 .31999 L .73811 .31693 L F
.73579 .32059 m .73768 .31999 L .73666 .31923 L F
.934 .968 .702 r
.73768 .31999 m .73956 .31673 L .73842 .31776 L F
.274 .137 .505 r
.36002 .55026 m .36045 .55333 L .35805 .55424 L F
.342 .142 .458 r
.36043 .55546 m .35805 .55424 L .36045 .55333 L F
.36043 .55546 m .35806 .55703 L .35805 .55424 L F
.35805 .55424 m .35806 .55703 L .36043 .55546 L F
.53 .917 .919 r
.67185 .32456 m .67486 .32333 L .67362 .32307 L F
.53 .922 .865 r
.67123 .32435 m .67185 .32456 L .67362 .32307 L F
.631 .773 .949 r
.27211 .57685 m .26936 .57808 L .26715 .57567 L F
.706 .826 .379 r
.70742 .33681 m .70842 .33486 L .70944 .33238 L F
.836 .449 0 r
.39904 .52792 m .40096 .53156 L .39988 .53018 L F
.919 .523 .176 r
.40243 .53418 m .39988 .53018 L .40096 .53156 L F
.636 .152 .087 r
.42497 .47639 m .42741 .47817 L .42906 .47671 L F
0 0 0 r
.42906 .47671 m .42997 .47511 L .43108 .47288 L F
.587 .389 .58 r
.42741 .47817 m .42997 .47511 L .42906 .47671 L F
.54 .297 .496 r
.32233 .52836 m .32461 .53015 L .32488 .52921 L F
.32233 .52836 m .32177 .53225 L .32461 .53015 L F
.65 .861 .48 r
.3419 .57059 m .33954 .57397 L .34009 .57302 L F
0 0 0 r
.33954 .57397 m .33964 .57494 L .34009 .57302 L F
.33954 .57397 m .3384 .57539 L .33964 .57494 L F
.659 .492 .647 r
.33005 .65789 m .32842 .65957 L .3262 .65867 L F
.33005 .65789 m .33092 .66101 L .32842 .65957 L F
.762 .785 .871 r
.3262 .65867 m .32842 .65957 L .32417 .66112 L F
.4 0 .114 r
.32417 .66112 m .32842 .65957 L .32683 .661 L F
.437 0 0 r
.32842 .65957 m .32928 .66026 L .32683 .661 L F
.32842 .65957 m .33092 .66101 L .32928 .66026 L F
.659 .492 .647 r
.33005 .65789 m .3262 .65867 L .32928 .66026 L F
.737 .789 .895 r
.33208 .65695 m .33005 .65789 L .32928 .66026 L F
.33208 .65695 m .33243 .65675 L .33005 .65789 L F
.105 0 .314 r
.47917 .55732 m .47979 .5594 L .47751 .56058 L F
0 0 .043 r
.47979 .5594 m .47929 .56286 L .47751 .56058 L F
0 .022 .594 r
.47929 .56286 m .47925 .56306 L .47751 .56058 L F
.732 .987 .793 r
.42349 .46669 m .42396 .46788 L .42619 .46657 L F
.42349 .46669 m .42205 .46854 L .42396 .46788 L F
0 .191 .641 r
.26299 .62676 m .26486 .62812 L .26456 .62776 L F
.754 .738 .837 r
.34895 .68555 m .34732 .68724 L .34601 .68332 L F
.778 .895 .926 r
.59457 .35923 m .59581 .3607 L .59817 .3585 L F
.54 .541 .805 r
.34823 .68126 m .34895 .68555 L .34601 .68332 L F
.751 .733 .836 r
.42073 .45748 m .4223 .46062 L .41818 .46002 L F
.795 .679 .736 r
.4223 .46062 m .41812 .46269 L .41818 .46002 L F
.4223 .46062 m .42009 .46435 L .41812 .46269 L F
.815 .833 .864 r
.42328 .45628 m .4223 .46062 L .42073 .45748 L F
.42328 .45628 m .42507 .45783 L .4223 .46062 L F
.78 .948 .93 r
.64695 .398 m .64783 .39912 L .65 .39712 L F
.98 .825 .618 r
.61305 .4019 m .61453 .40229 L .6139 .39794 L F
.897 .481 .178 r
.61351 .40351 m .61453 .40229 L .61305 .4019 L F
.496 0 0 r
.61919 .40436 m .61453 .40229 L .61351 .40351 L F
.163 .584 .935 r
.61995 .40413 m .61453 .40229 L .61919 .40436 L F
.745 .648 .089 r
.42689 .56351 m .42667 .56554 L .42675 .5659 L F
0 0 .204 r
.42667 .56554 m .42764 .56892 L .42675 .5659 L F
.765 .932 .579 r
.426 .49627 m .42815 .49254 L .42933 .49393 L F
.303 .396 .793 r
.43029 .49083 m .42933 .49393 L .42815 .49254 L F
.43029 .49083 m .43201 .4951 L .42933 .49393 L F
0 0 0 r
.42445 .54081 m .42293 .54448 L .42289 .54141 L F
.651 .293 0 r
.6139 .39794 m .6136 .39725 L .61207 .39393 L F
.375 .668 .972 r
.63001 .41061 m .62762 .41061 L .6254 .40861 L F
0 0 0 r
.35546 .57065 m .35453 .57274 L .35705 .56988 L F
.193 .167 .599 r
.47949 .55375 m .48144 .55586 L .47917 .55732 L F
0 0 .318 r
.48078 .55833 m .47917 .55732 L .48144 .55586 L F
.48078 .55833 m .47979 .5594 L .47917 .55732 L F
.86 .628 .586 r
.55755 .41747 m .56075 .41532 L .55688 .41441 L F
.55755 .41747 m .5607 .41804 L .56075 .41532 L F
.772 .7 .784 r
.55688 .41441 m .56075 .41532 L .55984 .41229 L F
.623 .958 .905 r
.68284 .37595 m .68653 .37416 L .68456 .37407 L F
.588 .944 .905 r
.68456 .37407 m .68653 .37416 L .68883 .37278 L F
.719 .947 .954 r
.45386 .47707 m .45324 .47941 L .45547 .47629 L F
.45386 .47707 m .45166 .47814 L .45324 .47941 L F
.495 .357 .622 r
.45324 .47941 m .45585 .47897 L .45547 .47629 L F
.647 .525 .701 r
.45296 .48214 m .45585 .47897 L .45324 .47941 L F
0 0 0 r
.30917 .62488 m .30674 .62576 L .30446 .62677 L F
.712 .639 .774 r
.52453 .39968 m .52722 .40399 L .52226 .40379 L F
.295 0 .059 r
.52299 .40717 m .5275 .40388 L .52482 .40591 L F
.52353 .40676 m .5275 .40388 L .52299 .40717 L F
.52267 .40739 m .52563 .40715 L .52676 .40535 L F
.619 .694 .897 r
.5263 .40692 m .52603 .40782 L .52563 .40715 L F
.295 0 .059 r
.52563 .40715 m .52588 .40713 L .52592 .40705 L F
.52563 .40715 m .52592 .40705 L .52676 .40535 L F
.52353 .40676 m .52712 .40465 L .52686 .40434 L F
.712 .639 .774 r
.52722 .40399 m .52619 .40477 L .52226 .40379 L F
.075 0 0 r
.52695 .40497 m .52999 .40411 L .5275 .40388 L F
.52767 .40514 m .52786 .40506 L .52695 .40497 L F
.52786 .40506 m .52999 .40411 L .52747 .40482 L F
.52786 .40506 m .52747 .40482 L .52695 .40497 L F
.52905 .40481 m .52999 .40411 L .52851 .40477 L F
.52807 .40504 m .52851 .40477 L .52767 .40514 L F
.52905 .40481 m .52851 .40477 L .52807 .40504 L F
.295 0 .059 r
.52686 .40434 m .52712 .40465 L .5275 .40388 L F
.507 .285 .512 r
.52999 .40411 m .52996 .40169 L .5275 .40388 L F
0 .23 .748 r
.52695 .40153 m .52796 .40512 L .52712 .40378 L F
.52622 .40097 m .52712 .40378 L .52453 .39968 L F
.52695 .40153 m .52712 .40378 L .52622 .40097 L F
.52796 .40512 m .5279 .40508 L .52453 .39968 L F
.825 .882 .885 r
.52226 .40379 m .52322 .39958 L .52453 .39968 L F
.52322 .39958 m .52328 .39933 L .52334 .39934 L F
.52322 .39958 m .52334 .39934 L .52453 .39968 L F
.029 .512 .879 r
.52005 .40209 m .52005 .40223 L .5196 .40175 L F
.52226 .40379 m .52005 .40223 L .52005 .40209 L F
.825 .882 .885 r
.52226 .40379 m .5196 .40175 L .52328 .39933 L F
.029 .512 .879 r
.52226 .40379 m .5234 .40406 L .52005 .40223 L F
.958 .907 .727 r
.52005 .40589 m .52005 .40223 L .5215 .40302 L F
.51953 .40691 m .52005 .40223 L .52005 .40589 L F
.385 .357 .704 r
.52226 .40379 m .52267 .40739 L .5234 .40406 L F
.5234 .40406 m .52267 .40739 L .52226 .40379 L F
.958 .907 .727 r
.51957 .40688 m .5215 .40302 L .5234 .40406 L F
.51953 .40691 m .5215 .40302 L .51957 .40688 L F
.571 .873 .573 r
.52589 .39994 m .52851 .39717 L .52577 .3987 L F
0 .237 .748 r
.52577 .3987 m .52597 .40078 L .52453 .39968 L F
.542 .539 .801 r
.52851 .39717 m .52695 .40153 L .52615 .39961 L F
.52851 .39717 m .52615 .39961 L .52577 .3987 L F
0 .237 .748 r
.52577 .3987 m .52615 .39961 L .52589 .39994 L F
.571 .873 .573 r
.52558 .40027 m .52589 .39994 L .52577 .3987 L F
.69 .183 .028 r
.52328 .39933 m .52558 .40027 L .52569 .39931 L F
.52552 .39876 m .52569 .39931 L .52577 .3987 L F
0 .237 .748 r
.52577 .3987 m .52453 .39968 L .52328 .39933 L F
.69 .183 .028 r
.52328 .39933 m .52569 .39931 L .52552 .39876 L F
.454 0 0 r
.52264 .39803 m .52698 .39847 L .52474 .39996 L F
.797 .594 .627 r
.5255 .3993 m .52628 .39892 L .52698 .39847 L F
.571 .873 .573 r
.52589 .39994 m .52717 .39831 L .52851 .39717 L F
.52558 .40027 m .52717 .39831 L .52589 .39994 L F
.891 .945 .838 r
.53238 .39489 m .52974 .39828 L .52851 .39717 L F
.987 .724 .354 r
.52974 .39828 m .52956 .40083 L .52851 .39717 L F
.542 .539 .801 r
.52851 .39717 m .52956 .40083 L .52695 .40153 L F
.797 .594 .627 r
.52628 .39892 m .52965 .39728 L .52698 .39847 L F
.571 .873 .573 r
.52711 .39839 m .52698 .39847 L .52717 .39831 L F
.52593 .39984 m .52698 .39847 L .52711 .39839 L F
.52558 .40027 m .52586 .39991 L .52593 .39984 L F
.52586 .39991 m .52698 .39847 L .52593 .39984 L F
0 .237 .748 r
.52589 .39994 m .52695 .40153 L .52597 .40078 L F
.52615 .39961 m .52695 .40153 L .52589 .39994 L F
.712 .639 .774 r
.52779 .4049 m .5279 .40508 L .5274 .40507 L F
.5279 .40508 m .52767 .40514 L .5274 .40507 L F
.5279 .40508 m .52799 .40522 L .52767 .40514 L F
.385 .357 .704 r
.52773 .40515 m .52767 .40514 L .52799 .40522 L F
.075 0 0 r
.52815 .40549 m .52773 .40515 L .52695 .40497 L F
.385 .357 .704 r
.52748 .40509 m .5274 .40507 L .52767 .40514 L F
.52748 .40509 m .52767 .40514 L .52773 .40515 L F
.52748 .40509 m .52773 .40515 L .52758 .40521 L F
.52773 .40515 m .52799 .40522 L .52781 .40521 L F
.52773 .40515 m .52781 .40521 L .52758 .40521 L F
.075 0 0 r
.52593 .40702 m .52815 .40549 L .52695 .40497 L F
.52592 .40705 m .52596 .40702 L .52593 .40702 L F
.52596 .40702 m .52815 .40549 L .52593 .40702 L F
.619 .694 .897 r
.52628 .40699 m .52838 .40699 L .52603 .40782 L F
.075 0 0 r
.52611 .40702 m .52815 .40549 L .52592 .40705 L F
.385 .357 .704 r
.5234 .40406 m .52226 .40379 L .5274 .40507 L F
.5234 .40406 m .5274 .40507 L .52748 .40509 L F
.295 0 .059 r
.52353 .40676 m .52676 .40535 L .52695 .40497 L F
.52668 .4049 m .52695 .40497 L .52712 .40465 L F
.52353 .40676 m .52695 .40497 L .52668 .4049 L F
.385 .357 .704 r
.5234 .40406 m .52748 .40509 L .52472 .40512 L F
.52429 .40499 m .52472 .40512 L .52442 .40513 L F
.5234 .40406 m .52472 .40512 L .52429 .40499 L F
.075 0 0 r
.52613 .407 m .52806 .40628 L .52999 .40411 L F
.605 .31 .442 r
.52999 .40411 m .53011 .40715 L .5332 .4043 L F
0 0 0 r
.52999 .40411 m .53088 .4047 L .53011 .40715 L F
.751 .76 .861 r
.5304 .40514 m .52838 .40699 L .52806 .40628 L F
.075 0 0 r
.52806 .40628 m .52887 .40597 L .52895 .40584 L F
.52806 .40628 m .52895 .40584 L .52999 .40411 L F
.385 .357 .704 r
.52748 .40509 m .52758 .40521 L .52442 .40513 L F
.712 .639 .774 r
.52722 .40399 m .52779 .4049 L .52619 .40477 L F
.52779 .4049 m .5274 .40507 L .52619 .40477 L F
.91 .914 .809 r
.52695 .40153 m .52442 .40513 L .52781 .40521 L F
.751 .76 .861 r
.52758 .40424 m .5276 .40432 L .5271 .40418 L F
.91 .914 .809 r
.52695 .40153 m .52781 .40521 L .52796 .40512 L F
0 0 0 r
.52999 .40411 m .52895 .40584 L .53088 .4047 L F
.075 0 0 r
.52815 .40549 m .52839 .40531 L .52773 .40515 L F
0 .23 .748 r
.52796 .40512 m .52799 .40522 L .5279 .40508 L F
.91 .914 .809 r
.52796 .40512 m .52781 .40521 L .52799 .40522 L F
.075 0 0 r
.52839 .40531 m .52905 .40481 L .52767 .40514 L F
.751 .76 .861 r
.5304 .40514 m .52806 .40628 L .5271 .40418 L F
0 0 0 r
.52895 .40584 m .52886 .406 L .53088 .4047 L F
.751 .76 .861 r
.53088 .4047 m .5304 .40514 L .53023 .40509 L F
.53088 .4047 m .53023 .40509 L .5276 .40432 L F
.53088 .4047 m .5276 .40432 L .52758 .40424 L F
.619 .694 .897 r
.528 .40615 m .52828 .40677 L .52665 .40573 L F
.075 0 0 r
.52584 .40722 m .52886 .406 L .52887 .40597 L F
.619 .694 .897 r
.52771 .40641 m .52828 .40677 L .52629 .40694 L F
.075 0 0 r
.52584 .40722 m .52887 .40597 L .52613 .407 L F
.619 .694 .897 r
.52629 .40694 m .52828 .40677 L .52628 .40699 L F
.52665 .40573 m .52771 .40641 L .52629 .40694 L F
.5271 .40418 m .528 .40615 L .52665 .40573 L F
.52828 .40677 m .52838 .40699 L .52628 .40699 L F
.295 0 .059 r
.52267 .40739 m .52353 .40676 L .52299 .40717 L F
.52267 .40739 m .52676 .40535 L .52353 .40676 L F
.619 .694 .897 r
.5263 .40692 m .52592 .40705 L .52442 .40513 L F
.52592 .40705 m .52563 .40715 L .5256 .40711 L F
.52592 .40705 m .5256 .40711 L .52442 .40513 L F
.075 0 0 r
.52584 .40722 m .52611 .40702 L .52592 .40705 L F
.619 .694 .897 r
.5271 .40418 m .5263 .40692 L .52442 .40513 L F
.419 .613 .93 r
.52554 .40699 m .52563 .40715 L .52267 .40739 L F
.52563 .40715 m .52603 .40782 L .52267 .40739 L F
.295 0 .059 r
.52267 .40739 m .52584 .40722 L .52588 .40713 L F
.421 .392 .721 r
.52267 .40739 m .52584 .40722 L .52565 .40698 L F
.52267 .40739 m .52565 .40698 L .5234 .40406 L F
.419 .613 .93 r
.52442 .40513 m .52554 .40699 L .52267 .40739 L F
.247 .266 .684 r
.3246 .62185 m .32266 .62043 L .32545 .61919 L F
.049 0 0 r
.31907 .6336 m .32135 .63172 L .31708 .63349 L F
.963 .731 .287 r
.40761 .54779 m .40709 .54954 L .40693 .5467 L F
.40761 .54779 m .40759 .55047 L .40709 .54954 L F
.55 .631 .884 r
.5753 .42173 m .57645 .4182 L .57322 .42059 L F
.84 .911 .885 r
.47523 .43873 m .47097 .44066 L .47395 .43759 L F
.805 .854 .886 r
.47523 .43577 m .47523 .43873 L .47395 .43759 L F
.47523 .43577 m .4773 .43731 L .47523 .43873 L F
.621 .853 .987 r
.56337 .38803 m .56148 .3907 L .55792 .38975 L F
.56337 .38803 m .56461 .38943 L .56148 .3907 L F
.433 .153 .387 r
.51535 .48644 m .51502 .48866 L .5124 .48931 L F
.485 .226 .447 r
.51789 .48575 m .51502 .48866 L .51535 .48644 L F
.56 .245 .392 r
.29399 .56903 m .29612 .5692 L .29389 .56719 L F
.577 .24 .362 r
.29389 .56719 m .29612 .5692 L .29643 .56721 L F
.704 .765 .9 r
.23991 .61831 m .242 .62015 L .24408 .61877 L F
.342 .327 .697 r
.54737 .43723 m .5482 .44292 L .54704 .44158 L F
.571 .374 .575 r
.54704 .44158 m .5482 .44292 L .54644 .44419 L F
.54704 .44158 m .5482 .44292 L .54644 .44419 L F
.648 .455 .609 r
.46522 .53464 m .46812 .53441 L .46784 .53169 L F
.238 .183 .59 r
.46784 .53169 m .46943 .52736 L .46678 .52803 L F
.46784 .53169 m .4699 .52995 L .46943 .52736 L F
.544 .502 .76 r
.46812 .53441 m .4699 .52995 L .46784 .53169 L F
.42 0 0 r
.35004 .49849 m .35045 .49861 L .34835 .49784 L F
.35004 .49849 m .35218 .49974 L .35045 .49861 L F
.658 .972 .844 r
.67892 .37796 m .68284 .37595 L .68212 .37527 L F
.623 .958 .905 r
.68284 .37595 m .68456 .37407 L .68212 .37527 L F
0 0 0 r
.67274 .34035 m .6748 .33768 L .67496 .34 L F
.854 .971 .87 r
.6748 .33768 m .67116 .33943 L .67496 .34 L F
.401 .545 .885 r
.67718 .33733 m .6748 .33768 L .67628 .33539 L F
.607 .077 0 r
.6748 .33768 m .6776 .33944 L .67496 .34 L F
.611 .579 .794 r
.67496 .34 m .67628 .33539 L .6748 .33768 L F
.85 .666 .654 r
.52599 .4407 m .52918 .44134 L .52786 .44055 L F
.871 .831 .805 r
.5252 .44333 m .52918 .44134 L .52599 .4407 L F
.5252 .44333 m .52685 .44338 L .52918 .44134 L F
.737 .549 .638 r
.52685 .44338 m .52993 .44476 L .52918 .44134 L F
.649 .703 .887 r
.52918 .44134 m .53093 .43802 L .52786 .44055 L F
.52918 .44134 m .53202 .44104 L .53093 .43802 L F
.574 .247 .377 r
.53172 .44308 m .53202 .44104 L .52918 .44134 L F
.388 .321 .66 r
.52918 .44134 m .52993 .44476 L .53172 .44308 L F
.692 .867 .965 r
.44892 .44964 m .44711 .45282 L .4455 .45147 L F
.44892 .44964 m .45065 .45107 L .44711 .45282 L F
.284 .094 .437 r
.39386 .47533 m .39174 .47921 L .39197 .47667 L F
.63 .61 .811 r
.36989 .69963 m .37372 .70212 L .37219 .69925 L F
.848 .938 .882 r
.37372 .70212 m .3748 .69872 L .37219 .69925 L F
.37372 .70212 m .37634 .69949 L .3748 .69872 L F
.171 0 0 r
.44908 .49548 m .44989 .49564 L .45229 .49617 L F
.449 .437 .753 r
.32102 .65056 m .31908 .65138 L .31825 .64732 L F
.179 0 .184 r
.31841 .65335 m .31908 .65138 L .32102 .65056 L F
.923 .593 .132 r
.43024 .54438 m .42855 .53999 L .43105 .54002 L F
.19 0 .068 r
.32761 .56177 m .32619 .56115 L .32871 .56031 L F
.32761 .56177 m .32526 .56294 L .32619 .56115 L F
.99 .732 .429 r
.39156 .55257 m .39316 .55064 L .39123 .54955 L F
.39156 .55257 m .3931 .55387 L .39316 .55064 L F
.421 .115 .338 r
.31716 .56433 m .31623 .5665 L .31381 .56704 L F
.709 .515 .625 r
.31915 .56315 m .31623 .5665 L .31716 .56433 L F
.606 .895 .597 r
.61133 .37439 m .60948 .37659 L .6122 .37382 L F
.253 .293 .71 r
.61185 .37811 m .60948 .37659 L .61133 .37439 L F
.521 .189 .345 r
.60911 .37886 m .60948 .37659 L .61185 .37811 L F
0 0 .227 r
.23717 .58914 m .23667 .59176 L .23526 .59283 L F
.944 .736 .592 r
.5958 .42138 m .59528 .42397 L .59709 .4248 L F
0 .185 .674 r
.59528 .42397 m .5978 .42621 L .59709 .4248 L F
.948 .88 .735 r
.3824 .62158 m .38574 .61867 L .38469 .61827 L F
.3824 .62158 m .38394 .62256 L .38574 .61867 L F
.898 .973 .816 r
.38574 .61867 m .38711 .61485 L .38469 .61827 L F
.38574 .61867 m .3882 .6155 L .38711 .61485 L F
.638 .077 0 r
.35931 .62457 m .35864 .62374 L .35667 .62261 L F
.35931 .62457 m .35864 .62374 L .35667 .62261 L F
0 0 .339 r
.36183 .61851 m .36391 .62309 L .35818 .62222 L F
.638 .077 0 r
.35931 .62457 m .35667 .62261 L .35818 .62222 L F
.35931 .62457 m .35667 .62261 L .35818 .62222 L F
.84 .729 .741 r
.35723 .62276 m .35931 .62457 L .35626 .62431 L F
.35795 .62162 m .35848 .62278 L .35723 .62276 L F
.35848 .62278 m .35931 .62457 L .35723 .62276 L F
.72 .282 .21 r
.35916 .62279 m .36391 .62309 L .36211 .6245 L F
.35818 .62222 m .36231 .62284 L .35916 .62279 L F
.36231 .62284 m .36391 .62309 L .35916 .62279 L F
.761 .987 .899 r
.36391 .62309 m .36466 .62114 L .36211 .6245 L F
.36391 .62309 m .36611 .62156 L .36466 .62114 L F
0 0 0 r
.66794 .38325 m .671 .38197 L .67033 .38201 L F
.493 .875 .973 r
.671 .38197 m .67265 .38073 L .67033 .38201 L F
.671 .38197 m .67378 .38118 L .67265 .38073 L F
.077 0 .362 r
.59555 .3518 m .59316 .35344 L .59336 .35311 L F
.59555 .3518 m .59548 .3522 L .59316 .35344 L F
.958 .943 .711 r
.36466 .62114 m .36611 .62156 L .36743 .61821 L F
.755 .967 .931 r
.45439 .44866 m .45903 .44702 L .45645 .44797 L F
.516 .609 .884 r
.37363 .62071 m .37454 .62285 L .37284 .62292 L F
.89 .968 .832 r
.37455 .62351 m .37744 .62255 L .37425 .62412 L F
.37628 .62007 m .37706 .62174 L .37455 .62351 L F
.37706 .62174 m .37744 .62255 L .37455 .62351 L F
.988 .895 .586 r
.37418 .62415 m .37483 .62623 L .37347 .62788 L F
.37418 .62415 m .37347 .62788 L .37509 .6268 L F
.37418 .62415 m .37509 .6268 L .37501 .62396 L F
.739 .455 .5 r
.37358 .6242 m .37501 .62396 L .37509 .6268 L F
.37284 .62292 m .37436 .62365 L .37358 .6242 L F
.89 .968 .832 r
.37429 .62395 m .37425 .62412 L .37418 .62415 L F
.37628 .62007 m .37425 .62412 L .37429 .62395 L F
.37628 .62007 m .37418 .62415 L .37501 .62396 L F
.739 .455 .5 r
.37436 .62365 m .37501 .62396 L .37358 .6242 L F
.516 .609 .884 r
.37454 .62285 m .37501 .62396 L .37436 .62365 L F
.37454 .62285 m .37436 .62365 L .37284 .62292 L F
.831 .723 .746 r
.67815 .35012 m .67832 .35348 L .67379 .35251 L F
.323 .754 .971 r
.67379 .35251 m .67832 .35348 L .67654 .35236 L F
.49 .386 .663 r
.68031 .3497 m .67832 .35348 L .67815 .35012 L F
.208 .591 .946 r
.67832 .35348 m .67968 .3523 L .67654 .35236 L F
.549 .028 0 r
.68068 .35523 m .67832 .35348 L .67875 .35677 L F
.751 .85 .924 r
.48035 .435 m .4773 .43731 L .47523 .43577 L F
.905 .833 .765 r
.45424 .56565 m .45191 .56705 L .45398 .56289 L F
.781 .507 .522 r
.45031 .56957 m .45424 .56565 L .45308 .56787 L F
.45031 .56957 m .45191 .56705 L .45424 .56565 L F
.838 .677 .683 r
.45644 .56544 m .45302 .56798 L .45424 .56565 L F
.198 0 0 r
.45259 .56804 m .45373 .56727 L .45279 .56552 L F
.45373 .56727 m .45644 .56544 L .4557 .56546 L F
.15 .266 .729 r
.45536 .56318 m .45644 .56544 L .45424 .56565 L F
.198 0 0 r
.45373 .56727 m .4557 .56546 L .45279 .56552 L F
.781 .507 .522 r
.45285 .56808 m .45308 .56787 L .45302 .56798 L F
.45031 .56957 m .45308 .56787 L .45285 .56808 L F
.474 .19 .402 r
.28605 .53418 m .28889 .53388 L .28884 .53051 L F
.675 .731 .892 r
.28856 .5295 m .28884 .53051 L .28995 .5285 L F
.043 .067 .559 r
.29066 .5327 m .28968 .53467 L .28884 .53051 L F
.39 .128 .391 r
.28884 .53051 m .28889 .53388 L .29066 .5327 L F
.695 .232 .149 r
.37553 .55097 m .37351 .55293 L .37051 .5503 L F
.881 .501 .317 r
.37544 .55301 m .37351 .55293 L .37553 .55097 L F
.584 .589 .823 r
.5469 .40726 m .54611 .41138 L .54444 .4091 L F
.5469 .40726 m .54887 .41077 L .54611 .41138 L F
.596 .797 .976 r
.45425 .57687 m .45053 .576 L .45293 .57351 L F
.81 .748 .794 r
.45293 .57351 m .45685 .57359 L .45425 .57687 L F
.731 .574 .678 r
.38337 .48898 m .38553 .49322 L .3811 .49234 L F
.69 .558 .7 r
.38806 .49142 m .38553 .49322 L .38337 .48898 L F
.098 0 0 r
.6833 .35425 m .68161 .35393 L .68068 .35523 L F
.6833 .35425 m .68493 .35394 L .68161 .35393 L F
.993 .827 .459 r
.60746 .42119 m .60559 .42217 L .60597 .42037 L F
.60746 .42119 m .60684 .42425 L .60559 .42217 L F
.875 .707 .67 r
.43053 .50465 m .43205 .50863 L .43329 .50626 L F
.488 .175 .361 r
.23832 .57972 m .24126 .57943 L .24321 .57603 L F
.226 0 0 r
.24126 .57943 m .24483 .5771 L .24321 .57603 L F
.58 .634 .869 r
.36614 .68644 m .36444 .68994 L .36286 .68616 L F
.36614 .68644 m .36676 .68941 L .36444 .68994 L F
.637 .57 .763 r
.3684 .69317 m .36444 .68994 L .36676 .68941 L F
.991 .87 .612 r
.3882 .6155 m .38795 .61186 L .38711 .61485 L F
.526 .719 .961 r
.31046 .65273 m .30935 .65472 L .30801 .65317 L F
.229 .339 .769 r
.31046 .65273 m .3122 .65759 L .30935 .65472 L F
0 0 0 r
.66333 .3178 m .66278 .31948 L .66571 .31637 L F
.935 .613 .163 r
.27756 .65069 m .27912 .65463 L .27817 .65361 L F
.685 .228 0 r
.27817 .65361 m .27912 .65463 L .28077 .65727 L F
.838 .56 .517 r
.27912 .65463 m .28154 .65748 L .28077 .65727 L F
.685 .228 0 r
.27817 .65361 m .28077 .65727 L .27719 .65619 L F
.106 .486 .899 r
.28077 .65727 m .28388 .65745 L .27992 .65703 L F
.291 0 0 r
.27719 .65619 m .28077 .65727 L .27944 .65698 L F
.106 .486 .899 r
.28077 .65727 m .27992 .65703 L .27944 .65698 L F
.838 .56 .517 r
.28154 .65748 m .28228 .65835 L .28077 .65727 L F
.832 .931 .896 r
.50981 .41781 m .50686 .41851 L .50875 .41681 L F
.859 .96 .87 r
.51273 .4147 m .50981 .41781 L .50875 .41681 L F
.204 0 0 r
.55242 .47376 m .55592 .47205 L .55448 .47403 L F
.237 0 .204 r
.55592 .47205 m .55861 .46991 L .55792 .47151 L F
.137 0 0 r
.55448 .47403 m .55592 .47205 L .55792 .47151 L F
.396 .804 .593 r
.61133 .37439 m .6122 .37382 L .61438 .37236 L F
.561 .283 .452 r
.33531 .54112 m .3329 .54186 L .33358 .54097 L F
.919 .537 .127 r
.40431 .53749 m .40243 .53418 L .40368 .5351 L F
.601 .441 .637 r
.35172 .57317 m .34916 .57645 L .34907 .57347 L F
.201 0 .353 r
.33242 .58244 m .33472 .57776 L .33341 .57988 L F
.33242 .58244 m .33508 .58177 L .33472 .57776 L F
.782 .488 .49 r
.33758 .57568 m .33284 .57742 L .33299 .57472 L F
.131 0 .344 r
.33598 .57623 m .33733 .57789 L .3384 .57539 L F
.782 .488 .49 r
.33821 .57581 m .33752 .57602 L .33758 .57568 L F
.131 0 .344 r
.33598 .57623 m .33472 .57776 L .33717 .57788 L F
.33598 .57623 m .33717 .57788 L .3372 .57772 L F
.782 .488 .49 r
.33752 .57602 m .33284 .57742 L .33758 .57568 L F
.131 0 .344 r
.3372 .57772 m .33717 .57788 L .33733 .57789 L F
.44 .149 .374 r
.33472 .57776 m .33765 .58102 L .33733 .57789 L F
.33472 .57776 m .33508 .58177 L .33765 .58102 L F
.784 .314 0 r
.36263 .50981 m .36255 .5083 L .36073 .50728 L F
.36263 .50981 m .36426 .51123 L .36255 .5083 L F
.982 .723 .461 r
.40759 .55047 m .40909 .55418 L .40747 .55298 L F
.976 .705 .302 r
.40909 .55418 m .40834 .55659 L .40747 .55298 L F
.40909 .55418 m .40928 .55718 L .40834 .55659 L F
.571 .28 .435 r
.27269 .55051 m .26928 .5526 L .27052 .55161 L F
.727 .436 0 r
.27069 .63187 m .27127 .63399 L .27093 .63323 L F
.569 .49 .726 r
.44443 .52363 m .44085 .52106 L .44548 .52169 L F
.695 .973 .922 r
.44884 .51966 m .44569 .52024 L .44548 .52169 L F
.392 .263 .584 r
.44569 .52024 m .44443 .52363 L .44548 .52169 L F
.693 .407 .484 r
.28102 .51436 m .28466 .51524 L .28517 .51219 L F
.69 .65 .805 r
.31653 .65722 m .31766 .6609 L .31466 .66061 L F
.687 .36 .415 r
.31466 .66061 m .31766 .6609 L .31696 .66256 L F
.31466 .66061 m .31696 .66256 L .31629 .66267 L F
.31466 .66061 m .31629 .66267 L .31466 .6633 L F
.31629 .66267 m .3167 .66319 L .31467 .6633 L F
.31629 .66267 m .31466 .6633 L .31466 .6633 L F
.31629 .66267 m .31696 .66256 L .3167 .66319 L F
.555 .387 .609 r
.3167 .66319 m .31692 .66237 L .31467 .6633 L F
.3167 .66319 m .31467 .6633 L .3144 .66341 L F
.687 .36 .415 r
.31467 .6633 m .3167 .66319 L .31466 .6633 L F
.631 .902 .985 r
.31439 .6634 m .31615 .66269 L .3142 .66298 L F
.3144 .66341 m .31467 .6633 L .31439 .6634 L F
.31467 .6633 m .31615 .66269 L .31439 .6634 L F
.3142 .66298 m .31692 .66237 L .31336 .66121 L F
.31615 .66269 m .31692 .66237 L .3142 .66298 L F
.514 .243 .442 r
.28517 .51219 m .28466 .51524 L .28724 .5146 L F
0 .133 .666 r
.31842 .65942 m .31766 .6609 L .31653 .65722 L F
.231 .715 .931 r
.31336 .66121 m .31692 .66237 L .31708 .66235 L F
.31712 .66229 m .31708 .66235 L .31906 .66211 L F
.315 .157 .501 r
.31906 .66211 m .31708 .66235 L .3167 .66319 L F
0 0 0 r
.3167 .66319 m .317 .66248 L .31708 .66235 L F
.315 .157 .501 r
.31708 .66235 m .31692 .66237 L .3167 .66319 L F
0 0 0 r
.3167 .66319 m .31708 .66235 L .31712 .66229 L F
.3167 .66319 m .31712 .66229 L .31906 .66211 L F
.31712 .66229 m .31842 .65942 L .31906 .66211 L F
.231 .715 .931 r
.31739 .66184 m .31712 .66229 L .31906 .66211 L F
0 0 0 r
.31712 .66229 m .31766 .6609 L .31842 .65942 L F
.317 .66248 m .31766 .6609 L .31712 .66229 L F
.231 .715 .931 r
.31336 .66121 m .31708 .66235 L .31739 .66184 L F
.712 .868 .955 r
.35839 .55978 m .36318 .55979 L .36043 .55546 L F
.411 .519 .857 r
.36318 .55979 m .36346 .5559 L .36043 .55546 L F
.36318 .55979 m .36523 .55959 L .36346 .5559 L F
.114 0 0 r
.38186 .47936 m .38472 .47861 L .38536 .47772 L F
.362 0 0 r
.38536 .47772 m .38472 .47861 L .38723 .47788 L F
0 0 0 r
.30006 .53848 m .30033 .53827 L .30243 .53828 L F
.056 0 0 r
.30243 .53828 m .30033 .53827 L .30135 .5383 L F
.323 .067 .363 r
.30606 .53969 m .30383 .54053 L .30433 .53817 L F
.056 0 0 r
.30243 .53828 m .30135 .5383 L .30461 .53841 L F
.082 .642 .731 r
.30308 .53826 m .30243 .53828 L .30433 .53817 L F
.30006 .53848 m .30243 .53828 L .30308 .53826 L F
.149 0 0 r
.30243 .53828 m .30707 .53758 L .30433 .53817 L F
.323 .067 .363 r
.30606 .53969 m .30433 .53817 L .30707 .53758 L F
.622 .364 .506 r
.41781 .59313 m .42057 .59554 L .41641 .59543 L F
.616 .34 .475 r
.41641 .59543 m .42057 .59554 L .41959 .5982 L F
.973 .777 .578 r
.42057 .59554 m .42132 .59895 L .41959 .5982 L F
.41959 .5982 m .42132 .59895 L .42057 .59554 L F
.41959 .5982 m .42057 .59554 L .4227 .5924 L F
.761 .276 .083 r
.4205 .59638 m .42028 .59509 L .41652 .59307 L F
.909 .887 .799 r
.42235 .59203 m .42057 .59554 L .41776 .59282 L F
.761 .276 .083 r
.42028 .59509 m .42019 .59455 L .41922 .59416 L F
.42028 .59509 m .41922 .59416 L .41652 .59307 L F
0 .079 .57 r
.41777 .59288 m .42057 .59554 L .41781 .59313 L F
.41776 .59282 m .41832 .59336 L .41777 .59288 L F
.41832 .59336 m .42057 .59554 L .41777 .59288 L F
.787 .612 .663 r
.55986 .39707 m .55673 .39852 L .5587 .39542 L F
.485 .898 .811 r
.34754 .61234 m .34362 .61396 L .34566 .61383 L F
.231 .301 .73 r
.34754 .61234 m .34891 .6119 L .34799 .6074 L F
0 0 0 r
.34566 .61383 m .34891 .6119 L .34754 .61234 L F
.83 .989 .726 r
.70175 .28338 m .70331 .28281 L .70422 .28025 L F
.024 0 0 r
.34776 .65379 m .34594 .65388 L .3452 .65447 L F
.3452 .65447 m .34594 .65388 L .34776 .65379 L F
.755 .403 .386 r
.33622 .65455 m .33933 .6568 L .337 .65684 L F
.117 0 0 r
.337 .65684 m .33843 .65714 L .335 .65853 L F
.337 .65684 m .33933 .6568 L .33843 .65714 L F
.788 .871 .909 r
.48726 .43245 m .48257 .43347 L .48575 .43106 L F
.805 .896 .907 r
.48913 .43073 m .48726 .43245 L .48575 .43106 L F
.61 .151 .138 r
.5403 .47634 m .5427 .47853 L .53929 .47894 L F
.5403 .47634 m .54362 .47694 L .5427 .47853 L F
.029 0 .404 r
.33743 .56754 m .33926 .56609 L .33848 .56291 L F
0 .079 .548 r
.33743 .56754 m .33818 .56814 L .33926 .56609 L F
.33743 .56754 m .33978 .56949 L .33818 .56814 L F
.504 .037 .079 r
.52999 .40411 m .5332 .4043 L .53398 .40262 L F
0 0 0 r
.53398 .40262 m .53523 .40293 L .53657 .40223 L F
.53398 .40262 m .5332 .4043 L .53523 .40293 L F
.905 .863 .789 r
.61207 .39393 m .61607 .39263 L .61423 .39441 L F
0 0 0 r
.28273 .57516 m .28256 .57489 L .28452 .57341 L F
.28273 .57516 m .2805 .57608 L .28256 .57489 L F
.545 .747 .97 r
.68311 .33533 m .68151 .33807 L .68011 .3363 L F
.68311 .33533 m .68473 .3374 L .68151 .33807 L F
.68151 .33807 m .68311 .33533 L .68031 .33868 L F
.68151 .33807 m .68473 .3374 L .68311 .33533 L F
.736 .601 .706 r
.48848 .51791 m .48516 .51858 L .48787 .51536 L F
.395 .251 .565 r
.49054 .51492 m .48848 .51791 L .48787 .51536 L F
.49054 .51492 m .49068 .51752 L .48848 .51791 L F
.445 .34 .642 r
.49068 .51752 m .48867 .52179 L .48848 .51791 L F
.788 .398 0 r
.39583 .52157 m .39493 .52054 L .394 .51807 L F
.799 .34 0 r
.39583 .52157 m .39585 .52298 L .39493 .52054 L F
.39583 .52157 m .39726 .52418 L .39585 .52298 L F
.085 0 .355 r
.34852 .62162 m .34886 .61885 L .35092 .61644 L F
.461 .501 .813 r
.23486 .56618 m .23346 .56757 L .2318 .56499 L F
.821 .483 .416 r
.22936 .56319 m .23299 .56806 L .2318 .56499 L F
.23299 .56806 m .23305 .56815 L .23301 .56804 L F
.23299 .56806 m .23301 .56804 L .2318 .56499 L F
.196 .168 .599 r
.2318 .56499 m .23446 .56571 L .23486 .56618 L F
.896 .939 .571 r
.23467 .56401 m .23416 .56537 L .23486 .56618 L F
.196 .168 .599 r
.23446 .56571 m .23447 .56572 L .23486 .56618 L F
.2318 .56499 m .23301 .56804 L .23444 .56577 L F
.896 .939 .571 r
.23446 .56571 m .23402 .5671 L .23486 .56618 L F
.196 .168 .599 r
.23446 .56571 m .23444 .56577 L .23447 .56572 L F
.2318 .56499 m .23444 .56577 L .23446 .56571 L F
.23301 .56804 m .23326 .5678 L .23447 .56572 L F
0 0 0 r
.23394 .56709 m .23282 .56823 L .23346 .56757 L F
.23486 .56618 m .23302 .56803 L .23394 .56709 L F
.23302 .56803 m .23283 .56823 L .23299 .56806 L F
.23302 .56803 m .23299 .56806 L .23394 .56709 L F
0 .139 .685 r
.22987 .56218 m .233 .56805 L .22936 .56319 L F
.233 .56805 m .23305 .56815 L .23299 .56806 L F
.233 .56805 m .23299 .56806 L .22936 .56319 L F
.196 .168 .599 r
.23301 .56804 m .23305 .56815 L .23325 .56782 L F
.23301 .56804 m .23325 .56782 L .23313 .56792 L F
0 0 0 r
.23313 .56792 m .23319 .56801 L .23198 .56909 L F
.23486 .56618 m .23402 .5671 L .23313 .56792 L F
.23402 .5671 m .23319 .56801 L .23313 .56792 L F
.196 .168 .599 r
.23313 .56792 m .23325 .56782 L .23326 .5678 L F
0 0 0 r
.23282 .56823 m .23263 .56841 L .23346 .56757 L F
.23283 .56823 m .23198 .56909 L .23266 .56839 L F
.23294 .56811 m .23266 .56839 L .23394 .56709 L F
.23283 .56823 m .23266 .56839 L .23294 .56811 L F
.812 .59 .601 r
.23198 .56909 m .2269 .56738 L .22897 .56938 L F
.23198 .56909 m .22945 .5694 L .2269 .56738 L F
.89 .716 .66 r
.22901 .56516 m .23003 .56592 L .22987 .56218 L F
.23003 .56592 m .23132 .56687 L .23077 .56509 L F
.23003 .56592 m .23077 .56509 L .22987 .56218 L F
.23132 .56687 m .23305 .56815 L .23195 .56609 L F
.23132 .56687 m .23195 .56609 L .22987 .56218 L F
.657 .756 .923 r
.23325 .56781 m .23297 .56809 L .22901 .56516 L F
.43 .08 .267 r
.23119 .56663 m .2269 .56738 L .22945 .5694 L F
.22908 .567 m .2269 .56881 L .2269 .56738 L F
.23119 .56663 m .22795 .56828 L .22908 .567 L F
.22795 .56828 m .2269 .56881 L .22908 .567 L F
.975 .726 .309 r
.23001 .5685 m .22834 .57024 L .23119 .56663 L F
.22945 .5694 m .22904 .5697 L .23001 .5685 L F
.22904 .5697 m .22834 .57024 L .23001 .5685 L F
.657 .756 .923 r
.23445 .56572 m .23325 .56781 L .22901 .56516 L F
.23325 .56781 m .23305 .56815 L .23297 .56809 L F
.896 .939 .571 r
.23445 .56571 m .23444 .56578 L .23446 .56571 L F
.657 .756 .923 r
.23447 .56572 m .23444 .56578 L .23445 .56572 L F
.23444 .56578 m .23305 .56815 L .23445 .56572 L F
.23447 .56572 m .22901 .56516 L .23153 .56417 L F
.635 .805 .965 r
.23467 .56401 m .23447 .56572 L .23445 .56571 L F
.23467 .56401 m .23445 .56571 L .23153 .56417 L F
.896 .939 .571 r
.23416 .56537 m .23444 .56578 L .23445 .56572 L F
.23445 .56571 m .23445 .56572 L .23445 .56571 L F
.23416 .56537 m .23445 .56572 L .23445 .56571 L F
.23416 .56537 m .23402 .5671 L .23444 .56578 L F
.23416 .56537 m .23319 .56801 L .23402 .5671 L F
0 0 0 r
.23282 .56823 m .23198 .56909 L .23263 .56841 L F
0 0 .247 r
.70006 .28958 m .699 .28933 L .69969 .28704 L F
.70006 .28958 m .69881 .29197 L .699 .28933 L F
0 0 .021 r
.62259 .42691 m .61993 .43018 L .62071 .42835 L F
.765 .827 .901 r
.45495 .5724 m .45685 .57359 L .45293 .57351 L F
0 0 .006 r
.45785 .56958 m .45685 .57359 L .45495 .5724 L F
.245 .701 .952 r
.36526 .69876 m .36989 .69963 L .36846 .69618 L F
.464 .552 .86 r
.36846 .69618 m .36989 .69963 L .37219 .69925 L F
.713 .621 .753 r
.42549 .59972 m .42282 .60273 L .42258 .6003 L F
.743 .67 .779 r
.42132 .59895 m .42282 .60273 L .42549 .59972 L F
.663 .452 .589 r
.48657 .52774 m .48315 .52519 L .48653 .52493 L F
.48657 .52774 m .48394 .52804 L .48315 .52519 L F
.544 .064 .065 r
.62138 .38833 m .62143 .38643 L .62054 .38825 L F
.816 .592 .035 r
.62143 .38643 m .62174 .38911 L .62138 .38833 L F
.142 .668 .876 r
.25797 .55742 m .25606 .55693 L .25377 .55691 L F
.541 .352 .573 r
.26058 .55411 m .26056 .55726 L .25797 .55742 L F
.57 .9 .982 r
.2586 .55583 m .25797 .55742 L .26056 .55726 L F
.2586 .55583 m .25606 .55693 L .25797 .55742 L F
.513 .901 .75 r
.27589 .63399 m .27491 .63501 L .27716 .6334 L F
.498 .906 .823 r
.27399 .63493 m .27491 .63501 L .27589 .63399 L F
.536 .352 .578 r
.62764 .3536 m .6269 .35669 L .62501 .35708 L F
.649 .431 .574 r
.6269 .35669 m .62493 .35918 L .62501 .35708 L F
0 0 0 r
.62619 .35705 m .62501 .35708 L .62493 .35918 L F
.62619 .35705 m .6269 .35669 L .62501 .35708 L F
.536 .352 .578 r
.62764 .3536 m .6269 .35669 L .62501 .35708 L F
.682 .921 .603 r
.4054 .49268 m .4037 .49413 L .40267 .4959 L F
.896 .523 .322 r
.40701 .49455 m .4037 .49413 L .4054 .49268 L F
.945 .698 .534 r
.40701 .49455 m .40548 .49789 L .4037 .49413 L F
.216 .37 .803 r
.34017 .68734 m .34286 .68934 L .34241 .68658 L F
.816 .87 .887 r
.62591 .35183 m .62764 .3536 L .62958 .35228 L F
.821 .689 .718 r
.62958 .35228 m .6269 .35669 L .62764 .3536 L F
0 0 .273 r
.62764 .3536 m .62934 .35415 L .62958 .35228 L F
.029 .052 .548 r
.62958 .35228 m .63135 .3479 L .62924 .34963 L F
.62958 .35228 m .63189 .35106 L .63135 .3479 L F
0 0 .108 r
.63146 .35296 m .62958 .35228 L .62934 .35415 L F
.63146 .35296 m .63189 .35106 L .62958 .35228 L F
.98 .688 .373 r
.28077 .65727 m .28228 .65835 L .28103 .66187 L F
.53 .09 .147 r
.28228 .65835 m .28601 .65976 L .28103 .66187 L F
.566 .634 .878 r
.23091 .57917 m .22926 .57996 L .22723 .57648 L F
.323 .09 .398 r
.23091 .57917 m .23041 .58179 L .22926 .57996 L F
0 0 .502 r
.23041 .58179 m .22998 .58282 L .22926 .57996 L F
.703 .422 0 r
.38029 .67052 m .38199 .67339 L .38286 .67062 L F
.38029 .67052 m .38123 .67399 L .38199 .67339 L F
.75 .32 .228 r
.42293 .54448 m .42696 .54812 L .42741 .54593 L F
0 0 0 r
.42741 .54593 m .42803 .54645 L .43024 .54438 L F
.42741 .54593 m .42696 .54812 L .42803 .54645 L F
.47 .295 .561 r
.26294 .5566 m .26058 .55411 L .26342 .5535 L F
.26294 .5566 m .26056 .55726 L .26058 .55411 L F
.803 .555 .564 r
.2586 .55583 m .26342 .5535 L .26058 .55411 L F
.116 0 .004 r
.28687 .57271 m .28975 .57031 L .28772 .571 L F
.948 .687 .226 r
.39843 .57586 m .39758 .57301 L .39766 .5753 L F
.988 .884 .55 r
.39672 .57877 m .39843 .57586 L .39766 .5753 L F
.39672 .57877 m .39752 .57986 L .39843 .57586 L F
.266 .021 .344 r
.35899 .60831 m .3562 .61166 L .35695 .60924 L F
.899 .58 .086 r
.40278 .48237 m .40323 .48476 L .40411 .48595 L F
.735 .225 .007 r
.40311 .48739 m .40411 .48595 L .40323 .48476 L F
.728 .986 .791 r
.57673 .37081 m .57452 .37293 L .57611 .3704 L F
0 0 .488 r
.57452 .37293 m .57584 .37354 L .57611 .3704 L F
.57452 .37293 m .57581 .3757 L .57584 .37354 L F
.094 0 .41 r
.33848 .56291 m .33926 .56609 L .34068 .56477 L F
.441 .871 .775 r
.64103 .38595 m .63865 .38716 L .63717 .38752 L F
0 0 0 r
.27677 .51685 m .27326 .51901 L .27545 .51738 L F
.681 .659 .822 r
.58785 .3728 m .58526 .37361 L .58406 .37171 L F
.829 .658 .671 r
.55482 .43724 m .55543 .4408 L .55179 .44036 L F
.673 .554 .713 r
.55482 .43724 m .55847 .43851 L .55543 .4408 L F
.595 .446 .65 r
.4355 .46058 m .43208 .46238 L .43208 .46048 L F
.4355 .46058 m .43208 .46048 L .43527 .46063 L F
.741 .737 .848 r
.42009 .46435 m .41572 .46342 L .41812 .46269 L F
.81 .893 .903 r
.32875 .52778 m .32488 .52921 L .32833 .52635 L F
.445 0 .088 r
.32875 .52778 m .32711 .52955 L .32488 .52921 L F
.489 .211 .418 r
.32711 .52955 m .32488 .52921 L .32875 .52778 L F
.761 .676 .769 r
.32891 .52573 m .32875 .52778 L .33168 .52505 L F
.414 .639 .948 r
.32949 .52587 m .32875 .52778 L .32833 .52635 L F
.772 .936 .586 r
.32949 .52587 m .32711 .52955 L .32875 .52778 L F
.602 .174 .201 r
.32711 .52955 m .33117 .5297 L .32875 .52778 L F
.174 .079 .499 r
.70499 .29399 m .70529 .29711 L .70296 .29871 L F
0 0 .128 r
.70443 .29794 m .70296 .29871 L .70529 .29711 L F
.70443 .29794 m .70247 .30123 L .70296 .29871 L F
0 0 0 r
.55482 .43724 m .55754 .43387 L .55847 .43851 L F
.707 .698 .839 r
.36199 .6993 m .36357 .70027 L .36526 .69876 L F
.288 .475 .869 r
.2621 .6174 m .26096 .61916 L .26069 .61757 L F
0 0 .211 r
.26094 .61899 m .26096 .61916 L .2621 .6174 L F
.26094 .61899 m .26177 .62184 L .26096 .61916 L F
.26096 .61906 m .26177 .62184 L .26094 .61899 L F
.968 .918 .583 r
.26009 .62347 m .26177 .62184 L .26096 .61906 L F
0 0 .211 r
.26094 .61899 m .26096 .61906 L .26094 .61899 L F
.968 .918 .583 r
.26092 .61912 m .26096 .61906 L .26094 .61899 L F
.26009 .62347 m .26096 .61906 L .26092 .61912 L F
.642 .281 .343 r
.25827 .62148 m .2593 .62143 L .25999 .61919 L F
0 0 .327 r
.26094 .62207 m .26009 .62347 L .26092 .61912 L F
.26094 .61924 m .26092 .61912 L .26094 .61899 L F
.26094 .62207 m .26092 .61912 L .26094 .61924 L F
.26094 .62207 m .26094 .61899 L .25999 .61919 L F
.302 .299 .69 r
.2623 .6213 m .26094 .62207 L .25999 .61919 L F
.642 .281 .343 r
.26166 .62133 m .2614 .62047 L .26118 .62028 L F
.26132 .6209 m .26118 .62028 L .25999 .61919 L F
.26166 .62133 m .26118 .62028 L .26132 .6209 L F
.2593 .62143 m .26166 .62133 L .26045 .61978 L F
.2593 .62143 m .26045 .61978 L .25999 .61919 L F
.26166 .62133 m .2623 .6213 L .2614 .62047 L F
.93 .845 .738 r
.36905 .68536 m .36676 .68941 L .36614 .68644 L F
.765 .596 .668 r
.36905 .68536 m .37099 .6899 L .36676 .68941 L F
.674 .969 .921 r
.71802 .32543 m .72228 .32411 L .72118 .32409 L F
.133 .288 .757 r
.23608 .57994 m .23846 .58233 L .23832 .57972 L F
.935 .846 .73 r
.45229 .49617 m .45045 .49585 L .44908 .49548 L F
.755 .569 .644 r
.5587 .39542 m .55673 .39852 L .5565 .39567 L F
.769 .97 .683 r
.34793 .64528 m .3461 .64657 L .34575 .64379 L F
.116 0 0 r
.34939 .64567 m .35059 .64533 L .34793 .64528 L F
.34939 .64567 m .34793 .64528 L .34575 .64379 L F
.414 0 0 r
.23217 .60912 m .23253 .60963 L .23053 .60791 L F
.23217 .60912 m .23456 .61048 L .23253 .60963 L F
.66 .564 .736 r
.23461 .60663 m .23685 .61015 L .23217 .60912 L F
.576 .061 0 r
.23217 .60912 m .23685 .61015 L .23456 .61048 L F
.158 0 0 r
.70151 .27678 m .69844 .27835 L .70079 .27606 L F
.105 .618 .892 r
.70343 .27641 m .70151 .27678 L .70079 .27606 L F
.70343 .27641 m .70498 .27718 L .70151 .27678 L F
.374 .265 .6 r
.48364 .54353 m .48241 .54712 L .48124 .54782 L F
.029 0 .412 r
.48241 .54712 m .48164 .55053 L .48124 .54782 L F
0 0 .273 r
.62764 .3536 m .6269 .35669 L .62934 .35415 L F
.901 .64 .534 r
.42518 .59257 m .42256 .58931 L .42563 .59034 L F
.42518 .59257 m .42235 .59203 L .42256 .58931 L F
.845 .382 .057 r
.42518 .59257 m .4227 .5924 L .42235 .59203 L F
.42518 .59257 m .42557 .59615 L .4227 .5924 L F
.506 .005 0 r
.30383 .54053 m .2996 .54108 L .30171 .54156 L F
.062 .269 .761 r
.32886 .51212 m .32922 .51121 L .33144 .50884 L F
.32922 .51121 m .32959 .51032 L .33036 .50971 L F
.32922 .51121 m .33036 .50971 L .33144 .50884 L F
.688 .634 .79 r
.32882 .51248 m .32539 .51188 L .32886 .51212 L F
.32706 .513 m .32539 .51188 L .32882 .51248 L F
.43 .871 .819 r
.32478 .5139 m .32706 .513 L .32539 .51188 L F
.688 .634 .79 r
.32677 .51308 m .32478 .5139 L .32508 .51289 L F
.3263 .51268 m .32508 .51289 L .32539 .51188 L F
.32677 .51308 m .32508 .51289 L .3263 .51268 L F
.43 .871 .819 r
.32478 .5139 m .32677 .51308 L .32706 .513 L F
.688 .634 .79 r
.32858 .51466 m .3263 .51268 L .32865 .51405 L F
.3263 .51268 m .32539 .51188 L .32649 .51261 L F
.3263 .51268 m .32649 .51261 L .32865 .51405 L F
.43 .871 .819 r
.32706 .513 m .32823 .51254 L .32539 .51188 L F
.536 .772 .985 r
.33162 .51195 m .32886 .51212 L .33144 .50884 L F
.062 .269 .761 r
.32886 .51212 m .32958 .512 L .32959 .51032 L F
.115 .661 .825 r
.32539 .51188 m .32958 .512 L .32886 .51212 L F
.43 .871 .819 r
.32823 .51254 m .32865 .51198 L .32539 .51188 L F
.32706 .513 m .3259 .51317 L .32958 .512 L F
.688 .634 .79 r
.32865 .51405 m .32706 .513 L .32882 .51248 L F
.187 0 0 r
.32959 .51211 m .3259 .51317 L .32964 .51266 L F
.32958 .512 m .32883 .51224 L .32959 .51211 L F
.32883 .51224 m .3259 .51317 L .32959 .51211 L F
.43 .871 .819 r
.32478 .5139 m .32542 .51349 L .32677 .51308 L F
.688 .634 .79 r
.32858 .51466 m .32478 .5139 L .32677 .51308 L F
.43 .871 .819 r
.32542 .51349 m .3259 .51317 L .32706 .513 L F
.32823 .51254 m .32958 .512 L .32865 .51198 L F
.761 .676 .769 r
.32891 .52573 m .33168 .52505 L .33023 .52439 L F
.573 .267 .411 r
.34863 .60264 m .34832 .60498 L .34481 .60502 L F
.509 .892 .717 r
.35437 .65035 m .35852 .64791 L .35591 .64848 L F
.184 0 .092 r
.33104 .5224 m .33168 .52505 L .33422 .52443 L F
.33104 .5224 m .33242 .52328 L .33168 .52505 L F
.628 .921 .977 r
.33168 .52505 m .33023 .52439 L .33242 .52328 L F
.451 .21 .457 r
.33422 .52443 m .33348 .52698 L .33168 .52505 L F
.35 .194 .524 r
.35088 .59911 m .35097 .60206 L .34863 .60264 L F
.378 .279 .615 r
.34863 .60264 m .35095 .6048 L .35097 .60206 L F
.575 .269 .412 r
.34863 .60264 m .35095 .6048 L .34832 .60498 L F
.378 .279 .615 r
.34863 .60264 m .35095 .6048 L .35097 .60206 L F
.575 .269 .412 r
.34863 .60264 m .35095 .6048 L .34832 .60498 L F
0 0 0 r
.35852 .64791 m .36135 .64489 L .35959 .64678 L F
.513 .914 .844 r
.35591 .64848 m .35852 .64791 L .35959 .64678 L F
.755 .658 .754 r
.36676 .68941 m .37099 .6899 L .3684 .69317 L F
.394 0 0 r
.36032 .68626 m .35434 .68684 L .35857 .68611 L F
.701 .586 .724 r
.60945 .36358 m .613 .36337 L .61344 .36132 L F
.606 .384 .553 r
.60945 .36358 m .61248 .36574 L .613 .36337 L F
.60945 .36358 m .61063 .36606 L .61248 .36574 L F
.67 .969 .916 r
.26714 .52073 m .26689 .52226 L .2689 .5207 L F
.26714 .52073 m .26403 .52253 L .26689 .52226 L F
.418 .828 .974 r
.57322 .38596 m .57086 .38647 L .56935 .38592 L F
.281 .575 .939 r
.43616 .59564 m .4381 .59777 L .43706 .59828 L F
.319 .796 .912 r
.4381 .59777 m .43944 .59696 L .43706 .59828 L F
.4381 .59777 m .44061 .59737 L .43944 .59696 L F
.815 .915 .906 r
.62428 .37137 m .62533 .3728 L .62264 .37311 L F
.85 .576 .524 r
.62264 .37311 m .62533 .3728 L .62471 .37533 L F
.663 .861 .975 r
.62428 .37137 m .62533 .3728 L .62637 .37127 L F
.743 .991 .803 r
.62533 .3728 m .62815 .37026 L .62637 .37127 L F
0 0 .069 r
.62471 .37533 m .62533 .3728 L .62637 .37127 L F
.687 .666 .824 r
.48657 .52774 m .48445 .53045 L .48394 .52804 L F
.779 .516 .537 r
.36922 .68319 m .37206 .68293 L .37229 .68025 L F
.528 .22 .39 r
.50971 .49256 m .50938 .49477 L .50628 .49501 L F
.398 .174 .453 r
.5124 .48931 m .5122 .49184 L .50971 .49256 L F
.498 .26 .484 r
.5122 .49184 m .50938 .49477 L .50971 .49256 L F
.873 .909 .852 r
.37863 .62909 m .37964 .62506 L .37723 .62789 L F
.37863 .62909 m .38123 .62605 L .37964 .62506 L F
.946 .889 .742 r
.37576 .62977 m .37863 .62909 L .37723 .62789 L F
.514 .294 .518 r
.50103 .49922 m .50095 .5018 L .49835 .50237 L F
.582 .407 .609 r
.50364 .49579 m .50361 .49881 L .50103 .49922 L F
.573 .349 .538 r
.50361 .49881 m .50095 .5018 L .50103 .49922 L F
.285 .21 .594 r
.43224 .55432 m .43449 .55299 L .43398 .55007 L F
.413 .342 .668 r
.43249 .55723 m .43449 .55299 L .43224 .55432 L F
.719 .956 .675 r
.3262 .65867 m .32417 .66112 L .32492 .65945 L F
.418 .733 .991 r
.32417 .66112 m .32683 .661 L .32492 .65945 L F
.609 .38 .544 r
.5437 .4304 m .54625 .42805 L .54484 .42692 L F
.5437 .4304 m .54674 .4309 L .54625 .42805 L F
.315 .184 .538 r
.54625 .42805 m .54745 .42622 L .54484 .42692 L F
.54625 .42805 m .54875 .43022 L .54745 .42622 L F
.54625 .42805 m .54674 .4309 L .54875 .43022 L F
.617 .471 .66 r
.36454 .58506 m .36114 .5835 L .36306 .582 L F
.36454 .58506 m .36158 .58625 L .36114 .5835 L F
.581 .406 .609 r
.50664 .49813 m .50364 .49579 L .50628 .49501 L F
.50664 .49813 m .50361 .49881 L .50364 .49579 L F
.542 .803 .994 r
.35075 .55364 m .34822 .55447 L .3487 .55229 L F
.858 .662 .127 r
.22999 .5855 m .22998 .58282 L .23041 .58179 L F
.97 .852 .448 r
.22918 .58373 m .22999 .5855 L .23041 .58179 L F
0 0 .329 r
.22918 .58373 m .22952 .58443 L .22999 .5855 L F
.858 .662 .127 r
.22999 .5855 m .2303 .58621 L .22998 .58282 L F
.22999 .5855 m .23035 .58672 L .2303 .58621 L F
.828 .354 .001 r
.22999 .5855 m .23204 .58769 L .23035 .58672 L F
.22999 .5855 m .23123 .58797 L .23204 .58769 L F
0 0 .329 r
.22952 .58443 m .23123 .58797 L .22999 .5855 L F
.395 0 .137 r
.36485 .55393 m .36748 .55348 L .36826 .55233 L F
.593 .568 .795 r
.36621 .54646 m .36826 .55233 L .37051 .5503 L F
.464 .055 .178 r
.36748 .55348 m .36988 .5533 L .36826 .55233 L F
.391 .843 .915 r
.44629 .49625 m .44908 .49548 L .44651 .49599 L F
.687 .98 .836 r
.64237 .3331 m .64056 .33474 L .63882 .33501 L F
.515 .086 .163 r
.70528 .30946 m .70758 .30813 L .70844 .30712 L F
0 0 .55 r
.38112 .59304 m .37977 .5899 L .38281 .59005 L F
.881 .75 .243 r
.7432 .30999 m .7432 .31434 L .74395 .31187 L F
.779 .512 .531 r
.33822 .52501 m .33348 .52698 L .33422 .52443 L F
.33822 .52501 m .33813 .52762 L .33348 .52698 L F
.99 .762 .496 r
.31458 .63494 m .31463 .63768 L .31527 .63737 L F
.404 .033 .216 r
.31204 .63994 m .31527 .63737 L .31463 .63768 L F
.31204 .63994 m .31458 .64 L .31527 .63737 L F
.271 .357 .769 r
.31527 .63737 m .31706 .63645 L .31458 .63494 L F
.704 .921 .585 r
.6827 .31888 m .68125 .32136 L .68383 .31803 L F
.681 .913 .974 r
.68016 .32032 m .68125 .32136 L .6827 .31888 L F
.91 .571 .388 r
.31295 .60908 m .31105 .61077 L .31091 .60859 L F
.31295 .60908 m .31105 .61077 L .31091 .60859 L F
.738 .68 .795 r
.24608 .57732 m .24483 .5771 L .24705 .57672 L F
0 0 0 r
.24483 .5771 m .24519 .57755 L .24705 .57672 L F
.536 .124 .207 r
.24519 .57755 m .24799 .57613 L .24705 .57672 L F
.24799 .57613 m .24979 .57523 L .24705 .57672 L F
.738 .68 .795 r
.24854 .57775 m .24608 .57732 L .24705 .57672 L F
.578 .718 .938 r
.24979 .57523 m .24854 .57775 L .24705 .57672 L F
.24979 .57523 m .25075 .57721 L .24854 .57775 L F
.567 .36 .559 r
.3971 .47006 m .39976 .47202 L .39954 .46941 L F
.3971 .47006 m .39706 .47273 L .39976 .47202 L F
.92 .673 .549 r
.24347 .5956 m .24066 .59545 L .24087 .59226 L F
0 .135 .579 r
.24347 .5956 m .24309 .59531 L .24066 .59545 L F
.24347 .5956 m .24511 .59678 L .24309 .59531 L F
.434 .384 .703 r
.36162 .60508 m .3595 .60592 L .35914 .60359 L F
.28 .038 .357 r
.36162 .60508 m .35899 .60831 L .3595 .60592 L F
.932 .774 .663 r
.3419 .57059 m .34009 .57302 L .33978 .56949 L F
.557 .238 .384 r
.3419 .57059 m .34009 .57302 L .34393 .57248 L F
0 .183 .71 r
.3419 .57059 m .34278 .56924 L .33978 .56949 L F
.3419 .57059 m .34393 .57248 L .34278 .56924 L F
.434 .384 .703 r
.36162 .60508 m .35914 .60359 L .36165 .60243 L F
.256 .364 .783 r
.73151 .31015 m .73017 .3131 L .72923 .3115 L F
.673 .65 .819 r
.35245 .6967 m .35355 .69238 L .35117 .69273 L F
.35245 .6967 m .35509 .69602 L .35355 .69238 L F
.624 .81 .971 r
.39706 .47273 m .40116 .47329 L .39976 .47202 L F
.839 .39 0 r
.40116 .47329 m .40184 .475 L .39976 .47202 L F
.986 .723 .439 r
.40114 .49759 m .40266 .49911 L .40267 .4959 L F
.626 .15 .105 r
.40548 .49789 m .40267 .4959 L .4037 .49413 L F
.472 .282 .541 r
.40267 .4959 m .40266 .49911 L .40548 .49789 L F
.626 .15 .105 r
.40548 .49789 m .40114 .49759 L .40267 .4959 L F
.094 0 .363 r
.4378 .48114 m .43634 .47986 L .43987 .47932 L F
.874 .719 .686 r
.44383 .48511 m .44021 .48505 L .44066 .4806 L F
.858 .864 .843 r
.44054 .48184 m .44106 .4815 L .44066 .4806 L F
.44021 .48505 m .44106 .4815 L .44054 .48184 L F
.388 .837 .735 r
.44106 .4815 m .43919 .48225 L .44159 .48116 L F
.44106 .4815 m .44159 .48116 L .44332 .48037 L F
.227 0 0 r
.44106 .4815 m .43859 .48146 L .4378 .48114 L F
0 0 0 r
.4378 .48114 m .43578 .48422 L .4363 .48266 L F
.094 0 .363 r
.4378 .48114 m .4363 .48266 L .43633 .48054 L F
.273 0 .1 r
.4363 .48266 m .43578 .48422 L .43271 .48489 L F
.871 .77 .747 r
.43378 .48322 m .43578 .48422 L .4378 .48114 L F
.227 0 0 r
.43859 .48146 m .43696 .48143 L .4378 .48114 L F
.094 0 .363 r
.4378 .48114 m .43633 .48054 L .43634 .47986 L F
0 0 0 r
.61344 .36132 m .613 .36337 L .61347 .36138 L F
0 0 .081 r
.613 .36337 m .6142 .3634 L .61347 .36138 L F
.613 .36337 m .61248 .36574 L .6142 .3634 L F
.008 .519 .862 r
.58431 .38538 m .58455 .38488 L .58324 .38383 L F
.58431 .38538 m .5863 .38588 L .58455 .38488 L F
.15 0 .218 r
.33442 .63419 m .33255 .63519 L .33163 .63752 L F
.431 .374 .693 r
.48417 .53742 m .48285 .5388 L .48184 .53599 L F
.684 .979 .879 r
.33282 .5333 m .33045 .53488 L .33145 .53319 L F
.633 .935 .965 r
.33145 .53319 m .32952 .5346 L .33045 .53488 L F
.33045 .53488 m .32952 .5346 L .33145 .53319 L F
.465 0 0 r
.37545 .50116 m .37476 .50246 L .37196 .50115 L F
.796 .888 .911 r
.37861 .498 m .37545 .50116 L .37473 .49849 L F
.71 .173 0 r
.37545 .50116 m .37824 .5043 L .37476 .50246 L F
.462 0 0 r
.33245 .49969 m .33709 .50138 L .33509 .5008 L F
.184 0 .092 r
.33104 .5224 m .33422 .52443 L .3338 .52173 L F
.33104 .5224 m .33023 .52439 L .33242 .52328 L F
.655 .598 .779 r
.41075 .48848 m .40784 .49232 L .40753 .48972 L F
.607 .839 .988 r
.41075 .48848 m .40753 .48972 L .40624 .48837 L F
0 0 0 r
.32306 .60553 m .32341 .60414 L .32367 .6022 L F
.943 .79 .33 r
.32355 .60761 m .32341 .60414 L .32306 .60553 L F
0 0 .316 r
.32306 .60553 m .32286 .60895 L .32355 .60761 L F
0 0 0 r
.223 .55367 m .22067 .55739 L .22211 .55572 L F
0 0 .442 r
.22107 .56006 m .22211 .55572 L .22067 .55739 L F
.896 .947 .832 r
.60312 .45661 m .60116 .45932 L .60194 .46015 L F
.731 .391 .405 r
.44038 .56629 m .43834 .56659 L .43854 .56398 L F
.44038 .56629 m .44352 .56823 L .43834 .56659 L F
.729 .648 .768 r
.44314 .56308 m .44352 .56823 L .44038 .56629 L F
.472 .829 .564 r
.33144 .50884 m .33279 .50764 L .33416 .51078 L F
.33144 .50884 m .32959 .51032 L .33279 .50764 L F
.497 .367 .634 r
.33416 .51078 m .33162 .51195 L .33144 .50884 L F
.828 .368 .124 r
.5556 .43226 m .55696 .43115 L .55451 .43068 L F
.373 .239 .568 r
.55855 .42779 m .55696 .43115 L .55917 .43037 L F
.618 .136 .088 r
.55696 .43115 m .55951 .43302 L .55754 .43387 L F
0 0 0 r
.55917 .43037 m .55696 .43115 L .5556 .43226 L F
.197 0 0 r
.2913 .66287 m .29351 .66312 L .28938 .66302 L F
0 0 .175 r
.33365 .64119 m .33449 .63759 L .33378 .6397 L F
.13 .212 .682 r
.33653 .63644 m .33449 .63759 L .33442 .63419 L F
0 0 0 r
.33378 .6397 m .33449 .63759 L .33653 .63644 L F
.973 .727 .503 r
.41432 .49463 m .41608 .49344 L .41159 .49289 L F
.41432 .49463 m .41604 .4963 L .41608 .49344 L F
.081 0 0 r
.43205 .50863 m .43501 .5087 L .4359 .50859 L F
.473 .781 .998 r
.43705 .50718 m .4387 .50844 L .4359 .50859 L F
.615 .955 .818 r
.4359 .50859 m .43501 .5087 L .43705 .50718 L F
.473 .781 .998 r
.43705 .50718 m .4387 .50844 L .4359 .50859 L F
.743 .487 .544 r
.44908 .49548 m .44492 .4974 L .44651 .49599 L F
.727 .308 0 r
.61215 .43091 m .61343 .43404 L .61002 .42981 L F
.61215 .43091 m .61416 .43469 L .61343 .43404 L F
.878 .891 .838 r
.38536 .67758 m .38247 .67995 L .38273 .68001 L F
.554 .434 .67 r
.38536 .67758 m .38608 .68057 L .38495 .68143 L F
.758 .561 .631 r
.38273 .68001 m .38608 .68057 L .38536 .67758 L F
.603 .709 .919 r
.35653 .68275 m .35434 .68684 L .35471 .68362 L F
.35653 .68275 m .35857 .68611 L .35434 .68684 L F
.958 .943 .711 r
.36466 .62114 m .36743 .61821 L .36502 .61803 L F
.42 .777 .996 r
.36857 .61642 m .36928 .61735 L .36579 .6171 L F
.988 .887 .56 r
.3685 .61664 m .36928 .61735 L .36857 .61642 L F
.274 .719 .961 r
.36928 .61735 m .37035 .61833 L .36743 .61821 L F
.547 .205 .34 r
.36743 .61821 m .37166 .61839 L .36943 .62227 L F
0 0 .48 r
.36928 .61735 m .36743 .61821 L .36943 .62227 L F
.988 .887 .56 r
.36775 .6192 m .36928 .61735 L .3685 .61664 L F
.274 .719 .961 r
.36928 .61735 m .37166 .61839 L .37035 .61833 L F
.811 .894 .902 r
.42826 .58487 m .42728 .58774 L .425 .58351 L F
.42826 .58487 m .42918 .5864 L .42728 .58774 L F
.922 .976 .729 r
.42489 .58813 m .42728 .58774 L .42918 .5864 L F
0 0 0 r
.62721 .36648 m .62929 .36339 L .62904 .36496 L F
.62904 .36496 m .62929 .36339 L .63093 .36142 L F
.495 .024 .066 r
.33113 .50115 m .33245 .49969 L .33509 .5008 L F
.657 .702 .879 r
.43138 .45721 m .42727 .4563 L .42991 .45441 L F
.252 0 0 r
.461 .59244 m .46184 .59372 L .45922 .59401 L F
.461 .59244 m .46353 .59216 L .46184 .59372 L F
.715 .72 .853 r
.62264 .37311 m .62246 .3762 L .62125 .37166 L F
.539 .566 .831 r
.62471 .37533 m .62246 .3762 L .62264 .37311 L F
.766 .675 .762 r
.62471 .37533 m .62238 .37922 L .62246 .3762 L F
.538 .321 .533 r
.31623 .5665 m .31349 .5696 L .31381 .56704 L F
0 0 0 r
.58647 .36636 m .58878 .36439 L .58964 .3626 L F
.359 .679 .978 r
.58867 .36152 m .59199 .3625 L .58964 .3626 L F
.875 .63 .104 r
.58964 .3626 m .58997 .36627 L .59199 .3625 L F
.318 .751 .97 r
.58997 .36627 m .58878 .36439 L .58647 .36636 L F
.845 .962 .63 r
.58728 .36866 m .58689 .36814 L .58878 .36502 L F
.58887 .3651 m .58878 .36502 L .58927 .36421 L F
.58728 .36866 m .58878 .36502 L .58887 .3651 L F
.875 .63 .104 r
.58964 .3626 m .58878 .36439 L .58964 .36575 L F
.58995 .366 m .58964 .36575 L .58997 .36627 L F
.58964 .3626 m .58964 .36575 L .58995 .366 L F
.571 .065 .013 r
.61409 .35354 m .61273 .35486 L .61039 .35463 L F
.545 .036 0 r
.61409 .35354 m .61694 .35518 L .61273 .35486 L F
.831 .711 .732 r
.3561 .64348 m .35303 .6449 L .35406 .64412 L F
0 0 0 r
.3561 .64348 m .35406 .64412 L .35303 .6449 L F
.753 .703 .805 r
.425 .58351 m .42109 .58273 L .4236 .58215 L F
.274 .463 .864 r
.42612 .58156 m .425 .58351 L .4236 .58215 L F
.42612 .58156 m .42826 .58487 L .425 .58351 L F
.925 .74 .632 r
.60325 .44408 m .60189 .44016 L .60213 .44374 L F
.965 .719 .516 r
.60301 .44689 m .60325 .44408 L .60213 .44374 L F
0 0 .292 r
.22944 .55939 m .22987 .56218 L .22936 .56319 L F
.041 .357 .83 r
.58037 .38251 m .58047 .38139 L .57716 .37905 L F
0 .001 .577 r
.58037 .38251 m .58066 .38111 L .58047 .38139 L F
.07 .416 .865 r
.58037 .38251 m .58324 .38383 L .58066 .38111 L F
.474 .292 .553 r
.34504 .60789 m .34216 .61135 L .34266 .60886 L F
.465 .228 .469 r
.51502 .48866 m .5122 .49184 L .5124 .48931 L F
0 0 0 r
.35959 .64678 m .36135 .64489 L .36321 .64336 L F
.735 .218 0 r
.3664 .51137 m .36853 .5139 L .37014 .5148 L F
.891 .485 .236 r
.36853 .5139 m .37193 .51792 L .37014 .5148 L F
.847 .415 .202 r
.37014 .5148 m .37193 .51792 L .3741 .51841 L F
0 0 .015 r
.31927 .64413 m .32048 .64161 L .32258 .63976 L F
.263 .763 .889 r
.2533 .5245 m .24917 .52456 L .25062 .52575 L F
.42 .852 .727 r
.68627 .31668 m .68639 .31644 L .68383 .31803 L F
.558 .342 .543 r
.68639 .31644 m .6827 .31888 L .68383 .31803 L F
.948 .905 .746 r
.42489 .58813 m .42918 .5864 L .42826 .58487 L F
.571 .115 .13 r
.46158 .53462 m .46411 .53523 L .46522 .53464 L F
.595 .209 .28 r
.46411 .53523 m .46812 .53441 L .46522 .53464 L F
.954 .876 .719 r
.42699 .55013 m .42526 .5534 L .42674 .55356 L F
.846 .58 .535 r
.42455 .55615 m .42674 .55356 L .42526 .5534 L F
.42455 .55615 m .42849 .55694 L .42674 .55356 L F
.643 .895 .984 r
.59725 .3674 m .59232 .36793 L .59578 .36561 L F
.719 .798 .914 r
.59578 .36561 m .59981 .36607 L .59725 .3674 L F
.403 .439 .784 r
.35058 .68224 m .34895 .68555 L .34823 .68126 L F
.825 .998 .778 r
.31242 .56078 m .31297 .55853 L .31487 .56029 L F
.31242 .56078 m .31011 .56167 L .31297 .55853 L F
0 0 0 r
.60429 .35617 m .60366 .3564 L .60129 .35701 L F
.60673 .35569 m .60429 .35617 L .60693 .35542 L F
.60673 .35569 m .60366 .3564 L .60429 .35617 L F
0 .177 .708 r
.72782 .32664 m .73096 .33036 L .72978 .32881 L F
.366 .739 .989 r
.73096 .33036 m .73287 .32912 L .72978 .32881 L F
.73096 .33036 m .73473 .33038 L .73287 .32912 L F
0 0 .416 r
.32933 .60943 m .33017 .61059 L .32866 .60819 L F
.32933 .60943 m .33051 .6121 L .33017 .61059 L F
.476 .867 .971 r
.42281 .49667 m .42608 .49569 L .426 .49627 L F
.765 .932 .579 r
.426 .49627 m .42608 .49569 L .42815 .49254 L F
.885 .906 .837 r
.37964 .62506 m .38123 .62605 L .38235 .62461 L F
.942 .963 .71 r
.28398 .6218 m .28438 .62215 L .28484 .62124 L F
0 0 0 r
.28606 .6206 m .28433 .622 L .28484 .62124 L F
.652 .121 0 r
.28403 .62179 m .28433 .622 L .28484 .62124 L F
.657 .767 .931 r
.28606 .6206 m .28433 .622 L .28405 .62179 L F
0 0 0 r
.28606 .6206 m .2839 .62188 L .28484 .62124 L F
.652 .121 0 r
.28087 .61965 m .28403 .62179 L .28484 .62124 L F
.657 .767 .931 r
.28606 .6206 m .28405 .62179 L .28171 .62003 L F
0 0 0 r
.28606 .6206 m .28346 .62219 L .2839 .62188 L F
0 .185 .635 r
.28342 .62132 m .28405 .62179 L .28377 .62162 L F
.28405 .62179 m .28433 .622 L .28403 .62179 L F
.28405 .62179 m .28403 .62179 L .28377 .62162 L F
.942 .963 .71 r
.28237 .62285 m .28438 .62215 L .28398 .6218 L F
0 0 0 r
.28346 .62219 m .28237 .62285 L .28398 .6218 L F
.28403 .62179 m .28398 .6218 L .28484 .62124 L F
.28346 .62219 m .28398 .6218 L .28403 .62179 L F
0 .185 .635 r
.28171 .62003 m .28342 .62132 L .28087 .61965 L F
.28342 .62132 m .28377 .62162 L .28087 .61965 L F
.942 .963 .71 r
.28237 .62285 m .28287 .62515 L .28438 .62215 L F
0 .185 .635 r
.28171 .62003 m .28087 .61965 L .27928 .62021 L F
.895 .9 .823 r
.38235 .62461 m .38394 .62256 L .38099 .62327 L F
.888 .913 .837 r
.38099 .62327 m .38394 .62256 L .3824 .62158 L F
.893 .965 .639 r
.55596 .42503 m .55429 .42625 L .55457 .42656 L F
0 0 0 r
.55667 .42517 m .55596 .42503 L .55787 .42341 L F
.55667 .42517 m .55429 .42625 L .55596 .42503 L F
.883 .452 .086 r
.37335 .51947 m .3741 .51841 L .37193 .51792 L F
.37335 .51947 m .37511 .5211 L .3741 .51841 L F
0 0 0 r
.61344 .36132 m .61347 .36138 L .61575 .35968 L F
.987 .722 .358 r
.39373 .55877 m .39498 .55739 L .39336 .55631 L F
.39373 .55877 m .39491 .55995 L .39498 .55739 L F
.801 .929 .555 r
.29234 .6389 m .29467 .63475 L .29463 .63777 L F
.615 .792 .966 r
.29028 .63691 m .29234 .6389 L .29463 .63777 L F
.781 .831 .891 r
.42328 .45628 m .42727 .4563 L .42507 .45783 L F
.822 .695 .724 r
.61327 .37974 m .60909 .38121 L .61185 .37811 L F
.61327 .37974 m .61117 .38287 L .60909 .38121 L F
.58 .369 .559 r
.61327 .37974 m .61239 .38389 L .61117 .38287 L F
.72 .987 .876 r
.61453 .37766 m .61521 .37809 L .61327 .37974 L F
.517 .742 .977 r
.61453 .37766 m .61327 .37974 L .61185 .37811 L F
.61453 .37766 m .61327 .37974 L .61185 .37811 L F
.732 .585 .691 r
.61521 .37809 m .61239 .38389 L .61327 .37974 L F
.853 .511 .405 r
.32439 .59158 m .32804 .5932 L .32653 .58985 L F
0 .074 .604 r
.32653 .58985 m .32888 .59047 L .32955 .5882 L F
.32653 .58985 m .32804 .5932 L .32888 .59047 L F
.973 .68 .406 r
.38626 .5376 m .38667 .54061 L .38826 .54142 L F
.943 .58 .258 r
.38667 .54061 m .38869 .54368 L .38826 .54142 L F
.813 .875 .892 r
.29024 .52716 m .28995 .5285 L .29279 .52769 L F
.859 .96 .87 r
.51273 .4147 m .50875 .41681 L .51186 .41409 L F
.795 .937 .923 r
.51362 .41179 m .51273 .4147 L .51186 .41409 L F
.51362 .41179 m .51602 .41222 L .51273 .4147 L F
.175 .376 .822 r
.28718 .65226 m .2862 .65378 L .28402 .65091 L F
.147 .337 .797 r
.28792 .65452 m .2862 .65378 L .28718 .65226 L F
.025 .43 .866 r
.28973 .65611 m .2862 .65378 L .28792 .65452 L F
.689 .25 0 r
.58409 .39632 m .58359 .39497 L .58144 .39454 L F
0 .064 .553 r
.58352 .39574 m .58409 .39632 L .58267 .39497 L F
.689 .25 0 r
.58409 .39632 m .58486 .3971 L .58359 .39497 L F
0 .049 .586 r
.58691 .39882 m .58359 .39497 L .58543 .39805 L F
0 .064 .553 r
.58574 .39774 m .58409 .39632 L .58352 .39574 L F
.689 .25 0 r
.58409 .39632 m .58543 .39805 L .58486 .3971 L F
.773 .98 .718 r
.35391 .59414 m .35608 .59264 L .35462 .59175 L F
.837 .929 .891 r
.3572 .58921 m .35608 .59264 L .35918 .59047 L F
.3572 .58921 m .35462 .59175 L .35608 .59264 L F
.65 .57 .751 r
.35608 .59264 m .35826 .59264 L .35918 .59047 L F
.624 .391 .544 r
.35608 .59264 m .35887 .59536 L .35826 .59264 L F
.35608 .59264 m .35513 .59727 L .35887 .59536 L F
.506 .693 .952 r
.33384 .52976 m .33192 .53189 L .33117 .5297 L F
.559 .649 .895 r
.33384 .52976 m .33282 .5333 L .33192 .53189 L F
.118 0 .102 r
.23246 .5538 m .2293 .55676 L .23097 .55443 L F
.729 .791 .902 r
.34486 .52486 m .34128 .52608 L .34366 .52133 L F
.767 .883 .929 r
.49945 .42519 m .49416 .42654 L .49844 .42368 L F
.843 .91 .881 r
.5007 .42393 m .49945 .42519 L .49844 .42368 L F
.536 .715 .955 r
.5341 .43783 m .53449 .43722 L .53221 .43773 L F
.53202 .44104 m .53527 .44088 L .53449 .43722 L F
.903 .723 .22 r
.53449 .43722 m .53466 .43798 L .53512 .43774 L F
.53466 .43798 m .53527 .44088 L .53518 .43904 L F
.53466 .43798 m .53518 .43904 L .53512 .43774 L F
.53449 .43722 m .53512 .43774 L .53362 .4362 L F
.233 .661 .958 r
.5341 .43686 m .53533 .43789 L .53413 .43686 L F
.418 .586 .911 r
.53068 .43556 m .53093 .43802 L .53449 .43722 L F
.52872 .4347 m .5295 .43587 L .53068 .43556 L F
.5295 .43587 m .53093 .43802 L .53068 .43556 L F
.52872 .4347 m .53449 .43722 L .53196 .43693 L F
.364 .308 .661 r
.53242 .4351 m .53196 .43693 L .53413 .43686 L F
.53148 .43414 m .53168 .4353 L .53242 .4351 L F
.53168 .4353 m .53196 .43693 L .53242 .4351 L F
.472 .43 .729 r
.53512 .43774 m .53527 .44088 L .53771 .43975 L F
.749 .574 .658 r
.53449 .43722 m .5356 .43797 L .53196 .43693 L F
.233 .661 .958 r
.53196 .43693 m .5345 .43766 L .5341 .43686 L F
.5345 .43766 m .53533 .43789 L .5341 .43686 L F
.472 .43 .729 r
.53512 .43774 m .53771 .43975 L .53714 .43647 L F
.233 .661 .958 r
.53533 .43789 m .5356 .43797 L .53551 .4379 L F
.83 .75 .775 r
.53512 .43774 m .53548 .43277 L .53362 .4362 L F
.233 .661 .958 r
.53533 .43789 m .53551 .4379 L .53413 .43686 L F
.536 .715 .955 r
.53202 .44104 m .5341 .43783 L .53093 .43802 L F
.5341 .43783 m .53221 .43773 L .53093 .43802 L F
.503 .138 .281 r
.5345 .44257 m .53202 .44104 L .53172 .44308 L F
.5345 .44257 m .53527 .44088 L .53202 .44104 L F
.535 .886 .654 r
.66479 .38571 m .66794 .38325 L .66655 .38402 L F
0 0 0 r
.66655 .38402 m .66794 .38325 L .67033 .38201 L F
.975 .711 .466 r
.34843 .51208 m .34603 .51208 L .34449 .51129 L F
.34843 .51208 m .34842 .5143 L .34603 .51208 L F
.516 .377 .629 r
.50095 .5018 m .4985 .50547 L .49835 .50237 L F
.491 .897 .925 r
.65803 .39 m .66231 .38918 L .66132 .38851 L F
0 0 0 r
.6638 .38712 m .66231 .38918 L .66479 .38571 L F
.648 .942 .961 r
.66132 .38851 m .66231 .38918 L .6638 .38712 L F
.304 0 .236 r
.55861 .46991 m .56046 .47164 L .55792 .47151 L F
.55861 .46991 m .56102 .46903 L .56046 .47164 L F
.575 .908 .672 r
.67757 .36573 m .67389 .36855 L .67722 .36645 L F
0 0 .121 r
.68026 .36263 m .67757 .36573 L .67951 .36496 L F
0 0 0 r
.67757 .36573 m .67722 .36645 L .67951 .36496 L F
0 .308 .754 r
.58603 .45757 m .58679 .45865 L .58904 .4598 L F
0 .413 .701 r
.29351 .66312 m .29644 .66398 L .29616 .66231 L F
.388 .571 .91 r
.29616 .66231 m .29644 .66398 L .29857 .66227 L F
.574 .575 .816 r
.29741 .66683 m .29857 .66227 L .29644 .66398 L F
.162 0 .138 r
.57645 .42702 m .57783 .42654 L .57895 .42387 L F
.481 .332 .601 r
.57895 .42387 m .58154 .42401 L .5811 .42134 L F
.755 .582 .663 r
.57783 .42654 m .58154 .42401 L .57895 .42387 L F
0 0 .35 r
.38199 .67339 m .38123 .67399 L .38226 .67556 L F
.976 .746 .524 r
.37611 .60867 m .37742 .61154 L .3763 .61146 L F
.327 .721 .982 r
.37742 .61154 m .37911 .61076 L .3763 .61146 L F
.37815 .6116 m .38054 .6118 L .37911 .61076 L F
.871 .91 .854 r
.38322 .60888 m .38054 .6118 L .37911 .61076 L F
.38322 .60888 m .38054 .6118 L .37911 .61076 L F
.968 .649 .333 r
.38054 .6118 m .37937 .6139 L .37911 .61076 L F
.871 .91 .854 r
.38322 .60888 m .37911 .61076 L .37891 .60814 L F
.276 .731 .955 r
.37891 .60814 m .3821 .60869 L .38177 .60813 L F
.3821 .60869 m .38322 .60888 L .38177 .60813 L F
.546 .598 .857 r
.37891 .60814 m .38177 .60813 L .37944 .6042 L F
.559 .382 .597 r
.37891 .60814 m .37911 .61076 L .38177 .60813 L F
.871 .91 .854 r
.38322 .60888 m .37911 .61076 L .38177 .60813 L F
0 0 .201 r
.37911 .61076 m .37979 .61247 L .38029 .60974 L F
.892 .78 .287 r
.3799 .61008 m .38031 .60963 L .37979 .61247 L F
0 0 0 r
.38086 .60902 m .37911 .61076 L .38031 .60963 L F
.892 .78 .287 r
.38004 .60719 m .38031 .60963 L .3799 .61008 L F
0 0 0 r
.38177 .60813 m .38086 .60902 L .38031 .60963 L F
.908 .938 .574 r
.38128 .6073 m .38177 .60813 L .38031 .60963 L F
.102 .341 .812 r
.37944 .6042 m .38177 .60813 L .38184 .60595 L F
.908 .938 .574 r
.38184 .60595 m .38177 .60813 L .38128 .6073 L F
0 0 .201 r
.37911 .61076 m .38029 .60974 L .38031 .60963 L F
.327 .721 .982 r
.37742 .61154 m .37815 .6116 L .37911 .61076 L F
.576 .31 .476 r
.36471 .59946 m .36442 .60221 L .36165 .60243 L F
.317 0 0 r
.37087 .60166 m .3697 .60201 L .36951 .59976 L F
.644 .369 .488 r
.36951 .59976 m .36471 .59946 L .36954 .60004 L F
.317 0 0 r
.3697 .60201 m .36881 .60228 L .36951 .59976 L F
.644 .369 .488 r
.36951 .59976 m .36954 .60004 L .36976 .60007 L F
.36951 .59976 m .36442 .60221 L .36471 .59946 L F
.675 .868 .972 r
.43906 .45269 m .44306 .45273 L .44061 .45385 L F
.817 .721 .759 r
.33051 .6121 m .32799 .61517 L .32681 .61212 L F
.33051 .6121 m .32681 .61212 L .32801 .61283 L F
.843 .994 .843 r
.33051 .6121 m .32801 .61283 L .33017 .61059 L F
.204 .079 .478 r
.33029 .55924 m .32887 .55738 L .33085 .55681 L F
.33029 .55924 m .32871 .56031 L .32887 .55738 L F
.972 .678 .405 r
.43208 .46238 m .42861 .4656 L .429 .46352 L F
.43208 .46238 m .43114 .4643 L .42861 .4656 L F
.43208 .46238 m .433 .46636 L .43114 .4643 L F
.735 .591 .695 r
.62706 .41454 m .63096 .4164 L .63001 .41061 L F
0 0 .381 r
.63001 .41061 m .63096 .4164 L .63153 .41475 L F
.659 .97 .895 r
.63153 .41475 m .63096 .4164 L .62965 .41638 L F
.392 .833 .706 r
.63015 .41688 m .63229 .41554 L .62965 .41638 L F
.63015 .41688 m .63408 .41483 L .63229 .41554 L F
.655 .598 .779 r
.41075 .48848 m .41159 .49289 L .40784 .49232 L F
.885 .906 .837 r
.37964 .62506 m .38235 .62461 L .38099 .62327 L F
.824 .445 0 r
.58673 .39975 m .58691 .39882 L .58543 .39805 L F
.58673 .39975 m .5878 .40136 L .58691 .39882 L F
.94 .63 .424 r
.60128 .43965 m .60144 .43779 L .59994 .43588 L F
.60128 .43965 m .60189 .44016 L .60144 .43779 L F
.647 .697 .883 r
.33966 .53418 m .33728 .53516 L .33554 .53317 L F
.248 .097 .47 r
.33966 .53418 m .33788 .53751 L .33728 .53516 L F
.877 .84 .806 r
.37358 .69244 m .37708 .69233 L .37749 .69064 L F
.379 0 .026 r
.5427 .47853 m .54362 .47694 L .54544 .47796 L F
.271 0 .281 r
.54362 .47694 m .54571 .47613 L .54544 .47796 L F
.551 .649 .9 r
.3751 .60434 m .37653 .60618 L .3782 .60535 L F
.567 .403 .618 r
.37611 .60867 m .3782 .60535 L .37653 .60618 L F
.918 .537 .27 r
.59994 .43588 m .60091 .43551 L .59714 .43272 L F
.332 .111 .421 r
.69247 .33292 m .69068 .33414 L .69115 .3358 L F
.342 .259 .616 r
.32143 .54111 m .32375 .54296 L .32391 .54109 L F
.32143 .54111 m .32185 .54399 L .32375 .54296 L F
.956 .743 .29 r
.59239 .41619 m .59316 .41491 L .59212 .41404 L F
.59239 .41619 m .59316 .41776 L .59316 .41491 L F
.965 .94 .667 r
.39285 .60084 m .39359 .6022 L .39499 .59934 L F
.923 .971 .691 r
.39433 .59871 m .39285 .60084 L .39499 .59934 L F
.993 .755 .466 r
.62721 .36648 m .62815 .37026 L .62652 .36848 L F
.944 .861 .728 r
.62637 .37127 m .62815 .37026 L .62652 .36848 L F
.532 .515 .782 r
.63025 .36883 m .62815 .37026 L .62721 .36648 L F
.461 .861 .68 r
.62637 .37127 m .62815 .37026 L .63025 .36883 L F
0 0 0 r
.47128 .58793 m .47019 .58945 L .47262 .58604 L F
.633 .937 .7 r
.46798 .5908 m .47019 .58945 L .47128 .58793 L F
.964 .83 .663 r
.3811 .49234 m .37823 .4948 L .37965 .49111 L F
.3811 .49234 m .37984 .49606 L .37823 .4948 L F
.979 .689 .322 r
.39487 .56269 m .39628 .56631 L .39636 .5637 L F
0 .073 .635 r
.3411 .59855 m .34366 .60176 L .34294 .59841 L F
.482 .085 .211 r
.34294 .59841 m .33894 .6007 L .3411 .59855 L F
.981 .857 .642 r
.60597 .41453 m .60378 .41644 L .60402 .41386 L F
.60597 .41453 m .6051 .41763 L .60378 .41644 L F
.381 0 0 r
.25919 .62719 m .26299 .62676 L .26034 .6249 L F
.513 .008 0 r
.26168 .62893 m .26299 .62676 L .26456 .62776 L F
.485 .901 .87 r
.61347 .36138 m .61793 .36021 L .61575 .35968 L F
.433 .827 .609 r
.36609 .63796 m .36913 .63583 L .36752 .63689 L F
0 0 .292 r
.36589 .64075 m .36609 .63796 L .36752 .63689 L F
.582 .037 0 r
.39386 .47533 m .39688 .47806 L .39859 .47907 L F
.501 .854 .993 r
.39859 .47907 m .39963 .47744 L .40184 .475 L F
.39859 .47907 m .39688 .47806 L .39963 .47744 L F
.569 .172 .25 r
.30096 .65321 m .30149 .65115 L .29681 .65153 L F
.399 .796 .986 r
.45732 .53416 m .4588 .53407 L .46158 .53462 L F
0 0 .28 r
.46158 .53462 m .46266 .53549 L .46411 .53523 L F
.46158 .53462 m .46156 .53778 L .46266 .53549 L F
.589 .55 .778 r
.38278 .48263 m .38472 .47861 L .38186 .47936 L F
.482 .18 .377 r
.52707 .47962 m .52707 .4818 L .52414 .48198 L F
.566 .245 .384 r
.52707 .47962 m .52966 .48156 L .52707 .4818 L F
.568 .245 .381 r
.52975 .47953 m .52966 .48156 L .52707 .47962 L F
.614 .115 0 r
.28746 .66071 m .28938 .66302 L .28776 .66143 L F
0 0 0 r
.47528 .58293 m .47431 .58505 L .47262 .58604 L F
.47262 .58604 m .47431 .58505 L .47128 .58793 L F
.162 .701 .808 r
.26141 .51638 m .26308 .51612 L .26568 .51623 L F
.187 .72 .784 r
.26308 .51612 m .26724 .51571 L .26568 .51623 L F
.743 .67 .779 r
.42132 .59895 m .42549 .59972 L .42383 .59838 L F
.623 .96 .87 r
.42654 .59828 m .42549 .59972 L .42764 .59834 L F
.422 .728 .989 r
.42383 .59838 m .42549 .59972 L .42654 .59828 L F
.705 .642 .784 r
.35509 .69602 m .35912 .69678 L .35772 .69298 L F
.486 .516 .813 r
.35772 .69298 m .35912 .69678 L .36119 .6963 L F
.489 .542 .837 r
.35912 .69678 m .36199 .6993 L .36119 .6963 L F
.791 .697 .761 r
.72768 .32047 m .72896 .32442 L .72526 .32339 L F
.773 .886 .471 r
.72896 .32442 m .72766 .32609 L .72526 .32339 L F
0 0 .54 r
.72782 .32664 m .72978 .32881 L .72766 .32609 L F
.258 .507 .902 r
.72766 .32609 m .72978 .32881 L .73086 .3283 L F
.653 .097 0 r
.72766 .32609 m .73086 .3283 L .72706 .32653 L F
.72766 .32609 m .72706 .32653 L .72705 .32652 L F
.773 .886 .471 r
.72896 .32442 m .72836 .32559 L .72766 .32609 L F
.72836 .32559 m .72782 .32664 L .72766 .32609 L F
.627 .605 .809 r
.7317 .32289 m .72896 .32442 L .72768 .32047 L F
.589 .848 .994 r
.73488 .32355 m .72896 .32442 L .7317 .32289 L F
.175 .376 .822 r
.28718 .65226 m .28402 .65091 L .28778 .65102 L F
.182 0 0 r
.43837 .5863 m .44149 .58686 L .44245 .58654 L F
0 0 0 r
.44149 .58686 m .44502 .58574 L .44245 .58654 L F
.646 .603 .791 r
.37287 .5309 m .37067 .53264 L .36868 .5305 L F
.874 .885 .839 r
.27802 .57339 m .27537 .57663 L .27358 .57555 L F
.578 .404 .609 r
.27537 .57663 m .27781 .57686 L .27802 .57339 L F
.728 .24 .083 r
.27781 .57686 m .27358 .57555 L .27537 .57663 L F
0 0 .009 r
.23004 .53788 m .2311 .53626 L .2316 .53391 L F
0 0 .157 r
.22928 .5403 m .2311 .53626 L .23004 .53788 L F
.887 .979 .822 r
.43108 .47288 m .43049 .47218 L .43285 .46927 L F
.469 .084 .227 r
.43108 .47288 m .4326 .47376 L .43049 .47218 L F
.43108 .47288 m .4326 .4745 L .4326 .47376 L F
.43108 .47288 m .42997 .47511 L .4326 .4745 L F
.04 .135 .636 r
.55942 .43549 m .55847 .43851 L .55754 .43387 L F
.55944 .43561 m .55847 .43851 L .55942 .43549 L F
.914 .805 .725 r
.55691 .4418 m .55964 .43759 L .55568 .4379 L F
.55964 .43759 m .55967 .43755 L .55963 .43755 L F
.55964 .43759 m .55963 .43755 L .55568 .4379 L F
.04 .135 .636 r
.55946 .43553 m .55944 .43561 L .55942 .43549 L F
0 0 0 r
.6638 .38712 m .66479 .38571 L .66655 .38402 L F
0 .454 .713 r
.34038 .49623 m .34149 .49654 L .33763 .49565 L F
0 .429 .698 r
.34419 .4972 m .34149 .49654 L .34038 .49623 L F
.063 .628 .739 r
.3286 .495 m .32945 .49505 L .32717 .49505 L F
.889 .649 .571 r
.33004 .49508 m .32945 .49505 L .33153 .49442 L F
.26 0 0 r
.33204 .49488 m .33153 .49442 L .32945 .49505 L F
.063 .628 .739 r
.33204 .49488 m .32945 .49505 L .3286 .495 L F
.889 .649 .571 r
.32924 .49544 m .32945 .49505 L .33004 .49508 L F
.32924 .49544 m .32671 .49607 L .32945 .49505 L F
.32924 .49544 m .32903 .49852 L .32671 .49607 L F
.697 .642 .791 r
.46014 .52819 m .46405 .52881 L .46275 .52726 L F
.709 .666 .805 r
.46275 .52726 m .46405 .52881 L .46678 .52803 L F
.386 .084 .326 r
.30567 .64098 m .30292 .64154 L .302 .64414 L F
.569 .882 .598 r
.32239 .63049 m .32135 .63172 L .31907 .6336 L F
.367 .003 .208 r
.41485 .51098 m .41829 .50774 L .41595 .50872 L F
.41485 .51098 m .41758 .51039 L .41829 .50774 L F
.337 .819 .817 r
.41829 .50774 m .41987 .50693 L .42012 .50705 L F
0 0 0 r
.41829 .50774 m .41865 .50871 L .41987 .50693 L F
.41829 .50774 m .41758 .51039 L .41865 .50871 L F
.642 .869 .502 r
.29298 .65274 m .2948 .65061 L .29485 .65032 L F
.892 .894 .823 r
.41292 .48268 m .40894 .48477 L .4115 .48426 L F
0 0 0 r
.41292 .48268 m .4147 .48171 L .41586 .48039 L F
.593 .316 .466 r
.4115 .48426 m .4147 .48171 L .41292 .48268 L F
.033 0 .441 r
.31942 .64717 m .31825 .64732 L .31927 .64413 L F
.449 .437 .753 r
.32102 .65056 m .31825 .64732 L .31942 .64717 L F
.489 .063 .159 r
.55105 .39394 m .55448 .39445 L .55571 .39285 L F
0 0 0 r
.55571 .39285 m .55643 .39271 L .55624 .39014 L F
0 0 .034 r
.47799 .57449 m .47758 .57352 L .47837 .57166 L F
.066 0 .329 r
.47919 .57281 m .47846 .57395 L .47799 .57449 L F
0 0 .034 r
.47799 .57449 m .47715 .57618 L .4773 .57527 L F
0 0 0 r
.47592 .57867 m .47799 .57449 L .47607 .57771 L F
.066 0 .329 r
.47846 .57395 m .47663 .57681 L .47799 .57449 L F
0 0 .034 r
.47799 .57449 m .4773 .57527 L .47758 .57352 L F
0 0 .446 r
.21783 .57319 m .21772 .57714 L .21895 .57524 L F
.119 .167 .637 r
.21772 .57714 m .21977 .57764 L .21895 .57524 L F
.21772 .57714 m .21848 .57945 L .21977 .57764 L F
.633 .112 0 r
.34284 .52665 m .34489 .52764 L .34065 .52689 L F
.34284 .52665 m .34489 .52764 L .34065 .52689 L F
.73 .761 .256 r
.70044 .35456 m .69985 .35695 L .70103 .353 L F
0 0 0 r
.69929 .35937 m .69985 .35695 L .70044 .35456 L F
.837 .735 .752 r
.5892 .40477 m .59092 .40199 L .5878 .40136 L F
.635 .903 .593 r
.66851 .37162 m .66577 .37481 L .66486 .37475 L F
.592 .519 .741 r
.34362 .61396 m .34105 .61505 L .34001 .61207 L F
.514 .362 .613 r
.5471 .40197 m .54968 .40108 L .54956 .39855 L F
.713 .603 .732 r
.54968 .40108 m .54693 .40459 L .5471 .40197 L F
0 0 .161 r
.5471 .40197 m .54693 .40459 L .54788 .40222 L F
.782 .998 .839 r
.54788 .40222 m .54693 .40459 L .54632 .40406 L F
.771 .578 .638 r
.54693 .40459 m .54602 .40459 L .54632 .40406 L F
.54602 .40459 m .54259 .40462 L .54632 .40406 L F
.54693 .40459 m .54352 .40727 L .54259 .40462 L F
.128 0 0 r
.54492 .40521 m .54632 .40406 L .54259 .40462 L F
.612 .882 .559 r
.54665 .40346 m .54632 .40406 L .54492 .40521 L F
.54788 .40222 m .54632 .40406 L .54665 .40346 L F
.54788 .40222 m .54492 .40521 L .54695 .40385 L F
.54788 .40222 m .54695 .40385 L .54716 .40282 L F
.54788 .40222 m .54716 .40282 L .54742 .40147 L F
0 0 .161 r
.54897 .40133 m .54788 .40222 L .54968 .40108 L F
.5471 .40197 m .54788 .40222 L .54897 .40133 L F
.514 .362 .613 r
.5471 .40197 m .54968 .40108 L .54956 .39855 L F
.431 .374 .693 r
.48417 .53742 m .48533 .54015 L .48285 .5388 L F
.975 .684 .404 r
.60471 .45051 m .60301 .44689 L .60327 .44933 L F
.991 .77 .504 r
.60442 .45284 m .60471 .45051 L .60327 .44933 L F
.439 .044 .191 r
.29612 .5692 m .30032 .56673 L .29643 .56721 L F
.654 .964 .92 r
.3498 .59521 m .34728 .59653 L .34819 .59495 L F
.839 .73 .744 r
.38556 .58648 m .38517 .58881 L .38738 .58554 L F
.38556 .58648 m .38517 .58881 L .38738 .58554 L F
.454 .088 .253 r
.69521 .33119 m .69334 .33001 L .69247 .33292 L F
.69521 .33119 m .69594 .32991 L .69334 .33001 L F
.354 .504 .869 r
.29128 .65506 m .28973 .65611 L .28792 .65452 L F
.29128 .65506 m .29212 .65712 L .28973 .65611 L F
.971 .93 .669 r
.52338 .44247 m .52473 .43977 L .52407 .43776 L F
.52396 .43797 m .52407 .43776 L .52401 .43758 L F
.52338 .44247 m .52407 .43776 L .52396 .43797 L F
.982 .871 .504 r
.52401 .43758 m .52407 .43776 L .52389 .43847 L F
.52407 .43776 m .52473 .43977 L .52389 .43847 L F
.769 .569 .627 r
.52389 .43847 m .52872 .4347 L .52558 .43488 L F
.52415 .43761 m .52558 .43488 L .52494 .43491 L F
.52389 .43847 m .52558 .43488 L .52415 .43761 L F
.726 .917 .958 r
.52599 .4407 m .52786 .44055 L .52389 .43847 L F
.733 .919 .956 r
.52389 .43847 m .52786 .44055 L .53093 .43802 L F
.715 .536 .646 r
.33719 .5536 m .33313 .55578 L .3345 .55368 L F
.075 0 .249 r
.47949 .55375 m .48164 .55053 L .48089 .55316 L F
.215 .171 .59 r
.48089 .55316 m .48144 .55586 L .47949 .55375 L F
.737 .789 .895 r
.33208 .65695 m .33092 .66101 L .33308 .65943 L F
.871 .928 .86 r
.32928 .66026 m .33092 .66101 L .33208 .65695 L F
.77 .285 .078 r
.69115 .3358 m .69475 .33729 L .69365 .33848 L F
.976 .674 .314 r
.69475 .33729 m .69505 .34003 L .69365 .33848 L F
.956 .876 .473 r
.39617 .58734 m .39669 .58961 L .3974 .5857 L F
.982 .873 .507 r
.39617 .58734 m .39622 .59233 L .39669 .58961 L F
.674 .143 0 r
.52923 .44514 m .52993 .44476 L .52685 .44338 L F
.582 .911 .674 r
.53172 .44308 m .52993 .44476 L .52923 .44514 L F
.204 .551 .932 r
.24745 .62067 m .24847 .62125 L .24633 .62086 L F
0 .219 .658 r
.24847 .62125 m .24867 .62115 L .24633 .62086 L F
.192 0 0 r
.24516 .62106 m .24633 .62086 L .24867 .62115 L F
.24488 .62105 m .24633 .62086 L .24516 .62106 L F
.204 .551 .932 r
.24408 .61877 m .24745 .62067 L .24633 .62086 L F
0 .219 .658 r
.24847 .62125 m .25022 .62234 L .24867 .62115 L F
.6 .678 .896 r
.32341 .5355 m .32691 .53668 L .32622 .53447 L F
0 .203 .724 r
.32691 .53668 m .32812 .53623 L .32622 .53447 L F
.324 .218 .576 r
.3266 .5395 m .32812 .53623 L .32691 .53668 L F
.681 .949 .686 r
.63059 .39021 m .632 .3895 L .62921 .39227 L F
.204 .333 .773 r
.62921 .39227 m .63195 .39412 L .63059 .39021 L F
.524 .24 .425 r
.31349 .5696 m .31046 .57196 L .31096 .57008 L F
.781 .588 .639 r
.5565 .39567 m .55673 .39852 L .55223 .3981 L F
.766 .675 .762 r
.62471 .37533 m .62661 .3796 L .62238 .37922 L F
0 .119 .667 r
.62765 .37822 m .62661 .3796 L .6256 .37732 L F
.527 .122 .216 r
.62765 .37822 m .62588 .37618 L .6257 .37645 L F
0 .119 .667 r
.6257 .37645 m .6256 .37732 L .62488 .37571 L F
.62765 .37822 m .6256 .37732 L .62572 .37632 L F
.112 .653 .845 r
.6244 .37915 m .62661 .3796 L .62585 .37909 L F
.62238 .37922 m .62471 .37943 L .6244 .37915 L F
.62471 .37943 m .62661 .3796 L .6244 .37915 L F
.065 0 0 r
.62117 .37981 m .62238 .37922 L .62585 .37909 L F
.527 .122 .216 r
.62765 .37822 m .6257 .37645 L .62387 .37927 L F
0 .119 .667 r
.62572 .37632 m .6257 .37645 L .62471 .37533 L F
.6257 .37645 m .62488 .37571 L .62471 .37533 L F
.956 .942 .72 r
.62404 .37396 m .62471 .37533 L .62479 .37513 L F
.62404 .37396 m .62479 .37513 L .62637 .37127 L F
.715 .72 .853 r
.62264 .37311 m .62125 .37166 L .62428 .37137 L F
.728 .722 .845 r
.62125 .37166 m .62428 .37137 L .62264 .37311 L F
.727 .625 .745 r
.62373 .3689 m .62428 .37137 L .61955 .37116 L F
.73 .584 .692 r
.61955 .37116 m .62428 .37137 L .62125 .37166 L F
.701 .609 .75 r
.62652 .36848 m .62428 .37137 L .62373 .3689 L F
.752 .657 .101 r
.62404 .37396 m .62434 .36913 L .62304 .37253 L F
0 .133 .657 r
.62322 .37268 m .62404 .37396 L .62304 .37253 L F
.956 .942 .72 r
.62404 .37396 m .62637 .37127 L .62428 .37137 L F
.752 .657 .101 r
.62404 .37396 m .62428 .37137 L .62434 .36913 L F
0 .133 .657 r
.62551 .3747 m .62404 .37396 L .62322 .37268 L F
0 0 .476 r
.62404 .37396 m .62563 .37584 L .62471 .37533 L F
0 .133 .657 r
.62551 .3747 m .62588 .37618 L .62404 .37396 L F
.84 .906 .497 r
.62575 .37601 m .62588 .37618 L .62578 .37578 L F
.6257 .37643 m .62588 .37618 L .62575 .37601 L F
0 0 .476 r
.62563 .37584 m .62588 .37618 L .62765 .37822 L F
.62404 .37396 m .62588 .37618 L .62563 .37584 L F
.62563 .37584 m .62765 .37822 L .62572 .37632 L F
.62563 .37584 m .62572 .37632 L .62471 .37533 L F
.84 .906 .497 r
.62404 .3788 m .6257 .37643 L .62565 .37592 L F
.62546 .37484 m .62565 .37592 L .62551 .3747 L F
.62404 .3788 m .62565 .37592 L .62546 .37484 L F
.6257 .37643 m .62578 .37578 L .62551 .3747 L F
.62387 .37927 m .62412 .37888 L .62404 .3788 L F
.62412 .37888 m .62588 .37618 L .62404 .3788 L F
.49 .903 .865 r
.62585 .37909 m .62661 .3796 L .62765 .37822 L F
0 0 0 r
.34581 .52446 m .34486 .52486 L .34694 .52496 L F
.54 .371 .6 r
.34486 .52486 m .34748 .527 L .34694 .52496 L F
.439 .179 .422 r
.42599 .51477 m .42578 .51611 L .42338 .51568 L F
.42578 .51611 m .42562 .51721 L .42484 .51668 L F
.42578 .51611 m .42484 .51668 L .42338 .51568 L F
.012 0 0 r
.423 .51778 m .42635 .51708 L .42451 .51875 L F
.4224 .51739 m .42384 .51727 L .423 .51778 L F
.42384 .51727 m .42635 .51708 L .423 .51778 L F
0 0 .169 r
.21783 .57319 m .21865 .57252 L .21923 .56971 L F
0 0 .446 r
.21783 .57319 m .21895 .57524 L .21865 .57252 L F
.677 .977 .877 r
.4451 .59793 m .44538 .59664 L .44411 .59757 L F
.4451 .59793 m .44799 .59608 L .44538 .59664 L F
0 .205 .67 r
.57815 .38995 m .58085 .39214 L .57961 .39125 L F
.805 .896 .907 r
.48913 .43073 m .48575 .43106 L .48752 .42935 L F
.82 .904 .899 r
.49066 .42676 m .48913 .43073 L .48752 .42935 L F
.49066 .42676 m .49209 .42803 L .48913 .43073 L F
.681 .659 .822 r
.58785 .3728 m .58406 .37171 L .58658 .37076 L F
.795 .881 .909 r
.58938 .36869 m .58785 .3728 L .58658 .37076 L F
.58938 .36869 m .59121 .3702 L .58785 .3728 L F
0 0 .147 r
.47592 .57867 m .47588 .58131 L .47528 .58293 L F
.685 .783 .308 r
.47588 .58131 m .47431 .58505 L .47528 .58293 L F
.843 .91 .881 r
.5007 .42393 m .49844 .42368 L .49915 .42253 L F
.8 .883 .906 r
.50384 .42113 m .5007 .42393 L .49915 .42253 L F
.346 .686 .98 r
.56628 .44723 m .56372 .44723 L .56581 .44568 L F
.56628 .44723 m .56372 .44723 L .56581 .44568 L F
.417 .764 .996 r
.70365 .29269 m .70231 .29421 L .7009 .29301 L F
.70365 .29269 m .70499 .29399 L .70231 .29421 L F
.457 .823 .566 r
.65683 .32262 m .65475 .3243 L .65655 .32282 L F
.516 .912 .803 r
.65655 .32282 m .65475 .3243 L .65294 .32473 L F
.537 .497 .759 r
.34216 .61135 m .34001 .61207 L .33931 .60873 L F
.592 .519 .741 r
.34362 .61396 m .34001 .61207 L .34216 .61135 L F
.98 .76 .534 r
.33931 .60873 m .33779 .6112 L .34001 .61207 L F
.313 0 0 r
.33764 .51415 m .3419 .51457 L .33963 .51412 L F
.551 .374 .595 r
.34201 .51191 m .3419 .51457 L .33963 .51412 L F
.33963 .51412 m .3419 .51457 L .34201 .51191 L F
.709 .515 .625 r
.31915 .56315 m .32009 .5665 L .31623 .5665 L F
.628 .488 .673 r
.32123 .56266 m .32009 .5665 L .31915 .56315 L F
.559 .649 .895 r
.33384 .52976 m .33554 .53317 L .33282 .5333 L F
.868 .971 .656 r
.65642 .33589 m .65457 .3399 L .65761 .33727 L F
.911 .91 .806 r
.65892 .33231 m .65761 .33727 L .66034 .33409 L F
.65892 .33231 m .65642 .33589 L .65761 .33727 L F
.874 .885 .839 r
.27802 .57339 m .27358 .57555 L .27571 .57482 L F
.094 0 0 r
.27802 .57339 m .27838 .57425 L .28095 .57235 L F
.27802 .57339 m .27571 .57482 L .27838 .57425 L F
.248 .097 .47 r
.33966 .53418 m .3396 .53682 L .33788 .53751 L F
0 0 0 r
.3396 .53682 m .33597 .53895 L .33788 .53751 L F
.248 .097 .47 r
.33788 .53751 m .3396 .53682 L .33966 .53418 L F
.379 .777 .986 r
.25803 .61649 m .25752 .61771 L .25554 .61733 L F
.25803 .61649 m .26069 .61757 L .25752 .61771 L F
.683 .172 .019 r
.52797 .44555 m .52685 .44338 L .5252 .44333 L F
.52797 .44555 m .52923 .44514 L .52685 .44338 L F
.41 .62 .938 r
.54786 .4587 m .54783 .46022 L .54639 .46023 L F
.118 .657 .852 r
.54639 .46023 m .54783 .46022 L .54716 .46018 L F
.421 .324 .639 r
.54639 .46023 m .54925 .4612 L .54863 .46009 L F
.54639 .46023 m .54716 .46018 L .54786 .4587 L F
.268 .732 .948 r
.54716 .46018 m .54783 .46022 L .54749 .46011 L F
.421 .324 .639 r
.54716 .46018 m .54749 .46011 L .54786 .4587 L F
.76 .911 .941 r
.54749 .46011 m .54783 .46022 L .54786 .4587 L F
.421 .324 .639 r
.54749 .46011 m .54852 .45988 L .54786 .4587 L F
.76 .911 .941 r
.54431 .45903 m .54749 .46011 L .54786 .4587 L F
.268 .732 .948 r
.54716 .46018 m .54749 .46011 L .54431 .45903 L F
.421 .324 .639 r
.54716 .46018 m .54863 .46009 L .54852 .45988 L F
.54639 .46023 m .54673 .46312 L .54925 .4612 L F
.669 .264 .268 r
.54925 .4612 m .55212 .46205 L .5493 .45981 L F
.547 .334 .542 r
.5493 .45981 m .55212 .46205 L .55201 .4593 L F
.669 .264 .268 r
.54925 .4612 m .5493 .45981 L .55201 .4593 L F
.54925 .4612 m .55105 .45864 L .54786 .4587 L F
.412 0 .065 r
.54737 .45943 m .54993 .46018 L .5466 .46056 L F
.54786 .4587 m .54886 .45941 L .54737 .45943 L F
.54886 .45941 m .54993 .46018 L .54737 .45943 L F
.268 .732 .948 r
.54268 .45992 m .54716 .46018 L .54537 .45946 L F
.54348 .45948 m .54537 .45946 L .54431 .45903 L F
.54268 .45992 m .54537 .45946 L .54348 .45948 L F
.118 .657 .852 r
.54639 .46023 m .54716 .46018 L .54268 .45992 L F
.793 .593 .631 r
.54268 .46254 m .54639 .46023 L .54268 .45992 L F
.54268 .46254 m .54673 .46312 L .54639 .46023 L F
.646 .803 .958 r
.28466 .51524 m .28937 .51604 L .28724 .5146 L F
.801 .839 .88 r
.28724 .5146 m .28937 .51604 L .29143 .51438 L F
.125 0 .267 r
.32872 .59455 m .33027 .59693 L .32905 .5939 L F
.32872 .59455 m .32857 .59776 L .33027 .59693 L F
.694 .926 .968 r
.46784 .44272 m .46422 .44312 L .46634 .44137 L F
.743 .913 .951 r
.46946 .43967 m .46784 .44272 L .46634 .44137 L F
.46946 .43967 m .47097 .44066 L .46784 .44272 L F
0 .116 .662 r
.3091 .64379 m .31159 .64744 L .31214 .64744 L F
.381 .017 .216 r
.31743 .5602 m .31997 .55969 L .32064 .55677 L F
.112 0 .197 r
.32064 .55677 m .32297 .55612 L .32416 .55261 L F
.118 0 .137 r
.32064 .55677 m .32212 .55825 L .32297 .55612 L F
.32064 .55677 m .32013 .55901 L .32212 .55825 L F
.038 0 0 r
.32212 .55825 m .32654 .55553 L .32297 .55612 L F
.32212 .55825 m .32425 .55765 L .32654 .55553 L F
.452 .749 .993 r
.3202 .55669 m .3239 .55757 L .32212 .55825 L F
.3239 .55757 m .32425 .55765 L .32212 .55825 L F
.118 0 .137 r
.32013 .55901 m .31997 .55969 L .32212 .55825 L F
.615 .611 .823 r
.45572 .52537 m .46014 .52819 L .45868 .5243 L F
.678 .624 .788 r
.45868 .5243 m .46014 .52819 L .46275 .52726 L F
0 0 0 r
.56703 .46624 m .57038 .46297 L .56952 .46506 L F
.57038 .46297 m .57333 .46027 L .57234 .46211 L F
.56952 .46506 m .57038 .46297 L .57234 .46211 L F
.497 .107 .23 r
.30329 .65271 m .30149 .65115 L .30096 .65321 L F
.732 .757 .873 r
.34449 .69299 m .34537 .68882 L .34286 .68934 L F
.34449 .69299 m .34685 .69183 L .34537 .68882 L F
.773 .682 .763 r
.43777 .54311 m .4409 .54428 L .43886 .54188 L F
.851 .58 .528 r
.43777 .54311 m .44073 .54703 L .4409 .54428 L F
.831 .723 .746 r
.67815 .35012 m .67379 .35251 L .67637 .34877 L F
.663 .74 .907 r
.67905 .34769 m .67815 .35012 L .67637 .34877 L F
.67905 .34769 m .68031 .3497 L .67815 .35012 L F
.74 .726 .838 r
.33963 .55312 m .34368 .55531 L .34369 .55355 L F
0 0 0 r
.223 .55367 m .22451 .55272 L .22542 .55063 L F
0 0 .016 r
.22211 .55572 m .22451 .55272 L .223 .55367 L F
.805 .646 .685 r
.54002 .43095 m .5437 .4304 L .54249 .42725 L F
.66 .421 .547 r
.53937 .4334 m .5437 .4304 L .54002 .43095 L F
.53937 .4334 m .54392 .43267 L .5437 .4304 L F
.609 .38 .544 r
.5437 .4304 m .54484 .42692 L .54249 .42725 L F
.685 .523 .661 r
.54392 .43267 m .54674 .4309 L .5437 .4304 L F
0 0 0 r
.23645 .53702 m .23483 .53936 L .23343 .54072 L F
.035 0 .453 r
.2352 .54206 m .23343 .54072 L .23483 .53936 L F
.2352 .54206 m .23362 .54366 L .23343 .54072 L F
.726 .871 .949 r
.42553 .45492 m .42727 .4563 L .42328 .45628 L F
.719 .869 .952 r
.42991 .45441 m .42727 .4563 L .42553 .45492 L F
.986 .854 .481 r
.39613 .5815 m .39752 .57986 L .39672 .57877 L F
.39613 .5815 m .39687 .5825 L .39752 .57986 L F
.447 .881 .839 r
.67486 .32333 m .67628 .32219 L .67362 .32307 L F
.67486 .32333 m .67697 .32241 L .67628 .32219 L F
.744 .775 .878 r
.56283 .38232 m .56055 .38363 L .55887 .38185 L F
.55887 .38185 m .56055 .38363 L .56283 .38232 L F
0 0 0 r
.63459 .38837 m .632 .3895 L .63059 .39021 L F
.516 .633 .905 r
.34947 .68994 m .35117 .69273 L .35355 .69238 L F
.612 .443 .629 r
.54644 .44419 m .54647 .44687 L .5482 .44292 L F
.5482 .44292 m .54647 .44687 L .54644 .44419 L F
.981 .816 .413 r
.43854 .56398 m .43741 .56562 L .43804 .56223 L F
.43854 .56398 m .43834 .56659 L .43741 .56562 L F
.07 .341 .817 r
.72754 .31053 m .72604 .31169 L .72355 .30799 L F
.017 0 0 r
.72786 .31176 m .72923 .3115 L .72604 .31169 L F
.72786 .31176 m .72604 .31169 L .72754 .31053 L F
0 0 0 r
.42931 .52837 m .42686 .53112 L .42946 .52768 L F
.165 .318 .774 r
.42851 .52527 m .4308 .52611 L .42946 .52768 L F
.582 .547 .78 r
.4308 .52611 m .43207 .53009 L .42931 .52837 L F
.689 .61 .762 r
.43455 .52862 m .43207 .53009 L .4308 .52611 L F
.43455 .52862 m .4308 .52611 L .43397 .5271 L F
.554 .529 .782 r
.43212 .52617 m .43515 .52615 L .43364 .52392 L F
.9 .986 .771 r
.43455 .52862 m .43397 .5271 L .43568 .52499 L F
.717 .474 .557 r
.43097 .52738 m .43561 .52766 L .43562 .52735 L F
.798 .637 .682 r
.42919 .52704 m .43353 .52711 L .4308 .52611 L F
.43136 .52714 m .43353 .52711 L .42919 .52704 L F
.43353 .52711 m .43397 .5271 L .4308 .52611 L F
.42894 .52718 m .43097 .52738 L .43397 .5271 L F
.717 .474 .557 r
.43097 .52738 m .43568 .52499 L .43397 .5271 L F
.43143 .52715 m .43562 .52735 L .43568 .52499 L F
.43097 .52738 m .43562 .52735 L .43143 .52715 L F
.798 .637 .682 r
.42894 .52718 m .43136 .52714 L .42919 .52704 L F
.165 .318 .774 r
.42824 .52459 m .4308 .52611 L .42851 .52527 L F
.752 .857 .928 r
.2533 .5245 m .25757 .52345 L .25656 .52283 L F
.079 .621 .848 r
.26053 .52345 m .25656 .52283 L .25757 .52345 L F
.038 .599 .803 r
.429 .5001 m .43331 .50069 L .43052 .50138 L F
.665 .795 .338 r
.41953 .49063 m .41853 .49274 L .41871 .49248 L F
.973 .717 .486 r
.41871 .49248 m .41869 .49503 L .41686 .49353 L F
.556 .005 0 r
.42076 .49482 m .42608 .49569 L .42281 .49667 L F
.374 0 0 r
.41986 .49453 m .42303 .49606 L .42076 .49482 L F
.42303 .49606 m .42354 .49631 L .42076 .49482 L F
.38 .22 .536 r
.4187 .4937 m .42076 .49482 L .41869 .49503 L F
.41871 .49248 m .42076 .49482 L .4187 .4937 L F
.042 .373 .84 r
.33072 .64542 m .33488 .64958 L .33314 .6441 L F
.708 .568 .695 r
.33276 .65169 m .33601 .65003 L .33488 .64958 L F
.242 .344 .769 r
.33314 .6441 m .33488 .64958 L .33571 .6468 L F
.217 .602 .95 r
.33488 .64958 m .33699 .65003 L .33571 .6468 L F
.33488 .64958 m .33601 .65003 L .33699 .65003 L F
.711 .813 .928 r
.63398 .40623 m .63606 .40838 L .63717 .40729 L F
.526 .53 .802 r
.42931 .52837 m .43094 .53285 L .42686 .53112 L F
.374 .803 .626 r
.33622 .65455 m .33243 .65675 L .33417 .65597 L F
.662 .939 .672 r
.33762 .65286 m .33622 .65455 L .33417 .65597 L F
.204 0 0 r
.55242 .47376 m .55448 .47403 L .55184 .47489 L F
.579 .602 .84 r
.36119 .6963 m .36199 .6993 L .36392 .69573 L F
.707 .698 .839 r
.36199 .6993 m .36526 .69876 L .36392 .69573 L F
0 0 0 r
.23453 .53062 m .2364 .53035 L .23741 .52886 L F
.23741 .52886 m .23803 .52922 L .23934 .52936 L F
.23741 .52886 m .2364 .53035 L .23803 .52922 L F
.711 .663 .801 r
.46275 .52726 m .46678 .52803 L .46526 .52428 L F
.349 .254 .605 r
.45585 .47897 m .45783 .4784 L .45547 .47629 L F
.595 .707 .922 r
.45783 .4784 m .45386 .47707 L .45547 .47629 L F
.589 .614 .845 r
.46678 .52803 m .46783 .5238 L .46526 .52428 L F
.46678 .52803 m .46943 .52736 L .46783 .5238 L F
.974 .907 .565 r
.59984 .399 m .59815 .40071 L .59796 .39792 L F
.59984 .399 m .59926 .4009 L .59815 .40071 L F
.853 .859 .845 r
.46035 .5137 m .4588 .51122 L .45672 .51344 L F
.895 .48 .186 r
.45672 .51344 m .46092 .51704 L .46035 .5137 L F
.729 .82 .921 r
.46035 .5137 m .46233 .5113 L .4588 .51122 L F
.761 .651 .741 r
.42281 .49667 m .41869 .49503 L .42076 .49482 L F
.42281 .49667 m .42076 .49919 L .41869 .49503 L F
.649 .144 0 r
.36699 .51256 m .3664 .51137 L .36426 .51123 L F
.36699 .51256 m .36853 .5139 L .3664 .51137 L F
.795 .558 .579 r
.29028 .63691 m .29463 .63777 L .29467 .63475 L F
.467 .29 .557 r
.29701 .63696 m .29463 .63777 L .29467 .63475 L F
.29701 .63696 m .29463 .63777 L .29467 .63475 L F
0 0 .493 r
.22542 .55063 m .22668 .54918 L .22622 .54641 L F
0 0 0 r
.22542 .55063 m .22451 .55272 L .22668 .54918 L F
.622 .101 0 r
.60671 .42662 m .60917 .42876 L .61002 .42981 L F
.532 .918 .919 r
.61909 .34663 m .62105 .34506 L .6214 .3456 L F
.492 .881 .704 r
.61909 .34663 m .61951 .34624 L .62105 .34506 L F
.745 .828 .916 r
.65892 .33231 m .66034 .33409 L .66245 .33249 L F
.726 .676 .802 r
.35355 .69238 m .35509 .69602 L .35772 .69298 L F
.322 .512 .887 r
.44949 .5163 m .44992 .51904 L .45143 .51635 L F
.593 .605 .833 r
.32247 .53341 m .32341 .5355 L .32622 .53447 L F
0 .177 .669 r
.59253 .39159 m .59432 .3925 L .59176 .39013 L F
.564 .018 0 r
.59211 .3907 m .59176 .39013 L .59432 .3925 L F
0 0 .363 r
.59154 .38978 m .59253 .39159 L .59176 .39013 L F
.564 .018 0 r
.58993 .38892 m .59176 .39013 L .59211 .3907 L F
0 0 .363 r
.59074 .38833 m .59154 .38978 L .59176 .39013 L F
0 .177 .669 r
.59253 .39159 m .59557 .3939 L .59432 .3925 L F
0 0 0 r
.23873 .53722 m .23483 .53936 L .23645 .53702 L F
.364 .809 .953 r
.23645 .53702 m .24057 .53659 L .23873 .53722 L F
.675 .731 .892 r
.28856 .5295 m .28995 .5285 L .29024 .52716 L F
.776 .611 .675 r
.33326 .51776 m .32858 .51466 L .33114 .51411 L F
.33326 .51776 m .32843 .51813 L .32858 .51466 L F
.417 0 0 r
.33326 .51776 m .32769 .51893 L .32843 .51813 L F
.33326 .51776 m .33068 .51921 L .32769 .51893 L F
.188 0 .143 r
.33612 .51564 m .33326 .51776 L .33114 .51411 L F
.33612 .51564 m .33516 .51733 L .33326 .51776 L F
.405 .458 .802 r
.23765 .60885 m .23685 .61015 L .23461 .60663 L F
.769 .95 .935 r
.23456 .61048 m .23685 .61015 L .23765 .60885 L F
.636 .235 .267 r
.36043 .55546 m .36346 .5559 L .36485 .55393 L F
.727 .469 .537 r
.36346 .5559 m .36748 .55348 L .36485 .55393 L F
0 0 0 r
.42712 .56169 m .42667 .56554 L .42689 .56351 L F
.32367 .6022 m .32569 .60146 L .3273 .59916 L F
.288 0 .032 r
.3273 .59916 m .32835 .60082 L .32857 .59776 L F
.3273 .59916 m .32569 .60146 L .32835 .60082 L F
.782 .848 .394 r
.70103 .353 m .70253 .34863 L .70233 .35063 L F
0 0 0 r
.70044 .35456 m .70103 .353 L .70233 .35063 L F
.508 .729 .973 r
.72276 .30663 m .72206 .30859 L .72098 .30674 L F
.72276 .30663 m .72355 .30799 L .72206 .30859 L F
.431 .257 .542 r
.3623 .54673 m .36243 .55004 L .36002 .55026 L F
.297 .152 .509 r
.36203 .55239 m .36002 .55026 L .36243 .55004 L F
.36203 .55239 m .36045 .55333 L .36002 .55026 L F
.744 .252 0 r
.59617 .39537 m .59796 .39792 L .59592 .39611 L F
.224 .74 .728 r
.28346 .6404 m .28662 .63967 L .28163 .64093 L F
.801 .396 .285 r
.28755 .64306 m .28662 .63967 L .28346 .6404 L F
.863 .427 .015 r
.23469 .60543 m .23461 .60663 L .23397 .60447 L F
.23469 .60543 m .23765 .60885 L .23461 .60663 L F
.022 0 .026 r
.45105 .57907 m .44984 .58158 L .45274 .57867 L F
.704 .765 .9 r
.23991 .61831 m .24408 .61877 L .24207 .6206 L F
.682 .258 .233 r
.24408 .61877 m .24633 .62086 L .24207 .6206 L F
.383 .157 .443 r
.62417 .39043 m .62174 .38911 L .62138 .38833 L F
.957 .87 .71 r
.32984 .65275 m .33276 .65169 L .33099 .65019 L F
.562 .391 .607 r
.35307 .59583 m .35088 .59911 L .3498 .59521 L F
.644 .562 .748 r
.35918 .59047 m .35826 .59264 L .36288 .59197 L F
.551 .295 .482 r
.35887 .59536 m .36288 .59197 L .35826 .59264 L F
.779 .583 .635 r
.45484 .52463 m .45572 .52537 L .45215 .52449 L F
.45484 .52463 m .45572 .52537 L .45215 .52449 L F
.018 .565 .834 r
.33516 .4953 m .33153 .49442 L .33338 .49491 L F
0 .496 .708 r
.33604 .4954 m .33516 .4953 L .33338 .49491 L F
.33604 .4954 m .33763 .49565 L .33516 .4953 L F
.342 .285 .648 r
.2539 .60826 m .25259 .61145 L .25191 .60885 L F
.25259 .61145 m .2539 .60826 L .25191 .60885 L F
.445 .34 .642 r
.49068 .51752 m .49086 .52103 L .48867 .52179 L F
.429 .347 .662 r
.49135 .52354 m .48867 .52179 L .49086 .52103 L F
.49135 .52354 m .48923 .52455 L .48867 .52179 L F
.824 .589 .583 r
.55672 .41994 m .5607 .41804 L .55755 .41747 L F
.55672 .41994 m .56066 .42061 L .5607 .41804 L F
.956 .876 .473 r
.39617 .58734 m .3974 .5857 L .39657 .58511 L F
.549 .24 .396 r
.60129 .35701 m .60095 .35891 L .59817 .3585 L F
.406 .108 .343 r
.60366 .3564 m .60095 .35891 L .60129 .35701 L F
.711 .616 .749 r
.42076 .49919 m .41604 .4963 L .41869 .49503 L F
0 0 0 r
.67143 .36971 m .66851 .37162 L .67012 .37065 L F
.67389 .36855 m .67143 .36971 L .67012 .37065 L F
.776 .634 .704 r
.36846 .69618 m .37242 .6962 L .37152 .69547 L F
.464 .552 .86 r
.36846 .69618 m .37219 .69925 L .37242 .6962 L F
.622 .644 .851 r
.37242 .6962 m .37358 .69244 L .37152 .69547 L F
.55 .355 .569 r
.37219 .69925 m .3748 .69872 L .37242 .6962 L F
.595 .209 .28 r
.46411 .53523 m .46696 .53631 L .46812 .53441 L F
.544 .502 .76 r
.46812 .53441 m .47053 .53374 L .4699 .52995 L F
.367 0 .197 r
.46696 .53631 m .47053 .53374 L .46812 .53441 L F
.751 .781 .877 r
.36392 .69573 m .36526 .69876 L .36846 .69618 L F
0 .419 .711 r
.34051 .6277 m .34347 .62858 L .34163 .62799 L F
.045 .364 .835 r
.34305 .62836 m .34163 .62799 L .34435 .62945 L F
.33995 .62574 m .34163 .62799 L .34305 .62836 L F
0 .419 .711 r
.33951 .6274 m .34051 .6277 L .34163 .62799 L F
.659 .568 .741 r
.34603 .62494 m .34651 .62799 L .34347 .62858 L F
.967 .767 .582 r
.46743 .54439 m .46641 .54748 L .46528 .54588 L F
.234 .368 .795 r
.46743 .54439 m .46828 .5426 L .46565 .54034 L F
.704 .547 .672 r
.46528 .54588 m .46828 .5426 L .46743 .54439 L F
.907 .982 .775 r
.32402 .59435 m .32404 .5967 L .3259 .59416 L F
.995 .802 .531 r
.32439 .59158 m .3259 .59416 L .32804 .5932 L F
.32439 .59158 m .32402 .59435 L .3259 .59416 L F
.62 .789 .963 r
.56909 .44617 m .57068 .44836 L .56628 .44723 L F
.679 .816 .948 r
.57323 .44644 m .57068 .44836 L .56909 .44617 L F
.454 .205 .446 r
.32799 .61517 m .33059 .6173 L .32691 .61768 L F
.615 .184 0 r
.73562 .32551 m .73655 .32684 L .73511 .32461 L F
.516 .377 .629 r
.50095 .5018 m .50148 .50509 L .4985 .50547 L F
.368 .096 .364 r
.50148 .50509 m .49874 .5077 L .4985 .50547 L F
.574 .604 .845 r
.27855 .51493 m .28214 .51618 L .28102 .51436 L F
.765 .723 .814 r
.45764 .51843 m .45875 .52157 L .46134 .51863 L F
.727 .658 .782 r
.46134 .51863 m .45875 .52157 L .46166 .51972 L F
.711 .552 .671 r
.45868 .5243 m .46166 .51972 L .45875 .52157 L F
0 0 0 r
.36043 .62071 m .36183 .61851 L .35818 .62222 L F
.507 .805 .999 r
.36268 .61703 m .36502 .61803 L .36183 .61851 L F
.628 .813 .392 r
.36268 .61703 m .36183 .61851 L .36043 .62071 L F
.496 .344 .603 r
.34916 .57645 m .34925 .57939 L .34666 .57998 L F
.472 .337 .616 r
.34922 .58161 m .34666 .57998 L .34925 .57939 L F
.34922 .58161 m .34685 .58267 L .34666 .57998 L F
.496 .344 .603 r
.34666 .57998 m .34925 .57939 L .34916 .57645 L F
.472 .337 .616 r
.34666 .57998 m .34922 .58161 L .34925 .57939 L F
.34666 .57998 m .34685 .58267 L .34922 .58161 L F
.837 .735 .752 r
.5892 .40477 m .5878 .40136 L .5873 .40347 L F
.904 .491 .158 r
.58946 .40679 m .5892 .40477 L .5873 .40347 L F
.751 .664 .765 r
.23783 .54684 m .23929 .55068 L .23498 .55019 L F
.407 .257 .564 r
.23733 .55239 m .23498 .55019 L .23929 .55068 L F
0 .03 .599 r
.23946 .54876 m .23929 .55068 L .23783 .54684 L F
.858 .969 .649 r
.23946 .54876 m .23733 .55239 L .23929 .55068 L F
.927 .958 .779 r
.56378 .42911 m .56659 .42812 L .56488 .42642 L F
.56378 .42911 m .56451 .43139 L .56659 .42812 L F
.875 .881 .836 r
.56488 .42642 m .56659 .42812 L .56934 .42463 L F
.562 .407 .629 r
.54956 .39855 m .55223 .3981 L .55105 .39394 L F
.425 .267 .561 r
.55223 .3981 m .55448 .39445 L .55105 .39394 L F
.457 .317 .603 r
.6681 .3401 m .67156 .34197 L .67116 .33943 L F
.6681 .3401 m .66852 .34344 L .67156 .34197 L F
.258 .547 .926 r
.30432 .66382 m .30498 .66228 L .30577 .66365 L F
.376 .019 .225 r
.44164 .52442 m .43841 .52677 L .43899 .52521 L F
.495 .905 .844 r
.44538 .59664 m .44799 .59608 L .45034 .59481 L F
.832 .9 .888 r
.39367 .67368 m .39683 .67329 L .39441 .67111 L F
.716 .313 .283 r
.63153 .41475 m .63337 .41109 L .63001 .41061 L F
.48 .162 .351 r
.63484 .41231 m .63337 .41109 L .63153 .41475 L F
.63484 .41231 m .63566 .41083 L .63337 .41109 L F
.923 .593 .132 r
.43024 .54438 m .42934 .5436 L .42855 .53999 L F
.978 .918 .629 r
.43024 .54438 m .42803 .54645 L .42934 .5436 L F
.545 .412 .65 r
.34241 .68658 m .34448 .68219 L .34259 .68293 L F
.526 .332 .56 r
.49874 .5077 m .49582 .51098 L .49631 .50883 L F
.518 .272 .481 r
.30281 .567 m .30603 .56662 L .30632 .56364 L F
.133 0 .364 r
.30632 .56364 m .30752 .56524 L .30834 .56294 L F
.30632 .56364 m .30603 .56662 L .30752 .56524 L F
.348 0 0 r
.41586 .48039 m .4147 .48171 L .41808 .48108 L F
.342 0 .14 r
.41586 .48039 m .41808 .48108 L .41859 .4795 L F
.396 .095 .332 r
.42109 .58273 m .42407 .57994 L .4236 .58215 L F
.423 .124 .351 r
.42407 .57994 m .42612 .58156 L .4236 .58215 L F
.42407 .57994 m .42657 .57941 L .42612 .58156 L F
.743 .236 0 r
.35513 .50287 m .35584 .50241 L .35451 .50114 L F
.35513 .50287 m .35813 .50556 L .35584 .50241 L F
.71 .303 .276 r
.38436 .68194 m .38608 .68057 L .38273 .68001 L F
.746 .701 .162 r
.33314 .6441 m .33365 .64119 L .33378 .6397 L F
.691 .925 .606 r
.33876 .65035 m .34119 .64763 L .34116 .65164 L F
.716 .672 .806 r
.61872 .37608 m .61962 .3787 L .61521 .37809 L F
.732 .585 .691 r
.61521 .37809 m .61657 .38212 L .61239 .38389 L F
.687 .277 .263 r
.61521 .37809 m .61876 .38161 L .61657 .38212 L F
.135 0 0 r
.61239 .38389 m .61657 .38212 L .61561 .38316 L F
.691 .841 .955 r
.61561 .38316 m .61655 .3816 L .61509 .38305 L F
.687 .277 .263 r
.61521 .37809 m .61942 .37936 L .61778 .38064 L F
.691 .841 .955 r
.61655 .3816 m .61755 .37995 L .61573 .38225 L F
.61655 .3816 m .61573 .38225 L .61509 .38305 L F
.687 .277 .263 r
.61521 .37809 m .61962 .3787 L .61942 .37936 L F
.61778 .38064 m .61942 .37936 L .61876 .38161 L F
.382 0 0 r
.61962 .3787 m .62117 .37981 L .61876 .38161 L F
.61962 .3787 m .62238 .37922 L .62117 .37981 L F
.874 .44 .051 r
.5958 .42138 m .59316 .41776 L .59351 .42032 L F
.889 .672 .603 r
.59344 .4231 m .5958 .42138 L .59351 .42032 L F
.59344 .4231 m .59528 .42397 L .5958 .42138 L F
.165 .243 .699 r
.41291 .49074 m .41159 .49289 L .41075 .48848 L F
.239 .342 .768 r
.41291 .49074 m .41432 .49463 L .41159 .49289 L F
.895 .48 .186 r
.45672 .51344 m .4586 .51703 L .46092 .51704 L F
.765 .723 .814 r
.45764 .51843 m .46134 .51863 L .46092 .51704 L F
.843 .889 .873 r
.44211 .57545 m .44377 .57193 L .44256 .57425 L F
.649 .36 .467 r
.44377 .57193 m .4488 .57254 L .44577 .57107 L F
.753 .953 .94 r
.44377 .57193 m .44577 .57107 L .44722 .56882 L F
0 0 .478 r
.33238 .62152 m .33379 .62352 L .33446 .62115 L F
.33238 .62152 m .33256 .62511 L .33379 .62352 L F
.442 .876 .897 r
.58406 .37171 m .5854 .37048 L .58658 .37076 L F
0 0 0 r
.58406 .37171 m .5828 .37376 L .5854 .37048 L F
0 .311 .685 r
.57611 .3704 m .57987 .37225 L .57673 .37081 L F
.92 .719 .616 r
.43053 .50465 m .42878 .50765 L .43205 .50863 L F
.75 .64 .738 r
.42878 .50765 m .43064 .51045 L .43205 .50863 L F
.197 0 0 r
.43064 .51045 m .43501 .5087 L .43205 .50863 L F
.973 .916 .587 r
.4263 .55881 m .42631 .5565 L .42455 .55615 L F
0 0 .552 r
.42592 .55691 m .4263 .55881 L .42455 .55615 L F
.815 .6 .043 r
.42592 .55691 m .42629 .55966 L .4263 .55881 L F
.42629 .55966 m .42647 .56097 L .4263 .55881 L F
.973 .916 .587 r
.4263 .55881 m .42849 .55694 L .42631 .5565 L F
.4263 .55881 m .42705 .56067 L .42849 .55694 L F
.843 .944 .888 r
.56252 .43308 m .56451 .43139 L .56378 .42911 L F
.529 .589 .858 r
.43288 .53314 m .43078 .53457 L .43094 .53285 L F
0 .141 .665 r
.43245 .53588 m .43078 .53457 L .43288 .53314 L F
.43245 .53588 m .43222 .53711 L .43078 .53457 L F
.691 .486 .605 r
.37742 .59933 m .38114 .5989 L .38099 .5978 L F
0 0 0 r
.37742 .59933 m .38099 .5978 L .37888 .59881 L F
.731 .971 .718 r
.37888 .59881 m .38099 .5978 L .38162 .59683 L F
.619 .435 .611 r
.38099 .5978 m .38351 .59722 L .38162 .59683 L F
.38099 .5978 m .38114 .5989 L .38351 .59722 L F
.55 .551 .808 r
.53324 .44709 m .53608 .44661 L .5345 .44257 L F
.53324 .44709 m .53385 .4449 L .53441 .44527 L F
.49 .78 .996 r
.53441 .44527 m .53608 .44661 L .53324 .44709 L F
.037 0 0 r
.53489 .44558 m .53441 .44527 L .53297 .44674 L F
.981 .71 .436 r
.5345 .44257 m .53608 .44661 L .53441 .44527 L F
.037 0 0 r
.53703 .4443 m .53441 .44527 L .53489 .44558 L F
.55 .551 .808 r
.53385 .4449 m .5345 .44257 L .53441 .44527 L F
.762 .649 .736 r
.33416 .51078 m .33114 .51411 L .33162 .51195 L F
.662 .903 .98 r
.591 .35362 m .59336 .35311 L .59037 .35392 L F
.801 .839 .88 r
.28724 .5146 m .29143 .51438 L .28988 .51421 L F
.483 .309 .567 r
.55855 .42779 m .56209 .42959 L .5599 .42328 L F
.55855 .42779 m .55917 .43037 L .56209 .42959 L F
.649 .431 .574 r
.6269 .35669 m .6284 .35666 L .62493 .35918 L F
.553 .873 .591 r
.62934 .35415 m .6269 .35669 L .62619 .35705 L F
.689 .415 .503 r
.29739 .57548 m .30164 .57276 L .29989 .57497 L F
.119 0 0 r
.30429 .57294 m .29989 .57497 L .30164 .57276 L F
0 .185 .674 r
.59528 .42397 m .59789 .42588 L .5978 .42621 L F
.92 .643 .501 r
.5956 .42918 m .5978 .42621 L .59789 .42588 L F
.5956 .42918 m .5986 .42933 L .5978 .42621 L F
.706 .481 .58 r
.371 .5991 m .36951 .59976 L .36976 .60007 L F
0 0 0 r
.37364 .59948 m .37087 .60166 L .371 .5991 L F
.629 .53 .722 r
.37364 .59948 m .37087 .60166 L .371 .5991 L F
.449 .321 .613 r
.31458 .63494 m .31706 .63645 L .31463 .63768 L F
.843 .942 .888 r
.73828 .30978 m .74279 .30788 L .74034 .31068 L F
.73828 .30978 m .74104 .30734 L .74279 .30788 L F
0 0 .266 r
.74349 .3081 m .74279 .30788 L .74104 .30734 L F
.74349 .3081 m .7432 .30999 L .74279 .30788 L F
.843 .944 .888 r
.56252 .43308 m .56378 .42911 L .56169 .4321 L F
.544 .817 .996 r
.57333 .46027 m .57527 .46019 L .5739 .45837 L F
.738 .825 .365 r
.57234 .46211 m .57333 .46027 L .5739 .45837 L F
.226 0 0 r
.24126 .57943 m .24373 .57896 L .24483 .5771 L F
0 0 0 r
.24483 .5771 m .24373 .57896 L .24519 .57755 L F
.839 .994 .846 r
.7432 .31434 m .7429 .31315 L .73956 .31673 L F
.881 .75 .243 r
.7432 .30999 m .7429 .31315 L .7432 .31434 L F
.909 .873 .79 r
.31464 .65497 m .3122 .65759 L .31395 .65351 L F
.811 .48 .429 r
.31527 .65121 m .31464 .65497 L .31395 .65351 L F
.31527 .65121 m .31841 .65335 L .31464 .65497 L F
0 .168 .704 r
.31666 .65588 m .31464 .65497 L .31841 .65335 L F
.31666 .65588 m .31653 .65722 L .31464 .65497 L F
0 .238 .717 r
.57716 .37905 m .57663 .37816 L .57593 .37701 L F
.57716 .37905 m .58047 .38139 L .57663 .37816 L F
.792 .796 .303 r
.70678 .33812 m .70632 .34082 L .70742 .33681 L F
.706 .826 .379 r
.70742 .33681 m .70944 .33238 L .70779 .3361 L F
0 0 0 r
.70678 .33812 m .70742 .33681 L .70779 .3361 L F
.2316 .53391 m .23318 .53313 L .23453 .53062 L F
.23453 .53062 m .23501 .53178 L .2364 .53035 L F
.23453 .53062 m .23318 .53313 L .23501 .53178 L F
.554 .814 .994 r
.28687 .57271 m .28452 .57341 L .28277 .57218 L F
.564 .57 .818 r
.28452 .57341 m .28844 .57452 L .28687 .57271 L F
.006 0 0 r
.285 .57429 m .28452 .57341 L .28687 .57271 L F
.285 .57429 m .28273 .57516 L .28452 .57341 L F
.612 .178 .193 r
.62086 .4064 m .61995 .40413 L .61919 .40436 L F
.945 .671 .488 r
.38187 .53007 m .38403 .5334 L .38277 .53214 L F
.97 .662 .374 r
.41769 .50277 m .41577 .50228 L .41592 .50072 L F
.837 .379 0 r
.38869 .54368 m .38995 .54603 L .39151 .547 L F
.992 .77 .499 r
.38975 .54837 m .39151 .547 L .38995 .54603 L F
.38975 .54837 m .39123 .54955 L .39151 .547 L F
.936 .967 .727 r
.54002 .43095 m .54249 .42725 L .54122 .4273 L F
.362 .761 .985 r
.54249 .42725 m .54324 .42587 L .54122 .4273 L F
.54249 .42725 m .54484 .42692 L .54324 .42587 L F
.85 .996 .824 r
.51873 .40918 m .51602 .41222 L .5167 .40968 L F
.77 .939 .937 r
.5167 .40968 m .51602 .41222 L .51362 .41179 L F
.691 .971 .926 r
.67378 .38118 m .67698 .37952 L .67504 .3792 L F
.729 .966 .937 r
.67826 .3771 m .67698 .37952 L .67892 .37796 L F
.744 .981 .912 r
.67504 .3792 m .67698 .37952 L .67826 .3771 L F
0 .426 .817 r
.27093 .63323 m .27127 .63399 L .27399 .63493 L F
0 0 0 r
.42445 .54081 m .42398 .54304 L .42293 .54448 L F
.07 .31 .793 r
.42693 .54808 m .42693 .54809 L .42293 .54448 L F
.6 .611 .834 r
.42803 .54645 m .42696 .54812 L .42398 .54304 L F
.712 .923 .584 r
.42634 .54801 m .42597 .54919 L .42713 .54765 L F
.42741 .54703 m .42713 .54765 L .42803 .54645 L F
.07 .31 .793 r
.42398 .54304 m .42609 .54664 L .42293 .54448 L F
.42609 .54664 m .42693 .54808 L .42498 .54632 L F
.42609 .54664 m .42498 .54632 L .42293 .54448 L F
.712 .923 .584 r
.42634 .54801 m .42713 .54765 L .42741 .54703 L F
.07 .31 .793 r
.42693 .54808 m .42696 .54812 L .42693 .54809 L F
.803 .967 .91 r
.42597 .54919 m .42989 .54793 L .42803 .54645 L F
.488 0 0 r
.42741 .54703 m .42888 .54752 L .42634 .54801 L F
.42803 .54645 m .42881 .54743 L .42741 .54703 L F
.42881 .54743 m .42888 .54752 L .42741 .54703 L F
.77 .638 .715 r
.41812 .46269 m .41572 .46342 L .41818 .46002 L F
.999 .823 .526 r
.45166 .47814 m .45143 .48106 L .45296 .48214 L F
1 .808 .483 r
.45033 .47969 m .45026 .48011 L .45143 .48106 L F
.863 .788 .776 r
.44806 .48425 m .45283 .4822 L .45143 .48106 L F
0 0 0 r
.45143 .48106 m .44985 .48271 L .44806 .48425 L F
1 .808 .483 r
.45026 .48011 m .44985 .48271 L .45143 .48106 L F
.863 .788 .776 r
.45283 .4822 m .45296 .48214 L .45143 .48106 L F
.44806 .48425 m .45026 .4856 L .45296 .48214 L F
.609 .406 .581 r
.45026 .4856 m .45323 .48548 L .45296 .48214 L F
.647 .525 .701 r
.45296 .48214 m .45655 .48185 L .45585 .47897 L F
.544 .304 .503 r
.45323 .48548 m .45655 .48185 L .45296 .48214 L F
.795 .587 .619 r
.25437 .61106 m .25817 .61164 L .25429 .60935 L F
.794 .609 .651 r
.25994 .60908 m .25617 .61042 L .2539 .60826 L F
.265 .585 .945 r
.25429 .60935 m .25675 .61078 L .25444 .6094 L F
.794 .609 .651 r
.25994 .60908 m .25817 .61164 L .25617 .61042 L F
.265 .585 .945 r
.25675 .61078 m .25821 .61162 L .25617 .61042 L F
.25675 .61078 m .25617 .61042 L .25444 .6094 L F
.25429 .60935 m .25817 .61164 L .25821 .61162 L F
.794 .609 .651 r
.25617 .61042 m .25817 .61164 L .25498 .61115 L F
.25617 .61042 m .25498 .61115 L .25489 .61087 L F
.25617 .61042 m .25489 .61087 L .25435 .60939 L F
.25617 .61042 m .25435 .60939 L .25444 .6094 L F
.25479 .60911 m .25439 .60928 L .25436 .60921 L F
.25443 .60877 m .25436 .60921 L .2539 .60826 L F
.25479 .60911 m .25436 .60921 L .25443 .60877 L F
.25842 .60844 m .2539 .60826 L .25687 .6078 L F
.25742 .60874 m .2539 .60826 L .25842 .60844 L F
.87 .645 .596 r
.2539 .60826 m .25439 .60928 L .25687 .6078 L F
.77 .676 .759 r
.25597 .60437 m .25643 .60612 L .25244 .60732 L F
.25643 .60612 m .25687 .6078 L .25575 .60768 L F
.25643 .60612 m .25575 .60768 L .25244 .60732 L F
.332 .768 .968 r
.25575 .60768 m .25502 .60705 L .25244 .60732 L F
.25687 .6078 m .25625 .60755 L .25575 .60768 L F
.25625 .60755 m .25502 .60705 L .25575 .60768 L F
.794 .609 .651 r
.25994 .60908 m .25742 .60874 L .25842 .60844 L F
.52 0 0 r
.25687 .6078 m .25977 .60914 L .25994 .60908 L F
.692 .761 .905 r
.25985 .60771 m .25977 .60914 L .25687 .6078 L F
.538 .84 .999 r
.25985 .60771 m .25687 .6078 L .25821 .60644 L F
.27 .119 .484 r
.25537 .60854 m .25746 .60947 L .25805 .60709 L F
.25695 .60737 m .25805 .60709 L .25821 .60644 L F
.908 .898 .806 r
.25746 .60341 m .25687 .6078 L .25597 .60437 L F
.25746 .60341 m .25502 .60705 L .25625 .60755 L F
.25714 .60577 m .25625 .60755 L .25687 .6078 L F
.25746 .60341 m .25625 .60755 L .25714 .60577 L F
.27 .119 .484 r
.2571 .60734 m .25821 .60644 L .25741 .60726 L F
.2571 .60734 m .25741 .60726 L .25687 .6078 L F
.25552 .60861 m .2571 .60734 L .25687 .6078 L F
.25599 .60809 m .25805 .60709 L .25695 .60737 L F
.25439 .60928 m .25821 .60644 L .25552 .60861 L F
.25434 .6093 m .25821 .60644 L .25439 .60928 L F
.25537 .60854 m .2559 .60826 L .25599 .60809 L F
.2559 .60826 m .25805 .60709 L .25599 .60809 L F
.25434 .6093 m .25502 .60934 L .25537 .60854 L F
.25502 .60934 m .25746 .60947 L .25537 .60854 L F
.87 .645 .596 r
.2539 .60826 m .25429 .60935 L .25439 .60928 L F
.27 .119 .484 r
.25429 .60935 m .25434 .6093 L .25439 .60928 L F
.25429 .60935 m .25433 .60935 L .25434 .6093 L F
.794 .609 .651 r
.25617 .61042 m .25439 .60928 L .25479 .60911 L F
.27 .119 .484 r
.25433 .60935 m .25746 .60947 L .25434 .6093 L F
.794 .609 .651 r
.25617 .61042 m .25445 .60941 L .25439 .60928 L F
.87 .645 .596 r
.2539 .60826 m .25437 .61106 L .25429 .60935 L F
.794 .609 .651 r
.25445 .60941 m .25405 .60918 L .2539 .60826 L F
.265 .585 .945 r
.25444 .6094 m .25821 .61162 L .25913 .61116 L F
.25435 .60939 m .25913 .61116 L .25868 .61262 L F
.25429 .60935 m .25444 .6094 L .25435 .60939 L F
.25444 .6094 m .25913 .61116 L .25435 .60939 L F
.794 .609 .651 r
.25444 .6094 m .25435 .60939 L .25433 .60934 L F
.261 .294 .707 r
.25429 .60935 m .25435 .60939 L .25433 .60935 L F
.794 .609 .651 r
.25433 .60934 m .25437 .61106 L .25405 .60918 L F
.25489 .61087 m .25437 .61106 L .25433 .60934 L F
.261 .294 .707 r
.25433 .60935 m .25442 .60944 L .25439 .60935 L F
.25435 .60939 m .25442 .60944 L .25433 .60935 L F
.25439 .60935 m .25868 .61262 L .25746 .60947 L F
.25442 .60944 m .25868 .61262 L .25439 .60935 L F
.794 .609 .651 r
.25489 .61087 m .25498 .61115 L .25437 .61106 L F
.573 .659 .895 r
.26435 .60675 m .25977 .60914 L .25983 .60803 L F
.26395 .60683 m .25983 .60803 L .25985 .60771 L F
.26435 .60675 m .25983 .60803 L .26395 .60683 L F
.596 .418 .611 r
.49323 .51158 m .49337 .51455 L .49054 .51492 L F
.525 .361 .602 r
.49582 .51098 m .49337 .51455 L .49323 .51158 L F
.823 .47 0 r
.33256 .62511 m .33163 .625 L .33379 .62352 L F
.33256 .62511 m .33356 .62813 L .33163 .625 L F
.543 .009 0 r
.33256 .62511 m .33618 .62716 L .33356 .62813 L F
.774 .687 .767 r
.32683 .56672 m .32268 .56633 L .32526 .56294 L F
.391 .795 .983 r
.32683 .56672 m .32514 .56594 L .32268 .56633 L F
.067 .615 .836 r
.32917 .56653 m .32514 .56594 L .32683 .56672 L F
.875 .881 .836 r
.56488 .42642 m .56934 .42463 L .56679 .42307 L F
.805 .815 .859 r
.56679 .42307 m .56934 .42463 L .57213 .42194 L F
.834 .69 .704 r
.61117 .38287 m .61094 .38537 L .60909 .38121 L F
.01 .292 .788 r
.61117 .38287 m .61239 .38389 L .61292 .38397 L F
.352 .265 .616 r
.61292 .38397 m .61094 .38537 L .61117 .38287 L F
.61292 .38397 m .61094 .38537 L .61117 .38287 L F
.457 .245 .503 r
.50938 .49477 m .50664 .49813 L .50628 .49501 L F
.638 .793 .957 r
.69702 .30406 m .70091 .30472 L .6995 .30305 L F
.589 .05 0 r
.69702 .30406 m .69983 .30578 L .70091 .30472 L F
.827 .395 0 r
.59926 .4009 m .60179 .40497 L .60052 .40366 L F
.961 .646 .241 r
.60179 .40497 m .60092 .40607 L .60052 .40366 L F
.60179 .40497 m .60212 .40743 L .60092 .40607 L F
.105 0 .243 r
.6104 .3877 m .61094 .38537 L .61292 .38397 L F
.439 .044 .191 r
.29612 .5692 m .29855 .5691 L .30032 .56673 L F
.436 0 .068 r
.29855 .5691 m .30281 .567 L .30032 .56673 L F
.78 .948 .93 r
.64695 .398 m .65 .39712 L .64883 .39628 L F
.839 .939 .891 r
.65 .39712 m .6517 .39358 L .64883 .39628 L F
.65 .39712 m .65258 .39479 L .6517 .39358 L F
.04 0 .238 r
.2191 .56346 m .22115 .56275 L .22107 .56006 L F
.077 0 .354 r
.2191 .56346 m .21977 .56622 L .22115 .56275 L F
0 0 .347 r
.21886 .566 m .21977 .56622 L .2191 .56346 L F
.666 .726 .894 r
.34537 .68882 m .34685 .69183 L .34947 .68994 L F
.82 .872 .884 r
.55825 .41127 m .55984 .41229 L .56223 .41008 L F
.58 .49 .718 r
.60911 .37886 m .60909 .38121 L .60663 .38222 L F
.55 .833 .998 r
.60032 .36481 m .59981 .36607 L .59578 .36561 L F
.688 .961 .943 r
.601 .36398 m .59981 .36607 L .60032 .36481 L F
.864 .759 .745 r
.601 .36398 m .60254 .36768 L .59981 .36607 L F
.936 .83 .715 r
.60254 .36768 m .60264 .37101 L .59981 .36607 L F
.629 .339 .459 r
.62354 .3661 m .62652 .36848 L .62373 .3689 L F
.993 .755 .466 r
.62721 .36648 m .62652 .36848 L .62354 .3661 L F
.515 .086 .163 r
.70528 .30946 m .70746 .30984 L .70758 .30813 L F
.542 .108 .166 r
.70758 .30813 m .71135 .30916 L .71142 .30675 L F
.978 .707 .443 r
.32628 .51815 m .32478 .5139 L .32569 .51521 L F
.32628 .51815 m .3244 .5169 L .32478 .5139 L F
0 0 .262 r
.32353 .52134 m .3244 .5169 L .32628 .51815 L F
.536 .324 .54 r
.32628 .51815 m .32624 .52111 L .32353 .52134 L F
.682 .585 .741 r
.32858 .51466 m .32628 .51815 L .32569 .51521 L F
.564 .432 .658 r
.32858 .51466 m .32843 .51813 L .32628 .51815 L F
0 0 .384 r
.32769 .51893 m .32628 .51815 L .32843 .51813 L F
.144 0 0 r
.33068 .51921 m .3282 .51904 L .32769 .51893 L F
0 0 .384 r
.32769 .51893 m .32624 .52111 L .32627 .51862 L F
.518 .913 .909 r
.32769 .51893 m .32443 .52002 L .3267 .51893 L F
.144 0 0 r
.3282 .51904 m .3267 .51893 L .32769 .51893 L F
0 0 .384 r
.32769 .51893 m .32627 .51862 L .32628 .51815 L F
.991 .852 .605 r
.44186 .55374 m .43982 .55525 L .44163 .55525 L F
.97 .733 .303 r
.44102 .54986 m .44103 .55297 L .44186 .55374 L F
.96 .945 .67 r
.44103 .55297 m .43982 .55525 L .44186 .55374 L F
.674 .538 .691 r
.36621 .54646 m .3623 .54673 L .36229 .54407 L F
0 .054 .612 r
.36523 .55959 m .36653 .56347 L .36658 .56031 L F
.435 0 0 r
.36653 .56347 m .36787 .5652 L .36658 .56031 L F
.36653 .56347 m .36417 .56541 L .36787 .5652 L F
0 0 .369 r
.41212 .5941 m .41201 .59566 L .41301 .59821 L F
.551 .256 .421 r
.42497 .47639 m .4247 .47863 L .42741 .47817 L F
.658 .927 .973 r
.36846 .69618 m .37152 .69547 L .36918 .69423 L F
.821 .959 .902 r
.36918 .69423 m .37152 .69547 L .37358 .69244 L F
.869 .434 .161 r
.27183 .62702 m .27134 .62525 L .26856 .62385 L F
.711 .216 0 r
.40535 .54469 m .40693 .5467 L .40385 .54347 L F
.561 .377 .589 r
.49348 .51681 m .49054 .51492 L .49337 .51455 L F
.49348 .51681 m .49068 .51752 L .49054 .51492 L F
.778 .895 .926 r
.59457 .35923 m .59817 .3585 L .59655 .35743 L F
.52 .508 .783 r
.59817 .3585 m .59975 .35473 L .59655 .35743 L F
.59817 .3585 m .60095 .35891 L .59975 .35473 L F
.779 .974 .916 r
.45976 .4447 m .46098 .44539 L .45903 .44702 L F
.775 .97 .921 r
.45784 .44636 m .45976 .4447 L .45903 .44702 L F
.029 0 .412 r
.48241 .54712 m .4835 .54903 L .48164 .55053 L F
.096 0 .355 r
.4835 .54903 m .48089 .55316 L .48164 .55053 L F
.755 .967 .931 r
.45439 .44866 m .45784 .44636 L .45903 .44702 L F
.91 .979 .78 r
.57387 .43395 m .57089 .4375 L .57253 .43515 L F
0 0 0 r
.57569 .43263 m .57387 .43395 L .57253 .43515 L F
.846 .4 0 r
.59815 .40071 m .59926 .4009 L .60052 .40366 L F
.745 .927 .95 r
.29066 .5327 m .28889 .53388 L .28968 .53467 L F
.615 .618 .831 r
.54205 .41011 m .53832 .40811 L .54067 .40741 L F
.589 .603 .834 r
.54352 .40727 m .54205 .41011 L .54067 .40741 L F
.54352 .40727 m .54444 .4091 L .54205 .41011 L F
.866 .805 .787 r
.57555 .44055 m .57126 .44248 L .57434 .43935 L F
.57555 .44055 m .57356 .44376 L .57126 .44248 L F
.648 .757 .928 r
.68228 .34563 m .68031 .3497 L .67905 .34769 L F
.68228 .34563 m .68318 .34872 L .68031 .3497 L F
.373 .295 .638 r
.68362 .35146 m .68052 .3539 L .68031 .3497 L F
.482 .219 .439 r
.68031 .3497 m .68318 .34872 L .68362 .35146 L F
.691 .971 .926 r
.67378 .38118 m .67504 .3792 L .67265 .38073 L F
.944 .581 .241 r
.39988 .53018 m .39766 .52669 L .39904 .52792 L F
.877 .84 .806 r
.37358 .69244 m .37749 .69064 L .37605 .68858 L F
.729 .703 .826 r
.37749 .69064 m .37822 .68717 L .37605 .68858 L F
.37749 .69064 m .3809 .68867 L .37822 .68717 L F
.774 .996 .805 r
.65457 .3399 m .65428 .33944 L .65113 .34246 L F
.868 .971 .656 r
.65642 .33589 m .65428 .33944 L .65457 .3399 L F
.589 .567 .797 r
.34482 .65167 m .3452 .65447 L .34261 .65505 L F
.573 .349 .538 r
.50361 .49881 m .50373 .5014 L .50095 .5018 L F
.502 .265 .487 r
.50664 .49813 m .50373 .5014 L .50361 .49881 L F
.861 .785 .775 r
.41818 .46002 m .41388 .46206 L .41626 .45878 L F
.41818 .46002 m .41572 .46342 L .41388 .46206 L F
.82 .898 .897 r
.41931 .45649 m .41818 .46002 L .41626 .45878 L F
.41931 .45649 m .42073 .45748 L .41818 .46002 L F
.823 .931 .903 r
.5739 .45837 m .57527 .46019 L .57849 .45643 L F
.672 .233 .2 r
.60628 .36677 m .6102 .36823 L .61063 .36606 L F
.60628 .36677 m .60681 .36837 L .6102 .36823 L F
.205 .305 .746 r
.70006 .28958 m .7009 .29301 L .69881 .29197 L F
.343 .194 .529 r
.53967 .40698 m .53832 .40811 L .54067 .40741 L F
.53967 .40698 m .53832 .40811 L .54067 .40741 L F
.316 .058 .355 r
.23846 .58233 m .24126 .57943 L .23832 .57972 L F
.224 .74 .728 r
.28346 .6404 m .28163 .64093 L .27915 .64255 L F
0 0 0 r
.27792 .64477 m .27869 .64241 L .27764 .64325 L F
.27869 .64241 m .27903 .64137 L .27834 .6423 L F
.27869 .64241 m .27834 .6423 L .27764 .64325 L F
.92 .567 .349 r
.27736 .6437 m .27903 .64137 L .27792 .64477 L F
.224 .74 .728 r
.27937 .64262 m .27915 .64255 L .27736 .6437 L F
.28346 .6404 m .27915 .64255 L .27937 .64262 L F
0 0 0 r
.27792 .64477 m .27764 .64325 L .27485 .64266 L F
.273 0 0 r
.27736 .6437 m .28163 .64093 L .27903 .64137 L F
.189 .314 .761 r
.22551 .59556 m .22685 .59561 L .22558 .59186 L F
.199 .236 .675 r
.22551 .59556 m .22765 .59784 L .22685 .59561 L F
.308 .258 .638 r
.22551 .59556 m .22605 .59896 L .22765 .59784 L F
.477 .702 .967 r
.34413 .54621 m .35044 .54971 L .3473 .54612 L F
.551 .409 .641 r
.34413 .54621 m .3473 .54612 L .35044 .54971 L F
.704 .798 .923 r
.3473 .54612 m .35044 .54971 L .34975 .5452 L F
.3473 .54612 m .35044 .54971 L .34975 .5452 L F
.526 .246 .433 r
.52414 .48198 m .52334 .48505 L .52064 .48542 L F
.594 .359 .53 r
.52707 .4818 m .52334 .48505 L .52414 .48198 L F
.898 .48 .119 r
.39493 .52054 m .39244 .51686 L .394 .51807 L F
.893 .976 .677 r
.70497 .34267 m .70632 .34082 L .70678 .33812 L F
.924 .549 .138 r
.58015 .39353 m .58085 .39214 L .57815 .38995 L F
.58015 .39353 m .58144 .39454 L .58085 .39214 L F
.995 .858 .523 r
.41111 .58596 m .40962 .58778 L .41064 .58511 L F
.41111 .58596 m .41041 .58887 L .40962 .58778 L F
.711 .552 .671 r
.45868 .5243 m .46259 .52492 L .46166 .51972 L F
.462 .286 .555 r
.46166 .51972 m .46402 .51772 L .46134 .51863 L F
.46166 .51972 m .46433 .51989 L .46402 .51772 L F
.657 .515 .679 r
.46166 .51972 m .46526 .52428 L .46433 .51989 L F
.46166 .51972 m .46259 .52492 L .46526 .52428 L F
.562 .391 .607 r
.35307 .59583 m .35343 .59883 L .35088 .59911 L F
.927 .545 .171 r
.6051 .41763 m .6042 .41876 L .60378 .41644 L F
.6051 .41763 m .60597 .42037 L .6042 .41876 L F
.936 .671 .511 r
.57126 .44248 m .57356 .44376 L .57323 .44644 L F
.817 .666 .695 r
.33789 .60496 m .33567 .60835 L .33931 .60873 L F
.539 .154 .26 r
.33511 .6109 m .33931 .60873 L .33567 .60835 L F
.33511 .6109 m .33779 .6112 L .33931 .60873 L F
0 0 .406 r
.33931 .60873 m .34037 .60449 L .33789 .60496 L F
0 0 0 r
.33931 .60873 m .33942 .60949 L .34064 .60753 L F
.33931 .60873 m .33779 .6112 L .33942 .60949 L F
.754 .647 .743 r
.38281 .59005 m .38517 .58881 L .38556 .58648 L F
.711 .542 .659 r
.38281 .59005 m .38112 .59304 L .38517 .58881 L F
.843 .889 .873 r
.44211 .57545 m .44326 .57703 L .44632 .57358 L F
.851 .398 .005 r
.43834 .56659 m .43813 .56835 L .43741 .56562 L F
.43834 .56659 m .4402 .56976 L .43813 .56835 L F
.837 .702 .715 r
.44352 .56823 m .4402 .56976 L .43834 .56659 L F
.665 .811 .367 r
.61895 .43184 m .6189 .43214 L .61993 .43018 L F
0 0 0 r
.61993 .43018 m .62224 .42913 L .61895 .43184 L F
.466 .866 .691 r
.61895 .43184 m .62064 .43048 L .619 .43155 L F
.61895 .43184 m .619 .43155 L .61714 .43277 L F
.665 .811 .367 r
.61895 .43184 m .6179 .43404 L .6189 .43214 L F
0 0 .021 r
.62259 .42691 m .62224 .42913 L .61993 .43018 L F
.534 .317 .531 r
.32416 .55261 m .32639 .55308 L .32622 .5505 L F
.651 .405 .533 r
.32622 .5505 m .32639 .55308 L .32958 .55283 L F
.593 .279 .406 r
.71135 .30916 m .71429 .30929 L .71142 .30675 L F
.385 .056 .279 r
.3689 .57924 m .36954 .57697 L .36635 .57935 L F
.3689 .57924 m .36954 .57697 L .36635 .57935 L F
.513 .171 .324 r
.37183 .5786 m .36954 .57697 L .3689 .57924 L F
.3689 .57924 m .36954 .57697 L .37183 .5786 L F
.315 .442 .83 r
.21848 .57945 m .22165 .58141 L .21977 .57764 L F
.441 .871 .775 r
.64103 .38595 m .63717 .38752 L .64004 .38543 L F
.223 .717 .917 r
.64368 .3858 m .64103 .38595 L .64004 .38543 L F
.943 .85 .721 r
.30558 .63225 m .30738 .6324 L .30563 .62818 L F
.249 .763 .81 r
.30207 .63392 m .3041 .63359 L .30422 .63536 L F
.3041 .63359 m .30606 .63328 L .30422 .63536 L F
.438 .77 .997 r
.30606 .63328 m .30812 .6346 L .30824 .63416 L F
.30689 .6332 m .30824 .63416 L .30854 .63304 L F
.30655 .63323 m .30824 .63416 L .30689 .6332 L F
.30606 .63328 m .30644 .63343 L .30655 .63323 L F
.30644 .63343 m .30824 .63416 L .30655 .63323 L F
.943 .85 .721 r
.30556 .63399 m .30666 .63303 L .30558 .63225 L F
.813 .606 .623 r
.30854 .63304 m .30422 .63536 L .30606 .63328 L F
.639 .581 .774 r
.30207 .63392 m .30556 .63399 L .30338 .6286 L F
.943 .85 .721 r
.30556 .63399 m .30563 .62818 L .30338 .6286 L F
.679 .942 .665 r
.30485 .63375 m .30685 .63268 L .30556 .63399 L F
.943 .85 .721 r
.30666 .63303 m .30738 .6324 L .30558 .63225 L F
.679 .942 .665 r
.30685 .63268 m .30738 .6324 L .30666 .63303 L F
.30685 .63268 m .30666 .63303 L .30556 .63399 L F
.718 .649 .092 r
.30812 .6346 m .3079 .63621 L .30854 .63304 L F
.813 .606 .623 r
.30854 .63304 m .3079 .63621 L .30422 .63536 L F
0 .433 .689 r
.30422 .63536 m .3079 .63621 L .3064 .63587 L F
.30422 .63536 m .3064 .63587 L .30403 .63808 L F
.811 .822 .859 r
.30403 .63808 m .3043 .63665 L .30422 .63536 L F
.555 .148 .226 r
.30422 .63536 m .30556 .63399 L .30207 .63392 L F
.679 .942 .665 r
.30485 .63375 m .30556 .63399 L .30422 .63536 L F
.811 .822 .859 r
.3043 .63665 m .30485 .63375 L .30422 .63536 L F
.718 .649 .092 r
.30812 .6346 m .30788 .63671 L .3079 .63621 L F
0 0 .465 r
.3079 .63621 m .30874 .63552 L .30792 .63564 L F
.3079 .63621 m .30792 .63564 L .3064 .63587 L F
.718 .649 .092 r
.30788 .63671 m .3078 .63742 L .3079 .63621 L F
.658 .262 0 r
.41039 .56334 m .40989 .56256 L .40819 .55934 L F
.974 .67 .305 r
.41039 .56334 m .40927 .56513 L .40989 .56256 L F
.41039 .56334 m .41067 .56604 L .40927 .56513 L F
0 0 0 r
.43917 .55919 m .4384 .56023 L .43919 .55901 L F
.43917 .55919 m .43919 .55901 L .44163 .55525 L F
.728 .503 0 r
.43914 .5594 m .43917 .55919 L .43886 .55693 L F
.687 .147 0 r
.4384 .56023 m .44123 .56255 L .44314 .56308 L F
0 .094 .567 r
.43942 .56098 m .4384 .56023 L .43917 .55919 L F
.728 .503 0 r
.43919 .55982 m .43917 .55919 L .43914 .5594 L F
0 0 0 r
.43917 .55919 m .44163 .55525 L .43982 .55525 L F
.968 .918 .583 r
.26009 .62347 m .26034 .6249 L .26177 .62184 L F
.715 .707 .841 r
.5388 .45937 m .54268 .45992 L .54036 .45636 L F
.652 .419 .553 r
.53981 .46275 m .54268 .45992 L .5388 .45937 L F
.53981 .46275 m .54268 .46254 L .54268 .45992 L F
.268 .732 .948 r
.54268 .45992 m .54431 .45903 L .54036 .45636 L F
.576 .364 .556 r
.34799 .6074 m .34481 .60502 L .34832 .60498 L F
.34799 .6074 m .34504 .60789 L .34481 .60502 L F
.775 .661 .738 r
.55673 .39852 m .55412 .40171 L .55223 .3981 L F
.811 .669 .706 r
.34651 .62799 m .34687 .63124 L .34388 .63141 L F
.368 .34 .697 r
.34947 .63005 m .34687 .63124 L .34651 .62799 L F
.25 .081 .446 r
.34698 .63384 m .34687 .63124 L .34947 .63005 L F
.736 .499 .571 r
.31557 .5472 m .31951 .5477 L .31823 .54684 L F
.623 .858 .987 r
.32087 .5462 m .31951 .5477 L .31823 .54684 L F
.31823 .54684 m .31951 .5477 L .32087 .5462 L F
.615 .242 .314 r
.44383 .48511 m .43946 .48768 L .44021 .48505 L F
.44383 .48511 m .44331 .48782 L .43946 .48768 L F
.598 .301 .437 r
.4454 .48582 m .44331 .48782 L .44383 .48511 L F
.428 0 0 r
.44677 .48587 m .4454 .48582 L .44383 .48511 L F
.342 .285 .648 r
.2539 .60826 m .25437 .61106 L .25259 .61145 L F
.25259 .61145 m .25437 .61106 L .2539 .60826 L F
.751 .85 .924 r
.48035 .435 m .47523 .43577 L .47878 .43359 L F
.758 .858 .924 r
.48095 .43198 m .48035 .435 L .47878 .43359 L F
.48095 .43198 m .48257 .43347 L .48035 .435 L F
.505 .292 .524 r
.38839 .67208 m .39195 .66938 L .38937 .66678 L F
.87 .94 .862 r
.31056 .66622 m .3144 .66341 L .31221 .66272 L F
0 0 0 r
.31056 .66622 m .31466 .6633 L .3144 .66341 L F
.631 .902 .985 r
.3144 .66341 m .31336 .66121 L .31221 .66272 L F
.555 .387 .609 r
.3167 .66319 m .3144 .66341 L .31466 .6633 L F
.55 .107 .151 r
.44066 .4806 m .4378 .48114 L .43987 .47932 L F
.516 .398 .657 r
.48909 .52704 m .48653 .52493 L .48923 .52455 L F
.48909 .52704 m .48657 .52774 L .48653 .52493 L F
.678 .624 .788 r
.45868 .5243 m .46275 .52726 L .46259 .52492 L F
.678 .612 .775 r
.46259 .52492 m .46275 .52726 L .46526 .52428 L F
.991 .737 .434 r
.45629 .54653 m .45792 .55122 L .4558 .54907 L F
.972 .659 .301 r
.4558 .54907 m .45792 .55122 L .4562 .54979 L F
.499 .483 .77 r
.45905 .54624 m .45792 .55122 L .45629 .54653 L F
.496 .37 .638 r
.45792 .55122 m .46041 .55112 L .46171 .5483 L F
.45792 .55122 m .46041 .55112 L .46171 .5483 L F
.499 .483 .77 r
.45905 .54624 m .46041 .55112 L .45792 .55122 L F
.427 .681 .969 r
.45792 .55122 m .45872 .54888 L .4562 .54979 L F
.45792 .55122 m .46041 .55112 L .45872 .54888 L F
.687 .848 .96 r
.45083 .44851 m .45065 .45107 L .44892 .44964 L F
.45083 .44851 m .45245 .44994 L .45065 .45107 L F
.678 .703 .866 r
.62493 .35918 m .62904 .35995 L .6284 .35666 L F
.467 .891 .883 r
.42776 .46533 m .42619 .46657 L .42861 .4656 L F
.42776 .46533 m .42349 .46669 L .42619 .46657 L F
.781 .768 .841 r
.34545 .51767 m .3441 .51491 L .34744 .51535 L F
.828 .842 .858 r
.34744 .51535 m .34603 .51208 L .34842 .5143 L F
.34744 .51535 m .3441 .51491 L .34603 .51208 L F
.43 .871 .823 r
.43199 .48493 m .43049 .486 L .43271 .48489 L F
.613 .932 .963 r
.63144 .34082 m .62693 .34162 L .62938 .33994 L F
.595 .909 .981 r
.63144 .34082 m .63305 .33894 L .63349 .33903 L F
.63144 .34082 m .62938 .33994 L .63305 .33894 L F
.535 .869 .6 r
.669 .31405 m .67083 .31222 L .6721 .31132 L F
.592 .947 .833 r
.669 .31405 m .66852 .31378 L .67083 .31222 L F
.616 .34 .475 r
.41641 .59543 m .41959 .5982 L .41596 .59771 L F
.271 .736 .947 r
.44061 .59737 m .44196 .5965 L .43944 .59696 L F
.44061 .59737 m .44411 .59757 L .44196 .5965 L F
.826 .737 .766 r
.39127 .47352 m .38643 .47458 L .38883 .47161 L F
.39127 .47352 m .38896 .47667 L .38643 .47458 L F
.422 0 0 r
.38883 .47161 m .3931 .4734 L .39127 .47352 L F
.635 .323 .426 r
.32416 .55261 m .32654 .55553 L .32639 .55308 L F
.32416 .55261 m .32297 .55612 L .32654 .55553 L F
.439 .851 .684 r
.42968 .49661 m .42797 .49745 L .42613 .49873 L F
0 0 0 r
.42797 .49745 m .42481 .49976 L .42613 .49873 L F
.019 0 .074 r
.32367 .6022 m .32341 .60414 L .32569 .60146 L F
.481 .187 .39 r
.36621 .54646 m .36243 .55004 L .3623 .54673 L F
.669 .37 .457 r
.34029 .55863 m .34346 .5563 L .34155 .55708 L F
0 0 .442 r
.22107 .56006 m .22202 .55942 L .22211 .55572 L F
.168 0 .258 r
.22107 .56006 m .22239 .56101 L .22202 .55942 L F
.22107 .56006 m .22115 .56275 L .22239 .56101 L F
.585 .15 .181 r
.56416 .43969 m .56192 .43809 L .56095 .43942 L F
0 0 0 r
.62587 .42422 m .62502 .42583 L .62259 .42691 L F
0 0 .023 r
.62502 .42583 m .62224 .42913 L .62259 .42691 L F
.04 .135 .636 r
.55946 .43553 m .55754 .43387 L .55951 .43302 L F
.728 .644 .765 r
.55223 .3981 m .54968 .40108 L .54956 .39855 L F
.55223 .3981 m .55412 .40171 L .54968 .40108 L F
.477 .334 .607 r
.54956 .39855 m .55168 .39962 L .55223 .3981 L F
.54956 .39855 m .54968 .40108 L .55168 .39962 L F
.71 .303 .276 r
.38436 .68194 m .38273 .68001 L .38247 .67995 L F
.522 .711 .958 r
.43114 .4643 m .433 .46636 L .43406 .46415 L F
.389 .193 .49 r
.433 .46636 m .43515 .46815 L .43406 .46415 L F
.433 .46636 m .43285 .46927 L .43515 .46815 L F
.879 .881 .832 r
.44124 .50511 m .4387 .50844 L .43705 .50718 L F
.929 .92 .541 r
.3922 .60351 m .39359 .6022 L .39285 .60084 L F
.3922 .60351 m .3924 .60542 L .39359 .6022 L F
.053 0 .168 r
.54067 .40741 m .5412 .40526 L .54259 .40462 L F
.588 .338 .505 r
.31843 .54386 m .32087 .5462 L .32185 .54399 L F
.58 .04 0 r
.54485 .46419 m .54673 .46312 L .54268 .46254 L F
.487 .865 .653 r
.54925 .4612 m .54673 .46312 L .54485 .46419 L F
.935 .716 .237 r
.40747 .55298 m .40709 .54954 L .40759 .55047 L F
.637 .331 .436 r
.53385 .47884 m .52966 .48156 L .52975 .47953 L F
0 0 .262 r
.32353 .52134 m .32443 .52002 L .3244 .5169 L F
.417 .778 .995 r
.32624 .52111 m .32443 .52002 L .32353 .52134 L F
.837 .702 .715 r
.44352 .56823 m .44297 .56987 L .4402 .56976 L F
.729 .648 .768 r
.44314 .56308 m .44446 .56744 L .44352 .56823 L F
.633 .476 .653 r
.44446 .56744 m .44297 .56987 L .44352 .56823 L F
.971 .667 .285 r
.60263 .41001 m .60391 .41121 L .60402 .41386 L F
0 0 .31 r
.48502 .54275 m .48241 .54712 L .48364 .54353 L F
.48502 .54275 m .48464 .54545 L .48241 .54712 L F
.055 0 .406 r
.48464 .54805 m .48241 .54712 L .48464 .54545 L F
.48464 .54805 m .4835 .54903 L .48241 .54712 L F
.436 0 0 r
.35868 .64103 m .35403 .64192 L .35459 .64015 L F
.831 .711 .732 r
.3561 .64348 m .35868 .64103 L .35459 .64015 L F
.365 0 0 r
.3578 .64278 m .35868 .64103 L .3561 .64348 L F
.3578 .64278 m .35976 .64099 L .35868 .64103 L F
.436 0 .068 r
.29855 .5691 m .30115 .5691 L .30281 .567 L F
.428 0 .064 r
.30281 .567 m .30115 .5691 L .30471 .56823 L F
.401 0 .147 r
.30281 .567 m .30471 .56823 L .30603 .56662 L F
.762 .895 .937 r
.49416 .42654 m .49209 .42803 L .49066 .42676 L F
.98 .908 .657 r
.41195 .57003 m .41078 .57242 L .40973 .57154 L F
.988 .837 .604 r
.41195 .57003 m .40973 .57154 L .41049 .56894 L F
.749 .991 .883 r
.61719 .4335 m .6179 .43404 L .61895 .43184 L F
0 0 0 r
.30896 .62496 m .30446 .62677 L .30916 .62583 L F
.434 .851 .959 r
.30562 .62561 m .30916 .62583 L .30446 .62677 L F
.482 0 0 r
.30562 .62561 m .30924 .62619 L .30916 .62583 L F
.30924 .62619 m .30966 .62626 L .30916 .62583 L F
0 0 0 r
.30917 .62488 m .30896 .62496 L .30916 .62583 L F
.31048 .62381 m .30917 .62488 L .30916 .62583 L F
.7 .545 .674 r
.36881 .60228 m .36442 .60221 L .36951 .59976 L F
0 0 0 r
.30006 .53848 m .2996 .54108 L .30033 .53827 L F
.803 .555 .564 r
.2586 .55583 m .26294 .5566 L .26342 .5535 L F
.391 .18 .47 r
.26514 .55562 m .26294 .5566 L .26342 .5535 L F
.26514 .55562 m .26294 .5566 L .26342 .5535 L F
.857 .972 .866 r
.65258 .39479 m .65469 .3908 L .6517 .39358 L F
.65258 .39479 m .65563 .39171 L .65469 .3908 L F
.384 .683 .977 r
.25377 .55691 m .25606 .55693 L .25434 .55521 L F
.25377 .55691 m .25606 .55693 L .25434 .55521 L F
0 0 0 r
.54601 .41453 m .54887 .41077 L .54863 .41377 L F
.493 .544 .837 r
.55128 .41038 m .54887 .41077 L .5469 .40726 L F
.508 .318 .558 r
.55128 .41038 m .54863 .41377 L .54887 .41077 L F
.919 .537 .127 r
.40431 .53749 m .40303 .53639 L .40243 .53418 L F
.983 .726 .333 r
.40408 .54015 m .40303 .53639 L .40431 .53749 L F
.807 .999 .838 r
.51873 .40918 m .51953 .40691 L .52074 .40787 L F
.51873 .40918 m .5167 .40968 L .51953 .40691 L F
0 0 0 r
.65208 .38117 m .65323 .37999 L .65029 .38216 L F
.65593 .37893 m .65323 .37999 L .65208 .38117 L F
.58171 .42051 m .5811 .42134 L .58226 .41998 L F
.132 .093 .543 r
.5811 .42134 m .58327 .4222 L .58226 .41998 L F
.5811 .42134 m .58154 .42401 L .58327 .4222 L F
.111 .47 .893 r
.53758 .40114 m .53657 .40223 L .53523 .40293 L F
0 0 0 r
.71249 .32951 m .71555 .32698 L .71412 .3277 L F
.567 .939 .855 r
.71751 .32521 m .71555 .32698 L .71802 .32543 L F
.53 .894 .689 r
.71412 .3277 m .71555 .32698 L .71751 .32521 L F
.783 .769 .84 r
.42687 .48331 m .42397 .48632 L .42109 .48375 L F
.889 .877 .817 r
.59232 .36793 m .59121 .3702 L .58938 .36869 L F
.084 .465 .888 r
.4486 .50285 m .44835 .50399 L .44725 .50215 L F
.4486 .50285 m .45025 .50467 L .44835 .50399 L F
.532 .515 .782 r
.63025 .36883 m .62721 .36648 L .62904 .36496 L F
.707 .939 .632 r
.67486 .30808 m .6721 .31132 L .67352 .30896 L F
.701 .93 .611 r
.6721 .31132 m .67083 .31222 L .67352 .30896 L F
.32 0 0 r
.37645 .60049 m .3778 .60109 L .3802 .59938 L F
.733 .962 .684 r
.3802 .59938 m .3778 .60109 L .37833 .60051 L F
.256 0 0 r
.3802 .59938 m .38094 .59892 L .37742 .59933 L F
.32 0 0 r
.37645 .60049 m .3802 .59938 L .37742 .59933 L F
.733 .962 .684 r
.3802 .59938 m .37833 .60051 L .38135 .59722 L F
.256 0 0 r
.3802 .59938 m .38114 .5989 L .38094 .59892 L F
.67 .166 0 r
.38162 .59683 m .38234 .5978 L .38135 .59722 L F
.548 .909 .716 r
.38259 .59782 m .38114 .5989 L .3802 .59938 L F
.38351 .59722 m .38266 .59782 L .38259 .59782 L F
.38266 .59782 m .38114 .5989 L .38259 .59782 L F
.38351 .59722 m .3802 .59938 L .38271 .59829 L F
.67 .166 0 r
.38234 .5978 m .38271 .59829 L .38206 .59778 L F
.38234 .5978 m .38206 .59778 L .38135 .59722 L F
0 .365 .801 r
.32738 .6587 m .328 .65921 L .3262 .65867 L F
.328 .65921 m .32928 .66026 L .32762 .65941 L F
.328 .65921 m .32762 .65941 L .3262 .65867 L F
.826 .692 .717 r
.32793 .65332 m .32988 .6583 L .32579 .65668 L F
.775 .296 .097 r
.32579 .65668 m .32988 .6583 L .32738 .6587 L F
0 .121 .663 r
.32987 .6554 m .32988 .6583 L .32793 .65332 L F
.896 .977 .813 r
.32738 .6587 m .32988 .6583 L .32987 .6554 L F
.962 .694 .481 r
.32928 .66026 m .32988 .6583 L .32738 .6587 L F
.831 .822 .84 r
.32909 .65806 m .32928 .66026 L .33208 .65695 L F
.236 0 0 r
.32738 .6587 m .32913 .65792 L .32891 .65825 L F
.831 .822 .84 r
.32738 .6587 m .328 .65921 L .32891 .65825 L F
.539 .79 .991 r
.32492 .65945 m .32928 .66026 L .32738 .6587 L F
.831 .822 .84 r
.32909 .65806 m .32928 .66026 L .33208 .65695 L F
.32738 .6587 m .328 .65921 L .32909 .65806 L F
.328 .65921 m .32928 .66026 L .32909 .65806 L F
.328 .65921 m .32928 .66026 L .32909 .65806 L F
0 0 0 r
.32843 .659 m .32891 .65825 L .32894 .65873 L F
.32891 .65825 m .32913 .65792 L .3291 .65806 L F
.32891 .65825 m .3291 .65806 L .32894 .65873 L F
.236 0 0 r
.32738 .6587 m .32891 .65825 L .32782 .65993 L F
.831 .822 .84 r
.32738 .6587 m .32891 .65825 L .32909 .65806 L F
0 0 0 r
.32894 .65873 m .3291 .65806 L .33069 .65687 L F
.3291 .65806 m .32913 .65792 L .32939 .65774 L F
.3291 .65806 m .32939 .65774 L .33069 .65687 L F
.32782 .65993 m .32843 .659 L .32894 .65873 L F
0 .365 .801 r
.32738 .6587 m .3262 .65867 L .32492 .65945 L F
.988 .89 .569 r
.32579 .65668 m .3262 .65867 L .32492 .65945 L F
.485 .226 .447 r
.51789 .48575 m .5177 .48811 L .51502 .48866 L F
.535 .268 .456 r
.51789 .48575 m .52045 .48772 L .5177 .48811 L F
.542 .265 .444 r
.52064 .48542 m .52045 .48772 L .51789 .48575 L F
.864 .584 .512 r
.39149 .6716 m .3937 .66989 L .39195 .66938 L F
.39149 .6716 m .39441 .67111 L .3937 .66989 L F
.471 .241 .483 r
.31557 .5472 m .31823 .54684 L .31843 .54386 L F
.588 .338 .505 r
.31843 .54386 m .31823 .54684 L .32087 .5462 L F
.145 0 0 r
.64617 .38567 m .64368 .3858 L .64702 .38474 L F
0 0 0 r
.64702 .38474 m .64271 .38661 L .6455 .386 L F
.546 .867 .583 r
.64747 .38424 m .64702 .38474 L .6455 .386 L F
.64889 .38297 m .64702 .38474 L .64747 .38424 L F
.145 0 0 r
.64767 .38559 m .64617 .38567 L .64702 .38474 L F
.781 .965 .661 r
.64889 .38297 m .65029 .38216 L .64767 .38559 L F
.79 .996 .864 r
.64889 .38297 m .64767 .38559 L .64702 .38474 L F
0 0 0 r
.37742 .59933 m .37888 .59881 L .3763 .59809 L F
.45178 .57482 m .45293 .57351 L .45053 .576 L F
.123 .217 .69 r
.45053 .576 m .45274 .57867 L .45178 .57482 L F
.183 0 0 r
.26749 .62402 m .26775 .62296 L .26476 .6248 L F
.418 0 .016 r
.26856 .62385 m .26775 .62296 L .26749 .62402 L F
.464 .09 .244 r
.43817 .45976 m .4355 .46058 L .43527 .46063 L F
.49 .502 .796 r
.44666 .56611 m .44446 .56744 L .44314 .56308 L F
.421 .358 .681 r
.44666 .56611 m .44722 .56882 L .44446 .56744 L F
.566 .634 .878 r
.23091 .57917 m .22723 .57648 L .22961 .57627 L F
.315 .496 .877 r
.22961 .57627 m .23252 .57764 L .23091 .57917 L F
.172 .068 .485 r
.23252 .57764 m .23041 .58179 L .23091 .57917 L F
.454 .463 .779 r
.38472 .47861 m .38774 .48155 L .38723 .47788 L F
.769 .744 .83 r
.38896 .47667 m .38723 .47788 L .38643 .47458 L F
.871 .543 .427 r
.38643 .47458 m .38751 .47737 L .38712 .47727 L F
.454 .463 .779 r
.38472 .47861 m .38591 .48261 L .38774 .48155 L F
.751 .847 .401 r
.38718 .4775 m .38609 .47963 L .38431 .47863 L F
.38751 .47737 m .38725 .47779 L .38718 .4775 L F
0 0 .19 r
.38723 .47788 m .38723 .47771 L .38716 .47744 L F
.38723 .47788 m .38716 .47744 L .38712 .4773 L F
.751 .847 .401 r
.38725 .47779 m .38609 .47963 L .38718 .4775 L F
0 0 .19 r
.38712 .4773 m .38716 .47744 L .38712 .47727 L F
.38658 .47523 m .38712 .47727 L .38643 .47458 L F
.38723 .47788 m .38712 .47727 L .38658 .47523 L F
.844 .453 .308 r
.38248 .47615 m .38712 .47727 L .38431 .47863 L F
.38712 .47727 m .38751 .47737 L .38718 .4775 L F
.38712 .47727 m .38718 .4775 L .38431 .47863 L F
.871 .543 .427 r
.38643 .47458 m .38712 .47727 L .38248 .47615 L F
0 0 .19 r
.38723 .47771 m .38723 .47762 L .38643 .47458 L F
.544 .324 .531 r
.38723 .47788 m .38774 .48155 L .39041 .48104 L F
0 0 0 r
.25207 .51812 m .24799 .52083 L .2502 .52021 L F
.25207 .51812 m .24673 .52151 L .24799 .52083 L F
.2502 .52021 m .25413 .51693 L .25207 .51812 L F
.588 .729 .941 r
.62407 .40673 m .62255 .40906 L .62271 .40673 L F
.62407 .40673 m .6254 .40861 L .62255 .40906 L F
.71 .838 .943 r
.3572 .58921 m .35918 .59047 L .36152 .58923 L F
.644 .562 .748 r
.35918 .59047 m .36288 .59197 L .36152 .58923 L F
.529 .807 .997 r
.2586 .55583 m .26056 .55726 L .26294 .5566 L F
0 0 0 r
.33964 .57494 m .3384 .57539 L .33733 .57789 L F
.944 .734 .265 r
.41125 .57951 m .41034 .58046 L .41049 .57787 L F
.41125 .57951 m .41123 .58246 L .41034 .58046 L F
.735 .816 .915 r
.41869 .49503 m .41604 .4963 L .41432 .49463 L F
0 .056 .621 r
.31842 .65942 m .31653 .65722 L .31666 .65588 L F
.975 .924 .647 r
.40834 .55659 m .40928 .55718 L .40819 .55934 L F
.228 .046 .414 r
.49096 .52587 m .48923 .52455 L .49135 .52354 L F
.49096 .52587 m .48909 .52704 L .48923 .52455 L F
0 0 0 r
.7169 .30816 m .71612 .30977 L .71699 .30848 L F
.71681 .30785 m .7169 .30816 L .71828 .30701 L F
.508 .911 .836 r
.7169 .30816 m .72098 .30674 L .71828 .30701 L F
.7169 .30816 m .71963 .30657 L .72098 .30674 L F
.625 .876 .989 r
.71865 .30603 m .71963 .30657 L .7169 .30816 L F
0 0 0 r
.7169 .30816 m .71699 .30848 L .71865 .30603 L F
.71429 .30929 m .7169 .30816 L .71681 .30785 L F
.879 .881 .832 r
.44124 .50511 m .43705 .50718 L .43955 .5034 L F
.719 .77 .893 r
.44393 .50342 m .44124 .50511 L .43955 .5034 L F
.688 .634 .79 r
.32858 .51466 m .32569 .51521 L .32478 .5139 L F
.737 .789 .895 r
.33208 .65695 m .33308 .65943 L .33243 .65675 L F
.284 .461 .859 r
.25157 .57483 m .25075 .57721 L .24979 .57523 L F
.25157 .57483 m .25418 .57861 L .25075 .57721 L F
.968 .649 .333 r
.38054 .6118 m .38128 .61508 L .37937 .6139 L F
.858 .863 .414 r
.38339 .60872 m .38128 .61508 L .38054 .6118 L F
.631 .773 .949 r
.27211 .57685 m .26715 .57567 L .26966 .57525 L F
.658 .875 .98 r
.27358 .57555 m .27211 .57685 L .26966 .57525 L F
0 0 0 r
.27358 .57555 m .27058 .57833 L .27211 .57685 L F
.843 .889 .873 r
.44211 .57545 m .44632 .57358 L .44377 .57193 L F
.652 .529 .701 r
.44377 .57193 m .44632 .57358 L .4488 .57254 L F
.612 .863 .512 r
.67486 .30808 m .67642 .30591 L .67621 .30635 L F
.648 .921 .631 r
.67486 .30808 m .67352 .30896 L .67642 .30591 L F
.918 .909 .512 r
.27836 .64643 m .27756 .65069 L .27787 .64904 L F
.744 .481 0 r
.27756 .65069 m .27762 .6518 L .27787 .64904 L F
.27756 .65069 m .27817 .65361 L .27762 .6518 L F
.319 .227 .591 r
.35567 .563 m .35603 .56578 L .35466 .56641 L F
.698 .568 .705 r
.35603 .56578 m .35312 .56798 L .35466 .56641 L F
0 0 0 r
.64237 .3331 m .64462 .3317 L .64599 .3307 L F
.586 .888 .6 r
.64599 .3307 m .64641 .32982 L .64825 .32947 L F
.64599 .3307 m .64462 .3317 L .64641 .32982 L F
.038 .599 .803 r
.43134 .50042 m .43187 .50032 L .43331 .50069 L F
.908 .877 .793 r
.42834 .50318 m .43053 .50465 L .43331 .50069 L F
.42834 .50318 m .43331 .50069 L .43092 .50213 L F
.998 .849 .545 r
.43331 .50069 m .43092 .50213 L .43187 .50032 L F
.524 .397 .649 r
.43092 .50213 m .43245 .50022 L .43187 .50032 L F
.829 .995 .852 r
.43331 .50069 m .43187 .50032 L .43437 .49783 L F
.524 .397 .649 r
.43245 .50022 m .4331 .49941 L .43187 .50032 L F
.038 .599 .803 r
.429 .5001 m .43187 .50032 L .43134 .50042 L F
.829 .995 .852 r
.43331 .50069 m .43437 .49783 L .43572 .49806 L F
.625 .103 0 r
.43331 .50069 m .43585 .50298 L .43092 .50213 L F
0 0 0 r
.65208 .38117 m .65029 .38216 L .64889 .38297 L F
.489 .362 .633 r
.34897 .62423 m .34651 .62799 L .34603 .62494 L F
.34897 .62423 m .34936 .62729 L .34651 .62799 L F
.368 .34 .697 r
.34947 .63005 m .34651 .62799 L .34936 .62729 L F
.725 .29 .218 r
.4402 .56976 m .44297 .56987 L .44051 .57103 L F
.958 .663 .434 r
.44297 .56987 m .44107 .57096 L .44097 .57082 L F
.752 .923 .947 r
.44107 .57096 m .44722 .56882 L .44563 .56766 L F
.742 .753 .862 r
.44107 .57096 m .44563 .56766 L .4417 .56757 L F
0 0 .104 r
.44154 .57162 m .44107 .57096 L .44171 .56978 L F
.44144 .57264 m .44107 .57096 L .44154 .57162 L F
.958 .663 .434 r
.44097 .57082 m .44107 .57096 L .44051 .57103 L F
.137 0 0 r
.55448 .47403 m .55792 .47151 L .55741 .47312 L F
.234 0 .088 r
.55792 .47151 m .55986 .47305 L .55741 .47312 L F
.55792 .47151 m .56046 .47164 L .55986 .47305 L F
.806 .568 .579 r
.69729 .31679 m .69346 .31936 L .69324 .31676 L F
.69729 .31679 m .69735 .31989 L .69346 .31936 L F
.973 .662 .348 r
.59172 .41865 m .59316 .41776 L .59239 .41619 L F
.59172 .41865 m .59351 .42032 L .59316 .41776 L F
.785 .748 .819 r
.37144 .6345 m .37017 .63169 L .36949 .63394 L F
.37144 .6345 m .37225 .63044 L .37017 .63169 L F
.37144 .6345 m .36949 .63394 L .3718 .63222 L F
.737 .934 .953 r
.36949 .63394 m .37144 .6345 L .3718 .63222 L F
0 0 0 r
.37023 .63361 m .36949 .63394 L .3718 .63222 L F
.717 .932 .96 r
.36913 .63583 m .36949 .63394 L .36802 .63461 L F
0 0 0 r
.36847 .63517 m .36949 .63394 L .37023 .63361 L F
.717 .932 .96 r
.36802 .63461 m .36949 .63394 L .36755 .6341 L F
.36913 .63583 m .37144 .6345 L .36949 .63394 L F
.434 .082 .268 r
.2269 .56738 m .2245 .56842 L .22629 .5697 L F
0 .103 .658 r
.2269 .56881 m .22629 .5697 L .2245 .56842 L F
.2269 .56881 m .22831 .57178 L .22629 .5697 L F
.318 .226 .591 r
.22629 .5697 m .22831 .57178 L .22653 .5724 L F
.461 .873 .729 r
.61711 .37668 m .61521 .37809 L .61453 .37766 L F
.61711 .37668 m .61872 .37608 L .61521 .37809 L F
.588 .944 .905 r
.68456 .37407 m .68883 .37278 L .68726 .37269 L F
.587 .946 .883 r
.68726 .37269 m .68883 .37278 L .69117 .37133 L F
0 0 0 r
.45398 .56289 m .45191 .56705 L .45279 .56552 L F
.101 .246 .727 r
.4553 .56151 m .45536 .56318 L .45398 .56289 L F
.703 .557 .686 r
.45279 .56552 m .45536 .56318 L .45398 .56289 L F
0 0 .319 r
.47929 .56286 m .47902 .56653 L .47925 .56306 L F
0 0 0 r
.61675 .35932 m .6164 .35996 L .61765 .35768 L F
.485 .901 .87 r
.61599 .36072 m .6164 .35996 L .61793 .36021 L F
.753 .67 .77 r
.6142 .3634 m .61805 .36409 L .6164 .35996 L F
0 0 0 r
.61546 .36168 m .6164 .35996 L .61675 .35932 L F
.485 .901 .87 r
.61347 .36138 m .6164 .35996 L .61599 .36072 L F
.236 0 0 r
.6164 .35996 m .6209 .3611 L .61793 .36021 L F
.724 .659 .785 r
.35561 .61245 m .35092 .61644 L .35018 .61519 L F
.663 .286 .321 r
.36169 .68746 m .36286 .68616 L .35857 .68611 L F
.529 .187 .332 r
.36429 .68871 m .36286 .68616 L .36169 .68746 L F
.36429 .68871 m .36614 .68644 L .36286 .68616 L F
.264 0 .311 r
.3631 .58705 m .36152 .58923 L .36412 .58813 L F
.779 .948 .612 r
.36169 .5885 m .36152 .58923 L .36282 .58743 L F
0 0 .396 r
.36288 .59197 m .36443 .58799 L .36152 .58923 L F
.871 .736 .71 r
.36414 .58815 m .36214 .59003 L .36169 .5885 L F
.36434 .58812 m .36426 .58827 L .36414 .58815 L F
.36633 .58783 m .36443 .58824 L .36434 .58812 L F
.36443 .58824 m .36426 .58827 L .36434 .58812 L F
0 0 .396 r
.36288 .59197 m .36439 .59105 L .36443 .58824 L F
.36437 .58815 m .36443 .58824 L .36443 .58799 L F
.36288 .59197 m .36443 .58824 L .36437 .58815 L F
.683 .477 .601 r
.36443 .58799 m .36443 .58824 L .36633 .58783 L F
.36443 .58824 m .36439 .59105 L .36633 .58783 L F
.871 .736 .71 r
.36633 .58783 m .36466 .58871 L .36426 .58827 L F
.36466 .58871 m .36214 .59003 L .36414 .58815 L F
.264 0 .311 r
.36454 .58506 m .3631 .58705 L .36414 .58812 L F
.3631 .58705 m .36412 .58813 L .36414 .58812 L F
.581 .26 .389 r
.36633 .58783 m .36414 .58815 L .36454 .58506 L F
.264 0 .311 r
.36454 .58506 m .36414 .58812 L .36443 .58799 L F
.779 .948 .612 r
.36169 .5885 m .36282 .58743 L .36454 .58506 L F
.581 .26 .389 r
.36414 .58815 m .36169 .5885 L .36454 .58506 L F
.535 .061 .075 r
.36169 .5885 m .36214 .59003 L .3608 .58935 L F
.36169 .5885 m .3598 .58883 L .36152 .58923 L F
.36169 .5885 m .3608 .58935 L .3598 .58883 L F
.285 .27 .666 r
.36574 .58134 m .36454 .58506 L .36306 .582 L F
.36574 .58134 m .36657 .58514 L .36454 .58506 L F
.29 .171 .539 r
.36454 .58506 m .36633 .58783 L .36657 .58514 L F
.614 .268 .361 r
.36443 .58799 m .36633 .58783 L .36454 .58506 L F
.29 .171 .539 r
.36454 .58506 m .36633 .58783 L .36657 .58514 L F
.661 .575 .748 r
.55382 .40444 m .54968 .40108 L .55412 .40171 L F
.637 .331 .436 r
.53385 .47884 m .53235 .48174 L .52966 .48156 L F
.635 .355 .476 r
.5363 .47877 m .53235 .48174 L .53385 .47884 L F
.628 .488 .673 r
.32123 .56266 m .32268 .56633 L .32009 .5665 L F
.644 .496 .668 r
.32526 .56294 m .32268 .56633 L .32123 .56266 L F
.763 .683 .774 r
.3931 .4734 m .39386 .47533 L .39706 .47273 L F
.746 .954 .943 r
.65469 .3908 m .65563 .39171 L .65803 .39 L F
0 0 0 r
.32488 .52921 m .32645 .52811 L .32833 .52635 L F
.343 .568 .922 r
.32488 .52921 m .32711 .52955 L .32645 .52811 L F
.489 .211 .418 r
.32711 .52955 m .32461 .53015 L .32488 .52921 L F
.188 0 0 r
.35158 .64632 m .35059 .64533 L .34939 .64567 L F
.35158 .64632 m .35303 .6449 L .35059 .64533 L F
.72 .237 .099 r
.38162 .59683 m .38351 .59722 L .38271 .59829 L F
.503 0 0 r
.36988 .5533 m .37101 .55413 L .37496 .55431 L F
.766 .919 .939 r
.37496 .55431 m .37351 .55293 L .37544 .55301 L F
.37496 .55431 m .37101 .55413 L .37351 .55293 L F
.577 .795 .982 r
.39593 .48729 m .39693 .48862 L .39348 .48814 L F
.39348 .48814 m .39693 .48862 L .39593 .48729 L F
.406 .698 .981 r
.39593 .48729 m .39817 .4871 L .39693 .48862 L F
.39593 .48729 m .39817 .4871 L .39693 .48862 L F
.589 .928 .727 r
.42981 .49591 m .42968 .49661 L .43201 .4951 L F
.42981 .49591 m .42797 .49745 L .42968 .49661 L F
.647 .697 .883 r
.33966 .53418 m .33554 .53317 L .3392 .53345 L F
.561 .665 .907 r
.34047 .53072 m .33966 .53418 L .3392 .53345 L F
.34047 .53072 m .34215 .5337 L .33966 .53418 L F
0 0 .001 r
.3396 .53682 m .34215 .5337 L .33966 .53418 L F
.3396 .53682 m .34215 .5337 L .33966 .53418 L F
.889 .559 .063 r
.3931 .4734 m .39309 .47507 L .39386 .47533 L F
.719 .29 .23 r
.39274 .47743 m .39386 .47533 L .39309 .47507 L F
.39274 .47743 m .39688 .47806 L .39386 .47533 L F
.899 .979 .805 r
.54741 .43573 m .54785 .43704 L .55029 .43375 L F
0 .297 .791 r
.54942 .43769 m .54785 .43704 L .54741 .43573 L F
.91 .702 .61 r
.59838 .44179 m .60189 .44016 L .60128 .43965 L F
.59838 .44179 m .60213 .44374 L .60189 .44016 L F
.267 .246 .649 r
.22605 .59896 m .22624 .60256 L .22831 .60038 L F
.34 .356 .731 r
.22624 .60256 m .22897 .60418 L .22831 .60038 L F
.874 .616 .546 r
.39149 .6716 m .39367 .67368 L .39441 .67111 L F
.715 .536 .646 r
.33719 .5536 m .33786 .5569 L .33313 .55578 L F
.407 .331 .659 r
.33966 .5558 m .33786 .5569 L .33719 .5536 L F
.833 .78 .801 r
.55825 .41127 m .56223 .41008 L .56105 .40705 L F
.18 .708 .854 r
.56223 .41008 m .56071 .40975 L .56105 .40705 L F
.56223 .41008 m .56479 .40984 L .56071 .40975 L F
.647 .593 .78 r
.28102 .51436 m .28214 .51618 L .28466 .51524 L F
.922 .576 .363 r
.40082 .48375 m .40323 .48476 L .40306 .48387 L F
.40178 .48308 m .40306 .48387 L .40278 .48237 L F
.40082 .48375 m .40306 .48387 L .40178 .48308 L F
.744 .27 .119 r
.40066 .48304 m .40082 .48375 L .40203 .4832 L F
.39708 .48263 m .40082 .48375 L .40066 .48304 L F
.902 .537 .336 r
.40203 .4832 m .40082 .48375 L .40178 .48308 L F
.744 .27 .119 r
.39708 .48263 m .40197 .4832 L .40178 .48308 L F
.39783 .48111 m .40178 .48308 L .398 .48074 L F
.39708 .48263 m .40178 .48308 L .39783 .48111 L F
.398 .48074 m .40203 .4832 L .39864 .47944 L F
.40197 .4832 m .40203 .4832 L .398 .48074 L F
.887 .574 .45 r
.40068 .48645 m .40323 .48476 L .40082 .48375 L F
.902 .537 .336 r
.40203 .4832 m .40178 .48308 L .40278 .48237 L F
.949 .727 .568 r
.39864 .47944 m .40203 .4832 L .39963 .47744 L F
.52 .543 .82 r
.39963 .47744 m .40203 .4832 L .40337 .48051 L F
.086 .075 .547 r
.40189 .48228 m .4011 .48498 L .40082 .48375 L F
.4011 .48498 m .40068 .48645 L .40082 .48375 L F
.087 0 .387 r
.61552 .3996 m .6139 .39794 L .61403 .39563 L F
.74 .668 .78 r
.61726 .39387 m .61403 .39563 L .61423 .39441 L F
.61726 .39387 m .61858 .39657 L .61403 .39563 L F
.767 .477 .494 r
.61403 .39563 m .61858 .39657 L .61768 .39859 L F
.61403 .39563 m .61768 .39859 L .61552 .3996 L F
0 0 0 r
.61492 .39433 m .61403 .39563 L .61349 .39725 L F
0 0 .179 r
.616 .3891 m .61423 .39441 L .61726 .39387 L F
.177 .712 .763 r
.61506 .39402 m .61726 .39387 L .61423 .39441 L F
0 0 0 r
.61506 .39402 m .61403 .39563 L .61492 .39433 L F
0 .207 .729 r
.61403 .39563 m .6139 .39794 L .61332 .39666 L F
.61403 .39563 m .61332 .39666 L .61207 .39393 L F
.087 0 .387 r
.61552 .3996 m .61305 .4019 L .6139 .39794 L F
.23 .251 .676 r
.21886 .566 m .21923 .56971 L .2206 .56752 L F
.178 .069 .483 r
.21865 .57252 m .22089 .57124 L .2206 .56752 L F
.23 .251 .676 r
.21886 .566 m .2206 .56752 L .2211 .56806 L F
.21886 .566 m .22063 .56763 L .21977 .56622 L F
.22063 .56763 m .2211 .56806 L .22076 .56759 L F
.22063 .56763 m .22076 .56759 L .21977 .56622 L F
.178 .069 .483 r
.21865 .57252 m .22055 .56765 L .21923 .56971 L F
.22055 .56765 m .2206 .56752 L .22052 .56765 L F
.22055 .56765 m .22052 .56765 L .21923 .56971 L F
.428 .83 .979 r
.44196 .5965 m .44411 .59757 L .44538 .59664 L F
.82 .919 .903 r
.5665 .3874 m .56461 .38943 L .56337 .38803 L F
.762 .649 .736 r
.33416 .51078 m .33612 .51564 L .33114 .51411 L F
.581 .555 .791 r
.33764 .51415 m .33612 .51564 L .33416 .51078 L F
.766 .955 .639 r
.33764 .51415 m .33516 .51733 L .33612 .51564 L F
.487 .313 .571 r
.48909 .52704 m .48918 .5298 L .48657 .52774 L F
.404 .322 .65 r
.48918 .5298 m .48715 .53076 L .48657 .52774 L F
.675 .868 .972 r
.43906 .45269 m .44149 .45144 L .44306 .45273 L F
.653 .876 .982 r
.44149 .45144 m .4455 .45147 L .44306 .45273 L F
.346 .418 .794 r
.24006 .58465 m .24081 .58171 L .23846 .58233 L F
.24006 .58465 m .24193 .58509 L .24081 .58171 L F
.951 .887 .733 r
.37861 .498 m .37823 .4948 L .37984 .49606 L F
.796 .309 0 r
.46351 .53821 m .46364 .53863 L .46156 .53778 L F
.991 .776 .394 r
.46364 .53863 m .46266 .53549 L .46156 .53778 L F
.42 .322 .637 r
.34489 .52764 m .34762 .52995 L .34748 .527 L F
.34489 .52764 m .34551 .5308 L .34762 .52995 L F
.966 .641 .308 r
.39188 .55531 m .3931 .55387 L .39156 .55257 L F
.39188 .55531 m .39336 .55631 L .3931 .55387 L F
0 0 .073 r
.22364 .58927 m .22412 .58482 L .22248 .5854 L F
.22364 .58927 m .22401 .58774 L .22412 .58482 L F
0 .05 .614 r
.22364 .58927 m .22558 .59186 L .22401 .58774 L F
.42 .078 .276 r
.36635 .57935 m .36574 .58134 L .36306 .582 L F
.546 .193 .321 r
.36635 .57935 m .3671 .58056 L .3689 .57924 L F
.36635 .57935 m .36574 .58134 L .3671 .58056 L F
.288 .112 .461 r
.36635 .57935 m .3671 .58056 L .3689 .57924 L F
.546 .193 .321 r
.3671 .58056 m .36574 .58134 L .36635 .57935 L F
.3671 .58056 m .36574 .58134 L .36635 .57935 L F
.664 .9 .979 r
.67968 .3523 m .68052 .3539 L .68362 .35146 L F
.724 .659 .785 r
.35561 .61245 m .3532 .61887 L .35092 .61644 L F
0 0 0 r
.35505 .61396 m .3532 .61887 L .35561 .61245 L F
.3546 .61516 m .3532 .61887 L .35505 .61396 L F
0 .291 .786 r
.35092 .61644 m .3532 .61887 L .35355 .61802 L F
.873 .759 .733 r
.35353 .61803 m .3505 .62506 L .35034 .61977 L F
0 0 0 r
.35355 .61802 m .3532 .61887 L .35421 .61622 L F
.873 .759 .733 r
.35355 .61802 m .35344 .61827 L .35353 .61803 L F
.35344 .61827 m .3505 .62506 L .35353 .61803 L F
0 0 0 r
.3548 .61463 m .3546 .61516 L .35505 .61396 L F
.35421 .61622 m .35391 .617 L .3548 .61463 L F
.35391 .617 m .3532 .61887 L .3548 .61463 L F
0 .291 .786 r
.35092 .61644 m .35353 .61802 L .35034 .61977 L F
.35353 .61802 m .35355 .61802 L .35353 .61803 L F
.35353 .61802 m .35353 .61803 L .35034 .61977 L F
.713 .875 .957 r
.33072 .64542 m .33127 .64313 L .32881 .64158 L F
.33072 .64542 m .33314 .6441 L .33127 .64313 L F
.7 .822 .374 r
.22748 .54407 m .2281 .54242 L .22928 .5403 L F
.853 .905 .493 r
.22685 .54417 m .22748 .54407 L .2281 .54242 L F
.22685 .54417 m .22622 .54641 L .22712 .54472 L F
0 0 .229 r
.22622 .54641 m .22675 .54736 L .22685 .54417 L F
.853 .905 .493 r
.22685 .54417 m .2281 .54242 L .22673 .54418 L F
.894 .914 .516 r
.22685 .54417 m .22621 .54485 L .22647 .54302 L F
.853 .905 .493 r
.22685 .54417 m .22673 .54418 L .22621 .54485 L F
.826 .647 .098 r
.22685 .54417 m .2265 .54347 L .22647 .54302 L F
.919 .974 .698 r
.2281 .54242 m .22673 .54418 L .22647 .54302 L F
.22673 .54418 m .22621 .54485 L .22647 .54302 L F
.826 .647 .098 r
.22673 .54418 m .22675 .54736 L .22655 .5442 L F
.22685 .54417 m .22683 .54465 L .22673 .54418 L F
.22683 .54465 m .22675 .54736 L .22673 .54418 L F
.22685 .54417 m .22655 .5442 L .2265 .54347 L F
.853 .905 .493 r
.22685 .54417 m .22712 .54472 L .22748 .54407 L F
0 0 0 r
.61561 .38316 m .61657 .38212 L .61876 .38161 L F
.85 .648 .629 r
.33571 .6468 m .33884 .6436 L .33942 .64408 L F
.608 .437 .624 r
.36442 .60221 m .36162 .60508 L .36165 .60243 L F
.638 .423 .576 r
.31557 .5472 m .31195 .55038 L .31573 .55001 L F
.805 .815 .859 r
.56679 .42307 m .57213 .42194 L .56997 .42001 L F
.837 .81 .824 r
.56997 .42001 m .57213 .42194 L .57322 .42059 L F
.83 .75 .775 r
.53512 .43774 m .53714 .43647 L .53548 .43277 L F
.803 .74 .793 r
.53548 .43277 m .53714 .43647 L .53937 .4334 L F
.636 .497 .676 r
.53714 .43647 m .54039 .43648 L .53937 .4334 L F
.22 .103 .5 r
.53714 .43647 m .53948 .43881 L .54039 .43648 L F
.53714 .43647 m .53771 .43975 L .53948 .43881 L F
.907 .724 .223 r
.60684 .42425 m .60609 .42502 L .60559 .42217 L F
.60684 .42425 m .60671 .42662 L .60609 .42502 L F
.61 .822 .982 r
.41511 .46947 m .41618 .47076 L .41971 .46988 L F
.571 .28 .435 r
.26928 .5526 m .27269 .55051 L .26795 .54962 L F
.26928 .5526 m .27193 .55284 L .27269 .55051 L F
.27269 .55051 m .27193 .55284 L .26928 .5526 L F
.173 0 .258 r
.27452 .54955 m .27193 .55284 L .27269 .55051 L F
.27452 .54955 m .27193 .55284 L .27269 .55051 L F
.798 .999 .845 r
.44786 .48902 m .44479 .49025 L .44613 .48753 L F
.44786 .48902 m .44464 .49179 L .44479 .49025 L F
.458 .261 .524 r
.44786 .48902 m .45026 .4856 L .44677 .48587 L F
.44815 .4886 m .45025 .48824 L .45026 .4856 L F
.44786 .48902 m .45025 .48824 L .44815 .4886 L F
.475 0 0 r
.44613 .48753 m .45025 .48824 L .44786 .48902 L F
.486 .213 .424 r
.45025 .48824 m .45323 .48548 L .45026 .4856 L F
.45025 .48824 m .45294 .48784 L .45323 .48548 L F
.475 0 0 r
.44613 .48753 m .44799 .48817 L .45025 .48824 L F
.451 0 0 r
.44799 .48817 m .45242 .48787 L .45025 .48824 L F
.45242 .48787 m .45294 .48784 L .45025 .48824 L F
0 0 0 r
.33029 .55924 m .32761 .56177 L .32871 .56031 L F
.828 .731 .757 r
.41572 .46342 m .41135 .46536 L .41388 .46206 L F
.41572 .46342 m .41389 .46631 L .41135 .46536 L F
.15 0 0 r
.46353 .59216 m .46449 .59322 L .46184 .59372 L F
.46353 .59216 m .466 .5916 L .46449 .59322 L F
.263 .763 .889 r
.2533 .5245 m .25161 .52426 L .24917 .52456 L F
.51 .913 .857 r
.25656 .52283 m .25428 .52353 L .2533 .5245 L F
.36 0 .092 r
.25428 .52353 m .25161 .52426 L .2533 .5245 L F
.423 0 0 r
.46411 .53523 m .46266 .53549 L .46696 .53631 L F
.506 .847 .996 r
.58904 .4598 m .59293 .46 L .59157 .45908 L F
.331 .627 .959 r
.59293 .46 m .59449 .45834 L .59157 .45908 L F
.59293 .46 m .5961 .46046 L .59449 .45834 L F
0 .462 .803 r
.59293 .46 m .5973 .46159 L .5961 .46046 L F
.762 .58 .651 r
.32009 .5665 m .31598 .56913 L .31623 .5665 L F
.32009 .5665 m .32008 .56951 L .31598 .56913 L F
.707 .534 .653 r
.32226 .56862 m .32009 .5665 L .32268 .56633 L F
.32226 .56862 m .32008 .56951 L .32009 .5665 L F
.601 .441 .637 r
.35172 .57317 m .35186 .57601 L .34916 .57645 L F
.605 .429 .616 r
.3519 .5788 m .34916 .57645 L .35186 .57601 L F
.3519 .5788 m .34925 .57939 L .34916 .57645 L F
.601 .441 .637 r
.34916 .57645 m .35186 .57601 L .35172 .57317 L F
.605 .429 .616 r
.3519 .5788 m .34916 .57645 L .35186 .57601 L F
.3519 .5788 m .34925 .57939 L .34916 .57645 L F
.289 .074 .403 r
.48715 .53076 m .48684 .53306 L .48466 .53394 L F
.401 .288 .608 r
.48684 .53306 m .48417 .53742 L .48466 .53394 L F
.697 .95 .955 r
.4083 .46862 m .40907 .46621 L .41135 .46536 L F
.4083 .46862 m .40702 .46735 L .40907 .46621 L F
.608 .952 .815 r
.68711 .35233 m .68493 .35394 L .6833 .35425 L F
.417 .512 .848 r
.45947 .48221 m .45585 .47897 L .45655 .48185 L F
.45947 .48221 m .45783 .4784 L .45585 .47897 L F
.418 .828 .974 r
.57322 .38596 m .56935 .38592 L .57228 .38561 L F
.164 .594 .936 r
.57228 .38561 m .57606 .38733 L .57322 .38596 L F
.436 .152 .381 r
.31463 .63768 m .31458 .64 L .31204 .63994 L F
.305 .054 .359 r
.31706 .63645 m .31458 .64 L .31463 .63768 L F
.561 .283 .452 r
.33531 .54112 m .33416 .54299 L .3329 .54186 L F
0 0 0 r
.33251 .54365 m .3329 .54186 L .33416 .54299 L F
.61675 .37115 m .61963 .36856 L .61955 .37116 L F
.727 .625 .745 r
.62373 .3689 m .61955 .37116 L .61963 .36856 L F
.332 .111 .421 r
.69247 .33292 m .69115 .3358 L .69283 .33465 L F
.231 .301 .73 r
.69115 .3358 m .69365 .33848 L .69283 .33465 L F
.992 .755 .388 r
.69283 .33465 m .69365 .33848 L .69256 .33716 L F
0 0 .123 r
.69341 .33458 m .69283 .33465 L .69256 .33716 L F
0 0 .134 r
.69258 .33284 m .69432 .33328 L .69521 .33119 L F
.69263 .33295 m .69432 .33328 L .69258 .33284 L F
.69247 .33292 m .69283 .33465 L .69432 .33328 L F
.685 .963 .939 r
.69432 .33328 m .69283 .33465 L .69414 .33235 L F
0 0 .123 r
.69414 .33235 m .69317 .33407 L .69341 .33458 L F
.69317 .33407 m .69283 .33465 L .69341 .33458 L F
0 0 .134 r
.69247 .33292 m .69263 .33295 L .69258 .33284 L F
.812 .998 .85 r
.23304 .6002 m .23312 .60209 L .23616 .59926 L F
.842 .392 0 r
.23271 .60344 m .23312 .60209 L .23304 .6002 L F
0 0 .468 r
.23312 .60209 m .23469 .60543 L .23397 .60447 L F
.842 .392 0 r
.23271 .60344 m .23469 .60543 L .23312 .60209 L F
.8 .883 .906 r
.50384 .42113 m .49915 .42253 L .50214 .41945 L F
.803 .844 .882 r
.50495 .41679 m .50384 .42113 L .50214 .41945 L F
.50495 .41679 m .50686 .41851 L .50384 .42113 L F
.119 0 0 r
.30429 .57294 m .30236 .57444 L .29989 .57497 L F
.174 0 0 r
.30686 .57279 m .30236 .57444 L .30429 .57294 L F
.783 .4 .33 r
.31195 .55038 m .31536 .55176 L .31573 .55001 L F
.866 .876 .843 r
.31152 .55226 m .31281 .55382 L .31536 .55176 L F
0 0 0 r
.35561 .61245 m .3562 .61166 L .35529 .61386 L F
.35899 .60831 m .35739 .61087 L .3562 .61166 L F
.357 .61271 m .3562 .61166 L .35739 .61087 L F
.357 .61271 m .35529 .61386 L .3562 .61166 L F
.713 .603 .732 r
.54968 .40108 m .55104 .4048 L .54693 .40459 L F
.68 .463 .586 r
.55104 .4048 m .5469 .40726 L .54693 .40459 L F
.55104 .4048 m .55076 .4077 L .5469 .40726 L F
.661 .575 .748 r
.55382 .40444 m .55104 .4048 L .54968 .40108 L F
.358 .065 .324 r
.55382 .40444 m .55076 .4077 L .55104 .4048 L F
.794 .698 .759 r
.34852 .62162 m .34603 .62494 L .34486 .62128 L F
.604 .428 .616 r
.34852 .62162 m .34897 .62423 L .34603 .62494 L F
.085 0 .355 r
.34852 .62162 m .35092 .61644 L .35034 .61977 L F
0 .014 .517 r
.3505 .62506 m .34852 .62162 L .35034 .61977 L F
.3505 .62506 m .34897 .62423 L .34852 .62162 L F
.763 .695 .787 r
.32177 .53225 m .32247 .53341 L .32461 .53015 L F
.65 .539 .716 r
.32247 .53341 m .32622 .53447 L .32461 .53015 L F
.598 .903 .985 r
.2692 .57776 m .26862 .57944 L .27058 .57833 L F
0 .152 .685 r
.26715 .57567 m .26862 .57944 L .2692 .57776 L F
.396 .804 .593 r
.61133 .37439 m .61438 .37236 L .61313 .37268 L F
.399 .843 .735 r
.61313 .37268 m .61438 .37236 L .61675 .37115 L F
.276 .348 .757 r
.22165 .58141 m .22155 .58365 L .22303 .58103 L F
.359 .41 .778 r
.22248 .5854 m .22303 .58103 L .22155 .58365 L F
.798 .924 .92 r
.45315 .51998 m .45482 .52086 L .45764 .51843 L F
.771 .84 .904 r
.44806 .48425 m .44677 .48587 L .45026 .4856 L F
.833 .883 .451 r
.54239 .40143 m .54148 .40318 L .54259 .40462 L F
.54239 .40143 m .54098 .40389 L .54148 .40318 L F
.375 .668 .972 r
.63001 .41061 m .6254 .40861 L .62935 .40851 L F
.771 .952 .626 r
.62706 .41454 m .63001 .41061 L .62804 .41183 L F
.62706 .41454 m .62804 .41183 L .62802 .41186 L F
.62706 .41454 m .62787 .41227 L .62541 .41308 L F
.62787 .41227 m .62757 .41208 L .62541 .41308 L F
.62802 .41186 m .62799 .41186 L .62541 .41308 L F
.947 .939 .75 r
.6246 .41534 m .6254 .41798 L .62706 .41454 L F
.6246 .41534 m .62706 .41454 L .62541 .41308 L F
.977 .804 .602 r
.62402 .41122 m .62541 .41308 L .62366 .41299 L F
.99 .771 .513 r
.62426 .41297 m .62541 .41308 L .62402 .41122 L F
.404 .853 .907 r
.62366 .41299 m .6242 .41302 L .62389 .41293 L F
.6242 .41302 m .62541 .41308 L .62426 .41297 L F
.6242 .41302 m .62426 .41297 L .62389 .41293 L F
.99 .771 .513 r
.6246 .41534 m .62541 .41308 L .62426 .41297 L F
0 0 0 r
.62682 .41434 m .6246 .41534 L .62515 .41541 L F
.62682 .41434 m .62515 .41541 L .62517 .41537 L F
.62517 .41537 m .62515 .41538 L .62599 .41471 L F
.62514 .41538 m .62526 .41504 L .62599 .41471 L F
.62515 .41538 m .62599 .41471 L .62682 .41434 L F
.99 .857 .497 r
.62402 .41122 m .62366 .41299 L .62299 .41044 L F
.698 .805 .932 r
.62366 .41299 m .62437 .41266 L .62299 .41044 L F
.99 .771 .513 r
.62426 .41297 m .62402 .41122 L .62445 .4128 L F
.914 .573 .108 r
.6238 .41106 m .62443 .41276 L .62402 .41122 L F
.62299 .41044 m .62437 .41266 L .6238 .41106 L F
.62437 .41266 m .62443 .41276 L .6238 .41106 L F
.99 .771 .513 r
.62426 .41297 m .62445 .4128 L .62515 .41541 L F
.914 .573 .108 r
.62514 .41539 m .62514 .41538 L .62445 .4128 L F
.62444 .4128 m .62445 .4128 L .62402 .41122 L F
.62514 .41539 m .62445 .4128 L .62444 .4128 L F
.404 .853 .907 r
.62389 .41293 m .62406 .41295 L .62448 .41282 L F
.62442 .41279 m .62448 .41282 L .62573 .41245 L F
.62389 .41293 m .62448 .41282 L .62442 .41279 L F
.62437 .41266 m .6278 .41189 L .6268 .41153 L F
.62442 .41279 m .62803 .41184 L .62437 .41266 L F
.62573 .41245 m .62541 .41308 L .62755 .41207 L F
.62573 .41245 m .62755 .41207 L .62674 .41218 L F
.703 .544 .669 r
.62712 .41165 m .62681 .41344 L .6268 .41157 L F
.62802 .41186 m .62795 .41195 L .62712 .41165 L F
.404 .853 .907 r
.62674 .41218 m .62755 .41207 L .62799 .41186 L F
.62781 .4119 m .62799 .41186 L .62803 .41184 L F
.62674 .41218 m .62799 .41186 L .62781 .4119 L F
.771 .952 .626 r
.62787 .41227 m .62802 .41186 L .62757 .41208 L F
.703 .544 .669 r
.62795 .41195 m .62681 .41344 L .62705 .41207 L F
.62781 .4119 m .62705 .41207 L .62712 .41165 L F
.62795 .41195 m .62705 .41207 L .62781 .4119 L F
.62802 .41186 m .6268 .41157 L .6268 .41153 L F
.404 .853 .907 r
.6278 .41189 m .62803 .41184 L .6268 .41153 L F
.62366 .41299 m .62442 .41279 L .62437 .41266 L F
.698 .805 .932 r
.62437 .41266 m .6268 .41153 L .62299 .41044 L F
0 0 0 r
.62514 .41538 m .6246 .41534 L .62526 .41504 L F
.99 .771 .513 r
.6246 .41534 m .62426 .41297 L .62514 .41538 L F
.914 .573 .108 r
.62299 .41044 m .62514 .41539 L .62443 .41276 L F
.827 .712 .738 r
.62666 .41149 m .62638 .41223 L .62299 .41044 L F
.404 .853 .907 r
.62406 .41295 m .62541 .41308 L .62573 .41245 L F
.827 .712 .738 r
.62638 .41223 m .62517 .41537 L .62393 .41257 L F
.62638 .41223 m .62393 .41257 L .62299 .41044 L F
0 0 0 r
.62682 .41434 m .62517 .41537 L .62651 .41221 L F
.6268 .41212 m .62651 .41221 L .6268 .41153 L F
.62682 .41434 m .62651 .41221 L .6268 .41212 L F
.62515 .41538 m .62514 .41538 L .62515 .41538 L F
.62515 .41538 m .62515 .41538 L .62517 .41537 L F
.914 .573 .108 r
.62514 .41539 m .62515 .41541 L .62514 .41538 L F
.827 .712 .738 r
.62517 .41537 m .62515 .41541 L .62514 .41539 L F
.62517 .41537 m .62514 .41539 L .62299 .41044 L F
0 0 0 r
.62548 .41541 m .62515 .41538 L .62682 .41434 L F
.99 .771 .513 r
.6246 .41534 m .62514 .41538 L .62515 .41541 L F
.752 .655 .098 r
.6246 .41534 m .62433 .42025 L .6254 .41798 L F
.62454 .4163 m .62432 .41881 L .62433 .42025 L F
.6246 .41534 m .62432 .41881 L .62454 .4163 L F
.778 .5 .515 r
.62163 .42 m .62415 .42068 L .62432 .41881 L F
.869 .423 .09 r
.62432 .41881 m .62756 .42174 L .62433 .42025 L F
.778 .5 .515 r
.62415 .42068 m .62579 .42113 L .62432 .41881 L F
.918 .762 .277 r
.62399 .41662 m .62432 .41881 L .6246 .41534 L F
0 0 0 r
.62399 .41662 m .6246 .41534 L .62548 .41541 L F
.827 .712 .738 r
.6268 .41153 m .62678 .41157 L .62666 .41149 L F
.62678 .41157 m .62515 .41541 L .62666 .41149 L F
.703 .544 .669 r
.62828 .41152 m .62802 .41186 L .6268 .41153 L F
.771 .952 .626 r
.62802 .41186 m .62803 .41184 L .62799 .41186 L F
.703 .544 .669 r
.63111 .41148 m .62682 .41434 L .62681 .41344 L F
0 .093 .626 r
.63106 .40947 m .63001 .41061 L .62935 .40851 L F
.537 .879 .629 r
.62811 .41178 m .63001 .41061 L .63106 .40947 L F
.703 .544 .669 r
.62843 .41151 m .62804 .41183 L .62828 .41152 L F
.537 .879 .629 r
.62803 .41184 m .62804 .41183 L .62811 .41178 L F
.62804 .41183 m .63001 .41061 L .62811 .41178 L F
.703 .544 .669 r
.63111 .41148 m .62681 .41344 L .62804 .41183 L F
.63111 .41148 m .62804 .41183 L .62811 .41178 L F
.579 .219 .322 r
.62803 .41184 m .62811 .41178 L .63111 .41148 L F
.62811 .41178 m .63106 .40947 L .63111 .41148 L F
.703 .544 .669 r
.63111 .41148 m .62811 .41178 L .62843 .41151 L F
.771 .952 .626 r
.62802 .41186 m .62804 .41183 L .62803 .41184 L F
.685 .523 .661 r
.54392 .43267 m .54918 .43363 L .54674 .4309 L F
0 .235 .753 r
.54674 .4309 m .54918 .43363 L .54887 .43255 L F
.744 .845 .399 r
.54783 .43457 m .54741 .43573 L .54815 .4341 L F
0 0 .324 r
.54855 .43351 m .54837 .43378 L .54918 .43363 L F
.54392 .43267 m .54837 .43378 L .54855 .43351 L F
.54392 .43267 m .54481 .43445 L .54714 .43401 L F
.5462 .43324 m .54714 .43401 L .54837 .43378 L F
.54392 .43267 m .54714 .43401 L .5462 .43324 L F
.855 .946 .877 r
.54887 .43255 m .54918 .43363 L .54481 .43445 L F
.899 .979 .805 r
.54741 .43573 m .55029 .43375 L .54887 .43255 L F
0 .297 .791 r
.54942 .43769 m .54741 .43573 L .54878 .43792 L F
.036 .103 .604 r
.54783 .43457 m .54878 .43792 L .54741 .43573 L F
.744 .845 .399 r
.54783 .43457 m .54815 .4341 L .54887 .43255 L F
.036 .103 .604 r
.54829 .43334 m .54848 .4351 L .54783 .43457 L F
.54848 .4351 m .54878 .43792 L .54783 .43457 L F
.744 .845 .399 r
.54829 .43334 m .54783 .43457 L .54887 .43255 L F
.53 .814 .998 r
.54887 .43255 m .55029 .43375 L .55251 .43267 L F
.341 .242 .595 r
.55251 .43267 m .55029 .43375 L .55248 .43543 L F
.687 .98 .836 r
.64237 .3331 m .63882 .33501 L .64204 .333 L F
.439 .872 .787 r
.64237 .3331 m .64204 .333 L .64462 .3317 L F
.187 .72 .784 r
.26308 .51612 m .26576 .51568 L .26724 .51571 L F
.35 0 0 r
.26576 .51568 m .27011 .51688 L .26724 .51571 L F
.728 .24 .083 r
.27781 .57686 m .27583 .57788 L .27358 .57555 L F
.276 0 0 r
.2805 .57608 m .27583 .57788 L .27781 .57686 L F
.636 .649 .846 r
.3885 .67477 m .39149 .6716 L .38898 .67235 L F
.3885 .67477 m .39367 .67368 L .39149 .6716 L F
0 .394 .827 r
.28187 .54462 m .28399 .54649 L .28124 .54512 L F
.498 .429 .71 r
.28399 .54649 m .28192 .54753 L .28124 .54512 L F
.868 .995 .786 r
.44983 .568 m .45191 .56705 L .44965 .56946 L F
.173 0 .127 r
.44965 .56946 m .45191 .56705 L .45031 .56957 L F
.759 .993 .795 r
.45279 .56552 m .45191 .56705 L .44983 .568 L F
.498 .364 .629 r
.50393 .50418 m .50095 .5018 L .50373 .5014 L F
.50393 .50418 m .50148 .50509 L .50095 .5018 L F
.741 .964 .683 r
.68778 .29169 m .68501 .29474 L .68642 .29227 L F
.407 .835 .679 r
.68778 .29169 m .68887 .29083 L .69042 .29052 L F
.519 .553 .831 r
.3751 .60434 m .37645 .60049 L .37398 .60142 L F
.3751 .60434 m .37845 .60426 L .37645 .60049 L F
.551 .649 .9 r
.3751 .60434 m .3782 .60535 L .37845 .60426 L F
.833 .815 .833 r
.56997 .42001 m .57322 .42059 L .57241 .41665 L F
.682 .722 .879 r
.57241 .41665 m .57322 .42059 L .57645 .4182 L F
.557 .072 .06 r
.38549 .67259 m .38286 .67062 L .38199 .67339 L F
.745 .828 .916 r
.65892 .33231 m .66245 .33249 L .66145 .331 L F
.853 .877 .856 r
.66145 .331 m .66245 .33249 L .66527 .32933 L F
.898 .987 .768 r
.63418 .35841 m .63467 .35902 L .63727 .35493 L F
.775 .959 .645 r
.39049 .60698 m .38983 .60882 L .3924 .60542 L F
.928 .959 .645 r
.39049 .60698 m .3924 .60542 L .3922 .60351 L F
.717 .692 .825 r
.35355 .69238 m .35772 .69298 L .35613 .69008 L F
.555 .502 .751 r
.35772 .69298 m .35858 .68833 L .35613 .69008 L F
.35772 .69298 m .35999 .69245 L .35858 .68833 L F
.486 .516 .813 r
.35772 .69298 m .36119 .6963 L .35999 .69245 L F
.538 .321 .533 r
.31623 .5665 m .31598 .56913 L .31349 .5696 L F
.83 .724 .748 r
.44185 .49537 m .43915 .49661 L .44082 .49407 L F
.888 .911 .836 r
.44464 .49179 m .44185 .49537 L .44082 .49407 L F
.481 .187 .39 r
.36621 .54646 m .36526 .54942 L .36243 .55004 L F
.593 .568 .795 r
.36621 .54646 m .37051 .5503 L .36879 .54984 L F
.36621 .54646 m .36879 .54984 L .36877 .54664 L F
.749 .549 .625 r
.36877 .54664 m .36526 .54942 L .36621 .54646 L F
.149 0 0 r
.30243 .53828 m .30461 .53841 L .30707 .53758 L F
.567 .025 0 r
.30703 .53806 m .30707 .53758 L .30461 .53841 L F
.506 .178 .345 r
.30707 .53758 m .30885 .53931 L .30606 .53969 L F
.567 .025 0 r
.30703 .53806 m .30885 .53931 L .30707 .53758 L F
.814 .561 .555 r
.34346 .5563 m .33963 .55312 L .34369 .55355 L F
.652 .958 .759 r
.63791 .40539 m .63745 .40636 L .63897 .40441 L F
.711 .813 .928 r
.63398 .40623 m .63704 .40725 L .63745 .40636 L F
.478 .012 .068 r
.63398 .40623 m .63745 .40636 L .63359 .40673 L F
.644 .355 .466 r
.63359 .40673 m .63745 .40636 L .63481 .40824 L F
.652 .958 .759 r
.63481 .40824 m .63745 .40636 L .63791 .40539 L F
.711 .813 .928 r
.63704 .40725 m .63717 .40729 L .63745 .40636 L F
.774 .937 .935 r
.63717 .40729 m .64036 .40336 L .63745 .40636 L F
.63717 .40729 m .64142 .40446 L .64036 .40336 L F
.533 .335 .557 r
.67496 .34 m .6729 .3447 L .67274 .34035 L F
.806 .551 .553 r
.67156 .34197 m .67496 .34 L .67116 .33943 L F
.533 .335 .557 r
.67496 .34 m .67502 .34245 L .6729 .3447 L F
.806 .551 .553 r
.67156 .34197 m .67502 .34245 L .67496 .34 L F
.611 .579 .794 r
.67496 .34 m .6776 .33944 L .67628 .33539 L F
.729 .892 .502 r
.38835 .61066 m .38795 .61186 L .38983 .60882 L F
.754 .9 .508 r
.38835 .61066 m .38983 .60882 L .39049 .60698 L F
0 0 .323 r
.33422 .52443 m .33551 .51934 L .3338 .52173 L F
.33422 .52443 m .33529 .52339 L .33551 .51934 L F
0 0 .305 r
.33348 .52698 m .33529 .52339 L .33422 .52443 L F
.431 .347 .661 r
.39976 .47202 m .40178 .46885 L .39954 .46941 L F
.39976 .47202 m .40178 .46885 L .39954 .46941 L F
.096 0 0 r
.28938 .66302 m .29351 .66312 L .29246 .66319 L F
.503 .893 .952 r
.29351 .66312 m .29616 .66231 L .29419 .66192 L F
0 0 0 r
.24132 .53653 m .23873 .53722 L .24057 .53659 L F
.832 .381 .15 r
.54549 .42029 m .54572 .42171 L .54746 .42081 L F
.033 0 0 r
.54746 .42081 m .54881 .42108 L .55005 .42236 L F
.54746 .42081 m .54572 .42171 L .54881 .42108 L F
.575 .939 .817 r
.67628 .32219 m .67697 .32241 L .68016 .32032 L F
.553 .252 .41 r
.32391 .54109 m .32608 .542 L .3266 .5395 L F
.32391 .54109 m .32375 .54296 L .32608 .542 L F
.991 .77 .504 r
.60442 .45284 m .60327 .44933 L .60297 .45147 L F
.867 .7 .673 r
.6008 .45513 m .60442 .45284 L .60297 .45147 L F
.6008 .45513 m .60312 .45661 L .60442 .45284 L F
.24 .463 .874 r
.23818 .58745 m .23717 .58914 L .23544 .58618 L F
.147 0 .108 r
.53771 .43975 m .53527 .44088 L .5345 .44257 L F
.486 0 0 r
.35103 .49957 m .35218 .49974 L .35004 .49849 L F
.35103 .49957 m .35451 .50114 L .35218 .49974 L F
.932 .723 .598 r
.59714 .43272 m .5986 .42933 L .5956 .42918 L F
.781 .766 .839 r
.67527 .34375 m .67637 .34877 L .67206 .3488 L F
.801 .665 .714 r
.67206 .3488 m .67637 .34877 L .67379 .35251 L F
.633 .689 .884 r
.67773 .34413 m .67637 .34877 L .67527 .34375 L F
.67773 .34413 m .67905 .34769 L .67637 .34877 L F
.96 .893 .716 r
.42457 .55178 m .42699 .55013 L .42597 .54919 L F
.42457 .55178 m .42526 .5534 L .42699 .55013 L F
.803 .967 .91 r
.42597 .54919 m .42699 .55013 L .42989 .54793 L F
.965 .719 .516 r
.60301 .44689 m .60213 .44374 L .60148 .44542 L F
.932 .612 .412 r
.60149 .44821 m .60301 .44689 L .60148 .44542 L F
.60149 .44821 m .60327 .44933 L .60301 .44689 L F
.267 .246 .649 r
.22605 .59896 m .22831 .60038 L .22765 .59784 L F
.111 0 .187 r
.38591 .48261 m .38514 .48479 L .38774 .48155 L F
.571 .806 .988 r
.33114 .51411 m .32858 .51466 L .32964 .51266 L F
.33114 .51411 m .32858 .51466 L .32964 .51266 L F
.771 .578 .638 r
.54693 .40459 m .5469 .40726 L .54352 .40727 L F
.561 .02 0 r
.24292 .61565 m .24264 .61495 L .24072 .61384 L F
.24292 .61565 m .24379 .61602 L .24264 .61495 L F
.785 .293 0 r
.39244 .51686 m .38917 .51342 L .39089 .51475 L F
.539 .79 .991 r
.32492 .65945 m .32683 .661 L .32928 .66026 L F
.746 .249 0 r
.32679 .62904 m .32662 .62755 L .32431 .62932 L F
.32679 .62904 m .32799 .62958 L .32662 .62755 L F
.996 .862 .568 r
.35829 .63936 m .35976 .64099 L .3578 .64278 L F
.611 .689 .898 r
.33709 .52765 m .33554 .53317 L .33384 .52976 L F
.33723 .5277 m .33554 .53317 L .33709 .52765 L F
.33723 .5277 m .3392 .53345 L .33554 .53317 L F
.33736 .52775 m .3392 .53345 L .33723 .5277 L F
.379 .242 .567 r
.33704 .52748 m .33384 .52976 L .33348 .52698 L F
.777 .458 .447 r
.33641 .5274 m .33733 .52774 L .33829 .52766 L F
.379 .242 .567 r
.33729 .52752 m .33709 .52765 L .33704 .52748 L F
.33709 .52765 m .33384 .52976 L .33704 .52748 L F
.777 .458 .447 r
.33479 .52718 m .33458 .52799 L .33713 .52776 L F
.33711 .52769 m .33713 .52776 L .33733 .52774 L F
.33479 .52718 m .33713 .52776 L .33711 .52769 L F
.33479 .52718 m .33733 .52774 L .33641 .5274 L F
.611 .689 .898 r
.33729 .52752 m .33736 .52775 L .33723 .5277 L F
.33729 .52752 m .33723 .5277 L .33709 .52765 L F
.777 .458 .447 r
.33829 .52766 m .33732 .52774 L .33862 .52785 L F
.85 .439 0 r
.33862 .52785 m .3392 .53345 L .33736 .52775 L F
.33862 .52785 m .33736 .52775 L .33729 .52752 L F
.777 .458 .447 r
.33734 .52775 m .33458 .52799 L .33765 .52789 L F
.33732 .52774 m .33728 .52775 L .33734 .52775 L F
.33728 .52775 m .33458 .52799 L .33734 .52775 L F
.33732 .52774 m .33765 .52789 L .33862 .52785 L F
.379 .242 .567 r
.33734 .52753 m .33348 .52698 L .33813 .52762 L F
.33704 .52748 m .33348 .52698 L .33734 .52753 L F
.777 .458 .447 r
.33515 .52579 m .33787 .52741 L .33803 .52585 L F
.761 .307 .172 r
.34065 .52689 m .33785 .52741 L .33813 .52762 L F
.33785 .52741 m .33781 .52742 L .33782 .52742 L F
.33785 .52741 m .33782 .52742 L .33813 .52762 L F
.777 .458 .447 r
.33515 .52579 m .33734 .52753 L .33787 .52741 L F
.761 .307 .172 r
.33781 .52742 m .33729 .52752 L .33734 .52753 L F
.33781 .52742 m .33734 .52753 L .33813 .52762 L F
.777 .458 .447 r
.33781 .52742 m .33734 .52753 L .33824 .52765 L F
.761 .307 .172 r
.33781 .52742 m .33862 .52785 L .33729 .52752 L F
.34065 .52689 m .33862 .52785 L .33781 .52742 L F
.777 .458 .447 r
.33787 .52741 m .33781 .52742 L .33829 .52766 L F
.33781 .52742 m .33824 .52765 L .33829 .52766 L F
.33787 .52741 m .33862 .52785 L .33844 .52724 L F
.33787 .52741 m .33844 .52724 L .33803 .52585 L F
.33515 .52579 m .33479 .52718 L .33734 .52753 L F
.379 .242 .567 r
.33729 .52752 m .33704 .52748 L .33734 .52753 L F
.54 .894 .977 r
.37041 .68237 m .37206 .68293 L .36922 .68319 L F
.68 .943 .962 r
.37293 .68104 m .37206 .68293 L .37041 .68237 L F
.328 .544 .91 r
.37293 .68104 m .37421 .6836 L .37206 .68293 L F
0 0 0 r
.67989 .30115 m .68182 .29972 L .68225 .2978 L F
0 0 .137 r
.67989 .30115 m .68091 .30111 L .68182 .29972 L F
.67989 .30115 m .6795 .30364 L .68091 .30111 L F
.888 .46 .129 r
.37812 .52421 m .3794 .52729 L .38121 .52828 L F
.916 .534 .271 r
.3794 .52729 m .38187 .53007 L .38121 .52828 L F
0 0 0 r
.62493 .35918 m .6209 .3611 L .62378 .36052 L F
.647 .852 .462 r
.62619 .35705 m .62493 .35918 L .62378 .36052 L F
0 0 .2 r
.45045 .49585 m .44865 .50025 L .44932 .49909 L F
.561 .35 .551 r
.45045 .49585 m .44932 .49909 L .44908 .49548 L F
0 .078 .613 r
.57593 .37701 m .57584 .37354 L .57581 .3757 L F
.712 .868 .955 r
.35839 .55978 m .36043 .55546 L .35806 .55703 L F
.281 .23 .621 r
.36012 .55851 m .35806 .55703 L .36043 .55546 L F
.36012 .55851 m .35839 .55978 L .35806 .55703 L F
.726 .917 .958 r
.52599 .4407 m .52389 .43847 L .52473 .43977 L F
.95 .831 .692 r
.52338 .44247 m .52599 .4407 L .52473 .43977 L F
.52338 .44247 m .5252 .44333 L .52599 .4407 L F
.406 .841 .708 r
.33843 .65714 m .33933 .6568 L .34078 .65588 L F
.757 .628 .717 r
.62827 .40466 m .62935 .40851 L .6254 .40861 L F
.504 0 0 r
.62827 .40466 m .63187 .40764 L .62935 .40851 L F
0 .093 .626 r
.63106 .40947 m .62935 .40851 L .63187 .40764 L F
.696 .546 .679 r
.23498 .55019 m .23246 .5538 L .23297 .55137 L F
.565 .376 .583 r
.23498 .55019 m .23519 .55359 L .23246 .5538 L F
.777 .707 .786 r
.23783 .54684 m .23498 .55019 L .23333 .54635 L F
.407 .257 .564 r
.23733 .55239 m .23519 .55359 L .23498 .55019 L F
0 0 0 r
.68225 .2978 m .68447 .29581 L .68501 .29474 L F
.005 0 0 r
.68225 .2978 m .68403 .2982 L .68447 .29581 L F
.68225 .2978 m .68182 .29972 L .68403 .2982 L F
0 0 .328 r
.52882 .41671 m .52864 .41493 L .53034 .41222 L F
.116 0 .004 r
.28687 .57271 m .28918 .57201 L .28975 .57031 L F
.348 0 .076 r
.28975 .57031 m .29179 .57132 L .29399 .56903 L F
.28975 .57031 m .28918 .57201 L .29179 .57132 L F
0 0 0 r
.33789 .60496 m .33654 .60702 L .33567 .60835 L F
.508 .526 .81 r
.33894 .6007 m .33789 .60496 L .33674 .60154 L F
.33894 .6007 m .34037 .60449 L .33789 .60496 L F
0 0 0 r
.33845 .60527 m .33789 .60496 L .34037 .60449 L F
.33845 .60527 m .33654 .60702 L .33789 .60496 L F
.446 .433 .751 r
.34504 .61082 m .34362 .61396 L .34216 .61135 L F
.34504 .61082 m .34566 .61383 L .34362 .61396 L F
.796 .888 .911 r
.37861 .498 m .37473 .49849 L .37705 .49713 L F
.951 .887 .733 r
.37861 .498 m .37705 .49713 L .37823 .4948 L F
.793 .374 .253 r
.33509 .5008 m .33891 .5021 L .33758 .50377 L F
.51 .036 .065 r
.33758 .50377 m .33891 .5021 L .34151 .50317 L F
.812 .998 .85 r
.23304 .6002 m .23616 .59926 L .23418 .59808 L F
.596 .437 .637 r
.35172 .57317 m .35449 .57552 L .35453 .57274 L F
.35172 .57317 m .35186 .57601 L .35449 .57552 L F
.35172 .57317 m .35449 .57552 L .35453 .57274 L F
.35172 .57317 m .35186 .57601 L .35449 .57552 L F
.469 .513 .82 r
.5973 .46159 m .59833 .45839 L .5961 .46046 L F
.5973 .46159 m .5997 .46225 L .59833 .45839 L F
.611 .479 .677 r
.42824 .52459 m .43128 .52449 L .43078 .52091 L F
.605 .596 .816 r
.42824 .52459 m .43212 .52617 L .43128 .52449 L F
.532 .167 .293 r
.43128 .52449 m .4308 .52611 L .42824 .52459 L F
.611 .479 .677 r
.42824 .52459 m .43128 .52449 L .43078 .52091 L F
.632 .47 .645 r
.6102 .36823 m .61248 .36574 L .61063 .36606 L F
0 .348 .73 r
.58455 .38488 m .5863 .38588 L .5862 .38548 L F
.544 .304 .503 r
.45323 .48548 m .45682 .48485 L .45655 .48185 L F
.51 .179 .341 r
.45682 .48485 m .45947 .48221 L .45655 .48185 L F
.983 .704 .4 r
.39616 .5744 m .39758 .57301 L .39626 .5718 L F
.39616 .5744 m .39766 .5753 L .39758 .57301 L F
0 0 0 r
.35959 .64678 m .36321 .64336 L .36096 .6453 L F
.36321 .64336 m .36589 .64075 L .36446 .64264 L F
.36096 .6453 m .36321 .64336 L .36446 .64264 L F
.459 .279 .549 r
.42008 .52048 m .41768 .52138 L .41965 .51808 L F
.408 .268 .577 r
.3244 .5169 m .3259 .51317 L .32478 .5139 L F
.854 .92 .874 r
.47395 .43759 m .47097 .44066 L .46946 .43967 L F
.324 0 0 r
.56726 .43782 m .56416 .43969 L .56762 .4388 L F
0 .219 .708 r
.43496 .54067 m .43777 .54311 L .43886 .54188 L F
.97 .742 .535 r
.27838 .54939 m .27543 .54722 L .27547 .5485 L F
.742 .755 .245 r
.3875 .61287 m .38795 .61186 L .38835 .61066 L F
.3875 .61287 m .38711 .61485 L .38795 .61186 L F
.192 0 .03 r
.42338 .51568 m .4224 .51739 L .41965 .51808 L F
.012 0 0 r
.4224 .51739 m .42562 .51721 L .42635 .51708 L F
.529 .117 .203 r
.42338 .51568 m .42562 .51721 L .4224 .51739 L F
.584 .029 0 r
.37051 .5503 m .37105 .55135 L .36879 .54984 L F
.37051 .5503 m .37351 .55293 L .37105 .55135 L F
.477 .293 .551 r
.40548 .49789 m .40266 .49911 L .40114 .49759 L F
.40548 .49789 m .40512 .50061 L .40266 .49911 L F
.40266 .49911 m .40512 .50061 L .40548 .49789 L F
0 .219 .708 r
.43496 .54067 m .43748 .54239 L .43777 .54311 L F
.955 .631 .367 r
.43687 .54647 m .43777 .54311 L .43748 .54239 L F
.43687 .54647 m .43883 .54718 L .43777 .54311 L F
.851 .58 .528 r
.43777 .54311 m .43883 .54718 L .44073 .54703 L F
.531 .101 .169 r
.29179 .57132 m .29612 .5692 L .29399 .56903 L F
.728 .977 .92 r
.46308 .4427 m .46098 .44539 L .45976 .4447 L F
.46308 .4427 m .46422 .44312 L .46098 .44539 L F
.798 .748 .806 r
.53548 .43277 m .53937 .4334 L .53821 .42947 L F
.869 .782 .763 r
.53821 .42947 m .53937 .4334 L .54002 .43095 L F
.602 .4 .579 r
.54039 .43648 m .54392 .43267 L .53937 .4334 L F
.979 .689 .322 r
.39487 .56269 m .39502 .56533 L .39628 .56631 L F
.873 .743 .231 r
.3957 .56801 m .39628 .56631 L .39502 .56533 L F
.3957 .56801 m .39596 .56912 L .39628 .56631 L F
.179 0 .184 r
.31841 .65335 m .32102 .65056 L .32107 .65307 L F
.63 .638 .839 r
.32214 .64637 m .32102 .65056 L .31942 .64717 L F
.32214 .64637 m .3234 .65019 L .32102 .65056 L F
.586 .37 .555 r
.32102 .65056 m .3234 .65019 L .32107 .65307 L F
0 0 0 r
.68068 .35523 m .67875 .35677 L .67793 .35826 L F
.283 .119 .474 r
.32352 .63888 m .32258 .63976 L .32175 .63798 L F
0 0 0 r
.55667 .42517 m .55787 .42341 L .55712 .42274 L F
.946 .664 .207 r
.55672 .41994 m .55787 .42341 L .56066 .42061 L F
.55672 .41994 m .55712 .42274 L .55787 .42341 L F
.506 .005 0 r
.30383 .54053 m .30192 .54208 L .2996 .54108 L F
.163 0 0 r
.30606 .53969 m .30203 .54201 L .30383 .54053 L F
.30606 .53969 m .30435 .54146 L .30192 .54208 L F
.516 .325 .56 r
.30438 .54104 m .30703 .53806 L .30461 .53841 L F
.30435 .54146 m .30482 .54086 L .30438 .54104 L F
.30482 .54086 m .30703 .53806 L .30438 .54104 L F
.163 0 0 r
.30203 .54201 m .30192 .54208 L .30196 .54204 L F
.30203 .54201 m .30196 .54204 L .30383 .54053 L F
.541 .54 .802 r
.30954 .64955 m .30801 .65317 L .30678 .65036 L F
.30954 .64955 m .31046 .65273 L .30801 .65317 L F
.888 .911 .836 r
.44464 .49179 m .44082 .49407 L .44244 .49342 L F
.845 .978 .678 r
.44479 .49025 m .44464 .49179 L .44244 .49342 L F
.701 .947 .958 r
.2946 .51242 m .29672 .51091 L .29709 .5083 L F
.2946 .51242 m .29293 .51009 L .29672 .51091 L F
.29672 .51091 m .29293 .51009 L .2946 .51242 L F
.39 .174 .461 r
.24346 .58896 m .24087 .59226 L .24503 .59066 L F
0 0 .352 r
.24087 .59226 m .242 .59388 L .24503 .59066 L F
.24087 .59226 m .24066 .59545 L .242 .59388 L F
.465 .057 .181 r
.41859 .4795 m .42222 .48136 L .42046 .47896 L F
.41859 .4795 m .41989 .48041 L .42222 .48136 L F
.41859 .4795 m .41808 .48108 L .41989 .48041 L F
.724 .781 .898 r
.31305 .65057 m .31395 .65351 L .31046 .65273 L F
.807 .685 .729 r
.31395 .65351 m .3122 .65759 L .31046 .65273 L F
.882 .859 .814 r
.31527 .65121 m .31395 .65351 L .31305 .65057 L F
.2 .34 .781 r
.54864 .41629 m .54601 .41453 L .54863 .41377 L F
.465 .228 .469 r
.51502 .48866 m .51488 .4912 L .5122 .49184 L F
.494 .25 .473 r
.5177 .48811 m .51488 .4912 L .51502 .48866 L F
.75 .6 .69 r
.35626 .62431 m .35821 .62553 L .35817 .62503 L F
.757 .333 .243 r
.35817 .62503 m .35931 .62457 L .35879 .62527 L F
.35626 .62431 m .35802 .62446 L .35817 .62503 L F
.35802 .62446 m .35931 .62457 L .35817 .62503 L F
.72 .282 .21 r
.35818 .62222 m .36211 .6245 L .35931 .62457 L F
0 0 .298 r
.35795 .62162 m .35817 .62503 L .35881 .62213 L F
.35817 .62503 m .35821 .62553 L .35825 .62531 L F
.789 .317 .112 r
.35786 .62649 m .35821 .62553 L .35626 .62431 L F
.757 .333 .243 r
.35626 .62431 m .35832 .62509 L .35786 .62649 L F
.759 .757 .244 r
.35825 .62531 m .35821 .62553 L .35786 .62649 L F
.757 .333 .243 r
.35832 .62509 m .35879 .62527 L .35786 .62649 L F
0 0 .298 r
.35817 .62503 m .35825 .62531 L .35881 .62213 L F
.759 .757 .244 r
.35881 .62213 m .35825 .62531 L .35786 .62649 L F
.75 .6 .69 r
.35626 .62431 m .35817 .62503 L .35795 .62162 L F
.346 0 0 r
.35931 .62457 m .36061 .62658 L .35786 .62649 L F
.35931 .62457 m .36211 .6245 L .36061 .62658 L F
.911 .96 .806 r
.734 .31969 m .73056 .32221 L .73073 .3195 L F
.734 .31969 m .7317 .32289 L .73056 .32221 L F
.203 0 0 r
.29154 .64388 m .29086 .64368 L .28755 .64306 L F
.735 .816 .915 r
.41869 .49503 m .41432 .49463 L .41686 .49353 L F
.757 .241 0 r
.36689 .63126 m .3639 .62898 L .36581 .62733 L F
.536 0 0 r
.36648 .6302 m .36648 .62998 L .36431 .62862 L F
.42 .289 .596 r
.36949 .63394 m .36648 .62998 L .36826 .63149 L F
.536 0 0 r
.36826 .63149 m .36648 .62998 L .36648 .6302 L F
.723 .442 0 r
.36648 .62998 m .36689 .63126 L .36648 .62978 L F
.36648 .62998 m .36648 .62978 L .36581 .62733 L F
.42 .289 .596 r
.36949 .63394 m .36755 .6341 L .36689 .63126 L F
.98 .763 .538 r
.23882 .61341 m .23991 .61831 L .23805 .61767 L F
.723 .193 0 r
.23991 .61831 m .23988 .61994 L .23805 .61767 L F
.23991 .61831 m .24207 .6206 L .23988 .61994 L F
.906 .572 .093 r
.5916 .41208 m .58946 .40679 L .59012 .41021 L F
.942 .585 .302 r
.59061 .4136 m .5916 .41208 L .59012 .41021 L F
.59061 .4136 m .59212 .41404 L .5916 .41208 L F
.747 .964 .679 r
.43148 .59392 m .42875 .59711 L .43071 .59571 L F
.662 .973 .847 r
.31805 .62698 m .32245 .62468 L .32057 .62605 L F
.704 .911 .562 r
.3091 .64379 m .31204 .63994 L .30979 .64227 L F
.708 .537 .655 r
.3091 .64379 m .31146 .64502 L .31204 .63994 L F
.338 .173 .505 r
.31146 .64502 m .31458 .64 L .31204 .63994 L F
.31146 .64502 m .31435 .64297 L .31458 .64 L F
.02 0 .383 r
.31458 .64 m .31435 .64297 L .3156 .64176 L F
.404 .031 .215 r
.31204 .63994 m .31548 .6417 L .30979 .64227 L F
.31204 .63994 m .31458 .64 L .31548 .6417 L F
.502 .311 .553 r
.44236 .498 m .44228 .5007 L .43993 .49923 L F
.751 .991 .791 r
.6214 .3456 m .62275 .3432 L .62497 .34353 L F
.6214 .3456 m .62105 .34506 L .62275 .3432 L F
0 0 .292 r
.36589 .64075 m .36752 .63689 L .36592 .63863 L F
.877 .91 .504 r
.36446 .64264 m .36589 .64075 L .36592 .63863 L F
.627 .605 .809 r
.7317 .32289 m .72768 .32047 L .73056 .32221 L F
.651 .165 .083 r
.43883 .54718 m .44001 .54844 L .44073 .54703 L F
.796 .311 .059 r
.43687 .54647 m .43752 .54778 L .44001 .54844 L F
.273 .743 .942 r
.43752 .54778 m .43934 .548 L .44001 .54844 L F
.389 .7 .983 r
.44001 .54844 m .44093 .54903 L .44073 .54703 L F
.273 .743 .942 r
.43934 .548 m .44142 .54827 L .44001 .54844 L F
.389 .7 .983 r
.44001 .54844 m .44102 .54986 L .44093 .54903 L F
0 0 .015 r
.31927 .64413 m .32258 .63976 L .32243 .64349 L F
.571 .426 .645 r
.32243 .64349 m .31942 .64717 L .31927 .64413 L F
.899 .64 .538 r
.32671 .49607 m .32903 .49852 L .32644 .4978 L F
.898 .626 .519 r
.32644 .4978 m .32903 .49852 L .32864 .50105 L F
.727 .469 .537 r
.36346 .5559 m .367 .55645 L .36748 .55348 L F
0 0 .143 r
.36748 .55348 m .36826 .55461 L .36988 .5533 L F
.36748 .55348 m .367 .55645 L .36826 .55461 L F
.483 .266 .508 r
.44739 .47255 m .44729 .47511 L .44463 .47572 L F
.245 .041 .392 r
.44535 .47784 m .44729 .47511 L .44463 .47572 L F
.021 .081 .586 r
.44632 .47661 m .44463 .47572 L .44729 .47511 L F
.44632 .47661 m .44535 .47784 L .44463 .47572 L F
.483 .266 .508 r
.44739 .47255 m .44729 .47511 L .44463 .47572 L F
.794 .844 .89 r
.68311 .33533 m .68473 .3374 L .68638 .33589 L F
.68638 .33589 m .68473 .3374 L .68311 .33533 L F
.895 .766 .711 r
.53753 .46037 m .5388 .45937 L .53712 .45533 L F
.918 .94 .803 r
.53624 .46179 m .5388 .45937 L .53753 .46037 L F
.798 .603 .638 r
.53624 .46179 m .53981 .46275 L .5388 .45937 L F
.697 .684 .834 r
.53712 .45533 m .5388 .45937 L .54036 .45636 L F
.905 .524 .293 r
.37511 .5211 m .37598 .52333 L .37812 .52421 L F
.826 .443 .327 r
.37604 .52591 m .37812 .52421 L .37598 .52333 L F
.37604 .52591 m .3794 .52729 L .37812 .52421 L F
.627 .064 0 r
.35872 .50651 m .35972 .50645 L .35813 .50556 L F
.35872 .50651 m .36073 .50728 L .35972 .50645 L F
0 .235 .753 r
.54674 .4309 m .54887 .43255 L .54875 .43022 L F
.727 .81 .916 r
.43652 .45353 m .43262 .45327 L .43499 .45192 L F
.597 .814 .983 r
.43751 .45127 m .43652 .45353 L .43499 .45192 L F
.43751 .45127 m .43906 .45269 L .43652 .45353 L F
.425 .209 .48 r
.72768 .32047 m .7303 .31717 L .73073 .3195 L F
.467 .311 .586 r
.73073 .3195 m .73056 .32221 L .72768 .32047 L F
.769 .86 .917 r
.48575 .43106 m .48257 .43347 L .48095 .43198 L F
.963 .678 .445 r
.4511 .57201 m .45293 .57351 L .45178 .57482 L F
.765 .827 .9 r
.45495 .5724 m .45293 .57351 L .4511 .57201 L F
.773 .928 .936 r
.59578 .36561 m .59232 .36793 L .59135 .36653 L F
.391 .234 .546 r
.4224 .51739 m .42008 .52048 L .41965 .51808 L F
.485 .127 .282 r
.28399 .54649 m .28066 .54853 L .28192 .54753 L F
.975 .696 .436 r
.38488 .53621 m .38667 .54061 L .38626 .5376 L F
.567 .403 .618 r
.37611 .60867 m .37891 .60814 L .3782 .60535 L F
.507 .343 .593 r
.3763 .61146 m .37891 .60814 L .37611 .60867 L F
0 0 0 r
.23126 .55529 m .2293 .55676 L .23246 .5538 L F
.493 .303 .551 r
.23197 .55878 m .2293 .55676 L .23126 .55529 L F
.23197 .55878 m .22944 .55939 L .2293 .55676 L F
.161 0 0 r
.34038 .49623 m .33763 .49565 L .33604 .4954 L F
.751 .781 .877 r
.36392 .69573 m .36846 .69618 L .36662 .69505 L F
.658 .927 .973 r
.36846 .69618 m .36918 .69423 L .36662 .69505 L F
0 0 0 r
.32286 .60895 m .32177 .61112 L .32355 .60761 L F
.945 .655 .459 r
.43804 .56223 m .43532 .55797 L .4384 .56023 L F
0 0 .259 r
.43919 .55982 m .43952 .56102 L .43942 .56098 L F
0 .094 .567 r
.43942 .56098 m .44123 .56255 L .43919 .56088 L F
.925 .565 .135 r
.44023 .56358 m .44123 .56255 L .43942 .56098 L F
0 0 .259 r
.43952 .56102 m .44023 .56358 L .43942 .56098 L F
0 .094 .567 r
.43942 .56098 m .43919 .56088 L .4384 .56023 L F
.817 .546 .529 r
.35446 .68858 m .35857 .68611 L .35649 .68724 L F
.35446 .68858 m .35858 .68833 L .35857 .68611 L F
.037 .353 .828 r
.35845 .68424 m .35857 .68611 L .35653 .68275 L F
.229 .415 .838 r
.3577 .68223 m .35974 .68525 L .35872 .68445 L F
.3577 .68223 m .35872 .68445 L .35653 .68275 L F
.3577 .68223 m .35539 .68107 L .35744 .68068 L F
.3577 .68223 m .35744 .68068 L .35718 .6811 L F
.559 .707 .939 r
.35653 .68275 m .35471 .68362 L .35305 .68173 L F
.35653 .68275 m .35305 .68173 L .35539 .68107 L F
.229 .415 .838 r
.3577 .68223 m .35653 .68275 L .35539 .68107 L F
.3577 .68223 m .35718 .6811 L .35533 .68406 L F
.693 .628 .779 r
.35649 .68724 m .35756 .68281 L .35533 .68406 L F
.35756 .68281 m .3577 .68223 L .35736 .68249 L F
.35756 .68281 m .35736 .68249 L .35533 .68406 L F
.037 .353 .828 r
.35974 .68525 m .35928 .68558 L .35845 .68424 L F
.35928 .68558 m .35857 .68611 L .35845 .68424 L F
.414 .83 .65 r
.35649 .68724 m .35857 .68611 L .35974 .68525 L F
.663 .286 .321 r
.36169 .68746 m .35857 .68611 L .35858 .68833 L F
0 0 .358 r
.55248 .43543 m .55179 .44036 L .54942 .43769 L F
.945 .655 .459 r
.43804 .56223 m .43545 .56258 L .43532 .55797 L F
.821 .513 .468 r
.43804 .56223 m .43407 .56474 L .43545 .56258 L F
.43804 .56223 m .43741 .56562 L .43407 .56474 L F
.852 .975 .868 r
.36123 .63023 m .3639 .62898 L .36243 .63048 L F
.895 .475 .159 r
.36123 .63023 m .36243 .63048 L .36112 .63145 L F
.919 .88 .457 r
.36243 .63048 m .36132 .63422 L .36112 .63145 L F
.638 .207 .206 r
.26332 .62662 m .26476 .6248 L .26034 .6249 L F
.205 0 .01 r
.26606 .6261 m .26476 .6248 L .26332 .62662 L F
.26606 .6261 m .26749 .62402 L .26476 .6248 L F
.584 .835 .992 r
.36043 .62071 m .35818 .62222 L .35795 .62162 L F
.627 .071 0 r
.38613 .5107 m .38199 .50767 L .38396 .50878 L F
.569 .01 0 r
.38792 .51168 m .38613 .5107 L .38396 .50878 L F
.106 0 .369 r
.48533 .54015 m .48502 .54275 L .48364 .54353 L F
.401 .288 .608 r
.48684 .53306 m .48739 .53627 L .48417 .53742 L F
.167 .225 .679 r
.48697 .53847 m .48417 .53742 L .48739 .53627 L F
.48697 .53847 m .48533 .54015 L .48417 .53742 L F
.679 .908 .975 r
.42168 .45544 m .42073 .45748 L .41931 .45649 L F
.42168 .45544 m .42328 .45628 L .42073 .45748 L F
.617 .693 .898 r
.68549 .34814 m .68815 .35008 L .68318 .34872 L F
.742 .521 .594 r
.68318 .34872 m .68815 .35008 L .68711 .35233 L F
.739 .697 .811 r
.68908 .34782 m .68815 .35008 L .68549 .34814 L F
.907 .937 .57 r
.4289 .50615 m .43053 .50465 L .42834 .50318 L F
.4289 .50615 m .42878 .50765 L .43053 .50465 L F
.524 .24 .425 r
.31349 .5696 m .31315 .57197 L .31046 .57196 L F
.626 .33 .448 r
.31349 .5696 m .31589 .57191 L .31315 .57197 L F
.544 .338 .552 r
.31598 .56913 m .31589 .57191 L .31349 .5696 L F
.595 .922 .695 r
.43837 .5863 m .43504 .589 L .43659 .5872 L F
.245 0 0 r
.43659 .5872 m .44149 .58686 L .43837 .5863 L F
.574 .575 .816 r
.29741 .66683 m .29991 .66609 L .29857 .66227 L F
.23 .087 .471 r
.57645 .42702 m .57803 .42884 L .57783 .42654 L F
.57645 .42702 m .57599 .43025 L .57803 .42884 L F
0 0 0 r
.63359 .40673 m .63187 .40764 L .63398 .40623 L F
.988 .726 .426 r
.6995 .30305 m .70247 .30123 L .70182 .30172 L F
.748 .943 .615 r
.70443 .29794 m .70182 .30172 L .70247 .30123 L F
.676 .63 .796 r
.30412 .64859 m .3072 .64781 L .30282 .64607 L F
.551 .295 .482 r
.35887 .59536 m .36079 .59534 L .36288 .59197 L F
.184 0 .226 r
.36288 .59197 m .36382 .59379 L .36439 .59105 L F
.36288 .59197 m .36079 .59534 L .36382 .59379 L F
.602 .4 .579 r
.54039 .43648 m .54539 .4372 L .54392 .43267 L F
0 0 .324 r
.54392 .43267 m .54515 .43649 L .54481 .43445 L F
.682 .818 .949 r
.54446 .43239 m .54481 .43445 L .54342 .43296 L F
.54668 .43119 m .54481 .43445 L .54446 .43239 L F
0 0 .324 r
.54515 .43649 m .54539 .4372 L .54481 .43445 L F
.235 .092 .473 r
.40604 .4757 m .40488 .47644 L .40712 .47542 L F
.838 .545 .492 r
.56104 .40456 m .55704 .40652 L .5562 .40484 L F
.56104 .40456 m .56105 .40705 L .55704 .40652 L F
.452 0 0 r
.43201 .54903 m .43199 .54925 L .42989 .54793 L F
.43398 .55007 m .43199 .54925 L .43201 .54903 L F
.825 .38 0 r
.43199 .54925 m .4329 .55119 L .43179 .55045 L F
.43199 .54925 m .43179 .55045 L .43197 .54963 L F
.43199 .54925 m .43197 .54963 L .43254 .54696 L F
0 .279 .781 r
.42989 .54793 m .43199 .54925 L .43198 .54807 L F
.697 .78 .916 r
.27918 .62829 m .28264 .62783 L .27993 .62801 L F
.71 .449 .527 r
.27826 .63032 m .28264 .62783 L .27918 .62829 L F
.27826 .63032 m .28257 .63051 L .28264 .62783 L F
.891 .737 .23 r
.28264 .62783 m .28237 .62285 L .27993 .62801 L F
.031 .187 .693 r
.37845 .60426 m .3782 .60535 L .37944 .6042 L F
.546 .598 .857 r
.37891 .60814 m .37944 .6042 L .3782 .60535 L F
.187 0 0 r
.32958 .512 m .32964 .51266 L .32959 .51032 L F
.896 .928 .545 r
.23486 .56618 m .23447 .56572 L .23467 .56401 L F
.916 .603 .437 r
.60148 .44542 m .60213 .44374 L .59838 .44179 L F
.653 .106 0 r
.37992 .50555 m .37907 .50573 L .37824 .5043 L F
.37992 .50555 m .38199 .50767 L .37907 .50573 L F
.261 0 .223 r
.56046 .47164 m .56102 .46903 L .56351 .46797 L F
.198 .18 .612 r
.33597 .53895 m .33679 .54296 L .33531 .54112 L F
.532 .25 .433 r
.33531 .54112 m .33679 .54296 L .33416 .54299 L F
.979 .911 .656 r
.39622 .59233 m .39402 .59392 L .39513 .59463 L F
.982 .873 .507 r
.39617 .58734 m .39545 .59162 L .39622 .59233 L F
.944 .961 .69 r
.39545 .59162 m .39402 .59392 L .39622 .59233 L F
.829 .773 .8 r
.33571 .6468 m .33699 .65003 L .33938 .64713 L F
0 0 0 r
.69827 .36111 m .69929 .35937 L .69861 .36079 L F
.69929 .35937 m .70044 .35456 L .69981 .35682 L F
.769 .799 .311 r
.69861 .36079 m .69929 .35937 L .69981 .35682 L F
.512 0 0 r
.34682 .68136 m .35058 .68224 L .34823 .68126 L F
.24 0 .236 r
.32154 .57093 m .32008 .56951 L .32226 .56862 L F
0 0 0 r
.32514 .56594 m .32226 .56862 L .32268 .56633 L F
.32514 .56594 m .32409 .56763 L .32226 .56862 L F
.377 .164 .459 r
.32409 .56763 m .32154 .57093 L .32226 .56862 L F
.374 .151 .442 r
.36162 .60508 m .36124 .60785 L .35899 .60831 L F
.678 .3 .323 r
.36191 .6106 m .35987 .609 L .36164 .60948 L F
.35946 .60868 m .35739 .61087 L .35899 .60831 L F
.36191 .6106 m .35828 .61082 L .35946 .60868 L F
.35828 .61082 m .35739 .61087 L .35946 .60868 L F
.737 .452 .498 r
.35951 .60939 m .35739 .61087 L .36191 .6106 L F
.64 .301 .382 r
.35729 .61263 m .35951 .60939 L .35929 .61205 L F
.357 .61271 m .35791 .6115 L .35729 .61263 L F
.35791 .6115 m .35951 .60939 L .35729 .61263 L F
.442 0 0 r
.36252 .60953 m .36171 .60949 L .36191 .6106 L F
.36171 .60949 m .35951 .60939 L .36191 .6106 L F
0 0 0 r
.3614 .60781 m .36191 .6106 L .36124 .60785 L F
.36251 .6096 m .36191 .6106 L .36171 .60949 L F
.442 0 0 r
.36171 .60949 m .36248 .60971 L .36167 .60949 L F
.36252 .60953 m .3625 .60959 L .36171 .60949 L F
.3625 .60959 m .36248 .60971 L .36171 .60949 L F
.436 .3 .598 r
.36684 .60901 m .36252 .60953 L .36394 .6072 L F
0 0 0 r
.36394 .6072 m .36252 .60953 L .36191 .6106 L F
.36394 .6072 m .36251 .6096 L .3614 .60781 L F
.36251 .6096 m .36171 .60949 L .3614 .60781 L F
.442 0 0 r
.36167 .60949 m .36211 .61132 L .35951 .60939 L F
.36248 .60971 m .36211 .61132 L .36167 .60949 L F
.678 .3 .323 r
.36164 .60948 m .35899 .60831 L .36124 .60785 L F
.35987 .609 m .35899 .60831 L .36164 .60948 L F
.998 .779 .45 r
.39657 .58511 m .39687 .5825 L .39545 .58415 L F
.986 .862 .496 r
.39545 .58415 m .39687 .5825 L .39613 .5815 L F
0 .391 .7 r
.30747 .66521 m .30909 .66568 L .30805 .66561 L F
.456 .842 .623 r
.55168 .39962 m .54968 .40108 L .54788 .40222 L F
0 0 0 r
.68501 .29474 m .68607 .29419 L .68642 .29227 L F
.68501 .29474 m .68447 .29581 L .68607 .29419 L F
.26 0 0 r
.33204 .49488 m .33338 .49491 L .33153 .49442 L F
.824 .694 .721 r
.32654 .55553 m .33085 .55681 L .32958 .55283 L F
.873 .535 .407 r
.32654 .55553 m .33029 .55924 L .33085 .55681 L F
.032 .187 .693 r
.32958 .55283 m .33085 .55681 L .3319 .55526 L F
.71 .487 .584 r
.33313 .55578 m .33029 .55924 L .33085 .55681 L F
0 0 0 r
.33085 .55681 m .33123 .55746 L .3319 .55526 L F
.33085 .55681 m .33042 .55869 L .33123 .55746 L F
.179 0 0 r
.32917 .55811 m .33162 .55686 L .33123 .55746 L F
.025 0 .088 r
.33381 .55438 m .33123 .55746 L .33284 .55624 L F
.179 0 0 r
.33162 .55686 m .33284 .55624 L .33123 .55746 L F
0 0 0 r
.33042 .55869 m .33029 .55924 L .33123 .55746 L F
.762 .895 .937 r
.49416 .42654 m .49066 .42676 L .49243 .42519 L F
.761 .86 .923 r
.4964 .42218 m .49416 .42654 L .49243 .42519 L F
.4964 .42218 m .49844 .42368 L .49416 .42654 L F
.574 .853 .519 r
.68974 .31271 m .68627 .31668 L .68947 .31386 L F
.684 .946 .959 r
.69067 .31172 m .68974 .31271 L .68947 .31386 L F
.574 .853 .519 r
.68756 .3152 m .68639 .31644 L .68627 .31668 L F
.68846 .31416 m .68639 .31644 L .68756 .3152 L F
.68901 .31352 m .68851 .31408 L .68846 .31416 L F
.68851 .31408 m .68639 .31644 L .68846 .31416 L F
.767 .739 .827 r
.68904 .31498 m .68548 .31867 L .68639 .31644 L F
.896 .639 .127 r
.68947 .31386 m .68961 .31616 L .68902 .31462 L F
.837 .786 .803 r
.68411 .31437 m .68639 .31644 L .68974 .31271 L F
.94 .818 .367 r
.68961 .31616 m .68923 .31488 L .68872 .31372 L F
.767 .739 .827 r
.68923 .31488 m .68905 .31507 L .68904 .31498 L F
.68905 .31507 m .68548 .31867 L .68904 .31498 L F
.896 .639 .127 r
.68898 .31391 m .68902 .31462 L .68875 .31393 L F
.68947 .31386 m .68902 .31462 L .68898 .31391 L F
.68871 .31377 m .68875 .31393 L .68869 .31377 L F
.68947 .31386 m .68875 .31393 L .68871 .31377 L F
.767 .739 .827 r
.68905 .31507 m .68923 .31911 L .68548 .31867 L F
.68923 .31488 m .68923 .31579 L .68905 .31507 L F
.68923 .31579 m .68923 .31911 L .68905 .31507 L F
.837 .786 .803 r
.68411 .31437 m .68974 .31271 L .68701 .31286 L F
.896 .639 .127 r
.68902 .3135 m .68869 .31377 L .6884 .313 L F
.94 .818 .367 r
.68869 .31377 m .68872 .31372 L .6884 .313 L F
.68961 .31616 m .68872 .31372 L .68869 .31377 L F
.896 .639 .127 r
.68947 .31386 m .68869 .31377 L .68902 .3135 L F
.574 .853 .519 r
.68909 .31345 m .68901 .31352 L .68756 .3152 L F
.68974 .31271 m .68903 .3135 L .68909 .31345 L F
.68903 .3135 m .68901 .31352 L .68909 .31345 L F
.896 .639 .127 r
.68947 .31386 m .68902 .3135 L .69067 .31172 L F
.238 .717 .935 r
.6884 .313 m .68974 .31271 L .69067 .31172 L F
.6884 .313 m .68701 .31286 L .68974 .31271 L F
.896 .639 .127 r
.68902 .3135 m .6884 .313 L .69045 .31185 L F
.68902 .3135 m .69045 .31185 L .69067 .31172 L F
.863 .499 .359 r
.29145 .64887 m .29485 .65032 L .29332 .64724 L F
.721 .272 .183 r
.33982 .65314 m .33699 .65003 L .33762 .65286 L F
.853 .877 .856 r
.66145 .331 m .66527 .32933 L .66451 .32901 L F
.619 .959 .88 r
.66686 .32746 m .66527 .32933 L .66814 .32661 L F
.66686 .32746 m .66451 .32901 L .66527 .32933 L F
.354 0 0 r
.34192 .6528 m .34116 .65164 L .33982 .65314 L F
.34192 .6528 m .34482 .65167 L .34116 .65164 L F
.379 .018 .221 r
.42678 .54195 m .42445 .54081 L .42855 .53999 L F
.933 .602 .387 r
.42855 .53999 m .42934 .5436 L .42678 .54195 L F
.573 .83 .994 r
.23783 .54684 m .23333 .54635 L .23568 .5456 L F
.567 .828 .994 r
.23842 .5452 m .23783 .54684 L .23568 .5456 L F
0 .061 .603 r
.23842 .5452 m .23946 .54876 L .23783 .54684 L F
.525 .361 .602 r
.49582 .51098 m .49632 .51403 L .49337 .51455 L F
.38 .135 .412 r
.49632 .51403 m .49348 .51681 L .49337 .51455 L F
.943 .58 .258 r
.38667 .54061 m .387 .54261 L .38869 .54368 L F
.86 .41 .045 r
.387 .54261 m .38995 .54603 L .38869 .54368 L F
.701 .4 .463 r
.23519 .55359 m .23126 .55529 L .23246 .5538 L F
.924 .583 .131 r
.29021 .6512 m .28762 .65211 L .28778 .65102 L F
.28762 .65211 m .28718 .65226 L .28729 .65202 L F
.29021 .6512 m .2891 .64999 L .28718 .65226 L F
.29021 .6512 m .29128 .65506 L .28935 .65056 L F
.28921 .65011 m .28935 .65056 L .2891 .64999 L F
.29021 .6512 m .28935 .65056 L .28921 .65011 L F
.64 .611 .805 r
.29031 .65281 m .29128 .65506 L .29251 .65338 L F
.29031 .65281 m .29251 .65338 L .29298 .65274 L F
.608 .664 .879 r
.29449 .65622 m .29212 .65712 L .29128 .65506 L F
.29449 .65622 m .29128 .65506 L .29298 .65274 L F
.775 .818 .886 r
.29298 .65274 m .29128 .65506 L .28861 .65347 L F
.29298 .65274 m .29013 .65322 L .29232 .65622 L F
.347 .701 .984 r
.28861 .65347 m .29128 .65506 L .28792 .65452 L F
.775 .818 .886 r
.29013 .65322 m .28861 .65347 L .29065 .65498 L F
.29013 .65322 m .29065 .65498 L .29232 .65622 L F
.64 .611 .805 r
.2891 .64999 m .29031 .65281 L .29298 .65274 L F
.924 .583 .131 r
.28762 .65211 m .28729 .65202 L .28778 .65102 L F
0 .129 .676 r
.72526 .32339 m .72766 .32609 L .72715 .3241 L F
.72526 .32339 m .72715 .3241 L .72522 .3238 L F
.005 .55 .833 r
.72522 .3238 m .72715 .3241 L .72635 .32387 L F
.095 0 0 r
.72526 .32339 m .72522 .3238 L .7235 .32369 L F
.005 .55 .833 r
.72522 .3238 m .72635 .32387 L .72321 .32296 L F
.095 0 0 r
.7235 .32369 m .72522 .3238 L .72118 .32409 L F
.545 .412 .65 r
.34241 .68658 m .34506 .68604 L .34448 .68219 L F
.539 .435 .684 r
.34286 .68934 m .34506 .68604 L .34241 .68658 L F
.831 .736 .76 r
.69505 .34003 m .69073 .34158 L .69365 .33848 L F
.69505 .34003 m .69292 .3435 L .69073 .34158 L F
.882 .843 .802 r
.35297 .55012 m .35075 .55364 L .3487 .55229 L F
.897 .929 .831 r
.62125 .37166 m .61872 .37608 L .61859 .3733 L F
.967 .936 .646 r
.61859 .3733 m .61872 .37608 L .61711 .37668 L F
.857 .76 .754 r
.42475 .48156 m .42687 .48331 L .42673 .4812 L F
.42673 .4812 m .42687 .48331 L .42475 .48156 L F
.771 .709 .794 r
.27439 .62752 m .27918 .62829 L .27671 .62371 L F
.791 .501 .496 r
.27826 .63032 m .27918 .62829 L .27439 .62752 L F
.686 .675 .834 r
.27671 .62371 m .27918 .62829 L .27993 .62801 L F
.478 .407 .698 r
.36523 .55959 m .367 .55645 L .36346 .5559 L F
.36523 .55959 m .36761 .55907 L .367 .55645 L F
0 .054 .612 r
.36523 .55959 m .36658 .56031 L .36761 .55907 L F
.135 0 0 r
.61239 .38389 m .61561 .38316 L .61292 .38397 L F
0 0 .157 r
.22928 .5403 m .2306 .53898 L .2311 .53626 L F
0 0 0 r
.22928 .5403 m .2281 .54242 L .2306 .53898 L F
.945 .671 .488 r
.38187 .53007 m .38189 .53267 L .38403 .5334 L F
.904 .506 .238 r
.38189 .53267 m .38488 .53621 L .38403 .5334 L F
.884 .522 .355 r
.59344 .4231 m .59384 .4255 L .59528 .42397 L F
.642 .185 .152 r
.59384 .4255 m .59789 .42588 L .59528 .42397 L F
0 0 .267 r
.43504 .589 m .43634 .58993 L .43659 .5872 L F
.43504 .589 m .43491 .59168 L .43634 .58993 L F
.596 .866 .993 r
.37246 .61713 m .37166 .61839 L .36928 .61735 L F
0 0 0 r
.36943 .62227 m .37166 .61839 L .37246 .61713 L F
.796 .309 0 r
.46351 .53821 m .46565 .54034 L .46364 .53863 L F
.37 .297 .644 r
.46565 .54034 m .46696 .53631 L .46364 .53863 L F
.46565 .54034 m .46794 .53992 L .46696 .53631 L F
.389 .397 .747 r
.46565 .54034 m .46828 .5426 L .46794 .53992 L F
.675 .125 0 r
.58862 .38766 m .59074 .38833 L .58993 .38892 L F
.842 .382 0 r
.59074 .38833 m .59176 .39013 L .58993 .38892 L F
0 0 0 r
.6626 .3763 m .65854 .3778 L .66069 .37619 L F
.656 .967 .909 r
.66486 .37475 m .6626 .3763 L .66069 .37619 L F
.341 0 0 r
.25413 .51693 m .25675 .51718 L .25852 .5167 L F
0 0 0 r
.25675 .51718 m .26141 .51638 L .25852 .5167 L F
.726 .637 .758 r
.32622 .53447 m .32952 .5346 L .32711 .52955 L F
.645 .237 .257 r
.32622 .53447 m .32812 .53623 L .32952 .5346 L F
.49 .519 .814 r
.32711 .52955 m .32952 .5346 L .33145 .53319 L F
.066 0 .003 r
.32812 .53623 m .33145 .53319 L .32952 .5346 L F
.927 .853 .749 r
.3267 .63349 m .33022 .63104 L .32799 .62958 L F
.146 0 .131 r
.33022 .63104 m .33356 .62813 L .33181 .63085 L F
.248 .327 .749 r
.33022 .63104 m .3329 .63329 L .33181 .63085 L F
.146 0 .131 r
.33022 .63104 m .33356 .62813 L .33181 .63085 L F
.248 .327 .749 r
.33022 .63104 m .3329 .63329 L .33181 .63085 L F
0 0 0 r
.33325 .63661 m .33442 .63419 L .33163 .63752 L F
.362 .82 .929 r
.33325 .63661 m .33163 .63752 L .32974 .63739 L F
.052 0 .027 r
.69797 .32869 m .69594 .32991 L .69521 .33119 L F
.69797 .32869 m .69521 .33119 L .69772 .33045 L F
.776 .661 .107 r
.69774 .33002 m .69797 .32869 L .69772 .33045 L F
.756 .995 .835 r
.69806 .32814 m .69594 .32991 L .69797 .32869 L F
.776 .661 .107 r
.69788 .32759 m .69797 .32869 L .69774 .33002 L F
.756 .995 .835 r
.6992 .32719 m .69806 .32814 L .69797 .32869 L F
.771 .666 .748 r
.35866 .5627 m .35982 .56616 L .35603 .56578 L F
.778 .616 .68 r
.35982 .56616 m .35705 .56988 L .35603 .56578 L F
.557 .545 .797 r
.3626 .56495 m .35982 .56616 L .35866 .5627 L F
.412 0 .1 r
.31841 .65335 m .31925 .65535 L .31666 .65588 L F
.31841 .65335 m .32107 .65307 L .31925 .65535 L F
.689 .746 .895 r
.35459 .64015 m .35403 .64192 L .35174 .63989 L F
.498 .26 .484 r
.5122 .49184 m .51209 .49422 L .50938 .49477 L F
.505 .284 .513 r
.51488 .4912 m .51209 .49422 L .5122 .49184 L F
.33 .124 .442 r
.32691 .61768 m .32684 .62092 L .3246 .62185 L F
.465 .229 .47 r
.32948 .61994 m .32691 .61768 L .33059 .6173 L F
.32948 .61994 m .32684 .62092 L .32691 .61768 L F
.076 .213 .704 r
.44983 .568 m .44995 .56811 L .45259 .56804 L F
.765 .827 .9 r
.45495 .5724 m .45031 .56957 L .45293 .56803 L F
.076 .213 .704 r
.44995 .56811 m .45224 .57034 L .45259 .56804 L F
.44995 .56811 m .45259 .56804 L .45259 .56804 L F
.765 .827 .9 r
.45305 .56803 m .45293 .56803 L .45302 .56798 L F
.45495 .5724 m .45293 .56803 L .45305 .56803 L F
.45495 .5724 m .4511 .57201 L .45031 .56957 L F
.739 .778 .884 r
.45785 .56958 m .45495 .5724 L .45302 .56798 L F
.919 .712 .606 r
.59688 .43827 m .60128 .43965 L .59994 .43588 L F
.917 .726 .629 r
.59838 .44179 m .60128 .43965 L .59688 .43827 L F
.994 .752 .435 r
.39351 .56148 m .39491 .55995 L .39373 .55877 L F
.39351 .56148 m .39487 .56269 L .39491 .55995 L F
.474 .292 .553 r
.34504 .60789 m .34504 .61082 L .34216 .61135 L F
.2 .234 .673 r
.2352 .54206 m .23568 .5456 L .23362 .54366 L F
.467 .252 .503 r
.23568 .5456 m .23333 .54635 L .23362 .54366 L F
.51 .179 .341 r
.45682 .48485 m .45924 .48415 L .45947 .48221 L F
.506 .789 .996 r
.46142 .47877 m .45783 .4784 L .45947 .48221 L F
.599 .255 .357 r
.45924 .48415 m .46206 .48432 L .45947 .48221 L F
.612 .555 .766 r
.45947 .48221 m .46234 .48186 L .46142 .47877 L F
.549 .276 .454 r
.45947 .48221 m .46206 .48432 L .46234 .48186 L F
0 0 .275 r
.52635 .44399 m .5252 .44333 L .52338 .44247 L F
.683 .172 .019 r
.52797 .44555 m .5252 .44333 L .52519 .44594 L F
0 0 .275 r
.52635 .44399 m .52519 .44594 L .5252 .44333 L F
.698 .983 .857 r
.36581 .62733 m .3639 .62898 L .36123 .63023 L F
.104 .276 .755 r
.24193 .58509 m .24346 .58896 L .24423 .58701 L F
.599 .57 .793 r
.24503 .59066 m .24423 .58701 L .24346 .58896 L F
.884 .875 .437 r
.70029 .32316 m .6992 .32719 L .69939 .32449 L F
.919 .965 .657 r
.69939 .32449 m .6992 .32719 L .69797 .32869 L F
.599 .07 0 r
.38917 .51342 m .38613 .5107 L .38792 .51168 L F
.317 0 0 r
.37087 .60166 m .36909 .60347 L .36881 .60228 L F
0 0 0 r
.37364 .59948 m .37203 .60093 L .37087 .60166 L F
0 .126 .614 r
.34302 .50487 m .34419 .50552 L .34151 .50317 L F
.34302 .50487 m .34631 .50748 L .34419 .50552 L F
.917 .956 .624 r
.32671 .61001 m .32681 .61212 L .32866 .60819 L F
.786 .373 .267 r
.32866 .60819 m .33017 .61059 L .32671 .61001 L F
0 .458 .774 r
.3428 .51012 m .34591 .51124 L .34449 .51129 L F
.3428 .51012 m .34489 .51068 L .34591 .51124 L F
0 .264 .76 r
.34449 .51129 m .34489 .51068 L .3428 .51012 L F
.34449 .51129 m .34603 .51208 L .34489 .51068 L F
.525 .815 .999 r
.3428 .51012 m .34449 .51129 L .34035 .51075 L F
.945 .792 .661 r
.6729 .3447 m .67086 .34448 L .66852 .34344 L F
.377 .162 .455 r
.67156 .34197 m .66852 .34344 L .67086 .34448 L F
.839 .38 0 r
.43222 .53711 m .43316 .53966 L .43496 .54067 L F
0 0 .37 r
.43245 .53588 m .43316 .53966 L .43222 .53711 L F
.531 .473 .736 r
.4711 .52722 m .46783 .5238 L .46943 .52736 L F
.188 .188 .626 r
.46943 .52736 m .47156 .52951 L .4711 .52722 L F
.26 .197 .594 r
.4699 .52995 m .47156 .52951 L .46943 .52736 L F
0 0 0 r
.65899 .32151 m .65683 .32262 L .65655 .32282 L F
.65899 .32151 m .66024 .32085 L .65683 .32262 L F
.42635 .51708 m .42773 .51583 L .429 .5145 L F
.5 .896 .754 r
.42635 .51708 m .42562 .51721 L .42773 .51583 L F
.267 .036 .366 r
.42773 .51583 m .42562 .51721 L .42599 .51477 L F
.989 .724 .408 r
.42635 .51502 m .42696 .51663 L .42773 .51583 L F
.42696 .51663 m .42771 .51858 L .42773 .51583 L F
0 0 0 r
.429 .5145 m .42773 .51583 L .42962 .5139 L F
.66655 .38402 m .67033 .38201 L .66878 .38246 L F
.604 .94 .946 r
.67208 .38011 m .67033 .38201 L .67265 .38073 L F
.606 .945 .777 r
.66878 .38246 m .67033 .38201 L .67208 .38011 L F
.661 .869 .978 r
.73287 .32912 m .73473 .33038 L .73603 .32931 L F
.358 .065 .324 r
.55382 .40444 m .55347 .40689 L .55076 .4077 L F
.522 .201 .364 r
.55382 .40444 m .55704 .40652 L .55347 .40689 L F
.578 .124 .138 r
.55382 .40444 m .5562 .40484 L .55704 .40652 L F
.374 0 0 r
.25325 .61916 m .25337 .61713 L .25078 .62021 L F
.25325 .61916 m .25554 .61733 L .25337 .61713 L F
.971 .669 .281 r
.43398 .55007 m .4329 .55119 L .43199 .54925 L F
.43398 .55007 m .43449 .55299 L .4329 .55119 L F
.532 .51 .777 r
.22831 .57178 m .22723 .57648 L .22653 .5724 L F
.22831 .57178 m .22961 .57627 L .22723 .57648 L F
.495 .38 .651 r
.49342 .52005 m .49068 .51752 L .49348 .51681 L F
.49342 .52005 m .49086 .52103 L .49068 .51752 L F
.609 .298 .417 r
.60643 .37112 m .6102 .36823 L .60681 .36837 L F
.60643 .37112 m .60948 .37094 L .6102 .36823 L F
.632 .47 .645 r
.6102 .36823 m .61305 .36853 L .61248 .36574 L F
.509 .15 .293 r
.60948 .37094 m .61305 .36853 L .6102 .36823 L F
.71 .487 .584 r
.33313 .55578 m .33417 .55936 L .33029 .55924 L F
.622 .436 .609 r
.3369 .55897 m .33313 .55578 L .33786 .5569 L F
.3369 .55897 m .33417 .55936 L .33313 .55578 L F
0 .187 .706 r
.62643 .40044 m .62827 .40466 L .62224 .40337 L F
.75 .617 .712 r
.62224 .40337 m .62827 .40466 L .6254 .40861 L F
.408 0 .101 r
.33964 .57494 m .34393 .57248 L .34009 .57302 L F
0 0 0 r
.32833 .52635 m .32645 .52811 L .32949 .52587 L F
.109 0 .22 r
.32833 .52635 m .32949 .52587 L .33023 .52439 L F
.676 .828 .395 r
.70416 .34388 m .70299 .3463 L .70497 .34267 L F
.893 .976 .677 r
.70497 .34267 m .70678 .33812 L .70508 .34178 L F
.78 .843 .386 r
.70416 .34388 m .70497 .34267 L .70508 .34178 L F
.668 .897 .979 r
.31305 .65057 m .31527 .65121 L .31558 .64943 L F
.882 .859 .814 r
.31527 .65121 m .31305 .65057 L .31558 .64943 L F
0 0 .378 r
.32804 .5932 m .32892 .5932 L .32888 .59047 L F
.32804 .5932 m .32905 .5939 L .32892 .5932 L F
.564 .731 .953 r
.70614 .29131 m .70499 .29399 L .70365 .29269 L F
.70614 .29131 m .70771 .2933 L .70499 .29399 L F
.294 .164 .527 r
.70717 .29529 m .70499 .29399 L .70771 .2933 L F
.70717 .29529 m .70529 .29711 L .70499 .29399 L F
.771 .666 .748 r
.35866 .5627 m .35603 .56578 L .35567 .563 L F
.785 .748 .819 r
.37144 .6345 m .37441 .6317 L .37225 .63044 L F
.95 .956 .687 r
.63229 .41554 m .63408 .41483 L .63484 .41231 L F
.406 .108 .343 r
.60366 .3564 m .6036 .35816 L .60095 .35891 L F
.482 .172 .363 r
.60673 .35569 m .6036 .35816 L .60366 .3564 L F
0 .238 .754 r
.32801 .61283 m .32681 .61212 L .32671 .61001 L F
.572 .878 .585 r
.30446 .62677 m .303 .62831 L .30101 .6301 L F
0 0 .008 r
.46296 .51645 m .46327 .51435 L .46402 .51772 L F
0 .219 .732 r
.46433 .51989 m .46296 .51645 L .46402 .51772 L F
.234 0 0 r
.58769 .35915 m .58532 .35872 L .58346 .3581 L F
.139 .248 .715 r
.58769 .35915 m .58949 .35795 L .58532 .35872 L F
.936 .967 .727 r
.54002 .43095 m .54122 .4273 L .53821 .42947 L F
.627 .698 .896 r
.34223 .54971 m .33959 .55029 L .33778 .54885 L F
.591 .443 .649 r
.33959 .55029 m .33963 .55312 L .34223 .54971 L F
.33959 .55029 m .33963 .55312 L .34223 .54971 L F
.7 .411 .481 r
.32008 .56951 m .31589 .57191 L .31598 .56913 L F
.32008 .56951 m .31878 .57227 L .31589 .57191 L F
.24 0 .236 r
.32154 .57093 m .31878 .57227 L .32008 .56951 L F
.854 .92 .874 r
.47395 .43759 m .46946 .43967 L .47114 .43773 L F
.864 .909 .861 r
.47523 .43577 m .47395 .43759 L .47114 .43773 L F
.502 .265 .487 r
.50664 .49813 m .50654 .50093 L .50373 .5014 L F
.457 .245 .503 r
.50938 .49477 m .50941 .49766 L .50664 .49813 L F
.501 .29 .525 r
.50941 .49766 m .50654 .50093 L .50664 .49813 L F
.45 0 0 r
.43502 .54087 m .43496 .54067 L .43316 .53966 L F
.43502 .54087 m .43748 .54239 L .43496 .54067 L F
.062 .031 .506 r
.46558 .55689 m .46693 .55226 L .46459 .55253 L F
.46558 .55689 m .46734 .55505 L .46693 .55226 L F
0 0 .257 r
.46701 .55763 m .46734 .55505 L .46558 .55689 L F
.726 .637 .758 r
.32622 .53447 m .32711 .52955 L .32461 .53015 L F
.775 .841 .903 r
.50875 .41681 m .50686 .41851 L .50495 .41679 L F
.632 .302 .395 r
.34029 .55863 m .33786 .5569 L .33966 .5558 L F
.636 .826 .974 r
.3393 .55891 m .3369 .55897 L .34029 .55863 L F
0 0 .224 r
.33925 .55887 m .33998 .55936 L .33864 .55837 L F
.3393 .55891 m .33935 .55894 L .33925 .55887 L F
.33935 .55894 m .33998 .55936 L .33925 .55887 L F
.632 .302 .395 r
.34029 .55863 m .33909 .55875 L .33786 .5569 L F
.33909 .55875 m .3369 .55897 L .33753 .5576 L F
.33909 .55875 m .33753 .5576 L .33786 .5569 L F
.693 .741 .888 r
.69638 .30175 m .69702 .30406 L .69473 .30199 L F
.982 .778 .37 r
.69638 .30175 m .69636 .30194 L .6965 .30238 L F
.69662 .30261 m .6965 .30238 L .69702 .30406 L F
.69638 .30175 m .6965 .30238 L .69662 .30261 L F
.634 .728 .916 r
.69679 .30203 m .6977 .30237 L .69859 .30147 L F
.6977 .30237 m .6995 .30305 L .69859 .30147 L F
.5 .651 .926 r
.69859 .30147 m .70137 .30142 L .70018 .29904 L F
0 0 .464 r
.70018 .29904 m .69999 .30006 L .69859 .30147 L F
.634 .728 .916 r
.6965 .30238 m .6995 .30305 L .6968 .30203 L F
.469 .235 .476 r
.69677 .30203 m .69634 .3021 L .69638 .30175 L F
.634 .728 .916 r
.69634 .3021 m .6968 .30203 L .69618 .30179 L F
.6965 .30238 m .6968 .30203 L .69634 .3021 L F
.69473 .30199 m .6965 .30238 L .69618 .30179 L F
.6965 .30238 m .69702 .30406 L .6995 .30305 L F
.69473 .30199 m .69702 .30406 L .6965 .30238 L F
.982 .778 .37 r
.69636 .30194 m .69597 .30527 L .69702 .30406 L F
.049 .335 .815 r
.69928 .30387 m .69983 .30578 L .69702 .30406 L F
.69928 .30387 m .69702 .30406 L .69597 .30527 L F
.469 .235 .476 r
.69928 .30387 m .69597 .30527 L .69634 .3021 L F
.69928 .30387 m .69634 .3021 L .69677 .30203 L F
.116 .662 .825 r
.70182 .30172 m .69859 .30147 L .6995 .30305 L F
.70182 .30172 m .70137 .30142 L .69887 .30146 L F
.69877 .30148 m .69887 .30146 L .69859 .30147 L F
.70182 .30172 m .69887 .30146 L .69877 .30148 L F
.654 .099 0 r
.69928 .30387 m .70417 .3072 L .69983 .30578 L F
.69928 .30387 m .70174 .30624 L .70417 .3072 L F
0 0 .464 r
.69976 .3013 m .7008 .30517 L .69928 .30387 L F
.70018 .29904 m .7004 .30118 L .69976 .3013 L F
.7004 .30118 m .7008 .30517 L .69976 .3013 L F
.69999 .30006 m .69928 .30387 L .69859 .30147 L F
.469 .235 .476 r
.69928 .30387 m .69677 .30203 L .69859 .30147 L F
.69677 .30203 m .69638 .30175 L .69859 .30147 L F
.634 .728 .916 r
.69618 .30179 m .69679 .30203 L .69859 .30147 L F
.961 .632 .251 r
.39019 .55126 m .39123 .54955 L .38975 .54837 L F
.39019 .55126 m .39156 .55257 L .39123 .54955 L F
.71 .838 .943 r
.3572 .58921 m .36152 .58923 L .3598 .58883 L F
.56 .574 .825 r
.61305 .36853 m .6142 .3634 L .61248 .36574 L F
.372 0 0 r
.25022 .62234 m .25453 .62452 L .25287 .62332 L F
0 .253 .707 r
.25453 .62452 m .25439 .62398 L .25287 .62332 L F
.25453 .62452 m .25732 .6262 L .25439 .62398 L F
.686 .675 .834 r
.27671 .62371 m .27993 .62801 L .27915 .62355 L F
.819 .834 .86 r
.27915 .62355 m .27993 .62801 L .28237 .62285 L F
.422 0 0 r
.38883 .47161 m .39144 .47304 L .3931 .4734 L F
.896 .483 .089 r
.39144 .47304 m .39309 .47507 L .3931 .4734 L F
0 0 0 r
.63459 .38837 m .63059 .39021 L .63301 .38687 L F
.587 .796 .979 r
.63717 .38752 m .63459 .38837 L .63301 .38687 L F
.919 .523 .176 r
.40243 .53418 m .4008 .53324 L .39988 .53018 L F
.913 .512 .142 r
.40303 .53639 m .4008 .53324 L .40243 .53418 L F
.824 .43 0 r
.42647 .56097 m .42705 .56067 L .4263 .55881 L F
.42647 .56097 m .42712 .56169 L .42705 .56067 L F
.787 .699 .767 r
.62652 .36848 m .63025 .36883 L .62904 .36496 L F
.778 .724 .802 r
.62637 .37127 m .63025 .36883 L .62652 .36848 L F
.641 .774 .311 r
.33516 .63265 m .33442 .63419 L .33325 .63661 L F
0 .166 .691 r
.33653 .63644 m .33442 .63419 L .33516 .63265 L F
.673 .261 .255 r
.33653 .63644 m .33442 .63419 L .33325 .63661 L F
.347 .347 .717 r
.36012 .55851 m .36078 .56144 L .35839 .55978 L F
.77 .957 .932 r
.38226 .67556 m .38384 .67629 L .3871 .67407 L F
.577 .923 .726 r
.27523 .62466 m .27183 .62702 L .27439 .62752 L F
.833 .959 .624 r
.27632 .62197 m .27523 .62466 L .27671 .62371 L F
.771 .709 .794 r
.27439 .62752 m .27671 .62371 L .27523 .62466 L F
.673 .567 .728 r
.61185 .37811 m .60909 .38121 L .60911 .37886 L F
.581 .864 .995 r
.38643 .47458 m .38377 .47542 L .38441 .47355 L F
.871 .543 .427 r
.38643 .47458 m .38441 .47355 L .38377 .47542 L F
.734 .859 .94 r
.58949 .35795 m .58867 .36152 L .59304 .35773 L F
.691 .58 .726 r
.58867 .36152 m .59457 .35923 L .59304 .35773 L F
.58867 .36152 m .59199 .3625 L .59457 .35923 L F
.316 .058 .355 r
.23846 .58233 m .24081 .58171 L .24126 .57943 L F
.617 .683 .889 r
.68473 .34449 m .68318 .34872 L .68228 .34563 L F
.68473 .34449 m .68549 .34814 L .68318 .34872 L F
.742 .521 .594 r
.68318 .34872 m .68711 .35233 L .68362 .35146 L F
.547 .677 .924 r
.46526 .52428 m .46649 .5216 L .46433 .51989 L F
.46526 .52428 m .46783 .5238 L .46649 .5216 L F
.748 .238 0 r
.29098 .57543 m .28687 .57271 L .28844 .57452 L F
.539 .435 .684 r
.34286 .68934 m .34537 .68882 L .34506 .68604 L F
.802 .52 .509 r
.53888 .46579 m .53981 .46275 L .53624 .46179 L F
.732 .495 .568 r
.53888 .46579 m .54268 .46254 L .53981 .46275 L F
0 0 .03 r
.70253 .34863 m .70299 .3463 L .70416 .34388 L F
.719 .869 .952 r
.42991 .45441 m .42553 .45492 L .42857 .45282 L F
.666 .784 .937 r
.43089 .45145 m .42991 .45441 L .42857 .45282 L F
.43089 .45145 m .43262 .45327 L .42991 .45441 L F
.272 .058 .395 r
.48918 .5298 m .48684 .53306 L .48715 .53076 L F
.561 .23 .365 r
.54571 .47613 m .54829 .47788 L .54544 .47796 L F
.54571 .47613 m .5482 .47618 L .54829 .47788 L F
.958 .718 .534 r
.24571 .59106 m .2478 .59204 L .24613 .58844 L F
.448 0 0 r
.46319 .54935 m .46483 .55036 L .46171 .5483 L F
.46319 .54935 m .46483 .55036 L .46171 .5483 L F
.513 .383 .64 r
.46483 .55036 m .46793 .54994 L .46641 .54748 L F
.488 .284 .528 r
.46693 .55226 m .46483 .55036 L .46459 .55253 L F
.46693 .55226 m .46793 .54994 L .46483 .55036 L F
.986 .731 .455 r
.26572 .6072 m .26335 .60746 L .26435 .60675 L F
.26335 .60746 m .26206 .6076 L .26435 .60675 L F
.573 .659 .895 r
.26435 .60675 m .25985 .60771 L .26206 .6076 L F
.563 .936 .897 r
.26435 .60675 m .26206 .6076 L .26399 .60638 L F
.986 .731 .455 r
.26335 .60746 m .26399 .60638 L .26206 .6076 L F
.563 .936 .897 r
.26435 .60675 m .26399 .60638 L .26572 .6072 L F
.986 .731 .455 r
.26572 .6072 m .26471 .60672 L .26335 .60746 L F
0 0 0 r
.26336 .60745 m .26335 .60746 L .26435 .60675 L F
.986 .731 .455 r
.26471 .60672 m .26399 .60638 L .26335 .60746 L F
0 0 0 r
.26001 .60983 m .26001 .60982 L .26335 .60746 L F
.26001 .60983 m .26335 .60746 L .26336 .60745 L F
.26001 .60982 m .25977 .60914 L .26435 .60675 L F
.26001 .60983 m .25913 .61116 L .25977 .60914 L F
.574 .548 .788 r
.36119 .6963 m .36252 .69196 L .35999 .69245 L F
.36119 .6963 m .36392 .69573 L .36252 .69196 L F
0 0 0 r
.4227 .5924 m .42057 .59554 L .42235 .59203 L F
.425 .774 .996 r
.36579 .6171 m .36502 .61803 L .36268 .61703 L F
0 0 .266 r
.36583 .61963 m .36502 .61803 L .36579 .6171 L F
.36583 .61963 m .36466 .62114 L .36502 .61803 L F
0 .413 .81 r
.24867 .62115 m .25022 .62234 L .25287 .62332 L F
.346 0 0 r
.25732 .6262 m .25919 .62719 L .25842 .6268 L F
.495 0 0 r
.25842 .6268 m .25919 .62719 L .26123 .62887 L F
.29 .166 .534 r
.26168 .62893 m .25919 .62719 L .26034 .6249 L F
0 .197 .726 r
.26123 .62887 m .25919 .62719 L .26168 .62893 L F
.813 .739 .783 r
.69073 .34158 m .69292 .3435 L .69119 .34495 L F
.359 .41 .778 r
.22248 .5854 m .22412 .58482 L .22303 .58103 L F
.635 .355 .476 r
.5363 .47877 m .53655 .4809 L .53235 .48174 L F
.697 .4 .468 r
.5363 .47877 m .53925 .48202 L .53655 .4809 L F
.691 .401 .478 r
.53969 .47994 m .5363 .47877 L .53929 .47894 L F
.53969 .47994 m .53925 .48202 L .5363 .47877 L F
.94 .936 .764 r
.64036 .40336 m .6435 .40075 L .64301 .40016 L F
.64036 .40336 m .64142 .40446 L .6435 .40075 L F
.691 .979 .813 r
.6435 .40075 m .64489 .39867 L .64301 .40016 L F
.6435 .40075 m .64695 .398 L .64489 .39867 L F
0 0 0 r
.69545 .2814 m .69349 .28493 L .69487 .28314 L F
0 0 .012 r
.69487 .28314 m .69349 .28493 L .69273 .28704 L F
.447 .81 .995 r
.52267 .40739 m .52074 .40787 L .51953 .40691 L F
.514 .264 .474 r
.45025 .50467 m .45311 .50121 L .45007 .50136 L F
.11 0 0 r
.45146 .50181 m .45007 .50136 L .45311 .50121 L F
0 .156 .659 r
.45311 .50121 m .45553 .50301 L .45405 .50136 L F
.357 .179 .497 r
.45423 .50461 m .45553 .50301 L .45311 .50121 L F
0 .156 .659 r
.45311 .50121 m .45405 .50136 L .45146 .50181 L F
.815 .971 .9 r
.67892 .37796 m .68029 .37519 L .67826 .3771 L F
.67892 .37796 m .68212 .37527 L .68029 .37519 L F
.082 .372 .837 r
.57606 .38733 m .57815 .38995 L .57711 .38942 L F
.532 .286 .488 r
.36394 .6072 m .36124 .60785 L .36162 .60508 L F
.655 .507 .67 r
.36442 .60221 m .36431 .60515 L .36162 .60508 L F
.609 .27 .371 r
.36431 .60515 m .36394 .6072 L .36162 .60508 L F
.831 .711 .732 r
.3561 .64348 m .35459 .64015 L .35303 .6449 L F
0 0 0 r
.3561 .64348 m .35303 .6449 L .35708 .64365 L F
.027 0 .416 r
.3578 .64278 m .3561 .64348 L .35708 .64365 L F
.376 .019 .225 r
.44164 .52442 m .44123 .52611 L .43841 .52677 L F
.594 .212 .288 r
.44164 .52442 m .44412 .52625 L .44123 .52611 L F
.569 .49 .726 r
.44443 .52363 m .44164 .52442 L .44085 .52106 L F
.491 .268 .503 r
.44443 .52363 m .44412 .52625 L .44164 .52442 L F
.985 .717 .425 r
.43978 .52269 m .44164 .52442 L .44085 .52106 L F
0 0 0 r
.44149 .58686 m .44109 .58798 L .44273 .58662 L F
.734 .952 .65 r
.44273 .58662 m .44109 .58798 L .44186 .58704 L F
0 0 0 r
.44149 .58686 m .44273 .58662 L .4436 .58619 L F
.734 .952 .65 r
.44273 .58662 m .44186 .58704 L .44419 .58421 L F
0 0 0 r
.4436 .58619 m .44273 .58662 L .44502 .58574 L F
.271 .758 .667 r
.44502 .58574 m .4463 .58519 L .44629 .5852 L F
0 0 0 r
.44502 .58574 m .44629 .5852 L .44695 .58415 L F
.271 .758 .667 r
.44502 .58574 m .44273 .58662 L .4463 .58519 L F
.835 .782 .279 r
.68096 .35855 m .68026 .36263 L .68026 .36035 L F
.908 .845 .392 r
.68026 .36035 m .68026 .36263 L .67951 .36496 L F
.73 .596 .706 r
.43739 .52079 m .44085 .52106 L .44015 .51716 L F
.629 .183 .173 r
.43739 .52079 m .43978 .52269 L .44085 .52106 L F
.278 .246 .642 r
.44085 .52106 m .44141 .51804 L .44015 .51716 L F
.44085 .52106 m .44267 .51985 L .44141 .51804 L F
.476 .21 .43 r
.43978 .52269 m .44267 .51985 L .44085 .52106 L F
0 0 0 r
.57089 .4375 m .56762 .4388 L .57041 .43916 L F
.554 .529 .782 r
.43212 .52617 m .43364 .52392 L .43128 .52449 L F
.566 .069 0 r
.40385 .54347 m .40693 .5467 L .40524 .54501 L F
.986 .744 .353 r
.40693 .5467 m .40555 .54773 L .40524 .54501 L F
.40693 .5467 m .40709 .54954 L .40555 .54773 L F
.454 .243 .503 r
.51167 .49696 m .50938 .49477 L .51209 .49422 L F
.51167 .49696 m .50941 .49766 L .50938 .49477 L F
.634 .454 .623 r
.35097 .60206 m .35247 .60286 L .35343 .59883 L F
.35097 .60206 m .35247 .60286 L .35343 .59883 L F
.502 .257 .476 r
.35617 .59844 m .35887 .59536 L .35513 .59727 L F
.616 .59 .801 r
.35604 .59308 m .35536 .59789 L .35391 .59414 L F
.81 .462 .397 r
.35455 .59829 m .35617 .59844 L .35348 .59882 L F
.35359 .5982 m .35455 .59829 L .35343 .59883 L F
.35359 .5982 m .35464 .59949 L .35617 .59844 L F
.616 .59 .801 r
.35536 .59789 m .35517 .59929 L .35488 .59812 L F
.35536 .59789 m .35488 .59812 L .35391 .59414 L F
.81 .462 .397 r
.35455 .59829 m .35348 .59882 L .35343 .59883 L F
.69 .844 .957 r
.45303 .44736 m .45245 .44994 L .45083 .44851 L F
.45303 .44736 m .45439 .44866 L .45245 .44994 L F
0 0 .043 r
.47979 .5594 m .47961 .56157 L .47929 .56286 L F
0 0 .214 r
.47929 .56286 m .47961 .56157 L .47945 .56538 L F
0 0 .319 r
.47929 .56286 m .47945 .56538 L .47902 .56653 L F
.648 .946 .715 r
.43366 .51826 m .43203 .51921 L .43078 .52091 L F
.683 .616 .775 r
.43078 .52091 m .43366 .52102 L .43366 .51826 L F
.57 .45 .676 r
.43078 .52091 m .43364 .52392 L .43366 .52102 L F
0 0 .374 r
.4319 .52215 m .43078 .52091 L .43203 .51921 L F
.57 .45 .676 r
.43078 .52091 m .43128 .52449 L .43364 .52392 L F
0 0 .374 r
.4319 .52215 m .43128 .52449 L .43078 .52091 L F
.567 .455 .686 r
.56071 .40975 m .56056 .40999 L .55825 .41127 L F
.971 .668 .382 r
.55791 .41806 m .55636 .4175 L .55627 .41533 L F
.55644 .41501 m .55627 .41533 L .55624 .41458 L F
.55791 .41806 m .55627 .41533 L .55644 .41501 L F
.727 .299 .231 r
.55419 .41383 m .55781 .41222 L .55782 .41253 L F
.55654 .41484 m .55782 .41253 L .55798 .41547 L F
.55419 .41383 m .55782 .41253 L .55654 .41484 L F
.962 .762 .317 r
.55825 .41127 m .5582 .41277 L .55849 .41192 L F
.5582 .41277 m .55816 .41386 L .55849 .41192 L F
.727 .299 .231 r
.5582 .41277 m .55849 .41192 L .55834 .41296 L F
.55781 .41222 m .55849 .41192 L .5582 .41277 L F
.37 .012 .22 r
.55816 .41386 m .56052 .41474 L .55798 .41547 L F
0 0 0 r
.55834 .41296 m .55816 .41386 L .55798 .41547 L F
.55849 .41192 m .55816 .41386 L .55834 .41296 L F
.567 .455 .686 r
.55834 .41296 m .55816 .41386 L .5582 .41277 L F
.55854 .41325 m .55816 .41386 L .55834 .41296 L F
.727 .299 .231 r
.55781 .41222 m .55834 .41296 L .55798 .41547 L F
.567 .455 .686 r
.56056 .40999 m .55854 .41325 L .55825 .41127 L F
.55854 .41325 m .5582 .41277 L .55825 .41127 L F
.611 .79 .967 r
.55825 .41127 m .55849 .41192 L .55771 .41157 L F
.55825 .41127 m .55771 .41157 L .55389 .40988 L F
.191 0 0 r
.34654 .49765 m .34835 .49784 L .34419 .4972 L F
.352 0 0 r
.35004 .49849 m .34835 .49784 L .34654 .49765 L F
.479 .187 .391 r
.34799 .6074 m .35095 .6048 L .34832 .60498 L F
.34799 .6074 m .35095 .6048 L .34832 .60498 L F
.769 .563 0 r
.41026 .57522 m .40973 .57154 L .41078 .57242 L F
.41026 .57522 m .40998 .57424 L .40973 .57154 L F
.927 .587 .14 r
.41026 .57522 m .40955 .57694 L .40998 .57424 L F
.41026 .57522 m .41049 .57787 L .40955 .57694 L F
.516 .633 .905 r
.34947 .68994 m .35355 .69238 L .352 .68935 L F
.728 .713 .837 r
.352 .68935 m .35355 .69238 L .35613 .69008 L F
.974 .667 .353 r
.41041 .58887 m .40936 .59108 L .40962 .58778 L F
.41041 .58887 m .41089 .59261 L .40936 .59108 L F
.814 .98 .695 r
.38214 .48767 m .38177 .48729 L .38321 .48637 L F
0 0 0 r
.38177 .48729 m .38514 .48479 L .38321 .48637 L F
.559 .55 .801 r
.43207 .53009 m .43094 .53285 L .42931 .52837 L F
.529 .589 .858 r
.43288 .53314 m .43094 .53285 L .43207 .53009 L F
.539 0 0 r
.29453 .5765 m .29421 .57637 L .2933 .57563 L F
.33 0 0 r
.29296 .57535 m .2933 .57563 L .29098 .57543 L F
.18 .695 .891 r
.2933 .57563 m .28907 .5752 L .29098 .57543 L F
.748 .238 0 r
.29098 .57543 m .28907 .5752 L .28687 .57271 L F
.18 .695 .891 r
.2933 .57563 m .29107 .57513 L .28907 .5752 L F
.539 0 0 r
.29421 .57637 m .29107 .57513 L .2933 .57563 L F
.33 0 0 r
.29504 .57527 m .2933 .57563 L .29296 .57535 L F
.7 .416 .489 r
.69324 .31676 m .68923 .31911 L .68961 .31616 L F
.69324 .31676 m .69346 .31936 L .68923 .31911 L F
0 0 0 r
.23873 .53722 m .23664 .53855 L .23483 .53936 L F
.785 .537 .561 r
.24132 .53653 m .23664 .53855 L .23873 .53722 L F
.656 .687 .868 r
.57645 .4182 m .58171 .42051 L .58053 .41821 L F
.194 .485 .898 r
.58053 .41821 m .58171 .42051 L .58226 .41998 L F
.814 .561 .555 r
.34346 .5563 m .33966 .5558 L .33963 .55312 L F
.669 .37 .457 r
.34346 .5563 m .34029 .55863 L .33966 .5558 L F
.34346 .5563 m .34351 .55887 L .34029 .55863 L F
.34029 .55863 m .34351 .55887 L .34346 .5563 L F
.394 .694 .98 r
.34346 .5563 m .34474 .55555 L .34304 .55465 L F
.765 .692 .782 r
.43862 .51371 m .43597 .51674 L .44015 .51716 L F
.773 .66 .738 r
.43597 .51674 m .43739 .52079 L .44015 .51716 L F
.369 .381 .742 r
.44015 .51716 m .44123 .5129 L .43862 .51371 L F
.44015 .51716 m .44141 .51804 L .44123 .5129 L F
.367 0 .197 r
.46696 .53631 m .47014 .53554 L .47053 .53374 L F
.259 .283 .696 r
.47053 .53374 m .47156 .52951 L .4699 .52995 L F
.47053 .53374 m .47268 .53253 L .47156 .52951 L F
.07 0 .322 r
.47216 .53453 m .47053 .53374 L .47014 .53554 L F
.47216 .53453 m .47268 .53253 L .47053 .53374 L F
.704 .65 .793 r
.34774 .65151 m .3452 .65447 L .34482 .65167 L F
0 0 0 r
.3452 .65447 m .34562 .65439 L .34324 .65546 L F
.3452 .65447 m .34776 .65379 L .34562 .65439 L F
.024 0 0 r
.34776 .65379 m .3452 .65447 L .34774 .65151 L F
.651 .959 .934 r
.41401 .50368 m .41227 .50343 L .41232 .50445 L F
.634 .072 0 r
.41401 .50368 m .41644 .50548 L .41227 .50343 L F
.236 .709 .941 r
.70343 .27641 m .70735 .2771 L .70498 .27718 L F
0 0 .103 r
.41227 .50343 m .41267 .50727 L .41232 .50445 L F
.719 .77 .893 r
.44393 .50342 m .43955 .5034 L .44228 .5007 L F
.625 .672 .875 r
.44725 .50215 m .44393 .50342 L .44228 .5007 L F
.997 .835 .489 r
.73603 .32931 m .73655 .32684 L .73562 .32551 L F
.073 .342 .817 r
.72603 .30813 m .72355 .30799 L .72276 .30663 L F
.72603 .30813 m .72754 .31053 L .72355 .30799 L F
.431 .347 .661 r
.39976 .47202 m .40205 .4714 L .40178 .46885 L F
.39976 .47202 m .40205 .4714 L .40178 .46885 L F
0 .215 .738 r
.40184 .475 m .40228 .4744 L .39976 .47202 L F
0 0 0 r
.56997 .42001 m .56679 .42307 L .56731 .42055 L F
.805 .815 .859 r
.56679 .42307 m .56997 .42001 L .56731 .42055 L F
0 0 0 r
.67389 .36855 m .67012 .37065 L .6732 .36815 L F
.668 .975 .862 r
.67542 .36656 m .67722 .36645 L .67389 .36855 L F
.666 .973 .891 r
.67542 .36656 m .67389 .36855 L .6732 .36815 L F
.794 .971 .912 r
.41987 .50693 m .42426 .50505 L .42012 .50705 L F
.951 .947 .73 r
.42103 .50309 m .41987 .50693 L .4186 .50577 L F
.42103 .50309 m .4188 .50605 L .41987 .50693 L F
.975 .682 .298 r
.41987 .50693 m .41867 .50727 L .4186 .50577 L F
.951 .947 .73 r
.4188 .50605 m .41878 .50608 L .41883 .50611 L F
.4188 .50605 m .41883 .50611 L .41987 .50693 L F
.794 .971 .912 r
.41987 .50693 m .41878 .50608 L .42426 .50505 L F
0 0 0 r
.42426 .50505 m .41882 .50607 L .42457 .50524 L F
.41882 .50607 m .41878 .50608 L .41882 .50607 L F
.41882 .50607 m .41882 .50607 L .42457 .50524 L F
0 .014 .581 r
.41879 .506 m .41885 .50607 L .41861 .50554 L F
.62 .391 .548 r
.41865 .50871 m .41867 .50727 L .4193 .50709 L F
.41944 .50754 m .4193 .50709 L .41987 .50693 L F
.41865 .50871 m .4193 .50709 L .41944 .50754 L F
0 .014 .581 r
.41899 .50609 m .42061 .50826 L .41901 .50609 L F
.41885 .50607 m .41908 .50636 L .41899 .50609 L F
.41908 .50636 m .42061 .50826 L .41899 .50609 L F
.41885 .50607 m .41901 .50609 L .41861 .50554 L F
.951 .947 .73 r
.42103 .50309 m .4186 .50577 L .41817 .5034 L F
.62 .35 .486 r
.42361 .50466 m .41878 .50608 L .42103 .50309 L F
.42457 .50524 m .42245 .50555 L .42361 .50466 L F
.42245 .50555 m .41878 .50608 L .42361 .50466 L F
0 0 0 r
.4274 .50142 m .42426 .50505 L .42625 .50334 L F
.42426 .50505 m .42457 .50524 L .42625 .50334 L F
.716 .648 .781 r
.42415 .49925 m .42274 .50158 L .42481 .49976 L F
.42415 .49925 m .42552 .50408 L .42103 .50309 L F
.62 .35 .486 r
.42457 .50524 m .42103 .50309 L .42552 .50408 L F
0 .05 .605 r
.42563 .5009 m .42552 .50408 L .42415 .49925 L F
.42583 .50113 m .42581 .50134 L .42563 .5009 L F
.42581 .50134 m .42552 .50408 L .42563 .5009 L F
.363 .31 .664 r
.42354 .49631 m .42481 .49976 L .42797 .49745 L F
.42354 .49631 m .42415 .49925 L .42481 .49976 L F
.42354 .49631 m .42591 .49847 L .42415 .49925 L F
0 .05 .605 r
.42583 .50113 m .42415 .49925 L .42591 .49847 L F
.786 .532 .553 r
.42172 .50059 m .42484 .49901 L .42222 .49752 L F
.42484 .49901 m .42591 .49847 L .42446 .4981 L F
.42484 .49901 m .42446 .4981 L .42222 .49752 L F
.845 .983 .866 r
.42297 .50471 m .42383 .5045 L .42583 .50113 L F
.42383 .5045 m .42552 .50408 L .42562 .50314 L F
.42383 .5045 m .42562 .50314 L .42583 .50113 L F
0 .014 .581 r
.41861 .50554 m .42061 .50826 L .41862 .50486 L F
.4186 .50577 m .41879 .506 L .41861 .50554 L F
.962 .631 .266 r
.39726 .52418 m .39766 .52669 L .39585 .52298 L F
.771 .686 .769 r
.5469 .40726 m .54444 .4091 L .54352 .40727 L F
.493 .544 .837 r
.55128 .41038 m .5469 .40726 L .55076 .4077 L F
0 .219 .742 r
.34229 .63398 m .34471 .63754 L .34323 .63628 L F
.007 0 .22 r
.34639 .63593 m .34471 .63754 L .34698 .63384 L F
.411 .296 .612 r
.32684 .62092 m .3269 .62333 L .3246 .62185 L F
.85 .439 0 r
.33862 .52785 m .34047 .53072 L .3392 .53345 L F
.577 .943 .863 r
.67951 .36496 m .67722 .36645 L .67542 .36656 L F
.54 .269 .453 r
.52334 .48505 m .52045 .48772 L .52064 .48542 L F
.746 .954 .943 r
.65469 .3908 m .65803 .39 L .65688 .38926 L F
.663 .916 .977 r
.65803 .39 m .66028 .38752 L .65688 .38926 L F
.65803 .39 m .66132 .38851 L .66028 .38752 L F
.898 .987 .768 r
.63418 .35841 m .63727 .35493 L .6367 .35497 L F
.467 0 0 r
.54216 .43806 m .54039 .43648 L .53948 .43881 L F
.54216 .43806 m .54539 .4372 L .54039 .43648 L F
.783 .929 .563 r
.42657 .57941 m .4283 .57611 L .4293 .5788 L F
.381 .088 .337 r
.42612 .58156 m .42657 .57941 L .4293 .5788 L F
.769 .95 .935 r
.23456 .61048 m .23765 .60885 L .2367 .61072 L F
.072 0 .065 r
.2395 .60797 m .2367 .61072 L .23765 .60885 L F
.79 .726 .793 r
.23411 .60925 m .2367 .61072 L .23769 .60975 L F
.863 .427 .015 r
.23469 .60543 m .23535 .60702 L .23765 .60885 L F
.23535 .60702 m .23584 .60759 L .23765 .60885 L F
.519 .835 .999 r
.23765 .60885 m .23549 .60734 L .2395 .60797 L F
.79 .726 .793 r
.23673 .60863 m .23769 .60975 L .2395 .60797 L F
.23411 .60925 m .23769 .60975 L .23673 .60863 L F
.863 .427 .015 r
.23535 .60702 m .23549 .60734 L .23584 .60759 L F
.861 .841 .823 r
.56551 .38468 m .5665 .3874 L .56468 .38612 L F
.82 .919 .903 r
.5665 .3874 m .56337 .38803 L .56468 .38612 L F
.741 .79 .893 r
.5681 .38342 m .5665 .3874 L .56551 .38468 L F
.5681 .38342 m .56935 .38592 L .5665 .3874 L F
.107 .278 .756 r
.60399 .37108 m .60254 .36768 L .59947 .37114 L F
.493 .346 .609 r
.60399 .37108 m .60643 .37112 L .60681 .36837 L F
.526 .332 .56 r
.49874 .5077 m .4989 .51066 L .49582 .51098 L F
.425 .293 .597 r
.49854 .51305 m .49582 .51098 L .4989 .51066 L F
.49854 .51305 m .49632 .51403 L .49582 .51098 L F
0 0 0 r
.69773 .27943 m .69844 .27835 L .69545 .2814 L F
.74 .869 .94 r
.70079 .27606 m .69844 .27835 L .69944 .27485 L F
.779 .835 .372 r
.69944 .27485 m .69844 .27835 L .69773 .27943 L F
.746 .701 .162 r
.33342 .64215 m .33378 .6397 L .33379 .64247 L F
.884 .689 .17 r
.33326 .6414 m .33379 .64247 L .33378 .6397 L F
.336 .186 .524 r
.3343 .64292 m .33379 .64247 L .33326 .6414 L F
.33583 .64515 m .33379 .64247 L .3343 .64292 L F
.746 .701 .162 r
.33314 .6441 m .33342 .64215 L .33379 .64247 L F
.531 .825 .999 r
.33127 .64313 m .33314 .6441 L .33379 .64247 L F
.537 .434 .685 r
.29951 .63363 m .30101 .6301 L .30024 .63081 L F
.055 0 0 r
.40184 .475 m .40173 .47655 L .40228 .4744 L F
.40184 .475 m .39963 .47744 L .40173 .47655 L F
.322 .534 .904 r
.33951 .6274 m .34163 .62799 L .33995 .62574 L F
.755 .582 .663 r
.57783 .42654 m .58212 .42679 L .58154 .42401 L F
0 0 .362 r
.58154 .42401 m .58223 .42514 L .58327 .4222 L F
.58154 .42401 m .58212 .42679 L .58223 .42514 L F
.458 .24 .494 r
.32761 .56177 m .32756 .56604 L .32526 .56294 L F
.088 .363 .83 r
.24511 .59678 m .24499 .59451 L .24309 .59531 L F
.447 .051 .193 r
.24782 .59591 m .24705 .59758 L .24511 .59678 L F
.088 .363 .83 r
.24511 .59678 m .24705 .59758 L .24499 .59451 L F
.797 .982 .899 r
.70235 .31355 m .70149 .31265 L .70255 .31186 L F
.70255 .31186 m .70149 .31265 L .70235 .31355 L F
.7 .545 .674 r
.36881 .60228 m .36431 .60515 L .36442 .60221 L F
.975 .924 .647 r
.40834 .55659 m .40819 .55934 L .40853 .55994 L F
.798 .365 0 r
.40819 .55934 m .40989 .56256 L .40843 .56102 L F
.40819 .55934 m .40843 .56102 L .40853 .55994 L F
.099 .646 .83 r
.29419 .66192 m .29616 .66231 L .29857 .66227 L F
.753 .995 .852 r
.58658 .37076 m .58728 .36866 L .58938 .36869 L F
.58658 .37076 m .5854 .37048 L .58728 .36866 L F
0 0 0 r
.69773 .27943 m .69545 .2814 L .69487 .28314 L F
.34566 .61383 m .34822 .61243 L .34891 .6119 L F
.269 .329 .741 r
.34799 .6074 m .34891 .6119 L .3509 .6098 L F
.552 .867 .577 r
.34891 .6119 m .34822 .61243 L .3509 .6098 L F
.006 0 0 r
.285 .57429 m .28687 .57271 L .28277 .57218 L F
.728 .281 .19 r
.28687 .57271 m .28907 .5752 L .285 .57429 L F
.28687 .57271 m .28749 .57406 L .28918 .57201 L F
.28687 .57271 m .285 .57429 L .28749 .57406 L F
0 .152 .673 r
.43491 .59168 m .43616 .59564 L .43524 .59481 L F
.916 .551 .111 r
.43616 .59564 m .43559 .59597 L .43524 .59481 L F
.43616 .59564 m .43706 .59828 L .43559 .59597 L F
.764 .984 .906 r
.6232 .35151 m .62104 .35411 L .6254 .35123 L F
0 0 0 r
.6232 .35151 m .62189 .35331 L .62104 .35411 L F
.186 .711 .692 r
.62037 .35473 m .62422 .35373 L .62104 .35411 L F
.834 .976 .882 r
.62104 .35411 m .62422 .35373 L .62591 .35183 L F
.62104 .35411 m .62591 .35183 L .6254 .35123 L F
0 0 0 r
.62189 .35331 m .62069 .35495 L .62104 .35411 L F
.186 .711 .692 r
.61985 .35486 m .62037 .35473 L .62104 .35411 L F
0 0 0 r
.43318 .49119 m .43201 .4951 L .43029 .49083 L F
.43318 .49119 m .43273 .49325 L .43201 .4951 L F
.748 .992 .81 r
.43273 .49325 m .42981 .49591 L .43201 .4951 L F
.595 .756 .955 r
.57849 .45643 m .58267 .45723 L .58094 .45539 L F
.415 .543 .876 r
.58267 .45723 m .58357 .45484 L .58094 .45539 L F
.58267 .45723 m .58603 .45757 L .58357 .45484 L F
.842 .773 .785 r
.59833 .45839 m .60116 .45932 L .6008 .45513 L F
.869 .731 .707 r
.5997 .46225 m .60116 .45932 L .59833 .45839 L F
.799 .743 .8 r
.6008 .45513 m .60116 .45932 L .60312 .45661 L F
.607 .669 .883 r
.67628 .33539 m .67718 .33733 L .68011 .3363 L F
.828 .967 .893 r
.62497 .34353 m .62584 .34055 L .62693 .34162 L F
.62497 .34353 m .62275 .3432 L .62584 .34055 L F
.425 .267 .561 r
.55223 .3981 m .55404 .39732 L .55448 .39445 L F
0 0 .006 r
.55223 .3981 m .55315 .39806 L .55404 .39732 L F
.55223 .3981 m .55168 .39962 L .55315 .39806 L F
.507 .343 .593 r
.3763 .61146 m .37911 .61076 L .37891 .60814 L F
.87 .945 .582 r
.3423 .63292 m .34388 .63141 L .34229 .63398 L F
.813 .941 .581 r
.34435 .62945 m .34388 .63141 L .3423 .63292 L F
.483 .207 .418 r
.34215 .5337 m .3449 .53323 L .34551 .5308 L F
.289 .035 .343 r
.34551 .5308 m .34704 .53226 L .34762 .52995 L F
.34551 .5308 m .3449 .53323 L .34704 .53226 L F
.786 .756 .826 r
.3855 .66271 m .38762 .66327 L .38344 .66259 L F
.699 .761 .9 r
.37225 .63044 m .37441 .6317 L .37576 .62977 L F
.027 0 0 r
.60907 .35476 m .60673 .35569 L .60693 .35542 L F
.566 .909 .69 r
.63349 .33903 m .63519 .33729 L .63664 .33657 L F
.578 .928 .747 r
.63349 .33903 m .63305 .33894 L .63519 .33729 L F
.731 .971 .718 r
.37888 .59881 m .38162 .59683 L .38135 .59722 L F
0 0 0 r
.55917 .43037 m .5556 .43226 L .55951 .43302 L F
.804 .791 .841 r
.55951 .43302 m .56209 .42959 L .55917 .43037 L F
.446 .594 .906 r
.62105 .34506 m .61951 .34624 L .6194 .34457 L F
.138 .029 .456 r
.61351 .40351 m .61305 .4019 L .61552 .3996 L F
.558 .406 .63 r
.31907 .6336 m .31607 .63032 L .31788 .62972 L F
.31907 .6336 m .31602 .63581 L .31607 .63032 L F
.608 .825 .983 r
.44722 .56882 m .44965 .56946 L .44983 .568 L F
.103 .174 .652 r
.45031 .56957 m .4511 .57201 L .44965 .56946 L F
0 .049 .606 r
.44965 .56946 m .4511 .57201 L .44983 .568 L F
.632 .946 .736 r
.6024 .3497 m .60357 .34802 L .605 .34887 L F
.593 .426 .624 r
.35186 .57601 m .3519 .5788 L .35449 .57552 L F
.35449 .57552 m .3519 .5788 L .35186 .57601 L F
.957 .618 .246 r
.54663 .4517 m .54662 .44953 L .54505 .44816 L F
.573 .831 .994 r
.54505 .44816 m .54662 .44953 L .54908 .44871 L F
.715 .515 .618 r
.54663 .4517 m .54908 .44871 L .54662 .44953 L F
.997 .831 .551 r
.5873 .40347 m .5878 .40136 L .58673 .39975 L F
.725 .983 .78 r
.30305 .64222 m .30567 .64098 L .302 .64414 L F
.822 .949 .599 r
.3078 .63742 m .30567 .64098 L .30551 .63946 L F
.755 .99 .783 r
.30551 .63946 m .30567 .64098 L .30305 .64222 L F
0 0 0 r
.67123 .32435 m .66999 .32526 L .66814 .32661 L F
.426 .82 .597 r
.66999 .32526 m .66686 .32746 L .66814 .32661 L F
.824 .674 .696 r
.67164 .34935 m .67379 .35251 L .67003 .35146 L F
.6724 .34953 m .67379 .35251 L .67164 .34935 L F
.766 .585 .652 r
.66899 .34862 m .67206 .3488 L .67003 .35146 L F
.435 0 0 r
.66935 .34882 m .67348 .35037 L .67246 .35017 L F
.66973 .34891 m .67348 .35037 L .66935 .34882 L F
.824 .674 .696 r
.67206 .3488 m .6724 .34953 L .67164 .34935 L F
.767 .602 .674 r
.67278 .34547 m .66844 .3454 L .67086 .34448 L F
.67278 .34547 m .66899 .34862 L .66844 .3454 L F
.67278 .34547 m .67206 .3488 L .66899 .34862 L F
.781 .766 .839 r
.67527 .34375 m .67206 .3488 L .67278 .34547 L F
.529 .441 .7 r
.66899 .34862 m .67348 .35037 L .67086 .34448 L F
.364 .354 .714 r
.67086 .34448 m .67348 .35037 L .67434 .34638 L F
.684 .77 .916 r
.6732 .35035 m .67527 .35046 L .67385 .34851 L F
.67272 .3517 m .67472 .35073 L .6732 .35035 L F
.67472 .35073 m .67527 .35046 L .6732 .35035 L F
.435 0 0 r
.6712 .34985 m .67246 .35017 L .67138 .34995 L F
.66935 .34882 m .67246 .35017 L .6712 .34985 L F
.66899 .34862 m .66973 .34891 L .66935 .34882 L F
.178 .659 .928 r
.67003 .35146 m .67379 .35251 L .67272 .3517 L F
.476 .71 .972 r
.67379 .35251 m .67527 .35046 L .67272 .3517 L F
.67379 .35251 m .67654 .35236 L .67527 .35046 L F
.701 .631 .775 r
.43366 .51826 m .43366 .52102 L .43739 .52079 L F
.677 .449 .569 r
.43366 .52102 m .43732 .52347 L .43739 .52079 L F
.43366 .52102 m .43364 .52392 L .43732 .52347 L F
.606 .477 .679 r
.34506 .68604 m .34682 .68136 L .34448 .68219 L F
.487 .058 .15 r
.31046 .57196 m .30901 .57427 L .30686 .57279 L F
.65 .234 .242 r
.3131 .57437 m .31046 .57196 L .31315 .57197 L F
.3131 .57437 m .30901 .57427 L .31046 .57196 L F
.602 .418 .605 r
.3519 .5788 m .34922 .58161 L .34925 .57939 L F
.34925 .57939 m .34922 .58161 L .3519 .5788 L F
.285 0 .12 r
.24944 .59688 m .24705 .59758 L .24782 .59591 L F
.662 .903 .98 r
.591 .35362 m .5922 .3518 L .59336 .35311 L F
.665 .789 .941 r
.59555 .3518 m .59336 .35311 L .59394 .34938 L F
.865 .957 .865 r
.59336 .35311 m .5922 .3518 L .59394 .34938 L F
.502 .674 .941 r
.30282 .64607 m .3072 .64781 L .30517 .64553 L F
.399 .624 .944 r
.30517 .64553 m .3072 .64781 L .30863 .64721 L F
.113 0 .264 r
.30678 .65036 m .3072 .64781 L .30863 .64721 L F
.523 .305 .525 r
.36027 .52937 m .35786 .52695 L .36039 .5267 L F
.36027 .52937 m .35769 .52988 L .35786 .52695 L F
.237 0 .117 r
.45294 .48784 m .45682 .48485 L .45323 .48548 L F
.485 .174 .363 r
.36881 .60228 m .36394 .6072 L .36431 .60515 L F
.36881 .60228 m .36657 .60685 L .36394 .6072 L F
0 0 .013 r
.36909 .60347 m .36657 .60685 L .36881 .60228 L F
.472 .467 .771 r
.33552 .50649 m .33416 .51078 L .33279 .50764 L F
.33552 .50649 m .33613 .51025 L .33416 .51078 L F
.581 .555 .791 r
.33764 .51415 m .33416 .51078 L .33613 .51025 L F
.97 .742 .535 r
.27838 .54939 m .27691 .5491 L .2769 .54617 L F
.524 .085 .147 r
.28066 .54853 m .27691 .5491 L .27838 .54939 L F
.669 .264 .268 r
.54925 .4612 m .55201 .4593 L .55105 .45864 L F
.527 .785 .991 r
.55201 .4593 m .5549 .45884 L .5526 .45715 L F
.757 .983 .907 r
.55105 .45864 m .55201 .4593 L .5526 .45715 L F
.458 .266 .531 r
.55201 .4593 m .55469 .46112 L .5549 .45884 L F
.55201 .4593 m .55212 .46205 L .55469 .46112 L F
0 .298 .764 r
.3238 .54484 m .32597 .54557 L .32406 .5439 L F
0 0 0 r
.32524 .54662 m .32597 .54557 L .3238 .54484 L F
.582 .392 .589 r
.53929 .47894 m .54146 .47977 L .53969 .47994 L F
.53929 .47894 m .5427 .47853 L .54146 .47977 L F
.033 .561 .86 r
.5304 .44388 m .53017 .44426 L .5287 .44328 L F
.52 .867 .614 r
.53017 .44426 m .53172 .44308 L .53004 .44447 L F
.882 .604 .511 r
.53195 .44443 m .53172 .44308 L .53017 .44426 L F
.033 .561 .86 r
.53195 .44443 m .53017 .44426 L .5304 .44388 L F
.52 .867 .614 r
.53017 .44426 m .53004 .44447 L .52923 .44514 L F
.882 .604 .511 r
.53195 .44443 m .5345 .44257 L .53172 .44308 L F
.126 0 .122 r
.23138 .53545 m .23433 .53246 L .23318 .53313 L F
.23433 .53246 m .23501 .53178 L .23318 .53313 L F
.093 0 .251 r
.2316 .53391 m .23157 .53406 L .23318 .53313 L F
.23157 .53406 m .2311 .53626 L .23318 .53313 L F
.886 .534 .374 r
.44123 .56255 m .44177 .56483 L .44314 .56308 L F
0 .065 .619 r
.44611 .5641 m .44666 .56611 L .44696 .56558 L F
.49 .502 .796 r
.44666 .56611 m .44314 .56308 L .4461 .56502 L F
.44666 .56611 m .4461 .56502 L .44696 .56558 L F
.674 .242 .215 r
.44177 .56483 m .44585 .56542 L .44314 .56308 L F
.997 .772 .453 r
.44628 .56474 m .4461 .56502 L .44666 .56611 L F
.674 .242 .215 r
.44585 .56542 m .4461 .56502 L .44314 .56308 L F
.997 .772 .453 r
.44601 .56485 m .44563 .56766 L .44666 .56611 L F
.691 .434 .529 r
.44696 .56558 m .44563 .56766 L .44596 .56525 L F
.674 .242 .215 r
.44596 .56525 m .44696 .56558 L .4461 .56502 L F
.997 .772 .453 r
.44611 .5641 m .44601 .56485 L .4461 .56502 L F
.44611 .5641 m .4461 .56502 L .44628 .56474 L F
.691 .434 .529 r
.44696 .56558 m .44596 .56525 L .44611 .5641 L F
.674 .242 .215 r
.44585 .56542 m .44696 .56558 L .44596 .56525 L F
.983 .726 .333 r
.40408 .54015 m .403 .53899 L .40303 .53639 L F
.985 .781 .379 r
.40408 .54015 m .403 .54169 L .403 .53899 L F
.40408 .54015 m .40385 .54347 L .403 .54169 L F
.742 .795 .896 r
.5251 .42998 m .52896 .43037 L .52734 .42873 L F
.753 .559 .634 r
.5251 .43326 m .52896 .43037 L .5251 .42998 L F
.5251 .43326 m .5291 .43345 L .52896 .43037 L F
.622 .667 .872 r
.52896 .43037 m .53058 .4265 L .52734 .42873 L F
.52896 .43037 m .53162 .42957 L .53058 .4265 L F
.648 .521 .696 r
.5291 .43345 m .53162 .42957 L .52896 .43037 L F
.813 .739 .783 r
.69073 .34158 m .69119 .34495 L .68804 .34505 L F
.799 .697 .752 r
.69119 .34495 m .68908 .34782 L .68804 .34505 L F
.593 .379 .56 r
.3234 .65019 m .32361 .6536 L .32107 .65307 L F
.75 .775 .873 r
.32451 .64581 m .3234 .65019 L .32214 .64637 L F
.32451 .64581 m .32641 .64812 L .3234 .65019 L F
.754 .247 .005 r
.3234 .65019 m .32793 .65332 L .32361 .6536 L F
.859 .997 .796 r
.24453 .52975 m .24402 .53056 L .24673 .52733 L F
.108 0 .281 r
.24453 .52975 m .24324 .53286 L .24402 .53056 L F
.336 .784 .627 r
.66278 .31948 m .66024 .32085 L .65899 .32151 L F
.932 .596 .151 r
.60212 .40743 m .6018 .40784 L .60092 .40607 L F
.60212 .40743 m .60263 .41001 L .6018 .40784 L F
.732 .495 .568 r
.53888 .46579 m .54276 .46526 L .54268 .46254 L F
.996 .809 .449 r
.54154 .46127 m .54268 .46254 L .54134 .46415 L F
.554 .089 .104 r
.54485 .46419 m .54485 .463 L .54268 .46254 L F
.326 .18 .524 r
.54268 .46254 m .54276 .46526 L .54485 .46419 L F
.54268 .46254 m .54276 .46526 L .54485 .46419 L F
0 .087 .634 r
.35084 .6265 m .34897 .62423 L .3505 .62506 L F
.238 .182 .589 r
.35084 .6265 m .34936 .62729 L .34897 .62423 L F
.923 .64 .486 r
.60989 .39376 m .61179 .39158 L .6097 .3911 L F
.60989 .39376 m .61207 .39393 L .61179 .39158 L F
.64 .403 .544 r
.61423 .39441 m .61179 .39158 L .61207 .39393 L F
.61423 .39441 m .61465 .39117 L .61179 .39158 L F
.767 .995 .801 r
.66605 .37242 m .66851 .37162 L .66486 .37475 L F
.432 .864 .755 r
.67012 .37065 m .66851 .37162 L .66605 .37242 L F
.773 .928 .936 r
.59578 .36561 m .59135 .36653 L .59516 .3652 L F
.577 .814 .989 r
.59704 .3634 m .60032 .36481 L .59578 .36561 L F
.736 .992 .844 r
.59578 .36561 m .59516 .3652 L .59704 .3634 L F
.66 .589 .765 r
.31369 .61994 m .31709 .61887 L .31856 .61533 L F
.403 .359 .695 r
.31369 .61994 m .31613 .6198 L .31709 .61887 L F
.31369 .61994 m .31428 .62132 L .31613 .6198 L F
.502 .257 .476 r
.35617 .59844 m .35862 .59839 L .35887 .59536 L F
.433 .159 .396 r
.35862 .59839 m .36079 .59534 L .35887 .59536 L F
0 0 0 r
.37347 .62788 m .37017 .63169 L .37225 .63044 L F
0 0 .222 r
.24126 .57943 m .2422 .58061 L .24373 .57896 L F
.24126 .57943 m .24081 .58171 L .2422 .58061 L F
.346 .686 .98 r
.56628 .44723 m .56581 .44568 L .56471 .44768 L F
.821 .986 .88 r
.56628 .44723 m .56654 .4447 L .56581 .44568 L F
.56628 .44723 m .56931 .4445 L .56773 .44461 L F
.56628 .44723 m .56773 .44461 L .56647 .44541 L F
.286 .776 .712 r
.56909 .44617 m .56471 .44768 L .56569 .4459 L F
.56599 .44571 m .56569 .4459 L .56581 .44568 L F
.56909 .44617 m .56569 .4459 L .56599 .44571 L F
.821 .986 .88 r
.56647 .44541 m .56773 .44461 L .56654 .4447 L F
.286 .776 .712 r
.56909 .44617 m .56628 .44723 L .56471 .44768 L F
.798 .924 .92 r
.45315 .51998 m .45764 .51843 L .4554 .51908 L F
.654 .965 .918 r
.4586 .51703 m .4554 .51908 L .45764 .51843 L F
.701 .631 .775 r
.43366 .51826 m .43739 .52079 L .43597 .51674 L F
.457 .267 .533 r
.43739 .52079 m .43732 .52347 L .43978 .52269 L F
.368 .096 .364 r
.50148 .50509 m .50103 .50708 L .49874 .5077 L F
.424 .255 .546 r
.5011 .50976 m .49874 .5077 L .50103 .50708 L F
.5011 .50976 m .4989 .51066 L .49874 .5077 L F
0 0 .375 r
.33929 .62344 m .33911 .62415 L .33828 .6207 L F
.33828 .6207 m .33911 .62415 L .33929 .62344 L F
.33929 .62344 m .33828 .6207 L .33628 .62028 L F
.791 .501 .496 r
.27824 .63032 m .27439 .62752 L .27393 .62973 L F
.27826 .63032 m .27825 .63032 L .27824 .63032 L F
.27825 .63032 m .27439 .62752 L .27824 .63032 L F
.698 .659 .808 r
.27716 .6334 m .27803 .63047 L .27589 .63399 L F
.27803 .63047 m .27809 .63027 L .27793 .63053 L F
.27803 .63047 m .27793 .63053 L .27589 .63399 L F
.27716 .6334 m .27826 .63032 L .27809 .63027 L F
.27716 .6334 m .28009 .63307 L .27826 .63032 L F
.631 .406 .557 r
.42625 .50334 m .429 .5001 L .4274 .50142 L F
.87 .94 .862 r
.31056 .66622 m .31221 .66272 L .30909 .66568 L F
.416 .182 .449 r
.50654 .50093 m .50393 .50418 L .50373 .5014 L F
.399 .624 .944 r
.30517 .64553 m .30863 .64721 L .3091 .64379 L F
.30517 .64553 m .3091 .64379 L .30693 .64532 L F
.71 .958 .689 r
.30693 .64532 m .3091 .64379 L .30979 .64227 L F
0 .116 .662 r
.3091 .64379 m .31195 .64684 L .31146 .64502 L F
.69 .4 0 r
.31214 .64744 m .31305 .65057 L .31195 .64684 L F
0 .116 .662 r
.3091 .64379 m .31173 .64695 L .31195 .64684 L F
.65 .585 .768 r
.31195 .64684 m .30954 .64955 L .30863 .64721 L F
0 .116 .662 r
.31173 .64695 m .31214 .64744 L .31195 .64684 L F
.65 .585 .768 r
.31195 .64684 m .31305 .65057 L .30954 .64955 L F
0 0 0 r
.31223 .64669 m .31195 .64684 L .31009 .64866 L F
.31366 .64536 m .31195 .64684 L .31223 .64669 L F
.965 .858 .685 r
.37937 .6139 m .38128 .61508 L .37991 .61727 L F
.978 .909 .667 r
.33175 .62889 m .33305 .62892 L .33181 .63085 L F
.33163 .625 m .33305 .62892 L .33175 .62889 L F
.33163 .625 m .33181 .63085 L .33209 .6294 L F
.693 .153 0 r
.33209 .6294 m .33015 .62968 L .32991 .62885 L F
.33123 .62888 m .32991 .62885 L .32964 .62793 L F
.33209 .6294 m .32991 .62885 L .33123 .62888 L F
.978 .909 .667 r
.33163 .625 m .33356 .62813 L .33305 .62892 L F
.155 0 .137 r
.33181 .63085 m .33356 .62813 L .33618 .62716 L F
0 0 .062 r
.37965 .49111 m .38177 .48729 L .38214 .48767 L F
.379 .018 .221 r
.42678 .54195 m .42398 .54304 L .42445 .54081 L F
.681 .581 .736 r
.35705 .56988 m .35453 .57274 L .35312 .56798 L F
.461 .888 .828 r
.43572 .49806 m .43674 .4971 L .43915 .49661 L F
.416 .856 .92 r
.43437 .49783 m .43674 .4971 L .43572 .49806 L F
.442 .814 .993 r
.24237 .52405 m .2437 .52304 L .24909 .52394 L F
.742 .768 .265 r
.24271 .52671 m .2437 .52304 L .24237 .52405 L F
.556 .005 0 r
.42076 .49482 m .42354 .49631 L .42608 .49569 L F
.908 .979 .783 r
.42815 .49254 m .42608 .49569 L .42607 .49318 L F
.897 .979 .808 r
.42608 .49569 m .42354 .49631 L .42607 .49318 L F
.613 .47 .663 r
.35097 .60206 m .35095 .6048 L .35247 .60286 L F
.35097 .60206 m .35095 .6048 L .35247 .60286 L F
.944 .581 .241 r
.39988 .53018 m .39814 .529 L .39766 .52669 L F
.921 .528 .173 r
.4008 .53324 m .39814 .529 L .39988 .53018 L F
0 0 0 r
.47902 .56653 m .47945 .56538 L .4784 .56891 L F
.199 0 .049 r
.33209 .55249 m .33442 .55173 L .33564 .54933 L F
.059 0 0 r
.33564 .54933 m .3365 .55072 L .33778 .54885 L F
.33564 .54933 m .33442 .55173 L .3365 .55072 L F
.52 .867 .614 r
.53017 .44426 m .52923 .44514 L .52797 .44555 L F
.806 .947 .599 r
.3079 .63621 m .3078 .63742 L .30551 .63946 L F
.653 .876 .982 r
.44149 .45144 m .44379 .45029 L .4455 .45147 L F
.68 .892 .975 r
.44718 .44915 m .4455 .45147 L .44379 .45029 L F
.44718 .44915 m .44892 .44964 L .4455 .45147 L F
.389 .7 .983 r
.44001 .54844 m .44142 .54827 L .44102 .54986 L F
.991 .731 .41 r
.43903 .5495 m .44102 .54986 L .44142 .54827 L F
.43903 .5495 m .44103 .55297 L .44102 .54986 L F
.977 .739 .508 r
.32624 .52111 m .32471 .52268 L .32443 .52002 L F
.728 .892 .954 r
.32769 .51893 m .32443 .52002 L .32624 .52111 L F
.935 .716 .237 r
.40747 .55298 m .407 .5528 L .40709 .54954 L F
.949 .61 .207 r
.40747 .55298 m .40616 .5536 L .407 .5528 L F
.40747 .55298 m .40834 .55659 L .40616 .5536 L F
.573 .567 .808 r
.60095 .35891 m .60244 .3541 L .59975 .35473 L F
.60095 .35891 m .6036 .35816 L .60244 .3541 L F
.601 .873 .544 r
.24917 .52456 m .24781 .52591 L .24673 .52733 L F
0 0 0 r
.24781 .52591 m .24453 .52975 L .24673 .52733 L F
.858 .997 .793 r
.41213 .51203 m .41485 .51098 L .41305 .5105 L F
.439 .238 .509 r
.41637 .50663 m .41305 .5105 L .41485 .51098 L F
.262 0 .041 r
.41453 .51021 m .41213 .51203 L .41305 .5105 L F
.439 .238 .509 r
.41604 .50829 m .41485 .51098 L .41595 .50872 L F
.41559 .50886 m .41485 .51098 L .41604 .50829 L F
.262 0 .041 r
.41609 .5099 m .41381 .51113 L .41453 .51021 L F
.41381 .51113 m .41213 .51203 L .41453 .51021 L F
.439 .238 .509 r
.41637 .50663 m .41559 .50886 L .41604 .50829 L F
.997 .838 .497 r
.41123 .58246 m .4097 .58391 L .41034 .58046 L F
.41123 .58246 m .41064 .58511 L .4097 .58391 L F
.347 .701 .984 r
.28861 .65347 m .28792 .65452 L .28718 .65226 L F
.571 .928 .943 r
.68029 .37519 m .68212 .37527 L .68456 .37407 L F
.355 .212 .544 r
.49342 .52005 m .49135 .52354 L .49086 .52103 L F
.752 .376 .341 r
.67793 .35826 m .68096 .35855 L .68026 .36035 L F
.505 .544 .83 r
.33243 .65675 m .335 .65853 L .33403 .65873 L F
.33243 .65675 m .33403 .65873 L .33417 .65597 L F
.676 .925 .972 r
.42942 .46361 m .42861 .4656 L .43114 .4643 L F
.772 .997 .835 r
.42942 .46361 m .42776 .46533 L .42861 .4656 L F
.466 .22 .456 r
.50393 .50418 m .50103 .50708 L .50148 .50509 L F
.693 .798 .93 r
.64713 .3735 m .64493 .37507 L .64375 .37322 L F
.64375 .37322 m .64493 .37507 L .64713 .3735 L F
.191 .233 .676 r
.34694 .52496 m .34777 .52285 L .34581 .52446 L F
.34694 .52496 m .34882 .52559 L .34777 .52285 L F
.34694 .52496 m .34748 .527 L .34882 .52559 L F
.239 .619 .956 r
.23456 .61048 m .23411 .60925 L .23253 .60963 L F
.23456 .61048 m .2367 .61072 L .23411 .60925 L F
.749 .549 .625 r
.36877 .54664 m .36879 .54984 L .36526 .54942 L F
.119 0 0 r
.45034 .59481 m .45128 .59526 L .44881 .59564 L F
.216 .738 .839 r
.45036 .59531 m .44881 .59564 L .45128 .59526 L F
.495 .905 .844 r
.44718 .59597 m .45034 .59481 L .44881 .59564 L F
.216 .738 .839 r
.44724 .59549 m .44881 .59564 L .45036 .59531 L F
.495 .905 .844 r
.44538 .59664 m .44718 .59597 L .44881 .59564 L F
.119 0 0 r
.45034 .59481 m .45288 .59469 L .45128 .59526 L F
.74 .467 .516 r
.31221 .66272 m .31308 .65957 L .31194 .65927 L F
.208 .691 .93 r
.31308 .65957 m .31444 .65913 L .31194 .65927 L F
.31308 .65957 m .31593 .65994 L .31444 .65913 L F
.31444 .65913 m .31593 .65994 L .31308 .65957 L F
.31444 .65913 m .31308 .65957 L .31221 .66272 L F
.98 .784 .372 r
.55374 .42688 m .55457 .42656 L .55429 .42625 L F
.55374 .42688 m .55451 .43068 L .55457 .42656 L F
.708 .721 .199 r
.42487 .55465 m .42526 .5534 L .42457 .55178 L F
.66 .295 0 r
.42463 .55418 m .42485 .55465 L .42487 .55465 L F
.708 .721 .199 r
.42487 .55465 m .42455 .55615 L .42494 .55466 L F
0 0 .552 r
.42592 .55691 m .42455 .55615 L .42487 .55465 L F
.66 .295 0 r
.42485 .55465 m .42592 .55691 L .42487 .55465 L F
.708 .721 .199 r
.42487 .55465 m .42494 .55466 L .42526 .5534 L F
.988 .736 .455 r
.41067 .56604 m .40883 .56732 L .40927 .56513 L F
.41067 .56604 m .41049 .56894 L .40883 .56732 L F
.4 .145 .408 r
.34799 .6074 m .34504 .61082 L .34504 .60789 L F
.697 .377 .43 r
.69735 .31989 m .69347 .322 L .69346 .31936 L F
.69735 .31989 m .69723 .32221 L .69347 .322 L F
.58 .088 0 r
.69735 .31989 m .70029 .32316 L .70035 .32209 L F
.635 .324 .427 r
.69735 .31989 m .70035 .32209 L .69723 .32221 L F
0 0 0 r
.67268 .32428 m .67123 .32435 L .67362 .32307 L F
.67268 .32428 m .66999 .32526 L .67123 .32435 L F
.742 .992 .829 r
.61343 .43404 m .61416 .43469 L .61262 .43481 L F
0 0 0 r
.61416 .43469 m .61554 .4344 L .61262 .43481 L F
.61416 .43469 m .61719 .4335 L .61554 .4344 L F
.858 .997 .793 r
.41213 .51203 m .41205 .5141 L .41485 .51098 L F
.541 .317 .524 r
.41205 .5141 m .41476 .51383 L .41485 .51098 L F
.471 .261 .512 r
.41485 .51098 m .41738 .5131 L .41758 .51039 L F
.41485 .51098 m .41476 .51383 L .41738 .5131 L F
.824 .694 .721 r
.32654 .55553 m .32958 .55283 L .32639 .55308 L F
.481 0 0 r
.4227 .5924 m .42235 .59203 L .42068 .59084 L F
.42068 .59084 m .42235 .59203 L .4227 .5924 L F
.66 .473 .62 r
.42222 .48136 m .4247 .47863 L .42046 .47896 L F
.105 .017 .462 r
.48697 .53847 m .48502 .54275 L .48533 .54015 L F
.197 0 0 r
.43064 .51045 m .43402 .50993 L .43501 .5087 L F
0 0 0 r
.43501 .5087 m .43532 .50872 L .43705 .50718 L F
.43501 .5087 m .43402 .50993 L .43532 .50872 L F
.766 .955 .639 r
.33764 .51415 m .33551 .51591 L .33516 .51733 L F
.072 0 0 r
.34045 .51094 m .34097 .51119 L .33845 .51164 L F
.162 0 0 r
.33961 .51125 m .34223 .51082 L .3428 .51012 L F
.567 .906 .677 r
.34443 .50842 m .34376 .509 L .3428 .51012 L F
.162 0 0 r
.33961 .51125 m .3428 .51012 L .34035 .51075 L F
.072 0 0 r
.3428 .51012 m .34052 .51092 L .34035 .51075 L F
.34052 .51092 m .33845 .51164 L .33938 .51121 L F
.34052 .51092 m .33938 .51121 L .34035 .51075 L F
.567 .906 .677 r
.34389 .50886 m .34181 .5107 L .3428 .51012 L F
.072 0 0 r
.3428 .51012 m .34181 .5107 L .34052 .51092 L F
.101 .279 .758 r
.33845 .51164 m .33613 .51025 L .34035 .51075 L F
.522 0 0 r
.33613 .51025 m .33961 .51125 L .34035 .51075 L F
.534 .526 .792 r
.33975 .50494 m .34208 .51046 L .33961 .51107 L F
.34208 .51046 m .3421 .51052 L .34199 .51054 L F
.34208 .51046 m .34199 .51054 L .33961 .51107 L F
.3421 .51052 m .34216 .51064 L .34052 .51092 L F
.3421 .51052 m .34052 .51092 L .33961 .51107 L F
.329 .515 .888 r
.34443 .50842 m .34489 .51068 L .3428 .51012 L F
.34443 .50842 m .34489 .51068 L .3428 .51012 L F
0 0 0 r
.3428 .51012 m .34223 .51082 L .34443 .50842 L F
.581 .551 .786 r
.34443 .50842 m .34223 .51082 L .34208 .51046 L F
.34443 .50842 m .34208 .51046 L .33975 .50494 L F
.567 .906 .677 r
.34443 .50842 m .34389 .50886 L .34376 .509 L F
.534 .526 .792 r
.34216 .51064 m .34223 .51082 L .33961 .51107 L F
.567 .906 .677 r
.34389 .50886 m .34097 .51119 L .34181 .5107 L F
.534 .526 .792 r
.33961 .51107 m .3416 .51088 L .33961 .51125 L F
.3416 .51088 m .34223 .51082 L .34154 .51094 L F
.3416 .51088 m .34154 .51094 L .33961 .51125 L F
.072 0 0 r
.34052 .51092 m .34176 .51072 L .34045 .51094 L F
.34181 .5107 m .34176 .51072 L .34052 .51092 L F
.34176 .51072 m .34097 .51119 L .34045 .51094 L F
.523 .569 .844 r
.337 .50582 m .33953 .51109 L .33613 .51025 L F
.33953 .51109 m .33961 .51125 L .33923 .51114 L F
.33953 .51109 m .33923 .51114 L .33613 .51025 L F
.387 .814 .966 r
.34097 .51119 m .33914 .51115 L .33845 .51164 L F
.101 .279 .758 r
.33845 .51164 m .33706 .51264 L .33613 .51025 L F
.387 .814 .966 r
.33914 .51115 m .33678 .51111 L .33845 .51164 L F
.101 .279 .758 r
.33845 .51164 m .33764 .51415 L .33706 .51264 L F
.81 .964 .645 r
.33845 .51164 m .33551 .51591 L .33764 .51415 L F
.857 .76 .754 r
.42475 .48156 m .42673 .4812 L .42726 .48134 L F
.42673 .4812 m .42475 .48156 L .42726 .48134 L F
.301 0 0 r
.58017 .4272 m .58212 .42679 L .57783 .42654 L F
.867 .995 .796 r
.58223 .42514 m .58212 .42679 L .58017 .4272 L F
.61 .822 .982 r
.41511 .46947 m .41971 .46988 L .41791 .46855 L F
.703 .862 .957 r
.41791 .46855 m .41971 .46988 L .42205 .46854 L F
.972 .77 .572 r
.59172 .41865 m .59344 .4231 L .59351 .42032 L F
.74 .653 .763 r
.35174 .63989 m .35303 .6449 L .35459 .64015 L F
.584 .828 .991 r
.35496 .64342 m .35708 .64365 L .35691 .6437 L F
.35496 .64342 m .35691 .6437 L .35303 .6449 L F
.35496 .64342 m .35326 .64488 L .35328 .6449 L F
.35326 .64488 m .35158 .64632 L .35328 .6449 L F
0 0 0 r
.35331 .64492 m .35328 .6449 L .35198 .64694 L F
.584 .828 .991 r
.35496 .64342 m .35328 .6449 L .35226 .64303 L F
0 0 0 r
.35429 .64345 m .35328 .6449 L .35331 .64492 L F
.584 .828 .991 r
.35496 .64342 m .35226 .64303 L .35199 .64253 L F
.35496 .64342 m .35303 .6449 L .35158 .64632 L F
.828 .861 .871 r
.59304 .35773 m .59457 .35923 L .59655 .35743 L F
.543 .435 .681 r
.6776 .33944 m .68011 .3363 L .67628 .33539 L F
.6776 .33944 m .68031 .33868 L .68011 .3363 L F
0 .14 .589 r
.26456 .62776 m .26904 .63105 L .26733 .62982 L F
.652 .127 0 r
.26733 .62982 m .26904 .63105 L .27093 .63323 L F
.406 .694 .979 r
.33978 .56949 m .34064 .5676 L .33818 .56814 L F
.33978 .56949 m .34278 .56924 L .34064 .5676 L F
.864 .909 .861 r
.47523 .43577 m .47114 .43773 L .47434 .43501 L F
.768 .979 .914 r
.47523 .43577 m .47743 .43267 L .47878 .43359 L F
.47523 .43577 m .47434 .43501 L .47743 .43267 L F
.474 .769 .995 r
.43271 .48489 m .43578 .48422 L .43378 .48322 L F
.673 .966 .763 r
.43378 .48322 m .43199 .48493 L .43271 .48489 L F
.582 .916 .692 r
.63664 .33657 m .63698 .33571 L .63882 .33501 L F
.63664 .33657 m .63519 .33729 L .63698 .33571 L F
.067 .615 .836 r
.32917 .56653 m .32756 .56604 L .32514 .56594 L F
.617 .958 .884 r
.42452 .45471 m .42328 .45628 L .42168 .45544 L F
.42452 .45471 m .42553 .45492 L .42328 .45628 L F
0 0 0 r
.36988 .5533 m .37105 .55135 L .37101 .55413 L F
.36988 .5533 m .37051 .55346 L .37105 .55135 L F
.945 .792 .661 r
.6729 .3447 m .67278 .34547 L .67086 .34448 L F
.371 .253 .586 r
.67527 .34375 m .6729 .3447 L .67502 .34245 L F
.67527 .34375 m .67278 .34547 L .6729 .3447 L F
.502 .674 .941 r
.30282 .64607 m .30517 .64553 L .302 .64414 L F
.742 .468 .516 r
.30896 .66203 m .31194 .65927 L .31006 .65874 L F
.30896 .66203 m .31221 .66272 L .31194 .65927 L F
.117 .654 .854 r
.31006 .65874 m .31194 .65927 L .31444 .65913 L F
.465 .86 .668 r
.37605 .68858 m .37822 .68717 L .37688 .68776 L F
.974 .82 .406 r
.37688 .68776 m .37822 .68717 L .37817 .68558 L F
.771 .84 .904 r
.44806 .48425 m .4454 .48582 L .44677 .48587 L F
.811 .645 .677 r
.45007 .50136 m .44743 .50133 L .44865 .50025 L F
.721 .319 .287 r
.45007 .50136 m .4486 .50285 L .44743 .50133 L F
.11 0 0 r
.45146 .50181 m .4486 .50285 L .45007 .50136 L F
.941 .895 .497 r
.27762 .6518 m .27817 .65361 L .27719 .65619 L F
.755 .792 .883 r
.4588 .51122 m .46233 .5113 L .46172 .5099 L F
.148 .639 .917 r
.4651 .51073 m .46172 .5099 L .46233 .5113 L F
.02 .129 .638 r
.46327 .51435 m .46397 .51272 L .46233 .5113 L F
.471 .098 .25 r
.46397 .51272 m .4651 .51073 L .46233 .5113 L F
.739 .697 .811 r
.68908 .34782 m .68549 .34814 L .68804 .34505 L F
.735 .219 0 r
.36263 .50981 m .36699 .51256 L .36426 .51123 L F
.716 .988 .842 r
.46634 .44137 m .46422 .44312 L .46527 .44119 L F
.682 .965 .934 r
.46527 .44119 m .46422 .44312 L .46308 .4427 L F
.666 .726 .894 r
.34537 .68882 m .34947 .68994 L .34814 .68791 L F
.571 .632 .873 r
.34947 .68994 m .352 .68935 L .34814 .68791 L F
.804 .984 .892 r
.35471 .64818 m .35437 .65035 L .35591 .64848 L F
.824 .993 .861 r
.35309 .65007 m .35437 .65035 L .35471 .64818 L F
.884 .875 .437 r
.70029 .32316 m .69939 .32449 L .70035 .32209 L F
0 0 0 r
.23882 .61341 m .23865 .61562 L .24072 .61384 L F
.23882 .61341 m .23805 .61767 L .23865 .61562 L F
.482 .085 .211 r
.34294 .59841 m .34182 .60062 L .33894 .6007 L F
.737 .643 .756 r
.34305 .60005 m .34182 .60062 L .34294 .59841 L F
.415 .35 .676 r
.34579 .60089 m .34366 .60176 L .34294 .59841 L F
.34579 .60089 m .34294 .59841 L .34305 .60005 L F
0 0 .063 r
.34762 .52995 m .34882 .52559 L .34748 .527 L F
.918 .537 .27 r
.59994 .43588 m .59714 .43272 L .59934 .43496 L F
.919 .712 .606 r
.59688 .43827 m .59994 .43588 L .59934 .43496 L F
.531 .101 .169 r
.29179 .57132 m .2945 .57151 L .29612 .5692 L F
.131 0 0 r
.29612 .5692 m .29672 .57062 L .29855 .5691 L F
.29612 .5692 m .2945 .57151 L .29672 .57062 L F
.181 .273 .723 r
.22953 .57281 m .22961 .57627 L .22831 .57178 L F
.23063 .57374 m .23039 .57434 L .22953 .57281 L F
.23039 .57434 m .22961 .57627 L .22953 .57281 L F
.797 .534 .541 r
.23198 .56909 m .22952 .5728 L .22945 .5694 L F
.22952 .5728 m .22947 .57287 L .22947 .57271 L F
.22952 .5728 m .22947 .57271 L .22945 .5694 L F
0 0 0 r
.23319 .56801 m .22953 .5728 L .23198 .56909 L F
.22953 .5728 m .22952 .5728 L .23198 .56909 L F
.464 .267 .528 r
.22945 .5694 m .22947 .57275 L .22831 .57178 L F
.959 .631 .348 r
.22953 .5728 m .22952 .5728 L .22831 .57178 L F
.464 .267 .528 r
.22947 .57275 m .22947 .57287 L .22831 .57178 L F
.975 .726 .309 r
.22945 .5694 m .22947 .57275 L .22834 .57024 L F
.959 .631 .348 r
.22834 .57024 m .22926 .57228 L .22831 .57178 L F
.975 .726 .309 r
.22947 .57275 m .22947 .57287 L .22834 .57024 L F
0 0 0 r
.22953 .5728 m .22947 .57287 L .22952 .5728 L F
.866 .849 .824 r
.22834 .57024 m .22947 .57287 L .22953 .5728 L F
.22834 .57024 m .22953 .5728 L .23319 .56801 L F
.959 .631 .348 r
.22989 .57261 m .22953 .5728 L .22953 .5728 L F
.2293 .5723 m .22953 .5728 L .22831 .57178 L F
.22989 .57261 m .22953 .5728 L .2293 .5723 L F
.22834 .57024 m .22989 .57261 L .22926 .57228 L F
.22989 .57261 m .23063 .57374 L .22952 .5728 L F
.871 .587 .063 r
.60989 .39376 m .6097 .3911 L .60865 .38915 L F
.733 .919 .956 r
.52389 .43847 m .53093 .43802 L .52872 .4347 L F
.891 .485 .236 r
.36853 .5139 m .36966 .51701 L .37193 .51792 L F
.85 .398 .125 r
.36966 .51701 m .37058 .51884 L .37193 .51792 L F
.724 .211 0 r
.37193 .51792 m .37058 .51884 L .37335 .51947 L F
0 0 0 r
.46775 .54833 m .46528 .54588 L .46641 .54748 L F
.423 .348 .668 r
.46641 .54748 m .46793 .54994 L .46775 .54833 L F
0 0 0 r
.43285 .46927 m .43049 .47218 L .43193 .47041 L F
.359 .403 .771 r
.43049 .47218 m .4326 .47376 L .43193 .47041 L F
.453 .747 .992 r
.32964 .51266 m .33178 .51223 L .33114 .51411 L F
.32964 .51266 m .33178 .51223 L .33114 .51411 L F
.68 .965 .748 r
.64838 .39602 m .64695 .398 L .64883 .39628 L F
.687 .978 .812 r
.64489 .39867 m .64695 .398 L .64838 .39602 L F
.174 0 0 r
.30686 .57279 m .30486 .57413 L .30236 .57444 L F
.527 .005 0 r
.30901 .57427 m .30486 .57413 L .30686 .57279 L F
.77 .957 .932 r
.38226 .67556 m .3871 .67407 L .3841 .6739 L F
.81 .919 .911 r
.3841 .6739 m .3871 .67407 L .38898 .67235 L F
.869 .751 .241 r
.23393 .59606 m .23418 .59808 L .23466 .59521 L F
.223 0 0 r
.2437 .52304 m .24799 .52083 L .24909 .52394 L F
.525 .761 .983 r
.66178 .35054 m .66341 .35241 L .6606 .35155 L F
.809 .494 .457 r
.6606 .35155 m .66341 .35241 L .66348 .35508 L F
.799 .69 .744 r
.66178 .35054 m .666 .34859 L .66341 .35241 L F
.597 .536 .757 r
.666 .34859 m .66626 .35235 L .66341 .35241 L F
.568 .3 .47 r
.66341 .35241 m .66626 .35235 L .66348 .35508 L F
.501 .11 .23 r
.66341 .35241 m .66606 .35401 L .66348 .35508 L F
.66341 .35241 m .66626 .35235 L .66606 .35401 L F
.797 .885 .462 r
.33654 .60702 m .33511 .6109 L .33567 .60835 L F
.796 .769 .26 r
.43118 .52344 m .43128 .52449 L .4319 .52215 L F
.43118 .52344 m .4308 .52611 L .43128 .52449 L F
.096 .17 .652 r
.61246 .37623 m .61185 .37811 L .61133 .37439 L F
.308 0 .033 r
.61361 .37926 m .61453 .37766 L .61185 .37811 L F
.61361 .37926 m .61185 .37811 L .61246 .37623 L F
.438 .788 .997 r
.67379 .34426 m .67278 .34547 L .67086 .34448 L F
.919 .708 .6 r
.56479 .40984 m .56613 .41326 L .5642 .41299 L F
.892 .56 .411 r
.5642 .41299 m .56613 .41326 L .56453 .41536 L F
.74 .341 .296 r
.56613 .41326 m .56854 .41595 L .56453 .41536 L F
.245 .041 .392 r
.44535 .47784 m .44724 .47626 L .44643 .47632 L F
.805 .748 .799 r
.44717 .47785 m .44821 .47699 L .44729 .47511 L F
.44833 .47723 m .44942 .47598 L .44884 .47574 L F
.44833 .47723 m .44884 .47574 L .44729 .47511 L F
.032 0 0 r
.44942 .47598 m .4491 .47613 L .44846 .47618 L F
.4491 .47613 m .44714 .47705 L .44846 .47618 L F
.245 .041 .392 r
.44643 .47632 m .44724 .47626 L .44729 .47511 L F
.032 0 0 r
.44942 .47598 m .44632 .47661 L .44729 .47511 L F
.962 .793 .625 r
.45086 .47197 m .45009 .47485 L .4524 .47365 L F
.478 .276 .527 r
.45086 .47197 m .45105 .47423 L .45009 .47485 L F
.477 .074 .196 r
.4483 .47651 m .45163 .47415 L .44942 .47598 L F
.44714 .47705 m .45009 .47485 L .4524 .47365 L F
.478 .276 .527 r
.45105 .47423 m .45113 .47508 L .45026 .47489 L F
.45105 .47423 m .45026 .47489 L .45009 .47485 L F
.477 .074 .196 r
.44714 .47705 m .44944 .47557 L .4483 .47651 L F
.44944 .47557 m .45163 .47415 L .4483 .47651 L F
.45163 .47415 m .4524 .47365 L .44942 .47598 L F
.805 .748 .799 r
.44714 .47858 m .44833 .47723 L .44821 .47699 L F
.44714 .47858 m .44821 .47699 L .44717 .47785 L F
.623 .353 .488 r
.44714 .47858 m .44798 .48127 L .45033 .47969 L F
.672 .435 .553 r
.45033 .47969 m .44798 .48127 L .44745 .47978 L F
.245 .041 .392 r
.44535 .47784 m .44714 .47858 L .44719 .47732 L F
.44535 .47784 m .44719 .47732 L .44654 .47685 L F
.805 .748 .799 r
.44784 .47779 m .44985 .47639 L .44833 .47723 L F
.44714 .47858 m .44798 .4779 L .44784 .47779 L F
.44798 .4779 m .44985 .47639 L .44784 .47779 L F
.44864 .47844 m .45166 .47814 L .44798 .4779 L F
.623 .353 .488 r
.45044 .47826 m .45033 .47969 L .45166 .47814 L F
.44714 .47858 m .45033 .47969 L .45044 .47826 L F
.805 .748 .799 r
.44798 .4779 m .45166 .47814 L .44985 .47639 L F
0 0 .394 r
.45088 .47788 m .45024 .48091 L .45033 .47969 L F
.45024 .48091 m .44985 .48271 L .45033 .47969 L F
.672 .435 .553 r
.4478 .47775 m .44763 .47761 L .44911 .47868 L F
.245 .041 .392 r
.44654 .47685 m .44719 .47732 L .44724 .47626 L F
.672 .435 .553 r
.44763 .47761 m .44632 .47661 L .44713 .47721 L F
.44763 .47761 m .44713 .47721 L .44911 .47868 L F
.805 .748 .799 r
.44714 .47858 m .44864 .47844 L .44798 .4779 L F
.672 .435 .553 r
.44808 .47796 m .44745 .47978 L .44683 .47805 L F
.45033 .47969 m .44745 .47978 L .44808 .47796 L F
.45033 .47969 m .4478 .47775 L .44911 .47868 L F
.598 .207 .273 r
.44857 .47903 m .44926 .47869 L .44711 .47817 L F
.805 .748 .799 r
.44833 .47723 m .44985 .47639 L .44942 .47598 L F
.753 .746 .846 r
.44942 .47598 m .45166 .47814 L .45386 .47707 L F
.44942 .47598 m .45386 .47707 L .4524 .47365 L F
0 0 .056 r
.45113 .47508 m .45033 .47969 L .44714 .47705 L F
.4511 .47524 m .45088 .47788 L .45033 .47969 L F
.45113 .47508 m .45088 .47788 L .4511 .47524 L F
1 .824 .516 r
.45033 .47969 m .45143 .48106 L .45166 .47814 L F
0 0 .394 r
.45088 .47788 m .45115 .48109 L .44985 .48271 L F
.788 .532 .55 r
.44857 .47903 m .45065 .48069 L .45088 .47788 L F
.45065 .48069 m .45115 .48109 L .45088 .47788 L F
.598 .207 .273 r
.44926 .47869 m .45088 .47788 L .44844 .47807 L F
.44926 .47869 m .44844 .47807 L .44711 .47817 L F
.672 .435 .553 r
.44911 .47868 m .44713 .47721 L .44714 .4771 L F
.44778 .47758 m .44714 .4771 L .44714 .47705 L F
.44911 .47868 m .44714 .4771 L .44778 .47758 L F
.44713 .47721 m .44632 .47661 L .44652 .47672 L F
.44713 .47721 m .44652 .47672 L .44714 .47705 L F
.44763 .47761 m .44683 .47805 L .44632 .47661 L F
.44808 .47796 m .44683 .47805 L .44763 .47761 L F
.032 0 0 r
.44846 .47618 m .44714 .47705 L .44632 .47661 L F
.185 .107 .529 r
.44535 .47784 m .44798 .48127 L .44714 .47858 L F
.009 .064 .571 r
.44632 .47661 m .44798 .48127 L .44535 .47784 L F
.18 0 .352 r
.31146 .64502 m .31366 .64536 L .31435 .64297 L F
.31146 .64502 m .31195 .64684 L .31366 .64536 L F
.044 .088 .584 r
.55256 .40803 m .55076 .4077 L .55347 .40689 L F
.55256 .40803 m .55128 .41038 L .55076 .4077 L F
.542 .415 .657 r
.33551 .51934 m .33791 .51691 L .33516 .51733 L F
.33551 .51934 m .33884 .51914 L .33791 .51691 L F
.56 .355 .56 r
.33551 .51934 m .33837 .52267 L .33884 .51914 L F
.33551 .51934 m .33529 .52339 L .33837 .52267 L F
.594 .359 .53 r
.52707 .4818 m .5271 .4842 L .52334 .48505 L F
.604 .353 .51 r
.52707 .4818 m .52955 .48396 L .5271 .4842 L F
.52707 .4818 m .52966 .48156 L .52955 .48396 L F
.953 .761 .305 r
.53676 .45764 m .53753 .46037 L .53712 .45533 L F
.873 .897 .846 r
.53449 .46127 m .53753 .46037 L .53676 .45764 L F
.918 .94 .803 r
.53624 .46179 m .53753 .46037 L .53449 .46127 L F
.477 0 0 r
.302 .64414 m .30283 .64451 L .30265 .64526 L F
.30283 .64451 m .30517 .64553 L .30265 .64526 L F
.694 .225 .134 r
.30265 .64526 m .30607 .64785 L .30172 .64728 L F
.30265 .64526 m .30172 .64728 L .30249 .64591 L F
.174 .705 .847 r
.30265 .64526 m .30517 .64553 L .30693 .64532 L F
.689 .254 .211 r
.30265 .64526 m .30693 .64532 L .30607 .64785 L F
.694 .225 .134 r
.30265 .64526 m .30249 .64591 L .30377 .64365 L F
.477 0 0 r
.302 .64414 m .30265 .64526 L .30305 .64222 L F
.608 .868 .526 r
.67621 .30635 m .67794 .30404 L .6795 .30364 L F
.67621 .30635 m .67642 .30591 L .67794 .30404 L F
.294 .789 .767 r
.43915 .49661 m .43901 .49644 L .44082 .49407 L F
.43915 .49661 m .43674 .4971 L .43901 .49644 L F
.658 .597 .775 r
.36203 .55239 m .36043 .55546 L .36045 .55333 L F
.913 .978 .708 r
.37358 .69244 m .37605 .68858 L .37469 .68916 L F
.465 .86 .668 r
.37605 .68858 m .37688 .68776 L .37469 .68916 L F
.782 .287 .03 r
.35934 .50847 m .36073 .50728 L .35872 .50651 L F
.35934 .50847 m .36263 .50981 L .36073 .50728 L F
.964 .669 .254 r
.60597 .42037 m .60489 .42187 L .6042 .41876 L F
.60597 .42037 m .60559 .42217 L .60489 .42187 L F
.984 .808 .408 r
.23204 .58769 m .23085 .58518 L .23544 .58618 L F
.23204 .58769 m .23123 .58797 L .23085 .58518 L F
.422 .867 .824 r
.60843 .34782 m .61007 .34673 L .61113 .34708 L F
.60843 .34782 m .60753 .34784 L .61007 .34673 L F
.796 .33 .129 r
.70157 .3068 m .70341 .30895 L .70528 .30946 L F
.11 .255 .733 r
.70417 .3072 m .70341 .30895 L .70157 .3068 L F
.564 .109 0 r
.58673 .39975 m .58543 .39805 L .58409 .39632 L F
.752 .988 .775 r
.56931 .4445 m .57323 .44644 L .56909 .44617 L F
.614 .794 .968 r
.25434 .55521 m .25606 .55693 L .2586 .55583 L F
.2586 .55583 m .25606 .55693 L .25434 .55521 L F
.25434 .55521 m .25606 .55693 L .2586 .55583 L F
.664 .927 .973 r
.591 .35362 m .58603 .35503 L .58735 .35286 L F
0 0 0 r
.58735 .35286 m .5922 .3518 L .591 .35362 L F
.412 .607 .928 r
.57228 .38561 m .56935 .38592 L .5681 .38342 L F
0 0 .179 r
.616 .3891 m .61465 .39117 L .61423 .39441 L F
0 0 0 r
.30603 .56662 m .30471 .56823 L .30752 .56524 L F
.731 .301 .228 r
.67379 .34426 m .67502 .34245 L .67156 .34197 L F
.597 .165 .192 r
.67502 .34245 m .67773 .34413 L .67527 .34375 L F
.601 .149 .15 r
.67379 .34426 m .67773 .34413 L .67502 .34245 L F
.63 .475 .655 r
.29709 .5083 m .29672 .51091 L .29918 .50753 L F
.578 .311 .474 r
.3653 .55184 m .36243 .55004 L .36526 .54942 L F
.3653 .55184 m .36203 .55239 L .36243 .55004 L F
.901 .486 .12 r
.36751 .51474 m .36853 .5139 L .36699 .51256 L F
.36751 .51474 m .36966 .51701 L .36853 .5139 L F
.448 .309 .598 r
.43285 .46927 m .43517 .47076 L .43515 .46815 L F
.613 .151 .132 r
.43193 .47041 m .43517 .47076 L .43285 .46927 L F
.804 .791 .841 r
.55951 .43302 m .56169 .4321 L .56209 .42959 L F
.601 .6 .822 r
.56209 .42959 m .56169 .4321 L .56378 .42911 L F
0 0 .001 r
.3396 .53682 m .34105 .53635 L .34215 .5337 L F
.579 .588 .826 r
.33947 .53969 m .34105 .53635 L .3396 .53682 L F
0 0 0 r
.34055 .53657 m .3396 .53682 L .34105 .53635 L F
.34055 .53657 m .33756 .5383 L .3396 .53682 L F
0 0 .001 r
.3396 .53682 m .34105 .53635 L .34215 .5337 L F
.723 .57 .682 r
.44492 .4974 m .44228 .5007 L .44236 .498 L F
0 0 .487 r
.23053 .60791 m .23064 .60679 L .22897 .60418 L F
0 .164 .698 r
.23053 .60791 m .23253 .60963 L .23064 .60679 L F
.473 .749 .99 r
.3404 .53097 m .34103 .53195 L .34047 .53072 L F
.34103 .53195 m .34215 .5337 L .34126 .53214 L F
.34103 .53195 m .34126 .53214 L .34047 .53072 L F
.3404 .53097 m .34404 .53217 L .34215 .5337 L F
.391 .729 .99 r
.3404 .53097 m .34502 .53154 L .34404 .53217 L F
0 .534 .743 r
.34086 .53099 m .34502 .53154 L .3404 .53097 L F
.855 .906 .496 r
.33962 .53467 m .34086 .53099 L .34023 .5313 L F
.33962 .53467 m .33945 .53406 L .34057 .53161 L F
.34063 .53165 m .34057 .53161 L .34086 .53099 L F
.33962 .53467 m .34057 .53161 L .34063 .53165 L F
.512 .138 .268 r
.34215 .5337 m .34426 .53545 L .3449 .53323 L F
.34426 .53545 m .34215 .5337 L .34404 .53217 L F
.34426 .53545 m .34105 .53635 L .34215 .5337 L F
.34215 .5337 m .34105 .53635 L .34426 .53545 L F
.828 .861 .871 r
.59304 .35773 m .59655 .35743 L .59562 .35475 L F
.795 .834 .881 r
.59562 .35475 m .59655 .35743 L .59975 .35473 L F
.622 .101 0 r
.60671 .42662 m .61002 .42981 L .60868 .43021 L F
.435 0 0 r
.60868 .43021 m .61002 .42981 L .60933 .43085 L F
.778 .278 .003 r
.61002 .42981 m .61343 .43404 L .60933 .43085 L F
0 0 0 r
.69117 .37133 m .69472 .36903 L .69356 .37028 L F
0 0 .091 r
.69472 .36903 m .69637 .36504 L .69591 .36723 L F
.701 .919 .583 r
.69356 .37028 m .69472 .36903 L .69591 .36723 L F
0 0 .008 r
.46296 .51645 m .46397 .51272 L .46327 .51435 L F
.106 .486 .899 r
.28077 .65727 m .28561 .65893 L .28388 .65745 L F
.669 .971 .906 r
.28103 .66187 m .28561 .65893 L .28077 .65727 L F
.096 0 .355 r
.4835 .54903 m .48315 .55159 L .48089 .55316 L F
0 0 .408 r
.48315 .55159 m .48144 .55586 L .48089 .55316 L F
.881 .963 .845 r
.36922 .68319 m .36614 .68644 L .36778 .68345 L F
.54 .894 .977 r
.37041 .68237 m .36922 .68319 L .36778 .68345 L F
.787 .636 .694 r
.32361 .6536 m .32793 .65332 L .32579 .65668 L F
0 .121 .663 r
.32987 .6554 m .32793 .65332 L .32984 .65275 L F
.956 .687 .485 r
.56654 .4447 m .56931 .4445 L .56909 .44617 L F
.831 .97 .657 r
.3824 .62158 m .38469 .61827 L .38285 .61978 L F
.763 .941 .602 r
.38469 .61827 m .38711 .61485 L .38539 .61645 L F
.768 .959 .648 r
.38285 .61978 m .38469 .61827 L .38539 .61645 L F
.505 .136 .272 r
.5482 .47618 m .55184 .47489 L .55118 .47748 L F
.3 0 .157 r
.55184 .47489 m .55358 .47656 L .55118 .47748 L F
.55184 .47489 m .55448 .47403 L .55358 .47656 L F
.378 0 0 r
.29739 .57548 m .29453 .5765 L .2933 .57563 L F
.346 .812 .721 r
.29757 .57507 m .29739 .57548 L .29989 .57497 L F
.29757 .57507 m .29453 .5765 L .29739 .57548 L F
.956 .677 .468 r
.34575 .64379 m .3461 .64657 L .34417 .64553 L F
.406 0 0 r
.34718 .64482 m .34575 .64379 L .34417 .64553 L F
.34718 .64482 m .34939 .64567 L .34575 .64379 L F
.769 .86 .917 r
.48575 .43106 m .48095 .43198 L .48406 .42977 L F
.839 .931 .89 r
.48619 .42821 m .48575 .43106 L .48406 .42977 L F
.48619 .42821 m .48752 .42935 L .48575 .43106 L F
.377 .236 .56 r
.26715 .57567 m .2692 .57776 L .26966 .57525 L F
.969 .868 .474 r
.39373 .59653 m .39513 .59463 L .39402 .59392 L F
.39373 .59653 m .39433 .59871 L .39513 .59463 L F
.955 .676 .469 r
.42613 .58426 m .42826 .58487 L .42612 .58156 L F
.94 .844 .72 r
.42489 .58813 m .42826 .58487 L .42613 .58426 L F
.982 .717 .445 r
.4558 .54907 m .4562 .54979 L .45629 .54653 L F
.41 .137 .385 r
.4562 .54979 m .45905 .54624 L .45629 .54653 L F
.509 .15 .293 r
.60948 .37094 m .61214 .37196 L .61305 .36853 L F
.56 .574 .825 r
.61305 .36853 m .61577 .3682 L .6142 .3634 L F
0 0 .106 r
.61305 .36853 m .61473 .36908 L .61577 .3682 L F
.61305 .36853 m .61214 .37196 L .61473 .36908 L F
.115 0 0 r
.42607 .49318 m .43029 .49083 L .42815 .49254 L F
.557 .545 .797 r
.3626 .56495 m .35866 .5627 L .36078 .56144 L F
.841 .956 .613 r
.38539 .61645 m .38711 .61485 L .3875 .61287 L F
.414 .594 .918 r
.70701 .30725 m .70528 .30946 L .70341 .30895 L F
.223 .079 .464 r
.71021 .30727 m .70871 .3075 L .7054 .30683 L F
.70871 .3075 m .70746 .30768 L .70709 .30753 L F
.414 .594 .918 r
.70701 .30725 m .70706 .30753 L .7068 .30753 L F
.841 .893 .876 r
.70746 .30768 m .70746 .30984 L .70701 .30725 L F
.346 .791 .958 r
.70417 .3072 m .70701 .30725 L .70341 .30895 L F
.893 .89 .82 r
.70701 .30725 m .7054 .30683 L .70746 .30768 L F
.223 .079 .464 r
.70871 .3075 m .70709 .30753 L .7054 .30683 L F
.414 .594 .918 r
.7068 .30753 m .70746 .30984 L .70528 .30946 L F
.70706 .30753 m .70746 .30984 L .7068 .30753 L F
.448 0 0 r
.46319 .54935 m .46171 .5483 L .46041 .55112 L F
.46319 .54935 m .46171 .5483 L .46041 .55112 L F
.548 .515 .771 r
.46319 .54935 m .46041 .55112 L .45905 .54624 L F
.658 .799 .95 r
.45872 .54888 m .46041 .55112 L .46319 .54935 L F
.519 .917 .865 r
.71751 .32521 m .72118 .32409 L .72011 .32305 L F
.71751 .32521 m .71802 .32543 L .72118 .32409 L F
.277 .744 .946 r
.72118 .32409 m .72321 .32296 L .72011 .32305 L F
.72118 .32409 m .72522 .3238 L .72321 .32296 L F
.754 .246 0 r
.57611 .3704 m .57845 .37296 L .57987 .37225 L F
.522 0 0 r
.57845 .37296 m .5828 .37376 L .57987 .37225 L F
.728 .665 .787 r
.35839 .59126 m .35462 .59175 L .3572 .58921 L F
0 0 0 r
.35839 .59126 m .35391 .59414 L .35462 .59175 L F
.35839 .59126 m .35604 .59308 L .35391 .59414 L F
.055 .3 .788 r
.35925 .59005 m .35839 .59126 L .3572 .58921 L F
.459 .183 .407 r
.35925 .59005 m .35604 .59308 L .35839 .59126 L F
.947 .602 .322 r
.59239 .41619 m .59212 .41404 L .59061 .4136 L F
.497 .437 .72 r
.37364 .59948 m .37398 .60142 L .37645 .60049 L F
.872 .434 .05 r
.43813 .56835 m .4402 .56976 L .44051 .57103 L F
.114 0 .287 r
.57803 .42884 m .57599 .43025 L .57569 .43263 L F
.707 .89 .964 r
.37196 .50115 m .37221 .50036 L .37277 .50037 L F
.37196 .50115 m .37042 .49994 L .37277 .49856 L F
.686 .148 0 r
.37476 .50246 m .37042 .49994 L .37196 .50115 L F
.37476 .50246 m .37273 .50207 L .37083 .50031 L F
.37108 .50032 m .37083 .50031 L .37042 .49994 L F
.37476 .50246 m .37083 .50031 L .37108 .50032 L F
.707 .89 .964 r
.37277 .50037 m .37277 .49856 L .37473 .49849 L F
.37221 .50036 m .37277 .49856 L .37277 .50037 L F
.33 0 .143 r
.31278 .62367 m .31428 .62132 L .31048 .62381 L F
0 0 0 r
.31613 .6198 m .31428 .62132 L .31278 .62367 L F
.527 .399 .649 r
.35999 .69245 m .36169 .68746 L .35858 .68833 L F
.35999 .69245 m .36252 .69196 L .36169 .68746 L F
0 0 0 r
.65593 .37893 m .65208 .38117 L .65474 .37994 L F
.775 .841 .903 r
.50875 .41681 m .50495 .41679 L .50718 .41546 L F
.82 .881 .889 r
.51025 .41261 m .50875 .41681 L .50718 .41546 L F
.51025 .41261 m .51186 .41409 L .50875 .41681 L F
.662 .939 .672 r
.33762 .65286 m .33417 .65597 L .33657 .65597 L F
.358 .006 .224 r
.33982 .65314 m .33762 .65286 L .33657 .65597 L F
.608 .952 .815 r
.68711 .35233 m .6833 .35425 L .68362 .35146 L F
.901 .524 .308 r
.37383 .52233 m .37511 .5211 L .37335 .51947 L F
.37383 .52233 m .37598 .52333 L .37511 .5211 L F
.5 .835 .998 r
.54324 .42587 m .54484 .42692 L .54745 .42622 L F
.408 0 .101 r
.33964 .57494 m .34251 .57466 L .34393 .57248 L F
.561 .629 .876 r
.34278 .56924 m .34393 .57248 L .34546 .57092 L F
.124 0 0 r
.34393 .57248 m .34476 .57373 L .34546 .57092 L F
.34393 .57248 m .34251 .57466 L .34476 .57373 L F
.991 .877 .609 r
.39559 .57685 m .39766 .5753 L .39616 .5744 L F
.39559 .57685 m .39672 .57877 L .39766 .5753 L F
.688 .248 .2 r
.26168 .62893 m .26456 .62776 L .26322 .62956 L F
.676 .233 .192 r
.26456 .62776 m .26733 .62982 L .26322 .62956 L F
.683 .229 .166 r
.53655 .4809 m .53925 .48202 L .5388 .4829 L F
.967 .808 .38 r
.5388 .4829 m .53925 .48202 L .53969 .47994 L F
.424 .065 .25 r
.54146 .47977 m .5388 .4829 L .53969 .47994 L F
.707 .692 .834 r
.37225 .63044 m .37509 .6268 L .37347 .62788 L F
.479 .187 .391 r
.34799 .6074 m .35066 .60695 L .35095 .6048 L F
.34799 .6074 m .35066 .60695 L .35095 .6048 L F
.603 .294 .418 r
.35095 .6048 m .35066 .60695 L .3525 .60648 L F
.5 .32 .568 r
.35095 .6048 m .35367 .60426 L .35247 .60286 L F
.603 .294 .418 r
.35095 .6048 m .35066 .60695 L .3525 .60648 L F
.49 .289 .534 r
.35095 .6048 m .3525 .60648 L .35367 .60426 L F
.497 .437 .72 r
.37364 .59948 m .37645 .60049 L .3763 .59809 L F
0 0 0 r
.37437 .59968 m .37364 .59948 L .3763 .59809 L F
.37437 .59968 m .37203 .60093 L .37364 .59948 L F
.698 .568 .705 r
.35603 .56578 m .35705 .56988 L .35312 .56798 L F
.652 .864 .98 r
.73113 .30914 m .72923 .3115 L .72786 .31176 L F
.73113 .30914 m .73151 .31015 L .72923 .3115 L F
.869 .887 .846 r
.37723 .62789 m .37795 .62382 L .37509 .6268 L F
.37723 .62789 m .37964 .62506 L .37795 .62382 L F
.92 .812 .723 r
.37576 .62977 m .37723 .62789 L .37509 .6268 L F
.362 0 0 r
.26152 .62561 m .26034 .6249 L .26009 .62347 L F
.26152 .62561 m .26332 .62662 L .26034 .6249 L F
.836 .574 .542 r
.32671 .49607 m .32257 .49662 L .32379 .49581 L F
.32671 .49607 m .32644 .4978 L .32257 .49662 L F
.431 .873 .871 r
.32489 .49556 m .32499 .49559 L .32379 .49581 L F
.32499 .49559 m .32671 .49607 L .32404 .49583 L F
.32499 .49559 m .32404 .49583 L .32379 .49581 L F
.397 .244 .555 r
.32546 .49548 m .32717 .49505 L .32539 .49468 L F
.431 .873 .871 r
.32717 .49505 m .32709 .49524 L .32489 .49556 L F
.32709 .49524 m .32671 .49607 L .32489 .49556 L F
.397 .244 .555 r
.32566 .49757 m .32717 .49505 L .32546 .49548 L F
.208 0 0 r
.32301 .49675 m .32566 .49757 L .32257 .49662 L F
.32644 .4978 m .32566 .49757 L .32301 .49675 L F
.697 .216 0 r
.32644 .4978 m .32612 .49818 L .32566 .49757 L F
.397 .244 .555 r
.32566 .49757 m .32612 .49818 L .32627 .49775 L F
.32566 .49757 m .32627 .49775 L .32717 .49505 L F
.482 .254 .492 r
.32257 .49662 m .32566 .49757 L .32546 .49548 L F
.474 .862 .662 r
.32379 .49581 m .32257 .49662 L .32539 .49468 L F
.482 .254 .492 r
.32489 .49556 m .32546 .49548 L .32539 .49468 L F
.3 .057 .368 r
.32717 .49505 m .32489 .49556 L .32539 .49468 L F
.32489 .49556 m .32379 .49581 L .32539 .49468 L F
.482 .254 .492 r
.32389 .49571 m .32489 .49556 L .32539 .49468 L F
.32257 .49662 m .32546 .49548 L .32389 .49571 L F
.431 .873 .871 r
.32717 .49505 m .32945 .49505 L .32671 .49607 L F
.587 .946 .883 r
.68726 .37269 m .69117 .37133 L .69008 .37177 L F
.291 .768 .66 r
.69008 .37177 m .69117 .37133 L .69356 .37028 L F
.659 .926 .974 r
.34347 .62078 m .34486 .62128 L .34536 .61955 L F
.34347 .62078 m .34486 .62128 L .34536 .61955 L F
.086 0 .218 r
.30834 .56294 m .30752 .56524 L .31011 .56167 L F
0 0 0 r
.25675 .51718 m .25918 .51678 L .26141 .51638 L F
.26141 .51638 m .25918 .51678 L .26308 .51612 L F
.032 .187 .693 r
.32958 .55283 m .3319 .55526 L .33209 .55249 L F
.207 .515 .914 r
.55061 .41392 m .55096 .4145 L .55087 .41394 L F
.54863 .41377 m .55074 .41443 L .55061 .41392 L F
.55074 .41443 m .55096 .4145 L .55061 .41392 L F
.54863 .41377 m .55087 .41394 L .54864 .41629 L F
.836 .951 .893 r
.54728 .41515 m .54864 .41629 L .5505 .41351 L F
.536 .531 .796 r
.55087 .41394 m .55322 .41197 L .54991 .41177 L F
.724 .763 .883 r
.55121 .41244 m .55087 .41394 L .54991 .41177 L F
.836 .951 .893 r
.55037 .41302 m .5505 .41351 L .55121 .41244 L F
.54728 .41515 m .5505 .41351 L .55037 .41302 L F
.959 .922 .576 r
.35608 .63021 m .35657 .63066 L .35484 .63287 L F
.606 .46 .657 r
.35484 .63287 m .35612 .63098 L .35608 .63021 L F
.866 .527 .017 r
.35605 .62938 m .35657 .63066 L .35608 .63021 L F
.05 .243 .741 r
.3574 .62908 m .35657 .63066 L .35507 .62696 L F
.606 .46 .657 r
.35612 .63098 m .3574 .62908 L .35608 .63021 L F
.866 .527 .017 r
.35507 .62696 m .35605 .62938 L .35608 .63021 L F
.671 .87 .486 r
.35484 .63287 m .35657 .63066 L .3574 .62908 L F
.133 0 .016 r
.466 .5916 m .46717 .59297 L .46449 .59322 L F
.466 .5916 m .46798 .5908 L .46717 .59297 L F
.599 .668 .888 r
.68228 .34563 m .67905 .34769 L .67773 .34413 L F
.813 .376 0 r
.60671 .42662 m .60682 .42824 L .60609 .42502 L F
.60671 .42662 m .60868 .43021 L .60682 .42824 L F
.108 0 .281 r
.24453 .52975 m .24543 .53195 L .24324 .53286 L F
0 0 0 r
.24781 .52591 m .2466 .52776 L .24453 .52975 L F
.292 .202 .578 r
.24681 .5267 m .24717 .52712 L .24781 .52205 L F
.28 0 .16 r
.24957 .52542 m .24736 .52722 L .24781 .52591 L F
.24736 .52722 m .2465 .52792 L .24717 .52689 L F
.24736 .52722 m .24717 .52689 L .24781 .52591 L F
.24957 .52542 m .24791 .52749 L .24785 .52697 L F
.24957 .52542 m .24696 .52778 L .2467 .52776 L F
0 0 0 r
.25161 .52426 m .24781 .52591 L .24917 .52456 L F
.25161 .52426 m .24957 .52542 L .24781 .52591 L F
.366 .198 .516 r
.24826 .52816 m .2465 .52792 L .24905 .52714 L F
0 0 .095 r
.24781 .52205 m .24795 .52786 L .24821 .52481 L F
.24795 .52786 m .24795 .52806 L .24796 .52797 L F
.24795 .52786 m .24796 .52797 L .24821 .52481 L F
.28 0 .16 r
.24957 .52542 m .24905 .52714 L .24791 .52749 L F
.24785 .52697 m .24791 .52749 L .24696 .52778 L F
.2467 .52776 m .24696 .52778 L .2465 .52792 L F
.292 .202 .578 r
.24717 .52712 m .24777 .52785 L .24791 .52627 L F
.24777 .52785 m .24795 .52806 L .24795 .52786 L F
.24777 .52785 m .24795 .52786 L .24791 .52627 L F
.742 .768 .265 r
.24352 .52372 m .24301 .52512 L .2437 .52304 L F
.24271 .52671 m .24301 .52512 L .24352 .52372 L F
.776 .995 .79 r
.24271 .52671 m .24008 .52798 L .24301 .52512 L F
.716 .694 .828 r
.24264 .52583 m .24279 .52573 L .24301 .52512 L F
.24279 .52573 m .24518 .52421 L .24301 .52512 L F
0 0 .095 r
.24264 .52583 m .2429 .52826 L .24681 .5267 L F
.2429 .52826 m .24292 .52845 L .24343 .52822 L F
.2429 .52826 m .24343 .52822 L .24681 .5267 L F
.331 .791 .664 r
.24681 .5267 m .24343 .52822 L .24617 .52691 L F
.24343 .52822 m .24292 .52845 L .24617 .52691 L F
.292 .202 .578 r
.24717 .52712 m .24791 .52627 L .24781 .52205 L F
.716 .694 .828 r
.24264 .52583 m .24681 .5267 L .24518 .52421 L F
.292 .202 .578 r
.24681 .5267 m .24781 .52205 L .24518 .52421 L F
.727 .943 .954 r
.24812 .52598 m .24617 .52691 L .24821 .52481 L F
.331 .791 .664 r
.24681 .5267 m .24617 .52691 L .24762 .52772 L F
.24762 .52772 m .24617 .52691 L .24782 .52797 L F
.24681 .5267 m .24782 .52797 L .24766 .52771 L F
.727 .943 .954 r
.24796 .52791 m .24617 .52691 L .24812 .52598 L F
.24795 .52806 m .24775 .52793 L .24796 .52791 L F
.331 .791 .664 r
.24766 .52771 m .24782 .52797 L .24795 .52806 L F
.727 .943 .954 r
.24775 .52793 m .24617 .52691 L .24796 .52791 L F
0 0 0 r
.2466 .52776 m .2465 .52792 L .24631 .5281 L F
.2466 .52776 m .24631 .5281 L .24453 .52975 L F
0 0 .317 r
.24632 .53072 m .24453 .52975 L .2465 .52792 L F
.24632 .53072 m .24543 .53195 L .24453 .52975 L F
0 .203 .718 r
.58324 .38383 m .58341 .38308 L .58066 .38111 L F
.58324 .38383 m .58455 .38488 L .58341 .38308 L F
.872 .991 .815 r
.62434 .36913 m .62428 .37137 L .62652 .36848 L F
.718 .98 .771 r
.34118 .52517 m .34065 .52689 L .34276 .52617 L F
.34118 .52517 m .33862 .52785 L .34065 .52689 L F
.085 .645 .765 r
.72251 .30651 m .72098 .30674 L .71963 .30657 L F
.72251 .30651 m .72276 .30663 L .72098 .30674 L F
.823 .931 .903 r
.5739 .45837 m .57849 .45643 L .57701 .45478 L F
.713 .789 .911 r
.57849 .45643 m .58094 .45539 L .57701 .45478 L F
.757 .988 .769 r
.6795 .30364 m .67794 .30404 L .68091 .30111 L F
.042 .01 .49 r
.21865 .57252 m .22045 .57294 L .22089 .57124 L F
.21865 .57252 m .21895 .57524 L .22045 .57294 L F
.999 .806 .462 r
.74186 .3117 m .7432 .30999 L .74349 .3081 L F
.74186 .3117 m .7429 .31315 L .7432 .30999 L F
.862 .834 .817 r
.4635 .56292 m .46063 .56584 L .45887 .56382 L F
.648 .784 .946 r
.45887 .56382 m .46063 .56584 L .45644 .56544 L F
.756 .571 .645 r
.45644 .56544 m .46063 .56584 L .46022 .56822 L F
.45644 .56544 m .46022 .56822 L .45785 .56958 L F
.599 .938 .754 r
.45722 .56647 m .46154 .56375 L .45887 .56382 L F
.489 .883 .714 r
.45888 .56509 m .45981 .56451 L .46154 .56375 L F
.862 .834 .817 r
.46342 .56293 m .45887 .56382 L .46154 .56375 L F
.4635 .56292 m .46342 .56293 L .46154 .56375 L F
.865 .99 .731 r
.4635 .56292 m .46154 .56375 L .46387 .56064 L F
0 0 0 r
.46154 .56375 m .46276 .56268 L .46387 .56064 L F
.489 .883 .714 r
.45981 .56451 m .46276 .56268 L .46154 .56375 L F
0 .201 .638 r
.35419 .58114 m .35643 .58274 L .35392 .58108 L F
.35392 .58108 m .35643 .58274 L .35419 .58114 L F
.407 .489 .832 r
.42804 .51079 m .42962 .5139 L .43104 .51268 L F
.584 .387 .58 r
.33348 .52698 m .33384 .52976 L .33117 .5297 L F
.506 .693 .952 r
.33384 .52976 m .33117 .5297 L .33348 .52698 L F
0 0 .305 r
.33348 .52698 m .33515 .52579 L .33529 .52339 L F
0 0 .341 r
.33348 .52698 m .33458 .52799 L .33515 .52579 L F
.33348 .52698 m .33384 .52976 L .33458 .52799 L F
.981 .699 .411 r
.40709 .54954 m .40461 .55037 L .40555 .54773 L F
.40709 .54954 m .407 .5528 L .40461 .55037 L F
.66 .473 .62 r
.42222 .48136 m .42475 .48156 L .4247 .47863 L F
.613 .436 .618 r
.4247 .47863 m .42475 .48156 L .42741 .47817 L F
.805 .693 .741 r
.38344 .66259 m .3861 .65955 L .38338 .65981 L F
.3861 .65955 m .38344 .66259 L .38338 .65981 L F
.25 .081 .446 r
.34698 .63384 m .34947 .63005 L .34983 .63307 L F
.385 .13 .399 r
.34639 .63593 m .34698 .63384 L .34983 .63307 L F
.393 0 0 r
.33679 .54296 m .33251 .54365 L .33416 .54299 L F
.572 .808 .419 r
.32109 .61206 m .31951 .61422 L .32177 .61112 L F
0 .179 .627 r
.58409 .39632 m .58144 .39454 L .58015 .39353 L F
.152 .015 .427 r
.49096 .52587 m .48918 .5298 L .48909 .52704 L F
0 .308 .754 r
.58603 .45757 m .58904 .4598 L .58783 .45867 L F
.531 .83 .999 r
.58783 .45867 m .58904 .4598 L .59157 .45908 L F
.975 .696 .436 r
.38488 .53621 m .38505 .53992 L .38667 .54061 L F
.946 .584 .24 r
.3854 .54145 m .38667 .54061 L .38505 .53992 L F
.3854 .54145 m .387 .54261 L .38667 .54061 L F
.463 .052 .173 r
.43841 .52677 m .43615 .52986 L .43455 .52862 L F
.579 .179 .248 r
.44017 .52874 m .43841 .52677 L .44123 .52611 L F
.44017 .52874 m .43615 .52986 L .43841 .52677 L F
.497 .765 .991 r
.41213 .51203 m .41476 .51383 L .41205 .5141 L F
.561 .504 .749 r
.46234 .48186 m .46425 .47821 L .46142 .47877 L F
.46234 .48186 m .46508 .48154 L .46425 .47821 L F
.435 .071 .248 r
.46432 .48321 m .46234 .48186 L .46206 .48432 L F
.46432 .48321 m .46508 .48154 L .46234 .48186 L F
.401 0 0 r
.32107 .65307 m .32178 .65447 L .31925 .65535 L F
.32107 .65307 m .32361 .6536 L .32178 .65447 L F
.773 .923 .936 r
.58346 .3581 m .58574 .35474 L .58603 .35503 L F
.58346 .3581 m .58225 .35695 L .58574 .35474 L F
0 .361 .699 r
.58346 .3581 m .58419 .35825 L .58225 .35695 L F
.58346 .3581 m .58532 .35872 L .58419 .35825 L F
.961 .648 .382 r
.59592 .39611 m .59796 .39792 L .59815 .40071 L F
.949 .655 .209 r
.33965 .54198 m .3398 .54272 L .34038 .54324 L F
.627 .698 .896 r
.34223 .54971 m .33778 .54885 L .34038 .54324 L F
0 0 0 r
.33778 .54885 m .33857 .54729 L .34038 .54324 L F
.33857 .54729 m .34338 .54509 L .34038 .54324 L F
.569 .008 0 r
.73506 .31551 m .73666 .31592 L .73401 .31422 L F
.306 .498 .882 r
.73452 .31164 m .73666 .31592 L .73671 .31302 L F
.763 .581 .651 r
.73811 .31693 m .73666 .31592 L .73506 .31551 L F
.73811 .31693 m .73671 .31302 L .73666 .31592 L F
.569 .008 0 r
.73506 .31551 m .73666 .31592 L .73401 .31422 L F
0 0 .174 r
.55448 .39445 m .55539 .39428 L .55643 .39271 L F
.55448 .39445 m .55404 .39732 L .55539 .39428 L F
.571 .337 .522 r
.6241 .40517 m .62643 .40044 L .62224 .40337 L F
.947 .777 .639 r
.62224 .40337 m .62086 .4064 L .62367 .4061 L F
.773 .346 0 r
.62388 .4065 m .62407 .40673 L .62405 .40671 L F
.62367 .4061 m .62405 .40671 L .62224 .40337 L F
.62388 .4065 m .62405 .40671 L .62367 .4061 L F
.947 .777 .639 r
.62224 .40337 m .62367 .4061 L .6242 .40605 L F
.571 .337 .522 r
.62489 .40595 m .62224 .40337 L .6242 .40605 L F
.773 .346 0 r
.62258 .40438 m .62405 .40671 L .62224 .40337 L F
.719 .648 .778 r
.62329 .4055 m .62206 .40627 L .62086 .4064 L F
.62391 .40528 m .62334 .40558 L .62329 .4055 L F
.62334 .40558 m .62206 .40627 L .62329 .4055 L F
.62334 .40558 m .62367 .4061 L .62206 .40627 L F
.773 .346 0 r
.62287 .40527 m .62388 .4065 L .62367 .4061 L F
.62258 .40438 m .62367 .4061 L .62224 .40337 L F
.719 .648 .778 r
.6212 .40222 m .62329 .4055 L .62086 .4064 L F
.773 .346 0 r
.62287 .40527 m .62367 .4061 L .62258 .40438 L F
.62287 .40527 m .62407 .40673 L .62405 .40671 L F
.62287 .40527 m .62405 .40671 L .62258 .40438 L F
.719 .648 .778 r
.62391 .40528 m .6242 .40605 L .62367 .4061 L F
.62391 .40528 m .62367 .4061 L .62334 .40558 L F
.62149 .39874 m .62391 .40528 L .62329 .4055 L F
.62149 .39874 m .62329 .4055 L .6212 .40222 L F
.571 .337 .522 r
.62489 .40595 m .62529 .40453 L .6241 .40517 L F
.62529 .40453 m .62643 .40044 L .6241 .40517 L F
0 0 0 r
.62863 .39926 m .62922 .39728 L .62643 .40044 L F
.003 0 .254 r
.62863 .39926 m .62643 .40044 L .62489 .40595 L F
.358 0 0 r
.33516 .51733 m .33336 .51902 L .33068 .51921 L F
.542 .374 .603 r
.33551 .51591 m .33336 .51902 L .33516 .51733 L F
.474 .357 .639 r
.34223 .54971 m .34466 .54916 L .34413 .54621 L F
.34413 .54621 m .34466 .54916 L .34223 .54971 L F
.797 .885 .462 r
.33654 .60702 m .33539 .60918 L .33511 .6109 L F
.202 0 0 r
.33511 .6109 m .33783 .61139 L .33779 .6112 L F
.835 .684 .695 r
.33539 .60918 m .33783 .61139 L .33511 .6109 L F
.309 .653 .97 r
.72978 .32881 m .73287 .32912 L .73086 .3283 L F
.179 0 .273 r
.33628 .62028 m .33446 .62115 L .33379 .62352 L F
.925 .952 .788 r
.42609 .51081 m .42599 .51477 L .42804 .51079 L F
.984 .7 .374 r
.42609 .51081 m .42773 .51583 L .42599 .51477 L F
.105 0 .243 r
.6104 .3877 m .61292 .38397 L .61298 .38671 L F
.709 .545 .664 r
.35391 .59414 m .35515 .59923 L .35359 .5982 L F
.35515 .59923 m .35517 .59929 L .3551 .59924 L F
.35515 .59923 m .3551 .59924 L .35359 .5982 L F
.432 0 .07 r
.35581 .59916 m .35862 .59839 L .35859 .59839 L F
.35582 .59916 m .35862 .59839 L .35581 .59916 L F
.35494 .59928 m .35859 .59839 L .35617 .59844 L F
.616 .59 .801 r
.35517 .59923 m .35674 .59905 L .35517 .59929 L F
.432 0 .07 r
.35464 .59949 m .35859 .59839 L .35494 .59928 L F
.35464 .59949 m .35748 .60016 L .35823 .59899 L F
.35582 .59916 m .35823 .59899 L .35862 .59839 L F
.236 .753 .809 r
.35622 .59913 m .35464 .59949 L .35517 .59929 L F
.432 0 .07 r
.35464 .59949 m .35823 .59899 L .35622 .59913 L F
.236 .753 .809 r
.35853 .59879 m .35464 .59949 L .35622 .59913 L F
.432 0 .07 r
.35464 .59949 m .35622 .59913 L .35582 .59916 L F
.616 .59 .801 r
.35604 .59308 m .35674 .59905 L .35582 .59916 L F
.35518 .5992 m .35582 .59916 L .35517 .59923 L F
.35604 .59308 m .35582 .59916 L .35518 .5992 L F
.063 0 0 r
.35748 .60016 m .36091 .59837 L .35862 .59839 L F
.616 .59 .801 r
.35604 .59308 m .35853 .59879 L .35674 .59905 L F
.432 0 .07 r
.35464 .59949 m .35582 .59916 L .35581 .59916 L F
.172 .068 .485 r
.23252 .57764 m .23259 .58127 L .23041 .58179 L F
0 0 0 r
.23116 .58233 m .23041 .58179 L .23259 .58127 L F
.23116 .58233 m .22918 .58373 L .23041 .58179 L F
.505 .136 .272 r
.5482 .47618 m .55118 .47748 L .54829 .47788 L F
.531 .743 .973 r
.28776 .66143 m .28938 .66302 L .29009 .66083 L F
.467 .674 .954 r
.28938 .66302 m .29246 .66319 L .29009 .66083 L F
.069 0 0 r
.56351 .46797 m .56703 .46624 L .56613 .46711 L F
0 0 0 r
.56613 .46711 m .56703 .46624 L .56952 .46506 L F
.456 .842 .623 r
.55168 .39962 m .54788 .40222 L .55172 .40011 L F
0 0 0 r
.55168 .39962 m .55172 .40011 L .55315 .39806 L F
.478 .394 .683 r
.43455 .52862 m .43288 .53314 L .43207 .53009 L F
.43455 .52862 m .43506 .53274 L .43288 .53314 L F
.459 .283 .554 r
.43506 .53274 m .43245 .53588 L .43288 .53314 L F
.591 .189 .249 r
.44624 .50649 m .45025 .50467 L .4486 .50285 L F
.44624 .50649 m .44998 .50642 L .45025 .50467 L F
.631 .225 .255 r
.44998 .50642 m .45287 .50654 L .45025 .50467 L F
.522 .304 .525 r
.45025 .50467 m .45287 .50654 L .45423 .50461 L F
.882 .884 .83 r
.37795 .62382 m .37964 .62506 L .38099 .62327 L F
.647 .828 .412 r
.33778 .54885 m .3365 .55072 L .33857 .54729 L F
.762 .75 .842 r
.64801 .34258 m .65113 .34246 L .64811 .34069 L F
.817 .815 .848 r
.65113 .34246 m .65428 .33944 L .65229 .33752 L F
.887 .574 .45 r
.40068 .48645 m .40311 .48739 L .40323 .48476 L F
.223 .717 .917 r
.64368 .3858 m .64004 .38543 L .64271 .38661 L F
.546 .867 .583 r
.64818 .38491 m .6455 .386 L .64818 .38494 L F
.64889 .38297 m .64615 .38542 L .64818 .38491 L F
.64615 .38542 m .6455 .386 L .64818 .38491 L F
0 0 0 r
.64702 .38474 m .64368 .3858 L .64327 .38614 L F
.6445 .38583 m .64327 .38614 L .64271 .38661 L F
.64702 .38474 m .64327 .38614 L .6445 .38583 L F
.864 .857 .832 r
.49915 .42253 m .49844 .42368 L .4964 .42218 L F
.733 .962 .684 r
.3802 .59938 m .38135 .59722 L .38271 .59829 L F
.813 .838 .869 r
.35613 .69008 m .35858 .68833 L .35446 .68858 L F
.398 0 .025 r
.27838 .57425 m .28277 .57218 L .28095 .57235 L F
.977 .731 .317 r
.43449 .55299 m .4329 .55241 L .4329 .55119 L F
.43449 .55299 m .43446 .55564 L .4329 .55241 L F
.846 .668 .129 r
.43449 .55299 m .43464 .55706 L .43446 .55564 L F
.575 .939 .817 r
.67628 .32219 m .68016 .32032 L .67885 .32135 L F
0 0 0 r
.67885 .32135 m .68016 .32032 L .6827 .31888 L F
.475 .638 .927 r
.55389 .40988 m .55128 .41038 L .55256 .40803 L F
.825 .816 .841 r
.68473 .34449 m .68804 .34505 L .68549 .34814 L F
.585 .94 .924 r
.64641 .32982 m .64837 .32807 L .64979 .32737 L F
0 0 0 r
.64979 .32737 m .64837 .32807 L .64939 .32765 L F
.64979 .32737 m .64939 .32765 L .65092 .32704 L F
.6 .85 .49 r
.65088 .32617 m .65012 .32712 L .64979 .32737 L F
.65012 .32712 m .64825 .32947 L .64979 .32737 L F
.686 .978 .818 r
.64825 .32947 m .64641 .32982 L .64979 .32737 L F
.494 .25 .473 r
.5177 .48811 m .5175 .49058 L .51488 .4912 L F
.526 .243 .428 r
.5177 .48811 m .52027 .48997 L .5175 .49058 L F
.5177 .48811 m .52045 .48772 L .52027 .48997 L F
.877 .975 .67 r
.36778 .68345 m .36614 .68644 L .36678 .68473 L F
.873 .972 .657 r
.36678 .68473 m .36614 .68644 L .36429 .68871 L F
.159 0 0 r
.33604 .4954 m .33338 .49491 L .33204 .49488 L F
.829 .994 .748 r
.38099 .62327 m .3824 .62158 L .38285 .61978 L F
.675 .861 .97 r
.335 .65853 m .33657 .65597 L .33403 .65873 L F
.335 .65853 m .33843 .65714 L .33657 .65597 L F
0 0 .298 r
.35795 .62162 m .35881 .62213 L .36043 .62071 L F
.405 .214 .506 r
.36752 .63689 m .36755 .6341 L .36949 .63394 L F
.666 .9 .979 r
.44001 .45047 m .43906 .45269 L .43751 .45127 L F
.44001 .45047 m .44149 .45144 L .43906 .45269 L F
.98 .684 .351 r
.39359 .56416 m .39487 .56269 L .39351 .56148 L F
.39359 .56416 m .39502 .56533 L .39487 .56269 L F
.852 .395 .075 r
.4277 .59331 m .42844 .59213 L .42673 .59136 L F
.701 .4 .463 r
.23519 .55359 m .23455 .55549 L .23126 .55529 L F
0 0 0 r
.23548 .55408 m .23519 .55359 L .23733 .55239 L F
.23548 .55408 m .23455 .55549 L .23519 .55359 L F
.725 .949 .951 r
.62695 .34927 m .62591 .35183 L .62924 .34963 L F
.795 .998 .796 r
.62695 .34927 m .6254 .35123 L .62591 .35183 L F
.287 .396 .799 r
.22165 .58141 m .22147 .5772 L .21977 .57764 L F
.22165 .58141 m .22303 .58103 L .22147 .5772 L F
.48 .162 .351 r
.63484 .41231 m .63439 .41091 L .63526 .41257 L F
.63484 .41231 m .63153 .41475 L .63439 .41091 L F
.95 .956 .687 r
.63229 .41554 m .63484 .41231 L .63526 .41257 L F
.728 .713 .837 r
.352 .68935 m .35613 .69008 L .35446 .68858 L F
0 0 0 r
.69786 .36288 m .69637 .36504 L .69827 .36111 L F
0 0 .073 r
.69591 .36723 m .69637 .36504 L .69786 .36288 L F
.38 .135 .412 r
.49632 .51403 m .4959 .51612 L .49348 .51681 L F
.463 .308 .585 r
.4959 .51612 m .49342 .52005 L .49348 .51681 L F
.546 .536 .795 r
.23818 .58745 m .23904 .59119 L .23667 .59176 L F
0 0 0 r
.23801 .59088 m .23667 .59176 L .23904 .59119 L F
.23801 .59088 m .23534 .59386 L .23667 .59176 L F
.561 .741 .96 r
.28724 .5146 m .28988 .51421 L .28791 .51219 L F
.863 .914 .864 r
.37795 .62382 m .38099 .62327 L .38033 .62123 L F
.829 .994 .748 r
.38099 .62327 m .38285 .61978 L .38033 .62123 L F
.989 .87 .623 r
.43266 .51645 m .43366 .51826 L .43597 .51674 L F
.43266 .51645 m .43203 .51921 L .43366 .51826 L F
.232 .103 .492 r
.32518 .6376 m .32608 .63916 L .3257 .63603 L F
.32518 .6376 m .32463 .63966 L .32608 .63916 L F
0 .317 .803 r
.58047 .38139 m .57975 .37948 L .57663 .37816 L F
.58047 .38139 m .58066 .38111 L .57975 .37948 L F
.969 .704 .281 r
.43705 .50718 m .43585 .50298 L .43955 .5034 L F
.679 .974 .904 r
.29066 .5327 m .28889 .53388 L .29017 .53247 L F
.799 .927 .92 r
.49066 .42676 m .48752 .42935 L .48619 .42821 L F
.723 .918 .565 r
.41388 .46206 m .41478 .45993 L .41626 .45878 L F
.761 .956 .936 r
.41931 .45649 m .41626 .45878 L .41562 .45748 L F
.141 0 0 r
.41626 .45878 m .41739 .4595 L .41562 .45748 L F
.41626 .45878 m .41478 .45993 L .41739 .4595 L F
.33 .814 .82 r
.61292 .38397 m .61561 .38316 L .61509 .38305 L F
.119 .003 .433 r
.61292 .38397 m .61381 .38583 L .61298 .38671 L F
.61292 .38397 m .61509 .38305 L .61381 .38583 L F
.937 .619 .17 r
.39252 .55715 m .39336 .55631 L .39188 .55531 L F
.39252 .55715 m .39373 .55877 L .39336 .55631 L F
0 0 .397 r
.23075 .56038 m .22944 .55939 L .23197 .55878 L F
.23075 .56038 m .22987 .56218 L .22944 .55939 L F
.869 .858 .828 r
.32645 .52811 m .32711 .52955 L .32949 .52587 L F
.49 .519 .814 r
.32711 .52955 m .33145 .53319 L .33117 .5297 L F
.743 .608 .707 r
.54259 .40462 m .54352 .40727 L .54067 .40741 L F
.431 .592 .91 r
.32722 .64563 m .32641 .64812 L .32451 .64581 L F
.32722 .64563 m .33026 .64847 L .32641 .64812 L F
.506 0 0 r
.33099 .65019 m .32641 .64812 L .33026 .64847 L F
.742 .706 .818 r
.55727 .45535 m .56114 .45574 L .55979 .45187 L F
.682 .25 .218 r
.56027 .4578 m .56114 .45574 L .55727 .45535 L F
.332 .451 .831 r
.55979 .45187 m .56114 .45574 L .56331 .45436 L F
0 0 0 r
.56331 .45436 m .56114 .45574 L .56027 .4578 L F
.776 .582 .637 r
.44865 .50025 m .44492 .4974 L .44932 .49909 L F
.44865 .50025 m .44743 .50133 L .44492 .4974 L F
.658 .875 .98 r
.27358 .57555 m .26966 .57525 L .27145 .57492 L F
.64 .486 .658 r
.27145 .57492 m .27058 .57833 L .27358 .57555 L F
.67 .286 .309 r
.27358 .57555 m .27415 .57534 L .27571 .57482 L F
.27358 .57555 m .27145 .57492 L .27415 .57534 L F
.27358 .57555 m .27182 .57778 L .27145 .57492 L F
.27358 .57555 m .27583 .57788 L .27182 .57778 L F
.763 .942 .94 r
.65727 .33303 m .65642 .33589 L .65892 .33231 L F
.64 .955 .936 r
.66145 .331 m .6604 .33033 L .65892 .33231 L F
.649 .947 .716 r
.6604 .33033 m .65727 .33303 L .65892 .33231 L F
.739 .86 .937 r
.35419 .58114 m .35643 .58274 L .35795 .58102 L F
.35795 .58102 m .35643 .58274 L .35419 .58114 L F
.419 .816 .596 r
.65088 .32617 m .65282 .32478 L .65294 .32473 L F
0 0 0 r
.65088 .32617 m .64979 .32737 L .65282 .32478 L F
.33145 .53319 m .33384 .52976 L .33117 .5297 L F
.147 0 .323 r
.34366 .60176 m .34494 .60316 L .34579 .60089 L F
.34366 .60176 m .34334 .60439 L .34494 .60316 L F
.584 .479 .701 r
.36252 .69196 m .36429 .68871 L .36169 .68746 L F
.869 .434 .161 r
.27183 .62702 m .26856 .62385 L .26976 .62701 L F
.675 .363 .438 r
.27393 .62973 m .27439 .62752 L .27183 .62702 L F
0 0 .562 r
.27264 .62743 m .27393 .62973 L .27183 .62702 L F
.27264 .62743 m .27183 .62702 L .26976 .62701 L F
.796 .311 .059 r
.43687 .54647 m .44001 .54844 L .43883 .54718 L F
.984 .769 .533 r
.42602 .56804 m .42764 .56892 L .42667 .56554 L F
.832 .497 .42 r
.42555 .57117 m .42764 .56892 L .42602 .56804 L F
.632 .497 .68 r
.42764 .56892 m .43079 .57287 L .42945 .57172 L F
.832 .497 .42 r
.42555 .57117 m .43079 .57287 L .42764 .56892 L F
.927 .746 .637 r
.60012 .4514 m .60327 .44933 L .60149 .44821 L F
.60012 .4514 m .60297 .45147 L .60327 .44933 L F
.754 .758 .856 r
.55703 .4084 m .55825 .41127 L .55389 .40988 L F
.404 .555 .891 r
.55914 .40815 m .55825 .41127 L .55703 .4084 L F
.636 .799 .961 r
.56071 .40975 m .55825 .41127 L .55914 .40815 L F
.425 .563 .889 r
.24066 .59545 m .24309 .59531 L .242 .59388 L F
.219 0 .325 r
.32243 .64349 m .32463 .63966 L .32416 .64318 L F
.32243 .64349 m .32463 .63966 L .32416 .64318 L F
.162 0 .306 r
.32608 .63916 m .32463 .63966 L .32416 .64318 L F
.834 .677 .689 r
.32608 .63916 m .32416 .64318 L .32463 .63966 L F
.83 .642 .648 r
.33509 .5008 m .33061 .50294 L .33113 .50115 L F
.33509 .5008 m .33553 .50412 L .33061 .50294 L F
.793 .374 .253 r
.33509 .5008 m .33758 .50377 L .33553 .50412 L F
.674 .271 .273 r
.52872 .4347 m .5291 .43345 L .5251 .43326 L F
.648 .521 .696 r
.5291 .43345 m .53302 .43303 L .53162 .42957 L F
.357 0 0 r
.53148 .43414 m .5291 .43345 L .52872 .4347 L F
.53148 .43414 m .53302 .43303 L .5291 .43345 L F
.851 .987 .854 r
.34594 .6494 m .34482 .65167 L .34192 .6528 L F
.704 .65 .793 r
.34774 .65151 m .34482 .65167 L .34594 .6494 L F
.399 .843 .735 r
.61313 .37268 m .61675 .37115 L .61578 .3732 L F
.763 .344 .253 r
.61675 .37115 m .61859 .3733 L .61578 .3732 L F
.897 .929 .831 r
.62125 .37166 m .61675 .37115 L .61955 .37116 L F
.62125 .37166 m .61859 .3733 L .61675 .37115 L F
.783 .782 .851 r
.34774 .65151 m .34594 .6494 L .3461 .64657 L F
.34774 .65151 m .34981 .65027 L .34594 .6494 L F
.34774 .65151 m .34981 .65027 L .34594 .6494 L F
.449 .337 .634 r
.34998 .65252 m .34774 .65151 L .34981 .65027 L F
0 0 .308 r
.48078 .55833 m .47961 .56157 L .47979 .5594 L F
.891 .989 .779 r
.32177 .61112 m .31978 .6118 L .32176 .60926 L F
0 0 .262 r
.31978 .6118 m .32136 .61149 L .32143 .61074 L F
.31978 .6118 m .32157 .60934 L .32176 .60926 L F
.31978 .6118 m .32143 .61074 L .32157 .60934 L F
.845 .761 .77 r
.32177 .61112 m .31871 .61248 L .31978 .6118 L F
.31871 .61248 m .31757 .61298 L .31978 .6118 L F
.914 .965 .654 r
.32355 .60761 m .32177 .61112 L .32176 .60926 L F
.943 .79 .33 r
.32355 .60761 m .32302 .60705 L .32341 .60414 L F
.914 .965 .654 r
.32355 .60761 m .32176 .60926 L .32302 .60705 L F
.449 .337 .634 r
.34998 .65252 m .34776 .65379 L .34774 .65151 L F
.64 .958 .782 r
.25101 .58212 m .24855 .58321 L .2478 .5846 L F
.979 .89 .665 r
.37965 .49111 m .3773 .49279 L .37834 .49088 L F
.37965 .49111 m .37823 .4948 L .3773 .49279 L F
0 0 .062 r
.37965 .49111 m .38118 .48971 L .38177 .48729 L F
.516 .908 .929 r
.37965 .49111 m .37834 .49088 L .38118 .48971 L F
0 0 0 r
.35421 .61622 m .35561 .61245 L .35529 .61386 L F
.571 .426 .645 r
.32243 .64349 m .32214 .64637 L .31942 .64717 L F
.757 .841 .915 r
.29991 .66609 m .30577 .66365 L .30062 .6626 L F
.789 .825 .881 r
.30062 .6626 m .30577 .66365 L .30498 .66228 L F
.982 .698 .392 r
.43532 .55797 m .43397 .56074 L .43402 .55811 L F
.43532 .55797 m .43545 .56258 L .43397 .56074 L F
.482 .172 .363 r
.60673 .35569 m .6063 .35762 L .6036 .35816 L F
.589 .34 .507 r
.60907 .35476 m .6063 .35762 L .60673 .35569 L F
0 0 .005 r
.6316 .39572 m .63195 .39412 L .62922 .39728 L F
0 0 0 r
.6316 .39572 m .62922 .39728 L .62863 .39926 L F
.864 .759 .745 r
.601 .36398 m .59908 .36744 L .60254 .36768 L F
.88 .894 .838 r
.5981 .36977 m .60254 .36768 L .59908 .36744 L F
.5981 .36977 m .59947 .37114 L .60254 .36768 L F
.306 .771 .642 r
.24423 .62135 m .24488 .62105 L .2472 .61994 L F
.406 0 0 r
.24207 .6206 m .24488 .62105 L .24261 .62212 L F
.306 .771 .642 r
.24261 .62212 m .24488 .62105 L .24423 .62135 L F
.258 0 0 r
.24207 .6206 m .2454 .6208 L .24488 .62105 L F
.2454 .6208 m .24633 .62086 L .24488 .62105 L F
.702 .795 .922 r
.43499 .45192 m .43262 .45327 L .43089 .45145 L F
.637 .6 .795 r
.31305 .65057 m .31046 .65273 L .30954 .64955 L F
.632 .472 .648 r
.33965 .54198 m .33597 .53895 L .33756 .5383 L F
.355 .212 .544 r
.49342 .52005 m .49338 .52266 L .49135 .52354 L F
.372 .156 .451 r
.49338 .52266 m .49096 .52587 L .49135 .52354 L F
.551 .465 .711 r
.31856 .61533 m .31709 .61887 L .3195 .61731 L F
0 0 0 r
.3195 .61731 m .31709 .61887 L .31613 .6198 L F
.652 .537 .711 r
.3689 .57924 m .3671 .58056 L .37183 .5786 L F
.37183 .5786 m .3671 .58056 L .3689 .57924 L F
.587 .828 .452 r
.36211 .6245 m .36466 .62114 L .3634 .62275 L F
.759 .757 .244 r
.35881 .62213 m .35786 .62649 L .36061 .62658 L F
0 0 0 r
.36061 .62658 m .36203 .62461 L .36178 .62497 L F
.36061 .62658 m .3634 .62275 L .36287 .62549 L F
.768 .705 .792 r
.36061 .62658 m .3585 .62416 L .35881 .62213 L F
.36061 .62658 m .36287 .62549 L .3585 .62416 L F
.31 .028 .313 r
.36168 .62513 m .36081 .62516 L .3585 .62416 L F
.36287 .62549 m .36157 .62528 L .36168 .62513 L F
.36157 .62528 m .36081 .62516 L .36168 .62513 L F
0 0 0 r
.36178 .62497 m .36211 .6245 L .3634 .62275 L F
.36203 .62461 m .36211 .6245 L .36178 .62497 L F
.698 .983 .857 r
.36581 .62733 m .36301 .6291 L .36431 .62862 L F
.119 .439 .877 r
.36539 .62821 m .36431 .62862 L .36489 .6274 L F
.945 .599 .329 r
.36431 .62862 m .36648 .62998 L .36581 .62733 L F
.119 .439 .877 r
.36602 .62923 m .36431 .62862 L .36539 .62821 L F
.698 .983 .857 r
.36301 .6291 m .36123 .63023 L .36431 .62862 L F
.291 0 0 r
.25819 .52292 m .25428 .52353 L .25656 .52283 L F
.512 .07 .136 r
.29909 .65466 m .30096 .65321 L .29713 .65345 L F
.689 .966 .742 r
.64838 .39602 m .64883 .39628 L .6517 .39358 L F
.916 .534 .271 r
.3794 .52729 m .37993 .52921 L .38187 .53007 L F
.984 .715 .428 r
.38032 .5315 m .38187 .53007 L .37993 .52921 L F
.38032 .5315 m .38189 .53267 L .38187 .53007 L F
0 .174 .702 r
.53729 .46097 m .53624 .46179 L .53449 .46127 L F
.53831 .46406 m .53888 .46579 L .53703 .46297 L F
.579 .635 .871 r
.54134 .46415 m .53888 .46579 L .53729 .46097 L F
.592 .932 .739 r
.53623 .46733 m .53888 .46579 L .53735 .46634 L F
.874 .606 .53 r
.53623 .46733 m .53923 .46784 L .53888 .46579 L F
.787 .462 .439 r
.53841 .46516 m .53815 .46592 L .53735 .46634 L F
.553 .288 .469 r
.53612 .47068 m .53923 .46784 L .53623 .46733 L F
.787 .462 .439 r
.53815 .46592 m .53724 .46865 L .53735 .46634 L F
.65 .285 .34 r
.54239 .46719 m .53888 .46579 L .53923 .46784 L F
.553 .288 .469 r
.53612 .47068 m .53929 .47044 L .53923 .46784 L F
.407 0 .122 r
.54128 .46919 m .53923 .46784 L .53929 .47044 L F
.54128 .46919 m .54239 .46719 L .53923 .46784 L F
.787 .462 .439 r
.53815 .46592 m .54128 .46919 L .53724 .46865 L F
.53841 .46516 m .53874 .46562 L .53815 .46592 L F
.484 .884 .727 r
.53735 .46634 m .5387 .46564 L .53815 .46592 L F
.5387 .46564 m .54048 .46473 L .53874 .46562 L F
.5387 .46564 m .53874 .46562 L .53815 .46592 L F
.53735 .46634 m .53888 .46579 L .54048 .46473 L F
.65 .285 .34 r
.54239 .46719 m .54276 .46526 L .53888 .46579 L F
.153 0 .205 r
.54485 .46419 m .54276 .46526 L .54239 .46719 L F
.54485 .46419 m .54239 .46719 L .54516 .46672 L F
.431 .832 .978 r
.54386 .46598 m .54516 .46672 L .54239 .46719 L F
.54386 .46598 m .54239 .46719 L .54128 .46919 L F
.546 .419 .659 r
.54386 .46598 m .54128 .46919 L .53874 .46562 L F
.53923 .46531 m .53874 .46562 L .53841 .46516 L F
.484 .884 .727 r
.53735 .46634 m .53923 .46531 L .53841 .46516 L F
.53923 .46531 m .53957 .46513 L .53841 .46516 L F
.546 .419 .659 r
.53926 .46529 m .53923 .46531 L .53841 .46516 L F
.54386 .46598 m .53874 .46562 L .53926 .46529 L F
.787 .462 .439 r
.53874 .46562 m .54128 .46919 L .53815 .46592 L F
.484 .884 .727 r
.53815 .46592 m .54048 .46473 L .54061 .46464 L F
.53735 .46634 m .54061 .46464 L .54134 .46415 L F
.53957 .46513 m .54134 .46415 L .53926 .46487 L F
.53957 .46513 m .53926 .46487 L .53841 .46516 L F
0 .174 .702 r
.53729 .46097 m .53831 .46406 L .53624 .46179 L F
.53831 .46406 m .53703 .46297 L .53624 .46179 L F
0 .219 .732 r
.46433 .51989 m .46512 .51857 L .46296 .51645 L F
.031 .269 .767 r
.46649 .5216 m .46512 .51857 L .46433 .51989 L F
.138 .105 .554 r
.41289 .46391 m .41478 .45993 L .41388 .46206 L F
.41289 .46391 m .41482 .46285 L .41478 .45993 L F
.353 .802 .659 r
.41289 .46391 m .41188 .46437 L .41421 .46317 L F
.41289 .46391 m .41421 .46317 L .41482 .46285 L F
0 0 0 r
.41388 .46206 m .41213 .46434 L .41289 .46391 L F
.41213 .46434 m .41135 .46536 L .41289 .46391 L F
.53 .916 .789 r
.41135 .46536 m .41188 .46437 L .41289 .46391 L F
.41135 .46536 m .40907 .46621 L .41188 .46437 L F
.037 .344 .822 r
.57606 .38733 m .57904 .38918 L .57815 .38995 L F
.801 .347 0 r
.57884 .39242 m .58015 .39353 L .57815 .38995 L F
.57884 .39242 m .57815 .38995 L .57904 .38918 L F
.757 .841 .915 r
.29991 .66609 m .30062 .6626 L .29857 .66227 L F
.276 0 0 r
.2805 .57608 m .27865 .5775 L .27583 .57788 L F
.24 0 0 r
.28273 .57516 m .27865 .5775 L .2805 .57608 L F
.995 .832 .566 r
.3957 .56801 m .39626 .5718 L .39596 .56912 L F
.971 .667 .285 r
.60263 .41001 m .60402 .41386 L .60237 .41272 L F
.958 .764 .6 r
.60402 .41386 m .60188 .4153 L .60237 .41272 L F
.60402 .41386 m .60378 .41644 L .60188 .4153 L F
0 .467 .74 r
.26241 .52399 m .26109 .52357 L .25819 .52292 L F
.771 .973 .92 r
.26274 .5219 m .26241 .52399 L .26403 .52253 L F
.792 .984 .898 r
.26274 .5219 m .26109 .52357 L .26241 .52399 L F
.802 .536 .535 r
.55946 .43553 m .55951 .43302 L .5556 .43226 L F
.694 .912 .97 r
.46801 .43876 m .46634 .44137 L .46527 .44119 L F
.46801 .43876 m .46946 .43967 L .46634 .44137 L F
.655 .725 .901 r
.43559 .59597 m .43706 .59828 L .43944 .59696 L F
.128 0 0 r
.54492 .40521 m .54259 .40462 L .54148 .40318 L F
.38 .248 .573 r
.35186 .62973 m .34936 .62729 L .35084 .6265 L F
.35186 .62973 m .34947 .63005 L .34936 .62729 L F
.64 .603 .796 r
.44123 .5129 m .44141 .51804 L .44511 .51459 L F
.663 .644 .821 r
.44511 .51459 m .44141 .51804 L .44665 .51749 L F
.78 .678 .75 r
.44267 .51985 m .44665 .51749 L .44141 .51804 L F
.832 .536 .49 r
.38549 .67259 m .38898 .67235 L .38839 .67208 L F
.81 .919 .911 r
.3841 .6739 m .38898 .67235 L .38549 .67259 L F
.729 .692 .815 r
.38898 .67235 m .39195 .66938 L .38839 .67208 L F
.626 .519 .712 r
.39149 .6716 m .39195 .66938 L .38898 .67235 L F
0 0 0 r
.69786 .36288 m .69827 .36111 L .69861 .36079 L F
.632 .682 .879 r
.35471 .68362 m .35058 .68224 L .35305 .68173 L F
.999 .789 .466 r
.39617 .58734 m .39657 .58511 L .39545 .58415 L F
.701 .781 .913 r
.33565 .57268 m .33821 .57581 L .33299 .57472 L F
.782 .488 .49 r
.33821 .57581 m .33733 .57789 L .33284 .57742 L F
.482 .686 .957 r
.33964 .57494 m .33821 .57581 L .33565 .57268 L F
0 0 .097 r
.33964 .57494 m .33733 .57789 L .33821 .57581 L F
.972 .77 .572 r
.59172 .41865 m .59107 .42217 L .59344 .4231 L F
.93 .562 .291 r
.59146 .42311 m .59344 .4231 L .59107 .42217 L F
.59146 .42311 m .59384 .4255 L .59344 .4231 L F
.652 .259 .288 r
.32864 .50105 m .33113 .50115 L .33061 .50294 L F
.997 .831 .551 r
.5873 .40347 m .58673 .39975 L .58683 .40218 L F
.701 .323 0 r
.58768 .40472 m .5873 .40347 L .58683 .40218 L F
.58768 .40472 m .58884 .40687 L .5873 .40347 L F
.904 .491 .158 r
.58946 .40679 m .5873 .40347 L .58884 .40687 L F
.606 .477 .679 r
.34506 .68604 m .34781 .68555 L .34682 .68136 L F
.704 .62 .761 r
.34537 .68882 m .34781 .68555 L .34506 .68604 L F
.848 .872 .858 r
.49868 .41976 m .49915 .42253 L .4964 .42218 L F
.831 .863 .869 r
.50214 .41945 m .49915 .42253 L .49868 .41976 L F
.656 .967 .909 r
.66486 .37475 m .66069 .37619 L .66413 .37409 L F
.748 .984 .905 r
.66605 .37242 m .66486 .37475 L .66413 .37409 L F
.871 .543 .427 r
.38643 .47458 m .38248 .47615 L .38441 .47355 L F
.86 .9 .861 r
.38883 .47161 m .38643 .47458 L .38441 .47355 L F
.849 .466 0 r
.38643 .47458 m .38723 .47762 L .38751 .47737 L F
.664 .122 0 r
.31297 .55853 m .31508 .56054 L .31743 .5602 L F
.235 .278 .703 r
.31945 .55983 m .31743 .5602 L .31508 .56054 L F
.443 .148 .369 r
.31743 .5602 m .31965 .56136 L .31997 .55969 L F
.235 .278 .703 r
.31945 .55983 m .31965 .56136 L .31743 .5602 L F
.805 .492 0 r
.24081 .58171 m .24193 .58509 L .24096 .58265 L F
.459 0 0 r
.24193 .58509 m .24228 .58541 L .24096 .58265 L F
.24193 .58509 m .24423 .58701 L .24228 .58541 L F
.64 .486 .658 r
.27145 .57492 m .2692 .57776 L .27058 .57833 L F
.066 0 0 r
.24799 .52083 m .25042 .52046 L .2502 .52021 L F
0 0 0 r
.2502 .52021 m .25229 .51891 L .25413 .51693 L F
.2502 .52021 m .25042 .52046 L .25229 .51891 L F
.243 .379 .802 r
.2996 .54108 m .30192 .54208 L .30033 .53827 L F
.672 .92 .974 r
.66028 .38752 m .66132 .38851 L .6638 .38712 L F
.728 .932 .599 r
.31735 .63507 m .31706 .63645 L .31907 .6336 L F
0 0 .56 r
.31902 .63902 m .31706 .63645 L .31735 .63507 L F
.437 .481 .807 r
.22558 .59186 m .22685 .59561 L .22904 .59391 L F
.658 .503 .663 r
.22685 .59561 m .23161 .59754 L .22904 .59391 L F
.22685 .59561 m .22765 .59784 L .23161 .59754 L F
.991 .776 .394 r
.46266 .53549 m .46364 .53863 L .46696 .53631 L F
.687 .575 .724 r
.46794 .53992 m .47014 .53554 L .46696 .53631 L F
.798 .809 .861 r
.43751 .46542 m .43515 .46815 L .43845 .46744 L F
0 0 0 r
.43517 .47076 m .43845 .46744 L .43515 .46815 L F
.43517 .47076 m .43762 .46942 L .43845 .46744 L F
0 .072 .633 r
.43751 .46542 m .43899 .46765 L .43845 .46744 L F
.588 .181 .24 r
.43762 .46942 m .43899 .46765 L .43845 .46744 L F
0 0 .307 r
.28561 .65893 m .28601 .65976 L .28551 .65871 L F
.669 .971 .906 r
.28103 .66187 m .28601 .65976 L .28561 .65893 L F
.544 .305 .502 r
.52966 .48156 m .53228 .48365 L .52955 .48396 L F
.62 .271 .357 r
.52966 .48156 m .53235 .48174 L .53228 .48365 L F
.348 .404 .777 r
.54036 .45636 m .54184 .45374 L .53969 .45459 L F
0 0 0 r
.54157 .4539 m .53969 .45459 L .54184 .45374 L F
.697 .684 .834 r
.5374 .45542 m .54036 .45636 L .53969 .45459 L F
0 0 0 r
.53808 .45607 m .53969 .45459 L .54157 .4539 L F
.697 .684 .834 r
.53712 .45533 m .5374 .45542 L .53969 .45459 L F
.348 .404 .777 r
.54036 .45636 m .54431 .45903 L .54184 .45374 L F
0 0 0 r
.25413 .51693 m .25453 .51798 L .25675 .51718 L F
.25413 .51693 m .25229 .51891 L .25453 .51798 L F
.148 .639 .917 r
.4651 .51073 m .46414 .50993 L .46379 .51041 L F
.4651 .51073 m .46414 .50993 L .46172 .5099 L F
.927 .851 .748 r
.46324 .51176 m .46414 .50993 L .46397 .51272 L F
0 0 .378 r
.46443 .50953 m .46414 .50993 L .46324 .51176 L F
.46462 .50917 m .46414 .50993 L .46443 .50953 L F
.148 .639 .917 r
.46379 .51041 m .46414 .50993 L .46172 .5099 L F
.156 0 0 r
.46763 .50736 m .46414 .50993 L .4651 .51073 L F
.551 .384 .608 r
.46773 .5104 m .46763 .50736 L .4651 .51073 L F
.435 .062 .23 r
.46397 .51272 m .46773 .5104 L .4651 .51073 L F
.485 .127 .282 r
.28399 .54649 m .28332 .5483 L .28066 .54853 L F
.861 .84 .824 r
.28629 .54288 m .28399 .54649 L .28187 .54462 L F
.513 .362 .613 r
.28665 .54582 m .28399 .54649 L .28629 .54288 L F
.574 .307 .474 r
.28665 .54582 m .28332 .5483 L .28399 .54649 L F
.843 .882 .869 r
.51362 .41179 m .51186 .41409 L .51025 .41261 L F
.243 .368 .791 r
.56095 .43942 m .55946 .43553 L .55967 .43755 L F
.578 .267 .405 r
.5611 .44137 m .56356 .44141 L .56095 .43942 L F
.612 .244 .321 r
.56356 .44141 m .56416 .43969 L .56095 .43942 L F
.658 .597 .775 r
.36203 .55239 m .36346 .5559 L .36043 .55546 L F
0 0 0 r
.36346 .5559 m .36012 .55851 L .36043 .55546 L F
.871 .811 .789 r
.65229 .33752 m .65642 .33589 L .65549 .33492 L F
.65229 .33752 m .65428 .33944 L .65642 .33589 L F
.763 .942 .94 r
.65727 .33303 m .65549 .33492 L .65642 .33589 L F
.682 .722 .879 r
.57241 .41665 m .57645 .4182 L .57544 .41579 L F
.152 .681 .866 r
.57645 .4182 m .57783 .41777 L .57544 .41579 L F
.57645 .4182 m .58053 .41821 L .57783 .41777 L F
.54 .269 .453 r
.52334 .48505 m .52315 .48734 L .52045 .48772 L F
.583 .316 .477 r
.5271 .4842 m .52315 .48734 L .52334 .48505 L F
.502 .764 .989 r
.52635 .44399 m .52797 .44555 L .52519 .44594 L F
.433 .159 .396 r
.35862 .59839 m .36091 .59837 L .36079 .59534 L F
.399 .134 .393 r
.36079 .59534 m .36371 .59698 L .36382 .59379 L F
.36079 .59534 m .36091 .59837 L .36371 .59698 L F
.689 .866 .965 r
.36943 .62227 m .37284 .62292 L .36841 .62405 L F
.878 .484 .026 r
.37099 .6258 m .37067 .62426 L .37112 .62604 L F
.544 .182 .305 r
.36841 .62405 m .37051 .62351 L .37067 .62426 L F
.695 .889 .515 r
.36943 .62227 m .36841 .62405 L .36911 .62252 L F
.37 .694 .982 r
.36841 .62405 m .37067 .62426 L .36911 .62252 L F
.878 .484 .026 r
.36911 .62252 m .37067 .62426 L .37099 .6258 L F
.544 .182 .305 r
.37051 .62351 m .37284 .62292 L .37067 .62426 L F
.516 .609 .884 r
.37363 .62071 m .37284 .62292 L .36943 .62227 L F
.739 .455 .5 r
.37284 .62292 m .37112 .62604 L .37067 .62426 L F
.37284 .62292 m .37509 .6268 L .37112 .62604 L F
.493 .511 .804 r
.32375 .54296 m .32573 .54344 L .32608 .542 L F
.591 .586 .815 r
.63059 .39021 m .63195 .39412 L .63371 .39258 L F
.516 .477 .752 r
.32608 .542 m .3283 .53912 L .3266 .5395 L F
.32608 .542 m .32872 .54292 L .3283 .53912 L F
.866 .576 .495 r
.32817 .54404 m .32608 .542 L .32573 .54344 L F
.32817 .54404 m .32872 .54292 L .32608 .542 L F
.993 .875 .553 r
.73503 .32065 m .73579 .32059 L .735 .31922 L F
.756 .994 .809 r
.73488 .32262 m .73715 .32049 L .73579 .32059 L F
0 0 .212 r
.73508 .32289 m .73488 .32262 L .73579 .32059 L F
.993 .875 .553 r
.73508 .32289 m .73579 .32059 L .73503 .32065 L F
.756 .994 .809 r
.73715 .32049 m .73768 .31999 L .73579 .32059 L F
.487 .865 .653 r
.54925 .4612 m .54485 .46419 L .54758 .46402 L F
.549 0 0 r
.5509 .46317 m .54925 .4612 L .54758 .46402 L F
.5509 .46317 m .55212 .46205 L .54925 .4612 L F
.598 .301 .437 r
.4454 .48582 m .44613 .48753 L .44331 .48782 L F
0 0 .388 r
.44593 .48597 m .4454 .48582 L .44806 .48425 L F
.44593 .48597 m .44613 .48753 L .4454 .48582 L F
.203 0 0 r
.29154 .64388 m .28755 .64306 L .29006 .64236 L F
.855 .934 .876 r
.73956 .31673 m .74009 .31364 L .73946 .31463 L F
.73956 .31673 m .7429 .31315 L .74009 .31364 L F
.301 0 0 r
.58017 .4272 m .57783 .42654 L .57803 .42884 L F
.933 .671 .193 r
.43524 .59481 m .4345 .59449 L .43491 .59168 L F
0 0 0 r
.43491 .59168 m .4345 .59449 L .43634 .58993 L F
.785 .787 .853 r
.54431 .45903 m .54485 .463 L .54154 .46127 L F
.315 .431 .821 r
.5466 .46056 m .54485 .463 L .54431 .45903 L F
.63 .069 0 r
.54154 .46127 m .54309 .46208 L .54364 .46276 L F
.54309 .46208 m .54485 .463 L .54364 .46276 L F
.702 .979 .906 r
.54364 .46276 m .54485 .463 L .5466 .46056 L F
.425 .267 .562 r
.54485 .46419 m .54516 .46672 L .54758 .46402 L F
.773 .69 .772 r
.54645 .46253 m .54501 .46445 L .54364 .46276 L F
.762 .66 .75 r
.54134 .46415 m .54485 .46419 L .54364 .46276 L F
.773 .69 .772 r
.54501 .46445 m .54386 .46598 L .54364 .46276 L F
.866 .775 .759 r
.43451 .5132 m .43266 .51645 L .43597 .51674 L F
.797 .749 .808 r
.43451 .5132 m .43597 .51674 L .43862 .51371 L F
.683 .905 .974 r
.62938 .33994 m .62693 .34162 L .62584 .34055 L F
.886 .96 .623 r
.62957 .36222 m .62904 .36496 L .63093 .36142 L F
.771 .735 .82 r
.63093 .36142 m .63418 .35841 L .63024 .35705 L F
.63085 .36091 m .63024 .35705 L .63076 .36043 L F
0 .007 .522 r
.63214 .35861 m .63076 .36043 L .63024 .35705 L F
.652 .965 .795 r
.63063 .35975 m .63076 .36043 L .63214 .35861 L F
.62869 .36121 m .63076 .36043 L .63063 .35975 L F
.771 .735 .82 r
.63093 .36142 m .63085 .36091 L .63076 .36043 L F
.963 .726 .531 r
.24423 .58701 m .24571 .59106 L .24613 .58844 L F
.821 .959 .902 r
.36918 .69423 m .37358 .69244 L .37172 .6913 L F
.913 .978 .708 r
.37358 .69244 m .37469 .68916 L .37172 .6913 L F
0 0 .229 r
.22622 .54641 m .22668 .54918 L .22675 .54736 L F
.438 .197 .449 r
.33029 .55924 m .33026 .5619 L .32761 .56177 L F
.442 .228 .491 r
.33026 .5619 m .32756 .56604 L .32761 .56177 L F
.844 .703 .707 r
.41797 .48321 m .42222 .48136 L .41989 .48041 L F
.41797 .48321 m .42109 .48375 L .42222 .48136 L F
.264 0 .093 r
.42109 .48375 m .42475 .48156 L .42222 .48136 L F
.587 .389 .58 r
.42741 .47817 m .4307 .47779 L .42997 .47511 L F
.203 .155 .578 r
.42997 .47511 m .43225 .47613 L .4326 .4745 L F
.42997 .47511 m .4307 .47779 L .43225 .47613 L F
.754 .535 .599 r
.56479 .40984 m .56091 .41308 L .56071 .40975 L F
.56479 .40984 m .5642 .41299 L .56091 .41308 L F
0 0 0 r
.69273 .28704 m .69042 .29052 L .69231 .28848 L F
.624 .955 .795 r
.69231 .28848 m .69042 .29052 L .68887 .29083 L F
.414 .105 .33 r
.43608 .49043 m .43273 .49325 L .43318 .49119 L F
.115 0 0 r
.42661 .49288 m .42859 .49253 L .43029 .49083 L F
.209 .673 .943 r
.43029 .49083 m .43023 .48923 L .43266 .49084 L F
.43229 .49108 m .43266 .49084 L .43318 .49119 L F
.43029 .49083 m .43266 .49084 L .43229 .49108 L F
.636 .91 .982 r
.43318 .49119 m .43345 .48943 L .43601 .48763 L F
.555 .518 .769 r
.43601 .48763 m .43608 .49043 L .43318 .49119 L F
0 0 .324 r
.43273 .49325 m .43393 .4913 L .43365 .49021 L F
.43326 .49046 m .43365 .49021 L .43345 .48943 L F
.43273 .49325 m .43365 .49021 L .43326 .49046 L F
.686 .778 .921 r
.42859 .49253 m .43023 .48923 L .43029 .49083 L F
.42859 .49253 m .43273 .49325 L .43023 .48923 L F
.636 .91 .982 r
.43318 .49119 m .43023 .48923 L .43345 .48943 L F
0 0 .324 r
.43273 .49325 m .43345 .48943 L .43023 .48923 L F
.373 .759 .989 r
.42859 .49253 m .43323 .49263 L .43131 .49204 L F
.42859 .49253 m .43131 .49204 L .42931 .49143 L F
.115 0 0 r
.42607 .49318 m .42859 .49253 L .42661 .49288 L F
.64 .575 .766 r
.57041 .43916 m .57126 .44248 L .57132 .44058 L F
.613 .373 .53 r
.55251 .43267 m .55374 .42688 L .55141 .4316 L F
.55254 .4325 m .55451 .43068 L .55374 .42688 L F
.55261 .43256 m .55451 .43068 L .55254 .4325 L F
.5527 .43248 m .55305 .43245 L .55451 .43068 L F
.55279 .43263 m .5556 .43226 L .5527 .43248 L F
.52 .145 .27 r
.5546 .43431 m .5556 .43226 L .55291 .43261 L F
.55285 .43268 m .55291 .43261 L .55279 .43263 L F
.5546 .43431 m .55291 .43261 L .55285 .43268 L F
.865 .849 .826 r
.5518 .42956 m .55141 .4316 L .55374 .42688 L F
.702 .248 .17 r
.55304 .42785 m .55086 .42555 L .55221 .429 L F
.55374 .42688 m .55359 .42681 L .55304 .42785 L F
.55359 .42681 m .55086 .42555 L .55304 .42785 L F
.55221 .429 m .55044 .42536 L .5518 .42956 L F
.55086 .42555 m .55044 .42536 L .55221 .429 L F
.564 .467 .703 r
.54875 .43022 m .5518 .42956 L .55044 .42536 L F
.72 .709 .839 r
.54887 .43255 m .5518 .42956 L .54875 .43022 L F
.54887 .43255 m .55141 .4316 L .5518 .42956 L F
.595 .646 .871 r
.55261 .42706 m .55177 .43024 L .55018 .43192 L F
.55177 .43024 m .55141 .4316 L .55099 .43171 L F
.55177 .43024 m .55099 .43171 L .55018 .43192 L F
.014 .143 .655 r
.55461 .42884 m .55328 .43174 L .55261 .42706 L F
.55328 .43174 m .55285 .43268 L .55275 .43039 L F
.55328 .43174 m .55275 .43039 L .55261 .42706 L F
.55285 .43268 m .55284 .43267 L .55261 .42706 L F
.55284 .4327 m .55284 .4327 L .55261 .42706 L F
.595 .646 .871 r
.55261 .42706 m .55284 .4327 L .55141 .4316 L F
.751 .952 .638 r
.55278 .43136 m .55284 .43269 L .55461 .42884 L F
.55271 .43146 m .55284 .43269 L .55278 .43136 L F
.55271 .43146 m .55284 .43269 L .55284 .43269 L F
.014 .143 .655 r
.55285 .43268 m .55284 .4327 L .55284 .43267 L F
.55284 .4327 m .55284 .4327 L .55284 .4327 L F
.751 .952 .638 r
.55284 .43269 m .55284 .4327 L .55285 .43268 L F
.55284 .43269 m .55285 .43268 L .55461 .42884 L F
.52 .145 .27 r
.55451 .43449 m .5546 .43431 L .55251 .43267 L F
.751 .952 .638 r
.55284 .4327 m .55284 .4327 L .55284 .4327 L F
.52 .145 .27 r
.5546 .43431 m .55279 .43263 L .55251 .43267 L F
.751 .952 .638 r
.55284 .4327 m .55284 .4327 L .55461 .42884 L F
.613 .373 .53 r
.55305 .43245 m .5556 .43226 L .55452 .4307 L F
.55305 .43245 m .55452 .4307 L .55451 .43068 L F
.55251 .43267 m .55279 .43263 L .5527 .43248 L F
0 .319 .78 r
.55157 .43159 m .55284 .4327 L .55271 .43146 L F
.55141 .4316 m .5524 .43237 L .55157 .43159 L F
.5524 .43237 m .55284 .4327 L .55157 .43159 L F
.613 .373 .53 r
.55251 .43267 m .55261 .43256 L .55254 .4325 L F
.95 .95 .649 r
.39373 .59653 m .39285 .60084 L .39433 .59871 L F
.651 .814 .962 r
.57701 .45478 m .58094 .45539 L .5793 .45417 L F
.463 .744 .99 r
.5793 .45417 m .58094 .45539 L .58357 .45484 L F
0 0 0 r
.69772 .33045 m .69521 .33119 L .69432 .33328 L F
.987 .713 .381 r
.5981 .36977 m .59762 .3716 L .59947 .37114 L F
0 .287 .777 r
.60106 .37125 m .60249 .37305 L .59947 .37114 L F
.60106 .37125 m .59947 .37114 L .59762 .3716 L F
0 0 .026 r
.47598 .58024 m .47592 .57867 L .47607 .57771 L F
.47598 .58024 m .47588 .58131 L .47592 .57867 L F
.876 .992 .747 r
.62725 .36574 m .62652 .36848 L .62904 .36496 L F
.865 .993 .818 r
.62434 .36913 m .62652 .36848 L .62725 .36574 L F
.795 .834 .881 r
.59562 .35475 m .59975 .35473 L .5983 .35335 L F
.485 .793 .999 r
.59975 .35473 m .60244 .3541 L .5983 .35335 L F
.947 .699 .531 r
.70883 .31112 m .71135 .30916 L .70746 .30984 L F
.70883 .31112 m .71041 .31205 L .71135 .30916 L F
.57 .271 .422 r
.71135 .30916 m .71386 .31027 L .71429 .30929 L F
.71135 .30916 m .71041 .31205 L .71386 .31027 L F
.644 .957 .933 r
.67208 .38011 m .67265 .38073 L .67504 .3792 L F
.776 .932 .934 r
.45628 .44548 m .45439 .44866 L .45303 .44736 L F
.45628 .44548 m .45784 .44636 L .45439 .44866 L F
.805 .693 .741 r
.38344 .66259 m .3855 .66271 L .3861 .65955 L F
.804 .701 .752 r
.38393 .66522 m .3855 .66271 L .38344 .66259 L F
.805 .693 .741 r
.3861 .65955 m .3855 .66271 L .38344 .66259 L F
.804 .701 .752 r
.38344 .66259 m .3855 .66271 L .38393 .66522 L F
.805 .693 .741 r
.38344 .66259 m .3855 .66271 L .3861 .65955 L F
.324 .218 .576 r
.3266 .5395 m .3283 .53912 L .32812 .53623 L F
.715 .713 .847 r
.35389 .63735 m .35459 .64015 L .35174 .63989 L F
.78 .503 .518 r
.35459 .64015 m .35199 .64253 L .35174 .63989 L F
.35459 .64015 m .35496 .64342 L .35199 .64253 L F
.007 .195 .708 r
.35577 .63838 m .35459 .64015 L .35389 .63735 L F
.663 .682 .858 r
.35577 .63838 m .35496 .64342 L .35459 .64015 L F
.98 .705 .426 r
.44563 .56766 m .44722 .56882 L .44666 .56611 L F
.832 1 .804 r
.41341 .46983 m .413 .47191 L .41511 .46947 L F
.898 .626 .519 r
.32644 .4978 m .32864 .50105 L .32777 .49985 L F
.705 .192 .008 r
.32864 .50105 m .32926 .50326 L .32777 .49985 L F
.32864 .50105 m .33061 .50294 L .32926 .50326 L F
.63 .63 .831 r
.34732 .61037 m .34566 .61383 L .34504 .61082 L F
.34732 .61037 m .34822 .61243 L .34566 .61383 L F
.506 .789 .996 r
.46142 .47877 m .46051 .47795 L .45783 .4784 L F
.564 .786 .982 r
.46142 .47877 m .4631 .47709 L .46051 .47795 L F
.46142 .47877 m .46425 .47821 L .4631 .47709 L F
.661 .869 .978 r
.73287 .32912 m .73603 .32931 L .73482 .32791 L F
.997 .835 .489 r
.73603 .32931 m .73562 .32551 L .73482 .32791 L F
0 0 .14 r
.47945 .56538 m .47961 .56736 L .4784 .56891 L F
0 0 .261 r
.4784 .56891 m .47946 .57011 L .47837 .57166 L F
.4784 .56891 m .47961 .56736 L .47946 .57011 L F
.502 .112 .233 r
.36879 .54984 m .3653 .55184 L .36526 .54942 L F
.36879 .54984 m .3682 .55174 L .3653 .55184 L F
.477 .089 .224 r
.37105 .55135 m .3682 .55174 L .36879 .54984 L F
.233 .599 .951 r
.25966 .60557 m .25985 .60771 L .25821 .60644 L F
.25966 .60557 m .26206 .6076 L .25985 .60771 L F
.367 .492 .853 r
.23063 .57374 m .23252 .57764 L .22961 .57627 L F
.647 .969 .862 r
.42857 .45282 m .42553 .45492 L .42653 .45324 L F
.641 .966 .879 r
.42653 .45324 m .42553 .45492 L .42452 .45471 L F
.75 .64 .738 r
.42878 .50765 m .42804 .51079 L .43064 .51045 L F
.407 .489 .832 r
.42804 .51079 m .43104 .51268 L .43064 .51045 L F
.675 .574 .734 r
.43104 .51268 m .43402 .50993 L .43064 .51045 L F
.904 .572 .406 r
.61063 .39571 m .61207 .39393 L .60989 .39376 L F
.589 .224 .316 r
.61403 .39563 m .61207 .39393 L .61063 .39571 L F
.61403 .39563 m .61423 .39441 L .61207 .39393 L F
0 .207 .729 r
.61403 .39563 m .61207 .39393 L .61423 .39441 L F
.561 .812 .436 r
.3634 .62275 m .36466 .62114 L .36583 .61963 L F
.603 .95 .908 r
.23934 .52936 m .24003 .52807 L .24271 .52671 L F
0 0 .1 r
.23937 .52854 m .23979 .53151 L .24135 .5298 L F
.603 .95 .908 r
.23934 .52936 m .23803 .52922 L .24008 .52798 L F
0 0 .1 r
.23928 .52848 m .2393 .52859 L .23937 .52854 L F
.2393 .52859 m .23979 .53151 L .23937 .52854 L F
.603 .95 .908 r
.24003 .52807 m .24008 .52798 L .24031 .52786 L F
.24003 .52807 m .24031 .52786 L .24271 .52671 L F
.248 .444 .857 r
.27826 .63032 m .28223 .6336 L .28257 .63051 L F
0 0 .379 r
.34182 .60062 m .34037 .60449 L .33894 .6007 L F
0 0 0 r
.34147 .60505 m .33845 .60527 L .34037 .60449 L F
.715 .965 .71 r
.58603 .35503 m .58574 .35474 L .58735 .35286 L F
.778 .847 .903 r
.59449 .45834 m .5961 .46046 L .59833 .45839 L F
.89 .988 .741 r
.62725 .36574 m .62904 .36496 L .62957 .36222 L F
.632 .913 .981 r
.56684 .42237 m .56458 .42249 L .56679 .42307 L F
.414 0 0 r
.56856 .42137 m .56729 .42272 L .56717 .42271 L F
0 0 0 r
.56985 .42012 m .56856 .42137 L .56679 .42307 L F
.53 .834 .999 r
.56679 .42307 m .56856 .42137 L .56684 .42237 L F
.414 0 0 r
.56856 .42137 m .56465 .42264 L .56684 .42237 L F
.56856 .42137 m .56717 .42271 L .56465 .42264 L F
0 0 0 r
.56997 .42001 m .56856 .42137 L .56985 .42012 L F
.505 .284 .513 r
.51488 .4912 m .51475 .49364 L .51209 .49422 L F
.52 .302 .524 r
.5175 .49058 m .51475 .49364 L .51488 .4912 L F
.679 .387 .472 r
.33348 .5612 m .33029 .55924 L .33417 .55936 L F
.381 .073 .314 r
.33693 .55989 m .33417 .55936 L .3369 .55897 L F
.33693 .55989 m .33348 .5612 L .33417 .55936 L F
0 0 0 r
.27145 .52036 m .2681 .52067 L .26714 .52073 L F
.398 0 .025 r
.27838 .57425 m .28085 .57427 L .28277 .57218 L F
.041 0 0 r
.27326 .51901 m .2681 .52067 L .27145 .52036 L F
.661 .228 .209 r
.28277 .57218 m .28085 .57427 L .285 .57429 L F
.536 .124 .207 r
.24519 .57755 m .24803 .57778 L .24979 .57523 L F
0 0 0 r
.24979 .57523 m .25088 .57564 L .25157 .57483 L F
.24979 .57523 m .24803 .57778 L .25088 .57564 L F
.227 0 0 r
.55914 .40815 m .55526 .41091 L .5577 .4103 L F
.673 .836 .413 r
.55785 .41003 m .55914 .40815 L .5577 .4103 L F
.701 .212 .082 r
.55704 .40652 m .55998 .40691 L .55914 .40815 L F
.227 0 0 r
.55914 .40815 m .55703 .4084 L .55526 .41091 L F
.404 .379 .717 r
.55914 .40815 m .55703 .4084 L .55704 .40652 L F
.026 .313 .802 r
.55704 .40652 m .55914 .40815 L .55749 .40499 L F
.305 .51 .891 r
.55749 .40499 m .55914 .40815 L .56023 .40593 L F
.55749 .40499 m .55914 .40815 L .56023 .40593 L F
.673 .836 .413 r
.56023 .40593 m .55914 .40815 L .55785 .41003 L F
.701 .212 .082 r
.55998 .40691 m .56105 .40705 L .55914 .40815 L F
.982 .735 .482 r
.56105 .40705 m .56071 .40975 L .55914 .40815 L F
.822 .38 .185 r
.35286 .50241 m .35451 .50114 L .35103 .49957 L F
.796 .34 .158 r
.35513 .50287 m .35451 .50114 L .35286 .50241 L F
.755 .935 .945 r
.48095 .43198 m .47878 .43359 L .47743 .43267 L F
.588 .811 .984 r
.41953 .49063 m .4237 .49127 L .42197 .48989 L F
.902 .939 .825 r
.41968 .49267 m .4237 .49127 L .41953 .49063 L F
.41968 .49267 m .42076 .49482 L .4237 .49127 L F
.37 .697 .983 r
.4237 .49127 m .42198 .48963 L .42197 .48989 L F
.4237 .49127 m .42542 .49091 L .42198 .48963 L F
.83 .536 .492 r
.33061 .50294 m .33553 .50412 L .33552 .50649 L F
.392 .182 .471 r
.33552 .50649 m .33553 .50412 L .33758 .50377 L F
0 0 0 r
.5332 .4043 m .53011 .40715 L .53523 .40293 L F
.539 .688 .936 r
.43114 .4643 m .43241 .46148 L .42942 .46361 L F
.43114 .4643 m .43406 .46415 L .43241 .46148 L F
.838 .677 .683 r
.45644 .56544 m .45785 .56958 L .45302 .56798 L F
.593 .316 .466 r
.4115 .48426 m .41445 .48435 L .4147 .48171 L F
.548 .278 .458 r
.4147 .48171 m .41736 .48358 L .41808 .48108 L F
.4147 .48171 m .41445 .48435 L .41736 .48358 L F
0 0 .412 r
.367 .55645 m .3678 .55721 L .36826 .55461 L F
.367 .55645 m .36761 .55907 L .3678 .55721 L F
.515 .305 .532 r
.35507 .62696 m .35786 .62649 L .35626 .62431 L F
.704 .62 .761 r
.34537 .68882 m .34814 .68791 L .34781 .68555 L F
.658 .472 .621 r
.34781 .68555 m .35058 .68224 L .34682 .68136 L F
.723 .57 .682 r
.44492 .4974 m .44743 .50133 L .44228 .5007 L F
.478 .283 .536 r
.49854 .51305 m .4959 .51612 L .49632 .51403 L F
.315 .258 .633 r
.32192 .62737 m .32239 .63049 L .32431 .62932 L F
.439 0 .025 r
.30796 .5404 m .30606 .53969 L .30885 .53931 L F
.30796 .5404 m .30435 .54146 L .30606 .53969 L F
.55 .107 .151 r
.44066 .4806 m .44106 .4815 L .4378 .48114 L F
.7 .967 .733 r
.55672 .41994 m .55612 .41997 L .55791 .41806 L F
.399 .282 .603 r
.55951 .42197 m .55672 .41994 L .55791 .41806 L F
.55951 .42197 m .55712 .42274 L .55672 .41994 L F
.647 .61 .799 r
.36392 .69573 m .36511 .69131 L .36252 .69196 L F
.36392 .69573 m .36662 .69505 L .36511 .69131 L F
.937 .652 .185 r
.58902 .40803 m .58946 .40679 L .58884 .40687 L F
.58902 .40803 m .59012 .41021 L .58946 .40679 L F
.473 .889 .787 r
.34562 .65439 m .34776 .65379 L .34998 .65252 L F
.184 0 0 r
.25614 .61884 m .25554 .61733 L .25325 .61916 L F
.25614 .61884 m .25803 .61649 L .25554 .61733 L F
.482 .232 .458 r
.51475 .49364 m .51167 .49696 L .51209 .49422 L F
.85 .699 .695 r
.29298 .65274 m .29485 .65032 L .29145 .64887 L F
0 .429 .698 r
.34419 .4972 m .34038 .49623 L .34228 .49702 L F
.297 0 0 r
.34483 .49802 m .34419 .4972 L .34228 .49702 L F
.34483 .49802 m .34654 .49765 L .34419 .4972 L F
.787 .636 .694 r
.32361 .6536 m .32579 .65668 L .3248 .65385 L F
.989 .859 .619 r
.3248 .65385 m .32579 .65668 L .32492 .65945 L F
.392 .263 .584 r
.44478 .5227 m .44719 .52334 L .44443 .52363 L F
.44692 .52279 m .44719 .52334 L .44478 .5227 L F
.422 .21 .484 r
.44652 .52547 m .44443 .52363 L .44719 .52334 L F
.392 .263 .584 r
.44569 .52024 m .44692 .52279 L .44478 .5227 L F
.739 .411 .426 r
.44238 .52222 m .44719 .52334 L .44569 .52024 L F
.962 .849 .684 r
.44476 .52379 m .44719 .52334 L .44238 .52222 L F
.44476 .52379 m .44652 .52547 L .44719 .52334 L F
.199 0 0 r
.44476 .52379 m .44853 .52256 L .44652 .52547 L F
.44476 .52379 m .44739 .52363 L .44823 .52284 L F
.44774 .52282 m .44823 .52284 L .44853 .52256 L F
.44476 .52379 m .44823 .52284 L .44774 .52282 L F
.422 .21 .484 r
.44652 .52547 m .44412 .52625 L .44443 .52363 L F
.727 .7 .825 r
.55571 .44868 m .55969 .44924 L .55865 .4472 L F
.515 .297 .521 r
.55684 .45253 m .55969 .44924 L .55571 .44868 L F
.55684 .45253 m .55979 .45187 L .55969 .44924 L F
.695 .759 .901 r
.55969 .44924 m .56163 .44565 L .55865 .4472 L F
.55969 .44924 m .56291 .44844 L .56163 .44565 L F
.671 .45 .577 r
.55979 .45187 m .56291 .44844 L .55969 .44924 L F
.929 .585 .144 r
.59432 .3925 m .59557 .3939 L .59592 .39611 L F
.932 .761 .284 r
.70233 .35063 m .70253 .34863 L .70186 .34986 L F
0 0 .03 r
.70253 .34863 m .70416 .34388 L .70261 .34752 L F
.809 .813 .328 r
.70186 .34986 m .70253 .34863 L .70261 .34752 L F
.4 .145 .408 r
.34799 .6074 m .34732 .61037 L .34504 .61082 L F
.586 .314 .471 r
.3509 .6098 m .34799 .6074 L .35066 .60695 L F
.3509 .6098 m .34732 .61037 L .34799 .6074 L F
.269 .329 .741 r
.34799 .6074 m .3509 .6098 L .35066 .60695 L F
.463 .783 .998 r
.25325 .60293 m .25597 .60437 L .25268 .60453 L F
.77 .676 .759 r
.25597 .60437 m .25244 .60732 L .25268 .60453 L F
.52 .539 .816 r
.25244 .60732 m .25325 .60293 L .25268 .60453 L F
.037 .29 .783 r
.37845 .60426 m .3778 .60109 L .37645 .60049 L F
.37845 .60426 m .37944 .6042 L .3778 .60109 L F
.096 .17 .652 r
.61246 .37623 m .61133 .37439 L .61313 .37268 L F
.551 .465 .711 r
.31856 .61533 m .3195 .61731 L .31951 .61422 L F
0 0 .087 r
.31951 .61422 m .3195 .61731 L .31976 .61624 L F
.678 .536 .685 r
.31984 .61447 m .31991 .61844 L .32233 .61543 L F
0 0 .087 r
.31979 .61556 m .31976 .61624 L .31981 .61606 L F
.31979 .61556 m .31981 .61606 L .31982 .61567 L F
.31951 .61422 m .31976 .61624 L .31979 .61556 L F
.31951 .61422 m .31982 .61567 L .31757 .61298 L F
.678 .536 .685 r
.31904 .61501 m .31946 .61667 L .31982 .61567 L F
.731 .88 .474 r
.31981 .61606 m .3195 .61731 L .31958 .61645 L F
.678 .536 .685 r
.31958 .61645 m .31978 .61766 L .31981 .61606 L F
.31946 .61667 m .31981 .61606 L .31982 .61567 L F
.731 .88 .474 r
.31986 .61586 m .31981 .61606 L .31958 .61645 L F
.678 .536 .685 r
.31978 .61792 m .31991 .61844 L .31984 .61447 L F
.731 .88 .474 r
.31986 .61586 m .31958 .61645 L .31991 .61844 L F
.468 .172 .379 r
.31824 .61932 m .3195 .61731 L .31613 .6198 L F
.731 .88 .474 r
.31958 .61645 m .3195 .61731 L .31824 .61932 L F
.31958 .61645 m .31824 .61932 L .31991 .61844 L F
.678 .536 .685 r
.31946 .61667 m .31978 .61792 L .31978 .61766 L F
.31946 .61667 m .31978 .61766 L .31958 .61645 L F
0 0 .087 r
.31982 .61567 m .31986 .61586 L .31948 .61539 L F
.31982 .61567 m .31948 .61539 L .31757 .61298 L F
.678 .536 .685 r
.3188 .61407 m .31904 .61501 L .31984 .61447 L F
.31904 .61501 m .31982 .61567 L .31984 .61447 L F
0 0 .087 r
.31982 .61567 m .31981 .61606 L .31986 .61586 L F
.626 .586 .789 r
.3199 .61296 m .32233 .61543 L .32136 .61149 L F
.3188 .61407 m .31984 .61447 L .3199 .61296 L F
.31984 .61447 m .32233 .61543 L .3199 .61296 L F
.634 .958 .921 r
.55792 .38975 m .56201 .38681 L .56337 .38803 L F
.55792 .38975 m .55783 .38904 L .56201 .38681 L F
.621 .621 .83 r
.53162 .42957 m .53259 .42496 L .53058 .4265 L F
.53162 .42957 m .53455 .4289 L .53259 .42496 L F
.753 .668 .767 r
.53302 .43303 m .53455 .4289 L .53162 .42957 L F
0 0 .012 r
.69487 .28314 m .69273 .28704 L .6947 .2853 L F
0 0 0 r
.69273 .28704 m .69231 .28848 L .6947 .2853 L F
.587 .796 .979 r
.63717 .38752 m .63301 .38687 L .6356 .38379 L F
.779 .81 .878 r
.6384 .38314 m .63717 .38752 L .6356 .38379 L F
.6384 .38314 m .64004 .38543 L .63717 .38752 L F
.81 .876 .894 r
.34631 .50748 m .34954 .50736 L .34689 .50647 L F
.724 .926 .585 r
.35599 .53151 m .3552 .53327 L .35769 .52988 L F
.349 .142 .451 r
.35769 .52988 m .3552 .53327 L .35769 .5314 L F
.606 .374 .539 r
.3552 .53327 m .35789 .53497 L .35769 .5314 L F
0 0 .127 r
.356 .5338 m .3552 .53327 L .35599 .53151 L F
.606 .374 .539 r
.3552 .53327 m .35487 .53613 L .35789 .53497 L F
0 0 .127 r
.356 .5338 m .35487 .53613 L .3552 .53327 L F
.767 .745 .833 r
.37628 .62007 m .37501 .62396 L .37363 .62071 L F
.753 .668 .767 r
.53302 .43303 m .53548 .43277 L .53455 .4289 L F
.745 .577 .666 r
.53362 .4362 m .53548 .43277 L .53302 .43303 L F
.872 .907 .852 r
.53548 .43277 m .53662 .42821 L .53455 .4289 L F
.53548 .43277 m .53821 .42947 L .53662 .42821 L F
.814 .827 .86 r
.68757 .34169 m .68804 .34505 L .68473 .34449 L F
.864 .857 .832 r
.69073 .34158 m .68804 .34505 L .68757 .34169 L F
.742 .738 .848 r
.72589 .27023 m .72979 .27092 L .7275 .26752 L F
.401 .776 .993 r
.72589 .27023 m .72979 .27092 L .72919 .26996 L F
.508 .802 .999 r
.73754 .30849 m .73828 .30978 L .73438 .30912 L F
.766 .706 .796 r
.73438 .30912 m .73828 .30978 L .73426 .31151 L F
0 0 .434 r
.7275 .26752 m .72979 .27092 L .72919 .26996 L F
.869 .928 .862 r
.73754 .30849 m .74104 .30734 L .73828 .30978 L F
.156 0 0 r
.46763 .50736 m .46688 .50878 L .46414 .50993 L F
.316 .511 .888 r
.46763 .50736 m .46982 .50704 L .46884 .50558 L F
.316 .437 .826 r
.47075 .51016 m .46763 .50736 L .46773 .5104 L F
.47075 .51016 m .46982 .50704 L .46763 .50736 L F
.316 .511 .888 r
.46763 .50736 m .46884 .50558 L .46688 .50878 L F
.055 .3 .788 r
.35925 .59005 m .3572 .58921 L .3598 .58883 L F
.772 .966 .67 r
.38774 .48155 m .38514 .48479 L .38591 .48281 L F
.652 .151 .046 r
.38591 .48281 m .39007 .48347 L .38774 .48155 L F
.517 .251 .451 r
.38774 .48155 m .39007 .48347 L .39041 .48104 L F
0 0 0 r
.33926 .56609 m .33818 .56814 L .34068 .56477 L F
.882 .604 .511 r
.53195 .44443 m .53441 .44527 L .5345 .44257 L F
.459 .246 .502 r
.5345 .44257 m .53703 .4443 L .53744 .44167 L F
.5345 .44257 m .53441 .44527 L .53703 .4443 L F
.147 0 .108 r
.53771 .43975 m .5345 .44257 L .53744 .44167 L F
0 0 0 r
.38177 .48729 m .38338 .48647 L .38514 .48479 L F
.456 0 .003 r
.38514 .48479 m .38675 .48617 L .38591 .48281 L F
.38514 .48479 m .38338 .48647 L .38675 .48617 L F
.333 0 0 r
.45288 .59469 m .45672 .59415 L .45544 .59454 L F
.202 0 0 r
.45672 .59415 m .45922 .59401 L .45544 .59454 L F
0 0 .328 r
.52882 .41671 m .53034 .41222 L .53136 .41592 L F
.486 .321 .582 r
.52882 .41671 m .53122 .41918 L .53136 .41592 L F
.52882 .41671 m .53122 .41918 L .53136 .41592 L F
.873 .535 .407 r
.32654 .55553 m .32796 .55862 L .33029 .55924 L F
.882 .575 .463 r
.32796 .55862 m .32841 .55949 L .33029 .55924 L F
.656 .959 .935 r
.33029 .55924 m .32841 .55949 L .33123 .55746 L F
.679 .387 .472 r
.33348 .5612 m .33026 .5619 L .33029 .55924 L F
.999 .837 .512 r
.39613 .5815 m .39672 .57877 L .39559 .57685 L F
.737 .41 .428 r
.65826 .35226 m .66024 .35248 L .6606 .35155 L F
.327 .399 .784 r
.6606 .35155 m .66348 .35508 L .66178 .35054 L F
0 0 0 r
.66024 .35248 m .66178 .35054 L .6606 .35155 L F
.592 .945 .911 r
.6606 .35155 m .66178 .35054 L .65826 .35226 L F
.261 0 .223 r
.56046 .47164 m .56351 .46797 L .56304 .47084 L F
.43 .138 .367 r
.56613 .46711 m .56304 .47084 L .56351 .46797 L F
.897 .815 .759 r
.59906 .4538 m .60297 .45147 L .60012 .4514 L F
.59906 .4538 m .6008 .45513 L .60297 .45147 L F
.898 .48 .119 r
.39493 .52054 m .3938 .51992 L .39244 .51686 L F
.915 .519 .137 r
.39493 .52054 m .39432 .52182 L .3938 .51992 L F
.39493 .52054 m .39585 .52298 L .39432 .52182 L F
.424 .065 .25 r
.54146 .47977 m .54144 .48259 L .5388 .4829 L F
.398 .036 .228 r
.54544 .47796 m .54146 .47977 L .5427 .47853 L F
.54544 .47796 m .54454 .4804 L .54146 .47977 L F
.399 .042 .24 r
.54146 .47977 m .54407 .48208 L .54144 .48259 L F
.54146 .47977 m .54454 .4804 L .54407 .48208 L F
.757 .591 .671 r
.66844 .3454 m .66899 .34862 L .666 .34859 L F
.666 .34859 m .66899 .34862 L .66844 .3454 L F
.529 .441 .7 r
.66899 .34862 m .67086 .34448 L .66844 .3454 L F
.757 .591 .671 r
.66844 .3454 m .66899 .34862 L .666 .34859 L F
.336 .784 .627 r
.66278 .31948 m .65899 .32151 L .66116 .31965 L F
0 0 0 r
.66571 .31637 m .66278 .31948 L .66457 .31773 L F
.583 .944 .837 r
.66457 .31773 m .66278 .31948 L .66116 .31965 L F
.41 .137 .385 r
.4562 .54979 m .45872 .54888 L .45905 .54624 L F
.548 .515 .771 r
.46319 .54935 m .45905 .54624 L .46121 .54507 L F
.218 0 .329 r
.45905 .54624 m .45872 .54888 L .46121 .54507 L F
.919 .965 .657 r
.69939 .32449 m .69797 .32869 L .69788 .32759 L F
.663 .606 .78 r
.41686 .49353 m .41432 .49463 L .41291 .49074 L F
.183 0 0 r
.30067 .65408 m .30096 .65321 L .29909 .65466 L F
.30067 .65408 m .30329 .65271 L .30096 .65321 L F
.374 .433 .794 r
.70947 .29049 m .70771 .2933 L .70614 .29131 L F
.70947 .29049 m .70997 .29272 L .70771 .2933 L F
.969 .664 .275 r
.71108 .29227 m .70997 .29272 L .71139 .29205 L F
.345 .309 .675 r
.70997 .29272 m .71061 .29535 L .70801 .29352 L F
.969 .664 .275 r
.70924 .29359 m .71061 .29535 L .70997 .29272 L F
.70924 .29359 m .70997 .29272 L .71108 .29227 L F
.345 .309 .675 r
.70997 .29272 m .70801 .29352 L .70771 .2933 L F
.559 .242 .388 r
.70771 .2933 m .71061 .29535 L .70717 .29529 L F
.846 .4 0 r
.59815 .40071 m .60052 .40366 L .5995 .40228 L F
.953 .625 .215 r
.60052 .40366 m .59968 .40478 L .5995 .40228 L F
.60052 .40366 m .60092 .40607 L .59968 .40478 L F
.991 .776 .394 r
.46364 .53863 m .46249 .5382 L .46266 .53549 L F
.46266 .53549 m .46249 .5382 L .46364 .53863 L F
.543 .708 .948 r
.46783 .5238 m .46833 .52127 L .46649 .5216 L F
.46783 .5238 m .47048 .52322 L .46833 .52127 L F
.531 .473 .736 r
.4711 .52722 m .47048 .52322 L .46783 .5238 L F
.785 .537 .561 r
.24132 .53653 m .24091 .53914 L .23664 .53855 L F
0 0 .225 r
.24324 .53286 m .24255 .53627 L .24132 .53653 L F
0 0 0 r
.24255 .53627 m .24091 .53914 L .24132 .53653 L F
.537 .434 .685 r
.29951 .63363 m .30207 .63392 L .30101 .6301 L F
0 0 .388 r
.44593 .48597 m .44806 .48425 L .44718 .4837 L F
.477 .886 .938 r
.44985 .48271 m .44718 .4837 L .44806 .48425 L F
.784 .77 .841 r
.43769 .51067 m .43451 .5132 L .43862 .51371 L F
.592 .656 .882 r
.43769 .51067 m .43862 .51371 L .44123 .5129 L F
.897 .866 .8 r
.63523 .35357 m .6367 .35497 L .63888 .35164 L F
.855 .976 .865 r
.64196 .34842 m .63888 .35164 L .64027 .35003 L F
0 0 0 r
.70529 .29711 m .7044 .29824 L .70443 .29794 L F
.70681 .29686 m .70529 .29711 L .70717 .29529 L F
.70681 .29686 m .7044 .29824 L .70529 .29711 L F
.658 .472 .621 r
.34781 .68555 m .35085 .68479 L .35058 .68224 L F
.481 .271 .518 r
.35285 .68454 m .35305 .68173 L .35058 .68224 L F
.371 .263 .599 r
.35058 .68224 m .35085 .68479 L .35285 .68454 L F
.703 .862 .957 r
.41791 .46855 m .42205 .46854 L .42048 .46765 L F
.746 .994 .842 r
.42292 .46656 m .42205 .46854 L .42349 .46669 L F
.622 .893 .988 r
.42292 .46656 m .42048 .46765 L .42205 .46854 L F
.857 .76 .754 r
.42475 .48156 m .42726 .48134 L .42741 .47817 L F
.536 .343 .566 r
.42741 .47817 m .43021 .48051 L .4307 .47779 L F
.42741 .47817 m .42726 .48134 L .43021 .48051 L F
.447 .81 .995 r
.52267 .40739 m .51953 .40691 L .5234 .40406 L F
.419 .613 .93 r
.52442 .40513 m .52267 .40739 L .5234 .40406 L F
.365 .639 .96 r
.52267 .40739 m .52603 .40782 L .52584 .40722 L F
.214 .633 .953 r
.23547 .58519 m .23544 .58618 L .23085 .58518 L F
.23547 .58519 m .2379 .58627 L .23544 .58618 L F
.24 .463 .874 r
.23818 .58745 m .23544 .58618 L .2379 .58627 L F
0 0 .016 r
.22211 .55572 m .22324 .5551 L .22451 .55272 L F
.04 .014 .497 r
.22211 .55572 m .22346 .55777 L .22324 .5551 L F
.22211 .55572 m .22202 .55942 L .22346 .55777 L F
.272 .058 .395 r
.48918 .5298 m .48883 .53237 L .48684 .53306 L F
.297 .216 .593 r
.48904 .53511 m .48684 .53306 L .48883 .53237 L F
.48904 .53511 m .48739 .53627 L .48684 .53306 L F
.611 .918 .662 r
.66571 .31637 m .66737 .3144 L .66852 .31378 L F
0 0 0 r
.66571 .31637 m .66655 .31597 L .66737 .3144 L F
.66571 .31637 m .66457 .31773 L .66655 .31597 L F
.828 .379 .162 r
.33767 .62565 m .33911 .62415 L .33929 .62344 L F
.33767 .62565 m .33995 .62574 L .33911 .62415 L F
0 0 .511 r
.33911 .62415 m .33995 .62574 L .33929 .62344 L F
.678 .837 .412 r
.70105 .28431 m .69969 .28704 L .70175 .28338 L F
.102 .053 .511 r
.70197 .28725 m .69969 .28704 L .70105 .28431 L F
.70197 .28725 m .70006 .28958 L .69969 .28704 L F
.899 .965 .822 r
.32987 .6554 m .32913 .65792 L .32738 .6587 L F
0 0 .209 r
.33069 .65687 m .32913 .65792 L .32987 .6554 L F
.712 .952 .669 r
.67926 .35602 m .68068 .35523 L .67793 .35826 L F
.67 .884 .518 r
.67926 .35602 m .67793 .35826 L .67679 .3594 L F
.875 .443 .161 r
.67679 .3594 m .67793 .35826 L .67871 .3604 L F
.752 .376 .341 r
.67793 .35826 m .68026 .36035 L .67871 .3604 L F
.94 .818 .367 r
.68961 .31616 m .68923 .31911 L .68923 .31488 L F
.765 .912 .531 r
.55539 .39428 m .55404 .39732 L .55315 .39806 L F
.865 .923 .533 r
.70826 .33344 m .70779 .3361 L .70944 .33238 L F
.853 .901 .486 r
.70678 .33812 m .70779 .3361 L .70826 .33344 L F
0 0 0 r
.36346 .5559 m .36179 .55777 L .36012 .55851 L F
.461 .486 .798 r
.3656 .55501 m .36346 .5559 L .36203 .55239 L F
.382 .006 .195 r
.3656 .55501 m .36179 .55777 L .36346 .5559 L F
.869 .928 .862 r
.73754 .30849 m .73985 .30582 L .74104 .30734 L F
.018 .462 .873 r
.74138 .30655 m .74104 .30734 L .73985 .30582 L F
.74138 .30655 m .74349 .3081 L .74104 .30734 L F
.696 .615 .762 r
.34781 .68555 m .34814 .68791 L .35085 .68479 L F
.668 .572 .738 r
.34814 .68791 m .352 .68935 L .35085 .68479 L F
.144 .669 .879 r
.27809 .63027 m .27826 .63032 L .27393 .62973 L F
0 0 0 r
.44695 .58415 m .44869 .5835 L .44984 .58158 L F
.44695 .58415 m .44629 .58519 L .44869 .5835 L F
.44629 .58519 m .4463 .58519 L .44869 .5835 L F
.567 .346 .539 r
.4463 .58519 m .44869 .5835 L .44629 .5852 L F
.4463 .58519 m .4485 .5857 L .44869 .5835 L F
.052 .557 .882 r
.4474 .58486 m .4463 .58519 L .44419 .58421 L F
0 0 0 r
.44629 .58519 m .44629 .5852 L .4463 .58519 L F
.457 .587 .894 r
.57059 .41279 m .57099 .41375 L .56852 .41337 L F
.56852 .41337 m .57099 .41375 L .57059 .41279 L F
.482 .743 .986 r
.53948 .43881 m .53771 .43975 L .5356 .43797 L F
.077 0 .216 r
.53948 .43881 m .53771 .43975 L .53744 .44167 L F
.661 .776 .935 r
.63024 .35705 m .63418 .35841 L .63277 .3566 L F
.888 .867 .813 r
.63418 .35841 m .63523 .35357 L .63277 .3566 L F
0 0 0 r
.63214 .35861 m .63271 .35679 L .63487 .35542 L F
.63271 .35679 m .63277 .3566 L .63295 .3565 L F
.63271 .35679 m .63295 .3565 L .63487 .35542 L F
.888 .867 .813 r
.63418 .35841 m .6367 .35497 L .63531 .35364 L F
.63518 .3538 m .63531 .35364 L .63523 .35357 L F
.63418 .35841 m .63531 .35364 L .63518 .3538 L F
.625 .672 .875 r
.44725 .50215 m .44228 .5007 L .44743 .50133 L F
.432 .278 .571 r
.44743 .50133 m .4486 .50285 L .44725 .50215 L F
0 0 .39 r
.70084 .28933 m .70084 .2918 L .70006 .28958 L F
.773 .665 .112 r
.70079 .29067 m .70084 .2918 L .70084 .28933 L F
.447 .776 .998 r
.70084 .2918 m .70089 .29297 L .70006 .28958 L F
.773 .665 .112 r
.70066 .2937 m .70084 .2918 L .70079 .29067 L F
.447 .776 .998 r
.70084 .2918 m .7009 .29301 L .70089 .29297 L F
.70084 .2918 m .70365 .29269 L .7009 .29301 L F
.003 0 0 r
.3687 .68381 m .36778 .68345 L .36678 .68473 L F
.3687 .68381 m .37041 .68237 L .36778 .68345 L F
.595 .707 .922 r
.45783 .4784 m .45681 .47639 L .45386 .47707 L F
.38 .578 .918 r
.45783 .4784 m .45897 .47638 L .45681 .47639 L F
.529 .765 .984 r
.45783 .4784 m .46051 .47795 L .45897 .47638 L F
.713 .428 .493 r
.56356 .44141 m .56762 .4388 L .56416 .43969 L F
.56356 .44141 m .57055 .44293 L .56762 .4388 L F
.421 .745 .993 r
.5688 .43743 m .57041 .43916 L .56762 .4388 L F
.159 .252 .711 r
.56762 .4388 m .57027 .44156 L .5688 .43743 L F
.56762 .4388 m .57055 .44293 L .57027 .44156 L F
.107 0 0 r
.3441 .51491 m .34533 .51535 L .34603 .51208 L F
.3441 .51491 m .34307 .5159 L .34533 .51535 L F
.707 .692 .834 r
.37225 .63044 m .37576 .62977 L .37509 .6268 L F
0 0 0 r
.31048 .62381 m .30916 .62583 L .30966 .62626 L F
.448 .131 .335 r
.30966 .62626 m .31278 .62367 L .31048 .62381 L F
.869 .845 .818 r
.5526 .45715 m .5549 .45884 L .55727 .45535 L F
.46 .277 .545 r
.5549 .45884 m .55736 .45828 L .55727 .45535 L F
.42 .172 .429 r
.55469 .46112 m .55736 .45828 L .5549 .45884 L F
.733 .844 .933 r
.27399 .63493 m .27374 .63247 L .27093 .63323 L F
.27399 .63493 m .27589 .63399 L .27374 .63247 L F
.575 .28 .43 r
.7068 .29973 m .704 .30035 L .7044 .29824 L F
.35 .163 .481 r
.704 .30035 m .70602 .29959 L .70586 .2995 L F
.411 .862 .833 r
.704 .30035 m .70219 .30118 L .70443 .29794 L F
.704 .30035 m .70443 .29794 L .7044 .29824 L F
.35 .163 .481 r
.704 .30035 m .70586 .2995 L .70384 .29845 L F
.411 .862 .833 r
.704 .30035 m .70182 .30172 L .70219 .30118 L F
.704 .30035 m .70137 .30142 L .70182 .30172 L F
.799 .662 .711 r
.55368 .45181 m .55684 .45253 L .55571 .44868 L F
.991 .735 .415 r
.55574 .45392 m .55684 .45253 L .55368 .45181 L F
.55574 .45392 m .55727 .45535 L .55684 .45253 L F
.567 .46 .691 r
.55684 .45253 m .55727 .45535 L .55979 .45187 L F
0 0 .408 r
.48315 .55159 m .48318 .55434 L .48144 .55586 L F
.123 0 .41 r
.48318 .55434 m .48078 .55833 L .48144 .55586 L F
.799 .69 .744 r
.66178 .35054 m .66626 .35235 L .666 .34859 L F
.816 .404 .266 r
.66606 .35401 m .66626 .35235 L .66178 .35054 L F
.672 .537 .692 r
.66899 .34862 m .66626 .35235 L .666 .34859 L F
.66899 .34862 m .67003 .35146 L .66626 .35235 L F
.436 .409 .731 r
.66905 .35152 m .66626 .35235 L .666 .34859 L F
.281 .783 .805 r
.66626 .35235 m .67003 .35146 L .66905 .35152 L F
.227 0 .178 r
.66905 .35152 m .66626 .35235 L .66606 .35401 L F
.281 .783 .805 r
.66626 .35235 m .66905 .35152 L .66606 .35401 L F
.913 .816 .738 r
.55568 .4379 m .55967 .43755 L .55946 .43553 L F
.936 .571 .283 r
.5611 .44137 m .55967 .43755 L .55691 .4418 L F
.872 .83 .803 r
.54214 .42072 m .54549 .42029 L .54493 .41836 L F
.54214 .42072 m .54353 .42281 L .54549 .42029 L F
.213 0 .272 r
.54549 .42029 m .54353 .42281 L .54572 .42171 L F
.882 .961 .846 r
.54493 .41836 m .54549 .42029 L .54864 .41629 L F
.579 .588 .826 r
.33947 .53969 m .34289 .53954 L .34105 .53635 L F
.497 .324 .576 r
.33947 .53969 m .3426 .54107 L .34289 .53954 L F
.33947 .53969 m .33965 .54198 L .3426 .54107 L F
.858 .864 .843 r
.44021 .48505 m .43808 .48415 L .43919 .48225 L F
.871 .77 .747 r
.43378 .48322 m .43679 .48166 L .43696 .48143 L F
.43679 .48166 m .4378 .48114 L .43696 .48143 L F
.227 0 0 r
.44106 .4815 m .43958 .48185 L .43878 .48146 L F
.037 .557 .868 r
.43696 .48143 m .43958 .48185 L .43742 .4808 L F
.43696 .48143 m .43742 .4808 L .43734 .48077 L F
.388 .837 .735 r
.44106 .4815 m .43964 .48207 L .44332 .48037 L F
.43964 .48207 m .43919 .48225 L .43963 .48205 L F
.43964 .48207 m .43963 .48205 L .44332 .48037 L F
0 0 0 r
.43919 .48225 m .43808 .48415 L .43958 .48185 L F
.428 .865 .772 r
.44332 .48037 m .43931 .4822 L .43958 .48185 L F
.43931 .4822 m .43919 .48225 L .43958 .48185 L F
.11 .609 .902 r
.43958 .48185 m .44099 .48184 L .43986 .48151 L F
.43958 .48185 m .43986 .48151 L .43734 .48077 L F
.338 .231 .583 r
.43729 .48508 m .43951 .48196 L .43832 .48379 L F
.43951 .48196 m .43958 .48185 L .43951 .48196 L F
.43951 .48196 m .43951 .48196 L .43832 .48379 L F
.43758 .48475 m .43832 .48379 L .43808 .48415 L F
.43729 .48508 m .43832 .48379 L .43758 .48475 L F
.858 .864 .843 r
.44021 .48505 m .43929 .48253 L .44106 .4815 L F
.43929 .48253 m .43919 .48225 L .43964 .48207 L F
.43929 .48253 m .43964 .48207 L .44106 .4815 L F
.929 .795 .692 r
.44021 .48505 m .43946 .48768 L .43808 .48415 L F
.339 .767 .973 r
.59394 .34938 m .59887 .35023 L .59555 .3518 L F
.2 .381 .819 r
.27455 .63952 m .27485 .64266 L .27379 .64339 L F
.27455 .63952 m .27792 .64477 L .27485 .64266 L F
.64 .095 0 r
.27379 .64339 m .27485 .64266 L .27658 .64468 L F
.957 .694 .495 r
.34417 .64553 m .3461 .64657 L .34594 .6494 L F
.521 .204 .37 r
.35318 .67896 m .35539 .68107 L .35305 .68173 L F
.35318 .67896 m .35612 .6786 L .35539 .68107 L F
.35318 .67896 m .35539 .68107 L .35305 .68173 L F
.35318 .67896 m .35612 .6786 L .35539 .68107 L F
.55 .915 .952 r
.66297 .32918 m .66145 .331 L .66451 .32901 L F
.66297 .32918 m .6604 .33033 L .66145 .331 L F
0 .188 .712 r
.36761 .55907 m .36588 .55729 L .3678 .55721 L F
.36761 .55907 m .36658 .56031 L .36588 .55729 L F
.36761 .55907 m .36999 .5611 L .36923 .55956 L F
.666 .268 .282 r
.36658 .56031 m .36999 .5611 L .36761 .55907 L F
0 .188 .712 r
.36761 .55907 m .36923 .55956 L .36658 .56031 L F
.785 .293 0 r
.39244 .51686 m .39075 .5158 L .38917 .51342 L F
.89 .498 .28 r
.39244 .51686 m .39077 .51821 L .39075 .5158 L F
.39244 .51686 m .3938 .51992 L .39077 .51821 L F
0 0 .256 r
.22937 .60269 m .22932 .602 L .22885 .60082 L F
.589 .26 .379 r
.22768 .59784 m .22885 .60082 L .23161 .59754 L F
.887 .977 .679 r
.23161 .59754 m .22885 .60082 L .22907 .59873 L F
0 0 .256 r
.22932 .602 m .22907 .59873 L .22885 .60082 L F
.589 .26 .379 r
.22765 .59784 m .22885 .60082 L .22768 .59784 L F
0 0 .415 r
.22831 .60038 m .22885 .60082 L .22765 .59784 L F
.457 .028 .136 r
.32774 .56683 m .32514 .56594 L .32756 .56604 L F
.32774 .56683 m .32409 .56763 L .32514 .56594 L F
.237 0 .117 r
.45294 .48784 m .45541 .48701 L .45682 .48485 L F
0 0 0 r
.45765 .48498 m .45682 .48485 L .45541 .48701 L F
.45765 .48498 m .45924 .48415 L .45682 .48485 L F
.546 .151 .244 r
.43568 .52499 m .43978 .52269 L .43732 .52347 L F
.762 .993 .795 r
.70944 .33238 m .71249 .32951 L .7108 .32991 L F
.706 .908 .551 r
.70826 .33344 m .70944 .33238 L .7108 .32991 L F
.972 .659 .338 r
.39585 .52298 m .39766 .52669 L .3961 .52552 L F
.79 .378 0 r
.39814 .529 m .3961 .52552 L .39766 .52669 L F
.567 .208 .319 r
.53235 .48174 m .53503 .48362 L .53228 .48365 L F
.53235 .48174 m .53655 .4809 L .53503 .48362 L F
.704 .547 .672 r
.46528 .54588 m .46835 .54619 L .46828 .5426 L F
.697 .626 .773 r
.46794 .53992 m .46828 .5426 L .47069 .53923 L F
.565 .445 .675 r
.46828 .5426 m .47156 .54253 L .47069 .53923 L F
.527 .239 .42 r
.47097 .54498 m .46828 .5426 L .46835 .54619 L F
.47097 .54498 m .47156 .54253 L .46828 .5426 L F
.696 .447 .543 r
.31589 .57191 m .3131 .57437 L .31315 .57197 L F
0 0 0 r
.6833 .35425 m .68068 .35523 L .67926 .35602 L F
.741 .536 .616 r
.61694 .35518 m .61247 .35743 L .61273 .35486 L F
.61694 .35518 m .61672 .3578 L .61247 .35743 L F
.131 0 .1 r
.61985 .35486 m .61672 .3578 L .61694 .35518 L F
.294 .33 .729 r
.36283 .56017 m .3626 .56495 L .36078 .56144 L F
.045 0 0 r
.45288 .59469 m .4538 .59496 L .45128 .59526 L F
.45288 .59469 m .45544 .59454 L .4538 .59496 L F
.683 .191 .073 r
.26094 .61899 m .2621 .6174 L .25803 .61649 L F
.605 .82 .982 r
.601 .36398 m .60032 .36481 L .59704 .3634 L F
.864 .857 .832 r
.69073 .34158 m .68757 .34169 L .68949 .33994 L F
.837 .904 .885 r
.69365 .33848 m .69073 .34158 L .68949 .33994 L F
.573 .831 .994 r
.54505 .44816 m .54908 .44871 L .54752 .44732 L F
.715 .515 .618 r
.54663 .4517 m .54917 .45179 L .54908 .44871 L F
.704 .791 .918 r
.54908 .44871 m .55032 .44457 L .54752 .44732 L F
.54908 .44871 m .55169 .44768 L .55032 .44457 L F
.674 .608 .774 r
.54908 .44871 m .5534 .4493 L .55169 .44768 L F
.691 .493 .614 r
.54917 .45179 m .5534 .4493 L .54908 .44871 L F
.683 .229 .166 r
.53655 .4809 m .5388 .4829 L .53503 .48362 L F
.831 .537 .492 r
.26606 .6261 m .26856 .62385 L .26749 .62402 L F
0 0 .436 r
.47945 .56538 m .47961 .56157 L .4807 .56367 L F
0 0 .139 r
.4807 .56367 m .47961 .56736 L .47945 .56538 L F
.913 .75 .666 r
.42934 .5436 m .42803 .54645 L .42678 .54195 L F
.942 .588 .311 r
.60188 .4153 m .60378 .41644 L .6042 .41876 L F
0 0 0 r
.33864 .55837 m .3369 .55897 L .3393 .55891 L F
0 0 .224 r
.3393 .55891 m .33984 .56112 L .33998 .55936 L F
.831 .863 .869 r
.50214 .41945 m .49868 .41976 L .50056 .41805 L F
.801 .875 .901 r
.50495 .41679 m .50214 .41945 L .50056 .41805 L F
.264 0 .093 r
.42109 .48375 m .42344 .48421 L .42475 .48156 L F
.469 .073 .207 r
.42344 .48421 m .42726 .48134 L .42475 .48156 L F
.88 .862 .818 r
.37818 .61628 m .37991 .61727 L .37628 .62007 L F
.965 .858 .685 r
.37937 .6139 m .37991 .61727 L .37818 .61628 L F
.512 .076 .148 r
.31548 .6417 m .31458 .64 L .3156 .64176 L F
0 0 0 r
.30476 .65206 m .30678 .65036 L .30329 .65271 L F
.30476 .65206 m .30329 .65271 L .30067 .65408 L F
.374 0 0 r
.41986 .49453 m .42076 .49482 L .41968 .49267 L F
.616 .533 .738 r
.4326 .4745 m .43517 .47076 L .4326 .47376 L F
.4326 .4745 m .43402 .47457 L .43517 .47076 L F
.357 0 0 r
.43225 .47613 m .43402 .47457 L .4326 .4745 L F
.767 .493 .52 r
.32416 .64318 m .32881 .64158 L .32722 .64563 L F
.736 .336 .292 r
.32881 .64158 m .33018 .6449 L .32722 .64563 L F
.32881 .64158 m .33127 .64313 L .33018 .6449 L F
.867 .749 .237 r
.40962 .58778 m .4097 .58391 L .41064 .58511 L F
.969 .704 .281 r
.43705 .50718 m .43581 .50591 L .43585 .50298 L F
.995 .866 .545 r
.43705 .50718 m .43532 .50872 L .43581 .50591 L F
.861 .84 .824 r
.28629 .54288 m .28187 .54462 L .28501 .54404 L F
.325 .228 .588 r
.28848 .54481 m .28665 .54582 L .28629 .54288 L F
.648 .122 0 r
.28501 .54404 m .28848 .54481 L .28629 .54288 L F
.956 .628 .353 r
.40524 .54501 m .403 .54169 L .40385 .54347 L F
.842 .832 .837 r
.45672 .51344 m .457 .50966 L .45437 .51266 L F
.45672 .51344 m .4588 .51122 L .457 .50966 L F
.684 .283 0 r
.45739 .51508 m .45672 .51344 L .45437 .51266 L F
.45739 .51508 m .4586 .51703 L .45672 .51344 L F
0 0 0 r
.44984 .58158 m .45216 .58159 L .45274 .57867 L F
.44984 .58158 m .4508 .58228 L .45216 .58159 L F
.44984 .58158 m .44869 .5835 L .4508 .58228 L F
.86 .41 .045 r
.387 .54261 m .38797 .54488 L .38995 .54603 L F
.984 .726 .453 r
.38797 .54488 m .38975 .54837 L .38995 .54603 L F
.453 .881 .802 r
.4159 .46856 m .41511 .46947 L .41791 .46855 L F
.4159 .46856 m .41341 .46983 L .41511 .46947 L F
.796 .684 .741 r
.36043 .62071 m .36372 .6178 L .36268 .61703 L F
.631 .929 .675 r
.3613 .61937 m .36372 .6178 L .36043 .62071 L F
0 .193 .645 r
.36268 .61703 m .36372 .6178 L .36306 .61707 L F
.799 .98 .701 r
.36306 .61707 m .36372 .6178 L .3613 .61937 L F
.913 .512 .142 r
.40303 .53639 m .40203 .53621 L .4008 .53324 L F
.965 .682 .446 r
.40303 .53639 m .40124 .53786 L .40203 .53621 L F
.40303 .53639 m .403 .53899 L .40124 .53786 L F
0 0 0 r
.25253 .59397 m .24944 .59688 L .25055 .59556 L F
.44 .452 .776 r
.22239 .56101 m .22346 .55777 L .22202 .55942 L F
0 0 .435 r
.4289 .50615 m .42804 .51079 L .42878 .50765 L F
.4289 .50615 m .42941 .50923 L .42804 .51079 L F
.576 .939 .912 r
.42941 .50923 m .42609 .51081 L .42804 .51079 L F
.777 .804 .874 r
.38501 .47091 m .38665 .4714 L .38883 .47161 L F
.579 .859 .996 r
.38883 .47161 m .38665 .4714 L .38674 .47134 L F
.57 .891 .988 r
.3898 .46971 m .38674 .47134 L .38513 .47006 L F
.38674 .47134 m .38665 .4714 L .38659 .47134 L F
.38674 .47134 m .38659 .47134 L .38513 .47006 L F
.86 .9 .861 r
.38739 .47134 m .38646 .47131 L .38501 .47091 L F
.38883 .47161 m .38674 .47134 L .38739 .47134 L F
.38674 .47134 m .38646 .47131 L .38739 .47134 L F
.285 .721 .966 r
.38659 .47134 m .38665 .4714 L .38501 .47091 L F
.86 .9 .861 r
.38646 .47131 m .38496 .47112 L .38501 .47091 L F
.285 .721 .966 r
.38513 .47006 m .38659 .47134 L .38501 .47091 L F
.579 .859 .996 r
.38883 .47161 m .38674 .47134 L .3898 .46971 L F
.86 .9 .861 r
.38883 .47161 m .38441 .47355 L .38496 .47112 L F
.151 .335 .794 r
.3898 .46971 m .39144 .47304 L .38883 .47161 L F
.709 .598 .73 r
.57132 .44058 m .57434 .43935 L .57041 .43916 L F
0 .078 .613 r
.57593 .37701 m .57669 .37595 L .57584 .37354 L F
0 .144 .666 r
.57593 .37701 m .57663 .37816 L .57669 .37595 L F
.762 .75 .842 r
.64801 .34258 m .64811 .34069 L .64699 .34187 L F
.979 .915 .643 r
.34203 .56287 m .34068 .56477 L .34259 .56046 L F
.706 .582 .714 r
.52243 .43259 m .5251 .43326 L .5251 .42998 L F
.707 .318 .31 r
.52494 .43491 m .5251 .43326 L .52243 .43259 L F
.674 .271 .273 r
.52872 .4347 m .5251 .43326 L .52494 .43491 L F
.831 .537 .492 r
.26606 .6261 m .26976 .62701 L .26856 .62385 L F
.813 1 .804 r
.30302 .62712 m .30446 .62677 L .30101 .6301 L F
.434 .851 .959 r
.30562 .62561 m .30446 .62677 L .30302 .62712 L F
.675 .382 .47 r
.5183 .43498 m .52243 .43259 L .52049 .43176 L F
.5183 .43498 m .5224 .43497 L .52243 .43259 L F
.859 .927 .872 r
.52243 .43259 m .52388 .42898 L .52049 .43176 L F
.52243 .43259 m .5251 .42998 L .52388 .42898 L F
.636 .351 .469 r
.5224 .43497 m .52494 .43491 L .52243 .43259 L F
.678 .931 .634 r
.35389 .63735 m .35174 .63989 L .35207 .63897 L F
0 0 .174 r
.35207 .63897 m .35174 .63989 L .35199 .64253 L F
.759 .683 .779 r
.44511 .51459 m .44949 .5163 L .44752 .51486 L F
.44511 .51459 m .44665 .51749 L .44949 .5163 L F
.746 .639 .741 r
.44665 .51749 m .44569 .52024 L .44949 .5163 L F
.324 .508 .884 r
.44949 .5163 m .44991 .51416 L .44752 .51486 L F
.44949 .5163 m .45143 .51635 L .44991 .51416 L F
0 0 .457 r
.55624 .39014 m .55643 .39271 L .55702 .39128 L F
.702 .845 .417 r
.55643 .39271 m .55539 .39428 L .55702 .39128 L F
.934 .968 .702 r
.73768 .31999 m .73946 .31463 L .73811 .31693 L F
.791 .384 .278 r
.41797 .48321 m .42055 .48614 L .42109 .48375 L F
.368 0 .176 r
.42109 .48375 m .42312 .48531 L .42344 .48421 L F
.42109 .48375 m .42055 .48614 L .42312 .48531 L F
.689 .966 .742 r
.64838 .39602 m .6517 .39358 L .65025 .39428 L F
0 0 0 r
.6517 .39358 m .65469 .3908 L .65368 .39233 L F
.395 .824 .662 r
.65025 .39428 m .6517 .39358 L .65368 .39233 L F
.492 .261 .491 r
.56209 .42959 m .56488 .42642 L .5599 .42328 L F
.56209 .42959 m .56378 .42911 L .56488 .42642 L F
.583 .302 .456 r
.33673 .59369 m .33983 .59088 L .33738 .59145 L F
.33983 .59088 m .33673 .59369 L .33738 .59145 L F
0 0 0 r
.67511 .32306 m .67362 .32307 L .67628 .32219 L F
.67511 .32306 m .67268 .32428 L .67362 .32307 L F
.95 .804 .664 r
.32475 .63171 m .32799 .62958 L .32679 .62904 L F
.32475 .63171 m .3267 .63349 L .32799 .62958 L F
.627 .499 .686 r
.68011 .3363 m .68031 .33868 L .68311 .33533 L F
.757 .828 .907 r
.457 .50966 m .4588 .51122 L .46172 .5099 L F
.041 .016 .499 r
.32258 .63976 m .32338 .64334 L .32352 .63888 L F
.588 .563 .794 r
.32416 .64318 m .32214 .64637 L .32243 .64349 L F
0 0 0 r
.32416 .64318 m .32361 .64328 L .32338 .64334 L F
.32361 .64328 m .32243 .64349 L .32338 .64334 L F
.041 .016 .499 r
.32258 .63976 m .32243 .64349 L .32338 .64334 L F
.979 .683 .362 r
.3223 .64364 m .32338 .64334 L .32111 .64101 L F
.32286 .64486 m .32338 .64334 L .3223 .64364 L F
0 0 .44 r
.34229 .63398 m .34323 .63628 L .3423 .63292 L F
.516 .695 .949 r
.67654 .35236 m .67801 .34962 L .67527 .35046 L F
.67654 .35236 m .67968 .3523 L .67801 .34962 L F
.552 .516 .769 r
.45178 .57482 m .45274 .57867 L .45511 .57777 L F
.594 .831 .453 r
.45216 .58159 m .45511 .57777 L .45274 .57867 L F
.081 0 0 r
.53712 .45533 m .53808 .45607 L .53676 .45764 L F
.53843 .45495 m .53969 .45459 L .53808 .45607 L F
.089 .052 .517 r
.53851 .46009 m .53676 .45764 L .53808 .45607 L F
0 0 0 r
.53808 .45607 m .54184 .45374 L .54147 .45344 L F
.944 .692 .225 r
.53751 .45755 m .53851 .46009 L .53808 .45607 L F
.68 .976 .813 r
.53808 .45607 m .54147 .45344 L .5394 .45409 L F
0 0 0 r
.5394 .45409 m .53777 .45708 L .53808 .45607 L F
.53777 .45708 m .53751 .45755 L .53808 .45607 L F
.081 0 0 r
.53712 .45533 m .53843 .45495 L .53808 .45607 L F
.436 .409 .731 r
.66905 .35152 m .666 .34859 L .66899 .34862 L F
.435 0 0 r
.66899 .34862 m .67138 .34995 L .66905 .35152 L F
.753 .989 .779 r
.71386 .32705 m .71249 .32951 L .71412 .3277 L F
.754 .992 .797 r
.7108 .32991 m .71249 .32951 L .71386 .32705 L F
.946 .796 .662 r
.7027 .27913 m .70422 .28025 L .70343 .27641 L F
.886 .989 .796 r
.70144 .28226 m .70422 .28025 L .7027 .27913 L F
.70144 .28226 m .70175 .28338 L .70422 .28025 L F
.768 .7 .787 r
.70422 .28025 m .70735 .2771 L .70343 .27641 L F
.641 .101 0 r
.5509 .46317 m .5546 .46392 L .55212 .46205 L F
.468 .288 .554 r
.55212 .46205 m .5546 .46392 L .55469 .46112 L F
.904 .506 .238 r
.38189 .53267 m .38265 .53512 L .38488 .53621 L F
.941 .664 .485 r
.38269 .53785 m .38488 .53621 L .38265 .53512 L F
.38269 .53785 m .38505 .53992 L .38488 .53621 L F
.811 .756 .801 r
.53744 .44167 m .54105 .44243 L .53948 .43881 L F
.5 .054 .122 r
.53703 .4443 m .54105 .44243 L .53744 .44167 L F
.53703 .4443 m .53998 .44441 L .54105 .44243 L F
.691 .981 .835 r
.53821 .42947 m .54122 .4273 L .53919 .42751 L F
.477 .795 .999 r
.53662 .42821 m .53821 .42947 L .53919 .42751 L F
.639 .673 .867 r
.53948 .43881 m .54105 .44243 L .5433 .44079 L F
.186 0 0 r
.54105 .44243 m .54253 .44354 L .5433 .44079 L F
.54105 .44243 m .53998 .44441 L .54253 .44354 L F
0 0 0 r
.46775 .54833 m .46835 .54619 L .46528 .54588 L F
.46775 .54833 m .46794 .54788 L .46835 .54619 L F
.777 .607 .669 r
.46775 .54833 m .46793 .54994 L .46693 .55226 L F
.178 .189 .632 r
.46693 .55226 m .46794 .54788 L .46775 .54833 L F
.433 .227 .499 r
.5011 .50976 m .49854 .51305 L .4989 .51066 L F
.671 .45 .577 r
.55979 .45187 m .56311 .45156 L .56291 .44844 L F
.692 .757 .902 r
.56163 .44565 m .56291 .44844 L .56581 .44568 L F
.301 .174 .535 r
.56291 .44844 m .56499 .45052 L .56471 .44768 L F
.56291 .44844 m .56311 .45156 L .56499 .45052 L F
.19 0 .348 r
.56581 .44568 m .56291 .44844 L .56471 .44768 L F
.78 .678 .75 r
.44267 .51985 m .44569 .52024 L .44665 .51749 L F
.739 .411 .426 r
.44238 .52222 m .44569 .52024 L .44267 .51985 L F
.938 .959 .751 r
.25017 .58113 m .25101 .58212 L .25316 .58078 L F
.25017 .58113 m .24855 .58321 L .25101 .58212 L F
.735 .977 .921 r
.37473 .49849 m .3759 .49636 L .37705 .49713 L F
.37473 .49849 m .37277 .49856 L .3759 .49636 L F
.932 .723 .598 r
.59714 .43272 m .5956 .42918 L .59502 .43212 L F
.702 .334 .349 r
.59537 .43464 m .59714 .43272 L .59502 .43212 L F
.59537 .43464 m .59934 .43496 L .59714 .43272 L F
.64 .301 .382 r
.357 .61271 m .35739 .61087 L .35951 .60939 L F
.36 0 .082 r
.35951 .60939 m .36211 .61132 L .35929 .61205 L F
.688 .726 .879 r
.41227 .50343 m .41644 .50548 L .41445 .50188 L F
0 .303 .676 r
.41227 .50343 m .41578 .50501 L .41644 .50548 L F
.819 .649 .672 r
.41644 .50548 m .41267 .50727 L .41227 .50343 L F
.666 .954 .723 r
.41644 .50548 m .41578 .50501 L .41664 .50418 L F
.618 .475 .666 r
.27691 .5491 m .27942 .54559 L .2769 .54617 L F
.416 .182 .449 r
.50654 .50093 m .50628 .50337 L .50393 .50418 L F
.501 .29 .525 r
.50941 .49766 m .50926 .50025 L .50654 .50093 L F
.465 .217 .452 r
.50926 .50025 m .50628 .50337 L .50654 .50093 L F
.916 .603 .437 r
.60148 .44542 m .59838 .44179 L .59856 .44454 L F
.899 .661 .57 r
.59832 .4473 m .60148 .44542 L .59856 .44454 L F
.59832 .4473 m .60149 .44821 L .60148 .44542 L F
.697 .216 0 r
.32644 .4978 m .32777 .49985 L .32612 .49818 L F
.372 .027 .245 r
.3312 .63998 m .32974 .63739 L .32698 .63949 L F
.3312 .63998 m .33325 .63661 L .32974 .63739 L F
.693 .798 .93 r
.64713 .3735 m .64375 .37322 L .64628 .37041 L F
.64375 .37322 m .64713 .3735 L .6464 .37325 L F
.228 .353 .783 r
.6491 .37223 m .64713 .3735 L .64628 .37041 L F
.45 .881 .89 r
.6464 .37325 m .64713 .3735 L .6491 .37223 L F
.571 .928 .943 r
.68029 .37519 m .68456 .37407 L .68331 .37469 L F
.33 .784 .64 r
.68647 .37308 m .68456 .37407 L .68726 .37269 L F
.33 .783 .637 r
.68331 .37469 m .68456 .37407 L .68647 .37308 L F
0 0 .201 r
.37911 .61076 m .37937 .6139 L .37979 .61247 L F
.703 .557 .686 r
.45279 .56552 m .45644 .56544 L .45536 .56318 L F
.748 .866 .934 r
.5251 .42998 m .52734 .42873 L .52576 .42728 L F
.811 .925 .911 r
.52388 .42898 m .5251 .42998 L .52576 .42728 L F
.286 .776 .712 r
.56909 .44617 m .56581 .44568 L .56654 .4447 L F
.661 .849 .972 r
.57056 .44384 m .56909 .44617 L .56654 .4447 L F
.331 0 0 r
.41959 .5982 m .41556 .60036 L .41596 .59771 L F
.41959 .5982 m .41834 .6001 L .41556 .60036 L F
.481 0 0 r
.4227 .5924 m .42068 .59084 L .42019 .59455 L F
.642 .799 .357 r
.42049 .59631 m .4227 .5924 L .42019 .59455 L F
.4205 .59638 m .42057 .59626 L .42049 .59631 L F
.42057 .59626 m .4227 .5924 L .42049 .59631 L F
.42218 .59335 m .41959 .5982 L .4227 .5924 L F
.481 0 0 r
.42068 .59084 m .4227 .5924 L .42439 .59487 L F
.612 .169 0 r
.4227 .5924 m .42448 .59496 L .42439 .59487 L F
.42448 .59496 m .42539 .59627 L .42439 .59487 L F
.73 .943 .953 r
.4242 .59468 m .42439 .59487 L .42306 .59644 L F
0 0 .15 r
.42557 .59615 m .42539 .59627 L .42341 .59342 L F
.42365 .59364 m .42341 .59342 L .4227 .5924 L F
.42557 .59615 m .42341 .59342 L .42365 .59364 L F
.576 .303 .466 r
.42462 .59453 m .4277 .59331 L .42673 .59136 L F
.42439 .59487 m .42479 .59468 L .42462 .59453 L F
.42479 .59468 m .4277 .59331 L .42462 .59453 L F
.481 0 0 r
.42248 .59279 m .42439 .59487 L .4237 .59055 L F
.576 .303 .466 r
.42439 .59487 m .42673 .59136 L .42365 .59023 L F
.73 .943 .953 r
.42541 .59281 m .42439 .59487 L .4242 .59468 L F
.642 .799 .357 r
.42057 .59626 m .42003 .59733 L .42218 .59335 L F
.4205 .59638 m .42047 .59644 L .42057 .59626 L F
.42047 .59644 m .42003 .59733 L .42057 .59626 L F
.42003 .59733 m .41959 .5982 L .42218 .59335 L F
.756 .741 .839 r
.42488 .59363 m .42173 .59555 L .42115 .59517 L F
.42139 .59471 m .42115 .59517 L .42076 .59491 L F
.42488 .59363 m .42115 .59517 L .42139 .59471 L F
.42541 .59281 m .42488 .59363 L .42076 .59491 L F
.42488 .59363 m .42306 .59644 L .42173 .59555 L F
.481 0 0 r
.42068 .59084 m .42248 .59279 L .42365 .59023 L F
.42248 .59279 m .4237 .59055 L .42365 .59023 L F
.504 .456 .736 r
.4205 .59638 m .41834 .6001 L .41959 .5982 L F
.551 .409 .641 r
.34413 .54621 m .34466 .54916 L .3473 .54612 L F
.34413 .54621 m .34466 .54916 L .3473 .54612 L F
.059 0 .26 r
.24462 .53456 m .24324 .53286 L .24543 .53195 L F
.24462 .53456 m .24255 .53627 L .24324 .53286 L F
.678 .837 .412 r
.70105 .28431 m .70175 .28338 L .70144 .28226 L F
.504 .221 .418 r
.37888 .59881 m .3778 .60109 L .3763 .59809 L F
.977 .722 .48 r
.37645 .60049 m .37437 .59968 L .3763 .59809 L F
.762 .804 .887 r
.5395 .42231 m .54353 .42281 L .54214 .42072 L F
.819 .535 .507 r
.54324 .42587 m .54353 .42281 L .5395 .42231 L F
.291 .081 .413 r
.54572 .42171 m .54353 .42281 L .54324 .42587 L F
.459 .283 .554 r
.43506 .53274 m .43528 .53533 L .43245 .53588 L F
0 0 .159 r
.43528 .53533 m .43316 .53966 L .43245 .53588 L F
0 0 0 r
.69473 .30199 m .69859 .30147 L .69638 .30175 L F
.399 0 0 r
.29672 .57062 m .30115 .5691 L .29855 .5691 L F
.56 .343 .542 r
.35769 .5314 m .36027 .52937 L .35769 .52988 L F
.785 .533 .557 r
.36027 .52937 m .35599 .53151 L .35769 .52988 L F
.447 .246 .513 r
.51168 .4995 m .50941 .49766 L .51167 .49696 L F
.51168 .4995 m .50926 .50025 L .50941 .49766 L F
.791 .504 .502 r
.41808 .48108 m .41797 .48321 L .41989 .48041 L F
.631 .406 .557 r
.42625 .50334 m .42834 .50318 L .429 .5001 L F
.415 .205 .484 r
.429 .5001 m .43092 .50213 L .43187 .50032 L F
.429 .5001 m .42834 .50318 L .43092 .50213 L F
.568 .938 .839 r
.53919 .42751 m .54122 .4273 L .54324 .42587 L F
0 0 .435 r
.41212 .5941 m .41301 .59821 L .413 .59646 L F
.602 .335 .486 r
.41596 .59771 m .41556 .60036 L .41301 .59821 L F
.93 .551 .25 r
.41556 .60036 m .413 .59646 L .41301 .59821 L F
.863 .926 .867 r
.74009 .31364 m .7429 .31315 L .74186 .3117 L F
.577 .943 .863 r
.67951 .36496 m .67542 .36656 L .67847 .36371 L F
.981 .899 .655 r
.68026 .36035 m .67951 .36496 L .67847 .36371 L F
.799 .927 .92 r
.49066 .42676 m .48619 .42821 L .48897 .42541 L F
.817 .974 .896 r
.49243 .42519 m .49066 .42676 L .49131 .42426 L F
.674 .849 .966 r
.49131 .42426 m .49066 .42676 L .48897 .42541 L F
.745 .577 .666 r
.53362 .4362 m .53302 .43303 L .53148 .43414 L F
.905 .849 .777 r
.5688 .43743 m .57253 .43515 L .57041 .43916 L F
.712 .653 .789 r
.73426 .31151 m .73151 .31015 L .73438 .30912 L F
.768 .98 .912 r
.4587 .44404 m .45784 .44636 L .45628 .44548 L F
.4587 .44404 m .45976 .4447 L .45784 .44636 L F
.869 .845 .818 r
.5526 .45715 m .55727 .45535 L .55574 .45392 L F
.682 .25 .218 r
.56027 .4578 m .55727 .45535 L .55736 .45828 L F
.223 0 0 r
.2437 .52304 m .2461 .5226 L .24799 .52083 L F
0 0 0 r
.2461 .5226 m .25042 .52046 L .24799 .52083 L F
.809 .778 .824 r
.33017 .61059 m .32801 .61283 L .32671 .61001 L F
.395 .209 .507 r
.57219 .41874 m .56997 .42001 L .57241 .41665 L F
.461 .082 .234 r
.57219 .41874 m .56856 .42137 L .56997 .42001 L F
.009 0 0 r
.60249 .37305 m .60506 .37234 L .60643 .37112 L F
.61 .616 .832 r
.6036 .35816 m .60304 .35483 L .60244 .3541 L F
.6036 .35816 m .6063 .35762 L .60304 .35483 L F
.535 .125 .21 r
.60643 .37112 m .60913 .37215 L .60948 .37094 L F
0 .333 .662 r
.60784 .37165 m .60913 .37215 L .60643 .37112 L F
.60784 .37165 m .60643 .37112 L .60506 .37234 L F
.138 .029 .456 r
.61351 .40351 m .61552 .3996 L .61537 .40221 L F
.496 0 0 r
.61919 .40436 m .61351 .40351 L .61537 .40221 L F
.408 .268 .577 r
.3244 .5169 m .32609 .51733 L .3259 .51317 L F
.407 .272 .584 r
.3244 .5169 m .3267 .51893 L .32609 .51733 L F
.443 .271 .552 r
.3244 .5169 m .32443 .52002 L .3267 .51893 L F
.967 .905 .703 r
.43857 .55429 m .44103 .55297 L .43903 .5495 L F
.43857 .55429 m .43982 .55525 L .44103 .55297 L F
.757 .828 .907 r
.457 .50966 m .46172 .5099 L .45944 .5067 L F
.344 .417 .793 r
.46172 .5099 m .46203 .5056 L .45944 .5067 L F
.46172 .5099 m .46414 .50993 L .46203 .5056 L F
.548 .878 .991 r
.605 .34887 m .60615 .34716 L .60753 .34784 L F
.605 .34887 m .60357 .34802 L .60615 .34716 L F
.27 .047 .38 r
.3187 .65806 m .32178 .65447 L .32153 .65744 L F
.229 .749 .792 r
.31921 .65782 m .3187 .65806 L .32153 .65744 L F
0 .153 .695 r
.3187 .65806 m .31792 .65842 L .31666 .65588 L F
.229 .749 .792 r
.31784 .65805 m .3187 .65806 L .31921 .65782 L F
0 .153 .695 r
.3187 .65806 m .31842 .65942 L .31792 .65842 L F
0 .142 .687 r
.32065 .66165 m .31842 .65942 L .3187 .65806 L F
.284 .251 .644 r
.32065 .66165 m .31906 .66211 L .31842 .65942 L F
.714 .673 .809 r
.54887 .43255 m .55251 .43267 L .55141 .4316 L F
.52 .145 .27 r
.55451 .43449 m .55251 .43267 L .55248 .43543 L F
.464 .864 .687 r
.63882 .33501 m .64072 .33357 L .64204 .333 L F
.476 .882 .739 r
.63882 .33501 m .63698 .33571 L .64072 .33357 L F
.683 .803 .939 r
.64323 .34117 m .64699 .34187 L .64573 .34066 L F
.891 .812 .763 r
.64313 .34378 m .64699 .34187 L .64323 .34117 L F
.64313 .34378 m .64482 .34533 L .64699 .34187 L F
.763 .906 .939 r
.64699 .34187 m .64754 .339 L .64573 .34066 L F
.64699 .34187 m .64811 .34069 L .64754 .339 L F
.256 0 0 r
.54829 .47788 m .54454 .4804 L .54544 .47796 L F
.518 .39 .645 r
.40205 .4714 m .40442 .46806 L .40178 .46885 L F
.676 .732 .892 r
.61039 .35463 m .61273 .35486 L .60907 .35476 L F
.843 .882 .869 r
.51362 .41179 m .51025 .41261 L .51298 .41 L F
.774 .92 .935 r
.51534 .40859 m .51362 .41179 L .51298 .41 L F
.51534 .40859 m .5167 .40968 L .51362 .41179 L F
.293 .341 .74 r
.21895 .57524 m .22147 .5772 L .22045 .57294 L F
.364 .344 .703 r
.21977 .57764 m .22147 .5772 L .21895 .57524 L F
.719 .398 .435 r
.53396 .41521 m .53993 .41665 L .53799 .41322 L F
.57 .792 .983 r
.5364 .41176 m .53799 .41322 L .54045 .41239 L F
.352 .263 .613 r
.53799 .41322 m .54072 .41481 L .54045 .41239 L F
.53799 .41322 m .53993 .41665 L .54072 .41481 L F
.597 .948 .908 r
.35591 .64848 m .35668 .64707 L .35471 .64818 L F
.35591 .64848 m .35959 .64678 L .35668 .64707 L F
.941 .895 .497 r
.27762 .6518 m .27719 .65619 L .2776 .65484 L F
.155 .51 .913 r
.27719 .65619 m .27944 .65698 L .2776 .65484 L F
0 .419 .852 r
.6416 .38518 m .64004 .38543 L .6384 .38314 L F
.611 .628 .843 r
.64395 .38398 m .6416 .38518 L .63984 .38194 L F
.407 .848 .741 r
.64199 .38483 m .6416 .38518 L .64395 .38398 L F
.176 .378 .824 r
.63984 .38194 m .64111 .38428 L .6384 .38314 L F
.64111 .38428 m .6416 .38518 L .63959 .3839 L F
.64111 .38428 m .63959 .3839 L .6384 .38314 L F
.407 .848 .741 r
.63985 .38574 m .6416 .38518 L .64199 .38483 L F
0 .419 .852 r
.6416 .38518 m .64271 .38661 L .64091 .38582 L F
.6416 .38518 m .64091 .38582 L .64004 .38543 L F
.823 .901 .895 r
.63853 .38794 m .64199 .38644 L .6416 .38518 L F
.715 .982 .786 r
.63853 .38794 m .6416 .38518 L .63985 .38574 L F
.407 .848 .741 r
.63985 .38574 m .64247 .38462 L .64514 .38589 L F
.64247 .38462 m .64395 .38398 L .64469 .38517 L F
.64247 .38462 m .64469 .38517 L .64514 .38589 L F
.859 .408 .037 r
.41212 .5941 m .40936 .59108 L .41089 .59261 L F
.856 .925 .873 r
.63789 .35019 m .64196 .34842 L .64044 .34668 L F
0 0 .404 r
.22897 .60418 m .22885 .60082 L .22831 .60038 L F
.22897 .60418 m .22937 .60269 L .22885 .60082 L F
0 0 .53 r
.22897 .60418 m .23064 .60679 L .22937 .60269 L F
.539 .176 .299 r
.44082 .49407 m .44309 .49595 L .44244 .49342 L F
.44082 .49407 m .43901 .49644 L .44309 .49595 L F
.144 .669 .879 r
.27809 .63027 m .27393 .62973 L .27374 .63247 L F
.887 .832 .787 r
.27374 .63247 m .27589 .63399 L .27809 .63027 L F
.105 .017 .462 r
.48697 .53847 m .48708 .54133 L .48502 .54275 L F
.026 0 .324 r
.48708 .54133 m .48464 .54545 L .48502 .54275 L F
.424 .186 .446 r
.29829 .52015 m .29538 .52377 L .29777 .52289 L F
.29777 .52289 m .29538 .52377 L .29829 .52015 L F
.399 .164 .438 r
.29829 .52015 m .30009 .52199 L .30026 .51933 L F
.29829 .52015 m .29777 .52289 L .30009 .52199 L F
.30009 .52199 m .29829 .52015 L .30026 .51933 L F
.30009 .52199 m .29777 .52289 L .29829 .52015 L F
.076 .213 .704 r
.44983 .568 m .4511 .57201 L .45224 .57034 L F
.149 .318 .779 r
.4511 .57201 m .45379 .57411 L .45224 .57034 L F
.397 .339 .675 r
.45178 .57482 m .45379 .57411 L .4511 .57201 L F
.579 .887 .99 r
.25439 .57535 m .25418 .57687 L .25476 .5752 L F
0 .27 .776 r
.25418 .57687 m .25399 .57833 L .25157 .57483 L F
.666 .136 0 r
.25088 .57564 m .25418 .57687 L .25157 .57483 L F
.579 .887 .99 r
.25244 .57614 m .25418 .57687 L .25439 .57535 L F
0 .27 .776 r
.25418 .57687 m .25418 .57861 L .25399 .57833 L F
.947 .814 .68 r
.25204 .57811 m .25418 .57861 L .25418 .57687 L F
.25204 .57811 m .25316 .58078 L .25418 .57861 L F
.76 .911 .941 r
.54431 .45903 m .54786 .4587 L .54664 .45735 L F
.412 0 .065 r
.54786 .4587 m .55105 .45864 L .54993 .46018 L F
.582 .575 .81 r
.352 .68935 m .35285 .68454 L .35085 .68479 L F
.352 .68935 m .35446 .68858 L .35285 .68454 L F
.632 .891 .565 r
.28805 .65097 m .28718 .65226 L .2891 .64999 L F
.065 .231 .725 r
.28861 .65347 m .28718 .65226 L .28805 .65097 L F
.066 0 .003 r
.32812 .53623 m .33042 .53545 L .33145 .53319 L F
0 0 0 r
.33145 .53319 m .33312 .53199 L .33384 .52976 L F
.306 .071 .383 r
.33042 .53545 m .33312 .53199 L .33145 .53319 L F
.459 .374 .673 r
.39274 .47743 m .39569 .47962 L .39688 .47806 L F
.555 .072 .062 r
.39688 .47806 m .39569 .47962 L .39864 .47944 L F
.949 .727 .568 r
.39864 .47944 m .39963 .47744 L .39688 .47806 L F
.949 .698 .524 r
.6018 .40784 m .60263 .41001 L .60237 .41272 L F
.466 .22 .456 r
.50393 .50418 m .50364 .50652 L .50103 .50708 L F
.451 .223 .476 r
.50628 .50337 m .50364 .50652 L .50393 .50418 L F
.725 .5 .584 r
.69347 .322 m .68923 .31911 L .69346 .31936 L F
0 .02 .593 r
.70863 .30987 m .70746 .30984 L .70746 .30768 L F
.70863 .30987 m .70883 .31112 L .70746 .30984 L F
.599 .914 .661 r
.66852 .31378 m .66927 .31255 L .67083 .31222 L F
.66852 .31378 m .66737 .3144 L .66927 .31255 L F
.947 .657 .458 r
.58797 .41138 m .59012 .41021 L .58902 .40803 L F
.58797 .41138 m .59061 .4136 L .59012 .41021 L F
.564 .467 .703 r
.54875 .43022 m .55044 .42536 L .54745 .42622 L F
.768 .702 .79 r
.45143 .51635 m .4554 .51908 L .45402 .51569 L F
.45143 .51635 m .45315 .51998 L .4554 .51908 L F
.636 .088 0 r
.4586 .51703 m .45402 .51569 L .4554 .51908 L F
.759 .993 .795 r
.45279 .56552 m .44983 .568 L .45259 .56804 L F
.874 .535 .406 r
.32654 .55553 m .32425 .55765 L .32796 .55862 L F
.567 .455 .686 r
.56071 .40975 m .56091 .41308 L .55816 .41386 L F
.37 .012 .22 r
.55816 .41386 m .56091 .41308 L .56052 .41474 L F
.583 .316 .477 r
.5271 .4842 m .52583 .48717 L .52315 .48734 L F
.566 .279 .439 r
.5271 .4842 m .52981 .48641 L .52583 .48717 L F
.5271 .4842 m .52955 .48396 L .52981 .48641 L F
.352 0 0 r
.35004 .49849 m .34654 .49765 L .3488 .49934 L F
.727 .229 .051 r
.3488 .49934 m .35103 .49957 L .35004 .49849 L F
.566 .342 .535 r
.67086 .34448 m .67379 .34426 L .67156 .34197 L F
.698 .921 .968 r
.33843 .65714 m .3391 .65514 L .33657 .65597 L F
.33843 .65714 m .34078 .65588 L .3391 .65514 L F
.691 .493 .614 r
.54917 .45179 m .55368 .45181 L .5534 .4493 L F
.708 .709 .849 r
.5534 .4493 m .55442 .44534 L .55169 .44768 L F
.5534 .4493 m .55571 .44868 L .55442 .44534 L F
.654 .466 .618 r
.55368 .45181 m .55571 .44868 L .5534 .4493 L F
.152 .015 .427 r
.49096 .52587 m .49085 .52888 L .48918 .5298 L F
.319 .096 .411 r
.49079 .53142 m .48918 .5298 L .49085 .52888 L F
.49079 .53142 m .48883 .53237 L .48918 .5298 L F
.997 .791 .504 r
.40989 .56256 m .40789 .56423 L .40843 .56102 L F
.40989 .56256 m .40927 .56513 L .40789 .56423 L F
0 0 0 r
.33864 .55837 m .33693 .55989 L .3369 .55897 L F
.523 .569 .844 r
.337 .50582 m .33613 .51025 L .33552 .50649 L F
.977 .913 .665 r
.37705 .49713 m .3773 .49279 L .37823 .4948 L F
.57 .28 .436 r
.52045 .48772 m .52305 .48975 L .52027 .48997 L F
.547 .289 .476 r
.52315 .48734 m .52305 .48975 L .52045 .48772 L F
.019 .293 .787 r
.33106 .64854 m .33099 .65019 L .33026 .64847 L F
.88 .92 .527 r
.32984 .65275 m .33099 .65019 L .33106 .64854 L F
.571 .913 .97 r
.44718 .44915 m .45083 .44851 L .44892 .44964 L F
0 0 .51 r
.30563 .62818 m .30738 .6324 L .30758 .63091 L F
.681 .942 .665 r
.30758 .63091 m .30738 .6324 L .30485 .63375 L F
.569 .882 .598 r
.32239 .63049 m .31907 .6336 L .32145 .63251 L F
0 0 .046 r
.32431 .62932 m .32239 .63049 L .32145 .63251 L F
.396 0 0 r
.30236 .57444 m .29757 .57507 L .29989 .57497 L F
.876 .782 .754 r
.43946 .48768 m .43601 .48763 L .43808 .48415 L F
0 0 0 r
.43946 .48768 m .43608 .49043 L .43601 .48763 L F
.43946 .48768 m .43805 .48962 L .43608 .49043 L F
.198 0 0 r
.45259 .56804 m .45607 .56665 L .45644 .56544 L F
.653 .207 .179 r
.43946 .48768 m .44196 .48978 L .43805 .48962 L F
.614 .241 .312 r
.44331 .48782 m .44196 .48978 L .43946 .48768 L F
0 0 0 r
.45644 .56544 m .45722 .56647 L .45887 .56382 L F
.45644 .56544 m .45607 .56665 L .45722 .56647 L F
.563 0 0 r
.62286 .39002 m .62054 .38825 L .61852 .3878 L F
.642 .091 0 r
.62286 .39002 m .62138 .38833 L .62054 .38825 L F
.211 0 0 r
.32178 .65447 m .32361 .6536 L .3248 .65385 L F
0 0 .243 r
.41758 .51039 m .41738 .5131 L .41865 .50871 L F
.769 .269 0 r
.35872 .50651 m .35813 .50556 L .35513 .50287 L F
.445 .848 .971 r
.26527 .52122 m .26403 .52253 L .26714 .52073 L F
.26527 .52122 m .26274 .5219 L .26403 .52253 L F
.691 .841 .955 r
.61561 .38316 m .61876 .38161 L .61755 .37995 L F
0 0 .045 r
.27917 .6454 m .27836 .64643 L .27787 .64904 L F
.662 .837 .967 r
.36066 .62765 m .36123 .63023 L .3574 .62908 L F
.88 .608 .523 r
.3574 .62908 m .36123 .63023 L .36057 .63305 L F
.895 .475 .159 r
.36123 .63023 m .36112 .63145 L .36057 .63305 L F
.549 .759 .975 r
.36431 .62862 m .36123 .63023 L .36066 .62765 L F
0 .313 .797 r
.58341 .38308 m .58455 .38488 L .5862 .38548 L F
.787 .477 .465 r
.3449 .53323 m .34846 .53604 L .34704 .53226 L F
.3449 .53323 m .34426 .53545 L .34846 .53604 L F
.434 .082 .268 r
.2269 .56738 m .2269 .56881 L .2245 .56842 L F
.938 .747 .273 r
.31692 .63003 m .31788 .62972 L .31805 .62698 L F
.31692 .63003 m .31805 .62698 L .32057 .62605 L F
.274 .779 .824 r
.45765 .48498 m .46206 .48432 L .45924 .48415 L F
.77 .643 .72 r
.30863 .64721 m .30954 .64955 L .30678 .65036 L F
.589 .34 .507 r
.60907 .35476 m .60931 .35731 L .6063 .35762 L F
.748 .457 .49 r
.61247 .35743 m .60931 .35731 L .60907 .35476 L F
.601 .926 .699 r
.64204 .333 m .64275 .33174 L .64462 .3317 L F
.64204 .333 m .64072 .33357 L .64275 .33174 L F
.908 .618 .482 r
.37379 .52501 m .37598 .52333 L .37383 .52233 L F
.37379 .52501 m .37604 .52591 L .37598 .52333 L F
.465 .636 .929 r
.70237 .27416 m .70079 .27606 L .69944 .27485 L F
.70237 .27416 m .70343 .27641 L .70079 .27606 L F
.701 .644 .789 r
.43193 .47041 m .4326 .47376 L .43517 .47076 L F
.925 .565 .135 r
.44023 .56358 m .44177 .56483 L .44123 .56255 L F
.985 .881 .531 r
.41049 .56894 m .40893 .57022 L .40883 .56732 L F
.41049 .56894 m .40973 .57154 L .40893 .57022 L F
.986 .725 .347 r
.40834 .55659 m .40682 .55696 L .40616 .5536 L F
.40834 .55659 m .40853 .55994 L .40682 .55696 L F
.399 .661 .965 r
.67003 .35146 m .67138 .34995 L .66905 .35152 L F
.67003 .35146 m .67272 .3517 L .67138 .34995 L F
.614 .926 .685 r
.61554 .4344 m .61719 .4335 L .61895 .43184 L F
.404 .186 .467 r
.50364 .50652 m .5011 .50976 L .50103 .50708 L F
.654 .816 .961 r
.43349 .45034 m .43499 .45192 L .43089 .45145 L F
.541 .792 .991 r
.43597 .44985 m .43499 .45192 L .43349 .45034 L F
.43597 .44985 m .43751 .45127 L .43499 .45192 L F
.194 .485 .898 r
.58053 .41821 m .58226 .41998 L .58193 .41827 L F
0 0 .438 r
.58226 .41998 m .58327 .4222 L .58193 .41827 L F
.573 .931 .938 r
.61113 .34708 m .61254 .34552 L .61363 .34625 L F
.61113 .34708 m .61007 .34673 L .61254 .34552 L F
.761 .956 .936 r
.41931 .45649 m .41562 .45748 L .41766 .45564 L F
.53 .873 .99 r
.41766 .45564 m .42168 .45544 L .41931 .45649 L F
.87 .826 .801 r
.59833 .45839 m .6008 .45513 L .59906 .4538 L F
.696 .447 .543 r
.31589 .57191 m .31567 .57459 L .3131 .57437 L F
.761 .55 .612 r
.31878 .57227 m .31567 .57459 L .31589 .57191 L F
.624 .27 .351 r
.36684 .60901 m .36211 .61132 L .36252 .60953 L F
.901 .954 .612 r
.40389 .5019 m .40412 .50257 L .40512 .50061 L F
.338 .136 .453 r
.40412 .50257 m .40498 .50387 L .40512 .50061 L F
.436 .213 .476 r
.40512 .50061 m .40498 .50387 L .40767 .50195 L F
.524 .064 .103 r
.40512 .50061 m .40767 .50195 L .40389 .5019 L F
.692 .937 .965 r
.6194 .34457 m .61254 .34552 L .61516 .34427 L F
.6194 .34457 m .61363 .34625 L .61254 .34552 L F
.161 .603 .935 r
.61904 .34281 m .6194 .34457 L .61516 .34427 L F
.61904 .34281 m .6204 .34408 L .6194 .34457 L F
.446 .594 .906 r
.62105 .34506 m .6194 .34457 L .6204 .34408 L F
.302 .729 .971 r
.41213 .51203 m .41738 .5131 L .41476 .51383 L F
.599 .07 0 r
.38917 .51342 m .38803 .5127 L .38613 .5107 L F
.782 .291 0 r
.38917 .51342 m .38902 .51466 L .38803 .5127 L F
.38917 .51342 m .39075 .5158 L .38902 .51466 L F
.86 .611 .561 r
.68923 .31911 m .68578 .32026 L .68548 .31867 L F
.68923 .31911 m .68928 .32229 L .68578 .32026 L F
.725 .5 .584 r
.69347 .322 m .68928 .32229 L .68923 .31911 L F
.381 .088 .337 r
.42612 .58156 m .4293 .5788 L .4283 .5797 L F
.496 .474 .763 r
.43124 .57769 m .4293 .5788 L .4283 .57611 L F
0 0 0 r
.4283 .5797 m .4293 .5788 L .43124 .57769 L F
0 0 .445 r
.35062 .63197 m .34947 .63005 L .35186 .62973 L F
.35062 .63197 m .34983 .63307 L .34947 .63005 L F
.393 0 0 r
.33679 .54296 m .33475 .54399 L .33251 .54365 L F
.306 0 .238 r
.55231 .43743 m .54942 .43769 L .54878 .43792 L F
.55231 .43743 m .55248 .43543 L .54942 .43769 L F
.642 .091 0 r
.62286 .39002 m .62417 .39043 L .62138 .38833 L F
.34 .077 .361 r
.62134 .39362 m .62417 .39043 L .62414 .39297 L F
.474 .883 .942 r
.62674 .38929 m .62286 .39002 L .62412 .38905 L F
.84 .977 .877 r
.62778 .38472 m .62412 .38905 L .62673 .38434 L F
.892 .829 .779 r
.62778 .38472 m .62674 .38929 L .62412 .38905 L F
0 0 0 r
.62673 .38434 m .62412 .38905 L .62383 .38963 L F
.605 .658 .875 r
.62134 .39362 m .62414 .39297 L .62286 .39002 L F
.107 .332 .803 r
.6234 .39042 m .62414 .39297 L .62455 .39128 L F
.62286 .39002 m .62319 .39077 L .6234 .39042 L F
.62319 .39077 m .62414 .39297 L .6234 .39042 L F
0 0 0 r
.62447 .38857 m .62383 .38963 L .62369 .38991 L F
.474 .883 .942 r
.62674 .38929 m .62348 .39021 L .62369 .38987 L F
.432 .238 .516 r
.62414 .39297 m .62417 .39043 L .62672 .39214 L F
.578 .005 0 r
.62286 .39002 m .62455 .39128 L .62308 .39117 L F
0 0 0 r
.6244 .3887 m .62369 .38991 L .62308 .39117 L F
.62447 .38857 m .62369 .38991 L .6244 .3887 L F
.62657 .38464 m .62383 .38963 L .6264 .38496 L F
.993 .813 .557 r
.6262 .38389 m .6258 .38611 L .62535 .38225 L F
.474 .883 .942 r
.62674 .38929 m .62417 .39043 L .62348 .39021 L F
.022 0 .131 r
.62565 .38699 m .62673 .38434 L .62308 .39117 L F
.993 .813 .557 r
.6258 .38611 m .62565 .38699 L .62561 .38647 L F
0 0 0 r
.62628 .38519 m .62383 .38963 L .62442 .38866 L F
.62634 .38507 m .62383 .38963 L .62628 .38519 L F
.872 .904 .851 r
.62414 .38316 m .62552 .38666 L .62253 .38747 L F
.62552 .38666 m .62565 .38699 L .62531 .38704 L F
.62552 .38666 m .62531 .38704 L .62253 .38747 L F
0 0 0 r
.62466 .38823 m .62442 .38866 L .62447 .38857 L F
.62628 .38519 m .62442 .38866 L .62466 .38823 L F
.6264 .38496 m .62634 .38507 L .62628 .38519 L F
.994 .833 .471 r
.62535 .38225 m .62561 .38647 L .62414 .38316 L F
.62561 .38647 m .62565 .38699 L .62552 .38666 L F
.62561 .38647 m .62552 .38666 L .62414 .38316 L F
.993 .813 .557 r
.6258 .38611 m .62561 .38647 L .62535 .38225 L F
0 0 0 r
.62673 .38434 m .62657 .38464 L .6264 .38496 L F
.474 .883 .942 r
.62369 .38987 m .62348 .39021 L .62286 .39002 L F
.37 .258 .594 r
.62672 .39214 m .62417 .39043 L .62674 .38929 L F
.781 .981 .906 r
.33279 .50764 m .32959 .51032 L .33212 .50741 L F
.45 .338 .635 r
.32964 .51266 m .33212 .50741 L .32959 .51032 L F
0 0 0 r
.33384 .52976 m .3345 .53056 L .33458 .52799 L F
.33384 .52976 m .33312 .53199 L .3345 .53056 L F
.329 .293 .666 r
.35507 .62696 m .35608 .63021 L .3574 .62908 L F
.513 .297 .523 r
.3574 .62908 m .35786 .62649 L .35507 .62696 L F
.3574 .62908 m .35786 .62649 L .35507 .62696 L F
.761 .55 .612 r
.31878 .57227 m .3197 .57481 L .31567 .57459 L F
.449 .381 .689 r
.3214 .57381 m .31878 .57227 L .32154 .57093 L F
.3214 .57381 m .3197 .57481 L .31878 .57227 L F
.888 .871 .814 r
.54481 .43445 m .54539 .4372 L .54216 .43806 L F
.961 .805 .642 r
.34068 .56477 m .33984 .56112 L .34259 .56046 L F
.042 0 .019 r
.46794 .54788 m .47097 .54498 L .46835 .54619 L F
.589 .592 .823 r
.6142 .3634 m .61577 .3682 L .61834 .36696 L F
0 0 0 r
.61834 .36696 m .61577 .3682 L .61473 .36908 L F
.463 .308 .585 r
.4959 .51612 m .49651 .5192 L .49342 .52005 L F
.342 .14 .454 r
.49651 .5192 m .49338 .52266 L .49342 .52005 L F
.289 0 .159 r
.34858 .5276 m .35008 .52962 L .34885 .52705 L F
0 0 .063 r
.34762 .52995 m .3483 .5291 L .34858 .52722 L F
.699 .916 .968 r
.34704 .53226 m .3483 .5291 L .34762 .52995 L F
.34704 .53226 m .3474 .52997 L .3483 .5291 L F
.522 .264 .466 r
.34882 .52559 m .3483 .5291 L .34885 .52705 L F
.289 0 .159 r
.3474 .52997 m .34885 .52705 L .3483 .5291 L F
.3474 .52997 m .34858 .52981 L .34858 .5276 L F
.34858 .52981 m .35008 .52962 L .34858 .5276 L F
0 0 .063 r
.34858 .52646 m .34858 .52722 L .34882 .52559 L F
.34762 .52995 m .34858 .52722 L .34858 .52646 L F
.161 0 0 r
.61711 .37668 m .61453 .37766 L .61361 .37926 L F
.791 .504 .502 r
.41808 .48108 m .41736 .48358 L .41797 .48321 L F
.164 .594 .936 r
.57228 .38561 m .57472 .38613 L .57606 .38733 L F
0 .328 .812 r
.57821 .38747 m .57606 .38733 L .57472 .38613 L F
.57821 .38747 m .57904 .38918 L .57606 .38733 L F
.106 .415 .863 r
.726 .30683 m .72276 .30663 L .72251 .30651 L F
.726 .30683 m .72603 .30813 L .72276 .30663 L F
.464 .298 .57 r
.32948 .61994 m .3269 .62333 L .32684 .62092 L F
0 0 0 r
.33779 .6112 m .33783 .61139 L .33942 .60949 L F
.146 .033 .456 r
.23664 .53855 m .2352 .54206 L .23483 .53936 L F
.641 .905 .983 r
.44235 .44942 m .44149 .45144 L .44001 .45047 L F
.44235 .44942 m .44379 .45029 L .44149 .45144 L F
.342 0 .191 r
.55448 .47403 m .55624 .47598 L .55358 .47656 L F
.55448 .47403 m .55741 .47312 L .55624 .47598 L F
.855 .946 .877 r
.54887 .43255 m .54481 .43445 L .54829 .43334 L F
.66 .638 .817 r
.27632 .62197 m .27671 .62371 L .27521 .61996 L F
.749 .673 .777 r
.27928 .62021 m .27632 .62197 L .27521 .61996 L F
.477 .532 .835 r
.27521 .61996 m .27671 .62371 L .27915 .62355 L F
.357 0 0 r
.43225 .47613 m .43479 .47598 L .43402 .47457 L F
.484 .397 .681 r
.43517 .47076 m .43402 .47457 L .438 .47317 L F
.416 .075 .277 r
.43479 .47598 m .438 .47317 L .43402 .47457 L F
.197 .707 .897 r
.28884 .54215 m .29207 .54212 L .29174 .54243 L F
.644 .15 .062 r
.29174 .54243 m .29077 .54388 L .28884 .54215 L F
.481 .819 .526 r
.29174 .54243 m .29207 .54212 L .29325 .54104 L F
0 0 0 r
.29325 .54104 m .29077 .54388 L .29174 .54243 L F
.843 .957 .885 r
.59135 .36653 m .58938 .36869 L .58728 .36866 L F
.787 .689 .756 r
.34296 .54147 m .34651 .54531 L .34352 .54225 L F
.316 .662 .973 r
.34651 .54531 m .346 .54252 L .34352 .54225 L F
.339 0 0 r
.346 .54252 m .34389 .54277 L .34352 .54225 L F
.34389 .54277 m .34246 .54294 L .34352 .54225 L F
.787 .689 .756 r
.3426 .54107 m .34296 .54147 L .34352 .54225 L F
.896 .606 .489 r
.34181 .5461 m .34651 .54531 L .34338 .54509 L F
.34169 .54645 m .34651 .54531 L .34181 .5461 L F
.34102 .54661 m .34131 .54701 L .34651 .54531 L F
0 0 0 r
.33857 .54729 m .34102 .54661 L .34181 .5461 L F
.34138 .546 m .34181 .5461 L .34338 .54509 L F
.33857 .54729 m .34181 .5461 L .34138 .546 L F
.823 .993 .864 r
.34651 .54531 m .34131 .54701 L .346 .54252 L F
.837 .423 .254 r
.34684 .54435 m .34604 .54411 L .34505 .54434 L F
0 0 0 r
.346 .54252 m .34378 .54464 L .34505 .54434 L F
.346 .54252 m .34505 .54434 L .34429 .54158 L F
.353 0 0 r
.34352 .54225 m .33982 .54261 L .3426 .54107 L F
0 0 0 r
.33982 .54261 m .33965 .54198 L .3426 .54107 L F
.536 .841 .999 r
.33784 .54227 m .33759 .54416 L .33982 .54261 L F
.656 .155 .046 r
.34246 .54294 m .34039 .54409 L .33784 .54227 L F
.739 .976 .728 r
.34123 .54276 m .34246 .54294 L .34429 .54158 L F
.34123 .54276 m .34039 .54409 L .34246 .54294 L F
.015 .544 .853 r
.34505 .54434 m .34123 .54276 L .34429 .54158 L F
.837 .423 .254 r
.34604 .54411 m .3442 .54355 L .34505 .54434 L F
0 0 0 r
.34378 .54464 m .34217 .54618 L .34505 .54434 L F
.34217 .54618 m .34161 .54672 L .34233 .54622 L F
.34217 .54618 m .34233 .54622 L .34505 .54434 L F
.34161 .54672 m .34131 .54701 L .34157 .54682 L F
.34161 .54672 m .34157 .54682 L .34505 .54434 L F
.896 .606 .489 r
.34102 .54661 m .34169 .54645 L .34181 .5461 L F
.655 .951 .722 r
.36043 .64537 m .35959 .64678 L .36096 .6453 L F
.606 .951 .909 r
.35668 .64707 m .35959 .64678 L .36043 .64537 L F
.93 .84 .394 r
.42628 .56335 m .42667 .56554 L .42712 .56169 L F
.999 .807 .511 r
.42477 .56702 m .42667 .56554 L .42628 .56335 L F
.42477 .56702 m .42602 .56804 L .42667 .56554 L F
.777 .981 .908 r
.34347 .62078 m .34216 .62212 L .33929 .62344 L F
.838 .698 .708 r
.33995 .62574 m .34216 .62212 L .33929 .62344 L F
.272 0 0 r
.34347 .62078 m .33929 .62344 L .34216 .62212 L F
.838 .698 .708 r
.33995 .62574 m .34216 .62212 L .33929 .62344 L F
.524 .226 .403 r
.23119 .56663 m .22834 .57024 L .2269 .56881 L F
.664 .884 .523 r
.22933 .56852 m .22834 .57024 L .23119 .56663 L F
.945 .633 .192 r
.22882 .5694 m .22834 .57024 L .22933 .56852 L F
0 .118 .67 r
.22792 .57096 m .22834 .57024 L .22831 .57178 L F
.945 .633 .192 r
.22762 .57149 m .22871 .57266 L .22834 .57024 L F
.22762 .57149 m .22834 .57024 L .22882 .5694 L F
0 .118 .67 r
.2269 .56881 m .22834 .57024 L .22792 .57096 L F
.752 .962 .935 r
.4964 .42218 m .49243 .42519 L .49131 .42426 L F
0 0 0 r
.26001 .60983 m .25868 .61262 L .25913 .61116 L F
.848 .492 .38 r
.3764 .52802 m .3794 .52729 L .37604 .52591 L F
.3764 .52802 m .37993 .52921 L .3794 .52729 L F
.617 .958 .883 r
.34581 .52446 m .3438 .5246 L .34276 .52617 L F
.528 .877 .987 r
.3438 .5246 m .34118 .52517 L .34276 .52617 L F
.594 .602 .83 r
.45386 .47707 m .45454 .47278 L .4524 .47365 L F
.45386 .47707 m .45681 .47639 L .45454 .47278 L F
.544 .553 .814 r
.36511 .69131 m .36662 .69505 L .36918 .69423 L F
.584 .479 .701 r
.36252 .69196 m .36511 .69131 L .36429 .68871 L F
.441 .294 .584 r
.3259 .51317 m .32873 .51534 L .32964 .51266 L F
.3259 .51317 m .32609 .51733 L .32873 .51534 L F
0 0 0 r
.22668 .54918 m .22451 .55272 L .22553 .55123 L F
0 0 .146 r
.22324 .5551 m .22553 .55123 L .22451 .55272 L F
0 0 0 r
.71386 .31027 m .7169 .30816 L .71429 .30929 L F
.805 .492 0 r
.24081 .58171 m .24096 .58265 L .2422 .58061 L F
.373 0 0 r
.25334 .52494 m .24957 .52542 L .25161 .52426 L F
.36 0 .092 r
.25428 .52353 m .25334 .52494 L .25161 .52426 L F
.665 .29 .325 r
.34323 .63628 m .34639 .63593 L .34542 .63864 L F
.385 .13 .399 r
.34639 .63593 m .34983 .63307 L .34799 .635 L F
0 0 0 r
.34542 .63864 m .34639 .63593 L .34799 .635 L F
.588 .563 .794 r
.32416 .64318 m .32451 .64581 L .32214 .64637 L F
0 0 .337 r
.2206 .56752 m .22139 .57036 L .2211 .56806 L F
.2206 .56752 m .22089 .57124 L .22139 .57036 L F
.291 .768 .66 r
.69008 .37177 m .69356 .37028 L .69353 .37035 L F
0 0 0 r
.69527 .36863 m .69356 .37028 L .69591 .36723 L F
.69353 .37035 m .69356 .37028 L .69527 .36863 L F
.312 .377 .769 r
.22303 .58103 m .22412 .58482 L .22533 .58295 L F
.369 .3 .648 r
.22401 .58774 m .22533 .58295 L .22412 .58482 L F
.736 .735 .85 r
.55571 .44868 m .55701 .44403 L .55442 .44534 L F
.55571 .44868 m .55865 .4472 L .55701 .44403 L F
.518 .39 .645 r
.40205 .4714 m .40456 .47073 L .40442 .46806 L F
.681 .899 .975 r
.42463 .58049 m .42612 .58156 L .4283 .5797 L F
.987 .716 .402 r
.42613 .58426 m .42612 .58156 L .42463 .58049 L F
.451 0 0 r
.44799 .48817 m .45126 .48915 L .45294 .48784 L F
0 0 0 r
.45294 .48784 m .45343 .48806 L .45541 .48701 L F
.45294 .48784 m .45126 .48915 L .45343 .48806 L F
.406 0 0 r
.24207 .6206 m .24261 .62212 L .23988 .61994 L F
0 0 0 r
.65368 .39233 m .65469 .3908 L .65688 .38926 L F
.67885 .32135 m .6827 .31888 L .68351 .31902 L F
.633 .306 .399 r
.68548 .31867 m .68351 .31902 L .6827 .31888 L F
.558 .342 .543 r
.68639 .31644 m .68548 .31867 L .6827 .31888 L F
.483 0 0 r
.25453 .51798 m .25918 .51678 L .25675 .51718 L F
.745 .577 .666 r
.53362 .4362 m .53148 .43414 L .5342 .43377 L F
.123 .269 .742 r
.5342 .43377 m .5356 .43797 L .53362 .4362 L F
.435 .774 .997 r
.36352 .61549 m .36579 .6171 L .36268 .61703 L F
0 .193 .645 r
.36268 .61703 m .36306 .61707 L .36352 .61549 L F
.873 .759 .733 r
.35355 .61802 m .35379 .62279 L .3505 .62506 L F
.185 0 0 r
.3505 .62506 m .35379 .62279 L .35167 .62619 L F
0 0 .402 r
.35484 .62247 m .35379 .62279 L .35355 .61802 L F
0 0 0 r
.35167 .62619 m .35379 .62279 L .35484 .62247 L F
.51 .036 .065 r
.33758 .50377 m .34151 .50317 L .34022 .5034 L F
.654 .124 0 r
.34022 .5034 m .34151 .50317 L .34419 .50552 L F
.724 .679 .806 r
.55044 .42536 m .55429 .42625 L .55337 .42264 L F
.702 .248 .17 r
.55374 .42688 m .55429 .42625 L .55044 .42536 L F
.992 .758 .389 r
.55337 .42264 m .55429 .42625 L .55311 .42469 L F
.659 .453 .594 r
.62134 .39362 m .62146 .39632 L .61858 .39657 L F
.288 .788 .835 r
.62293 .39288 m .62134 .39362 L .62063 .39364 L F
.62293 .39288 m .62414 .39297 L .62134 .39362 L F
.589 .424 .626 r
.62414 .39297 m .62146 .39632 L .62134 .39362 L F
.692 .784 .922 r
.55032 .44457 m .55169 .44768 L .55442 .44534 L F
.79 .726 .793 r
.23411 .60925 m .2395 .60797 L .23549 .60734 L F
.4 .213 .508 r
.32857 .59776 m .33056 .6 L .33027 .59693 L F
.32857 .59776 m .32835 .60082 L .33056 .6 L F
.905 .849 .777 r
.5688 .43743 m .57087 .43955 L .57253 .43515 L F
0 0 .282 r
.57253 .43515 m .57087 .43955 L .57341 .43687 L F
.57386 .43595 m .57341 .43687 L .57413 .43611 L F
.57253 .43515 m .57341 .43687 L .57386 .43595 L F
0 .251 .73 r
.57128 .44119 m .5688 .43743 L .57027 .44156 L F
.57283 .44062 m .57192 .43989 L .57128 .44119 L F
.173 .16 .601 r
.57413 .43611 m .57087 .43955 L .57283 .44062 L F
0 .251 .73 r
.57283 .44062 m .57087 .43955 L .5688 .43743 L F
.57192 .43989 m .5688 .43743 L .57128 .44119 L F
.733 .468 .527 r
.33508 .58177 m .33841 .5844 L .33765 .58102 L F
.33508 .58177 m .33451 .58448 L .33841 .5844 L F
.524 .085 .147 r
.28066 .54853 m .27967 .54927 L .27691 .5491 L F
.379 0 .018 r
.28332 .5483 m .27967 .54927 L .28066 .54853 L F
.951 .614 .215 r
.60092 .40607 m .6018 .40784 L .60006 .40739 L F
.985 .723 .343 r
.60006 .40739 m .6018 .40784 L .60124 .41151 L F
.949 .698 .524 r
.6018 .40784 m .60237 .41272 L .60124 .41151 L F
.085 0 .435 r
.48079 .5611 m .47961 .56157 L .48078 .55833 L F
.077 0 .414 r
.4807 .56367 m .47961 .56157 L .48079 .5611 L F
.882 .961 .846 r
.54493 .41836 m .54864 .41629 L .54728 .41515 L F
.724 .763 .883 r
.55121 .41244 m .54864 .41629 L .55087 .41394 L F
.467 .336 .618 r
.46508 .48154 m .46713 .47748 L .46425 .47821 L F
.46508 .48154 m .46742 .48111 L .46713 .47748 L F
.331 0 .198 r
.46432 .48321 m .46742 .48111 L .46508 .48154 L F
0 0 .114 r
.43615 .52986 m .43506 .53274 L .43455 .52862 L F
.965 .654 .381 r
.3901 .55402 m .39156 .55257 L .39019 .55126 L F
.3901 .55402 m .39188 .55531 L .39156 .55257 L F
.736 .212 0 r
.37824 .5043 m .37707 .50494 L .37476 .50246 L F
.783 .28 0 r
.37907 .50573 m .37707 .50494 L .37824 .5043 L F
.467 .43 .733 r
.36283 .56017 m .36078 .56144 L .36012 .55851 L F
.746 .866 .936 r
.52576 .42728 m .52734 .42873 L .53058 .4265 L F
.755 .935 .945 r
.48095 .43198 m .47743 .43267 L .47972 .43121 L F
.827 .968 .894 r
.48095 .43198 m .48249 .42851 L .48406 .42977 L F
.48095 .43198 m .47972 .43121 L .48249 .42851 L F
.671 .203 .132 r
.42714 .5772 m .4283 .57611 L .4283 .57502 L F
.42714 .5772 m .43124 .57769 L .4283 .57611 L F
.995 .848 .578 r
.39099 .60253 m .39285 .60084 L .39216 .6002 L F
.39099 .60253 m .3922 .60351 L .39285 .60084 L F
.95 .95 .649 r
.39373 .59653 m .39216 .6002 L .39285 .60084 L F
.754 .951 .941 r
.63036 .34721 m .62924 .34963 L .63135 .3479 L F
.63036 .34721 m .62695 .34927 L .62924 .34963 L F
.461 .486 .798 r
.3656 .55501 m .36203 .55239 L .3653 .55184 L F
.768 .452 .452 r
.3302 .56518 m .32774 .56683 L .32756 .56604 L F
.3302 .56518 m .33064 .5672 L .32774 .56683 L F
.496 .486 .776 r
.33302 .56416 m .3302 .56518 L .33026 .5619 L F
.484 .33 .596 r
.33302 .56416 m .33064 .5672 L .3302 .56518 L F
0 .159 .694 r
.23161 .59754 m .23039 .59294 L .22904 .59391 L F
.23161 .59754 m .23202 .59671 L .23039 .59294 L F
.887 .977 .679 r
.23161 .59754 m .22907 .59873 L .23202 .59671 L F
.284 0 0 r
.45544 .59454 m .45922 .59401 L .458 .59459 L F
.204 0 0 r
.45922 .59401 m .46014 .59504 L .458 .59459 L F
.45922 .59401 m .46184 .59372 L .46014 .59504 L F
0 0 .445 r
.40389 .5019 m .40498 .50387 L .40412 .50257 L F
0 0 .207 r
.22553 .55123 m .22675 .54736 L .22668 .54918 L F
.92 .567 .349 r
.27736 .6437 m .27792 .64477 L .27935 .6432 L F
.371 0 .124 r
.27935 .6432 m .28346 .6404 L .27736 .6437 L F
.28051 .64291 m .28048 .64281 L .27935 .6432 L F
.28259 .64207 m .28346 .6404 L .27935 .6432 L F
.766 .322 0 r
.28199 .64592 m .28066 .64331 L .28069 .64341 L F
.28181 .64566 m .28069 .64341 L .28114 .64472 L F
.28199 .64592 m .28069 .64341 L .28181 .64566 L F
.371 0 .124 r
.28195 .6433 m .2824 .64243 L .281 .64278 L F
.691 .613 .765 r
.27935 .6432 m .27792 .64477 L .27745 .64404 L F
.27809 .64364 m .27745 .64404 L .27736 .64389 L F
.27935 .6432 m .27745 .64404 L .27809 .64364 L F
.371 0 .124 r
.28069 .64341 m .28045 .64292 L .27736 .6437 L F
.92 .567 .349 r
.27736 .6437 m .27935 .6432 L .28015 .64233 L F
.371 0 .124 r
.27809 .64364 m .27736 .6437 L .28015 .64233 L F
.691 .613 .765 r
.28015 .64233 m .27935 .6432 L .27455 .63952 L F
.27935 .6432 m .27736 .64389 L .27455 .63952 L F
.371 0 .124 r
.28069 .64341 m .27809 .64364 L .28015 .64233 L F
.45 .231 .488 r
.28199 .64592 m .28195 .6433 L .28015 .64233 L F
.371 0 .124 r
.28195 .6433 m .28069 .64341 L .28015 .64233 L F
.766 .322 0 r
.28114 .64472 m .28015 .64233 L .27981 .64283 L F
.28066 .64331 m .28015 .64233 L .28114 .64472 L F
.371 0 .124 r
.2824 .64243 m .28259 .64207 L .28048 .64281 L F
.2824 .64243 m .28048 .64281 L .28051 .64291 L F
.328 0 0 r
.28396 .6422 m .28346 .6404 L .28195 .6433 L F
.801 .396 .285 r
.28755 .64306 m .28346 .6404 L .28585 .64029 L F
.328 0 0 r
.28396 .6422 m .28585 .64029 L .28346 .6404 L F
.778 .847 .903 r
.59449 .45834 m .59833 .45839 L .59691 .45712 L F
.87 .826 .801 r
.59833 .45839 m .59906 .4538 L .59691 .45712 L F
.651 .564 .744 r
.43406 .46415 m .43515 .46815 L .43751 .46542 L F
.634 .173 .141 r
.24292 .61565 m .24072 .61384 L .23865 .61562 L F
.813 1 .804 r
.30302 .62712 m .30101 .6301 L .30338 .6286 L F
.639 .581 .774 r
.30207 .63392 m .30338 .6286 L .30101 .6301 L F
.754 .928 .573 r
.23318 .53313 m .2311 .53626 L .23138 .53545 L F
0 0 .101 r
.2306 .53898 m .23138 .53545 L .2311 .53626 L F
0 .126 .657 r
.23805 .61767 m .23988 .61994 L .23865 .61562 L F
.312 .128 .463 r
.33209 .55249 m .33381 .55438 L .33442 .55173 L F
.33209 .55249 m .3319 .55526 L .33381 .55438 L F
0 0 0 r
.32888 .59047 m .33192 .58754 L .32955 .5882 L F
.177 .712 .763 r
.61506 .39402 m .61423 .39441 L .61403 .39563 L F
0 0 0 r
.24373 .57896 m .2422 .58061 L .24519 .57755 L F
0 .15 .681 r
.22525 .58934 m .22558 .59186 L .22597 .59026 L F
.22401 .58774 m .22428 .58844 L .22525 .58934 L F
.22428 .58844 m .22558 .59186 L .22525 .58934 L F
.226 .182 .597 r
.22533 .58295 m .22525 .58934 L .22768 .5855 L F
.22525 .58934 m .22525 .58946 L .2253 .58938 L F
.22525 .58934 m .2253 .58938 L .22768 .5855 L F
.369 .3 .648 r
.22401 .58774 m .22525 .58946 L .22525 .58934 L F
.22401 .58774 m .22525 .58934 L .22533 .58295 L F
.099 .156 .634 r
.2253 .58938 m .22731 .5881 L .22768 .5855 L F
0 .15 .681 r
.22529 .58938 m .22597 .59026 L .22553 .58937 L F
.099 .156 .634 r
.22525 .58946 m .22538 .58938 L .2253 .58938 L F
.22538 .58938 m .22731 .5881 L .2253 .58938 L F
0 .15 .681 r
.22553 .58937 m .22597 .59026 L .22605 .58994 L F
.22401 .58774 m .22529 .58938 L .22553 .58937 L F
.218 .464 .88 r
.22558 .59186 m .22904 .59391 L .22605 .58994 L F
0 .406 .808 r
.61181 .37173 m .61214 .37196 L .6121 .37195 L F
.61181 .37173 m .6121 .37195 L .60948 .37094 L F
.61181 .37173 m .60948 .37094 L .60913 .37215 L F
.513 .807 .999 r
.6097 .37016 m .61181 .37173 L .60913 .37215 L F
.6097 .37016 m .61181 .37173 L .6097 .37016 L F
.898 .914 .825 r
.56468 .38612 m .56337 .38803 L .56201 .38681 L F
0 0 0 r
.44412 .52625 m .44017 .52874 L .44123 .52611 L F
.687 .575 .724 r
.46794 .53992 m .47069 .53923 L .47014 .53554 L F
.075 0 .189 r
.55451 .43449 m .55248 .43543 L .55231 .43743 L F
0 0 0 r
.47128 .58793 m .47431 .58505 L .47301 .58677 L F
.007 0 .299 r
.47588 .58131 m .47554 .58347 L .47431 .58505 L F
0 0 0 r
.47431 .58505 m .4748 .58569 L .47301 .58677 L F
.47431 .58505 m .47554 .58347 L .4748 .58569 L F
.751 .982 .91 r
.5287 .44328 m .53017 .44426 L .52797 .44555 L F
.928 .606 .41 r
.32281 .65831 m .32492 .65945 L .32383 .6612 L F
.989 .859 .619 r
.3248 .65385 m .32492 .65945 L .32281 .65831 L F
.166 0 0 r
.32492 .65945 m .32551 .66091 L .32383 .6612 L F
.32492 .65945 m .32738 .6587 L .32551 .66091 L F
.635 .739 .924 r
.29009 .66083 m .29246 .66319 L .29419 .66192 L F
.897 .783 .728 r
.35236 .60102 m .3512 .60391 L .35367 .60426 L F
.957 .939 .722 r
.35367 .60426 m .3517 .60497 L .3512 .60391 L F
.35367 .60426 m .3525 .60648 L .35219 .6059 L F
.35367 .60426 m .35219 .6059 L .35213 .60481 L F
.476 .57 .871 r
.35244 .60109 m .35367 .60426 L .35451 .60265 L F
.35236 .60102 m .3524 .60112 L .35244 .60109 L F
.3524 .60112 m .35367 .60426 L .35244 .60109 L F
.786 .47 .454 r
.35517 .59929 m .35464 .59949 L .35359 .5982 L F
.476 .57 .871 r
.35236 .60102 m .35451 .60265 L .35464 .59949 L F
.669 .76 .275 r
.35226 .60118 m .35236 .60102 L .35464 .59949 L F
.428 .815 .58 r
.35528 .59898 m .35226 .60118 L .35357 .60025 L F
.35519 .59905 m .35357 .60025 L .35464 .59949 L F
.35528 .59898 m .35357 .60025 L .35519 .59905 L F
.381 .008 .201 r
.3517 .60497 m .35367 .60426 L .3525 .60648 L F
.35213 .60481 m .35451 .60265 L .35367 .60426 L F
.3517 .60497 m .35224 .60452 L .35213 .60481 L F
.35224 .60452 m .35451 .60265 L .35213 .60481 L F
.416 .314 .63 r
.35297 .60252 m .3521 .60418 L .35226 .60118 L F
.381 .008 .201 r
.3517 .60497 m .35384 .6051 L .35451 .60265 L F
.082 0 .101 r
.35451 .60265 m .35384 .6051 L .35671 .60209 L F
0 0 0 r
.35384 .6051 m .35583 .6043 L .35671 .60209 L F
.416 .314 .63 r
.35419 .60481 m .35234 .60425 L .35297 .60252 L F
.35234 .60425 m .3521 .60418 L .35297 .60252 L F
.669 .76 .275 r
.35226 .60118 m .3512 .60391 L .35236 .60102 L F
.416 .314 .63 r
.3521 .60418 m .3512 .60391 L .35198 .6019 L F
.3521 .60418 m .35198 .6019 L .35226 .60118 L F
.957 .939 .722 r
.35213 .60481 m .35219 .6059 L .3517 .60497 L F
.339 .767 .973 r
.59394 .34938 m .59607 .34865 L .59887 .35023 L F
.849 .437 0 r
.59681 .34879 m .59887 .35023 L .59607 .34865 L F
.59681 .34879 m .5991 .3516 L .59887 .35023 L F
.155 0 .137 r
.33181 .63085 m .33618 .62716 L .33626 .6307 L F
.33624 .63073 m .33626 .6307 L .33626 .63073 L F
.33181 .63085 m .33626 .6307 L .33624 .63073 L F
.497 .469 .757 r
.33516 .63265 m .33181 .63085 L .33626 .63073 L F
.849 .479 .35 r
.33618 .62716 m .33738 .62906 L .33626 .63073 L F
.603 .819 .421 r
.33597 .63104 m .33734 .62912 L .33801 .62806 L F
.33734 .62912 m .33738 .62906 L .3374 .62904 L F
.925 .903 .783 r
.33738 .62906 m .33995 .62574 L .33767 .62565 L F
.33738 .62906 m .33767 .62565 L .33801 .62806 L F
.603 .819 .421 r
.33734 .62912 m .3374 .62904 L .33801 .62806 L F
.497 .469 .757 r
.33181 .63085 m .33519 .63196 L .33209 .6294 L F
.33181 .63085 m .33516 .63265 L .33519 .63196 L F
.33181 .63085 m .3329 .63329 L .33516 .63265 L F
.33516 .63265 m .3329 .63329 L .33181 .63085 L F
.159 0 0 r
.25609 .52373 m .25428 .52353 L .25819 .52292 L F
.056 0 0 r
.26109 .52357 m .25609 .52373 L .25819 .52292 L F
.947 .602 .322 r
.59239 .41619 m .59061 .4136 L .59084 .41482 L F
.973 .802 .611 r
.59172 .41865 m .59239 .41619 L .59084 .41482 L F
.681 .406 .499 r
.62679 .41667 m .63063 .4165 L .62679 .41671 L F
.62682 .41434 m .62906 .41561 L .62679 .41667 L F
.642 .967 .858 r
.63153 .41475 m .62965 .41638 L .63123 .41459 L F
.63145 .41449 m .63123 .41459 L .63142 .41438 L F
.63153 .41475 m .63123 .41459 L .63145 .41449 L F
.568 .838 .996 r
.63142 .41438 m .62965 .41638 L .63028 .41618 L F
.63142 .41438 m .63028 .41618 L .63229 .41554 L F
.915 .799 .717 r
.6337 .40855 m .63439 .41091 L .63153 .41475 L F
.804 .6 .039 r
.63106 .40947 m .63153 .41475 L .63111 .41148 L F
.915 .799 .717 r
.6337 .40855 m .63153 .41475 L .63106 .40947 L F
.767 .563 0 r
.63111 .41148 m .63153 .41475 L .63142 .41438 L F
.654 .507 .672 r
.63111 .41148 m .63439 .41175 L .63142 .41438 L F
.713 .98 .78 r
.63142 .41438 m .63439 .41175 L .63275 .41222 L F
0 0 0 r
.63267 .41239 m .63142 .41438 L .63275 .41222 L F
.853 .971 .87 r
.63229 .41554 m .63439 .41175 L .63142 .41438 L F
0 0 0 r
.63063 .4165 m .63142 .41438 L .63267 .41239 L F
.681 .406 .499 r
.62906 .41561 m .63063 .4165 L .62679 .41667 L F
.799 .792 .846 r
.40173 .47655 m .40442 .47848 L .40604 .4757 L F
.083 0 .029 r
.46798 .5908 m .47128 .58793 L .47045 .59028 L F
0 0 0 r
.47045 .59028 m .47128 .58793 L .47301 .58677 L F
.573 .321 .496 r
.33202 .61723 m .32948 .61994 L .33059 .6173 L F
.575 .331 .509 r
.33515 .52579 m .33837 .52267 L .33529 .52339 L F
.531 .83 .999 r
.58783 .45867 m .59157 .45908 L .5904 .45753 L F
.522 .764 .985 r
.5904 .45753 m .59157 .45908 L .59449 .45834 L F
.074 0 0 r
.46717 .59297 m .46798 .5908 L .47045 .59028 L F
.284 0 .273 r
.30752 .56524 m .30471 .56823 L .30648 .56753 L F
0 0 0 r
.31011 .56167 m .30752 .56524 L .30882 .56424 L F
.231 .042 .405 r
.30648 .56753 m .30882 .56424 L .30752 .56524 L F
.605 .708 .917 r
.28827 .64013 m .28755 .64306 L .28585 .64029 L F
.28827 .64013 m .29006 .64236 L .28755 .64306 L F
.86 .978 .857 r
.47114 .43773 m .46946 .43967 L .47012 .43681 L F
.801 .932 .919 r
.47012 .43681 m .46946 .43967 L .46801 .43876 L F
.995 .832 .566 r
.3957 .56801 m .39496 .57064 L .39626 .5718 L F
.974 .755 .33 r
.3953 .57347 m .39626 .5718 L .39496 .57064 L F
.3953 .57347 m .39616 .5744 L .39626 .5718 L F
.918 .524 .219 r
.55018 .43192 m .55141 .4316 L .54959 .43257 L F
0 .319 .78 r
.55141 .4316 m .55271 .43146 L .54959 .43257 L F
.5 .835 .998 r
.54324 .42587 m .54745 .42622 L .54617 .42567 L F
.641 .491 .663 r
.55005 .42236 m .54745 .42622 L .55044 .42536 L F
.55044 .42536 m .54745 .42622 L .55005 .42236 L F
.56 .9 .979 r
.55044 .42536 m .54745 .42622 L .54617 .42567 L F
.128 .447 .881 r
.57663 .37816 m .57897 .37763 L .57669 .37595 L F
.57663 .37816 m .57975 .37948 L .57897 .37763 L F
.741 .957 .66 r
.32569 .60146 m .32341 .60414 L .32405 .60291 L F
.316 0 0 r
.32569 .60146 m .32405 .60291 L .32739 .60195 L F
.313 0 .081 r
.32569 .60146 m .32739 .60195 L .32835 .60082 L F
.407 .304 .624 r
.55951 .42197 m .5596 .42451 L .55712 .42274 L F
.523 .27 .473 r
.5596 .42451 m .55667 .42517 L .55712 .42274 L F
.5596 .42451 m .55667 .42517 L .55712 .42274 L F
.67 .933 .645 r
.30754 .64919 m .30678 .65036 L .30476 .65206 L F
.169 0 0 r
.3072 .64986 m .30754 .64919 L .30649 .65016 L F
.31009 .64866 m .30754 .64919 L .3072 .64986 L F
0 0 0 r
.30863 .64721 m .30804 .64821 L .30754 .64919 L F
.30804 .64821 m .30678 .65036 L .30754 .64919 L F
.384 0 0 r
.31009 .64866 m .30863 .64721 L .30754 .64919 L F
.31009 .64866 m .31195 .64684 L .30863 .64721 L F
.979 .705 .314 r
.30703 .53806 m .30796 .5404 L .30885 .53931 L F
.872 .511 .017 r
.43524 .59481 m .43559 .59597 L .4345 .59449 L F
.131 0 .1 r
.61985 .35486 m .6193 .35664 L .61672 .3578 L F
0 0 0 r
.62069 .35495 m .61985 .35486 L .62104 .35411 L F
.62069 .35495 m .6193 .35664 L .61985 .35486 L F
.721 .805 .917 r
.73304 .3075 m .73151 .31015 L .73113 .30914 L F
.73304 .3075 m .73438 .30912 L .73151 .31015 L F
.596 .866 .993 r
.37246 .61713 m .36928 .61735 L .37137 .61736 L F
0 0 0 r
.36943 .62227 m .37246 .61713 L .37137 .61736 L F
.568 .564 .809 r
.37422 .61384 m .37246 .61713 L .37137 .61736 L F
.37422 .61384 m .37592 .61699 L .37246 .61713 L F
.597 .027 0 r
.37504 .61892 m .37246 .61713 L .37592 .61699 L F
.37504 .61892 m .37137 .61736 L .37246 .61713 L F
.724 .679 .806 r
.55044 .42536 m .55337 .42264 L .55005 .42236 L F
0 0 .393 r
.55128 .42337 m .55005 .42236 L .54881 .42108 L F
.55128 .42337 m .55044 .42536 L .55005 .42236 L F
0 0 0 r
.69773 .27943 m .69487 .28314 L .69703 .28158 L F
.158 0 .199 r
.69487 .28314 m .6972 .28366 L .69703 .28158 L F
.69487 .28314 m .6947 .2853 L .6972 .28366 L F
.403 .212 .505 r
.23153 .56417 m .22987 .56218 L .23075 .56038 L F
.23153 .56417 m .22901 .56516 L .22987 .56218 L F
.467 .43 .733 r
.36283 .56017 m .36012 .55851 L .36179 .55777 L F
.552 .516 .769 r
.45178 .57482 m .45511 .57777 L .45379 .57411 L F
.589 .33 .492 r
.57611 .3704 m .57584 .37354 L .57701 .37328 L F
.57611 .3704 m .57701 .37328 L .57725 .37165 L F
.652 .516 .685 r
.57584 .37354 m .57669 .37595 L .57845 .37296 L F
.796 .715 .181 r
.57677 .37484 m .57647 .37571 L .57696 .37217 L F
.57669 .37595 m .57661 .37587 L .57677 .37484 L F
.57661 .37587 m .57647 .37571 L .57677 .37484 L F
.589 .33 .492 r
.57725 .37165 m .57701 .37328 L .57845 .37296 L F
.125 0 .207 r
.65468 .32466 m .65648 .32253 L .65516 .32338 L F
.569 .918 .718 r
.65655 .32282 m .65516 .32338 L .65728 .32163 L F
.458 .821 .558 r
.65516 .32338 m .65719 .32169 L .65728 .32163 L F
.125 0 .207 r
.65648 .32253 m .65719 .32169 L .65516 .32338 L F
.372 .799 .616 r
.65358 .32439 m .65516 .32338 L .65655 .32282 L F
.65294 .32473 m .65516 .32338 L .65358 .32439 L F
.65294 .32473 m .65282 .32478 L .65516 .32338 L F
.977 .913 .665 r
.37705 .49713 m .3759 .49636 L .3773 .49279 L F
.099 .646 .83 r
.29419 .66192 m .29857 .66227 L .2965 .66109 L F
.067 .555 .894 r
.2965 .66109 m .29857 .66227 L .30062 .6626 L F
.826 .998 .781 r
.6638 .38712 m .66472 .38458 L .66271 .38602 L F
0 0 0 r
.66462 .38469 m .66271 .38602 L .66472 .38458 L F
.672 .92 .974 r
.66061 .38748 m .6638 .38712 L .66271 .38602 L F
0 0 0 r
.66174 .38762 m .66271 .38602 L .66462 .38469 L F
.672 .92 .974 r
.66028 .38752 m .66061 .38748 L .66271 .38602 L F
.826 .998 .781 r
.6638 .38712 m .66655 .38402 L .66472 .38458 L F
0 .001 .509 r
.60682 .42824 m .60868 .43021 L .60933 .43085 L F
.16 0 0 r
.55497 .40715 m .55347 .40689 L .55704 .40652 L F
.55497 .40715 m .55256 .40803 L .55347 .40689 L F
.992 .736 .407 r
.43446 .55564 m .43312 .55775 L .4329 .55241 L F
.43446 .55564 m .43402 .55811 L .43312 .55775 L F
.718 .757 .883 r
.65826 .35226 m .66178 .35054 L .65778 .35001 L F
.698 .744 .887 r
.65826 .35226 m .66024 .35248 L .65778 .35001 L F
.725 .75 .872 r
.65778 .35001 m .66178 .35054 L .66024 .35248 L F
.914 .511 .166 r
.38089 .53388 m .38189 .53267 L .38032 .5315 L F
.38089 .53388 m .38265 .53512 L .38189 .53267 L F
.655 .725 .901 r
.43559 .59597 m .43944 .59696 L .43815 .59613 L F
.435 .81 .993 r
.43944 .59696 m .44196 .5965 L .43815 .59613 L F
.718 .859 .949 r
.46414 .50993 m .46773 .5104 L .46397 .51272 L F
.46414 .50993 m .46688 .50878 L .46773 .5104 L F
.51 .068 .135 r
.46773 .5104 m .47013 .51177 L .47075 .51016 L F
.369 0 0 r
.46811 .51071 m .46773 .5104 L .46688 .50878 L F
.46811 .51071 m .47013 .51177 L .46773 .5104 L F
.751 .847 .401 r
.38751 .47737 m .38723 .47762 L .38609 .47963 L F
.591 .518 .741 r
.23479 .55809 m .23197 .55878 L .23126 .55529 L F
0 0 0 r
.23236 .55876 m .23197 .55878 L .23479 .55809 L F
.23236 .55876 m .23075 .56038 L .23197 .55878 L F
.04 0 0 r
.2403 .58849 m .23935 .58931 L .23869 .5883 L F
0 0 .335 r
.23869 .5883 m .23904 .59119 L .23821 .58757 L F
.953 .953 .7 r
.23869 .5883 m .23801 .59088 L .23904 .59119 L F
0 0 0 r
.23869 .5883 m .23685 .59168 L .23801 .59088 L F
.04 0 0 r
.23935 .58931 m .23728 .59112 L .23869 .5883 L F
0 0 .335 r
.23869 .5883 m .23821 .58757 L .23818 .58745 L F
.631 .929 .675 r
.3613 .61937 m .36043 .62071 L .35881 .62213 L F
.218 0 .063 r
.44445 .48868 m .44331 .48782 L .44613 .48753 L F
.44445 .48868 m .44196 .48978 L .44331 .48782 L F
.815 .813 .848 r
.64044 .34668 m .64482 .34533 L .64313 .34378 L F
.27 0 .203 r
.57544 .41579 m .57219 .41874 L .57241 .41665 L F
.64 .613 .806 r
.6164 .35996 m .62095 .36361 L .6209 .3611 L F
.607 .501 .707 r
.62095 .36361 m .62378 .36052 L .6209 .3611 L F
0 0 .352 r
.32812 .53623 m .32924 .53726 L .33042 .53545 L F
.151 0 .064 r
.33042 .53545 m .32924 .53726 L .33259 .53463 L F
.306 .071 .383 r
.33042 .53545 m .33259 .53463 L .33312 .53199 L F
.825 .87 .879 r
.33259 .53463 m .32924 .53726 L .32742 .53602 L F
.272 .041 .37 r
.33312 .53199 m .33476 .5332 L .3345 .53056 L F
.33312 .53199 m .33259 .53463 L .33476 .5332 L F
.743 .889 .946 r
.33257 .53408 m .33259 .53463 L .32903 .53365 L F
.825 .87 .879 r
.33259 .53463 m .32742 .53602 L .32903 .53365 L F
.564 .177 .268 r
.32742 .53602 m .33257 .53408 L .32903 .53365 L F
.616 .079 0 r
.33074 .53681 m .32971 .53657 L .33063 .53713 L F
.33063 .53713 m .32971 .53657 L .32924 .53726 L F
.33166 .53703 m .33074 .53681 L .33063 .53713 L F
.32971 .53657 m .32742 .53602 L .32924 .53726 L F
0 0 .352 r
.32812 .53623 m .32827 .53869 L .32924 .53726 L F
.32827 .53869 m .3283 .53912 L .32924 .53726 L F
.19 .389 .828 r
.3283 .53912 m .33114 .54098 L .32924 .53726 L F
.756 .703 .802 r
.32924 .53726 m .33114 .54098 L .33354 .53782 L F
.32924 .53726 m .32926 .53727 L .33166 .53703 L F
.32926 .53727 m .33354 .53782 L .33166 .53703 L F
.784 .682 .752 r
.33588 .53433 m .33354 .53782 L .33756 .5383 L F
0 0 0 r
.33383 .53739 m .33448 .53667 L .33354 .53782 L F
.33588 .53433 m .33448 .53667 L .33383 .53739 L F
.009 .215 .726 r
.33588 .53433 m .33756 .5383 L .33835 .53662 L F
.33588 .53433 m .33835 .53662 L .33962 .53467 L F
.74 .619 .725 r
.33588 .53433 m .33962 .53467 L .34023 .5313 L F
.975 .691 .294 r
.3345 .53056 m .33588 .53433 L .34023 .5313 L F
.654 .235 .237 r
.33835 .53662 m .33588 .53433 L .33476 .5332 L F
.33835 .53662 m .33448 .53667 L .33588 .53433 L F
.33835 .53662 m .33678 .53512 L .33696 .53508 L F
.33678 .53512 m .33476 .5332 L .33696 .53508 L F
.663 .495 .647 r
.3382 .53426 m .33724 .53501 L .33696 .53508 L F
.676 .833 .958 r
.33835 .53662 m .33448 .53667 L .33696 .53508 L F
.64 .142 .052 r
.33354 .53782 m .33518 .53955 L .33756 .5383 L F
.715 .975 .751 r
.33756 .5383 m .33518 .53955 L .33835 .53662 L F
.33756 .5383 m .33518 .53955 L .33835 .53662 L F
0 0 0 r
.33518 .53955 m .33716 .53818 L .33835 .53662 L F
.991 .739 .434 r
.33835 .53662 m .33716 .53818 L .33696 .53508 L F
.679 .977 .89 r
.34055 .53657 m .33756 .5383 L .33835 .53662 L F
.856 .897 .477 r
.33962 .53467 m .33835 .53662 L .33945 .53406 L F
0 0 .196 r
.33945 .53406 m .33835 .53662 L .34058 .53411 L F
.522 .135 .248 r
.33696 .53508 m .33833 .5371 L .34058 .53411 L F
.035 .009 .492 r
.33716 .53818 m .33833 .5371 L .33696 .53508 L F
.663 .495 .647 r
.33724 .53501 m .33476 .53696 L .33696 .53508 L F
.126 0 0 r
.33696 .53508 m .33495 .53615 L .33448 .53667 L F
.43 .813 .99 r
.33354 .53782 m .33448 .53667 L .33166 .53703 L F
.093 0 0 r
.33448 .53667 m .33391 .53681 L .33166 .53703 L F
.126 0 0 r
.33495 .53615 m .33229 .53757 L .33448 .53667 L F
.093 0 0 r
.33448 .53667 m .33229 .53757 L .32972 .53788 L F
.277 .148 .519 r
.33357 .5403 m .33518 .53955 L .33354 .53782 L F
0 0 .185 r
.33475 .54399 m .33518 .53955 L .33357 .5403 L F
.33475 .54399 m .33533 .54291 L .33518 .53955 L F
.508 .299 .531 r
.33518 .53955 m .33784 .54227 L .33716 .53818 L F
.33518 .53955 m .33533 .54291 L .33784 .54227 L F
.587 .651 .88 r
.3426 .54107 m .33965 .54198 L .33756 .5383 L F
.3426 .54107 m .33756 .5383 L .34055 .53657 L F
0 0 .194 r
.33784 .54227 m .33833 .5371 L .33716 .53818 L F
.33811 .53944 m .33832 .54113 L .33833 .5371 L F
.33784 .54227 m .33832 .54113 L .33811 .53944 L F
0 .246 .744 r
.33784 .54227 m .33898 .54232 L .33832 .54113 L F
.795 .363 .224 r
.33898 .54232 m .33843 .54198 L .33832 .54113 L F
.33843 .54198 m .33461 .53965 L .33832 .54113 L F
.806 .614 .643 r
.33649 .53836 m .33832 .54113 L .33461 .53965 L F
.33833 .5371 m .33833 .54061 L .33649 .53836 L F
.33833 .54061 m .33832 .54113 L .33649 .53836 L F
.33833 .5371 m .33649 .53836 L .3368 .5384 L F
.33649 .53836 m .33461 .53965 L .3368 .5384 L F
.663 .495 .647 r
.3382 .53426 m .3368 .5384 L .33476 .53696 L F
.405 .509 .851 r
.33529 .53688 m .3368 .5384 L .33599 .53678 L F
.33476 .53696 m .33616 .53795 L .33529 .53688 L F
.33616 .53795 m .3368 .5384 L .33529 .53688 L F
.126 0 0 r
.33696 .53508 m .33476 .53696 L .33302 .5372 L F
.33696 .53508 m .33238 .53755 L .33233 .53755 L F
.616 .079 0 r
.33166 .53703 m .32981 .53784 L .32742 .53602 L F
.32981 .53784 m .32972 .53788 L .32742 .53602 L F
.564 .177 .268 r
.32742 .53602 m .3304 .53694 L .33257 .53408 L F
.157 0 .303 r
.33097 .53619 m .33349 .53207 L .33257 .53408 L F
.3311 .53584 m .33349 .53207 L .33097 .53619 L F
.663 .831 .964 r
.33476 .5332 m .33259 .53463 L .33257 .53408 L F
.33476 .5332 m .33349 .53207 L .3345 .53056 L F
.98 .693 .321 r
.33349 .53207 m .33476 .5332 L .3345 .53056 L F
.663 .831 .964 r
.33476 .5332 m .33257 .53408 L .33349 .53207 L F
0 .123 .64 r
.3336 .53214 m .33476 .5332 L .33349 .53207 L F
.975 .691 .294 r
.3345 .53056 m .33476 .5332 L .33582 .53418 L F
0 .123 .64 r
.33531 .5332 m .33476 .5332 L .3336 .53214 L F
.975 .691 .294 r
.33582 .53418 m .33476 .5332 L .33588 .53433 L F
.157 0 .303 r
.3304 .53694 m .3311 .53584 L .33097 .53619 L F
.3304 .53694 m .33108 .53702 L .33349 .53207 L F
.434 .217 .483 r
.33349 .53207 m .33527 .53279 L .33531 .5332 L F
0 .123 .64 r
.33531 .5332 m .33696 .53508 L .33476 .5332 L F
.434 .217 .483 r
.33349 .53207 m .33108 .53702 L .33527 .53279 L F
.093 0 0 r
.33391 .53681 m .33116 .53751 L .33166 .53703 L F
.473 .27 .523 r
.33229 .53757 m .33527 .53279 L .33108 .53702 L F
.126 0 0 r
.33302 .5372 m .33476 .53696 L .33238 .53755 L F
.33233 .53755 m .33238 .53755 L .33229 .53757 L F
.473 .27 .523 r
.33229 .53757 m .33476 .53696 L .33527 .53279 L F
.405 .509 .851 r
.33476 .53696 m .33311 .53097 L .33527 .53279 L F
.33476 .53696 m .33599 .53678 L .33311 .53097 L F
.093 0 0 r
.33116 .53751 m .32972 .53788 L .3306 .53749 L F
.33116 .53751 m .3306 .53749 L .33166 .53703 L F
0 0 0 r
.56952 .46506 m .57234 .46211 L .57124 .46358 L F
.57124 .46358 m .57234 .46211 L .57445 .46077 L F
.738 .825 .365 r
.57234 .46211 m .5739 .45837 L .57445 .46077 L F
0 .25 .75 r
.58066 .38111 m .58231 .38146 L .57975 .37948 L F
.58066 .38111 m .58341 .38308 L .58231 .38146 L F
.95 .75 .597 r
.31693 .63234 m .31907 .6336 L .31788 .62972 L F
.728 .932 .599 r
.31735 .63507 m .31907 .6336 L .31693 .63234 L F
.929 .574 .331 r
.31907 .6336 m .31972 .63388 L .32145 .63251 L F
.31907 .6336 m .32034 .63663 L .31735 .63507 L F
.31907 .6336 m .31735 .63507 L .31972 .63388 L F
.899 .583 .441 r
.37086 .52086 m .37335 .51947 L .37058 .51884 L F
.37086 .52086 m .37383 .52233 L .37335 .51947 L F
.721 .782 .9 r
.63141 .38523 m .63301 .38687 L .62922 .3863 L F
.788 .689 .755 r
.62922 .3863 m .63301 .38687 L .63059 .39021 L F
.79 .794 .855 r
.6356 .38379 m .63301 .38687 L .63141 .38523 L F
.799 .748 .805 r
.56406 .38269 m .56468 .38612 L .5635 .38473 L F
.56406 .38269 m .56551 .38468 L .56468 .38612 L F
.898 .914 .825 r
.56468 .38612 m .56201 .38681 L .5635 .38473 L F
.621 .87 .989 r
.43198 .54807 m .43199 .54925 L .43254 .54696 L F
.837 .904 .885 r
.69365 .33848 m .68949 .33994 L .69256 .33716 L F
.857 .41 .128 r
.38581 .54378 m .387 .54261 L .3854 .54145 L F
.38581 .54378 m .38797 .54488 L .387 .54261 L F
.839 .685 .691 r
.61247 .35743 m .61347 .36138 L .6105 .36065 L F
.687 .399 .48 r
.61347 .36138 m .60981 .36397 L .6105 .36065 L F
.61347 .36138 m .6142 .3634 L .60981 .36397 L F
.326 .064 .354 r
.61672 .3578 m .61347 .36138 L .61247 .35743 L F
.61672 .3578 m .6164 .35996 L .61347 .36138 L F
.753 .67 .77 r
.6142 .3634 m .6164 .35996 L .61347 .36138 L F
0 .019 .531 r
.61546 .36168 m .61347 .36138 L .6164 .35996 L F
.61546 .36168 m .6142 .3634 L .61347 .36138 L F
.546 .506 .762 r
.61247 .35743 m .6164 .35996 L .61347 .36138 L F
.64 .611 .805 r
.2891 .64999 m .29298 .65274 L .29145 .64887 L F
.294 .782 .901 r
.29376 .65206 m .29527 .65237 L .29298 .65274 L F
.29376 .65206 m .29298 .65274 L .29232 .65622 L F
.873 .972 .657 r
.36678 .68473 m .36429 .68871 L .36664 .687 L F
.583 .499 .726 r
.36664 .687 m .3687 .68381 L .36678 .68473 L F
0 0 0 r
.2364 .53035 m .23501 .53178 L .23803 .52922 L F
.802 .536 .535 r
.55946 .43553 m .5556 .43226 L .55813 .43434 L F
.627 .257 .323 r
.55451 .43449 m .55813 .43434 L .5556 .43226 L F
.178 .189 .632 r
.46693 .55226 m .46868 .55119 L .46794 .54788 L F
0 0 .16 r
.46813 .55355 m .46693 .55226 L .46734 .55505 L F
.46813 .55355 m .46868 .55119 L .46693 .55226 L F
.28 .382 .789 r
.62489 .40595 m .6242 .40605 L .62149 .39874 L F
.57 .933 .788 r
.66472 .38458 m .66655 .38402 L .66878 .38246 L F
.804 .966 .652 r
.36592 .63863 m .36752 .63689 L .36555 .63851 L F
.795 .954 .623 r
.36847 .63517 m .36752 .63689 L .36901 .63466 L F
.81 .967 .653 r
.36555 .63851 m .36752 .63689 L .36847 .63517 L F
.36555 .63851 m .36847 .63517 L .36633 .63713 L F
0 0 0 r
.36637 .6371 m .36847 .63517 L .37064 .63467 L F
.36633 .63713 m .36847 .63517 L .36637 .6371 L F
.795 .954 .623 r
.36847 .63517 m .36901 .63466 L .36949 .63394 L F
.744 .661 .769 r
.28171 .62003 m .28237 .62285 L .28606 .6206 L F
.629 .823 .975 r
.3578 .64278 m .35708 .64365 L .35496 .64342 L F
.825 .709 .737 r
.28018 .62111 m .28237 .62285 L .28171 .62003 L F
.819 .834 .86 r
.27915 .62355 m .28237 .62285 L .28018 .62111 L F
0 0 .095 r
.61765 .35768 m .61672 .3578 L .6193 .35664 L F
.61765 .35768 m .6164 .35996 L .61672 .3578 L F
.231 .715 .931 r
.31336 .66121 m .31906 .66211 L .31688 .65941 L F
.357 .706 .985 r
.31688 .65941 m .31906 .66211 L .32065 .66165 L F
.423 .172 .427 r
.31011 .56167 m .31241 .56142 L .31297 .55853 L F
.468 .212 .443 r
.31297 .55853 m .31241 .56142 L .31508 .56054 L F
.583 .945 .86 r
.42849 .45183 m .42857 .45282 L .42653 .45324 L F
.42849 .45183 m .43089 .45145 L .42857 .45282 L F
0 0 .239 r
.32341 .60414 m .32417 .60577 L .32405 .60291 L F
.32341 .60414 m .32302 .60705 L .32417 .60577 L F
.568 .822 .993 r
.25746 .60341 m .25597 .60437 L .25325 .60293 L F
.739 .86 .937 r
.35419 .58114 m .35795 .58102 L .3567 .58034 L F
.35795 .58102 m .35419 .58114 L .3567 .58034 L F
.75 .612 .705 r
.59384 .4255 m .5956 .42918 L .59789 .42588 L F
.908 .564 .094 r
.39466 .56693 m .39502 .56533 L .39359 .56416 L F
.39466 .56693 m .3957 .56801 L .39502 .56533 L F
.913 .816 .738 r
.55568 .4379 m .55946 .43553 L .55813 .43434 L F
.573 .321 .496 r
.33202 .61723 m .33241 .61977 L .32948 .61994 L F
.438 .245 .52 r
.33417 .65597 m .33403 .65873 L .33657 .65597 L F
0 0 0 r
.63106 .40947 m .63359 .40673 L .6337 .40855 L F
.644 .355 .466 r
.63359 .40673 m .63481 .40824 L .6337 .40855 L F
.73 .44 .487 r
.56091 .41308 m .5642 .41299 L .56453 .41536 L F
.694 .156 0 r
.38199 .50767 m .38112 .50798 L .37907 .50573 L F
.648 .092 0 r
.38199 .50767 m .38432 .50984 L .38112 .50798 L F
.627 .071 0 r
.38613 .5107 m .38432 .50984 L .38199 .50767 L F
0 0 0 r
.56613 .46711 m .56952 .46506 L .56852 .46662 L F
.56852 .46662 m .56952 .46506 L .57124 .46358 L F
.783 .727 .801 r
.38723 .47762 m .39041 .48104 L .39274 .47743 L F
.584 .458 .674 r
.39041 .48104 m .39341 .48062 L .39274 .47743 L F
.516 .243 .44 r
.39007 .48347 m .39341 .48062 L .39041 .48104 L F
.971 .93 .669 r
.52338 .44247 m .52401 .43758 L .52217 .44096 L F
.171 .393 .837 r
.52488 .44083 m .52338 .44247 L .52217 .44096 L F
.52488 .44083 m .52635 .44399 L .52338 .44247 L F
.615 .678 .886 r
.55701 .44403 m .55865 .4472 L .56163 .44565 L F
0 0 .487 r
.63526 .41257 m .63439 .41091 L .6337 .40855 L F
.851 .929 .545 r
.70056 .3533 m .70044 .35456 L .70233 .35063 L F
.782 .765 .255 r
.69981 .35682 m .70044 .35456 L .70056 .3533 L F
.444 .526 .847 r
.53259 .42496 m .53455 .4289 L .53662 .42821 L F
.325 .486 .865 r
.34603 .51208 m .34678 .50999 L .34489 .51068 L F
.34603 .51208 m .34883 .51277 L .34678 .50999 L F
.724 .392 .416 r
.34603 .51208 m .34992 .51496 L .34883 .51277 L F
.34603 .51208 m .34533 .51535 L .34992 .51496 L F
.987 .759 .503 r
.32111 .64101 m .32352 .63888 L .31902 .63902 L F
.32111 .64101 m .32338 .64334 L .32352 .63888 L F
.862 .975 .858 r
.32167 .63841 m .32352 .63888 L .3257 .63603 L F
.88 .92 .527 r
.32984 .65275 m .33106 .64854 L .33138 .65162 L F
0 0 .401 r
.33095 .65514 m .32984 .65275 L .33138 .65162 L F
.33095 .65514 m .32987 .6554 L .32984 .65275 L F
0 .409 .774 r
.26123 .62887 m .25968 .62796 L .25842 .6268 L F
.688 .248 .2 r
.26168 .62893 m .26322 .62956 L .26123 .62887 L F
.777 .981 .907 r
.26243 .62895 m .26511 .62777 L .26407 .62817 L F
0 .409 .774 r
.26215 .62919 m .26224 .62912 L .25968 .62796 L F
.26123 .62887 m .26215 .62919 L .25968 .62796 L F
.26215 .62919 m .26322 .62956 L .26224 .62912 L F
.576 0 0 r
.25968 .62796 m .26322 .62956 L .26165 .62932 L F
.777 .981 .907 r
.26165 .62932 m .26238 .62899 L .26243 .62895 L F
.26238 .62899 m .26511 .62777 L .26243 .62895 L F
.665 .825 .961 r
.46425 .47821 m .46713 .47748 L .4631 .47709 L F
0 0 .114 r
.43615 .52986 m .43623 .53213 L .4361 .53203 L F
.436 .53027 m .4361 .53203 L .43551 .53155 L F
.43615 .52986 m .4361 .53203 L .436 .53027 L F
.267 .443 .849 r
.43615 .53241 m .43664 .53364 L .43528 .53533 L F
.863 .543 .023 r
.4361 .53203 m .43615 .5324 L .43664 .53364 L F
0 0 .39 r
.4361 .53203 m .43664 .53364 L .43623 .53213 L F
.267 .443 .849 r
.43623 .53213 m .43664 .53364 L .43615 .53241 L F
.863 .543 .023 r
.43615 .5324 m .43626 .5334 L .43664 .53364 L F
.267 .443 .849 r
.43611 .5322 m .43528 .53533 L .43506 .53274 L F
.43623 .53213 m .43615 .53241 L .43611 .5322 L F
.43615 .53241 m .43528 .53533 L .43611 .5322 L F
.863 .543 .023 r
.43554 .53033 m .43616 .53297 L .43611 .5322 L F
0 0 .114 r
.43551 .53155 m .43622 .53212 L .43506 .53274 L F
.43622 .53212 m .43623 .53213 L .43622 .53214 L F
.43622 .53212 m .43622 .53214 L .43506 .53274 L F
.935 .596 .367 r
.43389 .53187 m .43614 .53332 L .43554 .53033 L F
.43614 .53332 m .43626 .5334 L .43616 .53297 L F
.43614 .53332 m .43616 .53297 L .43554 .53033 L F
.863 .543 .023 r
.43606 .53191 m .43611 .5322 L .4361 .53203 L F
.43554 .53033 m .43611 .5322 L .43606 .53191 L F
.43616 .53297 m .43626 .5334 L .4361 .53203 L F
0 0 .39 r
.43554 .53033 m .4361 .53203 L .43623 .53213 L F
.67 .134 0 r
.3778 .60109 m .37437 .59968 L .37645 .60049 L F
.591 .518 .741 r
.23479 .55809 m .23126 .55529 L .23455 .55549 L F
0 0 .098 r
.23476 .55641 m .23455 .55549 L .23548 .55408 L F
.23476 .55641 m .23479 .55809 L .23455 .55549 L F
.845 .927 .884 r
.51953 .40691 m .5167 .40968 L .51534 .40859 L F
.232 0 .299 r
.31997 .55969 m .31965 .56136 L .32212 .55825 L F
.868 .957 .614 r
.42439 .55064 m .42457 .55178 L .42597 .54919 L F
.722 .522 0 r
.42487 .55465 m .42457 .55178 L .42439 .55064 L F
0 0 .073 r
.69591 .36723 m .69786 .36288 L .69728 .36502 L F
0 0 0 r
.69527 .36863 m .69591 .36723 L .69728 .36502 L F
.569 .918 .718 r
.65655 .32282 m .65728 .32163 L .65899 .32151 L F
.831 .709 .73 r
.62922 .3863 m .63059 .39021 L .62674 .38929 L F
.846 .575 .528 r
.62674 .38929 m .63059 .39021 L .63066 .39278 L F
.591 .586 .815 r
.63059 .39021 m .63371 .39258 L .63333 .39052 L F
.638 .596 .79 r
.63333 .39052 m .63066 .39278 L .63059 .39021 L F
.999 .789 .466 r
.39617 .58734 m .39545 .58415 L .39594 .58717 L F
.98 .872 .5 r
.39479 .58931 m .39617 .58734 L .39594 .58717 L F
.39479 .58931 m .39545 .59162 L .39617 .58734 L F
.798 .637 .682 r
.42894 .52718 m .4308 .52611 L .43118 .52344 L F
.568 .021 0 r
.34426 .53545 m .34611 .53678 L .34846 .53604 L F
.008 .199 .711 r
.34704 .53226 m .34846 .53604 L .34924 .53429 L F
.725 .988 .822 r
.34846 .53604 m .34611 .53678 L .34924 .53429 L F
.807 .717 .766 r
.37155 .67774 m .37293 .68104 L .36872 .68078 L F
.592 .398 .588 r
.37155 .67948 m .37302 .67735 L .37155 .67774 L F
.718 .837 .938 r
.36909 .68113 m .37293 .68104 L .37041 .68237 L F
.36954 .68083 m .37293 .68104 L .36909 .68113 L F
.592 .398 .588 r
.37156 .68125 m .37245 .67888 L .37155 .67948 L F
.37245 .67888 m .37302 .67735 L .37155 .67948 L F
.718 .837 .938 r
.36872 .68078 m .36954 .68083 L .36909 .68113 L F
.979 .759 .535 r
.36872 .68078 m .37041 .68237 L .3687 .68381 L F
.639 .222 .235 r
.33127 .64313 m .33385 .64507 L .33018 .6449 L F
.531 .825 .999 r
.33127 .64313 m .33379 .64247 L .33385 .64507 L F
.618 .475 .666 r
.27691 .5491 m .27967 .54927 L .27942 .54559 L F
.515 .065 .121 r
.27967 .54927 m .27874 .55037 L .27691 .5491 L F
.27967 .54927 m .27874 .55037 L .27691 .5491 L F
.872 .434 .05 r
.43813 .56835 m .44051 .57103 L .4396 .57033 L F
.443 .463 .785 r
.44051 .57103 m .4417 .56757 L .4396 .57033 L F
.44051 .57103 m .44107 .57096 L .4417 .56757 L F
.289 .748 .952 r
.44051 .57103 m .44107 .57096 L .4396 .57033 L F
.575 .528 .766 r
.47069 .53923 m .47216 .53453 L .47014 .53554 L F
.47069 .53923 m .47341 .53857 L .47216 .53453 L F
.291 .149 .509 r
.47156 .54253 m .47341 .53857 L .47069 .53923 L F
.864 .435 .193 r
.23308 .60589 m .23469 .60543 L .23271 .60344 L F
.23308 .60589 m .23549 .60734 L .23469 .60543 L F
0 0 0 r
.2681 .52067 m .26527 .52122 L .26714 .52073 L F
0 0 .005 r
.63365 .39355 m .63234 .39463 L .63365 .39357 L F
.63371 .39258 m .63307 .39353 L .63365 .39355 L F
.63307 .39353 m .63234 .39463 L .63365 .39355 L F
.223 0 .149 r
.63603 .39384 m .63581 .39372 L .63356 .39486 L F
.6345 .39307 m .63371 .39258 L .63369 .39326 L F
.63394 .3934 m .63369 .39326 L .63368 .39355 L F
.32 .293 .672 r
.63371 .39258 m .63613 .38926 L .63333 .39052 L F
.63371 .39258 m .63638 .39232 L .63613 .38926 L F
.223 0 .149 r
.63603 .39384 m .63638 .39232 L .63371 .39258 L F
0 .073 .611 r
.63459 .38991 m .63402 .39344 L .63333 .39052 L F
.63402 .39344 m .63394 .3934 L .63333 .39052 L F
.638 .596 .79 r
.63393 .39334 m .63394 .3934 L .63367 .39355 L F
.63394 .3934 m .63399 .39363 L .63368 .39355 L F
.63394 .3934 m .63368 .39355 L .63367 .39355 L F
.223 0 .149 r
.63368 .39355 m .63371 .39258 L .63365 .39355 L F
.638 .596 .79 r
.63333 .39052 m .63393 .39334 L .63066 .39278 L F
.83 .96 .895 r
.63197 .39257 m .63321 .39322 L .63345 .39107 L F
.63321 .39322 m .63387 .39356 L .63345 .39107 L F
.63345 .39107 m .63387 .39356 L .63459 .38991 L F
0 .073 .611 r
.63402 .39344 m .63399 .39363 L .63394 .3934 L F
.83 .96 .895 r
.63387 .39356 m .63399 .39363 L .63402 .39344 L F
.63387 .39356 m .63402 .39344 L .63459 .38991 L F
.223 0 .149 r
.63457 .39305 m .63454 .39303 L .6345 .39307 L F
.63454 .39303 m .63371 .39258 L .6345 .39307 L F
.63457 .39305 m .63369 .39326 L .63394 .3934 L F
.63581 .39372 m .63457 .39305 L .63368 .39355 L F
.023 .553 .854 r
.63368 .39355 m .63399 .39363 L .63387 .39356 L F
.223 0 .149 r
.63581 .39372 m .63365 .39355 L .63356 .39486 L F
.023 .553 .854 r
.63367 .39355 m .63368 .39355 L .63385 .39355 L F
.63368 .39355 m .63387 .39356 L .63385 .39355 L F
.638 .596 .79 r
.63393 .39334 m .63367 .39355 L .63066 .39278 L F
.023 .553 .854 r
.63066 .39278 m .63367 .39355 L .63197 .39257 L F
.63367 .39355 m .63385 .39355 L .63197 .39257 L F
0 0 .005 r
.63365 .39357 m .6316 .39572 L .63356 .39486 L F
.63234 .39463 m .6316 .39572 L .63365 .39357 L F
.428 .83 .979 r
.44196 .5965 m .44538 .59664 L .44465 .59682 L F
.398 .852 .893 r
.44538 .59664 m .44724 .59549 L .44465 .59682 L F
.44538 .59664 m .44881 .59564 L .44724 .59549 L F
.483 .317 .579 r
.21977 .56622 m .22239 .56101 L .22115 .56275 L F
.21977 .56622 m .22394 .56555 L .22239 .56101 L F
0 0 .286 r
.22139 .57036 m .22251 .56865 L .22198 .5661 L F
.22191 .56615 m .22198 .5661 L .22194 .56593 L F
.22139 .57036 m .22198 .5661 L .22191 .56615 L F
0 0 .258 r
.22239 .56101 m .22303 .56288 L .22331 .56348 L F
.22303 .56288 m .22394 .56555 L .22331 .56348 L F
.173 .316 .769 r
.22131 .56598 m .22194 .56593 L .22394 .56555 L F
.85 .864 .852 r
.22331 .56348 m .22394 .56555 L .22194 .56593 L F
0 0 0 r
.22331 .56348 m .22227 .56586 L .22367 .56423 L F
.22331 .56348 m .22367 .56423 L .22382 .56405 L F
.82 .38 .192 r
.22194 .56593 m .22251 .56865 L .22182 .56688 L F
0 0 0 r
.22227 .56586 m .22182 .56688 L .22292 .56533 L F
.22227 .56586 m .22292 .56533 L .22382 .56405 L F
0 0 .014 r
.22194 .56593 m .22182 .56688 L .22225 .56592 L F
.22194 .56593 m .22225 .56592 L .22331 .56348 L F
.173 .316 .769 r
.21977 .56622 m .22194 .56593 L .22131 .56598 L F
.21977 .56622 m .2211 .56806 L .22194 .56593 L F
.652 .572 .752 r
.23842 .5452 m .23568 .5456 L .2352 .54206 L F
.512 .73 .972 r
.34304 .55465 m .34474 .55555 L .34445 .55369 L F
.836 .536 .482 r
.34221 .55737 m .34474 .55555 L .34304 .55465 L F
.34221 .55737 m .34551 .5582 L .34474 .55555 L F
.448 .679 .963 r
.34474 .55555 m .34688 .55397 L .34445 .55369 L F
.458 .449 .761 r
.34551 .5582 m .34688 .55397 L .34474 .55555 L F
.815 .791 .83 r
.67793 .3543 m .67926 .35602 L .6778 .35452 L F
.664 .9 .979 r
.67968 .3523 m .68362 .35146 L .68282 .35224 L F
.67968 .3523 m .68282 .35224 L .68164 .35274 L F
.68164 .35274 m .68282 .35224 L .68218 .35286 L F
.162 .468 .891 r
.67801 .34962 m .67968 .3523 L .68218 .35286 L F
.67801 .34962 m .68218 .35286 L .6814 .3494 L F
.815 .791 .83 r
.68006 .35071 m .67962 .35359 L .67793 .3543 L F
.67962 .35359 m .67926 .35602 L .67793 .3543 L F
1 .821 .511 r
.68362 .35146 m .6833 .35425 L .68218 .35286 L F
.729 .474 .541 r
.69723 .32221 m .69404 .32448 L .69347 .322 L F
.69723 .32221 m .69755 .32486 L .69404 .32448 L F
.692 .447 .548 r
.69939 .32449 m .69723 .32221 L .70035 .32209 L F
.69939 .32449 m .69755 .32486 L .69723 .32221 L F
.591 .57 .799 r
.61864 .39957 m .62086 .4064 L .61919 .40436 L F
.719 .648 .778 r
.62149 .39874 m .62086 .4064 L .61864 .39957 L F
0 0 .041 r
.47591 .58342 m .47588 .58131 L .47598 .58024 L F
.47591 .58342 m .47554 .58347 L .47588 .58131 L F
.44 .452 .776 r
.22239 .56101 m .22456 .56092 L .22346 .55777 L F
0 0 .258 r
.22239 .56101 m .22331 .56348 L .22456 .56092 L F
.98 .743 .509 r
.39187 .56008 m .39351 .56148 L .39373 .55877 L F
.994 .858 .593 r
.39252 .55715 m .39187 .56008 L .39373 .55877 L F
.711 .926 .592 r
.42634 .54801 m .42439 .55064 L .42597 .54919 L F
.864 .972 .658 r
.23748 .5504 m .23782 .55155 L .23946 .54876 L F
0 0 0 r
.23964 .54948 m .23748 .5504 L .23946 .54876 L F
.22 0 0 r
.23964 .54948 m .23667 .54898 L .23748 .5504 L F
0 0 .336 r
.23725 .54965 m .23748 .5504 L .23667 .54898 L F
.23859 .55118 m .23748 .5504 L .23725 .54965 L F
.864 .972 .658 r
.23748 .5504 m .23733 .55239 L .23782 .55155 L F
0 0 0 r
.23728 .55299 m .23733 .55239 L .23748 .5504 L F
.23728 .55299 m .23548 .55408 L .23733 .55239 L F
.52 .302 .524 r
.5175 .49058 m .51738 .49317 L .51475 .49364 L F
.485 .257 .493 r
.52027 .48997 m .51738 .49317 L .5175 .49058 L F
.881 .704 .658 r
.32471 .52268 m .32645 .52811 L .32151 .52534 L F
.336 .683 .979 r
.32151 .52534 m .32645 .52811 L .32468 .52622 L F
0 .055 .609 r
.32634 .52409 m .32645 .52811 L .32471 .52268 L F
.824 .899 .894 r
.32468 .52622 m .32645 .52811 L .32634 .52409 L F
.731 .512 .595 r
.54646 .45453 m .54917 .45179 L .54663 .4517 L F
.54646 .45453 m .55008 .45537 L .54917 .45179 L F
.645 .42 .563 r
.55008 .45537 m .55368 .45181 L .54917 .45179 L F
.871 .736 .71 r
.36633 .58783 m .36439 .59105 L .36214 .59003 L F
.82 .522 .485 r
.43741 .56562 m .4346 .56756 L .43407 .56474 L F
.43741 .56562 m .43813 .56835 L .4346 .56756 L F
.561 .629 .876 r
.34278 .56924 m .34546 .57092 L .34504 .56794 L F
.34 .255 .613 r
.34546 .57092 m .34678 .56542 L .34504 .56794 L F
.34546 .57092 m .34805 .5706 L .34678 .56542 L F
.46 .204 .438 r
.34476 .57373 m .34805 .5706 L .34546 .57092 L F
.737 .564 .659 r
.30909 .66568 m .31221 .66272 L .30896 .66203 L F
.095 .273 .755 r
.31448 .66005 m .31336 .66121 L .31482 .66027 L F
0 0 0 r
.31444 .65913 m .31278 .6618 L .31336 .66121 L F
.214 .71 .916 r
.31006 .65874 m .31444 .65913 L .31237 .6587 L F
.903 .739 .668 r
.31237 .6587 m .31444 .65913 L .31336 .66121 L F
.095 .273 .755 r
.31237 .6587 m .31336 .66121 L .31448 .66005 L F
0 0 0 r
.31278 .6618 m .31221 .66272 L .31336 .66121 L F
.66 .645 .825 r
.3509 .6098 m .34822 .61243 L .34732 .61037 L F
.816 .404 .266 r
.66606 .35401 m .66178 .35054 L .66348 .35508 L F
.439 .238 .509 r
.41637 .50663 m .41609 .5099 L .41305 .5105 L F
.851 .929 .545 r
.70056 .3533 m .70233 .35063 L .70186 .34986 L F
.599 .57 .793 r
.24503 .59066 m .24571 .59106 L .24423 .58701 L F
.681 .452 .568 r
.242 .59388 m .24571 .59106 L .24503 .59066 L F
.464 .298 .57 r
.32948 .61994 m .32979 .62262 L .3269 .62333 L F
.568 .001 0 r
.38613 .5107 m .38544 .51079 L .38432 .50984 L F
.64 .099 0 r
.38613 .5107 m .38803 .5127 L .38544 .51079 L F
.397 .179 .463 r
.4307 .47779 m .43254 .47961 L .43225 .47613 L F
.4307 .47779 m .43021 .48051 L .43254 .47961 L F
.866 .576 .495 r
.32817 .54404 m .32993 .54555 L .32872 .54292 L F
.409 .395 .733 r
.3283 .53912 m .32872 .54292 L .33114 .54098 L F
.496 .421 .701 r
.32872 .54292 m .32993 .54555 L .33251 .54365 L F
.775 .632 .702 r
.42198 .48963 m .42821 .48645 L .42658 .4857 L F
.42198 .48963 m .42542 .49091 L .42821 .48645 L F
.784 .928 .929 r
.42967 .48322 m .42821 .48645 L .43199 .48493 L F
.42967 .48322 m .42658 .4857 L .42821 .48645 L F
0 .413 .81 r
.24867 .62115 m .25287 .62332 L .25078 .62021 L F
.288 .52 .903 r
.25078 .62021 m .25287 .62332 L .25375 .62167 L F
.155 .347 .803 r
.25375 .62167 m .25287 .62332 L .25439 .62398 L F
.041 0 0 r
.27326 .51901 m .27135 .52015 L .2681 .52067 L F
0 0 0 r
.27677 .51685 m .27465 .51846 L .27326 .51901 L F
.27465 .51846 m .27135 .52015 L .27326 .51901 L F
0 0 .31 r
.48464 .54805 m .48315 .55159 L .4835 .54903 L F
.724 .525 0 r
.43857 .55429 m .43917 .55919 L .43982 .55525 L F
.6 .77 .961 r
.41984 .48798 m .41953 .49063 L .42197 .48989 L F
.907 .784 .714 r
.41984 .48798 m .41968 .49267 L .41953 .49063 L F
.661 .766 .927 r
.68923 .31488 m .68639 .31644 L .68411 .31437 L F
.24 0 0 r
.28273 .57516 m .28126 .57695 L .27865 .5775 L F
.562 .86 .997 r
.28273 .57516 m .28085 .57427 L .285 .57429 L F
.552 .658 .906 r
.43406 .46415 m .43479 .46035 L .43241 .46148 L F
.43406 .46415 m .43722 .46413 L .43479 .46035 L F
.651 .564 .744 r
.43406 .46415 m .43751 .46542 L .43722 .46413 L F
.926 .966 .77 r
.34654 .52061 m .34581 .52446 L .34777 .52285 L F
.34654 .52061 m .3438 .5246 L .34581 .52446 L F
.789 .825 .881 r
.30062 .6626 m .30498 .66228 L .30373 .66202 L F
.739 .979 .741 r
.30565 .66057 m .30498 .66228 L .30747 .6596 L F
.684 .974 .911 r
.30373 .66202 m .30498 .66228 L .30565 .66057 L F
.693 .622 .772 r
.30498 .66228 m .30896 .66203 L .30747 .6596 L F
0 .278 .768 r
.30498 .66228 m .30909 .66568 L .30896 .66203 L F
.781 .795 .864 r
.37351 .55293 m .37101 .55413 L .37105 .55135 L F
.254 0 .264 r
.35811 .67794 m .35612 .6786 L .35539 .68107 L F
.35811 .67794 m .35612 .6786 L .35539 .68107 L F
.521 .773 .989 r
.5287 .44328 m .52797 .44555 L .52635 .44399 L F
.5287 .44328 m .52797 .44555 L .52635 .44399 L F
.576 .636 .873 r
.24499 .59451 m .24705 .59758 L .24944 .59688 L F
.801 .875 .901 r
.50495 .41679 m .50056 .41805 L .50365 .41559 L F
.745 .886 .944 r
.50718 .41546 m .50495 .41679 L .50365 .41559 L F
.694 .91 .564 r
.6402 .40225 m .63897 .40441 L .64152 .40106 L F
0 0 0 r
.6396 .40336 m .63897 .40441 L .6402 .40225 L F
.618 .904 .61 r
.63836 .40543 m .64036 .40336 L .63897 .40441 L F
0 0 0 r
.63816 .40606 m .63897 .40441 L .6396 .40336 L F
.618 .904 .61 r
.63745 .40636 m .63836 .40543 L .63897 .40441 L F
.961 .648 .382 r
.59592 .39611 m .59815 .40071 L .59695 .39879 L F
.636 .122 0 r
.59815 .40071 m .5979 .40097 L .59695 .39879 L F
.59815 .40071 m .5995 .40228 L .5979 .40097 L F
.492 .499 .792 r
.47075 .51016 m .47199 .50609 L .46982 .50704 L F
.47075 .51016 m .47353 .50932 L .47199 .50609 L F
.641 .406 .547 r
.47013 .51177 m .47353 .50932 L .47075 .51016 L F
.709 .531 .646 r
.30882 .56424 m .31241 .56142 L .31011 .56167 L F
.822 .75 .784 r
.34323 .56426 m .34504 .56794 L .34434 .56566 L F
.34323 .56426 m .34064 .5676 L .34504 .56794 L F
.798 .799 .853 r
.34064 .5676 m .34278 .56924 L .34504 .56794 L F
.744 .716 .825 r
.34574 .56552 m .34504 .56794 L .34678 .56542 L F
.606 .601 .82 r
.34678 .56542 m .34985 .56416 L .34738 .56476 L F
.34678 .56542 m .3514 .56795 L .34985 .56416 L F
.296 .227 .608 r
.34678 .56542 m .34948 .56931 L .3514 .56795 L F
.34948 .56931 m .34968 .5696 L .34979 .56949 L F
.34948 .56931 m .34979 .56949 L .3514 .56795 L F
.758 .539 .601 r
.34985 .56416 m .35071 .56747 L .34881 .56718 L F
.296 .227 .608 r
.34678 .56542 m .34805 .5706 L .34929 .56984 L F
.34678 .56542 m .34929 .56984 L .34913 .56897 L F
.34678 .56542 m .34959 .56966 L .34948 .56931 L F
.758 .539 .601 r
.34842 .56503 m .34881 .56718 L .34566 .5667 L F
.34985 .56416 m .34881 .56718 L .34842 .56503 L F
.296 .227 .608 r
.34913 .56897 m .34929 .56984 L .34959 .56966 L F
.34948 .56931 m .34959 .56966 L .34968 .5696 L F
.738 .456 .501 r
.34881 .56718 m .34802 .56849 L .34566 .5667 L F
.35071 .56747 m .34909 .56808 L .34881 .56718 L F
.34909 .56808 m .34802 .56849 L .34881 .56718 L F
.34802 .56849 m .34587 .56931 L .3457 .56717 L F
.34802 .56849 m .3457 .56717 L .34566 .5667 L F
.758 .539 .601 r
.34985 .56416 m .34566 .5667 L .34733 .56481 L F
.34755 .56472 m .34733 .56481 L .34738 .56476 L F
.34985 .56416 m .34733 .56481 L .34755 .56472 L F
.744 .716 .825 r
.34434 .56566 m .34447 .56608 L .34574 .56552 L F
.34447 .56608 m .34504 .56794 L .34574 .56552 L F
.66 .424 .551 r
.35066 .60695 m .3509 .6098 L .3525 .60648 L F
.35066 .60695 m .3509 .6098 L .3525 .60648 L F
.999 .837 .512 r
.39613 .5815 m .39559 .57685 L .39507 .58043 L F
.991 .86 .51 r
.3947 .58285 m .39613 .5815 L .39507 .58043 L F
.3947 .58285 m .39545 .58415 L .39613 .5815 L F
.533 .268 .46 r
.52955 .48396 m .5323 .48593 L .52981 .48641 L F
.52955 .48396 m .53228 .48365 L .5323 .48593 L F
.548 .515 .771 r
.46319 .54935 m .46121 .54507 L .45872 .54888 L F
.565 .561 .808 r
.73534 .30451 m .73438 .30912 L .73304 .3075 L F
.722 .629 .754 r
.7354 .30461 m .73985 .30582 L .73754 .30849 L F
.565 .561 .808 r
.73534 .30451 m .73534 .30469 L .73529 .30474 L F
.73534 .30451 m .73304 .3075 L .73534 .30469 L F
.73534 .30451 m .73534 .30469 L .73577 .30416 L F
.73534 .30451 m .7354 .30461 L .73534 .30469 L F
.722 .629 .754 r
.73534 .30451 m .73546 .30454 L .7354 .30461 L F
.73546 .30454 m .73985 .30582 L .7354 .30461 L F
.7 .655 .802 r
.73903 .30296 m .73985 .30582 L .73546 .30454 L F
.73556 .30442 m .73546 .30454 L .73534 .30451 L F
.73903 .30296 m .73546 .30454 L .73556 .30442 L F
.73903 .30296 m .73556 .30442 L .73577 .30416 L F
.73556 .30442 m .73534 .30451 L .73577 .30416 L F
0 0 0 r
.73537 .30465 m .73304 .3075 L .73513 .30495 L F
.73547 .30452 m .73513 .30495 L .7357 .30424 L F
.565 .561 .808 r
.7354 .30461 m .73754 .30849 L .73529 .30474 L F
0 0 0 r
.73537 .30465 m .73513 .30495 L .73547 .30452 L F
.73534 .30469 m .73527 .30477 L .73537 .30465 L F
.73527 .30477 m .73304 .3075 L .73537 .30465 L F
.7357 .30424 m .73383 .30654 L .73485 .30542 L F
.73383 .30654 m .73304 .3075 L .73309 .30745 L F
.73383 .30654 m .73309 .30745 L .73485 .30542 L F
.73577 .30416 m .73534 .30469 L .7357 .30424 L F
.565 .561 .808 r
.73529 .30474 m .73754 .30849 L .73438 .30912 L F
0 0 0 r
.7275 .26752 m .72589 .27023 L .72748 .2679 L F
.513 .714 .963 r
.72589 .27023 m .72919 .26996 L .72748 .2679 L F
.11 0 .299 r
.48904 .53511 m .48697 .53847 L .48739 .53627 L F
.957 .618 .246 r
.54663 .4517 m .54505 .44816 L .54332 .45201 L F
.743 .511 .578 r
.54184 .45374 m .54663 .4517 L .54332 .45201 L F
.54184 .45374 m .54646 .45453 L .54663 .4517 L F
.574 .307 .474 r
.28665 .54582 m .28604 .54837 L .28332 .5483 L F
.176 0 .318 r
.28848 .54481 m .28604 .54837 L .28665 .54582 L F
.703 .325 .33 r
.31567 .57459 m .3197 .57481 L .31851 .57724 L F
.031 0 .006 r
.31851 .57724 m .3197 .57481 L .3214 .57381 L F
.653 .914 .979 r
.55783 .38904 m .55624 .39014 L .55743 .388 L F
.96 .912 .723 r
.55702 .39128 m .55743 .388 L .55624 .39014 L F
.774 .997 .828 r
.62275 .3432 m .62105 .34506 L .62214 .34277 L F
.708 .942 .959 r
.62105 .34506 m .6204 .34408 L .62214 .34277 L F
.794 .72 .782 r
.33378 .6397 m .33653 .63644 L .33325 .63661 L F
.645 .207 .195 r
.33325 .63661 m .33486 .63849 L .33378 .6397 L F
.884 .689 .17 r
.33326 .6414 m .33378 .6397 L .33486 .63849 L F
.681 .452 .568 r
.242 .59388 m .24499 .59451 L .24571 .59106 L F
.703 .372 0 r
.24599 .59218 m .24571 .59106 L .24499 .59451 L F
.24599 .59218 m .24715 .59511 L .24571 .59106 L F
.867 .749 .237 r
.40962 .58778 m .40937 .58668 L .4097 .58391 L F
.805 .686 .142 r
.40962 .58778 m .40928 .58943 L .40937 .58668 L F
.40962 .58778 m .40936 .59108 L .40928 .58943 L F
.274 .779 .824 r
.45765 .48498 m .46039 .4843 L .46206 .48432 L F
.203 0 0 r
.46039 .4843 m .46432 .48321 L .46206 .48432 L F
.436 .3 .598 r
.36684 .60901 m .36394 .6072 L .36657 .60685 L F
.571 .913 .97 r
.44718 .44915 m .45005 .44786 L .45083 .44851 L F
.627 .947 .946 r
.45083 .44851 m .45206 .44672 L .45303 .44736 L F
.613 .932 .963 r
.45005 .44786 m .45206 .44672 L .45083 .44851 L F
.161 0 0 r
.34038 .49623 m .33604 .4954 L .33834 .49561 L F
.347 0 0 r
.33834 .49561 m .34228 .49702 L .34038 .49623 L F
.841 .998 .775 r
.5739 .45837 m .57442 .45602 L .57449 .45651 L F
0 0 .335 r
.57448 .45667 m .5739 .45837 L .57449 .45651 L F
.841 .998 .775 r
.57448 .45667 m .57701 .45478 L .57475 .45586 L F
.5739 .45837 m .57464 .45752 L .57448 .45667 L F
.57464 .45752 m .57701 .45478 L .57448 .45667 L F
.804 .648 .094 r
.57418 .45516 m .57449 .45651 L .57407 .45375 L F
.841 .998 .775 r
.5739 .45837 m .57475 .45586 L .57442 .45602 L F
.804 .648 .094 r
.57439 .45763 m .57448 .45667 L .57418 .45516 L F
.57448 .45667 m .57449 .45651 L .57418 .45516 L F
0 0 .335 r
.57439 .45763 m .5739 .45837 L .57448 .45667 L F
.593 .877 .993 r
.57701 .45478 m .5793 .45417 L .57815 .45279 L F
.712 .979 .774 r
.57442 .45602 m .57701 .45478 L .57815 .45279 L F
.697 .746 .889 r
.3718 .63222 m .36949 .63394 L .36826 .63149 L F
.857 .745 .738 r
.33241 .61977 m .33379 .62352 L .33121 .62292 L F
.839 .458 .33 r
.33121 .62292 m .33379 .62352 L .33163 .625 L F
.79 .715 .782 r
.33628 .62028 m .33379 .62352 L .33241 .61977 L F
.226 0 0 r
.30471 .56823 m .30115 .5691 L .30283 .5694 L F
.134 0 0 r
.30283 .5694 m .30648 .56753 L .30471 .56823 L F
.476 .21 .43 r
.43978 .52269 m .44238 .52222 L .44267 .51985 L F
.432 .864 .755 r
.67012 .37065 m .66605 .37242 L .67069 .36941 L F
.659 .969 .813 r
.66639 .37198 m .67069 .36941 L .66605 .37242 L F
.66766 .37037 m .66992 .36965 L .66639 .37198 L F
.66992 .36965 m .67069 .36941 L .66639 .37198 L F
.799 .933 .567 r
.67076 .36913 m .67012 .37065 L .67069 .36941 L F
.78 .997 .812 r
.67097 .36821 m .67069 .36941 L .66766 .37037 L F
.799 .933 .567 r
.67097 .36821 m .67012 .37065 L .67076 .36913 L F
.793 .987 .892 r
.67064 .36918 m .6732 .36815 L .67012 .37065 L F
.67097 .36821 m .67215 .36818 L .67064 .36918 L F
.67215 .36818 m .6732 .36815 L .67064 .36918 L F
.482 .232 .458 r
.51475 .49364 m .51405 .49652 L .51167 .49696 L F
.523 .27 .473 r
.51736 .49558 m .51475 .49364 L .51738 .49317 L F
.51736 .49558 m .51405 .49652 L .51475 .49364 L F
.756 .897 .941 r
.46135 .44137 m .45976 .4447 L .4587 .44404 L F
.46135 .44137 m .46308 .4427 L .45976 .4447 L F
.528 .109 .19 r
.3598 .58883 m .36214 .59003 L .35925 .59005 L F
0 .258 .712 r
.25439 .62398 m .25732 .6262 L .25842 .6268 L F
.723 .728 .854 r
.5681 .38342 m .56551 .38468 L .56406 .38269 L F
.984 .726 .453 r
.38797 .54488 m .38794 .54743 L .38975 .54837 L F
.921 .567 .345 r
.3882 .55042 m .38975 .54837 L .38794 .54743 L F
.3882 .55042 m .39019 .55126 L .38975 .54837 L F
.217 0 0 r
.27415 .57534 m .27838 .57425 L .27571 .57482 L F
.645 .207 .195 r
.33325 .63661 m .33653 .63644 L .33486 .63849 L F
.796 .7 .759 r
.33516 .63265 m .33653 .63644 L .33325 .63661 L F
.948 .642 .202 r
.33552 .63546 m .33653 .63644 L .33516 .63265 L F
.996 .859 .538 r
.33486 .63849 m .33653 .63644 L .33552 .63546 L F
.411 .477 .817 r
.58603 .45757 m .5861 .45428 L .58357 .45484 L F
.58603 .45757 m .58783 .45867 L .5861 .45428 L F
.897 .692 .617 r
.60012 .4514 m .60149 .44821 L .59832 .4473 L F
.477 .286 .543 r
.64628 .37041 m .64375 .37322 L .6464 .37325 L F
.653 .097 0 r
.72766 .32609 m .72705 .32652 L .72715 .3241 L F
.003 .547 .833 r
.26576 .51568 m .26808 .5161 L .27011 .51688 L F
.507 .853 .994 r
.27011 .51688 m .27075 .51543 L .272 .51538 L F
0 0 0 r
.2891 .64999 m .28955 .65074 L .28805 .65097 L F
.2891 .64999 m .29145 .64887 L .29049 .64982 L F
.907 .912 .812 r
.2898 .64907 m .29145 .64887 L .29353 .64554 L F
0 0 0 r
.28915 .65007 m .29049 .64982 L .28955 .65074 L F
.844 .455 .313 r
.28955 .65074 m .29145 .64887 L .2898 .64907 L F
.907 .912 .812 r
.2898 .64907 m .29353 .64554 L .2917 .64497 L F
.221 .383 .814 r
.29216 .64951 m .2898 .64907 L .29099 .64693 L F
.29238 .65 m .29142 .64965 L .29216 .64951 L F
.29142 .64965 m .2898 .64907 L .29216 .64951 L F
0 0 0 r
.2891 .64999 m .29049 .64982 L .28915 .65007 L F
.798 .973 .908 r
.47434 .43501 m .47114 .43773 L .47012 .43681 L F
0 0 0 r
.31613 .6198 m .31278 .62367 L .31554 .62281 L F
.238 0 .308 r
.31613 .6198 m .31746 .62202 L .31824 .61932 L F
.31613 .6198 m .31554 .62281 L .31746 .62202 L F
.601 .251 .348 r
.28749 .57406 m .29179 .57132 L .28918 .57201 L F
0 0 .39 r
.70084 .28933 m .70006 .28958 L .70197 .28725 L F
.936 .964 .68 r
.39338 .59294 m .39545 .59162 L .39479 .58931 L F
.39338 .59294 m .39402 .59392 L .39545 .59162 L F
.591 .57 .799 r
.61864 .39957 m .61919 .40436 L .61537 .40221 L F
.52 .539 .816 r
.25244 .60732 m .25502 .60705 L .25325 .60293 L F
.788 .687 .753 r
.42354 .49631 m .42797 .49745 L .42607 .49318 L F
.618 .606 .817 r
.42607 .49318 m .42797 .49745 L .42981 .49591 L F
.718 .987 .875 r
.71412 .3277 m .71637 .32481 L .71386 .32705 L F
.71412 .3277 m .71751 .32521 L .71637 .32481 L F
.264 .771 .845 r
.4597 .51688 m .46086 .51658 L .46296 .51645 L F
.564 .129 .173 r
.46296 .51645 m .46003 .51816 L .4586 .51703 L F
.892 .832 .78 r
.46296 .51645 m .46324 .51176 L .46397 .51272 L F
.46296 .51645 m .46086 .51658 L .46324 .51176 L F
.61 .069 0 r
.46296 .51645 m .46341 .5175 L .46003 .51816 L F
.46296 .51645 m .46512 .51857 L .46341 .5175 L F
.325 .196 .547 r
.46341 .5175 m .46377 .51584 L .46086 .51658 L F
.46377 .51584 m .46396 .51497 L .46086 .51658 L F
.264 .771 .845 r
.4586 .51703 m .46086 .51658 L .4597 .51688 L F
.645 .42 .563 r
.55008 .45537 m .55388 .45496 L .55368 .45181 L F
.526 .33 .558 r
.55388 .45496 m .55574 .45392 L .55368 .45181 L F
0 0 .211 r
.47946 .57011 m .47799 .57449 L .47837 .57166 L F
.856 .795 .79 r
.25204 .57811 m .25017 .58113 L .25316 .58078 L F
.564 .109 0 r
.58673 .39975 m .58409 .39632 L .58574 .39774 L F
.896 .683 .17 r
.58613 .40057 m .58673 .39975 L .58574 .39774 L F
.58613 .40057 m .58683 .40218 L .58673 .39975 L F
.921 .528 .173 r
.4008 .53324 m .39917 .53226 L .39814 .529 L F
.867 .467 .001 r
.4008 .53324 m .40049 .53444 L .39917 .53226 L F
.4008 .53324 m .40203 .53621 L .40049 .53444 L F
.644 .957 .933 r
.67208 .38011 m .67504 .3792 L .67434 .37892 L F
.5 .885 .705 r
.67504 .3792 m .67669 .37779 L .67434 .37892 L F
.67504 .3792 m .67826 .3771 L .67669 .37779 L F
.482 .374 .655 r
.4711 .52722 m .47316 .52239 L .47048 .52322 L F
.4711 .52722 m .47386 .52503 L .47316 .52239 L F
.447 .317 .61 r
.47364 .5286 m .4711 .52722 L .47156 .52951 L F
.47364 .5286 m .47386 .52503 L .4711 .52722 L F
.794 .92 .922 r
.64754 .339 m .64811 .34069 L .65229 .33752 L F
.256 0 0 r
.54829 .47788 m .54684 .47984 L .54454 .4804 L F
.465 .024 .114 r
.55057 .47906 m .54684 .47984 L .54829 .47788 L F
.443 .071 .236 r
.55118 .47748 m .55057 .47906 L .54829 .47788 L F
.478 .283 .536 r
.49854 .51305 m .49865 .51574 L .4959 .51612 L F
.333 .143 .467 r
.49865 .51574 m .49651 .5192 L .4959 .51612 L F
.614 .051 0 r
.34483 .49802 m .3488 .49934 L .34654 .49765 L F
.159 0 0 r
.25609 .52373 m .25334 .52494 L .25428 .52353 L F
.843 .957 .885 r
.59135 .36653 m .58728 .36866 L .59046 .36541 L F
.049 0 0 r
.59046 .36541 m .59516 .3652 L .59135 .36653 L F
.469 .073 .207 r
.42466 .48329 m .42648 .48377 L .42726 .48134 L F
.65 .863 .98 r
.42648 .48377 m .42967 .48322 L .42726 .48134 L F
.724 .718 .845 r
.42648 .48377 m .42658 .4857 L .42967 .48322 L F
.65 .863 .98 r
.42648 .48377 m .42777 .48314 L .42967 .48322 L F
.724 .718 .845 r
.42648 .48377 m .42967 .48322 L .42796 .48394 L F
.42648 .48377 m .42796 .48394 L .42777 .48314 L F
.137 .325 .789 r
.42796 .48394 m .42744 .48461 L .42617 .48286 L F
.42744 .48461 m .42658 .4857 L .42635 .48409 L F
.42744 .48461 m .42635 .48409 L .42617 .48286 L F
.469 .073 .207 r
.42344 .48421 m .42585 .48386 L .42466 .48329 L F
.42585 .48386 m .42648 .48377 L .42466 .48329 L F
.465 .181 .397 r
.42726 .48134 m .42967 .48322 L .43021 .48051 L F
.477 .532 .835 r
.27521 .61996 m .27915 .62355 L .27928 .62021 L F
.472 .306 .574 r
.27928 .62021 m .28018 .62111 L .28171 .62003 L F
.27928 .62021 m .27915 .62355 L .28018 .62111 L F
.375 0 .029 r
.42625 .50334 m .42738 .50475 L .42834 .50318 L F
.42625 .50334 m .42457 .50524 L .42738 .50475 L F
.96 .652 .4 r
.35062 .63197 m .35305 .6362 L .35275 .6332 L F
.399 .129 .384 r
.35484 .63287 m .35608 .63021 L .35275 .6332 L F
.959 .922 .576 r
.35608 .63021 m .35484 .63287 L .35275 .6332 L F
0 0 0 r
.35657 .63037 m .35589 .63073 L .35688 .62999 L F
.399 .129 .384 r
.35416 .63273 m .35275 .6332 L .35062 .63197 L F
.35484 .63287 m .35386 .63303 L .35416 .63273 L F
.35386 .63303 m .35275 .6332 L .35416 .63273 L F
.444 .264 .541 r
.35484 .63287 m .35305 .6362 L .35275 .6332 L F
.781 .669 .74 r
.35062 .63197 m .35305 .6362 L .35484 .63287 L F
0 0 0 r
.35429 .63314 m .3553 .63162 L .35657 .63037 L F
.3553 .63162 m .35589 .63073 L .35657 .63037 L F
.427 .77 .996 r
.36857 .61642 m .36579 .6171 L .36352 .61549 L F
.336 .158 .486 r
.36775 .6192 m .36579 .6171 L .36857 .61642 L F
.36775 .6192 m .36583 .61963 L .36579 .6171 L F
.701 .98 .803 r
.57383 .43312 m .57569 .43263 L .57253 .43515 L F
0 0 .282 r
.57253 .43515 m .57413 .43611 L .57383 .43312 L F
.429 0 0 r
.69347 .322 m .69237 .32323 L .68928 .32229 L F
.949 .597 .289 r
.69347 .322 m .69404 .32448 L .69237 .32323 L F
.27 0 .203 r
.57544 .41579 m .57463 .41974 L .57219 .41874 L F
.581 .201 .286 r
.57783 .41777 m .57463 .41974 L .57544 .41579 L F
.915 .867 .431 r
.61193 .37509 m .61246 .37623 L .61301 .37328 L F
.883 .935 .848 r
.61193 .37509 m .61068 .37979 L .61246 .37623 L F
.61193 .37509 m .60925 .37811 L .61068 .37979 L F
.042 0 0 r
.61193 .37509 m .61333 .37558 L .61135 .37604 L F
.61193 .37509 m .61135 .37604 L .61127 .37607 L F
.915 .867 .431 r
.61193 .37509 m .61301 .37328 L .61313 .37268 L F
.308 0 .033 r
.61361 .37926 m .61246 .37623 L .61068 .37979 L F
.812 .898 .484 r
.70573 .33928 m .70508 .34178 L .70678 .33812 L F
.779 .843 .386 r
.70416 .34388 m .70508 .34178 L .70573 .33928 L F
0 0 0 r
.44412 .52625 m .44232 .52742 L .44017 .52874 L F
.823 .963 .637 r
.44476 .52379 m .44412 .52625 L .44652 .52547 L F
.44476 .52379 m .44232 .52742 L .44412 .52625 L F
0 0 .335 r
.57439 .45763 m .57445 .46077 L .5739 .45837 L F
.902 .985 .735 r
.57803 .42884 m .57569 .43263 L .5749 .43209 L F
.893 .988 .748 r
.5749 .43209 m .57569 .43263 L .57383 .43312 L F
.971 .657 .343 r
.39585 .52298 m .3945 .52435 L .39432 .52182 L F
.39585 .52298 m .3961 .52552 L .3945 .52435 L F
.742 .468 .516 r
.30896 .66203 m .31006 .65874 L .30747 .6596 L F
.68 .288 .296 r
.25614 .61884 m .25999 .61919 L .25803 .61649 L F
.683 .191 .073 r
.26094 .61899 m .25803 .61649 L .25999 .61919 L F
.853 .901 .486 r
.70678 .33812 m .70826 .33344 L .70763 .33543 L F
.792 .896 .486 r
.70573 .33928 m .70678 .33812 L .70763 .33543 L F
.372 .156 .451 r
.49338 .52266 m .49401 .52521 L .49096 .52587 L F
.336 .131 .447 r
.49401 .52521 m .49085 .52888 L .49096 .52587 L F
.869 .423 .09 r
.62432 .41881 m .62579 .42113 L .62756 .42174 L F
.709 .875 .476 r
.62756 .42174 m .62607 .42355 L .62502 .42583 L F
.949 .6 .3 r
.62579 .42113 m .62607 .42355 L .62756 .42174 L F
.62579 .42113 m .62607 .42355 L .62756 .42174 L F
.942 .813 .687 r
.3257 .63603 m .3267 .63349 L .32475 .63171 L F
.406 .265 .575 r
.27967 .54927 m .28187 .54462 L .27942 .54559 L F
.845 .641 .627 r
.43344 .54439 m .43748 .54239 L .43502 .54087 L F
.43344 .54439 m .43687 .54647 L .43748 .54239 L F
.593 .655 .88 r
.54148 .40318 m .54098 .40389 L .53758 .40114 L F
.833 .999 .785 r
.34334 .60439 m .34064 .60753 L .34171 .60504 L F
.199 .081 .484 r
.33942 .60949 m .34171 .60504 L .34064 .60753 L F
.647 .68 .868 r
.73086 .3283 m .73287 .32912 L .73482 .32791 L F
.863 .723 .706 r
.61859 .3733 m .61711 .37668 L .61578 .3732 L F
.869 .651 .604 r
.59339 .42815 m .5956 .42918 L .59384 .4255 L F
.948 .811 .675 r
.59315 .43101 m .5956 .42918 L .59339 .42815 L F
.59315 .43101 m .59502 .43212 L .5956 .42918 L F
.981 .899 .655 r
.68026 .36035 m .67847 .36371 L .67871 .3604 L F
.6 .611 .834 r
.42803 .54645 m .42398 .54304 L .42678 .54195 L F
.488 0 0 r
.42803 .54645 m .43198 .54807 L .42888 .54752 L F
0 0 .375 r
.33929 .62344 m .33628 .62028 L .33867 .61999 L F
.415 0 0 r
.24091 .53914 m .23962 .53938 L .23878 .53885 L F
0 0 0 r
.24255 .53627 m .24201 .53783 L .24091 .53914 L F
.564 .936 .833 r
.24091 .53914 m .24201 .53783 L .23962 .53938 L F
0 0 .032 r
.24057 .53998 m .23962 .53938 L .24201 .53783 L F
.23949 .5416 m .23962 .53938 L .24057 .53998 L F
.415 0 0 r
.23878 .53885 m .23962 .53938 L .23664 .53855 L F
0 0 0 r
.43187 .50032 m .4331 .49941 L .43437 .49783 L F
.406 .78 .993 r
.47303 .51969 m .47482 .5193 L .47161 .51871 L F
.518 .393 .65 r
.47316 .52239 m .47482 .5193 L .47303 .51969 L F
.8 .927 .919 r
.47303 .51969 m .46833 .52127 L .47048 .52322 L F
.47303 .51969 m .47161 .51871 L .46833 .52127 L F
.589 .403 .598 r
.47048 .52322 m .47316 .52239 L .47303 .51969 L F
0 0 0 r
.2341 .59877 m .23418 .59808 L .23393 .59606 L F
.2341 .59877 m .23304 .6002 L .23418 .59808 L F
0 .032 .573 r
.26152 .62561 m .26009 .62347 L .26094 .62207 L F
.577 .835 .994 r
.63275 .3458 m .63135 .3479 L .63405 .34707 L F
.663 .945 .96 r
.63275 .3458 m .63036 .34721 L .63135 .3479 L F
.488 .346 .615 r
.63189 .35106 m .63405 .34707 L .63135 .3479 L F
0 0 0 r
.54442 .45022 m .54332 .45201 L .54505 .44816 L F
.707 .918 .576 r
.54184 .45374 m .54332 .45201 L .54442 .45022 L F
.953 .953 .684 r
.44613 .48753 m .44479 .49025 L .44445 .48868 L F
.935 .966 .694 r
.44593 .48597 m .44445 .48868 L .44613 .48753 L F
.564 .058 .009 r
.44445 .48868 m .44799 .48817 L .44613 .48753 L F
.873 .897 .846 r
.53449 .46127 m .53676 .45764 L .53729 .46097 L F
.608 .872 .537 r
.34799 .635 m .34983 .63307 L .35062 .63197 L F
.544 .434 .679 r
.52872 .4347 m .53196 .43693 L .53148 .43414 L F
0 0 0 r
.60865 .38915 m .61298 .38671 L .61121 .38798 L F
.647 .94 .692 r
.61121 .38798 m .61298 .38671 L .61381 .38583 L F
.645 .086 0 r
.35433 .53691 m .35487 .53613 L .356 .5338 L F
.35433 .53691 m .35738 .5383 L .35487 .53613 L F
.566 .293 .461 r
.35487 .53613 m .35738 .5383 L .35789 .53497 L F
.355 .746 .986 r
.285 .57429 m .28907 .5752 L .28749 .57406 L F
.327 .715 .982 r
.28907 .5752 m .29038 .57428 L .28749 .57406 L F
.28907 .5752 m .29107 .57513 L .29038 .57428 L F
.56 .343 .542 r
.35769 .5314 m .36014 .53204 L .36027 .52937 L F
.168 0 .346 r
.35789 .53497 m .36014 .53204 L .35769 .5314 L F
.56 .9 .979 r
.55044 .42536 m .54617 .42567 L .54867 .42658 L F
.806 .724 .774 r
.55128 .42337 m .54867 .42658 L .55044 .42536 L F
.621 .568 .773 r
.46552 .48879 m .46838 .48621 L .46594 .48727 L F
.741 .974 .721 r
.46305 .49028 m .46594 .48727 L .46435 .48809 L F
.655 .495 .655 r
.46552 .48879 m .46594 .48727 L .46305 .49028 L F
0 0 0 r
.46838 .48621 m .46435 .48809 L .46594 .48727 L F
.423 .663 .961 r
.36919 .61544 m .36928 .61735 L .36857 .61642 L F
.36919 .61544 m .37137 .61736 L .36928 .61735 L F
0 0 0 r
.36943 .62227 m .37137 .61736 L .36928 .61735 L F
.379 0 .037 r
.36928 .61735 m .36991 .61884 L .36775 .6192 L F
.36928 .61735 m .37137 .61736 L .36991 .61884 L F
.734 .639 .754 r
.53122 .41918 m .53673 .42236 L .53396 .41521 L F
.37 .626 .952 r
.53437 .4193 m .5365 .42207 L .53122 .41918 L F
.5365 .42207 m .53648 .42222 L .53122 .41918 L F
.459 .485 .799 r
.53396 .41521 m .53515 .41828 L .53802 .41935 L F
.53515 .41828 m .53673 .42236 L .53733 .42096 L F
.53515 .41828 m .53733 .42096 L .53802 .41935 L F
.726 .797 .908 r
.53802 .41935 m .53673 .42236 L .53437 .4193 L F
.637 .573 .766 r
.53622 .42162 m .53936 .42462 L .53943 .42354 L F
.5382 .42204 m .53943 .42354 L .5395 .42231 L F
.53622 .42162 m .53943 .42354 L .5382 .42204 L F
.381 .075 .316 r
.53678 .4202 m .53378 .42256 L .53622 .42162 L F
.53709 .41942 m .53686 .41963 L .53678 .4202 L F
.53686 .41963 m .53378 .42256 L .53678 .4202 L F
.37 .626 .952 r
.5365 .42207 m .53673 .42236 L .53648 .42222 L F
.236 .753 .809 r
.35853 .59879 m .35528 .59898 L .35464 .59949 L F
.088 0 .122 r
.35451 .60265 m .35748 .60016 L .35464 .59949 L F
.66 .709 .884 r
.57378 .41195 m .57099 .41375 L .57059 .41279 L F
.57059 .41279 m .57099 .41375 L .57378 .41195 L F
.996 .781 .421 r
.407 .5528 m .40525 .55287 L .40461 .55037 L F
.407 .5528 m .40616 .5536 L .40525 .55287 L F
.906 .609 .472 r
.6063 .35762 m .6036 .35912 L .60304 .35483 L F
.6063 .35762 m .60633 .36023 L .6036 .35912 L F
.742 .573 .664 r
.60931 .35731 m .60633 .36023 L .6063 .35762 L F
.616 .55 .757 r
.36511 .69131 m .36664 .687 L .36429 .68871 L F
.997 .776 .438 r
.74125 .30025 m .7427 .29937 L .74172 .29774 L F
.74125 .30025 m .74238 .30172 L .7427 .29937 L F
.74125 .30025 m .7427 .29937 L .74172 .29774 L F
.74125 .30025 m .74238 .30172 L .7427 .29937 L F
.646 .403 .536 r
.61858 .39657 m .62149 .39874 L .61768 .39859 L F
.61858 .39657 m .62146 .39632 L .62149 .39874 L F
.799 .999 .845 r
.46305 .49028 m .45922 .4927 L .46118 .49412 L F
.46305 .49028 m .46241 .48977 L .45922 .4927 L F
.91 .811 .737 r
.46214 .49255 m .46305 .49028 L .46118 .49412 L F
.741 .974 .721 r
.46305 .49028 m .46435 .48809 L .46241 .48977 L F
.69 .551 .692 r
.46214 .49255 m .46552 .48879 L .46305 .49028 L F
0 0 .119 r
.3156 .64176 m .31435 .64297 L .31366 .64536 L F
.061 .618 .813 r
.33733 .57789 m .33518 .57752 L .33284 .57742 L F
.048 .48 .886 r
.33733 .57789 m .33819 .57707 L .33518 .57752 L F
.33733 .57789 m .33905 .57796 L .33819 .57707 L F
.405 .444 .788 r
.33765 .58102 m .33905 .57796 L .33733 .57789 L F
.592 .656 .882 r
.43769 .51067 m .44123 .5129 L .43986 .50921 L F
.454 .318 .605 r
.44123 .5129 m .44389 .50963 L .43986 .50921 L F
.44123 .5129 m .44375 .51238 L .44389 .50963 L F
.64 .603 .796 r
.44123 .5129 m .44511 .51459 L .4435 .5151 L F
.44123 .5129 m .4435 .5151 L .44375 .51238 L F
.734 .859 .94 r
.58949 .35795 m .59304 .35773 L .59163 .35626 L F
.846 .883 .866 r
.59163 .35626 m .59304 .35773 L .59562 .35475 L F
.83 .536 .492 r
.33061 .50294 m .33552 .50649 L .33144 .50621 L F
.723 .932 .958 r
.33144 .50621 m .33552 .50649 L .33279 .50764 L F
.392 .182 .471 r
.33552 .50649 m .33758 .50377 L .337 .50582 L F
.441 .877 .817 r
.66549 .32799 m .66451 .32901 L .66686 .32746 L F
.66549 .32799 m .66297 .32918 L .66451 .32901 L F
.43 .138 .367 r
.56613 .46711 m .56576 .47009 L .56304 .47084 L F
.36 .066 .324 r
.56852 .46662 m .56576 .47009 L .56613 .46711 L F
.496 .486 .776 r
.33302 .56416 m .33026 .5619 L .33348 .5612 L F
.604 .426 .615 r
.33693 .55989 m .33302 .56416 L .33348 .5612 L F
.845 .927 .884 r
.51953 .40691 m .51534 .40859 L .5183 .40581 L F
.958 .907 .727 r
.51953 .40691 m .5183 .40581 L .52005 .40223 L F
.549 .271 .446 r
.52583 .48717 m .52305 .48975 L .52315 .48734 L F
0 0 0 r
.67826 .3771 m .68029 .37519 L .68059 .37535 L F
.525 .898 .71 r
.67669 .37779 m .67826 .3771 L .68059 .37535 L F
.93 .84 .394 r
.42628 .56335 m .42712 .56169 L .42647 .56097 L F
.951 .614 .215 r
.60092 .40607 m .60006 .40739 L .59968 .40478 L F
.385 .193 .493 r
.35539 .68107 m .35305 .68173 L .35285 .68454 L F
.712 .182 0 r
.40068 .48645 m .40328 .48799 L .40311 .48739 L F
.309 0 .17 r
.56046 .47164 m .56254 .47239 L .55986 .47305 L F
.56046 .47164 m .56304 .47084 L .56254 .47239 L F
.596 .795 .976 r
.46051 .47795 m .4631 .47709 L .45897 .47638 L F
.759 .963 .668 r
.64036 .40336 m .64301 .40016 L .64152 .40106 L F
.5 .867 .64 r
.64152 .40106 m .64301 .40016 L .64489 .39867 L F
.894 .764 .711 r
.3423 .63292 m .34323 .63628 L .34121 .63499 L F
.3423 .63292 m .34323 .63628 L .34121 .63499 L F
.643 .11 0 r
.34323 .63628 m .34377 .63757 L .34121 .63499 L F
.34323 .63628 m .34542 .63864 L .34377 .63757 L F
.299 .13 .477 r
.24129 .54473 m .23946 .54876 L .23842 .5452 L F
.24129 .54473 m .24113 .54813 L .23946 .54876 L F
0 0 0 r
.23964 .54948 m .23946 .54876 L .24113 .54813 L F
.774 .732 .814 r
.4631 .47709 m .46713 .47748 L .46545 .47347 L F
.65 .657 .844 r
.46713 .47748 m .46825 .47299 L .46545 .47347 L F
.46713 .47748 m .46988 .47656 L .46825 .47299 L F
.653 .474 .63 r
.46713 .47748 m .46968 .47983 L .46988 .47656 L F
.46713 .47748 m .46742 .48111 L .46968 .47983 L F
.399 0 0 r
.29672 .57062 m .29937 .57062 L .30115 .5691 L F
.232 0 0 r
.30115 .5691 m .29937 .57062 L .30283 .5694 L F
.017 .583 .788 r
.57783 .41777 m .58053 .41821 L .58193 .41827 L F
.989 .723 .4 r
.45275 .51169 m .45402 .51569 L .45437 .51266 L F
.993 .743 .43 r
.4527 .50891 m .45437 .51266 L .457 .50966 L F
.4527 .50891 m .45275 .51169 L .45437 .51266 L F
.684 .283 0 r
.45739 .51508 m .45437 .51266 L .45402 .51569 L F
.332 .451 .831 r
.55979 .45187 m .56331 .45436 L .56311 .45156 L F
.484 .397 .681 r
.43517 .47076 m .438 .47317 L .43762 .46942 L F
0 0 0 r
.26001 .60983 m .26435 .60675 L .26206 .6076 L F
.986 .731 .455 r
.26572 .6072 m .26548 .6098 L .26399 .60638 L F
.47 .842 .989 r
.26572 .6072 m .26399 .60638 L .26807 .60652 L F
.596 .43 .627 r
.26807 .60652 m .26548 .6098 L .26572 .6072 L F
.85 .439 0 r
.33862 .52785 m .34023 .5313 L .34047 .53072 L F
0 0 .025 r
.34023 .5313 m .3404 .53097 L .34047 .53072 L F
.126 0 0 r
.45544 .59454 m .4564 .59499 L .4538 .59496 L F
.45544 .59454 m .458 .59459 L .4564 .59499 L F
.179 0 0 r
.25918 .51678 m .26186 .5169 L .26308 .51612 L F
.139 0 0 r
.26186 .5169 m .26576 .51568 L .26308 .51612 L F
0 0 .18 r
.27677 .51685 m .27719 .51651 L .2774 .51461 L F
.283 .646 .967 r
.27292 .51418 m .27684 .51631 L .272 .51538 L F
.055 0 .184 r
.27972 .51426 m .27748 .51634 L .2774 .51461 L F
.283 .646 .967 r
.27683 .51632 m .27719 .51651 L .27681 .51642 L F
.27684 .51632 m .27719 .51651 L .27683 .51632 L F
.27684 .51631 m .27681 .51642 L .272 .51538 L F
0 0 0 r
.27681 .51638 m .27681 .51642 L .27683 .51632 L F
.27681 .51642 m .27677 .51685 L .27683 .51632 L F
.078 .584 .89 r
.272 .51538 m .27681 .51642 L .27677 .51685 L F
0 0 0 r
.27654 .51721 m .27677 .51685 L .27681 .51638 L F
.078 .584 .89 r
.27681 .51642 m .27719 .51651 L .27677 .51685 L F
.055 0 .184 r
.27748 .51634 m .27654 .51721 L .27683 .51632 L F
0 0 0 r
.27683 .51632 m .27677 .51685 L .2774 .51461 L F
.797 .723 .782 r
.2774 .51461 m .27719 .51651 L .27684 .51632 L F
.055 0 .184 r
.27684 .51632 m .27683 .51632 L .2774 .51461 L F
.797 .723 .782 r
.2774 .51461 m .27684 .51632 L .27292 .51418 L F
.055 0 .184 r
.27748 .51634 m .27684 .51632 L .2774 .51461 L F
.283 .646 .967 r
.27684 .51631 m .27684 .51632 L .27683 .51632 L F
0 0 0 r
.27654 .51721 m .27465 .51846 L .27677 .51685 L F
.861 .713 .696 r
.59674 .44119 m .59838 .44179 L .59688 .43827 L F
.813 .527 .505 r
.59689 .44405 m .59838 .44179 L .59674 .44119 L F
.59689 .44405 m .59856 .44454 L .59838 .44179 L F
.734 .639 .754 r
.53122 .41918 m .53396 .41521 L .53136 .41592 L F
0 0 .227 r
.5323 .41658 m .53136 .41592 L .53396 .41521 L F
.5323 .41658 m .53122 .41918 L .53136 .41592 L F
.469 .786 .999 r
.26414 .62492 m .26332 .62662 L .26152 .62561 L F
.536 .508 .772 r
.26414 .62492 m .26152 .62561 L .26094 .62207 L F
.918 .726 .233 r
.26277 .62377 m .26414 .62492 L .26275 .62365 L F
.469 .786 .999 r
.26414 .62492 m .26563 .62618 L .26332 .62662 L F
.918 .726 .233 r
.26354 .62724 m .26414 .62492 L .26277 .62377 L F
.469 .786 .999 r
.26414 .62492 m .26606 .6261 L .26563 .62618 L F
.535 .363 .595 r
.3682 .55174 m .3656 .55501 L .3653 .55184 L F
.776 .707 .786 r
.23469 .57471 m .23252 .57764 L .23063 .57374 L F
.27 .047 .379 r
.23469 .57471 m .23437 .57715 L .23252 .57764 L F
.115 .025 .466 r
.23387 .5796 m .23252 .57764 L .23437 .57715 L F
.23387 .5796 m .23259 .58127 L .23252 .57764 L F
.769 .586 .651 r
.61247 .35743 m .6105 .36065 L .60931 .35731 L F
.504 .858 .991 r
.31757 .61298 m .31337 .61289 L .3159 .61211 L F
.31757 .61298 m .31337 .61289 L .3159 .61211 L F
.613 .904 .985 r
.31757 .61298 m .3159 .61211 L .31978 .6118 L F
0 0 .545 r
.31757 .61298 m .31978 .6118 L .3159 .61211 L F
.31757 .61298 m .3188 .61407 L .31978 .6118 L F
.31757 .61298 m .31986 .61586 L .3188 .61407 L F
.97 .82 .639 r
.35305 .6362 m .35389 .63735 L .35207 .63897 L F
.342 .015 .258 r
.35577 .63838 m .35389 .63735 L .35207 .63897 L F
.35577 .63838 m .35635 .63588 L .35389 .63735 L F
.007 .195 .708 r
.35577 .63838 m .35389 .63735 L .35635 .63588 L F
.859 .408 .037 r
.41212 .5941 m .41059 .59344 L .40936 .59108 L F
.822 .48 .407 r
.41212 .5941 m .41151 .59596 L .41059 .59344 L F
.41212 .5941 m .413 .59646 L .41151 .59596 L F
.683 .905 .974 r
.62938 .33994 m .62584 .34055 L .62829 .33895 L F
.543 .882 .988 r
.62829 .33895 m .63305 .33894 L .62938 .33994 L F
.785 .533 .557 r
.36027 .52937 m .36014 .53204 L .35599 .53151 L F
.338 .769 .971 r
.36604 .57425 m .37018 .57475 L .369 .57398 L F
.36604 .57425 m .37018 .57475 L .369 .57398 L F
.956 .628 .353 r
.40524 .54501 m .4034 .54405 L .403 .54169 L F
.957 .615 .291 r
.40524 .54501 m .40382 .54694 L .4034 .54405 L F
.40524 .54501 m .40555 .54773 L .40382 .54694 L F
.763 .527 .575 r
.4417 .56757 m .44696 .56558 L .44177 .56483 L F
.4417 .56757 m .44563 .56766 L .44696 .56558 L F
.52 .543 .82 r
.39963 .47744 m .40337 .48051 L .40173 .47655 L F
.675 .788 .934 r
.38317 .67113 m .38549 .67259 L .38199 .67339 L F
.782 .766 .838 r
.38226 .67556 m .38317 .67113 L .38199 .67339 L F
.973 .686 .288 r
.40973 .57154 m .40897 .57347 L .40893 .57022 L F
.40973 .57154 m .40998 .57424 L .40897 .57347 L F
.723 .932 .958 r
.33144 .50621 m .33279 .50764 L .33212 .50741 L F
.983 .895 .56 r
.73482 .32791 m .73562 .32551 L .73508 .32289 L F
.439 .518 .843 r
.34105 .53635 m .34289 .53954 L .34418 .5382 L F
0 0 .201 r
.34418 .5382 m .3426 .54107 L .34289 .53954 L F
.364 .354 .714 r
.67086 .34448 m .67434 .34638 L .67379 .34426 L F
.848 .451 .29 r
.53297 .44674 m .53441 .44527 L .53195 .44443 L F
.804 .673 .719 r
.59756 .36581 m .601 .36398 L .59704 .3634 L F
.59756 .36581 m .59908 .36744 L .601 .36398 L F
.686 .973 .915 r
.67542 .36656 m .6732 .36815 L .67097 .36821 L F
.746 .555 .637 r
.42773 .51583 m .43266 .51645 L .43104 .51268 L F
.675 .574 .734 r
.43104 .51268 m .43451 .5132 L .43402 .50993 L F
.685 .528 .667 r
.43104 .51268 m .43266 .51645 L .43451 .5132 L F
.748 .946 .623 r
.63897 .40441 m .64036 .40336 L .64152 .40106 L F
.838 .982 .873 r
.2472 .61994 m .2475 .61774 L .2472 .61835 L F
.192 0 0 r
.24488 .62105 m .2472 .62111 L .2472 .61994 L F
.306 .771 .642 r
.24261 .62212 m .24694 .62007 L .24571 .6214 L F
.24694 .62007 m .2472 .61994 L .24571 .6214 L F
.467 .177 .389 r
.24261 .62212 m .24571 .6214 L .24464 .62375 L F
.97 .907 .556 r
.24475 .62245 m .24571 .6214 L .24505 .61869 L F
.24464 .62375 m .24571 .6214 L .24475 .62245 L F
.838 .982 .873 r
.2472 .61994 m .2472 .61835 L .24571 .6214 L F
.192 0 0 r
.2472 .62111 m .24867 .62115 L .2472 .61994 L F
.542 .827 .998 r
.2472 .61994 m .24867 .62115 L .25078 .62021 L F
.541 .681 .93 r
.28551 .65871 m .28776 .66143 L .29009 .66083 L F
.342 .14 .454 r
.49651 .5192 m .49637 .52189 L .49338 .52266 L F
.286 .073 .405 r
.49637 .52189 m .49401 .52521 L .49338 .52266 L F
.615 .387 .549 r
.42068 .59084 m .42355 .58769 L .42184 .58623 L F
.42068 .59084 m .42365 .59023 L .42355 .58769 L F
.875 .907 .849 r
.42184 .58623 m .42355 .58769 L .42613 .58426 L F
.575 .432 .649 r
.42355 .58769 m .42489 .58813 L .42613 .58426 L F
.804 .636 .673 r
.42365 .59023 m .42489 .58813 L .42355 .58769 L F
0 0 0 r
.43612 .53625 m .4352 .53769 L .43503 .53794 L F
.936 .967 .713 r
.43503 .53794 m .43502 .54087 L .43369 .54001 L F
.43503 .53794 m .43361 .54017 L .43502 .54087 L F
0 0 0 r
.4352 .53769 m .43361 .54017 L .43503 .53794 L F
.936 .967 .713 r
.43503 .53794 m .43369 .54001 L .43316 .53966 L F
.906 .896 .482 r
.43346 .54192 m .43502 .54087 L .43361 .54017 L F
.43346 .54192 m .43344 .54439 L .43502 .54087 L F
.83 .531 .483 r
.26863 .62953 m .26976 .62701 L .26606 .6261 L F
.455 .044 .17 r
.26927 .62973 m .26976 .62701 L .26863 .62953 L F
.26927 .62973 m .27264 .62743 L .26976 .62701 L F
.719 .584 .702 r
.46016 .49626 m .46469 .497 L .46214 .49255 L F
.72 .58 .697 r
.46208 .50015 m .46469 .497 L .46016 .49626 L F
.71 .565 .689 r
.46208 .50015 m .4653 .49953 L .46469 .497 L F
.691 .548 .686 r
.46759 .4967 m .46214 .49255 L .46469 .497 L F
.607 .365 .524 r
.4673 .49928 m .46469 .497 L .4653 .49953 L F
.4673 .49928 m .46759 .4967 L .46469 .497 L F
.921 .922 .796 r
.4417 .56757 m .44107 .57096 L .4396 .57033 L F
.732 .211 0 r
.4396 .57033 m .44107 .57096 L .44144 .57264 L F
0 0 .112 r
.44171 .56978 m .44107 .57096 L .4417 .56757 L F
.723 .676 .803 r
.24129 .54473 m .23842 .5452 L .2407 .54182 L F
0 .347 .817 r
.2407 .54182 m .24471 .54502 L .24129 .54473 L F
0 0 0 r
.24471 .54502 m .24113 .54813 L .24129 .54473 L F
.589 .592 .823 r
.6142 .3634 m .61704 .36558 L .61805 .36409 L F
.64 .613 .806 r
.6164 .35996 m .61805 .36409 L .62095 .36361 L F
.531 .056 .072 r
.61805 .36409 m .62072 .36474 L .62095 .36361 L F
.61805 .36409 m .61704 .36558 L .62072 .36474 L F
.162 0 .306 r
.32608 .63916 m .32416 .64318 L .32686 .64235 L F
0 0 .445 r
.32608 .63916 m .32686 .64235 L .32727 .64094 L F
.713 .852 .948 r
.30278 .52868 m .29921 .52875 L .30211 .52796 L F
.656 .211 .182 r
.30278 .52868 m .30049 .53017 L .29921 .52875 L F
.331 .663 .973 r
.30211 .52796 m .30407 .52776 L .30278 .52868 L F
.419 .821 .61 r
.30407 .52776 m .30049 .53017 L .30278 .52868 L F
.83 .928 .897 r
.53523 .40293 m .53011 .40715 L .53088 .4047 L F
.965 .648 .36 r
.59348 .43328 m .59502 .43212 L .59315 .43101 L F
.59348 .43328 m .59537 .43464 L .59502 .43212 L F
.473 .889 .787 r
.34562 .65439 m .34998 .65252 L .34851 .65188 L F
0 0 0 r
.33565 .57268 m .33299 .57472 L .33428 .57412 L F
.707 .608 .038 r
.33299 .57472 m .33294 .57558 L .33428 .57412 L F
.33299 .57472 m .33284 .57742 L .33294 .57558 L F
.626 .948 .753 r
.34998 .65252 m .35309 .65007 L .35085 .65119 L F
.47 .839 .991 r
.34851 .65188 m .34998 .65252 L .35085 .65119 L F
.737 .643 .756 r
.34305 .60005 m .34579 .60089 L .34182 .60062 L F
.653 .471 .626 r
.34494 .60316 m .34182 .60062 L .34579 .60089 L F
.146 .033 .456 r
.23664 .53855 m .23661 .54126 L .2352 .54206 L F
.652 .572 .752 r
.23842 .5452 m .2352 .54206 L .23661 .54126 L F
0 0 .221 r
.2211 .56806 m .22139 .57036 L .22194 .56593 L F
.83 .479 .39 r
.70066 .2937 m .70365 .29269 L .70084 .2918 L F
.70066 .2937 m .7039 .29468 L .70365 .29269 L F
.55 .314 .511 r
.7039 .29468 m .70614 .29131 L .70365 .29269 L F
.838 .698 .708 r
.33995 .62574 m .33929 .62344 L .33767 .62565 L F
.33995 .62574 m .33767 .62565 L .34044 .62447 L F
.045 .364 .835 r
.33995 .62574 m .34435 .62945 L .34178 .62871 L F
0 0 .524 r
.34044 .62447 m .33995 .62574 L .34178 .62871 L F
.621 .568 .773 r
.46552 .48879 m .47001 .49029 L .46838 .48621 L F
.593 .446 .65 r
.46717 .49369 m .47001 .49029 L .46552 .48879 L F
.69 .551 .692 r
.46214 .49255 m .46717 .49369 L .46552 .48879 L F
.719 .584 .702 r
.46016 .49626 m .46214 .49255 L .46118 .49412 L F
.691 .548 .686 r
.46759 .4967 m .46717 .49369 L .46214 .49255 L F
.733 .782 .892 r
.26322 .62956 m .26733 .62982 L .26511 .62777 L F
.83 .531 .483 r
.26863 .62953 m .26511 .62777 L .26733 .62982 L F
.186 .266 .714 r
.26733 .62982 m .26968 .63187 L .26863 .62953 L F
.652 .127 0 r
.26733 .62982 m .27093 .63323 L .26968 .63187 L F
.299 .647 .968 r
.4345 .59449 m .43559 .59597 L .43815 .59613 L F
.777 .981 .908 r
.34347 .62078 m .33867 .61999 L .34155 .62014 L F
.34347 .62078 m .33929 .62344 L .33867 .61999 L F
.66 .923 .975 r
.34536 .61955 m .34347 .62078 L .34155 .62014 L F
.475 .638 .927 r
.55389 .40988 m .54991 .41177 L .55322 .41197 L F
.55389 .40988 m .55256 .40803 L .54991 .41177 L F
.251 0 .011 r
.55526 .41091 m .55389 .40988 L .55322 .41197 L F
.55526 .41091 m .55703 .4084 L .55389 .40988 L F
.912 .85 .769 r
.43899 .46765 m .43722 .46413 L .43751 .46542 L F
.303 .364 .76 r
.22303 .58103 m .22347 .5768 L .22147 .5772 L F
.22303 .58103 m .22501 .58114 L .22347 .5768 L F
.3 .375 .773 r
.22303 .58103 m .22533 .58295 L .22501 .58114 L F
.882 .449 .094 r
.36751 .51474 m .37058 .51884 L .36966 .51701 L F
.943 .888 .747 r
.38899 .60594 m .3922 .60351 L .39099 .60253 L F
.38899 .60594 m .39049 .60698 L .3922 .60351 L F
.636 .306 .396 r
.55939 .44326 m .5611 .44137 L .55691 .4418 L F
.744 .563 .648 r
.55939 .44326 m .56356 .44141 L .5611 .44137 L F
.059 0 0 r
.68059 .37535 m .68029 .37519 L .68331 .37469 L F
.096 0 .226 r
.38177 .48729 m .38118 .48971 L .38338 .48647 L F
.978 .772 .356 r
.41049 .57787 m .40957 .57958 L .40955 .57694 L F
.41049 .57787 m .41034 .58046 L .40957 .57958 L F
.894 .739 .682 r
.57662 .42492 m .57803 .42884 L .57602 .42756 L F
.902 .985 .735 r
.57803 .42884 m .5749 .43209 L .57602 .42756 L F
.625 .608 .813 r
.58017 .4272 m .57803 .42884 L .57662 .42492 L F
.752 .718 .82 r
.2407 .54182 m .23842 .5452 L .23661 .54126 L F
.478 .141 .316 r
.33758 .50377 m .33975 .50494 L .337 .50582 L F
.33758 .50377 m .34022 .5034 L .33975 .50494 L F
.977 .748 .524 r
.44375 .51238 m .44511 .51459 L .44752 .51486 L F
.44375 .51238 m .4435 .5151 L .44511 .51459 L F
.612 .956 .869 r
.34334 .60439 m .34147 .60505 L .34494 .60316 L F
.903 .687 .6 r
.5905 .42682 m .59384 .4255 L .59146 .42311 L F
.5905 .42682 m .59339 .42815 L .59384 .4255 L F
0 0 .331 r
.56311 .45156 m .56406 .45225 L .56499 .45052 L F
.56311 .45156 m .56331 .45436 L .56406 .45225 L F
.433 .227 .499 r
.5011 .50976 m .50106 .5124 L .49854 .51305 L F
.299 .083 .408 r
.50106 .5124 m .49865 .51574 L .49854 .51305 L F
.587 .789 .976 r
.5668 .38181 m .5681 .38342 L .56406 .38269 L F
.375 .657 .967 r
.56913 .3817 m .5681 .38342 L .5668 .38181 L F
.56913 .3817 m .57043 .3834 L .5681 .38342 L F
.412 .607 .928 r
.57228 .38561 m .5681 .38342 L .57043 .3834 L F
.663 .682 .858 r
.35577 .63838 m .3578 .64278 L .35496 .64342 L F
.005 0 .099 r
.35421 .61622 m .35529 .61386 L .357 .61271 L F
0 0 0 r
.45423 .50461 m .45287 .50654 L .45553 .50301 L F
.862 .793 .782 r
.44464 .50467 m .4486 .50285 L .4477 .50294 L F
.44464 .50467 m .44624 .50649 L .4486 .50285 L F
.415 .864 .87 r
.45146 .50181 m .45025 .50173 L .4486 .50285 L F
.418 .861 .782 r
.4486 .50285 m .45025 .50173 L .4477 .50294 L F
.465 .217 .452 r
.50926 .50025 m .50903 .50299 L .50628 .50337 L F
.398 .162 .436 r
.51149 .50206 m .50926 .50025 L .51168 .4995 L F
.51149 .50206 m .50903 .50299 L .50926 .50025 L F
.957 .694 .495 r
.34417 .64553 m .34594 .6494 L .34375 .64816 L F
.851 .987 .854 r
.34594 .6494 m .34227 .6517 L .34375 .64816 L F
.34594 .6494 m .34192 .6528 L .34227 .6517 L F
.6 .639 .861 r
.242 .59388 m .24309 .59531 L .24499 .59451 L F
.969 .913 .698 r
.34689 .50647 m .34443 .50842 L .34419 .50552 L F
.767 .745 .833 r
.37628 .62007 m .37363 .62071 L .37504 .61892 L F
.88 .862 .818 r
.37818 .61628 m .37628 .62007 L .37504 .61892 L F
.168 0 .346 r
.35789 .53497 m .36038 .53424 L .36014 .53204 L F
.767 .479 .498 r
.35789 .53497 m .36156 .53852 L .36038 .53424 L F
.35789 .53497 m .35738 .5383 L .36156 .53852 L F
.561 .812 .436 r
.36444 .62142 m .36583 .61963 L .36552 .62242 L F
.311 .089 .406 r
.36552 .62242 m .36583 .61963 L .36775 .6192 L F
.901 .899 .815 r
.36552 .62242 m .36636 .61751 L .36543 .62084 L F
.36552 .62242 m .36775 .6192 L .36636 .61751 L F
0 .029 .6 r
.36543 .62084 m .36671 .62351 L .36552 .62242 L F
.36671 .62351 m .36714 .62442 L .36552 .62242 L F
.561 .812 .436 r
.3634 .62275 m .36444 .62142 L .36552 .62242 L F
.176 0 .233 r
.36287 .62549 m .3634 .62275 L .36552 .62242 L F
.357 .23 .567 r
.47156 .52951 m .47392 .53144 L .47364 .5286 L F
.175 .231 .682 r
.47268 .53253 m .47392 .53144 L .47156 .52951 L F
.787 .699 .767 r
.39144 .47304 m .38723 .47762 L .39274 .47743 L F
.86 .736 .724 r
.39144 .47304 m .39274 .47743 L .39309 .47507 L F
.459 .374 .673 r
.39274 .47743 m .39341 .48062 L .39569 .47962 L F
.015 0 .414 r
.71041 .31205 m .71271 .30994 L .71386 .31027 L F
0 0 0 r
.71386 .31027 m .71612 .30977 L .7169 .30816 L F
.187 .718 .832 r
.71271 .30994 m .71612 .30977 L .71386 .31027 L F
.543 .882 .988 r
.62829 .33895 m .63062 .33808 L .63305 .33894 L F
.663 .922 .975 r
.63305 .33894 m .63414 .33673 L .63519 .33729 L F
.63305 .33894 m .63062 .33808 L .63414 .33673 L F
.06 .604 .844 r
.60244 .3541 m .60062 .35358 L .5983 .35335 L F
.243 .226 .64 r
.60304 .35483 m .60715 .35435 L .60622 .35132 L F
.60304 .35483 m .60622 .35132 L .6039 .35405 L F
0 .196 .726 r
.60244 .3541 m .6039 .35405 L .60062 .35358 L F
.60244 .3541 m .60304 .35483 L .6039 .35405 L F
.244 0 0 r
.43437 .49783 m .43674 .49804 L .43674 .4971 L F
.43437 .49783 m .4331 .49941 L .43674 .49804 L F
.62 .391 .548 r
.41865 .50871 m .41637 .50663 L .4186 .50577 L F
.41865 .50871 m .41609 .5099 L .41637 .50663 L F
.544 .17 .281 r
.28545 .53529 m .29017 .53247 L .28728 .53569 L F
.515 .309 .538 r
.29017 .53247 m .28986 .53539 L .28728 .53569 L F
.302 0 .137 r
.29017 .53247 m .2916 .53381 L .28986 .53539 L F
.29017 .53247 m .28851 .53511 L .29082 .53471 L F
.557 .045 0 r
.28986 .53539 m .28713 .53533 L .28728 .53569 L F
.28713 .53533 m .28545 .53529 L .28627 .53547 L F
.28713 .53533 m .28627 .53547 L .28728 .53569 L F
.28986 .53539 m .28776 .53671 L .28545 .53529 L F
.302 0 .137 r
.28851 .53511 m .28814 .53571 L .29067 .53476 L F
.28851 .53511 m .29067 .53476 L .29082 .53471 L F
.482 .686 .957 r
.33964 .57494 m .33565 .57268 L .33788 .5716 L F
.371 .793 .974 r
.3416 .57393 m .33964 .57494 L .33788 .5716 L F
.3416 .57393 m .34251 .57466 L .33964 .57494 L F
.474 .11 .267 r
.33964 .57494 m .34158 .5768 L .34251 .57466 L F
.33964 .57494 m .34158 .5768 L .34251 .57466 L F
0 .432 .783 r
.72705 .32652 m .73086 .3283 L .72951 .3273 L F
.516 .908 .93 r
.73086 .3283 m .73187 .3265 L .72951 .3273 L F
.73086 .3283 m .7349 .3263 L .73187 .3265 L F
.647 .68 .868 r
.73086 .3283 m .73482 .32791 L .7349 .3263 L F
.523 .478 .748 r
.34239 .61767 m .34536 .61955 L .34368 .61907 L F
.34239 .61767 m .34368 .61907 L .34352 .61696 L F
0 0 0 r
.68726 .37269 m .68941 .37235 L .68647 .37308 L F
.68726 .37269 m .69008 .37177 L .68941 .37235 L F
.461 .232 .479 r
.51405 .49652 m .51168 .4995 L .51167 .49696 L F
.65 .689 .873 r
.23253 .60963 m .23308 .60589 L .23064 .60679 L F
.23253 .60963 m .23411 .60925 L .23308 .60589 L F
.546 .151 .244 r
.43568 .52499 m .43873 .52511 L .43978 .52269 L F
.296 0 .093 r
.43873 .52511 m .44238 .52222 L .43978 .52269 L F
.614 .926 .685 r
.61554 .4344 m .61895 .43184 L .61714 .43277 L F
0 0 0 r
.62224 .42913 m .62064 .43048 L .61895 .43184 L F
.65208 .38117 m .64889 .38297 L .65141 .38138 L F
.65141 .38138 m .64889 .38297 L .65091 .38184 L F
.65091 .38184 m .64889 .38297 L .64818 .38494 L F
.64 .486 .658 r
.2692 .57776 m .27145 .57492 L .26966 .57525 L F
.688 .592 .743 r
.43092 .50213 m .4289 .50615 L .42834 .50318 L F
.491 .12 .263 r
.42738 .50475 m .43092 .50213 L .42834 .50318 L F
.522 .037 .046 r
.33383 .58615 m .33841 .5844 L .33451 .58448 L F
.33383 .58615 m .33663 .58611 L .33841 .5844 L F
.583 .302 .456 r
.33673 .59369 m .33947 .5936 L .33983 .59088 L F
.33983 .59088 m .33947 .5936 L .33673 .59369 L F
.566 .499 .739 r
.33765 .58102 m .33841 .5844 L .33902 .58121 L F
.33765 .58102 m .33902 .58121 L .33836 .58147 L F
.57 .607 .851 r
.33905 .57796 m .33836 .58147 L .33905 .58123 L F
.399 .169 .446 r
.33902 .58121 m .34254 .58285 L .34282 .57991 L F
.306 .032 .323 r
.33902 .58121 m .33897 .58537 L .34098 .58448 L F
.399 .169 .446 r
.33902 .58121 m .34282 .57991 L .33836 .58147 L F
.57 .607 .851 r
.33978 .57834 m .33905 .58123 L .34282 .57991 L F
.33905 .57796 m .33905 .58123 L .33978 .57834 L F
.058 0 0 r
.33841 .5844 m .33897 .58537 L .33901 .58136 L F
.33891 .58176 m .33901 .58136 L .33902 .58121 L F
.33841 .5844 m .33901 .58136 L .33891 .58176 L F
.33841 .5844 m .33663 .58611 L .33897 .58537 L F
.564 .286 .452 r
.33983 .59088 m .33947 .5936 L .34172 .59313 L F
.34172 .59313 m .33947 .5936 L .33983 .59088 L F
.123 0 .41 r
.48318 .55434 m .48306 .55698 L .48078 .55833 L F
.113 .008 .445 r
.48296 .55976 m .48078 .55833 L .48306 .55698 L F
.48296 .55976 m .48079 .5611 L .48078 .55833 L F
.502 .907 .901 r
.4184 .46743 m .41791 .46855 L .42048 .46765 L F
.4184 .46743 m .4159 .46856 L .41791 .46855 L F
.769 .269 0 r
.35872 .50651 m .35513 .50287 L .35696 .5054 L F
.754 .28 0 r
.35696 .5054 m .35934 .50847 L .35872 .50651 L F
.628 .489 .674 r
.32675 .5216 m .32443 .52002 L .3267 .51893 L F
.32675 .5216 m .32471 .52268 L .32443 .52002 L F
.522 .419 .679 r
.32471 .52268 m .3267 .51893 L .32443 .52002 L F
.793 .877 .909 r
.61755 .37995 m .61876 .38161 L .62117 .37981 L F
.912 .85 .769 r
.43899 .46765 m .43837 .46257 L .43722 .46413 L F
.43899 .46765 m .43666 .46665 L .43837 .46257 L F
.588 .181 .24 r
.43899 .46765 m .43762 .46942 L .43666 .46665 L F
.43899 .46765 m .4398 .46988 L .43762 .46942 L F
.43762 .46942 m .4398 .46988 L .43899 .46765 L F
.291 .149 .509 r
.47156 .54253 m .47355 .54151 L .47341 .53857 L F
.048 0 .051 r
.47232 .54351 m .47156 .54253 L .47097 .54498 L F
.47232 .54351 m .47355 .54151 L .47156 .54253 L F
.45 .338 .635 r
.32964 .51266 m .33178 .51223 L .33212 .50741 L F
.382 .097 .351 r
.32964 .51266 m .33246 .51375 L .33178 .51223 L F
.32964 .51266 m .32873 .51534 L .33246 .51375 L F
.976 .839 .643 r
.7027 .27913 m .70343 .27641 L .70237 .27416 L F
.594 .831 .453 r
.45216 .58159 m .45367 .57958 L .45511 .57777 L F
.395 .308 .639 r
.45379 .57411 m .45439 .57461 L .45597 .57354 L F
.45439 .57461 m .4566 .57644 L .45597 .57354 L F
.898 .595 .094 r
.45597 .57354 m .4566 .57644 L .45528 .57548 L F
.13 .285 .755 r
.45511 .57777 m .4566 .57644 L .45439 .57461 L F
.309 .036 .327 r
.45491 .5758 m .45552 .5762 L .45515 .57508 L F
.898 .595 .094 r
.45522 .57532 m .45528 .57548 L .45518 .57541 L F
.45597 .57354 m .45528 .57548 L .45522 .57532 L F
.45597 .57354 m .45578 .57397 L .45746 .57252 L F
.528 .808 .997 r
.45726 .57734 m .4592 .57454 L .45726 .57396 L F
.898 .595 .094 r
.45578 .57397 m .45541 .57488 L .45678 .57352 L F
.45541 .57488 m .45575 .57471 L .45678 .57352 L F
.45578 .57397 m .45678 .57352 L .45807 .57199 L F
0 0 0 r
.45912 .57115 m .45807 .57199 L .45579 .57469 L F
.309 .036 .327 r
.4553 .57525 m .45538 .57517 L .45568 .57348 L F
.45538 .57517 m .45611 .57453 L .45607 .57445 L F
0 0 0 r
.45607 .57445 m .45579 .57469 L .45538 .57517 L F
.45607 .57445 m .45538 .57517 L .45603 .5745 L F
.898 .595 .094 r
.45541 .57488 m .45522 .57532 L .45575 .57471 L F
.45522 .57532 m .45538 .57517 L .45678 .57352 L F
.309 .036 .327 r
.45538 .57517 m .45603 .5745 L .45568 .57348 L F
.45603 .5745 m .45607 .57444 L .45568 .57348 L F
0 0 0 r
.45603 .5745 m .45538 .57517 L .45518 .57541 L F
.45511 .57777 m .45367 .57958 L .4566 .57644 L F
0 0 .018 r
.4566 .57644 m .45367 .57958 L .45538 .57864 L F
0 0 0 r
.4566 .57644 m .45538 .57864 L .45726 .57734 L F
.4566 .57644 m .45726 .57734 L .45528 .57548 L F
.309 .036 .327 r
.45528 .57548 m .45726 .57734 L .45515 .57508 L F
.45552 .5762 m .45726 .57734 L .45528 .57548 L F
.13 .285 .755 r
.45511 .57777 m .45439 .57461 L .45403 .57478 L F
.309 .036 .327 r
.45491 .5758 m .45518 .57541 L .45726 .57734 L F
0 0 0 r
.45422 .57714 m .45491 .5758 L .45537 .57563 L F
.45529 .57549 m .45726 .57734 L .45531 .57553 L F
.528 .808 .997 r
.45726 .57734 m .45726 .57396 L .45611 .57453 L F
.309 .036 .327 r
.4553 .57525 m .45726 .57734 L .45611 .57453 L F
0 0 0 r
.45561 .5761 m .45537 .57563 L .457 .57506 L F
.45422 .57714 m .45537 .57563 L .45561 .5761 L F
.45528 .57548 m .45529 .57549 L .45518 .57541 L F
.45529 .57549 m .45531 .57553 L .45518 .57541 L F
.528 .808 .997 r
.45607 .57444 m .45622 .57412 L .45568 .57348 L F
.898 .595 .094 r
.45597 .57354 m .45746 .57252 L .45807 .57199 L F
.346 .165 .488 r
.45379 .57411 m .45597 .57354 L .45592 .57068 L F
.275 .229 .624 r
.45807 .57199 m .45592 .57068 L .45597 .57354 L F
.45807 .57199 m .45835 .56917 L .45592 .57068 L F
0 0 .391 r
.45912 .57115 m .45835 .56917 L .45807 .57199 L F
.771 .963 .661 r
.45852 .57123 m .45622 .57412 L .45568 .57348 L F
.528 .808 .997 r
.45622 .57412 m .4564 .5737 L .45568 .57348 L F
.898 .595 .094 r
.45522 .57532 m .45518 .57541 L .45538 .57517 L F
.771 .963 .661 r
.45622 .57412 m .45518 .57541 L .45568 .57348 L F
.4571 .57316 m .45603 .5745 L .45518 .57541 L F
.45878 .5712 m .45721 .57308 L .4571 .57316 L F
.45721 .57308 m .45603 .5745 L .4571 .57316 L F
.45852 .57123 m .45878 .5712 L .45614 .57429 L F
.45852 .57123 m .45614 .57429 L .45622 .57412 L F
0 0 0 r
.45912 .57115 m .45579 .57469 L .45607 .57445 L F
.771 .963 .661 r
.45878 .5712 m .45912 .57115 L .45603 .5745 L F
.528 .808 .997 r
.45611 .57453 m .45726 .57396 L .45681 .57382 L F
0 0 .285 r
.457 .57506 m .45607 .57395 L .4592 .57454 L F
.45607 .57395 m .45568 .57348 L .4564 .5737 L F
.528 .808 .997 r
.45607 .57445 m .45681 .57382 L .4564 .5737 L F
0 0 .285 r
.45607 .57395 m .4564 .5737 L .4592 .57454 L F
.528 .808 .997 r
.45607 .57445 m .4564 .5737 L .45607 .57444 L F
.771 .963 .661 r
.45622 .57412 m .45614 .57429 L .45518 .57541 L F
.309 .036 .327 r
.45603 .5745 m .45607 .57445 L .45607 .57444 L F
.528 .808 .997 r
.45611 .57453 m .45681 .57382 L .45607 .57445 L F
.309 .036 .327 r
.45515 .57508 m .4553 .57525 L .45568 .57348 L F
.13 .285 .755 r
.45403 .57478 m .45439 .57461 L .45379 .57411 L F
.536 .208 .36 r
.28884 .54215 m .29077 .54388 L .29207 .54212 L F
.807 .749 .798 r
.56052 .41474 m .56139 .41931 L .55791 .41806 L F
.487 .092 .216 r
.56052 .41474 m .56016 .4157 L .56002 .41555 L F
.73 .44 .487 r
.56137 .41337 m .56453 .41536 L .56052 .41474 L F
.764 .722 .813 r
.56453 .41536 m .56139 .41931 L .56052 .41474 L F
.135 .082 .527 r
.56022 .41559 m .56221 .41596 L .56175 .41275 L F
.55928 .41674 m .56079 .41634 L .56002 .41555 L F
.56079 .41634 m .56221 .41596 L .56002 .41555 L F
.726 .62 .739 r
.55928 .41674 m .55791 .41806 L .56052 .41474 L F
0 0 0 r
.55636 .4175 m .55928 .41674 L .55791 .41806 L F
.55928 .41674 m .55837 .41707 L .55968 .41667 L F
.135 .082 .527 r
.55928 .41674 m .56002 .41555 L .56052 .41474 L F
.487 .092 .216 r
.56052 .41474 m .55924 .4168 L .55636 .4175 L F
.55924 .4168 m .55896 .41727 L .55718 .41743 L F
.55837 .41707 m .55718 .41743 L .55636 .4175 L F
.617 .643 .854 r
.55636 .4175 m .5596 .41721 L .55941 .41688 L F
0 0 0 r
.55636 .4175 m .55822 .41712 L .55837 .41707 L F
.55636 .4175 m .55837 .41707 L .55928 .41674 L F
.487 .092 .216 r
.55924 .4168 m .55837 .41707 L .55636 .4175 L F
.617 .643 .854 r
.55822 .41712 m .55941 .41688 L .55935 .41679 L F
.135 .082 .527 r
.56002 .41555 m .56006 .41548 L .56052 .41474 L F
0 0 0 r
.56175 .41275 m .56016 .4157 L .56052 .41474 L F
.135 .082 .527 r
.56006 .41548 m .56175 .41275 L .56052 .41474 L F
.73 .44 .487 r
.56091 .41308 m .56137 .41337 L .56052 .41474 L F
.752 .615 .707 r
.55798 .41547 m .56052 .41474 L .55624 .41458 L F
.727 .299 .231 r
.55419 .41383 m .55641 .41479 L .55624 .41458 L F
.55641 .41479 m .55798 .41547 L .55624 .41458 L F
.536 .531 .796 r
.55087 .41394 m .55419 .41383 L .55322 .41197 L F
.971 .69 .281 r
.55624 .41458 m .55499 .41307 L .55247 .41368 L F
.55624 .41458 m .55636 .4175 L .55499 .41308 L F
.55624 .41458 m .55499 .41308 L .55499 .41307 L F
.487 .092 .216 r
.56052 .41474 m .55636 .4175 L .55624 .41458 L F
.799 .714 .771 r
.55791 .4143 m .55935 .41679 L .56175 .41275 L F
0 0 0 r
.55988 .41663 m .5596 .41721 L .55981 .41663 L F
.487 .092 .216 r
.55924 .4168 m .5596 .41721 L .55896 .41727 L F
0 0 0 r
.55928 .41674 m .55968 .41667 L .55965 .41664 L F
.55968 .41667 m .55981 .41663 L .55965 .41664 L F
.487 .092 .216 r
.56002 .41555 m .55974 .41665 L .55924 .4168 L F
.55974 .41665 m .5596 .41721 L .55924 .4168 L F
0 0 0 r
.55968 .41667 m .55998 .41662 L .55981 .41663 L F
.799 .714 .771 r
.55935 .41679 m .5596 .41721 L .55988 .41663 L F
0 0 0 r
.55968 .41667 m .55935 .41679 L .5598 .41665 L F
.56175 .41275 m .55988 .41663 L .56016 .4157 L F
.55988 .41663 m .55981 .41663 L .56016 .4157 L F
.135 .082 .527 r
.56002 .41555 m .56022 .41559 L .56175 .41275 L F
.487 .092 .216 r
.56016 .4157 m .5596 .41721 L .56002 .41555 L F
.799 .714 .771 r
.55935 .41679 m .55988 .41663 L .56175 .41275 L F
0 0 0 r
.55968 .41667 m .55883 .41694 L .55935 .41679 L F
.5598 .41665 m .55935 .41679 L .55985 .41664 L F
.55985 .41664 m .55783 .41726 L .55998 .41662 L F
.55883 .41694 m .55783 .41726 L .55985 .41664 L F
.617 .643 .854 r
.55636 .4175 m .55822 .41712 L .55791 .4143 L F
0 0 0 r
.55837 .41707 m .55783 .41726 L .55968 .41667 L F
.617 .643 .854 r
.55822 .41712 m .55935 .41679 L .55791 .4143 L F
0 0 0 r
.55636 .4175 m .55783 .41726 L .55822 .41712 L F
.55965 .41664 m .55998 .41662 L .56221 .41596 L F
.696 .51 .632 r
.46517 .50333 m .4653 .49953 L .46208 .50015 L F
.596 .496 .71 r
.46517 .50333 m .4673 .49928 L .4653 .49953 L F
.57 .511 .75 r
.44244 .49342 m .44445 .48868 L .44479 .49025 L F
.665 .681 .855 r
.55438 .44147 m .55691 .4418 L .55568 .4379 L F
.706 .426 .497 r
.55701 .44403 m .55691 .4418 L .55438 .44147 L F
.636 .306 .396 r
.55939 .44326 m .55691 .4418 L .55701 .44403 L F
.53 .873 .99 r
.41766 .45564 m .41982 .45487 L .42168 .45544 L F
.489 .862 .984 r
.4197 .45459 m .42168 .45544 L .41982 .45487 L F
.4197 .45459 m .42452 .45471 L .42168 .45544 L F
0 0 0 r
.67352 .30896 m .67083 .31222 L .67249 .31023 L F
.652 .964 .795 r
.67083 .31222 m .66927 .31255 L .67249 .31023 L F
.819 .52 .483 r
.55282 .44342 m .55438 .44147 L .55233 .44154 L F
.665 .681 .855 r
.55438 .44147 m .55568 .4379 L .55233 .44154 L F
.706 .426 .497 r
.55701 .44403 m .55438 .44147 L .55282 .44342 L F
.73 .737 .857 r
.35446 .68858 m .35533 .68406 L .35285 .68454 L F
.35446 .68858 m .35649 .68724 L .35533 .68406 L F
.511 .853 .995 r
.27093 .63323 m .27206 .63166 L .26968 .63187 L F
.27093 .63323 m .27374 .63247 L .27206 .63166 L F
.494 .208 .409 r
.56139 .41931 m .55951 .42197 L .55791 .41806 L F
.56139 .41931 m .56194 .42125 L .55951 .42197 L F
.313 0 0 r
.5338 .39627 m .52974 .39828 L .53238 .39489 L F
.5338 .39627 m .53261 .39788 L .52974 .39828 L F
.02 0 0 r
.535 .39686 m .5338 .39627 L .53238 .39489 L F
.535 .39686 m .53261 .39788 L .5338 .39627 L F
.745 .886 .944 r
.50718 .41546 m .50365 .41559 L .50558 .41395 L F
.806 .852 .884 r
.51025 .41261 m .50718 .41546 L .50558 .41395 L F
.782 .766 .838 r
.38226 .67556 m .3841 .6739 L .38317 .67113 L F
.616 .55 .757 r
.36511 .69131 m .3677 .69066 L .36664 .687 L F
.544 .553 .814 r
.36511 .69131 m .36918 .69423 L .3677 .69066 L F
.641 .434 .588 r
.23119 .56663 m .2269 .56881 L .22901 .56516 L F
.951 .883 .482 r
.23153 .56417 m .23119 .56663 L .22901 .56516 L F
.703 .652 .795 r
.23119 .56663 m .23153 .56417 L .22901 .56516 L F
.368 .062 .309 r
.54442 .45022 m .54505 .44816 L .54752 .44732 L F
.501 .304 .546 r
.6464 .37325 m .6491 .37223 L .64628 .37041 L F
.589 .424 .626 r
.62414 .39297 m .62447 .39569 L .62146 .39632 L F
.224 0 0 r
.62146 .39632 m .6233 .39673 L .62149 .39874 L F
.62146 .39632 m .62447 .39569 L .6233 .39673 L F
.821 .36 .126 r
.35934 .50847 m .36101 .51074 L .36263 .50981 L F
.738 .237 .036 r
.36101 .51074 m .36484 .51214 L .36263 .50981 L F
.735 .219 0 r
.36263 .50981 m .36484 .51214 L .36699 .51256 L F
.534 .526 .792 r
.33975 .50494 m .33961 .51125 L .337 .50582 L F
.992 .739 .402 r
.403 .53899 m .40175 .54038 L .40124 .53786 L F
.403 .53899 m .403 .54169 L .40175 .54038 L F
.544 .17 .281 r
.28545 .53529 m .28814 .53571 L .29017 .53247 L F
.302 0 .137 r
.29017 .53247 m .29082 .53471 L .2916 .53381 L F
.906 .815 .747 r
.46016 .49626 m .45922 .4927 L .45824 .49508 L F
.953 .842 .695 r
.45698 .4986 m .46016 .49626 L .45824 .49508 L F
.45698 .4986 m .45863 .49971 L .46016 .49626 L F
.783 .604 .657 r
.45863 .49971 m .46208 .50015 L .46016 .49626 L F
.848 .789 .794 r
.46016 .49626 m .46118 .49412 L .45922 .4927 L F
.011 0 0 r
.67885 .32135 m .67511 .32306 L .67628 .32219 L F
.423 .786 .995 r
.5793 .45417 m .584 .45238 L .57815 .45279 L F
.5793 .45417 m .58392 .45408 L .584 .45238 L F
.463 .744 .99 r
.5793 .45417 m .58357 .45484 L .58392 .45408 L F
.228 .298 .728 r
.51611 .43209 m .51685 .43045 L .51888 .42995 L F
.937 .863 .74 r
.51888 .42995 m .51685 .43045 L .51777 .43078 L F
.898 .858 .793 r
.5165 .43365 m .52049 .43176 L .51777 .43078 L F
.51672 .43159 m .51777 .43078 L .51685 .43045 L F
.228 .298 .728 r
.51611 .43209 m .51888 .42995 L .51688 .43146 L F
.51685 .43045 m .51672 .43159 L .51611 .43209 L F
.51611 .43209 m .5165 .43365 L .51685 .43045 L F
.51611 .43209 m .51688 .43146 L .51673 .43158 L F
.51672 .43159 m .5165 .43365 L .51611 .43209 L F
.898 .858 .793 r
.5165 .43365 m .51777 .43078 L .51672 .43159 L F
.228 .298 .728 r
.51673 .43158 m .51777 .43078 L .51774 .43074 L F
.51777 .43078 m .51888 .42995 L .51875 .43004 L F
.51777 .43078 m .51875 .43004 L .51774 .43074 L F
.937 .863 .74 r
.51888 .42995 m .51777 .43078 L .52049 .43176 L F
.898 .858 .793 r
.5165 .43365 m .5183 .43498 L .52049 .43176 L F
.789 .911 .924 r
.52049 .43176 m .52216 .42788 L .51888 .42995 L F
.52049 .43176 m .52388 .42898 L .52216 .42788 L F
.897 .478 .147 r
.59084 .41482 m .59061 .4136 L .58797 .41138 L F
.639 .673 .867 r
.53948 .43881 m .5433 .44079 L .54216 .43806 L F
.472 .535 .841 r
.5433 .44079 m .545 .43792 L .54216 .43806 L F
.5433 .44079 m .54644 .44021 L .545 .43792 L F
.34 0 .205 r
.5433 .44079 m .54504 .44292 L .54644 .44021 L F
.54317 .44126 m .54253 .44354 L .54504 .44292 L F
0 0 0 r
.54504 .44292 m .54253 .44354 L .54086 .4445 L F
.54504 .44292 m .54086 .4445 L .54322 .44314 L F
.535 0 0 r
.5464 .44411 m .54504 .44292 L .54322 .44314 L F
.54718 .44435 m .54504 .44292 L .5464 .44411 L F
.34 0 .205 r
.5433 .44079 m .54317 .44126 L .54504 .44292 L F
.51 0 0 r
.32425 .55765 m .32841 .55949 L .32796 .55862 L F
.242 0 .256 r
.55723 .46059 m .55736 .45828 L .55469 .46112 L F
.351 .032 .276 r
.55893 .45848 m .55736 .45828 L .55723 .46059 L F
0 0 .23 r
.55965 .45978 m .55893 .45848 L .55846 .46225 L F
0 0 0 r
.56331 .45436 m .56027 .4578 L .56257 .45654 L F
.382 .823 .685 r
.56257 .45654 m .56027 .4578 L .55893 .45848 L F
.497 .904 .815 r
.5611 .45674 m .56257 .45654 L .55893 .45848 L F
0 0 .23 r
.5611 .45674 m .55893 .45848 L .55965 .45978 L F
.32 0 .01 r
.55893 .45848 m .56027 .4578 L .5587 .45806 L F
.55893 .45848 m .5587 .45806 L .55736 .45828 L F
.973 .802 .611 r
.59172 .41865 m .59084 .41482 L .59039 .41686 L F
.978 .779 .566 r
.58948 .42096 m .59172 .41865 L .59039 .41686 L F
.58948 .42096 m .59107 .42217 L .59172 .41865 L F
.824 .346 .01 r
.35094 .50151 m .35103 .49957 L .3488 .49934 L F
.35094 .50151 m .35286 .50241 L .35103 .49957 L F
.79 .855 .899 r
.32597 .54557 m .32993 .54555 L .32817 .54404 L F
.32597 .54557 m .32527 .54772 L .32993 .54555 L F
0 0 .049 r
.32714 .64139 m .32652 .64516 L .32727 .64094 L F
.32686 .64235 m .32662 .64432 L .32714 .64139 L F
.32662 .64432 m .32652 .64516 L .32714 .64139 L F
.767 .493 .52 r
.32416 .64318 m .3265 .64505 L .32451 .64581 L F
.3265 .64505 m .32722 .64563 L .32638 .64569 L F
.3265 .64505 m .32638 .64569 L .32451 .64581 L F
.358 .006 .224 r
.33982 .65314 m .33657 .65597 L .3391 .65514 L F
.389 0 .153 r
.34154 .65439 m .33982 .65314 L .3391 .65514 L F
.34154 .65439 m .34192 .6528 L .33982 .65314 L F
0 0 0 r
.6833 .35425 m .67926 .35602 L .68218 .35286 L F
.889 .543 .386 r
.36484 .51214 m .36751 .51474 L .36699 .51256 L F
.942 .588 .311 r
.60188 .4153 m .6042 .41876 L .60234 .41762 L F
.932 .554 .188 r
.6042 .41876 m .60401 .42148 L .60234 .41762 L F
.6042 .41876 m .60489 .42187 L .60401 .42148 L F
.783 .609 .665 r
.46218 .50304 m .46208 .50015 L .45863 .49971 L F
.696 .51 .632 r
.46517 .50333 m .46208 .50015 L .46218 .50304 L F
.743 .845 .927 r
.42967 .48322 m .43199 .48493 L .43378 .48322 L F
.9 .979 .697 r
.38829 .60861 m .38835 .61066 L .39049 .60698 L F
.889 .876 .44 r
.3875 .61287 m .38835 .61066 L .38829 .60861 L F
.933 .56 .178 r
.40853 .55994 m .40686 .55987 L .40682 .55696 L F
.40853 .55994 m .40843 .56102 L .40686 .55987 L F
.049 0 0 r
.59046 .36541 m .59406 .36542 L .59516 .3652 L F
0 0 0 r
.59574 .36456 m .59516 .3652 L .59406 .36542 L F
.59574 .36456 m .595 .36604 L .59516 .3652 L F
.571 .302 .469 r
.43585 .50298 m .43242 .50615 L .43092 .50213 L F
.43585 .50298 m .43581 .50591 L .43242 .50615 L F
.79 .378 0 r
.39814 .529 m .39714 .52798 L .3961 .52552 L F
.921 .528 .174 r
.39814 .529 m .39739 .53098 L .39714 .52798 L F
.39814 .529 m .39917 .53226 L .39739 .53098 L F
.526 .545 .817 r
.33818 .56814 m .33903 .56385 L .34068 .56477 L F
.33818 .56814 m .34064 .5676 L .33903 .56385 L F
.776 .888 .925 r
.48619 .42821 m .48406 .42977 L .48249 .42851 L F
.181 0 0 r
.282 .54885 m .27967 .54927 L .28332 .5483 L F
.393 .842 .923 r
.28604 .54837 m .282 .54885 L .28332 .5483 L F
.929 .585 .144 r
.59432 .3925 m .59592 .39611 L .59464 .3949 L F
.815 .425 0 r
.59592 .39611 m .59588 .39731 L .59464 .3949 L F
.59592 .39611 m .59695 .39879 L .59588 .39731 L F
.804 .636 .673 r
.42365 .59023 m .42673 .59136 L .42489 .58813 L F
.698 .204 .07 r
.23063 .57374 m .23259 .57585 L .23469 .57471 L F
.214 .002 .36 r
.23613 .57598 m .23469 .57471 L .23745 .57426 L F
.23613 .57598 m .23437 .57715 L .23469 .57471 L F
.624 .836 .982 r
.23259 .57585 m .23745 .57426 L .23469 .57471 L F
.992 .819 .569 r
.60237 .41272 m .60057 .41401 L .60124 .41151 L F
.60237 .41272 m .60188 .4153 L .60057 .41401 L F
.33 .205 .555 r
.55723 .46059 m .55469 .46112 L .55689 .46269 L F
.356 .199 .526 r
.55469 .46112 m .5546 .46392 L .55689 .46269 L F
.733 .953 .655 r
.62351 .42656 m .62224 .42913 L .62502 .42583 L F
.619 .495 .689 r
.62351 .42656 m .62064 .43048 L .62224 .42913 L F
0 0 0 r
.70681 .29686 m .70717 .29529 L .7065 .29439 L F
.474 .726 .98 r
.70717 .29529 m .70924 .29359 L .7065 .29439 L F
.70717 .29529 m .71061 .29535 L .70924 .29359 L F
.776 .498 .516 r
.37112 .62604 m .37509 .6268 L .37185 .62852 L F
.616 .899 .6 r
.37509 .6268 m .37795 .62382 L .37604 .62548 L F
.624 .957 .811 r
.37185 .62852 m .37509 .6268 L .37604 .62548 L F
.599 .668 .888 r
.68228 .34563 m .67773 .34413 L .68051 .34375 L F
.698 .921 .968 r
.68398 .3441 m .68228 .34563 L .68051 .34375 L F
.68398 .3441 m .68473 .34449 L .68228 .34563 L F
.792 .789 .85 r
.44464 .50467 m .44255 .5063 L .44624 .50649 L F
.775 .662 .738 r
.44255 .5063 m .44615 .50935 L .44624 .50649 L F
.651 .461 .613 r
.44615 .50935 m .44998 .50642 L .44624 .50649 L F
.123 .399 .851 r
.27455 .62818 m .27393 .62973 L .27264 .62743 L F
.982 .735 .486 r
.27206 .63166 m .27393 .62973 L .27455 .62818 L F
.27206 .63166 m .27374 .63247 L .27393 .62973 L F
.726 .589 .703 r
.33241 .61977 m .32979 .62262 L .32948 .61994 L F
.461 .082 .234 r
.57219 .41874 m .57114 .42137 L .56856 .42137 L F
.352 0 .188 r
.57452 .4203 m .57219 .41874 L .57463 .41974 L F
.57452 .4203 m .57114 .42137 L .57219 .41874 L F
.806 .926 .915 r
.64414 .34063 m .64323 .34117 L .64573 .34066 L F
.64414 .34063 m .64313 .34378 L .64323 .34117 L F
.695 .952 .682 r
.67352 .30896 m .675 .30674 L .67642 .30591 L F
0 0 0 r
.67352 .30896 m .67447 .30869 L .675 .30674 L F
.67352 .30896 m .67249 .31023 L .67447 .30869 L F
.026 0 .324 r
.48708 .54133 m .48678 .5439 L .48464 .54545 L F
0 0 .283 r
.48678 .5439 m .48464 .54805 L .48464 .54545 L F
.185 0 0 r
.3505 .62506 m .35035 .62512 L .35084 .6265 L F
0 0 .287 r
.35147 .62765 m .35084 .6265 L .35035 .62512 L F
.35147 .62765 m .35186 .62973 L .35084 .6265 L F
.745 .466 .508 r
.41409 .48519 m .41736 .48358 L .41445 .48435 L F
.428 .87 .827 r
.43349 .45034 m .43089 .45145 L .42849 .45183 L F
.83 .928 .897 r
.53523 .40293 m .53088 .4047 L .53365 .40138 L F
.772 .847 .908 r
.53758 .40114 m .53523 .40293 L .53365 .40138 L F
.644 .906 .982 r
.44488 .44817 m .44379 .45029 L .44235 .44942 L F
.44488 .44817 m .44718 .44915 L .44379 .45029 L F
.721 .983 .901 r
.71897 .3229 m .71751 .32521 L .72011 .32305 L F
.726 .989 .872 r
.71637 .32481 m .71751 .32521 L .71897 .3229 L F
0 0 .146 r
.22324 .5551 m .22518 .5539 L .22553 .55123 L F
0 0 .207 r
.22553 .55123 m .22659 .54999 L .22675 .54736 L F
0 0 .047 r
.22553 .55123 m .22603 .55277 L .22659 .54999 L F
.22553 .55123 m .22518 .5539 L .22603 .55277 L F
.274 .604 .953 r
.5734 .38447 m .57228 .38561 L .57043 .3834 L F
.5734 .38447 m .57472 .38613 L .57228 .38561 L F
.633 .306 .399 r
.68548 .31867 m .68578 .32026 L .68351 .31902 L F
0 .422 .822 r
.68578 .32026 m .68928 .32229 L .68796 .32115 L F
.041 .471 .882 r
.68928 .32229 m .69109 .32182 L .68796 .32115 L F
.68928 .32229 m .69237 .32323 L .69109 .32182 L F
0 0 0 r
.65368 .39233 m .65688 .38926 L .65589 .39086 L F
.46 .881 .776 r
.65688 .38926 m .66028 .38752 L .65937 .38793 L F
0 0 0 r
.65589 .39086 m .65688 .38926 L .65937 .38793 L F
.404 .186 .467 r
.50364 .50652 m .50352 .50905 L .5011 .50976 L F
.256 .025 .359 r
.50352 .50905 m .50106 .5124 L .5011 .50976 L F
.977 .748 .524 r
.44375 .51238 m .44752 .51486 L .44713 .51299 L F
.548 .594 .852 r
.44752 .51486 m .44954 .51265 L .44713 .51299 L F
.44752 .51486 m .44991 .51416 L .44954 .51265 L F
.734 .736 .852 r
.46175 .47107 m .46234 .46553 L .46065 .46725 L F
.46175 .47107 m .46431 .46734 L .46234 .46553 L F
.627 .582 .785 r
.46175 .47107 m .46523 .47077 L .46431 .46734 L F
.686 .485 .609 r
.46159 .47351 m .46523 .47077 L .46175 .47107 L F
.726 .746 .869 r
.46175 .47107 m .46065 .46725 L .45697 .46957 L F
.706 .424 .495 r
.45889 .47322 m .46175 .47107 L .45697 .46957 L F
.45889 .47322 m .46159 .47351 L .46175 .47107 L F
.701 .592 .731 r
.43402 .50993 m .43451 .5132 L .43769 .51067 L F
.428 .479 .811 r
.34777 .52285 m .34882 .52559 L .35075 .52415 L F
.522 .264 .466 r
.34882 .52559 m .34885 .52705 L .35075 .52415 L F
.677 .721 .882 r
.41445 .50188 m .41817 .5034 L .41682 .50168 L F
.937 .564 .226 r
.41817 .5034 m .41664 .50418 L .41682 .50168 L F
.535 .697 .944 r
.58357 .45484 m .58514 .45264 L .58392 .45408 L F
.58357 .45484 m .5861 .45428 L .58514 .45264 L F
0 0 0 r
.35355 .61802 m .35421 .61622 L .35483 .61878 L F
0 0 .402 r
.35484 .62247 m .35355 .61802 L .35483 .61878 L F
.711 .389 .431 r
.67761 .34684 m .67773 .34413 L .67379 .34426 L F
.517 .254 .454 r
.68037 .34621 m .67773 .34413 L .67761 .34684 L F
.68037 .34621 m .68051 .34375 L .67773 .34413 L F
.973 .928 .647 r
.58327 .4222 m .58223 .42514 L .58171 .42231 L F
0 0 .458 r
.58193 .41827 m .58294 .42123 L .58297 .4205 L F
0 0 .499 r
.58193 .41827 m .5828 .42015 L .58316 .41891 L F
.5828 .42015 m .58297 .4205 L .58316 .41891 L F
.99 .738 .373 r
.58348 .41779 m .58316 .41891 L .58415 .41673 L F
0 0 .499 r
.58193 .41827 m .58316 .41891 L .58088 .41859 L F
0 .497 .711 r
.58088 .41859 m .58316 .41891 L .57914 .41831 L F
.269 .767 .892 r
.58088 .41859 m .57646 .41867 L .57783 .41777 L F
.58088 .41859 m .57914 .41831 L .57646 .41867 L F
.749 .735 .84 r
.58316 .41891 m .58134 .42091 L .57914 .41831 L F
.99 .738 .373 r
.582 .42015 m .58316 .41891 L .58348 .41779 L F
.823 .94 .576 r
.58302 .41925 m .58297 .4205 L .58171 .42231 L F
.58316 .41891 m .58297 .4205 L .58302 .41925 L F
0 0 .458 r
.58294 .42123 m .58327 .4222 L .58297 .4205 L F
.959 .946 .675 r
.58297 .4205 m .58327 .4222 L .58171 .42231 L F
.745 .993 .842 r
.42597 .46389 m .42349 .46669 L .42776 .46533 L F
.795 .891 .913 r
.42597 .46389 m .42776 .46533 L .42942 .46361 L F
.816 .842 .868 r
.70255 .31186 m .70149 .31265 L .70014 .31086 L F
.70014 .31086 m .70149 .31265 L .70255 .31186 L F
.70255 .31186 m .70149 .31265 L .70014 .31086 L F
.396 0 0 r
.30236 .57444 m .30021 .57526 L .29757 .57507 L F
.571 .09 .074 r
.30486 .57413 m .30021 .57526 L .30236 .57444 L F
.405 .444 .788 r
.33765 .58102 m .33836 .58147 L .33905 .57796 L F
0 0 0 r
.30747 .6596 m .30814 .65996 L .30565 .66057 L F
.30747 .6596 m .31006 .65874 L .30814 .65996 L F
0 0 .56 r
.31902 .63902 m .31735 .63507 L .31727 .63791 L F
.439 .148 .373 r
.32034 .63663 m .31727 .63791 L .31735 .63507 L F
.32034 .63663 m .31902 .63902 L .31727 .63791 L F
.32034 .63663 m .32167 .63841 L .31902 .63902 L F
.981 .91 .647 r
.32034 .63663 m .31902 .63902 L .32167 .63841 L F
.459 0 0 r
.32573 .54344 m .32406 .5439 L .32817 .54404 L F
.714 .887 .96 r
.46527 .44119 m .46308 .4427 L .46135 .44137 L F
.406 .265 .575 r
.27967 .54927 m .282 .54885 L .28187 .54462 L F
.181 0 0 r
.27967 .54927 m .27874 .55037 L .282 .54885 L F
.282 .54885 m .27874 .55037 L .27967 .54927 L F
.79 .794 .855 r
.6356 .38379 m .63141 .38523 L .63461 .38284 L F
.569 .831 .995 r
.63713 .38198 m .6356 .38379 L .63461 .38284 L F
.63713 .38198 m .6384 .38314 L .6356 .38379 L F
.099 .156 .634 r
.22525 .58946 m .22605 .58994 L .22731 .5881 L F
.034 .175 .68 r
.22401 .58774 m .22605 .58994 L .22525 .58946 L F
.451 .223 .476 r
.50628 .50337 m .5063 .50588 L .50364 .50652 L F
.283 .097 .443 r
.50835 .50479 m .50628 .50337 L .50903 .50299 L F
.50835 .50479 m .5063 .50588 L .50628 .50337 L F
0 0 0 r
.2461 .5226 m .24818 .52172 L .25042 .52046 L F
.25042 .52046 m .25019 .52085 L .25229 .51891 L F
.25042 .52046 m .24818 .52172 L .25019 .52085 L F
.655 .573 .751 r
.61864 .39957 m .61537 .40221 L .61552 .3996 L F
.269 .734 .947 r
.36534 .68091 m .36627 .68157 L .36232 .68112 L F
.504 0 0 r
.36232 .68112 m .36627 .68157 L .36393 .68212 L F
.476 .864 .975 r
.36872 .68078 m .36627 .68157 L .36534 .68091 L F
.849 .989 .852 r
.36393 .68212 m .36627 .68157 L .36534 .68091 L F
.476 .864 .975 r
.36872 .68078 m .36627 .68157 L .36534 .68091 L F
.276 .779 .855 r
.60615 .34716 m .61007 .34673 L .60753 .34784 L F
.814 1 .802 r
.62455 .39128 m .62414 .39297 L .62293 .39288 L F
.545 .8 .992 r
.62672 .39214 m .62414 .39297 L .62455 .39128 L F
.567 .457 .689 r
.62672 .39214 m .62447 .39569 L .62414 .39297 L F
.575 .331 .509 r
.33515 .52579 m .33803 .52585 L .33837 .52267 L F
.576 .332 .51 r
.33837 .52267 m .34118 .52517 L .34063 .52233 L F
.33837 .52267 m .33803 .52585 L .34118 .52517 L F
.985 .734 .47 r
.51234 .43291 m .51465 .43221 L .51281 .4305 L F
.412 .718 .987 r
.51281 .4305 m .51465 .43221 L .51685 .43045 L F
.596 .044 0 r
.5165 .43365 m .51465 .43221 L .51234 .43291 L F
.735 .443 .486 r
.32488 .56103 m .32685 .55969 L .32659 .55915 L F
.51 0 0 r
.32631 .55856 m .32659 .55915 L .32841 .55949 L F
.471 .891 .905 r
.32841 .55949 m .32659 .55915 L .32917 .55811 L F
.735 .443 .486 r
.32685 .55969 m .32917 .55811 L .32659 .55915 L F
.51 0 0 r
.32425 .55765 m .32659 .55915 L .32631 .55856 L F
.471 .891 .905 r
.32841 .55949 m .32917 .55811 L .33123 .55746 L F
0 0 .159 r
.43528 .53533 m .43503 .53794 L .43316 .53966 L F
.724 .525 0 r
.43857 .55429 m .43886 .55693 L .43917 .55919 L F
.728 .503 0 r
.43919 .55982 m .43942 .56098 L .43917 .55919 L F
.538 .001 0 r
.46833 .52127 m .46512 .51857 L .46649 .5216 L F
.734 .991 .861 r
.64641 .32982 m .64462 .3317 L .64594 .32941 L F
.733 .99 .872 r
.64462 .3317 m .64275 .33174 L .64594 .32941 L F
.759 .5 .541 r
.3131 .57437 m .30916 .57656 L .30901 .57427 L F
.3131 .57437 m .31298 .5763 L .30916 .57656 L F
.665 .391 .496 r
.31567 .57459 m .31298 .5763 L .3131 .57437 L F
.69 .764 .908 r
.42266 .54146 m .42398 .54304 L .42678 .54195 L F
.42266 .54146 m .42398 .54304 L .42678 .54195 L F
.538 .257 .436 r
.44988 .50926 m .45287 .50654 L .44998 .50642 L F
.44988 .50926 m .4527 .50891 L .45287 .50654 L F
.272 .04 .367 r
.45287 .50654 m .45517 .5057 L .45553 .50301 L F
.423 .406 .735 r
.45287 .50654 m .45537 .5085 L .45517 .5057 L F
.66 .36 .452 r
.45287 .50654 m .4527 .50891 L .45537 .5085 L F
.45287 .50654 m .4527 .50891 L .45537 .5085 L F
.236 0 0 r
.32738 .6587 m .32782 .65993 L .32551 .66091 L F
.746 .866 .936 r
.52576 .42728 m .53058 .4265 L .5288 .42535 L F
.778 .883 .922 r
.5288 .42535 m .53058 .4265 L .53259 .42496 L F
.57 .792 .983 r
.5364 .41176 m .54045 .41239 L .53914 .4093 L F
.541 .629 .888 r
.53914 .4093 m .54045 .41239 L .54346 .41175 L F
.654 .511 .676 r
.54072 .41481 m .54346 .41175 L .54045 .41239 L F
.898 .871 .433 r
.31693 .63234 m .31788 .62972 L .31692 .63003 L F
0 0 .342 r
.60304 .35483 m .6036 .35912 L .60434 .35766 L F
.117 0 .283 r
.60304 .35483 m .60622 .35631 L .60715 .35435 L F
.60304 .35483 m .60434 .35766 L .60622 .35631 L F
.66 .284 .321 r
.32057 .62605 m .32262 .62858 L .31692 .63003 L F
.81 .366 .188 r
.32057 .62605 m .32431 .62932 L .32262 .62858 L F
.593 .446 .65 r
.46717 .49369 m .4699 .49309 L .47001 .49029 L F
.604 .486 .692 r
.46759 .4967 m .4699 .49309 L .46717 .49369 L F
.873 .801 .775 r
.62607 .42355 m .62351 .42656 L .62502 .42583 L F
.492 .899 .787 r
.34445 .55369 m .34221 .55472 L .34304 .55465 L F
.893 .63 .533 r
.34065 .5562 m .34304 .55465 L .34221 .55472 L F
.34065 .5562 m .34221 .55737 L .34304 .55465 L F
.601 .251 .348 r
.28749 .57406 m .29038 .57428 L .29179 .57132 L F
0 0 .031 r
.29179 .57132 m .29234 .57282 L .2945 .57151 L F
.29179 .57132 m .29038 .57428 L .29234 .57282 L F
.9 .979 .697 r
.38829 .60861 m .39049 .60698 L .38899 .60594 L F
.622 .722 .919 r
.52603 .40782 m .52886 .406 L .52584 .40722 L F
.52603 .40782 m .52838 .40699 L .52886 .406 L F
.991 .765 .498 r
.41188 .50605 m .41267 .50727 L .41227 .50343 L F
.398 .19 .477 r
.41445 .50188 m .41578 .50501 L .41227 .50343 L F
.402 .185 .466 r
.41227 .50343 m .41578 .50501 L .41188 .50605 L F
.467 .257 .509 r
.30192 .54208 m .30461 .53841 L .30033 .53827 L F
.30192 .54208 m .30435 .54146 L .30461 .53841 L F
.879 .506 .334 r
.39432 .52182 m .39077 .51821 L .3938 .51992 L F
.41 .302 .621 r
.43766 .50788 m .43769 .51067 L .43986 .50921 L F
.185 0 0 r
.44255 .5063 m .43766 .50788 L .43986 .50921 L F
.632 .591 .789 r
.43986 .50921 m .44389 .50963 L .44255 .5063 L F
.156 .644 .919 r
.27944 .65698 m .28217 .65625 L .2776 .65484 L F
.27944 .65698 m .28388 .65745 L .28217 .65625 L F
.823 .809 .837 r
.67434 .34638 m .67348 .35037 L .67138 .34995 L F
.684 .77 .916 r
.67272 .3517 m .67385 .34851 L .67138 .34995 L F
.636 .088 0 r
.4586 .51703 m .45671 .51756 L .45402 .51569 L F
.533 .783 .99 r
.45739 .51508 m .46086 .51658 L .4586 .51703 L F
.462 .176 .392 r
.4586 .51703 m .45739 .51508 L .45671 .51756 L F
.4586 .51703 m .46086 .51658 L .45739 .51508 L F
.4586 .51703 m .46003 .51816 L .46086 .51658 L F
.401 0 .148 r
.55741 .47312 m .55889 .47535 L .55624 .47598 L F
.55741 .47312 m .55986 .47305 L .55889 .47535 L F
.28 .382 .789 r
.62489 .40595 m .62149 .39874 L .6233 .39673 L F
.746 .682 .789 r
.62863 .39926 m .62489 .40595 L .6233 .39673 L F
.338 .325 .698 r
.34965 .51653 m .3503 .51689 L .35024 .5167 L F
.34965 .51653 m .35069 .51916 L .35198 .5178 L F
.84 .672 .674 r
.35024 .5167 m .35069 .51916 L .34965 .51653 L F
.35024 .5167 m .34705 .51853 L .35069 .51916 L F
.34705 .51853 m .34711 .51866 L .35069 .51916 L F
.6 .693 .908 r
.34654 .52061 m .35069 .51916 L .34688 .51863 L F
.34654 .52061 m .35031 .51856 L .35069 .51916 L F
.434 .477 .805 r
.34849 .52165 m .35075 .52415 L .35031 .51856 L F
.34777 .52285 m .34936 .52354 L .34849 .52165 L F
.34936 .52354 m .35075 .52415 L .34849 .52165 L F
.84 .672 .674 r
.34705 .51853 m .34688 .51863 L .34711 .51866 L F
.34992 .51496 m .35024 .5167 L .34965 .51653 L F
.199 .201 .635 r
.34992 .51496 m .34965 .51653 L .35006 .51613 L F
.84 .672 .674 r
.34992 .51496 m .35006 .51613 L .35024 .5167 L F
.199 .201 .635 r
.34992 .51496 m .35006 .51613 L .35176 .51445 L F
.84 .672 .674 r
.34992 .51496 m .34976 .51516 L .35006 .51613 L F
.338 .325 .698 r
.34965 .51653 m .35194 .51718 L .35176 .51445 L F
.84 .672 .674 r
.34976 .51516 m .34688 .51863 L .35024 .5167 L F
.338 .325 .698 r
.35024 .5167 m .35198 .5178 L .35194 .51718 L F
.3503 .51689 m .35198 .5178 L .35024 .5167 L F
.936 .946 .769 r
.35905 .63645 m .35577 .63838 L .35635 .63588 L F
.35905 .63645 m .35829 .63936 L .35577 .63838 L F
.49 .015 .053 r
.35693 .63814 m .35635 .63588 L .35577 .63838 L F
.35693 .63814 m .35905 .63645 L .35635 .63588 L F
.678 .53 .677 r
.45897 .47638 m .45454 .47278 L .45681 .47639 L F
.489 .275 .515 r
.3574 .62908 m .36066 .62765 L .35786 .62649 L F
.553 .873 .591 r
.62934 .35415 m .62619 .35705 L .63024 .35705 L F
.536 .363 .593 r
.62903 .35705 m .62961 .35673 L .63024 .35705 L F
.94 .962 .677 r
.63024 .35705 m .63146 .35296 L .62934 .35415 L F
.63024 .35705 m .62961 .35673 L .63146 .35296 L F
.474 .181 .386 r
.62659 .35983 m .62635 .36228 L .62792 .36156 L F
.62811 .36083 m .62792 .36156 L .62869 .36121 L F
.486 .293 .543 r
.62659 .35983 m .628 .36084 L .62961 .35673 L F
0 .242 .746 r
.62803 .36077 m .628 .36084 L .62659 .35983 L F
.62869 .36121 m .628 .36084 L .62803 .36077 L F
.662 .826 .398 r
.628 .36084 m .62796 .36066 L .62828 .36012 L F
0 0 .049 r
.62834 .35998 m .628 .36084 L .62821 .36046 L F
.62834 .35998 m .62821 .36046 L .63058 .35618 L F
.662 .826 .398 r
.628 .36084 m .62828 .36012 L .6309 .35559 L F
.474 .181 .386 r
.62659 .35983 m .62792 .36156 L .62811 .36083 L F
0 0 .049 r
.62961 .35673 m .62834 .35998 L .63058 .35618 L F
.62961 .35673 m .63058 .35618 L .6309 .35559 L F
.536 .363 .593 r
.62619 .35705 m .62961 .35673 L .62903 .35705 L F
0 .007 .522 r
.63214 .35861 m .63024 .35705 L .63277 .3566 L F
.651 .461 .613 r
.44615 .50935 m .44988 .50926 L .44998 .50642 L F
.338 .135 .451 r
.50571 .50809 m .50364 .50652 L .5063 .50588 L F
.50571 .50809 m .50352 .50905 L .50364 .50652 L F
.065 0 0 r
.62117 .37981 m .62585 .37909 L .62387 .37927 L F
.527 .122 .216 r
.62765 .37822 m .62387 .37927 L .62585 .37909 L F
0 0 .52 r
.2384 .58559 m .23818 .58745 L .2379 .58627 L F
0 0 .317 r
.2384 .58559 m .23869 .5883 L .23818 .58745 L F
.813 .781 .823 r
.3841 .6739 m .38549 .67259 L .38317 .67113 L F
.915 .573 .378 r
.38269 .53785 m .3854 .54145 L .38505 .53992 L F
.846 .883 .866 r
.59163 .35626 m .59562 .35475 L .59426 .3543 L F
.281 .782 .775 r
.5983 .35335 m .59426 .3543 L .59562 .35475 L F
.884 .505 .315 r
.37379 .52501 m .37428 .52743 L .37604 .52591 L F
.876 .491 .306 r
.37604 .52591 m .37428 .52743 L .3764 .52802 L F
0 0 0 r
.54993 .46018 m .55105 .45864 L .5526 .45715 L F
.881 .97 .842 r
.42753 .59649 m .42875 .59711 L .43148 .59392 L F
.665 .391 .496 r
.31567 .57459 m .31544 .57708 L .31298 .5763 L F
.703 .325 .33 r
.31567 .57459 m .31851 .57724 L .31544 .57708 L F
.001 .379 .842 r
.33106 .64854 m .33026 .64847 L .32722 .64563 L F
.818 .671 .701 r
.59756 .36581 m .5981 .36977 L .59908 .36744 L F
.483 0 0 r
.25453 .51798 m .25714 .51813 L .25918 .51678 L F
.225 0 0 r
.25918 .51678 m .25714 .51813 L .26186 .5169 L F
.568 .829 .994 r
.43846 .44925 m .43751 .45127 L .43597 .44985 L F
.43846 .44925 m .44001 .45047 L .43751 .45127 L F
.67 .974 .888 r
.64754 .339 m .64734 .33823 L .64573 .34066 L F
.678 .978 .844 r
.64734 .33823 m .64414 .34063 L .64573 .34066 L F
.268 0 0 r
.67885 .32135 m .68351 .31902 L .68129 .32176 L F
.612 .067 0 r
.68351 .31902 m .68419 .32115 L .68129 .32176 L F
.68351 .31902 m .68578 .32026 L .68419 .32115 L F
.909 .938 .816 r
.58171 .42231 m .58223 .42514 L .58017 .4272 L F
.168 .242 .696 r
.36566 .56361 m .36417 .56541 L .36283 .56017 L F
.62 .301 .408 r
.36417 .56541 m .3671 .56717 L .36787 .5652 L F
.287 .419 .821 r
.36566 .56361 m .3671 .56717 L .36417 .56541 L F
.71 .745 .879 r
.36588 .55729 m .36658 .56031 L .36283 .56017 L F
.168 .242 .696 r
.36566 .56361 m .36283 .56017 L .36658 .56031 L F
.083 0 .296 r
.36787 .5652 m .36999 .5611 L .36658 .56031 L F
.393 .692 .98 r
.36923 .55956 m .36999 .5611 L .36658 .56031 L F
.736 .602 .708 r
.36923 .55956 m .36566 .56361 L .36658 .56031 L F
.381 .512 .865 r
.36588 .55729 m .36923 .55956 L .36658 .56031 L F
.709 .416 .478 r
.41648 .48615 m .41797 .48321 L .41736 .48358 L F
.41648 .48615 m .42055 .48614 L .41797 .48321 L F
.407 .615 .935 r
.29185 .64097 m .29006 .64236 L .28827 .64013 L F
0 .108 .608 r
.29353 .64554 m .29006 .64236 L .2917 .64497 L F
.204 .236 .673 r
.29185 .64097 m .2917 .64497 L .29006 .64236 L F
.852 .643 .619 r
.32471 .52268 m .32151 .52534 L .31984 .52415 L F
.32471 .52268 m .31984 .52415 L .32225 .52367 L F
0 .055 .609 r
.32666 .52216 m .32471 .52268 L .32675 .5216 L F
.522 .419 .679 r
.32666 .52216 m .3279 .52263 L .32766 .52189 L F
.32471 .52268 m .32608 .52266 L .32666 .52216 L F
.32608 .52266 m .3279 .52263 L .32666 .52216 L F
.104 0 .173 r
.32757 .52137 m .32666 .52216 L .32675 .5216 L F
0 0 0 r
.33068 .51921 m .32675 .5216 L .3267 .51893 L F
.522 .419 .679 r
.32471 .52268 m .325 .5226 L .3267 .51893 L F
.325 .5226 m .32766 .52189 L .3275 .5214 L F
0 0 0 r
.33068 .51921 m .32949 .52045 L .32675 .5216 L F
.32949 .52045 m .32757 .52137 L .32675 .5216 L F
.522 .419 .679 r
.325 .5226 m .3275 .5214 L .3267 .51893 L F
0 0 0 r
.32949 .52045 m .329 .52097 L .32757 .52137 L F
.526 0 0 r
.32471 .52268 m .32634 .52409 L .3279 .52263 L F
.104 0 .173 r
.329 .52097 m .32751 .52143 L .32757 .52137 L F
.27 .266 .671 r
.3267 .51893 m .32751 .52143 L .329 .52097 L F
.32751 .52143 m .3279 .52263 L .329 .52097 L F
.104 0 .173 r
.329 .52097 m .32666 .52216 L .32751 .52143 L F
.329 .52097 m .32634 .52409 L .32666 .52216 L F
0 .055 .609 r
.32634 .52409 m .32471 .52268 L .32666 .52216 L F
.526 0 0 r
.32471 .52268 m .32225 .52367 L .32634 .52409 L F
.798 .973 .908 r
.47434 .43501 m .47012 .43681 L .47304 .43398 L F
.791 .932 .926 r
.47743 .43267 m .47434 .43501 L .47304 .43398 L F
.839 .628 .082 r
.51802 .43672 m .5183 .43498 L .5165 .43365 L F
.51802 .43672 m .51847 .4379 L .5183 .43498 L F
.37 .21 .53 r
.5183 .43498 m .52039 .43644 L .5224 .43497 L F
.5183 .43498 m .51847 .4379 L .52039 .43644 L F
.564 .058 .009 r
.44445 .48868 m .44841 .48919 L .44799 .48817 L F
.482 .009 .055 r
.44841 .48919 m .45126 .48915 L .44799 .48817 L F
.024 0 .146 r
.39857 .48416 m .39846 .48549 L .39883 .48512 L F
.679 .152 0 r
.39824 .48298 m .39857 .48416 L .40082 .48375 L F
.024 0 .146 r
.39857 .48416 m .39883 .48512 L .40059 .4834 L F
.679 .152 0 r
.39708 .48263 m .39857 .48416 L .39824 .48298 L F
.086 .075 .547 r
.40189 .48228 m .40082 .48375 L .39857 .48416 L F
.302 .729 .971 r
.41213 .51203 m .41599 .51207 L .41738 .5131 L F
.975 .677 .298 r
.41738 .5131 m .41609 .5099 L .41865 .50871 L F
.41738 .5131 m .41599 .51207 L .41609 .5099 L F
.862 .975 .858 r
.32167 .63841 m .3257 .63603 L .32501 .63742 L F
.942 .813 .687 r
.3257 .63603 m .32475 .63171 L .32649 .63459 L F
0 0 0 r
.32501 .63742 m .3257 .63603 L .32649 .63459 L F
.744 .716 .825 r
.34434 .56566 m .34678 .56542 L .34738 .56476 L F
.777 .993 .779 r
.35085 .65119 m .35309 .65007 L .35471 .64818 L F
.682 .953 .953 r
.45398 .44526 m .45303 .44736 L .45206 .44672 L F
.45398 .44526 m .45628 .44548 L .45303 .44736 L F
.861 .509 .385 r
.3764 .52802 m .38032 .5315 L .37993 .52921 L F
.64 .486 .658 r
.2692 .57776 m .27182 .57778 L .27145 .57492 L F
.606 .061 0 r
.2692 .57776 m .27147 .57996 L .26962 .57881 L F
.597 .275 .394 r
.27182 .57778 m .27147 .57996 L .2692 .57776 L F
.606 .061 0 r
.2692 .57776 m .26962 .57881 L .27182 .57778 L F
.64 .486 .658 r
.27145 .57492 m .27182 .57778 L .2692 .57776 L F
.491 .06 .149 r
.44853 .52256 m .45151 .52303 L .45292 .52168 L F
.206 .082 .48 r
.4506 .52287 m .44853 .52256 L .45292 .52168 L F
0 0 0 r
.45292 .52168 m .45151 .52303 L .45471 .52111 L F
.576 .323 .496 r
.45471 .52111 m .4506 .52287 L .45292 .52168 L F
.593 .655 .88 r
.54148 .40318 m .53758 .40114 L .54177 .40134 L F
.343 .42 .797 r
.54309 .40063 m .54148 .40318 L .54177 .40134 L F
.245 .292 .713 r
.54309 .40063 m .54492 .40521 L .54148 .40318 L F
.653 .417 .549 r
.52401 .43758 m .5224 .43497 L .52039 .43644 L F
.52401 .43758 m .52494 .43491 L .5224 .43497 L F
0 0 .088 r
.69995 .35844 m .69861 .36079 L .69981 .35682 L F
0 0 0 r
.69786 .36288 m .69861 .36079 L .69995 .35844 L F
.161 0 0 r
.61711 .37668 m .61361 .37926 L .61755 .37995 L F
.393 .467 .817 r
.61578 .3732 m .61711 .37668 L .61905 .37495 L F
.648 .552 .732 r
.61755 .37995 m .61905 .37495 L .61711 .37668 L F
.261 0 .241 r
.2437 .52304 m .24518 .52421 L .2461 .5226 L F
.2437 .52304 m .24301 .52512 L .24518 .52421 L F
.708 .861 .955 r
.37277 .49856 m .37042 .49994 L .36869 .4987 L F
.66 .106 0 r
.37042 .49994 m .3707 .50136 L .36869 .4987 L F
.37042 .49994 m .37273 .50207 L .3707 .50136 L F
.497 .537 .828 r
.23085 .58518 m .23123 .58797 L .22918 .58373 L F
.778 .957 .639 r
.2281 .54242 m .22844 .5409 L .2306 .53898 L F
.919 .974 .698 r
.2281 .54242 m .22647 .54302 L .22844 .5409 L F
.653 .471 .626 r
.34494 .60316 m .34147 .60505 L .34182 .60062 L F
.786 .317 0 r
.73084 .31362 m .73147 .31372 L .72985 .31227 L F
.731 .983 .772 r
.73147 .31372 m .73135 .31464 L .73219 .31384 L F
0 .441 .71 r
.73364 .31515 m .73135 .31464 L .73147 .31372 L F
.73364 .31515 m .73506 .31551 L .73282 .31498 L F
.73262 .31492 m .73282 .31498 L .73135 .31464 L F
.73364 .31515 m .73282 .31498 L .73262 .31492 L F
.786 .317 0 r
.73157 .31461 m .73147 .31372 L .73084 .31362 L F
.73206 .31528 m .73183 .31469 L .73157 .31461 L F
.73183 .31469 m .73147 .31372 L .73157 .31461 L F
.731 .983 .772 r
.73147 .31372 m .73219 .31384 L .73452 .31164 L F
.993 .808 .553 r
.3942 .57597 m .39616 .5744 L .3953 .57347 L F
.3942 .57597 m .39559 .57685 L .39616 .5744 L F
.626 .862 .987 r
.60925 .37811 m .60926 .38003 L .61068 .37979 L F
.845 .87 .86 r
.60925 .37811 m .608 .38161 L .60926 .38003 L F
.729 .446 .498 r
.608 .38161 m .61068 .37979 L .60926 .38003 L F
.927 .779 .676 r
.35829 .63936 m .3578 .64278 L .35577 .63838 L F
.592 .937 .941 r
.37117 .62087 m .37363 .62071 L .36943 .62227 L F
.682 .33 .371 r
.37117 .62087 m .37504 .61892 L .37363 .62071 L F
.828 .872 .878 r
.37172 .6913 m .37469 .68916 L .37268 .68733 L F
.608 .817 .98 r
.37268 .68733 m .37469 .68916 L .37688 .68776 L F
.923 .55 .29 r
.70883 .31112 m .71077 .31419 L .71041 .31205 L F
.015 0 .414 r
.71041 .31205 m .71077 .31419 L .71271 .30994 L F
.941 .788 .663 r
.4242 .58742 m .42613 .58426 L .42426 .5854 L F
.875 .907 .849 r
.42434 .58535 m .42613 .58426 L .42464 .58524 L F
.188 .155 .587 r
.42538 .58605 m .4242 .58742 L .42426 .5854 L F
.875 .907 .849 r
.42423 .58539 m .42613 .58426 L .42434 .58535 L F
.42386 .5853 m .42613 .58426 L .42423 .58539 L F
.941 .788 .663 r
.42426 .5854 m .42613 .58426 L .42444 .58435 L F
.875 .692 .652 r
.42423 .58486 m .42464 .58388 L .42463 .58049 L F
.941 .788 .663 r
.42428 .58472 m .42444 .58435 L .42429 .58436 L F
.42426 .5854 m .42444 .58435 L .42428 .58472 L F
.875 .907 .849 r
.42184 .58623 m .42386 .5853 L .42423 .58539 L F
.777 .649 .722 r
.42418 .58444 m .4242 .58742 L .42184 .58623 L F
.875 .692 .652 r
.42305 .58136 m .42425 .58463 L .42463 .58049 L F
.777 .649 .722 r
.42429 .58436 m .42428 .58472 L .42418 .58444 L F
.42428 .58472 m .4242 .58742 L .42418 .58444 L F
.875 .692 .652 r
.42144 .58226 m .42423 .58486 L .42425 .58463 L F
.42144 .58226 m .42425 .58463 L .42305 .58136 L F
.42428 .58472 m .42464 .58524 L .42464 .58388 L F
.42429 .58492 m .42464 .58524 L .42428 .58472 L F
.854 .702 .692 r
.42429 .58436 m .42464 .58524 L .42429 .58492 L F
.188 .155 .587 r
.42429 .58492 m .42428 .58472 L .42429 .58436 L F
.875 .692 .652 r
.42423 .58486 m .42429 .58492 L .42428 .58472 L F
.854 .702 .692 r
.42429 .58436 m .42429 .58492 L .42144 .58226 L F
.188 .155 .587 r
.42431 .58541 m .42429 .58492 L .42429 .58436 L F
.42509 .5856 m .42431 .58541 L .42429 .58436 L F
.42431 .58541 m .42426 .5854 L .42428 .58472 L F
.42538 .58605 m .42426 .5854 L .42509 .5856 L F
.946 .752 .608 r
.42464 .58524 m .42613 .58426 L .42463 .58049 L F
0 .179 .627 r
.58409 .39632 m .58015 .39353 L .58267 .39497 L F
.692 .596 .744 r
.3267 .51893 m .32873 .51534 L .32609 .51733 L F
.989 .732 .364 r
.4417 .56757 m .44177 .56483 L .44023 .56358 L F
.729 .446 .498 r
.608 .38161 m .61083 .38272 L .61068 .37979 L F
.757 .613 .698 r
.61083 .38272 m .61361 .37926 L .61068 .37979 L F
.592 .937 .941 r
.37117 .62087 m .36943 .62227 L .36911 .62252 L F
.879 .549 .044 r
.58902 .40803 m .58884 .40687 L .58768 .40472 L F
0 0 .028 r
.36439 .59105 m .36382 .59379 L .36461 .59201 L F
.36439 .59105 m .36461 .59201 L .36214 .59003 L F
0 0 .275 r
.27145 .57492 m .27217 .57554 L .27415 .57534 L F
.27145 .57492 m .27182 .57778 L .27217 .57554 L F
.709 .381 0 r
.58768 .40472 m .58683 .40218 L .58613 .40057 L F
.078 0 .306 r
.68447 .29581 m .68403 .2982 L .68607 .29419 L F
.81 1 .821 r
.23476 .55641 m .23236 .55876 L .23479 .55809 L F
.516 .316 .548 r
.40576 .47275 m .407 .47278 L .40456 .47073 L F
.448 .131 .335 r
.30966 .62626 m .31218 .62589 L .31278 .62367 L F
.448 .169 .397 r
.31218 .62589 m .31554 .62281 L .31278 .62367 L F
.961 .805 .642 r
.34068 .56477 m .33903 .56385 L .33984 .56112 L F
.998 .782 .444 r
.39262 .59559 m .39373 .59653 L .39402 .59392 L F
.965 .885 .5 r
.39338 .59294 m .39262 .59559 L .39402 .59392 L F
.849 .994 .835 r
.37795 .62382 m .38033 .62123 L .37828 .62178 L F
.878 .976 .673 r
.37604 .62548 m .37795 .62382 L .37828 .62178 L F
0 0 .045 r
.27917 .6454 m .27787 .64904 L .27929 .64838 L F
.742 .652 .094 r
.27787 .64904 m .27769 .64967 L .27929 .64838 L F
.27787 .64904 m .27762 .6518 L .27769 .64967 L F
.793 .877 .909 r
.61755 .37995 m .62117 .37981 L .61992 .37922 L F
.406 .825 .969 r
.62117 .37981 m .62296 .37862 L .61992 .37922 L F
.62117 .37981 m .62387 .37927 L .62296 .37862 L F
.771 .759 .842 r
.23308 .60589 m .23411 .60925 L .23549 .60734 L F
.832 .563 .015 r
.60559 .42217 m .60564 .42384 L .60489 .42187 L F
.60559 .42217 m .60609 .42502 L .60564 .42384 L F
.211 0 0 r
.27583 .57788 m .27147 .57996 L .27182 .57778 L F
.27583 .57788 m .27395 .57956 L .27147 .57996 L F
.669 .208 .148 r
.27583 .57788 m .27807 .57994 L .27395 .57956 L F
.542 .26 .437 r
.27865 .5775 m .27807 .57994 L .27583 .57788 L F
0 0 .209 r
.33069 .65687 m .32987 .6554 L .33095 .65514 L F
.727 .291 .216 r
.2464 .58675 m .24228 .58541 L .24423 .58701 L F
.488 .346 .615 r
.63189 .35106 m .63438 .35017 L .63405 .34707 L F
.44 .236 .505 r
.63415 .35198 m .63189 .35106 L .63146 .35296 L F
.63415 .35198 m .63438 .35017 L .63189 .35106 L F
.772 .688 .771 r
.33381 .55438 m .33998 .55591 L .3365 .55072 L F
.339 .734 .983 r
.33651 .55425 m .33998 .55591 L .33539 .55478 L F
0 .057 .613 r
.3365 .55072 m .3374 .55207 L .33858 .55291 L F
.3374 .55207 m .33998 .55591 L .33858 .55291 L F
.672 .856 .97 r
.33907 .55395 m .33998 .55591 L .33787 .5549 L F
.33858 .55291 m .33768 .55481 L .33651 .55425 L F
.314 0 .215 r
.3375 .55519 m .33954 .55359 L .33858 .55291 L F
.33954 .55359 m .33968 .55347 L .33858 .55291 L F
.283 0 .122 r
.33495 .55581 m .33744 .55382 L .33651 .55425 L F
.33744 .55382 m .33858 .55291 L .33651 .55425 L F
.339 .734 .983 r
.33651 .55425 m .33539 .55478 L .33381 .55438 L F
.607 .593 .812 r
.5861 .45428 m .58783 .45867 L .5904 .45753 L F
.783 .609 .665 r
.46218 .50304 m .45863 .49971 L .45838 .50224 L F
.812 .545 .535 r
.45803 .50514 m .46218 .50304 L .45838 .50224 L F
.45803 .50514 m .46203 .5056 L .46218 .50304 L F
.753 .579 .66 r
.46203 .5056 m .46517 .50333 L .46218 .50304 L F
.701 .592 .731 r
.43402 .50993 m .43769 .51067 L .43532 .50872 L F
.284 .688 .972 r
.61631 .36472 m .61704 .36558 L .6157 .36471 L F
.61835 .36473 m .61704 .36558 L .61631 .36472 L F
.589 .592 .823 r
.6142 .3634 m .61778 .36648 L .61704 .36558 L F
.61778 .36648 m .61834 .36696 L .61704 .36558 L F
0 0 0 r
.61834 .36696 m .61473 .36908 L .61704 .36558 L F
.154 0 0 r
.46184 .59372 m .46333 .5948 L .46014 .59504 L F
.46184 .59372 m .46449 .59322 L .46333 .5948 L F
.363 0 0 r
.32926 .50326 m .33061 .50294 L .32944 .50389 L F
.842 .489 0 r
.33212 .50741 m .3311 .50562 L .33144 .50621 L F
.904 .502 .1 r
.32988 .50354 m .33061 .50294 L .33144 .50621 L F
.842 .489 0 r
.3311 .50562 m .33027 .50417 L .33144 .50621 L F
.904 .502 .1 r
.32944 .50389 m .32988 .50354 L .3304 .50442 L F
.32973 .50419 m .3304 .50442 L .3311 .50562 L F
.32944 .50389 m .3304 .50442 L .32973 .50419 L F
.846 .492 0 r
.33027 .50417 m .3297 .50376 L .32885 .50388 L F
.904 .502 .1 r
.32944 .50389 m .3311 .50562 L .33116 .50588 L F
.32944 .50389 m .33116 .50588 L .33027 .50417 L F
.775 .689 .768 r
.33027 .50417 m .32728 .5041 L .32944 .50389 L F
.846 .492 0 r
.32963 .50415 m .32885 .50388 L .32728 .5041 L F
.33027 .50417 m .32885 .50388 L .32963 .50415 L F
.842 .489 0 r
.3311 .50562 m .33109 .50575 L .33027 .50417 L F
.33212 .50741 m .33142 .50693 L .3311 .50562 L F
.904 .502 .1 r
.33116 .50588 m .3311 .50562 L .33144 .50621 L F
.33116 .50588 m .33144 .50621 L .33027 .50417 L F
.842 .489 0 r
.33109 .50575 m .33107 .50669 L .33027 .50417 L F
.33142 .50693 m .33107 .50669 L .3311 .50562 L F
.734 .342 .309 r
.34738 .56476 m .34323 .56426 L .34434 .56566 L F
.34738 .56476 m .34566 .5667 L .34323 .56426 L F
.122 0 0 r
.32835 .60082 m .32739 .60195 L .33056 .6 L F
.229 .281 .709 r
.35854 .59274 m .35853 .59879 L .35604 .59308 L F
.063 0 0 r
.35748 .60016 m .35975 .59957 L .36091 .59837 L F
.229 .281 .709 r
.35854 .59274 m .36047 .59878 L .35853 .59879 L F
.3 0 0 r
.36047 .59878 m .35528 .59898 L .35853 .59879 L F
.794 .92 .922 r
.64754 .339 m .65229 .33752 L .65165 .33721 L F
.545 .889 .65 r
.65549 .33492 m .65406 .33576 L .65229 .33752 L F
.587 .946 .883 r
.65406 .33576 m .65165 .33721 L .65229 .33752 L F
.951 .731 .569 r
.67871 .3604 m .67638 .36133 L .67679 .3594 L F
.67871 .3604 m .67847 .36371 L .67638 .36133 L F
.93 .971 .74 r
.43545 .56258 m .43412 .56325 L .43397 .56074 L F
.43545 .56258 m .43407 .56474 L .43412 .56325 L F
0 .302 .769 r
.58141 .39355 m .58015 .39353 L .57884 .39242 L F
.58141 .39355 m .58267 .39497 L .58015 .39353 L F
.907 .851 .777 r
.33163 .625 m .33209 .6294 L .32964 .62793 L F
.693 .153 0 r
.33209 .6294 m .33519 .63196 L .33015 .62968 L F
.41 .302 .621 r
.43766 .50788 m .43532 .50872 L .43769 .51067 L F
.516 0 0 r
.34877 .64696 m .34939 .64567 L .34718 .64482 L F
.34877 .64696 m .35158 .64632 L .34939 .64567 L F
.169 0 .142 r
.31824 .61932 m .31952 .6211 L .31991 .61844 L F
.31824 .61932 m .31746 .62202 L .31952 .6211 L F
.102 0 .36 r
.49079 .53142 m .48904 .53511 L .48883 .53237 L F
.655 .641 .824 r
.36588 .55729 m .36283 .56017 L .36179 .55777 L F
.36588 .55729 m .36179 .55777 L .3644 .55754 L F
.382 .006 .195 r
.3656 .55501 m .3644 .55754 L .36179 .55777 L F
.535 .363 .595 r
.3682 .55174 m .36826 .55461 L .3656 .55501 L F
.75 .39 .371 r
.3678 .55721 m .3656 .55501 L .36826 .55461 L F
.653 .202 .169 r
.36588 .55729 m .3644 .55754 L .3678 .55721 L F
.75 .39 .371 r
.3678 .55721 m .3644 .55754 L .3656 .55501 L F
.674 .971 .791 r
.36096 .6453 m .36446 .64264 L .36185 .64373 L F
.96 .937 .711 r
.36338 .64183 m .36446 .64264 L .36589 .63872 L F
.955 .942 .723 r
.36185 .64373 m .36446 .64264 L .36338 .64183 L F
0 0 0 r
.36191 .64366 m .36338 .64183 L .3645 .64075 L F
.36185 .64373 m .36338 .64183 L .36191 .64366 L F
.96 .937 .711 r
.36338 .64183 m .36589 .63872 L .36592 .63863 L F
.026 .313 .802 r
.55704 .40652 m .55749 .40499 L .55497 .40715 L F
.459 .412 .718 r
.47216 .53453 m .47392 .53144 L .47268 .53253 L F
.81 .546 .539 r
.42773 .51583 m .43203 .51921 L .43266 .51645 L F
.972 .815 .629 r
.40883 .56732 m .40789 .56423 L .40927 .56513 L F
.811 .329 .05 r
.35504 .50483 m .35513 .50287 L .35286 .50241 L F
.35504 .50483 m .35696 .5054 L .35513 .50287 L F
.734 .973 .928 r
.58574 .35474 m .58225 .35695 L .58347 .35457 L F
.911 .668 .167 r
.58419 .35825 m .58347 .35457 L .58225 .35695 L F
0 0 .061 r
.46813 .55355 m .46734 .55505 L .46701 .55763 L F
.843 .971 .88 r
.55612 .41997 m .55337 .42264 L .55374 .41981 L F
.97 .697 .459 r
.55337 .42264 m .55128 .42337 L .55374 .41981 L F
.55337 .42264 m .55311 .42469 L .55128 .42337 L F
.897 .606 .487 r
.3901 .55402 m .39252 .55715 L .39188 .55531 L F
0 0 .174 r
.35207 .63897 m .35199 .64253 L .35055 .64028 L F
.676 .259 0 r
.35055 .64028 m .35199 .64253 L .35328 .6449 L F
.504 .361 .619 r
.46759 .4967 m .4701 .49587 L .4699 .49309 L F
.641 .483 .653 r
.4673 .49928 m .4701 .49587 L .46759 .4967 L F
.627 .958 .811 r
.6682 .38228 m .66878 .38246 L .67028 .38065 L F
0 0 0 r
.67018 .38074 m .6682 .38228 L .67028 .38065 L F
.57 .933 .788 r
.66628 .38377 m .66878 .38246 L .6682 .38228 L F
0 0 0 r
.66722 .3837 m .6682 .38228 L .67018 .38074 L F
.57 .933 .788 r
.66472 .38458 m .66628 .38377 L .6682 .38228 L F
.626 .956 .797 r
.66878 .38246 m .67208 .38011 L .67028 .38065 L F
.516 .243 .44 r
.39007 .48347 m .39282 .48327 L .39341 .48062 L F
.684 .402 .489 r
.39341 .48062 m .39708 .48263 L .39569 .47962 L F
.39341 .48062 m .39282 .48327 L .39708 .48263 L F
0 0 .359 r
.45553 .50301 m .45698 .4986 L .45405 .50136 L F
.45553 .50301 m .45643 .5015 L .45698 .4986 L F
.522 .247 .439 r
.45553 .50301 m .45803 .50514 L .45643 .5015 L F
.45553 .50301 m .45517 .5057 L .45803 .50514 L F
.984 .709 .415 r
.29523 .65497 m .29527 .65237 L .29376 .65206 L F
.38 0 0 r
.29909 .65466 m .29527 .65237 L .29523 .65497 L F
.682 .33 .371 r
.37117 .62087 m .37608 .61952 L .37504 .61892 L F
.597 .027 0 r
.37504 .61892 m .37608 .61952 L .37137 .61736 L F
.713 .613 .744 r
.37592 .61699 m .37818 .61628 L .37504 .61892 L F
.776 .629 .697 r
.45224 .57034 m .45607 .56665 L .45259 .56804 L F
.474 .854 .634 r
.66069 .37619 m .65714 .37863 L .65894 .37695 L F
.442 .851 .678 r
.66262 .37481 m .66413 .37409 L .66069 .37619 L F
.449 .862 .706 r
.66262 .37481 m .66069 .37619 L .65894 .37695 L F
.549 .271 .446 r
.52583 .48717 m .52585 .48936 L .52305 .48975 L F
.564 .282 .447 r
.52973 .48795 m .52583 .48717 L .52981 .48641 L F
.52973 .48795 m .52585 .48936 L .52583 .48717 L F
.685 .782 .924 r
.45454 .47278 m .45086 .47197 L .4524 .47365 L F
.723 .317 .278 r
.33064 .5672 m .3297 .5695 L .32774 .56683 L F
.484 .33 .596 r
.33302 .56416 m .33328 .56685 L .33064 .5672 L F
.582 .256 .382 r
.33328 .56685 m .3297 .5695 L .33064 .5672 L F
.693 .628 .779 r
.35649 .68724 m .35974 .68525 L .3577 .68223 L F
0 0 0 r
.58735 .35286 m .58838 .3529 L .5922 .3518 L F
.888 .975 .827 r
.5922 .3518 m .59291 .34873 L .59394 .34938 L F
.5922 .3518 m .58838 .3529 L .59291 .34873 L F
.783 .651 .716 r
.4283 .5797 m .43124 .57769 L .42714 .5772 L F
.742 .573 .664 r
.60931 .35731 m .6105 .36065 L .60633 .36023 L F
.473 .231 .466 r
.44853 .52256 m .44898 .52413 L .44666 .52527 L F
.206 .082 .48 r
.4503 .5233 m .4492 .52487 L .44898 .52413 L F
.45013 .52324 m .44898 .52413 L .44853 .52256 L F
.4503 .5233 m .44898 .52413 L .45013 .52324 L F
.8 .895 .911 r
.45013 .52324 m .45151 .52303 L .44853 .52256 L F
.45021 .52317 m .4506 .52287 L .4513 .523 L F
.44739 .52363 m .45013 .52324 L .44853 .52256 L F
.206 .082 .48 r
.4506 .52287 m .4503 .5233 L .44853 .52256 L F
.8 .895 .911 r
.44739 .52363 m .4506 .52287 L .45021 .52317 L F
.45109 .5231 m .4513 .523 L .45151 .52303 L F
.44739 .52363 m .4513 .523 L .45109 .5231 L F
.473 .231 .466 r
.44666 .52527 m .4492 .52487 L .44652 .52547 L F
.44898 .52413 m .4492 .52487 L .44666 .52527 L F
.736 .701 .818 r
.61381 .38583 m .61509 .38305 L .61083 .38272 L F
.61381 .38583 m .61083 .38272 L .61332 .38383 L F
.86 .995 .817 r
.61121 .38798 m .61381 .38583 L .61332 .38383 L F
.082 0 .445 r
.22346 .55777 m .22518 .5539 L .22324 .5551 L F
.483 0 0 r
.61313 .37268 m .61463 .37436 L .61193 .37509 L F
.61313 .37268 m .61578 .3732 L .61463 .37436 L F
.775 .662 .738 r
.44255 .5063 m .44389 .50963 L .44615 .50935 L F
.764 .58 .649 r
.44389 .50963 m .44375 .51238 L .44615 .50935 L F
.784 .611 .666 r
.44375 .51238 m .44713 .51299 L .44615 .50935 L F
.436 .248 .526 r
.44713 .51299 m .44988 .50926 L .44615 .50935 L F
.752 .962 .935 r
.4964 .42218 m .49131 .42426 L .49519 .42093 L F
.856 .896 .864 r
.49868 .41976 m .4964 .42218 L .49576 .41982 L F
.898 .911 .824 r
.49576 .41982 m .4964 .42218 L .49519 .42093 L F
.699 .916 .968 r
.34704 .53226 m .34502 .53154 L .3474 .52997 L F
.557 .597 .849 r
.34924 .53429 m .34502 .53154 L .34704 .53226 L F
.579 .635 .871 r
.54134 .46415 m .53957 .45962 L .54154 .46127 L F
.81 .963 .908 r
.54214 .45872 m .54154 .46127 L .53957 .45962 L F
.54214 .45872 m .54431 .45903 L .54154 .46127 L F
.695 .513 .637 r
.54154 .46127 m .54364 .46276 L .54134 .46415 L F
.473 .856 .644 r
.67642 .30591 m .67694 .3053 L .67794 .30404 L F
.67642 .30591 m .675 .30674 L .67694 .3053 L F
.917 .839 .753 r
.37937 .6139 m .37685 .61354 L .37979 .61247 L F
.37937 .6139 m .37818 .61628 L .37685 .61354 L F
.348 .752 .983 r
.58168 .37267 m .5828 .37376 L .57845 .37296 L F
.885 .985 .812 r
.5854 .37048 m .5828 .37376 L .5835 .37051 L F
.863 .972 .86 r
.5835 .37051 m .5828 .37376 L .58168 .37267 L F
.393 .844 .757 r
.65141 .38138 m .65474 .37994 L .65208 .38117 L F
.767 .725 .814 r
.53622 .42162 m .5395 .42231 L .53802 .41935 L F
.736 .712 .829 r
.53802 .41935 m .5395 .42231 L .54214 .42072 L F
.819 .535 .507 r
.54324 .42587 m .5395 .42231 L .53936 .42462 L F
.291 .133 .487 r
.24096 .58265 m .24203 .58446 L .2422 .58061 L F
0 0 .505 r
.24096 .58265 m .24228 .58541 L .24203 .58446 L F
.703 .652 .795 r
.23119 .56663 m .23319 .56801 L .23153 .56417 L F
.866 .849 .824 r
.22834 .57024 m .23319 .56801 L .23119 .56663 L F
.71 .655 .793 r
.23153 .56417 m .23319 .56801 L .23467 .56401 L F
.853 .971 .87 r
.63229 .41554 m .63526 .41257 L .63439 .41175 L F
.711 .503 .605 r
.69939 .32449 m .69788 .32759 L .69755 .32486 L F
0 0 0 r
.36847 .63517 m .3718 .63222 L .37064 .63467 L F
.025 .227 .732 r
.34985 .56416 m .3514 .56795 L .35218 .56627 L F
.713 .921 .58 r
.3514 .56795 m .34968 .5696 L .35218 .56627 L F
.407 .558 .893 r
.28955 .65074 m .28861 .65347 L .28805 .65097 L F
.28955 .65074 m .29232 .65622 L .28861 .65347 L F
.893 .734 .678 r
.32406 .5439 m .32597 .54557 L .32817 .54404 L F
.473 0 0 r
.2475 .61774 m .24976 .61853 L .24669 .61679 L F
.267 0 0 r
.30796 .5404 m .30723 .54132 L .30435 .54146 L F
.979 .705 .314 r
.30703 .53806 m .30723 .54132 L .30796 .5404 L F
.805 .999 .803 r
.62275 .3432 m .62487 .33996 L .62584 .34055 L F
.62275 .3432 m .62214 .34277 L .62487 .33996 L F
.892 .829 .779 r
.62778 .38472 m .62922 .3863 L .62674 .38929 L F
.701 .922 .967 r
.63147 .38346 m .62922 .3863 L .62778 .38472 L F
.63147 .38346 m .63141 .38523 L .62922 .3863 L F
0 0 0 r
.47663 .57681 m .47607 .57771 L .47799 .57449 L F
0 0 .231 r
.47696 .57881 m .47607 .57771 L .47663 .57681 L F
.47696 .57881 m .47598 .58024 L .47607 .57771 L F
.745 .993 .842 r
.42597 .46389 m .42292 .46656 L .42349 .46669 L F
.922 .723 .616 r
.72603 .30813 m .72786 .31176 L .72754 .31053 L F
0 0 0 r
.73034 .3102 m .73113 .30914 L .72883 .31098 L F
.7289 .3111 m .72883 .31098 L .72786 .31176 L F
.73034 .3102 m .72883 .31098 L .7289 .3111 L F
.73034 .3102 m .72786 .31176 L .72603 .30813 L F
.56 .072 0 r
.72899 .3114 m .72924 .31166 L .72763 .30972 L F
.72924 .31166 m .72985 .31227 L .72907 .31138 L F
.72924 .31166 m .72907 .31138 L .72763 .30972 L F
.593 .748 .951 r
.29009 .66083 m .29419 .66192 L .29245 .66 L F
.616 .66 .87 r
.29419 .66192 m .29537 .65817 L .29245 .66 L F
.29419 .66192 m .2965 .66109 L .29537 .65817 L F
.985 .807 .582 r
.42381 .56995 m .42555 .57117 L .42602 .56804 L F
.99 .862 .615 r
.42477 .56702 m .42381 .56995 L .42602 .56804 L F
0 0 .487 r
.63526 .41257 m .6337 .40855 L .63481 .40824 L F
.479 .227 .454 r
.53228 .48365 m .53479 .48536 L .5323 .48593 L F
.543 .185 .31 r
.53228 .48365 m .53503 .48362 L .53479 .48536 L F
.982 .7 .401 r
.39205 .56301 m .39351 .56148 L .39187 .56008 L F
.39205 .56301 m .39359 .56416 L .39351 .56148 L F
.291 .081 .413 r
.54572 .42171 m .54324 .42587 L .54418 .42303 L F
.664 .911 .589 r
.54572 .42171 m .5458 .42108 L .54881 .42108 L F
.54572 .42171 m .54418 .42303 L .5458 .42108 L F
.685 .693 .851 r
.3677 .69066 m .37172 .6913 L .36982 .68792 L F
.728 .606 .721 r
.36918 .69423 m .37172 .6913 L .3677 .69066 L F
.828 .872 .878 r
.37172 .6913 m .37268 .68733 L .36982 .68792 L F
.597 .133 .123 r
.61349 .39725 m .61403 .39563 L .61063 .39571 L F
.55 .314 .511 r
.7039 .29468 m .7065 .29439 L .70614 .29131 L F
.474 .864 .974 r
.70856 .28989 m .70947 .29049 L .70614 .29131 L F
.565 .512 .754 r
.7065 .29439 m .70856 .28989 L .70614 .29131 L F
.692 .96 .713 r
.68619 .34241 m .68757 .34169 L .68473 .34449 L F
.659 .911 .979 r
.68619 .34241 m .68473 .34449 L .68398 .3441 L F
.976 .839 .643 r
.7027 .27913 m .70237 .27416 L .70027 .2781 L F
.907 .777 .706 r
.69943 .28077 m .7027 .27913 L .70027 .2781 L F
.69943 .28077 m .70144 .28226 L .7027 .27913 L F
.901 .608 .107 r
.39496 .58516 m .39545 .58415 L .3947 .58285 L F
.39496 .58516 m .39594 .58717 L .39545 .58415 L F
0 0 .193 r
.43612 .53625 m .43528 .53533 L .43664 .53364 L F
.43612 .53625 m .43503 .53794 L .43528 .53533 L F
.625 .893 .987 r
.44488 .44817 m .45005 .44786 L .44718 .44915 L F
0 0 .101 r
.2306 .53898 m .23139 .53766 L .23138 .53545 L F
0 0 0 r
.2306 .53898 m .23027 .53946 L .23139 .53766 L F
.2306 .53898 m .22844 .5409 L .23027 .53946 L F
.205 0 .254 r
.3319 .55526 m .33123 .55746 L .33381 .55438 L F
.174 0 0 r
.54918 .45517 m .55008 .45537 L .54646 .45453 L F
.461 .839 .988 r
.55192 .4546 m .55008 .45537 L .54918 .45517 L F
.55192 .4546 m .55388 .45496 L .55008 .45537 L F
.101 .334 .806 r
.3778 .60109 m .37944 .6042 L .38009 .60271 L F
.108 .343 .811 r
.37944 .6042 m .38184 .60595 L .38009 .60271 L F
0 0 .487 r
.63526 .41257 m .63481 .40824 L .63594 .40989 L F
.652 .958 .759 r
.63481 .40824 m .63897 .40441 L .63694 .40792 L F
.215 0 .234 r
.63594 .40989 m .63481 .40824 L .63694 .40792 L F
.676 .708 .872 r
.29376 .65206 m .29232 .65622 L .28955 .65074 L F
.746 .614 .712 r
.59688 .43827 m .59934 .43496 L .59537 .43464 L F
0 0 0 r
.4748 .58569 m .47554 .58347 L .47591 .58342 L F
.785 .687 .756 r
.33385 .64507 m .33525 .64938 L .33106 .64854 L F
.805 .556 .562 r
.33106 .64854 m .33525 .64938 L .33475 .65161 L F
.555 .628 .88 r
.33583 .64515 m .33525 .64938 L .33385 .64507 L F
.33583 .64515 m .33794 .64877 L .33525 .64938 L F
.133 0 0 r
.33525 .64938 m .33615 .65023 L .33475 .65161 L F
.33525 .64938 m .33794 .64877 L .33615 .65023 L F
.717 .929 .961 r
.40858 .46648 m .40702 .46735 L .40762 .46553 L F
.161 0 .275 r
.40762 .46553 m .40565 .4691 L .4076 .46791 L F
.40762 .46553 m .4076 .46791 L .40645 .46437 L F
.40762 .46553 m .40645 .46437 L .40636 .46409 L F
.717 .929 .961 r
.40907 .46621 m .40858 .46648 L .40762 .46553 L F
.607 .501 .707 r
.62095 .36361 m .6241 .36335 L .62378 .36052 L F
.468 .223 .46 r
.62072 .36474 m .62443 .36517 L .62095 .36361 L F
.506 .144 .286 r
.62443 .36517 m .6241 .36335 L .62095 .36361 L F
.674 .971 .791 r
.36096 .6453 m .36185 .64373 L .36043 .64537 L F
.6 .77 .961 r
.41984 .48798 m .42197 .48989 L .42055 .48614 L F
.022 .224 .73 r
.42055 .48614 m .42197 .48989 L .42198 .48963 L F
.555 .931 .822 r
.54962 .40062 m .54788 .40222 L .54742 .40147 L F
.54962 .40062 m .55172 .40011 L .54788 .40222 L F
.871 .587 .063 r
.60989 .39376 m .60865 .38915 L .6092 .39199 L F
.673 .344 0 r
.6092 .39199 m .61063 .39571 L .60989 .39376 L F
.335 0 0 r
.29794 .65577 m .29909 .65466 L .29523 .65497 L F
.376 .841 .871 r
.30067 .65408 m .29909 .65466 L .2987 .65422 L F
.846 .889 .462 r
.2987 .65422 m .29909 .65466 L .29794 .65577 L F
.301 .048 .353 r
.68887 .29083 m .68642 .29227 L .68607 .29419 L F
.536 .885 .649 r
.65598 .33413 m .65549 .33492 L .65727 .33303 L F
.65598 .33413 m .65406 .33576 L .65549 .33492 L F
0 0 0 r
.63487 .35542 m .63277 .3566 L .63523 .35357 L F
.045 0 0 r
.33336 .51902 m .329 .52097 L .33068 .51921 L F
.614 .532 .738 r
.61726 .39387 m .61852 .3878 L .616 .3891 L F
.414 .105 .33 r
.43608 .49043 m .43541 .49259 L .43273 .49325 L F
.206 0 .242 r
.43805 .48962 m .43541 .49259 L .43608 .49043 L F
.518 .393 .65 r
.47316 .52239 m .4758 .52185 L .47482 .5193 L F
.427 .137 .367 r
.47585 .52413 m .47316 .52239 L .47386 .52503 L F
.47585 .52413 m .4758 .52185 L .47316 .52239 L F
.285 .721 .966 r
.38513 .47006 m .38501 .47091 L .38308 .46982 L F
.17 .044 .455 r
.38501 .47091 m .38513 .47006 L .38308 .46982 L F
.38501 .47091 m .38606 .47276 L .38513 .47006 L F
.775 .928 .564 r
.38285 .47509 m .38441 .47355 L .38248 .47615 L F
0 0 0 r
.38606 .47276 m .38441 .47355 L .38285 .47509 L F
.38606 .47276 m .38285 .47509 L .38317 .4739 L F
.864 .805 .791 r
.38317 .4739 m .3875 .47261 L .38606 .47276 L F
.3875 .47261 m .38983 .47191 L .38606 .47276 L F
.17 .044 .455 r
.38501 .47091 m .38455 .47292 L .38606 .47276 L F
.38455 .47292 m .38441 .47355 L .38606 .47276 L F
.898 .49 .218 r
.34221 .55737 m .34507 .5606 L .34551 .5582 L F
.458 .449 .761 r
.34551 .5582 m .34752 .55741 L .34688 .55397 L F
.231 .022 .376 r
.34507 .5606 m .34752 .55741 L .34551 .5582 L F
.485 .257 .493 r
.52027 .48997 m .52017 .49261 L .51738 .49317 L F
.569 .314 .49 r
.52305 .48975 m .52017 .49261 L .52027 .48997 L F
.908 .858 .78 r
.33516 .63265 m .33325 .63661 L .33265 .63381 L F
.989 .87 .62 r
.33265 .63381 m .33325 .63661 L .3312 .63998 L F
.556 .545 .798 r
.45143 .51635 m .45275 .51169 L .44991 .51416 L F
.45143 .51635 m .45402 .51569 L .45275 .51169 L F
.568 .938 .839 r
.53919 .42751 m .54324 .42587 L .54154 .42667 L F
.683 .165 0 r
.54154 .42667 m .54324 .42587 L .53936 .42462 L F
.853 .987 .714 r
.54418 .42303 m .54324 .42587 L .54154 .42667 L F
0 0 0 r
.54324 .42587 m .54368 .42587 L .54154 .42667 L F
.555 .464 .706 r
.54368 .42587 m .54464 .42869 L .54189 .42931 L F
0 0 0 r
.54386 .42588 m .54368 .42587 L .54274 .42763 L F
.5453 .42361 m .54368 .42587 L .54386 .42588 L F
.54324 .42587 m .54335 .42586 L .54368 .42587 L F
.54335 .42586 m .54617 .42567 L .54368 .42587 L F
.695 .965 .938 r
.38033 .62123 m .38153 .61924 L .37828 .62178 L F
.38033 .62123 m .38285 .61978 L .38153 .61924 L F
.46 .61 .912 r
.43479 .46035 m .43722 .46413 L .43837 .46257 L F
.846 .575 .528 r
.62674 .38929 m .63066 .39278 L .62672 .39214 L F
.616 .088 0 r
.62672 .39214 m .63066 .39278 L .62935 .39386 L F
.023 .553 .854 r
.63066 .39278 m .63197 .39257 L .62935 .39386 L F
.573 .587 .829 r
.46988 .47656 m .47081 .47241 L .46825 .47299 L F
.46988 .47656 m .47244 .47603 L .47081 .47241 L F
.399 .241 .548 r
.46968 .47983 m .47244 .47603 L .46988 .47656 L F
.655 .573 .751 r
.61864 .39957 m .61552 .3996 L .61768 .39859 L F
.089 .052 .517 r
.53851 .46009 m .53729 .46097 L .53676 .45764 L F
.957 .871 .711 r
.53461 .46929 m .53612 .47068 L .53623 .46733 L F
.529 .219 .385 r
.53866 .47248 m .53929 .47044 L .53612 .47068 L F
0 .172 .645 r
.53866 .47248 m .53612 .47068 L .53461 .46929 L F
.083 0 .296 r
.36787 .5652 m .36977 .56414 L .36999 .5611 L F
0 0 .106 r
.36787 .5652 m .3671 .56717 L .36977 .56414 L F
.821 .656 .679 r
.41652 .59307 m .42068 .59084 L .41804 .5908 L F
.41652 .59307 m .42019 .59455 L .42068 .59084 L F
.615 .387 .549 r
.42068 .59084 m .42184 .58623 L .41984 .58778 L F
.982 .871 .504 r
.52401 .43758 m .52389 .43847 L .52494 .43491 L F
.776 .888 .925 r
.48619 .42821 m .48249 .42851 L .48484 .42711 L F
.878 .929 .852 r
.48619 .42821 m .48741 .42403 L .48897 .42541 L F
.48619 .42821 m .48484 .42711 L .48741 .42403 L F
.404 .198 .484 r
.36909 .60347 m .36888 .60623 L .36657 .60685 L F
.394 .174 .458 r
.36888 .60623 m .36684 .60901 L .36657 .60685 L F
.36888 .60623 m .36684 .60901 L .36657 .60685 L F
0 .508 .832 r
.34056 .49613 m .34228 .49702 L .33834 .49561 L F
0 .348 .711 r
.34483 .49802 m .34228 .49702 L .34056 .49613 L F
.919 .905 .505 r
.37059 .62995 m .37101 .63166 L .37072 .63082 L F
.445 .527 .848 r
.36739 .62673 m .37072 .63082 L .36602 .62923 L F
.893 .768 .272 r
.37043 .63079 m .37101 .63166 L .37059 .62995 L F
.697 .746 .889 r
.37132 .63212 m .36826 .63149 L .37101 .63166 L F
.257 .667 .965 r
.37072 .63082 m .37101 .63166 L .36826 .63149 L F
.893 .768 .272 r
.37021 .63199 m .37101 .63166 L .37043 .63079 L F
.697 .746 .889 r
.3718 .63222 m .37132 .63212 L .37101 .63166 L F
.985 .811 .415 r
.37064 .63467 m .3718 .63222 L .37101 .63166 L F
.75 .476 .518 r
.55667 .42517 m .55261 .42706 L .55311 .42469 L F
.55667 .42517 m .55598 .42661 L .55261 .42706 L F
.064 0 .14 r
.55818 .42631 m .55667 .42517 L .5596 .42451 L F
.55818 .42631 m .55598 .42661 L .55667 .42517 L F
.457 .099 .27 r
.24884 .56784 m .25195 .56678 L .2495 .5672 L F
.282 0 0 r
.25195 .56678 m .24884 .56784 L .2495 .5672 L F
.744 .563 .648 r
.55939 .44326 m .5638 .44197 L .56356 .44141 L F
.918 .62 .464 r
.5638 .44197 m .56581 .44568 L .56356 .44141 L F
.712 .503 .605 r
.56654 .4447 m .56356 .44141 L .56581 .44568 L F
.56654 .4447 m .57055 .44293 L .56356 .44141 L F
0 0 .468 r
.47341 .53857 m .47468 .53427 L .47216 .53453 L F
.47341 .53857 m .47509 .53702 L .47468 .53427 L F
0 0 .208 r
.47355 .54151 m .47509 .53702 L .47341 .53857 L F
.718 .985 .802 r
.58728 .36866 m .5854 .37048 L .58689 .36814 L F
.714 .985 .886 r
.58689 .36814 m .5854 .37048 L .5835 .37051 L F
.836 .73 .746 r
.595 .36604 m .5981 .36977 L .59756 .36581 L F
.595 .36604 m .59459 .36909 L .5981 .36977 L F
.734 .549 .642 r
.59459 .36909 m .59762 .3716 L .5981 .36977 L F
.436 .248 .526 r
.44713 .51299 m .44954 .51265 L .44988 .50926 L F
.582 .905 .654 r
.45636 .48588 m .45765 .48498 L .45541 .48701 L F
.467 .098 .254 r
.45343 .48806 m .45636 .48588 L .45541 .48701 L F
0 0 0 r
.32888 .59047 m .32997 .58971 L .33192 .58754 L F
.602 .305 .437 r
.33124 .58928 m .33192 .58754 L .32997 .58971 L F
.33124 .58928 m .33264 .5865 L .33192 .58754 L F
.587 .428 .633 r
.54431 .45903 m .54646 .45453 L .54184 .45374 L F
.54431 .45903 m .54664 .45735 L .54646 .45453 L F
.684 .502 .634 r
.54664 .45735 m .54918 .45517 L .54646 .45453 L F
.54664 .45735 m .54918 .45517 L .54646 .45453 L F
.166 0 0 r
.43815 .59613 m .44196 .5965 L .44047 .59647 L F
0 .515 .72 r
.44196 .5965 m .44312 .59659 L .44047 .59647 L F
.44196 .5965 m .44465 .59682 L .44312 .59659 L F
.348 0 0 r
.60981 .36397 m .6142 .3634 L .61303 .3646 L F
.602 .859 .51 r
.61303 .3646 m .6142 .3634 L .61546 .36168 L F
.729 .802 .909 r
.63669 .34621 m .64044 .34668 L .6397 .34391 L F
.803 .695 .746 r
.63669 .34621 m .63789 .35019 L .64044 .34668 L F
.828 .856 .867 r
.6397 .34391 m .64044 .34668 L .64313 .34378 L F
.036 .206 .71 r
.36382 .59379 m .36607 .596 L .36461 .59201 L F
.463 .272 .536 r
.36382 .59379 m .36371 .59698 L .36607 .596 L F
.201 0 0 r
.28507 .64165 m .28585 .64029 L .28396 .6422 L F
.28507 .64165 m .28827 .64013 L .28585 .64029 L F
.29 .006 .297 r
.38135 .59722 m .3778 .60109 L .37888 .59881 L F
.998 .85 .545 r
.39393 .56946 m .3957 .56801 L .39466 .56693 L F
.39393 .56946 m .39496 .57064 L .3957 .56801 L F
.856 .896 .864 r
.49868 .41976 m .49576 .41982 L .49711 .41851 L F
.825 .898 .892 r
.50056 .41805 m .49868 .41976 L .49711 .41851 L F
.983 .895 .56 r
.73482 .32791 m .73508 .32289 L .7349 .3263 L F
.806 .852 .884 r
.51025 .41261 m .50558 .41395 L .50872 .41135 L F
.828 .892 .887 r
.51298 .41 m .51025 .41261 L .50872 .41135 L F
.733 .78 .89 r
.37685 .61354 m .37592 .61699 L .37422 .61384 L F
.37685 .61354 m .37818 .61628 L .37592 .61699 L F
.762 .692 .785 r
.31261 .56425 m .31679 .56463 L .31508 .56054 L F
.656 .193 .141 r
.31261 .56425 m .31411 .5667 L .31679 .56463 L F
.779 .7 .777 r
.31508 .56054 m .31679 .56463 L .31965 .56136 L F
.487 .275 .517 r
.31679 .56463 m .31932 .56409 L .31965 .56136 L F
0 0 0 r
.31679 .56463 m .31796 .56422 L .31932 .56409 L F
.31679 .56463 m .31411 .5667 L .31796 .56422 L F
.336 .186 .524 r
.33583 .64515 m .33385 .64507 L .33379 .64247 L F
.122 0 .105 r
.68182 .29972 m .68091 .30111 L .68403 .2982 L F
.703 .68 .825 r
.47001 .49029 m .47118 .48621 L .46838 .48621 L F
.47001 .49029 m .47266 .4899 L .47118 .48621 L F
.688 .525 .661 r
.47001 .49029 m .4699 .49309 L .47266 .4899 L F
.563 .921 .74 r
.46432 .48321 m .46655 .48161 L .46742 .48111 L F
.411 .033 .209 r
.46655 .48161 m .47006 .48051 L .46742 .48111 L F
.341 0 .186 r
.46742 .48111 m .47006 .48051 L .46968 .47983 L F
.71 .253 0 r
.72748 .2679 m .72919 .26996 L .7275 .26752 L F
.78 .552 .591 r
.69755 .32486 m .69441 .32694 L .69404 .32448 L F
.69755 .32486 m .69788 .32759 L .69441 .32694 L F
.618 .606 .817 r
.42607 .49318 m .42981 .49591 L .42859 .49253 L F
.758 .712 .809 r
.42859 .49253 m .42981 .49591 L .43273 .49325 L F
.692 .757 .902 r
.56163 .44565 m .56581 .44568 L .5638 .44197 L F
.39 .196 .493 r
.56581 .44568 m .56789 .44645 L .56654 .4447 L F
.56581 .44568 m .56471 .44768 L .56789 .44645 L F
.451 .049 .185 r
.32286 .64486 m .32416 .64318 L .32338 .64334 L F
.832 1 .813 r
.55315 .39806 m .55172 .40011 L .54962 .40062 L F
.538 .327 .542 r
.52017 .49261 m .51736 .49558 L .51738 .49317 L F
.568 0 0 r
.5885 .38771 m .58934 .38899 L .5888 .38821 L F
.513 0 0 r
.5862 .38548 m .58835 .38746 L .5885 .38771 L F
0 .255 .765 r
.5862 .38548 m .5885 .38771 L .58634 .38444 L F
.568 0 0 r
.5885 .38771 m .5888 .38821 L .58754 .38642 L F
.513 0 0 r
.58835 .38746 m .58993 .38892 L .5885 .38771 L F
.407 0 0 r
.58993 .38892 m .59114 .38984 L .5885 .38771 L F
.564 .018 0 r
.58993 .38892 m .59432 .3925 L .59156 .38988 L F
.407 0 0 r
.58993 .38892 m .59156 .38988 L .59114 .38984 L F
.717 .254 .15 r
.34105 .53635 m .34418 .5382 L .34055 .53657 L F
0 0 .369 r
.52238 .41388 m .52069 .41543 L .52247 .41439 L F
.352 .746 .985 r
.52069 .41543 m .52452 .41587 L .52247 .41439 L F
.794 .65 .703 r
.52224 .41689 m .52452 .41587 L .52069 .41543 L F
0 .141 .663 r
.52198 .41582 m .52069 .41543 L .52238 .41388 L F
.52198 .41582 m .52224 .41689 L .52069 .41543 L F
.619 .837 .983 r
.36923 .55956 m .36999 .5611 L .37279 .56025 L F
.43 .151 .387 r
.36999 .5611 m .37185 .56328 L .37279 .56025 L F
.36999 .5611 m .36977 .56414 L .37185 .56328 L F
.704 .855 .435 r
.32176 .60926 m .32157 .60934 L .32302 .60705 L F
.139 0 .031 r
.32302 .60705 m .32378 .60838 L .32417 .60577 L F
.32302 .60705 m .32157 .60934 L .32378 .60838 L F
0 0 .287 r
.43407 .56474 m .4346 .56756 L .43412 .56325 L F
.762 .624 .707 r
.55939 .44326 m .56163 .44565 L .5638 .44197 L F
.217 0 0 r
.27415 .57534 m .27656 .57566 L .27838 .57425 L F
.635 .2 .198 r
.27656 .57566 m .28085 .57427 L .27838 .57425 L F
.972 .923 .679 r
.37834 .49088 m .3773 .49279 L .3764 .49115 L F
.406 .858 .818 r
.38118 .48971 m .37834 .49088 L .3764 .49115 L F
.647 .852 .462 r
.62619 .35705 m .62378 .36052 L .62659 .35983 L F
.536 .363 .593 r
.62619 .35705 m .62659 .35983 L .62961 .35673 L F
.448 .784 .998 r
.23781 .56694 m .2405 .56676 L .24016 .56816 L F
.23781 .56694 m .2405 .56676 L .24016 .56816 L F
.574 .153 .205 r
.43964 .53086 m .43615 .52986 L .44017 .52874 L F
.509 .356 .609 r
.44232 .52742 m .43964 .53086 L .44017 .52874 L F
.612 .955 .895 r
.62584 .34055 m .6274 .33877 L .62829 .33895 L F
.588 .922 .966 r
.62584 .34055 m .62487 .33996 L .6274 .33877 L F
.596 .619 .845 r
.34502 .53154 m .34426 .53545 L .34404 .53217 L F
.34502 .53154 m .34672 .53583 L .34426 .53545 L F
.555 .071 .062 r
.34426 .53545 m .34611 .53678 L .34672 .53583 L F
.306 .032 .323 r
.33902 .58121 m .34098 .58448 L .34254 .58285 L F
.81 .546 .539 r
.42773 .51583 m .42771 .51858 L .43203 .51921 L F
.753 .516 .574 r
.42758 .52168 m .43203 .51921 L .42771 .51858 L F
.42758 .52168 m .4319 .52215 L .43203 .51921 L F
.42 .24 .529 r
.43424 .5212 m .4319 .52215 L .43203 .51921 L F
.43424 .5212 m .4319 .52215 L .43203 .51921 L F
.731 .983 .772 r
.73147 .31372 m .73452 .31164 L .73386 .31145 L F
0 .365 .819 r
.73452 .31164 m .73607 .31158 L .73386 .31145 L F
.73452 .31164 m .73671 .31302 L .73607 .31158 L F
.426 .577 .901 r
.22605 .58994 m .22904 .59391 L .23039 .59294 L F
.597 .931 .727 r
.66116 .31965 m .65899 .32151 L .66049 .31981 L F
.609 .955 .849 r
.66049 .31981 m .65899 .32151 L .65728 .32163 L F
0 0 0 r
.63487 .35542 m .63523 .35357 L .63415 .35198 L F
.77 .693 .777 r
.63438 .35017 m .63523 .35357 L .63789 .35019 L F
.666 .466 .605 r
.37051 .55346 m .3682 .55174 L .37105 .55135 L F
.37051 .55346 m .36826 .55461 L .3682 .55174 L F
.243 0 .152 r
.55358 .47656 m .55057 .47906 L .55118 .47748 L F
.055 0 .356 r
.48464 .54805 m .48432 .55075 L .48315 .55159 L F
0 0 .378 r
.48406 .55324 m .48315 .55159 L .48432 .55075 L F
.48406 .55324 m .48318 .55434 L .48315 .55159 L F
0 0 .016 r
.31965 .56136 m .3202 .55669 L .32212 .55825 L F
.584 .268 .4 r
.29599 .63167 m .29692 .62949 L .29374 .62947 L F
.29374 .62947 m .29692 .62949 L .29599 .63167 L F
.809 .967 .906 r
.63439 .41175 m .63526 .41257 L .63594 .40989 L F
0 0 .52 r
.2384 .58559 m .2379 .58627 L .23547 .58519 L F
.398 .598 .927 r
.5323 .41658 m .53437 .4193 L .53122 .41918 L F
.399 .241 .548 r
.46968 .47983 m .47254 .47942 L .47244 .47603 L F
.354 .042 .29 r
.47006 .48051 m .47254 .47942 L .46968 .47983 L F
.545 .929 .868 r
.272 .51538 m .27075 .51543 L .27292 .51418 L F
.88 .608 .523 r
.3574 .62908 m .36057 .63305 L .35893 .63264 L F
0 0 .27 r
.36112 .63145 m .36138 .63508 L .36057 .63305 L F
.963 .814 .383 r
.23213 .60218 m .23271 .60344 L .23304 .6002 L F
0 0 0 r
.2341 .59877 m .23213 .60218 L .23304 .6002 L F
.772 .847 .908 r
.53758 .40114 m .53365 .40138 L .53651 .4003 L F
.54 .704 .946 r
.53913 .39795 m .53758 .40114 L .53651 .4003 L F
.53913 .39795 m .54177 .40134 L .53758 .40114 L F
.576 .636 .873 r
.24499 .59451 m .24944 .59688 L .24808 .59532 L F
.032 .469 .879 r
.24944 .59688 m .24977 .59619 L .24808 .59532 L F
0 0 0 r
.25082 .59558 m .25047 .59668 L .24944 .59688 L F
.25253 .59397 m .25047 .59668 L .25082 .59558 L F
.829 .356 .06 r
.25047 .59668 m .25026 .59735 L .25026 .59734 L F
.032 .469 .879 r
.24944 .59688 m .25024 .59672 L .24977 .59619 L F
.25024 .59672 m .25047 .59668 L .24977 .59619 L F
.78 .352 0 r
.24977 .59619 m .25026 .59735 L .24902 .59534 L F
.107 .434 .874 r
.24808 .59532 m .24977 .59619 L .24836 .59426 L F
.78 .352 0 r
.24977 .59619 m .24902 .59534 L .24836 .59426 L F
.829 .356 .06 r
.25047 .59668 m .25026 .59734 L .24977 .59619 L F
.469 .829 .995 r
.34718 .64482 m .34417 .64553 L .34519 .64407 L F
0 0 .063 r
.34417 .64553 m .34464 .64645 L .34519 .64407 L F
.34417 .64553 m .34375 .64816 L .34464 .64645 L F
.797 .976 .906 r
.55791 .41806 m .55612 .41997 L .55374 .41981 L F
.745 .466 .508 r
.41409 .48519 m .41648 .48615 L .41736 .48358 L F
.344 .077 .357 r
.43021 .48051 m .42967 .48322 L .43254 .47961 L F
.772 .688 .771 r
.33381 .55438 m .3365 .55072 L .33442 .55173 L F
.57 .511 .75 r
.44244 .49342 m .44547 .49265 L .44445 .48868 L F
.459 .281 .551 r
.44309 .49595 m .44547 .49265 L .44244 .49342 L F
0 0 0 r
.32431 .62932 m .32145 .63251 L .32253 .63143 L F
.511 .853 .583 r
.32253 .63143 m .32145 .63251 L .31972 .63388 L F
0 0 .514 r
.43813 .56835 m .43756 .56706 L .4346 .56756 L F
.43813 .56835 m .4396 .57033 L .43756 .56706 L F
.578 .005 0 r
.62286 .39002 m .62308 .39117 L .62412 .38905 L F
.779 .7 .777 r
.31508 .56054 m .31965 .56136 L .31945 .55983 L F
0 0 .016 r
.31965 .56136 m .32 .55965 L .3202 .55669 L F
0 0 .457 r
.31935 .56391 m .32 .55965 L .31965 .56136 L F
.31936 .56388 m .32 .55965 L .31935 .56391 L F
.31932 .56409 m .32053 .56291 L .32 .55965 L F
.076 0 0 r
.31577 .56475 m .31956 .56329 L .31796 .56422 L F
.31956 .56329 m .32053 .56291 L .31951 .56343 L F
.31956 .56329 m .31951 .56343 L .31796 .56422 L F
0 0 .457 r
.31932 .56409 m .31936 .56388 L .31935 .56391 L F
.889 .468 .082 r
.37086 .52086 m .37379 .52501 L .37383 .52233 L F
.134 0 0 r
.30283 .5694 m .30629 .5681 L .30648 .56753 L F
.231 .042 .405 r
.30648 .56753 m .30864 .56707 L .30882 .56424 L F
.284 0 .157 r
.30629 .5681 m .30864 .56707 L .30648 .56753 L F
.865 .805 .789 r
.33738 .62906 m .33516 .63265 L .33626 .63073 L F
.674 .853 .447 r
.33597 .63104 m .33516 .63265 L .33738 .62906 L F
.512 .819 1 r
.25148 .59103 m .25188 .59218 L .25334 .59072 L F
0 .184 .71 r
.25188 .59218 m .25247 .59388 L .25032 .59085 L F
.814 .802 .84 r
.25032 .59085 m .24715 .59511 L .24599 .59218 L F
.687 .19 .06 r
.24833 .59154 m .25188 .59218 L .25032 .59085 L F
.512 .819 1 r
.24833 .59154 m .25188 .59218 L .25148 .59103 L F
0 .184 .71 r
.25188 .59218 m .25253 .59397 L .25247 .59388 L F
0 0 .258 r
.25188 .59218 m .25047 .59668 L .25253 .59397 L F
.778 .883 .922 r
.5288 .42535 m .53259 .42496 L .53179 .42449 L F
.753 .994 .825 r
.53378 .42256 m .53259 .42496 L .53622 .42162 L F
.745 .993 .866 r
.53378 .42256 m .53179 .42449 L .53259 .42496 L F
.692 .615 .766 r
.53259 .42496 m .53649 .42532 L .53622 .42162 L F
.444 .526 .847 r
.53259 .42496 m .53662 .42821 L .53649 .42532 L F
0 0 0 r
.66999 .32526 m .66895 .32622 L .66686 .32746 L F
.67116 .3247 m .66999 .32526 L .67268 .32428 L F
.67116 .3247 m .66895 .32622 L .66999 .32526 L F
.979 .696 .316 r
.56471 .44768 m .56499 .45052 L .56378 .44886 L F
.755 .57 .645 r
.56378 .44886 m .56789 .44645 L .56471 .44768 L F
0 0 .091 r
.33845 .60527 m .33539 .60918 L .33654 .60702 L F
0 .565 .715 r
.30901 .57427 m .30752 .57421 L .30679 .5742 L F
0 .211 .736 r
.30916 .57656 m .30752 .57421 L .30901 .57427 L F
0 .19 .716 r
.30752 .57421 m .30946 .57525 L .30888 .57424 L F
.30752 .57421 m .30888 .57424 L .30779 .57233 L F
0 .565 .715 r
.30679 .5742 m .30752 .57421 L .30486 .57413 L F
.636 .45 .615 r
.4699 .49309 m .47301 .49297 L .47266 .4899 L F
.68 .668 .831 r
.47118 .48621 m .47266 .4899 L .47472 .48643 L F
.608 .573 .79 r
.47266 .4899 m .47554 .48955 L .47472 .48643 L F
.554 .373 .59 r
.47301 .49297 m .47554 .48955 L .47266 .4899 L F
.73 .75 .868 r
.4527 .50891 m .457 .50966 L .45537 .5085 L F
.758 .749 .845 r
.45537 .5085 m .457 .50966 L .45944 .5067 L F
.908 .858 .78 r
.33516 .63265 m .33265 .63381 L .33519 .63196 L F
0 0 .425 r
.33676 .63414 m .33516 .63265 L .33597 .63104 L F
.33676 .63414 m .33552 .63546 L .33516 .63265 L F
0 0 .153 r
.60627 .36511 m .60701 .36302 L .60791 .3618 L F
.903 .749 .68 r
.60887 .36049 m .60791 .3618 L .60633 .36023 L F
0 .154 .696 r
.60633 .36023 m .60791 .3618 L .60792 .36046 L F
0 0 .153 r
.60701 .36302 m .60792 .36046 L .60791 .3618 L F
.903 .749 .68 r
.6105 .36065 m .60791 .3618 L .60887 .36049 L F
.6105 .36065 m .60981 .36397 L .60791 .3618 L F
.645 .302 .377 r
.43659 .5872 m .43911 .58935 L .44149 .58686 L F
0 0 0 r
.44149 .58686 m .43911 .58935 L .44109 .58798 L F
.126 0 .122 r
.23138 .53545 m .23393 .53453 L .23501 .53178 L F
.1 0 .054 r
.23803 .52922 m .23501 .53178 L .23701 .53052 L F
.208 0 .159 r
.23501 .53178 m .23618 .53357 L .23701 .53052 L F
.23501 .53178 m .23393 .53453 L .23618 .53357 L F
.441 .272 .554 r
.282 .54885 m .28501 .54404 L .28187 .54462 L F
.723 .815 .35 r
.7034 .34522 m .70261 .34752 L .70416 .34388 L F
.779 .843 .386 r
.70416 .34388 m .70573 .33928 L .7051 .34149 L F
.699 .81 .35 r
.7034 .34522 m .70416 .34388 L .7051 .34149 L F
0 0 0 r
.64455 .38638 m .64271 .38661 L .64199 .38644 L F
.64455 .38638 m .6455 .386 L .64271 .38661 L F
.601 .341 .495 r
.31666 .65588 m .31925 .65535 L .3187 .65806 L F
.923 .767 .669 r
.59361 .43996 m .59674 .44119 L .59688 .43827 L F
.919 .657 .526 r
.59338 .44245 m .59674 .44119 L .59361 .43996 L F
.59338 .44245 m .59689 .44405 L .59674 .44119 L F
.93 .551 .25 r
.41556 .60036 m .41344 .59933 L .413 .59646 L F
.514 .678 .939 r
.41556 .60036 m .41604 .59769 L .41344 .59933 L F
.41556 .60036 m .41834 .6001 L .41604 .59769 L F
.794 .65 .703 r
.52224 .41689 m .52475 .41866 L .52452 .41587 L F
.494 0 0 r
.52224 .41689 m .52359 .41805 L .52475 .41866 L F
.243 0 0 r
.52586 .41654 m .52452 .41587 L .52475 .41866 L F
.728 .985 .898 r
.52475 .41866 m .52359 .41805 L .52586 .41654 L F
.377 .164 .459 r
.32409 .56763 m .32377 .57024 L .32154 .57093 L F
.308 .176 .533 r
.32377 .57024 m .3214 .57381 L .32154 .57093 L F
.232 0 .222 r
.2422 .58061 m .24399 .58008 L .24519 .57755 L F
.532 .196 .344 r
.24399 .58008 m .24803 .57778 L .24519 .57755 L F
.589 .937 .766 r
.54495 .4579 m .54431 .45903 L .54214 .45872 L F
.54495 .4579 m .54664 .45735 L .54431 .45903 L F
.315 .431 .821 r
.5466 .46056 m .54431 .45903 L .54664 .45735 L F
.6 .927 .708 r
.66605 .37242 m .66413 .37409 L .66262 .37481 L F
.61 .889 .99 r
.55783 .38904 m .55969 .38682 L .56201 .38681 L F
.55783 .38904 m .55743 .388 L .55969 .38682 L F
.702 .269 .218 r
.43254 .54696 m .43687 .54647 L .43344 .54439 L F
.43254 .54696 m .43752 .54778 L .43687 .54647 L F
0 0 0 r
.70186 .34986 m .70261 .34752 L .7034 .34522 L F
.596 .384 .564 r
.23962 .53938 m .23661 .54126 L .23664 .53855 L F
.23962 .53938 m .23661 .54126 L .23664 .53855 L F
.544 .928 .844 r
.35069 .51916 m .35159 .51787 L .35198 .5178 L F
.35069 .51916 m .35031 .51856 L .35159 .51787 L F
.919 .674 .552 r
.59532 .4367 m .59688 .43827 L .59537 .43464 L F
.923 .767 .669 r
.59361 .43996 m .59688 .43827 L .59532 .4367 L F
.796 .61 .65 r
.32286 .64486 m .32686 .64235 L .32416 .64318 L F
0 0 .211 r
.47946 .57011 m .47919 .57281 L .47799 .57449 L F
.736 .712 .829 r
.53802 .41935 m .54214 .42072 L .5405 .4183 L F
.773 .833 .898 r
.5405 .4183 m .54214 .42072 L .54493 .41836 L F
.891 .969 .655 r
.43808 .48415 m .43601 .48763 L .43729 .48508 L F
0 .187 .619 r
.34678 .50999 m .34443 .50842 L .34489 .51068 L F
.712 .179 0 r
.37707 .50494 m .37273 .50207 L .37476 .50246 L F
.495 .042 .104 r
.53503 .48362 m .5388 .4829 L .5375 .48495 L F
.307 0 0 r
.5388 .4829 m .54012 .48438 L .5375 .48495 L F
.5388 .4829 m .54144 .48259 L .54012 .48438 L F
.584 .945 .855 r
.65937 .38793 m .66028 .38752 L .66271 .38602 L F
.185 0 0 r
.3505 .62506 m .35167 .62619 L .35035 .62512 L F
0 0 0 r
.25676 .52378 m .25469 .52568 L .25389 .52612 L F
.056 0 0 r
.25659 .52371 m .25664 .52373 L .25609 .52373 L F
.26109 .52357 m .25664 .52373 L .25659 .52371 L F
.046 0 0 r
.25741 .52324 m .25609 .52373 L .25851 .52374 L F
0 0 0 r
.25741 .52324 m .2568 .52379 L .25676 .52378 L F
.2568 .52379 m .25469 .52568 L .25676 .52378 L F
.056 0 0 r
.26109 .52357 m .25851 .52374 L .2567 .52373 L F
.408 0 .012 r
.26274 .5219 m .25851 .52374 L .26109 .52357 L F
.26274 .5219 m .26085 .52387 L .25851 .52374 L F
.501 .538 .827 r
.25851 .52374 m .26085 .52387 L .26076 .52376 L F
.25851 .52374 m .26076 .52376 L .25969 .52248 L F
.056 0 0 r
.2567 .52373 m .25851 .52374 L .25664 .52373 L F
.782 .693 .765 r
.57027 .44156 m .57055 .44293 L .56654 .4447 L F
0 0 0 r
.57124 .46358 m .57445 .46077 L .57242 .46183 L F
.97 .932 .657 r
.57242 .46183 m .57445 .46077 L .57439 .45763 L F
.139 0 0 r
.26186 .5169 m .26361 .51677 L .26576 .51568 L F
.192 .722 .767 r
.26361 .51677 m .26808 .5161 L .26576 .51568 L F
.637 .573 .766 r
.53622 .42162 m .53649 .42532 L .53936 .42462 L F
.445 .329 .628 r
.53649 .42532 m .53919 .42751 L .53936 .42462 L F
.53649 .42532 m .53662 .42821 L .53919 .42751 L F
.223 .079 .464 r
.71021 .30727 m .70863 .30987 L .70746 .30768 L F
.567 .52 .762 r
.36664 .687 m .3677 .69066 L .36982 .68792 L F
.565 .432 .658 r
.37203 .60093 m .37167 .60307 L .36909 .60347 L F
.478 .259 .502 r
.37131 .60562 m .36888 .60623 L .36909 .60347 L F
.565 .432 .658 r
.37203 .60093 m .37167 .60307 L .36909 .60347 L F
.513 .257 .464 r
.37167 .60307 m .37131 .60562 L .36909 .60347 L F
.643 .953 .942 r
.58574 .35474 m .58639 .35299 L .58735 .35286 L F
.58574 .35474 m .58347 .35457 L .58639 .35299 L F
.829 .99 .729 r
.27217 .57554 m .27182 .57778 L .26962 .57881 L F
.661 .603 .779 r
.40767 .50195 m .40498 .50387 L .40389 .5019 L F
0 0 0 r
.36091 .59837 m .36181 .59824 L .36371 .59698 L F
.36091 .59837 m .35975 .59957 L .36181 .59824 L F
.864 .804 .789 r
.59588 .45338 m .59906 .4538 L .59827 .45 L F
.874 .782 .757 r
.59691 .45712 m .59906 .4538 L .59588 .45338 L F
.858 .8 .794 r
.59827 .45 m .59906 .4538 L .60012 .4514 L F
0 0 0 r
.5635 .38473 m .5668 .38181 L .56406 .38269 L F
.6 .693 .908 r
.34654 .52061 m .34777 .52285 L .35031 .51856 L F
.944 .595 .193 r
.60057 .41401 m .60188 .4153 L .60234 .41762 L F
.479 .154 .337 r
.54134 .46415 m .54364 .46276 L .54386 .46598 L F
.198 0 .212 r
.54645 .46253 m .54364 .46276 L .5466 .46056 L F
.835 .684 .695 r
.33539 .60918 m .33337 .61207 L .33783 .61139 L F
.875 .67 .623 r
.33512 .61462 m .33783 .61139 L .33337 .61207 L F
.33512 .61462 m .33467 .61802 L .33783 .61139 L F
.502 .299 .537 r
.33783 .61139 m .33786 .61561 L .33942 .60949 L F
0 0 .016 r
.33783 .61139 m .33784 .61427 L .33786 .61561 L F
.33783 .61139 m .33467 .61802 L .33732 .61488 L F
.536 .244 .418 r
.33305 .61872 m .33512 .61462 L .33344 .61598 L F
.33305 .61872 m .33467 .61802 L .33512 .61462 L F
.39 .522 .87 r
.33467 .61802 m .33738 .61702 L .33784 .61427 L F
.277 0 0 r
.33673 .61612 m .33342 .61641 L .33572 .61473 L F
.33738 .61702 m .33637 .61686 L .33673 .61612 L F
.33637 .61686 m .33342 .61641 L .33673 .61612 L F
0 0 .016 r
.33784 .61381 m .33732 .61488 L .33784 .61427 L F
.33783 .61139 m .33732 .61488 L .33784 .61381 L F
.711 .389 .431 r
.67761 .34684 m .67379 .34426 L .67434 .34638 L F
.958 .893 .721 r
.74071 .31024 m .74349 .3081 L .74138 .30655 L F
.74071 .31024 m .74186 .3117 L .74349 .3081 L F
.353 .825 .884 r
.52452 .41587 m .52507 .41514 L .52247 .41439 L F
.52507 .41514 m .52437 .41483 L .52247 .41439 L F
.52452 .41587 m .52732 .41532 L .52553 .41507 L F
.243 0 0 r
.52586 .41654 m .52732 .41532 L .52452 .41587 L F
0 0 0 r
.52923 .4142 m .52732 .41532 L .52586 .41654 L F
.52923 .4142 m .52822 .4149 L .52858 .41516 L F
.52822 .4149 m .52586 .41654 L .52858 .41516 L F
.694 .167 0 r
.52518 .41512 m .52858 .41516 L .52586 .41654 L F
.201 0 0 r
.52858 .41516 m .52721 .41527 L .52883 .41533 L F
.52858 .41516 m .52883 .41533 L .531 .41542 L F
.474 .892 .904 r
.52561 .41457 m .52923 .4142 L .529 .41122 L F
.924 .932 .793 r
.52572 .41396 m .52608 .41366 L .52588 .41367 L F
.52561 .41457 m .529 .41122 L .52572 .41396 L F
.474 .892 .904 r
.52582 .41489 m .52732 .41532 L .52923 .4142 L F
.52582 .41489 m .52923 .4142 L .52561 .41457 L F
.924 .932 .793 r
.52572 .41396 m .52767 .41033 L .52407 .41278 L F
.694 .167 0 r
.52463 .41307 m .52739 .41453 L .52675 .4147 L F
.52476 .41327 m .52675 .4147 L .52586 .41494 L F
.52463 .41307 m .52675 .4147 L .52476 .41327 L F
.52463 .41307 m .52561 .41457 L .52518 .41512 L F
.52407 .41278 m .52463 .41307 L .52518 .41512 L F
.924 .932 .793 r
.52515 .41502 m .52572 .41396 L .52407 .41278 L F
.474 .892 .904 r
.52542 .41506 m .52732 .41532 L .52582 .41489 L F
.353 .825 .884 r
.52518 .41512 m .52553 .41507 L .52542 .41506 L F
.694 .167 0 r
.52739 .41453 m .52858 .41516 L .52518 .41512 L F
.52577 .41367 m .52721 .41527 L .52858 .41516 L F
.52407 .41278 m .52523 .41369 L .52577 .41367 L F
.52523 .41369 m .52721 .41527 L .52577 .41367 L F
.924 .932 .793 r
.52588 .41367 m .529 .41122 L .52767 .41033 L F
.52608 .41366 m .529 .41122 L .52588 .41367 L F
.52515 .41502 m .52561 .41457 L .52572 .41396 L F
.694 .167 0 r
.52561 .41457 m .52582 .41489 L .52554 .41499 L F
.52561 .41457 m .52554 .41499 L .52518 .41512 L F
.52582 .41489 m .52586 .41494 L .52542 .41506 L F
.52582 .41489 m .52542 .41506 L .52518 .41512 L F
.474 .892 .904 r
.52515 .41502 m .52542 .41506 L .52582 .41489 L F
.52515 .41502 m .52582 .41489 L .52561 .41457 L F
.81 .714 .759 r
.52407 .41278 m .52522 .4152 L .52437 .41483 L F
.533 .518 .785 r
.52247 .41439 m .52437 .41483 L .52407 .41278 L F
.81 .714 .759 r
.52407 .41278 m .52437 .41483 L .52305 .41426 L F
.533 .518 .785 r
.52437 .41483 m .52515 .41502 L .52407 .41278 L F
.353 .825 .884 r
.52507 .41514 m .52518 .41512 L .52515 .41502 L F
.52518 .41512 m .52542 .41506 L .52515 .41502 L F
.52452 .41587 m .52553 .41507 L .52507 .41514 L F
.81 .714 .759 r
.52217 .41554 m .52586 .41654 L .52198 .41582 L F
.52305 .41426 m .52426 .41525 L .52217 .41554 L F
.52426 .41525 m .52586 .41654 L .52217 .41554 L F
.52522 .4152 m .52586 .41654 L .52305 .41426 L F
.353 .825 .884 r
.52507 .41514 m .52515 .41502 L .52437 .41483 L F
.753 .579 .66 r
.46203 .5056 m .46776 .50616 L .46517 .50333 L F
.639 .178 .142 r
.46454 .50766 m .46776 .50616 L .46203 .5056 L F
.596 .518 .737 r
.46884 .50558 m .46517 .50333 L .46776 .50616 L F
.266 .065 .411 r
.46688 .50878 m .46776 .50616 L .46454 .50766 L F
.46688 .50878 m .46884 .50558 L .46776 .50616 L F
.031 0 .006 r
.31851 .57724 m .3214 .57381 L .32067 .57648 L F
.308 .176 .533 r
.32377 .57024 m .32376 .57332 L .3214 .57381 L F
.602 .402 .584 r
.32376 .57332 m .32067 .57648 L .3214 .57381 L F
.712 .459 .541 r
.3577 .68223 m .36232 .68112 L .35974 .68525 L F
.449 .249 .515 r
.36232 .68112 m .36229 .6845 L .35974 .68525 L F
.712 .459 .541 r
.3577 .68223 m .36229 .6845 L .36232 .68112 L F
.317 .146 .485 r
.36232 .68112 m .36393 .68212 L .36534 .68091 L F
.36232 .68112 m .36229 .6845 L .36393 .68212 L F
.504 0 0 r
.36232 .68112 m .36393 .68212 L .36229 .6845 L F
.964 .712 .505 r
.59114 .42919 m .59339 .42815 L .5905 .42682 L F
.59114 .42919 m .59315 .43101 L .59339 .42815 L F
.546 .13 .203 r
.46295 .48423 m .46655 .48161 L .46432 .48321 L F
.203 0 0 r
.46039 .4843 m .46295 .48423 L .46432 .48321 L F
.596 .496 .71 r
.46517 .50333 m .46927 .50324 L .4673 .49928 L F
.596 .518 .737 r
.46884 .50558 m .46927 .50324 L .46517 .50333 L F
.961 .937 .709 r
.3248 .65385 m .32153 .65744 L .32178 .65447 L F
.3248 .65385 m .32281 .65831 L .32153 .65744 L F
.264 0 .304 r
.30693 .64532 m .30979 .64227 L .30904 .64479 L F
.162 0 .037 r
.30607 .64785 m .30693 .64532 L .30904 .64479 L F
.112 .031 .476 r
.22045 .57294 m .22139 .57036 L .22089 .57124 L F
.688 .592 .743 r
.43092 .50213 m .43242 .50615 L .4289 .50615 L F
0 0 .459 r
.43006 .5077 m .4289 .50615 L .43242 .50615 L F
.43006 .5077 m .42941 .50923 L .4289 .50615 L F
.661 .766 .927 r
.68923 .31488 m .68411 .31437 L .68701 .31286 L F
.64 .748 .927 r
.6884 .313 m .68923 .31488 L .68701 .31286 L F
.513 .807 .999 r
.6097 .37016 m .60913 .37215 L .60784 .37165 L F
.779 .835 .372 r
.69944 .27485 m .69773 .27943 L .70027 .2781 L F
.567 .434 .66 r
.69703 .28158 m .70027 .2781 L .69773 .27943 L F
.43 .863 .759 r
.67028 .38065 m .67208 .38011 L .67434 .37892 L F
.805 .35 .156 r
.38112 .50798 m .37707 .50494 L .37907 .50573 L F
.752 .718 .82 r
.2407 .54182 m .23917 .54161 L .23969 .54203 L F
.23917 .54161 m .23661 .54126 L .23929 .54193 L F
.23917 .54161 m .23929 .54193 L .23969 .54203 L F
.58 .357 .541 r
.23929 .54193 m .23924 .54236 L .23661 .54126 L F
.752 .718 .82 r
.23969 .54203 m .23942 .54196 L .23927 .54212 L F
.23942 .54196 m .23661 .54126 L .23927 .54212 L F
0 0 .032 r
.23934 .54205 m .23932 .54211 L .23929 .54193 L F
.23932 .54211 m .23924 .54236 L .23927 .54211 L F
.23932 .54211 m .23927 .54211 L .23929 .54193 L F
0 .244 .703 r
.24137 .54173 m .2407 .54182 L .23936 .5421 L F
.23939 .5421 m .23936 .5421 L .23927 .54212 L F
.24137 .54173 m .23936 .5421 L .23939 .5421 L F
.409 .348 .678 r
.23934 .54205 m .23927 .54212 L .23924 .54236 L F
0 0 .032 r
.23949 .5416 m .23934 .54205 L .23962 .53938 L F
.409 .348 .678 r
.23949 .5416 m .23927 .54212 L .23934 .54205 L F
0 0 .032 r
.23934 .54205 m .23929 .54193 L .23962 .53938 L F
.58 .357 .541 r
.23962 .53938 m .23929 .54193 L .23661 .54126 L F
.771 .984 .736 r
.24471 .54502 m .2447 .5445 L .24526 .54328 L F
0 0 0 r
.24495 .54646 m .24471 .54502 L .24526 .54328 L F
.841 .611 .589 r
.24712 .54501 m .24526 .54328 L .24765 .54286 L F
.24712 .54501 m .24495 .54646 L .24526 .54328 L F
0 .244 .703 r
.24368 .54365 m .2447 .5445 L .24295 .54333 L F
0 .347 .817 r
.2407 .54182 m .2447 .5445 L .24471 .54502 L F
0 0 0 r
.24471 .54502 m .24332 .54726 L .24113 .54813 L F
.24495 .54646 m .24332 .54726 L .24471 .54502 L F
.526 .751 .978 r
.24526 .54328 m .2447 .5445 L .24137 .54173 L F
.987 .765 .517 r
.2442 .54441 m .24495 .54646 L .24526 .54328 L F
.24317 .5455 m .24461 .54627 L .2442 .54441 L F
.24461 .54627 m .24495 .54646 L .2442 .54441 L F
.559 .522 .77 r
.24252 .53847 m .24337 .5406 L .24137 .54173 L F
.178 0 0 r
.24526 .54328 m .24455 .54403 L .2471 .54322 L F
.24455 .54403 m .24521 .54432 L .2471 .54322 L F
0 .244 .703 r
.24137 .54173 m .24368 .54365 L .2407 .54182 L F
.24368 .54365 m .24295 .54333 L .2407 .54182 L F
.829 .449 .333 r
.24137 .54173 m .24317 .5455 L .24526 .54328 L F
.559 .522 .77 r
.24337 .5406 m .2448 .54422 L .24404 .54367 L F
.24337 .5406 m .24404 .54367 L .24137 .54173 L F
.178 0 0 r
.24455 .54403 m .24317 .5455 L .24521 .54432 L F
0 0 0 r
.6316 .39572 m .62863 .39926 L .62993 .39703 L F
.63356 .39486 m .6316 .39572 L .62993 .39703 L F
.839 .817 .334 r
.36536 .63747 m .36555 .63851 L .36558 .63666 L F
.96 .937 .711 r
.36338 .64183 m .36563 .639 L .36555 .63851 L F
0 0 0 r
.36338 .64183 m .36555 .63851 L .3645 .64075 L F
.863 .861 .836 r
.36118 .64172 m .36278 .64259 L .36481 .63949 L F
.839 .817 .334 r
.36475 .63981 m .36555 .63851 L .36536 .63747 L F
.3645 .64075 m .36463 .64048 L .36475 .63981 L F
.3645 .64075 m .36558 .63666 L .36508 .63908 L F
.863 .861 .836 r
.36485 .63923 m .36481 .63949 L .36508 .63908 L F
.36118 .64172 m .36481 .63949 L .36485 .63923 L F
.839 .817 .334 r
.36463 .64048 m .36555 .63851 L .36475 .63981 L F
.96 .937 .711 r
.36563 .639 m .36592 .63863 L .36555 .63851 L F
.892 .708 .646 r
.59704 .3634 m .595 .36604 L .59756 .36581 L F
.545 .561 .821 r
.71237 .28989 m .70997 .29272 L .70947 .29049 L F
.71224 .29017 m .70997 .29272 L .71237 .28989 L F
.71252 .28986 m .71139 .29205 L .70997 .29272 L F
.456 .811 .997 r
.71068 .28879 m .71238 .28978 L .70947 .29049 L F
.71238 .28978 m .71237 .28989 L .70947 .29049 L F
.969 .664 .275 r
.70924 .29359 m .71139 .29205 L .71034 .29342 L F
.797 .92 .92 r
.71283 .28867 m .71252 .28986 L .71068 .28879 L F
.131 .195 .663 r
.70856 .28989 m .70924 .29359 L .7108 .29131 L F
.565 .512 .754 r
.7065 .29439 m .70924 .29359 L .70856 .28989 L F
.749 .935 .948 r
.70686 .29247 m .70907 .29071 L .7108 .29131 L F
.403 0 0 r
.70907 .29071 m .71033 .29135 L .7108 .29131 L F
.815 .938 .573 r
.7108 .29131 m .71034 .29342 L .71149 .29125 L F
.815 .938 .574 r
.71034 .29342 m .71138 .29206 L .71239 .28971 L F
.71034 .29342 m .71239 .28971 L .71241 .28948 L F
.71138 .29206 m .71144 .29194 L .71283 .28867 L F
.456 .811 .997 r
.71238 .28978 m .71252 .28986 L .71237 .28989 L F
.545 .561 .821 r
.71252 .28986 m .71224 .29017 L .71237 .28989 L F
.857 .972 .866 r
.71283 .28867 m .71139 .29205 L .71252 .28986 L F
.666 .93 .971 r
.70924 .29359 m .71034 .29342 L .7108 .29131 L F
.71 .986 .853 r
.7108 .29131 m .7087 .29313 L .70924 .29359 L F
.075 .149 .638 r
.71092 .29515 m .70924 .29359 L .7108 .29131 L F
.71 .986 .853 r
.70924 .29359 m .7087 .29313 L .7108 .29131 L F
.815 .938 .574 r
.71138 .29206 m .71139 .29205 L .71144 .29194 L F
.332 .348 .727 r
.7108 .29131 m .71367 .29302 L .71092 .29515 L F
.749 .935 .948 r
.70686 .29247 m .7108 .29131 L .7087 .29313 L F
.403 0 0 r
.71033 .29135 m .71367 .29302 L .7108 .29131 L F
.815 .938 .573 r
.7108 .29131 m .71149 .29125 L .71241 .28948 L F
.71244 .28919 m .71241 .28948 L .71283 .28867 L F
.7108 .29131 m .71241 .28948 L .71244 .28919 L F
.815 .938 .574 r
.71241 .28948 m .71239 .28971 L .71283 .28867 L F
.915 .979 .718 r
.41775 .58884 m .41804 .5908 L .41984 .58778 L F
.48 .097 .235 r
.42184 .58623 m .41775 .58884 L .41984 .58778 L F
.654 .124 0 r
.34022 .5034 m .34419 .50552 L .33975 .50494 L F
.686 .973 .915 r
.67542 .36656 m .67097 .36821 L .6739 .36487 L F
.785 .772 .841 r
.67638 .36133 m .67542 .36656 L .6739 .36487 L F
.67638 .36133 m .67847 .36371 L .67542 .36656 L F
.827 .979 .885 r
.6232 .35151 m .6254 .35123 L .62695 .34927 L F
.756 .327 0 r
.40936 .59108 m .4094 .59198 L .40928 .58943 L F
.40936 .59108 m .41059 .59344 L .4094 .59198 L F
.386 .827 .694 r
.66686 .32746 m .66895 .32622 L .66549 .32799 L F
.791 .932 .926 r
.47743 .43267 m .47304 .43398 L .47469 .4324 L F
.71 .939 .96 r
.47972 .43121 m .47743 .43267 L .47469 .4324 L F
.537 .536 .802 r
.36604 .57425 m .369 .57398 L .36711 .56995 L F
.36604 .57425 m .36711 .56995 L .36668 .57291 L F
.4 .766 .994 r
.36668 .57291 m .369 .57398 L .36604 .57425 L F
.59 .301 .446 r
.36746 .58074 m .37001 .58303 L .37064 .58063 L F
.37064 .58063 m .37001 .58303 L .36746 .58074 L F
.37064 .58063 m .37001 .58303 L .36746 .58074 L F
.44 .528 .851 r
.22147 .5772 m .22172 .57318 L .22045 .57294 L F
.22147 .5772 m .22347 .5768 L .22172 .57318 L F
.199 .081 .484 r
.33942 .60949 m .34142 .60838 L .34171 .60504 L F
.417 .219 .502 r
.33942 .60949 m .34009 .61231 L .34142 .60838 L F
.33942 .60949 m .33786 .61561 L .34009 .61231 L F
.593 .849 .993 r
.63405 .34707 m .6354 .3449 L .63275 .3458 L F
.63405 .34707 m .63669 .34621 L .6354 .3449 L F
.769 .552 .604 r
.63405 .34707 m .63789 .35019 L .63669 .34621 L F
.63405 .34707 m .63438 .35017 L .63789 .35019 L F
.766 .387 .338 r
.37137 .61736 m .37608 .61952 L .36991 .61884 L F
.813 .657 .689 r
.36991 .61884 m .37608 .61952 L .37117 .62087 L F
0 0 0 r
.34227 .6517 m .34192 .6528 L .34154 .65439 L F
.072 0 .267 r
.48904 .53511 m .48849 .53759 L .48697 .53847 L F
.065 0 .449 r
.48824 .54009 m .48697 .53847 L .48849 .53759 L F
.48824 .54009 m .48708 .54133 L .48697 .53847 L F
.692 .784 .922 r
.55032 .44457 m .55442 .44534 L .55282 .44342 L F
.715 .711 .845 r
.55442 .44534 m .55701 .44403 L .55282 .44342 L F
0 0 0 r
.56852 .46662 m .57124 .46358 L .571 .46564 L F
.57242 .46183 m .571 .46564 L .57125 .46357 L F
.57085 .46699 m .571 .46564 L .57158 .46358 L F
.57059 .46821 m .571 .46564 L .57085 .46699 L F
.57125 .46357 m .571 .46564 L .57124 .46358 L F
.101 0 .211 r
.23138 .53545 m .23316 .53647 L .23393 .53453 L F
.23138 .53545 m .23139 .53766 L .23316 .53647 L F
.022 .224 .73 r
.42055 .48614 m .42198 .48963 L .42312 .48531 L F
.751 .729 .832 r
.42312 .48531 m .42198 .48963 L .42658 .4857 L F
.651 .576 .758 r
.34418 .5382 m .3426 .54107 L .34055 .53657 L F
.542 .827 .998 r
.2472 .61994 m .25078 .62021 L .24976 .61853 L F
.564 .419 .643 r
.24976 .61853 m .25325 .61916 L .25078 .62021 L F
.585 .47 .688 r
.25078 .62021 m .25325 .61916 L .24976 .61853 L F
.567 .457 .689 r
.62672 .39214 m .62756 .39467 L .62447 .39569 L F
.066 0 0 r
.62447 .39569 m .62756 .39467 L .6233 .39673 L F
.62447 .39569 m .62756 .39467 L .6233 .39673 L F
0 0 0 r
.41781 .59175 m .41652 .59307 L .41804 .5908 L F
.41781 .59175 m .41804 .5908 L .41775 .58884 L F
.989 .876 .537 r
.41034 .58046 m .40869 .58201 L .40957 .57958 L F
.41034 .58046 m .4097 .58391 L .40869 .58201 L F
.405 .806 .984 r
.3391 .65514 m .34324 .65546 L .34154 .65439 L F
.567 .92 .957 r
.344 .65407 m .34324 .65546 L .34562 .65439 L F
.425 .777 .996 r
.34154 .65439 m .34324 .65546 L .344 .65407 L F
.751 .455 .483 r
.45643 .5015 m .45863 .49971 L .45698 .4986 L F
.45643 .5015 m .45838 .50224 L .45863 .49971 L F
.806 .947 .599 r
.3079 .63621 m .30551 .63946 L .30859 .63863 L F
0 0 .465 r
.3079 .63621 m .30964 .63752 L .30874 .63552 L F
.3079 .63621 m .30859 .63863 L .30964 .63752 L F
.333 .143 .467 r
.49865 .51574 m .49855 .51842 L .49651 .5192 L F
.241 .061 .425 r
.4981 .52084 m .49651 .5192 L .49855 .51842 L F
.4981 .52084 m .49637 .52189 L .49651 .5192 L F
.951 .883 .482 r
.23153 .56417 m .23025 .5663 L .23119 .56663 L F
.664 .884 .523 r
.22933 .56852 m .23119 .56663 L .23025 .5663 L F
.961 .936 .709 r
.62957 .36222 m .63076 .36043 L .62869 .36121 L F
.358 .528 .888 r
.24499 .59451 m .24808 .59532 L .24599 .59218 L F
.957 .627 .342 r
.69404 .32448 m .6927 .32567 L .69237 .32323 L F
.69404 .32448 m .69441 .32694 L .6927 .32567 L F
0 0 0 r
.47045 .59028 m .47301 .58677 L .47222 .58899 L F
.47222 .58899 m .47301 .58677 L .4748 .58569 L F
.878 .484 .026 r
.36911 .62252 m .37112 .62604 L .36941 .62473 L F
.826 .491 0 r
.37112 .62604 m .37088 .62711 L .36941 .62473 L F
.37112 .62604 m .37185 .62852 L .37088 .62711 L F
.346 .823 .869 r
.58532 .35872 m .58949 .35795 L .58485 .3586 L F
.74 .924 .952 r
.58485 .3586 m .58949 .35795 L .59163 .35626 L F
.776 .658 .732 r
.67354 .35799 m .67407 .36015 L .67057 .35941 L F
.273 .715 .962 r
.67057 .35941 m .67407 .36015 L .6731 .35914 L F
.562 .809 .991 r
.67556 .35802 m .67407 .36015 L .67354 .35799 L F
.67556 .35802 m .67679 .3594 L .67407 .36015 L F
.454 .204 .443 r
.67407 .36015 m .67679 .3594 L .67638 .36133 L F
.998 .79 .487 r
.67638 .36133 m .6731 .35914 L .67407 .36015 L F
.995 .786 .419 r
.40124 .53786 m .40049 .53444 L .40203 .53621 L F
.747 .952 .944 r
.63461 .38284 m .63141 .38523 L .63147 .38346 L F
.462 .799 .999 r
.38591 .48281 m .38839 .48234 L .39007 .48347 L F
.469 .749 .99 r
.39092 .48155 m .39007 .48347 L .38839 .48234 L F
.39092 .48155 m .39282 .48327 L .39007 .48347 L F
.795 .891 .913 r
.42597 .46389 m .42942 .46361 L .4278 .46226 L F
.758 .867 .928 r
.4278 .46226 m .42942 .46361 L .43241 .46148 L F
.841 .673 .674 r
.34585 .51773 m .34992 .51496 L .34533 .51535 L F
.34585 .51773 m .34688 .51863 L .34992 .51496 L F
.824 .606 .607 r
.35176 .51445 m .34883 .51277 L .34992 .51496 L F
.806 .762 .812 r
.37422 .61384 m .37137 .61736 L .36919 .61544 L F
.802 .997 .856 r
.41766 .45564 m .41562 .45748 L .41589 .45562 L F
.688 .632 .787 r
.41739 .4595 m .41589 .45562 L .41562 .45748 L F
.825 .898 .892 r
.50056 .41805 m .49711 .41851 L .49928 .41703 L F
.791 .923 .924 r
.50217 .41442 m .50056 .41805 L .49928 .41703 L F
.50217 .41442 m .50365 .41559 L .50056 .41805 L F
.452 .856 .968 r
.33124 .58928 m .32997 .58971 L .32888 .59047 L F
0 0 0 r
.32892 .5932 m .33124 .58928 L .32888 .59047 L F
.754 .994 .822 r
.68912 .33929 m .68757 .34169 L .68619 .34241 L F
.68912 .33929 m .68949 .33994 L .68757 .34169 L F
0 0 0 r
.54838 .45641 m .54918 .45517 L .54664 .45735 L F
.244 0 0 r
.55192 .4546 m .54918 .45517 L .54838 .45641 L F
.088 0 .122 r
.35451 .60265 m .35671 .60209 L .35748 .60016 L F
.824 .948 .595 r
.34435 .62945 m .3423 .63292 L .34238 .63127 L F
.825 .912 .513 r
.34238 .63127 m .3423 .63292 L .34121 .63499 L F
.56 .331 .525 r
.43634 .58993 m .43911 .58935 L .43659 .5872 L F
.976 .676 .368 r
.5979 .40097 m .5995 .40228 L .59968 .40478 L F
.984 .7 .374 r
.42609 .51081 m .42635 .51502 L .42773 .51583 L F
.518 .316 .545 r
.5526 .45715 m .55574 .45392 L .55388 .45496 L F
.296 .791 .786 r
.29921 .52875 m .30095 .52811 L .30211 .52796 L F
0 0 0 r
.30211 .52796 m .30095 .52811 L .30407 .52776 L F
.932 .725 .601 r
.42439 .59487 m .42539 .59627 L .42306 .59644 L F
.981 .693 .377 r
.39075 .5158 m .38938 .51712 L .38902 .51466 L F
.39075 .5158 m .39077 .51821 L .38938 .51712 L F
.857 .68 .662 r
.43752 .54778 m .43903 .5495 L .44142 .54827 L F
.775 .321 .172 r
.4329 .55119 m .43025 .55236 L .43179 .55045 L F
.4329 .55119 m .4329 .55241 L .43025 .55236 L F
.927 .554 .15 r
.69831 .27423 m .69944 .27485 L .70027 .2781 L F
.597 .79 .973 r
.70055 .2727 m .69944 .27485 L .69831 .27423 L F
.70055 .2727 m .70237 .27416 L .69944 .27485 L F
.495 0 0 r
.2681 .52067 m .26788 .52175 L .26527 .52122 L F
0 0 0 r
.27135 .52015 m .26788 .52175 L .2681 .52067 L F
.778 .686 .762 r
.25746 .60947 m .26206 .6076 L .25966 .60557 L F
.25746 .60947 m .26001 .60983 L .26206 .6076 L F
.605 .778 .963 r
.26399 .60638 m .26206 .6076 L .25966 .60557 L F
.26399 .60638 m .26206 .6076 L .25966 .60557 L F
.054 0 .019 r
.23803 .52922 m .23928 .52848 L .24008 .52798 L F
.23803 .52922 m .23701 .53052 L .23928 .52848 L F
.79 .881 .913 r
.61343 .43404 m .61262 .43481 L .61135 .43333 L F
.61343 .43404 m .61135 .43333 L .60933 .43085 L F
.469 .745 .989 r
.61135 .43333 m .61262 .43481 L .61554 .4344 L F
1 .802 .482 r
.40998 .57424 m .40843 .57592 L .40897 .57347 L F
.40998 .57424 m .40955 .57694 L .40843 .57592 L F
.052 .218 .716 r
.53673 .43627 m .5356 .43797 L .5342 .43377 L F
.492 .813 1 r
.53413 .43686 m .5356 .43797 L .53673 .43627 L F
.777 .671 .746 r
.25325 .60293 m .25502 .60705 L .25746 .60341 L F
0 0 0 r
.73304 .3075 m .73113 .30914 L .73034 .3102 L F
.742 .926 .575 r
.53493 .41305 m .53396 .41521 L .5364 .41176 L F
.775 .982 .906 r
.53714 .40926 m .5364 .41176 L .53914 .4093 L F
.81 .938 .575 r
.53493 .41305 m .5364 .41176 L .53714 .40926 L F
.368 0 0 r
.29234 .57282 m .29672 .57062 L .2945 .57151 L F
.682 .97 .922 r
.584 .45238 m .58392 .45408 L .58514 .45264 L F
0 .258 .712 r
.25439 .62398 m .25842 .6268 L .25687 .62552 L F
.666 .116 0 r
.25842 .6268 m .25932 .62881 L .25687 .62552 L F
.25842 .6268 m .25968 .62796 L .25932 .62881 L F
.475 .28 .535 r
.2422 .58061 m .24444 .58376 L .24399 .58008 L F
.2422 .58061 m .24203 .58446 L .24444 .58376 L F
.592 .167 .205 r
.36014 .53204 m .356 .5338 L .35599 .53151 L F
.36014 .53204 m .35846 .53435 L .356 .5338 L F
.388 .805 .975 r
.35738 .5383 m .36021 .5378 L .35973 .53842 L F
.998 .811 .525 r
.36116 .53706 m .36021 .5378 L .36038 .53424 L F
.36156 .53852 m .36021 .5378 L .36116 .53706 L F
.255 0 0 r
.35567 .53976 m .35825 .53941 L .36021 .5378 L F
.533 .271 .464 r
.35825 .53941 m .35873 .53896 L .36021 .5378 L F
.095 .037 .494 r
.36038 .53424 m .36021 .5378 L .3617 .53623 L F
.533 .271 .464 r
.35873 .53896 m .36079 .53707 L .36021 .5378 L F
.36079 .53707 m .3617 .53623 L .36021 .5378 L F
.388 .805 .975 r
.35973 .53842 m .36021 .5378 L .36156 .53852 L F
.773 .387 .325 r
.36038 .53424 m .35846 .53435 L .36031 .53354 L F
.095 .037 .494 r
.36038 .53424 m .36125 .53386 L .35846 .53435 L F
.726 .638 .76 r
.36125 .53386 m .35627 .53532 L .35846 .53435 L F
.35627 .53532 m .3558 .53545 L .35846 .53435 L F
.773 .387 .325 r
.36031 .53354 m .35846 .53435 L .36014 .53204 L F
.793 .515 .517 r
.33458 .52799 m .34023 .5313 L .33862 .52785 L F
.655 .651 .834 r
.33803 .52585 m .33862 .52785 L .34118 .52517 L F
.777 .981 .907 r
.26165 .62932 m .26322 .62956 L .26511 .62777 L F
.895 .473 .124 r
.39714 .52798 m .3945 .52435 L .3961 .52552 L F
.522 .764 .985 r
.5904 .45753 m .59449 .45834 L .59294 .45653 L F
.732 .757 .872 r
.59449 .45834 m .59691 .45712 L .59294 .45653 L F
.81 .912 .909 r
.52216 .42788 m .52388 .42898 L .52576 .42728 L F
.208 0 0 r
.4564 .59499 m .458 .59459 L .46014 .59504 L F
.364 .308 .661 r
.53148 .43414 m .53413 .43686 L .5342 .43377 L F
.5 .867 .64 r
.64152 .40106 m .64489 .39867 L .64338 .39954 L F
0 0 0 r
.64489 .39867 m .64838 .39602 L .647 .39729 L F
.4 .816 .626 r
.64338 .39954 m .64489 .39867 L .647 .39729 L F
.393 .842 .923 r
.28604 .54837 m .28449 .54811 L .282 .54885 L F
0 .07 .617 r
.28501 .54404 m .28604 .54837 L .28848 .54481 L F
.28501 .54404 m .28682 .54685 L .28604 .54837 L F
.608 .942 .943 r
.28682 .54685 m .28449 .54811 L .28604 .54837 L F
.594 .076 0 r
.29107 .57513 m .29437 .57692 L .28956 .57629 L F
.539 0 0 r
.29453 .5765 m .29437 .57692 L .29107 .57513 L F
.734 .969 .933 r
.3428 .57214 m .34251 .57466 L .3416 .57393 L F
.147 .411 .855 r
.33886 .56991 m .34157 .57389 L .33788 .5716 L F
.34157 .57389 m .3416 .57393 L .34157 .57391 L F
.34157 .57389 m .34157 .57391 L .33788 .5716 L F
.469 .597 .897 r
.3428 .57214 m .3416 .57393 L .33886 .56991 L F
.505 .91 .872 r
.34095 .57376 m .34074 .57476 L .34191 .57327 L F
.34227 .5726 m .34191 .57327 L .3428 .57214 L F
.34095 .57376 m .34191 .57327 L .34227 .5726 L F
.797 .997 .859 r
.34074 .57476 m .34251 .57466 L .3428 .57214 L F
.469 .105 .265 r
.34251 .57466 m .34438 .57616 L .34476 .57373 L F
.34251 .57466 m .34158 .5768 L .34438 .57616 L F
.726 .589 .703 r
.33241 .61977 m .33121 .62292 L .32979 .62262 L F
.691 .614 .766 r
.4631 .47709 m .46545 .47347 L .46159 .47351 L F
.773 .652 .73 r
.45897 .47638 m .4631 .47709 L .46159 .47351 L F
.253 .186 .585 r
.29921 .52875 m .30049 .53017 L .30095 .52811 L F
.686 .485 .609 r
.46159 .47351 m .46545 .47347 L .46523 .47077 L F
.498 .364 .63 r
.46523 .47077 m .46713 .46689 L .46431 .46734 L F
.46523 .47077 m .46776 .47014 L .46713 .46689 L F
.672 .577 .74 r
.46545 .47347 m .46776 .47014 L .46523 .47077 L F
.322 0 0 r
.31006 .65874 m .31111 .66018 L .30814 .65996 L F
.31006 .65874 m .31237 .6587 L .31111 .66018 L F
.601 .389 .566 r
.44988 .50926 m .45275 .51169 L .4527 .50891 L F
.44988 .50926 m .44954 .51265 L .45275 .51169 L F
.525 .013 0 r
.59156 .38988 m .59432 .3925 L .593 .39131 L F
.956 .632 .226 r
.593 .39131 m .59432 .3925 L .59464 .3949 L F
.782 .765 .255 r
.69981 .35682 m .70056 .3533 L .70035 .35594 L F
0 0 .087 r
.69995 .35844 m .69981 .35682 L .70035 .35594 L F
.625 .608 .813 r
.58017 .4272 m .57662 .42492 L .57876 .42601 L F
.909 .938 .816 r
.58171 .42231 m .58017 .4272 L .57876 .42601 L F
.957 .628 .234 r
.38089 .53388 m .38269 .53785 L .38265 .53512 L F
.641 .105 0 r
.61461 .42818 m .61483 .42832 L .61474 .42752 L F
.685 .58 .732 r
.61506 .42935 m .61473 .42745 L .61474 .42752 L F
.61506 .42935 m .61688 .42386 L .61416 .42415 L F
.61506 .42935 m .61826 .42834 L .61688 .42386 L F
.118 0 0 r
.61665 .42954 m .61826 .42834 L .61506 .42935 L F
.61665 .42954 m .61506 .42935 L .61474 .42752 L F
.641 .105 0 r
.61483 .42832 m .61665 .42954 L .61474 .42752 L F
.685 .58 .732 r
.61473 .42745 m .61416 .42415 L .61474 .42752 L F
.491 .466 .758 r
.4242 .58742 m .42607 .59031 L .42365 .59023 L F
.4242 .58742 m .42365 .59023 L .42403 .58888 L F
.467 .156 .354 r
.42365 .59023 m .42541 .59281 L .42398 .59111 L F
.42365 .59023 m .42607 .59031 L .42541 .59281 L F
.42365 .59023 m .42398 .59111 L .42403 .58888 L F
.799 .343 .157 r
.41986 .49453 m .42222 .49752 L .42354 .49631 L F
.707 .217 .079 r
.42222 .49752 m .42591 .49847 L .42354 .49631 L F
.707 .918 .576 r
.54184 .45374 m .54442 .45022 L .54346 .45124 L F
.721 .972 .73 r
.54346 .45124 m .54147 .45344 L .54184 .45374 L F
.86 .71 .695 r
.42944 .49109 m .43323 .49263 L .42931 .49143 L F
.43017 .48907 m .43267 .49199 L .42944 .49109 L F
.43267 .49199 m .43323 .49263 L .42944 .49109 L F
.53 .819 .999 r
.43541 .49259 m .43393 .4913 L .43339 .49218 L F
.43512 .49266 m .43339 .49218 L .43273 .49325 L F
.43541 .49259 m .43339 .49218 L .43512 .49266 L F
.838 .938 .892 r
.40907 .46621 m .41067 .46223 L .41188 .46437 L F
.40907 .46621 m .40762 .46553 L .41067 .46223 L F
.71 .974 .924 r
.42149 .4656 m .42048 .46765 L .42292 .46656 L F
.42149 .4656 m .4184 .46743 L .42048 .46765 L F
.887 .988 .8 r
.38273 .61764 m .38285 .61978 L .38539 .61645 L F
.858 .984 .852 r
.38153 .61924 m .38285 .61978 L .38273 .61764 L F
.55 .575 .832 r
.35974 .68525 m .36229 .6845 L .3577 .68223 L F
.474 .246 .487 r
.32628 .56958 m .32409 .56763 L .32774 .56683 L F
.32628 .56958 m .32377 .57024 L .32409 .56763 L F
.531 .308 .521 r
.4701 .49587 m .47301 .49297 L .4699 .49309 L F
.523 .876 .986 r
.41763 .45374 m .41766 .45564 L .41589 .45562 L F
.41763 .45374 m .41982 .45487 L .41766 .45564 L F
.644 .66 .851 r
.46982 .50704 m .47059 .50465 L .46884 .50558 L F
.46982 .50704 m .47199 .50609 L .47059 .50465 L F
.793 .583 .618 r
.25746 .60947 m .25868 .61262 L .26001 .60983 L F
.439 .185 .43 r
.26001 .60983 m .26108 .61206 L .25868 .61262 L F
.26001 .60983 m .26108 .61206 L .25868 .61262 L F
.671 .87 .486 r
.35484 .63287 m .3574 .62908 L .35893 .63264 L F
.493 .019 .057 r
.35771 .63311 m .35893 .63264 L .35799 .63313 L F
.35695 .63275 m .35893 .63264 L .35771 .63311 L F
.762 .35 .269 r
.35893 .63264 m .36138 .63508 L .36008 .63306 L F
.344 .262 .618 r
.3574 .62908 m .35771 .63311 L .35966 .63314 L F
.762 .35 .269 r
.35893 .63264 m .36007 .63306 L .35974 .63312 L F
.344 .262 .618 r
.3574 .62908 m .35966 .63313 L .36066 .62765 L F
.35966 .63313 m .35966 .63314 L .35966 .63313 L F
.35966 .63313 m .35966 .63313 L .36066 .62765 L F
0 0 0 r
.35966 .63314 m .35682 .63373 L .36008 .63306 L F
.323 .54 .908 r
.36008 .63306 m .36138 .63508 L .36259 .63336 L F
.428 .117 .334 r
.35966 .63314 m .36008 .63306 L .36259 .63336 L F
.35966 .63314 m .36259 .63336 L .36238 .63293 L F
.762 .35 .269 r
.35974 .63312 m .36008 .63306 L .35978 .63312 L F
.35974 .63312 m .35978 .63312 L .35975 .63312 L F
.36007 .63306 m .36008 .63306 L .35974 .63312 L F
.428 .117 .334 r
.35966 .63313 m .36238 .63293 L .36094 .63001 L F
.35966 .63314 m .36238 .63293 L .35966 .63313 L F
.762 .35 .269 r
.35975 .63312 m .35978 .63312 L .35976 .63313 L F
.344 .262 .618 r
.35788 .63319 m .35774 .63351 L .35832 .63339 L F
.35771 .63319 m .35774 .63351 L .35788 .63319 L F
.35771 .63311 m .35832 .63339 L .35966 .63314 L F
0 0 0 r
.35966 .63314 m .35774 .63351 L .35682 .63373 L F
.762 .35 .269 r
.35788 .63319 m .35976 .63313 L .35682 .63373 L F
.35893 .63264 m .35976 .63313 L .35788 .63319 L F
.344 .262 .618 r
.35771 .63311 m .35771 .63319 L .35788 .63319 L F
.493 .019 .057 r
.35484 .63287 m .35695 .63275 L .35771 .63311 L F
.606 .46 .657 r
.35484 .63287 m .35774 .63351 L .35771 .63311 L F
.472 0 0 r
.35682 .63373 m .35774 .63351 L .35484 .63287 L F
.493 .019 .057 r
.35484 .63287 m .35799 .63313 L .35682 .63373 L F
.606 .46 .657 r
.35484 .63287 m .35771 .63311 L .3574 .62908 L F
.631 .345 .465 r
.43674 .4971 m .43938 .4988 L .43901 .49644 L F
.598 .322 .47 r
.43901 .49644 m .44303 .49832 L .44309 .49595 L F
.43901 .49644 m .43938 .4988 L .44303 .49832 L F
.932 .959 .768 r
.32153 .65744 m .32281 .65831 L .32065 .66165 L F
.928 .606 .41 r
.32281 .65831 m .32383 .6612 L .32065 .66165 L F
.41 .098 .323 r
.56304 .47084 m .56528 .4721 L .56254 .47239 L F
.56304 .47084 m .56576 .47009 L .56528 .4721 L F
.824 .948 .595 r
.34435 .62945 m .34238 .63127 L .34178 .62871 L F
.281 .782 .775 r
.5983 .35335 m .59677 .35356 L .59426 .3543 L F
.137 .64 .905 r
.5983 .35335 m .59931 .35298 L .59677 .35356 L F
.5983 .35335 m .60062 .35358 L .59931 .35298 L F
.943 .685 .217 r
.5489 .44042 m .54878 .43792 L .54791 .43675 L F
.682 .818 .949 r
.54668 .43119 m .54829 .43334 L .54481 .43445 L F
.409 .678 .971 r
.54668 .43119 m .54829 .43334 L .54959 .43257 L F
.971 .763 .333 r
.54812 .43487 m .54849 .43526 L .54829 .43334 L F
.54791 .43675 m .54849 .43526 L .54812 .43487 L F
.54791 .43675 m .54829 .43334 L .54959 .43257 L F
.409 .678 .971 r
.54668 .43119 m .54894 .43226 L .54891 .43187 L F
.54894 .43226 m .54959 .43257 L .54891 .43187 L F
.987 .747 .36 r
.54873 .42925 m .55018 .43192 L .54959 .43257 L F
.909 .884 .797 r
.55261 .42706 m .55018 .43192 L .54873 .42925 L F
.632 .888 .987 r
.54959 .43257 m .55095 .43051 L .54873 .42925 L F
.435 .268 .554 r
.55095 .43051 m .54891 .43187 L .54873 .42925 L F
.653 .954 .737 r
.54886 .43118 m .54891 .43187 L .55001 .43018 L F
.49 .309 .561 r
.54873 .42925 m .54891 .43187 L .54668 .43119 L F
.653 .954 .737 r
.54691 .43287 m .54891 .43187 L .54886 .43118 L F
.82 .708 .741 r
.5474 .43412 m .54959 .43257 L .54891 .43187 L F
.5466 .43532 m .54764 .43436 L .5474 .43412 L F
.54764 .43436 m .54959 .43257 L .5474 .43412 L F
.971 .763 .333 r
.54791 .43675 m .54878 .43792 L .54849 .43526 L F
.8 .685 .738 r
.5489 .44042 m .55231 .43743 L .54878 .43792 L F
.615 .678 .886 r
.55701 .44403 m .56163 .44565 L .55939 .44326 L F
.385 .193 .493 r
.35539 .68107 m .35285 .68454 L .35533 .68406 L F
0 0 0 r
.24462 .53456 m .24201 .53783 L .24255 .53627 L F
.976 .732 .501 r
.59532 .4367 m .59537 .43464 L .59348 .43328 L F
.519 .483 .756 r
.60384 .36824 m .60249 .37305 L .60106 .37125 L F
.60384 .36824 m .60506 .37234 L .60249 .37305 L F
0 0 0 r
.32431 .62932 m .32253 .63143 L .32262 .62858 L F
0 0 .17 r
.32431 .62932 m .32568 .62495 L .32679 .62904 L F
.804 .867 .425 r
.33153 .57967 m .33284 .57742 L .33518 .57752 L F
.33153 .57967 m .33294 .57558 L .33284 .57742 L F
.159 0 0 r
.33604 .4954 m .33204 .49488 L .33412 .49538 L F
.156 0 0 r
.33412 .49538 m .33834 .49561 L .33604 .4954 L F
.796 .61 .65 r
.32286 .64486 m .32652 .64516 L .32686 .64235 L F
0 0 0 r
.43361 .5055 m .43242 .50615 L .43581 .50591 L F
.43361 .5055 m .43006 .5077 L .43242 .50615 L F
.709 .531 .646 r
.30882 .56424 m .31261 .56425 L .31241 .56142 L F
.555 .414 .644 r
.31241 .56142 m .31261 .56425 L .31508 .56054 L F
.574 .021 0 r
.30998 .62702 m .30966 .62626 L .30562 .62561 L F
.246 0 0 r
.31071 .62747 m .30966 .62626 L .30998 .62702 L F
.31071 .62747 m .31218 .62589 L .30966 .62626 L F
.674 .849 .966 r
.49131 .42426 m .48897 .42541 L .48741 .42403 L F
.579 .635 .871 r
.54134 .46415 m .53729 .46097 L .53957 .45962 L F
.479 .154 .337 r
.54134 .46415 m .54386 .46598 L .53841 .46516 L F
.703 .614 .754 r
.61768 .39859 m .62149 .39874 L .61864 .39957 L F
.459 .412 .718 r
.47216 .53453 m .47468 .53427 L .47392 .53144 L F
.777 .993 .779 r
.35085 .65119 m .35471 .64818 L .35285 .65011 L F
0 0 0 r
.35616 .64742 m .35471 .64818 L .35668 .64707 L F
.35285 .65011 m .35471 .64818 L .35616 .64742 L F
.984 .727 .46 r
.32905 .5939 m .33027 .59693 L .32892 .5932 L F
.965 .662 .256 r
.32892 .5932 m .32972 .59541 L .3292 .59564 L F
.724 .699 .826 r
.3292 .59564 m .3248 .59556 L .32735 .59288 L F
0 0 0 r
.3292 .59564 m .32502 .59853 L .3248 .59556 L F
.775 .954 .632 r
.3294 .59426 m .32802 .59617 L .3292 .59564 L F
0 0 0 r
.3292 .59564 m .32685 .59777 L .32502 .59853 L F
.775 .954 .632 r
.32802 .59617 m .32685 .59777 L .3292 .59564 L F
.965 .662 .256 r
.32972 .59541 m .33027 .59693 L .3292 .59564 L F
0 .102 .612 r
.33279 .59913 m .3292 .59564 L .33027 .59693 L F
.453 .323 .613 r
.33027 .59693 m .33056 .6 L .33279 .59913 L F
.701 .444 .531 r
.32988 .62428 m .32979 .62262 L .33121 .62292 L F
.6 .378 .551 r
.32782 .62373 m .32996 .62584 L .32568 .62495 L F
.32979 .62262 m .32988 .62428 L .32782 .62373 L F
.32988 .62428 m .32996 .62584 L .32782 .62373 L F
.839 .458 .33 r
.33121 .62292 m .33132 .62345 L .32988 .62428 L F
.33132 .62345 m .33158 .62472 L .33015 .62435 L F
.33132 .62345 m .33015 .62435 L .32988 .62428 L F
.6 .378 .551 r
.32979 .62262 m .33015 .62435 L .32989 .62454 L F
.32996 .62577 m .33048 .62594 L .32996 .62584 L F
.701 .444 .531 r
.32878 .62539 m .33048 .62594 L .33015 .62435 L F
.32878 .62539 m .32979 .62262 L .32988 .62428 L F
.32878 .62539 m .33015 .62435 L .32979 .62262 L F
.839 .458 .33 r
.32988 .62428 m .33163 .625 L .32878 .62539 L F
.33158 .62472 m .33163 .625 L .32988 .62428 L F
.51 .415 .684 r
.32964 .62793 m .32568 .62495 L .33048 .62594 L F
.32964 .62793 m .32679 .62904 L .32568 .62495 L F
.75 .942 .612 r
.5323 .41658 m .53396 .41521 L .53493 .41305 L F
.459 .485 .799 r
.53396 .41521 m .53802 .41935 L .53993 .41665 L F
.483 .818 .521 r
.647 .39729 m .64838 .39602 L .65025 .39428 L F
.461 .232 .479 r
.51405 .49652 m .51427 .49889 L .51168 .4995 L F
.432 .156 .393 r
.51736 .49558 m .51427 .49889 L .51405 .49652 L F
.513 .812 .999 r
.44652 .52547 m .44739 .52363 L .44476 .52379 L F
.44652 .52547 m .4492 .52487 L .44739 .52363 L F
.956 .633 .226 r
.403 .54169 m .40214 .54229 L .40175 .54038 L F
.403 .54169 m .4034 .54405 L .40214 .54229 L F
.576 .911 .683 r
.63519 .33729 m .63677 .33556 L .63698 .33571 L F
.573 .92 .96 r
.63519 .33729 m .63414 .33673 L .63677 .33556 L F
.877 .826 .794 r
.73946 .31463 m .74009 .31364 L .7384 .31211 L F
.86 .909 .865 r
.74009 .31364 m .74071 .31024 L .7384 .31211 L F
.74009 .31364 m .74186 .3117 L .74071 .31024 L F
.346 .165 .488 r
.45379 .57411 m .45592 .57068 L .45224 .57034 L F
.669 .503 .651 r
.33673 .59369 m .34001 .59419 L .33947 .5936 L F
.33673 .59369 m .33705 .59722 L .34001 .59419 L F
.33673 .59369 m .34001 .59419 L .33947 .5936 L F
.33673 .59369 m .33705 .59722 L .34001 .59419 L F
.577 .723 .942 r
.67385 .34851 m .67527 .35046 L .67801 .34962 L F
.037 0 0 r
.53703 .4443 m .53297 .44674 L .53597 .44661 L F
.401 0 0 r
.53861 .44584 m .53703 .4443 L .53597 .44661 L F
.53861 .44584 m .53998 .44441 L .53703 .4443 L F
.604 .709 .918 r
.22456 .56092 m .22619 .55914 L .22346 .55777 L F
.22456 .56092 m .22752 .56097 L .22619 .55914 L F
0 0 .001 r
.22456 .56092 m .2252 .56197 L .22752 .56097 L F
.22456 .56092 m .22331 .56348 L .2252 .56197 L F
.95 .685 .5 r
.70105 .28431 m .70144 .28226 L .69943 .28077 L F
.27 .047 .38 r
.3187 .65806 m .31925 .65535 L .32178 .65447 L F
.8 .685 .738 r
.5489 .44042 m .55233 .44154 L .55231 .43743 L F
.647 .417 .556 r
.55032 .44457 m .55233 .44154 L .5489 .44042 L F
.55032 .44457 m .55282 .44342 L .55233 .44154 L F
.658 .57 .745 r
.55231 .43743 m .55233 .44154 L .55568 .4379 L F
.819 .747 .784 r
.55196 .46703 m .5546 .46392 L .5509 .46317 L F
.459 .227 .474 r
.55456 .46634 m .5546 .46392 L .55196 .46703 L F
.308 .111 .442 r
.55689 .46269 m .5546 .46392 L .55456 .46634 L F
.176 .378 .824 r
.63984 .38194 m .6384 .38314 L .63713 .38198 L F
.763 .581 .651 r
.73811 .31693 m .73946 .31463 L .73671 .31302 L F
.877 .826 .794 r
.73946 .31463 m .7384 .31211 L .73671 .31302 L F
.828 .892 .887 r
.51298 .41 m .50872 .41135 L .51044 .40942 L F
.718 .914 .962 r
.51534 .40859 m .51298 .41 L .51044 .40942 L F
.787 .694 .762 r
.47161 .51871 m .47482 .5193 L .47411 .51523 L F
.351 .385 .757 r
.47411 .51523 m .47482 .5193 L .47644 .5172 L F
.249 .243 .656 r
.47482 .5193 m .47725 .52056 L .47644 .5172 L F
.47482 .5193 m .4758 .52185 L .47725 .52056 L F
.909 .755 .679 r
.57662 .42492 m .57309 .42672 L .575 .42464 L F
.57662 .42492 m .57602 .42756 L .57309 .42672 L F
.433 0 0 r
.57876 .42601 m .57662 .42492 L .575 .42464 L F
.933 .943 .601 r
.35062 .63197 m .35186 .62973 L .35147 .62765 L F
.336 .131 .447 r
.49401 .52521 m .49383 .52776 L .49085 .52888 L F
.193 0 .373 r
.49383 .52776 m .49079 .53142 L .49085 .52888 L F
.588 .822 .988 r
.30979 .64227 m .31548 .6417 L .30793 .64086 L F
.978 .747 .52 r
.30904 .64479 m .30979 .64227 L .30793 .64086 L F
0 .226 .67 r
.25439 .62398 m .25597 .6216 L .25375 .62167 L F
.25439 .62398 m .25649 .62515 L .25597 .6216 L F
.25616 .62508 m .25687 .62552 L .25649 .62515 L F
.944 .93 .576 r
.25649 .62515 m .25687 .62552 L .25529 .62688 L F
0 0 0 r
.25678 .62522 m .25649 .62515 L .25529 .62688 L F
.25792 .62396 m .25649 .62515 L .25678 .62522 L F
0 .226 .67 r
.25439 .62398 m .25616 .62508 L .25649 .62515 L F
.681 .899 .975 r
.42463 .58049 m .4283 .5797 L .42714 .5772 L F
0 0 0 r
.65589 .39086 m .65937 .38793 L .65806 .38953 L F
.584 .945 .855 r
.65937 .38793 m .66271 .38602 L .66174 .38762 L F
0 0 0 r
.65806 .38953 m .65937 .38793 L .66174 .38762 L F
.348 .161 .481 r
.34885 .52705 m .35286 .52383 L .35075 .52415 L F
.34885 .52705 m .35298 .52684 L .35286 .52383 L F
.671 .416 .526 r
.35008 .52962 m .35298 .52684 L .34885 .52705 L F
0 0 0 r
.69008 .37177 m .69204 .37122 L .68941 .37235 L F
.69008 .37177 m .69303 .37056 L .69204 .37122 L F
.69303 .37056 m .69353 .37035 L .69204 .37122 L F
.615 .921 .668 r
.69204 .37122 m .69353 .37035 L .69527 .36863 L F
.69204 .37122 m .69527 .36863 L .6943 .36962 L F
.419 .814 .591 r
.69112 .37184 m .69204 .37122 L .6943 .36962 L F
0 0 0 r
.68819 .37334 m .69204 .37122 L .69072 .37212 L F
.419 .814 .591 r
.69072 .37212 m .69204 .37122 L .69112 .37184 L F
.674 .277 .285 r
.60981 .36397 m .60627 .36511 L .60791 .3618 L F
.60981 .36397 m .61022 .36548 L .60627 .36511 L F
.348 0 0 r
.60981 .36397 m .61303 .3646 L .61022 .36548 L F
.743 .845 .927 r
.42967 .48322 m .43378 .48322 L .43244 .4826 L F
.73 .66 .78 r
.43254 .47961 m .43378 .48322 L .43696 .48143 L F
.086 .244 .731 r
.43254 .47961 m .43488 .48151 L .43378 .48322 L F
.597 .914 .977 r
.43488 .48151 m .43244 .4826 L .43378 .48322 L F
0 0 0 r
.29207 .54212 m .29077 .54388 L .29325 .54104 L F
.701 .878 .964 r
.42653 .45324 m .42452 .45471 L .4197 .45459 L F
0 0 0 r
.53802 .41935 m .54072 .41481 L .53993 .41665 L F
.692 .319 .335 r
.31298 .5763 m .31099 .57905 L .30916 .57656 L F
.676 .299 .324 r
.31513 .57865 m .31298 .5763 L .31544 .57708 L F
.31513 .57865 m .31099 .57905 L .31298 .5763 L F
.428 .87 .827 r
.43349 .45034 m .42849 .45183 L .43219 .45033 L F
.39 .813 .969 r
.43454 .44922 m .43349 .45034 L .43219 .45033 L F
.43454 .44922 m .43597 .44985 L .43349 .45034 L F
0 0 .296 r
.48202 .56216 m .48079 .5611 L .48296 .55976 L F
.48202 .56216 m .4807 .56367 L .48079 .5611 L F
.604 .426 .615 r
.33693 .55989 m .33635 .56378 L .33302 .56416 L F
.447 .203 .449 r
.33635 .56378 m .33328 .56685 L .33302 .56416 L F
.254 0 .264 r
.35811 .67794 m .35539 .68107 L .35744 .68068 L F
.35811 .67794 m .35539 .68107 L .35744 .68068 L F
.66 .923 .975 r
.34536 .61955 m .34155 .62014 L .34368 .61907 L F
.254 .764 .852 r
.34642 .61898 m .34536 .61955 L .34368 .61907 L F
1 .814 .507 r
.34538 .61885 m .34642 .61898 L .34541 .61813 L F
.254 .764 .852 r
.34642 .61898 m .34767 .61913 L .34536 .61955 L F
.34642 .61898 m .34536 .61955 L .34368 .61907 L F
.34642 .61898 m .34795 .61908 L .34536 .61955 L F
1 .814 .507 r
.34531 .62085 m .34642 .61898 L .34538 .61885 L F
.254 .764 .852 r
.34642 .61898 m .34795 .61908 L .34767 .61913 L F
.391 0 0 r
.61704 .36558 m .61993 .36582 L .62072 .36474 L F
.61993 .36582 m .62443 .36517 L .62072 .36474 L F
.828 .856 .867 r
.6397 .34391 m .64313 .34378 L .64212 .34239 L F
.806 .926 .915 r
.64414 .34063 m .64212 .34239 L .64313 .34378 L F
.897 .692 .617 r
.60012 .4514 m .59832 .4473 L .59827 .45 L F
.067 .555 .894 r
.2965 .66109 m .30062 .6626 L .29973 .66024 L F
.423 .526 .858 r
.29973 .66024 m .30062 .6626 L .30164 .66008 L F
.605 .736 .937 r
.30062 .6626 m .30373 .66202 L .30164 .66008 L F
.67 .975 .877 r
.35328 .6449 m .35158 .64632 L .34877 .64696 L F
.36 .066 .324 r
.56852 .46662 m .56836 .46926 L .56576 .47009 L F
.195 .001 .375 r
.56852 .46662 m .57059 .46821 L .56836 .46926 L F
.56852 .46662 m .571 .46564 L .57059 .46821 L F
.153 0 0 r
.68129 .32176 m .68074 .3221 L .67778 .32233 L F
.126 0 0 r
.68074 .3221 m .67931 .32214 L .67778 .32233 L F
.153 0 0 r
.68129 .32176 m .67778 .32233 L .67885 .32135 L F
.126 0 0 r
.67931 .32214 m .67661 .32222 L .67778 .32233 L F
.011 0 0 r
.6763 .32251 m .67778 .32233 L .67511 .32306 L F
.67885 .32135 m .67778 .32233 L .6763 .32251 L F
.296 0 .093 r
.43873 .52511 m .44088 .52461 L .44238 .52222 L F
.54 .14 .231 r
.44238 .52222 m .44088 .52461 L .44476 .52379 L F
.643 .311 .394 r
.32774 .56683 m .3297 .5695 L .32628 .56958 L F
.692 .596 .744 r
.3267 .51893 m .32863 .5204 L .32873 .51534 L F
.27 .266 .671 r
.3267 .51893 m .329 .52097 L .32863 .5204 L F
0 0 .461 r
.32873 .51534 m .32863 .5204 L .33032 .51658 L F
.47 .464 .769 r
.329 .52097 m .33032 .51658 L .32863 .5204 L F
.898 .538 .351 r
.32777 .49985 m .32603 .50152 L .32612 .49818 L F
.32777 .49985 m .32926 .50326 L .32603 .50152 L F
.723 .973 .734 r
.23387 .5796 m .23116 .58233 L .23259 .58127 L F
.782 .693 .765 r
.57027 .44156 m .56654 .4447 L .57056 .44384 L F
.964 .699 .484 r
.56854 .44279 m .57056 .44384 L .57027 .44156 L F
.495 .516 .808 r
.57035 .44673 m .57283 .44756 L .57195 .44363 L F
.366 .024 .246 r
.57231 .4435 m .57199 .44319 L .56854 .44279 L F
.57199 .44319 m .57027 .44156 L .56881 .4426 L F
.57199 .44319 m .56881 .4426 L .56854 .44279 L F
.455 .612 .915 r
.57195 .44363 m .57585 .44509 L .57517 .44378 L F
.366 .024 .246 r
.57231 .44325 m .57283 .44062 L .57027 .44156 L F
.455 .612 .915 r
.57195 .44363 m .57282 .44367 L .57241 .44327 L F
.57282 .44367 m .57517 .44378 L .57275 .44333 L F
.57282 .44367 m .57275 .44333 L .57241 .44327 L F
.366 .024 .246 r
.57272 .44321 m .57283 .44062 L .57231 .44325 L F
.5727 .44357 m .57239 .44331 L .57231 .4435 L F
.403 .63 .946 r
.57251 .44336 m .5727 .44357 L .57231 .4435 L F
.455 .612 .915 r
.57241 .44327 m .57268 .44305 L .57209 .44407 L F
.866 .645 .112 r
.57269 .44301 m .57274 .44285 L .57272 .44321 L F
.57207 .43846 m .57272 .44321 L .57258 .44261 L F
.455 .612 .915 r
.57282 .44294 m .57477 .443 L .57419 .44187 L F
.57245 .44323 m .57299 .44318 L .57282 .44294 L F
.57299 .44318 m .57477 .443 L .57282 .44294 L F
.366 .024 .246 r
.5727 .44357 m .57272 .44321 L .57231 .44325 L F
.455 .612 .915 r
.57241 .44327 m .57517 .44378 L .57477 .443 L F
.57241 .44327 m .57477 .443 L .57245 .44323 L F
.925 .751 .647 r
.57258 .44261 m .5727 .44357 L .57072 .43996 L F
.455 .612 .915 r
.57265 .44317 m .57419 .44187 L .57254 .4436 L F
.866 .645 .112 r
.57265 .44317 m .57272 .44321 L .5727 .44357 L F
.57258 .44261 m .57268 .44305 L .57265 .44317 L F
.57268 .44305 m .57272 .44321 L .57265 .44317 L F
.455 .612 .915 r
.57268 .44305 m .57282 .44294 L .57265 .44317 L F
.57282 .44294 m .57419 .44187 L .57265 .44317 L F
.925 .751 .647 r
.57072 .43996 m .57255 .4433 L .57009 .44066 L F
.57255 .4433 m .5727 .44357 L .57251 .44336 L F
.57255 .4433 m .57251 .44336 L .57009 .44066 L F
.57207 .43846 m .57258 .44261 L .57072 .43996 L F
.455 .612 .915 r
.57268 .44305 m .57254 .4436 L .57209 .44407 L F
.866 .645 .112 r
.57207 .43846 m .57283 .44062 L .57274 .44285 L F
.57207 .43846 m .57274 .44285 L .57269 .44301 L F
.366 .024 .246 r
.57239 .44331 m .57027 .44156 L .57231 .4435 L F
.403 .63 .946 r
.57009 .44066 m .57251 .44336 L .56854 .44279 L F
.57251 .44336 m .57231 .4435 L .56854 .44279 L F
.455 .612 .915 r
.57195 .44363 m .57241 .44327 L .57222 .44357 L F
.57188 .44381 m .57222 .44357 L .57157 .44462 L F
.58 .574 .812 r
.57195 .44363 m .57283 .44756 L .57585 .44509 L F
.455 .612 .915 r
.57195 .44363 m .57222 .44357 L .57188 .44381 L F
.57241 .44327 m .57209 .44407 L .57157 .44462 L F
.386 .184 .479 r
.41664 .50418 m .41445 .50188 L .41682 .50168 L F
.41664 .50418 m .41578 .50501 L .41445 .50188 L F
.664 .832 .964 r
.28791 .51219 m .28386 .51188 L .28618 .51081 L F
.28618 .51081 m .28386 .51188 L .28791 .51219 L F
.076 .226 .716 r
.28791 .51219 m .28855 .50978 L .28618 .51081 L F
.28791 .51219 m .2903 .51444 L .28855 .50978 L F
.91 .509 .128 r
.42381 .56995 m .42624 .57367 L .42555 .57117 L F
.783 .416 .363 r
.42555 .57117 m .42624 .57367 L .42975 .57391 L F
.557 .597 .849 r
.34924 .53429 m .34672 .53583 L .34502 .53154 L F
0 0 0 r
.34924 .53429 m .34611 .53678 L .34672 .53583 L F
.898 .717 .648 r
.26548 .6098 m .26514 .61322 L .264 .61265 L F
.596 .43 .627 r
.26548 .6098 m .26807 .60652 L .26399 .60638 L F
.26548 .6098 m .26846 .60928 L .26807 .60652 L F
.541 .268 .45 r
.26548 .6098 m .26846 .60928 L .26769 .61197 L F
.394 .266 .586 r
.26769 .61197 m .26514 .61322 L .26548 .6098 L F
.534 .268 .458 r
.264 .61265 m .26769 .61197 L .26548 .6098 L F
.596 .43 .627 r
.26807 .60652 m .26846 .60928 L .26548 .6098 L F
.541 .268 .45 r
.26548 .6098 m .26846 .60928 L .26769 .61197 L F
0 0 0 r
.29004 .53586 m .28986 .53539 L .2916 .53381 L F
.29004 .53586 m .28776 .53671 L .28986 .53539 L F
.676 .187 .081 r
.43674 .49804 m .43938 .4988 L .43674 .4971 L F
.785 .525 0 r
.413 .59646 m .41022 .59677 L .41151 .59596 L F
.413 .59646 m .41271 .59627 L .41022 .59677 L F
.413 .59646 m .41344 .59933 L .41271 .59627 L F
.311 0 0 r
.30377 .64365 m .30305 .64222 L .30265 .64526 L F
.30377 .64365 m .30574 .64202 L .30305 .64222 L F
.755 .99 .783 r
.30551 .63946 m .30305 .64222 L .30574 .64202 L F
.761 .251 0 r
.6036 .35912 m .60633 .36023 L .60491 .36089 L F
0 .154 .696 r
.60633 .36023 m .60792 .36046 L .60491 .36089 L F
.299 .083 .408 r
.50106 .5124 m .50074 .51488 L .49865 .51574 L F
.256 .084 .446 r
.5004 .51733 m .49865 .51574 L .50074 .51488 L F
.5004 .51733 m .49855 .51842 L .49865 .51574 L F
.933 .953 .771 r
.38543 .61289 m .38539 .61645 L .3875 .61287 L F
.935 .953 .766 r
.38273 .61764 m .38539 .61645 L .38543 .61289 L F
.385 .456 .811 r
.33194 .50992 m .33231 .50844 L .33212 .50741 L F
.33178 .51223 m .33231 .50844 L .33194 .50992 L F
.654 .099 0 r
.33582 .50917 m .33255 .50747 L .33231 .50844 L F
.767 .35 0 r
.33212 .50741 m .33231 .50844 L .33107 .50669 L F
.654 .099 0 r
.33255 .50747 m .33107 .50669 L .33231 .50844 L F
.933 .953 .771 r
.38543 .61289 m .3875 .61287 L .38612 .61194 L F
.889 .876 .44 r
.3875 .61287 m .38829 .60861 L .38612 .61194 L F
.999 .803 .465 r
.4097 .58391 m .40814 .58523 L .40869 .58201 L F
.4097 .58391 m .40937 .58668 L .40814 .58523 L F
.597 .452 .655 r
.56194 .42125 m .5596 .42451 L .55951 .42197 L F
.649 .579 .763 r
.33864 .55837 m .33635 .56378 L .33693 .55989 L F
.416 .314 .63 r
.35419 .60481 m .3517 .60497 L .3512 .60391 L F
.434 .162 .4 r
.28061 .5793 m .27865 .5775 L .28126 .57695 L F
.28061 .5793 m .27807 .57994 L .27865 .5775 L F
.708 .861 .955 r
.37277 .49856 m .36869 .4987 L .37082 .49721 L F
.767 .862 .92 r
.3759 .49636 m .37277 .49856 L .37082 .49721 L F
.583 .499 .726 r
.36664 .687 m .36982 .68792 L .3687 .68381 L F
.195 .337 .781 r
.61234 .3938 m .61063 .39571 L .6092 .39199 L F
0 .324 .771 r
.61146 .39564 m .61063 .39571 L .61234 .3938 L F
.61146 .39564 m .61349 .39725 L .61063 .39571 L F
0 0 0 r
.46838 .48621 m .4668 .48706 L .46435 .48809 L F
.641 .938 .963 r
.47118 .48621 m .4668 .48706 L .46838 .48621 L F
.639 .178 .142 r
.46454 .50766 m .46203 .5056 L .46414 .50993 L F
0 0 .378 r
.46462 .50917 m .46454 .50766 L .46414 .50993 L F
.827 1 .823 r
.45199 .49966 m .45146 .50181 L .45405 .50136 L F
.45199 .49966 m .45025 .50173 L .45146 .50181 L F
.743 .934 .95 r
.6233 .39673 m .62149 .39874 L .62236 .39608 L F
.6233 .39673 m .62149 .39874 L .62236 .39608 L F
0 .061 .574 r
.60682 .42824 m .60933 .43085 L .60838 .42971 L F
0 .055 .619 r
.60933 .43085 m .6105 .43135 L .60838 .42971 L F
.60933 .43085 m .61135 .43333 L .6105 .43135 L F
.526 .029 .018 r
.68293 .34524 m .68051 .34375 L .68037 .34621 L F
.68293 .34524 m .68398 .3441 L .68051 .34375 L F
.791 .55 .573 r
.7084 .29602 m .70924 .29359 L .71061 .29535 L F
.301 .276 .664 r
.70924 .29359 m .7084 .29602 L .71061 .29535 L F
.89 .874 .815 r
.54342 .43296 m .54481 .43445 L .54216 .43806 L F
.489 .452 .743 r
.47364 .5286 m .47585 .52413 L .47386 .52503 L F
.368 .062 .309 r
.54442 .45022 m .54752 .44732 L .54591 .44765 L F
.774 .997 .842 r
.54748 .44638 m .54752 .44732 L .55032 .44457 L F
.811 .997 .774 r
.54591 .44765 m .54752 .44732 L .54748 .44638 L F
.807 .95 .914 r
.52886 .406 m .52838 .40699 L .53088 .4047 L F
0 0 0 r
.54993 .46018 m .5526 .45715 L .55191 .45879 L F
.305 .422 .816 r
.55512 .45612 m .5526 .45715 L .55192 .4546 L F
0 0 0 r
.55191 .45879 m .5526 .45715 L .55512 .45612 L F
.882 .679 .624 r
.59684 .44674 m .59856 .44454 L .59689 .44405 L F
.59684 .44674 m .59832 .4473 L .59856 .44454 L F
.714 .887 .96 r
.46527 .44119 m .46135 .44137 L .46377 .43999 L F
.824 .908 .897 r
.46644 .43743 m .46527 .44119 L .46377 .43999 L F
.46644 .43743 m .46801 .43876 L .46527 .44119 L F
.541 .681 .93 r
.28551 .65871 m .29009 .66083 L .28845 .65954 L F
.581 .821 .99 r
.28845 .65954 m .29009 .66083 L .29245 .66 L F
.796 .995 .869 r
.69037 .33752 m .68949 .33994 L .68912 .33929 L F
.69037 .33752 m .69256 .33716 L .68949 .33994 L F
.993 .743 .425 r
.43402 .55811 m .43282 .55805 L .43312 .55775 L F
.43402 .55811 m .43397 .56074 L .43282 .55805 L F
.806 .762 .812 r
.37422 .61384 m .36919 .61544 L .37293 .61206 L F
.438 .698 .975 r
.37504 .61181 m .37422 .61384 L .37293 .61206 L F
.37504 .61181 m .37685 .61354 L .37422 .61384 L F
.626 .586 .789 r
.3188 .61407 m .32136 .61149 L .31978 .6118 L F
.584 .945 .859 r
.67252 .35775 m .67354 .35799 L .67057 .35941 L F
.009 .58 .77 r
.67556 .35802 m .67354 .35799 L .67252 .35775 L F
.643 .447 .604 r
.34281 .51781 m .34533 .51535 L .34307 .5159 L F
.786 .718 .788 r
.54838 .40775 m .55256 .40803 L .55106 .40447 L F
.792 .696 .758 r
.54838 .40775 m .54991 .41177 L .55256 .40803 L F
.641 .647 .84 r
.55106 .40447 m .55256 .40803 L .55497 .40715 L F
.273 .096 .45 r
.46086 .51658 m .46396 .51497 L .46324 .51176 L F
.325 .196 .547 r
.46341 .5175 m .46086 .51658 L .46003 .51816 L F
.797 .641 .689 r
.33475 .65161 m .33631 .65407 L .33095 .65514 L F
.062 0 0 r
.33095 .65514 m .33631 .65407 L .33288 .65532 L F
.714 .809 .924 r
.33615 .65023 m .33631 .65407 L .33475 .65161 L F
.33615 .65023 m .33823 .65328 L .33631 .65407 L F
0 0 0 r
.33631 .65407 m .33531 .65546 L .33288 .65532 L F
.33631 .65407 m .33823 .65328 L .3354 .65542 L F
.33531 .65546 m .3354 .65542 L .33524 .65555 L F
.33631 .65407 m .3354 .65542 L .33531 .65546 L F
.44 .816 .566 r
.3355 .65535 m .33823 .65328 L .3383 .65319 L F
.33524 .65555 m .3354 .65542 L .3355 .65535 L F
.3354 .65542 m .33823 .65328 L .3355 .65535 L F
.455 .837 .987 r
.33383 .65519 m .33564 .65524 L .33628 .65452 L F
.44 .816 .566 r
.33524 .65555 m .3383 .65319 L .3382 .6553 L F
.455 .837 .987 r
.33564 .65524 m .33594 .65525 L .33612 .65486 L F
.33564 .65524 m .33612 .65486 L .33628 .65452 L F
.33594 .65525 m .33762 .65529 L .33695 .65491 L F
.33594 .65525 m .33695 .65491 L .33628 .65452 L F
.33762 .65529 m .3382 .6553 L .33808 .65526 L F
.33762 .65529 m .33808 .65526 L .33628 .65452 L F
0 0 0 r
.33531 .65546 m .33524 .65555 L .33472 .6555 L F
.33531 .65546 m .33472 .6555 L .33288 .65532 L F
.33565 .57268 m .33619 .57246 L .33788 .5716 L F
.33565 .57268 m .33428 .57412 L .33619 .57246 L F
.685 .782 .924 r
.45454 .47278 m .45368 .47004 L .45086 .47197 L F
.73 .949 .95 r
.45697 .46957 m .45368 .47004 L .45454 .47278 L F
.672 .57 .732 r
.45454 .47278 m .45889 .47322 L .45697 .46957 L F
.678 .53 .677 r
.45897 .47638 m .45889 .47322 L .45454 .47278 L F
.001 .379 .842 r
.33106 .64854 m .32722 .64563 L .33018 .6449 L F
.537 .456 .711 r
.30338 .6286 m .30562 .62561 L .30302 .62712 L F
.30338 .6286 m .30563 .62818 L .30562 .62561 L F
.673 .662 .831 r
.54855 .46631 m .55196 .46703 L .5509 .46317 L F
.653 .184 .127 r
.55026 .46805 m .55196 .46703 L .54855 .46631 L F
.721 .706 .835 r
.54516 .46672 m .54855 .46631 L .54758 .46402 L F
.647 .333 .425 r
.54792 .46908 m .54855 .46631 L .54516 .46672 L F
.673 .662 .831 r
.54855 .46631 m .5509 .46317 L .54758 .46402 L F
.653 .184 .127 r
.55063 .46843 m .54855 .46631 L .54792 .46908 L F
.607 .44 .629 r
.55162 .46572 m .5493 .46783 L .54685 .46521 L F
.5493 .46783 m .54792 .46908 L .54745 .46739 L F
.5493 .46783 m .54745 .46739 L .54685 .46521 L F
.653 .184 .127 r
.55063 .46843 m .55086 .4682 L .55026 .46805 L F
.55086 .4682 m .55196 .46703 L .55026 .46805 L F
.915 .963 .798 r
.55689 .46269 m .55406 .46545 L .55523 .46359 L F
.535 .821 .998 r
.55244 .46589 m .55196 .46703 L .55162 .46572 L F
.55399 .46622 m .55271 .46673 L .55244 .46589 L F
.55271 .46673 m .55196 .46703 L .55244 .46589 L F
0 0 .476 r
.55175 .46386 m .55173 .46398 L .5509 .46317 L F
.667 .54 .7 r
.54993 .46018 m .5509 .46317 L .54758 .46402 L F
.961 .636 .25 r
.54963 .46171 m .5509 .46317 L .54993 .46018 L F
.54963 .46171 m .54993 .46018 L .55191 .45879 L F
.788 .978 .7 r
.54992 .46019 m .54963 .46171 L .55191 .45879 L F
0 .159 .698 r
.54992 .46019 m .55175 .46386 L .54963 .46171 L F
.31 .797 .886 r
.55181 .46352 m .55175 .46386 L .5511 .46359 L F
.528 .582 .853 r
.55439 .46327 m .55175 .46386 L .54992 .46019 L F
.31 .797 .886 r
.55439 .46327 m .55175 .46386 L .55181 .46352 L F
0 0 .476 r
.55175 .46386 m .55186 .4641 L .55173 .46398 L F
.535 .821 .998 r
.55456 .46634 m .55397 .4665 L .55399 .46622 L F
.55456 .46634 m .55162 .46572 L .55294 .46654 L F
0 0 .476 r
.55186 .4641 m .55294 .46654 L .55231 .4655 L F
.55186 .4641 m .55231 .4655 L .5509 .46317 L F
.915 .963 .798 r
.55406 .46545 m .55294 .46654 L .55409 .46506 L F
.55406 .46545 m .55409 .46506 L .55523 .46359 L F
.535 .821 .998 r
.55397 .4665 m .55196 .46703 L .55399 .46622 L F
.944 .924 .562 r
.55063 .46843 m .55196 .46703 L .55162 .46572 L F
.396 .841 .731 r
.54838 .45641 m .54664 .45735 L .54495 .4579 L F
.732 .56 .658 r
.43345 .48943 m .43729 .48508 L .43601 .48763 L F
.386 .501 .853 r
.27629 .63756 m .27887 .64113 L .27455 .63952 L F
.746 .292 0 r
.27833 .64061 m .27887 .64113 L .27629 .63756 L F
.691 .613 .765 r
.28006 .64228 m .27455 .63952 L .27887 .64113 L F
.746 .292 0 r
.27981 .64283 m .27887 .64113 L .27833 .64061 L F
.691 .613 .765 r
.28015 .64233 m .28006 .64228 L .27887 .64113 L F
.755 .297 0 r
.27981 .64283 m .28015 .64233 L .27887 .64113 L F
.459 .183 .407 r
.35925 .59005 m .35854 .59274 L .35604 .59308 L F
.279 0 .101 r
.36214 .59003 m .35854 .59274 L .35925 .59005 L F
.569 .314 .49 r
.52305 .48975 m .52296 .4922 L .52017 .49261 L F
.614 .38 .539 r
.52585 .48936 m .52296 .4922 L .52305 .48975 L F
0 0 .283 r
.48678 .5439 m .48645 .5465 L .48464 .54805 L F
.015 0 .374 r
.48645 .5465 m .48432 .55075 L .48464 .54805 L F
0 0 0 r
.31366 .64536 m .31009 .64866 L .31198 .64732 L F
.3156 .64176 m .31366 .64536 L .31444 .64395 L F
.645 .867 .496 r
.31377 .64487 m .31366 .64536 L .31198 .64732 L F
.831 .792 .814 r
.31444 .64395 m .31198 .64732 L .30945 .64632 L F
.795 .506 .499 r
.31871 .64937 m .31871 .64727 L .31327 .6455 L F
.31326 .64551 m .31327 .6455 L .31324 .64549 L F
.31871 .64937 m .31327 .6455 L .31326 .64551 L F
.645 .867 .496 r
.31444 .64395 m .31431 .64418 L .31377 .64487 L F
.31431 .64418 m .31366 .64536 L .31377 .64487 L F
.361 .264 .608 r
.27029 .60868 m .26846 .60928 L .26807 .60652 L F
.26807 .60652 m .26846 .60928 L .27029 .60868 L F
.27029 .60868 m .26846 .60928 L .26807 .60652 L F
.873 .823 .796 r
.24774 .57978 m .25017 .58113 L .25204 .57811 L F
.905 .798 .731 r
.24774 .57978 m .24855 .58321 L .25017 .58113 L F
.727 .641 .762 r
.40305 .49128 m .40655 .49248 L .40617 .49102 L F
.712 .182 0 r
.40068 .48645 m .40436 .49005 L .40328 .48799 L F
.40436 .49005 m .40437 .49005 L .40328 .48799 L F
.063 0 .344 r
.40328 .48799 m .40437 .49005 L .40536 .48788 L F
.727 .641 .762 r
.40437 .49005 m .40617 .49102 L .40536 .48788 L F
.063 0 .344 r
.40437 .49005 m .40437 .49006 L .40536 .48788 L F
.109 .247 .726 r
.40214 .48626 m .40435 .49003 L .40068 .48645 L F
.727 .641 .762 r
.40436 .49005 m .40437 .49005 L .4042 .48958 L F
.591 .42 .619 r
.40033 .4914 m .40432 .49008 L .39835 .48725 L F
.40432 .49008 m .4043 .49003 L .39835 .48725 L F
.727 .641 .762 r
.40305 .49128 m .40464 .49115 L .40418 .49021 L F
.591 .42 .619 r
.40432 .49008 m .40305 .49128 L .40437 .49006 L F
.40033 .4914 m .40305 .49128 L .40432 .49008 L F
.727 .641 .762 r
.40305 .49128 m .40418 .49021 L .40401 .48986 L F
.40464 .49115 m .40617 .49102 L .4043 .49001 L F
.40464 .49115 m .4043 .49001 L .40401 .48986 L F
.591 .42 .619 r
.40432 .49008 m .40437 .49006 L .4043 .49003 L F
.712 .182 0 r
.40436 .49005 m .40437 .49006 L .40437 .49005 L F
.109 .247 .726 r
.40435 .49003 m .40437 .49006 L .40436 .49005 L F
.40435 .49003 m .40436 .49005 L .40068 .48645 L F
.727 .641 .762 r
.4042 .48958 m .40437 .49005 L .40536 .48788 L F
.086 .075 .547 r
.40189 .48228 m .40214 .48626 L .40068 .48645 L F
.019 .023 .518 r
.40319 .48322 m .40214 .48626 L .40189 .48228 L F
.862 .949 .87 r
.40222 .48603 m .40175 .48511 L .40214 .48626 L F
.40319 .48322 m .40175 .48511 L .40222 .48603 L F
.748 .722 .828 r
.40059 .4834 m .40175 .48511 L .40319 .48322 L F
0 .039 .592 r
.40175 .48511 m .40245 .48523 L .40118 .48399 L F
.40175 .48511 m .40118 .48399 L .40059 .4834 L F
.643 .597 .787 r
.39835 .48725 m .4043 .49003 L .40175 .48511 L F
.727 .641 .762 r
.4043 .49001 m .40436 .49005 L .40416 .48965 L F
.643 .597 .787 r
.4043 .49003 m .40437 .49006 L .40416 .48965 L F
.4043 .49003 m .40416 .48965 L .40175 .48511 L F
.727 .641 .762 r
.40416 .48965 m .40436 .49005 L .4042 .48958 L F
.40401 .48986 m .4043 .49001 L .40416 .48965 L F
.063 0 .344 r
.40328 .48799 m .40536 .48788 L .40759 .48698 L F
.856 .587 .052 r
.23213 .60218 m .23308 .60589 L .23271 .60344 L F
.77 .839 .381 r
.34259 .65013 m .34375 .64816 L .34227 .6517 L F
.638 .801 .363 r
.34464 .64645 m .34375 .64816 L .34259 .65013 L F
.402 0 0 r
.59291 .34873 m .59607 .34865 L .59394 .34938 L F
.495 .042 .104 r
.53503 .48362 m .5375 .48495 L .53479 .48536 L F
0 0 0 r
.38718 .47767 m .38723 .47762 L .39144 .47304 L F
.38718 .47767 m .39144 .47304 L .38983 .47191 L F
.968 .647 .304 r
.38983 .47191 m .39144 .47304 L .3898 .46971 L F
.327 0 0 r
.58193 .41827 m .58088 .41859 L .57783 .41777 L F
.778 .686 .762 r
.25746 .60947 m .25966 .60557 L .25821 .60644 L F
.73 .66 .78 r
.43254 .47961 m .43696 .48143 L .43488 .47871 L F
.037 .557 .868 r
.43696 .48143 m .43734 .48077 L .43488 .48151 L F
.675 .64 .807 r
.74212 .30429 m .73985 .30582 L .73903 .30296 L F
.903 .972 .67 r
.74212 .30429 m .74138 .30655 L .73985 .30582 L F
0 0 .179 r
.73034 .3102 m .72985 .31227 L .73205 .30869 L F
.821 .862 .413 r
.73205 .30869 m .7312 .3098 L .73128 .30961 L F
0 0 0 r
.73295 .30759 m .73034 .3102 L .73205 .30869 L F
.821 .862 .413 r
.73205 .30869 m .73128 .30961 L .73214 .30754 L F
0 0 0 r
.73304 .3075 m .73295 .30759 L .73205 .30869 L F
.73485 .30542 m .73304 .3075 L .73205 .30869 L F
.345 .11 .407 r
.51378 .50109 m .51168 .4995 L .51427 .49889 L F
.51378 .50109 m .51149 .50206 L .51168 .4995 L F
0 0 .194 r
.60609 .42502 m .60641 .42609 L .60564 .42384 L F
0 .172 .707 r
.60682 .42824 m .60846 .42861 L .60641 .42609 L F
.623 .121 0 r
.60641 .42609 m .60708 .42737 L .60672 .42685 L F
.60641 .42609 m .60672 .42685 L .60534 .42488 L F
0 0 .194 r
.60609 .42502 m .60624 .42566 L .60641 .42609 L F
.60624 .42566 m .60682 .42824 L .60641 .42609 L F
.89 .874 .815 r
.54342 .43296 m .54216 .43806 L .54347 .43594 L F
.46 .679 .959 r
.54216 .43806 m .545 .43792 L .54347 .43594 L F
.357 .706 .985 r
.31688 .65941 m .32065 .66165 L .3189 .66004 L F
.932 .959 .768 r
.32153 .65744 m .32065 .66165 L .3187 .65806 L F
.573 .835 .995 r
.32065 .66165 m .32136 .65914 L .3189 .66004 L F
.32065 .66165 m .32383 .6612 L .32136 .65914 L F
.677 .947 .959 r
.45745 .44327 m .45628 .44548 L .45398 .44526 L F
.45745 .44327 m .4587 .44404 L .45628 .44548 L F
.102 0 .36 r
.49079 .53142 m .49128 .5339 L .48904 .53511 L F
.116 0 .321 r
.49128 .5339 m .48849 .53759 L .48904 .53511 L F
.25 .306 .726 r
.61688 .42386 m .61826 .42834 L .6197 .42685 L F
.564 .888 .624 r
.6197 .42685 m .61826 .42834 L .61665 .42954 L F
.687 .872 .968 r
.4463 .58519 m .44273 .58662 L .44419 .58421 L F
.873 .823 .796 r
.24774 .57978 m .25204 .57811 L .25088 .57564 L F
.655 .684 .865 r
.25088 .57564 m .25204 .57811 L .25418 .57687 L F
.945 .582 .233 r
.58986 .42181 m .59107 .42217 L .58948 .42096 L F
.58986 .42181 m .59146 .42311 L .59107 .42217 L F
.743 .672 .782 r
.54724 .41203 m .54991 .41177 L .54838 .40775 L F
.722 .542 .647 r
.54728 .41515 m .54991 .41177 L .54724 .41203 L F
.54728 .41515 m .55121 .41244 L .54991 .41177 L F
.552 .326 .527 r
.37156 .68125 m .37155 .67774 L .36872 .68078 L F
.525 .898 .71 r
.67669 .37779 m .68059 .37535 L .67993 .37608 L F
.106 0 0 r
.68331 .37469 m .67993 .37608 L .68059 .37535 L F
.624 .479 .664 r
.61378 .41108 m .61661 .40772 L .61427 .40923 L F
.61378 .41108 m .61689 .41112 L .61661 .40772 L F
.557 .185 .292 r
.61611 .41446 m .61378 .41108 L .61392 .41241 L F
.61581 .414 m .61689 .41112 L .61389 .41108 L F
.61611 .41446 m .61389 .41108 L .61392 .41129 L F
.61627 .41377 m .61689 .41112 L .61581 .414 L F
.013 .102 .612 r
.61611 .41446 m .61392 .41241 L .61503 .40925 L F
.576 .724 .943 r
.61313 .41537 m .61563 .41275 L .61268 .41508 L F
.61404 .41594 m .61473 .41455 L .61313 .41537 L F
.61473 .41455 m .61563 .41275 L .61313 .41537 L F
.557 .185 .292 r
.61611 .41446 m .61627 .41377 L .61581 .414 L F
.61392 .41129 m .61389 .41108 L .61378 .41108 L F
.824 .98 .886 r
.61427 .40923 m .61503 .40925 L .61404 .41207 L F
.61399 .41175 m .61404 .41207 L .61392 .41241 L F
.61427 .40923 m .61404 .41207 L .61399 .41175 L F
0 0 .361 r
.61392 .41241 m .61378 .41108 L .61427 .40923 L F
0 .394 .839 r
.28388 .65745 m .28561 .65893 L .28551 .65871 L F
0 .29 .703 r
.61578 .3732 m .61905 .37495 L .61734 .37375 L F
.61578 .3732 m .61734 .37375 L .61463 .37436 L F
0 0 0 r
.34147 .60505 m .34171 .60504 L .33845 .60527 L F
.782 .689 .761 r
.52633 .44922 m .53054 .44974 L .53007 .44484 L F
.885 .889 .829 r
.53028 .44704 m .52995 .44555 L .53007 .44484 L F
.53054 .44974 m .53028 .44792 L .53028 .44704 L F
.53028 .44792 m .52995 .44555 L .53028 .44704 L F
0 0 0 r
.53237 .4476 m .53297 .44674 L .53054 .44974 L F
.885 .889 .829 r
.53054 .44974 m .53297 .44674 L .52995 .44555 L F
.775 .952 .932 r
.53237 .4476 m .53028 .44932 L .53164 .45085 L F
.202 0 0 r
.52825 .44958 m .53054 .44974 L .52656 .44925 L F
.52825 .44958 m .52656 .44925 L .52633 .44922 L F
.775 .952 .932 r
.52964 .44985 m .52825 .44958 L .52895 .45042 L F
.53237 .4476 m .53054 .44974 L .52825 .44958 L F
.53237 .4476 m .52825 .44958 L .52964 .44985 L F
.53028 .44932 m .52895 .45042 L .53028 .45063 L F
.53028 .44932 m .53028 .45063 L .53164 .45085 L F
.807 .989 .733 r
.52633 .44922 m .53007 .44484 L .52914 .44537 L F
.52633 .44922 m .52914 .44537 L .52707 .44782 L F
.307 0 0 r
.5284 .44593 m .53007 .44484 L .52995 .44555 L F
.807 .989 .733 r
.52789 .44639 m .52914 .44537 L .52815 .44594 L F
.52707 .44782 m .52764 .44714 L .52789 .44639 L F
.52764 .44714 m .52914 .44537 L .52789 .44639 L F
.431 .059 .23 r
.52865 .44595 m .52859 .44593 L .52781 .44612 L F
.53011 .44659 m .52907 .44581 L .52802 .44617 L F
.648 .648 .836 r
.52807 .44606 m .52859 .44593 L .52815 .44594 L F
.307 0 0 r
.5284 .44593 m .52852 .4459 L .52859 .44593 L F
.648 .648 .836 r
.52859 .44593 m .52866 .44591 L .5284 .44593 L F
.52859 .44593 m .5284 .44593 L .52815 .44594 L F
.307 0 0 r
.52801 .44602 m .5284 .44593 L .53011 .44659 L F
.5284 .44593 m .52859 .44593 L .53011 .44659 L F
.52852 .4459 m .52995 .44555 L .53001 .44594 L F
.648 .648 .836 r
.52866 .44591 m .53011 .44554 L .52823 .44593 L F
.307 0 0 r
.52815 .44594 m .53007 .44484 L .5284 .44593 L F
.648 .648 .836 r
.5284 .44593 m .52823 .44593 L .52815 .44594 L F
.52866 .44591 m .52823 .44593 L .5284 .44593 L F
.307 0 0 r
.52859 .44593 m .53001 .44594 L .53011 .44659 L F
.52852 .4459 m .53001 .44594 L .52859 .44593 L F
.431 .059 .23 r
.52802 .44617 m .52865 .44595 L .52781 .44612 L F
.52865 .44595 m .52907 .44581 L .52859 .44593 L F
.53011 .44659 m .53011 .44554 L .52907 .44581 L F
.807 .989 .733 r
.52633 .44922 m .52792 .4462 L .52488 .44771 L F
.431 .059 .23 r
.52797 .44615 m .52781 .44612 L .52801 .44602 L F
.807 .989 .733 r
.52792 .4462 m .52801 .44602 L .52725 .44643 L F
.52792 .4462 m .52725 .44643 L .52488 .44771 L F
.431 .059 .23 r
.53011 .44659 m .52797 .44615 L .52801 .44602 L F
.307 0 0 r
.52801 .44602 m .52815 .44594 L .5284 .44593 L F
.883 .456 .165 r
.52995 .44555 m .53195 .44443 L .5287 .44328 L F
.339 .088 .379 r
.5287 .44328 m .53042 .44386 L .52957 .44486 L F
.018 0 .227 r
.52995 .44555 m .5308 .4425 L .53307 .44077 L F
.883 .456 .165 r
.52995 .44555 m .53297 .44674 L .53195 .44443 L F
.018 0 .227 r
.52995 .44555 m .53307 .44077 L .53213 .44349 L F
.683 .669 .83 r
.53272 .44295 m .53093 .44504 L .53383 .44327 L F
.295 .073 .397 r
.53287 .44281 m .53307 .44077 L .53377 .44171 L F
.53356 .44217 m .53377 .44171 L .53389 .44187 L F
.53287 .44281 m .53377 .44171 L .53356 .44217 L F
.272 0 .216 r
.53383 .44327 m .53117 .44564 L .53209 .44564 L F
.53117 .44564 m .53011 .44659 L .53135 .44599 L F
.53117 .44564 m .53135 .44599 L .53209 .44564 L F
.018 0 .227 r
.53049 .44562 m .53117 .44564 L .5312 .44571 L F
.085 0 .008 r
.53011 .44659 m .52995 .44555 L .53136 .44573 L F
.272 0 .216 r
.53117 .44564 m .53011 .44554 L .53011 .44659 L F
.53383 .44327 m .53093 .44504 L .53117 .44564 L F
.018 0 .227 r
.53049 .44562 m .5309 .44509 L .53117 .44564 L F
.272 0 .216 r
.53093 .44504 m .53011 .44554 L .53117 .44564 L F
.018 0 .227 r
.5312 .44571 m .53117 .44564 L .53121 .44571 L F
.53121 .44571 m .53213 .44349 L .53136 .44573 L F
.683 .669 .83 r
.53213 .44349 m .53093 .44504 L .53272 .44295 L F
.018 0 .227 r
.5309 .44509 m .53213 .44349 L .53121 .44571 L F
.932 .805 .697 r
.5321 .44549 m .53383 .44327 L .53209 .44564 L F
.295 .073 .397 r
.53273 .44288 m .53307 .44077 L .53287 .44281 L F
.5322 .44328 m .53307 .44077 L .53272 .44295 L F
.429 .506 .836 r
.53307 .44077 m .5308 .4425 L .53062 .44194 L F
.53307 .44077 m .53062 .44194 L .52973 .43914 L F
.537 0 0 r
.5309 .44046 m .53307 .44077 L .52973 .43914 L F
.53106 .44064 m .53124 .44065 L .5309 .44046 L F
.53124 .44065 m .53307 .44077 L .5309 .44046 L F
.457 .879 .924 r
.5348 .43993 m .53307 .44077 L .53106 .44064 L F
.573 .688 .918 r
.53106 .44064 m .53137 .44093 L .53213 .44035 L F
.48 .286 .539 r
.53673 .43627 m .53413 .43686 L .5342 .43377 L F
.457 .879 .924 r
.5352 .43986 m .5333 .44021 L .53392 .43601 L F
.5333 .44021 m .53106 .44064 L .53336 .43692 L F
.5333 .44021 m .53336 .43692 L .53392 .43601 L F
.573 .688 .918 r
.53222 .44046 m .5352 .43986 L .53224 .44046 L F
.53106 .44064 m .5333 .44021 L .53222 .44046 L F
.5333 .44021 m .5352 .43986 L .53222 .44046 L F
.53318 .44265 m .53383 .44327 L .5334 .44253 L F
.683 .669 .83 r
.53272 .44295 m .53383 .44327 L .53318 .44265 L F
.295 .073 .397 r
.53136 .44573 m .53213 .44349 L .53389 .44187 L F
.89 .846 .794 r
.53392 .43601 m .53106 .44064 L .52986 .4381 L F
.578 .716 .937 r
.53106 .44064 m .53403 .43986 L .53246 .43744 L F
.573 .688 .918 r
.53106 .44064 m .53213 .44035 L .53216 .44035 L F
.53106 .44064 m .53216 .44035 L .5352 .43986 L F
.578 .716 .937 r
.53106 .44064 m .53224 .44046 L .53216 .44035 L F
.573 .688 .918 r
.53318 .44265 m .5334 .44253 L .53213 .44035 L F
.932 .805 .697 r
.53213 .44035 m .5322 .44047 L .53219 .44047 L F
.295 .073 .397 r
.53219 .44047 m .53224 .44046 L .53213 .44035 L F
.53224 .44046 m .5352 .43986 L .53216 .44035 L F
.53224 .44046 m .53216 .44035 L .53213 .44035 L F
.573 .688 .918 r
.53197 .4415 m .53318 .44265 L .5328 .44181 L F
.53197 .4415 m .5328 .44181 L .53213 .44035 L F
.53137 .44093 m .53197 .4415 L .53213 .44035 L F
.295 .073 .397 r
.53272 .44295 m .53273 .44288 L .53287 .44281 L F
.53213 .44349 m .5322 .44328 L .53272 .44295 L F
.53 .573 .843 r
.52973 .43914 m .5308 .4425 L .5287 .44328 L F
.683 .669 .83 r
.52908 .44191 m .53272 .44295 L .53106 .44064 L F
.53272 .44295 m .53318 .44265 L .53106 .44064 L F
.53258 .44291 m .53213 .44349 L .53272 .44295 L F
.018 0 .227 r
.52995 .44555 m .53213 .44349 L .53049 .44562 L F
.339 .088 .379 r
.5287 .44328 m .5308 .4425 L .53042 .44386 L F
.52957 .44486 m .53042 .44386 L .52995 .44555 L F
.683 .669 .83 r
.52908 .44191 m .53093 .44504 L .53258 .44291 L F
.295 .073 .397 r
.53136 .44573 m .53329 .44278 L .53211 .44048 L F
.932 .805 .697 r
.5324 .44091 m .53327 .44231 L .53318 .44254 L F
.5322 .44047 m .53327 .44231 L .53213 .44048 L F
.53327 .44231 m .5334 .44253 L .53326 .44285 L F
.295 .073 .397 r
.53329 .44278 m .53219 .44047 L .53211 .44048 L F
.932 .805 .697 r
.53327 .44231 m .53326 .44285 L .5321 .44549 L F
.457 .879 .924 r
.5352 .43986 m .53307 .44077 L .5348 .43993 L F
.295 .073 .397 r
.53389 .44187 m .53307 .44077 L .5352 .43986 L F
.53329 .44278 m .5352 .43986 L .53219 .44047 L F
.932 .805 .697 r
.53213 .44048 m .5324 .44091 L .5321 .44549 L F
.5324 .44091 m .53318 .44254 L .5321 .44549 L F
.573 .688 .918 r
.53224 .44046 m .5352 .43986 L .53423 .44016 L F
.578 .716 .937 r
.53216 .44035 m .53423 .44016 L .53403 .43986 L F
.53224 .44046 m .53423 .44016 L .53216 .44035 L F
.295 .073 .397 r
.53211 .44048 m .53219 .44047 L .53213 .44035 L F
.932 .805 .697 r
.53213 .44035 m .53219 .44047 L .53213 .44048 L F
.414 .38 .712 r
.53209 .44564 m .53136 .44573 L .53203 .44109 L F
.53213 .44115 m .53203 .44109 L .53213 .44035 L F
.53209 .44564 m .53203 .44109 L .53213 .44115 L F
.932 .805 .697 r
.5334 .44253 m .53383 .44327 L .5321 .44549 L F
.683 .669 .83 r
.52908 .44191 m .53011 .44554 L .53093 .44504 L F
.648 .648 .836 r
.52864 .44521 m .53011 .44554 L .52961 .44377 L F
.52815 .44594 m .52944 .44568 L .52864 .44521 L F
.52944 .44568 m .53011 .44554 L .52864 .44521 L F
.527 .626 .892 r
.5287 .44328 m .52635 .44399 L .52488 .44083 L F
.5287 .44328 m .52488 .44083 L .5274 .44003 L F
.648 .648 .836 r
.52781 .44612 m .52807 .44606 L .52908 .44191 L F
.52807 .44606 m .52961 .44377 L .52908 .44191 L F
.807 .989 .733 r
.52771 .44659 m .52815 .44594 L .52801 .44602 L F
.52707 .44782 m .52815 .44594 L .52771 .44659 L F
.861 .942 .871 r
.23685 .59168 m .23534 .59386 L .23801 .59088 L F
0 0 0 r
.23685 .59168 m .23393 .59606 L .23534 .59386 L F
.759 .722 .818 r
.59294 .45653 m .59691 .45712 L .59588 .45338 L F
.671 .203 .132 r
.42714 .5772 m .4283 .57502 L .42975 .57391 L F
.943 .832 .706 r
.62126 .37133 m .62434 .36913 L .62412 .36804 L F
.62126 .37133 m .62304 .37253 L .62434 .36913 L F
.806 .753 .803 r
.62434 .36913 m .62496 .36399 L .62412 .36804 L F
.62434 .36913 m .62725 .36574 L .62496 .36399 L F
.398 0 0 r
.25229 .51891 m .25395 .51975 L .25453 .51798 L F
.25229 .51891 m .25019 .52085 L .25395 .51975 L F
.624 .836 .982 r
.23259 .57585 m .23613 .57598 L .23745 .57426 L F
.056 0 0 r
.23946 .57335 m .23613 .57598 L .23745 .57426 L F
.23946 .57335 m .23613 .57598 L .23745 .57426 L F
.546 .13 .203 r
.46295 .48423 m .46547 .48447 L .46655 .48161 L F
.411 .033 .209 r
.46655 .48161 m .47091 .48217 L .47006 .48051 L F
.73 .598 .709 r
.46547 .48447 m .47091 .48217 L .46655 .48161 L F
.998 .833 .549 r
.39367 .57885 m .39559 .57685 L .3942 .57597 L F
.39367 .57885 m .39507 .58043 L .39559 .57685 L F
.986 .709 .371 r
.3234 .60165 m .32209 .60217 L .32179 .59854 L F
0 0 0 r
.32502 .59853 m .32405 .60291 L .32179 .59854 L F
.971 .693 .444 r
.32179 .59854 m .32209 .60217 L .31987 .60035 L F
.972 .716 .488 r
.32209 .60217 m .31996 .60315 L .31987 .60035 L F
.441 .857 .702 r
.32384 .60098 m .32072 .60272 L .32209 .60217 L F
.32072 .60272 m .31996 .60315 L .32209 .60217 L F
.986 .709 .371 r
.32405 .60291 m .32209 .60217 L .3234 .60165 L F
0 0 0 r
.32502 .59853 m .32455 .60114 L .32405 .60291 L F
.543 .907 .961 r
.32455 .60114 m .32209 .60217 L .32405 .60291 L F
.363 .156 .459 r
.32405 .60291 m .32628 .60499 L .32739 .60195 L F
.32405 .60291 m .32417 .60577 L .32628 .60499 L F
0 .099 .628 r
.54977 .42134 m .55128 .42337 L .54881 .42108 L F
.54977 .42134 m .54881 .42108 L .5458 .42108 L F
.549 .834 .998 r
.73671 .31302 m .7376 .31075 L .73607 .31158 L F
.73671 .31302 m .7384 .31211 L .7376 .31075 L F
0 0 0 r
.56406 .45225 m .56331 .45436 L .56257 .45654 L F
.969 .707 .483 r
.38617 .54627 m .38797 .54488 L .38581 .54378 L F
.38617 .54627 m .38794 .54743 L .38797 .54488 L F
.915 .956 .624 r
.26407 .62817 m .26606 .6261 L .26414 .62492 L F
.26407 .62817 m .26511 .62777 L .26606 .6261 L F
.83 .531 .483 r
.26863 .62953 m .26606 .6261 L .26511 .62777 L F
.571 .09 .074 r
.30486 .57413 m .30291 .57582 L .30021 .57526 L F
.523 .849 .558 r
.30514 .57371 m .30486 .57413 L .30752 .57421 L F
.30514 .57371 m .30291 .57582 L .30486 .57413 L F
.776 .64 .711 r
.39569 .47962 m .39708 .48263 L .39864 .47944 L F
.097 0 0 r
.39569 .47962 m .39828 .47964 L .39864 .47944 L F
.802 .868 .428 r
.39864 .47944 m .40173 .47655 L .40015 .47808 L F
.39864 .47944 m .4003 .47489 L .40173 .47655 L F
.39864 .47944 m .39828 .47964 L .4003 .47489 L F
.49 .847 .593 r
.40015 .47808 m .39828 .47964 L .39864 .47944 L F
.757 .613 .698 r
.61083 .38272 m .61509 .38305 L .61361 .37926 L F
.631 .549 .744 r
.61361 .37926 m .61509 .38305 L .61755 .37995 L F
0 0 0 r
.24332 .54726 m .23964 .54948 L .24113 .54813 L F
.9 .771 .71 r
.3773 .49279 m .37378 .49475 L .3764 .49115 L F
.3773 .49279 m .3759 .49636 L .37378 .49475 L F
.776 .629 .697 r
.45224 .57034 m .45592 .57068 L .45607 .56665 L F
.319 .315 .698 r
.45592 .57068 m .45722 .56647 L .45607 .56665 L F
.167 .472 .893 r
.57728 .38645 m .57472 .38613 L .5734 .38447 L F
.57728 .38645 m .57821 .38747 L .57472 .38613 L F
.959 .631 .348 r
.22834 .57024 m .22871 .57266 L .23063 .57374 L F
0 .058 .618 r
.2309 .57293 m .23063 .57374 L .22871 .57266 L F
.2309 .57293 m .23259 .57585 L .23063 .57374 L F
.464 0 0 r
.41609 .5099 m .41152 .50913 L .41213 .51203 L F
.41609 .5099 m .41393 .51028 L .41152 .50913 L F
.955 .625 .353 r
.41609 .5099 m .41599 .51207 L .41393 .51028 L F
.394 .843 .752 r
.31482 .66027 m .31336 .66121 L .31688 .65941 L F
.897 .478 .147 r
.59084 .41482 m .58797 .41138 L .58805 .41378 L F
.94 .723 .581 r
.59039 .41686 m .59084 .41482 L .58805 .41378 L F
.045 0 0 r
.33336 .51902 m .33186 .52037 L .329 .52097 L F
.491 0 0 r
.33562 .52054 m .33336 .51902 L .33614 .5188 L F
.33562 .52054 m .33186 .52037 L .33336 .51902 L F
.542 .374 .603 r
.33551 .51591 m .33614 .5188 L .33336 .51902 L F
.805 .556 .562 r
.33106 .64854 m .33475 .65161 L .33138 .65162 L F
.797 .641 .689 r
.33475 .65161 m .33095 .65514 L .33138 .65162 L F
.796 .715 .181 r
.57669 .37595 m .57696 .37217 L .57845 .37296 L F
.715 .189 0 r
.57897 .37763 m .57647 .37571 L .57669 .37595 L F
.75 .605 .697 r
.46396 .51497 m .46462 .50917 L .46324 .51176 L F
.972 .815 .629 r
.40883 .56732 m .40723 .56634 L .40789 .56423 L F
.984 .706 .399 r
.40883 .56732 m .40739 .56847 L .40723 .56634 L F
.40883 .56732 m .40893 .57022 L .40739 .56847 L F
0 .127 .658 r
.23865 .61562 m .23988 .61994 L .24063 .61782 L F
.081 .289 .773 r
.23988 .61994 m .24261 .62212 L .24063 .61782 L F
.243 .232 .646 r
.4035 .47246 m .40173 .47655 L .4003 .47489 L F
.4035 .47246 m .40392 .47569 L .40173 .47655 L F
0 0 0 r
.40272 .47637 m .40173 .47655 L .40392 .47569 L F
.40272 .47637 m .40015 .47808 L .40173 .47655 L F
.882 .449 .094 r
.36751 .51474 m .36881 .51773 L .37058 .51884 L F
.954 .643 .402 r
.36881 .51773 m .37086 .52086 L .37058 .51884 L F
.536 0 0 r
.36826 .63149 m .36431 .62862 L .36602 .62923 L F
.257 .667 .965 r
.37072 .63082 m .36826 .63149 L .36602 .62923 L F
.616 .609 .82 r
.22501 .58114 m .22533 .58295 L .22725 .58014 L F
.655 .662 .845 r
.22533 .58295 m .22918 .58373 L .22725 .58014 L F
.226 .182 .597 r
.22533 .58295 m .22768 .5855 L .22918 .58373 L F
.62 .391 .548 r
.41865 .50871 m .41862 .50675 L .41867 .50727 L F
.351 .812 .928 r
.41572 .50833 m .41876 .50829 L .41867 .50727 L F
.41876 .50829 m .42061 .50826 L .41867 .50727 L F
.62 .391 .548 r
.41862 .50675 m .4186 .50577 L .41867 .50727 L F
.789 .354 .216 r
.70066 .2937 m .70268 .29623 L .7039 .29468 L F
.013 0 0 r
.70268 .29623 m .7065 .29439 L .7039 .29468 L F
.554 .842 .998 r
.43805 .48962 m .44196 .48978 L .44047 .48868 L F
.647 .879 .984 r
.44047 .48868 m .44196 .48978 L .44445 .48868 L F
0 0 .489 r
.3773 .68312 m .38017 .68082 L .37757 .68304 L F
0 0 0 r
.65331 .38072 m .65141 .38138 L .65091 .38184 L F
.65331 .38072 m .65474 .37994 L .65141 .38138 L F
.67794 .30404 m .68056 .30296 L .68091 .30111 L F
.67794 .30404 m .67694 .3053 L .68056 .30296 L F
.898 .49 .218 r
.34221 .55737 m .34302 .56057 L .34507 .5606 L F
.803 .318 .046 r
.34302 .56057 m .34413 .56157 L .34507 .5606 L F
.231 .022 .376 r
.34507 .5606 m .34741 .55971 L .34752 .55741 L F
.477 .094 .234 r
.34413 .56157 m .34741 .55971 L .34507 .5606 L F
.477 .238 .473 r
.31902 .63902 m .32167 .63841 L .32111 .64101 L F
.799 .863 .896 r
.61473 .36908 m .61214 .37196 L .61181 .37173 L F
.635 .653 .851 r
.22725 .58014 m .22918 .58373 L .23116 .58233 L F
.22725 .58014 m .22924 .58125 L .23045 .58083 L F
.22924 .58125 m .23116 .58233 L .23045 .58083 L F
.757 .909 .528 r
.22918 .58373 m .23045 .58083 L .23116 .58233 L F
.22918 .58373 m .22768 .5855 L .23045 .58083 L F
.241 .74 .666 r
.23387 .5796 m .23045 .58083 L .23116 .58233 L F
0 .235 .752 r
.23107 .58061 m .23116 .58233 L .23045 .58083 L F
.868 .977 .674 r
.23045 .58083 m .22768 .5855 L .22763 .58372 L F
.672 .378 .466 r
.22763 .58372 m .23106 .58062 L .23045 .58083 L F
.23106 .58062 m .23107 .58061 L .23045 .58083 L F
.497 .537 .828 r
.23085 .58518 m .22918 .58373 L .23116 .58233 L F
.078 .272 .759 r
.23145 .59454 m .23202 .59671 L .23209 .59551 L F
.23039 .59294 m .23114 .59468 L .23145 .59454 L F
.23114 .59468 m .23202 .59671 L .23145 .59454 L F
.005 .089 .601 r
.23184 .59159 m .23145 .59454 L .23294 .59079 L F
.23145 .59454 m .23137 .59511 L .2316 .59446 L F
.23145 .59454 m .2316 .59446 L .23294 .59079 L F
.309 .391 .784 r
.23039 .59294 m .23137 .59511 L .23145 .59454 L F
.23039 .59294 m .23145 .59454 L .23184 .59159 L F
.445 .559 .877 r
.23216 .59445 m .23294 .59079 L .2316 .59446 L F
.078 .272 .759 r
.2314 .59446 m .23209 .59551 L .23216 .59445 L F
.445 .559 .877 r
.23216 .59445 m .2316 .59446 L .23137 .59511 L F
.078 .272 .759 r
.23039 .59294 m .2314 .59446 L .23216 .59445 L F
.519 .699 .951 r
.23216 .59445 m .23393 .59606 L .23202 .59671 L F
.912 .981 .759 r
.23202 .59671 m .22907 .59873 L .23216 .59445 L F
.859 .972 .658 r
.46387 .56064 m .46556 .55668 L .46701 .55763 L F
.46387 .56064 m .46352 .56006 L .46556 .55668 L F
.904 .85 .399 r
.46387 .56064 m .46276 .56268 L .46352 .56006 L F
.555 .29 .469 r
.52981 .48641 m .53215 .488 L .52973 .48795 L F
.52981 .48641 m .5323 .48593 L .53215 .488 L F
.276 .779 .855 r
.60615 .34716 m .60893 .34662 L .61007 .34673 L F
.469 .891 .897 r
.61007 .34673 m .61175 .34548 L .61254 .34552 L F
.61007 .34673 m .60893 .34662 L .61175 .34548 L F
.491 .12 .263 r
.42738 .50475 m .42996 .50465 L .43092 .50213 L F
.524 .397 .649 r
.43092 .50213 m .43354 .50186 L .4331 .49941 L F
.536 .209 .361 r
.42996 .50465 m .43354 .50186 L .43092 .50213 L F
.124 0 0 r
.45893 .48526 m .45765 .48498 L .45636 .48588 L F
.45893 .48526 m .46039 .4843 L .45765 .48498 L F
.678 .553 .705 r
.62378 .36052 m .6241 .36335 L .62659 .35983 L F
.858 .994 .748 r
.34323 .56426 m .34044 .56601 L .34064 .5676 L F
.749 .328 .248 r
.34566 .5667 m .34044 .56601 L .34323 .56426 L F
.955 .798 .646 r
.57602 .42756 m .57293 .4292 L .57309 .42672 L F
.57602 .42756 m .5749 .43209 L .57293 .4292 L F
.147 .411 .855 r
.33886 .56991 m .33788 .5716 L .33619 .57246 L F
.879 .549 .044 r
.58902 .40803 m .58768 .40472 L .58817 .40692 L F
.963 .899 .527 r
.58728 .41067 m .58902 .40803 L .58817 .40692 L F
.58728 .41067 m .58797 .41138 L .58902 .40803 L F
.62 .869 .989 r
.42888 .54752 m .43198 .54807 L .43254 .54696 L F
.508 .828 1 r
.27217 .57554 m .27656 .57566 L .27415 .57534 L F
.968 .779 .596 r
.58878 .42584 m .59146 .42311 L .58986 .42181 L F
.58878 .42584 m .5905 .42682 L .59146 .42311 L F
.629 .794 .354 r
.38609 .47963 m .38723 .47762 L .38718 .47767 L F
.84 .648 .643 r
.69788 .32759 m .6955 .32881 L .69441 .32694 L F
.69788 .32759 m .69772 .33045 L .6955 .32881 L F
.718 .579 .699 r
.37051 .55346 m .3678 .55721 L .36826 .55461 L F
.37051 .55346 m .3678 .55721 L .36826 .55461 L F
.911 .738 .242 r
.5785 .39007 m .57904 .38918 L .57821 .38747 L F
.5785 .39007 m .57884 .39242 L .57904 .38918 L F
.825 .912 .513 r
.34238 .63127 m .34121 .63499 L .34234 .63425 L F
0 .144 .686 r
.34234 .63425 m .34121 .63499 L .34377 .63757 L F
.082 0 .445 r
.22346 .55777 m .22542 .55666 L .22518 .5539 L F
.303 .474 .863 r
.22346 .55777 m .22619 .55914 L .22542 .55666 L F
.635 .929 .971 r
.54685 .46521 m .54516 .46672 L .54386 .46598 L F
.337 .356 .733 r
.54685 .46521 m .54792 .46908 L .54516 .46672 L F
.81 .912 .909 r
.52216 .42788 m .52576 .42728 L .5248 .42687 L F
.501 .894 .739 r
.52576 .42728 m .52745 .42586 L .5248 .42687 L F
.52576 .42728 m .5288 .42535 L .52745 .42586 L F
0 0 0 r
.65714 .37863 m .65474 .37994 L .65331 .38072 L F
.375 .025 .238 r
.54454 .4804 m .54671 .48148 L .54407 .48208 L F
.54454 .4804 m .54684 .47984 L .54671 .48148 L F
.652 .695 .878 r
.2965 .66109 m .29794 .65577 L .29537 .65817 L F
.2965 .66109 m .29973 .66024 L .29794 .65577 L F
.661 .951 .715 r
.61765 .35768 m .6193 .35664 L .62069 .35495 L F
.194 0 .315 r
.62659 .35983 m .6241 .36335 L .62635 .36228 L F
.62659 .35983 m .6241 .36335 L .62635 .36228 L F
.749 .758 .86 r
.62496 .36399 m .62725 .36574 L .62635 .36228 L F
.987 .818 .589 r
.62445 .36515 m .62412 .36804 L .62496 .36399 L F
.62349 .36734 m .62364 .3675 L .62445 .36515 L F
.62364 .3675 m .62412 .36804 L .62445 .36515 L F
.19 0 .307 r
.62444 .36514 m .6241 .36335 L .62443 .36517 L F
.62525 .3628 m .6241 .36335 L .62445 .36515 L F
.391 0 0 r
.61993 .36582 m .62268 .36644 L .62443 .36517 L F
.987 .818 .589 r
.62268 .36644 m .62478 .36418 L .62443 .36517 L F
.62478 .36418 m .62496 .36399 L .62443 .36517 L F
0 0 .067 r
.62443 .36517 m .62496 .36399 L .62445 .36515 L F
.19 0 .307 r
.62445 .36515 m .62444 .36514 L .62443 .36517 L F
0 0 .067 r
.62445 .36515 m .62496 .36399 L .62635 .36228 L F
.19 0 .307 r
.62635 .36228 m .62525 .3628 L .62445 .36515 L F
.987 .818 .589 r
.62268 .36644 m .62349 .36734 L .62496 .36399 L F
.256 .025 .359 r
.50352 .50905 m .50311 .51143 L .50106 .5124 L F
.277 .065 .401 r
.50311 .51143 m .50074 .51488 L .50106 .5124 L F
.412 .677 .97 r
.72011 .32305 m .72124 .3219 L .71897 .3229 L F
.72011 .32305 m .72321 .32296 L .72124 .3219 L F
.117 .207 .682 r
.56654 .4447 m .56896 .44536 L .56854 .44279 L F
.56654 .4447 m .56789 .44645 L .56896 .44536 L F
.845 .962 .63 r
.58728 .36866 m .58927 .36421 L .59046 .36541 L F
.319 .315 .698 r
.45592 .57068 m .45835 .56917 L .45722 .56647 L F
.641 .406 .547 r
.47013 .51177 m .47297 .51155 L .47353 .50932 L F
.481 .493 .793 r
.47199 .50609 m .47353 .50932 L .4753 .50823 L F
.48 .252 .49 r
.47353 .50932 m .47529 .51095 L .4753 .50823 L F
.47353 .50932 m .47297 .51155 L .47529 .51095 L F
.857 .816 .809 r
.62635 .36228 m .62725 .36574 L .62957 .36222 L F
.083 0 .146 r
.29868 .62855 m .29692 .62949 L .29599 .63167 L F
.29868 .62855 m .29692 .62949 L .29599 .63167 L F
.734 .766 .879 r
.46431 .46734 m .46713 .46689 L .46568 .46326 L F
.515 .551 .83 r
.46713 .46689 m .46766 .46157 L .46568 .46326 L F
.502 .128 .262 r
.46926 .46895 m .47013 .46673 L .46713 .46689 L F
.481 .081 .204 r
.47005 .46707 m .47013 .46673 L .47036 .46708 L F
.46713 .46689 m .47013 .46673 L .47005 .46707 L F
.515 .551 .83 r
.46713 .46689 m .47005 .46707 L .46766 .46157 L F
.47005 .46707 m .47036 .46708 L .4703 .46696 L F
.154 0 .113 r
.47005 .46707 m .47013 .46673 L .46999 .4671 L F
.263 .02 .345 r
.47036 .46708 m .47013 .46673 L .47257 .46581 L F
.154 0 .113 r
.47257 .46581 m .47013 .46673 L .47005 .46708 L F
.552 .57 .826 r
.4703 .46696 m .47036 .46708 L .47257 .46581 L F
.154 0 .113 r
.47257 .46581 m .47005 .46708 L .46972 .46851 L F
.552 .57 .826 r
.46766 .46157 m .4703 .46696 L .47257 .46581 L F
.515 .551 .83 r
.47005 .46707 m .4703 .46696 L .46766 .46157 L F
.154 0 .113 r
.46972 .46851 m .47005 .46707 L .46926 .46895 L F
.47005 .46707 m .46999 .4671 L .46926 .46895 L F
.502 .128 .262 r
.46926 .46895 m .46713 .46689 L .46776 .47014 L F
.385 .456 .811 r
.33178 .51223 m .33476 .51273 L .33231 .50844 L F
.612 .448 .636 r
.33246 .51375 m .33476 .51273 L .33178 .51223 L F
.41 .73 .99 r
.58 .37131 m .57845 .37296 L .57696 .37217 L F
.58 .37131 m .58168 .37267 L .57845 .37296 L F
.636 .836 .977 r
.44102 .44803 m .44001 .45047 L .43846 .44925 L F
.44102 .44803 m .44235 .44942 L .44001 .45047 L F
.973 .73 .51 r
.52198 .41582 m .52359 .41805 L .52224 .41689 L F
.607 .593 .812 r
.5861 .45428 m .5904 .45753 L .58861 .45386 L F
.654 .745 .917 r
.5904 .45753 m .59244 .45553 L .58861 .45386 L F
.5904 .45753 m .59294 .45653 L .59244 .45553 L F
.56 .38 .593 r
.35539 .68107 m .35533 .68406 L .35744 .68068 L F
.306 .476 .864 r
.34678 .50999 m .34883 .51277 L .34906 .51072 L F
.824 .606 .607 r
.35176 .51445 m .34906 .51072 L .34883 .51277 L F
.837 .998 .781 r
.53709 .41942 m .53622 .42162 L .53802 .41935 L F
.975 .725 .491 r
.38837 .55282 m .39019 .55126 L .3882 .55042 L F
.38837 .55282 m .3901 .55402 L .39019 .55126 L F
.778 .5 .515 r
.62163 .42 m .62432 .41881 L .62399 .41662 L F
.816 .533 .51 r
.72715 .3241 m .72323 .3257 L .72321 .32296 L F
.72715 .3241 m .72705 .32652 L .72323 .3257 L F
.684 .685 .845 r
.44954 .51265 m .44991 .51416 L .45275 .51169 L F
.802 .713 .766 r
.42257 .57951 m .42714 .5772 L .42513 .57594 L F
.42257 .57951 m .42463 .58049 L .42714 .5772 L F
.837 .797 .812 r
.42513 .57594 m .42714 .5772 L .42975 .57391 L F
.663 .675 .851 r
.34172 .59313 m .34001 .59419 L .33947 .5936 L F
.33947 .5936 m .34001 .59419 L .34172 .59313 L F
.014 .143 .655 r
.55461 .42884 m .55261 .42706 L .55598 .42661 L F
.015 0 0 r
.55461 .42884 m .55598 .42661 L .55818 .42631 L F
.95 .95 .648 r
.39165 .59818 m .39373 .59653 L .39262 .59559 L F
.39165 .59818 m .39216 .6002 L .39373 .59653 L F
0 0 0 r
.65282 .32478 m .64979 .32737 L .65185 .32585 L F
.65185 .32585 m .65516 .32338 L .65282 .32478 L F
.824 .84 .861 r
.60357 .34802 m .59681 .34879 L .60167 .34757 L F
.60357 .34802 m .5991 .3516 L .59681 .34879 L F
.464 .887 .907 r
.60357 .34802 m .60599 .34694 L .60615 .34716 L F
.60357 .34802 m .60167 .34757 L .60599 .34694 L F
.177 .489 .902 r
.5725 .38266 m .57043 .3834 L .56913 .3817 L F
.5725 .38266 m .5734 .38447 L .57043 .3834 L F
.486 .255 .488 r
.53936 .42462 m .53919 .42751 L .54154 .42667 L F
0 .308 .799 r
.22619 .55914 m .22752 .56097 L .22656 .55908 L F
.975 .898 .681 r
.22752 .56097 m .2252 .56197 L .22656 .55908 L F
0 0 .481 r
.34064 .5676 m .34044 .56601 L .33903 .56385 L F
0 .353 .714 r
.68578 .32026 m .68796 .32115 L .68741 .32072 L F
.68578 .32026 m .68741 .32072 L .68419 .32115 L F
.346 .791 .958 r
.70417 .3072 m .7054 .30683 L .70701 .30725 L F
.395 0 .035 r
.25334 .52494 m .24905 .52714 L .24957 .52542 L F
.25334 .52494 m .25169 .52695 L .24905 .52714 L F
.078 0 0 r
.25389 .52612 m .25334 .52494 L .25609 .52373 L F
.25389 .52612 m .25169 .52695 L .25334 .52494 L F
.989 .88 .543 r
.27455 .63952 m .27304 .64075 L .27267 .63721 L F
.27455 .63952 m .27379 .64339 L .27304 .64075 L F
.52 .711 .958 r
.27629 .63756 m .27455 .63952 L .27267 .63721 L F
.619 .837 .983 r
.36923 .55956 m .37279 .56025 L .3707 .55897 L F
.296 .738 .964 r
.3753 .55982 m .3707 .55897 L .37279 .56025 L F
.374 .076 .325 r
.37279 .56025 m .37185 .56328 L .3753 .55982 L F
.219 .679 .947 r
.59172 .36475 m .59046 .36541 L .58927 .36421 L F
.59172 .36475 m .59406 .36542 L .59046 .36541 L F
.512 .84 .546 r
.68091 .30111 m .68287 .29919 L .68403 .2982 L F
0 0 0 r
.68091 .30111 m .68231 .30092 L .68287 .29919 L F
.68091 .30111 m .68056 .30296 L .68231 .30092 L F
0 0 .439 r
.3383 .65319 m .33823 .65328 L .33615 .65023 L F
.608 .396 .569 r
.46738 .52066 m .47037 .52308 L .46732 .52334 L F
.937 .932 .575 r
.46732 .52334 m .46778 .52117 L .46738 .52066 L F
.538 .001 0 r
.46833 .52127 m .46738 .52066 L .4669 .52006 L F
.407 0 .031 r
.47161 .51871 m .46738 .52066 L .46833 .52127 L F
.608 .396 .569 r
.46738 .52066 m .47059 .52032 L .47037 .52308 L F
.937 .932 .575 r
.46778 .52117 m .46793 .52043 L .46738 .52066 L F
.538 .001 0 r
.4669 .52006 m .46738 .52066 L .46512 .51857 L F
0 .127 .658 r
.23865 .61562 m .24063 .61782 L .24292 .61565 L F
.224 0 0 r
.24245 .61704 m .24292 .61565 L .24063 .61782 L F
.515 0 0 r
.57975 .37948 m .58034 .38031 L .57897 .37763 L F
.57975 .37948 m .58231 .38146 L .58034 .38031 L F
.972 .664 .365 r
.33401 .51557 m .33406 .51704 L .33551 .51591 L F
.933 .945 .776 r
.33678 .51111 m .33551 .51591 L .33845 .51164 L F
.33678 .51111 m .33401 .51557 L .33551 .51591 L F
.972 .664 .365 r
.33401 .51557 m .33406 .51704 L .33551 .51591 L F
.154 .344 .801 r
.33686 .51405 m .33551 .51591 L .33406 .51704 L F
.33686 .51405 m .33822 .51757 L .33551 .51591 L F
.432 .303 .604 r
.33822 .51757 m .33614 .5188 L .33551 .51591 L F
.37 0 0 r
.54368 .42587 m .54617 .42567 L .54867 .42658 L F
.716 .916 .566 r
.56194 .42125 m .56059 .42247 L .5596 .42451 L F
0 0 0 r
.56058 .42488 m .5596 .42451 L .56059 .42247 L F
.56058 .42488 m .55818 .42631 L .5596 .42451 L F
.756 .308 .185 r
.46462 .50917 m .46688 .50878 L .46454 .50766 L F
.46462 .50917 m .46811 .51071 L .46688 .50878 L F
.746 .682 .789 r
.62863 .39926 m .6233 .39673 L .62704 .39809 L F
.81 .932 .913 r
.62993 .39703 m .62863 .39926 L .62704 .39809 L F
.636 .853 .982 r
.2916 .5093 m .29114 .51122 L .28855 .50978 L F
.416 .075 .277 r
.43479 .47598 m .43731 .47554 L .438 .47317 L F
.61 .573 .787 r
.438 .47317 m .4398 .46988 L .43762 .46942 L F
.438 .47317 m .44274 .47276 L .4398 .46988 L F
.583 .274 .41 r
.43731 .47554 m .44274 .47276 L .438 .47317 L F
.833 .736 .757 r
.61416 .42415 m .61688 .42386 L .6156 .42058 L F
.538 .579 .844 r
.61688 .42386 m .61747 .41978 L .6156 .42058 L F
.61688 .42386 m .61962 .42318 L .61747 .41978 L F
.25 .306 .726 r
.61688 .42386 m .6197 .42685 L .61962 .42318 L F
0 0 0 r
.64979 .32737 m .65092 .32704 L .65185 .32585 L F
.634 .328 .435 r
.30864 .56707 m .31261 .56425 L .30882 .56424 L F
.30864 .56707 m .31188 .56698 L .31261 .56425 L F
.398 .109 .353 r
.31188 .56698 m .31411 .5667 L .31261 .56425 L F
.282 0 0 r
.46449 .59322 m .46561 .59447 L .46333 .5948 L F
.46449 .59322 m .46717 .59297 L .46561 .59447 L F
.912 .961 .636 r
.51682 .43896 m .51847 .4379 L .51802 .43672 L F
.467 .845 .618 r
.52039 .43644 m .51847 .4379 L .51682 .43896 L F
0 0 0 r
.29662 .57522 m .29453 .5765 L .29757 .57507 L F
.29662 .57522 m .29437 .57692 L .29453 .5765 L F
.585 .47 .688 r
.25078 .62021 m .25375 .62167 L .25325 .61916 L F
.842 .993 .743 r
.4115 .47083 m .41093 .47305 L .41341 .46983 L F
0 0 .509 r
.42487 .5594 m .42561 .55943 L .42322 .55927 L F
.949 .734 .271 r
.42561 .55943 m .42647 .56097 L .42626 .55945 L F
.808 .587 .027 r
.42561 .55943 m .42628 .56335 L .42647 .56097 L F
.42605 .56201 m .42599 .56268 L .42628 .56335 L F
.42561 .55943 m .42599 .56268 L .42605 .56201 L F
0 0 0 r
.42592 .56344 m .42599 .56268 L .42778 .55985 L F
.42592 .56344 m .42778 .55985 L .42777 .55992 L F
0 0 .509 r
.42767 .55962 m .42599 .56268 L .42561 .55943 L F
.42791 .55964 m .42778 .55985 L .42767 .55962 L F
.42778 .55985 m .42599 .56268 L .42767 .55962 L F
.42791 .55964 m .42561 .55943 L .42487 .5594 L F
.949 .734 .271 r
.42561 .55943 m .42626 .55945 L .42592 .55691 L F
.906 .656 .549 r
.42321 .55514 m .42561 .55943 L .42592 .55691 L F
0 0 0 r
.42777 .55992 m .42778 .55985 L .42791 .55964 L F
.884 .885 .457 r
.42628 .56335 m .42599 .56268 L .42501 .56516 L F
0 0 0 r
.42501 .56516 m .42599 .56268 L .42592 .56344 L F
.42501 .56516 m .42791 .55964 L .42388 .5643 L F
.906 .656 .549 r
.42321 .55514 m .42322 .55927 L .42561 .55943 L F
.943 .729 .259 r
.42269 .55746 m .42322 .55927 L .42321 .55514 L F
.372 .567 .913 r
.42791 .55964 m .42322 .55927 L .42269 .55746 L F
.842 .985 .865 r
.42315 .56335 m .42388 .5643 L .42768 .55992 L F
.42755 .55992 m .42768 .55992 L .42791 .55964 L F
.42315 .56335 m .42768 .55992 L .42755 .55992 L F
.42315 .56335 m .42791 .55964 L .42545 .55913 L F
.817 .356 .131 r
.42772 .56014 m .42716 .5617 L .42604 .56001 L F
.42727 .55994 m .42604 .56001 L .42545 .55913 L F
.42772 .56014 m .42604 .56001 L .42727 .55994 L F
.42857 .56052 m .42744 .56146 L .42772 .56014 L F
.42744 .56146 m .42716 .5617 L .42772 .56014 L F
.567 .715 .941 r
.58514 .45264 m .5861 .45428 L .58762 .45195 L F
.516 .645 .914 r
.5861 .45428 m .58861 .45386 L .58762 .45195 L F
0 0 .139 r
.57407 .45375 m .57449 .45651 L .57442 .45602 L F
.898 .871 .433 r
.31693 .63234 m .31692 .63003 L .31829 .63086 L F
.72 .709 .839 r
.31829 .63086 m .31735 .63507 L .31693 .63234 L F
0 0 .401 r
.27762 .6518 m .27941 .65267 L .27769 .64967 L F
.27762 .6518 m .2776 .65484 L .27941 .65267 L F
.112 .031 .476 r
.22045 .57294 m .22172 .57318 L .22139 .57036 L F
.552 .84 .998 r
.32369 .64277 m .32652 .64516 L .32286 .64486 L F
.937 .907 .766 r
.32727 .64094 m .32652 .64516 L .32369 .64277 L F
.642 .958 .777 r
.40759 .48698 m .40642 .48675 L .40981 .48569 L F
.40759 .48698 m .40536 .48788 L .40642 .48675 L F
.727 .626 .745 r
.54346 .41175 m .54724 .41203 L .54589 .40885 L F
.715 .544 .657 r
.54329 .41475 m .54724 .41203 L .54346 .41175 L F
.54329 .41475 m .54728 .41515 L .54724 .41203 L F
.743 .672 .782 r
.54724 .41203 m .54838 .40775 L .54589 .40885 L F
.889 .543 .386 r
.36484 .51214 m .36502 .51422 L .36751 .51474 L F
.856 .454 .276 r
.36502 .51422 m .36881 .51773 L .36751 .51474 L F
.466 0 0 r
.23116 .58233 m .23547 .58519 L .23085 .58518 L F
.075 0 .189 r
.55451 .43449 m .55231 .43743 L .55526 .43679 L F
.658 .57 .745 r
.55231 .43743 m .55568 .4379 L .55526 .43679 L F
.164 0 .245 r
.35657 .61515 m .35421 .61622 L .357 .61271 L F
.211 .164 .584 r
.35657 .61851 m .35421 .61622 L .35657 .61515 L F
.35657 .61851 m .35483 .61878 L .35421 .61622 L F
.516 .325 .56 r
.30435 .54146 m .30723 .54132 L .30703 .53806 L F
.792 .742 .806 r
.40977 .5106 m .41213 .51203 L .41152 .50913 L F
.855 .417 .174 r
.40977 .5106 m .41108 .51327 L .41213 .51203 L F
0 0 0 r
.41213 .51203 m .41393 .51028 L .41599 .51207 L F
.41213 .51203 m .41108 .51327 L .41393 .51028 L F
.529 .35 .582 r
.26999 .55453 m .27259 .55425 L .27254 .55112 L F
.26999 .55453 m .27259 .55425 L .27254 .55112 L F
.773 .833 .898 r
.5405 .4183 m .54493 .41836 L .5438 .41713 L F
.892 .526 .055 r
.54329 .41475 m .54493 .41836 L .54728 .41515 L F
.54329 .41475 m .5438 .41713 L .54493 .41836 L F
.49 .852 .99 r
.37757 .68046 m .38017 .68082 L .38044 .67997 L F
.725 .969 .715 r
.38017 .68082 m .37757 .68304 L .38044 .67997 L F
.19 0 .289 r
.37257 .57964 m .37001 .58303 L .37064 .58063 L F
.37064 .58063 m .37001 .58303 L .37257 .57964 L F
.824 .98 .886 r
.61427 .40923 m .61661 .40772 L .61545 .40685 L F
.747 .967 .933 r
.61545 .40685 m .61661 .40772 L .61797 .4048 L F
.61545 .40685 m .61661 .40772 L .61797 .4048 L F
.446 .836 .983 r
.61545 .40685 m .61661 .40772 L .61953 .40699 L F
0 0 .456 r
.61661 .40772 m .61765 .41046 L .61953 .40699 L F
.61661 .40772 m .61689 .41112 L .61765 .41046 L F
.456 .811 .997 r
.71068 .28879 m .70947 .29049 L .70856 .28989 L F
.837 .797 .812 r
.42513 .57594 m .42975 .57391 L .42624 .57367 L F
.429 0 0 r
.58634 .38444 m .58231 .38146 L .58341 .38308 L F
.093 .411 .862 r
.5862 .38548 m .58634 .38444 L .58341 .38308 L F
.531 .308 .521 r
.4701 .49587 m .47294 .49524 L .47301 .49297 L F
.554 .373 .59 r
.47301 .49297 m .47619 .49257 L .47554 .48955 L F
.749 .671 .774 r
.47294 .49524 m .47619 .49257 L .47301 .49297 L F
.185 0 0 r
.44255 .5063 m .44063 .5075 L .43766 .50788 L F
.815 .873 .889 r
.44239 .50297 m .44255 .5063 L .44464 .50467 L F
.97 .932 .643 r
.44239 .50297 m .44063 .5075 L .44255 .5063 L F
.715 .559 .677 r
.45897 .47638 m .46159 .47351 L .45889 .47322 L F
0 0 .018 r
.31623 .64155 m .3156 .64176 L .31721 .64065 L F
.713 .54 .653 r
.31444 .64395 m .31612 .64157 L .3156 .64176 L F
.31658 .6414 m .31721 .64065 L .31572 .64168 L F
.121 .656 .859 r
.31593 .64161 m .31623 .64155 L .31614 .64154 L F
.512 .076 .148 r
.31593 .64161 m .3156 .64176 L .31623 .64155 L F
.713 .54 .653 r
.31658 .6414 m .31593 .64161 L .3156 .64176 L F
.31593 .64161 m .31572 .64168 L .3156 .64176 L F
.512 .076 .148 r
.31548 .6417 m .3156 .64176 L .31593 .64161 L F
.121 .656 .859 r
.31548 .6417 m .31593 .64161 L .30793 .64086 L F
.31593 .64161 m .31614 .64154 L .30793 .64086 L F
.69 .374 .435 r
.30793 .64086 m .31614 .64154 L .31444 .64395 L F
.31614 .64154 m .31623 .64155 L .31444 .64395 L F
0 0 0 r
.31444 .64395 m .31623 .64155 L .31721 .64065 L F
.713 .54 .653 r
.31444 .64395 m .31658 .6414 L .31612 .64157 L F
.346 .823 .869 r
.58532 .35872 m .58485 .3586 L .58419 .35825 L F
.084 0 .005 r
.2461 .5226 m .24518 .52421 L .24818 .52172 L F
.857 .68 .662 r
.43752 .54778 m .43713 .5507 L .43903 .5495 L F
.864 .7 .676 r
.43713 .5507 m .43857 .55429 L .43903 .5495 L F
.262 0 .014 r
.55986 .47305 m .56141 .47445 L .55889 .47535 L F
.55986 .47305 m .56254 .47239 L .56141 .47445 L F
.624 .836 .982 r
.23259 .57585 m .23437 .57715 L .23613 .57598 L F
0 0 .456 r
.23259 .57585 m .23387 .5796 L .23437 .57715 L F
.588 .076 0 r
.23075 .56038 m .23391 .56357 L .23153 .56417 L F
0 0 0 r
.23184 .56517 m .23153 .56417 L .23391 .56357 L F
.23184 .56517 m .23025 .5663 L .23153 .56417 L F
.74 .745 .856 r
.42327 .579 m .42463 .58049 L .42257 .57951 L F
.875 .692 .652 r
.42144 .58226 m .42463 .58049 L .42327 .579 L F
.123 0 .214 r
.54128 .46919 m .53929 .47044 L .53866 .47248 L F
.986 .746 .486 r
.43225 .47613 m .43254 .47961 L .43081 .47822 L F
.208 .721 .885 r
.43225 .47613 m .43182 .47581 L .43479 .47598 L F
.556 .427 .66 r
.43225 .47613 m .43254 .47961 L .43479 .47598 L F
.599 .938 .754 r
.45722 .56647 m .45888 .56509 L .46154 .56375 L F
.299 .647 .968 r
.4345 .59449 m .43815 .59613 L .43653 .59281 L F
.979 .686 .373 r
.43653 .59281 m .43815 .59613 L .43666 .59532 L F
.553 0 0 r
.44047 .59647 m .43666 .59532 L .43815 .59613 L F
.797 .905 .917 r
.47012 .43681 m .46801 .43876 L .46644 .43743 L F
.556 .444 .682 r
.47554 .48955 m .47769 .48585 L .47472 .48643 L F
.47554 .48955 m .47828 .4895 L .47769 .48585 L F
.195 .14 .564 r
.47554 .48955 m .47759 .49115 L .47828 .4895 L F
.47554 .48955 m .47619 .49257 L .47759 .49115 L F
.844 .706 .71 r
.44296 .48515 m .44718 .4837 L .44568 .48294 L F
.44296 .48515 m .44593 .48597 L .44718 .4837 L F
.514 .872 .986 r
.44985 .48271 m .44568 .48294 L .44718 .4837 L F
.369 .415 .778 r
.39597 .48148 m .39659 .48249 L .3951 .48282 L F
.205 .733 .789 r
.39356 .48316 m .3951 .48282 L .39708 .48263 L F
.729 .308 .248 r
.3951 .48282 m .39857 .48416 L .39708 .48263 L F
.3951 .48282 m .39846 .48549 L .39857 .48416 L F
.369 .415 .778 r
.39659 .48249 m .39846 .48549 L .3951 .48282 L F
.205 .733 .789 r
.39282 .48327 m .3951 .48282 L .39356 .48316 L F
.763 .787 .873 r
.45944 .5067 m .46203 .5056 L .45803 .50514 L F
.898 .872 .434 r
.40555 .54773 m .40436 .54959 L .40382 .54694 L F
.40555 .54773 m .40461 .55037 L .40436 .54959 L F
.975 .91 .679 r
.38983 .60161 m .39099 .60253 L .39216 .6002 L F
.932 .97 .727 r
.39165 .59818 m .38983 .60161 L .39216 .6002 L F
.638 .545 .733 r
.3687 .68381 m .37156 .68125 L .36872 .68078 L F
.332 .275 .642 r
.35218 .56627 m .35071 .56747 L .34985 .56416 L F
.063 0 0 r
.33056 .6 m .32739 .60195 L .33042 .60067 L F
.462 .175 .391 r
.32628 .60499 m .33042 .60067 L .32739 .60195 L F
.339 .242 .596 r
.46512 .51857 m .46738 .52066 L .46696 .51798 L F
.861 .509 .385 r
.3764 .52802 m .37818 .53153 L .38032 .5315 L F
.761 .303 .162 r
.37818 .53153 m .37861 .53302 L .38032 .5315 L F
.909 .538 .313 r
.38032 .5315 m .37861 .53302 L .38089 .53388 L F
.966 .679 .437 r
.42456 .5136 m .42609 .51081 L .42458 .51235 L F
.42456 .5136 m .42635 .51502 L .42609 .51081 L F
.627 .43 .596 r
.42377 .50901 m .42807 .50933 L .42738 .50475 L F
.68 .592 .751 r
.42996 .50465 m .43006 .5077 L .43251 .50618 L F
.43337 .50545 m .43251 .50618 L .43361 .5055 L F
.42996 .50465 m .43251 .50618 L .43337 .50545 L F
0 0 .122 r
.42996 .50465 m .43016 .50746 L .43005 .50755 L F
.43006 .5076 m .43016 .50746 L .43006 .5077 L F
.481 .329 .597 r
.42738 .50475 m .42807 .50933 L .43016 .50746 L F
.511 .433 .704 r
.42377 .50901 m .42685 .51013 L .42807 .50933 L F
.691 .977 .8 r
.42807 .50933 m .42685 .51013 L .43016 .50746 L F
.744 .993 .849 r
.43016 .50746 m .42685 .51013 L .42753 .50989 L F
.43016 .50746 m .42753 .50989 L .42858 .50952 L F
.42969 .50858 m .42858 .50952 L .42941 .50923 L F
0 0 0 r
.43016 .50746 m .42941 .50923 L .43006 .5077 L F
.744 .993 .849 r
.43016 .50746 m .42858 .50952 L .42969 .50858 L F
.262 .492 .889 r
.42649 .50831 m .42812 .50848 L .42685 .51013 L F
.566 .82 .45 r
.42812 .50848 m .42719 .50965 L .42685 .51013 L F
0 0 0 r
.42685 .51013 m .42609 .51081 L .42651 .51061 L F
.42685 .51013 m .42458 .51235 L .42609 .51081 L F
.511 .433 .704 r
.42377 .50901 m .42458 .51235 L .42685 .51013 L F
.949 .624 .201 r
.42296 .50933 m .42456 .5136 L .42458 .51235 L F
.674 .866 .476 r
.42685 .51013 m .42456 .5136 L .42296 .50933 L F
.566 .82 .45 r
.42719 .50965 m .4255 .51179 L .42685 .51013 L F
0 0 0 r
.42685 .51013 m .42651 .51061 L .42941 .50923 L F
.722 .973 .927 r
.56201 .38681 m .56332 .38479 L .5635 .38473 L F
.56201 .38681 m .55969 .38682 L .56332 .38479 L F
0 0 0 r
.26324 .522 m .26274 .5219 L .26527 .52122 L F
.26324 .522 m .26085 .52387 L .26274 .5219 L F
.84 .906 .497 r
.6239 .37919 m .62551 .3747 L .62523 .3771 L F
.476 0 0 r
.62386 .37329 m .62551 .3747 L .62304 .37253 L F
.989 .738 .454 r
.62523 .3771 m .62551 .3747 L .62386 .37329 L F
.62523 .3771 m .62386 .37329 L .62652 .37505 L F
.62523 .3771 m .62652 .37505 L .62665 .37514 L F
.84 .906 .497 r
.62387 .37927 m .6239 .37919 L .62523 .3771 L F
.69 .962 .942 r
.62296 .37862 m .62387 .37927 L .62523 .3771 L F
.612 .804 .973 r
.264 .61265 m .26514 .61322 L .26108 .61206 L F
.264 .61265 m .26514 .61322 L .26108 .61206 L F
.901 .544 .356 r
.264 .61265 m .26514 .61322 L .2651 .61527 L F
.26 .012 .335 r
.2651 .61527 m .26514 .61322 L .26769 .61197 L F
0 0 0 r
.69786 .36288 m .69995 .35844 L .69896 .36074 L F
.69728 .36502 m .69786 .36288 L .69896 .36074 L F
.333 0 .221 r
.51086 .50407 m .50903 .50299 L .51149 .50206 L F
.51086 .50407 m .50835 .50479 L .50903 .50299 L F
0 0 0 r
.68607 .29419 m .68403 .2982 L .68554 .29608 L F
.634 .89 .56 r
.68403 .2982 m .68287 .29919 L .68554 .29608 L F
.711 .556 .677 r
.55568 .4379 m .55813 .43434 L .55451 .43449 L F
.603 .332 .478 r
.55846 .46225 m .55893 .45848 L .55723 .46059 L F
.806 .925 .915 r
.50558 .41395 m .50365 .41559 L .50217 .41442 L F
.915 .573 .378 r
.38269 .53785 m .38317 .54084 L .3854 .54145 L F
.918 .582 .389 r
.38317 .54084 m .3836 .54312 L .3854 .54145 L F
.892 .535 .359 r
.3854 .54145 m .3836 .54312 L .38581 .54378 L F
.732 .56 .658 r
.43345 .48943 m .43805 .48962 L .43729 .48508 L F
.338 .231 .583 r
.43729 .48508 m .4393 .48462 L .43958 .48185 L F
.499 .44 .722 r
.43805 .48962 m .4393 .48462 L .43729 .48508 L F
.516 .839 .539 r
.46922 .54666 m .46971 .54611 L .47097 .54498 L F
0 0 0 r
.46971 .54611 m .47232 .54351 L .47097 .54498 L F
0 0 .481 r
.4706 .5476 m .47027 .5458 L .46971 .54611 L F
0 0 0 r
.46971 .54611 m .47027 .5458 L .47232 .54351 L F
0 0 .53 r
.4706 .5476 m .47086 .54546 L .47027 .5458 L F
0 0 0 r
.47027 .5458 m .4704 .54574 L .47041 .54572 L F
.47027 .5458 m .47041 .54572 L .47232 .54351 L F
0 0 .53 r
.4706 .5476 m .47096 .54558 L .47086 .54546 L F
0 0 0 r
.47041 .54572 m .47415 .54224 L .47232 .54351 L F
.47037 .54577 m .47043 .54572 L .47041 .54572 L F
.47043 .54572 m .47415 .54224 L .47041 .54572 L F
0 0 .02 r
.47415 .54224 m .47355 .54151 L .47232 .54351 L F
.858 .697 .682 r
.47093 .54185 m .47415 .54224 L .47043 .54572 L F
0 0 .53 r
.47027 .54578 m .47042 .5457 L .47002 .54441 L F
.858 .697 .682 r
.47039 .54561 m .47043 .54572 L .47037 .54577 L F
.47093 .54185 m .47043 .54572 L .47039 .54561 L F
.47093 .54185 m .47041 .54552 L .47002 .54441 L F
.803 .639 .678 r
.46855 .54027 m .47093 .54185 L .47002 .54441 L F
0 0 .317 r
.47002 .54441 m .47043 .54536 L .46885 .54106 L F
.47002 .54441 m .46885 .54106 L .46855 .54027 L F
.858 .697 .682 r
.47041 .54552 m .47039 .54561 L .47002 .54441 L F
.47039 .54561 m .47037 .54577 L .47002 .54441 L F
0 0 .53 r
.47039 .54561 m .47086 .54546 L .47004 .54444 L F
.47042 .5457 m .47042 .5457 L .47039 .54561 L F
.47042 .5457 m .47086 .54546 L .47039 .54561 L F
.47042 .5457 m .47004 .54444 L .47002 .54441 L F
.47027 .5458 m .47041 .54572 L .47027 .54578 L F
.47041 .54572 m .47086 .54546 L .47027 .54578 L F
0 0 .481 r
.47027 .5458 m .47002 .54441 L .46971 .54611 L F
0 0 0 r
.46971 .54611 m .47037 .54577 L .4704 .54574 L F
0 0 .447 r
.47002 .54441 m .47029 .54545 L .46971 .54611 L F
.47029 .54545 m .47037 .54577 L .46971 .54611 L F
.516 .839 .539 r
.46794 .54788 m .46971 .54611 L .46922 .54666 L F
.575 .28 .43 r
.7068 .29973 m .7044 .29824 L .70681 .29686 L F
.276 0 .282 r
.35657 .61515 m .357 .61271 L .35929 .61205 L F
0 0 .232 r
.47591 .58342 m .47598 .58024 L .47696 .57881 L F
.857 .816 .809 r
.62635 .36228 m .62957 .36222 L .62869 .36121 L F
.308 .071 .383 r
.50571 .50809 m .50311 .51143 L .50352 .50905 L F
1 .822 .496 r
.57056 .44384 m .56896 .44536 L .56854 .44279 L F
.131 .613 .917 r
.56854 .44279 m .57056 .44384 L .57195 .44363 L F
.495 .516 .808 r
.57035 .44673 m .57195 .44363 L .57056 .44384 L F
1 .822 .496 r
.57056 .44384 m .57035 .44673 L .56996 .44634 L F
.57056 .44384 m .56996 .44634 L .5696 .44475 L F
.131 .613 .917 r
.56854 .44279 m .57195 .44363 L .57157 .44462 L F
.469 .289 .553 r
.56901 .44213 m .57157 .44462 L .57009 .44066 L F
.56854 .44279 m .56926 .44322 L .56901 .44213 L F
.56926 .44322 m .57157 .44462 L .56901 .44213 L F
1 .822 .496 r
.5696 .44475 m .56996 .44634 L .56896 .44536 L F
.459 .281 .551 r
.44309 .49595 m .44553 .49538 L .44547 .49265 L F
.625 .447 .621 r
.44303 .49832 m .44553 .49538 L .44309 .49595 L F
.895 .608 .101 r
.60803 .38787 m .6092 .39199 L .60865 .38915 L F
.596 .948 .907 r
.60865 .38915 m .61052 .3874 L .60803 .38787 L F
.60865 .38915 m .61121 .38798 L .61052 .3874 L F
.532 .196 .344 r
.24399 .58008 m .24774 .57978 L .24803 .57778 L F
.873 .823 .796 r
.24774 .57978 m .25088 .57564 L .24803 .57778 L F
.641 .483 .653 r
.4673 .49928 m .47041 .49864 L .4701 .49587 L F
.731 .553 .651 r
.4673 .49928 m .47122 .50217 L .47041 .49864 L F
.4673 .49928 m .46927 .50324 L .47122 .50217 L F
.729 .6 .712 r
.33018 .6449 m .33385 .64507 L .33106 .64854 L F
.984 .873 .643 r
.30607 .64785 m .30649 .65016 L .30485 .65021 L F
.297 .775 .678 r
.30645 .6499 m .30649 .65016 L .30485 .65021 L F
.67 .933 .645 r
.30754 .64919 m .30651 .65026 L .30649 .65016 L F
.297 .775 .678 r
.30735 .64972 m .30649 .65016 L .30645 .6499 L F
.67 .933 .645 r
.30651 .65026 m .30476 .65206 L .30649 .65016 L F
0 0 .007 r
.24632 .53072 m .24462 .53456 L .24543 .53195 L F
.6 .927 .708 r
.66605 .37242 m .66262 .37481 L .6644 .37305 L F
.652 .957 .756 r
.66766 .37037 m .66605 .37242 L .6644 .37305 L F
.691 .886 .51 r
.54346 .45124 m .54442 .45022 L .54591 .44765 L F
.466 0 0 r
.23116 .58233 m .23519 .58529 L .23547 .58519 L F
.313 .776 .646 r
.23547 .58519 m .23708 .58439 L .2384 .58559 L F
.23547 .58519 m .23519 .58529 L .23708 .58439 L F
.653 .417 .549 r
.52401 .43758 m .52039 .43644 L .52399 .43623 L F
0 0 0 r
.52398 .43846 m .52401 .43758 L .52399 .43623 L F
.52398 .43846 m .52217 .44096 L .52385 .43787 L F
.428 .552 .878 r
.52488 .44083 m .52217 .44096 L .52398 .43846 L F
.486 0 0 r
.52418 .43928 m .52398 .43846 L .52318 .43668 L F
.52462 .44042 m .52398 .43846 L .52418 .43928 L F
0 0 0 r
.52398 .43846 m .52385 .43787 L .52401 .43758 L F
.758 .749 .845 r
.45537 .5085 m .45944 .5067 L .45803 .50514 L F
.183 0 .266 r
.50835 .50479 m .50571 .50809 L .5063 .50588 L F
0 0 0 r
.68619 .34241 m .68398 .3441 L .68293 .34524 L F
.954 .749 .588 r
.41151 .59596 m .41022 .59677 L .41059 .59344 L F
.705 .617 .756 r
.47041 .49864 m .47294 .49524 L .4701 .49587 L F
.73 .943 .953 r
.42541 .59281 m .4277 .59331 L .42439 .59487 L F
0 0 .08 r
.42801 .59442 m .4277 .59331 L .42541 .59281 L F
.962 .807 .642 r
.33984 .56112 m .33864 .55837 L .33998 .55936 L F
.33984 .56112 m .33903 .56385 L .33864 .55837 L F
.068 .111 .599 r
.27917 .6454 m .27929 .64838 L .28113 .64671 L F
.487 .835 .562 r
.28113 .64671 m .27929 .64838 L .27769 .64967 L F
.526 .522 .793 r
.33251 .54365 m .33357 .5403 L .33114 .54098 L F
.33251 .54365 m .33475 .54399 L .33357 .5403 L F
0 0 0 r
.32575 .63099 m .32475 .63171 L .32679 .62904 L F
.612 .387 .551 r
.32964 .62793 m .32575 .63099 L .32679 .62904 L F
0 0 0 r
.73034 .3102 m .72603 .30813 L .72763 .30972 L F
0 .215 .739 r
.726 .30683 m .72763 .30972 L .72603 .30813 L F
.726 .30683 m .72763 .30972 L .72603 .30813 L F
0 0 0 r
.73577 .30416 m .73485 .30542 L .73505 .3029 L F
.702 .72 .863 r
.73734 .29956 m .73577 .30416 L .73505 .3029 L F
.73734 .29956 m .73903 .30296 L .73577 .30416 L F
.96 .912 .723 r
.55702 .39128 m .55557 .39165 L .55743 .388 L F
.949 .928 .747 r
.55702 .39128 m .55519 .39239 L .55557 .39165 L F
.55702 .39128 m .55539 .39428 L .55519 .39239 L F
.962 .772 .6 r
.55311 .42469 m .55261 .42706 L .55128 .42337 L F
.612 .554 .765 r
.45517 .5057 m .45537 .5085 L .45803 .50514 L F
.763 .581 .651 r
.73811 .31693 m .73506 .31551 L .73735 .3156 L F
.929 .944 .784 r
.735 .31922 m .73811 .31693 L .73735 .3156 L F
.735 .31922 m .73579 .32059 L .73811 .31693 L F
.431 .648 .95 r
.54309 .40063 m .54177 .40134 L .53913 .39795 L F
0 0 0 r
.53802 .41935 m .53986 .41751 L .54072 .41481 L F
.654 .511 .676 r
.54072 .41481 m .54329 .41475 L .54346 .41175 L F
0 0 0 r
.54072 .41481 m .5438 .41713 L .54329 .41475 L F
.746 .969 .93 r
.5405 .4183 m .53986 .41751 L .53802 .41935 L F
.54033 .41809 m .53918 .41737 L .53986 .41751 L F
.5405 .4183 m .54031 .41817 L .54033 .41809 L F
.53964 .4177 m .53966 .41767 L .54033 .41809 L F
.828 .531 .488 r
.5438 .41713 m .54032 .41731 L .5405 .4183 L F
.221 0 .311 r
.53986 .41751 m .53986 .41757 L .54036 .4171 L F
.54036 .41709 m .54036 .4171 L .54051 .41696 L F
.53986 .41751 m .54036 .4171 L .54036 .41709 L F
.605 .31 .442 r
.5438 .41713 m .54629 .41862 L .54345 .41877 L F
.746 .969 .93 r
.54031 .41817 m .53964 .4177 L .54033 .41809 L F
.828 .531 .488 r
.54032 .41731 m .53964 .4177 L .5405 .4183 L F
.221 0 .311 r
.53986 .41757 m .53984 .41825 L .54033 .4173 L F
.809 .658 .695 r
.54345 .41877 m .54129 .41861 L .54001 .41786 L F
.746 .969 .93 r
.53964 .4177 m .53918 .41737 L .53966 .41767 L F
.92 .683 .564 r
.53918 .41737 m .53984 .41825 L .53986 .41751 L F
.809 .658 .695 r
.5401 .41767 m .54001 .41786 L .53918 .41737 L F
.834 .915 .517 r
.54004 .41782 m .53984 .41825 L .53994 .418 L F
.828 .531 .488 r
.54032 .41731 m .53918 .41737 L .53964 .4177 L F
0 0 0 r
.54072 .41481 m .53986 .41751 L .54124 .41556 L F
.828 .531 .488 r
.54032 .41731 m .54031 .41735 L .53918 .41737 L F
.834 .915 .517 r
.54022 .41749 m .54013 .41768 L .54004 .41782 L F
.54031 .41735 m .54013 .41768 L .54022 .41749 L F
.828 .531 .488 r
.54031 .41735 m .54023 .41772 L .5401 .41767 L F
.54031 .41735 m .5401 .41767 L .53918 .41737 L F
.221 0 .311 r
.53986 .41757 m .54033 .4173 L .54051 .41696 L F
.834 .915 .517 r
.54051 .41696 m .54031 .41735 L .54022 .41749 L F
.54013 .41768 m .53984 .41825 L .54004 .41782 L F
.726 .797 .908 r
.53802 .41935 m .53656 .41933 L .53709 .41942 L F
.53656 .41933 m .53437 .4193 L .53709 .41942 L F
.809 .658 .695 r
.54345 .41877 m .54001 .41786 L .5401 .41767 L F
.221 0 .311 r
.53986 .41751 m .54051 .41696 L .54124 .41556 L F
.834 .915 .517 r
.54053 .41682 m .53994 .418 L .54062 .41628 L F
.828 .531 .488 r
.54379 .41715 m .5435 .41851 L .54217 .41818 L F
.5435 .41851 m .54348 .41862 L .54305 .4185 L F
.5435 .41851 m .54305 .4185 L .54023 .41772 L F
.54348 .41862 m .54298 .41862 L .54023 .41772 L F
.377 .411 .769 r
.54559 .41645 m .54629 .41862 L .5438 .41713 L F
.09 0 .421 r
.5479 .415 m .54629 .41862 L .54559 .41645 L F
.226 0 0 r
.54169 .41849 m .54473 .4186 L .54636 .41705 L F
.54129 .41861 m .5415 .41861 L .54169 .41849 L F
.5415 .41861 m .54473 .4186 L .54169 .41849 L F
.828 .531 .488 r
.5438 .41713 m .54379 .41715 L .54023 .41772 L F
.54379 .41715 m .54217 .41818 L .54023 .41772 L F
.5438 .41713 m .54023 .41772 L .54032 .41731 L F
0 0 0 r
.54177 .4156 m .54124 .41556 L .5438 .41713 L F
.881 .48 .26 r
.54124 .41556 m .5438 .41713 L .54329 .41475 L F
.403 .499 .843 r
.54476 .41501 m .5438 .41713 L .54124 .41556 L F
.54476 .41501 m .54559 .41645 L .5438 .41713 L F
.226 0 0 r
.54123 .41848 m .54636 .41705 L .54049 .41694 L F
.54129 .41861 m .54169 .41849 L .54123 .41848 L F
.54169 .41849 m .54636 .41705 L .54123 .41848 L F
0 0 0 r
.54072 .41481 m .54124 .41556 L .54177 .4156 L F
.741 .735 .845 r
.54254 .41145 m .53997 .41791 L .53954 .41096 L F
.53997 .41791 m .53984 .41825 L .53982 .41783 L F
.53997 .41791 m .53982 .41783 L .53954 .41096 L F
.788 .77 .837 r
.53954 .41096 m .53982 .41783 L .53653 .41349 L F
.53982 .41783 m .53984 .41825 L .53946 .4177 L F
.524 .826 1 r
.54001 .41786 m .53986 .41785 L .53918 .41737 L F
.53986 .41785 m .53984 .41784 L .53918 .41737 L F
.788 .77 .837 r
.53982 .41783 m .53946 .4177 L .53653 .41349 L F
.524 .826 1 r
.53986 .41785 m .53985 .41785 L .53984 .41784 L F
0 0 .06 r
.53918 .41737 m .5385 .41842 L .53709 .41942 L F
.653 .901 .982 r
.53908 .41747 m .53898 .41742 L .53918 .41737 L F
.53709 .41942 m .53898 .41742 L .53908 .41747 L F
.428 0 0 r
.5323 .41658 m .53709 .41942 L .53437 .4193 L F
.5327 .41682 m .53513 .41839 L .53611 .41884 L F
.5323 .41658 m .53513 .41839 L .5327 .41682 L F
.054 .343 .82 r
.53434 .41652 m .53513 .41839 L .53464 .41808 L F
.53434 .41652 m .53464 .41808 L .5323 .41658 L F
.694 .574 .716 r
.53242 .41375 m .53517 .41045 L .53025 .40928 L F
.53242 .41375 m .53493 .41305 L .53517 .41045 L F
.687 .547 .69 r
.53242 .41375 m .5323 .41658 L .53493 .41305 L F
0 0 .196 r
.53408 .41508 m .53411 .41525 L .53346 .41497 L F
.53411 .41525 m .53434 .41652 L .53401 .41593 L F
.85 .752 .754 r
.53411 .41525 m .53434 .41652 L .53545 .41425 L F
0 0 .196 r
.53527 .41462 m .53501 .41527 L .53545 .41425 L F
.53434 .41652 m .53501 .41527 L .53527 .41462 L F
.428 0 0 r
.53611 .41884 m .53513 .41839 L .53709 .41942 L F
.653 .901 .982 r
.53709 .41942 m .53513 .41839 L .53898 .41742 L F
.9 .983 .79 r
.53675 .41944 m .53836 .41807 L .53513 .41839 L F
.53836 .41807 m .53918 .41737 L .53529 .41835 L F
.53836 .41807 m .53529 .41835 L .53513 .41839 L F
0 0 .06 r
.5385 .41842 m .53778 .41954 L .53723 .41944 L F
.5385 .41842 m .53723 .41944 L .53709 .41942 L F
.53778 .41954 m .5362 .422 L .53709 .41942 L F
.381 .075 .316 r
.53709 .41942 m .5362 .422 L .53378 .42256 L F
.9 .983 .79 r
.53596 .42012 m .5362 .422 L .5385 .41842 L F
.53836 .41807 m .5385 .41842 L .53918 .41737 L F
.53596 .42012 m .5385 .41842 L .53836 .41807 L F
.92 .683 .564 r
.53918 .41737 m .53775 .41768 L .53984 .41825 L F
.569 .697 .928 r
.53775 .41768 m .53946 .4177 L .53984 .41825 L F
.524 .826 1 r
.53985 .41785 m .53775 .41768 L .53955 .4177 L F
.53976 .41821 m .53775 .41768 L .54001 .41786 L F
.53899 .41801 m .53943 .41766 L .5382 .41768 L F
.53826 .41782 m .5382 .41768 L .53775 .41768 L F
.53899 .41801 m .5382 .41768 L .53826 .41782 L F
.53955 .4177 m .53775 .41768 L .53897 .41742 L F
.53985 .41785 m .53897 .41742 L .53918 .41737 L F
.569 .697 .928 r
.53775 .41768 m .53653 .41349 L .53946 .4177 L F
.524 .826 1 r
.53943 .41766 m .54026 .417 L .53775 .41768 L F
.53901 .41801 m .53902 .41801 L .53899 .41801 L F
.53902 .41801 m .54026 .417 L .53899 .41801 L F
.569 .697 .928 r
.53775 .41768 m .53743 .41472 L .53653 .41349 L F
0 0 0 r
.53474 .41591 m .53501 .41527 L .53751 .41435 L F
0 0 .196 r
.53501 .41527 m .53434 .41652 L .53411 .41524 L F
.751 .994 .858 r
.53413 .41509 m .53411 .41525 L .53545 .41425 L F
.53413 .41509 m .53545 .41425 L .5344 .41514 L F
.99 .813 .571 r
.531 .41542 m .5323 .41658 L .53242 .41375 L F
.054 .343 .82 r
.53434 .41652 m .5323 .41658 L .531 .41542 L F
.59 .523 .748 r
.52923 .4142 m .53242 .41375 L .53025 .40928 L F
.99 .813 .571 r
.531 .41542 m .53242 .41375 L .52923 .4142 L F
.389 .507 .857 r
.5324 .41311 m .53434 .41652 L .531 .41542 L F
.549 .031 0 r
.53478 .41511 m .53501 .41527 L .53369 .41651 L F
.53545 .41425 m .53501 .41527 L .53478 .41511 L F
0 0 .196 r
.53501 .41527 m .53411 .41524 L .53398 .41454 L F
.53501 .41527 m .53398 .41454 L .53395 .4144 L F
.53501 .41527 m .53484 .41596 L .53434 .41652 L F
.53434 .41652 m .53484 .41596 L .53501 .41527 L F
0 0 0 r
.53369 .41651 m .53501 .41527 L .53474 .41591 L F
0 0 .196 r
.53411 .41525 m .53401 .41593 L .53359 .4152 L F
.85 .752 .754 r
.52952 .41866 m .53434 .41652 L .5341 .41526 L F
.549 .031 0 r
.5344 .41514 m .53369 .41651 L .53152 .41757 L F
.53545 .41425 m .53478 .41511 L .5344 .41514 L F
.85 .752 .754 r
.5341 .41526 m .53434 .41652 L .53411 .41525 L F
.549 .031 0 r
.53478 .41511 m .53369 .41651 L .5344 .41514 L F
0 0 .196 r
.53394 .41518 m .53359 .4152 L .53346 .41497 L F
.53411 .41525 m .53359 .4152 L .53394 .41518 L F
.751 .994 .858 r
.52837 .41876 m .52952 .41866 L .53411 .41525 L F
.52837 .41876 m .53411 .41525 L .53413 .41509 L F
.52837 .41876 m .53413 .41509 L .53152 .41757 L F
.53413 .41509 m .5344 .41514 L .53152 .41757 L F
0 0 .196 r
.53395 .4144 m .53408 .41508 L .5324 .41311 L F
.53408 .41508 m .53346 .41497 L .5324 .41311 L F
0 .122 .672 r
.53434 .41652 m .53484 .41596 L .53513 .41839 L F
.743 .281 .155 r
.53391 .41783 m .53513 .41839 L .53484 .41596 L F
.5333 .41908 m .53513 .41839 L .53391 .41783 L F
.9 .983 .79 r
.53596 .42012 m .53675 .41944 L .53513 .41839 L F
.524 .826 1 r
.54129 .41861 m .54049 .41694 L .54026 .417 L F
.54129 .41861 m .53976 .41821 L .54001 .41786 L F
.834 .915 .517 r
.54051 .41696 m .53994 .418 L .54053 .41682 L F
.524 .826 1 r
.54129 .41861 m .54026 .417 L .53901 .41801 L F
.006 .582 .715 r
.54629 .41862 m .54473 .4186 L .5415 .41861 L F
.54195 .41861 m .5415 .41861 L .54129 .41861 L F
.54629 .41862 m .5415 .41861 L .54195 .41861 L F
.828 .531 .488 r
.54348 .41862 m .54345 .41877 L .54298 .41862 L F
.834 .915 .517 r
.54124 .41556 m .54051 .41696 L .54092 .41554 L F
.54051 .41696 m .54062 .41628 L .54092 .41554 L F
.54124 .41556 m .54092 .41554 L .54254 .41145 L F
.928 .673 .53 r
.59351 .44513 m .59689 .44405 L .59338 .44245 L F
.59351 .44513 m .59684 .44674 L .59689 .44405 L F
.468 .26 .513 r
.63609 .35102 m .63438 .35017 L .63415 .35198 L F
.989 .732 .364 r
.4417 .56757 m .44023 .56358 L .43987 .56623 L F
.331 .062 .347 r
.44171 .56978 m .4417 .56757 L .4396 .57033 L F
.824 .71 .739 r
.4396 .57033 m .4417 .56757 L .43987 .56623 L F
1 .809 .504 r
.40843 .56102 m .40657 .56211 L .40686 .55987 L F
.40843 .56102 m .40789 .56423 L .40657 .56211 L F
.333 0 0 r
.33621 .49607 m .33834 .49561 L .33412 .49538 L F
.378 0 0 r
.33888 .4968 m .33834 .49561 L .33621 .49607 L F
.33888 .4968 m .34056 .49613 L .33834 .49561 L F
.574 .153 .205 r
.43964 .53086 m .43623 .53213 L .43615 .52986 L F
.711 .556 .677 r
.55568 .4379 m .55451 .43449 L .55526 .43679 L F
.6 .465 .669 r
.37437 .59968 m .37167 .60307 L .37203 .60093 L F
.734 .766 .879 r
.46431 .46734 m .46568 .46326 L .46234 .46553 L F
.354 .33 .694 r
.62935 .39386 m .62756 .39467 L .62672 .39214 L F
.549 .759 .975 r
.36431 .62862 m .36066 .62765 L .36287 .62549 L F
0 .153 .69 r
.36489 .6274 m .36431 .62862 L .36287 .62549 L F
0 .073 .611 r
.63459 .38991 m .63333 .39052 L .63613 .38926 L F
.976 .732 .501 r
.59532 .4367 m .59348 .43328 L .59424 .4354 L F
.984 .907 .617 r
.59361 .43996 m .59532 .4367 L .59424 .4354 L F
.728 .665 .788 r
.47081 .47241 m .47244 .47603 L .47485 .47287 L F
.608 .493 .696 r
.47244 .47603 m .47528 .47613 L .47485 .47287 L F
.542 .351 .571 r
.47244 .47603 m .47523 .47848 L .47528 .47613 L F
.47244 .47603 m .47254 .47942 L .47523 .47848 L F
.228 0 .189 r
.23701 .53052 m .23838 .53269 L .23928 .52848 L F
.23701 .53052 m .23618 .53357 L .23838 .53269 L F
.592 .233 .33 r
.31544 .57708 m .31768 .57909 L .31513 .57865 L F
.591 .233 .331 r
.31544 .57708 m .31851 .57724 L .31768 .57909 L F
.489 .452 .743 r
.47364 .5286 m .4761 .52731 L .47585 .52413 L F
.538 .422 .669 r
.47392 .53144 m .4761 .52731 L .47364 .5286 L F
.909 .503 .179 r
.39257 .56543 m .39359 .56416 L .39205 .56301 L F
.39257 .56543 m .39466 .56693 L .39359 .56416 L F
.585 .94 .924 r
.64641 .32982 m .64594 .32941 L .64837 .32807 L F
.703 .784 .914 r
.44464 .50467 m .44356 .50165 L .44239 .50297 L F
.44464 .50467 m .4477 .50294 L .44356 .50165 L F
.613 .855 .492 r
.35249 .55211 m .35191 .5528 L .35104 .55411 L F
.5 .611 .894 r
.35104 .55411 m .35417 .55459 L .35249 .55211 L F
.34 .669 .975 r
.35191 .5528 m .35417 .55459 L .35104 .55411 L F
0 0 .123 r
.69414 .33235 m .69256 .33716 L .69187 .33588 L F
.883 .98 .828 r
.69187 .33588 m .69256 .33716 L .69037 .33752 L F
0 0 .064 r
.48065 .56575 m .47961 .56736 L .4807 .56367 L F
0 0 .218 r
.47946 .57011 m .47961 .56736 L .48065 .56575 L F
.973 .667 .299 r
.39393 .57239 m .39496 .57064 L .39393 .56946 L F
.39393 .57239 m .3953 .57347 L .39496 .57064 L F
.247 .321 .743 r
.46794 .54788 m .47069 .55025 L .46971 .54611 L F
.397 .337 .673 r
.46868 .55119 m .47069 .55025 L .46794 .54788 L F
0 0 .461 r
.32873 .51534 m .33032 .51658 L .33246 .51375 L F
.19 0 0 r
.519 .40045 m .52328 .39933 L .5196 .40175 L F
.993 .865 .598 r
.52005 .40223 m .519 .40045 L .5196 .40175 L F
.52005 .40223 m .51858 .40207 L .519 .40045 L F
.886 .888 .827 r
.5183 .40581 m .51858 .40207 L .52005 .40223 L F
.73 .949 .95 r
.45697 .46957 m .45602 .46866 L .45368 .47004 L F
.787 .918 .926 r
.46065 .46725 m .45602 .46866 L .45697 .46957 L F
0 0 0 r
.36138 .63508 m .36024 .63575 L .36026 .63585 L F
.36138 .63508 m .35693 .63814 L .3601 .63709 L F
.36259 .63336 m .3601 .63709 L .36077 .63395 L F
.36035 .63621 m .3601 .63709 L .36009 .63761 L F
.36077 .63395 m .36032 .63607 L .36035 .63621 L F
.36032 .63607 m .3601 .63709 L .36035 .63621 L F
.36026 .63585 m .35905 .63645 L .35693 .63814 L F
.36024 .63575 m .35905 .63645 L .36026 .63585 L F
.792 .709 .772 r
.47122 .50217 m .46927 .50324 L .46884 .50558 L F
.505 .321 .565 r
.46884 .50558 m .47059 .50465 L .47122 .50217 L F
.71 .939 .96 r
.47972 .43121 m .47469 .4324 L .47837 .43039 L F
.793 .998 .85 r
.48249 .42851 m .47972 .43121 L .48058 .42891 L F
.714 .936 .96 r
.48058 .42891 m .47972 .43121 L .47837 .43039 L F
.723 .315 .274 r
.61199 .3855 m .608 .38161 L .60637 .38132 L F
.86 .995 .817 r
.61259 .38526 m .61203 .38548 L .61199 .38553 L F
.61241 .38545 m .61199 .38553 L .61052 .3874 L F
.61259 .38526 m .61199 .38553 L .61241 .38545 L F
.331 0 0 r
.60947 .38565 m .61179 .38558 L .60678 .38457 L F
.61179 .38558 m .61208 .38557 L .61195 .38554 L F
.61179 .38558 m .61195 .38554 L .60678 .38457 L F
.389 .153 .431 r
.61052 .3874 m .61332 .38383 L .61208 .38557 L F
.723 .315 .274 r
.61208 .38557 m .61201 .38549 L .61199 .3855 L F
.61201 .38549 m .608 .38161 L .61199 .3855 L F
.86 .995 .817 r
.61121 .38798 m .61259 .38526 L .61052 .3874 L F
.61259 .38526 m .61332 .38383 L .61203 .38548 L F
0 0 .061 r
.46813 .55355 m .46701 .55763 L .46556 .55668 L F
.797 .976 .906 r
.55791 .41806 m .55374 .41981 L .55636 .4175 L F
.996 .809 .538 r
.56378 .44886 m .56499 .45052 L .56406 .45225 L F
.228 .643 .957 r
.32136 .65914 m .32383 .6612 L .32551 .66091 L F
.564 .929 .933 r
.4159 .46856 m .41462 .46828 L .41341 .46983 L F
.602 .932 .722 r
.41462 .46828 m .4115 .47083 L .41341 .46983 L F
.46 .296 .571 r
.27254 .55112 m .27259 .55425 L .27488 .55339 L F
.27488 .55339 m .27259 .55425 L .27254 .55112 L F
.984 .709 .415 r
.29523 .65497 m .29589 .65127 L .2977 .65409 L F
.29523 .65497 m .29376 .65206 L .29589 .65127 L F
.335 0 0 r
.29794 .65577 m .29523 .65497 L .29537 .65817 L F
0 0 .177 r
.29579 .65666 m .29523 .65497 L .2977 .65409 L F
.29579 .65666 m .29537 .65817 L .29523 .65497 L F
0 0 0 r
.5635 .38473 m .5655 .38348 L .5668 .38181 L F
.382 .809 .633 r
.5635 .38473 m .56332 .38479 L .5655 .38348 L F
.063 .628 .739 r
.33204 .49488 m .32717 .49505 L .32997 .4947 L F
.283 0 0 r
.32997 .4947 m .33412 .49538 L .33204 .49488 L F
.591 .024 0 r
.38544 .51079 m .38112 .50798 L .38432 .50984 L F
.751 .729 .832 r
.42312 .48531 m .42658 .4857 L .42537 .4873 L F
0 0 0 r
.42796 .48394 m .42537 .4873 L .42658 .4857 L F
.193 0 .373 r
.49383 .52776 m .49339 .5304 L .49079 .53142 L F
.088 0 .358 r
.49269 .53273 m .49079 .53142 L .49339 .5304 L F
.49269 .53273 m .49128 .5339 L .49079 .53142 L F
.541 .424 .669 r
.34063 .52233 m .3432 .52203 L .34281 .51781 L F
.636 .464 .632 r
.34063 .52233 m .3438 .5246 L .3432 .52203 L F
.34063 .52233 m .34118 .52517 L .3438 .5246 L F
.758 .867 .928 r
.4278 .46226 m .43241 .46148 L .43061 .45981 L F
.639 .813 .967 r
.43061 .45981 m .43241 .46148 L .43479 .46035 L F
.778 .996 .862 r
.69772 .33045 m .69432 .33328 L .69414 .33235 L F
.387 .487 .839 r
.6731 .35914 m .67057 .35941 L .67252 .35775 L F
.469 .063 .186 r
.27455 .62818 m .27264 .62743 L .26927 .62973 L F
.957 .871 .711 r
.53461 .46929 m .53623 .46733 L .53735 .46634 L F
0 0 0 r
.38118 .48971 m .38239 .48821 L .38338 .48647 L F
.382 .822 .952 r
.38338 .48647 m .38634 .48582 L .38675 .48617 L F
0 0 0 r
.38338 .48647 m .38368 .48651 L .38634 .48582 L F
.38338 .48647 m .38239 .48821 L .38368 .48651 L F
.533 .919 .918 r
.44312 .59659 m .44465 .59682 L .44724 .59549 L F
.672 .577 .74 r
.46545 .47347 m .46825 .47299 L .46776 .47014 L F
.714 .786 .303 r
.70122 .35123 m .70056 .3533 L .70186 .34986 L F
0 0 0 r
.70186 .34986 m .7034 .34522 L .70258 .34765 L F
.709 .785 .303 r
.70122 .35123 m .70186 .34986 L .70258 .34765 L F
.914 .626 .136 r
.38675 .48617 m .38634 .48582 L .38591 .48281 L F
.808 .895 .905 r
.61473 .36908 m .61181 .37173 L .6097 .37016 L F
0 0 0 r
.29099 .64693 m .2898 .64907 L .2917 .64497 L F
0 .016 .538 r
.29331 .64338 m .29172 .64451 L .29185 .64097 L F
.29331 .64338 m .29185 .64097 L .29233 .64113 L F
.644 .221 .224 r
.28833 .64396 m .29231 .64111 L .28507 .64165 L F
.335 .115 .424 r
.2935 .64152 m .29185 .64097 L .29232 .6411 L F
.644 .221 .224 r
.29231 .64111 m .29232 .6411 L .29231 .6411 L F
.29231 .64111 m .29231 .6411 L .28507 .64165 L F
0 .016 .538 r
.29242 .64126 m .29233 .64113 L .29237 .64114 L F
.29331 .64338 m .29233 .64113 L .29242 .64126 L F
.29346 .64183 m .29237 .64114 L .2935 .64152 L F
.29331 .64338 m .29237 .64114 L .29346 .64183 L F
.502 0 0 r
.28507 .64165 m .29231 .6411 L .28827 .64013 L F
.29231 .6411 m .29232 .6411 L .29231 .6411 L F
.29231 .6411 m .29231 .6411 L .28827 .64013 L F
.386 0 0 r
.2935 .64152 m .28833 .64396 L .29331 .64338 L F
.411 .859 .893 r
.2941 .64282 m .29331 .64338 L .29015 .64351 L F
.29544 .64258 m .29331 .64338 L .2941 .64282 L F
0 .016 .538 r
.29331 .64338 m .2917 .64497 L .29172 .64451 L F
0 0 0 r
.29099 .64693 m .2917 .64497 L .29331 .64338 L F
.832 1 .813 r
.55315 .39806 m .54962 .40062 L .55207 .39904 L F
.794 .708 .77 r
.55539 .39428 m .55315 .39806 L .55225 .39466 L F
.764 .83 .903 r
.55539 .39428 m .55225 .39466 L .55519 .39239 L F
.227 .149 .555 r
.55315 .39806 m .55519 .39239 L .55225 .39466 L F
.55315 .39806 m .55541 .39671 L .55519 .39239 L F
.72 .641 .77 r
.5536 .4011 m .55315 .39806 L .55207 .39904 L F
.5536 .4011 m .55541 .39671 L .55315 .39806 L F
.86 .533 .432 r
.38902 .51466 m .38544 .51079 L .38803 .5127 L F
.672 .21 .146 r
.61879 .39543 m .62063 .39364 L .61506 .39402 L F
.264 .765 .729 r
.62293 .39288 m .62063 .39364 L .62102 .39329 L F
0 0 0 r
.62102 .39329 m .62063 .39364 L .61879 .39543 L F
.406 .858 .818 r
.38118 .48971 m .3764 .49115 L .37895 .49085 L F
.064 .193 .688 r
.38118 .48971 m .38321 .49158 L .38239 .48821 L F
.491 0 0 r
.38118 .48978 m .38118 .48971 L .37895 .49085 L F
.38118 .48978 m .38321 .49158 L .38118 .48971 L F
0 0 0 r
.24301 .52512 m .24008 .52798 L .24264 .52583 L F
.186 0 .203 r
.23928 .52848 m .24264 .52583 L .24008 .52798 L F
.23928 .52848 m .24135 .5298 L .24264 .52583 L F
0 0 .1 r
.23928 .52848 m .23838 .53269 L .23979 .53151 L F
.341 0 0 r
.57117 .42206 m .56729 .42272 L .56856 .42137 L F
.344 0 0 r
.57114 .42137 m .57117 .42206 L .56856 .42137 L F
.533 .375 .612 r
.37437 .59968 m .37444 .60277 L .37167 .60307 L F
.498 .244 .46 r
.37444 .60277 m .37131 .60562 L .37167 .60307 L F
.548 .485 .737 r
.47199 .50609 m .47506 .50532 L .47059 .50465 L F
.47199 .50609 m .4753 .50823 L .47506 .50532 L F
.866 .437 .013 r
.59695 .39879 m .59642 .3997 L .59588 .39731 L F
.59695 .39879 m .5979 .40097 L .59642 .3997 L F
.795 .502 .492 r
.42758 .52168 m .43118 .52344 L .4319 .52215 L F
.73 .937 .955 r
.30249 .65125 m .30067 .65408 L .2987 .65422 L F
.30249 .65125 m .30476 .65206 L .30067 .65408 L F
.845 .87 .86 r
.60925 .37811 m .60637 .38132 L .608 .38161 L F
.723 .315 .274 r
.61208 .38557 m .61083 .38272 L .608 .38161 L F
.911 .658 .544 r
.59651 .44878 m .59832 .4473 L .59684 .44674 L F
.59651 .44878 m .59827 .45 L .59832 .4473 L F
.562 .578 .827 r
.32888 .63399 m .3312 .63998 L .32698 .63949 L F
.476 0 0 r
.62386 .37329 m .62304 .37253 L .62126 .37133 L F
.279 0 .101 r
.36214 .59003 m .36087 .59248 L .35854 .59274 L F
.649 .255 .285 r
.36461 .59201 m .36087 .59248 L .36214 .59003 L F
0 0 0 r
.70057 .35339 m .70056 .3533 L .70122 .35123 L F
.70057 .35339 m .70035 .35594 L .70056 .3533 L F
.548 .589 .847 r
.2724 .64506 m .27304 .64075 L .27379 .64339 L F
.64 .095 0 r
.27379 .64339 m .2748 .6452 L .2724 .64506 L F
.27379 .64339 m .27658 .64468 L .2748 .6452 L F
.563 0 0 r
.34756 .49976 m .3488 .49934 L .34483 .49802 L F
.685 .138 0 r
.35094 .50151 m .3488 .49934 L .34756 .49976 L F
0 0 0 r
.33042 .60067 m .33279 .59913 L .33056 .6 L F
.461 .343 .633 r
.63853 .38794 m .64178 .39025 L .64199 .38644 L F
.337 0 0 r
.64385 .38822 m .64199 .38644 L .64178 .39025 L F
.64385 .38822 m .64455 .38638 L .64199 .38644 L F
.708 .603 .737 r
.47041 .49864 m .47122 .50217 L .47389 .49893 L F
.674 .552 .708 r
.47122 .50217 m .47497 .50231 L .47389 .49893 L F
.646 .434 .581 r
.47059 .50465 m .47497 .50231 L .47122 .50217 L F
.635 .2 .198 r
.27656 .57566 m .27918 .57613 L .28085 .57427 L F
.448 .311 .602 r
.28126 .57695 m .28222 .57452 L .28085 .57427 L F
.28126 .57695 m .28363 .57626 L .28222 .57452 L F
.654 .223 .212 r
.28085 .57427 m .28363 .57626 L .28222 .57452 L F
.28085 .57427 m .27918 .57613 L .28363 .57626 L F
.015 .46 .871 r
.23924 .54236 m .23927 .54212 L .23661 .54126 L F
.836 .596 .576 r
.70661 .31237 m .70883 .31112 L .70863 .30987 L F
.70661 .31237 m .71077 .31419 L .70883 .31112 L F
0 0 .183 r
.48406 .55324 m .48306 .55698 L .48318 .55434 L F
.718 .914 .962 r
.51534 .40859 m .51044 .40942 L .51389 .4076 L F
.839 .927 .89 r
.5183 .40581 m .51534 .40859 L .51389 .4076 L F
.448 .169 .397 r
.31218 .62589 m .31491 .62541 L .31554 .62281 L F
.902 .805 .328 r
.31554 .62281 m .31491 .62541 L .31461 .62382 L F
.31554 .62281 m .31461 .62382 L .31746 .62202 L F
.538 .008 0 r
.56465 .42264 m .56059 .42247 L .56194 .42125 L F
0 .394 .839 r
.28388 .65745 m .28551 .65871 L .28403 .65768 L F
.2 0 0 r
.28551 .65871 m .28658 .65903 L .28403 .65768 L F
.28551 .65871 m .28845 .65954 L .28658 .65903 L F
.572 .323 .501 r
.29499 .6387 m .29751 .64115 L .29481 .64145 L F
.29499 .6387 m .29787 .63841 L .29751 .64115 L F
.29499 .6387 m .29751 .64115 L .29481 .64145 L F
.29499 .6387 m .29787 .63841 L .29751 .64115 L F
.973 .924 .674 r
.39594 .58717 m .39373 .58859 L .39479 .58931 L F
.984 .887 .645 r
.39496 .58516 m .39373 .58859 L .39594 .58717 L F
.253 0 .123 r
.68887 .29083 m .69133 .29023 L .69231 .28848 L F
0 0 0 r
.6947 .2853 m .69231 .28848 L .69411 .28653 L F
.392 .168 .45 r
.69133 .29023 m .69411 .28653 L .69231 .28848 L F
0 0 0 r
.33845 .60527 m .33719 .60836 L .33539 .60918 L F
.33836 .60662 m .33845 .60527 L .34171 .60504 L F
.33836 .60662 m .33719 .60836 L .33845 .60527 L F
.579 .902 .649 r
.6589 .33126 m .65727 .33303 L .6604 .33033 L F
0 0 0 r
.66146 .32998 m .6604 .33033 L .66297 .32918 L F
.66146 .32998 m .6589 .33126 L .6604 .33033 L F
.502 .909 .865 r
.31932 .56409 m .31796 .56422 L .32053 .56291 L F
.541 .629 .888 r
.53914 .4093 m .54346 .41175 L .54194 .40814 L F
.777 .707 .785 r
.54346 .41175 m .54426 .40695 L .54194 .40814 L F
.54346 .41175 m .54589 .40885 L .54426 .40695 L F
.524 .327 .555 r
.45402 .51569 m .45671 .51756 L .45739 .51508 L F
.65 .61 .796 r
.37117 .62087 m .36911 .62252 L .36775 .6192 L F
.37017 .61925 m .36775 .6192 L .36991 .61884 L F
.37117 .62087 m .36984 .62022 L .37017 .61925 L F
.36984 .62022 m .36775 .6192 L .37017 .61925 L F
.077 .254 .743 r
.36775 .6192 m .36911 .62252 L .36922 .6197 L F
.941 .958 .664 r
.36922 .6197 m .36911 .62245 L .36714 .62442 L F
.36911 .62245 m .36911 .62252 L .36908 .62255 L F
.36911 .62245 m .36908 .62255 L .36714 .62442 L F
.872 .553 .442 r
.36714 .62442 m .36911 .62252 L .36941 .62473 L F
.947 .698 .235 r
.53798 .4602 m .53851 .46009 L .53751 .45755 L F
.46 .87 .716 r
.53895 .45999 m .53729 .46097 L .53851 .46009 L F
.947 .698 .235 r
.5381 .46087 m .53851 .46009 L .53798 .4602 L F
.46 .87 .716 r
.53957 .45962 m .53895 .45999 L .53851 .46009 L F
.827 .979 .885 r
.6232 .35151 m .62695 .34927 L .6262 .34846 L F
.771 .974 .918 r
.62915 .34645 m .62695 .34927 L .63036 .34721 L F
.62915 .34645 m .6262 .34846 L .62695 .34927 L F
.67 .134 0 r
.3778 .60109 m .37652 .60161 L .37437 .59968 L F
.64 .095 0 r
.3778 .60109 m .38009 .60271 L .37652 .60161 L F
.844 .455 .313 r
.28955 .65074 m .2898 .64907 L .29238 .65 L F
.301 .048 .353 r
.68887 .29083 m .68607 .29419 L .68872 .29301 L F
.154 0 .018 r
.68607 .29419 m .68811 .29495 L .68872 .29301 L F
.68607 .29419 m .68554 .29608 L .68811 .29495 L F
.015 0 0 r
.54253 .44354 m .53998 .44441 L .53861 .44584 L F
.856 .612 .568 r
.31356 .53807 m .31028 .54005 L .3122 .53833 L F
.31356 .53807 m .31354 .54108 L .31028 .54005 L F
0 .206 .725 r
.31477 .53717 m .31356 .53807 L .3122 .53833 L F
.31477 .53717 m .31596 .54052 L .31356 .53807 L F
.502 .32 .567 r
.31356 .53807 m .31596 .54052 L .31354 .54108 L F
0 0 .208 r
.47355 .54151 m .47486 .53972 L .47509 .53702 L F
0 0 .02 r
.47415 .54224 m .47486 .53972 L .47355 .54151 L F
.963 .792 .623 r
.41833 .48743 m .42055 .48614 L .41984 .48798 L F
.458 .161 .373 r
.41648 .48615 m .41833 .48743 L .42055 .48614 L F
.86 .964 .867 r
.4198 .48515 m .42032 .48532 L .42201 .48275 L F
0 0 0 r
.42201 .48275 m .42032 .48532 L .42057 .48504 L F
.586 .891 .989 r
.42312 .48531 m .42048 .48518 L .42057 .48504 L F
.42207 .48289 m .42057 .48504 L .42201 .48275 L F
.42312 .48531 m .42057 .48504 L .42207 .48289 L F
.42312 .48531 m .42055 .48614 L .42012 .48557 L F
.329 .152 .482 r
.42035 .48535 m .42057 .48504 L .42032 .48532 L F
.586 .891 .989 r
.42024 .48544 m .42012 .48557 L .4198 .48515 L F
.924 .972 .76 r
.4198 .48515 m .42055 .48614 L .41833 .48743 L F
0 0 0 r
.41833 .48743 m .42022 .48543 L .4198 .48515 L F
.42022 .48543 m .42032 .48532 L .4198 .48515 L F
.586 .891 .989 r
.42047 .48518 m .42024 .48544 L .4198 .48515 L F
.42312 .48531 m .42012 .48557 L .42047 .48518 L F
.264 .028 .357 r
.42344 .48421 m .42617 .48286 L .42648 .48377 L F
.42344 .48421 m .42312 .48531 L .42617 .48286 L F
.701 .771 .906 r
.42617 .48286 m .42312 .48531 L .42201 .48275 L F
.42617 .48286 m .42201 .48275 L .42419 .48118 L F
.329 .152 .482 r
.42057 .48507 m .4227 .48266 L .42057 .48504 L F
.4206 .48567 m .42264 .48275 L .42057 .48507 L F
.42264 .48275 m .4227 .48266 L .42057 .48507 L F
.4206 .48567 m .42057 .48504 L .42035 .48535 L F
0 0 0 r
.42201 .48275 m .42057 .48504 L .4227 .48266 L F
.586 .891 .989 r
.42048 .48518 m .4198 .48515 L .42201 .48275 L F
.013 0 0 r
.41833 .48743 m .42055 .48614 L .42312 .48531 L F
0 0 .064 r
.58937 .35157 m .58838 .3529 L .58735 .35286 L F
.434 .868 .773 r
.58639 .35299 m .58937 .35157 L .58735 .35286 L F
.889 .468 .082 r
.37086 .52086 m .37215 .52402 L .37379 .52501 L F
.926 .557 .142 r
.37286 .52605 m .37379 .52501 L .37215 .52402 L F
.37286 .52605 m .37428 .52743 L .37379 .52501 L F
0 0 .287 r
.47725 .52056 m .4758 .52185 L .47585 .52413 L F
.424 .821 .603 r
.36371 .59698 m .36414 .59661 L .36607 .596 L F
.36371 .59698 m .36181 .59824 L .36414 .59661 L F
.767 .862 .92 r
.3759 .49636 m .37082 .49721 L .37378 .49475 L F
.727 .291 .216 r
.2464 .58675 m .24503 .58743 L .24228 .58541 L F
.965 .884 .701 r
.24659 .58237 m .2464 .58675 L .24855 .58321 L F
.24659 .58237 m .24503 .58743 L .2464 .58675 L F
.863 .756 .744 r
.45824 .49508 m .45922 .4927 L .45819 .49122 L F
.842 .906 .881 r
.45922 .4927 m .4604 .48887 L .45819 .49122 L F
.45922 .4927 m .46241 .48977 L .4604 .48887 L F
.509 .306 .541 r
.68872 .29301 m .69133 .29023 L .68887 .29083 L F
.362 .777 .979 r
.70417 .3072 m .70174 .30624 L .7054 .30683 L F
.841 .731 .743 r
.41664 .50418 m .41867 .50727 L .4186 .50577 L F
0 .014 .581 r
.4186 .50577 m .41862 .50486 L .41664 .50418 L F
.407 .615 .935 r
.29185 .64097 m .28827 .64013 L .29232 .6411 L F
.753 .909 .945 r
.6354 .3449 m .63669 .34621 L .6397 .34391 L F
0 0 0 r
.6972 .28366 m .6947 .2853 L .69411 .28653 L F
.918 .802 .716 r
.70027 .2781 m .70237 .27416 L .70055 .2727 L F
.417 .27 .573 r
.70661 .31237 m .70918 .31194 L .71077 .31419 L F
.84 .902 .881 r
.71271 .30994 m .71077 .31419 L .70918 .31194 L F
.427 .77 .996 r
.36857 .61642 m .36352 .61549 L .36757 .61696 L F
.987 .85 .62 r
.36857 .61642 m .36775 .6192 L .36636 .61751 L F
.807 .985 .717 r
.36919 .61544 m .36857 .61642 L .36757 .61696 L F
.987 .85 .62 r
.36857 .61642 m .36775 .6192 L .36636 .61751 L F
.672 .96 .739 r
.34562 .65439 m .34636 .65297 L .344 .65407 L F
.34562 .65439 m .34851 .65188 L .34636 .65297 L F
.257 .459 .866 r
.33889 .64697 m .33794 .64877 L .33583 .64515 L F
.718 .947 .647 r
.33615 .65023 m .33794 .64877 L .33889 .64697 L F
0 0 0 r
.33539 .60918 m .33406 .61111 L .33337 .61207 L F
.079 0 0 r
.3362 .61038 m .33539 .60918 L .33719 .60836 L F
.3362 .61038 m .33406 .61111 L .33539 .60918 L F
.674 .849 .966 r
.49131 .42426 m .48741 .42403 L .49004 .42316 L F
.811 .908 .907 r
.49522 .41856 m .49131 .42426 L .49004 .42316 L F
.849 .983 .863 r
.49576 .41982 m .49529 .41943 L .49711 .41851 L F
.92 .966 .784 r
.49576 .41982 m .49519 .42093 L .49522 .41856 L F
.811 .908 .907 r
.49522 .41856 m .49521 .41956 L .49131 .42426 L F
.92 .966 .784 r
.49576 .41982 m .49522 .41856 L .49481 .41901 L F
.849 .983 .863 r
.49529 .41943 m .49481 .41901 L .49565 .41883 L F
.49529 .41943 m .49565 .41883 L .49711 .41851 L F
.811 .908 .907 r
.49521 .41956 m .49519 .42093 L .49354 .42235 L F
.49521 .41956 m .49354 .42235 L .49131 .42426 L F
0 .042 .56 r
.70028 .30458 m .69928 .30387 L .7008 .30517 L F
.70028 .30458 m .70174 .30624 L .69928 .30387 L F
.778 .996 .862 r
.69772 .33045 m .69414 .33235 L .6955 .32881 L F
.711 .913 .964 r
.62214 .34277 m .6204 .34408 L .61904 .34281 L F
0 0 0 r
.34636 .65297 m .34851 .65188 L .35085 .65119 L F
.675 .64 .807 r
.74212 .30429 m .73903 .30296 L .74125 .30025 L F
.903 .972 .67 r
.74212 .30429 m .74073 .30499 L .74138 .30655 L F
0 0 .246 r
.74125 .30025 m .74196 .30295 L .74212 .30429 L F
.903 .972 .67 r
.74212 .30429 m .74196 .30295 L .74073 .30499 L F
.727 .952 .656 r
.3279 .52263 m .32634 .52409 L .329 .52097 L F
.453 .285 .562 r
.33114 .54098 m .33357 .5403 L .33354 .53782 L F
.493 0 0 r
.25968 .62796 m .25952 .62848 L .25932 .62881 L F
.25968 .62796 m .26165 .62932 L .25952 .62848 L F
.486 .414 .701 r
.38248 .47615 m .38189 .47961 L .38431 .47863 L F
.393 .201 .498 r
.38431 .47863 m .38189 .47961 L .3825 .48131 L F
.844 .453 .308 r
.38248 .47615 m .38431 .47863 L .38189 .47961 L F
.779 .703 .779 r
.38431 .47863 m .3825 .48131 L .38189 .47961 L F
.43 .863 .759 r
.67028 .38065 m .67434 .37892 L .67315 .38001 L F
0 0 0 r
.67315 .38001 m .67434 .37892 L .67669 .37779 L F
.625 .893 .987 r
.44488 .44817 m .45049 .44672 L .45005 .44786 L F
.647 .905 .982 r
.45049 .44672 m .45206 .44672 L .45005 .44786 L F
.549 .859 .559 r
.6589 .33126 m .65598 .33413 L .65727 .33303 L F
.654 .932 .97 r
.30366 .56923 m .30629 .5681 L .30283 .5694 L F
.703 .248 .169 r
.30143 .57142 m .30366 .56923 L .30283 .5694 L F
.30143 .57142 m .30495 .57268 L .30366 .56923 L F
.302 0 .105 r
.30366 .56923 m .3079 .56894 L .30629 .5681 L F
.587 .182 .241 r
.30366 .56923 m .30779 .57233 L .3079 .56894 L F
.30366 .56923 m .30495 .57268 L .30779 .57233 L F
.879 .506 .334 r
.39432 .52182 m .3921 .52131 L .39077 .51821 L F
.849 .432 .241 r
.39432 .52182 m .39272 .52325 L .3921 .52131 L F
.964 .653 .385 r
.3945 .52435 m .39272 .52325 L .39432 .52182 L F
.773 .728 .811 r
.52956 .40083 m .53088 .4047 L .5271 .40418 L F
.796 .739 .8 r
.53365 .40138 m .53088 .4047 L .52956 .40083 L F
.579 .219 .322 r
.62803 .41184 m .63111 .41148 L .6268 .41153 L F
.538 .327 .542 r
.52017 .49261 m .52006 .49515 L .51736 .49558 L F
.511 .263 .475 r
.52296 .4922 m .52006 .49515 L .52017 .49261 L F
0 .004 .577 r
.26863 .62953 m .27017 .63057 L .26927 .62973 L F
.26863 .62953 m .26968 .63187 L .27017 .63057 L F
0 0 .322 r
.34304 .55899 m .34302 .56057 L .34221 .55737 L F
.34304 .55899 m .34221 .55737 L .34065 .5562 L F
0 .116 .642 r
.22937 .60269 m .23064 .60679 L .23155 .60564 L F
.543 .919 .936 r
.23155 .60564 m .23064 .60679 L .23245 .60612 L F
.965 .64 .327 r
.23187 .60704 m .23099 .60534 L .23155 .60564 L F
0 0 .43 r
.22937 .60269 m .23155 .60564 L .23007 .60358 L F
.965 .64 .327 r
.23099 .60534 m .23007 .60358 L .23155 .60564 L F
.543 .919 .936 r
.23155 .60564 m .23245 .60612 L .23308 .60589 L F
.253 .005 .33 r
.26769 .61197 m .26846 .60928 L .27029 .60868 L F
.26769 .61197 m .26846 .60928 L .27029 .60868 L F
.561 .17 .258 r
.34688 .55397 m .34221 .55472 L .34445 .55369 L F
.74 .924 .952 r
.58485 .3586 m .59163 .35626 L .59065 .35559 L F
.722 .964 .94 r
.59285 .3539 m .59163 .35626 L .59426 .3543 L F
.727 .969 .934 r
.59285 .3539 m .59065 .35559 L .59163 .35626 L F
.966 .713 .5 r
.43713 .5507 m .43677 .55355 L .43857 .55429 L F
.951 .666 .219 r
.43787 .55546 m .43857 .55429 L .43677 .55355 L F
.43787 .55546 m .43886 .55693 L .43857 .55429 L F
0 0 0 r
.32892 .5932 m .33004 .59197 L .33094 .58979 L F
.515 .899 .953 r
.32892 .5932 m .32735 .59288 L .33004 .59197 L F
.489 .1 .229 r
.32735 .59288 m .32917 .5941 L .33004 .59197 L F
.32917 .5941 m .3294 .59426 L .33004 .59197 L F
0 0 0 r
.33094 .58979 m .33004 .59197 L .33124 .58928 L F
.24 .747 .705 r
.66116 .31965 m .66327 .31892 L .66457 .31773 L F
.66116 .31965 m .66049 .31981 L .66327 .31892 L F
.582 .256 .382 r
.33328 .56685 m .33242 .56963 L .3297 .5695 L F
.447 .203 .449 r
.33635 .56378 m .33596 .56636 L .33328 .56685 L F
.455 .156 .368 r
.33596 .56636 m .33242 .56963 L .33328 .56685 L F
.216 .738 .839 r
.44724 .59549 m .45128 .59526 L .44979 .59564 L F
0 0 0 r
.44979 .59564 m .45128 .59526 L .4538 .59496 L F
.052 .557 .882 r
.4474 .58486 m .4485 .5857 L .4463 .58519 L F
.441 .272 .554 r
.282 .54885 m .28449 .54811 L .28501 .54404 L F
.667 .54 .7 r
.54993 .46018 m .54758 .46402 L .5466 .46056 L F
.339 .314 .685 r
.5466 .46056 m .54758 .46402 L .54963 .46171 L F
.467 .1 .257 r
.54645 .46253 m .5466 .46056 L .54963 .46171 L F
.661 .973 .851 r
.37185 .62852 m .373 .6263 L .37088 .62711 L F
.37185 .62852 m .37604 .62548 L .373 .6263 L F
.649 .579 .763 r
.33864 .55837 m .33903 .56385 L .33635 .56378 L F
.158 0 .006 r
.33903 .56385 m .33596 .56636 L .33635 .56378 L F
.863 .756 .744 r
.45824 .49508 m .45819 .49122 L .45484 .49505 L F
.83 .633 .637 r
.45484 .49505 m .45698 .4986 L .45824 .49508 L F
.701 .475 0 r
.6143 .42505 m .61474 .42752 L .61416 .42415 L F
.641 .105 0 r
.61461 .42818 m .61474 .42752 L .6143 .42505 L F
.432 .156 .393 r
.51736 .49558 m .51663 .49848 L .51427 .49889 L F
.538 .27 .456 r
.52006 .49515 m .51663 .49848 L .51736 .49558 L F
.286 .073 .405 r
.49637 .52189 m .49599 .52434 L .49401 .52521 L F
.088 0 .366 r
.4952 .52665 m .49401 .52521 L .49599 .52434 L F
.4952 .52665 m .49383 .52776 L .49401 .52521 L F
.641 .647 .84 r
.55106 .40447 m .55497 .40715 L .55446 .40397 L F
.552 .564 .82 r
.55446 .40397 m .55497 .40715 L .55749 .40499 L F
.369 .017 .23 r
.47006 .48051 m .47091 .48217 L .47218 .48143 L F
.354 .042 .29 r
.47006 .48051 m .47218 .48143 L .47254 .47942 L F
.676 .259 0 r
.35055 .64028 m .35216 .643 L .3517 .64208 L F
.35216 .643 m .35328 .6449 L .3517 .64208 L F
.143 .407 .853 r
.3517 .64208 m .3518 .64127 L .35122 .64113 L F
.684 .303 .319 r
.34845 .64161 m .35055 .64028 L .3517 .64208 L F
.795 .354 .201 r
.35334 .64165 m .35207 .63897 L .35069 .64035 L F
.3518 .64127 m .35069 .64035 L .35016 .64086 L F
.35334 .64165 m .35069 .64035 L .3518 .64127 L F
.143 .407 .853 r
.3517 .64208 m .35429 .64345 L .3541 .64318 L F
.3517 .64208 m .3541 .64318 L .3518 .64127 L F
.3517 .64208 m .35122 .64113 L .35016 .64086 L F
.35122 .64113 m .35094 .64055 L .35016 .64086 L F
.795 .354 .201 r
.35411 .64326 m .35334 .64165 L .35016 .64086 L F
.143 .407 .853 r
.3518 .64127 m .3541 .64318 L .35194 .64015 L F
.35122 .64113 m .35194 .64015 L .35094 .64055 L F
.3518 .64127 m .35194 .64015 L .35122 .64113 L F
0 0 0 r
.35016 .64086 m .35207 .63897 L .35055 .64028 L F
.795 .354 .201 r
.35411 .64326 m .35016 .64086 L .35194 .64015 L F
.897 .491 .079 r
.35194 .64015 m .35408 .64316 L .35315 .64295 L F
.35408 .64316 m .35429 .64345 L .35414 .64338 L F
.35408 .64316 m .35414 .64338 L .35315 .64295 L F
.557 .255 .412 r
.35411 .64326 m .35411 .64326 L .35207 .63897 L F
.35411 .64326 m .35577 .63838 L .35292 .63884 L F
.35411 .64326 m .35292 .63884 L .35207 .63897 L F
.63 .725 .916 r
.70018 .29904 m .70137 .30142 L .704 .30035 L F
.461 .245 .498 r
.704 .30035 m .7041 .30273 L .70137 .30142 L F
.704 .30035 m .7041 .30273 L .70137 .30142 L F
.614 .38 .539 r
.52585 .48936 m .52586 .49225 L .52296 .4922 L F
.476 .203 .419 r
.52973 .48795 m .52586 .49225 L .52585 .48936 L F
.535 .63 .892 r
.4346 .56756 m .43582 .56536 L .43412 .56325 L F
.4346 .56756 m .43756 .56706 L .43582 .56536 L F
0 0 .265 r
.48841 .54222 m .48708 .54133 L .48824 .54009 L F
.48841 .54222 m .48678 .5439 L .48708 .54133 L F
.69 .183 .028 r
.52328 .39933 m .52165 .40029 L .52558 .40027 L F
.17 .706 .814 r
.52165 .40029 m .52474 .39996 L .52558 .40027 L F
.549 .926 .796 r
.52558 .40027 m .52474 .39996 L .52698 .39847 L F
.907 .784 .714 r
.41984 .48798 m .41862 .49253 L .41968 .49267 L F
.914 .702 .601 r
.41862 .49253 m .41986 .49453 L .41968 .49267 L F
.999 .815 .478 r
.39339 .58163 m .39507 .58043 L .39367 .57885 L F
.39339 .58163 m .3947 .58285 L .39507 .58043 L F
.878 .499 .318 r
.35433 .53691 m .35567 .53976 L .35738 .5383 L F
.255 0 0 r
.35567 .53976 m .36021 .5378 L .35738 .5383 L F
.969 .651 .327 r
.40616 .5536 m .40543 .55579 L .40525 .55287 L F
.40616 .5536 m .40682 .55696 L .40543 .55579 L F
.535 .357 .587 r
.44547 .49265 m .44841 .48919 L .44445 .48868 L F
.44547 .49265 m .4481 .4921 L .44841 .48919 L F
.59 .415 .613 r
.44553 .49538 m .4481 .4921 L .44547 .49265 L F
.899 .503 .256 r
.37501 .52927 m .3764 .52802 L .37428 .52743 L F
.37501 .52927 m .37818 .53153 L .3764 .52802 L F
.401 .167 .44 r
.61332 .38383 m .61083 .38272 L .61208 .38557 L F
.5 .279 .51 r
.5323 .48593 m .53485 .48786 L .53215 .488 L F
.5323 .48593 m .53479 .48536 L .53485 .48786 L F
.786 .942 .928 r
.30649 .65016 m .30476 .65206 L .30249 .65125 L F
.176 0 0 r
.68331 .37469 m .68647 .37308 L .68581 .37415 L F
.021 0 0 r
.68647 .37308 m .68819 .37334 L .68581 .37415 L F
.68647 .37308 m .68941 .37235 L .68819 .37334 L F
.795 .502 .492 r
.42758 .52168 m .42738 .52412 L .43118 .52344 L F
.871 .614 .547 r
.42738 .52412 m .42894 .52718 L .43118 .52344 L F
.567 .434 .66 r
.69703 .28158 m .69943 .28077 L .70027 .2781 L F
.795 .656 .709 r
.6972 .28366 m .69943 .28077 L .69703 .28158 L F
.358 0 .164 r
.54144 .48259 m .54306 .48445 L .54012 .48438 L F
.54144 .48259 m .54407 .48208 L .54306 .48445 L F
.804 .612 .643 r
.56773 .44949 m .57035 .44673 L .56789 .44645 L F
.783 .577 .623 r
.56773 .44949 m .57008 .45034 L .57035 .44673 L F
.616 .293 .401 r
.57365 .44935 m .57035 .44673 L .57008 .45034 L F
.57365 .44935 m .57283 .44756 L .57035 .44673 L F
.261 .75 .657 r
.64818 .38494 m .6455 .386 L .64455 .38638 L F
.173 .16 .601 r
.57413 .43611 m .57283 .44062 L .57207 .43846 L F
.595 .544 .768 r
.22347 .5768 m .22501 .58114 L .22725 .58014 L F
.637 .894 .985 r
.53914 .4093 m .54093 .40719 L .53714 .40926 L F
.53914 .4093 m .54194 .40814 L .54093 .40719 L F
.639 .351 .465 r
.53002 .39959 m .52956 .40083 L .52974 .39828 L F
.736 .659 .774 r
.53261 .39788 m .53002 .39959 L .52974 .39828 L F
.995 .786 .419 r
.40124 .53786 m .40026 .53678 L .40049 .53444 L F
.954 .609 .235 r
.40124 .53786 m .40028 .53905 L .40026 .53678 L F
.40124 .53786 m .40175 .54038 L .40028 .53905 L F
0 0 .136 r
.63146 .35296 m .62961 .35673 L .63126 .35503 L F
0 0 .113 r
.63146 .35296 m .63285 .35284 L .63415 .35198 L F
.63146 .35296 m .63126 .35503 L .63285 .35284 L F
.744 .398 .397 r
.46868 .51388 m .47074 .5143 L .47013 .51177 L F
.843 .465 .333 r
.47013 .51177 m .47411 .51523 L .47297 .51155 L F
.47013 .51177 m .47074 .5143 L .47411 .51523 L F
.912 .642 .515 r
.46868 .51388 m .47013 .51177 L .46811 .51071 L F
.957 .628 .234 r
.38089 .53388 m .38156 .53855 L .38269 .53785 L F
.954 .608 .293 r
.38139 .53917 m .38269 .53785 L .38156 .53855 L F
.38139 .53917 m .38317 .54084 L .38269 .53785 L F
.701 .693 .839 r
.54589 .40885 m .54838 .40775 L .54426 .40695 L F
.192 .722 .767 r
.2637 .51676 m .26588 .51632 L .26808 .5161 L F
.264 .772 .798 r
.26808 .5161 m .26588 .51632 L .26841 .51568 L F
0 0 0 r
.26588 .51632 m .26609 .5176 L .26821 .51584 L F
.26588 .51632 m .26821 .51584 L .26841 .51568 L F
.192 .722 .767 r
.26361 .51677 m .26588 .51632 L .2637 .51676 L F
.264 .772 .798 r
.26808 .5161 m .26841 .51568 L .27075 .51543 L F
.779 .703 .779 r
.38431 .47863 m .38591 .48281 L .3825 .48131 L F
.703 .171 0 r
.3825 .48131 m .38591 .48281 L .38465 .48349 L F
.256 .595 .95 r
.3837 .4684 m .38513 .47006 L .38308 .46982 L F
.3837 .4684 m .38513 .47006 L .38308 .46982 L F
.526 .713 .957 r
.38732 .4805 m .38591 .48281 L .38431 .47863 L F
.38732 .4805 m .38839 .48234 L .38591 .48281 L F
.97 .656 .288 r
.38591 .48281 m .38634 .48582 L .38465 .48349 L F
.467 .748 .99 r
.39092 .48155 m .3951 .48282 L .39282 .48327 L F
.19 0 0 r
.519 .40045 m .52165 .40029 L .52328 .39933 L F
0 0 0 r
.61765 .41046 m .61689 .41112 L .61611 .41446 L F
.491 .466 .758 r
.4242 .58742 m .42403 .58888 L .42184 .58623 L F
.552 .491 .74 r
.42864 .58934 m .4242 .58742 L .42538 .58605 L F
.42864 .58934 m .42607 .59031 L .4242 .58742 L F
.806 .925 .915 r
.50558 .41395 m .50217 .41442 L .50441 .41294 L F
.791 .956 .922 r
.50872 .41135 m .50558 .41395 L .50441 .41294 L F
.565 .68 .917 r
.24817 .56349 m .24884 .56784 L .24736 .56556 L F
.457 .099 .27 r
.24884 .56784 m .2519 .56748 L .25195 .56678 L F
.282 0 0 r
.25195 .56678 m .25139 .56735 L .24884 .56784 L F
.565 .68 .917 r
.25172 .56729 m .2519 .56748 L .251 .56759 L F
.25139 .56735 m .251 .56759 L .24884 .56784 L F
.25172 .56729 m .251 .56759 L .25139 .56735 L F
.036 0 .191 r
.25195 .56678 m .2519 .56748 L .25354 .56599 L F
.625 .7 .899 r
.25354 .56599 m .2519 .56748 L .25164 .5672 L F
0 0 0 r
.25354 .56599 m .25272 .56651 L .25195 .56678 L F
.25289 .56645 m .25139 .56735 L .25195 .56678 L F
.625 .7 .899 r
.25354 .56599 m .25164 .5672 L .24817 .56349 L F
0 0 0 r
.25354 .56599 m .25289 .56645 L .25272 .56651 L F
.25289 .56645 m .25087 .56789 L .25139 .56735 L F
.282 0 0 r
.25139 .56735 m .25087 .56789 L .24884 .56784 L F
.565 .68 .917 r
.24817 .56349 m .25172 .56729 L .24884 .56784 L F
.149 .637 .918 r
.24884 .56784 m .24957 .56721 L .24736 .56556 L F
.24884 .56784 m .25087 .56789 L .24957 .56721 L F
.964 .637 .322 r
.34377 .63757 m .34542 .63864 L .34554 .64125 L F
.893 .9 .825 r
.34377 .63757 m .34542 .63864 L .34799 .635 L F
0 .251 .759 r
.34604 .63716 m .34542 .63864 L .34377 .63757 L F
.34604 .63716 m .34845 .64161 L .34542 .63864 L F
.675 .374 .456 r
.34542 .63864 m .34845 .64161 L .34554 .64125 L F
.817 .345 0 r
.39917 .53226 m .39829 .53261 L .39739 .53098 L F
.39917 .53226 m .40049 .53444 L .39829 .53261 L F
.715 .182 0 r
.35305 .50387 m .35286 .50241 L .35094 .50151 L F
.35305 .50387 m .35504 .50483 L .35286 .50241 L F
.576 .323 .496 r
.4506 .52287 m .45471 .52111 L .45151 .52303 L F
.451 .872 .75 r
.67366 .32328 m .67268 .32428 L .67511 .32306 L F
.67366 .32328 m .67116 .3247 L .67268 .32428 L F
.869 .781 .761 r
.24659 .58237 m .24855 .58321 L .24774 .57978 L F
.575 .043 0 r
.59114 .38984 m .59156 .38988 L .593 .39131 L F
.46 .204 .438 r
.34476 .57373 m .34745 .57319 L .34805 .5706 L F
0 0 0 r
.34805 .5706 m .34793 .57209 L .34968 .5696 L F
.562 .216 .34 r
.34849 .56951 m .34625 .57196 L .34587 .56931 L F
.34968 .5696 m .34823 .5706 L .34849 .56951 L F
.34823 .5706 m .34625 .57196 L .34849 .56951 L F
0 0 0 r
.34805 .5706 m .34745 .57319 L .3478 .57239 L F
.34796 .57173 m .3478 .57239 L .34793 .57209 L F
.34805 .5706 m .3478 .57239 L .34796 .57173 L F
.749 .671 .774 r
.47294 .49524 m .47653 .49565 L .47619 .49257 L F
.755 .647 .741 r
.47294 .49524 m .47389 .49893 L .47653 .49565 L F
.693 .553 .692 r
.47389 .49893 m .47761 .49906 L .47653 .49565 L F
.656 .603 .783 r
.47619 .49257 m .47653 .49565 L .47912 .49246 L F
.68 .64 .802 r
.47653 .49565 m .48026 .49587 L .47912 .49246 L F
.695 .554 .691 r
.47761 .49906 m .48026 .49587 L .47653 .49565 L F
.897 .606 .487 r
.3901 .55402 m .39032 .55667 L .39252 .55715 L F
.978 .714 .459 r
.39032 .55667 m .39187 .56008 L .39252 .55715 L F
.836 .724 .741 r
.44296 .48515 m .44445 .48868 L .44593 .48597 L F
.719 .733 .215 r
.34259 .65013 m .34227 .6517 L .34154 .65439 L F
.158 .124 .567 r
.32575 .63099 m .32649 .63459 L .32475 .63171 L F
0 0 0 r
.66457 .31773 m .66604 .31795 L .66655 .31597 L F
.66457 .31773 m .66327 .31892 L .66604 .31795 L F
.521 .864 .992 r
.41834 .6001 m .41872 .59859 L .41604 .59769 L F
.504 .456 .736 r
.4205 .59638 m .42066 .59924 L .41834 .6001 L F
.521 .864 .992 r
.41834 .6001 m .42066 .59924 L .41872 .59859 L F
.657 .576 .753 r
.46696 .51798 m .47028 .51767 L .46868 .51388 L F
.407 0 .031 r
.47161 .51871 m .47059 .52032 L .46738 .52066 L F
.529 .14 .248 r
.46793 .52043 m .46982 .51909 L .46696 .51798 L F
.461 .528 .84 r
.47004 .51843 m .47059 .52032 L .47101 .51965 L F
.46989 .51888 m .47059 .52032 L .47004 .51843 L F
.47042 .51803 m .47101 .51965 L .47161 .51871 L F
.529 .14 .248 r
.46871 .51865 m .47028 .51767 L .46696 .51798 L F
.46982 .51909 m .46989 .51888 L .46871 .51865 L F
.46989 .51888 m .47028 .51767 L .46871 .51865 L F
.461 .528 .84 r
.47049 .519 m .47101 .51965 L .4708 .51906 L F
.47049 .519 m .4708 .51906 L .47042 .51803 L F
.46913 .51731 m .47049 .519 L .47042 .51803 L F
.873 .645 .59 r
.47397 .51543 m .47136 .51715 L .47161 .51871 L F
.47125 .51654 m .47042 .51803 L .47161 .51871 L F
.47124 .51643 m .47116 .51657 L .47125 .51654 L F
.47116 .51657 m .47042 .51803 L .47125 .51654 L F
.657 .576 .753 r
.47028 .51767 m .47062 .51764 L .46939 .51526 L F
.47028 .51767 m .46939 .51526 L .46868 .51388 L F
.47062 .51764 m .47116 .51657 L .46868 .51388 L F
.847 .556 .497 r
.46868 .51388 m .47116 .51657 L .46913 .51731 L F
.657 .576 .753 r
.47062 .51764 m .47203 .51751 L .47116 .51657 L F
.529 .14 .248 r
.4702 .51791 m .47062 .51764 L .47028 .51767 L F
.873 .645 .59 r
.47124 .51643 m .46913 .51731 L .47042 .51803 L F
.847 .556 .497 r
.47116 .51657 m .47203 .51751 L .46913 .51731 L F
.529 .14 .248 r
.46982 .51909 m .47203 .51751 L .47062 .51764 L F
.46982 .51909 m .47062 .51764 L .4702 .51791 L F
.873 .645 .59 r
.47411 .51523 m .47124 .51643 L .47136 .51715 L F
.47411 .51523 m .47136 .51715 L .47397 .51543 L F
.461 .528 .84 r
.46913 .51731 m .46989 .51888 L .47004 .51843 L F
.864 .682 .655 r
.46913 .51731 m .47203 .51751 L .47006 .51891 L F
.46913 .51731 m .47006 .51891 L .46793 .52043 L F
.461 .528 .84 r
.46989 .51888 m .47007 .51892 L .47059 .52032 L F
.47007 .51892 m .4725 .5194 L .47082 .52021 L F
.47007 .51892 m .47082 .52021 L .47059 .52032 L F
.46913 .51731 m .47246 .51938 L .46989 .51888 L F
.47246 .51938 m .4725 .5194 L .46989 .51888 L F
.873 .645 .59 r
.47411 .51523 m .47074 .5143 L .46913 .51731 L F
.598 .549 .771 r
.47411 .51523 m .47529 .51095 L .47297 .51155 L F
.47411 .51523 m .47682 .51484 L .47529 .51095 L F
.351 .385 .757 r
.47411 .51523 m .47644 .5172 L .47682 .51484 L F
.704 .787 .916 r
.61109 .41717 m .61531 .41783 L .61404 .41594 L F
.827 .542 .507 r
.61109 .41717 m .61319 .41875 L .61485 .41776 L F
.793 .997 .86 r
.61311 .4188 m .61125 .4197 L .6131 .4188 L F
.61318 .41887 m .61251 .41916 L .61311 .4188 L F
.61251 .41916 m .61125 .4197 L .61311 .4188 L F
.505 .363 .621 r
.61318 .41887 m .61352 .42339 L .6156 .42058 L F
.61318 .41887 m .6156 .42058 L .61389 .42023 L F
.61318 .41887 m .61389 .42023 L .61352 .42339 L F
.833 .736 .757 r
.61416 .42415 m .6156 .42058 L .61352 .42339 L F
.505 .363 .621 r
.61389 .42023 m .6156 .42347 L .6149 .42344 L F
.61389 .42023 m .6149 .42344 L .61352 .42339 L F
.61318 .41887 m .61389 .42023 L .61125 .4197 L F
.827 .542 .507 r
.61319 .41875 m .61125 .4197 L .61389 .42023 L F
.6136 .41906 m .61389 .42023 L .6156 .42058 L F
.607 .364 .523 r
.61805 .42223 m .61788 .42356 L .6136 .41929 L F
.6136 .41916 m .6136 .41929 L .61318 .41887 L F
.61805 .42223 m .6136 .41929 L .6136 .41916 L F
.827 .542 .507 r
.61485 .41776 m .6156 .42058 L .61531 .41783 L F
.61319 .41875 m .61344 .41895 L .61485 .41776 L F
.61344 .41895 m .6156 .42058 L .61539 .41978 L F
.61344 .41895 m .61539 .41978 L .61485 .41776 L F
0 .397 .823 r
.61516 .41849 m .61325 .41886 L .61187 .41753 L F
.61325 .41886 m .61318 .41887 L .61311 .4188 L F
.61325 .41886 m .61311 .4188 L .61187 .41753 L F
.44 .31 .607 r
.61531 .41783 m .6156 .42058 L .61747 .41978 L F
.607 .364 .523 r
.61805 .42223 m .6136 .41916 L .6171 .42019 L F
.6136 .41916 m .61318 .41887 L .61338 .41894 L F
.827 .542 .507 r
.61351 .41899 m .61354 .41911 L .6136 .41906 L F
.61354 .41911 m .6136 .41916 L .6136 .41906 L F
.607 .364 .523 r
.6136 .41916 m .61338 .41894 L .6171 .42019 L F
.827 .542 .507 r
.61354 .41911 m .6136 .41929 L .6136 .41916 L F
.6136 .41929 m .61389 .42023 L .6136 .41906 L F
.505 .363 .621 r
.61318 .41887 m .61712 .4228 L .6156 .42347 L F
.61712 .4228 m .61749 .42316 L .61574 .42347 L F
.61749 .42316 m .61729 .42353 L .61574 .42347 L F
.701 .475 0 r
.6143 .42505 m .61416 .42415 L .61352 .42339 L F
.373 0 0 r
.61428 .42501 m .6142 .42502 L .6143 .42505 L F
.61352 .42339 m .6142 .42502 L .61428 .42501 L F
.61352 .42339 m .61613 .42349 L .6142 .42502 L F
.61613 .42349 m .61788 .42356 L .6142 .42502 L F
.572 .918 .964 r
.6142 .42502 m .6154 .42339 L .61367 .42508 L F
.6142 .42502 m .61367 .42508 L .61297 .42576 L F
.505 .363 .621 r
.61749 .42316 m .61788 .42356 L .61729 .42353 L F
.77 .512 .545 r
.6142 .42502 m .61788 .42356 L .61805 .42223 L F
.6142 .42502 m .61758 .42257 L .61669 .42384 L F
.61758 .42257 m .61805 .42223 L .61789 .42242 L F
.61758 .42257 m .61789 .42242 L .61669 .42384 L F
.776 .669 .745 r
.61747 .41978 m .61962 .42318 L .62163 .42 L F
.182 .454 .879 r
.61856 .42047 m .61805 .42223 L .6171 .42019 L F
.771 .901 .503 r
.61669 .42384 m .61789 .42242 L .61856 .42047 L F
.61789 .42242 m .61805 .42223 L .61812 .422 L F
.61789 .42242 m .61812 .422 L .61856 .42047 L F
.505 .363 .621 r
.61712 .4228 m .61574 .42347 L .6156 .42347 L F
.827 .542 .507 r
.61319 .41875 m .61389 .42023 L .61351 .41899 L F
.61109 .41717 m .61125 .4197 L .61319 .41875 L F
.793 .997 .86 r
.6131 .4188 m .61125 .4197 L .61187 .41753 L F
.492 .685 .952 r
.61404 .41594 m .61531 .41783 L .6179 .41687 L F
.389 .309 .644 r
.61531 .41783 m .61747 .41978 L .6179 .41687 L F
.846 .659 .649 r
.5485 .44326 m .55032 .44457 L .5489 .44042 L F
.774 .997 .842 r
.54748 .44638 m .55032 .44457 L .5485 .44326 L F
.435 .292 .587 r
.44869 .5835 m .45105 .58579 L .4508 .58228 L F
.506 .294 .526 r
.4485 .5857 m .45105 .58579 L .44869 .5835 L F
.843 .818 .337 r
.70763 .33543 m .70826 .33344 L .70752 .33472 L F
.721 .918 .566 r
.70953 .331 m .70826 .33344 L .7108 .32991 L F
.638 .795 .352 r
.70752 .33472 m .70826 .33344 L .70953 .331 L F
.967 .69 .454 r
.40955 .57694 m .40773 .57861 L .40843 .57592 L F
.40955 .57694 m .40957 .57958 L .40773 .57861 L F
.787 .933 .928 r
.42295 .46368 m .42292 .46656 L .42597 .46389 L F
.42295 .46368 m .42149 .4656 L .42292 .46656 L F
.373 .759 .989 r
.42931 .49143 m .43323 .49263 L .42859 .49253 L F
.614 .388 .551 r
.43568 .52499 m .43834 .52705 L .43873 .52511 L F
.43568 .52499 m .43561 .52766 L .43834 .52705 L F
.133 0 .214 r
.66655 .31597 m .66927 .31255 L .66737 .3144 L F
.38 .841 .888 r
.62829 .33895 m .63008 .33797 L .63062 .33808 L F
.62829 .33895 m .6274 .33877 L .63008 .33797 L F
.224 .244 .671 r
.42676 .55126 m .42487 .55465 L .42439 .55064 L F
.807 1 .81 r
.42676 .55126 m .42463 .55418 L .42487 .55465 L F
.66 .295 0 r
.42463 .55418 m .42592 .55691 L .42487 .55465 L F
.019 0 0 r
.33284 .55624 m .33651 .55425 L .33381 .55438 L F
.325 0 .239 r
.55358 .47656 m .55309 .47824 L .55057 .47906 L F
.31 0 .234 r
.55556 .47731 m .55358 .47656 L .55624 .47598 L F
.55556 .47731 m .55309 .47824 L .55358 .47656 L F
.819 .831 .358 r
.43271 .54589 m .43344 .54439 L .43346 .54192 L F
.43271 .54589 m .43254 .54696 L .43344 .54439 L F
.789 .765 .831 r
.42967 .48322 m .43081 .47822 L .43254 .47961 L F
.413 .254 .555 r
.43479 .47598 m .43254 .47961 L .43488 .47871 L F
.412 .252 .553 r
.43488 .47871 m .43254 .47961 L .43081 .47822 L F
.43488 .47871 m .43488 .48151 L .43254 .47961 L F
.761 .989 .892 r
.46435 .48809 m .463 .48785 L .46241 .48977 L F
.631 .887 .987 r
.46241 .48977 m .463 .48785 L .4604 .48887 L F
.747 .952 .944 r
.63461 .38284 m .63147 .38346 L .63324 .38328 L F
.237 .74 .679 r
.63713 .38198 m .63461 .38284 L .63324 .38328 L F
.681 .757 .909 r
.30164 .66008 m .30373 .66202 L .30565 .66057 L F
.782 .952 .928 r
.6233 .39673 m .62756 .39467 L .62724 .39405 L F
.6233 .39673 m .62724 .39405 L .6249 .39505 L F
.6233 .39673 m .62676 .39311 L .62236 .39608 L F
0 .465 .831 r
.62538 .39702 m .6233 .39673 L .62236 .39608 L F
.62538 .39702 m .62704 .39809 L .62439 .39712 L F
.62538 .39702 m .62439 .39712 L .6233 .39673 L F
.639 .921 .977 r
.62848 .39609 m .62704 .39809 L .62538 .39702 L F
.317 .806 .805 r
.62643 .39692 m .62538 .39702 L .62485 .3983 L F
.62749 .39599 m .62848 .39609 L .62538 .39702 L F
.62749 .39599 m .62538 .39702 L .62643 .39692 L F
.529 .135 .239 r
.62485 .3983 m .62538 .39702 L .62243 .3961 L F
.6224 .39612 m .62243 .3961 L .62236 .39608 L F
.62485 .3983 m .62243 .3961 L .6224 .39612 L F
.782 .952 .928 r
.6249 .39505 m .62724 .39405 L .62676 .39311 L F
.483 .794 .999 r
.62676 .39311 m .62756 .39467 L .62935 .39386 L F
0 .211 .736 r
.30916 .57656 m .30946 .57525 L .30752 .57421 L F
.764 .255 0 r
.30916 .57656 m .31099 .57905 L .30924 .57818 L F
.30916 .57656 m .30924 .57818 L .30946 .57525 L F
.368 0 0 r
.29234 .57282 m .29477 .57267 L .29672 .57062 L F
.449 0 .055 r
.29672 .57062 m .29477 .57267 L .2989 .57193 L F
.448 0 .058 r
.29672 .57062 m .2989 .57193 L .29937 .57062 L F
.705 .617 .756 r
.47041 .49864 m .47389 .49893 L .47294 .49524 L F
.659 .514 .676 r
.47497 .50231 m .47761 .49906 L .47389 .49893 L F
.954 .614 .322 r
.59348 .43328 m .59315 .43101 L .59114 .42919 L F
.464 .43 .736 r
.46776 .47014 m .46825 .47299 L .4701 .46946 L F
.635 .639 .837 r
.46825 .47299 m .47081 .47241 L .4701 .46946 L F
.712 .674 .811 r
.36977 .56414 m .3671 .56717 L .36566 .56361 L F
.845 .859 .854 r
.35405 .62711 m .35589 .63073 L .35106 .63201 L F
.42 0 0 r
.35106 .63201 m .35589 .63073 L .35429 .63314 L F
0 .174 .708 r
.35688 .62999 m .35589 .63073 L .35405 .62711 L F
0 0 0 r
.23685 .59168 m .2353 .59466 L .23393 .59606 L F
.23869 .5883 m .23728 .59112 L .23685 .59168 L F
.23728 .59112 m .2353 .59466 L .23685 .59168 L F
.673 .529 .681 r
.36888 .60623 m .36954 .60885 L .36684 .60901 L F
.504 .328 .576 r
.37131 .60562 m .37151 .60838 L .36888 .60623 L F
.37 .335 .688 r
.37151 .60838 m .36954 .60885 L .36888 .60623 L F
0 0 0 r
.5668 .38181 m .56778 .38155 L .56913 .3817 L F
.5668 .38181 m .5655 .38348 L .56778 .38155 L F
1 .813 .507 r
.73957 .30875 m .74138 .30655 L .74073 .30499 L F
.73957 .30875 m .74071 .31024 L .74138 .30655 L F
.275 .626 .961 r
.60062 .35358 m .60259 .35229 L .59931 .35298 L F
.60062 .35358 m .6039 .35405 L .60259 .35229 L F
.624 .27 .351 r
.36684 .60901 m .36533 .61128 L .36211 .61132 L F
.587 .228 .328 r
.36684 .60901 m .36881 .61086 L .36533 .61128 L F
.588 .228 .325 r
.36684 .60901 m .36954 .60885 L .36881 .61086 L F
.701 .322 .326 r
.27658 .64468 m .27917 .6454 L .2748 .6452 L F
0 0 0 r
.71244 .32827 m .71269 .32809 L .71535 .32664 L F
.615 .918 .656 r
.70953 .331 m .71269 .32809 L .71128 .32893 L F
0 0 0 r
.71128 .32893 m .71269 .32809 L .71244 .32827 L F
.501 .831 .536 r
.7108 .32991 m .71298 .32788 L .71269 .32809 L F
.71298 .32788 m .71386 .32705 L .71269 .32809 L F
.504 .836 .545 r
.70953 .331 m .7108 .32991 L .71269 .32809 L F
.984 .743 .346 r
.40928 .58943 m .40814 .58523 L .40937 .58668 L F
.556 .921 .946 r
.64973 .33708 m .64754 .339 L .65165 .33721 L F
.64973 .33708 m .64734 .33823 L .64754 .339 L F
.533 .875 .621 r
.35671 .60209 m .35975 .59957 L .35748 .60016 L F
.56 .057 .016 r
.31111 .66018 m .31237 .6587 L .31482 .66027 L F
.416 .314 .63 r
.35419 .60481 m .35384 .6051 L .3517 .60497 L F
.531 .123 .212 r
.28545 .53529 m .28776 .53671 L .28814 .53571 L F
.409 .168 .434 r
.33264 .5865 m .33294 .58961 L .3359 .58775 L F
.483 .818 .521 r
.647 .39729 m .65025 .39428 L .64894 .39564 L F
0 0 0 r
.65025 .39428 m .65368 .39233 L .65234 .39335 L F
.64894 .39564 m .65025 .39428 L .65234 .39335 L F
.976 .676 .368 r
.5979 .40097 m .59968 .40478 L .598 .40345 L F
.961 .627 .307 r
.598 .40345 m .59968 .40478 L .60006 .40739 L F
.804 .867 .425 r
.33153 .57967 m .33518 .57752 L .3336 .57904 L F
0 0 0 r
.33559 .57743 m .33518 .57752 L .33819 .57707 L F
.33559 .57743 m .3336 .57904 L .33518 .57752 L F
0 0 .025 r
.34023 .5313 m .34086 .53099 L .3404 .53097 L F
.998 .79 .487 r
.67638 .36133 m .67679 .3594 L .67556 .35802 L F
0 0 0 r
.67926 .35602 m .67679 .3594 L .67855 .35713 L F
0 0 .118 r
.67855 .35713 m .67679 .3594 L .67638 .36133 L F
.933 .585 .346 r
.6955 .32881 m .6927 .32567 L .69441 .32694 L F
.694 .933 .624 r
.34799 .635 m .35062 .63197 L .34882 .63341 L F
.933 .943 .601 r
.35062 .63197 m .35147 .62765 L .35106 .63201 L F
0 0 0 r
.34882 .63341 m .35062 .63197 L .35106 .63201 L F
.824 .939 .903 r
.69965 .30935 m .70014 .31086 L .70154 .30972 L F
.828 .365 .112 r
.36101 .51074 m .36502 .51422 L .36484 .51214 L F
.079 .145 .631 r
.33676 .63414 m .33714 .63765 L .33552 .63546 L F
.996 .859 .538 r
.33486 .63849 m .33552 .63546 L .33714 .63765 L F
.397 0 0 r
.34946 .55418 m .34816 .55467 L .34688 .55397 L F
.174 .239 .691 r
.34816 .55467 m .34752 .55741 L .34898 .55511 L F
.34688 .55397 m .34691 .55416 L .34816 .55467 L F
.34691 .55416 m .34752 .55741 L .34816 .55467 L F
.397 0 0 r
.34816 .55467 m .34781 .55577 L .34521 .55576 L F
.34946 .55418 m .34872 .5549 L .34816 .55467 L F
.34872 .5549 m .34781 .55577 L .34816 .55467 L F
.34816 .55467 m .34521 .55576 L .34688 .55397 L F
.449 0 0 r
.35156 .55528 m .34993 .55549 L .34946 .55418 L F
0 0 .281 r
.34741 .55971 m .34905 .55511 L .34752 .55741 L F
.449 0 0 r
.34993 .55549 m .34872 .5549 L .34946 .55418 L F
0 0 .281 r
.34905 .55511 m .34913 .55488 L .34902 .55505 L F
.34905 .55511 m .34902 .55505 L .34752 .55741 L F
.449 0 0 r
.34902 .55505 m .34781 .55577 L .34872 .5549 L F
.972 .928 .643 r
.34894 .56136 m .34943 .55889 L .35139 .56076 L F
.361 .164 .473 r
.35005 .5564 m .34921 .55899 L .34943 .55889 L F
.35005 .5564 m .34943 .55889 L .35029 .55679 L F
.34931 .55667 m .3493 .55679 L .35005 .5564 L F
.3493 .55679 m .34882 .56021 L .35002 .55649 L F
.3493 .55679 m .35002 .55649 L .35005 .5564 L F
.34942 .55536 m .35075 .55756 L .35156 .55528 L F
.449 0 0 r
.34993 .55549 m .34977 .55551 L .34952 .55535 L F
.34964 .55535 m .34952 .55535 L .34902 .55505 L F
.34993 .55549 m .34952 .55535 L .34964 .55535 L F
.361 .164 .473 r
.34913 .55488 m .34942 .55536 L .35156 .55528 L F
.35075 .55756 m .34943 .55889 L .35044 .5584 L F
.502 .469 .753 r
.34894 .56136 m .34893 .56014 L .34882 .56021 L F
.477 .094 .234 r
.34413 .56157 m .34698 .56133 L .34741 .55971 L F
.356 .491 .858 r
.34698 .56133 m .34813 .56063 L .34741 .55971 L F
.34813 .56063 m .34882 .56021 L .34828 .56002 L F
.34813 .56063 m .34828 .56002 L .34741 .55971 L F
.835 .44 .299 r
.34454 .55793 m .34706 .56133 L .34698 .56133 L F
.356 .491 .858 r
.34698 .56133 m .34894 .56136 L .34882 .56021 L F
.835 .44 .299 r
.34454 .55793 m .34894 .56136 L .34706 .56133 L F
.588 .664 .891 r
.34454 .55793 m .34698 .56133 L .34413 .56157 L F
.835 .44 .299 r
.34454 .55793 m .34763 .56235 L .34775 .56226 L F
.34811 .56072 m .34775 .56226 L .34894 .56136 L F
.34454 .55793 m .34775 .56226 L .34811 .56072 L F
.972 .928 .643 r
.34894 .56136 m .3482 .56192 L .34893 .56011 L F
.34894 .56136 m .34893 .56011 L .34943 .55889 L F
.34943 .55889 m .35044 .5584 L .35139 .56076 L F
.502 .469 .753 r
.34894 .56136 m .35052 .55912 L .34893 .56014 L F
.646 .534 .712 r
.3537 .55852 m .35045 .55839 L .35101 .55796 L F
.3537 .55852 m .35139 .56076 L .35044 .5584 L F
.502 .469 .753 r
.35052 .55912 m .35115 .55822 L .34952 .55962 L F
.35052 .55912 m .34952 .55962 L .34882 .56021 L F
.646 .534 .712 r
.35189 .55845 m .35044 .5584 L .35045 .55839 L F
.3537 .55852 m .35187 .55846 L .35189 .55845 L F
.35187 .55846 m .35044 .5584 L .35189 .55845 L F
.35101 .55796 m .35045 .55839 L .35081 .55792 L F
.708 .7 .84 r
.35249 .55211 m .35417 .55459 L .35527 .55264 L F
.795 .819 .871 r
.35527 .55264 m .35417 .55459 L .35191 .5528 L F
.709 .488 .587 r
.35175 .5574 m .35398 .55429 L .35135 .55763 L F
.35149 .5576 m .35135 .55763 L .35121 .55781 L F
.35175 .5574 m .35135 .55763 L .35149 .5576 L F
.35163 .55756 m .3537 .55852 L .35398 .55429 L F
.646 .534 .712 r
.35203 .55783 m .35149 .5576 L .35199 .55773 L F
.35203 .55783 m .35199 .55773 L .35233 .55789 L F
.361 .164 .473 r
.34989 .55777 m .34943 .55889 L .35075 .55756 L F
.646 .534 .712 r
.3537 .55852 m .35019 .55779 L .35203 .55783 L F
.709 .488 .587 r
.35115 .55822 m .3537 .55852 L .35163 .55756 L F
.646 .534 .712 r
.35233 .55789 m .35199 .55773 L .35346 .55812 L F
.709 .488 .587 r
.35135 .55763 m .35398 .55429 L .35123 .55766 L F
.646 .534 .712 r
.35149 .5576 m .35116 .55746 L .35157 .55758 L F
.35149 .5576 m .35157 .55758 L .35346 .55812 L F
.35293 .55725 m .35116 .55746 L .35281 .55705 L F
.35346 .55812 m .35157 .55758 L .35293 .55725 L F
.35157 .55758 m .35116 .55746 L .35293 .55725 L F
.709 .488 .587 r
.35123 .55766 m .35398 .55429 L .35156 .55528 L F
.35121 .55781 m .35135 .55763 L .35123 .55766 L F
.361 .164 .473 r
.35075 .55756 m .3509 .5578 L .35123 .55766 L F
.3509 .5578 m .35121 .55781 L .35123 .55766 L F
.35075 .55756 m .35123 .55766 L .35156 .55528 L F
.35029 .55679 m .34989 .55777 L .35075 .55756 L F
.646 .534 .712 r
.35203 .55783 m .35019 .55779 L .34983 .5569 L F
.709 .488 .587 r
.35115 .55822 m .35175 .5574 L .35121 .55781 L F
.361 .164 .473 r
.3509 .5578 m .35044 .5584 L .35108 .5581 L F
.35075 .55756 m .35044 .5584 L .3509 .5578 L F
.646 .534 .712 r
.35081 .55792 m .35044 .5584 L .35019 .55779 L F
.361 .164 .473 r
.3509 .5578 m .35115 .55822 L .35121 .55781 L F
.646 .534 .712 r
.3537 .55852 m .35203 .55783 L .35346 .55812 L F
0 0 0 r
.35151 .55585 m .35219 .55601 L .34983 .5569 L F
.35398 .55429 m .35305 .55519 L .35151 .55585 L F
.35305 .55519 m .35219 .55601 L .35151 .55585 L F
.646 .534 .712 r
.35281 .55705 m .34983 .5569 L .35219 .55601 L F
.35116 .55746 m .34983 .5569 L .35281 .55705 L F
.361 .164 .473 r
.34941 .55545 m .34882 .56021 L .34948 .55546 L F
.34911 .55522 m .34882 .56021 L .34942 .55536 L F
0 0 .281 r
.34741 .55971 m .34882 .56021 L .3491 .55539 L F
.34898 .55529 m .3491 .55539 L .34911 .55522 L F
.34898 .55529 m .34911 .55522 L .34905 .55511 L F
.34741 .55971 m .3491 .55539 L .34898 .55529 L F
.449 0 0 r
.34924 .55558 m .34781 .55577 L .34902 .55505 L F
.34905 .55511 m .34902 .55505 L .34902 .55505 L F
.34924 .55558 m .34902 .55505 L .34905 .55511 L F
0 0 .281 r
.34905 .55511 m .34911 .55522 L .34913 .55488 L F
.636 .224 .245 r
.3493 .55557 m .34668 .55631 L .34781 .55577 L F
.361 .164 .473 r
.34948 .55546 m .34931 .55667 L .35005 .5564 L F
.636 .224 .245 r
.34977 .55551 m .34935 .55562 L .3493 .55557 L F
.34935 .55562 m .34668 .55631 L .3493 .55557 L F
.972 .928 .643 r
.34943 .55889 m .34763 .56235 L .34983 .5569 L F
.3482 .56192 m .34763 .56235 L .34943 .55889 L F
.34943 .55889 m .34983 .5569 L .35044 .5584 L F
.361 .164 .473 r
.35108 .5581 m .34882 .56021 L .35115 .55822 L F
.34921 .55899 m .34882 .56021 L .35108 .5581 L F
0 0 0 r
.35398 .55429 m .35151 .55585 L .35156 .55528 L F
.35151 .55585 m .34983 .5569 L .35059 .55619 L F
.35151 .55585 m .35059 .55619 L .35156 .55528 L F
.636 .224 .245 r
.35156 .55528 m .35015 .55558 L .34977 .55551 L F
.35015 .55558 m .34668 .55631 L .34977 .55551 L F
.361 .164 .473 r
.34942 .55536 m .34941 .55545 L .34948 .55546 L F
.449 0 0 r
.34977 .55551 m .34909 .55521 L .34902 .55505 L F
.361 .164 .473 r
.34913 .55488 m .34911 .55522 L .34942 .55536 L F
.449 0 0 r
.34977 .55551 m .34924 .55558 L .34909 .55521 L F
.174 .239 .691 r
.34688 .55397 m .34722 .55416 L .34913 .55488 L F
.34722 .55416 m .34898 .55511 L .34902 .55505 L F
.34722 .55416 m .34902 .55505 L .34913 .55488 L F
.944 .595 .193 r
.60057 .41401 m .60234 .41762 L .60096 .41626 L F
0 0 .4 r
.60234 .41762 m .60401 .42148 L .60395 .42043 L F
.60234 .41762 m .60395 .42043 L .60096 .41626 L F
.824 .71 .739 r
.4396 .57033 m .43987 .56623 L .43756 .56706 L F
.408 .259 .566 r
.44171 .56978 m .4396 .57033 L .44144 .57264 L F
.894 .576 .079 r
.4034 .54405 m .4029 .54533 L .40214 .54229 L F
.4034 .54405 m .40382 .54694 L .4029 .54533 L F
.732 .734 .852 r
.74125 .30025 m .73903 .30296 L .73734 .29956 L F
0 0 .084 r
.48202 .56216 m .48065 .56575 L .4807 .56367 L F
.643 .447 .604 r
.34281 .51781 m .34585 .51773 L .34533 .51535 L F
.565 .408 .627 r
.43634 .58993 m .4345 .59449 L .43653 .59281 L F
.88 .664 .14 r
.43634 .58993 m .43653 .59281 L .43593 .59139 L F
.43634 .58993 m .43593 .59139 L .43911 .58935 L F
.847 .729 .733 r
.42635 .51502 m .42426 .51782 L .42771 .51858 L F
.862 .689 .667 r
.42548 .51956 m .42771 .51858 L .42426 .51782 L F
.42548 .51956 m .42758 .52168 L .42771 .51858 L F
.839 .927 .89 r
.5183 .40581 m .51389 .4076 L .51563 .40543 L F
.886 .888 .827 r
.5183 .40581 m .51563 .40543 L .51858 .40207 L F
.761 .7 .794 r
.37268 .68733 m .37688 .68776 L .37521 .686 L F
.276 .018 .329 r
.55499 .41307 m .55322 .41197 L .55247 .41368 L F
.55499 .41307 m .55526 .41091 L .55322 .41197 L F
0 0 .049 r
.62961 .35673 m .6309 .35559 L .63126 .35503 L F
.592 .398 .588 r
.37156 .68125 m .37307 .67985 L .37302 .67735 L F
.734 .634 .748 r
.30551 .63946 m .30574 .64202 L .30859 .63863 L F
.547 .818 .461 r
.30859 .63863 m .30574 .64202 L .30684 .64069 L F
.57 .879 .591 r
.30684 .64069 m .30574 .64202 L .30377 .64365 L F
.45 .179 .41 r
.34684 .57557 m .34476 .57373 L .34438 .57616 L F
.34599 .57482 m .34745 .57319 L .34476 .57373 L F
.542 .492 .749 r
.34625 .57196 m .34443 .57603 L .34342 .57356 L F
.34443 .57603 m .34438 .57616 L .34435 .57609 L F
.34443 .57603 m .34435 .57609 L .34342 .57356 L F
.45 .179 .41 r
.34684 .57557 m .3473 .57381 L .34599 .57482 L F
.3473 .57381 m .34745 .57319 L .34599 .57482 L F
.191 0 .263 r
.46813 .55355 m .47069 .55025 L .46868 .55119 L F
.736 .659 .774 r
.53261 .39788 m .53365 .40138 L .53002 .39959 L F
.796 .739 .8 r
.53365 .40138 m .52956 .40083 L .53002 .39959 L F
.742 .75 .858 r
.535 .39686 m .53365 .40138 L .53261 .39788 L F
.535 .39686 m .53651 .4003 L .53365 .40138 L F
.875 .705 .668 r
.41862 .49253 m .4168 .49517 L .41986 .49453 L F
.79 .45 .412 r
.4168 .49517 m .41785 .49725 L .41986 .49453 L F
.732 .373 .371 r
.41986 .49453 m .41785 .49725 L .42222 .49752 L F
0 .187 .619 r
.34678 .50999 m .3463 .50959 L .34443 .50842 L F
0 .416 .751 r
.34678 .50999 m .34906 .51072 L .3463 .50959 L F
.638 .545 .733 r
.3687 .68381 m .37184 .68371 L .37156 .68125 L F
.596 .484 .696 r
.36982 .68792 m .37184 .68371 L .3687 .68381 L F
.701 .878 .964 r
.42653 .45324 m .4197 .45459 L .42537 .45335 L F
.186 .716 .733 r
.42408 .45357 m .4197 .45459 L .42062 .45375 L F
.32 .763 .963 r
.42062 .45375 m .4197 .45459 L .41982 .45487 L F
.42062 .45375 m .41982 .45487 L .41763 .45374 L F
.646 .434 .581 r
.47059 .50465 m .47506 .50532 L .47497 .50231 L F
.659 .514 .676 r
.47497 .50231 m .47784 .50203 L .47761 .49906 L F
.664 .447 .581 r
.47497 .50231 m .47788 .50481 L .47784 .50203 L F
.47497 .50231 m .47506 .50532 L .47788 .50481 L F
0 0 0 r
.67926 .35602 m .67855 .35713 L .6778 .35452 L F
.815 .791 .83 r
.68006 .35071 m .68218 .35286 L .67926 .35602 L F
.548 .589 .847 r
.2724 .64506 m .2748 .6452 L .27304 .64075 L F
0 .382 .712 r
.25088 .57564 m .25418 .57687 L .25244 .57614 L F
.25088 .57564 m .25418 .57687 L .25244 .57614 L F
.579 .887 .99 r
.25476 .5752 m .25418 .57687 L .25244 .57614 L F
.94 .723 .581 r
.59039 .41686 m .58805 .41378 L .58737 .4166 L F
.932 .739 .619 r
.58743 .41937 m .59039 .41686 L .58737 .4166 L F
.58743 .41937 m .58948 .42096 L .59039 .41686 L F
.325 0 .251 r
.56576 .47009 m .56753 .47118 L .56528 .4721 L F
.56576 .47009 m .56836 .46926 L .56753 .47118 L F
.581 .551 .786 r
.34443 .50842 m .33975 .50494 L .34419 .50552 L F
.185 0 0 r
.31267 .62706 m .31218 .62589 L .31071 .62747 L F
.31267 .62706 m .31491 .62541 L .31218 .62589 L F
.952 .951 .657 r
.38184 .60595 m .38031 .60963 L .38004 .60719 L F
.918 .651 .159 r
.58805 .41378 m .58797 .41138 L .58728 .41067 L F
.587 .054 0 r
.53957 .45962 m .53851 .46009 L .5381 .46087 L F
.107 0 0 r
.5381 .46087 m .54214 .45872 L .53957 .45962 L F
.386 0 0 r
.42289 .58342 m .42121 .58386 L .4236 .58408 L F
.854 .702 .692 r
.42429 .58436 m .42241 .58297 L .42289 .58342 L F
0 0 .558 r
.42551 .58425 m .42429 .58436 L .42289 .58342 L F
.386 0 0 r
.42289 .58342 m .4236 .58408 L .42551 .58425 L F
.854 .702 .692 r
.42241 .58297 m .42144 .58226 L .42289 .58342 L F
0 0 .558 r
.42551 .58425 m .42538 .58605 L .42429 .58436 L F
.823 .809 .837 r
.67434 .34638 m .67138 .34995 L .67385 .34851 L F
.456 .242 .499 r
.43354 .50186 m .43674 .49804 L .4331 .49941 L F
.793 .515 .517 r
.33458 .52799 m .3345 .53056 L .34023 .5313 L F
.734 .625 .737 r
.43666 .46665 m .43762 .46942 L .4358 .46832 L F
.825 .493 .427 r
.43762 .46942 m .43603 .47161 L .4358 .46832 L F
0 0 0 r
.43827 .4699 m .43762 .46942 L .4398 .46988 L F
.43827 .4699 m .43603 .47161 L .43762 .46942 L F
.298 0 0 r
.4398 .46988 m .43827 .4699 L .43762 .46942 L F
.57 .891 .988 r
.3898 .46971 m .38513 .47006 L .38786 .46874 L F
.904 .562 .385 r
.38983 .47191 m .3898 .46971 L .38786 .46874 L F
.835 .784 .804 r
.38786 .46874 m .3898 .46971 L .38835 .46598 L F
.695 .554 .691 r
.47761 .49906 m .48053 .49886 L .48026 .49587 L F
.566 .572 .818 r
.47912 .49246 m .48026 .49587 L .48193 .49411 L F
.56 .492 .736 r
.48053 .49886 m .48193 .49411 L .48026 .49587 L F
.497 .441 .725 r
.24228 .58541 m .24444 .58376 L .24203 .58446 L F
.24228 .58541 m .24503 .58743 L .24444 .58376 L F
.845 .395 .14 r
.35545 .50636 m .35696 .5054 L .35504 .50483 L F
.35545 .50636 m .35909 .5086 L .35696 .5054 L F
.754 .28 0 r
.35696 .5054 m .35909 .5086 L .35934 .50847 L F
.223 0 0 r
.2989 .57193 m .30283 .5694 L .29937 .57062 L F
.2989 .57193 m .30143 .57142 L .30283 .5694 L F
.682 .923 .972 r
.62915 .34645 m .63036 .34721 L .63275 .3458 L F
.937 .883 .754 r
.70661 .31237 m .70505 .31335 L .70696 .31375 L F
.417 .27 .573 r
.70661 .31237 m .70681 .314 L .70918 .31194 L F
.924 .598 .136 r
.70591 .31414 m .70706 .31601 L .70696 .31375 L F
.841 .596 .051 r
.70696 .31375 m .70706 .31601 L .70661 .31237 L F
.417 .27 .573 r
.70681 .314 m .70706 .31601 L .70779 .31461 L F
.70681 .314 m .70779 .31461 L .70918 .31194 L F
.924 .598 .136 r
.70591 .31414 m .70661 .31388 L .70505 .31335 L F
.70661 .31388 m .70696 .31375 L .70613 .31357 L F
.70661 .31388 m .70613 .31357 L .70505 .31335 L F
.596 .484 .696 r
.36982 .68792 m .37268 .68733 L .37184 .68371 L F
.893 .9 .825 r
.34479 .63694 m .34799 .635 L .34604 .63716 L F
.682 .895 .537 r
.34604 .63716 m .34799 .635 L .34882 .63341 L F
.798 .713 .771 r
.34604 .63716 m .34882 .63341 L .34479 .63295 L F
.178 .201 .647 r
.34796 .6375 m .34604 .63716 L .34746 .63458 L F
0 0 0 r
.35016 .64086 m .35055 .64028 L .34845 .64161 L F
.35 .485 .854 r
.35016 .64086 m .34845 .64161 L .34604 .63716 L F
.35016 .64086 m .34604 .63716 L .34828 .63935 L F
.178 .201 .647 r
.34828 .63935 m .34604 .63716 L .34796 .6375 L F
.893 .9 .825 r
.34377 .63757 m .34479 .63694 L .34604 .63716 L F
.577 .723 .942 r
.67385 .34851 m .67761 .34684 L .67434 .34638 L F
.67385 .34851 m .67801 .34962 L .67761 .34684 L F
.621 .486 .676 r
.67801 .34962 m .68037 .34621 L .67761 .34684 L F
0 .172 .707 r
.60682 .42824 m .60838 .42971 L .60846 .42861 L F
.868 .45 .012 r
.43345 .48943 m .43541 .49259 L .43805 .48962 L F
.499 .44 .722 r
.43805 .48962 m .44047 .48868 L .4393 .48462 L F
.757 .366 0 r
.38009 .60271 m .38184 .60595 L .3812 .60518 L F
.939 .96 .665 r
.3812 .60518 m .38184 .60595 L .38004 .60719 L F
.868 .45 .012 r
.43345 .48943 m .43393 .4913 L .43541 .49259 L F
.724 .86 .946 r
.7426 .29295 m .74389 .29449 L .74123 .2953 L F
.838 .961 .888 r
.46135 .44137 m .4587 .44404 L .45901 .44133 L F
.865 .977 .853 r
.45901 .44133 m .4587 .44404 L .45745 .44327 L F
.749 .405 .401 r
.41409 .48519 m .41635 .48823 L .41648 .48615 L F
.896 .907 .825 r
.70174 .30624 m .69965 .30935 L .70154 .30972 L F
.605 .058 0 r
.69965 .30935 m .70233 .31169 L .70154 .30972 L F
0 0 0 r
.70154 .30972 m .7054 .30683 L .70174 .30624 L F
.70154 .30972 m .70522 .3081 L .7054 .30683 L F
.753 .699 .801 r
.70233 .31169 m .70522 .3081 L .70154 .30972 L F
.583 .666 .895 r
.53913 .39795 m .53651 .4003 L .535 .39686 L F
.454 .874 .748 r
.63698 .33571 m .63925 .33416 L .64072 .33357 L F
.63698 .33571 m .63677 .33556 L .63925 .33416 L F
0 0 .311 r
.43412 .56325 m .43282 .55805 L .43397 .56074 L F
.641 .938 .963 r
.47118 .48621 m .47028 .48547 L .4668 .48706 L F
.69 .841 .955 r
.47128 .48387 m .47118 .48621 L .47351 .48492 L F
.91 .978 .781 r
.47128 .48387 m .47028 .48547 L .47118 .48621 L F
.68 .668 .831 r
.47118 .48621 m .47472 .48643 L .47351 .48492 L F
.908 .502 .192 r
.39077 .51821 m .38995 .51979 L .38938 .51712 L F
.39077 .51821 m .3921 .52131 L .38995 .51979 L F
.84 .977 .877 r
.62778 .38472 m .62673 .38434 L .6262 .38389 L F
.54 .881 .987 r
.63147 .38346 m .62778 .38472 L .6262 .38389 L F
.419 .552 .883 r
.29794 .65577 m .29973 .66024 L .30164 .66008 L F
.845 .463 0 r
.60489 .42187 m .60457 .42242 L .60401 .42148 L F
.60489 .42187 m .60564 .42384 L .60457 .42242 L F
.855 .398 .045 r
.35909 .5086 m .36101 .51074 L .35934 .50847 L F
.891 .945 .838 r
.53238 .39489 m .52851 .39717 L .53075 .39481 L F
.604 .427 .616 r
.53075 .39481 m .52851 .39717 L .53289 .39553 L F
0 0 0 r
.52698 .39847 m .53289 .39553 L .52851 .39717 L F
.52698 .39847 m .52965 .39728 L .53289 .39553 L F
.07 0 0 r
.53289 .39553 m .52965 .39728 L .53204 .39653 L F
.389 0 0 r
.53289 .39553 m .53329 .39586 L .53075 .39481 L F
.49 0 0 r
.53329 .39586 m .53238 .39489 L .53075 .39481 L F
.53329 .39586 m .535 .39686 L .53238 .39489 L F
.365 .748 .988 r
.26968 .63187 m .27206 .63166 L .27017 .63057 L F
.693 .54 .674 r
.47784 .50203 m .48053 .49886 L .47761 .49906 L F
.791 .55 .573 r
.7084 .29602 m .7065 .29439 L .70924 .29359 L F
.7084 .29602 m .70681 .29686 L .7065 .29439 L F
.381 .147 .429 r
.7084 .29602 m .7068 .29973 L .70681 .29686 L F
.7084 .29602 m .71003 .29881 L .7068 .29973 L F
.301 .276 .664 r
.70924 .29359 m .7104 .29634 L .7084 .29602 L F
.333 .13 .448 r
.7104 .29634 m .71003 .29881 L .7084 .29602 L F
.943 .685 .217 r
.5489 .44042 m .545 .43792 L .54644 .44021 L F
.5489 .44042 m .54791 .43675 L .545 .43792 L F
.832 .545 .503 r
.54644 .44021 m .5485 .44326 L .5489 .44042 L F
.013 0 0 r
.70268 .29623 m .70543 .29543 L .7065 .29439 L F
0 0 0 r
.7065 .29439 m .7087 .29313 L .70924 .29359 L F
.7065 .29439 m .70543 .29543 L .7087 .29313 L F
.534 .009 0 r
.2748 .6452 m .27917 .6454 L .27722 .64684 L F
.068 .111 .599 r
.27917 .6454 m .28113 .64671 L .28199 .64592 L F
.369 0 0 r
.27722 .64684 m .27917 .6454 L .28199 .64592 L F
.686 .233 .17 r
.43569 .54933 m .43752 .54778 L .43254 .54696 L F
.995 .832 .567 r
.43569 .54933 m .43713 .5507 L .43752 .54778 L F
.489 .545 .84 r
.43532 .50872 m .4365 .50464 L .43361 .5055 L F
.43532 .50872 m .43766 .50788 L .4365 .50464 L F
.41 .302 .621 r
.43532 .50872 m .43793 .5108 L .43766 .50788 L F
.43766 .50788 m .43793 .5108 L .43532 .50872 L F
.648 .552 .732 r
.61755 .37995 m .61992 .37922 L .61905 .37495 L F
.417 .462 .8 r
.61142 .38997 m .6092 .39199 L .60803 .38787 L F
.328 .316 .693 r
.61234 .3938 m .6092 .39199 L .61142 .38997 L F
.476 .203 .419 r
.52973 .48795 m .52845 .49172 L .52586 .49225 L F
.519 .238 .428 r
.53215 .488 m .52845 .49172 L .52973 .48795 L F
.756 .24 0 r
.34877 .64696 m .34718 .64482 L .34519 .64407 L F
.289 .104 .448 r
.3365 .55072 m .33838 .55063 L .33857 .54729 L F
.303 .219 .592 r
.3365 .55072 m .33858 .55291 L .33838 .55063 L F
.753 .639 .735 r
.4426 .46872 m .4398 .46988 L .44437 .46977 L F
.68 .58 .737 r
.4398 .46988 m .44401 .4726 L .44437 .46977 L F
.69 .568 .713 r
.44437 .46977 m .44535 .46557 L .4426 .46872 L F
.44437 .46977 m .44648 .46688 L .44535 .46557 L F
.44437 .46977 m .44736 .46994 L .44648 .46688 L F
.249 0 .125 r
.44401 .4726 m .44736 .46994 L .44437 .46977 L F
.807 .776 .824 r
.43413 .56194 m .43582 .56536 L .43852 .56194 L F
0 0 .282 r
.43556 .56288 m .43501 .5639 L .43413 .56194 L F
0 0 .311 r
.43412 .56325 m .43413 .56194 L .43337 .56026 L F
0 .028 .596 r
.43412 .56325 m .43582 .56536 L .43413 .56194 L F
0 0 .282 r
.43501 .5639 m .43369 .56637 L .43413 .56194 L F
0 0 .311 r
.43337 .56026 m .43413 .56194 L .43282 .55805 L F
.55 .386 .612 r
.32628 .56958 m .32376 .57332 L .32377 .57024 L F
.824 .98 .886 r
.61427 .40923 m .61545 .40685 L .61503 .40925 L F
.832 .545 .503 r
.54644 .44021 m .54504 .44292 L .5485 .44326 L F
.709 .715 .854 r
.47472 .48643 m .47769 .48585 L .47351 .48492 L F
.577 .397 .601 r
.5271 .40418 m .52442 .40513 L .52695 .40153 L F
.5271 .40418 m .52442 .40513 L .52695 .40153 L F
.482 .325 .591 r
.52956 .40083 m .5271 .40418 L .52695 .40153 L F
.38 .255 .582 r
.37652 .60161 m .37444 .60277 L .37437 .59968 L F
.994 .854 .591 r
.74084 .29479 m .74123 .2953 L .73997 .29627 L F
.969 .713 .493 r
.73997 .29627 m .74172 .29774 L .74123 .2953 L F
.741 .884 .945 r
.74084 .29479 m .7426 .29295 L .74123 .2953 L F
.774 .967 .671 r
.74123 .2953 m .7426 .29295 L .73997 .29627 L F
.8 .895 .911 r
.44739 .52363 m .4492 .52487 L .4506 .52287 L F
.469 .86 .663 r
.42653 .45324 m .42778 .45216 L .42849 .45183 L F
.459 .884 .806 r
.42653 .45324 m .42537 .45335 L .42778 .45216 L F
.277 .14 .508 r
.57646 .41867 m .57463 .41974 L .57783 .41777 L F
.106 0 0 r
.68331 .37469 m .68272 .3754 L .67993 .37608 L F
.068 0 0 r
.68581 .37415 m .68272 .3754 L .68331 .37469 L F
.307 .07 .382 r
.4604 .543 m .46195 .54381 L .46242 .54088 L F
.4604 .543 m .46195 .54381 L .46242 .54088 L F
.139 .285 .752 r
.23039 .59294 m .23216 .59445 L .23137 .59511 L F
0 0 .256 r
.22937 .60269 m .22989 .6032 L .22907 .59873 L F
0 0 .43 r
.22937 .60269 m .23007 .60358 L .22989 .6032 L F
.933 .605 .392 r
.41492 .59469 m .4169 .59595 L .41652 .59307 L F
.506 .818 .497 r
.41781 .59175 m .41492 .59469 L .41652 .59307 L F
.761 .276 .083 r
.4205 .59638 m .41652 .59307 L .4169 .59595 L F
.534 .001 0 r
.28217 .65625 m .28388 .65745 L .28403 .65768 L F
.647 .879 .984 r
.44047 .48868 m .44445 .48868 L .44296 .48515 L F
.206 0 0 r
.27654 .51721 m .27732 .5178 L .27465 .51846 L F
.055 0 .184 r
.27972 .51426 m .27732 .5178 L .27654 .51721 L F
.066 0 .329 r
.47919 .57281 m .4788 .57542 L .47663 .57681 L F
0 0 .199 r
.47663 .57681 m .47797 .57798 L .47696 .57881 L F
.47663 .57681 m .4788 .57542 L .47797 .57798 L F
.574 .021 0 r
.30998 .62702 m .30562 .62561 L .30563 .62818 L F
0 0 .51 r
.30563 .62818 m .30758 .63091 L .30998 .62702 L F
.765 .563 .624 r
.34171 .60504 m .34515 .60744 L .34338 .60478 L F
.34171 .60504 m .34142 .60838 L .34515 .60744 L F
.093 0 .06 r
.34009 .61231 m .34515 .60744 L .34142 .60838 L F
.34009 .61231 m .34366 .61113 L .34515 .60744 L F
0 0 .264 r
.34515 .60744 m .346 .60443 L .34338 .60478 L F
.34515 .60744 m .34609 .60721 L .346 .60443 L F
0 0 0 r
.34515 .60744 m .34535 .60981 L .34609 .60721 L F
.34515 .60744 m .34366 .61113 L .34535 .60981 L F
.212 .012 .377 r
.4981 .52084 m .49599 .52434 L .49637 .52189 L F
.628 .914 .981 r
.28386 .51188 m .2845 .51007 L .28618 .51081 L F
.28386 .51188 m .2845 .51007 L .28618 .51081 L F
0 .184 .707 r
.36711 .56995 m .369 .57398 L .36935 .57199 L F
.592 .838 .991 r
.36935 .57199 m .369 .57398 L .36668 .57291 L F
.503 .371 .633 r
.63638 .39232 m .63853 .38794 L .63613 .38926 L F
.63638 .39232 m .63928 .39144 L .63853 .38794 L F
.148 0 0 r
.63833 .39251 m .63638 .39232 L .63603 .39384 L F
.63833 .39251 m .63928 .39144 L .63638 .39232 L F
.797 .905 .917 r
.47012 .43681 m .46644 .43743 L .46887 .43588 L F
.843 .954 .886 r
.47168 .4332 m .47012 .43681 L .46887 .43588 L F
.47168 .4332 m .47304 .43398 L .47012 .43681 L F
0 .101 .642 r
.23384 .60428 m .23308 .60589 L .23213 .60218 L F
.777 .648 .719 r
.23384 .60428 m .23155 .60564 L .23308 .60589 L F
.795 .656 .709 r
.6972 .28366 m .70105 .28431 L .69943 .28077 L F
.72 .275 .192 r
.6972 .28366 m .70006 .28608 L .70105 .28431 L F
0 .085 .611 r
.70105 .28431 m .7028 .28614 L .70197 .28725 L F
.585 .123 .124 r
.70006 .28608 m .7028 .28614 L .70105 .28431 L F
.322 .013 .275 r
.4481 .4921 m .45126 .48915 L .44841 .48919 L F
.62 .324 .445 r
.28749 .57406 m .28956 .57629 L .29038 .57428 L F
.948 .605 .204 r
.35286 .52383 m .35031 .51856 L .35075 .52415 L F
.832 .752 .775 r
.59053 .37075 m .59459 .36909 L .59338 .36784 L F
.59053 .37075 m .59203 .37241 L .59459 .36909 L F
.659 .49 .644 r
.59203 .37241 m .59472 .37222 L .59459 .36909 L F
.97 .86 .674 r
.59338 .36784 m .59459 .36909 L .595 .36604 L F
.734 .549 .642 r
.59459 .36909 m .59472 .37222 L .59762 .3716 L F
.983 .701 .395 r
.38652 .54902 m .38794 .54743 L .38617 .54627 L F
.38652 .54902 m .3882 .55042 L .38794 .54743 L F
.399 .139 .4 r
.31851 .57724 m .32037 .57864 L .31768 .57909 L F
.31851 .57724 m .32067 .57648 L .32037 .57864 L F
0 0 0 r
.71549 .3257 m .71386 .32705 L .71637 .32481 L F
.71269 .32809 m .71386 .32705 L .71549 .3257 L F
.727 .668 .792 r
.47081 .47241 m .47485 .47287 L .47338 .46901 L F
.674 .657 .825 r
.47485 .47287 m .47602 .46819 L .47338 .46901 L F
.47485 .47287 m .47774 .47202 L .47602 .46819 L F
.628 .499 .686 r
.47528 .47613 m .47774 .47202 L .47485 .47287 L F
.215 .28 .715 r
.35198 .5178 m .35395 .51674 L .35176 .51445 L F
.357 .812 .693 r
.35198 .5178 m .35159 .51787 L .35395 .51674 L F
.957 .645 .397 r
.44916 .47403 m .45113 .47508 L .45086 .47197 L F
.707 .895 .965 r
.45086 .47197 m .45186 .4693 L .45053 .47122 L F
.45086 .47197 m .45368 .47004 L .45186 .4693 L F
.91 .919 .531 r
.45053 .47122 m .44916 .47403 L .45086 .47197 L F
.957 .645 .397 r
.44916 .47403 m .45113 .47508 L .45086 .47197 L F
.806 .93 .558 r
.38943 .60428 m .39099 .60253 L .38983 .60161 L F
.771 .895 .49 r
.39033 .59986 m .38983 .60161 L .39165 .59818 L F
0 0 .095 r
.39033 .59986 m .38993 .60297 L .38983 .60161 L F
.38993 .60297 m .38972 .60457 L .38975 .60363 L F
.38993 .60297 m .38975 .60363 L .38983 .60161 L F
.806 .93 .558 r
.38943 .60428 m .38899 .60594 L .38928 .60546 L F
.38965 .60403 m .38928 .60546 L .39099 .60253 L F
.38943 .60428 m .38928 .60546 L .38965 .60403 L F
.584 .945 .852 r
.48484 .42711 m .48249 .42851 L .48058 .42891 L F
0 0 0 r
.65234 .39335 m .65368 .39233 L .65589 .39086 L F
.464 .43 .736 r
.46776 .47014 m .4701 .46946 L .46926 .46895 L F
.725 .734 .858 r
.545 .39771 m .54742 .40147 L .54309 .40063 L F
.809 .751 .799 r
.54514 .4022 m .54309 .40063 L .54742 .40147 L F
.54514 .4022 m .54742 .40147 L .54606 .40076 L F
.273 .502 .894 r
.54823 .39924 m .54742 .40147 L .545 .39771 L F
.527 .785 .991 r
.54823 .39924 m .54742 .40147 L .54962 .40062 L F
.701 .953 .953 r
.54823 .39924 m .54606 .40076 L .54742 .40147 L F
.527 .785 .991 r
.54823 .39924 m .54742 .40147 L .54962 .40062 L F
.757 .695 .793 r
.54695 .40385 m .54962 .40062 L .54742 .40147 L F
.31 .085 .402 r
.54742 .40147 m .54695 .40385 L .54962 .40062 L F
.806 .815 .858 r
.59244 .45553 m .59294 .45653 L .59588 .45338 L F
.366 .198 .516 r
.24826 .52816 m .24632 .53072 L .2465 .52792 L F
.649 .476 .636 r
.47784 .50203 m .48064 .50177 L .48053 .49886 L F
.56 .492 .736 r
.48053 .49886 m .48314 .49823 L .48193 .49411 L F
.597 .47 .678 r
.48064 .50177 m .48314 .49823 L .48053 .49886 L F
.778 .5 .515 r
.62163 .42 m .62325 .42151 L .62579 .42113 L F
.431 0 0 r
.62579 .42113 m .62181 .42217 L .62452 .42214 L F
.62579 .42113 m .62325 .42151 L .62181 .42217 L F
.955 .609 .274 r
.62452 .42214 m .62607 .42355 L .62579 .42113 L F
0 0 0 r
.30964 .63752 m .30859 .63863 L .30684 .64069 L F
.705 .359 .388 r
.25827 .62148 m .25999 .61919 L .25614 .61884 L F
.57 .302 .47 r
.25999 .61919 m .2628 .61893 L .2623 .6213 L F
.25999 .61919 m .2628 .61893 L .2623 .6213 L F
.931 .808 .702 r
.57293 .4292 m .5749 .43209 L .57383 .43312 L F
.937 .75 .625 r
.37151 .60838 m .36881 .61086 L .36954 .60885 L F
.494 .29 .532 r
.25375 .62167 m .25614 .61884 L .25325 .61916 L F
.703 .544 .669 r
.63111 .41148 m .63142 .41438 L .62682 .41434 L F
.666 .745 .909 r
.47351 .48492 m .47769 .48585 L .47616 .48398 L F
.595 .593 .82 r
.47769 .48585 m .47872 .4814 L .47616 .48398 L F
.47769 .48585 m .48028 .4851 L .47872 .4814 L F
.575 .458 .682 r
.47769 .48585 m .48044 .48883 L .48028 .4851 L F
.47769 .48585 m .47828 .4895 L .48044 .48883 L F
.015 0 .374 r
.48645 .5465 m .48633 .54917 L .48432 .55075 L F
0 0 .059 r
.48633 .54917 m .48406 .55324 L .48432 .55075 L F
.956 .632 .226 r
.593 .39131 m .59464 .3949 L .59215 .39399 L F
.661 .267 0 r
.59464 .3949 m .59497 .39574 L .59215 .39399 L F
.59464 .3949 m .59588 .39731 L .59497 .39574 L F
.244 0 0 r
.55192 .4546 m .54838 .45641 L .55 .45555 L F
.577 .093 .069 r
.55 .45555 m .55512 .45612 L .55192 .4546 L F
0 0 .08 r
.41059 .59344 m .411 .5941 L .4094 .59198 L F
.41059 .59344 m .41022 .59677 L .411 .5941 L F
.67 .975 .877 r
.35328 .6449 m .34877 .64696 L .35198 .64694 L F
.166 .409 .85 r
.3517 .64208 m .35328 .6449 L .35429 .64345 L F
.063 .018 .489 r
.35147 .62765 m .35035 .62512 L .35167 .62619 L F
.739 .571 .665 r
.34281 .51781 m .34654 .52061 L .34585 .51773 L F
.34281 .51781 m .3432 .52203 L .34654 .52061 L F
.755 .614 .703 r
.3432 .52203 m .3438 .5246 L .34654 .52061 L F
.803 .686 .735 r
.34585 .51773 m .34654 .52061 L .34688 .51863 L F
.284 0 .157 r
.30629 .5681 m .3079 .56894 L .30864 .56707 L F
.546 .161 .263 r
.54671 .48148 m .55057 .47906 L .54929 .48067 L F
.54671 .48148 m .54684 .47984 L .55057 .47906 L F
.306 0 .009 r
.55309 .47824 m .54929 .48067 L .55057 .47906 L F
.158 0 .006 r
.33903 .56385 m .33829 .5659 L .33596 .56636 L F
.667 .217 .176 r
.33903 .56385 m .34044 .56601 L .33829 .5659 L F
.773 .71 .792 r
.33015 .62968 m .33519 .63196 L .33265 .63381 L F
.581 .821 .99 r
.28845 .65954 m .29245 .66 L .29078 .65915 L F
.731 .958 .944 r
.29245 .66 m .29362 .6578 L .29078 .65915 L F
.29245 .66 m .29537 .65817 L .29362 .6578 L F
.758 .467 .492 r
.42288 .52325 m .42758 .52168 L .42548 .51956 L F
.42288 .52325 m .42738 .52412 L .42758 .52168 L F
.552 .886 .631 r
.64072 .33357 m .64229 .33194 L .64275 .33174 L F
.424 .848 .701 r
.64072 .33357 m .64162 .33277 L .64229 .33194 L F
.64072 .33357 m .63925 .33416 L .64162 .33277 L F
0 0 0 r
.52745 .42586 m .5288 .42535 L .53179 .42449 L F
.442 .851 .966 r
.23708 .61176 m .23472 .61241 L .23444 .61162 L F
.698 .161 0 r
.23472 .61241 m .2348 .61381 L .23444 .61162 L F
.23472 .61241 m .23677 .61474 L .2348 .61381 L F
.969 .726 .513 r
.23708 .61176 m .23677 .61474 L .23472 .61241 L F
.868 .987 .716 r
.72048 .29881 m .72004 .29861 L .72141 .29811 L F
.72048 .29881 m .72004 .29861 L .72141 .29811 L F
.708 .675 .816 r
.72133 .30315 m .72251 .30651 L .71963 .30657 L F
.531 .483 .748 r
.72453 .30309 m .72251 .30651 L .72133 .30315 L F
.72453 .30309 m .726 .30683 L .72251 .30651 L F
.806 .724 .774 r
.55128 .42337 m .55261 .42706 L .54867 .42658 L F
.909 .884 .797 r
.55261 .42706 m .54873 .42925 L .54867 .42658 L F
.355 .056 .312 r
.42541 .59281 m .42607 .59031 L .42864 .58934 L F
.584 .414 .617 r
.264 .61265 m .2651 .61527 L .26769 .61197 L F
.703 .475 .576 r
.5509 .46317 m .54685 .46521 L .54758 .46402 L F
.669 .832 .962 r
.54758 .46402 m .5509 .46317 L .54963 .46171 L F
0 0 0 r
.54963 .46171 m .54758 .46402 L .54685 .46521 L F
.502 .909 .853 r
.6358 .35051 m .63609 .35102 L .63415 .35198 L F
.487 .85 .603 r
.6358 .35051 m .63415 .35198 L .63285 .35284 L F
.497 .315 .563 r
.63415 .35198 m .63723 .35206 L .63609 .35102 L F
.208 .11 .517 r
.63608 .35315 m .63415 .35198 L .63723 .35206 L F
.63608 .35315 m .63487 .35542 L .63415 .35198 L F
.358 .089 .362 r
.28363 .57626 m .28061 .5793 L .28126 .57695 L F
.985 .723 .343 r
.60006 .40739 m .60124 .41151 L .59982 .41015 L F
.986 .841 .613 r
.60124 .41151 m .59924 .41274 L .59982 .41015 L F
.60124 .41151 m .60057 .41401 L .59924 .41274 L F
.624 .954 .922 r
.34642 .61898 m .34795 .61908 L .34886 .61756 L F
.34886 .61756 m .34795 .61908 L .34642 .61898 L F
.738 .47 .524 r
.32944 .50389 m .32603 .50152 L .32926 .50326 L F
.31 .028 .313 r
.36287 .62549 m .36066 .62765 L .36228 .62736 L F
0 0 .103 r
.36066 .62765 m .36094 .63001 L .36228 .62736 L F
.36066 .62765 m .35966 .63314 L .36094 .63001 L F
.447 .461 .78 r
.22172 .57318 m .22251 .56865 L .22139 .57036 L F
.843 .75 .76 r
.407 .47278 m .4035 .47246 L .40565 .4691 L F
.249 0 .125 r
.44401 .4726 m .44657 .47116 L .44736 .46994 L F
.446 .417 .733 r
.44736 .46994 m .44925 .46867 L .44648 .46688 L F
0 0 0 r
.44736 .46994 m .44657 .47116 L .44925 .46867 L F
.789 .815 .873 r
.45199 .49966 m .45405 .50136 L .45698 .4986 L F
.469 .296 .563 r
.28501 .54404 m .28449 .54811 L .28682 .54685 L F
.722 .888 .956 r
.37082 .49721 m .36869 .4987 L .36707 .49735 L F
.776 .3 .106 r
.36869 .4987 m .36737 .50002 L .36707 .49735 L F
.36869 .4987 m .3707 .50136 L .36737 .50002 L F
.924 .766 .667 r
.6814 .3494 m .68218 .35286 L .68006 .35071 L F
.738 .456 .501 r
.35071 .56747 m .34968 .5696 L .34587 .56931 L F
0 0 .045 r
.35071 .56747 m .34968 .5696 L .35218 .56627 L F
.72 .962 .943 r
.23236 .55876 m .23042 .55867 L .23075 .56038 L F
.588 .076 0 r
.23075 .56038 m .2332 .56306 L .23391 .56357 L F
0 .072 .631 r
.23272 .5623 m .2332 .56306 L .23194 .56168 L F
.843 .998 .822 r
.23391 .56357 m .2332 .56306 L .23367 .56189 L F
.401 .506 .85 r
.23367 .56189 m .2332 .56306 L .23042 .55867 L F
.897 .974 .673 r
.23367 .56189 m .23184 .56517 L .23391 .56357 L F
.188 0 .367 r
.23331 .56404 m .23184 .56517 L .23322 .5627 L F
.23349 .56292 m .23322 .5627 L .23367 .56189 L F
.23331 .56404 m .23322 .5627 L .23349 .56292 L F
0 .072 .631 r
.23042 .55867 m .23272 .5623 L .23075 .56038 L F
.23272 .5623 m .23194 .56168 L .23075 .56038 L F
.551 .39 .616 r
.44648 .46688 m .44866 .46606 L .44535 .46557 L F
.44648 .46688 m .44925 .46867 L .44866 .46606 L F
0 .235 .752 r
.23107 .58061 m .23519 .58529 L .23116 .58233 L F
.525 .905 .741 r
.34182 .6044 m .34171 .60504 L .34338 .60478 L F
.34182 .6044 m .33836 .60662 L .34171 .60504 L F
.959 .762 .594 r
.74125 .30025 m .74172 .29774 L .73997 .29627 L F
.74125 .30025 m .74172 .29774 L .73997 .29627 L F
.579 .944 .86 r
.63613 .38926 m .63799 .38759 L .63459 .38991 L F
.63613 .38926 m .63853 .38794 L .63799 .38759 L F
.612 .387 .551 r
.32964 .62793 m .32976 .63087 L .32575 .63099 L F
.32976 .63087 m .32979 .63163 L .32941 .63157 L F
.32976 .63087 m .32941 .63157 L .32575 .63099 L F
.773 .71 .792 r
.32988 .63061 m .33265 .63381 L .32888 .63399 L F
.33015 .62968 m .33025 .62985 L .32988 .63061 L F
.33025 .62985 m .33265 .63381 L .32988 .63061 L F
.889 .738 .688 r
.33265 .63381 m .3312 .63998 L .32888 .63399 L F
.938 .936 .768 r
.4358 .46832 m .43538 .46791 L .43666 .46665 L F
.957 .646 .227 r
.4358 .46832 m .43603 .47161 L .43538 .46791 L F
.631 .583 .781 r
.23838 .59973 m .24183 .59939 L .24039 .59729 L F
0 0 0 r
.23838 .59973 m .24019 .59821 L .24039 .59729 L F
.583 .321 .485 r
.24183 .59939 m .24108 .60214 L .23838 .59973 L F
.996 .785 .504 r
.24108 .60214 m .24019 .59821 L .23838 .59973 L F
.427 .839 .969 r
.43698 .44869 m .43597 .44985 L .43454 .44922 L F
.43698 .44869 m .43846 .44925 L .43597 .44985 L F
.621 .486 .676 r
.67801 .34962 m .6814 .3494 L .68037 .34621 L F
.522 .148 .273 r
.68006 .35071 m .6814 .3494 L .67801 .34962 L F
.724 .66 .787 r
.54426 .40695 m .54838 .40775 L .54695 .40385 L F
.763 .681 .771 r
.54695 .40385 m .54838 .40775 L .55106 .40447 L F
.915 .963 .798 r
.55689 .46269 m .55456 .46634 L .55294 .46654 L F
.958 .676 .46 r
.55294 .46654 m .55456 .46634 L .55378 .46801 L F
.438 .873 .798 r
.61254 .34552 m .61425 .34434 L .61516 .34427 L F
.44 .877 .828 r
.61254 .34552 m .61175 .34548 L .61425 .34434 L F
.585 .75 .956 r
.32243 .55575 m .32425 .55765 L .3202 .55669 L F
.785 .322 0 r
.32243 .55575 m .32371 .55762 L .32425 .55765 L F
.804 .578 .595 r
.32371 .55762 m .32659 .55915 L .32425 .55765 L F
.943 .76 .625 r
.42321 .55514 m .42592 .55691 L .42463 .55418 L F
.835 .885 .454 r
.42501 .56516 m .42477 .56702 L .42628 .56335 L F
.807 .985 .717 r
.36919 .61544 m .36757 .61696 L .36926 .61303 L F
.821 .89 .892 r
.37082 .61142 m .36919 .61544 L .36926 .61303 L F
.37082 .61142 m .37293 .61206 L .36919 .61544 L F
.808 .895 .905 r
.61473 .36908 m .6097 .37016 L .6135 .36778 L F
.867 .984 .703 r
.61704 .36558 m .61473 .36908 L .61521 .36657 L F
.566 .779 .979 r
.61521 .36657 m .61473 .36908 L .6135 .36778 L F
.729 .545 .642 r
.45643 .5015 m .45803 .50514 L .45838 .50224 L F
.717 .984 .893 r
.42282 .57899 m .42159 .57849 L .41885 .57892 L F
.893 .746 .692 r
.41903 .58167 m .42165 .58002 L .41885 .57892 L F
.861 .995 .765 r
.42282 .57899 m .42257 .57951 L .42291 .57903 L F
.42242 .57935 m .42257 .57951 L .42282 .57899 L F
.717 .984 .893 r
.42327 .579 m .42257 .57951 L .42242 .57935 L F
.893 .746 .692 r
.42242 .57935 m .42327 .579 L .42282 .57899 L F
.861 .995 .765 r
.42159 .57849 m .42242 .57935 L .42282 .57899 L F
.42159 .57849 m .42291 .57903 L .42513 .57594 L F
.717 .984 .893 r
.42327 .579 m .42159 .57849 L .42282 .57899 L F
.42327 .579 m .42242 .57935 L .42159 .57849 L F
.893 .746 .692 r
.42165 .58002 m .42327 .579 L .42242 .57935 L F
.42165 .58002 m .42282 .57899 L .41885 .57892 L F
.662 .458 .598 r
.24399 .58008 m .24659 .58237 L .24774 .57978 L F
.24399 .58008 m .24444 .58376 L .24659 .58237 L F
.708 .675 .816 r
.72133 .30315 m .71963 .30657 L .71865 .30603 L F
.31 .028 .313 r
.36287 .62549 m .36228 .62736 L .36081 .62516 L F
0 0 0 r
.36405 .62492 m .36287 .62549 L .36552 .62242 L F
.161 .2 .654 r
.36489 .6274 m .36287 .62549 L .36405 .62492 L F
.198 0 .345 r
.5004 .51733 m .4981 .52084 L .49855 .51842 L F
.938 .579 .178 r
.3189 .66004 m .3187 .65806 L .31784 .65805 L F
.421 .142 .382 r
.32153 .65744 m .3187 .65806 L .3189 .66004 L F
.403 .492 .837 r
.22347 .5768 m .22438 .57321 L .22172 .57318 L F
.22347 .5768 m .2256 .57683 L .22438 .57321 L F
.595 .544 .768 r
.22347 .5768 m .22725 .58014 L .2256 .57683 L F
.529 .411 .663 r
.60747 .36846 m .60506 .37234 L .60384 .36824 L F
.60747 .36846 m .60784 .37165 L .60506 .37234 L F
.505 .83 .999 r
.60506 .37234 m .60784 .37165 L .60682 .37074 L F
.60506 .37234 m .60682 .37074 L .60381 .37348 L F
.725 .435 .487 r
.60381 .37348 m .60784 .37165 L .60506 .37234 L F
.628 .499 .686 r
.47528 .47613 m .47885 .47592 L .47774 .47202 L F
.727 .567 .673 r
.47523 .47848 m .47885 .47592 L .47528 .47613 L F
0 0 0 r
.42553 .54965 m .42439 .55064 L .42634 .54801 L F
.166 .317 .773 r
.42676 .55126 m .42439 .55064 L .42553 .54965 L F
.951 .653 .435 r
.38831 .55557 m .3901 .55402 L .38837 .55282 L F
.38831 .55557 m .39032 .55667 L .3901 .55402 L F
.57 .505 .743 r
.34368 .61907 m .33971 .61511 L .34352 .61696 L F
.738 .388 .389 r
.51304 .43611 m .5165 .43365 L .51234 .43291 L F
.51304 .43611 m .51802 .43672 L .5165 .43365 L F
.533 .693 .941 r
.32151 .52534 m .32225 .52367 L .31984 .52415 L F
.32151 .52534 m .32468 .52622 L .32225 .52367 L F
.745 .706 .814 r
.40655 .49248 m .4047 .49564 L .40912 .49594 L F
.471 .817 .998 r
.4047 .49564 m .40763 .49477 L .40912 .49594 L F
.853 .426 0 r
.40912 .49594 m .40763 .49477 L .40655 .49248 L F
.238 .717 .935 r
.6884 .313 m .68956 .31279 L .68701 .31286 L F
.64 .748 .927 r
.6884 .313 m .68701 .31286 L .68956 .31279 L F
.515 .899 .952 r
.59472 .37222 m .59726 .37114 L .59762 .3716 L F
.675 .652 .819 r
.60144 .36607 m .59762 .3716 L .59726 .37114 L F
.60144 .36607 m .60106 .37125 L .59762 .3716 L F
.238 .333 .76 r
.35657 .61851 m .35693 .62101 L .35483 .61878 L F
.749 .777 .876 r
.35693 .62101 m .35484 .62247 L .35483 .61878 L F
0 0 0 r
.46561 .59447 m .46717 .59297 L .4692 .59199 L F
.074 0 0 r
.46717 .59297 m .47045 .59028 L .4692 .59199 L F
.306 .417 .811 r
.27941 .65267 m .282 .6562 L .28206 .65611 L F
.971 .689 .438 r
.28217 .65625 m .28145 .65551 L .27941 .65267 L F
.611 .814 .978 r
.28208 .65607 m .28303 .65452 L .28145 .65551 L F
.28246 .65641 m .28298 .65469 L .28208 .65607 L F
.28298 .65469 m .28303 .65452 L .28208 .65607 L F
.306 .417 .811 r
.27941 .65267 m .2776 .65484 L .282 .6562 L F
.28206 .65611 m .282 .6562 L .28217 .65625 L F
.469 .745 .989 r
.61135 .43333 m .61554 .4344 L .6141 .43294 L F
.773 .721 .804 r
.61554 .4344 m .61665 .42954 L .6141 .43294 L F
.61554 .4344 m .61714 .43277 L .61665 .42954 L F
.486 .414 .701 r
.38248 .47615 m .38431 .47863 L .38285 .47509 L F
0 0 0 r
.4692 .59199 m .47045 .59028 L .47222 .58899 L F
.426 .577 .901 r
.22605 .58994 m .23039 .59294 L .23023 .59242 L F
.309 .391 .784 r
.23039 .59294 m .23184 .59159 L .23023 .59242 L F
.546 .923 .789 r
.52057 .42833 m .51888 .42995 L .52216 .42788 L F
.509 .853 .585 r
.51774 .43074 m .51888 .42995 L .52057 .42833 L F
.833 .897 .478 r
.43837 .46257 m .43733 .46505 L .43704 .46447 L F
0 0 0 r
.43837 .46257 m .43704 .46447 L .43966 .46123 L F
.712 .584 .711 r
.43704 .46447 m .44108 .46523 L .43966 .46123 L F
0 0 0 r
.43966 .46123 m .43894 .46306 L .43704 .46447 L F
.46 .61 .912 r
.43479 .46035 m .43837 .46257 L .43729 .45918 L F
.114 .257 .734 r
.43837 .46257 m .43966 .46123 L .43729 .45918 L F
.801 .725 .78 r
.43966 .46123 m .43704 .46447 L .4356 .46061 L F
.43966 .46123 m .43704 .46447 L .4356 .46061 L F
.933 .771 .658 r
.43704 .46447 m .43504 .46396 L .4356 .46061 L F
.503 .12 .247 r
.43894 .46306 m .43673 .46387 L .43704 .46447 L F
.418 0 0 r
.43704 .46447 m .43546 .46433 L .43504 .46396 L F
.503 .12 .247 r
.43673 .46387 m .43546 .46433 L .43704 .46447 L F
.833 .897 .478 r
.43733 .46505 m .43666 .46665 L .43704 .46447 L F
.285 .281 .678 r
.43538 .46791 m .43704 .46447 L .43666 .46665 L F
.652 .891 .983 r
.44316 .44714 m .44235 .44942 L .44102 .44803 L F
.44316 .44714 m .44488 .44817 L .44235 .44942 L F
.67 .469 .605 r
.47784 .50203 m .48056 .50459 L .48064 .50177 L F
.47784 .50203 m .47788 .50481 L .48056 .50459 L F
.408 .583 .912 r
.22605 .58994 m .23023 .59242 L .22731 .5881 L F
.013 0 0 r
.41833 .48743 m .42312 .48531 L .42278 .48752 L F
.486 .165 .347 r
.42312 .48531 m .42537 .4873 L .42278 .48752 L F
0 .106 .611 r
.58494 .39684 m .58267 .39497 L .58141 .39355 L F
0 .064 .553 r
.58574 .39774 m .58267 .39497 L .58494 .39684 L F
.427 0 .06 r
.38943 .60428 m .38534 .6064 L .38729 .6077 L F
.988 .865 .506 r
.3886 .60561 m .38899 .60594 L .38943 .60428 L F
.427 0 .06 r
.38943 .60428 m .38972 .60457 L .38534 .6064 L F
.827 .93 .9 r
.38534 .6064 m .3889 .60491 L .38737 .60265 L F
.3889 .60491 m .38972 .60457 L .38922 .60416 L F
.3889 .60491 m .38922 .60416 L .38737 .60265 L F
.988 .865 .506 r
.38729 .6077 m .38802 .60694 L .3886 .60561 L F
.38802 .60694 m .38899 .60594 L .3886 .60561 L F
.38729 .6077 m .38829 .60861 L .38899 .60594 L F
.509 .096 .193 r
.33804 .5202 m .33614 .5188 L .33822 .51757 L F
.33804 .5202 m .33562 .52054 L .33614 .5188 L F
.392 .062 .282 r
.51427 .49889 m .5163 .50036 L .51378 .50109 L F
.51427 .49889 m .51663 .49848 L .5163 .50036 L F
.603 .332 .478 r
.55846 .46225 m .55723 .46059 L .55689 .46269 L F
.394 .172 .454 r
.54418 .3883 m .54414 .39106 L .54157 .3916 L F
.54157 .3916 m .54414 .39106 L .54418 .3883 L F
.831 .902 .889 r
.46065 .46725 m .46082 .46432 L .45927 .46611 L F
.46065 .46725 m .46234 .46553 L .46082 .46432 L F
.787 .918 .926 r
.46065 .46725 m .45927 .46611 L .45602 .46866 L F
.688 .497 .622 r
.32878 .62539 m .32964 .62793 L .33048 .62594 L F
.907 .851 .777 r
.33163 .625 m .32964 .62793 L .32878 .62539 L F
.332 .119 .433 r
.34044 .62447 m .33767 .62565 L .33801 .62806 L F
.33801 .62806 m .33767 .62565 L .34044 .62447 L F
.748 .759 .861 r
.32225 .52367 m .32468 .52622 L .32634 .52409 L F
.79 .606 .651 r
.58789 .37449 m .59203 .37241 L .59053 .37075 L F
.58789 .37449 m .59195 .37521 L .59203 .37241 L F
.66 .497 .652 r
.59203 .37241 m .59195 .37521 L .59472 .37222 L F
.59203 .37241 m .59195 .37521 L .59472 .37222 L F
.046 0 0 r
.25741 .52324 m .25389 .52612 L .25609 .52373 L F
.394 .298 .627 r
.28222 .57452 m .28363 .57626 L .28546 .57532 L F
.28546 .57532 m .28363 .57626 L .28222 .57452 L F
.754 .547 .616 r
.42061 .50826 m .42457 .50524 L .42297 .50471 L F
.42061 .50826 m .42377 .50901 L .42457 .50524 L F
.627 .43 .596 r
.42377 .50901 m .42738 .50475 L .42457 .50524 L F
.954 .643 .402 r
.36881 .51773 m .36897 .52008 L .37086 .52086 L F
.897 .484 .195 r
.36897 .52008 m .37215 .52402 L .37086 .52086 L F
.674 .97 .784 r
.65894 .37695 m .65714 .37863 L .65862 .37663 L F
.473 .833 .994 r
.60701 .34525 m .60615 .34716 L .60599 .34694 L F
.60701 .34525 m .60893 .34662 L .60615 .34716 L F
.432 .198 .456 r
.32111 .64101 m .32167 .63841 L .32501 .63742 L F
.978 .714 .459 r
.39032 .55667 m .39017 .55936 L .39187 .56008 L F
.979 .683 .363 r
.39054 .56186 m .39187 .56008 L .39017 .55936 L F
.39054 .56186 m .39205 .56301 L .39187 .56008 L F
.728 .938 .955 r
.35668 .64707 m .36043 .64537 L .35843 .64461 L F
.744 .94 .949 r
.35843 .64461 m .36043 .64537 L .36185 .64373 L F
0 0 .145 r
.69747 .36695 m .69527 .36863 L .69728 .36502 L F
0 0 0 r
.6943 .36962 m .69527 .36863 L .69747 .36695 L F
.789 .765 .831 r
.42967 .48322 m .42777 .48314 L .43081 .47822 L F
0 0 0 r
.42967 .48322 m .43052 .48322 L .42796 .48394 L F
.42967 .48322 m .43244 .4826 L .43052 .48322 L F
.7028 .28614 m .70084 .28933 L .70197 .28725 L F
.594 .269 .39 r
.36552 .62242 m .36714 .62442 L .36405 .62492 L F
.964 .872 .698 r
.39195 .59181 m .39479 .58931 L .39373 .58859 L F
.39195 .59181 m .39338 .59294 L .39479 .58931 L F
.979 .683 .362 r
.32286 .64486 m .32244 .64394 L .32204 .64447 L F
0 0 0 r
.3217 .64491 m .32204 .64447 L .32369 .64277 L F
.9 .986 .773 r
.32204 .64447 m .32286 .64486 L .319 .64781 L F
0 0 0 r
.319 .64781 m .32204 .64447 L .3217 .64491 L F
.979 .683 .362 r
.32244 .64394 m .32111 .64101 L .32204 .64447 L F
.757 .982 .737 r
.32369 .64277 m .32286 .64486 L .319 .64781 L F
.464 .793 .999 r
.27147 .57996 m .27395 .57956 L .26962 .57881 L F
.754 .724 .825 r
.43987 .56623 m .43582 .56536 L .43756 .56706 L F
.43987 .56623 m .43852 .56194 L .43582 .56536 L F
.43987 .56623 m .44023 .56358 L .43852 .56194 L F
.992 .769 .393 r
.40893 .57022 m .40792 .57228 L .40739 .56847 L F
.40893 .57022 m .40897 .57347 L .40792 .57228 L F
.494 .29 .532 r
.25375 .62167 m .25597 .6216 L .25614 .61884 L F
.382 .16 .449 r
.29751 .64115 m .29787 .63841 L .30006 .63781 L F
.30006 .63781 m .29787 .63841 L .29751 .64115 L F
.367 0 .15 r
.43624 .50122 m .43938 .4988 L .43674 .49804 L F
.43624 .50122 m .43901 .50046 L .43938 .4988 L F
.429 0 .115 r
.43901 .50046 m .44303 .49832 L .43938 .4988 L F
.777 .879 .921 r
.44105 .46682 m .4398 .46988 L .4426 .46872 L F
.808 .886 .901 r
.44105 .46682 m .4426 .46872 L .44535 .46557 L F
.969 .726 .513 r
.23708 .61176 m .23865 .61562 L .23677 .61474 L F
.23677 .61474 m .23865 .61562 L .23708 .61176 L F
.728 .938 .955 r
.35668 .64707 m .35843 .64461 L .35616 .64742 L F
.48 .097 .235 r
.42184 .58623 m .42006 .58872 L .41775 .58884 L F
.78 .456 .439 r
.42184 .58623 m .42403 .58888 L .42006 .58872 L F
.718 .194 0 r
.37273 .50207 m .37129 .5029 L .3707 .50136 L F
.37273 .50207 m .37494 .50434 L .37129 .5029 L F
.712 .179 0 r
.37707 .50494 m .37494 .50434 L .37273 .50207 L F
.511 .263 .475 r
.52296 .4922 m .52276 .49466 L .52006 .49515 L F
.5 .254 .473 r
.52296 .4922 m .52546 .49405 L .52276 .49466 L F
.571 .218 .331 r
.52586 .49225 m .52546 .49405 L .52296 .4922 L F
.749 .777 .876 r
.35693 .62101 m .35881 .62213 L .35484 .62247 L F
.725 .443 .5 r
.35484 .62247 m .35881 .62213 L .3585 .62416 L F
.861 .904 .862 r
.35943 .61802 m .35881 .62213 L .35693 .62101 L F
.35943 .61802 m .3613 .61937 L .35881 .62213 L F
0 .353 .812 r
.36636 .61751 m .36775 .6192 L .36922 .6197 L F
.893 .746 .692 r
.41903 .58167 m .42144 .58226 L .42327 .579 L F
.273 .705 .966 r
.33759 .54416 m .33533 .54291 L .33475 .54399 L F
.867 .984 .703 r
.61704 .36558 m .61521 .36657 L .6157 .36471 L F
.284 .688 .972 r
.61835 .36473 m .61993 .36582 L .61704 .36558 L F
.468 .72 .979 r
.62555 .40455 m .62792 .40471 L .62656 .40251 L F
.62792 .40471 m .62841 .40449 L .62656 .40251 L F
.215 0 0 r
.62649 .4048 m .62866 .40475 L .62555 .40455 L F
.589 .777 .97 r
.62656 .40251 m .62866 .40475 L .63135 .40354 L F
.831 .549 .513 r
.62306 .40383 m .62474 .4044 L .62656 .40251 L F
.034 .173 .679 r
.62649 .4048 m .62555 .40455 L .62656 .40251 L F
.468 .72 .979 r
.62792 .40471 m .62866 .40475 L .62841 .40449 L F
.562 .887 .989 r
.63135 .40354 m .62866 .40475 L .62649 .4048 L F
.425 .863 .916 r
.62768 .40409 m .62929 .40392 L .62649 .4048 L F
.63054 .40354 m .62939 .40405 L .62649 .4048 L F
.62862 .40353 m .62649 .4048 L .62703 .40518 L F
.034 .173 .679 r
.62649 .4048 m .62656 .40251 L .62703 .40518 L F
.831 .549 .513 r
.62474 .4044 m .62703 .40518 L .62685 .40418 L F
.62474 .4044 m .62685 .40418 L .62656 .40251 L F
.425 .863 .916 r
.62862 .40353 m .63054 .40354 L .62929 .40392 L F
.62862 .40353 m .62929 .40392 L .62768 .40409 L F
.63054 .40354 m .63135 .40354 L .62939 .40405 L F
.993 .875 .553 r
.73508 .32289 m .735 .31922 L .73415 .32184 L F
.976 .812 .398 r
.73407 .32425 m .73508 .32289 L .73415 .32184 L F
.73407 .32425 m .7349 .3263 L .73508 .32289 L F
.757 .695 .793 r
.54695 .40385 m .55106 .40447 L .54962 .40062 L F
.704 .668 .812 r
.54962 .40062 m .55106 .40447 L .5536 .4011 L F
.664 .609 .783 r
.55106 .40447 m .55446 .40397 L .5536 .4011 L F
.616 .948 .933 r
.33786 .61561 m .3399 .61336 L .34009 .61231 L F
.33786 .61561 m .33784 .61427 L .3399 .61336 L F
.776 .799 .872 r
.43479 .47598 m .43182 .47581 L .43316 .47384 L F
.778 .539 .574 r
.43479 .47598 m .43081 .47822 L .43182 .47581 L F
.43479 .47598 m .43488 .47871 L .43081 .47822 L F
.559 .551 .802 r
.43603 .47161 m .43479 .47598 L .43316 .47384 L F
.43603 .47161 m .43731 .47554 L .43479 .47598 L F
.515 .332 .571 r
.43479 .47598 m .43488 .47871 L .43731 .47554 L F
.43479 .47598 m .43488 .47871 L .43731 .47554 L F
0 0 0 r
.66174 .38762 m .66472 .38458 L .66402 .38618 L F
.66472 .38458 m .6682 .38228 L .66722 .3837 L F
.66402 .38618 m .66472 .38458 L .66722 .3837 L F
.62399 .41662 m .62682 .41434 L .62679 .41671 L F
.681 .406 .499 r
.62682 .41434 m .63142 .41438 L .63063 .4165 L F
.357 .096 .374 r
.51001 .43353 m .51281 .4305 L .51234 .43291 L F
.985 .734 .47 r
.51234 .43291 m .51281 .4305 L .51001 .43353 L F
.588 .014 0 r
.51281 .4305 m .51494 .43242 L .51234 .43291 L F
.51281 .4305 m .51611 .43209 L .51494 .43242 L F
.228 .298 .728 r
.51685 .43045 m .51611 .43209 L .51281 .4305 L F
.519 .268 .475 r
.5468 .39015 m .54414 .39106 L .54418 .3883 L F
.54418 .3883 m .54414 .39106 L .5468 .39015 L F
.636 .193 .181 r
.34151 .54691 m .34131 .54701 L .34102 .54661 L F
.34269 .54762 m .34131 .54701 L .34151 .54691 L F
.507 .279 .503 r
.33857 .54729 m .34087 .54747 L .34102 .54661 L F
.33857 .54729 m .33838 .55063 L .34269 .54762 L F
.125 0 .217 r
.33858 .55291 m .34169 .5489 L .33838 .55063 L F
.34169 .5489 m .34269 .54762 L .34162 .54836 L F
.34169 .5489 m .34162 .54836 L .33838 .55063 L F
.33858 .55291 m .33968 .55347 L .34215 .54866 L F
.34169 .5489 m .34215 .54866 L .34269 .54762 L F
.33858 .55291 m .34215 .54866 L .34169 .5489 L F
.469 .208 .435 r
.34269 .54762 m .33968 .55347 L .34361 .55032 L F
.636 .193 .181 r
.34269 .54762 m .34316 .54868 L .34135 .54705 L F
.481 .415 .706 r
.34281 .54833 m .34183 .54725 L .34163 .54717 L F
.636 .193 .181 r
.34269 .54762 m .34135 .54705 L .34131 .54701 L F
.507 .279 .503 r
.34135 .54705 m .34269 .54762 L .34151 .54691 L F
.481 .415 .706 r
.34183 .54725 m .34151 .54691 L .34163 .54717 L F
.34163 .54717 m .34151 .54691 L .34143 .54698 L F
.34316 .54868 m .34283 .54831 L .34281 .54833 L F
.34283 .54831 m .34151 .54691 L .34281 .54833 L F
.34146 .54715 m .34143 .54698 L .34135 .54705 L F
.34316 .54868 m .34143 .54698 L .34146 .54715 L F
.507 .279 .503 r
.34087 .54747 m .34269 .54762 L .34135 .54705 L F
.481 .415 .706 r
.34135 .54705 m .34151 .54691 L .34131 .54701 L F
.507 .279 .503 r
.34087 .54747 m .34151 .54691 L .34102 .54661 L F
.481 .415 .706 r
.34316 .54868 m .34459 .54541 L .34151 .54691 L F
.34459 .54541 m .34505 .54434 L .34131 .54701 L F
.732 .742 .86 r
.41482 .46285 m .41188 .46437 L .41067 .46223 L F
0 0 0 r
.29279 .53279 m .29004 .53586 L .2916 .53381 L F
.2916 .53381 m .29082 .53471 L .29279 .53279 L F
.148 0 .263 r
.23728 .55299 m .23476 .55641 L .23548 .55408 L F
.97 .86 .674 r
.59338 .36784 m .595 .36604 L .59574 .36456 L F
.884 .606 .512 r
.59298 .44815 m .59684 .44674 L .59351 .44513 L F
.59298 .44815 m .59651 .44878 L .59684 .44674 L F
.789 .983 .72 r
.67335 .36459 m .6739 .36487 L .67097 .36821 L F
0 0 0 r
.67638 .36133 m .67424 .36439 L .67582 .36335 L F
.67846 .35983 m .67638 .36133 L .67582 .36335 L F
.67846 .35983 m .67582 .36335 L .67847 .36239 L F
.394 .852 .85 r
.67668 .36279 m .67582 .36335 L .67438 .36331 L F
.67847 .36239 m .67582 .36335 L .67668 .36279 L F
0 0 0 r
.67424 .36439 m .6739 .36487 L .67582 .36335 L F
.494 .905 .861 r
.67582 .36335 m .6739 .36487 L .67335 .36459 L F
0 0 .086 r
.41975 .49027 m .41862 .49253 L .41984 .48798 L F
.41973 .49075 m .41911 .49175 L .41975 .49027 L F
.41911 .49175 m .41862 .49253 L .41975 .49027 L F
.41973 .49075 m .41984 .48798 L .41833 .48743 L F
.332 .262 .626 r
.42132 .48957 m .41833 .48743 L .42278 .48752 L F
.41833 .48743 m .42035 .48888 L .4206 .48567 L F
.42035 .48888 m .42132 .48957 L .42094 .48752 L F
.42035 .48888 m .42094 .48752 L .4206 .48567 L F
.749 .994 .856 r
.47469 .4324 m .47304 .43398 L .47405 .43188 L F
.668 .925 .973 r
.47405 .43188 m .47304 .43398 L .47168 .4332 L F
.538 .422 .669 r
.47392 .53144 m .47632 .53069 L .4761 .52731 L F
.238 .121 .511 r
.47468 .53427 m .47632 .53069 L .47392 .53144 L F
.441 .287 .575 r
.51001 .43353 m .51304 .43611 L .51234 .43291 L F
0 0 .361 r
.51133 .43447 m .51001 .43353 L .51234 .43291 L F
.441 .287 .575 r
.51001 .43353 m .5102 .43644 L .51304 .43611 L F
0 0 .361 r
.51133 .43447 m .5102 .43644 L .51001 .43353 L F
.718 .864 .95 r
.33819 .57707 m .33905 .57796 L .34158 .5768 L F
.57 .607 .851 r
.33905 .57796 m .34282 .57991 L .34158 .5768 L F
.919 .656 .523 r
.43482 .55226 m .43713 .5507 L .43569 .54933 L F
.43482 .55226 m .43677 .55355 L .43713 .5507 L F
.485 .84 .577 r
.24818 .52172 m .24518 .52421 L .24781 .52205 L F
0 0 0 r
.24781 .52205 m .25019 .52085 L .24818 .52172 L F
.24781 .52205 m .2493 .52243 L .25019 .52085 L F
0 0 .095 r
.24781 .52205 m .24821 .52481 L .2493 .52243 L F
.491 .207 .411 r
.34065 .5562 m .33998 .55936 L .33864 .55837 L F
.093 0 .096 r
.34221 .55472 m .3427 .55561 L .34065 .5562 L F
0 0 .322 r
.34304 .55899 m .34065 .5562 L .33998 .55936 L F
.159 0 .289 r
.3427 .55561 m .33998 .55936 L .34065 .5562 L F
.64 .615 .809 r
.61714 .43277 m .61982 .42863 L .61665 .42954 L F
.61714 .43277 m .62064 .43048 L .61982 .42863 L F
.822 .691 .719 r
.44356 .50165 m .4477 .50294 L .44582 .49816 L F
.587 .526 .754 r
.4477 .50294 m .44846 .49765 L .44582 .49816 L F
.4477 .50294 m .45025 .50173 L .44846 .49765 L F
.758 .486 .523 r
.31692 .63003 m .32262 .62858 L .32253 .63143 L F
.536 .209 .361 r
.42996 .50465 m .43293 .50422 L .43354 .50186 L F
.456 .242 .499 r
.43354 .50186 m .43624 .50122 L .43674 .49804 L F
.427 .111 .324 r
.43354 .50186 m .43673 .50193 L .43624 .50122 L F
.43354 .50186 m .43293 .50422 L .43673 .50193 L F
.705 .359 .388 r
.25827 .62148 m .25614 .61884 L .25597 .6216 L F
.107 .434 .874 r
.24808 .59532 m .24833 .59154 L .24599 .59218 L F
.24808 .59532 m .24836 .59426 L .24833 .59154 L F
.749 .67 .774 r
.30095 .52811 m .30049 .53017 L .30407 .52776 L F
.773 .665 .112 r
.70066 .2937 m .70084 .28933 L .69935 .29255 L F
0 .159 .686 r
.69935 .29255 m .70268 .29623 L .70066 .2937 L F
.709 .292 .252 r
.27807 .57994 m .27664 .58144 L .27395 .57956 L F
.64 .204 .197 r
.27807 .57994 m .2803 .58196 L .27664 .58144 L F
.472 .251 .496 r
.28061 .5793 m .2803 .58196 L .27807 .57994 L F
.933 .585 .346 r
.6955 .32881 m .69315 .32822 L .6927 .32567 L F
.976 .821 .626 r
.6955 .32881 m .69272 .33089 L .69315 .32822 L F
.6955 .32881 m .69414 .33235 L .69272 .33089 L F
.351 .819 .747 r
.40981 .48569 m .41128 .48487 L .4126 .48442 L F
.763 .741 .833 r
.41069 .45951 m .40662 .45902 L .40932 .45617 L F
.693 .566 .708 r
.41067 .46223 m .40662 .45902 L .41069 .45951 L F
.696 .708 .857 r
.41361 .45836 m .41069 .45951 L .40932 .45617 L F
.678 .629 .793 r
.41361 .45836 m .41478 .45993 L .41069 .45951 L F
.783 .622 .681 r
.41478 .45993 m .41067 .46223 L .41069 .45951 L F
.036 0 .171 r
.35693 .63814 m .35577 .63838 L .35411 .64326 L F
.498 .028 .069 r
.34688 .55397 m .3427 .55561 L .34221 .55472 L F
.34688 .55397 m .34521 .55576 L .3427 .55561 L F
.174 .239 .691 r
.34688 .55397 m .34913 .55488 L .34946 .55418 L F
.486 .896 .92 r
.4668 .48706 m .463 .48785 L .46435 .48809 L F
.757 .697 .156 r
.69995 .35844 m .70035 .35594 L .70057 .35339 L F
.07 .144 .634 r
.61905 .37495 m .61992 .37922 L .62108 .37639 L F
.185 0 0 r
.61992 .37922 m .62052 .37857 L .62108 .37639 L F
.61992 .37922 m .62296 .37862 L .62202 .3797 L F
.61992 .37922 m .62202 .3797 L .62052 .37857 L F
.467 .845 .618 r
.52039 .43644 m .51682 .43896 L .51903 .43537 L F
.491 .75 .987 r
.52243 .43456 m .52039 .43644 L .51903 .43537 L F
.52243 .43456 m .52399 .43623 L .52039 .43644 L F
.711 .557 0 r
.4329 .55241 m .43301 .55532 L .43025 .55236 L F
.726 .387 .406 r
.43301 .55532 m .43677 .55355 L .43482 .55226 L F
.937 .961 .667 r
.43325 .55437 m .43482 .55226 L .43417 .55081 L F
.43301 .55532 m .43401 .55362 L .43325 .55437 L F
.43401 .55362 m .43482 .55226 L .43325 .55437 L F
.43301 .55532 m .43417 .55081 L .43485 .55336 L F
.897 .633 .53 r
.43298 .55487 m .43301 .55532 L .43485 .55336 L F
.781 .401 .336 r
.43025 .55236 m .43301 .55532 L .42918 .55445 L F
.897 .633 .53 r
.43301 .55532 m .43076 .55665 L .42918 .55445 L F
.43076 .55665 m .43301 .55532 L .43298 .55487 L F
.711 .557 0 r
.4329 .55241 m .43304 .55587 L .43301 .55532 L F
0 0 0 r
.43485 .55336 m .43322 .55509 L .43126 .55633 L F
.43173 .55587 m .43126 .55633 L .43076 .55665 L F
.43485 .55336 m .43126 .55633 L .43173 .55587 L F
.711 .557 0 r
.43304 .55587 m .43312 .55775 L .43301 .55532 L F
.665 .943 .961 r
.42691 .46226 m .42633 .46357 L .4278 .46226 L F
.479 .827 .551 r
.43061 .45981 m .42915 .46104 L .4278 .46226 L F
.376 .127 .404 r
.42915 .46104 m .42691 .46226 L .4278 .46226 L F
.42915 .46104 m .42893 .4633 L .42691 .46226 L F
.057 .279 .77 r
.42691 .46226 m .42893 .4633 L .42769 .46052 L F
.42691 .46226 m .42769 .46052 L .42735 .45976 L F
.665 .943 .961 r
.42691 .46226 m .42597 .46389 L .42633 .46357 L F
.42691 .46226 m .42295 .46368 L .42597 .46389 L F
.709 .381 0 r
.58768 .40472 m .58613 .40057 L .58622 .40332 L F
.955 .611 .249 r
.58662 .40516 m .58768 .40472 L .58622 .40332 L F
.58662 .40516 m .58817 .40692 L .58768 .40472 L F
.797 .723 .782 r
.2774 .51461 m .2741 .5143 L .27615 .51412 L F
.289 .064 .389 r
.27615 .51412 m .27496 .5162 L .27669 .51407 L F
.721 .985 .895 r
.2774 .51461 m .27615 .51412 L .27769 .51283 L F
.289 .064 .389 r
.27615 .51412 m .27669 .51407 L .27769 .51283 L F
.797 .723 .782 r
.2741 .5143 m .27292 .51418 L .27615 .51412 L F
.721 .985 .895 r
.2774 .51461 m .27769 .51283 L .27972 .51426 L F
.241 .74 .666 r
.23145 .58047 m .23107 .58061 L .23045 .58083 L F
.23157 .58043 m .23107 .58061 L .23145 .58047 L F
.873 .45 .027 r
.23107 .58061 m .22922 .58017 L .23045 .58083 L F
.381 .432 .789 r
.22725 .58014 m .22922 .58017 L .22934 .57872 L F
.757 .68 .132 r
.22934 .57872 m .22922 .58017 L .22934 .57819 L F
.873 .45 .027 r
.23107 .58061 m .22934 .57819 L .22922 .58017 L F
.23107 .58061 m .23051 .58081 L .22934 .57819 L F
.722 .925 .583 r
.23192 .57879 m .23061 .58077 L .23107 .58061 L F
.873 .45 .027 r
.23107 .58061 m .23054 .58087 L .23051 .58081 L F
.722 .925 .583 r
.23061 .58077 m .23054 .58087 L .23107 .58061 L F
.241 .74 .666 r
.23387 .5796 m .23107 .58061 L .23157 .58043 L F
.519 .554 .832 r
.23327 .57168 m .2349 .57548 L .23259 .57585 L F
.438 .185 .432 r
.2349 .57548 m .23375 .57794 L .23259 .57585 L F
0 .14 .681 r
.23524 .5737 m .2349 .57548 L .23327 .57168 L F
.23529 .57375 m .23526 .5739 L .23524 .5737 L F
.23526 .5739 m .2349 .57548 L .23524 .5737 L F
.519 .554 .832 r
.23327 .57168 m .23259 .57585 L .2309 .57293 L F
.246 .756 .866 r
.22895 .57189 m .23327 .57168 L .2309 .57293 L F
.22976 .57185 m .23083 .57163 L .23327 .57168 L F
.22895 .57189 m .23083 .57163 L .22976 .57185 L F
.407 .617 .937 r
.23161 .56898 m .2337 .57104 L .23083 .57163 L F
0 .156 .684 r
.23532 .57263 m .23529 .57375 L .23327 .57168 L F
.23532 .57263 m .23327 .57168 L .23083 .57163 L F
.407 .617 .937 r
.2337 .57104 m .23512 .57243 L .23083 .57163 L F
.23512 .57243 m .23532 .57263 L .23513 .57259 L F
.23512 .57243 m .23513 .57259 L .23083 .57163 L F
0 0 .061 r
.23529 .57375 m .23375 .57794 L .2349 .57548 L F
.23529 .57375 m .23482 .57635 L .23375 .57794 L F
.635 .944 .725 r
.23482 .57635 m .23401 .57703 L .23375 .57794 L F
0 0 .456 r
.23259 .57585 m .23375 .57794 L .23355 .57866 L F
.635 .944 .725 r
.23401 .57703 m .23192 .57879 L .23375 .57794 L F
0 0 .456 r
.23355 .57866 m .23375 .57794 L .23387 .5796 L F
.84 .998 .824 r
.23375 .57794 m .23107 .58061 L .23387 .5796 L F
.162 0 .037 r
.30607 .64785 m .30904 .64479 L .30758 .64661 L F
.978 .747 .52 r
.30904 .64479 m .30793 .64086 L .30945 .64632 L F
.882 .729 .687 r
.30945 .64632 m .30758 .64661 L .30904 .64479 L F
0 .097 .592 r
.46364 .54175 m .46532 .54337 L .46242 .54088 L F
.587 .311 .464 r
.46242 .54088 m .46532 .54337 L .46195 .54381 L F
0 .097 .592 r
.46364 .54175 m .46242 .54088 L .46195 .54381 L F
.318 0 0 r
.32997 .4947 m .33224 .49529 L .33412 .49538 L F
.45 0 0 r
.33224 .49529 m .33621 .49607 L .33412 .49538 L F
.841 .731 .743 r
.41664 .50418 m .41478 .50787 L .41867 .50727 L F
.361 0 0 r
.41478 .50787 m .41572 .50833 L .41867 .50727 L F
.762 .554 .616 r
.47759 .49115 m .48044 .48883 L .47828 .4895 L F
0 0 0 r
.34009 .61231 m .34161 .61216 L .34366 .61113 L F
.34009 .61231 m .3399 .61336 L .34161 .61216 L F
0 0 .498 r
.23971 .58572 m .23869 .5883 L .2384 .58559 L F
.23971 .58572 m .2403 .58849 L .23869 .5883 L F
.322 .013 .275 r
.4481 .4921 m .45074 .49159 L .45126 .48915 L F
.627 .435 .604 r
.45074 .49159 m .45343 .48806 L .45126 .48915 L F
.536 .508 .772 r
.26414 .62492 m .26094 .62207 L .2623 .6213 L F
.814 .995 .861 r
.36558 .63666 m .36555 .63851 L .36633 .63713 L F
.704 .914 .967 r
.46236 .439 m .46135 .44137 L .45901 .44133 L F
.46236 .439 m .46377 .43999 L .46135 .44137 L F
.574 .073 .025 r
.60627 .36511 m .61022 .36548 L .60903 .36681 L F
.085 0 0 r
.60903 .36681 m .61022 .36548 L .61303 .3646 L F
.831 .747 .771 r
.59588 .45338 m .59827 .45 L .59651 .44878 L F
0 .49 .782 r
.68796 .32115 m .69109 .32182 L .68741 .32072 L F
0 0 0 r
.32179 .59854 m .3248 .59556 L .32222 .59607 L F
.613 .399 .567 r
.3248 .59556 m .32179 .59854 L .32222 .59607 L F
0 0 0 r
.55846 .46225 m .55689 .46269 L .55523 .46359 L F
.028 .119 .624 r
.68037 .34621 m .6826 .34695 L .68293 .34524 L F
.68037 .34621 m .6814 .3494 L .6827 .34698 L F
.853 .917 .874 r
.68148 .34547 m .68006 .34895 L .67855 .34876 L F
.68006 .34895 m .67961 .35004 L .67924 .34959 L F
.68006 .34895 m .67924 .34959 L .67855 .34876 L F
.028 .119 .624 r
.6826 .34695 m .6827 .34698 L .68271 .34687 L F
.6826 .34695 m .68271 .34687 L .68293 .34524 L F
.526 .92 .878 r
.65406 .33576 m .64973 .33708 L .65165 .33721 L F
0 0 .459 r
.33406 .61111 m .33512 .61462 L .33337 .61207 L F
.846 .808 .813 r
.45819 .49122 m .4562 .48772 L .45366 .49095 L F
.856 .784 .78 r
.45484 .49505 m .45819 .49122 L .45366 .49095 L F
.674 .744 .904 r
.45819 .49122 m .4604 .48887 L .4562 .48772 L F
.483 .884 .733 r
.51494 .43242 m .51611 .43209 L .51774 .43074 L F
.116 0 .321 r
.49128 .5339 m .49085 .53623 L .48849 .53759 L F
.179 .031 .43 r
.49085 .53623 m .48824 .54009 L .48849 .53759 L F
0 0 .413 r
.41664 .50418 m .41707 .50036 L .41682 .50168 L F
.41664 .50418 m .41707 .50036 L .41682 .50168 L F
.755 .57 .645 r
.56378 .44886 m .56773 .44949 L .56789 .44645 L F
.757 .464 .488 r
.34138 .51408 m .33678 .51111 L .34097 .51119 L F
.43 .151 .386 r
.34443 .50842 m .34294 .51147 L .34097 .51119 L F
.431 .232 .508 r
.34294 .51147 m .34138 .51408 L .34097 .51119 L F
.656 .603 .783 r
.47619 .49257 m .47912 .49246 L .47759 .49115 L F
.657 .773 .935 r
.545 .43792 m .54791 .43675 L .54347 .43594 L F
0 .362 .771 r
.57988 .39244 m .57884 .39242 L .5785 .39007 L F
.57988 .39244 m .58141 .39355 L .57884 .39242 L F
.538 0 0 r
.72323 .3257 m .72705 .32652 L .72574 .32707 L F
0 .44 .798 r
.72705 .32652 m .72936 .32725 L .72849 .32659 L F
.72936 .32725 m .72951 .3273 L .72849 .32659 L F
.402 .823 .968 r
.72768 .32598 m .72849 .32659 L .72772 .32595 L F
0 .44 .798 r
.72705 .32652 m .72849 .32659 L .72574 .32707 L F
.402 .823 .968 r
.72574 .32707 m .72849 .32659 L .72768 .32598 L F
.382 .533 .882 r
.23023 .59242 m .2296 .58765 L .22731 .5881 L F
.23023 .59242 m .23184 .59159 L .2296 .58765 L F
.623 .959 .831 r
.63174 .39509 m .63356 .39486 L .62993 .39703 L F
.378 .841 .801 r
.63603 .39384 m .63356 .39486 L .63174 .39509 L F
.727 .668 .792 r
.47081 .47241 m .47338 .46901 L .4701 .46946 L F
.927 .591 .139 r
.25047 .59668 m .25163 .59957 L .25026 .59735 L F
.25047 .59668 m .25163 .59957 L .25026 .59735 L F
.401 .135 .391 r
.53461 .46929 m .53735 .46634 L .53724 .46865 L F
0 0 .524 r
.34044 .62447 m .34178 .62871 L .33801 .62806 L F
.792 .398 .308 r
.33801 .62806 m .34178 .62871 L .34238 .63127 L F
.238 .121 .511 r
.47468 .53427 m .47635 .53328 L .47632 .53069 L F
.25 .144 .533 r
.47468 .53427 m .47509 .53702 L .47635 .53328 L F
.703 .475 .576 r
.5509 .46317 m .55162 .46572 L .54685 .46521 L F
0 0 .476 r
.55175 .46386 m .5509 .46317 L .54963 .46171 L F
.476 .34 .616 r
.5509 .46317 m .55294 .46654 L .55162 .46572 L F
0 0 .318 r
.22675 .54736 m .22723 .54578 L .22647 .54302 L F
0 0 .298 r
.22675 .54736 m .22803 .54837 L .22723 .54578 L F
.22675 .54736 m .22659 .54999 L .22803 .54837 L F
.695 .715 .864 r
.432 .57766 m .43375 .57981 L .43083 .57937 L F
.846 .616 .59 r
.43375 .57981 m .43054 .58178 L .43083 .57937 L F
.43375 .57981 m .43395 .58285 L .43054 .58178 L F
.054 .389 .849 r
.4341 .5784 m .43375 .57981 L .432 .57766 L F
0 .264 .772 r
.4341 .5784 m .43626 .58175 L .43375 .57981 L F
.45 .314 .604 r
.43626 .58175 m .43395 .58285 L .43375 .57981 L F
.925 .891 .48 r
.54718 .44435 m .5485 .44326 L .54504 .44292 L F
.54718 .44435 m .54748 .44638 L .5485 .44326 L F
0 0 .213 r
.23458 .59713 m .23393 .59606 L .2353 .59466 L F
.23458 .59713 m .2341 .59877 L .23393 .59606 L F
.922 .737 .636 r
.726 .30683 m .72539 .30965 L .72763 .30972 L F
.56 .072 0 r
.72899 .3114 m .72763 .30972 L .72539 .30965 L F
.625 .305 .408 r
.72763 .30972 m .72985 .31227 L .73034 .3102 L F
0 .19 .716 r
.30752 .57421 m .30779 .57233 L .30514 .57371 L F
.829 .786 .811 r
.60384 .36824 m .60106 .37125 L .60144 .36607 L F
.60384 .36824 m .60144 .36607 L .60244 .36701 L F
.819 .942 .906 r
.60398 .36807 m .60572 .3645 L .60627 .36511 L F
.60395 .36803 m .60572 .3645 L .60398 .36807 L F
.60384 .36824 m .60244 .36701 L .60291 .36665 L F
.60395 .36803 m .60291 .36665 L .60572 .3645 L F
.60384 .36824 m .60291 .36665 L .60395 .36803 L F
.652 .521 .691 r
.60627 .36511 m .60747 .36846 L .60384 .36824 L F
.019 0 0 r
.60572 .3645 m .60244 .36701 L .60551 .36523 L F
0 0 .516 r
.60086 .36432 m .60551 .36523 L .60244 .36701 L F
.60086 .36432 m .60485 .36881 L .60551 .36523 L F
.60276 .36646 m .60296 .36654 L .60334 .36711 L F
.60086 .36432 m .60225 .36579 L .60276 .36646 L F
.60225 .36579 m .60296 .36654 L .60276 .36646 L F
.60334 .36711 m .60382 .36745 L .60485 .36881 L F
.60296 .36654 m .60382 .36745 L .60334 .36711 L F
.819 .942 .906 r
.60384 .36824 m .60395 .36803 L .60398 .36807 L F
.833 .574 .548 r
.37411 .68261 m .37156 .68125 L .37184 .68371 L F
.741 .643 .751 r
.37268 .68733 m .37411 .68261 L .37184 .68371 L F
.779 .921 .932 r
.55519 .39239 m .55225 .39466 L .5513 .39328 L F
.515 .03 .042 r
.55519 .39239 m .5513 .39328 L .55225 .39466 L F
.576 .905 .661 r
.41152 .50913 m .41001 .51008 L .40977 .5106 L F
.504 0 0 r
.41393 .51028 m .41001 .51008 L .41152 .50913 L F
.751 .576 .002 r
.43653 .59281 m .43649 .59417 L .43593 .59139 L F
.43653 .59281 m .43666 .59532 L .43649 .59417 L F
0 0 0 r
.69728 .36502 m .69896 .36074 L .69891 .36292 L F
0 0 .134 r
.69747 .36695 m .69728 .36502 L .69891 .36292 L F
.932 .56 .17 r
.58973 .42806 m .5905 .42682 L .58878 .42584 L F
.58973 .42806 m .59114 .42919 L .5905 .42682 L F
.873 .532 .028 r
.40461 .55037 m .40452 .55213 L .40436 .54959 L F
.40461 .55037 m .40525 .55287 L .40452 .55213 L F
0 0 0 r
.56406 .45225 m .56257 .45654 L .56371 .45459 L F
.717 .985 .809 r
.56371 .45459 m .56257 .45654 L .5611 .45674 L F
0 .397 .823 r
.61516 .41849 m .6171 .42019 L .61318 .41887 L F
.883 .709 .661 r
.36352 .61549 m .35943 .61802 L .36146 .61457 L F
.36352 .61549 m .36306 .61707 L .35943 .61802 L F
.602 .546 .765 r
.36533 .61128 m .36352 .61549 L .36146 .61457 L F
.36533 .61128 m .36757 .61696 L .36352 .61549 L F
.194 0 0 r
.534 .44772 m .53297 .44674 L .53237 .4476 L F
.534 .44772 m .53597 .44661 L .53297 .44674 L F
.218 0 .351 r
.50274 .51382 m .50074 .51488 L .50311 .51143 L F
.266 .056 .396 r
.50251 .51631 m .50074 .51488 L .50274 .51382 L F
.50251 .51631 m .5004 .51733 L .50074 .51488 L F
.062 0 0 r
.33095 .65514 m .33288 .65532 L .33069 .65687 L F
0 0 0 r
.65185 .32585 m .65468 .32466 L .65516 .32338 L F
.197 0 0 r
.56254 .47239 m .56379 .47322 L .56141 .47445 L F
.56254 .47239 m .56528 .4721 L .56379 .47322 L F
0 0 .452 r
.41001 .51008 m .41108 .51327 L .40977 .5106 L F
0 0 .218 r
.47946 .57011 m .48065 .56575 L .48042 .56828 L F
0 0 .319 r
.48042 .56828 m .47919 .57281 L .47946 .57011 L F
.041 0 .15 r
.34522 .50936 m .34443 .50842 L .3463 .50959 L F
.34522 .50936 m .34294 .51147 L .34443 .50842 L F
.088 .236 .722 r
.24629 .61399 m .2475 .61774 L .2452 .61565 L F
.958 .632 .355 r
.69237 .32323 m .69097 .32443 L .69109 .32182 L F
.69237 .32323 m .6927 .32567 L .69097 .32443 L F
.716 .983 .797 r
.63799 .38759 m .63853 .38794 L .63985 .38574 L F
.461 .343 .633 r
.63853 .38794 m .63928 .39144 L .64178 .39025 L F
.773 .637 .077 r
.22656 .55908 m .22542 .55666 L .22619 .55914 L F
.664 .651 .828 r
.47602 .46819 m .47774 .47202 L .4799 .46895 L F
.6 .563 .784 r
.47774 .47202 m .48126 .47306 L .4799 .46895 L F
.704 .601 .738 r
.47885 .47592 m .48126 .47306 L .47774 .47202 L F
.911 .668 .167 r
.58419 .35824 m .58366 .35755 L .58347 .35457 L F
.79 .527 .54 r
.58347 .35457 m .58366 .35755 L .57965 .35691 L F
.606 .929 .964 r
.58523 .35569 m .58305 .35674 L .58366 .35755 L F
.58305 .35674 m .58258 .35697 L .58366 .35755 L F
.911 .668 .167 r
.58419 .35825 m .58366 .35755 L .58419 .35824 L F
.741 .983 .909 r
.58593 .35587 m .58419 .35825 L .58485 .3586 L F
.58593 .35587 m .58366 .35755 L .58419 .35825 L F
.672 .561 .721 r
.43834 .52705 m .44088 .52461 L .43873 .52511 L F
.962 .921 .717 r
.41607 .49355 m .4168 .49517 L .41862 .49253 L F
.036 0 0 r
.41948 .49288 m .41862 .49253 L .41973 .49075 L F
.41948 .49288 m .41607 .49355 L .41862 .49253 L F
.791 .956 .922 r
.50872 .41135 m .50441 .41294 L .50732 .41019 L F
.832 .931 .896 r
.51044 .40942 m .50872 .41135 L .50927 .40829 L F
.81 .914 .909 r
.50927 .40829 m .50872 .41135 L .50732 .41019 L F
.948 .629 .198 r
.39496 .58516 m .3947 .58285 L .39339 .58163 L F
.556 .014 0 r
.34086 .53099 m .34288 .53285 L .34502 .53154 L F
.142 0 0 r
.34502 .53154 m .34593 .53217 L .3474 .52997 L F
.34502 .53154 m .34288 .53285 L .34593 .53217 L F
0 0 0 r
.42606 .47405 m .42459 .47542 L .42726 .47201 L F
.42606 .47405 m .42459 .47542 L .42726 .47201 L F
.879 .775 .743 r
.69842 .27672 m .69943 .28077 L .70027 .2781 L F
.69842 .27672 m .69943 .28077 L .70027 .2781 L F
.871 .903 .851 r
.36306 .61707 m .3613 .61937 L .35943 .61802 L F
.083 0 0 r
.25604 .51964 m .26186 .5169 L .25714 .51813 L F
.25604 .51964 m .25849 .51901 L .26186 .5169 L F
.37 0 0 r
.25849 .51901 m .26361 .51677 L .26186 .5169 L F
.783 .622 .681 r
.41478 .45993 m .41482 .46285 L .41067 .46223 L F
.688 .632 .787 r
.41739 .4595 m .41478 .45993 L .41361 .45836 L F
.675 .535 .686 r
.41478 .45993 m .41482 .46285 L .41739 .4595 L F
.41478 .45993 m .41482 .46285 L .41739 .4595 L F
.962 .89 .507 r
.40789 .56423 m .40657 .5649 L .40657 .56211 L F
.40789 .56423 m .40723 .56634 L .40657 .5649 L F
0 0 0 r
.63816 .40606 m .63694 .40792 L .63897 .40441 L F
.63594 .40989 m .63694 .40792 L .63816 .40606 L F
.776 .613 .678 r
.44535 .46557 m .44901 .46308 L .44817 .46232 L F
.44535 .46557 m .44866 .46606 L .44901 .46308 L F
.531 .781 .99 r
.45205 .46283 m .44817 .46232 L .44901 .46308 L F
.09 0 .057 r
.44866 .46606 m .45205 .46283 L .44901 .46308 L F
.916 .88 .456 r
.42347 .56795 m .42477 .56702 L .42501 .56516 L F
.42347 .56795 m .42381 .56995 L .42477 .56702 L F
.381 .415 .771 r
.34158 .5768 m .34282 .57991 L .34441 .57906 L F
0 0 .29 r
.34282 .57991 m .34372 .58074 L .34441 .57906 L F
.34282 .57991 m .34254 .58285 L .34372 .58074 L F
.798 .359 .204 r
.31354 .54108 m .3115 .54231 L .31028 .54005 L F
.253 0 0 r
.3146 .54083 m .31173 .54222 L .31354 .54108 L F
.31596 .54052 m .31495 .54092 L .3146 .54083 L F
.31495 .54092 m .31173 .54222 L .3146 .54083 L F
.31596 .54052 m .31413 .54204 L .3115 .54231 L F
.933 .81 .7 r
.3163 .53763 m .31596 .54052 L .31477 .53717 L F
0 0 .456 r
.31477 .53717 m .31545 .54105 L .31581 .5376 L F
.038 0 0 r
.31651 .54136 m .31413 .54204 L .31596 .54052 L F
0 0 .456 r
.31545 .54105 m .31547 .54115 L .31547 .54105 L F
.31545 .54105 m .31547 .54105 L .31581 .5376 L F
.813 .999 .84 r
.3122 .53833 m .31028 .54005 L .31077 .53884 L F
.7 .546 .675 r
.31077 .53884 m .31477 .53717 L .3122 .53833 L F
.31077 .53884 m .31533 .54108 L .31477 .53717 L F
.31533 .54108 m .31547 .54115 L .31545 .54105 L F
.31533 .54108 m .31545 .54105 L .31477 .53717 L F
.253 0 0 r
.31173 .54222 m .3115 .54231 L .31157 .54227 L F
.31173 .54222 m .31157 .54227 L .31354 .54108 L F
0 0 0 r
.37779 .61381 m .37979 .61247 L .37685 .61354 L F
.37779 .61381 m .37685 .61354 L .37504 .61181 L F
.853 .936 .878 r
.73187 .3265 m .7349 .3263 L .73407 .32425 L F
.583 .274 .41 r
.43731 .47554 m .44026 .47545 L .44274 .47276 L F
.68 .58 .737 r
.4398 .46988 m .44274 .47276 L .44401 .4726 L F
.46 .122 .305 r
.44274 .47276 m .44379 .47446 L .44401 .4726 L F
.44274 .47276 m .44026 .47545 L .44379 .47446 L F
.128 0 .227 r
.33326 .6414 m .33486 .63849 L .33429 .64109 L F
.319 .023 .296 r
.33429 .64109 m .33486 .63849 L .33714 .63765 L F
.695 .944 .656 r
.59472 .37222 m .59233 .37481 L .59326 .37309 L F
.763 .959 .652 r
.59472 .37222 m .59326 .37309 L .59586 .36974 L F
.762 .958 .65 r
.59586 .36974 m .59326 .37309 L .59421 .37093 L F
.59452 .37054 m .59421 .37093 L .59432 .37066 L F
.59586 .36974 m .59421 .37093 L .59452 .37054 L F
.695 .944 .656 r
.59233 .37481 m .59195 .37521 L .59326 .37309 L F
.58 .837 .994 r
.59326 .37309 m .59195 .37521 L .59047 .37387 L F
.045 0 0 r
.59326 .37309 m .59176 .37443 L .59454 .3736 L F
.568 .345 .537 r
.59454 .3736 m .59176 .37443 L .59161 .37409 L F
.431 .206 .469 r
.59047 .37387 m .58789 .37449 L .59053 .37075 L F
.644 .926 .65 r
.59192 .3688 m .59053 .37075 L .59099 .37028 L F
.59192 .3688 m .59099 .37028 L .59338 .36784 L F
.741 .765 .873 r
.59172 .36475 m .59574 .36456 L .59406 .36542 L F
.043 .267 .763 r
.59172 .36475 m .59338 .36784 L .59574 .36456 L F
.59172 .36475 m .5942 .36607 L .59338 .36784 L F
.714 .949 .657 r
.5942 .36607 m .59192 .3688 L .59338 .36784 L F
.649 .132 0 r
.59338 .36784 m .59586 .36974 L .59192 .3688 L F
.728 .683 .807 r
.59174 .36595 m .59192 .3688 L .5942 .36607 L F
.948 .942 .743 r
.59192 .3688 m .5942 .36607 L .59515 .36861 L F
.471 0 0 r
.59174 .36595 m .5928 .366 L .59172 .36475 L F
.5928 .366 m .5942 .36607 L .59355 .36572 L F
.5928 .366 m .59355 .36572 L .59172 .36475 L F
.752 .397 .38 r
.58837 .36608 m .59192 .3688 L .59174 .36595 L F
.948 .942 .743 r
.59192 .3688 m .59083 .36778 L .5916 .36645 L F
.701 .737 .879 r
.59304 .364 m .5942 .36607 L .59174 .36595 L F
.948 .942 .743 r
.59255 .3661 m .5916 .36645 L .59304 .364 L F
.59192 .3688 m .5916 .36645 L .59255 .3661 L F
.59192 .3688 m .59304 .364 L .5942 .36607 L F
.377 0 .145 r
.59515 .36861 m .59237 .36808 L .59192 .3688 L F
.59237 .36808 m .59083 .36778 L .59192 .3688 L F
.765 .623 .058 r
.59038 .3723 m .59053 .37075 L .59192 .3688 L F
.59038 .3723 m .59047 .37387 L .59053 .37075 L F
.689 .175 .005 r
.59038 .3723 m .59326 .37309 L .59047 .37387 L F
.59038 .3723 m .59176 .37443 L .59326 .37309 L F
.916 .947 .6 r
.59042 .37131 m .59038 .3723 L .59192 .3688 L F
.568 .345 .537 r
.59281 .37263 m .59161 .37409 L .59042 .37131 L F
.59454 .3736 m .59161 .37409 L .59281 .37263 L F
.045 0 0 r
.59326 .37309 m .59454 .3736 L .59435 .37109 L F
.59326 .37309 m .59435 .37109 L .59432 .37066 L F
.763 .959 .652 r
.59472 .37222 m .59586 .36974 L .59726 .37114 L F
.626 .23 .273 r
.33153 .57967 m .33061 .58106 L .32944 .57936 L F
.272 0 0 r
.32944 .57936 m .33057 .57986 L .33153 .57967 L F
.677 .207 .13 r
.3308 .58092 m .33006 .57979 L .33061 .58106 L F
0 0 0 r
.3336 .57904 m .33061 .58106 L .33153 .57967 L F
.677 .207 .13 r
.3321 .58005 m .33113 .57993 L .3308 .58092 L F
.33113 .57993 m .33006 .57979 L .3308 .58092 L F
.804 .867 .425 r
.33153 .57967 m .33113 .57993 L .33294 .57558 L F
.272 0 0 r
.33057 .57986 m .33113 .57993 L .33153 .57967 L F
.804 .867 .425 r
.33113 .57993 m .33144 .57896 L .33294 .57558 L F
0 .162 .696 r
.32927 .57797 m .33057 .57986 L .32944 .57936 L F
.677 .207 .13 r
.33047 .5797 m .32927 .57797 L .33006 .57979 L F
.793 .597 .637 r
.33294 .57558 m .33144 .57896 L .32927 .57797 L F
.677 .207 .13 r
.33224 .57933 m .32927 .57797 L .33047 .5797 L F
.3336 .57904 m .33006 .57979 L .3321 .58005 L F
.793 .597 .637 r
.33144 .57896 m .33097 .58003 L .32927 .57797 L F
.677 .207 .13 r
.3336 .57904 m .32927 .57797 L .33224 .57933 L F
.272 0 0 r
.33057 .57986 m .33097 .58003 L .33113 .57993 L F
0 .162 .696 r
.32927 .57797 m .33097 .58003 L .33057 .57986 L F
.804 .867 .425 r
.33113 .57993 m .33097 .58003 L .33144 .57896 L F
0 0 .5 r
.32944 .57936 m .33061 .58106 L .32927 .57797 L F
0 0 .469 r
.35996 .59461 m .35854 .59274 L .36087 .59248 L F
.36027 .59715 m .36047 .59878 L .35903 .59426 L F
.296 .792 .797 r
.36181 .59824 m .36047 .59878 L .35996 .59461 L F
.3 0 0 r
.36047 .59878 m .35803 .5992 L .35528 .59898 L F
.296 .792 .797 r
.36181 .59824 m .35803 .5992 L .36047 .59878 L F
.659 .405 .524 r
.36054 .59874 m .35758 .60119 L .35803 .5992 L F
0 0 0 r
.35975 .59957 m .35758 .60119 L .3613 .5986 L F
.3617 .59831 m .3613 .5986 L .36181 .59824 L F
.35975 .59957 m .3613 .5986 L .3617 .59831 L F
.659 .405 .524 r
.36098 .59882 m .35758 .60119 L .36054 .59874 L F
.36092 .59867 m .36054 .59874 L .36084 .59849 L F
.36098 .59882 m .36054 .59874 L .36092 .59867 L F
.58 .224 .329 r
.35803 .5992 m .35792 .60101 L .35604 .59957 L F
.533 .875 .621 r
.35671 .60209 m .35758 .60119 L .35975 .59957 L F
.58 .224 .329 r
.35792 .60101 m .35792 .60103 L .3579 .60102 L F
.35792 .60101 m .3579 .60102 L .35604 .59957 L F
.35803 .5992 m .35604 .59957 L .35528 .59898 L F
.659 .405 .524 r
.36084 .59849 m .36054 .59874 L .35803 .5992 L F
.36181 .59824 m .36098 .59882 L .36084 .59849 L F
0 0 .469 r
.35996 .59461 m .36027 .59715 L .35854 .59274 L F
.36027 .59715 m .35903 .59426 L .35854 .59274 L F
.76 .99 .773 r
.63275 .41222 m .63439 .41175 L .63594 .40989 L F
.858 .801 .794 r
.42172 .50059 m .41862 .50486 L .42297 .50471 L F
.868 .73 .707 r
.41862 .50486 m .42061 .50826 L .42297 .50471 L F
.744 .743 .851 r
.42172 .50059 m .42297 .50471 L .42583 .50113 L F
.734 .663 .78 r
.44015 .58826 m .43806 .58679 L .43845 .58699 L F
.43806 .58679 m .43585 .58524 L .43845 .58699 L F
.44015 .58826 m .43593 .59139 L .43585 .58524 L F
.428 0 0 r
.4398 .58802 m .44015 .58826 L .43845 .58699 L F
.527 .906 .739 r
.44042 .58844 m .43911 .58935 L .44015 .58826 L F
.428 0 0 r
.44103 .58895 m .44015 .58826 L .4398 .58802 L F
.633 .522 .71 r
.44015 .58826 m .44419 .58421 L .44109 .58798 L F
.44015 .58826 m .44361 .58612 L .44419 .58421 L F
.44015 .58826 m .44289 .58778 L .44361 .58612 L F
0 .183 .684 r
.43951 .58736 m .44103 .58895 L .43845 .58699 L F
.43919 .58738 m .43845 .58699 L .4368 .58756 L F
.43951 .58736 m .43845 .58699 L .43919 .58738 L F
.527 .906 .739 r
.44109 .58798 m .44042 .58844 L .44015 .58826 L F
.529 .891 .678 r
.44015 .58826 m .43911 .58935 L .43593 .59139 L F
0 0 .019 r
.31071 .62747 m .30998 .62702 L .30758 .63091 L F
.814 .802 .84 r
.25032 .59085 m .24609 .58909 L .24859 .58962 L F
.25032 .59085 m .24599 .59218 L .24604 .59066 L F
.25032 .59085 m .24604 .59066 L .24801 .58989 L F
.687 .19 .06 r
.24833 .59154 m .25032 .59085 L .24859 .58962 L F
.24833 .59154 m .24859 .58966 L .25245 .58919 L F
.24859 .58966 m .24859 .58962 L .24873 .5896 L F
.24859 .58966 m .24873 .5896 L .25245 .58919 L F
.814 .802 .84 r
.24801 .58989 m .24604 .59066 L .24609 .58909 L F
.785 .893 .921 r
.7384 .31211 m .73957 .30875 L .7376 .31075 L F
.7384 .31211 m .74071 .31024 L .73957 .30875 L F
.879 .597 .506 r
.56855 .45179 m .57008 .45034 L .56773 .44949 L F
.56855 .45179 m .57166 .45303 L .57008 .45034 L F
.25 .356 .777 r
.57008 .45034 m .57345 .45177 L .57365 .44935 L F
.57008 .45034 m .57166 .45303 L .57345 .45177 L F
.927 .554 .15 r
.69831 .27423 m .70027 .2781 L .69842 .27672 L F
.918 .802 .716 r
.70027 .2781 m .69831 .27423 L .69842 .27672 L F
.70027 .2781 m .70055 .2727 L .69831 .27423 L F
.396 .841 .731 r
.54838 .45641 m .54495 .4579 L .54773 .45752 L F
.782 .531 .557 r
.54773 .45752 m .55 .45555 L .54838 .45641 L F
.661 .758 .273 r
.29038 .57428 m .29037 .57426 L .29234 .57282 L F
.29038 .57428 m .28956 .57629 L .29037 .57426 L F
.639 .813 .967 r
.43061 .45981 m .43479 .46035 L .43319 .45861 L F
.618 .935 .96 r
.43479 .46035 m .43571 .45887 L .43319 .45861 L F
.43479 .46035 m .43729 .45918 L .43571 .45887 L F
.16 .7 .796 r
.26788 .52175 m .26324 .522 L .26527 .52122 L F
.78 .997 .812 r
.67097 .36821 m .66766 .37037 L .67112 .36736 L F
.789 .983 .72 r
.67335 .36459 m .67097 .36821 L .67112 .36736 L F
.773 .878 .923 r
.54194 .40814 m .54426 .40695 L .54261 .40532 L F
.854 .952 .877 r
.54093 .40719 m .54194 .40814 L .54261 .40532 L F
.514 .872 .986 r
.44985 .48271 m .44816 .48211 L .44568 .48294 L F
.562 .892 .986 r
.44985 .48271 m .45115 .48109 L .44816 .48211 L F
.861 .978 .856 r
.44105 .46682 m .43827 .4699 L .4398 .46988 L F
0 0 .095 r
.24264 .52583 m .24135 .5298 L .24292 .52845 L F
.711 .913 .964 r
.62214 .34277 m .61904 .34281 L .62168 .34223 L F
0 0 0 r
.62214 .34277 m .6239 .34116 L .62423 .34062 L F
.6239 .34116 m .62238 .34223 L .62344 .34191 L F
.6239 .34116 m .62344 .34191 L .62515 .3414 L F
.62423 .34062 m .6239 .34116 L .62487 .33996 L F
.571 .911 .972 r
.62214 .34277 m .62168 .34223 L .6239 .34116 L F
.758 .532 .59 r
.36206 .56012 m .36177 .56348 L .36566 .56361 L F
.373 .202 .516 r
.36397 .56252 m .36177 .56348 L .36206 .56012 L F
.758 .532 .59 r
.36206 .56012 m .36566 .56361 L .36397 .56252 L F
.625 .275 .359 r
.47254 .47942 m .47476 .48102 L .47523 .47848 L F
.47254 .47942 m .47218 .48143 L .47476 .48102 L F
.74 .89 .948 r
.46082 .46432 m .46234 .46553 L .46568 .46326 L F
.381 .432 .789 r
.22725 .58014 m .22934 .57872 L .2256 .57683 L F
.359 .511 .873 r
.22725 .58014 m .23045 .58083 L .22922 .58017 L F
.788 .288 0 r
.58754 .38642 m .58934 .38899 L .58756 .38823 L F
.58754 .38642 m .58756 .38823 L .58772 .38704 L F
.58754 .38642 m .58772 .38704 L .58802 .38479 L F
.662 .229 0 r
.58634 .38444 m .58745 .38613 L .58754 .38642 L F
.58745 .38613 m .5885 .38771 L .58754 .38642 L F
.568 0 0 r
.5885 .38771 m .59114 .38984 L .58934 .38899 L F
0 0 0 r
.65185 .32585 m .65092 .32704 L .65468 .32466 L F
.885 .942 .846 r
.61734 .37375 m .61905 .37495 L .62126 .37133 L F
.511 .407 .673 r
.61905 .37495 m .62205 .37477 L .62126 .37133 L F
.07 .144 .634 r
.61905 .37495 m .62108 .37639 L .62205 .37477 L F
.979 .898 .666 r
.393 .57485 m .3942 .57597 L .3953 .57347 L F
.983 .87 .643 r
.393 .57485 m .3953 .57347 L .39393 .57239 L F
.531 .781 .99 r
.45205 .46283 m .45212 .46208 L .44817 .46232 L F
.09 0 .057 r
.44866 .46606 m .45062 .46523 L .45205 .46283 L F
.678 .904 .976 r
.45205 .46283 m .45332 .46065 L .45212 .46208 L F
.003 .032 .537 r
.45383 .46467 m .45205 .46283 L .45062 .46523 L F
.45383 .46467 m .45332 .46065 L .45205 .46283 L F
.809 .751 .799 r
.54514 .4022 m .54492 .40521 L .54309 .40063 L F
.54514 .4022 m .54695 .40385 L .54492 .40521 L F
.842 .888 .873 r
.54261 .40532 m .54426 .40695 L .54695 .40385 L F
.751 .232 0 r
.37902 .50766 m .37494 .50434 L .37707 .50494 L F
.805 .35 .156 r
.38112 .50798 m .37902 .50766 L .37707 .50494 L F
.701 .601 .741 r
.47506 .50532 m .4753 .50823 L .47788 .50481 L F
.646 .524 .7 r
.4753 .50823 m .47842 .50789 L .47788 .50481 L F
.624 .456 .634 r
.47529 .51095 m .47842 .50789 L .4753 .50823 L F
.261 0 .247 r
.51378 .50109 m .51086 .50407 L .51149 .50206 L F
.597 .47 .678 r
.48064 .50177 m .48338 .50098 L .48314 .49823 L F
.669 .539 .697 r
.48056 .50459 m .48338 .50098 L .48064 .50177 L F
.904 .562 .385 r
.38983 .47191 m .38513 .47006 L .38606 .47276 L F
.986 .815 .588 r
.42726 .47201 m .42606 .47405 L .42555 .47178 L F
.299 0 .184 r
.42836 .47255 m .42606 .47405 L .42726 .47201 L F
.36 0 0 r
.42555 .47178 m .42836 .47255 L .42726 .47201 L F
.876 .972 .846 r
.49711 .41851 m .49776 .41565 L .49928 .41703 L F
.49711 .41851 m .49481 .41901 L .49776 .41565 L F
.391 .088 .327 r
.28382 .64384 m .28195 .6433 L .28199 .64592 L F
.28382 .64384 m .28396 .6422 L .28195 .6433 L F
.34 0 0 r
.45893 .48526 m .46295 .48423 L .46039 .4843 L F
.806 .815 .858 r
.59244 .45553 m .59588 .45338 L .59395 .45229 L F
.831 .747 .771 r
.59588 .45338 m .59651 .44878 L .59395 .45229 L F
.591 .545 .772 r
.47529 .51095 m .47682 .51484 L .47867 .51405 L F
.529 .363 .6 r
.47644 .5172 m .47867 .51405 L .47682 .51484 L F
.565 .625 .87 r
.58861 .45386 m .5905 .45169 L .58762 .45195 L F
.58861 .45386 m .59244 .45553 L .5905 .45169 L F
.833 .574 .548 r
.37411 .68261 m .37307 .67985 L .37156 .68125 L F
.99 .758 .488 r
.36519 .57149 m .36668 .57291 L .36711 .56995 L F
0 .184 .707 r
.36711 .56995 m .36935 .57199 L .36969 .56949 L F
.781 .506 .521 r
.36969 .56949 m .36519 .57149 L .36711 .56995 L F
0 0 0 r
.27465 .51846 m .27284 .51987 L .27135 .52015 L F
.879 .965 .638 r
.27496 .5162 m .27465 .51846 L .27732 .5178 L F
.27496 .5162 m .27284 .51987 L .27465 .51846 L F
.064 .619 .816 r
.44997 .58549 m .4485 .5857 L .4474 .58486 L F
.44997 .58549 m .45105 .58579 L .4485 .5857 L F
.895 .473 .124 r
.39714 .52798 m .39575 .52714 L .3945 .52435 L F
.949 .647 .43 r
.39714 .52798 m .3954 .52958 L .39575 .52714 L F
.39714 .52798 m .39739 .53098 L .3954 .52958 L F
0 0 .014 r
.43282 .55805 m .43301 .55532 L .43312 .55775 L F
.627 .934 .965 r
.29362 .6578 m .29537 .65817 L .29579 .65666 L F
.538 .27 .456 r
.52006 .49515 m .51989 .49751 L .51663 .49848 L F
.516 .258 .463 r
.52276 .49466 m .51989 .49751 L .52006 .49515 L F
.584 .945 .852 r
.48484 .42711 m .48058 .42891 L .4835 .4263 L F
.783 .981 .714 r
.48741 .42403 m .48484 .42711 L .48575 .42491 L F
.689 .929 .968 r
.48575 .42491 m .48484 .42711 L .4835 .4263 L F
.494 .796 .999 r
.59047 .37387 m .59195 .37521 L .58789 .37449 L F
.741 .643 .751 r
.37268 .68733 m .37521 .686 L .37411 .68261 L F
.731 .637 .754 r
.37521 .686 m .37757 .68304 L .37411 .68261 L F
.546 .52 .778 r
.36607 .596 m .36778 .59177 L .36461 .59201 L F
.36607 .596 m .36852 .59538 L .36778 .59177 L F
.473 0 0 r
.36414 .59661 m .36852 .59538 L .36607 .596 L F
0 0 0 r
.44379 .47446 m .44657 .47116 L .44401 .4726 L F
.851 .6 .06 r
.58562 .39926 m .58574 .39774 L .58494 .39684 L F
.58562 .39926 m .58613 .40057 L .58574 .39774 L F
.753 .285 .136 r
.25529 .62688 m .25687 .62552 L .25932 .62881 L F
.553 0 0 r
.44047 .59647 m .4384 .59667 L .43666 .59532 L F
0 0 0 r
.44312 .59659 m .4384 .59667 L .44047 .59647 L F
.916 .819 .736 r
.55743 .388 m .55366 .3904 L .55573 .38861 L F
.55743 .388 m .55557 .39165 L .55366 .3904 L F
.326 .796 .698 r
.55743 .388 m .5583 .38748 L .55969 .38682 L F
.55743 .388 m .55573 .38861 L .5583 .38748 L F
.5 .142 .29 r
.57452 .4203 m .57117 .42206 L .57114 .42137 L F
.542 .38 .611 r
.54154 .42667 m .54189 .42931 L .53919 .42751 L F
.54154 .42667 m .54189 .42931 L .53919 .42751 L F
.795 .997 .786 r
.62308 .39117 m .62455 .39128 L .62293 .39288 L F
.736 .602 .708 r
.36923 .55956 m .36977 .56414 L .36566 .56361 L F
.595 .5 .717 r
.37185 .56328 m .36977 .56414 L .36923 .55956 L F
.557 .407 .633 r
.36977 .56414 m .37221 .56607 L .37185 .56328 L F
.36977 .56414 m .37221 .56607 L .37185 .56328 L F
0 0 0 r
.37384 .60393 m .37131 .60562 L .37444 .60277 L F
.555 .324 .52 r
.37652 .60161 m .37384 .60393 L .37444 .60277 L F
.426 .183 .44 r
.25395 .51975 m .25604 .51964 L .25453 .51798 L F
.591 .187 .244 r
.25453 .51798 m .25604 .51964 L .25714 .51813 L F
.893 .768 .272 r
.37021 .63199 m .37064 .63467 L .37101 .63166 L F
.682 .97 .922 r
.584 .45238 m .58514 .45264 L .58365 .45178 L F
.497 .846 .995 r
.58514 .45264 m .58635 .45098 L .58365 .45178 L F
.58514 .45264 m .58762 .45195 L .58635 .45098 L F
.622 .951 .929 r
.41746 .467 m .4159 .46856 L .4184 .46743 L F
.41746 .467 m .41462 .46828 L .4159 .46856 L F
.433 0 0 r
.57876 .42601 m .575 .42464 L .57839 .42351 L F
.863 .881 .849 r
.58171 .42231 m .57876 .42601 L .57839 .42351 L F
.744 .672 .781 r
.73187 .28989 m .73316 .29388 L .72931 .29346 L F
.63 .149 .093 r
.72931 .29346 m .73316 .29388 L .7316 .29564 L F
.256 .362 .78 r
.73187 .28989 m .73477 .2916 L .73316 .29388 L F
.614 .857 .495 r
.73316 .29388 m .73477 .2916 L .7316 .29564 L F
.333 .168 .501 r
.57585 .44509 m .57283 .44756 L .57365 .44935 L F
.274 .085 .433 r
.4003 .47489 m .39828 .47964 L .40015 .47808 L F
.4003 .47489 m .40015 .47808 L .39954 .4744 L F
.648 .963 .919 r
.4003 .47489 m .40147 .47282 L .4035 .47246 L F
.4003 .47489 m .39954 .4744 L .40147 .47282 L F
.776 .667 .743 r
.6179 .41687 m .62163 .42 L .62046 .41637 L F
.6179 .41687 m .61747 .41978 L .62163 .42 L F
.826 .441 .323 r
.62181 .42217 m .62325 .42151 L .62163 .42 L F
.223 0 .348 r
.62163 .42 m .61962 .42318 L .62181 .42217 L F
.729 .65 .771 r
.62046 .41637 m .62163 .42 L .62399 .41662 L F
.787 .992 .882 r
.73258 .3115 m .73147 .31372 L .73386 .31145 L F
0 .441 .71 r
.73267 .31452 m .73147 .31372 L .73206 .31528 L F
.786 .317 0 r
.73206 .31528 m .72985 .31227 L .73223 .31371 L F
.927 .877 .454 r
.7315 .31597 m .73206 .31528 L .73223 .31371 L F
.73115 .31707 m .73206 .31528 L .7315 .31597 L F
0 .441 .71 r
.73364 .31515 m .73267 .31452 L .73206 .31528 L F
0 0 .183 r
.48406 .55324 m .48434 .55527 L .48306 .55698 L F
0 0 .149 r
.48434 .55527 m .48296 .55976 L .48306 .55698 L F
0 .172 .645 r
.53866 .47248 m .53461 .46929 L .53724 .46865 L F
.477 .818 .527 r
.32612 .49818 m .32997 .4947 L .32717 .49505 L F
.438 .233 .503 r
.3202 .55669 m .32239 .55871 L .32243 .55575 L F
.3202 .55669 m .32 .55965 L .32239 .55871 L F
.948 .605 .207 r
.59924 .41274 m .60057 .41401 L .60096 .41626 L F
.676 .708 .872 r
.29376 .65206 m .28955 .65074 L .29238 .65 L F
.489 .629 .914 r
.29589 .65127 m .29376 .65206 L .29238 .65 L F
0 0 0 r
.57054 .45313 m .57075 .45291 L .5691 .45347 L F
.458 0 0 r
.57075 .45291 m .57166 .45303 L .57092 .45273 L F
.485 .901 .867 r
.57345 .45177 m .57166 .45303 L .57075 .45291 L F
0 0 0 r
.5721 .45277 m .57075 .45291 L .57054 .45313 L F
.458 0 0 r
.57075 .45291 m .57092 .45273 L .56855 .45179 L F
.625 .447 .621 r
.44303 .49832 m .44582 .49816 L .44553 .49538 L F
.59 .415 .613 r
.44553 .49538 m .44843 .49492 L .4481 .4921 L F
.592 .423 .621 r
.44553 .49538 m .44582 .49816 L .44843 .49492 L F
.76 .289 .125 r
.36714 .62442 m .36941 .62473 L .37088 .62711 L F
.591 .383 .568 r
.5375 .48495 m .53485 .48786 L .53479 .48536 L F
.021 .233 .739 r
.27304 .64075 m .2748 .6452 L .2756 .64283 L F
.727 .833 .384 r
.2756 .64283 m .2748 .6452 L .27365 .64715 L F
.519 .042 .064 r
.27365 .64715 m .2748 .6452 L .27722 .64684 L F
0 0 .153 r
.60627 .36511 m .60767 .36291 L .60792 .36046 L F
.673 .974 .897 r
.60627 .36511 m .60572 .3645 L .60767 .36291 L F
.574 .073 .025 r
.60627 .36511 m .60903 .36681 L .60747 .36846 L F
.167 0 .334 r
.32157 .60934 m .32306 .6106 L .32378 .60838 L F
.32157 .60934 m .32136 .61149 L .32306 .6106 L F
.585 .412 .613 r
.4481 .4921 m .451 .49407 L .45074 .49159 L F
.4481 .4921 m .44843 .49492 L .451 .49407 L F
.937 .75 .625 r
.37151 .60838 m .37293 .61206 L .37082 .61142 L F
.414 .488 .827 r
.37504 .61181 m .37293 .61206 L .37151 .60838 L F
0 0 .459 r
.33406 .61111 m .33572 .61473 L .33512 .61462 L F
0 0 0 r
.33342 .61641 m .33512 .61462 L .33572 .61473 L F
.33342 .61641 m .33344 .61598 L .33512 .61462 L F
.282 .712 .968 r
.73506 .31551 m .73735 .3156 L .73364 .31515 L F
.971 .672 .278 r
.43729 .55699 m .43886 .55693 L .43787 .55546 L F
.43729 .55699 m .43919 .55982 L .43886 .55693 L F
.753 .909 .945 r
.6354 .3449 m .6397 .34391 L .63772 .34362 L F
.728 .96 .943 r
.6397 .34391 m .64124 .34159 L .63772 .34362 L F
.6397 .34391 m .64212 .34239 L .64124 .34159 L F
.626 .561 .762 r
.6197 .42685 m .62181 .42217 L .61962 .42318 L F
.037 .114 .616 r
.6036 .35912 m .60491 .36089 L .60434 .35766 L F
0 0 0 r
.6239 .34116 m .6274 .33877 L .62487 .33996 L F
.4239 .57775 m .42513 .57594 L .42664 .57459 L F
.68 .923 .61 r
.42485 .57608 m .4239 .57775 L .42664 .57459 L F
.044 0 .359 r
.42519 .57844 m .4239 .57775 L .42485 .57608 L F
.42529 .57916 m .4239 .57775 L .42519 .57844 L F
.861 .995 .765 r
.42159 .57849 m .42316 .57736 L .4239 .57775 L F
.42316 .57736 m .42513 .57594 L .4239 .57775 L F
0 0 0 r
.42664 .57459 m .42513 .57594 L .42624 .57367 L F
.491 .859 .628 r
.66473 .32827 m .66515 .32812 L .66724 .32647 L F
.317 .782 .659 r
.66546 .328 m .66515 .32812 L .66297 .32918 L F
0 0 0 r
.66146 .32998 m .66515 .32812 L .66392 .32886 L F
.491 .859 .628 r
.66392 .32886 m .66515 .32812 L .66473 .32827 L F
.317 .782 .659 r
.66549 .32799 m .66515 .32812 L .66546 .328 L F
0 0 0 r
.66297 .32918 m .66515 .32812 L .66146 .32998 L F
.72 .709 .839 r
.31829 .63086 m .31972 .63388 L .31735 .63507 L F
.967 .762 .575 r
.73997 .29627 m .74084 .29479 L .73869 .29228 L F
.691 .779 .918 r
.73869 .29228 m .7426 .29295 L .74084 .29479 L F
.719 .733 .215 r
.34259 .65013 m .34154 .65439 L .344 .65407 L F
.095 .037 .494 r
.36038 .53424 m .3617 .53623 L .36125 .53386 L F
.465 .269 .529 r
.32378 .60838 m .32628 .60499 L .32417 .60577 L F
.709 .275 0 r
.42381 .56995 m .425 .57249 L .42624 .57367 L F
0 0 0 r
.42664 .57459 m .42624 .57367 L .425 .57249 L F
.591 .024 0 r
.38544 .51079 m .38345 .50992 L .38112 .50798 L F
.903 .55 .364 r
.38544 .51079 m .3836 .5127 L .38345 .50992 L F
.38544 .51079 m .38678 .51464 L .3836 .5127 L F
.86 .533 .432 r
.38902 .51466 m .38678 .51464 L .38544 .51079 L F
.595 .5 .717 r
.37185 .56328 m .36923 .55956 L .3707 .55897 L F
.786 .532 .553 r
.42172 .50059 m .42583 .50113 L .42591 .49847 L F
.688 .632 .787 r
.41739 .4595 m .41361 .45836 L .41589 .45562 L F
.867 .497 .007 r
.60564 .42384 m .60534 .42488 L .60457 .42242 L F
.60564 .42384 m .60637 .42598 L .60534 .42488 L F
.92 .531 .146 r
.60457 .42242 m .60521 .42446 L .60371 .42348 L F
.60521 .42446 m .60534 .42488 L .60371 .42348 L F
.845 .381 .057 r
.60457 .42242 m .60371 .42348 L .60308 .42186 L F
.847 .385 .028 r
.60308 .42186 m .60371 .42348 L .60194 .42241 L F
0 .318 .762 r
.60371 .42348 m .60534 .42383 L .60234 .42257 L F
.60371 .42348 m .60234 .42257 L .60194 .42241 L F
0 .023 .592 r
.60534 .42488 m .60678 .42513 L .60431 .4238 L F
.60534 .42488 m .60431 .4238 L .60371 .42348 L F
.867 .497 .007 r
.60637 .42598 m .60641 .42609 L .60534 .42488 L F
.994 .868 .59 r
.39153 .5945 m .39338 .59294 L .39195 .59181 L F
.39153 .5945 m .39262 .59559 L .39338 .59294 L F
.721 .844 .94 r
.58593 .35587 m .58485 .3586 L .59065 .35559 L F
.308 .071 .383 r
.50571 .50809 m .50538 .5105 L .50311 .51143 L F
.355 .128 .425 r
.50538 .5105 m .50274 .51382 L .50311 .51143 L F
0 0 0 r
.67669 .37779 m .67993 .37608 L .67887 .3768 L F
.67993 .37608 m .68149 .37596 L .67887 .3768 L F
.67993 .37608 m .68272 .3754 L .68149 .37596 L F
.89 .636 .548 r
.45492 .49781 m .45698 .4986 L .45484 .49505 L F
.789 .815 .873 r
.45199 .49966 m .45698 .4986 L .45492 .49781 L F
.937 .855 .422 r
.7051 .34149 m .70573 .33928 L .70474 .34043 L F
.854 .937 .564 r
.70649 .33628 m .70573 .33928 L .70763 .33543 L F
.823 .889 .464 r
.70474 .34043 m .70573 .33928 L .70649 .33628 L F
.718 .864 .95 r
.33819 .57707 m .34158 .5768 L .34074 .57476 L F
.381 .415 .771 r
.34158 .5768 m .34441 .57906 L .34438 .57616 L F
.551 .8 .991 r
.30164 .66008 m .30565 .66057 L .30398 .65932 L F
.544 .75 .972 r
.30565 .66057 m .30647 .65855 L .30398 .65932 L F
.30565 .66057 m .30814 .65996 L .30647 .65855 L F
.693 .175 0 r
.38345 .50992 m .37902 .50766 L .38112 .50798 L F
.491 .854 .611 r
.64332 .39948 m .64152 .40106 L .64338 .39954 L F
0 0 0 r
.6402 .40225 m .64152 .40106 L .64332 .39948 L F
.167 0 0 r
.26841 .51568 m .27292 .51418 L .27075 .51543 L F
.775 .954 .632 r
.3294 .59426 m .3292 .59564 L .33224 .59838 L F
0 .102 .612 r
.33279 .59913 m .33224 .59838 L .3292 .59564 L F
.787 .715 .784 r
.54128 .46919 m .53866 .47248 L .53724 .46865 L F
0 0 0 r
.67315 .38001 m .67669 .37779 L .67577 .3791 L F
.67577 .3791 m .67669 .37779 L .67887 .3768 L F
.63 .725 .916 r
.70018 .29904 m .704 .30035 L .70268 .29623 L F
.475 0 0 r
.70602 .29959 m .70465 .29878 L .70384 .29845 L F
0 0 .572 r
.70268 .29623 m .70332 .29823 L .70384 .29845 L F
.584 .862 .532 r
.70268 .29623 m .70173 .29707 L .70018 .29904 L F
.888 .46 .102 r
.70384 .29845 m .70173 .29707 L .70268 .29623 L F
.475 0 0 r
.70465 .29878 m .70173 .29707 L .70384 .29845 L F
0 0 .572 r
.70332 .29823 m .704 .30035 L .70384 .29845 L F
.35 .163 .481 r
.70654 .30113 m .704 .30035 L .70679 .29973 L F
.70654 .30113 m .70679 .29973 L .7068 .29973 L F
.902 .664 .156 r
.70654 .30113 m .70688 .30447 L .70642 .30183 L F
.35 .163 .481 r
.704 .30035 m .70654 .30113 L .70602 .29959 L F
.704 .30035 m .7041 .30273 L .70654 .30113 L F
.70654 .30113 m .7041 .30273 L .704 .30035 L F
.902 .664 .156 r
.70654 .30113 m .70642 .30183 L .70602 .29959 L F
.77 .952 .627 r
.60426 .38398 m .60637 .38132 L .60482 .38234 L F
.705 .497 .604 r
.60426 .38398 m .60678 .38457 L .60637 .38132 L F
0 0 0 r
.60821 .37959 m .60637 .38132 L .60925 .37811 L F
.514 .866 .617 r
.60482 .38234 m .60637 .38132 L .60821 .37959 L F
.723 .315 .274 r
.61208 .38557 m .60637 .38132 L .60678 .38457 L F
.48 .619 .911 r
.43393 .4913 m .43323 .49263 L .43017 .48907 L F
.648 .828 .969 r
.42931 .49143 m .43323 .49263 L .43393 .4913 L F
.481 .329 .597 r
.42738 .50475 m .43016 .50746 L .42996 .50465 L F
.815 .541 .523 r
.34587 .56931 m .34044 .56601 L .34566 .5667 L F
.739 .274 .143 r
.38902 .51466 m .38742 .51611 L .38678 .51464 L F
.951 .623 .367 r
.38938 .51712 m .38742 .51611 L .38902 .51466 L F
.383 .588 .924 r
.6105 .43135 m .61135 .43333 L .61255 .43132 L F
.488 .722 .975 r
.61135 .43333 m .6141 .43294 L .61255 .43132 L F
0 0 .336 r
.23859 .55118 m .23728 .55299 L .23748 .5504 L F
.903 .571 .408 r
.37861 .53555 m .38089 .53388 L .37861 .53302 L F
.37861 .53555 m .38156 .53855 L .38089 .53388 L F
.7 .183 0 r
.33888 .4968 m .34303 .4979 L .34056 .49613 L F
0 .348 .711 r
.34483 .49802 m .34056 .49613 L .34303 .4979 L F
.964 .727 .286 r
.40682 .55696 m .406 .5584 L .40543 .55579 L F
.40682 .55696 m .40686 .55987 L .406 .5584 L F
.296 .738 .964 r
.3753 .55982 m .37314 .55888 L .3707 .55897 L F
.794 .68 .738 r
.3753 .55982 m .3707 .55897 L .37314 .55888 L F
.3753 .55982 m .37185 .56328 L .3707 .55897 L F
.015 0 0 r
.54253 .44354 m .53861 .44584 L .54086 .4445 L F
.089 0 .447 r
.22518 .5539 m .2265 .55545 L .22603 .55277 L F
.22518 .5539 m .22542 .55666 L .2265 .55545 L F
.647 .905 .982 r
.45049 .44672 m .45168 .44567 L .45206 .44672 L F
.718 .971 .93 r
.45206 .44672 m .45294 .44468 L .45398 .44526 L F
.644 .903 .983 r
.45168 .44567 m .45294 .44468 L .45206 .44672 L F
.594 .926 .963 r
.59552 .35269 m .59426 .3543 L .59677 .35356 L F
.59552 .35269 m .59285 .3539 L .59426 .3543 L F
.816 .996 .765 r
.43085 .57767 m .432 .57766 L .43083 .57937 L F
0 0 .1 r
.43054 .58178 m .43085 .57767 L .43083 .57937 L F
.69 .841 .955 r
.47128 .48387 m .47351 .48492 L .47218 .48143 L F
.658 .671 .851 r
.47218 .48143 m .47351 .48492 L .47616 .48398 L F
.882 .936 .848 r
.40851 .46371 m .40762 .46553 L .40636 .46409 L F
.788 .801 .863 r
.41067 .46223 m .40762 .46553 L .40851 .46371 L F
.81 .932 .913 r
.62993 .39703 m .62704 .39809 L .62963 .39689 L F
.623 .959 .831 r
.63174 .39509 m .62993 .39703 L .62963 .39689 L F
0 0 0 r
.64713 .3855 m .64658 .38566 L .64606 .38713 L F
.261 .75 .657 r
.64818 .38494 m .64564 .38594 L .64658 .38566 L F
.89 .943 .84 r
.65091 .38184 m .64818 .38494 L .64717 .38327 L F
.995 .861 .532 r
.64717 .38327 m .64818 .38494 L .64658 .38566 L F
.611 .628 .843 r
.64395 .38398 m .63984 .38194 L .6432 .38407 L F
.189 .719 .74 r
.64717 .38327 m .64395 .38398 L .6432 .38407 L F
.247 0 0 r
.64626 .38444 m .64395 .38398 L .64717 .38327 L F
.64514 .38589 m .64425 .38446 L .64626 .38444 L F
.64425 .38446 m .64395 .38398 L .64626 .38444 L F
.64704 .38452 m .64717 .38327 L .64737 .38428 L F
.64635 .38433 m .64717 .38327 L .64704 .38452 L F
.89 .943 .84 r
.65091 .38184 m .64717 .38327 L .64886 .38269 L F
.819 .91 .902 r
.64735 .38069 m .64886 .38269 L .64717 .38327 L F
.189 .719 .74 r
.64717 .38327 m .6432 .38407 L .64665 .38421 L F
.819 .91 .902 r
.6469 .38296 m .64717 .38327 L .64665 .38421 L F
.64735 .38069 m .64728 .38178 L .6469 .38296 L F
.64728 .38178 m .64717 .38327 L .6469 .38296 L F
.542 .616 .876 r
.64338 .38353 m .64575 .38417 L .6432 .38407 L F
.64419 .38117 m .64575 .38417 L .64338 .38353 L F
.247 0 0 r
.64514 .38589 m .64635 .38433 L .64704 .38452 L F
.64514 .38589 m .64737 .38428 L .64716 .38521 L F
.836 .613 .601 r
.64514 .38589 m .64606 .38558 L .64419 .38117 L F
.346 .52 .885 r
.64753 .38508 m .64658 .38566 L .6473 .38485 L F
.247 0 0 r
.64716 .38521 m .64737 .38428 L .64753 .38508 L F
.315 .48 .864 r
.64698 .38444 m .64753 .38508 L .64789 .38443 L F
.346 .52 .885 r
.64753 .38508 m .6473 .38485 L .64822 .38382 L F
.836 .613 .601 r
.64742 .38496 m .64753 .38508 L .64742 .38495 L F
0 0 0 r
.64822 .38382 m .64689 .38586 L .64595 .38752 L F
.64689 .38586 m .64606 .38713 L .64598 .38742 L F
.64689 .38586 m .64598 .38742 L .64595 .38752 L F
.836 .613 .601 r
.64655 .38406 m .64742 .38496 L .64658 .38396 L F
.64742 .38496 m .64742 .38495 L .64658 .38396 L F
.64606 .38558 m .64753 .38508 L .64655 .38406 L F
.542 .616 .876 r
.64419 .38117 m .64665 .38421 L .64575 .38417 L F
.836 .613 .601 r
.64606 .38558 m .64658 .38396 L .64419 .38117 L F
.736 .676 .792 r
.64735 .38069 m .64665 .38421 L .64419 .38117 L F
.315 .48 .864 r
.64673 .38284 m .64698 .38444 L .64822 .38382 L F
.64419 .38117 m .64822 .38382 L .64735 .38069 L F
.329 .794 .684 r
.65331 .38072 m .65091 .38184 L .64886 .38269 L F
.65331 .38072 m .64886 .38269 L .65157 .38111 L F
.547 .798 .992 r
.65157 .38111 m .64886 .38269 L .64735 .38069 L F
.65157 .38111 m .64735 .38069 L .65076 .38074 L F
.529 .332 .558 r
.64822 .38382 m .65076 .38074 L .64735 .38069 L F
.694 .56 .699 r
.64995 .38079 m .65076 .38074 L .64822 .38382 L F
.933 .968 .741 r
.64995 .38079 m .64822 .38382 L .64706 .38383 L F
.64968 .38234 m .64706 .38383 L .64977 .38247 L F
.64827 .38255 m .64706 .38383 L .64979 .38227 L F
.315 .48 .864 r
.64577 .38301 m .64698 .38444 L .64673 .38284 L F
.528 .921 .888 r
.64977 .38247 m .64706 .38383 L .64567 .38361 L F
.64977 .38247 m .64567 .38361 L .64798 .38257 L F
.22 0 0 r
.65075 .38388 m .64977 .38247 L .64798 .38257 L F
.65108 .38404 m .64977 .38247 L .65075 .38388 L F
.933 .968 .741 r
.64979 .38227 m .64968 .38234 L .64977 .38247 L F
.64995 .38079 m .64827 .38255 L .64979 .38227 L F
.315 .48 .864 r
.64419 .38117 m .64577 .38301 L .64673 .38284 L F
.64698 .38444 m .64789 .38443 L .64822 .38382 L F
0 0 0 r
.64822 .38382 m .64722 .38494 L .64713 .3855 L F
.64722 .38494 m .64658 .38566 L .64709 .38551 L F
.64722 .38494 m .64709 .38551 L .64713 .3855 L F
.261 .75 .657 r
.64564 .38594 m .64455 .38638 L .64658 .38566 L F
0 0 0 r
.64658 .38566 m .64455 .38638 L .64385 .38822 L F
.488 .499 .795 r
.5536 .4011 m .55446 .40397 L .55701 .4031 L F
.552 .564 .82 r
.55556 .40434 m .55749 .40499 L .55701 .4031 L F
.431 0 0 r
.55749 .40499 m .55687 .40551 L .55701 .4031 L F
.073 0 .296 r
.55762 .40258 m .55701 .4031 L .55687 .40551 L F
.475 .283 .54 r
.55655 .40071 m .55701 .4031 L .55923 .40006 L F
.737 .632 .742 r
.55923 .40006 m .55701 .4031 L .55795 .4013 L F
.073 0 .296 r
.55795 .4013 m .55701 .4031 L .55762 .40258 L F
.552 .564 .82 r
.55446 .40397 m .55556 .40434 L .55701 .4031 L F
.995 .768 .476 r
.4251 .54628 m .42553 .54965 L .42634 .54801 L F
.651 .265 .3 r
.42634 .54801 m .42871 .54953 L .42553 .54965 L F
.995 .768 .476 r
.4251 .54628 m .42553 .54965 L .42634 .54801 L F
.612 .321 .451 r
.42888 .54752 m .42871 .54953 L .42634 .54801 L F
.176 .695 .884 r
.63967 .35083 m .63609 .35102 L .6358 .35051 L F
.446 .315 .609 r
.63967 .35083 m .63723 .35206 L .63609 .35102 L F
.477 .074 .196 r
.44714 .47705 m .45113 .47508 L .45009 .47485 L F
.998 .79 .487 r
.67638 .36133 m .67556 .35802 L .6731 .35914 L F
0 0 .118 r
.67855 .35713 m .67638 .36133 L .67846 .35983 L F
0 0 .114 r
.32612 .49818 m .32603 .50152 L .32643 .49948 L F
.477 .818 .527 r
.32612 .49818 m .3281 .49638 L .32997 .4947 L F
0 0 .041 r
.32612 .49818 m .32643 .49948 L .3281 .49638 L F
.779 .737 .814 r
.42076 .59491 m .42306 .59644 L .4205 .59638 L F
.705 .3 .279 r
.4205 .59638 m .42306 .59644 L .42284 .59763 L F
0 0 0 r
.42531 .59685 m .42284 .59763 L .42306 .59644 L F
.984 .743 .346 r
.40928 .58943 m .40816 .58836 L .40814 .58523 L F
.992 .739 .403 r
.4094 .59198 m .40816 .58836 L .40928 .58943 L F
.981 .688 .36 r
.57383 .43312 m .57413 .43611 L .57264 .4347 L F
.931 .808 .702 r
.57293 .4292 m .57383 .43312 L .57365 .43251 L F
.853 .893 .469 r
.57365 .43251 m .57383 .43312 L .57264 .4347 L F
.981 .688 .36 r
.57383 .43312 m .57413 .43611 L .57264 .4347 L F
.638 .877 .526 r
.24359 .53574 m .24201 .53783 L .24462 .53456 L F
0 0 .104 r
.24547 .53339 m .24462 .53456 L .24632 .53072 L F
0 0 0 r
.24589 .53342 m .24462 .53456 L .24547 .53339 L F
.24589 .53342 m .24359 .53574 L .24462 .53456 L F
.913 .522 .25 r
.3836 .54312 m .38617 .54627 L .38581 .54378 L F
.983 .697 .375 r
.5979 .40097 m .59658 .40223 L .59642 .3997 L F
.5979 .40097 m .598 .40345 L .59658 .40223 L F
.062 0 0 r
.57442 .45602 m .57815 .45279 L .5773 .45533 L F
.235 0 .018 r
.58565 .45156 m .58365 .45178 L .58635 .45098 L F
.445 .777 .998 r
.5805 .45263 m .584 .45238 L .58267 .45218 L F
.679 .739 .896 r
.57651 .45123 m .584 .45238 L .58365 .45178 L F
.235 0 .018 r
.58289 .45384 m .58358 .45199 L .58565 .45156 L F
.58358 .45199 m .58365 .45178 L .58565 .45156 L F
.445 .777 .998 r
.57815 .45279 m .5805 .45263 L .57651 .45123 L F
.5805 .45263 m .58267 .45218 L .57651 .45123 L F
.977 .684 .306 r
.5773 .45533 m .57815 .45279 L .57651 .45123 L F
.446 .836 .983 r
.61545 .40685 m .61953 .40699 L .61797 .4048 L F
.944 .848 .717 r
.61797 .4048 m .61953 .40699 L .61765 .41046 L F
.342 .62 .954 r
.6204 .40511 m .61953 .40699 L .61864 .40574 L F
.6204 .40511 m .61953 .40699 L .61797 .4048 L F
0 0 0 r
.62198 .40454 m .6204 .40511 L .61906 .40649 L F
.62306 .40383 m .6204 .40511 L .62198 .40454 L F
.342 .62 .954 r
.6204 .40511 m .61864 .40574 L .61797 .4048 L F
.252 .154 .544 r
.44925 .46867 m .45062 .46523 L .44866 .46606 L F
.826 .682 .704 r
.43254 .54696 m .42871 .54953 L .42888 .54752 L F
.43254 .54696 m .43179 .55045 L .42871 .54953 L F
0 0 .529 r
.43271 .54589 m .43569 .54933 L .43254 .54696 L F
.503 .364 .624 r
.43254 .54696 m .43569 .54933 L .43179 .55045 L F
.297 .775 .678 r
.30735 .64972 m .31009 .64866 L .30649 .65016 L F
.515 .905 .763 r
.31087 .64789 m .31009 .64866 L .30922 .649 L F
.31068 .64799 m .30922 .649 L .30735 .64972 L F
.31087 .64789 m .30922 .649 L .31068 .64799 L F
.882 .729 .687 r
.30945 .64632 m .31084 .64788 L .30758 .64661 L F
.515 .905 .763 r
.31153 .64764 m .31009 .64866 L .31087 .64789 L F
.31198 .64732 m .31153 .64764 L .31087 .64789 L F
.31198 .64732 m .30735 .64972 L .31041 .64862 L F
.882 .729 .687 r
.31084 .64788 m .31095 .64801 L .31076 .64793 L F
.31084 .64788 m .31076 .64793 L .30758 .64661 L F
0 0 0 r
.31095 .64801 m .31041 .64862 L .30999 .64916 L F
.738 .265 .126 r
.30935 .64849 m .31095 .64801 L .30999 .64916 L F
.30758 .64661 m .31076 .64793 L .30935 .64849 L F
.31076 .64793 m .31095 .64801 L .30935 .64849 L F
.753 .715 .817 r
.5905 .45169 m .59244 .45553 L .59395 .45229 L F
.429 0 .115 r
.43901 .50046 m .44164 .50028 L .44303 .49832 L F
.869 .765 .745 r
.44164 .50028 m .44582 .49816 L .44303 .49832 L F
0 0 0 r
.33042 .60067 m .33169 .60071 L .33279 .59913 L F
.826 .755 .785 r
.3413 .64104 m .34272 .6446 L .33939 .64446 L F
.748 .337 .272 r
.33939 .64446 m .34272 .6446 L .3405 .64684 L F
.972 .826 .413 r
.33279 .59913 m .33169 .60071 L .33224 .59838 L F
.501 .337 .591 r
.34554 .64125 m .34272 .6446 L .3413 .64104 L F
.34554 .64125 m .34519 .64407 L .34272 .6446 L F
.462 .228 .472 r
.34272 .6446 m .34464 .64645 L .3405 .64684 L F
.34272 .6446 m .34519 .64407 L .34464 .64645 L F
.786 .942 .928 r
.30649 .65016 m .30249 .65125 L .30485 .65021 L F
.721 .343 .332 r
.2845 .51007 m .28855 .50978 L .28618 .51081 L F
.2845 .51007 m .28855 .50978 L .28618 .51081 L F
.795 .997 .786 r
.62308 .39117 m .62293 .39288 L .62102 .39329 L F
.445 .527 .848 r
.36739 .62673 m .36602 .62923 L .36489 .6274 L F
.638 .408 .553 r
.4332 .52914 m .43561 .52766 L .43097 .52738 L F
.4332 .52914 m .43554 .53033 L .43561 .52766 L F
.785 .532 .554 r
.43554 .53033 m .43623 .53213 L .43561 .52766 L F
.786 .532 .554 r
.43561 .52766 m .43964 .53086 L .43834 .52705 L F
.43561 .52766 m .43623 .53213 L .43964 .53086 L F
.391 0 .043 r
.3079 .56894 m .31188 .56698 L .30864 .56707 L F
.904 .981 .713 r
.37596 .62312 m .37604 .62548 L .37828 .62178 L F
.867 .991 .824 r
.373 .6263 m .37604 .62548 L .37596 .62312 L F
.612 .774 .958 r
.47759 .49115 m .47912 .49246 L .48158 .49179 L F
.566 .572 .818 r
.47912 .49246 m .48193 .49411 L .48158 .49179 L F
.498 .675 .944 r
.41022 .59677 m .41271 .59627 L .411 .5941 L F
.345 .113 .412 r
.50835 .50479 m .50804 .50722 L .50571 .50809 L F
.39 .139 .408 r
.50782 .50972 m .50571 .50809 L .50804 .50722 L F
.50782 .50972 m .50538 .5105 L .50571 .50809 L F
.291 .119 .467 r
.33015 .62968 m .32888 .63399 L .32979 .63163 L F
.477 .284 .539 r
.33015 .62968 m .32979 .63163 L .32964 .62793 L F
.186 .716 .733 r
.42408 .45357 m .42537 .45335 L .4197 .45459 L F
.237 .74 .679 r
.63713 .38198 m .63324 .38328 L .636 .38275 L F
.141 0 0 r
.63909 .38234 m .63713 .38198 L .636 .38275 L F
.63909 .38234 m .63984 .38194 L .63713 .38198 L F
.904 .981 .713 r
.37596 .62312 m .37828 .62178 L .37725 .62168 L F
.643 .959 .778 r
.37828 .62178 m .38153 .61924 L .37923 .62031 L F
.613 .955 .898 r
.37725 .62168 m .37828 .62178 L .37923 .62031 L F
.602 .402 .584 r
.32376 .57332 m .32556 .57631 L .32067 .57648 L F
.55 .386 .612 r
.32628 .56958 m .32679 .57397 L .32376 .57332 L F
.642 .415 .559 r
.32693 .57554 m .32376 .57332 L .32679 .57397 L F
.32693 .57554 m .32556 .57631 L .32376 .57332 L F
.739 .6 .702 r
.37411 .68261 m .37757 .68304 L .37757 .68046 L F
.636 .516 .699 r
.37757 .68046 m .37757 .68304 L .38044 .67997 L F
0 0 .232 r
.47591 .58342 m .47696 .57881 L .47697 .58166 L F
0 0 0 r
.4748 .58569 m .47591 .58342 L .47697 .58166 L F
.765 .684 .773 r
.73997 .29627 m .74125 .30025 L .73734 .29956 L F
0 0 .237 r
.73997 .29627 m .74072 .29853 L .74125 .30025 L F
.93 .571 .151 r
.74054 .30141 m .74125 .30025 L .74072 .29853 L F
.74054 .30141 m .74196 .30295 L .74125 .30025 L F
0 0 0 r
.49004 .42316 m .48741 .42403 L .48575 .42491 L F
.696 .708 .857 r
.41361 .45836 m .40932 .45617 L .41177 .45508 L F
.746 .746 .852 r
.41589 .45562 m .41361 .45836 L .41177 .45508 L F
.402 .253 .562 r
.3747 .60672 m .37131 .60562 L .37384 .60393 L F
.3747 .60672 m .37151 .60838 L .37131 .60562 L F
0 0 .314 r
.59278 .34793 m .59243 .34911 L .59127 .35004 L F
.855 .997 .811 r
.59291 .34873 m .5904 .35074 L .59127 .35004 L F
.59291 .34873 m .58838 .3529 L .58937 .35157 L F
.104 0 0 r
.59127 .35004 m .59573 .34878 L .59291 .34873 L F
.59127 .35004 m .59207 .35028 L .59573 .34878 L F
0 0 .314 r
.59243 .34911 m .59207 .35028 L .59127 .35004 L F
.855 .997 .811 r
.5904 .35074 m .58937 .35157 L .59127 .35004 L F
.402 0 0 r
.59291 .34873 m .59573 .34878 L .59607 .34865 L F
.329 0 .128 r
.54407 .48208 m .54575 .48386 L .54306 .48445 L F
.54407 .48208 m .54671 .48148 L .54575 .48386 L F
.36 .832 .828 r
.63062 .33808 m .63272 .33706 L .63414 .33673 L F
.63062 .33808 m .63008 .33797 L .63272 .33706 L F
.682 .923 .972 r
.62915 .34645 m .63275 .3458 L .63192 .34535 L F
.588 .933 .948 r
.63448 .34408 m .63275 .3458 L .6354 .3449 L F
.63448 .34408 m .63192 .34535 L .63275 .3458 L F
.966 .777 .597 r
.40773 .57861 m .40957 .57958 L .40869 .58201 L F
.364 .635 .958 r
.32172 .53559 m .32265 .53732 L .31987 .53578 L F
.418 .223 .506 r
.32248 .53759 m .31987 .53578 L .32265 .53732 L F
.32009 .5363 m .31987 .53578 L .32248 .53759 L F
0 0 0 r
.31987 .53578 m .3163 .53763 L .31836 .53646 L F
.364 .635 .958 r
.31904 .53628 m .31987 .53578 L .31836 .53646 L F
.562 .362 .567 r
.31904 .53628 m .31596 .54052 L .31626 .53796 L F
.31987 .53578 m .31932 .53645 L .31904 .53628 L F
.31932 .53645 m .31596 .54052 L .31904 .53628 L F
.31987 .53578 m .31858 .54035 L .31596 .54052 L F
.781 .939 .931 r
.31904 .53628 m .31869 .53555 L .31973 .53611 L F
.31836 .53646 m .31853 .53599 L .31904 .53628 L F
.31853 .53599 m .31869 .53555 L .31904 .53628 L F
.418 .223 .506 r
.32137 .53935 m .31858 .54035 L .31987 .53578 L F
.364 .635 .958 r
.32172 .53559 m .31987 .53578 L .31904 .53628 L F
.562 .362 .567 r
.31987 .53578 m .31626 .53796 L .3163 .53763 L F
.781 .939 .931 r
.31973 .53611 m .31957 .53316 L .32172 .53559 L F
.31869 .53555 m .31957 .53316 L .31973 .53611 L F
.418 .223 .506 r
.32137 .53935 m .32009 .5363 L .32248 .53759 L F
.996 .797 .437 r
.32172 .53559 m .32137 .53935 L .32265 .53732 L F
.724 .753 .875 r
.56438 .40758 m .56838 .40744 L .56653 .40428 L F
0 0 0 r
.56657 .40886 m .56677 .40839 L .56525 .41054 L F
.335 0 0 r
.56677 .40839 m .56838 .40744 L .56716 .40748 L F
.348 .553 .91 r
.56653 .40428 m .56838 .40744 L .56942 .40527 L F
.75 .96 .665 r
.56942 .40527 m .56838 .40744 L .56677 .40839 L F
0 0 0 r
.56827 .40668 m .56677 .40839 L .56657 .40886 L F
.335 0 0 r
.56677 .40839 m .56716 .40748 L .56438 .40758 L F
.811 .822 .859 r
.30403 .63808 m .3064 .63587 L .30485 .63375 L F
.864 .805 .791 r
.38317 .4739 m .38718 .47767 L .38983 .47191 L F
.393 .201 .498 r
.38431 .47863 m .3825 .48131 L .38229 .48055 L F
.06 .385 .847 r
.38317 .47985 m .38431 .47863 L .38229 .48055 L F
.933 .773 .66 r
.38609 .47963 m .38642 .47695 L .38525 .47799 L F
.314 .488 .871 r
.38431 .47863 m .38609 .47963 L .38317 .4739 L F
.933 .773 .66 r
.38609 .47963 m .38718 .47767 L .38642 .47695 L F
.06 .385 .847 r
.38571 .47783 m .38732 .4805 L .38431 .47863 L F
.38571 .47783 m .38494 .47827 L .38317 .47985 L F
.38494 .47827 m .38431 .47863 L .38317 .47985 L F
.933 .773 .66 r
.38525 .47799 m .38642 .47695 L .38317 .4739 L F
.484 .524 .823 r
.24369 .59835 m .24183 .59939 L .24039 .59729 L F
.325 .081 .382 r
.24342 .60113 m .24183 .59939 L .24369 .59835 L F
.24342 .60113 m .24108 .60214 L .24183 .59939 L F
.896 .483 .195 r
.3945 .52435 m .39332 .52578 L .39272 .52325 L F
.3945 .52435 m .39575 .52714 L .39332 .52578 L F
0 .053 .591 r
.3825 .48131 m .38465 .48349 L .38229 .48055 L F
.937 .907 .766 r
.32727 .64094 m .32369 .64277 L .32627 .6435 L F
.32727 .64094 m .32627 .6435 L .3265 .63987 L F
.785 .79 .857 r
.42691 .48009 m .42777 .48314 L .42419 .48118 L F
.824 .777 .808 r
.42419 .48118 m .42777 .48314 L .42617 .48286 L F
.817 .807 .842 r
.43081 .47822 m .42777 .48314 L .42691 .48009 L F
.989 .726 .379 r
.39257 .56543 m .39393 .56946 L .39466 .56693 L F
.519 .238 .428 r
.53215 .488 m .5312 .4914 L .52845 .49172 L F
.526 .245 .431 r
.53401 .48973 m .53215 .488 L .53485 .48786 L F
.53401 .48973 m .5312 .4914 L .53215 .488 L F
.657 .259 .28 r
.31513 .57865 m .31325 .58118 L .31099 .57905 L F
.384 0 0 r
.31513 .57865 m .31489 .57978 L .31325 .58118 L F
.31513 .57865 m .31768 .57909 L .31489 .57978 L F
.062 0 0 r
.57442 .45602 m .5773 .45533 L .57407 .45375 L F
.871 .989 .727 r
.67961 .35004 m .6814 .3494 L .68006 .35071 L F
.746 .984 .76 r
.6827 .34698 m .6814 .3494 L .67961 .35004 L F
.286 .282 .68 r
.31986 .61586 m .31991 .61844 L .3188 .61407 L F
0 0 0 r
.24252 .53847 m .24201 .53783 L .24359 .53574 L F
.24252 .53847 m .23949 .5416 L .24201 .53783 L F
.778 .795 .867 r
.71055 .30513 m .70871 .30653 L .70688 .30447 L F
0 0 0 r
.7054 .30683 m .70633 .30535 L .70872 .30654 L F
.7054 .30683 m .70872 .30654 L .70931 .30719 L F
.70633 .30535 m .70635 .30532 L .70954 .30693 L F
.70633 .30535 m .70954 .30693 L .71021 .30727 L F
.736 .689 .805 r
.71248 .30641 m .70954 .30693 L .71055 .30513 L F
.70954 .30693 m .70871 .30653 L .71055 .30513 L F
.696 .553 .688 r
.71248 .30641 m .71021 .30727 L .70954 .30693 L F
0 0 0 r
.70635 .30532 m .70688 .30447 L .71021 .30727 L F
.778 .795 .867 r
.70871 .30653 m .70776 .30725 L .70688 .30447 L F
0 0 0 r
.70931 .30719 m .70872 .30654 L .71021 .30727 L F
.736 .689 .805 r
.70954 .30693 m .70776 .30725 L .70871 .30653 L F
.696 .553 .688 r
.70954 .30693 m .71021 .30727 L .70776 .30725 L F
0 0 0 r
.7054 .30683 m .70608 .30661 L .70688 .30447 L F
.7054 .30683 m .70522 .3081 L .70608 .30661 L F
.204 0 .087 r
.28814 .53571 m .29004 .53586 L .29082 .53471 L F
.28814 .53571 m .28776 .53671 L .29004 .53586 L F
.612 .448 .636 r
.33246 .51375 m .33401 .51557 L .33476 .51273 L F
.936 .678 .203 r
.33317 .51387 m .33401 .51557 L .33246 .51375 L F
.33317 .51387 m .33246 .51375 L .33032 .51658 L F
.623 .932 .967 r
.61109 .41717 m .61404 .41594 L .61268 .41508 L F
0 0 .223 r
.61187 .41753 m .61109 .41717 L .61268 .41508 L F
.61187 .41753 m .61125 .4197 L .61109 .41717 L F
.691 .682 .837 r
.61506 .39402 m .61349 .39725 L .61146 .39564 L F
.61506 .39402 m .61627 .39639 L .61349 .39725 L F
0 0 0 r
.61506 .39402 m .61349 .39725 L .61627 .39639 L F
.886 .78 .739 r
.60599 .34694 m .60091 .34606 L .6035 .34592 L F
.60599 .34694 m .60167 .34757 L .60091 .34606 L F
.503 .884 .968 r
.60599 .34694 m .60614 .34501 L .60701 .34525 L F
.60599 .34694 m .6035 .34592 L .60614 .34501 L F
1 .818 .503 r
.40897 .57347 m .40732 .57508 L .40792 .57228 L F
.40897 .57347 m .40843 .57592 L .40732 .57508 L F
.835 .605 .59 r
.72321 .32296 m .72323 .3257 L .72124 .3219 L F
.948 .605 .204 r
.35286 .52383 m .35139 .52302 L .35031 .51856 L F
.638 .491 .667 r
.35286 .52383 m .35606 .52041 L .35362 .52161 L F
.651 .943 .96 r
.35363 .5217 m .35286 .52383 L .35362 .52161 L F
.35363 .5217 m .35139 .52302 L .35286 .52383 L F
.638 .491 .667 r
.35286 .52383 m .35667 .52442 L .35606 .52041 L F
.506 .175 .34 r
.35298 .52684 m .35667 .52442 L .35286 .52383 L F
.794 .676 .734 r
.44408 .45997 m .44817 .46232 L .44484 .45914 L F
.44408 .45997 m .44559 .46276 L .44817 .46232 L F
.518 .817 .999 r
.4437 .46436 m .44817 .46232 L .44559 .46276 L F
.4437 .46436 m .44535 .46557 L .44817 .46232 L F
.569 .754 .965 r
.44817 .46232 m .44729 .45863 L .44484 .45914 L F
.44817 .46232 m .45212 .46208 L .45101 .46129 L F
.44829 .46202 m .45101 .46129 L .44908 .45991 L F
.44817 .46232 m .45101 .46129 L .44829 .46202 L F
.591 .76 .959 r
.45212 .46208 m .45332 .46065 L .44729 .45863 L F
.252 .125 .506 r
.45383 .46467 m .45589 .46027 L .45332 .46065 L F
.127 0 0 r
.45327 .46069 m .454 .46163 L .45144 .4623 L F
.45332 .46065 m .45333 .46067 L .45327 .46069 L F
.45333 .46067 m .454 .46163 L .45327 .46069 L F
.632 .141 .066 r
.45324 .46068 m .45144 .4623 L .44994 .46208 L F
.569 .754 .965 r
.44817 .46232 m .44908 .45991 L .44753 .45962 L F
.44753 .45962 m .44908 .45991 L .44729 .45863 L F
.632 .141 .066 r
.45332 .46065 m .44994 .46208 L .44729 .45863 L F
.302 .164 .522 r
.44729 .45863 m .44865 .46142 L .44839 .46162 L F
.44719 .45901 m .44839 .46162 L .44585 .46358 L F
.44729 .45863 m .44839 .46162 L .44719 .45901 L F
.358 .311 .668 r
.44585 .46358 m .44882 .46254 L .44853 .46622 L F
.716 .347 .35 r
.44909 .46284 m .45144 .4623 L .4486 .46207 L F
.316 0 .045 r
.45284 .46626 m .45383 .46467 L .45062 .46523 L F
.856 .723 .716 r
.44952 .46281 m .44962 .46291 L .44908 .46284 L F
.44962 .46291 m .45284 .46626 L .44923 .46297 L F
.44962 .46291 m .44923 .46297 L .44908 .46284 L F
.252 .154 .544 r
.44925 .46867 m .45163 .46682 L .45062 .46523 L F
.316 0 .045 r
.45284 .46626 m .45062 .46523 L .45163 .46682 L F
.856 .723 .716 r
.44908 .46284 m .45284 .46626 L .44853 .46622 L F
.44952 .46281 m .45144 .4623 L .45284 .46626 L F
.716 .347 .35 r
.44952 .46281 m .45144 .4623 L .44909 .46284 L F
.856 .723 .716 r
.44914 .46242 m .45144 .4623 L .44952 .46281 L F
.716 .347 .35 r
.44956 .46281 m .45144 .4623 L .44952 .46281 L F
.831 .842 .855 r
.454 .46163 m .45284 .46626 L .45144 .4623 L F
.252 .125 .506 r
.45488 .46243 m .45606 .46339 L .45589 .46027 L F
.45383 .46467 m .45606 .46339 L .45488 .46243 L F
0 0 0 r
.45284 .46626 m .45606 .46339 L .45383 .46467 L F
.831 .842 .855 r
.45367 .46294 m .45606 .46339 L .45284 .46626 L F
.562 .023 0 r
.4539 .46416 m .45765 .46468 L .45606 .46339 L F
.45765 .46468 m .45794 .46472 L .45606 .46339 L F
.831 .842 .855 r
.454 .46163 m .45511 .46257 L .45367 .46294 L F
.45511 .46257 m .45606 .46339 L .45367 .46294 L F
.494 .316 .568 r
.45075 .4637 m .45179 .46257 L .44953 .46351 L F
.4539 .46416 m .45264 .46321 L .45075 .4637 L F
.45264 .46321 m .45179 .46257 L .45075 .4637 L F
.45179 .46257 m .45144 .4623 L .45077 .46273 L F
.45179 .46257 m .45077 .46273 L .44953 .46351 L F
.716 .347 .35 r
.44914 .46292 m .44956 .46281 L .44909 .46284 L F
.856 .723 .716 r
.44914 .46242 m .44952 .46281 L .44908 .46284 L F
.358 .311 .668 r
.44882 .46254 m .44914 .46242 L .44908 .46284 L F
.44882 .46254 m .44908 .46284 L .44853 .46622 L F
.716 .347 .35 r
.44953 .46351 m .44962 .46346 L .44914 .46292 L F
.44962 .46346 m .45144 .4623 L .44914 .46292 L F
.302 .164 .522 r
.44865 .46142 m .44855 .46263 L .44585 .46358 L F
.716 .347 .35 r
.44911 .46318 m .4486 .46207 L .44761 .46198 L F
.44953 .46351 m .4486 .46207 L .44911 .46318 L F
.762 .56 .624 r
.44787 .46178 m .44861 .46189 L .44845 .46131 L F
.44861 .46189 m .44994 .46208 L .44865 .46142 L F
.44861 .46189 m .44865 .46142 L .44845 .46131 L F
.44761 .46198 m .45144 .4623 L .44787 .46178 L F
.302 .164 .522 r
.44865 .46142 m .44914 .46242 L .44855 .46263 L F
.632 .141 .066 r
.44994 .46208 m .44914 .46242 L .44865 .46142 L F
.44994 .46208 m .44865 .46142 L .44729 .45863 L F
.762 .56 .624 r
.44845 .46131 m .45144 .4623 L .45055 .45963 L F
.44994 .46208 m .45144 .4623 L .44845 .46131 L F
.632 .141 .066 r
.44994 .46208 m .45144 .4623 L .44914 .46242 L F
.45332 .46065 m .45327 .46069 L .45324 .46068 L F
.45327 .46069 m .45144 .4623 L .45324 .46068 L F
.179 0 0 r
.32917 .55811 m .33149 .55775 L .33284 .55624 L F
.019 0 0 r
.33284 .55624 m .33495 .55581 L .33651 .55425 L F
.016 0 0 r
.33284 .55624 m .33389 .55689 L .33495 .55581 L F
.33284 .55624 m .33149 .55775 L .33389 .55689 L F
.027 0 .383 r
.48841 .54222 m .48645 .5465 L .48678 .5439 L F
.509 .356 .609 r
.43964 .53086 m .44232 .52742 L .43834 .52705 L F
.43964 .53086 m .44217 .53023 L .44232 .52742 L F
.44232 .52742 m .44217 .53023 L .43964 .53086 L F
.727 .823 .925 r
.62305 .34974 m .61949 .35133 L .6232 .35151 L F
.802 .687 .737 r
.61949 .35133 m .62069 .35495 L .6232 .35151 L F
.81 .879 .896 r
.6232 .35151 m .62483 .34698 L .62305 .34974 L F
.6232 .35151 m .6262 .34846 L .62483 .34698 L F
.467 .098 .254 r
.45343 .48806 m .4562 .48772 L .45636 .48588 L F
.793 .587 .623 r
.4562 .48772 m .45893 .48526 L .45636 .48588 L F
.979 .748 .518 r
.54189 .42931 m .54342 .43296 L .54134 .43196 L F
.972 .684 .423 r
.54134 .43196 m .54342 .43296 L .54347 .43594 L F
.676 .708 .872 r
.54464 .42869 m .54342 .43296 L .54189 .42931 L F
.54464 .42869 m .54668 .43119 L .54342 .43296 L F
.804 .648 .094 r
.57439 .45763 m .57407 .45375 L .57558 .45817 L F
0 0 0 r
.57268 .46175 m .57439 .45763 L .57558 .45817 L F
.57268 .46175 m .57242 .46183 L .57439 .45763 L F
.138 0 0 r
.70918 .31194 m .70661 .31237 L .70863 .30987 L F
.70918 .31194 m .70505 .31335 L .70661 .31237 L F
.528 0 0 r
.34546 .49914 m .34483 .49802 L .34303 .4979 L F
.34546 .49914 m .34756 .49976 L .34483 .49802 L F
.71 .658 .796 r
.40305 .49128 m .4047 .49564 L .40655 .49248 L F
.659 .972 .864 r
.40158 .49766 m .40399 .49578 L .40351 .49573 L F
.038 .228 .73 r
.40537 .49362 m .40486 .49517 L .40305 .49128 L F
.40486 .49517 m .4047 .49564 L .40449 .49507 L F
.40486 .49517 m .40449 .49507 L .40305 .49128 L F
.695 .944 .96 r
.40537 .49362 m .40347 .49486 L .4047 .49564 L F
.832 .969 .889 r
.4036 .49495 m .40351 .49573 L .4047 .49564 L F
.40347 .49486 m .40347 .49502 L .4036 .49495 L F
.40347 .49502 m .40351 .49573 L .4036 .49495 L F
.23 0 0 r
.40428 .49567 m .40763 .49477 L .4047 .49564 L F
.40427 .49555 m .40763 .49477 L .40428 .49567 L F
.40427 .49555 m .4062 .49552 L .40536 .4953 L F
.40351 .49573 m .40427 .49555 L .40428 .49567 L F
.40351 .49573 m .40431 .49567 L .40427 .49555 L F
.40431 .49567 m .4062 .49552 L .40427 .49555 L F
.40452 .49565 m .40543 .49592 L .4062 .49552 L F
.40351 .49573 m .40417 .49579 L .40452 .49565 L F
.40417 .49579 m .40543 .49592 L .40452 .49565 L F
.659 .972 .864 r
.40399 .49578 m .40428 .49554 L .40351 .49573 L F
.786 .809 .87 r
.40074 .49632 m .39789 .49793 L .40158 .49766 L F
.754 .798 .888 r
.40074 .49632 m .40158 .49766 L .40351 .49573 L F
0 0 0 r
.40149 .49694 m .39925 .49738 L .40428 .49554 L F
.399 .49818 m .39894 .49866 L .39903 .49836 L F
.147 0 0 r
.39894 .49785 m .399 .49818 L .40158 .49766 L F
0 0 0 r
.399 .49818 m .39907 .49797 L .40149 .49694 L F
.39907 .49797 m .39925 .49738 L .40149 .49694 L F
.721 .601 .722 r
.39612 .49388 m .40074 .49632 L .39741 .49202 L F
.617 .306 .421 r
.39741 .49202 m .39958 .49379 L .40305 .49128 L F
.39958 .49379 m .40024 .49434 L .40063 .49391 L F
.39958 .49379 m .40063 .49391 L .40305 .49128 L F
.69 .764 .908 r
.40074 .49632 m .40024 .49434 L .39741 .49202 L F
.754 .798 .888 r
.40314 .49503 m .40347 .49502 L .40347 .49486 L F
.859 .554 .027 r
.40399 .49429 m .40428 .49554 L .40329 .49503 L F
.687 .766 .912 r
.40537 .49362 m .40347 .49486 L .40306 .49479 L F
.859 .554 .027 r
.40205 .49407 m .40207 .49408 L .40129 .49399 L F
.40207 .49408 m .40329 .49503 L .40191 .49431 L F
.40207 .49408 m .40191 .49431 L .40129 .49399 L F
0 0 0 r
.40305 .49128 m .40381 .49204 L .40537 .49362 L F
.687 .766 .912 r
.40537 .49362 m .40207 .49408 L .40242 .49366 L F
.859 .554 .027 r
.40329 .49496 m .40329 .49503 L .40205 .49407 L F
0 0 0 r
.40314 .49503 m .40184 .4943 L .40338 .49507 L F
.40184 .4943 m .40088 .49377 L .40191 .49431 L F
.40184 .4943 m .40191 .49431 L .40338 .49507 L F
.40056 .49409 m .40088 .49377 L .40269 .49477 L F
.69 .764 .908 r
.40074 .49632 m .40314 .49503 L .40024 .49434 L F
0 0 0 r
.40203 .49463 m .40269 .49477 L .40314 .49503 L F
.40184 .49456 m .40269 .49477 L .40203 .49463 L F
.69 .764 .908 r
.40314 .49503 m .40347 .49486 L .40203 .49463 L F
.40314 .49503 m .40203 .49463 L .40024 .49434 L F
0 0 0 r
.40183 .49455 m .40184 .49456 L .40203 .49463 L F
.40056 .49409 m .40269 .49477 L .40183 .49455 L F
.40305 .49128 m .40063 .49391 L .40088 .49376 L F
.40063 .49391 m .40024 .49434 L .40112 .49377 L F
.40117 .4936 m .40112 .49377 L .40321 .49242 L F
.687 .766 .912 r
.40207 .49408 m .40321 .49242 L .40381 .49204 L F
.40537 .49362 m .40306 .49479 L .40207 .49408 L F
0 0 0 r
.40319 .49142 m .40088 .49376 L .40381 .49204 L F
.40305 .49128 m .40088 .49376 L .40319 .49142 L F
.40063 .49391 m .40321 .49242 L .40381 .49204 L F
.859 .554 .027 r
.40301 .49408 m .40129 .49399 L .40048 .49356 L F
.40399 .49429 m .403 .49418 L .40301 .49408 L F
.403 .49418 m .40129 .49399 L .40301 .49408 L F
0 0 0 r
.40063 .49391 m .40112 .49377 L .40117 .4936 L F
.40045 .4942 m .40048 .49356 L .40088 .49377 L F
.57 .803 .987 r
.40042 .49419 m .40024 .49434 L .40023 .49417 L F
.40025 .49415 m .40023 .49417 L .40023 .49414 L F
.40042 .49419 m .40023 .49417 L .40025 .49415 L F
.859 .554 .027 r
.40387 .49376 m .40399 .49429 L .40104 .49368 L F
0 0 .129 r
.40062 .49379 m .40112 .49377 L .40235 .49367 L F
.57 .803 .987 r
.40321 .49242 m .40112 .49377 L .40326 .49199 L F
.40112 .49377 m .40024 .49434 L .40096 .49378 L F
.40112 .49377 m .40096 .49378 L .40326 .49199 L F
0 0 0 r
.40029 .49416 m .40048 .49356 L .40045 .4942 L F
0 0 .094 r
.40033 .49406 m .40046 .49391 L .40048 .49356 L F
0 0 .129 r
.40048 .49356 m .40062 .49379 L .40112 .49375 L F
.859 .554 .027 r
.40117 .4936 m .40104 .49368 L .40048 .49356 L F
0 0 .129 r
.40048 .49356 m .40112 .49375 L .40117 .4936 L F
.57 .803 .987 r
.40326 .49199 m .40096 .49378 L .40016 .49169 L F
.40112 .49377 m .40045 .4942 L .4004 .49379 L F
.859 .554 .027 r
.40387 .49376 m .40104 .49368 L .40117 .4936 L F
0 0 .129 r
.40117 .4936 m .40112 .49375 L .40235 .49367 L F
.687 .766 .912 r
.40095 .49424 m .40045 .4942 L .40321 .49242 L F
.40095 .49424 m .40203 .49463 L .40024 .49434 L F
.40095 .49424 m .40024 .49434 L .40045 .4942 L F
0 0 0 r
.40019 .49446 m .40056 .49409 L .40314 .49503 L F
.754 .798 .888 r
.40074 .49632 m .40332 .49577 L .40329 .4951 L F
.40074 .49632 m .40347 .49502 L .40314 .49503 L F
.721 .601 .722 r
.39612 .49388 m .39789 .49793 L .40074 .49632 L F
0 0 0 r
.39925 .49738 m .39997 .49516 L .40338 .49507 L F
.39997 .49516 m .40019 .49446 L .40317 .49503 L F
.39997 .49516 m .40317 .49503 L .40338 .49507 L F
.754 .798 .888 r
.40329 .4951 m .40351 .49573 L .40347 .49502 L F
.40332 .49577 m .40351 .49573 L .40329 .4951 L F
0 0 0 r
.39925 .49738 m .40338 .49507 L .40428 .49554 L F
.659 .972 .864 r
.40158 .49766 m .40147 .49769 L .40428 .49554 L F
.40147 .49769 m .399 .49818 L .40428 .49554 L F
.23 0 0 r
.40351 .49573 m .40438 .49584 L .40437 .49581 L F
.816 .466 .394 r
.40428 .49554 m .40546 .49961 L .40677 .49948 L F
.859 .554 .027 r
.40436 .4958 m .40437 .49583 L .40428 .49554 L F
.40437 .49583 m .40435 .49578 L .40428 .49554 L F
.816 .466 .394 r
.40428 .49554 m .40438 .49584 L .40396 .49579 L F
.40428 .49554 m .40396 .49579 L .40351 .49573 L F
0 0 .129 r
.40062 .49379 m .40029 .49764 L .40198 .49601 L F
.40048 .49356 m .40046 .49391 L .40062 .49379 L F
.57 .803 .987 r
.40096 .49378 m .40042 .49419 L .4004 .49396 L F
0 0 .129 r
.40046 .49391 m .40029 .49764 L .40062 .49379 L F
.57 .803 .987 r
.40062 .49379 m .4004 .49396 L .40038 .4938 L F
.40096 .49378 m .4004 .49396 L .40062 .49379 L F
.40096 .49378 m .40038 .4938 L .40016 .49169 L F
.687 .766 .912 r
.40207 .49408 m .40203 .49463 L .40095 .49424 L F
0 0 .129 r
.40063 .49381 m .40198 .49601 L .40234 .49373 L F
.687 .766 .912 r
.40207 .49408 m .40095 .49424 L .40321 .49242 L F
0 0 .129 r
.40112 .49377 m .40234 .49373 L .40235 .49367 L F
.40063 .49381 m .40234 .49373 L .40112 .49377 L F
0 0 .094 r
.39903 .49836 m .40029 .49764 L .40046 .49391 L F
.57 .803 .987 r
.40045 .4942 m .40024 .49434 L .40023 .49414 L F
0 0 0 r
.40019 .49446 m .40029 .49416 L .40045 .4942 L F
0 0 .094 r
.39903 .49836 m .40046 .49391 L .40033 .49406 L F
.57 .803 .987 r
.40042 .49419 m .40023 .49414 L .40016 .49169 L F
.40381 .49204 m .40321 .49242 L .40326 .49199 L F
0 0 .129 r
.40062 .49379 m .40063 .49381 L .40112 .49377 L F
.57 .803 .987 r
.40381 .49204 m .40112 .49377 L .40016 .49169 L F
.40112 .49377 m .4004 .49379 L .40016 .49169 L F
.40045 .4942 m .40023 .49414 L .40016 .49169 L F
.687 .766 .912 r
.40207 .49408 m .40306 .49479 L .40203 .49463 L F
.859 .554 .027 r
.40326 .4942 m .40329 .49496 L .40205 .49407 L F
0 0 .129 r
.40235 .49367 m .40198 .49601 L .40387 .49376 L F
.687 .766 .912 r
.40518 .49343 m .40242 .49366 L .40381 .49204 L F
.40537 .49362 m .40242 .49366 L .40518 .49343 L F
.859 .554 .027 r
.40399 .49429 m .40329 .49503 L .40326 .4942 L F
0 0 0 r
.399 .49818 m .39903 .49836 L .40048 .49356 L F
.147 0 0 r
.39808 .49792 m .399 .49818 L .39894 .49785 L F
.39789 .49793 m .3983 .49802 L .39808 .49792 L F
.3983 .49802 m .399 .49818 L .39808 .49792 L F
0 0 .094 r
.39894 .49866 m .39923 .49845 L .39903 .49836 L F
.39923 .49845 m .40029 .49764 L .39903 .49836 L F
.816 .466 .394 r
.40428 .49554 m .40441 .49574 L .40535 .49597 L F
.40441 .49574 m .40677 .49948 L .40535 .49597 L F
.23 0 0 r
.40496 .49587 m .40535 .49597 L .40543 .49592 L F
.40437 .49581 m .40535 .49597 L .40496 .49587 L F
.40438 .49584 m .40535 .49597 L .40437 .49581 L F
.816 .466 .394 r
.40428 .49554 m .40535 .49597 L .40438 .49584 L F
.859 .554 .027 r
.40425 .49517 m .40461 .4965 L .40427 .49546 L F
.40461 .4965 m .40546 .49961 L .40437 .49583 L F
.40461 .4965 m .40437 .49583 L .40427 .49546 L F
.40427 .49546 m .40436 .4958 L .40428 .49554 L F
.40437 .49583 m .40546 .49961 L .40435 .49578 L F
.40387 .49376 m .40425 .49517 L .40427 .49546 L F
.23 0 0 r
.40536 .4953 m .4062 .49552 L .40763 .49477 L F
.727 .567 .673 r
.47523 .47848 m .47884 .47872 L .47885 .47592 L F
.704 .601 .738 r
.47885 .47592 m .48147 .47531 L .48126 .47306 L F
.689 .536 .673 r
.47885 .47592 m .47884 .47872 L .48147 .47531 L F
.854 .937 .564 r
.70649 .33628 m .70763 .33543 L .70752 .33472 L F
.926 .563 .138 r
.40214 .54229 m .40028 .53905 L .40175 .54038 L F
.405 .143 .4 r
.45216 .58159 m .4508 .58228 L .45367 .57958 L F
.361 .086 .354 r
.4508 .58228 m .45302 .58218 L .45367 .57958 L F
.479 .325 .593 r
.4508 .58228 m .45105 .58579 L .45348 .58497 L F
.4508 .58228 m .45348 .58497 L .45193 .5839 L F
.4508 .58228 m .45193 .5839 L .45302 .58218 L F
0 0 0 r
.55889 .47535 m .55556 .47731 L .55624 .47598 L F
.53 .573 .843 r
.52973 .43914 m .5287 .44328 L .5274 .44003 L F
.408 .066 .271 r
.52845 .49172 m .52546 .49405 L .52586 .49225 L F
0 0 0 r
.3359 .58775 m .33897 .58537 L .33663 .58611 L F
.409 .125 .368 r
.71637 .32481 m .71972 .32431 L .71549 .3257 L F
.71637 .32481 m .71897 .3229 L .71972 .32431 L F
.677 .23 .184 r
.56626 .4512 m .56773 .44949 L .56378 .44886 L F
.864 .488 .331 r
.56626 .4512 m .56855 .45179 L .56773 .44949 L F
.588 .747 .953 r
.39092 .48155 m .38839 .48234 L .38732 .4805 L F
.858 .94 .571 r
.34717 .59769 m .34624 .59899 L .34855 .5984 L F
.573 .21 .314 r
.34624 .59899 m .34822 .60105 L .34855 .5984 L F
.34624 .59899 m .34558 .6014 L .34822 .60105 L F
.858 .94 .571 r
.34717 .59769 m .34558 .6014 L .34624 .59899 L F
.076 0 .323 r
.49487 .52917 m .49383 .52776 L .4952 .52665 L F
.49487 .52917 m .49339 .5304 L .49383 .52776 L F
.841 .718 .728 r
.42195 .5169 m .42635 .51502 L .42456 .5136 L F
.42195 .5169 m .42426 .51782 L .42635 .51502 L F
.11 .609 .902 r
.43958 .48185 m .44099 .48184 L .43734 .48077 L F
.663 .684 .859 r
.4393 .48462 m .44099 .48184 L .43958 .48185 L F
.59 .523 .748 r
.52923 .4142 m .53025 .40928 L .529 .41122 L F
.99 .813 .571 r
.531 .41542 m .52923 .4142 L .52858 .41516 L F
0 0 .19 r
.24826 .52816 m .24547 .53339 L .24632 .53072 L F
.043 0 0 r
.66927 .31255 m .6716 .31147 L .67249 .31023 L F
0 0 0 r
.6716 .31147 m .67447 .30869 L .67249 .31023 L F
.27135 .52015 m .26957 .52149 L .26788 .52175 L F
.27284 .51987 m .26957 .52149 L .27135 .52015 L F
.406 .153 .415 r
.51086 .50407 m .50804 .50722 L .50835 .50479 L F
.969 .804 .624 r
.38465 .48349 m .38634 .48582 L .38368 .48651 L F
.138 0 0 r
.70918 .31194 m .70863 .30987 L .71021 .30727 L F
.627 .477 .658 r
.47842 .50789 m .48056 .50459 L .47788 .50481 L F
.431 .648 .95 r
.54309 .40063 m .53913 .39795 L .54147 .39653 L F
.656 .637 .819 r
.545 .39771 m .54309 .40063 L .54147 .39653 L F
.317 .802 .764 r
.67661 .32222 m .67511 .32306 L .67778 .32233 L F
.67661 .32222 m .67366 .32328 L .67511 .32306 L F
.962 .649 .382 r
.38654 .55173 m .3882 .55042 L .38652 .54902 L F
.38654 .55173 m .38837 .55282 L .3882 .55042 L F
0 0 0 r
.68819 .37334 m .68941 .37235 L .69204 .37122 L F
.35167 .62619 m .35484 .62247 L .3544 .62439 L F
.725 .443 .5 r
.35484 .62247 m .3585 .62416 L .3544 .62439 L F
0 0 .258 r
.25188 .59218 m .25169 .59543 L .25047 .59668 L F
0 0 0 r
.25169 .59543 m .25026 .59735 L .25047 .59668 L F
.954 .614 .322 r
.59348 .43328 m .59114 .42919 L .59177 .43199 L F
.903 .492 .119 r
.59424 .4354 m .59348 .43328 L .59177 .43199 L F
.32 .785 .938 r
.28658 .65903 m .28845 .65954 L .29078 .65915 L F
.771 .637 .713 r
.46696 .51798 m .46616 .51413 L .46341 .5175 L F
.657 .576 .753 r
.46696 .51798 m .46868 .51388 L .46616 .51413 L F
.529 .14 .248 r
.46793 .52043 m .46696 .51798 L .46738 .52066 L F
.836 .864 .865 r
.5835 .37051 m .58168 .37267 L .58 .37131 L F
.417 .462 .8 r
.61142 .38997 m .60803 .38787 L .61052 .3874 L F
.56 .362 .57 r
.48147 .47531 m .47884 .47872 L .4814 .47793 L F
.64 .553 .741 r
.48126 .47306 m .48147 .47531 L .48395 .47229 L F
.605 .503 .711 r
.48147 .47531 m .48468 .47503 L .48395 .47229 L F
.596 .392 .575 r
.48147 .47531 m .4837 .47601 L .48468 .47503 L F
.48147 .47531 m .4814 .47793 L .4837 .47601 L F
.61 .102 .019 r
.28956 .57629 m .29437 .57692 L .29195 .578 L F
.545 .916 .752 r
.29195 .578 m .29437 .57692 L .29662 .57522 L F
.843 .59 .556 r
.42871 .54953 m .43179 .55045 L .43025 .55236 L F
.559 .837 .997 r
.36566 .56361 m .36177 .56348 L .36397 .56252 L F
.624 .456 .634 r
.47529 .51095 m .47927 .51135 L .47842 .50789 L F
.591 .545 .772 r
.47529 .51095 m .47867 .51405 L .47927 .51135 L F
.326 .262 .631 r
.60897 .36821 m .60747 .36846 L .60903 .36681 L F
.60897 .36821 m .60784 .37165 L .60747 .36846 L F
.722 .888 .956 r
.37082 .49721 m .36707 .49735 L .37018 .49741 L F
.493 .847 .588 r
.37195 .49613 m .37082 .49721 L .37018 .49741 L F
.37195 .49613 m .37378 .49475 L .37082 .49721 L F
.285 .281 .678 r
.43538 .46791 m .43754 .46733 L .43704 .46447 L F
.571 .389 .596 r
.43538 .46791 m .43827 .4699 L .43754 .46733 L F
.43538 .46791 m .43603 .47161 L .43827 .4699 L F
0 0 0 r
.34636 .65297 m .35041 .65136 L .34903 .6518 L F
.377 0 0 r
.34903 .6518 m .35152 .65241 L .34829 .65203 L F
.598 .848 .992 r
.34496 .65184 m .34636 .65297 L .34903 .6518 L F
.377 0 0 r
.34903 .6518 m .34829 .65203 L .34726 .65191 L F
0 0 0 r
.35041 .65136 m .35085 .65119 L .34903 .6518 L F
.407 .846 .731 r
.34903 .6518 m .35085 .65119 L .35285 .65011 L F
.153 0 .269 r
.45367 .57958 m .455 .58158 L .45538 .57864 L F
.45367 .57958 m .45302 .58218 L .455 .58158 L F
.856 .405 .117 r
.37501 .52927 m .37861 .53302 L .37818 .53153 L F
0 0 .199 r
.28507 .64165 m .28396 .6422 L .28382 .64384 L F
.607 .44 .629 r
.55162 .46572 m .55063 .46843 L .54792 .46908 L F
.533 .919 .918 r
.44312 .59659 m .44724 .59549 L .44549 .59628 L F
0 0 0 r
.44979 .59564 m .44549 .59628 L .44724 .59549 L F
.739 .599 .701 r
.46616 .51413 m .46811 .51071 L .46462 .50917 L F
.912 .642 .515 r
.46868 .51388 m .46811 .51071 L .46616 .51413 L F
.727 .767 .885 r
.24796 .58603 m .24813 .58702 L .24667 .58813 L F
.679 .734 .892 r
.24965 .58722 m .24859 .58962 L .24796 .58603 L F
.25245 .58919 m .24884 .58959 L .24965 .58722 L F
.24884 .58959 m .24859 .58962 L .24965 .58722 L F
.727 .767 .885 r
.24667 .58813 m .24859 .58962 L .24609 .58909 L F
.24813 .58702 m .24859 .58962 L .24667 .58813 L F
.679 .734 .892 r
.25245 .58919 m .24796 .58603 L .25154 .58556 L F
.732 .936 .954 r
.25154 .58556 m .24796 .58603 L .25181 .58449 L F
.488 .805 1 r
.24599 .59218 m .24449 .58818 L .24609 .58909 L F
.477 .229 .458 r
.24449 .58818 m .24796 .58603 L .24609 .58909 L F
.24449 .58818 m .2452 .58873 L .24796 .58603 L F
.2452 .58873 m .24602 .58936 L .24722 .58731 L F
.2452 .58873 m .24722 .58731 L .24796 .58603 L F
.692 .48 .595 r
.24796 .58603 m .24602 .58936 L .25181 .58449 L F
.74 .612 .716 r
.24444 .58376 m .24503 .58743 L .24659 .58237 L F
.608 .039 0 r
.23971 .58572 m .24449 .58818 L .2403 .58849 L F
.23971 .58572 m .24255 .58787 L .24449 .58818 L F
.28 0 .101 r
.24618 .58683 m .24255 .58787 L .24047 .58571 L F
.876 .951 .856 r
.24574 .58737 m .24596 .5871 L .24732 .58617 L F
.2503 .58514 m .24507 .58771 L .25058 .58495 L F
.25034 .58519 m .24622 .58918 L .24533 .58804 L F
.25034 .58519 m .24533 .58804 L .24593 .58729 L F
.25058 .58495 m .24604 .58722 L .24643 .58684 L F
.24775 .586 m .24764 .58608 L .24732 .58617 L F
.447 .164 .389 r
.24732 .58617 m .2466 .58637 L .24575 .58484 L F
.156 .259 .72 r
.24575 .58484 m .24613 .58642 L .24732 .58617 L F
.876 .951 .856 r
.24759 .58611 m .24643 .58684 L .24732 .58617 L F
.24593 .58729 m .24533 .58804 L .24507 .58771 L F
.24604 .58722 m .24574 .58737 L .24608 .58711 L F
.24604 .58722 m .24608 .58711 L .24643 .58684 L F
.24574 .58737 m .24507 .58771 L .24596 .5871 L F
.28 0 .101 r
.24596 .58717 m .24507 .58771 L .24589 .58719 L F
.257 .022 .355 r
.24732 .58617 m .24675 .5867 L .24507 .58771 L F
.24675 .5867 m .24595 .58746 L .24596 .58717 L F
.876 .951 .856 r
.25058 .58495 m .24643 .58684 L .24775 .586 L F
.25008 .58594 m .24602 .58936 L .25034 .58519 L F
.25083 .58496 m .24507 .58771 L .25109 .58476 L F
.799 .8 .852 r
.24633 .58721 m .24881 .58795 L .24732 .58617 L F
.257 .022 .355 r
.24662 .58683 m .24537 .58821 L .24522 .58816 L F
.24732 .58617 m .2458 .58776 L .24662 .58683 L F
.2458 .58776 m .24537 .58821 L .24662 .58683 L F
.799 .8 .852 r
.24607 .58777 m .24655 .59054 L .24881 .58795 L F
.24585 .58792 m .24655 .59054 L .24607 .58777 L F
.876 .951 .856 r
.24622 .58918 m .24602 .58936 L .24507 .58771 L F
.799 .8 .852 r
.24536 .58826 m .24655 .59054 L .2458 .58776 L F
.488 .805 1 r
.24599 .59218 m .24655 .59054 L .24449 .58818 L F
0 .18 .698 r
.2449 .58784 m .24602 .58936 L .24449 .58818 L F
.257 .022 .355 r
.24533 .58804 m .24528 .58808 L .24507 .58771 L F
0 .18 .698 r
.24507 .58771 m .24528 .58808 L .2449 .58784 L F
0 .042 .605 r
.24488 .58786 m .24522 .58814 L .24507 .58771 L F
.257 .022 .355 r
.24528 .58808 m .24522 .58814 L .24507 .58771 L F
0 .18 .698 r
.24529 .58809 m .24602 .58936 L .2449 .58784 L F
0 .042 .605 r
.24449 .58818 m .24535 .58825 L .24488 .58786 L F
.257 .022 .355 r
.24522 .58814 m .24522 .58816 L .2452 .58816 L F
.24528 .58808 m .24523 .58815 L .24522 .58814 L F
.24523 .58815 m .24522 .58816 L .24522 .58814 L F
.24529 .58809 m .24522 .58816 L .24528 .58808 L F
0 .042 .605 r
.24522 .58814 m .24535 .58825 L .24507 .58771 L F
.24522 .58814 m .24526 .58818 L .24522 .58814 L F
.638 .175 .137 r
.24522 .58834 m .2452 .58816 L .24539 .58822 L F
0 .042 .605 r
.24526 .58818 m .24535 .58825 L .24522 .58814 L F
.257 .022 .355 r
.24522 .58814 m .2452 .58816 L .24507 .58771 L F
0 .18 .698 r
.24507 .58771 m .24529 .58809 L .24528 .58808 L F
.257 .022 .355 r
.24533 .58804 m .24529 .58809 L .24528 .58808 L F
0 .042 .605 r
.24449 .58818 m .24655 .59054 L .24535 .58825 L F
.638 .175 .137 r
.24543 .59058 m .24522 .58834 L .24554 .58841 L F
.24637 .5891 m .24554 .58841 L .24666 .58865 L F
.24543 .59058 m .24554 .58841 L .24637 .5891 L F
.24522 .58834 m .24539 .58822 L .24666 .58865 L F
.799 .8 .852 r
.2458 .58776 m .24585 .58792 L .24607 .58777 L F
.257 .022 .355 r
.24596 .58717 m .24533 .58804 L .24507 .58771 L F
.799 .8 .852 r
.24507 .58771 m .24536 .58826 L .2458 .58776 L F
.257 .022 .355 r
.24732 .58617 m .24522 .58816 L .24533 .58804 L F
.799 .8 .852 r
.24652 .5878 m .24881 .58795 L .24596 .5871 L F
.257 .022 .355 r
.24732 .58617 m .24666 .58865 L .24537 .58821 L F
.799 .8 .852 r
.24596 .5871 m .24633 .58721 L .24732 .58617 L F
.28 0 .101 r
.24601 .58716 m .24596 .58717 L .24599 .58713 L F
.24596 .58717 m .24589 .58719 L .24596 .5871 L F
.257 .022 .355 r
.24595 .58746 m .24533 .58804 L .24596 .58717 L F
.28 0 .101 r
.24601 .58716 m .24507 .58771 L .24596 .58717 L F
.799 .8 .852 r
.24507 .58771 m .24652 .5878 L .24601 .58716 L F
.28 0 .101 r
.24694 .58697 m .24507 .58771 L .24601 .58716 L F
.799 .8 .852 r
.24507 .58771 m .24601 .58716 L .24596 .5871 L F
.447 .164 .389 r
.24732 .58617 m .24596 .5871 L .24694 .58697 L F
.28 0 .101 r
.24694 .58697 m .24601 .58716 L .24605 .58708 L F
.447 .164 .389 r
.24596 .5871 m .24507 .58771 L .24694 .58697 L F
.28 0 .101 r
.24694 .58697 m .24605 .58708 L .24618 .58683 L F
.24601 .58716 m .24599 .58713 L .24618 .58683 L F
.24596 .58717 m .24596 .5871 L .24618 .58683 L F
.447 .164 .389 r
.24732 .58617 m .24694 .58697 L .2466 .58637 L F
.332 .697 .982 r
.24625 .58662 m .24694 .58697 L .24618 .58683 L F
.24625 .58662 m .24618 .58683 L .24047 .58571 L F
.768 .798 .878 r
.24575 .58484 m .24694 .58697 L .24195 .58436 L F
.156 .259 .72 r
.24613 .58642 m .24666 .58865 L .24709 .58701 L F
.24634 .58638 m .24709 .58701 L .24732 .58617 L F
.24613 .58642 m .24709 .58701 L .24634 .58638 L F
.876 .951 .856 r
.24764 .58608 m .24759 .58611 L .24732 .58617 L F
.156 .259 .72 r
.24606 .58614 m .24831 .58734 L .24666 .58865 L F
.24575 .58484 m .24672 .58579 L .24606 .58614 L F
.24672 .58579 m .24831 .58734 L .24606 .58614 L F
.332 .697 .982 r
.24178 .58451 m .2457 .58633 L .24047 .58571 L F
.24268 .58475 m .2457 .58633 L .24178 .58451 L F
.2457 .58633 m .24625 .58662 L .24541 .58648 L F
.2457 .58633 m .24541 .58648 L .24047 .58571 L F
.28 0 .101 r
.24589 .58719 m .24255 .58787 L .24618 .58683 L F
.439 .799 .996 r
.24342 .58675 m .24831 .58734 L .24672 .58579 L F
.2451 .58537 m .24672 .58579 L .24575 .58484 L F
.24342 .58675 m .24672 .58579 L .2451 .58537 L F
.332 .697 .982 r
.24195 .58436 m .24268 .58475 L .24178 .58451 L F
.28 0 .101 r
.24589 .58719 m .24507 .58771 L .24255 .58787 L F
.876 .951 .856 r
.25109 .58476 m .2503 .58514 L .25058 .58495 L F
.25181 .58449 m .25008 .58594 L .25034 .58519 L F
.25181 .58449 m .25083 .58496 L .25109 .58476 L F
.841 .611 .589 r
.24712 .54501 m .24765 .54286 L .24948 .5438 L F
.731 .511 .594 r
.24948 .5438 m .24928 .54702 L .24712 .54501 L F
.582 .865 .995 r
.24948 .5438 m .24765 .54286 L .25023 .54198 L F
.014 .195 .706 r
.25023 .54198 m .25184 .5463 L .24948 .5438 L F
.582 .865 .995 r
.24948 .5438 m .24765 .54286 L .25023 .54198 L F
.475 .294 .555 r
.24948 .5438 m .25184 .5463 L .24928 .54702 L F
.905 .589 .436 r
.58733 .422 m .58948 .42096 L .58743 .41937 L F
.58733 .422 m .58986 .42181 L .58948 .42096 L F
.455 .156 .368 r
.33596 .56636 m .33518 .56913 L .33242 .56963 L F
.14 0 .237 r
.33695 .56818 m .33596 .56636 L .33829 .5659 L F
.33695 .56818 m .33518 .56913 L .33596 .56636 L F
0 0 0 r
.52745 .42586 m .53179 .42449 L .52993 .42511 L F
.736 .992 .851 r
.52993 .42511 m .53179 .42449 L .53378 .42256 L F
.81 .913 .517 r
.35477 .53559 m .35434 .53689 L .35511 .53545 L F
.35477 .53559 m .35511 .53545 L .356 .5338 L F
0 0 0 r
.35158 .53635 m .35209 .537 L .35477 .53559 L F
.402 .825 .654 r
.35477 .53559 m .35209 .537 L .3538 .53599 L F
.72 .696 .826 r
.34964 .53281 m .35158 .53635 L .35477 .53559 L F
.34964 .53281 m .35477 .53559 L .35259 .53266 L F
.402 .825 .654 r
.35477 .53559 m .3538 .53599 L .35552 .53498 L F
.043 0 0 r
.35846 .53435 m .35477 .53559 L .356 .5338 L F
.35846 .53435 m .3558 .53545 L .35477 .53559 L F
.382 .512 .864 r
.35477 .53559 m .3558 .53545 L .3554 .53367 L F
.35477 .53559 m .3554 .53367 L .35489 .53134 L F
.81 .913 .517 r
.35477 .53559 m .35433 .53691 L .35434 .53689 L F
.855 .994 .831 r
.52962 .40858 m .529 .41122 L .53025 .40928 L F
.782 .944 .93 r
.52767 .41033 m .529 .41122 L .52962 .40858 L F
.996 .809 .538 r
.56378 .44886 m .56406 .45225 L .56418 .45224 L F
0 0 0 r
.56406 .45225 m .56371 .45459 L .56418 .45224 L F
.731 .714 .835 r
.32253 .63143 m .31972 .63388 L .31829 .63086 L F
.422 .294 .6 r
.32853 .57189 m .32628 .56958 L .3297 .5695 L F
.32853 .57189 m .32679 .57397 L .32628 .56958 L F
.509 .306 .541 r
.68872 .29301 m .6914 .29247 L .69133 .29023 L F
.24 0 .009 r
.68811 .29495 m .6914 .29247 L .68872 .29301 L F
.462 .175 .391 r
.32628 .60499 m .32908 .60472 L .33042 .60067 L F
.217 0 .279 r
.33042 .60067 m .33108 .60379 L .33169 .60071 L F
.33042 .60067 m .32908 .60472 L .33108 .60379 L F
.133 0 .214 r
.66655 .31597 m .66917 .3151 L .66927 .31255 L F
0 0 0 r
.66655 .31597 m .66604 .31795 L .668 .31625 L F
.66327 .31892 m .66481 .31888 L .66604 .31795 L F
.58 .882 .588 r
.66676 .31712 m .66481 .31888 L .66782 .31591 L F
.66604 .31795 m .6649 .31881 L .66676 .31712 L F
.6649 .31881 m .66481 .31888 L .66676 .31712 L F
0 0 0 r
.66887 .3152 m .668 .31625 L .66917 .3151 L F
.66655 .31597 m .66777 .31621 L .66887 .3152 L F
.66777 .31621 m .668 .31625 L .66887 .3152 L F
.567 .276 .433 r
.32556 .57631 m .32037 .57864 L .32067 .57648 L F
.799 .499 .481 r
.42894 .52718 m .4332 .52914 L .43097 .52738 L F
.745 .726 .834 r
.451 .49407 m .45484 .49505 L .45366 .49095 L F
.737 .587 .688 r
.451 .49407 m .45492 .49781 L .45484 .49505 L F
.205 0 .03 r
.71003 .29881 m .70654 .30113 L .7068 .29973 L F
.799 .499 .481 r
.42894 .52718 m .4291 .52927 L .4332 .52914 L F
.79 .47 .449 r
.4291 .52927 m .43135 .53249 L .4332 .52914 L F
.116 0 0 r
.43135 .53249 m .43554 .53033 L .4332 .52914 L F
.706 .651 .792 r
.47872 .4814 m .48028 .4851 L .48283 .48189 L F
.647 .562 .746 r
.48283 .48189 m .48028 .4851 L .48298 .4844 L F
.664 .551 .716 r
.48044 .48883 m .48298 .4844 L .48028 .4851 L F
.296 0 .22 r
.23393 .53453 m .2354 .53576 L .23618 .53357 L F
.23393 .53453 m .23316 .53647 L .2354 .53576 L F
0 0 .287 r
.47725 .52056 m .47585 .52413 L .47407 .52258 L F
.503 .556 .843 r
.4761 .52731 m .47634 .52258 L .47585 .52413 L F
.4761 .52731 m .47869 .52687 L .47634 .52258 L F
.075 0 .324 r
.47632 .53069 m .47869 .52687 L .4761 .52731 L F
0 0 0 r
.67447 .30869 m .67694 .3053 L .675 .30674 L F
.31952 .6211 m .31746 .62202 L .31461 .62382 L F
.8 .88 .904 r
.50217 .41442 m .49928 .41703 L .49776 .41565 L F
.69 .374 .435 r
.30793 .64086 m .31444 .64395 L .30945 .64632 L F
0 0 0 r
.52216 .42788 m .52334 .42772 L .52057 .42833 L F
.52216 .42788 m .5248 .42687 L .52334 .42772 L F
.898 .621 .509 r
.42195 .5169 m .42548 .51956 L .42426 .51782 L F
.42195 .5169 m .42194 .51969 L .42548 .51956 L F
.918 .766 .677 r
.42194 .51969 m .42395 .52102 L .42548 .51956 L F
.758 .467 .492 r
.42288 .52325 m .42548 .51956 L .42395 .52102 L F
0 0 0 r
.6972 .28366 m .69411 .28653 L .69733 .28541 L F
.698 .313 .315 r
.69733 .28541 m .70006 .28608 L .6972 .28366 L F
.732 .707 .827 r
.41271 .59627 m .41344 .59933 L .41604 .59769 L F
.863 .881 .849 r
.58171 .42231 m .57839 .42351 L .58134 .42091 L F
.823 .94 .576 r
.58316 .41891 m .58171 .42231 L .58134 .42091 L F
.576 .323 .496 r
.4506 .52287 m .45404 .52353 L .45471 .52111 L F
.45471 .52111 m .45404 .52353 L .4506 .52287 L F
.853 .487 0 r
.40026 .53678 m .39829 .53261 L .40049 .53444 L F
.276 0 .282 r
.35657 .61515 m .35929 .61205 L .35943 .61477 L F
.747 .577 .665 r
.36211 .61132 m .35943 .61477 L .35929 .61205 L F
.578 .925 .956 r
.26228 .62829 m .26165 .62932 L .26407 .62817 L F
.25952 .62848 m .26116 .62913 L .26228 .62829 L F
.26116 .62913 m .26165 .62932 L .26228 .62829 L F
.25952 .62848 m .26407 .62817 L .26165 .62982 L F
.9 .986 .74 r
.26165 .62982 m .26407 .62817 L .26354 .62724 L F
.26165 .62982 m .26336 .62749 L .26373 .62729 L F
.26336 .62749 m .26354 .62724 L .26365 .62727 L F
.26336 .62749 m .26365 .62727 L .26373 .62729 L F
0 0 .039 r
.66917 .3151 m .6716 .31147 L .66927 .31255 L F
0 0 0 r
.34793 .57209 m .34745 .57319 L .34684 .57557 L F
.206 0 .308 r
.55658 .41144 m .55526 .41091 L .55499 .41307 L F
.542 .779 .986 r
.55382 .41152 m .55499 .41307 L .55247 .41368 L F
.55382 .41152 m .55499 .41307 L .55247 .41368 L F
.617 .643 .854 r
.55636 .4175 m .55791 .4143 L .55499 .41307 L F
.206 0 .308 r
.5577 .4103 m .55685 .41051 L .55658 .41144 L F
.55685 .41051 m .55526 .41091 L .55658 .41144 L F
.805 .888 .904 r
.5577 .4103 m .55499 .41307 L .55382 .41152 L F
.164 0 0 r
.55791 .4143 m .55382 .41152 L .55499 .41307 L F
.55611 .41307 m .55371 .41414 L .55382 .41152 L F
.55791 .4143 m .55578 .41422 L .55611 .41307 L F
.55578 .41422 m .55371 .41414 L .55611 .41307 L F
.314 .488 .871 r
.38431 .47863 m .38317 .4739 L .38285 .47509 L F
.878 .853 .815 r
.57377 .42204 m .575 .42464 L .57309 .42672 L F
.591 .725 .937 r
.57839 .42351 m .575 .42464 L .57377 .42204 L F
0 0 0 r
.61125 .37658 m .61127 .37607 L .61333 .37558 L F
.61127 .37607 m .60925 .37811 L .61127 .37583 L F
.60967 .37734 m .61127 .37607 L .61125 .37658 L F
.61127 .37607 m .61127 .37583 L .61193 .37509 L F
.042 0 0 r
.61193 .37509 m .61463 .37436 L .61333 .37558 L F
.925 .862 .427 r
.31188 .56698 m .31104 .56845 L .31134 .56931 L F
.391 0 .043 r
.3079 .56894 m .31104 .56845 L .31188 .56698 L F
.482 .469 .767 r
.31188 .56698 m .31496 .56722 L .31411 .5667 L F
.499 .34 .596 r
.31188 .56698 m .31134 .56931 L .31496 .56722 L F
.825 .595 .59 r
.7314 .3182 m .73364 .31515 L .73206 .31528 L F
.7314 .3182 m .735 .31922 L .73364 .31515 L F
.664 .512 .668 r
.73364 .31515 m .735 .31922 L .73735 .3156 L F
.536 .508 .772 r
.26414 .62492 m .2623 .6213 L .26275 .62365 L F
.918 .726 .233 r
.26354 .62724 m .26407 .62817 L .26414 .62492 L F
.71 .944 .957 r
.47691 .42974 m .47469 .4324 L .47405 .43188 L F
.47691 .42974 m .47837 .43039 L .47469 .4324 L F
0 0 0 r
.24039 .59729 m .24181 .59644 L .24369 .59835 L F
.24039 .59729 m .24019 .59821 L .24181 .59644 L F
.529 .363 .6 r
.47644 .5172 m .47949 .51638 L .47867 .51405 L F
.481 .357 .635 r
.47725 .52056 m .47949 .51638 L .47644 .5172 L F
.075 .149 .638 r
.71092 .29515 m .7104 .29634 L .70924 .29359 L F
.987 .852 .618 r
.38543 .61289 m .38612 .61194 L .38483 .61107 L F
.916 .928 .804 r
.38483 .61107 m .38612 .61194 L .38829 .60861 L F
.745 .896 .946 r
.50927 .40829 m .51389 .4076 L .51044 .40942 L F
.615 .82 .414 r
.60967 .37734 m .60925 .37811 L .61127 .37607 L F
.60967 .37734 m .60821 .37959 L .60925 .37811 L F
.775 .997 .81 r
.5394 .45409 m .54147 .45344 L .54346 .45124 L F
.627 .477 .658 r
.47842 .50789 m .48182 .50797 L .48056 .50459 L F
.684 .493 .622 r
.47842 .50789 m .48182 .51068 L .48182 .50797 L F
.47842 .50789 m .47927 .51135 L .48182 .51068 L F
.983 .9 .649 r
.43664 .53364 m .43486 .53547 L .43612 .53625 L F
.936 .958 .758 r
.43486 .53547 m .43361 .54017 L .43612 .53625 L F
.736 .706 .823 r
.39419 .48051 m .3951 .48282 L .39092 .48155 L F
.475 .556 .858 r
.39597 .48148 m .3951 .48282 L .39419 .48051 L F
.53 .18 .319 r
.33291 .57036 m .3297 .5695 L .33242 .56963 L F
.33291 .57036 m .32853 .57189 L .3297 .5695 L F
.563 .502 .745 r
.42284 .59763 m .42066 .59924 L .4205 .59638 L F
.72 .919 .961 r
.41872 .59859 m .42066 .59924 L .42284 .59763 L F
.039 .468 .881 r
.57531 .38419 m .5734 .38447 L .5725 .38266 L F
.57531 .38419 m .57728 .38645 L .5734 .38447 L F
.661 .553 .722 r
.48193 .49411 m .48314 .49823 L .48552 .49484 L F
.585 .451 .665 r
.48314 .49823 m .48582 .49767 L .48552 .49484 L F
.612 .495 .696 r
.48338 .50098 m .48582 .49767 L .48314 .49823 L F
.851 .941 .88 r
.31836 .53646 m .3163 .53763 L .31658 .53543 L F
.781 .939 .931 r
.31836 .53646 m .31658 .53543 L .31957 .53316 L F
.993 .744 .425 r
.39883 .45728 m .40011 .459 L .39991 .46177 L F
.576 .843 .995 r
.40068 .45688 m .40011 .459 L .39958 .45829 L F
.40068 .45688 m .40255 .45837 L .40011 .459 L F
.855 .911 .87 r
.40518 .45514 m .40255 .45837 L .40068 .45688 L F
.576 .843 .995 r
.40068 .45688 m .39958 .45829 L .39883 .45728 L F
.54 .326 .538 r
.40011 .459 m .40205 .46078 L .39991 .46177 L F
.40011 .459 m .40255 .45837 L .40205 .46078 L F
.721 .722 .85 r
.39991 .46177 m .40068 .45688 L .39883 .45728 L F
.39991 .46177 m .40205 .46078 L .40068 .45688 L F
.722 .66 .788 r
.40518 .45514 m .40662 .45902 L .40255 .45837 L F
.855 .911 .87 r
.40518 .45514 m .40068 .45688 L .40419 .45857 L F
.808 .963 .643 r
.40662 .45902 m .40205 .46078 L .40255 .45837 L F
.40662 .45902 m .40483 .46029 L .40205 .46078 L F
.397 .52 .864 r
.40068 .45688 m .40205 .46078 L .40483 .46029 L F
.40068 .45688 m .40483 .46029 L .40419 .45857 L F
0 0 0 r
.39963 .459 m .40068 .45688 L .40188 .45533 L F
.407 .585 .914 r
.40033 .4546 m .40068 .45688 L .39843 .4543 L F
.40215 .45489 m .40175 .45543 L .40033 .4546 L F
.40175 .45543 m .40068 .45688 L .40033 .4546 L F
0 0 0 r
.39963 .459 m .40215 .45489 L .40171 .45792 L F
.463 .412 .715 r
.3983 .4542 m .40091 .45705 L .40022 .45454 L F
.534 .322 .539 r
.40014 .45422 m .40215 .45489 L .39843 .4543 L F
.463 .412 .715 r
.39968 .45422 m .40022 .45454 L .40014 .45422 L F
.534 .322 .539 r
.40014 .45422 m .39843 .4543 L .3983 .4542 L F
.463 .412 .715 r
.3983 .4542 m .40022 .45454 L .39968 .45422 L F
.40091 .45705 m .40171 .45792 L .40114 .4566 L F
.40091 .45705 m .40114 .4566 L .40014 .45422 L F
0 0 0 r
.40188 .45533 m .40164 .45564 L .40215 .45489 L F
.40164 .45564 m .40068 .45688 L .40175 .45543 L F
.40164 .45564 m .40175 .45543 L .40215 .45489 L F
.171 .056 .471 r
.30758 .63091 m .30762 .63418 L .30904 .63109 L F
.361 .617 .949 r
.30665 .63456 m .3064 .63587 L .30874 .63552 L F
.30485 .63375 m .30572 .63493 L .30665 .63456 L F
.30572 .63493 m .3064 .63587 L .30665 .63456 L F
.733 .654 .771 r
.30471 .63654 m .30296 .64094 L .30224 .63751 L F
.30471 .63654 m .30684 .64069 L .30296 .64094 L F
.634 .61 .808 r
.30735 .63956 m .30684 .64069 L .30471 .63654 L F
.30735 .63956 m .30471 .63654 L .30699 .63876 L F
.665 .399 .507 r
.30006 .63781 m .30296 .64094 L .29955 .64028 L F
.4 .157 .425 r
.30224 .63751 m .30006 .63781 L .29995 .63838 L F
.30224 .63751 m .29995 .63838 L .29955 .64028 L F
.627 .908 .615 r
.30048 .63889 m .30224 .63751 L .30051 .63929 L F
.30048 .63889 m .30051 .63929 L .29955 .64028 L F
.069 .613 .845 r
.30032 .63827 m .30043 .63828 L .30048 .63889 L F
.655 .512 .676 r
.29955 .64028 m .30296 .64094 L .30224 .63751 L F
0 0 0 r
.30458 .63662 m .30224 .63751 L .30048 .63889 L F
.30471 .63654 m .30129 .63845 L .30616 .63962 L F
.069 .613 .845 r
.30042 .63824 m .30616 .63962 L .30048 .63889 L F
.382 .16 .449 r
.29751 .64115 m .30006 .63781 L .29955 .64028 L F
.30006 .63781 m .29751 .64115 L .29955 .64028 L F
.645 .273 .324 r
.29955 .64028 m .30296 .64094 L .30181 .64239 L F
.022 .232 .737 r
.29955 .64028 m .30181 .64239 L .30048 .63889 L F
.79 .722 .788 r
.30048 .63889 m .30181 .64239 L .29774 .64215 L F
0 0 0 r
.29898 .64128 m .30048 .63889 L .29774 .64215 L F
.965 .698 .478 r
.29937 .63647 m .30021 .63852 L .29909 .63907 L F
.742 .859 .427 r
.30032 .63827 m .30048 .63889 L .29902 .64122 L F
.30032 .63827 m .29902 .64122 L .29898 .64128 L F
.965 .698 .478 r
.30021 .63852 m .30097 .64032 L .30008 .63875 L F
.509 .515 .798 r
.30031 .63829 m .30021 .63852 L .30011 .63825 L F
.742 .859 .427 r
.30031 .63821 m .30032 .63827 L .30021 .63852 L F
.30031 .63821 m .30021 .63852 L .30008 .63875 L F
.30031 .63821 m .30008 .63875 L .30097 .64032 L F
.30008 .63875 m .30021 .63852 L .29898 .64128 L F
.30008 .63875 m .29898 .64128 L .30097 .64032 L F
.965 .698 .478 r
.30008 .63875 m .30097 .64032 L .29965 .63945 L F
.30021 .63852 m .29965 .63945 L .29909 .63907 L F
.509 .515 .798 r
.30208 .63864 m .30097 .64032 L .30021 .63852 L F
.30208 .63864 m .30021 .63852 L .30031 .63829 L F
.92 .781 .69 r
.30364 .6372 m .30616 .63962 L .30069 .6383 L F
.509 .515 .798 r
.30069 .6383 m .30011 .63825 L .30051 .63739 L F
.92 .781 .69 r
.30065 .63811 m .30069 .6383 L .30031 .63821 L F
.30364 .6372 m .30069 .6383 L .30065 .63811 L F
.509 .515 .798 r
.30051 .63739 m .30011 .63825 L .29937 .63647 L F
.92 .781 .69 r
.30364 .6372 m .30065 .63811 L .30166 .63668 L F
.30065 .63811 m .30031 .63821 L .30083 .63762 L F
.30065 .63811 m .30082 .63764 L .30166 .63668 L F
.30082 .63764 m .30087 .63757 L .30166 .63668 L F
0 0 0 r
.30471 .63654 m .30224 .63751 L .30458 .63662 L F
.125 .658 .864 r
.30166 .63668 m .3026 .63679 L .30364 .6372 L F
.665 .113 0 r
.30364 .6372 m .30471 .63654 L .30533 .63786 L F
.30364 .6372 m .30699 .63876 L .30471 .63654 L F
.886 .806 .765 r
.30705 .63576 m .30701 .63781 L .30364 .6372 L F
.30701 .63781 m .30699 .63876 L .30364 .6372 L F
.30825 .63607 m .30699 .63876 L .30705 .63576 L F
.361 .617 .949 r
.30757 .63563 m .30874 .63552 L .30816 .63604 L F
.30485 .63375 m .3072 .63481 L .30757 .63563 L F
.3072 .63481 m .30874 .63552 L .30757 .63563 L F
.881 .949 .594 r
.30927 .63534 m .30888 .63591 L .30873 .63505 L F
.30888 .63591 m .30825 .63607 L .30829 .63597 L F
0 0 0 r
.3081 .6361 m .30874 .63552 L .30927 .63534 L F
.881 .949 .594 r
.30883 .63562 m .30829 .63597 L .30873 .63505 L F
.30888 .63591 m .30829 .63597 L .30883 .63562 L F
0 0 0 r
.30797 .63622 m .3081 .6361 L .30927 .63534 L F
.093 .255 .739 r
.30874 .63552 m .30964 .63752 L .30927 .63534 L F
.873 .834 .805 r
.30927 .63534 m .30964 .63752 L .30735 .63956 L F
.881 .949 .594 r
.30927 .63534 m .30735 .63956 L .30699 .63876 L F
0 0 0 r
.30797 .63622 m .30927 .63534 L .30873 .63505 L F
.059 0 0 r
.31096 .63474 m .30873 .63505 L .30799 .63656 L F
.881 .949 .594 r
.30888 .63591 m .30699 .63876 L .30825 .63607 L F
.059 0 0 r
.30817 .63694 m .30799 .63656 L .30759 .63739 L F
.31096 .63474 m .30799 .63656 L .30817 .63694 L F
.361 .617 .949 r
.30485 .63375 m .30816 .63604 L .30794 .63599 L F
.30485 .63375 m .3081 .6361 L .30788 .63615 L F
.558 0 0 r
.30755 .63589 m .30763 .63532 L .30485 .63375 L F
.30786 .63594 m .30763 .63532 L .30755 .63589 L F
.886 .806 .765 r
.30815 .63624 m .30364 .6372 L .30759 .63739 L F
.30873 .63505 m .30827 .63601 L .30787 .63593 L F
.30873 .63505 m .30787 .63593 L .30806 .63533 L F
.30873 .63505 m .30806 .63533 L .30809 .63563 L F
0 0 .094 r
.30904 .63109 m .30809 .63563 L .30873 .63505 L F
.886 .806 .765 r
.30827 .63601 m .30825 .63607 L .30755 .63589 L F
.361 .617 .949 r
.30794 .63599 m .30816 .63604 L .3081 .6361 L F
.30788 .63615 m .3081 .6361 L .30797 .63622 L F
0 0 .094 r
.30809 .63563 m .30797 .63622 L .30873 .63505 L F
.886 .806 .765 r
.30873 .63505 m .30809 .63563 L .30815 .63624 L F
0 0 .094 r
.30805 .63517 m .30763 .63532 L .30786 .63594 L F
.30831 .63457 m .30786 .63594 L .30797 .63622 L F
.30904 .63109 m .30786 .63594 L .30831 .63457 L F
.886 .806 .765 r
.30806 .63533 m .30787 .63593 L .30705 .63576 L F
.30827 .63601 m .30755 .63589 L .30705 .63576 L F
.558 0 0 r
.30797 .63622 m .30786 .63594 L .30755 .63589 L F
.886 .806 .765 r
.30806 .63533 m .30364 .6372 L .30815 .63624 L F
0 0 .094 r
.30904 .63109 m .30797 .6343 L .30805 .63517 L F
.30797 .6343 m .30763 .63532 L .30805 .63517 L F
.125 .658 .864 r
.3026 .63679 m .30759 .63739 L .30364 .6372 L F
.665 .113 0 r
.30364 .6372 m .30533 .63786 L .30616 .63962 L F
.819 .718 .754 r
.30208 .63864 m .30759 .63739 L .30166 .63668 L F
.59 .624 .854 r
.30087 .63757 m .30208 .63864 L .30166 .63668 L F
.509 .515 .798 r
.30208 .63864 m .30082 .63764 L .30087 .63757 L F
.30082 .63764 m .29937 .63647 L .30214 .63583 L F
.92 .781 .69 r
.30082 .63764 m .30083 .63762 L .30087 .63757 L F
.509 .515 .798 r
.30177 .63839 m .30069 .6383 L .30065 .63811 L F
.30177 .63839 m .30065 .63811 L .30082 .63764 L F
.30208 .63864 m .30011 .63825 L .30177 .63839 L F
.59 .624 .854 r
.30031 .63821 m .30208 .63864 L .30087 .63757 L F
.509 .515 .798 r
.30208 .63864 m .30087 .63757 L .30216 .63582 L F
.30082 .63764 m .30214 .63583 L .30216 .63582 L F
.30082 .63764 m .30065 .63811 L .30051 .63739 L F
.069 .613 .845 r
.30031 .63821 m .30042 .63824 L .30043 .63828 L F
.30031 .63821 m .30043 .63828 L .30032 .63827 L F
.171 .056 .471 r
.30762 .63418 m .30763 .63532 L .30807 .634 L F
.30762 .63418 m .30807 .634 L .30904 .63109 L F
.295 .79 .777 r
.61516 .34427 m .61694 .34349 L .61904 .34281 L F
.61516 .34427 m .61425 .34434 L .61694 .34349 L F
0 0 0 r
.44379 .47446 m .44515 .47348 L .44657 .47116 L F
.44657 .47116 m .44776 .47017 L .44925 .46867 L F
.78 .697 .772 r
.44515 .47348 m .44776 .47017 L .44657 .47116 L F
.565 .932 .797 r
.56314 .40565 m .56228 .40669 L .56377 .40562 L F
.422 .803 .991 r
.56023 .40593 m .56228 .40669 L .56314 .40565 L F
.729 .324 .28 r
.55998 .40887 m .56228 .40669 L .56023 .40593 L F
.55998 .40887 m .56412 .40938 L .56228 .40669 L F
.581 .601 .837 r
.56228 .40669 m .56438 .40758 L .56377 .40562 L F
.725 .323 .288 r
.56412 .40938 m .56438 .40758 L .56228 .40669 L F
.663 .684 .859 r
.4393 .48462 m .44296 .48515 L .44099 .48184 L F
.713 .57 .693 r
.4393 .48462 m .44047 .48868 L .44296 .48515 L F
.743 .715 .826 r
.44099 .48184 m .44296 .48515 L .44568 .48294 L F
.914 .979 .719 r
.31461 .62382 m .31491 .62541 L .31267 .62706 L F
.549 .889 .984 r
.4701 .46946 m .47338 .46901 L .47189 .46838 L F
.588 .88 .993 r
.47338 .46901 m .47602 .46819 L .47444 .46712 L F
.623 .918 .978 r
.47189 .46838 m .47338 .46901 L .47444 .46712 L F
.916 .928 .804 r
.38483 .61107 m .38829 .60861 L .38729 .6077 L F
.762 .554 .616 r
.47759 .49115 m .48158 .49179 L .48044 .48883 L F
.664 .551 .716 r
.48044 .48883 m .48417 .48832 L .48298 .4844 L F
.644 .486 .654 r
.48158 .49179 m .48417 .48832 L .48044 .48883 L F
.741 .95 .946 r
.43373 .48037 m .43356 .48205 L .43488 .48151 L F
.43356 .48205 m .43355 .48215 L .43488 .48151 L F
.354 .818 .729 r
.43052 .48322 m .43141 .48293 L .43335 .48214 L F
.43356 .48205 m .43244 .4826 L .43488 .48151 L F
.43141 .48293 m .43242 .4826 L .43356 .48205 L F
.43242 .4826 m .43244 .4826 L .43356 .48205 L F
.483 .739 .984 r
.4317 .47898 m .43351 .48208 L .43373 .48037 L F
.43351 .48208 m .43355 .48215 L .43356 .48205 L F
.43351 .48208 m .43356 .48205 L .43373 .48037 L F
.896 .935 .832 r
.43351 .48208 m .43052 .48322 L .43355 .48215 L F
.4317 .47898 m .43052 .48322 L .43351 .48208 L F
.354 .818 .729 r
.43052 .48322 m .43335 .48214 L .43488 .48151 L F
.501 .538 .827 r
.25851 .52374 m .25969 .52248 L .25741 .52324 L F
0 0 0 r
.25969 .52248 m .25469 .52568 L .25741 .52324 L F
0 .274 .776 r
.60838 .42971 m .6105 .43135 L .60846 .42861 L F
.812 .762 .806 r
.38654 .46462 m .38786 .46874 L .38835 .46598 L F
.774 .849 .908 r
.3837 .4684 m .38513 .47006 L .38786 .46874 L F
.3837 .4684 m .38513 .47006 L .38786 .46874 L F
.904 .562 .385 r
.38983 .47191 m .38786 .46874 L .38513 .47006 L F
.707 .661 .802 r
.38835 .46598 m .38786 .46874 L .39067 .46518 L F
.719 .766 .89 r
.38654 .46462 m .39067 .46518 L .38835 .46598 L F
.751 .731 .834 r
.38654 .46462 m .38786 .46874 L .39067 .46518 L F
.886 .989 .798 r
.54591 .44765 m .54748 .44638 L .54718 .44435 L F
.961 .627 .307 r
.598 .40345 m .60006 .40739 L .59869 .40614 L F
.994 .765 .476 r
.59869 .40614 m .60006 .40739 L .59982 .41015 L F
.669 .539 .697 r
.48056 .50459 m .48433 .50453 L .48338 .50098 L F
.556 .353 .561 r
.48182 .50797 m .48433 .50453 L .48056 .50459 L F
.652 .576 .757 r
.48193 .49411 m .48417 .49099 L .48158 .49179 L F
.48193 .49411 m .48552 .49484 L .48417 .49099 L F
.613 .399 .567 r
.3248 .59556 m .32502 .59853 L .32179 .59854 L F
0 0 0 r
.32179 .59854 m .32294 .59771 L .3248 .59556 L F
0 0 .006 r
.3248 .59556 m .32669 .59469 L .32735 .59288 L F
.72 .556 .667 r
.32294 .59771 m .32669 .59469 L .3248 .59556 L F
.718 .684 .816 r
.62046 .41637 m .62399 .41662 L .62307 .4131 L F
.569 .559 .803 r
.62399 .41662 m .6261 .41219 L .62307 .4131 L F
.62399 .41662 m .62679 .41671 L .6261 .41219 L F
0 0 0 r
.41833 .48743 m .4206 .48567 L .42032 .48532 L F
.826 .965 .896 r
.46644 .43743 m .46377 .43999 L .46429 .43726 L F
.782 .931 .931 r
.46429 .43726 m .46377 .43999 L .46236 .439 L F
.024 0 .146 r
.39857 .48416 m .40059 .4834 L .40189 .48228 L F
.427 0 0 r
.40189 .48228 m .40059 .4834 L .40319 .48322 L F
.232 0 .28 r
.40189 .48228 m .40319 .48322 L .40412 .48123 L F
.107 0 0 r
.5381 .46087 m .54099 .46019 L .54214 .45872 L F
.667 .289 .321 r
.54099 .46019 m .54495 .4579 L .54214 .45872 L F
.645 .965 .901 r
.35606 .52041 m .35449 .52026 L .35362 .52161 L F
.725 .987 .887 r
.35529 .51972 m .35606 .52041 L .3586 .51964 L F
.35529 .51972 m .35449 .52026 L .35606 .52041 L F
.585 .454 .669 r
.35606 .52041 m .35913 .52369 L .3586 .51964 L F
.35606 .52041 m .35667 .52442 L .35913 .52369 L F
.847 .601 .059 r
.40739 .56847 m .40657 .5649 L .40723 .56634 L F
0 .49 .841 r
.57072 .38159 m .56913 .3817 L .56778 .38155 L F
.57072 .38159 m .5725 .38266 L .56913 .3817 L F
.843 .526 .452 r
.43054 .58178 m .43395 .58285 L .43323 .58536 L F
.257 0 .254 r
.43323 .58536 m .43395 .58285 L .43626 .58175 L F
0 0 0 r
.22647 .54302 m .22683 .54346 L .22844 .5409 L F
0 0 .309 r
.22647 .54302 m .22723 .54578 L .22683 .54346 L F
.719 .248 .129 r
.71897 .3229 m .72205 .32465 L .71972 .32431 L F
.828 .603 .599 r
.72124 .3219 m .72205 .32465 L .71897 .3229 L F
0 0 .059 r
.48633 .54917 m .4856 .55158 L .48406 .55324 L F
0 0 .192 r
.4856 .55158 m .48434 .55527 L .48406 .55324 L F
.842 .888 .873 r
.54261 .40532 m .54695 .40385 L .54514 .4022 L F
.984 .907 .617 r
.59361 .43996 m .59424 .4354 L .59221 .43894 L F
.957 .733 .557 r
.59164 .44156 m .59361 .43996 L .59221 .43894 L F
.59164 .44156 m .59338 .44245 L .59361 .43996 L F
.315 .78 .653 r
.64275 .33174 m .64482 .33073 L .64594 .32941 L F
.64275 .33174 m .64229 .33194 L .64482 .33073 L F
.672 .561 .721 r
.43834 .52705 m .44232 .52742 L .44088 .52461 L F
0 0 0 r
.68619 .34241 m .68293 .34524 L .68487 .34428 L F
.68781 .3409 m .68912 .33929 L .68619 .34241 L F
.68781 .3409 m .68619 .34241 L .68487 .34428 L F
.992 .835 .584 r
.58752 .42453 m .58986 .42181 L .58733 .422 L F
.58752 .42453 m .58878 .42584 L .58986 .42181 L F
.47 .464 .769 r
.329 .52097 m .33186 .52037 L .33032 .51658 L F
.467 .279 .541 r
.34887 .61194 m .34879 .6147 L .35121 .61412 L F
.34887 .61194 m .34879 .6147 L .35121 .61412 L F
.392 .168 .45 r
.69133 .29023 m .69434 .28903 L .69411 .28653 L F
.502 .245 .457 r
.69411 .28653 m .69741 .2883 L .69733 .28541 L F
.69411 .28653 m .69434 .28903 L .69741 .2883 L F
.856 .454 .276 r
.36502 .51422 m .36655 .51712 L .36881 .51773 L F
.9 .585 .442 r
.36655 .51712 m .36897 .52008 L .36881 .51773 L F
.718 .497 .589 r
.47476 .48102 m .47884 .47872 L .47523 .47848 L F
.47476 .48102 m .47872 .4814 L .47884 .47872 L F
.723 .587 .702 r
.47872 .4814 m .4814 .47793 L .47884 .47872 L F
.764 .994 .869 r
.64341 .33996 m .64212 .34239 L .64414 .34063 L F
.73 .961 .942 r
.64124 .34159 m .64212 .34239 L .64341 .33996 L F
.772 .643 .72 r
.71612 .30719 m .71612 .30977 L .71216 .30915 L F
.773 .64 .714 r
.71216 .30915 m .71612 .30977 L .71271 .30994 L F
.706 .589 .723 r
.71865 .30603 m .71612 .30977 L .71612 .30719 L F
.572 .711 .936 r
.35045 .54609 m .35448 .54696 L .35174 .54782 L F
.35045 .54609 m .35448 .54696 L .35174 .54782 L F
.824 .606 .607 r
.35176 .51445 m .34897 .51451 L .34906 .51072 L F
.718 .302 .257 r
.35176 .51445 m .34979 .5162 L .34897 .51451 L F
.721 .306 .26 r
.35176 .51445 m .35395 .51674 L .34979 .5162 L F
.603 .944 .933 r
.62869 .36121 m .62796 .36066 L .62635 .36228 L F
.667 .511 .664 r
.32979 .63163 m .32649 .63459 L .32575 .63099 L F
.644 .569 .756 r
.48126 .47306 m .48266 .4683 L .4799 .46895 L F
.48126 .47306 m .48395 .47229 L .48266 .4683 L F
.066 0 .257 r
.49755 .5232 m .49599 .52434 L .4981 .52084 L F
.194 0 .331 r
.49755 .5232 m .4952 .52665 L .49599 .52434 L F
.779 .921 .932 r
.55519 .39239 m .5513 .39328 L .55366 .3904 L F
.515 .03 .042 r
.55519 .39239 m .55367 .39433 L .5513 .39328 L F
.894 .835 .781 r
.55557 .39165 m .55519 .39239 L .55366 .3904 L F
.419 .295 .604 r
.55541 .39671 m .5577 .39588 L .55519 .39239 L F
.706 .217 0 r
.55519 .39239 m .55611 .39447 L .55367 .39433 L F
.55519 .39239 m .5577 .39588 L .55611 .39447 L F
.187 0 .181 r
.56753 .47118 m .56836 .46926 L .57059 .46821 L F
.716 .588 .711 r
.27206 .63166 m .27455 .62818 L .26927 .62973 L F
.828 .365 .112 r
.36101 .51074 m .36294 .51364 L .36502 .51422 L F
.872 .449 .206 r
.3635 .51554 m .36502 .51422 L .36294 .51364 L F
.3635 .51554 m .36655 .51712 L .36502 .51422 L F
.093 .562 .907 r
.23708 .58439 m .23971 .58572 L .2384 .58559 L F
.21 0 .317 r
.6914 .29247 m .69434 .28903 L .69133 .29023 L F
.334 .81 .747 r
.63414 .33673 m .6353 .33602 L .63677 .33556 L F
.63414 .33673 m .63272 .33706 L .6353 .33602 L F
.789 .482 .47 r
.38009 .60271 m .37661 .60453 L .37652 .60161 L F
.38009 .60271 m .3812 .60518 L .37661 .60453 L F
.486 .154 .329 r
.25446 .58779 m .2536 .59085 L .25334 .59072 L F
.034 .373 .84 r
.25334 .59072 m .2536 .59085 L .25356 .59079 L F
.687 .19 .06 r
.25103 .59 m .25245 .58919 L .25334 .59072 L F
.486 .154 .329 r
.25446 .58779 m .25334 .59072 L .25245 .58919 L F
.034 .373 .84 r
.25334 .59072 m .25356 .59079 L .2513 .58776 L F
.687 .19 .06 r
.24833 .59154 m .25103 .59 L .25334 .59072 L F
.541 .497 .756 r
.25446 .58779 m .25245 .58919 L .25154 .58556 L F
.943 .943 .756 r
.61464 .3603 m .61765 .35768 L .617 .35697 L F
.61464 .3603 m .61546 .36168 L .61765 .35768 L F
.81 .997 .857 r
.617 .35697 m .61765 .35768 L .62069 .35495 L F
0 0 0 r
.65234 .39335 m .65589 .39086 L .65476 .39212 L F
.65476 .39212 m .65589 .39086 L .65806 .38953 L F
.773 .69 .772 r
.54645 .46253 m .54685 .46521 L .54386 .46598 L F
.67 .619 .789 r
.54963 .46171 m .54685 .46521 L .54645 .46253 L F
.627 .893 .987 r
.44559 .44613 m .44488 .44817 L .44316 .44714 L F
.44559 .44613 m .45049 .44672 L .44488 .44817 L F
.513 .913 .896 r
.72048 .29881 m .71733 .29996 L .72004 .29861 L F
.585 .037 0 r
.72133 .30315 m .71733 .29996 L .72048 .29881 L F
.043 .598 .822 r
.72004 .29861 m .72341 .29897 L .72048 .29881 L F
.531 .456 .716 r
.72432 .29884 m .72133 .30315 L .72048 .29881 L F
.72432 .29884 m .72048 .29881 L .72341 .29897 L F
.716 .588 .711 r
.27206 .63166 m .26927 .62973 L .27017 .63057 L F
0 0 0 r
.23139 .53766 m .23027 .53946 L .23316 .53647 L F
0 0 .014 r
.43282 .55805 m .43293 .55802 L .43301 .55532 L F
.886 .482 .046 r
.43282 .55805 m .43413 .56194 L .43388 .56171 L F
.4328 .56009 m .43388 .56171 L .4328 .56072 L F
.43282 .55805 m .43388 .56171 L .4328 .56009 L F
.767 .521 .562 r
.43293 .55802 m .43185 .55864 L .43076 .55665 L F
.43185 .55864 m .42857 .56052 L .43065 .55683 L F
.43185 .55864 m .43065 .55683 L .43076 .55665 L F
.886 .482 .046 r
.43282 .55805 m .4328 .56072 L .43293 .55802 L F
.863 .712 .694 r
.43852 .56194 m .44023 .56358 L .43919 .55982 L F
.43852 .56194 m .44023 .56358 L .43919 .55982 L F
1 .815 .497 r
.39367 .57885 m .3942 .57597 L .393 .57485 L F
0 0 0 r
.44979 .59564 m .4538 .59496 L .45235 .59542 L F
.227 0 0 r
.4538 .59496 m .4564 .59499 L .45235 .59542 L F
.588 .889 .99 r
.61175 .34548 m .60893 .34662 L .60701 .34525 L F
.442 .851 .966 r
.23708 .61176 m .23444 .61162 L .23524 .60828 L F
.872 .759 .735 r
.23444 .61162 m .23708 .61176 L .23524 .60828 L F
0 0 .158 r
.23781 .61306 m .23677 .61474 L .23708 .61176 L F
.23781 .61306 m .23708 .61176 L .23444 .61162 L F
.877 .485 .022 r
.72931 .29346 m .72811 .29325 L .72856 .29205 L F
.72931 .29346 m .73014 .29569 L .72811 .29325 L F
.891 .975 .823 r
.72989 .29031 m .72931 .29346 L .72856 .29205 L F
.72989 .29031 m .73187 .28989 L .72931 .29346 L F
.63 .149 .093 r
.72931 .29346 m .7316 .29564 L .73014 .29569 L F
.64 .632 .827 r
.29454 .50986 m .29324 .51162 L .2916 .5093 L F
.32 .692 .98 r
.29166 .50883 m .29454 .50986 L .2916 .5093 L F
.29166 .50883 m .29406 .50878 L .29454 .50986 L F
.812 .967 .904 r
.29406 .50878 m .29324 .51162 L .29454 .50986 L F
.29406 .50878 m .29057 .51146 L .29324 .51162 L F
0 0 0 r
.22331 .56348 m .22382 .56405 L .2252 .56197 L F
.536 .864 .995 r
.52644 .43936 m .52488 .44083 L .52398 .43846 L F
.52644 .43936 m .5274 .44003 L .52488 .44083 L F
.75 .605 .697 r
.46396 .51497 m .46616 .51413 L .46462 .50917 L F
.749 .604 .696 r
.46341 .5175 m .46616 .51413 L .46396 .51497 L F
.848 .996 .76 r
.32233 .61543 m .31991 .61844 L .31937 .61754 L F
.916 .777 .295 r
.31937 .61754 m .31991 .61844 L .31952 .6211 L F
.947 .906 .524 r
.593 .39131 m .59191 .39233 L .59114 .38984 L F
.593 .39131 m .59215 .39399 L .59191 .39233 L F
.336 .186 .524 r
.33583 .64515 m .33326 .6414 L .33552 .64383 L F
.202 .375 .813 r
.33686 .6432 m .33583 .64515 L .33552 .64383 L F
.268 .46 .864 r
.33686 .6432 m .33889 .64697 L .33583 .64515 L F
.455 0 0 r
.34913 .55488 m .35156 .55528 L .34946 .55418 L F
.552 .491 .74 r
.42864 .58934 m .42538 .58605 L .42659 .58829 L F
.355 .056 .312 r
.42541 .59281 m .42864 .58934 L .42757 .59062 L F
.702 .26 .2 r
.42864 .58934 m .43105 .59173 L .42757 .59062 L F
.012 .217 .726 r
.42956 .58751 m .42864 .58934 L .42659 .58829 L F
.42956 .58751 m .43105 .59173 L .42864 .58934 L F
.434 .677 .966 r
.51304 .43611 m .5102 .43644 L .51133 .43447 L F
.638 .379 .51 r
.5102 .43644 m .51249 .43809 L .51019 .4393 L F
.464 .426 .731 r
.5102 .43644 m .51249 .43809 L .51304 .43611 L F
.638 .379 .51 r
.5102 .43644 m .51249 .43809 L .51019 .4393 L F
.726 .336 .311 r
.35527 .55264 m .35191 .5528 L .35249 .55211 L F
.848 .996 .76 r
.32233 .61543 m .31937 .61754 L .32035 .61529 L F
.604 .629 .849 r
.32233 .61543 m .32306 .6106 L .32136 .61149 L F
.32341 .61528 m .32614 .6149 L .32432 .61236 L F
.459 .819 .996 r
.32233 .61543 m .32313 .61541 L .32614 .6149 L F
.301 .643 .967 r
.32614 .6149 m .32564 .61015 L .32306 .6106 L F
.32614 .6149 m .32578 .61392 L .32564 .61015 L F
.32578 .61392 m .32541 .61288 L .32562 .6104 L F
.32578 .61392 m .32562 .6104 L .32564 .61015 L F
.222 .445 .865 r
.3258 .61424 m .32726 .61659 L .32674 .61383 L F
.455 .82 .995 r
.32313 .61541 m .32341 .61528 L .32357 .61533 L F
.301 .643 .967 r
.32614 .6149 m .32674 .61383 L .32541 .61288 L F
.455 .82 .995 r
.32341 .61528 m .32674 .61383 L .32357 .61533 L F
.32357 .61533 m .32674 .61383 L .32614 .6149 L F
.222 .445 .865 r
.32341 .61528 m .32589 .61613 L .3258 .61424 L F
.32589 .61613 m .32726 .61659 L .3258 .61424 L F
.32313 .61541 m .32336 .61547 L .32341 .61528 L F
.32336 .61547 m .32726 .61659 L .32341 .61528 L F
.604 .629 .849 r
.32233 .61543 m .32341 .61528 L .32306 .6106 L F
.32341 .61528 m .32432 .61236 L .32306 .6106 L F
.514 0 0 r
.32289 .61617 m .32233 .61543 L .32035 .61529 L F
.32289 .61617 m .32575 .61833 L .32233 .61543 L F
.719 .192 0 r
.32575 .61833 m .32313 .61541 L .32233 .61543 L F
.855 .398 .045 r
.35909 .5086 m .35935 .50987 L .36101 .51074 L F
.81 .325 0 r
.361 .51246 m .36101 .51074 L .35935 .50987 L F
.361 .51246 m .36294 .51364 L .36101 .51074 L F
.474 0 0 r
.42061 .50826 m .42296 .50933 L .42377 .50901 L F
.874 .898 .846 r
.72133 .30315 m .71865 .30603 L .71872 .30286 L F
.865 .801 .785 r
.71733 .29996 m .71493 .30333 L .71358 .30141 L F
.781 .527 .552 r
.71956 .29885 m .71983 .30195 L .72004 .29861 L F
.215 0 .295 r
.71733 .29996 m .71833 .30109 L .71493 .30333 L F
.71833 .30109 m .71862 .30142 L .71816 .30166 L F
.71833 .30109 m .71816 .30166 L .71493 .30333 L F
.71862 .30142 m .71862 .30142 L .71493 .30333 L F
.71862 .30142 m .71806 .30189 L .71493 .30333 L F
.707 .593 .726 r
.71865 .30603 m .71493 .30333 L .7181 .30187 L F
.864 .595 .529 r
.7181 .30185 m .71885 .30245 L .71853 .3015 L F
.707 .593 .726 r
.71873 .30247 m .7181 .30187 L .71875 .30157 L F
.71865 .30603 m .7181 .30187 L .71873 .30247 L F
.864 .595 .529 r
.71853 .3015 m .71885 .30245 L .71906 .30176 L F
.874 .898 .846 r
.71906 .30176 m .71885 .30245 L .71875 .30157 L F
.71885 .30245 m .71872 .30286 L .71873 .30247 L F
.71885 .30245 m .71873 .30247 L .71875 .30157 L F
.864 .595 .529 r
.7181 .30185 m .7181 .30187 L .71883 .30245 L F
.874 .898 .846 r
.72133 .30315 m .71872 .30286 L .71885 .30245 L F
.71987 .30225 m .71885 .30245 L .71906 .30176 L F
.72133 .30315 m .71885 .30245 L .71987 .30225 L F
.864 .595 .529 r
.71873 .30247 m .71751 .30388 L .72106 .30471 L F
.7181 .30187 m .71787 .30264 L .71873 .30247 L F
.71787 .30264 m .71751 .30388 L .71873 .30247 L F
.565 .625 .87 r
.72187 .3049 m .7215 .30567 L .7201 .30254 L F
.302 .247 .628 r
.72066 .30381 m .72087 .30381 L .71983 .30195 L F
.864 .595 .529 r
.7191 .30164 m .72071 .30353 L .71983 .30195 L F
.565 .625 .87 r
.7204 .30278 m .7201 .30254 L .71983 .30195 L F
.72187 .3049 m .7201 .30254 L .7204 .30278 L F
.864 .595 .529 r
.72071 .30353 m .72187 .3049 L .71983 .30195 L F
.71885 .30245 m .72114 .30431 L .7191 .30164 L F
.72114 .30431 m .72187 .3049 L .72071 .30353 L F
.302 .247 .628 r
.72114 .30431 m .72087 .30381 L .72066 .30381 L F
.864 .595 .529 r
.72114 .30431 m .72071 .30353 L .7191 .30164 L F
.662 .634 .811 r
.72432 .29884 m .72453 .30309 L .72133 .30315 L F
.302 .247 .628 r
.72087 .30381 m .72431 .30392 L .71983 .30195 L F
.475 .554 .857 r
.71983 .30195 m .72431 .30392 L .72179 .29941 L F
.527 .481 .748 r
.72614 .30315 m .726 .30683 L .72453 .30309 L F
.978 .863 .479 r
.7247 .30735 m .72539 .30965 L .726 .30683 L F
.981 .851 .466 r
.7247 .30735 m .726 .30683 L .72614 .30315 L F
.7247 .30735 m .72614 .30315 L .72764 .30714 L F
.667 .526 .682 r
.7239 .30487 m .72764 .30714 L .7247 .30735 L F
.599 .617 .841 r
.72179 .29941 m .72431 .30392 L .72442 .30014 L F
.97 .845 .662 r
.7247 .30735 m .72451 .30256 L .7239 .30487 L F
.302 .247 .628 r
.72341 .30448 m .72431 .30392 L .72374 .3039 L F
.7215 .30567 m .7239 .30487 L .72431 .30392 L F
.695 .698 .849 r
.72431 .30392 m .7239 .30487 L .72442 .30014 L F
.97 .845 .662 r
.72451 .30256 m .72442 .30014 L .72406 .30334 L F
.72451 .30256 m .72406 .30334 L .7239 .30487 L F
.302 .247 .628 r
.72208 .3053 m .72341 .30448 L .72087 .30381 L F
.72341 .30448 m .72374 .3039 L .72087 .30381 L F
.864 .595 .529 r
.72114 .30431 m .72116 .30433 L .72187 .3049 L F
.302 .247 .628 r
.72208 .3053 m .72087 .30381 L .72114 .30431 L F
.541 .152 .253 r
.72173 .305 m .7215 .30567 L .72187 .3049 L F
.302 .247 .628 r
.7215 .30567 m .72173 .305 L .72066 .30381 L F
.838 .754 .77 r
.72166 .30485 m .72173 .305 L .72187 .3049 L F
.302 .247 .628 r
.72173 .305 m .72175 .30495 L .72166 .30485 L F
.72173 .305 m .72166 .30485 L .72066 .30381 L F
.707 .593 .726 r
.71865 .30603 m .71612 .30719 L .71493 .30333 L F
.838 .754 .77 r
.7165 .30365 m .71775 .30782 L .72173 .305 L F
.7165 .30365 m .72173 .305 L .72166 .30485 L F
.541 .152 .253 r
.71775 .30782 m .7215 .30567 L .72173 .305 L F
.302 .247 .628 r
.7215 .30567 m .72208 .3053 L .72175 .30495 L F
.864 .595 .529 r
.71885 .30245 m .71883 .30245 L .72116 .30433 L F
.71885 .30245 m .72116 .30433 L .72114 .30431 L F
.7181 .30185 m .71883 .30245 L .71885 .30245 L F
.7181 .30187 m .72106 .30471 L .72187 .3049 L F
.71641 .30047 m .7165 .30365 L .71751 .30388 L F
.71641 .30047 m .71751 .30388 L .7181 .30185 L F
.585 .037 0 r
.72133 .30315 m .71918 .30183 L .71733 .29996 L F
.71918 .30183 m .71855 .30134 L .71733 .29996 L F
.781 .527 .552 r
.71641 .30047 m .71862 .30143 L .71956 .29885 L F
.71862 .30143 m .71983 .30195 L .71956 .29885 L F
.215 0 .295 r
.71862 .30142 m .71862 .30142 L .71862 .30142 L F
.71862 .30142 m .71875 .30157 L .71806 .30189 L F
.864 .595 .529 r
.71641 .30047 m .7181 .30185 L .71853 .3015 L F
.585 .037 0 r
.71918 .30183 m .71906 .30176 L .71855 .30134 L F
.71906 .30176 m .71862 .30142 L .71855 .30134 L F
.864 .595 .529 r
.71864 .30143 m .71906 .30176 L .7191 .30164 L F
.71641 .30047 m .71906 .30176 L .71864 .30143 L F
.585 .037 0 r
.71906 .30176 m .71875 .30157 L .71862 .30142 L F
.542 .492 .749 r
.34625 .57196 m .34684 .57557 L .34438 .57616 L F
.895 .473 .143 r
.34677 .57847 m .34342 .57356 L .34438 .57616 L F
.472 .304 .57 r
.34441 .57906 m .34677 .57847 L .34438 .57616 L F
.315 .79 .702 r
.43025 .451 m .43219 .45033 L .42849 .45183 L F
.363 .821 .72 r
.43454 .44922 m .43219 .45033 L .43025 .451 L F
.533 .603 .869 r
.61879 .39543 m .61627 .39639 L .61506 .39402 L F
.672 .21 .146 r
.61879 .39543 m .61506 .39402 L .61627 .39639 L F
.364 0 0 r
.61831 .34976 m .61432 .35116 L .61493 .35112 L F
.61666 .3506 m .61493 .35112 L .61574 .35106 L F
.779 .749 .825 r
.61664 .35044 m .61676 .35056 L .61691 .35052 L F
.61664 .35044 m .61692 .35439 L .62069 .35495 L F
.67 .666 .838 r
.61574 .35106 m .61692 .35439 L .61664 .35044 L F
.636 .866 .985 r
.61831 .34976 m .61664 .35044 L .61949 .35133 L F
.67 .666 .838 r
.61574 .35106 m .61664 .35044 L .61831 .34976 L F
.364 0 0 r
.61831 .34976 m .61493 .35112 L .61666 .3506 L F
.779 .749 .825 r
.61691 .35052 m .62069 .35495 L .61949 .35133 L F
.61676 .35056 m .62069 .35495 L .61691 .35052 L F
.81 .997 .857 r
.617 .35697 m .62069 .35495 L .61692 .35439 L F
.865 .801 .785 r
.71733 .29996 m .71358 .30141 L .71641 .30047 L F
.781 .527 .552 r
.71641 .30047 m .72004 .29861 L .71733 .29996 L F
.965 .672 .426 r
.38831 .55557 m .39017 .55936 L .39032 .55667 L F
.79 .431 .376 r
.43966 .46123 m .43571 .45887 L .43729 .45918 L F
.847 .566 .512 r
.42403 .58888 m .4201 .59087 L .42006 .58872 L F
.42403 .58888 m .42398 .59111 L .4201 .59087 L F
0 0 0 r
.42321 .55514 m .42463 .55418 L .4231 .55557 L F
.675 .906 .568 r
.42454 .55387 m .42463 .55418 L .42676 .55126 L F
.4231 .55557 m .42676 .55126 L .42439 .55371 L F
.802 .311 0 r
.42676 .55126 m .42731 .5537 L .42439 .55371 L F
.227 .623 .955 r
.42504 .55326 m .42471 .55349 L .42731 .5537 L F
.42471 .55349 m .42439 .55371 L .42461 .55371 L F
.42471 .55349 m .42461 .55371 L .42731 .5537 L F
.675 .906 .568 r
.4231 .55557 m .42426 .55451 L .42454 .55387 L F
.42426 .55451 m .42463 .55418 L .42454 .55387 L F
0 .138 .682 r
.24063 .61782 m .24261 .62212 L .24292 .62017 L F
0 .188 .719 r
.24292 .62017 m .24261 .62212 L .24464 .62375 L F
.707 .604 .738 r
.33231 .50844 m .33476 .51273 L .33678 .51111 L F
.629 .465 .641 r
.33476 .51273 m .33401 .51557 L .33678 .51111 L F
.719 .192 0 r
.32575 .61833 m .32625 .61824 L .32313 .61541 L F
.222 .445 .865 r
.32313 .61541 m .32625 .61824 L .32726 .61659 L F
.306 0 .009 r
.55309 .47824 m .55198 .4802 L .54929 .48067 L F
0 0 0 r
.55387 .47869 m .55309 .47824 L .55556 .47731 L F
.55387 .47869 m .55198 .4802 L .55309 .47824 L F
.66119 .37566 m .66262 .37481 L .65894 .37695 L F
.66119 .37566 m .65894 .37695 L .65862 .37663 L F
.91 .932 .56 r
.34086 .53099 m .33945 .53406 L .33971 .53214 L F
0 .051 .612 r
.34194 .53133 m .34288 .53285 L .34086 .53099 L F
.34194 .53133 m .34086 .53099 L .33971 .53214 L F
.596 .543 .766 r
.36926 .61303 m .36757 .61696 L .36533 .61128 L F
.78 .96 .646 r
.3764 .49115 m .37378 .49475 L .37441 .49282 L F
.78 .961 .649 r
.37441 .49282 m .37378 .49475 L .37195 .49613 L F
.536 .841 .999 r
.33784 .54227 m .33533 .54291 L .33759 .54416 L F
.94 .579 .285 r
.37286 .52605 m .37501 .52927 L .37428 .52743 L F
.723 .875 .467 r
.23278 .60065 m .23213 .60218 L .2341 .59877 L F
0 .123 .644 r
.23278 .60065 m .23384 .60428 L .23213 .60218 L F
0 0 0 r
.41868 .58436 m .42144 .58226 L .41903 .58167 L F
.41868 .58436 m .42289 .58342 L .42144 .58226 L F
.757 .621 .708 r
.71493 .30333 m .71612 .30719 L .71248 .30641 L F
.772 .643 .72 r
.71612 .30719 m .71216 .30915 L .71248 .30641 L F
.724 .582 .696 r
.44088 .52461 m .44232 .52742 L .44476 .52379 L F
.795 .741 .803 r
.51249 .43809 m .51429 .43977 L .51019 .4393 L F
.728 .72 .843 r
.51304 .43611 m .51429 .43977 L .51802 .43672 L F
.912 .961 .636 r
.51682 .43896 m .51802 .43672 L .51429 .43977 L F
.573 .629 .868 r
.51682 .43896 m .51429 .43977 L .51304 .43611 L F
.704 .668 .812 r
.54962 .40062 m .5536 .4011 L .55207 .39904 L F
.534 .001 0 r
.28217 .65625 m .28403 .65768 L .28246 .65641 L F
.265 .339 .753 r
.28403 .65768 m .28558 .65583 L .28246 .65641 L F
.28403 .65768 m .28658 .65903 L .28558 .65583 L F
.758 .888 .481 r
.23458 .59713 m .23278 .60065 L .2341 .59877 L F
.72 .641 .77 r
.5536 .4011 m .55655 .40071 L .55541 .39671 L F
.488 .499 .795 r
.5536 .4011 m .55701 .4031 L .55655 .40071 L F
.548 .556 .814 r
.55655 .40071 m .5577 .39588 L .55541 .39671 L F
.55655 .40071 m .55923 .40006 L .5577 .39588 L F
.538 .923 .906 r
.43965 .44789 m .43846 .44925 L .43698 .44869 L F
.43965 .44789 m .44102 .44803 L .43846 .44925 L F
.897 .944 .831 r
.61464 .3603 m .61303 .3646 L .61546 .36168 L F
.968 .788 .605 r
.58728 .41067 m .58817 .40692 L .58662 .40516 L F
.896 .902 .491 r
.5507 .46609 m .55063 .46843 L .55162 .46572 L F
.944 .924 .562 r
.55063 .46843 m .55162 .46572 L .55294 .46654 L F
.896 .902 .491 r
.5507 .46609 m .55162 .46572 L .55294 .46654 L F
.474 .348 .628 r
.37185 .56328 m .37221 .56607 L .37456 .56539 L F
.97 .674 .273 r
.43245 .53939 m .43346 .54192 L .43361 .54017 L F
.936 .958 .758 r
.43486 .53547 m .43245 .53939 L .43361 .54017 L F
.564 .888 .624 r
.6197 .42685 m .61665 .42954 L .61982 .42863 L F
.626 .561 .762 r
.6197 .42685 m .62351 .42656 L .62181 .42217 L F
.698 .564 .7 r
.61982 .42863 m .62351 .42656 L .6197 .42685 L F
.455 .816 .996 r
.29977 .65745 m .30044 .65608 L .29959 .6562 L F
.419 .552 .883 r
.29794 .65577 m .29985 .65799 L .29977 .65745 L F
.846 .889 .462 r
.2987 .65422 m .29794 .65577 L .29977 .65745 L F
.768 .467 .477 r
.2987 .65422 m .29977 .65745 L .29579 .65666 L F
.455 .816 .996 r
.29977 .65745 m .29959 .6562 L .29795 .65644 L F
.419 .552 .883 r
.29985 .65799 m .30164 .66008 L .29977 .65745 L F
.563 .686 .922 r
.29977 .65745 m .30164 .66008 L .30398 .65932 L F
.727 .662 .786 r
.47927 .51135 m .47867 .51405 L .48182 .51068 L F
.223 0 .293 r
.47867 .51405 m .47999 .51439 L .48182 .51068 L F
.525 .532 .804 r
.47949 .51638 m .47999 .51439 L .47867 .51405 L F
.16 .7 .796 r
.26788 .52175 m .26551 .52172 L .26324 .522 L F
.411 .86 .887 r
.26817 .52083 m .26788 .52175 L .26957 .52149 L F
.26817 .52083 m .26551 .52172 L .26788 .52175 L F
0 0 0 r
.64594 .32941 m .6474 .3296 L .64837 .32807 L F
.64594 .32941 m .64482 .33073 L .6474 .3296 L F
.82 .708 .741 r
.5466 .43532 m .54791 .43675 L .54959 .43257 L F
.632 .888 .987 r
.54959 .43257 m .55271 .43146 L .55095 .43051 L F
.837 .999 .796 r
.37923 .62031 m .38153 .61924 L .38273 .61764 L F
.714 .961 .944 r
.45368 .47004 m .45458 .46822 L .45186 .4693 L F
.45368 .47004 m .45602 .46866 L .45458 .46822 L F
.91 .542 .321 r
.39272 .52325 m .38995 .51979 L .3921 .52131 L F
.724 .753 .875 r
.56438 .40758 m .56653 .40428 L .56377 .40562 L F
.335 0 0 r
.56677 .40839 m .56438 .40758 L .56412 .40938 L F
0 0 .452 r
.42551 .58425 m .42659 .58829 L .42538 .58605 L F
.386 0 0 r
.2935 .64152 m .29232 .6411 L .28833 .64396 L F
.612 .495 .696 r
.48338 .50098 m .48676 .50126 L .48582 .49767 L F
.577 .482 .71 r
.48338 .50098 m .48703 .50397 L .48676 .50126 L F
.48338 .50098 m .48433 .50453 L .48703 .50397 L F
.506 .601 .882 r
.36228 .62736 m .3635 .62493 L .36081 .62516 L F
.36228 .62736 m .36489 .6274 L .3635 .62493 L F
.387 0 0 r
.3631 .62933 m .36228 .62736 L .36094 .63001 L F
.3631 .62933 m .36489 .6274 L .36228 .62736 L F
.075 0 .324 r
.47632 .53069 m .47837 .52957 L .47869 .52687 L F
.695 .854 .439 r
.47635 .53328 m .47837 .52957 L .47632 .53069 L F
.603 .819 .421 r
.33597 .63104 m .33801 .62806 L .33834 .63126 L F
0 0 .501 r
.33728 .63347 m .33597 .63104 L .33834 .63126 L F
.33728 .63347 m .33676 .63414 L .33597 .63104 L F
.629 .548 .744 r
.44846 .49765 m .45025 .50173 L .45199 .49966 L F
.984 .705 .394 r
.27267 .63721 m .27304 .64075 L .27157 .63697 L F
.293 .718 .971 r
.27399 .63643 m .27267 .63721 L .27157 .63697 L F
.27399 .63643 m .27629 .63756 L .27267 .63721 L F
.796 .581 .611 r
.34906 .51072 m .34578 .51348 L .3463 .50959 L F
.34906 .51072 m .34897 .51451 L .34578 .51348 L F
.892 .78 .287 r
.38004 .60719 m .37979 .61247 L .37818 .61096 L F
.978 .772 .56 r
.37818 .61096 m .37979 .61247 L .37779 .61381 L F
.179 .031 .43 r
.49085 .53623 m .49072 .53907 L .48824 .54009 L F
.045 0 .205 r
.49072 .53907 m .48841 .54222 L .48824 .54009 L F
.946 .659 .462 r
.38139 .53917 m .3836 .54312 L .38317 .54084 L F
.855 .997 .808 r
.43182 .47581 m .43192 .47395 L .43316 .47384 L F
.943 .799 .672 r
.43182 .47581 m .42903 .47687 L .43192 .47395 L F
.43182 .47581 m .43081 .47822 L .42903 .47687 L F
.651 .943 .96 r
.35363 .5217 m .35362 .52161 L .35449 .52026 L F
.869 .765 .745 r
.44164 .50028 m .44356 .50165 L .44582 .49816 L F
.694 .566 .706 r
.44843 .49492 m .44582 .49816 L .44846 .49765 L F
.568 .082 0 r
.5766 .38575 m .57821 .38747 L .57728 .38645 L F
0 0 .474 r
.5766 .38575 m .5785 .39007 L .57821 .38747 L F
.774 .69 .77 r
.26962 .57881 m .27395 .57956 L .27217 .57554 L F
.743 .676 .786 r
.27217 .57554 m .27395 .57956 L .27638 .57659 L F
.57 .423 .642 r
.27395 .57956 m .27664 .58144 L .27638 .57659 L F
0 0 0 r
.45864 .56563 m .45888 .56509 L .45722 .56647 L F
0 0 .549 r
.45722 .56647 m .4587 .56744 L .45864 .56563 L F
.45722 .56647 m .45835 .56917 L .4587 .56744 L F
.712 .577 .701 r
.31134 .56931 m .30985 .57273 L .31341 .57207 L F
0 0 0 r
.31079 .57159 m .30985 .57273 L .31134 .56931 L F
.31079 .57159 m .31134 .56931 L .31104 .56845 L F
.606 .553 .769 r
.31341 .57207 m .31496 .56722 L .31134 .56931 L F
.447 .461 .78 r
.22172 .57318 m .22438 .57321 L .22251 .56865 L F
.491 .42 .705 r
.42347 .56795 m .425 .57249 L .42381 .56995 L F
.878 .853 .815 r
.57377 .42204 m .57309 .42672 L .57129 .42547 L F
.967 .716 .504 r
.57129 .42547 m .57309 .42672 L .57293 .4292 L F
.744 .704 .813 r
.54347 .43594 m .54791 .43675 L .5466 .43532 L F
.769 .647 .728 r
.39835 .48725 m .39635 .49119 L .40033 .4914 L F
.817 .608 .62 r
.39635 .49119 m .39741 .49202 L .40033 .4914 L F
.617 .306 .421 r
.39741 .49202 m .40305 .49128 L .40033 .4914 L F
.86 .969 .65 r
.43626 .5334 m .43486 .53547 L .43664 .53364 L F
.881 .858 .815 r
.55374 .41981 m .55128 .42337 L .54977 .42134 L F
.627 .318 .427 r
.30985 .57273 m .31191 .57506 L .31341 .57207 L F
.606 .553 .769 r
.31341 .57207 m .31594 .57256 L .31496 .56722 L F
.71 .411 .47 r
.31341 .57207 m .31587 .57515 L .31594 .57256 L F
.31341 .57207 m .31191 .57506 L .31587 .57515 L F
.274 0 .008 r
.25169 .52695 m .24826 .52816 L .24905 .52714 L F
.311 .41 .802 r
.33429 .64109 m .33552 .64383 L .33326 .6414 L F
.533 .518 .785 r
.52247 .41439 m .52407 .41278 L .52238 .41388 L F
.051 0 .172 r
.52198 .41582 m .52238 .41388 L .52407 .41278 L F
0 0 0 r
.64178 .39025 m .63928 .39144 L .63833 .39251 L F
.371 0 0 r
.25019 .52085 m .25303 .52088 L .25395 .51975 L F
.17 0 0 r
.25303 .52088 m .25604 .51964 L .25395 .51975 L F
.633 .639 .838 r
.35943 .61802 m .35693 .62101 L .35657 .61851 L F
.29 .051 .368 r
.54154 .42667 m .54368 .42587 L .54418 .42303 L F
.155 0 .268 r
.54418 .42303 m .54646 .42241 L .5458 .42108 L F
.783 .538 .566 r
.54867 .42658 m .54464 .42869 L .54368 .42587 L F
.778 .936 .582 r
.5453 .42361 m .54274 .42763 L .54448 .42448 L F
0 0 .143 r
.54418 .42303 m .5453 .42361 L .54643 .42241 L F
.54418 .42303 m .54368 .42587 L .5453 .42361 L F
.778 .936 .582 r
.5453 .42361 m .54448 .42448 L .54559 .42247 L F
0 0 .143 r
.54643 .42241 m .5453 .42361 L .54646 .42241 L F
.599 .422 .613 r
.35943 .61477 m .35657 .61851 L .35657 .61515 L F
.152 .279 .741 r
.43603 .47161 m .4385 .47358 L .43731 .47554 L F
.523 .769 .987 r
.4385 .47358 m .44026 .47545 L .43731 .47554 L F
.836 .864 .865 r
.5835 .37051 m .58 .37131 L .58261 .37011 L F
.686 .975 .909 r
.5835 .37051 m .58536 .36806 L .58689 .36814 L F
.5835 .37051 m .58261 .37011 L .58536 .36806 L F
.297 0 0 r
.3281 .49638 m .33224 .49529 L .32997 .4947 L F
.113 .596 .911 r
.22895 .57189 m .22871 .57266 L .22762 .57149 L F
.22895 .57189 m .2309 .57293 L .22871 .57266 L F
.432 .198 .456 r
.32111 .64101 m .32501 .63742 L .32351 .64074 L F
.315 .258 .633 r
.32369 .64277 m .32111 .64101 L .32351 .64074 L F
.32369 .64277 m .32204 .64447 L .32111 .64101 L F
.888 .662 .143 r
.58622 .40332 m .58613 .40057 L .58562 .39926 L F
.732 .707 .827 r
.41271 .59627 m .41604 .59769 L .4169 .59595 L F
.41271 .59627 m .4169 .59595 L .41492 .59469 L F
.373 .426 .787 r
.41779 .59423 m .41604 .59769 L .41586 .59765 L F
.687 .363 .422 r
.4169 .59595 m .41872 .59859 L .4205 .59638 L F
.373 .426 .787 r
.41779 .59423 m .41872 .59859 L .41604 .59769 L F
.41 0 0 r
.41604 .59769 m .41728 .59909 L .41586 .59765 L F
.41604 .59769 m .41872 .59859 L .41728 .59909 L F
.562 .216 .34 r
.34968 .5696 m .34793 .57209 L .34625 .57196 L F
.315 .79 .702 r
.43025 .451 m .42849 .45183 L .42778 .45216 L F
0 0 .039 r
.35419 .60481 m .35319 .60728 L .35384 .6051 L F
.009 0 .086 r
.35319 .60728 m .35583 .6043 L .35384 .6051 L F
.941 .858 .429 r
.33247 .61759 m .33305 .61872 L .33344 .61598 L F
.536 .244 .418 r
.33305 .61872 m .33578 .61829 L .33467 .61802 L F
.537 .247 .422 r
.3353 .62065 m .33578 .61829 L .33305 .61872 L F
0 .128 .648 r
.3353 .62065 m .33305 .61872 L .33247 .61759 L F
.725 .435 .487 r
.60381 .37348 m .60733 .37363 L .60784 .37165 L F
.935 .933 .774 r
.60682 .37074 m .60784 .37165 L .60897 .36821 L F
.429 .204 .469 r
.60733 .37363 m .6097 .37016 L .60784 .37165 L F
.448 .095 .273 r
.51663 .49848 m .51902 .4999 L .5163 .50036 L F
.51663 .49848 m .51989 .49751 L .51902 .4999 L F
.226 .179 .594 r
.25597 .6216 m .25792 .62396 L .25827 .62148 L F
.25609 .62244 m .25649 .62515 L .25792 .62396 L F
.882 .933 .849 r
.25564 .62415 m .25792 .62396 L .25529 .62688 L F
.603 .061 0 r
.26015 .62582 m .25792 .62396 L .25564 .62415 L F
.26071 .62603 m .25792 .62396 L .26015 .62582 L F
.226 .179 .594 r
.25597 .6216 m .25609 .62244 L .25792 .62396 L F
.817 .739 .778 r
.57524 .36792 m .57696 .37217 L .57452 .3703 L F
.923 .702 .585 r
.57696 .37217 m .57434 .37283 L .57452 .3703 L F
.57696 .37217 m .57647 .37571 L .57434 .37283 L F
.438 .532 .856 r
.57863 .36919 m .57696 .37217 L .57524 .36792 L F
.561 .689 .925 r
.57863 .36919 m .58 .37131 L .57696 .37217 L F
.779 .455 .44 r
.3544 .62439 m .3585 .62416 L .35722 .62709 L F
.584 .091 .051 r
.3585 .62416 m .35975 .62632 L .35722 .62709 L F
.3585 .62416 m .36081 .62516 L .35975 .62632 L F
.879 .871 .428 r
.39262 .59559 m .39145 .59751 L .39165 .59818 L F
.994 .765 .402 r
.39153 .5945 m .39145 .59751 L .39262 .59559 L F
.964 .637 .322 r
.34377 .63757 m .34554 .64125 L .3413 .64104 L F
.469 .309 .581 r
.34751 .64353 m .34519 .64407 L .34554 .64125 L F
.664 .325 .39 r
.34554 .64125 m .34845 .64161 L .34751 .64353 L F
.707 .604 .738 r
.33231 .50844 m .33678 .51111 L .33582 .50917 L F
0 .057 .617 r
.33678 .51111 m .33626 .50934 L .33582 .50917 L F
.85 .651 .111 r
.33678 .51111 m .33668 .51232 L .33626 .50934 L F
.87 .651 .121 r
.33678 .51111 m .33686 .51405 L .33668 .51232 L F
.757 .464 .488 r
.34138 .51408 m .33686 .51405 L .33678 .51111 L F
.407 .043 .232 r
.36273 .59401 m .36087 .59248 L .36461 .59201 L F
.424 .786 .996 r
.36461 .59201 m .36627 .59092 L .36531 .59054 L F
.781 .664 .734 r
.36531 .59054 m .36273 .59401 L .36461 .59201 L F
.423 .784 .996 r
.36778 .59177 m .36627 .59092 L .36461 .59201 L F
.881 .448 .14 r
.58231 .38146 m .58124 .38241 L .58034 .38031 L F
.648 .112 0 r
.58231 .38146 m .58493 .38341 L .58124 .38241 L F
.429 0 0 r
.58634 .38444 m .58493 .38341 L .58231 .38146 L F
.389 .279 .607 r
.56378 .44886 m .56418 .45224 L .56626 .4512 L F
.56378 .44886 m .56418 .45224 L .56626 .4512 L F
.208 0 0 r
.4564 .59499 m .46014 .59504 L .45918 .5956 L F
.135 0 0 r
.46014 .59504 m .46333 .5948 L .45918 .5956 L F
0 0 .516 r
.35671 .60209 m .35792 .60103 L .35758 .60119 L F
0 0 0 r
.35671 .60209 m .35656 .6033 L .35792 .60103 L F
.35671 .60209 m .35583 .6043 L .35656 .6033 L F
.093 0 0 r
.73386 .31145 m .73607 .31158 L .73258 .3115 L F
.631 .207 .22 r
.63007 .38618 m .63147 .38346 L .63004 .38358 L F
.62929 .38572 m .63004 .38358 L .6262 .38389 L F
.63007 .38618 m .63004 .38358 L .62929 .38572 L F
0 .24 .671 r
.62798 .38449 m .6262 .38389 L .62535 .38225 L F
.993 .813 .557 r
.6262 .38389 m .62673 .38434 L .62565 .38699 L F
.854 .81 .806 r
.62646 .38987 m .62915 .38769 L .62767 .38744 L F
.62638 .38946 m .62767 .38744 L .62595 .38715 L F
.62646 .38987 m .62767 .38744 L .62638 .38946 L F
.449 0 0 r
.62595 .38715 m .62767 .38744 L .62821 .38803 L F
.62767 .38744 m .62915 .38769 L .62821 .38803 L F
.975 .765 .342 r
.62821 .38803 m .62859 .38739 L .62884 .38571 L F
.62821 .38803 m .62852 .38792 L .62859 .38739 L F
.62821 .38803 m .62884 .38571 L .62876 .38555 L F
.62852 .38792 m .62915 .38769 L .62911 .38623 L F
.62852 .38792 m .62911 .38623 L .62909 .38555 L F
.62889 .38538 m .62909 .38555 L .62906 .38419 L F
0 .24 .671 r
.62852 .38508 m .62881 .38532 L .6262 .38389 L F
.62881 .38532 m .62929 .38572 L .62804 .38498 L F
.62881 .38532 m .62804 .38498 L .6262 .38389 L F
.975 .765 .342 r
.62821 .38803 m .6287 .38583 L .62907 .38544 L F
.631 .207 .22 r
.63075 .38615 m .63147 .38346 L .63007 .38618 L F
.21 0 .099 r
.63324 .38328 m .63147 .38346 L .63075 .38615 L F
.63324 .38328 m .63075 .38615 L .63148 .38548 L F
.755 .563 .637 r
.63005 .38617 m .63247 .386 L .62909 .38555 L F
.63247 .386 m .63376 .38591 L .63205 .38578 L F
.63247 .386 m .63205 .38578 L .62909 .38555 L F
.21 0 .099 r
.63324 .38328 m .63148 .38548 L .62906 .38419 L F
.755 .563 .637 r
.62915 .38769 m .63355 .38599 L .62911 .38623 L F
.63355 .38599 m .63376 .38591 L .62911 .38623 L F
.21 0 .099 r
.63148 .38548 m .63075 .38615 L .63065 .38652 L F
.755 .563 .637 r
.62909 .38555 m .63122 .38572 L .62906 .38419 L F
.631 .207 .22 r
.63065 .38652 m .63075 .38615 L .63007 .38618 L F
.21 0 .099 r
.63148 .38548 m .63065 .38652 L .62906 .38419 L F
.755 .563 .637 r
.63122 .38572 m .63376 .38591 L .6318 .38519 L F
.63122 .38572 m .6318 .38519 L .62906 .38419 L F
0 .24 .671 r
.62921 .38563 m .63007 .38618 L .62929 .38572 L F
.755 .563 .637 r
.62911 .38623 m .63005 .38617 L .62909 .38555 L F
.21 0 .099 r
.63324 .38328 m .62906 .38419 L .63376 .38591 L F
.852 .399 .008 r
.62906 .38419 m .63065 .38652 L .62921 .3855 L F
.975 .765 .342 r
.62907 .38544 m .62918 .38523 L .62919 .38531 L F
.62898 .38539 m .62906 .38419 L .62997 .38384 L F
.62876 .38555 m .62884 .38571 L .62906 .38419 L F
.6287 .38583 m .62881 .38532 L .62898 .38539 L F
.62881 .38532 m .62906 .38419 L .62898 .38539 L F
0 .24 .671 r
.62889 .38527 m .62902 .38541 L .62852 .38508 L F
.62902 .38541 m .62929 .38572 L .62881 .38532 L F
.62902 .38541 m .62881 .38532 L .62852 .38508 L F
.852 .399 .008 r
.62906 .38419 m .62921 .3855 L .62889 .38527 L F
.975 .765 .342 r
.62919 .38531 m .62997 .38384 L .63092 .38347 L F
.62918 .38523 m .62997 .38384 L .62919 .38531 L F
.62852 .38792 m .62909 .38555 L .62889 .38538 L F
.6287 .38583 m .62898 .38539 L .62907 .38544 L F
.62898 .38539 m .62997 .38384 L .62907 .38544 L F
0 .24 .671 r
.62915 .38547 m .63065 .38652 L .63007 .38618 L F
.975 .765 .342 r
.62961 .38568 m .62907 .38544 L .63092 .38347 L F
0 .24 .671 r
.62889 .38527 m .62921 .3855 L .62915 .38547 L F
.62921 .3855 m .63065 .38652 L .62915 .38547 L F
.62889 .38527 m .63007 .38618 L .62921 .38563 L F
.975 .765 .342 r
.62821 .38803 m .62907 .38544 L .62961 .38568 L F
0 .26 .765 r
.62627 .38194 m .62889 .38527 L .62535 .38225 L F
.555 .427 .66 r
.62595 .38715 m .62624 .38248 L .62414 .38316 L F
.62624 .38248 m .62627 .38194 L .62594 .38213 L F
.62624 .38248 m .62594 .38213 L .62414 .38316 L F
0 .24 .671 r
.62841 .38486 m .62822 .38478 L .62798 .38449 L F
.62822 .38478 m .6262 .38389 L .62798 .38449 L F
.62889 .38527 m .62852 .38508 L .62841 .38486 L F
.62852 .38508 m .6262 .38389 L .62841 .38486 L F
.731 .204 0 r
.60401 .42148 m .60308 .42186 L .60395 .42043 L F
.60401 .42148 m .60457 .42242 L .60308 .42186 L F
.576 .724 .943 r
.61404 .41594 m .61593 .41558 L .61563 .41275 L F
.492 .685 .952 r
.61404 .41594 m .6179 .41687 L .61593 .41558 L F
0 0 .361 r
.70165 .29974 m .70018 .29904 L .70173 .29707 L F
.70117 .29951 m .7009 .30454 L .70018 .29904 L F
.70165 .29974 m .70131 .30189 L .70117 .29951 L F
.70131 .30189 m .7009 .30454 L .70117 .29951 L F
.739 .571 .665 r
.70312 .30376 m .70282 .30669 L .70153 .30556 L F
0 0 .361 r
.7009 .30454 m .7008 .30517 L .70075 .30466 L F
.7009 .30454 m .70075 .30466 L .70018 .29904 L F
.575 .597 .838 r
.70131 .30189 m .70028 .30458 L .7008 .30517 L F
.70165 .29974 m .70095 .30221 L .70131 .30189 L F
.70095 .30221 m .70028 .30458 L .70131 .30189 L F
.70165 .29974 m .70312 .30376 L .70028 .30458 L F
.739 .571 .665 r
.70115 .30433 m .70013 .30434 L .70028 .30458 L F
.70144 .30409 m .70013 .30434 L .70115 .30433 L F
.70144 .30409 m .70153 .30556 L .70013 .30434 L F
.70312 .30376 m .70144 .30409 L .70115 .30433 L F
.70312 .30376 m .70153 .30556 L .70144 .30409 L F
.876 .843 .808 r
.46556 .55668 m .46352 .56006 L .46132 .55826 L F
.785 .785 .285 r
.46352 .56006 m .463 .56076 L .46132 .55826 L F
.46352 .56006 m .46276 .56268 L .463 .56076 L F
.597 .638 .862 r
.34101 .51592 m .33822 .51757 L .33686 .51405 L F
.423 .273 .572 r
.34101 .51592 m .34055 .51961 L .33822 .51757 L F
.484 .269 .511 r
.33822 .51757 m .34055 .51961 L .33804 .5202 L F
.72 .6 .722 r
.30779 .57233 m .30985 .57273 L .31079 .57159 L F
.30779 .57233 m .31191 .57506 L .30985 .57273 L F
0 0 0 r
.56379 .47322 m .56528 .4721 L .56753 .47118 L F
.808 .963 .643 r
.40662 .45902 m .40467 .46148 L .40483 .46029 L F
.809 .62 .646 r
.40662 .45902 m .40851 .46371 L .40467 .46148 L F
.715 .657 .79 r
.40932 .45617 m .40662 .45902 L .40518 .45514 L F
.693 .566 .708 r
.41067 .46223 m .40851 .46371 L .40662 .45902 L F
.658 .671 .851 r
.47218 .48143 m .47616 .48398 L .47476 .48102 L F
.705 .641 .783 r
.47476 .48102 m .47616 .48398 L .47872 .4814 L F
.645 .54 .721 r
.44846 .49765 m .451 .49407 L .44843 .49492 L F
.881 .858 .815 r
.55374 .41981 m .54977 .42134 L .55203 .42086 L F
.763 .996 .83 r
.55636 .4175 m .55374 .41981 L .55495 .41743 L F
.753 .965 .677 r
.55374 .41981 m .55203 .42086 L .55495 .41743 L F
.861 .797 .787 r
.59298 .44815 m .59395 .45229 L .59651 .44878 L F
0 0 0 r
.55846 .46225 m .55523 .46359 L .55768 .46308 L F
0 0 .23 r
.5611 .45674 m .55846 .46225 L .56084 .46034 L F
0 0 0 r
.56084 .46034 m .55846 .46225 L .55768 .46308 L F
.761 .781 .87 r
.6179 .41687 m .62046 .41637 L .61908 .41326 L F
.783 .791 .859 r
.61908 .41326 m .62046 .41637 L .62307 .4131 L F
.14 0 .296 r
.49994 .51966 m .4981 .52084 L .5004 .51733 L F
.228 .015 .368 r
.49994 .51966 m .49755 .5232 L .4981 .52084 L F
.661 .424 .55 r
.42459 .52681 m .42738 .52412 L .42288 .52325 L F
.42459 .52681 m .42717 .52697 L .42738 .52412 L F
.871 .614 .547 r
.42738 .52412 m .42717 .52697 L .42894 .52718 L F
.761 .518 .566 r
.33124 .58928 m .33382 .59205 L .33294 .58961 L F
.33124 .58928 m .33004 .59197 L .33382 .59205 L F
.808 .886 .901 r
.44105 .46682 m .44535 .46557 L .4437 .46436 L F
.518 .817 .999 r
.4437 .46436 m .44585 .46358 L .44535 .46557 L F
.421 .302 .612 r
.44585 .46358 m .4437 .46436 L .44535 .46557 L F
.555 .464 .706 r
.54368 .42587 m .54189 .42931 L .54154 .42667 L F
0 0 .385 r
.54154 .42667 m .54274 .42763 L .54368 .42587 L F
.54154 .42667 m .54189 .42931 L .54274 .42763 L F
.79 .527 .54 r
.58347 .35457 m .57965 .35691 L .58257 .35379 L F
.752 .97 .928 r
.58347 .35457 m .58493 .35193 L .58639 .35299 L F
.58347 .35457 m .58257 .35379 L .58493 .35193 L F
.645 .54 .721 r
.44846 .49765 m .45244 .49784 L .451 .49407 L F
.629 .548 .744 r
.44846 .49765 m .45199 .49966 L .45244 .49784 L F
.828 .537 .497 r
.4126 .48442 m .4137 .48838 L .41635 .48823 L F
.566 .384 .594 r
.41406 .48806 m .4137 .48838 L .4126 .48442 L F
.41406 .48806 m .4126 .48442 L .41128 .48487 L F
.143 .417 .86 r
.58754 .38642 m .58493 .38341 L .58634 .38444 L F
.526 .92 .878 r
.65406 .33576 m .65194 .3359 L .64973 .33708 L F
.605 .94 .751 r
.65598 .33413 m .65568 .33395 L .65406 .33576 L F
.614 .956 .886 r
.65568 .33395 m .65194 .3359 L .65406 .33576 L F
.834 .998 .782 r
.69037 .33752 m .68912 .33929 L .69002 .3367 L F
.823 .963 .637 r
.69002 .3367 m .68912 .33929 L .68781 .3409 L F
.075 .518 .9 r
.62091 .36494 m .61993 .36582 L .61835 .36473 L F
.62091 .36494 m .62268 .36644 L .61993 .36582 L F
.779 .737 .814 r
.42076 .59491 m .4205 .59638 L .41966 .5955 L F
.967 .832 .659 r
.4205 .59638 m .41872 .59859 L .41966 .5955 L F
.966 .723 .52 r
.44916 .47403 m .45088 .47788 L .45113 .47508 L F
.783 .538 .566 r
.54867 .42658 m .54873 .42925 L .54464 .42869 L F
.906 .849 .776 r
.6141 .43294 m .61665 .42954 L .61461 .42818 L F
.732 .801 .322 r
.57158 .46358 m .571 .46564 L .57242 .46183 L F
.045 .125 .624 r
.35477 .53559 m .35567 .53976 L .35433 .53691 L F
.828 .603 .599 r
.72124 .3219 m .72323 .3257 L .72205 .32465 L F
.77 .924 .938 r
.24957 .56721 m .25087 .56789 L .25354 .56599 L F
.565 .098 .103 r
.63063 .4165 m .63017 .41838 L .62679 .41671 L F
0 0 0 r
.63063 .4165 m .63275 .41222 L .63256 .41485 L F
.63256 .41485 m .63017 .41838 L .63063 .4165 L F
.39 .522 .87 r
.33467 .61802 m .33578 .61829 L .33738 .61702 L F
.886 .991 .783 r
.46834 .5511 m .47069 .55025 L .46813 .55355 L F
0 0 .49 r
.47014 .54758 m .47004 .54753 L .47069 .55025 L F
0 0 0 r
.46834 .5511 m .47014 .54758 L .47069 .55025 L F
.46834 .5511 m .47049 .54777 L .47014 .54758 L F
.47049 .54777 m .4706 .5476 L .47014 .54758 L F
0 0 .49 r
.47014 .54758 m .46971 .54611 L .47004 .54753 L F
.738 .982 .91 r
.33896 .57451 m .33819 .57707 L .34074 .57476 L F
.505 .91 .872 r
.34095 .57376 m .33896 .57451 L .34074 .57476 L F
.358 .089 .362 r
.28363 .57626 m .28286 .57862 L .28061 .5793 L F
.548 .373 .597 r
.28286 .57862 m .2803 .58196 L .28061 .5793 L F
.131 .195 .663 r
.70856 .28989 m .7108 .29131 L .71068 .28879 L F
.553 .858 .997 r
.60229 .38305 m .59994 .38426 L .60426 .38398 L F
.558 .107 .136 r
.59994 .38426 m .60243 .38588 L .60426 .38398 L F
.77 .952 .627 r
.60426 .38398 m .60482 .38234 L .60229 .38305 L F
.675 .248 .225 r
.60243 .38588 m .6069 .38494 L .60426 .38398 L F
.682 .282 .281 r
.6069 .38494 m .60678 .38457 L .60426 .38398 L F
.112 0 .097 r
.4692 .59199 m .47222 .58899 L .47154 .59139 L F
0 0 .027 r
.47222 .58899 m .4748 .58569 L .47432 .5879 L F
0 0 .031 r
.47154 .59139 m .47222 .58899 L .47432 .5879 L F
.483 .794 .999 r
.62676 .39311 m .62935 .39386 L .62818 .39278 L F
.709 .866 .956 r
.62935 .39386 m .63068 .39106 L .62818 .39278 L F
.62935 .39386 m .63197 .39257 L .63068 .39106 L F
.715 .189 0 r
.57897 .37763 m .57719 .37661 L .57647 .37571 L F
.828 .378 0 r
.57897 .37763 m .57887 .37907 L .57719 .37661 L F
.57897 .37763 m .58034 .38031 L .57887 .37907 L F
.718 .446 .513 r
.47037 .52308 m .47407 .52258 L .47373 .52458 L F
.47037 .52308 m .47373 .52458 L .47203 .52459 L F
.785 .854 .902 r
.47258 .52459 m .47436 .52232 L .47203 .52459 L F
.47373 .52458 m .47402 .52353 L .47258 .52459 L F
.47402 .52353 m .47436 .52232 L .47258 .52459 L F
0 0 .287 r
.47725 .52056 m .47407 .52258 L .47558 .5224 L F
.47701 .52136 m .47558 .5224 L .47674 .52226 L F
.47725 .52056 m .47558 .5224 L .47701 .52136 L F
.481 .357 .635 r
.47725 .52056 m .47974 .51988 L .47949 .51638 L F
.668 .373 .465 r
.47674 .52226 m .47974 .51988 L .47725 .52056 L F
.935 .674 .518 r
.47407 .52258 m .47585 .52413 L .47373 .52458 L F
.788 .991 .884 r
.47373 .52458 m .47585 .52413 L .47634 .52258 L F
.789 .671 .733 r
.71493 .30333 m .71055 .30513 L .71358 .30141 L F
.71493 .30333 m .71248 .30641 L .71055 .30513 L F
0 0 0 r
.24332 .54726 m .2409 .5489 L .23964 .54948 L F
.24495 .54646 m .2409 .5489 L .24332 .54726 L F
.819 .553 .538 r
.27923 .57732 m .28363 .57626 L .27918 .57613 L F
.27923 .57732 m .28286 .57862 L .28363 .57626 L F
.212 0 .293 r
.28546 .57532 m .28286 .57862 L .28363 .57626 L F
.28363 .57626 m .28286 .57862 L .28546 .57532 L F
.469 .289 .553 r
.56854 .44279 m .56896 .44536 L .57157 .44462 L F
.131 .613 .917 r
.56854 .44279 m .57157 .44462 L .56896 .44536 L F
.021 0 .282 r
.22659 .54999 m .22797 .55142 L .22803 .54837 L F
.22659 .54999 m .22603 .55277 L .22797 .55142 L F
.843 .481 .367 r
.40851 .46371 m .40636 .46409 L .40467 .46148 L F
.805 .945 .594 r
.4035 .47246 m .4035 .47185 L .40565 .4691 L F
.457 .097 .266 r
.40565 .4691 m .40863 .47043 L .4076 .46791 L F
.40565 .4691 m .4035 .47185 L .40863 .47043 L F
.431 0 0 r
.55749 .40499 m .56023 .40593 L .55687 .40551 L F
.646 .903 .983 r
.44955 .44477 m .45049 .44672 L .44559 .44613 L F
.44955 .44477 m .45168 .44567 L .45049 .44672 L F
0 0 0 r
.22844 .5409 m .22859 .54123 L .23027 .53946 L F
.22844 .5409 m .22683 .54346 L .22859 .54123 L F
.542 .779 .986 r
.55382 .41152 m .55247 .41368 L .55107 .41225 L F
.55382 .41152 m .55247 .41368 L .55107 .41225 L F
.773 .637 .077 r
.22656 .55908 m .2265 .55545 L .22542 .55666 L F
0 0 0 r
.22511 .55988 m .22627 .55844 L .22641 .55837 L F
0 0 .195 r
.22641 .55837 m .22736 .55706 L .2276 .55402 L F
0 0 0 r
.22627 .55844 m .22736 .55706 L .22641 .55837 L F
.773 .637 .077 r
.22655 .55831 m .22641 .55837 L .2265 .55545 L F
.22656 .55908 m .22641 .55837 L .22655 .55831 L F
.899 .982 .708 r
.2252 .56197 m .22641 .55837 L .22656 .55908 L F
.744 .726 .835 r
.29836 .65014 m .2987 .65422 L .2977 .65409 L F
.768 .467 .477 r
.2987 .65422 m .29579 .65666 L .2977 .65409 L F
.71 .701 .839 r
.30249 .65125 m .2987 .65422 L .29836 .65014 L F
.085 0 0 r
.60903 .36681 m .61303 .3646 L .61195 .36375 L F
.897 .944 .831 r
.61464 .3603 m .61195 .36375 L .61303 .3646 L F
.971 .693 .444 r
.32179 .59854 m .31987 .60035 L .32094 .59866 L F
.421 .866 .814 r
.32179 .59854 m .32094 .59866 L .32294 .59771 L F
.847 .556 .497 r
.46868 .51388 m .46913 .51731 L .47074 .5143 L F
.556 .353 .561 r
.48182 .50797 m .4843 .5076 L .48433 .50453 L F
.467 .251 .501 r
.4843 .5076 m .48703 .50397 L .48433 .50453 L F
.841 .911 .884 r
.60259 .35229 m .6039 .35405 L .60622 .35132 L F
.44 .737 .99 r
.25242 .58366 m .25154 .58556 L .25181 .58449 L F
.25242 .58366 m .25353 .58505 L .25154 .58556 L F
.541 .497 .756 r
.25446 .58779 m .25154 .58556 L .25353 .58505 L F
.619 .947 .762 r
.63214 .35861 m .63038 .35927 L .62869 .36121 L F
.619 .951 .929 r
.63038 .35927 m .62796 .36066 L .62869 .36121 L F
.229 .749 .792 r
.31784 .65805 m .32153 .65744 L .31987 .65849 L F
.421 .142 .382 r
.32153 .65744 m .3189 .66004 L .32136 .65914 L F
.698 .333 .353 r
.32136 .65914 m .32413 .65937 L .32153 .65744 L F
0 .272 .764 r
.32153 .65744 m .32184 .6568 L .31987 .65849 L F
.32153 .65744 m .32413 .65937 L .32184 .6568 L F
.76 .99 .773 r
.63275 .41222 m .63594 .40989 L .63564 .40949 L F
0 0 0 r
.63594 .40989 m .63816 .40606 L .63564 .40949 L F
.705 .741 .231 r
.62268 .36644 m .62126 .37133 L .62412 .36804 L F
.684 .303 .319 r
.34845 .64161 m .3517 .64208 L .35016 .64086 L F
.713 .647 .782 r
.44408 .45997 m .4407 .46299 L .44559 .46276 L F
.565 .131 .174 r
.4407 .46299 m .4437 .46436 L .44559 .46276 L F
.623 .48 .667 r
.48298 .4844 m .48569 .48137 L .48283 .48189 L F
.48298 .4844 m .48627 .48523 L .48569 .48137 L F
.617 .531 .735 r
.48417 .48832 m .48627 .48523 L .48298 .4844 L F
.508 .344 .594 r
.48552 .49484 m .48777 .49136 L .48417 .49099 L F
.48552 .49484 m .48825 .4943 L .48777 .49136 L F
.615 .473 .666 r
.48552 .49484 m .4888 .49683 L .48825 .4943 L F
.48552 .49484 m .48582 .49767 L .4888 .49683 L F
.941 .578 .276 r
.39081 .56445 m .39205 .56301 L .39054 .56186 L F
.39081 .56445 m .39257 .56543 L .39205 .56301 L F
.918 .651 .159 r
.58805 .41378 m .58728 .41067 L .58744 .41182 L F
.916 .768 .683 r
.58566 .41561 m .58805 .41378 L .58744 .41182 L F
.58566 .41561 m .58737 .4166 L .58805 .41378 L F
.678 .963 .742 r
.6644 .37305 m .66262 .37481 L .66416 .37268 L F
.661 .936 .665 r
.66416 .37268 m .66262 .37481 L .66119 .37566 L F
.068 0 0 r
.68581 .37415 m .6857 .37458 L .68272 .3754 L F
0 0 0 r
.68581 .37415 m .68819 .37334 L .6857 .37458 L F
.351 .812 .928 r
.41572 .50833 m .4184 .50778 L .42061 .50826 L F
0 .5 .813 r
.4184 .50778 m .42296 .50933 L .42061 .50826 L F
.873 .801 .775 r
.62351 .42656 m .62493 .42574 L .62607 .42355 L F
.843 .695 .698 r
.62493 .42574 m .62326 .42935 L .62351 .42656 L F
.873 .801 .775 r
.62607 .42355 m .62493 .42574 L .62351 .42656 L F
.843 .695 .698 r
.62351 .42656 m .62326 .42935 L .62493 .42574 L F
0 0 .319 r
.48042 .56828 m .48048 .57118 L .47919 .57281 L F
0 0 0 r
.47919 .57281 m .47968 .57368 L .4788 .57542 L F
.47919 .57281 m .48048 .57118 L .47968 .57368 L F
.873 .801 .775 r
.62351 .42656 m .62607 .42355 L .62452 .42214 L F
.577 .791 .98 r
.62731 .42143 m .62607 .42355 L .62452 .42214 L F
.62731 .42143 m .62607 .42355 L .62452 .42214 L F
0 0 0 r
.4748 .58569 m .47697 .58166 L .47641 .58433 L F
.47432 .5879 m .4748 .58569 L .47641 .58433 L F
.757 .697 .156 r
.69995 .35844 m .70057 .35339 L .70009 .35561 L F
.901 .897 .482 r
.69896 .36074 m .69995 .35844 L .70009 .35561 L F
.954 .722 .266 r
.52318 .43668 m .52399 .43623 L .52243 .43456 L F
.52318 .43668 m .52398 .43846 L .52399 .43623 L F
.885 .942 .846 r
.61734 .37375 m .62126 .37133 L .61994 .37275 L F
.705 .741 .231 r
.62268 .36644 m .62182 .36919 L .62126 .37133 L F
0 0 0 r
.62244 .37167 m .62126 .37133 L .62182 .36919 L F
.476 0 0 r
.62386 .37329 m .62126 .37133 L .62205 .37477 L F
0 0 0 r
.62244 .37167 m .61994 .37275 L .62126 .37133 L F
.876 .993 .794 r
.46562 .55449 m .46813 .55355 L .46556 .55668 L F
.883 .991 .791 r
.46562 .55449 m .46834 .5511 L .46813 .55355 L F
.743 .715 .826 r
.44099 .48184 m .44568 .48294 L .44407 .48085 L F
.573 .594 .836 r
.44568 .48294 m .44719 .47972 L .44407 .48085 L F
.44568 .48294 m .44816 .48211 L .44719 .47972 L F
.644 .486 .654 r
.48158 .49179 m .48417 .49099 L .48417 .48832 L F
.617 .531 .735 r
.48417 .48832 m .48695 .4877 L .48627 .48523 L F
.596 .447 .65 r
.48417 .48832 m .48417 .49099 L .48695 .4877 L F
.628 .962 .863 r
.36633 .63713 m .37064 .63467 L .36879 .63503 L F
.906 .976 .798 r
.36879 .63503 m .37064 .63467 L .37021 .63199 L F
.37 0 0 r
.43294 .46057 m .43061 .45981 L .43319 .45861 L F
.43294 .46057 m .42915 .46104 L .43061 .45981 L F
.527 .86 .995 r
.59821 .35188 m .59677 .35356 L .59931 .35298 L F
.47 .813 .998 r
.60259 .35229 m .59821 .35188 L .59931 .35298 L F
.914 .928 .551 r
.47635 .53328 m .47509 .53702 L .47495 .53484 L F
.978 .717 .467 r
.47509 .53702 m .47288 .53857 L .47495 .53484 L F
.47509 .53702 m .47486 .53972 L .47288 .53857 L F
.837 .384 .137 r
.35545 .50636 m .35935 .50987 L .35909 .5086 L F
.906 .977 .794 r
.54786 .47149 m .55063 .46843 L .54831 .46886 L F
.69 .472 .587 r
.54786 .47149 m .55085 .47126 L .55063 .46843 L F
.875 .989 .818 r
.54831 .46886 m .55063 .46843 L .5507 .46609 L F
.944 .924 .562 r
.55063 .46843 m .55294 .46654 L .55378 .46801 L F
.606 .302 .428 r
.55406 .47055 m .55063 .46843 L .55085 .47126 L F
.55406 .47055 m .55378 .46801 L .55063 .46843 L F
.549 .889 .984 r
.4701 .46946 m .47189 .46838 L .46926 .46895 L F
.883 .504 .316 r
.42717 .52697 m .4291 .52927 L .42894 .52718 L F
.413 0 0 r
.59215 .39399 m .59318 .39479 L .59191 .39233 L F
.59215 .39399 m .59497 .39574 L .59318 .39479 L F
.486 .896 .92 r
.4668 .48706 m .46539 .48685 L .463 .48785 L F
.686 .677 .835 r
.4668 .48706 m .47028 .48547 L .46547 .48447 L F
.793 .298 .007 r
.24712 .54501 m .24722 .54648 L .24495 .54646 L F
.24712 .54501 m .24928 .54702 L .24722 .54648 L F
.702 .669 .814 r
.6731 .35914 m .67556 .35802 L .67252 .35775 L F
.825 .961 .631 r
.32433 .61999 m .32625 .61824 L .32575 .61833 L F
.665 .912 .592 r
.32726 .61659 m .32625 .61824 L .32433 .61999 L F
.527 .86 .995 r
.59821 .35188 m .59552 .35269 L .59677 .35356 L F
0 0 .137 r
.43537 .59696 m .43666 .59532 L .4384 .59667 L F
.43537 .59696 m .43649 .59417 L .43666 .59532 L F
.516 .258 .463 r
.52276 .49466 m .52243 .4971 L .51989 .49751 L F
.35 .056 .317 r
.52546 .49405 m .52243 .4971 L .52276 .49466 L F
.183 0 0 r
.23416 .55906 m .23236 .55876 L .23476 .55641 L F
.23416 .55906 m .23042 .55867 L .23236 .55876 L F
.37 0 0 r
.25849 .51901 m .26035 .51941 L .26361 .51677 L F
.143 0 0 r
.26035 .51941 m .26588 .51632 L .26361 .51677 L F
.867 .541 .026 r
.59588 .39731 m .59642 .3997 L .59497 .39574 L F
.427 .455 .787 r
.44925 .46867 m .45053 .47122 L .44776 .47017 L F
.44925 .46867 m .45186 .4693 L .45053 .47122 L F
.44925 .46867 m .45163 .46682 L .45186 .4693 L F
.038 0 0 r
.31651 .54136 m .31596 .54052 L .31771 .54084 L F
.105 0 0 r
.31858 .54035 m .31771 .54084 L .31596 .54052 L F
.499 .329 .581 r
.7271 .29899 m .72453 .30309 L .72432 .29884 L F
.72736 .30008 m .72786 .30221 L .72659 .30255 L F
.527 .481 .748 r
.72614 .30315 m .72453 .30309 L .72786 .30221 L F
0 0 0 r
.7306 .29912 m .72786 .30221 L .72736 .30008 L F
.72748 .29901 m .72736 .30008 L .7271 .29899 L F
.7306 .29912 m .72736 .30008 L .72748 .29901 L F
.309 .143 .487 r
.72965 .30076 m .72985 .30316 L .727 .30315 L F
.72705 .30267 m .727 .30315 L .72641 .30315 L F
.72965 .30076 m .727 .30315 L .72705 .30267 L F
.72648 .30291 m .72641 .30315 L .72614 .30315 L F
0 0 0 r
.72993 .29988 m .72965 .30076 L .72786 .30221 L F
.7306 .29912 m .72965 .30076 L .72993 .29988 L F
.927 .649 .169 r
.72965 .30076 m .72985 .30316 L .72941 .30148 L F
.309 .143 .487 r
.72965 .30076 m .72614 .30315 L .72786 .30221 L F
.72965 .30076 m .72641 .30315 L .72648 .30291 L F
.927 .649 .169 r
.72965 .30076 m .72941 .30148 L .72899 .2999 L F
.603 .462 .663 r
.73014 .29569 m .7306 .29912 L .7271 .29899 L F
.927 .649 .169 r
.72965 .30076 m .72899 .2999 L .72873 .29893 L F
.499 .329 .581 r
.7271 .29899 m .72736 .30008 L .72453 .30309 L F
.72736 .30008 m .72659 .30255 L .72453 .30309 L F
.083 0 0 r
.41221 .49042 m .41635 .48823 L .4137 .48838 L F
.41221 .49042 m .41473 .48972 L .41635 .48823 L F
.79 .483 .47 r
.41473 .48972 m .41833 .48743 L .41635 .48823 L F
.714 .921 .963 r
.45469 .44286 m .45398 .44526 L .45294 .44468 L F
.45469 .44286 m .45745 .44327 L .45398 .44526 L F
.728 .538 .634 r
.34593 .53217 m .35008 .52962 L .3474 .52997 L F
.747 .577 .665 r
.36211 .61132 m .36146 .61457 L .35943 .61477 L F
.602 .546 .765 r
.36533 .61128 m .36146 .61457 L .36211 .61132 L F
.936 .678 .203 r
.33317 .51387 m .33406 .51704 L .33401 .51557 L F
.7 .984 .844 r
.31796 .56422 m .31411 .5667 L .31577 .56475 L F
0 0 0 r
.53861 .44584 m .53597 .44661 L .534 .44772 L F
.76 .661 .753 r
.52488 .44771 m .52594 .45033 L .52633 .44922 L F
.48 .065 .173 r
.52895 .45042 m .52633 .44922 L .52594 .45033 L F
.52895 .45042 m .52825 .44958 L .52633 .44922 L F
.603 .563 .782 r
.43766 .50788 m .43866 .5034 L .4365 .50464 L F
.43766 .50788 m .44063 .5075 L .43866 .5034 L F
.585 .432 .64 r
.43766 .50788 m .43793 .5108 L .44063 .5075 L F
.43766 .50788 m .43793 .5108 L .44063 .5075 L F
0 0 0 r
.52143 .42035 m .52213 .41871 L .52128 .42059 L F
.973 .73 .51 r
.52285 .41702 m .52213 .41871 L .52359 .41805 L F
.52359 .41805 m .52198 .41582 L .52586 .41654 L F
.52359 .41805 m .52213 .41871 L .52198 .41582 L F
0 0 0 r
.52347 .41711 m .52213 .41871 L .52143 .42035 L F
.973 .73 .51 r
.52198 .41582 m .52213 .41871 L .52285 .41702 L F
0 0 .19 r
.24826 .52816 m .24766 .53197 L .24547 .53339 L F
.274 0 .008 r
.25169 .52695 m .25031 .52893 L .24826 .52816 L F
.172 0 .254 r
.24966 .53093 m .24826 .52816 L .25031 .52893 L F
.24966 .53093 m .24766 .53197 L .24826 .52816 L F
.623 .121 0 r
.60641 .42609 m .60846 .42861 L .60708 .42737 L F
.738 .982 .91 r
.33896 .57451 m .33559 .57743 L .33819 .57707 L F
.68 .592 .751 r
.42996 .50465 m .43361 .5055 L .43293 .50422 L F
0 0 0 r
.66722 .3837 m .67028 .38065 L .66973 .38263 L F
.197 0 0 r
.67028 .38065 m .67224 .38152 L .66973 .38263 L F
.67028 .38065 m .67315 .38001 L .67224 .38152 L F
.421 .175 .434 r
.59842 .36135 m .59574 .36456 L .59832 .364 L F
.59842 .36135 m .59574 .36456 L .59832 .364 L F
.503 .232 .436 r
.60199 .36072 m .59832 .364 L .59842 .36135 L F
0 0 .255 r
.59842 .36135 m .60019 .36186 L .60199 .36072 L F
.503 .232 .436 r
.60199 .36072 m .60154 .36331 L .59832 .364 L F
.60199 .36072 m .60154 .36331 L .59832 .364 L F
.508 .244 .449 r
.59832 .364 m .60154 .36331 L .59842 .36135 L F
0 0 .255 r
.59842 .36135 m .59832 .364 L .60019 .36186 L F
.331 0 0 r
.60947 .38565 m .60678 .38457 L .6069 .38494 L F
.335 .116 .426 r
.23677 .55549 m .23476 .55641 L .23728 .55299 L F
0 0 0 r
.23677 .55549 m .23416 .55906 L .23476 .55641 L F
.247 .751 .888 r
.37756 .49056 m .37895 .49085 L .3764 .49115 L F
.37756 .49056 m .3764 .49115 L .37441 .49282 L F
.591 .383 .568 r
.5375 .48495 m .53758 .4879 L .53485 .48786 L F
.485 .301 .556 r
.5402 .48716 m .5375 .48495 L .54012 .48438 L F
.5402 .48716 m .53758 .4879 L .5375 .48495 L F
.3 0 0 r
.4341 .5784 m .432 .57766 L .43085 .57767 L F
.684 .303 .319 r
.34845 .64161 m .35016 .64086 L .34751 .64353 L F
.982 .728 .47 r
.35419 .60481 m .35175 .60647 L .35319 .60728 L F
.746 .831 .373 r
.35582 .60069 m .35419 .60481 L .35226 .60118 L F
.35582 .60069 m .35437 .60357 L .35419 .60481 L F
.723 .611 .732 r
.35437 .60357 m .35175 .60647 L .35419 .60481 L F
.973 .697 .446 r
.41607 .49355 m .41785 .49725 L .4168 .49517 L F
.475 .896 .863 r
.55636 .4175 m .5573 .41624 L .55783 .41726 L F
.55636 .4175 m .55495 .41743 L .5573 .41624 L F
0 0 0 r
.44419 .58421 m .44533 .58424 L .4474 .58486 L F
.44419 .58421 m .44361 .58612 L .44533 .58424 L F
.51 .896 .955 r
.64604 .33895 m .64414 .34063 L .64734 .33823 L F
.64604 .33895 m .64341 .33996 L .64414 .34063 L F
.748 .399 .392 r
.30021 .57526 m .29662 .57522 L .29757 .57507 L F
.30021 .57526 m .29863 .57585 L .29662 .57522 L F
.598 .156 .172 r
.30021 .57526 m .30291 .57582 L .29863 .57585 L F
.74 .89 .948 r
.46082 .46432 m .46568 .46326 L .46393 .4619 L F
.814 .915 .907 r
.46568 .46326 m .46629 .46038 L .46393 .4619 L F
.46568 .46326 m .46766 .46157 L .46629 .46038 L F
0 0 0 r
.68561 .34398 m .68293 .34524 L .6827 .34698 L F
.68561 .34398 m .68487 .34428 L .68293 .34524 L F
.946 .597 .313 r
.6927 .32567 m .69136 .32686 L .69097 .32443 L F
.6927 .32567 m .69315 .32822 L .69136 .32686 L F
.697 .618 .764 r
.43985 .45847 m .4407 .46299 L .44408 .45997 L F
.537 .248 .423 r
.4407 .46299 m .44108 .46523 L .4437 .46436 L F
.876 .496 .318 r
.72323 .3257 m .72207 .32756 L .72205 .32465 L F
.58 .127 .141 r
.72574 .32707 m .72207 .32756 L .72323 .3257 L F
.744 .94 .949 r
.35843 .64461 m .36185 .64373 L .36099 .64361 L F
0 0 0 r
.36185 .64373 m .36278 .64259 L .36099 .64361 L F
.36185 .64373 m .3645 .64075 L .36278 .64259 L F
.628 .962 .863 r
.36633 .63713 m .36879 .63503 L .36558 .63666 L F
.594 .779 .968 r
.36493 .54051 m .3674 .54065 L .36365 .53812 L F
.672 .319 .368 r
.36493 .54051 m .36612 .54255 L .3674 .54065 L F
.596 .779 .968 r
.36365 .53812 m .3674 .54065 L .36887 .53936 L F
.401 .019 .194 r
.3674 .54065 m .36875 .54205 L .36887 .53936 L F
.3674 .54065 m .36612 .54255 L .36875 .54205 L F
0 0 0 r
.46561 .59447 m .4692 .59199 L .46812 .5935 L F
.46812 .5935 m .4692 .59199 L .47154 .59139 L F
.619 .495 .689 r
.62351 .42656 m .62326 .42935 L .62064 .43048 L F
.667 .629 .802 r
.62064 .43048 m .62326 .42935 L .61982 .42863 L F
0 0 0 r
.23216 .59445 m .22907 .59873 L .23105 .59696 L F
.445 .559 .877 r
.23216 .59445 m .2353 .59466 L .23294 .59079 L F
.658 .217 .191 r
.23216 .59445 m .23458 .59713 L .2353 .59466 L F
.23216 .59445 m .23105 .59696 L .23458 .59713 L F
.876 .843 .808 r
.46556 .55668 m .46132 .55826 L .46397 .55575 L F
.876 .993 .794 r
.46562 .55449 m .46556 .55668 L .46397 .55575 L F
.989 .726 .379 r
.39257 .56543 m .39255 .56847 L .39393 .56946 L F
.936 .654 .479 r
.39169 .5711 m .39393 .56946 L .39255 .56847 L F
.39169 .5711 m .39393 .57239 L .39393 .56946 L F
.781 .316 .14 r
.31768 .57909 m .32059 .58173 L .31489 .57978 L F
.597 .45 .652 r
.32037 .57864 m .32059 .58173 L .31768 .57909 L F
0 0 0 r
.62202 .3797 m .62296 .37862 L .62523 .3771 L F
.926 .563 .138 r
.40214 .54229 m .40088 .54197 L .40028 .53905 L F
.914 .514 .141 r
.40214 .54229 m .40142 .54438 L .40088 .54197 L F
.40214 .54229 m .4029 .54533 L .40142 .54438 L F
.852 .64 .101 r
.40525 .55287 m .40498 .55457 L .40452 .55213 L F
.40525 .55287 m .40543 .55579 L .40498 .55457 L F
.639 .097 0 r
.5248 .42687 m .52732 .42863 L .52334 .42772 L F
.517 .322 .555 r
.52745 .42586 m .52732 .42863 L .5248 .42687 L F
.818 .642 .665 r
.73415 .32184 m .735 .31922 L .7314 .3182 L F
.506 .175 .34 r
.35298 .52684 m .35565 .52664 L .35667 .52442 L F
.659 .336 .415 r
.35667 .52442 m .36055 .52525 L .35913 .52369 L F
.35667 .52442 m .35565 .52664 L .36055 .52525 L F
.821 .825 .348 r
.70258 .34765 m .7034 .34522 L .70266 .34644 L F
.818 .898 .484 r
.70408 .34268 m .7034 .34522 L .7051 .34149 L F
.77 .826 .357 r
.70266 .34644 m .7034 .34522 L .70408 .34268 L F
.277 .14 .508 r
.57646 .41867 m .57452 .4203 L .57463 .41974 L F
.726 .387 .406 r
.43301 .55532 m .43787 .55546 L .43677 .55355 L F
.854 .536 .009 r
.5906 .42893 m .59114 .42919 L .58973 .42806 L F
.5906 .42893 m .59177 .43199 L .59114 .42919 L F
.409 .348 .678 r
.23949 .5416 m .24137 .54173 L .23927 .54212 L F
.228 .643 .957 r
.32136 .65914 m .32551 .66091 L .32413 .65937 L F
.655 .798 .951 r
.32551 .66091 m .32684 .65862 L .32413 .65937 L F
.32551 .66091 m .32782 .65993 L .32684 .65862 L F
.793 .587 .623 r
.4562 .48772 m .4604 .48887 L .45893 .48526 L F
.657 .468 .617 r
.463 .48785 m .45893 .48526 L .4604 .48887 L F
.463 .48785 m .46295 .48423 L .45893 .48526 L F
.402 .194 .479 r
.55371 .38754 m .55366 .3904 L .55573 .38861 L F
.742 .73 .84 r
.5905 .45169 m .59395 .45229 L .59298 .44815 L F
.699 .969 .932 r
.46766 .43536 m .46644 .43743 L .46429 .43726 L F
.46766 .43536 m .46887 .43588 L .46644 .43743 L F
.611 .787 .966 r
.43889 .5809 m .44026 .58244 L .43626 .58175 L F
.713 .283 .228 r
.43626 .58175 m .44026 .58244 L .43879 .58432 L F
.464 .717 .978 r
.44165 .58063 m .44026 .58244 L .43889 .5809 L F
.705 .594 .728 r
.44165 .58063 m .43879 .58432 L .44026 .58244 L F
.975 .884 .513 r
.51858 .40207 m .51761 .40176 L .519 .40045 L F
.746 .921 .561 r
.519 .40045 m .52006 .39807 L .52165 .40029 L F
.519 .40045 m .51761 .40176 L .52006 .39807 L F
.944 .848 .717 r
.61797 .4048 m .61765 .41046 L .61503 .40925 L F
.894 .704 .638 r
.61503 .40925 m .61765 .41046 L .61611 .41446 L F
0 0 0 r
.65719 .32169 m .66049 .31981 L .65728 .32163 L F
.65719 .32169 m .6594 .32084 L .66049 .31981 L F
.03 0 0 r
.6594 .32084 m .66327 .31892 L .66049 .31981 L F
0 0 .377 r
.36365 .53812 m .36612 .54255 L .36493 .54051 L F
.111 .285 .761 r
.22438 .57321 m .2256 .57683 L .22619 .57467 L F
.323 .524 .896 r
.2256 .57683 m .22934 .57872 L .22619 .57467 L F
.488 .805 1 r
.24599 .59218 m .24833 .59154 L .24655 .59054 L F
.643 .467 .63 r
.43673 .50193 m .43901 .50046 L .43624 .50122 L F
.786 .759 .829 r
.73734 .29956 m .73365 .29882 L .73592 .29647 L F
.81 .721 .766 r
.73734 .29956 m .73505 .3029 L .73365 .29882 L F
.217 0 0 r
.73592 .29647 m .73997 .29627 L .73734 .29956 L F
.71 .944 .957 r
.48058 .42891 m .47837 .43039 L .47691 .42974 L F
.758 .486 .523 r
.31692 .63003 m .32253 .63143 L .31829 .63086 L F
.288 .059 .382 r
.50251 .51631 m .49994 .51966 L .5004 .51733 L F
0 .306 .779 r
.73385 .29033 m .73477 .2916 L .73187 .28989 L F
.73385 .29033 m .73187 .28989 L .72989 .29031 L F
.542 .895 .675 r
.45602 .46866 m .45927 .46611 L .45749 .46719 L F
.533 .9 .966 r
.45602 .46866 m .45749 .46719 L .45458 .46822 L F
.745 .896 .946 r
.50927 .40829 m .5124 .40646 L .51389 .4076 L F
.858 .968 .868 r
.51563 .40543 m .51389 .4076 L .51453 .40444 L F
.776 .902 .93 r
.51389 .4076 m .5124 .40646 L .51453 .40444 L F
.818 .898 .484 r
.70408 .34268 m .7051 .34149 L .70474 .34043 L F
.781 .596 .03 r
.24736 .56556 m .24704 .56302 L .24817 .56349 L F
.24736 .56556 m .2471 .56509 L .24704 .56302 L F
0 .155 .626 r
.24736 .56556 m .24957 .56721 L .2471 .56509 L F
0 0 .538 r
.40536 .48788 m .40636 .49173 L .40663 .49094 L F
.057 .134 .629 r
.40536 .48788 m .40663 .49094 L .4073 .48924 L F
.712 .916 .964 r
.40537 .49362 m .40688 .4902 L .40663 .49094 L F
.40688 .4902 m .4073 .48924 L .40663 .49094 L F
0 0 .538 r
.40636 .49173 m .40655 .49248 L .40663 .49094 L F
.916 .938 .577 r
.40655 .49248 m .40537 .49362 L .40663 .49094 L F
.877 .484 .288 r
.40655 .49248 m .40763 .49477 L .40537 .49362 L F
.462 .373 .669 r
.59833 .34769 m .59607 .34865 L .59573 .34878 L F
.59833 .34769 m .59681 .34879 L .59607 .34865 L F
.498 .824 .52 r
.63723 .35206 m .63603 .35318 L .63608 .35315 L F
.616 .828 .982 r
.63967 .35083 m .63723 .35206 L .6358 .35051 L F
.932 .802 .694 r
.56458 .42575 m .566 .42965 L .56485 .42852 L F
.948 .591 .253 r
.56485 .42852 m .566 .42965 L .56534 .43133 L F
.193 .374 .814 r
.5674 .42858 m .566 .42965 L .56458 .42575 L F
0 0 0 r
.56534 .43133 m .566 .42965 L .5674 .42858 L F
.905 .859 .785 r
.69414 .33235 m .69057 .33412 L .69272 .33089 L F
.69414 .33235 m .69187 .33588 L .69057 .33412 L F
.744 .726 .835 r
.29836 .65014 m .2977 .65409 L .29589 .65127 L F
0 0 0 r
.29279 .53279 m .29004 .53586 L .29082 .53471 L F
.5 .142 .29 r
.57452 .4203 m .57377 .42204 L .57117 .42206 L F
0 0 .011 r
.57646 .41867 m .57377 .42204 L .57452 .4203 L F
.457 .027 .133 r
.5458 .42108 m .54646 .42241 L .54977 .42134 L F
0 0 0 r
.33428 .57412 m .33294 .57558 L .33619 .57246 L F
.8 .88 .904 r
.50217 .41442 m .49776 .41565 L .50056 .41307 L F
.76 .873 .93 r
.50441 .41294 m .50217 .41442 L .50056 .41307 L F
.378 .841 .801 r
.63603 .39384 m .63174 .39509 L .63405 .3943 L F
.499 .904 .808 r
.63833 .39251 m .63603 .39384 L .63795 .39238 L F
.501 .906 .815 r
.63795 .39238 m .63603 .39384 L .63405 .3943 L F
.608 .528 .739 r
.48395 .47229 m .48551 .46798 L .48266 .4683 L F
.48395 .47229 m .48662 .47143 L .48551 .46798 L F
.56 .475 .715 r
.48395 .47229 m .48696 .47409 L .48662 .47143 L F
.48395 .47229 m .48468 .47503 L .48696 .47409 L F
.08 0 0 r
.6097 .37016 m .61218 .36938 L .6135 .36778 L F
.493 .212 .416 r
.61218 .36938 m .61521 .36657 L .6135 .36778 L F
.663 .463 .603 r
.3642 .52672 m .36436 .53026 L .36173 .52964 L F
.3642 .52672 m .36436 .53026 L .36173 .52964 L F
.249 .147 .537 r
.3642 .52672 m .36436 .53026 L .36591 .52902 L F
.36591 .52902 m .36436 .53026 L .3642 .52672 L F
.747 .524 .593 r
.41707 .50036 m .42222 .49752 L .41785 .49725 L F
.41707 .50036 m .42172 .50059 L .42222 .49752 L F
.571 .096 .088 r
.33242 .56963 m .33559 .5714 L .33291 .57036 L F
.492 .247 .472 r
.33518 .56913 m .33559 .5714 L .33242 .56963 L F
0 0 0 r
.33342 .61641 m .33247 .61759 L .33344 .61598 L F
.596 .543 .766 r
.36926 .61303 m .36533 .61128 L .36881 .61086 L F
.167 0 0 r
.36009 .63761 m .3601 .63709 L .35693 .63814 L F
.858 .945 .874 r
.41975 .46408 m .4184 .46743 L .42149 .4656 L F
.41975 .46408 m .41746 .467 L .4184 .46743 L F
.821 .562 .549 r
.40147 .47282 m .4035 .47185 L .4035 .47246 L F
.319 .023 .296 r
.33429 .64109 m .33714 .63765 L .33697 .64037 L F
0 0 .208 r
.33728 .63668 m .33714 .63765 L .33676 .63414 L F
.532 .313 .528 r
.33714 .63765 m .33964 .63764 L .33697 .64037 L F
.281 0 0 r
.33775 .63887 m .33964 .63764 L .33714 .63765 L F
.33775 .63887 m .33714 .63765 L .33728 .63668 L F
.799 .877 .904 r
.62483 .34698 m .6262 .34846 L .62915 .34645 L F
.781 .506 .521 r
.36969 .56949 m .36935 .57199 L .36519 .57149 L F
.338 .118 .425 r
.37221 .56607 m .36969 .56949 L .37193 .56863 L F
.454 .212 .457 r
.36969 .56949 m .37183 .5714 L .37193 .56863 L F
.36969 .56949 m .36935 .57199 L .37183 .5714 L F
.338 .118 .425 r
.37221 .56607 m .36969 .56949 L .37193 .56863 L F
.454 .212 .457 r
.36969 .56949 m .37183 .5714 L .37193 .56863 L F
.36969 .56949 m .36935 .57199 L .37183 .5714 L F
.616 .629 .841 r
.43293 .50422 m .43361 .5055 L .4365 .50464 L F
.919 .764 .673 r
.73505 .3029 m .73301 .30205 L .73365 .29882 L F
.882 .472 .231 r
.73505 .3029 m .73376 .30428 L .73301 .30205 L F
.995 .771 .415 r
.73485 .30542 m .73376 .30428 L .73505 .3029 L F
.937 .75 .625 r
.37151 .60838 m .37082 .61142 L .36881 .61086 L F
.426 .3 .605 r
.3747 .60672 m .3739 .61014 L .37151 .60838 L F
.414 .488 .827 r
.37504 .61181 m .37151 .60838 L .3739 .61014 L F
0 0 0 r
.6239 .34116 m .62629 .34013 L .6274 .33877 L F
.085 0 0 r
.62629 .34013 m .63008 .33797 L .6274 .33877 L F
0 0 0 r
.58927 .36421 m .58689 .36814 L .58837 .36608 L F
.563 .213 .332 r
.58536 .36806 m .58837 .36608 L .58689 .36814 L F
.609 .075 0 r
.28956 .57629 m .28836 .57788 L .29037 .57426 L F
.28956 .57629 m .29195 .578 L .28836 .57788 L F
.061 0 .262 r
.41664 .50418 m .4158 .50741 L .41478 .50787 L F
0 0 .413 r
.41664 .50418 m .41755 .50288 L .41707 .50036 L F
.41664 .50418 m .41755 .50288 L .41707 .50036 L F
.255 .512 .905 r
.41664 .50418 m .41862 .50486 L .41755 .50288 L F
0 0 .095 r
.4176 .50494 m .41664 .50418 L .41755 .50288 L F
.4176 .50494 m .4158 .50741 L .41658 .50442 L F
.557 .621 .872 r
.4176 .50494 m .41572 .50833 L .4158 .50741 L F
.4176 .50494 m .4184 .50778 L .41572 .50833 L F
.81 .725 .771 r
.4201 .50483 m .4184 .50778 L .4176 .50494 L F
.426 0 0 r
.4133 .50491 m .41624 .50574 L .4176 .50494 L F
.897 .878 .808 r
.41628 .50561 m .4176 .50494 L .41624 .50574 L F
.41628 .50561 m .41817 .50523 L .4176 .50494 L F
.41817 .50523 m .4201 .50483 L .4176 .50494 L F
0 0 .095 r
.4176 .50494 m .41658 .50442 L .41664 .50418 L F
.701 .786 .917 r
.41468 .45357 m .41589 .45562 L .41177 .45508 L F
.626 .75 .937 r
.41763 .45374 m .41589 .45562 L .41468 .45357 L F
.508 .828 1 r
.27217 .57554 m .27463 .57492 L .27656 .57566 L F
.743 .676 .786 r
.27217 .57554 m .27638 .57659 L .27463 .57492 L F
.42 .383 .711 r
.27638 .57659 m .27656 .57566 L .27463 .57492 L F
.27638 .57659 m .27923 .57732 L .27656 .57566 L F
.652 .486 .646 r
.27638 .57659 m .28062 .58025 L .27923 .57732 L F
.27638 .57659 m .27664 .58144 L .28062 .58025 L F
.81 .792 .836 r
.7271 .29899 m .72432 .29884 L .72678 .2966 L F
.603 .462 .663 r
.73014 .29569 m .7271 .29899 L .72678 .2966 L F
.965 .8 .628 r
.70006 .28608 m .6998 .28893 L .70084 .28933 L F
0 0 0 r
.6998 .28893 m .69935 .29255 L .70084 .28933 L F
.717 .674 .807 r
.70006 .28608 m .70084 .28933 L .7028 .28614 L F
.802 .673 .721 r
.51494 .43242 m .51133 .43447 L .51234 .43291 L F
.861 .735 .722 r
.38239 .48821 m .38321 .49158 L .38118 .48978 L F
1 .812 .482 r
.40657 .56211 m .406 .5584 L .40686 .55987 L F
.378 .837 .765 r
.407 .47469 m .40272 .47637 L .40392 .47569 L F
.407 .47469 m .40598 .47492 L .40272 .47637 L F
.469 .584 .886 r
.407 .47469 m .4096 .47487 L .4084 .47304 L F
.524 .336 .568 r
.4096 .47487 m .40691 .47796 L .407 .47469 L F
.473 0 0 r
.36414 .59661 m .36673 .59705 L .36852 .59538 L F
0 .022 .573 r
.36778 .59177 m .36852 .59538 L .36934 .59375 L F
.695 .918 .584 r
.36852 .59538 m .36673 .59705 L .36934 .59375 L F
.462 .229 .473 r
.24017 .55403 m .23728 .55299 L .23859 .55118 L F
.24017 .55403 m .23677 .55549 L .23728 .55299 L F
.714 .62 .751 r
.48417 .49099 m .48777 .49136 L .48695 .4877 L F
.395 .405 .753 r
.48695 .4877 m .48777 .49136 L .48935 .48994 L F
.696 .613 .759 r
.48825 .4943 m .48935 .48994 L .48777 .49136 L F
.933 .81 .7 r
.3163 .53763 m .31477 .53717 L .31658 .53543 L F
.708 .757 .89 r
.70776 .30725 m .71021 .30727 L .70688 .30447 L F
.696 .553 .688 r
.71248 .30641 m .71216 .30915 L .71021 .30727 L F
.733 .55 .645 r
.71216 .30915 m .70918 .31194 L .71021 .30727 L F
0 0 0 r
.44979 .59564 m .44846 .59606 L .44549 .59628 L F
.511 0 0 r
.45235 .59542 m .44846 .59606 L .44979 .59564 L F
.975 .741 .521 r
.31099 .57905 m .30921 .58097 L .30924 .57818 L F
.139 .253 .721 r
.31099 .57905 m .31325 .58118 L .31212 .57805 L F
.975 .741 .521 r
.31099 .57905 m .30921 .58097 L .30924 .57818 L F
.464 .819 .997 r
.30924 .57818 m .31099 .57905 L .31212 .57805 L F
.761 .781 .87 r
.6179 .41687 m .61908 .41326 L .61593 .41558 L F
0 0 .149 r
.48434 .55527 m .48405 .558 L .48296 .55976 L F
0 0 0 r
.48405 .558 m .48202 .56216 L .48296 .55976 L F
.583 .467 .687 r
.48182 .50797 m .48182 .51068 L .4843 .5076 L F
0 0 0 r
.68419 .32115 m .68074 .3221 L .68129 .32176 L F
.646 .766 .936 r
.47602 .46819 m .47724 .46464 L .47444 .46712 L F
.47602 .46819 m .47862 .46754 L .47724 .46464 L F
.653 .664 .848 r
.47602 .46819 m .4799 .46895 L .47862 .46754 L F
.761 .464 .481 r
.56465 .42264 m .56058 .42488 L .56059 .42247 L F
.56465 .42264 m .56458 .42575 L .56058 .42488 L F
.66 .378 .482 r
.56465 .42264 m .56717 .42521 L .56458 .42575 L F
.609 .383 .549 r
.56729 .42272 m .56717 .42521 L .56465 .42264 L F
.167 0 0 r
.26841 .51568 m .27089 .51543 L .27292 .51418 L F
.501 .299 .537 r
.27292 .51418 m .27496 .5162 L .27615 .51412 L F
.713 .236 .116 r
.27089 .51543 m .27496 .5162 L .27292 .51418 L F
.935 .599 .373 r
.35305 .50387 m .35325 .50614 L .35504 .50483 L F
.816 .386 .222 r
.35504 .50483 m .35325 .50614 L .35545 .50636 L F
.804 .578 .595 r
.32371 .55762 m .32239 .55871 L .32659 .55915 L F
.684 .219 .143 r
.32239 .55871 m .32488 .56103 L .32659 .55915 L F
.642 .864 .983 r
.58927 .36421 m .58542 .36446 L .58755 .36331 L F
0 0 0 r
.58927 .36421 m .58837 .36608 L .58755 .36331 L F
.272 0 0 r
.58837 .36608 m .58927 .36421 L .58755 .36331 L F
.58837 .36608 m .59172 .36475 L .58927 .36421 L F
.704 .577 .709 r
.4814 .47793 m .48569 .48137 L .4837 .47601 L F
.603 .502 .712 r
.4837 .47601 m .48696 .47409 L .48468 .47503 L F
.4837 .47601 m .48797 .47797 L .48696 .47409 L F
.588 .512 .736 r
.4837 .47601 m .48569 .48137 L .48797 .47797 L F
.723 .587 .702 r
.47872 .4814 m .48283 .48189 L .4814 .47793 L F
.704 .577 .709 r
.4814 .47793 m .48283 .48189 L .48569 .48137 L F
.253 .419 .834 r
.55294 .46654 m .55378 .46801 L .55548 .46706 L F
.021 0 .373 r
.55548 .46706 m .55378 .46801 L .55406 .47055 L F
.641 .081 0 r
.34996 .50197 m .35094 .50151 L .34756 .49976 L F
.726 .198 0 r
.34996 .50197 m .35305 .50387 L .35094 .50151 L F
.84 .902 .881 r
.71271 .30994 m .70918 .31194 L .71216 .30915 L F
.927 .969 .761 r
.68006 .35071 m .6778 .35452 L .67713 .35332 L F
.793 .46 0 r
.6778 .35452 m .67855 .35713 L .67713 .35332 L F
.664 .392 .498 r
.24836 .59426 m .25188 .59218 L .24833 .59154 L F
.24836 .59426 m .25169 .59543 L .25188 .59218 L F
.639 .921 .977 r
.62848 .39609 m .62963 .39689 L .62704 .39809 L F
.736 .525 .607 r
.31688 .65941 m .3189 .66004 L .31482 .66027 L F
.748 .668 .773 r
.31482 .66027 m .3189 .66004 L .31784 .65805 L F
.474 .785 .998 r
.59994 .38426 m .59894 .38296 L .596 .38345 L F
.59994 .38426 m .59894 .38296 L .596 .38345 L F
.917 .944 .804 r
.60166 .37936 m .59994 .38426 L .60229 .38305 L F
.60166 .37936 m .59894 .38296 L .59994 .38426 L F
.355 .245 .589 r
.60229 .38305 m .59994 .38426 L .59894 .38296 L F
.60229 .38305 m .60243 .38588 L .59994 .38426 L F
.671 .915 .595 r
.63358 .35641 m .63214 .35861 L .63487 .35542 L F
.71 .977 .766 r
.63358 .35641 m .63038 .35927 L .63214 .35861 L F
.416 .238 .529 r
.4201 .59087 m .41775 .58884 L .42006 .58872 L F
.4201 .59087 m .41781 .59175 L .41775 .58884 L F
.558 .775 .979 r
.58762 .45195 m .5882 .44967 L .58635 .45098 L F
.58762 .45195 m .5905 .45169 L .5882 .44967 L F
.678 .651 .816 r
.46766 .46157 m .47179 .46251 L .47164 .45958 L F
.552 .57 .826 r
.46766 .46157 m .47257 .46581 L .47179 .46251 L F
.686 .668 .827 r
.47179 .46251 m .47311 .4584 L .47164 .45958 L F
.47179 .46251 m .47476 .46195 L .47311 .4584 L F
.672 .545 .702 r
.47179 .46251 m .47257 .46581 L .47476 .46195 L F
0 0 .206 r
.49269 .53273 m .49085 .53623 L .49128 .5339 L F
.733 .362 .348 r
.72205 .32465 m .71802 .32699 L .71972 .32431 L F
.72205 .32465 m .72207 .32756 L .71802 .32699 L F
.495 .863 .634 r
.66724 .32647 m .66549 .32799 L .66895 .32622 L F
.498 .905 .822 r
.66991 .32505 m .66895 .32622 L .67116 .3247 L F
.66991 .32505 m .66724 .32647 L .66895 .32622 L F
.259 0 .232 r
.24589 .53342 m .24252 .53847 L .24359 .53574 L F
.732 .801 .322 r
.57158 .46358 m .57242 .46183 L .57268 .46175 L F
.495 .863 .634 r
.66724 .32647 m .66515 .32812 L .66549 .32799 L F
.619 .553 .758 r
.48797 .47797 m .48569 .48137 L .48852 .4808 L F
.529 .381 .624 r
.48627 .48523 m .48852 .4808 L .48569 .48137 L F
.821 .903 .898 r
.38106 .61818 m .38273 .61764 L .38111 .61642 L F
.837 .999 .796 r
.37923 .62031 m .38273 .61764 L .38106 .61818 L F
.914 .888 .792 r
.38111 .61642 m .38273 .61764 L .38543 .61289 L F
.424 .817 .986 r
.34998 .64575 m .35198 .64694 L .34877 .64696 L F
.859 .956 .871 r
.35429 .64345 m .35198 .64694 L .34998 .64575 L F
.721 .343 .332 r
.2845 .51007 m .28728 .51088 L .28855 .50978 L F
.2845 .51007 m .28728 .51088 L .28855 .50978 L F
.636 .853 .982 r
.2916 .5093 m .28855 .50978 L .29166 .50883 L F
.144 0 0 r
.28855 .50978 m .2905 .50992 L .29166 .50883 L F
.144 .198 .661 r
.28855 .50978 m .29057 .51146 L .2905 .50992 L F
.144 0 0 r
.28855 .50978 m .28728 .51088 L .2905 .50992 L F
.144 .198 .661 r
.28855 .50978 m .2905 .50992 L .28728 .51088 L F
.941 .572 .23 r
.598 .40345 m .59693 .40476 L .59658 .40223 L F
.598 .40345 m .59869 .40614 L .59693 .40476 L F
.691 .683 .837 r
.4799 .46895 m .48115 .46443 L .47862 .46754 L F
.4799 .46895 m .48266 .4683 L .48115 .46443 L F
.724 .93 .596 r
.63603 .35318 m .63487 .35542 L .63608 .35315 L F
.63603 .35318 m .63358 .35641 L .63487 .35542 L F
.513 .391 .651 r
.32649 .63459 m .32642 .63728 L .32501 .63742 L F
.648 .434 .579 r
.32642 .63728 m .32351 .64074 L .32501 .63742 L F
.464 .444 .752 r
.22251 .56865 m .22382 .56405 L .22182 .56688 L F
.968 .852 .673 r
.43657 .56113 m .43919 .55982 L .43729 .55699 L F
.43657 .56113 m .43852 .56194 L .43919 .55982 L F
.559 .522 .77 r
.24252 .53847 m .24137 .54173 L .23949 .5416 L F
.955 .855 .703 r
.57264 .4347 m .57413 .43611 L .57207 .43846 L F
0 0 0 r
.68272 .3754 m .68434 .37511 L .68149 .37596 L F
.68272 .3754 m .6857 .37458 L .68434 .37511 L F
.116 0 0 r
.43135 .53249 m .43389 .53187 L .43554 .53033 L F
.948 .629 .198 r
.39496 .58516 m .39339 .58163 L .39341 .58443 L F
.984 .905 .62 r
.39273 .58778 m .39496 .58516 L .39341 .58443 L F
.39273 .58778 m .39373 .58859 L .39496 .58516 L F
.542 .59 .851 r
.29306 .64636 m .29238 .65 L .29099 .64693 L F
.29306 .64636 m .29471 .64944 L .29238 .65 L F
.544 .616 .874 r
.29471 .64944 m .29589 .65127 L .29238 .65 L F
.815 .541 .523 r
.34587 .56931 m .34149 .56877 L .34044 .56601 L F
.746 .619 .718 r
.34625 .57196 m .34149 .56877 L .34587 .56931 L F
.941 .688 .527 r
.58566 .41561 m .58743 .41937 L .58737 .4166 L F
.01 .427 .862 r
.57531 .38419 m .5766 .38575 L .57728 .38645 L F
.595 .942 .783 r
.59573 .34878 m .59702 .34722 L .59833 .34769 L F
.59573 .34878 m .59207 .35028 L .59702 .34722 L F
.913 .638 .507 r
.59139 .4443 m .59338 .44245 L .59164 .44156 L F
.59139 .4443 m .59351 .44513 L .59338 .44245 L F
.599 .419 .609 r
.37082 .61142 m .36926 .61303 L .36881 .61086 L F
.942 .636 .431 r
.36758 .6137 m .36926 .61303 L .36881 .61086 L F
0 0 0 r
.49004 .42316 m .48575 .42491 L .48858 .42207 L F
.799 .992 .879 r
.49522 .41856 m .49004 .42316 L .49073 .42087 L F
.674 .89 .976 r
.49073 .42087 m .49004 .42316 L .48858 .42207 L F
.59 .58 .81 r
.34259 .65013 m .344 .65407 L .34636 .65297 L F
.339 0 .13 r
.53758 .4879 m .53401 .48973 L .53485 .48786 L F
0 0 .355 r
.4587 .56744 m .45835 .56917 L .45912 .57115 L F
.695 .552 .687 r
.34294 .51147 m .34403 .51466 L .34138 .51408 L F
.531 .466 .728 r
.34522 .50936 m .34578 .51348 L .34294 .51147 L F
.541 .465 .718 r
.34578 .51348 m .34403 .51466 L .34294 .51147 L F
.964 .657 .395 r
.40382 .54694 m .40168 .54766 L .4029 .54533 L F
.40382 .54694 m .40436 .54959 L .40168 .54766 L F
.931 .58 .342 r
.38938 .51712 m .38758 .51846 L .38742 .51611 L F
.38938 .51712 m .38995 .51979 L .38758 .51846 L F
.737 .587 .688 r
.451 .49407 m .45244 .49784 L .45492 .49781 L F
.736 .635 .746 r
.45244 .49784 m .45199 .49966 L .45492 .49781 L F
.598 .488 .7 r
.48182 .51068 m .48483 .51053 L .4843 .5076 L F
.608 .366 .524 r
.48182 .51068 m .48512 .51308 L .48483 .51053 L F
.48182 .51068 m .47999 .51439 L .48512 .51308 L F
.217 0 0 r
.73592 .29647 m .73956 .29677 L .73997 .29627 L F
.775 .689 .769 r
.73997 .29627 m .7426 .29295 L .73869 .29228 L F
.849 .48 0 r
.73956 .29677 m .74072 .29853 L .73997 .29627 L F
.817 .608 .62 r
.39635 .49119 m .39612 .49388 L .39741 .49202 L F
.894 .554 .396 r
.39829 .53261 m .3954 .52958 L .39739 .53098 L F
.595 .47 .679 r
.48676 .50126 m .4888 .49683 L .48582 .49767 L F
.22 0 0 r
.23964 .54948 m .23927 .54958 L .23667 .54898 L F
.319 .788 .68 r
.2409 .5489 m .23927 .54958 L .23964 .54948 L F
0 0 .196 r
.33945 .53406 m .34058 .53411 L .33971 .53214 L F
.913 .522 .25 r
.3836 .54312 m .38414 .54537 L .38617 .54627 L F
.933 .605 .393 r
.38406 .54772 m .38617 .54627 L .38414 .54537 L F
.38406 .54772 m .38652 .54902 L .38617 .54627 L F
.43 .866 .916 r
.45348 .58497 m .45105 .58579 L .44997 .58549 L F
.408 .066 .271 r
.52845 .49172 m .52814 .49345 L .52546 .49405 L F
.441 .079 .252 r
.5312 .4914 m .52814 .49345 L .52845 .49172 L F
0 .471 .745 r
.34123 .49731 m .34303 .4979 L .33888 .4968 L F
.356 0 0 r
.34546 .49914 m .34303 .4979 L .34123 .49731 L F
0 0 0 r
.34882 .63341 m .35106 .63201 L .35133 .63262 L F
.845 .859 .854 r
.35405 .62711 m .35106 .63201 L .35147 .62765 L F
.42 0 0 r
.35106 .63201 m .35429 .63314 L .35133 .63262 L F
.147 .109 .554 r
.32 .55965 m .32154 .56151 L .32239 .55871 L F
.32 .55965 m .32053 .56291 L .32154 .56151 L F
.909 .818 .745 r
.42076 .59491 m .41781 .59175 L .4201 .59087 L F
.42076 .59491 m .41779 .59423 L .41781 .59175 L F
.42076 .59491 m .41966 .5955 L .41779 .59423 L F
.828 .816 .839 r
.42398 .59111 m .42076 .59491 L .4201 .59087 L F
.756 .741 .839 r
.42541 .59281 m .42076 .59491 L .42398 .59111 L F
.405 .172 .445 r
.37221 .56607 m .37193 .56863 L .37456 .56539 L F
.37221 .56607 m .37193 .56863 L .37456 .56539 L F
.987 .852 .618 r
.38543 .61289 m .38483 .61107 L .38406 .61261 L F
.914 .888 .792 r
.38111 .61642 m .38543 .61289 L .38406 .61261 L F
.523 .789 .994 r
.67432 .35663 m .67556 .35802 L .67252 .35775 L F
.67432 .35663 m .67556 .35802 L .67252 .35775 L F
.948 .605 .207 r
.59924 .41274 m .60096 .41626 L .5992 .41531 L F
.825 .354 .08 r
.60096 .41626 m .59987 .41733 L .5992 .41531 L F
.60096 .41626 m .60395 .42043 L .59987 .41733 L F
.815 .938 .573 r
.7108 .29131 m .71283 .28867 L .71068 .28879 L F
.463 .388 .687 r
.42757 .59062 m .42801 .59442 L .42541 .59281 L F
.867 .895 .851 r
.60144 .36607 m .59726 .37114 L .59586 .36974 L F
.028 0 .379 r
.24766 .53197 m .24589 .53342 L .24547 .53339 L F
.799 .877 .904 r
.62483 .34698 m .62915 .34645 L .62746 .34557 L F
.449 .863 .954 r
.63016 .34502 m .62915 .34645 L .63192 .34535 L F
.63016 .34502 m .62746 .34557 L .62915 .34645 L F
.853 .487 0 r
.40026 .53678 m .39905 .53526 L .39829 .53261 L F
.977 .725 .312 r
.40028 .53905 m .39905 .53526 L .40026 .53678 L F
.794 .969 .666 r
.34381 .60297 m .34338 .60478 L .34558 .6014 L F
.675 .956 .948 r
.34381 .60297 m .34182 .6044 L .34338 .60478 L F
.534 .462 .721 r
.34338 .60478 m .346 .60443 L .34558 .6014 L F
0 0 0 r
.63126 .35503 m .6309 .35559 L .63285 .35284 L F
.392 .161 .44 r
.463 .48785 m .46547 .48447 L .46295 .48423 L F
.522 .631 .899 r
.30814 .65996 m .30868 .65679 L .30647 .65855 L F
.30814 .65996 m .31111 .66018 L .30868 .65679 L F
.49 .309 .561 r
.54873 .42925 m .54668 .43119 L .54464 .42869 L F
0 0 .421 r
.70028 .30458 m .69965 .30935 L .70174 .30624 L F
.70028 .30458 m .70099 .30759 L .69965 .30935 L F
0 0 .435 r
.70094 .30946 m .69965 .30935 L .70099 .30759 L F
.605 .058 0 r
.69965 .30935 m .70083 .3108 L .70233 .31169 L F
0 0 .435 r
.70094 .30946 m .70083 .3108 L .69965 .30935 L F
.451 .435 .75 r
.31594 .57256 m .31703 .56782 L .31496 .56722 L F
.31594 .57256 m .31796 .57202 L .31703 .56782 L F
.511 .357 .608 r
.31587 .57515 m .31796 .57202 L .31594 .57256 L F
.841 .778 .79 r
.44164 .50028 m .44239 .50297 L .44356 .50165 L F
.361 .079 .344 r
.51378 .50109 m .51334 .50331 L .51086 .50407 L F
.395 .108 .355 r
.5159 .50254 m .51378 .50109 L .5163 .50036 L F
.5159 .50254 m .51334 .50331 L .51378 .50109 L F
.489 .1 .229 r
.32735 .59288 m .32669 .59469 L .3294 .59426 L F
0 .039 .559 r
.31028 .54005 m .3115 .54231 L .31077 .53884 L F
.927 .969 .761 r
.68006 .35071 m .67713 .35332 L .67961 .35004 L F
.516 0 0 r
.53329 .39586 m .53767 .39595 L .535 .39686 L F
.583 .666 .895 r
.53913 .39795 m .535 .39686 L .53767 .39595 L F
.676 .935 .967 r
.46766 .46157 m .46874 .45937 L .46629 .46038 L F
.46766 .46157 m .47164 .45958 L .46874 .45937 L F
.673 .924 .973 r
.63671 .34257 m .6354 .3449 L .63772 .34362 L F
.63671 .34257 m .63448 .34408 L .6354 .3449 L F
.774 .527 .561 r
.32243 .55575 m .32239 .55871 L .32371 .55762 L F
.999 .842 .544 r
.40732 .57508 m .40843 .57592 L .40773 .57861 L F
.6 .819 .984 r
.36935 .57199 m .36668 .57291 L .36519 .57149 L F
.988 .729 .433 r
.36519 .57149 m .36668 .57291 L .36494 .57395 L F
.371 0 0 r
.29037 .57426 m .29477 .57267 L .29234 .57282 L F
.529 .005 0 r
.33004 .59197 m .3336 .59435 L .33382 .59205 L F
0 0 .266 r
.33382 .59205 m .3359 .58775 L .33294 .58961 L F
.33382 .59205 m .33531 .59139 L .3359 .58775 L F
0 0 0 r
.33382 .59205 m .33447 .59301 L .33531 .59139 L F
.33382 .59205 m .3336 .59435 L .33447 .59301 L F
.756 .24 0 r
.34877 .64696 m .34519 .64407 L .34751 .64353 L F
0 .144 .686 r
.34234 .63425 m .34377 .63757 L .33964 .63764 L F
.778 .642 .711 r
.33964 .63764 m .34377 .63757 L .3413 .64104 L F
.766 .322 0 r
.28199 .64592 m .27981 .64283 L .28009 .64307 L F
.369 0 0 r
.27722 .64684 m .28199 .64592 L .28113 .64671 L F
.758 .734 .83 r
.28382 .64384 m .28199 .64592 L .28009 .64307 L F
0 0 0 r
.28254 .6455 m .28199 .64592 L .28113 .64671 L F
.28254 .6455 m .28199 .64592 L .28113 .64671 L F
.465 .269 .529 r
.32378 .60838 m .32645 .60766 L .32628 .60499 L F
.459 .166 .38 r
.32306 .6106 m .32645 .60766 L .32378 .60838 L F
0 .159 .686 r
.69935 .29255 m .70278 .29572 L .70268 .29623 L F
.662 .929 .641 r
.70268 .29623 m .7041 .29416 L .70543 .29543 L F
.70268 .29623 m .70278 .29572 L .7041 .29416 L F
.94 .604 .363 r
.4159 .51684 m .41411 .51678 L .41349 .51788 L F
.927 .723 .607 r
.41349 .51788 m .4159 .52131 L .4159 .51684 L F
.953 .605 .246 r
.41349 .51788 m .41676 .52352 L .4159 .52131 L F
.41349 .51788 m .41521 .52244 L .41676 .52352 L F
.944 .589 .197 r
.41381 .52045 m .41521 .52244 L .41349 .51788 L F
.94 .604 .363 r
.4159 .51684 m .4141 .51961 L .41411 .51678 L F
.4141 .51961 m .41399 .51943 L .41411 .51678 L F
.159 .1 .536 r
.4159 .51684 m .4159 .52131 L .41757 .51897 L F
.651 .602 .787 r
.41674 .51818 m .41437 .52002 L .41415 .51958 L F
.944 .589 .197 r
.41381 .52045 m .41349 .51788 L .41411 .51678 L F
.992 .74 .427 r
.41273 .51673 m .41381 .52045 L .41411 .51678 L F
.651 .602 .787 r
.41437 .52002 m .41381 .52045 L .41314 .51814 L F
.047 0 0 r
.41674 .51818 m .4141 .51961 L .4159 .51684 L F
.97 .651 .327 r
.41273 .51673 m .41399 .51943 L .41411 .51678 L F
.651 .602 .787 r
.41437 .52002 m .41399 .51943 L .41273 .51673 L F
.41399 .51943 m .41314 .51814 L .41273 .51673 L F
.97 .651 .327 r
.41273 .51673 m .41397 .51981 L .41399 .51943 L F
.047 0 0 r
.41674 .51818 m .41397 .51981 L .4141 .51961 L F
.651 .602 .787 r
.41674 .51818 m .41415 .51958 L .41273 .51673 L F
.94 .604 .363 r
.4141 .51961 m .41397 .51981 L .41399 .51943 L F
.159 .1 .536 r
.4159 .51684 m .41757 .51897 L .41783 .51637 L F
.047 0 0 r
.41674 .51818 m .4159 .51684 L .41783 .51637 L F
0 0 0 r
.55969 .38682 m .56167 .3859 L .56332 .38479 L F
.55 .885 .631 r
.56332 .38479 m .56342 .38428 L .5655 .38348 L F
.56332 .38479 m .56167 .3859 L .56342 .38428 L F
.792 .998 .798 r
.47034 .46654 m .47257 .46581 L .46926 .46895 L F
.256 .063 .416 r
.47476 .46195 m .47257 .46581 L .47448 .46447 L F
.47476 .46195 m .47257 .46581 L .47448 .46447 L F
.536 .918 .782 r
.47448 .46447 m .47257 .46581 L .47034 .46654 L F
0 0 .257 r
.71126 .29732 m .7104 .29634 L .71092 .29515 L F
.71126 .29732 m .71003 .29881 L .7104 .29634 L F
.844 .77 .78 r
.27496 .5162 m .27972 .51426 L .27769 .51283 L F
.27496 .5162 m .27732 .5178 L .27972 .51426 L F
.655 .928 .973 r
.53025 .40928 m .53187 .40713 L .52962 .40858 L F
.53025 .40928 m .53406 .40771 L .53187 .40713 L F
.677 .595 .756 r
.53025 .40928 m .53517 .41045 L .53406 .40771 L F
.73 .457 .514 r
.25792 .62396 m .2623 .6213 L .25827 .62148 L F
.25792 .62396 m .26275 .62365 L .2623 .6213 L F
.178 0 0 r
.24526 .54328 m .2471 .54322 L .24765 .54286 L F
0 0 0 r
.61521 .36657 m .61835 .36473 L .6157 .36471 L F
.646 .458 .614 r
.33801 .62806 m .33991 .63 L .33834 .63126 L F
.792 .398 .308 r
.33951 .62916 m .34238 .63127 L .33991 .63 L F
.724 .592 .708 r
.33834 .63126 m .34238 .63127 L .33991 .63 L F
.61 .403 .575 r
.34238 .63127 m .34332 .62662 L .33991 .63 L F
.525 .493 .763 r
.34144 .62892 m .3418 .63401 L .33991 .63 L F
.3418 .63401 m .34182 .63424 L .33991 .63 L F
.792 .398 .308 r
.33801 .62806 m .33951 .62916 L .33991 .63 L F
0 0 0 r
.55969 .38682 m .5583 .38748 L .56167 .3859 L F
.956 .66 .435 r
.27588 .64001 m .27629 .63756 L .27399 .63643 L F
.746 .292 0 r
.27981 .64283 m .27629 .63756 L .27588 .64001 L F
.253 0 .081 r
.54671 .48148 m .54839 .483 L .54575 .48386 L F
.54671 .48148 m .54929 .48067 L .54839 .483 L F
.788 .357 .224 r
.43766 .47619 m .44164 .47778 L .44026 .47545 L F
.96 .843 .682 r
.4385 .47358 m .43766 .47619 L .44026 .47545 L F
.803 .357 .184 r
.44026 .47545 m .44404 .47825 L .44379 .47446 L F
.44026 .47545 m .44164 .47778 L .44404 .47825 L F
.966 .777 .597 r
.40773 .57861 m .40869 .58201 L .40804 .58122 L F
.852 .782 .281 r
.40869 .58201 m .40798 .58395 L .40804 .58122 L F
.40869 .58201 m .40814 .58523 L .40798 .58395 L F
.597 .638 .862 r
.34101 .51592 m .33686 .51405 L .34138 .51408 L F
.55 .281 .46 r
.34138 .51408 m .34331 .51616 L .34101 .51592 L F
.675 .268 .267 r
.34403 .51466 m .34331 .51616 L .34138 .51408 L F
.721 .844 .94 r
.58593 .35587 m .59065 .35559 L .58938 .35442 L F
.743 .918 .951 r
.58938 .35442 m .59065 .35559 L .59285 .3539 L F
.428 .851 .952 r
.24928 .54702 m .25027 .54586 L .24722 .54648 L F
.24928 .54702 m .25184 .5463 L .25027 .54586 L F
.709 .307 .284 r
.60349 .38686 m .6069 .38494 L .60243 .38588 L F
.056 .019 .494 r
.60429 .38391 m .60243 .38588 L .60229 .38305 L F
.854 .503 .388 r
.60243 .38588 m .60134 .38798 L .60303 .38782 L F
.709 .307 .284 r
.60641 .38956 m .60243 .38588 L .60303 .38782 L F
0 0 0 r
.60429 .38391 m .60134 .38798 L .60243 .38588 L F
.886 .974 .831 r
.60073 .3864 m .60131 .3879 L .60429 .38391 L F
.60131 .3879 m .60134 .38798 L .60144 .38784 L F
.60131 .3879 m .60144 .38784 L .60429 .38391 L F
.709 .307 .284 r
.60641 .38956 m .60687 .38524 L .60349 .38686 L F
.60687 .38524 m .6069 .38494 L .60349 .38686 L F
.281 0 .218 r
.60947 .38565 m .6069 .38494 L .60641 .38956 L F
.677 .504 .645 r
.36405 .62492 m .36714 .62442 L .36489 .6274 L F
.933 .579 .157 r
.36405 .62492 m .36489 .6274 L .3635 .62493 L F
.873 .859 .824 r
.69057 .33412 m .69187 .33588 L .69037 .33752 L F
.775 .997 .81 r
.5394 .45409 m .54346 .45124 L .54268 .45132 L F
.937 .935 .582 r
.54454 .44687 m .54346 .45124 L .54591 .44765 L F
.54454 .44687 m .54268 .45132 L .54355 .45087 L F
0 0 0 r
.54369 .44964 m .54268 .45132 L .54454 .44687 L F
.692 .948 .671 r
.54157 .4519 m .54268 .45132 L .54369 .44964 L F
.54136 .45212 m .54268 .45132 L .54157 .4519 L F
.937 .935 .582 r
.54355 .45087 m .54268 .45132 L .54346 .45124 L F
.746 .867 .935 r
.61369 .40527 m .61545 .40685 L .61797 .4048 L F
.987 .744 .478 r
.61503 .40925 m .61545 .40685 L .61369 .40527 L F
.834 .967 .888 r
.51563 .40543 m .51761 .40176 L .51858 .40207 L F
.961 .88 .486 r
.39846 .48549 m .39762 .48709 L .39835 .48725 L F
.908 .959 .812 r
.39762 .48709 m .39635 .49119 L .39835 .48725 L F
.685 .701 .859 r
.39835 .48725 m .40059 .4834 L .39846 .48549 L F
.39835 .48725 m .40175 .48511 L .40059 .4834 L F
.152 .052 .478 r
.4158 .50741 m .41572 .50833 L .41478 .50787 L F
.207 .005 .371 r
.41572 .50833 m .41393 .51028 L .41478 .50787 L F
.424 .817 .986 r
.34998 .64575 m .34877 .64696 L .34751 .64353 L F
.736 .837 .927 r
.41975 .46408 m .42149 .4656 L .42295 .46368 L F
.618 .858 .988 r
.62075 .34856 m .61949 .35133 L .62305 .34974 L F
.62075 .34856 m .61831 .34976 L .61949 .35133 L F
.614 .899 .987 r
.54347 .43594 m .5466 .43532 L .54467 .43401 L F
.86 .953 .871 r
.54467 .43401 m .5466 .43532 L .54891 .43187 L F
.406 .013 .177 r
.51989 .49751 m .5216 .49922 L .51902 .4999 L F
.51989 .49751 m .52243 .4971 L .5216 .49922 L F
.769 .672 .756 r
.41957 .52255 m .42288 .52325 L .42395 .52102 L F
.778 .651 .722 r
.41957 .52255 m .42063 .52662 L .42288 .52325 L F
.71 .557 .678 r
.42063 .52662 m .42459 .52681 L .42288 .52325 L F
.537 .138 .232 r
.42537 .4873 m .42132 .48957 L .42278 .48752 L F
.782 .531 .557 r
.54773 .45752 m .55191 .45879 L .55 .45555 L F
.685 .366 .429 r
.5536 .45705 m .55 .45555 L .55191 .45879 L F
.5536 .45705 m .55512 .45612 L .55 .45555 L F
.79 .483 .47 r
.41473 .48972 m .41973 .49075 L .41833 .48743 L F
.332 .262 .626 r
.41833 .48743 m .41973 .49075 L .42132 .48957 L F
.42132 .48957 m .41973 .49075 L .41833 .48743 L F
.145 .394 .843 r
.64169 .38154 m .6432 .38407 L .63984 .38194 L F
.64169 .38154 m .63984 .38194 L .63909 .38234 L F
.46 .823 .995 r
.2709 .60708 m .27291 .60802 L .27542 .60743 L F
.2709 .60708 m .27291 .60802 L .27542 .60743 L F
.589 .942 .795 r
.56514 .40411 m .56377 .40562 L .56653 .40428 L F
.56514 .40411 m .56314 .40565 L .56377 .40562 L F
.284 0 .233 r
.53237 .4476 m .53411 .44967 L .534 .44772 L F
.53237 .4476 m .53164 .45085 L .53411 .44967 L F
.61 .403 .575 r
.34238 .63127 m .34495 .62777 L .34332 .62662 L F
.34238 .63127 m .34507 .63062 L .34495 .62777 L F
0 0 .334 r
.34495 .62777 m .34507 .63062 L .34616 .62943 L F
.34495 .62777 m .34616 .62943 L .34332 .62662 L F
.855 .916 .872 r
.55095 .43051 m .55271 .43146 L .55461 .42884 L F
.58 .938 .795 r
.64338 .39954 m .64515 .39781 L .64332 .39948 L F
.64338 .39954 m .647 .39729 L .64515 .39781 L F
.739 .536 .618 r
.35943 .61477 m .36146 .61457 L .35943 .61802 L F
.027 0 .383 r
.48841 .54222 m .48832 .54548 L .48645 .5465 L F
0 0 .007 r
.48832 .54548 m .48633 .54917 L .48645 .5465 L F
.644 .963 .801 r
.64515 .39781 m .647 .39729 L .64894 .39564 L F
.667 .6 .771 r
.45074 .49159 m .451 .49407 L .45366 .49095 L F
0 .084 .644 r
.22768 .5855 m .2296 .58765 L .22763 .58372 L F
.447 .254 .525 r
.22731 .5881 m .2296 .58765 L .22768 .5855 L F
.641 .216 .22 r
.27656 .57566 m .27923 .57732 L .27918 .57613 L F
.817 .807 .842 r
.43081 .47822 m .42691 .48009 L .42903 .47687 L F
.542 .917 .939 r
.39092 .48155 m .3924 .48012 L .39419 .48051 L F
.249 .754 .886 r
.39419 .48051 m .39447 .47963 L .3969 .47923 L F
.39419 .48051 m .3924 .48012 L .39447 .47963 L F
.475 .556 .858 r
.39597 .48148 m .39419 .48051 L .3969 .47923 L F
0 0 0 r
.40891 .50072 m .40886 .50046 L .40677 .49948 L F
.391 .19 .484 r
.40886 .50046 m .40871 .50359 L .41096 .50015 L F
0 0 0 r
.40891 .50072 m .40871 .50359 L .40886 .50046 L F
.416 .695 .978 r
.40886 .50046 m .40941 .49857 L .40677 .49948 L F
.40886 .50046 m .41096 .50015 L .40941 .49857 L F
.715 .657 .79 r
.40932 .45617 m .40518 .45514 L .40767 .45441 L F
.676 .775 .925 r
.40767 .45441 m .41177 .45508 L .40932 .45617 L F
.738 .47 .524 r
.32944 .50389 m .32728 .5041 L .32603 .50152 L F
0 .109 .629 r
.32603 .50152 m .32728 .5041 L .32643 .49948 L F
.897 .484 .195 r
.36897 .52008 m .3702 .52311 L .37215 .52402 L F
.899 .497 .232 r
.3702 .52311 m .37286 .52605 L .37215 .52402 L F
.788 .749 .818 r
.44164 .50028 m .43866 .5034 L .44239 .50297 L F
.788 .644 .702 r
.43866 .5034 m .44063 .5075 L .44239 .50297 L F
.838 .982 .693 r
.34254 .58285 m .34098 .58448 L .34372 .58074 L F
.588 .747 .953 r
.39092 .48155 m .38732 .4805 L .38927 .48083 L F
.504 .858 .991 r
.38927 .48083 m .3924 .48012 L .39092 .48155 L F
.625 .7 .899 r
.25354 .56599 m .24817 .56349 L .25208 .56552 L F
.77 .924 .938 r
.24957 .56721 m .25354 .56599 L .25208 .56552 L F
.93 .881 .764 r
.74073 .30499 m .74196 .30295 L .74054 .30141 L F
0 0 .328 r
.6261 .41219 m .62679 .41671 L .62676 .41471 L F
.128 .401 .852 r
.62679 .41671 m .63037 .417 L .62676 .41471 L F
.62679 .41671 m .63017 .41838 L .63037 .417 L F
.63 .745 .931 r
.46364 .54175 m .46532 .54337 L .46195 .54381 L F
.184 .33 .778 r
.33686 .6432 m .33552 .64383 L .33429 .64109 L F
0 0 .474 r
.5766 .38575 m .57825 .38846 L .5785 .39007 L F
0 0 .356 r
.5789 .39075 m .5785 .39007 L .57825 .38846 L F
.5789 .39075 m .57988 .39244 L .5785 .39007 L F
0 0 .168 r
.43346 .54192 m .43358 .54457 L .43271 .54589 L F
0 .088 .632 r
.43358 .54457 m .43524 .54856 L .43271 .54589 L F
0 0 .529 r
.43271 .54589 m .43524 .54856 L .43569 .54933 L F
.267 .124 .494 r
.32628 .60499 m .3282 .60687 L .32908 .60472 L F
.32628 .60499 m .32645 .60766 L .3282 .60687 L F
0 0 .199 r
.33738 .61702 m .33578 .61829 L .3353 .62065 L F
.857 .447 0 r
.33313 .52632 m .33097 .52259 L .33185 .52583 L F
.807 .323 0 r
.332 .52454 m .33313 .52632 L .33185 .52583 L F
.33225 .52246 m .33313 .52632 L .332 .52454 L F
.857 .447 0 r
.33313 .52632 m .3315 .52375 L .33097 .52259 L F
.541 .484 .741 r
.33225 .52246 m .332 .52454 L .33097 .52259 L F
.332 .52454 m .33185 .52583 L .33097 .52259 L F
.857 .447 0 r
.332 .52454 m .33263 .52622 L .3315 .52375 L F
.33313 .52632 m .33292 .52628 L .332 .52454 L F
.33292 .52628 m .33263 .52622 L .332 .52454 L F
.928 .936 .578 r
.33313 .52632 m .33121 .52847 L .33263 .52622 L F
.807 .323 0 r
.33225 .52246 m .33554 .52616 L .33313 .52632 L F
.696 .896 .53 r
.33362 .52506 m .33313 .52632 L .33554 .52616 L F
.33362 .52506 m .33121 .52847 L .33313 .52632 L F
0 0 0 r
.62205 .37477 m .62108 .37639 L .62386 .37329 L F
0 0 .116 r
.23184 .56517 m .22933 .56852 L .23025 .5663 L F
.354 .818 .729 r
.43052 .48322 m .43488 .48151 L .43355 .48215 L F
.741 .95 .946 r
.43373 .48037 m .43488 .48151 L .43734 .48077 L F
.82 .896 .896 r
.63068 .39106 m .63197 .39257 L .63459 .38991 L F
.627 .435 .604 r
.45074 .49159 m .45366 .49095 L .45343 .48806 L F
.574 .396 .603 r
.45366 .49095 m .4562 .48772 L .45343 .48806 L F
.736 .992 .851 r
.52993 .42511 m .53378 .42256 L .53342 .42421 L F
0 0 0 r
.5362 .422 m .53342 .42421 L .53378 .42256 L F
.701 .581 .717 r
.53517 .41045 m .53493 .41305 L .53714 .40926 L F
.717 .495 .587 r
.34578 .51348 m .34331 .51616 L .34403 .51466 L F
.355 .128 .425 r
.50538 .5105 m .50507 .51295 L .50274 .51382 L F
.292 .061 .382 r
.50507 .51295 m .50251 .51631 L .50274 .51382 L F
.966 .743 .304 r
.39526 .49024 m .39612 .49388 L .39635 .49119 L F
.908 .959 .812 r
.39762 .48709 m .39526 .49024 L .39635 .49119 L F
.252 .764 .787 r
.43316 .47384 m .43447 .47333 L .43603 .47161 L F
.43316 .47384 m .43192 .47395 L .43447 .47333 L F
0 0 0 r
.6998 .28893 m .69957 .29094 L .69935 .29255 L F
0 .093 .607 r
.70089 .29376 m .69935 .29255 L .69957 .29094 L F
.70089 .29376 m .70278 .29572 L .69935 .29255 L F
.626 .387 .537 r
.35582 .60069 m .35226 .60118 L .35528 .59898 L F
.425 .274 .571 r
.35528 .59898 m .35792 .60103 L .35582 .60069 L F
.427 .505 .836 r
.34304 .55899 m .34413 .56157 L .34302 .56057 L F
.698 .564 .7 r
.61982 .42863 m .62326 .42935 L .62351 .42656 L F
.24 0 .009 r
.68811 .29495 m .69085 .29416 L .6914 .29247 L F
.21 0 .317 r
.6914 .29247 m .6942 .29141 L .69434 .28903 L F
.139 0 0 r
.6914 .29247 m .6933 .29316 L .6942 .29141 L F
.6914 .29247 m .69085 .29416 L .6933 .29316 L F
.753 .699 .801 r
.70233 .31169 m .70505 .31335 L .70522 .3081 L F
.276 0 .11 r
.70301 .31507 m .70505 .31335 L .70233 .31169 L F
.70301 .31507 m .70591 .31414 L .70505 .31335 L F
0 0 .122 r
.70522 .3081 m .70505 .31335 L .70534 .31031 L F
.926 .963 .656 r
.70505 .31335 m .70413 .31255 L .70534 .31031 L F
.483 0 0 r
.70505 .31335 m .70591 .31414 L .70413 .31255 L F
.896 .875 .808 r
.70918 .31194 m .70591 .31414 L .70505 .31335 L F
.707 .822 .936 r
.61563 .41275 m .61593 .41558 L .61908 .41326 L F
.886 .989 .798 r
.54591 .44765 m .54718 .44435 L .54454 .44687 L F
.157 .351 .806 r
.47311 .4584 m .47476 .46195 L .47636 .4609 L F
0 0 .261 r
.47636 .4609 m .47476 .46195 L .47448 .46447 L F
.994 .765 .476 r
.59869 .40614 m .59982 .41015 L .59842 .40875 L F
.998 .846 .558 r
.59982 .41015 m .59815 .41138 L .59842 .40875 L F
.59982 .41015 m .59924 .41274 L .59815 .41138 L F
0 0 0 r
.33294 .57558 m .33477 .57464 L .33619 .57246 L F
.806 .974 .902 r
.33886 .56991 m .33619 .57246 L .33559 .5714 L F
.522 .751 .979 r
.33477 .57464 m .33559 .5714 L .33619 .57246 L F
.78 .678 .751 r
.49207 .48088 m .49585 .48135 L .49467 .47785 L F
.691 .458 .565 r
.49207 .48088 m .49436 .48309 L .49585 .48135 L F
.632 .581 .778 r
.49585 .48135 m .4973 .4771 L .49467 .47785 L F
.49585 .48135 m .49877 .48106 L .4973 .4771 L F
.735 .507 .582 r
.49436 .48309 m .49877 .48106 L .49585 .48135 L F
.555 .324 .52 r
.37652 .60161 m .37661 .60453 L .37384 .60393 L F
.906 .849 .776 r
.6141 .43294 m .61461 .42818 L .61255 .43132 L F
.752 .714 .816 r
.48115 .46443 m .48266 .4683 L .48509 .4649 L F
.648 .563 .746 r
.48266 .4683 m .48551 .46798 L .48509 .4649 L F
.811 .576 .583 r
.30172 .64728 m .30607 .64785 L .30485 .65021 L F
0 0 .073 r
.30485 .65021 m .30607 .64785 L .30758 .64661 L F
.992 .739 .403 r
.4094 .59198 m .40784 .59086 L .40816 .58836 L F
.904 .512 .26 r
.411 .5941 m .40784 .59086 L .4094 .59198 L F
.718 .629 .757 r
.40437 .49006 m .40305 .49128 L .40536 .48788 L F
0 0 0 r
.55889 .47535 m .5576 .47664 L .55556 .47731 L F
.621 .952 .786 r
.56141 .47445 m .5576 .47664 L .55889 .47535 L F
0 0 0 r
.34372 .58074 m .34677 .57847 L .34441 .57906 L F
.55191 .45879 m .55512 .45612 L .5536 .45705 L F
.572 .925 .745 r
.55698 .45461 m .55512 .45612 L .5536 .45705 L F
.55698 .45461 m .55512 .45612 L .5536 .45705 L F
.363 .821 .724 r
.2493 .52243 m .25303 .52088 L .25019 .52085 L F
.695 .854 .439 r
.47635 .53328 m .47642 .53292 L .47837 .52957 L F
.677 .885 .517 r
.47635 .53328 m .47495 .53484 L .47642 .53292 L F
.722 .69 .819 r
.31324 .64549 m .31871 .64727 L .32013 .64517 L F
.816 .835 .864 r
.32013 .64517 m .31871 .64727 L .32204 .64447 L F
.98 .711 .316 r
.31871 .64937 m .31871 .64727 L .31764 .64689 L F
.657 .121 0 r
.319 .64781 m .31871 .64727 L .31764 .64689 L F
.106 0 .053 r
.32204 .64447 m .31871 .64727 L .319 .64781 L F
0 0 .235 r
.319 .64781 m .31871 .64727 L .31871 .64937 L F
.85 .947 .589 r
.34721 .61612 m .34642 .61898 L .34874 .6148 L F
.624 .954 .922 r
.34642 .61898 m .34886 .61756 L .34879 .6147 L F
.787 .943 .927 r
.34541 .61813 m .34642 .61898 L .34721 .61612 L F
.057 0 0 r
.34692 .61962 m .34886 .61756 L .34642 .61898 L F
.949 .853 .713 r
.34721 .61612 m .34886 .61756 L .34692 .61962 L F
.778 .996 .865 r
.34276 .61876 m .34541 .61813 L .34721 .61612 L F
.949 .853 .713 r
.34721 .61612 m .34692 .61962 L .34824 .61813 L F
.679 .259 0 r
.34721 .61612 m .34806 .61798 L .34556 .61755 L F
.34721 .61612 m .34556 .61755 L .34534 .61751 L F
.85 .947 .589 r
.34721 .61612 m .34874 .6148 L .34879 .6147 L F
.468 .281 .543 r
.34879 .6147 m .34886 .61756 L .35121 .61412 L F
.89 .881 .818 r
.35121 .61412 m .34721 .61612 L .34879 .6147 L F
0 0 .282 r
.43559 .56024 m .43657 .56113 L .43559 .56009 L F
.807 .776 .824 r
.43413 .56194 m .43747 .56194 L .43657 .56113 L F
0 0 .282 r
.43556 .56288 m .43413 .56194 L .43657 .56113 L F
.43556 .56288 m .43657 .56113 L .43559 .56024 L F
.807 .776 .824 r
.43747 .56194 m .43852 .56194 L .43657 .56113 L F
.523 .211 .38 r
.32693 .57554 m .3231 .57783 L .32556 .57631 L F
.32693 .57554 m .32612 .57774 L .3231 .57783 L F
.42 .325 .641 r
.32853 .57189 m .32693 .57554 L .32679 .57397 L F
.32853 .57189 m .3286 .57559 L .32693 .57554 L F
.66 .465 .61 r
.3286 .57559 m .32612 .57774 L .32693 .57554 L F
.72 .919 .961 r
.41872 .59859 m .42284 .59763 L .4217 .59823 L F
0 0 0 r
.42531 .59685 m .42421 .59754 L .42284 .59763 L F
.42284 .59763 m .42421 .59754 L .4217 .59823 L F
.226 .74 .72 r
.65606 .37994 m .65331 .38072 L .65157 .38111 L F
.873 .859 .824 r
.69057 .33412 m .69037 .33752 L .69002 .3367 L F
.543 .329 .54 r
.36714 .62442 m .36739 .62673 L .36489 .6274 L F
.827 .734 .762 r
.36922 .6197 m .36714 .62442 L .36543 .62084 L F
.76 .289 .125 r
.36714 .62442 m .37088 .62711 L .36739 .62673 L F
0 0 0 r
.3359 .58775 m .33732 .58731 L .33897 .58537 L F
.484 .138 .303 r
.33732 .58731 m .34098 .58448 L .33897 .58537 L F
.333 .168 .501 r
.57585 .44509 m .57365 .44935 L .57603 .44831 L F
.347 .117 .416 r
.57345 .45177 m .57603 .44831 L .57365 .44935 L F
.406 .153 .415 r
.51086 .50407 m .51057 .50647 L .50804 .50722 L F
.39 .14 .41 r
.51292 .50572 m .51086 .50407 L .51334 .50331 L F
.51292 .50572 m .51057 .50647 L .51086 .50407 L F
0 0 .192 r
.49487 .52917 m .49269 .53273 L .49339 .5304 L F
.769 .672 .756 r
.41957 .52255 m .42395 .52102 L .42194 .51969 L F
.76 .671 .764 r
.39954 .4744 m .40272 .47637 L .40147 .47282 L F
.39954 .4744 m .40015 .47808 L .40272 .47637 L F
.616 .711 .913 r
.40272 .47637 m .40598 .47492 L .40147 .47282 L F
.873 .801 .775 r
.62351 .42656 m .62452 .42214 L .62181 .42217 L F
.732 .502 .579 r
.42553 .54965 m .42871 .54953 L .42676 .55126 L F
.776 .574 .627 r
.42871 .54953 m .43025 .55236 L .42676 .55126 L F
.961 .944 .686 r
.35598 .63712 m .35693 .63814 L .35411 .64326 L F
.545 .691 .935 r
.35786 .63552 m .35693 .63814 L .35598 .63712 L F
.35786 .63552 m .36009 .63761 L .35693 .63814 L F
.716 .615 .742 r
.53406 .40771 m .53517 .41045 L .53714 .40926 L F
.977 .72 .474 r
.38649 .55442 m .38837 .55282 L .38654 .55173 L F
.38649 .55442 m .38831 .55557 L .38837 .55282 L F
.896 .875 .808 r
.70918 .31194 m .70706 .31601 L .70591 .31414 L F
.755 .708 .808 r
.54147 .39653 m .53913 .39795 L .53767 .39595 L F
0 0 0 r
.62102 .39329 m .61879 .39543 L .62236 .39608 L F
.639 .132 .027 r
.62077 .39759 m .62236 .39608 L .61879 .39543 L F
.777 .822 .887 r
.62236 .39608 m .62376 .39176 L .62102 .39329 L F
.62236 .39608 m .62676 .39311 L .62376 .39176 L F
.529 .135 .239 r
.62485 .3983 m .62236 .39608 L .62077 .39759 L F
.565 .78 .98 r
.53673 .43627 m .5394 .43559 L .53798 .43403 L F
.53673 .43627 m .5394 .43559 L .53798 .43403 L F
.358 .819 .925 r
.61463 .37436 m .61526 .37319 L .61333 .37558 L F
.61463 .37436 m .61734 .37375 L .61526 .37319 L F
.713 .54 .653 r
.31444 .64395 m .32013 .64517 L .31721 .64065 L F
0 0 0 r
.31444 .64395 m .31721 .64065 L .317 .64301 L F
.391 .42 .771 r
.31721 .64065 m .32013 .64517 L .31973 .64287 L F
.726 .391 .412 r
.31721 .64065 m .31973 .64287 L .317 .64301 L F
0 0 0 r
.54274 .42763 m .54189 .42931 L .54134 .43196 L F
.259 0 .232 r
.24589 .53342 m .24461 .53786 L .24252 .53847 L F
.028 0 .379 r
.24766 .53197 m .24705 .53462 L .24589 .53342 L F
.75 .554 .63 r
.24705 .53462 m .24461 .53786 L .24589 .53342 L F
.873 .827 .799 r
.3413 .64104 m .33939 .64446 L .33686 .6432 L F
.928 .761 .655 r
.33939 .64446 m .33889 .64697 L .33686 .6432 L F
.275 .132 .498 r
.3405 .64684 m .33889 .64697 L .33939 .64446 L F
.633 .682 .878 r
.60091 .34606 m .59681 .34879 L .59833 .34769 L F
.60091 .34606 m .60167 .34757 L .59681 .34879 L F
.818 .642 .665 r
.73415 .32184 m .7314 .3182 L .73202 .32008 L F
.956 .676 .464 r
.73407 .32425 m .73415 .32184 L .73202 .32008 L F
.595 .47 .679 r
.48676 .50126 m .48952 .5007 L .4888 .49683 L F
.59 .46 .671 r
.48703 .50397 m .48952 .5007 L .48676 .50126 L F
0 0 .441 r
.22907 .59873 m .23063 .59931 L .23105 .59696 L F
.22907 .59873 m .22989 .6032 L .23063 .59931 L F
.393 .265 .586 r
.42121 .581 m .41885 .57892 L .42159 .57849 L F
.42121 .581 m .41903 .58167 L .41885 .57892 L F
.473 .327 .601 r
.26729 .582 m .26732 .58521 L .26959 .58403 L F
.26729 .582 m .26732 .58521 L .26959 .58403 L F
.753 .708 .809 r
.42555 .47178 m .42606 .47405 L .42836 .47255 L F
.616 .629 .841 r
.43293 .50422 m .4365 .50464 L .43673 .50193 L F
.708 .506 .613 r
.23963 .60378 m .23839 .60406 L .23965 .60084 L F
.994 .76 .461 r
.23965 .60084 m .23952 .60097 L .23965 .60107 L F
.23965 .60084 m .23965 .60107 L .24108 .60214 L F
.708 .506 .613 r
.24204 .60323 m .23963 .60378 L .23965 .60084 L F
.996 .785 .504 r
.24025 .59847 m .23958 .60075 L .24019 .59821 L F
.24108 .60214 m .23967 .60084 L .24025 .59847 L F
.23967 .60084 m .23958 .60075 L .24025 .59847 L F
.768 .492 .517 r
.24342 .60113 m .23967 .60084 L .24108 .60214 L F
.23967 .60084 m .23965 .60084 L .24108 .60214 L F
.24342 .60113 m .24204 .60323 L .23966 .60085 L F
.23967 .60084 m .23966 .60085 L .23965 .60084 L F
.24342 .60113 m .23966 .60085 L .23967 .60084 L F
.996 .785 .504 r
.24108 .60214 m .23952 .60097 L .23958 .60075 L F
0 0 0 r
.25216 .52798 m .25169 .52695 L .25389 .52612 L F
.25216 .52798 m .25031 .52893 L .25169 .52695 L F
.42201 .48275 m .4227 .48266 L .42419 .48118 L F
.634 .651 .849 r
.54419 .39526 m .545 .39771 L .54147 .39653 L F
.558 .604 .855 r
.54683 .39489 m .545 .39771 L .54419 .39526 L F
.611 .084 0 r
.54404 .39853 m .54823 .39924 L .545 .39771 L F
.709 .919 .576 r
.54404 .39853 m .545 .39771 L .54683 .39489 L F
.243 .745 .685 r
.61904 .34281 m .61953 .3426 L .62168 .34223 L F
.61904 .34281 m .61694 .34349 L .61953 .3426 L F
.343 .799 .671 r
.6353 .33602 m .63925 .33416 L .63677 .33556 L F
.847 .601 .059 r
.40739 .56847 m .40691 .56766 L .40657 .5649 L F
.962 .678 .249 r
.40739 .56847 m .4065 .56986 L .40691 .56766 L F
.40739 .56847 m .40792 .57228 L .4065 .56986 L F
.62 .664 .871 r
.43992 .47977 m .44404 .47825 L .44164 .47778 L F
.43992 .47977 m .44407 .48085 L .44404 .47825 L F
.647 .663 .851 r
.44404 .47825 m .44515 .47348 L .44379 .47446 L F
.44404 .47825 m .44711 .47817 L .44515 .47348 L F
.634 .357 .481 r
.44407 .48085 m .44711 .47817 L .44404 .47825 L F
.269 0 0 r
.45235 .59542 m .4564 .59499 L .45471 .59585 L F
.054 .621 .718 r
.45918 .5956 m .45471 .59585 L .4564 .59499 L F
.76 .873 .93 r
.50441 .41294 m .50056 .41307 L .50302 .41173 L F
.831 .916 .893 r
.50732 .41019 m .50441 .41294 L .50302 .41173 L F
.841 .911 .884 r
.60259 .35229 m .60622 .35132 L .60424 .35227 L F
.279 .248 .645 r
.60622 .35132 m .60715 .35435 L .60848 .35394 L F
.733 .281 .177 r
.60622 .35132 m .60848 .35394 L .60424 .35227 L F
.697 .618 .764 r
.43985 .45847 m .44408 .45997 L .44182 .45995 L F
.867 .945 .865 r
.44326 .45811 m .44408 .45997 L .44484 .45914 L F
.44326 .45811 m .44182 .45995 L .44408 .45997 L F
.61 .177 .196 r
.59792 .36764 m .60086 .36432 L .59824 .36803 L F
.891 .643 .556 r
.60144 .36607 m .59824 .36803 L .60086 .36432 L F
.867 .895 .851 r
.60144 .36607 m .59586 .36974 L .59824 .36803 L F
.61 .177 .196 r
.59792 .36764 m .60122 .36805 L .60086 .36432 L F
.891 .643 .556 r
.60144 .36607 m .60086 .36432 L .60244 .36701 L F
.467 .073 .209 r
.60086 .36432 m .60122 .36805 L .60382 .36745 L F
.25 .014 .347 r
.56626 .4512 m .56418 .45224 L .56371 .45459 L F
.58 .87 .995 r
.72951 .3273 m .73068 .32549 L .72849 .32659 L F
.72951 .3273 m .73187 .3265 L .73068 .32549 L F
.896 .902 .491 r
.5507 .46609 m .55294 .46654 L .55175 .46386 L F
.84 .835 .841 r
.55523 .46359 m .55294 .46654 L .55175 .46386 L F
.208 .457 .877 r
.55175 .46386 m .55294 .46654 L .55548 .46706 L F
.576 .242 .367 r
.43571 .45887 m .43294 .46057 L .43319 .45861 L F
.643 .19 .161 r
.43447 .47333 m .4385 .47358 L .43603 .47161 L F
.497 .273 .504 r
.43827 .4699 m .4385 .47358 L .43603 .47161 L F
.404 .781 .992 r
.54022 .39554 m .54147 .39653 L .53895 .39614 L F
.54022 .39554 m .54147 .39653 L .53767 .39595 L F
.177 0 0 r
.5387 .39656 m .54139 .39498 L .54022 .39554 L F
.641 .898 .984 r
.54419 .39526 m .54022 .39554 L .54263 .39425 L F
.177 0 0 r
.54139 .39498 m .54263 .39425 L .54022 .39554 L F
.404 .781 .992 r
.54022 .39554 m .53895 .39614 L .53767 .39595 L F
.641 .898 .984 r
.54419 .39526 m .54147 .39653 L .54022 .39554 L F
0 0 0 r
.35285 .65011 m .35616 .64742 L .35442 .64922 L F
.718 .945 .642 r
.35679 .64594 m .35616 .64742 L .35805 .64507 L F
0 0 0 r
.35545 .64686 m .35679 .64594 L .35877 .64467 L F
.838 .983 .699 r
.35442 .64922 m .35679 .64594 L .3547 .64735 L F
0 0 0 r
.3547 .64735 m .35679 .64594 L .35545 .64686 L F
.718 .945 .642 r
.35679 .64594 m .35805 .64507 L .35843 .64461 L F
.713 .913 .559 r
.35442 .64922 m .35616 .64742 L .35679 .64594 L F
.542 .125 .2 r
.30291 .57582 m .29855 .5779 L .29863 .57585 L F
.30291 .57582 m .30161 .57806 L .29855 .5779 L F
.792 .957 .921 r
.30398 .57363 m .30291 .57582 L .30514 .57371 L F
.228 0 .038 r
.30417 .57712 m .30291 .57582 L .30398 .57363 L F
.30417 .57712 m .30161 .57806 L .30291 .57582 L F
0 0 .356 r
.30398 .57363 m .30417 .57712 L .30291 .57582 L F
0 0 0 r
.44312 .59659 m .4414 .59662 L .4384 .59667 L F
.087 0 0 r
.44549 .59628 m .4414 .59662 L .44312 .59659 L F
.48 .619 .911 r
.43393 .4913 m .43017 .48907 L .43223 .48735 L F
.648 .828 .969 r
.42931 .49143 m .43393 .4913 L .43227 .49009 L F
.978 .692 .404 r
.43227 .49009 m .43393 .4913 L .43223 .48735 L F
.716 .615 .742 r
.53406 .40771 m .53714 .40926 L .53656 .40665 L F
.752 .79 .884 r
.53714 .40926 m .53895 .40526 L .53656 .40665 L F
.53714 .40926 m .54093 .40719 L .53895 .40526 L F
.667 .289 .321 r
.54099 .46019 m .54397 .46068 L .54495 .4579 L F
.771 .551 .599 r
.54397 .46068 m .54773 .45752 L .54495 .4579 L F
.601 .888 .99 r
.54903 .4512 m .55032 .4521 L .55153 .45015 L F
.54903 .4512 m .55032 .4521 L .55153 .45015 L F
.747 .662 .766 r
.61502 .39253 m .61506 .39402 L .61234 .3938 L F
.691 .682 .837 r
.61506 .39402 m .61146 .39564 L .61234 .3938 L F
.572 .522 .76 r
.61779 .39203 m .61506 .39402 L .61502 .39253 L F
.533 .603 .869 r
.61879 .39543 m .61506 .39402 L .61779 .39203 L F
.55 .861 .997 r
.44102 .44803 m .44184 .4463 L .44316 .44714 L F
.682 .976 .898 r
.43965 .44789 m .44184 .4463 L .44102 .44803 L F
.689 .52 .653 r
.37661 .60453 m .3747 .60672 L .37384 .60393 L F
.143 0 0 r
.61953 .3426 m .6239 .34116 L .62168 .34223 L F
.567 .276 .433 r
.32556 .57631 m .3231 .57783 L .32037 .57864 L F
.555 .754 .97 r
.46926 .46895 m .47189 .46838 L .47034 .46654 L F
.429 .204 .469 r
.60733 .37363 m .61 .37294 L .6097 .37016 L F
.392 .197 .493 r
.61 .37294 m .61218 .36938 L .6097 .37016 L F
.972 .684 .423 r
.54134 .43196 m .54347 .43594 L .5394 .43559 L F
.573 .837 .995 r
.5394 .43559 m .54347 .43594 L .54202 .43478 L F
.86 .953 .871 r
.54467 .43401 m .54891 .43187 L .54691 .43287 L F
0 0 0 r
.54641 .4332 m .54467 .43401 L .54691 .43287 L F
.556 .83 .997 r
.5424 .43508 m .54347 .43594 L .54467 .43401 L F
0 0 0 r
.54322 .43525 m .54467 .43401 L .54641 .4332 L F
.556 .83 .997 r
.54202 .43478 m .5424 .43508 L .54467 .43401 L F
.149 0 .311 r
.32685 .59777 m .32455 .60114 L .32502 .59853 L F
.632 .092 0 r
.5691 .45347 m .56855 .45179 L .56626 .4512 L F
.5691 .45347 m .57075 .45291 L .56855 .45179 L F
.125 .398 .85 r
.72717 .30842 m .72539 .30965 L .7247 .30735 L F
.72717 .30842 m .72899 .3114 L .72539 .30965 L F
.305 .048 .349 r
.50782 .50972 m .50507 .51295 L .50538 .5105 L F
.787 .323 .138 r
.36737 .50002 m .3707 .50136 L .37129 .5029 L F
.903 .492 .119 r
.59424 .4354 m .59177 .43199 L .58925 .43536 L F
.91 .815 .741 r
.59221 .43894 m .59424 .4354 L .58925 .43536 L F
.609 .949 .925 r
.58777 .35119 m .58639 .35299 L .58493 .35193 L F
.58777 .35119 m .58937 .35157 L .58639 .35299 L F
.935 .755 .634 r
.44776 .47017 m .44916 .47403 L .45053 .47122 L F
.407 .043 .232 r
.36273 .59401 m .35996 .59461 L .36087 .59248 L F
.718 .947 .647 r
.33615 .65023 m .33889 .64697 L .33841 .64977 L F
0 0 .439 r
.3383 .65319 m .33615 .65023 L .33841 .64977 L F
.525 .532 .804 r
.47949 .51638 m .48212 .51616 L .47999 .51439 L F
.447 .299 .587 r
.47974 .51988 m .48212 .51616 L .47949 .51638 L F
.802 .624 .661 r
.3812 .60518 m .37633 .60727 L .37661 .60453 L F
.3812 .60518 m .38004 .60719 L .37633 .60727 L F
.865 .854 .829 r
.35031 .51856 m .34979 .5162 L .35159 .51787 L F
.35031 .51856 m .34718 .51951 L .34979 .5162 L F
.951 .614 .336 r
.35031 .51856 m .34812 .52006 L .34718 .51951 L F
.35031 .51856 m .35139 .52302 L .34812 .52006 L F
.588 .664 .891 r
.34454 .55793 m .34413 .56157 L .34304 .55899 L F
.97 .707 .478 r
.39575 .52714 m .3935 .52812 L .39332 .52578 L F
.39575 .52714 m .3954 .52958 L .3935 .52812 L F
.744 .226 0 r
.38742 .51611 m .3836 .5127 L .38678 .51464 L F
.866 .966 .861 r
.72678 .2966 m .72811 .29325 L .73014 .29569 L F
.224 .402 .829 r
.73133 .29324 m .7316 .29564 L .73014 .29569 L F
.73133 .29324 m .7316 .29564 L .73014 .29569 L F
.669 .647 .819 r
.7316 .29564 m .7306 .29912 L .73014 .29569 L F
.899 .982 .708 r
.2252 .56197 m .22451 .56155 L .22641 .55837 L F
.97 .873 .484 r
.2252 .56197 m .22382 .56405 L .22451 .56155 L F
.32 .785 .938 r
.28658 .65903 m .29078 .65915 L .2889 .65963 L F
.565 .936 .902 r
.29078 .65915 m .29072 .65825 L .2889 .65963 L F
.29078 .65915 m .29362 .6578 L .29072 .65825 L F
.68 .478 .606 r
.34979 .5162 m .34578 .51348 L .34897 .51451 L F
.794 .95 .922 r
.35 .59563 m .34717 .59769 L .34855 .5984 L F
.73 .598 .709 r
.46547 .48447 m .47028 .48547 L .47091 .48217 L F
.622 .494 .685 r
.47091 .48217 m .47128 .48387 L .47218 .48143 L F
.47091 .48217 m .47028 .48547 L .47128 .48387 L F
.589 .94 .785 r
.67694 .3053 m .67892 .30336 L .68056 .30296 L F
.512 .906 .778 r
.68056 .30296 m .68112 .30196 L .68231 .30092 L F
.68056 .30296 m .67892 .30336 L .68112 .30196 L F
.734 .984 .772 r
.46991 .43388 m .47168 .4332 L .46887 .43588 L F
.692 .967 .934 r
.46991 .43388 m .46887 .43588 L .46766 .43536 L F
1 .815 .497 r
.39367 .57885 m .393 .57485 L .39251 .57766 L F
.996 .789 .431 r
.39233 .58049 m .39367 .57885 L .39251 .57766 L F
.39233 .58049 m .39339 .58163 L .39367 .57885 L F
.647 .397 .526 r
.42063 .52662 m .42309 .52843 L .42459 .52681 L F
.635 .307 .399 r
.42309 .52843 m .42717 .52697 L .42459 .52681 L F
.738 .661 .775 r
.41393 .51028 m .41108 .51327 L .41001 .51008 L F
.51 .464 .741 r
.48627 .48523 m .48695 .4877 L .48943 .48709 L F
.395 .405 .753 r
.48695 .4877 m .48935 .48994 L .48943 .48709 L F
.667 .361 .446 r
.36436 .53026 m .36347 .53233 L .36173 .52964 L F
.36173 .52964 m .36347 .53233 L .36436 .53026 L F
.967 .716 .504 r
.57129 .42547 m .57293 .4292 L .57125 .42782 L F
.754 .488 0 r
.57293 .4292 m .57299 .42998 L .57125 .42782 L F
.57293 .4292 m .57365 .43251 L .57299 .42998 L F
.728 .769 .886 r
.411 .5941 m .41271 .59627 L .41492 .59469 L F
.542 .553 .816 r
.27157 .63697 m .27304 .64075 L .27588 .64001 L F
.452 .247 .509 r
.27588 .64001 m .27304 .64075 L .2756 .64283 L F
.834 .967 .888 r
.51563 .40543 m .51453 .40444 L .51761 .40176 L F
.347 .101 .392 r
.51057 .50647 m .50782 .50972 L .50804 .50722 L F
.806 .711 .759 r
.32013 .64517 m .32204 .64447 L .31973 .64287 L F
.722 .69 .819 r
.31324 .64549 m .32013 .64517 L .31444 .64395 L F
.657 .121 0 r
.319 .64781 m .31973 .64287 L .32204 .64447 L F
.599 .422 .613 r
.35943 .61477 m .35943 .61802 L .35657 .61851 L F
0 0 .322 r
.34304 .55899 m .33998 .55936 L .3427 .55561 L F
.865 .725 .706 r
.4084 .47304 m .4115 .47083 L .40951 .46937 L F
.4084 .47304 m .4096 .47487 L .4115 .47083 L F
.786 .861 .905 r
.40951 .46937 m .4115 .47083 L .41462 .46828 L F
.9 .585 .442 r
.36655 .51712 m .36673 .51978 L .36897 .52008 L F
.889 .484 .24 r
.36724 .521 m .36897 .52008 L .36673 .51978 L F
.36724 .521 m .3702 .52311 L .36897 .52008 L F
0 .353 .812 r
.36636 .61751 m .36922 .6197 L .36839 .6199 L F
.827 .734 .762 r
.36922 .6197 m .36543 .62084 L .36839 .6199 L F
.786 .547 .575 r
.41676 .52352 m .42063 .52662 L .41957 .52255 L F
.41676 .52352 m .41665 .52644 L .42063 .52662 L F
.836 .551 .507 r
.41713 .52762 m .42063 .52662 L .41665 .52644 L F
.41713 .52762 m .42068 .52938 L .42063 .52662 L F
.647 .397 .526 r
.42063 .52662 m .42068 .52938 L .42309 .52843 L F
.469 .672 .952 r
.37642 .60978 m .37504 .61181 L .3739 .61014 L F
.476 0 0 r
.3761 .61281 m .37779 .61381 L .37504 .61181 L F
.3761 .61281 m .37504 .61181 L .37642 .60978 L F
.913 .839 .758 r
.54404 .39853 m .54514 .4022 L .54606 .40076 L F
.54404 .39853 m .54211 .40253 L .54514 .4022 L F
.906 .865 .788 r
.54211 .40253 m .54261 .40532 L .54514 .4022 L F
.667 .511 .664 r
.32979 .63163 m .32888 .63399 L .32649 .63459 L F
.67 .521 .674 r
.32649 .63459 m .32888 .63399 L .32642 .63728 L F
.643 .824 .97 r
.31111 .66018 m .31482 .66027 L .31306 .65902 L F
.31111 .66018 m .31482 .66027 L .31306 .65902 L F
.769 .99 .889 r
.31482 .66027 m .31543 .65833 L .31306 .65902 L F
.31482 .66027 m .31784 .65805 L .31543 .65833 L F
.334 .176 .513 r
.72985 .30316 m .72764 .30714 L .72614 .30315 L F
.074 0 .299 r
.35565 .52664 m .35716 .52769 L .36055 .52525 L F
.36 .833 .843 r
.36055 .52525 m .35906 .52552 L .35913 .52369 L F
.36055 .52525 m .36049 .52471 L .35906 .52552 L F
.593 .362 .536 r
.35716 .52769 m .36049 .52471 L .36055 .52525 L F
.407 .846 .731 r
.34903 .6518 m .35285 .65011 L .35152 .65241 L F
0 0 0 r
.35152 .65241 m .35285 .65011 L .35442 .64922 L F
.283 0 .122 r
.33495 .55581 m .3375 .55519 L .33858 .55291 L F
.93 .881 .764 r
.74073 .30499 m .74054 .30141 L .73813 .30428 L F
.967 .819 .644 r
.73806 .30721 m .74073 .30499 L .73813 .30428 L F
.73806 .30721 m .73957 .30875 L .74073 .30499 L F
.56 .875 .993 r
.52973 .43914 m .5274 .44003 L .52644 .43936 L F
.852 .669 .132 r
.40814 .58523 m .40776 .58668 L .40798 .58395 L F
.40814 .58523 m .40816 .58836 L .40776 .58668 L F
.631 .654 .855 r
.29836 .65014 m .29589 .65127 L .29471 .64944 L F
0 0 .274 r
.47696 .57881 m .47761 .58035 L .47697 .58166 L F
.47696 .57881 m .47797 .57798 L .47761 .58035 L F
.725 .516 .607 r
.57117 .42206 m .56717 .42521 L .56729 .42272 L F
.57117 .42206 m .57129 .42547 L .56717 .42521 L F
.563 .389 .603 r
.57117 .42206 m .57377 .42204 L .57129 .42547 L F
.505 .575 .86 r
.25573 .58561 m .25446 .58779 L .25353 .58505 L F
.25573 .58561 m .25645 .58704 L .25446 .58779 L F
.257 0 .243 r
.25575 .58999 m .25446 .58779 L .25645 .58704 L F
.377 .06 .295 r
.25814 .5894 m .25575 .58999 L .25645 .58704 L F
.087 .622 .862 r
.25814 .5894 m .25766 .58931 L .25575 .58999 L F
.257 0 .243 r
.25575 .58999 m .25363 .59074 L .25446 .58779 L F
.087 .622 .862 r
.25766 .58931 m .25401 .58864 L .25575 .58999 L F
.257 0 .243 r
.25575 .58999 m .2536 .59085 L .25363 .59074 L F
.496 .792 .998 r
.61244 .38662 m .61052 .3874 L .60947 .38565 L F
.61283 .38674 m .61235 .38688 L .61244 .38662 L F
.61235 .38688 m .61052 .3874 L .61244 .38662 L F
.708 .72 .859 r
.61487 .38248 m .61345 .38656 L .61252 .38663 L F
.496 .792 .998 r
.61345 .38656 m .61253 .38635 L .61252 .38663 L F
.61253 .38635 m .60947 .38565 L .61252 .38663 L F
.756 .993 .808 r
.61253 .38646 m .61252 .38663 L .61244 .38662 L F
.61416 .38351 m .61252 .38663 L .61253 .38646 L F
.318 0 0 r
.61075 .38632 m .61244 .38662 L .60947 .38565 L F
.61244 .38662 m .61252 .38663 L .60947 .38565 L F
.756 .993 .808 r
.61416 .38351 m .61244 .38662 L .61325 .38426 L F
.665 .837 .42 r
.61487 .38248 m .61252 .38663 L .61416 .38351 L F
.496 .792 .998 r
.61345 .38656 m .61283 .38674 L .60947 .38565 L F
.756 .993 .808 r
.61325 .38426 m .61244 .38662 L .61075 .38632 L F
.476 .42 .715 r
.61345 .38656 m .61407 .38917 L .61052 .3874 L F
.463 .426 .732 r
.61407 .38917 m .61142 .38997 L .61052 .3874 L F
.991 .748 .46 r
.41521 .52244 m .41665 .52644 L .41676 .52352 L F
.832 .76 .783 r
.41957 .52255 m .4159 .52131 L .41676 .52352 L F
.017 0 0 r
.64973 .33708 m .64604 .33895 L .64734 .33823 L F
.086 0 .413 r
.38983 .60161 m .38972 .60457 L .38943 .60428 L F
0 0 0 r
.65806 .38953 m .66174 .38762 L .66058 .38887 L F
.66058 .38887 m .66174 .38762 L .66402 .38618 L F
.678 .167 .018 r
.58314 .39629 m .58141 .39355 L .57988 .39244 L F
0 .106 .611 r
.58494 .39684 m .58141 .39355 L .58385 .39562 L F
.678 .167 .018 r
.58314 .39629 m .58385 .39562 L .58141 .39355 L F
.057 0 0 r
.34692 .61962 m .34642 .61898 L .34531 .62085 L F
.643 .467 .63 r
.43673 .50193 m .43866 .5034 L .43901 .50046 L F
.631 .47 .646 r
.43673 .50193 m .4365 .50464 L .43866 .5034 L F
.297 0 0 r
.3281 .49638 m .33075 .49634 L .33224 .49529 L F
.476 0 0 r
.33224 .49529 m .33075 .49634 L .3347 .49636 L F
.45 0 0 r
.33224 .49529 m .3347 .49636 L .33621 .49607 L F
0 0 0 r
.67447 .30869 m .67671 .30711 L .67694 .3053 L F
.67694 .3053 m .67671 .30711 L .67892 .30336 L F
0 0 .49 r
.47014 .54758 m .4706 .5476 L .46971 .54611 L F
.175 0 0 r
.24181 .59644 m .24461 .5969 L .24369 .59835 L F
0 0 .254 r
.24461 .5969 m .24342 .60113 L .24369 .59835 L F
.587 .442 .652 r
.3253 .58018 m .32037 .57864 L .3231 .57783 L F
.3253 .58018 m .32059 .58173 L .32037 .57864 L F
.529 .381 .624 r
.48627 .48523 m .48934 .48447 L .48852 .4808 L F
.51 .464 .741 r
.48627 .48523 m .48943 .48709 L .48934 .48447 L F
.766 .716 .805 r
.4725 .5194 m .47037 .52308 L .47059 .52032 L F
.182 .434 .866 r
.23184 .59159 m .23127 .58704 L .2296 .58765 L F
.23184 .59159 m .23186 .58882 L .23127 .58704 L F
.23184 .59159 m .23294 .59079 L .23186 .58882 L F
0 0 0 r
.6716 .31147 m .67396 .31023 L .67447 .30869 L F
.67447 .30869 m .67396 .31023 L .67671 .30711 L F
.941 .958 .743 r
.24505 .61869 m .24571 .6214 L .2475 .61774 L F
.71 .775 .903 r
.51775 .43338 m .51903 .43537 L .51532 .43477 L F
.785 .672 .74 r
.51903 .43537 m .51682 .43896 L .51532 .43477 L F
.563 .779 .979 r
.52076 .4331 m .51903 .43537 L .51775 .43338 L F
.52076 .4331 m .52243 .43456 L .51903 .43537 L F
.708 .983 .812 r
.66569 .37092 m .6644 .37305 L .66416 .37268 L F
.66569 .37092 m .66766 .37037 L .6644 .37305 L F
0 .457 .714 r
.31784 .65805 m .31794 .658 L .31543 .65833 L F
.31784 .65805 m .31987 .65849 L .31794 .658 L F
.773 .828 .895 r
.47724 .46464 m .47862 .46754 L .48115 .46443 L F
.398 .211 .508 r
.44182 .45995 m .43966 .46123 L .43985 .45847 L F
.968 .788 .605 r
.58728 .41067 m .58662 .40516 L .58571 .40947 L F
.961 .637 .244 r
.58744 .41182 m .58728 .41067 L .58571 .40947 L F
.179 0 .222 r
.23618 .53357 m .23723 .53475 L .23838 .53269 L F
.23618 .53357 m .2354 .53576 L .23723 .53475 L F
.401 .817 .627 r
.46024 .56416 m .45888 .56509 L .45864 .56563 L F
.46024 .56416 m .46276 .56268 L .45902 .56501 L F
0 0 .344 r
.46024 .56416 m .46137 .56445 L .46111 .56355 L F
.848 .99 .725 r
.463 .56076 m .46276 .56268 L .46024 .56416 L F
0 0 .344 r
.46024 .56416 m .46111 .56355 L .46103 .56329 L F
.401 .817 .627 r
.46024 .56416 m .45902 .56501 L .45888 .56509 L F
.741 .627 .733 r
.33964 .63764 m .3413 .64104 L .33697 .64037 L F
.873 .827 .799 r
.3413 .64104 m .33686 .6432 L .33697 .64037 L F
.783 .791 .859 r
.61908 .41326 m .62307 .4131 L .62182 .4124 L F
.606 .834 .986 r
.62307 .4131 m .6261 .41219 L .62442 .41084 L F
.69 .937 .965 r
.62182 .4124 m .62307 .4131 L .62442 .41084 L F
.978 .888 .667 r
.43017 .48907 m .42931 .49143 L .42808 .48983 L F
.895 .988 .779 r
.43017 .48907 m .43073 .48616 L .43223 .48735 L F
.43017 .48907 m .42808 .48983 L .43073 .48616 L F
.631 .17 .14 r
.33562 .52054 m .33397 .52154 L .33186 .52037 L F
.27 0 0 r
.33804 .5202 m .33397 .52154 L .33562 .52054 L F
0 0 .34 r
.35913 .52369 m .36087 .52169 L .3586 .51964 L F
.35913 .52369 m .35906 .52552 L .36087 .52169 L F
.584 .521 .751 r
.34793 .57209 m .34684 .57557 L .34625 .57196 L F
.558 .494 .74 r
.34684 .57557 m .34939 .575 L .34793 .57209 L F
.34684 .57557 m .34939 .575 L .34793 .57209 L F
.762 .737 .829 r
.33686 .51405 m .33406 .51704 L .33317 .51387 L F
.21 .122 .531 r
.39865 .47964 m .39597 .48148 L .3969 .47923 L F
.768 .329 0 r
.39656 .48324 m .39846 .48549 L .39597 .48148 L F
.39656 .48324 m .39597 .48148 L .39865 .47964 L F
.575 .434 .652 r
.3544 .62439 m .35147 .62765 L .35167 .62619 L F
.3544 .62439 m .35405 .62711 L .35147 .62765 L F
.615 .603 .815 r
.60491 .36089 m .60622 .35631 L .60434 .35766 L F
.60491 .36089 m .60792 .36046 L .60622 .35631 L F
.541 .152 .253 r
.71775 .30782 m .72174 .30749 L .7215 .30567 L F
.636 .508 .69 r
.72174 .30749 m .7239 .30487 L .7215 .30567 L F
.434 .503 .831 r
.31496 .56722 m .31577 .56475 L .31411 .5667 L F
.531 .841 .999 r
.2348 .61381 m .23677 .61474 L .23781 .61306 L F
0 0 .208 r
.33728 .63668 m .33676 .63414 L .33728 .63347 L F
.636 .076 0 r
.37494 .50434 m .37415 .50513 L .37129 .5029 L F
.748 .228 0 r
.37494 .50434 m .37688 .50674 L .37415 .50513 L F
.751 .232 0 r
.37902 .50766 m .37688 .50674 L .37494 .50434 L F
.411 .519 .857 r
.6105 .43135 m .61189 .42808 L .60846 .42861 L F
.6105 .43135 m .61255 .43132 L .61189 .42808 L F
.767 .384 .329 r
.43025 .55236 m .42918 .55445 L .42676 .55126 L F
0 0 0 r
.55556 .47731 m .5576 .47664 L .55387 .47869 L F
.68781 .3409 m .68487 .34428 L .68561 .34398 L F
.68781 .3409 m .68561 .34398 L .6883 .34014 L F
.823 .963 .637 r
.69002 .3367 m .68781 .3409 L .6883 .34014 L F
.384 .238 .557 r
.28254 .6455 m .28112 .65018 L .28113 .64671 L F
.28113 .64671 m .28112 .65018 L .28254 .6455 L F
.774 .388 .326 r
.2821 .64631 m .28382 .64384 L .28009 .64307 L F
.443 0 0 r
.2845 .64546 m .28382 .64384 L .2821 .64631 L F
.2845 .64546 m .28615 .6443 L .28382 .64384 L F
0 0 .199 r
.28507 .64165 m .28382 .64384 L .28615 .6443 L F
.588 .889 .99 r
.61175 .34548 m .60701 .34525 L .6099 .34441 L F
.266 .768 .876 r
.6099 .34441 m .61425 .34434 L .61175 .34548 L F
.846 .492 0 r
.33027 .50417 m .33107 .50669 L .3297 .50376 L F
.872 .441 .037 r
.58814 .42687 m .58878 .42584 L .58752 .42453 L F
.58814 .42687 m .58973 .42806 L .58878 .42584 L F
.795 .299 0 r
.37902 .50766 m .37778 .50826 L .37688 .50674 L F
.679 .133 0 r
.37902 .50766 m .38112 .5096 L .37778 .50826 L F
.693 .175 0 r
.38345 .50992 m .38112 .5096 L .37902 .50766 L F
.777 .648 .719 r
.23384 .60428 m .23187 .60704 L .23155 .60564 L F
.846 .387 .004 r
.40467 .46148 m .40636 .46409 L .40457 .46293 L F
.40467 .46148 m .40457 .46293 L .40483 .46029 L F
.671 .416 .526 r
.35008 .52962 m .35285 .52957 L .35298 .52684 L F
.472 .251 .497 r
.35298 .52684 m .35549 .52883 L .35565 .52664 L F
.35298 .52684 m .35285 .52957 L .35549 .52883 L F
0 0 0 r
.41868 .58436 m .42121 .58386 L .42289 .58342 L F
.778 .795 .867 r
.71055 .30513 m .70688 .30447 L .70974 .30171 L F
.84 .847 .85 r
.71358 .30141 m .71055 .30513 L .70974 .30171 L F
.491 .761 .991 r
.4401 .49884 m .44164 .50028 L .43901 .50046 L F
.575 .406 .615 r
.43901 .50046 m .43866 .5034 L .44164 .50028 L F
.491 .761 .991 r
.4401 .49884 m .44164 .50028 L .43901 .50046 L F
.771 .754 .837 r
.61407 .38917 m .61234 .3938 L .61142 .38997 L F
.879 .757 .723 r
.60485 .36881 m .60897 .36821 L .60903 .36681 L F
.60485 .36881 m .60682 .37074 L .60897 .36821 L F
.257 0 .254 r
.43323 .58536 m .43564 .58249 L .43572 .58451 L F
.843 .526 .452 r
.43054 .58178 m .43227 .58408 L .43195 .58433 L F
.809 .723 .771 r
.43195 .58433 m .42804 .58572 L .43105 .58373 L F
0 0 .483 r
.43054 .58178 m .43195 .58433 L .43083 .58076 L F
0 .012 .579 r
.43179 .58251 m .43189 .58416 L .43208 .58305 L F
.43189 .58416 m .43195 .58433 L .43208 .58305 L F
.43132 .58232 m .43189 .58416 L .43179 .58251 L F
.809 .723 .771 r
.43195 .58433 m .43185 .58426 L .43208 .58305 L F
.43185 .58426 m .43105 .58373 L .43208 .58305 L F
.802 .819 .34 r
.43128 .58416 m .43208 .58305 L .43215 .58266 L F
.509 .748 .982 r
.43195 .58433 m .43407 .58373 L .43208 .58305 L F
.809 .723 .771 r
.43195 .58433 m .42956 .58751 L .42804 .58572 L F
.802 .819 .34 r
.43128 .58416 m .43106 .58582 L .43208 .58305 L F
.136 0 0 r
.43308 .58337 m .43128 .58416 L .43215 .58266 L F
.779 .668 .741 r
.43208 .58305 m .43407 .58373 L .43357 .58187 L F
.136 0 0 r
.43237 .58239 m .43229 .58242 L .43233 .58234 L F
.908 .891 .472 r
.43233 .58234 m .43208 .58305 L .43301 .57979 L F
.779 .668 .741 r
.43241 .58237 m .43357 .58187 L .43301 .57979 L F
.596 .83 .988 r
.43698 .57922 m .43626 .58175 L .4341 .5784 L F
.478 .282 .535 r
.43407 .58373 m .43698 .57922 L .43394 .57966 L F
.43328 .5808 m .43394 .57966 L .43301 .57979 L F
.43407 .58373 m .43394 .57966 L .43328 .5808 L F
.779 .668 .741 r
.43208 .58305 m .43357 .58187 L .43237 .58239 L F
.802 .819 .34 r
.43229 .58242 m .43208 .58305 L .43233 .58234 L F
.779 .668 .741 r
.43218 .58272 m .43221 .58266 L .43226 .58244 L F
.43221 .58266 m .43229 .58242 L .43226 .58244 L F
.802 .819 .34 r
.43215 .58266 m .43208 .58305 L .43229 .58242 L F
.779 .668 .741 r
.43221 .58266 m .43237 .58239 L .43229 .58242 L F
.43208 .58305 m .43237 .58239 L .43218 .58272 L F
.136 0 0 r
.43308 .58337 m .43237 .58239 L .43409 .58127 L F
.43237 .58239 m .43237 .58239 L .43237 .58239 L F
.43237 .58239 m .43237 .58239 L .43409 .58127 L F
.43237 .58239 m .43233 .58234 L .43243 .58229 L F
.43237 .58239 m .43243 .58229 L .43409 .58127 L F
0 0 .342 r
.43409 .58127 m .43243 .58229 L .43301 .57979 L F
.43243 .58229 m .43233 .58234 L .43301 .57979 L F
.779 .668 .741 r
.43226 .58244 m .43241 .58237 L .43301 .57979 L F
.136 0 0 r
.43275 .58291 m .43215 .58266 L .43229 .58242 L F
.43275 .58291 m .43229 .58242 L .43237 .58239 L F
.43308 .58337 m .43215 .58266 L .43275 .58291 L F
0 .012 .579 r
.43083 .58076 m .43132 .58232 L .43179 .58251 L F
.77 .28 .064 r
.43148 .58468 m .43195 .58433 L .43208 .58305 L F
.846 .664 .656 r
.43323 .58536 m .42956 .58751 L .43195 .58433 L F
.77 .28 .064 r
.43106 .58582 m .43195 .58433 L .43148 .58468 L F
.843 .526 .452 r
.43227 .58408 m .43297 .58501 L .43195 .58433 L F
.43297 .58501 m .43323 .58536 L .43195 .58433 L F
.574 .833 .994 r
.43195 .58433 m .43323 .58536 L .43572 .58451 L F
.716 .35 .355 r
.43195 .58433 m .43572 .58451 L .43323 .58536 L F
.452 .437 .752 r
.43585 .58524 m .43323 .58536 L .43572 .58451 L F
.716 .35 .355 r
.43195 .58433 m .43574 .58521 L .43572 .58451 L F
.43574 .58521 m .43585 .58524 L .43572 .58451 L F
.257 0 .254 r
.43564 .58249 m .43626 .58175 L .43572 .58451 L F
.596 .83 .988 r
.43698 .57922 m .43889 .5809 L .43626 .58175 L F
.713 .283 .228 r
.43626 .58175 m .43879 .58432 L .43572 .58451 L F
.79 .991 .752 r
.45927 .46611 m .46022 .46407 L .45749 .46719 L F
.45927 .46611 m .46082 .46432 L .46022 .46407 L F
0 0 0 r
.68554 .29608 m .68287 .29919 L .68497 .29755 L F
0 0 .044 r
.68231 .30092 m .68497 .29755 L .68287 .29919 L F
.753 .89 .486 r
.32091 .62285 m .3181 .62309 L .32094 .62296 L F
.337 0 .06 r
.3181 .62309 m .31952 .6211 L .31555 .6233 L F
.916 .777 .295 r
.31937 .61754 m .31949 .62038 L .3199 .61962 L F
.31949 .62038 m .31952 .6211 L .3199 .61962 L F
.71 .173 0 r
.3199 .61962 m .31914 .62041 L .3203 .61887 L F
.87 .484 .009 r
.31937 .61754 m .3199 .61962 L .31887 .61816 L F
.377 .624 .949 r
.31887 .61816 m .3199 .61962 L .32099 .61795 L F
.71 .173 0 r
.3199 .61962 m .3203 .61887 L .32099 .61795 L F
.753 .89 .486 r
.3199 .61962 m .31952 .6211 L .3181 .62309 L F
.3199 .61962 m .3181 .62309 L .32091 .62285 L F
.337 0 .06 r
.3181 .62309 m .31555 .6233 L .31461 .62382 L F
.363 .821 .72 r
.43454 .44922 m .43025 .451 L .43242 .44936 L F
.407 .828 .967 r
.43528 .44816 m .43454 .44922 L .43242 .44936 L F
.43528 .44816 m .43698 .44869 L .43454 .44922 L F
.49 .816 1 r
.36778 .59177 m .36946 .59102 L .36627 .59092 L F
0 .022 .573 r
.36778 .59177 m .36934 .59375 L .36946 .59102 L F
.946 .659 .462 r
.38139 .53917 m .38171 .54254 L .3836 .54312 L F
.906 .521 .279 r
.38171 .54254 m .38205 .54451 L .3836 .54312 L F
.902 .513 .275 r
.38205 .54451 m .38414 .54537 L .3836 .54312 L F
.469 .208 .435 r
.34269 .54762 m .34361 .55032 L .34316 .54868 L F
0 0 .039 r
.66917 .3151 m .67119 .31351 L .6716 .31147 L F
0 0 .036 r
.6716 .31147 m .67119 .31351 L .67396 .31023 L F
.715 .976 .921 r
.26151 .52207 m .26085 .52387 L .26324 .522 L F
.159 .388 .836 r
.25969 .52248 m .26085 .52387 L .26151 .52207 L F
.467 .251 .501 r
.4843 .5076 m .48694 .50685 L .48703 .50397 L F
.59 .46 .671 r
.48703 .50397 m .48982 .50365 L .48952 .5007 L F
.537 .307 .514 r
.48703 .50397 m .48694 .50685 L .4896 .50607 L F
.551 .303 .494 r
.48703 .50397 m .4896 .50607 L .48982 .50365 L F
.965 .672 .426 r
.38831 .55557 m .38839 .55844 L .39017 .55936 L F
.919 .529 .141 r
.38839 .55844 m .39054 .56186 L .39017 .55936 L F
0 0 0 r
.32137 .53935 m .31771 .54084 L .31858 .54035 L F
.567 .55 .796 r
.24836 .59426 m .25026 .59735 L .25169 .59543 L F
.711 .94 .633 r
.25026 .59735 m .2502 .5966 L .25169 .59543 L F
.521 .487 .759 r
.25169 .59543 m .2531 .59771 L .25026 .59735 L F
.862 .424 .163 r
.25408 .60155 m .25026 .59735 L .2531 .59771 L F
0 0 .301 r
.25026 .59735 m .25095 .59877 L .2502 .5966 L F
.862 .424 .163 r
.25408 .60155 m .2518 .60084 L .25026 .59735 L F
0 0 .301 r
.25026 .59735 m .2518 .60084 L .25095 .59877 L F
.811 .84 .872 r
.5882 .44967 m .5905 .45169 L .59298 .44815 L F
.023 .297 .791 r
.3635 .62493 m .36489 .6274 L .36539 .62589 L F
.747 .919 .556 r
.36539 .62589 m .36489 .6274 L .3631 .62933 L F
.95 .948 .641 r
.3803 .61608 m .38106 .61818 L .38111 .61642 L F
.938 .965 .696 r
.37923 .62031 m .38106 .61818 L .3803 .61608 L F
0 0 0 r
.64837 .32807 m .64953 .32786 L .65092 .32704 L F
.64837 .32807 m .6474 .3296 L .64953 .32786 L F
.382 .08 .324 r
.40767 .45441 m .40518 .45514 L .40419 .45857 L F
.113 0 0 r
.68497 .29755 m .68811 .29495 L .68554 .29608 L F
.537 .098 .153 r
.54979 .47273 m .55085 .47126 L .54786 .47149 L F
.29 0 .011 r
.54979 .47273 m .55406 .47055 L .55085 .47126 L F
.966 .711 .497 r
.54718 .47302 m .54786 .47149 L .54642 .47019 L F
.906 .977 .794 r
.54786 .47149 m .54831 .46886 L .54642 .47019 L F
.5 .144 .295 r
.54979 .47273 m .54786 .47149 L .54718 .47302 L F
.519 .866 .991 r
.62373 .3476 m .62305 .34974 L .62483 .34698 L F
.62373 .3476 m .62075 .34856 L .62305 .34974 L F
.613 .892 .584 r
.32782 .65993 m .32874 .6586 L .32684 .65862 L F
.32782 .65993 m .33069 .65687 L .32874 .6586 L F
.629 .904 .984 r
.53406 .40771 m .53513 .40584 L .53187 .40713 L F
.53406 .40771 m .53656 .40665 L .53513 .40584 L F
.882 .729 .687 r
.30945 .64632 m .31198 .64732 L .31095 .64801 L F
.777 .997 .811 r
.31095 .64801 m .31198 .64732 L .31041 .64862 L F
.707 .687 .829 r
.61291 .35373 m .61692 .35439 L .61574 .35106 L F
.731 .478 .545 r
.61352 .35704 m .61692 .35439 L .61291 .35373 L F
.61352 .35704 m .617 .35697 L .61692 .35439 L F
.608 .699 .908 r
.57419 .44187 m .57585 .44509 L .57322 .44295 L F
0 .088 .553 r
.57322 .44295 m .57585 .44509 L .5783 .44707 L F
.365 .227 .557 r
.57585 .44509 m .57603 .44831 L .5783 .44707 L F
0 0 .486 r
.57647 .37571 m .57625 .37515 L .57434 .37283 L F
.57647 .37571 m .57719 .37661 L .57625 .37515 L F
.573 .629 .868 r
.51682 .43896 m .51304 .43611 L .51532 .43477 L F
.912 .527 .27 r
.32944 .52453 m .33263 .52622 L .33097 .52259 L F
.32944 .52453 m .33097 .52259 L .33225 .52246 L F
.753 .615 .706 r
.39364 .49715 m .39789 .49793 L .39612 .49388 L F
.555 .773 .98 r
.39574 .49481 m .39789 .49793 L .39364 .49715 L F
.39579 .49479 m .39789 .49793 L .39574 .49481 L F
.785 .307 0 r
.39579 .49479 m .399 .49818 L .39789 .49793 L F
.39577 .49477 m .3958 .49479 L .39579 .49479 L F
.3958 .49479 m .399 .49818 L .39579 .49479 L F
.662 .883 .521 r
.39504 .49494 m .39364 .49715 L .39396 .49673 L F
.39504 .49494 m .39396 .49673 L .39612 .49388 L F
.39504 .49494 m .39612 .49388 L .39527 .49503 L F
.966 .743 .304 r
.39526 .49024 m .39527 .495 L .39612 .49388 L F
.423 .563 .891 r
.39524 .49489 m .39364 .49715 L .39504 .49494 L F
.966 .743 .304 r
.39527 .495 m .39527 .49502 L .39528 .49502 L F
.39527 .49502 m .39528 .49503 L .39528 .49502 L F
.423 .563 .891 r
.39577 .49477 m .39534 .49525 L .39524 .49489 L F
.39534 .49525 m .39364 .49715 L .39524 .49489 L F
.966 .743 .304 r
.39527 .49502 m .39527 .49503 L .39528 .49503 L F
.39527 .495 m .39528 .49502 L .39612 .49388 L F
.944 .692 .525 r
.39365 .49197 m .39524 .49496 L .39526 .49024 L F
.39524 .49496 m .39527 .49503 L .39527 .495 L F
.842 .581 .544 r
.39506 .49509 m .39504 .49494 L .3952 .49492 L F
.39518 .49504 m .3952 .49492 L .39563 .49485 L F
.39506 .49509 m .3952 .49492 L .39518 .49504 L F
.944 .692 .525 r
.39524 .49496 m .39527 .495 L .39527 .49443 L F
.39524 .49463 m .39527 .49443 L .39526 .49024 L F
.39524 .49496 m .39527 .49443 L .39524 .49463 L F
.555 .773 .98 r
.39577 .49477 m .39579 .49479 L .39574 .49481 L F
.87 .712 .683 r
.39591 .4935 m .39704 .49465 L .3952 .49492 L F
.47 .529 .837 r
.39365 .49197 m .39504 .49494 L .39527 .49503 L F
.87 .712 .683 r
.39511 .49482 m .3952 .49492 L .39504 .49494 L F
.39591 .4935 m .3952 .49492 L .39511 .49482 L F
.39509 .49267 m .39591 .4935 L .39517 .49473 L F
.39505 .49442 m .39517 .49473 L .39504 .49494 L F
.39509 .49267 m .39517 .49473 L .39505 .49442 L F
.785 .307 0 r
.3958 .49479 m .39894 .49866 L .399 .49818 L F
.39577 .49477 m .3958 .49481 L .3958 .49479 L F
.3958 .49481 m .39894 .49866 L .3958 .49479 L F
.842 .581 .544 r
.39533 .49778 m .39506 .49509 L .39586 .49491 L F
.39594 .49507 m .39586 .49491 L .39598 .49489 L F
.39533 .49778 m .39894 .49866 L .3958 .49481 L F
.39533 .49778 m .3958 .49481 L .39577 .49477 L F
.39506 .49509 m .39563 .49485 L .3958 .49483 L F
.39578 .49493 m .3958 .49483 L .39704 .49465 L F
.39506 .49509 m .3958 .49483 L .39578 .49493 L F
.39533 .49778 m .39586 .49491 L .39594 .49507 L F
.39671 .49525 m .39598 .49489 L .39704 .49465 L F
.39533 .49778 m .39598 .49489 L .39671 .49525 L F
.847 .891 .87 r
.45901 .44133 m .45745 .44327 L .45469 .44286 L F
.771 .895 .49 r
.39033 .59986 m .39165 .59818 L .39145 .59751 L F
.783 .671 .74 r
.43208 .58305 m .43095 .58167 L .43083 .58076 L F
0 0 .1 r
.43054 .58178 m .43083 .58076 L .43069 .57969 L F
.783 .671 .74 r
.43095 .58167 m .42894 .57922 L .43083 .58076 L F
0 0 .1 r
.43069 .57969 m .43083 .58076 L .43085 .57767 L F
.087 0 0 r
.44549 .59628 m .44404 .59661 L .4414 .59662 L F
.386 .831 .94 r
.44846 .59606 m .44404 .59661 L .44549 .59628 L F
.717 .66 .792 r
.44711 .47817 m .45088 .47788 L .44916 .47403 L F
.272 0 0 r
.58837 .36608 m .59174 .36595 L .59172 .36475 L F
.486 0 0 r
.52462 .44042 m .52644 .43936 L .52398 .43846 L F
.771 .754 .837 r
.61407 .38917 m .61502 .39253 L .61234 .3938 L F
.844 .755 .765 r
.61363 .39152 m .61502 .39253 L .61407 .38917 L F
.61363 .39152 m .61731 .38989 L .61502 .39253 L F
.572 .522 .76 r
.61779 .39203 m .61502 .39253 L .61731 .38989 L F
.623 .941 .954 r
.33135 .6553 m .33069 .65687 L .33288 .65532 L F
.725 .938 .616 r
.32874 .6586 m .33069 .65687 L .33135 .6553 L F
.716 .771 .895 r
.35395 .51674 m .35159 .51787 L .34979 .5162 L F
.502 .555 .843 r
.47634 .52258 m .47869 .52687 L .4807 .5258 L F
.089 0 .329 r
.47869 .52687 m .48011 .52751 L .4807 .5258 L F
.47869 .52687 m .47837 .52957 L .48011 .52751 L F
.213 0 0 r
.23568 .58781 m .23669 .58826 L .23788 .58639 L F
.23399 .58891 m .23669 .58826 L .23568 .58781 L F
.546 .878 .615 r
.2403 .58849 m .23834 .58997 L .23728 .59112 L F
.108 0 0 r
.23786 .5923 m .23728 .59112 L .23834 .58997 L F
0 0 .202 r
.23929 .5911 m .23786 .5923 L .23834 .58997 L F
.819 .454 .364 r
.23929 .5911 m .23669 .58826 L .23786 .5923 L F
.23929 .5911 m .23812 .59151 L .23669 .58826 L F
0 .036 .564 r
.23669 .58826 m .23812 .59151 L .2377 .5887 L F
.632 .813 .391 r
.23788 .58639 m .23669 .58826 L .23705 .58766 L F
.825 .362 .117 r
.23708 .58439 m .23788 .58639 L .23866 .58519 L F
.709 .557 .679 r
.23708 .58439 m .23519 .58529 L .23107 .58061 L F
.784 .478 .47 r
.23419 .58373 m .23788 .58639 L .23708 .58439 L F
.23419 .58373 m .23394 .5863 L .23788 .58639 L F
.632 .813 .391 r
.23788 .58639 m .23705 .58766 L .23869 .58494 L F
.213 0 0 r
.23399 .58891 m .23788 .58639 L .23394 .5863 L F
.743 .898 .51 r
.23869 .58494 m .23669 .58826 L .23739 .58664 L F
0 .036 .564 r
.23669 .58826 m .2377 .5887 L .23739 .58664 L F
.825 .362 .117 r
.23866 .58519 m .23788 .58639 L .23971 .58572 L F
0 .179 .677 r
.24047 .58571 m .24255 .58787 L .23971 .58572 L F
.24047 .58571 m .23971 .58572 L .23788 .58639 L F
.832 .76 .783 r
.41957 .52255 m .41757 .51897 L .4159 .52131 L F
0 0 0 r
.25969 .52248 m .25753 .52445 L .25469 .52568 L F
.25947 .52331 m .25969 .52248 L .26151 .52207 L F
.25947 .52331 m .25753 .52445 L .25969 .52248 L F
.766 .708 .798 r
.43754 .46733 m .43827 .4699 L .44105 .46682 L F
0 0 0 r
.65476 .39212 m .65806 .38953 L .65716 .39064 L F
.65716 .39064 m .65806 .38953 L .66058 .38887 L F
.609 .492 .694 r
.48662 .47143 m .48908 .46806 L .48551 .46798 L F
.48662 .47143 m .48941 .47068 L .48908 .46806 L F
.654 .542 .715 r
.48696 .47409 m .48941 .47068 L .48662 .47143 L F
.539 .331 .546 r
.36533 .61828 m .36543 .62084 L .36636 .61751 L F
.499 .269 .496 r
.36636 .61751 m .36839 .6199 L .36533 .61828 L F
.479 .286 .539 r
.36839 .6199 m .36543 .62084 L .36533 .61828 L F
.194 0 .331 r
.49755 .5232 m .4972 .52556 L .4952 .52665 L F
.15 0 .327 r
.4972 .52556 m .49487 .52917 L .4952 .52665 L F
.721 .606 .728 r
.42651 .51563 m .42195 .5169 L .42456 .5136 L F
.7 .481 .588 r
.42651 .51563 m .42194 .51969 L .42195 .5169 L F
.42651 .51563 m .42536 .52 L .42194 .51969 L F
.674 .866 .476 r
.42685 .51013 m .42661 .51042 L .42456 .5136 L F
.42661 .51042 m .4255 .51179 L .42502 .51271 L F
.045 0 .422 r
.42528 .51234 m .4255 .51179 L .42542 .5119 L F
.674 .866 .476 r
.42661 .51042 m .42528 .51234 L .42512 .51273 L F
.906 .689 .184 r
.4255 .51179 m .42651 .51563 L .42477 .51381 L F
.045 0 .422 r
.42512 .51283 m .4255 .51179 L .42528 .51234 L F
.674 .866 .476 r
.42512 .51273 m .42502 .51271 L .42456 .5136 L F
.42528 .51234 m .42502 .51271 L .42512 .51273 L F
.906 .689 .184 r
.42502 .51271 m .42477 .51381 L .42456 .5136 L F
.42512 .51283 m .42477 .51381 L .42502 .51271 L F
.815 .61 .625 r
.42318 .51536 m .42427 .51556 L .42512 .51283 L F
.42502 .51271 m .42512 .51283 L .42528 .51234 L F
.42318 .51536 m .42512 .51283 L .42502 .51271 L F
.906 .689 .184 r
.4255 .51179 m .42512 .51283 L .42502 .51271 L F
.045 0 .422 r
.42427 .51556 m .4255 .51179 L .42512 .51283 L F
.815 .61 .625 r
.41876 .51456 m .42318 .51536 L .42542 .5119 L F
.42318 .51536 m .42528 .51234 L .42542 .5119 L F
.906 .689 .184 r
.4255 .51179 m .42555 .51454 L .42651 .51563 L F
.996 .843 .571 r
.4237 .51832 m .42651 .51563 L .42555 .51454 L F
.4237 .51832 m .42536 .52 L .42651 .51563 L F
.597 .396 .58 r
.52993 .42511 m .52732 .42863 L .52745 .42586 L F
.526 .364 .604 r
.4888 .49683 m .49117 .49379 L .48825 .4943 L F
.4888 .49683 m .4918 .49647 L .49117 .49379 L F
.621 .487 .678 r
.4888 .49683 m .49229 .50009 L .4918 .49647 L F
.4888 .49683 m .48952 .5007 L .49229 .50009 L F
.27 0 0 r
.33804 .5202 m .33628 .52153 L .33397 .52154 L F
.368 0 0 r
.34055 .51961 m .33628 .52153 L .33804 .5202 L F
0 0 .068 r
.40536 .48788 m .40675 .48686 L .40642 .48675 L F
.057 .134 .629 r
.40536 .48788 m .4073 .48924 L .40675 .48686 L F
.992 .75 .388 r
.406 .5584 m .40498 .55457 L .40543 .55579 L F
.648 .434 .579 r
.32642 .63728 m .3265 .63987 L .32351 .64074 L F
.563 .686 .922 r
.29977 .65745 m .30398 .65932 L .30222 .65697 L F
.622 .767 .949 r
.30398 .65932 m .30456 .65655 L .30222 .65697 L F
.30398 .65932 m .30647 .65855 L .30456 .65655 L F
.35 .056 .317 r
.52546 .49405 m .52489 .49619 L .52243 .4971 L F
.353 .022 .258 r
.52814 .49345 m .52489 .49619 L .52546 .49405 L F
.492 .839 .996 r
.73258 .3115 m .73607 .31158 L .73552 .31055 L F
.68 .726 .885 r
.73607 .31158 m .73806 .30721 L .73552 .31055 L F
.73607 .31158 m .7376 .31075 L .73806 .30721 L F
.921 .67 .542 r
.69109 .32182 m .68897 .3234 L .68741 .32072 L F
.69109 .32182 m .69097 .32443 L .68897 .3234 L F
.746 .39 .379 r
.29863 .57585 m .29855 .5779 L .29662 .57522 L F
.688 .775 .918 r
.54404 .39853 m .54606 .40076 L .54823 .39924 L F
.945 .96 .714 r
.39133 .5901 m .39195 .59181 L .39373 .58859 L F
.962 .94 .699 r
.39273 .58778 m .39133 .5901 L .39373 .58859 L F
.184 .33 .778 r
.33686 .6432 m .33429 .64109 L .33697 .64037 L F
.793 .85 .396 r
.70177 .34882 m .70122 .35123 L .70258 .34765 L F
.73 .752 .242 r
.70057 .35339 m .70122 .35123 L .70177 .34882 L F
.71 .944 .957 r
.48058 .42891 m .47691 .42974 L .47944 .42839 L F
.75 .993 .82 r
.48154 .42686 m .4835 .4263 L .48058 .42891 L F
.707 .969 .934 r
.48154 .42686 m .48058 .42891 L .47944 .42839 L F
.736 .704 .821 r
.3405 .64684 m .33841 .64977 L .33889 .64697 L F
.502 .251 .467 r
.60478 .37648 m .60733 .37363 L .60381 .37348 L F
.60478 .37648 m .60737 .37635 L .60733 .37363 L F
.321 .069 .368 r
.60737 .37635 m .61 .37294 L .60733 .37363 L F
.991 .88 .609 r
.27995 .60642 m .28063 .60487 L .28204 .60485 L F
.716 .987 .868 r
.28204 .60485 m .28063 .60487 L .28265 .6033 L F
.476 .24 .476 r
.28265 .6033 m .27995 .60642 L .28204 .60485 L F
.073 0 .296 r
.55795 .4013 m .55687 .40551 L .55733 .40318 L F
.066 0 .056 r
.55923 .40006 m .55795 .4013 L .56077 .40098 L F
.025 0 0 r
.56077 .40098 m .55795 .4013 L .55733 .40318 L F
0 0 0 r
.62665 .37514 m .62438 .37833 L .62523 .3771 L F
.732 .925 .578 r
.62536 .3762 m .62438 .37833 L .62525 .37711 L F
.62536 .3762 m .62525 .37711 L .62665 .37514 L F
.292 0 0 r
.62298 .37603 m .62536 .3762 L .62665 .37514 L F
.526 .918 .903 r
.62543 .37566 m .62536 .3762 L .62416 .37594 L F
.62831 .375 m .62536 .3762 L .62543 .37566 L F
.003 .147 .662 r
.6258 .37796 m .62438 .37833 L .62536 .3762 L F
.62629 .37998 m .62438 .37833 L .6258 .37796 L F
0 0 0 r
.62202 .3797 m .62337 .3786 L .62438 .37833 L F
.62337 .3786 m .62523 .3771 L .62438 .37833 L F
.71 .701 .839 r
.30249 .65125 m .29836 .65014 L .30083 .64985 L F
.659 .683 .861 r
.30083 .64985 m .30485 .65021 L .30249 .65125 L F
.737 .991 .866 r
.55461 .42884 m .55818 .42631 L .55628 .42619 L F
.553 .932 .888 r
.55628 .42619 m .55818 .42631 L .56058 .42488 L F
.635 .307 .399 r
.42309 .52843 m .42743 .5292 L .42717 .52697 L F
.883 .504 .316 r
.42717 .52697 m .42743 .5292 L .4291 .52927 L F
.895 .985 .722 r
.27409 .58255 m .27664 .58144 L .27331 .5852 L F
.845 .644 .63 r
.27664 .58144 m .27747 .58498 L .27331 .5852 L F
.469 .226 .463 r
.2803 .58196 m .27747 .58498 L .27664 .58144 L F
0 0 0 r
.28062 .58025 m .27664 .58144 L .27409 .58255 L F
.576 .822 .447 r
.38368 .48651 m .38239 .48821 L .38118 .48978 L F
0 .548 .721 r
.32155 .57768 m .32182 .57773 L .31844 .57748 L F
.32155 .57768 m .3231 .57783 L .31844 .57748 L F
.526 .138 .248 r
.32005 .57933 m .32155 .57768 L .31844 .57748 L F
.662 .899 .559 r
.32142 .57766 m .32155 .57768 L .32005 .57933 L F
.419 .384 .713 r
.32075 .57442 m .32155 .57768 L .32286 .5759 L F
.662 .899 .559 r
.32286 .5759 m .32155 .57768 L .32142 .57766 L F
0 .548 .721 r
.32155 .57768 m .3231 .57783 L .32182 .57773 L F
.796 .999 .828 r
.32286 .5759 m .3231 .57783 L .32155 .57768 L F
.32286 .5759 m .3231 .57783 L .32155 .57768 L F
.639 .372 .499 r
.328 .57849 m .3231 .57783 L .32612 .57774 L F
.328 .57849 m .3253 .58018 L .3231 .57783 L F
.549 .556 .814 r
.5577 .39588 m .55923 .40006 L .56106 .39854 L F
.066 0 .056 r
.55923 .40006 m .56077 .40098 L .56106 .39854 L F
.84 .835 .841 r
.55523 .46359 m .55175 .46386 L .55439 .46327 L F
.259 .767 .858 r
.55768 .46308 m .55523 .46359 L .55439 .46327 L F
.658 .575 .751 r
.48852 .4808 m .49075 .47732 L .48797 .47797 L F
.48852 .4808 m .49207 .48088 L .49075 .47732 L F
.612 .434 .617 r
.48852 .4808 m .49196 .48374 L .49207 .48088 L F
.48852 .4808 m .48934 .48447 L .49196 .48374 L F
.43 .856 .724 r
.47405 .43188 m .47168 .4332 L .46991 .43388 L F
.634 .357 .481 r
.44407 .48085 m .44719 .47972 L .44711 .47817 L F
.767 .723 .812 r
.44711 .47817 m .44916 .47403 L .44515 .47348 L F
.598 .207 .273 r
.44857 .47903 m .44711 .47817 L .44719 .47972 L F
.662 .842 .43 r
.73205 .30869 m .72985 .31227 L .7312 .3098 L F
.722 .958 .946 r
.7312 .3098 m .72985 .31227 L .72899 .3114 L F
.505 .206 .393 r
.73223 .31371 m .72985 .31227 L .73258 .3115 L F
.961 .642 .37 r
.40168 .54766 m .40436 .54959 L .40452 .55213 L F
0 0 0 r
.56379 .47322 m .56753 .47118 L .566 .47213 L F
.511 .832 .527 r
.56753 .47118 m .57059 .46821 L .56918 .46951 L F
.546 .889 .648 r
.566 .47213 m .56753 .47118 L .56918 .46951 L F
.781 .683 .755 r
.33829 .5659 m .34044 .56601 L .33984 .56206 L F
.312 .343 .732 r
.33984 .56206 m .34044 .56601 L .34247 .56445 L F
0 0 0 r
.34149 .56877 m .34247 .56445 L .34044 .56601 L F
.567 .294 .462 r
.34479 .63295 m .34507 .63062 L .34238 .63127 L F
.468 .333 .614 r
.34238 .63127 m .34234 .63425 L .34479 .63295 L F
.567 .294 .462 r
.34479 .63295 m .34507 .63062 L .34238 .63127 L F
.548 .459 .706 r
.48483 .51053 m .48694 .50685 L .4843 .5076 L F
0 0 .135 r
.4815 .56456 m .48065 .56575 L .48202 .56216 L F
0 0 .256 r
.48042 .56828 m .48065 .56575 L .4815 .56456 L F
.937 .789 .671 r
.41966 .5955 m .41872 .59859 L .41779 .59423 L F
.392 .161 .44 r
.463 .48785 m .46539 .48685 L .46547 .48447 L F
.799 .795 .849 r
.53895 .40526 m .54093 .40719 L .54261 .40532 L F
.69 .98 .885 r
.63174 .39509 m .62963 .39689 L .63098 .39484 L F
.636 .92 .977 r
.63098 .39484 m .62963 .39689 L .62848 .39609 L F
.532 .152 .265 r
.54012 .48438 m .54252 .486 L .5402 .48716 L F
.54012 .48438 m .54306 .48445 L .54252 .486 L F
.655 .562 .738 r
.48551 .46798 m .48794 .46429 L .48509 .4649 L F
.48551 .46798 m .48908 .46806 L .48794 .46429 L F
.591 .725 .937 r
.57839 .42351 m .57377 .42204 L .57645 .42169 L F
.795 .769 .829 r
.57645 .42169 m .58134 .42091 L .57839 .42351 L F
.469 .226 .463 r
.2803 .58196 m .27987 .58442 L .27747 .58498 L F
.215 .011 .372 r
.28181 .58261 m .2803 .58196 L .28295 .58169 L F
.28181 .58261 m .27987 .58442 L .2803 .58196 L F
.548 .373 .597 r
.28286 .57862 m .28295 .58169 L .2803 .58196 L F
.942 .96 .731 r
.49411 .41782 m .49522 .41856 L .49073 .42087 L F
.49411 .41782 m .49481 .41901 L .49522 .41856 L F
.188 .687 .913 r
.58366 .35755 m .58258 .35697 L .57965 .35691 L F
.628 .956 .796 r
.58593 .35587 m .58523 .35569 L .58366 .35755 L F
.005 0 0 r
.455 .58158 m .45302 .58218 L .45193 .5839 L F
.642 .916 .624 r
.23027 .53946 m .23112 .53808 L .23316 .53647 L F
.892 .97 .656 r
.23316 .53647 m .23198 .53685 L .2354 .53576 L F
.23316 .53647 m .23112 .53808 L .23198 .53685 L F
0 0 0 r
.66066 .33135 m .6583 .3324 L .65798 .33247 L F
.528 .915 .786 r
.65798 .33247 m .65598 .33413 L .6576 .33254 L F
.337 .818 .805 r
.65656 .33318 m .65568 .33395 L .65798 .33247 L F
0 0 0 r
.6583 .3324 m .65656 .33318 L .65798 .33247 L F
.528 .915 .786 r
.65798 .33247 m .6576 .33254 L .6589 .33126 L F
0 0 0 r
.66066 .33135 m .6589 .33126 L .66146 .32998 L F
.66066 .33135 m .65798 .33247 L .6589 .33126 L F
.831 .916 .893 r
.50732 .41019 m .50302 .41173 L .50588 .40922 L F
.814 .933 .91 r
.50927 .40829 m .50732 .41019 L .50588 .40922 L F
.589 .777 .97 r
.62656 .40251 m .63135 .40354 L .63017 .40278 L F
.738 .965 .937 r
.63241 .40116 m .63135 .40354 L .63017 .40278 L F
.482 .597 .891 r
.62656 .40251 m .62978 .40275 L .62669 .39873 L F
.62978 .40275 m .63017 .40278 L .63003 .40261 L F
.62978 .40275 m .63003 .40261 L .62669 .39873 L F
.682 .665 .827 r
.62669 .39873 m .63017 .40278 L .63241 .40116 L F
.738 .965 .936 r
.63241 .40116 m .63135 .40354 L .62862 .40353 L F
0 0 0 r
.63107 .40233 m .63194 .40157 L .62862 .40353 L F
.63194 .40157 m .63241 .40116 L .63044 .40239 L F
.63194 .40157 m .63044 .40239 L .62862 .40353 L F
.296 .792 .797 r
.36181 .59824 m .35996 .59461 L .36009 .59714 L F
.704 .886 .964 r
.36414 .59661 m .36181 .59824 L .36009 .59714 L F
.793 .597 .637 r
.33294 .57558 m .33023 .57735 L .332 .57698 L F
.565 .123 .159 r
.33294 .57558 m .33173 .57738 L .3328 .57713 L F
.815 .696 .734 r
.3328 .57682 m .3303 .57364 L .33271 .57305 L F
.3328 .57713 m .33261 .57686 L .3328 .57682 L F
.33261 .57686 m .3303 .57364 L .3328 .57682 L F
.793 .597 .637 r
.332 .57698 m .32927 .57797 L .33173 .57738 L F
.33023 .57735 m .32927 .57797 L .332 .57698 L F
.565 .123 .159 r
.33294 .57558 m .3328 .57713 L .33477 .57464 L F
.943 .729 .259 r
.42269 .55746 m .42321 .55514 L .4231 .55557 L F
.387 .745 .992 r
.62376 .39176 m .62676 .39311 L .62818 .39278 L F
.424 0 0 r
.33055 .5925 m .33004 .59197 L .3294 .59426 L F
.33055 .5925 m .3336 .59435 L .33004 .59197 L F
.545 .916 .752 r
.29195 .578 m .29662 .57522 L .29487 .57682 L F
.666 .383 .483 r
.29662 .57522 m .29855 .5779 L .29487 .57682 L F
.159 0 0 r
.36081 .62516 m .36211 .6257 L .35975 .62632 L F
.36081 .62516 m .3635 .62493 L .36211 .6257 L F
0 0 0 r
.57059 .46821 m .57158 .46358 L .57315 .46742 L F
.517 .861 .993 r
.57059 .46821 m .57203 .46654 L .56918 .46951 L F
.57059 .46821 m .57315 .46742 L .57203 .46654 L F
.441 .857 .702 r
.32384 .60098 m .32209 .60217 L .32455 .60114 L F
.675 .963 .935 r
.63772 .34362 m .63929 .34119 L .63671 .34257 L F
.63772 .34362 m .64124 .34159 L .63929 .34119 L F
0 0 .104 r
.69896 .36074 m .69921 .36223 L .69891 .36292 L F
.901 .897 .482 r
.69896 .36074 m .70009 .35561 L .69934 .35956 L F
0 0 .105 r
.69934 .35956 m .69921 .36223 L .69896 .36074 L F
.725 .713 .839 r
.43734 .48077 m .44099 .48184 L .43992 .47977 L F
.62 .664 .871 r
.43992 .47977 m .44099 .48184 L .44407 .48085 L F
.528 .915 .786 r
.65798 .33247 m .65568 .33395 L .65598 .33413 L F
.595 .276 .399 r
.34521 .55576 m .34454 .55793 L .3427 .55561 L F
.251 .205 .61 r
.34454 .55793 m .34304 .55899 L .3427 .55561 L F
.284 .234 .624 r
.24063 .61782 m .24292 .62017 L .24245 .61704 L F
.45 .335 .632 r
.23927 .54958 m .23873 .5505 L .23667 .54898 L F
0 0 .336 r
.23859 .55118 m .23667 .54898 L .23873 .5505 L F
.755 .644 .738 r
.58316 .41891 m .58743 .41937 L .58566 .41561 L F
.772 .535 .576 r
.58313 .42158 m .58743 .41937 L .58316 .41891 L F
.58313 .42158 m .58733 .422 L .58743 .41937 L F
.965 .675 .256 r
.24651 .61705 m .2475 .61774 L .24629 .61399 L F
.933 .965 .751 r
.24505 .61869 m .2475 .61774 L .24651 .61705 L F
.793 .85 .396 r
.70177 .34882 m .70258 .34765 L .70266 .34644 L F
.339 0 .13 r
.53758 .4879 m .53669 .49012 L .53401 .48973 L F
.155 0 0 r
.5402 .48716 m .53669 .49012 L .53758 .4879 L F
.766 .716 .805 r
.4725 .5194 m .47407 .52258 L .47037 .52308 L F
.485 .575 .87 r
.47674 .52226 m .47407 .52258 L .4725 .5194 L F
.737 .468 .522 r
.42702 .53238 m .4291 .52927 L .42743 .5292 L F
.42702 .53238 m .43135 .53249 L .4291 .52927 L F
.184 0 0 r
.58777 .35119 m .59127 .35004 L .58937 .35157 L F
.666 .973 .828 r
.46022 .46407 m .46082 .46432 L .46393 .4619 L F
.973 .697 .446 r
.41607 .49355 m .41609 .49619 L .41785 .49725 L F
.846 .666 .658 r
.41355 .49954 m .41785 .49725 L .41609 .49619 L F
.41355 .49954 m .41707 .50036 L .41785 .49725 L F
.973 .697 .446 r
.41785 .49725 m .41948 .49288 L .41898 .49551 L F
.41785 .49725 m .41607 .49355 L .41948 .49288 L F
.41785 .49725 m .41609 .49619 L .41607 .49355 L F
.524 .825 .999 r
.41898 .49551 m .41609 .49619 L .41785 .49725 L F
.505 .911 .857 r
.42778 .45216 m .42537 .45335 L .42408 .45357 L F
.443 0 0 r
.33621 .49607 m .3347 .49636 L .33888 .4968 L F
.535 .87 .603 r
.66944 .3686 m .67112 .36736 L .66766 .37037 L F
.585 .942 .805 r
.66944 .3686 m .66766 .37037 L .66569 .37092 L F
.819 .994 .756 r
.73485 .30542 m .73205 .30869 L .73214 .30754 L F
.917 .527 .133 r
.3294 .59426 m .33224 .59838 L .32941 .59544 L F
.985 .736 .471 r
.33169 .60071 m .32941 .59544 L .33224 .59838 L F
.17 0 0 r
.25303 .52088 m .25483 .52097 L .25604 .51964 L F
.348 0 0 r
.25483 .52097 m .25849 .51901 L .25604 .51964 L F
.572 .939 .896 r
.3801 .48943 m .37895 .49085 L .37756 .49056 L F
.3801 .48943 m .38118 .48978 L .37895 .49085 L F
.971 .658 .345 r
.36493 .51835 m .36655 .51712 L .3635 .51554 L F
.36493 .51835 m .36673 .51978 L .36655 .51712 L F
.143 .417 .86 r
.58754 .38642 m .58802 .38479 L .58493 .38341 L F
.006 .582 .715 r
.54629 .41862 m .54129 .41861 L .54345 .41877 L F
0 .129 .67 r
.3873 .47949 m .38732 .4805 L .38571 .47783 L F
.116 .558 .918 r
.3873 .47949 m .38927 .48083 L .38732 .4805 L F
.44 0 .039 r
.29477 .57267 m .29714 .57375 L .2989 .57193 L F
.576 .201 .294 r
.29714 .57375 m .30143 .57142 L .2989 .57193 L F
.799 .714 .771 r
.55791 .4143 m .56175 .41275 L .56024 .41443 L F
.767 .718 .808 r
.55998 .40887 m .56175 .41275 L .56412 .40938 L F
.192 .383 .823 r
.56304 .41043 m .56175 .41275 L .55998 .40887 L F
.671 .877 .501 r
.56304 .41043 m .56024 .41443 L .56175 .41275 L F
.591 .472 .686 r
.56175 .41275 m .56524 .41253 L .56412 .40938 L F
.784 .533 .557 r
.56175 .41275 m .56582 .41601 L .56524 .41253 L F
.56175 .41275 m .56221 .41596 L .56582 .41601 L F
.559 .518 .766 r
.3558 .53545 m .35567 .53976 L .35477 .53559 L F
.3558 .53545 m .35825 .53941 L .35567 .53976 L F
.633 .878 .53 r
.23027 .53946 m .22859 .54123 L .23112 .53808 L F
0 0 0 r
.67266 .36549 m .67335 .36459 L .67112 .36736 L F
.604 .902 .62 r
.67266 .36549 m .67112 .36736 L .66944 .3686 L F
.852 .998 .804 r
.55366 .3904 m .5513 .39328 L .55181 .39081 L F
.399 .576 .91 r
.55167 .39342 m .5513 .39328 L .55367 .39433 L F
.55167 .39342 m .55181 .39081 L .5513 .39328 L F
0 0 0 r
.68419 .32115 m .68326 .32144 L .68074 .3221 L F
.016 0 0 r
.68741 .32072 m .68326 .32144 L .68419 .32115 L F
.614 .577 .789 r
.44816 .48211 m .44857 .47903 L .44719 .47972 L F
.44816 .48211 m .45115 .48109 L .44857 .47903 L F
.348 .054 .317 r
.31324 .64549 m .31444 .64395 L .317 .64301 L F
.401 .506 .85 r
.23367 .56189 m .23042 .55867 L .23416 .55906 L F
0 0 0 r
.23677 .55549 m .23587 .55758 L .23416 .55906 L F
0 0 .255 r
.23534 .56033 m .23416 .55906 L .23587 .55758 L F
.23534 .56033 m .23367 .56189 L .23416 .55906 L F
0 0 .355 r
.72004 .29861 m .72179 .29941 L .72341 .29897 L F
.72004 .29861 m .71983 .30195 L .72179 .29941 L F
0 0 .067 r
.36591 .52902 m .36347 .53233 L .36436 .53026 L F
.36436 .53026 m .36347 .53233 L .36591 .52902 L F
.607 .355 .509 r
.33991 .63 m .33728 .63347 L .33834 .63126 L F
.33991 .63 m .34182 .63424 L .33728 .63347 L F
0 0 0 r
.34144 .62892 m .33991 .63 L .34332 .62662 L F
.5 .214 .412 r
.40988 .46451 m .41319 .46156 L .41152 .4601 L F
.40988 .46451 m .41301 .46439 L .41319 .46156 L F
.877 .838 .804 r
.41755 .50288 m .42172 .50059 L .41707 .50036 L F
.41755 .50288 m .41862 .50486 L .42172 .50059 L F
.359 .451 .819 r
.41319 .46156 m .41478 .46067 L .41152 .4601 L F
.41319 .46156 m .41535 .46096 L .41478 .46067 L F
.541 .248 .419 r
.41319 .46156 m .41562 .46353 L .41535 .46096 L F
.41319 .46156 m .41301 .46439 L .41562 .46353 L F
.479 0 0 r
.28009 .64307 m .27981 .64283 L .27588 .64001 L F
.788 .978 .7 r
.54992 .46019 m .55191 .45879 L .54773 .45752 L F
.888 .662 .143 r
.58622 .40332 m .58562 .39926 L .586 .40196 L F
.967 .66 .265 r
.58545 .40443 m .58622 .40332 L .586 .40196 L F
.58545 .40443 m .58662 .40516 L .58622 .40332 L F
0 0 .04 r
.47968 .57368 m .47797 .57798 L .4788 .57542 L F
.607 .762 .953 r
.42649 .50831 m .42685 .51013 L .42296 .50933 L F
.735 .507 .582 r
.49436 .48309 m .49884 .48373 L .49877 .48106 L F
.527 .426 .683 r
.49877 .48106 m .50112 .47745 L .4973 .4771 L F
.49877 .48106 m .50132 .48038 L .50112 .47745 L F
.532 .347 .576 r
.49877 .48106 m .5015 .48309 L .50132 .48038 L F
.49877 .48106 m .49884 .48373 L .5015 .48309 L F
.529 .271 .468 r
.36911 .55568 m .37191 .55525 L .37245 .55274 L F
.36911 .55568 m .37191 .55525 L .37245 .55274 L F
.337 .1 .399 r
.37245 .55274 m .37409 .55447 L .37421 .55177 L F
.37245 .55274 m .37191 .55525 L .37409 .55447 L F
.37409 .55447 m .37245 .55274 L .37421 .55177 L F
.37409 .55447 m .37191 .55525 L .37245 .55274 L F
0 0 0 r
.37154 .62976 m .37059 .62995 L .37247 .62879 L F
0 .247 .761 r
.37059 .62995 m .37072 .63082 L .37009 .63005 L F
.993 .808 .436 r
.37021 .63199 m .37059 .62995 L .36952 .63187 L F
0 0 0 r
.36952 .63187 m .37059 .62995 L .37154 .62976 L F
0 .247 .761 r
.37059 .62995 m .37009 .63005 L .36739 .62673 L F
.669 .647 .819 r
.7316 .29564 m .73365 .29882 L .7306 .29912 L F
.837 .676 .684 r
.73365 .29882 m .72965 .30076 L .7306 .29912 L F
.971 .876 .684 r
.23524 .60828 m .23444 .61162 L .2328 .6101 L F
.925 .556 .137 r
.2328 .6101 m .23444 .61162 L .2348 .61381 L F
0 0 .184 r
.23605 .60924 m .23444 .61162 L .23524 .60828 L F
.222 .377 .808 r
.23781 .61306 m .23444 .61162 L .23605 .60924 L F
.82 .896 .896 r
.63068 .39106 m .63459 .38991 L .63344 .38864 L F
.759 .736 .832 r
.63459 .38991 m .63376 .38591 L .63344 .38864 L F
.63459 .38991 m .63638 .3856 L .63376 .38591 L F
.63459 .38991 m .63799 .38759 L .63638 .3856 L F
.434 .503 .831 r
.31496 .56722 m .31703 .56782 L .31577 .56475 L F
0 0 .223 r
.3079 .56894 m .30865 .57025 L .31104 .56845 L F
.3079 .56894 m .30779 .57233 L .30865 .57025 L F
.818 .661 .688 r
.69741 .2883 m .70006 .28608 L .69733 .28541 L F
.986 .88 .637 r
.60019 .36186 m .60271 .35954 L .60199 .36072 L F
0 0 .159 r
.60271 .35954 m .60154 .36331 L .60199 .36072 L F
.601 .832 .987 r
.42808 .48983 m .42931 .49143 L .43227 .49009 L F
.993 .772 .497 r
.39656 .48324 m .39762 .48709 L .39846 .48549 L F
.39656 .48324 m .39762 .48709 L .39846 .48549 L F
.856 .405 .117 r
.37501 .52927 m .37662 .53212 L .37861 .53302 L F
.902 .665 .571 r
.37662 .53212 m .37861 .53555 L .37861 .53302 L F
.706 .69 .832 r
.34743 .53548 m .35158 .53635 L .34964 .53281 L F
.161 0 0 r
.34746 .53933 m .35158 .53635 L .34743 .53548 L F
.34746 .53933 m .35006 .53853 L .35158 .53635 L F
0 0 0 r
.35158 .53635 m .35006 .53853 L .35209 .537 L F
.832 .76 .783 r
.41957 .52255 m .41521 .52244 L .41757 .51897 L F
.2 .346 .788 r
.41797 .52465 m .41521 .52244 L .41957 .52255 L F
0 0 0 r
.42194 .51969 m .42075 .52189 L .41957 .52255 L F
.4201 .52377 m .41957 .52255 L .42075 .52189 L F
.4201 .52377 m .41797 .52465 L .41957 .52255 L F
.832 .76 .783 r
.41957 .52255 m .41521 .52244 L .41757 .51897 L F
.548 .459 .706 r
.48483 .51053 m .48789 .51023 L .48694 .50685 L F
.467 .295 .563 r
.48483 .51053 m .48707 .51241 L .48789 .51023 L F
.48483 .51053 m .48512 .51308 L .48707 .51241 L F
.798 .743 .802 r
.57914 .41831 m .58134 .42091 L .57645 .42169 L F
.404 .222 .517 r
.58316 .41891 m .58134 .42091 L .58313 .42158 L F
.819 .994 .756 r
.73485 .30542 m .73214 .30754 L .73376 .30428 L F
.657 .89 .981 r
.73376 .30428 m .73516 .30383 L .73485 .30542 L F
.534 .227 .394 r
.73376 .30428 m .73516 .30383 L .73485 .30542 L F
.399 .837 .944 r
.24449 .58818 m .24255 .58787 L .2403 .58849 L F
0 .18 .698 r
.24507 .58771 m .24449 .58818 L .24255 .58787 L F
0 .042 .605 r
.24449 .58818 m .24507 .58771 L .24255 .58787 L F
.942 .864 .734 r
.57452 .3703 m .57443 .36606 L .57524 .36792 L F
.57452 .3703 m .57298 .36914 L .57443 .36606 L F
.755 .428 0 r
.57434 .37283 m .57298 .36914 L .57452 .3703 L F
0 0 .123 r
.2265 .55545 m .22797 .55142 L .22603 .55277 L F
.809 .988 .883 r
.46318 .52548 m .46732 .52334 L .46758 .52652 L F
.46318 .52548 m .46697 .52224 L .46732 .52334 L F
.937 .932 .575 r
.46732 .52334 m .46697 .52224 L .46793 .52043 L F
.543 .349 .568 r
.47037 .52308 m .46758 .52652 L .46732 .52334 L F
.855 .916 .872 r
.55095 .43051 m .55461 .42884 L .5541 .42805 L F
.737 .991 .866 r
.55461 .42884 m .55628 .42619 L .5541 .42805 L F
.746 .619 .718 r
.34625 .57196 m .3428 .57214 L .34149 .56877 L F
.948 .687 .507 r
.34342 .57356 m .3428 .57214 L .34625 .57196 L F
.648 .787 .948 r
.41079 .45343 m .41177 .45508 L .40767 .45441 L F
.663 .941 .963 r
.41277 .45306 m .41177 .45508 L .41079 .45343 L F
.41277 .45306 m .41468 .45357 L .41177 .45508 L F
.228 .015 .368 r
.49994 .51966 m .50004 .52227 L .49755 .5232 L F
.245 .025 .368 r
.50004 .52227 m .4972 .52556 L .49755 .5232 L F
0 0 0 r
.37596 .62312 m .37725 .62168 L .37923 .62031 L F
.696 .613 .759 r
.48825 .4943 m .49117 .49379 L .48935 .48994 L F
.614 .051 0 r
.28084 .57843 m .28286 .57862 L .27923 .57732 L F
.498 .335 .59 r
.28535 .58078 m .28295 .58169 L .28286 .57862 L F
.689 .15 0 r
.28314 .58045 m .28286 .57862 L .28084 .57843 L F
.704 .182 0 r
.2812 .58104 m .28314 .58045 L .28209 .57963 L F
.022 .55 .857 r
.28151 .58091 m .28314 .58045 L .2812 .58104 L F
.643 .083 0 r
.28209 .57963 m .28314 .58045 L .28084 .57843 L F
.022 .55 .857 r
.28383 .57999 m .28314 .58045 L .28151 .58091 L F
.689 .15 0 r
.28314 .58045 m .28535 .58078 L .28451 .58005 L F
.28314 .58045 m .28451 .58005 L .28286 .57862 L F
.03 0 0 r
.6594 .32084 m .66221 .32002 L .66327 .31892 L F
0 0 0 r
.66327 .31892 m .66221 .32002 L .66481 .31888 L F
.682 .341 .391 r
.27747 .58498 m .2731 .58711 L .27331 .5852 L F
.27747 .58498 m .27617 .5878 L .2731 .58711 L F
.358 .011 .232 r
.27857 .5871 m .27747 .58498 L .27987 .58442 L F
.27857 .5871 m .27617 .5878 L .27747 .58498 L F
.669 .901 .978 r
.44955 .44477 m .45294 .44468 L .45168 .44567 L F
.654 .542 .715 r
.48696 .47409 m .49074 .47457 L .48941 .47068 L F
.653 .534 .706 r
.48696 .47409 m .49075 .47732 L .49074 .47457 L F
.48696 .47409 m .48797 .47797 L .49075 .47732 L F
.248 0 .196 r
.53331 .49208 m .5312 .4914 L .53401 .48973 L F
.264 0 .028 r
.53669 .49012 m .53331 .49208 L .53401 .48973 L F
.248 .719 .943 r
.66799 .36004 m .66898 .36069 L .66502 .36006 L F
.66502 .36006 m .66898 .36069 L .66799 .36004 L F
.61 .925 .97 r
.66799 .36004 m .66898 .36069 L .67061 .35875 L F
.67061 .35875 m .66898 .36069 L .66799 .36004 L F
.248 .719 .943 r
.66799 .36004 m .66898 .36069 L .66502 .36006 L F
.667 .46 .595 r
.33784 .61427 m .33406 .61111 L .3362 .61038 L F
.33784 .61427 m .33572 .61473 L .33406 .61111 L F
.451 .849 .654 r
.64019 .39111 m .64178 .39025 L .63833 .39251 L F
0 0 0 r
.64595 .38752 m .64385 .38822 L .64326 .38878 L F
.609 .762 .952 r
.64595 .38752 m .64326 .38878 L .64311 .38858 L F
.64449 .38717 m .64311 .38858 L .64154 .38644 L F
.33 .03 .296 r
.64606 .38713 m .64658 .38566 L .64385 .38822 L F
0 0 0 r
.64595 .38752 m .64606 .38713 L .64385 .38822 L F
.609 .762 .952 r
.64595 .38752 m .64311 .38858 L .64449 .38717 L F
.607 .923 .681 r
.64385 .38822 m .64178 .39025 L .64117 .39058 L F
.6422 .38952 m .64117 .39058 L .64019 .39111 L F
.64385 .38822 m .64117 .39058 L .6422 .38952 L F
.74 .934 .951 r
.42691 .48009 m .42419 .48118 L .42483 .47961 L F
.649 .383 .502 r
.42483 .47961 m .42903 .47687 L .42691 .48009 L F
.075 0 .281 r
.69434 .28903 m .69655 .28889 L .69741 .2883 L F
.69434 .28903 m .6942 .29141 L .69655 .28889 L F
.443 .473 .796 r
.2556 .60056 m .25408 .60155 L .2531 .59771 L F
.238 0 0 r
.2556 .60056 m .2518 .60084 L .25408 .60155 L F
.649 .337 .429 r
.45538 .57864 m .45881 .58023 L .45726 .57734 L F
.45538 .57864 m .455 .58158 L .45881 .58023 L F
.988 .742 .361 r
.59924 .41274 m .59812 .414 L .59815 .41138 L F
.59924 .41274 m .5992 .41531 L .59812 .414 L F
.596 .237 .331 r
.71972 .32431 m .71535 .32664 L .71549 .3257 L F
.71972 .32431 m .71802 .32699 L .71535 .32664 L F
.609 .086 0 r
.36087 .52169 m .35529 .51972 L .3586 .51964 L F
0 0 0 r
.71269 .32809 m .71549 .3257 L .71535 .32664 L F
.929 .845 .74 r
.38004 .60719 m .37642 .60978 L .37633 .60727 L F
.38004 .60719 m .37818 .61096 L .37642 .60978 L F
.382 .512 .864 r
.35477 .53559 m .35489 .53134 L .35259 .53266 L F
.402 .825 .654 r
.35477 .53559 m .35552 .53498 L .3558 .53545 L F
.741 .952 .646 r
.34234 .63425 m .33964 .63764 L .3405 .63572 L F
.744 .964 .682 r
.3405 .63572 m .33964 .63764 L .33775 .63887 L F
.451 .798 .998 r
.59753 .3819 m .59894 .38296 L .596 .38345 L F
.59753 .3819 m .59894 .38296 L .596 .38345 L F
.753 .797 .888 r
.56582 .41601 m .56221 .41596 L .56388 .41443 L F
.588 .765 .963 r
.32413 .65937 m .32481 .65656 L .32184 .6568 L F
.32413 .65937 m .32684 .65862 L .32481 .65656 L F
.983 .699 .344 r
.59497 .39574 m .59642 .3997 L .59512 .39838 L F
.981 .688 .347 r
.59642 .3997 m .59522 .401 L .59512 .39838 L F
.59642 .3997 m .59658 .40223 L .59522 .401 L F
.927 .877 .454 r
.73115 .31707 m .7314 .3182 L .73206 .31528 L F
0 0 .262 r
.73202 .32008 m .7314 .3182 L .73115 .31707 L F
.818 .661 .688 r
.69741 .2883 m .6998 .28893 L .70006 .28608 L F
.294 0 0 r
.29166 .50883 m .2905 .50992 L .29406 .50878 L F
.517 .729 .97 r
.52264 .39803 m .52165 .40029 L .52006 .39807 L F
.52264 .39803 m .52474 .39996 L .52165 .40029 L F
.441 .079 .252 r
.5312 .4914 m .53083 .49313 L .52814 .49345 L F
.248 0 .196 r
.53331 .49208 m .53083 .49313 L .5312 .4914 L F
.02 0 0 r
.30999 .64916 m .31041 .64862 L .30735 .64972 L F
.954 .914 .548 r
.43417 .55081 m .43482 .55226 L .43569 .54933 L F
.741 .993 .842 r
.43569 .54933 m .43524 .54856 L .43662 .54744 L F
.718 .914 .559 r
.43662 .54744 m .43417 .55081 L .43569 .54933 L F
.755 .939 .944 r
.46874 .45937 m .47164 .45958 L .47311 .4584 L F
0 0 0 r
.67582 .36335 m .67335 .36459 L .67266 .36549 L F
.83 .701 .722 r
.31489 .57978 m .32059 .58173 L .31748 .58448 L F
.775 .595 .656 r
.32059 .58173 m .32083 .586 L .31748 .58448 L F
.319 .244 .613 r
.32326 .58445 m .32059 .58173 L .3253 .58018 L F
.32326 .58445 m .32083 .586 L .32059 .58173 L F
.909 .538 .314 r
.3836 .5127 m .38112 .5096 L .38345 .50992 L F
.303 .376 .773 r
.62089 .39396 m .61879 .39543 L .61779 .39203 L F
.639 .132 .027 r
.62077 .39759 m .61879 .39543 L .61889 .3987 L F
.087 0 .419 r
.61889 .3987 m .61879 .39543 L .62089 .39396 L F
.668 .373 .465 r
.47674 .52226 m .48098 .52309 L .47974 .51988 L F
.447 .299 .587 r
.47974 .51988 m .48255 .51952 L .48212 .51616 L F
.521 .348 .587 r
.48098 .52309 m .48255 .51952 L .47974 .51988 L F
.143 0 0 r
.26035 .51941 m .26309 .51915 L .26588 .51632 L F
0 0 0 r
.26588 .51632 m .26309 .51915 L .26609 .5176 L F
.558 .933 .9 r
.29072 .65825 m .29362 .6578 L .29579 .65666 L F
.94 .579 .285 r
.37286 .52605 m .37324 .5285 L .37501 .52927 L F
.874 .577 .482 r
.37324 .5285 m .37662 .53212 L .37501 .52927 L F
.736 .704 .821 r
.3405 .64684 m .34259 .65013 L .33841 .64977 L F
.702 .47 .57 r
.34259 .65013 m .3383 .65319 L .33841 .64977 L F
.34259 .65013 m .34294 .6516 L .3383 .65319 L F
.813 .725 .769 r
.34464 .64645 m .34259 .65013 L .3405 .64684 L F
.59 .58 .81 r
.34259 .65013 m .3445 .65157 L .34496 .65184 L F
.3445 .65157 m .34636 .65297 L .34496 .65184 L F
.159 0 0 r
.34544 .65212 m .34496 .65184 L .34726 .65191 L F
.327 0 0 r
.33838 .65412 m .34294 .6516 L .34496 .65184 L F
.33838 .65412 m .34496 .65184 L .34247 .65245 L F
.402 .282 .601 r
.34496 .65184 m .34294 .6516 L .34259 .65013 L F
.148 0 0 r
.3383 .65319 m .34294 .6516 L .33838 .65412 L F
.702 .757 .895 r
.34224 .6525 m .34376 .64901 L .34162 .65252 L F
.327 0 0 r
.34072 .65314 m .34234 .6525 L .34224 .6525 L F
.33838 .65412 m .34247 .65245 L .34072 .65314 L F
0 0 0 r
.33838 .65412 m .34224 .6525 L .34123 .65317 L F
.702 .757 .895 r
.34224 .6525 m .34162 .65252 L .34123 .65317 L F
.327 0 0 r
.34234 .6525 m .34247 .65245 L .34224 .6525 L F
.148 0 0 r
.3383 .65319 m .33838 .65412 L .3382 .6553 L F
.68 .922 .972 r
.33628 .65452 m .33674 .65471 L .33879 .65335 L F
.1 .301 .779 r
.33879 .65335 m .3382 .6553 L .33838 .65412 L F
.68 .922 .972 r
.33674 .65471 m .3382 .6553 L .3386 .65397 L F
.33674 .65471 m .3386 .65397 L .33879 .65335 L F
.159 0 0 r
.34224 .6525 m .34496 .65184 L .34544 .65212 L F
.977 .781 .575 r
.47288 .53857 m .47486 .53972 L .47415 .54224 L F
.104 0 0 r
.67224 .38152 m .67315 .38001 L .67577 .3791 L F
.803 .561 .571 r
.31871 .56737 m .32396 .56557 L .32189 .56544 L F
.31871 .56737 m .32378 .56831 L .32396 .56557 L F
.49 .831 .998 r
.32396 .56557 m .32652 .56502 L .32493 .56399 L F
.613 .952 .918 r
.32493 .56399 m .32189 .56544 L .32396 .56557 L F
.542 .35 .57 r
.32378 .56831 m .32652 .56502 L .32396 .56557 L F
.978 .703 .437 r
.39087 .5673 m .39257 .56543 L .39081 .56445 L F
.39087 .5673 m .39255 .56847 L .39257 .56543 L F
0 0 .019 r
.31071 .62747 m .30758 .63091 L .31003 .63043 L F
.393 .103 .348 r
.3123 .62915 m .31071 .62747 L .31003 .63043 L F
.3123 .62915 m .31267 .62706 L .31071 .62747 L F
.076 0 0 r
.31577 .56475 m .31826 .56425 L .32053 .56291 L F
0 0 0 r
.32053 .56291 m .32059 .56339 L .32154 .56151 L F
.32053 .56291 m .31826 .56425 L .32059 .56339 L F
.771 .445 0 r
.59114 .38984 m .59126 .39125 L .58934 .38899 L F
.59114 .38984 m .59191 .39233 L .59126 .39125 L F
.777 .648 .719 r
.23384 .60428 m .23524 .60828 L .23187 .60704 L F
.971 .876 .684 r
.23524 .60828 m .2328 .6101 L .23187 .60704 L F
.07 .21 .703 r
.23607 .60651 m .23524 .60828 L .23384 .60428 L F
0 0 .184 r
.23605 .60924 m .23524 .60828 L .23607 .60651 L F
0 0 0 r
.29099 .64693 m .29331 .64338 L .29306 .64636 L F
.759 .612 .695 r
.43704 .46447 m .44105 .46682 L .44108 .46523 L F
.43704 .46447 m .43754 .46733 L .44105 .46682 L F
.689 .65 .806 r
.44108 .46523 m .44105 .46682 L .4437 .46436 L F
0 0 .349 r
.32198 .53167 m .32172 .53559 L .31957 .53316 L F
.32187 .53345 m .32246 .5346 L .32172 .53559 L F
0 0 .147 r
.32218 .53768 m .32172 .53559 L .32246 .5346 L F
.253 .114 .49 r
.32394 .53656 m .32218 .53768 L .32246 .5346 L F
.482 .558 .857 r
.31988 .53332 m .32313 .53591 L .32246 .5346 L F
.32313 .53591 m .32394 .53656 L .32246 .5346 L F
0 0 .349 r
.32198 .53167 m .32246 .5346 L .32187 .53345 L F
0 0 .147 r
.32218 .53768 m .32137 .53935 L .32172 .53559 L F
.909 .708 .619 r
.59139 .4443 m .59298 .44815 L .59351 .44513 L F
.654 .82 .963 r
.35843 .64461 m .35877 .64467 L .35679 .64594 L F
.35843 .64461 m .36099 .64361 L .35883 .6425 L F
.35843 .64461 m .35883 .6425 L .35877 .64467 L F
.371 0 0 r
.29037 .57426 m .29259 .57414 L .29477 .57267 L F
.442 0 0 r
.29259 .57414 m .29714 .57375 L .29477 .57267 L F
.264 .102 .465 r
.33695 .56818 m .33559 .5714 L .33518 .56913 L F
.07 0 0 r
.53289 .39553 m .53204 .39653 L .53329 .39586 L F
.258 0 .09 r
.24017 .55403 m .23587 .55758 L .23677 .55549 L F
.743 .63 .735 r
.49075 .47732 m .49467 .47785 L .49337 .47379 L F
.745 .621 .721 r
.49075 .47732 m .49207 .48088 L .49467 .47785 L F
.656 .581 .759 r
.49337 .47379 m .49467 .47785 L .4973 .4771 L F
.82 .723 .757 r
.60848 .35394 m .61291 .35373 L .61175 .35262 L F
.60848 .35394 m .61024 .35745 L .61291 .35373 L F
.594 .405 .596 r
.61024 .35745 m .61352 .35704 L .61291 .35373 L F
.666 .925 .974 r
.61432 .35116 m .61528 .35149 L .61574 .35106 L F
.364 0 0 r
.61831 .34976 m .61721 .3512 L .61432 .35116 L F
.374 .793 .976 r
.61721 .3512 m .61377 .35098 L .61432 .35116 L F
.61377 .35098 m .61316 .35094 L .61432 .35116 L F
.666 .925 .974 r
.61432 .35116 m .61291 .35373 L .61528 .35149 L F
.61432 .35116 m .61175 .35262 L .61291 .35373 L F
.36 0 .032 r
.43293 .55802 m .43787 .55546 L .43301 .55532 L F
.43293 .55802 m .43551 .55768 L .43787 .55546 L F
.638 .229 .253 r
.43787 .55546 m .43551 .55768 L .43729 .55699 L F
.91 .815 .741 r
.59221 .43894 m .58925 .43536 L .59047 .43782 L F
.969 .785 .602 r
.59047 .43782 m .59164 .44156 L .59221 .43894 L F
.3 0 .22 r
.52243 .4971 m .52424 .49867 L .5216 .49922 L F
.52243 .4971 m .52489 .49619 L .52424 .49867 L F
0 0 .491 r
.22683 .54346 m .22864 .54399 L .22859 .54123 L F
.22683 .54346 m .22723 .54578 L .22864 .54399 L F
.529 .917 .8 r
.48575 .42491 m .4835 .4263 L .48154 .42686 L F
.511 0 0 r
.45235 .59542 m .45067 .59644 L .44846 .59606 L F
.342 0 0 r
.45471 .59585 m .45067 .59644 L .45235 .59542 L F
.91 .542 .321 r
.39272 .52325 m .39063 .52252 L .38995 .51979 L F
.929 .548 .241 r
.39272 .52325 m .39153 .52468 L .39063 .52252 L F
.39272 .52325 m .39332 .52578 L .39153 .52468 L F
.974 .846 .444 r
.39133 .5901 m .39153 .5945 L .39195 .59181 L F
.971 .748 .542 r
.26732 .58521 m .26658 .58773 L .2649 .58568 L F
0 0 0 r
.2649 .58568 m .26959 .58403 L .26732 .58521 L F
.688 .409 .494 r
.27044 .58715 m .26732 .58521 L .26959 .58403 L F
.27044 .58715 m .26658 .58773 L .26732 .58521 L F
.51 .329 .571 r
.42121 .581 m .41868 .58436 L .41903 .58167 L F
.615 .121 0 r
.22934 .57819 m .22619 .57467 L .22934 .57872 L F
0 0 0 r
.63448 .34408 m .63016 .34502 L .63192 .34535 L F
.743 .918 .951 r
.58938 .35442 m .59285 .3539 L .59161 .35303 L F
.532 .92 .912 r
.59507 .35289 m .59367 .35312 L .59285 .3539 L F
.467 .825 .996 r
.59285 .3539 m .59423 .35258 L .59161 .35303 L F
.465 0 0 r
.59555 .35369 m .59026 .35398 L .59084 .35357 L F
.59289 .35324 m .59084 .35357 L .59161 .35303 L F
.59555 .35369 m .59084 .35357 L .59289 .35324 L F
.532 .92 .912 r
.59552 .35269 m .59423 .35258 L .59367 .35312 L F
.59552 .35269 m .59367 .35312 L .59507 .35289 L F
.847 .891 .87 r
.45901 .44133 m .45469 .44286 L .45827 .44105 L F
.751 .976 .921 r
.45985 .43905 m .46236 .439 L .45901 .44133 L F
.798 .998 .794 r
.45985 .43905 m .45901 .44133 L .45827 .44105 L F
.177 .348 .797 r
.43245 .53939 m .43524 .54172 L .43346 .54192 L F
0 0 .234 r
.43461 .54314 m .43346 .54192 L .43524 .54172 L F
.43461 .54314 m .43358 .54457 L .43346 .54192 L F
.682 .745 .898 r
.58261 .37011 m .58 .37131 L .57863 .36919 L F
.903 .707 .629 r
.70046 .31323 m .70301 .31507 L .70233 .31169 L F
.88 .451 .159 r
.70046 .31323 m .70193 .31615 L .70301 .31507 L F
.759 .903 .514 r
.70301 .31507 m .70193 .31615 L .70413 .31255 L F
.597 .738 .943 r
.70413 .31255 m .70591 .31414 L .70301 .31507 L F
.6 .665 .885 r
.30868 .65679 m .31111 .66018 L .31306 .65902 L F
.087 .06 .528 r
.3303 .57364 m .32853 .57189 L .33291 .57036 L F
.571 .095 .086 r
.33291 .57036 m .33271 .57305 L .3303 .57364 L F
.33291 .57036 m .33559 .5714 L .33271 .57305 L F
.719 .759 .884 r
.48115 .46443 m .48509 .4649 L .48389 .46343 L F
.668 .758 .918 r
.48509 .4649 m .48649 .46219 L .48389 .46343 L F
.48509 .4649 m .48794 .46429 L .48649 .46219 L F
.999 .842 .544 r
.40732 .57508 m .40773 .57861 L .40677 .57746 L F
.97 .657 .346 r
.40773 .57861 m .40645 .58014 L .40677 .57746 L F
.40773 .57861 m .40804 .58122 L .40645 .58014 L F
.922 .83 .737 r
.6309 .35559 m .62632 .35858 L .62956 .35568 L F
.6309 .35559 m .62796 .36066 L .62632 .35858 L F
.834 .997 .772 r
.63285 .35284 m .6309 .35559 L .62956 .35568 L F
.333 .114 .424 r
.3359 .58775 m .33747 .59008 L .33732 .58731 L F
.3359 .58775 m .33531 .59139 L .33747 .59008 L F
0 .542 .76 r
.411 .5941 m .41492 .59469 L .41376 .59442 L F
.833 .998 .831 r
.41376 .59442 m .41492 .59469 L .41781 .59175 L F
.806 .974 .902 r
.33886 .56991 m .33559 .5714 L .33695 .56818 L F
.706 .773 .905 r
.34149 .56877 m .33886 .56991 L .33695 .56818 L F
.469 .597 .897 r
.3428 .57214 m .33886 .56991 L .34149 .56877 L F
.451 .849 .654 r
.64019 .39111 m .63833 .39251 L .63795 .39238 L F
.085 0 0 r
.62629 .34013 m .62899 .3393 L .63008 .33797 L F
.055 0 0 r
.63008 .33797 m .63163 .33843 L .63272 .33706 L F
.63008 .33797 m .62899 .3393 L .63163 .33843 L F
.867 .761 .743 r
.56458 .42575 m .56485 .42852 L .56097 .42752 L F
.884 .713 .666 r
.56097 .42752 m .56485 .42852 L .56244 .43147 L F
.948 .591 .253 r
.56485 .42852 m .56534 .43133 L .56244 .43147 L F
.698 .614 .759 r
.48935 .48994 m .49117 .49379 L .49352 .49034 L F
.539 .404 .645 r
.49117 .49379 m .49419 .49353 L .49352 .49034 L F
.328 .108 .42 r
.4918 .49647 m .49419 .49353 L .49117 .49379 L F
.602 .408 .59 r
.45365 .56872 m .45393 .57148 L .45063 .57195 L F
0 0 0 r
.45237 .57104 m .45365 .56872 L .45063 .57195 L F
0 0 .449 r
.45509 .57139 m .45393 .57148 L .45365 .56872 L F
.621 .18 .181 r
.45509 .57139 m .45365 .56872 L .45237 .57104 L F
.421 .147 .39 r
.41221 .49042 m .41406 .48806 L .4137 .48838 L F
.916 .753 .665 r
.393 .57485 m .39393 .57239 L .39169 .5711 L F
1 .812 .482 r
.40657 .56211 m .40551 .56204 L .406 .5584 L F
0 .028 .599 r
.40657 .5649 m .40551 .56204 L .40657 .56211 L F
.84 .847 .85 r
.71358 .30141 m .70974 .30171 L .71229 .30066 L F
.496 .864 .985 r
.71358 .30141 m .71229 .30066 L .71641 .30047 L F
.695 .578 .72 r
.33991 .59572 m .33774 .59825 L .34086 .59774 L F
.568 .397 .609 r
.34094 .59827 m .34096 .59832 L .34013 .5983 L F
.34018 .59827 m .34013 .5983 L .33774 .59825 L F
.34094 .59827 m .34013 .5983 L .34018 .59827 L F
0 0 0 r
.34086 .59774 m .34037 .59812 L .34166 .59733 L F
.34037 .59812 m .34018 .59827 L .34079 .59788 L F
.34037 .59812 m .34079 .59788 L .34166 .59733 L F
.386 .301 .637 r
.34264 .59684 m .34096 .59832 L .34079 .59788 L F
.288 .365 .768 r
.34086 .59774 m .34264 .59684 L .33991 .59572 L F
.386 .301 .637 r
.34264 .59684 m .34079 .59788 L .33991 .59572 L F
.427 0 .04 r
.33774 .59825 m .34018 .59827 L .34086 .59774 L F
.568 .397 .609 r
.33991 .59572 m .34094 .59827 L .33774 .59825 L F
.43 0 .03 r
.34096 .59832 m .33909 .59911 L .33774 .59825 L F
0 0 0 r
.34166 .59733 m .33909 .59911 L .34264 .59684 L F
.34018 .59827 m .33909 .59911 L .34166 .59733 L F
.427 0 .04 r
.33774 .59825 m .33909 .59911 L .34018 .59827 L F
.337 0 0 r
.56653 .40428 m .56942 .40527 L .56514 .40411 L F
.717 .495 .587 r
.34578 .51348 m .34713 .51664 L .34331 .51616 L F
.751 .623 .717 r
.3463 .50959 m .34578 .51348 L .34522 .50936 L F
.68 .478 .606 r
.34979 .5162 m .34713 .51664 L .34578 .51348 L F
.968 .934 .644 r
.70649 .33628 m .70752 .33472 L .70581 .33554 L F
.837 .941 .575 r
.7083 .33199 m .70752 .33472 L .70953 .331 L F
.857 .988 .717 r
.70581 .33554 m .70752 .33472 L .7083 .33199 L F
.802 .311 0 r
.42676 .55126 m .42918 .55445 L .42731 .5537 L F
.875 .975 .844 r
.49776 .41565 m .49481 .41901 L .49411 .41782 L F
.864 .894 .855 r
.44326 .45811 m .44484 .45914 L .44501 .45682 L F
.51 .591 .872 r
.44484 .45914 m .44747 .45646 L .44501 .45682 L F
.397 .41 .757 r
.44729 .45863 m .44747 .45646 L .44484 .45914 L F
.846 .664 .656 r
.43323 .58536 m .43416 .58836 L .42956 .58751 L F
.826 .742 .772 r
.42956 .58751 m .43416 .58836 L .43105 .59173 L F
.421 .152 .398 r
.43105 .59173 m .43416 .58836 L .43337 .59115 L F
.452 .437 .752 r
.43585 .58524 m .43416 .58836 L .43323 .58536 L F
.827 .737 .765 r
.43585 .58524 m .43337 .59115 L .43416 .58836 L F
0 0 0 r
.53861 .44584 m .534 .44772 L .53689 .4474 L F
.54086 .4445 m .53861 .44584 L .53689 .4474 L F
.847 .923 .882 r
.72678 .2966 m .72432 .29884 L .72341 .29897 L F
.69 .318 .337 r
.35656 .6033 m .35582 .60069 L .35792 .60103 L F
.35656 .6033 m .35437 .60357 L .35582 .60069 L F
.952 .919 .741 r
.30172 .64728 m .30262 .64617 L .30377 .64365 L F
.849 .965 .878 r
.30517 .64134 m .30684 .64069 L .30377 .64365 L F
0 0 .182 r
.30377 .64365 m .30421 .64454 L .30496 .64205 L F
.30483 .64189 m .30496 .64205 L .30517 .64134 L F
.30377 .64365 m .30496 .64205 L .30483 .64189 L F
.30421 .64454 m .305 .64263 L .30517 .64134 L F
.298 .042 .348 r
.30547 .6421 m .30517 .64134 L .30506 .64218 L F
.68 .556 .707 r
.30548 .64146 m .30542 .64215 L .30514 .64228 L F
.30542 .64215 m .30541 .64227 L .30531 .64227 L F
.36 0 0 r
.30531 .64227 m .30541 .64227 L .30537 .6423 L F
.298 .042 .348 r
.30762 .64172 m .30506 .64218 L .30673 .64282 L F
.68 .556 .707 r
.30542 .64215 m .30531 .64227 L .30514 .64228 L F
.298 .042 .348 r
.30762 .64172 m .30603 .64147 L .30547 .6421 L F
.30603 .64147 m .3054 .64137 L .30547 .6421 L F
0 0 .113 r
.30603 .64124 m .30542 .64225 L .30553 .64084 L F
.30542 .64225 m .30541 .64227 L .30542 .64215 L F
.30542 .64225 m .30542 .64215 L .30553 .64084 L F
.298 .042 .348 r
.3054 .64137 m .30517 .64134 L .30542 .64198 L F
.3054 .64137 m .30542 .64198 L .30547 .6421 L F
.30537 .6423 m .30506 .64218 L .305 .64259 L F
.36 0 0 r
.30514 .64228 m .30531 .64227 L .30522 .64238 L F
.30531 .64227 m .30537 .6423 L .30522 .64238 L F
.30181 .64239 m .30514 .64228 L .30244 .64396 L F
.30514 .64228 m .30522 .64238 L .30244 .64396 L F
.68 .556 .707 r
.30548 .64146 m .30514 .64228 L .30181 .64239 L F
.2 .38 .818 r
.30553 .64084 m .30517 .64134 L .30762 .64172 L F
.561 .908 .692 r
.30244 .64396 m .30537 .6423 L .30603 .64124 L F
.30537 .6423 m .30541 .64227 L .30542 .64225 L F
.30537 .6423 m .30542 .64225 L .30603 .64124 L F
.298 .042 .348 r
.30673 .64282 m .30537 .6423 L .30463 .64538 L F
.30537 .6423 m .305 .64259 L .30463 .64538 L F
.68 .556 .707 r
.30553 .64084 m .30548 .64146 L .30181 .64239 L F
0 0 .182 r
.30421 .64454 m .30463 .64538 L .305 .64263 L F
.30274 .64591 m .30262 .64617 L .30463 .64538 L F
.943 .899 .753 r
.30172 .64728 m .29979 .64866 L .29998 .64799 L F
.29979 .64866 m .29961 .64879 L .29988 .64821 L F
.29979 .64866 m .29988 .64821 L .29998 .64799 L F
.605 .562 .78 r
.29774 .64215 m .3 .64763 L .29656 .64828 L F
.29992 .64802 m .30023 .6482 L .29988 .64821 L F
.943 .899 .753 r
.30172 .64728 m .30083 .64985 L .29961 .64879 L F
.602 .452 .65 r
.30181 .64239 m .30031 .64793 L .29774 .64215 L F
.30031 .64793 m .30023 .6482 L .30014 .64798 L F
.30031 .64793 m .30014 .64798 L .29774 .64215 L F
.30072 .64641 m .30237 .64643 L .30065 .64786 L F
.30031 .64793 m .30065 .64786 L .30023 .6482 L F
.943 .899 .753 r
.30172 .64728 m .29998 .64799 L .3002 .64795 L F
.602 .452 .65 r
.30072 .64641 m .30065 .64786 L .30031 .64793 L F
.943 .899 .753 r
.3002 .64795 m .29992 .64802 L .30014 .64798 L F
.29998 .64799 m .29992 .64802 L .3002 .64795 L F
0 0 0 r
.30023 .6482 m .30065 .64786 L .30141 .64801 L F
.943 .899 .753 r
.30161 .64755 m .30058 .64785 L .30154 .64771 L F
.30058 .64785 m .3007 .64787 L .30154 .64771 L F
.30172 .64728 m .30014 .64798 L .30161 .64755 L F
.811 .576 .583 r
.30172 .64728 m .30485 .65021 L .30083 .64985 L F
.943 .899 .753 r
.30172 .64728 m .30141 .64801 L .30262 .64617 L F
0 0 0 r
.30065 .64786 m .30237 .64643 L .30141 .64801 L F
.943 .899 .753 r
.30058 .64785 m .30014 .64798 L .3007 .64787 L F
.30154 .64771 m .29911 .64835 L .30141 .64801 L F
.605 .562 .78 r
.30014 .64798 m .30023 .6482 L .29992 .64802 L F
.943 .899 .753 r
.29992 .64802 m .29911 .64835 L .30154 .64771 L F
.605 .562 .78 r
.3 .64763 m .30014 .64798 L .29992 .64802 L F
.3 .64763 m .29988 .64821 L .29656 .64828 L F
.602 .452 .65 r
.30181 .64239 m .30199 .64368 L .30072 .64641 L F
.30199 .64368 m .30237 .64643 L .30072 .64641 L F
.943 .899 .753 r
.29998 .64799 m .29961 .64879 L .29911 .64835 L F
.36 0 0 r
.30181 .64239 m .30244 .64396 L .30238 .64608 L F
.30233 .64609 m .30238 .64608 L .30237 .64643 L F
.30181 .64239 m .30238 .64608 L .30233 .64609 L F
0 0 0 r
.30463 .64538 m .30262 .64617 L .30141 .64801 L F
0 0 .182 r
.30377 .64365 m .30274 .64591 L .30463 .64538 L F
.876 .907 .498 r
.30166 .64701 m .30237 .64643 L .30244 .64396 L F
.30141 .64801 m .30197 .64709 L .30166 .64701 L F
.30197 .64709 m .30237 .64643 L .30166 .64701 L F
.30141 .64801 m .30244 .64396 L .30463 .64538 L F
.167 0 .304 r
.30206 .64627 m .30181 .64644 L .30244 .64396 L F
.30181 .64644 m .30008 .64759 L .30244 .64396 L F
.30206 .64627 m .30008 .64759 L .30244 .64396 L F
.512 .908 .787 r
.29957 .6476 m .30008 .64759 L .30115 .64688 L F
.301 .64684 m .30115 .64688 L .30206 .64627 L F
.29957 .6476 m .30115 .64688 L .301 .64684 L F
0 0 0 r
.30685 .64469 m .30206 .64627 L .30332 .64631 L F
.959 .675 .454 r
.30206 .64627 m .30244 .64396 L .30052 .6434 L F
0 0 0 r
.30442 .64549 m .30463 .64538 L .30274 .64604 L F
.3028 .64603 m .30274 .64604 L .30206 .64627 L F
.30561 .6451 m .30274 .64604 L .3028 .64603 L F
.098 0 .278 r
.30206 .64627 m .30244 .64396 L .30332 .64631 L F
.773 .266 0 r
.30302 .646 m .30244 .64396 L .30052 .6434 L F
.30332 .64631 m .30318 .64594 L .30302 .646 L F
.30318 .64594 m .30244 .64396 L .30302 .646 L F
0 0 0 r
.30561 .6451 m .30505 .64526 L .30442 .64549 L F
.30505 .64526 m .30463 .64538 L .30442 .64549 L F
.30685 .64469 m .30463 .64538 L .30561 .6451 L F
.485 .901 .867 r
.57345 .45177 m .57075 .45291 L .5721 .45277 L F
.794 .804 .86 r
.53895 .40526 m .54261 .40532 L .54211 .40253 L F
.91 .838 .762 r
.60015 .37542 m .60381 .37348 L .60218 .37198 L F
.60015 .37542 m .60147 .3766 L .60381 .37348 L F
.781 .612 .671 r
.60381 .37348 m .60147 .3766 L .60478 .37648 L F
.812 .848 .877 r
.60218 .37198 m .60381 .37348 L .60682 .37074 L F
.961 .637 .244 r
.58744 .41182 m .58571 .40947 L .58635 .4111 L F
.913 .948 .6 r
.58607 .41282 m .58744 .41182 L .58635 .4111 L F
.58607 .41282 m .58566 .41561 L .58744 .41182 L F
.566 .384 .594 r
.41406 .48806 m .41128 .48487 L .41337 .48344 L F
.421 .147 .39 r
.41221 .49042 m .41473 .48972 L .41406 .48806 L F
.124 .254 .728 r
.41489 .48471 m .41406 .48806 L .41337 .48344 L F
.831 .375 0 r
.41303 .48841 m .41406 .48806 L .41489 .48471 L F
.41303 .48841 m .41473 .48972 L .41406 .48806 L F
0 0 0 r
.28062 .58025 m .27409 .58255 L .27649 .58249 L F
.003 .163 .678 r
.28062 .58025 m .28084 .57843 L .27923 .57732 L F
.28062 .58025 m .28209 .57963 L .28084 .57843 L F
0 0 0 r
.27892 .5819 m .28062 .58025 L .27649 .58249 L F
.27892 .5819 m .28209 .57963 L .28062 .58025 L F
.948 .687 .507 r
.34342 .57356 m .34095 .57376 L .3428 .57214 L F
.866 .458 .001 r
.34342 .57356 m .34347 .57613 L .34095 .57376 L F
.34342 .57356 m .34476 .57735 L .34347 .57613 L F
.895 .473 .143 r
.34677 .57847 m .3449 .57775 L .34342 .57356 L F
.719 .9 .96 r
.34446 .57395 m .34226 .57498 L .34347 .57613 L F
.63 .287 .371 r
.34347 .57613 m .34054 .57627 L .34095 .57376 L F
.719 .9 .96 r
.34226 .57498 m .34171 .57523 L .34347 .57613 L F
.866 .458 .001 r
.34476 .57735 m .3449 .57775 L .34347 .57613 L F
.043 0 0 r
.2409 .5489 m .23873 .5505 L .23927 .54958 L F
.2409 .5489 m .23859 .55118 L .23873 .5505 L F
.2409 .5489 m .2404 .55085 L .23859 .55118 L F
0 0 0 r
.24397 .54593 m .2409 .5489 L .24495 .54646 L F
.24375 .54581 m .24286 .54678 L .24397 .54593 L F
.24286 .54678 m .2409 .5489 L .24397 .54593 L F
.481 .362 .64 r
.24495 .54646 m .2471 .54322 L .24317 .5455 L F
.24495 .54646 m .24722 .54648 L .2471 .54322 L F
0 0 0 r
.24647 .5458 m .24454 .54682 L .24657 .54397 L F
.247 .54364 m .24657 .54397 L .2471 .54322 L F
.24647 .5458 m .24657 .54397 L .247 .54364 L F
.061 0 0 r
.24576 .5445 m .24454 .54682 L .24242 .54767 L F
.2471 .54322 m .24657 .54397 L .24576 .5445 L F
.24657 .54397 m .24454 .54682 L .24576 .5445 L F
0 0 0 r
.24317 .5455 m .24235 .54672 L .24375 .54581 L F
.24235 .54672 m .2409 .5489 L .24375 .54581 L F
.24317 .5455 m .24157 .54849 L .2409 .5489 L F
.24157 .54849 m .2404 .55085 L .2409 .5489 L F
.62 .481 .672 r
.48952 .5007 m .48982 .50365 L .49229 .50009 L F
.43 .811 .991 r
.25181 .58449 m .24992 .58286 L .25242 .58366 L F
.894 .968 .826 r
.25181 .58449 m .24732 .58617 L .24992 .58286 L F
.913 .578 .108 r
.58453 .3977 m .58494 .39684 L .58385 .39562 L F
.58453 .3977 m .58562 .39926 L .58494 .39684 L F
.747 .981 .912 r
.52407 .41278 m .52525 .41026 L .52369 .41197 L F
.52407 .41278 m .52767 .41033 L .52525 .41026 L F
0 .288 .788 r
.52653 .41508 m .52721 .41527 L .52407 .41278 L F
0 .148 .665 r
.52369 .41197 m .52653 .41508 L .52407 .41278 L F
.78 .749 .825 r
.41284 .46662 m .41018 .46788 L .41462 .46828 L F
.786 .861 .905 r
.40951 .46937 m .41462 .46828 L .41018 .46788 L F
.743 .747 .855 r
.41284 .46662 m .41462 .46828 L .41746 .467 L F
.996 .814 .546 r
.69315 .32822 m .69146 .32945 L .69136 .32686 L F
.69315 .32822 m .69272 .33089 L .69146 .32945 L F
.609 .427 .609 r
.31191 .57506 m .31453 .57732 L .31587 .57515 L F
.511 .357 .608 r
.31587 .57515 m .31826 .57477 L .31796 .57202 L F
.671 .464 .597 r
.31453 .57732 m .31826 .57477 L .31587 .57515 L F
.746 .892 .945 r
.4223 .46307 m .42691 .46226 L .42472 .46053 L F
.4223 .46307 m .42295 .46368 L .42691 .46226 L F
.057 .279 .77 r
.42691 .46226 m .42735 .45976 L .42472 .46053 L F
.393 .247 .562 r
.342 .51782 m .34101 .51592 L .34331 .51616 L F
.342 .51782 m .34055 .51961 L .34101 .51592 L F
0 0 0 r
.71003 .29881 m .70602 .29959 L .70654 .30113 L F
.81 .914 .52 r
.70797 .29854 m .7075 .29945 L .70803 .29927 L F
.659 .604 .782 r
.70974 .30171 m .70688 .30447 L .70662 .30301 L F
.70974 .30171 m .70662 .30301 L .70602 .29959 L F
.70974 .30171 m .70602 .29959 L .70741 .29937 L F
.70841 .29982 m .70741 .29937 L .70803 .29927 L F
.70974 .30171 m .70741 .29937 L .70841 .29982 L F
.733 .332 .289 r
.70899 .30189 m .71302 .30296 L .71262 .30171 L F
.71214 .30072 m .71229 .30066 L .70974 .30171 L F
.7112 .30107 m .71262 .30171 L .71229 .30066 L F
.70899 .30189 m .70974 .30171 L .70803 .29927 L F
.70899 .30189 m .71214 .30072 L .70974 .30171 L F
.70899 .30189 m .71262 .30171 L .7112 .30107 L F
.81 .914 .52 r
.7075 .29945 m .70677 .30086 L .70803 .29927 L F
0 0 0 r
.70856 .2991 m .70803 .29927 L .70602 .29959 L F
.71003 .29881 m .70803 .29927 L .70856 .2991 L F
.622 .958 .825 r
.71222 .29666 m .71003 .29881 L .71126 .29732 L F
0 0 .374 r
.71283 .295 m .71126 .29732 L .71092 .29515 L F
.622 .958 .825 r
.71222 .29666 m .70803 .29927 L .71003 .29881 L F
.863 .681 .151 r
.69928 .28903 m .6998 .28893 L .69741 .2883 L F
.69928 .28903 m .69957 .29094 L .6998 .28893 L F
.833 .998 .831 r
.41376 .59442 m .41781 .59175 L .41568 .593 L F
.935 .623 .426 r
.41781 .59175 m .41779 .59423 L .41568 .593 L F
.77 .705 .79 r
.60622 .35631 m .60848 .35394 L .60715 .35435 L F
.993 .755 .394 r
.74054 .30141 m .74072 .29853 L .73956 .29677 L F
.762 .498 .534 r
.56023 .40593 m .55635 .40824 L .55687 .40551 L F
.673 .836 .413 r
.56023 .40593 m .5577 .4103 L .55998 .40887 L F
.762 .498 .534 r
.56023 .40593 m .55998 .40887 L .55635 .40824 L F
.502 .158 .316 r
.56023 .40593 m .5624 .40786 L .55998 .40887 L F
.56023 .40593 m .56314 .40565 L .5624 .40786 L F
.632 .436 .599 r
.28113 .64671 m .27769 .64967 L .27722 .64684 L F
.28113 .64671 m .28112 .65018 L .27769 .64967 L F
.487 .835 .562 r
.28113 .64671 m .27769 .64967 L .28112 .65018 L F
.76 .8 .885 r
.39691 .4548 m .39883 .45728 L .39424 .45725 L F
.471 .515 .822 r
.39755 .45984 m .39424 .45725 L .39883 .45728 L F
.408 .585 .914 r
.39843 .4543 m .39883 .45728 L .39691 .4548 L F
.39843 .4543 m .40068 .45688 L .39883 .45728 L F
.155 0 0 r
.39883 .45728 m .39963 .459 L .39755 .45984 L F
.39883 .45728 m .40068 .45688 L .39963 .459 L F
.76 .661 .753 r
.52488 .44771 m .52206 .45166 L .52594 .45033 L F
.449 .026 .142 r
.52206 .45166 m .52519 .45165 L .52594 .45033 L F
.051 0 0 r
.52519 .45165 m .52895 .45042 L .52594 .45033 L F
.735 .443 .486 r
.32488 .56103 m .32887 .56183 L .32917 .55811 L F
.672 .47 .604 r
.32887 .56183 m .33149 .55775 L .32917 .55811 L F
.779 .455 .44 r
.3544 .62439 m .35722 .62709 L .35405 .62711 L F
0 0 0 r
.65468 .32466 m .65092 .32704 L .65329 .32589 L F
.65329 .32589 m .65666 .32361 L .65468 .32466 L F
.125 0 .207 r
.65468 .32466 m .65666 .32361 L .65719 .32169 L F
.054 .621 .718 r
.45918 .5956 m .45728 .59569 L .45471 .59585 L F
.225 0 0 r
.45918 .5956 m .46093 .59526 L .46158 .59545 L F
.46093 .59526 m .46333 .5948 L .46158 .59545 L F
.355 .79 .966 r
.46369 .59592 m .46251 .59572 L .46158 .59545 L F
.46251 .59572 m .45986 .59526 L .46158 .59545 L F
.242 .755 .848 r
.46158 .59545 m .45728 .59569 L .45918 .5956 L F
0 0 .206 r
.49269 .53273 m .49212 .53523 L .49085 .53623 L F
.045 0 .381 r
.49212 .53523 m .49072 .53907 L .49085 .53623 L F
0 0 0 r
.30964 .63752 m .30684 .64069 L .30735 .63956 L F
.811 .708 .751 r
.33668 .51232 m .33116 .51227 L .33404 .50865 L F
.81 .718 .764 r
.33668 .51232 m .33317 .51387 L .33116 .51227 L F
.762 .737 .829 r
.33686 .51405 m .33317 .51387 L .33668 .51232 L F
.588 .64 .87 r
.33626 .50934 m .33668 .51232 L .33404 .50865 L F
.618 .165 .152 r
.60147 .3766 m .60376 .37784 L .60478 .37648 L F
.254 0 0 r
.60478 .37648 m .6069 .37689 L .60737 .37635 L F
.60478 .37648 m .60376 .37784 L .6069 .37689 L F
.702 .963 .941 r
.56778 .38155 m .5655 .38348 L .56657 .38136 L F
.748 .987 .771 r
.5655 .38348 m .56342 .38428 L .56657 .38136 L F
.537 .138 .232 r
.42537 .4873 m .42397 .4897 L .42132 .48957 L F
.371 .154 .45 r
.42796 .48394 m .42791 .4869 L .42537 .4873 L F
.671 .285 .306 r
.42808 .48983 m .42537 .4873 L .42791 .4869 L F
.42808 .48983 m .42397 .4897 L .42537 .4873 L F
.834 .915 .517 r
.54124 .41556 m .54254 .41145 L .54476 .41501 L F
0 0 0 r
.48405 .558 m .48319 .56045 L .48202 .56216 L F
0 0 .123 r
.48319 .56045 m .4815 .56456 L .48202 .56216 L F
.051 .256 .751 r
.34616 .62943 m .34507 .63062 L .34716 .63172 L F
.694 .719 .869 r
.63638 .3856 m .63799 .38759 L .63985 .38574 L F
.847 .923 .882 r
.72678 .2966 m .72341 .29897 L .72513 .29674 L F
.866 .966 .861 r
.72678 .2966 m .72513 .29674 L .72811 .29325 L F
.187 .575 .939 r
.44809 .58343 m .4474 .58486 L .44533 .58424 L F
.44809 .58343 m .44997 .58549 L .4474 .58486 L F
0 .247 .761 r
.37059 .62995 m .36739 .62673 L .37088 .62711 L F
.346 .823 .806 r
.37321 .62608 m .37088 .62711 L .373 .6263 L F
.124 0 .381 r
.37059 .62995 m .37088 .62711 L .37321 .62608 L F
.977 .725 .312 r
.40028 .53905 m .39977 .53902 L .39905 .53526 L F
.93 .552 .251 r
.40028 .53905 m .39928 .541 L .39977 .53902 L F
.40028 .53905 m .40088 .54197 L .39928 .541 L F
.903 .707 .629 r
.70046 .31323 m .70233 .31169 L .70083 .3108 L F
.67 .146 0 r
.34754 .50164 m .34756 .49976 L .34546 .49914 L F
.34754 .50164 m .34996 .50197 L .34756 .49976 L F
.538 .338 .556 r
.30485 .63375 m .30763 .63532 L .30758 .63091 L F
.832 .999 .794 r
.38368 .48651 m .38118 .48978 L .3801 .48943 L F
.967 .644 .321 r
.33121 .51877 m .33186 .52037 L .33039 .51883 L F
0 .279 .703 r
.33186 .52037 m .33202 .5202 L .33039 .51883 L F
.236 .753 .833 r
.33202 .5202 m .32899 .51892 L .33039 .51883 L F
.32899 .51892 m .32848 .5187 L .33039 .51883 L F
.967 .644 .321 r
.33032 .51658 m .33121 .51877 L .33039 .51883 L F
0 .279 .703 r
.33186 .52037 m .33397 .52154 L .33202 .5202 L F
.455 .401 .707 r
.33397 .52154 m .33225 .52246 L .33186 .52037 L F
.975 .796 .6 r
.58925 .43536 m .59177 .43199 L .5906 .42893 L F
.834 .864 .866 r
.73806 .30721 m .7376 .31075 L .73957 .30875 L F
.691 .458 .565 r
.49207 .48088 m .49196 .48374 L .49436 .48309 L F
.754 .787 .88 r
.51133 .43447 m .51532 .43477 L .51304 .43611 L F
.312 0 .207 r
.31987 .60035 m .32294 .59771 L .32094 .59866 L F
.532 .28 .479 r
.32154 .56151 m .32488 .56103 L .32239 .55871 L F
.746 .867 .935 r
.61369 .40527 m .61797 .4048 L .61693 .40303 L F
0 0 0 r
.61648 .40733 m .61797 .4048 L .61503 .40925 L F
.464 .516 .827 r
.61797 .4048 m .61863 .401 L .61693 .40303 L F
.61797 .4048 m .6204 .40511 L .61863 .401 L F
.39 0 0 r
.61906 .40649 m .61797 .4048 L .61648 .40733 L F
.61906 .40649 m .6204 .40511 L .61797 .4048 L F
.598 .691 .908 r
.29656 .64828 m .29471 .64944 L .29306 .64636 L F
.29656 .64828 m .2975 .64851 L .29471 .64944 L F
.631 .654 .855 r
.29836 .65014 m .29471 .64944 L .2975 .64851 L F
.68 .21 0 r
.38229 .48055 m .38465 .48349 L .38366 .48249 L F
.994 .863 .591 r
.38366 .48249 m .38465 .48349 L .38368 .48651 L F
.316 .133 .467 r
.35998 .57809 m .3623 .57455 L .35984 .57536 L F
.35998 .57809 m .3623 .57455 L .35984 .57536 L F
.087 .06 .528 r
.3303 .57364 m .3286 .57559 L .32853 .57189 L F
.561 .156 .23 r
.32742 .53602 m .32972 .53788 L .3304 .53694 L F
.513 .352 .6 r
.4076 .46791 m .40988 .46451 L .40636 .46409 L F
.4076 .46791 m .41018 .46788 L .40988 .46451 L F
.523 .328 .558 r
.4076 .46791 m .40951 .46937 L .41018 .46788 L F
.4076 .46791 m .40863 .47043 L .40951 .46937 L F
.985 .871 .64 r
.57299 .42998 m .57365 .43251 L .57264 .4347 L F
.894 .554 .396 r
.39829 .53261 m .39616 .53248 L .3954 .52958 L F
.902 .501 .236 r
.39829 .53261 m .39674 .5342 L .39616 .53248 L F
.39829 .53261 m .39905 .53526 L .39674 .5342 L F
.597 .396 .58 r
.52993 .42511 m .53066 .42857 L .52732 .42863 L F
.324 .071 .367 r
.53342 .42421 m .53066 .42857 L .52993 .42511 L F
.003 .52 .857 r
.25356 .58449 m .25353 .58505 L .25242 .58366 L F
.25356 .58449 m .25573 .58561 L .25353 .58505 L F
.516 0 0 r
.53329 .39586 m .536 .39718 L .53767 .39595 L F
.039 0 0 r
.536 .39718 m .54022 .39554 L .53767 .39595 L F
.589 .881 .577 r
.7083 .33199 m .70953 .331 L .71128 .32893 L F
.717 .297 .249 r
.32944 .52453 m .33362 .52506 L .33225 .52246 L F
.807 .323 0 r
.33225 .52246 m .33362 .52506 L .33554 .52616 L F
.446 .869 .744 r
.66991 .32505 m .67116 .3247 L .67366 .32328 L F
.657 .577 .753 r
.22251 .56865 m .22438 .57321 L .22762 .57149 L F
.518 .294 .513 r
.22438 .57321 m .22619 .57467 L .22762 .57149 L F
.438 .551 .873 r
.32728 .5041 m .32855 .50109 L .32643 .49948 L F
.32728 .5041 m .3297 .50376 L .32855 .50109 L F
.585 .131 .14 r
.26071 .62603 m .26275 .62365 L .25792 .62396 L F
.92 .592 .405 r
.26071 .62603 m .26354 .62724 L .26275 .62365 L F
.853 .947 .878 r
.73068 .32549 m .73187 .3265 L .73407 .32425 L F
.336 .738 .982 r
.29579 .65666 m .29977 .65745 L .29795 .65644 L F
.455 .816 .996 r
.29977 .65745 m .30222 .65697 L .30044 .65608 L F
0 0 .101 r
.34098 .58448 m .34294 .58362 L .34372 .58074 L F
0 0 0 r
.34372 .58074 m .3449 .57775 L .34677 .57847 L F
.34372 .58074 m .34437 .58019 L .3449 .57775 L F
.443 .357 .665 r
.34294 .58362 m .34437 .58019 L .34372 .58074 L F
.837 .676 .684 r
.73365 .29882 m .73301 .30205 L .72965 .30076 L F
.738 .671 .785 r
.73592 .29647 m .73365 .29882 L .7316 .29564 L F
.468 .891 .83 r
.6857 .37458 m .68645 .37352 L .68434 .37511 L F
.6857 .37458 m .68819 .37334 L .68645 .37352 L F
.875 .975 .844 r
.49776 .41565 m .49411 .41782 L .49661 .41505 L F
.744 .993 .827 r
.50056 .41307 m .49776 .41565 L .49877 .41356 L F
.695 .96 .945 r
.49776 .41565 m .49661 .41505 L .49877 .41356 L F
.944 .596 .321 r
.361 .51246 m .36139 .51483 L .36294 .51364 L F
.857 .43 .207 r
.36294 .51364 m .36139 .51483 L .3635 .51554 L F
.517 .817 .999 r
.24655 .59054 m .24833 .59154 L .25334 .59072 L F
.552 .93 .824 r
.55366 .3904 m .5551 .38894 L .55573 .38861 L F
.55366 .3904 m .55181 .39081 L .5551 .38894 L F
.999 .802 .466 r
.58571 .40947 m .58662 .40516 L .58545 .40443 L F
.492 .238 .457 r
.4227 .48266 m .42483 .47961 L .42419 .48118 L F
.794 .912 .921 r
.7087 .29313 m .70543 .29543 L .7041 .29416 L F
.64 .838 .977 r
.34479 .63295 m .34882 .63341 L .34716 .63172 L F
.496 .772 .993 r
.34716 .63172 m .34882 .63341 L .35133 .63262 L F
.985 .722 .341 r
.45064 .57469 m .45205 .57846 L .45135 .57834 L F
.988 .887 .558 r
.45135 .57834 m .45205 .57846 L .45036 .58003 L F
.72 .512 .608 r
.45393 .57148 m .45064 .57469 L .45063 .57195 L F
0 0 .317 r
.45237 .57104 m .45063 .57195 L .45064 .57469 L F
.172 .358 .807 r
.45345 .57718 m .45205 .57846 L .45064 .57469 L F
0 0 0 r
.45036 .58003 m .45205 .57846 L .45345 .57718 L F
.43 .866 .916 r
.45348 .58497 m .44997 .58549 L .45193 .5839 L F
.288 .059 .382 r
.50251 .51631 m .50256 .51897 L .49994 .51966 L F
.269 .035 .363 r
.50256 .51897 m .50004 .52227 L .49994 .51966 L F
.644 .221 .224 r
.28833 .64396 m .28507 .64165 L .28615 .6443 L F
.798 .713 .771 r
.34604 .63716 m .34716 .63172 L .34746 .63458 L F
.34604 .63716 m .34479 .63295 L .34716 .63172 L F
0 .323 .786 r
.57308 .38212 m .5725 .38266 L .57072 .38159 L F
.57308 .38212 m .57531 .38419 L .5725 .38266 L F
.639 .563 .752 r
.48908 .46806 m .49068 .46372 L .48794 .46429 L F
.48908 .46806 m .49184 .46748 L .49068 .46372 L F
.628 .505 .694 r
.48908 .46806 m .48941 .47068 L .49184 .46748 L F
.47 .52 .827 r
.57719 .36529 m .57524 .36792 L .57443 .36606 L F
.57719 .36529 m .57863 .36919 L .57524 .36792 L F
.983 .7 .386 r
.43073 .48616 m .43227 .49009 L .43223 .48735 L F
0 0 .42 r
.52198 .41582 m .52282 .41655 L .52653 .41508 L F
.52198 .41582 m .52213 .41871 L .52274 .41798 L F
.52282 .41655 m .52274 .41798 L .52347 .41711 L F
.52198 .41582 m .52274 .41798 L .52282 .41655 L F
.52282 .41655 m .52347 .41711 L .52602 .41541 L F
.52282 .41655 m .52602 .41541 L .52653 .41508 L F
.52347 .41711 m .52198 .41582 L .52374 .41554 L F
.52282 .41655 m .52213 .41871 L .52198 .41582 L F
.52347 .41711 m .52274 .41798 L .52282 .41655 L F
.52274 .41798 m .52213 .41871 L .52282 .41655 L F
.403 .018 .19 r
.52144 .41703 m .52284 .41612 L .52044 .41738 L F
.52284 .41612 m .52374 .41554 L .52285 .41604 L F
.52284 .41612 m .52285 .41604 L .52044 .41738 L F
.52044 .41738 m .52285 .41604 L .51893 .41339 L F
.52285 .41604 m .52374 .41554 L .52289 .41516 L F
.52285 .41604 m .52289 .41516 L .51893 .41339 L F
.52053 .41762 m .52144 .41703 L .52044 .41738 L F
.176 .695 .884 r
.63967 .35083 m .6358 .35051 L .63835 .34931 L F
.616 .828 .982 r
.63967 .35083 m .6358 .35051 L .63835 .34931 L F
0 0 0 r
.34479 .63295 m .34234 .63425 L .3405 .63572 L F
.867 .96 .622 r
.58777 .35119 m .58593 .35587 L .58938 .35442 L F
.58777 .35119 m .58523 .35569 L .58593 .35587 L F
.661 .949 .954 r
.60091 .34606 m .59833 .34769 L .59702 .34722 L F
.889 .788 .744 r
.43389 .53187 m .43486 .53547 L .43626 .5334 L F
.653 .534 .706 r
.34092 .56538 m .33829 .5659 L .33984 .56206 L F
.528 .211 .374 r
.34092 .56538 m .33695 .56818 L .33829 .5659 L F
.525 .258 .454 r
.37191 .55525 m .3707 .55722 L .36911 .55568 L F
.37191 .55525 m .3707 .55722 L .36911 .55568 L F
.924 .884 .776 r
.30398 .57363 m .30514 .57371 L .30495 .57268 L F
.726 .775 .892 r
.30495 .57268 m .30514 .57371 L .30779 .57233 L F
.743 .747 .855 r
.41284 .46662 m .41746 .467 L .41562 .46353 L F
.759 .742 .837 r
.41562 .46353 m .41746 .467 L .41975 .46408 L F
.09 0 .421 r
.5479 .415 m .54765 .41773 L .54629 .41862 L F
.56 .101 .12 r
.54765 .41773 m .54473 .4186 L .54629 .41862 L F
0 0 .007 r
.48832 .54548 m .4877 .54761 L .48633 .54917 L F
0 0 0 r
.4877 .54761 m .4856 .55158 L .48633 .54917 L F
.346 .60443 m .34722 .60349 L .34822 .60105 L F
.097 .036 .492 r
.34609 .60721 m .34722 .60349 L .346 .60443 L F
.693 .577 .72 r
.34558 .6014 m .346 .60443 L .34822 .60105 L F
.662 .121 0 r
.24704 .56302 m .25208 .56552 L .24817 .56349 L F
.7 .977 .912 r
.55783 .41726 m .56024 .41443 L .56221 .41596 L F
.55783 .41726 m .5573 .41624 L .56024 .41443 L F
0 .436 .829 r
.39687 .47834 m .3969 .47923 L .39447 .47963 L F
.39687 .47834 m .39865 .47964 L .3969 .47923 L F
.171 .056 .471 r
.30758 .63091 m .30904 .63109 L .31003 .63043 L F
.623 .167 .149 r
.57651 .45123 m .58365 .45178 L .58289 .45384 L F
.664 .793 .943 r
.45186 .4693 m .45284 .46626 L .45163 .46682 L F
.45186 .4693 m .45458 .46822 L .45284 .46626 L F
.005 0 0 r
.30523 .64079 m .30684 .64069 L .30553 .64084 L F
.2 .38 .818 r
.30553 .64084 m .30762 .64172 L .30699 .63876 L F
0 0 .113 r
.30615 .64094 m .30553 .64084 L .30699 .63876 L F
.30603 .64124 m .30553 .64084 L .30615 .64094 L F
.005 0 0 r
.30296 .64094 m .30523 .64079 L .30553 .64084 L F
.861 .981 .853 r
.36765 .49755 m .37018 .49741 L .36737 .50002 L F
.608 .952 .908 r
.37195 .49613 m .37018 .49741 L .36765 .49755 L F
.693 .715 .866 r
.34853 .61089 m .35012 .61133 L .34972 .60988 L F
.719 .26 .158 r
.34853 .61089 m .34954 .61248 L .35012 .61133 L F
.582 .644 .877 r
.34972 .60988 m .35012 .61133 L .35288 .6104 L F
0 0 0 r
.35012 .61133 m .35079 .61161 L .35288 .6104 L F
.35012 .61133 m .34954 .61248 L .35079 .61161 L F
.795 .508 .502 r
.30044 .54976 m .29949 .55171 L .29852 .54917 L F
.29852 .54917 m .29949 .55171 L .30044 .54976 L F
0 0 .051 r
.30213 .54844 m .29949 .55171 L .30044 .54976 L F
.30044 .54976 m .29949 .55171 L .30213 .54844 L F
.795 .508 .502 r
.30044 .54976 m .29949 .55171 L .29852 .54917 L F
.875 .781 .754 r
.37878 .53808 m .38139 .53917 L .38156 .53855 L F
.938 .576 .294 r
.37878 .53808 m .38171 .54254 L .38139 .53917 L F
.324 0 .226 r
.51902 .4999 m .5159 .50254 L .5163 .50036 L F
.644 .963 .801 r
.64515 .39781 m .64894 .39564 L .64871 .39571 L F
.46 .852 .651 r
.64894 .39564 m .65234 .39335 L .65089 .39414 L F
.451 .84 .624 r
.64871 .39571 m .64894 .39564 L .65089 .39414 L F
0 0 0 r
.65089 .39414 m .65234 .39335 L .65476 .39212 L F
.348 .054 .317 r
.31324 .64549 m .317 .64301 L .31506 .64519 L F
.12 .553 .919 r
.31506 .64519 m .31764 .64689 L .31324 .64549 L F
.795 .506 .499 r
.31871 .64937 m .31324 .64549 L .31764 .64689 L F
.964 .671 .427 r
.38653 .55745 m .38831 .55557 L .38649 .55442 L F
.38653 .55745 m .38839 .55844 L .38831 .55557 L F
.77 .705 .79 r
.60622 .35631 m .61024 .35745 L .60848 .35394 L F
.783 .687 .758 r
.60622 .35631 m .60792 .36046 L .61024 .35745 L F
.054 0 .146 r
.60792 .36046 m .60951 .35975 L .61024 .35745 L F
.505 .17 .333 r
.61024 .35745 m .60951 .35975 L .61314 .35888 L F
.508 .164 .318 r
.61314 .35888 m .61352 .35704 L .61024 .35745 L F
.939 .958 .751 r
.24765 .54286 m .24824 .53899 L .25023 .54198 L F
.24765 .54286 m .24658 .54236 L .24824 .53899 L F
.963 .936 .7 r
.24765 .54286 m .2471 .54322 L .24658 .54236 L F
.685 .966 .933 r
.31794 .658 m .31987 .65849 L .32184 .6568 L F
.343 .799 .671 r
.6353 .33602 m .63777 .33478 L .63925 .33416 L F
.324 .787 .666 r
.63925 .33416 m .64106 .33326 L .64162 .33277 L F
.63925 .33416 m .63777 .33478 L .64106 .33326 L F
.612 .861 .99 r
.29911 .64835 m .30083 .64985 L .29836 .65014 L F
.994 .789 .52 r
.27722 .64684 m .27769 .64967 L .27709 .65043 L F
.618 .52 .721 r
.27769 .64967 m .27941 .65267 L .28112 .65018 L F
.538 .056 .058 r
.27769 .64967 m .27964 .65135 L .27709 .65043 L F
.27769 .64967 m .28112 .65018 L .27964 .65135 L F
.405 .524 .865 r
.33264 .5106 m .33328 .50902 L .33404 .50865 L F
.654 .099 0 r
.33444 .50845 m .33404 .50865 L .33107 .50669 L F
.288 .333 .735 r
.33107 .50669 m .33391 .50836 L .33172 .50243 L F
.405 .524 .865 r
.33372 .50881 m .33391 .50836 L .33404 .50865 L F
.33391 .50836 m .33407 .508 L .33404 .50865 L F
0 .266 .724 r
.33404 .50865 m .33417 .50851 L .33391 .50836 L F
.33404 .50865 m .33391 .50836 L .33107 .50669 L F
.288 .333 .735 r
.33391 .50836 m .33417 .50851 L .33401 .50813 L F
.33391 .50836 m .33401 .50813 L .33172 .50243 L F
.411 .406 .743 r
.33172 .50243 m .33401 .50813 L .33503 .50463 L F
0 0 0 r
.33503 .50463 m .33417 .50851 L .33404 .50865 L F
.411 .406 .743 r
.33401 .50813 m .33417 .50851 L .33444 .50726 L F
0 0 0 r
.33503 .50463 m .33404 .50865 L .33407 .50801 L F
.411 .406 .743 r
.33401 .50813 m .33407 .50801 L .33503 .50463 L F
0 0 0 r
.33449 .50654 m .33407 .50801 L .33413 .50689 L F
.411 .406 .743 r
.33407 .50801 m .33444 .50726 L .33503 .50463 L F
.405 .524 .865 r
.33328 .50902 m .33413 .50689 L .33407 .508 L F
.33328 .50902 m .33407 .508 L .33401 .50813 L F
.33367 .50883 m .33401 .50813 L .33372 .50881 L F
.33328 .50902 m .33401 .50813 L .33367 .50883 L F
.654 .099 0 r
.33582 .50917 m .33404 .50865 L .33444 .50845 L F
.242 0 0 r
.33582 .50917 m .33626 .50934 L .33404 .50865 L F
.405 .524 .865 r
.33264 .5106 m .33619 .50966 L .33547 .50869 L F
0 0 0 r
.33404 .50865 m .3323 .51083 L .33264 .5106 L F
.405 .524 .865 r
.33264 .5106 m .33547 .50869 L .33413 .50689 L F
0 0 0 r
.3323 .51083 m .33116 .51227 L .33264 .5106 L F
.663 .111 0 r
.3378 .50858 m .33413 .50689 L .33619 .50966 L F
0 .034 .523 r
.33413 .50689 m .33526 .50792 L .33361 .50741 L F
.33413 .50689 m .33361 .50741 L .3322 .50698 L F
0 0 0 r
.33503 .50463 m .33449 .50654 L .33413 .50689 L F
.11 0 0 r
.41872 .59859 m .41986 .59915 L .41728 .59909 L F
.41872 .59859 m .4217 .59823 L .41986 .59915 L F
.2 0 0 r
.54929 .48067 m .5506 .48166 L .54839 .483 L F
.54929 .48067 m .55198 .4802 L .5506 .48166 L F
.208 .714 .902 r
.25208 .56552 m .2471 .56509 L .24957 .56721 L F
.972 .885 .684 r
.38406 .61261 m .38483 .61107 L .38246 .6122 L F
.869 .993 .812 r
.38465 .60913 m .38483 .61107 L .38729 .6077 L F
.881 .992 .783 r
.38246 .6122 m .38483 .61107 L .38465 .60913 L F
0 0 0 r
.66402 .38618 m .66722 .3837 L .66666 .38526 L F
.224 0 .15 r
.66666 .38526 m .66722 .3837 L .66973 .38263 L F
.492 .839 .996 r
.73258 .3115 m .73552 .31055 L .73223 .31371 L F
.597 .1 .044 r
.60551 .36523 m .60696 .36547 L .60572 .3645 L F
.349 .211 .548 r
.60572 .3645 m .60696 .36547 L .60767 .36291 L F
0 0 0 r
.34927 .64232 m .34751 .64353 L .35016 .64086 L F
.293 .296 .692 r
.34927 .64232 m .34998 .64575 L .34751 .64353 L F
.791 .383 0 r
.58034 .38031 m .58009 .38091 L .57887 .37907 L F
.58034 .38031 m .58124 .38241 L .58009 .38091 L F
.573 .366 .561 r
.63376 .38591 m .636 .38275 L .63324 .38328 L F
.126 0 0 r
.68074 .3221 m .67934 .32235 L .67661 .32222 L F
.078 0 0 r
.68341 .32224 m .68074 .3221 L .68326 .32144 L F
.68341 .32224 m .67934 .32235 L .68074 .3221 L F
0 0 .206 r
.24019 .59821 m .23952 .60097 L .24181 .59644 L F
.875 .781 .754 r
.37878 .53808 m .38156 .53855 L .37861 .53555 L F
.98 .747 .514 r
.59693 .40476 m .59869 .40614 L .59842 .40875 L F
.542 .553 .816 r
.27157 .63697 m .27588 .64001 L .27399 .63643 L F
.497 .288 .526 r
.48212 .51616 m .48512 .51308 L .47999 .51439 L F
.864 .682 .655 r
.46913 .51731 m .46793 .52043 L .4725 .5194 L F
.875 .751 .721 r
.60696 .36547 m .60903 .36681 L .60767 .36291 L F
.879 .757 .723 r
.60485 .36881 m .60903 .36681 L .60696 .36547 L F
.762 .699 .792 r
.60767 .36291 m .60903 .36681 L .61195 .36375 L F
.594 .595 .823 r
.36875 .54205 m .36365 .53812 L .36887 .53936 L F
.983 .793 .572 r
.40792 .57228 m .40543 .57406 L .4065 .56986 L F
.40792 .57228 m .40732 .57508 L .40543 .57406 L F
.776 .741 .82 r
.34331 .53528 m .34535 .53697 L .34743 .53548 L F
.87 .715 .688 r
.34331 .53528 m .34471 .53918 L .34535 .53697 L F
.549 .347 .559 r
.34471 .53918 m .34743 .53548 L .34535 .53697 L F
0 .174 .708 r
.35688 .62999 m .35405 .62711 L .35722 .62709 L F
.557 .866 .996 r
.43052 .48322 m .42914 .48228 L .42796 .48394 L F
.573 .312 .483 r
.43073 .48616 m .42796 .48394 L .42914 .48228 L F
.43073 .48616 m .42791 .4869 L .42796 .48394 L F
.302 .314 .707 r
.60792 .36046 m .61039 .36201 L .60951 .35975 L F
.495 .247 .469 r
.60792 .36046 m .60767 .36291 L .61039 .36201 L F
.60792 .36046 m .60767 .36291 L .61039 .36201 L F
.953 .716 .543 r
.33032 .51658 m .3288 .51681 L .32831 .51266 L F
.815 .379 .206 r
.33032 .51658 m .32848 .5187 L .3288 .51681 L F
.715 .666 .8 r
.33317 .51387 m .33032 .51658 L .32831 .51266 L F
.956 .626 .348 r
.33039 .51883 m .32848 .5187 L .33032 .51658 L F
.567 .559 .805 r
.25407 .54526 m .25184 .5463 L .25023 .54198 L F
.561 .915 .962 r
.25027 .54586 m .25184 .5463 L .25407 .54526 L F
.717 .459 .535 r
.56717 .42521 m .57129 .42547 L .57125 .42782 L F
.858 .94 .571 r
.34717 .59769 m .34531 .60121 L .34558 .6014 L F
.801 .97 .668 r
.34531 .60121 m .34381 .60297 L .34558 .6014 L F
.726 .638 .76 r
.36125 .53386 m .3617 .53623 L .3558 .53545 L F
.533 .271 .464 r
.3617 .53623 m .35825 .53941 L .3558 .53545 L F
.3617 .53623 m .36069 .53938 L .35825 .53941 L F
.35825 .53941 m .36069 .53938 L .3617 .53623 L F
.459 .454 .765 r
.36385 .53489 m .3617 .53623 L .36125 .53386 L F
.644 .382 .508 r
.3617 .53623 m .36365 .53812 L .36385 .53489 L F
.3617 .53623 m .36069 .53938 L .36365 .53812 L F
0 0 0 r
.36163 .53658 m .3617 .53623 L .36385 .53489 L F
.36163 .53658 m .36069 .53938 L .3617 .53623 L F
.459 .454 .765 r
.36385 .53489 m .3617 .53623 L .36125 .53386 L F
.788 .736 .805 r
.51311 .4223 m .51669 .42174 L .51492 .42089 L F
.724 .582 .695 r
.51311 .4223 m .51645 .42432 L .51669 .42174 L F
.621 .611 .82 r
.51669 .42174 m .51965 .4189 L .51492 .42089 L F
.51669 .42174 m .51923 .42194 L .51965 .4189 L F
.547 .101 .142 r
.51853 .42404 m .51669 .42174 L .51645 .42432 L F
.51853 .42404 m .51923 .42194 L .51669 .42174 L F
.883 .452 .08 r
.39063 .52252 m .38758 .51846 L .38995 .51979 L F
0 0 .268 r
.35906 .52552 m .36049 .52471 L .36087 .52169 L F
.486 .422 .71 r
.319 .64781 m .32111 .64976 L .31871 .64937 L F
.319 .64781 m .32111 .64976 L .31871 .64937 L F
.515 .747 .979 r
.54579 .39317 m .54419 .39526 L .54263 .39425 L F
.54579 .39317 m .54683 .39489 L .54419 .39526 L F
.877 .573 .469 r
.28433 .51211 m .28213 .51235 L .2845 .51007 L F
.526 .256 .449 r
.2845 .51007 m .28675 .5121 L .28433 .51211 L F
.434 .843 .97 r
.28675 .5121 m .28213 .51235 L .28433 .51211 L F
.28213 .51235 m .28675 .5121 L .2845 .51007 L F
.89 .881 .818 r
.35121 .61412 m .34886 .61756 L .34721 .61612 L F
.814 .933 .91 r
.50927 .40829 m .50588 .40922 L .50832 .40794 L F
.597 .947 .911 r
.50927 .40829 m .51056 .40657 L .5124 .40646 L F
.50927 .40829 m .50832 .40794 L .51056 .40657 L F
.541 .389 .624 r
.48941 .47068 m .49203 .47023 L .49184 .46748 L F
.701 .568 .702 r
.48941 .47068 m .49337 .47379 L .49203 .47023 L F
.48941 .47068 m .49074 .47457 L .49337 .47379 L F
.234 0 .254 r
.34668 .55631 m .34521 .55576 L .34781 .55577 L F
.34668 .55631 m .34454 .55793 L .34521 .55576 L F
.543 .829 .998 r
.59832 .364 m .60154 .36331 L .60019 .36186 L F
.337 0 .06 r
.3181 .62309 m .31461 .62382 L .3152 .62358 L F
.914 .979 .719 r
.31461 .62382 m .31605 .62534 L .3152 .62358 L F
.31461 .62382 m .31267 .62706 L .31605 .62534 L F
.59 .274 .401 r
.31605 .62534 m .3123 .62915 L .31471 .62851 L F
.31605 .62534 m .31267 .62706 L .3123 .62915 L F
.187 .043 .44 r
.31605 .62534 m .3181 .62309 L .3152 .62358 L F
.31605 .62534 m .31819 .62623 L .3181 .62309 L F
.306 0 .032 r
.3168 .62743 m .31605 .62534 L .31471 .62851 L F
.3168 .62743 m .31819 .62623 L .31605 .62534 L F
.537 .803 .995 r
.70802 .28075 m .70929 .28232 L .70533 .2816 L F
.70802 .28075 m .70929 .28232 L .70533 .2816 L F
.6 .836 .989 r
.70802 .28075 m .70929 .28232 L .71082 .27997 L F
.70802 .28075 m .70929 .28232 L .71082 .27997 L F
.459 .166 .38 r
.32306 .6106 m .32564 .61015 L .32645 .60766 L F
.144 0 .236 r
.32645 .60766 m .32564 .61015 L .3282 .60687 L F
.776 .741 .82 r
.34331 .53528 m .34743 .53548 L .34593 .53217 L F
.549 .347 .559 r
.34471 .53918 m .34746 .53933 L .34743 .53548 L F
.688 .662 .819 r
.34593 .53217 m .34743 .53548 L .34964 .53281 L F
.837 .384 .137 r
.35545 .50636 m .35733 .50936 L .35935 .50987 L F
.704 .172 0 r
.35733 .50936 m .361 .51246 L .35935 .50987 L F
.668 .917 .976 r
.53513 .40584 m .53656 .40665 L .53895 .40526 L F
.282 0 .272 r
.65719 .32169 m .65666 .32361 L .6594 .32084 L F
.01 .427 .862 r
.57531 .38419 m .57703 .38457 L .5766 .38575 L F
0 0 .382 r
.57735 .38687 m .5766 .38575 L .57703 .38457 L F
0 0 .54 r
.57754 .38709 m .57735 .38687 L .57613 .38677 L F
0 0 .382 r
.57735 .38687 m .57825 .38846 L .57714 .38664 L F
0 0 .54 r
.57872 .38735 m .57843 .38901 L .57735 .38687 L F
.57872 .38735 m .57735 .38687 L .57754 .38709 L F
0 0 .382 r
.57735 .38687 m .57714 .38664 L .5766 .38575 L F
.484 .138 .303 r
.33732 .58731 m .34054 .58711 L .34098 .58448 L F
.235 0 .237 r
.34098 .58448 m .34255 .58629 L .34294 .58362 L F
.34098 .58448 m .34054 .58711 L .34255 .58629 L F
0 0 .456 r
.31477 .53717 m .31581 .5376 L .31658 .53543 L F
.859 .956 .871 r
.35429 .64345 m .34998 .64575 L .35315 .64295 L F
0 0 .087 r
.37818 .61096 m .37779 .61381 L .3786 .61217 L F
.37818 .61096 m .3786 .61217 L .37642 .60978 L F
.612 .861 .99 r
.29911 .64835 m .29836 .65014 L .2975 .64851 L F
0 0 0 r
.33836 .60662 m .3362 .61038 L .33719 .60836 L F
.583 .405 .606 r
.57646 .41867 m .57645 .42169 L .57377 .42204 L F
.57646 .41867 m .57645 .42169 L .57377 .42204 L F
.758 .949 .626 r
.58415 .41673 m .58316 .41891 L .58566 .41561 L F
.913 .948 .601 r
.58607 .41282 m .58415 .41673 L .58566 .41561 L F
.601 .81 .98 r
.44292 .49828 m .44164 .50028 L .4401 .49884 L F
.44292 .49828 m .44164 .50028 L .4401 .49884 L F
.762 .427 .418 r
.2448 .54422 m .24317 .5455 L .24137 .54173 L F
.958 .642 .387 r
.38406 .54772 m .38654 .55173 L .38652 .54902 L F
0 0 .073 r
.30485 .65021 m .30758 .64661 L .30735 .64972 L F
.718 .446 .513 r
.47037 .52308 m .47203 .52459 L .47091 .52582 L F
.543 .349 .568 r
.47037 .52308 m .47091 .52582 L .46758 .52652 L F
.899 .865 .797 r
.54134 .43196 m .5394 .43559 L .53798 .43403 L F
.588 .81 .984 r
.5394 .43559 m .5406 .43333 L .53798 .43403 L F
.5394 .43559 m .54202 .43478 L .5406 .43333 L F
.768 .983 .906 r
.52525 .41026 m .52767 .41033 L .52962 .40858 L F
.736 .837 .927 r
.41975 .46408 m .42295 .46368 L .4223 .46307 L F
.798 .743 .802 r
.57914 .41831 m .57645 .42169 L .57646 .41867 L F
.99 .751 .374 r
.3922 .58305 m .39339 .58163 L .39233 .58049 L F
.3922 .58305 m .39341 .58443 L .39339 .58163 L F
.51 .342 .588 r
.49229 .50009 m .48982 .50365 L .49241 .50264 L F
.57 .319 .497 r
.48982 .50365 m .4925 .50464 L .49241 .50264 L F
.48982 .50365 m .4896 .50607 L .4925 .50464 L F
.835 .388 .162 r
.35387 .50746 m .35545 .50636 L .35325 .50614 L F
.35387 .50746 m .35733 .50936 L .35545 .50636 L F
.243 0 0 r
.32351 .64074 m .32431 .64181 L .32369 .64277 L F
.32351 .64074 m .3265 .63987 L .32431 .64181 L F
.074 0 .299 r
.35565 .52664 m .35549 .52883 L .35716 .52769 L F
.933 .745 .625 r
.32433 .61999 m .32575 .61833 L .32289 .61617 L F
.447 0 0 r
.46722 .52877 m .46318 .52548 L .46758 .52652 L F
.556 .389 .61 r
.46758 .52652 m .47072 .52959 L .46722 .52877 L F
.46758 .52652 m .47091 .52582 L .47072 .52959 L F
.627 .725 .918 r
.48794 .46429 m .48915 .46029 L .48649 .46219 L F
.48794 .46429 m .49068 .46372 L .48915 .46029 L F
0 0 .374 r
.71283 .295 m .71092 .29515 L .71367 .29302 L F
.987 .744 .478 r
.61503 .40925 m .61369 .40527 L .61648 .40733 L F
.802 .673 .721 r
.51494 .43242 m .51532 .43477 L .51133 .43447 L F
.603 .491 .699 r
.51774 .43074 m .51532 .43477 L .51494 .43242 L F
.51774 .43074 m .51775 .43338 L .51532 .43477 L F
.536 .918 .782 r
.47448 .46447 m .47034 .46654 L .47444 .46712 L F
0 0 .261 r
.47636 .4609 m .47448 .46447 L .47538 .46277 L F
0 0 .208 r
.47538 .46277 m .47448 .46447 L .47444 .46712 L F
0 .5 .813 r
.4184 .50778 m .42147 .50858 L .42296 .50933 L F
.83 .706 .726 r
.42147 .50858 m .42542 .5119 L .42296 .50933 L F
0 0 0 r
.42542 .5119 m .42649 .50831 L .42296 .50933 L F
.777 .488 .496 r
.41323 .50232 m .41707 .50036 L .41355 .49954 L F
.41323 .50232 m .41755 .50288 L .41707 .50036 L F
0 .08 .612 r
.56412 .40938 m .56525 .41054 L .56677 .40839 L F
.56412 .40938 m .56524 .41253 L .56525 .41054 L F
.743 .63 .735 r
.49075 .47732 m .49337 .47379 L .49074 .47457 L F
.061 0 0 r
.64229 .33194 m .64162 .33277 L .64482 .33073 L F
.778 .567 .615 r
.317 .64301 m .31973 .64287 L .31764 .64689 L F
.657 .121 0 r
.319 .64781 m .31764 .64689 L .31973 .64287 L F
.72 .6 .722 r
.30779 .57233 m .30946 .57525 L .31191 .57506 L F
.712 .534 .647 r
.30946 .57525 m .30924 .57818 L .31191 .57506 L F
.668 .471 .609 r
.30924 .57818 m .31212 .57805 L .31191 .57506 L F
.609 .427 .609 r
.31191 .57506 m .31212 .57805 L .31453 .57732 L F
.99 .738 .373 r
.582 .42015 m .58313 .42158 L .58316 .41891 L F
.956 .676 .464 r
.73407 .32425 m .73202 .32008 L .73301 .32311 L F
.853 .947 .878 r
.73068 .32549 m .73407 .32425 L .73301 .32311 L F
.701 .479 .584 r
.3168 .58635 m .31349 .58406 L .31748 .58448 L F
.34 0 0 r
.31748 .58448 m .3193 .58531 L .31891 .58517 L F
.3193 .58531 m .32083 .586 L .31891 .58517 L F
0 .304 .701 r
.31748 .58448 m .32017 .58578 L .31831 .58467 L F
.31748 .58448 m .31831 .58467 L .3168 .58635 L F
.701 .479 .584 r
.3168 .58635 m .31317 .58662 L .31349 .58406 L F
.597 .2 .26 r
.3168 .58635 m .31321 .58822 L .31317 .58662 L F
.686 .98 .842 r
.3181 .5849 m .31321 .58822 L .3168 .58635 L F
.31831 .58467 m .31802 .58487 L .3181 .5849 L F
.31802 .58487 m .31321 .58822 L .3181 .5849 L F
.34 0 0 r
.31891 .58517 m .32083 .586 L .32017 .58578 L F
.516 .916 .858 r
.32017 .58578 m .32083 .586 L .32326 .58445 L F
0 0 .5 r
.23422 .60276 m .23384 .60428 L .23278 .60065 L F
0 .159 .698 r
.23422 .60276 m .23607 .60651 L .23384 .60428 L F
.655 .798 .951 r
.47034 .46654 m .47189 .46838 L .47444 .46712 L F
.555 .813 .994 r
.62442 .41084 m .6261 .41219 L .62734 .41018 L F
.003 .019 .522 r
.6261 .41219 m .62827 .41327 L .62734 .41018 L F
.6261 .41219 m .62676 .41471 L .62827 .41327 L F
.753 .664 .763 r
.67713 .35332 m .67855 .35713 L .67432 .35663 L F
.91 .733 .236 r
.67855 .35713 m .67819 .35822 L .67662 .35695 L F
.67819 .35822 m .67798 .35886 L .67778 .35859 L F
.67819 .35822 m .67778 .35859 L .67662 .35695 L F
.937 .919 .544 r
.67607 .36012 m .67701 .3611 L .67559 .36161 L F
0 0 .575 r
.67662 .35695 m .67798 .35886 L .67802 .35733 L F
.149 0 0 r
.67628 .35686 m .67855 .35713 L .67662 .35695 L F
0 0 .575 r
.67662 .35695 m .67802 .35733 L .67804 .35682 L F
.67776 .35609 m .67804 .35682 L .67807 .35587 L F
.67662 .35695 m .67804 .35682 L .67776 .35609 L F
.878 .978 .837 r
.67639 .35224 m .67713 .35332 L .67432 .35663 L F
0 0 .575 r
.67662 .35695 m .67807 .35587 L .67749 .35672 L F
.94 .964 .721 r
.67798 .35886 m .67719 .35664 L .67767 .35621 L F
.67804 .35682 m .67767 .35621 L .67807 .35587 L F
.67798 .35886 m .67767 .35621 L .67804 .35682 L F
.878 .978 .837 r
.67639 .35224 m .67432 .35663 L .67443 .35491 L F
.01 .567 .815 r
.67432 .35663 m .67489 .35664 L .67488 .35517 L F
.67489 .35664 m .67749 .35672 L .67548 .35553 L F
.67489 .35664 m .67548 .35553 L .67488 .35517 L F
.9 .976 .808 r
.67961 .35004 m .67713 .35332 L .67639 .35224 L F
0 0 0 r
.67639 .35224 m .67549 .35552 L .67692 .35209 L F
.67549 .35552 m .67538 .3559 L .67569 .35512 L F
.67549 .35552 m .67569 .35512 L .67692 .35209 L F
.462 .262 .522 r
.67443 .35491 m .67749 .35672 L .67538 .3559 L F
0 0 .522 r
.67668 .35291 m .67749 .35672 L .67807 .35587 L F
.024 .434 .867 r
.67694 .35613 m .67749 .35672 L .67781 .35625 L F
.67543 .35592 m .67781 .35625 L .67757 .35588 L F
.67757 .35588 m .67781 .35625 L .67807 .35587 L F
0 0 .369 r
.67719 .35664 m .67709 .35589 L .67807 .35587 L F
.024 .434 .867 r
.67538 .3559 m .67543 .35592 L .67807 .35587 L F
0 0 .369 r
.67709 .35589 m .67668 .35291 L .67807 .35587 L F
.024 .434 .867 r
.67689 .35445 m .67807 .35587 L .67725 .35411 L F
.67538 .3559 m .67709 .35588 L .67689 .35445 L F
.67709 .35588 m .67807 .35587 L .67689 .35445 L F
0 0 .369 r
.67719 .35661 m .67791 .35784 L .67732 .35548 L F
.67719 .35664 m .6772 .35666 L .67719 .35661 L F
.6772 .35666 m .67791 .35784 L .67719 .35661 L F
.024 .434 .867 r
.67589 .35472 m .67687 .35428 L .67668 .35291 L F
.67687 .35428 m .67725 .35411 L .67668 .35291 L F
0 0 .369 r
.67709 .35589 m .67709 .35588 L .67668 .35291 L F
.024 .434 .867 r
.67538 .3559 m .67725 .35411 L .67589 .35472 L F
0 0 .369 r
.67709 .35588 m .67732 .35548 L .67668 .35291 L F
.67719 .35664 m .67732 .35548 L .67709 .35589 L F
.024 .434 .867 r
.67543 .35592 m .67676 .35644 L .67694 .35613 L F
.67676 .35644 m .67749 .35672 L .67694 .35613 L F
.874 .548 .038 r
.67695 .35397 m .67732 .35548 L .6766 .35306 L F
.67732 .35548 m .67791 .35784 L .67722 .35531 L F
.67732 .35548 m .67722 .35531 L .6766 .35306 L F
.01 .567 .815 r
.6744 .35539 m .67488 .35517 L .67443 .35491 L F
.67432 .35663 m .67488 .35517 L .6744 .35539 L F
.874 .548 .038 r
.6766 .35306 m .67729 .35559 L .67635 .35352 L F
.67729 .35559 m .67791 .35784 L .67681 .3548 L F
.67729 .35559 m .67681 .3548 L .67635 .35352 L F
.67668 .35291 m .67695 .35397 L .6766 .35306 L F
.149 0 0 r
.67432 .35663 m .67628 .35686 L .67662 .35695 L F
.01 .567 .815 r
.67432 .35663 m .67662 .35695 L .67749 .35672 L F
.937 .919 .544 r
.67719 .35664 m .67709 .35921 L .67607 .36012 L F
.67709 .35921 m .67701 .3611 L .67607 .36012 L F
.91 .733 .236 r
.67855 .35713 m .67846 .35983 L .67798 .35886 L F
.004 .187 .701 r
.34822 .60105 m .34915 .59948 L .34717 .59769 L F
.112 .001 .437 r
.34722 .60349 m .34915 .59948 L .34822 .60105 L F
0 0 0 r
.5362 .422 m .53503 .42335 L .53342 .42421 L F
.624 .433 .604 r
.53596 .42012 m .53503 .42335 L .5362 .422 L F
.576 .242 .367 r
.43571 .45887 m .4356 .46061 L .43294 .46057 L F
.79 .431 .376 r
.43966 .46123 m .4356 .46061 L .43571 .45887 L F
.796 .894 .914 r
.40457 .46293 m .40636 .46409 L .40934 .4617 L F
.692 .621 .772 r
.40636 .46409 m .40988 .46451 L .40934 .4617 L F
.2 .346 .788 r
.41797 .52465 m .41665 .52644 L .41521 .52244 L F
0 0 .068 r
.41797 .52465 m .41713 .52762 L .41665 .52644 L F
.816 .708 .746 r
.39424 .45725 m .39553 .46081 L .39417 .45784 L F
.966 .727 .525 r
.39417 .45784 m .39553 .46081 L .39405 .46088 L F
.471 .515 .822 r
.39755 .45984 m .39553 .46081 L .39424 .45725 L F
.449 .025 .142 r
.39755 .45984 m .39405 .46088 L .39553 .46081 L F
.611 .073 0 r
.42757 .59062 m .4306 .59267 L .42801 .59442 L F
.42757 .59062 m .43105 .59173 L .4306 .59267 L F
.962 .71 .511 r
.30865 .57025 m .31079 .57159 L .31104 .56845 L F
.908 .926 .815 r
.3478 .57391 m .34677 .57847 L .34939 .575 L F
.3478 .57391 m .3449 .57775 L .34677 .57847 L F
.564 .392 .606 r
.34677 .57847 m .34962 .57826 L .34939 .575 L F
.602 .908 .982 r
.34677 .57847 m .34754 .57666 L .34962 .57826 L F
.34677 .57847 m .3449 .57775 L .34754 .57666 L F
.292 .061 .382 r
.50507 .51295 m .50512 .5156 L .50251 .51631 L F
.234 0 .332 r
.50512 .5156 m .50256 .51897 L .50251 .51631 L F
.316 0 0 r
.3115 .54231 m .31547 .54115 L .31077 .53884 L F
.278 .781 .842 r
.29015 .64351 m .29027 .64373 L .28833 .64396 L F
.004 0 0 r
.29015 .64351 m .28833 .64396 L .28715 .64476 L F
.479 .527 .829 r
.29003 .64327 m .29015 .64351 L .28948 .64401 L F
.29189 .64078 m .29015 .64351 L .29003 .64327 L F
.278 .781 .842 r
.29015 .64351 m .29331 .64338 L .29027 .64373 L F
.665 .571 .74 r
.29544 .64258 m .29306 .64636 L .29331 .64338 L F
.665 .628 .802 r
.49203 .47023 m .49337 .47379 L .49593 .47092 L F
.651 .605 .79 r
.49337 .47379 m .49716 .47443 L .49593 .47092 L F
.656 .581 .759 r
.49337 .47379 m .4973 .4771 L .49716 .47443 L F
.715 .622 .752 r
.49716 .47443 m .4973 .4771 L .49997 .47381 L F
.665 .549 .713 r
.4973 .4771 m .50112 .47745 L .49997 .47381 L F
.629 .961 .894 r
.55001 .43018 m .54891 .43187 L .55095 .43051 L F
.787 .542 .566 r
.31747 .56783 m .32378 .56831 L .31871 .56737 L F
.31747 .56783 m .32365 .57108 L .32378 .56831 L F
.602 .512 .725 r
.31747 .56783 m .32331 .57335 L .32365 .57108 L F
0 0 .472 r
.3172 .56857 m .31796 .57202 L .31756 .56859 L F
.438 .431 .754 r
.31826 .57477 m .31747 .56783 L .31796 .57202 L F
.784 .694 .765 r
.31703 .56782 m .313 .56785 L .31577 .56475 L F
.23 0 0 r
.31703 .56782 m .31544 .56807 L .313 .56785 L F
.405 .417 .76 r
.31703 .56782 m .31826 .56425 L .31577 .56475 L F
.31703 .56782 m .31871 .56737 L .31826 .56425 L F
.31703 .56782 m .31826 .56425 L .31577 .56475 L F
.31703 .56782 m .31871 .56737 L .31826 .56425 L F
.551 .131 .197 r
.31871 .56737 m .31544 .56807 L .31703 .56782 L F
0 0 .472 r
.31703 .56782 m .31747 .56783 L .31871 .56737 L F
.438 .431 .754 r
.31826 .57477 m .32075 .57442 L .31747 .56783 L F
0 0 .472 r
.31703 .56782 m .3172 .56857 L .31747 .56783 L F
.3172 .56857 m .31756 .56859 L .31747 .56783 L F
.602 .512 .725 r
.31796 .5683 m .32075 .57442 L .32331 .57335 L F
.31747 .56783 m .31779 .56847 L .31796 .5683 L F
.31779 .56847 m .32075 .57442 L .31796 .5683 L F
.474 .116 .277 r
.31881 .5678 m .3171 .57027 L .31891 .56779 L F
0 0 0 r
.31849 .56825 m .31802 .56862 L .31848 .56778 L F
.31823 .56863 m .31802 .56862 L .31849 .56825 L F
.3185 .56865 m .31848 .56778 L .31868 .56759 L F
.551 .131 .197 r
.31871 .56737 m .31846 .56782 L .31544 .56807 L F
.474 .116 .277 r
.31544 .56807 m .3171 .57027 L .31881 .5678 L F
0 0 0 r
.32059 .56622 m .3171 .57027 L .31891 .56779 L F
.3185 .56865 m .31823 .56863 L .31849 .56825 L F
.31868 .56759 m .31848 .56778 L .31871 .56737 L F
.561 .391 .608 r
.31544 .56807 m .31881 .5678 L .31826 .56425 L F
.31881 .5678 m .31891 .56779 L .31889 .5677 L F
.657 .603 .782 r
.31826 .56425 m .31871 .56737 L .32189 .56544 L F
.195 .256 .699 r
.32059 .56622 m .31871 .56737 L .31826 .56425 L F
.561 .391 .608 r
.31881 .5678 m .31889 .5677 L .31826 .56425 L F
0 0 0 r
.32059 .56622 m .3185 .56865 L .3186 .56801 L F
.31988 .56665 m .31889 .5677 L .31871 .56737 L F
.32059 .56622 m .3186 .56801 L .31988 .56665 L F
.37 .263 .6 r
.31826 .56425 m .31889 .5677 L .32059 .56622 L F
.31889 .5677 m .31891 .56779 L .32059 .56622 L F
0 0 0 r
.31889 .5677 m .3186 .56801 L .31862 .56795 L F
.31889 .5677 m .31862 .56795 L .31871 .56737 L F
.3185 .56865 m .3171 .57027 L .31802 .56862 L F
.594 .595 .823 r
.36875 .54205 m .36612 .54255 L .36365 .53812 L F
.486 .273 .515 r
.36875 .54205 m .36604 .54543 L .36612 .54255 L F
.36875 .54205 m .36604 .54543 L .36612 .54255 L F
.344 .348 .719 r
.34247 .56445 m .34092 .56538 L .33984 .56206 L F
.34247 .56445 m .33984 .56206 L .34056 .56415 L F
.312 .343 .732 r
.33984 .56206 m .34247 .56445 L .34056 .56415 L F
.636 .472 .643 r
.29004 .53586 m .29016 .53939 L .28755 .53908 L F
0 0 0 r
.28755 .53908 m .28901 .53807 L .29004 .53586 L F
.995 .762 .458 r
.28901 .53807 m .29016 .53939 L .29004 .53586 L F
0 .26 .768 r
.2353 .59466 m .23554 .59298 L .23294 .59079 L F
.821 .939 .575 r
.23728 .59112 m .23554 .59298 L .2353 .59466 L F
.967 .697 .47 r
.36094 .63001 m .36259 .63336 L .36053 .63265 L F
.933 .878 .759 r
.36053 .63265 m .36259 .63336 L .36077 .63395 L F
.66 .465 .61 r
.3286 .57559 m .32927 .57797 L .32612 .57774 L F
.553 .559 .814 r
.3303 .57364 m .32927 .57797 L .3286 .57559 L F
.982 .761 .354 r
.40816 .58836 m .40715 .58842 L .40776 .58668 L F
.40816 .58836 m .40784 .59086 L .40715 .58842 L F
.5 .214 .412 r
.40988 .46451 m .41152 .4601 L .40934 .4617 L F
.681 .476 .602 r
.40988 .46451 m .41284 .46662 L .41301 .46439 L F
.40988 .46451 m .41018 .46788 L .41284 .46662 L F
.171 .7 .689 r
.43105 .59173 m .43217 .59145 L .4306 .59267 L F
.43105 .59173 m .43337 .59115 L .43217 .59145 L F
0 0 0 r
.25407 .52648 m .25389 .52612 L .25469 .52568 L F
.25407 .52648 m .25216 .52798 L .25389 .52612 L F
.611 .296 .412 r
.43228 .59777 m .43521 .59836 L .43537 .59696 L F
.389 0 .022 r
.43537 .59696 m .43456 .59779 L .43228 .59777 L F
.482 .62 .91 r
.43372 .59548 m .43491 .59779 L .43228 .59777 L F
.364 0 .005 r
.43662 .59775 m .43558 .59777 L .43537 .59696 L F
0 0 .137 r
.43537 .59696 m .43521 .59836 L .43549 .59743 L F
.364 0 .005 r
.43558 .59777 m .43456 .59779 L .43537 .59696 L F
.43762 .59754 m .436 .59712 L .4384 .59667 L F
.436 .59712 m .43537 .59696 L .43657 .59684 L F
.436 .59712 m .43657 .59684 L .4384 .59667 L F
0 0 .137 r
.43537 .59696 m .43549 .59743 L .43649 .59417 L F
.915 .805 .724 r
.43649 .59417 m .43551 .59736 L .43372 .59548 L F
.43551 .59736 m .43549 .59743 L .43545 .59739 L F
.43551 .59736 m .43545 .59739 L .43372 .59548 L F
.43549 .59743 m .43521 .59836 L .43491 .59778 L F
.43549 .59743 m .43491 .59778 L .43372 .59548 L F
.364 0 .005 r
.43762 .59754 m .43662 .59775 L .43581 .59724 L F
.436 .59712 m .43581 .59724 L .43537 .59696 L F
.43762 .59754 m .43581 .59724 L .436 .59712 L F
.43662 .59775 m .43405 .5983 L .43456 .59779 L F
.482 .62 .91 r
.43491 .59779 m .43521 .59836 L .43254 .59782 L F
.43456 .59779 m .43254 .59782 L .43228 .59777 L F
.43491 .59779 m .43254 .59782 L .43456 .59779 L F
.389 0 .022 r
.43456 .59779 m .43405 .5983 L .43228 .59777 L F
.812 .848 .877 r
.60218 .37198 m .60682 .37074 L .60485 .36881 L F
.127 0 0 r
.45332 .46065 m .45589 .46027 L .454 .46163 L F
.595 .488 .702 r
.5501 .4384 m .55313 .43873 L .55322 .43578 L F
.5501 .4384 m .55313 .43873 L .55322 .43578 L F
.022 0 .131 r
.62565 .38699 m .62308 .39117 L .62253 .38747 L F
.771 .551 .599 r
.54397 .46068 m .54771 .46066 L .54773 .45752 L F
.441 .284 .57 r
.54773 .45752 m .54771 .46066 L .54992 .46019 L F
.971 .689 .438 r
.28217 .65625 m .28246 .65641 L .28145 .65551 L F
.611 .814 .978 r
.28246 .65641 m .28558 .65583 L .28303 .65452 L F
.786 .288 0 r
.57719 .37661 m .57607 .37697 L .57625 .37515 L F
.57719 .37661 m .57887 .37907 L .57607 .37697 L F
.226 .74 .72 r
.65606 .37994 m .65157 .38111 L .65408 .38034 L F
0 0 0 r
.65774 .37812 m .65862 .37663 L .65606 .37994 L F
.608 .954 .836 r
.65774 .37812 m .65606 .37994 L .65408 .38034 L F
0 0 0 r
.61532 .36651 m .61746 .36413 L .61835 .36473 L F
.61536 .36641 m .61746 .36413 L .61532 .36651 L F
.61536 .36641 m .61602 .36601 L .61746 .36413 L F
.61521 .36657 m .61536 .36641 L .61532 .36651 L F
.61521 .36657 m .61602 .36601 L .61536 .36641 L F
0 .176 .705 r
.61602 .36601 m .61743 .36726 L .61675 .36557 L F
.796 .915 .92 r
.61746 .36413 m .61602 .36601 L .61582 .36326 L F
0 .176 .705 r
.61602 .36601 m .61675 .36557 L .61624 .36431 L F
.61595 .36501 m .61624 .36431 L .61582 .36326 L F
.61602 .36601 m .61624 .36431 L .61595 .36501 L F
.03 .575 .839 r
.62091 .36494 m .61835 .36473 L .61746 .36413 L F
.641 .616 .809 r
.5479 .415 m .54559 .41645 L .54476 .41501 L F
.172 0 .194 r
.32908 .60472 m .3282 .60687 L .33108 .60379 L F
0 0 0 r
.6943 .36962 m .69747 .36695 L .69627 .36808 L F
.69849 .36453 m .69747 .36695 L .69891 .36292 L F
.753 .912 .536 r
.69627 .36808 m .69747 .36695 L .69849 .36453 L F
.696 .791 .924 r
.30456 .65655 m .30647 .65855 L .30868 .65679 L F
.738 .671 .785 r
.73592 .29647 m .7316 .29564 L .73517 .29575 L F
.204 .664 .943 r
.73782 .29583 m .73592 .29647 L .73517 .29575 L F
.73782 .29583 m .73956 .29677 L .73592 .29647 L F
.775 .977 .914 r
.46429 .43726 m .46236 .439 L .45985 .43905 L F
.419 .814 .591 r
.69072 .37212 m .6943 .36962 L .69287 .37078 L F
0 0 0 r
.69287 .37078 m .6943 .36962 L .69627 .36808 L F
.44041 .46113 m .43966 .46123 L .44182 .45995 L F
.44041 .46113 m .43894 .46306 L .43966 .46123 L F
.025 0 0 r
.28833 .64396 m .28615 .6443 L .2845 .64546 L F
.621 .952 .786 r
.56141 .47445 m .55946 .47508 L .5576 .47664 L F
.439 .866 .751 r
.56306 .47326 m .56141 .47445 L .56379 .47322 L F
.56306 .47326 m .55946 .47508 L .56141 .47445 L F
.706 .773 .905 r
.34149 .56877 m .33695 .56818 L .33993 .56843 L F
0 0 0 r
.34149 .56877 m .34197 .5672 L .34247 .56445 L F
.654 .95 .951 r
.34149 .56877 m .33993 .56843 L .34197 .5672 L F
.769 .683 .768 r
.32627 .6435 m .32791 .64036 L .3265 .63987 L F
.432 0 0 r
.32431 .64181 m .3265 .63987 L .32791 .64036 L F
.544 .115 .176 r
.46333 .5948 m .46561 .59447 L .46369 .59592 L F
0 0 0 r
.46369 .59592 m .46561 .59447 L .46812 .5935 L F
.071 0 .262 r
.49443 .53157 m .49269 .53273 L .49487 .52917 L F
.208 .013 .382 r
.49443 .53157 m .49212 .53523 L .49269 .53273 L F
.755 .939 .944 r
.46874 .45937 m .47311 .4584 L .47191 .45751 L F
.492 .844 .994 r
.47191 .45751 m .47311 .4584 L .47575 .45762 L F
.157 .351 .806 r
.47311 .4584 m .47636 .4609 L .47575 .45762 L F
.005 0 0 r
.30296 .64094 m .30553 .64084 L .30181 .64239 L F
.363 .821 .724 r
.2493 .52243 m .25065 .52175 L .25303 .52088 L F
.12 0 0 r
.25303 .52088 m .25065 .52175 L .25483 .52097 L F
.794 .912 .921 r
.7087 .29313 m .7041 .29416 L .70686 .29247 L F
.738 .265 .126 r
.30758 .64661 m .30999 .64916 L .30735 .64972 L F
.793 .422 .353 r
.73301 .30205 m .72985 .30316 L .72965 .30076 L F
.73301 .30205 m .73376 .30428 L .72985 .30316 L F
.808 .974 .677 r
.28112 .65018 m .27955 .65246 L .27964 .65135 L F
.247 .621 .958 r
.2797 .65057 m .27964 .65135 L .28152 .65125 L F
.82 .628 .643 r
.27722 .64684 m .27709 .65043 L .27285 .6485 L F
.247 .621 .958 r
.27686 .64951 m .27964 .65135 L .2797 .65057 L F
.808 .974 .677 r
.27955 .65246 m .27941 .65267 L .27964 .65135 L F
0 .139 .683 r
.27941 .65267 m .28145 .65551 L .27964 .65135 L F
.359 .16 .468 r
.34972 .60988 m .34954 .61248 L .34853 .61089 L F
.827 .737 .765 r
.43585 .58524 m .43593 .59139 L .43337 .59115 L F
.829 .545 0 r
.43593 .59139 m .43586 .59284 L .43337 .59115 L F
.43593 .59139 m .43649 .59417 L .43586 .59284 L F
.716 .973 .926 r
.63929 .34119 m .64124 .34159 L .64341 .33996 L F
.704 .905 .545 r
.52319 .44944 m .52488 .44771 L .52131 .44679 L F
.787 .289 0 r
.52323 .44803 m .52368 .44844 L .52319 .44944 L F
.704 .905 .545 r
.52319 .44944 m .5222 .45145 L .52488 .44771 L F
.787 .289 0 r
.52368 .44844 m .5265 .45096 L .52319 .44944 L F
.704 .905 .545 r
.52319 .44944 m .52206 .45166 L .5222 .45145 L F
.456 .707 .975 r
.52319 .44944 m .52519 .45165 L .52206 .45166 L F
.193 .374 .814 r
.5674 .42858 m .56458 .42575 L .56717 .42521 L F
.717 .459 .535 r
.56717 .42521 m .57125 .42782 L .5674 .42858 L F
.39 .762 .992 r
.44013 .57953 m .43889 .5809 L .43698 .57922 L F
.44005 .57962 m .44165 .58063 L .43889 .5809 L F
.628 .398 .55 r
.43762 .57955 m .43709 .58333 L .44048 .58103 L F
.43698 .57922 m .43699 .57953 L .43762 .57955 L F
.43699 .57953 m .43709 .58333 L .43762 .57955 L F
.39 .762 .992 r
.44013 .57953 m .44027 .57963 L .44005 .57962 L F
.44027 .57963 m .44165 .58063 L .44005 .57962 L F
.423 .716 .985 r
.28755 .53908 m .29016 .53939 L .28901 .53807 L F
.118 0 0 r
.33495 .55581 m .3364 .5562 L .3375 .55519 L F
.33495 .55581 m .33389 .55689 L .3364 .5562 L F
.87 .587 .505 r
.42231 .53125 m .42309 .52843 L .42068 .52938 L F
.42231 .53125 m .42467 .53259 L .42309 .52843 L F
.677 .499 .638 r
.42309 .52843 m .42702 .53238 L .42743 .5292 L F
.42309 .52843 m .42467 .53259 L .42702 .53238 L F
.483 .293 .547 r
.30743 .52543 m .30479 .52615 L .30735 .52273 L F
.507 .358 .613 r
.30479 .52615 m .30745 .52913 L .30743 .52543 L F
.483 .293 .547 r
.30743 .52543 m .30479 .52615 L .30735 .52273 L F
.507 .358 .613 r
.30743 .52543 m .30745 .52913 L .30479 .52615 L F
.431 .82 .987 r
.23367 .57833 m .23192 .57879 L .23482 .57635 L F
.23367 .57833 m .23204 .57814 L .23192 .57879 L F
.23204 .57814 m .23148 .57808 L .23192 .57879 L F
.722 .925 .583 r
.23192 .57879 m .23107 .58061 L .23171 .57997 L F
.23192 .57879 m .23171 .57997 L .23375 .57794 L F
.174 0 0 r
.54306 .48445 m .54461 .48494 L .54252 .486 L F
.54306 .48445 m .54575 .48386 L .54461 .48494 L F
.288 .333 .735 r
.33107 .50669 m .33172 .50243 L .3297 .50376 L F
.464 .444 .752 r
.22251 .56865 m .22472 .56907 L .22382 .56405 L F
.657 .577 .753 r
.22251 .56865 m .22762 .57149 L .22472 .56907 L F
.468 .498 .806 r
.28658 .65903 m .28749 .65538 L .28558 .65583 L F
.28658 .65903 m .2889 .65963 L .28749 .65538 L F
.56 .875 .993 r
.52973 .43914 m .52644 .43936 L .52886 .43851 L F
.537 0 0 r
.53106 .44064 m .52973 .43914 L .52886 .43851 L F
.955 .855 .703 r
.57264 .4347 m .57207 .43846 L .57092 .43807 L F
.925 .751 .647 r
.57207 .43846 m .57009 .44066 L .57092 .43807 L F
0 0 0 r
.42787 .59617 m .42531 .59685 L .42801 .59442 L F
.486 .814 1 r
.3478 .57391 m .34939 .575 L .35155 .5743 L F
.421 .285 .589 r
.34939 .575 m .35178 .5772 L .35155 .5743 L F
.34939 .575 m .34962 .57826 L .35178 .5772 L F
.491 .795 .999 r
.65775 .37533 m .65862 .37663 L .6546 .37589 L F
.65775 .37533 m .65862 .37663 L .6546 .37589 L F
.972 .747 .319 r
.65775 .37533 m .65862 .37663 L .65774 .37812 L F
.587 .851 .994 r
.66119 .37566 m .65862 .37663 L .65775 .37533 L F
.493 .212 .416 r
.61218 .36938 m .61505 .3687 L .61521 .36657 L F
.291 .218 .599 r
.61505 .3687 m .61602 .36601 L .61521 .36657 L F
.143 0 0 r
.61953 .3426 m .62238 .34223 L .6239 .34116 L F
0 0 0 r
.6239 .34116 m .62515 .3414 L .62629 .34013 L F
.715 .612 .74 r
.49326 .48736 m .4962 .48711 L .49436 .48309 L F
.619 .448 .629 r
.49352 .49034 m .4962 .48711 L .49326 .48736 L F
.49352 .49034 m .4965 .49031 L .4962 .48711 L F
.725 .616 .736 r
.49436 .48309 m .4962 .48711 L .49884 .48373 L F
.627 .477 .659 r
.4962 .48711 m .49923 .48683 L .49884 .48373 L F
.591 .408 .603 r
.4965 .49031 m .49923 .48683 L .4962 .48711 L F
.853 .816 .812 r
.40891 .50072 m .40744 .50546 L .40871 .50359 L F
.816 .959 .628 r
.40871 .50359 m .40918 .50147 L .41096 .50015 L F
0 0 .437 r
.40744 .50546 m .40918 .50147 L .40871 .50359 L F
.961 .944 .686 r
.35598 .63712 m .35411 .64326 L .35194 .64015 L F
.896 .566 .414 r
.69097 .32443 m .68916 .32594 L .68897 .3234 L F
.69097 .32443 m .69136 .32686 L .68916 .32594 L F
.479 0 0 r
.28009 .64307 m .27588 .64001 L .2756 .64283 L F
.687 .241 .186 r
.2778 .64491 m .28009 .64307 L .2756 .64283 L F
.793 .39 .288 r
.27887 .64405 m .2821 .64631 L .28009 .64307 L F
.27967 .64552 m .2821 .64631 L .27887 .64405 L F
.802 .42 .332 r
.28019 .64684 m .2821 .64631 L .2778 .64491 L F
.299 .789 .749 r
.2845 .64546 m .2821 .64631 L .28019 .64684 L F
.2845 .64546 m .28035 .64679 L .28384 .64817 L F
.28035 .64679 m .28019 .64684 L .28042 .64692 L F
.28035 .64679 m .28042 .64692 L .28384 .64817 L F
.793 .39 .288 r
.2778 .64491 m .27967 .64552 L .27887 .64405 L F
.651 .619 .805 r
.41473 .48972 m .41948 .49288 L .41973 .49075 L F
.27 .112 .475 r
.41948 .49288 m .42132 .48957 L .41973 .49075 L F
.41948 .49288 m .42132 .48957 L .41973 .49075 L F
.752 .381 .352 r
.53751 .45755 m .54099 .46019 L .5381 .46087 L F
.135 0 .29 r
.45864 .56563 m .4601 .56656 L .46024 .56416 L F
.45864 .56563 m .4587 .56744 L .4601 .56656 L F
.705 .577 .709 r
.48935 .48994 m .49326 .48736 L .48943 .48709 L F
.48935 .48994 m .49352 .49034 L .49326 .48736 L F
.669 .393 .493 r
.52732 .42863 m .52479 .43119 L .52334 .42772 L F
.52732 .42863 m .52736 .43123 L .52479 .43119 L F
.531 .165 .292 r
.52732 .42863 m .53 .43043 L .52736 .43123 L F
.52732 .42863 m .53066 .42857 L .53 .43043 L F
0 0 .123 r
.2265 .55545 m .2276 .55402 L .22797 .55142 L F
0 0 .195 r
.22641 .55837 m .2276 .55402 L .2265 .55545 L F
.899 .497 .232 r
.3702 .52311 m .37085 .52519 L .37286 .52605 L F
.913 .598 .433 r
.37085 .52519 m .37324 .5285 L .37286 .52605 L F
.94 .91 .763 r
.38737 .60265 m .38972 .60457 L .39033 .59986 L F
0 0 .035 r
.47697 .58166 m .47761 .58035 L .47641 .58433 L F
.564 .446 .677 r
.4306 .59267 m .42787 .59617 L .42801 .59442 L F
.804 .757 .809 r
.4362 .47738 m .43373 .48037 L .43734 .48077 L F
.726 .716 .841 r
.4362 .47738 m .43734 .48077 L .43992 .47977 L F
.258 0 0 r
.58493 .38341 m .58505 .38363 L .58124 .38241 L F
.326 0 0 r
.58493 .38341 m .58802 .38479 L .58505 .38363 L F
.542 .06 .059 r
.22933 .56852 m .22472 .56907 L .22762 .57149 L F
.22933 .56852 m .22887 .57074 L .22472 .56907 L F
0 0 0 r
.23184 .56517 m .23055 .56747 L .22933 .56852 L F
.007 0 0 r
.23035 .56939 m .22933 .56852 L .23055 .56747 L F
.23035 .56939 m .22887 .57074 L .22933 .56852 L F
.374 .84 .814 r
.61734 .37375 m .61861 .37266 L .61526 .37319 L F
.61734 .37375 m .61994 .37275 L .61861 .37266 L F
.239 0 .243 r
.5159 .50254 m .51292 .50572 L .51334 .50331 L F
.762 .699 .792 r
.60767 .36291 m .61195 .36375 L .61039 .36201 L F
.861 .839 .822 r
.61039 .36201 m .61195 .36375 L .61464 .3603 L F
.433 .334 .643 r
.49352 .49034 m .49625 .4925 L .4965 .49031 L F
.49352 .49034 m .49419 .49353 L .49625 .4925 L F
.971 .658 .337 r
.62052 .37857 m .62202 .3797 L .62108 .37639 L F
0 0 .023 r
.62386 .37329 m .62108 .37639 L .62301 .37562 L F
0 .073 .594 r
.62108 .37639 m .62298 .37603 L .62301 .37562 L F
.62108 .37639 m .62202 .3797 L .62298 .37603 L F
.861 .981 .853 r
.36765 .49755 m .36737 .50002 L .36655 .49819 L F
.883 .455 .162 r
.36737 .50002 m .36629 .50125 L .36655 .49819 L F
.36737 .50002 m .36874 .50305 L .36629 .50125 L F
.787 .323 .138 r
.36737 .50002 m .37129 .5029 L .36874 .50305 L F
.899 .865 .797 r
.54134 .43196 m .53798 .43403 L .5406 .43333 L F
0 0 0 r
.54274 .42763 m .54134 .43196 L .54338 .43003 L F
.54338 .43003 m .54134 .43196 L .5406 .43333 L F
.867 .6 .071 r
.58539 .40079 m .58562 .39926 L .58453 .3977 L F
.58539 .40079 m .586 .40196 L .58562 .39926 L F
.699 .426 .507 r
.29487 .57682 m .29173 .58027 L .29195 .578 L F
.29487 .57682 m .29471 .58098 L .29173 .58027 L F
.655 .26 .285 r
.29487 .57682 m .29759 .57952 L .29471 .58098 L F
.29487 .57682 m .29855 .5779 L .29759 .57952 L F
.324 .071 .367 r
.53342 .42421 m .53301 .42772 L .53066 .42857 L F
.389 .123 .385 r
.53545 .42597 m .53342 .42421 L .53503 .42335 L F
.53545 .42597 m .53301 .42772 L .53342 .42421 L F
.017 0 0 r
.64973 .33708 m .64864 .33817 L .64604 .33895 L F
0 0 0 r
.65194 .3359 m .65208 .33587 L .64973 .33708 L F
.65208 .33587 m .64864 .33817 L .64973 .33708 L F
.347 .117 .416 r
.57345 .45177 m .57582 .45088 L .57603 .44831 L F
.284 .068 .399 r
.57603 .44831 m .57776 .44927 L .5783 .44707 L F
.57603 .44831 m .57582 .45088 L .57776 .44927 L F
0 0 0 r
.5721 .45277 m .57582 .45088 L .57345 .45177 L F
.528 .211 .374 r
.34092 .56538 m .33993 .56843 L .33695 .56818 L F
.265 0 .264 r
.34197 .5672 m .34092 .56538 L .34247 .56445 L F
.34197 .5672 m .33993 .56843 L .34092 .56538 L F
.266 .768 .876 r
.6099 .34441 m .61287 .34392 L .61425 .34434 L F
.182 0 0 r
.61287 .34392 m .61694 .34349 L .61425 .34434 L F
.98 .858 .648 r
.42236 .56622 m .42501 .56516 L .42388 .5643 L F
.42236 .56622 m .42347 .56795 L .42501 .56516 L F
.712 .626 .76 r
.48943 .48709 m .49326 .48736 L .49196 .48374 L F
.715 .612 .74 r
.49326 .48736 m .49436 .48309 L .49196 .48374 L F
.723 .669 .796 r
.56024 .41443 m .5573 .41624 L .55678 .41446 L F
.067 .362 .832 r
.55678 .41446 m .55899 .41532 L .55872 .41483 L F
.064 0 0 r
.56024 .41443 m .55678 .41446 L .55791 .4143 L F
.067 .362 .832 r
.55678 .41446 m .55872 .41483 L .55783 .41321 L F
.164 0 0 r
.55539 .4142 m .55678 .41446 L .55371 .41414 L F
.55791 .4143 m .55678 .41446 L .55539 .4142 L F
.43 .856 .724 r
.47405 .43188 m .46991 .43388 L .47275 .43122 L F
.746 .987 .898 r
.47496 .42975 m .47691 .42974 L .47405 .43188 L F
.719 .966 .938 r
.47496 .42975 m .47405 .43188 L .47275 .43122 L F
.497 .288 .526 r
.48212 .51616 m .48493 .51626 L .48512 .51308 L F
.485 .326 .59 r
.48212 .51616 m .48417 .51815 L .48493 .51626 L F
.48212 .51616 m .48255 .51952 L .48417 .51815 L F
.491 .241 .462 r
.5638 .45671 m .56371 .45459 L .5611 .45674 L F
0 0 .269 r
.5611 .45674 m .56222 .45834 L .5638 .45671 L F
.5611 .45674 m .56084 .46034 L .56222 .45834 L F
.496 .373 .642 r
.41096 .50015 m .41189 .49532 L .40941 .49857 L F
.41096 .50015 m .41335 .49732 L .41189 .49532 L F
.41096 .50015 m .41355 .49954 L .41335 .49732 L F
.712 .219 .07 r
.41096 .50015 m .41323 .50232 L .41355 .49954 L F
.41096 .50015 m .40918 .50147 L .41323 .50232 L F
.482 .62 .91 r
.43372 .59548 m .43228 .59777 L .43062 .5957 L F
.223 0 0 r
.43228 .59777 m .43306 .5981 L .43062 .5957 L F
.4328 .59793 m .43405 .5983 L .43306 .5981 L F
.356 .827 .884 r
.43306 .5981 m .43762 .59754 L .43534 .59739 L F
.034 0 0 r
.43534 .59739 m .43323 .59821 L .43306 .5981 L F
.43323 .59821 m .43164 .59884 L .43306 .5981 L F
.223 0 0 r
.43228 .59777 m .4328 .59793 L .43306 .5981 L F
.689 .52 .653 r
.37661 .60453 m .37633 .60727 L .3747 .60672 L F
.821 .562 .549 r
.40147 .47282 m .40598 .47492 L .4035 .47185 L F
.687 .558 .703 r
.4035 .47185 m .4084 .47304 L .40863 .47043 L F
.4035 .47185 m .40598 .47492 L .4084 .47304 L F
.505 .911 .857 r
.42778 .45216 m .42408 .45357 L .42587 .45284 L F
.802 .975 .904 r
.42587 .45284 m .43025 .451 L .42778 .45216 L F
.255 .359 .778 r
.34622 .53705 m .34471 .53918 L .34331 .53528 L F
.539 .27 .456 r
.34746 .53933 m .34471 .53918 L .34622 .53705 L F
.34746 .53933 m .34429 .54158 L .34471 .53918 L F
.34746 .53933 m .34429 .54158 L .34471 .53918 L F
.371 0 .007 r
.54977 .42134 m .54646 .42241 L .5453 .42361 L F
.54879 .42183 m .5453 .42361 L .5487 .42191 L F
.639 .965 .888 r
.54691 .42189 m .5487 .42191 L .5453 .42361 L F
.165 0 0 r
.5485 .42206 m .5487 .42191 L .54691 .42189 L F
.55101 .42234 m .5487 .42191 L .5485 .42206 L F
.371 0 .007 r
.54977 .42134 m .54879 .42183 L .5487 .42191 L F
.247 0 0 r
.54977 .42134 m .55101 .42234 L .55203 .42086 L F
.54977 .42134 m .5487 .42191 L .55101 .42234 L F
.508 .868 .986 r
.2701 .52003 m .26957 .52149 L .27284 .51987 L F
.2701 .52003 m .26817 .52083 L .26957 .52149 L F
.305 .048 .349 r
.50782 .50972 m .50768 .51238 L .50507 .51295 L F
.212 .005 .367 r
.50702 .5145 m .50507 .51295 L .50768 .51238 L F
.50702 .5145 m .50512 .5156 L .50507 .51295 L F
.855 .781 .779 r
.5236 .44433 m .52131 .44679 L .52488 .44771 L F
.734 .688 .806 r
.5236 .44433 m .52781 .44612 L .52604 .44295 L F
.648 .648 .836 r
.52781 .44612 m .52908 .44191 L .52604 .44295 L F
.346 .678 .978 r
.52801 .44602 m .52781 .44612 L .5236 .44433 L F
.52801 .44602 m .5236 .44433 L .52488 .44771 L F
.761 .741 .835 r
.36077 .63395 m .36009 .63761 L .35786 .63552 L F
.981 .741 .334 r
.46946 .53755 m .46897 .53306 L .46964 .53571 L F
.946 .73 .58 r
.46713 .53151 m .46897 .53306 L .4693 .53612 L F
.46895 .53623 m .4693 .53612 L .46946 .53755 L F
.46713 .53151 m .4693 .53612 L .46895 .53623 L F
.46713 .53151 m .46895 .53623 L .46496 .53414 L F
.46895 .53623 m .46946 .53755 L .46775 .53625 L F
.46895 .53623 m .46775 .53625 L .46496 .53414 L F
.907 .731 .231 r
.46964 .53571 m .4694 .53622 L .46958 .53633 L F
.206 .733 .788 r
.46946 .53755 m .46698 .53773 L .46496 .53414 L F
.366 0 .082 r
.46964 .53571 m .46986 .53593 L .46948 .53606 L F
.46986 .53593 m .47116 .53728 L .46948 .53606 L F
.546 .513 .77 r
.47148 .53076 m .46964 .53571 L .46897 .53306 L F
.47148 .53076 m .47261 .5354 L .46964 .53571 L F
.366 0 .082 r
.46964 .53571 m .47261 .5354 L .47116 .53728 L F
.764 .732 .823 r
.47116 .53728 m .47022 .53361 L .46876 .53547 L F
.206 .733 .788 r
.46946 .53755 m .46894 .53744 L .46698 .53773 L F
.764 .732 .823 r
.46894 .53744 m .46876 .53547 L .46698 .53773 L F
.206 .733 .788 r
.46894 .53744 m .46886 .53742 L .46698 .53773 L F
.764 .732 .823 r
.46895 .53751 m .46894 .53744 L .46698 .53773 L F
.907 .731 .231 r
.46948 .53738 m .46894 .53741 L .46946 .53755 L F
.46894 .53741 m .46894 .53744 L .46946 .53755 L F
.764 .732 .823 r
.47116 .53728 m .46893 .53727 L .46895 .53751 L F
.366 0 .082 r
.46893 .53727 m .47116 .53728 L .46886 .53742 L F
.4694 .53622 m .47116 .53728 L .46893 .53727 L F
.46948 .53606 m .4697 .53622 L .4694 .53622 L F
.4697 .53622 m .47116 .53728 L .4694 .53622 L F
.764 .732 .823 r
.47116 .53728 m .46876 .53547 L .46893 .53727 L F
.907 .731 .231 r
.46894 .53741 m .46886 .53742 L .46894 .53744 L F
.979 .748 .519 r
.41441 .49208 m .41473 .48972 L .41221 .49042 L F
0 .159 .652 r
.41289 .49051 m .41221 .49042 L .41473 .48972 L F
.41289 .49051 m .41441 .49208 L .41221 .49042 L F
.8 .988 .734 r
.72871 .29037 m .72989 .29031 L .72856 .29205 L F
0 0 .444 r
.72811 .29325 m .72871 .29037 L .72856 .29205 L F
.398 .851 .897 r
.72483 .32684 m .72534 .32592 L .72525 .326 L F
.72483 .32684 m .72525 .326 L .72377 .32753 L F
.362 .829 .897 r
.72465 .32722 m .72483 .32684 L .72207 .32756 L F
.72574 .32707 m .72483 .32684 L .72465 .32722 L F
.402 .823 .968 r
.72574 .32707 m .72772 .32595 L .72483 .32684 L F
.347 .101 .392 r
.51057 .50647 m .51052 .50932 L .50782 .50972 L F
.245 .003 .335 r
.5098 .51131 m .50782 .50972 L .51052 .50932 L F
.5098 .51131 m .50768 .51238 L .50782 .50972 L F
.079 0 .207 r
.32508 .58301 m .3253 .58018 L .328 .57849 L F
.513 .353 .602 r
.32927 .57797 m .328 .57849 L .32612 .57774 L F
.32927 .57797 m .32957 .57899 L .328 .57849 L F
.535 .079 .116 r
.328 .57849 m .32718 .58193 L .32508 .58301 L F
.328 .57849 m .32957 .57899 L .32718 .58193 L F
.65 .394 .519 r
.24651 .61705 m .24629 .61399 L .24245 .61704 L F
.14 .686 .772 r
.26551 .52172 m .26151 .52207 L .26324 .522 L F
.629 .883 .988 r
.44184 .4463 m .44559 .44613 L .44316 .44714 L F
.893 .881 .815 r
.61314 .35888 m .617 .35697 L .61352 .35704 L F
.61314 .35888 m .61464 .3603 L .617 .35697 L F
.844 .755 .765 r
.61363 .39152 m .61779 .39203 L .61731 .38989 L F
.071 .624 .82 r
.61606 .39172 m .61779 .39203 L .61363 .39152 L F
.478 .488 .79 r
.62067 .38967 m .61779 .39203 L .61731 .38989 L F
.62067 .38967 m .62102 .39329 L .61779 .39203 L F
.142 .267 .733 r
.61731 .38989 m .61779 .39203 L .61961 .39085 L F
.415 .842 .954 r
.61961 .39085 m .61779 .39203 L .61606 .39172 L F
.303 .376 .773 r
.62089 .39396 m .61779 .39203 L .62102 .39329 L F
.769 .595 .662 r
.43135 .53249 m .43486 .53547 L .43389 .53187 L F
.43135 .53249 m .43129 .53555 L .43486 .53547 L F
.771 .643 .72 r
.43129 .53555 m .43245 .53939 L .43486 .53547 L F
.473 .454 .756 r
.49229 .50009 m .49378 .49608 L .4918 .49647 L F
.49229 .50009 m .49459 .49948 L .49378 .49608 L F
.496 .331 .587 r
.49229 .50009 m .49495 .50156 L .49459 .49948 L F
.49229 .50009 m .49241 .50264 L .49495 .50156 L F
.481 .836 .571 r
.25169 .59543 m .25356 .59596 L .2531 .59771 L F
.25169 .59543 m .25295 .59429 L .25356 .59596 L F
.25169 .59543 m .2502 .5966 L .25295 .59429 L F
.861 .839 .822 r
.61039 .36201 m .61464 .3603 L .61314 .35888 L F
.484 .869 .975 r
.43813 .44725 m .43698 .44869 L .43528 .44816 L F
.43813 .44725 m .43965 .44789 L .43698 .44869 L F
0 0 0 r
.54369 .44964 m .54454 .44687 L .54311 .44598 L F
.787 .993 .879 r
.54311 .44598 m .54454 .44687 L .54718 .44435 L F
.433 .198 .456 r
.56628 .45382 m .56371 .45459 L .5638 .45671 L F
.25 .014 .347 r
.56626 .4512 m .56371 .45459 L .56628 .45382 L F
.433 .198 .456 r
.56628 .45382 m .56371 .45459 L .5638 .45671 L F
.78 .697 .772 r
.44515 .47348 m .44916 .47403 L .44776 .47017 L F
.336 .796 .94 r
.41429 .45325 m .41468 .45357 L .41277 .45306 L F
.626 .75 .937 r
.41763 .45374 m .41468 .45357 L .41429 .45325 L F
0 .128 .648 r
.3353 .62065 m .33247 .61759 L .33342 .61641 L F
.3353 .62065 m .33342 .61641 L .33132 .61966 L F
.785 .47 .454 r
.33138 .62271 m .3353 .62065 L .33236 .61992 L F
.33138 .62271 m .33495 .62287 L .3353 .62065 L F
.695 .25 .192 r
.33194 .62499 m .33495 .62287 L .33138 .62271 L F
.33194 .62499 m .33138 .62271 L .33042 .62527 L F
0 0 0 r
.33077 .62442 m .33138 .62271 L .33196 .62155 L F
.33042 .62527 m .33138 .62271 L .33077 .62442 L F
.785 .47 .454 r
.33138 .62271 m .33236 .61992 L .33132 .61966 L F
0 0 .199 r
.33738 .61702 m .3353 .62065 L .33788 .61995 L F
.37 .098 .365 r
.3353 .62065 m .33495 .62287 L .33788 .61995 L F
.805 .888 .904 r
.5577 .4103 m .55382 .41152 L .55635 .40824 L F
.69 .73 .881 r
.55635 .40824 m .55998 .40887 L .5577 .4103 L F
.407 .487 .829 r
.2404 .55085 m .24017 .55403 L .23859 .55118 L F
.462 .79 .999 r
.41887 .45266 m .41763 .45374 L .41429 .45325 L F
.41887 .45266 m .42062 .45375 L .41763 .45374 L F
.622 .129 .061 r
.58587 .42342 m .58733 .422 L .58313 .42158 L F
.975 .685 .406 r
.58587 .42342 m .58752 .42453 L .58733 .422 L F
0 0 0 r
.66058 .38887 m .66402 .38618 L .66285 .38742 L F
.66285 .38742 m .66402 .38618 L .66666 .38526 L F
.47 0 0 r
.36211 .6257 m .3635 .62493 L .36539 .62589 L F
.728 .538 .634 r
.34593 .53217 m .34964 .53281 L .35008 .52962 L F
.045 0 .396 r
.35008 .52962 m .35115 .53145 L .35285 .52957 L F
.35008 .52962 m .34964 .53281 L .35115 .53145 L F
.39 .84 .747 r
.72341 .29897 m .7245 .2981 L .72513 .29674 L F
.72341 .29897 m .72179 .29941 L .7245 .2981 L F
.274 .047 .377 r
.51264 .50826 m .51057 .50647 L .51292 .50572 L F
.51264 .50826 m .51052 .50932 L .51057 .50647 L F
.707 .822 .936 r
.61563 .41275 m .61908 .41326 L .61775 .41112 L F
.595 .84 .991 r
.61908 .41326 m .62026 .41112 L .61775 .41112 L F
.61908 .41326 m .62182 .4124 L .62026 .41112 L F
.583 .868 .995 r
.40319 .48322 m .40059 .4834 L .40256 .48241 L F
.353 .022 .258 r
.52814 .49345 m .52723 .49655 L .52489 .49619 L F
.35 0 .198 r
.53083 .49313 m .52723 .49655 L .52814 .49345 L F
.573 .821 .992 r
.30865 .57025 m .30779 .57233 L .31079 .57159 L F
.868 .949 .864 r
.58257 .35379 m .57965 .35691 L .57998 .35375 L F
.297 0 0 r
.57691 .35412 m .58157 .35274 L .57998 .35375 L F
.813 .426 0 r
.57971 .35422 m .57998 .35375 L .57691 .35412 L F
.285 .711 .969 r
.57965 .35691 m .58085 .35588 L .58024 .35438 L F
.57977 .35574 m .58024 .35438 L .57998 .35375 L F
.57965 .35691 m .58024 .35438 L .57977 .35574 L F
.813 .426 0 r
.57971 .35422 m .58085 .35588 L .57998 .35375 L F
.297 0 0 r
.57691 .35412 m .57971 .35422 L .58157 .35274 L F
.792 .958 .635 r
.58157 .35274 m .58052 .35358 L .58237 .35069 L F
.868 .949 .864 r
.58257 .35379 m .57998 .35375 L .58157 .35274 L F
.792 .958 .635 r
.58052 .35358 m .57971 .35422 L .58079 .35279 L F
.58052 .35358 m .58079 .35279 L .58237 .35069 L F
.285 .711 .969 r
.57965 .35691 m .58258 .35697 L .58085 .35588 L F
.831 .549 .513 r
.62306 .40383 m .62656 .40251 L .62567 .40119 L F
.95 .953 .723 r
.62567 .40119 m .62656 .40251 L .62669 .39873 L F
.108 0 0 r
.23786 .5923 m .23554 .59298 L .23728 .59112 L F
.908 .562 .376 r
.3954 .52958 m .39337 .53061 L .3935 .52812 L F
.3954 .52958 m .39616 .53248 L .39337 .53061 L F
.666 .973 .828 r
.46022 .46407 m .46393 .4619 L .46201 .46232 L F
.547 .921 .775 r
.46393 .4619 m .46383 .46134 L .46201 .46232 L F
.46393 .4619 m .46629 .46038 L .46383 .46134 L F
.867 .761 .743 r
.56458 .42575 m .56097 .42752 L .56058 .42488 L F
.978 .757 .538 r
.39137 .57389 m .393 .57485 L .39169 .5711 L F
.985 .783 .551 r
.391 .57668 m .393 .57485 L .39137 .57389 L F
.391 .57668 m .39251 .57766 L .393 .57485 L F
.534 .81 .997 r
.55611 .39447 m .5577 .39588 L .56014 .39508 L F
.549 .556 .814 r
.5577 .39588 m .56106 .39854 L .56014 .39508 L F
.031 .501 .881 r
.25529 .62688 m .25932 .62881 L .25952 .62848 L F
.588 .465 .679 r
.49923 .48683 m .5015 .48309 L .49884 .48373 L F
.544 .115 .176 r
.46333 .5948 m .46369 .59592 L .46158 .59545 L F
.047 0 0 r
.41674 .51818 m .41783 .51637 L .41757 .51897 L F
.579 .003 0 r
.41713 .52762 m .42056 .53014 L .42068 .52938 L F
.847 .387 .017 r
.42056 .53014 m .42231 .53125 L .42068 .52938 L F
.738 .898 .95 r
.30735 .52273 m .3083 .5201 L .31014 .51969 L F
.399 .151 .418 r
.31014 .51969 m .30967 .52215 L .30735 .52273 L F
.285 0 0 r
.3083 .5201 m .31228 .51884 L .31014 .51969 L F
.321 .085 .391 r
.31228 .51884 m .30967 .52215 L .31014 .51969 L F
.738 .898 .95 r
.30735 .52273 m .30548 .52162 L .3083 .5201 L F
.442 .262 .54 r
.30735 .52273 m .30619 .52146 L .30548 .52162 L F
.30735 .52273 m .30967 .52215 L .30619 .52146 L F
.30735 .52273 m .30743 .52543 L .30967 .52215 L F
.30967 .52215 m .30743 .52543 L .30735 .52273 L F
.988 .72 .409 r
.52434 .40366 m .52454 .40668 L .52604 .40535 L F
.511 .775 .991 r
.52434 .40366 m .52604 .40535 L .52797 .40452 L F
.52434 .40366 m .52797 .40452 L .5268 .40344 L F
.74 .929 .584 r
.52604 .40535 m .5268 .40344 L .52797 .40452 L F
.52604 .40535 m .52454 .40668 L .5268 .40344 L F
.962 .934 .618 r
.24397 .59686 m .24342 .60113 L .24461 .5969 L F
0 .106 .64 r
.24263 .60056 m .24204 .60323 L .24342 .60113 L F
.596 .447 .649 r
.23935 .60413 m .24116 .60427 L .2404 .60404 L F
.258 0 0 r
.2383 .60507 m .24231 .60435 L .23839 .60406 L F
.2383 .60507 m .24065 .60501 L .24231 .60435 L F
.376 0 0 r
.2404 .60404 m .24065 .60501 L .2383 .60507 L F
.24204 .60323 m .24149 .60393 L .2404 .60404 L F
.596 .447 .649 r
.2404 .60404 m .24116 .60427 L .24125 .60402 L F
.376 0 0 r
.24204 .60323 m .2404 .60404 L .23839 .60406 L F
.596 .447 .649 r
.24202 .60194 m .24299 .59956 L .24317 .59832 L F
.24129 .60428 m .24209 .60207 L .24202 .60194 L F
.24209 .60207 m .24299 .59956 L .24202 .60194 L F
.23839 .60406 m .24003 .60404 L .24317 .59832 L F
.24003 .60404 m .24125 .60402 L .24317 .59832 L F
.666 .822 .388 r
.24317 .59832 m .24209 .60016 L .24396 .59687 L F
.529 .379 .621 r
.24181 .59644 m .23952 .60097 L .24317 .59832 L F
.666 .822 .388 r
.24317 .59832 m .23969 .59591 L .24181 .59644 L F
.24317 .59832 m .24168 .59825 L .23969 .59591 L F
.24317 .59832 m .24397 .59686 L .24168 .59825 L F
.24317 .59832 m .24396 .59687 L .24397 .59686 L F
.596 .447 .649 r
.24116 .60427 m .24179 .60269 L .24317 .59832 L F
0 .106 .64 r
.24209 .60016 m .24206 .60201 L .24263 .60056 L F
.24206 .60201 m .24204 .60323 L .24263 .60056 L F
.24206 .60201 m .24251 .60293 L .24204 .60323 L F
.24251 .60293 m .24296 .60383 L .24257 .60358 L F
.24251 .60293 m .24257 .60358 L .24204 .60323 L F
.596 .447 .649 r
.24129 .60428 m .24231 .60435 L .24215 .60371 L F
.24129 .60428 m .24215 .60371 L .2414 .60396 L F
.962 .934 .618 r
.24352 .60031 m .24263 .60056 L .24342 .60113 L F
.24396 .59687 m .24299 .59956 L .24352 .60031 L F
.24299 .59956 m .24263 .60056 L .24352 .60031 L F
.596 .447 .649 r
.24261 .60063 m .24251 .60293 L .24299 .59956 L F
.24226 .60159 m .24251 .60293 L .24261 .60063 L F
.189 0 0 r
.2432 .60424 m .24247 .6036 L .24347 .60416 L F
.973 .848 .446 r
.24317 .59832 m .24147 .60099 L .24209 .60016 L F
.24267 .59911 m .24251 .60293 L .24232 .60083 L F
.24317 .59832 m .24299 .59956 L .24267 .59911 L F
.962 .934 .618 r
.24396 .59687 m .24209 .60016 L .24263 .60056 L F
.973 .848 .446 r
.24241 .59951 m .24232 .60083 L .24223 .5998 L F
.24299 .59956 m .24251 .60293 L .24267 .59911 L F
.962 .934 .618 r
.24397 .59686 m .24396 .59687 L .24342 .60113 L F
0 .258 .767 r
.24404 .60045 m .24427 .60295 L .24234 .60049 L F
.24227 .60019 m .24234 .60049 L .24209 .60016 L F
.24404 .60045 m .24234 .60049 L .24227 .60019 L F
.973 .848 .446 r
.24267 .59911 m .24237 .60059 L .24241 .59951 L F
.24237 .60059 m .24232 .60083 L .24234 .60049 L F
.24237 .60059 m .24234 .60049 L .24241 .59951 L F
.635 .553 .744 r
.24427 .60295 m .24347 .60416 L .24232 .60083 L F
.24234 .60049 m .24232 .60083 L .24209 .60016 L F
.24427 .60295 m .24232 .60083 L .24234 .60049 L F
0 .106 .64 r
.24209 .60016 m .24347 .60416 L .24296 .60383 L F
.973 .848 .446 r
.24223 .60022 m .2423 .60359 L .24147 .60099 L F
.189 0 0 r
.24244 .60358 m .24204 .60323 L .24257 .60358 L F
.596 .447 .649 r
.24226 .60159 m .2423 .60353 L .24251 .60293 L F
.2423 .60353 m .24231 .60435 L .24242 .60358 L F
.2423 .60353 m .24242 .60358 L .24251 .60293 L F
0 .106 .64 r
.24209 .60016 m .24296 .60383 L .24206 .60201 L F
.973 .848 .446 r
.24251 .60293 m .24241 .60362 L .24223 .5998 L F
.24241 .60362 m .24231 .60435 L .2423 .60379 L F
.24241 .60362 m .2423 .60379 L .24223 .5998 L F
.189 0 0 r
.24213 .60405 m .24065 .60501 L .24149 .60393 L F
.24247 .6036 m .24149 .60393 L .24204 .60323 L F
.973 .848 .446 r
.2423 .60359 m .2423 .60379 L .24212 .60359 L F
.2423 .60379 m .24231 .60435 L .2422 .60393 L F
.189 0 0 r
.24213 .60405 m .24149 .60393 L .24241 .60362 L F
.973 .848 .446 r
.2423 .60379 m .2422 .60393 L .24212 .60359 L F
.189 0 0 r
.2432 .60424 m .24221 .60393 L .24247 .6036 L F
.24213 .60405 m .24241 .60362 L .24247 .6036 L F
.973 .848 .446 r
.2423 .60359 m .24212 .60359 L .24147 .60099 L F
.189 0 0 r
.24247 .6036 m .24244 .60358 L .24296 .60383 L F
.24244 .60358 m .24257 .60358 L .24296 .60383 L F
.24247 .6036 m .24296 .60383 L .24347 .60416 L F
0 0 0 r
.2422 .60393 m .2432 .60424 L .24147 .60099 L F
.24231 .60435 m .2432 .60424 L .2422 .60393 L F
.189 0 0 r
.2432 .60424 m .24213 .60405 L .24221 .60393 L F
0 0 0 r
.24231 .60435 m .24065 .60501 L .2432 .60424 L F
.189 0 0 r
.2432 .60424 m .24169 .6047 L .24213 .60405 L F
.24169 .6047 m .24065 .60501 L .24213 .60405 L F
0 .258 .767 r
.24404 .60045 m .24227 .60019 L .24147 .60099 L F
.24227 .60019 m .24209 .60016 L .24147 .60099 L F
.973 .848 .446 r
.24223 .5998 m .24223 .60022 L .24147 .60099 L F
.596 .447 .649 r
.2414 .60396 m .24215 .60371 L .24188 .60263 L F
.376 0 0 r
.24149 .60393 m .24065 .60501 L .2404 .60404 L F
.596 .447 .649 r
.23839 .60406 m .23935 .60413 L .2404 .60404 L F
.376 0 0 r
.2404 .60404 m .2383 .60507 L .23839 .60406 L F
.596 .447 .649 r
.24116 .60427 m .24129 .60428 L .24179 .60269 L F
.891 .766 .717 r
.58966 .4407 m .59164 .44156 L .59047 .43782 L F
.96 .742 .565 r
.58994 .44355 m .59164 .44156 L .58966 .4407 L F
.58994 .44355 m .59139 .4443 L .59164 .44156 L F
.965 .64 .327 r
.23187 .60704 m .23037 .60613 L .23007 .60358 L F
.908 .517 .101 r
.23187 .60704 m .23137 .60888 L .23037 .60613 L F
.23187 .60704 m .2328 .6101 L .23137 .60888 L F
.018 0 0 r
.28181 .58261 m .28295 .58169 L .28535 .58078 L F
.97 .907 .556 r
.24464 .62375 m .24505 .61869 L .24292 .62017 L F
.038 0 0 r
.23267 .56645 m .23184 .56517 L .23331 .56404 L F
.23267 .56645 m .23055 .56747 L .23184 .56517 L F
.992 .85 .492 r
.36508 .63908 m .36558 .63666 L .36416 .63838 L F
.69 .951 .955 r
.36558 .63666 m .36879 .63503 L .36776 .6342 L F
.36558 .63666 m .36776 .6342 L .36504 .63743 L F
.72 .267 .176 r
.36416 .63838 m .36558 .63666 L .36504 .63743 L F
.459 .454 .765 r
.36385 .53489 m .36125 .53386 L .36347 .53233 L F
.36385 .53489 m .36125 .53386 L .36347 .53233 L F
.682 .745 .898 r
.58261 .37011 m .57863 .36919 L .58117 .36902 L F
.153 0 0 r
.58188 .36769 m .58245 .36775 L .58378 .36832 L F
.58245 .36775 m .58643 .36822 L .58378 .36832 L F
.668 .974 .886 r
.58536 .36806 m .58457 .36865 L .58378 .36832 L F
.58457 .36865 m .58261 .37011 L .58378 .36832 L F
.547 .843 .998 r
.58261 .37011 m .58117 .36902 L .58378 .36832 L F
.641 .524 .705 r
.48934 .48447 m .48943 .48709 L .49196 .48374 L F
0 0 .122 r
.70522 .3081 m .70534 .31031 L .70608 .30661 L F
.368 0 0 r
.34055 .51961 m .33882 .52141 L .33628 .52153 L F
.111 0 0 r
.34151 .52059 m .34055 .51961 L .342 .51782 L F
.34151 .52059 m .33882 .52141 L .34055 .51961 L F
.316 0 0 r
.3115 .54231 m .31413 .54204 L .31547 .54115 L F
.066 0 0 r
.31547 .54115 m .31651 .54136 L .31581 .5376 L F
.31547 .54115 m .31413 .54204 L .31651 .54136 L F
.906 .498 .19 r
.34996 .50197 m .35325 .50614 L .35305 .50387 L F
.382 .08 .324 r
.40767 .45441 m .40419 .45857 L .40594 .45586 L F
.065 0 0 r
.41079 .45343 m .40767 .45441 L .40594 .45586 L F
.859 .694 .677 r
.59142 .44701 m .59298 .44815 L .59139 .4443 L F
.811 .84 .872 r
.5882 .44967 m .59298 .44815 L .59142 .44701 L F
0 0 .044 r
.68231 .30092 m .68443 .2995 L .68497 .29755 L F
0 0 0 r
.68231 .30092 m .68112 .30196 L .68443 .2995 L F
.916 .948 .805 r
.38111 .61642 m .38406 .61261 L .38246 .6122 L F
.769 .874 .924 r
.36099 .64361 m .36118 .64172 L .35883 .6425 L F
.36099 .64361 m .36278 .64259 L .36118 .64172 L F
.788 .991 .884 r
.47373 .52458 m .47634 .52258 L .47674 .52226 L F
.594 .559 .785 r
.47634 .52258 m .48098 .52309 L .47674 .52226 L F
.47634 .52258 m .4807 .5258 L .48098 .52309 L F
.519 .042 .064 r
.27365 .64715 m .27722 .64684 L .27522 .6457 L F
.82 .628 .643 r
.27722 .64684 m .27365 .64715 L .27522 .6457 L F
.27722 .64684 m .27285 .6485 L .27365 .64715 L F
.726 .716 .841 r
.4362 .47738 m .43992 .47977 L .43766 .47619 L F
.76 .68 .774 r
.43766 .47619 m .43992 .47977 L .44164 .47778 L F
.884 .967 .644 r
.27306 .51757 m .27496 .5162 L .27089 .51543 L F
.27306 .51757 m .27284 .51987 L .27496 .5162 L F
.986 .88 .637 r
.60019 .36186 m .60154 .36331 L .60271 .35954 L F
.607 .215 .274 r
.62301 .37562 m .62665 .37514 L .62386 .37329 L F
.702 .969 .74 r
.63275 .41222 m .63564 .40949 L .63394 .41027 L F
.894 .935 .562 r
.63394 .41027 m .63256 .41485 L .63275 .41222 L F
.974 .846 .444 r
.39133 .5901 m .39063 .59322 L .39153 .5945 L F
.91 .725 .226 r
.39078 .59499 m .39153 .5945 L .39063 .59322 L F
.39078 .59499 m .39145 .59751 L .39153 .5945 L F
.276 0 0 r
.24255 .58787 m .23834 .58997 L .2403 .58849 L F
.067 0 0 r
.55232 .47238 m .55406 .47055 L .54979 .47273 L F
0 0 0 r
.55585 .46971 m .55406 .47055 L .55232 .47238 L F
.021 0 .373 r
.55548 .46706 m .55406 .47055 L .55585 .46971 L F
.672 .378 .466 r
.22763 .58372 m .23153 .58381 L .23107 .58061 L F
.674 .379 .465 r
.23107 .58061 m .23153 .58381 L .23419 .58373 L F
.709 .557 .679 r
.23708 .58439 m .23107 .58061 L .23419 .58373 L F
.887 .904 .835 r
.23063 .59931 m .23278 .60065 L .23458 .59713 L F
.636 .148 .075 r
.23158 .60252 m .23278 .60065 L .23063 .59931 L F
.23158 .60252 m .23422 .60276 L .23278 .60065 L F
.045 0 .205 r
.49072 .53907 m .48994 .54139 L .48841 .54222 L F
.003 0 .374 r
.48948 .54381 m .48841 .54222 L .48994 .54139 L F
.48948 .54381 m .48832 .54548 L .48841 .54222 L F
.146 0 .183 r
.52213 .41871 m .51923 .42194 L .52128 .42059 L F
.842 .816 .824 r
.51965 .4189 m .52213 .41871 L .52053 .41762 L F
.51965 .4189 m .51923 .42194 L .52213 .41871 L F
.488 .818 1 r
.52053 .41762 m .52213 .41871 L .52347 .41711 L F
.003 0 0 r
.52128 .42059 m .51923 .42194 L .51853 .42404 L F
.243 0 0 r
.40675 .48686 m .41128 .48487 L .40642 .48675 L F
.40675 .48686 m .40964 .48659 L .41128 .48487 L F
0 0 0 r
.41128 .48487 m .41155 .4846 L .41337 .48344 L F
.41128 .48487 m .40964 .48659 L .41155 .4846 L F
.711 .665 .803 r
.57009 .44066 m .57157 .44462 L .57419 .44187 L F
.544 .836 .505 r
.57419 .44187 m .57322 .44295 L .57424 .44172 L F
0 .088 .553 r
.57322 .44295 m .5783 .44707 L .57418 .44826 L F
0 0 .302 r
.57424 .44172 m .57322 .44295 L .57418 .44826 L F
.609 .534 .745 r
.49184 .46748 m .49394 .46427 L .49068 .46372 L F
.49184 .46748 m .49481 .46695 L .49394 .46427 L F
.689 .572 .718 r
.49203 .47023 m .49481 .46695 L .49184 .46748 L F
0 0 0 r
.65092 .32704 m .65299 .32647 L .65329 .32589 L F
.65092 .32704 m .64953 .32786 L .65299 .32647 L F
.926 .93 .79 r
.69272 .33089 m .68967 .33275 L .69146 .32945 L F
.69272 .33089 m .69057 .33412 L .68967 .33275 L F
0 .011 .55 r
.22723 .54578 m .22884 .54619 L .22864 .54399 L F
.22723 .54578 m .22803 .54837 L .22884 .54619 L F
.808 .847 .88 r
.54354 .41429 m .54049 .41694 L .54636 .41705 L F
.548 .784 .986 r
.54573 .41293 m .54476 .41501 L .54254 .41145 L F
.54573 .41293 m .54783 .41469 L .54476 .41501 L F
.641 .616 .809 r
.5479 .415 m .54476 .41501 L .54783 .41469 L F
.254 .111 .486 r
.54636 .41705 m .54573 .41293 L .54354 .41429 L F
.54636 .41705 m .54783 .41469 L .54573 .41293 L F
0 0 0 r
.5506 .41399 m .54846 .4167 L .5479 .415 L F
.54846 .4167 m .54765 .41773 L .54773 .41687 L F
.54846 .4167 m .54773 .41687 L .5479 .415 L F
.5506 .41399 m .54967 .41615 L .54765 .41773 L F
.563 .243 .384 r
.54473 .4186 m .54848 .41704 L .54699 .41704 L F
.54617 .41723 m .54699 .41704 L .54636 .41705 L F
.54473 .4186 m .54699 .41704 L .54617 .41723 L F
.254 .111 .486 r
.54636 .41705 m .54848 .41704 L .54783 .41469 L F
.979 .748 .519 r
.41441 .49208 m .41607 .49355 L .41473 .48972 L F
.707 .66 .802 r
.41189 .49532 m .41607 .49355 L .41441 .49208 L F
.41189 .49532 m .41609 .49619 L .41607 .49355 L F
.651 .619 .805 r
.41473 .48972 m .41607 .49355 L .41948 .49288 L F
.505 .301 .537 r
.41607 .49355 m .41898 .49551 L .41948 .49288 L F
.41607 .49355 m .41609 .49619 L .41898 .49551 L F
.654 .61 .793 r
.34058 .53411 m .34194 .53133 L .33971 .53214 L F
0 0 0 r
.70009 .35561 m .70057 .35339 L .70035 .35506 L F
.73 .752 .242 r
.70057 .35339 m .70177 .34882 L .70134 .35123 L F
0 0 0 r
.70035 .35506 m .70057 .35339 L .70134 .35123 L F
.421 .302 .612 r
.44585 .46358 m .44646 .46617 L .4437 .46436 L F
.44585 .46358 m .44646 .46617 L .4437 .46436 L F
.898 .808 .75 r
.61189 .42808 m .61461 .42818 L .6143 .42505 L F
.888 .837 .79 r
.61189 .42808 m .61255 .43132 L .61461 .42818 L F
.559 .801 .989 r
.62375 .36391 m .62268 .36644 L .62091 .36494 L F
0 0 .085 r
.62362 .36712 m .62268 .36644 L .62375 .36391 L F
.62362 .36712 m .62182 .36919 L .62268 .36644 L F
.919 .529 .141 r
.38839 .55844 m .38905 .56075 L .39054 .56186 L F
.951 .632 .39 r
.38886 .56342 m .39054 .56186 L .38905 .56075 L F
.38886 .56342 m .39081 .56445 L .39054 .56186 L F
.977 .684 .306 r
.5773 .45533 m .57651 .45123 L .57973 .45426 L F
.623 .167 .149 r
.57651 .45123 m .58289 .45384 L .57973 .45426 L F
.571 .13 .162 r
.35285 .52957 m .35115 .53145 L .35489 .53134 L F
.435 .169 .409 r
.35285 .52957 m .35489 .53134 L .35549 .52883 L F
.083 .273 .758 r
.3558 .53545 m .35733 .53335 L .35489 .53134 L F
.623 .943 .735 r
.3558 .53545 m .35552 .53498 L .35733 .53335 L F
.785 .854 .902 r
.47373 .52458 m .47674 .52226 L .47436 .52232 L F
.62 .162 .143 r
.25573 .58561 m .25917 .58656 L .25645 .58704 L F
.377 .06 .295 r
.25892 .58724 m .25733 .58689 L .25917 .58656 L F
0 0 0 r
.25885 .58815 m .25814 .5894 L .25892 .58724 L F
.25905 .58714 m .25892 .58724 L .25917 .58656 L F
.25885 .58815 m .25892 .58724 L .25905 .58714 L F
.62 .162 .143 r
.25573 .58561 m .25905 .58714 L .25917 .58656 L F
.179 .48 .896 r
.25638 .58379 m .25925 .587 L .25573 .58561 L F
.62 .162 .143 r
.25905 .58714 m .25961 .5874 L .25917 .58656 L F
.179 .48 .896 r
.25925 .587 m .2596 .58739 L .25906 .58714 L F
.25925 .587 m .25906 .58714 L .25573 .58561 L F
.2596 .58739 m .25957 .58738 L .25905 .58714 L F
.25906 .58714 m .25905 .58714 L .25573 .58561 L F
.2596 .58739 m .25905 .58714 L .25906 .58714 L F
0 0 .429 r
.25917 .58656 m .25961 .5874 L .26003 .5861 L F
.497 .643 .922 r
.26003 .5861 m .25961 .5874 L .25925 .587 L F
0 0 0 r
.26003 .5861 m .25956 .58664 L .25917 .58656 L F
.25971 .58667 m .25905 .58714 L .25917 .58656 L F
.497 .643 .922 r
.26003 .5861 m .25925 .587 L .25638 .58379 L F
0 0 0 r
.26003 .5861 m .25971 .58667 L .25956 .58664 L F
.25971 .58667 m .25885 .58815 L .25905 .58714 L F
.179 .48 .896 r
.2596 .58739 m .25961 .5874 L .25957 .58738 L F
.377 .06 .295 r
.25814 .5894 m .25645 .58704 L .25733 .58689 L F
.25814 .5894 m .25733 .58689 L .25892 .58724 L F
.718 .646 .776 r
.49716 .47443 m .49862 .46977 L .49593 .47092 L F
.49716 .47443 m .49997 .47381 L .49862 .46977 L F
.361 0 0 r
.3347 .49636 m .33696 .49725 L .33888 .4968 L F
.476 0 0 r
.33696 .49725 m .34123 .49731 L .33888 .4968 L F
.113 0 0 r
.68497 .29755 m .68745 .2966 L .68811 .29495 L F
.24 0 .004 r
.68745 .2966 m .69085 .29416 L .68811 .29495 L F
.634 .598 .796 r
.49862 .46977 m .49997 .47381 L .50211 .47114 L F
.646 .616 .805 r
.49997 .47381 m .50293 .47323 L .50211 .47114 L F
.702 .57 .703 r
.49997 .47381 m .5041 .47716 L .50293 .47323 L F
.49997 .47381 m .50112 .47745 L .5041 .47716 L F
.563 .213 .332 r
.58536 .36806 m .5878 .36851 L .58837 .36608 L F
.752 .397 .38 r
.58837 .36608 m .5878 .36851 L .59192 .3688 L F
.389 .843 .771 r
.55573 .38861 m .55733 .38764 L .5583 .38748 L F
.368 .8 .624 r
.55573 .38861 m .5551 .38894 L .55733 .38764 L F
.81 .815 .854 r
.44533 .58424 m .44289 .58778 L .44605 .58638 L F
0 0 0 r
.44266 .5901 m .44605 .58638 L .44289 .58778 L F
.44266 .5901 m .44555 .58736 L .44605 .58638 L F
.134 .362 .821 r
.44533 .58424 m .44605 .58638 L .44741 .58522 L F
0 0 0 r
.44605 .58638 m .44555 .58736 L .44741 .58522 L F
.752 .615 .707 r
.60229 .38305 m .59894 .38296 L .60166 .37936 L F
.056 .019 .494 r
.60429 .38391 m .60229 .38305 L .60482 .38234 L F
0 0 0 r
.22762 .57149 m .22768 .57235 L .22895 .57189 L F
.22762 .57149 m .22619 .57467 L .22768 .57235 L F
.755 .428 0 r
.57434 .37283 m .57385 .37206 L .57298 .36914 L F
0 0 .483 r
.57625 .37515 m .57385 .37206 L .57434 .37283 L F
.769 .683 .768 r
.32627 .6435 m .33039 .64324 L .32791 .64036 L F
.75 .513 .572 r
.33007 .64601 m .33039 .64324 L .32627 .6435 L F
.872 .434 .053 r
.32791 .64036 m .33039 .64324 L .32901 .64267 L F
.997 .778 .483 r
.32901 .64267 m .33039 .64324 L .33007 .64601 L F
.18 .574 .937 r
.52407 .43359 m .52243 .43456 L .52076 .4331 L F
0 0 .311 r
.52305 .43551 m .52243 .43456 L .52407 .43359 L F
.52305 .43551 m .52318 .43668 L .52243 .43456 L F
.025 .214 .72 r
.25356 .59596 m .25404 .5975 L .2531 .59771 L F
.443 .473 .796 r
.2556 .60056 m .2531 .59771 L .25404 .5975 L F
.576 .201 .294 r
.29714 .57375 m .29994 .57411 L .30143 .57142 L F
.668 .126 0 r
.30185 .57272 m .30143 .57142 L .29994 .57411 L F
.30185 .57272 m .30398 .57363 L .30143 .57142 L F
.731 .487 .558 r
.30143 .57142 m .30398 .57363 L .30495 .57268 L F
.773 .828 .895 r
.47724 .46464 m .48115 .46443 L .4797 .46344 L F
.677 .905 .976 r
.48115 .46443 m .48389 .46343 L .48206 .46223 L F
.656 .883 .981 r
.4797 .46344 m .48115 .46443 L .48206 .46223 L F
.495 .286 .526 r
.48512 .51308 m .48727 .51492 L .48707 .51241 L F
.48512 .51308 m .48493 .51626 L .48727 .51492 L F
.558 .933 .9 r
.29072 .65825 m .29579 .65666 L .2944 .65471 L F
.433 .642 .945 r
.2944 .65471 m .29579 .65666 L .29795 .65644 L F
0 0 .324 r
.22989 .6032 m .23158 .60252 L .23063 .59931 L F
.22989 .6032 m .23007 .60358 L .23158 .60252 L F
.632 .092 0 r
.5691 .45347 m .56626 .4512 L .56628 .45382 L F
.428 0 0 r
.44103 .58895 m .44266 .5901 L .44015 .58826 L F
.54 .232 .395 r
.44266 .5901 m .44289 .58778 L .44015 .58826 L F
.15 0 .327 r
.4972 .52556 m .49723 .52812 L .49487 .52917 L F
.177 0 .331 r
.49723 .52812 m .49443 .53157 L .49487 .52917 L F
.014 0 .362 r
.23534 .56033 m .23331 .56404 L .23367 .56189 L F
.957 .756 .591 r
.59953 .37794 m .60147 .3766 L .60015 .37542 L F
.59953 .37794 m .60166 .37936 L .60147 .3766 L F
.782 .474 .466 r
.60205 .37872 m .60574 .37733 L .60376 .37784 L F
.60574 .37733 m .6069 .37689 L .60376 .37784 L F
.46 .381 .681 r
.60147 .3766 m .60159 .3784 L .60376 .37784 L F
.60159 .3784 m .60166 .37936 L .60376 .37784 L F
.677 .544 .696 r
.37633 .60727 m .3739 .61014 L .3747 .60672 L F
.677 .207 .13 r
.3336 .57904 m .33158 .5801 L .32927 .57797 L F
.595 .239 .336 r
.33559 .57743 m .33158 .5801 L .3336 .57904 L F
.821 .954 .903 r
.58257 .35379 m .58352 .35046 L .58493 .35193 L F
.58257 .35379 m .58157 .35274 L .58352 .35046 L F
0 0 0 r
.24135 .5298 m .23979 .53151 L .24292 .52845 L F
.975 .737 .515 r
.43413 .56194 m .43237 .56356 L .4328 .56072 L F
.43413 .56194 m .43369 .56637 L .43237 .56356 L F
0 0 0 r
.23838 .53269 m .23723 .53475 L .23979 .53151 L F
.941 .725 .582 r
.33263 .52622 m .33121 .52847 L .32944 .52453 L F
.542 .878 .617 r
.51774 .43074 m .52057 .42833 L .51904 .4294 L F
.083 0 0 r
.52057 .42833 m .52174 .42868 L .51904 .4294 L F
.52057 .42833 m .52334 .42772 L .52174 .42868 L F
.805 .968 .658 r
.32502 .59927 m .32455 .60114 L .32685 .59777 L F
.753 .99 .886 r
.32502 .59927 m .32384 .60098 L .32455 .60114 L F
.97 .931 .649 r
.32035 .61529 m .31937 .61754 L .31864 .61567 L F
.395 0 0 r
.31864 .61567 m .32289 .61617 L .32035 .61529 L F
.044 .441 .874 r
.32487 .50901 m .33026 .51177 L .32502 .50764 L F
.948 .927 .748 r
.56525 .41054 m .56524 .41253 L .56388 .41443 L F
.701 .558 .69 r
.50112 .47745 m .50132 .48038 L .5041 .47716 L F
.56 .466 .705 r
.48694 .50685 m .49027 .50877 L .4896 .50607 L F
.48694 .50685 m .48789 .51023 L .49027 .50877 L F
.43 .211 .478 r
.37633 .60727 m .37642 .60978 L .3739 .61014 L F
.37633 .60727 m .37642 .60978 L .3739 .61014 L F
0 0 0 r
.67577 .3791 m .67887 .3768 L .67767 .37798 L F
.67887 .3768 m .68038 .37695 L .67767 .37798 L F
.67887 .3768 m .68149 .37596 L .68038 .37695 L F
.46397 .55575 m .46132 .55826 L .46359 .55634 L F
.344 .247 .599 r
.46132 .55826 m .463 .56076 L .46359 .55634 L F
.696 .902 .545 r
.63564 .40949 m .63816 .40606 L .63688 .40727 L F
0 0 0 r
.63948 .40392 m .63816 .40606 L .6402 .40225 L F
.664 .892 .542 r
.63688 .40727 m .63816 .40606 L .63948 .40392 L F
0 0 0 r
.53855 .4562 m .53751 .45755 L .5394 .45409 L F
.752 .381 .352 r
.53751 .45755 m .53962 .46035 L .54099 .46019 L F
.119 .22 .695 r
.53855 .4562 m .53962 .46035 L .53751 .45755 L F
.568 .197 .298 r
.62746 .34557 m .62373 .3476 L .62483 .34698 L F
.897 .633 .53 r
.43301 .55532 m .43293 .55802 L .43076 .55665 L F
.43076 .55665 m .43293 .55802 L .43301 .55532 L F
.755 .661 .758 r
.35975 .62632 m .35688 .62999 L .35722 .62709 L F
.499 .903 .8 r
.50302 .41173 m .50056 .41307 L .49877 .41356 L F
.863 .681 .151 r
.69928 .28903 m .69741 .2883 L .69655 .28889 L F
0 0 .256 r
.48042 .56828 m .4815 .56456 L .48132 .56669 L F
0 0 .163 r
.48098 .56933 m .48042 .56828 L .48132 .56669 L F
.48098 .56933 m .48048 .57118 L .48042 .56828 L F
.636 .863 .985 r
.56221 .41596 m .56317 .41347 L .56388 .41443 L F
.56221 .41596 m .56024 .41443 L .56317 .41347 L F
.795 .724 .786 r
.40863 .47043 m .4084 .47304 L .40951 .46937 L F
.57 .441 .665 r
.36508 .63908 m .36278 .64259 L .3645 .64075 L F
.676 .134 0 r
.58813 .42774 m .58973 .42806 L .58814 .42687 L F
.58813 .42774 m .5906 .42893 L .58973 .42806 L F
.481 .415 .706 r
.34316 .54868 m .3456 .54837 L .34505 .54434 L F
.562 .424 .651 r
.34361 .55032 m .3456 .54837 L .34316 .54868 L F
.529 .917 .8 r
.48575 .42491 m .48154 .42686 L .48467 .42432 L F
.813 1 .83 r
.48858 .42207 m .48575 .42491 L .4865 .42256 L F
.778 .981 .907 r
.4865 .42256 m .48575 .42491 L .48467 .42432 L F
.966 .711 .497 r
.54718 .47302 m .54642 .47019 L .54398 .47323 L F
.696 .34 .368 r
.54398 .47323 m .54652 .47585 L .54718 .47302 L F
.263 0 .238 r
.54718 .47302 m .54891 .47475 L .54979 .47273 L F
.54718 .47302 m .54652 .47585 L .54891 .47475 L F
.672 .976 .869 r
.5124 .40646 m .51402 .4044 L .51453 .40444 L F
.5124 .40646 m .51056 .40657 L .51402 .4044 L F
.468 .111 .276 r
.28172 .58621 m .27987 .58442 L .28181 .58261 L F
.28172 .58621 m .27857 .5871 L .27987 .58442 L F
.925 .756 .654 r
.34713 .51664 m .34718 .51951 L .3459 .51663 L F
.703 .579 .714 r
.34979 .5162 m .34718 .51951 L .34713 .51664 L F
.169 .355 .806 r
.3459 .51663 m .34718 .51951 L .34822 .51773 L F
.155 .135 .582 r
.34812 .52006 m .34822 .51773 L .34718 .51951 L F
.316 .133 .467 r
.35998 .57809 m .36196 .57798 L .3623 .57455 L F
.35998 .57809 m .36196 .57798 L .3623 .57455 L F
.348 0 0 r
.25483 .52097 m .25716 .5209 L .25849 .51901 L F
.196 0 0 r
.25716 .5209 m .26035 .51941 L .25849 .51901 L F
.822 .358 0 r
.59191 .39233 m .59151 .39347 L .59126 .39125 L F
.59191 .39233 m .59318 .39479 L .59151 .39347 L F
.704 .886 .964 r
.36414 .59661 m .36009 .59714 L .36273 .59401 L F
.554 .294 .476 r
.36758 .59495 m .36414 .59661 L .36273 .59401 L F
.36758 .59495 m .36673 .59705 L .36414 .59661 L F
.66 .97 .819 r
.31658 .53543 m .31741 .5339 L .31957 .53316 L F
0 0 0 r
.31581 .5376 m .31741 .5339 L .31658 .53543 L F
.85 .698 .693 r
.52369 .41197 m .52374 .41554 L .52653 .41508 L F
.63 .938 .706 r
.52653 .41508 m .52542 .41525 L .52721 .41527 L F
.52653 .41508 m .52347 .41711 L .52542 .41525 L F
.585 .393 .588 r
.50132 .48038 m .50425 .47994 L .5041 .47716 L F
.708 .615 .751 r
.50293 .47323 m .5041 .47716 L .50648 .4737 L F
.48 .318 .583 r
.5041 .47716 m .50658 .47646 L .50648 .4737 L F
.485 .318 .578 r
.5041 .47716 m .50673 .47915 L .50658 .47646 L F
.5041 .47716 m .50425 .47994 L .50673 .47915 L F
.199 0 0 r
.43297 .57818 m .4341 .5784 L .43085 .57767 L F
.515 .882 .977 r
.43588 .57704 m .4341 .5784 L .43297 .57818 L F
.295 .43 .828 r
.43698 .57922 m .4341 .5784 L .43588 .57704 L F
.72 .512 .608 r
.45393 .57148 m .45409 .57475 L .45064 .57469 L F
.134 .001 .42 r
.45568 .57348 m .45393 .57148 L .45509 .57139 L F
.45568 .57348 m .45409 .57475 L .45393 .57148 L F
.912 .916 .807 r
.60166 .37936 m .59753 .3819 L .59953 .37794 L F
.60166 .37936 m .59894 .38296 L .59753 .3819 L F
.861 .989 .725 r
.60166 .37936 m .59894 .38296 L .59973 .38022 L F
.431 .842 .661 r
.59973 .38022 m .60376 .37784 L .60166 .37936 L F
.89 .471 .185 r
.5992 .41531 m .59806 .41656 L .59812 .414 L F
.5992 .41531 m .59987 .41733 L .59806 .41656 L F
.799 .532 .534 r
.31748 .58448 m .31325 .58118 L .31489 .57978 L F
.31748 .58448 m .31349 .58406 L .31325 .58118 L F
.542 .35 .57 r
.32378 .56831 m .32651 .56778 L .32652 .56502 L F
.551 .349 .561 r
.32365 .57108 m .32651 .56778 L .32378 .56831 L F
.966 .697 .269 r
.59497 .39574 m .59411 .3969 L .59318 .39479 L F
.59497 .39574 m .59512 .39838 L .59411 .3969 L F
.636 .224 .245 r
.35156 .55528 m .34983 .5569 L .34668 .55631 L F
0 0 0 r
.42224 .51984 m .42194 .51969 L .42536 .52 L F
.42224 .51984 m .42075 .52189 L .42194 .51969 L F
.961 .652 .243 r
.57203 .46654 m .57287 .46673 L .57158 .46358 L F
0 0 .349 r
.5725 .46271 m .57203 .46654 L .57158 .46358 L F
.948 .953 .657 r
.57088 .46629 m .57203 .46654 L .5725 .46271 L F
.57032 .46754 m .57203 .46654 L .57088 .46629 L F
.961 .652 .243 r
.57203 .46654 m .57315 .46742 L .57287 .46673 L F
.383 .843 .888 r
.59821 .35188 m .59423 .35258 L .59552 .35269 L F
.328 .108 .42 r
.4918 .49647 m .49378 .49608 L .49419 .49353 L F
.049 0 .126 r
.5624 .40786 m .56314 .40565 L .56514 .40411 L F
.984 .716 .43 r
.43129 .53555 m .43095 .53858 L .43245 .53939 L F
0 .235 .693 r
.43095 .53858 m .43524 .54172 L .43245 .53939 L F
.474 .469 .772 r
.31212 .57805 m .31325 .58118 L .31489 .57978 L F
.936 .641 .458 r
.31325 .58118 m .31394 .58237 L .31489 .57978 L F
.31325 .58118 m .31349 .58406 L .31174 .58082 L F
.31325 .58118 m .31174 .58082 L .31394 .58237 L F
.908 .869 .789 r
.54398 .47323 m .5457 .47108 L .54439 .47137 L F
.716 .767 .892 r
.53985 .47323 m .54398 .47323 L .54267 .4714 L F
.53985 .47323 m .54398 .47323 L .54267 .4714 L F
.908 .869 .789 r
.54398 .47323 m .54501 .46846 L .54267 .4714 L F
0 0 .51 r
.54522 .47443 m .54398 .47323 L .54267 .4714 L F
.7 .246 .171 r
.54141 .47404 m .54522 .47443 L .54292 .47169 L F
.54249 .47178 m .54292 .47169 L .54267 .4714 L F
.54141 .47404 m .54292 .47169 L .54249 .47178 L F
.908 .869 .789 r
.54439 .47137 m .54642 .47019 L .54501 .46846 L F
.5457 .47108 m .54642 .47019 L .54439 .47137 L F
.7 .832 .946 r
.54501 .46846 m .54642 .47019 L .54831 .46886 L F
.222 0 0 r
.2471 .54322 m .2448 .54422 L .24427 .54041 L F
.2471 .54322 m .24317 .5455 L .2448 .54422 L F
.061 0 0 r
.2471 .54322 m .24242 .54767 L .24317 .5455 L F
.132 .53 .918 r
.24658 .54236 m .2471 .54322 L .24427 .54041 L F
.42 .825 .978 r
.24714 .54441 m .24774 .5451 L .2471 .54322 L F
.24722 .54648 m .24774 .5451 L .24714 .54441 L F
.602 .942 .937 r
.25027 .54586 m .25009 .54462 L .24774 .5451 L F
0 0 0 r
.25009 .54462 m .24793 .54532 L .24774 .5451 L F
.24793 .54532 m .24647 .5458 L .24774 .5451 L F
.24647 .5458 m .2471 .54322 L .24774 .5451 L F
0 .034 .6 r
.24427 .54041 m .2448 .54422 L .24252 .53847 L F
.856 .955 .875 r
.2471 .54322 m .24317 .5455 L .24658 .54236 L F
.039 0 0 r
.26841 .51568 m .26855 .5168 L .27089 .51543 L F
.26841 .51568 m .26609 .5176 L .26855 .5168 L F
.715 .666 .8 r
.33317 .51387 m .32831 .51266 L .33116 .51227 L F
.673 .742 .902 r
.62376 .39176 m .62818 .39278 L .62646 .38987 L F
.713 .668 .804 r
.62818 .39278 m .62915 .38769 L .62646 .38987 L F
.62818 .39278 m .63068 .39106 L .62915 .38769 L F
.155 0 0 r
.5402 .48716 m .53928 .48919 L .53669 .49012 L F
0 0 0 r
.5414 .48785 m .5402 .48716 L .54252 .486 L F
.5414 .48785 m .53928 .48919 L .5402 .48716 L F
.281 0 0 r
.34713 .51664 m .3459 .51663 L .34331 .51616 L F
.57 .504 .742 r
.32597 .56368 m .32488 .56103 L .32493 .56399 L F
.32652 .56502 m .32887 .56183 L .32488 .56103 L F
0 0 .198 r
.32552 .56214 m .32493 .56399 L .32488 .56103 L F
.657 .603 .782 r
.31826 .56425 m .32189 .56544 L .32059 .56339 L F
.647 .317 .399 r
.32327 .56221 m .32131 .56532 L .32216 .56522 L F
.139 0 0 r
.32297 .56552 m .32189 .56544 L .32493 .56399 L F
.265 .146 .525 r
.3239 .56429 m .32297 .56552 L .32493 .56399 L F
.32535 .56269 m .3239 .56429 L .32493 .56399 L F
.32552 .56214 m .32475 .56316 L .32535 .56269 L F
.32475 .56316 m .3239 .56429 L .32535 .56269 L F
.57 .504 .742 r
.32652 .56502 m .32597 .56368 L .32493 .56399 L F
.265 .146 .525 r
.32552 .56214 m .32553 .56485 L .32297 .56552 L F
.647 .317 .399 r
.32435 .56348 m .32216 .56522 L .32553 .56485 L F
.32327 .56221 m .32216 .56522 L .32435 .56348 L F
.57 .504 .742 r
.32652 .56502 m .32915 .56452 L .32887 .56183 L F
.479 .3 .56 r
.32652 .56502 m .329 .56729 L .32915 .56452 L F
.32652 .56502 m .32651 .56778 L .329 .56729 L F
.987 .877 .529 r
.70408 .34268 m .70474 .34043 L .70337 .34136 L F
.873 .922 .529 r
.70467 .33936 m .70474 .34043 L .70649 .33628 L F
.87 .96 .623 r
.70337 .34136 m .70474 .34043 L .70467 .33936 L F
0 0 0 r
.66917 .3151 m .668 .31625 L .67119 .31351 L F
.315 .799 .746 r
.2354 .53576 m .23621 .5352 L .23723 .53475 L F
.2354 .53576 m .23198 .53685 L .23523 .53558 L F
.275 .775 .756 r
.23273 .53629 m .23621 .5352 L .23198 .53685 L F
.516 .311 .541 r
.22968 .54043 m .23136 .54123 L .23266 .53653 L F
.23251 .53659 m .23266 .53653 L .23273 .53629 L F
.22968 .54043 m .23266 .53653 L .23251 .53659 L F
.315 .799 .746 r
.23614 .53524 m .23523 .53558 L .23621 .5352 L F
.2354 .53576 m .23523 .53558 L .23614 .53524 L F
.175 0 0 r
.24181 .59644 m .24397 .59686 L .24461 .5969 L F
.862 .674 .646 r
.42732 .53474 m .43135 .53249 L .42702 .53238 L F
.42732 .53474 m .43129 .53555 L .43135 .53249 L F
.197 .316 .76 r
.56014 .39508 m .56106 .39854 L .56279 .39695 L F
.113 0 .151 r
.56106 .39854 m .56291 .39961 L .56279 .39695 L F
.56106 .39854 m .56077 .40098 L .56291 .39961 L F
.253 .591 .948 r
.32481 .65656 m .32684 .65862 L .32874 .6586 L F
.587 .537 .766 r
.42956 .58751 m .42659 .58829 L .42551 .58425 L F
.554 .148 .226 r
.68741 .32072 m .68568 .3228 L .68326 .32144 L F
.822 .492 .431 r
.68897 .3234 m .68568 .3228 L .68741 .32072 L F
.997 .853 .532 r
.69057 .33412 m .68907 .33536 L .68967 .33275 L F
.69057 .33412 m .69002 .3367 L .68907 .33536 L F
.834 .997 .772 r
.63285 .35284 m .62956 .35568 L .63149 .35441 L F
0 0 0 r
.63285 .35284 m .63474 .35151 L .6358 .35051 L F
.63149 .35441 m .63474 .35151 L .63285 .35284 L F
.902 .738 .669 r
.4356 .46061 m .43504 .46396 L .43201 .4619 L F
.463 0 0 r
.43504 .46396 m .43405 .46352 L .43201 .4619 L F
0 .29 .789 r
.43201 .4619 m .43405 .46352 L .43323 .46237 L F
.902 .738 .669 r
.4356 .46061 m .43201 .4619 L .43294 .46057 L F
0 .29 .789 r
.43201 .4619 m .43323 .46237 L .43212 .46081 L F
.306 .071 .385 r
.43201 .4619 m .42915 .46104 L .42966 .46098 L F
.43201 .4619 m .42966 .46098 L .43294 .46057 L F
.43201 .4619 m .42893 .4633 L .42915 .46104 L F
.882 .933 .849 r
.25564 .62415 m .25529 .62688 L .25335 .62618 L F
.427 0 0 r
.25335 .62618 m .25529 .62688 L .25763 .62819 L F
.031 .501 .881 r
.25529 .62688 m .25834 .62804 L .25763 .62819 L F
.427 0 0 r
.25335 .62618 m .25763 .62819 L .25587 .62857 L F
.313 .797 .893 r
.25763 .62819 m .25808 .62752 L .2559 .62856 L F
.25763 .62819 m .2559 .62856 L .25587 .62857 L F
.031 .501 .881 r
.25834 .62804 m .25952 .62848 L .25763 .62819 L F
.581 .177 .241 r
.27044 .58715 m .26882 .58961 L .26658 .58773 L F
.568 .525 .767 r
.27192 .58338 m .27044 .58715 L .26959 .58403 L F
.27192 .58338 m .2731 .58711 L .27044 .58715 L F
.501 .101 .215 r
.2731 .58711 m .26882 .58961 L .27044 .58715 L F
.796 .894 .914 r
.40457 .46293 m .40934 .4617 L .40743 .45967 L F
.727 .758 .878 r
.40743 .45967 m .40934 .4617 L .41152 .4601 L F
0 .164 .644 r
.35139 .52302 m .35076 .52228 L .34812 .52006 L F
.786 .99 .887 r
.35201 .5208 m .35139 .52302 L .35363 .5217 L F
.35201 .5208 m .35076 .52228 L .35139 .52302 L F
.663 .954 .726 r
.6402 .40225 m .64332 .39948 L .64168 .40023 L F
0 0 0 r
.63948 .40392 m .6402 .40225 L .64168 .40023 L F
.723 .562 .671 r
.63376 .38591 m .63638 .3856 L .636 .38275 L F
.725 .627 .749 r
.63638 .3856 m .63909 .38234 L .636 .38275 L F
.513 .491 .769 r
.35175 .60647 m .34972 .60988 L .35319 .60728 L F
.582 .644 .877 r
.34972 .60988 m .35288 .6104 L .35319 .60728 L F
.168 .065 .484 r
.35319 .60728 m .35527 .60751 L .35474 .60648 L F
.559 .518 .766 r
.35527 .60751 m .35459 .60731 L .35474 .60648 L F
.009 0 .086 r
.35319 .60728 m .35474 .60648 L .35495 .60529 L F
.559 .518 .766 r
.35459 .60731 m .35175 .60647 L .35474 .60648 L F
.009 0 .086 r
.35495 .60529 m .35474 .60648 L .35583 .6043 L F
.168 .065 .484 r
.35319 .60728 m .35288 .6104 L .35527 .60751 L F
.649 .383 .502 r
.42483 .47961 m .43045 .48064 L .42903 .47687 L F
.371 .126 .407 r
.42903 .47687 m .43236 .47688 L .43192 .47395 L F
.436 .273 .56 r
.42903 .47687 m .4317 .47898 L .43236 .47688 L F
.42903 .47687 m .43045 .48064 L .4317 .47898 L F
.602 .296 .423 r
.33728 .63347 m .3405 .63572 L .33728 .63668 L F
.33728 .63347 m .34182 .63424 L .3405 .63572 L F
.72 .556 .667 r
.32294 .59771 m .32685 .59777 L .32669 .59469 L F
.641 .495 .669 r
.32669 .59469 m .32685 .59777 L .3294 .59426 L F
.813 .983 .889 r
.27306 .51757 m .2701 .52003 L .27284 .51987 L F
.768 .728 .815 r
.418 .4603 m .41562 .46353 L .41975 .46408 L F
.698 .696 .844 r
.418 .4603 m .41975 .46408 L .4223 .46307 L F
.793 .67 .728 r
.41245 .51004 m .41062 .51268 L .41295 .51237 L F
.624 .203 .224 r
.41062 .51268 m .41209 .5146 L .41295 .51237 L F
.447 .45 .769 r
.41295 .51237 m .41499 .50973 L .41245 .51004 L F
.41295 .51237 m .41575 .51204 L .41499 .50973 L F
.622 .344 .475 r
.41209 .5146 m .41575 .51204 L .41295 .51237 L F
.904 .942 .823 r
.7316 .29564 m .73371 .29295 L .73265 .29315 L F
.7316 .29564 m .73385 .29033 L .73133 .29324 L F
.567 0 0 r
.73133 .29324 m .73517 .29575 L .7316 .29564 L F
.667 .164 .04 r
.72996 .29448 m .7339 .29529 L .73149 .29338 L F
.7311 .29345 m .73149 .29338 L .73133 .29324 L F
.72996 .29448 m .73149 .29338 L .7311 .29345 L F
.904 .942 .823 r
.73265 .29315 m .73477 .2916 L .73385 .29033 L F
.73371 .29295 m .73477 .2916 L .73265 .29315 L F
.868 .888 .848 r
.42515 .47313 m .42231 .47273 L .42467 .47086 L F
.886 .519 .343 r
.42515 .47313 m .42353 .47521 L .42231 .47273 L F
.54 .851 .546 r
.42781 .47049 m .42515 .47313 L .42467 .47086 L F
.42781 .47049 m .42617 .47197 L .42515 .47313 L F
0 0 0 r
.42617 .47197 m .42353 .47521 L .42515 .47313 L F
.847 .751 .758 r
.47093 .54185 m .47288 .53857 L .47415 .54224 L F
.921 .924 .797 r
.4237 .51832 m .42224 .51984 L .42536 .52 L F
.959 .624 .249 r
.59522 .401 m .59658 .40223 L .59693 .40476 L F
.091 0 0 r
.3459 .51663 m .342 .51782 L .34331 .51616 L F
.934 .764 .648 r
.62052 .37857 m .62005 .38106 L .62202 .3797 L F
.62052 .37857 m .62091 .38027 L .62005 .38106 L F
.62052 .37857 m .61989 .38196 L .61863 .38161 L F
.62052 .37857 m .61905 .38175 L .62005 .38106 L F
.987 .776 .533 r
.62202 .3797 m .6214 .38239 L .62091 .38027 L F
.62202 .3797 m .62091 .38027 L .62052 .37857 L F
.881 .989 .732 r
.62298 .37603 m .62217 .37912 L .62063 .38042 L F
.61959 .38096 m .62063 .38042 L .61905 .38175 L F
.62298 .37603 m .62063 .38042 L .61959 .38096 L F
.62217 .37912 m .62202 .3797 L .62005 .38106 L F
.62217 .37912 m .62005 .38106 L .61905 .38175 L F
.934 .764 .648 r
.62005 .38106 m .6214 .38239 L .61989 .38196 L F
.62091 .38027 m .6214 .38239 L .62005 .38106 L F
.748 .665 .769 r
.62438 .37833 m .6214 .38239 L .62202 .3797 L F
.568 .402 .616 r
.50132 .48038 m .50426 .48232 L .50425 .47994 L F
.50132 .48038 m .5015 .48309 L .50426 .48232 L F
.583 .787 .976 r
.42252 .45152 m .42062 .45375 L .41887 .45266 L F
.42252 .45152 m .42408 .45357 L .42062 .45375 L F
.237 .063 .431 r
.35079 .61161 m .34972 .60988 L .35266 .61031 L F
.733 .988 .803 r
.35288 .6104 m .35225 .61076 L .3527 .61028 L F
.513 .491 .769 r
.35175 .60647 m .353 .60993 L .34972 .60988 L F
.353 .60993 m .35266 .61031 L .34972 .60988 L F
.559 .518 .766 r
.35527 .60751 m .353 .60993 L .35175 .60647 L F
.733 .988 .803 r
.353 .60993 m .35079 .61161 L .35464 .60809 L F
.35225 .61076 m .35217 .61081 L .353 .60993 L F
.35217 .61081 m .35079 .61161 L .353 .60993 L F
.35336 .60982 m .3527 .61028 L .35527 .60751 L F
.559 .518 .766 r
.35527 .60751 m .35316 .61038 L .353 .60993 L F
.237 .063 .431 r
.35079 .61161 m .35266 .61031 L .35316 .61038 L F
.733 .988 .803 r
.35288 .6104 m .3527 .61028 L .35336 .60982 L F
.35225 .61076 m .35464 .60809 L .35527 .60751 L F
.513 .491 .769 r
.353 .60993 m .35316 .61038 L .35266 .61031 L F
.237 .063 .431 r
.35079 .61161 m .34954 .61248 L .34972 .60988 L F
.742 .979 .741 r
.63394 .41027 m .63564 .40949 L .63688 .40727 L F
.401 .742 .993 r
.28303 .65452 m .28558 .65583 L .28749 .65538 L F
.724 .582 .695 r
.51311 .4223 m .51233 .42519 L .51645 .42432 L F
.514 .104 .201 r
.51241 .42661 m .51645 .42432 L .51233 .42519 L F
.51241 .42661 m .51514 .42672 L .51645 .42432 L F
.479 .893 .917 r
.51554 .42591 m .51514 .42672 L .51369 .4266 L F
.635 .792 .347 r
.51528 .42643 m .51514 .42672 L .5151 .42676 L F
.51645 .42432 m .51514 .42672 L .51528 .42643 L F
.51645 .42432 m .51528 .42643 L .51853 .42404 L F
.479 .893 .917 r
.51586 .42619 m .51514 .42672 L .51528 .42643 L F
.635 .792 .347 r
.51528 .42643 m .5151 .42676 L .51578 .42622 L F
.51528 .42643 m .51578 .42622 L .51853 .42404 L F
.77 .993 .786 r
.52 .42209 m .51853 .42404 L .5151 .42676 L F
0 0 0 r
.52 .42209 m .51572 .42616 L .5169 .42541 L F
.479 .893 .917 r
.5169 .42541 m .51586 .42619 L .51578 .42612 L F
0 0 0 r
.5151 .42676 m .51514 .42672 L .5169 .42541 L F
.51572 .42616 m .5151 .42676 L .5169 .42541 L F
.479 .893 .917 r
.5169 .42541 m .51578 .42612 L .51554 .42591 L F
.51586 .42619 m .51528 .42643 L .51554 .42591 L F
.793 .912 .921 r
.45319 .44176 m .45294 .44468 L .45187 .44355 L F
.45319 .44176 m .45469 .44286 L .45294 .44468 L F
.669 .901 .978 r
.44955 .44477 m .45187 .44355 L .45294 .44468 L F
.32 .117 .44 r
.40059 .4834 m .40245 .48523 L .40256 .48241 L F
.40059 .4834 m .40245 .48523 L .40256 .48241 L F
.537 .9 .968 r
.45458 .46822 m .45498 .46685 L .45284 .46626 L F
.45458 .46822 m .45749 .46719 L .45498 .46685 L F
.573 .003 0 r
.37129 .5029 m .37188 .50404 L .36874 .50305 L F
.37129 .5029 m .37415 .50513 L .37188 .50404 L F
.869 .993 .812 r
.38465 .60913 m .38729 .6077 L .38534 .6064 L F
.246 .626 .959 r
.32431 .64181 m .32627 .6435 L .32369 .64277 L F
.904 .512 .26 r
.411 .5941 m .40872 .59355 L .40784 .59086 L F
.626 .099 0 r
.41269 .59709 m .411 .5941 L .41376 .59442 L F
.41269 .59709 m .40872 .59355 L .411 .5941 L F
.958 .947 .665 r
.57152 .43421 m .57264 .4347 L .57092 .43807 L F
.985 .871 .64 r
.57299 .42998 m .57264 .4347 L .57152 .43421 L F
.732 .603 .713 r
.55603 .43718 m .55609 .43425 L .55478 .4345 L F
.243 .319 .743 r
.55533 .43481 m .55603 .43718 L .55478 .4345 L F
.732 .603 .713 r
.55603 .43718 m .55533 .43481 L .55609 .43425 L F
.243 .319 .743 r
.55548 .4349 m .55603 .43718 L .55533 .43481 L F
.55712 .4367 m .55603 .43718 L .55559 .43534 L F
.55606 .43553 m .55559 .43534 L .55548 .4349 L F
.55712 .4367 m .55559 .43534 L .55606 .43553 L F
.376 .211 .527 r
.55609 .43425 m .55606 .43553 L .55799 .43631 L F
.243 .319 .743 r
.55799 .43631 m .55712 .4367 L .55548 .4349 L F
0 0 0 r
.55599 .43784 m .55603 .43718 L .55799 .43631 L F
.376 .211 .527 r
.55606 .43553 m .55599 .43784 L .55799 .43631 L F
.732 .603 .713 r
.55603 .43718 m .55366 .436 L .55533 .43481 L F
.55366 .436 m .55322 .43578 L .55609 .43425 L F
.55603 .43718 m .55313 .43873 L .55322 .43578 L F
.139 0 0 r
.55599 .43784 m .55313 .43873 L .55603 .43718 L F
.51 .417 .686 r
.55322 .43578 m .55599 .43784 L .55606 .43553 L F
.55548 .4349 m .55606 .43553 L .55609 .43425 L F
.243 .319 .743 r
.55799 .43631 m .55548 .4349 L .55609 .43425 L F
.55548 .4349 m .55533 .43481 L .55609 .43425 L F
.51 .417 .686 r
.55529 .43468 m .55548 .4349 L .55609 .43425 L F
.55322 .43578 m .55606 .43553 L .55529 .43468 L F
.243 .319 .743 r
.55533 .43481 m .55478 .4345 L .55609 .43425 L F
.957 .637 .23 r
.24704 .56302 m .2471 .56509 L .24593 .56313 L F
0 .139 .659 r
.24785 .56296 m .24704 .56302 L .24593 .56313 L F
.662 .121 0 r
.24704 .56302 m .24948 .56508 L .25208 .56552 L F
.208 .714 .902 r
.24947 .5653 m .24899 .565 L .2471 .56509 L F
.25208 .56552 m .24948 .56508 L .24947 .5653 L F
.24948 .56508 m .24899 .565 L .24947 .5653 L F
0 .139 .659 r
.24785 .56296 m .24949 .56498 L .24704 .56302 L F
.662 .121 0 r
.24948 .56508 m .24978 .56534 L .25208 .56552 L F
0 .139 .659 r
.24949 .56498 m .24978 .56534 L .24948 .56508 L F
.24949 .56498 m .24948 .56508 L .24704 .56302 L F
.208 .714 .902 r
.25208 .56552 m .24991 .56503 L .24899 .565 L F
.778 .807 .876 r
.24991 .56503 m .24949 .56498 L .24785 .56296 L F
.208 .714 .902 r
.24991 .56503 m .24966 .56497 L .24949 .56498 L F
.24991 .56503 m .24949 .56498 L .24899 .565 L F
.778 .807 .876 r
.25064 .56327 m .24991 .56503 L .24785 .56296 L F
.24991 .56503 m .24978 .56534 L .24949 .56498 L F
.867 .917 .861 r
.25208 .56552 m .24978 .56534 L .24991 .56503 L F
.25208 .56552 m .24991 .56503 L .25064 .56327 L F
.208 .714 .902 r
.25208 .56552 m .2499 .56496 L .24966 .56497 L F
.926 .918 .535 r
.4029 .54533 m .40125 .54721 L .40142 .54438 L F
.4029 .54533 m .40168 .54766 L .40125 .54721 L F
0 0 0 r
.63448 .34408 m .63278 .34454 L .63016 .34502 L F
.63671 .34257 m .63278 .34454 L .63448 .34408 L F
.725 .627 .749 r
.63638 .3856 m .63985 .38574 L .63909 .38234 L F
.482 .466 .763 r
.63909 .38234 m .63985 .38574 L .64514 .38589 L F
0 0 0 r
.33801 .60801 m .33836 .60662 L .33818 .60773 L F
.33801 .60801 m .3362 .61038 L .33836 .60662 L F
.33962 .60535 m .33836 .60662 L .34182 .6044 L F
.355 .278 .63 r
.33962 .60535 m .34015 .6083 L .33801 .60801 L F
.33962 .60535 m .33801 .60801 L .33818 .60773 L F
0 0 0 r
.33962 .60535 m .33818 .60773 L .33836 .60662 L F
.511 .574 .856 r
.51904 .4294 m .51775 .43338 L .51774 .43074 L F
.535 .301 .506 r
.59701 .35472 m .59564 .35669 L .59298 .35667 L F
.59701 .35472 m .59564 .35669 L .59298 .35667 L F
.104 0 0 r
.67224 .38152 m .67577 .3791 L .67389 .38013 L F
.364 .799 .628 r
.67389 .38013 m .67577 .3791 L .67767 .37798 L F
.38 .054 .281 r
.35529 .51972 m .35363 .5217 L .35449 .52026 L F
.542 .616 .876 r
.64419 .38117 m .6432 .38407 L .64169 .38154 L F
.985 .736 .471 r
.33169 .60071 m .33001 .60034 L .32941 .59544 L F
.964 .766 .589 r
.33169 .60071 m .32903 .60255 L .33001 .60034 L F
.33169 .60071 m .33108 .60379 L .32903 .60255 L F
.581 .89 .989 r
.63325 .39345 m .63174 .39509 L .63098 .39484 L F
.63325 .39345 m .63405 .3943 L .63174 .39509 L F
.756 .468 0 r
.70013 .30434 m .70099 .30759 L .70028 .30458 L F
0 0 0 r
.47797 .57798 m .47782 .58002 L .47761 .58035 L F
0 0 .04 r
.47968 .57368 m .47914 .57614 L .47797 .57798 L F
0 0 .006 r
.47914 .57614 m .47782 .58002 L .47797 .57798 L F
.977 .676 .337 r
.62632 .35858 m .62796 .36066 L .62641 .36106 L F
.473 .885 .762 r
.62641 .36106 m .62796 .36066 L .63038 .35927 L F
.804 .7 .751 r
.70688 .30447 m .70312 .30376 L .70602 .29959 L F
.815 .641 .666 r
.70608 .30661 m .70312 .30376 L .70688 .30447 L F
.578 .94 .909 r
.47944 .42839 m .47691 .42974 L .47496 .42975 L F
.511 .574 .856 r
.51904 .4294 m .52076 .4331 L .51775 .43338 L F
.778 .567 .615 r
.317 .64301 m .31764 .64689 L .31506 .64519 L F
0 0 0 r
.4856 .55158 m .48532 .55373 L .48434 .55527 L F
0 0 .138 r
.48505 .55627 m .48434 .55527 L .48532 .55373 L F
.48505 .55627 m .48405 .558 L .48434 .55527 L F
.321 .069 .368 r
.60737 .37635 m .61016 .37561 L .61 .37294 L F
.392 .197 .493 r
.61 .37294 m .61243 .37239 L .61218 .36938 L F
.049 0 .322 r
.61 .37294 m .61162 .37381 L .61243 .37239 L F
.61 .37294 m .61016 .37561 L .61162 .37381 L F
.961 .642 .37 r
.40168 .54766 m .40452 .55213 L .40298 .55105 L F
.955 .61 .263 r
.40452 .55213 m .40498 .55457 L .40298 .55105 L F
.92 .975 .705 r
.47837 .52957 m .47642 .53292 L .47656 .53055 L F
.364 0 .191 r
.47656 .53055 m .48011 .52751 L .47837 .52957 L F
.873 .922 .529 r
.70467 .33936 m .70649 .33628 L .70581 .33554 L F
.878 .652 .593 r
.38205 .54451 m .38406 .54772 L .38414 .54537 L F
.267 .131 .503 r
.63742 .35087 m .63603 .35318 L .6358 .35051 L F
.277 0 0 r
.6358 .35051 m .63474 .35151 L .63742 .35087 L F
.296 .009 .295 r
.63742 .35087 m .63835 .34931 L .6358 .35051 L F
.58 .882 .588 r
.66604 .31795 m .66782 .31591 L .668 .31625 L F
0 0 0 r
.2649 .58568 m .2669 .58534 L .26959 .58403 L F
.054 0 0 r
.2669 .58534 m .27192 .58338 L .26959 .58403 L F
.744 .226 0 r
.38742 .51611 m .38549 .51506 L .3836 .5127 L F
.942 .648 .452 r
.38758 .51846 m .38549 .51506 L .38742 .51611 L F
.778 .995 .871 r
.51311 .4223 m .51492 .42089 L .51377 .42044 L F
.566 .93 .931 r
.51377 .42044 m .51492 .42089 L .51965 .4189 L F
.487 .237 .46 r
.3623 .57455 m .36494 .57395 L .36519 .57149 L F
.3623 .57455 m .36494 .57395 L .36519 .57149 L F
.5 .816 1 r
.36627 .59092 m .36946 .59102 L .36531 .59054 L F
.577 .576 .815 r
.36934 .59375 m .36531 .59054 L .36946 .59102 L F
.528 .271 .469 r
.36519 .57149 m .36756 .57361 L .36494 .57395 L F
.36519 .57149 m .36756 .57361 L .36494 .57395 L F
.644 .894 .984 r
.48206 .46223 m .48389 .46343 L .48649 .46219 L F
.582 .939 .795 r
.34366 .61113 m .34161 .61216 L .34535 .60981 L F
.73 .78 .892 r
.48915 .46029 m .49068 .46372 L .4926 .46063 L F
.598 .6 .824 r
.49068 .46372 m .49394 .46427 L .4926 .46063 L F
.902 .665 .571 r
.37662 .53212 m .37637 .53489 L .37861 .53555 L F
.896 .621 .512 r
.37637 .53489 m .37878 .53808 L .37861 .53555 L F
.736 .372 .361 r
.46914 .52076 m .4725 .5194 L .46793 .52043 L F
.485 .575 .87 r
.47674 .52226 m .47572 .52158 L .47436 .52232 L F
.47572 .52158 m .4725 .5194 L .47403 .52179 L F
.47572 .52158 m .47403 .52179 L .47436 .52232 L F
.857 .709 .697 r
.46888 .52393 m .47203 .52459 L .47338 .52188 L F
.47223 .52202 m .47338 .52188 L .47373 .52117 L F
.46888 .52393 m .47338 .52188 L .47223 .52202 L F
0 0 .569 r
.47373 .52117 m .47436 .52232 L .4725 .5194 L F
.736 .372 .361 r
.46914 .52076 m .47373 .52117 L .4725 .5194 L F
.287 .001 .292 r
.37409 .55447 m .3707 .55722 L .37191 .55525 L F
.37191 .55525 m .3707 .55722 L .37409 .55447 L F
0 0 0 r
.46359 .55634 m .46562 .55449 L .46397 .55575 L F
.707 .983 .89 r
.31842 .5394 m .31771 .54084 L .32137 .53935 L F
.624 .295 .393 r
.32218 .53768 m .31842 .5394 L .32137 .53935 L F
.277 0 0 r
.33738 .61702 m .33572 .61473 L .33784 .61427 L F
.38 .054 .281 r
.35529 .51972 m .35648 .52117 L .35363 .5217 L F
.609 .086 0 r
.36087 .52169 m .35648 .52117 L .35529 .51972 L F
.217 .075 .462 r
.61218 .36938 m .61471 .3706 L .61505 .3687 L F
.61218 .36938 m .61243 .37239 L .61471 .3706 L F
.403 0 0 r
.4414 .59662 m .43762 .59754 L .4384 .59667 L F
0 0 0 r
.69849 .36453 m .69891 .36292 L .69921 .36223 L F
.703 .39 .445 r
.42483 .47961 m .42914 .48228 L .43045 .48064 L F
.693 .913 .573 r
.43045 .48064 m .42914 .48228 L .4317 .47898 L F
.896 .935 .832 r
.4317 .47898 m .42914 .48228 L .43052 .48322 L F
.617 .937 .722 r
.64168 .40023 m .64332 .39948 L .64515 .39781 L F
.624 .763 .946 r
.59515 .36861 m .59586 .36974 L .59192 .3688 L F
.59192 .3688 m .59586 .36974 L .59515 .36861 L F
.992 .738 .395 r
.59586 .36974 m .59432 .37066 L .59515 .36861 L F
.69 .794 .929 r
.59515 .36861 m .59586 .36974 L .59824 .36803 L F
.83 .706 .726 r
.42147 .50858 m .41852 .51185 L .42542 .5119 L F
.815 .61 .625 r
.41876 .51456 m .42542 .5119 L .41852 .51185 L F
0 0 0 r
.42542 .5119 m .4255 .51179 L .42649 .50831 L F
0 0 .262 r
.73202 .32008 m .73115 .31707 L .73129 .31888 L F
.843 .482 0 r
.73197 .32151 m .73202 .32008 L .73129 .31888 L F
.73197 .32151 m .73301 .32311 L .73202 .32008 L F
.895 .494 .244 r
.36874 .52419 m .3702 .52311 L .36724 .521 L F
.36874 .52419 m .37085 .52519 L .3702 .52311 L F
.98 .881 .661 r
.51106 .42335 m .51233 .42519 L .51311 .4223 L F
.8 .996 .774 r
.51106 .42335 m .51311 .4223 L .51377 .42044 L F
.906 .975 .799 r
.36776 .6342 m .36879 .63503 L .37021 .63199 L F
0 0 0 r
.67582 .36335 m .67266 .36549 L .67438 .36331 L F
.482 .57 .868 r
.73206 .28652 m .72989 .29031 L .72871 .29037 L F
.73206 .28652 m .73385 .29033 L .72989 .29031 L F
.605 .451 .646 r
.48707 .51241 m .49027 .50877 L .48789 .51023 L F
.953 .7 .518 r
.2712 .64249 m .27365 .64715 L .27101 .64525 L F
.954 .685 .489 r
.27101 .64525 m .27365 .64715 L .27285 .6485 L F
.735 .665 .781 r
.2756 .64283 m .27365 .64715 L .2712 .64249 L F
.768 .983 .906 r
.52525 .41026 m .52962 .40858 L .52843 .40948 L F
.733 .289 .196 r
.52843 .40948 m .53093 .40944 L .52902 .40907 L F
.52843 .40948 m .52902 .40907 L .52678 .40864 L F
.971 .69 .281 r
.53093 .40944 m .52995 .40969 L .52874 .40929 L F
.52902 .40907 m .52874 .40929 L .52678 .40864 L F
0 0 0 r
.52843 .40948 m .529 .40909 L .53093 .40944 L F
.971 .69 .281 r
.53093 .40944 m .529 .40909 L .52902 .40907 L F
0 0 0 r
.529 .40909 m .53187 .40713 L .53093 .40944 L F
.971 .69 .281 r
.53093 .40944 m .52874 .40929 L .529 .40909 L F
0 0 0 r
.52843 .40948 m .52962 .40858 L .5298 .40847 L F
.52902 .40907 m .5298 .40847 L .53164 .40728 L F
.52843 .40948 m .5298 .40847 L .52902 .40907 L F
.52843 .40948 m .53164 .40728 L .53187 .40713 L F
.991 .734 .426 r
.40804 .58122 m .40655 .58298 L .40645 .58014 L F
.40804 .58122 m .40798 .58395 L .40655 .58298 L F
0 0 0 r
.52742 .43929 m .52644 .43936 L .52462 .44042 L F
.52742 .43929 m .52886 .43851 L .52644 .43936 L F
.851 .548 .476 r
.28836 .57788 m .29195 .578 L .29173 .58027 L F
.832 .999 .794 r
.38368 .48651 m .3801 .48943 L .38154 .4876 L F
.994 .863 .591 r
.38366 .48348 m .38368 .48651 L .38511 .48519 L F
.513 .89 .698 r
.38511 .48519 m .38368 .48651 L .38154 .4876 L F
.783 .98 .908 r
.38387 .48461 m .38511 .48519 L .38154 .4876 L F
.639 .1 0 r
.3866 .48697 m .38511 .48519 L .38387 .48461 L F
.38705 .48735 m .38511 .48519 L .3866 .48697 L F
.994 .863 .591 r
.38366 .48249 m .38366 .48348 L .38511 .48519 L F
.781 .664 .734 r
.36531 .59054 m .36758 .59495 L .36273 .59401 L F
.577 .576 .815 r
.36934 .59375 m .36758 .59495 L .36531 .59054 L F
.221 0 .3 r
.36934 .59375 m .36673 .59705 L .36758 .59495 L F
.553 .559 .814 r
.3303 .57364 m .33173 .57738 L .32927 .57797 L F
.378 .273 .608 r
.32927 .57797 m .33158 .5801 L .32957 .57899 L F
.097 .036 .492 r
.34609 .60721 m .34742 .60631 L .34722 .60349 L F
.863 .993 .822 r
.34535 .60981 m .34742 .60631 L .34609 .60721 L F
.992 .75 .388 r
.406 .5584 m .40488 .55733 L .40498 .55457 L F
.972 .761 .559 r
.406 .5584 m .40359 .56073 L .40488 .55733 L F
.406 .5584 m .40551 .56204 L .40359 .56073 L F
.6 .665 .885 r
.30868 .65679 m .31306 .65902 L .31061 .65644 L F
.556 .715 .946 r
.31061 .65644 m .31306 .65902 L .31543 .65833 L F
.665 .571 .74 r
.29544 .64258 m .29656 .64828 L .29306 .64636 L F
.916 .948 .805 r
.38111 .61642 m .38246 .6122 L .3803 .61608 L F
.258 0 .09 r
.24017 .55403 m .23761 .55715 L .23587 .55758 L F
.407 .487 .829 r
.2404 .55085 m .24204 .55466 L .24017 .55403 L F
.655 .313 .381 r
.24112 .55685 m .24017 .55403 L .24204 .55466 L F
.24112 .55685 m .23761 .55715 L .24017 .55403 L F
.344 .331 .701 r
.48098 .52309 m .4807 .5258 L .48239 .52489 L F
.058 0 .153 r
.48239 .52489 m .4807 .5258 L .48011 .52751 L F
.126 .252 .724 r
.33862 .61262 m .33784 .61427 L .3362 .61038 L F
.697 .934 .965 r
.3399 .61336 m .33784 .61427 L .33862 .61262 L F
.663 .513 .671 r
.33784 .61427 m .33738 .61702 L .3399 .61336 L F
.33784 .61427 m .33738 .61702 L .3399 .61336 L F
.677 .61 .773 r
.34174 .62504 m .34309 .6268 L .34276 .6244 L F
.852 .406 0 r
.34155 .62574 m .34309 .6268 L .34037 .62324 L F
.896 .758 .7 r
.34223 .62057 m .34309 .6268 L .34335 .6239 L F
.979 .836 .632 r
.34335 .6239 m .34309 .6268 L .34155 .62574 L F
.3437 .62382 m .34155 .62574 L .34465 .6236 L F
.34335 .6239 m .343 .62425 L .3437 .62382 L F
.343 .62425 m .34155 .62574 L .3437 .62382 L F
.677 .61 .773 r
.34037 .62324 m .34174 .62504 L .34223 .62057 L F
.34174 .62504 m .34276 .6244 L .34223 .62057 L F
.789 .916 .925 r
.34309 .6268 m .34332 .62662 L .34155 .62574 L F
.591 .408 .603 r
.4965 .49031 m .49952 .48986 L .49923 .48683 L F
.588 .465 .679 r
.49923 .48683 m .50248 .48643 L .5015 .48309 L F
.572 .393 .6 r
.49952 .48986 m .50248 .48643 L .49923 .48683 L F
.355 .061 .32 r
.52489 .49619 m .52697 .49815 L .52424 .49867 L F
.52489 .49619 m .52723 .49655 L .52697 .49815 L F
.481 .267 .512 r
.4239 .57775 m .42121 .581 L .42159 .57849 L F
.512 .832 1 r
.3786 .61217 m .37779 .61381 L .3761 .61281 L F
.506 .909 .819 r
.49073 .42087 m .48858 .42207 L .4865 .42256 L F
.484 .849 .604 r
.38571 .47783 m .38229 .48055 L .38402 .4791 L F
0 .061 .626 r
.38229 .48055 m .3841 .4825 L .38402 .4791 L F
.38229 .48055 m .38366 .48249 L .3841 .4825 L F
.06 0 0 r
.63272 .33706 m .6343 .33754 L .6353 .33602 L F
.63272 .33706 m .63163 .33843 L .6343 .33754 L F
.572 .848 .996 r
.531 .41542 m .52721 .41527 L .52983 .41421 L F
.389 .507 .857 r
.5324 .41311 m .531 .41542 L .52983 .41421 L F
.965 .766 .326 r
.45796 .58216 m .45881 .58023 L .455 .58158 L F
.45796 .58216 m .45859 .5838 L .45881 .58023 L F
.51 .506 .787 r
.45881 .58023 m .46 .57702 L .45726 .57734 L F
.45881 .58023 m .46135 .58026 L .46 .57702 L F
.492 .283 .524 r
.45859 .5838 m .46135 .58026 L .45881 .58023 L F
.847 .758 .764 r
.7165 .30365 m .71441 .30688 L .71775 .30782 L F
.742 .422 .44 r
.71378 .30924 m .71775 .30782 L .71441 .30688 L F
.71378 .30924 m .71765 .30996 L .71775 .30782 L F
.516 .232 .422 r
.71775 .30782 m .72104 .30786 L .72174 .30749 L F
.71775 .30782 m .71765 .30996 L .72104 .30786 L F
.096 0 .326 r
.32643 .49948 m .32786 .49931 L .3281 .49638 L F
.147 .275 .74 r
.32643 .49948 m .32855 .50109 L .32786 .49931 L F
0 .028 .599 r
.40657 .5649 m .40673 .56388 L .40551 .56204 L F
.978 .829 .426 r
.40691 .56766 m .40673 .56388 L .40657 .5649 L F
.909 .538 .314 r
.3836 .5127 m .38148 .51183 L .38112 .5096 L F
.822 .375 .172 r
.38549 .51506 m .38148 .51183 L .3836 .5127 L F
.671 .464 .597 r
.31453 .57732 m .31844 .57748 L .31826 .57477 L F
.576 .487 .717 r
.31844 .57748 m .32075 .57442 L .31826 .57477 L F
.683 .977 .89 r
.34264 .59684 m .33909 .59911 L .34096 .59832 L F
0 0 0 r
.37596 .62312 m .37923 .62031 L .37688 .62121 L F
.938 .965 .696 r
.37923 .62031 m .3803 .61608 L .37865 .61796 L F
.929 .966 .762 r
.37688 .62121 m .37923 .62031 L .37865 .61796 L F
.157 0 .186 r
.46697 .52224 m .46914 .52076 L .46793 .52043 L F
.937 .915 .769 r
.59701 .35472 m .59821 .35188 L .59976 .35672 L F
.206 .725 .87 r
.59976 .35672 m .59564 .35669 L .59701 .35472 L F
.59976 .35672 m .59884 .35641 L .59564 .35669 L F
.802 .479 .442 r
.59821 .35188 m .60254 .3556 L .59976 .35672 L F
.937 .915 .769 r
.59701 .35472 m .59564 .35669 L .59821 .35188 L F
.816 .923 .538 r
.59821 .35188 m .59564 .35669 L .59678 .3536 L F
.855 .478 .334 r
.59678 .3536 m .60035 .35591 L .59821 .35188 L F
.60035 .35591 m .60084 .35623 L .60064 .35589 L F
.60035 .35591 m .60064 .35589 L .59821 .35188 L F
.47 .813 .998 r
.60259 .35229 m .60144 .35155 L .59821 .35188 L F
.60144 .35155 m .60108 .35131 L .60062 .35141 L F
.60144 .35155 m .60062 .35141 L .59821 .35188 L F
.773 .919 .935 r
.60177 .35148 m .60259 .35229 L .60424 .35227 L F
.889 .698 .638 r
.60254 .3556 m .6018 .35161 L .60424 .35227 L F
.6018 .35161 m .60177 .35148 L .60266 .35177 L F
.6018 .35161 m .60266 .35177 L .60424 .35227 L F
.773 .919 .935 r
.60177 .35148 m .60108 .35131 L .60259 .35229 L F
.262 .77 .847 r
.60108 .35131 m .59955 .35128 L .59821 .35188 L F
.376 0 0 r
.60201 .35581 m .59884 .35641 L .59976 .35672 L F
.60196 .35581 m .59884 .35641 L .60201 .35581 L F
.60254 .3556 m .60147 .35583 L .60206 .35579 L F
.60147 .35583 m .59884 .35641 L .60206 .35579 L F
.60206 .35579 m .60196 .35581 L .60201 .35581 L F
.60254 .3556 m .60101 .35696 L .59884 .35641 L F
.802 .479 .442 r
.59821 .35188 m .60084 .35623 L .60254 .3556 L F
.972 .797 .607 r
.60177 .35148 m .60092 .3558 L .59955 .35128 L F
.60092 .3558 m .60084 .35623 L .60073 .3558 L F
.60092 .3558 m .60073 .3558 L .59955 .35128 L F
.712 .916 .964 r
.40537 .49362 m .40665 .49134 L .4073 .48924 L F
.40537 .49362 m .40381 .49204 L .40665 .49134 L F
.415 .538 .872 r
.40537 .49362 m .40665 .49134 L .40381 .49204 L F
.40537 .49362 m .40805 .49324 L .40665 .49134 L F
.504 .383 .648 r
.40537 .49362 m .4082 .49497 L .40805 .49324 L F
.40537 .49362 m .40535 .49597 L .4082 .49497 L F
.913 .516 .22 r
.36493 .51835 m .36724 .521 L .36673 .51978 L F
.683 .325 .362 r
.34332 .62662 m .34616 .62943 L .34144 .62892 L F
.051 0 0 r
.52519 .45165 m .52789 .45107 L .52895 .45042 L F
0 .54 .791 r
.52969 .45033 m .52895 .45042 L .52789 .45107 L F
.52969 .45033 m .53164 .45085 L .52895 .45042 L F
.079 0 .207 r
.32508 .58301 m .32326 .58445 L .3253 .58018 L F
.692 .642 .795 r
.41301 .46439 m .41284 .46662 L .41562 .46353 L F
.891 .687 .172 r
.67798 .35886 m .67846 .35983 L .67847 .36239 L F
.474 .469 .772 r
.31212 .57805 m .31489 .57978 L .31453 .57732 L F
.506 .901 .939 r
.46756 .45905 m .46629 .46038 L .46874 .45937 L F
.544 .92 .774 r
.46383 .46134 m .46629 .46038 L .46756 .45905 L F
0 0 .123 r
.48319 .56045 m .48276 .56301 L .4815 .56456 L F
0 0 .022 r
.48276 .56301 m .48132 .56669 L .4815 .56456 L F
0 .023 .592 r
.60534 .42488 m .60708 .42737 L .60678 .42513 L F
.993 .851 .593 r
.3922 .58305 m .39273 .58778 L .39341 .58443 L F
.787 .665 .729 r
.35183 .59053 m .35069 .5947 L .35267 .59424 L F
.719 .5 .592 r
.35 .59563 m .35267 .59424 L .35069 .5947 L F
.35 .59563 m .35249 .59644 L .35267 .59424 L F
.527 .497 .766 r
.35183 .59053 m .35267 .59424 L .35505 .59338 L F
0 0 .112 r
.35249 .59644 m .35505 .59338 L .35267 .59424 L F
.94 .715 .57 r
.40732 .57508 m .40462 .57639 L .40543 .57406 L F
.40732 .57508 m .40677 .57746 L .40462 .57639 L F
.776 .667 .743 r
.56514 .40411 m .56942 .40527 L .56677 .40839 L F
.553 .932 .888 r
.55628 .42619 m .56058 .42488 L .56035 .42651 L F
.892 .607 .097 r
.56058 .42488 m .56097 .42752 L .56035 .42651 L F
.188 .351 .796 r
.25029 .53873 m .25023 .54198 L .24824 .53899 L F
.25029 .53873 m .25154 .54176 L .25023 .54198 L F
.567 .559 .805 r
.25407 .54526 m .25371 .54495 L .25239 .54469 L F
.25371 .54495 m .25023 .54198 L .25239 .54469 L F
.163 .184 .636 r
.25154 .54176 m .25239 .54469 L .25023 .54198 L F
.522 .411 .668 r
.25468 .54359 m .25239 .54469 L .25154 .54176 L F
.554 .924 .934 r
.25099 .54442 m .25239 .54469 L .25468 .54359 L F
.25009 .54462 m .25239 .54469 L .25099 .54442 L F
0 0 0 r
.47642 .53292 m .47754 .53252 L .47656 .53055 L F
.47642 .53292 m .47495 .53484 L .47754 .53252 L F
.558 .015 0 r
.68326 .32144 m .68568 .3228 L .68341 .32224 L F
.708 .72 .859 r
.61487 .38248 m .61605 .38576 L .61345 .38656 L F
.674 .548 .704 r
.61605 .38576 m .61407 .38917 L .61345 .38656 L F
.392 .803 .979 r
.60846 .42861 m .61047 .42741 L .60708 .42737 L F
.60846 .42861 m .61189 .42808 L .61047 .42741 L F
.167 .062 .481 r
.2296 .58765 m .23153 .58381 L .22763 .58372 L F
.2296 .58765 m .23127 .58704 L .23153 .58381 L F
.554 .557 .812 r
.60841 .41451 m .60982 .41848 L .61187 .41753 L F
.60841 .41451 m .61187 .41753 L .61268 .41508 L F
.506 0 0 r
.60896 .41458 m .61077 .41521 L .60841 .41451 L F
0 .173 .693 r
.60984 .41656 m .60969 .41812 L .60841 .41451 L F
.76 .441 .446 r
.60484 .41724 m .6099 .41665 L .60841 .41451 L F
.713 .963 .942 r
.60766 .41623 m .6099 .41665 L .60625 .41705 L F
.885 .553 .414 r
.61077 .41521 m .60942 .41613 L .60889 .41546 L F
.60942 .41613 m .60937 .41613 L .60889 .41546 L F
.907 .982 .722 r
.60999 .41497 m .60941 .4161 L .60991 .4158 L F
.506 0 0 r
.60932 .41463 m .61077 .41521 L .60896 .41458 L F
.61219 .41502 m .61077 .41521 L .60932 .41463 L F
.597 .28 .403 r
.61319 .41604 m .613 .4163 L .61077 .41521 L F
.907 .982 .722 r
.61298 .41608 m .61077 .41521 L .613 .4163 L F
.506 0 0 r
.61268 .41508 m .61077 .41521 L .61219 .41502 L F
.597 .28 .403 r
.61563 .41275 m .61077 .41521 L .61268 .41508 L F
.61563 .41275 m .61319 .41604 L .61077 .41521 L F
.907 .982 .722 r
.6125 .41004 m .61077 .41521 L .61298 .41608 L F
.76 .441 .446 r
.60484 .41724 m .60841 .41451 L .60751 .41351 L F
.885 .553 .414 r
.61077 .41521 m .60751 .41351 L .60841 .41451 L F
.61077 .41521 m .60889 .41546 L .60751 .41351 L F
.167 .339 .792 r
.60751 .41351 m .60937 .41613 L .60813 .41107 L F
.713 .963 .942 r
.60908 .41538 m .6094 .41606 L .60766 .41623 L F
.823 .798 .828 r
.60908 .41492 m .60994 .41502 L .6125 .41004 L F
.60937 .41611 m .60941 .4161 L .6125 .41004 L F
.907 .982 .722 r
.6125 .41004 m .60999 .41497 L .61077 .41521 L F
.861 .959 .62 r
.61646 .40996 m .6135 .41537 L .61563 .41275 L F
.6135 .41537 m .613 .4163 L .61365 .41542 L F
.6135 .41537 m .61365 .41542 L .61563 .41275 L F
.822 .751 .786 r
.6125 .41004 m .61292 .41531 L .61646 .40996 L F
.61292 .41531 m .613 .4163 L .6135 .41537 L F
.61292 .41531 m .6135 .41537 L .61646 .40996 L F
.015 .584 .777 r
.60986 .41492 m .61314 .41526 L .61244 .41526 L F
.61088 .41508 m .61244 .41526 L .61201 .41526 L F
.60986 .41492 m .61244 .41526 L .61088 .41508 L F
.61314 .41526 m .61391 .41533 L .6133 .41531 L F
.61314 .41526 m .6133 .41531 L .61201 .41526 L F
.6103 .41506 m .61201 .41526 L .61077 .41521 L F
.60986 .41492 m .61201 .41526 L .6103 .41506 L F
.823 .798 .828 r
.60813 .41107 m .60908 .41492 L .6125 .41004 L F
.60908 .41492 m .60937 .41611 L .60994 .41502 L F
.713 .963 .942 r
.60937 .41611 m .60942 .41613 L .60937 .41613 L F
.60941 .4161 m .60942 .41613 L .60937 .41611 L F
.60989 .4161 m .6099 .41665 L .60766 .41623 L F
.885 .553 .414 r
.60942 .41613 m .60938 .41616 L .60937 .41613 L F
.823 .798 .828 r
.60937 .41611 m .60938 .41616 L .60941 .4161 L F
.713 .963 .942 r
.6094 .41606 m .60941 .4161 L .60937 .41611 L F
.6094 .41606 m .60937 .41613 L .60766 .41623 L F
.167 .339 .792 r
.60937 .41613 m .60938 .41616 L .60937 .41611 L F
.60937 .41613 m .60937 .41611 L .60813 .41107 L F
.907 .982 .722 r
.60941 .4161 m .60938 .41616 L .60942 .41613 L F
.60941 .4161 m .60942 .41613 L .60991 .4158 L F
.713 .963 .942 r
.60986 .41492 m .60989 .4161 L .60942 .41613 L F
.60986 .41492 m .60942 .41613 L .60908 .41538 L F
.907 .982 .722 r
.60999 .41497 m .60991 .4158 L .61077 .41521 L F
0 .173 .693 r
.6099 .41665 m .60982 .41848 L .60969 .41812 L F
.6099 .41665 m .60969 .41812 L .60984 .41656 L F
.606 .765 .956 r
.61187 .41753 m .60982 .41848 L .6099 .41665 L F
.98 .747 .514 r
.59693 .40476 m .59842 .40875 L .59674 .4075 L F
.947 .719 .56 r
.59842 .40875 m .59615 .41029 L .59674 .4075 L F
.59842 .40875 m .59815 .41138 L .59615 .41029 L F
.54 .851 .546 r
.42781 .47049 m .42467 .47086 L .4263 .46908 L F
.987 .727 .438 r
.4263 .46908 m .42617 .47197 L .42781 .47049 L F
.775 .977 .914 r
.46429 .43726 m .45985 .43905 L .46331 .43714 L F
.688 .96 .944 r
.46526 .43528 m .46766 .43536 L .46429 .43726 L F
.734 .991 .846 r
.46526 .43528 m .46429 .43726 L .46331 .43714 L F
.184 0 0 r
.58777 .35119 m .58973 .35103 L .59127 .35004 L F
.673 .945 .681 r
.59127 .35004 m .58973 .35103 L .59278 .34793 L F
.977 .854 .653 r
.39023 .57006 m .39255 .56847 L .39087 .5673 L F
.39023 .57006 m .39169 .5711 L .39255 .56847 L F
.748 .916 .948 r
.59973 .38022 m .59894 .38296 L .59753 .3819 L F
.896 .758 .7 r
.34223 .62057 m .34335 .6239 L .34531 .62085 L F
.296 .102 .44 r
.34531 .62085 m .34335 .6239 L .34728 .6223 L F
.817 .865 .882 r
.34174 .62417 m .34465 .6236 L .34155 .62574 L F
.34198 .62212 m .34426 .62339 L .34174 .62417 L F
.34426 .62339 m .34465 .6236 L .34174 .62417 L F
.158 .251 .711 r
.34574 .62293 m .34658 .62234 L .34728 .6223 L F
.34335 .6239 m .34468 .62325 L .34574 .62293 L F
.34468 .62325 m .34658 .62234 L .34574 .62293 L F
.34335 .6239 m .34465 .6236 L .34658 .62234 L F
.743 .281 .155 r
.5333 .41908 m .53596 .42012 L .53513 .41839 L F
.571 .901 .656 r
.5394 .45409 m .54268 .45132 L .54136 .45212 L F
.353 0 .215 r
.54191 .45494 m .5394 .45409 L .54136 .45212 L F
.54191 .45494 m .53855 .4562 L .5394 .45409 L F
.32 .283 .66 r
.33801 .60801 m .33862 .61262 L .3362 .61038 L F
.324 0 .226 r
.51902 .4999 m .51845 .50182 L .5159 .50254 L F
.353 .01 .236 r
.52096 .50107 m .51902 .4999 L .5216 .49922 L F
.52096 .50107 m .51845 .50182 L .51902 .4999 L F
0 0 0 r
.54086 .4445 m .53689 .4474 L .53993 .44694 L F
.157 0 .077 r
.54322 .44314 m .54086 .4445 L .53993 .44694 L F
.497 .197 .387 r
.49625 .4925 m .49952 .48986 L .4965 .49031 L F
.003 0 0 r
.60737 .37635 m .6069 .37689 L .61016 .37561 L F
.9 .56 .079 r
.51241 .42661 m .51233 .42519 L .51106 .42335 L F
0 0 0 r
.42504 .55326 m .4231 .55557 L .42439 .55371 L F
.663 .872 .496 r
.46803 .55091 m .4706 .5476 L .46834 .5511 L F
.46803 .55091 m .47031 .54768 L .4706 .5476 L F
.777 .819 .344 r
.47031 .54768 m .47096 .54558 L .4706 .5476 L F
.431 .803 .994 r
.30222 .65697 m .30234 .65531 L .30044 .65608 L F
.30222 .65697 m .30456 .65655 L .30234 .65531 L F
.238 0 0 r
.2556 .60056 m .25385 .60124 L .2518 .60084 L F
0 0 .441 r
.25703 .59669 m .25787 .59801 L .25622 .59907 L F
.25768 .59477 m .25787 .59801 L .25703 .59669 L F
.632 .139 .063 r
.25787 .59801 m .25967 .59973 L .25891 .59965 L F
.415 .855 .758 r
.25787 .59801 m .25716 .59836 L .25622 .59907 L F
.031 .296 .788 r
.25622 .59907 m .25522 .59982 L .25404 .5975 L F
.319 .319 .702 r
.25567 .59535 m .25622 .59907 L .25404 .5975 L F
0 0 .441 r
.25768 .59477 m .25622 .59907 L .25567 .59535 L F
.415 .855 .758 r
.25716 .59836 m .25523 .59933 L .25622 .59907 L F
.031 .296 .788 r
.25622 .59907 m .2556 .60056 L .25522 .59982 L F
.709 .975 .756 r
.25622 .59907 m .25385 .60124 L .2556 .60056 L F
.807 .79 .837 r
.25236 .59955 m .25385 .60124 L .25622 .59907 L F
.632 .139 .063 r
.25787 .59801 m .25891 .59965 L .25531 .59926 L F
.87 .484 .009 r
.31937 .61754 m .31887 .61816 L .31864 .61567 L F
.507 0 0 r
.53204 .39653 m .536 .39718 L .53329 .39586 L F
.438 .202 .457 r
.49419 .49353 m .49616 .49526 L .49625 .4925 L F
.49419 .49353 m .49378 .49608 L .49616 .49526 L F
0 0 0 r
.57268 .46175 m .57558 .45817 L .57431 .46019 L F
0 0 .045 r
.57158 .46358 m .57268 .46175 L .57431 .46019 L F
.094 0 .416 r
.49202 .53779 m .49072 .53907 L .49212 .53523 L F
0 0 .17 r
.49202 .53779 m .48994 .54139 L .49072 .53907 L F
.199 .728 .77 r
.33862 .61262 m .34161 .61216 L .3399 .61336 L F
.928 .944 .785 r
.61277 .38809 m .61407 .38917 L .61605 .38576 L F
.997 .778 .434 r
.61363 .39152 m .61407 .38917 L .61277 .38809 L F
.516 .221 .405 r
.43192 .47395 m .43236 .47688 L .43434 .47572 L F
.496 .23 .441 r
.43192 .47395 m .43434 .47572 L .43447 .47333 L F
0 .297 .656 r
.27285 .6485 m .27709 .65043 L .27592 .64987 L F
0 .437 .84 r
.27709 .65043 m .27686 .64951 L .27592 .64987 L F
.27709 .65043 m .27964 .65135 L .27686 .64951 L F
.9 .976 .808 r
.67961 .35004 m .67639 .35224 L .67855 .34876 L F
.853 .917 .874 r
.68148 .34547 m .6827 .34698 L .67961 .35004 L F
.914 .98 .755 r
.41022 .51065 m .41062 .51268 L .41245 .51004 L F
.62 .956 .814 r
.4134 .50846 m .41245 .51004 L .41499 .50973 L F
.4134 .50846 m .41022 .51065 L .41245 .51004 L F
.463 .823 .995 r
.43572 .58451 m .43407 .58373 L .43195 .58433 L F
.691 .346 .387 r
.43572 .58451 m .43845 .58699 L .43585 .58524 L F
.092 .302 .782 r
.43572 .58451 m .43709 .58333 L .43407 .58373 L F
.632 .368 .5 r
.43572 .58451 m .43879 .58432 L .43845 .58699 L F
.092 .302 .782 r
.43572 .58451 m .43845 .58699 L .43709 .58333 L F
.691 .346 .387 r
.43572 .58451 m .43845 .58699 L .43585 .58524 L F
.179 .48 .896 r
.25638 .58379 m .25573 .58561 L .25356 .58449 L F
.966 .785 .608 r
.55687 .40551 m .55479 .4066 L .55733 .40318 L F
.55687 .40551 m .55635 .40824 L .55479 .4066 L F
.585 .583 .816 r
.55036 .41172 m .5479 .415 L .54783 .41469 L F
.55036 .41172 m .5506 .41399 L .5479 .415 L F
.9 .986 .74 r
.26165 .62982 m .26373 .62729 L .26594 .62932 L F
.785 .673 .74 r
.26722 .63178 m .26371 .6348 L .26401 .63194 L F
0 0 0 r
.26387 .63383 m .26401 .63194 L .26371 .6348 L F
.648 .267 .309 r
.2642 .62952 m .26594 .62932 L .26401 .63194 L F
0 0 0 r
.26401 .63194 m .26594 .62932 L .26728 .62899 L F
.26401 .63194 m .26728 .62899 L .26722 .63178 L F
.26442 .63036 m .26401 .63194 L .26387 .63383 L F
.648 .267 .309 r
.26165 .62982 m .2642 .62952 L .26401 .63194 L F
.218 .521 .916 r
.26728 .62899 m .26594 .62932 L .26373 .62729 L F
.958 .642 .387 r
.38406 .54772 m .38474 .55086 L .38654 .55173 L F
.974 .671 .375 r
.38474 .55086 m .38649 .55442 L .38654 .55173 L F
0 0 0 r
.46812 .5935 m .47154 .59139 L .47061 .59333 L F
0 0 .031 r
.47154 .59139 m .47432 .5879 L .4734 .59015 L F
.009 0 .058 r
.47061 .59333 m .47154 .59139 L .4734 .59015 L F
.853 .816 .812 r
.40891 .50072 m .40429 .50559 L .40744 .50546 L F
.658 .171 .084 r
.40429 .50559 m .40621 .50718 L .40744 .50546 L F
0 0 .437 r
.40744 .50546 m .40916 .5044 L .40918 .50147 L F
0 0 0 r
.40744 .50546 m .40621 .50718 L .40916 .5044 L F
.755 .661 .758 r
.35975 .62632 m .36094 .63001 L .35688 .62999 L F
.73 .439 .486 r
.35688 .62999 m .36094 .63001 L .36053 .63265 L F
.479 .496 .798 r
.3631 .62933 m .36094 .63001 L .35975 .62632 L F
.329 .086 .385 r
.36053 .63265 m .36094 .63001 L .3631 .62933 L F
.967 .697 .47 r
.36094 .63001 m .36053 .63265 L .3631 .62933 L F
.672 .47 .604 r
.32887 .56183 m .33157 .56108 L .33149 .55775 L F
.472 .88 .946 r
.33149 .55775 m .33238 .55663 L .33389 .55689 L F
.554 .377 .596 r
.33149 .55775 m .33427 .56058 L .33238 .55663 L F
.33149 .55775 m .33157 .56108 L .33427 .56058 L F
.805 .968 .658 r
.32502 .59927 m .32685 .59777 L .32294 .59771 L F
.783 .683 .754 r
.73516 .30383 m .74054 .30141 L .73885 .29988 L F
.73516 .30383 m .73813 .30428 L .74054 .30141 L F
.993 .755 .394 r
.74054 .30141 m .73956 .29677 L .73885 .29988 L F
.47 .646 .935 r
.34964 .53281 m .35259 .53266 L .35115 .53145 L F
.245 .025 .368 r
.50004 .52227 m .4997 .52479 L .4972 .52556 L F
.038 0 .166 r
.4997 .52479 m .49723 .52812 L .4972 .52556 L F
.959 .762 .313 r
.4587 .56744 m .45912 .57115 L .45852 .57123 L F
.456 .885 .828 r
.68645 .37352 m .68819 .37334 L .69072 .37212 L F
.766 .705 .795 r
.2905 .50992 m .29057 .51146 L .29406 .50878 L F
.76 .466 .487 r
.42714 .53811 m .43129 .53555 L .42732 .53474 L F
.42714 .53811 m .43095 .53858 L .43129 .53555 L F
0 0 0 r
.39006 .48102 m .3924 .48012 L .38927 .48083 L F
.39006 .48102 m .38927 .48083 L .3873 .47949 L F
.88 .838 .799 r
.39417 .45784 m .39257 .45574 L .39424 .45725 L F
.39417 .45784 m .39002 .45939 L .39257 .45574 L F
.985 .772 .373 r
.39417 .45784 m .39291 .45944 L .39002 .45939 L F
.39417 .45784 m .39405 .46088 L .39291 .45944 L F
.63 .727 .917 r
.50293 .47323 m .50648 .4737 L .50544 .47182 L F
.596 .766 .961 r
.50648 .4737 m .50786 .47122 L .50544 .47182 L F
.50648 .4737 m .50921 .47302 L .50786 .47122 L F
.622 .471 .655 r
.50658 .47646 m .50921 .47302 L .50648 .4737 L F
.539 .859 .997 r
.54646 .45973 m .54625 .46067 L .54397 .46068 L F
0 0 0 r
.54646 .45973 m .54397 .46068 L .54213 .4617 L F
.54646 .45973 m .54213 .4617 L .54462 .46101 L F
.79 .967 .663 r
.54681 .45816 m .54646 .45973 L .54462 .46101 L F
.54752 .45723 m .54646 .45973 L .54681 .45816 L F
.539 .859 .997 r
.54646 .45973 m .54771 .46066 L .54625 .46067 L F
.422 .797 .993 r
.54992 .46019 m .54771 .46066 L .54646 .45973 L F
0 0 0 r
.55373 .47912 m .55198 .4802 L .55387 .47869 L F
.5506 .48166 m .55198 .4802 L .55373 .47912 L F
.556 .402 .627 r
.36273 .59401 m .36009 .59714 L .35996 .59461 L F
.404 .647 .956 r
.33397 .52154 m .33493 .51973 L .33202 .5202 L F
.33397 .52154 m .33628 .52153 L .33493 .51973 L F
.599 .714 .924 r
.54933 .39362 m .54995 .39554 L .54683 .39489 L F
.596 .078 0 r
.54995 .39554 m .55018 .39721 L .54683 .39489 L F
.399 .576 .91 r
.55167 .39342 m .54995 .39554 L .54933 .39362 L F
.161 0 0 r
.54579 .39317 m .54933 .39362 L .54683 .39489 L F
.54579 .39317 m .54791 .39351 L .54933 .39362 L F
.664 .367 .46 r
.54791 .39351 m .55181 .39081 L .54933 .39362 L F
.399 .576 .91 r
.55167 .39342 m .54933 .39362 L .55181 .39081 L F
.784 .848 .393 r
.54917 .39556 m .55167 .39342 L .54791 .39351 L F
0 0 .087 r
.55091 .39407 m .54995 .39554 L .55167 .39342 L F
.55091 .39407 m .55018 .39721 L .54995 .39554 L F
.84 .66 .659 r
.55386 .39747 m .55351 .40032 L .55141 .39517 L F
.784 .848 .393 r
.55018 .39718 m .55128 .39441 L .55091 .39407 L F
.55018 .39721 m .55157 .39366 L .55018 .39718 L F
.822 .674 .699 r
.55167 .39342 m .55386 .39747 L .55128 .39441 L F
.784 .848 .393 r
.55157 .39366 m .55167 .39342 L .55157 .39366 L F
.55157 .39366 m .55157 .39366 L .55018 .39718 L F
0 0 .087 r
.55094 .39402 m .55018 .39721 L .55091 .39407 L F
.784 .848 .393 r
.55018 .39721 m .55091 .39407 L .54917 .39556 L F
.082 .275 .76 r
.54683 .39489 m .55018 .39721 L .54791 .39351 L F
.784 .848 .393 r
.55128 .39441 m .55118 .39384 L .55091 .39407 L F
.84 .66 .659 r
.55128 .39441 m .55128 .39441 L .55094 .39402 L F
.55128 .39441 m .55141 .39517 L .55119 .39462 L F
.55128 .39441 m .55119 .39462 L .55094 .39402 L F
.784 .848 .393 r
.55018 .39721 m .5502 .39711 L .55119 .39462 L F
.55128 .39441 m .55167 .39342 L .55118 .39384 L F
0 0 .087 r
.55094 .39402 m .55091 .39407 L .55167 .39342 L F
.822 .674 .699 r
.55167 .39342 m .55128 .39441 L .55094 .39402 L F
.784 .848 .393 r
.55128 .39441 m .55119 .39462 L .55157 .39366 L F
.55018 .39721 m .55119 .39462 L .55128 .39441 L F
.55157 .39366 m .55041 .396 L .55167 .39342 L F
.769 .631 .708 r
.55094 .39402 m .55012 .39718 L .55018 .39721 L F
.972 .853 .664 r
.55018 .39721 m .54945 .39977 L .54803 .39844 L F
.769 .631 .708 r
.55012 .39718 m .54945 .39977 L .55018 .39721 L F
.972 .853 .664 r
.55018 .39721 m .54803 .39844 L .54957 .39686 L F
.55018 .39721 m .54957 .39686 L .55041 .396 L F
.769 .631 .708 r
.55094 .39402 m .55119 .39462 L .55004 .39751 L F
.784 .848 .393 r
.5502 .39711 m .55041 .396 L .55157 .39366 L F
.769 .631 .708 r
.55004 .39751 m .55141 .39517 L .54945 .39977 L F
.55119 .39462 m .55141 .39517 L .55004 .39751 L F
.55141 .39517 m .55351 .40032 L .5509 .39997 L F
.55141 .39517 m .5509 .39997 L .54945 .39977 L F
.84 .66 .659 r
.55386 .39747 m .55141 .39517 L .55128 .39441 L F
.558 .153 .231 r
.29855 .5779 m .30077 .57963 L .29759 .57952 L F
.554 .155 .24 r
.30161 .57806 m .30077 .57963 L .29855 .5779 L F
.605 .562 .78 r
.29774 .64215 m .29656 .64828 L .29544 .64258 L F
.127 0 0 r
.29656 .64828 m .29911 .64835 L .2975 .64851 L F
.29656 .64828 m .30023 .6482 L .29911 .64835 L F
.486 .273 .515 r
.36875 .54205 m .36874 .54493 L .36604 .54543 L F
.36875 .54205 m .36874 .54493 L .36604 .54543 L F
.915 .805 .724 r
.43649 .59417 m .43372 .59548 L .43586 .59284 L F
.446 0 .047 r
.5674 .42858 m .57125 .42782 L .56992 .42962 L F
.854 .466 .309 r
.57125 .42782 m .57299 .42998 L .56992 .42962 L F
.689 .572 .718 r
.49203 .47023 m .49593 .47092 L .49481 .46695 L F
.148 0 0 r
.32154 .56151 m .32327 .56221 L .32488 .56103 L F
.32154 .56151 m .32059 .56339 L .32327 .56221 L F
.621 .655 .862 r
.7041 .29416 m .70278 .29572 L .70089 .29376 L F
.831 .995 .851 r
.34223 .62057 m .34541 .61813 L .34276 .61876 L F
.789 .625 .677 r
.34223 .62057 m .34531 .62085 L .34541 .61813 L F
.715 .669 .804 r
.62915 .38769 m .63068 .39106 L .63344 .38864 L F
.124 0 .381 r
.37059 .62995 m .37321 .62608 L .37247 .62879 L F
.277 0 0 r
.33707 .61697 m .33701 .61702 L .33342 .61641 L F
0 0 .166 r
.33833 .61529 m .33701 .61702 L .33862 .61262 L F
.33833 .61529 m .33701 .61702 L .33862 .61262 L F
.577 .83 .464 r
.33673 .6173 m .33701 .61702 L .33833 .61529 L F
.653 .192 .146 r
.33342 .61641 m .33701 .61702 L .33571 .61859 L F
.577 .83 .464 r
.33571 .61859 m .33701 .61702 L .33673 .6173 L F
.277 0 0 r
.33738 .61702 m .33701 .61702 L .33707 .61697 L F
0 0 .331 r
.33738 .61702 m .33833 .61529 L .33701 .61702 L F
.33738 .61702 m .33836 .61815 L .33833 .61529 L F
.33738 .61702 m .33788 .61995 L .33836 .61815 L F
.51 .417 .686 r
.55322 .43578 m .55313 .43873 L .55599 .43784 L F
.308 .778 .663 r
.34203 .60424 m .34182 .6044 L .34381 .60297 L F
.34203 .60424 m .33962 .60535 L .34182 .6044 L F
.595 .239 .336 r
.33559 .57743 m .33382 .58029 L .33158 .5801 L F
.612 .582 .796 r
.33477 .57464 m .33559 .57743 L .33896 .57451 L F
.522 .751 .979 r
.33477 .57464 m .33896 .57451 L .33698 .57367 L F
.475 .504 .808 r
.33698 .57367 m .33559 .57743 L .3328 .57713 L F
.33698 .57367 m .33794 .5771 L .33559 .57743 L F
.6 .245 .339 r
.33787 .57988 m .33559 .57743 L .33794 .5771 L F
.33787 .57988 m .33382 .58029 L .33559 .57743 L F
.091 0 0 r
.3459 .51663 m .34415 .51796 L .342 .51782 L F
.106 0 .101 r
.34415 .51796 m .34151 .52059 L .342 .51782 L F
.776 .6 .661 r
.2663 .58958 m .2649 .58568 L .26658 .58773 L F
.558 .189 .298 r
.26658 .58773 m .26882 .58961 L .2663 .58958 L F
.142 .267 .733 r
.61731 .38989 m .61961 .39085 L .62067 .38967 L F
.42 .825 .978 r
.24722 .54648 m .25027 .54586 L .24774 .5451 L F
.259 .767 .858 r
.55768 .46308 m .55439 .46327 L .55783 .4632 L F
0 0 0 r
.5599 .46195 m .55768 .46308 L .55783 .4632 L F
.5599 .46195 m .56084 .46034 L .55768 .46308 L F
.3123 .62915 m .31003 .63043 L .30904 .63109 L F
.381 .673 .974 r
.42587 .45284 m .42408 .45357 L .42252 .45152 L F
.446 .869 .744 r
.66991 .32505 m .67366 .32328 L .67292 .32388 L F
0 0 0 r
.67661 .32222 m .67538 .32295 L .67366 .32328 L F
.235 0 0 r
.67538 .32295 m .67292 .32388 L .67366 .32328 L F
0 0 0 r
.35583 .6043 m .35474 .60648 L .35656 .6033 L F
.698 .696 .844 r
.418 .4603 m .4223 .46307 L .42077 .45968 L F
.671 .725 .89 r
.42077 .45968 m .4223 .46307 L .42472 .46053 L F
.705 .594 .728 r
.44165 .58063 m .44361 .58612 L .43879 .58432 L F
.849 .785 .788 r
.44361 .58612 m .43949 .58682 L .43879 .58432 L F
.43949 .58682 m .43845 .58699 L .43846 .58689 L F
.43949 .58682 m .43846 .58689 L .43879 .58432 L F
.44361 .58612 m .44113 .58421 L .43845 .58699 L F
.44361 .58612 m .44289 .58778 L .44113 .58421 L F
.605 .538 .753 r
.44533 .58424 m .44361 .58612 L .44165 .58063 L F
.776 .759 .838 r
.44113 .58421 m .44231 .58662 L .44533 .58424 L F
.44231 .58662 m .44289 .58778 L .44377 .58651 L F
.44231 .58662 m .44377 .58651 L .44533 .58424 L F
.51 .329 .571 r
.42121 .581 m .42121 .58386 L .41868 .58436 L F
.703 .747 .886 r
.60964 .40475 m .61369 .40527 L .6122 .4034 L F
.757 .464 .487 r
.61357 .40741 m .61369 .40527 L .60964 .40475 L F
.793 .916 .922 r
.61369 .40527 m .61551 .40184 L .6122 .4034 L F
.61369 .40527 m .61693 .40303 L .61551 .40184 L F
.574 .307 .474 r
.61357 .40741 m .61648 .40733 L .61369 .40527 L F
.472 .32 .593 r
.4925 .50464 m .49495 .50156 L .49241 .50264 L F
.696 .982 .827 r
.55095 .43051 m .55224 .42845 L .55001 .43018 L F
.55095 .43051 m .5541 .42805 L .55224 .42845 L F
0 0 0 r
.4877 .54761 m .48688 .54996 L .4856 .55158 L F
.48688 .54996 m .48532 .55373 L .4856 .55158 L F
.748 .252 .052 r
.59161 .35303 m .58777 .35119 L .58938 .35442 L F
.78 .854 .905 r
.39691 .4548 m .39424 .45725 L .39257 .45574 L F
.816 .644 .669 r
.60622 .35631 m .60254 .3556 L .60424 .35227 L F
.256 0 0 r
.60622 .35631 m .60508 .35631 L .60254 .3556 L F
.695 .951 .679 r
.60848 .35394 m .60622 .35631 L .60424 .35227 L F
.60848 .35394 m .60746 .35434 L .60622 .35631 L F
.709 .98 .783 r
.60746 .35434 m .60508 .35631 L .60622 .35631 L F
.701 .946 .958 r
.30663 .57168 m .30398 .57363 L .30185 .57272 L F
.506 .422 .695 r
.30663 .57168 m .30676 .5738 L .30398 .57363 L F
.419 .228 .513 r
.30633 .57644 m .30398 .57363 L .30676 .5738 L F
.30633 .57644 m .30417 .57712 L .30398 .57363 L F
.75 .502 .557 r
.57407 .45375 m .57633 .45652 L .57558 .45817 L F
.57407 .45375 m .5773 .45533 L .57633 .45652 L F
.716 .973 .926 r
.63929 .34119 m .64341 .33996 L .64215 .34025 L F
.211 0 0 r
.64604 .33895 m .64215 .34025 L .64341 .33996 L F
.548 .565 .823 r
.61863 .401 m .6204 .40511 L .62306 .40383 L F
.654 .61 .793 r
.34058 .53411 m .34331 .53528 L .34194 .53133 L F
.286 0 .092 r
.34058 .53411 m .34072 .53639 L .34331 .53528 L F
.34058 .53411 m .33833 .5371 L .34072 .53639 L F
.755 .563 .637 r
.62915 .38769 m .63344 .38864 L .63376 .38591 L F
.863 .861 .836 r
.36118 .64172 m .36508 .63908 L .36416 .63838 L F
.595 .51 .728 r
.40535 .49597 m .40941 .49857 L .4082 .49497 L F
.40535 .49597 m .40677 .49948 L .40941 .49857 L F
.099 0 0 r
.33135 .6553 m .33288 .65532 L .33524 .65555 L F
0 0 0 r
.54683 .39489 m .54562 .39692 L .54404 .39853 L F
.082 .275 .76 r
.54683 .39489 m .54803 .39584 L .54562 .39692 L F
.54683 .39489 m .54791 .39351 L .54803 .39584 L F
.776 .667 .743 r
.56514 .40411 m .56677 .40839 L .56827 .40668 L F
.672 .222 0 r
.60308 .42186 m .59987 .41733 L .60395 .42043 L F
.661 .949 .954 r
.60091 .34606 m .59702 .34722 L .59945 .34617 L F
.56 .077 .067 r
.59945 .34617 m .6035 .34592 L .60091 .34606 L F
.907 .92 .816 r
.25064 .56327 m .2499 .56496 L .25208 .56552 L F
.938 .576 .294 r
.37878 .53808 m .37977 .54159 L .38171 .54254 L F
.925 .541 .24 r
.38021 .54341 m .38171 .54254 L .37977 .54159 L F
.38021 .54341 m .38205 .54451 L .38171 .54254 L F
.63 .727 .917 r
.50293 .47323 m .50544 .47182 L .50211 .47114 L F
.597 .826 .987 r
.35178 .5772 m .34962 .57826 L .34754 .57666 L F
.512 .297 .525 r
.36196 .57798 m .36494 .57395 L .3623 .57455 L F
.315 .132 .466 r
.36317 .57565 m .3623 .57455 L .36494 .57395 L F
.36317 .57565 m .36196 .57798 L .3623 .57455 L F
.939 .65 .467 r
.42231 .53125 m .42463 .53532 L .42467 .53259 L F
.681 .523 .665 r
.42467 .53259 m .42463 .53532 L .42702 .53238 L F
.235 0 .018 r
.58289 .45384 m .58635 .45098 L .58504 .45231 L F
.737 .958 .943 r
.58711 .44878 m .58635 .45098 L .5882 .44967 L F
.786 .92 .54 r
.58504 .45231 m .58635 .45098 L .58711 .44878 L F
.035 0 0 r
.54202 .43478 m .54467 .43401 L .54322 .43525 L F
.54202 .43478 m .54322 .43525 L .5406 .43333 L F
.955 .772 .615 r
.58967 .44524 m .59139 .4443 L .58994 .44355 L F
.58967 .44524 m .59142 .44701 L .59139 .4443 L F
.741 .871 .94 r
.45182 .58388 m .44997 .58549 L .44809 .58343 L F
.624 .297 .396 r
.44812 .58277 m .45009 .58155 L .44825 .58017 L F
.44809 .58343 m .44888 .58268 L .44812 .58277 L F
.44888 .58268 m .45009 .58155 L .44812 .58277 L F
.414 .357 .686 r
.45036 .58003 m .45009 .58155 L .44825 .58017 L F
.936 .863 .742 r
.45036 .58003 m .45009 .58155 L .44888 .58268 L F
.44862 .58264 m .44888 .58268 L .44809 .58343 L F
.45036 .58003 m .44888 .58268 L .44862 .58264 L F
.864 .724 .706 r
.45036 .58003 m .45146 .58274 L .44862 .58264 L F
.399 .832 .953 r
.44707 .58235 m .45062 .58249 L .45037 .58193 L F
.605 .538 .753 r
.44533 .58424 m .44165 .58063 L .44391 .58379 L F
.927 .937 .789 r
.44792 .58044 m .44533 .58424 L .44391 .58379 L F
.44825 .58017 m .44803 .58048 L .44792 .58044 L F
.44803 .58048 m .44533 .58424 L .44792 .58044 L F
.44825 .58017 m .44391 .58379 L .44625 .57943 L F
.658 .181 0 r
.44215 .58184 m .44391 .58379 L .44165 .58063 L F
.893 .82 .768 r
.44625 .57943 m .44391 .58379 L .44215 .58184 L F
.44625 .57943 m .44215 .58184 L .44634 .58245 L F
.44625 .57943 m .44626 .57992 L .44473 .57867 L F
.44626 .57992 m .44634 .58245 L .44511 .57956 L F
.44626 .57992 m .44511 .57956 L .44473 .57867 L F
.399 .832 .953 r
.44634 .58245 m .44766 .58246 L .44707 .58235 L F
.44766 .58246 m .45062 .58249 L .44707 .58235 L F
.864 .724 .706 r
.44862 .58264 m .45193 .5839 L .44809 .58343 L F
.45146 .58274 m .45193 .5839 L .44862 .58264 L F
.005 0 0 r
.455 .58158 m .45193 .5839 L .45426 .5822 L F
.642 .622 .814 r
.45426 .5822 m .45193 .5839 L .45036 .58003 L F
.399 .832 .953 r
.45062 .58249 m .45192 .58251 L .4516 .58239 L F
.45062 .58249 m .4516 .58239 L .45037 .58193 L F
.056 0 .366 r
.44809 .58343 m .44949 .58492 L .45192 .58251 L F
.747 .973 .926 r
.45037 .58193 m .45192 .58251 L .45096 .58089 L F
.802 .828 .871 r
.44809 .58343 m .45192 .58251 L .44634 .58245 L F
.956 .929 .588 r
.45096 .58089 m .45169 .58212 L .44949 .58492 L F
.45169 .58212 m .45192 .58251 L .45174 .5827 L F
.45169 .58212 m .45174 .5827 L .44949 .58492 L F
.741 .871 .94 r
.45193 .5839 m .45183 .58398 L .45182 .58388 L F
.45183 .58398 m .44997 .58549 L .45182 .58388 L F
.27 .112 .475 r
.41948 .49288 m .42123 .49223 L .42132 .48957 L F
.208 0 .327 r
.41948 .49288 m .41898 .49551 L .42123 .49223 L F
.27 .112 .475 r
.41948 .49288 m .42123 .49223 L .42132 .48957 L F
.208 0 .327 r
.42123 .49223 m .41898 .49551 L .41948 .49288 L F
.672 .938 .66 r
.3294 .59426 m .32687 .59635 L .33055 .5925 L F
.147 0 .174 r
.3294 .59426 m .32795 .59663 L .32941 .59544 L F
.97 .882 .69 r
.32795 .59663 m .32687 .59635 L .3294 .59426 L F
.444 .302 .592 r
.5624 .40786 m .56304 .41043 L .55998 .40887 L F
.933 .947 .612 r
.5507 .46609 m .55175 .46386 L .5511 .46359 L F
.208 .457 .877 r
.55175 .46386 m .55548 .46706 L .55439 .46327 L F
.668 .917 .976 r
.53513 .40584 m .53895 .40526 L .53802 .40456 L F
.818 .966 .901 r
.53992 .40228 m .53895 .40526 L .54211 .40253 L F
.846 .989 .854 r
.53992 .40228 m .53802 .40456 L .53895 .40526 L F
.598 .848 .992 r
.34496 .65184 m .34903 .6518 L .34726 .65191 L F
.561 .915 .962 r
.25027 .54586 m .25407 .54526 L .25239 .54469 L F
.608 .915 .979 r
.25468 .54359 m .25239 .54469 L .25407 .54526 L F
.25468 .54359 m .25239 .54469 L .25407 .54526 L F
.242 .755 .848 r
.46158 .59545 m .45986 .59526 L .45728 .59569 L F
.862 .45 .247 r
.38148 .51183 m .37778 .50826 L .38112 .5096 L F
.541 .835 .505 r
.373 .6263 m .37596 .62312 L .37569 .62336 L F
.691 .851 .435 r
.37569 .62336 m .37596 .62312 L .37688 .62121 L F
0 0 0 r
.65089 .39414 m .65476 .39212 L .65339 .39278 L F
.6569 .39103 m .65476 .39212 L .65716 .39064 L F
.323 .781 .641 r
.65339 .39278 m .65476 .39212 L .6569 .39103 L F
.762 .68 .772 r
.34593 .53217 m .34288 .53285 L .34194 .53133 L F
.766 .671 .758 r
.34194 .53133 m .34331 .53528 L .34593 .53217 L F
.2 .704 .906 r
.34072 .53639 m .34622 .53705 L .34331 .53528 L F
0 0 0 r
.64162 .33277 m .64376 .33221 L .64482 .33073 L F
.64162 .33277 m .64106 .33326 L .64376 .33221 L F
.988 .75 .484 r
.73661 .30568 m .73813 .30428 L .73516 .30383 L F
.73661 .30568 m .73806 .30721 L .73813 .30428 L F
0 0 0 r
.34479 .63295 m .3405 .63572 L .34365 .63283 L F
.64 .831 .974 r
.34716 .63172 m .34479 .63295 L .34568 .63142 L F
.768 .994 .874 r
.34568 .63142 m .34479 .63295 L .34365 .63283 L F
0 0 0 r
.53066 .42857 m .53252 .42813 L .53 .43043 L F
.53066 .42857 m .53301 .42772 L .53252 .42813 L F
0 0 .507 r
.33559 .5714 m .33698 .57367 L .33696 .57247 L F
.522 .751 .979 r
.33477 .57464 m .33698 .57367 L .33559 .5714 L F
.815 .696 .734 r
.3328 .57713 m .33173 .57738 L .3303 .57364 L F
.832 .846 .857 r
.33081 .57526 m .3328 .57713 L .33271 .57305 L F
.862 .428 .009 r
.33195 .57793 m .3328 .57713 L .33081 .57526 L F
.33225 .57863 m .33241 .57819 L .33195 .57793 L F
.33241 .57819 m .3328 .57713 L .33195 .57793 L F
0 0 0 r
.33352 .5767 m .3328 .57713 L .3329 .57769 L F
.33323 .57735 m .3329 .57769 L .33295 .57798 L F
.644 .527 .706 r
.33329 .57731 m .33326 .57733 L .33324 .57731 L F
.33327 .57729 m .33324 .57731 L .33081 .57526 L F
.33329 .57731 m .33324 .57731 L .33327 .57729 L F
0 0 0 r
.33324 .57731 m .3329 .57769 L .33323 .57735 L F
.33352 .5767 m .333 .57752 L .33324 .57731 L F
.333 .57752 m .3329 .57769 L .33324 .57731 L F
.773 .269 0 r
.33081 .57526 m .33049 .57719 L .33225 .57863 L F
.33081 .57526 m .33324 .57731 L .33049 .57719 L F
.644 .527 .706 r
.33271 .57305 m .33329 .57731 L .33081 .57526 L F
.935 .943 .772 r
.33053 .57711 m .33323 .57735 L .33256 .57366 L F
.773 .269 0 r
.33326 .57733 m .33329 .57735 L .33325 .57735 L F
.644 .527 .706 r
.33329 .57731 m .33329 .57735 L .33326 .57733 L F
.935 .943 .772 r
.33323 .57735 m .33329 .57735 L .33328 .5773 L F
.773 .269 0 r
.33324 .57731 m .33326 .57733 L .33324 .57733 L F
.935 .943 .772 r
.33323 .57735 m .33328 .5773 L .33256 .57366 L F
.773 .269 0 r
.33324 .57731 m .33324 .57733 L .33049 .57719 L F
0 0 0 r
.33295 .57798 m .3328 .57713 L .33225 .57863 L F
.3357 .5754 m .33352 .5767 L .33295 .57798 L F
.935 .943 .772 r
.33049 .57719 m .33069 .5772 L .33053 .57711 L F
.773 .269 0 r
.33326 .57733 m .33325 .57735 L .33049 .57719 L F
.935 .943 .772 r
.33069 .5772 m .33329 .57735 L .33053 .57711 L F
0 0 0 r
.33698 .57367 m .33362 .57646 L .33489 .57588 L F
.33362 .57646 m .3328 .57713 L .33352 .5767 L F
.33362 .57646 m .33352 .5767 L .33489 .57588 L F
.33621 .57471 m .33489 .57588 L .3357 .5754 L F
.33698 .57367 m .33489 .57588 L .33621 .57471 L F
.898 .924 .538 r
.33652 .5729 m .33698 .57367 L .3357 .5754 L F
0 0 .507 r
.33559 .5714 m .33696 .57247 L .33271 .57305 L F
.33696 .57247 m .33696 .57247 L .33696 .57247 L F
.33696 .57247 m .33696 .57247 L .33271 .57305 L F
.491 .82 1 r
.33271 .57305 m .33696 .57247 L .3331 .5713 L F
.898 .924 .538 r
.33684 .57193 m .33689 .57254 L .33652 .5729 L F
.33689 .57254 m .33698 .57367 L .33652 .5729 L F
.296 0 0 r
.42121 .58386 m .42444 .58449 L .42551 .58425 L F
.107 .402 .854 r
.42642 .58285 m .42551 .58425 L .42444 .58449 L F
.42642 .58285 m .42804 .58572 L .42551 .58425 L F
.587 .537 .766 r
.42956 .58751 m .42551 .58425 L .42804 .58572 L F
.948 .927 .748 r
.56525 .41054 m .56388 .41443 L .56317 .41347 L F
.928 .944 .785 r
.61277 .38809 m .61605 .38576 L .61381 .38659 L F
.472 .768 .995 r
.61768 .38394 m .61605 .38576 L .61487 .38248 L F
.61768 .38394 m .61902 .38542 L .61605 .38576 L F
.61605 .38576 m .61768 .38394 L .61381 .38659 L F
.61605 .38576 m .61902 .38542 L .61768 .38394 L F
0 0 .233 r
.23007 .60358 m .23076 .6052 L .23158 .60252 L F
.23007 .60358 m .23037 .60613 L .23076 .6052 L F
.64 .489 .663 r
.43073 .48616 m .42808 .48983 L .42791 .4869 L F
.744 .933 .592 r
.42943 .48787 m .42808 .48983 L .43073 .48616 L F
.821 .695 .726 r
.42943 .48787 m .43227 .49009 L .43073 .48616 L F
.601 .832 .987 r
.42808 .48983 m .43227 .49009 L .42943 .48787 L F
.473 0 0 r
.58401 .4225 m .58313 .42158 L .582 .42015 L F
.58401 .4225 m .58587 .42342 L .58313 .42158 L F
.802 .975 .904 r
.42587 .45284 m .42876 .45065 L .43025 .451 L F
.354 .823 .759 r
.42876 .45065 m .43242 .44936 L .43025 .451 L F
.342 .001 .234 r
.57633 .45652 m .5773 .45533 L .57973 .45426 L F
.312 0 .207 r
.31987 .60035 m .32232 .59987 L .32294 .59771 L F
.474 .108 .263 r
.32294 .59771 m .32232 .59987 L .32502 .59927 L F
.848 .82 .822 r
.5882 .44967 m .59142 .44701 L .58967 .44524 L F
.669 .964 .764 r
.60482 .38234 m .60821 .37959 L .60645 .38028 L F
0 0 0 r
.60949 .37779 m .60821 .37959 L .60967 .37734 L F
.668 .964 .764 r
.60645 .38028 m .60821 .37959 L .60949 .37779 L F
.751 .683 .785 r
.3932 .48613 m .39762 .48709 L .39656 .48324 L F
0 .11 .663 r
.3932 .48613 m .39526 .49024 L .39762 .48709 L F
.667 .163 0 r
.57954 .39268 m .57988 .39244 L .5789 .39075 L F
.57954 .39268 m .58314 .39629 L .57988 .39244 L F
.499 .903 .8 r
.50302 .41173 m .49877 .41356 L .502 .4114 L F
.655 .954 .736 r
.50588 .40922 m .50302 .41173 L .50427 .40996 L F
.638 .959 .919 r
.50427 .40996 m .50302 .41173 L .502 .4114 L F
.615 .121 0 r
.22934 .57819 m .22841 .57739 L .22619 .57467 L F
.817 .405 0 r
.22934 .57819 m .23054 .58087 L .22841 .57739 L F
0 0 0 r
.66392 .32886 m .66066 .33135 L .66146 .32998 L F
0 0 .208 r
.47538 .46277 m .47444 .46712 L .47724 .46464 L F
0 0 0 r
.34642 .59973 m .34531 .60121 L .34717 .59769 L F
.524 .299 .515 r
.35069 .5947 m .34717 .59769 L .35 .59563 L F
0 0 0 r
.3487 .59674 m .34717 .59769 L .35069 .5947 L F
.47 .216 .447 r
.34717 .59769 m .34915 .59948 L .35 .59563 L F
.273 .219 .613 r
.3487 .59674 m .34915 .59948 L .34717 .59769 L F
.551 .202 .329 r
.34915 .59948 m .34642 .59973 L .34717 .59769 L F
.535 0 0 r
.54718 .44435 m .54322 .44314 L .5463 .44095 L F
.787 .993 .879 r
.54311 .44598 m .54718 .44435 L .54576 .44517 L F
.986 .711 .358 r
.5488 .43945 m .54718 .44435 L .5463 .44095 L F
.5488 .43945 m .54941 .4425 L .54718 .44435 L F
.507 .87 .638 r
.54576 .44517 m .54718 .44435 L .54941 .4425 L F
.869 .948 .863 r
.68442 .34258 m .6827 .34698 L .68148 .34547 L F
.68442 .34258 m .68561 .34398 L .6827 .34698 L F
.402 .257 .567 r
.40483 .46029 m .40269 .46419 L .40457 .46293 L F
.482 .466 .763 r
.63909 .38234 m .64514 .38589 L .64169 .38154 L F
.087 0 .419 r
.61889 .3987 m .62089 .39396 L .62077 .39759 L F
.274 .09 .44 r
.61863 .401 m .61889 .3987 L .62077 .39759 L F
.62077 .39759 m .61889 .3987 L .61863 .401 L F
0 .182 .703 r
.57719 .36529 m .58001 .36831 L .57863 .36919 L F
.274 .735 .951 r
.58001 .36831 m .58117 .36902 L .57863 .36919 L F
.166 .146 .589 r
.32831 .51266 m .33072 .51487 L .33116 .51227 L F
.32831 .51266 m .3288 .51681 L .33072 .51487 L F
.949 .917 .55 r
.23965 .60084 m .23839 .60406 L .23952 .60097 L F
0 0 0 r
.36069 .53938 m .36162 .53927 L .36365 .53812 L F
0 0 .091 r
.36385 .53489 m .36365 .53812 L .36401 .53636 L F
.822 .991 .735 r
.36365 .53812 m .36162 .53927 L .36401 .53636 L F
.497 .571 .861 r
.27964 .65135 m .28145 .65551 L .28303 .65452 L F
0 0 .325 r
.47091 .52582 m .47086 .52855 L .47072 .52959 L F
.47091 .52582 m .47203 .52459 L .47086 .52855 L F
.551 0 0 r
.62676 .41471 m .63037 .417 L .62842 .41638 L F
.62676 .41471 m .62842 .41638 L .62827 .41327 L F
.851 .538 .458 r
.43447 .47333 m .43766 .47619 L .4385 .47358 L F
.791 .67 .73 r
.41779 .59423 m .41376 .59442 L .41568 .593 L F
.41779 .59423 m .41586 .59765 L .41376 .59442 L F
0 0 .485 r
.22803 .54837 m .22921 .5503 L .22884 .54619 L F
.095 .005 .453 r
.22803 .54837 m .22797 .55142 L .22921 .5503 L F
.93 .653 .493 r
.71461 .30211 m .71641 .30047 L .71229 .30066 L F
.71461 .30211 m .7165 .30365 L .71641 .30047 L F
0 0 0 r
.25753 .52445 m .25407 .52648 L .25469 .52568 L F
.909 .932 .815 r
.68701 .33875 m .68561 .34398 L .68526 .34123 L F
.68701 .33875 m .6883 .34014 L .68561 .34398 L F
.922 .942 .796 r
.68526 .34123 m .68561 .34398 L .68442 .34258 L F
.677 .466 .592 r
.62308 .39117 m .62067 .38967 L .62253 .38747 L F
.62308 .39117 m .62102 .39329 L .62067 .38967 L F
.62308 .39117 m .62376 .39176 L .62102 .39329 L F
.795 .997 .786 r
.62308 .39117 m .62102 .39329 L .62376 .39176 L F
.548 .073 .08 r
.32957 .57899 m .32983 .58183 L .32718 .58193 L F
.32957 .57899 m .33158 .5801 L .32983 .58183 L F
.986 .711 .358 r
.5488 .43945 m .54996 .44084 L .54941 .4425 L F
.531 .772 .986 r
.55139 .43896 m .54996 .44084 L .5488 .43945 L F
.701 .646 .791 r
.55139 .43896 m .54941 .4425 L .54996 .44084 L F
.719 .666 .797 r
.49593 .47092 m .49714 .46627 L .49481 .46695 L F
.49593 .47092 m .49862 .46977 L .49714 .46627 L F
.912 .946 .594 r
.57443 .36606 m .57298 .36914 L .57294 .36719 L F
.586 .889 .601 r
.57443 .36606 m .57488 .36528 L .57719 .36529 L F
.57443 .36606 m .57294 .36719 L .57488 .36528 L F
0 0 0 r
.64482 .33073 m .64634 .33104 L .6474 .3296 L F
.64482 .33073 m .64376 .33221 L .64634 .33104 L F
.617 .361 .507 r
.40718 .50141 m .40677 .49948 L .40546 .49961 L F
.40718 .50141 m .40891 .50072 L .40677 .49948 L F
.065 0 0 r
.41079 .45343 m .40594 .45586 L .40868 .45518 L F
.769 .532 .576 r
.40868 .45518 m .41277 .45306 L .41079 .45343 L F
0 .11 .663 r
.3932 .48613 m .39547 .48816 L .39526 .49024 L F
.441 .402 .719 r
.39547 .48816 m .39365 .49197 L .39526 .49024 L F
.092 0 0 r
.31741 .5339 m .32198 .53167 L .31957 .53316 L F
.942 .677 .506 r
.3935 .52812 m .39153 .52468 L .39332 .52578 L F
0 0 .111 r
.5506 .41399 m .55064 .41398 L .55036 .41172 L F
.35 .236 .58 r
.54783 .41469 m .55064 .41398 L .55036 .41172 L F
0 0 .078 r
.54848 .41704 m .55064 .41398 L .54783 .41469 L F
0 0 0 r
.60645 .38028 m .60429 .38391 L .60482 .38234 L F
.916 .916 .525 r
.47086 .52855 m .47032 .52981 L .47072 .52959 L F
.215 0 0 r
.46713 .53151 m .47012 .53099 L .46897 .53306 L F
.46713 .53151 m .46966 .53136 L .47148 .53076 L F
.671 .31 .352 r
.47072 .52959 m .46966 .53136 L .46722 .52877 L F
.916 .916 .525 r
.47032 .52981 m .46966 .53136 L .47022 .53043 L F
.47032 .52981 m .47022 .53043 L .47072 .52959 L F
.215 0 0 r
.47012 .53099 m .47148 .53076 L .46993 .53218 L F
.47012 .53099 m .46993 .53218 L .46897 .53306 L F
0 0 .48 r
.3379 .53187 m .33696 .53508 L .33531 .5332 L F
.3379 .53187 m .3382 .53426 L .33696 .53508 L F
.794 .299 0 r
.37778 .50826 m .37415 .50513 L .37688 .50674 L F
0 .034 .6 r
.24427 .54041 m .24252 .53847 L .24461 .53786 L F
.178 0 0 r
.71802 .32699 m .72207 .32756 L .72086 .32756 L F
0 0 0 r
.72207 .32756 m .72483 .32684 L .72377 .32753 L F
.72207 .32756 m .72377 .32753 L .72086 .32756 L F
0 0 .51 r
.54522 .47443 m .54652 .47585 L .54398 .47323 L F
.719 .222 0 r
.58314 .39629 m .58453 .3977 L .58385 .39562 L F
.581 .916 .693 r
.61058 .35184 m .60848 .35394 L .61175 .35262 L F
.61058 .35184 m .60746 .35434 L .60848 .35394 L F
.973 .762 .558 r
.39905 .53526 m .39977 .53902 L .39695 .53644 L F
.957 .615 .257 r
.39928 .541 m .39695 .53644 L .39977 .53902 L F
.607 .923 .681 r
.64385 .38822 m .64019 .39111 L .64326 .38878 L F
.696 .921 .591 r
.42463 .53532 m .42558 .53351 L .42702 .53238 L F
.937 .566 .259 r
.42558 .53351 m .42732 .53474 L .42702 .53238 L F
.815 .641 .666 r
.70608 .30661 m .70282 .30669 L .70312 .30376 L F
.818 .637 .657 r
.70608 .30661 m .70268 .30962 L .70282 .30669 L F
.70608 .30661 m .70534 .31031 L .70268 .30962 L F
.487 .221 .436 r
.3281 .49638 m .32786 .49931 L .33033 .49821 L F
.537 .206 .354 r
.3281 .49638 m .33033 .49821 L .33075 .49634 L F
0 0 0 r
.71128 .32893 m .71535 .32664 L .71422 .32689 L F
.065 .605 .853 r
.71535 .32664 m .71802 .32699 L .71724 .3264 L F
.71535 .32664 m .71724 .3264 L .71422 .32689 L F
.525 .778 .99 r
.32677 .64127 m .32627 .6435 L .32431 .64181 L F
.32677 .64127 m .32901 .64267 L .32627 .6435 L F
.75 .513 .572 r
.33007 .64601 m .32627 .6435 L .32901 .64267 L F
.917 .526 .237 r
.3871 .5597 m .38839 .55844 L .38653 .55745 L F
.3871 .5597 m .38905 .56075 L .38839 .55844 L F
.697 .936 .632 r
.71842 .2729 m .72044 .27123 L .71727 .27483 L F
.537 .327 .543 r
.72044 .27123 m .7208 .27402 L .71727 .27483 L F
.926 .609 .424 r
.71842 .2729 m .7208 .27402 L .72044 .27123 L F
.296 .102 .44 r
.34531 .62085 m .34728 .6223 L .34692 .61962 L F
.481 .267 .512 r
.4239 .57775 m .42363 .58039 L .42121 .581 L F
.044 0 .359 r
.42529 .57916 m .42363 .58039 L .4239 .57775 L F
.884 .713 .666 r
.56097 .42752 m .56244 .43147 L .56101 .42972 L F
.504 .811 1 r
.56203 .43433 m .56101 .42972 L .56244 .43147 L F
.526 .284 .491 r
.56534 .43133 m .56203 .43433 L .56244 .43147 L F
.575 .009 0 r
.43217 .59145 m .43337 .59115 L .43586 .59284 L F
.951 .795 .652 r
.42935 .57409 m .43085 .57767 L .42916 .5781 L F
.743 .288 .17 r
.42916 .5781 m .43085 .57767 L .42894 .57922 L F
.582 .562 .796 r
.43331 .57521 m .43085 .57767 L .42935 .57409 L F
.43331 .57521 m .43297 .57818 L .43085 .57767 L F
.392 .234 .545 r
.43085 .57767 m .43083 .58076 L .43301 .57979 L F
.668 .189 .104 r
.43085 .57767 m .43301 .57979 L .42894 .57922 L F
.039 0 0 r
.536 .39718 m .5387 .39656 L .54022 .39554 L F
.941 .922 .762 r
.69002 .3367 m .6883 .34014 L .68701 .33875 L F
.707 .66 .802 r
.41189 .49532 m .41335 .49732 L .41609 .49619 L F
.647 .485 .65 r
.41335 .49732 m .41355 .49954 L .41609 .49619 L F
.562 .397 .616 r
.42363 .58039 m .42121 .58386 L .42121 .581 L F
.42 .218 .498 r
.49027 .50877 m .4925 .50464 L .4896 .50607 L F
.56 .378 .592 r
.60596 .40793 m .60964 .40475 L .60712 .4059 L F
.611 .497 .699 r
.60725 .40738 m .60742 .40919 L .60596 .40793 L F
.56 .378 .592 r
.60596 .40793 m .60722 .40799 L .60725 .40738 L F
.60596 .40793 m .60975 .40633 L .60964 .40475 L F
.611 .497 .699 r
.60712 .4059 m .60725 .40738 L .60596 .40793 L F
.554 .496 .745 r
.60722 .40799 m .60742 .40919 L .60988 .40814 L F
.60596 .40793 m .60742 .40919 L .60722 .40799 L F
.992 .771 .5 r
.6055 .40696 m .60717 .40891 L .60715 .40755 L F
.6069 .40604 m .60715 .40755 L .60712 .4059 L F
.6055 .40696 m .60715 .40755 L .6069 .40604 L F
.60717 .40891 m .60742 .40919 L .60725 .40738 L F
.60717 .40891 m .60725 .40738 L .60712 .4059 L F
.56 .378 .592 r
.60725 .40738 m .60988 .40814 L .60975 .40633 L F
.60722 .40799 m .60988 .40814 L .60725 .40738 L F
.774 .671 .75 r
.41022 .51065 m .41209 .5146 L .41062 .51268 L F
.083 0 0 r
.54979 .47273 m .55105 .47376 L .55232 .47238 L F
.54979 .47273 m .54891 .47475 L .55105 .47376 L F
.964 .788 .616 r
.58919 .43375 m .5906 .42893 L .58813 .42774 L F
.975 .796 .6 r
.58925 .43536 m .5906 .42893 L .58919 .43375 L F
0 0 0 r
.47432 .5879 m .47641 .58433 L .47522 .58657 L F
.4734 .59015 m .47432 .5879 L .47522 .58657 L F
.132 .463 .889 r
.23443 .61104 m .23419 .61175 L .23578 .612 L F
.659 .159 0 r
.2328 .6101 m .23419 .61175 L .23137 .60888 L F
.132 .463 .889 r
.23137 .60888 m .23419 .61175 L .23443 .61104 L F
.925 .556 .137 r
.2328 .6101 m .23399 .61231 L .23419 .61175 L F
.23399 .61231 m .2348 .61381 L .23419 .61175 L F
.18 .412 .85 r
.23419 .61175 m .2348 .61381 L .23578 .612 L F
.531 .841 .999 r
.2348 .61381 m .23781 .61306 L .23746 .61582 L F
.107 .315 .789 r
.2348 .61381 m .23746 .61582 L .23578 .612 L F
.224 0 .15 r
.66666 .38526 m .66973 .38263 L .6692 .38422 L F
.219 0 .174 r
.6692 .38422 m .66973 .38263 L .67224 .38152 L F
.543 .52 .779 r
.49481 .46695 m .496 .46234 L .49394 .46427 L F
.49481 .46695 m .49714 .46627 L .496 .46234 L F
.731 .459 .516 r
.41323 .50232 m .4176 .50494 L .41755 .50288 L F
.42 0 0 r
.42278 .57338 m .42561 .57324 L .4215 .56873 L F
.491 .42 .705 r
.42347 .56795 m .42592 .57323 L .425 .57249 L F
.42 0 0 r
.42561 .57324 m .42592 .57323 L .42542 .57301 L F
.42561 .57324 m .42586 .57353 L .42592 .57323 L F
.42278 .57338 m .42586 .57353 L .42561 .57324 L F
0 0 .468 r
.42542 .57301 m .42558 .57321 L .425 .57249 L F
.42558 .57321 m .42664 .57459 L .42536 .57297 L F
.42558 .57321 m .42536 .57297 L .425 .57249 L F
.42586 .57353 m .42542 .57301 L .42592 .57323 L F
.42542 .57301 m .425 .57249 L .42592 .57323 L F
.42 0 0 r
.42542 .57301 m .42592 .57323 L .42434 .57162 L F
.42561 .57324 m .42434 .57162 L .4215 .56873 L F
0 0 .468 r
.42586 .57353 m .42628 .5741 L .42542 .57301 L F
.42628 .5741 m .42664 .57459 L .42542 .57301 L F
.832 .417 .254 r
.42664 .57459 m .42916 .5781 L .42485 .57608 L F
.396 .777 .991 r
.42935 .57409 m .42664 .57459 L .42586 .57353 L F
.453 .368 .671 r
.42935 .57409 m .42916 .5781 L .42664 .57459 L F
.888 .916 .837 r
.71727 .27483 m .71464 .27815 L .71321 .27678 L F
.509 .316 .553 r
.71727 .27483 m .71742 .27758 L .71464 .27815 L F
.388 .826 .951 r
.71464 .27815 m .71624 .27687 L .71321 .27678 L F
.71464 .27815 m .71742 .27758 L .71624 .27687 L F
.767 .973 .694 r
.4426 .45834 m .44182 .45995 L .44326 .45811 L F
.4426 .45834 m .44149 .45958 L .44182 .45995 L F
.838 .94 .572 r
.44149 .45958 m .44041 .46113 L .44182 .45995 L F
.815 .902 .493 r
.54283 .39995 m .54211 .40253 L .54404 .39853 L F
0 0 0 r
.54562 .39692 m .54283 .39995 L .54404 .39853 L F
.649 .808 .96 r
.40743 .45967 m .41152 .4601 L .40972 .45884 L F
.636 .674 .869 r
.41152 .4601 m .4126 .45575 L .40972 .45884 L F
.41152 .4601 m .41478 .46067 L .4126 .45575 L F
.593 .531 .754 r
.70094 .30946 m .70046 .31323 L .70083 .3108 L F
.70094 .30946 m .70269 .31418 L .70046 .31323 L F
.683 .408 .499 r
.70269 .31418 m .70193 .31615 L .70046 .31323 L F
.767 .973 .694 r
.4426 .45834 m .44326 .45811 L .44501 .45682 L F
.781 .903 .927 r
.44747 .45646 m .4426 .45834 L .44501 .45682 L F
.452 .124 .318 r
.31489 .57978 m .31844 .57748 L .31453 .57732 L F
.643 .925 .974 r
.72849 .32659 m .73068 .32549 L .72992 .32454 L F
.67 .96 .94 r
.72772 .32595 m .72849 .32659 L .72992 .32454 L F
.926 .538 .19 r
.58814 .42687 m .58752 .42453 L .58587 .42342 L F
0 .361 .704 r
.26373 .62729 m .26354 .62724 L .26071 .62603 L F
.435 .629 .936 r
.26229 .60885 m .26094 .61078 L .25972 .60909 L F
.26229 .60885 m .26094 .61078 L .25972 .60909 L F
0 0 .068 r
.41797 .52465 m .4177 .52697 L .41715 .52753 L F
.321 .109 .427 r
.4201 .52377 m .4177 .52697 L .41797 .52465 L F
.88 .911 .845 r
.41603 .52577 m .4177 .52697 L .4201 .52377 L F
0 .464 .81 r
.41603 .52577 m .41807 .52659 L .4177 .52697 L F
.41807 .52659 m .41947 .52714 L .4177 .52697 L F
0 0 .068 r
.41715 .52753 m .4177 .52697 L .41713 .52762 L F
0 .266 .772 r
.4177 .52697 m .42056 .53014 L .41713 .52762 L F
.629 .883 .988 r
.44184 .4463 m .44467 .44507 L .44559 .44613 L F
.564 .911 .97 r
.44642 .4446 m .44559 .44613 L .44467 .44507 L F
.44642 .4446 m .44955 .44477 L .44559 .44613 L F
0 0 0 r
.56534 .43133 m .5674 .42858 L .56707 .42922 L F
.446 0 .047 r
.5674 .42858 m .56992 .42962 L .56707 .42922 L F
.845 .967 .643 r
.6286 .41943 m .63017 .41838 L .63037 .417 L F
.785 .949 .613 r
.63256 .41485 m .63108 .41603 L .63017 .41838 L F
.791 .963 .65 r
.63017 .41838 m .63108 .41603 L .6286 .41943 L F
.941 .922 .762 r
.69002 .3367 m .68701 .33875 L .68907 .33536 L F
.707 .878 .961 r
.62026 .41112 m .62182 .4124 L .62442 .41084 L F
.753 .905 .52 r
.22641 .55837 m .22451 .56155 L .22511 .55988 L F
0 0 .068 r
.22451 .56155 m .22501 .56246 L .22511 .55988 L F
.22451 .56155 m .22382 .56405 L .22501 .56246 L F
.991 .752 .467 r
.3909 .57945 m .39251 .57766 L .391 .57668 L F
.3909 .57945 m .39233 .58049 L .39251 .57766 L F
.294 0 0 r
.55733 .38764 m .56167 .3859 L .5583 .38748 L F
.493 .253 .48 r
.33747 .59008 m .34054 .58711 L .33732 .58731 L F
.482 .378 .659 r
.38621 .47253 m .38317 .4739 L .38362 .47296 L F
.377 .161 .454 r
.38353 .47618 m .38317 .4739 L .38621 .47253 L F
.157 .021 .432 r
.38353 .47618 m .38317 .4739 L .38362 .47296 L F
.696 .791 .924 r
.30456 .65655 m .30868 .65679 L .30702 .65614 L F
.315 .764 .958 r
.30702 .65614 m .30868 .65679 L .31061 .65644 L F
.577 .566 .805 r
.28749 .65538 m .2889 .65963 L .29072 .65825 L F
.541 .835 .505 r
.373 .6263 m .37569 .62336 L .37321 .62608 L F
.222 0 0 r
.24162 .53069 m .24617 .52691 L .24292 .52845 L F
.24162 .53069 m .24413 .53013 L .24617 .52691 L F
0 0 0 r
.24617 .52691 m .24743 .52754 L .24821 .52481 L F
.24617 .52691 m .24579 .52886 L .24743 .52754 L F
.24617 .52691 m .24413 .53013 L .24579 .52886 L F
.401 .781 .992 r
.58352 .35046 m .58777 .35119 L .58493 .35193 L F
0 0 .006 r
.42504 .55326 m .42269 .55746 L .4231 .55557 L F
0 0 0 r
.35135 .59313 m .35069 .5947 L .35183 .59053 L F
.496 .313 .563 r
.35135 .59313 m .3487 .59674 L .35069 .5947 L F
.636 .508 .69 r
.72174 .30749 m .7247 .30735 L .7239 .30487 L F
.431 .843 .666 r
.72174 .30749 m .72355 .30626 L .7247 .30735 L F
.72174 .30749 m .72104 .30786 L .72355 .30626 L F
.195 .32 .765 r
.55439 .46327 m .55548 .46706 L .55706 .46528 L F
.788 .551 0 r
.55548 .46706 m .55585 .46971 L .55547 .46836 L F
.55548 .46706 m .55547 .46836 L .55706 .46528 L F
.632 .849 .464 r
.34162 .62134 m .34037 .62324 L .34223 .62057 L F
.134 .118 .573 r
.34162 .62134 m .34155 .62574 L .34037 .62324 L F
0 .271 .673 r
.58505 .38363 m .58009 .38091 L .58124 .38241 L F
.874 .577 .482 r
.37324 .5285 m .3742 .53167 L .37662 .53212 L F
.93 .695 .56 r
.37451 .5339 m .37662 .53212 L .3742 .53167 L F
.37451 .5339 m .37637 .53489 L .37662 .53212 L F
.184 .211 .655 r
.22619 .57467 m .22841 .57739 L .22768 .57235 L F
.508 .22 .412 r
.32972 .53788 m .33108 .53702 L .3304 .53694 L F
.999 .834 .502 r
.58444 .40317 m .586 .40196 L .58539 .40079 L F
.58444 .40317 m .58545 .40443 L .586 .40196 L F
.651 .502 .668 r
.5015 .48309 m .50515 .48605 L .50426 .48232 L F
.5015 .48309 m .50248 .48643 L .50515 .48605 L F
.957 .892 .506 r
.39078 .59499 m .39033 .59986 L .39145 .59751 L F
.71 .56 .683 r
.60551 .36523 m .60485 .36881 L .60696 .36547 L F
.526 .284 .491 r
.56534 .43133 m .56494 .43385 L .56203 .43433 L F
.26 .056 .402 r
.567 .43301 m .56534 .43133 L .56707 .42922 L F
.567 .43301 m .56494 .43385 L .56534 .43133 L F
.517 .817 .999 r
.24655 .59054 m .25334 .59072 L .24881 .58795 L F
.034 .373 .84 r
.25334 .59072 m .2513 .58776 L .24881 .58795 L F
.356 .126 .421 r
.42649 .50831 m .4255 .51179 L .42812 .50848 L F
.339 0 .078 r
.4217 .59823 m .42401 .5991 L .41986 .59915 L F
.4217 .59823 m .42421 .59754 L .42401 .5991 L F
.608 .952 .908 r
.37195 .49613 m .36765 .49755 L .37085 .4957 L F
.651 .874 .509 r
.37441 .49282 m .37195 .49613 L .37295 .49443 L F
.628 .947 .946 r
.37295 .49443 m .37195 .49613 L .37085 .4957 L F
.887 .904 .835 r
.23063 .59931 m .23458 .59713 L .23105 .59696 L F
.521 .348 .587 r
.48098 .52309 m .48283 .52242 L .48255 .51952 L F
.53 .369 .607 r
.48283 .52242 m .48417 .51815 L .48255 .51952 L F
0 0 0 r
.6594 .32084 m .65666 .32361 L .65873 .32207 L F
.65873 .32207 m .66221 .32002 L .6594 .32084 L F
.824 .919 .9 r
.61551 .40184 m .61693 .40303 L .61863 .401 L F
.888 .916 .837 r
.71727 .27483 m .71321 .27678 L .71644 .27236 L F
.697 .936 .632 r
.71842 .2729 m .71727 .27483 L .71644 .27236 L F
.776 .701 .78 r
.7208 .27402 m .71742 .27758 L .71727 .27483 L F
.182 0 0 r
.61287 .34392 m .61547 .34398 L .61694 .34349 L F
0 0 0 r
.61547 .34398 m .61953 .3426 L .61694 .34349 L F
.592 .6 .829 r
.49714 .46627 m .49862 .46977 L .50118 .46898 L F
.634 .598 .796 r
.49862 .46977 m .50211 .47114 L .50118 .46898 L F
.792 .726 .79 r
.4332 .57085 m .42993 .57085 L .43191 .56839 L F
.751 .521 .583 r
.4332 .57085 m .42935 .57409 L .42993 .57085 L F
.4332 .57085 m .43331 .57521 L .42935 .57409 L F
.671 .676 .846 r
.43587 .56745 m .4332 .57085 L .43191 .56839 L F
0 0 .275 r
.43404 .57255 m .4332 .57085 L .43582 .56752 L F
.43404 .57255 m .43582 .56752 L .43582 .5676 L F
.53 .277 .477 r
.43744 .57037 m .43634 .57107 L .43587 .56745 L F
.43634 .57107 m .43404 .57255 L .43582 .5676 L F
.43634 .57107 m .43582 .5676 L .43587 .56745 L F
.755 .715 .814 r
.43674 .57197 m .43404 .57255 L .43744 .57037 L F
.925 .597 .137 r
.43581 .57005 m .43581 .57116 L .43644 .5717 L F
.43636 .57118 m .43644 .5717 L .43674 .57197 L F
.43581 .57005 m .43644 .5717 L .43636 .57118 L F
.43499 .56836 m .43539 .57079 L .43581 .57116 L F
.43499 .56836 m .43581 .57116 L .43581 .57005 L F
0 0 .275 r
.43582 .5676 m .43582 .56752 L .43587 .56745 L F
.43404 .57255 m .43331 .57521 L .4332 .57085 L F
.35 0 .198 r
.53083 .49313 m .52986 .49589 L .52723 .49655 L F
.171 0 .104 r
.53331 .49208 m .52986 .49589 L .53083 .49313 L F
.959 .934 .609 r
.7025 .34325 m .70408 .34268 L .70337 .34136 L F
.7025 .34325 m .70266 .34644 L .70408 .34268 L F
.696 .566 .705 r
.35463 .58742 m .35183 .59053 L .35583 .59001 L F
.179 0 .22 r
.35463 .58742 m .35377 .58975 L .35183 .59053 L F
.527 .497 .766 r
.35183 .59053 m .35505 .59338 L .35583 .59001 L F
.511 .318 .555 r
.35377 .58975 m .35135 .59313 L .35183 .59053 L F
.669 .691 .862 r
.4126 .45575 m .41478 .46067 L .41634 .45705 L F
.633 .623 .823 r
.41535 .46096 m .41634 .45705 L .41478 .46067 L F
.639 .349 .463 r
.24505 .61869 m .24245 .61704 L .24292 .62017 L F
.24505 .61869 m .24651 .61705 L .24245 .61704 L F
.555 .012 0 r
.62395 .40566 m .62569 .40475 L .62306 .40383 L F
.375 .837 .895 r
.6242 .40436 m .62436 .40434 L .62569 .40475 L F
.251 0 0 r
.62569 .40475 m .62642 .40497 L .62306 .40383 L F
.62569 .40475 m .62703 .40518 L .62642 .40497 L F
.799 .974 .906 r
.62862 .40353 m .62703 .40518 L .62569 .40475 L F
.62862 .40353 m .62569 .40475 L .62894 .40389 L F
.375 .837 .895 r
.62436 .40434 m .62894 .40389 L .62569 .40475 L F
.669 .971 .806 r
.35353 .63816 m .35598 .63712 L .35194 .64015 L F
.63 .906 .984 r
.35353 .63816 m .35194 .64015 L .35093 .63906 L F
.819 .423 0 r
.35194 .64015 m .35315 .64295 L .35093 .63906 L F
.672 .222 0 r
.60308 .42186 m .60304 .42212 L .59987 .41733 L F
.847 .385 .028 r
.60308 .42186 m .60194 .42241 L .60304 .42212 L F
.408 .859 .816 r
.61861 .37266 m .61994 .37275 L .62244 .37167 L F
.551 .572 .828 r
.4926 .46063 m .49394 .46427 L .496 .46234 L F
.535 .922 .902 r
.56525 .4718 m .56379 .47322 L .566 .47213 L F
.541 .92 .785 r
.56306 .47326 m .56379 .47322 L .56525 .4718 L F
.314 0 .215 r
.3375 .55519 m .34003 .55456 L .33968 .55347 L F
.066 0 .26 r
.33968 .55347 m .34165 .55322 L .34361 .55032 L F
.33968 .55347 m .34003 .55456 L .34165 .55322 L F
.247 0 0 r
.33033 .49821 m .3347 .49636 L .33075 .49634 L F
.33033 .49821 m .33293 .49789 L .3347 .49636 L F
0 0 0 r
.33293 .49789 m .33696 .49725 L .3347 .49636 L F
.65934 .37717 m .65947 .37628 L .65861 .37782 L F
.462 0 0 r
.65947 .37628 m .66119 .37566 L .65958 .3755 L F
0 0 0 r
.66322 .37424 m .66416 .37268 L .66119 .37566 L F
.449 .867 .727 r
.66322 .37424 m .66119 .37566 L .65947 .37628 L F
0 0 0 r
.66168 .37509 m .65947 .37628 L .65934 .37717 L F
.462 0 0 r
.65947 .37628 m .65958 .3755 L .65775 .37533 L F
.849 .787 .791 r
.41757 .51897 m .41381 .52045 L .41674 .51818 L F
.41757 .51897 m .41521 .52244 L .41381 .52045 L F
.711 .665 .803 r
.57009 .44066 m .57419 .44187 L .57275 .43977 L F
.544 .836 .505 r
.57419 .44187 m .57424 .44172 L .57275 .43977 L F
.797 .671 .725 r
.41376 .59442 m .41586 .59765 L .41269 .59709 L F
.965 .862 .688 r
.41586 .59765 m .41313 .59974 L .41269 .59709 L F
.41586 .59765 m .41479 .6002 L .41313 .59974 L F
.427 .215 .487 r
.41728 .59909 m .41479 .6002 L .41586 .59765 L F
.648 .428 .57 r
.33447 .59301 m .33747 .59008 L .33531 .59139 L F
.939 .65 .467 r
.42231 .53125 m .42225 .53485 L .42463 .53532 L F
.021 .584 .8 r
.42225 .53485 m .42488 .53509 L .42463 .53532 L F
.471 .767 .995 r
.42558 .53351 m .42732 .53474 L .42463 .53532 L F
.248 0 .036 r
.42463 .53532 m .42489 .53669 L .42732 .53474 L F
.023 0 .453 r
.42558 .53351 m .42489 .53669 L .42463 .53532 L F
.42558 .53351 m .42463 .53532 L .42488 .53509 L F
0 0 0 r
.42463 .53532 m .42488 .53509 L .42558 .53351 L F
.543 .387 .619 r
.31034 .52821 m .30745 .52913 L .30743 .52543 L F
0 0 .231 r
.30743 .52543 m .30811 .52641 L .30788 .52592 L F
.30743 .52543 m .30745 .52913 L .30811 .52641 L F
.543 .387 .619 r
.31034 .52821 m .30743 .52543 L .30788 .52592 L F
.018 0 0 r
.28181 .58261 m .28535 .58078 L .28467 .58297 L F
.597 .243 .34 r
.28535 .58078 m .2876 .58303 L .28467 .58297 L F
0 0 0 r
.28615 .58095 m .28535 .58078 L .28314 .58045 L F
.487 .252 .482 r
.28762 .57994 m .2876 .58303 L .28535 .58078 L F
0 0 0 r
.28615 .58095 m .28762 .57994 L .28535 .58078 L F
.093 .644 .815 r
.56778 .38155 m .56657 .38136 L .57072 .38159 L F
.42 .218 .498 r
.49027 .50877 m .49221 .50825 L .4925 .50464 L F
.472 .32 .593 r
.4925 .50464 m .49637 .50526 L .49495 .50156 L F
.414 .169 .43 r
.49221 .50825 m .49637 .50526 L .4925 .50464 L F
.558 .781 .982 r
.348 .53676 m .34746 .53933 L .34622 .53705 L F
.348 .53676 m .35006 .53853 L .34746 .53933 L F
.294 .789 .864 r
.5265 .45096 m .52519 .45165 L .52319 .44944 L F
.5265 .45096 m .52789 .45107 L .52519 .45165 L F
0 0 0 r
.65399 .33409 m .65194 .3359 L .65568 .33395 L F
.65399 .33409 m .65208 .33587 L .65194 .3359 L F
.56 .358 .563 r
.313 .56785 m .31544 .56807 L .31577 .56475 L F
.561 .391 .608 r
.31544 .56807 m .31826 .56425 L .31577 .56475 L F
.117 .669 .753 r
.26551 .52172 m .26438 .52176 L .26151 .52207 L F
.389 .849 .864 r
.26817 .52083 m .26666 .5209 L .26551 .52172 L F
.393 .852 .85 r
.26666 .5209 m .26438 .52176 L .26551 .52172 L F
0 0 0 r
.56222 .45834 m .56084 .46034 L .5599 .46195 L F
.169 0 0 r
.62102 .39329 m .62376 .39176 L .62294 .39342 L F
0 0 0 r
.62577 .39053 m .62376 .39176 L .62646 .38987 L F
.62294 .39342 m .62376 .39176 L .62577 .39053 L F
.91 .849 .398 r
.69908 .35748 m .69934 .35956 L .70009 .35561 L F
0 0 0 r
.69934 .35985 m .69934 .35956 L .69908 .35748 L F
.69934 .35985 m .69921 .36223 L .69934 .35956 L F
.746 .914 .949 r
.63685 .39073 m .63405 .3943 L .63325 .39345 L F
.63685 .39073 m .63795 .39238 L .63405 .3943 L F
.665 .912 .592 r
.32726 .61659 m .32433 .61999 L .32772 .61988 L F
.11 .275 .753 r
.32379 .61725 m .32357 .61798 L .32289 .61617 L F
.32542 .61919 m .32289 .61617 L .32526 .61563 L F
.126 0 0 r
.32526 .61563 m .32289 .61617 L .32099 .61795 L F
.32435 .61545 m .32099 .61795 L .32396 .61538 L F
.32526 .61563 m .3241 .61626 L .32435 .61545 L F
.3241 .61626 m .32099 .61795 L .32435 .61545 L F
.11 .275 .753 r
.32542 .61919 m .32433 .61999 L .32357 .61798 L F
.32542 .61919 m .32357 .61798 L .32379 .61725 L F
.539 .269 .454 r
.32424 .62276 m .32772 .61988 L .32433 .61999 L F
0 0 .203 r
.32492 .62157 m .32433 .61999 L .32542 .61919 L F
.32492 .62157 m .32424 .62276 L .32433 .61999 L F
.239 0 .243 r
.5159 .50254 m .5153 .50518 L .51292 .50572 L F
.367 .054 .297 r
.51845 .50182 m .5153 .50518 L .5159 .50254 L F
.172 .358 .807 r
.45345 .57718 m .45064 .57469 L .45409 .57475 L F
.134 .001 .42 r
.45568 .57348 m .45518 .57541 L .45409 .57475 L F
.309 .036 .327 r
.45491 .5758 m .45409 .57475 L .45518 .57541 L F
.45491 .5758 m .45345 .57718 L .45409 .57475 L F
0 0 0 r
.6942 .29141 m .6933 .29316 L .69655 .28889 L F
.596 .447 .649 r
.23839 .60406 m .24317 .59832 L .23952 .60097 L F
.989 .764 .507 r
.41303 .48841 m .41289 .49051 L .41473 .48972 L F
0 0 .155 r
.34692 .61962 m .34752 .62131 L .34824 .61813 L F
.34692 .61962 m .34728 .6223 L .34752 .62131 L F
.461 .238 .489 r
.33775 .63887 m .3405 .63572 L .33728 .63668 L F
.567 .914 .704 r
.55567 .42628 m .5541 .42805 L .55628 .42619 L F
.566 .936 .821 r
.55224 .42845 m .5541 .42805 L .55567 .42628 L F
.153 .655 .909 r
.55367 .39433 m .55611 .39447 L .55167 .39342 L F
.958 .947 .665 r
.57108 .437 m .57092 .43807 L .57065 .437 L F
0 .187 .715 r
.57092 .43807 m .57172 .43743 L .57065 .437 L F
.278 0 0 r
.57028 .437 m .57065 .437 L .57172 .43743 L F
.56737 .43613 m .57065 .437 L .57028 .437 L F
.958 .947 .665 r
.57152 .43421 m .57108 .437 L .57065 .437 L F
0 .187 .715 r
.57092 .43807 m .57275 .43977 L .57172 .43743 L F
.748 .665 .769 r
.62438 .37833 m .62535 .38225 L .6214 .38239 L F
.382 0 0 r
.6214 .38239 m .62535 .38225 L .62422 .3831 L F
.6214 .38239 m .62422 .3831 L .62386 .38308 L F
0 0 0 r
.62131 .38302 m .61902 .38542 L .6214 .38239 L F
.773 .271 .008 r
.61863 .38161 m .6214 .38239 L .62131 .38302 L F
.382 0 0 r
.6214 .38239 m .62414 .38316 L .62131 .38302 L F
.457 .691 .967 r
.62104 .38287 m .6231 .3814 L .61905 .38175 L F
.62131 .38302 m .62145 .3829 L .62104 .38287 L F
.62145 .3829 m .6231 .3814 L .62104 .38287 L F
.382 0 0 r
.62386 .38308 m .62422 .3831 L .62414 .38316 L F
.008 .147 .661 r
.62629 .37998 m .62535 .38225 L .62438 .37833 L F
.761 .941 .604 r
.62414 .38316 m .62535 .38225 L .62629 .37998 L F
0 .26 .765 r
.62627 .38194 m .62535 .38225 L .62414 .38316 L F
.685 .946 .673 r
.46634 .55253 m .46834 .5511 L .46562 .55449 L F
.46634 .55253 m .46803 .55091 L .46834 .5511 L F
.502 .469 .753 r
.34894 .56136 m .35139 .56076 L .35115 .55822 L F
.022 .189 .698 r
.35583 .59001 m .35684 .5895 L .35463 .58742 L F
.539 .227 .387 r
.35463 .58742 m .35684 .5895 L .35377 .58975 L F
.93 .971 .719 r
.57431 .46019 m .57558 .45817 L .57633 .45652 L F
.658 .549 .719 r
.50426 .48232 m .50673 .47915 L .50425 .47994 L F
.971 .748 .545 r
.38955 .57289 m .39169 .5711 L .39023 .57006 L F
.38955 .57289 m .39137 .57389 L .39169 .5711 L F
.789 .56 .589 r
.34915 .59948 m .35249 .59644 L .35 .59563 L F
.894 .935 .562 r
.63394 .41027 m .63232 .41392 L .63256 .41485 L F
.89 .951 .601 r
.63232 .41392 m .63108 .41603 L .63256 .41485 L F
.605 .451 .646 r
.48707 .51241 m .48983 .51204 L .49027 .50877 L F
.433 .178 .426 r
.48727 .51492 m .48983 .51204 L .48707 .51241 L F
0 0 .313 r
.52462 .44042 m .52318 .43668 L .52305 .43551 L F
.776 .701 .78 r
.7208 .27402 m .72132 .27802 L .71742 .27758 L F
.432 .805 .993 r
.71742 .27758 m .72132 .27802 L .72046 .27708 L F
.786 .707 .777 r
.7208 .27402 m .72395 .2747 L .72132 .27802 L F
.562 .789 .984 r
.72132 .27802 m .72217 .27607 L .72046 .27708 L F
.545 .362 .583 r
.72132 .27802 m .72395 .2747 L .7243 .27741 L F
.562 .789 .984 r
.72132 .27802 m .7243 .27741 L .72217 .27607 L F
0 0 0 r
.61952 .34985 m .61831 .34976 L .62075 .34856 L F
.61952 .34985 m .61721 .3512 L .61831 .34976 L F
.62 .857 .988 r
.45458 .49396 m .45667 .49523 L .45345 .49622 L F
0 0 .157 r
.45423 .497 m .45345 .49622 L .45483 .49639 L F
.173 0 0 r
.45345 .49622 m .45667 .49523 L .45483 .49639 L F
0 0 .157 r
.45423 .497 m .45458 .49396 L .45345 .49622 L F
.915 .632 .492 r
.69136 .32686 m .68936 .3281 L .68916 .32594 L F
.69136 .32686 m .69146 .32945 L .68936 .3281 L F
.904 .729 .655 r
.32674 .61383 m .32726 .61659 L .32541 .61288 L F
.768 .692 .778 r
.32541 .61288 m .32726 .61659 L .32975 .61347 L F
.716 .936 .617 r
.32975 .61347 m .32726 .61659 L .32782 .61515 L F
.634 .078 0 r
.33132 .61966 m .32726 .61659 L .32772 .61988 L F
.33132 .61966 m .32988 .61906 L .32726 .61659 L F
0 .189 .718 r
.32726 .61659 m .32988 .61906 L .32782 .61515 L F
.006 .103 .616 r
.22382 .56405 m .22472 .56907 L .22557 .56622 L F
.308 .443 .834 r
.22472 .56907 m .22887 .57074 L .22557 .56622 L F
.411 .859 .893 r
.29544 .64258 m .29015 .64351 L .29338 .6443 L F
.132 0 0 r
.29774 .64215 m .29544 .64258 L .29338 .6443 L F
.789 .845 .894 r
.44895 .5763 m .44825 .58017 L .44625 .57943 L F
.44895 .5763 m .45135 .57834 L .44825 .58017 L F
.315 0 .16 r
.44825 .58017 m .45135 .57834 L .45036 .58003 L F
.933 .947 .612 r
.5507 .46609 m .5511 .46359 L .5478 .46602 L F
.859 .841 .826 r
.54831 .46886 m .5507 .46609 L .5478 .46602 L F
.8 .967 .911 r
.54283 .39995 m .53992 .40228 L .54211 .40253 L F
0 0 .426 r
.36163 .53658 m .36162 .53927 L .36069 .53938 L F
.127 0 .183 r
.55203 .42086 m .55453 .4201 L .55495 .41743 L F
.078 0 .169 r
.55495 .41743 m .55648 .41871 L .5573 .41624 L F
.55495 .41743 m .55453 .4201 L .55648 .41871 L F
.522 .917 .9 r
.43813 .44725 m .44184 .4463 L .43965 .44789 L F
.874 .74 .711 r
.43551 .55768 m .43657 .56113 L .43729 .55699 L F
.098 0 .105 r
.55371 .42194 m .55203 .42086 L .55101 .42234 L F
.55371 .42194 m .55453 .4201 L .55203 .42086 L F
.562 .424 .651 r
.34361 .55032 m .34598 .55108 L .3456 .54837 L F
.729 .423 .461 r
.34165 .55322 m .34598 .55108 L .34361 .55032 L F
.596 .938 .759 r
.37568 .49131 m .37756 .49056 L .37441 .49282 L F
.548 .827 .481 r
.37441 .49282 m .37295 .49443 L .37568 .49131 L F
.895 .985 .722 r
.27409 .58255 m .27331 .5852 L .27192 .58338 L F
.831 .673 .687 r
.27331 .5852 m .2731 .58711 L .27192 .58338 L F
.664 .134 0 r
.58934 .38899 m .58873 .38916 L .58756 .38823 L F
.58934 .38899 m .59126 .39125 L .58873 .38916 L F
0 0 0 r
.62629 .34013 m .62745 .33996 L .62899 .3393 L F
.62629 .34013 m .62515 .3414 L .62745 .33996 L F
.47761 .58035 m .47647 .58241 L .47641 .58433 L F
0 0 .233 r
.47647 .58241 m .47522 .58657 L .47641 .58433 L F
0 0 0 r
.65329 .32589 m .65561 .32531 L .65666 .32361 L F
.03 0 0 r
.65666 .32361 m .65825 .32413 L .65873 .32207 L F
.65666 .32361 m .65561 .32531 L .65825 .32413 L F
.81 .725 .771 r
.4201 .50483 m .42147 .50858 L .4184 .50778 L F
.756 .734 .832 r
.59829 .43121 m .5998 .43444 L .59626 .43359 L F
.814 .561 .556 r
.59626 .43359 m .5998 .43444 L .59941 .43693 L F
.307 .477 .865 r
.60115 .43245 m .5998 .43444 L .59829 .43121 L F
0 0 .155 r
.59941 .43693 m .5998 .43444 L .60115 .43245 L F
.269 .763 .904 r
.32437 .52847 m .32719 .52811 L .32836 .52839 L F
.32437 .52847 m .32719 .52811 L .32836 .52839 L F
.115 .656 .845 r
.33121 .52847 m .32719 .52811 L .32836 .52839 L F
.581 .904 .981 r
.55167 .41122 m .55382 .41152 L .55036 .41172 L F
.55167 .41122 m .55382 .41152 L .55036 .41172 L F
.878 .882 .833 r
.55635 .40824 m .55382 .41152 L .55167 .41122 L F
.532 .601 .868 r
.55371 .41414 m .55167 .41122 L .55382 .41152 L F
.11 .022 .465 r
.35505 .59338 m .35673 .58974 L .35583 .59001 L F
.35505 .59338 m .35686 .59229 L .35684 .5895 L F
.605 .389 .562 r
.35633 .59186 m .35391 .59284 L .35377 .58975 L F
.35686 .59229 m .35623 .59241 L .35633 .59186 L F
.35623 .59241 m .35391 .59284 L .35633 .59186 L F
.11 .022 .465 r
.35673 .58974 m .35684 .5895 L .35676 .58954 L F
.35673 .58974 m .35676 .58954 L .35583 .59001 L F
.021 0 .095 r
.2493 .52243 m .24821 .52481 L .25065 .52175 L F
.958 .676 .24 r
.43551 .55768 m .43559 .56009 L .43657 .56113 L F
.43551 .55768 m .43559 .56009 L .43657 .56113 L F
.885 .883 .452 r
.73122 .31487 m .73115 .31707 L .73223 .31371 L F
.844 .971 .878 r
.73223 .31371 m .73252 .31139 L .73221 .31265 L F
.73223 .31371 m .73552 .31055 L .73252 .31139 L F
.856 .889 .461 r
.73122 .31487 m .73223 .31371 L .73221 .31265 L F
.867 .421 .067 r
.36321 .51718 m .3635 .51554 L .36139 .51483 L F
.36321 .51718 m .36493 .51835 L .3635 .51554 L F
0 0 0 r
.66285 .38742 m .66666 .38526 L .66533 .38632 L F
.66533 .38632 m .66666 .38526 L .6692 .38422 L F
.972 .739 .527 r
.45064 .57469 m .45135 .57834 L .44895 .5763 L F
.685 .966 .933 r
.31794 .658 m .32184 .6568 L .32077 .65804 L F
0 0 0 r
.32184 .6568 m .32264 .65679 L .32077 .65804 L F
.32184 .6568 m .32481 .65656 L .32264 .65679 L F
.72 .923 .961 r
.45667 .44006 m .45469 .44286 L .45319 .44176 L F
.45667 .44006 m .45827 .44105 L .45469 .44286 L F
.7 .832 .946 r
.54501 .46846 m .54831 .46886 L .5478 .46602 L F
.432 0 0 r
.32431 .64181 m .32791 .64036 L .32677 .64127 L F
.882 .45 .146 r
.32791 .64036 m .32901 .64267 L .32677 .64127 L F
.549 .828 .482 r
.66569 .37092 m .66416 .37268 L .66574 .37083 L F
0 0 0 r
.66574 .37083 m .66416 .37268 L .66322 .37424 L F
.241 .757 .805 r
.60614 .34501 m .6099 .34441 L .60701 .34525 L F
.749 .993 .814 r
.51761 .40176 m .51453 .40444 L .51579 .40208 L F
.74 .965 .688 r
.51579 .40208 m .51453 .40444 L .51402 .4044 L F
.898 .808 .75 r
.61189 .42808 m .6143 .42505 L .6142 .42502 L F
.269 0 .188 r
.68497 .29755 m .68707 .29844 L .68745 .2966 L F
.68497 .29755 m .68443 .2995 L .68707 .29844 L F
.984 .719 .438 r
.38362 .47296 m .38353 .47618 L .38187 .47467 L F
.879 .869 .824 r
.38621 .47253 m .38187 .47467 L .38362 .47296 L F
0 0 0 r
.65299 .32647 m .65561 .32531 L .65329 .32589 L F
.504 .811 1 r
.56203 .43433 m .56441 .43322 L .56101 .42972 L F
.56203 .43433 m .56494 .43385 L .56441 .43322 L F
.311 0 0 r
.56203 .43433 m .56494 .43385 L .56478 .43502 L F
.56478 .43502 m .56494 .43385 L .56203 .43433 L F
.337 .818 .805 r
.65656 .33318 m .65399 .33409 L .65568 .33395 L F
.816 .844 .87 r
.35374 .63533 m .35598 .63712 L .35353 .63816 L F
.35374 .63533 m .35786 .63552 L .35598 .63712 L F
.883 .452 .08 r
.39063 .52252 m .3889 .52142 L .38758 .51846 L F
.832 .374 0 r
.39153 .52468 m .3889 .52142 L .39063 .52252 L F
.014 0 .362 r
.23534 .56033 m .23508 .56328 L .23331 .56404 L F
0 0 .014 r
.23508 .56328 m .23267 .56645 L .23331 .56404 L F
.851 .538 .458 r
.43447 .47333 m .43434 .47572 L .43766 .47619 L F
.843 .783 .794 r
.43434 .47572 m .4362 .47738 L .43766 .47619 L F
.551 .349 .561 r
.32365 .57108 m .32678 .571 L .32651 .56778 L F
.268 .145 .521 r
.32651 .56778 m .32851 .56925 L .329 .56729 L F
.32651 .56778 m .32678 .571 L .32851 .56925 L F
.447 0 0 r
.46722 .52877 m .46589 .52769 L .46318 .52548 L F
.798 .689 .745 r
.46408 .52996 m .46713 .53151 L .46496 .53414 L F
.508 .032 .059 r
.46453 .53207 m .4654 .53129 L .46408 .52996 L F
.991 .731 .389 r
.46713 .53151 m .4665 .52957 L .46722 .52877 L F
.784 .699 .77 r
.46408 .52996 m .46589 .52769 L .46713 .53151 L F
.508 .032 .059 r
.4654 .53129 m .46718 .52971 L .46636 .52978 L F
.4654 .53129 m .46636 .52978 L .46408 .52996 L F
.991 .731 .389 r
.4665 .52957 m .46589 .52769 L .46708 .52865 L F
.4665 .52957 m .46708 .52865 L .46722 .52877 L F
.551 .319 .517 r
.46722 .52877 m .46966 .53136 L .46713 .53151 L F
.741 .864 .937 r
.60712 .4059 m .60634 .40423 L .6055 .40696 L F
.60712 .4059 m .60964 .40475 L .60634 .40423 L F
.898 .673 .59 r
.52334 .42772 m .52479 .43119 L .52219 .43034 L F
.18 .574 .937 r
.52407 .43359 m .52219 .43034 L .52479 .43119 L F
.321 0 0 r
.52479 .43119 m .52568 .43204 L .52407 .43359 L F
.52479 .43119 m .52736 .43123 L .52568 .43204 L F
.105 0 .241 r
.34642 .59973 m .34381 .60297 L .34531 .60121 L F
0 0 0 r
.46338 .55815 m .463 .56076 L .46312 .56033 L F
.46359 .55634 m .46329 .55855 L .46338 .55815 L F
.46329 .55855 m .463 .56076 L .46338 .55815 L F
.565 .84 .497 r
.46109 .56002 m .46263 .55826 L .46296 .558 L F
.826 .709 .176 r
.46359 .55634 m .46344 .55761 L .46296 .558 L F
.46359 .55634 m .46296 .558 L .4643 .55609 L F
.759 .871 .445 r
.4636 .55703 m .46296 .558 L .4631 .55771 L F
.4643 .55609 m .46359 .5571 L .4636 .55703 L F
.46359 .5571 m .46296 .558 L .4636 .55703 L F
0 0 0 r
.46359 .55634 m .4643 .55609 L .46518 .5549 L F
.759 .871 .445 r
.4643 .55609 m .4631 .55771 L .46477 .55437 L F
0 .009 .573 r
.46406 .55319 m .46414 .55155 L .46508 .55159 L F
.46477 .55437 m .4645 .55344 L .46304 .55151 L F
0 0 .241 r
.46296 .558 m .4645 .55344 L .46477 .55437 L F
.46396 .55505 m .46425 .5564 L .4645 .55344 L F
.46296 .558 m .46386 .55689 L .46396 .55505 L F
.46386 .55689 m .46425 .5564 L .46396 .55505 L F
0 .009 .573 r
.46477 .55437 m .46406 .55319 L .46508 .55159 L F
.46406 .55319 m .46304 .55151 L .46414 .55155 L F
.565 .84 .497 r
.46263 .55826 m .46425 .5564 L .46296 .558 L F
.826 .709 .176 r
.46344 .55761 m .46338 .55815 L .46296 .558 L F
.46338 .55815 m .46312 .56033 L .46296 .558 L F
0 0 0 r
.46518 .5549 m .4643 .55609 L .46562 .55449 L F
.767 .905 .515 r
.46562 .55449 m .4643 .55609 L .46634 .55253 L F
.57 .504 .742 r
.24966 .53093 m .24705 .53462 L .24766 .53197 L F
.755 .326 .233 r
.72217 .27607 m .72395 .2747 L .7208 .27402 L F
.941 .647 .455 r
.7243 .27741 m .72395 .2747 L .72217 .27607 L F
.927 .649 .169 r
.72965 .30076 m .72985 .30316 L .72873 .29893 L F
.971 .686 .431 r
.45589 .46027 m .45606 .46339 L .454 .46163 L F
.479 .242 .476 r
.46577 .52705 m .46697 .52224 L .46318 .52548 L F
.344 .3 .664 r
.46318 .52548 m .46589 .52769 L .46577 .52705 L F
.701 .963 .942 r
.46991 .43388 m .46766 .43536 L .46526 .43528 L F
.375 .152 .443 r
.32564 .61015 m .32704 .6105 L .3282 .60687 L F
.768 .693 .781 r
.32541 .61288 m .32704 .6105 L .32564 .61015 L F
.916 .947 .6 r
.59042 .37131 m .59192 .3688 L .5878 .36851 L F
.75 .97 .698 r
.72513 .29674 m .72739 .29314 L .72811 .29325 L F
0 0 0 r
.72513 .29674 m .7245 .2981 L .72739 .29314 L F
.789 .56 .589 r
.34915 .59948 m .35021 .59984 L .35249 .59644 L F
0 0 .112 r
.35249 .59644 m .35434 .59558 L .35505 .59338 L F
0 0 0 r
.35249 .59644 m .35021 .59984 L .35434 .59558 L F
.716 .35 .355 r
.43195 .58433 m .43424 .5868 L .43585 .58524 L F
.708 .228 .108 r
.4368 .58756 m .43585 .58524 L .43424 .5868 L F
.4368 .58756 m .43845 .58699 L .43585 .58524 L F
.658 .181 0 r
.44215 .58184 m .44165 .58063 L .44013 .57953 L F
.622 .448 .626 r
.5638 .45671 m .56708 .45705 L .56628 .45382 L F
.493 .173 .352 r
.56816 .45525 m .5691 .45347 L .56628 .45382 L F
.269 .223 .62 r
.56628 .45382 m .56708 .45705 L .56816 .45525 L F
.493 .173 .352 r
.56816 .45525 m .5691 .45347 L .56628 .45382 L F
.247 .424 .841 r
.32855 .50109 m .3297 .50376 L .33016 .50116 L F
.693 .864 .963 r
.33016 .50116 m .3297 .50376 L .33172 .50243 L F
.208 .013 .382 r
.49443 .53157 m .49476 .53412 L .49212 .53523 L F
0 0 .219 r
.49476 .53412 m .49202 .53779 L .49212 .53523 L F
0 0 .366 r
.57298 .36914 m .57387 .36981 L .57294 .36719 L F
.57298 .36914 m .57385 .37206 L .57387 .36981 L F
.733 .911 .955 r
.34454 .55793 m .34516 .55556 L .34668 .55631 L F
.34454 .55793 m .34321 .55704 L .34516 .55556 L F
.082 .225 .713 r
.34516 .55556 m .34454 .55793 L .34321 .55704 L F
.34516 .55556 m .34763 .56235 L .34454 .55793 L F
.733 .911 .955 r
.34516 .55556 m .34321 .55704 L .34454 .55793 L F
.947 .934 .75 r
.59933 .3739 m .60218 .37198 L .60089 .37051 L F
.59933 .3739 m .60015 .37542 L .60218 .37198 L F
.886 .924 .842 r
.60089 .37051 m .60218 .37198 L .60485 .36881 L F
.914 .696 .594 r
.56992 .42962 m .57299 .42998 L .57152 .43421 L F
.861 .959 .62 r
.61646 .40996 m .61563 .41275 L .61775 .41112 L F
.492 .844 .994 r
.47191 .45751 m .47575 .45762 L .4741 .456 L F
.693 .812 .939 r
.47575 .45762 m .47672 .45475 L .4741 .456 L F
.47575 .45762 m .47823 .45642 L .47672 .45475 L F
.455 .352 .649 r
.47575 .45762 m .47827 .45939 L .47823 .45642 L F
.47575 .45762 m .47636 .4609 L .47827 .45939 L F
.265 0 0 r
.3364 .5562 m .34003 .55456 L .3375 .55519 L F
.886 .924 .842 r
.60089 .37051 m .60485 .36881 L .60382 .36745 L F
.496 .772 .993 r
.34716 .63172 m .35133 .63262 L .34957 .63219 L F
.663 .309 .363 r
.35133 .63262 m .34972 .63507 L .34957 .63219 L F
.35133 .63262 m .35374 .63533 L .34972 .63507 L F
.666 .309 .357 r
.35133 .63262 m .35429 .63314 L .35374 .63533 L F
.553 .68 .923 r
.2513 .58776 m .2536 .59085 L .25575 .58999 L F
.329 .087 .386 r
.25575 .58999 m .25295 .59429 L .2536 .59085 L F
.25575 .58999 m .25295 .59429 L .2536 .59085 L F
.495 0 0 r
.27344 .64309 m .2756 .64283 L .2712 .64249 L F
.692 .236 .164 r
.27465 .64448 m .2756 .64283 L .27344 .64309 L F
.27465 .64448 m .2778 .64491 L .2756 .64283 L F
.345 .293 .655 r
.47383 .53128 m .47261 .5354 L .47148 .53076 L F
.47383 .53128 m .47375 .5348 L .47261 .5354 L F
0 0 0 r
.47261 .5354 m .47375 .5348 L .47116 .53728 L F
.47261 .5354 m .47375 .5348 L .47116 .53728 L F
0 0 .485 r
.59042 .37131 m .59176 .37443 L .59038 .3723 L F
.041 0 .243 r
.35549 .52883 m .35489 .53134 L .35716 .52769 L F
0 0 0 r
.35429 .63314 m .35688 .62999 L .35618 .63233 L F
.73 .439 .486 r
.35688 .62999 m .36053 .63265 L .35618 .63233 L F
.077 0 0 r
.54461 .48494 m .54575 .48386 L .54839 .483 L F
.641 .868 .984 r
.64019 .39111 m .63795 .39238 L .63685 .39073 L F
.158 0 .254 r
.51466 .50694 m .51292 .50572 L .5153 .50518 L F
.51466 .50694 m .51264 .50826 L .51292 .50572 L F
.302 0 .204 r
.33116 .51227 m .3327 .51364 L .33264 .5106 L F
.33116 .51227 m .33072 .51487 L .3327 .51364 L F
.965 .766 .326 r
.45796 .58216 m .455 .58158 L .45426 .5822 L F
.501 .101 .215 r
.2731 .58711 m .27138 .58969 L .26882 .58961 L F
.666 .286 .316 r
.27544 .58945 m .27138 .58969 L .2731 .58711 L F
.67 .285 .308 r
.27617 .5878 m .27544 .58945 L .2731 .58711 L F
.767 .521 .562 r
.43293 .55802 m .4328 .56072 L .42857 .56052 L F
0 .239 .756 r
.43352 .55694 m .43293 .55802 L .43076 .55665 L F
.533 .275 .471 r
.43293 .55802 m .43559 .56009 L .43551 .55768 L F
0 .239 .756 r
.43352 .55694 m .43559 .56009 L .43293 .55802 L F
.344 .331 .701 r
.48098 .52309 m .48239 .52489 L .48283 .52242 L F
.377 .563 .908 r
.23186 .58882 m .23294 .59079 L .23399 .58891 L F
.187 .317 .765 r
.23294 .59079 m .23554 .59298 L .23399 .58891 L F
0 0 .317 r
.45237 .57104 m .45064 .57469 L .44922 .57346 L F
.989 .808 .568 r
.44922 .57346 m .45064 .57469 L .44895 .5763 L F
.51 .191 .363 r
.32365 .57108 m .32331 .57335 L .32678 .571 L F
.575 .583 .824 r
.50211 .47114 m .50389 .4684 L .50118 .46898 L F
.50211 .47114 m .50544 .47182 L .50389 .4684 L F
.878 .882 .833 r
.55635 .40824 m .55167 .41122 L .55479 .4066 L F
.802 .456 .402 r
.29259 .57414 m .29696 .57599 L .29714 .57375 L F
.29259 .57414 m .29248 .57642 L .29696 .57599 L F
.526 0 0 r
.29248 .57642 m .29484 .57768 L .29696 .57599 L F
0 0 0 r
.29696 .57599 m .29994 .57411 L .29714 .57375 L F
.29696 .57599 m .29895 .57524 L .29994 .57411 L F
.431 .003 .123 r
.29484 .57768 m .29895 .57524 L .29696 .57599 L F
.397 0 0 r
.23969 .59591 m .24397 .59686 L .24181 .59644 L F
.825 .795 .823 r
.4317 .47898 m .43373 .48037 L .4362 .47738 L F
.24 0 .004 r
.68745 .2966 m .69017 .29589 L .69085 .29416 L F
.313 0 .134 r
.69017 .29589 m .6933 .29316 L .69085 .29416 L F
.506 0 0 r
.56496 .45789 m .5638 .45671 L .56222 .45834 L F
.532 .908 .951 r
.56414 .45721 m .56496 .45789 L .56355 .45743 L F
.506 0 0 r
.56496 .45789 m .56572 .45853 L .5638 .45671 L F
.61 .31 .436 r
.56632 .45909 m .56708 .45705 L .5638 .45671 L F
.938 .897 .761 r
.56816 .45525 m .56496 .45789 L .56774 .45481 L F
0 0 0 r
.56669 .45625 m .56774 .45481 L .56496 .45789 L F
.532 .908 .951 r
.56669 .45625 m .56496 .45789 L .56414 .45721 L F
.506 0 0 r
.56496 .45789 m .56632 .45909 L .56572 .45853 L F
.896 .592 .462 r
.68897 .3234 m .68623 .32471 L .68568 .3228 L F
.68897 .3234 m .68916 .32594 L .68623 .32471 L F
0 0 0 r
.52 .42209 m .5169 .42541 L .51854 .42356 L F
.5191 .4231 m .52 .42209 L .51854 .42356 L F
.003 0 0 r
.52086 .42112 m .51853 .42404 L .52 .42209 L F
0 0 0 r
.5218 .42093 m .52 .42209 L .5191 .4231 L F
.003 0 0 r
.52128 .42059 m .52086 .42112 L .52 .42209 L F
0 0 0 r
.52347 .41711 m .52128 .42059 L .52327 .41956 L F
.52327 .41956 m .52128 .42059 L .52 .42209 L F
.877 .581 .484 r
.43076 .55665 m .42731 .5537 L .42918 .55445 L F
.973 .762 .558 r
.39905 .53526 m .39695 .53644 L .39674 .5342 L F
.902 .985 .77 r
.52006 .39807 m .51761 .40176 L .51761 .39819 L F
.91 .982 .741 r
.51761 .40176 m .51579 .40208 L .51761 .39819 L F
.418 .552 .883 r
.71283 .295 m .71222 .29666 L .71126 .29732 L F
.962 .64 .251 r
.55973 .37853 m .55867 .37959 L .5584 .37713 L F
.55 .747 .968 r
.56163 .37603 m .55973 .37853 L .5584 .37713 L F
.56163 .37603 m .56273 .37785 L .55973 .37853 L F
.627 .084 0 r
.55973 .37853 m .56257 .38058 L .55867 .37959 L F
.484 .28 .526 r
.56273 .37785 m .56257 .38058 L .55973 .37853 L F
.714 .611 .741 r
.32887 .56183 m .32915 .56452 L .33157 .56108 L F
.484 .309 .568 r
.32915 .56452 m .33158 .56397 L .33157 .56108 L F
.391 .198 .495 r
.32915 .56452 m .33121 .56648 L .33158 .56397 L F
.32915 .56452 m .329 .56729 L .33121 .56648 L F
.722 .974 .74 r
.50588 .40922 m .506 .40798 L .50832 .40794 L F
.50588 .40922 m .50427 .40996 L .506 .40798 L F
.621 .801 .968 r
.60988 .40814 m .60742 .40919 L .6055 .40696 L F
.566 .93 .931 r
.51377 .42044 m .51965 .4189 L .51603 .41899 L F
.776 .962 .926 r
.51603 .41899 m .51965 .4189 L .52053 .41762 L F
.345 0 0 r
.46812 .5935 m .46909 .59504 L .46654 .59507 L F
.077 .636 .79 r
.46909 .59504 m .46737 .59499 L .46654 .59507 L F
0 0 0 r
.46498 .59521 m .46812 .5935 L .46654 .59507 L F
.077 .636 .79 r
.46737 .59499 m .465 .59492 L .46654 .59507 L F
0 0 0 r
.46369 .59592 m .46498 .59521 L .46654 .59507 L F
.345 0 0 r
.46812 .5935 m .47061 .59333 L .46909 .59504 L F
.77 .28 .064 r
.43106 .58582 m .43424 .5868 L .43195 .58433 L F
.507 0 0 r
.34822 .51773 m .34415 .51796 L .3459 .51663 L F
.094 0 .175 r
.25216 .52798 m .24966 .53093 L .25031 .52893 L F
.851 .998 .807 r
.45749 .46719 m .46022 .46407 L .45794 .46472 L F
.761 .95 .939 r
.45749 .46719 m .45794 .46472 L .45498 .46685 L F
.74 .357 .326 r
.53962 .46035 m .53962 .46216 L .54099 .46019 L F
.489 0 0 r
.54213 .4617 m .54099 .46019 L .53962 .46216 L F
.54213 .4617 m .54397 .46068 L .54099 .46019 L F
.791 .992 .759 r
.22895 .57189 m .23035 .56939 L .23083 .57163 L F
.22895 .57189 m .22768 .57235 L .23035 .56939 L F
.452 .124 .318 r
.31489 .57978 m .31777 .57967 L .31844 .57748 L F
.576 .487 .717 r
.31844 .57748 m .32155 .57768 L .32075 .57442 L F
.526 .138 .248 r
.32005 .57933 m .31844 .57748 L .31777 .57967 L F
.91 .849 .398 r
.69908 .35748 m .70009 .35561 L .70035 .35506 L F
.863 .73 .714 r
.35618 .63233 m .35786 .63552 L .35374 .63533 L F
.709 .678 .818 r
.36053 .63265 m .35786 .63552 L .35618 .63233 L F
.773 .795 .871 r
.36053 .63265 m .36077 .63395 L .35786 .63552 L F
.291 .218 .599 r
.61505 .3687 m .61743 .36726 L .61602 .36601 L F
0 0 .026 r
.61505 .3687 m .61471 .3706 L .61743 .36726 L F
.092 0 0 r
.31741 .5339 m .31988 .53332 L .32198 .53167 L F
.432 .248 .53 r
.32198 .53167 m .32433 .53128 L .32437 .52847 L F
.44 .277 .563 r
.32198 .53167 m .32246 .5346 L .32433 .53128 L F
.875 .834 .803 r
.31988 .53332 m .32433 .53128 L .32198 .53167 L F
.432 .248 .53 r
.32198 .53167 m .32433 .53128 L .32437 .52847 L F
.988 .891 .571 r
.70177 .34882 m .70266 .34644 L .70106 .34745 L F
.959 .935 .613 r
.70106 .34745 m .70266 .34644 L .7025 .34325 L F
.848 .82 .822 r
.5882 .44967 m .58967 .44524 L .58711 .44878 L F
0 0 0 r
.52568 .43204 m .52736 .43123 L .53 .43043 L F
.275 .746 .941 r
.35648 .52117 m .35201 .5208 L .35363 .5217 L F
0 0 0 r
.57177 .45286 m .5721 .45277 L .5691 .45347 L F
.609 .954 .89 r
.57377 .45103 m .5721 .45277 L .57177 .45286 L F
.57377 .45103 m .57582 .45088 L .57333 .45215 L F
.815 .66 .69 r
.57275 .44511 m .57464 .45048 L .57088 .44787 L F
0 .209 .65 r
.57088 .44787 m .57412 .45011 L .57265 .44905 L F
.57412 .45011 m .57464 .45048 L .57412 .4501 L F
.57412 .45011 m .57412 .4501 L .57265 .44905 L F
.897 .777 .72 r
.57265 .44905 m .57464 .45048 L .57377 .45103 L F
0 0 0 r
.57422 .44995 m .57377 .45103 L .57294 .45337 L F
.57433 .44965 m .5742 .44999 L .57422 .44995 L F
.5742 .44999 m .57377 .45103 L .57422 .44995 L F
.476 0 0 r
.57418 .44826 m .5783 .44707 L .57692 .44862 L F
0 0 .302 r
.57424 .44172 m .57418 .44826 L .57275 .44511 L F
.6 .546 .766 r
.57692 .44862 m .57275 .44511 L .57418 .44826 L F
.57692 .44862 m .57464 .45048 L .57275 .44511 L F
0 0 0 r
.57444 .44937 m .57377 .45103 L .57433 .44965 L F
.609 .954 .89 r
.57377 .45103 m .57333 .45215 L .5721 .45277 L F
.578 .94 .909 r
.47944 .42839 m .47496 .42975 L .47794 .4271 L F
.729 .896 .955 r
.48154 .42686 m .47944 .42839 L .47794 .4271 L F
0 0 0 r
.33108 .60379 m .3282 .60687 L .32967 .60533 L F
.954 .797 .649 r
.33108 .60379 m .32967 .60533 L .32903 .60255 L F
.33108 .60379 m .32967 .60533 L .32903 .60255 L F
.028 0 .058 r
.3288 .51681 m .32982 .51741 L .33072 .51487 L F
.3288 .51681 m .32848 .5187 L .32982 .51741 L F
.852 .399 .008 r
.62906 .38419 m .62889 .38527 L .63092 .38347 L F
.946 .835 .702 r
.58864 .4403 m .59047 .43782 L .58863 .43644 L F
.58864 .4403 m .58966 .4407 L .59047 .43782 L F
.908 .781 .709 r
.58863 .43644 m .59047 .43782 L .58925 .43536 L F
.063 .505 .895 r
.61856 .42047 m .6171 .42019 L .61516 .41849 L F
.956 .703 .252 r
.59512 .39838 m .59436 .39977 L .59411 .3969 L F
.59512 .39838 m .59522 .401 L .59436 .39977 L F
.768 .693 .781 r
.32541 .61288 m .32975 .61347 L .32704 .6105 L F
0 .294 .787 r
.32704 .6105 m .32975 .61347 L .32893 .61172 L F
.983 .908 .603 r
.32975 .61347 m .32782 .61515 L .32893 .61172 L F
0 0 0 r
.3282 .60687 m .32808 .60737 L .32967 .60533 L F
.3282 .60687 m .32704 .6105 L .32808 .60737 L F
.34 0 0 r
.58536 .36806 m .58378 .36832 L .5878 .36851 L F
.867 .483 .002 r
.40784 .59086 m .40706 .59037 L .40715 .58842 L F
.40784 .59086 m .40872 .59355 L .40706 .59037 L F
.399 0 0 r
.58523 .35569 m .58085 .35588 L .58258 .35697 L F
.993 .851 .593 r
.3922 .58305 m .39139 .58668 L .39273 .58778 L F
.965 .921 .709 r
.39031 .58911 m .39273 .58778 L .39139 .58668 L F
.39031 .58911 m .39133 .5901 L .39273 .58778 L F
0 0 .097 r
.73129 .31888 m .73115 .31707 L .73122 .31487 L F
.461 .886 .808 r
.63098 .39484 m .62848 .39609 L .62749 .39599 L F
0 .246 .744 r
.33784 .54227 m .34039 .54409 L .33898 .54232 L F
.739 .946 .63 r
.311 .51989 m .30967 .52215 L .31228 .51884 L F
.673 .84 .963 r
.311 .51989 m .30619 .52146 L .30967 .52215 L F
.633 .623 .823 r
.41535 .46096 m .418 .4603 L .41634 .45705 L F
.608 .496 .701 r
.41535 .46096 m .41562 .46353 L .418 .4603 L F
.676 .668 .835 r
.40483 .46029 m .40594 .45586 L .40419 .45857 L F
.781 .277 0 r
.39616 .53248 m .39497 .53284 L .39337 .53061 L F
.834 .363 .005 r
.39616 .53248 m .39674 .5342 L .39497 .53284 L F
.971 .683 .42 r
.38918 .56644 m .39081 .56445 L .38886 .56342 L F
.38918 .56644 m .39087 .5673 L .39081 .56445 L F
.492 .238 .457 r
.4227 .48266 m .42509 .48215 L .42483 .47961 L F
.703 .39 .445 r
.42483 .47961 m .42509 .48215 L .42914 .48228 L F
.593 .575 .803 r
.42132 .48957 m .42256 .48513 L .4206 .48567 L F
.42132 .48957 m .42397 .4897 L .42256 .48513 L F
.48 .01 .061 r
.42397 .4897 m .42268 .49038 L .42132 .48957 L F
.42397 .4897 m .42268 .49038 L .42132 .48957 L F
.707 .985 .877 r
.52721 .41527 m .52794 .41327 L .52983 .41421 L F
.52721 .41527 m .52542 .41525 L .52794 .41327 L F
.497 .197 .387 r
.49625 .4925 m .49817 .49204 L .49952 .48986 L F
.572 .393 .6 r
.49952 .48986 m .50245 .48942 L .50248 .48643 L F
.713 .565 .686 r
.49817 .49204 m .50245 .48942 L .49952 .48986 L F
.406 .856 .797 r
.37767 .48999 m .37756 .49056 L .37568 .49131 L F
.37767 .48999 m .3801 .48943 L .37756 .49056 L F
.702 .744 .236 r
.47968 .57368 m .48048 .57118 L .48098 .56933 L F
.464 .235 .481 r
.28467 .58297 m .28172 .58621 L .28181 .58261 L F
.756 .704 .802 r
.3478 .57391 m .35155 .5743 L .34965 .57098 L F
.208 .416 .846 r
.34965 .57098 m .35155 .5743 L .35258 .57271 L F
.638 .957 .928 r
.35258 .57271 m .34999 .57433 L .35155 .5743 L F
.957 .699 .503 r
.35155 .5743 m .35178 .5772 L .34999 .57433 L F
.941 .629 .418 r
.40142 .54438 m .39928 .541 L .40088 .54197 L F
.546 .072 .081 r
.36401 .53636 m .36163 .53658 L .36385 .53489 L F
.083 0 .41 r
.3181 .62309 m .31961 .62447 L .32094 .62296 L F
.3181 .62309 m .31819 .62623 L .31961 .62447 L F
.808 .938 .914 r
.36503 .63405 m .36504 .63743 L .36776 .6342 L F
.928 .927 .557 r
.36416 .63838 m .36504 .63743 L .36503 .63405 L F
.169 0 0 r
.62102 .39329 m .62294 .39342 L .62089 .39396 L F
.473 .885 .762 r
.62641 .36106 m .63038 .35927 L .62914 .36045 L F
.704 .974 .761 r
.63177 .35712 m .63038 .35927 L .63358 .35641 L F
.651 .887 .538 r
.62914 .36045 m .63038 .35927 L .63177 .35712 L F
.711 .378 .412 r
.38402 .4791 m .3873 .47949 L .38571 .47783 L F
.886 .691 .634 r
.38402 .4791 m .38571 .47783 L .38353 .47618 L F
.601 .326 .472 r
.30417 .57712 m .30077 .57963 L .30161 .57806 L F
.449 .025 .142 r
.39755 .45984 m .39657 .46192 L .39405 .46088 L F
.421 .148 .391 r
.39963 .459 m .39657 .46192 L .39755 .45984 L F
.906 .498 .19 r
.34996 .50197 m .35131 .50524 L .35325 .50614 L F
.751 .237 0 r
.35131 .50524 m .35387 .50746 L .35325 .50614 L F
.529 0 0 r
.41542 .45462 m .41429 .45325 L .41277 .45306 L F
.12 .67 .733 r
.41831 .45267 m .41887 .45266 L .41429 .45325 L F
.41831 .45267 m .41429 .45325 L .41542 .45462 L F
.75 .554 .63 r
.24705 .53462 m .24824 .53899 L .24461 .53786 L F
.57 .504 .742 r
.24966 .53093 m .25017 .53446 L .24705 .53462 L F
.237 .233 .651 r
.25003 .53735 m .24705 .53462 L .25017 .53446 L F
.25003 .53735 m .24824 .53899 L .24705 .53462 L F
.934 .564 .273 r
.4215 .56873 m .42347 .56795 L .42236 .56622 L F
.4215 .56873 m .42592 .57323 L .42347 .56795 L F
.421 0 0 r
.72464 .31246 m .72899 .3114 L .72717 .30842 L F
.72464 .31246 m .72843 .3125 L .72899 .3114 L F
0 0 0 r
.72899 .3114 m .73034 .31071 L .7312 .3098 L F
.72899 .3114 m .72843 .3125 L .73034 .31071 L F
.896 .621 .512 r
.37637 .53489 m .37631 .53754 L .37878 .53808 L F
.874 .544 .422 r
.37651 .53992 m .37878 .53808 L .37631 .53754 L F
.37651 .53992 m .37977 .54159 L .37878 .53808 L F
.276 0 0 r
.24255 .58787 m .24082 .58962 L .23834 .58997 L F
.435 0 .049 r
.2452 .58816 m .24255 .58787 L .24507 .58771 L F
.2452 .58816 m .24082 .58962 L .24255 .58787 L F
.428 .619 .931 r
.25952 .62848 m .26165 .62982 L .26076 .62762 L F
0 .225 .645 r
.26162 .62871 m .26273 .62924 L .26237 .62904 L F
0 .155 .687 r
.26111 .62848 m .26162 .62871 L .26076 .62762 L F
.428 .619 .931 r
.25952 .62848 m .26076 .62762 L .25763 .62819 L F
.313 .797 .893 r
.25763 .62819 m .26076 .62762 L .25808 .62752 L F
.633 .085 0 r
.25808 .62752 m .26076 .62762 L .26162 .62871 L F
.782 .405 .342 r
.26162 .62871 m .26071 .62603 L .25808 .62752 L F
0 .361 .704 r
.26373 .62729 m .26071 .62603 L .26162 .62871 L F
.617 .831 .982 r
.26296 .6264 m .26162 .62871 L .2602 .6278 L F
0 .225 .645 r
.26162 .62871 m .26237 .62904 L .2602 .6278 L F
0 .155 .687 r
.26165 .62982 m .26162 .62871 L .26111 .62848 L F
.26165 .62982 m .26401 .63194 L .26162 .62871 L F
.506 .909 .819 r
.49073 .42087 m .4865 .42256 L .48985 .42023 L F
.809 .993 .871 r
.49411 .41782 m .49073 .42087 L .49138 .41841 L F
.807 .993 .873 r
.49073 .42087 m .48985 .42023 L .49138 .41841 L F
.541 .079 .106 r
.59821 .35188 m .59678 .3536 L .59423 .35258 L F
0 0 0 r
.59821 .35188 m .59955 .35128 L .59678 .3536 L F
.796 .839 .884 r
.60634 .40423 m .60964 .40475 L .6084 .40275 L F
.692 .929 .968 r
.60964 .40475 m .61094 .40225 L .6084 .40275 L F
.60964 .40475 m .6122 .4034 L .61094 .40225 L F
.757 .464 .487 r
.61357 .40741 m .60964 .40475 L .60988 .40814 L F
0 .155 .689 r
.69928 .28903 m .70089 .29376 L .69957 .29094 L F
.502 .608 .89 r
.70117 .28864 m .70089 .29376 L .69928 .28903 L F
.70117 .28864 m .70325 .2926 L .70089 .29376 L F
.621 .655 .862 r
.7041 .29416 m .70089 .29376 L .70325 .2926 L F
.475 0 0 r
.70602 .29959 m .70424 .29871 L .70173 .29707 L F
.823 .73 .763 r
.70602 .29959 m .70165 .29974 L .70424 .29871 L F
.70602 .29959 m .70312 .30376 L .70165 .29974 L F
.389 .771 .991 r
.70424 .29871 m .70803 .29927 L .70602 .29959 L F
.70424 .29871 m .70803 .29927 L .70602 .29959 L F
.479 .496 .798 r
.3631 .62933 m .35975 .62632 L .36211 .6257 L F
.742 .507 .574 r
.56014 .39508 m .55593 .39726 L .55611 .39447 L F
.56014 .39508 m .56142 .3977 L .55593 .39726 L F
.325 .315 .694 r
.56279 .39695 m .56142 .3977 L .56014 .39508 L F
.985 .721 .439 r
.59815 .41138 m .59655 .41273 L .59615 .41029 L F
.59815 .41138 m .59812 .414 L .59655 .41273 L F
.872 .955 .61 r
.47495 .53484 m .47288 .53857 L .47312 .53714 L F
.584 .418 .623 r
.47312 .53714 m .47754 .53252 L .47495 .53484 L F
.784 .672 .741 r
.72985 .30316 m .73376 .30428 L .73214 .30754 L F
.534 .227 .394 r
.73376 .30428 m .73661 .30568 L .73516 .30383 L F
.73376 .30428 m .73661 .30568 L .73516 .30383 L F
.356 0 0 r
.34546 .49914 m .34123 .49731 L .34352 .49878 L F
.757 .241 0 r
.34541 .50084 m .34546 .49914 L .34352 .49878 L F
.34541 .50084 m .34754 .50164 L .34546 .49914 L F
.978 .829 .426 r
.40691 .56766 m .40621 .56653 L .40673 .56388 L F
.995 .822 .46 r
.40691 .56766 m .40553 .56904 L .40621 .56653 L F
.40691 .56766 m .4065 .56986 L .40553 .56904 L F
.56 .101 .12 r
.54765 .41773 m .54705 .41947 L .54473 .4186 L F
0 0 0 r
.54967 .41615 m .54705 .41947 L .54765 .41773 L F
.784 .672 .741 r
.72985 .30316 m .73214 .30754 L .72994 .30568 L F
.098 .25 .732 r
.7312 .3098 m .72994 .30568 L .73214 .30754 L F
.57 .81 .989 r
.43406 .5754 m .43297 .57818 L .43331 .57521 L F
.43406 .5754 m .43588 .57704 L .43297 .57818 L F
.274 0 .24 r
.43588 .57704 m .43301 .57979 L .43297 .57818 L F
.403 0 0 r
.4414 .59662 m .43962 .59837 L .43762 .59754 L F
0 0 0 r
.44404 .59661 m .43962 .59837 L .4414 .59662 L F
.6 .455 .656 r
.48417 .51815 m .48727 .51492 L .48493 .51626 L F
.708 .984 .887 r
.57776 .44927 m .57582 .45088 L .57377 .45103 L F
0 0 0 r
.68038 .37695 m .68149 .37596 L .68434 .37511 L F
.318 .154 .495 r
.48983 .51204 m .49221 .50825 L .49027 .50877 L F
.945 .633 .412 r
.31174 .58082 m .31349 .58406 L .31116 .58283 L F
.979 .761 .538 r
.31349 .58406 m .31085 .5851 L .31116 .58283 L F
.31349 .58406 m .31317 .58662 L .31085 .5851 L F
.889 .922 .838 r
.73456 .30893 m .73552 .31055 L .73806 .30721 L F
.9 .922 .825 r
.73252 .31139 m .73552 .31055 L .73456 .30893 L F
.675 .891 .976 r
.47724 .46464 m .47791 .4622 L .47538 .46277 L F
.47724 .46464 m .4797 .46344 L .47791 .4622 L F
.644 .894 .984 r
.48206 .46223 m .48649 .46219 L .48454 .46084 L F
.687 .907 .973 r
.48454 .46084 m .48649 .46219 L .48915 .46029 L F
0 0 0 r
.57158 .46358 m .57431 .46019 L .57342 .46205 L F
.09 0 .281 r
.57601 .45898 m .57431 .46019 L .57633 .45652 L F
0 0 0 r
.57342 .46205 m .57431 .46019 L .57601 .45898 L F
.695 .982 .829 r
.45794 .46472 m .46022 .46407 L .46201 .46232 L F
.699 .489 .6 r
.31987 .60035 m .32384 .60098 L .32232 .59987 L F
.31987 .60035 m .31996 .60315 L .32384 .60098 L F
.42 .823 .617 r
.57633 .45652 m .57973 .45426 L .57835 .45509 L F
0 0 .22 r
.57601 .45898 m .57633 .45652 L .57835 .45509 L F
.676 .668 .835 r
.40483 .46029 m .40743 .45967 L .40594 .45586 L F
.796 .894 .914 r
.40457 .46293 m .40743 .45967 L .40483 .46029 L F
0 0 0 r
.47761 .58035 m .47782 .58002 L .47647 .58241 L F
.01 0 .347 r
.44585 .46358 m .44761 .46198 L .44729 .45863 L F
.546 .381 .609 r
.44729 .45863 m .45027 .45657 L .44747 .45646 L F
.44729 .45863 m .45055 .45963 L .45027 .45657 L F
.762 .56 .624 r
.44761 .46198 m .45055 .45963 L .44729 .45863 L F
.285 0 0 r
.3083 .5201 m .311 .51989 L .31228 .51884 L F
.085 .448 .881 r
.2518 .60084 m .25236 .59955 L .25095 .59877 L F
.2518 .60084 m .25385 .60124 L .25236 .59955 L F
0 0 .349 r
.5725 .46271 m .57158 .46358 L .57342 .46205 L F
.965 .691 .465 r
.58647 .44098 m .58966 .4407 L .58864 .4403 L F
.58647 .44098 m .58994 .44355 L .58966 .4407 L F
.643 .558 .744 r
.70413 .31255 m .70269 .31418 L .70094 .30946 L F
.101 0 .214 r
.70413 .31255 m .70193 .31615 L .70269 .31418 L F
.294 0 0 r
.55733 .38764 m .55999 .38744 L .56167 .3859 L F
.065 0 0 r
.56167 .3859 m .56263 .38613 L .56342 .38428 L F
.56167 .3859 m .55999 .38744 L .56263 .38613 L F
.639 .503 .681 r
.60951 .35975 m .61039 .36201 L .61314 .35888 L F
.735 .849 .934 r
.53837 .47174 m .53985 .47323 L .54267 .4714 L F
.595 .132 .124 r
.53837 .47174 m .54267 .4714 L .53985 .47323 L F
.913 .598 .433 r
.37085 .52519 m .37103 .52763 L .37324 .5285 L F
.94 .604 .365 r
.37174 .5299 m .37324 .5285 L .37103 .52763 L F
.37174 .5299 m .3742 .53167 L .37324 .5285 L F
.186 .344 .791 r
.24315 .55285 m .24204 .55466 L .2404 .55085 L F
0 0 0 r
.24315 .55285 m .24112 .55685 L .24204 .55466 L F
0 0 .517 r
.38366 .48249 m .38511 .48519 L .3841 .4825 L F
.526 .182 .326 r
.42658 .59935 m .42421 .59754 L .42787 .59617 L F
.564 .446 .677 r
.4306 .59267 m .43062 .5957 L .42787 .59617 L F
.357 .019 .249 r
.42881 .59893 m .42787 .59617 L .43062 .5957 L F
.13 0 0 r
.42881 .59893 m .43306 .5981 L .43164 .59884 L F
.269 .705 .964 r
.43143 .5988 m .42881 .59893 L .43164 .59884 L F
.357 .019 .249 r
.42881 .59893 m .4267 .59904 L .42787 .59617 L F
.702 .357 .39 r
.43062 .5957 m .43306 .5981 L .42881 .59893 L F
.269 .705 .964 r
.42735 .59798 m .42881 .59893 L .43143 .5988 L F
.357 .019 .249 r
.42881 .59893 m .42658 .59935 L .4267 .59904 L F
.678 .945 .676 r
.33788 .61995 m .33495 .62287 L .33564 .62141 L F
.781 .973 .687 r
.33836 .61815 m .33788 .61995 L .33564 .62141 L F
.242 0 0 r
.27089 .51543 m .26855 .5168 L .27126 .51651 L F
.794 .995 .871 r
.27126 .51651 m .27014 .51618 L .2702 .51611 L F
.242 0 0 r
.27089 .51543 m .27126 .51651 L .27246 .51697 L F
.62 .073 0 r
.27089 .51543 m .27126 .51651 L .27306 .51757 L F
.794 .995 .871 r
.27126 .51651 m .2702 .51611 L .27162 .51447 L F
.242 0 0 r
.27246 .51697 m .27126 .51651 L .27306 .51757 L F
0 0 0 r
.53187 .40713 m .53513 .40584 L .53418 .40649 L F
.573 .328 .506 r
.53418 .40649 m .53093 .40944 L .53187 .40713 L F
.455 .244 .503 r
.46577 .52705 m .46914 .52076 L .46697 .52224 L F
.622 .471 .655 r
.50658 .47646 m .50906 .47618 L .50921 .47302 L F
.747 .609 .705 r
.50673 .47915 m .50906 .47618 L .50658 .47646 L F
.529 .623 .89 r
.59564 .35669 m .59884 .35641 L .59678 .3536 L F
0 0 0 r
.5414 .48785 m .54252 .486 L .54461 .48494 L F
.814 .981 .697 r
.6345 .35374 m .63358 .35641 L .63603 .35318 L F
.815 .993 .75 r
.63177 .35712 m .63358 .35641 L .6345 .35374 L F
0 0 .045 r
.48948 .54381 m .4877 .54761 L .48832 .54548 L F
.601 .416 .604 r
.50248 .48643 m .50522 .4888 L .50515 .48605 L F
.50248 .48643 m .50245 .48942 L .50522 .4888 L F
.528 .808 .997 r
.45726 .57734 m .46 .57702 L .4592 .57454 L F
.491 .859 .628 r
.66392 .32886 m .66724 .32647 L .66598 .32734 L F
0 0 0 r
.66887 .32653 m .66724 .32647 L .66991 .32505 L F
.66887 .32653 m .66598 .32734 L .66724 .32647 L F
.458 .444 .755 r
.49378 .49608 m .49459 .49948 L .49706 .49904 L F
.452 .41 .72 r
.49459 .49948 m .4975 .50155 L .49706 .49904 L F
.512 .402 .665 r
.49495 .50156 m .4975 .50155 L .49459 .49948 L F
.878 .858 .817 r
.56573 .40617 m .56525 .41054 L .56304 .41043 L F
.451 .789 .998 r
.56317 .41347 m .56304 .41043 L .56525 .41054 L F
.626 .633 .838 r
.56827 .40668 m .56525 .41054 L .56573 .40617 L F
0 .025 .541 r
.62373 .36961 m .62182 .36919 L .62362 .36712 L F
.62373 .36961 m .62244 .37167 L .62182 .36919 L F
.337 .069 .351 r
.28265 .6033 m .28063 .60487 L .27995 .60642 L F
.825 .795 .823 r
.4317 .47898 m .4362 .47738 L .43434 .47572 L F
.157 0 .077 r
.54322 .44314 m .53993 .44694 L .54311 .44598 L F
0 0 0 r
.54494 .44251 m .5463 .44095 L .54322 .44314 L F
.627 .564 .763 r
.54311 .44598 m .54494 .44251 L .54322 .44314 L F
0 0 0 r
.24242 .54767 m .24157 .54849 L .24317 .5455 L F
.439 .318 .618 r
.24242 .54767 m .2404 .55085 L .24157 .54849 L F
.748 .252 .052 r
.59161 .35303 m .59026 .35398 L .58777 .35119 L F
.465 0 0 r
.59555 .35369 m .59161 .35303 L .59423 .35258 L F
.136 0 0 r
.57835 .45509 m .57973 .45426 L .58191 .45432 L F
.162 0 0 r
.57973 .45426 m .58289 .45384 L .58191 .45432 L F
.922 .685 .562 r
.38275 .60875 m .38534 .6064 L .38413 .60606 L F
.38275 .60875 m .38465 .60913 L .38534 .6064 L F
.827 .93 .9 r
.38534 .6064 m .38737 .60265 L .38643 .60505 L F
.38534 .6064 m .38643 .60505 L .38413 .60606 L F
.941 .955 .65 r
.29037 .57426 m .28836 .57788 L .28833 .57576 L F
.688 .213 .118 r
.28833 .57576 m .29248 .57642 L .29037 .57426 L F
.565 .251 .395 r
.29037 .57426 m .29248 .57642 L .29259 .57414 L F
.704 .172 0 r
.35733 .50936 m .35914 .51146 L .361 .51246 L F
.943 .585 .294 r
.35914 .51146 m .36139 .51483 L .361 .51246 L F
.623 .907 .984 r
.53411 .44967 m .53164 .45085 L .52969 .45033 L F
.653 .162 .073 r
.41337 .48344 m .41155 .4846 L .41489 .48471 L F
.863 .73 .714 r
.35618 .63233 m .35374 .63533 L .35429 .63314 L F
.269 .035 .363 r
.50256 .51897 m .50217 .52136 L .50004 .52227 L F
0 0 .101 r
.50217 .52136 m .4997 .52479 L .50004 .52227 L F
.724 .736 .86 r
.4082 .49497 m .41189 .49532 L .41038 .49194 L F
.762 .639 .726 r
.4082 .49497 m .40941 .49857 L .41189 .49532 L F
.797 .768 .827 r
.41038 .49194 m .41189 .49532 L .41441 .49208 L F
.677 .947 .685 r
.33564 .62141 m .33495 .62287 L .33194 .62499 L F
.377 0 .145 r
.59515 .36861 m .59042 .37131 L .59083 .36778 L F
.59515 .36861 m .59432 .37066 L .59042 .37131 L F
.487 .452 .744 r
.59675 .36497 m .59515 .36861 L .5942 .36607 L F
.59675 .36497 m .59792 .36764 L .59515 .36861 L F
.69 .794 .929 r
.59515 .36861 m .59824 .36803 L .59792 .36764 L F
.441 .863 .945 r
.59515 .36861 m .59792 .36764 L .59824 .36803 L F
.429 .108 .317 r
.59792 .36764 m .59432 .37066 L .59515 .36861 L F
.59792 .36764 m .59432 .37066 L .59515 .36861 L F
.519 0 0 r
.51761 .39819 m .52264 .39803 L .52006 .39807 L F
.73 .946 .634 r
.3327 .51364 m .33619 .50966 L .33264 .5106 L F
.97 .792 .607 r
.73885 .29988 m .73956 .29677 L .73782 .29583 L F
.828 .68 .7 r
.51893 .41339 m .52374 .41554 L .52369 .41197 L F
.403 .018 .19 r
.52053 .41762 m .52347 .41711 L .52374 .41554 L F
0 0 0 r
.33194 .61895 m .33132 .61966 L .33342 .61641 L F
.653 .192 .146 r
.33342 .61641 m .33571 .61859 L .33194 .61895 L F
.994 .765 .475 r
.40798 .58395 m .40776 .58668 L .40655 .58298 L F
.329 .152 .482 r
.4206 .48567 m .42256 .48513 L .4227 .48266 L F
.691 .416 .502 r
.24984 .58597 m .25242 .58366 L .24992 .58286 L F
.24984 .58597 m .25356 .58449 L .25242 .58366 L F
.984 .853 .475 r
.57692 .44862 m .5783 .44707 L .57776 .44927 L F
.57692 .44862 m .5783 .44707 L .57776 .44927 L F
.97 .845 .662 r
.7247 .30735 m .72355 .30626 L .72442 .30014 L F
.568 .196 .295 r
.72764 .30714 m .72717 .30842 L .7247 .30735 L F
.358 .311 .668 r
.44585 .46358 m .44853 .46622 L .44646 .46617 L F
.05 0 .407 r
.44738 .46337 m .44585 .46358 L .44646 .46617 L F
.44738 .46337 m .44761 .46198 L .44585 .46358 L F
0 0 .074 r
.23723 .53475 m .23902 .53419 L .23979 .53151 L F
0 0 0 r
.23811 .53461 m .23723 .53475 L .23621 .5352 L F
.23811 .53461 m .23902 .53419 L .23723 .53475 L F
.863 .93 .547 r
.73723 .29813 m .73516 .30383 L .73885 .29988 L F
.73723 .29813 m .73545 .30169 L .73516 .30383 L F
0 .057 .613 r
.73545 .30169 m .73661 .30568 L .73516 .30383 L F
.859 .554 .027 r
.40387 .49376 m .4041 .4972 L .40546 .49961 L F
.852 .408 .151 r
.40198 .49601 m .4041 .4972 L .40387 .49376 L F
.81 .668 .706 r
.70534 .31031 m .70413 .31255 L .70268 .30962 L F
.923 .701 .584 r
.40645 .58014 m .40462 .57639 L .40677 .57746 L F
0 .549 .783 r
.41876 .51456 m .42188 .51499 L .42427 .51556 L F
.045 0 .422 r
.42427 .51556 m .42555 .51454 L .4255 .51179 L F
.931 .966 .681 r
.42357 .51589 m .42427 .51556 L .42188 .51499 L F
.42357 .51589 m .42555 .51454 L .42427 .51556 L F
.198 .327 .77 r
.39405 .46088 m .39502 .45815 L .39291 .45944 L F
.39405 .46088 m .39657 .46192 L .39502 .45815 L F
.617 .937 .722 r
.64168 .40023 m .64515 .39781 L .64356 .39875 L F
.536 .917 .781 r
.64515 .39781 m .64871 .39571 L .64702 .39618 L F
.502 .87 .645 r
.64356 .39875 m .64515 .39781 L .64702 .39618 L F
.454 0 0 r
.52293 .39806 m .52387 .39857 L .52552 .39832 L F
.52264 .39803 m .52288 .39814 L .52293 .39806 L F
.52288 .39814 m .52387 .39857 L .52293 .39806 L F
.459 0 0 r
.52145 .39905 m .52231 .39905 L .52264 .39803 L F
.52229 .3991 m .5255 .3993 L .52288 .39814 L F
.52229 .3991 m .52288 .39814 L .52264 .39803 L F
0 0 0 r
.52397 .39758 m .52232 .39905 L .52145 .39905 L F
.905 .784 .716 r
.5198 .40097 m .5233 .40247 L .52168 .39947 L F
.52013 .40059 m .52168 .39947 L .52145 .39905 L F
.5198 .40097 m .52168 .39947 L .52013 .40059 L F
0 0 0 r
.52397 .39758 m .52372 .39799 L .52343 .3982 L F
.519 0 0 r
.51761 .39819 m .52145 .39905 L .52264 .39803 L F
.942 .705 .551 r
.52397 .39758 m .52167 .39892 L .51987 .39477 L F
.52397 .39758 m .51987 .39477 L .52301 .39432 L F
0 0 0 r
.5254 .39374 m .52397 .39758 L .52301 .39432 L F
.621 .801 .373 r
.52483 .396 m .52272 .39958 L .52346 .3984 L F
.52436 .39686 m .52346 .3984 L .52397 .39758 L F
0 0 0 r
.5254 .39374 m .52483 .396 L .52397 .39758 L F
.621 .801 .373 r
.52483 .396 m .52346 .3984 L .52436 .39686 L F
.307 .152 .501 r
.5233 .40247 m .5255 .3993 L .52302 .39914 L F
.52255 .39995 m .52302 .39914 L .52229 .3991 L F
.5233 .40247 m .52302 .39914 L .52255 .39995 L F
0 0 0 r
.52232 .39905 m .52221 .39915 L .52145 .39905 L F
.307 .152 .501 r
.52168 .39947 m .52221 .39915 L .52145 .39905 L F
0 0 0 r
.52221 .39915 m .52068 .40051 L .52145 .39905 L F
.307 .152 .501 r
.52221 .39915 m .52229 .3991 L .52145 .39905 L F
.5233 .40247 m .52229 .3991 L .52168 .39947 L F
0 0 0 r
.52302 .39866 m .52272 .39958 L .52187 .39997 L F
.52343 .3982 m .52326 .39851 L .52302 .39866 L F
.52326 .39851 m .52272 .39958 L .52302 .39866 L F
.52372 .39799 m .52272 .39958 L .52343 .3982 L F
.459 0 0 r
.52145 .39905 m .52229 .3991 L .52231 .39905 L F
0 0 0 r
.52243 .39895 m .52187 .39997 L .52171 .40004 L F
.52232 .39905 m .52171 .40004 L .52068 .40051 L F
.52243 .39895 m .52171 .40004 L .52232 .39905 L F
.52397 .39758 m .52187 .39997 L .52243 .39895 L F
.942 .705 .551 r
.52167 .39892 m .52145 .39905 L .52142 .39896 L F
.52167 .39892 m .52142 .39896 L .51987 .39477 L F
.454 0 0 r
.52552 .39832 m .5255 .3993 L .52698 .39847 L F
.52387 .39857 m .5255 .3993 L .52552 .39832 L F
0 .144 .688 r
.52986 .4381 m .52886 .43851 L .52742 .43929 L F
.52986 .4381 m .53106 .44064 L .52886 .43851 L F
.498 .172 .346 r
.27857 .5871 m .27544 .58945 L .27617 .5878 L F
.65 .136 .008 r
.39395 .48155 m .3924 .48012 L .39006 .48102 L F
.263 .205 .602 r
.39447 .47963 m .3924 .48012 L .39395 .48155 L F
.743 .343 .294 r
.36087 .52169 m .35829 .5235 L .35648 .52117 L F
.935 .694 .548 r
.36087 .52169 m .36049 .52471 L .35829 .5235 L F
0 .495 .803 r
.71724 .3264 m .71802 .32699 L .72086 .32756 L F
.433 .642 .945 r
.2944 .65471 m .29795 .65644 L .29652 .65437 L F
.565 .7 .932 r
.29652 .65437 m .29795 .65644 L .2991 .65379 L F
.528 .656 .917 r
.29795 .65644 m .30044 .65608 L .2991 .65379 L F
.802 .319 0 r
.40551 .56204 m .40486 .56263 L .40359 .56073 L F
.801 .318 0 r
.40551 .56204 m .40673 .56388 L .40486 .56263 L F
0 0 .125 r
.48505 .55627 m .48319 .56045 L .48405 .558 L F
0 0 .402 r
.33157 .56108 m .33286 .56298 L .33427 .56058 L F
.33157 .56108 m .33158 .56397 L .33286 .56298 L F
.594 .126 .113 r
.42401 .5991 m .42421 .59754 L .42658 .59935 L F
.78 .854 .905 r
.39691 .4548 m .39257 .45574 L .39514 .45412 L F
.073 .632 .794 r
.39514 .45412 m .39843 .4543 L .39691 .4548 L F
.692 .972 .766 r
.67119 .31351 m .668 .31625 L .66951 .31408 L F
.685 .96 .722 r
.668 .31625 m .66782 .31591 L .66951 .31408 L F
.049 0 .126 r
.5624 .40786 m .56514 .40411 L .56573 .40617 L F
.669 .3 .337 r
.56514 .40411 m .56827 .40668 L .56573 .40617 L F
.623 .8 .967 r
.34502 .56363 m .34247 .56445 L .34056 .56415 L F
.581 .359 .544 r
.34502 .56363 m .34197 .5672 L .34247 .56445 L F
.623 .8 .967 r
.34502 .56363 m .34247 .56445 L .34056 .56415 L F
.581 .359 .544 r
.34502 .56363 m .34197 .5672 L .34247 .56445 L F
.84 .872 .866 r
.63474 .35151 m .63603 .35318 L .63742 .35087 L F
.53 .369 .607 r
.48283 .52242 m .48508 .52146 L .48417 .51815 L F
.6 .455 .656 r
.48417 .51815 m .48646 .51797 L .48727 .51492 L F
.527 .367 .607 r
.48417 .51815 m .48715 .52064 L .48646 .51797 L F
.48417 .51815 m .48508 .52146 L .48715 .52064 L F
.84 .401 .181 r
.35387 .50746 m .35569 .51041 L .35733 .50936 L F
.738 .248 .072 r
.35569 .51041 m .35914 .51146 L .35733 .50936 L F
.274 .541 .92 r
.60204 .37859 m .60205 .37872 L .60122 .37878 L F
.431 .842 .661 r
.60205 .37885 m .60205 .37872 L .60376 .37784 L F
.782 .474 .466 r
.60205 .37872 m .60571 .38104 L .6069 .37689 L F
.274 .541 .92 r
.60436 .37807 m .60205 .37872 L .60204 .37859 L F
.431 .842 .661 r
.59973 .38022 m .60205 .37872 L .60205 .37885 L F
.563 .799 .988 r
.44244 .56683 m .44516 .56774 L .44096 .56712 L F
.247 0 .101 r
.44516 .56774 m .44168 .57077 L .44096 .56712 L F
.44307 .56956 m .44405 .56996 L .44168 .57077 L F
.44516 .56774 m .44439 .5693 L .44307 .56956 L F
.44439 .5693 m .44405 .56996 L .44307 .56956 L F
.563 .799 .988 r
.44482 .56637 m .44496 .56695 L .44244 .56683 L F
.44496 .56695 m .44516 .56774 L .44244 .56683 L F
0 0 .342 r
.445 .56649 m .44516 .56774 L .44482 .56637 L F
.594 .743 .948 r
.44084 .56668 m .44482 .56637 L .44096 .56712 L F
.581 .112 .106 r
.44084 .56668 m .44469 .56791 L .445 .56649 L F
.44109 .56676 m .4418 .56899 L .44411 .56891 L F
.61 .592 .808 r
.44469 .56791 m .44405 .56996 L .44439 .5693 L F
.44455 .56816 m .44405 .56996 L .44469 .56791 L F
.445 .56649 m .44439 .5693 L .44516 .56774 L F
.44455 .56816 m .44757 .57004 L .44405 .56996 L F
.581 .112 .106 r
.44469 .56791 m .44455 .56816 L .44646 .5685 L F
.44623 .56841 m .44646 .5685 L .44664 .56854 L F
.44469 .56791 m .44646 .5685 L .44623 .56841 L F
.234 .456 .87 r
.44741 .56878 m .44913 .56897 L .445 .56649 L F
0 0 0 r
.44728 .56884 m .44913 .56897 L .44741 .56878 L F
.323 .467 .849 r
.44792 .56888 m .44913 .56897 L .44853 .56939 L F
.44653 .56861 m .44853 .56939 L .44757 .57004 L F
.44646 .5685 m .44714 .56879 L .44653 .56861 L F
.44714 .56879 m .44853 .56939 L .44653 .56861 L F
.61 .592 .808 r
.44646 .5685 m .44757 .57004 L .44455 .56816 L F
.708 .562 .687 r
.44405 .56996 m .44115 .57327 L .44168 .57077 L F
.44405 .56996 m .44519 .57305 L .44115 .57327 L F
.788 .773 .838 r
.44757 .57004 m .44519 .57305 L .44405 .56996 L F
.468 0 0 r
.4418 .56899 m .44433 .5702 L .44728 .56884 L F
.44714 .56879 m .44728 .56884 L .44741 .56878 L F
.4418 .56899 m .44728 .56884 L .44714 .56879 L F
.581 .112 .106 r
.44725 .56873 m .44741 .56878 L .44734 .56872 L F
.44725 .56873 m .44734 .56872 L .445 .56649 L F
.323 .467 .849 r
.445 .56649 m .44853 .56939 L .44646 .5685 L F
0 0 0 r
.44433 .5702 m .44913 .56897 L .44728 .56884 L F
.323 .467 .849 r
.445 .56649 m .44913 .56897 L .44792 .56888 L F
.61 .592 .808 r
.445 .56649 m .44455 .56816 L .44469 .56791 L F
.581 .112 .106 r
.44469 .56791 m .44725 .56873 L .445 .56649 L F
.61 .592 .808 r
.445 .56649 m .44646 .5685 L .44455 .56816 L F
.581 .112 .106 r
.44664 .56854 m .44411 .56891 L .44741 .56878 L F
.44455 .56816 m .44411 .56891 L .44664 .56854 L F
.44109 .56676 m .44411 .56891 L .44469 .56791 L F
.44084 .56668 m .44087 .56675 L .44109 .56676 L F
.44087 .56675 m .4418 .56899 L .44109 .56676 L F
.816 .687 .722 r
.40526 .482 m .40675 .48686 L .40245 .48523 L F
.699 .169 0 r
.40631 .48669 m .40488 .48748 L .40245 .48523 L F
.679 .253 .228 r
.40245 .48523 m .40488 .48748 L .4009 .48677 L F
.637 .919 .635 r
.40488 .48748 m .40183 .49067 L .4009 .48677 L F
.742 .955 .654 r
.40577 .48555 m .40359 .48819 L .40488 .48748 L F
.40359 .48819 m .40308 .48881 L .40488 .48748 L F
.699 .169 0 r
.40675 .48686 m .40488 .48748 L .40631 .48669 L F
.488 .459 .751 r
.40859 .48123 m .40675 .48686 L .40526 .482 L F
.40859 .48123 m .40964 .48659 L .40675 .48686 L F
.741 .983 .758 r
.40611 .48628 m .40675 .48686 L .40964 .48659 L F
.40611 .48628 m .40488 .48748 L .40675 .48686 L F
.565 .521 .765 r
.4073 .48924 m .40964 .48659 L .40675 .48686 L F
.029 0 0 r
.35602 .55415 m .35398 .55429 L .35664 .55415 L F
.539 .343 .563 r
.35398 .55429 m .35726 .55745 L .35664 .55415 L F
.35398 .55429 m .3537 .55852 L .35726 .55745 L F
.029 0 0 r
.35602 .55415 m .35219 .55601 L .35398 .55429 L F
.394 .852 .85 r
.67847 .36239 m .67438 .36331 L .67701 .3611 L F
.891 .687 .172 r
.67798 .35886 m .67847 .36239 L .67701 .3611 L F
.624 .144 .093 r
.23839 .60406 m .2383 .60507 L .23595 .60356 L F
.23839 .60406 m .2383 .60507 L .23595 .60356 L F
.439 .331 .634 r
.2383 .60507 m .23607 .60651 L .23595 .60356 L F
.576 .91 .975 r
.41313 .59974 m .41479 .6002 L .41728 .59909 L F
.773 .95 .622 r
.61189 .42808 m .6142 .42502 L .61297 .42576 L F
.572 .918 .964 r
.6142 .42502 m .61669 .42384 L .6154 .42339 L F
.836 .613 .601 r
.64514 .38589 m .64419 .38117 L .64169 .38154 L F
0 0 .525 r
.40298 .55105 m .40498 .55457 L .40428 .55294 L F
.981 .768 .356 r
.40488 .55733 m .40428 .55294 L .40498 .55457 L F
.463 0 0 r
.43504 .46396 m .43546 .46433 L .43405 .46352 L F
.679 .706 .868 r
.51892 .41101 m .52369 .41197 L .52183 .40812 L F
.828 .68 .7 r
.51893 .41339 m .52369 .41197 L .51895 .41102 L F
.984 .717 .431 r
.51876 .41585 m .52053 .41762 L .51917 .41404 L F
.51876 .41585 m .51917 .41404 L .51893 .41339 L F
.776 .962 .926 r
.51603 .41899 m .52053 .41762 L .51876 .41585 L F
0 0 .034 r
.5197 .41591 m .51834 .41768 L .51876 .41585 L F
.51834 .41768 m .51807 .41803 L .51876 .41585 L F
.448 .251 .519 r
.52142 .41247 m .5189 .41566 L .51893 .41339 L F
.5189 .41566 m .51876 .41585 L .51893 .41339 L F
.828 .68 .7 r
.51893 .41339 m .51895 .41102 L .51892 .41101 L F
.622 .677 .881 r
.52183 .40812 m .52369 .41197 L .52525 .41026 L F
.112 .001 .437 r
.34722 .60349 m .34915 .60244 L .34915 .59948 L F
.095 .034 .491 r
.34937 .60187 m .3497 .60162 L .34915 .60244 L F
.134 0 0 r
.3495 .60187 m .34963 .60123 L .34937 .60187 L F
.095 .034 .491 r
.34937 .60187 m .34935 .60204 L .3497 .60162 L F
.808 .928 .913 r
.3497 .60162 m .34935 .60204 L .34915 .60244 L F
.095 .034 .491 r
.34935 .60204 m .34931 .60242 L .3497 .60162 L F
.808 .928 .913 r
.3497 .60162 m .34955 .60165 L .34935 .60204 L F
.134 0 0 r
.34935 .60204 m .34937 .60187 L .34915 .60244 L F
.34993 .60046 m .34915 .59948 L .34915 .60244 L F
.095 .034 .491 r
.34722 .60349 m .34937 .60187 L .34915 .60244 L F
.34871 .60273 m .34893 .60252 L .34937 .60187 L F
.34883 .60267 m .34935 .60204 L .34937 .60187 L F
.808 .928 .913 r
.34955 .60165 m .3475 .60204 L .34904 .60242 L F
.616 .932 .964 r
.34935 .60197 m .34804 .60217 L .34904 .60242 L F
.34941 .60189 m .34896 .60198 L .34935 .60197 L F
.34896 .60198 m .34804 .60217 L .34935 .60197 L F
.808 .928 .913 r
.3497 .60162 m .34896 .60198 L .3475 .60204 L F
.34896 .60198 m .34487 .60396 L .3475 .60204 L F
.095 .034 .491 r
.34722 .60349 m .34871 .60273 L .34937 .60187 L F
.34722 .60349 m .34742 .60631 L .34931 .60242 L F
.995 .808 .443 r
.34557 .60755 m .34487 .60396 L .34896 .60198 L F
.34941 .60189 m .34896 .60198 L .34953 .60171 L F
.095 .034 .491 r
.34871 .60273 m .34883 .60267 L .34893 .60252 L F
.995 .808 .443 r
.34557 .60755 m .34896 .60198 L .34941 .60189 L F
.616 .932 .964 r
.35019 .60078 m .3475 .60204 L .34804 .60217 L F
.995 .808 .443 r
.34953 .60187 m .34953 .60171 L .3497 .60162 L F
.34949 .60192 m .3495 .60187 L .34953 .60187 L F
.3495 .60187 m .34953 .60171 L .34953 .60187 L F
.808 .928 .913 r
.34935 .60204 m .34904 .60242 L .34915 .60244 L F
.134 0 0 r
.34934 .60213 m .34935 .60204 L .34915 .60244 L F
.616 .932 .964 r
.34934 .60213 m .34904 .60242 L .34915 .60244 L F
.095 .034 .491 r
.34883 .60267 m .34931 .60242 L .34935 .60204 L F
.616 .932 .964 r
.3495 .60187 m .34904 .60242 L .34934 .60213 L F
.134 0 0 r
.35019 .60078 m .34963 .60123 L .34953 .60171 L F
.616 .932 .964 r
.35019 .60078 m .34941 .60189 L .3495 .60187 L F
.808 .928 .913 r
.34955 .60165 m .34904 .60242 L .34935 .60204 L F
.134 0 0 r
.3495 .60187 m .34937 .60187 L .34934 .60213 L F
.616 .932 .964 r
.34941 .60189 m .34904 .60242 L .3495 .60187 L F
.35019 .60078 m .34804 .60217 L .34941 .60189 L F
.995 .808 .443 r
.34557 .60755 m .34953 .60171 L .34949 .60192 L F
.134 0 0 r
.35019 .60078 m .34993 .60046 L .34963 .60123 L F
.493 .713 .969 r
.50786 .47122 m .50921 .47302 L .50992 .471 L F
.452 .669 .956 r
.50992 .471 m .50921 .47302 L .51186 .47267 L F
.702 .682 .828 r
.50906 .47618 m .51186 .47267 L .50921 .47302 L F
.857 .709 .697 r
.46888 .52393 m .47373 .52117 L .46914 .52076 L F
.759 .58 .655 r
.47373 .52117 m .47203 .52459 L .47436 .52232 L F
.355 .79 .966 r
.46369 .59592 m .4624 .59489 L .45986 .59526 L F
.051 .616 .776 r
.46654 .59507 m .4624 .59489 L .46369 .59592 L F
.636 .805 .964 r
.32232 .59987 m .32384 .60098 L .32502 .59927 L F
.253 .112 .487 r
.4601 .56656 m .4587 .56744 L .45852 .57123 L F
0 .379 .782 r
.26511 .62728 m .26728 .62899 L .26373 .62729 L F
.26512 .62728 m .26513 .62729 L .26511 .62728 L F
.26513 .62729 m .26728 .62899 L .26511 .62728 L F
.499 .075 .167 r
.26728 .62899 m .26948 .63084 L .26722 .63178 L F
.26728 .62899 m .27277 .62924 L .26948 .63084 L F
.789 .618 .668 r
.26442 .63036 m .26948 .63084 L .26898 .62942 L F
.902 .942 .825 r
.26915 .62514 m .26728 .62899 L .26512 .62728 L F
.58 .52 .752 r
.26915 .62514 m .27277 .62924 L .26728 .62899 L F
.789 .618 .668 r
.26675 .62819 m .26898 .62942 L .2681 .62693 L F
.26442 .63036 m .26898 .62942 L .26675 .62819 L F
0 .379 .782 r
.26512 .62728 m .26373 .62729 L .26162 .62871 L F
0 0 0 r
.23979 .53151 m .24162 .53069 L .24292 .52845 L F
.103 0 .122 r
.23979 .53151 m .24104 .53294 L .24162 .53069 L F
.23979 .53151 m .23902 .53419 L .24104 .53294 L F
.549 .917 .948 r
.35883 .6425 m .36118 .64172 L .36013 .6409 L F
0 0 .216 r
.35877 .64467 m .35883 .6425 L .36013 .6409 L F
.889 .922 .838 r
.73456 .30893 m .73806 .30721 L .73661 .30568 L F
.844 .529 .455 r
.47148 .53076 m .46966 .53136 L .47072 .52959 L F
.199 .728 .77 r
.33862 .61262 m .34122 .6121 L .34161 .61216 L F
.643 .936 .683 r
.34161 .61216 m .34413 .60933 L .34535 .60981 L F
.34161 .61216 m .34122 .6121 L .34413 .60933 L F
.456 .265 .531 r
.51926 .44593 m .52199 .44543 L .52206 .44291 L F
.342 .797 .945 r
.52023 .44493 m .52199 .44543 L .51926 .44593 L F
.234 .507 .906 r
.52023 .44493 m .52114 .44588 L .52199 .44543 L F
.73 .959 .674 r
.52314 .44483 m .52199 .44543 L .52131 .44679 L F
.482 .745 .987 r
.52131 .44679 m .52199 .44543 L .51926 .44593 L F
.042 .192 .695 r
.52199 .44543 m .52319 .44944 L .52131 .44679 L F
0 0 .545 r
.52323 .44803 m .52319 .44944 L .52312 .44922 L F
.52323 .44803 m .52312 .44922 L .52199 .44543 L F
.234 .507 .906 r
.52114 .44588 m .52323 .44803 L .52199 .44543 L F
.52023 .44493 m .52341 .44594 L .52323 .44803 L F
.52341 .44594 m .52366 .44601 L .52323 .44803 L F
.73 .959 .674 r
.5236 .44433 m .52199 .44543 L .52314 .44483 L F
.768 .825 .897 r
.5236 .44433 m .52462 .44042 L .52206 .44291 L F
.5236 .44433 m .52604 .44295 L .52462 .44042 L F
.98 .722 .468 r
.52206 .44291 m .52199 .44543 L .5236 .44433 L F
.75 .512 .571 r
.31394 .58237 m .31777 .57967 L .31489 .57978 L F
.776 .759 .838 r
.44113 .58421 m .44533 .58424 L .44391 .58379 L F
.395 .827 .956 r
.44391 .58379 m .44533 .58424 L .44809 .58343 L F
.389 .261 .583 r
.44533 .58424 m .44741 .58522 L .44809 .58343 L F
.592 .898 .987 r
.42808 .48983 m .42268 .49038 L .42397 .4897 L F
.42808 .48983 m .42666 .48906 L .42268 .49038 L F
.673 .927 .972 r
.429 .48771 m .42808 .48983 L .42943 .48787 L F
.429 .48771 m .42666 .48906 L .42808 .48983 L F
0 0 0 r
.3123 .62915 m .30904 .63109 L .31139 .63143 L F
.167 .047 .461 r
.30904 .63109 m .31096 .63474 L .31139 .63143 L F
.30904 .63109 m .30873 .63505 L .31096 .63474 L F
.539 .269 .454 r
.32424 .62276 m .32722 .62248 L .32772 .61988 L F
.123 0 .304 r
.32772 .61988 m .32988 .61906 L .33132 .61966 L F
.32772 .61988 m .32845 .6213 L .32988 .61906 L F
.32772 .61988 m .32722 .62248 L .32845 .6213 L F
.476 0 0 r
.33696 .49725 m .33946 .49789 L .34123 .49731 L F
.607 .064 0 r
.33946 .49789 m .34352 .49878 L .34123 .49731 L F
.812 .911 .511 r
.34162 .62134 m .34223 .62057 L .34276 .61876 L F
.054 0 0 r
.2669 .58534 m .26933 .58486 L .27192 .58338 L F
.577 .174 .241 r
.26933 .58486 m .27409 .58255 L .27192 .58338 L F
.628 .522 .714 r
.34505 .54434 m .3456 .54837 L .34854 .54773 L F
.612 .46 .651 r
.3456 .54837 m .34598 .55108 L .34854 .54773 L F
.534 .853 .998 r
.44292 .49828 m .4401 .49884 L .43851 .49789 L F
.43851 .49789 m .4401 .49884 L .44292 .49828 L F
.957 .622 .24 r
.58498 .40985 m .58635 .4111 L .58571 .40947 L F
.995 .789 .512 r
.58607 .41282 m .58635 .4111 L .58498 .40985 L F
0 .087 .605 r
.59933 .3739 m .59953 .37794 L .60015 .37542 L F
.847 .387 .017 r
.42056 .53014 m .42073 .53053 L .4207 .53022 L F
0 0 .376 r
.42053 .52898 m .42073 .53053 L .42056 .53014 L F
.711 .51 0 r
.42053 .52898 m .42085 .53161 L .42073 .53053 L F
.42085 .53161 m .42106 .53329 L .42073 .53053 L F
.847 .387 .017 r
.4207 .53022 m .42073 .53053 L .42231 .53125 L F
.987 .723 .352 r
.42106 .53329 m .42231 .53125 L .42073 .53053 L F
.42106 .53329 m .42225 .53485 L .42231 .53125 L F
0 0 0 r
.30023 .6482 m .30141 .64801 L .29911 .64835 L F
.342 0 0 r
.45471 .59585 m .45339 .59661 L .45067 .59644 L F
.206 0 0 r
.45728 .59569 m .45339 .59661 L .45471 .59585 L F
.015 .544 .853 r
.34505 .54434 m .3442 .54355 L .34123 .54276 L F
.628 .522 .714 r
.34505 .54434 m .34854 .54773 L .34684 .54435 L F
.708 .935 .62 r
.40245 .48523 m .40526 .482 L .40256 .48241 L F
.816 .687 .722 r
.40526 .482 m .40245 .48523 L .40256 .48241 L F
.822 .937 .904 r
.45985 .43905 m .45827 .44105 L .45667 .44006 L F
0 0 0 r
.63671 .34257 m .63528 .34349 L .63278 .34454 L F
.6371 .34261 m .63671 .34257 L .63929 .34119 L F
.6371 .34261 m .63528 .34349 L .63671 .34257 L F
.582 .332 .503 r
.70424 .29871 m .70165 .29974 L .70173 .29707 L F
.951 .729 .268 r
.56097 .42752 m .56032 .42672 L .56035 .42651 L F
.56097 .42752 m .56101 .42972 L .56032 .42672 L F
0 0 .343 r
.33196 .62155 m .33132 .61966 L .33194 .61895 L F
.33196 .62155 m .33138 .62271 L .33132 .61966 L F
.788 .997 .861 r
.39355 .48417 m .3932 .48613 L .39656 .48324 L F
.514 0 0 r
.394 .48707 m .39547 .48816 L .3932 .48613 L F
.394 .48707 m .3932 .48613 L .39355 .48417 L F
.99 .773 .514 r
.4041 .4972 m .40718 .50141 L .40546 .49961 L F
.662 .908 .582 r
.67396 .31023 m .67119 .31351 L .67267 .31128 L F
.705 .975 .765 r
.67119 .31351 m .66951 .31408 L .67267 .31128 L F
.906 .975 .799 r
.36776 .6342 m .37021 .63199 L .36952 .63187 L F
.571 .933 .785 r
.64702 .39618 m .64871 .39571 L .65089 .39414 L F
.829 .692 .712 r
.61077 .41521 m .61187 .41753 L .6099 .41665 L F
.344 .446 .822 r
.61077 .41521 m .61391 .41533 L .61187 .41753 L F
.365 .48 .843 r
.61391 .41533 m .61516 .41849 L .61187 .41753 L F
.799 .665 .715 r
.35656 .6033 m .35474 .60648 L .35437 .60357 L F
.552 .405 .635 r
.70282 .30669 m .70094 .30946 L .70099 .30759 L F
.70282 .30669 m .70268 .30962 L .70094 .30946 L F
.643 .558 .744 r
.70413 .31255 m .70094 .30946 L .70268 .30962 L F
0 0 0 r
.6353 .33602 m .63645 .33617 L .63777 .33478 L F
.6353 .33602 m .6343 .33754 L .63645 .33617 L F
.942 .648 .452 r
.38758 .51846 m .38559 .51763 L .38549 .51506 L F
.865 .464 .275 r
.38758 .51846 m .38603 .51998 L .38559 .51763 L F
.38758 .51846 m .3889 .52142 L .38603 .51998 L F
.525 .493 .763 r
.34144 .62892 m .34365 .63283 L .34182 .63424 L F
0 0 0 r
.34182 .63424 m .34365 .63283 L .3405 .63572 L F
.556 .715 .946 r
.31061 .65644 m .31543 .65833 L .31353 .65622 L F
.515 .668 .931 r
.31543 .65833 m .31569 .65525 L .31353 .65622 L F
.31543 .65833 m .31794 .658 L .31569 .65525 L F
.756 .941 .604 r
.43073 .48616 m .429 .48771 L .42943 .48787 L F
.975 .673 .31 r
.42936 .48487 m .43073 .48616 L .42914 .48228 L F
.996 .786 .499 r
.42936 .48487 m .429 .48771 L .43073 .48616 L F
.43 .079 .268 r
.31116 .58283 m .31394 .58237 L .31174 .58082 L F
.488 .296 .546 r
.3786 .61217 m .3761 .61281 L .37642 .60978 L F
.483 .813 1 r
.34726 .65191 m .35152 .65241 L .34978 .65135 L F
.874 .931 .857 r
.35152 .65241 m .3525 .64861 L .34978 .65135 L F
.35152 .65241 m .35442 .64922 L .3525 .64861 L F
.177 0 .331 r
.49723 .52812 m .49679 .53061 L .49443 .53157 L F
0 0 .336 r
.49578 .53289 m .49443 .53157 L .49679 .53061 L F
.49578 .53289 m .49476 .53412 L .49443 .53157 L F
.467 .76 .994 r
.32437 .52847 m .32719 .52811 L .3251 .52669 L F
.32437 .52847 m .32719 .52811 L .3251 .52669 L F
.501 .303 .543 r
.32437 .52847 m .32433 .53128 L .32719 .52811 L F
.32437 .52847 m .32433 .53128 L .32719 .52811 L F
.596 .164 0 r
.57887 .37907 m .57909 .37945 L .57607 .37697 L F
.57887 .37907 m .58009 .38091 L .57909 .37945 L F
.675 .558 .715 r
.34927 .64232 m .35315 .64295 L .34998 .64575 L F
.879 .945 .583 r
.63742 .35087 m .63835 .34931 L .63746 .34926 L F
.064 .385 .847 r
.57595 .38293 m .57531 .38419 L .57308 .38212 L F
.57595 .38293 m .57703 .38457 L .57531 .38419 L F
.898 .836 .776 r
.47116 .53728 m .47288 .53857 L .47093 .54185 L F
.743 .769 .874 r
.46874 .45937 m .47004 .45531 L .46756 .45905 L F
.46874 .45937 m .47191 .45751 L .47004 .45531 L F
.625 .187 0 r
.59987 .41733 m .60152 .42006 L .59806 .41656 L F
.59987 .41733 m .60304 .42212 L .60152 .42006 L F
.836 .999 .809 r
.49661 .41505 m .49411 .41782 L .49456 .4156 L F
.811 .993 .87 r
.49411 .41782 m .49138 .41841 L .49456 .4156 L F
.234 0 .332 r
.50512 .5156 m .50465 .51795 L .50256 .51897 L F
.134 0 .312 r
.50393 .52005 m .50256 .51897 L .50465 .51795 L F
.50393 .52005 m .50217 .52136 L .50256 .51897 L F
.535 .591 .857 r
.42735 .45976 m .42893 .4633 L .43201 .4619 L F
.999 .802 .466 r
.58571 .40947 m .58545 .40443 L .58457 .40726 L F
.957 .622 .24 r
.58498 .40985 m .58571 .40947 L .58457 .40726 L F
.857 .403 .083 r
.36874 .50305 m .36753 .50382 L .36629 .50125 L F
.379 0 0 r
.37188 .50404 m .36753 .50382 L .36874 .50305 L F
.765 .683 .772 r
.29247 .6564 m .2944 .65471 L .29278 .6514 L F
.363 .07 .327 r
.29072 .65825 m .2944 .65471 L .29247 .6564 L F
.471 .538 .843 r
.29278 .6514 m .2944 .65471 L .29652 .65437 L F
.628 .65 .853 r
.35093 .63906 m .34927 .64232 L .34828 .63935 L F
.35093 .63906 m .35315 .64295 L .34927 .64232 L F
.569 .697 .928 r
.53775 .41768 m .54049 .41694 L .53743 .41472 L F
.959 .624 .249 r
.59522 .401 m .59693 .40476 L .59505 .40357 L F
.998 .779 .438 r
.59693 .40476 m .59561 .40625 L .59505 .40357 L F
.59693 .40476 m .59674 .4075 L .59561 .40625 L F
.972 .723 .5 r
.2712 .64249 m .27101 .64525 L .26888 .64463 L F
0 .513 .839 r
.27228 .64233 m .27344 .64309 L .2712 .64249 L F
.27228 .64233 m .2712 .64249 L .26888 .64463 L F
.693 .652 .805 r
.28749 .65538 m .29247 .6564 L .28996 .65234 L F
.577 .566 .805 r
.28749 .65538 m .29072 .65825 L .29247 .6564 L F
.765 .683 .772 r
.29247 .6564 m .29278 .6514 L .28996 .65234 L F
.784 .846 .898 r
.70686 .29247 m .7041 .29416 L .70325 .2926 L F
0 0 .28 r
.22797 .55142 m .2276 .55402 L .22921 .5503 L F
.861 .912 .865 r
.73068 .32549 m .73197 .32151 L .72992 .32454 L F
.73068 .32549 m .73301 .32311 L .73197 .32151 L F
.492 .283 .524 r
.45859 .5838 m .46039 .58464 L .46135 .58026 L F
.109 .004 .442 r
.46135 .58026 m .46316 .57648 L .46 .57702 L F
.46135 .58026 m .46288 .57963 L .46316 .57648 L F
.165 0 .384 r
.46135 .58026 m .46236 .58209 L .46288 .57963 L F
.46135 .58026 m .46039 .58464 L .46236 .58209 L F
.356 .827 .884 r
.43306 .5981 m .43405 .5983 L .43762 .59754 L F
.512 .297 .525 r
.36196 .57798 m .36485 .5774 L .36494 .57395 L F
.538 .318 .529 r
.36494 .57395 m .36741 .57634 L .36756 .57361 L F
.36494 .57395 m .36485 .5774 L .36741 .57634 L F
.573 .342 .528 r
.36756 .57361 m .36317 .57565 L .36494 .57395 L F
.398 .786 .989 r
.30234 .65531 m .30456 .65655 L .30702 .65614 L F
.216 0 .056 r
.52424 .49867 m .52096 .50107 L .5216 .49922 L F
.364 0 .191 r
.47656 .53055 m .47924 .5301 L .48011 .52751 L F
.058 0 .153 r
.48239 .52489 m .48011 .52751 L .48241 .52654 L F
.328 0 .242 r
.47924 .5301 m .48241 .52654 L .48011 .52751 L F
.878 .652 .593 r
.38205 .54451 m .38176 .54736 L .38406 .54772 L F
.917 .62 .466 r
.38204 .54942 m .38406 .54772 L .38176 .54736 L F
.38204 .54942 m .38474 .55086 L .38406 .54772 L F
0 0 .444 r
.72811 .29325 m .72893 .2926 L .72871 .29037 L F
.434 .872 .803 r
.72811 .29325 m .72739 .29314 L .72893 .2926 L F
.863 .993 .822 r
.34535 .60981 m .34557 .60755 L .34742 .60631 L F
.34535 .60981 m .34413 .60933 L .34557 .60755 L F
.84 .82 .829 r
.59702 .34722 m .59278 .34793 L .59407 .34703 L F
.59702 .34722 m .59207 .35028 L .59278 .34793 L F
.636 .871 .986 r
.59803 .34486 m .59702 .34722 L .59407 .34703 L F
.59803 .34486 m .59945 .34617 L .59702 .34722 L F
.612 .261 .351 r
.71229 .30066 m .71302 .30296 L .71461 .30211 L F
.565 .842 .501 r
.67396 .31023 m .6756 .30825 L .67671 .30711 L F
.593 .882 .576 r
.67396 .31023 m .67267 .31128 L .6756 .30825 L F
.044 .113 .611 r
.22382 .56405 m .22557 .56622 L .22501 .56246 L F
.822 .431 .313 r
.60134 .38798 m .60146 .38973 L .60303 .38782 L F
.768 .357 .272 r
.60146 .38973 m .60517 .39082 L .60303 .38782 L F
.596 .34 .499 r
.60517 .39082 m .60641 .38956 L .60303 .38782 L F
0 0 .198 r
.32552 .56214 m .32488 .56103 L .32327 .56221 L F
.852 .795 .795 r
.24824 .53899 m .24658 .54236 L .24427 .54041 L F
.974 .671 .375 r
.38474 .55086 m .38491 .55345 L .38649 .55442 L F
.952 .676 .479 r
.38447 .55646 m .38649 .55442 L .38491 .55345 L F
.38447 .55646 m .38653 .55745 L .38649 .55442 L F
.264 0 .028 r
.53669 .49012 m .53582 .49141 L .53331 .49208 L F
0 0 0 r
.53763 .49044 m .53669 .49012 L .53928 .48919 L F
.53763 .49044 m .53582 .49141 L .53669 .49012 L F
.742 .911 .951 r
.44642 .4446 m .45187 .44355 L .44955 .44477 L F
.824 .919 .9 r
.61551 .40184 m .61863 .401 L .61796 .40036 L F
.274 .09 .44 r
.61863 .401 m .61988 .39871 L .61796 .40036 L F
.61991 .39895 m .62077 .39759 L .61988 .39871 L F
.61863 .401 m .61991 .39895 L .61988 .39871 L F
.62077 .39759 m .61863 .401 L .61974 .39919 L F
.756 .52 .576 r
.61974 .39919 m .62485 .3983 L .62077 .39759 L F
0 0 0 r
.61988 .39871 m .62077 .39759 L .62321 .39648 L F
.61988 .39871 m .62193 .39745 L .61985 .39853 L F
.61988 .39871 m .61985 .39853 L .61947 .39873 L F
.548 .565 .823 r
.61863 .401 m .62306 .40383 L .61974 .39919 L F
.421 .293 .599 r
.49495 .50156 m .49773 .50424 L .4975 .50155 L F
.49495 .50156 m .49637 .50526 L .49773 .50424 L F
.281 0 .218 r
.60947 .38565 m .60641 .38956 L .6096 .38707 L F
.318 0 0 r
.61075 .38632 m .60947 .38565 L .6096 .38707 L F
.177 0 0 r
.5387 .39656 m .54135 .39595 L .54263 .39425 L F
.555 .89 .985 r
.54263 .39425 m .5438 .3927 L .54579 .39317 L F
.782 .662 .731 r
.54135 .39595 m .5438 .3927 L .54263 .39425 L F
0 0 0 r
.63107 .40233 m .62862 .40353 L .62894 .40389 L F
.354 .823 .759 r
.42876 .45065 m .43128 .4496 L .43242 .44936 L F
.467 .892 .845 r
.43242 .44936 m .43371 .44825 L .43528 .44816 L F
.475 .89 .785 r
.43128 .4496 m .43371 .44825 L .43242 .44936 L F
.433 .178 .426 r
.48727 .51492 m .49064 .51495 L .48983 .51204 L F
.318 .154 .495 r
.48983 .51204 m .49293 .51096 L .49221 .50825 L F
.271 .087 .438 r
.48983 .51204 m .4923 .51351 L .49293 .51096 L F
.48983 .51204 m .49064 .51495 L .4923 .51351 L F
.149 0 0 r
.56657 .38136 m .56952 .38165 L .57072 .38159 L F
.01 .576 .793 r
.56952 .38165 m .57308 .38212 L .57072 .38159 L F
.426 .648 .951 r
.61775 .41112 m .61911 .40909 L .61646 .40996 L F
.61775 .41112 m .62026 .41112 L .61911 .40909 L F
.851 .548 .476 r
.28836 .57788 m .29173 .58027 L .28762 .57994 L F
0 0 0 r
.28836 .57788 m .28762 .57994 L .28814 .57887 L F
.193 .029 .417 r
.28997 .58204 m .2876 .58303 L .28762 .57994 L F
.429 .8 .994 r
.28796 .58158 m .28762 .57994 L .28615 .58095 L F
.193 .029 .417 r
.28997 .58204 m .28762 .57994 L .29173 .58027 L F
.429 .8 .994 r
.28796 .58158 m .28814 .57887 L .28762 .57994 L F
.56 .077 .067 r
.59945 .34617 m .60265 .34824 L .6035 .34592 L F
0 0 0 r
.6035 .34592 m .60432 .34536 L .60614 .34501 L F
.6035 .34592 m .60265 .34824 L .60432 .34536 L F
.643 .662 .853 r
.40743 .45967 m .40868 .45518 L .40594 .45586 L F
.40743 .45967 m .40972 .45884 L .40868 .45518 L F
.934 .56 .255 r
.32795 .59663 m .32748 .5987 L .32687 .59635 L F
.921 .695 .579 r
.32941 .59544 m .32748 .5987 L .32795 .59663 L F
.8 .999 .846 r
.36013 .6409 m .36118 .64172 L .36416 .63838 L F
.664 .782 .937 r
.52604 .44295 m .52742 .43929 L .52462 .44042 L F
.52604 .44295 m .52908 .44191 L .52742 .43929 L F
.497 .464 .751 r
.30696 .52975 m .30811 .52641 L .30745 .52913 L F
.593 .271 .393 r
.31034 .52821 m .30696 .52975 L .30745 .52913 L F
.658 .549 .719 r
.50426 .48232 m .50802 .48269 L .50673 .47915 L F
.559 .401 .624 r
.50515 .48605 m .50802 .48269 L .50426 .48232 L F
.562 .397 .616 r
.42363 .58039 m .42444 .58449 L .42121 .58386 L F
0 .073 .632 r
.45826 .58236 m .45859 .5838 L .45796 .58216 L F
0 0 .159 r
.46096 .58469 m .46236 .58209 L .46039 .58464 L F
.803 .513 .499 r
.45826 .58236 m .46096 .58469 L .45859 .5838 L F
0 .367 .797 r
.45859 .5838 m .46096 .58469 L .46039 .58464 L F
.673 .929 .971 r
.3525 .64861 m .35442 .64922 L .3547 .64735 L F
.747 .609 .705 r
.50673 .47915 m .51058 .47964 L .50906 .47618 L F
.749 .596 .686 r
.50673 .47915 m .50802 .48269 L .51058 .47964 L F
.704 .529 .649 r
.51058 .47964 m .50802 .48269 L .51048 .4824 L F
.718 .596 .719 r
.50906 .47618 m .51058 .47964 L .51314 .47628 L F
.562 .383 .596 r
.51314 .47628 m .51058 .47964 L .51342 .47889 L F
.655 .534 .704 r
.51048 .4824 m .51342 .47889 L .51058 .47964 L F
.024 0 0 r
.61333 .37558 m .60949 .37779 L .60967 .37734 L F
0 0 0 r
.55064 .41398 m .54967 .41615 L .5506 .41399 L F
.726 .57 .679 r
.43509 .56731 m .43191 .56839 L .43369 .56637 L F
.671 .676 .846 r
.43587 .56745 m .43191 .56839 L .43509 .56731 L F
.03 .434 .869 r
.43369 .56637 m .43556 .56681 L .43509 .56731 L F
0 0 .35 r
.43556 .56681 m .43587 .56745 L .43509 .56731 L F
.912 .632 .499 r
.36874 .52419 m .37103 .52763 L .37085 .52519 L F
.887 .876 .818 r
.43369 .56637 m .43052 .56746 L .43237 .56356 L F
.43369 .56637 m .43191 .56839 L .43052 .56746 L F
0 .446 .862 r
.43459 .5659 m .43369 .56637 L .43556 .56288 L F
.43459 .5659 m .43556 .56681 L .43369 .56637 L F
.755 .282 .12 r
.29173 .58027 m .294 .5828 L .28997 .58204 L F
.686 .323 .353 r
.29173 .58027 m .29471 .58098 L .294 .5828 L F
.639 .965 .888 r
.54691 .42189 m .5453 .42361 L .54442 .42279 L F
.778 .936 .582 r
.5453 .42361 m .54559 .42247 L .54442 .42279 L F
.383 .266 .594 r
.54274 .42763 m .54598 .42895 L .54559 .42247 L F
.54274 .42763 m .54338 .43003 L .54598 .42895 L F
0 0 .08 r
.35505 .59338 m .35434 .59558 L .35686 .59229 L F
.577 .926 .954 r
.33389 .55689 m .33498 .55543 L .3364 .5562 L F
.33389 .55689 m .33238 .55663 L .33498 .55543 L F
.674 .541 .695 r
.43662 .54744 m .43358 .54457 L .43461 .54314 L F
.43662 .54744 m .43524 .54856 L .43358 .54457 L F
.458 .444 .755 r
.49378 .49608 m .49706 .49904 L .49616 .49526 L F
.456 .885 .828 r
.68645 .37352 m .69072 .37212 L .68838 .37243 L F
.578 .943 .88 r
.68838 .37243 m .69072 .37212 L .69287 .37078 L F
.565 .521 .765 r
.4073 .48924 m .41025 .48888 L .40964 .48659 L F
.685 .519 .656 r
.40665 .49134 m .41025 .48888 L .4073 .48924 L F
.559 .401 .624 r
.50515 .48605 m .5079 .48553 L .50802 .48269 L F
.541 .344 .563 r
.50515 .48605 m .50522 .4888 L .5079 .48553 L F
.334 .176 .513 r
.72985 .30316 m .72994 .30568 L .72764 .30714 L F
.061 0 .087 r
.72994 .30568 m .72717 .30842 L .72764 .30714 L F
.756 .52 .576 r
.61974 .39919 m .62567 .40119 L .62485 .3983 L F
.473 .353 .636 r
.62485 .3983 m .62669 .39873 L .62749 .39599 L F
.62485 .3983 m .62567 .40119 L .62669 .39873 L F
.298 0 .133 r
.31471 .62851 m .3123 .62915 L .31139 .63143 L F
.702 .682 .828 r
.50906 .47618 m .51314 .47628 L .51186 .47267 L F
.556 .597 .849 r
.51186 .47267 m .51314 .47628 L .51564 .47543 L F
.267 .08 .431 r
.51342 .47889 m .51564 .47543 L .51314 .47628 L F
.105 0 .241 r
.34642 .59973 m .34597 .60262 L .34381 .60297 L F
.376 0 .107 r
.34597 .60262 m .34203 .60424 L .34381 .60297 L F
.001 0 .049 r
.47827 .45939 m .47636 .4609 L .47538 .46277 L F
.793 .434 0 r
.40168 .54766 m .40298 .55105 L .40125 .54721 L F
.434 .843 .97 r
.28428 .51223 m .28508 .51156 L .28675 .5121 L F
.28675 .5121 m .28508 .51156 L .28213 .51235 L F
.563 .902 .978 r
.28675 .5121 m .28508 .51156 L .28783 .5106 L F
.479 .21 .428 r
.28783 .5106 m .28508 .51156 L .28675 .5121 L F
.238 .708 .943 r
.28318 .50974 m .28783 .5106 L .28508 .51156 L F
.479 .21 .428 r
.28783 .5106 m .28722 .51296 L .28508 .51156 L F
.107 .287 .764 r
.28508 .51156 m .28722 .51296 L .28644 .51041 L F
.238 .708 .943 r
.28318 .50974 m .28623 .50972 L .28783 .5106 L F
.107 .287 .764 r
.28508 .51156 m .28644 .51041 L .28623 .50972 L F
.434 .843 .97 r
.28213 .51235 m .28508 .51156 L .28428 .51223 L F
.916 .933 .805 r
.30952 .61636 m .31094 .61222 L .31235 .61612 L F
.30952 .61636 m .30793 .61612 L .31094 .61222 L F
.494 .889 .951 r
.31036 .61512 m .30952 .61636 L .31235 .61612 L F
.31036 .61512 m .30793 .61612 L .30952 .61636 L F
.602 .69 .905 r
.59675 .36497 m .5942 .36607 L .59304 .364 L F
0 0 0 r
.67671 .30711 m .6784 .30515 L .67892 .30336 L F
.67671 .30711 m .67792 .30701 L .6784 .30515 L F
.67671 .30711 m .6756 .30825 L .67792 .30701 L F
.778 .996 .865 r
.34276 .61876 m .34721 .61612 L .34534 .61751 L F
.679 .259 0 r
.34721 .61612 m .34824 .61813 L .34806 .61798 L F
.776 .998 .824 r
.49661 .41505 m .49767 .41271 L .49877 .41356 L F
.49661 .41505 m .49456 .4156 L .49767 .41271 L F
.707 .983 .89 r
.31842 .5394 m .31651 .54136 L .31771 .54084 L F
.831 .744 .769 r
.39395 .48155 m .39865 .47964 L .39687 .47834 L F
.39395 .48155 m .39656 .48324 L .39865 .47964 L F
0 0 .17 r
.49202 .53779 m .49197 .54019 L .48994 .54139 L F
0 0 0 r
.49197 .54019 m .48948 .54381 L .48994 .54139 L F
.545 .044 .016 r
.47148 .53076 m .46966 .53136 L .47383 .53128 L F
.47148 .53076 m .46966 .53136 L .47383 .53128 L F
.784 .846 .898 r
.70686 .29247 m .70325 .2926 L .70579 .29166 L F
.262 .763 .724 r
.70579 .29166 m .70907 .29071 L .70686 .29247 L F
.571 .817 .991 r
.42894 .57922 m .43083 .58076 L .43301 .57979 L F
0 0 0 r
.23198 .53685 m .23112 .53808 L .23273 .53629 L F
.788 .997 .861 r
.39355 .48417 m .39656 .48324 L .39395 .48155 L F
.025 0 0 r
.28833 .64396 m .2845 .64546 L .28715 .64476 L F
0 0 .546 r
.27413 .64329 m .27465 .64448 L .27344 .64309 L F
.82 .477 .408 r
.27218 .64571 m .27465 .64448 L .27413 .64329 L F
0 .007 .578 r
.27101 .64525 m .27265 .64815 L .27243 .647 L F
.27243 .647 m .27285 .6485 L .27326 .64802 L F
.27265 .64815 m .27285 .6485 L .27243 .647 L F
.734 .207 0 r
.26888 .64463 m .27101 .64525 L .27326 .64802 L F
.82 .477 .408 r
.27142 .64666 m .27226 .64609 L .27218 .64571 L F
.27226 .64609 m .27465 .64448 L .27218 .64571 L F
0 .404 .815 r
.27285 .6485 m .27592 .64987 L .27326 .64802 L F
.915 .658 .535 r
.37451 .5339 m .37631 .53754 L .37637 .53489 L F
.922 .909 .791 r
.40718 .50141 m .40429 .50559 L .40891 .50072 L F
.403 0 0 r
.61496 .39276 m .61606 .39172 L .61363 .39152 L F
.023 0 0 r
.61777 .39209 m .61606 .39172 L .61496 .39276 L F
.61777 .39209 m .61961 .39085 L .61606 .39172 L F
.823 .937 .903 r
.35527 .60751 m .35079 .61161 L .35316 .61038 L F
.707 .878 .961 r
.62026 .41112 m .62442 .41084 L .623 .40992 L F
.496 .846 .995 r
.62442 .41084 m .62734 .41018 L .623 .40992 L F
0 0 0 r
.53513 .40584 m .53802 .40456 L .53679 .40519 L F
.824 1 .811 r
.539 .40585 m .53905 .40563 L .54023 .40598 L F
.53905 .40563 m .53992 .40228 L .5402 .40567 L F
.53905 .40563 m .5402 .40567 L .54023 .40598 L F
.525 .475 .742 r
.5353 .40586 m .53868 .40562 L .53751 .40479 L F
0 0 0 r
.53573 .40566 m .53679 .40519 L .53612 .40554 L F
.53513 .40584 m .53679 .40519 L .53573 .40566 L F
.525 .475 .742 r
.5353 .40586 m .53685 .40511 L .53521 .39957 L F
.824 1 .811 r
.53723 .40459 m .53802 .40456 L .53992 .40228 L F
.53679 .40519 m .53802 .40456 L .53723 .40459 L F
.53723 .40459 m .53992 .40228 L .539 .40585 L F
.525 .475 .742 r
.53723 .40459 m .53729 .40458 L .53794 .4036 L F
.53729 .40458 m .53808 .40381 L .53794 .4036 L F
0 0 0 r
.54237 .40056 m .54046 .40227 L .53992 .40228 L F
.54261 .4004 m .54109 .40172 L .54237 .40056 L F
.54109 .40172 m .54046 .40227 L .54237 .40056 L F
.655 .473 .626 r
.54146 .40093 m .54109 .40172 L .54046 .40217 L F
.723 .761 .882 r
.54046 .40227 m .54023 .40598 L .53992 .40228 L F
.655 .473 .626 r
.54048 .40178 m .54046 .40217 L .5377 .40418 L F
0 0 0 r
.54283 .39995 m .54261 .4004 L .53992 .40228 L F
.655 .473 .626 r
.54146 .40093 m .54046 .40217 L .54048 .40178 L F
.723 .761 .882 r
.54037 .40559 m .54023 .40598 L .54046 .40227 L F
.655 .473 .626 r
.54109 .40172 m .53928 .40558 L .53798 .40443 L F
.705 .531 .651 r
.53834 .4042 m .53928 .40558 L .54044 .4031 L F
.54048 .40227 m .54044 .4031 L .54109 .40172 L F
.723 .761 .882 r
.54048 .40227 m .54044 .4031 L .54046 .40227 L F
.705 .531 .651 r
.53834 .4042 m .54044 .4031 L .54048 .40227 L F
.723 .761 .882 r
.54167 .40223 m .54037 .40559 L .54044 .4031 L F
.54167 .40223 m .54044 .4031 L .54048 .40227 L F
.655 .473 .626 r
.54109 .40172 m .53798 .40443 L .5377 .40418 L F
.705 .531 .651 r
.53521 .39957 m .53808 .40381 L .53986 .40229 L F
.53953 .40051 m .53986 .40229 L .54146 .40093 L F
.53521 .39957 m .53986 .40229 L .53953 .40051 L F
.53521 .39957 m .54146 .40093 L .54105 .40087 L F
.428 .345 .66 r
.53878 .39662 m .54105 .40087 L .54222 .39902 L F
.5387 .39656 m .53881 .39676 L .53878 .39662 L F
.53881 .39676 m .54105 .40087 L .53878 .39662 L F
.655 .473 .626 r
.53972 .4022 m .53701 .40472 L .53742 .40387 L F
.53701 .40472 m .53612 .40554 L .53628 .40533 L F
.525 .475 .742 r
.53685 .40511 m .53759 .40408 L .53617 .40282 L F
.655 .473 .626 r
.53701 .40472 m .53628 .40533 L .53742 .40387 L F
.705 .531 .651 r
.53808 .40381 m .53834 .4042 L .54146 .40093 L F
.53834 .4042 m .54109 .40172 L .54146 .40093 L F
0 0 0 r
.54261 .4004 m .54167 .40223 L .54046 .40227 L F
.655 .473 .626 r
.54146 .40093 m .5377 .40418 L .53972 .4022 L F
.5377 .40418 m .53612 .40554 L .53972 .4022 L F
.663 .388 .493 r
.53742 .40387 m .54167 .40223 L .54164 .40207 L F
.53972 .4022 m .54164 .40207 L .54146 .40093 L F
.53742 .40387 m .54164 .40207 L .53972 .4022 L F
.525 .475 .742 r
.53617 .40282 m .53794 .4036 L .53711 .40237 L F
.53606 .40245 m .53711 .40237 L .53521 .39957 L F
.53617 .40282 m .53711 .40237 L .53606 .40245 L F
.53759 .40408 m .53794 .4036 L .53617 .40282 L F
.53685 .40511 m .53751 .40479 L .53723 .40459 L F
.53751 .40479 m .53844 .40434 L .53723 .40459 L F
.824 1 .811 r
.53612 .40554 m .53679 .40519 L .53723 .40459 L F
.53612 .40554 m .53723 .40459 L .53861 .40557 L F
.525 .475 .742 r
.53442 .40593 m .53524 .40587 L .53521 .39957 L F
0 0 0 r
.53513 .40584 m .53573 .40566 L .53458 .40621 L F
.525 .475 .742 r
.53524 .40587 m .5353 .40586 L .5353 .40584 L F
.53524 .40587 m .5353 .40584 L .53521 .39957 L F
.281 .748 .945 r
.53612 .40554 m .53597 .40582 L .5353 .40586 L F
0 0 0 r
.53573 .40566 m .53612 .40554 L .5353 .40586 L F
.281 .748 .945 r
.53612 .40554 m .5353 .40586 L .53442 .40593 L F
0 0 0 r
.5353 .40586 m .53612 .40554 L .53458 .40621 L F
.53458 .40621 m .53612 .40554 L .53418 .40649 L F
.281 .748 .945 r
.53612 .40554 m .53442 .40593 L .53418 .40649 L F
.817 .675 .706 r
.52945 .40265 m .53442 .40593 L .53301 .4001 L F
.756 .299 .167 r
.52941 .40532 m .53442 .40593 L .52945 .40265 L F
.52941 .40532 m .53418 .40649 L .53442 .40593 L F
.525 .475 .742 r
.53442 .40593 m .53521 .39957 L .53301 .4001 L F
.564 0 0 r
.53052 .4061 m .53418 .40649 L .52941 .40532 L F
.603 .912 .98 r
.53612 .40554 m .53418 .40649 L .53052 .4061 L F
.573 .328 .506 r
.53418 .40649 m .53374 .40918 L .53093 .40944 L F
.707 .555 .68 r
.53612 .40554 m .53374 .40918 L .53418 .40649 L F
.603 .912 .98 r
.53612 .40554 m .53052 .4061 L .53459 .4067 L F
.602 .89 .587 r
.53657 .40473 m .53612 .40554 L .53459 .4067 L F
.53742 .40387 m .53612 .40554 L .53657 .40473 L F
.281 .748 .945 r
.53612 .40554 m .53868 .40562 L .53597 .40582 L F
.824 1 .811 r
.53612 .40554 m .53861 .40557 L .539 .40585 L F
.525 .475 .742 r
.53751 .40479 m .53928 .40558 L .53844 .40434 L F
.53868 .40562 m .53928 .40558 L .53751 .40479 L F
.655 .473 .626 r
.5377 .40418 m .53928 .40558 L .53612 .40554 L F
.525 .475 .742 r
.53729 .40458 m .53844 .40434 L .53808 .40381 L F
.281 .748 .945 r
.53612 .40554 m .53928 .40558 L .53868 .40562 L F
0 0 0 r
.55105 .47376 m .5531 .47257 L .55429 .47107 L F
.981 .827 .429 r
.55429 .47107 m .5531 .47257 L .55319 .4721 L F
0 0 0 r
.55535 .47008 m .55232 .47238 L .55429 .47107 L F
.981 .827 .429 r
.55429 .47107 m .55319 .4721 L .5536 .46994 L F
0 0 0 r
.55585 .46971 m .55535 .47008 L .55429 .47107 L F
.955 .921 .568 r
.55547 .46836 m .55585 .46971 L .55429 .47107 L F
.494 .559 .851 r
.24881 .58795 m .24984 .58597 L .24732 .58617 L F
.24881 .58795 m .2513 .58776 L .24984 .58597 L F
.179 0 .31 r
.50702 .5145 m .50465 .51795 L .50512 .5156 L F
.749 .979 .916 r
.72089 .30795 m .71765 .30996 L .7194 .30725 L F
.116 0 0 r
.71422 .31071 m .71765 .30996 L .71378 .30924 L F
.71422 .31071 m .71656 .31061 L .71765 .30996 L F
.702 .934 .621 r
.71765 .30996 m .71656 .31061 L .7194 .30725 L F
.891 .957 .836 r
.7194 .30725 m .71656 .31061 L .71559 .30966 L F
.7194 .30725 m .71559 .30966 L .71914 .30922 L F
.7194 .30725 m .71914 .30922 L .71837 .30676 L F
.7194 .30725 m .71837 .30676 L .71823 .30633 L F
.749 .979 .916 r
.72104 .30786 m .72089 .30795 L .7194 .30725 L F
0 0 0 r
.7194 .30725 m .72355 .30626 L .72104 .30786 L F
0 .235 .693 r
.43095 .53858 m .43388 .54038 L .43524 .54172 L F
.437 .681 .967 r
.43623 .5393 m .43524 .54172 L .43388 .54038 L F
.416 .055 .242 r
.43524 .54172 m .43861 .54155 L .43842 .54049 L F
.192 0 0 r
.43842 .54049 m .43685 .54158 L .43524 .54172 L F
.43685 .54158 m .43461 .54314 L .43524 .54172 L F
.43685 .54158 m .43755 .54185 L .43461 .54314 L F
.43842 .54049 m .43784 .54139 L .43685 .54158 L F
.437 .681 .967 r
.4385 .54145 m .43861 .54155 L .43731 .54162 L F
.43752 .54153 m .43731 .54162 L .43524 .54172 L F
.4385 .54145 m .43731 .54162 L .43752 .54153 L F
.092 0 .257 r
.44033 .53984 m .43861 .54155 L .43842 .54049 L F
.697 .779 .914 r
.44033 .53984 m .43861 .54155 L .43825 .54121 L F
0 0 0 r
.44033 .53984 m .43865 .54095 L .43842 .54049 L F
.43868 .54103 m .43784 .54139 L .43842 .54049 L F
.697 .779 .914 r
.44033 .53984 m .43825 .54121 L .43623 .5393 L F
0 0 0 r
.44033 .53984 m .43868 .54103 L .43865 .54095 L F
.437 .681 .967 r
.43833 .54129 m .4385 .54145 L .43685 .54158 L F
0 0 0 r
.43868 .54103 m .43755 .54185 L .43784 .54139 L F
.192 0 0 r
.43784 .54139 m .43755 .54185 L .43685 .54158 L F
.437 .681 .967 r
.43623 .5393 m .43833 .54129 L .43524 .54172 L F
.43833 .54129 m .43685 .54158 L .43524 .54172 L F
0 0 0 r
.55387 .47869 m .5576 .47664 L .55604 .47789 L F
.545 .896 .672 r
.5576 .47664 m .55765 .47614 L .55604 .47789 L F
.5576 .47664 m .55946 .47508 L .55765 .47614 L F
.775 .681 .76 r
.32944 .52453 m .33121 .52847 L .33362 .52506 L F
.777 .497 .511 r
.40916 .5044 m .41323 .50232 L .40918 .50147 L F
.40916 .5044 m .4133 .50491 L .41323 .50232 L F
.731 .459 .516 r
.41323 .50232 m .4133 .50491 L .4176 .50494 L F
.707 .677 .819 r
.52219 .43034 m .52076 .4331 L .51904 .4294 L F
.18 .574 .937 r
.52407 .43359 m .52076 .4331 L .52219 .43034 L F
.196 0 0 r
.25716 .5209 m .25963 .52045 L .26035 .51941 L F
.306 .089 .411 r
.26253 .51831 m .26309 .51915 L .26035 .51941 L F
.438 .076 .252 r
.25963 .52045 m .26253 .51831 L .26035 .51941 L F
.211 0 0 r
.64604 .33895 m .64498 .34 L .64215 .34025 L F
.557 .13 .185 r
.64864 .33817 m .64498 .34 L .64604 .33895 L F
.99 .773 .514 r
.4041 .4972 m .40253 .50137 L .40718 .50141 L F
.907 .863 .785 r
.40018 .50355 m .40718 .50141 L .40253 .50137 L F
.849 .694 .689 r
.40429 .50559 m .40332 .50651 L .40035 .50432 L F
0 .395 .828 r
.40035 .50432 m .40332 .50651 L .40258 .50581 L F
.983 .799 .579 r
.40255 .5058 m .40429 .50559 L .40035 .50432 L F
0 .395 .828 r
.40035 .50432 m .40258 .50581 L .40018 .50355 L F
.983 .799 .579 r
.40141 .50593 m .40255 .5058 L .40035 .50432 L F
.907 .863 .785 r
.40258 .50581 m .40332 .50651 L .40396 .50567 L F
.922 .909 .791 r
.40718 .50141 m .40396 .50567 L .40429 .50559 L F
.40396 .50567 m .40332 .50651 L .40429 .50559 L F
.983 .799 .579 r
.40227 .50724 m .40423 .50565 L .40396 .50567 L F
.40161 .50624 m .40396 .50567 L .40141 .50593 L F
.40227 .50724 m .40396 .50567 L .40161 .50624 L F
.40423 .50565 m .40429 .50559 L .40141 .50593 L F
.907 .863 .785 r
.40018 .50355 m .40258 .50581 L .40718 .50141 L F
.40258 .50581 m .40396 .50567 L .40718 .50141 L F
.545 .715 .951 r
.47823 .45642 m .47927 .45402 L .47672 .45475 L F
.47823 .45642 m .48078 .45587 L .47927 .45402 L F
.463 .283 .551 r
.47823 .45642 m .48076 .45859 L .48078 .45587 L F
.47823 .45642 m .47827 .45939 L .48076 .45859 L F
0 0 .006 r
.42504 .55326 m .42396 .55634 L .42269 .55746 L F
.372 .567 .913 r
.42791 .55964 m .42269 .55746 L .42545 .55913 L F
.166 .275 .732 r
.42396 .55634 m .42545 .55913 L .42269 .55746 L F
.889 .698 .638 r
.60254 .3556 m .60084 .35623 L .60177 .35148 L F
.153 0 0 r
.60508 .35631 m .60101 .35696 L .60254 .3556 L F
.485 .287 .535 r
.45458 .49396 m .45483 .49639 L .45667 .49523 L F
.898 .836 .776 r
.47116 .53728 m .47093 .54185 L .46855 .54027 L F
.951 .603 .226 r
.5382 .46091 m .53962 .46216 L .53962 .46035 L F
.072 .185 .678 r
.54108 .45803 m .53962 .46035 L .53855 .4562 L F
.687 .951 .689 r
.5382 .46091 m .53962 .46035 L .54108 .45803 L F
.128 .628 .906 r
.34516 .55556 m .34983 .5569 L .34668 .55631 L F
.998 .853 .539 r
.58457 .40726 m .58545 .40443 L .58444 .40317 L F
.535 .106 .172 r
.6125 .41004 m .61357 .40741 L .60988 .40814 L F
.42 0 .012 r
.61524 .40933 m .61357 .40741 L .6125 .41004 L F
0 .156 .64 r
.6125 .41004 m .60836 .40657 L .611 .40526 L F
.619 .553 .758 r
.61344 .40507 m .6125 .41004 L .611 .40526 L F
.42 0 .012 r
.61508 .40914 m .61648 .40733 L .61357 .40741 L F
.6154 .40908 m .61648 .40733 L .61508 .40914 L F
.619 .553 .758 r
.61344 .40507 m .61524 .40933 L .6125 .41004 L F
.629 .768 .946 r
.61222 .40969 m .61379 .40722 L .61123 .40847 L F
.6125 .41004 m .6127 .4096 L .61222 .40969 L F
.6127 .4096 m .61379 .40722 L .61222 .40969 L F
.42 0 .012 r
.61524 .40933 m .6154 .40908 L .61508 .40914 L F
.465 .292 .561 r
.48239 .52489 m .48508 .52146 L .48283 .52242 L F
0 .474 .717 r
.34568 .63142 m .34957 .63219 L .34716 .63172 L F
.34568 .63142 m .34957 .63219 L .34716 .63172 L F
.5 .272 .499 r
.34957 .63219 m .34746 .63458 L .34716 .63172 L F
.34957 .63219 m .34972 .63507 L .34746 .63458 L F
.701 .963 .942 r
.46991 .43388 m .46526 .43528 L .46873 .43338 L F
.725 .984 .787 r
.47275 .43122 m .46991 .43388 L .47097 .43191 L F
.677 .959 .944 r
.47097 .43191 m .46991 .43388 L .46873 .43338 L F
.337 .069 .351 r
.28265 .6033 m .27995 .60642 L .28245 .60589 L F
.476 .24 .476 r
.28265 .6033 m .28245 .60589 L .27995 .60642 L F
.336 .127 .441 r
.28442 .60509 m .28265 .6033 L .28538 .60316 L F
.28442 .60509 m .28245 .60589 L .28265 .6033 L F
.28442 .60509 m .28265 .6033 L .28538 .60316 L F
.28442 .60509 m .28245 .60589 L .28265 .6033 L F
.874 .888 .841 r
.43191 .56839 m .42993 .57085 L .42868 .56984 L F
.999 .844 .526 r
.42993 .57085 m .42843 .57309 L .42868 .56984 L F
.42993 .57085 m .42935 .57409 L .42843 .57309 L F
.223 0 0 r
.26438 .52176 m .25947 .52331 L .26151 .52207 L F
.401 .742 .993 r
.28303 .65452 m .28749 .65538 L .28567 .65184 L F
.739 .726 .839 r
.28567 .65184 m .28749 .65538 L .28996 .65234 L F
.4 .29 .612 r
.42642 .58285 m .42363 .58039 L .42529 .57916 L F
.42642 .58285 m .42444 .58449 L .42363 .58039 L F
.94 .91 .763 r
.38737 .60265 m .39033 .59986 L .38757 .60197 L F
.957 .892 .506 r
.39078 .59499 m .38973 .59924 L .39033 .59986 L F
.881 .991 .746 r
.38973 .59924 m .38757 .60197 L .39033 .59986 L F
.613 .089 0 r
.57785 .36655 m .57719 .36529 L .57681 .36529 L F
.758 .664 .758 r
.57629 .36442 m .57811 .36687 L .57785 .36655 L F
.655 .136 0 r
.57842 .36728 m .58001 .36831 L .57844 .36703 L F
.57842 .36728 m .57844 .36703 L .57785 .36655 L F
.373 .8 .97 r
.57706 .36749 m .5784 .36757 L .57842 .36728 L F
.613 .089 0 r
.57785 .36655 m .58001 .36831 L .57719 .36529 L F
.231 0 0 r
.57842 .36728 m .58188 .36769 L .58001 .36831 L F
.373 .8 .97 r
.5784 .36757 m .58107 .36772 L .57842 .36728 L F
.758 .664 .758 r
.57811 .36687 m .57842 .36728 L .57785 .36655 L F
.613 .089 0 r
.57785 .36655 m .57681 .36529 L .57488 .36528 L F
.334 .817 .828 r
.65353 .38022 m .65157 .38111 L .65076 .38074 L F
.65353 .38022 m .65408 .38034 L .65157 .38111 L F
0 0 .53 r
.23552 .60378 m .23539 .60485 L .23422 .60276 L F
.763 .801 .316 r
.23536 .60423 m .23539 .60485 L .23552 .60378 L F
0 0 .438 r
.23539 .60485 m .23541 .60518 L .23422 .60276 L F
.763 .801 .316 r
.23431 .60729 m .23539 .60485 L .23536 .60423 L F
0 0 .438 r
.23539 .60485 m .23607 .60651 L .23541 .60518 L F
.968 .728 .293 r
.23431 .60729 m .23607 .60651 L .23539 .60485 L F
.23431 .60729 m .23605 .60924 L .23607 .60651 L F
.626 .099 0 r
.41269 .59709 m .41096 .5959 L .40872 .59355 L F
.747 .502 0 r
.41269 .59709 m .41296 .59934 L .41096 .5959 L F
.41269 .59709 m .41313 .59974 L .41296 .59934 L F
.816 .707 .746 r
.51457 .46951 m .51843 .46967 L .51699 .46579 L F
.65 .166 .09 r
.51782 .47124 m .51843 .46967 L .51457 .46951 L F
.489 .528 .824 r
.51699 .46579 m .51843 .46967 L .52071 .46882 L F
.073 0 0 r
.52071 .46882 m .51843 .46967 L .51782 .47124 L F
.522 .917 .9 r
.43813 .44725 m .44058 .44612 L .44184 .4463 L F
.502 .907 .902 r
.44304 .44505 m .44467 .44507 L .44184 .4463 L F
.502 .907 .899 r
.44058 .44612 m .44304 .44505 L .44184 .4463 L F
.534 .326 .544 r
.49616 .49526 m .49817 .49204 L .49625 .4925 L F
.894 .5 .269 r
.34848 .50354 m .34996 .50197 L .34754 .50164 L F
.34848 .50354 m .35131 .50524 L .34996 .50197 L F
.926 .734 .249 r
.23035 .56939 m .23083 .57163 L .23072 .57001 L F
.23035 .56939 m .23072 .57001 L .23062 .56857 L F
.407 .617 .937 r
.23161 .56898 m .23083 .57163 L .23035 .56939 L F
.408 .175 .446 r
.22884 .57256 m .23161 .56898 L .23035 .56939 L F
0 0 0 r
.23161 .56898 m .23018 .56989 L .23035 .56939 L F
.096 0 .151 r
.22768 .57235 m .22884 .57256 L .23035 .56939 L F
0 0 0 r
.23018 .56989 m .22887 .57074 L .23035 .56939 L F
.926 .734 .249 r
.23035 .56939 m .23062 .56857 L .23055 .56747 L F
.031 0 .153 r
.23267 .56645 m .23035 .56939 L .23055 .56747 L F
.23267 .56645 m .23161 .56898 L .23035 .56939 L F
.304 .721 .975 r
.23035 .56939 m .23161 .56898 L .22986 .56858 L F
.726 .602 .718 r
.22557 .56622 m .22887 .57074 L .23035 .56939 L F
.22557 .56622 m .23035 .56939 L .22796 .56814 L F
.304 .721 .975 r
.23035 .56939 m .22986 .56858 L .22796 .56814 L F
.716 .986 .819 r
.566 .47213 m .56708 .47015 L .56525 .4718 L F
.566 .47213 m .56918 .46951 L .56708 .47015 L F
.825 .709 .737 r
.34616 .62943 m .34716 .63172 L .34568 .63142 L F
.45 0 .041 r
.67661 .32222 m .67934 .32235 L .67538 .32295 L F
.45 .871 .749 r
.65716 .39064 m .66058 .38887 L .65896 .38936 L F
.5 .897 .758 r
.65896 .38936 m .66058 .38887 L .66285 .38742 L F
.73 .573 .678 r
.70282 .30669 m .70099 .30759 L .70013 .30434 L F
.056 0 0 r
.67892 .30336 m .68071 .3039 L .68112 .30196 L F
.67892 .30336 m .6784 .30515 L .68071 .3039 L F
.913 .516 .22 r
.36493 .51835 m .36544 .52036 L .36724 .521 L F
.897 .589 .455 r
.36544 .52036 m .36874 .52419 L .36724 .521 L F
.993 .753 .395 r
.3911 .58197 m .39233 .58049 L .3909 .57945 L F
.3911 .58197 m .3922 .58305 L .39233 .58049 L F
.374 0 0 r
.25065 .52175 m .25262 .52245 L .25483 .52097 L F
0 0 0 r
.25262 .52245 m .25716 .5209 L .25483 .52097 L F
.45 .871 .749 r
.65716 .39064 m .65896 .38936 L .6569 .39103 L F
.152 0 .154 r
.62179 .39024 m .62253 .38747 L .62067 .38967 L F
.872 .904 .851 r
.62414 .38316 m .62253 .38747 L .62595 .38715 L F
.805 .677 .722 r
.62179 .39024 m .62595 .38715 L .62253 .38747 L F
.491 .716 .971 r
.33628 .52153 m .33728 .51947 L .33493 .51973 L F
.33628 .52153 m .33882 .52141 L .33728 .51947 L F
.172 0 .193 r
.51264 .50826 m .5098 .51131 L .51052 .50932 L F
.193 0 .241 r
.5098 .51131 m .50702 .5145 L .50768 .51238 L F
.988 .77 .52 r
.38943 .57559 m .39137 .57389 L .38955 .57289 L F
.38943 .57559 m .391 .57668 L .39137 .57389 L F
.721 .779 .898 r
.5491 .4584 m .54992 .46019 L .54646 .45973 L F
.507 .658 .928 r
.55226 .45857 m .54992 .46019 L .5491 .4584 L F
.334 .309 .682 r
.55226 .45857 m .55229 .4617 L .54992 .46019 L F
.528 .582 .853 r
.55439 .46327 m .5518 .46149 L .55229 .4617 L F
.31 .797 .886 r
.55439 .46327 m .5511 .46359 L .55229 .4617 L F
.507 .298 .531 r
.55357 .46134 m .55357 .4613 L .55274 .463 L F
.961 .89 .714 r
.5542 .46007 m .55406 .46427 L .55274 .463 L F
.195 .32 .765 r
.55439 .46327 m .55706 .46528 L .55783 .4632 L F
.853 .665 .647 r
.55419 .4641 m .55706 .46528 L .55406 .46427 L F
.928 .908 .782 r
.55706 .46528 m .55398 .46695 L .55406 .46427 L F
.89 .96 .836 r
.55864 .461 m .55706 .46528 L .55419 .4641 L F
.961 .89 .714 r
.55421 .46002 m .55419 .4641 L .55406 .46427 L F
.702 .696 .841 r
.55864 .461 m .55419 .4641 L .55421 .46002 L F
.377 .209 .523 r
.55589 .46163 m .5539 .4605 L .55414 .46534 L F
.961 .89 .714 r
.55418 .46004 m .55357 .4613 L .55229 .4617 L F
.55357 .4613 m .55318 .46209 L .55313 .46207 L F
.55357 .4613 m .55313 .46207 L .55229 .4617 L F
.452 .697 .972 r
.55024 .45655 m .55226 .45857 L .5491 .4584 L F
0 0 .288 r
.55437 .45759 m .55229 .4617 L .55226 .45857 L F
.55419 .45795 m .55421 .46002 L .55229 .4617 L F
.55437 .45759 m .55421 .46002 L .55419 .45795 L F
.552 .743 .966 r
.55437 .45759 m .55226 .45857 L .55024 .45655 L F
.549 .508 .763 r
.55024 .45655 m .55191 .46055 L .55421 .46002 L F
.55191 .46055 m .5525 .46197 L .55421 .46002 L F
.961 .89 .714 r
.55421 .46002 m .5542 .46007 L .55357 .46134 L F
.55421 .46002 m .55361 .46122 L .55418 .46004 L F
.55361 .46122 m .55318 .46209 L .55357 .4613 L F
.55361 .46122 m .55357 .4613 L .55418 .46004 L F
.377 .209 .523 r
.55391 .46069 m .55357 .46134 L .55414 .46534 L F
.019 0 .211 r
.55421 .46002 m .55363 .46118 L .55341 .46022 L F
.961 .89 .714 r
.55421 .46002 m .55357 .46134 L .55363 .46118 L F
.507 .298 .531 r
.55357 .4613 m .55356 .46128 L .55274 .463 L F
.961 .89 .714 r
.55319 .46209 m .55274 .463 L .55229 .4617 L F
.019 0 .211 r
.55403 .46031 m .5525 .46197 L .55266 .46264 L F
.55413 .4601 m .5525 .46197 L .55403 .46031 L F
.377 .209 .523 r
.55359 .46125 m .55356 .46128 L .55357 .4613 L F
.961 .89 .714 r
.55421 .46002 m .55319 .46209 L .55318 .46209 L F
.019 0 .211 r
.55363 .46118 m .55266 .46264 L .55274 .463 L F
.55421 .46002 m .55266 .46264 L .55363 .46118 L F
.507 .298 .531 r
.55356 .46128 m .55341 .46022 L .55274 .463 L F
.019 0 .211 r
.55421 .46002 m .55413 .4601 L .55403 .46031 L F
.377 .209 .523 r
.55363 .46115 m .55341 .46022 L .55356 .46128 L F
.55363 .46115 m .55356 .46128 L .55359 .46125 L F
.5539 .4605 m .55363 .46118 L .55391 .46069 L F
.55363 .46118 m .55357 .46134 L .55391 .46069 L F
.019 0 .211 r
.55363 .46118 m .55274 .463 L .55341 .46022 L F
.377 .209 .523 r
.5539 .4605 m .55341 .46022 L .55363 .46115 L F
.437 .168 .406 r
.55421 .46067 m .55421 .46002 L .55341 .46022 L F
.55589 .46163 m .55421 .46002 L .55421 .46067 L F
.377 .209 .523 r
.55363 .46118 m .55357 .4613 L .55357 .46134 L F
.5539 .4605 m .55357 .4613 L .55363 .46118 L F
.961 .89 .714 r
.55363 .46118 m .55357 .46134 L .55274 .463 L F
0 0 .015 r
.55406 .46427 m .55414 .46534 L .55274 .463 L F
.507 .298 .531 r
.55414 .46534 m .55357 .46134 L .55274 .463 L F
.528 .582 .853 r
.5518 .46149 m .54992 .46019 L .55229 .4617 L F
.78 .284 .026 r
.60177 .35148 m .59955 .35128 L .60108 .35131 L F
.803 .905 .913 r
.61768 .38394 m .61902 .38542 L .62131 .38302 L F
.61768 .38394 m .61902 .38542 L .62131 .38302 L F
.6 .927 .965 r
.6122 .4034 m .61356 .40135 L .61094 .40225 L F
.6122 .4034 m .61551 .40184 L .61356 .40135 L F
.942 .677 .506 r
.3935 .52812 m .39142 .52731 L .39153 .52468 L F
.948 .699 .528 r
.3935 .52812 m .39125 .52954 L .39142 .52731 L F
.3935 .52812 m .39337 .53061 L .39125 .52954 L F
.458 .677 .959 r
.2471 .56509 m .24785 .56296 L .24593 .56313 L F
.2471 .56509 m .2499 .56496 L .24785 .56296 L F
0 0 0 r
.61471 .3706 m .61243 .37239 L .61162 .37381 L F
.956 .625 .232 r
.23192 .57879 m .23289 .58286 L .23419 .58373 L F
.548 .381 .607 r
.23153 .58381 m .23394 .5863 L .23419 .58373 L F
.956 .625 .232 r
.23192 .57879 m .23289 .58286 L .23419 .58373 L F
.989 .727 .372 r
.23289 .58286 m .23394 .5863 L .23419 .58373 L F
.508 .22 .412 r
.32972 .53788 m .33229 .53757 L .33108 .53702 L F
0 0 0 r
.6474 .3296 m .64909 .32824 L .64953 .32786 L F
.6474 .3296 m .6489 .32993 L .64909 .32824 L F
.6474 .3296 m .64634 .33104 L .6489 .32993 L F
.811 .738 .783 r
.60986 .39084 m .61363 .39152 L .61277 .38809 L F
.737 .277 .157 r
.61221 .39293 m .61363 .39152 L .60986 .39084 L F
.403 0 0 r
.61496 .39276 m .61363 .39152 L .61221 .39293 L F
.843 .503 0 r
.57735 .38687 m .5789 .39075 L .57825 .38846 L F
.889 .948 .84 r
.35801 .60839 m .35877 .60974 L .36079 .60649 L F
.547 .445 .691 r
.35877 .60974 m .36158 .60937 L .36079 .60649 L F
.751 .304 .191 r
.35801 .60839 m .36158 .60937 L .35877 .60974 L F
.398 .851 .897 r
.72483 .32684 m .72772 .32595 L .72534 .32592 L F
.606 .243 .327 r
.53677 .44911 m .53689 .4474 L .534 .44772 L F
.363 0 .15 r
.53928 .44827 m .53689 .4474 L .53677 .44911 L F
.53928 .44827 m .53993 .44694 L .53689 .4474 L F
.797 .768 .827 r
.41038 .49194 m .41441 .49208 L .41289 .49051 L F
.176 .361 .809 r
.41634 .45705 m .418 .4603 L .41868 .4587 L F
.93 .645 .479 r
.42077 .45968 m .41868 .4587 L .418 .4603 L F
.972 .714 .482 r
.23578 .612 m .23781 .61306 L .23605 .60924 L F
.973 .755 .549 r
.23578 .612 m .23746 .61582 L .23781 .61306 L F
.483 .888 .94 r
.61432 .35116 m .61058 .35184 L .61175 .35262 L F
.452 .824 .575 r
.32226 .5852 m .32326 .58445 L .32508 .58301 L F
.32226 .5852 m .32508 .58301 L .32463 .58573 L F
.093 .585 .901 r
.32226 .5852 m .32463 .58573 L .32294 .58514 L F
.516 .916 .858 r
.32129 .5853 m .32326 .58445 L .32226 .5852 L F
.093 .585 .901 r
.32226 .5852 m .32294 .58514 L .3209 .58442 L F
.516 .916 .858 r
.32017 .58578 m .32129 .5853 L .32226 .5852 L F
.503 .51 .797 r
.50544 .47182 m .50723 .46792 L .50389 .4684 L F
.50544 .47182 m .50786 .47122 L .50723 .46792 L F
.592 .6 .829 r
.49714 .46627 m .50118 .46898 L .50004 .46586 L F
.618 .601 .811 r
.50004 .46586 m .50118 .46898 L .50367 .46622 L F
.601 .574 .795 r
.50118 .46898 m .50389 .4684 L .50367 .46622 L F
.548 .381 .607 r
.23153 .58381 m .23127 .58704 L .23394 .5863 L F
.227 0 .29 r
.48646 .51797 m .49064 .51495 L .48727 .51492 L F
0 0 .412 r
.46158 .56271 m .46103 .56329 L .46137 .56445 L F
0 0 0 r
.46103 .56329 m .463 .56076 L .46035 .56402 L F
.923 .975 .722 r
.46296 .558 m .46312 .56033 L .46103 .56329 L F
0 0 .412 r
.46175 .56124 m .46103 .56329 L .46158 .56271 L F
0 0 0 r
.46103 .56329 m .46035 .56402 L .46024 .56416 L F
.663 .865 .48 r
.46312 .56033 m .463 .56076 L .46103 .56329 L F
.27 .362 .773 r
.42256 .48513 m .42397 .4897 L .42526 .48735 L F
.665 .699 .871 r
.42268 .49038 m .42526 .48735 L .42397 .4897 L F
.382 .049 .271 r
.29471 .58098 m .29655 .5823 L .294 .5828 L F
.29471 .58098 m .29759 .57952 L .29655 .5823 L F
0 0 0 r
.56816 .45525 m .56708 .45705 L .56632 .45909 L F
.43759 .49164 m .43744 .49178 L .43478 .49271 L F
.43478 .49271 m .43744 .49178 L .43759 .49164 L F
.047 .225 .725 r
.57539 .3759 m .57516 .37353 L .57525 .37378 L F
0 0 .357 r
.57525 .37378 m .57504 .37231 L .57387 .36981 L F
.047 .225 .725 r
.57516 .37353 m .57504 .37231 L .57525 .37378 L F
0 0 .483 r
.57532 .37395 m .57525 .37378 L .57385 .37206 L F
.57625 .37515 m .57525 .37378 L .57532 .37395 L F
.95 .689 .232 r
.57607 .37697 m .57525 .37378 L .57625 .37515 L F
.334 .131 .449 r
.23737 .55957 m .23587 .55758 L .23761 .55715 L F
.23737 .55957 m .23534 .56033 L .23587 .55758 L F
.614 .571 .783 r
.49714 .46627 m .49954 .46293 L .496 .46234 L F
.49714 .46627 m .50004 .46586 L .49954 .46293 L F
.781 .707 .782 r
.35178 .5772 m .34754 .57666 L .34999 .57433 L F
.723 .611 .732 r
.35437 .60357 m .35474 .60648 L .35175 .60647 L F
.608 .304 .43 r
.33765 .52827 m .33997 .53066 L .34035 .52827 L F
.33765 .52827 m .33997 .53066 L .34035 .52827 L F
.606 .243 .327 r
.53677 .44911 m .534 .44772 L .53411 .44967 L F
0 0 .401 r
.23037 .60613 m .23137 .60888 L .23076 .6052 L F
.719 .222 0 r
.58314 .39629 m .58302 .39653 L .58453 .3977 L F
.933 .574 .31 r
.58303 .39908 m .58453 .3977 L .58302 .39653 L F
.58303 .39908 m .58539 .40079 L .58453 .3977 L F
.874 .888 .841 r
.43191 .56839 m .42868 .56984 L .43052 .56746 L F
.735 .991 .838 r
.5201 .40875 m .51892 .41101 L .52183 .40812 L F
.376 .164 .459 r
.52142 .41247 m .51892 .41101 L .5201 .40875 L F
.52142 .41247 m .51893 .41339 L .51892 .41101 L F
.848 .76 .765 r
.71249 .30537 m .7165 .30365 L .71461 .30211 L F
.71249 .30537 m .71441 .30688 L .7165 .30365 L F
.602 .942 .937 r
.25027 .54586 m .25239 .54469 L .25009 .54462 L F
.515 .747 .979 r
.71742 .27758 m .71939 .27506 L .71624 .27687 L F
.71742 .27758 m .72046 .27708 L .71939 .27506 L F
.882 .498 .306 r
.44232 .4791 m .44087 .48082 L .43975 .47939 L F
.904 .956 .82 r
.44232 .4791 m .44345 .47548 L .44464 .47883 L F
.44232 .4791 m .43975 .47939 L .44345 .47548 L F
.81 .592 .608 r
.44464 .47883 m .44087 .48082 L .44232 .4791 L F
.491 .427 .713 r
.35093 .63906 m .34828 .63935 L .34746 .63458 L F
.736 .939 .952 r
.61047 .42741 m .61189 .42808 L .61297 .42576 L F
.491 .427 .713 r
.35093 .63906 m .34746 .63458 L .34972 .63507 L F
.54 .383 .617 r
.36317 .57565 m .36485 .5774 L .36196 .57798 L F
1 .829 .524 r
.38967 .59185 m .39133 .5901 L .39031 .58911 L F
.38967 .59185 m .39063 .59322 L .39133 .5901 L F
.768 .661 .744 r
.36539 .62589 m .3631 .62933 L .36211 .6257 L F
.316 0 0 r
.43762 .59754 m .43821 .59807 L .43534 .59739 L F
.43762 .59754 m .43962 .59837 L .43821 .59807 L F
.254 .187 .585 r
.62321 .39648 m .62089 .39396 L .62294 .39342 L F
.62321 .39648 m .62077 .39759 L .62089 .39396 L F
.652 .888 .983 r
.4592 .57454 m .46 .57702 L .46144 .57406 L F
.553 .775 .981 r
.46 .57702 m .46316 .57648 L .46144 .57406 L F
.599 .947 .914 r
.51056 .40657 m .50832 .40794 L .506 .40798 L F
.852 .795 .795 r
.24824 .53899 m .24427 .54041 L .24461 .53786 L F
0 0 0 r
.25145 .53593 m .25118 .53627 L .25003 .53735 L F
.458 .603 .907 r
.25003 .53735 m .25029 .53873 L .24828 .53899 L F
0 0 0 r
.25118 .53627 m .24878 .53927 L .25003 .53735 L F
.458 .603 .907 r
.25003 .53735 m .24828 .53899 L .24824 .53899 L F
.319 .319 .702 r
.25567 .59535 m .25404 .5975 L .25356 .59596 L F
.377 .624 .949 r
.31887 .61816 m .32289 .61617 L .31864 .61567 L F
.31887 .61816 m .32099 .61795 L .32289 .61617 L F
0 0 .02 r
.23112 .53808 m .22859 .54123 L .22968 .54043 L F
0 0 .328 r
.22864 .54399 m .22968 .54043 L .22859 .54123 L F
.888 .865 .811 r
.34347 .57613 m .3449 .57775 L .3478 .57391 L F
.34347 .57613 m .3478 .57391 L .34754 .57666 L F
.754 .923 .561 r
.3484 .57221 m .3478 .57391 L .34965 .57098 L F
.31 .6 .948 r
.3484 .57221 m .34999 .57433 L .3478 .57391 L F
.538 .317 .528 r
.34999 .57433 m .34754 .57666 L .3478 .57391 L F
.848 .964 .635 r
.42388 .5643 m .4221 .56577 L .42236 .56622 L F
.973 .92 .601 r
.42315 .56335 m .4221 .56577 L .42388 .5643 L F
.024 0 0 r
.61333 .37558 m .61217 .37682 L .60949 .37779 L F
0 0 .016 r
.61526 .37319 m .61511 .37401 L .61333 .37558 L F
0 0 0 r
.61439 .3754 m .61333 .37558 L .61511 .37401 L F
.61439 .3754 m .61217 .37682 L .61333 .37558 L F
.724 .736 .86 r
.4082 .49497 m .41038 .49194 L .40805 .49324 L F
.729 .423 .461 r
.34165 .55322 m .34441 .55462 L .34598 .55108 L F
.525 .203 .364 r
.34598 .55108 m .34441 .55462 L .34802 .5529 L F
.621 .472 .658 r
.34598 .55108 m .34907 .55111 L .34854 .54773 L F
.558 .194 .306 r
.34598 .55108 m .34802 .5529 L .34907 .55111 L F
.73 .78 .892 r
.48915 .46029 m .4926 .46063 L .49162 .45889 L F
.507 .637 .912 r
.49162 .45889 m .4926 .46063 L .49496 .46002 L F
.551 .572 .828 r
.4926 .46063 m .496 .46234 L .49496 .46002 L F
.774 .726 .808 r
.33698 .57367 m .33896 .57451 L .34095 .57376 L F
.246 0 .273 r
.34095 .57376 m .33794 .5771 L .33698 .57367 L F
.34095 .57376 m .34054 .57627 L .33794 .5771 L F
.253 .591 .948 r
.32481 .65656 m .32874 .6586 L .32758 .65585 L F
.883 .897 .836 r
.32874 .6586 m .32963 .65432 L .32758 .65585 L F
.32874 .6586 m .33135 .6553 L .32963 .65432 L F
.429 .772 .997 r
.31831 .58467 m .32017 .58578 L .32226 .5852 L F
.749 .526 .593 r
.56142 .3977 m .55666 .4006 L .55593 .39726 L F
.56142 .3977 m .56077 .40098 L .55666 .4006 L F
.312 .123 .456 r
.56291 .39961 m .56142 .3977 L .56279 .39695 L F
.56291 .39961 m .56077 .40098 L .56142 .3977 L F
.574 .378 .578 r
.42256 .48513 m .42509 .48215 L .4227 .48266 L F
.878 .858 .817 r
.56573 .40617 m .56304 .41043 L .5624 .40786 L F
.573 .342 .528 r
.36756 .57361 m .36741 .57634 L .36317 .57565 L F
.57 .385 .591 r
.36741 .57634 m .36485 .5774 L .36317 .57565 L F
.906 .915 .519 r
.56774 .45481 m .5691 .45347 L .56816 .45525 L F
.069 0 0 r
.57177 .45286 m .5691 .45347 L .56774 .45481 L F
.633 .639 .839 r
.22841 .57739 m .23054 .58087 L .23192 .57879 L F
.336 .252 .612 r
.23054 .58087 m .23289 .58286 L .23192 .57879 L F
.442 .208 .463 r
.47061 .59333 m .4734 .59015 L .473 .59264 L F
0 0 0 r
.47522 .58657 m .47493 .58861 L .4734 .59015 L F
0 0 .222 r
.4734 .59015 m .47455 .5914 L .473 .59264 L F
.4734 .59015 m .47493 .58861 L .47455 .5914 L F
.607 .949 .799 r
.27104 .51861 m .26947 .52003 L .2701 .52003 L F
.066 0 .001 r
.27104 .51861 m .27006 .5196 L .26947 .52003 L F
.356 .83 .854 r
.26947 .52003 m .26868 .52061 L .2701 .52003 L F
.066 0 .001 r
.27006 .5196 m .26758 .52211 L .26947 .52003 L F
.356 .83 .854 r
.26947 .52003 m .26817 .52083 L .26868 .52061 L F
.26947 .52003 m .26666 .5209 L .26817 .52083 L F
.493 .253 .48 r
.33747 .59008 m .34015 .58963 L .34054 .58711 L F
.351 .139 .445 r
.34015 .58963 m .34255 .58629 L .34054 .58711 L F
.491 .395 .675 r
.30676 .5738 m .30865 .57025 L .30663 .57168 L F
.30676 .5738 m .30901 .57318 L .30865 .57025 L F
.43 .191 .449 r
.30901 .57318 m .30633 .57644 L .30676 .5738 L F
.701 .946 .958 r
.30663 .57168 m .30185 .57272 L .30405 .57256 L F
.815 .629 .65 r
.30405 .57256 m .30865 .57025 L .30663 .57168 L F
.943 .578 .239 r
.59151 .39347 m .59318 .39479 L .59207 .3959 L F
.878 .446 .155 r
.59318 .39479 m .59411 .3969 L .59207 .3959 L F
.643 .888 .985 r
.3662 .49639 m .36655 .49819 L .36409 .49821 L F
.3662 .49639 m .36765 .49755 L .36655 .49819 L F
.874 .628 .563 r
.36655 .49819 m .36334 .5008 L .36409 .49821 L F
.36655 .49819 m .36629 .50125 L .36334 .5008 L F
.798 .314 .054 r
.71939 .27506 m .7208 .27402 L .71842 .2729 L F
.71939 .27506 m .72217 .27607 L .7208 .27402 L F
.723 .835 .934 r
.32094 .62296 m .32424 .62276 L .32266 .62187 L F
.591 .498 .717 r
.32424 .62276 m .32927 .6266 L .32722 .62248 L F
.32927 .6266 m .32964 .62688 L .32934 .62633 L F
.32927 .6266 m .32934 .62633 L .32722 .62248 L F
.178 .432 .865 r
.32492 .62157 m .32871 .62583 L .32424 .62276 L F
.791 .707 .771 r
.3291 .62722 m .33001 .62761 L .3294 .62678 L F
.32811 .62867 m .32875 .62848 L .3291 .62722 L F
.32875 .62848 m .3307 .6279 L .3291 .62722 L F
.14 0 .273 r
.33018 .62772 m .32811 .62867 L .3294 .62678 L F
.791 .707 .771 r
.3294 .62678 m .3307 .6279 L .33042 .62527 L F
.496 .455 .742 r
.32722 .62248 m .32955 .62671 L .32845 .6213 L F
.32955 .62671 m .32964 .62688 L .3296 .62667 L F
.32955 .62671 m .3296 .62667 L .32845 .6213 L F
.14 0 .273 r
.33042 .62528 m .3294 .62678 L .33042 .62527 L F
.32964 .62659 m .3294 .62678 L .33042 .62528 L F
.776 .64 .711 r
.32845 .6213 m .3296 .62667 L .32492 .62157 L F
.3296 .62667 m .32964 .62688 L .32954 .62677 L F
.3296 .62667 m .32954 .62677 L .32492 .62157 L F
.14 0 .273 r
.33034 .62606 m .32964 .62659 L .33042 .62528 L F
.33028 .62671 m .32947 .62677 L .33034 .62606 L F
.32947 .62677 m .3294 .62678 L .33034 .62606 L F
.178 .432 .865 r
.32954 .62677 m .32964 .62688 L .32949 .62677 L F
.791 .707 .771 r
.33001 .62761 m .3307 .6279 L .3294 .62678 L F
.14 0 .273 r
.33018 .62772 m .3294 .62678 L .33028 .62671 L F
.178 .432 .865 r
.32871 .62583 m .32954 .62677 L .32927 .6266 L F
.32954 .62677 m .32949 .62677 L .32927 .6266 L F
.32871 .62583 m .32927 .6266 L .32424 .62276 L F
.488 .802 1 r
.56441 .43322 m .56494 .43385 L .567 .43301 L F
.045 0 0 r
.56478 .43502 m .56494 .43385 L .567 .43301 L F
.56478 .43502 m .56494 .43385 L .567 .43301 L F
.701 .758 .896 r
.47004 .45531 m .47191 .45751 L .4741 .456 L F
.073 .632 .794 r
.39514 .45412 m .3983 .4542 L .39843 .4543 L F
.948 .938 .746 r
.69146 .32945 m .6888 .33145 L .68936 .3281 L F
.69146 .32945 m .68967 .33275 L .6888 .33145 L F
.394 .213 .514 r
.34046 .57882 m .33794 .5771 L .34054 .57627 L F
.34046 .57882 m .33787 .57988 L .33794 .5771 L F
.984 .768 .532 r
.25777 .60873 m .25972 .60909 L .25823 .60565 L F
.453 .559 .872 r
.26229 .60885 m .25972 .60909 L .25823 .60565 L F
.187 .71 .867 r
.26229 .60885 m .25972 .60909 L .25777 .60873 L F
0 0 0 r
.54735 .44114 m .5463 .44095 L .54494 .44251 L F
.54735 .44114 m .5488 .43945 L .5463 .44095 L F
.851 .83 .356 r
.69849 .36453 m .69921 .36223 L .69934 .35985 L F
.706 .7 .842 r
.35115 .53145 m .35259 .53266 L .35489 .53134 L F
.852 .954 .878 r
.59829 .43121 m .59626 .43359 L .59556 .43168 L F
.877 .644 .119 r
.59556 .43168 m .59626 .43359 L .59641 .43645 L F
.814 .561 .556 r
.59626 .43359 m .59941 .43693 L .59641 .43645 L F
.672 .731 .894 r
.45027 .45657 m .45021 .45532 L .44747 .45646 L F
.526 .614 .883 r
.45027 .45657 m .45292 .45483 L .45021 .45532 L F
.134 0 .269 r
.45143 .45946 m .45027 .45657 L .45055 .45963 L F
.45143 .45946 m .45292 .45483 L .45027 .45657 L F
.656 .885 .982 r
.47791 .4622 m .4797 .46344 L .48206 .46223 L F
.532 .601 .868 r
.55371 .41414 m .55523 .41075 L .55167 .41122 L F
.55371 .41414 m .55678 .41446 L .55523 .41075 L F
.567 .835 .996 r
.30397 .53686 m .30157 .53768 L .30574 .53805 L F
.30574 .53805 m .30157 .53768 L .30397 .53686 L F
.39 .752 .993 r
.30574 .53805 m .30845 .53788 L .30397 .53686 L F
.30574 .53805 m .30845 .53788 L .30397 .53686 L F
0 0 0 r
.61547 .34398 m .61811 .34324 L .61953 .3426 L F
.61953 .3426 m .62061 .34219 L .62238 .34223 L F
.61953 .3426 m .61811 .34324 L .62061 .34219 L F
.47061 .59333 m .47083 .5939 L .46909 .59504 L F
.47061 .59333 m .473 .59264 L .47083 .5939 L F
.872 .642 .588 r
.33619 .50966 m .34005 .50858 L .3378 .50858 L F
.33619 .50966 m .33997 .51161 L .34005 .50858 L F
.451 0 0 r
.34265 .5078 m .3378 .50858 L .34005 .50858 L F
.264 .142 .519 r
.34005 .50858 m .34129 .5105 L .34265 .5078 L F
.34005 .50858 m .33997 .51161 L .34129 .5105 L F
.85 .752 .754 r
.52952 .41866 m .53116 .42052 L .53434 .41652 L F
.637 .431 .587 r
.53434 .41652 m .53116 .42052 L .5333 .41908 L F
.743 .281 .155 r
.5333 .41908 m .53484 .41596 L .53434 .41652 L F
.409 0 0 r
.33172 .50243 m .33266 .50312 L .33016 .50116 L F
.33172 .50243 m .33503 .50463 L .33266 .50312 L F
0 0 .219 r
.49476 .53412 m .49409 .53662 L .49202 .53779 L F
0 0 .12 r
.49293 .53858 m .49202 .53779 L .49409 .53662 L F
.49293 .53858 m .49197 .54019 L .49202 .53779 L F
.509 .27 .487 r
.60645 .38028 m .60949 .37779 L .6069 .37689 L F
0 0 0 r
.6069 .38008 m .60937 .37751 L .60857 .37932 L F
.60645 .38028 m .60702 .37974 L .6069 .38008 L F
.60702 .37974 m .60937 .37751 L .6069 .38008 L F
.52 .233 .42 r
.60823 .37637 m .60949 .37779 L .61016 .37561 L F
.6069 .37689 m .60792 .37724 L .60823 .37637 L F
0 0 0 r
.60702 .37974 m .60571 .38104 L .60937 .37751 L F
.60645 .38028 m .60601 .38074 L .60702 .37974 L F
.60601 .38074 m .60571 .38104 L .60702 .37974 L F
.52 .233 .42 r
.60792 .37724 m .60914 .37767 L .60823 .37637 L F
.60914 .37767 m .60949 .37779 L .60927 .37754 L F
.60914 .37767 m .60927 .37754 L .60823 .37637 L F
.227 0 .29 r
.48646 .51797 m .48976 .51676 L .49064 .51495 L F
.257 .111 .483 r
.48715 .52064 m .48976 .51676 L .48646 .51797 L F
.28 .15 .519 r
.65775 .37533 m .65774 .37812 L .65947 .37628 L F
.674 .541 .695 r
.43662 .54744 m .43461 .54314 L .43336 .54734 L F
.9 .873 .801 r
.43231 .54998 m .43662 .54744 L .43336 .54734 L F
.43231 .54998 m .43417 .55081 L .43662 .54744 L F
.431 .86 .936 r
.43613 .44695 m .43528 .44816 L .43371 .44825 L F
.43613 .44695 m .43813 .44725 L .43528 .44816 L F
.497 .571 .861 r
.27964 .65135 m .28303 .65452 L .28152 .65125 L F
.696 .745 .889 r
.28152 .65125 m .28303 .65452 L .28567 .65184 L F
.42 0 0 r
.59555 .35369 m .59302 .35512 L .59026 .35398 L F
.132 .458 .887 r
.59423 .35258 m .59678 .3536 L .59555 .35369 L F
.583 .095 .063 r
.59678 .3536 m .59302 .35512 L .59555 .35369 L F
.465 .292 .561 r
.48239 .52489 m .48509 .52432 L .48508 .52146 L F
.404 .161 .429 r
.48241 .52654 m .48362 .52528 L .48509 .52432 L F
.098 0 .292 r
.48365 .52528 m .48509 .52432 L .48362 .52528 L F
.404 .161 .429 r
.48361 .52531 m .48509 .52432 L .48444 .52446 L F
.48241 .52654 m .48465 .52468 L .48361 .52531 L F
.191 0 .117 r
.48365 .52528 m .48308 .52825 L .48672 .52541 L F
.48362 .52528 m .48362 .52531 L .48365 .52528 L F
.48362 .52531 m .48308 .52825 L .48365 .52528 L F
.404 .161 .429 r
.48465 .52468 m .48509 .52432 L .48365 .52528 L F
.48465 .52468 m .48365 .52528 L .48361 .52531 L F
.098 0 .292 r
.48672 .52541 m .48509 .52432 L .48365 .52528 L F
0 0 .113 r
.48241 .52654 m .48308 .52825 L .48362 .52531 L F
.48241 .52654 m .48362 .52531 L .48362 .52528 L F
.404 .161 .429 r
.48241 .52654 m .48444 .52446 L .48239 .52489 L F
.292 0 0 r
.62298 .37603 m .62665 .37514 L .62301 .37562 L F
.648 .428 .57 r
.33447 .59301 m .33754 .59348 L .33747 .59008 L F
.383 .166 .456 r
.33754 .59348 m .34015 .58963 L .33747 .59008 L F
.729 .896 .955 r
.48154 .42686 m .47794 .4271 L .48008 .42553 L F
.814 .933 .91 r
.48299 .42321 m .48154 .42686 L .48008 .42553 L F
.48299 .42321 m .48467 .42432 L .48154 .42686 L F
.991 .796 .546 r
.58802 .38479 m .58615 .3867 L .58505 .38363 L F
.58802 .38479 m .58756 .38823 L .58615 .3867 L F
.842 .532 .463 r
.59641 .43645 m .59941 .43693 L .59922 .43945 L F
0 0 .155 r
.59941 .43693 m .60115 .43245 L .60103 .43497 L F
0 0 .22 r
.59922 .43945 m .59941 .43693 L .60103 .43497 L F
.283 .735 .957 r
.33135 .6553 m .33239 .65441 L .32963 .65432 L F
.33135 .6553 m .33383 .65519 L .33239 .65441 L F
.099 0 0 r
.33135 .6553 m .33524 .65555 L .33383 .65519 L F
.241 .757 .805 r
.60614 .34501 m .60886 .34443 L .6099 .34441 L F
.165 0 0 r
.60886 .34443 m .61287 .34392 L .6099 .34441 L F
.966 .745 .552 r
.37988 .54614 m .38205 .54451 L .38021 .54341 L F
.37988 .54614 m .38176 .54736 L .38205 .54451 L F
.401 .781 .992 r
.58352 .35046 m .58621 .35019 L .58777 .35119 L F
.738 .88 .472 r
.58625 .35324 m .58523 .35569 L .58777 .35119 L F
.39 .771 .991 r
.58621 .35019 m .58973 .35103 L .58777 .35119 L F
.724 .284 .206 r
.58777 .35119 m .59026 .35398 L .58625 .35324 L F
.408 .859 .816 r
.61978 .37236 m .62244 .37167 L .61991 .3726 L F
.716 .985 .809 r
.61991 .3726 m .62244 .37167 L .62373 .36961 L F
.652 .957 .755 r
.6213 .37081 m .61991 .3726 L .62373 .36961 L F
0 0 0 r
.6213 .37081 m .62014 .37303 L .61991 .3726 L F
.62014 .37303 m .6201 .3731 L .61991 .3726 L F
.408 .859 .816 r
.61861 .37266 m .61978 .37236 L .61991 .3726 L F
.954 .768 .614 r
.58673 .44487 m .58994 .44355 L .58647 .44098 L F
.58673 .44487 m .58967 .44524 L .58994 .44355 L F
.872 .961 .625 r
.61077 .41521 m .6099 .41665 L .60986 .41492 L F
.986 .828 .439 r
.70134 .35123 m .70177 .34882 L .70106 .34745 L F
.713 .565 .686 r
.49817 .49204 m .50272 .49225 L .50245 .48942 L F
.625 .5 .69 r
.50245 .48942 m .50272 .49225 L .50522 .4888 L F
.622 .344 .475 r
.41209 .5146 m .41395 .51558 L .41575 .51204 L F
.583 .549 .782 r
.41575 .51204 m .41746 .50877 L .41499 .50973 L F
.41575 .51204 m .41852 .51185 L .41746 .50877 L F
.706 .441 .521 r
.41575 .51204 m .41876 .51456 L .41852 .51185 L F
.41575 .51204 m .41395 .51558 L .41876 .51456 L F
.648 .446 .596 r
.5079 .48553 m .51048 .4824 L .50802 .48269 L F
.5079 .48553 m .51068 .48549 L .51048 .4824 L F
.655 .534 .704 r
.51048 .4824 m .51385 .48206 L .51342 .47889 L F
.513 .268 .48 r
.51068 .48549 m .51385 .48206 L .51048 .4824 L F
.342 .074 .354 r
.62376 .36195 m .62091 .36494 L .62375 .36391 L F
.559 .801 .989 r
.62375 .36391 m .62091 .36494 L .62376 .36195 L F
.405 .196 .479 r
.62632 .35858 m .62376 .36195 L .62641 .36106 L F
.465 .338 .622 r
.62376 .36195 m .6262 .36377 L .62641 .36106 L F
.614 .281 .383 r
.62375 .36391 m .6262 .36377 L .62376 .36195 L F
.977 .676 .337 r
.62632 .35858 m .62641 .36106 L .62376 .36195 L F
.465 .338 .622 r
.62376 .36195 m .6262 .36377 L .62641 .36106 L F
.614 .281 .383 r
.62375 .36391 m .6262 .36377 L .62376 .36195 L F
.739 .319 .251 r
.31321 .58822 m .31113 .58954 L .31317 .58662 L F
.31113 .58954 m .31103 .58944 L .31317 .58662 L F
.31081 .58974 m .31074 .58972 L .31317 .58662 L F
.185 .035 .432 r
.31074 .58972 m .31085 .5851 L .31317 .58662 L F
.424 .362 .684 r
.31101 .59129 m .31084 .58996 L .3107 .58971 L F
.188 0 .088 r
.31081 .58974 m .31101 .59129 L .31065 .58984 L F
.31321 .58822 m .31101 .59129 L .31081 .58974 L F
.424 .362 .684 r
.31101 .59129 m .31123 .59062 L .31084 .58996 L F
.188 0 .088 r
.31321 .58822 m .31354 .59053 L .31101 .59129 L F
.424 .362 .684 r
.31148 .58988 m .31354 .59053 L .31234 .58729 L F
.31101 .59129 m .31247 .59085 L .31148 .58988 L F
.31247 .59085 m .31354 .59053 L .31148 .58988 L F
.739 .319 .251 r
.31113 .58954 m .31081 .58974 L .31103 .58944 L F
.918 .931 .802 r
.31085 .5851 m .30854 .58972 L .30705 .58889 L F
.185 .035 .432 r
.31066 .58957 m .30854 .58972 L .31085 .5851 L F
.424 .362 .684 r
.31064 .58961 m .30962 .58763 L .3095 .58765 L F
.31123 .59062 m .31066 .58957 L .31064 .58961 L F
.31066 .58957 m .30962 .58763 L .31064 .58961 L F
.31101 .59129 m .3107 .58971 L .31045 .58966 L F
.152 .32 .78 r
.31051 .58983 m .31101 .59129 L .30854 .58972 L F
.424 .362 .684 r
.31101 .59129 m .31045 .58966 L .31032 .58963 L F
.152 .32 .78 r
.31065 .58984 m .31101 .59129 L .31051 .58983 L F
.185 .035 .432 r
.31065 .58984 m .31051 .58983 L .31066 .58957 L F
.31051 .58983 m .30854 .58972 L .31066 .58957 L F
.739 .319 .251 r
.31081 .58974 m .31065 .58984 L .31074 .58972 L F
.424 .362 .684 r
.31032 .58963 m .3107 .58971 L .3095 .58765 L F
.185 .035 .432 r
.31066 .58957 m .31085 .5851 L .31074 .58972 L F
.424 .362 .684 r
.31123 .59062 m .31234 .58729 L .30962 .58763 L F
.185 .035 .432 r
.31065 .58984 m .31066 .58957 L .31074 .58972 L F
.232 0 0 r
.61743 .36726 m .62091 .36494 L .61746 .36413 L F
.61743 .36726 m .61994 .36685 L .62091 .36494 L F
.692 .238 .17 r
.62091 .36494 m .62362 .36712 L .62375 .36391 L F
.62091 .36494 m .61994 .36685 L .62362 .36712 L F
.874 .6 .075 r
.57172 .43743 m .57275 .43977 L .57233 .43861 L F
0 0 .547 r
.57233 .43861 m .57275 .43977 L .57424 .44172 L F
.059 .624 .746 r
.34035 .52827 m .34332 .52814 L .3443 .52817 L F
.152 0 .294 r
.34207 .52929 m .34035 .52827 L .3443 .52817 L F
.917 .978 .754 r
.3443 .52817 m .34445 .52429 L .34677 .52754 L F
.3443 .52817 m .34332 .52814 L .34445 .52429 L F
0 0 0 r
.34458 .52832 m .3443 .52817 L .34677 .52754 L F
.34458 .52832 m .34207 .52929 L .3443 .52817 L F
.87 .712 .683 r
.39509 .49267 m .39504 .49494 L .39365 .49197 L F
.842 .581 .544 r
.39533 .49778 m .39577 .49477 L .39504 .49494 L F
.433 .871 .899 r
.52969 .45033 m .52789 .45107 L .5265 .45096 L F
.098 .25 .732 r
.7312 .3098 m .73238 .30772 L .72994 .30568 L F
.66 .864 .479 r
.7312 .3098 m .73034 .31071 L .73238 .30772 L F
.781 .903 .927 r
.44747 .45646 m .44604 .4552 L .4426 .45834 L F
.666 .866 .975 r
.44747 .45646 m .44849 .45398 L .44604 .4552 L F
.44747 .45646 m .45021 .45532 L .44849 .45398 L F
.397 0 0 r
.24037 .59606 m .24145 .59656 L .24397 .59686 L F
.653 .917 .978 r
.24397 .59686 m .24145 .59656 L .24429 .59494 L F
.364 .135 .428 r
.24429 .59494 m .2426 .59708 L .24145 .59656 L F
.2426 .59708 m .24168 .59825 L .24145 .59656 L F
.397 0 0 r
.23969 .59591 m .24145 .59656 L .24037 .59606 L F
.828 .99 .731 r
.24429 .59494 m .24168 .59825 L .24397 .59686 L F
.37 .263 .6 r
.31826 .56425 m .32059 .56622 L .32059 .56339 L F
.195 .256 .699 r
.32059 .56622 m .31826 .56425 L .32059 .56339 L F
.292 .778 .908 r
.58001 .36831 m .58378 .36832 L .58117 .36902 L F
.735 .849 .934 r
.53837 .47174 m .54267 .4714 L .54142 .46878 L F
.595 .132 .124 r
.53837 .47174 m .54141 .47404 L .54267 .4714 L F
.885 .905 .837 r
.54267 .4714 m .54386 .46691 L .54142 .46878 L F
.54267 .4714 m .54501 .46846 L .54386 .46691 L F
.322 .015 .278 r
.629 .35777 m .62956 .35568 L .62632 .35858 L F
.301 .23 .608 r
.63149 .35441 m .62956 .35568 L .63177 .35712 L F
.479 .153 .335 r
.63177 .35712 m .62956 .35568 L .629 .35777 L F
.55 .922 .774 r
.66778 .36906 m .66569 .37092 L .66574 .37083 L F
.66778 .36906 m .66831 .36929 L .66569 .37092 L F
0 0 0 r
.66778 .36906 m .66574 .37083 L .66479 .37234 L F
.66778 .36906 m .66479 .37234 L .66698 .37086 L F
.66778 .36906 m .66698 .37086 L .66742 .3689 L F
.66778 .36906 m .66742 .3689 L .66755 .36831 L F
.55 .922 .774 r
.66778 .36906 m .66944 .3686 L .66831 .36929 L F
.993 .877 .573 r
.4065 .56986 m .40452 .57162 L .40553 .56904 L F
.4065 .56986 m .40543 .57406 L .40452 .57162 L F
.608 .727 .929 r
.3379 .53187 m .33531 .5332 L .33527 .53279 L F
.265 0 .127 r
.42231 .47273 m .42339 .4726 L .42467 .47086 L F
.526 .17 .307 r
.42467 .47086 m .42617 .47197 L .4263 .46908 L F
.42467 .47086 m .42339 .4726 L .42617 .47197 L F
.741 .782 .886 r
.43208 .58305 m .42804 .58572 L .42642 .58285 L F
0 0 0 r
.53252 .42813 m .53301 .42772 L .53545 .42597 L F
.65873 .32207 m .66106 .3213 L .66221 .32002 L F
.66221 .32002 m .66385 .31999 L .66481 .31888 L F
.66221 .32002 m .66106 .3213 L .66385 .31999 L F
.708 .961 .701 r
.56918 .46951 m .57203 .46654 L .57032 .46754 L F
.712 .985 .819 r
.56708 .47015 m .56918 .46951 L .57032 .46754 L F
.419 .384 .713 r
.32075 .57442 m .32286 .5759 L .32331 .57335 L F
.682 .665 .827 r
.62669 .39873 m .63241 .40116 L .6319 .40083 L F
.661 .973 .855 r
.6319 .40083 m .63241 .40116 L .63392 .39919 L F
.605 .88 .559 r
.63392 .39919 m .63241 .40116 L .63107 .40233 L F
0 0 0 r
.62306 .40383 m .61906 .40649 L .62153 .40624 L F
.708 .623 .76 r
.62306 .40383 m .62567 .40119 L .61974 .39919 L F
.555 .012 0 r
.62395 .40566 m .62306 .40383 L .62153 .40624 L F
.961 .709 .51 r
.3871 .5597 m .38886 .56342 L .38905 .56075 L F
.884 .691 .637 r
.4328 .56072 m .42895 .56249 L .42857 .56052 L F
.4328 .56072 m .43237 .56356 L .42895 .56249 L F
.234 .438 .856 r
.23624 .57196 m .23529 .57375 L .23532 .57263 L F
.039 0 .474 r
.23624 .57196 m .23482 .57635 L .23529 .57375 L F
.577 .619 .858 r
.34684 .54435 m .34854 .54773 L .35108 .54712 L F
.435 .342 .651 r
.34854 .54773 m .35129 .55022 L .35108 .54712 L F
.34854 .54773 m .34907 .55111 L .35129 .55022 L F
.862 .45 .247 r
.38148 .51183 m .37926 .51134 L .37778 .50826 L F
.829 .361 .082 r
.38148 .51183 m .38044 .51302 L .37926 .51134 L F
.38148 .51183 m .38315 .51443 L .38044 .51302 L F
.822 .375 .172 r
.38549 .51506 m .38315 .51443 L .38148 .51183 L F
.692 .601 .75 r
.43217 .59145 m .43062 .5957 L .4306 .59267 L F
.763 .765 .854 r
.33524 .65555 m .3382 .6553 L .33383 .65519 L F
.07 .629 .792 r
.58378 .36832 m .58643 .36822 L .5878 .36851 L F
.458 0 0 r
.58643 .36822 m .59083 .36778 L .5878 .36851 L F
.916 .947 .6 r
.59042 .37131 m .5878 .36851 L .59083 .36778 L F
.441 .855 .691 r
.62899 .3393 m .62997 .33839 L .63163 .33843 L F
.62899 .3393 m .62745 .33996 L .62997 .33839 L F
.995 .789 .512 r
.58607 .41282 m .58498 .40985 L .58479 .41133 L F
.951 .875 .467 r
.58479 .41133 m .58415 .41673 L .58607 .41282 L F
.147 0 0 r
.30548 .52162 m .30619 .52146 L .3083 .5201 L F
.875 .469 .253 r
.46966 .53136 m .47375 .5348 L .47383 .53128 L F
.46966 .53136 m .47022 .53361 L .47129 .53273 L F
0 0 .336 r
.47074 .53167 m .47022 .53361 L .46966 .53136 L F
.827 .954 .612 r
.47074 .53167 m .4689 .53469 L .47022 .53361 L F
0 0 0 r
.47022 .53361 m .46821 .53547 L .46698 .53773 L F
.47022 .53361 m .46859 .53521 L .46821 .53547 L F
.827 .954 .612 r
.4689 .53469 m .46859 .53521 L .47022 .53361 L F
.875 .469 .253 r
.47129 .53273 m .47022 .53361 L .47375 .5348 L F
.896 .801 .746 r
.47375 .5348 m .47022 .53361 L .47116 .53728 L F
.921 .695 .579 r
.32941 .59544 m .33001 .60034 L .32748 .5987 L F
.872 .749 .724 r
.71249 .30537 m .71378 .30924 L .71441 .30688 L F
0 .182 .709 r
.56101 .42972 m .56156 .42917 L .56032 .42672 L F
.56101 .42972 m .56441 .43322 L .56156 .42917 L F
.756 .495 .537 r
.34282 .57887 m .34321 .58154 L .34164 .58015 L F
0 0 0 r
.34164 .58015 m .34221 .5797 L .34282 .57887 L F
.987 .79 .554 r
.3449 .57775 m .34437 .58019 L .34282 .57887 L F
.653 .815 .961 r
.34754 .57666 m .3449 .57775 L .34347 .57613 L F
.636 .126 .017 r
.34437 .58019 m .34385 .5808 L .34282 .57887 L F
.34385 .5808 m .34321 .58154 L .34303 .58033 L F
.34385 .5808 m .34303 .58033 L .34282 .57887 L F
0 0 0 r
.34221 .5797 m .34523 .57734 L .34282 .57887 L F
.987 .79 .554 r
.3449 .57775 m .34282 .57887 L .34421 .57697 L F
0 0 0 r
.34164 .58015 m .34449 .57913 L .34523 .57734 L F
.34449 .57913 m .34453 .57912 L .34456 .57906 L F
.34449 .57913 m .34456 .57906 L .34523 .57734 L F
.443 .357 .665 r
.34294 .58362 m .34512 .58277 L .34437 .58019 L F
.43 .349 .665 r
.34437 .58019 m .34512 .58277 L .34721 .58206 L F
.636 .126 .017 r
.34437 .58019 m .34721 .58206 L .34321 .58154 L F
.455 .268 .537 r
.34255 .58629 m .34512 .58277 L .34294 .58362 L F
.34255 .58629 m .34496 .58602 L .34512 .58277 L F
.684 .459 .575 r
.34512 .58277 m .34939 .58559 L .34721 .58206 L F
.34512 .58277 m .34496 .58602 L .34939 .58559 L F
.69 .391 .463 r
.34721 .58206 m .34297 .58408 L .34321 .58154 L F
.63 .521 .712 r
.34164 .58015 m .34321 .58154 L .34019 .58182 L F
.69 .457 .565 r
.34297 .58408 m .34019 .58182 L .34321 .58154 L F
.748 .449 .477 r
.34263 .58207 m .34618 .5798 L .34434 .57931 L F
.319 .75 .97 r
.34234 .57879 m .34453 .57912 L .3423 .57991 L F
.748 .449 .477 r
.34256 .58135 m .34434 .57931 L .34234 .57879 L F
.34263 .58207 m .34434 .57931 L .34256 .58135 L F
.319 .75 .97 r
.34188 .57967 m .3423 .57991 L .34164 .58015 L F
.34234 .57879 m .3423 .57991 L .34188 .57967 L F
.987 .79 .554 r
.34421 .57697 m .34282 .57887 L .34347 .57613 L F
.81 .725 .771 r
.4201 .50483 m .41746 .50877 L .42147 .50858 L F
.813 .674 .71 r
.41746 .50877 m .41852 .51185 L .42147 .50858 L F
.8 .999 .812 r
.67056 .36602 m .67266 .36549 L .66944 .3686 L F
.794 .999 .814 r
.67438 .36331 m .67266 .36549 L .67056 .36602 L F
.668 .409 .52 r
.42731 .5537 m .42396 .55634 L .42504 .55326 L F
.523 .858 .995 r
.23788 .58639 m .23869 .58494 L .24047 .58571 L F
.461 .886 .808 r
.63098 .39484 m .62749 .39599 L .62955 .39326 L F
.703 .866 .959 r
.63325 .39345 m .63098 .39484 L .62955 .39326 L F
.399 0 0 r
.58523 .35569 m .58362 .35657 L .58085 .35588 L F
.793 .977 .692 r
.58625 .35324 m .58362 .35657 L .58523 .35569 L F
.852 .726 .723 r
.47086 .52855 m .47203 .52459 L .46888 .52393 L F
.957 .706 .516 r
.24943 .62265 m .24923 .6254 L .24742 .6218 L F
.822 .671 .696 r
.34983 .5569 m .34763 .56235 L .34516 .55556 L F
.537 .895 .975 r
.42027 .45103 m .42252 .45152 L .41887 .45266 L F
.588 .927 .724 r
.42027 .45103 m .41887 .45266 L .41831 .45267 L F
.726 .955 .948 r
.63746 .34926 m .63474 .35151 L .63742 .35087 L F
.63742 .35087 m .63474 .35151 L .63746 .34926 L F
.611 .876 .991 r
.63907 .34896 m .63746 .34926 L .63742 .35087 L F
.63742 .35087 m .63746 .34926 L .63907 .34896 L F
.803 .892 .908 r
.54386 .46691 m .54501 .46846 L .5478 .46602 L F
.885 .718 .67 r
.50927 .42645 m .51241 .42661 L .51106 .42335 L F
.285 0 0 r
.50967 .42658 m .51241 .42661 L .50927 .42645 L F
0 .576 .739 r
.51369 .4266 m .51241 .42661 L .50967 .42658 L F
.51369 .4266 m .51514 .42672 L .51241 .42661 L F
.664 .367 .46 r
.54791 .39351 m .55167 .39342 L .55181 .39081 L F
0 0 0 r
.5551 .38894 m .55181 .39081 L .55435 .38967 L F
.588 .41 .608 r
.55167 .39342 m .55435 .38967 L .55181 .39081 L F
.854 .81 .806 r
.62646 .38987 m .62899 .38898 L .62577 .39053 L F
.62646 .38987 m .62821 .38803 L .62899 .38898 L F
.62646 .38987 m .62595 .38715 L .62821 .38803 L F
.601 .326 .472 r
.30417 .57712 m .30357 .57985 L .30077 .57963 L F
.448 .213 .463 r
.30633 .57644 m .30357 .57985 L .30417 .57712 L F
.777 .748 .827 r
.43709 .58333 m .43845 .58699 L .44113 .58421 L F
0 0 0 r
.55387 .47869 m .55604 .47789 L .55373 .47912 L F
.983 .799 .579 r
.40227 .50724 m .40404 .50866 L .40429 .50559 L F
.405 .28 .596 r
.40429 .50559 m .40404 .50866 L .40621 .50718 L F
.833 .753 .775 r
.33376 .56606 m .33876 .56695 L .33713 .5629 L F
.435 .182 .431 r
.33376 .56606 m .33585 .56793 L .33876 .56695 L F
0 .035 .605 r
.33815 .56544 m .33876 .56695 L .3392 .56526 L F
.464 .879 .753 r
.33876 .56695 m .33824 .56653 L .3392 .56526 L F
0 0 0 r
.3392 .56526 m .33824 .56653 L .33957 .56519 L F
.3392 .56526 m .33957 .56519 L .34097 .5638 L F
0 .035 .605 r
.33713 .5629 m .33815 .56544 L .3392 .56526 L F
.464 .879 .753 r
.33876 .56695 m .33585 .56793 L .33824 .56653 L F
.171 0 .104 r
.53331 .49208 m .53271 .49452 L .52986 .49589 L F
0 0 .01 r
.53441 .49265 m .53331 .49208 L .53582 .49141 L F
.53441 .49265 m .53271 .49452 L .53331 .49208 L F
.794 .299 0 r
.37778 .50826 m .37579 .50744 L .37415 .50513 L F
.873 .449 .201 r
.37778 .50826 m .37655 .50958 L .37579 .50744 L F
.37778 .50826 m .37926 .51134 L .37655 .50958 L F
.685 .213 .125 r
.46844 .54598 m .47043 .54536 L .47002 .54441 L F
.569 .074 .039 r
.47002 .54441 m .47048 .54498 L .46886 .54556 L F
.47048 .54498 m .47052 .54504 L .47008 .54518 L F
.47048 .54498 m .47008 .54518 L .46886 .54556 L F
.869 .533 .412 r
.46484 .54246 m .47008 .54518 L .46844 .54598 L F
.47008 .54518 m .47043 .54536 L .46844 .54598 L F
.869 .59 .512 r
.46855 .54027 m .47034 .5451 L .46484 .54246 L F
.47034 .5451 m .47043 .54536 L .47008 .54518 L F
.47034 .5451 m .47008 .54518 L .46484 .54246 L F
.569 .074 .039 r
.46886 .54556 m .47096 .54558 L .46844 .54598 L F
.47052 .54504 m .47096 .54558 L .46886 .54556 L F
.801 .993 .757 r
.67056 .36602 m .66944 .3686 L .66778 .36906 L F
0 0 0 r
.6692 .38422 m .67224 .38152 L .67159 .3834 L F
.008 0 .26 r
.67438 .38057 m .67224 .38152 L .67389 .38013 L F
0 0 0 r
.67159 .3834 m .67224 .38152 L .67438 .38057 L F
.951 .789 .644 r
.73885 .29988 m .73782 .29583 L .73723 .29813 L F
.671 .903 .562 r
.44096 .56712 m .43849 .57009 L .43929 .5687 L F
.748 .566 .649 r
.44096 .56712 m .44168 .57077 L .43849 .57009 L F
.541 .09 .129 r
.43929 .5687 m .44084 .56668 L .44096 .56712 L F
.671 .725 .89 r
.42077 .45968 m .42472 .46053 L .4239 .45859 L F
.637 .636 .833 r
.42472 .46053 m .42735 .45976 L .4239 .45859 L F
.848 .739 .743 r
.71249 .30537 m .71006 .30869 L .71378 .30924 L F
0 0 0 r
.71009 .31129 m .71378 .30924 L .71006 .30869 L F
.71009 .31129 m .71422 .31071 L .71378 .30924 L F
.582 .925 .724 r
.57377 .45103 m .57464 .45048 L .57692 .44862 L F
.708 .984 .887 r
.57776 .44927 m .57377 .45103 L .57692 .44862 L F
.822 .674 .699 r
.55167 .39342 m .55611 .39447 L .55386 .39747 L F
.772 .598 .662 r
.55611 .39447 m .55593 .39726 L .55386 .39747 L F
.7 .339 .36 r
.38736 .48164 m .3873 .47949 L .38402 .4791 L F
.503 .185 .361 r
.38736 .48164 m .39006 .48102 L .3873 .47949 L F
.443 .782 .998 r
.24923 .6254 m .25335 .62618 L .25171 .62497 L F
.24923 .6254 m .25335 .62618 L .25171 .62497 L F
.618 .925 .674 r
.25389 .62528 m .25335 .62618 L .25171 .62497 L F
.529 .004 0 r
.25202 .6252 m .2525 .62563 L .25171 .62497 L F
.25335 .62618 m .2525 .62563 L .25202 .6252 L F
.885 .479 .046 r
.2525 .62563 m .25337 .62805 L .25191 .62636 L F
.402 0 0 r
.24781 .62821 m .25257 .62728 L .25026 .62865 L F
.885 .479 .046 r
.25337 .62805 m .25247 .62718 L .25191 .62636 L F
.787 .881 .915 r
.25093 .62567 m .25257 .62728 L .24781 .62821 L F
.885 .479 .046 r
.25257 .62728 m .25256 .62731 L .25247 .62718 L F
.618 .925 .674 r
.25389 .62528 m .25513 .6246 L .25335 .62618 L F
.529 .004 0 r
.25335 .62618 m .25587 .62857 L .2525 .62563 L F
.9 .495 .221 r
.2525 .62563 m .25587 .62857 L .25369 .62895 L F
.432 .871 .809 r
.25532 .62829 m .25808 .62752 L .25711 .62756 L F
.25369 .62895 m .25548 .62837 L .25532 .62829 L F
.25548 .62837 m .25808 .62752 L .25532 .62829 L F
.592 .041 0 r
.25651 .62742 m .25389 .62528 L .25192 .62636 L F
.25711 .62756 m .25673 .62729 L .25651 .62742 L F
.25673 .62729 m .25389 .62528 L .25651 .62742 L F
.734 .401 .416 r
.25808 .62752 m .25779 .62524 L .25389 .62528 L F
.25808 .62752 m .25389 .62528 L .25711 .62756 L F
.592 .041 0 r
.25647 .62706 m .25191 .62636 L .25442 .62548 L F
.25666 .62721 m .25635 .62716 L .25647 .62706 L F
.25635 .62716 m .25191 .62636 L .25647 .62706 L F
.25651 .62742 m .25191 .62636 L .25666 .62721 L F
.753 .767 .865 r
.25601 .62801 m .25666 .62721 L .25442 .62548 L F
.603 .061 0 r
.26071 .62603 m .25564 .62415 L .25779 .62524 L F
.816 .463 .389 r
.25808 .62752 m .26071 .62603 L .25779 .62524 L F
.51 .872 .642 r
.25971 .62431 m .2578 .62598 L .25623 .62703 L F
.2578 .62598 m .25734 .62639 L .2572 .62647 L F
.2578 .62598 m .2572 .62647 L .25623 .62703 L F
.592 .041 0 r
.25711 .62756 m .25651 .62742 L .25666 .62721 L F
.753 .767 .865 r
.25385 .62818 m .25601 .62801 L .25442 .62548 L F
.25369 .62895 m .2544 .62866 L .25385 .62818 L F
.2544 .62866 m .25601 .62801 L .25385 .62818 L F
.25213 .62668 m .25442 .62548 L .25191 .62636 L F
.787 .881 .915 r
.25247 .62717 m .25276 .62724 L .25257 .62728 L F
.753 .767 .865 r
.25247 .62718 m .25256 .62706 L .25213 .62668 L F
.787 .881 .915 r
.25099 .62563 m .25256 .62706 L .25247 .62717 L F
.25256 .62706 m .25276 .62724 L .25247 .62717 L F
.753 .767 .865 r
.25256 .62731 m .2527 .62718 L .25256 .62706 L F
.25256 .62731 m .25256 .62706 L .25247 .62718 L F
.2527 .62718 m .25442 .62548 L .25213 .62668 L F
0 .097 .578 r
.25309 .62751 m .2529 .62735 L .25184 .6264 L F
.2529 .62735 m .25276 .62724 L .25256 .62706 L F
.2529 .62735 m .25256 .62706 L .25184 .6264 L F
.885 .479 .046 r
.25337 .62805 m .25369 .62895 L .25256 .62731 L F
.25337 .62805 m .25256 .62731 L .25257 .62728 L F
.753 .767 .865 r
.25369 .62895 m .25399 .62753 L .25256 .62731 L F
.25399 .62753 m .25404 .62728 L .25263 .62731 L F
.25399 .62753 m .25263 .62731 L .25256 .62731 L F
.432 .871 .809 r
.25369 .62895 m .25587 .62857 L .25808 .62752 L F
.7 .559 .692 r
.25711 .62756 m .25678 .62951 L .25369 .62895 L F
0 0 0 r
.25472 .62883 m .25711 .62756 L .25369 .62895 L F
.597 .105 .056 r
.25026 .62865 m .25263 .62731 L .25472 .62883 L F
.25263 .62731 m .25276 .62724 L .2529 .62735 L F
.25263 .62731 m .2529 .62735 L .25472 .62883 L F
.402 0 0 r
.25257 .62728 m .25276 .62724 L .25263 .62731 L F
.25257 .62728 m .25263 .62731 L .25256 .62731 L F
.753 .767 .865 r
.25404 .62728 m .25442 .62548 L .25256 .62731 L F
0 .097 .578 r
.25472 .62883 m .25309 .62751 L .25099 .62563 L F
.25309 .62751 m .25184 .6264 L .25099 .62563 L F
.95 .945 .735 r
.2572 .62647 m .25573 .62789 L .25623 .62703 L F
.25732 .6264 m .25711 .6266 L .2572 .62647 L F
.25711 .6266 m .25573 .62789 L .2572 .62647 L F
.753 .767 .865 r
.25601 .62801 m .25711 .62756 L .25666 .62721 L F
.95 .945 .735 r
.25734 .62639 m .2573 .62642 L .25732 .6264 L F
.2573 .62642 m .25573 .62789 L .25732 .6264 L F
.25573 .62789 m .25472 .62883 L .25529 .62815 L F
.25573 .62789 m .25529 .62815 L .25623 .62703 L F
.402 0 0 r
.25256 .62731 m .25263 .62731 L .25255 .62736 L F
.25257 .62728 m .25255 .62736 L .25026 .62865 L F
.787 .881 .915 r
.25099 .62563 m .25257 .62728 L .25093 .62567 L F
.248 0 0 r
.25191 .62636 m .25277 .62589 L .2525 .62563 L F
.25277 .62589 m .25389 .62528 L .2525 .62563 L F
.592 .041 0 r
.25192 .62636 m .25389 .62528 L .25191 .62636 L F
.618 .925 .674 r
.25389 .62528 m .25564 .62415 L .25513 .6246 L F
.537 .021 0 r
.25779 .62524 m .25564 .62415 L .25389 .62528 L F
.857 .742 .736 r
.59605 .37836 m .59953 .37794 L .59927 .37747 L F
.59605 .37836 m .59753 .3819 L .59953 .37794 L F
0 .087 .605 r
.59933 .3739 m .60082 .37579 L .59953 .37794 L F
.703 .974 .763 r
.60082 .37579 m .59927 .37747 L .59953 .37794 L F
.877 .581 .484 r
.43076 .55665 m .4274 .55652 L .42731 .5537 L F
.893 .778 .728 r
.43076 .55665 m .42857 .56052 L .4274 .55652 L F
.256 .413 .828 r
.43076 .55665 m .43352 .55694 L .43322 .55509 L F
.568 .197 .298 r
.62746 .34557 m .62642 .34767 L .62373 .3476 L F
.307 0 .166 r
.62905 .34681 m .62746 .34557 L .63016 .34502 L F
.62905 .34681 m .62642 .34767 L .62746 .34557 L F
.87 .488 .316 r
.38549 .51506 m .38367 .51661 L .38315 .51443 L F
.959 .664 .433 r
.38559 .51763 m .38367 .51661 L .38549 .51506 L F
.335 .767 .97 r
.44216 .46573 m .44487 .46547 L .44646 .46617 L F
.44216 .46573 m .44487 .46547 L .44646 .46617 L F
.857 .928 .873 r
.44646 .46617 m .44738 .46337 L .44487 .46547 L F
.438 .474 .799 r
.44646 .46617 m .44853 .46622 L .44738 .46337 L F
.857 .928 .873 r
.44646 .46617 m .44738 .46337 L .44487 .46547 L F
.999 .842 .539 r
.68967 .33275 m .68803 .3339 L .6888 .33145 L F
.68967 .33275 m .68907 .33536 L .68803 .3339 L F
.704 .83 .942 r
.35209 .537 m .35006 .53853 L .348 .53676 L F
.514 .862 .991 r
.45284 .46626 m .45139 .46526 L .44853 .46622 L F
.743 .735 .844 r
.45498 .46685 m .45139 .46526 L .45284 .46626 L F
.934 .764 .648 r
.62052 .37857 m .61863 .38161 L .61905 .38175 L F
.979 .914 .606 r
.70445 .336 m .70581 .33554 L .70546 .3345 L F
.70445 .336 m .70467 .33936 L .70581 .33554 L F
.906 .976 .797 r
.70581 .33554 m .70765 .33096 L .70546 .3345 L F
.70581 .33554 m .7083 .33199 L .70765 .33096 L F
.857 .986 .848 r
.37321 .62608 m .37569 .62336 L .3724 .62439 L F
.962 .86 .452 r
.37247 .62879 m .37321 .62608 L .3724 .62439 L F
.926 .538 .19 r
.58814 .42687 m .58587 .42342 L .58656 .42519 L F
.904 .51 .093 r
.58813 .42774 m .58814 .42687 L .58656 .42519 L F
0 0 0 r
.44404 .59661 m .44208 .59774 L .43962 .59837 L F
.386 .831 .94 r
.44846 .59606 m .44656 .59602 L .44404 .59661 L F
0 0 0 r
.44511 .59668 m .44404 .59661 L .44656 .59602 L F
.44511 .59668 m .44208 .59774 L .44404 .59661 L F
.776 .994 .874 r
.38154 .4876 m .3801 .48943 L .38083 .48724 L F
.787 .998 .845 r
.38083 .48724 m .3801 .48943 L .37767 .48999 L F
.516 .311 .541 r
.22968 .54043 m .23273 .53629 L .23112 .53808 L F
.171 0 0 r
.26087 .58874 m .2649 .58568 L .26247 .58955 L F
.26092 .58862 m .2649 .58568 L .26087 .58874 L F
.2608 .5887 m .26092 .58862 L .26087 .58874 L F
.782 .279 0 r
.26247 .58955 m .26213 .59076 L .2608 .5887 L F
.532 .346 .573 r
.2608 .5887 m .26213 .59076 L .26137 .58852 L F
.171 0 0 r
.26092 .58862 m .26137 .58852 L .2649 .58568 L F
.532 .346 .573 r
.2608 .5887 m .26137 .58852 L .2607 .58655 L F
.171 0 0 r
.26137 .58852 m .2632 .58815 L .26338 .58789 L F
.26137 .58852 m .26338 .58789 L .2649 .58568 L F
.442 .296 .586 r
.26117 .58795 m .26213 .59076 L .26151 .58707 L F
.171 0 0 r
.2608 .5887 m .2632 .58815 L .26092 .58862 L F
.442 .296 .586 r
.26151 .58707 m .26174 .58845 L .2632 .58815 L F
.776 .6 .661 r
.2663 .58958 m .26247 .58955 L .2649 .58568 L F
.719 .364 .376 r
.2663 .58958 m .26445 .59205 L .26247 .58955 L F
.782 .279 0 r
.26247 .58955 m .26445 .59205 L .26213 .59076 L F
.442 .296 .586 r
.26174 .58845 m .26213 .59076 L .2632 .58815 L F
.2607 .58655 m .26117 .58795 L .26151 .58707 L F
.569 .089 .075 r
.2649 .58568 m .26581 .58805 L .2669 .58534 L F
.2649 .58568 m .2632 .58815 L .26581 .58805 L F
.979 .769 .354 r
.59436 .39977 m .59522 .401 L .59505 .40357 L F
.691 .424 .514 r
.49854 .49468 m .50272 .49225 L .49817 .49204 L F
.49854 .49468 m .50261 .49476 L .50272 .49225 L F
.587 .45 .661 r
.50272 .49225 m .50539 .49182 L .50522 .4888 L F
.563 .327 .516 r
.50261 .49476 m .50539 .49182 L .50272 .49225 L F
.367 .054 .297 r
.51845 .50182 m .51795 .50445 L .5153 .50518 L F
.213 0 .248 r
.52012 .50331 m .51845 .50182 L .52096 .50107 L F
.52012 .50331 m .51795 .50445 L .51845 .50182 L F
.184 .212 .656 r
.45606 .46339 m .45794 .46472 L .45751 .46225 L F
.573 .409 .621 r
.62641 .36106 m .629 .35777 L .62632 .35858 L F
0 0 .233 r
.47647 .58241 m .47639 .58488 L .47522 .58657 L F
0 0 0 r
.47522 .58657 m .47639 .58488 L .47493 .58861 L F
.603 .158 .167 r
.68341 .32224 m .68217 .32411 L .67934 .32235 L F
.718 .291 .235 r
.68623 .32471 m .68341 .32224 L .68568 .3228 L F
.68623 .32471 m .68217 .32411 L .68341 .32224 L F
.937 .651 .473 r
.37174 .5299 m .37451 .5339 L .3742 .53167 L F
.57 .81 .989 r
.43406 .5754 m .43331 .57521 L .43404 .57255 L F
.881 .936 .849 r
.73133 .29324 m .73063 .29056 L .72893 .2926 L F
.73133 .29324 m .73385 .29033 L .73063 .29056 L F
.667 .164 .04 r
.72996 .29448 m .73133 .29324 L .72893 .2926 L F
.567 0 0 r
.73133 .29324 m .7339 .29529 L .73517 .29575 L F
.581 .359 .544 r
.34502 .56363 m .345 .5673 L .34197 .5672 L F
.34502 .56363 m .345 .5673 L .34197 .5672 L F
.416 .143 .389 r
.34783 .56344 m .345 .5673 L .34502 .56363 L F
.463 .812 .998 r
.34502 .56363 m .34876 .56322 L .34783 .56344 L F
.613 .385 .547 r
.34754 .56526 m .34737 .5663 L .34845 .56585 L F
.416 .143 .389 r
.34783 .56344 m .34774 .56416 L .34667 .56502 L F
.613 .385 .547 r
.34502 .56363 m .34689 .56484 L .34776 .56409 L F
.34803 .5633 m .348 .56339 L .34876 .56322 L F
.197 .724 .733 r
.34876 .56322 m .34795 .5634 L .34783 .56344 L F
.613 .385 .547 r
.348 .56339 m .34776 .56409 L .34876 .56322 L F
.197 .724 .733 r
.34876 .56322 m .34877 .56315 L .34795 .5634 L F
.613 .385 .547 r
.34689 .56484 m .34845 .56585 L .34874 .56336 L F
.34776 .56409 m .34874 .56336 L .34876 .56322 L F
.34689 .56484 m .34774 .56416 L .34776 .56409 L F
.34774 .56416 m .34874 .56336 L .34776 .56409 L F
0 0 .064 r
.34787 .5635 m .3478 .56366 L .34783 .56345 L F
.613 .385 .547 r
.34787 .5635 m .34776 .56409 L .34803 .5633 L F
0 0 .064 r
.34851 .56442 m .34783 .56369 L .34787 .5635 L F
.34783 .56369 m .3478 .56366 L .34787 .5635 L F
.34851 .56442 m .34787 .5635 L .34877 .56315 L F
.34787 .5635 m .34783 .56344 L .34795 .5634 L F
.34787 .5635 m .34795 .5634 L .34877 .56315 L F
.613 .385 .547 r
.3479 .56331 m .34787 .5635 L .34803 .5633 L F
0 0 .064 r
.34783 .56369 m .34774 .56416 L .3478 .56366 L F
.34783 .56345 m .3478 .56366 L .34783 .56344 L F
.613 .385 .547 r
.34502 .56363 m .34776 .56409 L .3479 .56331 L F
.486 .351 .622 r
.34659 .56663 m .34745 .56683 L .34845 .56585 L F
.345 .5673 m .34745 .56683 L .34659 .56663 L F
.621 .651 .858 r
.34845 .56585 m .35115 .56618 L .34877 .56315 L F
.442 0 0 r
.34745 .56683 m .35115 .56618 L .34845 .56585 L F
.3477 .56679 m .34932 .5678 L .35115 .56618 L F
.34745 .56683 m .34932 .5678 L .3477 .56679 L F
.387 .551 .895 r
.34877 .56315 m .35115 .56618 L .35244 .56453 L F
.635 .411 .561 r
.34932 .5678 m .35244 .56453 L .35115 .56618 L F
.34932 .5678 m .35236 .56816 L .35244 .56453 L F
.597 .216 .292 r
.34932 .5678 m .35211 .57041 L .35236 .56816 L F
0 .172 .704 r
.3501 .56634 m .35149 .56915 L .34932 .5678 L F
.35149 .56915 m .35211 .57041 L .34932 .5678 L F
.106 .229 .709 r
.34851 .56442 m .34919 .56726 L .34745 .56683 L F
.34919 .56726 m .34932 .5678 L .34745 .56683 L F
0 0 .064 r
.34851 .56442 m .34745 .56683 L .34774 .56416 L F
.34851 .56442 m .34774 .56416 L .34783 .56369 L F
.613 .385 .547 r
.34689 .56484 m .345 .5673 L .34737 .5663 L F
.34689 .56484 m .34737 .5663 L .34754 .56526 L F
.416 .143 .389 r
.34667 .56502 m .3467 .56509 L .345 .5673 L F
.613 .385 .547 r
.34502 .56363 m .345 .5673 L .34689 .56484 L F
.416 .143 .389 r
.3467 .56509 m .34745 .56683 L .345 .5673 L F
.34774 .56416 m .34745 .56683 L .34667 .56502 L F
.085 0 .008 r
.53011 .44659 m .53136 .44573 L .53209 .44564 L F
.601 .088 .003 r
.42714 .53811 m .42932 .53954 L .43095 .53858 L F
.577 .059 0 r
.42932 .53954 m .43388 .54038 L .43095 .53858 L F
0 0 0 r
.62253 .34807 m .62075 .34856 L .62373 .3476 L F
.62253 .34807 m .61952 .34985 L .62075 .34856 L F
.621 .801 .968 r
.60827 .40771 m .6055 .40696 L .60836 .40657 L F
.982 .833 .619 r
.6055 .40696 m .60634 .40423 L .60505 .40303 L F
.6055 .40696 m .60505 .40303 L .60423 .40631 L F
.352 .775 .975 r
.60836 .40657 m .6055 .40696 L .60423 .40631 L F
.60836 .40657 m .60423 .40631 L .60732 .4072 L F
.705 .769 .902 r
.60845 .40552 m .60836 .40657 L .60732 .4072 L F
.60967 .40373 m .60836 .40657 L .60845 .40552 L F
.621 .801 .968 r
.60988 .40814 m .60827 .40771 L .60836 .40657 L F
0 .156 .64 r
.6125 .41004 m .60988 .40814 L .60836 .40657 L F
0 0 0 r
.66533 .38632 m .6692 .38422 L .66797 .38526 L F
.66797 .38526 m .6692 .38422 L .67159 .3834 L F
.798 1 .827 r
.58352 .35046 m .58157 .35274 L .58237 .35069 L F
.142 .664 .882 r
.7339 .29529 m .73782 .29583 L .73517 .29575 L F
.987 .719 .414 r
.52283 .4055 m .52434 .40366 L .5233 .40247 L F
.52283 .4055 m .52454 .40668 L .52434 .40366 L F
.355 .712 .986 r
.5268 .40344 m .5233 .40247 L .52434 .40366 L F
.424 .822 .607 r
.63469 .37276 m .63337 .37366 L .63267 .37417 L F
.413 .811 .984 r
.62936 .37466 m .63182 .37479 L .63267 .37417 L F
.203 0 0 r
.63329 .37487 m .63122 .37513 L .62936 .37466 L F
.219 0 0 r
.62936 .37466 m .63122 .37513 L .63267 .37417 L F
.615 .957 .851 r
.63104 .374 m .63204 .37206 L .63289 .37325 L F
.265 .166 .55 r
.63289 .37325 m .63122 .37513 L .63104 .374 L F
.424 .822 .607 r
.63337 .37366 m .6319 .37466 L .63267 .37417 L F
.6319 .37466 m .63122 .37513 L .63173 .37479 L F
.6319 .37466 m .63173 .37479 L .63267 .37417 L F
.413 .811 .984 r
.63182 .37479 m .63329 .37487 L .63267 .37417 L F
.664 .947 .958 r
.63469 .37276 m .63329 .37487 L .63267 .37417 L F
.701 .984 .837 r
.63469 .37276 m .63122 .37513 L .63329 .37487 L F
.265 .166 .55 r
.63289 .37325 m .63372 .37465 L .63122 .37513 L F
.102 .427 .871 r
.63204 .37206 m .63313 .37374 L .63104 .374 L F
.63313 .37374 m .63372 .37465 L .63236 .37432 L F
.63313 .37374 m .63236 .37432 L .63104 .374 L F
.984 .713 .425 r
.59812 .414 m .59806 .41656 L .59655 .41273 L F
.015 0 .475 r
.35664 .55415 m .35726 .55745 L .35778 .55624 L F
0 0 .091 r
.35778 .55624 m .35602 .55415 L .35664 .55415 L F
.445 .014 .124 r
.67292 .32388 m .66887 .32653 L .66991 .32505 L F
.534 .316 .53 r
.32851 .56925 m .33121 .56648 L .329 .56729 L F
.848 .957 .881 r
.44355 .58696 m .44266 .5901 L .44103 .58895 L F
.44355 .58696 m .44555 .58736 L .44266 .5901 L F
.82 .837 .861 r
.64154 .38644 m .64326 .38878 L .64019 .39111 L F
.406 0 0 r
.44846 .59606 m .45067 .59644 L .44656 .59602 L F
.58 .465 .687 r
.3199 .61962 m .32094 .62296 L .32266 .62187 L F
.71 .173 0 r
.3199 .61962 m .32266 .62187 L .31914 .62041 L F
.748 .993 .864 r
.32331 .57335 m .3234 .57186 L .32678 .571 L F
.392 .827 .681 r
.3234 .57186 m .32851 .56925 L .32678 .571 L F
.708 .935 .62 r
.40245 .48523 m .40326 .48363 L .40526 .482 L F
.849 .857 .848 r
.40797 .47887 m .40526 .482 L .40521 .48094 L F
.648 .257 .29 r
.40326 .48363 m .40521 .48094 L .40526 .482 L F
.509 .32 .559 r
.40797 .47887 m .40859 .48123 L .40526 .482 L F
.139 0 0 r
.32297 .56552 m .32059 .56622 L .32189 .56544 L F
.948 .943 .744 r
.37906 .61541 m .38246 .6122 L .38111 .61161 L F
.37906 .61541 m .3803 .61608 L .38246 .6122 L F
.896 .968 .822 r
.38111 .61161 m .38246 .6122 L .38465 .60913 L F
.152 0 .154 r
.62179 .39024 m .62067 .38967 L .61961 .39085 L F
.477 .539 .841 r
.25369 .53974 m .25154 .54176 L .25029 .53873 L F
.522 .411 .668 r
.25468 .54359 m .25154 .54176 L .25369 .53974 L F
.132 0 0 r
.29747 .64228 m .29338 .6443 L .2958 .64398 L F
.479 .527 .829 r
.29189 .64078 m .29338 .6443 L .29015 .64351 L F
.305 .774 .938 r
.29172 .64378 m .29338 .6443 L .29332 .64415 L F
.29172 .64378 m .29332 .64415 L .29189 .64078 L F
.479 .527 .829 r
.29174 .64329 m .28948 .64401 L .29172 .64378 L F
.004 0 0 r
.29015 .64351 m .28732 .64469 L .28948 .64401 L F
.479 .527 .829 r
.29189 .64078 m .28948 .64401 L .29174 .64329 L F
.004 0 0 r
.28732 .64469 m .28715 .64476 L .28948 .64401 L F
.014 0 0 r
.29172 .64378 m .29189 .64078 L .28933 .64124 L F
.479 .527 .829 r
.29189 .64078 m .29172 .64378 L .28933 .64124 L F
.014 0 0 r
.29172 .64378 m .28998 .6397 L .29189 .64078 L F
.525 .291 .502 r
.29172 .64378 m .29189 .64078 L .28998 .6397 L F
.29172 .64378 m .29497 .64066 L .29189 .64078 L F
.305 .774 .938 r
.29172 .64378 m .29189 .64078 L .29497 .64066 L F
.555 0 0 r
.28341 .64351 m .28715 .64476 L .28531 .64483 L F
.28341 .64351 m .28715 .64476 L .28531 .64483 L F
.355 .829 .855 r
.28531 .64483 m .28715 .64476 L .28948 .64401 L F
.28531 .64483 m .28715 .64476 L .28948 .64401 L F
.521 .332 .565 r
.28659 .64715 m .28948 .64401 L .28715 .64476 L F
.28659 .64715 m .28926 .64671 L .28948 .64401 L F
.355 .829 .855 r
.28531 .64483 m .28948 .64401 L .28805 .64449 L F
.54 .418 .662 r
.28926 .64671 m .29172 .64378 L .28948 .64401 L F
.014 0 0 r
.29172 .64378 m .28948 .64401 L .28805 .64449 L F
.29172 .64378 m .28805 .64449 L .28811 .64435 L F
.355 .829 .855 r
.28531 .64483 m .28948 .64401 L .28789 .64439 L F
.014 0 0 r
.29166 .64365 m .28811 .64435 L .28998 .6397 L F
0 0 0 r
.28837 .64433 m .28948 .64401 L .29172 .64378 L F
.494 .751 .986 r
.28531 .64483 m .28805 .64449 L .28792 .64439 L F
0 0 0 r
.28755 .64447 m .28786 .6444 L .28837 .64433 L F
.28786 .6444 m .28948 .64401 L .28837 .64433 L F
.494 .751 .986 r
.28532 .6447 m .28792 .64439 L .28546 .64249 L F
.28531 .64483 m .28792 .64439 L .28532 .6447 L F
.014 0 0 r
.29172 .64378 m .28811 .64435 L .29166 .64365 L F
.355 .829 .855 r
.28709 .64454 m .28789 .64439 L .28755 .64447 L F
.28531 .64483 m .28789 .64439 L .28709 .64454 L F
.525 .291 .502 r
.29172 .64378 m .28998 .6397 L .29225 .64193 L F
.71 .963 .942 r
.28988 .64335 m .29172 .64378 L .29225 .64193 L F
.28891 .64393 m .29172 .64378 L .28988 .64335 L F
.305 .774 .938 r
.29172 .64378 m .2958 .64398 L .29338 .6443 L F
.7 .275 .234 r
.29445 .64563 m .2958 .64398 L .29172 .64378 L F
.998 .85 .538 r
.29448 .64532 m .2958 .64398 L .29445 .64563 L F
.29483 .64257 m .2958 .64398 L .29448 .64532 L F
.132 0 0 r
.29774 .64215 m .29747 .64228 L .2958 .64398 L F
0 0 0 r
.29898 .64128 m .29774 .64215 L .2958 .64398 L F
.759 .977 .716 r
.70963 .29659 m .70803 .29927 L .71222 .29666 L F
.803 .975 .904 r
.71238 .29414 m .71222 .29666 L .71283 .295 L F
.71238 .29414 m .70963 .29659 L .71222 .29666 L F
.527 .831 1 r
.32481 .65656 m .32599 .65472 L .32264 .65679 L F
.32481 .65656 m .32758 .65585 L .32599 .65472 L F
.702 .744 .236 r
.47968 .57368 m .48098 .56933 L .48055 .57198 L F
0 0 .031 r
.4802 .57446 m .47968 .57368 L .48055 .57198 L F
.4802 .57446 m .47914 .57614 L .47968 .57368 L F
.411 .4 .737 r
.31581 .5376 m .31651 .54136 L .31842 .5394 L F
.692 .601 .75 r
.43217 .59145 m .43372 .59548 L .43062 .5957 L F
.534 .326 .544 r
.49616 .49526 m .49854 .49468 L .49817 .49204 L F
.852 .726 .723 r
.47086 .52855 m .46888 .52393 L .46909 .52689 L F
.984 .9 .64 r
.46897 .52913 m .47086 .52855 L .46909 .52689 L F
.46897 .52913 m .46966 .53136 L .47086 .52855 L F
.594 .652 .877 r
.41499 .50973 m .41624 .50574 L .4134 .50846 L F
.41499 .50973 m .41746 .50877 L .41624 .50574 L F
.58 .522 .755 r
.33121 .56648 m .33286 .56298 L .33158 .56397 L F
.865 .992 .739 r
.34742 .60631 m .34557 .60755 L .3497 .60162 L F
.941 .629 .418 r
.40142 .54438 m .39952 .54375 L .39928 .541 L F
.991 .741 .381 r
.40142 .54438 m .40016 .54582 L .39952 .54375 L F
.40142 .54438 m .40125 .54721 L .40016 .54582 L F
.912 .51 .146 r
.43231 .54998 m .43485 .55336 L .43417 .55081 L F
.568 .345 .537 r
.59454 .3736 m .59042 .37131 L .59432 .37066 L F
.286 .132 .489 r
.32855 .50109 m .33033 .49821 L .32786 .49931 L F
.32855 .50109 m .33016 .50116 L .33033 .49821 L F
.581 .614 .85 r
.33238 .55663 m .33427 .56058 L .33688 .55976 L F
.698 .329 .344 r
.33427 .56058 m .33713 .5629 L .33688 .55976 L F
.33427 .56058 m .33286 .56298 L .33713 .5629 L F
.624 .433 .604 r
.53503 .42335 m .53596 .42012 L .5333 .41908 L F
.53503 .42335 m .53707 .42407 L .53596 .42012 L F
.53596 .42012 m .53707 .42407 L .53503 .42335 L F
.728 .714 .837 r
.40868 .45518 m .40972 .45884 L .4126 .45575 L F
.055 0 .111 r
.5599 .46195 m .55783 .4632 L .55706 .46528 L F
.783 .699 .771 r
.52365 .46585 m .52664 .4652 L .52625 .46235 L F
.631 .262 .326 r
.52597 .46815 m .52664 .4652 L .52365 .46585 L F
.257 .309 .725 r
.52625 .46235 m .52664 .4652 L .52901 .46438 L F
.055 0 .146 r
.52901 .46438 m .52664 .4652 L .52597 .46815 L F
.253 .427 .841 r
.73206 .28652 m .73374 .28744 L .73385 .29033 L F
.887 .931 .843 r
.73385 .29033 m .73374 .28744 L .73063 .29056 L F
.872 .624 .56 r
.68936 .3281 m .68623 .32471 L .68916 .32594 L F
.779 .679 .754 r
.43588 .57704 m .43301 .57979 L .43698 .57922 L F
.478 .282 .535 r
.43407 .58373 m .43709 .58333 L .43698 .57922 L F
.824 .442 0 r
.43588 .57704 m .43698 .57922 L .4366 .57906 L F
.588 .512 .737 r
.43944 .57722 m .43698 .57922 L .43588 .57704 L F
.43944 .57722 m .44013 .57953 L .43698 .57922 L F
.628 .398 .55 r
.43698 .57922 m .43813 .58247 L .4366 .57906 L F
.43698 .57922 m .44048 .58103 L .44013 .57953 L F
.43698 .57922 m .44013 .57953 L .43813 .58247 L F
.964 .788 .616 r
.58919 .43375 m .58813 .42774 L .58807 .43261 L F
.988 .845 .611 r
.5873 .43516 m .58919 .43375 L .58807 .43261 L F
.5873 .43516 m .58863 .43644 L .58919 .43375 L F
.908 .781 .709 r
.58863 .43644 m .58925 .43536 L .58919 .43375 L F
.904 .769 .702 r
.40655 .58298 m .40776 .58668 L .40559 .58586 L F
.9 .776 .715 r
.40559 .58586 m .40776 .58668 L .40715 .58842 L F
.107 .66 .722 r
.60625 .41705 m .6099 .41665 L .60531 .41719 L F
.364 0 .189 r
.60593 .4181 m .60743 .41689 L .60625 .41705 L F
.60743 .41689 m .60986 .41492 L .60625 .41705 L F
.107 .66 .722 r
.60625 .41705 m .60531 .41719 L .60484 .41724 L F
.496 .313 .563 r
.35135 .59313 m .35155 .59616 L .3487 .59674 L F
.727 .678 .802 r
.35155 .59616 m .34915 .59948 L .3487 .59674 L F
.695 .615 .763 r
.35115 .55822 m .35139 .56076 L .3537 .55852 L F
.975 .729 .501 r
.32564 .52128 m .32554 .52451 L .32359 .52008 L F
.741 .892 .948 r
.32564 .52128 m .32683 .51838 L .32848 .5187 L F
.32564 .52128 m .32359 .52008 L .32683 .51838 L F
.633 .625 .825 r
.32863 .52056 m .32564 .52128 L .32848 .5187 L F
.75 .522 .586 r
.32944 .52453 m .32564 .52128 L .32863 .52056 L F
.32944 .52453 m .32554 .52451 L .32564 .52128 L F
0 0 0 r
.28836 .57788 m .28814 .57887 L .28833 .57576 L F
.234 .255 .678 r
.25181 .53299 m .25017 .53446 L .24966 .53093 L F
.022 0 .296 r
.25145 .53593 m .25017 .53446 L .25181 .53299 L F
.25145 .53593 m .25003 .53735 L .25017 .53446 L F
.439 .318 .618 r
.24242 .54767 m .24258 .55027 L .2404 .55085 L F
.186 .344 .791 r
.24315 .55285 m .2404 .55085 L .24258 .55027 L F
.263 0 0 r
.2461 .57692 m .24442 .57668 L .24207 .57601 L F
.2461 .57692 m .24442 .57668 L .24207 .57601 L F
.555 .918 .952 r
.2461 .57692 m .24442 .57668 L .24714 .57555 L F
.378 .839 .78 r
.24714 .57555 m .24442 .57668 L .2461 .57692 L F
.875 .834 .803 r
.31988 .53332 m .32246 .5346 L .32433 .53128 L F
.595 .104 .056 r
.61416 .38351 m .61768 .38394 L .61487 .38248 L F
.641 .868 .984 r
.64019 .39111 m .63685 .39073 L .63871 .38935 L F
.82 .837 .861 r
.64154 .38644 m .64019 .39111 L .63871 .38935 L F
.563 .243 .384 r
.54473 .4186 m .54705 .41947 L .54848 .41704 L F
0 0 .078 r
.54848 .41704 m .54967 .41615 L .55064 .41398 L F
0 0 0 r
.54848 .41704 m .54705 .41947 L .54967 .41615 L F
.822 1 .822 r
.7083 .33199 m .71081 .32812 L .70765 .33096 L F
.7083 .33199 m .71128 .32893 L .71081 .32812 L F
.447 .661 .952 r
.34067 .52517 m .34332 .52814 L .34035 .52827 L F
.991 .735 .41 r
.34035 .52827 m .33855 .52948 L .34067 .52517 L F
.34035 .52827 m .33997 .53066 L .33855 .52948 L F
.152 0 .294 r
.34207 .52929 m .33997 .53066 L .34035 .52827 L F
.236 .753 .833 r
.33202 .5202 m .32863 .52056 L .32848 .5187 L F
.33202 .5202 m .3305 .52011 L .32863 .52056 L F
.55 .93 .901 r
.33321 .51869 m .33202 .5202 L .33493 .51973 L F
.33321 .51869 m .3305 .52011 L .33202 .5202 L F
.769 .532 .576 r
.40868 .45518 m .4126 .45575 L .41277 .45306 L F
.529 0 0 r
.41542 .45462 m .41277 .45306 L .4126 .45575 L F
.541 .916 .761 r
.47496 .42975 m .47275 .43122 L .47097 .43191 L F
.571 .186 .273 r
.29759 .57952 m .29916 .58227 L .29655 .5823 L F
.29759 .57952 m .30077 .57963 L .29916 .58227 L F
.44 .324 .625 r
.23186 .58882 m .23394 .5863 L .23127 .58704 L F
.23186 .58882 m .23399 .58891 L .23394 .5863 L F
.313 0 .134 r
.69017 .29589 m .69301 .29512 L .6933 .29316 L F
0 0 .404 r
.6933 .29316 m .69503 .28859 L .69605 .28955 L F
.6933 .29316 m .69514 .29111 L .69503 .28859 L F
.983 .705 .335 r
.69503 .28859 m .69514 .29111 L .69374 .28738 L F
.69503 .28859 m .69374 .28738 L .69363 .28708 L F
0 0 .404 r
.69605 .28955 m .69503 .28859 L .69655 .28889 L F
.174 0 .107 r
.6933 .29316 m .69554 .29378 L .69514 .29111 L F
.6933 .29316 m .69301 .29512 L .69554 .29378 L F
.498 .172 .346 r
.27857 .5871 m .27805 .58926 L .27544 .58945 L F
.44 .094 .281 r
.28172 .58621 m .27805 .58926 L .27857 .5871 L F
.315 .764 .958 r
.30702 .65614 m .31061 .65644 L .30916 .65599 L F
.381 .795 .978 r
.31061 .65644 m .31155 .65533 L .30916 .65599 L F
.31061 .65644 m .31353 .65622 L .31155 .65533 L F
.682 .735 .89 r
.46698 .53773 m .46855 .54027 L .46548 .53971 L F
.46698 .53773 m .46884 .53761 L .46855 .54027 L F
.898 .836 .776 r
.47112 .53733 m .46855 .54027 L .46883 .53763 L F
.261 0 0 r
.46794 .53866 m .46996 .53814 L .46751 .5378 L F
.46711 .53785 m .46751 .5378 L .46698 .53773 L F
.46794 .53866 m .46751 .5378 L .46711 .53785 L F
.898 .836 .776 r
.47116 .53728 m .47112 .53733 L .46884 .53761 L F
.47112 .53733 m .46883 .53763 L .46884 .53761 L F
.47116 .53728 m .46884 .53761 L .46886 .53742 L F
.268 0 0 r
.46884 .53761 m .46996 .53814 L .47088 .53748 L F
.46698 .53773 m .46751 .5378 L .46884 .53761 L F
.46751 .5378 m .46996 .53814 L .46884 .53761 L F
.46698 .53773 m .47088 .53748 L .47116 .53728 L F
.682 .735 .89 r
.46698 .53773 m .46886 .53742 L .46884 .53761 L F
.869 .59 .512 r
.46855 .54027 m .46484 .54246 L .46548 .53971 L F
.971 .842 .657 r
.32893 .61172 m .32808 .60737 L .32704 .6105 L F
.414 .169 .43 r
.49221 .50825 m .49512 .50847 L .49637 .50526 L F
0 0 .42 r
.49221 .50825 m .49346 .50948 L .49512 .50847 L F
.49221 .50825 m .49293 .51096 L .49346 .50948 L F
.879 .869 .824 r
.38621 .47253 m .38353 .47618 L .38373 .47415 L F
.88 .87 .823 r
.38373 .47415 m .38353 .47618 L .38187 .47467 L F
0 .04 .559 r
.38493 .47458 m .38353 .47618 L .38373 .47415 L F
0 0 0 r
.28442 .60509 m .28874 .60179 L .28538 .60316 L F
.28442 .60509 m .28767 .60279 L .28874 .60179 L F
.126 0 0 r
.28874 .60179 m .28767 .60279 L .28538 .60316 L F
0 0 0 r
.29028 .60183 m .28767 .60279 L .28874 .60179 L F
.29028 .60183 m .28767 .60279 L .28874 .60179 L F
.52568 .43204 m .53 .43043 L .52824 .43119 L F
.64 .948 .731 r
.52824 .43119 m .53 .43043 L .53252 .42813 L F
.65 .776 .94 r
.52742 .43929 m .52908 .44191 L .53106 .44064 L F
.541 .512 .772 r
.34015 .6083 m .33862 .61262 L .33801 .60801 L F
.557 .779 .981 r
.43552 .49016 m .43744 .49178 L .43478 .49271 L F
.43478 .49271 m .43744 .49178 L .43552 .49016 L F
.43478 .49271 m .43744 .49178 L .43552 .49016 L F
.623 .907 .984 r
.53411 .44967 m .52969 .45033 L .53283 .45117 L F
0 0 0 r
.53411 .44967 m .53468 .45032 L .53677 .44911 L F
.53411 .44967 m .53283 .45117 L .53468 .45032 L F
.642 .622 .814 r
.45426 .5822 m .45036 .58003 L .45294 .58224 L F
.513 .703 .956 r
.45559 .58009 m .45426 .5822 L .45294 .58224 L F
.45559 .58009 m .45796 .58216 L .45426 .5822 L F
.072 .185 .678 r
.54124 .45743 m .53855 .4562 L .54191 .45494 L F
.54083 .45785 m .53855 .4562 L .54124 .45743 L F
.861 .908 .863 r
.53797 .46071 m .53953 .45652 L .53702 .45983 L F
.5382 .46091 m .53838 .46029 L .53797 .46071 L F
.53838 .46029 m .53953 .45652 L .53797 .46071 L F
.072 .185 .678 r
.54108 .45803 m .54083 .45785 L .54124 .45743 L F
.848 .438 .258 r
.37579 .50744 m .37188 .50404 L .37415 .50513 L F
.502 .097 .204 r
.26882 .58961 m .26445 .59205 L .2663 .58958 L F
.649 .941 .696 r
.67559 .36161 m .67701 .3611 L .67438 .36331 L F
.94 .964 .721 r
.67798 .35886 m .67701 .3611 L .67719 .35664 L F
.461 0 0 r
.34812 .52006 m .35076 .52228 L .34867 .52052 L F
.684 .752 .903 r
.34867 .52052 m .35076 .52228 L .35201 .5208 L F
.783 .93 .93 r
.4865 .42256 m .48467 .42432 L .48299 .42321 L F
.553 .68 .923 r
.2513 .58776 m .25575 .58999 L .25401 .58864 L F
.7 .339 .36 r
.38736 .48164 m .38402 .4791 L .3841 .4825 L F
.806 .448 0 r
.40125 .54721 m .40298 .55105 L .40207 .54955 L F
.816 .335 0 r
.40298 .55105 m .40229 .55199 L .40207 .54955 L F
.40298 .55105 m .40428 .55294 L .40229 .55199 L F
.982 .82 .605 r
.58636 .43729 m .58864 .4403 L .58863 .43644 L F
.988 .809 .576 r
.58647 .44098 m .58864 .4403 L .58636 .43729 L F
.183 .64 .94 r
.28213 .51235 m .28032 .51114 L .27832 .51102 L F
.27832 .51102 m .28032 .51114 L .28213 .51235 L F
.673 .896 .977 r
.28213 .51235 m .28318 .50974 L .28508 .51156 L F
.28213 .51235 m .28032 .51114 L .28318 .50974 L F
.28213 .51235 m .28318 .50974 L .28508 .51156 L F
.28213 .51235 m .28032 .51114 L .28318 .50974 L F
0 0 0 r
.34915 .59948 m .34597 .60262 L .34642 .59973 L F
.568 .115 .136 r
.42916 .5781 m .42529 .57916 L .42485 .57608 L F
.42916 .5781 m .42894 .57922 L .42529 .57916 L F
.394 .755 .993 r
.34658 .62234 m .34465 .6236 L .34198 .62212 L F
.771 .653 .732 r
.34568 .63142 m .34365 .63283 L .34616 .62943 L F
.923 .701 .584 r
.40645 .58014 m .40425 .57964 L .40462 .57639 L F
.873 .484 .297 r
.40645 .58014 m .40497 .58209 L .40425 .57964 L F
.979 .694 .405 r
.40655 .58298 m .40497 .58209 L .40645 .58014 L F
.455 .244 .503 r
.46577 .52705 m .46888 .52393 L .46914 .52076 L F
.935 .857 .74 r
.58711 .44878 m .58967 .44524 L .58673 .44487 L F
.822 .937 .904 r
.45985 .43905 m .45667 .44006 L .45907 .4387 L F
.763 .9 .938 r
.46164 .4358 m .45985 .43905 L .45907 .4387 L F
.46164 .4358 m .46331 .43714 L .45985 .43905 L F
.599 .523 .74 r
.55137 .40667 m .55036 .41172 L .54848 .40927 L F
.55137 .40667 m .55167 .41122 L .55036 .41172 L F
.625 .871 .988 r
.55036 .41172 m .55087 .40981 L .54848 .40927 L F
.55036 .41172 m .55167 .41122 L .55087 .40981 L F
.541 .372 .601 r
.55036 .41172 m .55064 .41398 L .55167 .41122 L F
0 0 .546 r
.27413 .64329 m .27344 .64309 L .27228 .64233 L F
.434 .831 .62 r
.5462 .48411 m .54665 .48388 L .5488 .48238 L F
.325 .779 .631 r
.54461 .48494 m .54722 .4836 L .54665 .48388 L F
0 0 0 r
.54348 .48651 m .54461 .48494 L .54665 .48388 L F
.434 .831 .62 r
.54492 .48497 m .54665 .48388 L .5462 .48411 L F
.325 .779 .631 r
.54722 .4836 m .54839 .483 L .54665 .48388 L F
.399 .824 .655 r
.54665 .48388 m .54839 .483 L .5506 .48166 L F
.707 .285 .243 r
.45067 .59644 m .44769 .59737 L .44656 .59602 L F
.179 0 0 r
.45339 .59661 m .44769 .59737 L .45067 .59644 L F
.959 .927 .722 r
.70337 .34136 m .70467 .33936 L .70445 .336 L F
.759 .977 .716 r
.70963 .29659 m .70797 .29854 L .70803 .29927 L F
.844 .457 .316 r
.70677 .30086 m .70899 .30189 L .70803 .29927 L F
.644 .633 .825 r
.40665 .49134 m .40805 .49324 L .41038 .49194 L F
.66 .584 .759 r
.43586 .59284 m .43372 .59548 L .43217 .59145 L F
0 0 0 r
.61016 .37561 m .61043 .37485 L .61162 .37381 L F
.61016 .37561 m .60949 .37779 L .61043 .37485 L F
.69 .977 .8 r
.25188 .59519 m .25156 .59485 L .25295 .59429 L F
.487 .723 .976 r
.25392 .59343 m .25369 .59503 L .25295 .59429 L F
.25369 .59503 m .25356 .59596 L .25329 .59521 L F
.25369 .59503 m .25329 .59521 L .25295 .59429 L F
.25392 .59343 m .25567 .59535 L .25356 .59596 L F
.441 .699 .975 r
.25392 .59343 m .25768 .59477 L .25567 .59535 L F
.982 .834 .621 r
.25295 .59429 m .25069 .59462 L .25392 .59343 L F
.25069 .59462 m .25066 .59463 L .25071 .59461 L F
.25069 .59462 m .25071 .59461 L .25392 .59343 L F
.25295 .59429 m .25081 .59515 L .25066 .59463 L F
.214 .723 .893 r
.25071 .59461 m .25768 .59477 L .25392 .59343 L F
.25066 .59463 m .25072 .59463 L .25071 .59461 L F
.25072 .59463 m .25768 .59477 L .25071 .59461 L F
.25137 .59464 m .25508 .59441 L .25442 .5947 L F
.25132 .59459 m .25557 .59438 L .25137 .59464 L F
.69 .977 .8 r
.2502 .5966 m .25081 .59515 L .25156 .59485 L F
.2502 .5966 m .25156 .59485 L .25188 .59519 L F
.443 .751 .994 r
.25151 .59321 m .25557 .59438 L .25066 .59463 L F
.001 .176 .692 r
.25087 .59506 m .2529 .59734 L .25171 .5938 L F
.25081 .59515 m .25097 .59531 L .25087 .59506 L F
.25097 .59531 m .2529 .59734 L .25087 .59506 L F
.25113 .59427 m .25171 .5938 L .25151 .59321 L F
.214 .723 .893 r
.25072 .59463 m .25132 .59459 L .25137 .59464 L F
.25066 .59463 m .25073 .59462 L .25072 .59463 L F
.25073 .59462 m .25132 .59459 L .25072 .59463 L F
.001 .176 .692 r
.25105 .59451 m .25171 .5938 L .25113 .59427 L F
.25081 .59515 m .25131 .59441 L .25105 .59451 L F
.25131 .59441 m .25171 .5938 L .25105 .59451 L F
.214 .723 .893 r
.25471 .59471 m .25557 .59438 L .25768 .59477 L F
0 0 0 r
.25458 .59511 m .25636 .59407 L .25557 .59438 L F
.651 .928 .973 r
.25768 .59477 m .25557 .59438 L .25844 .59285 L F
0 0 0 r
.25636 .59407 m .25844 .59285 L .25557 .59438 L F
.214 .723 .893 r
.25442 .5947 m .25557 .59438 L .25471 .59471 L F
.25508 .59441 m .25557 .59438 L .25442 .5947 L F
.065 .218 .713 r
.25095 .59877 m .25081 .59515 L .2502 .5966 L F
.822 .962 .9 r
.44741 .58522 m .44555 .58736 L .44355 .58696 L F
.887 .973 .831 r
.3724 .62439 m .37569 .62336 L .37688 .62121 L F
.824 .632 .642 r
.33855 .52948 m .33708 .52996 L .33831 .52925 L F
.33648 .53032 m .33569 .53051 L .33636 .53018 L F
.33681 .53012 m .33636 .53018 L .33831 .52925 L F
.33648 .53032 m .33636 .53018 L .33681 .53012 L F
.655 .247 .26 r
.33161 .52927 m .3348 .52996 L .33831 .52925 L F
.675 .4 .497 r
.3348 .52996 m .33496 .52994 L .33831 .52925 L F
.423 .279 .58 r
.33636 .53018 m .33511 .52991 L .33831 .52925 L F
.675 .4 .497 r
.33496 .52994 m .33855 .52948 L .33831 .52925 L F
.423 .279 .58 r
.33511 .52991 m .3322 .52927 L .33831 .52925 L F
.33622 .53025 m .33531 .53003 L .33636 .53018 L F
.3349 .52993 m .3322 .52927 L .33503 .52989 L F
.608 .727 .929 r
.3379 .53187 m .33527 .53279 L .33325 .53109 L F
.3379 .53187 m .33325 .53109 L .33347 .53103 L F
0 0 .22 r
.33811 .53213 m .3382 .53426 L .3379 .53187 L F
.342 0 0 r
.33811 .53213 m .3379 .53187 L .33311 .53097 L F
.608 .727 .929 r
.33347 .53103 m .33325 .53109 L .33311 .53097 L F
.795 .704 .764 r
.33311 .53097 m .3368 .5384 L .33811 .53213 L F
.423 .279 .58 r
.33234 .52943 m .33161 .52927 L .3322 .52927 L F
.33243 .53 m .33161 .52927 L .3328 .52999 L F
.3328 .52999 m .33161 .52927 L .33234 .52943 L F
.189 .715 .852 r
.33469 .52996 m .3348 .52996 L .33161 .52927 L F
.33469 .52996 m .33477 .52996 L .3348 .52996 L F
.664 .957 .944 r
.3348 .52996 m .33477 .52996 L .33481 .52995 L F
.675 .4 .497 r
.3348 .52996 m .33531 .53003 L .33496 .52994 L F
.664 .957 .944 r
.3348 .52996 m .33481 .52995 L .3349 .52996 L F
.423 .279 .58 r
.33394 .53134 m .3322 .52927 L .33622 .53025 L F
.807 .724 .773 r
.33161 .52927 m .32884 .53239 L .32702 .52983 L F
.613 .424 .602 r
.33084 .53014 m .33179 .53251 L .32884 .53239 L F
.33161 .52927 m .33166 .53009 L .33084 .53014 L F
.33166 .53009 m .33179 .53251 L .33084 .53014 L F
.423 .279 .58 r
.33394 .53134 m .33179 .53251 L .33166 .53009 L F
.33243 .53 m .33166 .53009 L .33161 .52927 L F
.33394 .53134 m .33166 .53009 L .33243 .53 L F
.189 .715 .852 r
.32994 .52986 m .33469 .52996 L .33161 .52927 L F
.32994 .52986 m .33217 .52964 L .33379 .52984 L F
.33323 .5299 m .33379 .52984 L .33443 .52992 L F
.32994 .52986 m .33379 .52984 L .33323 .5299 L F
.334 .52994 m .33443 .52992 L .33477 .52996 L F
.32994 .52986 m .33443 .52992 L .334 .52994 L F
.32994 .52986 m .33477 .52996 L .33469 .52996 L F
.423 .279 .58 r
.33394 .53134 m .33243 .53 L .3328 .52999 L F
.664 .957 .944 r
.33481 .52995 m .33217 .52964 L .33554 .5279 L F
.33477 .52996 m .33217 .52964 L .33481 .52995 L F
.423 .279 .58 r
.33531 .53003 m .3349 .52993 L .33636 .53018 L F
.3349 .52993 m .33503 .52989 L .33636 .53018 L F
.675 .4 .497 r
.33496 .52994 m .33646 .53017 L .33855 .52948 L F
.33646 .53017 m .3377 .53033 L .33855 .52948 L F
.824 .632 .642 r
.3377 .53033 m .338 .53243 L .33611 .53193 L F
.33855 .52948 m .33835 .53055 L .3377 .53033 L F
.33835 .53055 m .338 .53243 L .3377 .53033 L F
.664 .957 .944 r
.33646 .53017 m .33704 .53009 L .3377 .53033 L F
.824 .632 .642 r
.33704 .53009 m .33611 .53193 L .33394 .53134 L F
.33855 .52948 m .3377 .53033 L .33704 .53009 L F
.3377 .53033 m .33611 .53193 L .33704 .53009 L F
.33855 .52948 m .33648 .53032 L .33708 .52996 L F
.664 .957 .944 r
.33676 .53 m .33554 .5279 L .33762 .53001 L F
.3349 .52996 m .33507 .5294 L .33676 .53 L F
.33507 .5294 m .33554 .5279 L .33676 .53 L F
.3377 .53033 m .33762 .53001 L .33797 .53036 L F
.33704 .53009 m .33762 .53001 L .3377 .53033 L F
.675 .4 .497 r
.3377 .53033 m .33797 .53036 L .33855 .52948 L F
.664 .957 .944 r
.33481 .52995 m .33554 .5279 L .3349 .52996 L F
.675 .4 .497 r
.33531 .53003 m .33646 .53017 L .33496 .52994 L F
.664 .957 .944 r
.3348 .52996 m .33762 .53001 L .33646 .53017 L F
.824 .632 .642 r
.33648 .53032 m .33394 .53134 L .33569 .53051 L F
.988 .831 .6 r
.59674 .4075 m .59478 .40886 L .59561 .40625 L F
.59674 .4075 m .59615 .41029 L .59478 .40886 L F
0 0 .344 r
.46024 .56416 m .4601 .56656 L .46137 .56445 L F
.478 .274 .525 r
.56516 .3799 m .56273 .37785 L .56163 .37603 L F
.56516 .3799 m .56257 .38058 L .56273 .37785 L F
.833 .648 .651 r
.42489 .53669 m .42714 .53811 L .42732 .53474 L F
.955 .623 .346 r
.42558 .53351 m .42591 .53588 L .42732 .53474 L F
.009 0 .014 r
.65873 .32207 m .65825 .32413 L .66106 .3213 L F
.575 .364 .557 r
.45345 .57718 m .45332 .58161 L .45036 .58003 L F
0 0 .165 r
.45422 .57714 m .45345 .57718 L .45384 .57681 L F
.45422 .57714 m .45332 .58161 L .45345 .57718 L F
.636 .255 .306 r
.45036 .58003 m .45332 .58161 L .45294 .58224 L F
.761 .762 .853 r
.45422 .57714 m .45294 .58224 L .45332 .58161 L F
.45422 .57714 m .45559 .58009 L .45294 .58224 L F
.251 0 0 r
.4544 .5773 m .45422 .57714 L .45241 .57679 L F
0 0 .558 r
.4581 .57927 m .45796 .58216 L .45559 .58009 L F
0 0 0 r
.45678 .5798 m .4581 .57927 L .45559 .58009 L F
0 .031 .571 r
.45466 .57737 m .45678 .5798 L .45422 .57714 L F
.251 0 0 r
.45466 .57737 m .45422 .57714 L .4544 .5773 L F
0 0 .165 r
.45422 .57714 m .45384 .57681 L .45491 .5758 L F
.849 .992 .845 r
.45215 .44125 m .45319 .44176 L .45187 .44355 L F
.705 .901 .966 r
.45033 .44235 m .45215 .44125 L .45187 .44355 L F
.742 .911 .951 r
.44642 .4446 m .45033 .44235 L .45187 .44355 L F
0 0 .035 r
.25065 .52175 m .24821 .52481 L .25006 .52336 L F
.36 0 .206 r
.25065 .52175 m .25006 .52336 L .25262 .52245 L F
0 .318 .762 r
.60371 .42348 m .60678 .42513 L .60534 .42383 L F
.879 .869 .824 r
.38621 .47253 m .38373 .47415 L .38493 .47458 L F
.88 .87 .823 r
.38373 .47415 m .38187 .47467 L .38493 .47458 L F
.134 0 .13 r
.38493 .47458 m .38373 .47415 L .38462 .47391 L F
.879 .869 .824 r
.38621 .47253 m .38493 .47458 L .3844 .47343 L F
.134 0 .13 r
.38493 .47458 m .38462 .47391 L .38697 .47328 L F
.38493 .47458 m .38373 .47415 L .38697 .47328 L F
.879 .869 .824 r
.3844 .47343 m .38493 .47458 L .38187 .47467 L F
.94 .761 .632 r
.38824 .56897 m .39087 .5673 L .38918 .56644 L F
.38824 .56897 m .39023 .57006 L .39087 .5673 L F
.272 .087 .437 r
.35489 .53134 m .35612 .53094 L .35716 .52769 L F
.353 .303 .662 r
.35489 .53134 m .35733 .53335 L .35612 .53094 L F
.715 .57 .691 r
.34616 .62943 m .34365 .63283 L .34144 .62892 L F
.443 .261 .538 r
.67443 .35491 m .67538 .3559 L .67639 .35224 L F
.267 .08 .431 r
.51342 .47889 m .51549 .47829 L .51564 .47543 L F
.361 .357 .72 r
.51342 .47889 m .51623 .48063 L .51549 .47829 L F
.4 .35 .686 r
.51342 .47889 m .51385 .48206 L .51623 .48063 L F
.556 .648 .895 r
.55628 .42619 m .55708 .42181 L .55567 .42628 L F
.55628 .42619 m .56035 .42651 L .55708 .42181 L F
.561 .618 .867 r
.496 .46234 m .49758 .45924 L .49496 .46002 L F
.496 .46234 m .49954 .46293 L .49758 .45924 L F
.9 .776 .715 r
.40559 .58586 m .40715 .58842 L .40524 .58728 L F
.981 .705 .425 r
.40715 .58842 m .40545 .58921 L .40524 .58728 L F
.40715 .58842 m .40706 .59037 L .40545 .58921 L F
.079 .275 .761 r
.60151 .34452 m .59945 .34617 L .59803 .34486 L F
.60151 .34452 m .60265 .34824 L .59945 .34617 L F
.307 .388 .782 r
.32903 .60255 m .32967 .60533 L .32996 .60496 L F
.562 .813 .437 r
.32967 .60533 m .32808 .60737 L .32996 .60496 L F
.699 .903 .969 r
.71287 .32618 m .71128 .32893 L .71422 .32689 L F
.77 .994 .873 r
.71081 .32812 m .71128 .32893 L .71287 .32618 L F
.65 .194 .157 r
.33158 .5801 m .334 .58219 L .32983 .58183 L F
.593 .235 .33 r
.33382 .58029 m .334 .58219 L .33158 .5801 L F
.817 .865 .882 r
.34198 .62212 m .34155 .62574 L .34162 .62134 L F
.159 0 0 r
.34224 .6525 m .34726 .65191 L .34616 .65173 L F
.294 .789 .864 r
.34616 .65173 m .34726 .65191 L .34978 .65135 L F
.495 .519 .811 r
.53719 .43879 m .5352 .43986 L .53392 .43601 L F
.403 .845 .733 r
.53423 .44016 m .5352 .43986 L .53719 .43879 L F
.511 .318 .555 r
.35377 .58975 m .35391 .59284 L .35135 .59313 L F
.605 .389 .562 r
.35686 .59229 m .35377 .58975 L .35684 .5895 L F
.396 .777 .991 r
.42935 .57409 m .42586 .57353 L .42719 .57534 L F
.965 .922 .706 r
.42935 .57409 m .42719 .57534 L .42843 .57309 L F
.189 .312 .76 r
.5573 .41624 m .55899 .41532 L .55678 .41446 L F
0 0 0 r
.5573 .41624 m .55648 .41871 L .55899 .41532 L F
.86 .966 .866 r
.56657 .38136 m .5631 .38283 L .56516 .3799 L F
.56657 .38136 m .56342 .38428 L .5631 .38283 L F
.316 .687 .978 r
.56781 .3801 m .56657 .38136 L .56516 .3799 L F
.56781 .3801 m .56952 .38165 L .56657 .38136 L F
.674 .515 .662 r
.42338 .45621 m .42077 .45968 L .4239 .45859 L F
.42338 .45621 m .42077 .45968 L .4239 .45859 L F
.422 .349 .67 r
.42584 .45774 m .4239 .45859 L .42338 .45621 L F
.53 .673 .928 r
.4239 .45859 m .42584 .45774 L .42338 .45621 L F
.234 0 0 r
.38838 .45813 m .39257 .45574 L .39002 .45939 L F
.38838 .45813 m .39101 .45776 L .39257 .45574 L F
.438 .847 .669 r
.39257 .45574 m .39414 .45462 L .39514 .45412 L F
.716 .259 .165 r
.39257 .45574 m .39502 .45815 L .39414 .45462 L F
.39257 .45574 m .39101 .45776 L .39502 .45815 L F
.265 0 0 r
.3364 .5562 m .33916 .55573 L .34003 .55456 L F
0 0 0 r
.34003 .55456 m .33916 .55573 L .34165 .55322 L F
.965 .661 .398 r
.38311 .55238 m .38474 .55086 L .38204 .54942 L F
.38311 .55238 m .38491 .55345 L .38474 .55086 L F
.644 .154 .072 r
.34965 .57098 m .35258 .57271 L .3484 .57221 L F
.639 .09 0 r
.58119 .39546 m .58314 .39629 L .57954 .39268 L F
.58119 .39546 m .58302 .39653 L .58314 .39629 L F
.846 .8 .806 r
.44978 .56899 m .45237 .57104 L .44922 .57346 L F
.68 .794 .935 r
.45463 .56961 m .45237 .57104 L .44978 .56899 L F
.642 .677 .868 r
.45463 .56961 m .45509 .57139 L .45237 .57104 L F
.377 .818 .952 r
.55058 .43833 m .55139 .43896 L .54949 .43932 L F
.55058 .43833 m .54949 .43932 L .5488 .43945 L F
0 0 0 r
.55106 .43789 m .55058 .43833 L .54964 .43974 L F
.456 .777 .998 r
.55188 .43682 m .55139 .43896 L .55058 .43833 L F
0 0 0 r
.55188 .43682 m .55058 .43833 L .55106 .43789 L F
.377 .818 .952 r
.55058 .43833 m .5488 .43945 L .54735 .44114 L F
.984 .709 .341 r
.40621 .56653 m .40486 .56263 L .40673 .56388 L F
.734 .601 .708 r
.28996 .65234 m .29278 .6514 L .29185 .6506 L F
.507 .584 .867 r
.29278 .6514 m .29495 .65124 L .29185 .6506 L F
.471 .538 .843 r
.29278 .6514 m .29652 .65437 L .29495 .65124 L F
.986 .866 .633 r
.40488 .55733 m .40359 .56073 L .4025 .5592 L F
.981 .768 .356 r
.40488 .55733 m .40402 .5566 L .40428 .55294 L F
.954 .952 .686 r
.40488 .55733 m .4025 .5592 L .40402 .5566 L F
0 0 0 r
.68038 .37695 m .68434 .37511 L .68272 .37557 L F
.572 .932 .774 r
.68272 .37557 m .68434 .37511 L .68645 .37352 L F
.691 .416 .502 r
.24984 .58597 m .25373 .58831 L .25356 .58449 L F
0 0 .302 r
.25356 .58449 m .25485 .58445 L .25638 .58379 L F
.25356 .58449 m .25373 .58831 L .25485 .58445 L F
0 0 .35 r
.43556 .56681 m .43744 .57037 L .43587 .56745 L F
.519 .9 .731 r
.58191 .45432 m .58289 .45384 L .58504 .45231 L F
.682 .429 .532 r
.42477 .48477 m .42914 .48228 L .42509 .48215 L F
.42477 .48477 m .42936 .48487 L .42914 .48228 L F
0 0 0 r
.41039 .47864 m .40859 .48123 L .40797 .47887 L F
.486 .213 .425 r
.40521 .48094 m .41039 .47864 L .40797 .47887 L F
.689 .459 .569 r
.35434 .59558 m .35135 .59313 L .35391 .59284 L F
.35434 .59558 m .35155 .59616 L .35135 .59313 L F
.798 .689 .745 r
.46408 .52996 m .46496 .53414 L .46398 .53295 L F
.363 .448 .814 r
.46698 .53773 m .46398 .53295 L .46496 .53414 L F
.692 .482 .598 r
.55593 .39726 m .55351 .40032 L .55386 .39747 L F
.55593 .39726 m .55666 .4006 L .55351 .40032 L F
0 0 .125 r
.48505 .55627 m .48455 .55881 L .48319 .56045 L F
0 0 0 r
.48455 .55881 m .48276 .56301 L .48319 .56045 L F
.719 .605 .729 r
.52855 .42331 m .53026 .42406 L .53116 .42052 L F
.774 .392 .331 r
.52855 .42331 m .53127 .42655 L .53026 .42406 L F
.673 .538 .693 r
.53026 .42406 m .5333 .41908 L .53116 .42052 L F
.53026 .42406 m .53503 .42335 L .5333 .41908 L F
.742 .376 .361 r
.53026 .42406 m .53545 .42597 L .53503 .42335 L F
.391 .018 .206 r
.53545 .42597 m .53252 .42813 L .53127 .42655 L F
.53545 .42597 m .53453 .42809 L .53252 .42813 L F
0 0 0 r
.53252 .42813 m .53545 .42597 L .53453 .42809 L F
.451 .534 .851 r
.53308 .42719 m .53453 .42809 L .53252 .42813 L F
.742 .376 .361 r
.53026 .42406 m .53102 .42592 L .53545 .42597 L F
.53102 .42592 m .5319 .42647 L .53545 .42597 L F
.451 .534 .851 r
.53395 .42573 m .53453 .42808 L .53308 .42719 L F
.53453 .42808 m .53453 .42809 L .53308 .42719 L F
.742 .376 .361 r
.53102 .42592 m .53127 .42655 L .5319 .42647 L F
.038 0 .166 r
.4997 .52479 m .49894 .52697 L .49723 .52812 L F
.125 0 .31 r
.49894 .52697 m .49679 .53061 L .49723 .52812 L F
.513 .268 .48 r
.51068 .48549 m .51445 .48508 L .51385 .48206 L F
.305 .137 .481 r
.51385 .48206 m .51615 .48385 L .51623 .48063 L F
.51385 .48206 m .51445 .48508 L .51615 .48385 L F
.335 0 .166 r
.52723 .49655 m .52939 .49719 L .52697 .49815 L F
.52723 .49655 m .52986 .49589 L .52939 .49719 L F
.304 0 0 r
.63278 .34454 m .62905 .34681 L .63016 .34502 L F
0 0 .522 r
.30699 .63876 m .30762 .64172 L .30838 .6413 L F
.695 .28 .255 r
.30603 .64124 m .30699 .63876 L .30838 .6413 L F
.131 0 0 r
.61906 .40649 m .61648 .40733 L .61524 .40933 L F
.638 .183 .156 r
.40227 .50724 m .40621 .50718 L .40404 .50866 L F
.079 0 .257 r
.48509 .52432 m .48715 .52064 L .48508 .52146 L F
.26 .71 .957 r
.41728 .59909 m .41825 .59826 L .41588 .5992 L F
0 0 0 r
.41699 .59892 m .41588 .5992 L .41825 .59826 L F
.576 .91 .975 r
.41484 .59947 m .41728 .59909 L .41588 .5992 L F
0 0 0 r
.41422 .60036 m .41588 .5992 L .41699 .59892 L F
.576 .91 .975 r
.41313 .59974 m .41484 .59947 L .41588 .5992 L F
.26 .71 .957 r
.41728 .59909 m .41986 .59915 L .41825 .59826 L F
.593 .362 .536 r
.35716 .52769 m .36008 .52735 L .36049 .52471 L F
.935 .699 .558 r
.36049 .52471 m .36008 .52735 L .35829 .5235 L F
.606 .859 .991 r
.54891 .47475 m .54652 .47585 L .54522 .47443 L F
.999 .795 .461 r
.54522 .47443 m .54512 .4773 L .54652 .47585 L F
.385 0 .113 r
.54512 .4773 m .54891 .47475 L .54652 .47585 L F
.522 .244 .435 r
.68707 .29844 m .69017 .29589 L .68745 .2966 L F
.41 .589 .916 r
.2991 .65379 m .30044 .65608 L .30234 .65531 L F
.517 .224 .408 r
.3083 .5201 m .30619 .52146 L .311 .51989 L F
0 0 0 r
.29994 .57411 m .30184 .57318 L .30185 .57272 L F
.29994 .57411 m .29895 .57524 L .30184 .57318 L F
.342 .522 .888 r
.60708 .42737 m .60876 .42565 L .60678 .42513 L F
.448 .693 .97 r
.60708 .42737 m .61047 .42741 L .60876 .42565 L F
.946 .944 .747 r
.37865 .61796 m .3803 .61608 L .37906 .61541 L F
0 0 0 r
.48948 .54381 m .48885 .54588 L .4877 .54761 L F
.48885 .54588 m .48688 .54996 L .4877 .54761 L F
.063 .505 .895 r
.61856 .42047 m .61516 .41849 L .61794 .41862 L F
.771 .901 .503 r
.61669 .42384 m .61856 .42047 L .6187 .42232 L F
.581 .754 .96 r
.62072 .41802 m .61856 .42047 L .61794 .41862 L F
0 0 .001 r
.62072 .41802 m .6187 .42232 L .61856 .42047 L F
0 0 0 r
.64106 .33326 m .63777 .33478 L .64036 .33361 L F
.64036 .33361 m .64376 .33221 L .64106 .33326 L F
.852 .954 .878 r
.59829 .43121 m .59556 .43168 L .5972 .42969 L F
.73 .796 .905 r
.59973 .42769 m .59829 .43121 L .5972 .42969 L F
.59973 .42769 m .60066 .42972 L .59829 .43121 L F
.307 .477 .865 r
.60115 .43245 m .59829 .43121 L .60066 .42972 L F
.541 .512 .772 r
.34015 .6083 m .34122 .6121 L .33862 .61262 L F
.726 .574 .684 r
.34122 .6121 m .33833 .61529 L .33862 .61262 L F
.33833 .61529 m .34122 .6121 L .33862 .61262 L F
.393 .33 .668 r
.42339 .4726 m .42353 .47521 L .42231 .47273 L F
.583 .399 .598 r
.5406 .43333 m .5429 .43382 L .54338 .43003 L F
.485 .312 .571 r
.54338 .43003 m .54647 .43248 L .54598 .42895 L F
.54338 .43003 m .5429 .43382 L .54647 .43248 L F
.348 0 0 r
.2452 .58816 m .23929 .5911 L .24082 .58962 L F
.2452 .58816 m .24298 .59077 L .23929 .5911 L F
.638 .175 .137 r
.24543 .59058 m .24298 .59077 L .2452 .58816 L F
.734 .601 .708 r
.28996 .65234 m .29185 .6506 L .29147 .64982 L F
.285 .642 .966 r
.29185 .6506 m .29314 .64963 L .29147 .64982 L F
.29185 .6506 m .29495 .65124 L .29314 .64963 L F
.701 .646 .791 r
.55139 .43896 m .55357 .44285 L .54941 .4425 L F
.247 0 0 r
.54941 .4425 m .55357 .44285 L .55129 .4431 L F
.208 .387 .821 r
.55498 .44121 m .55357 .44285 L .55139 .43896 L F
.601 .952 .882 r
.55129 .4431 m .55357 .44285 L .55498 .44121 L F
.541 .09 .129 r
.43929 .5687 m .4418 .56899 L .44084 .56668 L F
.041 0 0 r
.44084 .56668 m .445 .56649 L .44482 .56637 L F
.745 .651 .757 r
.43236 .47688 m .4317 .47898 L .43434 .47572 L F
.84 .389 0 r
.53707 .42407 m .53545 .42597 L .53503 .42335 L F
.398 .285 .608 r
.53545 .42597 m .53807 .42594 L .53707 .42407 L F
.84 .389 0 r
.53707 .42407 m .5365 .42485 L .53616 .42514 L F
.398 .285 .608 r
.53545 .42597 m .53707 .42407 L .53503 .42335 L F
0 .388 .769 r
.5367 .42468 m .5365 .42485 L .5355 .4241 L F
.84 .389 0 r
.53707 .42407 m .53807 .42594 L .5365 .42485 L F
.614 .874 .991 r
.54037 .42481 m .53807 .42594 L .5365 .42485 L F
.54037 .42481 m .53807 .42594 L .5365 .42485 L F
0 .388 .769 r
.53845 .42553 m .5365 .42485 L .5367 .42468 L F
.84 .389 0 r
.53616 .42514 m .5365 .42485 L .53545 .42597 L F
.333 0 .18 r
.53545 .42597 m .53807 .42594 L .53453 .42809 L F
.796 .921 .921 r
.53453 .42809 m .5365 .42485 L .53545 .42597 L F
.777 .748 .827 r
.43709 .58333 m .44113 .58421 L .44048 .58103 L F
.553 .739 .962 r
.44113 .58421 m .44215 .58184 L .44048 .58103 L F
.44113 .58421 m .44391 .58379 L .44215 .58184 L F
.721 .684 .814 r
.59331 .38073 m .59753 .3819 L .59605 .37836 L F
.033 .564 .857 r
.59331 .38073 m .5963 .38127 L .59753 .3819 L F
.373 .798 .971 r
.59753 .3819 m .59692 .38066 L .59973 .38022 L F
.59753 .3819 m .5963 .38127 L .59692 .38066 L F
.695 .982 .829 r
.45794 .46472 m .46201 .46232 L .46124 .46218 L F
.602 .656 .875 r
.46201 .46232 m .46345 .45836 L .46259 .46034 L F
.46201 .46232 m .46383 .46134 L .46345 .45836 L F
.85 .994 .75 r
.46124 .46218 m .46201 .46232 L .46259 .46034 L F
.477 .883 .741 r
.36866 .49658 m .36765 .49755 L .3662 .49639 L F
.36866 .49658 m .37085 .4957 L .36765 .49755 L F
.727 .614 .732 r
.51699 .46579 m .52091 .46604 L .52042 .46568 L F
.489 .528 .824 r
.51699 .46579 m .52071 .46882 L .52091 .46604 L F
.668 .631 .803 r
.52091 .46604 m .52221 .46182 L .52042 .46568 L F
.52091 .46604 m .52365 .46585 L .52221 .46182 L F
.568 .195 .294 r
.52313 .46751 m .52091 .46604 L .52071 .46882 L F
.52313 .46751 m .52365 .46585 L .52091 .46604 L F
.583 .237 .348 r
.54322 .43525 m .5429 .43382 L .5406 .43333 L F
.896 .968 .822 r
.38111 .61161 m .38465 .60913 L .38275 .60875 L F
0 0 .285 r
.457 .57506 m .45491 .5758 L .45568 .57348 L F
.66 .925 .974 r
.5324 .41311 m .52983 .41421 L .53109 .41217 L F
.642 .903 .983 r
.52983 .41421 m .52794 .41327 L .53109 .41217 L F
.704 .182 0 r
.2812 .58104 m .28209 .57963 L .27892 .5819 L F
.625 .457 .635 r
.50522 .4888 m .50808 .48831 L .5079 .48553 L F
.59 .43 .633 r
.5079 .48553 m .51091 .4876 L .51068 .48549 L F
.5079 .48553 m .50808 .48831 L .51091 .4876 L F
.943 .585 .294 r
.35914 .51146 m .35955 .51378 L .36139 .51483 L F
.789 .308 .079 r
.35989 .5159 m .36139 .51483 L .35955 .51378 L F
.35989 .5159 m .36321 .51718 L .36139 .51483 L F
.394 .144 .413 r
.23958 .55875 m .23761 .55715 L .24112 .55685 L F
0 0 .124 r
.24385 .55317 m .24341 .55677 L .24185 .55723 L F
0 0 0 r
.24231 .55525 m .24223 .55561 L .24112 .55685 L F
.24226 .55558 m .23958 .55875 L .23991 .55835 L F
.24223 .55561 m .24077 .55734 L .24112 .55685 L F
0 0 .124 r
.24223 .55561 m .24185 .55723 L .24077 .55734 L F
0 0 0 r
.24226 .55558 m .23991 .55835 L .24223 .55561 L F
0 0 .124 r
.24231 .55525 m .24223 .55561 L .24077 .55734 L F
.24385 .55317 m .24185 .55723 L .24231 .55525 L F
0 0 0 r
.24231 .55525 m .24226 .55558 L .24223 .55561 L F
0 0 .124 r
.24231 .55525 m .24077 .55734 L .24226 .55558 L F
.24077 .55734 m .24057 .5576 L .24226 .55558 L F
0 0 0 r
.24077 .55734 m .23991 .55835 L .23993 .55833 L F
.24077 .55734 m .23993 .55833 L .24112 .55685 L F
0 0 .124 r
.24077 .55734 m .24185 .55723 L .24057 .5576 L F
0 0 0 r
.24252 .5541 m .24231 .55525 L .24112 .55685 L F
0 0 .124 r
.24385 .55317 m .24231 .55525 L .24226 .55558 L F
0 0 0 r
.24315 .55285 m .24226 .55558 L .24252 .5541 L F
.571 .933 .785 r
.64702 .39618 m .65089 .39414 L .64937 .39473 L F
.395 .833 .697 r
.64937 .39473 m .65089 .39414 L .65339 .39278 L F
.771 .328 .197 r
.39533 .49778 m .39684 .49998 L .39894 .49866 L F
0 0 0 r
.39894 .49866 m .39974 .49861 L .39972 .49807 L F
.39894 .49866 m .39684 .49998 L .39974 .49861 L F
.748 .252 0 r
.39521 .49874 m .39684 .49998 L .39533 .49778 L F
.3952 .49879 m .39529 .49885 L .39521 .49874 L F
.39529 .49885 m .39684 .49998 L .39521 .49874 L F
.545 .31 .511 r
.39509 .49267 m .39292 .49658 L .39401 .49394 L F
.87 .712 .683 r
.39509 .49267 m .39401 .49394 L .39438 .49403 L F
.39509 .49267 m .39438 .49403 L .39704 .49465 L F
.882 .784 .748 r
.39554 .49535 m .39704 .49465 L .39537 .49426 L F
.39292 .49658 m .39533 .49778 L .39566 .49718 L F
.39554 .49535 m .39566 .49718 L .39704 .49465 L F
.39292 .49658 m .39566 .49718 L .39554 .49535 L F
.427 .236 .516 r
.39872 .49704 m .39537 .49301 L .39755 .49336 L F
.39537 .49301 m .39513 .49271 L .39536 .49277 L F
.39537 .49301 m .39536 .49277 L .39755 .49336 L F
.39513 .49271 m .39509 .49267 L .39512 .49267 L F
.39513 .49271 m .39512 .49267 L .39755 .49336 L F
.882 .784 .748 r
.39292 .49658 m .39554 .49535 L .39438 .49403 L F
.39554 .49535 m .39537 .49426 L .39438 .49403 L F
.39292 .49658 m .39438 .49403 L .39401 .49394 L F
.748 .252 0 r
.3952 .49879 m .39533 .49778 L .39292 .49658 L F
.545 .31 .511 r
.39438 .49403 m .39424 .49735 L .39333 .49604 L F
.39509 .49267 m .39506 .49284 L .39438 .49403 L F
.39506 .49284 m .39424 .49735 L .39438 .49403 L F
.39509 .49267 m .39333 .49604 L .39327 .49595 L F
.39509 .49267 m .39631 .49855 L .39424 .49735 L F
.39327 .49595 m .39424 .49735 L .39292 .49658 L F
.499 .827 .999 r
.3952 .49879 m .39974 .49861 L .39684 .49998 L F
.427 .236 .516 r
.39872 .49704 m .39631 .49855 L .39509 .49267 L F
.574 .282 .436 r
.39631 .49855 m .3952 .49879 L .39292 .49658 L F
.499 .827 .999 r
.39819 .49867 m .39853 .49789 L .39974 .49861 L F
.3952 .49879 m .39853 .49789 L .39819 .49867 L F
.394 .118 .372 r
.39872 .49704 m .3952 .49879 L .39631 .49855 L F
.39872 .49704 m .39853 .49789 L .3952 .49879 L F
.95 .809 .362 r
.39813 .49562 m .39853 .49789 L .39872 .49704 L F
.914 .513 .152 r
.39813 .49562 m .39894 .49692 L .39853 .49789 L F
.563 .056 0 r
.39976 .49898 m .39974 .49861 L .39853 .49789 L F
.4008 .49989 m .39974 .49861 L .39976 .49898 L F
.713 .484 .576 r
.39974 .49861 m .40198 .49601 L .40029 .49764 L F
.39974 .49861 m .40253 .50137 L .40198 .49601 L F
.914 .513 .152 r
.39894 .49692 m .4008 .49989 L .39853 .49789 L F
0 0 0 r
.39972 .49807 m .39974 .49861 L .40029 .49764 L F
.275 .746 .941 r
.35648 .52117 m .3543 .52062 L .35201 .5208 L F
.826 .491 .422 r
.35829 .5235 m .3543 .52062 L .35648 .52117 L F
.85 .969 .874 r
.49877 .41356 m .50009 .40991 L .502 .4114 L F
.49877 .41356 m .49767 .41271 L .50009 .40991 L F
0 0 0 r
.25216 .52798 m .25098 .52952 L .24966 .53093 L F
.123 .234 .708 r
.25098 .52952 m .25181 .53299 L .24966 .53093 L F
.576 .805 .986 r
.54329 .41076 m .54254 .41145 L .53954 .41096 L F
.848 .783 .788 r
.54446 .40953 m .54573 .41293 L .54254 .41145 L F
0 0 0 r
.54446 .40953 m .54254 .41145 L .54329 .41076 L F
.83 .717 .74 r
.53494 .46628 m .53738 .46583 L .53712 .46344 L F
.589 .383 .57 r
.53445 .46872 m .53738 .46583 L .53494 .46628 L F
.53445 .46872 m .5376 .46851 L .53738 .46583 L F
.58 .482 .708 r
.53738 .46583 m .53962 .46216 L .53712 .46344 L F
.53738 .46583 m .54041 .46541 L .53962 .46216 L F
.651 .496 .661 r
.5376 .46851 m .54041 .46541 L .53738 .46583 L F
0 0 .243 r
.45463 .56961 m .45568 .57348 L .45509 .57139 L F
.488 .827 .999 r
.69503 .28859 m .69928 .28903 L .69655 .28889 L F
.895 .615 .504 r
.36321 .51718 m .36544 .52036 L .36493 .51835 L F
.726 .968 .936 r
.6154 .42339 m .61669 .42384 L .6187 .42232 L F
.832 .374 0 r
.39153 .52468 m .39012 .52376 L .3889 .52142 L F
.926 .661 .516 r
.39153 .52468 m .38915 .52635 L .39012 .52376 L F
.39153 .52468 m .39142 .52731 L .38915 .52635 L F
.061 0 0 r
.45728 .59569 m .45606 .59629 L .45339 .59661 L F
0 0 0 r
.45986 .59526 m .45822 .59564 L .45728 .59569 L F
.45728 .59569 m .45822 .59564 L .45606 .59629 L F
.54322 .43525 m .54691 .43287 L .54647 .43248 L F
.807 .861 .888 r
.54691 .43287 m .55001 .43018 L .54838 .42872 L F
.54691 .43287 m .54838 .42872 L .54849 .43123 L F
.575 .942 .872 r
.54647 .43248 m .54691 .43287 L .54849 .43123 L F
.003 0 .033 r
.24821 .52481 m .24895 .52619 L .25006 .52336 L F
.24821 .52481 m .24743 .52754 L .24895 .52619 L F
.412 .279 .588 r
.71095 .28978 m .71093 .28993 L .70833 .29081 L F
.262 .763 .724 r
.70603 .29159 m .70833 .29081 L .70907 .29071 L F
.448 0 0 r
.70833 .29081 m .71207 .29234 L .70907 .29071 L F
.403 0 0 r
.70907 .29071 m .71207 .29234 L .71367 .29302 L F
.522 0 0 r
.70833 .29081 m .71238 .29414 L .71207 .29234 L F
.71039 .29251 m .71062 .29285 L .71238 .29414 L F
.70833 .29081 m .71062 .29285 L .71039 .29251 L F
.877 .936 .561 r
.71062 .29285 m .70963 .29659 L .71238 .29414 L F
0 0 0 r
.71247 .28931 m .71093 .29332 L .71062 .29285 L F
.71093 .29332 m .71071 .2939 L .71062 .29285 L F
.412 .279 .588 r
.71093 .28993 m .71062 .29285 L .70833 .29081 L F
.262 .763 .724 r
.70579 .29166 m .70833 .29081 L .70603 .29159 L F
.807 .736 .785 r
.52734 .42024 m .52524 .42315 L .52855 .42331 L F
.61 .257 .347 r
.52439 .42575 m .52855 .42331 L .52524 .42315 L F
.52439 .42575 m .52706 .42559 L .52855 .42331 L F
.79 .728 .795 r
.52734 .42024 m .52855 .42331 L .53116 .42052 L F
.731 .403 .425 r
.52706 .42559 m .53127 .42655 L .52855 .42331 L F
.152 0 .071 r
.34907 .55111 m .34802 .5529 L .35129 .55022 L F
.633 .486 .665 r
.50539 .49182 m .50808 .48831 L .50522 .4888 L F
.659 .383 .49 r
.44168 .57077 m .4383 .57334 L .43849 .57009 L F
.44168 .57077 m .44115 .57327 L .4383 .57334 L F
.359 .672 .975 r
.39002 .45939 m .39101 .45776 L .38838 .45813 L F
.39002 .45939 m .39291 .45944 L .39101 .45776 L F
.555 .152 .233 r
.33004 .63081 m .3307 .6279 L .32811 .62867 L F
.197 .252 .694 r
.33042 .62527 m .3307 .6279 L .33292 .62743 L F
.058 0 .093 r
.33292 .62743 m .3307 .6279 L .33004 .63081 L F
0 0 0 r
.31581 .5376 m .31649 .53695 L .31741 .5339 L F
.411 .4 .737 r
.31581 .5376 m .31842 .5394 L .31649 .53695 L F
.593 .271 .393 r
.31034 .52821 m .30938 .53059 L .30696 .52975 L F
.487 .644 .926 r
.31228 .52726 m .31034 .52821 L .30788 .52592 L F
0 0 0 r
.31054 .52805 m .31034 .52821 L .31228 .52726 L F
.31054 .52805 m .30938 .53059 L .31034 .52821 L F
0 0 .202 r
.23929 .5911 m .23834 .58997 L .24082 .58962 L F
.696 .752 .895 r
.51699 .46579 m .52042 .46568 L .51856 .46157 L F
.805 .802 .848 r
.51856 .46157 m .52042 .46568 L .52221 .46182 L F
.707 .677 .819 r
.52219 .43034 m .51904 .4294 L .52166 .43117 L F
.425 .36 .681 r
.52219 .43034 m .52439 .42575 L .52174 .42868 L F
.52219 .43034 m .52519 .42959 L .52439 .42575 L F
.146 0 0 r
.52408 .43063 m .52219 .43034 L .52166 .43117 L F
.52408 .43063 m .52519 .42959 L .52219 .43034 L F
.727 .678 .802 r
.35155 .59616 m .35021 .59984 L .34915 .59948 L F
.74 .692 .805 r
.35434 .59558 m .35021 .59984 L .35155 .59616 L F
.772 .902 .933 r
.46526 .43528 m .46331 .43714 L .46164 .4358 L F
.829 .875 .878 r
.45631 .56975 m .45852 .57123 L .45568 .57348 L F
.253 .112 .487 r
.4601 .56656 m .45852 .57123 L .45631 .56975 L F
.437 .089 .275 r
.55435 .38967 m .55733 .38764 L .5551 .38894 L F
.896 .735 .674 r
.35784 .60552 m .36079 .60649 L .35976 .60266 L F
.889 .948 .84 r
.35801 .60839 m .36079 .60649 L .35784 .60552 L F
.431 .453 .782 r
.35976 .60266 m .36079 .60649 L .36283 .60511 L F
0 0 .48 r
.36079 .60649 m .36207 .60752 L .36283 .60511 L F
.36079 .60649 m .36158 .60937 L .36207 .60752 L F
0 0 0 r
.63777 .33478 m .63992 .33424 L .64036 .33361 L F
.63777 .33478 m .63645 .33617 L .63992 .33424 L F
.391 .173 .459 r
.40354 .45562 m .40171 .45792 L .40215 .45489 L F
.492 0 0 r
.40014 .45422 m .40354 .45562 L .40215 .45489 L F
.466 .267 .525 r
.40354 .45562 m .40171 .45792 L .40014 .45422 L F
.40014 .45422 m .40171 .45792 L .40354 .45562 L F
.882 .982 .696 r
.58229 .41787 m .582 .42015 L .58415 .41673 L F
.682 .16 0 r
.58218 .42113 m .58401 .4225 L .582 .42015 L F
.58218 .42113 m .582 .42015 L .58229 .41787 L F
.698 .63 .777 r
.49954 .46293 m .50004 .46586 L .50222 .46213 L F
.635 .549 .74 r
.50004 .46586 m .50367 .46622 L .50222 .46213 L F
.787 .566 .601 r
.33447 .59301 m .3336 .59435 L .33055 .5925 L F
.683 .223 .155 r
.33055 .5925 m .33255 .59498 L .33447 .59301 L F
.607 .075 0 r
.33255 .59498 m .33558 .59556 L .33447 .59301 L F
.125 0 0 r
.33754 .59348 m .33558 .59556 L .34001 .59273 L F
.605 .197 .243 r
.33447 .59301 m .33558 .59556 L .33648 .5946 L F
.33447 .59301 m .33648 .5946 L .33616 .59327 L F
.383 .166 .456 r
.33754 .59348 m .34001 .59273 L .34015 .58963 L F
.244 .38 .803 r
.33558 .59556 m .33707 .59342 L .34001 .59273 L F
.605 .197 .243 r
.33616 .59327 m .33648 .5946 L .33754 .59348 L F
0 0 .247 r
.3369 .59834 m .33697 .5965 L .33768 .59681 L F
.244 .38 .803 r
.33558 .59556 m .33768 .59681 L .33714 .59377 L F
.33699 .59354 m .33714 .59377 L .33707 .59342 L F
.33558 .59556 m .33714 .59377 L .33699 .59354 L F
.804 .597 .622 r
.3386 .59598 m .34054 .59705 L .34189 .59427 L F
.33734 .59664 m .33919 .59688 L .3386 .59598 L F
.33919 .59688 m .34054 .59705 L .3386 .59598 L F
0 0 .247 r
.33697 .5965 m .33707 .59342 L .33768 .59681 L F
.607 .075 0 r
.33697 .5965 m .33768 .59681 L .33691 .59635 L F
0 0 .247 r
.33697 .5965 m .33734 .59664 L .33707 .59342 L F
.33696 .59655 m .33699 .59656 L .33697 .5965 L F
.607 .075 0 r
.33255 .59498 m .33768 .59681 L .33418 .59529 L F
0 0 .247 r
.33699 .59656 m .33734 .59664 L .33697 .5965 L F
.607 .075 0 r
.33418 .59529 m .33697 .5965 L .33558 .59556 L F
.33697 .5965 m .33691 .59635 L .33558 .59556 L F
.518 .632 .903 r
.33699 .59672 m .3369 .59834 L .33768 .59681 L F
0 0 .247 r
.3369 .59834 m .33699 .59672 L .33696 .59655 L F
.518 .632 .903 r
.33699 .59672 m .33768 .59681 L .33699 .59656 L F
0 0 .247 r
.33699 .59672 m .33699 .59666 L .33699 .59665 L F
.33699 .59672 m .33699 .59665 L .33696 .59655 L F
.518 .632 .903 r
.33263 .59612 m .33699 .59672 L .33255 .59498 L F
.33699 .59672 m .33699 .59656 L .33255 .59498 L F
.33263 .59612 m .3369 .59834 L .33699 .59672 L F
0 0 .247 r
.3369 .59834 m .33716 .59734 L .33699 .59666 L F
.33716 .59734 m .33734 .59664 L .33696 .59655 L F
.507 .87 .638 r
.54576 .44517 m .54941 .4425 L .54884 .44502 L F
.247 0 0 r
.54941 .4425 m .55129 .4431 L .54884 .44502 L F
.9 .736 .669 r
.33001 .60034 m .32903 .60255 L .32748 .5987 L F
0 .516 .76 r
.5438 .3927 m .54791 .39351 L .54579 .39317 L F
.829 .875 .878 r
.45631 .56975 m .45568 .57348 L .45463 .56961 L F
.456 .265 .531 r
.51926 .44593 m .52013 .44125 L .51784 .44479 L F
.51926 .44593 m .52206 .44291 L .52013 .44125 L F
.342 .797 .945 r
.52023 .44493 m .51926 .44593 L .51784 .44479 L F
.503 .12 .247 r
.43894 .46306 m .43683 .4644 L .43546 .46433 L F
.779 .997 .854 r
.44041 .46113 m .43683 .4644 L .43894 .46306 L F
.964 .88 .702 r
.43237 .56356 m .42908 .56616 L .42895 .56249 L F
.43237 .56356 m .43052 .56746 L .42908 .56616 L F
0 0 .259 r
.56263 .38613 m .5631 .38283 L .56342 .38428 L F
.93 .645 .479 r
.42077 .45968 m .41803 .46008 L .41868 .4587 L F
.531 .922 .887 r
.42193 .45849 m .42077 .45968 L .4239 .45859 L F
.42193 .45849 m .41803 .46008 L .42077 .45968 L F
.216 0 .056 r
.52424 .49867 m .52348 .50036 L .52096 .50107 L F
.188 0 0 r
.52697 .49815 m .52348 .50036 L .52424 .49867 L F
0 0 .004 r
.42224 .51984 m .4201 .52377 L .42075 .52189 L F
.622 .677 .881 r
.52183 .40812 m .52525 .41026 L .52454 .40668 L F
.38 .585 .923 r
.52525 .41026 m .52678 .40864 L .52454 .40668 L F
.52525 .41026 m .52843 .40948 L .52678 .40864 L F
0 0 0 r
.67855 .34876 m .67639 .35224 L .67786 .35018 L F
.744 .97 .702 r
.68148 .34547 m .67855 .34876 L .67985 .34642 L F
0 0 0 r
.67985 .34642 m .67855 .34876 L .67786 .35018 L F
.769 .259 0 r
.39497 .53284 m .39125 .52954 L .39337 .53061 L F
.982 .82 .605 r
.58636 .43729 m .58863 .43644 L .5873 .43516 L F
.253 .112 .487 r
.4601 .56656 m .45631 .56975 L .45849 .56823 L F
.674 .897 .545 r
.46137 .56445 m .4601 .56656 L .45849 .56823 L F
.302 .433 .827 r
.40706 .59037 m .40872 .59355 L .41063 .59182 L F
.535 .035 0 r
.40872 .59355 m .40942 .59439 L .41063 .59182 L F
.88 .449 .152 r
.41096 .5959 m .40989 .59704 L .40942 .59439 L F
.734 .493 0 r
.40942 .59439 m .40952 .59536 L .40983 .5949 L F
.535 .035 0 r
.40885 .59369 m .41096 .5959 L .40942 .59439 L F
.734 .493 0 r
.40942 .59439 m .40983 .5949 L .41123 .59284 L F
.535 .035 0 r
.40872 .59355 m .40885 .59369 L .40942 .59439 L F
0 0 0 r
.32266 .62187 m .32094 .62296 L .31961 .62447 L F
.38 0 0 r
.59884 .35641 m .60084 .35623 L .59678 .3536 L F
.59884 .35641 m .60101 .35696 L .60084 .35623 L F
.587 .483 .703 r
.49706 .49904 m .49854 .49468 L .49616 .49526 L F
0 0 .097 r
.73129 .31888 m .73122 .31487 L .7307 .31738 L F
.928 .576 .14 r
.7307 .31999 m .73129 .31888 L .7307 .31738 L F
.7307 .31999 m .73197 .32151 L .73129 .31888 L F
.848 .951 .882 r
.55103 .40379 m .54835 .40725 L .54705 .40555 L F
.996 .825 .469 r
.54705 .40555 m .54835 .40725 L .54692 .40893 L F
.942 .599 .343 r
.54692 .40893 m .54835 .40725 L .54848 .40927 L F
.651 .598 .782 r
.55103 .40379 m .55137 .40667 L .54835 .40725 L F
.599 .523 .74 r
.55137 .40667 m .54848 .40927 L .54835 .40725 L F
.951 .875 .467 r
.58479 .41133 m .58366 .41569 L .58415 .41673 L F
.929 .967 .679 r
.58366 .41569 m .58229 .41787 L .58415 .41673 L F
0 0 0 r
.65654 .37936 m .65774 .37812 L .65408 .38034 L F
.65654 .37936 m .65408 .38034 L .65353 .38022 L F
.739 .726 .839 r
.28567 .65184 m .28996 .65234 L .28834 .65057 L F
.734 .601 .708 r
.28996 .65234 m .29147 .64982 L .28834 .65057 L F
.781 .75 .824 r
.52734 .42024 m .53116 .42052 L .52952 .41866 L F
.707 .919 .966 r
.5491 .4584 m .54646 .45973 L .54752 .45723 L F
.398 .198 .49 r
.23712 .61881 m .23746 .61582 L .23932 .61794 L F
.23712 .61881 m .23746 .61582 L .23932 .61794 L F
.381 .673 .974 r
.42587 .45284 m .42252 .45152 L .42409 .45082 L F
.817 .942 .908 r
.42691 .44995 m .42587 .45284 L .42409 .45082 L F
.42691 .44995 m .42876 .45065 L .42587 .45284 L F
.003 .578 .744 r
.62526 .41006 m .62734 .41018 L .62565 .41004 L F
.763 .378 .326 r
.6298 .40958 m .62565 .41004 L .62734 .41018 L F
.246 .104 .481 r
.62827 .41327 m .6298 .40958 L .62734 .41018 L F
.763 .378 .326 r
.6298 .40958 m .62679 .41106 L .62565 .41004 L F
0 .044 .612 r
.62632 .41001 m .62565 .41004 L .62679 .41106 L F
.62509 .40723 m .62565 .41004 L .62632 .41001 L F
.003 .578 .744 r
.623 .40992 m .62526 .41006 L .62565 .41004 L F
.262 .533 .918 r
.31569 .65525 m .31794 .658 L .31862 .65652 L F
.423 .725 .988 r
.31794 .658 m .32077 .65804 L .31862 .65652 L F
0 0 0 r
.5414 .48785 m .54461 .48494 L .54348 .48651 L F
.894 .53 .06 r
.37993 .54291 m .37977 .54159 L .37651 .53992 L F
.37993 .54291 m .38021 .54341 L .37977 .54159 L F
.723 .989 .851 r
.5478 .46602 m .5511 .46359 L .54894 .46402 L F
.839 .998 .824 r
.54894 .46402 m .5511 .46359 L .55229 .4617 L F
0 0 0 r
.3547 .64735 m .35877 .64467 L .35774 .64439 L F
0 0 .216 r
.35877 .64467 m .36013 .6409 L .35774 .64439 L F
.003 0 0 r
.60356 .34487 m .6075 .34472 L .60432 .34536 L F
.097 0 0 r
.6075 .34472 m .60625 .3448 L .6071 .3448 L F
.147 .686 .699 r
.60614 .34501 m .6075 .34472 L .60851 .3445 L F
.097 0 0 r
.6075 .34472 m .6071 .3448 L .61026 .34481 L F
.147 .686 .699 r
.60851 .3445 m .6075 .34472 L .60886 .34443 L F
.60614 .34501 m .60432 .34536 L .6075 .34472 L F
.812 .911 .511 r
.34162 .62134 m .34276 .61876 L .34198 .62212 L F
.255 .479 .882 r
.35507 .55705 m .3537 .55852 L .35219 .55601 L F
.526 .312 .532 r
.3537 .55852 m .35638 .55956 L .35726 .55745 L F
.255 .479 .882 r
.35507 .55705 m .35638 .55956 L .3537 .55852 L F
.23 0 0 r
.67934 .32235 m .67545 .32366 L .67538 .32295 L F
.67934 .32235 m .67822 .32345 L .67545 .32366 L F
.6 .065 0 r
.67934 .32235 m .68217 .32411 L .67822 .32345 L F
.773 .271 .008 r
.61863 .38161 m .62131 .38302 L .61905 .38175 L F
.457 .691 .967 r
.62131 .38302 m .62414 .38316 L .6231 .3814 L F
.538 .411 .654 r
.50389 .4684 m .50636 .46535 L .50367 .46622 L F
.50389 .4684 m .50723 .46792 L .50636 .46535 L F
.669 .936 .655 r
.31961 .62447 m .31819 .62623 L .3168 .62743 L F
0 0 0 r
.67639 .35224 m .67692 .35209 L .67786 .35018 L F
.344 .074 .352 r
.32824 .52381 m .32554 .52451 L .32944 .52453 L F
.934 .949 .772 r
.3305 .52011 m .32944 .52453 L .32863 .52056 L F
.3305 .52011 m .32824 .52381 L .32944 .52453 L F
.798 .975 .683 r
.5326 .46977 m .53175 .47209 L .53445 .46872 L F
.677 .508 .65 r
.53175 .47209 m .53691 .47333 L .53445 .46872 L F
.902 .874 .439 r
.53417 .46772 m .53445 .46872 L .53494 .46628 L F
.885 .972 .662 r
.5326 .46977 m .53445 .46872 L .53417 .46772 L F
.824 .684 .709 r
.53691 .47333 m .5376 .46851 L .53445 .46872 L F
0 0 0 r
.49197 .54019 m .49077 .54218 L .48948 .54381 L F
.49077 .54218 m .48885 .54588 L .48948 .54381 L F
.836 .705 .719 r
.41155 .4846 m .41303 .48841 L .41489 .48471 L F
.822 .526 0 r
.71207 .29234 m .71283 .295 L .71367 .29302 L F
.911 .537 .303 r
.38487 .55857 m .38653 .55745 L .38447 .55646 L F
.38487 .55857 m .3871 .5597 L .38653 .55745 L F
.588 .436 .643 r
.345 .5673 m .34495 .56861 L .34197 .5672 L F
.345 .5673 m .34495 .56861 L .34197 .5672 L F
.803 .892 .908 r
.54386 .46691 m .5478 .46602 L .54759 .4658 L F
.723 .989 .851 r
.5478 .46602 m .54894 .46402 L .54759 .4658 L F
.329 .623 .957 r
.33882 .52141 m .33972 .51971 L .33728 .51947 L F
.524 .849 .998 r
.34151 .52059 m .33972 .51971 L .33882 .52141 L F
.669 .691 .862 r
.4126 .45575 m .41634 .45705 L .41542 .45462 L F
.467 0 0 r
.41634 .45705 m .41868 .4587 L .41691 .45768 L F
.41634 .45705 m .41691 .45768 L .41542 .45462 L F
0 0 .382 r
.41542 .45462 m .41634 .45705 L .41691 .45768 L F
.738 .226 0 r
.43106 .58582 m .4327 .58758 L .43424 .5868 L F
.846 .806 .812 r
.43321 .58732 m .43665 .58751 L .43424 .5868 L F
.4327 .58758 m .43438 .58755 L .43321 .58732 L F
.43438 .58755 m .43665 .58751 L .43321 .58732 L F
.43361 .58757 m .4368 .58756 L .43665 .58751 L F
.867 .773 .756 r
.43438 .58755 m .43452 .58798 L .4327 .58758 L F
.846 .806 .812 r
.4327 .58758 m .43382 .58758 L .43361 .58757 L F
.43382 .58758 m .4368 .58756 L .43361 .58757 L F
.43448 .58757 m .43452 .58798 L .4368 .58756 L F
.4327 .58758 m .43452 .58798 L .43448 .58757 L F
.589 .619 .849 r
.43597 .58498 m .4347 .58761 L .43441 .58687 L F
.43414 .58396 m .43441 .58687 L .43308 .58337 L F
.43597 .58498 m .43441 .58687 L .43414 .58396 L F
.493 .536 .829 r
.43859 .58456 m .43494 .58763 L .43597 .58498 L F
.43494 .58763 m .43452 .58798 L .4347 .58761 L F
.43494 .58763 m .4347 .58761 L .43597 .58498 L F
.589 .619 .849 r
.4347 .58761 m .43452 .58798 L .43438 .58755 L F
.4347 .58761 m .43438 .58755 L .43308 .58337 L F
.867 .773 .756 r
.43308 .58337 m .43438 .58755 L .4327 .58758 L F
0 0 .101 r
.50217 .52136 m .50136 .52344 L .4997 .52479 L F
0 0 .141 r
.50136 .52344 m .49894 .52697 L .4997 .52479 L F
.719 .548 .657 r
.34207 .53769 m .34429 .53593 L .34352 .53649 L F
.48 .874 .697 r
.34352 .53649 m .34557 .53491 L .34705 .53419 L F
.719 .548 .657 r
.34429 .53593 m .34557 .53491 L .34352 .53649 L F
.2 .704 .906 r
.34325 .53669 m .34352 .53649 L .34622 .53705 L F
.34072 .53639 m .34352 .53649 L .34325 .53669 L F
.372 .502 .86 r
.34705 .53419 m .34622 .53705 L .34352 .53649 L F
.34705 .53419 m .348 .53676 L .34622 .53705 L F
.299 0 .193 r
.28538 .60316 m .28767 .60279 L .28442 .60509 L F
.377 .12 .392 r
.47791 .4622 m .47827 .45939 L .47538 .46277 L F
.396 .135 .397 r
.48076 .45859 m .47827 .45939 L .47791 .4622 L F
.052 0 0 r
.64215 .34025 m .64149 .34096 L .63929 .34119 L F
.613 .258 .344 r
.64149 .34096 m .6371 .34261 L .63929 .34119 L F
.591 .796 .978 r
.47004 .45531 m .4741 .456 L .47255 .45447 L F
.684 .845 .96 r
.4741 .456 m .47512 .45327 L .47255 .45447 L F
.4741 .456 m .47672 .45475 L .47512 .45327 L F
.866 .911 .859 r
.36503 .63405 m .36776 .6342 L .36952 .63187 L F
.565 .436 .663 r
.53204 .39653 m .53521 .39957 L .536 .39718 L F
.648 .434 .58 r
.53521 .39957 m .5387 .39656 L .536 .39718 L F
.88 .991 .748 r
.56057 .41261 m .56024 .41443 L .56304 .41043 L F
.087 0 0 r
.55899 .41532 m .56024 .41443 L .56057 .41261 L F
.55899 .41532 m .56317 .41347 L .56024 .41443 L F
.685 .519 .656 r
.40665 .49134 m .41038 .49194 L .41025 .48888 L F
.656 .579 .757 r
.40964 .48659 m .41025 .48888 L .41303 .48841 L F
.584 .44 .652 r
.41025 .48888 m .41289 .49051 L .41303 .48841 L F
.41025 .48888 m .41038 .49194 L .41289 .49051 L F
.642 .537 .72 r
.38511 .48519 m .38736 .48164 L .3841 .4825 L F
.687 .907 .973 r
.48454 .46084 m .48915 .46029 L .48594 .45983 L F
.758 .785 .875 r
.48915 .46029 m .48974 .45764 L .48594 .45983 L F
.48915 .46029 m .49162 .45889 L .48974 .45764 L F
.557 .779 .982 r
.45144 .4623 m .45143 .45946 L .45055 .45963 L F
.176 .548 .929 r
.62669 .39873 m .62989 .39888 L .62749 .39599 L F
.555 .365 .578 r
.63225 .39861 m .63392 .39919 L .63244 .39984 L F
.692 .801 .933 r
.63137 .40031 m .6319 .40083 L .63231 .4005 L F
.63177 .40014 m .63231 .4005 L .63392 .39919 L F
.63137 .40031 m .63231 .4005 L .63177 .40014 L F
.555 .365 .578 r
.63225 .39861 m .63177 .40014 L .62989 .39888 L F
.176 .548 .929 r
.62814 .39931 m .6319 .40083 L .63137 .40031 L F
.62814 .39931 m .63137 .40031 L .62989 .39888 L F
.555 .365 .578 r
.63177 .40014 m .63107 .40233 L .62989 .39888 L F
.63225 .39861 m .63257 .40069 L .63168 .40041 L F
.692 .801 .933 r
.62989 .39888 m .63137 .40031 L .63392 .39919 L F
.555 .365 .578 r
.63244 .39984 m .63392 .39919 L .63257 .40069 L F
.63168 .40041 m .63257 .40069 L .63107 .40233 L F
.176 .548 .929 r
.62669 .39873 m .62814 .39931 L .62989 .39888 L F
.959 .682 .468 r
.32554 .52451 m .32719 .52811 L .3251 .52669 L F
.985 .727 .451 r
.33803 .51279 m .33997 .51161 L .33619 .50966 L F
.33803 .51279 m .33959 .51401 L .33997 .51161 L F
.1 0 .295 r
.33997 .51161 m .33959 .51401 L .34129 .5105 L F
.109 .653 .839 r
.33498 .55543 m .33916 .55573 L .3364 .5562 L F
.986 .728 .446 r
.38935 .5783 m .391 .57668 L .38943 .57559 L F
.38935 .5783 m .3909 .57945 L .391 .57668 L F
.908 .513 .241 r
.58458 .42466 m .58587 .42342 L .58401 .4225 L F
.863 .434 .191 r
.58656 .42519 m .58587 .42342 L .58458 .42466 L F
.223 0 0 r
.26438 .52176 m .26199 .52313 L .25947 .52331 L F
.58 .82 .99 r
.26216 .52024 m .26438 .52176 L .26666 .5209 L F
.752 .711 .813 r
.53743 .41472 m .54049 .41694 L .54354 .41429 L F
.481 .762 .993 r
.45021 .45532 m .45117 .45333 L .44849 .45398 L F
.45021 .45532 m .45292 .45483 L .45117 .45333 L F
.298 0 .133 r
.31471 .62851 m .31139 .63143 L .31291 .6306 L F
.556 .926 .932 r
.3168 .62743 m .31471 .62851 L .31551 .62721 L F
.624 .86 .495 r
.31551 .62721 m .31471 .62851 L .31291 .6306 L F
.44 .094 .281 r
.28172 .58621 m .28053 .58896 L .27805 .58926 L F
.464 .235 .481 r
.28467 .58297 m .2845 .58566 L .28172 .58621 L F
.472 .126 .296 r
.28384 .58837 m .28172 .58621 L .2845 .58566 L F
.28384 .58837 m .28053 .58896 L .28172 .58621 L F
.601 .349 .506 r
.28706 .58537 m .28467 .58297 L .2876 .58303 L F
.28706 .58537 m .2845 .58566 L .28467 .58297 L F
.235 0 0 r
.67538 .32295 m .67545 .32366 L .67292 .32388 L F
.674 .58 .742 r
.41674 .51818 m .41397 .51981 L .41273 .51673 L F
.544 .909 .959 r
.42922 .44918 m .42876 .45065 L .42691 .44995 L F
.42922 .44918 m .43128 .4496 L .42876 .45065 L F
.665 .699 .871 r
.42268 .49038 m .42666 .48906 L .42526 .48735 L F
0 0 .444 r
.57843 .38901 m .5789 .39075 L .57735 .38687 L F
.955 .668 .229 r
.57843 .38901 m .57954 .39268 L .5789 .39075 L F
.75 .638 .737 r
.55479 .4066 m .55167 .41122 L .55137 .40667 L F
.439 .758 .995 r
.55087 .40981 m .55167 .41122 L .55523 .41075 L F
.574 .378 .578 r
.42256 .48513 m .42477 .48477 L .42509 .48215 L F
.433 .871 .898 r
.42584 .45774 m .42193 .45849 L .4239 .45859 L F
.53 .673 .928 r
.4239 .45859 m .42735 .45976 L .42584 .45774 L F
.927 .915 .786 r
.51457 .46951 m .51699 .46579 L .5157 .46459 L F
.696 .752 .895 r
.51699 .46579 m .51856 .46157 L .5157 .46459 L F
.578 .943 .88 r
.68838 .37243 m .69287 .37078 L .69256 .37035 L F
.685 .975 .795 r
.69287 .37078 m .6945 .36862 L .69256 .37035 L F
.69287 .37078 m .69627 .36808 L .6945 .36862 L F
.749 .652 .754 r
.55433 .40337 m .55479 .4066 L .55137 .40667 L F
.714 .628 .76 r
.55733 .40318 m .55479 .4066 L .55433 .40337 L F
.915 .658 .535 r
.37451 .5339 m .37376 .53687 L .37631 .53754 L F
.902 .576 .418 r
.37376 .53687 m .37651 .53992 L .37631 .53754 L F
0 0 0 r
.34915 .59948 m .3475 .60204 L .34597 .60262 L F
.134 0 0 r
.35019 .60078 m .3475 .60204 L .34915 .59948 L F
.59 .823 .437 r
.25175 .52843 m .25216 .52798 L .25407 .52648 L F
.25175 .52843 m .25098 .52952 L .25216 .52798 L F
0 0 .319 r
.71321 .27678 m .71547 .27112 L .71644 .27236 L F
.134 .556 .924 r
.71547 .27112 m .71842 .2729 L .71644 .27236 L F
.559 .264 .423 r
.28384 .64817 m .28659 .64715 L .2845 .64546 L F
.515 .277 .492 r
.28659 .64715 m .28715 .64476 L .2845 .64546 L F
.37 .834 .896 r
.44304 .44505 m .44642 .4446 L .44467 .44507 L F
0 0 0 r
.22921 .5503 m .2276 .55402 L .22847 .55264 L F
0 0 .397 r
.2276 .55402 m .22858 .55576 L .22847 .55264 L F
.024 0 .374 r
.2276 .55402 m .22736 .55706 L .22858 .55576 L F
.081 0 0 r
.65208 .33587 m .65111 .33792 L .64864 .33817 L F
0 0 0 r
.65322 .33623 m .65208 .33587 L .65399 .33409 L F
.65322 .33623 m .65111 .33792 L .65208 .33587 L F
.987 .839 .609 r
.39003 .58481 m .3922 .58305 L .3911 .58197 L F
.39003 .58481 m .39139 .58668 L .3922 .58305 L F
.673 .946 .684 r
.43391 .5782 m .43588 .57704 L .43406 .5754 L F
.43391 .5782 m .43301 .57979 L .43588 .57704 L F
.852 .882 .861 r
.4383 .57334 m .43588 .57704 L .43406 .5754 L F
.658 .59 .767 r
.4383 .57334 m .43944 .57722 L .43588 .57704 L F
0 0 .366 r
.43588 .57704 m .43664 .57747 L .43406 .5754 L F
.43588 .57704 m .4366 .57906 L .43664 .57747 L F
.441 .402 .719 r
.39547 .48816 m .39543 .49211 L .39365 .49197 L F
.87 .712 .683 r
.39509 .49267 m .39365 .49197 L .39543 .49211 L F
.394 .144 .413 r
.23958 .55875 m .23737 .55957 L .23761 .55715 L F
.894 .653 .566 r
.37988 .54614 m .38204 .54942 L .38176 .54736 L F
.595 .51 .729 r
.49706 .49904 m .4975 .50155 L .49976 .49824 L F
.51 .399 .664 r
.4975 .50155 m .50017 .50108 L .49976 .49824 L F
.116 0 .214 r
.49773 .50424 m .50017 .50108 L .4975 .50155 L F
.525 .825 .497 r
.65947 .37628 m .65774 .37812 L .65654 .37936 L F
.957 .615 .257 r
.39928 .541 m .3978 .54006 L .39695 .53644 L F
.937 .659 .191 r
.39928 .541 m .39851 .54207 L .3978 .54006 L F
.39928 .541 m .39952 .54375 L .39851 .54207 L F
.488 .802 1 r
.56441 .43322 m .56677 .42966 L .56556 .42975 L F
.56441 .43322 m .567 .43301 L .56707 .42922 L F
.833 .772 .794 r
.56156 .42917 m .56441 .43322 L .56556 .42975 L F
.56225 .42999 m .56556 .42975 L .56485 .43312 L F
.56156 .42917 m .56556 .42975 L .56225 .42999 L F
.488 .802 1 r
.56677 .42966 m .56707 .42922 L .56556 .42975 L F
.569 .107 .117 r
.56707 .42922 m .56992 .42962 L .56556 .42975 L F
.95 .834 .695 r
.40543 .57406 m .40272 .57563 L .40452 .57162 L F
.40543 .57406 m .40462 .57639 L .40272 .57563 L F
.899 .808 .331 r
.32331 .57335 m .32257 .57362 L .3234 .57186 L F
.32331 .57335 m .32286 .5759 L .32257 .57362 L F
.825 .891 .468 r
.32331 .57335 m .32257 .57362 L .3234 .57186 L F
.75 .512 .571 r
.31394 .58237 m .31762 .58327 L .31777 .57967 L F
.46 .244 .497 r
.31762 .58327 m .32005 .57933 L .31777 .57967 L F
.776 .688 .766 r
.52221 .46182 m .52365 .46585 L .52625 .46235 L F
.635 .261 .317 r
.52313 .46751 m .52597 .46815 L .52365 .46585 L F
.898 .931 .554 r
.33696 .57247 m .33698 .57367 L .33684 .57193 L F
.591 .7 .919 r
.42584 .45774 m .42735 .45976 L .4297 .45889 L F
.535 .591 .857 r
.42735 .45976 m .43201 .4619 L .4297 .45889 L F
.275 .775 .756 r
.23283 .53626 m .2347 .53554 L .23621 .5352 L F
.39 .85 .856 r
.2347 .53554 m .23811 .53461 L .23621 .5352 L F
.2347 .53554 m .23601 .53485 L .23811 .53461 L F
.187 .057 .46 r
.23433 .53839 m .2359 .53508 L .2347 .53554 L F
.2359 .53508 m .23601 .53485 L .2347 .53554 L F
.275 .775 .756 r
.23273 .53629 m .2347 .53554 L .23283 .53626 L F
.073 0 .324 r
.23273 .53629 m .23433 .53839 L .2347 .53554 L F
.23273 .53629 m .23136 .54123 L .23433 .53839 L F
.912 .632 .499 r
.36874 .52419 m .36877 .52699 L .37103 .52763 L F
.895 .551 .386 r
.36877 .52699 m .36908 .52934 L .37103 .52763 L F
.86 .49 .347 r
.37103 .52763 m .36908 .52934 L .37174 .5299 L F
.379 .45 .808 r
.59955 .35128 m .60084 .35623 L .60257 .35202 L F
.295 .252 .639 r
.60101 .35696 m .60257 .35202 L .60084 .35623 L F
.557 .13 .185 r
.64864 .33817 m .64822 .34046 L .64498 .34 L F
.123 0 .09 r
.65037 .33918 m .64864 .33817 L .65111 .33792 L F
.65037 .33918 m .64822 .34046 L .64864 .33817 L F
.658 .963 .927 r
.56306 .47326 m .5607 .47324 L .55946 .47508 L F
.67 .949 .699 r
.55946 .47508 m .5607 .47324 L .55765 .47614 L F
0 0 .328 r
.22864 .54399 m .22939 .54379 L .22968 .54043 L F
0 .041 .549 r
.22864 .54399 m .23012 .54607 L .22939 .54379 L F
.136 .078 .522 r
.22884 .54619 m .23012 .54607 L .22864 .54399 L F
.737 .543 .631 r
.52965 .39728 m .52957 .39997 L .53204 .39653 L F
.732 .536 .627 r
.52957 .39997 m .53301 .4001 L .53204 .39653 L F
.565 .436 .663 r
.53204 .39653 m .53301 .4001 L .53521 .39957 L F
0 0 .049 r
.72655 .31095 m .72464 .31246 L .72717 .30842 L F
.403 .17 .442 r
.72994 .30568 m .72998 .30792 L .72717 .30842 L F
.713 .507 .609 r
.72998 .30792 m .72655 .31095 L .72717 .30842 L F
.396 .653 .961 r
.42591 .53588 m .42714 .53811 L .42489 .53669 L F
.888 .47 .196 r
.42591 .53588 m .42932 .53954 L .42714 .53811 L F
.352 .171 .49 r
.23737 .55957 m .23508 .56328 L .23534 .56033 L F
0 0 0 r
.57342 .46205 m .57601 .45898 L .5751 .46051 L F
0 0 .22 r
.57601 .45898 m .57835 .45509 L .57746 .45789 L F
0 0 0 r
.5751 .46051 m .57601 .45898 L .57746 .45789 L F
.739 .232 0 r
.58873 .38916 m .58615 .3867 L .58756 .38823 L F
.697 .884 .967 r
.50427 .40996 m .502 .4114 L .50009 .40991 L F
.986 .828 .439 r
.70134 .35123 m .70106 .34745 L .70053 .35009 L F
.939 .888 .482 r
.70026 .35225 m .70134 .35123 L .70053 .35009 L F
.70026 .35225 m .70035 .35506 L .70134 .35123 L F
.72 .203 0 r
.2991 .65379 m .29495 .65124 L .29652 .65437 L F
.822 .738 .772 r
.60018 .38765 m .60146 .38973 L .60073 .3864 L F
.84 .586 .041 r
.60115 .38749 m .60126 .38882 L .60134 .38798 L F
.60073 .3864 m .60105 .38784 L .60115 .38749 L F
.60105 .38784 m .60126 .38882 L .60115 .38749 L F
.60126 .38882 m .60146 .38973 L .60142 .38916 L F
.60126 .38882 m .60142 .38916 L .60134 .38798 L F
.568 .642 .883 r
.60421 .38906 m .60146 .38973 L .60018 .38765 L F
.8 .495 .473 r
.60519 .39284 m .60517 .39082 L .60146 .38973 L F
.60519 .39284 m .60146 .38973 L .60421 .38906 L F
.568 .642 .883 r
.60421 .38906 m .60101 .38794 L .60319 .3896 L F
.60101 .38794 m .60018 .38765 L .60095 .38815 L F
.60101 .38794 m .60095 .38815 L .60319 .3896 L F
.886 .974 .831 r
.60073 .3864 m .60429 .38391 L .60219 .38487 L F
0 0 .535 r
.60117 .38532 m .60018 .38765 L .60073 .3864 L F
.60117 .38532 m .60073 .3864 L .6015 .3856 L F
.60117 .38532 m .6015 .3856 L .60219 .38487 L F
.814 .592 .035 r
.60076 .38472 m .60083 .38504 L .60117 .38532 L F
0 0 .535 r
.60117 .38532 m .60157 .3881 L .60018 .38765 L F
0 .222 .725 r
.60183 .38818 m .60319 .3896 L .6018 .3887 L F
.6016 .38817 m .6018 .3887 L .60095 .38815 L F
.60183 .38818 m .6018 .3887 L .6016 .38817 L F
.814 .592 .035 r
.60083 .38504 m .60142 .38769 L .60117 .38532 L F
0 .222 .725 r
.6008 .38782 m .60095 .38815 L .60018 .38765 L F
.6022 .38819 m .60095 .38815 L .6008 .38782 L F
0 0 .535 r
.60157 .3881 m .60169 .38888 L .60018 .38765 L F
.814 .592 .035 r
.60154 .38802 m .60169 .38888 L .60157 .3881 L F
0 .222 .725 r
.6022 .38819 m .60229 .38833 L .60183 .38818 L F
.6022 .38819 m .60154 .38802 L .60169 .38888 L F
.60154 .38802 m .60018 .38765 L .60169 .38888 L F
.814 .592 .035 r
.60142 .38769 m .60169 .38888 L .60154 .38802 L F
.60142 .38769 m .60157 .3881 L .60117 .38532 L F
0 .222 .725 r
.60229 .38833 m .60319 .3896 L .60183 .38818 L F
.798 .807 .859 r
.23181 .60193 m .23422 .60276 L .23124 .59992 L F
.36 .65 .966 r
.23497 .60107 m .23422 .60276 L .23124 .59992 L F
0 0 .53 r
.23552 .60378 m .23422 .60276 L .23497 .60107 L F
.541 .916 .761 r
.47496 .42975 m .47097 .43191 L .47368 .42877 L F
.818 .929 .907 r
.47669 .42588 m .47496 .42975 L .47368 .42877 L F
.47669 .42588 m .47794 .4271 L .47496 .42975 L F
.485 .287 .535 r
.45458 .49396 m .45423 .497 L .45483 .49639 L F
.515 .061 .113 r
.30077 .57963 m .30173 .58198 L .29916 .58227 L F
.30077 .57963 m .30357 .57985 L .30173 .58198 L F
.012 0 .127 r
.50393 .52005 m .50136 .52344 L .50217 .52136 L F
.751 .237 0 r
.35131 .50524 m .35225 .50658 L .35387 .50746 L F
.883 .478 .247 r
.35225 .50658 m .35569 .51041 L .35387 .50746 L F
.602 .69 .905 r
.59675 .36497 m .59304 .364 L .59632 .36289 L F
.301 .421 .817 r
.59796 .36286 m .59675 .36497 L .59632 .36289 L F
.865 .753 .242 r
.59796 .36286 m .59792 .36764 L .59675 .36497 L F
.483 .888 .94 r
.61432 .35116 m .61316 .35094 L .61058 .35184 L F
.877 .942 .576 r
.50927 .42645 m .51106 .42335 L .50965 .42461 L F
.818 .999 .792 r
.51106 .42335 m .51149 .42106 L .50959 .42204 L F
.51106 .42335 m .51377 .42044 L .51149 .42106 L F
.987 .718 .408 r
.50965 .42461 m .51106 .42335 L .50959 .42204 L F
0 0 0 r
.4435 .45733 m .44149 .45958 L .4426 .45834 L F
.496 .29 .53 r
.44604 .4552 m .4435 .45733 L .4426 .45834 L F
.994 .752 .44 r
.23511 .61031 m .23605 .60924 L .23431 .60729 L F
.23511 .61031 m .23578 .612 L .23605 .60924 L F
.502 .097 .204 r
.26882 .58961 m .26757 .59215 L .26445 .59205 L F
0 0 0 r
.27023 .59034 m .26882 .58961 L .27138 .58969 L F
.27013 .5904 m .26996 .59029 L .27023 .59034 L F
.26996 .59029 m .26882 .58961 L .27023 .59034 L F
.668 .162 .034 r
.27138 .58969 m .27352 .59154 L .2694 .59082 L F
.354 .309 .669 r
.26933 .58486 m .27038 .59037 L .27186 .58743 L F
.27038 .59037 m .27038 .59039 L .27039 .59038 L F
.27038 .59037 m .27039 .59038 L .27186 .58743 L F
.743 .574 .665 r
.26581 .58805 m .27034 .59038 L .26933 .58486 L F
.27034 .59038 m .27038 .59039 L .27038 .59037 L F
.27034 .59038 m .27038 .59037 L .26933 .58486 L F
0 0 0 r
.2694 .59082 m .26924 .59049 L .27013 .5904 L F
.26924 .59049 m .26882 .58961 L .27013 .5904 L F
.2694 .59082 m .26757 .59215 L .26882 .58961 L F
.607 .694 .905 r
.48078 .45587 m .48199 .4519 L .47927 .45402 L F
.48078 .45587 m .48334 .45509 L .48199 .4519 L F
.478 .248 .486 r
.48336 .45782 m .48078 .45587 L .48076 .45859 L F
.48336 .45782 m .48334 .45509 L .48078 .45587 L F
.864 .636 .591 r
.43849 .57009 m .43674 .57197 L .43929 .5687 L F
.43849 .57009 m .4383 .57334 L .43674 .57197 L F
.79 .682 .745 r
.5997 .44207 m .60091 .44611 L .59687 .4455 L F
.679 .197 .1 r
.59687 .4455 m .60091 .44611 L .59952 .44769 L F
.701 .632 .777 r
.60328 .44345 m .60091 .44611 L .5997 .44207 L F
.705 .23 .119 r
.59952 .44769 m .60091 .44611 L .60119 .44758 L F
.66 .568 .741 r
.60328 .44345 m .60428 .44581 L .60091 .44611 L F
.805 .561 .57 r
.60428 .44581 m .60119 .44758 L .60091 .44611 L F
.732 .621 .735 r
.51186 .47267 m .51473 .47175 L .51457 .46951 L F
.556 .597 .849 r
.51186 .47267 m .51564 .47543 L .51473 .47175 L F
.65 .166 .09 r
.51782 .47124 m .51457 .46951 L .51473 .47175 L F
.555 .507 .757 r
.51564 .47543 m .51782 .47124 L .51473 .47175 L F
.786 .693 .761 r
.33916 .55573 m .34321 .55704 L .34165 .55322 L F
.786 .362 .242 r
.33916 .55573 m .34151 .55867 L .34321 .55704 L F
.629 .614 .817 r
.34165 .55322 m .34321 .55704 L .34516 .55556 L F
0 0 0 r
.34321 .55704 m .34284 .55827 L .34516 .55556 L F
.34321 .55704 m .34151 .55867 L .34284 .55827 L F
.783 .671 .74 r
.43208 .58305 m .42642 .58285 L .42894 .57922 L F
.451 .789 .998 r
.56317 .41347 m .56057 .41261 L .56304 .41043 L F
0 .311 .749 r
.58009 .38091 m .58168 .38125 L .57909 .37945 L F
.58009 .38091 m .58271 .38226 L .58168 .38125 L F
0 .271 .673 r
.58505 .38363 m .58359 .38272 L .58009 .38091 L F
0 .22 .716 r
.57909 .37945 m .58168 .38125 L .58063 .37988 L F
.918 .613 .133 r
.58168 .38125 m .58124 .38285 L .58072 .3803 L F
.58168 .38125 m .58072 .3803 L .58063 .37988 L F
0 .311 .749 r
.58271 .38226 m .58359 .38272 L .58168 .38125 L F
.27 .362 .773 r
.42256 .48513 m .42526 .48735 L .42477 .48477 L F
.952 .941 .734 r
.35716 .52769 m .35829 .5235 L .36008 .52735 L F
.35716 .52769 m .35614 .5266 L .35829 .5235 L F
.951 .9 .514 r
.35716 .52769 m .35589 .52911 L .35614 .5266 L F
.35716 .52769 m .35612 .53094 L .35589 .52911 L F
.815 .629 .65 r
.30405 .57256 m .30901 .57318 L .30865 .57025 L F
.545 .516 .775 r
.30901 .57318 m .31082 .57047 L .30865 .57025 L F
.30901 .57318 m .31082 .57047 L .30865 .57025 L F
.634 .767 .944 r
.61911 .40909 m .62026 .41112 L .623 .40992 L F
.599 .617 .841 r
.72179 .29941 m .72442 .30014 L .7245 .2981 L F
.578 .222 .329 r
.72774 .31421 m .72843 .3125 L .72821 .3125 L F
.72774 .31421 m .72821 .3125 L .72464 .31246 L F
.385 .198 .501 r
.72774 .31421 m .72539 .31771 L .72767 .31674 L F
.72539 .31771 m .72523 .31796 L .72767 .31674 L F
.575 .773 .973 r
.72767 .31674 m .73053 .31594 L .72997 .31576 L F
.991 .734 .409 r
.72733 .31568 m .72774 .31421 L .72767 .31674 L F
.575 .773 .973 r
.72767 .31674 m .72997 .31576 L .72746 .31494 L F
0 .316 .778 r
.72637 .31274 m .72774 .31421 L .72464 .31246 L F
.579 .029 0 r
.72356 .31344 m .72774 .31421 L .72464 .31246 L F
.77 .696 .78 r
.72356 .31344 m .72523 .31796 L .72774 .31421 L F
.778 .699 .777 r
.72091 .31686 m .72523 .31796 L .72356 .31344 L F
.577 .332 .508 r
.72638 .31486 m .724 .31623 L .7229 .31462 L F
.991 .734 .409 r
.72648 .31308 m .72774 .31421 L .72733 .31568 L F
.72637 .31274 m .7265 .31287 L .72648 .31308 L F
0 0 .5 r
.72637 .31274 m .72767 .31674 L .72746 .31494 L F
.577 .332 .508 r
.72746 .31494 m .72635 .31536 L .72638 .31486 L F
.72635 .31536 m .724 .31623 L .72638 .31486 L F
.991 .734 .409 r
.7265 .31287 m .72774 .31421 L .72648 .31308 L F
0 .316 .778 r
.72637 .31274 m .72464 .31246 L .72655 .31095 L F
.648 .257 .29 r
.40326 .48363 m .40722 .48431 L .40521 .48094 L F
.557 .507 .755 r
.41155 .4846 m .40964 .48659 L .40859 .48123 L F
.41155 .4846 m .40859 .48123 L .40885 .48165 L F
0 0 0 r
.41039 .47864 m .40885 .48165 L .40859 .48123 L F
.486 .213 .425 r
.40521 .48094 m .40885 .48165 L .41039 .47864 L F
.569 .233 .359 r
.40521 .48094 m .41002 .48362 L .40885 .48165 L F
.40521 .48094 m .40722 .48431 L .41002 .48362 L F
.8 .999 .846 r
.36013 .6409 m .36416 .63838 L .36287 .63777 L F
.928 .927 .557 r
.36416 .63838 m .36503 .63405 L .36287 .63777 L F
.828 .749 .776 r
.4274 .55652 m .42857 .56052 L .42545 .55913 L F
.895 .486 .216 r
.42857 .56052 m .42895 .56249 L .42716 .5617 L F
.398 .786 .989 r
.30234 .65531 m .30702 .65614 L .30514 .6542 L F
.315 .693 .979 r
.30847 .65568 m .30702 .65614 L .30916 .65599 L F
.30514 .6542 m .30667 .65578 L .30847 .65568 L F
.30667 .65578 m .30702 .65614 L .30847 .65568 L F
.30514 .6542 m .30916 .65599 L .30766 .65609 L F
.292 .791 .816 r
.30766 .65609 m .30916 .65599 L .31155 .65533 L F
.30766 .65609 m .31023 .65559 L .31022 .65585 L F
.31023 .65559 m .31155 .65533 L .31099 .65554 L F
.31023 .65559 m .31099 .65554 L .31022 .65585 L F
.587 .483 .703 r
.49706 .49904 m .49976 .49824 L .49854 .49468 L F
.155 .135 .582 r
.34812 .52006 m .34867 .52052 L .34822 .51773 L F
.79 .565 .595 r
.33787 .57988 m .334 .58219 L .33382 .58029 L F
0 0 0 r
.69766 .36589 m .69627 .36808 L .69849 .36453 L F
.717 .983 .795 r
.6945 .36862 m .69627 .36808 L .69766 .36589 L F
.328 0 .242 r
.47924 .5301 m .48166 .52952 L .48241 .52654 L F
0 0 .113 r
.48241 .52654 m .48166 .52952 L .48308 .52825 L F
.978 .68 .352 r
.32996 .60496 m .32768 .60366 L .32903 .60255 L F
.992 .822 .571 r
.32996 .60496 m .32808 .60737 L .32768 .60366 L F
.698 .963 .719 r
.68133 .34481 m .68148 .34547 L .68067 .34392 L F
.68133 .34481 m .68442 .34258 L .68148 .34547 L F
.991 .888 .592 r
.68067 .34392 m .68148 .34547 L .67985 .34642 L F
.779 .62 .684 r
.57152 .43421 m .567 .43301 L .56974 .43302 L F
.57152 .43421 m .56737 .43613 L .567 .43301 L F
.57152 .43421 m .57065 .437 L .56737 .43613 L F
.914 .696 .594 r
.56992 .42962 m .57152 .43421 L .56974 .43302 L F
0 0 0 r
.68112 .30196 m .68335 .30053 L .68443 .2995 L F
.466 .259 .514 r
.68071 .3039 m .68335 .30053 L .68112 .30196 L F
.513 .907 .928 r
.35597 .62217 m .35752 .62233 L .3586 .62116 L F
.3586 .62116 m .35752 .62233 L .35597 .62217 L F
.54 .542 .805 r
.23399 .58891 m .23554 .59298 L .23786 .5923 L F
.555 .507 .757 r
.51564 .47543 m .51832 .47471 L .51782 .47124 L F
.439 .215 .475 r
.51564 .47543 m .51804 .4774 L .51832 .47471 L F
.51564 .47543 m .51549 .47829 L .51804 .4774 L F
.516 .91 .792 r
.51149 .42106 m .51377 .42044 L .51603 .41899 L F
.28 0 0 r
.40916 .5044 m .41185 .50509 L .4133 .50491 L F
.889 .988 .797 r
.41412 .50564 m .4112 .50901 L .4134 .50846 L F
.41421 .50529 m .41391 .50566 L .41412 .50564 L F
.41391 .50566 m .4112 .50901 L .41412 .50564 L F
.025 .586 .806 r
.41185 .50509 m .41518 .50558 L .4133 .50491 L F
.41518 .50558 m .41624 .50574 L .4156 .50556 L F
.41518 .50558 m .4156 .50556 L .4133 .50491 L F
.679 .253 .228 r
.40245 .48523 m .4009 .48677 L .40326 .48363 L F
.744 .747 .855 r
.52221 .46182 m .52625 .46235 L .52501 .45898 L F
.766 .759 .846 r
.52501 .45898 m .52625 .46235 L .52843 .45991 L F
.498 .346 .605 r
.52625 .46235 m .53022 .46247 L .52843 .45991 L F
.257 .309 .725 r
.52625 .46235 m .52901 .46438 L .53022 .46247 L F
.861 .955 .608 r
.59304 .364 m .59155 .3649 L .59174 .36337 L F
.59304 .364 m .59083 .36778 L .59155 .3649 L F
.232 .751 .824 r
.59174 .36337 m .59632 .36289 L .59304 .364 L F
.5 .897 .758 r
.65896 .38936 m .66285 .38742 L .66157 .38824 L F
0 0 0 r
.66157 .38824 m .66285 .38742 L .66533 .38632 L F
.463 .222 .462 r
.51091 .4876 m .51445 .48508 L .51068 .48549 L F
.774 .671 .75 r
.41022 .51065 m .40797 .51413 L .41209 .5146 L F
.386 0 0 r
.40797 .51413 m .41106 .51491 L .41209 .5146 L F
.153 .432 .869 r
.41384 .51365 m .41209 .5146 L .41106 .51491 L F
.546 .418 .656 r
.41209 .5146 m .41529 .51648 L .41395 .51558 L F
.238 .499 .9 r
.41395 .51558 m .41706 .51625 L .41876 .51456 L F
.41395 .51558 m .41674 .51818 L .41706 .51625 L F
.153 .432 .869 r
.41384 .51365 m .41529 .51648 L .41209 .5146 L F
.125 0 0 r
.68335 .30053 m .68707 .29844 L .68443 .2995 L F
.39 .771 .991 r
.58621 .35019 m .58897 .34996 L .58867 .35077 L F
.924 .708 .218 r
.58565 .35069 m .58625 .35324 L .58621 .35019 L F
.511 .009 0 r
.58565 .35069 m .58621 .35019 L .58625 .35324 L F
.58565 .35069 m .58897 .34996 L .58621 .35019 L F
.58565 .35069 m .58743 .35165 L .58897 .34996 L F
.709 .896 .522 r
.58897 .34996 m .58743 .35165 L .58944 .34868 L F
.58897 .34996 m .58944 .34868 L .59015 .34764 L F
.39 .771 .991 r
.58867 .35077 m .58897 .34996 L .58973 .35103 L F
.794 .975 .908 r
.58973 .35103 m .5923 .34744 L .59278 .34793 L F
.58973 .35103 m .58897 .34996 L .5923 .34744 L F
.656 .885 .982 r
.47791 .4622 m .48206 .46223 L .48066 .46136 L F
.584 .586 .821 r
.48076 .45859 m .48206 .46223 L .48454 .46084 L F
.341 .433 .81 r
.48076 .45859 m .48206 .46223 L .48309 .46015 L F
.771 .955 .932 r
.48066 .46136 m .48206 .46223 L .48309 .46015 L F
.451 .34 .637 r
.46316 .57648 m .46509 .57283 L .46144 .57406 L F
.46316 .57648 m .46576 .57606 L .46509 .57283 L F
.128 0 .272 r
.46288 .57963 m .46576 .57606 L .46316 .57648 L F
.375 .837 .895 r
.6242 .40436 m .62569 .40475 L .62395 .40566 L F
.851 .83 .356 r
.69849 .36453 m .69934 .35985 L .69938 .3624 L F
.693 .821 .375 r
.69766 .36589 m .69849 .36453 L .69938 .3624 L F
.565 .336 .528 r
.33571 .61859 m .33196 .62155 L .33194 .61895 L F
.804 .899 .909 r
.60634 .40423 m .60713 .40129 L .60505 .40303 L F
.60634 .40423 m .6084 .40275 L .60713 .40129 L F
.563 .327 .516 r
.50261 .49476 m .50528 .4944 L .50539 .49182 L F
.633 .486 .665 r
.50539 .49182 m .50803 .49151 L .50808 .48831 L F
.533 .268 .458 r
.50528 .4944 m .50803 .49151 L .50539 .49182 L F
.998 .853 .539 r
.58457 .40726 m .58444 .40317 L .58356 .40572 L F
.979 .688 .322 r
.58363 .40839 m .58457 .40726 L .58356 .40572 L F
.58363 .40839 m .58498 .40985 L .58457 .40726 L F
.751 .304 .191 r
.35801 .60839 m .35956 .61086 L .36158 .60937 L F
.931 .964 .67 r
.35777 .60408 m .35784 .60552 L .35976 .60266 L F
.364 .462 .827 r
.35777 .60408 m .36095 .60912 L .35801 .60839 L F
.484 .234 .459 r
.36095 .60912 m .35956 .61086 L .35801 .60839 L F
.658 .594 .772 r
.36207 .60752 m .36095 .60912 L .35777 .60408 L F
.753 .948 .626 r
.36207 .60752 m .35956 .61086 L .36095 .60912 L F
.794 .971 .673 r
.36158 .60937 m .35956 .61086 L .36207 .60752 L F
.68 .798 .937 r
.35258 .57271 m .34999 .57433 L .3484 .57221 L F
.616 .65 .86 r
.55523 .41075 m .55678 .41446 L .5576 .41196 L F
.067 .362 .832 r
.55678 .41446 m .55783 .41321 L .5576 .41196 L F
.545 .256 .428 r
.23969 .59591 m .24168 .59825 L .24145 .59656 L F
.951 .612 .212 r
.59478 .40886 m .59615 .41029 L .59655 .41273 L F
0 0 0 r
.25262 .52245 m .25526 .52172 L .25716 .5209 L F
.01 0 0 r
.25526 .52172 m .25963 .52045 L .25716 .5209 L F
.935 .964 .748 r
.68907 .33536 m .68688 .33627 L .68803 .3339 L F
.68907 .33536 m .68701 .33875 L .68688 .33627 L F
.848 .783 .788 r
.54446 .40953 m .54177 .41273 L .54573 .41293 L F
.816 .838 .867 r
.54177 .41273 m .54354 .41429 L .54573 .41293 L F
.857 .759 .754 r
.48974 .45764 m .49162 .45889 L .48995 .45518 L F
.57 .584 .828 r
.49162 .45889 m .4927 .45427 L .48995 .45518 L F
.49162 .45889 m .49425 .4583 L .4927 .45427 L F
.507 .637 .912 r
.49162 .45889 m .49496 .46002 L .49425 .4583 L F
.385 0 0 r
.55666 .4006 m .56077 .40098 L .55981 .40136 L F
.217 .703 .928 r
.55895 .40107 m .55994 .40115 L .55981 .40136 L F
.576 .942 .882 r
.55895 .40107 m .56077 .40098 L .56291 .39961 L F
.463 .871 .715 r
.56291 .39961 m .56077 .40098 L .55981 .40136 L F
.56291 .39961 m .55981 .40136 L .56263 .40137 L F
.217 .703 .928 r
.55994 .40115 m .56263 .40137 L .55981 .40136 L F
.025 0 0 r
.56077 .40098 m .55956 .40176 L .55981 .40136 L F
.55956 .40176 m .55733 .40318 L .55981 .40136 L F
.978 .763 .544 r
.61582 .36326 m .61743 .36726 L .61746 .36413 L F
.77 .829 .898 r
.63225 .39103 m .63325 .39345 L .62955 .39326 L F
.737 .744 .858 r
.63459 .38858 m .63325 .39345 L .63225 .39103 L F
.63459 .38858 m .63685 .39073 L .63325 .39345 L F
0 0 0 r
.7194 .30725 m .72202 .30665 L .7222 .30658 L F
.462 .821 .996 r
.7194 .30725 m .71938 .30723 L .72202 .30665 L F
.71938 .30723 m .71823 .30633 L .72088 .30655 L F
.71938 .30723 m .72088 .30655 L .72202 .30665 L F
.866 .977 .852 r
.71914 .30922 m .71937 .30901 L .71823 .30633 L F
.71937 .30901 m .72202 .30665 L .72088 .30655 L F
.71937 .30901 m .72088 .30655 L .71823 .30633 L F
0 0 0 r
.7222 .30658 m .72202 .30665 L .72355 .30626 L F
0 0 .418 r
.72355 .30626 m .72527 .30408 L .72442 .30014 L F
.674 .969 .779 r
.72355 .30626 m .72202 .30665 L .72527 .30408 L F
.866 .977 .852 r
.71914 .30922 m .71989 .30837 L .72202 .30665 L F
.132 0 .261 r
.71989 .30837 m .72168 .30841 L .72384 .30522 L F
.487 .849 .603 r
.72202 .30665 m .72407 .30488 L .72527 .30408 L F
.132 0 .261 r
.72346 .30539 m .72384 .30522 L .72407 .30488 L F
.71989 .30837 m .72189 .3067 L .72202 .30665 L F
.72189 .3067 m .72407 .30488 L .72202 .30665 L F
.71989 .30837 m .72384 .30522 L .72346 .30539 L F
0 0 0 r
.30157 .53768 m .30305 .53308 L .30397 .53686 L F
.30157 .53768 m .30227 .53588 L .30305 .53308 L F
.553 .853 .998 r
.30397 .53686 m .30227 .53588 L .30157 .53768 L F
0 0 .112 r
.33033 .49821 m .33083 .49903 L .33293 .49789 L F
.33027 .49922 m .33016 .50116 L .33083 .49903 L F
.867 .701 .675 r
.33266 .50312 m .33083 .49903 L .33016 .50116 L F
.33266 .50312 m .32947 .50256 L .33083 .49903 L F
.892 .898 .482 r
.33083 .49903 m .32947 .50256 L .32949 .50089 L F
0 0 0 r
.33083 .49903 m .32949 .50089 L .33126 .49889 L F
.482 .871 .682 r
.33209 .49795 m .33356 .49722 L .33083 .49903 L F
0 0 0 r
.33083 .49903 m .33126 .49889 L .33209 .49795 L F
0 0 .112 r
.33033 .49821 m .33027 .49922 L .33083 .49903 L F
.792 .561 .587 r
.27613 .64538 m .2778 .64491 L .27465 .64448 L F
.763 .486 .515 r
.27613 .64538 m .28019 .64684 L .2778 .64491 L F
.027 .56 .853 r
.43683 .4644 m .43405 .46352 L .43546 .46433 L F
0 0 0 r
.34123 .54276 m .34113 .54299 L .34039 .54409 L F
.213 .545 .929 r
.34039 .54409 m .34113 .54299 L .33898 .54232 L F
.34039 .54409 m .34113 .54299 L .33898 .54232 L F
.674 .58 .742 r
.41674 .51818 m .41273 .51673 L .41529 .51648 L F
.651 .602 .787 r
.41674 .51818 m .41273 .51673 L .41529 .51648 L F
.394 .233 .541 r
.47754 .53252 m .47924 .5301 L .47656 .53055 L F
.461 .874 .736 r
.37295 .49443 m .37085 .4957 L .36866 .49658 L F
.923 .93 .795 r
.53494 .46628 m .53712 .46344 L .53613 .46257 L F
.727 .887 .953 r
.53712 .46344 m .5382 .46091 L .53613 .46257 L F
.53712 .46344 m .53962 .46216 L .5382 .46091 L F
.844 .815 .821 r
.60986 .39084 m .61277 .38809 L .61075 .38632 L F
.756 .993 .808 r
.61416 .38351 m .61277 .38809 L .61381 .38659 L F
.61416 .38351 m .61075 .38632 L .61277 .38809 L F
.505 .882 .972 r
.42409 .45082 m .42252 .45152 L .42027 .45103 L F
.963 .648 .375 r
.38961 .59397 m .39063 .59322 L .38967 .59185 L F
.38961 .59397 m .39078 .59499 L .39063 .59322 L F
.429 .108 .317 r
.59792 .36764 m .59698 .37011 L .59432 .37066 L F
.59792 .36764 m .59698 .37011 L .59432 .37066 L F
.865 .753 .242 r
.59796 .36286 m .59755 .36591 L .59792 .36764 L F
.804 .499 .473 r
.59792 .36764 m .60089 .37051 L .60122 .36805 L F
0 0 0 r
.59825 .36798 m .59792 .36764 L .59755 .36591 L F
.804 .499 .473 r
.59792 .36764 m .5973 .36927 L .60089 .37051 L F
.5973 .36927 m .59698 .37011 L .59782 .37019 L F
.5973 .36927 m .59782 .37019 L .60089 .37051 L F
.949 .89 .738 r
.59838 .37019 m .59921 .37029 L .59698 .37011 L F
.59921 .37029 m .60089 .37051 L .59892 .3703 L F
.59921 .37029 m .59892 .3703 L .59698 .37011 L F
.66 .519 .681 r
.60122 .36805 m .60089 .37051 L .60382 .36745 L F
.949 .89 .738 r
.59939 .37031 m .60074 .37084 L .60089 .37051 L F
.59838 .37019 m .60074 .37084 L .59939 .37031 L F
.59838 .37019 m .59933 .3739 L .60074 .37084 L F
.691 .577 .723 r
.60253 .36864 m .60309 .3715 L .5992 .37041 L F
.564 .179 .271 r
.59972 .37014 m .60253 .36864 L .59999 .36994 L F
.969 .682 .432 r
.59776 .3688 m .59999 .36994 L .59698 .37011 L F
.59825 .36798 m .59943 .36931 L .59776 .3688 L F
.59943 .36931 m .59999 .36994 L .59776 .3688 L F
.949 .89 .738 r
.59838 .37019 m .59698 .37011 L .59999 .36994 L F
.691 .577 .723 r
.59958 .36974 m .5992 .37041 L .59838 .37019 L F
.59967 .36998 m .5992 .37041 L .59958 .36974 L F
0 .015 .589 r
.59838 .37019 m .60023 .37443 L .59884 .37199 L F
0 0 .044 r
.59989 .37061 m .60082 .37579 L .59838 .37019 L F
.60309 .3715 m .60152 .37446 L .59989 .37061 L F
.60152 .37446 m .60082 .37579 L .59989 .37061 L F
.969 .682 .432 r
.59943 .36931 m .59972 .37014 L .59999 .36994 L F
.691 .577 .723 r
.60253 .36864 m .59958 .36974 L .59999 .36994 L F
.59958 .36974 m .59838 .37019 L .59999 .36994 L F
.969 .682 .432 r
.59934 .36962 m .59848 .37104 L .59969 .37016 L F
.59825 .36798 m .59834 .36913 L .59934 .36962 L F
.59834 .36913 m .59848 .37104 L .59934 .36962 L F
.691 .577 .723 r
.6006 .36967 m .5992 .37041 L .60015 .36953 L F
.969 .682 .432 r
.59963 .37 m .59969 .37016 L .59972 .37014 L F
.59825 .36798 m .59969 .37016 L .59963 .37 L F
.59825 .36798 m .59972 .37014 L .59943 .36931 L F
.691 .577 .723 r
.60015 .36953 m .59967 .36998 L .59958 .36974 L F
.60253 .36864 m .6006 .36967 L .60015 .36953 L F
.564 .179 .271 r
.59952 .37028 m .60253 .36864 L .59972 .37014 L F
.59848 .37104 m .59978 .37027 L .59952 .37028 L F
.59978 .37027 m .60253 .36864 L .59952 .37028 L F
0 .015 .589 r
.59884 .37199 m .60082 .37579 L .59933 .3739 L F
.60023 .37443 m .60082 .37579 L .59884 .37199 L F
0 0 0 r
.59825 .36798 m .59698 .37011 L .59792 .36764 L F
.332 .697 .982 r
.24195 .58436 m .24047 .58571 L .23869 .58494 L F
.292 .778 .908 r
.58001 .36831 m .58188 .36769 L .58378 .36832 L F
.129 0 .117 r
.53109 .41217 m .53028 .41391 L .53074 .41368 L F
.978 .69 .31 r
.53144 .41071 m .5324 .41311 L .53109 .41217 L F
.573 .585 .827 r
.53374 .40918 m .5324 .41311 L .53093 .40944 L F
.706 .513 .625 r
.5324 .41311 m .53497 .41445 L .53653 .41349 L F
.83 .859 .867 r
.53653 .41349 m .53497 .41445 L .53538 .41374 L F
0 0 .196 r
.53517 .41378 m .5324 .41311 L .53653 .41349 L F
.689 .662 .818 r
.53785 .4094 m .53538 .41374 L .53374 .40918 L F
.53538 .41374 m .53497 .41445 L .53479 .41369 L F
.53538 .41374 m .53479 .41369 L .53374 .40918 L F
0 0 .196 r
.53609 .414 m .53517 .41378 L .53538 .41374 L F
.53625 .41381 m .53538 .41374 L .53653 .41349 L F
.53609 .414 m .53538 .41374 L .53625 .41381 L F
.83 .859 .867 r
.53653 .41349 m .53538 .41374 L .53785 .4094 L F
.573 .585 .827 r
.53374 .40918 m .53479 .41369 L .5324 .41311 L F
.53479 .41369 m .53497 .41445 L .5324 .41311 L F
0 0 .196 r
.53501 .41527 m .5324 .41311 L .53609 .414 L F
.129 0 .117 r
.53109 .41217 m .53074 .41368 L .53321 .41246 L F
.978 .69 .31 r
.53093 .40944 m .53144 .41071 L .53109 .41217 L F
0 0 0 r
.5414 .48785 m .53763 .49044 L .53928 .48919 L F
.662 .962 .932 r
.72534 .32592 m .72772 .32595 L .72992 .32454 L F
.739 .894 .949 r
.41002 .48362 m .40964 .48659 L .41155 .4846 L F
.41002 .48362 m .40611 .48628 L .40964 .48659 L F
.656 .579 .757 r
.40964 .48659 m .41303 .48841 L .41155 .4846 L F
.542 .874 .992 r
.31155 .65533 m .31353 .65622 L .31569 .65525 L F
.79 .565 .595 r
.33787 .57988 m .33794 .58268 L .334 .58219 L F
.327 .16 .496 r
.34046 .57882 m .33794 .58268 L .33787 .57988 L F
.453 .428 .741 r
.2513 .58776 m .25373 .58831 L .24984 .58597 L F
.2513 .58776 m .25401 .58864 L .25373 .58831 L F
.807 .747 .797 r
.50992 .471 m .51186 .47267 L .51457 .46951 L F
.983 .776 .546 r
.52954 .47388 m .53157 .4754 L .53175 .47209 L F
.796 .969 .666 r
.5326 .46977 m .52954 .47388 L .53175 .47209 L F
.735 .666 .782 r
.53157 .4754 m .53691 .47333 L .53175 .47209 L F
.633 .639 .839 r
.22841 .57739 m .23192 .57879 L .23148 .57808 L F
.595 .91 .98 r
.51904 .4294 m .52174 .42868 L .5202 .42765 L F
.647 .907 .594 r
.51856 .4296 m .51904 .4294 L .5202 .42765 L F
.402 .328 .659 r
.51904 .4294 m .51974 .43097 L .52166 .43117 L F
.533 0 0 r
.36753 .50382 m .36334 .5008 L .36629 .50125 L F
.577 .174 .241 r
.26933 .58486 m .27221 .58503 L .27409 .58255 L F
.396 0 .116 r
.27221 .58503 m .27649 .58249 L .27409 .58255 L F
.673 .95 .956 r
.61356 .40135 m .61551 .40184 L .61796 .40036 L F
.76 .982 .91 r
.564 .47084 m .56306 .47326 L .56525 .4718 L F
.564 .47084 m .5607 .47324 L .56306 .47326 L F
.979 .893 .543 r
.7025 .34325 m .70337 .34136 L .70267 .34023 L F
.959 .927 .722 r
.70337 .34136 m .70445 .336 L .70267 .34023 L F
.58 .924 .959 r
.30698 .54718 m .3056 .54687 L .30777 .5458 L F
.30698 .54718 m .3056 .54687 L .30777 .5458 L F
.856 .765 .761 r
.71302 .30296 m .71249 .30537 L .71461 .30211 L F
.668 .975 .851 r
.55093 .42884 m .55001 .43018 L .55224 .42845 L F
.479 .753 .99 r
.54838 .42872 m .55001 .43018 L .55093 .42884 L F
.482 .899 .874 r
.62238 .34223 m .62309 .3409 L .62515 .3414 L F
.62238 .34223 m .62061 .34219 L .62309 .3409 L F
.902 .932 .558 r
.69908 .35748 m .70035 .35506 L .69914 .35588 L F
.946 .905 .522 r
.69914 .35588 m .70035 .35506 L .70026 .35225 L F
.668 .409 .52 r
.42731 .5537 m .4274 .55652 L .42396 .55634 L F
.008 0 0 r
.41876 .51456 m .41956 .5153 L .42188 .51499 L F
.41876 .51456 m .41706 .51625 L .41956 .5153 L F
0 0 .342 r
.43409 .58127 m .43301 .57979 L .43391 .5782 L F
.874 .6 .075 r
.57172 .43743 m .57233 .43861 L .57442 .43769 L F
0 0 .547 r
.57233 .43861 m .57424 .44172 L .57449 .44037 L F
.108 .013 .455 r
.57442 .43769 m .57233 .43861 L .57449 .44037 L F
.184 0 .232 r
.54136 .45212 m .54369 .44964 L .54332 .4517 L F
.589 .606 .837 r
.54332 .4517 m .54191 .45494 L .54136 .45212 L F
.83 .859 .867 r
.53653 .41349 m .53785 .4094 L .53954 .41096 L F
.463 .824 .56 r
.53774 .41412 m .53751 .41435 L .53904 .41305 L F
0 0 0 r
.53369 .41651 m .53751 .41435 L .53601 .41554 L F
.463 .824 .56 r
.53601 .41554 m .53751 .41435 L .53774 .41412 L F
.096 0 0 r
.53751 .41435 m .53653 .41349 L .53731 .41456 L F
.53751 .41435 m .53731 .41456 L .53743 .41472 L F
.53751 .41435 m .53501 .41527 L .53653 .41349 L F
.694 .681 .833 r
.61416 .38351 m .61381 .38659 L .61768 .38394 L F
.335 .08 .371 r
.22939 .54379 m .23136 .54123 L .22968 .54043 L F
0 0 0 r
.64909 .32824 m .65299 .32647 L .64953 .32786 L F
.866 .992 .822 r
.52283 .4055 m .52183 .40812 L .52454 .40668 L F
.175 0 .32 r
.5268 .40344 m .52454 .40668 L .52669 .40597 L F
.28 .222 .613 r
.52454 .40668 m .52678 .40864 L .52669 .40597 L F
.175 0 .32 r
.5268 .40344 m .52454 .40668 L .52669 .40597 L F
.379 .763 .989 r
.52283 .4055 m .52454 .40668 L .52669 .40597 L F
.437 .089 .275 r
.55435 .38967 m .55703 .38935 L .55733 .38764 L F
.35 .017 .252 r
.55733 .38764 m .55703 .38935 L .55968 .38845 L F
.368 0 .039 r
.55733 .38764 m .55968 .38845 L .55999 .38744 L F
.426 .788 .996 r
.31073 .55559 m .31506 .55624 L .31247 .55683 L F
.31073 .55559 m .31506 .55624 L .31247 .55683 L F
.893 .761 .709 r
.62842 .41638 m .63037 .417 L .6286 .41943 L F
0 0 .5 r
.22768 .57235 m .22841 .57739 L .22911 .57494 L F
.333 .517 .888 r
.22841 .57739 m .23148 .57808 L .22911 .57494 L F
.938 .897 .761 r
.56816 .45525 m .56632 .45909 L .56496 .45789 L F
.514 .536 .816 r
.70448 .28765 m .70325 .2926 L .70117 .28864 L F
.70448 .28765 m .70579 .29166 L .70325 .2926 L F
.567 .358 .557 r
.4435 .45733 m .44041 .46113 L .44149 .45958 L F
.81 .973 .902 r
.5202 .42765 m .52174 .42868 L .52439 .42575 L F
.465 .857 .66 r
.47083 .5939 m .473 .59264 L .47455 .5914 L F
.962 .786 .618 r
.3877 .5719 m .39023 .57006 L .38824 .56897 L F
.3877 .5719 m .38955 .57289 L .39023 .57006 L F
.946 .886 .74 r
.63065 .41204 m .63394 .41027 L .63305 .40924 L F
.63065 .41204 m .63232 .41392 L .63394 .41027 L F
.85 .986 .857 r
.63394 .41027 m .63452 .40752 L .63305 .40924 L F
.63394 .41027 m .63688 .40727 L .63452 .40752 L F
.731 .616 .73 r
.46408 .52996 m .46718 .52971 L .46589 .52769 L F
.191 .085 .495 r
.46718 .52971 m .46909 .52689 L .46589 .52769 L F
.46718 .52971 m .46897 .52913 L .46909 .52689 L F
0 0 0 r
.46453 .53207 m .46897 .52913 L .46718 .52971 L F
0 0 .336 r
.47074 .53167 m .46966 .53136 L .46897 .52913 L F
.599 .947 .914 r
.51056 .40657 m .506 .40798 L .50959 .40625 L F
.854 .995 .828 r
.51056 .40657 m .5114 .40413 L .51402 .4044 L F
.51056 .40657 m .50959 .40625 L .5114 .40413 L F
0 0 .319 r
.71321 .27678 m .71547 .27441 L .71547 .27112 L F
0 .563 .711 r
.71321 .27678 m .71516 .27683 L .71547 .27441 L F
.71321 .27678 m .71624 .27687 L .71516 .27683 L F
.807 .747 .797 r
.50992 .471 m .51457 .46951 L .51286 .46765 L F
.927 .915 .786 r
.51457 .46951 m .5157 .46459 L .51286 .46765 L F
0 0 .125 r
.50702 .5145 m .50617 .5168 L .50465 .51795 L F
.235 .019 .368 r
.50617 .5168 m .50393 .52005 L .50465 .51795 L F
.937 .651 .473 r
.37174 .5299 m .37318 .53475 L .37451 .5339 L F
.989 .771 .515 r
.37225 .53531 m .37451 .5339 L .37318 .53475 L F
.37225 .53531 m .37376 .53687 L .37451 .5339 L F
.675 .93 .97 r
.45408 .43968 m .45319 .44176 L .45215 .44125 L F
.45408 .43968 m .45667 .44006 L .45319 .44176 L F
.632 .216 .236 r
.27544 .58945 m .27352 .59154 L .27138 .58969 L F
.51 .103 .203 r
.27805 .58926 m .27352 .59154 L .27544 .58945 L F
.876 .865 .825 r
.3132 .61181 m .31235 .61612 L .31094 .61222 L F
.3132 .61181 m .31036 .61512 L .31235 .61612 L F
.119 .249 .724 r
.57385 .37206 m .57525 .37378 L .57387 .36981 L F
.065 .218 .713 r
.25095 .59877 m .25236 .59955 L .25081 .59515 L F
.901 .838 .378 r
.42136 .56838 m .42236 .56622 L .4221 .56577 L F
.42136 .56838 m .4215 .56873 L .42236 .56622 L F
.351 .139 .445 r
.34015 .58963 m .34256 .58894 L .34255 .58629 L F
.055 0 .2 r
.34001 .59273 m .34256 .58894 L .34015 .58963 L F
.945 .715 .558 r
.38679 .56258 m .38886 .56342 L .3871 .5597 L F
.923 .571 .346 r
.38679 .56258 m .38724 .5652 L .38886 .56342 L F
.956 .64 .386 r
.38724 .5652 m .38918 .56644 L .38886 .56342 L F
.471 .759 .993 r
.60713 .40129 m .6084 .40275 L .61094 .40225 L F
.498 .702 .961 r
.6011 .36001 m .60019 .36186 L .59869 .36036 L F
.6011 .36001 m .60019 .36186 L .59869 .36036 L F
.929 .943 .597 r
.34129 .5105 m .34082 .50954 L .34265 .5078 L F
.451 0 0 r
.34265 .5078 m .34082 .50954 L .3378 .50858 L F
.282 0 .2 r
.51714 .50597 m .5153 .50518 L .51795 .50445 L F
.51714 .50597 m .51466 .50694 L .5153 .50518 L F
.794 .702 .763 r
.31649 .53695 m .32218 .53768 L .31988 .53332 L F
.624 .295 .393 r
.31842 .5394 m .32218 .53768 L .31649 .53695 L F
.959 .933 .608 r
.32167 .54076 m .32142 .53976 L .32361 .54193 L F
.32167 .54076 m .32161 .54049 L .32142 .53976 L F
.624 .295 .393 r
.321 .53822 m .32142 .53976 L .32218 .53768 L F
.32218 .53768 m .32142 .53976 L .31842 .5394 L F
.482 .558 .857 r
.31988 .53332 m .32218 .53768 L .32394 .53656 L F
.875 .881 .447 r
.32192 .53746 m .3212 .53835 L .32234 .53554 L F
.32142 .53976 m .32128 .53887 L .32166 .53867 L F
.037 0 .129 r
.32394 .53656 m .32142 .53976 L .32218 .53768 L F
.32394 .53656 m .32142 .53976 L .32218 .53768 L F
.875 .881 .447 r
.32142 .53976 m .32234 .53554 L .32394 .53656 L F
.959 .933 .608 r
.32161 .54049 m .3213 .53889 L .32142 .53976 L F
.875 .881 .447 r
.32128 .53887 m .3212 .53835 L .32166 .53867 L F
.959 .933 .608 r
.3213 .53889 m .3212 .53835 L .32128 .53887 L F
.3213 .53889 m .32128 .53887 L .32142 .53976 L F
.624 .295 .393 r
.31842 .5394 m .32142 .53976 L .321 .53822 L F
.558 .114 .15 r
.31695 .54202 m .31998 .54261 L .32167 .54076 L F
.959 .933 .608 r
.32167 .54076 m .31998 .54261 L .32007 .54228 L F
.464 0 .014 r
.32167 .54076 m .32007 .54228 L .31695 .54202 L F
.927 .864 .758 r
.3212 .53835 m .32007 .54228 L .31855 .54094 L F
.32007 .54228 m .31998 .54261 L .31981 .54241 L F
.32007 .54228 m .31981 .54241 L .31855 .54094 L F
.464 0 .014 r
.32007 .54228 m .31992 .54242 L .31981 .54241 L F
.32007 .54228 m .31981 .54241 L .31695 .54202 L F
.338 .652 .969 r
.31981 .54241 m .31998 .54261 L .31695 .54202 L F
.464 0 .014 r
.31992 .54242 m .31924 .54308 L .31695 .54202 L F
.338 .652 .969 r
.31855 .54094 m .31981 .54241 L .31695 .54202 L F
.959 .933 .608 r
.32167 .54076 m .32007 .54228 L .3212 .53835 L F
.464 0 .014 r
.32167 .54076 m .31928 .5431 L .31924 .54308 L F
0 0 0 r
.32036 .53937 m .32152 .53906 L .32154 .53905 L F
.33 .331 .709 r
.32667 .53863 m .32394 .53656 L .32458 .53663 L F
.32667 .53863 m .32458 .53663 L .32811 .53705 L F
.955 .903 .527 r
.32782 .53484 m .32758 .5367 L .32811 .53705 L F
.695 .67 .821 r
.32802 .53346 m .32761 .53626 L .32563 .53326 L F
.3271 .53306 m .32563 .53326 L .32485 .5321 L F
.32802 .53346 m .32563 .53326 L .3271 .53306 L F
.955 .903 .527 r
.32761 .53626 m .32758 .5367 L .32782 .53484 L F
.32802 .53346 m .32776 .53443 L .32811 .53705 L F
.695 .67 .821 r
.32802 .53346 m .32792 .53672 L .32761 .53626 L F
0 0 .133 r
.32798 .53389 m .32776 .53443 L .32802 .53346 L F
.164 .682 .888 r
.32394 .53656 m .32758 .5367 L .32811 .53705 L F
0 0 .133 r
.32779 .53636 m .32776 .53443 L .32798 .53389 L F
.591 .629 .858 r
.32761 .53626 m .32792 .53672 L .32758 .5367 L F
0 0 .133 r
.32774 .53671 m .32774 .53646 L .32774 .53645 L F
.32774 .53671 m .32774 .53645 L .32779 .53636 L F
.164 .682 .888 r
.32758 .5367 m .32792 .53672 L .32811 .53705 L F
0 0 .133 r
.32774 .53709 m .32774 .53671 L .32779 .53636 L F
.32774 .53646 m .32776 .53443 L .32779 .53636 L F
.837 .722 .194 r
.32811 .53705 m .32792 .53672 L .32802 .53346 L F
.955 .903 .527 r
.32776 .53443 m .32761 .53626 L .32782 .53484 L F
.591 .629 .858 r
.32761 .53626 m .32758 .5367 L .32394 .53656 L F
.955 .903 .527 r
.32776 .53443 m .32723 .53647 L .32758 .5367 L F
.32723 .53647 m .32667 .53863 L .32811 .53705 L F
0 0 .133 r
.32774 .53709 m .32667 .53863 L .32776 .53443 L F
.32774 .53709 m .32802 .53346 L .32717 .53422 L F
.428 0 .023 r
.33166 .53297 m .32717 .53422 L .3284 .53288 L F
0 0 0 r
.33166 .53297 m .32774 .53709 L .32717 .53422 L F
.651 .224 .219 r
.32717 .53422 m .32837 .53528 L .32876 .53311 L F
0 0 0 r
.33166 .53297 m .32948 .53625 L .32774 .53709 L F
.651 .224 .219 r
.32837 .53528 m .32948 .53625 L .32899 .53413 L F
.32837 .53528 m .32899 .53413 L .32876 .53311 L F
.428 0 .023 r
.3301 .53265 m .3284 .53288 L .32884 .53239 L F
.33166 .53297 m .3284 .53288 L .3301 .53265 L F
.591 .629 .858 r
.32485 .5321 m .32724 .5357 L .32394 .53656 L F
.32724 .5357 m .32761 .53626 L .32699 .53631 L F
.32724 .5357 m .32699 .53631 L .32394 .53656 L F
.077 .199 .69 r
.32774 .53709 m .32876 .54065 L .32667 .53863 L F
.32876 .54065 m .32876 .54065 L .32667 .53863 L F
.741 .631 .737 r
.32394 .53656 m .32453 .54078 L .32142 .53976 L F
.33 .331 .709 r
.32667 .53863 m .32453 .54078 L .32394 .53656 L F
0 0 0 r
.32141 .53896 m .32154 .53905 L .32589 .53721 L F
.32036 .53937 m .32154 .53905 L .32141 .53896 L F
.32003 .5395 m .32023 .53944 L .32036 .53937 L F
.32023 .53944 m .32152 .53906 L .32036 .53937 L F
.875 .881 .447 r
.32166 .53867 m .3212 .53835 L .32192 .53746 L F
0 0 0 r
.32003 .5395 m .32036 .53937 L .3212 .53835 L F
.32036 .53937 m .32589 .53721 L .3212 .53835 L F
.414 .223 .51 r
.50803 .49151 m .51091 .4876 L .50808 .48831 L F
.997 .77 .437 r
.32597 .59232 m .32687 .59635 L .32564 .59501 L F
.913 .55 .103 r
.32743 .59851 m .32682 .59731 L .32687 .59635 L F
.32682 .59731 m .32564 .59501 L .32674 .5962 L F
.32682 .59731 m .32674 .5962 L .32687 .59635 L F
.32734 .59842 m .3271 .59794 L .32743 .59851 L F
.3271 .59794 m .32564 .59501 L .32713 .59792 L F
.3271 .59794 m .32713 .59792 L .32743 .59851 L F
.715 .224 0 r
.3267 .59821 m .3264 .59791 L .32677 .59811 L F
.877 .928 .543 r
.32736 .59886 m .3264 .59791 L .32748 .5987 L F
.32579 .60093 m .3264 .59791 L .32736 .59886 L F
.715 .224 0 r
.32634 .59876 m .3264 .59791 L .3267 .59821 L F
.913 .55 .103 r
.3271 .59794 m .32685 .59793 L .32564 .59501 L F
.678 .833 .958 r
.32877 .5951 m .3269 .59791 L .33024 .597 L F
.3269 .59791 m .32695 .59805 L .33024 .597 L F
.32687 .59796 m .32677 .59811 L .32695 .59805 L F
0 0 0 r
.32687 .59796 m .32677 .59811 L .32687 .59795 L F
.913 .55 .103 r
.32686 .59794 m .32685 .59793 L .32687 .59793 L F
.757 .922 .944 r
.32687 .59795 m .32687 .59795 L .32685 .59792 L F
.32687 .59795 m .32677 .59811 L .32685 .59792 L F
.32687 .59795 m .32685 .59792 L .32685 .59792 L F
.678 .833 .958 r
.32685 .59792 m .32677 .59811 L .32687 .59796 L F
.913 .55 .103 r
.32748 .5987 m .32695 .59805 L .3271 .59794 L F
.32748 .5987 m .32734 .59842 L .32743 .59851 L F
.56 .034 0 r
.32695 .59805 m .32748 .5987 L .33024 .597 L F
.32677 .59811 m .32748 .5987 L .32695 .59805 L F
.32677 .59811 m .32677 .59818 L .32748 .5987 L F
.913 .55 .103 r
.32748 .5987 m .32677 .59818 L .32695 .59805 L F
0 0 0 r
.32688 .5981 m .32677 .59818 L .32677 .59811 L F
.32677 .59818 m .32667 .59825 L .32677 .59811 L F
.56 .034 0 r
.32677 .59811 m .3264 .59791 L .32677 .59818 L F
.913 .55 .103 r
.32677 .59818 m .3264 .59791 L .32685 .59793 L F
.32685 .59793 m .32685 .59793 L .32685 .59793 L F
.32677 .59818 m .32685 .59793 L .32685 .59793 L F
.32677 .59818 m .32685 .59793 L .32686 .59794 L F
.32688 .5981 m .32687 .59793 L .3271 .59794 L F
0 0 0 r
.32688 .5981 m .32677 .59811 L .32687 .59795 L F
.913 .55 .103 r
.32677 .59818 m .32687 .59793 L .32688 .5981 L F
0 0 0 r
.32687 .59795 m .32687 .59796 L .32687 .59795 L F
.32687 .59796 m .32687 .59795 L .32687 .59795 L F
.742 .668 .778 r
.33055 .5925 m .32687 .59635 L .32597 .59232 L F
.757 .922 .944 r
.32687 .59795 m .32685 .59792 L .3283 .59448 L F
.678 .833 .958 r
.32685 .59792 m .32687 .59796 L .3269 .59791 L F
.32687 .59796 m .32695 .59805 L .3269 .59791 L F
0 0 0 r
.32688 .5981 m .32687 .59795 L .32793 .59636 L F
.32687 .59795 m .32687 .59795 L .32793 .59636 L F
.712 .395 .44 r
.32689 .59827 m .33024 .597 L .32748 .5987 L F
0 0 0 r
.32688 .5981 m .32677 .59818 L .32688 .5981 L F
.32677 .59818 m .32667 .59825 L .32677 .59818 L F
.32677 .59818 m .32677 .59818 L .32688 .5981 L F
.712 .395 .44 r
.3264 .59791 m .32739 .59768 L .32706 .59808 L F
.32677 .59818 m .32706 .59808 L .32689 .59827 L F
.3264 .59791 m .32706 .59808 L .32677 .59818 L F
.32739 .59768 m .33024 .597 L .32689 .59827 L F
0 0 0 r
.3282 .59669 m .32688 .5981 L .32793 .59636 L F
.712 .395 .44 r
.32748 .59799 m .32813 .60025 L .32962 .59715 L F
.32739 .59768 m .32748 .59799 L .32962 .59715 L F
0 0 0 r
.3291 .59782 m .32736 .59804 L .3282 .59669 L F
.32736 .59804 m .32706 .59808 L .32739 .59768 L F
.32736 .59804 m .32739 .59768 L .3282 .59669 L F
.32706 .59808 m .32688 .5981 L .3282 .59669 L F
.32693 .59821 m .32662 .59833 L .32667 .59825 L F
.32688 .5981 m .32667 .59825 L .32667 .59825 L F
.712 .395 .44 r
.3264 .59791 m .32669 .5983 L .32739 .59768 L F
.32669 .5983 m .32727 .59909 L .32736 .59804 L F
0 0 0 r
.32736 .59804 m .32667 .59825 L .32688 .5981 L F
.32693 .59821 m .32667 .59825 L .32736 .59804 L F
.712 .395 .44 r
.32669 .5983 m .32736 .59804 L .32739 .59768 L F
.727 .666 .79 r
.32748 .5987 m .32903 .60255 L .32579 .60093 L F
.712 .395 .44 r
.32727 .59909 m .32813 .60025 L .32739 .59768 L F
0 0 0 r
.3291 .59782 m .32693 .59821 L .32736 .59804 L F
.715 .224 0 r
.32634 .59876 m .32813 .60025 L .32669 .5983 L F
0 0 0 r
.32668 .59832 m .32634 .59876 L .32662 .59833 L F
.715 .224 0 r
.32634 .59876 m .32669 .5983 L .3264 .59791 L F
0 0 0 r
.3291 .59782 m .32634 .59876 L .32668 .59832 L F
.3291 .59782 m .32662 .59833 L .32693 .59821 L F
.712 .395 .44 r
.32962 .59715 m .32813 .60025 L .33024 .597 L F
0 0 0 r
.32793 .59636 m .32744 .5971 L .32898 .59462 L F
.32744 .5971 m .32687 .59795 L .32744 .59705 L F
.32744 .5971 m .32744 .59705 L .32898 .59462 L F
.678 .833 .958 r
.32905 .59457 m .33024 .597 L .33255 .59498 L F
.757 .922 .944 r
.32898 .59462 m .32687 .59795 L .3283 .59448 L F
.678 .833 .958 r
.3283 .59448 m .32877 .5951 L .32898 .59469 L F
.32877 .5951 m .33024 .597 L .32905 .59457 L F
0 0 0 r
.32898 .59469 m .32793 .59636 L .32898 .59462 L F
.32899 .59477 m .32877 .5951 L .32898 .59469 L F
.32877 .5951 m .32793 .59636 L .32898 .59469 L F
.3291 .59782 m .32793 .59636 L .32899 .59477 L F
.678 .833 .958 r
.3283 .59448 m .32685 .59792 L .3269 .59791 L F
.3283 .59448 m .3269 .59791 L .32877 .5951 L F
.766 .281 .083 r
.32903 .60255 m .32768 .60366 L .32579 .60093 L F
.983 .697 .373 r
.32634 .59876 m .32792 .60256 L .32813 .60025 L F
.636 .304 .392 r
.32813 .60025 m .33082 .60074 L .33024 .597 L F
.751 .433 .446 r
.32813 .60025 m .33247 .60285 L .33082 .60074 L F
.32813 .60025 m .32813 .60027 L .33247 .60285 L F
.32813 .60027 m .32792 .60256 L .32941 .60266 L F
.32813 .60027 m .32941 .60266 L .33247 .60285 L F
.97 .76 .329 r
.32941 .60266 m .32945 .60465 L .33247 .60285 L F
0 .108 .626 r
.33056 .59963 m .32962 .60305 L .32938 .60061 L F
.32933 .59812 m .32938 .60061 L .3291 .59782 L F
.33056 .59963 m .32938 .60061 L .32933 .59812 L F
.97 .76 .329 r
.32792 .60256 m .32855 .60519 L .32945 .60465 L F
.32792 .60256 m .32945 .60465 L .32941 .60266 L F
0 .108 .626 r
.32962 .60305 m .32955 .6029 L .3291 .59782 L F
.705 .686 .829 r
.3291 .59782 m .32886 .59878 L .3286 .59799 L F
.32886 .59878 m .32792 .60256 L .3286 .59799 L F
.3286 .59799 m .32792 .60256 L .32634 .59876 L F
.75 .713 .817 r
.33024 .597 m .33438 .59901 L .33263 .59612 L F
.841 .457 .321 r
.33024 .597 m .33082 .60074 L .33438 .59901 L F
.558 .631 .88 r
.33438 .59901 m .3369 .59834 L .33263 .59612 L F
.654 .959 .935 r
.3369 .59834 m .33192 .59958 L .33571 .59753 L F
.68 .634 .797 r
.33734 .59664 m .33192 .59958 L .33362 .59652 L F
0 0 0 r
.33192 .59958 m .33244 .5994 L .33362 .59652 L F
.79 .481 .466 r
.33362 .59652 m .33292 .59822 L .3291 .59782 L F
.33292 .59822 m .33244 .5994 L .33098 .59871 L F
.33292 .59822 m .33098 .59871 L .3291 .59782 L F
.654 .959 .935 r
.33721 .59715 m .33571 .59753 L .33734 .59664 L F
.3369 .59834 m .33571 .59753 L .33721 .59715 L F
.705 .686 .829 r
.3291 .59782 m .32957 .60314 L .32792 .60256 L F
.906 .984 .768 r
.33438 .59901 m .33082 .60074 L .33192 .59958 L F
0 0 0 r
.33192 .59958 m .33082 .60074 L .33244 .5994 L F
0 .108 .626 r
.33115 .60036 m .3291 .59782 L .33244 .5994 L F
.759 .463 .484 r
.3288 .59882 m .33001 .59808 L .32846 .59743 L F
.33001 .59808 m .33038 .59785 L .32989 .59774 L F
.33001 .59808 m .32989 .59774 L .32846 .59743 L F
0 .108 .626 r
.33115 .60036 m .33095 .60071 L .33056 .59963 L F
.33095 .60071 m .32962 .60305 L .33056 .59963 L F
.32962 .60305 m .32957 .60314 L .32955 .6029 L F
.759 .463 .484 r
.32695 .59995 m .3288 .59882 L .32708 .59712 L F
.3288 .59882 m .32846 .59743 L .32708 .59712 L F
.915 .603 .122 r
.32775 .59444 m .3291 .59782 L .32898 .59469 L F
.32774 .59444 m .32777 .59449 L .32775 .59444 L F
.32777 .59449 m .3291 .59782 L .32775 .59444 L F
.32894 .59461 m .32898 .59469 L .32898 .59462 L F
.32774 .59444 m .32898 .59469 L .32894 .59461 L F
.678 .833 .958 r
.32891 .59455 m .32898 .59469 L .32905 .59457 L F
.746 .536 .61 r
.33055 .5925 m .32597 .59232 L .32621 .58944 L F
.758 .667 .115 r
.32844 .5923 m .3283 .59448 L .32868 .59153 L F
.819 .417 .287 r
.32868 .59153 m .3283 .59448 L .32891 .59446 L F
.757 .922 .944 r
.32895 .59446 m .3283 .59448 L .32844 .5923 L F
.32898 .59462 m .3283 .59448 L .32895 .59446 L F
.819 .417 .287 r
.32891 .59446 m .3283 .59448 L .32892 .59456 L F
.948 .748 .285 r
.32895 .59446 m .32894 .59449 L .32898 .59462 L F
.819 .417 .287 r
.32951 .59227 m .32892 .59456 L .33255 .59498 L F
.32868 .59153 m .32892 .59456 L .32951 .59227 L F
.948 .748 .285 r
.32844 .5923 m .32833 .59263 L .32894 .59449 L F
.32844 .5923 m .32894 .59449 L .32895 .59446 L F
.678 .833 .958 r
.3283 .59448 m .32896 .59469 L .32891 .59455 L F
.948 .748 .285 r
.32833 .59263 m .32774 .59444 L .32894 .59461 L F
.32833 .59263 m .32894 .59461 L .32898 .59462 L F
.678 .833 .958 r
.32896 .59469 m .32898 .59469 L .32894 .59461 L F
.32896 .59469 m .32894 .59461 L .32891 .59455 L F
.913 .55 .103 r
.32685 .59793 m .3264 .59791 L .32619 .5971 L F
.32685 .59793 m .32619 .5971 L .32564 .59501 L F
.022 .55 .857 r
.28383 .57999 m .28615 .58095 L .28314 .58045 L F
.765 .678 .767 r
.44694 .57221 m .44922 .57346 L .44519 .57305 L F
.763 .588 .661 r
.44922 .57346 m .44448 .57596 L .44519 .57305 L F
.44922 .57346 m .44895 .5763 L .44448 .57596 L F
.846 .8 .806 r
.44978 .56899 m .44922 .57346 L .44694 .57221 L F
.438 .076 .252 r
.25963 .52045 m .26216 .52024 L .26253 .51831 L F
.453 .129 .325 r
.26609 .5176 m .26309 .51915 L .26253 .51831 L F
.168 0 0 r
.26216 .52024 m .26609 .5176 L .26253 .51831 L F
.702 .982 .817 r
.35099 .5433 m .35008 .54431 L .35202 .54256 L F
.577 .619 .858 r
.34684 .54435 m .34885 .54567 L .35008 .54431 L F
.336 0 0 r
.34857 .54504 m .34684 .54435 L .35008 .54431 L F
.702 .982 .817 r
.34857 .54504 m .35008 .54431 L .35099 .5433 L F
.577 .619 .858 r
.34885 .54567 m .35108 .54712 L .35008 .54431 L F
.535 .611 .876 r
.35008 .54431 m .35108 .54712 L .35342 .54636 L F
.396 .188 .476 r
.35108 .54712 m .35312 .54851 L .35342 .54636 L F
.334 .208 .556 r
.35108 .54712 m .35129 .55022 L .35312 .54851 L F
.949 .926 .748 r
.39255 .48038 m .39395 .48155 L .39447 .47963 L F
.816 .513 .476 r
.39355 .48417 m .39395 .48155 L .39006 .48102 L F
.949 .926 .748 r
.39255 .48038 m .39447 .47963 L .393 .47771 L F
.751 .75 .852 r
.393 .47771 m .39687 .47834 L .39447 .47963 L F
.846 .95 .884 r
.39255 .48038 m .39395 .48155 L .39687 .47834 L F
.95 .689 .232 r
.57607 .37697 m .57539 .3759 L .57525 .37378 L F
.785 .284 0 r
.57909 .37945 m .57539 .3759 L .57607 .37697 L F
.836 .924 .891 r
.51402 .4044 m .51447 .40113 L .51579 .40208 L F
.51402 .4044 m .5114 .40413 L .51447 .40113 L F
.372 .583 .924 r
.60199 .42772 m .60066 .42972 L .59973 .42769 L F
0 0 .449 r
.60227 .43028 m .60066 .42972 L .60199 .42772 L F
.60227 .43028 m .60115 .43245 L .60066 .42972 L F
.298 .042 .348 r
.30762 .64172 m .30463 .64538 L .30685 .64469 L F
0 0 .122 r
.30838 .6413 m .30762 .64172 L .30685 .64469 L F
.502 .779 .994 r
.3259 .61381 m .32782 .61515 L .32526 .61563 L F
.729 .983 .905 r
.3259 .61381 m .32526 .61563 L .32396 .61538 L F
.502 .779 .994 r
.3259 .61381 m .32782 .61515 L .32526 .61563 L F
.694 .637 .788 r
.32782 .61515 m .32542 .61919 L .32526 .61563 L F
.251 .128 .511 r
.33004 .63081 m .32811 .62867 L .33018 .62772 L F
.824 .684 .709 r
.53691 .47333 m .53837 .47174 L .5376 .46851 L F
.902 .852 .784 r
.53691 .47333 m .53631 .47538 L .53837 .47174 L F
0 0 .01 r
.53837 .47174 m .53631 .47538 L .53765 .47437 L F
.642 .573 .761 r
.5376 .46851 m .53837 .47174 L .54142 .46878 L F
.549 .176 .286 r
.53765 .47437 m .54141 .47404 L .53837 .47174 L F
0 0 0 r
.43389 .55451 m .43322 .55509 L .43485 .55336 L F
.912 .51 .146 r
.43231 .54998 m .43389 .55451 L .43485 .55336 L F
.973 .805 .383 r
.40462 .57639 m .40356 .57786 L .40272 .57563 L F
.40462 .57639 m .40425 .57964 L .40356 .57786 L F
.555 .427 .66 r
.62595 .38715 m .62821 .38803 L .62627 .38194 L F
.608 .516 .724 r
.63092 .38347 m .62889 .38527 L .62627 .38194 L F
.635 .473 .646 r
.62627 .38194 m .62821 .38803 L .63092 .38347 L F
.452 .697 .972 r
.55024 .45655 m .5491 .4584 L .54752 .45723 L F
.43 .191 .449 r
.30901 .57318 m .30855 .57592 L .30633 .57644 L F
.709 .252 .166 r
.30733 .57536 m .30901 .57318 L .30405 .57256 L F
.545 .516 .775 r
.30901 .57318 m .31126 .57236 L .31082 .57047 L F
.998 .79 .448 r
.30733 .57536 m .30855 .57592 L .30878 .57454 L F
.30733 .57536 m .30878 .57454 L .30901 .57318 L F
.66 .347 .432 r
.30695 .57565 m .30733 .57536 L .30478 .57413 L F
.569 .903 .661 r
.30719 .57544 m .30733 .57536 L .30695 .57565 L F
0 0 0 r
.30901 .57381 m .30901 .57318 L .30733 .57536 L F
.569 .903 .661 r
.30901 .57381 m .30733 .57536 L .30719 .57544 L F
.506 .293 .525 r
.31126 .57236 m .30855 .57592 L .30901 .57318 L F
0 0 0 r
.30901 .57381 m .31126 .57236 L .30901 .57318 L F
.545 .516 .775 r
.30901 .57318 m .31126 .57236 L .31082 .57047 L F
.979 .767 .547 r
.24764 .62612 m .24923 .6254 L .24755 .62749 L F
.495 .332 .589 r
.25043 .62519 m .25074 .6248 L .2479 .62223 L F
.857 .997 .796 r
.2502 .62508 m .25054 .62505 L .25104 .62402 L F
.25054 .62505 m .25171 .62497 L .25118 .62423 L F
.25054 .62505 m .25118 .62423 L .25104 .62402 L F
.495 .332 .589 r
.24764 .62612 m .25043 .62519 L .2479 .62223 L F
.25043 .62519 m .25098 .62501 L .25074 .6248 L F
.24764 .62612 m .2479 .62223 L .24742 .6218 L F
.979 .767 .547 r
.24764 .62612 m .24755 .62749 L .24723 .62789 L F
.768 .286 0 r
.2432 .60424 m .24495 .60583 L .24347 .60416 L F
.03 0 0 r
.24764 .62612 m .24923 .6254 L .25171 .62497 L F
.24764 .62612 m .24923 .6254 L .25171 .62497 L F
.866 .911 .859 r
.36503 .63405 m .36952 .63187 L .3679 .63091 L F
.867 .965 .86 r
.36952 .63187 m .36992 .62928 L .3679 .63091 L F
.36952 .63187 m .37247 .62879 L .36992 .62928 L F
.331 0 0 r
.34822 .51773 m .34653 .51863 L .34415 .51796 L F
.277 .222 .613 r
.34867 .52052 m .35031 .51976 L .34822 .51773 L F
.679 .158 0 r
.34822 .51773 m .35031 .51976 L .34653 .51863 L F
.037 .362 .834 r
.26162 .62871 m .26401 .63194 L .26442 .63036 L F
.369 .677 .976 r
.42106 .53329 m .42488 .53509 L .42225 .53485 L F
0 0 0 r
.53763 .49044 m .53771 .49058 L .53582 .49141 L F
.53582 .49141 m .53771 .49058 L .53441 .49265 L F
.611 .924 .972 r
.31061 .53673 m .30907 .53633 L .30845 .53788 L F
.31061 .53673 m .30907 .53633 L .30845 .53788 L F
.488 .827 .999 r
.69503 .28859 m .69804 .28799 L .69928 .28903 L F
.317 .725 .978 r
.69804 .28799 m .70117 .28864 L .69928 .28903 L F
.979 .769 .354 r
.59436 .39977 m .59505 .40357 L .59365 .40227 L F
.948 .591 .234 r
.59505 .40357 m .59405 .40489 L .59365 .40227 L F
.59505 .40357 m .59561 .40625 L .59405 .40489 L F
.752 .711 .813 r
.53743 .41472 m .54354 .41429 L .54177 .41273 L F
.789 .291 0 r
.34541 .50084 m .34649 .50263 L .34754 .50164 L F
.807 .319 .006 r
.34754 .50164 m .34649 .50263 L .34848 .50354 L F
.74 .218 0 r
.3889 .52142 m .38786 .52216 L .38603 .51998 L F
.852 .394 .046 r
.3889 .52142 m .39012 .52376 L .38786 .52216 L F
.608 .76 .951 r
.34944 .52607 m .34677 .52754 L .34445 .52429 L F
.305 .784 .695 r
.34709 .52729 m .34677 .52754 L .34944 .52607 L F
.34709 .52729 m .34458 .52832 L .34677 .52754 L F
.327 0 .24 r
.66331 .3301 m .66066 .33135 L .66392 .32886 L F
.091 0 .11 r
.66549 .32853 m .66392 .32886 L .66598 .32734 L F
.66549 .32853 m .66331 .3301 L .66392 .32886 L F
.251 .274 .69 r
.22921 .5503 m .23012 .54607 L .22884 .54619 L F
.22921 .5503 m .23117 .54941 L .23012 .54607 L F
.157 0 .321 r
.22847 .55264 m .23117 .54941 L .22921 .5503 L F
.792 .717 .781 r
.35209 .537 m .348 .53676 L .35076 .53333 L F
.575 .001 0 r
.35076 .53333 m .35552 .53498 L .35209 .537 L F
.931 .966 .681 r
.42357 .51589 m .4237 .51832 L .42555 .51454 L F
.921 .932 .798 r
.42092 .5188 m .4237 .51832 L .42357 .51589 L F
.42092 .5188 m .42224 .51984 L .4237 .51832 L F
.621 .651 .858 r
.34845 .56585 m .34877 .56315 L .34876 .56322 L F
.773 .802 .877 r
.52013 .44125 m .52206 .44291 L .52462 .44042 L F
.802 .777 .83 r
.24785 .56296 m .2499 .56496 L .25064 .56327 L F
.457 .837 .988 r
.33239 .65441 m .33383 .65519 L .33628 .65452 L F
.33 0 0 r
.39514 .45412 m .39414 .45462 L .3983 .4542 L F
.557 .779 .982 r
.45144 .4623 m .4522 .46013 L .45143 .45946 L F
.45144 .4623 m .454 .46163 L .4522 .46013 L F
.494 .316 .568 r
.4539 .46416 m .454 .46163 L .45144 .4623 L F
.464 .735 .986 r
.27326 .64802 m .27592 .64987 L .27686 .64951 L F
.783 .93 .93 r
.4865 .42256 m .48299 .42321 L .48556 .42194 L F
.781 .951 .929 r
.48851 .41933 m .4865 .42256 L .48556 .42194 L F
.48851 .41933 m .48985 .42023 L .4865 .42256 L F
.549 0 0 r
.33946 .49789 m .34191 .49943 L .34352 .49878 L F
.72 .199 0 r
.34191 .49943 m .34541 .50084 L .34352 .49878 L F
.326 .233 .593 r
.24444 .54912 m .24242 .54767 L .24454 .54682 L F
.24444 .54912 m .24258 .55027 L .24242 .54767 L F
.102 0 0 r
.54154 .44711 m .53993 .44694 L .53928 .44827 L F
.54154 .44711 m .54311 .44598 L .53993 .44694 L F
.316 .581 .937 r
.41706 .51625 m .41674 .51818 L .41529 .51648 L F
0 0 .004 r
.32537 .58398 m .32508 .58301 L .32718 .58193 L F
.32537 .58398 m .32463 .58573 L .32508 .58301 L F
0 0 0 r
.58352 .35046 m .58237 .35069 L .58621 .35019 L F
.872 .624 .56 r
.68936 .3281 m .68618 .32743 L .68623 .32471 L F
.936 .712 .574 r
.68936 .3281 m .68649 .32984 L .68618 .32743 L F
.68936 .3281 m .6888 .33145 L .68649 .32984 L F
.921 .588 .394 r
.55867 .37959 m .5569 .37949 L .5584 .37713 L F
.531 .891 .976 r
.5584 .37713 m .55975 .37563 L .56163 .37603 L F
0 0 0 r
.5584 .37713 m .5569 .37949 L .55975 .37563 L F
.872 .789 .766 r
.31914 .62041 m .32266 .62187 L .31961 .62447 L F
.497 .464 .751 r
.30696 .52975 m .30938 .53059 L .30811 .52641 L F
.31 .046 .341 r
.31094 .61222 m .30793 .61612 L .31036 .61512 L F
.324 .057 .346 r
.31094 .61222 m .31036 .61512 L .3132 .61181 L F
.957 .645 .394 r
.39695 .53644 m .39497 .53284 L .39674 .5342 L F
.912 .977 .778 r
.68484 .33962 m .68701 .33875 L .68526 .34123 L F
.93 .964 .764 r
.68688 .33627 m .68701 .33875 L .68484 .33962 L F
.733 .865 .943 r
.72046 .27708 m .72217 .27607 L .71939 .27506 L F
0 0 .539 r
.4407 .57793 m .44013 .57953 L .43944 .57722 L F
.724 .871 .459 r
.4407 .57793 m .43813 .58247 L .44013 .57953 L F
.658 .181 0 r
.44215 .58184 m .44013 .57953 L .44048 .58103 L F
.735 .666 .782 r
.53157 .4754 m .53631 .47538 L .53691 .47333 L F
.788 .538 .559 r
.53174 .4774 m .53631 .47538 L .53157 .4754 L F
.53174 .4774 m .5359 .47806 L .53631 .47538 L F
0 0 .186 r
.53631 .47538 m .53731 .47601 L .53765 .47437 L F
.53631 .47538 m .5359 .47806 L .53731 .47601 L F
.309 .765 .953 r
.24878 .53927 m .25369 .53974 L .25029 .53873 L F
.905 .871 .793 r
.73221 .31265 m .73238 .30772 L .73034 .31071 L F
.73221 .31265 m .73252 .31139 L .73238 .30772 L F
.958 .798 .641 r
.73122 .31487 m .73221 .31265 L .73034 .31071 L F
.198 0 0 r
.61996 .39105 m .61961 .39085 L .61777 .39209 L F
.114 0 0 r
.62179 .39024 m .61961 .39085 L .61996 .39105 L F
.32 .134 .465 r
.52347 .41711 m .52612 .41626 L .52542 .41525 L F
.52347 .41711 m .52327 .41956 L .52612 .41626 L F
.81 .592 .608 r
.44464 .47883 m .44551 .48177 L .44087 .48082 L F
0 .084 .635 r
.44345 .47548 m .44555 .47858 L .44464 .47883 L F
0 0 .395 r
.44555 .47858 m .44679 .48084 L .44464 .47883 L F
.345 .316 .683 r
.44464 .47883 m .44679 .48084 L .44551 .48177 L F
.429 .8 .994 r
.28796 .58158 m .2876 .58303 L .28997 .58204 L F
0 .118 .669 r
.28796 .58158 m .28961 .58503 L .2876 .58303 L F
.486 .214 .426 r
.2876 .58303 m .28961 .58503 L .28706 .58537 L F
.841 .771 .784 r
.54454 .46617 m .54759 .4658 L .54462 .46101 L F
.797 .879 .907 r
.54386 .46691 m .54759 .4658 L .54454 .46617 L F
.413 .584 .911 r
.54462 .46101 m .54759 .4658 L .54894 .46402 L F
.924 .754 .653 r
.58444 .40317 m .58539 .40079 L .58303 .39908 L F
.511 .251 .456 r
.72994 .30568 m .73238 .30772 L .72998 .30792 L F
.616 .444 .627 r
.35374 .63533 m .35093 .63906 L .34972 .63507 L F
.209 0 .101 r
.52251 .50242 m .52096 .50107 L .52348 .50036 L F
.52251 .50242 m .52012 .50331 L .52096 .50107 L F
.711 .737 .871 r
.49954 .46293 m .50066 .45853 L .49758 .45924 L F
.49954 .46293 m .50222 .46213 L .50066 .45853 L F
.039 0 .474 r
.23624 .57196 m .23533 .57609 L .23482 .57635 L F
.25 .003 .331 r
.23533 .57609 m .23367 .57833 L .23482 .57635 L F
.71 .984 .812 r
.59463 .37863 m .59331 .38073 L .59605 .37836 L F
.385 .588 .923 r
.59463 .37863 m .5963 .38127 L .59331 .38073 L F
.271 .33 .741 r
.7245 .2981 m .72442 .30014 L .72725 .29978 L F
.23 .076 .456 r
.72442 .30014 m .72527 .30408 L .72725 .29978 L F
.749 .652 .754 r
.55433 .40337 m .55137 .40667 L .55103 .40379 L F
.803 .84 .376 r
.47813 .57803 m .47782 .58002 L .47914 .57614 L F
.837 .918 .523 r
.47647 .58241 m .47782 .58002 L .47813 .57803 L F
.489 .307 .561 r
.46589 .52769 m .46888 .52393 L .46577 .52705 L F
0 0 0 r
.33042 .62527 m .33196 .62155 L .33194 .62499 L F
.197 .252 .694 r
.33042 .62527 m .33292 .62743 L .33194 .62499 L F
.642 .495 .668 r
.33194 .62499 m .33018 .62772 L .33042 .62527 L F
.962 .86 .452 r
.37247 .62879 m .3724 .62439 L .37221 .62639 L F
.869 .964 .859 r
.36992 .62928 m .37247 .62879 L .37221 .62639 L F
.901 .884 .807 r
.46627 .54942 m .46803 .55091 L .46634 .55253 L F
.867 .836 .813 r
.46844 .54598 m .46803 .55091 L .46627 .54942 L F
.46844 .54598 m .47031 .54768 L .46803 .55091 L F
.763 .564 .629 r
.42173 .57543 m .42586 .57353 L .42278 .57338 L F
.42173 .57543 m .42485 .57608 L .42586 .57353 L F
.442 .219 .479 r
.42485 .57608 m .42719 .57534 L .42586 .57353 L F
0 0 .061 r
.48276 .56301 m .48266 .56519 L .48132 .56669 L F
.662 .758 .273 r
.48266 .56519 m .48098 .56933 L .48132 .56669 L F
.616 .444 .627 r
.35374 .63533 m .35353 .63816 L .35093 .63906 L F
.363 .401 .766 r
.44154 .57534 m .43944 .57722 L .4383 .57334 L F
0 0 .539 r
.4407 .57793 m .43944 .57722 L .44154 .57534 L F
.882 .991 .795 r
.63688 .40727 m .63948 .40392 L .63742 .40442 L F
.861 .983 .85 r
.63452 .40752 m .63688 .40727 L .63742 .40442 L F
0 0 0 r
.32059 .56622 m .32327 .56221 L .32059 .56339 L F
.969 .912 .699 r
.63004 .4148 m .63232 .41392 L .63065 .41204 L F
.63004 .4148 m .63108 .41603 L .63232 .41392 L F
.797 .594 .627 r
.5255 .3993 m .52957 .39997 L .52965 .39728 L F
.887 .973 .831 r
.3724 .62439 m .37688 .62121 L .37522 .6207 L F
.904 .887 .805 r
.37522 .6207 m .37688 .62121 L .37865 .61796 L F
.086 .38 .842 r
.55708 .42181 m .56161 .42301 L .55996 .42154 L F
.55708 .42181 m .56119 .42535 L .56161 .42301 L F
.212 .577 .942 r
.55996 .42154 m .56161 .42301 L .56394 .42242 L F
0 0 .031 r
.56394 .42242 m .56161 .42301 L .56119 .42535 L F
.382 .778 .987 r
.50786 .47122 m .50874 .46702 L .50723 .46792 L F
.50786 .47122 m .5088 .46995 L .50874 .46702 L F
.50786 .47122 m .50992 .471 L .5088 .46995 L F
.694 .637 .788 r
.32782 .61515 m .32988 .61906 L .32542 .61919 L F
.692 .515 .644 r
.32542 .61919 m .32845 .6213 L .32492 .62157 L F
.32542 .61919 m .32988 .61906 L .32845 .6213 L F
0 0 0 r
.66066 .33135 m .65916 .33231 L .65656 .33318 L F
.077 0 0 r
.66331 .3301 m .65916 .33231 L .66066 .33135 L F
.079 0 .257 r
.48509 .52432 m .48748 .52295 L .48715 .52064 L F
.257 .111 .483 r
.48715 .52064 m .49034 .51905 L .48976 .51676 L F
.143 0 .259 r
.48715 .52064 m .48748 .52295 L .49034 .51905 L F
.732 .615 .727 r
.60517 .39082 m .6096 .38707 L .60641 .38956 L F
.125 0 .177 r
.50897 .5133 m .50702 .5145 L .5098 .51131 L F
.057 0 .134 r
.50897 .5133 m .50617 .5168 L .50702 .5145 L F
.477 .305 .568 r
.35923 .58908 m .35686 .59229 L .35684 .5895 L F
.35923 .58908 m .35686 .59229 L .35684 .5895 L F
.437 .203 .46 r
.34255 .58629 m .34256 .58894 L .34496 .58602 L F
.861 .74 .727 r
.73352 .30485 m .73661 .30568 L .73545 .30169 L F
.935 .805 .692 r
.73352 .30485 m .73456 .30893 L .73661 .30568 L F
.713 .603 .731 r
.55666 .4006 m .55733 .40318 L .55433 .40337 L F
.385 0 0 r
.55666 .4006 m .55981 .40136 L .55733 .40318 L F
.919 .975 .765 r
.68526 .34123 m .68442 .34258 L .68133 .34481 L F
.676 .658 .825 r
.54023 .40598 m .53954 .41096 L .53785 .4094 L F
.54023 .40598 m .54329 .41076 L .53954 .41096 L F
.607 .949 .799 r
.27104 .51861 m .2701 .52003 L .27306 .51757 L F
.414 .168 .43 r
.49637 .50526 m .49751 .5071 L .49773 .50424 L F
.49637 .50526 m .49512 .50847 L .49751 .5071 L F
.802 .319 .059 r
.46996 .53814 m .47334 .54015 L .47116 .53728 L F
.65 .358 .462 r
.47116 .53728 m .47334 .54015 L .47312 .53714 L F
0 0 .024 r
.51172 .51004 m .5098 .51131 L .51264 .50826 L F
.169 0 .183 r
.51466 .50694 m .51172 .51004 L .51264 .50826 L F
.794 .999 .814 r
.67438 .36331 m .67056 .36602 L .67437 .36342 L F
0 0 0 r
.67438 .36331 m .67437 .36342 L .67559 .36161 L F
.822 .962 .9 r
.44741 .58522 m .44355 .58696 L .44652 .58613 L F
.056 0 .366 r
.44809 .58343 m .44741 .58522 L .44949 .58492 L F
0 0 0 r
.44949 .58492 m .44741 .58522 L .44652 .58613 L F
.508 .032 .059 r
.46453 .53207 m .46408 .52996 L .46398 .53295 L F
.698 .618 .764 r
.50367 .46622 m .50477 .46149 L .50222 .46213 L F
.50367 .46622 m .50636 .46535 L .50477 .46149 L F
.732 .615 .727 r
.60517 .39082 m .60986 .39084 L .6096 .38707 L F
.238 0 0 r
.60638 .39123 m .60986 .39084 L .60517 .39082 L F
.844 .815 .821 r
.60986 .39084 m .61075 .38632 L .6096 .38707 L F
.238 0 0 r
.60638 .39123 m .60517 .39082 L .60519 .39284 L F
.736 .283 .175 r
.60638 .39123 m .60825 .39177 L .60986 .39084 L F
.682 .174 .026 r
.61076 .39415 m .61221 .39293 L .60825 .39177 L F
.60723 .3918 m .60825 .39177 L .60638 .39123 L F
.61076 .39415 m .60825 .39177 L .60723 .3918 L F
.722 .617 .739 r
.60553 .39565 m .60638 .39123 L .60519 .39284 L F
.60605 .39295 m .60828 .395 L .60638 .39123 L F
.60553 .39565 m .60692 .39532 L .60605 .39295 L F
.60692 .39532 m .60828 .395 L .60605 .39295 L F
.232 .323 .752 r
.60478 .38951 m .60519 .39284 L .60421 .38906 L F
.682 .174 .026 r
.61076 .39415 m .60638 .39123 L .60828 .395 L F
.232 .323 .752 r
.6071 .39134 m .60582 .39234 L .60478 .38951 L F
.60582 .39234 m .60519 .39284 L .60478 .38951 L F
.523 .905 .949 r
.60565 .39192 m .60641 .39188 L .60649 .39181 L F
.60589 .39183 m .60649 .39181 L .6071 .39134 L F
.60565 .39192 m .60649 .39181 L .60589 .39183 L F
.60439 .39244 m .60519 .39284 L .60641 .39188 L F
.60439 .39244 m .60641 .39188 L .60565 .39192 L F
.736 .283 .175 r
.60825 .39177 m .61221 .39293 L .61075 .39163 L F
.60825 .39177 m .61075 .39163 L .60986 .39084 L F
.36 .833 .843 r
.6343 .33754 m .63163 .33843 L .62997 .33839 L F
.96 .677 .243 r
.59411 .3969 m .5933 .39839 L .59207 .3959 L F
.59411 .3969 m .59436 .39977 L .5933 .39839 L F
.718 .293 0 r
.43461 .5591 m .43559 .56009 L .43352 .55694 L F
0 0 .187 r
.4363 .56113 m .43559 .56009 L .43461 .5591 L F
.4363 .56113 m .43556 .56288 L .43559 .56009 L F
.454 .121 .31 r
.54332 .4517 m .54369 .44964 L .54608 .45095 L F
.582 .513 .742 r
.54643 .44883 m .54369 .44964 L .54311 .44598 L F
.435 .141 .366 r
.54608 .45095 m .54369 .44964 L .54643 .44883 L F
.433 .871 .899 r
.52969 .45033 m .5265 .45096 L .5289 .45045 L F
.235 0 0 r
.53283 .45117 m .52969 .45033 L .5289 .45045 L F
.042 0 .117 r
.51172 .51004 m .50897 .5133 L .5098 .51131 L F
.934 .562 .263 r
.38603 .51998 m .38367 .51661 L .38559 .51763 L F
.877 .533 .394 r
.35625 .51252 m .35914 .51146 L .35569 .51041 L F
.35625 .51252 m .35955 .51378 L .35914 .51146 L F
.489 .307 .561 r
.46589 .52769 m .46909 .52689 L .46888 .52393 L F
.889 .954 .84 r
.60152 .42006 m .60304 .42212 L .60194 .42241 L F
.919 .975 .765 r
.68526 .34123 m .68133 .34481 L .68484 .33962 L F
0 0 .501 r
.44656 .59602 m .44769 .59737 L .44742 .59675 L F
.44656 .59602 m .44742 .59675 L .44511 .59668 L F
.589 .606 .837 r
.54332 .4517 m .54416 .45487 L .54191 .45494 L F
.435 0 .06 r
.54191 .45494 m .54341 .45663 L .54108 .45803 L F
.54191 .45494 m .54416 .45487 L .54341 .45663 L F
.498 .71 .966 r
.32554 .52451 m .32604 .52189 L .32359 .52008 L F
.32554 .52451 m .32824 .52381 L .32604 .52189 L F
.344 .074 .352 r
.32554 .52451 m .3251 .52669 L .32824 .52381 L F
.32824 .52381 m .3251 .52669 L .32554 .52451 L F
.01 .576 .793 r
.56952 .38165 m .57255 .38182 L .57308 .38212 L F
0 .43 .732 r
.57255 .38182 m .57595 .38293 L .57308 .38212 L F
.378 .716 .988 r
.23427 .57047 m .23532 .57263 L .23161 .56898 L F
.23427 .57047 m .23624 .57196 L .23532 .57263 L F
.76 .609 .69 r
.55351 .40032 m .55433 .40337 L .55103 .40379 L F
.713 .603 .731 r
.55666 .4006 m .55433 .40337 L .55351 .40032 L F
.459 .802 .999 r
.35201 .5208 m .35031 .51976 L .34867 .52052 L F
.365 .752 .988 r
.35201 .5208 m .3543 .52062 L .35031 .51976 L F
.899 .841 .778 r
.55351 .40032 m .54957 .40248 L .54945 .39977 L F
.55351 .40032 m .55103 .40379 L .54957 .40248 L F
.847 .838 .836 r
.46844 .54598 m .47096 .54558 L .47031 .54768 L F
.9 .827 .766 r
.43298 .54225 m .43461 .54314 L .43388 .54038 L F
.926 .793 .694 r
.43129 .54568 m .43461 .54314 L .43298 .54225 L F
.43129 .54568 m .43336 .54734 L .43461 .54314 L F
.691 .725 .876 r
.43461 .54314 m .43623 .5393 L .43388 .54038 L F
.43461 .54314 m .43755 .54185 L .43623 .5393 L F
.93 .708 .581 r
.32621 .58944 m .32597 .59232 L .32364 .59119 L F
.022 .241 .745 r
.32695 .58779 m .32621 .58944 L .32364 .59119 L F
.746 .536 .61 r
.33055 .5925 m .32878 .59126 L .32868 .59153 L F
.32878 .59126 m .32621 .58944 L .32868 .59153 L F
0 .064 .628 r
.3288 .58971 m .32868 .59153 L .32695 .58779 L F
.758 .667 .115 r
.32847 .59207 m .32868 .59153 L .3288 .58971 L F
.32844 .5923 m .32868 .59153 L .32847 .59207 L F
.022 .241 .745 r
.32695 .58779 m .32868 .59153 L .32621 .58944 L F
.711 .59 .72 r
.24992 .58286 m .24732 .58617 L .24984 .58597 L F
.767 .599 .671 r
.567 .43301 m .56737 .43613 L .56478 .43502 L F
.926 .687 .199 r
.567 .43301 m .56713 .43414 L .56668 .43497 L F
.56713 .43414 m .56737 .43613 L .56668 .43497 L F
.773 .341 .224 r
.56737 .43613 m .56722 .43797 L .56478 .43502 L F
.29 .288 .685 r
.56478 .43502 m .56722 .43797 L .56668 .43497 L F
.882 .693 .643 r
.56668 .43497 m .56722 .43797 L .5656 .43684 L F
.56668 .43497 m .56722 .43797 L .5656 .43684 L F
0 0 0 r
.5665 .43531 m .56668 .43497 L .5656 .43684 L F
.56752 .43358 m .56668 .43497 L .5665 .43531 L F
.654 .277 .319 r
.5677 .4331 m .56794 .43273 L .56795 .43351 L F
.125 .663 .85 r
.56763 .43338 m .567 .43301 L .56668 .43497 L F
.23 0 .125 r
.56478 .43502 m .56668 .43497 L .567 .43301 L F
.7 .288 .261 r
.56485 .43312 m .56498 .4325 L .5674 .43332 L F
.56697 .4333 m .5674 .43332 L .56745 .43334 L F
.56485 .43312 m .5674 .43332 L .56697 .4333 L F
.56485 .43312 m .56745 .43334 L .56648 .43328 L F
.125 .663 .85 r
.56777 .43272 m .56974 .43302 L .567 .43301 L F
.56777 .43272 m .567 .43301 L .5677 .4331 L F
.7 .288 .261 r
.56498 .4325 m .56744 .4327 L .5677 .4331 L F
.56764 .4334 m .5677 .4331 L .56795 .43351 L F
.125 .663 .85 r
.5677 .4331 m .567 .43301 L .56763 .43338 L F
.7 .288 .261 r
.56498 .4325 m .5677 .4331 L .56764 .4334 L F
.125 .663 .85 r
.56779 .43272 m .56777 .43272 L .5677 .4331 L F
.56779 .43272 m .5679 .43273 L .56777 .43272 L F
.56809 .4326 m .56779 .43272 L .56763 .43338 L F
.654 .277 .319 r
.56556 .42975 m .56851 .42966 L .5677 .4331 L F
.125 .663 .85 r
.5679 .43273 m .56974 .43302 L .56777 .43272 L F
.56834 .43275 m .56974 .43302 L .56779 .43272 L F
.961 .689 .475 r
.56834 .43275 m .56992 .42962 L .56974 .43302 L F
.125 .663 .85 r
.56876 .43277 m .56974 .43302 L .56834 .43275 L F
.961 .689 .475 r
.56795 .43351 m .56834 .43275 L .56974 .43302 L F
.654 .277 .319 r
.56851 .42966 m .56992 .42962 L .5677 .4331 L F
.733 .783 .893 r
.56809 .4326 m .56765 .43335 L .56587 .43325 L F
.7 .288 .261 r
.56485 .43312 m .56578 .43324 L .56595 .43296 L F
.733 .783 .893 r
.56595 .43296 m .56587 .43325 L .56465 .43318 L F
.56809 .4326 m .56587 .43325 L .56595 .43296 L F
.7 .288 .261 r
.56498 .4325 m .56556 .42975 L .56744 .4327 L F
.56626 .4318 m .56595 .43296 L .56723 .43089 L F
.56485 .43312 m .56595 .43296 L .56626 .4318 L F
.73 .792 .902 r
.56723 .43089 m .56809 .4326 L .56595 .43296 L F
.733 .783 .893 r
.56765 .43335 m .56668 .43497 L .56465 .43318 L F
.7 .288 .261 r
.56648 .43328 m .56745 .43334 L .56762 .4334 L F
.56485 .43312 m .56762 .4334 L .56759 .43346 L F
.56578 .43324 m .56759 .43346 L .56753 .43309 L F
.56578 .43324 m .56753 .43309 L .56595 .43296 L F
.733 .783 .893 r
.56465 .43318 m .56668 .43497 L .56428 .43324 L F
.743 .659 .767 r
.56595 .43296 m .5656 .43684 L .56428 .43324 L F
0 0 0 r
.56809 .4326 m .56759 .43346 L .56779 .43311 L F
.743 .659 .767 r
.56809 .4326 m .56779 .43311 L .56595 .43296 L F
0 0 0 r
.56809 .4326 m .56765 .43335 L .56759 .43346 L F
.7 .288 .261 r
.56759 .43346 m .56783 .43305 L .56723 .43089 L F
.56759 .43346 m .56762 .4334 L .56795 .43351 L F
.56759 .43346 m .56795 .43351 L .56783 .43305 L F
0 0 0 r
.56779 .43311 m .56759 .43346 L .56752 .43358 L F
.56765 .43335 m .56668 .43497 L .56752 .43358 L F
.743 .659 .767 r
.56779 .43311 m .5656 .43684 L .56595 .43296 L F
.7 .288 .261 r
.56595 .43296 m .56753 .43309 L .56723 .43089 L F
0 .118 .67 r
.56156 .42917 m .56485 .43312 L .56321 .42967 L F
.695 .74 .886 r
.56321 .42967 m .56485 .43312 L .56723 .43089 L F
.73 .792 .902 r
.56723 .43089 m .56595 .43296 L .56465 .43318 L F
.56438 .43317 m .56465 .43318 L .56428 .43324 L F
.56723 .43089 m .56465 .43318 L .56438 .43317 L F
.654 .277 .319 r
.56794 .43273 m .56992 .42962 L .56834 .43275 L F
.125 .663 .85 r
.56809 .4326 m .56876 .43277 L .56779 .43272 L F
.654 .277 .319 r
.56794 .43273 m .56834 .43275 L .56795 .43351 L F
.769 .718 .805 r
.61028 .44523 m .61111 .44796 L .60791 .44929 L F
.307 0 .005 r
.60791 .44929 m .61111 .44796 L .60973 .45011 L F
.169 .632 .934 r
.61336 .44762 m .61111 .44796 L .61028 .44523 L F
.61336 .44762 m .61429 .44849 L .61111 .44796 L F
.61111 .44796 m .61429 .44849 L .61336 .44762 L F
.61111 .44796 m .61336 .44762 L .60973 .45011 L F
.584 .418 .623 r
.47312 .53714 m .47662 .53654 L .47754 .53252 L F
.321 .009 .271 r
.47334 .54015 m .47662 .53654 L .47312 .53714 L F
0 0 0 r
.67389 .38013 m .67767 .37798 L .67666 .37912 L F
.67666 .37912 m .67767 .37798 L .68038 .37695 L F
.897 .589 .455 r
.36544 .52036 m .36516 .52298 L .36874 .52419 L F
.865 .59 .52 r
.36247 .52321 m .36877 .52699 L .36874 .52419 L F
.874 .495 .321 r
.36247 .52321 m .36908 .52934 L .36877 .52699 L F
.433 .255 .538 r
.36261 .5228 m .36247 .52321 L .36516 .52298 L F
.874 .495 .321 r
.36247 .52321 m .3668 .5287 L .36908 .52934 L F
.895 .538 .359 r
.36338 .52493 m .3668 .5287 L .36247 .52321 L F
.433 .255 .538 r
.36261 .5228 m .36338 .52493 L .36247 .52321 L F
.937 .616 .404 r
.36093 .52143 m .36338 .52493 L .36268 .52297 L F
.36178 .52212 m .36268 .52297 L .36261 .5228 L F
.36093 .52143 m .36268 .52297 L .36178 .52212 L F
.865 .59 .52 r
.36289 .52317 m .36874 .52419 L .36516 .52298 L F
.36247 .52321 m .36302 .5233 L .36289 .52317 L F
.36302 .5233 m .36874 .52419 L .36289 .52317 L F
.489 .199 .4 r
.63149 .35441 m .6345 .35374 L .63474 .35151 L F
.726 .955 .948 r
.63746 .34926 m .63474 .35151 L .63574 .34907 L F
.63746 .34926 m .63474 .35151 L .63574 .34907 L F
.205 0 .325 r
.63474 .35151 m .6345 .35374 L .63746 .34926 L F
.073 0 0 r
.52071 .46882 m .51782 .47124 L .51931 .46964 L F
0 0 0 r
.52313 .46751 m .52071 .46882 L .51931 .46964 L F
.805 .677 .722 r
.62225 .39027 m .62584 .38915 L .62591 .38779 L F
.62347 .38924 m .62591 .38779 L .62595 .38715 L F
.62225 .39027 m .62591 .38779 L .62347 .38924 L F
.507 .843 .997 r
.62116 .39061 m .62179 .39024 L .61996 .39105 L F
.805 .677 .722 r
.62179 .39024 m .62225 .39027 L .62595 .38715 L F
.62225 .39027 m .62577 .39053 L .62584 .38915 L F
.507 .843 .997 r
.62482 .38929 m .62577 .39053 L .62179 .39024 L F
.62482 .38929 m .62179 .39024 L .62116 .39061 L F
.314 .8 .758 r
.62286 .38972 m .62482 .38929 L .62116 .39061 L F
.62037 .39086 m .62116 .39061 L .61996 .39105 L F
.62286 .38972 m .62116 .39061 L .62037 .39086 L F
0 0 0 r
.62294 .39342 m .62577 .39053 L .62576 .39322 L F
0 0 .306 r
.62595 .38715 m .62577 .39053 L .62693 .38762 L F
.727 .951 .95 r
.62693 .38762 m .62577 .39053 L .62482 .38929 L F
.699 .582 .721 r
.62899 .38898 m .62576 .39322 L .62577 .39053 L F
.971 .662 .363 r
.44448 .57596 m .44625 .57943 L .44473 .57867 L F
.754 .668 .766 r
.44448 .57596 m .44895 .5763 L .44625 .57943 L F
.991 .77 .507 r
.40918 .50147 m .40916 .5044 L .40759 .50316 L F
.40918 .50147 m .40916 .5044 L .40759 .50316 L F
.931 .733 .615 r
.59655 .41273 m .59806 .41656 L .59611 .41544 L F
.645 .095 0 r
.5994 .41825 m .59806 .41656 L .60152 .42006 L F
.889 .954 .84 r
.60152 .42006 m .60194 .42241 L .60119 .42073 L F
.99 .729 .399 r
.60111 .41761 m .60233 .42004 L .60169 .41646 L F
.217 .442 .864 r
.60179 .41896 m .60149 .41985 L .60264 .42065 L F
.60149 .41985 m .60192 .42019 L .60199 .42024 L F
.60202 .42022 m .60199 .42024 L .60324 .42107 L F
.60149 .41985 m .60199 .42024 L .60202 .42022 L F
.065 .116 .606 r
.60152 .42006 m .60119 .42073 L .60198 .42024 L F
.217 .442 .864 r
.60147 .4199 m .60119 .42073 L .60264 .42097 L F
.065 .116 .606 r
.60198 .42024 m .60119 .42073 L .6024 .42041 L F
.117 .324 .793 r
.6024 .42041 m .60195 .42053 L .60192 .41926 L F
.99 .729 .399 r
.60222 .41998 m .60233 .42004 L .60179 .41896 L F
.217 .442 .864 r
.6019 .41862 m .60179 .41896 L .60217 .41952 L F
.60179 .41896 m .60264 .42065 L .60324 .42107 L F
.117 .324 .793 r
.6024 .42041 m .60192 .41926 L .6019 .41862 L F
.6019 .4201 m .60149 .41985 L .60179 .41896 L F
.065 .116 .606 r
.60149 .41985 m .6024 .42041 L .60088 .41936 L F
.60198 .42024 m .6024 .42041 L .60149 .41985 L F
.117 .324 .793 r
.60195 .42053 m .60142 .42005 L .60149 .41985 L F
.065 .116 .606 r
.60152 .42006 m .60198 .42024 L .60088 .41936 L F
.217 .442 .864 r
.60149 .41985 m .60147 .4199 L .60192 .42019 L F
.60147 .4199 m .60264 .42097 L .60324 .42107 L F
.117 .324 .793 r
.60195 .42053 m .60149 .41985 L .6019 .4201 L F
.60192 .41926 m .60179 .41896 L .6019 .41862 L F
.60195 .42053 m .60179 .41896 L .60192 .41926 L F
.99 .729 .399 r
.60222 .41998 m .6024 .42041 L .60233 .42004 L F
.065 .116 .606 r
.60088 .41936 m .6024 .42041 L .59993 .4183 L F
.99 .729 .399 r
.60199 .41987 m .6024 .42041 L .60222 .41998 L F
.645 .095 0 r
.59611 .41544 m .59651 .41567 L .5994 .41825 L F
.59611 .41544 m .60152 .42006 L .60088 .41936 L F
.59651 .41567 m .59806 .41656 L .5994 .41825 L F
.59611 .41544 m .60088 .41936 L .5989 .41753 L F
.117 .324 .793 r
.60195 .42053 m .60119 .42073 L .60142 .42005 L F
.142 .428 .868 r
.59993 .4183 m .60119 .42073 L .6024 .42041 L F
.573 .034 0 r
.59993 .4183 m .60131 .41948 L .60036 .41909 L F
.60131 .41948 m .6024 .42041 L .60119 .41963 L F
.60131 .41948 m .60119 .41963 L .60036 .41909 L F
.99 .729 .399 r
.60036 .41909 m .60222 .41998 L .60111 .41761 L F
.60036 .41909 m .6024 .42041 L .60199 .41987 L F
.60222 .41998 m .60179 .41896 L .60111 .41761 L F
.645 .095 0 r
.5989 .41753 m .60088 .41936 L .59993 .4183 L F
.99 .729 .399 r
.60036 .41909 m .60169 .41646 L .6019 .41862 L F
.60036 .41909 m .6019 .41862 L .60047 .41781 L F
.995 .76 .419 r
.60047 .41781 m .6019 .41862 L .60059 .42047 L F
.589 .81 .411 r
.60108 .41977 m .6019 .41862 L .6016 .41903 L F
.60059 .42047 m .60114 .4197 L .60108 .41977 L F
.60114 .4197 m .6019 .41862 L .60108 .41977 L F
.117 .324 .793 r
.60204 .41843 m .6019 .41862 L .60169 .41646 L F
.459 0 0 r
.60487 .41833 m .60169 .41646 L .6019 .41862 L F
.886 .784 .743 r
.60354 .41719 m .60268 .41418 L .60169 .41646 L F
.459 0 0 r
.60487 .41833 m .60354 .41719 L .60169 .41646 L F
.959 .947 .681 r
.60085 .41488 m .60169 .41646 L .60268 .41418 L F
.884 .613 .094 r
.6019 .41862 m .60169 .41646 L .60085 .41488 L F
.6019 .41862 m .60085 .41488 L .60267 .41749 L F
.589 .81 .411 r
.6016 .41903 m .6019 .41862 L .60267 .41749 L F
.117 .324 .793 r
.60233 .42004 m .6019 .41862 L .60204 .41843 L F
.6024 .42041 m .6019 .41862 L .60233 .42004 L F
.217 .442 .864 r
.6019 .41862 m .60217 .41952 L .60324 .42107 L F
.735 .89 .494 r
.64052 .40154 m .63948 .40392 L .64168 .40023 L F
.785 .999 .831 r
.63742 .40442 m .63948 .40392 L .64052 .40154 L F
.559 .866 .567 r
.66782 .31591 m .66481 .31888 L .66654 .3171 L F
0 0 0 r
.66481 .31888 m .66577 .31858 L .66654 .3171 L F
.66481 .31888 m .66385 .31999 L .66577 .31858 L F
.64361 .39883 m .64168 .40023 L .64356 .39875 L F
.64052 .40154 m .64168 .40023 L .64361 .39883 L F
.612 .383 .545 r
.31085 .5851 m .31394 .58237 L .31116 .58283 L F
.805 .561 .57 r
.60428 .44581 m .60396 .44889 L .60119 .44758 L F
.499 .483 .77 r
.60686 .44434 m .60428 .44581 L .60328 .44345 L F
.78 .664 .735 r
.60789 .44666 m .60428 .44581 L .60686 .44434 L F
.60789 .44666 m .60396 .44889 L .60428 .44581 L F
.931 .964 .67 r
.35777 .60408 m .35976 .60266 L .35851 .60237 L F
.544 .838 .999 r
.36064 .60099 m .35976 .60266 L .36305 .60218 L F
.669 .964 .931 r
.36064 .60099 m .35851 .60237 L .35976 .60266 L F
.431 .453 .782 r
.35976 .60266 m .36283 .60511 L .36305 .60218 L F
.04 .017 .501 r
.22768 .57235 m .22911 .57494 L .22884 .57256 L F
0 0 0 r
.64909 .32824 m .65182 .3274 L .65299 .32647 L F
.014 0 0 r
.65182 .3274 m .65561 .32531 L .65299 .32647 L F
0 0 0 r
.61861 .37266 m .61511 .37401 L .61526 .37319 L F
.448 .213 .463 r
.30633 .57644 m .30602 .5792 L .30357 .57985 L F
.376 .153 .442 r
.30829 .57839 m .30633 .57644 L .30855 .57592 L F
.30829 .57839 m .30602 .5792 L .30633 .57644 L F
.791 .603 .648 r
.73723 .29813 m .73782 .29583 L .7339 .29529 L F
.742 .569 .66 r
.27686 .64951 m .28019 .64684 L .27613 .64538 L F
.247 .621 .958 r
.27686 .64951 m .28152 .65125 L .28019 .64684 L F
.597 .46 .665 r
.28019 .64684 m .28152 .65125 L .28384 .64817 L F
.303 .274 .66 r
.32313 .57854 m .32451 .57861 L .32438 .57828 L F
.662 .899 .559 r
.32286 .5759 m .32022 .57913 L .32313 .57854 L F
.303 .274 .66 r
.32313 .57854 m .32257 .57362 L .32286 .5759 L F
.32313 .57854 m .32438 .57828 L .32257 .57362 L F
.662 .899 .559 r
.32022 .57913 m .32005 .57933 L .32313 .57854 L F
.956 .7 .509 r
.40428 .55294 m .40173 .55492 L .40229 .55199 L F
.40428 .55294 m .40402 .5566 L .40173 .55492 L F
.165 0 0 r
.60886 .34443 m .61164 .34431 L .61287 .34392 L F
.272 0 0 r
.61287 .34392 m .61164 .34431 L .61547 .34398 L F
.837 .423 .254 r
.34684 .54435 m .34514 .54556 L .3442 .54355 L F
.336 0 0 r
.34857 .54504 m .34514 .54556 L .34684 .54435 L F
.872 .995 .782 r
.43052 .56746 m .42884 .56965 L .42832 .56847 L F
0 0 .374 r
.42795 .56761 m .42832 .56847 L .42954 .57064 L F
.986 .901 .603 r
.42908 .56616 m .42832 .56847 L .42763 .56701 L F
0 0 .374 r
.42763 .56701 m .42832 .56847 L .42795 .56761 L F
.872 .995 .782 r
.42884 .56965 m .42868 .56984 L .42832 .56847 L F
0 0 .145 r
.42868 .56984 m .42928 .57161 L .42832 .56847 L F
.42868 .56984 m .42843 .57309 L .42928 .57161 L F
.867 .594 .523 r
.70899 .30189 m .71249 .30537 L .71302 .30296 L F
.70899 .30189 m .70899 .30454 L .71249 .30537 L F
.923 .895 .784 r
.70899 .30726 m .71249 .30537 L .70899 .30454 L F
.70899 .30726 m .71006 .30869 L .71249 .30537 L F
.553 .604 .859 r
.49425 .4583 m .49496 .46002 L .49758 .45924 L F
.607 .949 .799 r
.27104 .51861 m .27306 .51757 L .27126 .51651 L F
.826 .895 .89 r
.27306 .51757 m .27395 .51378 L .27581 .51517 L F
.27306 .51757 m .27126 .51651 L .27395 .51378 L F
.603 .27 .378 r
.27581 .51517 m .27126 .51651 L .27306 .51757 L F
0 0 .376 r
.42053 .52898 m .42056 .53014 L .4177 .52697 L F
.897 .878 .808 r
.41628 .50561 m .41746 .50877 L .4201 .50483 L F
.375 0 .193 r
.3368 .5384 m .34072 .53639 L .33833 .5371 L F
.744 .983 .908 r
.59407 .34703 m .59278 .34793 L .5939 .34555 L F
.77 .996 .813 r
.59278 .34793 m .5923 .34744 L .5939 .34555 L F
.751 .908 .946 r
.32599 .65472 m .32758 .65585 L .32963 .65432 L F
.89 .846 .794 r
.53392 .43601 m .52986 .4381 L .53246 .43744 L F
.495 .519 .811 r
.53719 .43879 m .53392 .43601 L .53687 .43504 L F
.075 0 0 r
.53511 .43665 m .53392 .43601 L .53246 .43744 L F
.53511 .43665 m .53687 .43504 L .53392 .43601 L F
.902 .528 .313 r
.34848 .50354 m .34978 .50657 L .35131 .50524 L F
.738 .274 .148 r
.35131 .50524 m .34978 .50657 L .35225 .50658 L F
0 0 .386 r
.41624 .50574 m .41746 .50877 L .41628 .50561 L F
.935 .805 .692 r
.73352 .30485 m .73238 .30772 L .73456 .30893 L F
.878 .854 .814 r
.73238 .30772 m .73252 .31139 L .73456 .30893 L F
.726 .968 .936 r
.6154 .42339 m .6187 .42232 L .61839 .42229 L F
0 0 .001 r
.62072 .41802 m .62013 .42028 L .6187 .42232 L F
.642 .907 .598 r
.62013 .42028 m .61839 .42229 L .6187 .42232 L F
.676 .551 .705 r
.42339 .4726 m .42353 .47521 L .42617 .47197 L F
0 0 0 r
.47813 .57803 m .47914 .57614 L .4802 .57446 L F
.528 .916 .796 r
.59973 .38022 m .60122 .37878 L .60205 .37872 L F
.521 .918 .873 r
.59973 .38022 m .59692 .38066 L .60122 .37878 L F
.391 .12 .378 r
.54647 .43248 m .5429 .43382 L .54322 .43525 L F
.024 .434 .867 r
.67538 .3559 m .67668 .35291 L .67692 .35209 L F
.581 .614 .85 r
.33238 .55663 m .33688 .55976 L .33486 .559 L F
.109 .653 .839 r
.33498 .55543 m .33732 .55542 L .33916 .55573 L F
.34 .408 .786 r
.33688 .55976 m .33732 .55542 L .33486 .559 L F
.33688 .55976 m .33882 .55951 L .33732 .55542 L F
.428 .369 .689 r
.33713 .5629 m .33882 .55951 L .33688 .55976 L F
.877 .644 .119 r
.59556 .43168 m .59641 .43645 L .5949 .43526 L F
.975 .835 .64 r
.5949 .43526 m .59641 .43645 L .59553 .43901 L F
.842 .532 .463 r
.59641 .43645 m .59922 .43945 L .59553 .43901 L F
.997 .85 .524 r
.31741 .5339 m .31649 .53695 L .31567 .5356 L F
.886 .932 .844 r
.31567 .5356 m .31988 .53332 L .31741 .5339 L F
.458 0 0 r
.58643 .36822 m .58814 .36844 L .59083 .36778 L F
.839 .983 .871 r
.59083 .36778 m .58814 .36844 L .59155 .3649 L F
.64 .948 .731 r
.52824 .43119 m .53252 .42813 L .53197 .42899 L F
.52824 .43119 m .53197 .42899 L .52987 .43072 L F
.527 .508 .779 r
.52519 .42959 m .52568 .43204 L .52824 .43119 L F
.56 .749 .965 r
.52824 .43119 m .52568 .43204 L .52408 .43063 L F
.162 0 .29 r
.52741 .43363 m .52568 .43204 L .52824 .43119 L F
.466 .388 .685 r
.52439 .42575 m .52519 .42959 L .52733 .42847 L F
.527 .508 .779 r
.52519 .42959 m .52824 .43119 L .52733 .42847 L F
.56 .749 .965 r
.52824 .43119 m .52408 .43063 L .52733 .42847 L F
.64 .948 .731 r
.52987 .43072 m .53197 .42899 L .53108 .43038 L F
.668 .495 .643 r
.52733 .42847 m .53108 .43038 L .52824 .43119 L F
.584 .562 .796 r
.52824 .43119 m .52936 .42963 L .52733 .42847 L F
.668 .495 .643 r
.52733 .42847 m .52936 .42963 L .53108 .43038 L F
.584 .562 .796 r
.52894 .43022 m .53108 .43038 L .52936 .42963 L F
.52824 .43119 m .52951 .43083 L .52894 .43022 L F
.52951 .43083 m .53108 .43038 L .52894 .43022 L F
.181 0 .044 r
.53108 .43038 m .52741 .43363 L .52824 .43119 L F
.511 .893 .715 r
.5256 .42913 m .52733 .42847 L .52408 .43063 L F
.847 .387 .081 r
.5256 .42913 m .52936 .43101 L .52766 .42888 L F
.52728 .42848 m .52766 .42888 L .52733 .42847 L F
.5256 .42913 m .52766 .42888 L .52728 .42848 L F
.668 .495 .643 r
.52936 .42963 m .53084 .43047 L .53108 .43038 L F
.584 .562 .796 r
.52936 .42963 m .53108 .43038 L .53063 .42787 L F
.52936 .42963 m .53063 .42787 L .52733 .42847 L F
.668 .495 .643 r
.52733 .42847 m .52936 .43101 L .53084 .43047 L F
.249 0 .176 r
.52715 .43298 m .52936 .43101 L .5256 .42913 L F
.52741 .43363 m .52909 .43137 L .52715 .43298 L F
.52909 .43137 m .52936 .43101 L .52715 .43298 L F
.451 .534 .851 r
.53395 .42573 m .53252 .42813 L .53127 .42655 L F
.472 .047 .151 r
.53453 .42809 m .53108 .43038 L .53252 .42813 L F
.768 .919 .938 r
.48008 .42553 m .47794 .4271 L .47669 .42588 L F
.758 .907 .521 r
.30542 .62749 m .30659 .62624 L .30514 .6283 L F
.447 .091 .267 r
.30514 .6283 m .30659 .62624 L .30886 .62774 L F
.523 .001 0 r
.30886 .62774 m .30659 .62624 L .30542 .62749 L F
0 .432 .857 r
.40706 .59037 m .40927 .59037 L .40545 .58921 L F
.40706 .59037 m .41063 .59182 L .40927 .59037 L F
.93 .675 .53 r
.59126 .39125 m .58913 .39228 L .58873 .38916 L F
.59126 .39125 m .59151 .39347 L .58913 .39228 L F
0 0 0 r
.71009 .31129 m .71301 .31095 L .71422 .31071 L F
.307 .714 .977 r
.71559 .30966 m .71422 .31071 L .71301 .31095 L F
.602 .591 .813 r
.71428 .30566 m .71559 .30966 L .71301 .31095 L F
.965 .696 .267 r
.7147 .30871 m .71559 .30966 L .71461 .30839 L F
.307 .714 .977 r
.71559 .30966 m .71648 .31061 L .71422 .31071 L F
.433 .225 .495 r
.71566 .31194 m .71559 .30966 L .71301 .31095 L F
.71566 .31194 m .71559 .30966 L .71301 .31095 L F
.965 .696 .267 r
.71566 .31194 m .71559 .30966 L .7147 .30871 L F
.307 .714 .977 r
.71559 .30966 m .71656 .31061 L .71648 .31061 L F
.607 .372 .535 r
.35342 .54636 m .35679 .54652 L .356 .54633 L F
.495 .809 1 r
.35845 .54691 m .35859 .5464 L .35829 .5464 L F
.35679 .54652 m .35829 .5464 L .356 .54633 L F
.35845 .54691 m .35829 .5464 L .35679 .54652 L F
.607 .372 .535 r
.35342 .54636 m .35336 .54679 L .35641 .54655 L F
.3563 .54649 m .35641 .54655 L .35679 .54652 L F
.35342 .54636 m .35641 .54655 L .3563 .54649 L F
.495 .809 1 r
.35828 .54753 m .3583 .54748 L .356 .54633 L F
.3583 .54746 m .35845 .54691 L .356 .54633 L F
0 0 0 r
.35737 .54699 m .35426 .55037 L .35625 .54829 L F
.567 .048 0 r
.35774 .54656 m .35855 .54758 L .35736 .54699 L F
0 0 0 r
.35774 .54656 m .35734 .547 L .35736 .54699 L F
.108 0 .153 r
.35704 .54686 m .35734 .547 L .35774 .54656 L F
.607 .372 .535 r
.35679 .54652 m .3566 .54662 L .35774 .54656 L F
0 0 0 r
.35704 .54686 m .3567 .5467 L .35641 .54655 L F
.35847 .54756 m .3567 .5467 L .35704 .54686 L F
.607 .372 .535 r
.3566 .54662 m .35312 .54851 L .35774 .54656 L F
.35679 .54652 m .35774 .54656 L .356 .54633 L F
.567 .048 0 r
.35774 .54656 m .35736 .54699 L .356 .54633 L F
0 0 0 r
.35774 .54656 m .35736 .54699 L .35737 .54699 L F
.35734 .547 m .35426 .55037 L .35737 .54699 L F
.35847 .54756 m .35828 .54753 L .35729 .54701 L F
.35732 .547 m .35729 .54701 L .3567 .5467 L F
.35847 .54756 m .35729 .54701 L .35732 .547 L F
.108 0 .153 r
.35312 .54851 m .35426 .55037 L .35734 .547 L F
.35312 .54851 m .35734 .547 L .35704 .54686 L F
.607 .372 .535 r
.35336 .54679 m .35312 .54851 L .35679 .54652 L F
0 0 0 r
.35855 .54758 m .35847 .54756 L .356 .54633 L F
.35847 .54756 m .35641 .54655 L .356 .54633 L F
0 .038 .601 r
.35828 .54753 m .3588 .54703 L .35859 .5464 L F
0 0 0 r
.35828 .54753 m .35757 .54969 L .3588 .54703 L F
.35855 .54758 m .35757 .54969 L .35828 .54753 L F
.647 .557 .738 r
.35686 .59229 m .35434 .59558 L .35391 .59284 L F
.755 .696 .795 r
.28567 .65184 m .28834 .65057 L .28659 .64715 L F
.613 .655 .868 r
.28834 .65057 m .28926 .64671 L .28659 .64715 L F
.28834 .65057 m .29147 .64982 L .28926 .64671 L F
.069 0 0 r
.57152 .45298 m .56774 .45481 L .57019 .45327 L F
0 0 0 r
.57019 .45327 m .56774 .45481 L .56696 .45588 L F
.56767 .45541 m .56696 .45588 L .56669 .45625 L F
.57019 .45327 m .56696 .45588 L .56767 .45541 L F
.681 .97 .775 r
.57377 .45103 m .57177 .45286 L .57019 .45327 L F
.069 0 0 r
.57177 .45286 m .57152 .45298 L .57019 .45327 L F
.681 .97 .775 r
.57377 .45103 m .57019 .45327 L .57294 .45337 L F
.605 .34 .489 r
.57169 .45276 m .56887 .45335 L .57143 .45211 L F
0 0 0 r
.57019 .45327 m .56669 .45625 L .56887 .45335 L F
.605 .34 .489 r
.56958 .45378 m .57019 .45327 L .56912 .4535 L F
.57288 .45579 m .57019 .45327 L .56958 .45378 L F
.57288 .45579 m .57294 .45337 L .57019 .45327 L F
.57288 .45579 m .56988 .45396 L .57169 .45276 L F
.56912 .4535 m .57019 .45327 L .56887 .45335 L F
.56988 .45396 m .56887 .45335 L .57169 .45276 L F
.509 .309 .543 r
.55899 .41532 m .56211 .41666 L .56181 .41465 L F
.819 .559 .004 r
.56181 .41465 m .56211 .41666 L .55899 .41532 L F
.955 .636 .222 r
.56181 .41465 m .56211 .41666 L .56153 .415 L F
.087 0 0 r
.55899 .41532 m .56181 .41465 L .56251 .41377 L F
.451 .789 .998 r
.56317 .41347 m .56439 .41219 L .56057 .41261 L F
.521 .745 .977 r
.56057 .41261 m .56439 .41219 L .56296 .41 L F
.587 .676 .902 r
.56063 .41245 m .55899 .41532 L .56057 .41261 L F
.56063 .41245 m .56181 .41465 L .55899 .41532 L F
.955 .636 .222 r
.56181 .41465 m .56153 .415 L .56063 .41245 L F
.087 0 0 r
.56251 .41377 m .56181 .41465 L .56317 .41347 L F
.532 .851 .554 r
.56317 .41347 m .56181 .41465 L .56439 .41219 L F
.098 0 .292 r
.48672 .52541 m .48748 .52295 L .48509 .52432 L F
.489 .255 .486 r
.49976 .49824 m .50261 .49476 L .49854 .49468 L F
.49976 .49824 m .50249 .49745 L .50261 .49476 L F
.557 .311 .497 r
.50249 .49745 m .50527 .49691 L .50261 .49476 L F
.558 .311 .497 r
.50527 .49691 m .50528 .4944 L .50261 .49476 L F
.834 .698 .714 r
.39414 .45462 m .39502 .45815 L .3983 .4542 L F
.775 .602 .665 r
.39502 .45815 m .39963 .459 L .3983 .4542 L F
.463 .412 .715 r
.3983 .4542 m .39963 .459 L .40171 .45792 L F
.866 .992 .822 r
.52283 .4055 m .5201 .40875 L .52183 .40812 L F
.638 .698 .889 r
.50066 .45853 m .50222 .46213 L .50477 .46149 L F
.902 .525 .307 r
.58505 .38363 m .5831 .38465 L .58359 .38272 L F
.58505 .38363 m .58615 .3867 L .5831 .38465 L F
.445 .014 .124 r
.67292 .32388 m .67168 .32633 L .66887 .32653 L F
.152 0 0 r
.67439 .3252 m .67292 .32388 L .67545 .32366 L F
.67439 .3252 m .67168 .32633 L .67292 .32388 L F
.355 .712 .986 r
.5268 .40344 m .52536 .40206 L .5233 .40247 L F
.175 0 .32 r
.5268 .40344 m .52669 .40597 L .52536 .40206 L F
0 0 0 r
.53677 .44911 m .53664 .44967 L .53928 .44827 L F
.53677 .44911 m .53468 .45032 L .53664 .44967 L F
.451 .771 .997 r
.5382 .46091 m .53962 .46216 L .54213 .4617 L F
.604 .554 .771 r
.54041 .46541 m .54213 .4617 L .53962 .46216 L F
.821 .996 .763 r
.41913 .5199 m .41797 .52336 L .42092 .5188 L F
.41797 .52336 m .41771 .52414 L .41849 .52283 L F
.41797 .52336 m .41849 .52283 L .42092 .5188 L F
.41913 .5199 m .41846 .52074 L .41771 .52414 L F
.577 .393 .595 r
.41771 .52414 m .42224 .51984 L .42092 .5188 L F
.41771 .52414 m .4201 .52377 L .42224 .51984 L F
.54 .804 .994 r
.41589 .52317 m .4201 .52377 L .41744 .524 L F
.821 .996 .763 r
.41846 .52074 m .41756 .52188 L .41771 .52414 L F
.54 .804 .994 r
.41744 .524 m .41774 .52397 L .41771 .52414 L F
.41774 .52397 m .4201 .52377 L .41771 .52414 L F
.352 .725 .987 r
.41771 .52414 m .41767 .5236 L .41589 .52317 L F
.41767 .5236 m .41756 .52188 L .41589 .52317 L F
.88 .911 .845 r
.41774 .52362 m .4201 .52377 L .41788 .52345 L F
.41603 .52577 m .41951 .52406 L .41774 .52362 L F
.41951 .52406 m .4201 .52377 L .41774 .52362 L F
.416 .52533 m .41788 .52345 L .41589 .52317 L F
.41603 .52577 m .41788 .52345 L .416 .52533 L F
0 0 0 r
.5506 .48166 m .55373 .47912 L .55246 .48033 L F
.55373 .47912 m .55604 .47789 L .55246 .48033 L F
.497 .906 .875 r
.43862 .44624 m .43813 .44725 L .43613 .44695 L F
.43862 .44624 m .44058 .44612 L .43813 .44725 L F
.65 .776 .94 r
.52742 .43929 m .53106 .44064 L .52986 .4381 L F
.578 .716 .937 r
.53106 .44064 m .53246 .43744 L .52986 .4381 L F
.086 .38 .842 r
.55708 .42181 m .56035 .42651 L .56119 .42535 L F
0 0 .021 r
.56119 .42535 m .56035 .42651 L .56032 .42672 L F
.533 .268 .458 r
.50528 .4944 m .50841 .49387 L .50803 .49151 L F
.414 .223 .51 r
.50803 .49151 m .51107 .49231 L .51091 .4876 L F
.43 .153 .39 r
.51109 .49315 m .50803 .49151 L .50841 .49387 L F
.51109 .49315 m .51107 .49231 L .50803 .49151 L F
.395 .827 .956 r
.44391 .58379 m .44809 .58343 L .44634 .58245 L F
.346 .761 .979 r
.33493 .51973 m .33728 .51947 L .33321 .51869 L F
0 0 0 r
.55232 .47238 m .55105 .47376 L .55429 .47107 L F
.642 .537 .72 r
.38511 .48519 m .38637 .48501 L .38736 .48164 L F
.535 .198 .344 r
.38705 .48735 m .38637 .48501 L .38511 .48519 L F
.304 0 0 r
.63278 .34454 m .63184 .34623 L .62905 .34681 L F
.732 .573 .676 r
.63528 .34349 m .63184 .34623 L .63278 .34454 L F
.575 .001 0 r
.35076 .53333 m .35317 .53509 L .35552 .53498 L F
.412 0 0 r
.35317 .53509 m .35733 .53335 L .35552 .53498 L F
.785 .673 .74 r
.26722 .63178 m .26823 .63518 L .26371 .6348 L F
.426 .811 .989 r
.26371 .6348 m .26823 .63518 L .26616 .6343 L F
.168 .274 .73 r
.26928 .63499 m .26823 .63518 L .26722 .63178 L F
.187 .672 .927 r
.26616 .6343 m .26823 .63518 L .26928 .63499 L F
.184 .68 .917 r
.26901 .63462 m .26823 .63518 L .26928 .63499 L F
.516 .625 .898 r
.61618 .41545 m .61516 .41849 L .61391 .41533 L F
.61618 .41545 m .61794 .41862 L .61516 .41849 L F
.887 .689 .63 r
.56233 .38343 m .56149 .38206 L .56158 .38142 L F
.589 .028 0 r
.56174 .38037 m .56158 .38142 L .55867 .37959 L F
.075 .531 .901 r
.56158 .38142 m .5569 .37949 L .55867 .37959 L F
.55955 .38058 m .56035 .38021 L .5569 .37949 L F
.56158 .38142 m .56035 .38021 L .55955 .38058 L F
.887 .689 .63 r
.56149 .38206 m .56035 .38021 L .56158 .38142 L F
.56233 .38343 m .5598 .38303 L .56035 .38021 L F
.277 .111 .467 r
.56035 .38021 m .56072 .38247 L .5611 .37986 L F
.56035 .38021 m .5611 .37986 L .56133 .37827 L F
.589 .028 0 r
.56257 .38058 m .56158 .38142 L .56174 .38037 L F
.936 .567 .182 r
.56257 .38058 m .5631 .38283 L .56158 .38142 L F
.701 .632 .777 r
.60328 .44345 m .5997 .44207 L .60178 .44147 L F
.483 .501 .8 r
.60559 .44318 m .60328 .44345 L .60178 .44147 L F
.60559 .44318 m .60686 .44434 L .60328 .44345 L F
.179 0 0 r
.45339 .59661 m .45332 .59738 L .44769 .59737 L F
.234 .742 .884 r
.45339 .59661 m .45606 .59629 L .45514 .59578 L F
.45339 .59661 m .45514 .59578 L .45332 .59738 L F
.923 .93 .795 r
.53494 .46628 m .53613 .46257 L .53428 .46474 L F
.902 .874 .439 r
.53417 .46772 m .53494 .46628 L .53428 .46474 L F
.745 .641 .745 r
.50477 .46149 m .50636 .46535 L .50899 .46223 L F
0 0 .013 r
.50899 .46223 m .50636 .46535 L .50806 .46439 L F
.22 .165 .58 r
.50806 .46439 m .50636 .46535 L .50874 .46702 L F
.147 .178 .636 r
.50636 .46535 m .50723 .46792 L .50874 .46702 L F
0 0 0 r
.33293 .49789 m .3353 .49759 L .33696 .49725 L F
.506 0 0 r
.33696 .49725 m .3353 .49759 L .33946 .49789 L F
.904 .51 .093 r
.58813 .42774 m .58656 .42519 L .58746 .42726 L F
.98 .766 .541 r
.58645 .43117 m .58813 .42774 L .58746 .42726 L F
.58645 .43117 m .58807 .43261 L .58813 .42774 L F
0 0 0 r
.61743 .36726 m .61471 .3706 L .61682 .36909 L F
.61856 .36749 m .61743 .36726 L .61682 .36909 L F
.593 .885 .584 r
.61856 .36749 m .61687 .36892 L .61778 .36798 L F
0 0 0 r
.61856 .36749 m .61946 .36693 L .61743 .36726 L F
.593 .885 .584 r
.61856 .36749 m .61778 .36798 L .6198 .36592 L F
0 0 0 r
.61856 .36749 m .61994 .36685 L .61946 .36693 L F
.978 .861 .653 r
.42908 .56616 m .43052 .56746 L .42832 .56847 L F
.668 .962 .753 r
.34752 .62131 m .34728 .6223 L .34658 .62234 L F
0 .234 .752 r
.43201 .4619 m .43212 .46081 L .4297 .45889 L F
.518 .31 .538 r
.4524 .56867 m .45514 .56802 L .45109 .56749 L F
.276 .557 .93 r
.45109 .56749 m .45279 .56902 L .44978 .56899 L F
.518 .31 .538 r
.45334 .5691 m .45514 .56802 L .4516 .56886 L F
.7 .983 .872 r
.45514 .56802 m .45463 .56961 L .45334 .5691 L F
.518 .31 .538 r
.45419 .56921 m .45514 .56802 L .45334 .5691 L F
.7 .983 .872 r
.45514 .56802 m .45334 .5691 L .45316 .56903 L F
.276 .557 .93 r
.45109 .56749 m .45316 .56903 L .45279 .56902 L F
.518 .31 .538 r
.4516 .56886 m .4524 .56867 L .45109 .56749 L F
.068 .618 .829 r
.45024 .569 m .45463 .56961 L .44978 .56899 L F
.45259 .56902 m .45322 .56916 L .45024 .569 L F
.45322 .56916 m .45463 .56961 L .45024 .569 L F
.868 .733 .712 r
.44937 .57072 m .45252 .57132 L .4516 .56886 L F
.45046 .56868 m .4516 .56886 L .45109 .56749 L F
.44937 .57072 m .4516 .56886 L .45046 .56868 L F
.068 .618 .829 r
.45279 .56902 m .45298 .56908 L .45259 .56902 L F
.45298 .56908 m .45322 .56916 L .45259 .56902 L F
.518 .31 .538 r
.45252 .57132 m .45517 .57079 L .45515 .56927 L F
.45419 .56921 m .45515 .56927 L .45514 .56802 L F
.068 .618 .829 r
.45334 .5691 m .45463 .56961 L .45279 .56902 L F
.518 .31 .538 r
.45252 .57132 m .45515 .56927 L .45419 .56921 L F
.45252 .57132 m .45419 .56921 L .4516 .56886 L F
.068 .618 .829 r
.45316 .56903 m .45334 .5691 L .45279 .56902 L F
.217 .535 .924 r
.45631 .56975 m .45463 .56961 L .45514 .56802 L F
.539 .523 .786 r
.44853 .46622 m .44953 .46351 L .44738 .46337 L F
.44853 .46622 m .45139 .46526 L .44953 .46351 L F
.576 .493 .724 r
.32453 .54078 m .32288 .54368 L .32361 .54193 L F
.32453 .54078 m .32573 .54352 L .32288 .54368 L F
.459 .758 .994 r
.32288 .54368 m .32573 .54352 L .32361 .54193 L F
.087 .622 .862 r
.25814 .5894 m .25666 .58882 L .25401 .58864 L F
.704 .96 .946 r
.25939 .58737 m .25814 .5894 L .26003 .5861 L F
.25939 .58737 m .25666 .58882 L .25814 .5894 L F
.747 .673 .779 r
.28152 .65125 m .28567 .65184 L .28384 .64817 L F
.755 .696 .795 r
.28567 .65184 m .28659 .64715 L .28384 .64817 L F
0 0 .558 r
.4581 .57927 m .45826 .58236 L .45796 .58216 L F
.99 .874 .615 r
.39003 .58481 m .39031 .58911 L .39139 .58668 L F
.77 .776 .858 r
.46383 .46134 m .46756 .45905 L .46345 .45836 L F
0 0 0 r
.3379 .53187 m .33997 .53066 L .33811 .53213 L F
.027 .56 .853 r
.43683 .4644 m .43649 .46393 L .43405 .46352 L F
.695 .977 .792 r
.43936 .46161 m .43683 .4644 L .44041 .46113 L F
.43936 .46161 m .43649 .46393 L .43683 .4644 L F
0 0 0 r
.23158 .60252 m .23111 .60433 L .23181 .60193 L F
.23158 .60252 m .23076 .6052 L .23111 .60433 L F
.319 .487 .868 r
.23124 .59992 m .23158 .60252 L .23181 .60193 L F
0 0 .306 r
.62595 .38715 m .62693 .38762 L .62821 .38803 L F
.986 .806 .579 r
.40621 .56653 m .40553 .56904 L .404 .56815 L F
.984 .709 .341 r
.40621 .56653 m .40504 .56556 L .40486 .56263 L F
.988 .873 .626 r
.40621 .56653 m .404 .56815 L .40504 .56556 L F
.703 .475 .575 r
.42526 .48735 m .42936 .48487 L .42477 .48477 L F
.573 .409 .621 r
.62641 .36106 m .62914 .36045 L .629 .35777 L F
.37 .482 .843 r
.58085 .35588 m .58234 .35298 L .57971 .35422 L F
.58085 .35588 m .58362 .35657 L .58234 .35298 L F
.464 .88 .76 r
.60853 .38729 m .6096 .38707 L .61075 .38632 L F
.446 .877 .904 r
.5939 .34555 m .59803 .34486 L .59407 .34703 L F
.453 .559 .872 r
.26229 .60885 m .25823 .60565 L .26111 .60702 L F
.537 .32 .533 r
.25777 .60873 m .26111 .60702 L .25823 .60565 L F
.618 .31 .425 r
.28814 .57887 m .29248 .57642 L .28833 .57576 L F
.28814 .57887 m .29379 .57964 L .29248 .57642 L F
.43 .218 .489 r
.29379 .57964 m .29484 .57768 L .29248 .57642 L F
0 0 0 r
.66654 .3171 m .66951 .31408 L .66782 .31591 L F
.607 .17 0 r
.40359 .56073 m .40486 .56263 L .4025 .5592 L F
.734 .667 .784 r
.50477 .46149 m .50899 .46223 L .50749 .45809 L F
.565 .594 .841 r
.50899 .46223 m .50998 .45755 L .50749 .45809 L F
.50899 .46223 m .51161 .46164 L .50998 .45755 L F
.168 0 0 r
.51052 .463 m .50899 .46223 L .50806 .46439 L F
.51052 .463 m .51161 .46164 L .50899 .46223 L F
.819 .417 .287 r
.32868 .59153 m .33255 .59498 L .33055 .5925 L F
0 0 0 r
.48688 .54996 m .48645 .55209 L .48532 .55373 L F
0 0 .191 r
.48645 .55209 m .48505 .55627 L .48532 .55373 L F
.599 .771 .962 r
.47672 .45475 m .47799 .45165 L .47512 .45327 L F
.47672 .45475 m .47927 .45402 L .47799 .45165 L F
.456 .777 .998 r
.55188 .43682 m .55465 .43885 L .55139 .43896 L F
.208 .387 .821 r
.55498 .44121 m .55139 .43896 L .55465 .43885 L F
.492 .904 .865 r
.41296 .59934 m .41313 .59974 L .41528 .59799 L F
.087 0 0 r
.41313 .59974 m .41422 .60036 L .41207 .60171 L F
.41313 .59974 m .41588 .5992 L .41457 .60011 L F
.41402 .60025 m .41457 .60011 L .41422 .60036 L F
.41313 .59974 m .41457 .60011 L .41402 .60025 L F
0 0 0 r
.41528 .59799 m .41313 .59974 L .41301 .59996 L F
.41338 .60018 m .41301 .59996 L .41207 .60171 L F
.41528 .59799 m .41301 .59996 L .41338 .60018 L F
.88 .449 .152 r
.41096 .5959 m .41296 .59934 L .40989 .59704 L F
.532 .724 .961 r
.40989 .59704 m .41296 .59934 L .41528 .59799 L F
.661 .635 .814 r
.41528 .59799 m .41313 .60047 L .40989 .59704 L F
.41313 .60047 m .41166 .60084 L .40989 .59704 L F
.978 .7 .427 r
.40989 .59704 m .41207 .60171 L .41002 .59972 L F
.40989 .59704 m .41207 .60171 L .41002 .59972 L F
.661 .635 .814 r
.41313 .60047 m .41207 .60171 L .41166 .60084 L F
.929 .824 .72 r
.41207 .60171 m .41105 .60289 L .41002 .59972 L F
0 0 0 r
.41422 .60036 m .41105 .60289 L .41207 .60171 L F
.731 .735 .855 r
.41002 .59972 m .41105 .60289 L .41422 .60036 L F
.41002 .59972 m .4135 .60025 L .4123 .60018 L F
.4135 .60025 m .41422 .60036 L .41359 .6003 L F
.4135 .60025 m .41359 .6003 L .4123 .60018 L F
.88 .78 .747 r
.72857 .28585 m .72871 .29037 L .7266 .28881 L F
.781 .593 .645 r
.72871 .29037 m .72618 .29223 L .7266 .28881 L F
.72871 .29037 m .72893 .2926 L .72618 .29223 L F
.687 .767 .912 r
.72857 .28585 m .73206 .28652 L .72871 .29037 L F
0 0 0 r
.58191 .45432 m .5837 .45364 L .581 .4544 L F
.58191 .45432 m .58504 .45231 L .5837 .45364 L F
.397 .111 .359 r
.58363 .45371 m .581 .4544 L .5837 .45364 L F
.136 0 0 r
.57857 .45505 m .58191 .45432 L .581 .4544 L F
.397 .111 .359 r
.57975 .45692 m .581 .4544 L .58363 .45371 L F
.136 0 0 r
.57835 .45509 m .57857 .45505 L .581 .4544 L F
.907 .774 .702 r
.40655 .58298 m .40297 .58461 L .40497 .58209 L F
.40655 .58298 m .40559 .58586 L .40297 .58461 L F
.817 .675 .706 r
.52945 .40265 m .53301 .4001 L .52957 .39997 L F
.13 0 0 r
.55999 .38744 m .56323 .38622 L .56263 .38613 L F
0 0 .259 r
.56263 .38613 m .56323 .38622 L .5631 .38283 L F
.772 .902 .933 r
.46526 .43528 m .46164 .4358 L .46394 .43397 L F
.746 .896 .946 r
.46682 .43198 m .46526 .43528 L .46394 .43397 L F
.46682 .43198 m .46873 .43338 L .46526 .43528 L F
0 .101 .629 r
.35612 .53094 m .35827 .53137 L .35589 .52911 L F
.35612 .53094 m .35733 .53335 L .35827 .53137 L F
.54 .6 .863 r
.54446 .40953 m .54329 .41076 L .54023 .40598 L F
.75 .844 .922 r
.29314 .64963 m .29495 .65124 L .29781 .64895 L F
.635 .581 .777 r
.29495 .65124 m .30032 .6544 L .29781 .64895 L F
.72 .203 0 r
.2991 .65379 m .30032 .6544 L .29495 .65124 L F
.946 .944 .747 r
.37865 .61796 m .37906 .61541 L .37778 .61712 L F
.904 .887 .805 r
.37522 .6207 m .37865 .61796 L .37778 .61712 L F
.759 .592 .671 r
.59922 .43945 m .59606 .44103 L .59553 .43901 L F
.59922 .43945 m .5997 .44207 L .59606 .44103 L F
0 0 .22 r
.59922 .43945 m .60103 .43497 L .60095 .43903 L F
.542 .461 .714 r
.60095 .43903 m .5997 .44207 L .59922 .43945 L F
.639 .774 .945 r
.44215 .58184 m .44391 .58379 L .44634 .58245 L F
.187 .564 .936 r
.57147 .3804 m .56952 .38165 L .56781 .3801 L F
.57147 .3804 m .57255 .38182 L .56952 .38165 L F
.651 .496 .661 r
.5376 .46851 m .54142 .46878 L .54041 .46541 L F
.763 .65 .736 r
.29363 .58454 m .28997 .58204 L .294 .5828 L F
.589 .256 .374 r
.294 .5828 m .29627 .58494 L .29363 .58454 L F
.501 .268 .493 r
.29655 .5823 m .29627 .58494 L .294 .5828 L F
.81 .955 .911 r
.49138 .41841 m .48985 .42023 L .48851 .41933 L F
.651 .827 .407 r
.60545 .38176 m .60429 .38391 L .60645 .38028 L F
.741 .985 .767 r
.60219 .38487 m .60429 .38391 L .60545 .38176 L F
0 0 0 r
.60857 .37932 m .60545 .38176 L .60645 .38028 L F
.534 .316 .53 r
.32851 .56925 m .33105 .56918 L .33121 .56648 L F
.58 .522 .755 r
.33121 .56648 m .33376 .56606 L .33286 .56298 L F
.449 .246 .512 r
.33121 .56648 m .33345 .56852 L .33376 .56606 L F
.33121 .56648 m .33105 .56918 L .33345 .56852 L F
.997 .776 .475 r
.58479 .41133 m .58498 .40985 L .58363 .40839 L F
.937 .717 .578 r
.34106 .61968 m .34198 .62212 L .34276 .61876 L F
0 0 0 r
.34106 .61968 m .34276 .61876 L .34534 .61751 L F
.766 .759 .846 r
.52501 .45898 m .52843 .45991 L .52745 .45778 L F
.282 .512 .899 r
.52745 .45778 m .52843 .45991 L .53087 .46046 L F
.444 .329 .628 r
.52843 .45991 m .53022 .46247 L .53087 .46046 L F
.429 .772 .997 r
.31831 .58467 m .32226 .5852 L .3209 .58442 L F
.147 .691 .762 r
.62642 .34767 m .62253 .34807 L .62373 .3476 L F
.771 .865 .919 r
.51504 .4318 m .51974 .43097 L .51856 .4296 L F
.684 .321 .353 r
.51838 .43449 m .51974 .43097 L .51504 .4318 L F
.392 .034 .232 r
.52166 .43117 m .51974 .43097 L .51838 .43449 L F
.627 .564 .763 r
.54311 .44598 m .54576 .44517 L .54494 .44251 L F
.582 .513 .742 r
.54643 .44883 m .54311 .44598 L .54576 .44517 L F
0 0 0 r
.54534 .4454 m .54311 .44598 L .54154 .44711 L F
.54534 .4454 m .54576 .44517 L .54311 .44598 L F
0 .162 .694 r
.41986 .59915 m .41972 .59783 L .41825 .59826 L F
.608 .237 .313 r
.42401 .5991 m .42234 .60128 L .41986 .59915 L F
0 .162 .694 r
.41986 .59915 m .42234 .60128 L .41972 .59783 L F
0 0 .101 r
.49578 .53289 m .49409 .53662 L .49476 .53412 L F
.949 .939 .608 r
.60546 .35366 m .60508 .35631 L .60746 .35434 L F
0 0 0 r
.61058 .35184 m .60546 .35366 L .60746 .35434 L F
.919 .977 .713 r
.58532 .44956 m .58711 .44878 L .58631 .44768 L F
.58532 .44956 m .58504 .45231 L .58711 .44878 L F
.935 .857 .74 r
.58711 .44878 m .58673 .44487 L .58631 .44768 L F
0 0 0 r
.22511 .55988 m .2263 .5592 L .22736 .55706 L F
.138 .08 .524 r
.22501 .56246 m .2263 .5592 L .22511 .55988 L F
.726 .79 .307 r
.38757 .60197 m .38643 .60505 L .38737 .60265 L F
.78 .664 .735 r
.60789 .44666 m .60791 .44929 L .60396 .44889 L F
.756 .409 .396 r
.60791 .44929 m .60357 .45089 L .60396 .44889 L F
.60791 .44929 m .60778 .45144 L .60357 .45089 L F
.769 .718 .805 r
.61028 .44523 m .60791 .44929 L .60789 .44666 L F
.307 0 .005 r
.60791 .44929 m .60973 .45011 L .60778 .45144 L F
.835 .754 .774 r
.46606 .45494 m .47004 .45531 L .46842 .4543 L F
.46606 .45494 m .46756 .45905 L .47004 .45531 L F
.57 .843 .996 r
.471 .4533 m .47004 .45531 L .47255 .45447 L F
.644 .92 .977 r
.46842 .4543 m .47004 .45531 L .471 .4533 L F
.604 .554 .771 r
.54041 .46541 m .54454 .46617 L .54213 .4617 L F
.817 .949 .907 r
.54142 .46878 m .54454 .46617 L .54041 .46541 L F
0 0 0 r
.33838 .65412 m .34123 .65317 L .33879 .65335 L F
.631 .768 .945 r
.22796 .56814 m .22887 .57074 L .23161 .56898 L F
.187 .71 .867 r
.26229 .60885 m .25777 .60873 L .26111 .60702 L F
.209 .51 .911 r
.26286 .60726 m .26229 .60885 L .26111 .60702 L F
.26286 .60726 m .26229 .60885 L .26111 .60702 L F
.734 .207 0 r
.26888 .64463 m .27326 .64802 L .27142 .64666 L F
.82 .477 .408 r
.27142 .64666 m .27613 .64538 L .27465 .64448 L F
.916 .814 .732 r
.27326 .64802 m .27613 .64538 L .27142 .64666 L F
.464 .735 .986 r
.27326 .64802 m .27686 .64951 L .27613 .64538 L F
.745 .928 .578 r
.24427 .60295 m .2432 .60424 L .24347 .60416 L F
.272 0 .071 r
.30357 .57985 m .30473 .58086 L .30173 .58198 L F
.30357 .57985 m .30602 .5792 L .30473 .58086 L F
.399 .824 .655 r
.54665 .48388 m .5506 .48166 L .5488 .48238 L F
.531 .907 .739 r
.5488 .48238 m .5506 .48166 L .55246 .48033 L F
0 0 .021 r
.56119 .42535 m .56032 .42672 L .55757 .42746 L F
.767 .347 .252 r
.55757 .42746 m .56032 .42672 L .56156 .42917 L F
.77 .673 .756 r
.36401 .53636 m .36162 .53927 L .36163 .53658 L F
.783 .98 .908 r
.38387 .48461 m .38154 .4876 L .38083 .48724 L F
.964 .696 .477 r
.25086 .55667 m .24882 .55826 L .24913 .55502 L F
.686 .785 .925 r
.25291 .55471 m .25086 .55667 L .24913 .55502 L F
.352 0 .18 r
.25291 .55471 m .24882 .55826 L .25086 .55667 L F
.079 0 0 r
.52986 .49589 m .53148 .49589 L .52939 .49719 L F
.52986 .49589 m .53271 .49452 L .53148 .49589 L F
.023 0 .453 r
.42558 .53351 m .42591 .53588 L .42489 .53669 L F
.92 .973 .77 r
.60547 .41397 m .60484 .41724 L .60751 .41351 L F
.843 .998 .819 r
.60813 .41107 m .60547 .41397 L .60751 .41351 L F
0 0 0 r
.73034 .31071 m .72843 .3125 L .72774 .31421 L F
.392 .827 .681 r
.32382 .57165 m .32488 .57099 L .32851 .56925 L F
.625 .138 .076 r
.32851 .56925 m .32488 .57099 L .33052 .57143 L F
.703 .579 .713 r
.32488 .57099 m .33062 .57462 L .33052 .57143 L F
.541 .464 .717 r
.32257 .57362 m .32564 .57631 L .32488 .57099 L F
.559 .415 .642 r
.32257 .57362 m .32644 .5772 L .32564 .57631 L F
.32257 .57362 m .32451 .57861 L .32644 .5772 L F
.703 .579 .713 r
.32488 .57099 m .32564 .57631 L .33062 .57462 L F
0 0 0 r
.32506 .57086 m .32283 .57407 L .32257 .57362 L F
.3253 .57059 m .32515 .5708 L .32506 .57086 L F
.32515 .5708 m .32283 .57407 L .32506 .57086 L F
.392 .827 .681 r
.3234 .57186 m .32448 .57123 L .32382 .57165 L F
.32448 .57123 m .32488 .57099 L .32382 .57165 L F
.625 .138 .076 r
.32851 .56925 m .33052 .57143 L .33105 .56918 L F
.68 .529 .674 r
.6262 .36377 m .62362 .36712 L .62375 .36391 L F
.6262 .36377 m .62362 .36712 L .62375 .36391 L F
.777 .556 0 r
.33256 .57366 m .33271 .57305 L .3331 .5713 L F
.33256 .57366 m .33329 .57735 L .33271 .57305 L F
.588 .41 .608 r
.55167 .39342 m .55451 .39291 L .55435 .38967 L F
.474 .322 .595 r
.55435 .38967 m .55682 .39191 L .55703 .38935 L F
.55435 .38967 m .55451 .39291 L .55682 .39191 L F
.989 .76 .499 r
.44551 .48177 m .44322 .48277 L .44087 .48082 L F
.44551 .48177 m .44496 .48418 L .44322 .48277 L F
.071 0 .263 r
.44679 .48084 m .44496 .48418 L .44551 .48177 L F
.999 .81 .513 r
.40125 .54721 m .39983 .54924 L .40016 .54582 L F
.882 .539 .395 r
.40207 .54955 m .39983 .54924 L .40125 .54721 L F
0 0 .528 r
.341 .60595 m .33962 .60535 L .34203 .60424 L F
.341 .60595 m .34129 .60837 L .33962 .60535 L F
.103 .103 .572 r
.33962 .60535 m .34129 .60837 L .34015 .6083 L F
.948 .638 .416 r
.39125 .52954 m .38915 .52635 L .39142 .52731 L F
.19 0 0 r
.65253 .3816 m .65076 .38074 L .64995 .38079 L F
.223 0 0 r
.65253 .3816 m .64995 .38079 L .64977 .38247 L F
.703 .475 .575 r
.42526 .48735 m .429 .48771 L .42936 .48487 L F
.946 .598 .199 r
.53042 .47627 m .53157 .4754 L .52954 .47388 L F
.53042 .47627 m .53174 .4774 L .53157 .4754 L F
.294 .789 .864 r
.34616 .65173 m .34978 .65135 L .34808 .6498 L F
.851 .957 .879 r
.34978 .65135 m .35092 .64773 L .34808 .6498 L F
.34978 .65135 m .3525 .64861 L .35092 .64773 L F
.885 .839 .794 r
.64822 .38382 m .64424 .38571 L .64706 .38383 L F
.64822 .38382 m .64595 .38752 L .64424 .38571 L F
.769 .85 .401 r
.61043 .37485 m .60949 .37779 L .60937 .37751 L F
0 0 0 r
.61085 .37794 m .60949 .37779 L .61217 .37682 L F
.61085 .37794 m .60857 .37932 L .60949 .37779 L F
.772 .842 .386 r
.60949 .37779 m .60857 .37932 L .60937 .37751 L F
.002 0 .056 r
.55648 .41871 m .55453 .4201 L .55371 .42194 L F
.954 .731 .561 r
.38236 .55502 m .38491 .55345 L .38311 .55238 L F
.38236 .55502 m .38447 .55646 L .38491 .55345 L F
.609 .762 .952 r
.64595 .38752 m .64154 .38644 L .64424 .38571 L F
.421 .148 .391 r
.39657 .46192 m .39963 .459 L .39502 .45815 L F
.39657 .46192 m .39909 .46124 L .39963 .459 L F
.39963 .459 m .39909 .46124 L .39657 .46192 L F
.246 0 .323 r
.40171 .45792 m .39909 .46124 L .39963 .459 L F
.40171 .45792 m .39909 .46124 L .39963 .459 L F
.807 .79 .837 r
.25236 .59955 m .25622 .59907 L .25523 .59933 L F
.46 .244 .497 r
.31762 .58327 m .31995 .58269 L .32005 .57933 L F
.101 0 .398 r
.32005 .57933 m .32178 .5809 L .32313 .57854 L F
.32005 .57933 m .31995 .58269 L .32178 .5809 L F
.906 .922 .534 r
.5837 .45364 m .58504 .45231 L .58532 .44956 L F
.486 .351 .622 r
.34745 .56683 m .34495 .56861 L .345 .5673 L F
.345 .5673 m .34495 .56861 L .34745 .56683 L F
.11 .033 .479 r
.24444 .54912 m .24315 .55285 L .24258 .55027 L F
.19 0 0 r
.65253 .3816 m .65353 .38022 L .65076 .38074 L F
0 0 0 r
.4624 .59489 m .45822 .59564 L .45986 .59526 L F
.497 .643 .922 r
.26003 .5861 m .25638 .58379 L .2596 .58544 L F
.919 .796 .322 r
.2596 .58544 m .25939 .58737 L .26003 .5861 L F
.723 .725 .852 r
.45498 .46685 m .45794 .46472 L .4539 .46416 L F
.743 .735 .844 r
.45498 .46685 m .4539 .46416 L .45139 .46526 L F
0 0 .211 r
.33238 .55663 m .33328 .5522 L .33498 .55543 L F
.33238 .55663 m .33327 .55525 L .33328 .5522 L F
0 .225 .738 r
.33238 .55663 m .33486 .559 L .33327 .55525 L F
.627 .522 .715 r
.38736 .48164 m .38637 .48501 L .39006 .48102 L F
.67 .588 .754 r
.38637 .48501 m .39135 .48441 L .39006 .48102 L F
.514 .114 .219 r
.39002 .48684 m .38637 .48501 L .38705 .48735 L F
.39002 .48684 m .39135 .48441 L .38637 .48501 L F
.661 .392 .502 r
.32333 .56849 m .32059 .56622 L .32297 .56552 L F
.455 .317 .604 r
.32553 .56485 m .32333 .56849 L .32297 .56552 L F
.635 .87 .51 r
.62735 .42073 m .6286 .41943 L .62591 .42292 L F
.546 .378 .605 r
.6286 .41943 m .62919 .42244 L .62591 .42292 L F
.52 .29 .507 r
.62591 .42292 m .62919 .42244 L .62603 .42536 L F
.842 .861 .858 r
.62603 .42536 m .62735 .42073 L .62591 .42292 L F
.64 .805 .962 r
.31862 .65652 m .32077 .65804 L .32264 .65679 L F
.628 .472 .651 r
.61162 .37381 m .61511 .37401 L .61471 .3706 L F
0 0 0 r
.61162 .37381 m .61404 .37297 L .61511 .37401 L F
.61162 .37381 m .61043 .37485 L .61404 .37297 L F
.562 .553 .802 r
.5438 .3927 m .54803 .39584 L .54791 .39351 L F
.655 .696 .876 r
.42526 .48735 m .42666 .48906 L .429 .48771 L F
.128 0 .272 r
.46288 .57963 m .46504 .5785 L .46576 .57606 L F
.099 0 .215 r
.46435 .58085 m .46288 .57963 L .46236 .58209 L F
.46435 .58085 m .46504 .5785 L .46288 .57963 L F
0 0 0 r
.48455 .55881 m .48364 .56137 L .48276 .56301 L F
0 0 .027 r
.48364 .56137 m .48266 .56519 L .48276 .56301 L F
.992 .744 .447 r
.57613 .38677 m .57703 .38457 L .57595 .38293 L F
.57613 .38677 m .57735 .38687 L .57703 .38457 L F
.861 .878 .849 r
.6231 .3814 m .62414 .38316 L .62629 .37998 L F
0 0 0 r
.64036 .33361 m .64244 .33311 L .64376 .33221 L F
.64376 .33221 m .64505 .33211 L .64634 .33104 L F
.64376 .33221 m .64244 .33311 L .64505 .33211 L F
.902 .942 .825 r
.26915 .62514 m .26512 .62728 L .2681 .62693 L F
.033 .306 .796 r
.2725 .6282 m .26915 .62514 L .27157 .62459 L F
.2725 .6282 m .27277 .62924 L .26915 .62514 L F
.674 .434 .55 r
.2681 .62693 m .27157 .62459 L .26915 .62514 L F
.246 .104 .481 r
.62827 .41327 m .63065 .41204 L .6298 .40958 L F
.134 .015 .441 r
.62842 .41638 m .63065 .41204 L .62827 .41327 L F
.799 .738 .796 r
.46345 .45836 m .46756 .45905 L .46606 .45494 L F
.822 .751 .786 r
.6125 .41004 m .61646 .40996 L .61524 .40933 L F
.51 .878 .979 r
.61524 .40933 m .61646 .40996 L .61911 .40909 L F
0 0 0 r
.48885 .54588 m .48812 .54825 L .48688 .54996 L F
.48812 .54825 m .48645 .55209 L .48688 .54996 L F
.323 .781 .641 r
.65339 .39278 m .6569 .39103 L .65595 .39163 L F
.535 .893 .677 r
.65595 .39163 m .6569 .39103 L .65896 .38936 L F
.59 .422 .622 r
.629 .35777 m .62914 .36045 L .63177 .35712 L F
0 0 0 r
.63992 .33424 m .64244 .33311 L .64036 .33361 L F
.624 .127 .049 r
.30811 .52641 m .31228 .52726 L .30788 .52592 L F
0 0 0 r
.25627 .52546 m .25407 .52648 L .25753 .52445 L F
.25806 .52466 m .25753 .52445 L .25947 .52331 L F
.25806 .52466 m .25627 .52546 L .25753 .52445 L F
.749 .617 .712 r
.59606 .44103 m .5997 .44207 L .59687 .4455 L F
.542 .461 .714 r
.60095 .43903 m .60178 .44147 L .5997 .44207 L F
.153 0 0 r
.60508 .35631 m .60346 .35712 L .60101 .35696 L F
.949 .939 .608 r
.60546 .35366 m .60346 .35712 L .60508 .35631 L F
.517 .288 .507 r
.62576 .39322 m .62321 .39648 L .62294 .39342 L F
.572 .932 .774 r
.68272 .37557 m .68645 .37352 L .68604 .37328 L F
.604 .943 .935 r
.68821 .3717 m .68645 .37352 L .68838 .37243 L F
.602 .95 .817 r
.68604 .37328 m .68645 .37352 L .68821 .3717 L F
.79 .713 .779 r
.35171 .52419 m .35269 .52707 L .34944 .52607 L F
.771 .531 .572 r
.35284 .52929 m .34944 .52607 L .35269 .52707 L F
.545 .556 .817 r
.35456 .52312 m .35269 .52707 L .35171 .52419 L F
.35456 .52312 m .35614 .5266 L .35269 .52707 L F
.625 .446 .621 r
.35614 .5266 m .35284 .52929 L .35269 .52707 L F
.431 .003 .123 r
.29484 .57768 m .29728 .57779 L .29895 .57524 L F
.539 .216 .37 r
.29728 .57779 m .30184 .57318 L .29895 .57524 L F
.574 .888 .99 r
.32848 .5187 m .32965 .51732 L .32982 .51741 L F
.32848 .5187 m .32683 .51838 L .32965 .51732 L F
.589 .819 .43 r
.5262 .42177 m .52524 .42315 L .52734 .42024 L F
0 0 0 r
.52439 .42575 m .52524 .42315 L .5262 .42177 L F
.565 .205 .317 r
.55167 .39342 m .55376 .39481 L .55451 .39291 L F
.55167 .39342 m .55041 .396 L .55376 .39481 L F
.771 .908 .519 r
.46634 .55253 m .4643 .55609 L .46477 .55437 L F
.863 .64 .598 r
.60257 .35202 m .60346 .35712 L .60546 .35366 L F
.542 .243 .41 r
.60546 .35366 m .60346 .35712 L .60637 .35562 L F
.585 .822 .989 r
.60972 .35471 m .60529 .35418 L .60524 .35381 L F
0 0 0 r
.61058 .35184 m .60935 .35233 L .60546 .35366 L F
.471 .707 .972 r
.60257 .35202 m .60546 .35366 L .60496 .35165 L F
.60257 .35202 m .60546 .35366 L .60496 .35165 L F
0 0 0 r
.60904 .35244 m .60896 .35248 L .60834 .35269 L F
.60935 .35233 m .60896 .35248 L .60904 .35244 L F
.60935 .35233 m .60834 .35269 L .60546 .35366 L F
.497 .727 .975 r
.60546 .35366 m .60896 .35248 L .60496 .35165 L F
.585 .822 .989 r
.60972 .35471 m .60496 .35165 L .60896 .35248 L F
.794 .459 0 r
.60797 .35121 m .60868 .35264 L .60896 .35248 L F
.60868 .35264 m .60972 .35471 L .60896 .35248 L F
.585 .822 .989 r
.60721 .3531 m .60524 .35381 L .60496 .35165 L F
.60972 .35471 m .60524 .35381 L .60721 .3531 L F
.383 .823 .684 r
.61156 .35112 m .61058 .35184 L .61316 .35094 L F
.61156 .35112 m .60896 .35248 L .61058 .35184 L F
.395 .833 .697 r
.64937 .39473 m .65339 .39278 L .65265 .39309 L F
0 0 0 r
.65339 .39278 m .65595 .39163 L .65563 .39226 L F
.65265 .39309 m .65339 .39278 L .65563 .39226 L F
.54 .542 .805 r
.23399 .58891 m .23786 .5923 L .23669 .58826 L F
.726 .574 .684 r
.34122 .6121 m .34062 .61497 L .33833 .61529 L F
.33833 .61529 m .34062 .61497 L .34122 .6121 L F
.691 .604 .755 r
.34413 .60933 m .34122 .6121 L .34015 .6083 L F
.53 .363 .599 r
.59432 .37066 m .59454 .3736 L .59698 .37011 L F
.59432 .37066 m .59454 .3736 L .59698 .37011 L F
.385 0 .113 r
.54512 .4773 m .54813 .47716 L .54891 .47475 L F
0 0 0 r
.54891 .47475 m .55001 .47528 L .55105 .47376 L F
.54891 .47475 m .54813 .47716 L .55001 .47528 L F
.188 0 0 r
.52697 .49815 m .52603 .49999 L .52348 .50036 L F
0 0 0 r
.52789 .49857 m .52697 .49815 L .52939 .49719 L F
.52789 .49857 m .52603 .49999 L .52697 .49815 L F
.924 .955 .788 r
.7291 .32328 m .73197 .32151 L .7307 .31999 L F
.7291 .32328 m .72992 .32454 L .73197 .32151 L F
.522 .244 .435 r
.68707 .29844 m .69002 .29803 L .69017 .29589 L F
.354 .111 .4 r
.69017 .29589 m .69251 .29689 L .69301 .29512 L F
.69017 .29589 m .69002 .29803 L .69251 .29689 L F
.788 .773 .838 r
.44757 .57004 m .44694 .57221 L .44519 .57305 L F
.753 .734 .835 r
.44978 .56899 m .44694 .57221 L .44757 .57004 L F
.131 0 0 r
.61906 .40649 m .61524 .40933 L .617 .4055 L F
.437 .762 .996 r
.62079 .40524 m .61906 .40649 L .617 .4055 L F
.77 .638 .715 r
.61911 .40909 m .62153 .40624 L .61906 .40649 L F
0 0 .328 r
.62049 .40704 m .61906 .40649 L .62079 .40524 L F
.62038 .407 m .61911 .40909 L .61906 .40649 L F
.673 .95 .956 r
.61356 .40135 m .61796 .40036 L .61609 .40014 L F
.588 .92 .699 r
.61947 .39873 m .61796 .40036 L .61988 .39871 L F
.611 .95 .921 r
.61609 .40014 m .61796 .40036 L .61947 .39873 L F
.557 .58 .832 r
.61897 .39971 m .617 .4055 L .61609 .40014 L F
.61897 .39971 m .62079 .40524 L .617 .4055 L F
.487 0 0 r
.62145 .40584 m .62395 .40566 L .62079 .40524 L F
.307 .378 .772 r
.62153 .40624 m .62509 .40723 L .62395 .40566 L F
.902 .883 .805 r
.62165 .40573 m .62395 .40566 L .62145 .40584 L F
.419 0 0 r
.62188 .40572 m .62395 .40566 L .62324 .40633 L F
.62079 .40524 m .62342 .40559 L .62186 .40571 L F
.77 .638 .715 r
.61911 .40909 m .623 .40992 L .62153 .40624 L F
.307 .378 .772 r
.62153 .40624 m .623 .40992 L .62509 .40723 L F
.419 0 0 r
.6205 .40695 m .62324 .40633 L .62049 .40704 L F
.62079 .40524 m .62186 .40571 L .6205 .40695 L F
.62186 .40571 m .62324 .40633 L .6205 .40695 L F
.902 .883 .805 r
.62466 .40314 m .62165 .40573 L .62571 .40033 L F
.6242 .40436 m .6221 .40548 L .62466 .40314 L F
.6221 .40548 m .62165 .40573 L .62466 .40314 L F
.62165 .40573 m .62145 .40584 L .62152 .40574 L F
.62165 .40573 m .62152 .40574 L .62571 .40033 L F
.419 0 0 r
.62186 .40571 m .62395 .40566 L .62188 .40572 L F
.62342 .40559 m .62395 .40566 L .62186 .40571 L F
.902 .883 .805 r
.6242 .40436 m .62395 .40566 L .62165 .40573 L F
0 0 .557 r
.62145 .40584 m .62079 .40524 L .61897 .39971 L F
.62145 .40584 m .61897 .39971 L .62175 .3997 L F
.713 .64 .774 r
.62571 .40033 m .62145 .40584 L .62175 .3997 L F
.718 .801 .916 r
.6214 .4036 m .61877 .40709 L .62162 .40366 L F
.61868 .40664 m .61877 .40709 L .6214 .4036 L F
.784 .727 .799 r
.61609 .40014 m .617 .4055 L .61344 .40507 L F
.806 .64 .677 r
.61344 .40507 m .617 .4055 L .61524 .40933 L F
.647 .754 .927 r
.6165 .40626 m .61877 .40709 L .61787 .40268 L F
.537 .815 .997 r
.61877 .40709 m .61936 .40682 L .62215 .40301 L F
.61936 .40682 m .62287 .40521 L .6222 .40317 L F
.61936 .40682 m .6222 .40317 L .62215 .40301 L F
.64 .755 .932 r
.61936 .40682 m .62049 .40704 L .61877 .40709 L F
.68 .734 .891 r
.61936 .40682 m .61923 .40702 L .62049 .40704 L F
.537 .815 .997 r
.61921 .40702 m .62049 .40704 L .62324 .40633 L F
.61877 .40709 m .62049 .40704 L .61921 .40702 L F
.68 .734 .891 r
.61923 .40702 m .61803 .4088 L .62049 .40704 L F
.61815 .40838 m .61803 .4088 L .61936 .40682 L F
.537 .815 .997 r
.61877 .40709 m .62324 .40633 L .62287 .40521 L F
.68 .734 .891 r
.61864 .40668 m .61815 .40838 L .61936 .40682 L F
.64 .755 .932 r
.6165 .40626 m .61936 .40682 L .61877 .40709 L F
.68 .734 .891 r
.6165 .40626 m .61751 .40795 L .61864 .40668 L F
.61751 .40795 m .61803 .4088 L .61864 .40668 L F
.718 .801 .916 r
.61787 .40268 m .61868 .40664 L .6214 .4036 L F
.62187 .40299 m .62162 .40366 L .62215 .40301 L F
.61787 .40268 m .62162 .40366 L .62187 .40299 L F
0 0 .328 r
.62049 .40704 m .62022 .40745 L .62038 .407 L F
.62022 .40745 m .61911 .40909 L .62038 .407 L F
0 0 .376 r
.42053 .52898 m .4177 .52697 L .41947 .52714 L F
.547 .402 .636 r
.49976 .49824 m .50274 .50032 L .50249 .49745 L F
.522 .408 .665 r
.50017 .50108 m .50274 .50032 L .49976 .49824 L F
.565 .336 .528 r
.33571 .61859 m .33564 .62141 L .33196 .62155 L F
.577 .83 .464 r
.33571 .61859 m .33833 .61529 L .33836 .61815 L F
.627 .443 .614 r
.33836 .61815 m .33564 .62141 L .33571 .61859 L F
.629 .614 .817 r
.34165 .55322 m .34516 .55556 L .34441 .55462 L F
.586 .426 .631 r
.34516 .55556 m .34802 .5529 L .34441 .55462 L F
.34516 .55556 m .34822 .5553 L .34802 .5529 L F
.333 0 0 r
.34516 .55556 m .34633 .55743 L .34822 .5553 L F
.34516 .55556 m .34284 .55827 L .34633 .55743 L F
.901 .884 .807 r
.46627 .54942 m .46634 .55253 L .46508 .55159 L F
.771 .908 .519 r
.46634 .55253 m .46477 .55437 L .46508 .55159 L F
.394 .233 .541 r
.47754 .53252 m .47986 .53262 L .47924 .5301 L F
.212 .008 .371 r
.47662 .53654 m .47986 .53262 L .47754 .53252 L F
.594 .886 .991 r
.43971 .48805 m .43749 .48727 L .44069 .48618 L F
.43971 .48805 m .43749 .48727 L .44069 .48618 L F
.893 .506 .289 r
.38367 .51661 m .38044 .51302 L .38315 .51443 L F
.716 .347 .35 r
.44953 .46351 m .44761 .46198 L .44738 .46337 L F
.871 .468 .263 r
.71716 .27417 m .71842 .2729 L .71547 .27112 L F
.801 .36 .197 r
.71716 .27417 m .71939 .27506 L .71842 .2729 L F
.971 .842 .657 r
.32893 .61172 m .32704 .61164 L .32808 .60737 L F
.935 .802 .688 r
.32893 .61172 m .3259 .61381 L .32704 .61164 L F
.32893 .61172 m .32782 .61515 L .3259 .61381 L F
.567 .358 .557 r
.4435 .45733 m .44322 .46116 L .44041 .46113 L F
.496 .29 .53 r
.44604 .4552 m .44584 .45784 L .4435 .45733 L F
.712 .929 .602 r
.44584 .45784 m .44322 .46116 L .4435 .45733 L F
.544 .676 .925 r
.61864 .37898 m .61905 .38175 L .61863 .38161 L F
.61864 .37898 m .61905 .38175 L .61863 .38161 L F
.907 .912 .813 r
.62298 .37603 m .61905 .38175 L .61864 .37898 L F
.496 .696 .958 r
.61905 .38175 m .62133 .37885 L .61864 .37898 L F
.61905 .38175 m .6231 .3814 L .62133 .37885 L F
.978 .916 .652 r
.43172 .54826 m .43336 .54734 L .43129 .54568 L F
.43172 .54826 m .43231 .54998 L .43336 .54734 L F
.771 .748 .832 r
.63459 .38858 m .63871 .38935 L .63685 .39073 L F
.623 .497 .687 r
.54559 .42247 m .54691 .42189 L .54442 .42279 L F
.648 .434 .58 r
.53521 .39957 m .54105 .40087 L .5387 .39656 L F
.428 .345 .66 r
.5387 .39656 m .54222 .39902 L .54135 .39595 L F
.796 .547 .56 r
.33794 .58268 m .33403 .58462 L .334 .58219 L F
.33794 .58268 m .33781 .58534 L .33403 .58462 L F
.327 .16 .496 r
.34046 .57882 m .34019 .58182 L .33794 .58268 L F
.357 .181 .5 r
.34026 .58433 m .33794 .58268 L .34019 .58182 L F
.34026 .58433 m .33781 .58534 L .33794 .58268 L F
.911 .515 .231 r
.43499 .56836 m .43556 .56681 L .43459 .5659 L F
.43591 .56912 m .43744 .57037 L .43603 .5677 L F
.925 .597 .137 r
.43499 .56836 m .43674 .57197 L .43744 .57037 L F
.579 .17 .231 r
.43539 .57079 m .43929 .5687 L .43674 .57197 L F
.43579 .57058 m .43777 .57121 L .43929 .5687 L F
.43539 .57079 m .43576 .57086 L .43579 .57058 L F
.43576 .57086 m .43777 .57121 L .43579 .57058 L F
.911 .515 .231 r
.43499 .56836 m .43591 .56912 L .43556 .56681 L F
.43591 .56912 m .43603 .5677 L .43556 .56681 L F
.797 .56 .578 r
.5255 .3993 m .52945 .40265 L .52957 .39997 L F
.839 .998 .824 r
.54894 .46402 m .55229 .4617 L .55274 .463 L F
.907 .912 .813 r
.62298 .37603 m .61864 .37898 L .62128 .37639 L F
0 .57 .769 r
.62416 .37594 m .62298 .37603 L .62128 .37639 L F
.62416 .37594 m .62536 .3762 L .6235 .37607 L F
.013 .447 .868 r
.62478 .37583 m .62416 .37594 L .62269 .37631 L F
.811 .889 .466 r
.62831 .375 m .62629 .37998 L .62536 .3762 L F
.526 .918 .903 r
.62831 .375 m .62416 .37594 L .62693 .37703 L F
.013 .447 .868 r
.62571 .37561 m .62693 .37703 L .62416 .37594 L F
.62571 .37561 m .62416 .37594 L .62478 .37583 L F
0 .57 .769 r
.62416 .37594 m .6235 .37607 L .62298 .37603 L F
.957 .645 .394 r
.39695 .53644 m .39516 .53546 L .39497 .53284 L F
.866 .654 .614 r
.3978 .54006 m .39516 .53546 L .39695 .53644 L F
.753 .675 .776 r
.43674 .57197 m .4383 .57334 L .43404 .57255 L F
.852 .882 .861 r
.4383 .57334 m .43406 .5754 L .43404 .57255 L F
.623 .276 .361 r
.44115 .57327 m .44154 .57534 L .4383 .57334 L F
0 0 0 r
.35726 .55745 m .35638 .55956 L .35778 .55624 L F
0 .004 .568 r
.25523 .54177 m .25468 .54359 L .25369 .53974 L F
.743 .991 .878 r
.25523 .54177 m .25388 .54273 L .25468 .54359 L F
.25388 .54273 m .25175 .54425 L .25322 .54392 L F
.25388 .54273 m .25322 .54392 L .25468 .54359 L F
.798 .97 .91 r
.25523 .54177 m .25365 .54328 L .25175 .54425 L F
0 .004 .568 r
.25523 .54177 m .25369 .53974 L .25395 .53903 L F
0 0 .508 r
.2536 .53793 m .25523 .54177 L .25395 .53903 L F
.844 .861 .41 r
.25623 .53781 m .25523 .54177 L .2536 .53793 L F
0 0 .481 r
.25522 .54023 m .25365 .54328 L .25523 .54177 L F
.25454 .54155 m .25576 .54282 L .25365 .54328 L F
.25522 .54023 m .25523 .54031 L .25454 .54155 L F
.844 .861 .41 r
.25623 .53781 m .25522 .54023 L .25523 .54177 L F
0 0 .481 r
.25523 .54031 m .25576 .54282 L .25454 .54155 L F
0 0 0 r
.25576 .54282 m .25513 .54349 L .25365 .54328 L F
.25513 .54349 m .25285 .54592 L .25348 .54386 L F
.25513 .54349 m .25348 .54386 L .25365 .54328 L F
.554 .924 .934 r
.25009 .54462 m .25225 .54414 L .25175 .54425 L F
.25225 .54414 m .25468 .54359 L .25277 .54402 L F
.25225 .54414 m .25277 .54402 L .25175 .54425 L F
.979 .721 .467 r
.38774 .57444 m .38955 .57289 L .3877 .5719 L F
.38774 .57444 m .38943 .57559 L .38955 .57289 L F
.846 .95 .884 r
.39255 .48038 m .39687 .47834 L .393 .47771 L F
.726 .989 .862 r
.52837 .41876 m .52734 .42024 L .52952 .41866 L F
.594 .822 .432 r
.5262 .42177 m .52734 .42024 L .52837 .41876 L F
0 0 0 r
.46159 .57401 m .463 .57354 L .46313 .57356 L F
.463 .57354 m .46509 .57283 L .46313 .57356 L F
.013 .211 .721 r
.46509 .57283 m .46742 .57493 L .46594 .57111 L F
.321 .253 .623 r
.46576 .57606 m .46742 .57493 L .46509 .57283 L F
.153 0 .099 r
.46313 .57356 m .4655 .57287 L .46526 .57384 L F
.897 .569 .078 r
.46594 .57111 m .46722 .5744 L .46656 .57389 L F
.46722 .5744 m .46742 .57493 L .46656 .57389 L F
.898 .685 .606 r
.46656 .57389 m .46582 .57414 L .4662 .57361 L F
0 0 .356 r
.46594 .57111 m .46656 .57389 L .46703 .57222 L F
.898 .685 .606 r
.46656 .57389 m .4662 .57361 L .46692 .5726 L F
.46582 .57414 m .46405 .57475 L .46507 .57398 L F
.46582 .57414 m .46507 .57398 L .46692 .5726 L F
.153 0 .099 r
.46313 .57356 m .46526 .57384 L .46507 .57398 L F
.46313 .57356 m .46507 .57398 L .46329 .57359 L F
.46507 .57398 m .46526 .57384 L .46522 .57401 L F
.46507 .57398 m .46522 .57401 L .46501 .57396 L F
.46507 .57398 m .46501 .57396 L .46329 .57359 L F
.898 .685 .606 r
.46692 .5726 m .46541 .5737 L .46703 .57222 L F
0 0 .356 r
.46526 .57384 m .46703 .57222 L .46522 .57401 L F
.46594 .57111 m .46703 .57222 L .46526 .57384 L F
.013 .211 .721 r
.46509 .57283 m .46594 .57111 L .46313 .57356 L F
.153 0 .099 r
.46313 .57356 m .46594 .57111 L .4655 .57287 L F
.345 .583 .932 r
.46207 .57333 m .46501 .57396 L .4631 .57182 L F
.898 .685 .606 r
.46405 .57475 m .46392 .57479 L .46692 .5726 L F
.345 .583 .932 r
.46501 .57396 m .46522 .57401 L .46506 .57385 L F
.704 .718 .861 r
.4631 .57182 m .46703 .57222 L .46506 .57385 L F
.345 .583 .932 r
.46501 .57396 m .46506 .57385 L .4631 .57182 L F
.704 .718 .861 r
.4631 .57182 m .46506 .57385 L .46392 .57479 L F
.345 .583 .932 r
.46506 .57385 m .46506 .57385 L .4631 .57182 L F
.898 .685 .606 r
.46541 .5737 m .46499 .57401 L .46703 .57222 L F
.46499 .57401 m .46392 .57479 L .46506 .57385 L F
.46499 .57401 m .46506 .57385 L .46703 .57222 L F
.153 0 .099 r
.46313 .57356 m .46329 .57359 L .46207 .57333 L F
0 0 0 r
.46144 .57406 m .46159 .57401 L .46313 .57356 L F
.553 .255 .417 r
.30184 .57318 m .30405 .57256 L .30185 .57272 L F
.225 .741 .728 r
.59927 .37747 m .59463 .37863 L .59605 .37836 L F
.632 .937 .963 r
.4322 .4478 m .43128 .4496 L .42922 .44918 L F
.4322 .4478 m .43371 .44825 L .43128 .4496 L F
.769 .467 .476 r
.72893 .2926 m .72739 .29314 L .72618 .29223 L F
.879 .963 .848 r
.73063 .29056 m .72932 .29073 L .72893 .2926 L F
0 0 .545 r
.72932 .29073 m .72996 .29448 L .72893 .2926 L F
.982 .911 .628 r
.33811 .53213 m .3368 .5384 L .3382 .53426 L F
.675 .505 .648 r
.33564 .62141 m .33194 .62499 L .33196 .62155 L F
.231 0 0 r
.42401 .5991 m .42426 .59949 L .42234 .60128 L F
.42401 .5991 m .42658 .59935 L .42426 .59949 L F
.687 .767 .912 r
.72857 .28585 m .73139 .28454 L .73206 .28652 L F
.573 .007 0 r
.73198 .28755 m .73206 .28652 L .73139 .28454 L F
.73198 .28755 m .73374 .28744 L .73206 .28652 L F
.848 .951 .882 r
.55103 .40379 m .54705 .40555 L .54957 .40248 L F
0 0 0 r
.40966 .51189 m .40797 .51413 L .41022 .51065 L F
.486 .53 .828 r
.40966 .51189 m .41106 .51491 L .40797 .51413 L F
.056 .086 .575 r
.57294 .36719 m .5741 .36371 L .57488 .36528 L F
.57294 .36719 m .57521 .36599 L .5741 .36371 L F
0 0 .271 r
.57387 .36981 m .57522 .36602 L .57294 .36719 L F
.092 .428 .871 r
.57629 .36442 m .57488 .36528 L .5741 .36371 L F
.57629 .36442 m .57785 .36655 L .57488 .36528 L F
.801 .714 .769 r
.57523 .36419 m .5752 .36742 L .57629 .36442 L F
0 0 .271 r
.57522 .36602 m .57523 .36598 L .57521 .36599 L F
.57522 .36602 m .57521 .36599 L .57294 .36719 L F
.801 .714 .769 r
.57504 .36716 m .5752 .36742 L .57521 .36603 L F
0 0 .271 r
.57387 .36981 m .57486 .36835 L .57522 .36602 L F
.801 .714 .769 r
.57293 .36371 m .57486 .36835 L .5752 .36742 L F
0 0 .271 r
.57522 .36602 m .57486 .36835 L .57523 .36598 L F
.801 .714 .769 r
.57293 .36371 m .57504 .36716 L .57521 .36599 L F
.57504 .36716 m .57521 .36603 L .57521 .36599 L F
.57514 .36417 m .57521 .36599 L .57523 .36419 L F
.056 .086 .575 r
.57521 .36599 m .57521 .36595 L .57481 .36514 L F
.5748 .36515 m .57481 .36514 L .5741 .36371 L F
.57521 .36599 m .57481 .36514 L .5748 .36515 L F
.851 .394 .022 r
.5741 .36371 m .57521 .36595 L .57293 .36371 L F
.801 .714 .769 r
.57293 .36371 m .57521 .36599 L .57521 .36595 L F
.851 .394 .022 r
.57521 .36595 m .57523 .36598 L .57293 .36371 L F
.801 .714 .769 r
.57293 .36371 m .57521 .36595 L .57514 .36417 L F
.407 .86 .835 r
.5741 .36371 m .57586 .3626 L .57629 .36442 L F
.5741 .36371 m .57293 .36371 L .57586 .3626 L F
.801 .714 .769 r
.57293 .36371 m .57523 .36419 L .57586 .3626 L F
.57523 .36419 m .57629 .36442 L .57589 .36273 L F
.57523 .36419 m .57589 .36273 L .57586 .3626 L F
.056 .086 .575 r
.57521 .36599 m .57523 .36598 L .57521 .36595 L F
.463 .222 .462 r
.51091 .4876 m .51394 .487 L .51445 .48508 L F
.403 .187 .468 r
.51107 .49231 m .51394 .487 L .51091 .4876 L F
.197 .727 .787 r
.42426 .59949 m .42658 .59935 L .42881 .59893 L F
.714 .724 .858 r
.60686 .44434 m .61028 .44523 L .60789 .44666 L F
.791 .603 .648 r
.73723 .29813 m .7339 .29529 L .73564 .29689 L F
.941 .861 .733 r
.73406 .30023 m .73723 .29813 L .73564 .29689 L F
.73406 .30023 m .73545 .30169 L .73723 .29813 L F
.962 .756 .579 r
.33503 .50463 m .33413 .50689 L .33266 .50312 L F
.155 .184 .639 r
.3138 .58503 m .31321 .58822 L .31831 .58467 L F
.3138 .58503 m .31482 .58841 L .31321 .58822 L F
.189 0 .088 r
.31482 .58841 m .31354 .59053 L .31321 .58822 L F
.945 .596 .2 r
.29781 .64895 m .30032 .6544 L .29926 .65263 L F
.615 .666 .876 r
.29926 .65263 m .30032 .6544 L .2991 .65379 L F
.535 .397 .64 r
.50697 .42537 m .50434 .42611 L .50681 .42263 L F
.50697 .42537 m .50434 .42611 L .50681 .42263 L F
.833 .753 .775 r
.33376 .56606 m .33713 .5629 L .33286 .56298 L F
.428 .369 .689 r
.33713 .5629 m .33935 .56232 L .33882 .55951 L F
0 .035 .605 r
.33713 .5629 m .3392 .56526 L .33935 .56232 L F
.984 .726 .456 r
.52127 .4041 m .5233 .40247 L .5198 .40097 L F
.52127 .4041 m .52283 .4055 L .5233 .40247 L F
.307 .152 .501 r
.5233 .40247 m .52536 .40206 L .5255 .3993 L F
.798 .544 .553 r
.31394 .58237 m .31831 .58467 L .31762 .58327 L F
.31394 .58237 m .3138 .58503 L .31831 .58467 L F
.5 .482 .769 r
.31831 .58467 m .31995 .58269 L .31762 .58327 L F
.31831 .58467 m .3209 .58442 L .31995 .58269 L F
.647 .968 .841 r
.4134 .50846 m .4112 .50901 L .41022 .51065 L F
.442 .418 .737 r
.4112 .50901 m .40966 .51189 L .41022 .51065 L F
.191 0 0 r
.6075 .34472 m .61164 .34431 L .60886 .34443 L F
.878 .744 .71 r
.38731 .59803 m .39078 .59499 L .38961 .59397 L F
.38731 .59803 m .38973 .59924 L .39078 .59499 L F
.156 0 .134 r
.40621 .50718 m .40857 .50637 L .40916 .5044 L F
.549 .928 .91 r
.40857 .50637 m .41185 .50509 L .40903 .50484 L F
.40857 .50637 m .40973 .50522 L .41185 .50509 L F
.145 0 0 r
.41185 .50509 m .40973 .50522 L .41405 .50528 L F
.025 .586 .806 r
.41185 .50509 m .41421 .50529 L .41624 .50574 L F
.145 0 0 r
.41185 .50509 m .41405 .50528 L .41421 .50529 L F
.549 .928 .91 r
.40903 .50484 m .41185 .50509 L .40916 .5044 L F
.711 .469 .557 r
.3368 .5384 m .33461 .53965 L .33476 .53696 L F
.697 .884 .967 r
.50427 .40996 m .50009 .40991 L .50277 .40865 L F
.782 .903 .927 r
.506 .40798 m .50427 .40996 L .50277 .40865 L F
0 0 .472 r
.61471 .3706 m .61647 .37122 L .61682 .36909 L F
.61471 .3706 m .61511 .37401 L .61647 .37122 L F
.583 .095 .063 r
.59678 .3536 m .59597 .35559 L .59302 .35512 L F
.604 .929 .71 r
.59955 .35128 m .59821 .35192 L .59678 .3536 L F
.099 0 0 r
.59871 .3545 m .59678 .3536 L .59821 .35192 L F
.59871 .3545 m .59597 .35559 L .59678 .3536 L F
.638 .183 .156 r
.40227 .50724 m .40485 .50915 L .40621 .50718 L F
.3 0 .117 r
.40485 .50915 m .40857 .50637 L .40621 .50718 L F
.695 .92 .969 r
.45762 .4378 m .45667 .44006 L .45408 .43968 L F
.45762 .4378 m .45907 .4387 L .45667 .44006 L F
.712 .766 .895 r
.34445 .52429 m .34332 .52814 L .34067 .52517 L F
.968 .666 .394 r
.38936 .58093 m .3909 .57945 L .38935 .5783 L F
.38936 .58093 m .3911 .58197 L .3909 .57945 L F
.679 .704 .866 r
.48334 .45509 m .48451 .45063 L .48199 .4519 L F
.48334 .45509 m .48591 .45384 L .48451 .45063 L F
.737 .564 .659 r
.48336 .45782 m .48591 .45384 L .48334 .45509 L F
0 0 .096 r
.49819 .52902 m .49679 .53061 L .49894 .52697 L F
0 0 .097 r
.49819 .52902 m .49578 .53289 L .49679 .53061 L F
.016 .119 .629 r
.23076 .6052 m .23137 .60888 L .23237 .60705 L F
.367 .578 .922 r
.23137 .60888 m .23511 .61031 L .23237 .60705 L F
.132 .463 .889 r
.23137 .60888 m .23578 .612 L .23511 .61031 L F
.602 .842 .471 r
.32982 .51741 m .3327 .51364 L .33072 .51487 L F
0 0 0 r
.31799 .62673 m .31961 .62447 L .3168 .62743 L F
.31799 .62673 m .3168 .62743 L .31551 .62721 L F
0 .272 .643 r
.36305 .60218 m .36297 .60212 L .36064 .60099 L F
.401 .253 .563 r
.36305 .60218 m .36283 .60511 L .36512 .60416 L F
.36305 .60218 m .36512 .60416 L .36297 .60212 L F
.107 .287 .764 r
.28508 .51156 m .28623 .50972 L .28318 .50974 L F
.482 .264 .506 r
.24404 .60045 m .2432 .60424 L .24427 .60295 L F
.891 .541 .377 r
.59151 .39347 m .58918 .39433 L .58913 .39228 L F
.59151 .39347 m .59207 .3959 L .58918 .39433 L F
.858 .993 .828 r
.54222 .39902 m .54283 .39995 L .54562 .39692 L F
.962 .829 .403 r
.54222 .39902 m .54167 .40223 L .54283 .39995 L F
0 .369 .825 r
.61994 .36685 m .62373 .36961 L .62362 .36712 L F
.871 .805 .782 r
.44345 .47548 m .43975 .47939 L .4391 .47664 L F
.44345 .47548 m .4391 .47664 L .44215 .47627 L F
.823 .348 .051 r
.44215 .47627 m .44555 .47858 L .44345 .47548 L F
.662 .962 .932 r
.72534 .32592 m .72992 .32454 L .7291 .32328 L F
.921 .529 .17 r
.40524 .58728 m .40297 .58461 L .40559 .58586 L F
.782 .662 .731 r
.54135 .39595 m .54562 .39692 L .5438 .3927 L F
.858 .993 .828 r
.54222 .39902 m .54562 .39692 L .54135 .39595 L F
.562 .553 .802 r
.5438 .3927 m .54562 .39692 L .54803 .39584 L F
.427 .238 .521 r
.54562 .39692 m .54803 .39844 L .54803 .39584 L F
.744 .884 .943 r
.61047 .42741 m .61173 .42444 L .60876 .42565 L F
.61047 .42741 m .61297 .42576 L .61173 .42444 L F
.951 .952 .717 r
.38193 .60719 m .38275 .60875 L .38413 .60606 L F
0 0 0 r
.38193 .60719 m .38413 .60606 L .38643 .60505 L F
.405 .048 .242 r
.22736 .55706 m .22874 .55843 L .22858 .55576 L F
.22736 .55706 m .2263 .5592 L .22874 .55843 L F
.841 .69 .694 r
.51856 .46157 m .52221 .46182 L .52074 .45797 L F
.663 .603 .778 r
.52074 .45797 m .52221 .46182 L .52501 .45898 L F
0 0 0 r
.25381 .52778 m .25407 .52648 L .25627 .52546 L F
.25381 .52778 m .25175 .52843 L .25407 .52648 L F
.935 .867 .746 r
.34129 .5105 m .33803 .51279 L .34082 .50954 L F
.34129 .5105 m .33959 .51401 L .33803 .51279 L F
.928 .908 .782 r
.55706 .46528 m .55547 .46836 L .55398 .46695 L F
.981 .864 .648 r
.55398 .46695 m .55547 .46836 L .55429 .47107 L F
.278 0 0 r
.56737 .43613 m .56998 .43766 L .56722 .43797 L F
.56737 .43613 m .57172 .43743 L .56998 .43766 L F
.599 .818 .984 r
.63751 .38757 m .63871 .38935 L .63459 .38858 L F
.834 .911 .889 r
.64154 .38644 m .63871 .38935 L .63751 .38757 L F
.716 .631 .761 r
.40016 .49169 m .39547 .48816 L .39829 .48742 L F
.40016 .49169 m .39543 .49211 L .39547 .48816 L F
.401 .852 .899 r
.40016 .49169 m .39509 .49267 L .39543 .49211 L F
.40016 .49169 m .39815 .49166 L .39509 .49267 L F
.687 .608 .762 r
.40183 .49067 m .40016 .49169 L .39829 .48742 L F
.592 .94 .933 r
.40117 .49028 m .40016 .49169 L .40183 .49067 L F
.40117 .49028 m .39815 .49166 L .40016 .49169 L F
0 0 .313 r
.52462 .44042 m .52305 .43551 L .52288 .43738 L F
.773 .802 .877 r
.52013 .44125 m .52462 .44042 L .52288 .43738 L F
.648 .677 .864 r
.52462 .44042 m .52455 .43613 L .52288 .43738 L F
.52462 .44042 m .52742 .43929 L .52455 .43613 L F
.52462 .44042 m .52455 .43613 L .52288 .43738 L F
.52462 .44042 m .52742 .43929 L .52455 .43613 L F
.751 .233 0 r
.37926 .51134 m .3784 .512 L .37655 .50958 L F
.758 .243 0 r
.37926 .51134 m .38044 .51302 L .3784 .512 L F
.58 .82 .99 r
.26216 .52024 m .26666 .5209 L .26461 .51944 L F
.191 0 0 r
.26758 .52211 m .26666 .5209 L .26947 .52003 L F
.26758 .52211 m .26476 .52291 L .26666 .5209 L F
.403 .845 .733 r
.53423 .44016 m .53719 .43879 L .53624 .43969 L F
0 0 .408 r
.53777 .43736 m .53719 .43879 L .53687 .43504 L F
.729 .908 .539 r
.53624 .43969 m .53719 .43879 L .53777 .43736 L F
.232 .751 .824 r
.59174 .36337 m .59441 .36291 L .59632 .36289 L F
.015 .59 .712 r
.59632 .36289 m .59441 .36291 L .59796 .36286 L F
.129 .178 .646 r
.22501 .56246 m .22557 .56622 L .22699 .56425 L F
.2 .279 .721 r
.22557 .56622 m .22796 .56814 L .22699 .56425 L F
.578 .942 .835 r
.55093 .42884 m .55224 .42845 L .55567 .42628 L F
.913 .682 .575 r
.37831 .54449 m .38021 .54341 L .37993 .54291 L F
.37831 .54449 m .37988 .54614 L .38021 .54341 L F
.865 .714 .692 r
.44519 .57305 m .44154 .57534 L .44115 .57327 L F
.44519 .57305 m .44448 .57596 L .44154 .57534 L F
.591 .371 .551 r
.50975 .4192 m .50959 .42204 L .50681 .42263 L F
.988 .741 .468 r
.50975 .4192 m .50959 .42204 L .5082 .41794 L F
.5082 .41794 m .50959 .42204 L .50975 .4192 L F
.364 .462 .827 r
.35777 .60408 m .35801 .60839 L .35784 .60552 L F
.685 .223 .15 r
.42293 .57784 m .42485 .57608 L .42173 .57543 L F
.205 0 0 r
.4264 .5775 m .42485 .57608 L .42293 .57784 L F
.4264 .5775 m .42719 .57534 L .42485 .57608 L F
.563 .777 .979 r
.71422 .32689 m .71617 .32486 L .71287 .32618 L F
.71422 .32689 m .71724 .3264 L .71617 .32486 L F
.877 .928 .543 r
.32579 .60093 m .3249 .6009 L .3264 .59791 L F
.722 .221 0 r
.32579 .60093 m .32768 .60366 L .3249 .6009 L F
0 .395 .828 r
.40035 .50432 m .40018 .50355 L .39857 .50362 L F
0 .015 .588 r
.40129 .5046 m .40035 .50432 L .39857 .50362 L F
.40129 .5046 m .40083 .50505 L .40035 .50432 L F
.232 .318 .747 r
.40018 .50355 m .40129 .5046 L .39857 .50362 L F
.741 .251 .072 r
.40018 .50355 m .39942 .50452 L .40129 .5046 L F
.222 .739 .859 r
.40129 .5046 m .39942 .50452 L .40155 .50434 L F
.40129 .5046 m .40155 .50434 L .40287 .50424 L F
0 .015 .588 r
.40129 .5046 m .40227 .50724 L .40083 .50505 L F
.672 .93 .971 r
.35092 .64773 m .3525 .64861 L .3547 .64735 L F
.447 .408 .722 r
.54608 .45095 m .54416 .45487 L .54332 .4517 L F
.54608 .45095 m .54728 .45497 L .54416 .45487 L F
.323 0 0 r
.54416 .45487 m .54608 .45611 L .54341 .45663 L F
.54416 .45487 m .54728 .45497 L .54647 .45574 L F
.54416 .45487 m .54647 .45574 L .54575 .4559 L F
.565 .675 .913 r
.5433 .45644 m .54556 .45348 L .54185 .45403 L F
.54341 .45663 m .54359 .45637 L .5433 .45644 L F
.54359 .45637 m .54556 .45348 L .5433 .45644 L F
.323 0 0 r
.54575 .4559 m .54647 .45574 L .54608 .45611 L F
0 0 0 r
.23399 .56525 m .23267 .56645 L .23508 .56328 L F
.309 .107 .436 r
.23399 .56525 m .23161 .56898 L .23267 .56645 L F
.765 .667 .754 r
.6286 .41943 m .63108 .41603 L .62842 .41638 L F
.969 .65 .329 r
.62735 .42073 m .62919 .42244 L .6286 .41943 L F
0 .495 .803 r
.71724 .3264 m .72086 .32756 L .71978 .32649 L F
.407 .749 .994 r
.72086 .32756 m .72377 .32753 L .71978 .32649 L F
.768 .919 .938 r
.48008 .42553 m .47669 .42588 L .47841 .42389 L F
.752 .832 .913 r
.48299 .42321 m .48008 .42553 L .47841 .42389 L F
.275 .765 .908 r
.33356 .49722 m .33293 .49789 L .33083 .49903 L F
.33356 .49722 m .3353 .49759 L .33293 .49789 L F
.735 .745 .86 r
.43623 .5393 m .43755 .54185 L .44033 .53984 L F
.576 .433 .65 r
.63149 .35441 m .63177 .35712 L .6345 .35374 L F
0 0 .079 r
.23643 .56206 m .23508 .56328 L .23737 .55957 L F
.193 0 .127 r
.23602 .56421 m .23508 .56328 L .23643 .56206 L F
.23602 .56421 m .23399 .56525 L .23508 .56328 L F
.538 .629 .89 r
.71212 .30841 m .71006 .30869 L .70899 .30726 L F
.71212 .30841 m .71009 .31129 L .71006 .30869 L F
.713 .515 .619 r
.33833 .61529 m .34062 .61497 L .33836 .61815 L F
.33833 .61529 m .34062 .61497 L .33836 .61815 L F
.793 .697 .759 r
.36206 .58565 m .35923 .58908 L .36163 .58849 L F
.639 .275 .338 r
.35923 .58908 m .36183 .59114 L .36163 .58849 L F
.31 .16 .509 r
.36163 .58849 m .36454 .58505 L .36206 .58565 L F
.36163 .58849 m .36445 .58782 L .36454 .58505 L F
.254 .005 .33 r
.36163 .58849 m .36183 .59114 L .36445 .58782 L F
.098 0 .233 r
.24162 .53069 m .24276 .53163 L .24413 .53013 L F
.24162 .53069 m .24104 .53294 L .24276 .53163 L F
.895 .615 .504 r
.36321 .51718 m .36314 .51978 L .36544 .52036 L F
.899 .66 .569 r
.36314 .51978 m .36261 .5228 L .36544 .52036 L F
.809 .498 .463 r
.36544 .52036 m .36261 .5228 L .36516 .52298 L F
.396 .135 .397 r
.48076 .45859 m .47791 .4622 L .48066 .46136 L F
.637 .368 .494 r
.48066 .46136 m .48309 .46015 L .48076 .45859 L F
.584 .586 .821 r
.48076 .45859 m .48454 .46084 L .48336 .45782 L F
.508 .424 .695 r
.48076 .45859 m .48309 .46015 L .48336 .45782 L F
.439 .277 .563 r
.27927 .61742 m .27698 .61522 L .27951 .61469 L F
.27927 .61742 m .27666 .61828 L .27698 .61522 L F
.27927 .61742 m .27698 .61522 L .27951 .61469 L F
.27927 .61742 m .27666 .61828 L .27698 .61522 L F
.822 .526 0 r
.71207 .29234 m .71238 .29414 L .71283 .295 L F
.591 .7 .919 r
.42584 .45774 m .4297 .45889 L .42886 .45716 L F
.305 .551 .92 r
.4297 .45889 m .43058 .45719 L .42886 .45716 L F
.095 .279 .761 r
.4297 .45889 m .43212 .46081 L .43058 .45719 L F
.952 .675 .226 r
.4214 .57146 m .42278 .57338 L .4215 .56873 L F
0 0 0 r
.42232 .57502 m .42173 .57543 L .42278 .57338 L F
.42232 .57502 m .42278 .57338 L .4214 .57146 L F
.66574 .37083 m .66322 .37424 L .66479 .37234 L F
.363 .448 .814 r
.46698 .53773 m .46821 .53547 L .46398 .53295 L F
0 0 0 r
.46548 .53971 m .4663 .53897 L .46698 .53773 L F
.261 0 0 r
.46794 .53866 m .46698 .53773 L .4663 .53897 L F
.051 .616 .776 r
.46654 .59507 m .465 .59492 L .4624 .59489 L F
.245 .578 .943 r
.54848 .40927 m .54986 .40817 L .54692 .40893 L F
0 0 0 r
.54978 .4082 m .54692 .40893 L .54986 .40817 L F
.399 .834 .95 r
.54455 .40953 m .54848 .40927 L .54692 .40893 L F
.54446 .40953 m .54848 .40927 L .54692 .40893 L F
0 0 0 r
.54573 .40984 m .54692 .40893 L .54978 .4082 L F
.399 .834 .95 r
.54446 .40953 m .54455 .40953 L .54692 .40893 L F
.245 .578 .943 r
.54848 .40927 m .55087 .40981 L .54986 .40817 L F
.663 .111 0 r
.3378 .50858 m .33654 .50912 L .33413 .50689 L F
.361 0 0 r
.34082 .50954 m .33654 .50912 L .3378 .50858 L F
.89 .96 .836 r
.55864 .461 m .5599 .46195 L .55706 .46528 L F
.919 .952 .798 r
.56222 .45834 m .5599 .46195 L .55864 .461 L F
.756 .986 .756 r
.34415 .51796 m .34216 .51885 L .34231 .51978 L F
0 0 0 r
.34442 .51805 m .34216 .51885 L .34415 .51796 L F
.445 .319 .614 r
.34442 .51805 m .34438 .52112 L .34216 .51885 L F
0 .11 .656 r
.34216 .51885 m .34339 .51908 L .34201 .51793 L F
.34216 .51885 m .34201 .51793 L .34085 .51696 L F
.756 .986 .756 r
.34231 .51978 m .34216 .51885 L .34151 .52059 L F
0 0 0 r
.34442 .51805 m .34415 .51796 L .34653 .51863 L F
.99 .847 .606 r
.58356 .40572 m .58444 .40317 L .5831 .40182 L F
.924 .754 .653 r
.58444 .40317 m .58303 .39908 L .5831 .40182 L F
.027 0 .45 r
.34171 .57523 m .34054 .57627 L .34347 .57613 L F
.34171 .57523 m .34046 .57882 L .34054 .57627 L F
.615 .666 .876 r
.29926 .65263 m .2991 .65379 L .30131 .65362 L F
.41 .589 .916 r
.2991 .65379 m .30234 .65531 L .30131 .65362 L F
.374 .793 .976 r
.61721 .3512 m .61596 .35061 L .61316 .35094 L F
.576 .891 .989 r
.61905 .34927 m .61721 .3512 L .61952 .34985 L F
.61905 .34927 m .61596 .35061 L .61721 .3512 L F
.952 .834 .691 r
.38905 .58818 m .38967 .59185 L .39031 .58911 L F
.99 .874 .615 r
.39003 .58481 m .38905 .58818 L .39031 .58911 L F
.814 .573 .574 r
.68623 .32471 m .68229 .32654 L .68217 .32411 L F
.68623 .32471 m .68618 .32743 L .68229 .32654 L F
.658 .883 .981 r
.62842 .41638 m .63108 .41603 L .63004 .4148 L F
.279 0 .153 r
.24895 .52619 m .25262 .52245 L .25006 .52336 L F
.298 .074 .396 r
.48976 .51676 m .4923 .51351 L .49064 .51495 L F
0 .438 .785 r
.30705 .58889 m .30854 .58972 L .30561 .58836 L F
.30705 .58889 m .30854 .58972 L .30561 .58836 L F
.121 .319 .789 r
.30854 .58972 m .3095 .58765 L .30705 .58889 L F
.30854 .58972 m .31101 .59129 L .3095 .58765 L F
.374 .641 .96 r
.57816 .35227 m .57971 .35422 L .57691 .35412 L F
.57816 .35227 m .57971 .35422 L .57691 .35412 L F
.992 .741 .387 r
.59606 .44103 m .59687 .4455 L .59602 .44584 L F
.375 0 0 r
.59602 .44584 m .59687 .4455 L .59574 .44606 L F
.661 .111 0 r
.59687 .4455 m .59952 .44769 L .59574 .44606 L F
.704 .559 .687 r
.42894 .57922 m .42642 .58285 L .42529 .57916 L F
0 0 .412 r
.4366 .57906 m .43813 .58247 L .43664 .57747 L F
.602 .842 .471 r
.32982 .51741 m .33096 .51576 L .3327 .51364 L F
.627 .9 .592 r
.32982 .51741 m .32965 .51732 L .33096 .51576 L F
.951 .666 .462 r
.58303 .39908 m .58302 .39653 L .58119 .39546 L F
.51 .103 .203 r
.27805 .58926 m .27679 .59157 L .27352 .59154 L F
.246 0 0 r
.28053 .58896 m .27679 .59157 L .27805 .58926 L F
.535 .894 .679 r
.53976 .41252 m .53743 .41472 L .54177 .41273 L F
.53976 .41252 m .53751 .41435 L .53743 .41472 L F
.99 .725 .387 r
.42176 .54666 m .42197 .54968 L .421 .54857 L F
.445 .301 .591 r
.42176 .54666 m .42197 .54968 L .42429 .54885 L F
.508 0 0 r
.42176 .54666 m .42277 .54772 L .421 .54857 L F
.42176 .54666 m .42429 .54885 L .42277 .54772 L F
.572 .868 .995 r
.34216 .51885 m .33972 .51971 L .34151 .52059 L F
.707 .887 .963 r
.47097 .43191 m .46873 .43338 L .46682 .43198 L F
.701 .937 .963 r
.63107 .40233 m .62894 .40389 L .6242 .40436 L F
.106 .246 .726 r
.50965 .42461 m .50967 .42658 L .50927 .42645 L F
.844 .768 .778 r
.51898 .45357 m .51725 .45467 L .52079 .45528 L F
.818 .676 .706 r
.51725 .45467 m .52074 .45797 L .52079 .45528 L F
.767 .77 .855 r
.51898 .45357 m .52079 .45528 L .52358 .45249 L F
.681 .612 .772 r
.52079 .45528 m .52401 .455 L .52358 .45249 L F
.695 .53 .66 r
.52074 .45797 m .52401 .455 L .52079 .45528 L F
.295 0 0 r
.64498 .34 m .64149 .34096 L .64215 .34025 L F
.92 .687 .57 r
.38434 .56156 m .3871 .5597 L .38487 .55857 L F
.38434 .56156 m .38679 .56258 L .3871 .5597 L F
.955 .668 .229 r
.57843 .38901 m .57848 .39141 L .57954 .39268 L F
.846 .383 .049 r
.57927 .39419 m .57954 .39268 L .57848 .39141 L F
.57927 .39419 m .58119 .39546 L .57954 .39268 L F
.763 .378 .326 r
.6298 .40958 m .63065 .41204 L .62679 .41106 L F
.749 .384 .362 r
.35139 .58255 m .34721 .58206 L .34939 .58559 L F
.695 .503 .623 r
.34939 .58559 m .35139 .58559 L .35139 .58255 L F
.481 .851 .988 r
.34939 .58559 m .34496 .58602 L .34583 .58509 L F
.67 .38 .472 r
.34939 .58559 m .35112 .58801 L .35139 .58559 L F
.749 .384 .362 r
.35139 .58255 m .34961 .58601 L .34721 .58206 L F
0 0 0 r
.35205 .58361 m .35139 .58255 L .35139 .58559 L F
.35205 .58361 m .34961 .58601 L .35139 .58255 L F
.66168 .37509 m .66322 .37424 L .65947 .37628 L F
.695 .953 .686 r
.66479 .37234 m .66322 .37424 L .66168 .37509 L F
0 0 .159 r
.46096 .58469 m .46233 .58435 L .46236 .58209 L F
.166 0 .189 r
.46236 .58209 m .46437 .58366 L .46435 .58085 L F
.46236 .58209 m .46233 .58435 L .46437 .58366 L F
.01 0 0 r
.25526 .52172 m .25794 .52122 L .25963 .52045 L F
.195 .72 .717 r
.25794 .52122 m .26216 .52024 L .25963 .52045 L F
0 0 0 r
.61026 .34481 m .613 .34445 L .61388 .34426 L F
.613 .34445 m .61333 .34437 L .61388 .34426 L F
.004 0 0 r
.6152 .344 m .61164 .34431 L .61388 .34426 L F
.61547 .34398 m .6152 .344 L .61388 .34426 L F
0 0 0 r
.61388 .34426 m .61811 .34324 L .61547 .34398 L F
.61642 .34365 m .61621 .3437 L .61811 .34324 L F
.61388 .34426 m .61621 .3437 L .61642 .34365 L F
.61333 .34437 m .61621 .3437 L .61388 .34426 L F
.613 .34445 m .61582 .34383 L .61621 .3437 L F
.275 .762 .676 r
.61621 .3437 m .61582 .34383 L .61601 .34375 L F
.61621 .3437 m .61601 .34375 L .61845 .34278 L F
.277 .066 .402 r
.34347 .57613 m .34523 .57734 L .34446 .57395 L F
.34347 .57613 m .34282 .57887 L .34523 .57734 L F
.493 .536 .829 r
.43859 .58456 m .4368 .58756 L .43452 .58798 L F
.43859 .58456 m .43951 .58736 L .4368 .58756 L F
.737 .483 .545 r
.70473 .30413 m .70899 .30189 L .70677 .30086 L F
.70473 .30413 m .70899 .30454 L .70899 .30189 L F
.116 0 .214 r
.49773 .50424 m .49965 .50325 L .50017 .50108 L F
.288 .11 .457 r
.49773 .50424 m .49943 .50502 L .49965 .50325 L F
.49773 .50424 m .49751 .5071 L .49943 .50502 L F
0 0 .162 r
.69934 .35985 m .69908 .35748 L .69914 .35588 L F
0 0 .212 r
.60103 .43497 m .60115 .43245 L .60227 .43028 L F
.858 .766 .76 r
.38731 .59803 m .38757 .60197 L .38973 .59924 L F
.812 .513 .483 r
.54945 .39977 m .54543 .4019 L .54803 .39844 L F
.54945 .39977 m .54957 .40248 L .54543 .4019 L F
0 0 0 r
.67389 .38013 m .67666 .37912 L .67438 .38057 L F
.168 .274 .73 r
.26928 .63499 m .26722 .63178 L .26948 .63084 L F
0 .179 .663 r
.28306 .6427 m .28341 .64351 L .28044 .64331 L F
.28306 .6427 m .28531 .64483 L .28341 .64351 L F
.28341 .64351 m .28306 .6427 L .28044 .64331 L F
.28341 .64351 m .28531 .64483 L .28306 .6427 L F
.692 .199 .072 r
.60354 .41719 m .60484 .41724 L .60547 .41397 L F
.60354 .41719 m .60625 .41705 L .60484 .41724 L F
.743 .88 .471 r
.38169 .6099 m .38275 .60875 L .38193 .60719 L F
.38169 .6099 m .38111 .61161 L .38275 .60875 L F
.532 .705 .95 r
.623 .40992 m .62565 .41004 L .62509 .40723 L F
.54 .566 .83 r
.4927 .45427 m .49425 .4583 L .4968 .45763 L F
.553 .604 .859 r
.49425 .4583 m .49758 .45924 L .4968 .45763 L F
.815 .548 .535 r
.32597 .59232 m .32166 .59428 L .32364 .59119 L F
.32597 .59232 m .32564 .59501 L .32166 .59428 L F
.606 .928 .7 r
.35129 .55022 m .34802 .5529 L .34999 .55126 L F
.104 0 .151 r
.34999 .55126 m .35312 .54851 L .35129 .55022 L F
.077 0 0 r
.66331 .3301 m .66244 .3314 L .65916 .33231 L F
.427 .011 .144 r
.66549 .32853 m .66244 .3314 L .66331 .3301 L F
.461 .874 .736 r
.37295 .49443 m .36866 .49658 L .37057 .49507 L F
.62 .884 .555 r
.37568 .49131 m .37295 .49443 L .37398 .49293 L F
.633 .963 .836 r
.37398 .49293 m .37295 .49443 L .37057 .49507 L F
.848 .438 .258 r
.37579 .50744 m .37363 .50702 L .37188 .50404 L F
.81 .357 .161 r
.37579 .50744 m .37421 .50866 L .37363 .50702 L F
.893 .494 .254 r
.37655 .50958 m .37421 .50866 L .37579 .50744 L F
.638 .698 .889 r
.50066 .45853 m .50477 .46149 L .50333 .4575 L F
.748 .689 .795 r
.50333 .4575 m .50477 .46149 L .50749 .45809 L F
.524 .26 .456 r
.35602 .55415 m .35507 .55705 L .35219 .55601 L F
.993 .743 .425 r
.45423 .497 m .45295 .49307 L .45458 .49396 L F
.45423 .497 m .45285 .49584 L .45295 .49307 L F
.698 .25 .186 r
.45285 .49584 m .45458 .49396 L .45295 .49307 L F
.485 .287 .535 r
.45458 .49396 m .45697 .49639 L .45423 .497 L F
.698 .25 .186 r
.45285 .49584 m .45697 .49639 L .45458 .49396 L F
.466 .807 .999 r
.41956 .5153 m .42357 .51589 L .42188 .51499 L F
.902 .576 .418 r
.37376 .53687 m .37431 .53941 L .37651 .53992 L F
.854 .465 .306 r
.37431 .53941 m .37993 .54291 L .37651 .53992 L F
.734 .422 0 r
.40425 .57964 m .40497 .58209 L .40356 .57786 L F
0 0 .158 r
.28518 .58726 m .2845 .58566 L .28706 .58537 L F
.28518 .58726 m .28384 .58837 L .2845 .58566 L F
.94 .625 .414 r
.3006 .53184 m .30305 .53308 L .30254 .5303 L F
.751 .908 .946 r
.32599 .65472 m .32963 .65432 L .3285 .65299 L F
.94 .625 .414 r
.3006 .53184 m .30305 .53308 L .30254 .5303 L F
.106 .513 .908 r
.3285 .65299 m .32963 .65432 L .33042 .65339 L F
.242 .69 .955 r
.32963 .65432 m .33239 .65441 L .33042 .65339 L F
.048 .33 .811 r
.57265 .44905 m .57377 .45103 L .57444 .44937 L F
.359 .491 .856 r
.51832 .47471 m .51974 .47242 L .51782 .47124 L F
.51832 .47471 m .52072 .4755 L .51974 .47242 L F
.397 .078 .303 r
.51804 .4774 m .52072 .4755 L .51832 .47471 L F
.557 .507 .755 r
.41155 .4846 m .40885 .48165 L .41002 .48362 L F
.686 .905 .973 r
.41224 .48232 m .41002 .48362 L .41155 .4846 L F
.41224 .48232 m .41002 .48362 L .41155 .4846 L F
.858 .473 .317 r
.58502 .42723 m .58656 .42519 L .58458 .42466 L F
.58502 .42723 m .58746 .42726 L .58656 .42519 L F
.25 .003 .331 r
.23533 .57609 m .23608 .57854 L .23367 .57833 L F
.397 .438 .786 r
.2372 .57198 m .23533 .57609 L .23624 .57196 L F
.2372 .57198 m .2388 .57468 L .23533 .57609 L F
0 0 .332 r
.23695 .57534 m .23533 .57609 L .2388 .57468 L F
.23695 .57534 m .23608 .57854 L .23533 .57609 L F
.752 .911 .946 r
.56595 .46918 m .56525 .4718 L .56708 .47015 L F
.793 .947 .923 r
.564 .47084 m .56525 .4718 L .56595 .46918 L F
.981 .787 .571 r
.30305 .53308 m .30227 .53588 L .30397 .53686 L F
.837 .999 .792 r
.49346 .50948 m .49293 .51096 L .49323 .50895 L F
0 0 .136 r
.49293 .51096 m .49359 .51207 L .49323 .50895 L F
.49293 .51096 m .4923 .51351 L .49359 .51207 L F
.903 .677 .587 r
.59553 .43901 m .59243 .44112 L .59386 .43758 L F
.59553 .43901 m .59606 .44103 L .59243 .44112 L F
.975 .835 .64 r
.5949 .43526 m .59553 .43901 L .59386 .43758 L F
.525 .825 .497 r
.65947 .37628 m .65654 .37936 L .65861 .37782 L F
.098 0 .238 r
.50136 .52344 m .50055 .52565 L .49894 .52697 L F
0 0 .011 r
.50055 .52565 m .49819 .52902 L .49894 .52697 L F
.37 .834 .896 r
.44304 .44505 m .44566 .44432 L .44642 .4446 L F
.662 .967 .918 r
.44742 .44287 m .44642 .4446 L .44566 .44432 L F
.44742 .44287 m .45033 .44235 L .44642 .4446 L F
.806 .448 0 r
.39952 .54375 m .40016 .54582 L .39851 .54207 L F
.919 .952 .798 r
.56222 .45834 m .55864 .461 L .56118 .45719 L F
.496 .789 .997 r
.56118 .45719 m .56496 .45789 L .56222 .45834 L F
.566 .367 .57 r
.33882 .55951 m .33916 .55573 L .33732 .55542 L F
.33882 .55951 m .34151 .55867 L .33916 .55573 L F
.958 .798 .641 r
.73122 .31487 m .73034 .31071 L .7311 .31347 L F
.866 .795 .302 r
.7307 .31738 m .73122 .31487 L .7311 .31347 L F
.147 .691 .762 r
.62642 .34767 m .62588 .3476 L .62253 .34807 L F
0 .256 .727 r
.62642 .34767 m .62711 .34738 L .62588 .3476 L F
.465 .241 .489 r
.62905 .34681 m .62907 .34929 L .62642 .34767 L F
0 .256 .727 r
.62642 .34767 m .62907 .34929 L .62711 .34738 L F
.619 .777 .956 r
.57137 .44323 m .57275 .44511 L .56876 .44422 L F
.786 .617 .671 r
.56876 .44422 m .57275 .44511 L .57088 .44787 L F
.91 .854 .775 r
.57424 .44172 m .57275 .44511 L .57137 .44323 L F
.679 .525 .669 r
.4274 .55652 m .42545 .55913 L .42396 .55634 L F
.534 .892 .976 r
.44322 .46116 m .43936 .46161 L .44041 .46113 L F
.73 .946 .634 r
.3327 .51364 m .33465 .51077 L .33619 .50966 L F
.3327 .51364 m .33301 .51261 L .33304 .51314 L F
.732 .898 .513 r
.3327 .51364 m .33096 .51576 L .33301 .51261 L F
.191 0 .257 r
.33301 .51261 m .33096 .51576 L .33297 .51478 L F
.33301 .51261 m .33297 .51478 L .33298 .5121 L F
.33301 .51261 m .33298 .5121 L .33299 .51086 L F
.73 .946 .634 r
.33304 .51314 m .33301 .51261 L .33465 .51077 L F
.13 0 0 r
.55999 .38744 m .55968 .38845 L .56323 .38622 L F
.761 .351 .273 r
.23367 .57833 m .23293 .58089 L .23148 .57808 L F
.358 .019 .246 r
.23608 .57854 m .23293 .58089 L .23367 .57833 L F
.515 .221 .405 r
.50786 .4963 m .50528 .4944 L .50527 .49691 L F
.50786 .4963 m .50841 .49387 L .50528 .4944 L F
.15 .68 .863 r
.3353 .49759 m .3376 .49751 L .33946 .49789 L F
0 .226 .694 r
.34052 .49812 m .33946 .49789 L .3376 .49751 L F
.34052 .49812 m .34191 .49943 L .33946 .49789 L F
.407 .095 .321 r
.50017 .50108 m .50237 .50235 L .50274 .50032 L F
.50017 .50108 m .49965 .50325 L .50237 .50235 L F
0 0 0 r
.37767 .48999 m .37568 .49131 L .37398 .49293 L F
.817 .949 .907 r
.54142 .46878 m .54386 .46691 L .54454 .46617 L F
.335 .08 .371 r
.22939 .54379 m .23148 .54365 L .23136 .54123 L F
.177 0 .347 r
.23136 .54123 m .23425 .54113 L .23433 .53839 L F
.23136 .54123 m .23148 .54365 L .23425 .54113 L F
.396 0 .116 r
.27221 .58503 m .27495 .58463 L .27649 .58249 L F
.443 .066 .228 r
.27495 .58463 m .27892 .5819 L .27649 .58249 L F
.687 .608 .762 r
.40183 .49067 m .39829 .48742 L .4009 .48677 L F
.637 .919 .635 r
.40488 .48748 m .40308 .48881 L .40183 .49067 L F
.629 .962 .857 r
.40308 .48881 m .40117 .49028 L .40183 .49067 L F
.523 0 0 r
.37188 .50404 m .37036 .50522 L .36753 .50382 L F
.858 .433 .213 r
.37188 .50404 m .37363 .50702 L .37036 .50522 L F
.997 .843 .507 r
.70053 .35009 m .70106 .34745 L .70015 .34607 L F
.97 .917 .692 r
.70015 .34607 m .70106 .34745 L .7025 .34325 L F
.435 .853 .695 r
.24104 .53294 m .23902 .53419 L .23811 .53461 L F
.505 .882 .972 r
.42409 .45082 m .42027 .45103 L .42282 .45042 L F
.45 .872 .934 r
.42691 .44995 m .42409 .45082 L .42282 .45042 L F
.997 .776 .475 r
.58479 .41133 m .58363 .40839 L .58344 .41065 L F
.9 .729 .66 r
.58155 .41398 m .58479 .41133 L .58344 .41065 L F
.58155 .41398 m .58366 .41569 L .58479 .41133 L F
.401 .722 .989 r
.45292 .45483 m .45359 .45316 L .45117 .45333 L F
.733 .943 .625 r
.45096 .45648 m .45359 .45316 L .45292 .45483 L F
.998 .832 .548 r
.45096 .45648 m .45292 .45483 L .45143 .45946 L F
.743 .574 .665 r
.26581 .58805 m .26933 .58486 L .2669 .58534 L F
0 0 .229 r
.34822 .5553 m .34999 .55126 L .34802 .5529 L F
.582 .408 .611 r
.52305 .43551 m .52407 .43359 L .52568 .43204 L F
.983 .743 .342 r
.59606 .44103 m .59521 .4459 L .59243 .44112 L F
.59521 .4459 m .59511 .44589 L .59243 .44112 L F
.59606 .44103 m .59602 .44584 L .5954 .44597 L F
.792 .295 0 r
.59518 .44602 m .59574 .44606 L .59419 .44571 L F
.983 .743 .342 r
.59521 .4459 m .5954 .44597 L .59518 .44602 L F
.59606 .44103 m .5954 .44597 L .59521 .4459 L F
.886 .469 .206 r
.59052 .44171 m .59502 .44587 L .59419 .44571 L F
.054 .505 .891 r
.59509 .44589 m .59488 .44585 L .59482 .44585 L F
.59502 .44587 m .59488 .44585 L .59509 .44589 L F
.886 .469 .206 r
.59502 .44587 m .59518 .44602 L .59419 .44571 L F
.054 .505 .891 r
.59511 .44589 m .59502 .44587 L .59509 .44589 L F
.886 .469 .206 r
.59092 .44216 m .59419 .44571 L .59285 .44431 L F
.59052 .44171 m .59098 .44221 L .59092 .44216 L F
.59098 .44221 m .59419 .44571 L .59092 .44216 L F
0 .113 .663 r
.59052 .44171 m .58881 .44099 L .58864 .44091 L F
.879 .992 .798 r
.59361 .43428 m .5933 .43694 L .59126 .43728 L F
.712 .987 .85 r
.59126 .43728 m .5933 .43694 L .59333 .43638 L F
.861 .79 .781 r
.59333 .43638 m .59052 .44171 L .58864 .44091 L F
0 .314 .707 r
.58864 .44091 m .59055 .44183 L .58895 .44075 L F
0 .113 .663 r
.59052 .44171 m .59198 .44251 L .58881 .44099 L F
.896 .507 .279 r
.59345 .44294 m .59511 .44589 L .59052 .44171 L F
.59511 .44589 m .59502 .44587 L .59052 .44171 L F
0 .113 .663 r
.59052 .44171 m .59285 .44431 L .59198 .44251 L F
0 .314 .707 r
.59055 .44183 m .59198 .44251 L .59008 .44141 L F
.59055 .44183 m .59008 .44141 L .58895 .44075 L F
.896 .507 .279 r
.59243 .44112 m .59345 .44294 L .59052 .44171 L F
.59511 .44589 m .59518 .44602 L .59502 .44587 L F
.054 .505 .891 r
.59521 .4459 m .59502 .44583 L .59488 .44585 L F
.59521 .4459 m .59488 .44585 L .59511 .44589 L F
.59595 .44599 m .59704 .44562 L .59502 .44583 L F
.59595 .44599 m .59502 .44583 L .59521 .4459 L F
.59482 .44585 m .59704 .44562 L .59419 .44571 L F
.792 .295 0 r
.59518 .44602 m .5954 .44597 L .59574 .44606 L F
.5954 .44597 m .59602 .44584 L .59574 .44606 L F
.054 .505 .891 r
.59574 .44606 m .59595 .44599 L .59504 .44588 L F
.59574 .44606 m .59504 .44588 L .59482 .44585 L F
.983 .743 .342 r
.59521 .4459 m .59518 .44602 L .59511 .44589 L F
.932 .65 .482 r
.36933 .5317 m .37174 .5299 L .36908 .52934 L F
.36933 .5317 m .37318 .53475 L .37174 .5299 L F
.854 .465 .306 r
.37431 .53941 m .37473 .54156 L .37993 .54291 L F
.904 .655 .551 r
.37473 .54156 m .37831 .54449 L .37993 .54291 L F
.839 .743 .758 r
.4875 .4584 m .48974 .45764 L .48995 .45518 L F
.831 .884 .881 r
.48594 .45983 m .48974 .45764 L .4875 .4584 L F
.759 .826 .905 r
.39101 .45776 m .39291 .45944 L .39502 .45815 L F
.531 .92 .907 r
.42679 .4564 m .42444 .45754 L .42584 .45774 L F
.079 0 0 r
.42679 .4564 m .42605 .45682 L .42444 .45754 L F
.433 .871 .898 r
.42584 .45774 m .42444 .45754 L .42262 .45836 L F
.079 0 0 r
.42605 .45682 m .42275 .45869 L .42444 .45754 L F
.433 .871 .898 r
.42262 .45836 m .42444 .45754 L .42193 .45849 L F
.422 .82 .983 r
.42886 .45716 m .42679 .4564 L .42584 .45774 L F
.796 .48 0 r
.45836 .58391 m .45877 .58424 L .45826 .58236 L F
.803 .513 .499 r
.45826 .58236 m .45908 .58537 L .46096 .58469 L F
.067 0 0 r
.46025 .583 m .45836 .58391 L .45826 .58236 L F
.452 .883 .829 r
.45802 .58365 m .45836 .58391 L .46025 .583 L F
.45765 .58376 m .45836 .58391 L .45802 .58365 L F
.796 .48 0 r
.45836 .58391 m .45908 .58537 L .45877 .58424 L F
.326 .442 .826 r
.45885 .57781 m .45826 .58236 L .4581 .57927 L F
.45885 .57781 m .46084 .58096 L .45826 .58236 L F
.067 0 0 r
.46025 .583 m .45826 .58236 L .46084 .58096 L F
.865 .972 .857 r
.5088 .46995 m .50992 .471 L .51286 .46765 L F
.425 .209 .48 r
.54879 .42725 m .55101 .42234 L .54691 .42189 L F
.54879 .42725 m .55196 .42512 L .55101 .42234 L F
.729 .51 .594 r
.55196 .42512 m .55371 .42194 L .55101 .42234 L F
.553 .028 0 r
.42106 .53329 m .42558 .53351 L .42488 .53509 L F
.42262 .53337 m .42408 .53473 L .42558 .53351 L F
.954 .622 .347 r
.42408 .53473 m .42591 .53588 L .42558 .53351 L F
.865 .444 .006 r
.42549 .53706 m .42591 .53588 L .42408 .53473 L F
.991 .87 .609 r
.42508 .53335 m .42537 .53595 L .42408 .53473 L F
.42537 .53595 m .42549 .53706 L .42408 .53473 L F
.553 .028 0 r
.42106 .53329 m .42408 .53473 L .42262 .53337 L F
.577 .582 .822 r
.7245 .2981 m .72633 .29375 L .72739 .29314 L F
.7245 .2981 m .72732 .29781 L .72633 .29375 L F
.516 .24 .435 r
.7245 .2981 m .72725 .29978 L .72732 .29781 L F
.426 .788 .996 r
.31073 .55559 m .31314 .5552 L .31506 .55624 L F
.31073 .55559 m .31314 .5552 L .31506 .55624 L F
.51 .913 .859 r
.44604 .4552 m .44849 .45398 L .44759 .45408 L F
0 0 .29 r
.44759 .45408 m .44584 .45784 L .44604 .4552 L F
.11 .033 .479 r
.24444 .54912 m .2441 .5522 L .24315 .55285 L F
.271 .019 .336 r
.24385 .55317 m .24315 .55285 L .2441 .5522 L F
.24385 .55317 m .24226 .55558 L .24315 .55285 L F
.125 0 0 r
.68335 .30053 m .68604 .2998 L .68707 .29844 L F
.455 0 .062 r
.68604 .2998 m .69002 .29803 L .68707 .29844 L F
.723 .635 .759 r
.48594 .45983 m .48336 .45782 L .48454 .46084 L F
.979 .85 .643 r
.36409 .49821 m .36334 .5008 L .36169 .49997 L F
.535 .877 .625 r
.3662 .49639 m .36409 .49821 L .36169 .49997 L F
.149 0 .395 r
.31291 .6306 m .31139 .63143 L .31096 .63474 L F
.804 .521 .51 r
.44448 .57596 m .4407 .57793 L .44154 .57534 L F
.44448 .57596 m .44473 .57867 L .4407 .57793 L F
.752 .887 .48 r
.42545 .55913 m .42333 .56256 L .42315 .56335 L F
.722 .804 .332 r
.42333 .56256 m .4221 .56577 L .42315 .56335 L F
.865 .91 .86 r
.26948 .63084 m .27277 .62924 L .2725 .6282 L F
.795 .719 .78 r
.32129 .63472 m .325 .63336 L .32377 .63097 L F
.305 0 0 r
.32409 .63452 m .325 .63336 L .32129 .63472 L F
0 .17 .707 r
.32377 .63097 m .325 .63336 L .32608 .63319 L F
0 0 0 r
.32608 .63319 m .325 .63336 L .32409 .63452 L F
.32059 .56622 m .32131 .56532 L .32327 .56221 L F
.647 .317 .399 r
.32327 .56221 m .32553 .56485 L .32552 .56214 L F
.18 0 0 r
.33968 .60773 m .34129 .60837 L .341 .60595 L F
.691 .604 .755 r
.343 .60904 m .34015 .6083 L .34129 .60837 L F
.18 0 0 r
.33781 .61024 m .34129 .60837 L .33968 .60773 L F
.691 .604 .755 r
.34413 .60933 m .343 .60904 L .34129 .60837 L F
.466 0 0 r
.62032 .39322 m .61996 .39105 L .61777 .39209 L F
0 0 .019 r
.62286 .38972 m .61996 .39105 L .62032 .39322 L F
0 0 0 r
.5218 .42093 m .52327 .41956 L .52 .42209 L F
.607 .877 .55 r
.52612 .41626 m .52327 .41956 L .5218 .42093 L F
.894 .653 .566 r
.37988 .54614 m .37978 .54924 L .38204 .54942 L F
.854 .497 .377 r
.37978 .54924 m .38001 .55139 L .38204 .54942 L F
.858 .505 .382 r
.38001 .55139 m .38311 .55238 L .38204 .54942 L F
.979 .893 .543 r
.7025 .34325 m .70267 .34023 L .70185 .34204 L F
.97 .917 .692 r
.70015 .34607 m .7025 .34325 L .70185 .34204 L F
.816 .513 .476 r
.39355 .48417 m .39006 .48102 L .39135 .48441 L F
.782 .517 .535 r
.39002 .48684 m .39355 .48417 L .39135 .48441 L F
.988 .759 .499 r
.41514 .46048 m .41647 .46424 L .41691 .46176 L F
.41514 .46048 m .41647 .46424 L .41691 .46176 L F
.905 .504 .102 r
.43097 .55097 m .43231 .54998 L .43172 .54826 L F
.43097 .55097 m .43389 .55451 L .43231 .54998 L F
0 .293 .697 r
.25716 .58395 m .2596 .58544 L .25638 .58379 L F
.25716 .58395 m .25638 .58379 L .25485 .58445 L F
.853 .998 .806 r
.34557 .60755 m .34413 .60933 L .34456 .60723 L F
.642 .844 .978 r
.34456 .60723 m .34413 .60933 L .34129 .60837 L F
.826 .491 .422 r
.35829 .5235 m .35456 .52312 L .3543 .52062 L F
.853 .696 .687 r
.35829 .5235 m .35614 .5266 L .35456 .52312 L F
0 0 .229 r
.34822 .5553 m .3501 .55487 L .34999 .55126 L F
.104 0 .151 r
.34999 .55126 m .35235 .55139 L .35312 .54851 L F
0 0 .187 r
.34999 .55126 m .35115 .55312 L .35235 .55139 L F
.34999 .55126 m .3501 .55487 L .35115 .55312 L F
.991 .873 .611 r
.58618 .43393 m .58807 .43261 L .58645 .43117 L F
.58618 .43393 m .5873 .43516 L .58807 .43261 L F
.273 .778 .805 r
.43962 .59837 m .44208 .59774 L .44115 .59774 L F
.26 .758 .897 r
.43821 .59807 m .43962 .59837 L .44115 .59774 L F
.138 .08 .524 r
.22501 .56246 m .2263 .56187 L .2263 .5592 L F
.129 .178 .646 r
.22501 .56246 m .22699 .56425 L .2263 .56187 L F
.999 .835 .515 r
.23124 .59992 m .23181 .60193 L .23046 .60066 L F
.737 .749 .235 r
.23181 .60193 m .23136 .60311 L .23046 .60066 L F
.23181 .60193 m .23111 .60433 L .23136 .60311 L F
.925 .965 .774 r
.5725 .46271 m .57342 .46205 L .57213 .46156 L F
.713 .972 .929 r
.57213 .46156 m .57342 .46205 L .5751 .46051 L F
.057 .403 .857 r
.46398 .53295 m .46821 .53547 L .46453 .53207 L F
.197 .284 .728 r
.54494 .44251 m .54576 .44517 L .54713 .44326 L F
.646 .906 .591 r
.54713 .44326 m .54576 .44517 L .54534 .4454 L F
.505 .437 .714 r
.54943 .44801 m .54576 .44517 L .54884 .44502 L F
.54943 .44801 m .54643 .44883 L .54576 .44517 L F
.061 0 .172 r
.50393 .52005 m .50368 .52264 L .50136 .52344 L F
0 0 0 r
.50136 .52344 m .5024 .52432 L .50055 .52565 L F
.50136 .52344 m .50368 .52264 L .5024 .52432 L F
.951 .612 .212 r
.59478 .40886 m .59655 .41273 L .59451 .41208 L F
.967 .644 .305 r
.59611 .41544 m .59451 .41208 L .59655 .41273 L F
.829 .856 .401 r
.41868 .4587 m .41823 .45872 L .41691 .45768 L F
.41868 .4587 m .41803 .46008 L .41823 .45872 L F
.371 .088 .347 r
.54608 .45095 m .54643 .44883 L .54943 .44801 L F
.355 .119 .412 r
.52794 .41327 m .52542 .41525 L .52787 .4146 L F
.607 .52 .73 r
.52612 .41626 m .52787 .4146 L .52542 .41525 L F
.872 .789 .766 r
.31914 .62041 m .31961 .62447 L .31935 .62443 L F
.774 .896 .492 r
.31935 .62443 m .31961 .62447 L .31799 .62673 L F
.456 .86 .966 r
.31061 .53673 m .30907 .53633 L .3115 .53561 L F
.31061 .53673 m .30907 .53633 L .3115 .53561 L F
.506 .293 .525 r
.31126 .57236 m .31144 .5757 L .30855 .57592 L F
.664 .652 .828 r
.31357 .56944 m .31126 .57236 L .31082 .57047 L F
0 0 .453 r
.31082 .57047 m .31126 .57236 L .31172 .57058 L F
.76 .967 .678 r
.31172 .57058 m .31126 .57236 L .30901 .57381 L F
.664 .652 .828 r
.31357 .56944 m .31508 .57192 L .31126 .57236 L F
.276 0 .209 r
.31508 .57192 m .31144 .5757 L .31126 .57236 L F
.914 .558 .347 r
.35989 .5159 m .36314 .51978 L .36321 .51718 L F
.837 .918 .523 r
.47647 .58241 m .47813 .57803 L .47631 .58129 L F
0 0 .062 r
.47631 .58129 m .47639 .58488 L .47647 .58241 L F
.576 .493 .724 r
.32453 .54078 m .32361 .54193 L .32142 .53976 L F
.393 .409 .758 r
.32667 .53863 m .32573 .54352 L .32453 .54078 L F
.167 .7 .704 r
.62309 .3409 m .62745 .33996 L .62515 .3414 L F
.429 .871 .822 r
.44096 .4454 m .44058 .44612 L .43862 .44624 L F
.44096 .4454 m .44304 .44505 L .44058 .44612 L F
.142 .446 .879 r
.60194 .42241 m .60324 .42107 L .60119 .42073 L F
.60194 .42241 m .60534 .42383 L .60324 .42107 L F
.695 .53 .66 r
.52074 .45797 m .52501 .45898 L .52401 .455 L F
.54 .513 .774 r
.52358 .45249 m .52401 .455 L .52644 .45408 L F
.665 .576 .745 r
.52501 .45898 m .52644 .45408 L .52401 .455 L F
.924 .708 .218 r
.58565 .35069 m .58621 .35019 L .58237 .35069 L F
.579 .024 0 r
.72996 .29448 m .73287 .2962 L .7339 .29529 L F
.747 .235 0 r
.7339 .29529 m .73287 .2962 L .73564 .29689 L F
.747 .772 .873 r
.44355 .58696 m .44103 .58895 L .43951 .58736 L F
.234 .135 .532 r
.47924 .5301 m .4809 .53136 L .48166 .52952 L F
.503 .848 .579 r
.48166 .52952 m .48311 .52813 L .48308 .52825 L F
0 0 0 r
.48271 .52851 m .48049 .53121 L .48311 .52813 L F
.48166 .52952 m .48128 .53007 L .48271 .52851 L F
.48128 .53007 m .48049 .53121 L .48271 .52851 L F
.234 .135 .532 r
.48042 .531 m .47986 .53262 L .4809 .53136 L F
.47924 .5301 m .47966 .53182 L .48042 .531 L F
.47966 .53182 m .47986 .53262 L .48042 .531 L F
.787 .289 0 r
.52323 .44803 m .52481 .4506 L .5257 .45024 L F
0 0 .549 r
.52366 .44601 m .52481 .4506 L .52323 .44803 L F
.6 .576 .798 r
.5272 .44932 m .52481 .4506 L .52366 .44601 L F
.368 .812 .668 r
.52406 .45091 m .52481 .4506 L .5272 .44932 L F
.817 .86 .88 r
.52198 .45126 m .5265 .45096 L .52481 .4506 L F
0 0 0 r
.52198 .45126 m .52481 .4506 L .52312 .45138 L F
.368 .812 .668 r
.52312 .45138 m .52481 .4506 L .52406 .45091 L F
.787 .289 0 r
.5257 .45024 m .52481 .4506 L .5265 .45096 L F
.817 .86 .88 r
.52198 .45126 m .52358 .45249 L .5265 .45096 L F
.54 .513 .774 r
.52358 .45249 m .52644 .45408 L .5265 .45096 L F
.584 .939 .924 r
.5272 .44932 m .52481 .4506 L .5265 .45096 L F
.5265 .45096 m .52481 .4506 L .5272 .44932 L F
.555 .403 .629 r
.52644 .45408 m .5289 .45045 L .5265 .45096 L F
.861 .878 .849 r
.6231 .3814 m .62629 .37998 L .62481 .38058 L F
.811 .889 .466 r
.62831 .375 m .62624 .37936 L .62629 .37998 L F
.711 .981 .791 r
.62624 .37936 m .62481 .38058 L .62629 .37998 L F
.661 .392 .502 r
.32333 .56849 m .31983 .56962 L .32059 .56622 L F
0 0 .104 r
.32059 .56622 m .32127 .56727 L .32131 .56532 L F
.685 .671 .83 r
.31983 .56962 m .31769 .57225 L .31598 .56834 L F
.666 .641 .815 r
.32143 .57183 m .31769 .57225 L .31983 .56962 L F
.562 .419 .645 r
.32333 .56849 m .32143 .57183 L .31983 .56962 L F
.685 .671 .83 r
.31983 .56962 m .31598 .56834 L .3182 .56836 L F
.677 .217 .153 r
.31692 .56912 m .32057 .57003 L .3182 .56836 L F
.32057 .57003 m .32073 .57007 L .32057 .56996 L F
0 0 .104 r
.32048 .56668 m .31983 .56962 L .32053 .56847 L F
.32048 .56668 m .32053 .56847 L .32127 .56727 L F
.587 .352 .527 r
.3182 .56836 m .32127 .56727 L .31983 .56962 L F
.677 .217 .153 r
.32057 .57003 m .32057 .56996 L .3182 .56836 L F
0 0 .104 r
.32059 .56622 m .32048 .56668 L .32127 .56727 L F
.623 .497 .687 r
.54559 .42247 m .54879 .42725 L .54691 .42189 L F
.628 .539 .735 r
.54598 .42895 m .54879 .42725 L .54559 .42247 L F
.321 .009 .271 r
.47334 .54015 m .47684 .53903 L .47662 .53654 L F
.212 .008 .371 r
.47662 .53654 m .47926 .53572 L .47986 .53262 L F
.173 0 .263 r
.47662 .53654 m .47684 .53903 L .47926 .53572 L F
.147 0 .236 r
.23771 .56123 m .23737 .55957 L .23958 .55875 L F
.23771 .56123 m .23643 .56206 L .23737 .55957 L F
.232 0 .315 r
.52522 .43466 m .52305 .43551 L .52568 .43204 L F
.313 .083 .395 r
.52455 .43613 m .52305 .43551 L .52522 .43466 L F
.52455 .43613 m .52288 .43738 L .52305 .43551 L F
.43 .421 .749 r
.30811 .52641 m .30938 .53059 L .31054 .52805 L F
.405 0 .143 r
.53183 .48044 m .5359 .47806 L .53174 .4774 L F
.53183 .48044 m .53522 .47963 L .5359 .47806 L F
.28 .136 .499 r
.53522 .47963 m .53731 .47601 L .5359 .47806 L F
.864 .799 .785 r
.35778 .55624 m .35638 .55956 L .35507 .55705 L F
.91 .854 .775 r
.57424 .44172 m .57137 .44323 L .57449 .44037 L F
.162 0 .29 r
.52741 .43363 m .52522 .43466 L .52568 .43204 L F
.375 0 .193 r
.3368 .5384 m .33952 .53904 L .34072 .53639 L F
0 .483 .855 r
.33861 .53871 m .33952 .53904 L .3368 .5384 L F
.24 0 0 r
.33461 .53965 m .33861 .53871 L .3368 .5384 L F
.105 .381 .84 r
.33551 .53519 m .33861 .53871 L .3368 .5384 L F
.33551 .53519 m .33861 .53871 L .3368 .5384 L F
.744 .829 .917 r
.454 .46163 m .4558 .45772 L .4522 .46013 L F
.454 .46163 m .45763 .45959 L .4558 .45772 L F
.681 .609 .768 r
.454 .46163 m .45751 .46225 L .45763 .45959 L F
.057 0 .183 r
.64909 .32824 m .65081 .32839 L .65182 .3274 L F
.64909 .32824 m .6489 .32993 L .65081 .32839 L F
.739 .232 0 r
.58873 .38916 m .5872 .38822 L .58615 .3867 L F
.965 .645 .352 r
.58873 .38916 m .58743 .39096 L .5872 .38822 L F
.58873 .38916 m .58913 .39228 L .58743 .39096 L F
.604 .08 0 r
.53063 .42787 m .53127 .42655 L .52706 .42559 L F
.284 .784 .781 r
.53208 .42599 m .53395 .42573 L .53127 .42655 L F
.53208 .42599 m .53127 .42655 L .53063 .42787 L F
.505 .8 .998 r
.55699 .438 m .55465 .43885 L .55188 .43682 L F
.337 .143 .464 r
.55699 .438 m .55498 .44121 L .55465 .43885 L F
.129 0 .078 r
.34072 .53639 m .34207 .53769 L .34352 .53649 L F
.34072 .53639 m .33952 .53904 L .34207 .53769 L F
.34 0 .198 r
.65656 .33318 m .65322 .33623 L .65399 .33409 L F
.98 .849 .64 r
.43317 .56447 m .43459 .5659 L .43556 .56288 L F
.742 .975 .724 r
.43317 .56447 m .43556 .56288 L .4363 .56113 L F
.517 .288 .507 r
.62576 .39322 m .62534 .39617 L .62321 .39648 L F
.699 .582 .721 r
.62899 .38898 m .62955 .39326 L .62576 .39322 L F
.698 .535 .663 r
.62576 .39322 m .62749 .39599 L .62534 .39617 L F
.62576 .39322 m .62955 .39326 L .62749 .39599 L F
0 0 .432 r
.42293 .57784 m .42173 .57543 L .42232 .57502 L F
.168 0 0 r
.26216 .52024 m .26461 .51944 L .26609 .5176 L F
0 0 0 r
.26609 .5176 m .26719 .51747 L .26855 .5168 L F
.26609 .5176 m .26461 .51944 L .26719 .51747 L F
.775 .341 .219 r
.32463 .58573 m .32275 .5873 L .3209 .58442 L F
.011 .219 .729 r
.32537 .58398 m .32695 .58779 L .32463 .58573 L F
.664 .19 .119 r
.32463 .58573 m .32695 .58779 L .32275 .5873 L F
.43 .421 .749 r
.30811 .52641 m .31054 .52805 L .31228 .52726 L F
.407 .166 .432 r
.3618 .58831 m .35923 .58908 L .36206 .58565 L F
.543 .278 .464 r
.36445 .58782 m .36206 .58565 L .36454 .58505 L F
.36445 .58782 m .3618 .58831 L .36206 .58565 L F
.971 .69 .281 r
.53093 .40944 m .53109 .41217 L .52995 .40969 L F
.576 .942 .882 r
.55895 .40107 m .56287 .39962 L .56172 .40001 L F
.037 .091 .59 r
.55895 .40107 m .56069 .40346 L .56263 .40137 L F
1 .821 .518 r
.5602 .40052 m .56172 .40001 L .56069 .40346 L F
.572 .919 .962 r
.55895 .40107 m .56172 .40001 L .55999 .39931 L F
1 .821 .518 r
.55999 .39931 m .56172 .40001 L .5602 .40052 L F
.576 .942 .882 r
.56287 .39962 m .56291 .39961 L .56172 .40001 L F
.943 .59 .309 r
.56172 .40001 m .56291 .39961 L .56263 .40137 L F
0 0 0 r
.5414 .48785 m .53771 .49058 L .53763 .49044 L F
.5414 .48785 m .53982 .48913 L .53771 .49058 L F
.621 .937 .717 r
.54348 .48651 m .53982 .48913 L .5414 .48785 L F
.868 .773 .271 r
.34806 .61798 m .34824 .61813 L .34752 .62131 L F
.106 .634 .874 r
.59026 .35398 m .58856 .35336 L .58625 .35324 L F
0 .454 .817 r
.59302 .35512 m .58856 .35336 L .59026 .35398 L F
.342 .231 .58 r
.51623 .48063 m .51804 .4774 L .51549 .47829 L F
.696 .208 .084 r
.60896 .44664 m .61028 .44523 L .60686 .44434 L F
0 .151 .639 r
.61164 .44595 m .61336 .44762 L .61028 .44523 L F
.61164 .44595 m .61028 .44523 L .60896 .44664 L F
.014 0 0 r
.65182 .3274 m .65444 .32653 L .65561 .32531 L F
0 0 0 r
.65561 .32531 m .65676 .32474 L .65825 .32413 L F
.65561 .32531 m .65444 .32653 L .65676 .32474 L F
.821 .766 .801 r
.35076 .53333 m .348 .53676 L .34705 .53419 L F
.864 .883 .849 r
.51579 .40208 m .51693 .39822 L .51761 .39819 L F
.51579 .40208 m .51447 .40113 L .51693 .39822 L F
.754 .415 .41 r
.45908 .58537 m .45949 .5876 L .46096 .58469 L F
.611 .428 .609 r
.45949 .5876 m .46233 .58435 L .46096 .58469 L F
.935 .752 .63 r
.6888 .33145 m .68612 .33247 L .68649 .32984 L F
.6888 .33145 m .68803 .3339 L .68612 .33247 L F
0 0 0 r
.66157 .38824 m .66533 .38632 L .66413 .38714 L F
.338 .812 .749 r
.66533 .38632 m .66751 .38529 L .66413 .38714 L F
.66533 .38632 m .66797 .38526 L .66751 .38529 L F
.906 .984 .768 r
.33438 .59901 m .33192 .59958 L .3369 .59834 L F
.715 .628 .759 r
.45794 .46472 m .45884 .45964 L .45751 .46225 L F
.45794 .46472 m .46124 .46218 L .45884 .45964 L F
.662 .758 .273 r
.48266 .56519 m .48169 .56755 L .48157 .56789 L F
0 0 0 r
.4826 .56567 m .48169 .56755 L .48266 .56519 L F
.652 .801 .356 r
.4826 .56567 m .48186 .5671 L .48169 .56755 L F
.48186 .5671 m .48064 .5694 L .48169 .56755 L F
.662 .758 .273 r
.48157 .56789 m .48169 .56755 L .48098 .56933 L F
.769 .708 .171 r
.4806 .57028 m .48098 .56933 L .48169 .56755 L F
.4806 .57028 m .48055 .57198 L .48098 .56933 L F
.983 .704 .333 r
.69503 .28859 m .69363 .28708 L .69382 .28459 L F
.578 .541 .777 r
.69603 .28538 m .69503 .28859 L .69382 .28459 L F
.69603 .28538 m .69804 .28799 L .69503 .28859 L F
.931 .866 .752 r
.73352 .30485 m .73545 .30169 L .73406 .30023 L F
0 .123 .607 r
.56124 .37546 m .56163 .37603 L .55975 .37563 L F
.56124 .37546 m .56437 .37821 L .56163 .37603 L F
.478 .274 .525 r
.56516 .3799 m .56163 .37603 L .56437 .37821 L F
.424 .322 .634 r
.23012 .54607 m .23148 .54365 L .22939 .54379 L F
.384 .657 .966 r
.37965 .47621 m .37975 .47836 L .38002 .47704 L F
.732 .716 .836 r
.37612 .47592 m .37965 .47694 L .37509 .47982 L F
.37965 .47694 m .37953 .47732 L .37509 .47982 L F
.825 .941 .578 r
.37953 .47732 m .37805 .48018 L .37509 .47982 L F
.542 .765 .98 r
.37965 .47621 m .37965 .47694 L .37612 .47592 L F
.915 .942 .586 r
.37896 .4792 m .37965 .47694 L .37965 .47621 L F
.37965 .47694 m .37968 .47683 L .37965 .47621 L F
.542 .765 .98 r
.37965 .47621 m .38002 .47704 L .37965 .47694 L F
.825 .941 .578 r
.38002 .47704 m .37805 .48018 L .37953 .47732 L F
.915 .942 .586 r
.37805 .48018 m .37896 .4792 L .37929 .47779 L F
.37805 .48018 m .37929 .47779 L .37965 .47621 L F
.37896 .4792 m .37975 .47836 L .37968 .47683 L F
.732 .716 .836 r
.37965 .47694 m .38002 .47704 L .37953 .47732 L F
.825 .941 .578 r
.38002 .47704 m .37975 .47836 L .37805 .48018 L F
.516 .91 .792 r
.51149 .42106 m .51603 .41899 L .51477 .42113 L F
.394 .153 .426 r
.51807 .41803 m .51603 .41899 L .51876 .41585 L F
.364 0 .144 r
.51807 .41803 m .51477 .42113 L .51603 .41899 L F
.889 .988 .797 r
.41421 .50529 m .4134 .50846 L .41624 .50574 L F
.765 .33 .22 r
.53777 .43736 m .53687 .43504 L .53511 .43665 L F
.865 .521 .013 r
.72618 .29223 m .72633 .29375 L .72475 .28999 L F
.785 .32 .136 r
.72739 .29314 m .72633 .29375 L .72618 .29223 L F
.98 .894 .663 r
.7266 .28881 m .72618 .29223 L .72475 .28999 L F
.487 .313 .571 r
.59869 .36036 m .6011 .36001 L .60101 .35696 L F
.59869 .36036 m .6011 .36001 L .60101 .35696 L F
.448 .251 .519 r
.52142 .41247 m .52118 .41514 L .51876 .41585 L F
0 0 .034 r
.5197 .41591 m .51876 .41585 L .52118 .41514 L F
.81 .973 .902 r
.5202 .42765 m .52439 .42575 L .52301 .42468 L F
0 0 0 r
.52439 .42575 m .52527 .42329 L .52301 .42468 L F
.52439 .42575 m .5262 .42177 L .52527 .42329 L F
.466 .388 .685 r
.52439 .42575 m .52733 .42847 L .52706 .42559 L F
.612 .383 .545 r
.31085 .5851 m .3138 .58503 L .31394 .58237 L F
.921 .529 .17 r
.40524 .58728 m .40401 .58776 L .40297 .58461 L F
.964 .638 .265 r
.40524 .58728 m .40545 .58921 L .40401 .58776 L F
.085 0 .034 r
.52012 .50331 m .51714 .50597 L .51795 .50445 L F
.235 .019 .368 r
.50617 .5168 m .5057 .51927 L .50393 .52005 L F
0 0 0 r
.5057 .51927 m .50368 .52264 L .50393 .52005 L F
.179 0 .336 r
.51445 .48508 m .51567 .48624 L .51615 .48385 L F
.51445 .48508 m .51394 .487 L .51567 .48624 L F
.134 .015 .441 r
.62842 .41638 m .63004 .4148 L .63065 .41204 L F
.963 .871 .472 r
.57746 .45789 m .57835 .45509 L .57707 .45629 L F
.427 .142 .376 r
.57835 .45509 m .57975 .45692 L .57707 .45629 L F
.57835 .45509 m .581 .4544 L .57975 .45692 L F
.616 .65 .86 r
.55523 .41075 m .5576 .41196 L .55783 .40952 L F
.606 .598 .816 r
.5576 .41196 m .56021 .40807 L .55783 .40952 L F
.5576 .41196 m .56057 .41261 L .56021 .40807 L F
.521 .745 .977 r
.56057 .41261 m .56226 .41077 L .56021 .40807 L F
.56226 .41077 m .56296 .41 L .56222 .40948 L F
.56226 .41077 m .56222 .40948 L .56021 .40807 L F
.822 .779 .812 r
.56232 .41233 m .56181 .41465 L .56063 .41245 L F
.56439 .41219 m .56237 .41411 L .56232 .41233 L F
.56237 .41411 m .56181 .41465 L .56232 .41233 L F
.587 .676 .902 r
.56063 .41245 m .56057 .41261 L .5576 .41196 L F
.56063 .41245 m .5576 .41196 L .55783 .41321 L F
.63 .532 .725 r
.63225 .39103 m .62955 .39326 L .62899 .38898 L F
.441 .526 .849 r
.29147 .64982 m .2919 .64637 L .28926 .64671 L F
.29147 .64982 m .29314 .64963 L .2919 .64637 L F
.821 .766 .801 r
.35076 .53333 m .34705 .53419 L .34933 .53276 L F
.104 .239 .719 r
.35174 .53284 m .35317 .53509 L .35076 .53333 L F
.318 .775 .95 r
.35076 .53333 m .34933 .53276 L .35174 .53284 L F
0 0 0 r
.61658 .37344 m .61757 .37319 L .61511 .37401 L F
.61861 .37266 m .61757 .37319 L .61658 .37344 L F
.164 0 0 r
.61991 .3726 m .6201 .3731 L .61757 .37319 L F
.358 .619 .951 r
.61757 .37319 m .6201 .3731 L .61992 .37257 L F
.411 0 .002 r
.61991 .3726 m .61757 .37319 L .61861 .37266 L F
.358 .619 .951 r
.61757 .37319 m .61992 .37257 L .61937 .37099 L F
.201 0 .042 r
.61511 .37401 m .61757 .37319 L .61647 .37122 L F
.61511 .37401 m .61439 .3754 L .61757 .37319 L F
.61757 .37319 m .61439 .3754 L .61511 .37401 L F
.997 .812 .458 r
.61404 .37297 m .61439 .3754 L .61511 .37401 L F
.411 .305 .622 r
.45751 .46225 m .45931 .45766 L .45763 .45959 L F
.45751 .46225 m .45884 .45964 L .45931 .45766 L F
.992 .882 .594 r
.40553 .56904 m .40368 .57044 L .404 .56815 L F
.40553 .56904 m .40452 .57162 L .40368 .57044 L F
.342 .231 .58 r
.51623 .48063 m .51823 .48006 L .51804 .4774 L F
.317 .162 .507 r
.51623 .48063 m .51615 .48385 L .51823 .48006 L F
.115 .122 .588 r
.60344 .43759 m .60095 .43903 L .60103 .43497 L F
0 0 .06 r
.60146 .43989 m .60095 .43903 L .60344 .43759 L F
.832 .368 .103 r
.41384 .51365 m .41545 .51495 L .41529 .51648 L F
.41545 .51495 m .41706 .51625 L .41588 .5164 L F
.41384 .51365 m .41497 .51557 L .41706 .51625 L F
.644 .34 .44 r
.41541 .51325 m .41497 .51557 L .41384 .51365 L F
.966 .786 .351 r
.41425 .5139 m .41497 .51557 L .41523 .51421 L F
.41501 .51347 m .41523 .51421 L .41541 .51325 L F
.41425 .5139 m .41523 .51421 L .41501 .51347 L F
.832 .368 .103 r
.41545 .51495 m .41588 .5164 L .41529 .51648 L F
.769 .259 0 r
.39497 .53284 m .39321 .53213 L .39125 .52954 L F
.959 .624 .318 r
.39516 .53546 m .39321 .53213 L .39497 .53284 L F
.62 .463 .647 r
.50959 .42204 m .50697 .42537 L .50681 .42263 L F
.50681 .42263 m .50697 .42537 L .50959 .42204 L F
.798 .904 .502 r
.42843 .57309 m .42754 .57363 L .42928 .57161 L F
.42843 .57309 m .42719 .57534 L .42754 .57363 L F
.03 0 0 r
.24764 .62612 m .25171 .62497 L .2502 .62508 L F
.24764 .62612 m .25171 .62497 L .25098 .62501 L F
.953 .889 .495 r
.25104 .62402 m .25171 .62497 L .25098 .62501 L F
.474 .484 .788 r
.25401 .58864 m .25485 .58445 L .25373 .58831 L F
.268 0 .257 r
.55376 .39481 m .55682 .39191 L .55451 .39291 L F
.701 .299 .283 r
.3543 .52062 m .35058 .52156 L .35031 .51976 L F
.3543 .52062 m .35166 .52224 L .35058 .52156 L F
.816 .484 .426 r
.3543 .52062 m .35456 .52312 L .35166 .52224 L F
0 0 0 r
.49512 .50847 m .49346 .50948 L .49751 .5071 L F
.628 .539 .735 r
.54598 .42895 m .54838 .42872 L .54879 .42725 L F
.492 .382 .657 r
.54598 .42895 m .54849 .43123 L .54838 .42872 L F
.54598 .42895 m .54647 .43248 L .54849 .43123 L F
.435 .182 .431 r
.33376 .56606 m .33345 .56852 L .33585 .56793 L F
.372 .601 .936 r
.53246 .43744 m .53423 .44016 L .53624 .43969 L F
.931 .928 .781 r
.70444 .33312 m .70765 .33096 L .70702 .33013 L F
.70444 .33312 m .70546 .3345 L .70765 .33096 L F
.819 .98 .89 r
.70765 .33096 m .71081 .32812 L .70844 .32831 L F
.844 .996 .834 r
.70702 .33013 m .70765 .33096 L .70844 .32831 L F
.692 .801 .933 r
.62989 .39888 m .63392 .39919 L .63225 .39861 L F
.908 .646 .531 r
.4144 .50847 m .41193 .51129 L .4112 .50901 L F
.4144 .50847 m .41384 .51365 L .41193 .51129 L F
.4144 .50847 m .4112 .50901 L .41381 .5111 L F
.685 .433 .535 r
.41541 .51325 m .41384 .51365 L .4144 .50847 L F
.916 .587 .117 r
.41381 .5111 m .41541 .51325 L .4144 .50847 L F
.378 0 0 r
.60257 .35202 m .59821 .35192 L .59955 .35128 L F
.996 .864 .562 r
.59436 .39977 m .59269 .40085 L .5933 .39839 L F
.59436 .39977 m .59365 .40227 L .59269 .40085 L F
.393 .409 .758 r
.32667 .53863 m .32747 .54247 L .32573 .54352 L F
.723 .231 .07 r
.32573 .54352 m .32354 .5445 L .32361 .54193 L F
.32573 .54352 m .32764 .54557 L .32354 .5445 L F
.316 .254 .627 r
.32747 .54247 m .32764 .54557 L .32573 .54352 L F
0 .243 .758 r
.63114 .38973 m .62899 .38898 L .62821 .38803 L F
.4 0 0 r
.63044 .38938 m .62821 .38803 L .62693 .38762 L F
.63114 .38973 m .63005 .3891 L .63044 .38938 L F
.63005 .3891 m .62821 .38803 L .63044 .38938 L F
.63114 .38973 m .62693 .38762 L .62975 .38781 L F
.63 .532 .725 r
.63225 .39103 m .62899 .38898 L .63092 .38965 L F
.63132 .38994 m .63092 .38965 L .63114 .38973 L F
.63225 .39103 m .63092 .38965 L .63132 .38994 L F
.63225 .39103 m .63114 .38973 L .63122 .39097 L F
.861 .978 .857 r
.63362 .3878 m .63225 .39103 L .63122 .39097 L F
.63362 .3878 m .63459 .38858 L .63225 .39103 L F
.63362 .3878 m .63176 .39026 L .63479 .39137 L F
.63176 .39026 m .63122 .39097 L .63304 .39117 L F
.63176 .39026 m .63304 .39117 L .63479 .39137 L F
.617 .649 .859 r
.62975 .38781 m .63122 .39097 L .63114 .38973 L F
0 0 .549 r
.63099 .38976 m .631 .38978 L .62975 .38781 L F
.631 .38978 m .63122 .39097 L .6305 .38942 L F
.631 .38978 m .6305 .38942 L .62975 .38781 L F
0 0 .523 r
.33654 .50912 m .33619 .50966 L .33465 .51077 L F
.33654 .50912 m .33803 .51279 L .33619 .50966 L F
.698 .822 .942 r
.47799 .45165 m .47927 .45402 L .48199 .4519 L F
0 0 0 r
.52313 .46751 m .51931 .46964 L .52335 .46788 L F
.194 0 0 r
.52538 .46813 m .52313 .46751 L .52335 .46788 L F
.52538 .46813 m .52597 .46815 L .52313 .46751 L F
.81 .955 .911 r
.49138 .41841 m .48851 .41933 L .49072 .41779 L F
.803 .996 .862 r
.49456 .4156 m .49138 .41841 L .49072 .41779 L F
.571 .777 .976 r
.61954 .41609 m .61794 .41862 L .61618 .41545 L F
.61954 .41609 m .62072 .41802 L .61794 .41862 L F
.157 0 .321 r
.22847 .55264 m .23058 .55199 L .23117 .54941 L F
.211 .101 .504 r
.22847 .55264 m .23065 .55369 L .23058 .55199 L F
.22847 .55264 m .22858 .55576 L .23065 .55369 L F
.814 .465 .396 r
.60119 .44758 m .60396 .44889 L .60357 .45089 L F
.933 .81 .699 r
.38724 .5652 m .38824 .56897 L .38918 .56644 L F
.834 .911 .889 r
.64154 .38644 m .63751 .38757 L .64013 .38699 L F
.245 .757 .758 r
.64338 .38574 m .64424 .38571 L .64154 .38644 L F
.64338 .38574 m .64154 .38644 L .64013 .38699 L F
.238 .7 .948 r
.44769 .59737 m .4501 .59658 L .44742 .59675 L F
.44769 .59737 m .45332 .59738 L .4501 .59658 L F
.542 .874 .992 r
.31155 .65533 m .31569 .65525 L .31457 .65549 L F
0 .4 .789 r
.31569 .65525 m .31705 .65548 L .31457 .65549 L F
.31569 .65525 m .31862 .65652 L .31705 .65548 L F
.412 0 0 r
.35317 .53509 m .35546 .53504 L .35733 .53335 L F
.729 .936 .609 r
.35733 .53335 m .35546 .53504 L .35827 .53137 L F
.099 0 .31 r
.31003 .5768 m .30855 .57592 L .31144 .5757 L F
.31003 .5768 m .30829 .57839 L .30855 .57592 L F
0 0 0 r
.67666 .37912 m .68038 .37695 L .67887 .37764 L F
.409 .834 .674 r
.67887 .37764 m .68038 .37695 L .68272 .37557 L F
.535 .611 .876 r
.35008 .54431 m .35342 .54636 L .35202 .54256 L F
.514 .572 .852 r
.35342 .54636 m .35431 .54281 L .35202 .54256 L F
.35342 .54636 m .356 .54633 L .35431 .54281 L F
.1 .541 .911 r
.60678 .42513 m .60876 .42565 L .60534 .42383 L F
.309 .765 .953 r
.24878 .53927 m .25133 .53901 L .25369 .53974 L F
.317 .77 .955 r
.25133 .53901 m .25395 .53903 L .25369 .53974 L F
.819 .546 .525 r
.24441 .57456 m .24714 .57555 L .24442 .57668 L F
0 0 .122 r
.24451 .57643 m .24441 .57456 L .24442 .57668 L F
.819 .546 .525 r
.24441 .57456 m .24434 .57581 L .24449 .5758 L F
.24441 .57456 m .24449 .5758 L .24714 .57555 L F
.928 .572 .142 r
.24441 .57456 m .24354 .57541 L .2436 .5731 L F
.926 .733 .247 r
.2436 .5731 m .24413 .57503 L .24441 .57456 L F
.24413 .57503 m .24434 .57581 L .24441 .57456 L F
.928 .572 .142 r
.24404 .57492 m .24413 .57503 L .24399 .57498 L F
.744 .857 .932 r
.24438 .57537 m .24434 .57581 L .24416 .57515 L F
.24438 .57537 m .24416 .57515 L .24413 .57503 L F
.24438 .57533 m .24438 .57537 L .24413 .57503 L F
0 0 .122 r
.24448 .57596 m .24449 .57582 L .24441 .57456 L F
.928 .572 .142 r
.24413 .57503 m .2445 .5755 L .24409 .57509 L F
.24413 .57503 m .24409 .57509 L .24399 .57498 L F
.24441 .57456 m .2445 .57548 L .24404 .57492 L F
.2445 .57548 m .2445 .5755 L .24404 .57492 L F
.744 .857 .932 r
.24458 .57294 m .24438 .57533 L .2436 .5731 L F
.24438 .57533 m .24413 .57503 L .2436 .5731 L F
.24795 .57237 m .24449 .57567 L .24458 .57294 L F
.24449 .57567 m .24434 .57581 L .24458 .57294 L F
0 0 .122 r
.24451 .57643 m .24454 .57659 L .24449 .57582 L F
.24451 .57643 m .24449 .57582 L .24448 .57596 L F
.76 .907 .941 r
.24714 .57555 m .24477 .57577 L .24795 .57237 L F
.24714 .57555 m .24795 .57237 L .24774 .57396 L F
.313 .005 .272 r
.24774 .57396 m .24451 .57643 L .24714 .57555 L F
.378 .839 .78 r
.2455 .57623 m .24451 .57643 L .24442 .57668 L F
.24714 .57555 m .245 .57627 L .2455 .57623 L F
.245 .57627 m .24451 .57643 L .2455 .57623 L F
.313 .005 .272 r
.24774 .57396 m .24732 .57688 L .24451 .57643 L F
0 0 .122 r
.24454 .57659 m .2447 .57747 L .24441 .57456 L F
.76 .907 .941 r
.24477 .57577 m .24434 .57581 L .24458 .57558 L F
.24477 .57577 m .24458 .57558 L .24795 .57237 L F
.928 .572 .142 r
.24399 .57498 m .24458 .5763 L .24354 .57541 L F
.2445 .5755 m .24458 .5763 L .24399 .57498 L F
.24458 .5763 m .2447 .57747 L .24406 .57633 L F
.24458 .5763 m .24406 .57633 L .24354 .57541 L F
.476 .333 .607 r
.3618 .58831 m .36183 .59114 L .35923 .58908 L F
0 0 .092 r
.54146 .40093 m .54222 .39902 L .54105 .40087 L F
.54146 .40093 m .54167 .40223 L .54222 .39902 L F
.36 .833 .843 r
.6343 .33754 m .62997 .33839 L .63261 .33757 L F
0 0 0 r
.63261 .33757 m .63645 .33617 L .6343 .33754 L F
.524 .631 .899 r
.30131 .65362 m .30234 .65531 L .30514 .6542 L F
.604 .08 0 r
.53063 .42787 m .52706 .42559 L .52733 .42847 L F
.208 0 .234 r
.6784 .30515 m .67792 .30701 L .68071 .3039 L F
.539 .216 .37 r
.29728 .57779 m .29997 .5777 L .30184 .57318 L F
.553 .255 .417 r
.30184 .57318 m .30478 .57413 L .30405 .57256 L F
.557 .202 .322 r
.30274 .57753 m .30184 .57318 L .29997 .5777 L F
.30274 .57753 m .30478 .57413 L .30184 .57318 L F
.768 .785 .867 r
.39592 .48565 m .39829 .48742 L .394 .48707 L F
.732 .818 .918 r
.39829 .48742 m .39547 .48816 L .394 .48707 L F
.626 .766 .946 r
.4009 .48677 m .39829 .48742 L .39592 .48565 L F
.841 .771 .784 r
.54454 .46617 m .54462 .46101 L .54213 .4617 L F
0 0 .091 r
.35778 .55624 m .3575 .55244 L .35602 .55415 L F
.35778 .55624 m .35781 .55629 L .3575 .55244 L F
.673 .41 .515 r
.35781 .55629 m .35602 .55415 L .3575 .55244 L F
.35781 .55629 m .35507 .55705 L .35602 .55415 L F
0 0 0 r
.30927 .64406 m .30685 .64469 L .30332 .64631 L F
0 0 .122 r
.30838 .6413 m .30685 .64469 L .30927 .64406 L F
.995 .808 .443 r
.34557 .60755 m .34456 .60723 L .34487 .60396 L F
.458 .289 .564 r
.2607 .58655 m .2632 .58815 L .2608 .5887 L F
0 0 .191 r
.48645 .55209 m .48623 .55456 L .48505 .55627 L F
0 0 0 r
.48623 .55456 m .48455 .55881 L .48505 .55627 L F
.118 0 .191 r
.36283 .60511 m .36391 .60643 L .36512 .60416 L F
.36283 .60511 m .36207 .60752 L .36391 .60643 L F
.048 0 0 r
.55867 .37959 m .5569 .37949 L .55449 .37933 L F
.55867 .37959 m .5569 .37949 L .55449 .37933 L F
.635 .348 .464 r
.42716 .5617 m .42333 .56256 L .42545 .55913 L F
.196 .002 .375 r
.24831 .58734 m .24543 .59058 L .24666 .58865 L F
.917 .52 .205 r
.58458 .42466 m .58401 .4225 L .58218 .42113 L F
.471 .759 .993 r
.60713 .40129 m .61094 .40225 L .6097 .40088 L F
.578 .817 .989 r
.6097 .40088 m .61094 .40225 L .61356 .40135 L F
.955 .83 .682 r
.38731 .59803 m .3858 .60125 L .38757 .60197 L F
.969 .887 .693 r
.38505 .60399 m .38757 .60197 L .3858 .60125 L F
.38505 .60399 m .38643 .60505 L .38757 .60197 L F
.457 .837 .988 r
.33239 .65441 m .33628 .65452 L .3345 .653 L F
.712 .827 .936 r
.33628 .65452 m .33696 .65218 L .3345 .653 L F
.33628 .65452 m .33879 .65335 L .33696 .65218 L F
.176 0 0 r
.28961 .58503 m .28518 .58726 L .28706 .58537 L F
.676 .645 .812 r
.3588 .54703 m .35757 .54969 L .36095 .5495 L F
.591 .354 .525 r
.36095 .5495 m .3575 .55244 L .35757 .54969 L F
.623 .624 .83 r
.35855 .54758 m .3575 .55244 L .35757 .54969 L F
.406 0 0 r
.34123 .54276 m .3442 .54355 L .34113 .54299 L F
.54 .302 .502 r
.29916 .58227 m .29627 .58494 L .29655 .5823 L F
.886 .932 .844 r
.31567 .5356 m .31649 .53695 L .31988 .53332 L F
0 0 0 r
.67267 .31128 m .67469 .31004 L .6756 .30825 L F
.6756 .30825 m .67707 .30843 L .67792 .30701 L F
.6756 .30825 m .67469 .31004 L .67707 .30843 L F
.469 .889 .796 r
.44757 .57004 m .44913 .56897 L .44978 .56899 L F
.44757 .57004 m .44913 .56897 L .44978 .56899 L F
.531 .714 .956 r
.31977 .52201 m .32525 .52465 L .32255 .52119 L F
.31977 .52201 m .32525 .52465 L .32255 .52119 L F
.579 .746 .956 r
.51209 .42426 m .50967 .42658 L .50965 .42461 L F
.51209 .42426 m .51369 .4266 L .50967 .42658 L F
0 0 0 r
.26442 .63036 m .26371 .6348 L .26616 .6343 L F
.948 .638 .416 r
.39125 .52954 m .38933 .52879 L .38915 .52635 L F
.695 .162 0 r
.39321 .53213 m .38933 .52879 L .39125 .52954 L F
.538 .629 .89 r
.71212 .30841 m .71301 .31095 L .71009 .31129 L F
.197 .284 .728 r
.54494 .44251 m .54713 .44326 L .54735 .44114 L F
.75 .844 .922 r
.29314 .64963 m .29781 .64895 L .29563 .64877 L F
.651 .924 .975 r
.29563 .64877 m .29781 .64895 L .30008 .64759 L F
.945 .596 .2 r
.29781 .64895 m .29926 .65263 L .30008 .64759 L F
.967 .833 .658 r
.59561 .40625 m .5933 .40741 L .59405 .40489 L F
.59561 .40625 m .59478 .40886 L .5933 .40741 L F
.818 .676 .706 r
.51725 .45467 m .51679 .45765 L .52074 .45797 L F
.793 .919 .535 r
.51934 .45934 m .52074 .45797 L .51679 .45765 L F
.51934 .45934 m .51856 .46157 L .52074 .45797 L F
.474 .484 .788 r
.25401 .58864 m .25666 .58882 L .25485 .58445 L F
.737 .564 .659 r
.48336 .45782 m .4875 .4584 L .48591 .45384 L F
.583 .651 .883 r
.48451 .45063 m .48591 .45384 L .48861 .45241 L F
.587 .665 .892 r
.48591 .45384 m .48995 .45518 L .48861 .45241 L F
.839 .743 .758 r
.4875 .4584 m .48995 .45518 L .48591 .45384 L F
.253 .149 .537 r
.51782 .47124 m .51974 .47242 L .51931 .46964 L F
.796 .921 .921 r
.53453 .42809 m .53807 .42594 L .5365 .42485 L F
.99 .803 .558 r
.53676 .42773 m .53807 .42594 L .5365 .42485 L F
0 0 .453 r
.31082 .57047 m .31172 .57058 L .31357 .56944 L F
.794 .966 .915 r
.41581 .45214 m .41831 .45267 L .41542 .45462 L F
.735 .961 .941 r
.42027 .45103 m .41831 .45267 L .41581 .45214 L F
0 0 0 r
.66654 .3171 m .66894 .31575 L .66951 .31408 L F
.66654 .3171 m .66577 .31858 L .66894 .31575 L F
.242 .116 .501 r
.4675 .57775 m .46576 .57606 L .46504 .5785 L F
.4675 .57775 m .46742 .57493 L .46576 .57606 L F
.027 0 .45 r
.34171 .57523 m .34149 .57938 L .34046 .57882 L F
.63 .521 .712 r
.34164 .58015 m .34046 .57882 L .34149 .57938 L F
.34164 .58015 m .34019 .58182 L .34046 .57882 L F
.438 .82 .583 r
.64356 .39875 m .64702 .39618 L .64567 .39714 L F
0 0 0 r
.64567 .39714 m .64702 .39618 L .64937 .39473 L F
.987 .767 .516 r
.34189 .59427 m .34297 .59739 L .34394 .59559 L F
.545 .846 .998 r
.34506 .5947 m .34189 .59427 L .34394 .59559 L F
0 0 0 r
.34394 .59559 m .34297 .59739 L .34506 .5947 L F
.016 .119 .629 r
.23076 .6052 m .23237 .60705 L .23111 .60433 L F
.575 .934 .784 r
.44978 .56899 m .44913 .56897 L .45109 .56749 L F
.83 .844 .858 r
.61297 .42576 m .61395 .42133 L .61173 .42444 L F
.61297 .42576 m .6154 .42339 L .61395 .42133 L F
0 0 0 r
.66951 .31408 m .67157 .31241 L .67267 .31128 L F
.66951 .31408 m .66894 .31575 L .67157 .31241 L F
.713 .507 .609 r
.72998 .30792 m .73034 .31071 L .72655 .31095 L F
.545 .387 .618 r
.73238 .30772 m .73034 .31071 L .72998 .30792 L F
.944 .612 .367 r
.40207 .54955 m .40034 .55096 L .39983 .54924 L F
.40207 .54955 m .40229 .55199 L .40034 .55096 L F
.865 .972 .857 r
.5088 .46995 m .51286 .46765 L .51132 .46627 L F
.845 .89 .871 r
.51132 .46627 m .51286 .46765 L .5157 .46459 L F
.934 .562 .263 r
.38603 .51998 m .38418 .5189 L .38367 .51661 L F
.843 .495 .397 r
.38786 .52216 m .38418 .5189 L .38603 .51998 L F
.66 .799 .949 r
.48995 .45518 m .4914 .45203 L .48861 .45241 L F
.48995 .45518 m .4927 .45427 L .4914 .45203 L F
.439 .758 .995 r
.55087 .40981 m .55523 .41075 L .55389 .40909 L F
.6 .819 .984 r
.55389 .40909 m .55523 .41075 L .55783 .40952 L F
.552 .235 .385 r
.30096 .61817 m .30348 .6182 L .3032 .6202 L F
.30096 .61817 m .30348 .6182 L .3032 .6202 L F
.883 .478 .247 r
.35225 .50658 m .35362 .50976 L .35569 .51041 L F
.875 .459 .224 r
.35362 .50976 m .35411 .5116 L .35569 .51041 L F
.867 .445 .214 r
.35411 .5116 m .35625 .51252 L .35569 .51041 L F
.797 .36 0 r
.4025 .5592 m .40486 .56263 L .40356 .56127 L F
.975 .707 .3 r
.40486 .56263 m .40341 .56275 L .40356 .56127 L F
.40486 .56263 m .40504 .56556 L .40341 .56275 L F
.854 .541 .459 r
.35625 .51252 m .35989 .5159 L .35955 .51378 L F
.057 0 .134 r
.50897 .5133 m .50862 .51572 L .50617 .5168 L F
.042 0 .117 r
.51172 .51004 m .51119 .51253 L .50897 .5133 L F
0 0 0 r
.51119 .51253 m .50862 .51572 L .50897 .5133 L F
.91 .837 .761 r
.72679 .28452 m .72857 .28585 L .7266 .28881 L F
0 0 0 r
.72963 .2856 m .73139 .28454 L .72857 .28585 L F
.72963 .2856 m .72857 .28585 L .72679 .28452 L F
.412 .515 .853 r
.43405 .46352 m .43497 .46024 L .43212 .46081 L F
.43405 .46352 m .43649 .46393 L .43497 .46024 L F
.99 .727 .41 r
.42895 .56249 m .42768 .56448 L .42716 .5617 L F
.42895 .56249 m .42908 .56616 L .42768 .56448 L F
.254 .661 .965 r
.5664 .3789 m .56516 .3799 L .56437 .37821 L F
.5664 .3789 m .56781 .3801 L .56516 .3799 L F
.753 .678 .779 r
.50333 .4575 m .50749 .45809 L .50599 .45417 L F
.508 .542 .826 r
.50599 .45417 m .50749 .45809 L .50998 .45755 L F
0 .166 .698 r
.43128 .58416 m .4327 .58758 L .43106 .58582 L F
.808 .997 .783 r
.46164 .4358 m .45907 .4387 L .45995 .43634 L F
.701 .922 .967 r
.45995 .43634 m .45907 .4387 L .45762 .4378 L F
.673 .958 .945 r
.68838 .37243 m .69069 .36994 L .68821 .3717 L F
.68838 .37243 m .69256 .37035 L .69069 .36994 L F
.225 .741 .728 r
.59927 .37747 m .5973 .37789 L .59463 .37863 L F
.776 .507 .529 r
.60082 .37579 m .5973 .37789 L .59927 .37747 L F
0 .509 .859 r
.25206 .5324 m .25181 .53299 L .25098 .52952 L F
.25206 .5324 m .25278 .53297 L .25181 .53299 L F
.474 .255 .501 r
.25394 .5353 m .25181 .53299 L .25278 .53297 L F
.25394 .5353 m .25145 .53593 L .25181 .53299 L F
.803 .996 .862 r
.49456 .4156 m .49072 .41779 L .49307 .4143 L F
.837 .894 .88 r
.49767 .41271 m .49456 .4156 L .49307 .4143 L F
0 0 0 r
.24647 .5458 m .24444 .54912 L .24454 .54682 L F
.472 .047 .151 r
.53453 .42809 m .53378 .43043 L .53108 .43038 L F
.373 .354 .709 r
.5365 .42485 m .53453 .42809 L .53395 .42573 L F
.5365 .42485 m .53676 .42773 L .53453 .42809 L F
.189 0 .019 r
.53453 .42809 m .5361 .42932 L .53378 .43043 L F
.53453 .42809 m .53676 .42773 L .5361 .42932 L F
.376 0 .107 r
.34597 .60262 m .34487 .60396 L .34203 .60424 L F
0 0 0 r
.3475 .60204 m .34487 .60396 L .34597 .60262 L F
.932 .928 .779 r
.70445 .336 m .70546 .3345 L .70444 .33312 L F
.295 .252 .639 r
.60101 .35696 m .60346 .35712 L .60257 .35202 L F
.619 .613 .823 r
.60346 .35712 m .6011 .36001 L .60101 .35696 L F
0 0 .3 r
.60101 .35696 m .60217 .3573 L .60346 .35712 L F
.60101 .35696 m .6011 .36001 L .60217 .3573 L F
.864 .799 .785 r
.35778 .55624 m .35718 .55784 L .35781 .55629 L F
.35778 .55624 m .35507 .55705 L .35718 .55784 L F
.579 .321 .49 r
.33052 .57143 m .33345 .56852 L .33105 .56918 L F
.599 .938 .945 r
.3322 .56164 m .32962 .56265 L .3304 .56125 L F
.698 .592 .734 r
.3322 .56164 m .33286 .56298 L .32962 .56265 L F
.465 0 0 r
.32962 .56265 m .33286 .56298 L .33085 .56359 L F
0 .055 .603 r
.32962 .56265 m .33085 .56359 L .3304 .56125 L F
.696 .453 0 r
.60146 .43989 m .60178 .44147 L .60254 .44522 L F
.616 .758 .947 r
.60344 .43759 m .60178 .44147 L .60146 .43989 L F
.60344 .43759 m .60527 .44033 L .60178 .44147 L F
.696 .453 0 r
.60254 .44522 m .60178 .44147 L .60146 .43989 L F
.604 .612 .832 r
.60527 .44033 m .60559 .44318 L .60178 .44147 L F
.68 .842 .961 r
.41332 .4534 m .41542 .45462 L .41137 .45482 L F
.314 0 .153 r
.41542 .45462 m .41071 .45829 L .41137 .45482 L F
.41542 .45462 m .41413 .45824 L .41071 .45829 L F
.794 .966 .915 r
.41581 .45214 m .41542 .45462 L .41332 .4534 L F
.823 .446 .34 r
.41691 .45768 m .41413 .45824 L .41542 .45462 L F
0 0 0 r
.53664 .44967 m .54154 .44711 L .53928 .44827 L F
.534 .538 .806 r
.70725 .2869 m .70579 .29166 L .70448 .28765 L F
.70725 .2869 m .70833 .29081 L .70579 .29166 L F
.599 .615 .839 r
.52247 .40893 m .52142 .41247 L .5201 .40875 L F
.52247 .40893 m .5244 .41241 L .52142 .41247 L F
0 0 .297 r
.52278 .41337 m .52142 .41247 L .5244 .41241 L F
.52278 .41337 m .52118 .41514 L .52142 .41247 L F
0 0 .338 r
.57387 .36981 m .57435 .37034 L .57486 .36835 L F
.57387 .36981 m .57504 .37231 L .57435 .37034 L F
.531 .907 .739 r
.5488 .48238 m .55246 .48033 L .55247 .48032 L F
.686 .98 .86 r
.55246 .48033 m .55604 .47789 L .55402 .47821 L F
.55246 .48033 m .55402 .47821 L .55247 .48032 L F
.107 .134 .606 r
.34256 .58894 m .34297 .58408 L .34496 .58602 L F
.332 .626 .958 r
.34297 .58408 m .34583 .58509 L .34496 .58602 L F
.429 .8 .994 r
.28796 .58158 m .28997 .58204 L .28814 .57887 L F
0 .099 .645 r
.28814 .57887 m .29036 .58122 L .29379 .57964 L F
.28814 .57887 m .28997 .58204 L .29036 .58122 L F
.697 .953 .953 r
.32683 .51838 m .32359 .52008 L .32431 .51798 L F
.09 .296 .777 r
.32359 .52008 m .32604 .52189 L .32431 .51798 L F
.106 .406 .857 r
.59692 .38066 m .5963 .38127 L .59463 .37863 L F
.554 .887 .987 r
.28783 .5106 m .28623 .50972 L .28983 .50964 L F
.266 .02 .342 r
.28983 .50964 m .28722 .51296 L .28783 .5106 L F
.716 .628 .758 r
.45884 .45964 m .46124 .46218 L .46259 .46034 L F
.438 .82 .583 r
.64356 .39875 m .64567 .39714 L .64361 .39883 L F
.799 .716 .774 r
.50998 .45755 m .51161 .46164 L .51427 .45814 L F
.147 0 0 r
.51448 .4609 m .51161 .46164 L .51052 .463 L F
.503 .305 .545 r
.51427 .45814 m .51161 .46164 L .51448 .4609 L F
0 0 0 r
.34944 .52607 m .35125 .52541 L .35171 .52419 L F
.771 .531 .572 r
.35284 .52929 m .35157 .52921 L .34944 .52607 L F
0 .091 .615 r
.35157 .52921 m .35312 .52735 L .3523 .52563 L F
.35184 .52553 m .3523 .52563 L .35189 .52478 L F
.35157 .52921 m .3523 .52563 L .35184 .52553 L F
0 0 .518 r
.35126 .52539 m .35456 .52312 L .35171 .52419 L F
.35125 .52541 m .35127 .5254 L .35126 .52539 L F
.35127 .5254 m .35456 .52312 L .35126 .52539 L F
.799 .716 .774 r
.50998 .45755 m .51427 .45814 L .51258 .45662 L F
.532 .553 .822 r
.51427 .45814 m .51523 .45343 L .51258 .45662 L F
.51427 .45814 m .51679 .45765 L .51523 .45343 L F
.473 .284 .542 r
.51427 .45814 m .51448 .4609 L .51679 .45765 L F
.657 .876 .98 r
.471 .4533 m .47255 .45447 L .47512 .45327 L F
0 0 0 r
.61085 .37794 m .61217 .37682 L .61439 .3754 L F
.854 .943 .579 r
.3794 .61338 m .37906 .61541 L .38111 .61161 L F
.76 .926 .564 r
.3794 .61338 m .38111 .61161 L .38169 .6099 L F
.452 0 0 r
.34583 .58509 m .35112 .58801 L .34939 .58559 L F
.207 .71 .907 r
.61293 .41486 m .61391 .41533 L .60986 .41492 L F
.094 .625 .867 r
.61293 .41486 m .61618 .41545 L .61391 .41533 L F
.61293 .41486 m .61618 .41545 L .61391 .41533 L F
.348 0 .212 r
.34633 .55743 m .3501 .55487 L .34822 .5553 L F
.702 .757 .895 r
.34224 .6525 m .34616 .65173 L .34376 .64901 L F
.389 .161 .443 r
.27927 .61742 m .27666 .61828 L .27661 .62072 L F
.27927 .61742 m .27666 .61828 L .27661 .62072 L F
.933 .58 .329 r
.3828 .5573 m .38447 .55646 L .38236 .55502 L F
.3828 .5573 m .38487 .55857 L .38447 .55646 L F
.797 .56 .578 r
.5255 .3993 m .52536 .40206 L .52945 .40265 L F
.63 .412 .567 r
.52669 .40597 m .52945 .40265 L .52536 .40206 L F
.52669 .40597 m .52941 .40532 L .52945 .40265 L F
.872 .476 .28 r
.35025 .50809 m .35225 .50658 L .34978 .50657 L F
.35025 .50809 m .35362 .50976 L .35225 .50658 L F
.793 .526 .534 r
.33328 .5522 m .33732 .55542 L .33498 .55543 L F
.486 0 0 r
.36334 .5008 m .36402 .50154 L .36169 .49997 L F
.36334 .5008 m .36575 .5028 L .36402 .50154 L F
.533 0 0 r
.36753 .50382 m .36575 .5028 L .36334 .5008 L F
0 0 0 r
.50862 .51572 m .5057 .51927 L .50617 .5168 L F
.225 .341 .773 r
.33452 .56167 m .33286 .56298 L .3322 .56164 L F
.504 .907 .812 r
.33085 .56359 m .33286 .56298 L .33452 .56167 L F
.274 .541 .92 r
.60436 .37807 m .60571 .38104 L .60205 .37872 L F
.54 .6 .863 r
.54446 .40953 m .54023 .40598 L .54291 .40508 L F
0 0 0 r
.54381 .41084 m .54177 .41273 L .54446 .40953 L F
.506 .399 .667 r
.54705 .40555 m .54446 .40953 L .54291 .40508 L F
.54705 .40555 m .54692 .40893 L .54446 .40953 L F
0 0 0 r
.54446 .40953 m .54573 .40984 L .54381 .41084 L F
.54446 .40953 m .54692 .40893 L .54573 .40984 L F
.241 .749 .878 r
.61316 .35094 m .6142 .35017 L .61156 .35112 L F
.61316 .35094 m .61596 .35061 L .6142 .35017 L F
.504 .446 .725 r
.30008 .64759 m .29926 .65263 L .30282 .64944 L F
.562 .526 .773 r
.30131 .65362 m .30282 .64944 L .29926 .65263 L F
.675 .91 .577 r
.59606 .43071 m .5972 .42969 L .59556 .43168 L F
.823 .928 .902 r
.59783 .42678 m .5972 .42969 L .59606 .43071 L F
.59783 .42678 m .59973 .42769 L .5972 .42969 L F
.298 .074 .396 r
.48976 .51676 m .49173 .51597 L .4923 .51351 L F
.34 .16 .485 r
.48976 .51676 m .49034 .51905 L .49173 .51597 L F
.947 .698 .528 r
.37225 .53531 m .37431 .53941 L .37376 .53687 L F
.681 .533 .677 r
.45139 .46526 m .4539 .46416 L .44953 .46351 L F
0 0 0 r
.67267 .31128 m .67369 .31064 L .67469 .31004 L F
.67267 .31128 m .67157 .31241 L .67369 .31064 L F
.169 0 .183 r
.51466 .50694 m .51424 .50949 L .51172 .51004 L F
.046 0 .148 r
.5161 .50813 m .51466 .50694 L .51714 .50597 L F
.5161 .50813 m .51424 .50949 L .51466 .50694 L F
.811 .38 .222 r
.62749 .39599 m .62627 .39758 L .62534 .39617 L F
.62749 .39599 m .62989 .39888 L .62627 .39758 L F
.181 0 0 r
.61319 .39385 m .61221 .39293 L .61076 .39415 L F
.61319 .39385 m .61496 .39276 L .61221 .39293 L F
.591 .629 .858 r
.32485 .5321 m .32394 .53656 L .32234 .53554 L F
.603 .797 .974 r
.49758 .45924 m .49935 .45731 L .4968 .45763 L F
.49758 .45924 m .50066 .45853 L .49935 .45731 L F
.934 .693 .213 r
.5631 .38283 m .56233 .38343 L .56158 .38142 L F
.5631 .38283 m .56323 .38622 L .56233 .38343 L F
.055 0 .2 r
.34001 .59273 m .34118 .59231 L .34256 .58894 L F
.808 .682 .725 r
.33707 .59342 m .34013 .59019 L .34118 .59231 L F
0 0 .38 r
.34013 .59019 m .34103 .59229 L .3411 .5922 L F
.34103 .59229 m .34189 .59427 L .3411 .5922 L F
.34103 .59229 m .3411 .5922 L .3411 .5922 L F
.808 .682 .725 r
.33707 .59342 m .34097 .59237 L .34001 .59273 L F
.34097 .59237 m .34118 .59231 L .34094 .5924 L F
.34097 .59237 m .34094 .5924 L .34001 .59273 L F
.916 .926 .805 r
.35112 .58801 m .35205 .58361 L .35139 .58559 L F
.279 0 .153 r
.24895 .52619 m .25122 .52558 L .25262 .52245 L F
.124 0 0 r
.25122 .52558 m .25526 .52172 L .25262 .52245 L F
0 0 0 r
.65595 .39163 m .65816 .39098 L .65563 .39226 L F
.65595 .39163 m .65896 .38936 L .65816 .39098 L F
.227 0 .077 r
.39815 .49166 m .39755 .49336 L .39509 .49267 L F
.61 .795 .367 r
.49293 .53858 m .49077 .54218 L .49197 .54019 L F
.154 0 0 r
.30473 .58086 m .30602 .5792 L .30829 .57839 L F
.195 .054 .45 r
.55703 .38935 m .55935 .39048 L .55968 .38845 L F
.399 .815 .624 r
.55968 .38845 m .56166 .38715 L .56323 .38622 L F
.343 .153 .472 r
.55935 .39048 m .56166 .38715 L .55968 .38845 L F
.55935 .39048 m .56141 .38971 L .56166 .38715 L F
.476 .5 .804 r
.55962 .38572 m .56141 .38971 L .55935 .39048 L F
.723 .955 .668 r
.56141 .38971 m .5608 .38974 L .55935 .39048 L F
.195 .054 .45 r
.55703 .38935 m .55683 .39176 L .55935 .39048 L F
.921 .835 .743 r
.55935 .39048 m .55691 .38988 L .55793 .38571 L F
.476 .5 .804 r
.55962 .38572 m .55935 .39048 L .55793 .38571 L F
.723 .955 .668 r
.5608 .38974 m .55691 .38988 L .55935 .39048 L F
.195 .054 .45 r
.55683 .39176 m .55682 .39191 L .55935 .39048 L F
.738 .486 .548 r
.334 .58219 m .32961 .58471 L .32983 .58183 L F
.334 .58219 m .33403 .58462 L .32961 .58471 L F
.767 .77 .855 r
.51898 .45357 m .52358 .45249 L .52198 .45126 L F
.091 0 .132 r
.51323 .51125 m .51172 .51004 L .51424 .50949 L F
.51323 .51125 m .51119 .51253 L .51172 .51004 L F
.09 0 .018 r
.52458 .50139 m .52348 .50036 L .52603 .49999 L F
.52458 .50139 m .52251 .50242 L .52348 .50036 L F
.986 .888 .639 r
.39012 .52376 m .388 .52505 L .38786 .52216 L F
.39012 .52376 m .38915 .52635 L .388 .52505 L F
.722 .981 .91 r
.54967 .44271 m .54884 .44502 L .55129 .4431 L F
0 0 .36 r
.54993 .44566 m .54884 .44502 L .54967 .44271 L F
.54993 .44566 m .54943 .44801 L .54884 .44502 L F
.888 .47 .196 r
.42591 .53588 m .42715 .53891 L .42932 .53954 L F
.751 .903 .517 r
.42795 .54092 m .42932 .53954 L .42715 .53891 L F
.42795 .54092 m .42739 .54221 L .42932 .53954 L F
.881 .609 .522 r
.42739 .54221 m .43127 .54292 L .42932 .53954 L F
.701 .57 .704 r
.42932 .53954 m .43298 .54225 L .43388 .54038 L F
.42932 .53954 m .43127 .54292 L .43298 .54225 L F
.72 .799 .913 r
.55634 .42105 m .55996 .42154 L .55892 .41825 L F
.809 .588 .603 r
.55708 .42181 m .55996 .42154 L .55634 .42105 L F
.767 .824 .897 r
.55892 .41825 m .55996 .42154 L .56276 .41903 L F
.212 .577 .942 r
.55996 .42154 m .56394 .42242 L .56276 .41903 L F
0 0 0 r
.61988 .39871 m .62321 .39648 L .62193 .39745 L F
.412 0 0 r
.62193 .39745 m .62321 .39648 L .62627 .39758 L F
.433 .077 .259 r
.62321 .39648 m .62534 .39617 L .62627 .39758 L F
.437 .8 .996 r
.3331 .5713 m .33696 .57247 L .33684 .57193 L F
.783 .692 .764 r
.72226 .32086 m .72523 .31796 L .72091 .31686 L F
.809 .5 .468 r
.72503 .32007 m .72523 .31796 L .72091 .31686 L F
.322 .084 .389 r
.72767 .31674 m .72523 .31796 L .72503 .32007 L F
.709 .252 .166 r
.30733 .57536 m .30405 .57256 L .30478 .57413 L F
.612 .803 .973 r
.6154 .42339 m .61677 .42061 L .61395 .42133 L F
.6154 .42339 m .61839 .42229 L .61677 .42061 L F
.567 .822 .993 r
.24612 .56176 m .24785 .56296 L .24861 .56098 L F
.24612 .56176 m .24785 .56296 L .24861 .56098 L F
.276 0 .209 r
.31508 .57192 m .31336 .57512 L .31144 .5757 L F
.646 .651 .84 r
.31598 .56834 m .31508 .57192 L .31357 .56944 L F
.31598 .56834 m .31769 .57225 L .31508 .57192 L F
.738 .436 .47 r
.3175 .5752 m .31508 .57192 L .31769 .57225 L F
.3175 .5752 m .31336 .57512 L .31508 .57192 L F
.698 .82 .94 r
.26213 .59076 m .26061 .59185 L .26445 .59205 L F
.575 .53 .767 r
.26445 .59205 m .2632 .58815 L .26213 .59076 L F
.26445 .59205 m .26581 .58805 L .2632 .58815 L F
.26445 .59205 m .26757 .59215 L .26581 .58805 L F
.403 0 0 r
.26757 .59215 m .26526 .59425 L .26445 .59205 L F
.26757 .59215 m .26526 .59425 L .26445 .59205 L F
.601 .443 .639 r
.50249 .49745 m .50274 .50032 L .50527 .49691 L F
.627 .443 .614 r
.33836 .61815 m .33839 .62085 L .33564 .62141 L F
.781 .973 .687 r
.33836 .61815 m .33564 .62141 L .33839 .62085 L F
.777 .55 .591 r
.60152 .39498 m .60519 .39284 L .60439 .39244 L F
.60152 .39498 m .60553 .39565 L .60519 .39284 L F
.883 .976 .833 r
.53428 .46474 m .53613 .46257 L .53385 .46285 L F
.983 .794 .389 r
.53286 .46481 m .53428 .46474 L .53385 .46285 L F
.53286 .46481 m .53417 .46772 L .53428 .46474 L F
.771 .959 .649 r
.52619 .48369 m .52921 .48058 L .52763 .47946 L F
.52619 .48369 m .52649 .48404 L .52921 .48058 L F
.544 .332 .542 r
.52649 .48404 m .52927 .48376 L .52921 .48058 L F
.871 .931 .86 r
.52763 .47946 m .52921 .48058 L .53174 .4774 L F
.579 .441 .658 r
.52921 .48058 m .53183 .48044 L .53174 .4774 L F
.48 .243 .477 r
.52927 .48376 m .53183 .48044 L .52921 .48058 L F
.702 .385 .437 r
.3304 .56125 m .33486 .559 L .3322 .56164 L F
.225 .341 .773 r
.33452 .56167 m .3322 .56164 L .33486 .559 L F
.782 .517 .535 r
.39002 .48684 m .394 .48707 L .39355 .48417 L F
.557 0 0 r
.33728 .51947 m .33543 .51997 L .33321 .51869 L F
.49 .269 .505 r
.34011 .51689 m .33972 .51971 L .33728 .51947 L F
.34011 .51689 m .33972 .51971 L .33728 .51947 L F
.626 .957 .804 r
.33785 .5182 m .33728 .51947 L .33972 .51971 L F
.33785 .5182 m .33543 .51997 L .33728 .51947 L F
.782 .549 .584 r
.43975 .47939 m .4367 .4803 L .4391 .47664 L F
.43975 .47939 m .44087 .48082 L .4367 .4803 L F
.674 .684 .851 r
.52742 .43929 m .52986 .4381 L .52455 .43613 L F
.52742 .43929 m .52986 .4381 L .52455 .43613 L F
.707 .555 .68 r
.53612 .40554 m .53785 .4094 L .53374 .40918 L F
.677 .542 .693 r
.54023 .40598 m .53785 .4094 L .53612 .40554 L F
.678 .95 .955 r
.45138 .44065 m .45033 .44235 L .44742 .44287 L F
.45138 .44065 m .45215 .44125 L .45033 .44235 L F
.672 .93 .971 r
.35092 .64773 m .3547 .64735 L .3524 .64672 L F
.846 .96 .882 r
.3547 .64735 m .35363 .64551 L .3524 .64672 L F
.3547 .64735 m .35774 .64439 L .35363 .64551 L F
.107 .134 .606 r
.34256 .58894 m .34521 .5869 L .34297 .58408 L F
.989 .849 .61 r
.34256 .58894 m .34013 .59019 L .34521 .5869 L F
.34256 .58894 m .34118 .59231 L .34013 .59019 L F
0 0 .026 r
.59556 .43168 m .59566 .43328 L .59606 .43071 L F
.59556 .43168 m .59506 .43441 L .59566 .43328 L F
0 0 .112 r
.59734 .42864 m .59606 .43071 L .59566 .43328 L F
.59734 .42864 m .59566 .43327 L .59694 .4315 L F
.59566 .43327 m .59566 .43328 L .59694 .4315 L F
0 0 0 r
.59783 .42678 m .59702 .42858 L .59734 .42864 L F
.59702 .42858 m .59606 .43071 L .59734 .42864 L F
0 .095 .593 r
.59761 .42869 m .59734 .42864 L .59946 .43041 L F
.757 .722 .192 r
.59785 .42609 m .59783 .42678 L .59734 .42864 L F
.985 .796 .567 r
.59625 .42447 m .59785 .42609 L .59734 .42864 L F
.59625 .42447 m .59661 .42583 L .59562 .42685 L F
.59661 .42583 m .59734 .42864 L .59562 .42685 L F
0 .095 .593 r
.59562 .42685 m .59734 .42864 L .59761 .42869 L F
.4 .194 .482 r
.59734 .42864 m .59694 .4315 L .59946 .43041 L F
.687 .237 .177 r
.59562 .42685 m .59804 .42914 L .59403 .42849 L F
.59562 .42685 m .59403 .42849 L .59398 .42848 L F
.573 .883 .992 r
.59774 .4304 m .59694 .4315 L .59537 .43039 L F
.59946 .43041 m .59694 .4315 L .59774 .4304 L F
.184 .346 .793 r
.59633 .43201 m .59566 .43328 L .59361 .43428 L F
.59694 .4315 m .59566 .43328 L .59633 .43201 L F
0 0 .026 r
.59506 .43441 m .5949 .43526 L .59566 .43328 L F
.795 .363 .224 r
.33898 .54232 m .33688 .54268 L .33461 .53965 L F
.699 .208 .076 r
.33898 .54232 m .3368 .5441 L .33688 .54268 L F
.504 0 0 r
.34113 .54299 m .3368 .5441 L .33898 .54232 L F
0 0 .023 r
.46574 .54101 m .46548 .53971 L .46484 .54246 L F
.46574 .54101 m .4663 .53897 L .46548 .53971 L F
.738 .315 .245 r
.33781 .58534 m .33597 .5871 L .33403 .58462 L F
.259 0 .027 r
.34026 .58433 m .33597 .5871 L .33781 .58534 L F
.926 .917 .788 r
.51784 .44479 m .52013 .44125 L .51901 .43976 L F
.88 .92 .848 r
.51901 .43976 m .52013 .44125 L .52288 .43738 L F
.786 .617 .671 r
.56876 .44422 m .57088 .44787 L .57142 .44727 L F
0 .397 .849 r
.57088 .44787 m .57265 .44905 L .57142 .44727 L F
.724 .986 .893 r
.53385 .46285 m .53613 .46257 L .5382 .46091 L F
.579 .841 .994 r
.44634 .58245 m .44724 .58042 L .44473 .57867 L F
.44634 .58245 m .45037 .58193 L .44724 .58042 L F
.745 .509 .573 r
.42684 .54543 m .43127 .54292 L .42739 .54221 L F
.42684 .54543 m .43129 .54568 L .43127 .54292 L F
.642 .426 .574 r
.43127 .54292 m .43129 .54568 L .43298 .54225 L F
.591 .354 .525 r
.36095 .5495 m .36067 .55216 L .3575 .55244 L F
.507 .593 .875 r
.36095 .5495 m .36279 .54883 L .3588 .54703 L F
.406 .216 .507 r
.36279 .54883 m .36067 .55216 L .36095 .5495 L F
.766 .772 .858 r
.34376 .64901 m .34616 .65173 L .34808 .6498 L F
.18 .665 .927 r
.60199 .42772 m .59973 .42769 L .59783 .42678 L F
.51 .878 .979 r
.61524 .40933 m .61911 .40909 L .61803 .4088 L F
.679 .972 .913 r
.61803 .4088 m .61911 .40909 L .62049 .40704 L F
.665 .576 .745 r
.52501 .45898 m .52745 .45778 L .52644 .45408 L F
.959 .946 .694 r
.40402 .5566 m .40188 .55785 L .40173 .55492 L F
.40402 .5566 m .4025 .5592 L .40188 .55785 L F
.911 .669 .559 r
.37675 .54779 m .37988 .54614 L .37831 .54449 L F
.37675 .54779 m .37978 .54924 L .37988 .54614 L F
.783 .495 .499 r
.67822 .32345 m .67439 .3252 L .67545 .32366 L F
.882 .968 .841 r
.73063 .29056 m .73374 .28744 L .73198 .28755 L F
.108 0 0 r
.65538 .38074 m .65353 .38022 L .65253 .3816 L F
.65538 .38074 m .65654 .37936 L .65353 .38022 L F
.053 0 0 r
.64505 .33211 m .6489 .32993 L .64634 .33104 L F
.381 .439 .796 r
.60726 .44018 m .60559 .44318 L .60527 .44033 L F
.103 .376 .838 r
.60676 .44213 m .60559 .44318 L .60726 .44018 L F
.60676 .44213 m .60686 .44434 L .60559 .44318 L F
0 0 0 r
.38193 .60719 m .38643 .60505 L .38505 .60399 L F
.608 .76 .951 r
.34944 .52607 m .34445 .52429 L .34671 .52323 L F
.939 .571 .263 r
.34671 .52323 m .34855 .52642 L .34944 .52607 L F
.297 .369 .768 r
.34944 .52607 m .35157 .52921 L .35125 .52541 L F
0 0 0 r
.35125 .52541 m .34855 .52642 L .34944 .52607 L F
.509 .893 .721 r
.34855 .52642 m .34709 .52729 L .34944 .52607 L F
.932 .928 .779 r
.70445 .336 m .70444 .33312 L .70336 .3348 L F
.968 .935 .648 r
.702 .33894 m .70445 .336 L .70336 .3348 L F
.702 .33894 m .70267 .34023 L .70445 .336 L F
.556 .789 .986 r
.421 .54857 m .42197 .54968 L .42429 .54885 L F
.987 .882 .632 r
.58636 .43729 m .5873 .43516 L .58618 .43393 L F
.789 .857 .901 r
.60937 .37751 m .60571 .38104 L .60436 .37807 L F
.918 .931 .802 r
.31085 .5851 m .30705 .58889 L .3095 .58765 L F
.605 .213 .274 r
.31085 .5851 m .31234 .58729 L .3138 .58503 L F
.31085 .5851 m .3095 .58765 L .31234 .58729 L F
.191 0 0 r
.6075 .34472 m .61026 .34481 L .61164 .34431 L F
0 0 0 r
.61026 .34481 m .61388 .34426 L .61164 .34431 L F
.674 .434 .55 r
.2681 .62693 m .27185 .62751 L .27157 .62459 L F
.976 .674 .359 r
.27185 .62751 m .2725 .6282 L .27157 .62459 L F
.73 .941 .621 r
.27362 .62956 m .27561 .62781 L .273 .63112 L F
.613 .453 .641 r
.27561 .62781 m .27595 .63127 L .273 .63112 L F
.273 .584 .944 r
.27362 .62956 m .273 .63112 L .27494 .63053 L F
.283 .723 .964 r
.273 .63112 m .27595 .63127 L .27494 .63053 L F
0 0 .274 r
.49544 .53509 m .49409 .53662 L .49578 .53289 L F
0 0 0 r
.49471 .5372 m .49409 .53662 L .49544 .53509 L F
.49471 .5372 m .49293 .53858 L .49409 .53662 L F
.783 .988 .746 r
.70917 .29598 m .70797 .29854 L .70963 .29659 L F
0 0 0 r
.70917 .29598 m .70677 .30086 L .70797 .29854 L F
.43 .694 .975 r
.71724 .3264 m .71859 .32474 L .71617 .32486 L F
.71724 .3264 m .71978 .32649 L .71859 .32474 L F
.999 .818 .485 r
.5536 .46994 m .55202 .47144 L .55241 .47097 L F
.981 .864 .648 r
.55398 .46695 m .55417 .46945 L .5536 .46994 L F
0 0 .194 r
.55398 .46695 m .5536 .46994 L .55471 .46825 L F
.999 .818 .485 r
.5536 .46994 m .55241 .47097 L .55471 .46825 L F
.981 .864 .648 r
.55417 .46945 m .55429 .47107 L .5536 .46994 L F
.446 .877 .904 r
.5939 .34555 m .59675 .34418 L .59803 .34486 L F
.312 .796 .897 r
.59803 .34486 m .59957 .3439 L .60151 .34452 L F
.59803 .34486 m .59675 .34418 L .59957 .3439 L F
.816 .358 .139 r
.36931 .53425 m .37318 .53475 L .36933 .5317 L F
.36931 .53425 m .37225 .53531 L .37318 .53475 L F
.641 .924 .648 r
.55733 .47609 m .55604 .47789 L .55765 .47614 L F
.653 .971 .86 r
.55402 .47821 m .55604 .47789 L .55733 .47609 L F
.664 .842 .431 r
.70604 .30169 m .70473 .30413 L .70677 .30086 L F
0 0 0 r
.70917 .29598 m .70828 .29824 L .7081 .29817 L F
.759 .814 .338 r
.70911 .29498 m .70828 .29824 L .70917 .29598 L F
0 0 .01 r
.70911 .29498 m .70855 .29833 L .70828 .29824 L F
.70855 .29833 m .7083 .29983 L .70828 .29824 L F
0 0 0 r
.7081 .29817 m .70828 .29824 L .70677 .30086 L F
.644 .84 .438 r
.70828 .29824 m .70604 .30169 L .70677 .30086 L F
.789 .982 .902 r
.70844 .32831 m .71081 .32812 L .71287 .32618 L F
0 0 .025 r
.57848 .38988 m .57843 .38901 L .57872 .38735 L F
.57848 .38988 m .57848 .39141 L .57843 .38901 L F
.802 .949 .917 r
.60505 .40303 m .60713 .40129 L .60504 .40019 L F
0 0 .183 r
.60508 .40484 m .60505 .40303 L .60504 .40019 L F
.60508 .40484 m .60423 .40631 L .60505 .40303 L F
.964 .92 .711 r
.56795 .43351 m .56974 .43302 L .56809 .4326 L F
.114 0 0 r
.60853 .38729 m .61075 .38632 L .61023 .38701 L F
.732 .573 .676 r
.63528 .34349 m .63623 .34915 L .63184 .34623 L F
0 0 .485 r
.63632 .34394 m .63623 .34915 L .63528 .34349 L F
.377 .183 .487 r
.63411 .34754 m .63184 .34623 L .63424 .34782 L F
.63411 .34754 m .63424 .34782 L .63623 .34915 L F
.906 .862 .785 r
.63411 .34754 m .63623 .34915 L .63632 .34394 L F
0 0 .058 r
.63647 .34346 m .63498 .34604 L .63632 .34394 L F
.63498 .34604 m .63411 .34754 L .63632 .34394 L F
.492 .903 .888 r
.63765 .34214 m .63528 .34349 L .6371 .34261 L F
0 0 .485 r
.63632 .34394 m .63528 .34349 L .63737 .34229 L F
.613 .258 .344 r
.64149 .34096 m .64294 .34422 L .6371 .34261 L F
.517 .544 .822 r
.6371 .34261 m .64294 .34422 L .63953 .34042 L F
0 0 .485 r
.63632 .34394 m .63737 .34229 L .63765 .34214 L F
0 0 .058 r
.63421 .34737 m .63594 .34558 L .63411 .34754 L F
.63647 .34346 m .63594 .34558 L .63421 .34737 L F
0 0 0 r
.63851 .34218 m .63721 .34429 L .63594 .34558 L F
.47 .089 .234 r
.63721 .34429 m .63717 .3443 L .63594 .34558 L F
.152 0 .25 r
.63851 .34218 m .63594 .34558 L .63647 .34346 L F
.47 .089 .234 r
.63717 .3443 m .63494 .34508 L .63594 .34558 L F
.586 .923 .71 r
.63594 .34558 m .63393 .34713 L .63411 .34754 L F
.377 .183 .487 r
.63411 .34754 m .63208 .34893 L .63184 .34623 L F
.586 .923 .71 r
.63393 .34713 m .63258 .34818 L .63411 .34754 L F
.444 .863 .947 r
.63907 .34896 m .63574 .34907 L .63746 .34926 L F
.63907 .34896 m .63574 .34907 L .63746 .34926 L F
.284 .526 .909 r
.40287 .50424 m .40227 .50724 L .40129 .5046 L F
.629 .076 0 r
.40139 .50814 m .40227 .50724 L .40287 .50424 L F
.40139 .50814 m .40485 .50915 L .40227 .50724 L F
.837 .894 .88 r
.49767 .41271 m .49307 .4143 L .49628 .41156 L F
.842 .917 .884 r
.50009 .40991 m .49767 .41271 L .49628 .41156 L F
.972 .762 .561 r
.39117 .47666 m .39255 .48038 L .393 .47771 L F
.393 .47771 m .39255 .48038 L .39117 .47666 L F
.723 .635 .759 r
.48594 .45983 m .4875 .4584 L .48336 .45782 L F
.893 .647 .559 r
.57239 .38365 m .57595 .38293 L .57255 .38182 L F
.57239 .38365 m .57613 .38677 L .57595 .38293 L F
.833 .619 .613 r
.34487 .60396 m .341 .60595 L .34203 .60424 L F
.855 .776 .773 r
.32604 .52189 m .3305 .52011 L .32875 .52045 L F
.32604 .52189 m .32824 .52381 L .3305 .52011 L F
.657 .827 .965 r
.33183 .5169 m .3305 .52011 L .33321 .51869 L F
.826 1 .806 r
.33183 .5169 m .32875 .52045 L .3305 .52011 L F
.966 .817 .644 r
.38647 .56789 m .38824 .56897 L .38724 .5652 L F
.981 .78 .561 r
.38602 .57073 m .38824 .56897 L .38647 .56789 L F
.38602 .57073 m .3877 .5719 L .38824 .56897 L F
.572 .001 0 r
.34514 .54556 m .34113 .54299 L .3442 .54355 L F
.705 .921 .586 r
.51244 .43511 m .51504 .4318 L .51353 .43308 L F
.576 .388 .589 r
.51244 .43511 m .51518 .43478 L .51504 .4318 L F
.466 .868 .696 r
.51504 .4318 m .51856 .4296 L .51676 .43046 L F
.684 .321 .353 r
.51838 .43449 m .51504 .4318 L .51518 .43478 L F
0 0 0 r
.51353 .43308 m .51504 .4318 L .51676 .43046 L F
.99 .847 .606 r
.58356 .40572 m .5831 .40182 L .58235 .40447 L F
.973 .711 .476 r
.582 .40745 m .58356 .40572 L .58235 .40447 L F
.582 .40745 m .58363 .40839 L .58356 .40572 L F
.898 .568 .414 r
.68618 .32743 m .68446 .3289 L .68229 .32654 L F
.68618 .32743 m .68649 .32984 L .68446 .3289 L F
.782 .405 .342 r
.26162 .62871 m .25808 .62752 L .2602 .6278 L F
.633 .085 0 r
.25808 .62752 m .26162 .62871 L .2602 .6278 L F
.617 .831 .982 r
.26296 .6264 m .26512 .62728 L .26162 .62871 L F
0 .225 .645 r
.26162 .62871 m .26442 .63036 L .26273 .62924 L F
.968 .703 .479 r
.72859 .31829 m .7307 .31738 L .73053 .31594 L F
.72859 .31829 m .7307 .31999 L .7307 .31738 L F
.866 .795 .302 r
.7307 .31738 m .7311 .31347 L .73053 .31594 L F
.752 .832 .913 r
.48299 .42321 m .47841 .42389 L .48128 .42171 L F
.703 .871 .961 r
.48402 .42063 m .48299 .42321 L .48128 .42171 L F
.48402 .42063 m .48556 .42194 L .48299 .42321 L F
.896 .984 .717 r
.37778 .61712 m .37906 .61541 L .37694 .61682 L F
.857 .989 .721 r
.37694 .61682 m .37906 .61541 L .3794 .61338 L F
.716 .629 .759 r
.45884 .45964 m .46259 .46034 L .46345 .45836 L F
.078 0 0 r
.46096 .59551 m .45822 .59564 L .4624 .59489 L F
.498 .885 .708 r
.46265 .5942 m .4624 .59489 L .465 .59492 L F
.46265 .5942 m .46096 .59551 L .4624 .59489 L F
.842 .861 .858 r
.62603 .42536 m .62919 .42244 L .62735 .42073 L F
.457 .636 .933 r
.34323 .61984 m .34198 .62212 L .34106 .61968 L F
.394 .755 .993 r
.34658 .62234 m .34198 .62212 L .34521 .62252 L F
.457 .636 .933 r
.34323 .61984 m .34521 .62252 L .34198 .62212 L F
.642 .096 0 r
.58615 .3867 m .5856 .38702 L .5831 .38465 L F
.724 .221 0 r
.58615 .3867 m .5872 .38822 L .5856 .38702 L F
.482 .264 .506 r
.24404 .60045 m .24147 .60099 L .2432 .60424 L F
.673 .975 .83 r
.27228 .64233 m .26888 .64463 L .27196 .64192 L F
.378 0 0 r
.2725 .64278 m .27228 .64233 L .27196 .64192 L F
.2725 .64278 m .27413 .64329 L .27228 .64233 L F
0 0 .395 r
.44555 .47858 m .44604 .47934 L .44679 .48084 L F
.854 .949 .593 r
.44679 .48084 m .44535 .48228 L .44496 .48418 L F
.985 .895 .568 r
.44604 .47934 m .44535 .48228 L .44679 .48084 L F
.747 .772 .873 r
.44355 .58696 m .43951 .58736 L .44164 .58479 L F
.369 .837 .863 r
.44439 .58617 m .44355 .58696 L .44164 .58479 L F
.44439 .58617 m .44652 .58613 L .44355 .58696 L F
.009 .179 .692 r
.25081 .59515 m .25236 .59955 L .2529 .59734 L F
.552 .769 .978 r
.25236 .59955 m .25523 .59933 L .2529 .59734 L F
.796 .516 .512 r
.68217 .32411 m .67844 .32581 L .67822 .32345 L F
.68217 .32411 m .68229 .32654 L .67844 .32581 L F
.453 .76 .995 r
.71978 .32649 m .72377 .32753 L .72258 .32615 L F
.762 .903 .938 r
.72258 .32615 m .72377 .32753 L .72534 .32592 L F
.967 .727 .523 r
.38774 .57444 m .38935 .5783 L .38943 .57559 L F
.595 .115 .085 r
.33689 .53885 m .34207 .53769 L .34131 .53809 L F
.33859 .53897 m .34131 .53809 L .33952 .53904 L F
.799 .36 .204 r
.33461 .53965 m .33508 .54011 L .33861 .53871 L F
.33508 .54011 m .33528 .54004 L .33861 .53871 L F
.33508 .54011 m .33509 .54012 L .33528 .54004 L F
.509 .907 .794 r
.33861 .53871 m .33509 .54012 L .33689 .53885 L F
.33861 .53871 m .33689 .53885 L .33952 .53904 L F
.595 .115 .085 r
.33689 .53885 m .34131 .53809 L .33859 .53897 L F
.799 .36 .204 r
.33461 .53965 m .33509 .54029 L .33246 .54175 L F
.33509 .54029 m .33688 .54268 L .33246 .54175 L F
.621 .62 .828 r
.33246 .54175 m .33025 .5448 L .32977 .54346 L F
.33246 .54175 m .32977 .54346 L .32876 .54065 L F
.094 0 0 r
.33115 .54248 m .33389 .54084 L .33246 .54175 L F
.799 .36 .204 r
.33461 .53965 m .33246 .54175 L .33509 .54012 L F
.094 0 0 r
.33389 .54084 m .33509 .54012 L .33246 .54175 L F
.621 .62 .828 r
.33246 .54175 m .32876 .54065 L .33054 .54285 L F
.094 0 0 r
.33054 .54285 m .33115 .54248 L .33246 .54175 L F
.674 .787 .934 r
.31862 .65652 m .32264 .65679 L .32089 .65532 L F
.747 .876 .939 r
.32264 .65679 m .32376 .65362 L .32089 .65532 L F
.32264 .65679 m .32599 .65472 L .32376 .65362 L F
.967 .644 .305 r
.59611 .41544 m .59458 .41437 L .59451 .41208 L F
.529 0 0 r
.59611 .41544 m .59629 .41611 L .59458 .41437 L F
.59611 .41544 m .59993 .4183 L .59629 .41611 L F
.047 .225 .725 r
.57539 .3759 m .57621 .37397 L .57504 .37231 L F
.785 .284 0 r
.57909 .37945 m .57708 .3784 L .57539 .3759 L F
.998 .794 .498 r
.57708 .3784 m .57621 .37397 L .57539 .3759 L F
.826 .842 .86 r
.4558 .45772 m .45763 .45959 L .45931 .45766 L F
0 .234 .725 r
.41915 .52634 m .41819 .52643 L .41706 .52531 L F
.792 .892 .477 r
.41756 .52188 m .41629 .5251 L .41589 .52317 L F
.41629 .5251 m .41603 .52577 L .41599 .52502 L F
.41756 .52188 m .41618 .52444 L .41603 .52577 L F
0 .234 .725 r
.41789 .52554 m .41706 .52531 L .41618 .52444 L F
.41915 .52634 m .41706 .52531 L .41789 .52554 L F
.792 .892 .477 r
.41629 .5251 m .41599 .52502 L .41589 .52317 L F
.9 .836 .773 r
.58237 .35069 m .57971 .35422 L .57816 .35227 L F
.58237 .35069 m .57816 .35227 L .58089 .35138 L F
.132 0 0 r
.58237 .35069 m .58089 .35138 L .58565 .35069 L F
.077 .625 .835 r
.41628 .50561 m .41421 .50529 L .41624 .50574 L F
.41624 .50574 m .41421 .50529 L .41628 .50561 L F
.448 0 0 r
.37036 .50522 m .36575 .5028 L .36753 .50382 L F
.814 .54 .523 r
.32361 .54193 m .31928 .5431 L .32167 .54076 L F
.941 .64 .185 r
.72116 .31924 m .72226 .32086 L .72091 .31686 L F
.809 .5 .468 r
.72503 .32007 m .72091 .31686 L .72226 .32086 L F
.72503 .32007 m .72226 .32086 L .72116 .31924 L F
.27 .774 .765 r
.45606 .59629 m .45652 .59589 L .45514 .59578 L F
.45606 .59629 m .45822 .59564 L .45652 .59589 L F
.952 .834 .691 r
.38905 .58818 m .38767 .59115 L .38967 .59185 L F
.883 .497 .035 r
.38767 .59115 m .38961 .59397 L .38967 .59185 L F
.516 .916 .857 r
.43479 .44708 m .43371 .44825 L .4322 .4478 L F
.43479 .44708 m .43613 .44695 L .43371 .44825 L F
.917 .519 .197 r
.30514 .6283 m .30441 .62965 L .30542 .62749 L F
.30514 .6283 m .30624 .63074 L .30441 .62965 L F
.562 .409 .631 r
.30886 .62774 m .30624 .63074 L .30514 .6283 L F
.477 .353 .632 r
.27821 .63027 m .27561 .62781 L .27803 .62726 L F
.27821 .63027 m .27595 .63127 L .27561 .62781 L F
.808 .588 .605 r
.27362 .62956 m .27803 .62726 L .27561 .62781 L F
.997 .843 .507 r
.70053 .35009 m .70015 .34607 L .69955 .34866 L F
.992 .791 .411 r
.70026 .35225 m .70053 .35009 L .69955 .34866 L F
.712 .752 .884 r
.71624 .27687 m .71716 .27417 L .71516 .27683 L F
.71624 .27687 m .71939 .27506 L .71716 .27417 L F
.734 .3 0 r
.43336 .55736 m .43352 .55694 L .43322 .55509 L F
.43336 .55736 m .43461 .5591 L .43352 .55694 L F
.414 .602 .924 r
.23237 .60705 m .23511 .61031 L .23431 .60729 L F
.076 0 0 r
.65816 .39098 m .65896 .38936 L .66157 .38824 L F
.763 .65 .736 r
.29363 .58454 m .28961 .58503 L .28997 .58204 L F
.152 0 0 r
.29702 .58609 m .29436 .58673 L .29627 .58494 L F
.559 .61 .86 r
.29611 .58539 m .29436 .58673 L .29702 .58609 L F
.21 0 0 r
.29363 .58454 m .29223 .58546 L .28961 .58503 L F
.838 .46 .335 r
.29627 .58494 m .29192 .58567 L .29363 .58454 L F
.29627 .58494 m .29436 .58673 L .29192 .58567 L F
.559 .61 .86 r
.29274 .58277 m .29383 .58543 L .29611 .58539 L F
.29383 .58543 m .29436 .58673 L .29611 .58539 L F
.21 0 0 r
.29223 .58546 m .29192 .58567 L .29123 .58548 L F
.29223 .58546 m .29123 .58548 L .28961 .58503 L F
0 0 .412 r
.46175 .56124 m .46148 .56356 L .46224 .56295 L F
.46148 .56356 m .46137 .56445 L .46224 .56295 L F
.788 .459 0 r
.46175 .56124 m .46224 .56295 L .46165 .56145 L F
.46175 .56124 m .46165 .56145 L .46109 .56002 L F
.923 .975 .722 r
.46296 .558 m .46188 .56098 L .46175 .56124 L F
.46188 .56098 m .46103 .56329 L .46175 .56124 L F
.975 .912 .58 r
.46109 .56002 m .46296 .558 L .46175 .56124 L F
.19 .376 .818 r
.46224 .56295 m .46412 .56179 L .46109 .56002 L F
.402 .852 .778 r
.46105 .5629 m .46334 .56207 L .46224 .56295 L F
.46334 .56207 m .46412 .56179 L .46224 .56295 L F
.625 .379 .525 r
.3211 .57487 m .31769 .57225 L .32143 .57183 L F
.3211 .57487 m .3175 .5752 L .31769 .57225 L F
.508 .337 .585 r
.32377 .63097 m .32409 .63452 L .32129 .63472 L F
.782 .903 .927 r
.506 .40798 m .50277 .40865 L .5048 .40706 L F
.741 .903 .95 r
.50802 .40508 m .506 .40798 L .5048 .40706 L F
.50802 .40508 m .50959 .40625 L .506 .40798 L F
0 0 0 r
.55001 .47528 m .5531 .47257 L .55105 .47376 L F
.665 .579 .748 r
.28539 .55049 m .28268 .55218 L .28559 .55141 L F
.512 .182 .345 r
.28268 .55218 m .28473 .55446 L .28559 .55141 L F
.665 .579 .748 r
.28559 .55141 m .28268 .55218 L .28539 .55049 L F
.512 .182 .345 r
.28268 .55218 m .28473 .55446 L .28559 .55141 L F
.1 .64 .85 r
.4367 .4803 m .44087 .48082 L .43972 .48042 L F
.683 .968 .928 r
.43972 .48042 m .44087 .48082 L .44184 .47904 L F
.082 .234 .723 r
.44087 .48082 m .44322 .48277 L .44184 .47904 L F
.258 0 .238 r
.69301 .29512 m .69251 .29689 L .69554 .29378 L F
.931 .866 .752 r
.73352 .30485 m .73406 .30023 L .73226 .30342 L F
.981 .909 .647 r
.73178 .30605 m .73352 .30485 L .73226 .30342 L F
.73178 .30605 m .73238 .30772 L .73352 .30485 L F
.987 .733 .451 r
.44496 .48418 m .44325 .48552 L .44322 .48277 L F
.858 .963 .632 r
.44535 .48228 m .44325 .48552 L .44496 .48418 L F
.707 .887 .963 r
.47097 .43191 m .46682 .43198 L .46946 .43077 L F
.872 .914 .855 r
.47368 .42877 m .47097 .43191 L .46946 .43077 L F
.973 .845 .655 r
.38857 .5835 m .3911 .58197 L .38936 .58093 L F
.38857 .5835 m .39003 .58481 L .3911 .58197 L F
.852 .516 .417 r
.38441 .56439 m .38679 .56258 L .38434 .56156 L F
.38441 .56439 m .38724 .5652 L .38679 .56258 L F
.535 .877 .625 r
.3662 .49639 m .36169 .49997 L .36462 .49668 L F
.121 .64 .887 r
.36735 .49596 m .3662 .49639 L .36462 .49668 L F
.36735 .49596 m .36866 .49658 L .3662 .49639 L F
.742 .263 0 r
.60119 .44758 m .60205 .44961 L .59952 .44769 L F
.60119 .44758 m .60357 .45089 L .60205 .44961 L F
0 .526 .834 r
.64734 .34145 m .6438 .34043 L .64498 .34 L F
.423 0 0 r
.64644 .34086 m .64517 .34026 L .6438 .34043 L F
.415 .168 .428 r
.6438 .34043 m .64313 .34051 L .64498 .34 L F
.423 0 0 r
.64517 .34026 m .64387 .33964 L .6438 .34043 L F
.415 .168 .428 r
.6438 .34043 m .64149 .34096 L .64313 .34051 L F
.588 .228 .325 r
.64822 .34046 m .64734 .34145 L .64498 .34 L F
.639 .574 .766 r
.54838 .42872 m .55196 .42512 L .54879 .42725 L F
.54838 .42872 m .55093 .42884 L .55196 .42512 L F
.559 .141 .204 r
.55099 .43024 m .55093 .42884 L .54838 .42872 L F
.479 .753 .99 r
.54838 .42872 m .55093 .42884 L .55099 .43024 L F
.492 .148 .31 r
.51484 .43687 m .51518 .43478 L .51244 .43511 L F
.081 .22 .709 r
.51484 .43687 m .51244 .43511 L .51353 .43308 L F
0 0 .282 r
.51071 .42265 m .50959 .42204 L .51149 .42106 L F
.51071 .42265 m .50965 .42461 L .50959 .42204 L F
.163 .695 .852 r
.46909 .59504 m .46787 .59476 L .465 .59492 L F
.603 .953 .877 r
.47083 .5939 m .47023 .59352 L .46909 .59504 L F
.582 .937 .93 r
.47023 .59352 m .46787 .59476 L .46909 .59504 L F
.845 .89 .871 r
.51132 .46627 m .5157 .46459 L .51461 .46379 L F
.848 .975 .872 r
.51461 .46379 m .5157 .46459 L .51856 .46157 L F
.883 .935 .848 r
.42732 .49565 m .43035 .49539 L .42878 .49417 L F
.42732 .49565 m .42862 .49706 L .43035 .49539 L F
.57 .331 .514 r
.43035 .49539 m .43063 .49723 L .42862 .49706 L F
.958 .616 .29 r
.43035 .49539 m .42899 .49607 L .42878 .49417 L F
.43035 .49539 m .43063 .49723 L .42899 .49607 L F
.083 .372 .837 r
.22911 .57494 m .23148 .57808 L .23183 .57677 L F
0 0 .503 r
.23148 .57808 m .23293 .58089 L .23183 .57677 L F
.675 .505 .648 r
.33564 .62141 m .33566 .62427 L .33194 .62499 L F
.677 .947 .685 r
.33564 .62141 m .33194 .62499 L .33566 .62427 L F
.636 .474 .646 r
.33839 .62085 m .33566 .62427 L .33564 .62141 L F
.33839 .62085 m .33566 .62427 L .33564 .62141 L F
.168 0 0 r
.54381 .41084 m .53976 .41252 L .54177 .41273 L F
.872 .768 .745 r
.30706 .64118 m .30838 .6413 L .30759 .63739 L F
.291 .771 .923 r
.30603 .64124 m .30838 .6413 L .30706 .64118 L F
.501 .87 .982 r
.30838 .6413 m .31063 .63973 L .30759 .63739 L F
.30838 .6413 m .31214 .64054 L .31063 .63973 L F
.636 .463 .631 r
.30927 .64406 m .31214 .64054 L .30838 .6413 L F
.69 .391 .463 r
.34721 .58206 m .34648 .58528 L .34297 .58408 L F
.452 0 0 r
.34583 .58509 m .34962 .58735 L .35112 .58801 L F
.659 .391 .503 r
.34961 .58601 m .34962 .58735 L .34583 .58509 L F
.34961 .58601 m .34583 .58509 L .34648 .58528 L F
.661 .362 .456 r
.34721 .58206 m .34961 .58601 L .34648 .58528 L F
.748 .984 .755 r
.56539 .44414 m .56204 .4475 L .56504 .4442 L F
.541 .333 .546 r
.56539 .44414 m .56212 .45011 L .56204 .4475 L F
.56539 .44414 m .56531 .44565 L .56212 .45011 L F
.56531 .44565 m .56509 .44977 L .56308 .45 L F
.56531 .44565 m .56308 .45 L .56212 .45011 L F
.874 .744 .716 r
.56747 .44081 m .5676 .44117 L .56504 .4442 L F
.5676 .44117 m .56876 .44422 L .56605 .4442 L F
.5676 .44117 m .56605 .4442 L .56504 .4442 L F
.321 .154 .492 r
.56749 .44845 m .56539 .44414 L .56875 .44677 L F
.56596 .4453 m .56509 .44977 L .56539 .44414 L F
.56749 .44845 m .56646 .44901 L .56596 .4453 L F
.56646 .44901 m .56509 .44977 L .56596 .4453 L F
.838 .516 .444 r
.56504 .4442 m .56875 .44677 L .56539 .44414 L F
.56589 .44478 m .56876 .44422 L .56875 .44677 L F
.56504 .4442 m .56581 .4442 L .56589 .44478 L F
.56581 .4442 m .56876 .44422 L .56589 .44478 L F
.598 .606 .831 r
.57026 .44032 m .56876 .44422 L .56747 .44081 L F
.57026 .44032 m .57137 .44323 L .56876 .44422 L F
.786 .617 .671 r
.56876 .44422 m .57142 .44727 L .56875 .44677 L F
.883 .497 .035 r
.38767 .59115 m .38855 .59361 L .38961 .59397 L F
.908 .962 .81 r
.38855 .59361 m .38731 .59803 L .38961 .59397 L F
.722 .804 .332 r
.42333 .56256 m .42267 .5638 L .4221 .56577 L F
.074 .102 .586 r
.42267 .5638 m .42136 .56838 L .4221 .56577 L F
.603 .27 .378 r
.27581 .51517 m .27363 .51876 L .27126 .51651 L F
.465 .514 .824 r
.27635 .51246 m .27581 .51517 L .27395 .51378 L F
.27635 .51246 m .27795 .51638 L .27581 .51517 L F
.262 0 .169 r
.27596 .51789 m .27581 .51517 L .27795 .51638 L F
.27596 .51789 m .27363 .51876 L .27581 .51517 L F
.679 .974 .798 r
.69404 .36832 m .69256 .37035 L .6945 .36862 L F
.659 .954 .947 r
.69069 .36994 m .69256 .37035 L .69404 .36832 L F
.686 .785 .925 r
.25291 .55471 m .24913 .55502 L .25183 .55349 L F
.352 0 .18 r
.25291 .55471 m .25133 .55773 L .24882 .55826 L F
0 .385 .84 r
.25183 .55349 m .25384 .55434 L .25291 .55471 L F
0 0 0 r
.25384 .55434 m .25133 .55773 L .25291 .55471 L F
.913 .979 .77 r
.3724 .62439 m .37522 .6207 L .37419 .61999 L F
.892 .986 .8 r
.37419 .61999 m .37522 .6207 L .37778 .61712 L F
.747 .986 .765 r
.40611 .48628 m .40577 .48555 L .40488 .48748 L F
.657 .966 .793 r
.46394 .43397 m .46164 .4358 L .45995 .43634 L F
.952 .675 .226 r
.4214 .57146 m .4215 .56873 L .42136 .56838 L F
.737 .763 .258 r
.42754 .57363 m .42719 .57534 L .4264 .5775 L F
.168 .274 .73 r
.26928 .63499 m .26948 .63084 L .26873 .63352 L F
.588 .428 .632 r
.26928 .63499 m .27079 .63745 L .26904 .63802 L F
.63 .21 0 r
.26928 .63499 m .27079 .63745 L .26901 .63462 L F
.187 .672 .927 r
.26616 .6343 m .26928 .63499 L .26873 .63352 L F
.902 .764 .271 r
.26928 .63499 m .26904 .63802 L .26901 .63462 L F
0 0 .503 r
.26873 .63352 m .27079 .63745 L .26928 .63499 L F
.944 .597 .328 r
.43319 .56749 m .43459 .5659 L .43317 .56447 L F
.43319 .56749 m .43499 .56836 L .43459 .5659 L F
.584 .849 .501 r
.24057 .5576 m .23958 .55875 L .24226 .55558 L F
.249 0 .193 r
.24057 .5576 m .23771 .56123 L .23958 .55875 L F
.24057 .5576 m .24103 .56024 L .23771 .56123 L F
.707 .629 .767 r
.24341 .55677 m .24103 .56024 L .24057 .5576 L F
.357 .082 .351 r
.51109 .49315 m .50841 .49387 L .50786 .4963 L F
.919 .953 .797 r
.35736 .64147 m .36013 .6409 L .359 .64044 L F
.35736 .64147 m .35774 .64439 L .36013 .6409 L F
.864 .989 .833 r
.36013 .6409 m .35992 .63878 L .359 .64044 L F
.36013 .6409 m .36287 .63777 L .35992 .63878 L F
0 0 .167 r
.4923 .51351 m .49344 .51445 L .49359 .51207 L F
.4923 .51351 m .49173 .51597 L .49344 .51445 L F
.712 .611 .742 r
.51285 .44355 m .51734 .44366 L .51527 .43958 L F
.926 .917 .788 r
.51752 .44326 m .51785 .4422 L .5175 .4432 L F
.437 .826 .986 r
.51527 .43958 m .51901 .43976 L .51877 .43904 L F
.896 .928 .545 r
.51746 .44295 m .51901 .43976 L .51877 .43904 L F
0 .112 .665 r
.51527 .43958 m .51746 .44313 L .51722 .44159 L F
.51746 .44313 m .5175 .4432 L .51746 .44297 L F
.51746 .44313 m .51746 .44297 L .51722 .44159 L F
.896 .928 .545 r
.51746 .44295 m .51877 .43904 L .51746 .44185 L F
.926 .917 .788 r
.51746 .44333 m .51785 .4422 L .51741 .44312 L F
0 .112 .665 r
.5175 .4432 m .5178 .44367 L .51722 .44159 L F
.896 .928 .545 r
.51741 .44312 m .51746 .44295 L .51746 .44185 L F
.51741 .44312 m .51747 .44299 L .51746 .44295 L F
.51747 .44299 m .51901 .43976 L .51746 .44295 L F
0 .112 .665 r
.51737 .44175 m .5178 .44367 L .51746 .44185 L F
.51722 .44159 m .51741 .44229 L .51737 .44175 L F
.51741 .44229 m .5178 .44367 L .51737 .44175 L F
.926 .917 .788 r
.51747 .44339 m .51752 .44326 L .51746 .44333 L F
.51752 .44326 m .5175 .4432 L .51746 .44333 L F
.51784 .44479 m .51785 .44261 L .51747 .44339 L F
.51785 .44261 m .51785 .4422 L .51747 .44339 L F
.71 .503 .607 r
.51645 .44621 m .5178 .44367 L .51734 .44366 L F
.51621 .44603 m .51734 .44366 L .51285 .44355 L F
.51645 .44621 m .51734 .44366 L .51621 .44603 L F
.926 .917 .788 r
.51784 .44479 m .51901 .43976 L .51785 .4422 L F
.05 .604 .822 r
.51994 .44469 m .51925 .44472 L .51741 .44312 L F
.51925 .44472 m .51784 .44479 L .51746 .44333 L F
.712 .611 .742 r
.51746 .44333 m .5177 .44352 L .5175 .4432 L F
.05 .604 .822 r
.51925 .44472 m .51746 .44333 L .51741 .44312 L F
.712 .611 .742 r
.51734 .44366 m .5178 .44367 L .5177 .44352 L F
.51734 .44366 m .5177 .44352 L .51746 .44333 L F
.51734 .44366 m .5175 .4432 L .51527 .43958 L F
.05 .604 .822 r
.51994 .44469 m .52023 .44493 L .51784 .44479 L F
.364 .709 .986 r
.33696 .65218 m .33879 .65335 L .34123 .65317 L F
.68 .761 .912 r
.57906 .41498 m .58366 .41569 L .58155 .41398 L F
.632 .132 .044 r
.57906 .41498 m .58175 .41688 L .58366 .41569 L F
.932 .966 .683 r
.58366 .41569 m .58175 .41688 L .58229 .41787 L F
.58366 .41569 m .58175 .41688 L .58229 .41787 L F
.987 .727 .436 r
.42766 .46761 m .42626 .4637 L .42945 .46388 L F
.42766 .46761 m .42945 .46388 L .42776 .46528 L F
.42753 .46727 m .42726 .46727 L .42626 .4637 L F
.752 .575 .656 r
.42726 .46727 m .42297 .46651 L .42626 .4637 L F
.42726 .46727 m .42455 .46856 L .42297 .46651 L F
.596 .074 0 r
.42726 .46727 m .42297 .46651 L .42455 .46856 L F
.42726 .46727 m .42502 .46793 L .42297 .46651 L F
.798 .997 .855 r
.42776 .46528 m .42571 .46726 L .42726 .46727 L F
.42571 .46726 m .42502 .46793 L .42726 .46727 L F
.987 .727 .436 r
.42766 .46761 m .42726 .46727 L .42753 .46727 L F
.798 .997 .855 r
.42776 .46528 m .42726 .46727 L .42766 .46761 L F
.246 0 0 r
.28053 .58896 m .27864 .59116 L .27679 .59157 L F
.622 .219 .259 r
.28264 .59089 m .27864 .59116 L .28053 .58896 L F
.526 .246 .433 r
.28384 .58837 m .28264 .59089 L .28053 .58896 L F
.925 .965 .774 r
.5725 .46271 m .57213 .46156 L .56893 .46397 L F
.815 .693 .73 r
.56893 .46397 m .57032 .46754 L .5725 .46271 L F
.224 0 0 r
.26199 .52313 m .25806 .52466 L .25947 .52331 L F
.194 .699 .905 r
.33597 .49676 m .3353 .49759 L .33356 .49722 L F
.33597 .49676 m .3376 .49751 L .3353 .49759 L F
.392 .034 .232 r
.52166 .43117 m .51838 .43449 L .52054 .43337 L F
.251 0 0 r
.52288 .43243 m .52166 .43117 L .52054 .43337 L F
.52288 .43243 m .52408 .43063 L .52166 .43117 L F
0 0 0 r
.53118 .49581 m .52939 .49719 L .53148 .49589 L F
.53118 .49581 m .52789 .49857 L .52939 .49719 L F
.888 .81 .767 r
.53087 .46046 m .53022 .46247 L .52901 .46438 L F
0 0 0 r
.47639 .58488 m .47572 .58698 L .47493 .58861 L F
.47493 .58861 m .47484 .58912 L .47455 .5914 L F
.47493 .58861 m .47572 .58698 L .47484 .58912 L F
.408 .752 .994 r
.70039 .28809 m .70117 .28864 L .69804 .28799 L F
.568 .871 .995 r
.70039 .28809 m .70448 .28765 L .70117 .28864 L F
.692 .199 .072 r
.60354 .41719 m .60593 .4181 L .60625 .41705 L F
.217 .535 .924 r
.45631 .56975 m .45514 .56802 L .45517 .57079 L F
.69 .979 .893 r
.458 .56753 m .45849 .56823 L .45631 .56975 L F
.612 .877 .545 r
.458 .56753 m .45631 .56975 L .45517 .57079 L F
.811 .576 .582 r
.32983 .58183 m .32537 .58398 L .32718 .58193 L F
.236 .753 .776 r
.44849 .45398 m .45117 .45333 L .44759 .45408 L F
.774 .583 .64 r
.54097 .47698 m .54522 .47443 L .54141 .47404 L F
.54097 .47698 m .54512 .4773 L .54522 .47443 L F
.197 .727 .787 r
.42426 .59949 m .42881 .59893 L .42735 .59798 L F
0 0 .212 r
.60103 .43497 m .60227 .43028 L .60263 .43379 L F
.124 .123 .585 r
.60344 .43759 m .60103 .43497 L .60263 .43379 L F
.864 .996 .789 r
.40354 .45562 m .40171 .45792 L .40149 .45676 L F
.534 0 0 r
.40171 .45792 m .4013 .45851 L .40149 .45676 L F
.40171 .45792 m .40393 .45942 L .4013 .45851 L F
.624 .476 .66 r
.40354 .45562 m .40436 .45803 L .40171 .45792 L F
.535 .115 .19 r
.40436 .45803 m .40393 .45942 L .40171 .45792 L F
.263 .736 .941 r
.42611 .58806 m .42927 .58793 L .43024 .58855 L F
.42611 .58806 m .42927 .58793 L .43024 .58855 L F
.747 .952 .642 r
.69382 .28459 m .69505 .28203 L .69653 .28113 L F
.646 .513 .686 r
.69653 .28113 m .69603 .28538 L .69382 .28459 L F
.015 0 .279 r
.69382 .28459 m .69593 .28441 L .69505 .28203 L F
.69382 .28459 m .69363 .28708 L .69593 .28441 L F
.362 0 0 r
.62072 .36742 m .61994 .36685 L .61856 .36749 L F
0 .369 .825 r
.61994 .36685 m .62307 .3684 L .62373 .36961 L F
.362 0 0 r
.62072 .36742 m .62307 .3684 L .61994 .36685 L F
0 .1 .654 r
.60896 .44664 m .60686 .44434 L .60676 .44213 L F
.158 0 .242 r
.52901 .46438 m .52597 .46815 L .52827 .46657 L F
.495 .888 .726 r
.52827 .46657 m .52597 .46815 L .52538 .46813 L F
.646 .779 .944 r
.5169 .42541 m .51369 .4266 L .51209 .42426 L F
0 .431 .835 r
.23427 .57047 m .2372 .57198 L .23624 .57196 L F
.197 0 0 r
.52767 .48495 m .52927 .48376 L .52649 .48404 L F
.52767 .48495 m .52649 .48404 L .52619 .48369 L F
.718 .781 .902 r
.40722 .48431 m .40611 .48628 L .41002 .48362 L F
.538 .559 .824 r
.41384 .51365 m .41106 .51491 L .40966 .51189 L F
.873 .938 .859 r
.35363 .64551 m .35774 .64439 L .35736 .64147 L F
.346 .001 .229 r
.52787 .4146 m .53109 .41217 L .52794 .41327 L F
.924 .73 .622 r
.59478 .40886 m .59179 .41045 L .5933 .40741 L F
.59478 .40886 m .59451 .41208 L .59179 .41045 L F
.769 .698 .784 r
.33266 .50312 m .33413 .50689 L .32994 .50635 L F
.394 0 0 r
.33413 .50689 m .3322 .50698 L .32994 .50635 L F
.821 .725 .759 r
.35399 .62169 m .35839 .61793 L .35652 .61669 L F
.35399 .62169 m .35597 .62217 L .35839 .61793 L F
.513 .907 .928 r
.35597 .62217 m .3586 .62116 L .35839 .61793 L F
0 .034 .523 r
.33413 .50689 m .33654 .50912 L .33526 .50792 L F
.491 .782 .997 r
.35652 .61669 m .35839 .61793 L .3601 .61633 L F
.142 .078 .519 r
.35839 .61793 m .35997 .61987 L .3601 .61633 L F
.35839 .61793 m .3586 .62116 L .35997 .61987 L F
.25 .763 .825 r
.32431 .51798 m .32965 .51732 L .32683 .51838 L F
.002 0 .056 r
.55648 .41871 m .55371 .42194 L .55634 .42105 L F
0 0 .437 r
.55648 .41871 m .55783 .41321 L .55899 .41532 L F
.343 .648 .967 r
.55648 .41871 m .55892 .41825 L .55802 .41758 L F
.78 .764 .839 r
.55837 .41634 m .55892 .41825 L .56211 .41666 L F
0 0 .437 r
.55648 .41871 m .55802 .41758 L .55813 .41578 L F
.55802 .41758 m .55824 .4168 L .55813 .41578 L F
.55648 .41871 m .55813 .41578 L .55753 .41443 L F
.78 .764 .839 r
.55608 .41613 m .55802 .41758 L .55824 .4168 L F
.55608 .41613 m .55824 .4168 L .55789 .41629 L F
0 0 .437 r
.55753 .41443 m .55813 .41578 L .55783 .41321 L F
.972 .659 .336 r
.55783 .41321 m .55824 .4168 L .55669 .41458 L F
.78 .764 .839 r
.55789 .41629 m .55824 .4168 L .55837 .41634 L F
.55772 .41667 m .55837 .41634 L .55865 .41697 L F
.55608 .41613 m .55789 .41629 L .55772 .41667 L F
.55789 .41629 m .55837 .41634 L .55772 .41667 L F
.508 .689 .95 r
.55608 .41613 m .55772 .41667 L .55637 .41496 L F
.972 .659 .336 r
.55669 .41458 m .55771 .41666 L .55637 .41496 L F
.78 .764 .839 r
.55802 .41758 m .55892 .41825 L .55837 .41634 L F
0 0 .437 r
.55802 .41758 m .55831 .41738 L .55824 .4168 L F
.55648 .41871 m .55838 .41802 L .55831 .41738 L F
.972 .659 .336 r
.55824 .4168 m .55838 .41802 L .55669 .41458 L F
.78 .764 .839 r
.55865 .41697 m .56211 .41666 L .55954 .41726 L F
.55837 .41634 m .56211 .41666 L .55865 .41697 L F
.508 .689 .95 r
.55772 .41667 m .55954 .41726 L .55637 .41496 L F
.972 .659 .336 r
.55771 .41666 m .55772 .41667 L .55637 .41496 L F
.55772 .41667 m .55838 .41802 L .55762 .41687 L F
.55772 .41667 m .55762 .41687 L .55637 .41496 L F
.343 .648 .967 r
.55648 .41871 m .55802 .41758 L .55608 .41613 L F
.55648 .41871 m .55608 .41613 L .55838 .41802 L F
.72 .799 .913 r
.55634 .42105 m .55892 .41825 L .55648 .41871 L F
.822 .935 .904 r
.56708 .47015 m .56949 .46617 L .56595 .46918 L F
.56708 .47015 m .57032 .46754 L .56949 .46617 L F
.992 .829 .58 r
.45316 .50059 m .45285 .49584 L .45348 .49637 L F
.45327 .50024 m .45348 .49637 L .45423 .497 L F
.45316 .50059 m .45348 .49637 L .45327 .50024 L F
.45316 .50059 m .45423 .497 L .45335 .49951 L F
.764 .626 .707 r
.45335 .49951 m .4548 .50314 L .45319 .50176 L F
.4532 .50145 m .45319 .50176 L .45318 .50176 L F
.45335 .49951 m .45319 .50176 L .4532 .50145 L F
.495 .316 .567 r
.45423 .497 m .45572 .49992 L .45335 .49951 L F
.45423 .497 m .45697 .49639 L .45572 .49992 L F
0 0 0 r
.26855 .5168 m .27014 .51618 L .27126 .51651 L F
.26855 .5168 m .26719 .51747 L .27014 .51618 L F
.652 .957 .755 r
.6213 .37081 m .62373 .36961 L .62307 .3684 L F
0 0 0 r
.45678 .5798 m .45559 .58009 L .45422 .57714 L F
0 .22 .716 r
.57909 .37945 m .58063 .37988 L .57708 .3784 L F
.534 .892 .976 r
.44322 .46116 m .44193 .46059 L .43936 .46161 L F
.712 .929 .602 r
.44584 .45784 m .44421 .45923 L .44322 .46116 L F
.655 .94 .964 r
.44322 .46116 m .44421 .45923 L .44193 .46059 L F
.883 .893 .834 r
.73034 .31071 m .72774 .31421 L .72637 .31274 L F
.926 .706 .585 r
.30027 .53381 m .30305 .53308 L .3006 .53184 L F
.30027 .53381 m .30227 .53588 L .30305 .53308 L F
.30027 .53381 m .30305 .53308 L .3006 .53184 L F
.30027 .53381 m .30227 .53588 L .30305 .53308 L F
.203 0 .096 r
.66887 .32653 m .66549 .32853 L .66598 .32734 L F
.902 .975 .681 r
.36317 .6351 m .36287 .63777 L .36503 .63405 L F
.659 .92 .619 r
.36503 .63405 m .3679 .63091 L .36595 .63248 L F
.662 .947 .699 r
.36317 .6351 m .36503 .63405 L .36595 .63248 L F
.98 .843 .636 r
.67919 .34283 m .68067 .34392 L .67985 .34642 L F
.68 .169 0 r
.68133 .34481 m .68067 .34392 L .67919 .34283 L F
.195 .72 .717 r
.25794 .52122 m .25991 .52072 L .26216 .52024 L F
.415 .862 .811 r
.26216 .52024 m .26288 .51944 L .26461 .51944 L F
.26216 .52024 m .25991 .52072 L .26288 .51944 L F
.562 .41 .632 r
.26461 .51944 m .26199 .52313 L .26216 .52024 L F
0 0 0 r
.3357 .5754 m .33225 .57863 L .33549 .57843 L F
.898 .924 .538 r
.33684 .57193 m .3357 .5754 L .33789 .5748 L F
.054 0 .343 r
.3357 .5754 m .33746 .57619 L .33789 .5748 L F
.3357 .5754 m .33549 .57843 L .33746 .57619 L F
.716 .629 .759 r
.45884 .45964 m .46345 .45836 L .45931 .45766 L F
0 0 0 r
.34106 .61968 m .34534 .61751 L .34323 .61984 L F
.789 .526 .541 r
.34806 .61798 m .34323 .61984 L .34534 .61751 L F
.432 .327 .634 r
.26888 .64463 m .27142 .64666 L .27196 .64192 L F
.768 .679 .764 r
.71361 .26778 m .71547 .27112 L .71097 .27112 L F
.909 .596 .442 r
.71547 .27112 m .71364 .27278 L .71097 .27112 L F
.71547 .27112 m .71547 .27441 L .71364 .27278 L F
.806 .406 0 r
.71469 .2704 m .71547 .27112 L .71361 .26778 L F
.837 .471 .362 r
.71364 .27278 m .71547 .27112 L .71469 .2704 L F
.71364 .27278 m .71716 .27417 L .71547 .27112 L F
.578 .942 .835 r
.55093 .42884 m .55567 .42628 L .55516 .42738 L F
.665 .321 .38 r
.55567 .42628 m .55757 .42746 L .55516 .42738 L F
.523 .426 .686 r
.55708 .42181 m .55757 .42746 L .55567 .42628 L F
.455 0 .062 r
.68604 .2998 m .68874 .29969 L .69002 .29803 L F
.356 0 .005 r
.69002 .29803 m .69206 .29877 L .69251 .29689 L F
.69002 .29803 m .68874 .29969 L .69206 .29877 L F
.951 .666 .462 r
.58303 .39908 m .58119 .39546 L .58216 .399 L F
.952 .67 .465 r
.58137 .4007 m .58303 .39908 L .58216 .399 L F
.58137 .4007 m .5831 .40182 L .58303 .39908 L F
.797 .999 .818 r
.62076 .34715 m .61952 .34985 L .62253 .34807 L F
.62076 .34715 m .61905 .34927 L .61952 .34985 L F
.818 .637 .085 r
.69938 .3624 m .69934 .35985 L .69912 .36107 L F
0 0 .228 r
.69951 .35857 m .69934 .35985 L .69914 .35588 L F
.714 .67 .121 r
.69912 .36107 m .69934 .35985 L .69951 .35857 L F
.723 .761 .882 r
.54167 .40223 m .54291 .40508 L .54023 .40598 L F
.658 .861 .977 r
.44724 .58042 m .45037 .58193 L .45096 .58089 L F
.571 .061 .004 r
.70473 .30413 m .7076 .3057 L .70899 .30454 L F
.993 .755 .465 r
.7076 .3057 m .70899 .30726 L .70899 .30454 L F
.864 .521 .401 r
.34622 .50492 m .34848 .50354 L .34649 .50263 L F
.34622 .50492 m .34978 .50657 L .34848 .50354 L F
.423 .275 .575 r
.32608 .63319 m .32409 .63452 L .32377 .63097 L F
.422 .797 .993 r
.23869 .58494 m .23936 .58371 L .24195 .58436 L F
.03 0 .27 r
.23739 .58664 m .23936 .58371 L .23869 .58494 L F
.866 .654 .614 r
.3978 .54006 m .39394 .54151 L .39516 .53546 L F
.327 .762 .969 r
.39851 .54207 m .39394 .54151 L .3978 .54006 L F
.916 .777 .693 r
.68612 .33247 m .68803 .3339 L .68688 .33627 L F
.427 .011 .144 r
.66549 .32853 m .66481 .33116 L .66244 .3314 L F
.203 0 .096 r
.66887 .32653 m .6681 .32882 L .66549 .32853 L F
.203 0 .082 r
.6681 .32882 m .66481 .33116 L .66549 .32853 L F
.45 .872 .934 r
.42691 .44995 m .42282 .45042 L .4254 .44984 L F
.372 .837 .882 r
.42792 .44904 m .42691 .44995 L .4254 .44984 L F
.42792 .44904 m .42922 .44918 L .42691 .44995 L F
.872 .914 .855 r
.47368 .42877 m .46946 .43077 L .47224 .42806 L F
.757 .993 .806 r
.47669 .42588 m .47368 .42877 L .47468 .42666 L F
.679 .936 .966 r
.47468 .42666 m .47368 .42877 L .47224 .42806 L F
.453 .883 .819 r
.61621 .3437 m .62061 .34219 L .61811 .34324 L F
.91 .837 .761 r
.72679 .28452 m .7266 .28881 L .72534 .28714 L F
.98 .894 .663 r
.7266 .28881 m .72475 .28999 L .72534 .28714 L F
0 0 0 r
.53148 .49589 m .53271 .49452 L .53441 .49265 L F
.919 .643 .501 r
.24913 .55502 m .24882 .55826 L .24523 .55529 L F
.784 .969 .918 r
.24913 .55502 m .24953 .55221 L .25183 .55349 L F
.24913 .55502 m .24523 .55529 L .24953 .55221 L F
.034 0 0 r
.43534 .59739 m .43445 .59812 L .43164 .59884 L F
.369 .82 .94 r
.43821 .59807 m .43445 .59812 L .43534 .59739 L F
.697 .628 .776 r
.45931 .45766 m .46345 .45836 L .46196 .45434 L F
.745 .653 .758 r
.46196 .45434 m .46345 .45836 L .46606 .45494 L F
.409 .839 .69 r
.24626 .62674 m .24764 .62612 L .24478 .62769 L F
.556 .309 .497 r
.24478 .62769 m .24764 .62612 L .24723 .62789 L F
.377 .687 .98 r
.24478 .62769 m .24723 .62789 L .24626 .62674 L F
.75 .539 .61 r
.35174 .53284 m .35157 .52921 L .35284 .52929 L F
.625 .446 .621 r
.35614 .5266 m .35589 .52911 L .35284 .52929 L F
.106 0 .309 r
.35404 .53103 m .35284 .52929 L .35589 .52911 L F
.35311 .52967 m .35209 .53204 L .35284 .52929 L F
.35209 .53204 m .35174 .53284 L .35197 .5321 L F
.35209 .53204 m .35197 .5321 L .35284 .52929 L F
.241 .182 .587 r
.35256 .5318 m .3527 .53218 L .35404 .53103 L F
.628 .385 .531 r
.35256 .5318 m .35245 .53222 L .3527 .53218 L F
.77 .992 .884 r
.3527 .53218 m .3527 .53206 L .35404 .53103 L F
.106 0 .309 r
.35404 .53103 m .35252 .5322 L .35311 .52967 L F
.35251 .53224 m .35245 .53222 L .35311 .52967 L F
.35243 .5323 m .35174 .53284 L .35182 .53265 L F
.35243 .53229 m .35182 .53265 L .35311 .52967 L F
.35243 .5323 m .35182 .53265 L .35243 .53229 L F
.75 .539 .61 r
.35174 .53284 m .34933 .53276 L .35157 .52921 L F
.398 .827 .669 r
.34705 .53419 m .34736 .53385 L .34933 .53276 L F
.481 .899 .853 r
.34736 .53385 m .35251 .53224 L .34933 .53276 L F
.34736 .53385 m .34842 .53299 L .35257 .5322 L F
.35251 .53224 m .3527 .53218 L .35245 .53222 L F
.614 .59 .803 r
.35378 .53225 m .35317 .53509 L .35251 .53224 L F
.481 .899 .853 r
.35251 .53224 m .35251 .53224 L .35251 .53224 L F
.35251 .53224 m .3527 .53218 L .35251 .53224 L F
.614 .59 .803 r
.35251 .53224 m .35317 .53509 L .35174 .53284 L F
.35396 .53142 m .35251 .53224 L .35251 .53224 L F
.481 .899 .853 r
.35251 .53224 m .35257 .5322 L .35257 .5322 L F
.35251 .53224 m .35257 .5322 L .3527 .53218 L F
.35251 .53224 m .35257 .5322 L .35251 .53224 L F
.614 .59 .803 r
.35404 .53103 m .35396 .53142 L .35251 .53224 L F
.35396 .53142 m .35378 .53225 L .35251 .53224 L F
.481 .899 .853 r
.34736 .53385 m .35257 .5322 L .35251 .53224 L F
.241 .182 .587 r
.35157 .52921 m .35256 .5318 L .35404 .53103 L F
.77 .992 .884 r
.3527 .53206 m .35271 .53012 L .35404 .53103 L F
.106 0 .309 r
.35404 .53103 m .35251 .53224 L .35252 .5322 L F
.35251 .53224 m .35243 .5323 L .35245 .53222 L F
.481 .899 .853 r
.35251 .53224 m .35245 .53222 L .34933 .53276 L F
.628 .385 .531 r
.35157 .52921 m .34933 .53276 L .35245 .53222 L F
.35157 .52921 m .35245 .53222 L .35256 .5318 L F
.669 .82 .956 r
.35428 .62117 m .35597 .62217 L .35399 .62169 L F
.539 .491 .751 r
.35445 .62371 m .35444 .62384 L .35399 .62169 L F
.735 .358 .336 r
.35399 .62169 m .35186 .62268 L .35276 .62028 L F
.35399 .62169 m .35448 .62403 L .35186 .62268 L F
.614 .059 0 r
.35451 .62328 m .35276 .62028 L .35186 .62268 L F
.35759 .62397 m .35428 .62119 L .35469 .62176 L F
.269 0 .079 r
.35799 .62256 m .35597 .62217 L .35759 .62397 L F
.614 .059 0 r
.35759 .62397 m .35656 .6231 L .35657 .62311 L F
.539 .491 .751 r
.35428 .62119 m .35445 .62371 L .35399 .62169 L F
.35445 .62371 m .35448 .62403 L .35444 .62384 L F
.683 .5 .632 r
.35448 .62403 m .35759 .62397 L .35451 .62328 L F
.35448 .62403 m .35451 .62328 L .35186 .62268 L F
.539 .491 .751 r
.35458 .6216 m .35448 .62403 L .35428 .62119 L F
.614 .059 0 r
.35626 .62367 m .35469 .62176 L .35451 .62328 L F
.539 .491 .751 r
.35491 .62205 m .35448 .62403 L .35458 .6216 L F
.995 .865 .543 r
.3564 .62416 m .35759 .62397 L .35448 .62403 L F
.35711 .62404 m .35799 .62256 L .35759 .62397 L F
.614 .059 0 r
.35759 .62397 m .3568 .62336 L .35626 .62367 L F
.336 .071 .356 r
.35706 .62343 m .35712 .62347 L .3564 .62416 L F
.995 .865 .543 r
.3564 .62416 m .35714 .62345 L .35711 .62404 L F
.336 .071 .356 r
.35712 .62347 m .3587 .62452 L .3564 .62416 L F
.995 .865 .543 r
.3564 .62416 m .35715 .62341 L .35714 .62345 L F
.35715 .62341 m .35799 .62256 L .35711 .62404 L F
0 0 0 r
.35963 .62219 m .35832 .62249 L .35729 .62334 L F
.336 .071 .356 r
.35708 .62345 m .35963 .62219 L .3587 .62452 L F
0 0 0 r
.35963 .62219 m .35729 .62334 L .35683 .62373 L F
.336 .071 .356 r
.35706 .62343 m .35963 .62219 L .35708 .62345 L F
0 0 0 r
.35832 .62249 m .35799 .62256 L .35772 .62283 L F
.35832 .62249 m .35772 .62283 L .35683 .62373 L F
.269 0 .079 r
.35799 .62256 m .3586 .62116 L .35597 .62217 L F
0 0 0 r
.35997 .61987 m .3586 .62116 L .35799 .62256 L F
.35997 .61987 m .35799 .62256 L .35963 .62219 L F
.542 .477 .732 r
.35855 .61793 m .35963 .62219 L .35715 .62339 L F
.35717 .62305 m .35715 .62339 L .35706 .62343 L F
.35855 .61793 m .35715 .62339 L .35717 .62305 L F
.614 .059 0 r
.3568 .62336 m .35469 .62176 L .35626 .62367 L F
0 0 0 r
.3556 .61887 m .3549 .6201 L .35573 .61856 L F
.3549 .6201 m .35399 .62169 L .35509 .61971 L F
.3549 .6201 m .35509 .61971 L .35573 .61856 L F
.614 .059 0 r
.35469 .62176 m .35425 .62141 L .35451 .62328 L F
0 0 0 r
.35428 .62117 m .35399 .62169 L .35429 .6211 L F
.669 .82 .956 r
.35276 .62028 m .35428 .62117 L .35399 .62169 L F
.614 .059 0 r
.35425 .62141 m .35276 .62028 L .35387 .62218 L F
.35425 .62141 m .35387 .62218 L .35451 .62328 L F
.153 0 0 r
.35448 .62403 m .35673 .62351 L .3564 .62416 L F
.614 .059 0 r
.35759 .62397 m .35677 .62306 L .35679 .6233 L F
.153 0 0 r
.35673 .62351 m .35706 .62343 L .35682 .6237 L F
.35673 .62351 m .35682 .6237 L .3564 .62416 L F
.614 .059 0 r
.35657 .62311 m .35428 .62117 L .35428 .62119 L F
.35656 .6231 m .35428 .62117 L .35657 .62311 L F
.35469 .62176 m .35428 .62119 L .35425 .62141 L F
.35679 .6233 m .35597 .62217 L .35428 .62117 L F
.539 .491 .751 r
.3556 .61887 m .35491 .62205 L .35428 .62119 L F
0 0 0 r
.35684 .62389 m .35683 .62373 L .3564 .62416 L F
.35963 .62219 m .35683 .62373 L .35684 .62389 L F
.614 .059 0 r
.35677 .62306 m .35597 .62217 L .35679 .6233 L F
.35425 .62141 m .35428 .62117 L .35276 .62028 L F
0 0 0 r
.35573 .61856 m .35428 .62117 L .35652 .61669 L F
.35428 .62117 m .35429 .6211 L .35652 .61669 L F
.724 .193 0 r
.58918 .39433 m .59207 .3959 L .59144 .39682 L F
.845 .394 0 r
.59207 .3959 m .5933 .39839 L .59144 .39682 L F
.895 .987 .736 r
.32099 .61795 m .31914 .62041 L .31848 .61926 L F
0 0 0 r
.32099 .61795 m .32203 .61744 L .32396 .61538 L F
.31848 .61926 m .32203 .61744 L .32099 .61795 L F
0 0 .097 r
.49819 .52902 m .49786 .5315 L .49578 .53289 L F
0 0 .237 r
.49724 .53382 m .49578 .53289 L .49786 .5315 L F
.49724 .53382 m .49544 .53509 L .49578 .53289 L F
.729 .51 .594 r
.55196 .42512 m .55364 .4249 L .55371 .42194 L F
.735 .599 .706 r
.55364 .4249 m .55634 .42105 L .55371 .42194 L F
.701 .937 .963 r
.63107 .40233 m .6242 .40436 L .63006 .40139 L F
.263 .377 .791 r
.62989 .39888 m .63107 .40233 L .6311 .3998 L F
.971 .929 .638 r
.6311 .3998 m .63107 .40233 L .63006 .40139 L F
.001 .399 .85 r
.57142 .44727 m .57265 .44905 L .57444 .44937 L F
.603 .223 .294 r
.25806 .52466 m .25381 .52778 L .25627 .52546 L F
0 0 .011 r
.50055 .52565 m .5001 .52794 L .49819 .52902 L F
0 0 .09 r
.5001 .52794 m .49786 .5315 L .49819 .52902 L F
.869 .958 .861 r
.5114 .40413 m .50959 .40625 L .51007 .4031 L F
.81 .914 .91 r
.51007 .4031 m .50959 .40625 L .50802 .40508 L F
.616 .608 .82 r
.72633 .29375 m .72732 .29781 L .72783 .29645 L F
.542 .365 .591 r
.72725 .29978 m .72783 .29645 L .72732 .29781 L F
0 0 .29 r
.44759 .45408 m .44735 .45673 L .44584 .45784 L F
.311 0 .183 r
.44735 .45673 m .44421 .45923 L .44584 .45784 L F
.864 .996 .789 r
.40354 .45562 m .40149 .45676 L .40251 .45506 L F
.363 .776 .98 r
.40369 .45484 m .40354 .45562 L .40251 .45506 L F
.40369 .45484 m .40721 .45537 L .40354 .45562 L F
.691 .646 .8 r
.40721 .45537 m .40436 .45803 L .40354 .45562 L F
.608 .94 .946 r
.44096 .4454 m .44566 .44432 L .44304 .44505 L F
.823 .798 .828 r
.60813 .41107 m .6125 .41004 L .61123 .40847 L F
.629 .768 .946 r
.6125 .41004 m .61524 .40933 L .61379 .40722 L F
.402 .176 .452 r
.47334 .54015 m .47364 .54205 L .47684 .53903 L F
0 0 .355 r
.47469 .54048 m .47334 .54015 L .46996 .53814 L F
.47469 .54048 m .47364 .54205 L .47334 .54015 L F
0 0 .547 r
.40885 .48165 m .41002 .48362 L .40984 .48249 L F
.788 .45 .416 r
.34191 .49943 m .34649 .50263 L .34541 .50084 L F
.528 .291 .499 r
.63184 .34623 m .62907 .34929 L .62905 .34681 L F
0 0 .411 r
.24579 .55064 m .24385 .55317 L .2441 .5522 L F
.24579 .55064 m .24523 .55529 L .24385 .55317 L F
.308 0 .128 r
.24523 .55529 m .24341 .55677 L .24385 .55317 L F
.877 .936 .561 r
.71062 .29285 m .70917 .29598 L .70963 .29659 L F
.137 .191 .656 r
.42258 .53107 m .42106 .53329 L .42053 .52898 L F
.291 .403 .804 r
.42258 .53107 m .42408 .53473 L .42106 .53329 L F
.626 .766 .946 r
.4009 .48677 m .39592 .48565 L .3996 .48379 L F
.818 .821 .852 r
.40326 .48363 m .4009 .48677 L .3996 .48379 L F
.963 .92 .714 r
.5326 .46977 m .53417 .46772 L .53286 .46481 L F
.541 .882 .987 r
.63751 .38757 m .63459 .38858 L .63362 .3878 L F
.286 .31 .711 r
.3209 .58442 m .32178 .5809 L .31995 .58269 L F
.403 .187 .468 r
.51107 .49231 m .5139 .49028 L .51394 .487 L F
.244 .066 .431 r
.51394 .487 m .51546 .48866 L .51567 .48624 L F
.51394 .487 m .5139 .49028 L .51546 .48866 L F
.002 .563 .805 r
.56355 .45743 m .56496 .45789 L .56118 .45719 L F
.643 .589 .779 r
.52745 .45778 m .52906 .45345 L .52644 .45408 L F
.52745 .45778 m .53024 .45743 L .52906 .45345 L F
.282 .512 .899 r
.52745 .45778 m .53087 .46046 L .53024 .45743 L F
.871 .987 .831 r
.35992 .63878 m .36287 .63777 L .36317 .6351 L F
.642 .495 .668 r
.33194 .62499 m .33292 .62743 L .33018 .62772 L F
.058 0 .093 r
.33292 .62743 m .33004 .63081 L .33268 .63088 L F
.441 0 .077 r
.33018 .62772 m .33277 .62922 L .33004 .63081 L F
.33018 .62772 m .33292 .62743 L .33277 .62922 L F
.921 .767 .673 r
.73287 .2962 m .73406 .30023 L .73564 .29689 L F
.959 .79 .629 r
.58472 .42994 m .58746 .42726 L .58502 .42723 L F
.58472 .42994 m .58645 .43117 L .58746 .42726 L F
.623 .624 .83 r
.35855 .54758 m .36067 .55216 L .3575 .55244 L F
.803 .965 .651 r
.36067 .55216 m .35781 .55629 L .3575 .55244 L F
.509 .398 .663 r
.3595 .55366 m .3575 .55244 L .36067 .55216 L F
.892 .938 .838 r
.36309 .55139 m .36085 .55449 L .36067 .55216 L F
0 0 0 r
.36309 .55139 m .36238 .55184 L .36067 .55216 L F
.509 .398 .663 r
.3595 .55366 m .35781 .55629 L .35759 .55354 L F
.3595 .55366 m .35759 .55354 L .35867 .55316 L F
.803 .965 .651 r
.36067 .55216 m .36018 .55262 L .3595 .55366 L F
.36018 .55262 m .35818 .55447 L .3595 .55366 L F
.36067 .55216 m .35793 .55568 L .35781 .55629 L F
.509 .398 .663 r
.36085 .55449 m .3595 .55366 L .36067 .55216 L F
0 0 0 r
.36238 .55184 m .35818 .55447 L .36018 .55262 L F
.36238 .55184 m .36018 .55262 L .36067 .55216 L F
.509 .398 .663 r
.35867 .55316 m .35759 .55354 L .3575 .55244 L F
.36085 .55449 m .35781 .55629 L .3595 .55366 L F
.803 .965 .651 r
.3595 .55366 m .35818 .55447 L .35793 .55568 L F
.826 .842 .86 r
.4558 .45772 m .45931 .45766 L .45849 .45609 L F
.808 .811 .853 r
.45849 .45609 m .45931 .45766 L .46196 .45434 L F
.807 .743 .792 r
.58234 .35298 m .58362 .35657 L .58625 .35324 L F
.459 .321 .606 r
.2608 .5887 m .26061 .59185 L .26213 .59076 L F
.486 .035 .104 r
.49323 .50895 m .49751 .5071 L .49346 .50948 L F
.49323 .50895 m .4965 .50881 L .49751 .5071 L F
.174 0 .145 r
.4965 .50881 m .49943 .50502 L .49751 .5071 L F
0 0 0 r
.53087 .46046 m .52901 .46438 L .53015 .46243 L F
.15 .231 .693 r
.53024 .45743 m .53087 .46046 L .53282 .45848 L F
0 0 0 r
.53282 .45848 m .53087 .46046 L .53015 .46243 L F
.296 .697 .975 r
.42862 .49706 m .42899 .49607 L .42732 .49565 L F
.42862 .49706 m .43063 .49723 L .42899 .49607 L F
.503 .713 .965 r
.4914 .45203 m .4927 .45427 L .4952 .45379 L F
.54 .566 .83 r
.4927 .45427 m .4968 .45763 L .4952 .45379 L F
0 .193 .71 r
.43406 .5754 m .43524 .57696 L .43391 .5782 L F
.43406 .5754 m .43664 .57747 L .43394 .57422 L F
.43406 .5754 m .43394 .57422 L .43524 .57696 L F
.958 .628 .235 r
.59365 .40227 m .59274 .40357 L .59269 .40085 L F
.59365 .40227 m .59405 .40489 L .59274 .40357 L F
.677 .512 .656 r
.33194 .62499 m .33566 .62427 L .33292 .62743 L F
.33194 .62499 m .33566 .62427 L .33292 .62743 L F
.412 .546 .881 r
.34877 .56315 m .35244 .56453 L .35033 .56069 L F
.34877 .56315 m .35033 .56069 L .34851 .56442 L F
.286 .31 .711 r
.3209 .58442 m .32323 .58401 L .32178 .5809 L F
.264 .198 .592 r
.3209 .58442 m .32275 .5873 L .32323 .58401 L F
.504 .751 .984 r
.54986 .40817 m .55087 .40981 L .55389 .40909 L F
.871 .931 .86 r
.52763 .47946 m .53174 .4774 L .53042 .47627 L F
0 0 0 r
.53015 .46243 m .52901 .46438 L .52827 .46657 L F
.382 .794 .98 r
.60504 .40019 m .60713 .40129 L .6097 .40088 L F
.879 .963 .848 r
.73063 .29056 m .73198 .28755 L .72932 .29073 L F
.865 .91 .86 r
.26948 .63084 m .2725 .6282 L .27185 .62751 L F
.698 .29 .271 r
.46648 .53135 m .47074 .53167 L .46897 .52913 L F
0 0 0 r
.46453 .53207 m .46648 .53135 L .46897 .52913 L F
0 .372 .707 r
.28796 .58158 m .28615 .58095 L .28383 .57999 L F
.767 .989 .892 r
.3679 .63091 m .36992 .62928 L .36835 .62899 L F
.822 .966 .646 r
.36595 .63248 m .3679 .63091 L .36835 .62899 L F
.893 .506 .289 r
.38367 .51661 m .38151 .51585 L .38044 .51302 L F
.894 .508 .292 r
.38367 .51661 m .38204 .51804 L .38151 .51585 L F
.914 .546 .317 r
.38418 .5189 m .38204 .51804 L .38367 .51661 L F
.457 .389 .692 r
.33882 .55951 m .34149 .56159 L .34151 .55867 L F
.33882 .55951 m .33935 .56232 L .34149 .56159 L F
.825 .44 0 r
.40272 .57563 m .40356 .57786 L .40163 .57418 L F
.946 .921 .753 r
.40452 .57162 m .40272 .57563 L .40163 .57418 L F
.284 0 0 r
.57172 .43743 m .57174 .43765 L .56998 .43766 L F
.57172 .43743 m .57442 .43769 L .57174 .43765 L F
.803 .954 .915 r
.6718 .36306 m .67437 .36342 L .67056 .36602 L F
.82 .952 .905 r
.67559 .36161 m .67437 .36342 L .6718 .36306 L F
.785 .732 .804 r
.72633 .29375 m .72996 .29448 L .72932 .29073 L F
.616 .608 .82 r
.72633 .29375 m .72783 .29645 L .72996 .29448 L F
.537 .258 .439 r
.72783 .29645 m .73287 .2962 L .72996 .29448 L F
.364 0 .144 r
.51807 .41803 m .51743 .4205 L .51477 .42113 L F
0 0 0 r
.5197 .41591 m .51743 .4205 L .51807 .41803 L F
.869 .533 .412 r
.46484 .54246 m .46844 .54598 L .46549 .54509 L F
.902 .842 .776 r
.46549 .54509 m .46844 .54598 L .46627 .54942 L F
.388 0 0 r
.60357 .45089 m .60778 .45144 L .60601 .45184 L F
.542 .922 .798 r
.60601 .45184 m .60778 .45144 L .60973 .45011 L F
.521 .914 .807 r
.66797 .38526 m .67159 .3834 L .66974 .3838 L F
0 0 0 r
.67159 .3834 m .67438 .38057 L .67344 .38169 L F
.678 .976 .818 r
.66974 .3838 m .67159 .3834 L .67344 .38169 L F
0 0 0 r
.5024 .52432 m .5001 .52794 L .50055 .52565 L F
.443 .066 .228 r
.27495 .58463 m .27733 .58438 L .27892 .5819 L F
.305 0 .145 r
.27892 .5819 m .28016 .58253 L .2812 .58104 L F
.27892 .5819 m .27733 .58438 L .28016 .58253 L F
.717 .758 .885 r
.54543 .4019 m .54291 .40508 L .54167 .40223 L F
.632 .626 .826 r
.54543 .4019 m .54705 .40555 L .54291 .40508 L F
0 0 0 r
.24647 .5458 m .24567 .54787 L .24444 .54912 L F
0 0 .431 r
.24567 .54787 m .2441 .5522 L .24444 .54912 L F
.883 .893 .834 r
.73034 .31071 m .72637 .31274 L .72655 .31095 L F
.906 .971 .804 r
.72988 .30963 m .73034 .31071 L .73238 .30772 L F
.947 .587 .252 r
.72932 .31197 m .73034 .31071 L .72988 .30963 L F
.72932 .31197 m .7311 .31347 L .73034 .31071 L F
.839 .501 0 r
.56949 .46617 m .57032 .46754 L .56893 .46397 L F
.418 .211 .489 r
.50527 .49691 m .50274 .50032 L .50513 .49951 L F
.50527 .49691 m .50274 .50032 L .50513 .49951 L F
.347 .064 .334 r
.50274 .50032 m .50237 .50235 L .50513 .49951 L F
.695 .953 .686 r
.66479 .37234 m .66168 .37509 L .66431 .37415 L F
0 0 0 r
.66698 .37086 m .66479 .37234 L .66431 .37415 L F
.607 .877 .55 r
.52612 .41626 m .52257 .4201 L .52413 .41933 L F
.838 .371 .065 r
.52634 .41894 m .52612 .41626 L .52413 .41933 L F
.474 .826 .997 r
.52266 .41849 m .52519 .4188 L .52413 .41933 L F
.52519 .4188 m .52634 .41894 L .52413 .41933 L F
.607 .877 .55 r
.52257 .4201 m .5218 .42093 L .52413 .41933 L F
.607 .52 .73 r
.52612 .41626 m .52837 .41876 L .52787 .4146 L F
.009 0 .099 r
.5264 .42042 m .52634 .41894 L .52576 .42112 L F
.838 .371 .065 r
.52634 .41894 m .52837 .41876 L .52623 .41638 L F
0 0 .487 r
.52787 .4146 m .52837 .41876 L .52947 .41584 L F
.791 .999 .82 r
.52947 .41584 m .52837 .41876 L .52634 .41894 L F
.594 .822 .432 r
.5262 .42177 m .52837 .41876 L .52823 .4205 L F
.944 .582 .266 r
.52823 .4205 m .52837 .41876 L .52634 .41894 L F
.009 0 .099 r
.52879 .41784 m .52634 .41894 L .5264 .42042 L F
.838 .371 .065 r
.52634 .41894 m .52623 .41638 L .52612 .41626 L F
.705 .769 .902 r
.60967 .40373 m .611 .40526 L .60836 .40657 L F
.752 .983 .749 r
.51676 .43046 m .51856 .4296 L .5202 .42765 L F
.645 .125 0 r
.23161 .56898 m .2299 .56926 L .22796 .56814 L F
.408 .175 .446 r
.22884 .57256 m .23149 .57231 L .23161 .56898 L F
.309 .107 .436 r
.23399 .56525 m .23309 .56932 L .23161 .56898 L F
.149 .386 .837 r
.23309 .56932 m .23427 .57047 L .23161 .56898 L F
.911 .605 .452 r
.23161 .56898 m .23149 .57231 L .2299 .56926 L F
.307 .8 .813 r
.44115 .59774 m .44208 .59774 L .44511 .59668 L F
.702 .982 .817 r
.34857 .54504 m .35202 .54256 L .35126 .54425 L F
.2 .617 .948 r
.35202 .54256 m .35431 .54281 L .35199 .54126 L F
0 0 .102 r
.35199 .54126 m .35126 .54425 L .35202 .54256 L F
.856 .514 .404 r
.32564 .59501 m .32364 .59697 L .32166 .59428 L F
.32564 .59501 m .3264 .59791 L .32364 .59697 L F
.807 .743 .792 r
.58234 .35298 m .58625 .35324 L .58565 .35069 L F
.332 .633 .962 r
.58625 .35324 m .58743 .35165 L .58565 .35069 L F
.58625 .35324 m .58856 .35336 L .58743 .35165 L F
.354 .309 .669 r
.26933 .58486 m .27186 .58743 L .27221 .58503 L F
.37 .775 .984 r
.34376 .64901 m .34808 .6498 L .34625 .64881 L F
.727 .919 .958 r
.34625 .64881 m .34808 .6498 L .35092 .64773 L F
.867 .871 .838 r
.6693 .36447 m .67056 .36602 L .66778 .36906 L F
.803 .954 .915 r
.6718 .36306 m .67056 .36602 L .6693 .36447 L F
.877 .915 .849 r
.40915 .45475 m .41137 .45482 L .40836 .45743 L F
.727 .548 .649 r
.41137 .45482 m .41071 .45829 L .40836 .45743 L F
.604 .245 .334 r
.40915 .45475 m .41332 .4534 L .41137 .45482 L F
.103 .549 .913 r
.69612 .28041 m .69831 .28122 L .69653 .28113 L F
.952 .918 .557 r
.69653 .28113 m .69505 .28203 L .69612 .28041 L F
.218 .279 .713 r
.69831 .28122 m .69913 .28303 L .69653 .28113 L F
.371 .268 .606 r
.69913 .28303 m .69603 .28538 L .69653 .28113 L F
.449 .872 .932 r
.2502 .62508 m .25098 .62501 L .24764 .62612 L F
.292 .071 .396 r
.2502 .62508 m .24764 .62612 L .24723 .62789 L F
0 0 0 r
.2502 .62508 m .24764 .62612 L .24626 .62674 L F
.791 .301 .043 r
.3784 .512 m .37421 .50866 L .37655 .50958 L F
.865 .444 .006 r
.42549 .53706 m .42715 .53891 L .42591 .53588 L F
.976 .675 .362 r
.5185 .40973 m .5201 .40875 L .51853 .40747 L F
.864 .888 .851 r
.51853 .40747 m .5201 .40875 L .52283 .4055 L F
.296 0 0 r
.52153 .40976 m .5201 .40875 L .5185 .40973 L F
.52153 .40976 m .52247 .40893 L .5201 .40875 L F
.84 .755 .77 r
.51523 .45343 m .51898 .45357 L .51787 .45023 L F
.51523 .45343 m .51725 .45467 L .51898 .45357 L F
.708 .748 .883 r
.51787 .45023 m .51898 .45357 L .52198 .45126 L F
0 0 0 r
.24413 .53013 m .24276 .53163 L .24579 .52886 L F
.977 .675 .326 r
.38915 .52635 m .3879 .52752 L .388 .52505 L F
.38915 .52635 m .38933 .52879 L .3879 .52752 L F
.929 .767 .661 r
.50117 .45569 m .50333 .4575 L .5019 .45359 L F
.772 .81 .883 r
.50066 .45853 m .50333 .4575 L .50117 .45569 L F
.77 .705 .791 r
.5019 .45359 m .50333 .4575 L .50599 .45417 L F
.527 .486 .754 r
.28539 .55049 m .28559 .55141 L .28797 .55065 L F
.695 .72 .201 r
.28559 .55141 m .28779 .55077 L .28797 .55065 L F
.527 .486 .754 r
.28539 .55049 m .28797 .55065 L .28728 .54951 L F
.481 .542 .842 r
.28728 .54951 m .2879 .55067 L .28559 .55141 L F
.2879 .55067 m .28779 .55077 L .28559 .55141 L F
.28794 .55073 m .28851 .5518 L .28559 .55141 L F
.491 .146 .309 r
.28851 .5518 m .28473 .55446 L .28559 .55141 L F
.695 .72 .201 r
.28559 .55141 m .2852 .55262 L .28779 .55077 L F
.544 .864 .577 r
.28797 .55065 m .2898 .54881 L .28728 .54951 L F
.562 .584 .833 r
.29136 .55069 m .28851 .5518 L .2879 .55067 L F
.28875 .54993 m .2879 .55067 L .28728 .54951 L F
.523 .87 .618 r
.28797 .55065 m .2879 .55067 L .288 .55058 L F
.562 .584 .833 r
.29136 .55069 m .2879 .55067 L .28875 .54993 L F
.523 .87 .618 r
.28797 .55065 m .28779 .55077 L .2879 .55067 L F
.288 .55058 m .2879 .55067 L .28801 .55058 L F
.28801 .55058 m .2852 .55262 L .2883 .55005 L F
.28779 .55077 m .2852 .55262 L .28801 .55058 L F
.481 .542 .842 r
.2879 .55067 m .28794 .55073 L .28779 .55077 L F
.695 .72 .201 r
.28559 .55141 m .28473 .55446 L .2852 .55262 L F
.481 .542 .842 r
.28728 .54951 m .28559 .55141 L .28539 .55049 L F
.424 .322 .634 r
.23012 .54607 m .23231 .54568 L .23148 .54365 L F
.44 .395 .712 r
.23012 .54607 m .23316 .54818 L .23231 .54568 L F
.443 .395 .709 r
.23012 .54607 m .23117 .54941 L .23316 .54818 L F
.108 0 .153 r
.35312 .54851 m .35235 .55139 L .35426 .55037 L F
.998 .79 .441 r
.58577 .44412 m .58673 .44487 L .58647 .44098 L F
.925 .738 .632 r
.58427 .44659 m .58673 .44487 L .58577 .44412 L F
.58427 .44659 m .58631 .44768 L .58673 .44487 L F
0 0 .015 r
.55406 .46427 m .55398 .46695 L .55414 .46534 L F
.884 .548 .408 r
.72963 .2856 m .73198 .28755 L .73139 .28454 L F
.331 .263 .628 r
.52669 .40597 m .52885 .40813 L .52941 .40532 L F
.52669 .40597 m .52678 .40864 L .52885 .40813 L F
.459 .527 .84 r
.4952 .45379 m .4968 .45763 L .49935 .45731 L F
.562 .526 .773 r
.30131 .65362 m .30372 .65302 L .30282 .64944 L F
.524 .631 .899 r
.30131 .65362 m .30514 .6542 L .30372 .65302 L F
.892 .986 .8 r
.37419 .61999 m .37778 .61712 L .37694 .61682 L F
.431 .667 .961 r
.55569 .37729 m .5569 .37949 L .55449 .37933 L F
.55569 .37729 m .5569 .37949 L .55449 .37933 L F
.699 .729 .874 r
.46196 .45434 m .46606 .45494 L .4643 .45317 L F
.565 .625 .87 r
.46606 .45494 m .46721 .45239 L .4643 .45317 L F
.46606 .45494 m .46842 .4543 L .46721 .45239 L F
.811 .576 .582 r
.32983 .58183 m .32961 .58471 L .32537 .58398 L F
.73 .827 .925 r
.29702 .64062 m .2958 .64398 L .29483 .64257 L F
0 0 0 r
.29898 .64128 m .2958 .64398 L .2992 .64226 L F
.73 .827 .925 r
.29702 .64062 m .2992 .64226 L .2958 .64398 L F
.982 .91 .625 r
.70185 .34204 m .70267 .34023 L .70099 .34095 L F
.966 .937 .655 r
.70099 .34095 m .70267 .34023 L .702 .33894 L F
.763 .356 .28 r
.24195 .58436 m .24342 .58675 L .24575 .58484 L F
.562 .419 .645 r
.32333 .56849 m .3234 .57186 L .32143 .57183 L F
.572 .333 .515 r
.32257 .57362 m .32143 .57183 L .3234 .57186 L F
.32257 .57362 m .3211 .57487 L .32143 .57183 L F
.605 .618 .838 r
.52673 .41112 m .5244 .41241 L .52247 .40893 L F
.52673 .41112 m .52247 .40893 L .52493 .4098 L F
.88 .969 .651 r
.52493 .4098 m .5244 .41241 L .52673 .41112 L F
.52493 .4098 m .52278 .41337 L .5244 .41241 L F
0 0 .33 r
.55196 .42512 m .55093 .42884 L .55242 .42691 L F
0 0 0 r
.55093 .42884 m .55286 .42866 L .55099 .43024 L F
.55093 .42884 m .55516 .42738 L .55286 .42866 L F
0 0 .141 r
.55242 .42691 m .55093 .42884 L .55099 .43024 L F
.829 .529 0 r
.45836 .58391 m .45949 .5876 L .45908 .58537 L F
.596 .931 .727 r
.65825 .32413 m .65676 .32474 L .65981 .32243 L F
0 0 0 r
.65981 .32243 m .65881 .32325 L .65892 .32318 L F
.545 .851 .542 r
.65825 .32413 m .65981 .32243 L .66068 .32169 L F
0 0 0 r
.65981 .32243 m .65892 .32318 L .66108 .32185 L F
.545 .851 .542 r
.66068 .32169 m .65981 .32243 L .66106 .3213 L F
.88 .92 .848 r
.51901 .43976 m .52288 .43738 L .52216 .43808 L F
0 0 0 r
.52216 .43808 m .52288 .43738 L .52455 .43613 L F
.67344 .38169 m .67438 .38057 L .67666 .37912 L F
.867 .871 .838 r
.6693 .36447 m .66778 .36906 L .66755 .36831 L F
.502 .553 .841 r
.69363 .28708 m .69514 .29111 L .69779 .29 L F
.417 .322 .64 r
.69514 .29111 m .698 .29282 L .69779 .29 L F
.438 .314 .613 r
.69554 .29378 m .698 .29282 L .69514 .29111 L F
0 0 .518 r
.35284 .52431 m .35166 .52224 L .35456 .52312 L F
.35125 .52541 m .35155 .52307 L .35284 .52431 L F
.35155 .52307 m .35166 .52224 L .35284 .52431 L F
.35125 .52541 m .35058 .52156 L .35166 .52224 L F
.35125 .52541 m .35189 .52478 L .35058 .52156 L F
.727 .583 .693 r
.35189 .52478 m .34874 .52106 L .34975 .52133 L F
.35096 .5225 m .34975 .52133 L .35058 .52156 L F
.35189 .52478 m .34975 .52133 L .35096 .5225 L F
0 .091 .615 r
.35157 .52921 m .35189 .52478 L .35125 .52541 L F
.241 .182 .587 r
.35157 .52921 m .35404 .53103 L .35312 .52735 L F
.712 .469 .556 r
.4443 .5807 m .4407 .57793 L .44473 .57867 L F
.53 .161 .284 r
.44473 .57867 m .44724 .58042 L .4443 .5807 L F
0 .509 .859 r
.25206 .5324 m .25098 .52952 L .25175 .52843 L F
0 0 0 r
.37767 .48999 m .37398 .49293 L .37614 .4917 L F
.37904 .48897 m .38083 .48724 L .37767 .48999 L F
.37904 .48897 m .37767 .48999 L .37614 .4917 L F
.473 .255 .502 r
.50527 .49691 m .50513 .49951 L .50786 .4963 L F
.663 .895 .98 r
.24104 .53294 m .23981 .53169 L .24276 .53163 L F
.513 0 0 r
.23958 .53172 m .24131 .53261 L .24126 .53152 L F
.663 .895 .98 r
.23981 .53169 m .23977 .53166 L .24276 .53163 L F
.513 0 0 r
.24126 .53152 m .24127 .53166 L .24276 .53163 L F
.24127 .53166 m .24131 .53261 L .24276 .53163 L F
.23885 .53134 m .23958 .53172 L .24126 .53152 L F
.435 .853 .695 r
.24104 .53294 m .23811 .53461 L .23975 .5317 L F
.23981 .53169 m .23975 .5317 L .23977 .53166 L F
.24104 .53294 m .23975 .5317 L .23981 .53169 L F
0 0 0 r
.4765 .58439 m .47643 .58433 L .47705 .58259 L F
0 0 .062 r
.47637 .58428 m .47643 .58433 L .47639 .58488 L F
.747 .75 .235 r
.47639 .58488 m .47643 .58433 L .47572 .58698 L F
0 0 0 r
.47572 .58698 m .47643 .58433 L .4765 .58439 L F
0 0 .062 r
.47631 .58129 m .47643 .58433 L .47637 .58428 L F
.75 .992 .876 r
.5923 .34744 m .58897 .34996 L .59015 .34764 L F
.725 .675 .801 r
.60705 .38778 m .60732 .3891 L .60421 .38906 L F
.232 .323 .752 r
.6071 .39134 m .60421 .38906 L .60732 .3891 L F
.614 .601 .815 r
.60853 .38729 m .60732 .3891 L .60705 .38778 L F
.696 .459 .561 r
.60844 .38742 m .6071 .39134 L .60732 .3891 L F
.60848 .38742 m .6071 .39134 L .60844 .38742 L F
.60848 .38742 m .61191 .39317 L .60897 .39205 L F
.60859 .38739 m .61191 .39317 L .60848 .38742 L F
.416 .352 .678 r
.60967 .38721 m .61011 .39004 L .60859 .38739 L F
.60977 .38719 m .60981 .38759 L .60967 .38721 L F
.60981 .38759 m .61011 .39004 L .60967 .38721 L F
.681 .496 .629 r
.60981 .38759 m .61191 .39317 L .61023 .38701 L F
.328 .277 .648 r
.61218 .38679 m .61191 .39317 L .61023 .38701 L F
.416 .352 .678 r
.61218 .38679 m .61191 .39317 L .61011 .39004 L F
.681 .496 .629 r
.60981 .38759 m .61023 .38701 L .60976 .38715 L F
.416 .352 .678 r
.61218 .38679 m .61011 .39004 L .60977 .38719 L F
.696 .459 .561 r
.60724 .39094 m .60897 .39205 L .6071 .39134 L F
.60848 .38742 m .60897 .39205 L .60724 .39094 L F
.681 .496 .629 r
.60738 .39094 m .61191 .39317 L .60981 .38759 L F
.60897 .39205 m .61191 .39317 L .60738 .39094 L F
.466 .524 .834 r
.61283 .39167 m .61121 .39361 L .61319 .39385 L F
.61121 .39361 m .61076 .39415 L .61179 .39402 L F
.61121 .39361 m .61179 .39402 L .61319 .39385 L F
.681 .496 .629 r
.6071 .39134 m .60897 .39205 L .60738 .39094 L F
.6071 .39134 m .60981 .38759 L .60561 .38846 L F
.60981 .38759 m .60976 .38715 L .60561 .38846 L F
0 0 0 r
.60976 .38715 m .61023 .38701 L .60892 .38733 L F
.416 .352 .678 r
.60892 .38733 m .60859 .38739 L .60853 .38729 L F
.696 .459 .561 r
.60853 .38729 m .60859 .38739 L .60848 .38742 L F
.60853 .38729 m .60848 .38742 L .60844 .38742 L F
.614 .601 .815 r
.60853 .38729 m .60705 .38778 L .60892 .38733 L F
.60853 .38729 m .60892 .38733 L .61023 .38701 L F
.416 .352 .678 r
.61027 .38705 m .60892 .38733 L .60853 .38729 L F
.61218 .38679 m .60859 .38739 L .61027 .38705 L F
0 0 0 r
.60883 .38745 m .60976 .38715 L .6085 .38743 L F
.60976 .38715 m .60892 .38733 L .6085 .38743 L F
.466 .524 .834 r
.61283 .39167 m .61128 .39352 L .61319 .39385 L F
.61128 .39352 m .61076 .39415 L .61201 .39399 L F
.61128 .39352 m .61201 .39399 L .61319 .39385 L F
0 0 0 r
.60561 .38846 m .60883 .38745 L .60778 .38764 L F
.6065 .38804 m .60778 .38764 L .60705 .38778 L F
.60561 .38846 m .60778 .38764 L .6065 .38804 L F
.60883 .38745 m .6085 .38743 L .60705 .38778 L F
.66106 .3213 m .66253 .32134 L .66385 .31999 L F
.66106 .3213 m .65981 .32243 L .66253 .32134 L F
.18 .022 .416 r
.33935 .56232 m .34097 .5638 L .34149 .56159 L F
.33935 .56232 m .3392 .56526 L .34097 .5638 L F
.719 .986 .809 r
.38387 .48461 m .38083 .48724 L .38198 .48531 L F
.684 .914 .582 r
.38198 .48531 m .38083 .48724 L .37904 .48897 L F
.988 .809 .576 r
.58647 .44098 m .58636 .43729 L .58558 .44105 L F
.998 .79 .441 r
.58577 .44412 m .58647 .44098 L .58558 .44105 L F
.597 .268 .383 r
.60829 .39767 m .60828 .395 L .60553 .39565 L F
.642 .525 .706 r
.60829 .39767 m .61076 .39415 L .60828 .395 L F
0 0 0 r
.48073 .57258 m .48055 .57198 L .4806 .57028 L F
.48073 .57258 m .4802 .57446 L .48055 .57198 L F
.88 .612 .528 r
.31234 .58729 m .31482 .58841 L .3138 .58503 L F
.674 .976 .839 r
.45408 .43968 m .45215 .44125 L .45334 .43942 L F
.615 .925 .971 r
.45334 .43942 m .45215 .44125 L .45138 .44065 L F
.507 .896 .74 r
.66751 .38529 m .66797 .38526 L .66974 .3838 L F
.728 .248 .103 r
.35031 .51976 m .34874 .52106 L .34653 .51863 L F
.942 .595 .334 r
.35058 .52156 m .34874 .52106 L .35031 .51976 L F
.807 .998 .847 r
.27395 .51378 m .27126 .51651 L .27162 .51447 L F
.574 .276 .425 r
.27126 .51651 m .27363 .51876 L .27104 .51861 L F
.987 .721 .359 r
.27126 .51651 m .27104 .51861 L .27014 .51618 L F
.914 .558 .347 r
.35989 .5159 m .36099 .51895 L .36314 .51978 L F
.98 .761 .536 r
.36093 .52143 m .36314 .51978 L .36099 .51895 L F
.36093 .52143 m .36261 .5228 L .36314 .51978 L F
.397 .078 .303 r
.51804 .4774 m .52101 .47676 L .52072 .4755 L F
.303 .45 .843 r
.51974 .47242 m .52072 .4755 L .52183 .47387 L F
.654 .239 .245 r
.52101 .47676 m .52237 .477 L .52072 .4755 L F
.163 .257 .715 r
.52072 .4755 m .52237 .477 L .52183 .47387 L F
.946 .921 .753 r
.40452 .57162 m .40163 .57418 L .40368 .57044 L F
0 0 0 r
.32203 .61744 m .3259 .61381 L .32396 .61538 L F
.848 .975 .872 r
.51461 .46379 m .51856 .46157 L .51495 .46179 L F
.768 .965 .928 r
.51495 .46179 m .51856 .46157 L .51934 .45934 L F
.546 .739 .965 r
.62175 .41517 m .62072 .41802 L .61954 .41609 L F
.62175 .41517 m .62344 .41744 L .62072 .41802 L F
.443 .164 .394 r
.62344 .41744 m .62013 .42028 L .62072 .41802 L F
.059 0 0 r
.31096 .63474 m .30759 .63739 L .31008 .63766 L F
.149 0 .395 r
.31291 .6306 m .31096 .63474 L .31349 .6339 L F
.38 .098 .355 r
.31335 .63529 m .31096 .63474 L .31008 .63766 L F
.31335 .63529 m .31349 .6339 L .31096 .63474 L F
.812 .709 .751 r
.54957 .40248 m .54705 .40555 L .54543 .4019 L F
.385 .045 .262 r
.59155 .3649 m .59441 .36291 L .59174 .36337 L F
.61 .615 .832 r
.69913 .28303 m .69804 .28799 L .69603 .28538 L F
.54 .587 .85 r
.3588 .54703 m .36149 .54472 L .35859 .5464 L F
.3588 .54703 m .36279 .54883 L .36149 .54472 L F
.901 .98 .798 r
.63084 .40989 m .63065 .41204 L .63305 .40924 L F
.732 .97 .714 r
.63419 .4072 m .63305 .40924 L .63452 .40752 L F
.735 .992 .845 r
.63084 .40989 m .63305 .40924 L .63419 .4072 L F
.8 .955 .917 r
.5114 .40413 m .51335 .4005 L .51447 .40113 L F
.5114 .40413 m .51007 .4031 L .51335 .4005 L F
.167 .7 .704 r
.62309 .3409 m .62566 .34032 L .62745 .33996 L F
.368 .831 .761 r
.62745 .33996 m .62915 .33899 L .62997 .33839 L F
.62745 .33996 m .62566 .34032 L .62915 .33899 L F
.653 .105 0 r
.40927 .59037 m .40401 .58776 L .40545 .58921 L F
.555 .144 .217 r
.43929 .5687 m .44289 .56968 L .4418 .56899 L F
.43929 .5687 m .43777 .57121 L .44289 .56968 L F
.522 .363 .607 r
.22884 .57256 m .23173 .57434 L .23149 .57231 L F
.22884 .57256 m .22911 .57494 L .23173 .57434 L F
.402 .856 .823 r
.44697 .58548 m .44652 .58613 L .44439 .58617 L F
.44697 .58548 m .44949 .58492 L .44652 .58613 L F
.61 .615 .832 r
.69913 .28303 m .70039 .28809 L .69804 .28799 L F
.539 .197 .336 r
.69804 .28799 m .69779 .29 L .70062 .28932 L F
.139 .382 .836 r
.69804 .28799 m .6995 .28697 L .69631 .28832 L F
.555 .154 .235 r
.69804 .28799 m .70062 .28932 L .70039 .28809 L F
.139 .382 .836 r
.69804 .28799 m .70062 .28932 L .6995 .28697 L F
.657 .966 .793 r
.46394 .43397 m .45995 .43634 L .46292 .43381 L F
.661 .971 .895 r
.46682 .43198 m .46394 .43397 L .46501 .43215 L F
.674 .977 .855 r
.46501 .43215 m .46394 .43397 L .46292 .43381 L F
.555 .645 .893 r
.29068 .54295 m .29376 .54248 L .2952 .54118 L F
.639 .811 .966 r
.2952 .54118 m .29376 .54248 L .29329 .54217 L F
.363 .134 .427 r
.2952 .54118 m .29511 .54129 L .29465 .54146 L F
.2952 .54118 m .29465 .54146 L .29155 .54262 L F
.2952 .54118 m .29155 .54262 L .29143 .54265 L F
.475 .756 .992 r
.29329 .54217 m .29376 .54248 L .29155 .54262 L F
.552 .667 .913 r
.29155 .54262 m .29376 .54248 L .29068 .54295 L F
.363 .134 .427 r
.29511 .54129 m .29258 .5445 L .29068 .54295 L F
.639 .811 .966 r
.2952 .54118 m .29329 .54217 L .29097 .54066 L F
.475 .756 .992 r
.29097 .54066 m .29329 .54217 L .29038 .5427 L F
.29329 .54217 m .29155 .54262 L .29038 .5427 L F
.363 .134 .427 r
.29143 .54265 m .29155 .54262 L .29068 .54295 L F
.552 .667 .913 r
.29038 .5427 m .29155 .54262 L .29068 .54295 L F
0 .085 .557 r
.29068 .54295 m .29258 .5445 L .29038 .5427 L F
.646 .624 .813 r
.26904 .63802 m .27079 .63745 L .26901 .63462 L F
.926 .94 .586 r
.5949 .43526 m .5933 .43694 L .59566 .43328 L F
.5949 .43526 m .59386 .43758 L .5933 .43694 L F
.449 .202 .447 r
.36064 .60099 m .35777 .60408 L .35851 .60237 L F
.737 .946 .949 r
.33239 .65441 m .33284 .65228 L .33042 .65339 L F
.33239 .65441 m .3345 .653 L .33284 .65228 L F
.753 .401 .386 r
.60552 .39782 m .60553 .39565 L .60152 .39498 L F
.595 .269 .388 r
.60552 .39782 m .60829 .39767 L .60553 .39565 L F
.572 .445 .669 r
.51823 .48006 m .52101 .47676 L .51804 .4774 L F
.245 .051 .407 r
.23569 .56698 m .23399 .56525 L .23602 .56421 L F
.23569 .56698 m .23309 .56932 L .23399 .56525 L F
.621 .937 .717 r
.54348 .48651 m .54105 .48778 L .53982 .48913 L F
.56 .896 .654 r
.54348 .48651 m .54665 .48388 L .54492 .48497 L F
.568 .914 .705 r
.54492 .48497 m .54105 .48778 L .54348 .48651 L F
.124 0 0 r
.25122 .52558 m .25339 .52477 L .25526 .52172 L F
0 0 0 r
.25526 .52172 m .25609 .5217 L .25794 .52122 L F
.25526 .52172 m .25339 .52477 L .25609 .5217 L F
.699 .637 .783 r
.50874 .46702 m .51052 .463 L .50806 .46439 L F
.676 .878 .974 r
.31705 .65548 m .31862 .65652 L .32089 .65532 L F
.823 .931 .903 r
.48611 .4189 m .48556 .42194 L .48402 .42063 L F
.48611 .4189 m .48851 .41933 L .48556 .42194 L F
.615 .612 .825 r
.44164 .58479 m .43951 .58736 L .43859 .58456 L F
.415 .168 .428 r
.6438 .34043 m .64294 .34422 L .64149 .34096 L F
.717 .92 .962 r
.41823 .45872 m .41803 .46008 L .42193 .45849 L F
.774 .897 .495 r
.67985 .34642 m .67786 .35018 L .67882 .34751 L F
.726 .826 .37 r
.67882 .34751 m .67786 .35018 L .67692 .35209 L F
.455 .032 .146 r
.55041 .396 m .55331 .39697 L .55376 .39481 L F
.268 0 .257 r
.55376 .39481 m .55659 .39426 L .55682 .39191 L F
.47 .045 .149 r
.55376 .39481 m .55647 .3966 L .55659 .39426 L F
.55376 .39481 m .55331 .39697 L .55647 .3966 L F
.43 .281 .576 r
.22858 .55576 m .23093 .55722 L .23065 .55369 L F
.22858 .55576 m .22874 .55843 L .23093 .55722 L F
0 .464 .81 r
.41603 .52577 m .41819 .52643 L .41947 .52714 L F
0 .243 .744 r
.41819 .52643 m .42053 .52898 L .41947 .52714 L F
.606 .483 .687 r
.42256 .52582 m .42053 .52898 L .41947 .52714 L F
.724 .986 .893 r
.53385 .46285 m .5382 .46091 L .53702 .45983 L F
.384 .506 .858 r
.52678 .40864 m .52995 .40969 L .52885 .40813 L F
.861 .908 .863 r
.5382 .46091 m .54108 .45803 L .53953 .45652 L F
.555 .403 .629 r
.52644 .45408 m .52906 .45345 L .5289 .45045 L F
.148 .603 .929 r
.2602 .6278 m .25808 .62752 L .25734 .62639 L F
.949 .938 .604 r
.25734 .62639 m .25808 .62752 L .25711 .62756 L F
.424 0 .106 r
.25678 .62951 m .25808 .62752 L .2602 .6278 L F
.148 .603 .929 r
.2602 .6278 m .25808 .62752 L .25734 .62639 L F
0 0 0 r
.25009 .54462 m .24852 .5453 L .24647 .5458 L F
.25175 .54425 m .24852 .5453 L .25009 .54462 L F
.453 .223 .474 r
.3117 .64364 m .31214 .64054 L .30927 .64406 L F
.399 .22 .519 r
.31437 .63715 m .31214 .64054 L .31406 .63994 L F
.454 .845 .98 r
.31063 .63973 m .31214 .64054 L .31406 .63994 L F
.371 .153 .449 r
.3117 .64364 m .31214 .64054 L .31406 .63994 L F
0 .339 .812 r
.70663 .30416 m .70473 .30413 L .70604 .30169 L F
.70663 .30416 m .7076 .3057 L .70473 .30413 L F
.116 .635 .887 r
.42886 .45716 m .43058 .45719 L .42679 .4564 L F
.906 .971 .804 r
.72988 .30963 m .73238 .30772 L .73178 .30605 L F
0 0 .431 r
.24567 .54787 m .24579 .55064 L .2441 .5522 L F
.665 .864 .975 r
.53953 .45652 m .54108 .45803 L .54341 .45663 L F
0 0 0 r
.29813 .58339 m .29627 .58494 L .29916 .58227 L F
.29919 .58233 m .29916 .58227 L .30173 .58198 L F
.29919 .58233 m .29813 .58339 L .29916 .58227 L F
.772 .81 .883 r
.50066 .45853 m .50117 .45569 L .49935 .45731 L F
.842 .917 .884 r
.50009 .40991 m .49628 .41156 L .49809 .40936 L F
.645 .915 .979 r
.50009 .40991 m .50154 .40784 L .50277 .40865 L F
.50009 .40991 m .49809 .40936 L .50154 .40784 L F
.658 .174 .091 r
.25787 .59801 m .2529 .59734 L .25523 .59933 L F
.88 .636 .566 r
.59466 .36434 m .59796 .36286 L .59441 .36291 L F
.59466 .36434 m .59755 .36591 L .59796 .36286 L F
.981 .875 .509 r
.4025 .5592 m .40112 .56065 L .40188 .55785 L F
.857 .443 .246 r
.4025 .5592 m .40356 .56127 L .40112 .56065 L F
.713 .972 .929 r
.57213 .46156 m .5751 .46051 L .5745 .46017 L F
.587 .416 .617 r
.57746 .45789 m .57846 .46055 L .5751 .46051 L F
.44 .736 .99 r
.5751 .46051 m .57695 .45901 L .5745 .46017 L F
.5751 .46051 m .57846 .46055 L .57695 .45901 L F
.346 .001 .229 r
.52787 .4146 m .53028 .41391 L .53109 .41217 L F
.654 .718 .895 r
.52995 .40969 m .53109 .41217 L .53242 .41046 L F
.129 0 .117 r
.53109 .41217 m .53321 .41246 L .53242 .41046 L F
.98 .722 .467 r
.33037 .58015 m .33225 .57863 L .33049 .57719 L F
.487 0 0 r
.33407 .58002 m .33225 .57863 L .33037 .58015 L F
.428 .006 .133 r
.33407 .58002 m .33549 .57843 L .33225 .57863 L F
.717 .92 .962 r
.41823 .45872 m .42193 .45849 L .42002 .4589 L F
.238 0 0 r
.42444 .45754 m .42002 .4589 L .42193 .45849 L F
0 0 0 r
.35774 .54656 m .35625 .54829 L .35855 .54758 L F
.69 .457 .565 r
.34297 .58408 m .34026 .58433 L .34019 .58182 L F
.176 0 0 r
.28961 .58503 m .28769 .58676 L .28518 .58726 L F
.849 .729 .731 r
.28997 .58204 m .28961 .58503 L .28796 .58158 L F
0 0 0 r
.28989 .58587 m .28961 .58503 L .29192 .58567 L F
.28989 .58587 m .28769 .58676 L .28961 .58503 L F
.262 .1 .465 r
.51823 .48006 m .51615 .48385 L .51805 .48267 L F
0 0 .129 r
.51567 .48624 m .51805 .48267 L .51615 .48385 L F
.473 0 0 r
.54354 .47815 m .54512 .4773 L .54097 .47698 L F
.136 .677 .834 r
.54574 .47686 m .54512 .4773 L .54354 .47815 L F
.54574 .47686 m .54813 .47716 L .54512 .4773 L F
.288 0 .262 r
.55682 .39191 m .55902 .39332 L .55935 .39048 L F
.55682 .39191 m .55659 .39426 L .55902 .39332 L F
.657 .876 .98 r
.471 .4533 m .47512 .45327 L .47383 .45129 L F
.654 .813 .96 r
.47383 .45129 m .47512 .45327 L .47799 .45165 L F
.993 .8 .539 r
.40016 .54582 m .39983 .54924 L .39824 .54746 L F
.968 .652 .275 r
.40016 .54582 m .39881 .54467 L .39851 .54207 L F
.996 .821 .554 r
.40016 .54582 m .39824 .54746 L .39881 .54467 L F
.444 .285 .57 r
.32553 .56485 m .3278 .56429 L .32552 .56214 L F
.32553 .56485 m .3278 .56429 L .32552 .56214 L F
.65 .681 .866 r
.29314 .64963 m .29445 .64563 L .2919 .64637 L F
.29314 .64963 m .29563 .64877 L .29445 .64563 L F
0 0 0 r
.31357 .56944 m .31412 .56991 L .31598 .56834 L F
.31357 .56944 m .31172 .57058 L .31412 .56991 L F
.908 .573 .399 r
.38151 .51585 m .3784 .512 L .38044 .51302 L F
.576 .891 .989 r
.27494 .63053 m .27595 .63127 L .27821 .63027 L F
.966 .854 .679 r
.38427 .60034 m .38731 .59803 L .386 .59707 L F
.38427 .60034 m .3858 .60125 L .38731 .59803 L F
.908 .962 .81 r
.38855 .59361 m .386 .59707 L .38731 .59803 L F
.77 .863 .425 r
.62693 .37703 m .62624 .37936 L .62831 .375 L F
.478 .897 .877 r
.62831 .375 m .63017 .37361 L .63104 .374 L F
.63104 .374 m .63017 .37361 L .62831 .375 L F
.665 .501 .652 r
.62831 .375 m .63122 .37513 L .63104 .374 L F
.62831 .375 m .63122 .37513 L .63104 .374 L F
.342 .349 .722 r
.60732 .4072 m .60423 .40631 L .60508 .40484 L F
.64 .79 .954 r
.6231 .3814 m .6242 .3781 L .62133 .37885 L F
.6231 .3814 m .62481 .38058 L .6242 .3781 L F
.398 .827 .669 r
.34705 .53419 m .34557 .53491 L .34736 .53385 L F
.623 .582 .788 r
.23391 .59705 m .23124 .59992 L .23046 .60066 L F
.23391 .59705 m .23497 .60107 L .23124 .59992 L F
.789 .982 .902 r
.70844 .32831 m .71287 .32618 L .71177 .3252 L F
.629 .868 .987 r
.71287 .32618 m .715 .32366 L .71177 .3252 L F
.71287 .32618 m .71617 .32486 L .715 .32366 L F
.76 .307 0 r
.59458 .41437 m .59179 .41045 L .59451 .41208 L F
.619 .613 .823 r
.60346 .35712 m .60387 .35933 L .6011 .36001 L F
0 0 0 r
.60387 .35933 m .60211 .36004 L .6011 .36001 L F
.795 .711 .771 r
.60211 .36004 m .60217 .3573 L .6011 .36001 L F
.864 .888 .851 r
.51853 .40747 m .52283 .4055 L .52127 .4041 L F
.007 0 .279 r
.47986 .53262 m .47926 .53572 L .4809 .53136 L F
.789 .618 .668 r
.26442 .63036 m .2681 .62693 L .26512 .62728 L F
.662 .552 .72 r
.2681 .62693 m .26948 .63084 L .27185 .62751 L F
.032 0 0 r
.64937 .39473 m .65265 .39309 L .65233 .39376 L F
.209 0 0 r
.65233 .39376 m .65265 .39309 L .65475 .39339 L F
0 0 0 r
.65265 .39309 m .65563 .39226 L .65475 .39339 L F
.525 0 0 r
.35859 .5464 m .35431 .54281 L .356 .54633 L F
.35859 .5464 m .35705 .54528 L .35615 .54435 L F
.431 .367 .685 r
.3586 .54253 m .35859 .5464 L .36149 .54472 L F
.3586 .54253 m .35859 .5464 L .36149 .54472 L F
.903 .654 .551 r
.36149 .54472 m .35705 .54528 L .35859 .5464 L F
.485 0 0 r
.35866 .54609 m .35773 .54599 L .35705 .54528 L F
.35773 .54599 m .35485 .54566 L .35705 .54528 L F
.525 0 0 r
.35615 .54435 m .35705 .54528 L .35431 .54281 L F
.04 .023 .507 r
.46549 .54509 m .46574 .54101 L .46484 .54246 L F
.735 .961 .941 r
.42027 .45103 m .41581 .45214 L .4184 .4515 L F
0 0 0 r
.42074 .4512 m .42027 .45103 L .4184 .4515 L F
.42074 .4512 m .42282 .45042 L .42027 .45103 L F
.901 .851 .784 r
.46447 .54825 m .46508 .55159 L .46304 .55151 L F
.46447 .54825 m .46627 .54942 L .46508 .55159 L F
.561 .908 .692 r
.30244 .64396 m .30603 .64124 L .30532 .64438 L F
.59 .282 .415 r
.30532 .64438 m .30706 .64118 L .30603 .64124 L F
0 .202 .719 r
.29038 .5427 m .29258 .5445 L .29097 .54066 L F
.902 .842 .776 r
.46549 .54509 m .46627 .54942 L .46447 .54825 L F
.848 .993 .741 r
.46137 .56445 m .45849 .56823 L .458 .56753 L F
.646 .78 .945 r
.57816 .35227 m .57971 .35422 L .58234 .35298 L F
.594 .921 .693 r
.5197 .41591 m .52118 .41514 L .52278 .41337 L F
0 .435 .825 r
.60534 .42383 m .60876 .42565 L .60703 .42444 L F
.645 .853 .979 r
.60703 .42444 m .60876 .42565 L .61173 .42444 L F
.48 .243 .477 r
.52927 .48376 m .53204 .48313 L .53183 .48044 L F
.35 .151 .463 r
.53183 .48044 m .53426 .48197 L .53522 .47963 L F
.53183 .48044 m .53204 .48313 L .53426 .48197 L F
0 0 .127 r
.52941 .40532 m .53058 .40587 L .53052 .4061 L F
.52941 .40532 m .52885 .40813 L .53058 .40587 L F
.783 .521 .54 r
.26873 .63352 m .26948 .63084 L .26442 .63036 L F
.364 0 .189 r
.60593 .4181 m .6092 .41706 L .60986 .41492 L F
.284 0 .022 r
.6092 .41706 m .61293 .41486 L .60986 .41492 L F
.96 .8 .639 r
.55411 .40322 m .5566 .40268 L .55489 .40095 L F
.55411 .40322 m .55633 .40591 L .5566 .40268 L F
.79 .879 .912 r
.55489 .40095 m .5566 .40268 L .55895 .40107 L F
.684 .557 .705 r
.55633 .40591 m .55895 .40107 L .5566 .40268 L F
.731 .985 .9 r
.35606 .55528 m .35507 .55705 L .35781 .55629 L F
0 0 0 r
.35818 .55447 m .35606 .55528 L .35781 .55629 L F
.488 .072 .176 r
.35781 .55629 m .36068 .55746 L .36085 .55449 L F
.35781 .55629 m .35718 .55784 L .36068 .55746 L F
.819 .559 .004 r
.56218 .41634 m .56276 .41903 L .56211 .41666 L F
.56181 .41465 m .56276 .41903 L .56211 .41666 L F
0 .323 .781 r
.56276 .41903 m .5646 .41937 L .56211 .41666 L F
.572 .063 0 r
.56211 .41666 m .56292 .41781 L .56192 .41765 L F
.767 .824 .897 r
.55892 .41825 m .56276 .41903 L .56211 .41666 L F
.572 .063 0 r
.56211 .41666 m .56192 .41765 L .55954 .41726 L F
.819 .559 .004 r
.56181 .41465 m .56218 .41634 L .56211 .41666 L F
0 .323 .781 r
.56276 .41903 m .56602 .42084 L .5646 .41937 L F
.468 .332 .612 r
.56276 .41903 m .56394 .42242 L .56602 .42084 L F
.692 .981 .868 r
.64567 .38361 m .64706 .38383 L .64424 .38571 L F
.471 .686 .96 r
.64212 .37995 m .64521 .38065 L .6416 .3804 L F
.639 .677 .87 r
.64411 .38019 m .64521 .38065 L .64703 .37891 L F
.471 .686 .96 r
.64472 .38026 m .64521 .38065 L .64212 .37995 L F
.575 .29 .445 r
.6416 .3804 m .64521 .38065 L .64248 .38099 L F
.471 .686 .96 r
.64259 .37956 m .64411 .38019 L .64212 .37995 L F
.29 .359 .761 r
.6416 .3804 m .64241 .38196 L .64249 .3809 L F
.64212 .37995 m .64249 .3809 L .64259 .37956 L F
.6416 .3804 m .64249 .3809 L .64212 .37995 L F
.639 .677 .87 r
.64414 .38075 m .64521 .38065 L .64411 .38019 L F
.64248 .38099 m .64521 .38065 L .64249 .3809 L F
.684 .959 .721 r
.64567 .38361 m .64424 .38571 L .64366 .38573 L F
.64382 .38546 m .64366 .38573 L .64354 .38573 L F
.64567 .38361 m .64366 .38573 L .64382 .38546 L F
.64567 .38361 m .64354 .38573 L .64392 .38524 L F
.64567 .38361 m .64397 .38519 L .64479 .38532 L F
.64397 .38519 m .64423 .38548 L .64519 .38539 L F
.599 .543 .764 r
.64435 .38551 m .64437 .38576 L .64428 .38552 L F
.29 .359 .761 r
.64423 .38548 m .64437 .38576 L .64433 .38557 L F
.684 .959 .721 r
.64423 .38548 m .64426 .38553 L .64428 .38552 L F
.64423 .38548 m .64428 .38552 L .64519 .38539 L F
.599 .543 .764 r
.64435 .38551 m .64428 .38552 L .64249 .3809 L F
.29 .359 .761 r
.64402 .38509 m .64423 .38548 L .64421 .38485 L F
.64423 .38548 m .64433 .38557 L .64421 .38485 L F
.599 .543 .764 r
.64411 .38019 m .64435 .38551 L .64249 .3809 L F
.674 .743 .902 r
.64703 .37891 m .64521 .38065 L .64472 .38026 L F
.599 .543 .764 r
.64703 .37891 m .64472 .38026 L .64411 .38019 L F
.674 .743 .902 r
.64703 .37891 m .64472 .38026 L .64319 .37905 L F
.599 .543 .764 r
.64703 .37891 m .64643 .38047 L .64472 .38026 L F
.471 .686 .96 r
.64319 .37905 m .64472 .38026 L .64411 .38019 L F
.64319 .37905 m .64411 .38019 L .64259 .37956 L F
.599 .543 .764 r
.64643 .38047 m .64437 .38576 L .64411 .38019 L F
.701 .659 .805 r
.64319 .37905 m .64433 .38557 L .64703 .37891 L F
.64433 .38557 m .64437 .38576 L .64447 .3855 L F
.64433 .38557 m .64447 .3855 L .64703 .37891 L F
.684 .959 .721 r
.64529 .38505 m .64479 .38532 L .64519 .38539 L F
.64567 .38361 m .64479 .38532 L .64529 .38505 L F
.64392 .38524 m .64354 .38573 L .64338 .38574 L F
.64397 .38519 m .64348 .38564 L .64426 .38553 L F
.022 .203 .711 r
.64405 .38506 m .64426 .38553 L .64402 .38509 L F
.64426 .38553 m .64437 .38576 L .64423 .38548 L F
.64426 .38553 m .64423 .38548 L .64402 .38509 L F
.29 .359 .761 r
.64244 .38152 m .64397 .38489 L .64259 .37956 L F
.575 .29 .445 r
.6416 .3804 m .64248 .38099 L .64221 .38102 L F
.639 .677 .87 r
.64221 .38102 m .64248 .38099 L .64249 .3809 L F
.29 .359 .761 r
.64402 .38509 m .64421 .38485 L .64319 .37905 L F
.599 .543 .764 r
.64249 .3809 m .64437 .38576 L .64221 .38102 L F
.684 .959 .721 r
.64519 .38539 m .64338 .38574 L .64496 .38627 L F
.64348 .38564 m .64338 .38574 L .64519 .38539 L F
.29 .359 .761 r
.64241 .38196 m .64397 .38489 L .64244 .38152 L F
.64241 .38196 m .64402 .38509 L .64397 .38489 L F
.022 .203 .711 r
.64221 .38102 m .64405 .38506 L .6416 .3804 L F
.64405 .38506 m .64402 .38509 L .6416 .3804 L F
.29 .359 .761 r
.64259 .37956 m .64306 .38138 L .64319 .37905 L F
.64306 .38138 m .64402 .38509 L .64356 .38172 L F
.64306 .38138 m .64356 .38172 L .64319 .37905 L F
.864 .988 .837 r
.36835 .62899 m .36992 .62928 L .37221 .62639 L F
.564 .937 .88 r
.5923 .34744 m .59276 .34614 L .5939 .34555 L F
.5923 .34744 m .59015 .34764 L .59276 .34614 L F
.987 .882 .632 r
.58636 .43729 m .58618 .43393 L .58532 .43609 L F
.956 .845 .421 r
.5854 .43548 m .58636 .43729 L .58532 .43609 L F
.5854 .43548 m .58558 .44105 L .58636 .43729 L F
0 .042 .589 r
.25844 .59285 m .25937 .59698 L .25768 .59477 L F
.247 .136 .524 r
.25937 .59698 m .25787 .59801 L .25768 .59477 L F
.958 .637 .234 r
.5831 .38465 m .58168 .38125 L .58359 .38272 L F
.776 .931 .934 r
.32599 .65472 m .32619 .65247 L .32376 .65362 L F
.32599 .65472 m .3285 .65299 L .32619 .65247 L F
.829 .636 .643 r
.33953 .53206 m .33855 .52948 L .34207 .52929 L F
0 0 0 r
.34229 .52959 m .34207 .52929 L .34458 .52832 L F
.34229 .52959 m .33953 .53206 L .34207 .52929 L F
.588 .642 .871 r
.60432 .34536 m .60265 .34824 L .60151 .34452 L F
0 0 0 r
.48455 .55881 m .48394 .56059 L .48364 .56137 L F
.48623 .55456 m .48538 .55703 L .48455 .55881 L F
.48538 .55703 m .48394 .56059 L .48455 .55881 L F
.75 .713 .817 r
.33024 .597 m .33263 .59612 L .33255 .59498 L F
.985 .8 .4 r
.37221 .62639 m .3724 .62439 L .37136 .62603 L F
.913 .979 .77 r
.3724 .62439 m .37419 .61999 L .37303 .62233 L F
.756 .854 .412 r
.37136 .62603 m .3724 .62439 L .37303 .62233 L F
.904 .655 .551 r
.37473 .54156 m .37457 .5442 L .37831 .54449 L F
.943 .643 .441 r
.37457 .5442 m .37675 .54779 L .37831 .54449 L F
.455 .317 .604 r
.32553 .56485 m .32584 .56811 L .32333 .56849 L F
0 0 .196 r
.32584 .56811 m .3234 .57186 L .32333 .56849 L F
.691 .646 .8 r
.40721 .45537 m .40836 .45743 L .40436 .45803 L F
.01 0 0 r
.40836 .45743 m .40393 .45942 L .40436 .45803 L F
.978 .909 .581 r
.40504 .56556 m .4033 .56704 L .40341 .56275 L F
.40504 .56556 m .404 .56815 L .4033 .56704 L F
0 0 .18 r
.27911 .51237 m .27795 .51638 L .27635 .51246 L F
.27911 .51237 m .27907 .51497 L .27795 .51638 L F
.586 .895 .619 r
.27907 .51497 m .27596 .51789 L .27795 .51638 L F
.438 .311 .609 r
.29898 .64128 m .2992 .64226 L .30097 .64032 L F
.927 .722 .605 r
.57952 .41956 m .58229 .41787 L .58175 .41688 L F
.57952 .41956 m .58218 .42113 L .58229 .41787 L F
.416 .168 .428 r
.23117 .54941 m .23313 .55096 L .23316 .54818 L F
.23117 .54941 m .23058 .55199 L .23313 .55096 L F
.874 .879 .443 r
.4809 .53136 m .48049 .53121 L .48166 .52952 L F
.559 .305 .488 r
.33292 .62743 m .33571 .62943 L .33268 .63088 L F
.522 0 0 r
.33292 .62743 m .33384 .62857 L .33277 .62922 L F
.33292 .62743 m .33571 .62943 L .33384 .62857 L F
.907 .692 .6 r
.31914 .62041 m .31608 .62293 L .31848 .61926 L F
.31914 .62041 m .31935 .62443 L .31608 .62293 L F
.953 .679 .478 r
.57962 .39705 m .58119 .39546 L .57927 .39419 L F
.57962 .39705 m .58216 .399 L .58119 .39546 L F
.57 .42 .638 r
.23771 .56123 m .23602 .56421 L .23643 .56206 L F
.767 .347 .252 r
.55757 .42746 m .56156 .42917 L .56088 .43193 L F
0 .118 .67 r
.56156 .42917 m .56321 .42967 L .56088 .43193 L F
.688 .601 .753 r
.51987 .39477 m .51761 .39819 L .51693 .39822 L F
.51987 .39477 m .52145 .39905 L .51761 .39819 L F
0 0 0 r
.60705 .38778 m .60421 .38906 L .60561 .38846 L F
.808 .616 .642 r
.60319 .3896 m .60561 .38846 L .60421 .38906 L F
.915 .934 .807 r
.23811 .53461 m .23885 .53134 L .23977 .53166 L F
.23811 .53461 m .23601 .53485 L .23885 .53134 L F
.789 .526 .541 r
.34806 .61798 m .34709 .62011 L .34323 .61984 L F
.868 .773 .271 r
.34806 .61798 m .34752 .62131 L .34709 .62011 L F
.199 0 .232 r
.35004 .61699 m .34709 .62011 L .34806 .61798 L F
.35004 .61699 m .34709 .62011 L .34806 .61798 L F
.877 .662 .608 r
.37974 .55428 m .38311 .55238 L .38001 .55139 L F
.37974 .55428 m .38236 .55502 L .38311 .55238 L F
.969 .814 .634 r
.32808 .60737 m .32639 .60727 L .32768 .60366 L F
.99 .889 .579 r
.32808 .60737 m .32594 .60887 L .32639 .60727 L F
.32808 .60737 m .32704 .61164 L .32594 .60887 L F
.285 .712 .969 r
.31155 .65533 m .31234 .6545 L .31022 .65585 L F
.31155 .65533 m .31457 .65549 L .31234 .6545 L F
.409 .834 .674 r
.67887 .37764 m .68272 .37557 L .681 .37594 L F
.443 .837 .627 r
.68272 .37557 m .68604 .37328 L .6847 .37408 L F
.482 .89 .769 r
.681 .37594 m .68272 .37557 L .6847 .37408 L F
.84 .999 .797 r
.47841 .42389 m .47669 .42588 L .47468 .42666 L F
.096 .295 .774 r
.25066 .59463 m .25081 .59515 L .25151 .59321 L F
.535 .278 .472 r
.53152 .41757 m .52823 .4205 L .52837 .41876 L F
.391 .831 .698 r
.55129 .4431 m .5528 .44212 L .54967 .44271 L F
.55129 .4431 m .55498 .44121 L .5528 .44212 L F
0 0 0 r
.30927 .64406 m .30332 .64631 L .30736 .64276 L F
.458 .777 .998 r
.3117 .64364 m .30927 .64406 L .30736 .64276 L F
.511 .812 .999 r
.5019 .45359 m .50599 .45417 L .50449 .45297 L F
.5019 .45359 m .50599 .45417 L .50449 .45297 L F
.55 .854 .998 r
.50599 .45417 m .50712 .45234 L .50449 .45297 L F
.50599 .45417 m .50875 .45341 L .50712 .45234 L F
.508 .542 .826 r
.50599 .45417 m .50998 .45755 L .50875 .45341 L F
.731 .709 .831 r
.52288 .43243 m .5256 .42913 L .52408 .43063 L F
.568 .871 .995 r
.70039 .28809 m .70376 .28686 L .70448 .28765 L F
.923 .959 .786 r
.70448 .28765 m .7059 .28274 L .70725 .2869 L F
.70448 .28765 m .70376 .28686 L .7059 .28274 L F
.702 .385 .437 r
.3304 .56125 m .33452 .56167 L .33486 .559 L F
.795 .728 .789 r
.33327 .55525 m .33486 .559 L .33732 .55542 L F
.496 .204 .4 r
.33486 .559 m .33452 .56167 L .33703 .56085 L F
.33486 .559 m .33452 .56167 L .33703 .56085 L F
.967 .644 .313 r
.58918 .39433 m .58743 .39096 L .58913 .39228 L F
.829 .367 .112 r
.37421 .50866 m .37036 .50522 L .37363 .50702 L F
.911 .527 .106 r
.57695 .45901 m .57746 .45789 L .57707 .45629 L F
.57695 .45901 m .57846 .46055 L .57746 .45789 L F
.954 .609 .235 r
.55614 .40753 m .55633 .40591 L .55411 .40322 L F
.684 .557 .705 r
.55633 .40591 m .55966 .4054 L .55895 .40107 L F
.808 .583 .598 r
.55614 .40753 m .55966 .4054 L .55633 .40591 L F
.955 .732 .56 r
.40356 .57786 m .40497 .58209 L .40301 .58068 L F
.891 .864 .806 r
.40497 .58209 m .40129 .58346 L .40301 .58068 L F
.40497 .58209 m .40297 .58461 L .40129 .58346 L F
.955 .732 .56 r
.40356 .57786 m .40497 .58209 L .40301 .58068 L F
0 0 0 r
.49077 .54218 m .49034 .54439 L .48885 .54588 L F
.49034 .54439 m .48812 .54825 L .48885 .54588 L F
.54 .418 .662 r
.28926 .64671 m .2919 .64637 L .29172 .64378 L F
.762 .534 .587 r
.29036 .58122 m .29484 .57768 L .29379 .57964 L F
.29036 .58122 m .29467 .58113 L .29484 .57768 L F
.708 .607 .038 r
.29484 .57768 m .29467 .58113 L .2947 .58034 L F
.29484 .57768 m .2947 .58034 L .29728 .57779 L F
.912 .759 .679 r
.582 .40745 m .58344 .41065 L .58363 .40839 L F
.959 .624 .318 r
.39516 .53546 m .39384 .53525 L .39321 .53213 L F
.998 .827 .542 r
.39516 .53546 m .39313 .53737 L .39384 .53525 L F
.39516 .53546 m .39394 .54151 L .39313 .53737 L F
.61 .164 .168 r
.32961 .58471 m .33403 .58462 L .3319 .58667 L F
.729 .317 .266 r
.33403 .58462 m .33597 .5871 L .3319 .58667 L F
.549 .508 .763 r
.55024 .45655 m .55421 .46002 L .55437 .45759 L F
.559 .591 .842 r
.55544 .45284 m .55437 .45759 L .55459 .4554 L F
.55544 .45284 m .55683 .45709 L .55437 .45759 L F
.469 .225 .461 r
.55437 .45759 m .55592 .45709 L .55459 .4554 L F
.55437 .45759 m .55683 .45709 L .55592 .45709 L F
.55437 .45759 m .55421 .46002 L .55683 .45709 L F
.55683 .45709 m .55421 .46002 L .55437 .45759 L F
.602 .735 .938 r
.55459 .4554 m .55437 .45759 L .55024 .45655 L F
.97 .831 .65 r
.38746 .58697 m .39003 .58481 L .38857 .5835 L F
.38746 .58697 m .38905 .58818 L .39003 .58481 L F
.371 .266 .604 r
.2263 .5592 m .22805 .5611 L .22874 .55843 L F
.2263 .5592 m .2263 .56187 L .22805 .5611 L F
.848 .993 .741 r
.46137 .56445 m .458 .56753 L .4606 .56463 L F
.664 .944 .687 r
.4606 .56463 m .46224 .56295 L .46137 .56445 L F
.016 0 0 r
.61608 .39306 m .61496 .39276 L .61319 .39385 L F
.61608 .39306 m .61777 .39209 L .61496 .39276 L F
.651 .924 .975 r
.29563 .64877 m .30008 .64759 L .29957 .6476 L F
.504 .446 .725 r
.30008 .64759 m .30282 .64944 L .30206 .64627 L F
.521 .881 .981 r
.5355 .4241 m .53395 .42573 L .53208 .42599 L F
.5355 .4241 m .5365 .42485 L .53395 .42573 L F
.439 .858 .708 r
.63645 .33617 m .63845 .33481 L .63992 .33424 L F
0 0 0 r
.63992 .33424 m .64111 .33386 L .64244 .33311 L F
.63992 .33424 m .63845 .33481 L .64111 .33386 L F
.615 .957 .851 r
.63104 .374 m .63017 .37361 L .63204 .37206 L F
.102 .427 .871 r
.63204 .37206 m .63104 .374 L .63017 .37361 L F
.281 .233 .624 r
.63122 .37513 m .63372 .37465 L .63104 .374 L F
.693 .894 .97 r
.34752 .62131 m .34658 .62234 L .34521 .62252 L F
.517 .588 .865 r
.34658 .62234 m .34916 .62415 L .34752 .62131 L F
.908 .629 .503 r
.40198 .49601 m .40253 .50137 L .4041 .4972 L F
.152 0 0 r
.29702 .58609 m .29627 .58494 L .29813 .58339 L F
.34 0 .198 r
.65656 .33318 m .65598 .33532 L .65322 .33623 L F
.412 .073 .277 r
.65916 .33231 m .65598 .33532 L .65656 .33318 L F
0 0 0 r
.52145 .39905 m .52068 .40051 L .5198 .40097 L F
.649 .593 .778 r
.52906 .45345 m .53024 .45743 L .53259 .45388 L F
.53 .436 .693 r
.53024 .45743 m .53315 .45741 L .53259 .45388 L F
.15 .231 .693 r
.53024 .45743 m .53282 .45848 L .53315 .45741 L F
.575 .078 .036 r
.42684 .54543 m .42996 .54723 L .43129 .54568 L F
.982 .696 .387 r
.42996 .54723 m .43172 .54826 L .43129 .54568 L F
.758 .731 .828 r
.67919 .34283 m .67985 .34642 L .6758 .34602 L F
.774 .897 .495 r
.67985 .34642 m .67882 .34751 L .6758 .34602 L F
.875 .587 .497 r
.37675 .54779 m .38001 .55139 L .37978 .54924 L F
.702 .349 .375 r
.39267 .50176 m .39684 .49998 L .3952 .49879 L F
.39267 .50176 m .39616 .50267 L .39684 .49998 L F
0 0 0 r
.39684 .49998 m .39651 .50127 L .39711 .50118 L F
.39651 .50127 m .39616 .50267 L .39711 .50118 L F
0 0 .498 r
.39711 .50118 m .39842 .50165 L .3978 .50108 L F
0 0 0 r
.39684 .49998 m .39711 .50118 L .3952 .49879 L F
0 0 .498 r
.39711 .50118 m .3978 .50108 L .39605 .49947 L F
.578 .817 .989 r
.6097 .40088 m .61356 .40135 L .6124 .40021 L F
.618 .868 .99 r
.6124 .40021 m .61356 .40135 L .61609 .40014 L F
.776 .507 .529 r
.60082 .37579 m .60122 .37878 L .5973 .37789 L F
0 0 .044 r
.60309 .3715 m .60262 .37381 L .60082 .37579 L F
0 0 .441 r
.60268 .37645 m .60082 .37579 L .60262 .37381 L F
.60268 .37645 m .60122 .37878 L .60082 .37579 L F
.153 0 0 r
.58188 .36769 m .5857 .36822 L .58643 .36822 L F
.152 0 0 r
.58643 .36822 m .5857 .36822 L .58814 .36844 L F
.358 .619 .951 r
.61757 .37319 m .61937 .37099 L .61647 .37122 L F
.713 .952 .665 r
.30701 .62912 m .30624 .63074 L .30886 .62774 L F
.488 .806 1 r
.30441 .62965 m .30624 .63074 L .30701 .62912 L F
.679 .262 .246 r
.35589 .52911 m .35827 .53137 L .35404 .53103 L F
.78 .634 .7 r
.53731 .47601 m .54141 .47404 L .53765 .47437 L F
.735 .599 .706 r
.55364 .4249 m .55708 .42181 L .55634 .42105 L F
.993 .765 .398 r
.55646 .42625 m .55708 .42181 L .55364 .4249 L F
.55646 .42625 m .55757 .42746 L .55708 .42181 L F
.849 .729 .731 r
.28997 .58204 m .28796 .58158 L .29036 .58122 L F
.047 .598 .83 r
.27352 .59154 m .27179 .59105 L .26966 .59086 L F
.78 .487 .491 r
.27352 .59154 m .26908 .59351 L .27179 .59105 L F
.27352 .59154 m .27331 .59405 L .26908 .59351 L F
.413 .073 .275 r
.27679 .59157 m .27331 .59405 L .27352 .59154 L F
.594 .066 0 r
.27331 .59405 m .27143 .59546 L .26908 .59351 L F
.509 .343 .591 r
.27179 .59105 m .27234 .59461 L .2761 .59142 L F
.27179 .59105 m .2761 .59142 L .27614 .59139 L F
.047 .598 .83 r
.26966 .59086 m .27179 .59105 L .2694 .59082 L F
.819 .718 .754 r
.30208 .63864 m .30706 .64118 L .30759 .63739 L F
.872 .63 .57 r
.30532 .64438 m .30706 .64118 L .30208 .63864 L F
.289 0 .238 r
.30736 .64276 m .30706 .64118 L .30532 .64438 L F
.26 0 .215 r
.51995 .50443 m .51714 .50597 L .52012 .50331 L F
.096 0 .021 r
.52251 .50242 m .51995 .50443 L .52012 .50331 L F
.654 .632 .815 r
.2992 .64226 m .30244 .64396 L .30097 .64032 L F
.563 0 0 r
.30052 .6434 m .30244 .64396 L .2992 .64226 L F
.382 .471 .827 r
.30097 .64032 m .30244 .64396 L .30532 .64438 L F
.45 .061 .209 r
.51742 .43617 m .51518 .43478 L .51484 .43687 L F
.51742 .43617 m .51838 .43449 L .51518 .43478 L F
.501 .902 .925 r
.6142 .35017 m .61596 .35061 L .61905 .34927 L F
.986 .901 .603 r
.42908 .56616 m .42763 .56701 L .42768 .56448 L F
.947 .698 .528 r
.37225 .53531 m .37236 .5385 L .37431 .53941 L F
.824 .441 .328 r
.37255 .54098 m .37431 .53941 L .37236 .5385 L F
.37255 .54098 m .37473 .54156 L .37431 .53941 L F
.916 .777 .693 r
.68612 .33247 m .68688 .33627 L .68458 .33558 L F
.904 .869 .794 r
.68688 .33627 m .6834 .33828 L .68458 .33558 L F
.68688 .33627 m .68484 .33962 L .6834 .33828 L F
.502 .49 .776 r
.26581 .58805 m .26757 .59215 L .2694 .59082 L F
0 0 0 r
.2694 .59082 m .26526 .59425 L .26757 .59215 L F
.26757 .59215 m .26526 .59425 L .2694 .59082 L F
.053 0 0 r
.65182 .3274 m .65081 .32839 L .65444 .32653 L F
.567 .271 .426 r
.27221 .58503 m .27467 .58711 L .27495 .58463 L F
.27221 .58503 m .27186 .58743 L .27467 .58711 L F
.542 .365 .591 r
.72725 .29978 m .73064 .29931 L .72783 .29645 L F
.564 .366 .57 r
.72783 .29645 m .73064 .29931 L .73287 .2962 L F
.025 0 0 r
.31144 .5757 m .31336 .57512 L .31003 .5768 L F
.413 .584 .911 r
.54462 .46101 m .54894 .46402 L .5479 .46055 L F
.346 .338 .707 r
.54799 .45081 m .54885 .45278 L .54608 .45095 L F
.371 .088 .347 r
.54608 .45095 m .54943 .44801 L .54799 .45081 L F
.339 .338 .713 r
.54885 .45278 m .54728 .45497 L .54608 .45095 L F
.721 .224 .057 r
.55274 .463 m .5479 .46055 L .54894 .46402 L F
.442 .418 .737 r
.4112 .50901 m .41193 .51129 L .40966 .51189 L F
.538 .559 .824 r
.41384 .51365 m .40966 .51189 L .41193 .51129 L F
.493 .29 .532 r
.25145 .53593 m .25133 .53901 L .24878 .53927 L F
.493 .769 .993 r
.62253 .34807 m .62363 .34583 L .62076 .34715 L F
.62253 .34807 m .62588 .3476 L .62363 .34583 L F
0 0 0 r
.41063 .59182 m .40942 .59439 L .41123 .59284 L F
.41063 .59182 m .41123 .59284 L .40927 .59037 L F
.463 .847 .631 r
.6847 .37408 m .68604 .37328 L .68821 .3717 L F
.938 .726 .591 r
.38184 .56052 m .38487 .55857 L .3828 .5573 L F
.38184 .56052 m .38434 .56156 L .38487 .55857 L F
.84 .999 .797 r
.47841 .42389 m .47468 .42666 L .47743 .4239 L F
0 0 0 r
.48128 .42171 m .47841 .42389 L .47998 .42271 L F
.44 .876 .818 r
.47998 .42271 m .47841 .42389 L .47743 .4239 L F
.147 0 0 r
.51448 .4609 m .51052 .463 L .51288 .46249 L F
.04 0 .175 r
.51448 .4609 m .51691 .45976 L .51679 .45765 L F
0 0 0 r
.51448 .4609 m .51495 .46179 L .51691 .45976 L F
.943 .629 .41 r
.51288 .46249 m .51461 .46379 L .51448 .4609 L F
0 0 .205 r
.51448 .4609 m .51461 .46379 L .51495 .46179 L F
.348 .059 .324 r
.46435 .58085 m .4675 .57775 L .46504 .5785 L F
.892 .877 .814 r
.55265 .43946 m .55498 .44121 L .55699 .438 L F
.981 .723 .463 r
.5528 .44212 m .55498 .44121 L .55265 .43946 L F
.992 .791 .411 r
.70026 .35225 m .69955 .34866 L .6995 .35095 L F
.979 .879 .663 r
.69795 .35449 m .70026 .35225 L .6995 .35095 L F
.69795 .35449 m .69914 .35588 L .70026 .35225 L F
.512 .304 .534 r
.54462 .46101 m .5479 .46055 L .54752 .45723 L F
.816 .639 .662 r
.5479 .46055 m .55024 .45655 L .54752 .45723 L F
.909 .817 .745 r
.7291 .32328 m .7307 .31999 L .72859 .31829 L F
.721 .605 .727 r
.24179 .59265 m .23606 .59526 L .2386 .59155 L F
0 0 0 r
.2386 .59155 m .23868 .5918 L .2387 .5917 L F
.2386 .59155 m .23847 .59138 L .23929 .5911 L F
.773 .423 .394 r
.24298 .59077 m .2386 .59155 L .23929 .5911 L F
.24298 .59077 m .24179 .59265 L .2386 .59155 L F
0 0 0 r
.2386 .59155 m .2387 .5917 L .2393 .58923 L F
.2386 .59155 m .23812 .59151 L .23847 .59138 L F
.431 .367 .685 r
.3586 .54253 m .36149 .54472 L .36142 .54206 L F
.3586 .54253 m .36149 .54472 L .36142 .54206 L F
.603 .223 .294 r
.25806 .52466 m .25725 .52781 L .25381 .52778 L F
.224 0 0 r
.26199 .52313 m .26086 .52473 L .25806 .52466 L F
.695 .312 .319 r
.26145 .52796 m .25806 .52466 L .26086 .52473 L F
.26145 .52796 m .25725 .52781 L .25806 .52466 L F
.901 .869 .797 r
.6834 .33828 m .68484 .33962 L .68133 .34481 L F
.466 .716 .978 r
.71859 .32474 m .71978 .32649 L .72137 .32455 L F
.48 .737 .984 r
.71978 .32649 m .72258 .32615 L .72137 .32455 L F
.021 0 .028 r
.49943 .50502 m .50237 .50235 L .49965 .50325 L F
.502 .49 .776 r
.26581 .58805 m .2694 .59082 L .27038 .59039 L F
.88 .993 .78 r
.27038 .59039 m .2694 .59082 L .27186 .58743 L F
.619 .859 .988 r
.43823 .47788 m .4367 .4803 L .4391 .47664 L F
.43823 .47788 m .4353 .47905 L .4367 .4803 L F
.449 .635 .935 r
.43823 .47788 m .4367 .4803 L .4353 .47905 L F
.43823 .47788 m .43972 .48042 L .4367 .4803 L F
.593 .426 .624 r
.36445 .58782 m .36183 .59114 L .3618 .58831 L F
.653 .892 .982 r
.57832 .41368 m .57906 .41498 L .58155 .41398 L F
.537 .264 .449 r
.58013 .41783 m .57906 .41498 L .57832 .41368 L F
.58013 .41783 m .58175 .41688 L .57906 .41498 L F
.602 .591 .813 r
.71428 .30566 m .71301 .31095 L .71212 .30841 L F
.783 .521 .54 r
.26873 .63352 m .26442 .63036 L .26616 .6343 L F
.219 .528 .92 r
.71005 .30583 m .70899 .30726 L .7076 .3057 L F
.71005 .30583 m .71212 .30841 L .70899 .30726 L F
.433 .242 .519 r
.2536 .53793 m .25133 .53901 L .25145 .53593 L F
.468 .24 .485 r
.25394 .5353 m .2536 .53793 L .25145 .53593 L F
.235 0 0 r
.53283 .45117 m .5289 .45045 L .53127 .44987 L F
.65 .59 .774 r
.52906 .45345 m .53127 .44987 L .5289 .45045 L F
0 0 0 r
.63261 .33757 m .63531 .33665 L .63645 .33617 L F
.43 .845 .677 r
.63645 .33617 m .63531 .33665 L .63845 .33481 L F
.548 .025 0 r
.44184 .47904 m .44555 .47858 L .44215 .47627 L F
.44184 .47904 m .44604 .47934 L .44555 .47858 L F
.79 .879 .912 r
.55489 .40095 m .55895 .40107 L .55747 .39983 L F
.572 .919 .962 r
.55895 .40107 m .55999 .39931 L .55747 .39983 L F
.037 .091 .59 r
.55895 .40107 m .55966 .4054 L .56069 .40346 L F
.712 .983 .897 r
.47083 .5939 m .47129 .59195 L .47023 .59352 L F
.47083 .5939 m .47455 .5914 L .47129 .59195 L F
.971 .686 .43 r
.386 .57339 m .3877 .5719 L .38602 .57073 L F
.386 .57339 m .38774 .57444 L .3877 .5719 L F
0 0 0 r
.54964 .43974 m .55058 .43833 L .54735 .44114 L F
.257 .048 .393 r
.54964 .43974 m .54735 .44114 L .54713 .44326 L F
.579 .321 .49 r
.33052 .57143 m .3331 .5713 L .33345 .56852 L F
.499 .275 .504 r
.3331 .5713 m .33585 .56793 L .33345 .56852 L F
0 0 0 r
.41422 .60036 m .41825 .59826 L .4166 .5971 L F
.386 .746 .992 r
.4166 .5971 m .41825 .59826 L .41972 .59783 L F
0 0 0 r
.45652 .59589 m .45822 .59564 L .46096 .59551 L F
.935 .917 .539 r
.5933 .43694 m .59386 .43758 L .59243 .44112 L F
.873 .73 .701 r
.51523 .45343 m .51679 .45765 L .51725 .45467 L F
.783 .495 .499 r
.67822 .32345 m .67844 .32581 L .67439 .3252 L F
.669 .677 .849 r
.41972 .59783 m .42234 .60128 L .42426 .59949 L F
.504 0 0 r
.34113 .54299 m .33922 .54422 L .3368 .5441 L F
.617 .108 .017 r
.34113 .54299 m .34331 .54483 L .33922 .54422 L F
0 0 0 r
.344 .54475 m .34337 .54556 L .34331 .54483 L F
.34337 .54556 m .3427 .54643 L .34331 .54483 L F
.572 .001 0 r
.34327 .54436 m .34331 .54483 L .34113 .54299 L F
.34514 .54556 m .34331 .54483 L .34327 .54436 L F
.841 .982 .87 r
.55765 .47614 m .55982 .47247 L .55733 .47609 L F
.55765 .47614 m .5607 .47324 L .55982 .47247 L F
.762 .903 .938 r
.72258 .32615 m .72534 .32592 L .72458 .32463 L F
.783 .801 .867 r
.72534 .32592 m .72709 .32182 L .72458 .32463 L F
.72534 .32592 m .7291 .32328 L .72709 .32182 L F
.793 .526 .534 r
.33328 .5522 m .33327 .55525 L .33732 .55542 L F
.52 .838 .533 r
.51995 .50443 m .5161 .50813 L .51714 .50597 L F
.562 .892 .638 r
.6945 .36862 m .69619 .36682 L .69404 .36832 L F
.6945 .36862 m .69766 .36589 L .69619 .36682 L F
.913 .763 .682 r
.58532 .44956 m .58631 .44768 L .58427 .44659 L F
.434 0 0 r
.38345 .4851 m .38387 .48461 L .38198 .48531 L F
.639 .1 0 r
.38705 .48735 m .38387 .48461 L .38684 .48584 L F
.434 0 0 r
.38345 .4851 m .38684 .48584 L .38387 .48461 L F
.893 .555 .401 r
.3668 .5287 m .36706 .531 L .36908 .52934 L F
.885 .541 .391 r
.36908 .52934 m .36706 .531 L .36933 .5317 L F
0 0 0 r
.65037 .33918 m .64734 .34145 L .64822 .34046 L F
.608 .226 .295 r
.34857 .54504 m .34752 .54756 L .34514 .54556 L F
.616 .355 .498 r
.35126 .54425 m .34752 .54756 L .34857 .54504 L F
0 .243 .744 r
.41819 .52643 m .42041 .52784 L .42053 .52898 L F
0 .067 .62 r
.42041 .52784 m .42258 .53107 L .42053 .52898 L F
0 0 0 r
.65861 .37782 m .65654 .37936 L .65538 .38074 L F
.745 .751 .857 r
.56998 .43766 m .56722 .43797 L .5656 .43684 L F
.789 .682 .747 r
.56998 .43766 m .56747 .44081 L .5656 .43684 L F
.549 .342 .552 r
.56998 .43766 m .57026 .44032 L .56747 .44081 L F
.55 .321 .521 r
.57174 .43765 m .57026 .44032 L .56998 .43766 L F
.638 .843 .979 r
.39251 .48551 m .394 .48707 L .39002 .48684 L F
.793 .892 .915 r
.39251 .48551 m .39592 .48565 L .394 .48707 L F
.39251 .48551 m .39592 .48565 L .394 .48707 L F
.604 .652 .87 r
.31437 .63715 m .3148 .63292 L .31349 .6339 L F
.31437 .63715 m .31724 .63663 L .3148 .63292 L F
.539 .602 .865 r
.31487 .63611 m .31437 .63715 L .31335 .63529 L F
.546 .342 .555 r
.31406 .63994 m .31724 .63663 L .31437 .63715 L F
.539 .602 .865 r
.31487 .63611 m .31406 .63994 L .31437 .63715 L F
.818 .821 .852 r
.40326 .48363 m .3996 .48379 L .40197 .48182 L F
.009 .258 .762 r
.40419 .48208 m .40326 .48363 L .40197 .48182 L F
.618 .173 .172 r
.40326 .48363 m .40577 .48555 L .40722 .48431 L F
.009 .258 .762 r
.40419 .48208 m .40577 .48555 L .40326 .48363 L F
.064 .249 .742 r
.40743 .50853 m .40978 .51055 L .40919 .50915 L F
.3 0 .117 r
.40624 .50811 m .40743 .50853 L .40857 .50637 L F
.768 .683 .769 r
.40743 .50853 m .40973 .50522 L .40857 .50637 L F
.40973 .50522 m .4112 .50901 L .40743 .50853 L F
.40743 .50853 m .4112 .50901 L .40973 .50522 L F
.784 .954 .627 r
.40973 .50522 m .40743 .50853 L .40812 .50659 L F
.064 .249 .742 r
.40743 .50853 m .40919 .50915 L .40812 .50659 L F
.3 0 .117 r
.40485 .50915 m .40743 .50853 L .40624 .50811 L F
.814 .882 .453 r
.54799 .45081 m .54943 .44801 L .54993 .44566 L F
.974 .828 .638 r
.32364 .59119 m .32142 .58986 L .32275 .5873 L F
.888 .777 .733 r
.32364 .59119 m .32044 .59122 L .32142 .58986 L F
.32364 .59119 m .32166 .59428 L .32044 .59122 L F
.757 .726 .824 r
.32695 .58779 m .32364 .59119 L .32275 .5873 L F
.58 .829 .992 r
.60953 .3562 m .60637 .35562 L .60972 .35471 L F
.652 .59 .772 r
.60955 .35705 m .60637 .35562 L .60953 .3562 L F
.841 .754 .239 r
.60972 .35471 m .60955 .35705 L .60953 .3562 L F
.53 .695 .944 r
.34024 .57666 m .34164 .58015 L .34149 .57938 L F
1 .81 .491 r
.34024 .57666 m .34149 .57938 L .34171 .57523 L F
.319 .75 .97 r
.34234 .57879 m .34164 .58015 L .34024 .57666 L F
.731 .985 .9 r
.35606 .55528 m .35311 .5573 L .35507 .55705 L F
.425 0 0 r
.35311 .5573 m .35718 .55784 L .35507 .55705 L F
.701 .179 0 r
.57459 .38613 m .5761 .38674 L .57239 .38365 L F
.978 .749 .334 r
.57179 .38253 m .57239 .38365 L .57255 .38182 L F
.856 .403 .035 r
.57179 .38253 m .57459 .38613 L .57239 .38365 L F
.57179 .38253 m .57322 .38568 L .57459 .38613 L F
.294 .772 .925 r
.57459 .38613 m .57322 .38568 L .57353 .38569 L F
.57459 .38613 m .57353 .38569 L .57733 .3858 L F
.701 .179 0 r
.57459 .38613 m .57613 .38677 L .5761 .38674 L F
.105 .509 .907 r
.57733 .3858 m .57613 .38677 L .57459 .38613 L F
.57733 .3858 m .57872 .38735 L .57613 .38677 L F
0 0 .487 r
.52787 .4146 m .52947 .41584 L .53028 .41391 L F
.605 .049 0 r
.41071 .45829 m .41131 .45949 L .40836 .45743 L F
.29 0 .054 r
.41312 .45868 m .41071 .45829 L .41413 .45824 L F
.41312 .45868 m .41131 .45949 L .41071 .45829 L F
0 0 0 r
.5057 .51927 m .50515 .5208 L .50368 .52264 L F
.50862 .51572 m .50767 .51751 L .5057 .51927 L F
.5057 .51927 m .50767 .51751 L .50515 .5208 L F
.808 .583 .598 r
.55614 .40753 m .56021 .40807 L .55966 .4054 L F
0 0 .181 r
.55966 .4054 m .55985 .40595 L .56069 .40346 L F
.55966 .4054 m .56021 .40807 L .55985 .40595 L F
.531 .228 .398 r
.5214 .47136 m .52335 .46788 L .51931 .46964 L F
.513 .448 .721 r
.51974 .47242 m .5214 .47136 L .51931 .46964 L F
0 0 0 r
.67792 .30701 m .68026 .30504 L .68071 .3039 L F
.68071 .3039 m .68212 .30365 L .68343 .30304 L F
.68071 .3039 m .68026 .30504 L .68212 .30365 L F
.466 .259 .514 r
.68071 .3039 m .68343 .30304 L .68335 .30053 L F
0 0 0 r
.64567 .39714 m .64937 .39473 L .64845 .39576 L F
.64845 .39576 m .64937 .39473 L .65233 .39376 L F
.233 .57 .94 r
.34284 .55827 m .33963 .5544 L .34228 .55421 L F
.34284 .55827 m .34203 .55714 L .33963 .5544 L F
.34284 .55827 m .34151 .55867 L .34203 .55714 L F
0 .228 .746 r
.34151 .55867 m .34402 .56094 L .34203 .55714 L F
.498 .317 .566 r
.34149 .56159 m .34402 .56094 L .34151 .55867 L F
.01 0 0 r
.40836 .45743 m .4066 .45869 L .40393 .45942 L F
.877 .915 .849 r
.40915 .45475 m .40836 .45743 L .40721 .45537 L F
.483 0 0 r
.40836 .45743 m .40931 .45837 L .4066 .45869 L F
.773 .754 .836 r
.41122 .45969 m .41235 .46374 L .40943 .46367 L F
.41135 .45967 m .41235 .46374 L .41122 .45969 L F
.41131 .45949 m .40943 .46367 L .40976 .46115 L F
.968 .84 .662 r
.41262 .45947 m .41131 .45949 L .41312 .45868 L F
.773 .754 .836 r
.41131 .45949 m .41135 .45967 L .41122 .45969 L F
.968 .84 .662 r
.41075 .46245 m .41235 .46374 L .41131 .45949 L F
.41075 .46245 m .41127 .45969 L .41262 .45947 L F
.41127 .45969 m .41131 .45949 L .41262 .45947 L F
.72 .646 .775 r
.40664 .46165 m .4106 .45982 L .40883 .46137 L F
.4106 .45982 m .41131 .45949 L .41101 .45972 L F
.4106 .45982 m .41101 .45972 L .40883 .46137 L F
.773 .754 .836 r
.41131 .45949 m .40745 .46363 L .40883 .46137 L F
.72 .646 .775 r
.4106 .45982 m .41003 .45918 L .41131 .45949 L F
.41003 .45918 m .41006 .45879 L .41131 .45949 L F
.40664 .46165 m .40763 .46044 L .40935 .46008 L F
.40981 .46019 m .40935 .46008 L .4106 .45982 L F
.40664 .46165 m .40935 .46008 L .40981 .46019 L F
.632 .09 0 r
.40904 .46001 m .40957 .45996 L .40935 .46008 L F
.348 .36 .73 r
.40996 .45991 m .40996 .45996 L .40992 .45996 L F
.354 0 0 r
.40945 .46006 m .40935 .46008 L .40939 .46006 L F
.40992 .45996 m .40939 .46006 L .40957 .45996 L F
.348 .36 .73 r
.40995 .45971 m .40992 .45996 L .40957 .45996 L F
.942 .9 .755 r
.40931 .45837 m .40957 .45996 L .40904 .46001 L F
.72 .646 .775 r
.40763 .46044 m .40931 .45837 L .4091 .45967 L F
.348 .36 .73 r
.40998 .45968 m .40992 .45996 L .40995 .45971 L F
.40996 .45991 m .40992 .45996 L .40998 .45968 L F
.72 .646 .775 r
.40763 .46044 m .40979 .45931 L .40996 .45996 L F
.40979 .45931 m .41003 .45918 L .40998 .45968 L F
.348 .36 .73 r
.40998 .45968 m .40957 .45996 L .40931 .45837 L F
.72 .646 .775 r
.40979 .45931 m .40998 .45968 L .40996 .45996 L F
.483 0 0 r
.40836 .45743 m .41131 .45949 L .41006 .45879 L F
.781 .678 .75 r
.41014 .45844 m .4103 .45952 L .41312 .45868 L F
.773 .754 .836 r
.40976 .46115 m .40943 .46367 L .40745 .46363 L F
.895 .824 .77 r
.40883 .46137 m .40745 .46363 L .40664 .46165 L F
.72 .646 .775 r
.40664 .46165 m .41075 .46245 L .4099 .46004 L F
.354 0 0 r
.40987 .46004 m .40939 .46013 L .4097 .46005 L F
.942 .9 .755 r
.40931 .45837 m .40904 .46001 L .40882 .46003 L F
.72 .646 .775 r
.40763 .46044 m .40876 .46024 L .40882 .46003 L F
.40815 .4598 m .40882 .46003 L .40931 .45837 L F
.40763 .46044 m .40882 .46003 L .40815 .4598 L F
.632 .09 0 r
.40641 .46023 m .40882 .46003 L .40696 .46138 L F
.40882 .46003 m .40904 .46001 L .40895 .46007 L F
.72 .646 .775 r
.40664 .46165 m .40947 .46025 L .40763 .46044 L F
.40947 .46025 m .4099 .46004 L .40921 .46016 L F
.40947 .46025 m .40921 .46016 L .40763 .46044 L F
.632 .09 0 r
.40904 .46001 m .40935 .46008 L .40921 .46016 L F
.40895 .46007 m .40921 .46016 L .40696 .46138 L F
.40904 .46001 m .40921 .46016 L .40895 .46007 L F
.40882 .46003 m .40895 .46007 L .40696 .46138 L F
.942 .9 .755 r
.40931 .45837 m .40882 .46003 L .40641 .46023 L F
.72 .646 .775 r
.4091 .45967 m .40931 .45837 L .41003 .45918 L F
.354 0 0 r
.4097 .46005 m .40916 .46018 L .40935 .46008 L F
.4097 .46005 m .40935 .46008 L .40945 .46006 L F
.72 .646 .775 r
.40876 .46024 m .4099 .46004 L .40931 .45837 L F
.354 0 0 r
.40987 .46004 m .40916 .46018 L .40939 .46013 L F
.40987 .46004 m .40939 .46013 L .40987 .46004 L F
.781 .678 .75 r
.41062 .45989 m .41075 .46245 L .41163 .46105 L F
.41037 .45994 m .41075 .46245 L .41062 .45989 L F
.4103 .45952 m .41062 .45989 L .41312 .45868 L F
.41062 .45989 m .41163 .46105 L .41262 .45947 L F
.41062 .45989 m .41262 .45947 L .41312 .45868 L F
.354 0 0 r
.41034 .45995 m .40939 .46006 L .40992 .45996 L F
.40987 .46004 m .40939 .46006 L .41034 .45995 L F
.348 .36 .73 r
.41028 .45949 m .40998 .45968 L .40931 .45837 L F
.72 .646 .775 r
.40996 .45996 m .41003 .45918 L .4106 .45982 L F
.781 .678 .75 r
.41061 .46208 m .41075 .46245 L .41037 .45994 L F
.41034 .45995 m .41037 .45994 L .41014 .45844 L F
.41061 .46208 m .41037 .45994 L .41034 .45995 L F
.72 .646 .775 r
.41003 .45918 m .40931 .45837 L .41006 .45879 L F
.483 0 0 r
.40902 .45808 m .41006 .45879 L .40931 .45837 L F
.781 .678 .75 r
.40931 .45837 m .4099 .46004 L .41014 .45844 L F
.4099 .46004 m .41061 .46208 L .41034 .45995 L F
.348 .36 .73 r
.41028 .45949 m .40996 .45991 L .40998 .45968 L F
.41068 .45921 m .41029 .45959 L .41028 .45949 L F
.41029 .45959 m .40996 .45991 L .41028 .45949 L F
.41029 .45961 m .41034 .45995 L .40996 .45996 L F
.41068 .45921 m .40996 .45996 L .40996 .45991 L F
.781 .678 .75 r
.4099 .46004 m .41034 .45995 L .41014 .45844 L F
.354 0 0 r
.41435 .45984 m .40696 .46138 L .40915 .46019 L F
.40921 .46018 m .40915 .46019 L .40916 .46018 L F
.41435 .45984 m .40915 .46019 L .40921 .46018 L F
.41435 .45984 m .40987 .46004 L .41034 .45995 L F
.41435 .45984 m .40921 .46018 L .40987 .46004 L F
.40921 .46018 m .40916 .46018 L .40987 .46004 L F
.781 .678 .75 r
.4103 .45952 m .41037 .45994 L .41062 .45989 L F
.028 .596 .777 r
.41312 .45868 m .41177 .45847 L .40931 .45837 L F
.348 .36 .73 r
.41177 .45847 m .41028 .45949 L .40931 .45837 L F
.41068 .45921 m .4117 .45991 L .41034 .45995 L F
.41068 .45921 m .41034 .45995 L .41029 .45961 L F
.41177 .45847 m .41435 .45984 L .4117 .45991 L F
.41177 .45847 m .4117 .45991 L .41068 .45921 L F
.483 0 0 r
.40836 .45743 m .41006 .45879 L .40902 .45808 L F
.148 0 .076 r
.67048 .32755 m .66887 .32653 L .67168 .32633 L F
.67048 .32755 m .6681 .32882 L .66887 .32653 L F
.818 .761 .799 r
.28623 .50972 m .28722 .51296 L .28983 .50964 L F
.096 0 .198 r
.31551 .62721 m .31291 .6306 L .31455 .62997 L F
.244 .175 .576 r
.31455 .62997 m .31291 .6306 L .3148 .63292 L F
.201 .164 .591 r
.31291 .6306 m .31349 .6339 L .3148 .63292 L F
.662 .646 .824 r
.6124 .40021 m .611 .40526 L .60967 .40373 L F
.6124 .40021 m .61344 .40507 L .611 .40526 L F
.58 .147 .184 r
.51679 .45765 m .51691 .45976 L .51934 .45934 L F
.348 .607 .946 r
.60726 .44018 m .60527 .44033 L .60344 .43759 L F
.575 .684 .915 r
.61524 .40933 m .6165 .40626 L .61379 .40722 L F
.61524 .40933 m .61803 .4088 L .6165 .40626 L F
.738 .938 .951 r
.49072 .41779 m .48851 .41933 L .48611 .4189 L F
.453 .72 .982 r
.51071 .42265 m .51209 .42426 L .50965 .42461 L F
.816 .639 .662 r
.5479 .46055 m .5525 .46197 L .55024 .45655 L F
.721 .224 .057 r
.55274 .463 m .5525 .46197 L .5479 .46055 L F
0 0 .219 r
.55341 .46022 m .5525 .46197 L .55274 .463 L F
.368 .084 .345 r
.28535 .58998 m .28384 .58837 L .28518 .58726 L F
.28535 .58998 m .28264 .59089 L .28384 .58837 L F
.527 .6 .87 r
.361 .54752 m .36067 .55216 L .35855 .54758 L F
.406 .216 .507 r
.36279 .54883 m .36309 .55139 L .36067 .55216 L F
.527 .6 .87 r
.361 .54752 m .36309 .55139 L .36067 .55216 L F
0 .179 .663 r
.28306 .6427 m .28044 .64331 L .28079 .64038 L F
.636 .089 0 r
.28079 .64038 m .2812 .64168 L .28044 .64331 L F
.28079 .64038 m .28306 .6427 L .2812 .64168 L F
.808 .811 .853 r
.45849 .45609 m .46196 .45434 L .46026 .45284 L F
.712 .852 .949 r
.46196 .45434 m .46277 .4517 L .46026 .45284 L F
.46196 .45434 m .4643 .45317 L .46277 .4517 L F
.355 .798 .957 r
.46787 .59476 m .46265 .5942 L .465 .59492 L F
.904 .525 .3 r
.40297 .58461 m .40198 .58679 L .40129 .58346 L F
.40297 .58461 m .40401 .58776 L .40198 .58679 L F
.501 .098 .208 r
.58515 .37099 m .58814 .36844 L .5857 .36822 L F
.58515 .37099 m .58849 .37092 L .58814 .36844 L F
0 0 0 r
.58814 .36844 m .59074 .3671 L .59155 .3649 L F
.148 0 .226 r
.58814 .36844 m .59071 .36942 L .59074 .3671 L F
.58814 .36844 m .58849 .37092 L .59071 .36942 L F
.698 .822 .942 r
.47799 .45165 m .48199 .4519 L .48033 .45041 L F
.737 .901 .952 r
.48199 .4519 m .48295 .44951 L .48033 .45041 L F
.48199 .4519 m .48451 .45063 L .48295 .44951 L F
.921 .973 .766 r
.51447 .40113 m .51568 .39689 L .51693 .39822 L F
.51447 .40113 m .51335 .4005 L .51568 .39689 L F
.142 0 .126 r
.51265 .49208 m .51107 .49231 L .51109 .49315 L F
.51265 .49208 m .5139 .49028 L .51107 .49231 L F
.941 .635 .431 r
.5801 .40033 m .58216 .399 L .57962 .39705 L F
.5801 .40033 m .58137 .4007 L .58216 .399 L F
.67 .91 .583 r
.54608 .45611 m .54728 .45497 L .54885 .45278 L F
.652 .888 .983 r
.4592 .57454 m .46144 .57406 L .46027 .57495 L F
0 0 0 r
.46144 .57406 m .46313 .57356 L .46027 .57495 L F
.481 .271 .516 r
.68335 .30053 m .68343 .30304 L .68604 .2998 L F
0 0 0 r
.7229 .31462 m .72091 .31686 L .72356 .31344 L F
.406 .208 .496 r
.724 .31623 m .72091 .31686 L .7229 .31462 L F
.724 .31623 m .72116 .31924 L .72091 .31686 L F
0 0 0 r
.53664 .44967 m .54114 .44741 L .54154 .44711 L F
.448 .877 .793 r
.54337 .44588 m .54534 .4454 L .54234 .44675 L F
.793 .999 .819 r
.54713 .44326 m .54534 .4454 L .54337 .44588 L F
.54713 .44326 m .54704 .44333 L .54613 .44352 L F
.54704 .44333 m .54337 .44588 L .54613 .44352 L F
.738 .991 .814 r
.54443 .44378 m .54613 .44352 L .54337 .44588 L F
.351 0 0 r
.54473 .44382 m .54613 .44352 L .54443 .44378 L F
.54901 .44449 m .54613 .44352 L .54473 .44382 L F
.033 0 0 r
.54337 .44588 m .54476 .44646 L .54457 .44488 L F
.54337 .44588 m .54457 .44488 L .54443 .44378 L F
.448 .877 .793 r
.54337 .44588 m .54234 .44675 L .54154 .44711 L F
0 0 0 r
.54154 .44711 m .54114 .44741 L .54337 .44588 L F
.983 .701 .337 r
.40173 .55492 m .40034 .55096 L .40229 .55199 L F
.512 .902 .943 r
.42297 .46651 m .4248 .46313 L .42626 .4637 L F
.377 .615 .944 r
.4267 .46147 m .42626 .4637 L .4248 .46313 L F
.831 .971 .659 r
.43032 .46151 m .42917 .4632 L .42945 .46388 L F
.15 .678 .868 r
.42626 .4637 m .42908 .46358 L .42945 .46388 L F
.831 .971 .659 r
.42917 .4632 m .42888 .46434 L .42945 .46388 L F
.15 .678 .868 r
.42908 .46358 m .42925 .46357 L .42945 .46388 L F
.831 .971 .659 r
.42908 .46358 m .42776 .46528 L .42888 .46434 L F
.759 .704 .8 r
.4267 .46147 m .42911 .46345 L .43032 .46151 L F
.42911 .46345 m .42925 .46357 L .43032 .46151 L F
.377 .615 .944 r
.4267 .46147 m .42911 .46345 L .42626 .4637 L F
.831 .971 .659 r
.42917 .4632 m .42897 .46349 L .42904 .46355 L F
.377 .615 .944 r
.42911 .46345 m .42908 .46358 L .42626 .4637 L F
.831 .971 .659 r
.42911 .46345 m .42904 .46355 L .42908 .46358 L F
.42917 .4632 m .42904 .46355 L .42911 .46345 L F
.42897 .46349 m .42776 .46528 L .42908 .46358 L F
.377 .615 .944 r
.42911 .46345 m .42925 .46357 L .42908 .46358 L F
.502 .306 .547 r
.71097 .27112 m .71469 .2704 L .71361 .26778 L F
.512 .338 .582 r
.71364 .27278 m .71469 .2704 L .71097 .27112 L F
0 .337 .766 r
.29821 .64106 m .2992 .64226 L .29702 .64062 L F
0 .071 .574 r
.30052 .6434 m .2992 .64226 L .29821 .64106 L F
.732 .716 .836 r
.37612 .47592 m .37509 .47982 L .3734 .47881 L F
.434 .585 .903 r
.37509 .47982 m .37669 .47779 L .3734 .47881 L F
.37509 .47982 m .37805 .48018 L .37669 .47779 L F
.567 .532 .775 r
.70218 .28188 m .70039 .28809 L .69913 .28303 L F
.70218 .28188 m .70376 .28686 L .70039 .28809 L F
.973 .845 .654 r
.63065 .41204 m .62862 .41348 L .62679 .41106 L F
.63065 .41204 m .63004 .4148 L .62862 .41348 L F
.62862 .41348 m .63065 .41204 L .63084 .40989 L F
.62862 .41348 m .63004 .4148 L .63065 .41204 L F
.917 .52 .205 r
.58458 .42466 m .58218 .42113 L .58277 .42435 L F
.849 .43 .237 r
.58314 .42607 m .58458 .42466 L .58277 .42435 L F
.94 .593 .338 r
.58502 .42723 m .58458 .42466 L .58314 .42607 L F
.789 .857 .901 r
.60937 .37751 m .60436 .37807 L .60702 .37618 L F
.883 .874 .823 r
.61043 .37485 m .60937 .37751 L .60702 .37618 L F
.79 .858 .901 r
.61677 .42061 m .61839 .42229 L .62013 .42028 L F
.773 .973 .919 r
.55982 .47247 m .5607 .47324 L .564 .47084 L F
0 0 0 r
.24743 .52754 m .24783 .52776 L .24895 .52619 L F
.24743 .52754 m .24579 .52886 L .24783 .52776 L F
.967 .727 .523 r
.38774 .57444 m .38753 .5775 L .38935 .5783 L F
.941 .585 .186 r
.38753 .5775 m .38936 .58093 L .38935 .5783 L F
.279 0 .267 r
.55041 .396 m .54803 .39844 L .55076 .39762 L F
.453 .083 .245 r
.55041 .396 m .55076 .39762 L .55331 .39697 L F
0 .064 .613 r
.23111 .60433 m .23237 .60705 L .23136 .60311 L F
.795 .917 .529 r
.42945 .46388 m .42925 .46357 L .43032 .46151 L F
.493 .378 .651 r
.33268 .63088 m .33004 .63081 L .33277 .62922 L F
.33268 .63088 m .33028 .63365 L .33004 .63081 L F
.33004 .63081 m .33028 .63365 L .33268 .63088 L F
.456 .59 .897 r
.36512 .60416 m .36719 .60364 L .36297 .60212 L F
.234 0 .163 r
.36512 .60416 m .36391 .60643 L .36719 .60364 L F
0 0 0 r
.67792 .30701 m .67707 .30843 L .68026 .30504 L F
.076 0 0 r
.65816 .39098 m .66157 .38824 L .66024 .38912 L F
0 0 0 r
.66157 .38824 m .66413 .38714 L .66361 .3874 L F
.66024 .38912 m .66157 .38824 L .66361 .3874 L F
.266 0 0 r
.38841 .48825 m .39002 .48684 L .38705 .48735 L F
.38841 .48825 m .38705 .48735 L .38684 .48584 L F
.578 .516 .749 r
.55432 .43554 m .55478 .43687 L .55778 .43572 L F
.505 .8 .998 r
.55699 .438 m .55226 .43691 L .55419 .43688 L F
.55699 .438 m .55381 .43673 L .55565 .437 L F
.642 .903 .983 r
.55778 .43572 m .55699 .438 L .55547 .43686 L F
.578 .516 .749 r
.55478 .43687 m .55662 .43685 L .55778 .43572 L F
.642 .903 .983 r
.55778 .43572 m .55547 .43686 L .55512 .43661 L F
.578 .516 .749 r
.55547 .43686 m .55524 .43819 L .55662 .43685 L F
.55478 .43687 m .55488 .43716 L .55547 .43686 L F
.55488 .43716 m .55524 .43819 L .55547 .43686 L F
.505 .8 .998 r
.55419 .43688 m .55188 .43682 L .55381 .43673 L F
.55226 .43691 m .55188 .43682 L .55419 .43688 L F
.55565 .437 m .55381 .43673 L .5552 .43667 L F
.744 .608 .706 r
.55265 .43946 m .55524 .43819 L .55478 .43687 L F
.55381 .43673 m .55478 .43687 L .55432 .43554 L F
.55265 .43946 m .55478 .43687 L .55381 .43673 L F
.55265 .43946 m .55381 .43673 L .55188 .43682 L F
.55381 .43673 m .55432 .43554 L .55188 .43682 L F
.505 .8 .998 r
.5552 .43667 m .55188 .43682 L .55512 .43661 L F
.892 .877 .814 r
.55265 .43946 m .55699 .438 L .55524 .43819 L F
.76 .993 .874 r
.55524 .43819 m .55699 .438 L .55778 .43572 L F
.938 .76 .634 r
.25716 .58395 m .25939 .58737 L .2596 .58544 L F
.271 0 .238 r
.52538 .46813 m .52335 .46788 L .5214 .47136 L F
.697 .605 .749 r
.25485 .58445 m .25666 .58882 L .25939 .58737 L F
.486 .804 1 r
.55516 .42738 m .55757 .42746 L .55646 .42625 L F
.654 .888 .982 r
.55992 .42599 m .55757 .42746 L .55646 .42625 L F
.55992 .42599 m .55646 .42625 L .55992 .42568 L F
.244 .258 .676 r
.55757 .42746 m .55992 .42568 L .55646 .42625 L F
0 0 .021 r
.56119 .42535 m .55757 .42746 L .55992 .42599 L F
.821 .99 .871 r
.56286 .42341 m .56119 .42535 L .55992 .42599 L F
.795 .998 .849 r
.56217 .42283 m .55992 .42599 L .55992 .42568 L F
.56217 .42283 m .56286 .42341 L .55992 .42599 L F
.244 .258 .676 r
.55757 .42746 m .56088 .43193 L .55992 .42568 L F
.764 .676 .765 r
.55973 .45335 m .56118 .45719 L .55683 .45709 L F
.769 .628 .704 r
.55683 .45709 m .56118 .45719 L .55864 .461 L F
0 0 .429 r
.56131 .45088 m .56209 .45524 L .56149 .45624 L F
.462 .559 .868 r
.56275 .4546 m .56363 .45625 L .56149 .45624 L F
.56367 .45341 m .56365 .45511 L .56275 .4546 L F
.56365 .45511 m .56363 .45625 L .56275 .4546 L F
0 0 .429 r
.56209 .45524 m .5622 .45585 L .56149 .45624 L F
0 0 .477 r
.56149 .45624 m .56096 .45659 L .55973 .45335 L F
.796 .727 .788 r
.55973 .45335 m .55683 .45709 L .55544 .45284 L F
0 0 .429 r
.56131 .45088 m .56149 .45624 L .55973 .45335 L F
.701 .481 .586 r
.55639 .45402 m .56162 .45567 L .56189 .45411 L F
.56162 .45567 m .56209 .45524 L .56189 .45411 L F
.462 .559 .868 r
.56162 .45567 m .56149 .45624 L .56074 .45652 L F
.56207 .45526 m .56149 .45624 L .56162 .45567 L F
.56209 .45524 m .56074 .45652 L .5607 .45653 L F
.158 .304 .764 r
.56162 .45567 m .5607 .45653 L .5622 .45585 L F
.55639 .45402 m .55944 .4558 L .56012 .4552 L F
.769 .628 .704 r
.55683 .45709 m .55864 .461 L .55953 .45872 L F
0 .241 .703 r
.55683 .45709 m .55809 .4574 L .55592 .45709 L F
.55683 .45709 m .55837 .45801 L .55809 .4574 L F
.55837 .45801 m .55953 .45872 L .55809 .4574 L F
.722 .97 .721 r
.55796 .45711 m .55809 .4574 L .55692 .45804 L F
.158 .304 .764 r
.55944 .4558 m .5607 .45653 L .56012 .4552 L F
.5595 .45584 m .55924 .45535 L .5607 .45653 L F
.55639 .45402 m .55924 .45535 L .5595 .45584 L F
.55639 .45402 m .55807 .45735 L .55924 .45535 L F
.55807 .45735 m .55809 .4574 L .55924 .45535 L F
.454 .474 .79 r
.55592 .45709 m .55809 .4574 L .55639 .45402 L F
.714 .98 .777 r
.55891 .45471 m .55924 .45535 L .55721 .4562 L F
.712 .818 .931 r
.55889 .45063 m .55973 .45335 L .55544 .45284 L F
.427 .628 .938 r
.56131 .45088 m .55973 .45335 L .55889 .45063 L F
.701 .481 .586 r
.55639 .45402 m .56189 .45411 L .5589 .45242 L F
.714 .98 .777 r
.56037 .45343 m .55924 .45535 L .55891 .45471 L F
.722 .97 .721 r
.55853 .45661 m .55809 .4574 L .55796 .45711 L F
.55924 .45535 m .55853 .45661 L .55628 .45839 L F
.55853 .45661 m .55692 .45804 L .55628 .45839 L F
.158 .304 .764 r
.56012 .4552 m .5607 .45653 L .56162 .45567 L F
.462 .559 .868 r
.56209 .45524 m .56207 .45526 L .56162 .45567 L F
.56234 .45481 m .56209 .45524 L .5607 .45653 L F
.56367 .45341 m .56149 .45624 L .56234 .45481 L F
.701 .481 .586 r
.56162 .45567 m .5622 .45585 L .56209 .45524 L F
.5589 .45242 m .56189 .45411 L .56131 .45088 L F
.331 .794 .678 r
.56149 .45624 m .5622 .45585 L .56181 .45603 L F
.56149 .45624 m .56181 .45603 L .5607 .45653 L F
0 0 .477 r
.56149 .45624 m .56118 .45719 L .56096 .45659 L F
.128 .6 .919 r
.56355 .45743 m .56118 .45719 L .56149 .45624 L F
.807 .724 .773 r
.33161 .52927 m .32702 .52983 L .32994 .52986 L F
.776 .719 .799 r
.43497 .46024 m .43649 .46393 L .43936 .46161 L F
0 0 .439 r
.33684 .57193 m .33789 .5748 L .33806 .57302 L F
.33684 .57193 m .33806 .57302 L .33533 .57091 L F
.293 .304 .701 r
.33533 .57091 m .33806 .57302 L .3385 .56927 L F
.33533 .57091 m .3385 .56927 L .33872 .56735 L F
.465 .808 .999 r
.33423 .57149 m .33533 .57091 L .3331 .5713 L F
.33684 .57193 m .33533 .57091 L .33423 .57149 L F
.961 .942 .654 r
.69959 .34472 m .70185 .34204 L .70099 .34095 L F
.69959 .34472 m .70015 .34607 L .70185 .34204 L F
.464 .406 .708 r
.71 .28611 m .70833 .29081 L .70725 .2869 L F
.71 .28611 m .71095 .28978 L .70833 .29081 L F
.583 .032 0 r
.68229 .32654 m .6814 .32758 L .67844 .32581 L F
.779 .281 .014 r
.68229 .32654 m .68446 .3289 L .6814 .32758 L F
.758 .244 0 r
.62324 .40633 m .62395 .40566 L .62509 .40723 L F
0 0 0 r
.49293 .53858 m .49229 .54068 L .49077 .54218 L F
.49161 .54265 m .49077 .54218 L .49229 .54068 L F
.49324 .54174 m .4924 .54237 L .49161 .54265 L F
.49161 .54265 m .49034 .54439 L .49061 .543 L F
.49161 .54265 m .48944 .54662 L .49034 .54439 L F
.49034 .54439 m .48944 .54662 L .48812 .54825 L F
.863 .968 .644 r
.49161 .54265 m .48946 .54455 L .48944 .54662 L F
0 0 0 r
.4924 .54237 m .48946 .54455 L .49161 .54265 L F
.49161 .54265 m .49061 .543 L .49077 .54218 L F
.096 0 .198 r
.31551 .62721 m .31455 .62997 L .31367 .62643 L F
.552 .59 .845 r
.31608 .62293 m .31551 .62721 L .31367 .62643 L F
.31608 .62293 m .31799 .62673 L .31551 .62721 L F
.871 .495 .331 r
.4548 .50314 m .45431 .50496 L .45318 .50176 L F
.193 .123 .544 r
.45572 .49992 m .4548 .50314 L .45335 .49951 L F
.45572 .49992 m .45673 .50174 L .4548 .50314 L F
0 0 .034 r
.4548 .50314 m .45673 .50174 L .45431 .50496 L F
.291 .142 .498 r
.72725 .29978 m .72527 .30408 L .72764 .30043 L F
.42 0 0 r
.72523 .30132 m .72681 .30201 L .72665 .30212 L F
.466 0 0 r
.72665 .30212 m .72934 .30313 L .73069 .30197 L F
.42 0 0 r
.72681 .30201 m .72934 .30313 L .72665 .30212 L F
.641 .911 .609 r
.72646 .30225 m .72665 .30212 L .72764 .30043 L F
.72527 .30408 m .72665 .30212 L .72646 .30225 L F
.72527 .30408 m .72407 .30488 L .72665 .30212 L F
.486 .804 1 r
.55516 .42738 m .55646 .42625 L .55286 .42866 L F
0 .45 .7 r
.32619 .65247 m .3285 .65299 L .33042 .65339 L F
.531 .92 .819 r
.27395 .51378 m .2741 .51292 L .27635 .51246 L F
.27395 .51378 m .27162 .51447 L .2741 .51292 L F
.18 0 0 r
.33781 .61024 m .34042 .6097 L .34129 .60837 L F
.657 .154 .04 r
.34042 .6097 m .34472 .61048 L .34129 .60837 L F
.346 .036 .289 r
.43596 .45594 m .43595 .45594 L .43373 .45865 L F
.536 .581 .847 r
.43206 .46067 m .43373 .45865 L .43058 .45719 L F
.748 .238 0 r
.43373 .45865 m .42925 .45639 L .43058 .45719 L F
.43373 .45865 m .43204 .45826 L .42925 .45639 L F
.346 .036 .289 r
.43595 .45594 m .43204 .45826 L .43373 .45865 L F
.536 .581 .847 r
.43212 .46081 m .43373 .45865 L .43206 .46067 L F
.43212 .46081 m .43497 .46024 L .43373 .45865 L F
.741 .498 .562 r
.57442 .43769 m .57145 .44025 L .57174 .43765 L F
.57442 .43769 m .57449 .44037 L .57145 .44025 L F
.539 .829 .493 r
.42357 .51589 m .42218 .51735 L .42092 .5188 L F
.558 .899 .664 r
.42218 .51735 m .41913 .5199 L .42092 .5188 L F
.776 .719 .799 r
.43497 .46024 m .43936 .46161 L .43759 .45912 L F
.576 .616 .855 r
.43936 .46161 m .44027 .45813 L .43759 .45912 L F
.43936 .46161 m .44193 .46059 L .44027 .45813 L F
0 0 .33 r
.55196 .42512 m .55242 .42691 L .55364 .4249 L F
.533 .132 .227 r
.55646 .42625 m .55364 .4249 L .55242 .42691 L F
.854 .862 .846 r
.33266 .50312 m .32994 .50635 L .32964 .50363 L F
0 .448 .834 r
.3322 .50698 m .33317 .50656 L .33036 .50517 L F
.51 0 0 r
.33036 .50517 m .33317 .50656 L .33116 .50618 L F
.17 .569 .934 r
.32994 .50635 m .33036 .50517 L .32972 .50436 L F
.51 0 0 r
.33036 .50517 m .33116 .50618 L .32883 .50575 L F
.17 .569 .934 r
.32972 .50436 m .33036 .50517 L .32964 .50363 L F
.32994 .50635 m .3322 .50698 L .33036 .50517 L F
.629 .644 .846 r
.50998 .45755 m .51116 .4527 L .50875 .45341 L F
.50998 .45755 m .51258 .45662 L .51116 .4527 L F
.669 .167 .043 r
.31023 .5479 m .3108 .54535 L .30777 .5458 L F
.543 .249 .418 r
.3108 .54535 m .31023 .5479 L .30777 .5458 L F
.272 .777 .787 r
.43479 .44708 m .43862 .44624 L .43613 .44695 L F
.811 .975 .68 r
.49034 .51905 m .48748 .52295 L .48801 .52102 L F
.702 .741 .231 r
.48801 .52102 m .48748 .52295 L .48672 .52541 L F
.053 0 0 r
.64505 .33211 m .64782 .33123 L .6489 .32993 L F
0 0 0 r
.6489 .32993 m .64992 .32948 L .65081 .32839 L F
.6489 .32993 m .64782 .33123 L .64992 .32948 L F
.074 .102 .586 r
.42267 .5638 m .42287 .56673 L .42136 .56838 L F
.155 .04 .46 r
.4232 .5703 m .42136 .56838 L .42287 .56673 L F
.4232 .5703 m .4214 .57146 L .42136 .56838 L F
0 0 0 r
.5301 .48372 m .52927 .48376 L .52767 .48495 L F
.5301 .48372 m .53204 .48313 L .52927 .48376 L F
.154 0 0 r
.30473 .58086 m .30829 .57839 L .30593 .57819 L F
.548 .887 .64 r
.30976 .57687 m .30829 .57839 L .31003 .5768 L F
.564 .933 .913 r
.30593 .57819 m .30829 .57839 L .30976 .57687 L F
.809 .5 .468 r
.72503 .32007 m .72116 .31924 L .724 .31623 L F
.83 .783 .808 r
.72767 .31674 m .72503 .32007 L .724 .31623 L F
.512 .902 .943 r
.42297 .46651 m .42388 .4652 L .4248 .46313 L F
.42297 .46651 m .42157 .46607 L .42388 .4652 L F
.009 .267 .769 r
.42297 .46651 m .42388 .4652 L .42157 .46607 L F
.42297 .46651 m .42502 .46793 L .42388 .4652 L F
.779 .674 .749 r
.29823 .55156 m .30257 .55207 L .30147 .54974 L F
.336 .443 .822 r
.30147 .54974 m .30257 .55207 L .30385 .55021 L F
.409 .542 .878 r
.30385 .55021 m .30257 .55207 L .30125 .54973 L F
.30165 .54927 m .30125 .54973 L .30078 .5489 L F
.30385 .55021 m .30158 .54935 L .30165 .54927 L F
.952 .946 .637 r
.30078 .5489 m .29989 .54816 L .30311 .54831 L F
.409 .542 .878 r
.30385 .55021 m .30168 .54928 L .30311 .54831 L F
.30168 .54928 m .30078 .5489 L .30284 .54837 L F
.30168 .54928 m .30284 .54837 L .30311 .54831 L F
.764 .714 .805 r
.30078 .5489 m .30125 .54973 L .29823 .55156 L F
.686 .948 .678 r
.29823 .55156 m .29915 .54992 L .30078 .5489 L F
.308 0 0 r
.29989 .54816 m .30627 .54745 L .30311 .54831 L F
.30286 .54783 m .30378 .54852 L .30627 .54745 L F
.952 .946 .637 r
.30078 .5489 m .29915 .54992 L .29989 .54816 L F
.469 .297 .564 r
.29989 .54816 m .29915 .54992 L .30147 .54831 L F
.308 0 0 r
.29989 .54816 m .30147 .54831 L .30286 .54783 L F
.469 .297 .564 r
.29989 .54816 m .30147 .54831 L .30212 .54785 L F
.308 0 0 r
.29989 .54816 m .30146 .54831 L .30147 .54831 L F
.646 .968 .874 r
.30212 .54785 m .30104 .54978 L .30161 .54933 L F
.30236 .54817 m .3016 .54936 L .30385 .55021 L F
.30212 .54785 m .30203 .54811 L .30236 .54817 L F
.30203 .54811 m .3016 .54936 L .30236 .54817 L F
.446 .367 .674 r
.30627 .54745 m .30385 .55021 L .30311 .54831 L F
.308 0 0 r
.30308 .54835 m .30378 .54852 L .30356 .54836 L F
.30203 .54811 m .30356 .54836 L .30286 .54783 L F
.812 .776 .269 r
.30236 .54817 m .30378 .54852 L .30212 .54785 L F
.272 0 0 r
.31023 .5479 m .30605 .5497 L .30627 .54745 L F
.31023 .5479 m .30864 .54946 L .30605 .5497 L F
.446 .367 .674 r
.30413 .54989 m .30605 .5497 L .30385 .55021 L F
.30627 .54745 m .30605 .5497 L .30413 .54989 L F
.108 .662 .761 r
.30864 .54946 m .30819 .54949 L .30605 .5497 L F
.30819 .54949 m .30522 .54966 L .30605 .5497 L F
.30522 .54966 m .30351 .54976 L .3048 .54973 L F
.30522 .54966 m .3048 .54973 L .30605 .5497 L F
.812 .776 .269 r
.30364 .54992 m .30378 .54852 L .30236 .54817 L F
.30385 .55021 m .30384 .54988 L .30364 .54992 L F
.30384 .54988 m .30378 .54852 L .30364 .54992 L F
.308 0 0 r
.30146 .54831 m .30378 .54852 L .30308 .54835 L F
.30146 .54831 m .30356 .54836 L .30203 .54811 L F
.646 .968 .874 r
.30196 .54814 m .29915 .54992 L .30104 .54978 L F
.30212 .54785 m .30147 .54831 L .30196 .54814 L F
.30147 .54831 m .29915 .54992 L .30196 .54814 L F
.409 .542 .878 r
.3016 .54936 m .30125 .54973 L .30158 .54935 L F
.646 .968 .874 r
.3016 .54936 m .30122 .54976 L .30147 .54974 L F
.3016 .54936 m .30147 .54974 L .30385 .55021 L F
.409 .542 .878 r
.30385 .55021 m .30125 .54973 L .3016 .54936 L F
.30125 .54973 m .30125 .54973 L .3016 .54936 L F
.646 .968 .874 r
.30161 .54933 m .30104 .54978 L .30122 .54976 L F
.30161 .54933 m .30122 .54976 L .3016 .54936 L F
.666 .974 .873 r
.30101 .55 m .3012 .54976 L .29823 .55156 L F
.30147 .54974 m .30122 .54976 L .30101 .55 L F
.30122 .54976 m .3012 .54976 L .30101 .55 L F
.3012 .54976 m .29915 .54992 L .29823 .55156 L F
.764 .714 .805 r
.30125 .54973 m .30257 .55207 L .29823 .55156 L F
.582 .148 .182 r
.4592 .57454 m .46027 .57495 L .457 .57506 L F
.614 .949 .93 r
.34246 .5738 m .34171 .57523 L .34333 .57448 L F
.826 .514 .461 r
.34463 .57565 m .34182 .57329 L .34246 .5738 L F
.781 .712 .787 r
.33806 .57302 m .34246 .5738 L .34067 .57234 L F
.826 .514 .461 r
.34182 .57329 m .34067 .57234 L .34246 .5738 L F
.614 .949 .93 r
.34246 .5738 m .34333 .57448 L .34446 .57395 L F
.676 .902 .557 r
.34024 .57666 m .34171 .57523 L .34246 .5738 L F
.185 .628 .943 r
.56943 .37929 m .56781 .3801 L .5664 .3789 L F
.239 .602 .952 r
.56839 .37788 m .56943 .37929 L .5664 .3789 L F
.748 .347 0 r
.56839 .37788 m .56872 .37847 L .56943 .37929 L F
.185 .628 .943 r
.56943 .37929 m .57031 .3803 L .56781 .3801 L F
.748 .347 0 r
.56872 .37847 m .57048 .38164 L .56943 .37929 L F
.185 .628 .943 r
.56943 .37929 m .57147 .3804 L .57031 .3803 L F
.061 .176 .672 r
.22699 .56425 m .22796 .56814 L .22895 .56619 L F
.273 .449 .853 r
.22796 .56814 m .2299 .56926 L .22895 .56619 L F
.693 .659 .812 r
.57449 .44037 m .57137 .44323 L .57026 .44032 L F
.408 .781 .993 r
.36279 .54883 m .361 .54752 L .36149 .54472 L F
.36279 .54883 m .36568 .54843 L .361 .54752 L F
.308 .149 .495 r
.36279 .54883 m .36492 .55059 L .36568 .54843 L F
.36279 .54883 m .36309 .55139 L .36492 .55059 L F
.427 .87 .876 r
.3345 .653 m .33552 .65208 L .33284 .65228 L F
.3345 .653 m .33696 .65218 L .33552 .65208 L F
.081 0 .305 r
.52697 .43553 m .52522 .43466 L .52741 .43363 L F
.52697 .43553 m .52455 .43613 L .52522 .43466 L F
.808 .588 .605 r
.27362 .62956 m .27821 .63027 L .27803 .62726 L F
.697 .865 .961 r
.37057 .49507 m .36866 .49658 L .36881 .49413 L F
.859 .974 .862 r
.36881 .49413 m .36866 .49658 L .36735 .49596 L F
.582 .085 .04 r
.24543 .59058 m .24544 .59139 L .24298 .59077 L F
.196 .002 .375 r
.24831 .58734 m .24763 .59025 L .24543 .59058 L F
.117 0 .038 r
.24763 .59025 m .24544 .59139 L .24543 .59058 L F
.762 .764 .854 r
.34709 .62011 m .34521 .62252 L .34323 .61984 L F
.693 .894 .97 r
.34752 .62131 m .34521 .62252 L .34709 .62011 L F
0 0 0 r
.26448 .52406 m .26086 .52473 L .26199 .52313 L F
.562 .41 .632 r
.26461 .51944 m .26476 .52291 L .26199 .52313 L F
.301 0 0 r
.26476 .52291 m .26448 .52406 L .26199 .52313 L F
.664 .943 .683 r
.62043 .37669 m .62128 .37639 L .61864 .37898 L F
.42 .533 .865 r
.61864 .37898 m .62133 .37885 L .62043 .37669 L F
.575 .366 .559 r
.23046 .60066 m .23423 .60063 L .23391 .59705 L F
.54 .223 .379 r
.23046 .60066 m .233 .60297 L .23423 .60063 L F
.941 .614 .385 r
.23356 .60243 m .23444 .60006 L .23394 .5991 L F
.54 .223 .379 r
.23423 .60063 m .233 .60297 L .23459 .60062 L F
.941 .614 .385 r
.233 .60297 m .23356 .60243 L .23364 .60175 L F
.233 .60297 m .23364 .60175 L .23394 .5991 L F
.23356 .60243 m .23497 .60107 L .23444 .60006 L F
.575 .366 .559 r
.23423 .60063 m .23454 .60062 L .23444 .60006 L F
.23423 .60063 m .23444 .60006 L .23391 .59705 L F
.848 .564 .026 r
.23444 .60006 m .23497 .60107 L .23391 .59705 L F
.575 .366 .559 r
.23454 .60062 m .23459 .60062 L .23391 .59705 L F
.848 .564 .026 r
.23394 .5991 m .23444 .60006 L .23391 .59705 L F
.941 .614 .385 r
.233 .60297 m .23483 .60549 L .23497 .60107 L F
.972 .661 .345 r
.23497 .60107 m .23483 .60549 L .23552 .60378 L F
.325 .166 .506 r
.2263 .56187 m .22789 .56443 L .22805 .5611 L F
0 .033 .561 r
.22699 .56425 m .22789 .56443 L .2263 .56187 L F
0 .001 .533 r
.33321 .51869 m .33264 .51774 L .33183 .5169 L F
0 .278 .735 r
.33321 .51869 m .33543 .51997 L .33264 .51774 L F
.881 .595 .499 r
.31234 .58729 m .31354 .59053 L .31482 .58841 L F
.996 .858 .579 r
.56323 .38622 m .56166 .38715 L .56233 .38343 L F
.833 .619 .613 r
.34487 .60396 m .34238 .60718 L .341 .60595 L F
.34487 .60396 m .34456 .60723 L .34238 .60718 L F
.528 .291 .499 r
.63184 .34623 m .63208 .34893 L .62907 .34929 L F
.778 .801 .871 r
.34495 .5922 m .34189 .59427 L .34506 .5947 L F
.634 .453 .62 r
.34297 .59739 m .34583 .59759 L .34506 .5947 L F
.181 .306 .756 r
.34495 .5922 m .34506 .5947 L .34655 .5929 L F
.541 .569 .832 r
.34583 .59759 m .34655 .5929 L .34506 .5947 L F
.901 .715 .64 r
.5656 .43684 m .56747 .44081 L .56379 .43993 L F
.888 .769 .725 r
.56379 .43993 m .56747 .44081 L .56504 .4442 L F
.226 .268 .697 r
.44289 .56968 m .44433 .5702 L .4418 .56899 L F
.831 .636 .64 r
.43823 .47788 m .44215 .47627 L .4391 .47664 L F
.784 .726 .799 r
.51165 .42223 m .51209 .42426 L .51477 .42113 L F
.646 .779 .944 r
.51295 .42302 m .51209 .42426 L .51165 .42223 L F
.855 .87 .85 r
.51477 .42113 m .51209 .42426 L .51404 .42143 L F
.709 .671 .811 r
.51331 .42173 m .51165 .42223 L .51477 .42113 L F
.855 .87 .85 r
.51477 .42113 m .51404 .42143 L .51407 .42139 L F
.51407 .42139 m .51295 .42302 L .51292 .42248 L F
.709 .671 .811 r
.51331 .42173 m .51292 .42248 L .51165 .42223 L F
.855 .87 .85 r
.51335 .42166 m .51292 .42248 L .51289 .42183 L F
.51407 .42139 m .51292 .42248 L .51335 .42166 L F
.709 .671 .811 r
.51743 .4205 m .51854 .42356 L .51292 .42248 L F
.51743 .4205 m .51292 .42248 L .51331 .42173 L F
.51743 .4205 m .51331 .42173 L .51477 .42113 L F
.655 .723 .899 r
.51854 .42356 m .5169 .42541 L .51295 .42302 L F
.51292 .42248 m .51295 .42302 L .51165 .42223 L F
.51854 .42356 m .51295 .42302 L .51292 .42248 L F
.855 .87 .85 r
.51289 .42183 m .51209 .42426 L .51071 .42265 L F
.51295 .42302 m .51209 .42426 L .51289 .42183 L F
.646 .779 .944 r
.5169 .42541 m .51209 .42426 L .51295 .42302 L F
.94 .649 .461 r
.56204 .4475 m .56212 .45011 L .55999 .44926 L F
0 0 0 r
.56504 .4442 m .56204 .4475 L .5638 .44618 L F
.56204 .4475 m .55999 .44926 L .5638 .44618 L F
.61085 .37794 m .61439 .3754 L .61393 .37538 L F
.296 .358 .757 r
.61404 .37297 m .61643 .37356 L .61439 .3754 L F
.562 .922 .748 r
.61643 .37356 m .61393 .37538 L .61439 .3754 L F
.803 .903 .498 r
.69843 .36335 m .69766 .36589 L .69938 .3624 L F
.838 .965 .64 r
.69619 .36682 m .69766 .36589 L .69843 .36335 L F
.376 .224 .544 r
.31354 .59053 m .31312 .5934 L .31101 .59129 L F
.31354 .59053 m .31312 .5934 L .31101 .59129 L F
.677 .866 .473 r
.43749 .48727 m .43645 .48853 L .43795 .48635 L F
.57 .895 .985 r
.43749 .48727 m .43795 .48635 L .44069 .48618 L F
.43749 .48727 m .43795 .48635 L .44069 .48618 L F
.697 .283 .257 r
.30564 .57747 m .30478 .57413 L .30274 .57753 L F
.30564 .57747 m .30695 .57565 L .30478 .57413 L F
.784 .87 .435 r
.49173 .51597 m .49034 .51905 L .49057 .51769 L F
0 0 0 r
.49344 .51445 m .49173 .51597 L .49057 .51769 L F
.446 .333 .632 r
.23148 .54365 m .23409 .54483 L .23425 .54113 L F
.23148 .54365 m .23231 .54568 L .23409 .54483 L F
0 0 .204 r
.3259 .61381 m .32594 .60887 L .32704 .61164 L F
.782 .876 .916 r
.24626 .62674 m .24723 .62789 L .2502 .62508 L F
.68 .169 0 r
.68133 .34481 m .67919 .34283 L .68021 .34135 L F
.901 .869 .797 r
.6834 .33828 m .68133 .34481 L .68021 .34135 L F
.6 .819 .984 r
.55389 .40909 m .55783 .40952 L .55614 .40753 L F
.749 .775 .874 r
.55783 .40952 m .56021 .40807 L .55614 .40753 L F
.892 .474 .181 r
.5666 .46234 m .56893 .46397 L .56873 .46542 L F
.851 .4 .005 r
.5666 .46234 m .56856 .46518 L .56783 .46491 L F
.862 .413 .092 r
.56783 .46491 m .56893 .46397 L .5666 .46234 L F
0 0 0 r
.56647 .46442 m .56783 .46491 L .56863 .46271 L F
.842 .77 .782 r
.56254 .46926 m .56595 .46918 L .56498 .46577 L F
.81 .89 .901 r
.56595 .46918 m .56783 .46491 L .56498 .46577 L F
.817 .968 .653 r
.56254 .46926 m .56498 .46577 L .56339 .46685 L F
0 0 0 r
.56339 .46685 m .56498 .46577 L .56783 .46491 L F
.56339 .46685 m .56783 .46491 L .56647 .46442 L F
.851 .4 .005 r
.56856 .46518 m .56873 .46542 L .56783 .46491 L F
.928 .543 .18 r
.56871 .46558 m .56873 .46542 L .56783 .46491 L F
.851 .4 .005 r
.56873 .46542 m .569 .46581 L .56783 .46491 L F
.928 .543 .18 r
.56873 .46542 m .56893 .46397 L .56783 .46491 L F
.56949 .46617 m .56893 .46397 L .56871 .46558 L F
.892 .474 .181 r
.56873 .46542 m .56893 .46397 L .569 .46581 L F
.782 .945 .93 r
.56893 .46397 m .57213 .46156 L .56947 .46122 L F
.56893 .46397 m .56947 .46122 L .569 .46581 L F
.029 0 .018 r
.69554 .29378 m .69251 .29689 L .69581 .29464 L F
.588 .308 .459 r
.69581 .29464 m .698 .29282 L .69554 .29378 L F
.768 .978 .915 r
.5048 .40706 m .50277 .40865 L .50373 .40626 L F
.75 .962 .937 r
.50277 .40865 m .50154 .40784 L .50373 .40626 L F
0 0 0 r
.52527 .42329 m .5262 .42177 L .52823 .4205 L F
.581 .372 .562 r
.72637 .31274 m .7229 .31462 L .72356 .31344 L F
.854 .541 .459 r
.35625 .51252 m .35759 .51571 L .35989 .5159 L F
.796 .385 .272 r
.35759 .51571 m .35799 .51753 L .35989 .5159 L F
.899 .554 .383 r
.35799 .51753 m .36099 .51895 L .35989 .5159 L F
.554 .355 .565 r
.65322 .33623 m .65037 .33918 L .65111 .33792 L F
.083 .372 .837 r
.22911 .57494 m .23183 .57677 L .23173 .57434 L F
.905 .984 .77 r
.33465 .51077 m .33301 .51261 L .33299 .51086 L F
.855 .997 .808 r
.33465 .51077 m .33526 .50792 L .33654 .50912 L F
.33465 .51077 m .33299 .51086 L .33526 .50792 L F
.911 .925 .811 r
.51693 .39822 m .5191 .39261 L .51987 .39477 L F
.51693 .39822 m .51568 .39689 L .5191 .39261 L F
.867 .773 .756 r
.43308 .58337 m .4327 .58758 L .43128 .58416 L F
.812 .383 .226 r
.62627 .39758 m .62989 .39888 L .62817 .39971 L F
.698 .212 .09 r
.62989 .39888 m .6311 .3998 L .62817 .39971 L F
0 .46 .814 r
.59574 .44606 m .59952 .44769 L .59829 .44686 L F
.164 .263 .721 r
.59952 .44769 m .60136 .44566 L .59829 .44686 L F
.59952 .44769 m .60205 .44961 L .60136 .44566 L F
.916 .926 .805 r
.35112 .58801 m .34962 .58735 L .35205 .58361 L F
0 0 .196 r
.32584 .56811 m .3253 .57059 L .3234 .57186 L F
.541 .464 .717 r
.32257 .57362 m .32488 .57099 L .3234 .57186 L F
0 0 0 r
.3253 .57059 m .32257 .57362 L .3234 .57186 L F
.583 .651 .883 r
.48451 .45063 m .48861 .45241 L .48673 .45087 L F
.457 .744 .99 r
.48673 .45087 m .48861 .45241 L .4914 .45203 L F
.147 .536 .922 r
.41618 .52444 m .41819 .52643 L .41603 .52577 L F
.494 .751 .986 r
.28531 .64483 m .28546 .64249 L .28306 .6427 L F
.399 .681 .975 r
.28306 .6427 m .28531 .64483 L .28755 .64447 L F
0 0 0 r
.52216 .43808 m .52455 .43613 L .52433 .43886 L F
.037 0 .132 r
.52516 .43689 m .52455 .43613 L .52573 .43584 L F
.52528 .43682 m .52573 .43584 L .5259 .4358 L F
.52438 .43831 m .52573 .43584 L .52528 .43682 L F
.523 .542 .817 r
.52288 .43243 m .5253 .43678 L .52697 .43553 L F
.5253 .43678 m .52533 .43683 L .52697 .43553 L F
.037 0 .132 r
.52438 .43831 m .52445 .43742 L .52516 .43689 L F
.52445 .43742 m .52455 .43613 L .52516 .43689 L F
.837 .585 .558 r
.52433 .43886 m .52533 .43683 L .52528 .43682 L F
.52433 .43886 m .52528 .43682 L .52094 .436 L F
.835 .664 .669 r
.52094 .436 m .52528 .43682 L .52288 .43243 L F
.52528 .43682 m .52533 .43683 L .5253 .43678 L F
.52528 .43682 m .5253 .43678 L .52288 .43243 L F
0 0 .088 r
.52433 .43886 m .52533 .43683 L .52697 .43553 L F
.037 0 .132 r
.52433 .43886 m .52438 .43831 L .52697 .43553 L F
.52438 .43831 m .5259 .4358 L .52697 .43553 L F
.83 .783 .808 r
.72767 .31674 m .724 .31623 L .72746 .31494 L F
.909 .817 .745 r
.7291 .32328 m .72859 .31829 L .72709 .32182 L F
.966 .721 .285 r
.46656 .57389 m .46742 .57493 L .4675 .57775 L F
.999 .818 .481 r
.45069 .45819 m .45096 .45648 L .45138 .45913 L F
.45069 .45819 m .45138 .45913 L .45143 .45946 L F
.472 .268 .522 r
.45117 .45333 m .45359 .45316 L .45096 .45648 L F
.678 .442 .556 r
.44759 .45408 m .45117 .45333 L .45096 .45648 L F
.44759 .45408 m .45096 .45648 L .44735 .45673 L F
.718 .495 .586 r
.44735 .45673 m .45096 .45648 L .45069 .45819 L F
.771 .816 .888 r
.45069 .45819 m .45161 .45444 L .44966 .45676 L F
.45069 .45819 m .44966 .45676 L .44909 .45743 L F
.737 .782 .889 r
.4522 .46013 m .45356 .45578 L .45069 .45819 L F
.4522 .46013 m .4558 .45772 L .45356 .45578 L F
.999 .818 .481 r
.45069 .45819 m .45143 .45946 L .4522 .46013 L F
0 .379 .823 r
.25241 .55284 m .25183 .55349 L .24953 .55221 L F
.25241 .55284 m .25384 .55434 L .25183 .55349 L F
.829 .636 .643 r
.33953 .53206 m .338 .53243 L .33855 .52948 L F
.533 .055 .066 r
.33953 .53206 m .34047 .53394 L .338 .53243 L F
0 0 .302 r
.34229 .52959 m .34047 .53394 L .33953 .53206 L F
.701 .951 .674 r
.63452 .40752 m .63593 .4052 L .63419 .4072 L F
.63452 .40752 m .63742 .40442 L .63593 .4052 L F
.729 .74 .86 r
.61504 .41338 m .61618 .41545 L .61293 .41486 L F
.53 .563 .833 r
.61789 .41111 m .61618 .41545 L .61504 .41338 L F
.61789 .41111 m .61856 .41426 L .61618 .41545 L F
.495 .473 .762 r
.61856 .41426 m .61954 .41609 L .61618 .41545 L F
.6 .824 .986 r
.33785 .5182 m .33972 .51971 L .34216 .51885 L F
.556 .789 .986 r
.421 .54857 m .42429 .54885 L .42277 .54772 L F
.986 .744 .481 r
.42277 .54772 m .42429 .54885 L .42233 .55023 L F
.935 .734 .607 r
.68649 .32984 m .68471 .33149 L .68446 .3289 L F
.68649 .32984 m .68612 .33247 L .68471 .33149 L F
.723 .248 .121 r
.39401 .48724 m .39592 .48565 L .39251 .48551 L F
0 0 0 r
.39746 .48511 m .3996 .48379 L .39679 .48521 L F
.40002 .48402 m .3996 .48379 L .39746 .48511 L F
.39826 .48514 m .40002 .48402 L .39964 .48418 L F
.39826 .48514 m .39964 .48418 L .39746 .48511 L F
.39804 .48503 m .39746 .48511 L .3953 .48356 L F
.39826 .48514 m .39746 .48511 L .39804 .48503 L F
0 .322 .767 r
.39764 .48435 m .39826 .48514 L .3953 .48356 L F
.82 .803 .835 r
.3973 .48992 m .39826 .48514 L .39542 .48668 L F
0 0 0 r
.39542 .48668 m .39826 .48514 L .39656 .48666 L F
.683 .953 .953 r
.39908 .48327 m .39826 .48514 L .39764 .48435 L F
0 0 0 r
.39542 .48668 m .39826 .48514 L .39656 .48666 L F
.745 .941 .611 r
.39707 .48597 m .39826 .48514 L .39908 .48327 L F
.39656 .48666 m .39826 .48514 L .39707 .48597 L F
0 0 0 r
.39746 .48511 m .39679 .48521 L .39592 .48565 L F
.39746 .48511 m .39592 .48565 L .39401 .48724 L F
.175 0 .202 r
.54543 .4019 m .54682 .40155 L .54803 .39844 L F
.483 .165 .35 r
.54803 .39844 m .55085 .39969 L .55076 .39762 L F
.54803 .39844 m .54682 .40155 L .55085 .39969 L F
.118 .207 .681 r
.32876 .54065 m .32747 .54247 L .32667 .53863 L F
.232 .368 .796 r
.32876 .54065 m .33025 .5448 L .32747 .54247 L F
.504 .4 .669 r
.32747 .54247 m .33025 .5448 L .32764 .54557 L F
.572 .445 .669 r
.51823 .48006 m .52098 .4796 L .52101 .47676 L F
0 0 .015 r
.51805 .48267 m .52098 .4796 L .51823 .48006 L F
.733 .875 .947 r
.33898 .52731 m .33554 .5279 L .33732 .5271 L F
0 0 .301 r
.33841 .52746 m .33898 .52731 L .33732 .5271 L F
.833 .937 .568 r
.33855 .52948 m .33898 .52731 L .33971 .52712 L F
.33855 .52948 m .33797 .53036 L .33898 .52731 L F
.733 .875 .947 r
.33898 .52731 m .33797 .53036 L .33554 .5279 L F
.745 .516 .584 r
.33898 .52731 m .33889 .53009 L .34229 .52959 L F
0 0 .301 r
.34005 .52799 m .33889 .53009 L .33898 .52731 L F
.34005 .52799 m .33898 .52731 L .33841 .52746 L F
.833 .937 .568 r
.33971 .52712 m .33898 .52731 L .34067 .52517 L F
.755 .557 .627 r
.35554 .61396 m .35587 .61509 L .35707 .61444 L F
.3552 .61385 m .35534 .61411 L .35554 .61396 L F
.35534 .61411 m .35587 .61509 L .35554 .61396 L F
.35451 .61423 m .35587 .61509 L .3552 .61385 L F
.35265 .61305 m .35451 .61423 L .3552 .61385 L F
.762 .524 .574 r
.3552 .61385 m .35707 .61444 L .35512 .61435 L F
.761 .678 .771 r
.35512 .61435 m .35936 .61359 L .35951 .61152 L F
.35512 .61435 m .35951 .61152 L .35697 .6129 L F
.35512 .61434 m .35697 .6129 L .35918 .61307 L F
.35512 .61435 m .35512 .61434 L .35512 .61434 L F
.35512 .61434 m .35697 .6129 L .35512 .61434 L F
.831 .761 .785 r
.35587 .61509 m .35652 .61669 L .35707 .61444 L F
.764 .691 .782 r
.35707 .61444 m .35652 .61669 L .35936 .61359 L F
.831 .761 .785 r
.35587 .61509 m .35652 .61669 L .35707 .61444 L F
.761 .678 .771 r
.35512 .61435 m .35707 .61444 L .35936 .61359 L F
.762 .524 .574 r
.35432 .61357 m .3552 .61385 L .35512 .61434 L F
.761 .678 .771 r
.35697 .6129 m .35951 .61152 L .35956 .61086 L F
.35697 .6129 m .35956 .61086 L .35953 .61099 L F
.35697 .6129 m .35953 .61099 L .35918 .61307 L F
.68 .823 .952 r
.35345 .61208 m .35512 .61435 L .35918 .61307 L F
0 .18 .695 r
.35719 .61566 m .35666 .61543 L .35345 .61208 L F
.35666 .61543 m .35592 .61511 L .35553 .61463 L F
.35666 .61543 m .35553 .61463 L .35345 .61208 L F
.35592 .61511 m .35587 .61509 L .35576 .61496 L F
.35592 .61511 m .35576 .61496 L .35345 .61208 L F
.762 .524 .574 r
.35265 .61305 m .35432 .61357 L .35512 .61435 L F
.35432 .61357 m .35512 .61434 L .35512 .61435 L F
0 0 .216 r
.35956 .61086 m .35936 .61359 L .3604 .61208 L F
.35956 .61086 m .3604 .61208 L .35918 .61307 L F
.689 .908 .972 r
.43214 .55326 m .43322 .55509 L .43389 .55451 L F
.922 .603 .133 r
.43232 .55564 m .43322 .55509 L .43214 .55326 L F
.43232 .55564 m .43336 .55736 L .43322 .55509 L F
.43 .83 .98 r
.32431 .51798 m .32526 .51679 L .32685 .51747 L F
.32685 .51747 m .32526 .51679 L .32431 .51798 L F
.989 .758 .497 r
.32526 .51679 m .32522 .51747 L .32685 .51747 L F
.25 .763 .825 r
.32435 .51798 m .32685 .51747 L .32849 .51746 L F
.32431 .51798 m .32685 .51747 L .32435 .51798 L F
.289 .788 .843 r
.32965 .51732 m .32878 .51737 L .32947 .51685 L F
.32878 .51737 m .32685 .51747 L .32947 .51685 L F
.908 .923 .814 r
.33037 .51533 m .33011 .51638 L .32947 .51685 L F
.25 .763 .825 r
.32849 .51746 m .32685 .51747 L .32965 .51732 L F
.308 .246 .622 r
.32965 .51732 m .33183 .5169 L .33096 .51576 L F
.289 .788 .843 r
.32965 .51732 m .32947 .51685 L .33183 .5169 L F
.493 .28 .518 r
.32947 .51685 m .32921 .51815 L .33183 .5169 L F
.32921 .51815 m .32875 .52045 L .33111 .51773 L F
.32921 .51815 m .33111 .51773 L .33183 .5169 L F
.628 .635 .838 r
.32431 .51798 m .32604 .52189 L .32875 .52045 L F
.32431 .51798 m .32875 .52045 L .32685 .51747 L F
.493 .28 .518 r
.32947 .51685 m .32685 .51747 L .32875 .52045 L F
.672 .234 .202 r
.32929 .51977 m .32512 .51945 L .32554 .51897 L F
.32788 .51845 m .32554 .51897 L .32685 .51747 L F
.32929 .51977 m .32554 .51897 L .32788 .51845 L F
.908 .923 .814 r
.33011 .51638 m .32929 .51977 L .32947 .51685 L F
.493 .28 .518 r
.32947 .51685 m .32947 .51693 L .32685 .51747 L F
.32947 .51693 m .32929 .51977 L .32685 .51747 L F
.989 .758 .497 r
.32522 .51747 m .32512 .51945 L .32685 .51747 L F
.957 .629 .353 r
.5807 .42286 m .58218 .42113 L .57952 .41956 L F
.5807 .42286 m .58277 .42435 L .58218 .42113 L F
0 0 .399 r
.72415 .28386 m .72484 .28676 L .72449 .28344 L F
0 .058 .604 r
.72317 .28072 m .72449 .28344 L .72415 .28386 L F
.447 .332 .63 r
.72449 .28344 m .72484 .28676 L .72415 .28386 L F
.976 .718 .476 r
.7223 .28422 m .72484 .28676 L .72449 .28344 L F
.447 .332 .63 r
.72449 .28344 m .72619 .28505 L .72484 .28676 L F
.976 .718 .476 r
.72449 .28344 m .72484 .28676 L .7223 .28422 L F
.725 .228 .055 r
.7223 .28422 m .72562 .28493 L .72449 .28344 L F
.72562 .28493 m .72619 .28505 L .72449 .28344 L F
0 .058 .604 r
.7237 .28242 m .72449 .28344 L .72317 .28072 L F
.72415 .28386 m .72449 .28344 L .7237 .28242 L F
.465 .885 .92 r
.34067 .52517 m .34217 .52405 L .34291 .52449 L F
.712 .766 .895 r
.34445 .52429 m .34067 .52517 L .34291 .52449 L F
.416 0 .025 r
.34067 .52517 m .34198 .5269 L .34217 .52405 L F
.34067 .52517 m .33898 .52731 L .34198 .5269 L F
.642 .965 .829 r
.62693 .38762 m .62482 .38929 L .62286 .38972 L F
0 .378 .794 r
.60205 .44961 m .60357 .45089 L .60601 .45184 L F
.771 .983 .73 r
.53148 .49589 m .53257 .49362 L .53118 .49581 L F
.53148 .49589 m .53441 .49265 L .53257 .49362 L F
.681 .776 .923 r
.31648 .60577 m .31791 .60759 L .3142 .60662 L F
.765 .336 .232 r
.31791 .60759 m .316 .60929 L .3142 .60662 L F
.496 .693 .956 r
.31951 .60684 m .31791 .60759 L .31648 .60577 L F
.243 0 0 r
.31951 .60684 m .316 .60929 L .31791 .60759 L F
.803 .903 .498 r
.69843 .36335 m .69938 .3624 L .69912 .36107 L F
.971 .654 .308 r
.69791 .35699 m .69914 .35588 L .69795 .35449 L F
.69791 .35699 m .69951 .35857 L .69914 .35588 L F
.174 0 .145 r
.4965 .50881 m .49882 .50783 L .49943 .50502 L F
.021 0 .028 r
.49943 .50502 m .50154 .50477 L .50237 .50235 L F
.031 0 .102 r
.49943 .50502 m .49882 .50783 L .50154 .50477 L F
0 0 0 r
.32203 .61744 m .32429 .61581 L .3259 .61381 L F
.654 .497 .659 r
.32594 .60887 m .3264 .61417 L .32859 .61164 L F
.64 .079 0 r
.32859 .61164 m .32658 .61106 L .32638 .61086 L F
0 0 .204 r
.3259 .61381 m .32622 .61404 L .32603 .60993 L F
.32622 .61404 m .3264 .61417 L .32635 .61357 L F
.32622 .61404 m .32635 .61357 L .32603 .60993 L F
.3259 .61381 m .32603 .60993 L .32594 .60967 L F
.687 .969 .76 r
.32648 .61305 m .32462 .61484 L .32484 .61416 L F
.32859 .61164 m .32639 .61341 L .32648 .61305 L F
.32639 .61341 m .32462 .61484 L .32648 .61305 L F
.64 .079 0 r
.32612 .61017 m .32638 .61086 L .32505 .60954 L F
.32859 .61164 m .32638 .61086 L .32612 .61017 L F
0 0 .204 r
.32594 .60967 m .32603 .60993 L .32594 .60887 L F
.777 .904 .507 r
.3259 .61381 m .32462 .61484 L .3264 .61417 L F
.3259 .61381 m .32429 .61581 L .32462 .61484 L F
.568 .076 .048 r
.30701 .62912 m .30886 .62774 L .30542 .62749 L F
.78 .719 .795 r
.32884 .53239 m .32485 .5321 L .32702 .52983 L F
.695 .67 .821 r
.32802 .53346 m .32485 .5321 L .32717 .53422 L F
.695 .258 .209 r
.32884 .53239 m .32717 .53422 L .32485 .5321 L F
.428 0 .023 r
.33166 .53297 m .32884 .53239 L .33179 .53251 L F
.907 .658 .55 r
.56069 .40346 m .56172 .40001 L .56263 .40137 L F
.989 .77 .513 r
.58468 .43259 m .58645 .43117 L .58472 .42994 L F
.58468 .43259 m .58618 .43393 L .58645 .43117 L F
.18 .109 .534 r
.42832 .56847 m .42928 .57161 L .42954 .57064 L F
.781 .722 .798 r
.61609 .40014 m .61344 .40507 L .6124 .40021 L F
.375 0 0 r
.41497 .51557 m .41956 .5153 L .41706 .51625 L F
.896 .727 .664 r
.31608 .62293 m .31935 .62443 L .31799 .62673 L F
.173 .263 .717 r
.34514 .54556 m .34648 .54378 L .34331 .54483 L F
.34514 .54556 m .34752 .54756 L .34648 .54378 L F
.864 .988 .837 r
.36835 .62899 m .37221 .62639 L .37136 .62603 L F
.168 0 0 r
.54381 .41084 m .54218 .41211 L .53976 .41252 L F
0 0 0 r
.54573 .40984 m .54218 .41211 L .54381 .41084 L F
.781 .713 .788 r
.34082 .50954 m .33803 .51279 L .33654 .50912 L F
.359 .359 .723 r
.30759 .63739 m .31063 .63973 L .31008 .63766 L F
.626 .576 .778 r
.35019 .60078 m .3475 .60204 L .34583 .59759 L F
.35019 .60078 m .3475 .60204 L .34583 .59759 L F
.28 .136 .499 r
.53522 .47963 m .53743 .47945 L .53731 .47601 L F
.212 0 .135 r
.53426 .48197 m .53743 .47945 L .53522 .47963 L F
.622 .632 .84 r
.52174 .39053 m .51987 .39477 L .5191 .39261 L F
.52174 .39053 m .52301 .39432 L .51987 .39477 L F
.752 .983 .749 r
.51676 .43046 m .5202 .42765 L .51872 .42896 L F
0 0 0 r
.5202 .42765 m .52301 .42468 L .52185 .42628 L F
.51872 .42896 m .5202 .42765 L .52185 .42628 L F
.774 .968 .674 r
.45885 .57781 m .4581 .57927 L .45678 .5798 L F
.888 .466 .076 r
.72229 .28156 m .72317 .28072 L .72204 .27918 L F
.72229 .28156 m .72449 .28344 L .72317 .28072 L F
.72229 .28156 m .72317 .28072 L .72204 .27918 L F
.72229 .28156 m .72449 .28344 L .72317 .28072 L F
.992 .875 .602 r
.58131 .40326 m .5831 .40182 L .58137 .4007 L F
.58131 .40326 m .58235 .40447 L .5831 .40182 L F
.79 .971 .674 r
.49057 .51769 m .49034 .51905 L .48801 .52102 L F
.11 .579 .914 r
.48295 .44951 m .48451 .45063 L .48673 .45087 L F
.642 .578 .767 r
.43664 .57747 m .43409 .58127 L .43391 .5782 L F
.43664 .57747 m .43813 .58247 L .43409 .58127 L F
.719 .573 .69 r
.43813 .58247 m .43308 .58337 L .43409 .58127 L F
.952 .702 .522 r
.59899 .39699 m .60152 .39498 L .60032 .39368 L F
.59899 .39699 m .60189 .39845 L .60152 .39498 L F
.82 .94 .906 r
.60032 .39368 m .60152 .39498 L .60439 .39244 L F
.753 .401 .386 r
.60552 .39782 m .60152 .39498 L .60189 .39845 L F
.78 .634 .7 r
.53731 .47601 m .54097 .47698 L .54141 .47404 L F
.995 .862 .581 r
.53985 .47542 m .54097 .47698 L .54141 .47404 L F
.918 .569 .36 r
.42961 .54999 m .43172 .54826 L .42996 .54723 L F
.42961 .54999 m .43097 .55097 L .43172 .54826 L F
.812 .723 .767 r
.70062 .28932 m .698 .29282 L .70172 .29339 L F
.847 .521 .436 r
.69868 .29468 m .70172 .29339 L .698 .29282 L F
.69868 .29468 m .70207 .29603 L .70172 .29339 L F
.548 .589 .847 r
.70172 .29339 m .70339 .2889 L .70062 .28932 L F
.70172 .29339 m .70473 .29261 L .70339 .2889 L F
.528 .337 .566 r
.70207 .29603 m .70473 .29261 L .70172 .29339 L F
.697 .605 .749 r
.25485 .58445 m .25939 .58737 L .25716 .58395 L F
0 0 .01 r
.5326 .46977 m .53224 .47226 L .52954 .47388 L F
0 0 0 r
.52976 .47362 m .52954 .47388 L .53224 .47226 L F
.52976 .47362 m .52869 .47489 L .52954 .47388 L F
.634 .717 .907 r
.29563 .64877 m .29665 .64494 L .29445 .64563 L F
.29563 .64877 m .29957 .6476 L .29665 .64494 L F
.638 .958 .924 r
.45509 .43796 m .45408 .43968 L .45334 .43942 L F
.45509 .43796 m .45762 .4378 L .45408 .43968 L F
0 .577 .719 r
.31519 .57512 m .31336 .57512 L .3175 .5752 L F
.422 0 0 r
.3201 .57535 m .31519 .57512 L .3175 .5752 L F
.486 .053 .141 r
.3211 .57487 m .3201 .57535 L .3175 .5752 L F
.979 .686 .326 r
.39983 .54924 m .39841 .55009 L .39824 .54746 L F
.872 .433 .13 r
.40034 .55096 m .39841 .55009 L .39983 .54924 L F
.626 .96 .837 r
.53441 .49265 m .53771 .49058 L .53565 .49102 L F
.624 .938 .715 r
.53257 .49362 m .53441 .49265 L .53565 .49102 L F
.822 .779 .812 r
.56439 .41219 m .56063 .41245 L .56296 .41 L F
0 0 0 r
.49471 .5372 m .49229 .54068 L .49293 .53858 L F
.667 .952 .711 r
.63742 .40442 m .64052 .40154 L .63878 .40243 L F
.662 .94 .676 r
.63593 .4052 m .63742 .40442 L .63878 .40243 L F
.536 .017 0 r
.4254 .56369 m .42333 .56256 L .42716 .5617 L F
.815 .5 .457 r
.42716 .5617 m .42768 .56448 L .4254 .56369 L F
.854 .862 .846 r
.33266 .50312 m .32964 .50363 L .32947 .50256 L F
.666 .881 .978 r
.34445 .52429 m .34626 .52283 L .34671 .52323 L F
.34445 .52429 m .34291 .52449 L .34626 .52283 L F
.466 .807 .999 r
.41956 .5153 m .42242 .51455 L .42357 .51589 L F
.992 .801 .422 r
.42242 .51455 m .42218 .51735 L .42357 .51589 L F
.814 .989 .879 r
.47455 .5914 m .47484 .58912 L .47129 .59195 L F
.733 .74 .857 r
.30027 .53381 m .29864 .53561 L .30227 .53588 L F
0 0 .236 r
.42784 .54367 m .42684 .54543 L .42739 .54221 L F
.139 .344 .805 r
.42784 .54367 m .42996 .54723 L .42684 .54543 L F
.791 .642 .084 r
.45318 .50176 m .45316 .50059 L .45335 .49951 L F
0 0 0 r
.62043 .37669 m .62416 .37594 L .62128 .37639 L F
.22 .675 .949 r
.46821 .53547 m .46648 .53135 L .46453 .53207 L F
.46821 .53547 m .46416 .53404 L .46648 .53135 L F
.46821 .53547 m .46859 .53521 L .46416 .53404 L F
.303 0 .245 r
.24852 .5453 m .24567 .54787 L .24647 .5458 L F
0 0 0 r
.49724 .53382 m .49471 .5372 L .49544 .53509 L F
.482 .264 .506 r
.24147 .60099 m .24366 .60317 L .24404 .60045 L F
.24404 .60045 m .24366 .60317 L .24147 .60099 L F
.791 .642 .084 r
.45318 .50176 m .45301 .50083 L .45316 .50059 L F
0 0 .285 r
.45318 .50176 m .45431 .50496 L .45301 .50083 L F
.822 .723 .756 r
.73064 .29931 m .73406 .30023 L .73287 .2962 L F
.832 .701 .718 r
.73226 .30342 m .73406 .30023 L .73064 .29931 L F
0 0 0 r
.39924 .49129 m .39815 .49166 L .40117 .49028 L F
.39924 .49129 m .39755 .49336 L .39815 .49166 L F
.928 .771 .667 r
.34189 .59427 m .34054 .59705 L .34297 .59739 L F
.91 .595 .438 r
.34054 .59705 m .34139 .59963 L .34297 .59739 L F
.776 .398 .34 r
.34297 .59739 m .34561 .59992 L .34583 .59759 L F
.34297 .59739 m .34139 .59963 L .34561 .59992 L F
.69 .865 .965 r
.40984 .48249 m .41002 .48362 L .41224 .48232 L F
.40984 .48249 m .41002 .48362 L .41224 .48232 L F
.55 .321 .521 r
.57174 .43765 m .57145 .44025 L .57026 .44032 L F
.083 0 .193 r
.22805 .5611 m .23093 .55722 L .22874 .55843 L F
.658 .594 .772 r
.36207 .60752 m .35777 .60408 L .36016 .60356 L F
.51 .566 .848 r
.36391 .60643 m .36207 .60752 L .36016 .60356 L F
.449 .202 .447 r
.36064 .60099 m .36016 .60356 L .35777 .60408 L F
.186 .55 .931 r
.36297 .60212 m .36369 .60187 L .36064 .60099 L F
.374 .137 .421 r
.36283 .60241 m .36064 .60099 L .36369 .60187 L F
.36283 .60241 m .36016 .60356 L .36064 .60099 L F
.963 .92 .714 r
.5326 .46977 m .53286 .46481 L .53363 .46818 L F
0 0 0 r
.53334 .46992 m .5326 .46977 L .53363 .46818 L F
.53334 .46992 m .53224 .47226 L .5326 .46977 L F
.788 .307 .081 r
.34622 .50492 m .34811 .50749 L .34978 .50657 L F
.786 .304 .079 r
.34978 .50657 m .34811 .50749 L .35025 .50809 L F
.369 .82 .94 r
.43821 .59807 m .43672 .59775 L .43445 .59812 L F
.209 0 0 r
.43882 .59835 m .43821 .59807 L .44115 .59774 L F
.43882 .59835 m .43672 .59775 L .43821 .59807 L F
.788 .63 .686 r
.45572 .49992 m .45697 .49639 L .45285 .49584 L F
.385 .045 .262 r
.59155 .3649 m .59466 .36434 L .59441 .36291 L F
.912 .759 .679 r
.582 .40745 m .58051 .41047 L .58344 .41065 L F
.894 .833 .779 r
.58051 .41047 m .58155 .41398 L .58344 .41065 L F
.006 0 0 r
.61023 .38701 m .61218 .38679 L .60853 .38729 L F
.902 .554 .374 r
.43324 .56963 m .43499 .56836 L .43319 .56749 L F
.43324 .56963 m .43539 .57079 L .43499 .56836 L F
.06 .535 .893 r
.33884 .49687 m .3376 .49751 L .33597 .49676 L F
.33884 .49687 m .34052 .49812 L .3376 .49751 L F
.297 0 0 r
.32127 .56727 m .32553 .56485 L .32131 .56532 L F
.32127 .56727 m .32342 .56703 L .32553 .56485 L F
.367 .219 .544 r
.3278 .56429 m .32584 .56811 L .32553 .56485 L F
.754 .525 .584 r
.32342 .56703 m .3278 .56429 L .32553 .56485 L F
0 0 0 r
.47813 .57803 m .47793 .58002 L .47631 .58129 L F
0 0 .214 r
.47705 .58259 m .47631 .58129 L .47793 .58002 L F
.47705 .58259 m .47643 .58433 L .47631 .58129 L F
.568 .076 .048 r
.30701 .62912 m .30542 .62749 L .30441 .62965 L F
.45 .207 .454 r
.32961 .58471 m .32941 .58721 L .32695 .58779 L F
.526 .815 .998 r
.32537 .58398 m .32639 .58416 L .32816 .58338 L F
.32639 .58416 m .32961 .58471 L .32816 .58338 L F
.99 .728 .394 r
.32961 .58471 m .32941 .58721 L .32816 .58338 L F
.61 .164 .168 r
.32961 .58471 m .3319 .58667 L .32941 .58721 L F
.799 .533 .536 r
.3319 .58667 m .32816 .58338 L .32941 .58721 L F
.3319 .58667 m .32794 .58638 L .32816 .58338 L F
0 0 .064 r
.32816 .58338 m .32844 .58476 L .33022 .58247 L F
.32816 .58338 m .33022 .58247 L .33022 .58246 L F
.977 .851 .456 r
.69955 .34866 m .70015 .34607 L .69896 .34721 L F
.97 .862 .465 r
.69896 .34721 m .70015 .34607 L .69959 .34472 L F
.82 .952 .905 r
.67559 .36161 m .6718 .36306 L .6749 .36081 L F
.962 .929 .599 r
.67719 .35664 m .67559 .36161 L .6749 .36081 L F
.834 .902 .887 r
.6242 .3781 m .62481 .38058 L .62624 .37936 L F
.011 0 0 r
.30173 .58198 m .30473 .58086 L .30445 .58131 L F
.672 .804 .352 r
.30445 .58131 m .30473 .58086 L .30593 .57819 L F
.676 .878 .974 r
.31705 .65548 m .32089 .65532 L .31953 .65309 L F
.662 .789 .942 r
.31953 .65309 m .32089 .65532 L .32376 .65362 L F
.885 .882 .825 r
.55975 .37563 m .5569 .37949 L .55569 .37729 L F
.266 .482 .881 r
.5569 .37949 m .55805 .37744 L .55569 .37729 L F
.5569 .37949 m .56035 .38021 L .55805 .37744 L F
.453 .883 .819 r
.61621 .3437 m .61988 .34218 L .62061 .34219 L F
.373 .823 .704 r
.62061 .34219 m .6224 .34116 L .62309 .3409 L F
.392 .85 .815 r
.62061 .34219 m .61988 .34218 L .6224 .34116 L F
0 0 .194 r
.55398 .46695 m .55471 .46825 L .55414 .46534 L F
.977 .912 .667 r
.45096 .58089 m .44912 .58241 L .44724 .58042 L F
.45096 .58089 m .44949 .58492 L .44912 .58241 L F
.369 .125 .407 r
.29702 .64062 m .29497 .64066 L .29483 .64257 L F
.269 .761 .908 r
.41823 .45872 m .41413 .45824 L .41691 .45768 L F
.608 .94 .946 r
.44096 .4454 m .44448 .44389 L .44566 .44432 L F
.692 .981 .881 r
.44566 .44432 m .44667 .44245 L .44742 .44287 L F
.664 .96 .937 r
.44448 .44389 m .44667 .44245 L .44566 .44432 L F
.976 .672 .336 r
.5872 .38822 m .58592 .38943 L .5856 .38702 L F
.5872 .38822 m .58743 .39096 L .58592 .38943 L F
.652 .127 0 r
.53968 .47809 m .54097 .47698 L .53731 .47601 L F
.481 0 0 r
.54354 .47815 m .54097 .47698 L .53968 .47809 L F
.18 .665 .927 r
.60199 .42772 m .59783 .42678 L .60145 .42582 L F
0 0 .307 r
.60305 .42871 m .60199 .42772 L .60145 .42582 L F
.60305 .42871 m .60227 .43028 L .60199 .42772 L F
.978 .906 .67 r
.38679 .58973 m .38767 .59115 L .38905 .58818 L F
.98 .808 .6 r
.38746 .58697 m .38679 .58973 L .38905 .58818 L F
.936 .619 .413 r
.32764 .54557 m .32564 .54604 L .32354 .5445 L F
.32764 .54557 m .32751 .54785 L .32564 .54604 L F
.443 .196 .443 r
.33025 .5448 m .32751 .54785 L .32764 .54557 L F
.536 .017 0 r
.4254 .56369 m .42267 .5638 L .42333 .56256 L F
.966 .819 .646 r
.26273 .62924 m .26512 .62728 L .26296 .6264 L F
.26273 .62924 m .26442 .63036 L .26512 .62728 L F
.775 .661 .738 r
.43813 .58247 m .43859 .58456 L .43597 .58498 L F
.623 .591 .797 r
.44117 .5813 m .43859 .58456 L .43813 .58247 L F
.44117 .5813 m .44164 .58479 L .43859 .58456 L F
.553 .927 .794 r
.53771 .49058 m .53821 .48954 L .53565 .49102 L F
.53771 .49058 m .53982 .48913 L .53821 .48954 L F
.634 .535 .724 r
.30514 .6542 m .30632 .65291 L .30372 .65302 L F
.30514 .6542 m .30766 .65609 L .30632 .65291 L F
.595 .547 .772 r
.30282 .64944 m .30372 .65302 L .30593 .6503 L F
.659 .644 .823 r
.30372 .65302 m .30632 .65291 L .30593 .6503 L F
.773 .973 .919 r
.55982 .47247 m .564 .47084 L .56254 .46926 L F
.784 .869 .911 r
.56254 .46926 m .564 .47084 L .56595 .46918 L F
.541 .882 .987 r
.63751 .38757 m .63362 .3878 L .63632 .38706 L F
.437 .838 .977 r
.63903 .38632 m .63751 .38757 L .63632 .38706 L F
.63903 .38632 m .64013 .38699 L .63751 .38757 L F
.23 0 0 r
.34726 .5726 m .34246 .5738 L .34446 .57395 L F
.54 .531 .794 r
.34446 .57395 m .34721 .57426 L .34726 .5726 L F
.633 .554 .747 r
.34523 .57734 m .34721 .57426 L .34446 .57395 L F
.143 0 0 r
.31412 .56991 m .3182 .56836 L .31598 .56834 L F
.951 .607 .219 r
.40356 .57786 m .40204 .57708 L .40163 .57418 L F
.984 .774 .541 r
.40356 .57786 m .40137 .57959 L .40204 .57708 L F
.40356 .57786 m .40301 .58068 L .40137 .57959 L F
.558 .268 .43 r
.36183 .59114 m .36166 .59397 L .3642 .5933 L F
.3642 .5933 m .36166 .59397 L .36183 .59114 L F
.962 .929 .599 r
.67719 .35664 m .6749 .36081 L .67791 .35784 L F
.834 .902 .887 r
.6242 .3781 m .62624 .37936 L .62693 .37703 L F
.638 .857 .983 r
.40745 .46363 m .41235 .46374 L .41075 .46245 L F
.706 .673 .816 r
.60346 .35712 m .60387 .35933 L .60777 .358 L F
.639 .292 .367 r
.60777 .358 m .60332 .35961 L .60387 .35933 L F
.706 .673 .816 r
.60346 .35712 m .60777 .358 L .60637 .35562 L F
.639 .292 .367 r
.60777 .358 m .60654 .35919 L .60211 .36004 L F
.652 .59 .772 r
.60955 .35705 m .60777 .358 L .60637 .35562 L F
0 0 0 r
.60925 .35753 m .60777 .358 L .60955 .35705 L F
.659 .858 .976 r
.60345 .35743 m .60581 .35877 L .60925 .35753 L F
0 0 0 r
.60925 .35753 m .60654 .35919 L .60777 .358 L F
.659 .858 .976 r
.60581 .35877 m .60654 .35919 L .6089 .35774 L F
.60581 .35877 m .6089 .35774 L .60925 .35753 L F
.639 .292 .367 r
.60332 .35961 m .60211 .36004 L .60255 .35986 L F
.60332 .35961 m .60255 .35986 L .60387 .35933 L F
.308 .066 .375 r
.69206 .29877 m .69581 .29464 L .69251 .29689 L F
.589 .927 .723 r
.26719 .51747 m .26461 .51944 L .2657 .51817 L F
.581 .942 .904 r
.26461 .51944 m .26288 .51944 L .2657 .51817 L F
.892 .471 .17 r
.35411 .5116 m .35759 .51571 L .35625 .51252 L F
.614 .79 .356 r
.47912 .57632 m .47813 .57803 L .4802 .57446 L F
0 0 0 r
.47806 .57891 m .47813 .57803 L .47912 .57632 L F
.47806 .57891 m .47793 .58002 L .47813 .57803 L F
.372 .601 .936 r
.53246 .43744 m .53624 .43969 L .53511 .43665 L F
.78 .709 .785 r
.53511 .43665 m .53624 .43969 L .53777 .43736 L F
.833 .778 .8 r
.45356 .45578 m .45849 .45609 L .45616 .45247 L F
.83 .784 .808 r
.4558 .45772 m .45849 .45609 L .45356 .45578 L F
.76 .759 .851 r
.45616 .45247 m .45849 .45609 L .46026 .45284 L F
.972 .768 .57 r
.72932 .31197 m .73053 .31594 L .7311 .31347 L F
.65 .59 .774 r
.52906 .45345 m .53259 .45388 L .53127 .44987 L F
.929 .748 .637 r
.46794 .53866 m .46996 .53814 L .46859 .53521 L F
0 0 0 r
.46624 .54185 m .46784 .53982 L .46766 .53956 L F
.465 0 0 r
.47067 .5392 m .46996 .53814 L .46808 .53862 L F
.47067 .5392 m .46808 .53862 L .46806 .53868 L F
.46806 .53868 m .46808 .53862 L .46794 .53866 L F
0 .493 .806 r
.46892 .53845 m .47067 .5392 L .46794 .53866 L F
0 0 0 r
.46784 .53982 m .46892 .53845 L .46794 .53932 L F
.46784 .53982 m .46794 .53932 L .46766 .53956 L F
.465 0 0 r
.47067 .5392 m .47469 .54048 L .46996 .53814 L F
.627 .236 .283 r
.34297 .58408 m .3386 .58664 L .34026 .58433 L F
.34297 .58408 m .34521 .5869 L .3386 .58664 L F
.332 .626 .958 r
.34297 .58408 m .34648 .58528 L .34583 .58509 L F
.866 .469 .283 r
.35025 .50809 m .35411 .5116 L .35362 .50976 L F
.459 .865 .96 r
.43524 .57696 m .43664 .57747 L .43391 .5782 L F
.85 .555 .489 r
.56296 .41 m .55985 .40595 L .56021 .40807 L F
.885 .882 .825 r
.55975 .37563 m .55569 .37729 L .55843 .37398 L F
.348 .466 .838 r
.56127 .37284 m .55975 .37563 L .55843 .37398 L F
.56127 .37284 m .56124 .37546 L .55975 .37563 L F
.653 .892 .982 r
.57832 .41368 m .58155 .41398 L .58051 .41047 L F
.934 .772 .657 r
.38455 .5669 m .38724 .5652 L .38441 .56439 L F
.38455 .5669 m .38647 .56789 L .38724 .5652 L F
.788 .63 .686 r
.45572 .49992 m .45285 .49584 L .45316 .50059 L F
.731 .32 .268 r
.45301 .50083 m .45572 .49992 L .45316 .50059 L F
.763 .842 .388 r
.48073 .57258 m .47912 .57632 L .4802 .57446 L F
.353 .471 .84 r
.52165 .4422 m .52023 .44493 L .51994 .44469 L F
.52165 .4422 m .52366 .44601 L .52023 .44493 L F
.76 .955 .643 r
.52165 .4422 m .52023 .44493 L .51994 .44469 L F
.67 .579 .745 r
.37488 .4725 m .37474 .46884 L .37625 .47017 L F
0 0 .499 r
.37474 .46884 m .37488 .4725 L .37625 .47017 L F
.813 .493 0 r
.57833 .39236 m .57848 .39141 L .57848 .38988 L F
.57833 .39236 m .57927 .39419 L .57848 .39141 L F
.708 .748 .883 r
.51787 .45023 m .52198 .45126 L .52101 .44925 L F
0 0 0 r
.52198 .45126 m .52298 .44866 L .52101 .44925 L F
.52198 .45126 m .52312 .45138 L .52298 .44866 L F
.57 .42 .638 r
.23771 .56123 m .2404 .56574 L .23602 .56421 L F
.383 .099 .354 r
.23723 .56481 m .23602 .56421 L .2404 .56574 L F
.23723 .56481 m .23569 .56698 L .23602 .56421 L F
.573 .375 .575 r
.72764 .30043 m .73064 .29931 L .72725 .29978 L F
.713 .578 .702 r
.28016 .58253 m .28383 .57999 L .2812 .58104 L F
.369 0 0 r
.25365 .54328 m .25051 .54602 L .25175 .54425 L F
.25365 .54328 m .25285 .54592 L .25051 .54602 L F
.494 .866 .647 r
.62907 .34929 m .62595 .35132 L .62711 .34738 L F
.62907 .34929 m .62721 .35035 L .62595 .35132 L F
.136 0 0 r
.63037 .34935 m .62907 .34929 L .63208 .34893 L F
.63037 .34935 m .62721 .35035 L .62907 .34929 L F
.757 .681 .777 r
.72475 .28999 m .72633 .29375 L .72932 .29073 L F
.106 .406 .857 r
.59692 .38066 m .59463 .37863 L .5973 .37789 L F
.327 0 0 r
.60496 .35165 m .60107 .35212 L .60257 .35202 L F
.60496 .35165 m .60359 .35269 L .60107 .35212 L F
.859 .466 .296 r
.60359 .35269 m .60321 .35233 L .60107 .35212 L F
.461 .211 .448 r
.60107 .35212 m .59932 .35195 L .60257 .35202 L F
.859 .466 .296 r
.60321 .35233 m .59982 .34919 L .60107 .35212 L F
.461 .211 .448 r
.60107 .35212 m .59821 .35192 L .59932 .35195 L F
.208 0 .298 r
.31224 .54659 m .3108 .54535 L .31433 .54534 L F
.091 0 0 r
.3108 .54535 m .31321 .54546 L .31433 .54534 L F
0 0 0 r
.31321 .54546 m .31695 .54202 L .31433 .54534 L F
.49 .291 .537 r
.31695 .54202 m .31685 .54494 L .31433 .54534 L F
.465 .854 .648 r
.31533 .54445 m .31433 .54534 L .31685 .54494 L F
.31533 .54445 m .31224 .54659 L .31433 .54534 L F
.364 .835 .858 r
.40767 .45461 m .40721 .45537 L .40369 .45484 L F
.40767 .45461 m .40915 .45475 L .40721 .45537 L F
.439 0 0 r
.52153 .40976 m .52493 .4098 L .52247 .40893 L F
0 0 .085 r
.55589 .46163 m .55607 .46342 L .55609 .46335 L F
.702 .696 .841 r
.55864 .461 m .55574 .46036 L .55589 .46163 L F
.791 .991 .883 r
.55953 .45872 m .55864 .461 L .55589 .46163 L F
.827 .899 .891 r
.55809 .4574 m .55798 .45761 L .55713 .45895 L F
.55798 .45761 m .55589 .46163 L .55713 .45895 L F
.55809 .4574 m .55953 .45872 L .55589 .46163 L F
0 0 .085 r
.55589 .46163 m .55609 .46335 L .55713 .45895 L F
.702 .696 .841 r
.55574 .46036 m .55421 .46002 L .55589 .46163 L F
.377 .209 .523 r
.55589 .46163 m .55414 .46534 L .55607 .46342 L F
.974 .85 .657 r
.55713 .45895 m .55607 .46342 L .55487 .46247 L F
.55713 .45895 m .55487 .46247 L .55444 .46212 L F
.638 .749 .929 r
.4643 .45317 m .46578 .44965 L .46277 .4517 L F
.4643 .45317 m .46721 .45239 L .46578 .44965 L F
.73 .552 .65 r
.34874 .52106 m .34442 .51805 L .34653 .51863 L F
.837 .683 .692 r
.71547 .27441 m .71516 .27683 L .71364 .27278 L F
.819 .675 .704 r
.71364 .27278 m .71516 .27683 L .71716 .27417 L F
0 .366 .833 r
.32648 .60247 m .32792 .60256 L .3249 .6009 L F
.3279 .60268 m .32792 .60256 L .32648 .60247 L F
.97 .76 .329 r
.32855 .60519 m .32792 .60256 L .32768 .60366 L F
.32855 .60519 m .32777 .60531 L .32792 .60256 L F
.32792 .60256 m .32777 .60531 L .32855 .60519 L F
.791 .541 .558 r
.32957 .60314 m .32777 .60531 L .32792 .60256 L F
0 .366 .833 r
.32768 .60366 m .3279 .60268 L .32648 .60247 L F
.881 .623 .544 r
.32792 .60256 m .32777 .60531 L .32585 .60199 L F
.32585 .60199 m .32777 .60531 L .32792 .60256 L F
.32638 .60216 m .32792 .60256 L .32957 .60314 L F
.32585 .60199 m .32633 .60212 L .32638 .60216 L F
.32633 .60212 m .32792 .60256 L .32638 .60216 L F
.726 .7 .826 r
.32855 .60519 m .32639 .60727 L .33063 .60651 L F
.602 .23 .308 r
.32594 .60887 m .33063 .60651 L .32639 .60727 L F
.32594 .60887 m .32909 .60911 L .33063 .60651 L F
.647 .604 .792 r
.33063 .60651 m .33247 .60285 L .32855 .60519 L F
.364 0 .036 r
.32909 .60911 m .33327 .60667 L .33063 .60651 L F
.003 .168 .683 r
.32817 .60336 m .32826 .60355 L .32806 .60428 L F
.328 .6042 m .32806 .60428 L .32777 .60531 L F
.32817 .60336 m .32806 .60428 L .328 .6042 L F
.724 .38 .395 r
.32818 .60445 m .32993 .60681 L .33062 .60702 L F
.53 .513 .781 r
.33027 .60701 m .32998 .60694 L .32993 .60681 L F
.881 .623 .544 r
.32824 .60273 m .32957 .60314 L .32909 .60286 L F
.724 .38 .395 r
.32818 .60445 m .33062 .60702 L .32836 .60243 L F
.003 .168 .683 r
.32826 .60355 m .3298 .60682 L .32808 .60563 L F
.3298 .60682 m .33037 .60803 L .32816 .60572 L F
.3298 .60682 m .32816 .60572 L .32808 .60563 L F
.53 .513 .781 r
.33112 .60753 m .32998 .60694 L .33027 .60701 L F
.046 0 .423 r
.33008 .60701 m .33047 .60707 L .33027 .60701 L F
.003 .168 .683 r
.33014 .60739 m .3301 .60746 L .32817 .60336 L F
.889 .774 .278 r
.32639 .60727 m .32594 .60887 L .32609 .60698 L F
.635 .594 .791 r
.32777 .60531 m .32594 .60887 L .32609 .60698 L F
.32777 .60531 m .32909 .60911 L .32594 .60887 L F
.985 .848 .624 r
.32609 .60698 m .32585 .60199 L .32777 .60531 L F
.32609 .60698 m .32417 .60768 L .32585 .60199 L F
0 .162 .683 r
.32777 .60531 m .33037 .60803 L .32909 .60911 L F
.046 0 .423 r
.32516 .60692 m .33015 .60706 L .33008 .60701 L F
.33015 .60706 m .33047 .60707 L .33008 .60701 L F
.003 .168 .683 r
.32886 .60382 m .32998 .60694 L .32817 .60336 L F
.32998 .60694 m .33014 .60739 L .32989 .60688 L F
.32998 .60694 m .32989 .60688 L .32817 .60336 L F
.33014 .60739 m .33037 .60803 L .3301 .60746 L F
.647 .604 .792 r
.33063 .60651 m .33327 .60667 L .33247 .60285 L F
.881 .623 .544 r
.32824 .60273 m .32909 .60286 L .32836 .60243 L F
.282 .42 .824 r
.33082 .60074 m .33378 .6011 L .33244 .5994 L F
.33082 .60074 m .33247 .60285 L .33378 .6011 L F
.708 .985 .827 r
.33115 .60036 m .32836 .60243 L .32957 .60314 L F
0 0 0 r
.33107 .60311 m .33062 .60702 L .32836 .60243 L F
.53 .513 .781 r
.33184 .60706 m .33112 .60753 L .33067 .60671 L F
0 0 0 r
.33103 .60348 m .33079 .60566 L .33062 .60702 L F
.33079 .60566 m .33065 .6069 L .33065 .6069 L F
.33079 .60566 m .33065 .6069 L .33062 .60702 L F
.53 .513 .781 r
.33184 .60706 m .33079 .60566 L .33107 .60311 L F
.741 .496 .559 r
.33047 .60707 m .33065 .6069 L .33062 .60702 L F
.046 0 .423 r
.33027 .60701 m .33047 .60707 L .33062 .60702 L F
.724 .38 .395 r
.32993 .60681 m .33027 .60701 L .33062 .60702 L F
.53 .513 .781 r
.33112 .60753 m .32993 .60681 L .32836 .60243 L F
0 0 0 r
.33107 .60311 m .33065 .6069 L .33103 .60348 L F
.53 .513 .781 r
.33079 .60566 m .32836 .60243 L .33107 .60311 L F
.33079 .60566 m .33067 .60671 L .32836 .60243 L F
.33184 .60706 m .33067 .60671 L .33079 .60566 L F
0 0 0 r
.33106 .60328 m .33085 .60588 L .33065 .6069 L F
.741 .496 .559 r
.33032 .60701 m .33085 .60588 L .33065 .6069 L F
.744 .623 .724 r
.32609 .60698 m .32594 .60887 L .3237 .60803 L F
.363 .821 .719 r
.3237 .60803 m .32417 .60768 L .32609 .60698 L F
.046 0 .423 r
.32516 .60692 m .32652 .60826 L .33026 .60713 L F
.32516 .60692 m .33026 .60713 L .33015 .60706 L F
.724 .38 .395 r
.32993 .60681 m .33008 .60701 L .33027 .60701 L F
.003 .168 .683 r
.32826 .60355 m .32808 .60563 L .32777 .60531 L F
.881 .623 .544 r
.32792 .60256 m .32585 .60199 L .32554 .60151 L F
.32585 .60199 m .32824 .60273 L .32836 .60243 L F
.003 .168 .683 r
.32836 .60243 m .32777 .60531 L .32585 .60199 L F
.724 .38 .395 r
.32585 .60199 m .32516 .60692 L .33008 .60701 L F
.32585 .60199 m .33008 .60701 L .32818 .60445 L F
.32585 .60199 m .32818 .60445 L .32836 .60243 L F
.003 .168 .683 r
.32836 .60243 m .32886 .60382 L .32817 .60336 L F
.968 .884 .695 r
.3264 .59791 m .3249 .6009 L .32375 .59948 L F
.412 0 0 r
.3249 .6009 m .32566 .60132 L .32554 .60151 L F
.32566 .60132 m .32792 .60256 L .32562 .60154 L F
.101 .323 .797 r
.32598 .60175 m .32836 .60243 L .32695 .59995 L F
.32585 .60199 m .32666 .60213 L .32598 .60175 L F
.32666 .60213 m .32836 .60243 L .32598 .60175 L F
.412 0 0 r
.32555 .6015 m .32562 .60154 L .32554 .60151 L F
.32566 .60132 m .32562 .60154 L .32555 .6015 L F
.696 .274 0 r
.32554 .60151 m .32585 .60199 L .32552 .60155 L F
.968 .884 .695 r
.3264 .59791 m .32375 .59948 L .32364 .59697 L F
.955 .713 .259 r
.32554 .60151 m .32437 .59761 L .32375 .59948 L F
.696 .274 0 r
.32554 .60151 m .32552 .60155 L .32466 .60039 L F
.955 .713 .259 r
.32554 .60151 m .32466 .60039 L .32437 .59761 L F
.101 .323 .797 r
.32585 .60199 m .32695 .59995 L .32466 .60039 L F
.607 .475 .676 r
.32437 .59761 m .32466 .60039 L .32708 .59712 L F
.452 .275 .549 r
.32466 .60039 m .32695 .59995 L .32708 .59712 L F
.824 .361 0 r
.32767 .60205 m .3304 .60588 L .32449 .59984 L F
.3304 .60588 m .33033 .60586 L .32449 .59984 L F
.764 .671 .76 r
.32695 .59995 m .32836 .60243 L .33115 .60036 L F
.9 .708 .201 r
.33115 .60036 m .33107 .60311 L .33077 .60043 L F
.775 .724 .806 r
.33077 .60043 m .33107 .60311 L .32767 .60205 L F
.741 .496 .559 r
.32781 .60783 m .33071 .60595 L .33032 .60701 L F
.32652 .60826 m .32902 .60689 L .32781 .60783 L F
.32902 .60689 m .33071 .60595 L .32781 .60783 L F
.33071 .60595 m .33084 .60588 L .3308 .60598 L F
.33071 .60595 m .3308 .60598 L .33032 .60701 L F
.33084 .60588 m .33085 .60588 L .33032 .60701 L F
.046 0 .423 r
.33015 .60706 m .33026 .60713 L .33047 .60707 L F
.741 .496 .559 r
.32652 .60826 m .33065 .6069 L .33047 .60707 L F
.53 .513 .781 r
.33112 .60753 m .33037 .60803 L .33014 .60739 L F
.33038 .60715 m .33014 .60739 L .32998 .60694 L F
.33112 .60753 m .33014 .60739 L .33038 .60715 L F
.364 0 .036 r
.32909 .60911 m .33222 .60886 L .33327 .60667 L F
.346 .77 .974 r
.33037 .60803 m .33222 .60886 L .32909 .60911 L F
.657 .906 .98 r
.33184 .60706 m .33222 .60886 L .33037 .60803 L F
.442 .344 .648 r
.33037 .60803 m .33253 .60983 L .33184 .60706 L F
.741 .496 .559 r
.32652 .60826 m .33063 .60864 L .33085 .60588 L F
.831 .537 .491 r
.32883 .60241 m .33055 .60609 L .32767 .60205 L F
.33107 .60311 m .33071 .60518 L .32883 .60241 L F
.33071 .60518 m .33055 .60609 L .32883 .60241 L F
0 0 0 r
.33107 .60311 m .33085 .60588 L .33106 .60328 L F
.033 .156 .662 r
.33327 .60667 m .33446 .60522 L .33247 .60285 L F
.115 .181 .655 r
.33247 .60285 m .33446 .60522 L .33378 .6011 L F
.902 .804 .742 r
.33262 .6013 m .33341 .60437 L .33107 .60311 L F
.928 .768 .664 r
.33341 .60437 m .33184 .60706 L .33107 .60311 L F
.902 .804 .742 r
.33262 .6013 m .33107 .60311 L .33115 .60036 L F
.944 .895 .499 r
.33104 .60185 m .33087 .60541 L .33261 .60482 L F
.33087 .60541 m .33085 .60588 L .33109 .60573 L F
.33087 .60541 m .33109 .60573 L .33261 .60482 L F
.787 .913 .925 r
.33077 .60043 m .32767 .60205 L .32449 .59984 L F
.73 .733 .853 r
.32449 .59984 m .33033 .60586 L .33104 .60185 L F
.824 .361 0 r
.3304 .60588 m .33055 .60609 L .33033 .60586 L F
.73 .733 .853 r
.33033 .60586 m .33055 .60609 L .3306 .60564 L F
.33033 .60586 m .3306 .60564 L .33104 .60185 L F
.741 .496 .559 r
.33063 .60864 m .3307 .60865 L .33085 .60588 L F
.259 0 .027 r
.34026 .58433 m .3386 .58664 L .33597 .5871 L F
.465 .192 .414 r
.56069 .40346 m .56421 .40283 L .56172 .40001 L F
.678 .976 .818 r
.66974 .3838 m .67344 .38169 L .67199 .38239 L F
.615 .937 .724 r
.67344 .38169 m .67666 .37912 L .67513 .37976 L F
.609 .928 .698 r
.67199 .38239 m .67344 .38169 L .67513 .37976 L F
.689 .656 .812 r
.46842 .4543 m .46958 .44961 L .46721 .45239 L F
.46842 .4543 m .471 .4533 L .46958 .44961 L F
.913 .763 .682 r
.58532 .44956 m .58427 .44659 L .5842 .44865 L F
.969 .934 .655 r
.58295 .45248 m .58532 .44956 L .5842 .44865 L F
.58295 .45248 m .5837 .45364 L .58532 .44956 L F
.604 .245 .334 r
.40915 .45475 m .41058 .45682 L .41332 .4534 L F
.41058 .45682 m .41177 .45684 L .41332 .4534 L F
.831 .505 .437 r
.41332 .4534 m .4113 .45787 L .41321 .45758 L F
.895 .753 .698 r
.41312 .45685 m .4101 .4534 L .41259 .45234 L F
.41321 .45758 m .41266 .45685 L .41312 .45685 L F
.41266 .45685 m .4101 .4534 L .41312 .45685 L F
.604 .245 .334 r
.41058 .45682 m .4113 .45787 L .41177 .45684 L F
.831 .505 .437 r
.41332 .4534 m .41321 .45758 L .41581 .45214 L F
.258 0 .108 r
.24895 .52619 m .24783 .52776 L .25122 .52558 L F
.788 .901 .498 r
.72619 .28505 m .72679 .28452 L .72534 .28714 L F
.52 0 0 r
.72619 .28505 m .72963 .2856 L .72679 .28452 L F
.795 .843 .888 r
.60973 .45011 m .61164 .44595 L .60896 .44664 L F
.60973 .45011 m .60896 .44664 L .60971 .44979 L F
.542 .922 .798 r
.60601 .45184 m .60973 .45011 L .60971 .44979 L F
.795 .843 .888 r
.60973 .45011 m .61336 .44762 L .61164 .44595 L F
.736 .212 0 r
.38933 .52879 m .38903 .53028 L .3879 .52752 L F
.38933 .52879 m .39142 .53117 L .38903 .53028 L F
.695 .162 0 r
.39321 .53213 m .39142 .53117 L .38933 .52879 L F
0 0 0 r
.52185 .42628 m .52301 .42468 L .52527 .42329 L F
.516 .854 .581 r
.64052 .40154 m .64361 .39883 L .64224 .39987 L F
.548 .903 .694 r
.63878 .40243 m .64052 .40154 L .64224 .39987 L F
0 .448 .844 r
.47325 .53913 m .47467 .54023 L .47469 .54048 L F
.682 .962 .733 r
.47684 .53903 m .47474 .54102 L .47469 .54048 L F
.47684 .53903 m .47469 .54048 L .4751 .54056 L F
0 .448 .844 r
.47467 .54023 m .4751 .54056 L .47469 .54048 L F
.682 .962 .733 r
.47474 .54102 m .47364 .54205 L .47469 .54048 L F
.699 .637 .783 r
.50874 .46702 m .51132 .46627 L .51052 .463 L F
.668 .515 .669 r
.50874 .46702 m .5088 .46995 L .51132 .46627 L F
0 .48 .841 r
.36297 .60212 m .36551 .60259 L .36369 .60187 L F
.36297 .60212 m .36719 .60364 L .36551 .60259 L F
.877 .828 .796 r
.60268 .41418 m .60547 .41397 L .60432 .41243 L F
.886 .784 .743 r
.60354 .41719 m .60547 .41397 L .60268 .41418 L F
.837 .825 .836 r
.60432 .41243 m .60547 .41397 L .60813 .41107 L F
.891 .809 .761 r
.28998 .6397 m .28805 .64449 L .28546 .64249 L F
0 0 0 r
.28755 .64447 m .29172 .64378 L .28891 .64393 L F
.7 .275 .234 r
.29445 .64563 m .29172 .64378 L .2919 .64637 L F
.93 .713 .588 r
.28891 .64393 m .2919 .64637 L .29172 .64378 L F
.985 .854 .629 r
.59405 .40489 m .59198 .40612 L .59274 .40357 L F
.59405 .40489 m .5933 .40741 L .59198 .40612 L F
.978 .749 .334 r
.57179 .38253 m .57255 .38182 L .57147 .3804 L F
.479 .876 .707 r
.67513 .37976 m .67666 .37912 L .67887 .37764 L F
0 0 .077 r
.34217 .52405 m .34626 .52283 L .34291 .52449 L F
.681 .673 .836 r
.62784 .40009 m .6242 .40436 L .62571 .40033 L F
.7 .32 .325 r
.62571 .40033 m .62503 .40232 L .62291 .40063 L F
.62571 .40033 m .62291 .40063 L .62175 .3997 L F
.681 .673 .836 r
.62817 .39971 m .62784 .40009 L .62571 .40033 L F
.62817 .39971 m .63006 .40139 L .6242 .40436 L F
.813 .344 0 r
.3415 .50044 m .34191 .49943 L .34052 .49812 L F
.3415 .50044 m .34379 .50234 L .34191 .49943 L F
.788 .45 .416 r
.34191 .49943 m .34379 .50234 L .34649 .50263 L F
.768 .811 .887 r
.34925 .64608 m .3524 .64672 L .3518 .64403 L F
.796 .79 .847 r
.35092 .64773 m .3524 .64672 L .34925 .64608 L F
.504 .633 .91 r
.3518 .64403 m .3524 .64672 L .35363 .64551 L F
.466 .829 .571 r
.64224 .39987 m .64361 .39883 L .64567 .39714 L F
.972 .825 .64 r
.38342 .60307 m .3858 .60125 L .38427 .60034 L F
.38342 .60307 m .38505 .60399 L .3858 .60125 L F
.269 .272 .678 r
.53845 .42553 m .53676 .42773 L .5365 .42485 L F
0 0 0 r
.5361 .42932 m .53676 .42773 L .53845 .42553 L F
.336 0 .133 r
.59074 .3671 m .59466 .36434 L .59155 .3649 L F
.538 .926 .867 r
.33696 .65218 m .33704 .65081 L .33552 .65208 L F
.33696 .65218 m .34017 .6504 L .33704 .65081 L F
.364 .709 .986 r
.33696 .65218 m .34123 .65317 L .34017 .6504 L F
0 0 0 r
.66385 .31999 m .66514 .3202 L .66577 .31858 L F
.66385 .31999 m .66253 .32134 L .66514 .3202 L F
.955 .624 .35 r
.39384 .53525 m .39142 .53117 L .39321 .53213 L F
.934 .924 .555 r
.4809 .53136 m .47925 .53296 L .48049 .53121 L F
.4809 .53136 m .47926 .53572 L .47925 .53296 L F
.176 0 0 r
.2657 .51817 m .27014 .51618 L .26719 .51747 L F
0 0 0 r
.31321 .54546 m .31533 .54445 L .31695 .54202 L F
.774 .687 .768 r
.32275 .5873 m .32695 .58779 L .32537 .58398 L F
.192 0 .077 r
.32436 .58915 m .32593 .58794 L .3256 .58779 L F
.199 0 0 r
.32515 .58758 m .3256 .58779 L .32695 .58779 L F
0 .093 .632 r
.32794 .58638 m .32695 .58779 L .3256 .58779 L F
.192 0 .077 r
.32593 .58794 m .32794 .58638 L .3256 .58779 L F
.199 0 0 r
.32275 .5873 m .3256 .58779 L .32515 .58758 L F
.167 .303 .759 r
.31695 .54202 m .31928 .5431 L .31855 .54094 L F
.359 .187 .507 r
.31928 .5431 m .31685 .54494 L .31695 .54202 L F
.942 .753 .618 r
.31928 .5431 m .31735 .54337 L .31855 .54094 L F
0 0 .011 r
.31855 .54094 m .31735 .54337 L .32003 .5395 L F
.927 .864 .758 r
.3212 .53835 m .31855 .54094 L .32003 .5395 L F
.857 .961 .626 r
.31735 .54337 m .31912 .53911 L .32003 .5395 L F
.928 .62 .439 r
.32045 .5435 m .31785 .54254 L .31735 .54337 L F
.857 .961 .626 r
.31735 .54337 m .31677 .5422 L .31912 .53911 L F
.31677 .5422 m .31674 .54214 L .31682 .54204 L F
.31677 .5422 m .31682 .54204 L .31912 .53911 L F
.12 .647 .875 r
.32182 .54403 m .31735 .54337 L .31928 .5431 L F
.32006 .54377 m .32045 .5435 L .31735 .54337 L F
.32182 .54403 m .32045 .5435 L .32006 .54377 L F
.814 .54 .523 r
.32361 .54193 m .32354 .5445 L .31928 .5431 L F
0 0 0 r
.32165 .54297 m .32069 .54333 L .32045 .5435 L F
.307 0 0 r
.32354 .5445 m .32182 .54403 L .31928 .5431 L F
.928 .62 .439 r
.31785 .54254 m .31674 .54214 L .31735 .54337 L F
.029 0 0 r
.31695 .54202 m .31735 .54337 L .31688 .54413 L F
.31695 .54202 m .31533 .54445 L .31735 .54337 L F
.928 .62 .439 r
.32045 .5435 m .31826 .54425 L .31674 .54214 L F
0 0 0 r
.32069 .54333 m .31826 .54425 L .32045 .5435 L F
.959 .815 .658 r
.31912 .53911 m .31674 .54214 L .31622 .5402 L F
.545 .727 .959 r
.31826 .54425 m .31912 .54206 L .31716 .54081 L F
.31693 .54162 m .31716 .54081 L .31622 .5402 L F
.31826 .54425 m .31716 .54081 L .31693 .54162 L F
.029 0 0 r
.31688 .54413 m .31735 .54337 L .31685 .54494 L F
0 .093 .632 r
.32794 .58638 m .3288 .58971 L .32695 .58779 L F
.84 .785 .799 r
.34017 .6504 m .34123 .65317 L .34376 .64901 L F
.982 .804 .4 r
.40368 .57044 m .40284 .56991 L .404 .56815 L F
.976 .818 .406 r
.404 .56815 m .40284 .56991 L .4033 .56704 L F
.727 .919 .958 r
.34625 .64881 m .35092 .64773 L .34925 .64608 L F
.495 .888 .726 r
.52827 .46657 m .52538 .46813 L .52795 .46898 L F
0 0 0 r
.53015 .46243 m .52827 .46657 L .53032 .46516 L F
0 0 .115 r
.53032 .46516 m .52827 .46657 L .52795 .46898 L F
.771 .652 .732 r
.43664 .57747 m .43813 .58247 L .4407 .57793 L F
.503 .323 .569 r
.43813 .58247 m .4407 .57793 L .43664 .57747 L F
.43813 .58247 m .44117 .5813 L .4407 .57793 L F
.712 .469 .556 r
.4443 .5807 m .44117 .5813 L .4407 .57793 L F
.503 .323 .569 r
.4407 .57793 m .44117 .5813 L .43813 .58247 L F
.796 .982 .899 r
.5048 .40706 m .50502 .40458 L .50802 .40508 L F
.5048 .40706 m .50373 .40626 L .50502 .40458 L F
.559 .416 .643 r
.24128 .56544 m .23771 .56123 L .24103 .56024 L F
.24128 .56544 m .2404 .56574 L .23771 .56123 L F
.327 .762 .969 r
.39851 .54207 m .39666 .54132 L .39394 .54151 L F
.933 .556 .2 r
.39881 .54467 m .39666 .54132 L .39851 .54207 L F
.056 .389 .849 r
.60324 .42107 m .60534 .42383 L .60585 .4226 L F
.131 .483 .9 r
.60534 .42383 m .60703 .42444 L .60585 .4226 L F
.658 .842 .971 r
.40237 .50133 m .40018 .50355 L .40253 .50137 L F
.346 0 0 r
.40287 .50424 m .40018 .50355 L .40237 .50133 L F
.40287 .50424 m .39942 .50452 L .40018 .50355 L F
.53 .466 .729 r
.35244 .56453 m .35518 .56168 L .35033 .56069 L F
.35244 .56453 m .35505 .56397 L .35518 .56168 L F
.575 .362 .555 r
.35244 .56453 m .35481 .56759 L .35505 .56397 L F
.35244 .56453 m .35236 .56816 L .35481 .56759 L F
0 0 .253 r
.48394 .56059 m .48266 .56519 L .48364 .56137 L F
.48394 .56059 m .4838 .56363 L .48266 .56519 L F
0 0 0 r
.4826 .56567 m .48266 .56519 L .4838 .56363 L F
.629 .939 .96 r
.46826 .43025 m .46682 .43198 L .46501 .43215 L F
.46826 .43025 m .46946 .43077 L .46682 .43198 L F
.512 .275 .493 r
.50513 .49951 m .50237 .50235 L .50474 .50132 L F
0 0 .031 r
.50786 .4963 m .50513 .49951 L .50677 .49842 L F
0 0 0 r
.50474 .50132 m .50677 .49842 L .50513 .49951 L F
.744 .718 .827 r
.32044 .59122 m .32166 .59428 L .31755 .59387 L F
.577 .054 0 r
.32166 .59428 m .32034 .59533 L .31755 .59387 L F
0 0 .563 r
.32166 .59428 m .32364 .59697 L .32307 .59552 L F
.32166 .59428 m .32307 .59552 L .32034 .59533 L F
.841 .883 .871 r
.57965 .45834 m .57846 .46055 L .57695 .45901 L F
.57695 .45901 m .57846 .46055 L .57965 .45834 L F
.966 .786 .351 r
.41425 .5139 m .41541 .51325 L .41381 .5111 L F
.562 .584 .833 r
.29136 .55069 m .28868 .54992 L .2898 .54881 L F
.28868 .54992 m .28728 .54951 L .2898 .54881 L F
.544 .864 .577 r
.28797 .55065 m .288 .55059 L .2898 .54881 L F
.288 .55059 m .2883 .55005 L .2898 .54881 L F
.652 .474 .63 r
.6097 .40088 m .60508 .40484 L .60504 .40019 L F
.6097 .40088 m .60967 .40373 L .60508 .40484 L F
.549 .583 .841 r
.60829 .39767 m .6097 .40088 L .6124 .40021 L F
.60829 .39767 m .6097 .40088 L .6124 .40021 L F
.492 .344 .607 r
.6124 .40021 m .60967 .40373 L .6097 .40088 L F
.298 0 .01 r
.24451 .57643 m .24732 .57688 L .2447 .57747 L F
.843 .495 .397 r
.38786 .52216 m .38555 .52209 L .38418 .5189 L F
.769 .331 .21 r
.38786 .52216 m .38628 .52389 L .38555 .52209 L F
.975 .689 .419 r
.38786 .52216 m .388 .52505 L .38628 .52389 L F
.49 0 0 r
.56875 .44677 m .57008 .44832 L .56749 .44845 L F
.56875 .44677 m .57142 .44727 L .57008 .44832 L F
.503 .713 .965 r
.4914 .45203 m .4952 .45379 L .49374 .45278 L F
.672 .876 .975 r
.4952 .45379 m .49783 .45279 L .49581 .45178 L F
.735 .934 .953 r
.49374 .45278 m .4952 .45379 L .49581 .45178 L F
.459 .527 .84 r
.4952 .45379 m .49935 .45731 L .49783 .45279 L F
0 0 0 r
.50677 .49842 m .51057 .49573 L .50786 .4963 L F
.357 .082 .351 r
.51109 .49315 m .50786 .4963 L .51057 .49573 L F
.669 .439 .563 r
.33052 .57143 m .33256 .57366 L .3331 .5713 L F
.33052 .57143 m .33062 .57462 L .33256 .57366 L F
.645 .853 .979 r
.60703 .42444 m .61173 .42444 L .60978 .42525 L F
.705 .907 .549 r
.61279 .42237 m .61173 .42444 L .61395 .42133 L F
.737 .984 .771 r
.60978 .42525 m .61173 .42444 L .61279 .42237 L F
.437 .876 .835 r
.34709 .52729 m .34581 .52738 L .34458 .52832 L F
.439 .845 .66 r
.34581 .52738 m .34229 .52959 L .34458 .52832 L F
.199 0 .359 r
.51265 .49208 m .51109 .49315 L .51057 .49573 L F
.903 .507 .25 r
.38418 .5189 m .383 .52068 L .38204 .51804 L F
.38418 .5189 m .38555 .52209 L .383 .52068 L F
.958 .637 .234 r
.5831 .38465 m .58213 .38386 L .58168 .38125 L F
0 .07 .586 r
.5831 .38465 m .58435 .38553 L .58213 .38386 L F
.5831 .38465 m .5856 .38702 L .58435 .38553 L F
.721 .697 .826 r
.60122 .37878 m .59692 .38066 L .5973 .37789 L F
0 0 0 r
.32283 .57407 m .3211 .57487 L .32257 .57362 L F
.764 .524 .571 r
.46027 .57495 m .45821 .57809 L .457 .57506 L F
.46027 .57495 m .45885 .57781 L .45821 .57809 L F
.173 .343 .794 r
.4631 .57182 m .46316 .57201 L .46207 .57333 L F
.596 .943 .926 r
.46106 .57456 m .46313 .57356 L .46207 .57333 L F
.173 .343 .794 r
.46316 .57201 m .46392 .57479 L .46207 .57333 L F
.596 .943 .926 r
.46027 .57495 m .46106 .57456 L .46207 .57333 L F
.196 0 .247 r
.46177 .57626 m .46027 .57495 L .46207 .57333 L F
.46177 .57626 m .45885 .57781 L .46027 .57495 L F
.762 .992 .788 r
.60319 .38273 m .60219 .38487 L .60545 .38176 L F
.755 .961 .663 r
.60319 .38273 m .60117 .38532 L .60219 .38487 L F
.222 .251 .68 r
.52068 .40051 m .52127 .4041 L .5198 .40097 L F
.462 .217 .457 r
.27495 .58463 m .27707 .58655 L .27733 .58438 L F
.27495 .58463 m .27467 .58711 L .27707 .58655 L F
.361 .818 .711 r
.43051 .4484 m .42922 .44918 L .42792 .44904 L F
.43051 .4484 m .4322 .4478 L .42922 .44918 L F
.424 .05 .223 r
.71566 .31194 m .71914 .30922 L .71559 .30966 L F
.71566 .31194 m .71866 .31151 L .71914 .30922 L F
.105 0 .132 r
.71914 .30922 m .72168 .30841 L .71989 .30837 L F
.71914 .30922 m .71866 .31151 L .72168 .30841 L F
.836 .596 .575 r
.37974 .55428 m .3828 .5573 L .38236 .55502 L F
.2 .13 .548 r
.60526 .36722 m .60309 .3715 L .60253 .36864 L F
.60526 .36722 m .60558 .3706 L .60309 .3715 L F
.059 0 .158 r
.60558 .3706 m .60262 .37381 L .60309 .3715 L F
.988 .779 .388 r
.60732 .4072 m .60724 .41024 L .60813 .41107 L F
.837 .825 .836 r
.60432 .41243 m .60813 .41107 L .60724 .41024 L F
.693 .978 .804 r
.60813 .41107 m .6096 .40889 L .60732 .4072 L F
.638 .922 .976 r
.6096 .40889 m .60724 .41024 L .60813 .41107 L F
.693 .978 .804 r
.60813 .41107 m .61123 .40847 L .6096 .40889 L F
.638 .922 .976 r
.6096 .40889 m .60724 .41024 L .60813 .41107 L F
.814 .46 .387 r
.2741 .51292 m .27911 .51237 L .27635 .51246 L F
.868 .465 .004 r
.25206 .5324 m .25394 .5353 L .25278 .53297 L F
.757 .681 .777 r
.72475 .28999 m .72932 .29073 L .72731 .28899 L F
.746 .663 .768 r
.72932 .29073 m .72963 .2856 L .72731 .28899 L F
.72932 .29073 m .73198 .28755 L .72963 .2856 L F
.865 .741 .724 r
.35718 .55784 m .35518 .56168 L .35823 .56077 L F
.358 .021 .25 r
.35505 .56397 m .35823 .56077 L .35518 .56168 L F
.35505 .56397 m .35728 .56393 L .35823 .56077 L F
.516 .442 .711 r
.35823 .56077 m .36068 .55746 L .35718 .55784 L F
.35823 .56077 m .36102 .56088 L .36068 .55746 L F
.525 .172 .311 r
.35823 .56077 m .36098 .56188 L .36102 .56088 L F
.35823 .56077 m .35728 .56393 L .36098 .56188 L F
.787 .684 .75 r
.42811 .56998 m .42524 .57169 L .4232 .5703 L F
.324 .372 .758 r
.42393 .57082 m .42232 .57502 L .4214 .57146 L F
.42397 .57084 m .42232 .57502 L .42393 .57082 L F
0 0 .19 r
.42268 .57633 m .42232 .57502 L .42397 .57084 L F
.787 .684 .75 r
.42524 .57169 m .42393 .57082 L .4232 .5703 L F
.566 .278 .437 r
.4232 .5703 m .42393 .57082 L .4214 .57146 L F
.787 .684 .75 r
.42393 .57082 m .4232 .57033 L .4232 .5703 L F
.566 .278 .437 r
.4232 .5703 m .42398 .57081 L .42393 .57082 L F
0 0 .19 r
.42397 .57087 m .42397 .57084 L .42398 .57081 L F
.42268 .57633 m .42397 .57084 L .42397 .57087 L F
.787 .684 .75 r
.42397 .57084 m .4239 .57099 L .4232 .57033 L F
.4239 .57099 m .42297 .57266 L .4232 .57033 L F
.324 .372 .758 r
.42398 .57081 m .42397 .57084 L .42393 .57082 L F
.566 .278 .437 r
.4232 .5703 m .42297 .57266 L .42398 .57081 L F
.976 .921 .625 r
.42297 .57266 m .42268 .57633 L .42397 .57087 L F
.42208 .57424 m .42397 .57087 L .42398 .57081 L F
.787 .684 .75 r
.4239 .57099 m .42293 .57307 L .42297 .57266 L F
.566 .278 .437 r
.42297 .57266 m .42293 .57307 L .42398 .57081 L F
.976 .921 .625 r
.42208 .57424 m .42209 .57426 L .42297 .57266 L F
.42209 .57426 m .42268 .57633 L .42297 .57266 L F
.42203 .57404 m .42208 .57424 L .42398 .57081 L F
.787 .684 .75 r
.42524 .57169 m .4239 .57248 L .42397 .57084 L F
.4239 .57248 m .42293 .57307 L .42397 .57084 L F
0 0 .19 r
.42268 .57633 m .42293 .57784 L .42232 .57502 L F
0 0 0 r
.65475 .39339 m .65563 .39226 L .65816 .39098 L F
0 0 .031 r
.56394 .42242 m .56119 .42535 L .56286 .42341 L F
.517 .544 .822 r
.6371 .34261 m .63953 .34042 L .63765 .34214 L F
.738 .938 .951 r
.49072 .41779 m .48611 .4189 L .48951 .41691 L F
.917 .95 .802 r
.49307 .4143 m .49072 .41779 L .48951 .41691 L F
.243 0 0 r
.62344 .41744 m .61895 .41896 L .62013 .42028 L F
.62344 .41744 m .62211 .41891 L .61895 .41896 L F
.618 .688 .893 r
.6244 .41208 m .62344 .41744 L .62175 .41517 L F
.6244 .41208 m .62656 .41648 L .62344 .41744 L F
0 0 0 r
.62404 .417 m .62344 .41744 L .62656 .41648 L F
.62404 .417 m .62211 .41891 L .62344 .41744 L F
.25794 .52122 m .25609 .5217 L .25991 .52072 L F
.413 .073 .275 r
.27679 .59157 m .2759 .59356 L .27331 .59405 L F
.327 0 .232 r
.27818 .59293 m .27679 .59157 L .27864 .59116 L F
.27818 .59293 m .2759 .59356 L .27679 .59157 L F
.018 0 .241 r
.61682 .36909 m .61647 .37122 L .61856 .36749 L F
0 0 0 r
.32178 .5809 m .32451 .57861 L .32313 .57854 L F
.321 .096 .409 r
.51122 .45027 m .50875 .45341 L .51116 .4527 L F
.44 .801 .996 r
.50712 .45234 m .50875 .45341 L .51116 .4527 L F
.491 .719 .972 r
.51149 .42106 m .51477 .42113 L .51322 .41939 L F
.855 .87 .85 r
.51477 .42113 m .51149 .42106 L .51322 .41939 L F
.51477 .42113 m .51071 .42265 L .51149 .42106 L F
.633 .554 .747 r
.34523 .57734 m .34813 .57766 L .34721 .57426 L F
.802 .458 .406 r
.34453 .57912 m .34813 .57766 L .34523 .57734 L F
0 0 0 r
.62997 .33839 m .63176 .33804 L .63261 .33757 L F
.62997 .33839 m .62915 .33899 L .63176 .33804 L F
.454 .036 .155 r
.67439 .3252 m .67048 .32755 L .67168 .32633 L F
.641 .764 .937 r
.42062 .47368 m .42149 .47601 L .41968 .47484 L F
.618 .065 0 r
.42149 .47601 m .42066 .47582 L .41968 .47484 L F
.989 .792 .402 r
.42062 .47368 m .42066 .47582 L .42149 .47601 L F
.061 .176 .672 r
.22699 .56425 m .22895 .56619 L .22789 .56443 L F
.46 0 0 r
.62032 .39322 m .61777 .39209 L .61608 .39306 L F
.982 .693 .35 r
.67382 .34412 m .6758 .34602 L .67427 .34696 L F
.823 .898 .894 r
.67919 .34283 m .6758 .34602 L .67382 .34412 L F
.532 0 0 r
.6758 .34602 m .67882 .34751 L .67427 .34696 L F
.689 .976 .797 r
.60684 .37972 m .60545 .38176 L .60857 .37932 L F
.906 .982 .721 r
.60746 .37788 m .60857 .37932 L .61085 .37794 L F
.60746 .37788 m .60684 .37972 L .60857 .37932 L F
.967 .644 .313 r
.58918 .39433 m .58789 .3936 L .58743 .39096 L F
.707 .171 0 r
.58918 .39433 m .58946 .39574 L .58789 .3936 L F
.58918 .39433 m .59144 .39682 L .58946 .39574 L F
.719 .66 .79 r
.49783 .45279 m .5019 .45359 L .50045 .44976 L F
.752 .552 .626 r
.50117 .45569 m .5019 .45359 L .49783 .45279 L F
.556 .569 .822 r
.50045 .44976 m .5019 .45359 L .50449 .45297 L F
.692 .981 .875 r
.301 .58075 m .30173 .58198 L .30445 .58131 L F
.301 .58075 m .29919 .58233 L .30173 .58198 L F
.531 .816 .469 r
.33746 .57619 m .33549 .57843 L .33407 .58002 L F
.939 .832 .387 r
.3486 .52494 m .34855 .52642 L .34771 .52496 L F
.34874 .52106 m .3486 .52494 L .34671 .52323 L F
.3486 .52494 m .34771 .52496 L .34671 .52323 L F
.34874 .52106 m .34813 .52544 L .34855 .52642 L F
.217 0 0 r
.35125 .52489 m .35108 .52578 L .34813 .52544 L F
.35189 .52478 m .35181 .52488 L .35125 .52489 L F
.35181 .52488 m .35108 .52578 L .35125 .52489 L F
.808 1 .813 r
.34813 .52544 m .34709 .52729 L .34855 .52642 L F
.491 .146 .309 r
.28851 .5518 m .28728 .55435 L .28473 .55446 L F
.415 .115 .345 r
.29136 .55069 m .28728 .55435 L .28851 .5518 L F
.991 .738 .43 r
.58428 .4428 m .58558 .44105 L .5854 .43548 L F
.58428 .4428 m .58577 .44412 L .58558 .44105 L F
.49 0 0 r
.63395 .3918 m .63479 .39137 L .63122 .39097 L F
.593 .584 .812 r
.63479 .39137 m .63632 .38706 L .63362 .3878 L F
.63479 .39137 m .63747 .39056 L .63701 .38916 L F
.656 .621 .803 r
.63632 .38706 m .63747 .39056 L .639 .38845 L F
.806 .99 .738 r
.639 .38845 m .63747 .39056 L .63617 .39105 L F
.63908 .38862 m .63617 .39105 L .63966 .3898 L F
.639 .38845 m .6387 .38872 L .63908 .38862 L F
.6387 .38872 m .63617 .39105 L .63908 .38862 L F
.593 .584 .812 r
.63543 .38957 m .63701 .38916 L .63632 .38706 L F
.63479 .39137 m .63701 .38916 L .63543 .38957 L F
0 0 0 r
.63617 .39105 m .63479 .39137 L .63395 .3918 L F
.63617 .39105 m .63747 .39056 L .63479 .39137 L F
.917 .95 .802 r
.49307 .4143 m .48951 .41691 L .49096 .41495 L F
.731 .99 .819 r
.49628 .41156 m .49307 .4143 L .49419 .41221 L F
.73 .99 .825 r
.49307 .4143 m .49096 .41495 L .49419 .41221 L F
.534 .677 .929 r
.31457 .65549 m .31535 .65263 L .31234 .6545 L F
.31457 .65549 m .31705 .65548 L .31535 .65263 L F
.719 .573 .69 r
.43813 .58247 m .43597 .58498 L .43308 .58337 L F
.434 .831 .62 r
.54492 .48497 m .5488 .48238 L .54824 .48275 L F
.455 .869 .726 r
.5488 .48238 m .55247 .48032 L .55039 .48118 L F
.433 .822 .593 r
.5488 .48238 m .55039 .48118 L .54824 .48275 L F
.658 .174 .091 r
.25787 .59801 m .25531 .59926 L .2529 .59734 L F
.273 .181 .565 r
.25937 .59698 m .25967 .59973 L .25787 .59801 L F
.25937 .59698 m .25967 .59973 L .25787 .59801 L F
.592 .565 .793 r
.30632 .65291 m .3086 .64962 L .30593 .6503 L F
.30632 .65291 m .31024 .65345 L .3086 .64962 L F
.54 .418 .663 r
.30766 .65609 m .31024 .65345 L .30632 .65291 L F
0 .526 .834 r
.64734 .34145 m .64644 .34086 L .6438 .34043 L F
.374 .815 .953 r
.64964 .34075 m .64734 .34145 L .65037 .33918 L F
.64964 .34075 m .64644 .34086 L .64734 .34145 L F
.696 .635 .784 r
.51052 .463 m .51132 .46627 L .51461 .46379 L F
.646 .78 .945 r
.57816 .35227 m .58234 .35298 L .58089 .35138 L F
.786 .846 .897 r
.58089 .35138 m .58234 .35298 L .58565 .35069 L F
.437 .473 .799 r
.23136 .60311 m .23237 .60705 L .23439 .60658 L F
.883 .479 .251 r
.59466 .36434 m .59825 .36798 L .59755 .36591 L F
.883 .874 .823 r
.61043 .37485 m .60702 .37618 L .60988 .37452 L F
.676 .967 .928 r
.61043 .37485 m .6119 .37268 L .61404 .37297 L F
.693 .979 .806 r
.61043 .37485 m .60988 .37452 L .6119 .37268 L F
.834 .742 .763 r
.50871 .43984 m .51267 .44031 L .511 .43649 L F
.831 .751 .776 r
.50974 .4436 m .51267 .44031 L .50871 .43984 L F
.634 .438 .601 r
.50974 .4436 m .51285 .44355 L .51267 .44031 L F
.557 .607 .859 r
.511 .43649 m .51267 .44031 L .51527 .43958 L F
.712 .611 .742 r
.51285 .44355 m .51527 .43958 L .51267 .44031 L F
.938 .69 .536 r
.36963 .5371 m .37225 .53531 L .36931 .53425 L F
.36963 .5371 m .37236 .5385 L .37225 .53531 L F
.689 .908 .972 r
.43214 .55326 m .43389 .55451 L .43097 .55097 L F
0 .044 .612 r
.62509 .40723 m .62679 .41106 L .62481 .40976 L F
.764 .26 0 r
.62679 .41106 m .6263 .41167 L .62481 .40976 L F
.62679 .41106 m .62862 .41348 L .6263 .41167 L F
0 .365 .826 r
.56124 .37546 m .56374 .3769 L .56437 .37821 L F
.041 .464 .88 r
.56463 .37712 m .56437 .37821 L .56374 .3769 L F
.56463 .37712 m .5664 .3789 L .56437 .37821 L F
.82 .94 .906 r
.60032 .39368 m .60439 .39244 L .60319 .3896 L F
.622 .723 .919 r
.60439 .39244 m .6071 .39134 L .60319 .3896 L F
.849 .426 .225 r
.40112 .56065 m .40356 .56127 L .40341 .56275 L F
0 0 .029 r
.48812 .54825 m .48769 .55097 L .48645 .55209 L F
0 0 0 r
.48769 .55097 m .48623 .55456 L .48645 .55209 L F
.39 .848 .8 r
.5939 .34555 m .59568 .34459 L .59675 .34418 L F
.183 0 0 r
.59276 .34614 m .59568 .34459 L .5939 .34555 L F
.688 .974 .783 r
.60684 .37972 m .60319 .38273 L .60545 .38176 L F
.841 .883 .871 r
.57965 .45834 m .57975 .45692 L .57965 .4584 L F
.57965 .45834 m .57707 .45629 L .57975 .45692 L F
.397 .111 .359 r
.57975 .45692 m .5837 .45364 L .58172 .45499 L F
0 0 0 r
.57965 .4584 m .57975 .45692 L .58172 .45499 L F
.671 .937 .966 r
.56947 .46122 m .57213 .46156 L .5745 .46017 L F
.654 .718 .895 r
.52995 .40969 m .53242 .41046 L .53237 .4095 L F
.431 .756 .995 r
.53237 .4095 m .53242 .41046 L .5347 .40905 L F
.128 0 .392 r
.53242 .41046 m .53483 .41168 L .5347 .40905 L F
.53242 .41046 m .53321 .41246 L .53483 .41168 L F
0 0 0 r
.32283 .57407 m .3201 .57535 L .3211 .57487 L F
.564 .179 .271 r
.59848 .37104 m .60207 .37112 L .60253 .36864 L F
.453 .083 .245 r
.60253 .36864 m .6054 .37021 L .60526 .36722 L F
.60253 .36864 m .60207 .37112 L .6054 .37021 L F
.181 0 .044 r
.53108 .43038 m .53 .43272 L .52741 .43363 L F
.249 0 .176 r
.52741 .43363 m .53 .43272 L .52936 .43101 L F
.719 .655 .785 r
.53108 .43038 m .52936 .43101 L .53063 .42787 L F
.256 0 0 r
.53069 .43123 m .53204 .43128 L .53 .43272 L F
.53108 .43038 m .53147 .43075 L .53069 .43123 L F
.53147 .43075 m .53204 .43128 L .53069 .43123 L F
.53108 .43038 m .53378 .43043 L .53278 .43092 L F
.53147 .43075 m .53278 .43092 L .53204 .43128 L F
.53108 .43038 m .53278 .43092 L .53147 .43075 L F
.375 .295 .638 r
.52964 .4305 m .53174 .43058 L .53208 .42599 L F
.52936 .43101 m .5311 .4307 L .52964 .4305 L F
.5311 .4307 m .53174 .43058 L .52964 .4305 L F
.53174 .43058 m .53326 .43032 L .5331 .42975 L F
.53174 .43058 m .5331 .42975 L .53208 .42599 L F
.136 0 0 r
.53204 .43128 m .52936 .43101 L .53 .43272 L F
.53204 .43128 m .53326 .43032 L .52936 .43101 L F
.158 .045 .464 r
.53063 .42787 m .52936 .43101 L .53208 .42599 L F
.829 .859 .868 r
.5256 .42913 m .52936 .43101 L .52812 .42821 L F
.289 .738 .96 r
.71617 .32486 m .71738 .324 L .715 .32366 L F
.71617 .32486 m .71859 .32474 L .71738 .324 L F
.621 .387 .541 r
.60508 .40484 m .60967 .40373 L .60732 .4072 L F
.91 .64 .517 r
.38149 .56339 m .38434 .56156 L .38184 .56052 L F
.38149 .56339 m .38441 .56439 L .38434 .56156 L F
.371 .153 .449 r
.3117 .64364 m .31406 .63994 L .31402 .64267 L F
.607 .715 .921 r
.31402 .64267 m .31063 .63973 L .31406 .63994 L F
.546 .342 .555 r
.31406 .63994 m .31727 .63988 L .31724 .63663 L F
.539 .602 .865 r
.31487 .63611 m .31727 .63988 L .31406 .63994 L F
.524 .244 .432 r
.31406 .63994 m .31727 .63988 L .31648 .64213 L F
.31406 .63994 m .31727 .63988 L .31648 .64213 L F
.468 .251 .499 r
.31402 .64267 m .31406 .63994 L .31648 .64213 L F
.263 0 .28 r
.46574 .54101 m .46794 .53866 L .4663 .53897 L F
.922 .906 .79 r
.44912 .58241 m .44949 .58492 L .44697 .58548 L F
.72 .844 .94 r
.53953 .45652 m .54341 .45663 L .54185 .45403 L F
.565 .675 .913 r
.54341 .45663 m .54608 .45611 L .54556 .45348 L F
.225 .746 .778 r
.4233 .45004 m .42282 .45042 L .42074 .4512 L F
.4233 .45004 m .4254 .44984 L .42282 .45042 L F
.669 .167 .043 r
.31023 .5479 m .30738 .54749 L .3108 .54535 L F
.278 .642 .966 r
.31112 .54363 m .31321 .54546 L .3108 .54535 L F
.749 .99 .792 r
.3108 .54535 m .30738 .54749 L .31112 .54363 L F
.208 0 .298 r
.31224 .54659 m .31023 .5479 L .3108 .54535 L F
.834 .572 .544 r
.63953 .34042 m .6438 .34043 L .64387 .33964 L F
.63953 .34042 m .64294 .34422 L .6438 .34043 L F
0 .372 .707 r
.28796 .58158 m .28383 .57999 L .28646 .57908 L F
.577 .646 .882 r
.28861 .5778 m .28796 .58158 L .28646 .57908 L F
.28861 .5778 m .29036 .58122 L .28796 .58158 L F
.267 .49 .887 r
.58856 .35336 m .59126 .35244 L .58743 .35165 L F
.58856 .35336 m .59152 .35429 L .59126 .35244 L F
0 .454 .817 r
.59302 .35512 m .59152 .35429 L .58856 .35336 L F
.576 .891 .989 r
.27494 .63053 m .27821 .63027 L .27772 .63295 L F
.803 .533 .53 r
.27772 .63295 m .27362 .62956 L .27494 .63053 L F
.27772 .63295 m .27821 .63027 L .27362 .62956 L F
.456 0 0 r
.24276 .53163 m .23977 .53166 L .23885 .53134 L F
0 0 0 r
.24276 .53163 m .2439 .53154 L .24579 .52886 L F
.467 .043 .15 r
.24131 .53261 m .2439 .53154 L .24276 .53163 L F
.553 .536 .79 r
.24882 .55826 m .2486 .55542 L .24523 .55529 L F
.24882 .55826 m .25133 .55773 L .2486 .55542 L F
0 0 0 r
.45422 .57714 m .457 .57506 L .45466 .57737 L F
.791 .481 .465 r
.457 .57506 m .45821 .57809 L .45466 .57737 L F
.915 .782 .301 r
.58158 .40568 m .58235 .40447 L .58131 .40326 L F
.58158 .40568 m .582 .40745 L .58235 .40447 L F
0 0 0 r
.55783 .41321 m .55979 .41283 L .56063 .41245 L F
.766 .721 .811 r
.55637 .41496 m .55979 .41283 L .55783 .41321 L F
0 0 0 r
.50237 .50235 m .50419 .5017 L .50474 .50132 L F
.50237 .50235 m .50154 .50477 L .50419 .5017 L F
.912 .769 .691 r
.68471 .33149 m .68612 .33247 L .68458 .33558 L F
.54 .418 .663 r
.30766 .65609 m .31022 .65585 L .31024 .65345 L F
.409 .556 .89 r
.3148 .63292 m .31724 .63663 L .319 .63584 L F
.339 .182 .516 r
.31724 .63663 m .31911 .63881 L .319 .63584 L F
.31724 .63663 m .31727 .63988 L .31911 .63881 L F
0 0 0 r
.42426 .59949 m .42735 .59798 L .42581 .59932 L F
.42426 .59949 m .42581 .59932 L .42347 .59886 L F
.485 0 0 r
.42347 .59886 m .42581 .59932 L .42568 .59944 L F
.669 .677 .849 r
.42003 .59795 m .42426 .59949 L .42347 .59886 L F
.485 0 0 r
.42347 .59886 m .42568 .59944 L .42422 .60084 L F
.669 .677 .849 r
.41972 .59783 m .42003 .59795 L .42347 .59886 L F
0 0 0 r
.52789 .49857 m .52458 .50139 L .52603 .49999 L F
.731 .32 .268 r
.45301 .50083 m .45673 .50174 L .45572 .49992 L F
.511 .528 .811 r
.69363 .28708 m .69631 .28832 L .69593 .28441 L F
.502 .553 .841 r
.69363 .28708 m .69779 .29 L .69631 .28832 L F
.511 .825 1 r
.61395 .42133 m .6158 .41944 L .61279 .42237 L F
.61395 .42133 m .61677 .42061 L .6158 .41944 L F
.412 .073 .277 r
.65916 .33231 m .65896 .33459 L .65598 .33532 L F
.19 0 .232 r
.66127 .3334 m .65916 .33231 L .66244 .3314 L F
.66127 .3334 m .65896 .33459 L .65916 .33231 L F
.611 .95 .921 r
.61609 .40014 m .61947 .39873 L .61897 .39971 L F
.367 .12 .402 r
.61947 .39873 m .62175 .3997 L .61897 .39971 L F
.61947 .39873 m .62193 .39745 L .62175 .3997 L F
.992 .836 .586 r
.5933 .39839 m .5914 .39938 L .59144 .39682 L F
.5933 .39839 m .59269 .40085 L .5914 .39938 L F
.832 .701 .718 r
.73226 .30342 m .73064 .29931 L .73069 .30197 L F
.997 .829 .551 r
.73061 .30457 m .73226 .30342 L .73069 .30197 L F
.73061 .30457 m .73178 .30605 L .73226 .30342 L F
.79 .858 .901 r
.61677 .42061 m .62013 .42028 L .61895 .41896 L F
.543 .846 .532 r
.48308 .52825 m .48472 .52644 L .48672 .52541 L F
.48308 .52825 m .48311 .52813 L .48472 .52644 L F
.535 .027 0 r
.29036 .58122 m .29274 .58277 L .29467 .58113 L F
.816 .53 .505 r
.29274 .58277 m .2947 .58034 L .29467 .58113 L F
.763 .801 .316 r
.23431 .60729 m .23552 .60378 L .23439 .60658 L F
.658 .753 .267 r
.23483 .60549 m .23439 .60658 L .23552 .60378 L F
.808 1 .815 r
.3819 .60578 m .38193 .60719 L .38505 .60399 L F
.765 .666 .113 r
.38169 .6099 m .38193 .60719 L .3819 .60578 L F
.801 .699 .752 r
.338 .53243 m .33551 .53519 L .33394 .53134 L F
.88 .909 .844 r
.33635 .53114 m .33551 .53519 L .338 .53243 L F
.088 .272 .756 r
.338 .53243 m .33889 .53009 L .33635 .53114 L F
.338 .53243 m .34047 .53394 L .33889 .53009 L F
.734 .493 0 r
.40942 .59439 m .40989 .59704 L .40952 .59536 L F
.969 .934 .655 r
.58172 .45499 m .5837 .45364 L .58295 .45248 L F
.935 .917 .539 r
.5933 .43694 m .59243 .44112 L .59333 .43638 L F
.896 .507 .279 r
.59243 .44112 m .59052 .44171 L .59333 .43638 L F
.288 .056 .377 r
.23936 .58371 m .24342 .58675 L .24195 .58436 L F
.611 .428 .609 r
.45949 .5876 m .46258 .58727 L .46233 .58435 L F
.548 .633 .887 r
.46258 .58727 m .46437 .58366 L .46233 .58435 L F
.355 0 .182 r
.24579 .52886 m .24758 .53006 L .24783 .52776 L F
.24579 .52886 m .2439 .53154 L .24758 .53006 L F
.835 .802 .82 r
.33688 .54268 m .33432 .54505 L .33246 .54175 L F
.085 0 .038 r
.33656 .54396 m .33659 .54418 L .33432 .54505 L F
.33682 .54383 m .33664 .5441 L .33656 .54396 L F
.33664 .5441 m .33659 .54418 L .33656 .54396 L F
.43 0 0 r
.33922 .54422 m .33741 .54539 L .33734 .54533 L F
.085 0 .038 r
.33688 .54268 m .33682 .54383 L .33432 .54505 L F
.381 .807 .627 r
.33593 .54406 m .33432 .54505 L .33667 .54415 L F
.43 0 0 r
.33664 .5441 m .33667 .54415 L .33593 .54406 L F
.381 .807 .627 r
.33593 .54406 m .33667 .54415 L .3368 .5441 L F
.43 0 0 r
.33667 .54415 m .33734 .54533 L .33593 .54406 L F
.33922 .54422 m .33734 .54533 L .33664 .5441 L F
.381 .807 .627 r
.33593 .54406 m .33272 .54595 L .33432 .54505 L F
.661 .336 .413 r
.33593 .54406 m .3355 .5458 L .33272 .54595 L F
.3355 .5458 m .33478 .54872 L .33413 .54785 L F
.3355 .5458 m .33413 .54785 L .33272 .54595 L F
.085 0 .038 r
.33682 .54383 m .3368 .5441 L .33659 .54418 L F
0 .543 .791 r
.53058 .40587 m .53459 .4067 L .53052 .4061 L F
.844 .843 .843 r
.25104 .62402 m .25098 .62501 L .2502 .62508 L F
.581 .372 .562 r
.72637 .31274 m .72746 .31494 L .7229 .31462 L F
.577 .332 .508 r
.72746 .31494 m .724 .31623 L .7229 .31462 L F
.885 .926 .844 r
.70444 .33312 m .70702 .33013 L .70421 .3302 L F
.85 .948 .881 r
.70421 .3302 m .70702 .33013 L .70844 .32831 L F
.939 .832 .387 r
.34874 .52106 m .34671 .52323 L .34626 .52283 L F
.59 .624 .854 r
.30031 .63821 m .30097 .64032 L .30208 .63864 L F
.752 .859 .928 r
.29909 .63907 m .30097 .64032 L .30208 .63864 L F
.382 .471 .827 r
.30097 .64032 m .30532 .64438 L .30208 .63864 L F
.84 .785 .799 r
.34017 .6504 m .34376 .64901 L .34216 .64866 L F
.24 .741 .902 r
.34376 .64901 m .34464 .64844 L .34216 .64866 L F
.34376 .64901 m .34625 .64881 L .34464 .64844 L F
.593 .358 .53 r
.34097 .5638 m .34402 .56094 L .34149 .56159 L F
.932 .909 .775 r
.70336 .3348 m .70444 .33312 L .70236 .33318 L F
.885 .926 .844 r
.70444 .33312 m .70421 .3302 L .70346 .33191 L F
.89 .95 .839 r
.70236 .33318 m .70444 .33312 L .70346 .33191 L F
0 0 0 r
.44522 .56997 m .4469 .5697 L .44913 .56897 L F
.832 .401 .214 r
.4469 .5697 m .44937 .57072 L .44913 .56897 L F
.316 .716 .979 r
.44892 .56938 m .4469 .5697 L .44482 .56891 L F
.44924 .56942 m .4469 .5697 L .44892 .56938 L F
0 0 0 r
.44433 .5702 m .4469 .5697 L .44522 .56997 L F
.182 0 .298 r
.44913 .56897 m .44937 .57072 L .45109 .56749 L F
.723 .251 .126 r
.35431 .54281 m .35705 .54528 L .35177 .54399 L F
.952 .672 .468 r
.35431 .54281 m .35177 .54399 L .35199 .54126 L F
.583 .55 .783 r
.53127 .44987 m .53259 .45388 L .53513 .45319 L F
.658 .572 .747 r
.53315 .45741 m .53513 .45319 L .53259 .45388 L F
.468 .833 .581 r
.53904 .41305 m .53751 .41435 L .53976 .41252 L F
.079 0 .008 r
.52054 .43337 m .51838 .43449 L .51742 .43617 L F
.983 .701 .337 r
.40173 .55492 m .40054 .55389 L .40034 .55096 L F
.984 .715 .427 r
.40173 .55492 m .40023 .55658 L .40054 .55389 L F
.40173 .55492 m .40188 .55785 L .40023 .55658 L F
.81 .612 .635 r
.45514 .56802 m .45316 .56903 L .45109 .56749 L F
.22 0 0 r
.65108 .38404 m .65253 .3816 L .64977 .38247 L F
.175 .453 .88 r
.61515 .37126 m .61404 .37297 L .6119 .37268 L F
.61515 .37126 m .61643 .37356 L .61404 .37297 L F
.066 0 .001 r
.27104 .51861 m .26971 .52121 L .26758 .52211 L F
0 0 0 r
.27164 .51907 m .27104 .51861 L .27363 .51876 L F
.029 0 0 r
.27596 .51789 m .27164 .51907 L .27363 .51876 L F
.27596 .51789 m .27418 .51871 L .27164 .51907 L F
.257 .753 .903 r
.27164 .51907 m .27418 .51871 L .27236 .51875 L F
0 0 0 r
.27164 .51907 m .27056 .51956 L .27104 .51861 L F
.257 .753 .903 r
.27164 .51907 m .27236 .51875 L .26971 .5188 L F
0 0 0 r
.27164 .51907 m .26971 .52121 L .27056 .51956 L F
.871 .63 .571 r
.62817 .39971 m .6311 .3998 L .63006 .40139 L F
0 .033 .563 r
.23739 .58664 m .23812 .59151 L .2393 .58923 L F
0 0 0 r
.2386 .59155 m .2393 .58923 L .23812 .59151 L F
.957 .632 .358 r
.59981 .39937 m .60189 .39845 L .59899 .39699 L F
.59981 .39937 m .60173 .40043 L .60189 .39845 L F
.667 .395 .5 r
.60173 .40043 m .60552 .39782 L .60189 .39845 L F
.269 .705 .964 r
.42735 .59798 m .43164 .59884 L .43001 .59893 L F
.163 0 0 r
.43164 .59884 m .43248 .59962 L .43001 .59893 L F
.43164 .59884 m .43445 .59812 L .43248 .59962 L F
.658 .639 .82 r
.46958 .44961 m .471 .4533 L .47383 .45129 L F
.238 0 0 r
.42444 .45754 m .42275 .45869 L .42002 .4589 L F
.981 .77 .547 r
.45241 .57679 m .45422 .57714 L .45308 .57402 L F
.45308 .57402 m .45422 .57714 L .45241 .57679 L F
.463 .847 .631 r
.6847 .37408 m .68821 .3717 L .68667 .37214 L F
.715 .964 .94 r
.68948 .36926 m .68821 .3717 L .69069 .36994 L F
.753 .983 .746 r
.68667 .37214 m .68821 .3717 L .68948 .36926 L F
.146 .082 .521 r
.23316 .54818 m .23409 .54483 L .23231 .54568 L F
.65 .962 .925 r
.45995 .43634 m .45762 .4378 L .45509 .43796 L F
0 0 .118 r
.32485 .5321 m .32234 .53554 L .32494 .53312 L F
.691 .437 .535 r
.32234 .53554 m .32589 .53721 L .32494 .53312 L F
.32234 .53554 m .3212 .53835 L .32589 .53721 L F
.854 .561 .029 r
.23394 .5991 m .23459 .60062 L .23391 .59705 L F
.541 .569 .832 r
.34583 .59759 m .34856 .59713 L .34655 .5929 L F
.84 .727 .202 r
.34583 .59759 m .34533 .5974 L .34856 .59713 L F
.34583 .59759 m .34561 .59992 L .34533 .5974 L F
.626 .576 .778 r
.35019 .60078 m .34583 .59759 L .34856 .59713 L F
.35019 .60078 m .34583 .59759 L .34856 .59713 L F
.284 0 .022 r
.6092 .41706 m .61215 .4165 L .61293 .41486 L F
.032 0 0 r
.6144 .41536 m .61293 .41486 L .61215 .4165 L F
.6144 .41536 m .61504 .41338 L .61293 .41486 L F
.495 .311 .56 r
.52098 .4796 m .52237 .477 L .52101 .47676 L F
0 0 0 r
.64244 .33311 m .64376 .33294 L .64505 .33211 L F
.64244 .33311 m .64111 .33386 L .64376 .33294 L F
.803 .733 .787 r
.33085 .56359 m .3278 .56429 L .3304 .56125 L F
.466 .155 .353 r
.33085 .56359 m .32784 .56739 L .3278 .56429 L F
.33085 .56359 m .33066 .56478 L .3293 .56554 L F
.697 .665 .815 r
.33085 .56359 m .33452 .56167 L .3304 .56125 L F
.282 .365 .771 r
.3304 .56125 m .33333 .56296 L .33085 .56359 L F
.552 .383 .607 r
.33156 .56449 m .33333 .56296 L .33162 .56435 L F
.527 .207 .368 r
.33268 .56612 m .33152 .56452 L .33333 .56296 L F
.462 .144 .34 r
.32784 .56739 m .33115 .56473 L .33062 .56503 L F
.466 .155 .353 r
.3293 .56554 m .32956 .56594 L .32784 .56739 L F
.33066 .56478 m .33062 .56503 L .3293 .56554 L F
.527 .207 .368 r
.33268 .56612 m .3303 .56708 L .33097 .56522 L F
.462 .144 .34 r
.32784 .56739 m .3303 .56708 L .33115 .56473 L F
.527 .207 .368 r
.33268 .56612 m .33062 .56503 L .33152 .56451 L F
.462 .144 .34 r
.33115 .56473 m .3303 .56708 L .33162 .56435 L F
.527 .207 .368 r
.33097 .56522 m .3303 .56708 L .33062 .56503 L F
.466 .155 .353 r
.33062 .56503 m .3303 .56708 L .32956 .56594 L F
.33062 .56503 m .32956 .56594 L .3293 .56554 L F
.462 .144 .34 r
.32783 .56666 m .33095 .56476 L .3278 .56429 L F
.527 .207 .368 r
.33152 .56451 m .33062 .56503 L .33085 .56359 L F
.462 .144 .34 r
.33095 .56476 m .33162 .56435 L .33144 .56435 L F
.33095 .56476 m .33144 .56435 L .3278 .56429 L F
.32784 .56739 m .33062 .56503 L .32783 .56666 L F
.466 .155 .353 r
.32956 .56594 m .3303 .56708 L .32784 .56739 L F
.462 .144 .34 r
.33115 .56473 m .33162 .56435 L .32783 .56666 L F
.552 .383 .607 r
.3303 .56708 m .33333 .56296 L .33156 .56449 L F
.527 .207 .368 r
.33152 .56452 m .33148 .56447 L .33333 .56296 L F
.33148 .56447 m .33085 .56359 L .33163 .56339 L F
.689 .551 .692 r
.33151 .56431 m .33162 .56435 L .33159 .56426 L F
.3315 .56435 m .33162 .56435 L .33151 .56431 L F
.527 .207 .368 r
.33153 .56412 m .33163 .56339 L .33333 .56296 L F
.339 .357 .733 r
.33153 .56412 m .33333 .56296 L .3304 .56125 L F
.33162 .56435 m .33333 .56296 L .33153 .56412 L F
.527 .207 .368 r
.33148 .56447 m .33153 .56412 L .33333 .56296 L F
.689 .551 .692 r
.33144 .56435 m .3315 .56435 L .33151 .56431 L F
.3278 .56429 m .33144 .56435 L .3304 .56125 L F
.33144 .56435 m .33159 .56426 L .3304 .56125 L F
.518 .889 .688 r
.39924 .49129 m .40117 .49028 L .40308 .48881 L F
.424 0 .106 r
.26007 .62787 m .2602 .6278 L .26008 .62789 L F
.679 .803 .941 r
.25734 .62639 m .26296 .6264 L .2602 .6278 L F
.424 0 .106 r
.25678 .62951 m .26007 .62787 L .25875 .62888 L F
.26007 .62787 m .26008 .62789 L .25875 .62888 L F
.575 .053 0 r
.2602 .6278 m .26273 .62924 L .25875 .62888 L F
.771 .528 .567 r
.25875 .62888 m .26296 .6264 L .25734 .62639 L F
.25875 .62888 m .26273 .62924 L .26296 .6264 L F
0 0 .074 r
.26009 .62732 m .26015 .62836 L .25992 .62578 L F
.26015 .62836 m .26016 .62859 L .26013 .62826 L F
.26015 .62836 m .26013 .62826 L .25992 .62578 L F
.758 .769 .264 r
.67635 .35352 m .67692 .35209 L .67668 .35291 L F
.726 .826 .37 r
.67882 .34751 m .67692 .35209 L .67812 .34959 L F
0 0 0 r
.67812 .34959 m .67692 .35209 L .67635 .35352 L F
.351 .774 .975 r
.41093 .57077 m .41507 .57127 L .41429 .57052 L F
.67 .199 .127 r
.41337 .5729 m .41507 .57127 L .41093 .57077 L F
.983 .896 .562 r
.41429 .57052 m .41507 .57127 L .41337 .5729 L F
.647 .884 .984 r
.48271 .41948 m .48128 .42171 L .47998 .42271 L F
.48271 .41948 m .48402 .42063 L .48128 .42171 L F
.553 .261 .425 r
.2983 .58158 m .29728 .57779 L .2947 .58034 L F
.2983 .58158 m .29997 .5777 L .29728 .57779 L F
.795 .733 .795 r
.51258 .45662 m .51523 .45343 L .51116 .4527 L F
0 0 0 r
.39251 .48551 m .39002 .48684 L .38841 .48825 L F
.543 .505 .763 r
.30206 .64627 m .30282 .64944 L .30484 .64838 L F
.595 .547 .772 r
.30282 .64944 m .30593 .6503 L .30484 .64838 L F
.81 .89 .901 r
.56595 .46918 m .56949 .46617 L .56783 .46491 L F
.601 .053 0 r
.33179 .53251 m .33388 .53415 L .33166 .53297 L F
.477 0 0 r
.33551 .53519 m .33179 .53251 L .33394 .53134 L F
.33444 .53442 m .33388 .53415 L .33179 .53251 L F
.33551 .53519 m .33388 .53415 L .33444 .53442 L F
.88 .909 .844 r
.33635 .53114 m .33388 .53415 L .33551 .53519 L F
0 0 0 r
.33445 .53346 m .33518 .53325 L .33388 .53415 L F
.33635 .53114 m .33518 .53325 L .33445 .53346 L F
.33757 .53213 m .33567 .53311 L .33518 .53325 L F
.33567 .53311 m .3335 .53424 L .33518 .53325 L F
.25 0 0 r
.33518 .53325 m .33305 .53375 L .33388 .53415 L F
0 0 0 r
.33106 .53421 m .33166 .53297 L .33388 .53415 L F
.25 0 0 r
.33305 .53375 m .33106 .53421 L .33388 .53415 L F
.796 .559 .579 r
.34042 .6097 m .34456 .60723 L .34238 .60718 L F
.34042 .6097 m .34472 .61048 L .34456 .60723 L F
.43 .277 .571 r
.34456 .60723 m .34472 .61048 L .34691 .60941 L F
.34456 .60723 m .34472 .61048 L .34691 .60941 L F
.506 .395 .662 r
.25381 .52778 m .25434 .5329 L .25206 .5324 L F
.088 .084 .557 r
.25586 .52909 m .25434 .5329 L .25401 .52972 L F
.199 .059 .454 r
.25404 .5282 m .25586 .52909 L .2568 .52868 L F
.088 .084 .557 r
.25586 .52909 m .25401 .52972 L .25405 .52793 L F
.199 .059 .454 r
.25371 .52814 m .25586 .52909 L .25404 .5282 L F
.088 .084 .557 r
.25405 .52793 m .25404 .5282 L .25381 .52778 L F
.25404 .5282 m .25401 .52972 L .25384 .5281 L F
.25404 .5282 m .25384 .5281 L .25381 .52778 L F
.25644 .52855 m .25408 .52778 L .25725 .52781 L F
.232 .733 .902 r
.26145 .52796 m .26013 .52756 L .25725 .52781 L F
.733 .438 .481 r
.26013 .52756 m .25729 .52858 L .25725 .52781 L F
.352 .32 .683 r
.25676 .52856 m .25679 .52867 L .25699 .52857 L F
.25679 .52867 m .2568 .52868 L .25681 .52867 L F
.418 .361 .688 r
.25676 .52866 m .2568 .52868 L .25679 .52867 L F
.733 .438 .481 r
.25729 .52858 m .25586 .52909 L .25644 .52855 L F
.25702 .52857 m .25644 .52855 L .25729 .52845 L F
.352 .32 .683 r
.25676 .52856 m .25699 .52857 L .25902 .52755 L F
.25679 .52867 m .25681 .52867 L .25902 .52755 L F
.571 .47 .7 r
.25586 .52909 m .25902 .52755 L .25702 .52857 L F
.25586 .52909 m .25702 .52857 L .2568 .52868 L F
.733 .438 .481 r
.25729 .52845 m .25644 .52855 L .25725 .52781 L F
.25729 .52858 m .25702 .52857 L .25729 .52845 L F
.352 .32 .683 r
.25516 .52304 m .25676 .52856 L .25902 .52755 L F
.088 .084 .557 r
.25643 .52857 m .25381 .52778 L .25408 .52778 L F
.25643 .52857 m .25408 .52778 L .25644 .52855 L F
.25586 .52909 m .25405 .52793 L .25643 .52857 L F
.25405 .52793 m .25381 .52778 L .25643 .52857 L F
.418 .361 .688 r
.25407 .52689 m .25676 .52866 L .25516 .52304 L F
.25676 .52866 m .25679 .52867 L .25516 .52304 L F
.25371 .52814 m .25404 .5282 L .25407 .52689 L F
.25404 .5282 m .2568 .52868 L .25407 .52689 L F
.315 .341 .729 r
.25586 .52909 m .25489 .53291 L .25434 .5329 L F
.214 .584 .944 r
.25434 .5329 m .25489 .53291 L .25206 .5324 L F
.441 .622 .928 r
.25489 .53291 m .25394 .5353 L .25206 .5324 L F
.25489 .53291 m .25575 .53459 L .25394 .5353 L F
.586 .467 .684 r
.25575 .53459 m .2536 .53793 L .25394 .5353 L F
0 0 0 r
.23065 .55369 m .23313 .55096 L .23058 .55199 L F
.717 .758 .885 r
.54543 .4019 m .54167 .40223 L .544 .40292 L F
.428 0 .107 r
.544 .40292 m .54682 .40155 L .54543 .4019 L F
0 0 .129 r
.51567 .48624 m .51764 .48524 L .51805 .48267 L F
0 0 .16 r
.51567 .48624 m .51653 .48683 L .51764 .48524 L F
.51567 .48624 m .51546 .48866 L .51653 .48683 L F
.367 .807 .651 r
.66413 .38714 m .66599 .38604 L .66361 .3874 L F
.66413 .38714 m .66751 .38529 L .66599 .38604 L F
.947 .653 .204 r
.71461 .30839 m .71559 .30966 L .71428 .30566 L F
.982 .771 .544 r
.45784 .58692 m .45949 .5876 L .45836 .58391 L F
0 .237 .75 r
.46088 .58696 m .45949 .5876 L .45784 .58692 L F
.591 .352 .523 r
.45949 .5876 m .46211 .59014 L .46258 .58727 L F
0 .237 .75 r
.46088 .58696 m .46211 .59014 L .45949 .5876 L F
.738 .716 .83 r
.30912 .64198 m .3117 .64364 L .30736 .64276 L F
.607 .715 .921 r
.31402 .64267 m .3117 .64364 L .30912 .64198 L F
0 0 .546 r
.24795 .57237 m .24873 .57324 L .24774 .57396 L F
.294 0 .267 r
.24983 .57566 m .24774 .57396 L .24873 .57324 L F
.24983 .57566 m .24732 .57688 L .24774 .57396 L F
.65 .654 .84 r
.51122 .45027 m .51245 .44569 L .51037 .44773 L F
.51122 .45027 m .514 .4502 L .51245 .44569 L F
.714 .565 .685 r
.50617 .44852 m .51017 .44972 L .50971 .44581 L F
.979 .916 .633 r
.51054 .44859 m .51122 .45027 L .5106 .44842 L F
.50973 .45107 m .51093 .45043 L .51057 .44869 L F
.50973 .45107 m .51057 .44869 L .51017 .44972 L F
.722 .544 .649 r
.50964 .45112 m .51095 .44995 L .51017 .44972 L F
.50964 .45112 m .51017 .44972 L .50617 .44852 L F
.979 .916 .633 r
.51017 .44972 m .51057 .44869 L .51054 .44859 L F
.51093 .45043 m .51122 .45027 L .51054 .44859 L F
0 0 .313 r
.50971 .44581 m .51054 .44859 L .51037 .44773 L F
.51054 .44859 m .51095 .44995 L .51037 .44773 L F
.714 .565 .685 r
.51017 .44972 m .51095 .44995 L .51054 .44859 L F
.51017 .44972 m .51054 .44859 L .50971 .44581 L F
.979 .916 .633 r
.50964 .45112 m .50973 .45107 L .51037 .44773 L F
.50973 .45107 m .5106 .44842 L .51037 .44773 L F
.953 .639 .397 r
.51116 .4527 m .51122 .45027 L .50964 .45112 L F
.822 .652 .672 r
.51116 .4527 m .514 .4502 L .51122 .45027 L F
.612 .646 .86 r
.33746 .57619 m .33806 .57302 L .33789 .5748 L F
.77 .992 .884 r
.3527 .53218 m .34842 .53299 L .35271 .53012 L F
0 0 0 r
.51546 .48866 m .5139 .49028 L .51265 .49208 L F
.401 .243 .549 r
.3006 .53184 m .29864 .53561 L .30027 .53381 L F
.052 0 .184 r
.29864 .53561 m .29782 .53786 L .30027 .53381 L F
.29864 .53561 m .29782 .53786 L .30027 .53381 L F
.85 .829 .827 r
.51681 .50604 m .51871 .50552 L .51868 .50508 L F
.52 .838 .533 r
.51995 .50443 m .51808 .50616 L .5169 .50736 L F
.113 0 0 r
.52169 .50471 m .51747 .50673 L .51995 .50443 L F
.85 .829 .827 r
.51871 .50552 m .52169 .50471 L .5192 .50502 L F
.51871 .50552 m .5192 .50502 L .51868 .50508 L F
.52 .838 .533 r
.5169 .50736 m .51747 .50673 L .5161 .50813 L F
.51808 .50616 m .51747 .50673 L .5169 .50736 L F
.096 0 .021 r
.52251 .50242 m .52169 .50471 L .51995 .50443 L F
0 0 0 r
.56602 .42084 m .56394 .42242 L .56286 .42341 L F
.702 .741 .231 r
.48801 .52102 m .48672 .52541 L .48682 .52302 L F
.886 .984 .711 r
.48672 .52541 m .48472 .52644 L .48682 .52302 L F
.446 .778 .998 r
.26405 .59741 m .26672 .59712 L .26469 .59581 L F
.26405 .59741 m .26672 .59712 L .26469 .59581 L F
.504 .751 .984 r
.54986 .40817 m .55389 .40909 L .55133 .40629 L F
.706 .73 .869 r
.55133 .40629 m .55389 .40909 L .55614 .40753 L F
.495 .311 .56 r
.52098 .4796 m .5236 .47894 L .52237 .477 L F
.747 .687 .794 r
.52183 .47387 m .52237 .477 L .52646 .47298 L F
.747 .694 .801 r
.52217 .47239 m .52183 .47387 L .52646 .47298 L F
.844 .938 .887 r
.52646 .47298 m .52237 .477 L .52458 .47327 L F
.516 .484 .759 r
.52237 .477 m .52639 .4759 L .52458 .47327 L F
.459 .299 .576 r
.52237 .477 m .5236 .47894 L .52639 .4759 L F
.436 .387 .704 r
.23569 .56698 m .23427 .57047 L .23309 .56932 L F
.756 .965 .675 r
.55247 .48032 m .55402 .47821 L .55334 .47828 L F
.756 .99 .78 r
.55039 .48118 m .55247 .48032 L .55334 .47828 L F
.793 .467 .437 r
.34379 .50234 m .34378 .50474 L .34649 .50263 L F
.892 .649 .563 r
.34649 .50263 m .34378 .50474 L .34622 .50492 L F
.962 .722 .527 r
.3856 .57635 m .38774 .57444 L .386 .57339 L F
.3856 .57635 m .38753 .5775 L .38774 .57444 L F
0 0 .53 r
.44274 .58261 m .44164 .58479 L .44117 .5813 L F
.416 0 0 r
.4428 .58571 m .44439 .58617 L .44372 .58583 L F
.4428 .58571 m .44372 .58583 L .44164 .58479 L F
.791 .7 .764 r
.43887 .58515 m .44055 .58924 L .4428 .58571 L F
.972 .659 .302 r
.4428 .58571 m .44169 .58742 L .44175 .58556 L F
.416 0 0 r
.4428 .58571 m .44164 .58479 L .44274 .58261 L F
.785 .714 .785 r
.43887 .58515 m .4428 .58571 L .44274 .58261 L F
.972 .659 .302 r
.4428 .58571 m .44175 .58556 L .44179 .5844 L F
0 .076 .637 r
.35719 .61566 m .35652 .61669 L .35587 .61509 L F
.491 .782 .997 r
.35652 .61669 m .3601 .61633 L .35936 .61359 L F
0 0 0 r
.3556 .61887 m .35652 .61669 L .35719 .61566 L F
.9 .946 .827 r
.27142 .64666 m .27413 .64329 L .2725 .64278 L F
.974 .678 .395 r
.2725 .64278 m .27413 .64329 L .27217 .64064 L F
.2725 .64278 m .27413 .64329 L .27217 .64064 L F
.03 0 0 r
.53321 .41246 m .53028 .41391 L .52947 .41584 L F
.839 .795 .809 r
.44965 .57478 m .45252 .57132 L .44937 .57072 L F
.561 .371 .581 r
.44965 .57478 m .45308 .57402 L .45252 .57132 L F
.532 .352 .583 r
.45308 .57402 m .45517 .57079 L .45252 .57132 L F
.11 0 0 r
.65336 .33898 m .64964 .34075 L .65037 .33918 L F
.554 .355 .565 r
.65322 .33623 m .65336 .33898 L .65037 .33918 L F
.597 .807 .98 r
.60436 .37807 m .60122 .37878 L .60268 .37645 L F
.803 .928 .917 r
.31003 .5768 m .31336 .57512 L .31169 .57355 L F
.065 .525 .897 r
.31169 .57355 m .31336 .57512 L .31519 .57512 L F
0 0 .069 r
.27908 .51494 m .27756 .51629 L .27907 .51497 L F
.814 .46 .387 r
.27865 .51242 m .27867 .51521 L .27911 .51237 L F
.2741 .51292 m .27814 .51495 L .27865 .51242 L F
.27814 .51495 m .27867 .51521 L .27865 .51242 L F
.27867 .51521 m .27868 .5152 L .27911 .51237 L F
0 0 .022 r
.27911 .51237 m .27907 .51497 L .28089 .51112 L F
.061 0 .306 r
.28089 .51112 m .27907 .51497 L .27911 .51237 L F
0 0 .022 r
.27908 .51425 m .27973 .51307 L .27907 .51497 L F
.27911 .51237 m .27973 .51307 L .27908 .51425 L F
.388 .306 .642 r
.28034 .51049 m .27973 .51307 L .28161 .51198 L F
.28034 .51049 m .27973 .51307 L .28161 .51198 L F
.677 .894 .537 r
.28161 .51198 m .28007 .51245 L .27973 .51307 L F
0 0 .022 r
.27911 .51237 m .27868 .5152 L .27973 .51307 L F
0 0 .069 r
.27973 .51307 m .27868 .5152 L .27908 .51494 L F
.27973 .51307 m .27903 .51544 L .27867 .51565 L F
.27799 .51565 m .27756 .51629 L .27908 .51494 L F
.6 .905 .633 r
.27756 .51629 m .27596 .51789 L .27907 .51497 L F
0 0 .069 r
.27839 .51528 m .27867 .51565 L .2779 .51609 L F
.12 0 0 r
.27867 .51521 m .27866 .51521 L .27868 .51522 L F
.27814 .51495 m .27866 .51521 L .27867 .51521 L F
.2741 .51292 m .27814 .51495 L .27814 .51495 L F
.27814 .51495 m .27866 .51521 L .27814 .51495 L F
0 0 .069 r
.27831 .51518 m .2779 .51609 L .27799 .51565 L F
.12 0 0 r
.27504 .51341 m .2748 .51384 L .27822 .51505 L F
.2741 .51292 m .2748 .51384 L .27504 .51341 L F
0 0 0 r
.2748 .51384 m .27365 .51435 L .27468 .51405 L F
.12 0 0 r
.27814 .51495 m .27822 .51505 L .27866 .51521 L F
.2741 .51292 m .27822 .51505 L .27814 .51495 L F
.327 .812 .852 r
.2748 .51384 m .27973 .51307 L .27866 .51521 L F
.2748 .51384 m .2777 .51317 L .27973 .51307 L F
0 0 0 r
.2748 .51384 m .27468 .51405 L .2777 .51317 L F
0 0 .069 r
.27973 .51307 m .27831 .51518 L .27866 .5152 L F
.27973 .51307 m .27866 .5152 L .27868 .5152 L F
0 0 .022 r
.27868 .5152 m .27868 .51522 L .27973 .51307 L F
.814 .46 .387 r
.27867 .51521 m .27868 .51522 L .27868 .5152 L F
.327 .812 .852 r
.27866 .51521 m .27973 .51307 L .27868 .51522 L F
0 0 .069 r
.27973 .51307 m .27839 .51528 L .27831 .51518 L F
.27831 .51518 m .27799 .51565 L .27867 .51521 L F
.27839 .51528 m .2779 .51609 L .27831 .51518 L F
.27831 .51518 m .27867 .51521 L .27868 .5152 L F
.27973 .51307 m .27867 .51565 L .27839 .51528 L F
.677 .894 .537 r
.28007 .51245 m .2777 .51317 L .27973 .51307 L F
0 0 .069 r
.27799 .51565 m .2779 .51609 L .27756 .51629 L F
.31 .408 .8 r
.70899 .28455 m .70725 .2869 L .7059 .28274 L F
.626 .86 .987 r
.71 .28611 m .70725 .2869 L .70899 .28455 L F
.974 .719 .485 r
.26618 .64074 m .26832 .63901 L .26804 .64209 L F
.54 .226 .385 r
.26655 .6408 m .26832 .63901 L .26618 .64074 L F
0 0 .361 r
.26991 .64015 m .27196 .64192 L .26804 .64209 L F
.27123 .63878 m .26804 .64209 L .26832 .63901 L F
.54 .226 .385 r
.27051 .64146 m .26943 .64025 L .26655 .6408 L F
.26943 .64025 m .26832 .63901 L .26655 .6408 L F
0 0 .361 r
.27123 .63878 m .27148 .63985 L .26991 .64015 L F
.27148 .63985 m .27196 .64192 L .26991 .64015 L F
.979 .681 .336 r
.27217 .64064 m .27123 .63878 L .2734 .6382 L F
.27217 .64064 m .2734 .6382 L .27183 .63997 L F
0 0 .361 r
.27123 .63878 m .27185 .64072 L .27185 .6408 L F
.27133 .6392 m .27185 .6408 L .27188 .64157 L F
.27123 .63878 m .27185 .6408 L .27133 .6392 L F
.965 .673 .425 r
.27185 .6408 m .2725 .64278 L .27217 .64064 L F
0 0 .361 r
.27188 .64157 m .2725 .64278 L .27196 .64192 L F
.27185 .64072 m .2725 .64278 L .27188 .64157 L F
.619 .078 0 r
.27196 .64192 m .27051 .64146 L .26804 .64209 L F
.9 .946 .827 r
.27142 .64666 m .2725 .64278 L .27196 .64192 L F
.619 .078 0 r
.27196 .64192 m .2725 .64278 L .27051 .64146 L F
.965 .673 .425 r
.27051 .64146 m .2725 .64278 L .27185 .6408 L F
.979 .681 .336 r
.27217 .64064 m .2725 .64278 L .27185 .64072 L F
.27217 .64064 m .27185 .64072 L .27123 .63878 L F
.27185 .6408 m .27185 .64072 L .27051 .64146 L F
.27185 .64072 m .27183 .63997 L .27095 .64096 L F
.27185 .64072 m .27095 .64096 L .27051 .64146 L F
.27217 .64064 m .27183 .63997 L .27185 .6408 L F
.494 .124 .266 r
.40171 .51008 m .40365 .50865 L .40331 .50861 L F
.703 .97 .931 r
.40485 .50915 m .40331 .50861 L .40569 .50714 L F
.494 .124 .266 r
.40365 .50865 m .40569 .50714 L .40331 .50861 L F
0 .442 .73 r
.4028 .50855 m .40331 .50861 L .40485 .50915 L F
.40139 .50814 m .40331 .50861 L .4028 .50855 L F
.703 .97 .931 r
.40485 .50915 m .40569 .50714 L .40743 .50853 L F
.693 .659 .812 r
.57449 .44037 m .57026 .44032 L .57145 .44025 L F
.499 .275 .504 r
.3331 .5713 m .33533 .57091 L .33585 .56793 L F
0 0 .287 r
.33585 .56793 m .33872 .56735 L .33824 .56653 L F
.33585 .56793 m .33533 .57091 L .33872 .56735 L F
.747 .25 0 r
.43472 .56002 m .43461 .5591 L .43336 .55736 L F
.43472 .56002 m .4363 .56113 L .43461 .5591 L F
.839 .795 .809 r
.44965 .57478 m .44937 .57072 L .44931 .57282 L F
.143 .31 .774 r
.45146 .57388 m .44965 .57478 L .44931 .57282 L F
.981 .77 .547 r
.45241 .57679 m .45308 .57402 L .44965 .57478 L F
.143 .31 .774 r
.45146 .57388 m .45241 .57679 L .44965 .57478 L F
.358 .019 .246 r
.23608 .57854 m .23533 .5803 L .23293 .58089 L F
.792 .83 .36 r
.23695 .57534 m .23533 .5803 L .23608 .57854 L F
.255 .709 .954 r
.42679 .4564 m .43058 .45719 L .42925 .45639 L F
.257 .048 .393 r
.54964 .43974 m .54713 .44326 L .54967 .44271 L F
.364 0 0 r
.54713 .44326 m .54901 .44449 L .54967 .44271 L F
.54713 .44326 m .54613 .44352 L .54901 .44449 L F
.231 0 0 r
.57842 .36728 m .58107 .36772 L .58188 .36769 L F
.36 .702 .984 r
.58423 .36663 m .58188 .36769 L .58107 .36772 L F
.58423 .36663 m .5857 .36822 L .58188 .36769 L F
.998 .794 .498 r
.57708 .3784 m .57572 .37695 L .57621 .37397 L F
.088 .437 .876 r
.57708 .3784 m .57719 .3768 L .57572 .37695 L F
.57708 .3784 m .58063 .37988 L .57719 .3768 L F
.264 0 .005 r
.35317 .53509 m .34869 .53788 L .35104 .53831 L F
.54 .344 .564 r
.35104 .53831 m .35449 .538 L .35317 .53509 L F
.264 0 .005 r
.35317 .53509 m .35176 .53734 L .34869 .53788 L F
.614 .59 .803 r
.35404 .53103 m .35546 .53504 L .35317 .53509 L F
.579 .362 .55 r
.35449 .538 m .35578 .53791 L .35317 .53509 L F
.746 .333 .265 r
.35578 .53791 m .35176 .53734 L .35317 .53509 L F
.6 .363 .529 r
.35546 .53504 m .35578 .53791 L .35317 .53509 L F
.657 .166 .073 r
.67844 .32581 m .67714 .32722 L .67439 .3252 L F
.599 .097 .033 r
.6814 .32758 m .67714 .32722 L .67844 .32581 L F
.715 .673 .807 r
.53468 .45032 m .53283 .45117 L .53127 .44987 L F
.812 .999 .795 r
.49809 .40936 m .49628 .41156 L .49715 .40919 L F
.81 1 .81 r
.49628 .41156 m .49419 .41221 L .49715 .40919 L F
.85 .986 .71 r
.47926 .53572 m .47684 .53903 L .47733 .53697 L F
.936 .965 .689 r
.47926 .53572 m .47733 .53697 L .47925 .53296 L F
0 0 .012 r
.4888 .54897 m .48812 .54825 L .48944 .54662 L F
.4888 .54897 m .48769 .55097 L .48812 .54825 L F
.999 .818 .485 r
.5536 .46994 m .5531 .47257 L .55202 .47144 L F
.654 .813 .96 r
.47383 .45129 m .47799 .45165 L .4764 .4496 L F
.711 .775 .902 r
.47799 .45165 m .47885 .44889 L .4764 .4496 L F
.47799 .45165 m .48033 .45041 L .47885 .44889 L F
.716 .76 .887 r
.33246 .54175 m .33432 .54505 L .33025 .5448 L F
0 .002 .576 r
.33272 .54595 m .33478 .54872 L .33389 .54697 L F
.33272 .54595 m .33389 .54697 L .33304 .54531 L F
.381 .145 .426 r
.33272 .54595 m .33025 .5448 L .33148 .54487 L F
.33272 .54595 m .33148 .54487 L .33432 .54505 L F
.618 .868 .99 r
.6124 .40021 m .61609 .40014 L .61505 .39969 L F
.781 .722 .798 r
.61609 .40014 m .6124 .40021 L .61505 .39969 L F
.37 .793 .974 r
.61897 .39971 m .61609 .40014 L .61505 .39969 L F
.61897 .39971 m .61609 .40014 L .61505 .39969 L F
0 .151 .679 r
.2299 .56926 m .23032 .56642 L .22895 .56619 L F
.2299 .56926 m .23156 .57069 L .23032 .56642 L F
0 .149 .682 r
.2299 .56926 m .23149 .57231 L .23156 .57069 L F
.272 .766 .701 r
.24544 .59139 m .24179 .59265 L .24298 .59077 L F
.628 .749 .935 r
.2536 .53793 m .25395 .53903 L .25133 .53901 L F
0 0 0 r
.51901 .43976 m .52216 .43808 L .52038 .43974 L F
.51901 .43976 m .52038 .43974 L .51877 .43904 L F
.775 .689 .769 r
.71428 .30566 m .71823 .30633 L .71693 .30232 L F
.611 .804 .974 r
.71769 .30467 m .71823 .30633 L .71428 .30566 L F
.674 .372 0 r
.71769 .30467 m .71823 .30633 L .71693 .30232 L F
.691 .197 .068 r
.60622 .41947 m .60593 .4181 L .60354 .41719 L F
.834 .677 .688 r
.60622 .41947 m .6092 .41706 L .60593 .4181 L F
.488 .661 .938 r
.52374 .39118 m .52301 .39432 L .52174 .39053 L F
.52374 .39118 m .5254 .39374 L .52301 .39432 L F
.511 .882 .975 r
.44069 .48618 m .43795 .48635 L .4401 .48567 L F
.368 .044 .277 r
.43913 .48773 m .4401 .48567 L .44069 .48618 L F
.606 .93 .964 r
.44069 .48618 m .44322 .48277 L .44325 .48552 L F
.44069 .48618 m .44188 .4844 L .44322 .48277 L F
.44069 .48618 m .4401 .48567 L .44188 .4844 L F
.633 .882 .542 r
.44188 .4844 m .44069 .48618 L .44325 .48552 L F
.44188 .4844 m .43913 .48773 L .44069 .48618 L F
.941 .585 .186 r
.38753 .5775 m .38799 .57984 L .38936 .58093 L F
.988 .882 .547 r
.3877 .58226 m .38936 .58093 L .38799 .57984 L F
.3877 .58226 m .38857 .5835 L .38936 .58093 L F
.926 .703 .582 r
.38331 .56978 m .38647 .56789 L .38455 .5669 L F
.38331 .56978 m .38602 .57073 L .38647 .56789 L F
.321 .356 .742 r
.72534 .28714 m .72731 .28899 L .72619 .28505 L F
.994 .849 .587 r
.72534 .28714 m .72475 .28999 L .72484 .28676 L F
.325 0 0 r
.25175 .54425 m .25051 .54602 L .24852 .5453 L F
.461 .211 .448 r
.60107 .35212 m .59871 .3545 L .59821 .35192 L F
.513 .448 .721 r
.51974 .47242 m .52217 .47239 L .5214 .47136 L F
.303 .45 .843 r
.51974 .47242 m .52183 .47387 L .52217 .47239 L F
.551 .37 .589 r
.65598 .33532 m .65336 .33898 L .65322 .33623 L F
0 .448 .834 r
.3322 .50698 m .33526 .50792 L .33317 .50656 L F
.828 .995 .851 r
.60346 .35712 m .60529 .35418 L .60637 .35562 L F
.585 .822 .989 r
.60972 .35471 m .60637 .35562 L .60529 .35418 L F
.908 .573 .399 r
.38151 .51585 m .37868 .51502 L .3784 .512 L F
.754 .415 .409 r
.38151 .51585 m .37784 .51731 L .37868 .51502 L F
.38151 .51585 m .38204 .51804 L .37784 .51731 L F
0 .309 .799 r
.58565 .35069 m .58743 .35165 L .58619 .34966 L F
.58565 .35069 m .58743 .35165 L .58619 .34966 L F
.892 .938 .838 r
.36309 .55139 m .35842 .55444 L .36085 .55449 L F
.41 .586 .914 r
.36068 .55746 m .35842 .55444 L .36085 .55449 L F
.95 .82 .68 r
.70028 .33735 m .70336 .3348 L .70236 .33318 L F
.70028 .33735 m .702 .33894 L .70336 .3348 L F
.459 0 0 r
.60487 .41833 m .60622 .41947 L .60354 .41719 L F
.752 .552 .626 r
.50117 .45569 m .49783 .45279 L .49935 .45731 L F
.822 .652 .672 r
.51116 .4527 m .51523 .45343 L .514 .4502 L F
.688 .588 .738 r
.514 .4502 m .51523 .45343 L .51787 .45023 L F
.881 .967 .843 r
.36174 .49892 m .36265 .4989 L .36169 .49997 L F
.36185 .49611 m .36169 .49997 L .36008 .49826 L F
.827 .374 .149 r
.36402 .50154 m .36008 .49826 L .36169 .49997 L F
.36402 .50154 m .36354 .50179 L .36075 .49895 L F
.3609 .49895 m .36075 .49895 L .36008 .49826 L F
.36402 .50154 m .36075 .49895 L .3609 .49895 L F
.881 .967 .843 r
.36185 .49611 m .36462 .49668 L .36265 .4989 L F
.36185 .49611 m .36265 .4989 L .36174 .49892 L F
.386 .834 .932 r
.36735 .49596 m .36462 .49668 L .36185 .49611 L F
.536 0 0 r
.36575 .5028 m .36484 .50343 L .36402 .50154 L F
.36575 .5028 m .3684 .5044 L .36484 .50343 L F
.448 0 0 r
.37036 .50522 m .3684 .5044 L .36575 .5028 L F
.809 .962 .908 r
.55001 .47528 m .54813 .47716 L .54574 .47686 L F
.972 .906 .557 r
.58532 .43609 m .58618 .43393 L .58467 .43523 L F
.987 .722 .425 r
.58467 .43523 m .58618 .43393 L .58468 .43259 L F
.53 0 0 r
.26647 .52419 m .26476 .52291 L .26758 .52211 L F
.26647 .52419 m .26448 .52406 L .26476 .52291 L F
.658 .572 .747 r
.53315 .45741 m .53643 .45663 L .53513 .45319 L F
.399 0 .115 r
.53533 .4584 m .53315 .45741 L .53282 .45848 L F
.53533 .4584 m .53643 .45663 L .53315 .45741 L F
.96 .886 .713 r
.59198 .40612 m .5933 .40741 L .59179 .41045 L F
.187 .057 .46 r
.23433 .53839 m .23586 .53759 L .23601 .53485 L F
.318 .205 .565 r
.23425 .54113 m .23586 .53759 L .23433 .53839 L F
.809 .691 .735 r
.56428 .43324 m .5656 .43684 L .56202 .43664 L F
.808 .578 .589 r
.56202 .43664 m .5656 .43684 L .56379 .43993 L F
.839 .756 .77 r
.50805 .44332 m .50974 .4436 L .50871 .43984 L F
.817 .438 .337 r
.50971 .44581 m .50974 .4436 L .50805 .44332 L F
.633 .276 .348 r
.50971 .44581 m .51245 .44569 L .50974 .4436 L F
.601 .298 .428 r
.51245 .44569 m .51285 .44355 L .50974 .4436 L F
0 0 .015 r
.51805 .48267 m .52035 .48166 L .52098 .4796 L F
.017 0 .021 r
.52098 .4796 m .5223 .48057 L .5236 .47894 L F
.52098 .4796 m .52035 .48166 L .5223 .48057 L F
.837 .882 .875 r
.49581 .45178 m .49783 .45279 L .50045 .44976 L F
.546 .32 .523 r
.2694 .59082 m .26908 .59351 L .27179 .59105 L F
.547 .386 .614 r
.2694 .59082 m .27179 .59105 L .27186 .58743 L F
.218 .228 .656 r
.23136 .60311 m .233 .60297 L .23046 .60066 L F
.193 0 .26 r
.68604 .2998 m .68343 .30304 L .68616 .30124 L F
.593 .198 .262 r
.68616 .30124 m .68884 .30158 L .68604 .2998 L F
.567 .235 .365 r
.68604 .2998 m .68884 .30158 L .68874 .29969 L F
.888 .769 .725 r
.56379 .43993 m .56504 .4442 L .56408 .44232 L F
.849 .897 .477 r
.56504 .4442 m .5645 .44411 L .56408 .44232 L F
.56504 .4442 m .5638 .44618 L .5645 .44411 L F
.848 .971 .655 r
.47684 .53903 m .4751 .54056 L .47733 .53697 L F
.573 .375 .575 r
.72764 .30043 m .73069 .30197 L .73064 .29931 L F
.466 0 0 r
.72665 .30212 m .73069 .30197 L .72764 .30043 L F
.479 .898 .872 r
.52458 .50139 m .52454 .50102 L .52251 .50242 L F
0 0 0 r
.52337 .50309 m .52251 .50242 L .52454 .50102 L F
.52337 .50309 m .52169 .50471 L .52251 .50242 L F
.054 .505 .891 r
.59574 .44606 m .59829 .44686 L .59704 .44562 L F
.672 .409 .514 r
.42732 .49565 m .42899 .49607 L .42878 .49417 L F
.808 1 .815 r
.3819 .60578 m .38505 .60399 L .38342 .60307 L F
.363 0 .058 r
.68212 .30365 m .68616 .30124 L .68343 .30304 L F
.952 .921 .562 r
.73061 .30457 m .72988 .30963 L .73178 .30605 L F
.73061 .30457 m .72965 .30712 L .72988 .30963 L F
.946 .898 .506 r
.72988 .30963 m .72852 .31068 L .72932 .31197 L F
.72988 .30963 m .72965 .30712 L .72852 .31068 L F
0 0 .236 r
.42784 .54367 m .42739 .54221 L .42795 .54092 L F
.146 .082 .521 r
.23316 .54818 m .23445 .54743 L .23409 .54483 L F
.058 0 .415 r
.23313 .55096 m .23445 .54743 L .23316 .54818 L F
.535 .278 .472 r
.53152 .41757 m .53116 .42005 L .52823 .4205 L F
.408 .169 .437 r
.53366 .41924 m .53152 .41757 L .53369 .41651 L F
.53366 .41924 m .53116 .42005 L .53152 .41757 L F
.761 .867 .926 r
.72137 .32455 m .72258 .32615 L .72458 .32463 L F
.76 .307 0 r
.59458 .41437 m .59343 .41331 L .59351 .41286 L F
0 .178 .709 r
.59458 .41437 m .59759 .4154 L .59343 .41331 L F
.92 .909 .794 r
.59704 .41493 m .59772 .41551 L .59883 .41399 L F
0 .178 .709 r
.59759 .4154 m .59761 .4154 L .59758 .41539 L F
.59759 .4154 m .59758 .41539 L .59343 .41331 L F
.59458 .41437 m .59629 .41611 L .59759 .41541 L F
.59458 .41437 m .59759 .41541 L .59759 .4154 L F
.92 .909 .794 r
.59516 .41593 m .59772 .41551 L .59758 .41539 L F
.477 0 0 r
.59758 .41539 m .59756 .41539 L .59331 .41402 L F
.92 .909 .794 r
.59636 .41529 m .59758 .41539 L .59704 .41493 L F
.916 .91 .8 r
.59756 .41539 m .59516 .41593 L .59257 .41378 L F
.92 .909 .794 r
.59516 .41593 m .59758 .41539 L .59756 .41539 L F
0 .178 .709 r
.59759 .4154 m .59759 .41541 L .59761 .4154 L F
.916 .91 .8 r
.59761 .4154 m .59516 .41593 L .59756 .41539 L F
.92 .909 .794 r
.59516 .41593 m .59756 .41539 L .59636 .41529 L F
.477 0 0 r
.59343 .41331 m .59758 .41539 L .59331 .41402 L F
.59758 .41539 m .59761 .4154 L .59756 .41539 L F
.573 .034 0 r
.59993 .4183 m .60023 .41886 L .59629 .41611 L F
.60023 .41886 m .60036 .41909 L .59948 .41844 L F
.60023 .41886 m .59948 .41844 L .59629 .41611 L F
.589 .015 0 r
.59629 .41611 m .60036 .41909 L .59646 .41721 L F
.705 .677 .821 r
.59668 .41692 m .60085 .41488 L .59883 .41399 L F
.59646 .41721 m .59685 .41701 L .59668 .41692 L F
.59685 .41701 m .60085 .41488 L .59668 .41692 L F
.92 .909 .794 r
.59745 .41564 m .59646 .41721 L .59764 .41562 L F
.589 .015 0 r
.59759 .41541 m .59646 .41721 L .59761 .4154 L F
.59629 .41611 m .59646 .41721 L .59759 .41541 L F
.92 .909 .794 r
.59516 .41593 m .59646 .41721 L .59745 .41564 L F
.59762 .41552 m .59764 .41562 L .59772 .41551 L F
.59516 .41593 m .59764 .41562 L .59762 .41552 L F
.477 0 0 r
.59343 .41331 m .59331 .41402 L .59257 .41378 L F
.76 .307 0 r
.59351 .41286 m .59343 .41331 L .59179 .41045 L F
.466 .554 .862 r
.52995 .40969 m .53058 .40587 L .52885 .40813 L F
.52995 .40969 m .53237 .4095 L .53058 .40587 L F
0 0 0 r
.65081 .32839 m .65321 .32721 L .65444 .32653 L F
.65444 .32653 m .65597 .32638 L .65676 .32474 L F
.65444 .32653 m .65321 .32721 L .65597 .32638 L F
.66064 .37654 m .66168 .37509 L .65861 .37782 L F
.051 0 0 r
.66431 .37415 m .66168 .37509 L .66064 .37654 L F
.332 .815 .851 r
.43278 .44708 m .4322 .4478 L .43051 .4484 L F
.43278 .44708 m .43479 .44708 L .4322 .4478 L F
.132 0 .179 r
.51805 .48267 m .51982 .48393 L .52035 .48166 L F
.51805 .48267 m .51764 .48524 L .51982 .48393 L F
.652 .127 0 r
.53968 .47809 m .53731 .47601 L .53743 .47945 L F
.863 .954 .868 r
.69733 .27831 m .69612 .28041 L .69599 .27741 L F
.043 .033 .518 r
.69505 .28203 m .69599 .27741 L .69612 .28041 L F
.595 .574 .8 r
.69733 .27831 m .69831 .28122 L .69612 .28041 L F
.318 .758 .965 r
.29049 .50781 m .29471 .50835 L .2923 .50907 L F
.29049 .50781 m .29471 .50835 L .2923 .50907 L F
.712 .972 .739 r
.4706 .42879 m .47224 .42806 L .46946 .43077 L F
.665 .951 .953 r
.4706 .42879 m .46946 .43077 L .46826 .43025 L F
.84 .908 .5 r
.6693 .36447 m .66755 .36831 L .66785 .36621 L F
.635 .951 .942 r
.6718 .36306 m .6693 .36447 L .67067 .3625 L F
.602 .84 .466 r
.67067 .3625 m .6693 .36447 L .66785 .36621 L F
.715 .38 .41 r
.28264 .59089 m .27818 .59293 L .27864 .59116 L F
.28264 .59089 m .28231 .59313 L .27818 .59293 L F
.651 .459 .61 r
.28535 .58998 m .28231 .59313 L .28264 .59089 L F
.804 .44 0 r
.38679 .58973 m .38855 .59361 L .38767 .59115 L F
.713 .578 .702 r
.28016 .58253 m .28219 .58349 L .28383 .57999 L F
.236 .738 .673 r
.28529 .57948 m .28646 .57908 L .28383 .57999 L F
0 0 .154 r
.28219 .58349 m .28529 .57948 L .28383 .57999 L F
.367 .219 .544 r
.3278 .56429 m .32784 .56739 L .32584 .56811 L F
.27 .01 .323 r
.32784 .56739 m .3253 .57059 L .32584 .56811 L F
.914 .976 .697 r
.46435 .58085 m .46591 .57659 L .4675 .57775 L F
.966 .721 .285 r
.46656 .57389 m .4675 .57775 L .46591 .57659 L F
.828 .995 .851 r
.60346 .35712 m .60217 .3573 L .60529 .35418 L F
.5 .657 .93 r
.5998 .4378 m .60146 .43989 L .59994 .43748 L F
.941 .632 .425 r
.59946 .44165 m .60146 .43989 L .5998 .4378 L F
.59946 .44165 m .60254 .44522 L .60146 .43989 L F
.7 .753 .893 r
.59994 .43748 m .60146 .43989 L .60344 .43759 L F
.65 .919 .625 r
.60344 .43759 m .60146 .43989 L .60291 .43806 L F
.941 .632 .425 r
.60146 .43989 m .60369 .44242 L .60291 .43806 L F
.60146 .43989 m .60254 .44522 L .59946 .44165 L F
.60146 .43989 m .59946 .44165 L .60369 .44242 L F
.673 .812 .95 r
.34085 .51696 m .33785 .5182 L .34216 .51885 L F
0 .11 .656 r
.34216 .51885 m .34438 .52112 L .34339 .51908 L F
0 0 .404 r
.35936 .61359 m .36064 .61543 L .3604 .61208 L F
.35936 .61359 m .35999 .61593 L .36064 .61543 L F
.35999 .61593 m .3601 .61633 L .36064 .61543 L F
0 0 0 r
.36064 .61543 m .35855 .61793 L .35719 .61566 L F
.36064 .61543 m .35719 .61566 L .35928 .61614 L F
.393 .826 .673 r
.36084 .61526 m .36064 .61543 L .35928 .61614 L F
.346 .211 .551 r
.36082 .61249 m .36064 .61543 L .36262 .61427 L F
.3604 .61208 m .36044 .61264 L .36082 .61249 L F
.36044 .61264 m .36064 .61543 L .36082 .61249 L F
.3604 .61208 m .36262 .61427 L .36286 .61156 L F
0 0 0 r
.36221 .61194 m .36082 .61315 L .35884 .61392 L F
.36286 .61156 m .36254 .61181 L .36221 .61194 L F
.36254 .61181 m .36082 .61315 L .36221 .61194 L F
.393 .826 .673 r
.36262 .61427 m .36064 .61543 L .36084 .61526 L F
.966 .861 .685 r
.43008 .59402 m .42847 .59359 L .42837 .59076 L F
.763 .828 .903 r
.42837 .59076 m .43008 .59402 L .43156 .59188 L F
.966 .861 .685 r
.42837 .59076 m .42847 .59359 L .43008 .59402 L F
.471 .077 .21 r
.42847 .59359 m .43156 .59188 L .43008 .59402 L F
.583 .55 .783 r
.53127 .44987 m .53513 .45319 L .53468 .45032 L F
.382 .22 .534 r
.53513 .45319 m .53664 .44967 L .53468 .45032 L F
.808 1 .813 r
.34813 .52544 m .34581 .52738 L .34709 .52729 L F
.582 .052 0 r
.27486 .59585 m .27331 .59405 L .2759 .59356 L F
.27486 .59585 m .27143 .59546 L .27331 .59405 L F
.436 .387 .704 r
.23569 .56698 m .23698 .57177 L .23427 .57047 L F
0 .307 .7 r
.23698 .57177 m .2372 .57198 L .23427 .57047 L F
.214 .464 .881 r
.62588 .3476 m .62652 .34533 L .62363 .34583 L F
.62588 .3476 m .62711 .34738 L .62652 .34533 L F
.49 .824 .999 r
.28044 .64331 m .28306 .6427 L .2812 .64168 L F
.845 .43 .247 r
.42463 .53962 m .42715 .53891 L .42549 .53706 L F
.42463 .53962 m .42795 .54092 L .42715 .53891 L F
.977 .685 .307 r
.57787 .39544 m .57927 .39419 L .57833 .39236 L F
.57787 .39544 m .57962 .39705 L .57927 .39419 L F
.422 0 0 r
.3201 .57535 m .31799 .57586 L .31519 .57512 L F
.865 .996 .777 r
.32043 .5729 m .3201 .57535 L .32283 .57407 L F
.32043 .5729 m .31799 .57586 L .3201 .57535 L F
.382 0 0 r
.44289 .56968 m .43777 .57121 L .43964 .57194 L F
.25 0 0 r
.44355 .56997 m .44289 .56968 L .43964 .57194 L F
.44355 .56997 m .44433 .5702 L .44289 .56968 L F
.417 .856 .755 r
.53426 .48197 m .53204 .48313 L .5301 .48372 L F
.802 .458 .406 r
.34453 .57912 m .34618 .5798 L .34813 .57766 L F
0 0 .281 r
.34743 .57631 m .34819 .57745 L .34699 .57684 L F
.34743 .57631 m .34699 .57684 L .34463 .57565 L F
.882 .585 .071 r
.34721 .57426 m .34768 .576 L .34743 .57631 L F
.34768 .576 m .34813 .57766 L .34743 .57631 L F
0 0 0 r
.34813 .57766 m .34618 .5798 L .34806 .57851 L F
.34813 .57766 m .34806 .57851 L .34743 .57631 L F
.272 .777 .787 r
.43479 .44708 m .43743 .44635 L .43862 .44624 L F
.46 .888 .876 r
.43743 .44635 m .44096 .4454 L .43862 .44624 L F
.03 0 .27 r
.23739 .58664 m .23885 .58631 L .23936 .58371 L F
0 .033 .563 r
.23739 .58664 m .2393 .58923 L .23885 .58631 L F
.663 .388 .493 r
.53742 .40387 m .54292 .40358 L .54167 .40223 L F
.304 .338 .732 r
.54167 .40223 m .54292 .40358 L .544 .40292 L F
.841 .754 .239 r
.60972 .35471 m .60925 .35753 L .60955 .35705 L F
.489 .285 .53 r
.4473 .48874 m .44996 .48814 L .44737 .48608 L F
.4473 .48874 m .44996 .48814 L .44737 .48608 L F
0 0 0 r
.30901 .57381 m .30695 .57565 L .30564 .57747 L F
0 0 .391 r
.23149 .57231 m .23235 .57254 L .23156 .57069 L F
.23149 .57231 m .23173 .57434 L .23235 .57254 L F
0 0 .141 r
.55242 .42691 m .55099 .43024 L .55286 .42866 L F
.793 .694 .756 r
.40973 .50522 m .4112 .50901 L .41421 .50529 L F
.017 .235 .741 r
.23173 .57434 m .23392 .57628 L .23235 .57254 L F
.401 .289 .611 r
.23173 .57434 m .23183 .57677 L .23392 .57628 L F
.798 .83 .876 r
.3724 .49099 m .37398 .49293 L .37057 .49507 L F
.619 .77 .953 r
.37614 .4917 m .37398 .49293 L .3724 .49099 L F
.323 .413 .799 r
.32178 .5809 m .32437 .58275 L .32344 .58019 L F
0 0 0 r
.32178 .5809 m .32344 .58019 L .32451 .57861 L F
.703 .764 .9 r
.32323 .58401 m .32437 .58275 L .32178 .5809 L F
.231 .748 .849 r
.41224 .48232 m .41122 .48212 L .40984 .48249 L F
.40984 .48249 m .41122 .48212 L .41224 .48232 L F
.581 .944 .887 r
.4134 .48084 m .41122 .48212 L .41224 .48232 L F
.41224 .48232 m .41122 .48212 L .4134 .48084 L F
.4 .197 .485 r
.25104 .62402 m .2502 .62508 L .25191 .62636 L F
0 0 0 r
.50368 .52264 m .50515 .5208 L .5024 .52432 L F
0 0 .446 r
.35176 .53734 m .35104 .53831 L .34869 .53788 L F
.532 .314 .528 r
.35104 .53831 m .35199 .54126 L .35449 .538 L F
0 0 .446 r
.35176 .53734 m .35199 .54126 L .35104 .53831 L F
.681 .901 .975 r
.61123 .40847 m .61294 .40596 L .6096 .40889 L F
.61123 .40847 m .61379 .40722 L .61294 .40596 L F
.331 0 .077 r
.2798 .58611 m .28219 .58349 L .28016 .58253 L F
.2798 .58611 m .2825 .58576 L .28219 .58349 L F
0 0 .154 r
.28219 .58349 m .28468 .58208 L .28529 .57948 L F
.124 0 .095 r
.28219 .58349 m .28433 .58491 L .28468 .58208 L F
.28219 .58349 m .2825 .58576 L .28433 .58491 L F
.621 .739 .931 r
.59897 .42363 m .59783 .42678 L .59785 .42609 L F
.59897 .42363 m .60145 .42582 L .59783 .42678 L F
.795 .821 .872 r
.46578 .44965 m .46721 .45239 L .46958 .44961 L F
.642 .965 .829 r
.62693 .38762 m .62286 .38972 L .62549 .38819 L F
.202 0 0 r
.62975 .38781 m .62693 .38762 L .62549 .38819 L F
.667 .395 .5 r
.60173 .40043 m .60504 .40019 L .60552 .39782 L F
.048 0 0 r
.60737 .39794 m .60552 .39782 L .60504 .40019 L F
.60737 .39794 m .60829 .39767 L .60552 .39782 L F
.941 .676 .505 r
.43119 .56679 m .43317 .56447 L .43172 .5633 L F
.43119 .56679 m .43319 .56749 L .43317 .56447 L F
.857 .912 .869 r
.43172 .5633 m .43317 .56447 L .4363 .56113 L F
.309 .052 .351 r
.49359 .51207 m .4965 .50881 L .49323 .50895 L F
.675 .248 .225 r
.56509 .44977 m .55999 .44926 L .56212 .45011 L F
.882 .845 .804 r
.56723 .43089 m .56795 .43351 L .56809 .4326 L F
.709 .77 .9 r
.43823 .47788 m .43972 .48042 L .44184 .47904 L F
.751 .744 .846 r
.5236 .47894 m .52763 .47946 L .52639 .4759 L F
.69 .217 .123 r
.5227 .48006 m .52575 .48109 L .5236 .47894 L F
.5223 .48057 m .524 .48083 L .5227 .48006 L F
.524 .48083 m .52575 .48109 L .5227 .48006 L F
.968 .928 .611 r
.52575 .48109 m .52763 .47946 L .52556 .47919 L F
.52575 .48109 m .52556 .47919 L .5236 .47894 L F
.52575 .48109 m .52619 .48369 L .52763 .47946 L F
.402 .483 .828 r
.52874 .48317 m .52831 .48336 L .52469 .47937 L F
.488 .797 .999 r
.52679 .48407 m .52619 .48369 L .52575 .48109 L F
.867 .511 .011 r
.52584 .48194 m .52679 .48407 L .52575 .48109 L F
.402 .483 .828 r
.52831 .48336 m .52679 .48407 L .52582 .4819 L F
.673 .81 .948 r
.52469 .47937 m .52575 .48109 L .5223 .48057 L F
.867 .511 .011 r
.52469 .47937 m .52584 .48194 L .52575 .48109 L F
.402 .483 .828 r
.52831 .48336 m .52582 .4819 L .52469 .47937 L F
.812 .775 .818 r
.52639 .4759 m .52763 .47946 L .53042 .47627 L F
.875 .587 .497 r
.37675 .54779 m .37816 .55157 L .38001 .55139 L F
.914 .692 .587 r
.37797 .55348 m .38001 .55139 L .37816 .55157 L F
.37797 .55348 m .37974 .55428 L .38001 .55139 L F
.501 .3 .54 r
.59426 .35584 m .59302 .35512 L .59597 .35559 L F
.59426 .35584 m .59152 .35429 L .59302 .35512 L F
.486 .186 .381 r
.27707 .58655 m .28016 .58253 L .27733 .58438 L F
.27707 .58655 m .2798 .58611 L .28016 .58253 L F
.905 .494 .169 r
.35799 .51753 m .36093 .52143 L .36099 .51895 L F
.048 .248 .745 r
.23912 .57288 m .2372 .57198 L .23698 .57177 L F
.23912 .57288 m .2388 .57468 L .2372 .57198 L F
.973 .753 .326 r
.69864 .34964 m .69955 .34866 L .69896 .34721 L F
.69864 .34964 m .6995 .35095 L .69955 .34866 L F
.691 .699 .853 r
.3237 .53009 m .32485 .5321 L .32062 .53141 L F
.736 .432 .465 r
.32485 .5321 m .32357 .53354 L .32062 .53141 L F
.789 .736 .804 r
.32702 .52983 m .32485 .5321 L .3237 .53009 L F
.711 .222 .082 r
.32494 .53312 m .32717 .53422 L .32485 .5321 L F
.789 .736 .804 r
.32702 .52983 m .3237 .53009 L .32571 .52934 L F
.156 .279 .74 r
.32485 .5321 m .32571 .52934 L .32357 .53354 L F
.32485 .5321 m .32717 .53422 L .32571 .52934 L F
.798 .83 .876 r
.3724 .49099 m .37057 .49507 L .36881 .49413 L F
0 .234 .725 r
.41915 .52634 m .42041 .52784 L .41819 .52643 L F
.776 .688 .767 r
.61306 .35831 m .61433 .3618 L .61154 .36108 L F
.694 .196 .053 r
.61433 .3618 m .61322 .36305 L .61154 .36108 L F
.534 .553 .821 r
.6164 .36082 m .61433 .3618 L .61306 .35831 L F
.25 0 0 r
.6164 .36082 m .61322 .36305 L .61433 .3618 L F
.758 .664 .758 r
.57629 .36442 m .57486 .36835 L .57842 .36728 L F
.223 0 .251 r
.57486 .36835 m .57706 .36749 L .57842 .36728 L F
.545 .537 .797 r
.23293 .58089 m .23392 .57628 L .23183 .57677 L F
.23293 .58089 m .23533 .5803 L .23392 .57628 L F
.355 .798 .957 r
.46787 .59476 m .4659 .59407 L .46265 .5942 L F
.479 .886 .94 r
.47023 .59352 m .4659 .59407 L .46787 .59476 L F
.512 .908 .787 r
.29957 .6476 m .30206 .64627 L .30103 .64745 L F
.543 .505 .763 r
.30206 .64627 m .30484 .64838 L .30332 .64631 L F
.084 0 0 r
.30103 .64745 m .30206 .64627 L .30332 .64631 L F
.458 0 0 r
.42735 .59798 m .43001 .59893 L .42581 .59932 L F
.67 .513 .664 r
.69779 .29 m .698 .29282 L .70062 .28932 L F
.823 .898 .894 r
.67919 .34283 m .67382 .34412 L .67758 .34114 L F
.848 .84 .836 r
.68021 .34135 m .67919 .34283 L .67758 .34114 L F
.915 .607 .448 r
.71268 .30693 m .71212 .30841 L .71005 .30583 L F
.71268 .30693 m .71428 .30566 L .71212 .30841 L F
.607 .954 .856 r
.44888 .44113 m .44742 .44287 L .44667 .44245 L F
.44888 .44113 m .45138 .44065 L .44742 .44287 L F
.751 .71 .814 r
.51245 .44569 m .514 .4502 L .51645 .44621 L F
.684 .62 .777 r
.514 .4502 m .51787 .45023 L .51645 .44621 L F
.523 .24 .427 r
.42485 .57991 m .4264 .5775 L .42293 .57784 L F
0 .046 .605 r
.42444 .57881 m .42293 .57784 L .42268 .57633 L F
.42444 .57881 m .42485 .57991 L .42293 .57784 L F
0 0 0 r
.65861 .37782 m .65538 .38074 L .65772 .37937 L F
.66064 .37654 m .65861 .37782 L .65772 .37937 L F
.98 .788 .574 r
.34761 .567 m .34932 .5678 L .34851 .56442 L F
0 .172 .704 r
.3501 .56634 m .34932 .5678 L .34761 .567 L F
.551 .917 .951 r
.3142 .60662 m .31441 .60549 L .31648 .60577 L F
0 0 .563 r
.3142 .60662 m .316 .60929 L .31441 .60549 L F
.386 .746 .992 r
.4166 .5971 m .41972 .59783 L .4186 .5974 L F
.477 0 0 r
.41972 .59783 m .42213 .59949 L .4186 .5974 L F
.41972 .59783 m .42347 .59886 L .42213 .59949 L F
.955 .796 .35 r
.5628 .42039 m .56271 .41773 L .56292 .41781 L F
.572 .063 0 r
.56211 .41666 m .56331 .41797 L .56292 .41781 L F
.38 .373 .726 r
.55954 .41726 m .56292 .41781 L .56222 .41411 L F
.955 .796 .35 r
.56271 .41773 m .56268 .41686 L .56292 .41781 L F
.572 .063 0 r
.56331 .41797 m .5646 .41937 L .56292 .41781 L F
.976 .718 .476 r
.7223 .28422 m .72449 .28344 L .72229 .28156 L F
.725 .228 .055 r
.7223 .28422 m .72449 .28344 L .72229 .28156 L F
.671 .526 .679 r
.44322 .48277 m .44604 .47934 L .44184 .47904 L F
.44322 .48277 m .44535 .48228 L .44604 .47934 L F
.943 .905 .755 r
.44188 .4844 m .44535 .48228 L .44322 .48277 L F
.008 .209 .721 r
.42258 .53107 m .42508 .53335 L .42408 .53473 L F
.951 .731 .57 r
.58314 .42607 m .58472 .42994 L .58502 .42723 L F
.95 .922 .746 r
.57444 .44937 m .57294 .45337 L .57143 .45211 L F
.984 .71 .342 r
.57143 .45211 m .57294 .45337 L .57288 .45579 L F
.896 .978 .689 r
.40251 .45506 m .40149 .45676 L .40142 .45508 L F
0 0 0 r
.40431 .45478 m .40369 .45484 L .40251 .45506 L F
.40431 .45478 m .40251 .45506 L .40142 .45508 L F
.501 .902 .925 r
.6142 .35017 m .61905 .34927 L .61678 .34928 L F
.651 .903 .579 r
.62034 .34736 m .61905 .34927 L .62076 .34715 L F
.681 .974 .909 r
.61678 .34928 m .61905 .34927 L .62034 .34736 L F
.808 .32 0 r
.37215 .50809 m .3684 .5044 L .37036 .50522 L F
.829 .367 .112 r
.37421 .50866 m .37215 .50809 L .37036 .50522 L F
.989 .768 .511 r
.69912 .36107 m .69951 .35857 L .69791 .35699 L F
.837 .585 .558 r
.52433 .43886 m .52038 .43974 L .52216 .43808 L F
.622 .635 .842 r
.44193 .46059 m .44421 .45923 L .44027 .45813 L F
0 .001 .57 r
.4101 .4534 m .40915 .45475 L .40767 .45461 L F
.4101 .4534 m .4113 .45787 L .40915 .45475 L F
.532 .923 .844 r
.45334 .43942 m .45138 .44065 L .44888 .44113 L F
.689 .446 .55 r
.23912 .57288 m .23695 .57534 L .2388 .57468 L F
0 0 0 r
.50474 .50132 m .5061 .50005 L .50677 .49842 L F
.493 .841 .572 r
.50474 .50132 m .50419 .5017 L .5061 .50005 L F
.696 .635 .784 r
.51052 .463 m .51461 .46379 L .51288 .46249 L F
.937 .591 .344 r
.51245 .46425 m .51461 .46379 L .51288 .46249 L F
.833 .666 .674 r
.33725 .59031 m .33539 .59023 L .33597 .5871 L F
.665 .397 .504 r
.33725 .59031 m .33316 .59315 L .33539 .59023 L F
.33725 .59031 m .33707 .59342 L .33316 .59315 L F
.583 .594 .829 r
.3386 .58664 m .33725 .59031 L .33597 .5871 L F
.3386 .58664 m .34013 .59019 L .33725 .59031 L F
.583 .339 .512 r
.34013 .59019 m .33707 .59342 L .33725 .59031 L F
.879 .62 .541 r
.36706 .531 m .36931 .53425 L .36933 .5317 L F
.821 .372 .168 r
.37612 .51119 m .37215 .50809 L .37421 .50866 L F
.791 .301 .043 r
.3784 .512 m .37612 .51119 L .37421 .50866 L F
.793 .295 0 r
.31354 .59053 m .31755 .59387 L .31362 .59345 L F
.411 .484 .824 r
.31522 .59292 m .3155 .59287 L .31369 .59355 L F
.438 .818 .991 r
.31326 .59371 m .31755 .59387 L .31312 .5934 L F
.411 .484 .824 r
.31368 .59354 m .31369 .59355 L .31326 .59371 L F
.31522 .59292 m .31369 .59355 L .31368 .59354 L F
.793 .295 0 r
.3132 .59286 m .31362 .59345 L .31312 .5934 L F
.31354 .59053 m .31362 .59345 L .3132 .59286 L F
.31354 .59053 m .31522 .59292 L .31755 .59387 L F
.438 .818 .991 r
.31326 .59371 m .3155 .59287 L .31755 .59387 L F
.803 .907 .913 r
.31755 .59387 m .31863 .5908 L .32044 .59122 L F
.31755 .59387 m .31522 .59292 L .31863 .5908 L F
.763 .282 .095 r
.32034 .59533 m .3155 .59287 L .31755 .59387 L F
.907 .818 .348 r
.4013 .45851 m .40142 .45508 L .40149 .45676 L F
.606 .101 0 r
.33963 .5544 m .34198 .55709 L .34058 .55583 L F
.34198 .55709 m .34203 .55714 L .34058 .55583 L F
.569 .833 .995 r
.33933 .55472 m .34058 .55583 L .3387 .55468 L F
.606 .101 0 r
.33963 .5544 m .34058 .55583 L .34228 .55421 L F
.679 .574 .73 r
.34633 .55743 m .34284 .55827 L .34228 .55421 L F
.993 .757 .469 r
.34228 .55421 m .34203 .55714 L .34058 .55583 L F
.679 .574 .73 r
.34633 .55743 m .34228 .55421 L .34203 .55714 L F
.569 .833 .995 r
.34399 .55503 m .34058 .55583 L .33933 .55472 L F
0 0 0 r
.29842 .5831 m .29804 .58391 L .29813 .58339 L F
.29804 .58391 m .29702 .58609 L .29775 .5843 L F
.29804 .58391 m .29775 .5843 L .29813 .58339 L F
.437 .499 .825 r
.2947 .58034 m .29806 .58387 L .29919 .58233 L F
.29806 .58387 m .29816 .58398 L .29919 .58233 L F
.816 .53 .505 r
.29274 .58277 m .29803 .58395 L .2947 .58034 L F
.29803 .58395 m .29816 .58398 L .29806 .58387 L F
.29803 .58395 m .29806 .58387 L .2947 .58034 L F
.559 .61 .86 r
.29803 .58395 m .29702 .58609 L .29816 .58398 L F
.29274 .58277 m .29702 .58609 L .29803 .58395 L F
0 0 0 r
.29919 .58233 m .29702 .58609 L .29816 .58398 L F
.29919 .58233 m .29717 .58581 L .29803 .58395 L F
.29844 .58308 m .29803 .58395 L .29842 .5831 L F
.29919 .58233 m .29803 .58395 L .29844 .58308 L F
.29717 .58581 m .29702 .58609 L .29842 .5831 L F
.457 .857 .674 r
.66599 .38604 m .66751 .38529 L .66974 .3838 L F
.643 .966 .832 r
.61789 .41111 m .61504 .41338 L .61634 .41151 L F
0 0 0 r
.61634 .41151 m .61504 .41338 L .6144 .41536 L F
.5161 .50813 m .51323 .51125 L .51424 .50949 L F
.474 .227 .458 r
.23885 .53134 m .23601 .53485 L .2388 .53201 L F
.439 .199 .451 r
.2388 .53201 m .24131 .53261 L .23885 .53134 L F
.778 .312 .139 r
.45885 .57781 m .46435 .58085 L .46084 .58096 L F
.968 .678 .427 r
.46435 .58085 m .46025 .583 L .46084 .58096 L F
.778 .312 .139 r
.45885 .57781 m .46316 .58147 L .46435 .58085 L F
.968 .678 .427 r
.46435 .58085 m .46316 .58147 L .46342 .58134 L F
.46435 .58085 m .46437 .58366 L .46316 .58147 L F
0 .347 .735 r
.46495 .58237 m .46316 .58147 L .46437 .58366 L F
.968 .678 .427 r
.46342 .58134 m .46316 .58147 L .46025 .583 L F
.566 .938 .861 r
.4618 .58142 m .46025 .583 L .46249 .58183 L F
.4618 .58142 m .46249 .58183 L .46316 .58147 L F
.646 .158 0 r
.46133 .58115 m .4618 .58142 L .46038 .58008 L F
.6 .743 .945 r
.4629 .58291 m .46318 .58463 L .46222 .5824 L F
.4629 .58291 m .46222 .5824 L .4618 .58142 L F
.96 .637 .355 r
.46437 .58366 m .46311 .58509 L .46495 .58237 L F
.46311 .58509 m .46312 .58503 L .46495 .58237 L F
.46296 .58525 m .46297 .58524 L .46495 .58237 L F
.548 .633 .887 r
.46258 .58727 m .46488 .58583 L .46437 .58366 L F
.96 .637 .355 r
.46437 .58366 m .46488 .58583 L .4633 .58537 L F
.108 0 .03 r
.46312 .58503 m .46618 .58292 L .46495 .58237 L F
.247 .062 .421 r
.46495 .58237 m .46832 .58144 L .46664 .583 L F
0 .347 .735 r
.46495 .58237 m .46664 .583 L .46581 .58264 L F
.108 0 .03 r
.46618 .58292 m .46532 .58227 L .46495 .58237 L F
0 .347 .735 r
.46495 .58237 m .46581 .58264 L .46316 .58147 L F
.108 0 .03 r
.46578 .58262 m .46698 .58207 L .46532 .58227 L F
.46698 .58207 m .46832 .58144 L .46729 .58173 L F
.46698 .58207 m .46729 .58173 L .46532 .58227 L F
.46595 .58257 m .46832 .58144 L .46578 .58262 L F
.7 .796 .924 r
.46664 .583 m .46674 .58232 L .46644 .58242 L F
.403 .404 .747 r
.46581 .58264 m .46664 .583 L .46644 .58242 L F
.108 0 .03 r
.46739 .58208 m .46832 .58144 L .46581 .58264 L F
.7 .796 .924 r
.46644 .58242 m .46738 .57792 L .46513 .57866 L F
.46674 .58232 m .46738 .57792 L .46644 .58242 L F
.46674 .58232 m .46594 .58041 L .46738 .57792 L F
.46652 .58256 m .46594 .58041 L .46674 .58232 L F
.46652 .58256 m .46707 .58222 L .46594 .58041 L F
.46707 .58222 m .46832 .58144 L .46764 .58115 L F
.46707 .58222 m .46764 .58115 L .46594 .58041 L F
.46664 .583 m .46652 .58256 L .46674 .58232 L F
.46664 .583 m .46832 .58144 L .46652 .58256 L F
.108 0 .03 r
.46634 .5828 m .46739 .58208 L .46715 .58217 L F
.46619 .58276 m .46715 .58217 L .46581 .58264 L F
.46634 .5828 m .46715 .58217 L .46619 .58276 L F
.914 .976 .697 r
.46435 .58085 m .46316 .58147 L .46591 .57659 L F
.403 .404 .747 r
.46316 .58147 m .46581 .58264 L .46513 .57866 L F
.108 0 .03 r
.46581 .58264 m .46595 .58257 L .46578 .58262 L F
.403 .404 .747 r
.46581 .58264 m .46644 .58242 L .46513 .57866 L F
.405 0 0 r
.46628 .58285 m .46664 .583 L .46624 .58287 L F
.108 0 .03 r
.46618 .58292 m .46634 .5828 L .46581 .58264 L F
.405 0 0 r
.46316 .58147 m .46581 .58264 L .46269 .58171 L F
.765 .667 .754 r
.4618 .58142 m .46313 .58493 L .45898 .58487 L F
.46313 .58493 m .46292 .58533 L .45898 .58487 L F
.754 .787 .88 r
.46366 .58228 m .46296 .58525 L .4629 .58291 L F
.405 0 0 r
.46581 .58264 m .46599 .58278 L .46269 .58171 L F
.46599 .58278 m .46587 .58275 L .46269 .58171 L F
.754 .787 .88 r
.46594 .58041 m .46466 .58249 L .46366 .58228 L F
.6 .743 .945 r
.46315 .58483 m .46317 .58492 L .46313 .58493 L F
.46317 .58492 m .46319 .58502 L .46318 .585 L F
.46317 .58492 m .46318 .585 L .46313 .58493 L F
.754 .787 .88 r
.46466 .58249 m .46317 .58492 L .46366 .58228 L F
.46317 .58492 m .46296 .58525 L .46312 .58458 L F
.46317 .58492 m .46312 .58458 L .46366 .58228 L F
.405 0 0 r
.46599 .58278 m .46602 .5828 L .46587 .58275 L F
.765 .667 .754 r
.46296 .58525 m .4633 .58537 L .46292 .58533 L F
.96 .637 .355 r
.46296 .58525 m .4633 .58537 L .46296 .58525 L F
.46437 .58366 m .4633 .58537 L .46296 .58525 L F
.765 .667 .754 r
.46318 .58506 m .4633 .58537 L .46297 .58524 L F
.108 0 .03 r
.46296 .58525 m .4632 .58508 L .46318 .58506 L F
.96 .637 .355 r
.46311 .58509 m .46296 .58525 L .46312 .58503 L F
.108 0 .03 r
.46297 .58524 m .46318 .58506 L .46312 .58503 L F
.46296 .58525 m .46318 .58506 L .46297 .58524 L F
.765 .667 .754 r
.46297 .58524 m .4633 .58537 L .46296 .58525 L F
.46313 .58493 m .46318 .58506 L .46297 .58524 L F
.108 0 .03 r
.4632 .58508 m .46832 .58144 L .46312 .58503 L F
.754 .787 .88 r
.46594 .58041 m .46832 .58144 L .4632 .58508 L F
.6 .743 .945 r
.46325 .5851 m .46318 .58506 L .46313 .58493 L F
.96 .637 .355 r
.46296 .58525 m .46296 .58525 L .46297 .58524 L F
.754 .787 .88 r
.46317 .58492 m .4632 .58508 L .46296 .58525 L F
.46594 .58041 m .4632 .58508 L .46317 .58492 L F
.6 .743 .945 r
.46318 .58463 m .46325 .5851 L .46319 .58502 L F
.46318 .58463 m .46319 .58502 L .46315 .58483 L F
.46325 .5851 m .4633 .58537 L .46318 .58506 L F
.46318 .58463 m .46313 .58493 L .4618 .58142 L F
.4629 .58291 m .46296 .58525 L .4633 .58537 L F
0 0 .479 r
.46523 .58464 m .4629 .58291 L .46253 .58524 L F
.46552 .58458 m .4629 .58291 L .46523 .58464 L F
.765 .667 .754 r
.4618 .58142 m .45898 .58487 L .46025 .583 L F
.646 .158 0 r
.4629 .58291 m .4618 .58142 L .46133 .58115 L F
.405 0 0 r
.46316 .58147 m .46269 .58171 L .4618 .58142 L F
.787 .697 .765 r
.72746 .31494 m .73053 .31594 L .72932 .31197 L F
.807 .663 .704 r
.72859 .31829 m .73053 .31594 L .72746 .31494 L F
.553 .39 .615 r
.27186 .58743 m .2745 .59027 L .27467 .58711 L F
.27186 .58743 m .27179 .59105 L .2745 .59027 L F
.926 .905 .784 r
.58296 .44517 m .58577 .44412 L .58428 .4428 L F
.58296 .44517 m .58427 .44659 L .58577 .44412 L F
.447 .618 .924 r
.43394 .57422 m .43664 .57747 L .43722 .57502 L F
.831 .979 .882 r
.43722 .57502 m .43664 .57747 L .43524 .57696 L F
.961 .703 .5 r
.68446 .3289 m .68211 .33028 L .6814 .32758 L F
.68446 .3289 m .68471 .33149 L .68211 .33028 L F
.804 1 .814 r
.35855 .54758 m .35625 .54829 L .35866 .54609 L F
.347 .675 .977 r
.35866 .54609 m .361 .54752 L .35855 .54758 L F
.884 .749 .708 r
.41532 .51607 m .41341 .51645 L .41539 .51621 L F
.375 0 0 r
.41497 .51557 m .41619 .51589 L .41904 .51533 L F
0 0 .394 r
.41425 .5139 m .41539 .51621 L .41497 .51557 L F
.884 .749 .708 r
.41425 .5139 m .41341 .51644 L .41532 .51607 L F
.41341 .51644 m .41341 .51645 L .41532 .51607 L F
.375 0 0 r
.41904 .51533 m .41799 .51638 L .41956 .5153 L F
.41619 .51589 m .41799 .51638 L .41904 .51533 L F
.849 .627 .602 r
.42038 .51664 m .41956 .5153 L .41799 .51638 L F
.42038 .51664 m .42242 .51455 L .41956 .5153 L F
.447 0 0 r
.32571 .52934 m .32994 .52986 L .32702 .52983 L F
.635 .126 .02 r
.34139 .59963 m .34347 .60135 L .34561 .59992 L F
.917 .964 .65 r
.34561 .59992 m .34347 .60135 L .34533 .5974 L F
.808 .682 .725 r
.33707 .59342 m .34189 .59427 L .34013 .59019 L F
.804 .597 .622 r
.33734 .59664 m .34189 .59427 L .33707 .59342 L F
.788 .845 .894 r
.3411 .5922 m .34189 .59427 L .34495 .5922 L F
.097 .365 .83 r
.60305 .42871 m .60551 .43239 L .60227 .43028 L F
.458 .373 .672 r
.60551 .43239 m .60263 .43379 L .60227 .43028 L F
0 0 0 r
.54573 .40984 m .54986 .40817 L .54862 .40745 L F
.717 .961 .693 r
.5511 .40605 m .54986 .40817 L .55133 .40629 L F
.671 .938 .966 r
.54862 .40745 m .54986 .40817 L .5511 .40605 L F
.616 .355 .498 r
.35126 .54425 m .35083 .54987 L .34752 .54756 L F
0 0 .102 r
.35199 .54126 m .35177 .54399 L .35126 .54425 L F
0 0 .107 r
.35177 .54399 m .35083 .54987 L .35126 .54425 L F
0 0 0 r
.36309 .55139 m .35842 .55444 L .35818 .55447 L F
.476 .572 .873 r
.36492 .55059 m .36309 .55139 L .361 .54752 L F
0 0 0 r
.33597 .49676 m .33356 .49722 L .33209 .49795 L F
.468 .452 .757 r
.25381 .52778 m .25175 .52843 L .25122 .52558 L F
.25381 .52778 m .25175 .52843 L .25122 .52558 L F
.506 .395 .662 r
.25381 .52778 m .25206 .5324 L .25175 .52843 L F
.269 .761 .908 r
.41823 .45872 m .41312 .45868 L .41413 .45824 L F
.41823 .45872 m .41585 .45817 L .41312 .45868 L F
.086 .592 .892 r
.41823 .45872 m .41849 .45814 L .41585 .45817 L F
.41823 .45872 m .42002 .4589 L .41849 .45814 L F
.374 .697 .983 r
.63482 .37146 m .63289 .37325 L .63204 .37206 L F
.63482 .37146 m .63637 .37307 L .63289 .37325 L F
.446 .231 .492 r
.63637 .37307 m .63372 .37465 L .63289 .37325 L F
.915 .942 .586 r
.37805 .48018 m .37965 .47621 L .38029 .47897 L F
.603 .676 .892 r
.37669 .47779 m .37805 .48018 L .38029 .47897 L F
.891 .809 .761 r
.28998 .6397 m .28546 .64249 L .2888 .63974 L F
0 .044 .569 r
.29079 .64017 m .28998 .6397 L .2888 .63974 L F
.769 .651 .732 r
.29308 .63773 m .29079 .64017 L .29083 .63844 L F
.516 .899 .953 r
.2915 .63909 m .29036 .63944 L .29079 .64017 L F
0 .044 .569 r
.29079 .64017 m .29127 .64097 L .28998 .6397 L F
.819 .908 .901 r
.28725 .63927 m .2888 .63974 L .28759 .64074 L F
.28725 .63927 m .28759 .64074 L .28546 .64249 L F
.679 .609 .771 r
.28725 .63927 m .28835 .64225 L .28881 .64186 L F
.28725 .63927 m .28881 .64186 L .29079 .64017 L F
.348 0 0 r
.29079 .64017 m .28864 .63996 L .28725 .63927 L F
0 .17 .707 r
.28725 .63927 m .28864 .63996 L .28705 .63842 L F
.28725 .63927 m .28705 .63842 L .28631 .6377 L F
.516 .899 .953 r
.29036 .63944 m .28864 .63996 L .29079 .64017 L F
0 .044 .569 r
.29079 .64017 m .29225 .64193 L .29127 .64097 L F
0 0 0 r
.51119 .51253 m .51008 .51431 L .50862 .51572 L F
.50862 .51572 m .51008 .51431 L .50767 .51751 L F
.918 .613 .133 r
.58168 .38125 m .58213 .38386 L .58124 .38285 L F
.952 .64 .403 r
.5185 .40973 m .51853 .40747 L .51687 .40891 L F
0 0 0 r
.52017 .40565 m .51853 .40747 L .52127 .4041 L F
.555 .863 .563 r
.51687 .40891 m .51853 .40747 L .52017 .40565 L F
.832 .954 .895 r
.52014 .42016 m .5218 .42093 L .51854 .42356 L F
.685 .908 .973 r
.52413 .41933 m .5218 .42093 L .52266 .41849 L F
.723 .944 .955 r
.52266 .41849 m .5218 .42093 L .52014 .42016 L F
.896 .882 .812 r
.35736 .64147 m .359 .64044 L .35651 .63962 L F
.853 .995 .756 r
.35902 .63859 m .359 .64044 L .35992 .63878 L F
.624 .897 .987 r
.35651 .63962 m .359 .64044 L .35902 .63859 L F
.831 .636 .64 r
.43823 .47788 m .44184 .47904 L .44215 .47627 L F
.785 .448 0 r
.40973 .50522 m .4106 .50791 L .4112 .50901 L F
.982 .883 .526 r
.4106 .50791 m .40978 .51055 L .4112 .50901 L F
.631 .153 .101 r
.40978 .51055 m .41381 .5111 L .4112 .50901 L F
.85 .948 .881 r
.70421 .3302 m .70844 .32831 L .70781 .32713 L F
.834 .973 .884 r
.70781 .32713 m .70844 .32831 L .71177 .3252 L F
.832 .954 .895 r
.52014 .42016 m .51854 .42356 L .51743 .4205 L F
.197 0 0 r
.52767 .48495 m .52619 .48369 L .52503 .48548 L F
.488 .797 .999 r
.52679 .48407 m .52503 .48548 L .52619 .48369 L F
.003 0 0 r
.60356 .34487 m .60625 .3448 L .6075 .34472 L F
.975 .712 .468 r
.29732 .63807 m .29937 .63647 L .29909 .63907 L F
.133 0 0 r
.29953 .638 m .29937 .63647 L .29732 .63807 L F
.752 .859 .928 r
.29909 .63907 m .30208 .63864 L .30096 .63986 L F
0 .311 .696 r
.29732 .63807 m .29909 .63907 L .30096 .63986 L F
.219 .432 .855 r
.2993 .63756 m .29569 .63526 L .29607 .63521 L F
.29932 .63719 m .29535 .63468 L .29765 .63485 L F
.133 0 0 r
.29985 .63786 m .29937 .63647 L .29953 .638 L F
.766 .69 .779 r
.29964 .63795 m .29943 .63588 L .29931 .63743 L F
.822 .669 .693 r
.29947 .63531 m .29932 .63719 L .29765 .63485 L F
.766 .69 .779 r
.29943 .63588 m .29939 .63553 L .29932 .63719 L F
.29943 .63588 m .29932 .63719 L .29931 .63743 L F
.133 0 0 r
.29985 .63786 m .30216 .63582 L .29937 .63647 L F
.766 .69 .779 r
.29964 .63794 m .29947 .63531 L .29939 .63553 L F
.29964 .63795 m .29964 .63794 L .29964 .63794 L F
.29964 .63794 m .29947 .63531 L .29964 .63794 L F
0 .311 .696 r
.29732 .63807 m .30096 .63986 L .29975 .63977 L F
.766 .69 .779 r
.29975 .63977 m .30217 .63729 L .30203 .63719 L F
.133 0 0 r
.29985 .63787 m .30018 .63771 L .29985 .63786 L F
.3001 .6378 m .30018 .63771 L .29985 .63787 L F
.30018 .63771 m .30216 .63582 L .29985 .63786 L F
.263 0 0 r
.30217 .63729 m .30216 .63582 L .3001 .6378 L F
.766 .69 .779 r
.29975 .63977 m .30203 .63719 L .29985 .63787 L F
.133 0 0 r
.29985 .63787 m .29985 .63786 L .29964 .63795 L F
.766 .69 .779 r
.29964 .63795 m .29985 .63787 L .29964 .63794 L F
.29975 .63977 m .29985 .63787 L .29964 .63795 L F
.133 0 0 r
.29989 .63799 m .29985 .63787 L .29953 .638 L F
.29985 .63787 m .29964 .63795 L .29953 .638 L F
.263 0 0 r
.30217 .63729 m .3001 .6378 L .29989 .63799 L F
.766 .69 .779 r
.29964 .63791 m .30203 .63719 L .29947 .63531 L F
.29964 .63794 m .3001 .6378 L .29964 .63791 L F
.3001 .6378 m .30203 .63719 L .29964 .63791 L F
.133 0 0 r
.29989 .63799 m .3001 .6378 L .29985 .63787 L F
.822 .669 .693 r
.29947 .63531 m .29989 .63799 L .29932 .63719 L F
.766 .69 .779 r
.29964 .63795 m .2989 .6368 L .29953 .638 L F
.219 .432 .855 r
.29989 .63799 m .2993 .63756 L .29932 .63719 L F
.2993 .63756 m .29535 .63468 L .29932 .63719 L F
.766 .69 .779 r
.29931 .63743 m .29939 .63553 L .2989 .6368 L F
0 .454 .736 r
.29867 .63496 m .29815 .63491 L .29609 .63557 L F
.29815 .63491 m .29765 .63485 L .29726 .63504 L F
.29815 .63491 m .29726 .63504 L .29609 .63557 L F
.219 .432 .855 r
.2993 .63756 m .29732 .63807 L .29569 .63526 L F
.29607 .63521 m .29569 .63526 L .29535 .63468 L F
.29989 .63799 m .29953 .638 L .2993 .63756 L F
.29953 .638 m .29732 .63807 L .2993 .63756 L F
.766 .69 .779 r
.29953 .638 m .2989 .6368 L .2982 .63863 L F
.2982 .63863 m .29947 .63531 L .29788 .6384 L F
.29975 .63977 m .29964 .63795 L .2982 .63863 L F
.743 .723 .195 r
.66785 .36621 m .66755 .36831 L .66698 .37086 L F
.791 .366 .239 r
.40393 .45942 m .40217 .45975 L .4013 .45851 L F
.18 .708 .704 r
.4066 .45869 m .40217 .45975 L .40393 .45942 L F
.892 .471 .17 r
.35411 .5116 m .35549 .51474 L .35759 .51571 L F
.901 .498 .228 r
.35549 .51474 m .35799 .51753 L .35759 .51571 L F
.734 .907 .954 r
.33268 .63088 m .33384 .62857 L .33277 .62922 L F
.33268 .63088 m .33571 .62943 L .33384 .62857 L F
.803 .879 .902 r
.5646 .41937 m .56286 .42341 L .56217 .42283 L F
.5646 .41937 m .56602 .42084 L .56286 .42341 L F
.813 .932 .911 r
.51007 .4031 m .50802 .40508 L .50502 .40458 L F
0 0 0 r
.51323 .51125 m .51008 .51431 L .51119 .51253 L F
.347 .608 .946 r
.29665 .64494 m .29957 .6476 L .30103 .64745 L F
.384 .395 .749 r
.34721 .57426 m .34909 .57349 L .34726 .5726 L F
.882 .585 .071 r
.34721 .57426 m .34743 .57631 L .34909 .57349 L F
.939 .917 .767 r
.40368 .57044 m .40036 .57305 L .40284 .56991 L F
.40368 .57044 m .40163 .57418 L .40036 .57305 L F
.083 0 .193 r
.22805 .5611 m .23025 .56014 L .23093 .55722 L F
.075 0 .418 r
.22805 .5611 m .22984 .56209 L .23025 .56014 L F
.22805 .5611 m .22789 .56443 L .22984 .56209 L F
.864 .706 .684 r
.6213 .37081 m .62307 .3684 L .62072 .36742 L F
.276 .154 .527 r
.33183 .5169 m .33297 .51478 L .33096 .51576 L F
.812 .775 .818 r
.52639 .4759 m .53042 .47627 L .52869 .47489 L F
.879 .606 .522 r
.37255 .54098 m .37457 .5442 L .37473 .54156 L F
.681 .6 .758 r
.7059 .28274 m .70376 .28686 L .70218 .28188 L F
0 0 0 r
.40002 .48402 m .40197 .48182 L .3996 .48379 L F
.841 .883 .871 r
.57965 .45834 m .57695 .45901 L .57707 .45629 L F
.57695 .45901 m .57965 .45834 L .57965 .4584 L F
.732 .716 .836 r
.37612 .47592 m .3734 .47881 L .37669 .47779 L F
.22 .104 .501 r
.37612 .47592 m .37842 .47747 L .37965 .47621 L F
.37612 .47592 m .37669 .47779 L .37842 .47747 L F
.976 .717 .307 r
.59269 .40085 m .59171 .40229 L .5914 .39938 L F
.59269 .40085 m .59274 .40357 L .59171 .40229 L F
.378 0 0 r
.4443 .5807 m .44274 .58261 L .44117 .5813 L F
.557 .097 .116 r
.44724 .58042 m .44274 .58261 L .4443 .5807 L F
.691 .631 .784 r
.43373 .45865 m .43497 .46024 L .43759 .45912 L F
.497 .905 .821 r
.59835 .35357 m .59597 .35559 L .59871 .3545 L F
.59835 .35357 m .59426 .35584 L .59597 .35559 L F
.021 .584 .8 r
.52646 .47298 m .52443 .47261 L .52217 .47239 L F
.91 .793 .719 r
.52646 .47298 m .52458 .47327 L .52443 .47261 L F
.704 .243 .154 r
.52458 .47327 m .52869 .47489 L .52646 .47298 L F
0 .231 .75 r
.52646 .47298 m .52668 .47175 L .52443 .47261 L F
.52646 .47298 m .52869 .47489 L .52668 .47175 L F
.483 .896 .801 r
.43882 .59835 m .44115 .59774 L .44342 .59646 L F
.307 .8 .813 r
.44115 .59774 m .44511 .59668 L .44342 .59646 L F
.895 .538 .359 r
.36338 .52493 m .36192 .52785 L .3668 .5287 L F
.891 .681 .612 r
.36192 .52785 m .36706 .531 L .3668 .5287 L F
.953 .673 .469 r
.62324 .40633 m .62509 .40723 L .62481 .40976 L F
.684 .61 .767 r
.51787 .45023 m .51994 .44469 L .51645 .44621 L F
.51787 .45023 m .52101 .44925 L .51994 .44469 L F
.901 .486 .141 r
.58314 .42607 m .58277 .42435 L .5807 .42286 L F
.001 .399 .85 r
.57142 .44727 m .57444 .44937 L .57416 .44853 L F
.502 0 0 r
.57008 .44832 m .57142 .44727 L .57416 .44853 L F
0 0 .443 r
.46648 .53135 m .46859 .53521 L .47074 .53167 L F
.46648 .53135 m .46848 .53407 L .46859 .53521 L F
.6 .045 0 r
.46416 .53404 m .46859 .53521 L .46664 .53562 L F
.512 .912 .825 r
.46859 .53521 m .46848 .53407 L .46664 .53562 L F
.988 .721 .363 r
.5842 .44865 m .58427 .44659 L .58296 .44517 L F
.486 .547 .844 r
.70062 .28932 m .70245 .28564 L .6995 .28697 L F
.70062 .28932 m .70339 .2889 L .70245 .28564 L F
0 0 0 r
.55188 .43682 m .54964 .43974 L .55265 .43946 L F
.605 .426 .613 r
.54967 .44271 m .55265 .43946 L .54964 .43974 L F
.943 .905 .755 r
.44188 .4844 m .44325 .48552 L .44535 .48228 L F
0 0 0 r
.65081 .32839 m .64992 .32948 L .65321 .32721 L F
.729 .77 .885 r
.31535 .65263 m .31705 .65548 L .31953 .65309 L F
.303 0 0 r
.63247 .3917 m .63395 .3918 L .63122 .39097 L F
.967 .654 .267 r
.63157 .38946 m .63169 .38916 L .63226 .38813 L F
0 .08 .613 r
.63247 .3917 m .63099 .38976 L .63169 .38916 L F
.303 0 0 r
.63247 .3917 m .63108 .39021 L .6312 .39003 L F
.967 .654 .267 r
.63114 .39029 m .63247 .3917 L .63169 .38916 L F
.63114 .39029 m .63147 .38961 L .63157 .38946 L F
.63147 .38961 m .63169 .38916 L .63157 .38946 L F
.303 0 0 r
.63247 .3917 m .63122 .39097 L .63108 .39021 L F
.6312 .39003 m .63108 .39021 L .63099 .38976 L F
.413 .84 .688 r
.47468 .42666 m .47224 .42806 L .4706 .42879 L F
.848 .84 .836 r
.68021 .34135 m .67758 .34114 L .6805 .33815 L F
.832 .854 .862 r
.6805 .33815 m .6834 .33828 L .68021 .34135 L F
.476 .572 .873 r
.36492 .55059 m .361 .54752 L .36568 .54843 L F
.11 0 .2 r
.36755 .54727 m .36492 .55059 L .36568 .54843 L F
.36755 .54727 m .36492 .55059 L .36568 .54843 L F
.55 .897 .978 r
.64338 .38574 m .64013 .38699 L .63903 .38632 L F
.042 .582 .849 r
.59957 .3439 m .60356 .34487 L .60151 .34452 L F
.588 .642 .871 r
.60432 .34536 m .60151 .34452 L .60356 .34487 L F
.351 0 0 r
.45514 .59578 m .4501 .59658 L .45332 .59738 L F
.405 .454 .798 r
.70053 .27859 m .69831 .28122 L .69733 .27831 L F
.212 .275 .712 r
.70071 .28078 m .69831 .28122 L .70053 .27859 L F
.70071 .28078 m .69913 .28303 L .69831 .28122 L F
0 0 0 r
.64845 .39576 m .65233 .39376 L .65109 .39542 L F
.251 0 0 r
.65233 .39376 m .65359 .39485 L .65109 .39542 L F
.65233 .39376 m .65475 .39339 L .65359 .39485 L F
.741 .668 .778 r
.70873 .28183 m .71272 .28266 L .71 .28611 L F
0 0 .261 r
.70899 .28455 m .70883 .28699 L .70907 .28667 L F
.926 .637 .159 r
.70891 .28242 m .71 .28611 L .70899 .28455 L F
0 0 .261 r
.70899 .28455 m .70907 .28667 L .7105 .28473 L F
.926 .637 .159 r
.70873 .28183 m .70891 .28242 L .70899 .28455 L F
.586 .443 .654 r
.71272 .28266 m .7138 .28576 L .71 .28611 L F
.547 .46 .708 r
.71287 .28814 m .71 .28611 L .7138 .28576 L F
.71287 .28814 m .71095 .28978 L .71 .28611 L F
.327 .762 .969 r
.39394 .54151 m .39468 .54063 L .39313 .53737 L F
.39394 .54151 m .39666 .54132 L .39468 .54063 L F
.612 .779 .961 r
.57681 .35055 m .57816 .35227 L .58089 .35138 L F
.57681 .35055 m .57816 .35227 L .58089 .35138 L F
.046 .614 .717 r
.40767 .45461 m .40369 .45484 L .40431 .45478 L F
.09 .108 .584 r
.23093 .55722 m .23181 .55328 L .23065 .55369 L F
.23093 .55722 m .23256 .55639 L .23181 .55328 L F
.1 0 .199 r
.23093 .55722 m .23196 .55914 L .23256 .55639 L F
.23093 .55722 m .23025 .56014 L .23196 .55914 L F
.359 .826 .762 r
.2486 .55542 m .2457 .55626 L .24523 .55529 L F
.2486 .55542 m .24752 .55543 L .2457 .55626 L F
.67 .536 .692 r
.2486 .55542 m .25384 .55434 L .25241 .55284 L F
.494 .407 .687 r
.25186 .55338 m .25541 .55431 L .25159 .55424 L F
.252 .762 .757 r
.25054 .55428 m .2486 .55542 L .25241 .55284 L F
.16 .609 .934 r
.25037 .55155 m .25241 .55284 L .24953 .55221 L F
.162 .61 .935 r
.25037 .55155 m .25237 .55173 L .25241 .55284 L F
.494 .407 .687 r
.25237 .55173 m .25322 .55245 L .25186 .55338 L F
.25322 .55245 m .25541 .55431 L .25186 .55338 L F
.252 .762 .757 r
.24996 .55473 m .24967 .55488 L .25054 .55428 L F
.24967 .55488 m .2486 .55542 L .25054 .55428 L F
.24996 .55473 m .24752 .55543 L .2486 .55542 L F
.67 .536 .692 r
.2486 .55542 m .25133 .55773 L .25384 .55434 L F
0 .1 .654 r
.60896 .44664 m .60676 .44213 L .60488 .44673 L F
0 0 .346 r
.60969 .44681 m .60971 .44979 L .60896 .44664 L F
.774 .871 .919 r
.60461 .44994 m .60971 .44979 L .6097 .44796 L F
.493 0 0 r
.60807 .44809 m .60896 .44664 L .60488 .44673 L F
.60815 .44812 m .60818 .44807 L .60807 .44809 L F
.60818 .44807 m .60896 .44664 L .60807 .44809 L F
.60868 .44806 m .60896 .44664 L .60815 .44812 L F
0 0 .346 r
.60969 .44681 m .60896 .44664 L .60868 .44806 L F
.774 .871 .919 r
.60868 .44806 m .6097 .44796 L .60969 .44681 L F
0 0 .346 r
.60969 .44681 m .60868 .44806 L .60863 .44833 L F
.45 0 0 r
.60719 .44807 m .60488 .44673 L .60366 .44741 L F
.60719 .44807 m .60366 .44741 L .60382 .44746 L F
.60762 .44809 m .60488 .44673 L .60719 .44807 L F
.60807 .44809 m .60488 .44673 L .60762 .44809 L F
.764 .938 .94 r
.60662 .44729 m .60702 .44774 L .60969 .44681 L F
.45 0 0 r
.60382 .44746 m .60366 .44741 L .60364 .44743 L F
.60733 .44809 m .60364 .44743 L .60662 .44729 L F
.764 .938 .94 r
.60601 .4481 m .60665 .4481 L .60969 .44681 L F
.45 0 0 r
.60815 .44812 m .60807 .44809 L .60762 .44809 L F
.774 .871 .919 r
.60745 .4482 m .60815 .44812 L .60762 .44809 L F
.60461 .44994 m .6097 .44796 L .60745 .4482 L F
.45 0 0 r
.60863 .44833 m .60815 .44812 L .60719 .44807 L F
.774 .871 .919 r
.60762 .44809 m .60868 .44806 L .60969 .44681 L F
.60815 .44812 m .60868 .44806 L .60762 .44809 L F
.764 .938 .94 r
.60571 .44849 m .60745 .4482 L .60969 .44681 L F
.45 0 0 r
.60863 .44833 m .60733 .44809 L .60662 .44729 L F
.764 .938 .94 r
.60662 .44729 m .60601 .4481 L .60702 .44774 L F
.60601 .4481 m .60571 .44849 L .60665 .4481 L F
.60571 .44849 m .60461 .44994 L .60745 .4482 L F
.775 .87 .918 r
.60601 .45184 m .60461 .44994 L .60498 .45112 L F
.60601 .45184 m .60971 .44979 L .60461 .44994 L F
.508 .539 .823 r
.60498 .45112 m .60461 .44994 L .60601 .4481 L F
.60625 .44817 m .60601 .4481 L .60662 .44729 L F
.60498 .45112 m .60601 .4481 L .60625 .44817 L F
.493 0 0 r
.60863 .44833 m .60868 .44806 L .60815 .44812 L F
.981 .84 .629 r
.72484 .28676 m .72475 .28999 L .72356 .28829 L F
.662 .808 .953 r
.72475 .28999 m .72731 .28899 L .72356 .28829 L F
.72475 .28999 m .72731 .28899 L .72356 .28829 L F
.741 .636 .743 r
.32323 .58401 m .32275 .5873 L .32537 .58398 L F
.229 0 0 r
.32142 .58986 m .3256 .58779 L .32275 .5873 L F
.942 .893 .752 r
.40129 .58346 m .40137 .57959 L .40301 .58068 L F
.978 .916 .609 r
.46304 .55151 m .46269 .54975 L .46447 .54825 L F
0 0 0 r
.46542 .54649 m .46549 .54509 L .46447 .54825 L F
.702 .933 .62 r
.46269 .54975 m .46542 .54649 L .46447 .54825 L F
.294 0 .265 r
.52527 .42329 m .52823 .4205 L .52805 .42261 L F
.59 .223 .314 r
.52823 .4205 m .5309 .42243 L .52805 .42261 L F
.53 .263 .455 r
.53116 .42005 m .5309 .42243 L .52823 .4205 L F
.936 .658 .489 r
.36963 .5371 m .37255 .54098 L .37236 .5385 L F
.272 .766 .701 r
.24544 .59139 m .24254 .59232 L .24179 .59265 L F
.781 .998 .84 r
.24561 .58963 m .24544 .59139 L .24763 .59025 L F
.24561 .58963 m .24254 .59232 L .24544 .59139 L F
.92 .792 .703 r
.51741 .44312 m .5178 .44367 L .51645 .44621 L F
.857 .912 .869 r
.43172 .5633 m .4363 .56113 L .43472 .56002 L F
.934 .597 .372 r
.3784 .512 m .37664 .51356 L .37612 .51119 L F
.3784 .512 m .37868 .51502 L .37664 .51356 L F
.751 .665 .767 r
.35827 .53137 m .35546 .53504 L .35404 .53103 L F
0 .084 .644 r
.57504 .37231 m .57621 .37397 L .57435 .37034 L F
.013 .093 .602 r
.52261 .40236 m .52127 .4041 L .52068 .40051 L F
0 0 0 r
.52261 .40236 m .52017 .40565 L .52127 .4041 L F
.809 .661 .699 r
.72619 .28505 m .72731 .28899 L .72963 .2856 L F
.646 .963 .799 r
.53982 .48913 m .54105 .48778 L .54114 .48736 L F
.646 .963 .801 r
.53821 .48954 m .53982 .48913 L .54114 .48736 L F
.575 .511 .746 r
.54707 .4516 m .54727 .45156 L .54855 .44679 L F
.814 .882 .453 r
.54799 .45081 m .54993 .44566 L .54848 .44841 L F
.54799 .45081 m .54848 .44841 L .54844 .4485 L F
0 .105 .636 r
.54987 .45097 m .54799 .45081 L .54844 .4485 L F
.575 .511 .746 r
.54844 .4485 m .54987 .45097 L .54878 .44862 L F
.701 .255 .188 r
.54845 .44846 m .54877 .44859 L .54987 .45097 L F
.54877 .44859 m .55275 .45016 L .54987 .45097 L F
.575 .511 .746 r
.54878 .44862 m .54987 .45097 L .54917 .44875 L F
.818 .602 .609 r
.55386 .44587 m .54852 .44843 L .54993 .44566 L F
.55386 .44587 m .55375 .44875 L .54854 .44847 L F
.701 .255 .188 r
.54854 .44847 m .55375 .44875 L .54877 .44859 L F
.575 .511 .746 r
.54847 .44843 m .54917 .44875 L .54848 .44841 L F
.54844 .4485 m .5489 .44866 L .54847 .44843 L F
.701 .255 .188 r
.54877 .44859 m .55375 .44875 L .55275 .45016 L F
.575 .511 .746 r
.5489 .44866 m .54917 .44875 L .54847 .44843 L F
.701 .255 .188 r
.54845 .44846 m .54854 .44847 L .54877 .44859 L F
.818 .602 .609 r
.54852 .44843 m .54854 .44847 L .54845 .44846 L F
.55386 .44587 m .54854 .44847 L .54852 .44843 L F
.575 .511 .746 r
.54849 .44838 m .54917 .44875 L .5488 .44757 L F
.818 .602 .609 r
.54852 .44843 m .54848 .44841 L .54993 .44566 L F
.575 .511 .746 r
.54848 .44841 m .54852 .44843 L .54849 .44838 L F
.54852 .44843 m .54917 .44875 L .54849 .44838 L F
.54727 .45156 m .5488 .44757 L .54855 .44679 L F
.814 .882 .453 r
.54844 .4485 m .54848 .44841 L .54845 .44846 L F
.818 .602 .609 r
.54852 .44843 m .54845 .44846 L .54848 .44841 L F
0 .105 .636 r
.54987 .45097 m .54844 .4485 L .54845 .44846 L F
.54987 .45097 m .54885 .45278 L .54799 .45081 L F
.575 .511 .746 r
.54727 .45156 m .54987 .45097 L .54844 .4485 L F
0 0 0 r
.23065 .55369 m .23181 .55328 L .23313 .55096 L F
.699 .923 .967 r
.63037 .34935 m .63208 .34893 L .63411 .34754 L F
.803 .928 .917 r
.31003 .5768 m .31169 .57355 L .30976 .57687 L F
.84 .976 .878 r
.36719 .60364 m .36363 .60468 L .36551 .60259 L F
.36719 .60364 m .36391 .60643 L .36363 .60468 L F
.758 .596 .677 r
.35311 .5573 m .35518 .56168 L .35718 .55784 L F
.638 .753 .932 r
.48033 .45041 m .48295 .44951 L .47885 .44889 L F
.751 .994 .838 r
.29469 .64139 m .29702 .64062 L .29483 .64257 L F
0 .01 .579 r
.29483 .64257 m .29665 .64494 L .29469 .64139 L F
.998 .85 .538 r
.29483 .64257 m .29445 .64563 L .29665 .64494 L F
.626 .709 .905 r
.69631 .28832 m .69811 .28396 L .69593 .28441 L F
.69631 .28832 m .6995 .28697 L .69811 .28396 L F
.756 .637 .728 r
.33062 .57462 m .33049 .57719 L .33256 .57366 L F
0 0 0 r
.53286 .46481 m .53385 .46285 L .53324 .46473 L F
.822 .85 .869 r
.53385 .46285 m .53702 .45983 L .53586 .45885 L F
.53514 .45898 m .53586 .45885 L .53533 .4584 L F
.53385 .46285 m .53586 .45885 L .53514 .45898 L F
.53385 .46285 m .53533 .4584 L .53493 .46082 L F
.68 .878 .499 r
.53282 .45848 m .53015 .46243 L .53083 .46085 L F
.512 .156 .298 r
.53494 .46028 m .53371 .45923 L .53083 .46085 L F
.53371 .45923 m .53282 .45848 L .53191 .45955 L F
.53371 .45923 m .53191 .45955 L .53083 .46085 L F
0 0 0 r
.53324 .46473 m .53385 .46285 L .53493 .46082 L F
.612 .735 .933 r
.53643 .45663 m .53807 .45477 L .53513 .45319 L F
.53643 .45663 m .53953 .45652 L .53807 .45477 L F
.867 .846 .821 r
.53533 .4584 m .53953 .45652 L .53643 .45663 L F
.348 .607 .946 r
.60726 .44018 m .60344 .43759 L .60547 .43664 L F
.996 .861 .542 r
.60676 .44213 m .60726 .44018 L .60604 .44093 L F
0 .052 .618 r
.60661 .43791 m .60726 .44018 L .60547 .43664 L F
.982 .903 .58 r
.60604 .44093 m .60726 .44018 L .60661 .43791 L F
.851 .671 .658 r
.57849 .40924 m .582 .40745 L .58158 .40568 L F
.57849 .40924 m .58051 .41047 L .582 .40745 L F
.907 .534 .313 r
.40401 .58776 m .40264 .58937 L .40198 .58679 L F
.67 .198 .124 r
.40401 .58776 m .40668 .58979 L .40264 .58937 L F
.653 .105 0 r
.40927 .59037 m .40668 .58979 L .40401 .58776 L F
.457 .744 .99 r
.48673 .45087 m .4914 .45203 L .4891 .45061 L F
.217 .497 .902 r
.4914 .45203 m .49218 .45083 L .4891 .45061 L F
.4914 .45203 m .49374 .45278 L .49218 .45083 L F
.371 .167 .468 r
.35205 .58361 m .34962 .58735 L .34961 .58601 L F
.945 .96 .712 r
.51646 .42011 m .51743 .4205 L .51788 .41959 L F
.51666 .41986 m .51788 .41959 L .5197 .41591 L F
.51646 .42011 m .51788 .41959 L .51666 .41986 L F
.341 0 0 r
.51637 .42039 m .52014 .42016 L .51743 .4205 L F
.406 .846 .934 r
.51584 .42049 m .51646 .42011 L .51442 .42074 L F
.51477 .42113 m .51743 .4205 L .51646 .42011 L F
.341 0 0 r
.51502 .42026 m .51763 .42017 L .51637 .42039 L F
.406 .846 .934 r
.51442 .42074 m .51646 .42011 L .51322 .41939 L F
.341 0 0 r
.51418 .42017 m .51522 .42017 L .51502 .42026 L F
.51522 .42017 m .51763 .42017 L .51502 .42026 L F
.945 .96 .712 r
.51646 .42011 m .5197 .41591 L .51893 .4165 L F
.51646 .42011 m .51893 .4165 L .51869 .41927 L F
.526 .651 .914 r
.51706 .41655 m .51646 .42011 L .51869 .41927 L F
.307 0 0 r
.51322 .41939 m .51646 .42011 L .51418 .42017 L F
.888 .971 .832 r
.51441 .41991 m .51646 .42011 L .51706 .41655 L F
.033 0 .275 r
.51931 .41649 m .51869 .41927 L .51893 .4165 L F
.978 .756 .535 r
.51848 .41651 m .51869 .41927 L .51931 .41649 L F
.51706 .41655 m .51768 .41758 L .51848 .41651 L F
.51768 .41758 m .51869 .41927 L .51848 .41651 L F
0 0 0 r
.51663 .41955 m .51662 .41901 L .51856 .4175 L F
.51662 .41901 m .51661 .41864 L .51711 .41834 L F
.51662 .41901 m .51711 .41834 L .51856 .4175 L F
.341 0 0 r
.51763 .42017 m .52014 .42016 L .51637 .42039 L F
.51524 .42017 m .51912 .42072 L .52014 .42016 L F
.51488 .42025 m .51912 .42072 L .51524 .42017 L F
.51418 .42017 m .51488 .42025 L .51524 .42017 L F
.871 .976 .848 r
.51418 .42017 m .51646 .42011 L .51441 .41991 L F
.719 .629 .756 r
.51418 .42017 m .51912 .42072 L .51441 .41991 L F
.406 .846 .934 r
.51477 .42113 m .51584 .42049 L .51442 .42074 L F
.351 .824 .889 r
.51418 .42017 m .51743 .4205 L .51477 .42113 L F
.763 .662 .751 r
.51623 .42392 m .51912 .42072 L .51441 .41991 L F
0 0 0 r
.51578 .42045 m .51608 .41979 L .51663 .41955 L F
.51608 .41979 m .51661 .41864 L .51663 .41955 L F
.351 .824 .889 r
.51418 .42017 m .51477 .42113 L .51322 .41939 L F
.758 .716 .813 r
.46488 .58583 m .46875 .58693 L .46632 .588 L F
.548 .633 .887 r
.46258 .58727 m .46643 .58817 L .46632 .588 L F
.46402 .58637 m .46632 .588 L .46488 .58583 L F
.46258 .58727 m .46632 .588 L .46402 .58637 L F
.664 .426 .551 r
.46384 .58909 m .46662 .58821 L .46258 .58727 L F
.733 .628 .741 r
.46384 .58909 m .46632 .588 L .46662 .58821 L F
.46632 .588 m .46875 .58693 L .46662 .58821 L F
.758 .716 .813 r
.46488 .58583 m .46632 .588 L .46384 .58909 L F
.548 .633 .887 r
.46643 .58817 m .46662 .58821 L .46488 .58583 L F
.664 .426 .551 r
.46384 .58909 m .46258 .58727 L .46211 .59014 L F
.938 .583 .316 r
.40163 .57418 m .40017 .57573 L .40036 .57305 L F
.40163 .57418 m .40204 .57708 L .40017 .57573 L F
.958 .618 .304 r
.37842 .47747 m .38029 .47897 L .37965 .47621 L F
.51 .566 .848 r
.36391 .60643 m .36016 .60356 L .36165 .60634 L F
.099 .195 .677 r
.36282 .60607 m .36016 .60356 L .36283 .60241 L F
.36282 .60607 m .36165 .60634 L .36016 .60356 L F
.549 .583 .841 r
.60829 .39767 m .6124 .40021 L .61202 .39797 L F
.60829 .39767 m .61016 .39883 L .61057 .39855 L F
.61016 .39883 m .6124 .40021 L .61057 .39855 L F
.345 0 0 r
.61057 .39855 m .60737 .39794 L .60959 .39866 L F
.28 .781 .774 r
.6109 .39833 m .61057 .39855 L .60959 .39866 L F
0 0 0 r
.61328 .39772 m .61202 .39797 L .61057 .39855 L F
.28 .781 .774 r
.61328 .39772 m .61057 .39855 L .6109 .39833 L F
.345 0 0 r
.61057 .39855 m .60829 .39767 L .60737 .39794 L F
.642 .525 .706 r
.60829 .39767 m .61202 .39797 L .61076 .39415 L F
.797 .904 .501 r
.32589 .53721 m .32717 .53422 L .32494 .53312 L F
.648 .961 .782 r
.32589 .53721 m .32152 .53906 L .32563 .53632 L F
.089 0 0 r
.32348 .53763 m .32457 .53741 L .32563 .53632 L F
.797 .904 .501 r
.32589 .53721 m .32563 .53632 L .32676 .53518 L F
0 0 .386 r
.3284 .53853 m .32876 .54065 L .32774 .53709 L F
.3284 .53853 m .32774 .53709 L .32948 .53625 L F
0 .398 .843 r
.32563 .53632 m .3284 .53853 L .32948 .53625 L F
.32563 .53632 m .32836 .53662 L .3284 .53853 L F
.089 0 0 r
.32457 .53741 m .32836 .53662 L .32563 .53632 L F
.797 .904 .501 r
.32676 .53518 m .32563 .53632 L .32717 .53422 L F
.309 .052 .351 r
.49359 .51207 m .49601 .51134 L .4965 .50881 L F
.315 .065 .366 r
.49359 .51207 m .49344 .51445 L .49601 .51134 L F
.883 .479 .251 r
.59466 .36434 m .59636 .36721 L .59825 .36798 L F
.96 .674 .447 r
.59654 .36947 m .59825 .36798 L .59636 .36721 L F
.59654 .36947 m .59848 .37104 L .59825 .36798 L F
.775 .923 .934 r
.48611 .4189 m .48402 .42063 L .48271 .41948 L F
.439 .799 .996 r
.24757 .58725 m .24775 .58693 L .24831 .58734 L F
.579 .868 .995 r
.24831 .58734 m .24651 .58603 L .24829 .58559 L F
0 0 .237 r
.24829 .58559 m .24763 .59025 L .24831 .58734 L F
.24823 .58602 m .24833 .58919 L .24763 .59025 L F
.24829 .58559 m .24829 .5859 L .24823 .58602 L F
.24829 .5859 m .24833 .58919 L .24823 .58602 L F
.439 .799 .996 r
.24342 .58675 m .24651 .58603 L .24775 .58693 L F
.24342 .58675 m .24775 .58693 L .24757 .58725 L F
.713 .805 .922 r
.45616 .45247 m .46026 .45284 L .45874 .4511 L F
.663 .789 .942 r
.46026 .45284 m .46151 .44925 L .45874 .4511 L F
.46026 .45284 m .46277 .4517 L .46151 .44925 L F
.935 .624 .167 r
.58743 .39096 m .58666 .39173 L .58592 .38943 L F
.58743 .39096 m .58789 .3936 L .58666 .39173 L F
.703 .764 .9 r
.32323 .58401 m .32537 .58398 L .32437 .58275 L F
.578 .716 .937 r
.32437 .58275 m .32537 .58398 L .32816 .58338 L F
.124 .123 .585 r
.60344 .43759 m .60263 .43379 L .6022 .4364 L F
.76 .662 .753 r
.60551 .43239 m .6022 .4364 L .60263 .43379 L F
.813 .441 .352 r
.38639 .48733 m .38684 .48584 L .38345 .4851 L F
.266 0 0 r
.38841 .48825 m .38684 .48584 L .38639 .48733 L F
.634 .601 .799 r
.30484 .64838 m .30593 .6503 L .3086 .64962 L F
.836 .596 .575 r
.37974 .55428 m .3797 .5571 L .3828 .5573 L F
.861 .637 .597 r
.37947 .55975 m .3828 .5573 L .3797 .5571 L F
.37947 .55975 m .38184 .56052 L .3828 .5573 L F
.496 .693 .956 r
.31951 .60684 m .31648 .60577 L .31909 .60564 L F
.243 0 0 r
.31951 .60684 m .31847 .60873 L .316 .60929 L F
.964 .834 .414 r
.31909 .60564 m .31847 .60873 L .31951 .60684 L F
.626 .496 .684 r
.32062 .53141 m .32357 .53354 L .3237 .53009 L F
.588 .308 .459 r
.69581 .29464 m .69868 .29468 L .698 .29282 L F
.509 .334 .579 r
.28769 .58676 m .28535 .58998 L .28518 .58726 L F
.28769 .58676 m .28535 .58998 L .28518 .58726 L F
.888 .932 .841 r
.61937 .37099 m .6201 .3731 L .6213 .37081 L F
.707 .455 .541 r
.3468 .59025 m .3411 .5922 L .34495 .5922 L F
.181 .306 .756 r
.34495 .5922 m .34655 .5929 L .3468 .59025 L F
.15 .498 .907 r
.60585 .4226 m .60703 .42444 L .60978 .42525 L F
.71 .503 .607 r
.51645 .44621 m .51285 .44355 L .51245 .44569 L F
.069 0 .007 r
.24852 .5453 m .24774 .547 L .24567 .54787 L F
.307 0 .109 r
.25051 .54602 m .24774 .547 L .24852 .5453 L F
.335 .504 .877 r
.29176 .57919 m .29036 .58122 L .28861 .5778 L F
.136 .227 .695 r
.29176 .57919 m .29274 .58277 L .29036 .58122 L F
.412 0 0 r
.62193 .39745 m .62627 .39758 L .62439 .39644 L F
.711 .437 .509 r
.62627 .39758 m .62571 .40033 L .62439 .39644 L F
.62627 .39758 m .62817 .39971 L .62571 .40033 L F
.412 0 0 r
.3249 .6009 m .32554 .60151 L .32375 .59948 L F
0 0 0 r
.52185 .42628 m .52527 .42329 L .52418 .42535 L F
.65 .45 .599 r
.52805 .42261 m .52418 .42535 L .52527 .42329 L F
.954 .609 .235 r
.55614 .40753 m .55411 .40322 L .55133 .40629 L F
.785 .661 .727 r
.32644 .5772 m .33049 .57719 L .33062 .57462 L F
.829 .571 .55 r
.32624 .57958 m .33049 .57719 L .32644 .5772 L F
.32624 .57958 m .33037 .58015 L .33049 .57719 L F
.988 .879 .626 r
.37303 .62233 m .37419 .61999 L .37193 .62116 L F
.756 .971 .698 r
.37419 .61999 m .37694 .61682 L .37479 .61831 L F
.752 .983 .747 r
.37193 .62116 m .37419 .61999 L .37479 .61831 L F
.632 .938 .962 r
.31735 .54337 m .31533 .54445 L .31685 .54494 L F
.58 .254 .381 r
.68884 .30158 m .69206 .29877 L .68874 .29969 L F
.912 .769 .691 r
.68471 .33149 m .68458 .33558 L .68304 .3344 L F
.917 .843 .755 r
.68458 .33558 m .6834 .33828 L .68304 .3344 L F
.793 .711 .773 r
.57523 .36598 m .57486 .36835 L .57293 .36371 L F
.223 0 .251 r
.57486 .36835 m .57435 .37034 L .57706 .36749 L F
.875 .896 .844 r
.72458 .32463 m .72709 .32182 L .72576 .32001 L F
.932 .892 .768 r
.72576 .32001 m .72709 .32182 L .72859 .31829 L F
.754 .525 .584 r
.32342 .56703 m .32784 .56739 L .3278 .56429 L F
.507 .537 .822 r
.31024 .65345 m .31091 .64928 L .3086 .64962 L F
.31024 .65345 m .31294 .65363 L .31091 .64928 L F
.557 .432 .665 r
.31024 .65345 m .31234 .6545 L .31294 .65363 L F
.31024 .65345 m .31022 .65585 L .31234 .6545 L F
.827 .85 .391 r
.48169 .56755 m .48064 .5694 L .4806 .57028 L F
.364 0 .043 r
.43445 .59812 m .43629 .59879 L .43248 .59962 L F
.43445 .59812 m .43672 .59775 L .43629 .59879 L F
.671 .937 .966 r
.56947 .46122 m .5745 .46017 L .57309 .45865 L F
.643 .841 .976 r
.57309 .45865 m .5745 .46017 L .57695 .45901 L F
.58 .254 .381 r
.68884 .30158 m .69205 .30131 L .69206 .29877 L F
.308 .066 .375 r
.69206 .29877 m .69518 .29767 L .69581 .29464 L F
.391 .11 .362 r
.69206 .29877 m .69516 .30021 L .69518 .29767 L F
.69206 .29877 m .69205 .30131 L .69516 .30021 L F
0 0 .209 r
.40989 .59704 m .41064 .59864 L .40952 .59536 L F
.40989 .59704 m .41002 .59972 L .41064 .59864 L F
.96 .886 .713 r
.59198 .40612 m .59179 .41045 L .59109 .40939 L F
.905 .502 .108 r
.59343 .41331 m .59109 .40939 L .59179 .41045 L F
.897 .528 .33 r
.33539 .59023 m .3319 .58667 L .33597 .5871 L F
.725 .989 .838 r
.49809 .40936 m .49896 .40751 L .50154 .40784 L F
.49809 .40936 m .49715 .40919 L .49896 .40751 L F
.656 .718 .894 r
.40664 .46165 m .40745 .46363 L .41075 .46245 L F
.338 0 0 r
.30118 .57916 m .29997 .5777 L .2983 .58158 L F
.30118 .57916 m .30274 .57753 L .29997 .5777 L F
.443 .196 .443 r
.33025 .5448 m .32998 .54724 L .32751 .54785 L F
.381 .145 .426 r
.33272 .54595 m .32998 .54724 L .33025 .5448 L F
.081 .22 .709 r
.51484 .43687 m .51353 .43308 L .511 .43649 L F
.557 .607 .859 r
.511 .43649 m .51527 .43958 L .51484 .43687 L F
.589 .472 .688 r
.51527 .43958 m .51742 .43617 L .51484 .43687 L F
.479 .876 .707 r
.67513 .37976 m .67887 .37764 L .67732 .37817 L F
0 0 0 r
.68082 .37614 m .67887 .37764 L .681 .37594 L F
.485 .886 .738 r
.67732 .37817 m .67887 .37764 L .68082 .37614 L F
.834 .677 .688 r
.60622 .41947 m .60994 .42036 L .6092 .41706 L F
.574 .005 0 r
.60951 .42153 m .60994 .42036 L .60622 .41947 L F
.411 .401 .738 r
.6092 .41706 m .60994 .42036 L .61203 .41784 L F
.881 .688 .637 r
.60951 .42153 m .61203 .41784 L .60994 .42036 L F
.761 .867 .926 r
.72137 .32455 m .72458 .32463 L .72464 .32174 L F
.875 .896 .844 r
.72458 .32463 m .72576 .32001 L .72464 .32174 L F
.861 .808 .797 r
.68304 .3344 m .6834 .33828 L .6805 .33815 L F
.479 .762 .993 r
.32619 .65247 m .33042 .65339 L .32844 .65204 L F
.454 .884 .825 r
.33042 .65339 m .33107 .65253 L .32844 .65204 L F
.33042 .65339 m .33284 .65228 L .33107 .65253 L F
.244 .575 .942 r
.35265 .61305 m .35512 .61435 L .35345 .61208 L F
.214 .531 .922 r
.35345 .61208 m .35587 .61509 L .35265 .61305 L F
.785 .661 .727 r
.32644 .5772 m .33062 .57462 L .32564 .57631 L F
.962 .802 .365 r
.56063 .41245 m .56 .40948 L .56296 .41 L F
.56063 .41245 m .55979 .41283 L .56 .40948 L F
.578 .597 .835 r
.62105 .41231 m .61856 .41426 L .61789 .41111 L F
.528 .488 .756 r
.62175 .41517 m .61856 .41426 L .62105 .41231 L F
.62175 .41517 m .61954 .41609 L .61856 .41426 L F
.82 .792 .826 r
.49685 .44922 m .50045 .44976 L .49837 .44818 L F
.837 .882 .875 r
.49581 .45178 m .50045 .44976 L .49685 .44922 L F
.635 .715 .905 r
.50045 .44976 m .50181 .44622 L .49837 .44818 L F
.50045 .44976 m .50356 .44937 L .50181 .44622 L F
.556 .569 .822 r
.50045 .44976 m .50449 .45297 L .50356 .44937 L F
.586 .011 0 r
.69868 .29468 m .70047 .29573 L .70207 .29603 L F
.528 .337 .566 r
.70207 .29603 m .70509 .29573 L .70473 .29261 L F
.318 .783 .938 r
.70047 .29573 m .70509 .29573 L .70207 .29603 L F
.903 .654 .551 r
.36149 .54472 m .35866 .54609 L .35705 .54528 L F
.36149 .54472 m .361 .54752 L .35866 .54609 L F
.759 .995 .849 r
.31109 .63598 m .31335 .63529 L .31008 .63766 L F
.505 0 0 r
.31487 .63611 m .31335 .63529 L .31109 .63598 L F
.437 .473 .799 r
.23136 .60311 m .23439 .60658 L .233 .60297 L F
.485 .282 .528 r
.341 .60595 m .34042 .6097 L .33781 .61024 L F
.766 .538 .589 r
.34238 .60718 m .34042 .6097 L .341 .60595 L F
.743 .883 .944 r
.41968 .47484 m .41616 .47305 L .42062 .47368 L F
.41968 .47484 m .41615 .4748 L .41616 .47305 L F
.425 .236 .518 r
.41886 .47421 m .41968 .47484 L .42066 .47582 L F
.41886 .47421 m .41615 .4748 L .41968 .47484 L F
.349 .085 .365 r
.4965 .50881 m .49844 .51038 L .49882 .50783 L F
.4965 .50881 m .49601 .51134 L .49844 .51038 L F
.943 .826 .699 r
.70099 .34095 m .702 .33894 L .70028 .33735 L F
.83 .704 .169 r
.3601 .61633 m .35997 .61987 L .35973 .61809 L F
.824 .694 .155 r
.35973 .61809 m .35997 .61987 L .35963 .62219 L F
.896 .694 .621 r
.43394 .57422 m .43539 .57079 L .43324 .56963 L F
.52 .023 .016 r
.43542 .57317 m .43539 .57079 L .43394 .57422 L F
.563 .074 .052 r
.43542 .57317 m .43574 .57302 L .43587 .57285 L F
.43394 .57422 m .43537 .57327 L .43542 .57317 L F
.43537 .57327 m .43574 .57302 L .43542 .57317 L F
.896 .694 .621 r
.43394 .57422 m .43324 .56963 L .43537 .57327 L F
.733 .405 .425 r
.4293 .57212 m .43528 .57343 L .43324 .56963 L F
.896 .694 .621 r
.43394 .57422 m .43537 .57327 L .43549 .57347 L F
.733 .405 .425 r
.43528 .57343 m .43535 .57344 L .43531 .57337 L F
.43528 .57343 m .43531 .57337 L .43324 .56963 L F
.43535 .57344 m .43549 .57347 L .43539 .5733 L F
.43535 .57344 m .43539 .5733 L .43537 .57327 L F
.43531 .57337 m .43537 .57327 L .43324 .56963 L F
.43535 .57344 m .43537 .57327 L .43531 .57337 L F
.778 .538 .571 r
.43082 .57594 m .43524 .57696 L .43394 .57422 L F
.563 .074 .052 r
.43394 .57422 m .43722 .57502 L .43595 .57528 L F
.43374 .57511 m .43595 .57528 L .4336 .57575 L F
.43394 .57422 m .43595 .57528 L .43374 .57511 L F
.43394 .57422 m .4347 .57407 L .43537 .57327 L F
.4347 .57407 m .43496 .57402 L .43528 .57343 L F
.4347 .57407 m .43528 .57343 L .43537 .57327 L F
.697 .651 .8 r
.43039 .57486 m .43515 .57357 L .4293 .57212 L F
.43515 .57357 m .43549 .57347 L .43528 .57343 L F
.43515 .57357 m .43528 .57343 L .4293 .57212 L F
.43082 .57594 m .43255 .57503 L .43039 .57486 L F
.563 .074 .052 r
.43394 .57422 m .4336 .57575 L .43496 .57402 L F
.778 .538 .571 r
.43082 .57594 m .43394 .57422 L .43549 .57347 L F
.697 .651 .8 r
.43255 .57503 m .43549 .57347 L .43039 .57486 L F
.563 .074 .052 r
.43537 .57327 m .43496 .57402 L .43574 .57302 L F
.52 .023 .016 r
.43587 .57285 m .4357 .57214 L .43542 .57317 L F
.4357 .57214 m .43539 .57079 L .43542 .57317 L F
.43587 .57285 m .43777 .57121 L .43539 .57079 L F
.809 .597 .615 r
.42768 .56448 m .42763 .56701 L .4254 .56369 L F
.985 .732 .462 r
.388 .52505 m .38629 .52637 L .38628 .52389 L F
.388 .52505 m .3879 .52752 L .38629 .52637 L F
.943 .643 .441 r
.37457 .5442 m .37466 .54696 L .37675 .54779 L F
.904 .596 .453 r
.37459 .54975 m .37675 .54779 L .37466 .54696 L F
.929 .75 .64 r
.37229 .55153 m .37357 .5555 L .37582 .5505 L F
.3753 .55047 m .37582 .5505 L .37593 .55025 L F
.37229 .55153 m .37582 .5505 L .3753 .55047 L F
.838 .623 .612 r
.37595 .55067 m .37357 .5555 L .37622 .55556 L F
.37593 .55025 m .37582 .5505 L .37595 .55067 L F
.37582 .5505 m .37357 .5555 L .37595 .55067 L F
.904 .596 .453 r
.37498 .54939 m .37608 .55051 L .37675 .54779 L F
.37459 .54975 m .37567 .5503 L .37498 .54939 L F
.37567 .5503 m .37608 .55051 L .37498 .54939 L F
.37608 .55051 m .37816 .55157 L .3778 .55058 L F
.37608 .55051 m .3778 .55058 L .37675 .54779 L F
0 0 .335 r
.71247 .28931 m .71095 .28978 L .71287 .28814 L F
.71247 .28931 m .71062 .29285 L .71095 .28978 L F
.282 .132 .492 r
.23601 .53485 m .23716 .53667 L .2388 .53201 L F
.123 0 .106 r
.23716 .53667 m .24131 .53261 L .2388 .53201 L F
.809 .962 .908 r
.55001 .47528 m .54574 .47686 L .54914 .47494 L F
.829 .947 .899 r
.55202 .47144 m .55001 .47528 L .54914 .47494 L F
.55202 .47144 m .5531 .47257 L .55001 .47528 L F
0 0 .077 r
.34217 .52405 m .34438 .52112 L .34626 .52283 L F
.7 .75 .891 r
.34874 .52106 m .34626 .52283 L .34438 .52112 L F
.713 .868 .955 r
.60299 .35939 m .60654 .35919 L .60469 .35813 L F
.60211 .36004 m .60287 .3599 L .60299 .35939 L F
.60287 .3599 m .60654 .35919 L .60299 .35939 L F
.104 .237 .717 r
.60217 .3573 m .60312 .35884 L .60345 .35743 L F
.713 .868 .955 r
.6026 .35908 m .60469 .35813 L .60345 .35743 L F
.60211 .36004 m .60469 .35813 L .6026 .35908 L F
.104 .237 .717 r
.60312 .35884 m .60371 .3598 L .60345 .35743 L F
.795 .711 .771 r
.60211 .36004 m .59975 .36071 L .60217 .3573 L F
0 0 0 r
.60371 .3598 m .59975 .36071 L .60211 .36004 L F
.407 .49 .832 r
.6026 .35908 m .60371 .3598 L .60211 .36004 L F
.619 .462 .648 r
.60312 .35884 m .60265 .35911 L .60371 .3598 L F
.407 .49 .832 r
.60345 .35743 m .60371 .3598 L .6026 .35908 L F
.619 .462 .648 r
.60265 .35911 m .59975 .36071 L .60371 .3598 L F
.60217 .3573 m .60012 .3602 L .60312 .35884 L F
.60012 .3602 m .59975 .36071 L .60312 .35884 L F
.662 .789 .942 r
.31953 .65309 m .32376 .65362 L .32191 .65204 L F
.659 .931 .971 r
.32376 .65362 m .32413 .65188 L .32191 .65204 L F
.32376 .65362 m .32619 .65247 L .32413 .65188 L F
.905 .929 .551 r
.55544 .45284 m .55459 .4554 L .55402 .45422 L F
0 0 .476 r
.55459 .4554 m .55592 .45709 L .55402 .45422 L F
0 0 0 r
.66577 .31858 m .66822 .31718 L .66894 .31575 L F
.66577 .31858 m .66514 .3202 L .66822 .31718 L F
.466 .829 .571 r
.64224 .39987 m .64567 .39714 L .6445 .39824 L F
0 0 0 r
.6445 .39824 m .64567 .39714 L .64845 .39576 L F
.30332 .64631 m .30736 .64276 L .30532 .64438 L F
.834 .973 .884 r
.70781 .32713 m .71177 .3252 L .7111 .32504 L F
.457 .885 .818 r
.715 .32366 m .71362 .32392 L .71177 .3252 L F
.461 .889 .857 r
.71362 .32392 m .7111 .32504 L .71177 .3252 L F
.735 .325 .272 r
.36165 .60634 m .36276 .60866 L .36391 .60643 L F
.925 .86 .424 r
.36391 .60643 m .36276 .60866 L .36363 .60468 L F
.501 .308 .55 r
.55432 .43554 m .55512 .43661 L .55188 .43682 L F
.354 .354 .72 r
.70473 .29261 m .70613 .2879 L .70339 .2889 L F
.495 .314 .564 r
.70473 .29261 m .70509 .29573 L .70732 .29193 L F
.446 .192 .434 r
.70732 .29193 m .70692 .29329 L .7065 .29316 L F
.70732 .29193 m .7065 .29316 L .70473 .29261 L F
.354 .354 .72 r
.70473 .29261 m .7065 .29316 L .70645 .29244 L F
.248 0 0 r
.7065 .29316 m .70732 .29193 L .70633 .29362 L F
.354 .354 .72 r
.7065 .29316 m .70692 .29329 L .70679 .29237 L F
.7065 .29316 m .70679 .29237 L .70613 .2879 L F
.248 0 0 r
.70489 .29555 m .7065 .29316 L .70509 .29573 L F
.7065 .29316 m .70633 .29362 L .70509 .29573 L F
.70413 .29484 m .70676 .29244 L .70489 .29555 L F
.70676 .29244 m .70732 .29193 L .7064 .29331 L F
.70676 .29244 m .7064 .29331 L .70489 .29555 L F
.145 .1 .545 r
.70732 .29193 m .70939 .29223 L .70925 .28978 L F
0 0 0 r
.71062 .29285 m .71071 .2939 L .70917 .29598 L F
.663 .147 .001 r
.70732 .29193 m .71071 .2939 L .71023 .29329 L F
.70853 .29211 m .71023 .29329 L .70939 .29223 L F
.70732 .29193 m .71023 .29329 L .70853 .29211 L F
.478 .445 .743 r
.70815 .28911 m .70748 .29138 L .70925 .28978 L F
.145 .1 .545 r
.70732 .29193 m .70732 .29193 L .70692 .29329 L F
.70768 .29152 m .70925 .28978 L .70796 .29171 L F
.663 .147 .001 r
.70732 .29193 m .70779 .29274 L .71071 .2939 L F
.70779 .29274 m .70911 .29498 L .7105 .29404 L F
.70779 .29274 m .7105 .29404 L .71071 .2939 L F
.478 .445 .743 r
.70748 .29138 m .70717 .29244 L .70796 .29171 L F
.70717 .29244 m .70692 .29329 L .70741 .29255 L F
.70717 .29244 m .70741 .29255 L .70796 .29171 L F
.70748 .29138 m .70796 .29171 L .70925 .28978 L F
.70613 .2879 m .70679 .29237 L .70815 .28911 L F
.248 0 0 r
.70676 .29244 m .7068 .29244 L .70732 .29193 L F
.478 .445 .743 r
.7068 .29244 m .70692 .29329 L .70718 .29239 L F
.248 0 0 r
.7068 .29244 m .70721 .29244 L .70722 .29239 L F
.7068 .29244 m .70722 .29239 L .70732 .29193 L F
.478 .445 .743 r
.70679 .29237 m .7068 .29244 L .70815 .28911 L F
.7068 .29244 m .70718 .29239 L .70815 .28911 L F
.248 0 0 r
.70413 .29484 m .70675 .29454 L .70721 .29244 L F
.70413 .29484 m .70721 .29244 L .70676 .29244 L F
.354 .354 .72 r
.70479 .29242 m .70645 .29244 L .70613 .2879 L F
.70473 .29261 m .70645 .29244 L .70479 .29242 L F
.257 .466 .872 r
.62612 .41512 m .62656 .41648 L .6244 .41208 L F
.967 .874 .692 r
.62404 .417 m .62656 .41648 L .62612 .41512 L F
0 0 0 r
.53204 .43128 m .53378 .43043 L .5361 .42932 L F
.458 .74 .989 r
.28473 .55446 m .28728 .55435 L .2852 .55262 L F
.311 0 .183 r
.44735 .45673 m .44674 .45854 L .44421 .45923 L F
.718 .495 .586 r
.44735 .45673 m .45069 .45819 L .44909 .45743 L F
.44735 .45673 m .44909 .45743 L .44674 .45854 L F
.269 .61 .955 r
.40984 .48249 m .41122 .48212 L .40924 .48027 L F
.571 .843 .996 r
.40924 .48027 m .40984 .48249 L .40664 .48127 L F
.269 .61 .955 r
.40924 .48027 m .41122 .48212 L .40984 .48249 L F
.571 .843 .996 r
.40924 .48027 m .40984 .48249 L .40664 .48127 L F
.86 .585 .521 r
.38107 .56615 m .38441 .56439 L .38149 .56339 L F
.38107 .56615 m .38455 .5669 L .38441 .56439 L F
.446 .839 .981 r
.35089 .61264 m .35265 .61305 L .35345 .61208 L F
.35089 .61264 m .35265 .61305 L .35345 .61208 L F
.669 .912 .977 r
.70218 .28188 m .69913 .28303 L .70071 .28078 L F
.946 .662 .467 r
.58131 .40326 m .58137 .4007 L .5801 .40033 L F
.591 .946 .903 r
.69069 .36994 m .69187 .36821 L .68948 .36926 L F
.69069 .36994 m .69404 .36832 L .69187 .36821 L F
.581 .815 .428 r
.41468 .59968 m .41422 .60036 L .4166 .5971 L F
.315 .801 .883 r
.4123 .60018 m .41422 .60036 L .41468 .59968 L F
.996 .86 .568 r
.40188 .55785 m .39999 .5594 L .40023 .55658 L F
.40188 .55785 m .40112 .56065 L .39999 .5594 L F
.887 .991 .764 r
.37694 .61682 m .3794 .61338 L .37716 .61457 L F
.897 .981 .703 r
.37479 .61831 m .37694 .61682 L .37716 .61457 L F
.461 0 0 r
.70663 .30416 m .71005 .30583 L .7076 .3057 L F
.523 .479 .749 r
.31455 .62997 m .31624 .62578 L .31367 .62643 L F
.31455 .62997 m .31638 .6293 L .31624 .62578 L F
0 0 .432 r
.31455 .62997 m .31656 .63063 L .31638 .6293 L F
.31455 .62997 m .3148 .63292 L .31656 .63063 L F
.176 0 0 r
.2657 .51817 m .26789 .51787 L .27014 .51618 L F
0 0 0 r
.27014 .51618 m .27057 .51661 L .27162 .51447 L F
.27014 .51618 m .26789 .51787 L .27057 .51661 L F
.773 .997 .824 r
.34625 .64881 m .34679 .64714 L .34464 .64844 L F
.34625 .64881 m .34925 .64608 L .34679 .64714 L F
.691 .631 .784 r
.43373 .45865 m .43759 .45912 L .43596 .45594 L F
.12 .666 .823 r
.31648 .60577 m .31441 .60549 L .31909 .60564 L F
.175 0 .01 r
.24783 .52776 m .2503 .52731 L .25122 .52558 L F
.468 .452 .757 r
.25381 .52778 m .25122 .52558 L .25339 .52477 L F
.25381 .52778 m .25122 .52558 L .25339 .52477 L F
.807 .674 .716 r
.2503 .52731 m .25339 .52477 L .25122 .52558 L F
.65 .962 .925 r
.45995 .43634 m .45509 .43796 L .45863 .4361 L F
.707 .981 .794 r
.46097 .43449 m .46292 .43381 L .45995 .43634 L F
.673 .969 .921 r
.46097 .43449 m .45995 .43634 L .45863 .4361 L F
0 0 0 r
.50677 .49842 m .50913 .49724 L .51057 .49573 L F
0 0 .163 r
.51265 .49208 m .51057 .49573 L .51209 .49383 L F
.529 .825 .493 r
.51057 .49573 m .51072 .49551 L .51209 .49383 L F
.51057 .49573 m .50913 .49724 L .51072 .49551 L F
0 0 0 r
.28529 .57948 m .28861 .5778 L .28646 .57908 L F
.48769 .55097 m .48703 .55276 L .48623 .55456 L F
0 0 .274 r
.48703 .55276 m .48538 .55703 L .48623 .55456 L F
.372 .436 .798 r
.25151 .59321 m .25458 .59511 L .25557 .59438 L F
.508 .79 .996 r
.30566 .62775 m .30441 .62965 L .30273 .62866 L F
.30566 .62775 m .30701 .62912 L .30441 .62965 L F
0 0 0 r
.30441 .62965 m .30476 .6301 L .30273 .62866 L F
.30441 .62965 m .30701 .62912 L .30476 .6301 L F
.66894 .31575 m .67105 .31412 L .67157 .31241 L F
.004 0 0 r
.66894 .31575 m .6706 .31608 L .67105 .31412 L F
.66894 .31575 m .66822 .31718 L .6706 .31608 L F
.955 .624 .35 r
.39384 .53525 m .39173 .53401 L .39142 .53117 L F
.949 .701 .527 r
.39384 .53525 m .39134 .53647 L .39173 .53401 L F
.39384 .53525 m .39313 .53737 L .39134 .53647 L F
.816 .805 .841 r
.43596 .45594 m .43759 .45912 L .44016 .45601 L F
.674 .572 .732 r
.43759 .45912 m .44027 .45813 L .44016 .45601 L F
.916 .977 .767 r
.37823 .61263 m .38169 .6099 L .38063 .6091 L F
.37823 .61263 m .3794 .61338 L .38169 .6099 L F
.765 .666 .113 r
.38169 .6099 m .3819 .60578 L .38063 .6091 L F
.776 .32 .164 r
.34431 .50625 m .34622 .50492 L .34378 .50474 L F
.34431 .50625 m .34811 .50749 L .34622 .50492 L F
.675 .976 .878 r
.55402 .47821 m .55495 .47655 L .55334 .47828 L F
.55402 .47821 m .55733 .47609 L .55495 .47655 L F
.143 0 0 r
.31412 .56991 m .31692 .56912 L .3182 .56836 L F
.587 .352 .527 r
.3182 .56836 m .32073 .57007 L .32127 .56727 L F
.585 .812 .986 r
.57288 .45579 m .57707 .45629 L .57622 .45485 L F
.805 .565 .576 r
.57594 .45696 m .57707 .45629 L .57541 .45609 L F
.57309 .45865 m .57695 .45901 L .57707 .45629 L F
.564 .69 .925 r
.57695 .45901 m .57622 .45485 L .57707 .45629 L F
.57686 .45848 m .57779 .45639 L .57622 .45485 L F
.57695 .45901 m .57703 .45877 L .57686 .45848 L F
.57703 .45877 m .57779 .45639 L .57686 .45848 L F
.805 .565 .576 r
.57309 .45865 m .57594 .45696 L .57288 .45579 L F
.57594 .45696 m .57541 .45609 L .57288 .45579 L F
.959 .62 .3 r
.60496 .35165 m .60529 .35418 L .60359 .35269 L F
.95 .922 .746 r
.57444 .44937 m .57143 .45211 L .57416 .44853 L F
0 0 0 r
.51265 .49208 m .51458 .49056 L .51546 .48866 L F
0 0 .022 r
.51265 .49208 m .5137 .49217 L .51458 .49056 L F
.51265 .49208 m .51209 .49383 L .5137 .49217 L F
.933 .556 .2 r
.39881 .54467 m .3972 .54353 L .39666 .54132 L F
.977 .788 .583 r
.39881 .54467 m .39655 .54636 L .3972 .54353 L F
.39881 .54467 m .39824 .54746 L .39655 .54636 L F
.236 .428 .847 r
.56427 .37488 m .56124 .37546 L .56127 .37284 L F
.56427 .37488 m .56374 .3769 L .56124 .37546 L F
.382 .22 .534 r
.53513 .45319 m .53734 .4527 L .53664 .44967 L F
.437 .43 .753 r
.53513 .45319 m .53807 .45477 L .53734 .4527 L F
0 0 0 r
.35481 .56759 m .35728 .56393 L .35505 .56397 L F
.753 .858 .927 r
.60702 .37618 m .60436 .37807 L .60268 .37645 L F
.315 .358 .748 r
.51994 .44469 m .52101 .44925 L .52298 .44866 L F
.013 .093 .602 r
.52261 .40236 m .52068 .40051 L .52272 .39958 L F
.973 .663 .341 r
.50065 .44178 m .50169 .43973 L .50012 .43838 L F
.257 .646 .964 r
.50012 .43838 m .50169 .43973 L .50429 .43958 L F
.209 0 0 r
.50429 .43958 m .50169 .43973 L .50065 .44178 L F
.937 .794 .676 r
.38546 .58587 m .38857 .5835 L .3877 .58226 L F
.38546 .58587 m .38746 .58697 L .38857 .5835 L F
0 0 0 r
.53977 .44831 m .54114 .44741 L .53664 .44967 L F
.545 .427 .669 r
.53734 .4527 m .53977 .44831 L .53664 .44967 L F
.372 .436 .798 r
.25151 .59321 m .2529 .59734 L .25458 .59511 L F
.273 .299 .706 r
.2529 .59734 m .25531 .59926 L .25458 .59511 L F
.942 .893 .752 r
.40129 .58346 m .39966 .58238 L .40137 .57959 L F
.96 .624 .262 r
.40129 .58346 m .40026 .58518 L .39966 .58238 L F
.40129 .58346 m .40198 .58679 L .40026 .58518 L F
.931 .969 .743 r
.37716 .61457 m .3794 .61338 L .37823 .61263 L F
.001 0 .18 r
.41581 .45214 m .41728 .45218 L .4184 .4515 L F
.41581 .45214 m .41321 .45758 L .41728 .45218 L F
.988 .835 .601 r
.58377 .36945 m .5857 .36822 L .58423 .36663 L F
.58377 .36945 m .58515 .37099 L .5857 .36822 L F
.884 .919 .843 r
.54608 .45611 m .54707 .4516 L .54556 .45348 L F
.54608 .45611 m .54885 .45278 L .54707 .4516 L F
.376 .161 .455 r
.55647 .3966 m .55902 .39332 L .55659 .39426 L F
.743 .673 .782 r
.24758 .53006 m .2503 .52731 L .24783 .52776 L F
.544 .909 .959 r
.56363 .45625 m .56355 .45743 L .56149 .45624 L F
.56363 .45625 m .56669 .45625 L .56355 .45743 L F
0 0 0 r
.30516 .64469 m .30736 .64276 L .30332 .64631 L F
.747 .765 .868 r
.30822 .63844 m .30736 .64276 L .30594 .64263 L F
.30822 .63844 m .30912 .64198 L .30736 .64276 L F
.991 .886 .593 r
.30594 .64263 m .30736 .64276 L .30516 .64469 L F
.912 .58 .403 r
.3409 .50305 m .34379 .50234 L .3415 .50044 L F
.3409 .50305 m .34378 .50474 L .34379 .50234 L F
.415 .373 .703 r
.23826 .57007 m .23569 .56698 L .23723 .56481 L F
.506 0 0 r
.24128 .56544 m .23723 .56481 L .2404 .56574 L F
.24128 .56544 m .2406 .56612 L .23723 .56481 L F
0 0 .416 r
.23915 .56798 m .23723 .56481 L .2406 .56612 L F
.729 .278 .181 r
.23962 .56832 m .23915 .56798 L .24136 .56779 L F
0 .277 .683 r
.23826 .57007 m .2436 .5731 L .23912 .57288 L F
.23826 .57007 m .24309 .57277 L .2436 .5731 L F
.502 0 0 r
.23945 .5713 m .24309 .57277 L .24266 .57252 L F
.23945 .5713 m .24266 .57252 L .23826 .57007 L F
.048 .248 .745 r
.23912 .57288 m .23698 .57177 L .23826 .57007 L F
.502 0 0 r
.23945 .5713 m .23826 .57007 L .23915 .56798 L F
0 0 .416 r
.23915 .56798 m .23826 .57007 L .23764 .56692 L F
.415 .373 .703 r
.23826 .57007 m .23698 .57177 L .23569 .56698 L F
.652 .199 .162 r
.23915 .56798 m .23684 .57147 L .23945 .5713 L F
.351 .794 .633 r
.23581 .57327 m .23945 .5713 L .23684 .57147 L F
.969 .717 .499 r
.23945 .5713 m .23717 .57251 L .23774 .57064 L F
.652 .199 .162 r
.23915 .56798 m .23497 .56781 L .23684 .57147 L F
.23915 .56798 m .2391 .56818 L .23497 .56781 L F
.969 .717 .499 r
.23945 .5713 m .23791 .57071 L .23826 .56893 L F
.23791 .57071 m .23774 .57064 L .23781 .57041 L F
.23791 .57071 m .23781 .57041 L .23826 .56893 L F
.23945 .5713 m .23826 .56893 L .23837 .56883 L F
.23945 .5713 m .23837 .56883 L .23947 .56931 L F
.24148 .57036 m .23947 .56931 L .24166 .57027 L F
.23945 .5713 m .23947 .56931 L .24148 .57036 L F
.652 .199 .162 r
.2389 .56901 m .23858 .5703 L .23837 .56883 L F
.2391 .56818 m .2389 .56901 L .23837 .56883 L F
.969 .717 .499 r
.23837 .56883 m .23832 .56871 L .23916 .5691 L F
.729 .278 .181 r
.23832 .56871 m .23858 .5703 L .2389 .56901 L F
.23832 .56871 m .2389 .56901 L .23915 .56798 L F
.652 .199 .162 r
.2391 .56818 m .23753 .56958 L .23497 .56781 L F
.969 .717 .499 r
.23837 .56883 m .23826 .56893 L .23832 .56871 L F
0 0 .001 r
.23832 .56871 m .23826 .56893 L .23899 .56979 L F
.23826 .56893 m .23781 .57041 L .23813 .56999 L F
.652 .199 .162 r
.23826 .56893 m .23813 .56999 L .23753 .56958 L F
.301 .362 .759 r
.23631 .56593 m .2383 .56976 L .23659 .56554 L F
.652 .199 .162 r
.23837 .56883 m .23858 .5703 L .23813 .56999 L F
.301 .362 .759 r
.2383 .56976 m .23858 .5703 L .23833 .56972 L F
.652 .199 .162 r
.23837 .56883 m .23813 .56999 L .23826 .56893 L F
0 0 .001 r
.23826 .56893 m .23833 .56972 L .23833 .56901 L F
.857 .493 0 r
.23659 .56554 m .23833 .56972 L .23832 .56871 L F
.23833 .56972 m .23858 .5703 L .23832 .56871 L F
0 0 .001 r
.23826 .56893 m .23813 .56999 L .23833 .56972 L F
.23833 .56901 m .23833 .56972 L .23861 .56935 L F
.23861 .56935 m .23796 .57132 L .23899 .56979 L F
.301 .362 .759 r
.23813 .56999 m .23858 .5703 L .2383 .56976 L F
0 0 .001 r
.23813 .56999 m .23796 .57132 L .23861 .56935 L F
.301 .362 .759 r
.23753 .56958 m .23813 .56999 L .23631 .56593 L F
.23813 .56999 m .2383 .56976 L .23631 .56593 L F
.2383 .56976 m .23833 .56972 L .23659 .56554 L F
0 0 .001 r
.23813 .56999 m .23717 .57251 L .23796 .57132 L F
.23781 .57041 m .23717 .57251 L .23813 .56999 L F
.969 .717 .499 r
.23837 .56883 m .23916 .5691 L .24166 .57027 L F
.301 .362 .759 r
.23497 .56781 m .23753 .56958 L .23631 .56593 L F
.729 .278 .181 r
.23832 .56871 m .23915 .56798 L .23962 .56832 L F
0 0 .416 r
.23915 .56798 m .23764 .56692 L .23723 .56481 L F
.413 .815 .602 r
.54337 .44588 m .54114 .44741 L .53977 .44831 L F
.734 .75 .864 r
.33264 .51774 m .33543 .51997 L .33785 .5182 L F
.794 .459 0 r
.60797 .35121 m .60896 .35248 L .61156 .35112 L F
0 0 0 r
.45652 .59589 m .46096 .59551 L .4591 .59481 L F
.569 .875 .994 r
.4591 .59481 m .46096 .59551 L .46265 .5942 L F
0 0 0 r
.3952 .49879 m .39408 .50074 L .39267 .50176 L F
.705 .271 .217 r
.3952 .49879 m .39711 .50118 L .39408 .50074 L F
.527 .274 .475 r
.41093 .57077 m .41429 .57052 L .41337 .5729 L F
.983 .701 .343 r
.40034 .55096 m .39915 .55255 L .39841 .55009 L F
.40034 .55096 m .40054 .55389 L .39915 .55255 L F
.665 .875 .5 r
.63765 .34214 m .63647 .34346 L .63632 .34394 L F
0 0 0 r
.63851 .34218 m .63765 .34214 L .63953 .34042 L F
.63851 .34218 m .63647 .34346 L .63765 .34214 L F
.719 .548 .657 r
.34207 .53769 m .34694 .5393 L .34557 .53491 L F
.666 .518 .674 r
.34557 .53491 m .34869 .53788 L .34736 .53385 L F
.34557 .53491 m .34694 .5393 L .34869 .53788 L F
.808 .616 .642 r
.60319 .3896 m .6071 .39134 L .60561 .38846 L F
.399 .681 .975 r
.28306 .6427 m .28755 .64447 L .28546 .64249 L F
.49 .709 .967 r
.28546 .64249 m .28755 .64447 L .28891 .64393 L F
.602 .89 .587 r
.53742 .40387 m .53459 .4067 L .53779 .40644 L F
.393 0 0 r
.54246 .4043 m .53742 .40387 L .53779 .40644 L F
.54246 .4043 m .54292 .40358 L .53742 .40387 L F
.658 .639 .82 r
.46958 .44961 m .47383 .45129 L .4721 .44843 L F
.749 .693 .798 r
.47383 .45129 m .4764 .4496 L .4721 .44843 L F
.549 .497 .75 r
.50449 .45297 m .50617 .44852 L .50356 .44937 L F
.50449 .45297 m .50712 .45234 L .50617 .44852 L F
.566 .494 .733 r
.55992 .42568 m .56088 .43193 L .56321 .42967 L F
.793 .782 .843 r
.56321 .42967 m .56428 .43324 L .55947 .43289 L F
.821 .709 .742 r
.55947 .43289 m .56428 .43324 L .56202 .43664 L F
.707 .734 .872 r
.56723 .43089 m .56428 .43324 L .56321 .42967 L F
0 0 0 r
.51546 .48866 m .51458 .49056 L .51653 .48683 L F
.725 .605 .723 r
.62439 .39644 m .62175 .3997 L .62193 .39745 L F
.266 0 .202 r
.37185 .47492 m .36951 .47583 L .37244 .47311 L F
.37185 .47492 m .36951 .47583 L .37244 .47311 L F
.965 .678 .437 r
.37244 .47311 m .37185 .47492 L .37052 .47111 L F
.707 .47 .564 r
.37052 .47111 m .37474 .46884 L .37244 .47311 L F
.67 .579 .745 r
.37488 .4725 m .37244 .47311 L .37474 .46884 L F
.302 0 .098 r
.37488 .4725 m .37185 .47492 L .37244 .47311 L F
.275 .141 .51 r
.24774 .547 m .24579 .55064 L .24567 .54787 L F
.445 0 0 r
.36369 .60187 m .36551 .60259 L .36283 .60241 L F
.56 .612 .861 r
.32751 .54785 m .3284 .54399 L .32564 .54604 L F
.32751 .54785 m .32998 .54724 L .3284 .54399 L F
.282 .132 .492 r
.23601 .53485 m .23586 .53759 L .23716 .53667 L F
.774 .968 .674 r
.45885 .57781 m .45678 .5798 L .45821 .57809 L F
.485 .467 .763 r
.46177 .57626 m .46316 .58147 L .45885 .57781 L F
0 0 0 r
.62043 .37669 m .62269 .37631 L .62416 .37594 L F
.193 0 0 r
.63176 .33804 m .63531 .33665 L .63261 .33757 L F
.633 .128 0 r
.39326 .50294 m .39508 .5046 L .39267 .50176 L F
.701 .343 .366 r
.39267 .50176 m .39508 .5046 L .39616 .50267 L F
.633 .128 0 r
.39326 .50294 m .39267 .50176 L .39408 .50074 L F
.903 .935 .824 r
.60292 .41138 m .60268 .41418 L .60432 .41243 L F
.78 .936 .932 r
.60589 .40904 m .60432 .41243 L .60724 .41024 L F
.60589 .40904 m .60292 .41138 L .60432 .41243 L F
.326 .812 .815 r
.42792 .44904 m .4254 .44984 L .4233 .45004 L F
.319 .757 .967 r
.71859 .32474 m .72137 .32455 L .71738 .324 L F
.457 .002 .081 r
.4186 .5974 m .41468 .59968 L .4166 .5971 L F
.051 0 0 r
.67157 .31241 m .67338 .31288 L .67369 .31064 L F
.67157 .31241 m .67105 .31412 L .67338 .31288 L F
.967 .923 .594 r
.32964 .50363 m .32949 .50089 L .32947 .50256 L F
.32964 .50363 m .32818 .50402 L .32949 .50089 L F
.845 .386 .094 r
.33036 .50517 m .32818 .50402 L .32964 .50363 L F
.97 .893 .692 r
.50616 .44106 m .50805 .44332 L .50871 .43984 L F
.921 .917 .796 r
.50575 .44584 m .50805 .44332 L .50616 .44106 L F
.817 .438 .337 r
.50971 .44581 m .50805 .44332 L .50575 .44584 L F
.681 .539 .686 r
.63116 .35038 m .62721 .35035 L .63037 .34935 L F
.62721 .35035 m .62811 .35036 L .6293 .3475 L F
.62811 .35036 m .63116 .35038 L .63042 .34923 L F
.62811 .35036 m .63042 .34923 L .6293 .3475 L F
.699 .923 .967 r
.63037 .34935 m .63411 .34754 L .63265 .34815 L F
.63247 .34824 m .63265 .34815 L .63258 .34818 L F
.63037 .34935 m .63265 .34815 L .63247 .34824 L F
0 0 .211 r
.63258 .34818 m .63116 .35038 L .63037 .34935 L F
0 0 0 r
.33327 .60667 m .33222 .60886 L .33446 .60522 L F
.031 .348 .825 r
.32354 .5445 m .32403 .54306 L .32182 .54403 L F
.32354 .5445 m .32564 .54604 L .32403 .54306 L F
.079 0 0 r
.42679 .4564 m .42541 .45784 L .42275 .45869 L F
0 0 0 r
.42767 .45693 m .42679 .4564 L .42925 .45639 L F
.42767 .45693 m .42541 .45784 L .42679 .4564 L F
.652 .265 .299 r
.35236 .56816 m .35486 .56972 L .35481 .56759 L F
.35236 .56816 m .35211 .57041 L .35486 .56972 L F
.266 .696 .965 r
.5854 .43548 m .58532 .43609 L .58467 .43523 L F
.511 .834 .999 r
.54707 .4516 m .54885 .45278 L .54987 .45097 L F
.159 0 0 r
.65401 .38206 m .65253 .3816 L .65108 .38404 L F
.65401 .38206 m .65538 .38074 L .65253 .3816 L F
.04 .023 .507 r
.46549 .54509 m .46631 .54411 L .46574 .54101 L F
0 0 0 r
.46542 .54649 m .46631 .54411 L .46549 .54509 L F
.718 .203 0 r
.40927 .59037 m .40936 .59159 L .40668 .58979 L F
.40927 .59037 m .41123 .59284 L .40936 .59159 L F
.937 .616 .404 r
.36093 .52143 m .36132 .52411 L .36338 .52493 L F
.909 .525 .278 r
.36132 .52411 m .36172 .52635 L .36338 .52493 L F
.991 .733 .419 r
.36172 .52635 m .36192 .52785 L .36338 .52493 L F
.867 .846 .821 r
.53533 .4584 m .53702 .45983 L .53953 .45652 L F
.972 .849 .661 r
.68471 .33149 m .68169 .3329 L .68211 .33028 L F
.68471 .33149 m .68304 .3344 L .68169 .3329 L F
.962 .773 .601 r
.72484 .28676 m .72356 .28829 L .7223 .28422 L F
.589 .842 .481 r
.72484 .28676 m .72356 .28829 L .72619 .28505 L F
.577 .404 .611 r
.2745 .59027 m .27707 .58655 L .27467 .58711 L F
.807 .663 .704 r
.72859 .31829 m .72746 .31494 L .72755 .31746 L F
.932 .892 .768 r
.72576 .32001 m .72859 .31829 L .72755 .31746 L F
.831 .812 .832 r
.31063 .63973 m .30912 .64198 L .30822 .63844 L F
.607 .715 .921 r
.31402 .64267 m .30912 .64198 L .31063 .63973 L F
.592 .753 .955 r
.44305 .45662 m .4427 .45488 L .44016 .45601 L F
.699 .526 .649 r
.44027 .45813 m .44305 .45662 L .44016 .45601 L F
.44027 .45813 m .44421 .45923 L .44305 .45662 L F
.493 .68 .949 r
.44305 .45662 m .44528 .4549 L .4427 .45488 L F
.548 .571 .829 r
.44421 .45923 m .44528 .4549 L .44305 .45662 L F
.593 .358 .53 r
.34097 .5638 m .34368 .56378 L .34402 .56094 L F
.775 .71 .79 r
.34203 .55714 m .34402 .56094 L .34633 .55743 L F
.626 .504 .694 r
.34402 .56094 m .34715 .56085 L .34633 .55743 L F
.77 .643 .721 r
.34368 .56378 m .34715 .56085 L .34402 .56094 L F
.05 .604 .822 r
.51994 .44469 m .51741 .44312 L .51645 .44621 L F
.866 .469 .283 r
.35025 .50809 m .35193 .51115 L .35411 .5116 L F
.873 .473 .272 r
.35241 .513 m .35411 .5116 L .35193 .51115 L F
.35241 .513 m .35549 .51474 L .35411 .5116 L F
0 .071 .574 r
.30052 .6434 m .29665 .64494 L .29915 .64455 L F
.30052 .6434 m .29821 .64106 L .29665 .64494 L F
.773 .266 0 r
.30332 .64631 m .30052 .6434 L .3027 .64529 L F
.635 .161 .11 r
.3027 .64529 m .30052 .6434 L .29915 .64455 L F
0 0 0 r
.66333 .33173 m .66244 .3314 L .66481 .33116 L F
.66333 .33173 m .66127 .3334 L .66244 .3314 L F
.453 0 .054 r
.31863 .5908 m .32142 .58986 L .32044 .59122 L F
.661 .774 .933 r
.61379 .40722 m .61401 .40541 L .61294 .40596 L F
.61379 .40722 m .6165 .40626 L .61401 .40541 L F
.113 .077 .534 r
.23425 .54113 m .23409 .54483 L .23592 .54291 L F
.335 .298 .668 r
.23445 .54743 m .23592 .54291 L .23409 .54483 L F
.679 .734 .892 r
.71202 .28023 m .71272 .28266 L .70873 .28183 L F
.483 .605 .897 r
.71452 .28142 m .71272 .28266 L .71202 .28023 L F
0 0 .479 r
.71328 .28318 m .71272 .28266 L .71452 .28142 L F
.483 .605 .897 r
.71452 .28142 m .71202 .28023 L .71459 .28023 L F
.871 .755 .732 r
.71196 .28143 m .71328 .28318 L .71459 .28023 L F
0 0 .479 r
.71328 .28318 m .71351 .28349 L .71272 .28266 L F
0 0 .396 r
.71361 .28359 m .7138 .28576 L .71272 .28266 L F
.871 .755 .732 r
.71037 .28216 m .71328 .28318 L .71196 .28143 L F
0 0 .479 r
.71328 .28318 m .71361 .28359 L .71351 .28349 L F
.432 .273 .565 r
.31312 .5934 m .31522 .59292 L .31354 .59053 L F
.318 .205 .565 r
.23425 .54113 m .23612 .54039 L .23586 .53759 L F
.113 .077 .534 r
.23425 .54113 m .23592 .54291 L .23612 .54039 L F
.454 .036 .155 r
.67439 .3252 m .67293 .32732 L .67048 .32755 L F
.635 .233 .266 r
.67714 .32722 m .67293 .32732 L .67439 .3252 L F
.601 .767 .959 r
.62133 .37885 m .62269 .37631 L .62043 .37669 L F
.62133 .37885 m .6242 .3781 L .62269 .37631 L F
.411 .401 .738 r
.6092 .41706 m .61203 .41784 L .61215 .4165 L F
0 0 0 r
.51568 .39689 m .51715 .39526 L .5191 .39261 L F
.597 .932 .73 r
.52174 .39053 m .5191 .39261 L .52053 .39121 L F
0 0 0 r
.5191 .39261 m .51829 .39418 L .52053 .39121 L F
.5191 .39261 m .51722 .39516 L .51829 .39418 L F
.15 .684 .85 r
.52053 .39121 m .52374 .39118 L .52174 .39053 L F
.52053 .39121 m .52224 .39085 L .52374 .39118 L F
0 0 0 r
.52053 .39121 m .51829 .39418 L .52224 .39085 L F
.794 .898 .916 r
.52176 .39098 m .51829 .39418 L .51766 .39216 L F
.52224 .39085 m .51829 .39418 L .52176 .39098 L F
0 0 0 r
.51722 .39516 m .51715 .39526 L .51829 .39418 L F
.25609 .5217 m .25837 .52117 L .25991 .52072 L F
.25991 .52072 m .26077 .52073 L .26288 .51944 L F
.344 0 .006 r
.25837 .52117 m .26077 .52073 L .25991 .52072 L F
.12 0 .11 r
.26971 .52121 m .26647 .52419 L .26758 .52211 L F
.887 .678 .614 r
.38331 .56978 m .386 .57339 L .38602 .57073 L F
.571 .399 .61 r
.52217 .47239 m .52538 .46813 L .5214 .47136 L F
.98 .711 .442 r
.42933 .47179 m .43132 .47609 L .42955 .47467 L F
.42933 .47179 m .43132 .47609 L .42955 .47467 L F
.42955 .47467 m .43132 .47609 L .42933 .47179 L F
.42955 .47467 m .43132 .47609 L .42933 .47179 L F
.345 0 0 r
.40419 .48208 m .40197 .48182 L .40002 .48402 L F
.906 .969 .807 r
.31326 .59371 m .31064 .59689 L .31312 .5934 L F
.31326 .59371 m .31064 .59689 L .31312 .5934 L F
.411 .484 .824 r
.31522 .59292 m .31326 .59371 L .31312 .5934 L F
.785 .963 .922 r
.34925 .64608 m .3518 .64403 L .34925 .64399 L F
.868 .993 .814 r
.34679 .64714 m .34925 .64608 L .34925 .64399 L F
.197 .155 .582 r
.30433 .63823 m .30208 .63864 L .30216 .63582 L F
0 0 0 r
.30096 .63986 m .30208 .63864 L .30433 .63823 L F
.589 .629 .859 r
.30484 .64838 m .30672 .64634 L .30332 .64631 L F
.30484 .64838 m .3086 .64962 L .30672 .64634 L F
.877 .982 .698 r
.45316 .57203 m .45517 .57079 L .45308 .57402 L F
.856 .996 .818 r
.45517 .57079 m .45572 .56813 L .458 .56753 L F
.873 .983 .699 r
.45316 .57203 m .45572 .56813 L .45517 .57079 L F
.853 .51 .403 r
.38438 .57885 m .38753 .5775 L .3856 .57635 L F
.38438 .57885 m .38799 .57984 L .38753 .5775 L F
.306 0 0 r
.29821 .64106 m .29702 .64062 L .29469 .64139 L F
.867 .993 .816 r
.2974 .6382 m .29702 .64062 L .29469 .64139 L F
.563 .056 0 r
.4008 .49989 m .40237 .50133 L .39974 .49861 L F
.658 .842 .971 r
.40237 .50133 m .40253 .50137 L .39974 .49861 L F
.542 .604 .864 r
.31911 .63881 m .31727 .63988 L .31487 .63611 L F
.194 0 .276 r
.31648 .64213 m .31727 .63988 L .31911 .63881 L F
.31911 .63881 m .31727 .63988 L .31648 .64213 L F
.539 .491 .751 r
.3556 .61887 m .35706 .62343 L .35448 .62403 L F
.583 .766 .966 r
.4721 .44843 m .4764 .4496 L .47417 .44743 L F
.615 .71 .913 r
.4764 .4496 m .47754 .44613 L .47417 .44743 L F
.4764 .4496 m .47885 .44889 L .47754 .44613 L F
.676 .759 .913 r
.53807 .45477 m .53953 .45652 L .54185 .45403 L F
.589 .472 .688 r
.51527 .43958 m .51877 .43904 L .51742 .43617 L F
.526 .255 .448 r
.51746 .44185 m .51877 .43904 L .51527 .43958 L F
.557 .097 .116 r
.44724 .58042 m .44566 .58235 L .44274 .58261 L F
.814 .416 .297 r
.44912 .58241 m .44566 .58235 L .44724 .58042 L F
.915 .607 .448 r
.71268 .30693 m .71461 .30839 L .71428 .30566 L F
.546 .363 .584 r
.71769 .30467 m .71428 .30566 L .71693 .30232 L F
.531 .326 .547 r
.71428 .30566 m .71461 .30839 L .71769 .30467 L F
.71428 .30566 m .71461 .30839 L .71769 .30467 L F
.557 .227 .364 r
.34463 .57565 m .3454 .5734 L .34246 .5738 L F
.23 0 0 r
.34558 .57302 m .3454 .5734 L .34246 .5738 L F
.781 .712 .787 r
.33806 .57302 m .34024 .57666 L .34246 .5738 L F
.826 .514 .461 r
.34463 .57565 m .3454 .5734 L .34067 .57234 L F
.741 .773 .274 r
.34508 .57409 m .3454 .5734 L .34463 .57565 L F
.735 .792 .898 r
.34067 .57234 m .3454 .5734 L .34311 .57131 L F
.471 .705 .971 r
.34311 .57131 m .3454 .5734 L .34595 .57106 L F
.741 .773 .274 r
.34595 .57106 m .3454 .5734 L .34508 .57409 L F
.23 0 0 r
.34726 .5726 m .3454 .5734 L .34558 .57302 L F
.583 .102 .078 r
.34909 .57349 m .3454 .5734 L .34726 .5726 L F
.34909 .57349 m .3454 .5734 L .34726 .5726 L F
0 .477 .743 r
.59957 .3439 m .60204 .34444 L .60285 .3447 L F
.22 .73 .887 r
.59824 .34415 m .60204 .34444 L .59957 .3439 L F
.59824 .34415 m .60053 .34396 L .60204 .34444 L F
.60053 .34396 m .60094 .34393 L .60204 .34444 L F
0 .477 .743 r
.60285 .3447 m .60204 .34444 L .60356 .34487 L F
0 .528 .705 r
.60204 .34444 m .60625 .3448 L .60356 .34487 L F
.526 .45 .713 r
.36068 .55746 m .36102 .56088 L .36308 .56031 L F
.643 .908 .599 r
.36098 .56188 m .36308 .56031 L .36102 .56088 L F
.788 .619 .671 r
.54246 .4043 m .544 .40292 L .54292 .40358 L F
.804 .988 .885 r
.45146 .57388 m .45308 .57402 L .45241 .57679 L F
.45146 .57388 m .45316 .57203 L .45308 .57402 L F
.514 .406 .669 r
.30433 .63244 m .3047 .63584 L .30216 .63582 L F
.197 .155 .582 r
.30433 .63823 m .30216 .63582 L .3047 .63584 L F
.263 0 0 r
.30217 .63729 m .3047 .63584 L .30216 .63582 L F
.514 .406 .669 r
.30433 .63244 m .3047 .63584 L .30216 .63582 L F
.863 .802 .789 r
.42954 .57064 m .42928 .57161 L .42754 .57363 L F
.796 .562 .583 r
.45383 .58604 m .45836 .58391 L .45765 .58376 L F
.45383 .58604 m .45784 .58692 L .45836 .58391 L F
.058 0 .415 r
.23313 .55096 m .23439 .55013 L .23445 .54743 L F
0 0 0 r
.23313 .55096 m .23181 .55328 L .23439 .55013 L F
.795 .671 .728 r
.58941 .37741 m .59087 .37858 L .58918 .37439 L F
.946 .603 .198 r
.58941 .37741 m .59102 .38138 L .59087 .37858 L F
.669 .611 .781 r
.58918 .37439 m .59087 .37858 L .59344 .37721 L F
.517 .403 .663 r
.59087 .37858 m .59392 .37993 L .59344 .37721 L F
.59087 .37858 m .59102 .38138 L .59392 .37993 L F
.929 .971 .745 r
.61306 .35831 m .61154 .36108 L .61126 .35789 L F
.989 .734 .441 r
.61322 .36305 m .61126 .35789 L .61154 .36108 L F
.67 .945 .686 r
.65662 .39191 m .65953 .38909 L .65808 .38982 L F
0 0 0 r
.65752 .39111 m .65662 .39191 L .65808 .38982 L F
.465 .849 .631 r
.65576 .39268 m .65816 .39098 L .65662 .39191 L F
0 0 0 r
.6563 .39389 m .65662 .39191 L .65752 .39111 L F
.465 .849 .631 r
.65475 .39339 m .65576 .39268 L .65662 .39191 L F
.661 .967 .791 r
.65953 .38909 m .65816 .39098 L .66024 .38912 L F
.644 .929 .66 r
.65662 .39191 m .65816 .39098 L .65953 .38909 L F
.738 .992 .826 r
.61208 .37569 m .61085 .37794 L .61393 .37538 L F
.69 .953 .953 r
.61208 .37569 m .60746 .37788 L .61085 .37794 L F
.795 .821 .872 r
.46578 .44965 m .46958 .44961 L .46809 .44812 L F
.627 .919 .978 r
.46958 .44961 m .47245 .44683 L .46809 .44812 L F
.46958 .44961 m .4721 .44843 L .47245 .44683 L F
.551 .37 .589 r
.65598 .33532 m .65621 .33826 L .65336 .33898 L F
.328 .206 .557 r
.6584 .33654 m .65598 .33532 L .65896 .33459 L F
.6584 .33654 m .65621 .33826 L .65598 .33532 L F
.772 .764 .846 r
.42388 .4652 m .42502 .46793 L .42776 .46528 L F
.777 .732 .811 r
.35811 .53539 m .35578 .53791 L .35935 .53793 L F
.575 .545 .784 r
.35578 .53791 m .35892 .54016 L .35935 .53793 L F
.564 .629 .874 r
.35811 .53539 m .35935 .53793 L .3611 .53744 L F
.686 .98 .861 r
.35892 .54016 m .3611 .53744 L .35935 .53793 L F
.11 0 0 r
.65336 .33898 m .65294 .33988 L .64964 .34075 L F
.23 0 0 r
.65587 .33931 m .65294 .33988 L .65336 .33898 L F
.248 0 0 r
.65621 .33826 m .65587 .33931 L .65336 .33898 L F
.771 .816 .888 r
.45069 .45819 m .45356 .45578 L .45161 .45444 L F
.729 .599 .711 r
.57568 .41664 m .58013 .41783 L .57832 .41368 L F
.812 .664 .699 r
.5755 .41877 m .58013 .41783 L .57568 .41664 L F
.5755 .41877 m .57952 .41956 L .58013 .41783 L F
.675 .51 .654 r
.57952 .41956 m .58175 .41688 L .58013 .41783 L F
.847 .392 .113 r
.25369 .62895 m .25615 .63251 L .25392 .63191 L F
.707 .433 .508 r
.25369 .62895 m .25678 .62951 L .25615 .63251 L F
.601 .896 .988 r
.25099 .62563 m .25442 .62548 L .25191 .62636 L F
0 .097 .578 r
.25472 .62883 m .25099 .62563 L .25442 .62548 L F
.982 .699 .392 r
.25434 .62558 m .25472 .62883 L .25442 .62548 L F
.25306 .62739 m .25383 .62806 L .25434 .62558 L F
.25383 .62806 m .25472 .62883 L .25434 .62558 L F
.597 .105 .056 r
.25026 .62865 m .25472 .62883 L .25216 .62943 L F
.935 .867 .747 r
.25216 .62943 m .25472 .62883 L .25306 .62739 L F
.859 .97 .866 r
.25553 .62745 m .25472 .62883 L .25216 .62943 L F
.25623 .62703 m .25472 .62883 L .25553 .62745 L F
.847 .392 .113 r
.25369 .62895 m .2538 .63039 L .25472 .62883 L F
.2538 .63039 m .25392 .63191 L .25472 .62883 L F
.95 .945 .735 r
.25734 .62639 m .25711 .62756 L .25472 .62883 L F
.926 .701 .579 r
.25216 .62943 m .25472 .62883 L .25392 .63191 L F
.25216 .62943 m .25472 .62883 L .25392 .63191 L F
.859 .97 .866 r
.25623 .62703 m .25374 .6285 L .25496 .63033 L F
.25374 .6285 m .25216 .62943 L .25346 .62985 L F
.25374 .6285 m .25346 .62985 L .25496 .63033 L F
.612 .429 .611 r
.55076 .39762 m .55085 .39969 L .55331 .39697 L F
.773 .686 .768 r
.29097 .54066 m .29258 .5445 L .2952 .54118 L F
.742 .991 .873 r
.33704 .65081 m .34017 .6504 L .34216 .64866 L F
0 0 0 r
.64505 .33211 m .64624 .33176 L .64782 .33123 L F
.64505 .33211 m .64376 .33294 L .64624 .33176 L F
.813 .932 .911 r
.51007 .4031 m .50502 .40458 L .50929 .40263 L F
.811 .999 .801 r
.51007 .4031 m .51054 .40084 L .51335 .4005 L F
.51007 .4031 m .50929 .40263 L .51054 .40084 L F
.473 .674 .952 r
.57586 .3626 m .57833 .36226 L .57629 .36442 L F
.57586 .3626 m .57833 .36226 L .57629 .36442 L F
.849 .561 .5 r
.38628 .52389 m .383 .52068 L .38555 .52209 L F
.896 .648 .557 r
.37622 .55556 m .37974 .55428 L .37797 .55348 L F
.37622 .55556 m .3797 .5571 L .37974 .55428 L F
.963 .942 .664 r
.69729 .35322 m .6995 .35095 L .69864 .34964 L F
.69729 .35322 m .69795 .35449 L .6995 .35095 L F
.688 .655 .811 r
.61202 .39797 m .61319 .39385 L .61076 .39415 L F
.601 .886 .991 r
.43823 .47788 m .4353 .47905 L .43611 .47719 L F
.43823 .47788 m .4353 .47905 L .43611 .47719 L F
.478 .274 .524 r
.4353 .47905 m .43506 .48174 L .43823 .47788 L F
.088 0 .042 r
.32451 .57861 m .32344 .58019 L .32644 .5772 L F
.879 .756 .723 r
.71287 .31058 m .71566 .31194 L .71461 .30839 L F
.854 .413 .165 r
.71287 .31058 m .71465 .31328 L .71566 .31194 L F
0 0 0 r
.71566 .31194 m .71801 .3103 L .71866 .31151 L F
.71566 .31194 m .71465 .31328 L .71801 .3103 L F
.348 0 .212 r
.34633 .55743 m .34881 .55682 L .3501 .55487 L F
.64 .83 .42 r
.3501 .55487 m .34881 .55682 L .35115 .55312 L F
.743 .626 .73 r
.55085 .39969 m .55489 .40095 L .55331 .39697 L F
.741 .316 .24 r
.55085 .39969 m .55363 .40257 L .55489 .40095 L F
.935 .913 .53 r
.55489 .40095 m .55363 .40257 L .55411 .40322 L F
.702 .635 .779 r
.55489 .40095 m .55647 .3966 L .55331 .39697 L F
.55489 .40095 m .55747 .39983 L .55647 .3966 L F
.504 .633 .91 r
.3518 .64403 m .35363 .64551 L .3543 .64249 L F
.864 .894 .855 r
.3543 .64249 m .35363 .64551 L .35736 .64147 L F
0 0 0 r
.35235 .55139 m .35115 .55312 L .35426 .55037 L F
.336 0 .133 r
.59074 .3671 m .59318 .36677 L .59466 .36434 L F
.83 .494 .419 r
.59466 .36434 m .59318 .36677 L .59636 .36721 L F
.621 .953 .787 r
.46501 .43215 m .46292 .43381 L .46097 .43449 L F
.774 .914 .934 r
.67379 .35948 m .6718 .36306 L .67067 .3625 L F
.67379 .35948 m .6749 .36081 L .6718 .36306 L F
.737 .649 .762 r
.45431 .50496 m .45673 .50174 L .45301 .50083 L F
.794 .947 .922 r
.6158 .41944 m .61677 .42061 L .61895 .41896 L F
.41 .586 .914 r
.36068 .55746 m .36217 .55663 L .35842 .55444 L F
.526 .45 .713 r
.36068 .55746 m .36308 .56031 L .36217 .55663 L F
.897 .528 .33 r
.33539 .59023 m .3322 .58906 L .3319 .58667 L F
.917 .975 .773 r
.33539 .59023 m .33242 .59102 L .3322 .58906 L F
.33539 .59023 m .33316 .59315 L .33242 .59102 L F
.991 .769 .388 r
.57751 .38848 m .57872 .38735 L .57733 .3858 L F
.57751 .38848 m .57848 .38988 L .57872 .38735 L F
0 0 0 r
.5001 .52794 m .49939 .53003 L .49786 .5315 L F
.735 .903 .524 r
.49939 .53003 m .49724 .53382 L .49786 .5315 L F
.855 .961 .625 r
.61856 .36749 m .61647 .37122 L .61687 .36892 L F
.992 .736 .395 r
.61647 .37122 m .61515 .37126 L .61687 .36892 L F
.61647 .37122 m .61643 .37356 L .61515 .37126 L F
.586 .467 .684 r
.25575 .53459 m .25623 .53781 L .2536 .53793 L F
.607 .677 .891 r
.70441 .27892 m .7059 .28274 L .70218 .28188 L F
.582 .878 .993 r
.70218 .28188 m .70429 .27991 L .70441 .27892 L F
.70218 .28188 m .70071 .28078 L .70429 .27991 L F
.721 .366 .377 r
.39616 .50267 m .39942 .50452 L .39711 .50118 L F
.39616 .50267 m .39508 .5046 L .39942 .50452 L F
.975 .722 .486 r
.58303 .42878 m .58472 .42994 L .58314 .42607 L F
.965 .651 .369 r
.58327 .4313 m .58472 .42994 L .58303 .42878 L F
.99 .732 .422 r
.58327 .4313 m .58468 .43259 L .58472 .42994 L F
0 0 .159 r
.32364 .59697 m .32437 .59761 L .32307 .59552 L F
.32364 .59697 m .32375 .59948 L .32437 .59761 L F
.407 0 0 r
.41539 .51621 m .41799 .51638 L .41497 .51557 L F
.608 .411 .59 r
.26908 .59351 m .27234 .59461 L .27179 .59105 L F
.505 .27 .492 r
.27179 .59105 m .27614 .59139 L .2745 .59027 L F
.879 .992 .797 r
.62262 .35474 m .61994 .35798 L .61967 .35699 L F
.62262 .35474 m .61967 .35699 L .62138 .35594 L F
.402 .16 .429 r
.62252 .35702 m .61994 .35798 L .62262 .35474 L F
.312 .143 .484 r
.62595 .35132 m .62525 .35397 L .62262 .35474 L F
.282 .068 .401 r
.62525 .35397 m .62252 .35702 L .62262 .35474 L F
.828 .994 .858 r
.62367 .35424 m .62262 .35474 L .62138 .35594 L F
.312 .143 .484 r
.62595 .35132 m .62525 .35397 L .62262 .35474 L F
.828 .994 .858 r
.62367 .35424 m .62525 .35397 L .62262 .35474 L F
.826 .973 .665 r
.55733 .47609 m .55982 .47247 L .55812 .47365 L F
.809 .995 .863 r
.55733 .47609 m .55812 .47365 L .55495 .47655 L F
.791 .481 .465 r
.45466 .57737 m .45821 .57809 L .45678 .5798 L F
0 0 0 r
.36064 .61543 m .3601 .61633 L .35973 .61809 L F
.977 .682 .307 r
.578 .3979 m .57962 .39705 L .57787 .39544 L F
.578 .3979 m .5801 .40033 L .57962 .39705 L F
.821 .439 0 r
.57621 .37397 m .57525 .37278 L .57435 .37034 L F
0 0 .201 r
.57621 .37397 m .57742 .37469 L .57525 .37278 L F
.57621 .37397 m .57572 .37695 L .57742 .37469 L F
0 0 0 r
.50677 .49842 m .5061 .50005 L .50913 .49724 L F
.282 .048 .371 r
.25615 .63251 m .25678 .62951 L .25875 .62888 L F
.801 .711 .765 r
.34881 .55682 m .35033 .56069 L .35311 .5573 L F
.42 .81 .988 r
.35311 .5573 m .35135 .55621 L .34881 .55682 L F
.718 .58 .699 r
.35033 .56069 m .35518 .56168 L .35311 .5573 L F
.347 0 0 r
.35606 .55528 m .35135 .55621 L .35311 .5573 L F
.407 .171 .441 r
.33824 .56653 m .34056 .56631 L .34097 .5638 L F
.9 .528 .321 r
.33872 .56735 m .34056 .56631 L .33824 .56653 L F
.863 .954 .868 r
.69733 .27831 m .69599 .27741 L .69835 .27621 L F
.418 .417 .752 r
.69952 .27424 m .69733 .27831 L .69834 .27623 L F
.69959 .27411 m .70053 .27859 L .69733 .27831 L F
.506 .293 .525 r
.69787 .27702 m .69679 .27993 L .70008 .27655 L F
.69599 .27741 m .69657 .27921 L .69787 .27702 L F
.69657 .27921 m .69679 .27993 L .69787 .27702 L F
.418 .417 .752 r
.69959 .27411 m .69952 .27424 L .69835 .27621 L F
.69952 .27424 m .69834 .27623 L .69835 .27621 L F
.512 .31 .543 r
.69599 .27741 m .69986 .27544 L .69959 .27411 L F
.418 .417 .752 r
.69959 .27411 m .69835 .27621 L .69886 .27514 L F
.512 .31 .543 r
.69835 .27621 m .70008 .27655 L .69986 .27544 L F
.69599 .27741 m .69787 .27702 L .69835 .27621 L F
.69787 .27702 m .70008 .27655 L .69835 .27621 L F
.863 .954 .868 r
.69835 .27621 m .69599 .27741 L .69886 .27514 L F
.759 .814 .338 r
.70911 .29498 m .70917 .29598 L .71071 .2939 L F
.518 .889 .688 r
.39924 .49129 m .40308 .48881 L .40142 .48756 L F
.875 .884 .838 r
.40142 .48756 m .40308 .48881 L .40577 .48555 L F
.428 .801 .994 r
.44511 .59668 m .44742 .59675 L .44342 .59646 L F
.551 .033 0 r
.44342 .59646 m .44742 .59675 L .44649 .59779 L F
.388 0 0 r
.44742 .59675 m .44848 .59833 L .44649 .59779 L F
.44742 .59675 m .4501 .59658 L .44848 .59833 L F
0 0 0 r
.33106 .53421 m .32948 .53625 L .33166 .53297 L F
.731 .709 .831 r
.52288 .43243 m .52741 .43363 L .5256 .42913 L F
.523 .542 .817 r
.52288 .43243 m .52697 .43553 L .52741 .43363 L F
.299 0 .278 r
.52697 .43553 m .53 .43272 L .52741 .43363 L F
.52697 .43553 m .53 .43272 L .52741 .43363 L F
0 .493 .806 r
.46892 .53845 m .46794 .53866 L .46766 .53956 L F
0 0 0 r
.46574 .54101 m .46766 .53956 L .46794 .53866 L F
.415 .115 .345 r
.29136 .55069 m .29002 .55381 L .28728 .55435 L F
.612 .606 .82 r
.29163 .54859 m .29136 .55069 L .2898 .54881 L F
.29163 .54859 m .29387 .55032 L .29136 .55069 L F
0 0 .058 r
.2915 .55229 m .29136 .55069 L .29387 .55032 L F
.2915 .55229 m .29002 .55381 L .29136 .55069 L F
.303 .779 .925 r
.60625 .3448 m .60895 .34441 L .61026 .34481 L F
.255 .758 .885 r
.61156 .34401 m .61026 .34481 L .60895 .34441 L F
.61156 .34401 m .613 .34445 L .61026 .34481 L F
0 0 0 r
.51353 .43308 m .51676 .43046 L .51575 .43177 L F
.51575 .43177 m .51676 .43046 L .51872 .42896 L F
.707 .455 .541 r
.3468 .59025 m .34655 .5929 L .3411 .5922 L F
.256 0 .269 r
.34942 .5897 m .34655 .5929 L .3468 .59025 L F
.34655 .5929 m .34942 .5897 L .3468 .59025 L F
0 .218 .733 r
.34655 .5929 m .34856 .59713 L .34905 .59522 L F
.724 .976 .922 r
.34856 .59713 m .34533 .5974 L .34905 .59522 L F
.445 .297 .585 r
.6096 .40889 m .60724 .41024 L .60732 .4072 L F
.996 .861 .542 r
.60676 .44213 m .60604 .44093 L .60369 .44242 L F
.884 .79 .751 r
.60369 .44242 m .60488 .44673 L .60676 .44213 L F
.11 .579 .914 r
.48295 .44951 m .48673 .45087 L .48558 .44901 L F
.427 .645 .949 r
.48558 .44901 m .48673 .45087 L .4891 .45061 L F
.319 .057 .35 r
.32073 .57007 m .32342 .56703 L .32127 .56727 L F
.644 .965 .901 r
.69187 .36821 m .69404 .36832 L .69619 .36682 L F
.015 0 0 r
.6224 .34116 m .62566 .34032 L .62309 .3409 L F
.998 .847 .535 r
.60797 .35121 m .60925 .35753 L .60972 .35471 L F
.77 .643 .721 r
.34368 .56378 m .34851 .56442 L .34715 .56085 L F
.971 .771 .577 r
.34579 .56575 m .34851 .56442 L .34368 .56378 L F
.34579 .56575 m .34761 .567 L .34851 .56442 L F
.743 .63 .734 r
.34715 .56085 m .34851 .56442 L .35033 .56069 L F
.186 .265 .712 r
.25844 .59285 m .26115 .59573 L .25937 .59698 L F
.908 .978 .787 r
.26115 .59573 m .25967 .59973 L .25937 .59698 L F
0 0 0 r
.46624 .54185 m .46576 .54111 L .46631 .54411 L F
.847 .784 .283 r
.46576 .54402 m .46624 .54185 L .46629 .54337 L F
.46576 .54402 m .46629 .54337 L .46631 .54411 L F
0 0 0 r
.46207 .54669 m .46576 .54402 L .46321 .54737 L F
.46515 .54459 m .46537 .54449 L .46576 .54402 L F
.847 .784 .283 r
.46576 .54402 m .46631 .54411 L .46542 .54649 L F
.867 .995 .796 r
.46321 .54737 m .46576 .54402 L .46542 .54649 L F
0 0 0 r
.46537 .54449 m .46775 .54339 L .46576 .54402 L F
.062 .05 .529 r
.46576 .54402 m .46647 .54219 L .46624 .54185 L F
.46647 .54219 m .46718 .54036 L .46624 .54185 L F
0 0 0 r
.46624 .54185 m .46574 .54101 L .46576 .54111 L F
.46624 .54185 m .46766 .53956 L .46574 .54101 L F
.584 .081 .024 r
.27234 .59461 m .27143 .59546 L .26908 .59351 L F
.735 .966 .697 r
.458 .56753 m .45918 .56521 L .4606 .56463 L F
.732 .991 .844 r
.45572 .56813 m .45918 .56521 L .458 .56753 L F
.896 .882 .812 r
.35736 .64147 m .35651 .63962 L .3543 .64249 L F
.825 1 .803 r
.61399 .3732 m .61393 .37538 L .61643 .37356 L F
.61399 .3732 m .61208 .37569 L .61393 .37538 L F
.302 0 .098 r
.37488 .4725 m .37445 .47431 L .37185 .47492 L F
0 0 .499 r
.37474 .46884 m .37547 .47188 L .37488 .4725 L F
0 0 0 r
.37547 .47188 m .37445 .47431 L .37488 .4725 L F
.385 .84 .912 r
.43526 .44609 m .43479 .44708 L .43278 .44708 L F
.43526 .44609 m .43743 .44635 L .43479 .44708 L F
.453 .878 .918 r
.6142 .35017 m .6133 .34991 L .61156 .35112 L F
.454 .883 .893 r
.61156 .35112 m .6133 .34991 L .60797 .35121 L F
.492 .221 .431 r
.52094 .436 m .52054 .43337 L .51742 .43617 L F
.835 .664 .669 r
.52094 .436 m .52288 .43243 L .52054 .43337 L F
.875 .884 .838 r
.40142 .48756 m .40577 .48555 L .40365 .48636 L F
.114 .334 .803 r
.40615 .48342 m .40577 .48555 L .40419 .48208 L F
.844 .999 .807 r
.40365 .48636 m .40577 .48555 L .40615 .48342 L F
.84 .793 .807 r
.57568 .41664 m .57832 .41368 L .57602 .41219 L F
.832 .796 .818 r
.57602 .41219 m .57832 .41368 L .58051 .41047 L F
.77 .473 .483 r
.4248 .46313 m .42776 .46528 L .4267 .46147 L F
.4248 .46313 m .42388 .4652 L .42776 .46528 L F
.667 .863 .473 r
.42954 .57064 m .42754 .57363 L .42746 .57356 L F
.42954 .57064 m .42746 .57356 L .4293 .57212 L F
.42954 .57064 m .4293 .57212 L .42938 .56939 L F
.733 .405 .425 r
.4293 .57212 m .43324 .56963 L .42938 .56939 L F
.232 0 .034 r
.42938 .56939 m .43104 .57067 L .43095 .57074 L F
.42938 .56939 m .43095 .57074 L .4293 .57212 L F
0 0 .374 r
.42763 .56701 m .42846 .5686 L .42938 .56939 L F
.42846 .5686 m .42954 .57064 L .42938 .56939 L F
.928 .852 .747 r
.34438 .53988 m .34646 .54109 L .34694 .5393 L F
.794 .982 .71 r
.34406 .54278 m .34646 .54109 L .34438 .53988 L F
.34406 .54278 m .34331 .54483 L .34646 .54109 L F
.593 .402 .592 r
.34646 .54109 m .34331 .54483 L .34648 .54378 L F
.37 .226 .552 r
.34648 .54378 m .34848 .5431 L .34646 .54109 L F
.778 .558 .602 r
.34848 .5431 m .34438 .53988 L .34646 .54109 L F
.839 .915 .886 r
.301 .58075 m .30445 .58131 L .30593 .57819 L F
.138 .666 .871 r
.61448 .3578 m .61306 .35831 L .61126 .35789 L F
.61448 .3578 m .61622 .35839 L .61306 .35831 L F
.534 .553 .821 r
.6164 .36082 m .61306 .35831 L .61622 .35839 L F
.843 .766 .777 r
.6263 .41167 m .63084 .40989 L .63018 .40904 L F
.6263 .41167 m .62862 .41348 L .63084 .40989 L F
.788 .988 .89 r
.63084 .40989 m .63199 .40736 L .63018 .40904 L F
.63084 .40989 m .63419 .4072 L .63199 .40736 L F
.831 .998 .78 r
.56254 .46926 m .5605 .47017 L .55982 .47247 L F
.831 .973 .665 r
.55982 .47247 m .5605 .47017 L .55812 .47365 L F
.698 .729 .874 r
.70873 .28183 m .7059 .28274 L .70441 .27892 L F
.573 .318 .492 r
.70873 .28183 m .70899 .28455 L .7059 .28274 L F
.861 .79 .781 r
.59333 .43638 m .58864 .44091 L .59126 .43728 L F
.924 .716 .603 r
.59165 .43792 m .59419 .4366 L .59173 .43717 L F
.59134 .43741 m .59173 .43717 L .59126 .43728 L F
.59165 .43792 m .59173 .43717 L .59134 .43741 L F
.896 .983 .713 r
.59566 .43328 m .59412 .43567 L .59361 .43428 L F
.59412 .43567 m .5933 .43694 L .5934 .43612 L F
.59412 .43567 m .5934 .43612 L .59361 .43428 L F
.184 .346 .793 r
.59566 .43328 m .5982 .43486 L .59694 .4315 L F
.59694 .4315 m .5982 .43486 L .59566 .43328 L F
.46 .888 .876 r
.43743 .44635 m .43992 .44528 L .44096 .4454 L F
.546 .927 .904 r
.44228 .44397 m .44448 .44389 L .44096 .4454 L F
.553 .932 .878 r
.43992 .44528 m .44228 .44397 L .44096 .4454 L F
0 0 0 r
.51221 .43458 m .51575 .43177 L .51464 .43333 L F
.386 .833 .721 r
.51216 .43444 m .51221 .43458 L .51464 .43333 L F
.51028 .43528 m .51221 .43458 L .51216 .43444 L F
.638 .863 .492 r
.51221 .43458 m .511 .43649 L .51229 .43476 L F
.51221 .43458 m .51229 .43476 L .51353 .43308 L F
0 0 0 r
.51221 .43458 m .51353 .43308 L .51575 .43177 L F
.288 .214 .597 r
.3237 .53009 m .32357 .53354 L .32571 .52934 L F
.549 .805 .993 r
.40812 .50659 m .40743 .50853 L .40569 .50714 L F
.40812 .50659 m .40743 .50853 L .40569 .50714 L F
.668 .128 0 r
.40602 .50943 m .40743 .50853 L .40812 .50659 L F
.40602 .50943 m .40978 .51055 L .40743 .50853 L F
0 .269 .776 r
.42041 .52784 m .42271 .52964 L .42258 .53107 L F
.928 .638 .473 r
.42271 .52964 m .42508 .53335 L .42258 .53107 L F
.239 .602 .952 r
.56839 .37788 m .5664 .3789 L .56463 .37712 L F
.788 .414 .348 r
.57768 .42166 m .57952 .41956 L .5755 .41877 L F
.865 .529 .414 r
.57768 .42166 m .5807 .42286 L .57952 .41956 L F
.051 0 0 r
.69518 .29767 m .69868 .29468 L .69581 .29464 L F
.209 0 .16 r
.37862 .49061 m .37904 .48897 L .37614 .4917 L F
.495 .116 .25 r
.38126 .49053 m .37904 .48897 L .37862 .49061 L F
.684 .914 .582 r
.38198 .48531 m .37904 .48897 L .38171 .48872 L F
.481 .124 .283 r
.38126 .49053 m .38171 .48872 L .37904 .48897 L F
0 0 .464 r
.4013 .45851 m .40217 .45975 L .4008 .45742 L F
.527 .794 .994 r
.40217 .45975 m .40148 .45755 L .4008 .45742 L F
.617 .294 .401 r
.40148 .45755 m .4002 .45898 L .4008 .45742 L F
.4002 .45898 m .3997 .45954 L .4008 .45742 L F
.907 .818 .348 r
.40139 .45589 m .4008 .45742 L .40142 .45508 L F
.4013 .45851 m .4008 .45742 L .40139 .45589 L F
.453 .086 .251 r
.27827 .59509 m .2759 .59356 L .27818 .59293 L F
.27827 .59509 m .27492 .59583 L .2759 .59356 L F
.28 0 .16 r
.27827 .59509 m .27402 .59803 L .27486 .59585 L F
.27827 .59509 m .2771 .59733 L .27402 .59803 L F
.526 .05 .07 r
.27512 .59585 m .27667 .59701 L .27732 .59509 L F
.27667 .59701 m .2771 .59733 L .2771 .5973 L F
.27667 .59701 m .2771 .5973 L .27732 .59509 L F
.453 .086 .251 r
.27492 .59583 m .27486 .59585 L .27488 .59581 L F
.27492 .59583 m .27488 .59581 L .2759 .59356 L F
.443 .846 .973 r
.27681 .5933 m .27654 .59266 L .2759 .59356 L F
.499 .363 .626 r
.27654 .59266 m .27512 .59585 L .27732 .59509 L F
.27614 .59139 m .2758 .59286 L .27654 .59266 L F
.443 .846 .973 r
.27654 .59266 m .27626 .59273 L .2759 .59356 L F
.499 .363 .626 r
.2758 .59286 m .27512 .59585 L .27654 .59266 L F
.443 .846 .973 r
.27654 .59266 m .27642 .59237 L .27626 .59273 L F
.499 .363 .626 r
.27614 .59139 m .27654 .59266 L .27642 .59237 L F
.27654 .59266 m .27732 .59509 L .27642 .59237 L F
.443 .846 .973 r
.27818 .59293 m .27642 .59237 L .27681 .5933 L F
0 0 0 r
.39251 .48551 m .38841 .48825 L .39192 .48816 L F
.492 .262 .494 r
.39192 .48816 m .39401 .48724 L .39251 .48551 L F
.406 .804 .985 r
.41454 .54415 m .41857 .5444 L .41802 .54382 L F
.653 .207 .179 r
.41726 .54644 m .41857 .5444 L .41454 .54415 L F
.985 .844 .461 r
.41752 .54411 m .41857 .5444 L .41726 .54644 L F
.41788 .54432 m .41726 .54644 L .41793 .54473 L F
.128 0 0 r
.41454 .54415 m .41716 .5439 L .41527 .54484 L F
.41716 .5439 m .41802 .54382 L .41741 .54405 L F
.41716 .5439 m .41741 .54405 L .41527 .54484 L F
.41802 .54382 m .41778 .54396 L .41527 .54484 L F
.653 .207 .179 r
.41726 .54644 m .41454 .54415 L .41431 .54638 L F
.972 .879 .683 r
.41527 .54484 m .41778 .54396 L .41767 .54273 L F
.985 .844 .461 r
.4176 .54337 m .41774 .54352 L .41752 .54411 L F
.41774 .54352 m .41802 .54382 L .41778 .54396 L F
.41774 .54352 m .41778 .54396 L .41752 .54411 L F
.41802 .54382 m .41857 .5444 L .41752 .54411 L F
.128 0 0 r
.41802 .54382 m .41824 .5438 L .41778 .54396 L F
.985 .844 .461 r
.41767 .54273 m .41857 .5444 L .4176 .54337 L F
.972 .879 .683 r
.41778 .54396 m .41824 .5438 L .41767 .54273 L F
.985 .844 .461 r
.41767 .54273 m .41752 .54411 L .41788 .54432 L F
.41752 .54411 m .41726 .54644 L .41788 .54432 L F
.406 .804 .985 r
.41802 .54382 m .41857 .5444 L .41824 .5438 L F
.633 .248 0 r
.41824 .5438 m .41857 .5444 L .41767 .54273 L F
.812 .755 .799 r
.60136 .44566 m .60488 .44673 L .60369 .44242 L F
.644 .091 0 r
.60364 .44743 m .60488 .44673 L .60136 .44566 L F
.686 .8 .935 r
.55778 .43572 m .56202 .43664 L .56082 .43483 L F
0 0 .439 r
.55947 .43289 m .56202 .43664 L .56082 .43483 L F
.607 .183 0 r
.56082 .43483 m .56202 .43664 L .5629 .43803 L F
.808 .578 .589 r
.56269 .43788 m .56379 .43993 L .5629 .43803 L F
.993 .744 .406 r
.56379 .43993 m .56288 .44163 L .5629 .43803 L F
.724 .592 .018 r
.5629 .43803 m .56285 .4387 L .56331 .43833 L F
.5629 .43803 m .56331 .43833 L .56373 .438 L F
.808 .578 .589 r
.56202 .43664 m .56269 .43788 L .5629 .43803 L F
.789 .746 .813 r
.51691 .45976 m .51495 .46179 L .51934 .45934 L F
.291 .641 .966 r
.51836 .45815 m .51934 .45934 L .52033 .45757 L F
.52033 .45757 m .51934 .45934 L .51836 .45815 L F
.583 .339 .512 r
.34013 .59019 m .33985 .59312 L .33707 .59342 L F
.687 .648 .806 r
.34521 .5869 m .34013 .59019 L .3386 .58664 L F
.657 .403 .524 r
.3411 .5922 m .33985 .59312 L .34013 .59019 L F
.94 .571 .25 r
.52098 .38889 m .52174 .39053 L .51957 .38893 L F
.52098 .38889 m .52174 .39053 L .51957 .38893 L F
.921 .972 .771 r
.50871 .43984 m .511 .43649 L .509 .43656 L F
.688 .98 .881 r
.509 .43656 m .511 .43649 L .51221 .43458 L F
.571 .399 .61 r
.52217 .47239 m .52443 .47261 L .52538 .46813 L F
.488 .797 .999 r
.52679 .48407 m .52767 .48495 L .52503 .48548 L F
.756 .897 .5 r
.52495 .50014 m .52458 .50139 L .52789 .49857 L F
.8 .991 .88 r
.52851 .49637 m .52789 .49857 L .53118 .49581 L F
.824 1 .815 r
.52851 .49637 m .52495 .50014 L .52789 .49857 L F
.491 .57 .863 r
.233 .60297 m .23439 .60658 L .23483 .60549 L F
0 0 .171 r
.55935 .39048 m .5599 .39107 L .56141 .38971 L F
.55935 .39048 m .55902 .39332 L .5599 .39107 L F
.904 .924 .82 r
.38451 .59614 m .38855 .59361 L .38735 .59281 L F
.38451 .59614 m .386 .59707 L .38855 .59361 L F
.956 .626 .227 r
.38679 .58973 m .38735 .59281 L .38855 .59361 L F
.568 .859 .997 r
.61967 .35699 m .61994 .35798 L .62252 .35702 L F
.834 .453 .33 r
.43191 .55923 m .43336 .55736 L .43232 .55564 L F
.43191 .55923 m .43472 .56002 L .43336 .55736 L F
.8 .868 .428 r
.40287 .50424 m .40159 .50672 L .40139 .50814 L F
.151 .487 .902 r
.40159 .50672 m .40331 .50861 L .40139 .50814 L F
.288 .056 .377 r
.23936 .58371 m .24129 .58388 L .24342 .58675 L F
.23936 .58371 m .23885 .58631 L .24129 .58388 L F
.691 .519 .65 r
.55286 .42866 m .55646 .42625 L .55242 .42691 L F
.918 .757 .666 r
.56233 .38343 m .55962 .38572 L .5598 .38303 L F
.56233 .38343 m .56166 .38715 L .55962 .38572 L F
.959 .947 .681 r
.60085 .41488 m .60268 .41418 L .60292 .41138 L F
.688 .655 .811 r
.61202 .39797 m .61484 .39695 L .61319 .39385 L F
0 0 0 r
.61328 .39772 m .61484 .39695 L .61202 .39797 L F
.816 .805 .841 r
.43596 .45594 m .44016 .45601 L .43863 .45466 L F
.765 .709 .8 r
.46662 .58821 m .46875 .58693 L .46488 .58583 L F
.592 .826 .988 r
.44016 .45601 m .4427 .45488 L .43863 .45466 L F
.44016 .45601 m .4427 .45488 L .43863 .45466 L F
.832 .794 .815 r
.50181 .44622 m .50356 .44937 L .50575 .44584 L F
.529 .388 .633 r
.50356 .44937 m .50617 .44852 L .50575 .44584 L F
.77 .951 .625 r
.55363 .40257 m .55133 .40629 L .55411 .40322 L F
.946 .603 .198 r
.58941 .37741 m .5895 .38026 L .59102 .38138 L F
.424 .219 .495 r
.59102 .38138 m .59352 .3828 L .59392 .37993 L F
0 .229 .646 r
.59195 .38177 m .59102 .38138 L .5895 .38026 L F
.59195 .38177 m .59352 .3828 L .59102 .38138 L F
.57 .893 .631 r
.46942 .59262 m .4691 .59302 L .47095 .59137 L F
.479 .886 .94 r
.46853 .59374 m .4691 .59302 L .4659 .59407 L F
.041 0 0 r
.4659 .59407 m .4691 .59302 L .46727 .59437 L F
.57 .893 .631 r
.46727 .59437 m .4691 .59302 L .46942 .59262 L F
.479 .886 .94 r
.47023 .59352 m .4691 .59302 L .46853 .59374 L F
.766 .978 .915 r
.47129 .59195 m .47095 .59137 L .47023 .59352 L F
.796 .996 .862 r
.47095 .59137 m .4691 .59302 L .47023 .59352 L F
.868 .469 .277 r
.34875 .50953 m .35025 .50809 L .34811 .50749 L F
.34875 .50953 m .35193 .51115 L .35025 .50809 L F
.976 .916 .668 r
.38451 .59614 m .38427 .60034 L .386 .59707 L F
.33 0 .031 r
.43629 .59879 m .43672 .59775 L .43882 .59835 L F
.74 .575 .67 r
.34633 .55743 m .35033 .56069 L .34881 .55682 L F
.34633 .55743 m .34715 .56085 L .35033 .56069 L F
.943 .826 .699 r
.69979 .33955 m .70099 .34095 L .70028 .33735 L F
.974 .901 .683 r
.6985 .34322 m .70099 .34095 L .69979 .33955 L F
.6985 .34322 m .69959 .34472 L .70099 .34095 L F
.875 .864 .416 r
.42754 .57363 m .42645 .57537 L .42746 .57356 L F
.42754 .57363 m .4264 .5775 L .42645 .57537 L F
0 .306 .76 r
.60324 .42107 m .60463 .42131 L .6019 .41862 L F
.60324 .42107 m .60585 .4226 L .60463 .42131 L F
.426 .236 .518 r
.36951 .47583 m .37191 .4777 L .37185 .47492 L F
.39 .524 .871 r
.30672 .64634 m .3086 .64962 L .30975 .64751 L F
.453 .602 .909 r
.3086 .64962 m .31091 .64928 L .30975 .64751 L F
.373 .8 .97 r
.57706 .36749 m .57987 .36705 L .58107 .36772 L F
.515 .863 .991 r
.57987 .36705 m .58423 .36663 L .58107 .36772 L F
.921 .836 .743 r
.56783 .46491 m .569 .46581 L .56947 .46122 L F
0 0 0 r
.65359 .39485 m .65475 .39339 L .65662 .39191 L F
.675 .248 .225 r
.56509 .44977 m .56131 .45088 L .55999 .44926 L F
.56509 .44977 m .56323 .45157 L .56131 .45088 L F
.538 .082 .117 r
.56753 .45132 m .56509 .44977 L .56749 .44845 L F
.56753 .45132 m .56323 .45157 L .56509 .44977 L F
.763 .828 .903 r
.42837 .59076 m .43156 .59188 L .43119 .58963 L F
.471 .077 .21 r
.42847 .59359 m .43119 .59353 L .43156 .59188 L F
.12 .158 .627 r
.43156 .59188 m .43301 .58906 L .43119 .58963 L F
.43156 .59188 m .43376 .592 L .43301 .58906 L F
.128 0 .115 r
.43156 .59188 m .43119 .59353 L .43376 .592 L F
.652 .506 .672 r
.36166 .59397 m .36158 .59661 L .3642 .5933 L F
.3642 .5933 m .36158 .59661 L .36166 .59397 L F
.36166 .59397 m .36158 .59661 L .3642 .5933 L F
.753 .588 .672 r
.4254 .56369 m .42287 .56673 L .42267 .5638 L F
.4254 .56369 m .42763 .56701 L .42287 .56673 L F
.589 .302 .449 r
.42763 .56701 m .4232 .5703 L .42287 .56673 L F
.42763 .56701 m .42811 .56998 L .4232 .5703 L F
.512 .251 .455 r
.42763 .56701 m .42938 .56939 L .42811 .56998 L F
.028 0 0 r
.54218 .41211 m .53904 .41305 L .53976 .41252 L F
.508 .516 .8 r
.55647 .3966 m .55747 .39983 L .55999 .39931 L F
.826 .577 .564 r
.42938 .56939 m .43319 .56749 L .43119 .56679 L F
.42938 .56939 m .43324 .56963 L .43319 .56749 L F
0 0 0 r
.30901 .57381 m .30564 .57747 L .30812 .57626 L F
.582 .246 .366 r
.299 .52799 m .30128 .53006 L .3023 .52819 L F
.299 .52799 m .30128 .53006 L .3023 .52819 L F
.424 .195 .461 r
.31172 .57058 m .30901 .57381 L .31169 .57355 L F
.855 .854 .84 r
.30812 .57626 m .31169 .57355 L .30901 .57381 L F
.318 .758 .965 r
.29049 .50781 m .29305 .50758 L .29471 .50835 L F
.29049 .50781 m .29305 .50758 L .29471 .50835 L F
.611 .9 .987 r
.29538 .50652 m .29305 .50758 L .29471 .50835 L F
.29538 .50652 m .29305 .50758 L .29471 .50835 L F
.314 .636 .964 r
.58646 .36919 m .58515 .37099 L .58377 .36945 L F
.479 .051 .148 r
.58515 .37099 m .58838 .37141 L .58849 .37092 L F
.314 .636 .964 r
.58646 .36919 m .58838 .37141 L .58515 .37099 L F
.775 .923 .934 r
.48611 .4189 m .48271 .41948 L .4847 .41756 L F
.736 .923 .954 r
.48799 .41589 m .48611 .4189 L .4847 .41756 L F
.48799 .41589 m .48951 .41691 L .48611 .4189 L F
.669 .489 .632 r
.31169 .57355 m .31412 .56991 L .31172 .57058 L F
.361 .804 .956 r
.32413 .65188 m .32619 .65247 L .32844 .65204 L F
.835 .804 .822 r
.35992 .63878 m .36086 .63587 L .35902 .63859 L F
.35992 .63878 m .36317 .6351 L .36086 .63587 L F
.908 .96 .812 r
.72932 .31197 m .72646 .31357 L .72746 .31494 L F
.964 .69 .26 r
.72654 .31605 m .72746 .31494 L .72646 .31357 L F
.72654 .31605 m .72755 .31746 L .72746 .31494 L F
.759 .995 .849 r
.31109 .63598 m .31008 .63766 L .30822 .63844 L F
.428 0 .107 r
.544 .40292 m .54679 .40283 L .54682 .40155 L F
.207 0 0 r
.54679 .40283 m .55085 .39969 L .54682 .40155 L F
.84 .793 .807 r
.57568 .41664 m .57602 .41219 L .57354 .41559 L F
.84 .543 .486 r
.57301 .41795 m .57568 .41664 L .57354 .41559 L F
.57301 .41795 m .5755 .41877 L .57568 .41664 L F
.75 .608 .701 r
.35449 .538 m .35651 .54098 L .35578 .53791 L F
.35449 .538 m .35199 .54126 L .35651 .54098 L F
.535 .054 .062 r
.35233 .54124 m .35312 .54214 L .35651 .54098 L F
.35199 .54126 m .35223 .54145 L .35233 .54124 L F
.35223 .54145 m .35312 .54214 L .35233 .54124 L F
.15 .216 .678 r
.35349 .53889 m .35199 .54126 L .35176 .53734 L F
.731 .988 .886 r
.35349 .53889 m .35165 .54065 L .35199 .54126 L F
.535 .054 .062 r
.35312 .54214 m .35514 .54233 L .35651 .54098 L F
.35312 .54214 m .35405 .54286 L .35514 .54233 L F
.35405 .54286 m .35409 .5429 L .35412 .54288 L F
.35405 .54286 m .35412 .54288 L .35514 .54233 L F
.486 .418 .706 r
.35177 .54399 m .35463 .54307 L .35366 .54276 L F
.535 .054 .062 r
.35409 .5429 m .35435 .5431 L .35445 .54301 L F
.35409 .5429 m .35445 .54301 L .35514 .54233 L F
.486 .418 .706 r
.35409 .5429 m .35463 .54307 L .35455 .54218 L F
.264 .146 .525 r
.35455 .54218 m .35435 .5431 L .35409 .5429 L F
.35455 .54218 m .35409 .5429 L .35199 .54126 L F
.486 .418 .706 r
.35366 .54276 m .35409 .5429 L .35455 .54218 L F
.264 .146 .525 r
.35455 .54218 m .35199 .54126 L .35191 .54223 L F
.35455 .54218 m .35191 .54223 L .35177 .54399 L F
.644 .786 .333 r
.35241 .54105 m .35192 .54203 L .35165 .54065 L F
.35349 .53889 m .35241 .54105 L .35165 .54065 L F
.35349 .53889 m .35348 .53891 L .35185 .54216 L F
.35348 .53891 m .35233 .54114 L .35188 .5421 L F
.35348 .53891 m .35188 .5421 L .35185 .54216 L F
.763 .748 .839 r
.3518 .54227 m .34848 .5431 L .35165 .54065 L F
.511 .466 .743 r
.35165 .54065 m .35171 .54223 L .35181 .54223 L F
.644 .786 .333 r
.35192 .54203 m .3518 .54227 L .35178 .54201 L F
.35192 .54203 m .35185 .54216 L .3518 .54227 L F
.511 .466 .743 r
.35241 .54105 m .35188 .5421 L .35455 .54218 L F
.35188 .5421 m .35187 .54223 L .35455 .54218 L F
.35212 .54234 m .35177 .54399 L .35366 .54276 L F
.107 0 0 r
.35185 .5424 m .35158 .54246 L .3518 .54227 L F
.35185 .5424 m .3518 .54227 L .35188 .5421 L F
.511 .466 .743 r
.35171 .54223 m .35171 .54243 L .35212 .54234 L F
.35171 .54243 m .35177 .54399 L .35212 .54234 L F
.722 .594 .713 r
.34848 .5431 m .35083 .54987 L .35177 .54399 L F
.253 0 0 r
.35155 .54249 m .34848 .5431 L .3518 .54227 L F
.706 .622 .761 r
.34848 .5431 m .34923 .5433 L .34962 .54287 L F
.34923 .5433 m .35177 .54399 L .35171 .54243 L F
.107 0 0 r
.35159 .54247 m .35155 .54249 L .35158 .54246 L F
.706 .622 .761 r
.34923 .5433 m .35171 .54243 L .35165 .54065 L F
.253 0 0 r
.34943 .54432 m .34848 .5431 L .35155 .54249 L F
.706 .622 .761 r
.34848 .5431 m .34962 .54287 L .35165 .54065 L F
.107 0 0 r
.35224 .5435 m .34943 .54432 L .35155 .54249 L F
.35224 .5435 m .35155 .54249 L .35159 .54247 L F
.35224 .5435 m .35158 .54246 L .35185 .5424 L F
.511 .466 .743 r
.35171 .54223 m .35366 .54276 L .35455 .54218 L F
.107 0 0 r
.35224 .5435 m .35185 .5424 L .35233 .54114 L F
.35185 .5424 m .35188 .5421 L .35233 .54114 L F
.511 .466 .743 r
.35188 .5421 m .35181 .54223 L .35187 .54223 L F
.644 .786 .333 r
.35192 .54203 m .35178 .54201 L .35165 .54065 L F
.511 .466 .743 r
.35165 .54065 m .35181 .54223 L .35241 .54105 L F
.591 .032 0 r
.35653 .54515 m .35485 .54566 L .35177 .54399 L F
.35705 .54528 m .35485 .54566 L .35653 .54515 L F
.897 .986 .732 r
.35485 .54566 m .35319 .54636 L .35333 .54612 L F
.486 .418 .706 r
.35177 .54399 m .35485 .54566 L .35463 .54307 L F
.897 .986 .732 r
.35485 .54566 m .35333 .54612 L .35463 .54391 L F
.644 .786 .333 r
.35349 .53889 m .35185 .54216 L .35192 .54203 L F
.575 .545 .784 r
.35578 .53791 m .35651 .54098 L .35892 .54016 L F
0 0 0 r
.35651 .54098 m .35801 .54002 L .35892 .54016 L F
.735 .551 0 r
.35459 .54303 m .35485 .54566 L .35463 .54391 L F
.35455 .54218 m .35461 .54288 L .35461 .54288 L F
0 0 0 r
.35651 .54098 m .35462 .54284 L .35801 .54002 L F
.35462 .54284 m .35461 .54288 L .35801 .54002 L F
.752 .61 .701 r
.35801 .54002 m .35461 .54288 L .35455 .54218 L F
0 0 0 r
.35462 .54284 m .35435 .5431 L .35461 .54288 L F
.752 .61 .701 r
.35461 .54288 m .35435 .5431 L .35455 .54218 L F
.735 .551 0 r
.35455 .54218 m .35461 .54288 L .35459 .54303 L F
.35461 .54288 m .35485 .54566 L .35459 .54303 L F
.413 .84 .688 r
.47468 .42666 m .4706 .42879 L .47351 .42615 L F
.724 .972 .727 r
.47743 .4239 m .47468 .42666 L .47575 .42467 L F
.678 .959 .944 r
.47575 .42467 m .47468 .42666 L .47351 .42615 L F
0 .18 .695 r
.35719 .61566 m .35345 .61208 L .35918 .61307 L F
0 0 0 r
.35719 .61566 m .35918 .61307 L .3604 .61208 L F
.813 .985 .714 r
.34752 .54756 m .3449 .55088 L .34562 .54863 L F
.035 0 .131 r
.3476 .54843 m .3449 .55088 L .34752 .54756 L F
.415 .282 .59 r
.3476 .54843 m .3473 .5528 L .3449 .55088 L F
0 .104 .576 r
.3449 .55088 m .3459 .55158 L .34562 .54863 L F
.3449 .55088 m .3473 .5528 L .3459 .55158 L F
.726 .775 .28 r
.56069 .40346 m .56011 .40474 L .55985 .40226 L F
.56069 .40346 m .55985 .40595 L .56011 .40474 L F
1 .821 .518 r
.55999 .39931 m .56069 .40346 L .55985 .40226 L F
0 0 0 r
.52493 .4098 m .52336 .40986 L .52153 .40976 L F
.52493 .4098 m .52278 .41337 L .52441 .41109 L F
.52493 .4098 m .52441 .41109 L .52336 .40986 L F
.963 .878 .485 r
.69843 .36335 m .69912 .36107 L .69788 .36225 L F
.989 .768 .511 r
.69912 .36107 m .69791 .35699 L .69826 .3595 L F
.991 .816 .436 r
.69788 .36225 m .69912 .36107 L .69826 .3595 L F
.905 .929 .551 r
.55544 .45284 m .55402 .45422 L .55401 .45152 L F
.714 .828 .936 r
.55889 .45063 m .55544 .45284 L .55533 .45173 L F
.794 .882 .91 r
.55533 .45173 m .55544 .45284 L .55401 .45152 L F
.437 .499 .825 r
.2947 .58034 m .29919 .58233 L .2983 .58158 L F
0 .11 .591 r
.60089 .42514 m .60145 .42582 L .59897 .42363 L F
.653 .241 0 r
.60305 .42871 m .60145 .42582 L .60089 .42514 L F
.983 .884 .532 r
.47484 .58912 m .47572 .58698 L .47403 .58879 L F
0 0 0 r
.47572 .58698 m .47705 .58259 L .47599 .58504 L F
.845 .934 .558 r
.47572 .58698 m .47599 .58504 L .47403 .58879 L F
.221 0 .244 r
.52443 .47261 m .52795 .46898 L .52538 .46813 L F
.548 .571 .829 r
.44421 .45923 m .44674 .45854 L .44528 .4549 L F
.521 .334 .569 r
.31367 .62643 m .31624 .62578 L .31608 .62293 L F
0 0 0 r
.31848 .61926 m .31608 .62293 L .31776 .62142 L F
.591 .552 .779 r
.31624 .62578 m .31776 .62142 L .31608 .62293 L F
.262 .49 .888 r
.3148 .63292 m .31667 .63364 L .31656 .63063 L F
.409 .556 .89 r
.3148 .63292 m .31649 .6341 L .31667 .63364 L F
.332 0 0 r
.31667 .63364 m .31808 .63055 L .31656 .63063 L F
.31667 .63364 m .31615 .63425 L .31729 .63205 L F
.31667 .63364 m .31729 .63205 L .31808 .63055 L F
.409 .556 .89 r
.31649 .6341 m .319 .63584 L .31667 .63364 L F
.276 .154 .527 r
.33183 .5169 m .33264 .51774 L .33297 .51478 L F
.351 0 0 r
.45514 .59578 m .45285 .59658 L .4501 .59658 L F
.394 0 0 r
.45652 .59589 m .45285 .59658 L .45514 .59578 L F
.864 .706 .684 r
.6213 .37081 m .62072 .36742 L .61856 .36749 L F
.571 .054 0 r
.62425 .3712 m .62251 .37113 L .62057 .36946 L F
.864 .706 .684 r
.6213 .37081 m .61925 .36833 L .62057 .36946 L F
.888 .932 .841 r
.61937 .37099 m .6213 .37081 L .62057 .36946 L F
.571 .054 0 r
.62251 .37113 m .62007 .37102 L .62057 .36946 L F
.864 .706 .684 r
.61925 .36833 m .61856 .36749 L .62057 .36946 L F
.783 .716 .789 r
.33985 .59312 m .34054 .59705 L .33734 .59664 L F
.466 .494 .804 r
.34239 .59592 m .34054 .59705 L .33985 .59312 L F
.392 .324 .661 r
.34239 .59592 m .34139 .59963 L .34054 .59705 L F
.051 0 0 r
.66431 .37415 m .66064 .37654 L .6632 .37543 L F
0 0 0 r
.66602 .37217 m .66698 .37086 L .66431 .37415 L F
.535 .815 .463 r
.66602 .37217 m .66431 .37415 L .6632 .37543 L F
.912 .639 .143 r
.27991 .6161 m .28062 .61914 L .28017 .61932 L F
0 .046 .591 r
.28157 .61746 m .28062 .61914 L .27991 .6161 L F
.67 .911 .584 r
.28017 .61932 m .28062 .61914 L .28157 .61746 L F
0 0 .435 r
.26177 .52562 m .26145 .52796 L .26086 .52473 L F
.806 .98 .897 r
.26177 .52562 m .26013 .52756 L .26145 .52796 L F
.543 .781 .986 r
.31112 .54363 m .31533 .54445 L .31321 .54546 L F
.665 .197 .13 r
.34331 .54483 m .3381 .54541 L .33922 .54422 L F
.34331 .54483 m .3427 .54643 L .3381 .54541 L F
0 0 0 r
.344 .54475 m .34331 .54483 L .34406 .54278 L F
.062 0 .304 r
.46656 .53379 m .46848 .53407 L .46648 .53135 L F
.324 .06 .351 r
.46416 .53404 m .46656 .53379 L .46648 .53135 L F
.921 .97 .776 r
.36595 .63248 m .36835 .62899 L .36735 .62839 L F
.852 .953 .879 r
.36835 .62899 m .36994 .62516 L .36735 .62839 L F
.36835 .62899 m .37136 .62603 L .36994 .62516 L F
.595 .115 .085 r
.33689 .53885 m .34018 .53935 L .34207 .53769 L F
.682 .222 .155 r
.34018 .53935 m .34438 .53988 L .34207 .53769 L F
.687 .215 .124 r
.34207 .53769 m .34438 .53988 L .34694 .5393 L F
.669 .167 .043 r
.31023 .5479 m .30627 .54745 L .30738 .54749 L F
.06 0 0 r
.31224 .54659 m .30864 .54946 L .31023 .5479 L F
.398 .736 .992 r
.28306 .6427 m .28369 .64112 L .2812 .64168 L F
.28306 .6427 m .28546 .64249 L .28369 .64112 L F
.28369 .64112 m .28306 .6427 L .2812 .64168 L F
.28369 .64112 m .28546 .64249 L .28306 .6427 L F
.347 0 0 r
.35606 .55528 m .35355 .55656 L .35135 .55621 L F
0 0 0 r
.35668 .55565 m .35606 .55528 L .35765 .55468 L F
.35668 .55565 m .35355 .55656 L .35606 .55528 L F
.35818 .55447 m .35765 .55468 L .35606 .55528 L F
.935 .718 .238 r
.69791 .35699 m .69795 .35449 L .69729 .35322 L F
.879 .606 .522 r
.37255 .54098 m .37241 .54376 L .37457 .5442 L F
.878 .604 .518 r
.37241 .54376 m .37241 .54649 L .37457 .5442 L F
.853 .561 .494 r
.37457 .5442 m .37241 .54649 L .37466 .54696 L F
.936 .628 .171 r
.5856 .38702 m .58501 .38838 L .58435 .38553 L F
.5856 .38702 m .58592 .38943 L .58501 .38838 L F
.358 .827 .773 r
.36086 .63587 m .36317 .6351 L .36389 .63483 L F
.845 .94 .885 r
.36317 .6351 m .36595 .63248 L .36444 .63184 L F
.36317 .6351 m .36444 .63184 L .36389 .63483 L F
.863 .893 .856 r
.6158 .41944 m .61895 .41896 L .61844 .41638 L F
.453 .491 .808 r
.61895 .41896 m .62066 .41489 L .61844 .41638 L F
.61895 .41896 m .62211 .41891 L .62066 .41489 L F
.479 .321 .589 r
.38198 .48531 m .38453 .48741 L .38345 .4851 L F
.38198 .48531 m .38171 .48872 L .38453 .48741 L F
.593 .885 .584 r
.61856 .36749 m .6198 .36592 L .62057 .36946 L F
0 0 0 r
.5024 .52432 m .5017 .52657 L .5001 .52794 L F
.688 .738 .23 r
.49994 .52825 m .5001 .52794 L .5017 .52657 L F
.49994 .52825 m .49939 .53003 L .5001 .52794 L F
.275 .762 .676 r
.61621 .3437 m .61845 .34278 L .61988 .34218 L F
0 0 0 r
.61988 .34218 m .62108 .34182 L .6224 .34116 L F
.61988 .34218 m .61845 .34278 L .62108 .34182 L F
.977 .902 .674 r
.23459 .60062 m .233 .60297 L .23394 .5991 L F
.333 .101 .404 r
.53331 .4211 m .53116 .42005 L .53366 .41924 L F
.53331 .4211 m .5309 .42243 L .53116 .42005 L F
.432 .832 .627 r
.62246 .34591 m .62076 .34715 L .62363 .34583 L F
.62246 .34591 m .62034 .34736 L .62076 .34715 L F
.794 .982 .9 r
.34694 .5393 m .34747 .53737 L .34869 .53788 L F
.34694 .5393 m .34438 .53988 L .34747 .53737 L F
.402 .074 .291 r
.34056 .56631 m .34368 .56378 L .34097 .5638 L F
.383 0 0 r
.43964 .57194 m .43777 .57121 L .43587 .57285 L F
.756 .897 .5 r
.52495 .50014 m .52454 .50102 L .52458 .50139 L F
.908 .96 .812 r
.72932 .31197 m .72852 .31068 L .72646 .31357 L F
.936 .658 .489 r
.36963 .5371 m .36976 .53985 L .37255 .54098 L F
.914 .641 .509 r
.36921 .54241 m .37255 .54098 L .36976 .53985 L F
.36921 .54241 m .37241 .54376 L .37255 .54098 L F
.306 .773 .648 r
.47998 .42271 m .47743 .4239 L .47575 .42467 L F
.783 .74 .813 r
.40973 .50522 m .4075 .50485 L .40858 .50246 L F
.719 .261 .162 r
.40973 .50522 m .40812 .50659 L .4075 .50485 L F
.366 .501 .862 r
.41053 .50267 m .40973 .50522 L .40858 .50246 L F
.849 .963 .631 r
.41053 .50267 m .40812 .50659 L .40973 .50522 L F
.915 .565 .363 r
.40812 .50659 m .4106 .50791 L .40973 .50522 L F
.641 .751 .929 r
.47885 .44889 m .48295 .44951 L .48207 .4475 L F
.315 .541 .911 r
.48207 .4475 m .48295 .44951 L .48408 .4475 L F
.485 .755 .99 r
.48408 .4475 m .48295 .44951 L .48558 .44901 L F
.734 .75 .864 r
.33264 .51774 m .33785 .5182 L .33546 .51782 L F
.478 .85 .988 r
.3397 .51708 m .33785 .5182 L .34085 .51696 L F
.3397 .51708 m .33546 .51782 L .33785 .5182 L F
.86 .938 .872 r
.53103 .49316 m .53118 .49581 L .53257 .49362 L F
.903 .956 .821 r
.53103 .49316 m .52851 .49637 L .53118 .49581 L F
.724 .639 .764 r
.23392 .57628 m .23533 .5803 L .23695 .57534 L F
.756 .418 .411 r
.46211 .59014 m .46278 .5933 L .46162 .59268 L F
.561 .821 .994 r
.46265 .5942 m .46328 .59356 L .46278 .5933 L F
.46253 .59403 m .46278 .5933 L .46162 .59268 L F
.46265 .5942 m .46278 .5933 L .46253 .59403 L F
.288 0 .203 r
.46162 .59268 m .46246 .59132 L .46211 .59014 L F
.46246 .59132 m .46384 .58909 L .46211 .59014 L F
.46246 .59132 m .46315 .59173 L .46384 .58909 L F
0 0 .364 r
.46291 .59217 m .46288 .59277 L .46246 .59132 L F
.46288 .59277 m .46287 .59303 L .46211 .59014 L F
.46287 .59303 m .46278 .5933 L .46211 .59014 L F
.288 0 .203 r
.46162 .59268 m .46299 .59232 L .46246 .59132 L F
.46299 .59232 m .46378 .59211 L .46246 .59132 L F
0 0 .364 r
.46311 .58837 m .46291 .59217 L .46211 .59014 L F
.46291 .59217 m .46246 .59132 L .46211 .59014 L F
.561 .821 .994 r
.46328 .59356 m .46428 .59255 L .46276 .59262 L F
.46296 .59339 m .46276 .59262 L .46162 .59268 L F
.46328 .59356 m .46276 .59262 L .46296 .59339 L F
.447 .325 .621 r
.46281 .59237 m .46428 .59255 L .46378 .59211 L F
.46162 .59268 m .46276 .59262 L .46281 .59237 L F
.46276 .59262 m .46428 .59255 L .46281 .59237 L F
.994 .876 .583 r
.46281 .59237 m .46284 .59359 L .46291 .59217 L F
.46245 .59302 m .46264 .5933 L .46281 .59237 L F
0 0 .364 r
.46287 .59303 m .46284 .59359 L .46278 .5933 L F
.994 .876 .583 r
.46264 .5933 m .46284 .59359 L .46281 .59237 L F
.447 .325 .621 r
.46281 .59237 m .46428 .59255 L .46378 .59211 L F
.46162 .59268 m .46276 .59262 L .46281 .59237 L F
.46276 .59262 m .46428 .59255 L .46281 .59237 L F
.994 .876 .583 r
.46245 .59302 m .46281 .59237 L .46311 .58837 L F
.46281 .59237 m .46291 .59217 L .46294 .59158 L F
.46281 .59237 m .46294 .59158 L .46311 .58837 L F
.46071 .59042 m .46245 .59302 L .4626 .59199 L F
.46069 .59045 m .46245 .59302 L .46071 .59042 L F
.197 0 .215 r
.46126 .58923 m .46069 .59045 L .45839 .59247 L F
.569 .875 .994 r
.4591 .59481 m .46265 .5942 L .46162 .59268 L F
.319 .778 .639 r
.46035 .59418 m .4591 .59481 L .46162 .59268 L F
.903 .94 .824 r
.46035 .59418 m .4606 .59056 L .45839 .59247 L F
.4606 .59056 m .46061 .59034 L .45839 .59247 L F
.197 0 .215 r
.4606 .59056 m .46006 .5918 L .45926 .59212 L F
.903 .94 .824 r
.46035 .59418 m .46069 .59045 L .4606 .59056 L F
.197 0 .215 r
.46069 .59045 m .46067 .5905 L .4606 .59056 L F
.46067 .5905 m .46006 .5918 L .4606 .59056 L F
.46069 .59045 m .45926 .59212 L .45839 .59247 L F
.756 .418 .411 r
.46278 .5933 m .46284 .59359 L .46162 .59268 L F
.319 .778 .639 r
.46035 .59418 m .46162 .59268 L .46284 .59359 L F
.903 .94 .824 r
.46035 .59418 m .46284 .59359 L .46075 .59054 L F
.994 .876 .583 r
.46095 .59007 m .4626 .59199 L .4619 .58932 L F
.46061 .59034 m .46077 .59047 L .46095 .59007 L F
.46077 .59047 m .4626 .59199 L .46095 .59007 L F
0 0 .017 r
.46204 .59029 m .46052 .59161 L .46111 .58996 L F
.197 0 .215 r
.46145 .58903 m .46082 .59017 L .46126 .58923 L F
.994 .876 .583 r
.46061 .59034 m .46082 .59017 L .46145 .58903 L F
0 0 .223 r
.4633 .58537 m .46211 .59014 L .46088 .58696 L F
.4633 .58537 m .46311 .58837 L .46211 .59014 L F
.994 .876 .583 r
.46082 .59017 m .46311 .58837 L .46145 .58903 L F
.197 0 .215 r
.46145 .58903 m .46006 .5918 L .46082 .59017 L F
0 0 .017 r
.46156 .58926 m .46111 .58996 L .46145 .58903 L F
.46204 .59029 m .46111 .58996 L .46156 .58926 L F
.903 .94 .824 r
.46067 .59066 m .46075 .59054 L .46069 .59045 L F
.46035 .59418 m .46075 .59054 L .46067 .59066 L F
.4606 .59056 m .46069 .59045 L .46061 .59034 L F
.197 0 .215 r
.46145 .58903 m .46052 .59161 L .46006 .5918 L F
.994 .876 .583 r
.46061 .59034 m .46069 .59045 L .46071 .59042 L F
.4619 .58932 m .4626 .59199 L .46311 .58837 L F
.288 0 .203 r
.46315 .59173 m .46378 .59211 L .46381 .59052 L F
.46315 .59173 m .46381 .59052 L .46384 .58909 L F
.758 .716 .813 r
.46488 .58583 m .46384 .58909 L .4655 .58818 L F
0 0 .136 r
.46384 .58909 m .46378 .59211 L .4655 .58818 L F
.812 .776 .269 r
.30385 .55021 m .30351 .54976 L .30378 .54852 L F
.261 .77 .836 r
.30605 .5497 m .30351 .54976 L .30385 .55021 L F
.736 .741 .855 r
.35211 .57041 m .34909 .57349 L .35324 .57375 L F
.854 .49 .361 r
.3489 .57496 m .35324 .57375 L .34909 .57349 L F
.3489 .57496 m .35164 .57585 L .35324 .57375 L F
.404 .409 .751 r
.34752 .54756 m .34848 .5431 L .34648 .54378 L F
.34752 .54756 m .35083 .54987 L .34848 .5431 L F
.543 .084 .113 r
.34752 .54756 m .35006 .54885 L .3476 .54843 L F
.787 .601 .649 r
.35115 .55312 m .3476 .54843 L .35006 .54885 L F
.35115 .55312 m .34766 .55283 L .3476 .54843 L F
.34766 .55283 m .3473 .5528 L .34733 .55235 L F
.34766 .55283 m .34733 .55235 L .3476 .54843 L F
.484 .503 .802 r
.34881 .55682 m .3473 .5528 L .35115 .55312 L F
.34928 .55524 m .35135 .55621 L .35007 .55255 L F
.34881 .55682 m .35012 .5565 L .34928 .55524 L F
.35012 .5565 m .35135 .55621 L .34928 .55524 L F
.41 .815 .98 r
.34562 .54863 m .35006 .54885 L .34752 .54756 L F
.509 .602 .882 r
.35211 .57041 m .35324 .57375 L .35498 .57228 L F
.401 .088 .315 r
.35164 .57585 m .35498 .57228 L .35324 .57375 L F
.908 .499 .175 r
.60053 .40162 m .60173 .40043 L .59981 .39937 L F
0 0 0 r
.60287 .40047 m .60173 .40043 L .60053 .40162 L F
.226 .742 .861 r
.60486 .4 m .60504 .40019 L .60173 .40043 L F
0 0 0 r
.60287 .40047 m .60486 .4 L .60173 .40043 L F
.597 .932 .73 r
.52174 .39053 m .52053 .39121 L .51957 .38893 L F
.15 .684 .85 r
.52053 .39121 m .52174 .39053 L .51957 .38893 L F
.903 .961 .631 r
.42645 .57537 m .4264 .5775 L .42485 .57991 L F
.743 .723 .195 r
.66785 .36621 m .66698 .37086 L .66856 .36893 L F
0 0 0 r
.66856 .36893 m .66698 .37086 L .66602 .37217 L F
.598 .238 .33 r
.33022 .58246 m .33407 .58002 L .33037 .58015 L F
.33022 .58246 m .33325 .58271 L .33407 .58002 L F
.173 0 .233 r
.33407 .58002 m .3364 .57951 L .33746 .57619 L F
.199 0 .212 r
.33325 .58271 m .3364 .57951 L .33407 .58002 L F
.333 .816 .845 r
.63617 .39105 m .63395 .3918 L .63247 .3917 L F
0 0 0 r
.52195 .41511 m .5197 .41591 L .52278 .41337 L F
.978 .756 .535 r
.51706 .41655 m .51915 .41649 L .52028 .4137 L F
.033 0 .275 r
.51931 .41649 m .51893 .4165 L .52195 .41511 L F
.978 .756 .535 r
.51915 .41649 m .51931 .41649 L .51935 .41638 L F
.51915 .41649 m .51935 .41638 L .52028 .4137 L F
0 0 0 r
.52104 .41544 m .51893 .4165 L .5197 .41591 L F
.52195 .41511 m .52006 .41598 L .52104 .41544 L F
.52006 .41598 m .51893 .4165 L .52104 .41544 L F
.457 .857 .674 r
.66599 .38604 m .66974 .3838 L .66833 .38453 L F
.418 .833 .655 r
.67181 .3824 m .66974 .3838 L .67199 .38239 L F
.418 .833 .654 r
.66833 .38453 m .66974 .3838 L .67181 .3824 L F
.386 .834 .932 r
.36735 .49596 m .36185 .49611 L .36305 .49584 L F
.833 .879 .877 r
.36881 .49413 m .36735 .49596 L .36305 .49584 L F
.998 .781 .448 r
.35404 .53103 m .35271 .53012 L .35312 .52735 L F
.898 .685 .606 r
.46656 .57389 m .46591 .57659 L .46392 .57479 L F
.855 .974 .665 r
.51568 .39689 m .51335 .4005 L .51406 .3979 L F
.567 .898 .652 r
.51568 .39689 m .51406 .3979 L .51715 .39526 L F
.59 .167 .208 r
.45918 .56521 m .46224 .56295 L .4606 .56463 L F
0 0 0 r
.65676 .32474 m .65881 .32325 L .65981 .32243 L F
.65981 .32243 m .66108 .32185 L .66253 .32134 L F
.628 .95 .76 r
.60737 .39794 m .60504 .40019 L .60486 .4 L F
.706 .745 .882 r
.50712 .45234 m .51116 .4527 L .50964 .45112 L F
.774 .996 .863 r
.63531 .40476 m .63419 .4072 L .63593 .4052 L F
.762 .987 .898 r
.63199 .40736 m .63419 .4072 L .63531 .40476 L F
.447 0 0 r
.58213 .38386 m .58274 .38442 L .58124 .38285 L F
.58213 .38386 m .58435 .38553 L .58274 .38442 L F
.949 .764 .618 r
.38546 .58587 m .38679 .58973 L .38746 .58697 L F
.985 .707 .388 r
.37185 .47492 m .3734 .47881 L .37191 .4777 L F
.37191 .4777 m .3734 .47881 L .37185 .47492 L F
.382 .337 .683 r
.46664 .53562 m .46656 .53379 L .46416 .53404 L F
.51 .642 .915 r
.34869 .53788 m .34932 .53531 L .34736 .53385 L F
.34869 .53788 m .35176 .53734 L .34932 .53531 L F
.872 .984 .834 r
.34869 .53788 m .34932 .53531 L .35176 .53734 L F
.34869 .53788 m .34747 .53737 L .34932 .53531 L F
.324 .789 .936 r
.34869 .53788 m .34747 .53737 L .35176 .53734 L F
.97 .893 .692 r
.50616 .44106 m .50871 .43984 L .50665 .43826 L F
.921 .972 .771 r
.50871 .43984 m .509 .43656 L .50665 .43826 L F
.825 .998 .781 r
.56339 .46685 m .5605 .47017 L .56254 .46926 L F
0 0 .237 r
.53015 .46243 m .53095 .46338 L .53083 .46085 L F
.53015 .46243 m .53032 .46516 L .53095 .46338 L F
.472 .499 .805 r
.35486 .56972 m .35769 .56874 L .35556 .56669 L F
.554 .035 0 r
.35556 .56669 m .35769 .56874 L .35559 .56687 L F
0 0 0 r
.35481 .56759 m .35556 .56669 L .35553 .56651 L F
.554 .035 0 r
.35556 .56669 m .35559 .56687 L .35531 .56663 L F
0 0 0 r
.35553 .56651 m .35556 .56669 L .35728 .56393 L F
.472 .499 .805 r
.35486 .56972 m .35556 .56669 L .35481 .56759 L F
.996 .802 .528 r
.58838 .37141 m .58941 .37741 L .58918 .37439 L F
.58838 .37141 m .58806 .37884 L .58941 .37741 L F
.974 .798 .377 r
.58715 .3729 m .58806 .37884 L .58838 .37141 L F
.84 .631 .086 r
.58715 .3729 m .58768 .37803 L .58806 .37884 L F
.947 .6 .203 r
.58768 .37803 m .58941 .37741 L .58806 .37884 L F
.58768 .37803 m .5895 .38026 L .58941 .37741 L F
.724 .819 .924 r
.46151 .44925 m .46277 .4517 L .46578 .44965 L F
.769 .919 .937 r
.36086 .63587 m .36389 .63483 L .35988 .63359 L F
.845 .907 .879 r
.35988 .63359 m .36389 .63483 L .36444 .63184 L F
0 .199 .718 r
.33284 .65228 m .3336 .65076 L .33107 .65253 L F
.545 .275 .457 r
.33284 .65228 m .33552 .65208 L .33517 .65453 L F
0 .199 .718 r
.33284 .65228 m .33517 .65453 L .3336 .65076 L F
.651 .459 .61 r
.28535 .58998 m .28548 .59321 L .28231 .59313 L F
.684 .332 0 r
.28561 .5881 m .28614 .58824 L .28489 .58705 L F
.731 .928 .585 r
.28614 .58824 m .28535 .58998 L .28654 .58834 L F
0 .127 .652 r
.28614 .58824 m .28729 .59217 L .28535 .58998 L F
.684 .332 0 r
.28651 .58943 m .28614 .58824 L .28561 .5881 L F
.731 .928 .585 r
.28614 .58824 m .28654 .58834 L .28769 .58676 L F
.321 .205 .561 r
.28729 .59217 m .28548 .59321 L .28535 .58998 L F
.7 .753 .893 r
.59994 .43748 m .60344 .43759 L .6022 .4364 L F
0 0 0 r
.60467 .43738 m .60344 .43759 L .60291 .43806 L F
.60467 .43738 m .60547 .43664 L .60344 .43759 L F
.715 .759 .888 r
.6022 .4364 m .60547 .43664 L .60344 .43759 L F
.5 0 0 r
.38204 .51804 m .37902 .5178 L .37784 .51731 L F
.896 .492 .23 r
.38204 .51804 m .38067 .51941 L .37902 .5178 L F
.38204 .51804 m .383 .52068 L .38067 .51941 L F
.741 .931 .951 r
.59557 .4383 m .5998 .4378 L .59994 .43748 L F
.825 .543 .512 r
.59946 .44165 m .5998 .4378 L .59557 .4383 L F
0 0 .54 r
.39851 .4936 m .39755 .49336 L .39924 .49129 L F
.39851 .4936 m .39872 .49704 L .39755 .49336 L F
0 0 0 r
.65676 .32474 m .65796 .32475 L .65881 .32325 L F
.65676 .32474 m .65597 .32638 L .65796 .32475 L F
.6 .576 .798 r
.5272 .44932 m .52366 .44601 L .52539 .44819 L F
.368 .812 .668 r
.52312 .45138 m .5272 .44932 L .52539 .44819 L F
.575 .324 .498 r
.55512 .43661 m .55778 .43572 L .55432 .43554 L F
.417 .856 .755 r
.53426 .48197 m .5301 .48372 L .53231 .48261 L F
.646 .955 .754 r
.53556 .4802 m .53743 .47945 L .53426 .48197 L F
.648 .966 .819 r
.53556 .4802 m .53426 .48197 L .53231 .48261 L F
.656 .621 .803 r
.63632 .38706 m .639 .38845 L .63903 .38632 L F
.238 .333 .759 r
.63903 .38632 m .639 .38845 L .64182 .38818 L F
.169 0 .216 r
.639 .38845 m .63966 .3898 L .64182 .38818 L F
.204 .198 .629 r
.24316 .56254 m .24128 .56544 L .24103 .56024 L F
.215 .037 .411 r
.24316 .56254 m .2406 .56612 L .24128 .56544 L F
.73 .552 .65 r
.34874 .52106 m .34438 .52112 L .34442 .51805 L F
.446 .863 .717 r
.53968 .47809 m .53743 .47945 L .53556 .4802 L F
.879 .62 .541 r
.36706 .531 m .36701 .53379 L .36931 .53425 L F
.89 .589 .47 r
.3671 .53622 m .36931 .53425 L .36701 .53379 L F
.3671 .53622 m .36963 .5371 L .36931 .53425 L F
.767 .658 .742 r
.4267 .46147 m .42776 .46528 L .43032 .46151 L F
.826 .987 .874 r
.51335 .4005 m .51054 .40084 L .51406 .3979 L F
.665 .722 .892 r
.44566 .58235 m .44439 .58617 L .4428 .58571 L F
.44566 .58235 m .44697 .58548 L .44439 .58617 L F
.794 .714 .777 r
.57849 .40924 m .57714 .40999 L .58051 .41047 L F
.832 .796 .818 r
.57602 .41219 m .58051 .41047 L .57714 .40999 L F
.168 0 0 r
.37388 .49129 m .37614 .4917 L .3724 .49099 L F
.811 .395 .256 r
.37448 .49336 m .37614 .4917 L .37388 .49129 L F
.168 0 0 r
.37388 .49129 m .37614 .4917 L .3724 .49099 L F
.563 .187 .287 r
.37739 .49381 m .37767 .4912 L .37448 .49336 L F
.498 .124 .261 r
.38029 .493 m .37862 .49061 L .37767 .4912 L F
.448 .092 .268 r
.38029 .493 m .37767 .4912 L .37739 .49381 L F
0 0 0 r
.37862 .49061 m .37448 .49336 L .37767 .4912 L F
.37862 .49061 m .37614 .4917 L .37448 .49336 L F
.869 .426 .123 r
.33928 .49924 m .34052 .49812 L .33884 .49687 L F
.33928 .49924 m .3415 .50044 L .34052 .49812 L F
.25 0 0 r
.6164 .36082 m .61617 .36238 L .61322 .36305 L F
.319 .37 .758 r
.61869 .35889 m .6164 .36082 L .61622 .35839 L F
0 0 0 r
.61869 .35889 m .61617 .36238 L .6164 .36082 L F
.988 .721 .363 r
.5842 .44865 m .58296 .44517 L .58275 .44735 L F
.966 .846 .673 r
.58132 .45115 m .5842 .44865 L .58275 .44735 L F
.58132 .45115 m .58295 .45248 L .5842 .44865 L F
.644 .948 .952 r
.34925 .64399 m .3518 .64403 L .3543 .64249 L F
.279 .313 .718 r
.51742 .43617 m .52038 .43974 L .52094 .436 L F
.51742 .43617 m .51877 .43904 L .52038 .43974 L F
.753 .858 .927 r
.60702 .37618 m .60268 .37645 L .60421 .37511 L F
.60429 .37508 m .60421 .37511 L .60425 .37507 L F
.60702 .37618 m .60421 .37511 L .60429 .37508 L F
.60702 .37618 m .60425 .37507 L .60492 .375 L F
.421 0 0 r
.60479 .37493 m .60988 .37452 L .60702 .37618 L F
.631 .491 .673 r
.60414 .37448 m .60437 .37506 L .60539 .37475 L F
.421 0 0 r
.60456 .3748 m .60509 .37477 L .60479 .37493 L F
.60509 .37477 m .60988 .37452 L .60479 .37493 L F
.60509 .37477 m .60783 .3753 L .60988 .37452 L F
.631 .491 .673 r
.60479 .37493 m .60565 .37834 L .6054 .37483 L F
.60479 .37493 m .6054 .37483 L .60523 .3748 L F
.60539 .37475 m .60565 .37834 L .60783 .3753 L F
.421 0 0 r
.60456 .3748 m .60783 .3753 L .60509 .37477 L F
.631 .491 .673 r
.60523 .3748 m .6054 .37483 L .60539 .37475 L F
.60437 .37506 m .6044 .37514 L .60479 .37493 L F
.6044 .37514 m .60565 .37834 L .60479 .37493 L F
.776 .561 .608 r
.60144 .37783 m .60565 .37834 L .60437 .37506 L F
.60425 .37507 m .60437 .37506 L .60414 .37448 L F
.179 .159 .597 r
.60414 .37448 m .60456 .3748 L .60425 .37507 L F
.60414 .37448 m .60425 .37507 L .60268 .37645 L F
.776 .561 .608 r
.60361 .37514 m .60425 .37507 L .60414 .37448 L F
.60144 .37783 m .60437 .37506 L .60361 .37514 L F
.753 .858 .927 r
.60492 .375 m .60425 .37507 L .60456 .3748 L F
.669 .611 .781 r
.58918 .37439 m .59344 .37721 L .59183 .3734 L F
0 0 .422 r
.59344 .37721 m .59455 .37241 L .59183 .3734 L F
.59344 .37721 m .59475 .37545 L .59455 .37241 L F
.96 .64 .24 r
.59344 .37721 m .59247 .37837 L .59475 .37545 L F
.59344 .37721 m .59392 .37993 L .59247 .37837 L F
.612 .779 .961 r
.57681 .35055 m .58089 .35138 L .57947 .34978 L F
.57681 .35055 m .58089 .35138 L .57947 .34978 L F
.552 .774 .981 r
.57947 .34978 m .58089 .35138 L .58208 .34915 L F
.58208 .34915 m .58089 .35138 L .57947 .34978 L F
0 0 0 r
.48512 .55865 m .48394 .56059 L .48538 .55703 L F
0 0 .326 r
.48512 .55865 m .48467 .5624 L .48394 .56059 L F
0 0 .32 r
.48467 .5624 m .4838 .56363 L .48394 .56059 L F
.942 .638 .433 r
.55985 .40595 m .55794 .4079 L .56011 .40474 L F
.55985 .40595 m .56 .40948 L .55794 .4079 L F
.85 .555 .489 r
.56296 .41 m .56 .40948 L .55985 .40595 L F
.207 0 0 r
.54679 .40283 m .54937 .40201 L .55085 .39969 L F
.729 .327 .286 r
.54937 .40201 m .55363 .40257 L .55085 .39969 L F
0 .378 .794 r
.60205 .44961 m .60601 .45184 L .60498 .45112 L F
.062 .036 .512 r
.36282 .60607 m .36276 .60866 L .36165 .60634 L F
.159 .351 .806 r
.52485 .44464 m .52366 .44601 L .52165 .4422 L F
.587 .312 .466 r
.52298 .44866 m .52539 .44819 L .52366 .44601 L F
.52375 .44701 m .52366 .44601 L .52485 .44464 L F
.709 .915 .568 r
.52165 .4422 m .51994 .44469 L .52016 .4436 L F
.587 .312 .466 r
.52298 .44866 m .52325 .44761 L .52375 .44701 L F
.52325 .44761 m .52366 .44601 L .52375 .44701 L F
.52298 .44866 m .52485 .44464 L .52179 .44582 L F
.091 0 0 r
.52179 .44582 m .52485 .44464 L .52611 .44515 L F
.52179 .44582 m .52516 .4453 L .52016 .4436 L F
.52516 .4453 m .52611 .44515 L .52543 .44498 L F
.52516 .4453 m .52543 .44498 L .52016 .4436 L F
.909 .663 .555 r
.37593 .55025 m .37816 .55157 L .37459 .54975 L F
.37593 .55025 m .37797 .55348 L .37816 .55157 L F
.729 .77 .885 r
.31535 .65263 m .31953 .65309 L .31777 .65161 L F
.667 .813 .953 r
.31953 .65309 m .32191 .65204 L .31777 .65161 L F
.698 .729 .874 r
.70873 .28183 m .70441 .27892 L .70737 .27797 L F
.013 .516 .867 r
.7074 .27768 m .71233 .27911 L .71079 .2786 L F
.681 .887 .974 r
.70949 .27836 m .70873 .28183 L .70737 .27797 L F
.71064 .27883 m .70873 .28183 L .70949 .27836 L F
.302 .547 .918 r
.7074 .27768 m .70737 .27797 L .70647 .27827 L F
.144 .191 .653 r
.70762 .2801 m .7074 .27768 L .70647 .27827 L F
.681 .887 .974 r
.70978 .28018 m .71195 .28026 L .70873 .28183 L F
.144 .191 .653 r
.70946 .28305 m .70834 .28013 L .70762 .2801 L F
.572 .341 .527 r
.7074 .27768 m .70949 .27836 L .70885 .2781 L F
.70885 .2781 m .70958 .2784 L .71233 .27911 L F
.263 .666 .967 r
.71233 .27911 m .71202 .28023 L .71089 .27873 L F
.572 .341 .527 r
.70958 .2784 m .71212 .27943 L .71233 .27911 L F
.263 .666 .967 r
.71233 .27911 m .71089 .27873 L .71079 .2786 L F
.302 .547 .918 r
.7074 .27768 m .71079 .2786 L .70949 .27836 L F
.7074 .27768 m .70949 .27836 L .70737 .27797 L F
.681 .887 .974 r
.71089 .27873 m .71202 .28023 L .71064 .27883 L F
.572 .341 .527 r
.7074 .27768 m .71212 .27943 L .70949 .27836 L F
.144 .191 .653 r
.70834 .28013 m .7074 .27768 L .70762 .2801 L F
.681 .887 .974 r
.71064 .27883 m .71202 .28023 L .71195 .28026 L F
.71064 .27883 m .71195 .28026 L .70978 .28018 L F
.71079 .2786 m .71089 .27873 L .71064 .27883 L F
.572 .341 .527 r
.71057 .27885 m .71037 .28216 L .71212 .27943 L F
.7074 .27768 m .70866 .27958 L .71057 .27885 L F
.70866 .27958 m .71037 .28216 L .71057 .27885 L F
.681 .887 .974 r
.71079 .2786 m .71064 .27883 L .70949 .27836 L F
.637 .592 .787 r
.31294 .65363 m .31234 .6545 L .31535 .65263 L F
.565 .566 .813 r
.32344 .58019 m .32437 .58275 L .32624 .57958 L F
.578 .716 .937 r
.32437 .58275 m .32816 .58338 L .32624 .57958 L F
0 .235 .745 r
.52016 .4436 m .51994 .44469 L .52179 .44582 L F
.315 .358 .748 r
.51994 .44469 m .52298 .44866 L .52179 .44582 L F
0 0 0 r
.2898 .54881 m .29046 .54893 L .29163 .54859 L F
.2898 .54881 m .2883 .55005 L .29046 .54893 L F
.306 .289 .676 r
.22789 .56443 m .23032 .56642 L .22984 .56209 L F
.156 .275 .736 r
.22895 .56619 m .23032 .56642 L .22789 .56443 L F
.993 .744 .406 r
.56379 .43993 m .56408 .44232 L .56288 .44163 L F
.707 .47 .564 r
.37052 .47111 m .37547 .47188 L .37474 .46884 L F
.44 .151 .375 r
.32344 .58019 m .32624 .57958 L .32644 .5772 L F
.61 .855 .99 r
.59704 .44562 m .59829 .44686 L .60136 .44566 L F
.997 .857 .562 r
.40112 .56065 m .39927 .5624 L .39999 .5594 L F
.867 .493 .337 r
.40147 .56296 m .39927 .5624 L .40112 .56065 L F
.849 .426 .225 r
.40112 .56065 m .40341 .56275 L .40147 .56296 L F
.538 .1 .156 r
.41585 .45817 m .41177 .45847 L .41312 .45868 L F
.984 .705 .347 r
.57048 .38164 m .57147 .3804 L .56943 .37929 L F
.57048 .38164 m .57179 .38253 L .57147 .3804 L F
.921 .97 .776 r
.36595 .63248 m .36735 .62839 L .36693 .6311 L F
.505 .862 .989 r
.36444 .63184 m .36595 .63248 L .36693 .6311 L F
.983 .72 .447 r
.33316 .59315 m .33362 .59652 L .33133 .59484 L F
.964 .92 .577 r
.33316 .59315 m .33133 .59484 L .33242 .59102 L F
.69 .535 .671 r
.33707 .59342 m .33362 .59652 L .33316 .59315 L F
.786 .712 .782 r
.53058 .40587 m .53237 .4095 L .53459 .4067 L F
.39 .169 .454 r
.53459 .4067 m .53237 .4095 L .5347 .40905 L F
.53459 .4067 m .53237 .4095 L .5347 .40905 L F
.963 .888 .709 r
.62571 .37561 m .62693 .37703 L .62881 .37398 L F
.62881 .37398 m .62693 .37703 L .62571 .37561 L F
.563 .873 .994 r
.25971 .62431 m .25992 .62578 L .25734 .62639 L F
.679 .487 .62 r
.25992 .62578 m .25875 .62888 L .25734 .62639 L F
.353 .582 .929 r
.52374 .39118 m .52662 .39162 L .5254 .39374 L F
0 0 0 r
.52578 .39371 m .5254 .39374 L .52662 .39162 L F
.52578 .39371 m .52483 .396 L .5254 .39374 L F
.741 .936 .951 r
.50154 .40784 m .50243 .40545 L .50373 .40626 L F
.50154 .40784 m .49896 .40751 L .50243 .40545 L F
.404 .492 .836 r
.71361 .28359 m .71287 .28814 L .7138 .28576 L F
.71361 .28359 m .71565 .28692 L .71287 .28814 L F
0 0 0 r
.71565 .28692 m .71247 .28931 L .71287 .28814 L F
.5024 .52432 m .50515 .5208 L .50421 .52306 L F
.50515 .5208 m .50767 .51751 L .50651 .5195 L F
.50421 .52306 m .50515 .5208 L .50651 .5195 L F
.501 .645 .921 r
.24364 .58397 m .24342 .58675 L .24129 .58388 L F
.24364 .58397 m .24651 .58603 L .24342 .58675 L F
.984 .797 .575 r
.40341 .56275 m .40158 .56601 L .40147 .56296 L F
.40341 .56275 m .4033 .56704 L .40158 .56601 L F
0 0 0 r
.36098 .56188 m .35728 .56393 L .35969 .56296 L F
.643 .908 .599 r
.36098 .56188 m .36233 .56006 L .36308 .56031 L F
.36098 .56188 m .35969 .56296 L .36233 .56006 L F
.699 .781 .915 r
.63204 .37206 m .63372 .37465 L .63637 .37307 L F
.447 0 0 r
.32571 .52934 m .32685 .5301 L .32808 .52963 L F
.283 .437 .839 r
.32625 .53113 m .32685 .5301 L .32571 .52934 L F
.32717 .53422 m .32685 .5301 L .32625 .53113 L F
.713 .63 .763 r
.33056 .52882 m .32685 .5301 L .32706 .52758 L F
.33056 .52882 m .32706 .52758 L .32922 .52754 L F
.652 .948 .715 r
.32922 .52754 m .32739 .52917 L .32685 .5301 L F
.432 0 0 r
.32571 .52934 m .32685 .5301 L .3254 .52938 L F
.32571 .52934 m .32685 .5301 L .3254 .52938 L F
.621 .549 .752 r
.32706 .52758 m .32685 .5301 L .3254 .52938 L F
.652 .948 .715 r
.32739 .52917 m .32601 .53042 L .32685 .5301 L F
.63 .076 0 r
.32685 .5301 m .32596 .53046 L .3254 .52938 L F
.652 .948 .715 r
.32601 .53042 m .32596 .53046 L .32685 .5301 L F
.447 0 0 r
.32808 .52963 m .32685 .5301 L .32994 .52986 L F
.475 .895 .887 r
.32994 .52986 m .33056 .52882 L .33217 .52964 L F
.32994 .52986 m .32685 .5301 L .33056 .52882 L F
.852 .737 .735 r
.7223 .28422 m .72356 .28829 L .72619 .28505 L F
.994 .75 .421 r
.72934 .30313 m .73061 .30457 L .73069 .30197 L F
.684 .75 .901 r
.6322 .38628 m .63632 .38706 L .63572 .38488 L F
.6322 .38628 m .63632 .38706 L .63572 .38488 L F
.32 .494 .874 r
.63774 .38496 m .63632 .38706 L .63572 .38488 L F
.63572 .38488 m .63632 .38706 L .63774 .38496 L F
.644 .091 0 r
.60364 .44743 m .60136 .44566 L .60205 .44961 L F
.291 .403 .805 r
.60205 .44961 m .60498 .45112 L .60364 .44743 L F
.923 .631 .472 r
.39142 .53117 m .38908 .53283 L .38903 .53028 L F
.892 .567 .426 r
.39142 .53117 m .39173 .53401 L .38908 .53283 L F
.946 .922 .754 r
.36994 .62516 m .37136 .62603 L .37303 .62233 L F
.773 .295 .099 r
.58789 .3936 m .58648 .39477 L .58666 .39173 L F
.58789 .3936 m .58946 .39574 L .58648 .39477 L F
.744 .857 .932 r
.24795 .57237 m .2436 .5731 L .24558 .56974 L F
0 0 .536 r
.24815 .57194 m .24795 .57237 L .24558 .56974 L F
.24815 .57194 m .24873 .57324 L .24795 .57237 L F
.603 .676 .892 r
.37669 .47779 m .38029 .47897 L .37842 .47747 L F
.976 .916 .668 r
.38451 .59614 m .38225 .60063 L .38427 .60034 L F
.996 .863 .576 r
.38225 .60063 m .38342 .60307 L .38427 .60034 L F
.508 .36 .616 r
.53601 .41554 m .53366 .41924 L .53369 .41651 L F
.901 .647 .545 r
.42471 .54149 m .42795 .54092 L .42463 .53962 L F
.42471 .54149 m .42784 .54367 L .42795 .54092 L F
.531 .906 .733 r
.67469 .31004 m .67369 .31064 L .67707 .30843 L F
.887 .879 .822 r
.3234 .56925 m .32784 .56739 L .32342 .56703 L F
.3234 .56925 m .3253 .57059 L .32784 .56739 L F
.727 .583 .693 r
.35189 .52478 m .34813 .52544 L .34874 .52106 L F
.891 .469 .094 r
.35189 .52478 m .35312 .52735 L .35108 .52578 L F
.136 0 0 r
.57288 .45579 m .57423 .45672 L .57309 .45865 L F
.57288 .45579 m .57622 .45485 L .57423 .45672 L F
.542 .604 .864 r
.31911 .63881 m .31807 .63578 L .319 .63584 L F
.267 .528 .913 r
.31667 .63364 m .319 .63584 L .31998 .63449 L F
.616 .958 .876 r
.31998 .63449 m .319 .63584 L .31807 .63578 L F
.483 .896 .801 r
.43882 .59835 m .44342 .59646 L .44155 .59766 L F
.454 0 0 r
.44342 .59646 m .4443 .59765 L .44155 .59766 L F
.44342 .59646 m .44649 .59779 L .4443 .59765 L F
.241 .489 .892 r
.25489 .53291 m .25671 .5331 L .25575 .53459 L F
.099 .292 .77 r
.25671 .5331 m .25818 .53654 L .25575 .53459 L F
.381 .321 .665 r
.25818 .53654 m .25623 .53781 L .25575 .53459 L F
.993 .874 .595 r
.59274 .40357 m .59091 .40484 L .59171 .40229 L F
.59274 .40357 m .59198 .40612 L .59091 .40484 L F
.944 .722 .572 r
.4645 .55344 m .46269 .54975 L .46304 .55151 L F
.849 .885 .865 r
.41676 .51937 m .41756 .52188 L .41913 .5199 L F
.927 .946 .604 r
.41651 .52249 m .41756 .52188 L .41676 .51937 L F
.807 .331 0 r
.41409 .52089 m .41555 .52268 L .41651 .52249 L F
.927 .946 .604 r
.41651 .52249 m .41618 .52444 L .41732 .52233 L F
0 .208 .65 r
.41753 .52512 m .41618 .52444 L .41651 .52249 L F
.807 .331 0 r
.41555 .52268 m .41753 .52512 L .41651 .52249 L F
.927 .946 .604 r
.41651 .52249 m .41732 .52233 L .41756 .52188 L F
.906 .723 .644 r
.37721 .46561 m .3747 .46604 L .37533 .46411 L F
.763 .349 .265 r
.37721 .46561 m .37539 .46748 L .3747 .46604 L F
.471 .701 .969 r
.3758 .46302 m .37721 .46561 L .37533 .46411 L F
.998 .842 .556 r
.3758 .46302 m .37539 .46748 L .37721 .46561 L F
.12 .526 .914 r
.41064 .59864 m .41002 .59972 L .4123 .60018 L F
.972 .671 .386 r
.39824 .54746 m .39841 .55009 L .39655 .54636 L F
.352 .479 .848 r
.61319 .39385 m .61484 .39695 L .61657 .39556 L F
.496 .881 .694 r
.61657 .39556 m .61484 .39695 L .61328 .39772 L F
.378 0 .008 r
.58619 .34966 m .59015 .34764 L .58743 .35165 L F
.58619 .34966 m .58909 .34979 L .59015 .34764 L F
.653 .928 .973 r
.59015 .34764 m .59151 .3455 L .59276 .34614 L F
0 0 0 r
.59015 .34764 m .58909 .34979 L .59151 .3455 L F
.966 .779 .342 r
.52131 .41254 m .52278 .41337 L .52441 .41109 L F
.52131 .41254 m .52195 .41511 L .52278 .41337 L F
.63 .92 .647 r
.55021 .40652 m .5511 .40605 L .55279 .40424 L F
0 0 0 r
.54947 .40717 m .54862 .40745 L .5511 .40605 L F
.63 .92 .647 r
.54947 .40717 m .5511 .40605 L .55021 .40652 L F
.77 .951 .625 r
.55167 .40574 m .5511 .40605 L .55133 .40629 L F
.55363 .40257 m .5511 .40605 L .55167 .40574 L F
.647 .754 .927 r
.6165 .40626 m .61787 .40268 L .61401 .40541 L F
.844 .386 .109 r
.39666 .54132 m .39546 .54237 L .39468 .54063 L F
.933 .555 .221 r
.39666 .54132 m .3972 .54353 L .39546 .54237 L F
.998 .847 .545 r
.69896 .34721 m .69959 .34472 L .6985 .34322 L F
.905 .494 .169 r
.35799 .51753 m .35923 .52051 L .36093 .52143 L F
.966 .642 .322 r
.35961 .5227 m .36093 .52143 L .35923 .52051 L F
.35961 .5227 m .36132 .52411 L .36093 .52143 L F
.9 .483 .126 r
.38903 .53028 m .38629 .52637 L .3879 .52752 L F
.66 .903 .571 r
.55843 .37398 m .55675 .37601 L .55784 .37429 L F
.852 .993 .837 r
.55843 .37398 m .55967 .37058 L .56127 .37284 L F
.066 .175 .67 r
.55784 .37429 m .55927 .37481 L .55899 .37249 L F
.852 .993 .837 r
.55843 .37398 m .55837 .37284 L .55967 .37058 L F
.884 .85 .394 r
.55843 .37398 m .55784 .37429 L .55837 .37284 L F
.066 .175 .67 r
.55784 .37429 m .55899 .37249 L .55899 .37242 L F
.66 .903 .571 r
.55675 .37601 m .55569 .37729 L .55784 .37429 L F
.469 .537 .844 r
.55569 .37729 m .55805 .37744 L .55784 .37429 L F
.885 .819 .778 r
.44912 .58241 m .44697 .58548 L .44566 .58235 L F
0 .215 .734 r
.59152 .35429 m .59238 .35262 L .59126 .35244 L F
.501 .3 .54 r
.59152 .35429 m .59319 .35381 L .59238 .35262 L F
.59152 .35429 m .59426 .35584 L .59319 .35381 L F
.59152 .35429 m .59166 .35686 L .59426 .35584 L F
.59426 .35584 m .59166 .35686 L .59152 .35429 L F
.661 .97 .813 r
.6681 .32882 m .66651 .32905 L .66481 .33116 L F
0 0 0 r
.67048 .32755 m .66651 .32905 L .6681 .32882 L F
.941 .949 .629 r
.31949 .56053 m .31791 .56384 L .31759 .56214 L F
.613 .422 .599 r
.32024 .56356 m .31791 .56384 L .31949 .56053 L F
.934 .612 .405 r
.31759 .56214 m .32024 .56356 L .31949 .56053 L F
.488 .105 .241 r
.51519 .46403 m .51288 .46249 L .51245 .46425 L F
.51519 .46403 m .51288 .46249 L .51245 .46425 L F
0 0 0 r
.26448 .52406 m .2626 .52447 L .26086 .52473 L F
0 0 .435 r
.26177 .52562 m .26086 .52473 L .2626 .52447 L F
.944 .692 .526 r
.56166 .38715 m .56141 .38971 L .55962 .38572 L F
.651 .956 .751 r
.66651 .32905 m .66333 .33173 L .66481 .33116 L F
.607 .954 .871 r
.44457 .44273 m .44448 .44389 L .44228 .44397 L F
.44457 .44273 m .44667 .44245 L .44448 .44389 L F
.605 .426 .613 r
.54967 .44271 m .5528 .44212 L .55265 .43946 L F
.727 .624 .744 r
.5528 .44212 m .54993 .44566 L .54967 .44271 L F
.55205 .44304 m .55386 .44587 L .54993 .44566 L F
.5528 .44212 m .55305 .44299 L .55205 .44304 L F
.55305 .44299 m .55386 .44587 L .55205 .44304 L F
.5 .159 .321 r
.55227 .44414 m .55043 .44313 L .54901 .44449 L F
.55043 .44313 m .54967 .44271 L .54949 .44317 L F
.55043 .44313 m .54949 .44317 L .54901 .44449 L F
.55227 .44414 m .5528 .44212 L .54967 .44271 L F
.26 .036 .373 r
.33037 .58015 m .32816 .58338 L .33022 .58246 L F
.812 .74 .785 r
.32624 .57958 m .32816 .58338 L .33037 .58015 L F
0 0 .064 r
.32816 .58338 m .32794 .58638 L .32844 .58476 L F
.418 .828 .974 r
.24763 .59025 m .24833 .58919 L .24561 .58963 L F
0 0 0 r
.50244 .52472 m .5024 .52432 L .50421 .52306 L F
.50244 .52472 m .5017 .52657 L .5024 .52432 L F
.468 0 0 r
.59455 .37241 m .59848 .37104 L .59654 .36947 L F
.59455 .37241 m .59738 .37244 L .59848 .37104 L F
.45 0 0 r
.59848 .37104 m .59738 .37244 L .6017 .3718 L F
.454 0 0 r
.59848 .37104 m .6017 .3718 L .60207 .37112 L F
.832 .794 .815 r
.50181 .44622 m .50575 .44584 L .50456 .44512 L F
0 0 .36 r
.50744 .44125 m .50635 .44328 L .50616 .44106 L F
.722 .941 .626 r
.50682 .44208 m .50635 .44328 L .50744 .44125 L F
.50592 .44328 m .50635 .44328 L .50682 .44208 L F
.921 .917 .796 r
.50575 .44584 m .50587 .44455 L .50635 .44328 L F
.50587 .44455 m .50616 .44106 L .50635 .44328 L F
.775 .977 .914 r
.50456 .44512 m .50575 .44584 L .50635 .44328 L F
.714 .565 .685 r
.50617 .44852 m .50971 .44581 L .50575 .44584 L F
.612 .646 .86 r
.33746 .57619 m .34024 .57666 L .33806 .57302 L F
.592 .12 .102 r
.34028 .57957 m .33746 .57619 L .3364 .57951 L F
.74 .983 .909 r
.33997 .5801 m .34234 .57879 L .34087 .57879 L F
.592 .12 .102 r
.34027 .57898 m .34024 .57666 L .33989 .5791 L F
.757 .251 .007 r
.33992 .5788 m .34024 .57666 L .34027 .57898 L F
.74 .983 .909 r
.33993 .57909 m .34027 .57898 L .33992 .5788 L F
.33997 .5801 m .34087 .57879 L .33993 .57909 L F
.592 .12 .102 r
.34028 .57957 m .34027 .57898 L .33989 .5791 L F
.757 .251 .007 r
.33992 .5788 m .34027 .57898 L .34028 .57957 L F
.74 .983 .909 r
.34027 .57898 m .34087 .57879 L .33992 .5788 L F
.592 .12 .102 r
.33989 .5791 m .34024 .57666 L .33746 .57619 L F
.772 .393 .337 r
.64964 .34075 m .64718 .34274 L .64644 .34086 L F
.64964 .34075 m .6501 .34343 L .64718 .34274 L F
0 0 0 r
.65294 .33988 m .6501 .34343 L .64964 .34075 L F
.192 0 0 r
.4501 .59658 m .45087 .59731 L .44848 .59833 L F
.4501 .59658 m .45285 .59658 L .45087 .59731 L F
.679 .184 .064 r
.29002 .55381 m .2852 .55262 L .28728 .55435 L F
.832 .71 .729 r
.5347 .40905 m .53779 .40644 L .53459 .4067 L F
.347 .608 .946 r
.29665 .64494 m .30103 .64745 L .29915 .64455 L F
.627 .678 .879 r
.29915 .64455 m .30103 .64745 L .3027 .64529 L F
.084 0 0 r
.30103 .64745 m .30332 .64631 L .3027 .64529 L F
.53 .138 .243 r
.64387 .33964 m .63851 .34218 L .63953 .34042 L F
.532 .923 .844 r
.45334 .43942 m .44888 .44113 L .45329 .43877 L F
.681 .979 .857 r
.45509 .43796 m .45334 .43942 L .45447 .43758 L F
.666 .97 .909 r
.45447 .43758 m .45334 .43942 L .45329 .43877 L F
0 .241 .755 r
.60076 .38472 m .6022 .38819 L .60169 .38888 L F
.874 .861 .825 r
.45356 .45578 m .4546 .45092 L .45161 .45444 L F
.45356 .45578 m .45616 .45247 L .4546 .45092 L F
.87 .958 .86 r
.28989 .58587 m .28614 .58824 L .28769 .58676 L F
.713 .883 .96 r
.45616 .45247 m .45703 .44975 L .4546 .45092 L F
.45616 .45247 m .45874 .4511 L .45703 .44975 L F
0 0 0 r
.27162 .51447 m .27217 .51467 L .2741 .51292 L F
.27162 .51447 m .27057 .51661 L .27217 .51467 L F
.467 .273 .533 r
.53968 .47809 m .54226 .47739 L .53985 .47542 L F
.742 .991 .873 r
.33704 .65081 m .34216 .64866 L .34028 .65068 L F
.208 .724 .877 r
.34216 .64866 m .34464 .64844 L .34356 .6481 L F
.34216 .64866 m .34356 .6481 L .34028 .65068 L F
.93 .916 .533 r
.59897 .39465 m .59899 .39699 L .60032 .39368 L F
0 0 0 r
.60201 .39205 m .60032 .39368 L .60319 .3896 L F
.519 .859 .591 r
.59897 .39465 m .60032 .39368 L .60201 .39205 L F
.48 .792 .999 r
.43858 .48395 m .4401 .48567 L .43492 .4847 L F
.776 .686 .764 r
.4401 .48567 m .43645 .48853 L .43492 .4847 L F
.368 .044 .277 r
.43913 .48773 m .43645 .48853 L .4401 .48567 L F
.604 .858 .992 r
.44188 .4844 m .4401 .48567 L .43858 .48395 L F
0 0 .023 r
.44944 .572 m .44931 .57282 L .44937 .57072 L F
.44944 .572 m .44937 .57072 L .4469 .5697 L F
.564 .69 .925 r
.57695 .45901 m .57965 .4584 L .57779 .45639 L F
.363 0 .058 r
.68212 .30365 m .68498 .30321 L .68616 .30124 L F
.643 .208 .202 r
.68616 .30124 m .68912 .30337 L .68884 .30158 L F
.68616 .30124 m .68498 .30321 L .68912 .30337 L F
.599 .731 .937 r
.2447 .57747 m .24561 .5748 L .24354 .57541 L F
.2447 .57747 m .24732 .57688 L .24561 .5748 L F
.766 .72 .81 r
.29192 .58567 m .29436 .58673 L .29274 .58277 L F
.456 .228 .479 r
.29702 .58609 m .29414 .58934 L .29436 .58673 L F
.29702 .58609 m .29414 .58934 L .29436 .58673 L F
.54 .226 .385 r
.27051 .64146 m .27123 .63878 L .26832 .63901 L F
.275 .141 .51 r
.24774 .547 m .24686 .55034 L .24579 .55064 L F
.677 .55 .703 r
.24953 .55221 m .24579 .55064 L .24686 .55034 L F
.24953 .55221 m .24523 .55529 L .24579 .55064 L F
.308 0 .128 r
.24523 .55529 m .2457 .55626 L .24341 .55677 L F
.421 .313 .626 r
.67382 .34412 m .672 .34769 L .67427 .34696 L F
.44 .369 .68 r
.67427 .34696 m .67567 .34899 L .672 .34769 L F
.982 .693 .35 r
.67382 .34412 m .67427 .34696 L .672 .34769 L F
.44 .369 .68 r
.67427 .34696 m .67567 .34899 L .672 .34769 L F
.721 .605 .727 r
.24179 .59265 m .24125 .59603 L .23606 .59526 L F
.569 .488 .723 r
.24342 .59517 m .24309 .59844 L .24078 .59675 L F
.917 .594 .419 r
.24309 .59844 m .2421 .59739 L .24078 .59675 L F
.527 0 0 r
.24125 .59603 m .24078 .59675 L .23843 .59561 L F
.569 .488 .723 r
.2424 .59558 m .24078 .59675 L .24125 .59603 L F
.24342 .59517 m .24189 .59609 L .2424 .59558 L F
.24189 .59609 m .24078 .59675 L .2424 .59558 L F
.917 .594 .419 r
.2421 .59739 m .23952 .59464 L .24078 .59675 L F
.527 0 0 r
.23843 .59561 m .24078 .59675 L .23606 .59526 L F
.319 .579 .935 r
.23606 .59526 m .24078 .59675 L .23952 .59464 L F
.917 .594 .419 r
.24137 .59661 m .23882 .59747 L .23952 .59464 L F
.24309 .59844 m .24019 .59779 L .24137 .59661 L F
.24019 .59779 m .23882 .59747 L .24137 .59661 L F
.181 .179 .62 r
.24254 .59232 m .24125 .59603 L .24179 .59265 L F
.24254 .59232 m .24342 .59517 L .24125 .59603 L F
0 .357 .808 r
.44944 .572 m .45146 .57388 L .44931 .57282 L F
.481 0 0 r
.54354 .47815 m .53968 .47809 L .54226 .47739 L F
.66 .801 .95 r
.54484 .47474 m .54354 .47815 L .54226 .47739 L F
.54484 .47474 m .54574 .47686 L .54354 .47815 L F
.952 .638 .401 r
.51687 .40891 m .51725 .41153 L .5185 .40973 L F
.283 0 0 r
.51725 .41153 m .52153 .40976 L .5185 .40973 L F
.796 .766 .825 r
.67596 .35623 m .6749 .36081 L .67379 .35948 L F
.67596 .35623 m .67791 .35784 L .6749 .36081 L F
.863 .64 .598 r
.38331 .56978 m .38455 .5669 L .38107 .56615 L F
.855 .793 .79 r
.32043 .5729 m .3253 .57059 L .3234 .56925 L F
.32043 .5729 m .32283 .57407 L .3253 .57059 L F
0 0 0 r
.50767 .51751 m .51008 .51431 L .50913 .51614 L F
.50651 .5195 m .50767 .51751 L .50913 .51614 L F
.51209 .49383 m .51072 .49551 L .5137 .49217 L F
.237 .247 .668 r
.31624 .62578 m .31638 .6293 L .3183 .62773 L F
0 0 0 r
.31794 .62832 m .31638 .6293 L .31656 .63063 L F
.31811 .62788 m .31638 .6293 L .31794 .62832 L F
.3183 .62773 m .31656 .63063 L .31808 .63055 L F
.987 .721 .359 r
.3168 .62691 m .3176 .6292 L .31689 .63009 L F
.3176 .6292 m .31808 .63055 L .31721 .63022 L F
.3176 .6292 m .31721 .63022 L .31689 .63009 L F
0 0 0 r
.3183 .62773 m .31811 .62788 L .31794 .62832 L F
.501 .787 .996 r
.44482 .56891 m .4469 .5697 L .44433 .5702 L F
.751 .993 .81 r
.44482 .56891 m .44433 .5702 L .44355 .56997 L F
.974 .78 .582 r
.41886 .47421 m .42062 .47368 L .41616 .47305 L F
.41886 .47421 m .42066 .47582 L .42062 .47368 L F
.696 .557 .693 r
.42289 .47208 m .42066 .47582 L .42062 .47368 L F
.907 .511 .103 r
.56288 .44163 m .56408 .44232 L .5645 .44411 L F
.611 .622 .837 r
.58838 .37141 m .58918 .37439 L .59183 .3734 L F
.723 .987 .811 r
.54492 .48497 m .54114 .48736 L .54105 .48778 L F
.54492 .48497 m .54285 .48551 L .54114 .48736 L F
.612 .953 .816 r
.54492 .48497 m .54824 .48275 L .54633 .48329 L F
.612 .953 .809 r
.54633 .48329 m .54285 .48551 L .54492 .48497 L F
.457 .002 .081 r
.4186 .5974 m .41918 .59851 L .41468 .59968 L F
.619 .09 0 r
.4186 .5974 m .42213 .59949 L .41918 .59851 L F
.825 .815 .84 r
.56887 .45335 m .56669 .45625 L .56574 .45218 L F
.9 .851 .786 r
.56574 .45218 m .56669 .45625 L .56363 .45625 L F
.435 .333 .64 r
.53208 .42599 m .53326 .43032 L .53528 .42848 L F
.541 .877 .617 r
.53528 .42848 m .53326 .43032 L .53204 .43128 L F
0 0 0 r
.53204 .43128 m .5361 .42932 L .53528 .42848 L F
.919 .976 .759 r
.53528 .42848 m .5361 .42932 L .53845 .42553 L F
.707 .629 .767 r
.24341 .55677 m .24436 .56047 L .24103 .56024 L F
.204 .198 .629 r
.24316 .56254 m .24103 .56024 L .24436 .56047 L F
.25 .321 .742 r
.24585 .55902 m .24436 .56047 L .24341 .55677 L F
.301 .052 .359 r
.24585 .55902 m .24316 .56254 L .24436 .56047 L F
.946 .922 .754 r
.36994 .62516 m .37303 .62233 L .37193 .62116 L F
0 0 0 r
.68026 .30504 m .67707 .30843 L .67928 .30654 L F
.476 .235 .469 r
.67928 .30654 m .68212 .30365 L .68026 .30504 L F
0 0 0 r
.42002 .4589 m .42082 .45896 L .41849 .45814 L F
.42002 .4589 m .42275 .45869 L .42082 .45896 L F
0 0 .356 r
.59982 .34919 m .59871 .3545 L .60107 .35212 L F
.257 .466 .872 r
.62612 .41512 m .6244 .41208 L .62619 .41465 L F
.967 .874 .692 r
.62404 .417 m .62612 .41512 L .62619 .41465 L F
.702 .496 .607 r
.6076 .367 m .60558 .3706 L .60526 .36722 L F
.892 .756 .704 r
.6054 .37021 m .6076 .367 L .60526 .36722 L F
.6054 .37021 m .60558 .3706 L .6076 .367 L F
.028 0 .481 r
.23586 .53759 m .23686 .53973 L .23716 .53667 L F
.23586 .53759 m .23612 .54039 L .23686 .53973 L F
.701 .925 .597 r
.28147 .61389 m .27991 .6161 L .2808 .61426 L F
.542 .542 .804 r
.28147 .61389 m .28321 .61603 L .27991 .6161 L F
0 .046 .591 r
.28157 .61746 m .27991 .6161 L .28321 .61603 L F
0 0 .252 r
.2808 .61426 m .27991 .6161 L .28017 .61932 L F
0 0 0 r
.32063 .61849 m .32203 .61744 L .31848 .61926 L F
.078 0 .115 r
.32063 .61849 m .31848 .61926 L .31776 .62142 L F
.4 .081 .305 r
.53532 .42633 m .5355 .4241 L .53208 .42599 L F
.435 .333 .64 r
.53208 .42599 m .53528 .42848 L .53532 .42633 L F
0 0 0 r
.3319 .58667 m .3288 .58971 L .32794 .58638 L F
.33072 .58931 m .32774 .59444 L .32844 .5923 L F
0 .131 .661 r
.33242 .59102 m .33206 .59064 L .3322 .58906 L F
.33206 .59064 m .33075 .58922 L .33215 .58907 L F
.33206 .59064 m .33215 .58907 L .3322 .58906 L F
.33242 .59102 m .33091 .58922 L .33075 .58922 L F
0 0 0 r
.33091 .58922 m .33045 .59006 L .33079 .58922 L F
0 .131 .661 r
.33242 .59102 m .33234 .59046 L .33111 .58939 L F
.33166 .59012 m .33111 .58939 L .33091 .58922 L F
.33242 .59102 m .33111 .58939 L .33166 .59012 L F
.642 .148 .064 r
.33234 .59046 m .33064 .5903 L .33091 .58922 L F
0 0 0 r
.33097 .58922 m .33086 .5894 L .33091 .58922 L F
.33086 .5894 m .33045 .59006 L .33091 .58922 L F
0 .131 .661 r
.33075 .58922 m .3307 .58916 L .33078 .58916 L F
.094 0 .399 r
.33061 .58865 m .32844 .5923 L .3288 .58971 L F
0 .131 .661 r
.3307 .58916 m .33014 .58856 L .33061 .58867 L F
.094 0 .399 r
.33067 .58915 m .33041 .58898 L .33061 .58865 L F
.33173 .58799 m .3288 .58971 L .33014 .58856 L F
0 .131 .661 r
.3307 .58916 m .33091 .58922 L .33014 .58856 L F
.33075 .58922 m .33079 .58922 L .3307 .58916 L F
.33075 .58922 m .33078 .58916 L .3322 .58906 L F
.876 .51 .348 r
.3322 .58906 m .33061 .58867 L .3319 .58667 L F
.094 0 .399 r
.33173 .58799 m .3307 .58934 L .33061 .58865 L F
0 .131 .661 r
.33079 .58922 m .33091 .58922 L .3307 .58916 L F
.094 0 .399 r
.3307 .58934 m .32844 .5923 L .33041 .58898 L F
.3307 .58934 m .33041 .58898 L .33067 .58915 L F
.33061 .58865 m .32844 .5923 L .33061 .58865 L F
0 0 0 r
.33147 .58709 m .33014 .58856 L .3288 .58971 L F
.602 .353 .513 r
.32718 .58823 m .32705 .59123 L .32988 .58927 L F
.642 .148 .064 r
.33027 .58935 m .32966 .58915 L .33014 .58856 L F
.849 .783 .787 r
.33058 .58941 m .32988 .58927 L .3278 .5907 L F
.32779 .59084 m .3278 .5907 L .32705 .59123 L F
.33058 .58941 m .3278 .5907 L .32779 .59084 L F
.094 0 .399 r
.33061 .58865 m .33061 .58865 L .33061 .58865 L F
.876 .51 .348 r
.33061 .58867 m .33014 .58856 L .33054 .58813 L F
.33061 .58867 m .33054 .58813 L .3319 .58667 L F
.602 .353 .513 r
.32962 .58914 m .33014 .58856 L .32966 .58915 L F
0 0 0 r
.3319 .58667 m .33014 .58856 L .33147 .58709 L F
.602 .353 .513 r
.32718 .58823 m .33173 .58799 L .33014 .58856 L F
.32789 .58819 m .32966 .58915 L .33173 .58799 L F
.642 .148 .064 r
.32988 .58927 m .32966 .58915 L .33027 .58935 L F
.602 .353 .513 r
.32966 .58915 m .32988 .58927 L .32991 .58925 L F
.32966 .58915 m .32991 .58925 L .33173 .58799 L F
.3288 .59005 m .32962 .58914 L .32888 .59014 L F
.32962 .58914 m .32966 .58915 L .32888 .59014 L F
.32718 .58823 m .32988 .58927 L .32966 .58915 L F
.32718 .58823 m .33014 .58856 L .32962 .58914 L F
.32718 .58823 m .32966 .58915 L .32789 .58819 L F
.32718 .58823 m .32962 .58914 L .3288 .59005 L F
.435 0 0 r
.33247 .58767 m .33665 .58654 L .33286 .58484 L F
.79 .424 .365 r
.32844 .58476 m .33247 .58767 L .33286 .58484 L F
.32844 .58476 m .32875 .58718 L .33247 .58767 L F
.602 .353 .513 r
.32801 .58767 m .32861 .58939 L .32875 .58718 L F
.32861 .58939 m .32888 .59014 L .32884 .58922 L F
.32861 .58939 m .32884 .58922 L .32875 .58718 L F
.32718 .58823 m .32792 .58906 L .32801 .58767 L F
.32792 .58906 m .32888 .59014 L .32801 .58767 L F
.192 0 .077 r
.32436 .58915 m .32718 .58823 L .32794 .58638 L F
.009 0 .364 r
.32718 .58823 m .32844 .58476 L .32794 .58638 L F
.32718 .58823 m .32875 .58718 L .32844 .58476 L F
.925 .693 .569 r
.32875 .58718 m .32888 .59014 L .32654 .58614 L F
.32654 .58614 m .32888 .59014 L .32875 .58718 L F
.32875 .58718 m .32888 .59014 L .32654 .58614 L F
.778 .605 .039 r
.32875 .58718 m .32888 .59014 L .32874 .58905 L F
.767 .365 .29 r
.32875 .58718 m .32874 .58905 L .32944 .58879 L F
.33005 .58735 m .32944 .58879 L .33247 .58767 L F
.32875 .58718 m .32944 .58879 L .33005 .58735 L F
.849 .783 .787 r
.3275 .59323 m .32775 .59291 L .32705 .59123 L F
.32775 .59291 m .33058 .58941 L .32774 .59087 L F
.32775 .59291 m .32774 .59087 L .32705 .59123 L F
0 0 0 r
.33045 .59006 m .32774 .59444 L .33072 .58931 L F
.849 .783 .787 r
.3275 .59323 m .32774 .59444 L .33086 .5894 L F
.33081 .5894 m .33086 .5894 L .33097 .58922 L F
.3275 .59323 m .33086 .5894 L .33081 .5894 L F
.642 .148 .064 r
.33086 .5894 m .33048 .58941 L .33091 .58922 L F
0 0 0 r
.33079 .58922 m .33045 .59006 L .33072 .58931 L F
.849 .783 .787 r
.3275 .59323 m .33097 .58922 L .33086 .58907 L F
.642 .148 .064 r
.33064 .5903 m .32888 .59014 L .33048 .58941 L F
.33064 .5903 m .33048 .58941 L .33086 .5894 L F
0 0 0 r
.32782 .59547 m .32775 .59456 L .3278 .59268 L F
.32775 .59456 m .32774 .59444 L .32775 .59418 L F
.32775 .59456 m .32775 .59418 L .3278 .59268 L F
0 0 .304 r
.3278 .59268 m .32891 .59005 L .32888 .59014 L F
0 .176 .712 r
.32993 .58843 m .32942 .5888 L .32874 .58905 L F
.226 .179 .593 r
.32957 .58847 m .33325 .58669 L .32874 .58905 L F
.26 .515 .906 r
.32874 .58905 m .32888 .59014 L .32957 .58847 L F
0 0 .304 r
.32891 .59005 m .32957 .58847 L .32921 .58934 L F
.32891 .59005 m .32921 .58934 L .32888 .59014 L F
0 .176 .712 r
.33325 .58669 m .33247 .58767 L .32942 .5888 L F
.33325 .58669 m .32942 .5888 L .32993 .58843 L F
.642 .148 .064 r
.33029 .5895 m .32988 .58927 L .33027 .58935 L F
.33091 .58922 m .33029 .5895 L .33014 .58856 L F
0 .131 .661 r
.3307 .58916 m .33061 .58867 L .3322 .58906 L F
.849 .783 .787 r
.33058 .58941 m .33173 .58799 L .32988 .58927 L F
.642 .148 .064 r
.33029 .5895 m .32888 .59014 L .32966 .58915 L F
0 0 0 r
.33173 .58799 m .33097 .58922 L .33079 .58922 L F
.849 .783 .787 r
.33086 .58907 m .33097 .58922 L .33173 .58799 L F
0 0 .04 r
.33133 .59484 m .33234 .59046 L .33242 .59102 L F
.33199 .59199 m .33216 .59307 L .33234 .59046 L F
.33133 .59484 m .3319 .59362 L .33199 .59199 L F
.3319 .59362 m .33216 .59307 L .33199 .59199 L F
.229 0 0 r
.32142 .58986 m .32436 .58915 L .3256 .58779 L F
.891 .681 .612 r
.36192 .52785 m .36241 .53003 L .36706 .531 L F
.865 .607 .546 r
.36148 .53187 m .36706 .531 L .36241 .53003 L F
.36148 .53187 m .36701 .53379 L .36706 .531 L F
.453 0 .054 r
.31863 .5908 m .32066 .59172 L .32142 .58986 L F
.411 0 .039 r
.32142 .58986 m .32361 .5912 L .32436 .58915 L F
.32142 .58986 m .32066 .59172 L .32361 .5912 L F
.598 .215 .289 r
.27756 .51629 m .27418 .51871 L .27596 .51789 L F
.593 .072 0 r
.30465 .66806 m .30886 .6685 L .30683 .66985 L F
.358 0 0 r
.30767 .6687 m .30886 .6685 L .30465 .66806 L F
.44 .876 .818 r
.31028 .66754 m .30886 .6685 L .30767 .6687 L F
.397 .804 .59 r
.30683 .66985 m .30886 .6685 L .31028 .66754 L F
.202 0 0 r
.62975 .38781 m .62549 .38819 L .62862 .38745 L F
0 .151 .673 r
.63169 .38916 m .63099 .38976 L .62975 .38781 L F
.63169 .38916 m .62975 .38781 L .62862 .38745 L F
.976 .726 .492 r
.59144 .39682 m .58963 .39815 L .58946 .39574 L F
.59144 .39682 m .5914 .39938 L .58963 .39815 L F
.7 .543 .671 r
.52458 .47327 m .52639 .4759 L .52869 .47489 L F
.043 .033 .518 r
.69505 .28203 m .69679 .27993 L .69599 .27741 L F
.279 .38 .787 r
.69505 .28203 m .69811 .28396 L .69679 .27993 L F
.371 .374 .733 r
.69505 .28203 m .69593 .28441 L .69811 .28396 L F
.638 .723 .909 r
.47754 .44613 m .47885 .44889 L .48207 .4475 L F
.76 .662 .753 r
.60551 .43239 m .60547 .43664 L .6022 .4364 L F
0 0 .026 r
.60553 .43534 m .60547 .43664 L .60551 .43239 L F
.565 .824 .994 r
.6022 .4364 m .60547 .43664 L .60553 .43534 L F
.667 .203 .142 r
.60467 .43738 m .60661 .43791 L .60547 .43664 L F
.884 .957 .616 r
.60467 .43738 m .60547 .43664 L .60553 .43534 L F
.667 .203 .142 r
.60467 .43738 m .60661 .43791 L .60547 .43664 L F
.365 .592 .932 r
.58743 .35165 m .58909 .34979 L .58619 .34966 L F
.58743 .35165 m .59126 .35244 L .58909 .34979 L F
0 0 0 r
.60419 .39058 m .60319 .3896 L .6022 .38819 L F
.60419 .39058 m .60201 .39205 L .60319 .3896 L F
.619 .863 .989 r
.60852 .40798 m .60724 .41024 L .6096 .40889 L F
.60852 .40798 m .60589 .40904 L .60724 .41024 L F
.55 .897 .978 r
.64338 .38574 m .63903 .38632 L .64186 .38441 L F
.27 0 0 r
.6431 .3858 m .64338 .38574 L .64186 .38441 L F
.6431 .3858 m .64496 .38627 L .64338 .38574 L F
.629 .081 0 r
.29163 .54859 m .29277 .54972 L .29387 .55032 L F
.961 .823 .661 r
.29277 .54972 m .2915 .55229 L .29387 .55032 L F
.356 .589 .933 r
.6017 .3718 m .60262 .37381 L .60558 .3706 L F
.6017 .3718 m .60365 .37173 L .60262 .37381 L F
.005 0 .402 r
.60414 .37448 m .60262 .37381 L .60365 .37173 L F
.60414 .37448 m .60268 .37645 L .60262 .37381 L F
0 0 .392 r
.53324 .46473 m .53363 .46818 L .53286 .46481 L F
0 0 0 r
.5161 .50813 m .51467 .50979 L .51323 .51125 L F
.434 .692 .973 r
.5161 .50813 m .51747 .50673 L .51681 .50604 L F
.766 .903 .511 r
.51681 .50604 m .51467 .50979 L .5161 .50813 L F
.102 0 0 r
.63456 .33749 m .63845 .33481 L .63531 .33665 L F
.63456 .33749 m .63766 .33644 L .63845 .33481 L F
0 0 0 r
.63845 .33481 m .63977 .33476 L .64111 .33386 L F
.63845 .33481 m .63766 .33644 L .63977 .33476 L F
.18 .708 .704 r
.40541 .45898 m .40497 .45906 L .40217 .45975 L F
.586 .012 0 r
.40497 .45906 m .40641 .46023 L .40397 .45926 L F
.527 .794 .994 r
.40217 .45975 m .40497 .45906 L .40148 .45755 L F
.586 .012 0 r
.40497 .45906 m .40397 .45926 L .40356 .4591 L F
.18 .708 .704 r
.4066 .45869 m .40497 .45906 L .40541 .45898 L F
.942 .9 .755 r
.40931 .45837 m .40497 .45906 L .4066 .45869 L F
.538 .852 .551 r
.51158 .51271 m .51008 .51431 L .51323 .51125 L F
.514 .84 .543 r
.51323 .51125 m .51467 .50979 L .51158 .51271 L F
.564 .629 .874 r
.35811 .53539 m .3611 .53744 L .36126 .53683 L F
.686 .98 .861 r
.35892 .54016 m .35938 .53975 L .3611 .53744 L F
.911 .914 .52 r
.3611 .53744 m .36066 .5365 L .36126 .53683 L F
.876 .978 .679 r
.3611 .53744 m .35938 .53975 L .36066 .5365 L F
.935 .706 .568 r
.4033 .56704 m .4007 .56857 L .40158 .56601 L F
.4033 .56704 m .40284 .56991 L .4007 .56857 L F
.401 .578 .911 r
.55637 .41496 m .55838 .41802 L .55608 .41613 L F
.364 0 0 r
.34813 .52544 m .3433 .52373 L .34581 .52738 L F
.34813 .52544 m .34767 .52567 L .3433 .52373 L F
.115 0 0 r
.35108 .52578 m .34767 .52567 L .34813 .52544 L F
0 .388 .769 r
.53845 .42553 m .5355 .4241 L .53738 .42296 L F
.919 .976 .759 r
.53528 .42848 m .53845 .42553 L .53785 .42575 L F
.345 .497 .867 r
.54063 .42404 m .53845 .42553 L .53738 .42296 L F
.435 .849 .679 r
.53785 .42575 m .53845 .42553 L .54063 .42404 L F
.741 .931 .951 r
.59557 .4383 m .59994 .43748 L .5982 .43486 L F
.687 .704 .86 r
.59994 .43748 m .6022 .4364 L .5982 .43486 L F
.809 .568 .573 r
.67427 .34696 m .67882 .34751 L .67812 .34959 L F
.773 .477 .486 r
.28231 .59313 m .27827 .59509 L .27818 .59293 L F
.28231 .59313 m .28181 .59568 L .27827 .59509 L F
.597 .308 .448 r
.28231 .59313 m .28461 .59546 L .28181 .59568 L F
.62 .305 .416 r
.28548 .59321 m .28461 .59546 L .28231 .59313 L F
0 0 .125 r
.40259 .50219 m .40237 .50133 L .4008 .49989 L F
.825 .569 .017 r
.40237 .50133 m .40281 .50445 L .40287 .50424 L F
0 0 .125 r
.40259 .50219 m .40281 .50445 L .40237 .50133 L F
.861 .634 .593 r
.37947 .55975 m .38149 .56339 L .38184 .56052 L F
.743 .673 .782 r
.24758 .53006 m .25201 .53137 L .2503 .52731 L F
0 0 0 r
.2459 .53269 m .25201 .53137 L .24758 .53006 L F
.2459 .53269 m .24841 .53223 L .25201 .53137 L F
.334 .15 .475 r
.25201 .53137 m .25371 .52814 L .2503 .52731 L F
.25201 .53137 m .25402 .53088 L .25371 .52814 L F
.233 .745 .723 r
.25201 .53137 m .25084 .53151 L .25402 .53088 L F
.25201 .53137 m .24841 .53223 L .25084 .53151 L F
.773 .638 .711 r
.62481 .40976 m .62072 .40971 L .62324 .40633 L F
.54 .252 .426 r
.62481 .40976 m .62105 .41231 L .62072 .40971 L F
.62481 .40976 m .6244 .41208 L .62105 .41231 L F
0 0 .222 r
.62601 .41083 m .62481 .40976 L .6263 .41167 L F
.62601 .41083 m .6244 .41208 L .62481 .40976 L F
.905 .674 .579 r
.42745 .54652 m .42996 .54723 L .42784 .54367 L F
.42745 .54652 m .42996 .54723 L .42784 .54367 L F
.987 .757 .504 r
.42828 .5489 m .42996 .54723 L .42745 .54652 L F
.42828 .5489 m .42961 .54999 L .42996 .54723 L F
.566 .375 .581 r
.64496 .38627 m .64798 .38257 L .64567 .38361 L F
0 0 0 r
.25458 .59511 m .25606 .59485 L .25844 .59285 L F
.747 .244 .023 r
.25781 .59418 m .25844 .59285 L .25606 .59485 L F
.25781 .59418 m .26115 .59573 L .25844 .59285 L F
.647 .627 .815 r
.31294 .65363 m .31345 .64851 L .31091 .64928 L F
.31294 .65363 m .31535 .65263 L .31345 .64851 L F
.571 .599 .842 r
.6995 .28697 m .70065 .28269 L .69811 .28396 L F
.6995 .28697 m .70245 .28564 L .70065 .28269 L F
.663 .147 .001 r
.70732 .29193 m .70675 .29454 L .70911 .29498 L F
.335 .298 .668 r
.23445 .54743 m .2361 .54694 L .23592 .54291 L F
.284 .136 .496 r
.23439 .55013 m .2361 .54694 L .23445 .54743 L F
.65 .144 .031 r
.35578 .53791 m .35349 .53889 L .35176 .53734 L F
.821 1 .815 r
.35626 .53595 m .35578 .53791 L .35811 .53539 L F
.575 .358 .548 r
.35626 .53595 m .35349 .53889 L .35578 .53791 L F
.648 .968 .832 r
.61789 .41111 m .61983 .40909 L .62072 .40971 L F
.61789 .41111 m .61634 .41151 L .61983 .40909 L F
.578 .597 .835 r
.62105 .41231 m .61789 .41111 L .62072 .40971 L F
.559 .777 .98 r
.55536 .44388 m .55386 .44587 L .5528 .44212 L F
.55536 .44388 m .55687 .44565 L .55386 .44587 L F
.592 .312 .461 r
.55386 .44587 m .55663 .44793 L .55375 .44875 L F
.55386 .44587 m .55687 .44565 L .55663 .44793 L F
.639 .923 .646 r
.60529 .35418 m .60244 .35703 L .60384 .35514 L F
.971 .665 .376 r
.60529 .35418 m .60384 .35514 L .60359 .35269 L F
.44 .68 .966 r
.60384 .35514 m .60677 .3549 L .60526 .35324 L F
.60384 .35514 m .60526 .35324 L .60508 .35304 L F
.639 .923 .646 r
.60244 .35703 m .60217 .3573 L .60384 .35514 L F
.104 .237 .717 r
.60217 .3573 m .60345 .35743 L .60384 .35514 L F
0 0 .356 r
.59982 .34919 m .60035 .35182 L .59871 .3545 L F
.704 .983 .82 r
.60035 .35182 m .59837 .35364 L .59871 .3545 L F
.485 .364 .641 r
.60035 .35182 m .5997 .35457 L .59816 .35384 L F
.60035 .35182 m .59816 .35384 L .598 .35377 L F
.704 .983 .82 r
.60035 .35182 m .59845 .35348 L .59837 .35364 L F
.859 .466 .296 r
.60359 .35269 m .60035 .35182 L .59982 .34919 L F
.789 .669 .73 r
.60035 .35182 m .60384 .35514 L .60359 .35269 L F
.315 .108 .431 r
.59982 .34919 m .598 .35377 L .60035 .35182 L F
.60035 .35182 m .598 .35377 L .59982 .34919 L F
.789 .669 .73 r
.60035 .35182 m .5997 .35457 L .60384 .35514 L F
.74 .879 .944 r
.60035 .35182 m .598 .35377 L .59744 .35356 L F
.59811 .35236 m .59744 .35356 L .59573 .35293 L F
.60035 .35182 m .59744 .35356 L .59811 .35236 L F
.644 .751 .927 r
.59319 .35381 m .59426 .35584 L .59703 .3543 L F
.59741 .35361 m .59703 .3543 L .59835 .35357 L F
.59319 .35381 m .59703 .3543 L .59741 .35361 L F
.506 .573 .857 r
.59845 .35348 m .5985 .35326 L .598 .35377 L F
.286 .781 .746 r
.59785 .35304 m .59573 .35293 L .598 .35377 L F
.74 .879 .944 r
.59876 .35221 m .5968 .35268 L .59855 .35307 L F
.5968 .35268 m .59573 .35293 L .59785 .35304 L F
.5968 .35268 m .59785 .35304 L .59855 .35307 L F
.608 .835 .986 r
.59769 .35231 m .59785 .35304 L .60068 .35104 L F
.59785 .35304 m .598 .35377 L .5985 .35326 L F
.74 .879 .944 r
.60035 .35182 m .59876 .35221 L .59845 .35348 L F
.608 .835 .986 r
.59785 .35304 m .5985 .35326 L .60068 .35104 L F
.286 .781 .746 r
.59769 .35231 m .59573 .35293 L .59785 .35304 L F
.74 .879 .944 r
.59855 .35307 m .59573 .35293 L .59845 .35348 L F
.59845 .35348 m .59573 .35293 L .59835 .35357 L F
.506 .573 .857 r
.59816 .35384 m .59845 .35348 L .598 .35377 L F
.59845 .35348 m .59923 .35252 L .5985 .35326 L F
.5997 .35457 m .60068 .35104 L .59923 .35252 L F
.704 .983 .82 r
.59845 .35348 m .59836 .3536 L .59837 .35364 L F
.506 .573 .857 r
.5997 .35457 m .59923 .35252 L .59816 .35384 L F
.704 .983 .82 r
.59845 .35348 m .59835 .35357 L .59836 .3536 L F
.329 .796 .93 r
.3962 .50458 m .39831 .50402 L .39893 .50453 L F
.39508 .5046 m .39717 .50423 L .3962 .50458 L F
.39717 .50423 m .39831 .50402 L .3962 .50458 L F
.39893 .50453 m .39831 .50402 L .39942 .50452 L F
.874 .46 .024 r
.39942 .50452 m .39831 .50402 L .39711 .50118 L F
.286 .443 .843 r
.39797 .50511 m .40091 .50558 L .39951 .50337 L F
0 0 .498 r
.39711 .50118 m .39831 .50402 L .39842 .50165 L F
.286 .443 .843 r
.39813 .50387 m .39842 .50165 L .39831 .50402 L F
.39813 .50387 m .39951 .50337 L .39842 .50165 L F
.427 0 0 r
.39508 .5046 m .39797 .50511 L .39831 .50402 L F
.286 .443 .843 r
.39797 .50511 m .39813 .50387 L .39831 .50402 L F
.39797 .50511 m .39951 .50337 L .39813 .50387 L F
.33 .135 .458 r
.62595 .35132 m .62721 .35035 L .62711 .34738 L F
.393 .606 .933 r
.62711 .34738 m .62889 .34606 L .62652 .34533 L F
.187 .032 .425 r
.62711 .34738 m .6293 .3475 L .62889 .34606 L F
.62711 .34738 m .62721 .35035 L .6293 .3475 L F
.807 .674 .716 r
.2503 .52731 m .25371 .52814 L .25339 .52477 L F
.418 .361 .688 r
.25371 .52814 m .25516 .52304 L .25339 .52477 L F
.199 .059 .454 r
.25371 .52814 m .25402 .53088 L .25586 .52909 L F
.839 .915 .886 r
.301 .58075 m .30593 .57819 L .30464 .57913 L F
.547 .087 .113 r
.30118 .57916 m .30464 .57913 L .30274 .57753 L F
.507 .105 .214 r
.30464 .57913 m .30564 .57747 L .30274 .57753 L F
.675 .589 .752 r
.42087 .55385 m .42321 .5544 L .42233 .55023 L F
0 0 .247 r
.42233 .55023 m .42245 .55287 L .42087 .55385 L F
.829 .662 .675 r
.42032 .55639 m .42321 .5544 L .42087 .55385 L F
0 0 .128 r
.42194 .55446 m .42087 .55385 L .42245 .55287 L F
.42194 .55446 m .42032 .55639 L .42087 .55385 L F
.259 0 0 r
.71738 .324 m .71362 .32392 L .715 .32366 L F
0 0 .084 r
.25772 .5382 m .25623 .53781 L .25818 .53654 L F
.25772 .5382 m .25522 .54023 L .25623 .53781 L F
.829 .662 .675 r
.42032 .55639 m .42392 .55725 L .42321 .5544 L F
.79 .478 .461 r
.42104 .5588 m .42392 .55725 L .42032 .55639 L F
.42104 .5588 m .42392 .55965 L .42392 .55725 L F
.487 .449 .74 r
.42321 .5544 m .42392 .55725 L .42652 .55628 L F
.356 .135 .434 r
.42392 .55725 m .42392 .55965 L .42652 .55628 L F
0 0 0 r
.62566 .34032 m .62834 .33959 L .62915 .33899 L F
.048 0 0 r
.62834 .33959 m .63176 .33804 L .62915 .33899 L F
.128 0 0 r
.41454 .54415 m .41527 .54484 L .41431 .54638 L F
.912 .752 .67 r
.42156 .56275 m .42287 .56673 L .42267 .5638 L F
.42156 .56275 m .42287 .56673 L .42267 .5638 L F
0 0 .274 r
.48703 .55276 m .48686 .55544 L .48538 .55703 L F
0 0 .187 r
.48686 .55544 m .48512 .55865 L .48538 .55703 L F
.762 .971 .693 r
.48311 .52813 m .48049 .53121 L .48128 .52928 L F
.974 .92 .671 r
.48049 .53121 m .47851 .53195 L .48128 .52928 L F
.48049 .53121 m .47925 .53296 L .47851 .53195 L F
.945 .695 .528 r
.37731 .55844 m .3797 .5571 L .37622 .55556 L F
.37731 .55844 m .37947 .55975 L .3797 .5571 L F
.574 .875 .994 r
.47245 .44683 m .4721 .44843 L .47417 .44743 L F
.889 .891 .825 r
.36815 .49237 m .36881 .49413 L .36626 .49458 L F
.833 .879 .877 r
.36881 .49413 m .36305 .49584 L .36626 .49458 L F
.831 .966 .892 r
.37036 .49089 m .36881 .49413 L .36815 .49237 L F
.37036 .49089 m .3724 .49099 L .36881 .49413 L F
.653 .854 .977 r
.6242 .3781 m .62571 .37561 L .62269 .37631 L F
.6242 .3781 m .62693 .37703 L .62571 .37561 L F
.69 .535 .671 r
.33707 .59342 m .33734 .59664 L .33362 .59652 L F
.616 .479 .672 r
.33985 .59312 m .33734 .59664 L .33707 .59342 L F
0 0 0 r
.6584 .33654 m .65587 .33931 L .65621 .33826 L F
.051 0 0 r
.69518 .29767 m .69751 .29666 L .69868 .29468 L F
0 0 0 r
.69868 .29468 m .69914 .29546 L .70047 .29573 L F
.69868 .29468 m .69751 .29666 L .69914 .29546 L F
.399 .836 .703 r
.681 .37594 m .6847 .37408 L .68311 .3747 L F
.658 .956 .741 r
.68311 .3747 m .6847 .37408 L .68667 .37214 L F
.318 .783 .938 r
.70047 .29573 m .70413 .29484 L .70509 .29573 L F
.685 .772 .917 r
.32403 .54306 m .32564 .54604 L .3284 .54399 L F
.975 .722 .307 r
.40023 .55658 m .39915 .55255 L .40054 .55389 L F
.645 .163 .093 r
.25967 .59973 m .25754 .60118 L .25531 .59926 L F
.908 .978 .787 r
.26115 .59573 m .25718 .59986 L .25967 .59973 L F
.993 .835 .583 r
.25718 .59986 m .25754 .60118 L .25967 .59973 L F
.452 .883 .829 r
.45765 .58376 m .46025 .583 L .45898 .58487 L F
.695 .74 .886 r
.56321 .42967 m .56723 .43089 L .56583 .42859 L F
.707 .734 .872 r
.56723 .43089 m .56321 .42967 L .56583 .42859 L F
.621 .953 .787 r
.46501 .43215 m .46097 .43449 L .46415 .43206 L F
.661 .969 .905 r
.46611 .43034 m .46826 .43025 L .46501 .43215 L F
.683 .975 .798 r
.46611 .43034 m .46501 .43215 L .46415 .43206 L F
.43 0 0 r
.33922 .54422 m .33593 .54406 L .3368 .5441 L F
.149 0 .236 r
.33741 .54539 m .33478 .54872 L .33593 .54406 L F
.967 .673 .419 r
.32401 .62165 m .32063 .61849 L .31959 .62081 L F
.424 .814 .584 r
.3214 .61787 m .32153 .61782 L .32063 .61849 L F
.967 .673 .419 r
.32401 .62165 m .3214 .61787 L .32063 .61849 L F
.726 .384 0 r
.3213 .6179 m .3214 .61787 L .32219 .62011 L F
.32069 .6164 m .3214 .61787 L .3213 .6179 L F
.424 .814 .584 r
.3214 .61787 m .32203 .61744 L .32153 .61782 L F
.3214 .61787 m .32429 .61581 L .32203 .61744 L F
.545 .333 .543 r
.53182 .39602 m .53442 .3956 L .53194 .39338 L F
.53182 .39602 m .53442 .3956 L .53194 .39338 L F
.794 .366 0 r
.57185 .38403 m .57179 .38253 L .57048 .38164 L F
.749 .286 0 r
.57046 .38266 m .57185 .38403 L .57048 .38164 L F
0 .287 .758 r
.57065 .38277 m .57185 .38403 L .57046 .38266 L F
.794 .366 0 r
.57185 .38403 m .57304 .38528 L .57179 .38253 L F
.87 .435 .159 r
.57042 .38092 m .57332 .38423 L .57046 .38266 L F
.693 .349 0 r
.57059 .38165 m .57151 .38376 L .571 .38243 L F
.57057 .38159 m .571 .38243 L .57042 .38092 L F
.57059 .38165 m .571 .38243 L .57057 .38159 L F
0 .287 .758 r
.57332 .38423 m .57185 .38403 L .57178 .38395 L F
.57137 .38316 m .57178 .38395 L .57065 .38277 L F
.57332 .38423 m .57178 .38395 L .57137 .38316 L F
.794 .366 0 r
.57185 .38403 m .57322 .38568 L .57304 .38528 L F
.512 .156 .298 r
.53494 .46028 m .53533 .4584 L .53282 .45848 L F
.471 .264 .517 r
.36363 .60468 m .36283 .60241 L .36551 .60259 L F
.36363 .60468 m .36282 .60607 L .36283 .60241 L F
.836 .998 .784 r
.49096 .41495 m .48951 .41691 L .4903 .41442 L F
.726 .921 .959 r
.4903 .41442 m .48951 .41691 L .48799 .41589 L F
.413 .815 .602 r
.54337 .44588 m .53977 .44831 L .54287 .44751 L F
.033 0 0 r
.54337 .44588 m .54287 .44751 L .54476 .44646 L F
.593 .54 .764 r
.62105 .41231 m .6244 .41208 L .62175 .41517 L F
.887 .678 .614 r
.38331 .56978 m .38281 .57246 L .386 .57339 L F
.918 .692 .581 r
.38273 .57549 m .386 .57339 L .38281 .57246 L F
.38273 .57549 m .3856 .57635 L .386 .57339 L F
.988 .838 .605 r
.30476 .6301 m .30701 .62912 L .30566 .62775 L F
.577 .404 .611 r
.2745 .59027 m .27705 .58992 L .27707 .58655 L F
.466 .315 .591 r
.27707 .58655 m .27982 .58906 L .2798 .58611 L F
.27707 .58655 m .27705 .58992 L .27982 .58906 L F
.946 .662 .467 r
.58131 .40326 m .5801 .40033 L .57966 .40205 L F
.932 .603 .39 r
.57995 .40362 m .58131 .40326 L .57966 .40205 L F
.57995 .40362 m .58158 .40568 L .58131 .40326 L F
.813 .441 .352 r
.38639 .48733 m .38345 .4851 L .38453 .48741 L F
.991 .87 .609 r
.42508 .53335 m .42412 .53626 L .42549 .53706 L F
.807 .59 .03 r
.42412 .53626 m .42463 .53962 L .42549 .53706 L F
.9 .726 .656 r
.67635 .35352 m .67791 .35784 L .67596 .35623 L F
.67635 .35352 m .67791 .35784 L .67596 .35623 L F
.376 .161 .455 r
.55647 .3966 m .55887 .39602 L .55902 .39332 L F
.508 .516 .8 r
.55647 .3966 m .55999 .39931 L .55887 .39602 L F
.141 .252 .719 r
.36308 .56031 m .36455 .55874 L .36217 .55663 L F
.587 .946 .889 r
.36455 .55874 m .36233 .56006 L .36308 .56031 L F
.283 .226 .615 r
.23606 .59526 m .23868 .5918 L .2386 .59155 L F
.23606 .59526 m .23952 .59464 L .23868 .5918 L F
.13 0 0 r
.45652 .59589 m .45565 .59641 L .45285 .59658 L F
0 0 0 r
.4591 .59481 m .45802 .59533 L .45652 .59589 L F
.45652 .59589 m .45802 .59533 L .45565 .59641 L F
.832 .71 .729 r
.5347 .40905 m .53675 .41187 L .53779 .40644 L F
.397 .292 .617 r
.53779 .40644 m .53675 .41187 L .54071 .40843 L F
.222 .456 .873 r
.5347 .40905 m .5377 .4103 L .53675 .41187 L F
.986 .737 .468 r
.54026 .41158 m .54071 .40843 L .53675 .41187 L F
.54026 .41158 m .53675 .41187 L .5377 .4103 L F
0 0 .379 r
.29289 .54818 m .29292 .55121 L .29291 .55122 L F
.29223 .55012 m .29291 .55122 L .2915 .55229 L F
.681 .133 0 r
.29163 .54859 m .29134 .54867 L .29277 .54972 L F
.29134 .54867 m .29178 .54938 L .29277 .54972 L F
.938 .778 .657 r
.29046 .54893 m .2915 .55229 L .29277 .54972 L F
0 0 .379 r
.29289 .54818 m .29291 .55122 L .29223 .55012 L F
.681 .133 0 r
.29134 .54867 m .29046 .54893 L .29178 .54938 L F
.186 .334 .781 r
.43492 .4847 m .43645 .48853 L .43753 .48621 L F
.573 .801 .986 r
.43753 .48621 m .43645 .48853 L .43913 .48773 L F
0 0 .077 r
.34217 .52405 m .3433 .52373 L .34438 .52112 L F
.786 .478 .466 r
.34438 .52112 m .3433 .52373 L .33994 .5229 L F
.547 .771 .981 r
.34243 .52227 m .3433 .52373 L .33994 .5229 L F
.54 .618 .879 r
.34229 .52497 m .34241 .52264 L .34243 .52227 L F
.786 .478 .466 r
.34245 .5219 m .33994 .5229 L .34243 .52227 L F
0 0 .196 r
.34243 .52227 m .34186 .51813 L .34339 .51908 L F
.34204 .51945 m .34248 .5212 L .34186 .51813 L F
.34243 .52227 m .34248 .5212 L .34204 .51945 L F
.786 .478 .466 r
.34438 .52112 m .34245 .5219 L .34243 .52227 L F
.997 .858 .541 r
.34438 .52112 m .34243 .52227 L .34339 .51908 L F
.54 .618 .879 r
.34241 .52264 m .34248 .5212 L .34243 .52227 L F
.708 .677 .817 r
.34198 .5269 m .3433 .52373 L .34217 .52405 L F
.34198 .5269 m .34581 .52738 L .3433 .52373 L F
.481 0 0 r
.3433 .52373 m .34229 .52497 L .34243 .52227 L F
.3433 .52373 m .34454 .52502 L .34229 .52497 L F
.3433 .52373 m .34767 .52567 L .34454 .52502 L F
.54 .618 .879 r
.34229 .52497 m .34454 .52502 L .34248 .5212 L F
0 .062 .625 r
.34248 .5212 m .34454 .52502 L .34393 .52309 L F
.816 .333 0 r
.34393 .52309 m .34282 .52252 L .34248 .5212 L F
.34282 .52252 m .34162 .52191 L .34248 .5212 L F
.358 .464 .832 r
.33396 .51362 m .33546 .51782 L .33725 .515 L F
.286 .702 .972 r
.33725 .515 m .33489 .51434 L .33396 .51362 L F
0 0 .43 r
.33297 .51478 m .33396 .51362 L .33298 .51286 L F
.616 .629 .84 r
.33264 .51774 m .33396 .51362 L .33297 .51478 L F
.33264 .51774 m .33546 .51782 L .33396 .51362 L F
.286 .702 .972 r
.33489 .51434 m .33274 .51374 L .33396 .51362 L F
0 0 .43 r
.33298 .51286 m .33396 .51362 L .33299 .51086 L F
.49 .709 .967 r
.28546 .64249 m .28891 .64393 L .28835 .64225 L F
.748 .836 .919 r
.28891 .64393 m .29079 .64017 L .28835 .64225 L F
.28891 .64393 m .29225 .64193 L .29079 .64017 L F
.205 0 0 r
.26288 .51944 m .26573 .51932 L .2657 .51817 L F
.26288 .51944 m .26077 .52073 L .26573 .51932 L F
.985 .898 .581 r
.48064 .5694 m .48073 .57258 L .4806 .57028 L F
.821 .34 .013 r
.27614 .59139 m .27705 .58992 L .2745 .59027 L F
0 0 0 r
.25609 .5217 m .25339 .52477 L .25516 .52304 L F
.475 .168 .365 r
.25516 .52304 m .25837 .52117 L .25609 .5217 L F
.757 .251 .007 r
.33992 .5788 m .34234 .57879 L .34024 .57666 L F
.467 .043 .15 r
.24131 .53261 m .24345 .53309 L .2439 .53154 L F
.357 0 .157 r
.24345 .53309 m .24758 .53006 L .2439 .53154 L F
.95 .809 .362 r
.39813 .49562 m .39872 .49704 L .39851 .4936 L F
.849 .885 .865 r
.41676 .51937 m .41913 .5199 L .41799 .51638 L F
.721 .717 .846 r
.41799 .51638 m .41913 .5199 L .42218 .51735 L F
0 0 0 r
.67369 .31064 m .67616 .30989 L .67707 .30843 L F
.005 0 .082 r
.67369 .31064 m .67543 .3113 L .67616 .30989 L F
.67369 .31064 m .67338 .31288 L .67543 .3113 L F
.566 .901 .66 r
.48311 .52813 m .48288 .52783 L .48472 .52644 L F
.48311 .52813 m .48128 .52928 L .48288 .52783 L F
.719 .988 .849 r
.61937 .37099 m .61731 .37154 L .61643 .37356 L F
.662 .955 .946 r
.61731 .37154 m .61399 .3732 L .61643 .37356 L F
.666 .2 .137 r
.32666 .54226 m .32876 .54065 L .3284 .53853 L F
.32666 .54226 m .33054 .54285 L .32876 .54065 L F
.598 .632 .856 r
.3284 .54399 m .32998 .54724 L .33272 .54595 L F
.989 .733 .369 r
.57824 .39998 m .5801 .40033 L .578 .3979 L F
.57824 .39998 m .57966 .40205 L .5801 .40033 L F
.733 .614 .725 r
.60369 .44242 m .60467 .43738 L .60291 .43806 L F
.154 .223 .683 r
.42233 .55023 m .42321 .5544 L .42436 .55316 L F
.487 .449 .74 r
.42321 .5544 m .42475 .55524 L .42436 .55316 L F
.42321 .5544 m .42652 .55628 L .42475 .55524 L F
.901 .486 .141 r
.58314 .42607 m .5807 .42286 L .58127 .4251 L F
.977 .724 .484 r
.58138 .42785 m .58314 .42607 L .58127 .4251 L F
.58138 .42785 m .58303 .42878 L .58314 .42607 L F
.722 .544 .649 r
.50964 .45112 m .50617 .44852 L .50712 .45234 L F
0 0 0 r
.4198 .45134 m .4184 .4515 L .41728 .45218 L F
.4198 .45134 m .42074 .4512 L .4184 .4515 L F
.326 .812 .815 r
.42792 .44904 m .4233 .45004 L .4259 .44932 L F
0 0 0 r
.42854 .44898 m .42792 .44904 L .4259 .44932 L F
.42854 .44898 m .43051 .4484 L .42792 .44904 L F
.53153 .41441 m .53321 .41246 L .52947 .41584 L F
.53483 .41168 m .53321 .41246 L .53153 .41441 L F
0 0 .313 r
.50971 .44581 m .51037 .44773 L .51245 .44569 L F
0 0 0 r
.6445 .39824 m .64845 .39576 L .64731 .39743 L F
.352 0 .119 r
.64845 .39576 m .65021 .39758 L .64731 .39743 L F
.64845 .39576 m .65109 .39542 L .65021 .39758 L F
.59 .167 .208 r
.45918 .56521 m .46197 .56559 L .46224 .56295 L F
.402 .852 .778 r
.46105 .5629 m .46224 .56295 L .46197 .56559 L F
.475 .291 .55 r
.43492 .4847 m .43858 .48395 L .43506 .48174 L F
.48 .792 .999 r
.43858 .48395 m .43492 .4847 L .43506 .48174 L F
.44 .167 .401 r
.52038 .43974 m .51877 .43904 L .51746 .44185 L F
.748 .701 .807 r
.52038 .43974 m .51746 .44185 L .51877 .43904 L F
.731 .538 0 r
.25971 .62431 m .25992 .62578 L .25945 .62161 L F
.679 .487 .62 r
.25992 .62578 m .26016 .62859 L .25875 .62888 L F
.731 .538 0 r
.25971 .62431 m .25992 .62578 L .25945 .62161 L F
0 0 .074 r
.26009 .62732 m .25992 .62578 L .25971 .62431 L F
.972 .923 .61 r
.33299 .51086 m .33317 .50656 L .33526 .50792 L F
.74 .337 .288 r
.33299 .51086 m .33012 .51277 L .33143 .51259 L F
.972 .923 .61 r
.33299 .51086 m .33143 .51259 L .33145 .51251 L F
.74 .337 .288 r
.33299 .51086 m .33396 .51362 L .33103 .51297 L F
.33299 .51086 m .33145 .51251 L .33028 .51266 L F
.33145 .51251 m .33145 .51251 L .33139 .51252 L F
.33145 .51251 m .33139 .51252 L .33028 .51266 L F
0 0 .171 r
.33012 .51277 m .32897 .50776 L .33139 .51252 L F
.33012 .51277 m .33139 .51252 L .33143 .51259 L F
.868 .765 .746 r
.33317 .50656 m .33145 .51251 L .32897 .50776 L F
.33145 .51251 m .33143 .51259 L .33139 .51252 L F
.33145 .51251 m .33139 .51252 L .32897 .50776 L F
.74 .337 .288 r
.33028 .51266 m .33103 .51297 L .33012 .51277 L F
.33145 .51251 m .33103 .51297 L .33028 .51266 L F
.972 .923 .61 r
.33299 .51086 m .33145 .51251 L .33317 .50656 L F
0 0 0 r
.50913 .51614 m .51008 .51431 L .51158 .51271 L F
.16 .609 .934 r
.25037 .55155 m .24953 .55221 L .24686 .55034 L F
0 .528 .705 r
.60204 .34444 m .60491 .34468 L .60625 .3448 L F
.121 .672 .761 r
.60491 .34468 m .60895 .34441 L .60625 .3448 L F
.351 .818 .742 r
.35955 .5346 m .35811 .53539 L .36126 .53683 L F
.782 .371 0 r
.36126 .53683 m .36066 .5365 L .35955 .5346 L F
.994 .761 .465 r
.33922 .54422 m .3381 .54541 L .33741 .54539 L F
.725 .605 .723 r
.62439 .39644 m .62571 .40033 L .62175 .3997 L F
.713 .64 .774 r
.62571 .40033 m .62175 .3997 L .6246 .40198 L F
.624 .831 .98 r
.6214 .40236 m .6232 .40072 L .62092 .40195 L F
.62215 .40301 m .62251 .40223 L .6214 .40236 L F
.62251 .40223 m .6232 .40072 L .6214 .40236 L F
.713 .64 .774 r
.62517 .40191 m .6246 .40198 L .62503 .40232 L F
.62571 .40033 m .6246 .40198 L .62517 .40191 L F
.392 .324 .661 r
.34239 .59592 m .34383 .59921 L .34139 .59963 L F
.372 .239 .568 r
.34383 .59921 m .34347 .60135 L .34139 .59963 L F
.122 .524 .914 r
.52976 .47362 m .52668 .47175 L .52869 .47489 L F
.912 .633 .138 r
.5955 .36748 m .59636 .36721 L .59318 .36677 L F
.5955 .36748 m .59654 .36947 L .59636 .36721 L F
.221 0 .244 r
.52443 .47261 m .52668 .47175 L .52795 .46898 L F
.193 0 0 r
.63176 .33804 m .63456 .33749 L .63531 .33665 L F
0 0 0 r
.65772 .37937 m .65538 .38074 L .65401 .38206 L F
.303 .726 .972 r
.45609 .58587 m .45784 .58692 L .45383 .58604 L F
.417 .647 .953 r
.45898 .58487 m .45784 .58692 L .45609 .58587 L F
.45898 .58487 m .46088 .58696 L .45784 .58692 L F
.184 0 .221 r
.66127 .3334 m .6584 .33654 L .65896 .33459 L F
.267 0 .213 r
.38453 .48741 m .38171 .48872 L .38126 .49053 L F
.256 0 .269 r
.34942 .5897 m .34859 .59233 L .34655 .5929 L F
.34655 .5929 m .34859 .59233 L .34942 .5897 L F
.538 .225 .385 r
.34942 .5897 m .35165 .59183 L .35181 .58911 L F
.34942 .5897 m .34859 .59233 L .35165 .59183 L F
.34942 .5897 m .35165 .59183 L .35181 .58911 L F
.34942 .5897 m .34859 .59233 L .35165 .59183 L F
.449 .337 .634 r
.53182 .39865 m .52912 .39673 L .53182 .39602 L F
.53182 .39865 m .52953 .39979 L .52912 .39673 L F
.53182 .39865 m .52912 .39673 L .53182 .39602 L F
.53182 .39865 m .52953 .39979 L .52912 .39673 L F
.318 .509 .886 r
.55805 .37744 m .56035 .38021 L .56133 .37827 L F
.277 .111 .467 r
.56035 .38021 m .5598 .38303 L .56072 .38247 L F
0 0 .015 r
.70828 .29824 m .7083 .29983 L .70604 .30169 L F
.849 .892 .869 r
.7083 .29983 m .70663 .30416 L .70604 .30169 L F
.79 .481 .466 r
.33362 .59652 m .3291 .59782 L .33133 .59484 L F
.744 .946 .947 r
.32685 .51747 m .32822 .51492 L .32947 .51685 L F
.32685 .51747 m .32526 .51679 L .32822 .51492 L F
.749 .722 .827 r
.49374 .45278 m .49481 .44789 L .49218 .45083 L F
.49374 .45278 m .49581 .45178 L .49481 .44789 L F
.908 .904 .808 r
.70305 .32874 m .70346 .33191 L .70421 .3302 L F
.885 .909 .839 r
.70115 .33166 m .70346 .33191 L .70305 .32874 L F
.70115 .33166 m .70236 .33318 L .70346 .33191 L F
.985 .898 .581 r
.48064 .5694 m .47951 .57243 L .48073 .57258 L F
0 0 .226 r
.47951 .57243 m .47912 .57632 L .48073 .57258 L F
.402 .074 .291 r
.34056 .56631 m .34307 .56583 L .34368 .56378 L F
.538 .198 .34 r
.34307 .56583 m .34579 .56575 L .34368 .56378 L F
0 .448 .844 r
.47325 .53913 m .47469 .54048 L .47067 .5392 L F
.901 .498 .228 r
.35549 .51474 m .35606 .5167 L .35799 .51753 L F
.895 .498 .259 r
.35655 .51901 m .35799 .51753 L .35606 .5167 L F
.35655 .51901 m .35923 .52051 L .35799 .51753 L F
.92 .711 .218 r
.58409 .43415 m .58468 .43259 L .58327 .4313 L F
.58409 .43415 m .58467 .43523 L .58468 .43259 L F
.884 .84 .797 r
.34909 .57349 m .34743 .57631 L .34463 .57565 L F
0 0 .281 r
.34743 .57631 m .34806 .57851 L .34819 .57745 L F
0 0 0 r
.67701 .34243 m .67758 .34114 L .67382 .34412 L F
.849 .904 .873 r
.67635 .33921 m .6805 .33815 L .67758 .34114 L F
.855 .893 .862 r
.68066 .3348 m .6805 .33815 L .67732 .33896 L F
.67683 .33872 m .67732 .33896 L .67635 .33921 L F
.67725 .33829 m .6773 .33882 L .67683 .33872 L F
.6773 .33882 m .67732 .33896 L .67683 .33872 L F
.67735 .33818 m .67732 .33896 L .67725 .33829 L F
.68066 .3348 m .6784 .33762 L .67735 .33818 L F
.6784 .33762 m .67732 .33896 L .67735 .33818 L F
.826 .811 .836 r
.68066 .3348 m .67635 .33921 L .67745 .33483 L F
.824 .809 .836 r
.67745 .33483 m .67635 .33921 L .67728 .33887 L F
.67745 .33483 m .6773 .33821 L .6748 .33817 L F
.6773 .33821 m .67728 .33887 L .67649 .33865 L F
.6773 .33821 m .67649 .33865 L .6748 .33817 L F
.929 .779 .306 r
.67728 .33887 m .67648 .33978 L .67495 .33831 L F
.67649 .33865 m .67495 .33831 L .6748 .33817 L F
.67728 .33887 m .67495 .33831 L .67649 .33865 L F
.849 .904 .873 r
.67635 .33921 m .67758 .34114 L .67728 .33887 L F
.902 .761 .266 r
.67728 .33887 m .67743 .33999 L .67701 .34243 L F
.67743 .33999 m .67758 .34114 L .67755 .3412 L F
.67743 .33999 m .67755 .3412 L .67701 .34243 L F
.473 0 .036 r
.26573 .51932 m .26729 .51951 L .2657 .51817 L F
.353 .021 .256 r
.2657 .51817 m .26729 .51951 L .26789 .51787 L F
.799 .737 .794 r
.29469 .64139 m .29665 .64494 L .29821 .64106 L F
.283 .437 .839 r
.32717 .53422 m .32876 .53311 L .32685 .5301 L F
.651 .224 .219 r
.32717 .53422 m .32563 .53632 L .32948 .53625 L F
.849 .627 .602 r
.42038 .51664 m .42218 .51735 L .42242 .51455 L F
.653 .892 .982 r
.30406 .52683 m .3023 .52819 L .30223 .52585 L F
0 0 0 r
.3023 .52819 m .30406 .52683 L .30223 .52585 L F
.3023 .52819 m .30128 .53006 L .30406 .52683 L F
.30406 .52683 m .30128 .53006 L .3023 .52819 L F
.49471 .5372 m .49394 .53914 L .49229 .54068 L F
0 0 .16 r
.49394 .53914 m .49161 .54265 L .49229 .54068 L F
.798 .632 .676 r
.42961 .54999 m .43214 .55326 L .43097 .55097 L F
.924 .974 .709 r
.40858 .50246 m .4075 .50485 L .4074 .50288 L F
0 0 .3 r
.4075 .50485 m .40812 .50659 L .4074 .50288 L F
.424 .095 .301 r
.4075 .50485 m .40569 .50714 L .40812 .50659 L F
.955 .894 .727 r
.70028 .33735 m .70236 .33318 L .70115 .33166 L F
.867 .977 .676 r
.69584 .36608 m .69843 .36335 L .69788 .36225 L F
.69584 .36608 m .69619 .36682 L .69843 .36335 L F
.84 .773 .787 r
.49481 .44789 m .49581 .45178 L .49685 .44922 L F
.619 .635 .844 r
.70245 .28564 m .70339 .2889 L .70613 .2879 L F
.915 .539 .295 r
.40198 .58679 m .40035 .58702 L .40026 .58518 L F
.40198 .58679 m .40264 .58937 L .40035 .58702 L F
.716 .784 .906 r
.59675 .34418 m .59568 .34459 L .59957 .3439 L F
.183 0 0 r
.59276 .34614 m .59491 .3456 L .59568 .34459 L F
.645 .96 .783 r
.59491 .3456 m .59465 .34523 L .59533 .34467 L F
.59583 .34457 m .59533 .34467 L .59697 .3433 L F
.59491 .3456 m .59533 .34467 L .59583 .34457 L F
.077 0 0 r
.59719 .34432 m .59824 .34415 L .59957 .3439 L F
.59568 .34459 m .5967 .34441 L .59719 .34432 L F
.5967 .34441 m .59824 .34415 L .59719 .34432 L F
.456 .876 .761 r
.66024 .38912 m .662 .38783 L .65953 .38909 L F
.66024 .38912 m .66361 .3874 L .662 .38783 L F
.308 .705 .978 r
.55663 .44793 m .55999 .44926 L .55916 .44813 L F
.55663 .44793 m .55999 .44926 L .55916 .44813 L F
.807 .969 .906 r
.5638 .44618 m .56001 .44924 L .55916 .44813 L F
.135 .226 .694 r
.55882 .44435 m .55916 .44813 L .55687 .44565 L F
.807 .969 .906 r
.5638 .44618 m .55916 .44813 L .56196 .44419 L F
.831 .772 .796 r
.56196 .44419 m .55916 .44813 L .55882 .44435 L F
0 .305 .766 r
.55823 .4469 m .55916 .44813 L .56171 .44952 L F
.55786 .44663 m .55916 .44813 L .55823 .4469 L F
.807 .969 .906 r
.56001 .44924 m .55999 .44926 L .55916 .44813 L F
0 .079 .637 r
.55999 .44926 m .56171 .44952 L .55916 .44813 L F
.55999 .44926 m .56131 .45088 L .56171 .44952 L F
.314 .755 .965 r
.71738 .324 m .72137 .32455 L .7204 .32381 L F
.582 .909 .665 r
.72137 .32455 m .72464 .32174 L .72322 .32255 L F
.6 .916 .976 r
.7204 .32381 m .72137 .32455 L .72322 .32255 L F
.998 .853 .543 r
.36402 .50154 m .36238 .50331 L .36354 .50179 L F
.763 .342 .251 r
.36484 .50343 m .36238 .50331 L .36402 .50154 L F
.958 .856 .698 r
.58172 .45499 m .58295 .45248 L .58132 .45115 L F
.268 .723 .955 r
.43204 .45826 m .42767 .45693 L .42925 .45639 L F
.971 .931 .666 r
.35902 .63859 m .36086 .63587 L .35988 .63359 L F
.852 .98 .863 r
.72168 .30841 m .71866 .31151 L .71801 .3103 L F
.244 0 0 r
.37036 .49089 m .37388 .49129 L .3724 .49099 L F
.101 .262 .743 r
.23032 .56642 m .23156 .57069 L .23269 .56833 L F
.396 .464 .813 r
.23235 .57254 m .23269 .56833 L .23156 .57069 L F
.397 .292 .617 r
.53779 .40644 m .54071 .40843 L .54246 .4043 L F
.558 .92 .95 r
.23673 .57493 m .23392 .57628 L .23695 .57534 L F
.695 .163 0 r
.23673 .57493 m .23235 .57254 L .23392 .57628 L F
.577 .004 0 r
.23673 .57493 m .23904 .57601 L .23582 .57508 L F
.23673 .57493 m .23582 .57508 L .23432 .57465 L F
.689 .446 .55 r
.23741 .57482 m .23673 .57493 L .23695 .57534 L F
.23912 .57288 m .23673 .57493 L .23741 .57482 L F
.808 .516 .495 r
.38399 .49011 m .38639 .48733 L .38453 .48741 L F
.38399 .49011 m .38846 .49103 L .38639 .48733 L F
.738 .499 .567 r
.38639 .48733 m .38846 .49103 L .38841 .48825 L F
.423 0 0 r
.64644 .34086 m .64494 .34026 L .64387 .33964 L F
0 0 .359 r
.64644 .34086 m .64797 .34119 L .64494 .34026 L F
.64644 .34086 m .64718 .34274 L .64797 .34119 L F
0 0 0 r
.67707 .30843 m .67857 .30868 L .67928 .30654 L F
.67707 .30843 m .67616 .30989 L .67857 .30868 L F
0 0 .269 r
.55414 .46534 m .55468 .46561 L .55607 .46342 L F
.55414 .46534 m .55471 .46825 L .55468 .46561 L F
.669 .287 0 r
.42203 .57404 m .42444 .57881 L .42268 .57633 L F
.854 .497 .376 r
.39313 .53737 m .39124 .53908 L .39134 .53647 L F
.39313 .53737 m .39468 .54063 L .39124 .53908 L F
.73 .968 .708 r
.50502 .40458 m .50373 .40626 L .50486 .40415 L F
.651 .921 .976 r
.50373 .40626 m .50243 .40545 L .50486 .40415 L F
.856 .714 .705 r
.71287 .31058 m .71461 .30839 L .71268 .30693 L F
.868 .924 .533 r
.48659 .52257 m .48801 .52102 L .48682 .52302 L F
.846 .993 .74 r
.49057 .51769 m .48801 .52102 L .48851 .51877 L F
.83 .923 .534 r
.48851 .51877 m .48801 .52102 L .48659 .52257 L F
.846 .446 .285 r
.42347 .59886 m .42152 .60062 L .42213 .59949 L F
.485 0 0 r
.42347 .59886 m .42422 .60084 L .42152 .60062 L F
.052 .129 .625 r
.42977 .59156 m .42837 .59076 L .43119 .58963 L F
.42977 .59156 m .43119 .58963 L .42699 .58915 L F
.661 .176 .089 r
.43119 .58963 m .42865 .59005 L .42775 .58924 L F
.606 .947 .927 r
.43222 .58799 m .42865 .59005 L .43119 .58963 L F
.429 .248 .531 r
.43222 .58799 m .42997 .59126 L .42865 .59005 L F
.42997 .59126 m .42977 .59156 L .42865 .59005 L F
.661 .176 .089 r
.42775 .58924 m .42865 .59005 L .42699 .58915 L F
.606 .947 .927 r
.43222 .58799 m .43119 .58963 L .43301 .58906 L F
.716 .98 .773 r
.36185 .49611 m .36035 .49793 L .3611 .4964 L F
.848 .995 .756 r
.36185 .49611 m .36374 .49284 L .36305 .49584 L F
.36185 .49611 m .3611 .4964 L .36374 .49284 L F
.723 .929 .595 r
.36374 .49284 m .3611 .4964 L .36197 .49452 L F
.04 .23 .731 r
.3611 .4964 m .36339 .49833 L .362 .49459 L F
.3611 .4964 m .362 .49459 L .36197 .49452 L F
.716 .98 .773 r
.36035 .49793 m .36008 .49826 L .3611 .4964 L F
.83 .404 .226 r
.36008 .49826 m .35834 .49952 L .3611 .4964 L F
.36008 .49826 m .36354 .50179 L .35834 .49952 L F
.884 .84 .797 r
.34909 .57349 m .34463 .57565 L .3454 .5734 L F
.682 .643 .805 r
.35211 .57041 m .35211 .57365 L .34909 .57349 L F
.216 0 0 r
.34909 .57349 m .34949 .57413 L .3489 .57496 L F
.34909 .57349 m .35211 .57365 L .34949 .57413 L F
.533 0 0 r
.60702 .4206 m .60622 .41947 L .60487 .41833 L F
.60702 .4206 m .60951 .42153 L .60622 .41947 L F
.78 .979 .709 r
.56217 .42283 m .55992 .42568 L .56053 .42375 L F
.566 .494 .733 r
.55992 .42568 m .56304 .42946 L .56164 .42842 L F
.56304 .42946 m .56321 .42967 L .56164 .42842 L F
.821 .835 .86 r
.56164 .42842 m .55816 .42882 L .5602 .42736 L F
.56164 .42842 m .5602 .42736 L .56088 .42688 L F
0 0 .541 r
.56053 .42375 m .55992 .42568 L .56164 .42842 L F
0 .372 .799 r
.35842 .55444 m .35765 .55468 L .35818 .55447 L F
.865 .972 .858 r
.57706 .36749 m .57435 .37034 L .57408 .36878 L F
.94 .653 .191 r
.57525 .37278 m .57408 .36878 L .57435 .37034 L F
.351 .818 .742 r
.35955 .5346 m .35626 .53595 L .35811 .53539 L F
.766 .721 .811 r
.55637 .41496 m .55954 .41726 L .55979 .41283 L F
.4 .402 .746 r
.55979 .41283 m .55954 .41726 L .56222 .41411 L F
.542 .477 .732 r
.35855 .61793 m .35706 .62343 L .3556 .61887 L F
.498 0 0 r
.60988 .37452 m .61208 .37569 L .6119 .37268 L F
.60988 .37452 m .60783 .3753 L .61208 .37569 L F
.022 0 .037 r
.58849 .37092 m .58838 .37141 L .59071 .36942 L F
.956 .9 .728 r
.38093 .60382 m .3819 .60578 L .38342 .60307 L F
.996 .863 .576 r
.38225 .60063 m .38188 .60207 L .38342 .60307 L F
.921 .957 .791 r
.38188 .60207 m .38093 .60382 L .38342 .60307 L F
.952 .679 .228 r
.37784 .51731 m .37664 .51356 L .37868 .51502 L F
.37784 .51731 m .37697 .51644 L .37664 .51356 L F
.755 .244 0 r
.37902 .5178 m .37697 .51644 L .37784 .51731 L F
.123 .3 .771 r
.56427 .37488 m .56463 .37712 L .56374 .3769 L F
.58 .311 .474 r
.31791 .56384 m .31922 .566 L .32024 .56356 L F
0 0 .505 r
.31759 .56214 m .31922 .566 L .31791 .56384 L F
.028 0 0 r
.54218 .41211 m .54166 .41259 L .53904 .41305 L F
.559 .846 .517 r
.54379 .41023 m .54218 .41211 L .54573 .40984 L F
.54379 .41023 m .54166 .41259 L .54218 .41211 L F
0 0 .195 r
.55902 .39332 m .55887 .39602 L .5599 .39107 L F
.446 0 0 r
.61906 .39433 m .62032 .39322 L .61608 .39306 L F
.053 0 .174 r
.62286 .38972 m .62032 .39322 L .62272 .39206 L F
0 0 0 r
.62272 .39206 m .62032 .39322 L .61906 .39433 L F
.268 .723 .955 r
.43204 .45826 m .43061 .45699 L .42767 .45693 L F
.06 .286 .775 r
.43204 .45826 m .43326 .45571 L .43061 .45699 L F
.346 .036 .289 r
.43596 .45594 m .43582 .4567 L .43204 .45826 L F
.43582 .4567 m .4353 .45962 L .43307 .45869 L F
.43582 .4567 m .43307 .45869 L .43204 .45826 L F
.06 .286 .775 r
.43204 .45826 m .43307 .45869 L .43326 .45571 L F
.43307 .45869 m .4353 .45962 L .43436 .45782 L F
.43307 .45869 m .43436 .45782 L .43326 .45571 L F
.127 0 0 r
.4427 .45488 m .44153 .45491 L .43863 .45466 L F
.971 .86 .672 r
.43863 .45466 m .4353 .45962 L .43596 .45594 L F
.43863 .45466 m .43491 .45743 L .4353 .45962 L F
.965 .868 .691 r
.43436 .45782 m .43445 .45486 L .43326 .45571 L F
.4353 .45962 m .43491 .45743 L .43436 .45782 L F
.43491 .45743 m .43445 .45486 L .43436 .45782 L F
.992 .75 .458 r
.43326 .45571 m .43437 .45965 L .43284 .45849 L F
.43326 .45571 m .43437 .45965 L .43284 .45849 L F
.971 .86 .672 r
.43491 .45743 m .43379 .45827 L .4353 .45962 L F
0 0 0 r
.43491 .45743 m .43469 .4576 L .43491 .45743 L F
.43471 .45758 m .43469 .4576 L .43491 .45743 L F
.43531 .45715 m .43491 .45743 L .43809 .45507 L F
.965 .868 .691 r
.4353 .45962 m .43454 .45479 L .43445 .45486 L F
.43495 .4574 m .43379 .45827 L .43454 .45479 L F
.4353 .45962 m .43379 .45827 L .43495 .4574 L F
0 0 0 r
.43496 .45741 m .43471 .45758 L .43491 .45743 L F
.43496 .45741 m .43491 .45743 L .43531 .45715 L F
.44005 .45371 m .43863 .45466 L .44153 .45491 L F
.44005 .45371 m .43496 .45741 L .43809 .45507 L F
.43496 .45741 m .43379 .45827 L .43469 .4576 L F
.43888 .45449 m .43809 .45507 L .43863 .45466 L F
.44005 .45371 m .43809 .45507 L .43888 .45449 L F
0 0 .372 r
.57751 .38848 m .57833 .39236 L .57848 .38988 L F
.821 .372 .168 r
.37612 .51119 m .37387 .5107 L .37215 .50809 L F
.83 .391 .191 r
.37612 .51119 m .37454 .51254 L .37387 .5107 L F
.912 .532 .284 r
.37612 .51119 m .37664 .51356 L .37454 .51254 L F
.438 .862 .73 r
.64782 .33123 m .64871 .33036 L .64992 .32948 L F
.64782 .33123 m .64624 .33176 L .64871 .33036 L F
0 0 .115 r
.53032 .46516 m .52795 .46898 L .52988 .46759 L F
.057 0 .149 r
.52795 .46898 m .52668 .47175 L .52988 .46759 L F
.726 .519 .611 r
.38846 .49103 m .39192 .48816 L .38841 .48825 L F
.717 .724 .856 r
.46392 .57479 m .46177 .57626 L .46207 .57333 L F
.895 .753 .698 r
.41321 .45758 m .4113 .45787 L .4101 .4534 L F
.804 .821 .865 r
.41728 .45218 m .41321 .45758 L .41259 .45234 L F
0 0 0 r
.51872 .42896 m .52185 .42628 L .5216 .42794 L F
.798 .599 .632 r
.52418 .42535 m .5216 .42794 L .52185 .42628 L F
.441 .195 .444 r
.59074 .3671 m .59071 .36942 L .59318 .36677 L F
.659 .858 .976 r
.60345 .35743 m .60925 .35753 L .60818 .35632 L F
.998 .847 .535 r
.60797 .35121 m .60803 .35278 L .60925 .35753 L F
.57 .516 .755 r
.61402 .34926 m .60797 .35121 L .6133 .34991 L F
.982 .845 .63 r
.60677 .3549 m .60818 .35632 L .60797 .35121 L F
.60677 .3549 m .60797 .35121 L .60762 .35108 L F
.981 .706 .424 r
.60797 .35121 m .60911 .35494 L .60762 .35108 L F
.471 .888 .92 r
.61586 .34893 m .6133 .34991 L .6142 .35017 L F
.232 0 0 r
.61586 .34893 m .61402 .34926 L .6133 .34991 L F
.57 .516 .755 r
.61402 .34926 m .60911 .35494 L .60797 .35121 L F
.75 .808 .898 r
.60858 .35074 m .61402 .34926 L .61043 .34892 L F
0 0 0 r
.61043 .34892 m .60919 .35041 L .60858 .35074 L F
0 .155 .683 r
.60772 .3512 m .60911 .35494 L .60858 .35074 L F
.60774 .35137 m .60911 .35494 L .60767 .35106 L F
.75 .808 .898 r
.60858 .35074 m .60911 .35494 L .61402 .34926 L F
0 .155 .683 r
.60767 .35106 m .60772 .3512 L .60858 .35074 L F
.60762 .35108 m .60774 .35137 L .60767 .35106 L F
.061 0 0 r
.60858 .35074 m .60677 .3549 L .60762 .35108 L F
.998 .847 .535 r
.60803 .35278 m .60818 .35632 L .60896 .3572 L F
.60803 .35278 m .60896 .3572 L .60925 .35753 L F
.061 0 0 r
.60858 .35074 m .60508 .35304 L .60677 .3549 L F
.53 .41 .661 r
.61007 .35133 m .60783 .35486 L .60703 .35293 L F
0 0 0 r
.60919 .35041 m .60746 .35248 L .60858 .35074 L F
.60746 .35248 m .60745 .35249 L .60858 .35074 L F
.061 0 0 r
.60858 .35074 m .6078 .35195 L .60508 .35304 L F
.6078 .35195 m .6072 .35255 L .60508 .35304 L F
.60745 .35249 m .60743 .3525 L .60508 .35304 L F
.324 .461 .844 r
.60508 .35304 m .60743 .3525 L .60615 .35081 L F
0 0 .483 r
.60615 .35081 m .60588 .35241 L .60508 .35304 L F
.271 .612 .956 r
.60508 .35304 m .60588 .35241 L .60068 .35104 L F
.216 .604 .95 r
.60068 .35104 m .60588 .35241 L .60499 .35138 L F
.99 .869 .618 r
.60615 .35081 m .60476 .35049 L .60441 .34994 L F
.915 .915 .802 r
.60409 .35033 m .60409 .35033 L .60429 .35038 L F
.60409 .35033 m .60429 .35038 L .60429 .35037 L F
.60409 .35033 m .60588 .35241 L .60615 .35081 L F
.216 .604 .95 r
.60352 .35044 m .60423 .35089 L .60409 .35033 L F
.60423 .35089 m .60499 .35138 L .60426 .35052 L F
.60423 .35089 m .60426 .35052 L .60409 .35033 L F
.60068 .35104 m .60499 .35138 L .60352 .35044 L F
.271 .612 .956 r
.60508 .35304 m .60068 .35104 L .60217 .35398 L F
.915 .915 .802 r
.60409 .35033 m .60429 .35037 L .60441 .34994 L F
.77 .762 .251 r
.60441 .34994 m .60429 .35038 L .60429 .35037 L F
.915 .915 .802 r
.60429 .35037 m .60615 .35081 L .60441 .34994 L F
.77 .762 .251 r
.60441 .34994 m .60429 .35037 L .60437 .34997 L F
.60429 .35004 m .60356 .35303 L .60413 .35018 L F
.60437 .34997 m .60427 .35036 L .60429 .35004 L F
.60427 .35036 m .60356 .35303 L .60429 .35004 L F
.60429 .35038 m .60356 .35303 L .60437 .34997 L F
.915 .915 .802 r
.60429 .35037 m .60429 .35038 L .60615 .35081 L F
.99 .869 .618 r
.60615 .35081 m .6054 .35146 L .60476 .35049 L F
.6054 .35146 m .60356 .35303 L .60426 .35048 L F
.6054 .35146 m .60426 .35048 L .60441 .34994 L F
.216 .604 .95 r
.60408 .35033 m .60409 .35033 L .60409 .35033 L F
.60352 .35044 m .60409 .35033 L .60408 .35033 L F
.891 .686 .62 r
.60697 .35278 m .60475 .35404 L .60571 .35183 L F
.60688 .35257 m .60571 .35183 L .60615 .35081 L F
.60697 .35278 m .60571 .35183 L .60688 .35257 L F
.60783 .35486 m .60551 .35424 L .60697 .35278 L F
.60551 .35424 m .60475 .35404 L .60697 .35278 L F
.061 0 0 r
.6078 .35195 m .60745 .35249 L .6072 .35255 L F
.53 .41 .661 r
.60745 .35249 m .60744 .3525 L .60743 .3525 L F
.061 0 0 r
.60745 .35249 m .60744 .3525 L .60743 .3525 L F
.53 .41 .661 r
.60746 .35248 m .60745 .35249 L .60615 .35081 L F
.61007 .35133 m .60703 .35293 L .60872 .35115 L F
0 0 0 r
.60746 .35248 m .60744 .3525 L .60745 .35249 L F
.8 .614 .651 r
.60615 .35081 m .60744 .3525 L .60746 .35248 L F
.60615 .35081 m .60746 .35248 L .61043 .34892 L F
.53 .41 .661 r
.60872 .35115 m .60746 .35248 L .60615 .35081 L F
.60745 .35249 m .60743 .3525 L .60615 .35081 L F
.324 .461 .844 r
.60743 .3525 m .60744 .3525 L .60615 .35081 L F
.53 .41 .661 r
.60744 .3525 m .60703 .35293 L .60615 .35081 L F
.691 .465 .575 r
.53532 .42633 m .53738 .42296 L .5355 .4241 L F
.319 .057 .35 r
.32073 .57007 m .3234 .56925 L .32342 .56703 L F
.641 .966 .843 r
.54824 .48275 m .54813 .48164 L .54633 .48329 L F
.54824 .48275 m .55039 .48118 L .54813 .48164 L F
.941 .789 .664 r
.33714 .58305 m .33665 .58654 L .3386 .58664 L F
.725 .711 .837 r
.33714 .58305 m .3386 .58664 L .34023 .58553 L F
.491 .007 .033 r
.33665 .58654 m .34023 .58553 L .3386 .58664 L F
.506 0 0 r
.34085 .51696 m .3402 .5167 L .3397 .51708 L F
.34085 .51696 m .34339 .51908 L .3402 .5167 L F
.961 .764 .593 r
.38495 .58862 m .38679 .58973 L .38546 .58587 L F
.856 .551 .471 r
.3848 .59165 m .38679 .58973 L .38495 .58862 L F
.3848 .59165 m .38735 .59281 L .38679 .58973 L F
.466 .494 .804 r
.34239 .59592 m .33985 .59312 L .3411 .5922 L F
.438 .108 .308 r
.34655 .5929 m .34239 .59592 L .3411 .5922 L F
.564 .933 .913 r
.30593 .57819 m .30976 .57687 L .30874 .57934 L F
.855 .854 .84 r
.30812 .57626 m .30976 .57687 L .31169 .57355 L F
.932 .733 .611 r
.30874 .57934 m .30976 .57687 L .30812 .57626 L F
.825 .815 .84 r
.56887 .45335 m .56574 .45218 L .56753 .45132 L F
.671 .757 .915 r
.56753 .45132 m .57143 .45211 L .56887 .45335 L F
.986 .896 .575 r
.59198 .40612 m .59001 .40757 L .59091 .40484 L F
.59198 .40612 m .59109 .40939 L .59001 .40757 L F
.644 .965 .901 r
.69187 .36821 m .69619 .36682 L .69584 .36608 L F
.955 .662 .439 r
.30433 .63823 m .3047 .63584 L .30217 .63729 L F
.859 .986 .71 r
.62324 .40633 m .62072 .40971 L .62149 .40731 L F
.21 .359 .796 r
.62215 .40301 m .62324 .40633 L .62443 .40416 L F
.734 .972 .717 r
.62443 .40416 m .62324 .40633 L .62149 .40731 L F
.86 .938 .872 r
.53103 .49316 m .53257 .49362 L .53193 .49178 L F
.814 .976 .896 r
.53257 .49362 m .53446 .49041 L .53193 .49178 L F
.53257 .49362 m .53565 .49102 L .53446 .49041 L F
.617 .884 .559 r
.49344 .51445 m .49057 .51769 L .49184 .51593 L F
.648 .95 .73 r
.49184 .51593 m .49057 .51769 L .48851 .51877 L F
.459 .878 .761 r
.662 .38783 m .66361 .3874 L .66599 .38604 L F
.808 .32 0 r
.37215 .50809 m .37018 .50715 L .3684 .5044 L F
.823 .346 .031 r
.37215 .50809 m .37112 .50908 L .37018 .50715 L F
.37215 .50809 m .37387 .5107 L .37112 .50908 L F
.052 .129 .625 r
.42977 .59156 m .42847 .59359 L .42837 .59076 L F
.483 .714 .972 r
.42977 .59156 m .43119 .59353 L .42847 .59359 L F
.837 .889 .878 r
.49685 .44922 m .49837 .44818 L .49704 .44676 L F
.692 .929 .968 r
.49837 .44818 m .50037 .44506 L .49704 .44676 L F
.49837 .44818 m .50181 .44622 L .50037 .44506 L F
.838 .623 .612 r
.37593 .55025 m .37622 .55556 L .37797 .55348 L F
.726 .519 .611 r
.38846 .49103 m .39213 .49103 L .39192 .48816 L F
0 0 .339 r
.39192 .48816 m .39302 .48916 L .39401 .48724 L F
.39192 .48816 m .39213 .49103 L .39302 .48916 L F
.542 .604 .864 r
.31631 .63703 m .31487 .63611 L .31807 .63578 L F
.131 0 0 r
.31561 .63681 m .31807 .63578 L .31487 .63611 L F
.529 .911 .763 r
.31961 .63469 m .31807 .63578 L .31561 .63681 L F
.31998 .63449 m .31807 .63578 L .31961 .63469 L F
.542 .604 .864 r
.31911 .63881 m .31631 .63703 L .31807 .63578 L F
.077 0 0 r
.59568 .34459 m .59491 .3456 L .59824 .34415 L F
.393 .548 .89 r
.57572 .37695 m .57719 .3768 L .57742 .37469 L F
.505 0 0 r
.31487 .63611 m .31109 .63598 L .3133 .63542 L F
.131 0 0 r
.31561 .63681 m .31487 .63611 L .3133 .63542 L F
.676 .243 .213 r
.6814 .32758 m .67969 .3291 L .67714 .32722 L F
.872 .532 .403 r
.6814 .32758 m .68211 .33028 L .67969 .3291 L F
.509 .277 .499 r
.31881 .5747 m .32073 .57007 L .31692 .56912 L F
.31881 .5747 m .32043 .5729 L .32073 .57007 L F
.855 .793 .79 r
.32043 .5729 m .3234 .56925 L .32073 .57007 L F
0 0 0 r
.62549 .38819 m .62286 .38972 L .62538 .38872 L F
.084 0 .18 r
.62538 .38872 m .62286 .38972 L .62272 .39206 L F
.991 .865 .519 r
.3509 .57205 m .35211 .57365 L .35211 .57041 L F
.966 .937 .684 r
.34949 .57413 m .35211 .57365 L .3509 .57205 L F
.658 .356 .451 r
.68912 .30337 m .69205 .30131 L .68884 .30158 L F
.39 .706 .985 r
.59419 .44571 m .59593 .44411 L .59285 .44431 L F
.59419 .44571 m .59704 .44562 L .59593 .44411 L F
.438 .108 .308 r
.34655 .5929 m .34652 .59601 L .34239 .59592 L F
.637 .264 .32 r
.34905 .59522 m .34655 .5929 L .34859 .59233 L F
.34905 .59522 m .34652 .59601 L .34655 .5929 L F
0 .218 .733 r
.34655 .5929 m .34905 .59522 L .34859 .59233 L F
.766 .626 .705 r
.27143 .59546 m .27614 .59139 L .27234 .59461 L F
.828 .744 .772 r
.51037 .44773 m .51095 .44995 L .50964 .45112 L F
.788 .619 .671 r
.54246 .4043 m .54283 .4055 L .544 .40292 L F
.114 0 .287 r
.544 .40292 m .54586 .40424 L .54679 .40283 L F
.544 .40292 m .54283 .4055 L .54586 .40424 L F
.865 .972 .858 r
.57706 .36749 m .57408 .36878 L .57564 .36605 L F
.498 .752 .986 r
.57826 .36533 m .57706 .36749 L .57564 .36605 L F
.57826 .36533 m .57987 .36705 L .57706 .36749 L F
.765 .299 .139 r
.3684 .5044 m .36672 .50574 L .36484 .50343 L F
.801 .351 .173 r
.3684 .5044 m .37018 .50715 L .36672 .50574 L F
.763 .282 .095 r
.32034 .59533 m .31802 .59509 L .3155 .59287 L F
.849 .895 .87 r
.32066 .59172 m .32034 .59533 L .32307 .59552 L F
.32066 .59172 m .31802 .59509 L .32034 .59533 L F
0 0 0 r
.40281 .50445 m .40159 .50672 L .40287 .50424 L F
.753 .96 .663 r
.49601 .51134 m .49344 .51445 L .49427 .5125 L F
.742 .929 .583 r
.49344 .51445 m .49184 .51593 L .49427 .5125 L F
.763 .962 .663 r
.49601 .51134 m .49522 .51086 L .49844 .51038 L F
.49601 .51134 m .49427 .5125 L .49522 .51086 L F
.555 .895 .655 r
.54862 .40745 m .54732 .40825 L .54573 .40984 L F
.397 .015 .192 r
.54732 .40825 m .54379 .41023 L .54573 .40984 L F
.433 .776 .997 r
.3336 .65076 m .33552 .65208 L .33704 .65081 L F
.982 .72 .454 r
.33517 .65453 m .33552 .65208 L .3336 .65076 L F
0 0 0 r
.30516 .64469 m .30332 .64631 L .3027 .64529 L F
.581 .775 .971 r
.30332 .64631 m .30516 .64469 L .3027 .64529 L F
.30332 .64631 m .30672 .64634 L .30516 .64469 L F
.387 .214 .521 r
.61363 .41671 m .61215 .4165 L .61203 .41784 L F
.61363 .41671 m .6144 .41536 L .61215 .4165 L F
.821 .706 .738 r
.527 .42502 m .52812 .42821 L .5256 .42913 L F
.324 .801 .732 r
.5256 .42913 m .52812 .42821 L .52596 .42878 L F
0 .092 .641 r
.52896 .42602 m .52812 .42821 L .527 .42502 L F
.721 .981 .771 r
.52596 .42878 m .52812 .42821 L .52896 .42602 L F
.559 .37 .581 r
.28729 .59217 m .28461 .59546 L .28548 .59321 L F
.774 .281 0 r
.38438 .57885 m .3877 .58226 L .38799 .57984 L F
.921 .836 .743 r
.56783 .46491 m .56947 .46122 L .5685 .46299 L F
.764 .969 .926 r
.56947 .46122 m .57218 .45789 L .57062 .45925 L F
.56947 .46122 m .57309 .45865 L .57218 .45789 L F
0 0 0 r
.5685 .46299 m .56947 .46122 L .57062 .45925 L F
.145 .689 .791 r
.61156 .34401 m .61582 .34383 L .613 .34445 L F
.561 .387 .603 r
.42933 .47179 m .42955 .47467 L .43207 .47139 L F
.98 .711 .442 r
.42933 .47179 m .42955 .47467 L .43207 .47139 L F
.509 .602 .882 r
.35211 .57041 m .35498 .57228 L .35486 .56972 L F
.457 .329 .618 r
.35498 .57228 m .35769 .56874 L .35486 .56972 L F
.602 .828 .986 r
.31777 .65161 m .32191 .65204 L .32024 .65076 L F
.611 .831 .984 r
.32024 .65076 m .32191 .65204 L .32273 .64997 L F
.411 .607 .929 r
.32273 .64997 m .32191 .65204 L .32413 .65188 L F
.471 .888 .92 r
.61586 .34893 m .6142 .35017 L .61678 .34928 L F
.652 .26 .289 r
.46488 .58583 m .46311 .58837 L .4633 .58537 L F
.46488 .58583 m .4655 .58818 L .46311 .58837 L F
0 0 0 r
.28529 .57948 m .28712 .57891 L .28861 .5778 L F
.623 .165 .143 r
.28712 .57891 m .29176 .57919 L .28861 .5778 L F
.662 .407 .524 r
.41473 .47748 m .41643 .47783 L .41615 .4748 L F
.41473 .47748 m .41643 .47783 L .41615 .4748 L F
.91 .975 .789 r
.41616 .47305 m .41615 .4748 L .41575 .47322 L F
.499 .685 .95 r
.41616 .47305 m .41886 .47421 L .41615 .4748 L F
0 .462 .824 r
.41769 .47336 m .41886 .47421 L .41616 .47305 L F
.41769 .47336 m .41886 .47421 L .41616 .47305 L F
.425 .236 .518 r
.41615 .4748 m .41769 .47336 L .41575 .47322 L F
.41615 .4748 m .41886 .47421 L .41769 .47336 L F
.41615 .4748 m .41643 .47783 L .41886 .47421 L F
.41886 .47421 m .41643 .47783 L .41615 .4748 L F
.679 .874 .972 r
.45703 .44975 m .45874 .4511 L .46151 .44925 L F
.686 .98 .861 r
.35892 .54016 m .35801 .54002 L .35938 .53975 L F
.591 .552 .779 r
.31624 .62578 m .31836 .62608 L .31776 .62142 L F
.598 .247 .345 r
.3183 .62773 m .31836 .62608 L .31624 .62578 L F
.749 .634 .732 r
.46591 .57659 m .46316 .58147 L .46177 .57626 L F
.403 .404 .747 r
.46316 .58147 m .46182 .57868 L .4618 .58142 L F
.46316 .58147 m .46513 .57866 L .46182 .57868 L F
.597 .834 .457 r
.49724 .53382 m .49589 .5355 L .49563 .53596 L F
.727 .886 .489 r
.4981 .53176 m .49589 .5355 L .49724 .53382 L F
.911 .936 .569 r
.4981 .53176 m .49659 .53493 L .49589 .5355 L F
.496 .879 .686 r
.49659 .53493 m .49601 .53528 L .49589 .5355 L F
.49601 .53528 m .49413 .53642 L .49589 .5355 L F
.597 .834 .457 r
.49563 .53596 m .49589 .5355 L .49471 .5372 L F
0 0 0 r
.49589 .5355 m .49394 .53914 L .49471 .5372 L F
.992 .776 .512 r
.40137 .57959 m .40017 .57573 L .40204 .57708 L F
.551 .206 .337 r
.55536 .44388 m .5528 .44212 L .55227 .44414 L F
0 0 0 r
.49882 .50783 m .50031 .50631 L .50154 .50477 L F
.49882 .50783 m .49913 .50819 L .50031 .50631 L F
.49882 .50783 m .49844 .51038 L .49913 .50819 L F
.813 .935 .566 r
.60275 .38154 m .60117 .38532 L .60319 .38273 L F
.60275 .38154 m .60076 .38472 L .60117 .38532 L F
.629 .649 .851 r
.52988 .46759 m .53095 .46338 L .53032 .46516 L F
.468 .252 .503 r
.316 .60929 m .31909 .60564 L .31441 .60549 L F
.316 .60929 m .31847 .60873 L .31909 .60564 L F
.956 .82 .668 r
.34932 .53531 m .34842 .53299 L .34736 .53385 L F
.717 .724 .856 r
.46392 .57479 m .46591 .57659 L .46177 .57626 L F
.094 0 0 r
.33054 .54285 m .33088 .54274 L .33509 .54012 L F
.572 .894 .987 r
.33509 .54012 m .33562 .53876 L .33689 .53885 L F
.719 .986 .81 r
.33509 .54012 m .33088 .54274 L .33562 .53876 L F
.86 .814 .803 r
.57995 .40362 m .57639 .40887 L .57849 .40924 L F
.822 .852 .87 r
.57552 .40844 m .57639 .40887 L .57641 .40868 L F
.57589 .40879 m .57714 .40999 L .57849 .40924 L F
.57552 .40844 m .57589 .40879 L .57639 .40887 L F
.57552 .40844 m .57641 .40868 L .57613 .40926 L F
.909 .919 .813 r
.5764 .40868 m .57613 .40926 L .57639 .40887 L F
.57683 .40405 m .57639 .40887 L .57995 .40362 L F
.822 .852 .87 r
.57641 .40868 m .57639 .40887 L .57849 .40924 L F
.86 .814 .803 r
.57639 .40887 m .57613 .40926 L .57849 .40924 L F
.822 .852 .87 r
.57641 .40868 m .57849 .40924 L .57613 .40926 L F
.979 .858 .649 r
.57552 .40844 m .57602 .41219 L .57714 .40999 L F
.909 .919 .813 r
.57674 .40406 m .57613 .40926 L .5764 .40868 L F
.57674 .40406 m .57639 .40887 L .57683 .40405 L F
.86 .814 .803 r
.57995 .40362 m .57849 .40924 L .58158 .40568 L F
.676 .759 .913 r
.53807 .45477 m .54185 .45403 L .5406 .45439 L F
.465 .447 .753 r
.53734 .4527 m .53807 .45477 L .5406 .45439 L F
.73 .627 .062 r
.43191 .55923 m .43172 .5633 L .43472 .56002 L F
.43191 .55923 m .4317 .56235 L .43172 .5633 L F
.941 .821 .372 r
.43067 .56181 m .43172 .5633 L .4317 .56235 L F
.43067 .56181 m .43119 .56679 L .43172 .5633 L F
.983 .83 .612 r
.34203 .55714 m .3401 .55877 L .34058 .55583 L F
.916 .932 .806 r
.68304 .3344 m .68066 .3348 L .68169 .3329 L F
.68304 .3344 m .6805 .33815 L .68066 .3348 L F
0 0 0 r
.3556 .61887 m .35719 .61566 L .35855 .61793 L F
.356 .589 .933 r
.6017 .3718 m .6054 .37021 L .60207 .37112 L F
.852 .98 .863 r
.72168 .30841 m .71801 .3103 L .72011 .30663 L F
.889 .866 .81 r
.72407 .30488 m .72168 .30841 L .72011 .30663 L F
.283 0 0 r
.51725 .41153 m .52011 .41133 L .52153 .40976 L F
0 0 0 r
.52153 .40976 m .52239 .40989 L .52336 .40986 L F
.52153 .40976 m .52011 .41133 L .52239 .40989 L F
.944 .722 .572 r
.4645 .55344 m .46243 .5529 L .46269 .54975 L F
.998 .775 .447 r
.4645 .55344 m .46298 .55527 L .46243 .5529 L F
.4645 .55344 m .46425 .5564 L .46298 .55527 L F
.607 .723 .928 r
.5982 .43486 m .6022 .4364 L .60117 .43383 L F
.55 .844 .998 r
.6022 .4364 m .60389 .43419 L .60117 .43383 L F
.6022 .4364 m .60553 .43534 L .60389 .43419 L F
.775 .688 .767 r
.33889 .53009 m .34047 .53394 L .34229 .52959 L F
.786 .328 .155 r
.55639 .45402 m .55533 .45173 L .55401 .45152 L F
.517 .17 .318 r
.55533 .45173 m .56131 .45088 L .55889 .45063 L F
.701 .481 .586 r
.55639 .45402 m .56131 .45088 L .55533 .45173 L F
.088 .519 .905 r
.61726 .35749 m .61622 .35839 L .61448 .3578 L F
.61726 .35749 m .61869 .35889 L .61622 .35839 L F
.889 .866 .81 r
.72407 .30488 m .72011 .30663 L .72299 .30355 L F
.873 .941 .858 r
.72665 .30212 m .72407 .30488 L .72299 .30355 L F
.5 .903 .919 r
.43755 .44517 m .43743 .44635 L .43526 .44609 L F
.43755 .44517 m .43992 .44528 L .43743 .44635 L F
.821 .34 .013 r
.27614 .59139 m .27818 .59293 L .27705 .58992 L F
.27614 .59139 m .27642 .59237 L .27818 .59293 L F
0 0 0 r
.27818 .59293 m .27982 .58906 L .27705 .58992 L F
.27818 .59293 m .27902 .5913 L .27982 .58906 L F
.578 .905 .98 r
.27818 .59293 m .27642 .59237 L .27902 .5913 L F
.685 .498 .628 r
.31401 .57269 m .31692 .56912 L .31412 .56991 L F
.31401 .57269 m .31881 .5747 L .31692 .56912 L F
.821 .59 .59 r
.3258 .57618 m .32078 .57312 L .32291 .57273 L F
.3258 .57618 m .32051 .57575 L .32043 .5729 L F
.829 .696 .159 r
.32557 .57144 m .3258 .57618 L .32291 .57273 L F
.074 0 0 r
.324 .57252 m .32291 .57273 L .32144 .57427 L F
.32557 .57144 m .32291 .57273 L .324 .57252 L F
.821 .59 .59 r
.32078 .57312 m .32043 .5729 L .32291 .57273 L F
.447 0 0 r
.3258 .57618 m .32029 .57791 L .32051 .57575 L F
.3258 .57618 m .32318 .57821 L .32029 .57791 L F
.829 .696 .159 r
.32557 .57144 m .32547 .57549 L .3258 .57618 L F
0 0 0 r
.32557 .57745 m .32318 .57821 L .3258 .57618 L F
.32557 .57745 m .3258 .57618 L .32547 .57549 L F
.619 .956 .905 r
.4706 .42879 m .46826 .43025 L .46611 .43034 L F
.335 .797 .679 r
.30627 .54745 m .30632 .54732 L .30738 .54749 L F
.455 .877 .769 r
.30632 .54732 m .30476 .54784 L .30832 .54624 L F
.561 .862 .555 r
.31112 .54363 m .30777 .54709 L .30959 .54499 L F
.617 .951 .784 r
.30738 .54749 m .30632 .54732 L .30959 .54499 L F
.455 .877 .769 r
.30632 .54732 m .30921 .54584 L .30959 .54499 L F
.30827 .54632 m .30832 .54624 L .30921 .54584 L F
.30632 .54732 m .30832 .54624 L .30827 .54632 L F
.561 .862 .555 r
.30777 .54709 m .30738 .54749 L .30786 .54695 L F
.30777 .54709 m .30786 .54695 L .30959 .54499 L F
.332 0 0 r
.31667 .63364 m .31998 .63449 L .31615 .63425 L F
.169 .41 .851 r
.60611 .43026 m .60551 .43239 L .60305 .42871 L F
.799 .63 .072 r
.6052 .43205 m .60551 .43239 L .60611 .43026 L F
.6052 .43205 m .60553 .43534 L .60551 .43239 L F
.076 0 0 r
.33757 .53213 m .33635 .53114 L .33889 .53009 L F
.33757 .53213 m .33518 .53325 L .33635 .53114 L F
.309 0 0 r
.30262 .60917 m .30072 .61119 L .30303 .60993 L F
.447 .777 .998 r
.3029 .60813 m .30545 .60876 L .30262 .60917 L F
.499 .326 .578 r
.30545 .60876 m .30509 .61168 L .30262 .60917 L F
0 .195 .722 r
.3029 .60813 m .30509 .61168 L .30262 .60917 L F
0 0 .306 r
.30262 .60917 m .30303 .60993 L .3029 .60813 L F
.776 .94 .593 r
.3029 .60813 m .30072 .61119 L .30262 .60917 L F
.545 .427 .669 r
.53734 .4527 m .54148 .45288 L .53977 .44831 L F
.465 .447 .753 r
.53734 .4527 m .5406 .45439 L .54148 .45288 L F
.892 .497 .269 r
.3409 .50305 m .34208 .50599 L .34378 .50474 L F
.769 .301 .134 r
.34378 .50474 m .34208 .50599 L .34431 .50625 L F
.25 .321 .742 r
.24585 .55902 m .24341 .55677 L .2457 .55626 L F
.873 .941 .858 r
.72665 .30212 m .72299 .30355 L .72523 .30132 L F
.776 .4 .344 r
.52576 .42112 m .52634 .41894 L .52266 .41849 L F
0 0 0 r
.52947 .41584 m .52634 .41894 L .52879 .41784 L F
.015 0 0 r
.6224 .34116 m .6251 .34062 L .62566 .34032 L F
0 0 0 r
.62566 .34032 m .6251 .34062 L .62834 .33959 L F
.837 .889 .878 r
.49685 .44922 m .49704 .44676 L .49481 .44789 L F
.461 0 0 r
.70663 .30416 m .70938 .30581 L .71005 .30583 L F
.374 0 0 r
.71005 .30583 m .70938 .30581 L .71268 .30693 L F
.745 .48 .531 r
.35728 .56393 m .35243 .56354 L .35525 .56277 L F
.35728 .56393 m .35268 .566 L .35243 .56354 L F
.35728 .56393 m .35556 .56669 L .35268 .566 L F
.611 .877 .991 r
.35728 .56393 m .35803 .56163 L .35969 .56296 L F
.35728 .56393 m .35525 .56277 L .35803 .56163 L F
.914 .72 .627 r
.40812 .50659 m .40978 .51055 L .4106 .50791 L F
.135 .226 .694 r
.55882 .44435 m .55687 .44565 L .55536 .44388 L F
.905 .502 .108 r
.59343 .41331 m .59198 .41238 L .59109 .40939 L F
.856 .415 .003 r
.59257 .41378 m .59198 .41238 L .59343 .41331 L F
.903 .961 .631 r
.42645 .57537 m .42485 .57991 L .42444 .57881 L F
.908 .904 .808 r
.70305 .32874 m .70421 .3302 L .70442 .32728 L F
.83 .94 .898 r
.70421 .3302 m .70683 .32586 L .70442 .32728 L F
.70421 .3302 m .70781 .32713 L .70683 .32586 L F
.935 .718 .238 r
.69791 .35699 m .69729 .35322 L .69665 .3556 L F
.953 .641 .216 r
.6971 .35806 m .69791 .35699 L .69665 .3556 L F
.6971 .35806 m .69826 .3595 L .69791 .35699 L F
.996 .761 .425 r
.52767 .48495 m .52625 .48637 L .52679 .48407 L F
.612 .938 .954 r
.52874 .48317 m .5301 .48372 L .52767 .48495 L F
.476 .79 .999 r
.52874 .48317 m .52767 .48495 L .52679 .48407 L F
.659 .204 .16 r
.34579 .56575 m .3501 .56634 L .34761 .567 L F
.669 .489 .632 r
.31169 .57355 m .31401 .57269 L .31412 .56991 L F
.798 .632 .676 r
.42961 .54999 m .42905 .55302 L .43214 .55326 L F
.814 .539 .523 r
.42905 .55302 m .43232 .55564 L .43214 .55326 L F
.734 .751 .866 r
.26647 .52419 m .2626 .52447 L .26448 .52406 L F
.412 .862 .82 r
.26647 .52419 m .26177 .52562 L .2626 .52447 L F
.26647 .52419 m .26401 .52467 L .26177 .52562 L F
.698 .97 .749 r
.26971 .52121 m .26732 .52253 L .26647 .52419 L F
.671 .976 .875 r
.26732 .52253 m .26401 .52467 L .26647 .52419 L F
.942 .9 .755 r
.40931 .45837 m .40641 .46023 L .40497 .45906 L F
.568 .859 .997 r
.61967 .35699 m .62252 .35702 L .62138 .35594 L F
.828 .994 .858 r
.62367 .35424 m .62252 .35702 L .62525 .35397 L F
.797 .962 .916 r
.62138 .35594 m .62252 .35702 L .62367 .35424 L F
.997 .804 .448 r
.69864 .34964 m .69896 .34721 L .69795 .34582 L F
.998 .847 .545 r
.69896 .34721 m .6985 .34322 L .69795 .34582 L F
.484 .503 .802 r
.34881 .55682 m .35007 .55255 L .3473 .5528 L F
.27 0 .284 r
.2734 .6382 m .27123 .63878 L .27051 .64146 L F
.699 .781 .915 r
.63204 .37206 m .63637 .37307 L .63482 .37146 L F
.511 .728 .971 r
.63778 .37059 m .63637 .37307 L .63482 .37146 L F
.63778 .37059 m .63888 .37247 L .63637 .37307 L F
.63637 .37307 m .63778 .37059 L .63482 .37146 L F
.63637 .37307 m .63888 .37247 L .63778 .37059 L F
0 0 0 r
.6224 .34116 m .62375 .34098 L .6251 .34062 L F
.6224 .34116 m .62108 .34182 L .62375 .34098 L F
.884 .873 .821 r
.59897 .42363 m .59785 .42609 L .59625 .42447 L F
.735 .903 .524 r
.49939 .53003 m .4981 .53176 L .49724 .53382 L F
0 .059 .543 r
.57719 .3768 m .58063 .37988 L .57912 .3785 L F
.719 .466 0 r
.58063 .37988 m .58073 .38074 L .57912 .3785 L F
.58063 .37988 m .58124 .38285 L .58073 .38074 L F
.724 .819 .924 r
.46151 .44925 m .46578 .44965 L .464 .44801 L F
.761 .827 .903 r
.46578 .44965 m .46809 .44812 L .464 .44801 L F
.825 .995 .857 r
.61294 .40596 m .61401 .40541 L .61364 .4036 L F
.686 .94 .964 r
.61364 .4036 m .61401 .40541 L .61787 .40268 L F
.793 .4 .31 r
.42436 .55316 m .42245 .55287 L .42233 .55023 L F
.623 .955 .92 r
.53565 .49102 m .53821 .48954 L .53693 .48928 L F
.587 .915 .973 r
.53446 .49041 m .53565 .49102 L .53693 .48928 L F
.853 .846 .836 r
.5645 .44411 m .5638 .44618 L .56196 .44419 L F
.774 .518 .549 r
.24354 .57541 m .23912 .57288 L .2436 .5731 L F
.86 .94 .872 r
.2436 .5731 m .24366 .57051 L .24558 .56974 L F
.2436 .5731 m .24309 .57277 L .24366 .57051 L F
.627 .064 0 r
.2436 .5731 m .24282 .57379 L .24354 .57541 L F
.387 .292 .625 r
.24354 .57541 m .24561 .5748 L .2436 .5731 L F
.627 .064 0 r
.2436 .5731 m .24561 .5748 L .24282 .57379 L F
.361 .804 .956 r
.32413 .65188 m .32844 .65204 L .32667 .65122 L F
0 .523 .825 r
.32667 .65122 m .32844 .65204 L .33107 .65253 L F
.357 0 0 r
.42581 .59932 m .43001 .59893 L .42847 .59957 L F
.374 0 0 r
.43001 .59893 m .43082 .59986 L .42847 .59957 L F
.43001 .59893 m .43248 .59962 L .43082 .59986 L F
0 0 .133 r
.53352 .46671 m .53363 .46818 L .53324 .46473 L F
.796 .696 .154 r
.53352 .46671 m .53334 .46992 L .53363 .46818 L F
.747 .419 .429 r
.57373 .42241 m .5755 .41877 L .57301 .41795 L F
.57373 .42241 m .57768 .42166 L .5755 .41877 L F
.439 .176 .417 r
.37185 .47492 m .37547 .47188 L .37052 .47111 L F
.37185 .47492 m .37445 .47431 L .37547 .47188 L F
.479 .276 .527 r
.37185 .47492 m .37191 .4777 L .37445 .47431 L F
.303 .535 .91 r
.30672 .64634 m .30753 .64424 L .30516 .64469 L F
.30672 .64634 m .30975 .64751 L .30753 .64424 L F
.831 .571 .547 r
.298 .66818 m .29361 .67062 L .29638 .66743 L F
.298 .66818 m .2978 .67094 L .29361 .67062 L F
.625 .694 .894 r
.2986 .66405 m .298 .66818 L .29638 .66743 L F
.2986 .66405 m .30094 .66799 L .298 .66818 L F
.52 .245 .438 r
.30094 .66799 m .2978 .67094 L .298 .66818 L F
.845 .386 .094 r
.33036 .50517 m .32883 .50575 L .32818 .50402 L F
.785 .452 .425 r
.32594 .60887 m .32505 .60954 L .3237 .60803 L F
.64 .079 0 r
.32859 .61164 m .32594 .60887 L .32909 .60911 L F
.32859 .61164 m .32505 .60954 L .32594 .60887 L F
.654 .497 .659 r
.32594 .60887 m .32859 .61164 L .32909 .60911 L F
.263 .666 .967 r
.71233 .27911 m .71459 .28023 L .71202 .28023 L F
.851 .991 .734 r
.72464 .32174 m .7256 .31892 L .72322 .32255 L F
.72464 .32174 m .72576 .32001 L .7256 .31892 L F
.189 0 .378 r
.52429 .39872 m .52272 .39958 L .52483 .396 L F
.95 .807 .359 r
.52429 .39872 m .5241 .40008 L .52272 .39958 L F
.234 .069 .442 r
.5241 .40008 m .52261 .40236 L .52272 .39958 L F
.566 .375 .581 r
.64496 .38627 m .64786 .3874 L .64798 .38257 L F
.351 0 0 r
.65208 .3846 m .64798 .38257 L .64786 .3874 L F
.65208 .3846 m .65108 .38404 L .64798 .38257 L F
.563 .022 0 r
.40668 .58979 m .40582 .59146 L .40264 .58937 L F
.013 0 0 r
.40774 .59051 m .40668 .58979 L .40936 .59159 L F
.40774 .59051 m .40582 .59146 L .40668 .58979 L F
.982 .909 .636 r
.7288 .30557 m .73061 .30457 L .72934 .30313 L F
.7288 .30557 m .72965 .30712 L .73061 .30457 L F
0 .208 .65 r
.41753 .52512 m .41915 .52634 L .41618 .52444 L F
.306 .773 .648 r
.47998 .42271 m .47575 .42467 L .47877 .42225 L F
.699 .936 .63 r
.48271 .41948 m .47998 .42271 L .48107 .42076 L F
.67 .961 .938 r
.48107 .42076 m .47998 .42271 L .47877 .42225 L F
.634 .623 .822 r
.31535 .65263 m .31605 .64776 L .31345 .64851 L F
.31535 .65263 m .31777 .65161 L .31605 .64776 L F
.598 .921 .688 r
.67199 .38239 m .67363 .38053 L .67181 .3824 L F
.67199 .38239 m .67513 .37976 L .67363 .38053 L F
.725 .711 .837 r
.33714 .58305 m .34023 .58553 L .33992 .58196 L F
.491 .007 .033 r
.33665 .58654 m .33929 .58764 L .34023 .58553 L F
.009 .092 .603 r
.33992 .58196 m .34023 .58553 L .34199 .58467 L F
0 0 0 r
.34023 .58553 m .33929 .58764 L .34199 .58467 L F
.877 .896 .842 r
.43887 .58515 m .43781 .58954 L .44055 .58924 L F
.43887 .58515 m .43368 .5911 L .43781 .58954 L F
.402 .85 .765 r
.43781 .58954 m .43894 .5887 L .44055 .58924 L F
.43781 .58954 m .43368 .5911 L .43894 .5887 L F
0 0 0 r
.51575 .43177 m .51872 .42896 L .51844 .43129 L F
.377 .117 .388 r
.51844 .43129 m .51872 .42896 L .5216 .42794 L F
.745 .516 .584 r
.33898 .52731 m .34229 .52959 L .34198 .5269 L F
.837 .585 .558 r
.52433 .43886 m .52094 .436 L .52038 .43974 L F
.502 .297 .534 r
.52433 .43886 m .52042 .43973 L .52356 .43787 L F
.685 .933 .967 r
.52566 .43661 m .52433 .43886 L .52356 .43787 L F
0 0 0 r
.52556 .43668 m .52356 .43787 L .52167 .43947 L F
.52566 .43661 m .52356 .43787 L .52556 .43668 L F
.502 .297 .534 r
.52042 .43973 m .52038 .43974 L .52356 .43787 L F
.52433 .43886 m .52165 .4422 L .52038 .43974 L F
.52433 .43886 m .52432 .44149 L .52165 .4422 L F
.361 .187 .506 r
.52642 .44061 m .52433 .43886 L .52566 .43661 L F
.52642 .44061 m .52432 .44149 L .52433 .43886 L F
.973 .663 .341 r
.50065 .44178 m .50012 .43838 L .49756 .44174 L F
.257 .646 .964 r
.50012 .43838 m .50429 .43958 L .5031 .43744 L F
.125 0 0 r
.50012 .43838 m .5031 .43744 L .50018 .43914 L F
.914 .866 .777 r
.5031 .43744 m .50015 .43816 L .50018 .43914 L F
.638 .87 .509 r
.49894 .43956 m .50012 .43838 L .49874 .4385 L F
.49929 .43922 m .49756 .44174 L .50012 .43838 L F
.125 0 0 r
.50012 .43838 m .50018 .43914 L .49874 .4385 L F
.914 .866 .777 r
.50015 .43816 m .49874 .4385 L .49957 .43887 L F
.50015 .43816 m .49957 .43887 L .50018 .43914 L F
.638 .87 .509 r
.49894 .43956 m .49873 .4399 L .49929 .43922 L F
.49873 .4399 m .49756 .44174 L .49929 .43922 L F
.412 .681 .973 r
.49894 .43956 m .50065 .44178 L .49756 .44174 L F
.733 .308 .241 r
.5961 .38059 m .59247 .37837 L .59392 .37993 L F
.163 0 .397 r
.59392 .37993 m .59352 .3828 L .5961 .38059 L F
.115 0 .211 r
.23181 .55328 m .23326 .55284 L .23439 .55013 L F
.236 .173 .579 r
.23181 .55328 m .23369 .55557 L .23326 .55284 L F
.16 .155 .602 r
.23256 .55639 m .23369 .55557 L .23181 .55328 L F
.726 .833 .384 r
.56863 .46271 m .56783 .46491 L .5685 .46299 L F
.391 .85 .873 r
.70047 .29573 m .70244 .29441 L .70413 .29484 L F
.70047 .29573 m .69914 .29546 L .70244 .29441 L F
.742 .405 0 r
.59894 .39743 m .59899 .39699 L .59897 .39465 L F
.809 .592 .608 r
.59479 .39707 m .59894 .39743 L .59897 .39465 L F
.407 .811 .981 r
.59723 .39658 m .59894 .39743 L .59479 .39707 L F
.489 0 0 r
.59883 .39761 m .59894 .39743 L .59723 .39658 L F
.742 .405 0 r
.59894 .39743 m .59981 .39937 L .59906 .39721 L F
.753 .418 0 r
.59894 .39743 m .60053 .40162 L .59981 .39937 L F
.598 .574 .798 r
.60287 .40047 m .60053 .40162 L .59894 .39743 L F
.489 0 0 r
.60164 .39943 m .59894 .39743 L .59883 .39761 L F
.742 .405 0 r
.59894 .39743 m .59906 .39721 L .59899 .39699 L F
.766 .72 .81 r
.29192 .58567 m .29274 .58277 L .28989 .58587 L F
.748 .701 .807 r
.52038 .43974 m .52165 .4422 L .51746 .44185 L F
.709 .915 .568 r
.52165 .4422 m .52016 .4436 L .51746 .44185 L F
.159 .351 .806 r
.52485 .44464 m .52165 .4422 L .52432 .44149 L F
.296 .776 .684 r
.66253 .32134 m .66359 .32081 L .66372 .32082 L F
.66253 .32134 m .66108 .32185 L .66359 .32081 L F
0 0 0 r
.66108 .32185 m .66228 .32195 L .66359 .32081 L F
.525 .845 .546 r
.66359 .32081 m .66228 .32195 L .66348 .32079 L F
.66359 .32081 m .66348 .32079 L .6654 .31895 L F
.296 .776 .684 r
.66372 .32082 m .66359 .32081 L .66514 .3202 L F
.773 .997 .84 r
.49096 .41495 m .49388 .41136 L .49419 .41221 L F
.49096 .41495 m .4903 .41442 L .49388 .41136 L F
.675 .737 .234 r
.32462 .61484 m .32429 .61581 L .32484 .61416 L F
.756 .982 .739 r
.32484 .61416 m .32429 .61581 L .3214 .61787 L F
.732 .716 .836 r
.61319 .39385 m .61608 .39306 L .61283 .39167 L F
.61283 .39167 m .61608 .39306 L .61319 .39385 L F
.352 .479 .848 r
.61319 .39385 m .61657 .39556 L .61608 .39306 L F
.446 0 0 r
.61906 .39433 m .61608 .39306 L .61657 .39556 L F
.732 .716 .836 r
.61319 .39385 m .61608 .39306 L .61283 .39167 L F
.65 .45 .599 r
.52805 .42261 m .527 .42502 L .52418 .42535 L F
.503 .048 .106 r
.52805 .42261 m .53017 .42441 L .527 .42502 L F
.52805 .42261 m .5309 .42243 L .53017 .42441 L F
.75 .994 .862 r
.47484 .58912 m .47095 .59137 L .47129 .59195 L F
.47484 .58912 m .47403 .58879 L .47095 .59137 L F
.881 .547 .412 r
.57798 .42371 m .5807 .42286 L .57768 .42166 L F
.57798 .42371 m .58127 .4251 L .5807 .42286 L F
.733 .601 .71 r
.34198 .5269 m .34229 .52959 L .34581 .52738 L F
.018 .19 .7 r
.24732 .57688 m .24802 .57452 L .24561 .5748 L F
.253 0 .2 r
.24732 .57688 m .24878 .57747 L .24983 .57566 L F
.018 .19 .7 r
.24732 .57688 m .24878 .57747 L .24802 .57452 L F
.866 .98 .685 r
.7256 .31892 m .72755 .31746 L .72654 .31605 L F
.7256 .31892 m .72576 .32001 L .72755 .31746 L F
0 0 0 r
.35236 .54905 m .35115 .55312 L .35028 .54973 L F
.35236 .54905 m .35426 .55037 L .35115 .55312 L F
.895 .865 .803 r
.35426 .55037 m .35007 .55255 L .35236 .54905 L F
0 0 0 r
.35236 .54905 m .35155 .55119 L .35426 .55037 L F
.777 .878 .92 r
.35521 .54849 m .35426 .55037 L .35236 .54905 L F
.35625 .54829 m .35466 .54995 L .35521 .54849 L F
.35466 .54995 m .35426 .55037 L .35521 .54849 L F
.826 .755 .785 r
.35866 .54609 m .35625 .54829 L .35532 .54654 L F
.35615 .54581 m .35532 .54654 L .35485 .54566 L F
.35866 .54609 m .35532 .54654 L .35615 .54581 L F
.777 .878 .92 r
.35625 .54829 m .35236 .54905 L .35485 .54566 L F
.233 0 .139 r
.35377 .54859 m .35558 .54646 L .35351 .54813 L F
.35251 .549 m .35351 .54813 L .35236 .54905 L F
.35377 .54859 m .35351 .54813 L .35251 .549 L F
.936 .585 .165 r
.35581 .54693 m .35668 .5511 L .35745 .55036 L F
.35558 .54646 m .35574 .54711 L .35581 .54693 L F
.35574 .54711 m .35668 .5511 L .35581 .54693 L F
.233 0 .139 r
.35155 .55119 m .35236 .54905 L .35426 .55037 L F
.35155 .55119 m .35377 .54859 L .35236 .54905 L F
0 0 0 r
.35236 .54905 m .35028 .54973 L .35006 .54885 L F
.099 0 0 r
.55375 .44875 m .55494 .44916 L .55275 .45016 L F
.55375 .44875 m .55663 .44793 L .55494 .44916 L F
.9 .526 .316 r
.42623 .54519 m .42784 .54367 L .42471 .54149 L F
.999 .798 .489 r
.42623 .54519 m .42745 .54652 L .42784 .54367 L F
.15 .498 .907 r
.60585 .4226 m .60978 .42525 L .60885 .42456 L F
.812 .815 .853 r
.60978 .42525 m .60951 .42153 L .60885 .42456 L F
.60978 .42525 m .61279 .42237 L .60951 .42153 L F
.85 .471 0 r
.58501 .38838 m .58592 .38943 L .58666 .39173 L F
.561 .629 .877 r
.44909 .45743 m .44528 .4549 L .44674 .45854 L F
.85 .569 .513 r
.41341 .51645 m .41345 .51967 L .41539 .51621 L F
.776 .472 .472 r
.41539 .51621 m .41676 .51937 L .41799 .51638 L F
.41539 .51621 m .41345 .51967 L .41676 .51937 L F
.801 .308 0 r
.64455 .38767 m .64496 .38627 L .6431 .3858 L F
.539 0 0 r
.64455 .38767 m .64847 .38792 L .64496 .38627 L F
.511 0 0 r
.64847 .38792 m .64786 .3874 L .64496 .38627 L F
.569 0 0 r
.42005 .5282 m .42041 .52784 L .41915 .52634 L F
.42005 .5282 m .42271 .52964 L .42041 .52784 L F
.469 .743 .988 r
.60267 .41749 m .60487 .41833 L .6019 .41862 L F
.095 .225 .709 r
.60267 .41749 m .6019 .41862 L .60463 .42131 L F
.815 .919 .907 r
.24129 .58388 m .23885 .58631 L .23723 .58539 L F
0 .045 .609 r
.23885 .58631 m .23967 .58532 L .23723 .58539 L F
.23885 .58631 m .23999 .58784 L .23967 .58532 L F
.261 .192 .587 r
.23885 .58631 m .2393 .58923 L .23999 .58784 L F
.113 .004 .439 r
.23592 .54291 m .23686 .53973 L .23612 .54039 L F
0 0 .16 r
.58551 .43964 m .58428 .4428 L .58503 .43792 L F
.5855 .43905 m .58503 .43792 L .5854 .43548 L F
.58551 .43964 m .58503 .43792 L .5855 .43905 L F
.964 .772 .331 r
.5873 .43937 m .58636 .44034 L .58597 .44019 L F
0 0 .16 r
.58551 .43967 m .58548 .43974 L .58551 .43964 L F
.58548 .43974 m .58428 .4428 L .58551 .43964 L F
.903 .969 .66 r
.5826 .44409 m .58428 .4428 L .58551 .43967 L F
0 0 .16 r
.58551 .43967 m .5854 .43548 L .58386 .43697 L F
.77 .327 .198 r
.58336 .43921 m .58551 .43967 L .58386 .43697 L F
.886 .974 .832 r
.58414 .43987 m .5826 .44409 L .58365 .4425 L F
.58431 .43985 m .58365 .4425 L .58551 .43967 L F
.58414 .43987 m .58365 .4425 L .58431 .43985 L F
.964 .772 .331 r
.5873 .43937 m .58597 .44019 L .5856 .4393 L F
.765 .812 .89 r
.58571 .43763 m .58597 .43791 L .58336 .43921 L F
.58597 .43791 m .5873 .43937 L .5856 .4393 L F
.58597 .43791 m .5856 .4393 L .58336 .43921 L F
.608 .951 .81 r
.58536 .43726 m .58571 .43763 L .58336 .43921 L F
.338 .428 .807 r
.58483 .43777 m .58636 .44034 L .58536 .43726 L F
.886 .974 .832 r
.58414 .43987 m .58551 .43967 L .58336 .43921 L F
.964 .772 .331 r
.5856 .4393 m .58597 .44019 L .58336 .43921 L F
.338 .428 .807 r
.58336 .43921 m .58437 .43959 L .58483 .43777 L F
.58437 .43959 m .58636 .44034 L .58483 .43777 L F
.903 .969 .66 r
.5826 .44409 m .58296 .44517 L .58428 .4428 L F
.387 0 .15 r
.33268 .56612 m .33244 .56672 L .3303 .56708 L F
.552 .383 .607 r
.33244 .56672 m .33349 .56682 L .33348 .56654 L F
.3303 .56708 m .33213 .56693 L .33244 .56672 L F
.33213 .56693 m .33349 .56682 L .33244 .56672 L F
.131 0 .049 r
.33377 .56583 m .33346 .56604 L .33268 .56612 L F
.33346 .56604 m .33244 .56672 L .3326 .56632 L F
.33346 .56604 m .3326 .56632 L .33268 .56612 L F
.315 .219 .585 r
.33333 .56296 m .33535 .56541 L .33268 .56612 L F
.347 .226 .57 r
.33333 .56296 m .33346 .56604 L .33535 .56541 L F
.33346 .56604 m .33349 .56682 L .33535 .56541 L F
.552 .383 .607 r
.3303 .56708 m .33348 .56654 L .33333 .56296 L F
.412 0 .13 r
.3303 .56708 m .33157 .56895 L .33349 .56682 L F
0 0 0 r
.33535 .56541 m .33157 .56895 L .33349 .56682 L F
.131 0 .049 r
.33535 .56541 m .33157 .56895 L .33244 .56672 L F
.33535 .56541 m .33244 .56672 L .33377 .56583 L F
.387 0 .15 r
.33244 .56672 m .33157 .56895 L .3303 .56708 L F
.926 .619 .442 r
.36921 .54241 m .37241 .54649 L .37241 .54376 L F
.028 0 0 r
.62652 .34533 m .62246 .34591 L .62363 .34583 L F
.738 .795 .898 r
.45203 .56595 m .44975 .56516 L .45204 .5634 L F
.378 .163 .456 r
.45204 .5634 m .45203 .56595 L .45474 .56245 L F
.498 .786 .997 r
.44975 .56516 m .45474 .56245 L .45204 .5634 L F
.9 .528 .321 r
.33872 .56735 m .3397 .56851 L .34056 .56631 L F
.696 .406 .48 r
.3397 .56851 m .34307 .56583 L .34056 .56631 L F
.607 .183 0 r
.56082 .43483 m .5629 .43803 L .56373 .438 L F
.724 .592 .018 r
.5629 .43803 m .56288 .44163 L .56285 .4387 L F
.975 .668 .329 r
.5914 .39938 m .59017 .40085 L .58963 .39815 L F
.5914 .39938 m .59171 .40229 L .59017 .40085 L F
.085 0 .182 r
.25051 .54602 m .24686 .55034 L .24774 .547 L F
.623 .543 .743 r
.30593 .57819 m .30812 .57626 L .30564 .57747 L F
.602 .952 .889 r
.4566 .43619 m .45509 .43796 L .45447 .43758 L F
.4566 .43619 m .45863 .4361 L .45509 .43796 L F
.826 .891 .888 r
.56164 .42842 m .55955 .43274 L .55904 .43109 L F
.55955 .43274 m .55947 .43289 L .55904 .43109 L F
.56164 .42842 m .56321 .42967 L .55947 .43289 L F
.821 .835 .86 r
.56164 .42842 m .55904 .43109 L .55816 .42882 L F
0 .205 .658 r
.55904 .43109 m .56034 .43168 L .55848 .42923 L F
.55904 .43109 m .55848 .42923 L .55816 .42882 L F
0 .134 .681 r
.55947 .43289 m .56082 .43483 L .55904 .43109 L F
.421 .313 .626 r
.67382 .34412 m .67427 .34696 L .67363 .34301 L F
0 0 0 r
.67701 .34243 m .67382 .34412 L .67363 .34301 L F
.892 .876 .813 r
.47733 .53697 m .4751 .54056 L .47325 .53913 L F
.872 .513 .366 r
.35241 .513 m .35606 .5167 L .35549 .51474 L F
.06 0 0 r
.31224 .54659 m .31072 .54872 L .30864 .54946 L F
.735 .695 .813 r
.31112 .54363 m .31224 .54659 L .31533 .54445 L F
.066 .264 .755 r
.31112 .54363 m .31346 .54554 L .31224 .54659 L F
0 0 0 r
.31346 .54554 m .31072 .54872 L .31224 .54659 L F
.204 .715 .892 r
.45285 .59658 m .45348 .5959 L .45087 .59731 L F
.45285 .59658 m .45565 .59641 L .45348 .5959 L F
0 .372 .799 r
.35842 .55444 m .36217 .55663 L .36068 .55533 L F
.35842 .55444 m .36068 .55533 L .35765 .55468 L F
.864 .458 .261 r
.34875 .50953 m .35015 .51247 L .35193 .51115 L F
.856 .445 .252 r
.35193 .51115 m .35015 .51247 L .35241 .513 L F
.968 .911 .562 r
.47912 .57632 m .47745 .57795 L .47806 .57891 L F
0 0 .226 r
.47951 .57243 m .47973 .57428 L .47912 .57632 L F
.788 .937 .579 r
.47973 .57428 m .47745 .57795 L .47912 .57632 L F
.83 .999 .785 r
.50419 .5017 m .50154 .50477 L .50211 .50249 L F
.773 .892 .484 r
.50154 .50477 m .5012 .50426 L .50211 .50249 L F
.50154 .50477 m .50031 .50631 L .5012 .50426 L F
.674 .796 .94 r
.40924 .48027 m .41122 .48212 L .4134 .48084 L F
.40924 .48027 m .41122 .48212 L .4134 .48084 L F
.514 .911 .806 r
.448 .44121 m .44667 .44245 L .44457 .44273 L F
.448 .44121 m .44888 .44113 L .44667 .44245 L F
.864 .839 .819 r
.39966 .58238 m .39985 .57868 L .40137 .57959 L F
.992 .776 .512 r
.40137 .57959 m .39985 .57868 L .40017 .57573 L F
.774 .518 .549 r
.24354 .57541 m .23904 .57601 L .23912 .57288 L F
.405 0 .045 r
.24354 .57541 m .23835 .57833 L .23904 .57601 L F
.24354 .57541 m .24131 .57815 L .23835 .57833 L F
0 0 0 r
.24336 .57708 m .24131 .57815 L .24203 .57727 L F
.24336 .57708 m .24203 .57727 L .24354 .57541 L F
.24336 .57708 m .24354 .57541 L .24282 .57379 L F
.068 0 0 r
.24336 .57708 m .24678 .57589 L .24679 .57588 L F
.24454 .57657 m .24679 .57588 L .24798 .57509 L F
.24336 .57708 m .24679 .57588 L .24454 .57657 L F
.436 .543 .867 r
.24561 .5748 m .24601 .57087 L .24282 .57379 L F
.24561 .5748 m .24802 .57452 L .24601 .57087 L F
.068 0 0 r
.24336 .57708 m .24555 .57662 L .24798 .57509 L F
.702 .256 .188 r
.24679 .57588 m .24848 .57687 L .24678 .57589 L F
.24798 .57509 m .24847 .57684 L .24679 .57588 L F
.24847 .57684 m .24848 .57687 L .24679 .57588 L F
.271 .775 .861 r
.24775 .57645 m .24336 .57708 L .24678 .57589 L F
.068 0 0 r
.24555 .57662 m .24607 .57637 L .24798 .57509 L F
.61 .462 .656 r
.24601 .57087 m .24768 .57561 L .24363 .57409 L F
.24293 .5737 m .24363 .57409 L .24282 .57379 L F
.24601 .57087 m .24363 .57409 L .24293 .5737 L F
.271 .775 .861 r
.24796 .57642 m .24775 .57645 L .24687 .57586 L F
.24775 .57645 m .24678 .57589 L .24687 .57586 L F
.971 .81 .625 r
.24983 .57566 m .24878 .57747 L .24802 .57452 L F
.702 .256 .188 r
.24798 .57509 m .24983 .57703 L .24848 .57687 L F
.24678 .57589 m .24848 .57687 L .24577 .57657 L F
.068 0 0 r
.24555 .57662 m .24577 .57657 L .24607 .57637 L F
0 0 .299 r
.24815 .57194 m .24983 .57566 L .24873 .57324 L F
.98 .735 .491 r
.24802 .57452 m .24983 .57566 L .24815 .57194 L F
.963 .715 .512 r
.24601 .57087 m .24802 .57452 L .24815 .57194 L F
.24601 .57087 m .24802 .57452 L .24815 .57194 L F
.626 .745 .933 r
.24917 .57332 m .25045 .57363 L .2503 .57368 L F
.24917 .57332 m .2503 .57368 L .24802 .57452 L F
.409 .277 .589 r
.24798 .57509 m .24917 .57332 L .24802 .57452 L F
.522 .286 .498 r
.24798 .57509 m .25045 .57363 L .24802 .57452 L F
.24798 .57509 m .24983 .57703 L .25045 .57363 L F
.409 .277 .589 r
.24798 .57509 m .24983 .57703 L .24917 .57332 L F
.801 .561 .575 r
.24917 .57332 m .24841 .57527 L .24696 .57262 L F
.24917 .57332 m .24696 .57262 L .24601 .57087 L F
.24841 .57527 m .24796 .57642 L .24768 .57561 L F
.24841 .57527 m .24768 .57561 L .24601 .57087 L F
.61 .462 .656 r
.24768 .57561 m .24796 .57642 L .24687 .57586 L F
.24768 .57561 m .24687 .57586 L .24282 .57379 L F
.271 .775 .861 r
.24687 .57586 m .24336 .57708 L .24282 .57379 L F
.068 0 0 r
.24336 .57708 m .24577 .57657 L .24678 .57589 L F
.271 .775 .861 r
.24612 .57668 m .24577 .57657 L .24336 .57708 L F
.24796 .57642 m .24577 .57657 L .24612 .57668 L F
.258 0 0 r
.24879 .57415 m .24523 .57638 L .24577 .57657 L F
.058 0 0 r
.24577 .57657 m .24438 .57693 L .24336 .57708 L F
.258 0 0 r
.24523 .57638 m .24345 .57749 L .24577 .57657 L F
.379 .232 .553 r
.24336 .57708 m .24119 .5816 L .24131 .57815 L F
.748 .232 0 r
.23835 .57833 m .23432 .57465 L .23904 .57601 L F
.575 .392 .596 r
.24131 .57815 m .24119 .5816 L .23835 .57833 L F
.793 .716 .779 r
.23842 .57736 m .24119 .5816 L .24336 .57708 L F
.058 0 0 r
.24438 .57693 m .2414 .57772 L .24336 .57708 L F
.446 .863 .717 r
.53968 .47809 m .53556 .4802 L .53803 .47874 L F
.288 .788 .815 r
.54049 .47749 m .53968 .47809 L .53803 .47874 L F
.54049 .47749 m .54226 .47739 L .53968 .47809 L F
.819 .908 .901 r
.28725 .63927 m .28546 .64249 L .28369 .64112 L F
.531 .525 .794 r
.28546 .64249 m .28725 .63927 L .28369 .64112 L F
.28546 .64249 m .28835 .64225 L .28725 .63927 L F
.508 .36 .616 r
.53601 .41554 m .53618 .41852 L .53366 .41924 L F
.439 .137 .356 r
.53621 .42015 m .53366 .41924 L .53618 .41852 L F
.53621 .42015 m .53331 .4211 L .53366 .41924 L F
.933 .734 .612 r
.31759 .56214 m .31922 .566 L .32024 .56356 L F
.123 0 .106 r
.23716 .53667 m .24017 .53543 L .24131 .53261 L F
0 0 0 r
.24017 .53543 m .24345 .53309 L .24131 .53261 L F
.372 .126 .407 r
.67652 .34484 m .67363 .34301 L .67427 .34696 L F
.67652 .34484 m .67701 .34243 L .67363 .34301 L F
0 0 0 r
.54947 .40717 m .54732 .40825 L .54862 .40745 L F
.781 .6 .655 r
.34234 .57879 m .34618 .5798 L .34453 .57912 L F
.748 .449 .477 r
.34263 .58207 m .34599 .58244 L .34618 .5798 L F
.229 .025 .381 r
.34618 .5798 m .34798 .58133 L .34806 .57851 L F
.34618 .5798 m .34599 .58244 L .34798 .58133 L F
.823 .974 .892 r
.62072 .40971 m .61983 .40909 L .62149 .40731 L F
.282 .048 .371 r
.25615 .63251 m .25875 .62888 L .258 .63122 L F
.651 .921 .977 r
.25392 .63191 m .25615 .63251 L .258 .63122 L F
.834 .393 .183 r
.35938 .53975 m .35626 .53595 L .35955 .5346 L F
.35938 .53975 m .35565 .53892 L .35626 .53595 L F
.35938 .53975 m .35801 .54002 L .35565 .53892 L F
.53 .566 .836 r
.36066 .5365 m .35938 .53975 L .35955 .5346 L F
.225 0 0 r
.40858 .50246 m .4074 .50288 L .41053 .50267 L F
.598 .215 .289 r
.27756 .51629 m .27641 .51937 L .27418 .51871 L F
.026 0 .056 r
.27865 .51797 m .27756 .51629 L .27903 .51544 L F
.27865 .51797 m .27641 .51937 L .27756 .51629 L F
.23 0 0 r
.25875 .62888 m .25997 .62979 L .258 .63122 L F
.25875 .62888 m .26016 .62859 L .25997 .62979 L F
.884 .876 .823 r
.41123 .59284 m .40952 .59536 L .40808 .59301 L F
.778 .411 0 r
.40952 .59536 m .40958 .59654 L .40808 .59301 L F
.40952 .59536 m .41015 .59721 L .40958 .59654 L F
.913 .511 .179 r
.40808 .59301 m .40958 .59654 L .40763 .59564 L F
.204 .686 .932 r
.40958 .59654 m .41178 .59647 L .40906 .59593 L F
.40958 .59654 m .40906 .59593 L .40763 .59564 L F
.778 .411 0 r
.41015 .59721 m .41064 .59864 L .40958 .59654 L F
.883 .492 .036 r
.59109 .40939 m .59049 .41041 L .59001 .40757 L F
.59109 .40939 m .59198 .41238 L .59049 .41041 L F
.357 0 .157 r
.24345 .53309 m .2459 .53269 L .24758 .53006 L F
.399 .836 .703 r
.681 .37594 m .68311 .3747 L .68082 .37614 L F
.599 .865 .993 r
.44528 .4549 m .44153 .45491 L .4427 .45488 L F
.914 .658 .537 r
.37233 .54886 m .37466 .54696 L .37241 .54649 L F
.37233 .54886 m .37459 .54975 L .37466 .54696 L F
.526 .783 .991 r
.24511 .62836 m .24587 .62661 L .24321 .62767 L F
.24511 .62836 m .24781 .62821 L .24587 .62661 L F
.24511 .62836 m .24587 .62661 L .24321 .62767 L F
.24511 .62836 m .24781 .62821 L .24587 .62661 L F
0 0 0 r
.33597 .49676 m .33209 .49795 L .33449 .49737 L F
.314 0 0 r
.33449 .49737 m .33884 .49687 L .33597 .49676 L F
0 0 0 r
.48467 .5624 m .4826 .56567 L .4838 .56363 L F
.723 .955 .668 r
.56141 .38971 m .55969 .39083 L .55691 .38988 L F
.56141 .38971 m .5599 .39107 L .55969 .39083 L F
.453 .841 .625 r
.67715 .3782 m .67513 .37976 L .67732 .37817 L F
.465 .859 .666 r
.67363 .38053 m .67513 .37976 L .67715 .3782 L F
.946 .789 .332 r
.35312 .52735 m .35214 .52822 L .35108 .52578 L F
.35312 .52735 m .35271 .53012 L .35214 .52822 L F
.755 .641 .081 r
.25997 .62979 m .26016 .62859 L .26009 .62732 L F
.618 .946 .758 r
.63878 .40243 m .64224 .39987 L .64054 .4005 L F
.542 .914 .749 r
.64054 .4005 m .64224 .39987 L .6445 .39824 L F
.387 .647 .96 r
.55967 .37058 m .56239 .37091 L .56127 .37284 L F
.159 .348 .803 r
.56239 .37091 m .56427 .37488 L .56127 .37284 L F
.779 .928 .932 r
.70683 .32586 m .70781 .32713 L .7111 .32504 L F
.24 0 .076 r
.31522 .59292 m .31795 .59238 L .31863 .5908 L F
.444 .03 .159 r
.31863 .5908 m .31795 .59238 L .32066 .59172 L F
.857 .727 .718 r
.55887 .39602 m .55999 .39931 L .5573 .39911 L F
.87 .641 .589 r
.55999 .39931 m .55621 .40072 L .5573 .39911 L F
.55999 .39931 m .55985 .40226 L .55621 .40072 L F
.345 0 0 r
.40419 .48208 m .40002 .48402 L .40244 .48304 L F
.637 .123 .004 r
.40244 .48304 m .40615 .48342 L .40419 .48208 L F
.999 .8 .47 r
.58151 .44636 m .58296 .44517 L .5826 .44409 L F
.58151 .44636 m .58275 .44735 L .58296 .44517 L F
.381 .096 .349 r
.28529 .57948 m .28699 .58136 L .28712 .57891 L F
.28529 .57948 m .28468 .58208 L .28699 .58136 L F
.972 .864 .671 r
.69842 .33716 m .70028 .33735 L .69892 .3359 L F
.69842 .33716 m .69979 .33955 L .70028 .33735 L F
.955 .894 .727 r
.70028 .33735 m .70115 .33166 L .69892 .3359 L F
.427 .645 .949 r
.48558 .44901 m .4891 .45061 L .48829 .44799 L F
.608 .643 .859 r
.4891 .45061 m .4908 .44731 L .48829 .44799 L F
.4891 .45061 m .49218 .45083 L .4908 .44731 L F
.15 0 .257 r
.52035 .48166 m .51982 .48393 L .5223 .48057 L F
.658 .356 .451 r
.68912 .30337 m .69191 .30351 L .69205 .30131 L F
.507 .232 .431 r
.69205 .30131 m .69517 .30277 L .69516 .30021 L F
.69205 .30131 m .69191 .30351 L .69517 .30277 L F
.689 .446 .55 r
.23912 .57288 m .23904 .57601 L .23673 .57493 L F
.755 .988 .768 r
.63593 .4052 m .6384 .402 L .63531 .40476 L F
.63593 .4052 m .63878 .40243 L .6384 .402 L F
.356 .589 .933 r
.6017 .3718 m .60558 .3706 L .6054 .37021 L F
.703 .743 .882 r
.54185 .45403 m .5434 .45116 L .5406 .45439 L F
.54185 .45403 m .54556 .45348 L .5434 .45116 L F
.62 .897 .987 r
.25341 .62449 m .25442 .62548 L .25099 .62563 L F
.982 .699 .392 r
.25306 .62739 m .25442 .62548 L .25341 .62449 L F
.644 .948 .952 r
.34925 .64399 m .3543 .64249 L .35232 .64105 L F
.809 .76 .807 r
.35232 .64105 m .3543 .64249 L .35651 .63962 L F
.618 .946 .758 r
.63878 .40243 m .64054 .4005 L .6384 .402 L F
.829 .929 .898 r
.26971 .5188 m .26971 .52121 L .27164 .51907 L F
.934 .968 .732 r
.26971 .5188 m .26732 .52253 L .26971 .52121 L F
.915 .652 .526 r
.62326 .41411 m .62619 .41465 L .6244 .41208 L F
.903 .801 .737 r
.62404 .417 m .62619 .41465 L .62326 .41411 L F
.967 .809 .633 r
.69682 .3417 m .69979 .33955 L .69842 .33716 L F
.69682 .3417 m .6985 .34322 L .69979 .33955 L F
.861 .595 .535 r
.36693 .53901 m .36963 .5371 L .3671 .53622 L F
.36693 .53901 m .36976 .53985 L .36963 .5371 L F
.674 .918 .974 r
.64083 .38393 m .63903 .38632 L .64186 .38441 L F
0 .227 .705 r
.63903 .38632 m .64047 .38703 L .64083 .38393 L F
.63903 .38632 m .64104 .38766 L .64047 .38703 L F
.911 .938 .813 r
.63892 .38529 m .64047 .38703 L .63757 .38932 L F
.63906 .38487 m .64047 .38703 L .63892 .38529 L F
0 .227 .705 r
.64104 .38766 m .64182 .38818 L .64047 .38703 L F
.433 0 0 r
.42275 .45869 m .42358 .45938 L .42082 .45896 L F
.463 .223 .463 r
.42541 .45784 m .42515 .46043 L .42275 .45869 L F
.345 .125 .431 r
.42767 .45693 m .42515 .46043 L .42541 .45784 L F
.433 0 0 r
.42365 .45934 m .42515 .46043 L .42358 .45938 L F
.555 .84 .998 r
.42358 .45938 m .42515 .46043 L .4261 .45856 L F
.32 .801 .743 r
.4261 .45856 m .42354 .4594 L .42358 .45938 L F
.42354 .4594 m .4216 .46004 L .42358 .45938 L F
.433 0 0 r
.42275 .45869 m .42365 .45934 L .42358 .45938 L F
.864 .635 .59 r
.37926 .56274 m .38149 .56339 L .37947 .55975 L F
.915 .712 .614 r
.37905 .56536 m .38149 .56339 L .37926 .56274 L F
.37905 .56536 m .38107 .56615 L .38149 .56339 L F
.851 .987 .712 r
.5646 .41937 m .56217 .42283 L .5628 .42039 L F
.851 .984 .701 r
.5628 .42039 m .56217 .42283 L .56053 .42375 L F
.051 0 0 r
.53017 .42441 m .5309 .42243 L .53331 .4211 L F
.98 .805 .595 r
.57141 .41679 m .57354 .41559 L .57215 .41373 L F
.57141 .41679 m .57301 .41795 L .57354 .41559 L F
.859 .827 .815 r
.57215 .41373 m .57354 .41559 L .57602 .41219 L F
.38 .742 .991 r
.4336 .57575 m .43524 .57696 L .43082 .57594 L F
.83 .899 .888 r
.43722 .57502 m .43524 .57696 L .4336 .57575 L F
.611 .622 .837 r
.58838 .37141 m .59183 .3734 L .59057 .37219 L F
.635 .863 .985 r
.59313 .3711 m .59183 .3734 L .59455 .37241 L F
.59313 .3711 m .59057 .37219 L .59183 .3734 L F
.818 .618 .633 r
.5598 .38303 m .55962 .38572 L .5556 .38503 L F
.5598 .38303 m .5556 .38503 L .55847 .38393 L F
.291 0 0 r
.55847 .38393 m .56072 .38247 L .5598 .38303 L F
.969 .882 .69 r
.37914 .60829 m .3819 .60578 L .38093 .60382 L F
.37914 .60829 m .38063 .6091 L .3819 .60578 L F
.652 .784 .944 r
.30282 .66656 m .30465 .66806 L .30094 .66799 L F
.662 .289 .327 r
.30094 .66799 m .30465 .66806 L .30417 .6699 L F
.464 .62 .918 r
.30861 .66649 m .30465 .66806 L .30282 .66656 L F
.30861 .66649 m .30767 .6687 L .30465 .66806 L F
.499 .135 .279 r
.30417 .6699 m .30465 .66806 L .30683 .66985 L F
.817 .422 .306 r
.34431 .50625 m .34616 .50923 L .34811 .50749 L F
.825 .436 .314 r
.34811 .50749 m .34616 .50923 L .34875 .50953 L F
0 0 0 r
.54341 .40719 m .54586 .40424 L .54283 .4055 L F
0 0 .229 r
.54341 .40719 m .54283 .4055 L .54246 .4043 L F
.54341 .40719 m .54246 .4043 L .54071 .40843 L F
.742 .751 .86 r
.5434 .45116 m .54556 .45348 L .54707 .4516 L F
.454 .429 .741 r
.31795 .59238 m .3155 .59287 L .31522 .59292 L F
.085 0 .182 r
.25051 .54602 m .24929 .5492 L .24686 .55034 L F
.369 .425 .788 r
.24929 .5492 m .25037 .55155 L .24686 .55034 L F
0 0 .479 r
.71328 .28318 m .71452 .28142 L .71459 .28023 L F
0 0 0 r
.67048 .32755 m .6693 .32826 L .66651 .32905 L F
.415 0 0 r
.67334 .32866 m .6693 .32826 L .67048 .32755 L F
.465 .057 .181 r
.67293 .32732 m .67334 .32866 L .67048 .32755 L F
.809 .568 .573 r
.67427 .34696 m .67812 .34959 L .67567 .34899 L F
.939 .879 .749 r
.67812 .34959 m .67708 .34966 L .67567 .34899 L F
.67812 .34959 m .67635 .35352 L .67708 .34966 L F
.849 .561 .5 r
.38628 .52389 m .38362 .52343 L .383 .52068 L F
.837 .506 .427 r
.38628 .52389 m .38376 .52582 L .38362 .52343 L F
.902 .626 .511 r
.38629 .52637 m .38376 .52582 L .38628 .52389 L F
0 0 0 r
.51982 .48393 m .51764 .48524 L .51653 .48683 L F
.575 .1 .09 r
.33056 .52882 m .33554 .5279 L .33217 .52964 L F
.065 .525 .897 r
.31169 .57355 m .31519 .57512 L .31401 .57269 L F
.603 .433 .624 r
.31519 .57512 m .31881 .5747 L .31401 .57269 L F
.31519 .57512 m .31799 .57586 L .31881 .5747 L F
.837 .75 .767 r
.57779 .45639 m .58172 .45499 L .58018 .45376 L F
.57779 .45639 m .57965 .4584 L .58172 .45499 L F
.958 .856 .698 r
.58172 .45499 m .58132 .45115 L .58018 .45376 L F
.269 .091 .446 r
.23686 .53973 m .24017 .53543 L .23716 .53667 L F
.783 .376 .28 r
.37448 .49336 m .37388 .49129 L .37036 .49089 L F
.201 .35 .79 r
.60585 .4226 m .60702 .4206 L .60463 .42131 L F
.60585 .4226 m .60736 .42135 L .60702 .4206 L F
.60585 .4226 m .60885 .42456 L .60736 .42135 L F
.665 .834 .965 r
.48558 .44901 m .48829 .44799 L .48408 .4475 L F
0 .158 .697 r
.32417 .60768 m .32505 .60954 L .3237 .60803 L F
.768 .87 .923 r
.54759 .47344 m .54574 .47686 L .54484 .47474 L F
.54759 .47344 m .54914 .47494 L .54574 .47686 L F
.266 .696 .965 r
.5854 .43548 m .58467 .43523 L .58386 .43697 L F
.69 .979 .891 r
.62601 .41083 m .6263 .41167 L .63018 .40904 L F
.798 .599 .632 r
.52418 .42535 m .5256 .42913 L .5216 .42794 L F
.821 .706 .738 r
.527 .42502 m .5256 .42913 L .52418 .42535 L F
.967 .641 .301 r
.39655 .54636 m .39841 .55009 L .39688 .54892 L F
.921 .528 .209 r
.39841 .55009 m .39733 .55148 L .39688 .54892 L F
.39841 .55009 m .39915 .55255 L .39733 .55148 L F
.982 .91 .608 r
.40036 .57305 m .4007 .56857 L .40284 .56991 L F
.40036 .57305 m .39925 .57325 L .4007 .56857 L F
.922 .657 .519 r
.40036 .57305 m .39798 .57452 L .39925 .57325 L F
.40036 .57305 m .40017 .57573 L .39798 .57452 L F
.848 .989 .853 r
.60565 .37834 m .60319 .38273 L .60684 .37972 L F
.60565 .37834 m .60275 .38154 L .60319 .38273 L F
.61 .855 .99 r
.59704 .44562 m .60136 .44566 L .59972 .44445 L F
.878 .877 .83 r
.59972 .44445 m .60136 .44566 L .60369 .44242 L F
.817 .688 .722 r
.43119 .56679 m .43178 .56767 L .42938 .56939 L F
.232 0 .034 r
.42938 .56939 m .43178 .56767 L .43104 .57067 L F
.714 .277 0 r
.43145 .56785 m .43178 .56767 L .43119 .56679 L F
.799 .723 .192 r
.43104 .57067 m .43178 .56767 L .43145 .56785 L F
.319 .778 .639 r
.46035 .59418 m .45802 .59533 L .4591 .59481 L F
.875 .495 .32 r
.35953 .5256 m .36132 .52411 L .35961 .5227 L F
.35953 .5256 m .36172 .52635 L .36132 .52411 L F
.622 .686 .889 r
.30975 .64751 m .31091 .64928 L .31345 .64851 L F
.884 .876 .823 r
.41123 .59284 m .40808 .59301 L .40936 .59159 L F
.89 .568 .432 r
.36514 .53553 m .36701 .53379 L .36148 .53187 L F
.36514 .53553 m .3671 .53622 L .36701 .53379 L F
.591 .028 0 r
.24601 .57087 m .24558 .56974 L .24366 .57051 L F
.24601 .57087 m .24815 .57194 L .24558 .56974 L F
.156 0 .15 r
.52879 .41784 m .53153 .41441 L .52947 .41584 L F
.605 .065 0 r
.57622 .45485 m .57656 .45567 L .57423 .45672 L F
.57622 .45485 m .57779 .45639 L .57656 .45567 L F
.881 .688 .637 r
.60951 .42153 m .61279 .42237 L .61203 .41784 L F
.684 .59 .745 r
.61279 .42237 m .61363 .41671 L .61203 .41784 L F
.376 .096 .355 r
.2825 .58576 m .28488 .58705 L .28433 .58491 L F
.773 .947 .934 r
.28614 .58824 m .28586 .58773 L .28489 .58703 L F
.28586 .58773 m .28433 .58491 L .28488 .58702 L F
.28586 .58773 m .28488 .58702 L .28489 .58703 L F
.506 .52 .805 r
.28699 .58136 m .2891 .58511 L .28969 .58437 L F
.779 .984 .902 r
.28973 .58468 m .28902 .58521 L .28989 .58587 L F
.2897 .58449 m .28838 .58561 L .28973 .58468 L F
.506 .52 .805 r
.2891 .58511 m .28949 .5858 L .28969 .58437 L F
.779 .984 .902 r
.28902 .58521 m .28743 .58641 L .2882 .58624 L F
.28902 .58521 m .2882 .58624 L .28989 .58587 L F
.28838 .58561 m .28743 .58641 L .28973 .58468 L F
.734 .617 .728 r
.28433 .58491 m .28838 .58561 L .28699 .58136 L F
.28838 .58561 m .28949 .5858 L .2891 .58511 L F
.28838 .58561 m .2891 .58511 L .28699 .58136 L F
.773 .947 .934 r
.28586 .58773 m .28742 .58642 L .28433 .58491 L F
.28742 .58642 m .28838 .58561 L .28803 .58555 L F
.28742 .58642 m .28803 .58555 L .28433 .58491 L F
.87 .958 .86 r
.28989 .58587 m .28742 .58642 L .28614 .58824 L F
.779 .984 .902 r
.28483 .58698 m .28484 .58699 L .28742 .58642 L F
.28743 .58641 m .28742 .58642 L .28989 .58587 L F
.28483 .58698 m .28742 .58642 L .28743 .58641 L F
.773 .947 .934 r
.28614 .58824 m .28838 .58561 L .28586 .58773 L F
.87 .958 .86 r
.28742 .58642 m .28493 .58697 L .28614 .58824 L F
.773 .947 .934 r
.28614 .58824 m .28949 .5858 L .28838 .58561 L F
.779 .984 .902 r
.28969 .58437 m .28483 .58698 L .28743 .58641 L F
.28969 .58437 m .28743 .58641 L .2897 .58449 L F
.28483 .58698 m .28479 .587 L .28484 .58699 L F
.87 .958 .86 r
.28493 .58697 m .28489 .58703 L .28614 .58824 L F
.28489 .58703 m .28486 .58707 L .28614 .58824 L F
.376 .096 .355 r
.28488 .58705 m .28488 .58705 L .28489 .58703 L F
.773 .947 .934 r
.28614 .58824 m .28486 .58707 L .28489 .58704 L F
.376 .096 .355 r
.28488 .58705 m .28489 .58705 L .28489 .58704 L F
.28488 .58705 m .28489 .58704 L .28489 .58703 L F
.87 .958 .86 r
.28493 .58697 m .28479 .587 L .28486 .58707 L F
.773 .947 .934 r
.28489 .58704 m .28479 .587 L .28484 .58699 L F
.376 .096 .355 r
.2825 .58576 m .28176 .58823 L .28485 .58707 L F
.773 .947 .934 r
.28486 .58707 m .28486 .58707 L .28488 .58705 L F
.376 .096 .355 r
.28488 .58705 m .28485 .58707 L .28489 .58705 L F
.2825 .58576 m .28485 .58707 L .28488 .58705 L F
.773 .947 .934 r
.28488 .58705 m .28479 .587 L .28489 .58704 L F
.28486 .58707 m .28479 .587 L .28488 .58705 L F
.28614 .58824 m .28489 .58703 L .28489 .58704 L F
.28614 .58824 m .28484 .58699 L .28949 .5858 L F
.28614 .58824 m .28489 .58704 L .28489 .58705 L F
.376 .096 .355 r
.28488 .58705 m .28489 .58703 L .28433 .58491 L F
.832 .997 .838 r
.28969 .58437 m .28989 .58587 L .29274 .58277 L F
.535 0 0 r
.36217 .55663 m .36175 .55658 L .36068 .55533 L F
.36217 .55663 m .36455 .55874 L .36175 .55658 L F
.334 0 .105 r
.51575 .43177 m .51734 .43346 L .51464 .43333 L F
.51575 .43177 m .51844 .43129 L .51734 .43346 L F
0 .53 .772 r
.60094 .34393 m .60491 .34468 L .60204 .34444 L F
.317 .133 .465 r
.69518 .29767 m .6974 .29906 L .69751 .29666 L F
.69518 .29767 m .69516 .30021 L .6974 .29906 L F
.449 .839 .983 r
.59276 .34614 m .59151 .3455 L .59491 .3456 L F
.51 .459 .736 r
.2983 .58158 m .301 .58075 L .30118 .57916 L F
.2983 .58158 m .29919 .58233 L .301 .58075 L F
.983 .705 .339 r
.47733 .53697 m .47611 .53609 L .47633 .53386 L F
.892 .876 .813 r
.47733 .53697 m .47325 .53913 L .47611 .53609 L F
.776 .676 .753 r
.47925 .53296 m .47733 .53697 L .47633 .53386 L F
.983 .705 .339 r
.47733 .53697 m .47611 .53609 L .47633 .53386 L F
.859 .827 .815 r
.57215 .41373 m .57602 .41219 L .57467 .41093 L F
.979 .858 .649 r
.57552 .40844 m .57467 .41093 L .57602 .41219 L F
.956 .703 .514 r
.40159 .50672 m .40171 .51008 L .40331 .50861 L F
.728 .828 .927 r
.3953 .48356 m .39746 .48511 L .39401 .48724 L F
.3953 .48356 m .39401 .48724 L .39417 .48688 L F
.642 .783 .327 r
.39401 .48724 m .39302 .48916 L .39417 .48688 L F
.779 .995 .793 r
.50419 .5017 m .50502 .49957 L .5061 .50005 L F
.50419 .5017 m .50211 .50249 L .50502 .49957 L F
.284 .136 .496 r
.23439 .55013 m .2359 .54956 L .2361 .54694 L F
0 0 .127 r
.23439 .55013 m .23549 .55118 L .2359 .54956 L F
.23439 .55013 m .23326 .55284 L .23549 .55118 L F
.765 .996 .827 r
.4847 .41756 m .48271 .41948 L .48371 .41735 L F
.753 .952 .637 r
.48271 .41948 m .48107 .42076 L .48371 .41735 L F
.517 .436 .704 r
.62721 .35035 m .62786 .35292 L .62595 .35132 L F
.61 .429 .612 r
.62786 .35292 m .62525 .35397 L .62595 .35132 L F
.517 .436 .704 r
.62721 .35035 m .62786 .35292 L .62595 .35132 L F
.61 .429 .612 r
.62786 .35292 m .62525 .35397 L .62595 .35132 L F
.768 .853 .914 r
.59071 .36942 m .58838 .37141 L .58646 .36919 L F
.374 0 0 r
.59057 .37219 m .58715 .3729 L .58838 .37141 L F
.721 .717 .846 r
.41799 .51638 m .42218 .51735 L .42038 .51664 L F
.631 .925 .974 r
.57218 .45789 m .57309 .45865 L .57423 .45672 L F
.01 .1 .611 r
.25458 .59511 m .25531 .59926 L .25638 .59796 L F
.095 .231 .715 r
.25531 .59926 m .25754 .60118 L .25638 .59796 L F
.279 .131 .494 r
.32146 .62237 m .32087 .62285 L .32241 .6236 L F
.109 0 .264 r
.32146 .62237 m .32055 .62345 L .32087 .62285 L F
.32055 .62345 m .31836 .62608 L .32087 .62285 L F
.32087 .62285 m .3183 .62773 L .32034 .6263 L F
.312 .102 .424 r
.32241 .6236 m .32087 .62285 L .32034 .6263 L F
.654 .598 .779 r
.31776 .62142 m .31828 .62544 L .32146 .62237 L F
.31828 .62544 m .31836 .62608 L .32055 .62345 L F
.109 0 .264 r
.32087 .62285 m .32055 .62345 L .32055 .62345 L F
.654 .598 .779 r
.31828 .62544 m .32055 .62345 L .32146 .62237 L F
.109 0 .264 r
.32055 .62345 m .3183 .62773 L .3183 .62773 L F
.32055 .62345 m .3183 .62773 L .32055 .62345 L F
.32087 .62285 m .31836 .62608 L .3183 .62773 L F
.856 .714 .705 r
.71287 .31058 m .71279 .30902 L .71167 .3096 L F
0 0 .533 r
.71327 .3103 m .71287 .31058 L .71167 .3096 L F
.795 .805 .859 r
.71801 .3103 m .71327 .3103 L .71409 .30988 L F
.856 .714 .705 r
.71279 .30902 m .71268 .30693 L .71167 .3096 L F
.457 .49 .805 r
.70938 .30581 m .71167 .3096 L .71268 .30693 L F
.70938 .30581 m .71435 .30976 L .71167 .3096 L F
.795 .805 .859 r
.71801 .3103 m .71409 .30988 L .71728 .30947 L F
.102 .658 .757 r
.71399 .30992 m .71434 .30985 L .71448 .30987 L F
.71078 .30998 m .71327 .3103 L .71167 .3096 L F
.70955 .31051 m .7118 .31038 L .71078 .30998 L F
.7118 .31038 m .71327 .3103 L .71078 .30998 L F
0 0 .533 r
.71327 .3103 m .71465 .31328 L .71287 .31058 L F
.795 .805 .859 r
.71801 .3103 m .71465 .31328 L .71327 .3103 L F
.102 .658 .757 r
.70955 .31051 m .71314 .31024 L .71327 .3103 L F
0 .018 .554 r
.71654 .31346 m .71314 .31024 L .71359 .31437 L F
.335 .351 .729 r
.71433 .31285 m .71359 .31437 L .71322 .31095 L F
.71352 .31107 m .71322 .31095 L .71314 .31024 L F
.71433 .31285 m .71322 .31095 L .71352 .31107 L F
.102 .658 .757 r
.71014 .3104 m .71409 .30988 L .71399 .30992 L F
.71409 .30988 m .71434 .30985 L .71399 .30992 L F
.457 .49 .805 r
.71438 .30978 m .71434 .30985 L .71167 .3096 L F
.71435 .30976 m .71438 .30978 L .71431 .30978 L F
.795 .805 .859 r
.71728 .30947 m .71434 .30985 L .71477 .30962 L F
.71715 .30932 m .71477 .30962 L .71655 .30864 L F
.71728 .30947 m .71477 .30962 L .71715 .30932 L F
.457 .49 .805 r
.71436 .30981 m .71448 .30987 L .71434 .30985 L F
.71438 .30978 m .71448 .30987 L .71436 .30981 L F
.795 .805 .859 r
.71434 .30985 m .71409 .30988 L .71441 .30972 L F
.102 .658 .757 r
.71005 .31044 m .71014 .3104 L .71448 .30987 L F
.71014 .3104 m .71167 .3096 L .71434 .30985 L F
.794 .729 .792 r
.71409 .3097 m .70955 .31051 L .71448 .30987 L F
.457 .49 .805 r
.71435 .30976 m .71431 .30978 L .71167 .3096 L F
.794 .729 .792 r
.70853 .30735 m .70947 .31028 L .71409 .3097 L F
.102 .658 .757 r
.70955 .31051 m .71167 .3096 L .71005 .31044 L F
.794 .729 .792 r
.70947 .31028 m .70955 .31051 L .71409 .3097 L F
.795 .805 .859 r
.71434 .30985 m .71438 .30978 L .71443 .3098 L F
.76 .261 .036 r
.71428 .30978 m .71448 .30987 L .71438 .30978 L F
.71432 .30977 m .71438 .30978 L .71435 .30976 L F
.71428 .30978 m .71438 .30978 L .71432 .30977 L F
.795 .805 .859 r
.71443 .3098 m .71441 .30972 L .71655 .30864 L F
.71438 .30978 m .71441 .30972 L .71443 .3098 L F
.76 .261 .036 r
.71428 .30978 m .71435 .30976 L .70938 .30581 L F
.073 0 0 r
.71314 .31024 m .71348 .31008 L .71394 .30995 L F
.71348 .31008 m .71532 .30922 L .71417 .30982 L F
.71348 .31008 m .71417 .30982 L .71394 .30995 L F
.71532 .30922 m .71655 .30864 L .71441 .30972 L F
.71532 .30922 m .71441 .30972 L .71327 .3103 L F
.71348 .31008 m .71387 .31024 L .71655 .30864 L F
.71314 .31024 m .71394 .30995 L .71318 .31026 L F
.71314 .31024 m .71335 .31024 L .71348 .31008 L F
.71318 .31026 m .71394 .30995 L .71327 .3103 L F
.71335 .31024 m .71387 .31024 L .71348 .31008 L F
.76 .261 .036 r
.70853 .30735 m .71388 .30961 L .70938 .30581 L F
.71388 .30961 m .71428 .30978 L .71395 .30952 L F
.71388 .30961 m .71395 .30952 L .70938 .30581 L F
.256 .055 .403 r
.22984 .56209 m .23196 .55914 L .23025 .56014 L F
.708 .562 .686 r
.57416 .44853 m .57143 .45211 L .57008 .44832 L F
.7 .863 .959 r
.464 .44801 m .46809 .44812 L .46634 .4468 L F
.549 .811 .994 r
.46634 .4468 m .46809 .44812 L .47245 .44683 L F
.634 .072 0 r
.51912 .42072 m .52257 .42203 L .52014 .42016 L F
.723 .944 .955 r
.52266 .41849 m .52014 .42016 L .52257 .42203 L F
.317 .509 .887 r
.55805 .37744 m .55927 .37481 L .55784 .37429 L F
.55805 .37744 m .56133 .37827 L .55927 .37481 L F
.684 .59 .745 r
.61279 .42237 m .6158 .41944 L .61363 .41671 L F
.779 .597 .654 r
.57008 .44832 m .56753 .45132 L .56749 .44845 L F
.57008 .44832 m .57143 .45211 L .56753 .45132 L F
.993 .877 .593 r
.37533 .46411 m .3747 .46604 L .37388 .46311 L F
.701 .947 .957 r
.37533 .46411 m .37388 .46311 L .3758 .46302 L F
.522 .39 .642 r
.34533 .5974 m .34239 .59592 L .34652 .59601 L F
.34533 .5974 m .34383 .59921 L .34239 .59592 L F
.315 .341 .729 r
.25586 .52909 m .25671 .5331 L .25489 .53291 L F
.905 .661 .559 r
.37233 .54886 m .37593 .55025 L .37459 .54975 L F
.37233 .54886 m .37229 .55153 L .37593 .55025 L F
.929 .756 .646 r
.67635 .35352 m .67307 .35525 L .67556 .35252 L F
.67635 .35352 m .67596 .35623 L .67307 .35525 L F
.968 .917 .578 r
.67708 .34966 m .67635 .35352 L .67556 .35252 L F
.98 .707 .434 r
.39326 .50294 m .39325 .50563 L .39508 .5046 L F
.427 0 0 r
.39508 .5046 m .39325 .50563 L .39797 .50511 L F
.438 0 .047 r
.43248 .59962 m .43629 .59879 L .43485 .60061 L F
.302 0 0 r
.43629 .59879 m .43741 .60031 L .43485 .60061 L F
.43629 .59879 m .43882 .59835 L .43741 .60031 L F
.315 .145 .484 r
.2798 .58611 m .28176 .58823 L .2825 .58576 L F
.2798 .58611 m .27982 .58906 L .28176 .58823 L F
.623 .543 .743 r
.30593 .57819 m .30874 .57934 L .30812 .57626 L F
.381 .272 .604 r
.44924 .56942 m .44944 .572 L .4469 .5697 L F
.875 .661 .61 r
.38216 .57836 m .3856 .57635 L .38273 .57549 L F
.38216 .57836 m .38438 .57885 L .3856 .57635 L F
.755 .244 0 r
.37902 .5178 m .37842 .51856 L .37697 .51644 L F
.647 .088 0 r
.38067 .51941 m .37842 .51856 L .37902 .5178 L F
.463 .824 .56 r
.53601 .41554 m .53904 .41305 L .53895 .415 L F
.454 .238 .494 r
.54137 .41417 m .53904 .41305 L .54166 .41259 L F
.54137 .41417 m .53895 .415 L .53904 .41305 L F
.733 .614 .725 r
.60369 .44242 m .60604 .44093 L .60467 .43738 L F
.687 .59 .742 r
.60467 .43738 m .60604 .44093 L .60661 .43791 L F
.095 0 .297 r
.52048 .45471 m .51836 .45815 L .52033 .45757 L F
.181 .152 .587 r
.51975 .4588 m .51836 .45815 L .52033 .45757 L F
.095 0 .297 r
.52033 .45757 m .51836 .45815 L .52048 .45471 L F
.181 .152 .587 r
.51975 .4588 m .51836 .45815 L .52033 .45757 L F
.048 0 0 r
.62834 .33959 m .63064 .33924 L .63176 .33804 L F
.155 0 0 r
.63176 .33804 m .63387 .33817 L .63456 .33749 L F
.63176 .33804 m .63064 .33924 L .63387 .33817 L F
.709 .935 .962 r
.34475 .6467 m .34464 .64844 L .34679 .64714 L F
.835 .997 .835 r
.34356 .6481 m .34464 .64844 L .34475 .6467 L F
.851 .987 .712 r
.5646 .41937 m .5628 .42039 L .56292 .41781 L F
.616 .896 .987 r
.56439 .42774 m .56321 .42967 L .56164 .42842 L F
.56439 .42774 m .56583 .42859 L .56321 .42967 L F
.56439 .42774 m .56321 .42967 L .56164 .42842 L F
.56439 .42774 m .56583 .42859 L .56321 .42967 L F
.934 .668 .511 r
.41194 .51259 m .41381 .5111 L .40978 .51055 L F
.41194 .51259 m .41425 .5139 L .41381 .5111 L F
.996 .835 .568 r
.3972 .54353 m .39525 .54512 L .39546 .54237 L F
.3972 .54353 m .39655 .54636 L .39525 .54512 L F
.937 .706 .563 r
.37731 .56162 m .37947 .55975 L .37731 .55844 L F
.37731 .56162 m .37926 .56274 L .37947 .55975 L F
.976 .921 .625 r
.42203 .57404 m .42398 .57081 L .42293 .57307 L F
.703 .744 .236 r
.52578 .39371 m .52429 .39872 L .52483 .396 L F
0 0 0 r
.57586 .3626 m .57692 .36264 L .57833 .36226 L F
.456 .228 .479 r
.29702 .58609 m .29659 .58875 L .29414 .58934 L F
.29702 .58609 m .29659 .58875 L .29414 .58934 L F
.922 .761 .665 r
.42669 .55169 m .42961 .54999 L .42828 .5489 L F
.42669 .55169 m .42905 .55302 L .42961 .54999 L F
.561 .821 .994 r
.46265 .5942 m .4659 .59407 L .46428 .59255 L F
.466 .268 .526 r
.53182 .39602 m .53441 .39786 L .53442 .3956 L F
.53182 .39602 m .53182 .39865 L .53441 .39786 L F
.53182 .39602 m .53441 .39786 L .53442 .3956 L F
.53182 .39602 m .53182 .39865 L .53441 .39786 L F
.809 .76 .807 r
.35232 .64105 m .35651 .63962 L .35498 .63782 L F
.657 .741 .912 r
.35651 .63962 m .35902 .63859 L .35498 .63782 L F
.498 .124 .261 r
.38029 .493 m .38126 .49053 L .37862 .49061 L F
.447 .188 .427 r
.30476 .6301 m .30566 .62775 L .30273 .62866 L F
0 0 0 r
.4888 .54897 m .48703 .55276 L .48769 .55097 L F
.685 .979 .829 r
.60737 .39794 m .60486 .4 L .60287 .40047 L F
.787 .684 .75 r
.42811 .56998 m .42746 .57356 L .42293 .57307 L F
.708 .175 0 r
.42645 .57537 m .42293 .57307 L .42746 .57356 L F
.336 .255 .615 r
.4293 .57212 m .42746 .57356 L .42811 .56998 L F
0 0 0 r
.4293 .57212 m .42645 .57537 L .42746 .57356 L F
.4293 .57212 m .42645 .57537 L .42746 .57356 L F
.779 .928 .932 r
.70683 .32586 m .7111 .32504 L .70919 .32433 L F
.683 .949 .957 r
.71256 .32255 m .7111 .32504 L .71362 .32392 L F
.71256 .32255 m .70919 .32433 L .7111 .32504 L F
.561 .086 .086 r
.39049 .49271 m .39213 .49103 L .38846 .49103 L F
.718 .918 .568 r
.39302 .48916 m .39213 .49103 L .39049 .49271 L F
.641 .467 .631 r
.52312 .45138 m .52539 .44819 L .52298 .44866 L F
.74 .777 .883 r
.28631 .6377 m .29083 .63844 L .2888 .63974 L F
.827 .999 .828 r
.49715 .40919 m .49419 .41221 L .49467 .40996 L F
.827 .999 .827 r
.49419 .41221 m .49388 .41136 L .49467 .40996 L F
.975 .722 .307 r
.40023 .55658 m .39918 .55537 L .39915 .55255 L F
.998 .776 .454 r
.40023 .55658 m .39859 .55812 L .39918 .55537 L F
.40023 .55658 m .39999 .5594 L .39859 .55812 L F
.849 .892 .869 r
.7083 .29983 m .70518 .30283 L .70663 .30416 L F
0 .326 .808 r
.70842 .30413 m .70663 .30416 L .70518 .30283 L F
0 0 .236 r
.70952 .30332 m .70951 .30335 L .70842 .30413 L F
0 .326 .808 r
.70842 .30413 m .70938 .30581 L .70757 .30473 L F
.76 .261 .036 r
.70853 .30735 m .70938 .30581 L .70842 .30413 L F
0 0 .236 r
.70951 .30335 m .70853 .30735 L .70842 .30413 L F
0 .326 .808 r
.70842 .30413 m .70757 .30473 L .70663 .30416 L F
.903 .951 .823 r
.60783 .3753 m .60684 .37972 L .60746 .37788 L F
.60783 .3753 m .60565 .37834 L .60684 .37972 L F
.605 .794 .972 r
.33725 .515 m .33546 .51782 L .3397 .51708 L F
.679 .184 .064 r
.29002 .55381 m .28764 .55484 L .2852 .55262 L F
.633 .954 .772 r
.29081 .55247 m .29002 .55381 L .2915 .55229 L F
.29081 .55247 m .28764 .55484 L .29002 .55381 L F
.463 .253 .509 r
.43492 .4847 m .43753 .48621 L .43858 .48395 L F
.395 .1 .343 r
.45383 .58604 m .45765 .58376 L .45609 .58587 L F
.454 .429 .741 r
.31795 .59238 m .31802 .59509 L .3155 .59287 L F
.3155 .59287 m .31802 .59509 L .31795 .59238 L F
.3155 .59287 m .31802 .59509 L .31795 .59238 L F
.407 .532 .87 r
.55904 .43109 m .56082 .43483 L .5629 .43447 L F
.607 .183 0 r
.56082 .43483 m .56373 .438 L .5629 .43447 L F
.706 .967 .727 r
.55039 .48118 m .55334 .47828 L .55154 .47921 L F
.704 .985 .843 r
.54813 .48164 m .55039 .48118 L .55154 .47921 L F
.969 .667 .274 r
.58202 .42996 m .58303 .42878 L .58138 .42785 L F
.58202 .42996 m .58327 .4313 L .58303 .42878 L F
.522 .046 .066 r
.67714 .32722 m .67334 .32866 L .67293 .32732 L F
.67714 .32722 m .67565 .3288 L .67334 .32866 L F
.679 .231 .179 r
.67969 .3291 m .67565 .3288 L .67714 .32722 L F
.52 .245 .438 r
.30094 .66799 m .30033 .67039 L .2978 .67094 L F
.613 .688 .896 r
.30282 .66656 m .30094 .66799 L .2986 .66405 L F
.662 .289 .327 r
.30094 .66799 m .30417 .6699 L .30033 .67039 L F
.988 .896 .6 r
.72852 .31068 m .72965 .30712 L .7288 .30557 L F
.041 0 0 r
.4659 .59407 m .46727 .59437 L .46428 .59255 L F
.526 .895 .969 r
.32403 .54306 m .32045 .5435 L .32182 .54403 L F
.335 .797 .679 r
.30627 .54745 m .30378 .54852 L .30632 .54732 L F
.878 .877 .83 r
.59972 .44445 m .60369 .44242 L .59946 .44165 L F
0 0 0 r
.64111 .33386 m .64219 .33332 L .64376 .33294 L F
.64111 .33386 m .63977 .33476 L .64219 .33332 L F
.729 .921 .957 r
.47925 .53296 m .47633 .53386 L .47851 .53195 L F
.884 .873 .821 r
.59897 .42363 m .59625 .42447 L .59791 .42118 L F
0 .163 .702 r
.60089 .42514 m .59897 .42363 L .59791 .42118 L F
.706 .977 .773 r
.6096 .40889 m .61294 .40596 L .611 .40686 L F
.646 .898 .983 r
.60852 .40798 m .6096 .40889 L .611 .40686 L F
.871 .948 .589 r
.3062 .64064 m .30822 .63844 L .30594 .64263 L F
.796 .992 .878 r
.30796 .63641 m .31109 .63598 L .30822 .63844 L F
.898 .947 .592 r
.30796 .63641 m .30822 .63844 L .3062 .64064 L F
.769 .969 .68 r
.25237 .55173 m .24996 .55473 L .25241 .55284 L F
.646 .967 .89 r
.46097 .43449 m .45863 .4361 L .4566 .43619 L F
.878 .537 .4 r
.36354 .50179 m .35883 .50165 L .35834 .49952 L F
.36354 .50179 m .36238 .50331 L .35883 .50165 L F
.792 .933 .925 r
.50429 .43958 m .50665 .43826 L .50537 .4372 L F
0 0 0 r
.50853 .43703 m .50665 .43826 L .509 .43656 L F
0 0 .238 r
.50616 .44106 m .50665 .43826 L .50853 .43703 L F
.934 .612 .405 r
.383 .52068 m .38114 .52212 L .38067 .51941 L F
.383 .52068 m .38362 .52343 L .38114 .52212 L F
.863 .64 .598 r
.38331 .56978 m .38107 .56615 L .381 .56897 L F
.898 .689 .612 r
.381 .56897 m .38281 .57246 L .38331 .56978 L F
.509 .79 .996 r
.26618 .64074 m .26804 .64209 L .27051 .64146 L F
.638 .723 .909 r
.47754 .44613 m .48207 .4475 L .48042 .44505 L F
.3 .567 .931 r
.48042 .44505 m .48207 .4475 L .48408 .4475 L F
.649 .831 .97 r
.70946 .28305 m .70493 .28398 L .70899 .28455 L F
.448 .221 .475 r
.70613 .2879 m .70899 .28455 L .70493 .28398 L F
.70613 .2879 m .70883 .28699 L .70899 .28455 L F
.313 .468 .854 r
.70899 .28455 m .71037 .28216 L .70946 .28305 L F
0 0 .261 r
.70899 .28455 m .7105 .28473 L .71037 .28216 L F
.865 .88 .846 r
.55202 .47144 m .54914 .47494 L .54759 .47344 L F
.224 0 .096 r
.4008 .45742 m .40431 .45478 L .40142 .45508 L F
.714 .277 0 r
.43145 .56785 m .43119 .56679 L .43067 .56181 L F
.419 .118 .345 r
.70441 .27892 m .70647 .27827 L .70737 .27797 L F
.505 .318 .561 r
.5347 .40905 m .53483 .41168 L .5377 .4103 L F
.5347 .40905 m .53483 .41168 L .5377 .4103 L F
.619 .799 .968 r
.39408 .50074 m .39711 .50118 L .39605 .49947 L F
.827 .999 .828 r
.49715 .40919 m .49467 .40996 L .49586 .40881 L F
.689 .975 .789 r
.49715 .40919 m .49832 .40731 L .49896 .40751 L F
.65 .954 .943 r
.49715 .40919 m .49586 .40881 L .49832 .40731 L F
.122 .524 .914 r
.52976 .47362 m .53035 .47293 L .52668 .47175 L F
.734 .654 .77 r
.53334 .46992 m .52976 .47362 L .53224 .47226 L F
.537 .852 .553 r
.53113 .47224 m .52976 .47362 L .53161 .47171 L F
.53314 .47021 m .53035 .47293 L .52976 .47362 L F
.494 .341 .602 r
.53035 .47293 m .53071 .47601 L .52749 .47612 L F
.973 .69 .428 r
.529 .47495 m .53071 .47601 L .53037 .47308 L F
.5299 .4736 m .53037 .47308 L .53035 .47293 L F
.529 .47495 m .53037 .47308 L .5299 .4736 L F
.537 .852 .553 r
.53314 .47021 m .53113 .47224 L .53334 .46992 L F
.53113 .47224 m .53161 .47171 L .53334 .46992 L F
.234 0 0 r
.52329 .42844 m .5256 .42913 L .52412 .42872 L F
.324 .801 .732 r
.5256 .42913 m .52596 .42878 L .52412 .42872 L F
.263 0 .083 r
.52526 .4291 m .52412 .42872 L .52596 .42878 L F
.52376 .42979 m .52412 .42872 L .52526 .4291 L F
.234 0 0 r
.5216 .42794 m .52329 .42844 L .52412 .42872 L F
0 .092 .641 r
.52896 .42602 m .527 .42502 L .53017 .42441 L F
.324 .171 .513 r
.6119 .37268 m .61399 .3732 L .61515 .37126 L F
.6119 .37268 m .61208 .37569 L .61399 .3732 L F
.367 .827 .739 r
.4233 .45004 m .42074 .4512 L .42221 .45035 L F
.368 .834 .782 r
.42221 .45035 m .42074 .4512 L .4198 .45134 L F
.619 .635 .844 r
.70245 .28564 m .70613 .2879 L .70493 .28398 L F
.478 .445 .743 r
.70613 .2879 m .70925 .28978 L .70883 .28699 L F
.352 .528 .89 r
.32066 .59172 m .32307 .59552 L .32457 .59357 L F
0 0 .424 r
.32307 .59552 m .32437 .59761 L .32457 .59357 L F
.374 .808 .963 r
.71738 .324 m .71637 .3234 L .71362 .32392 L F
.323 .756 .97 r
.71738 .324 m .71852 .32269 L .71637 .3234 L F
.71738 .324 m .7204 .32381 L .71852 .32269 L F
.889 .679 .613 r
.39173 .53401 m .39134 .53647 L .38908 .53283 L F
.85 .829 .827 r
.51681 .50604 m .51747 .50673 L .52169 .50471 L F
.707 .973 .924 r
.52337 .50309 m .51868 .50508 L .52169 .50471 L F
.762 .685 .778 r
.34964 .56335 m .34728 .56321 L .34907 .56071 L F
.652 .2 .167 r
.34964 .56335 m .34835 .56497 L .34728 .56321 L F
.538 .523 .787 r
.35117 .55906 m .34964 .56335 L .34907 .56071 L F
.35117 .55906 m .35243 .56354 L .34964 .56335 L F
.844 .836 .838 r
.35243 .56354 m .34835 .56497 L .34964 .56335 L F
.12 0 0 r
.2741 .51292 m .27217 .51467 L .2748 .51384 L F
.27 0 0 r
.62057 .36946 m .61731 .37154 L .61937 .37099 L F
.358 .127 .421 r
.63783 .38266 m .63572 .38488 L .63774 .38496 L F
.32 .494 .874 r
.63774 .38496 m .63572 .38488 L .63783 .38266 L F
.677 .915 .59 r
.44188 .4844 m .44021 .48587 L .43913 .48773 L F
.46 .747 .991 r
.43913 .48773 m .44021 .48587 L .43753 .48621 L F
.614 .449 .635 r
.53895 .415 m .53618 .41852 L .53601 .41554 L F
.977 .899 .552 r
.58386 .43697 m .58467 .43523 L .58313 .43645 L F
.963 .916 .566 r
.58313 .43645 m .58467 .43523 L .58409 .43415 L F
.476 .697 .965 r
.61988 .35421 m .62138 .35594 L .61967 .35699 L F
.61988 .35421 m .62138 .35594 L .61967 .35699 L F
.479 .52 .822 r
.28498 .6149 m .28321 .61603 L .28147 .61389 L F
0 0 0 r
.28157 .61746 m .28321 .61603 L .28498 .6149 L F
.622 .468 .652 r
.53977 .44831 m .5434 .45116 L .54287 .44751 L F
.53977 .44831 m .54148 .45288 L .5434 .45116 L F
0 0 0 r
.33209 .49795 m .32949 .50089 L .33128 .49921 L F
.312 0 .049 r
.33128 .49921 m .33409 .49866 L .33209 .49795 L F
.304 0 .113 r
.33209 .49795 m .33409 .49866 L .33449 .49737 L F
.593 .086 .015 r
.57322 .38568 m .57593 .38726 L .57733 .3858 L F
.977 .679 .371 r
.57593 .38726 m .57751 .38848 L .57733 .3858 L F
.341 0 0 r
.42581 .59932 m .42681 .60052 L .42422 .60084 L F
.42581 .59932 m .42847 .59957 L .42681 .60052 L F
0 0 .294 r
.33012 .51277 m .32947 .51685 L .32822 .51492 L F
.33012 .51277 m .33037 .51533 L .32947 .51685 L F
.33012 .51277 m .33037 .51533 L .32947 .51685 L F
.948 .957 .708 r
.40259 .50219 m .40159 .50672 L .40281 .50445 L F
0 0 .078 r
.48944 .54662 m .48895 .55001 L .4888 .54897 L F
0 0 0 r
.48943 .54676 m .48944 .54662 L .48946 .54455 L F
.48943 .54676 m .48895 .55001 L .48944 .54662 L F
.333 .816 .845 r
.63617 .39105 m .63247 .3917 L .63516 .3909 L F
.549 .912 .958 r
.63757 .38932 m .63617 .39105 L .63516 .3909 L F
.63757 .38932 m .63966 .3898 L .63617 .39105 L F
.814 .539 .523 r
.42905 .55302 m .42903 .55579 L .43232 .55564 L F
.941 .738 .6 r
.42946 .55798 m .43232 .55564 L .42903 .55579 L F
.42946 .55798 m .43191 .55923 L .43232 .55564 L F
.691 .465 .575 r
.53532 .42633 m .53785 .42575 L .53738 .42296 L F
.52 .349 .59 r
.53785 .42575 m .54063 .42404 L .53738 .42296 L F
0 0 0 r
.57815 .39397 m .57787 .39544 L .57833 .39236 L F
0 0 .372 r
.57751 .38848 m .57841 .39131 L .57833 .39236 L F
.718 .642 .082 r
.57841 .39131 m .57815 .39397 L .57833 .39236 L F
0 0 0 r
.35719 .61566 m .3604 .61208 L .35884 .61392 L F
.36286 .61156 m .35884 .61392 L .3604 .61208 L F
.43096 .44818 m .43051 .4484 L .42854 .44898 L F
.43096 .44818 m .43278 .44708 L .43051 .4484 L F
.466 .288 .554 r
.30212 .54785 m .30378 .54852 L .29989 .54816 L F
0 .507 .849 r
.2845 .61429 m .28498 .6149 L .28407 .61464 L F
.2845 .61429 m .28407 .61464 L .28147 .61389 L F
0 0 0 r
.28157 .61746 m .28498 .6149 L .28291 .61665 L F
.28461 .61419 m .2845 .61429 L .28291 .61665 L F
.787 .997 .798 r
.28538 .61309 m .28498 .6149 L .2845 .61429 L F
0 0 0 r
.28538 .61309 m .2845 .61429 L .28461 .61419 L F
0 .507 .849 r
.2845 .61429 m .28147 .61389 L .2808 .61426 L F
.882 .99 .745 r
.59557 .4383 m .5982 .43486 L .59633 .43502 L F
.595 .628 .854 r
.5982 .43486 m .59946 .43041 L .59694 .4315 L F
.5982 .43486 m .60117 .43383 L .59946 .43041 L F
.5982 .43486 m .59946 .43041 L .59694 .4315 L F
.5982 .43486 m .60117 .43383 L .59946 .43041 L F
.31 .798 .766 r
.5982 .43486 m .59893 .43423 L .59633 .43502 L F
.5982 .43486 m .60117 .43383 L .59893 .43423 L F
.215 .037 .411 r
.24316 .56254 m .24284 .56555 L .2406 .56612 L F
.353 0 .183 r
.24284 .56555 m .23915 .56798 L .2406 .56612 L F
.864 .839 .819 r
.39966 .58238 m .3975 .58161 L .39985 .57868 L F
.833 .377 0 r
.40026 .58518 m .3975 .58161 L .39966 .58238 L F
.416 .127 .364 r
.50697 .41693 m .5052 .41545 L .50783 .41449 L F
.50697 .41693 m .5052 .41545 L .50783 .41449 L F
.401 .088 .315 r
.35164 .57585 m .35448 .5753 L .35498 .57228 L F
.457 .329 .618 r
.35498 .57228 m .35759 .57123 L .35769 .56874 L F
.227 0 .265 r
.35498 .57228 m .35726 .57225 L .35759 .57123 L F
.35498 .57228 m .35448 .5753 L .35726 .57225 L F
.379 .153 .441 r
.54685 .41875 m .54421 .42209 L .54667 .42157 L F
.54667 .42157 m .54421 .42209 L .54685 .41875 L F
.932 .92 .779 r
.37823 .61263 m .38063 .6091 L .37914 .60829 L F
.917 .891 .79 r
.3973 .48992 m .40142 .48756 L .399 .48829 L F
.3973 .48992 m .39924 .49129 L .40142 .48756 L F
.686 .711 .867 r
.40142 .48756 m .40244 .48304 L .40002 .48402 L F
.40142 .48756 m .40365 .48636 L .40288 .48425 L F
.40217 .48424 m .40288 .48425 L .40244 .48304 L F
.40142 .48756 m .40288 .48425 L .40217 .48424 L F
.491 .546 .841 r
.40244 .48439 m .40142 .48756 L .40002 .48402 L F
.396 0 0 r
.39826 .48514 m .40244 .48439 L .40143 .48424 L F
.39969 .48423 m .40143 .48424 L .40002 .48402 L F
.39826 .48514 m .40143 .48424 L .39969 .48423 L F
.894 .978 .815 r
.399 .48829 m .40142 .48756 L .40244 .48439 L F
.844 .997 .771 r
.611 .40686 m .61294 .40596 L .61364 .4036 L F
.454 .474 .79 r
.55592 .45709 m .55639 .45402 L .55402 .45422 L F
.86 .997 .785 r
.55471 .46825 m .55202 .47144 L .55251 .46912 L F
.926 .972 .751 r
.55471 .46825 m .55251 .46912 L .55468 .46561 L F
.396 0 0 r
.43248 .59962 m .43308 .60062 L .43082 .59986 L F
.43248 .59962 m .43485 .60061 L .43308 .60062 L F
.581 .024 0 r
.38782 .49176 m .38846 .49103 L .38399 .49011 L F
.561 .086 .086 r
.39049 .49271 m .38846 .49103 L .38782 .49176 L F
.783 .862 .908 r
.25099 .62563 m .24781 .62821 L .24587 .62661 L F
.286 .578 .94 r
.24781 .62821 m .2481 .62619 L .24587 .62661 L F
.24781 .62821 m .25026 .62865 L .2481 .62619 L F
.181 .591 .941 r
.24781 .62821 m .25026 .62865 L .24587 .62661 L F
.907 .511 .103 r
.56288 .44163 m .5645 .44411 L .56196 .44419 L F
.658 .956 .741 r
.68311 .3747 m .68667 .37214 L .68656 .3725 L F
0 0 0 r
.68667 .37214 m .68948 .36926 L .68866 .37086 L F
.68656 .3725 m .68667 .37214 L .68866 .37086 L F
.647 .797 .955 r
.43376 .592 m .43119 .59353 L .42977 .59156 L F
.982 .811 .597 r
.39851 .4936 m .39924 .49129 L .3973 .48992 L F
.138 .315 .78 r
.35247 .56823 m .35211 .57041 L .3501 .56634 L F
.991 .865 .519 r
.3509 .57205 m .35211 .57041 L .35247 .56823 L F
.247 0 0 r
.62425 .3712 m .62224 .37143 L .62007 .37102 L F
.505 0 0 r
.62224 .37143 m .62185 .37118 L .62007 .37102 L F
.27 0 0 r
.62057 .36946 m .62007 .37102 L .61836 .37087 L F
.505 0 0 r
.62185 .37118 m .619 .36928 L .62007 .37102 L F
.27 0 0 r
.61836 .37087 m .62007 .37102 L .61731 .37154 L F
.211 .338 .775 r
.6198 .36592 m .62248 .36751 L .62057 .36946 L F
.571 .054 0 r
.62425 .3712 m .62057 .36946 L .62248 .36751 L F
0 0 0 r
.66018 .37787 m .66064 .37654 L .65772 .37937 L F
.166 0 .036 r
.6632 .37543 m .66064 .37654 L .66018 .37787 L F
0 0 0 r
.42194 .55446 m .42104 .5588 L .42032 .55639 L F
.687 .969 .76 r
.32859 .61164 m .32484 .61416 L .32658 .61106 L F
.854 .836 .827 r
.32859 .61164 m .3264 .61417 L .32462 .61484 L F
.738 .901 .518 r
.48682 .52302 m .48472 .52644 L .48545 .52465 L F
.763 .962 .66 r
.48472 .52644 m .48288 .52783 L .48545 .52465 L F
.574 .875 .994 r
.47245 .44683 m .47417 .44743 L .47313 .44664 L F
.65 .915 .979 r
.47417 .44743 m .47547 .44522 L .47313 .44664 L F
.47417 .44743 m .47754 .44613 L .47547 .44522 L F
.209 0 0 r
.50429 .43958 m .50065 .44178 L .5031 .43744 L F
.46 .538 .849 r
.5031 .43744 m .50429 .43958 L .50537 .4372 L F
.5031 .43744 m .50429 .43958 L .50537 .4372 L F
0 0 .047 r
.56 .40948 m .56023 .40957 L .55794 .4079 L F
.56 .40948 m .55979 .41283 L .56023 .40957 L F
.971 .661 .288 r
.33928 .49924 m .3409 .50305 L .3415 .50044 L F
.888 .972 .831 r
.44909 .45743 m .45161 .45444 L .45049 .45339 L F
.872 .974 .85 r
.45049 .45339 m .45161 .45444 L .4546 .45092 L F
.762 .725 .818 r
.4908 .44731 m .49218 .45083 L .49481 .44789 L F
.904 .815 .75 r
.67307 .35525 m .67596 .35623 L .67379 .35948 L F
.986 .726 .442 r
.40147 .56296 m .40004 .56476 L .39927 .5624 L F
.40147 .56296 m .40158 .56601 L .40004 .56476 L F
.888 .972 .831 r
.44909 .45743 m .45049 .45339 L .44783 .45427 L F
.561 .629 .877 r
.44909 .45743 m .44783 .45427 L .44528 .4549 L F
.989 .734 .441 r
.61322 .36305 m .61188 .36255 L .61126 .35789 L F
.512 .862 .991 r
.61617 .36238 m .61188 .36255 L .61322 .36305 L F
.981 .911 .609 r
.47806 .57891 m .47705 .58259 L .47793 .58002 L F
.808 .785 .832 r
.60156 .4082 m .59912 .41129 L .60292 .41138 L F
.831 .665 .677 r
.59912 .41129 m .60085 .41488 L .60292 .41138 L F
.737 .753 .866 r
.60156 .4082 m .60292 .41138 L .60589 .40904 L F
.736 .263 0 r
.67427 .34696 m .67567 .34899 L .67436 .34783 L F
.67427 .34696 m .67436 .34783 L .67652 .34484 L F
.846 .993 .744 r
.52494 .49884 m .52454 .50102 L .52495 .50014 L F
.914 .981 .751 r
.52494 .49884 m .52337 .50309 L .52454 .50102 L F
.632 .265 .328 r
.32844 .58476 m .33325 .58271 L .33022 .58246 L F
.514 .23 .421 r
.54685 .41875 m .54947 .42085 L .54667 .42157 L F
.54685 .41875 m .54904 .4179 L .54947 .42085 L F
.538 .371 .604 r
.54667 .42157 m .54832 .41808 L .54685 .41875 L F
.54832 .41808 m .54885 .41695 L .54685 .41875 L F
.54667 .42157 m .54947 .42085 L .54899 .41781 L F
.54832 .41808 m .54899 .41781 L .54885 .41695 L F
.352 .822 .761 r
.54842 .41803 m .54904 .4179 L .54685 .41875 L F
.393 .2 .496 r
.5523 .41725 m .54904 .4179 L .55213 .4147 L F
.808 .733 .781 r
.54899 .41781 m .55076 .41712 L .54885 .41695 L F
.352 .822 .761 r
.54932 .41763 m .54923 .41772 L .54842 .41803 L F
.54923 .41772 m .54904 .4179 L .54842 .41803 L F
.241 .755 .843 r
.5523 .41725 m .54904 .4179 L .54923 .41772 L F
.808 .733 .781 r
.5523 .41725 m .54947 .42085 L .54904 .4179 L F
.54947 .42085 m .55076 .41712 L .54899 .41781 L F
.241 .755 .843 r
.5523 .41725 m .54923 .41772 L .54934 .41761 L F
.808 .733 .781 r
.55063 .41751 m .5523 .41725 L .55076 .41712 L F
.54947 .42085 m .5523 .41725 L .55063 .41751 L F
.538 .371 .604 r
.54667 .42157 m .54899 .41781 L .54832 .41808 L F
.352 .822 .761 r
.54934 .41761 m .54932 .41763 L .54832 .41808 L F
.54823 .41812 m .54832 .41808 L .54685 .41875 L F
.54934 .41761 m .54832 .41808 L .54823 .41812 L F
.181 0 .356 r
.54885 .41695 m .54934 .41761 L .54685 .41875 L F
.786 .328 .155 r
.55639 .45402 m .55401 .45152 L .55402 .45422 L F
0 0 .233 r
.25772 .5382 m .25576 .54282 L .25522 .54023 L F
.44 .167 .401 r
.52038 .43974 m .51746 .44185 L .51877 .43962 L F
.17 .309 .764 r
.51877 .43962 m .51746 .44185 L .52016 .4436 L F
.121 .672 .761 r
.60491 .34468 m .60766 .34439 L .60895 .34441 L F
.282 0 0 r
.60766 .34439 m .61156 .34401 L .60895 .34441 L F
0 0 0 r
.68948 .36926 m .69187 .36821 L .69184 .36837 L F
.68866 .37086 m .68948 .36926 L .69184 .36837 L F
.818 .588 .59 r
.55962 .38572 m .55793 .38571 L .5556 .38503 L F
.524 .335 .566 r
.36385 .48757 m .36667 .48723 L .36648 .48424 L F
.36385 .48757 m .36667 .48723 L .36648 .48424 L F
0 0 0 r
.65772 .37937 m .65401 .38206 L .65671 .38074 L F
.66018 .37787 m .65772 .37937 L .65671 .38074 L F
.777 .998 .823 r
.55437 .47601 m .55334 .47828 L .55495 .47655 L F
.778 .984 .728 r
.55154 .47921 m .55334 .47828 L .55437 .47601 L F
.774 .281 0 r
.38438 .57885 m .3863 .58148 L .3877 .58226 L F
.862 .867 .842 r
.3863 .58148 m .38546 .58587 L .3877 .58226 L F
.685 .772 .917 r
.32403 .54306 m .3284 .54399 L .32666 .54226 L F
.426 .298 .602 r
.3284 .54399 m .33054 .54285 L .32666 .54226 L F
.3284 .54399 m .33101 .5436 L .33054 .54285 L F
.598 .632 .856 r
.3284 .54399 m .33272 .54595 L .33101 .5436 L F
0 0 0 r
.33309 .52935 m .33171 .53065 L .33193 .53046 L F
.575 .1 .09 r
.33438 .52811 m .33309 .52935 L .33554 .5279 L F
.51 .884 .682 r
.33554 .5279 m .33309 .52935 L .33544 .52753 L F
0 0 0 r
.33309 .52935 m .33193 .53046 L .33544 .52753 L F
.575 .1 .09 r
.33056 .52882 m .33309 .52935 L .33438 .52811 L F
.51 .884 .682 r
.33554 .5279 m .33544 .52753 L .33732 .5271 L F
.277 .071 .409 r
.23256 .55639 m .23388 .55829 L .23369 .55557 L F
.23256 .55639 m .23196 .55914 L .23388 .55829 L F
.981 .881 .655 r
.32949 .50089 m .32818 .50402 L .32712 .50197 L F
0 0 0 r
.32949 .50089 m .32953 .50117 L .33128 .49921 L F
.32949 .50089 m .32712 .50197 L .32953 .50117 L F
.498 .281 .515 r
.42652 .55628 m .42905 .55302 L .42669 .55169 L F
.42652 .55628 m .42903 .55579 L .42905 .55302 L F
.336 .255 .615 r
.4293 .57212 m .42811 .56998 L .42938 .56939 L F
.988 .886 .627 r
.58132 .45115 m .58275 .44735 L .58151 .44636 L F
.494 .124 .266 r
.40171 .51008 m .40425 .50983 L .40569 .50714 L F
.738 .393 .397 r
.40569 .50714 m .40602 .50943 L .40812 .50659 L F
.40569 .50714 m .40425 .50983 L .40602 .50943 L F
.002 0 .399 r
.58493 .36515 m .58268 .36628 L .58482 .36486 L F
.58578 .36728 m .58377 .36945 L .58423 .36663 L F
.58578 .36728 m .58423 .36663 L .58268 .36628 L F
.58578 .36728 m .58268 .36628 L .58493 .36515 L F
.515 .863 .991 r
.58146 .3669 m .58268 .36628 L .58423 .36663 L F
.57987 .36705 m .58268 .36628 L .58146 .3669 L F
.6 .605 .829 r
.31605 .64776 m .31777 .65161 L .32024 .65076 L F
.415 .73 .99 r
.41527 .54484 m .41726 .54644 L .41431 .54638 L F
.814 .897 .901 r
.24366 .57051 m .24309 .57277 L .23945 .5713 L F
.309 0 .102 r
.65021 .39758 m .65109 .39542 L .65359 .39485 L F
.523 .289 .501 r
.32361 .5912 m .32718 .58823 L .32436 .58915 L F
0 0 0 r
.54763 .4026 m .54679 .40283 L .54586 .40424 L F
.54763 .4026 m .54937 .40201 L .54679 .40283 L F
.01 .1 .611 r
.25458 .59511 m .25638 .59796 L .25606 .59485 L F
.157 0 0 r
.6251 .34062 m .62803 .34008 L .62834 .33959 L F
.048 0 0 r
.62834 .33959 m .62803 .34008 L .63064 .33924 L F
.997 .804 .448 r
.69864 .34964 m .69795 .34582 L .6973 .34838 L F
.976 .922 .65 r
.69656 .35072 m .69864 .34964 L .6973 .34838 L F
.69656 .35072 m .69729 .35322 L .69864 .34964 L F
.865 .88 .846 r
.55202 .47144 m .54759 .47344 L .54833 .47349 L F
.815 .98 .891 r
.55251 .46912 m .55202 .47144 L .54833 .47349 L F
.881 .447 .094 r
.32658 .61106 m .32417 .60768 L .32505 .60954 L F
0 0 0 r
.31069 .63616 m .31109 .63598 L .30796 .63641 L F
.31069 .63616 m .3133 .63542 L .31109 .63598 L F
.833 .455 .336 r
.40602 .50943 m .4078 .51219 L .40978 .51055 L F
.682 .237 .188 r
.40978 .51055 m .4078 .51219 L .41194 .51259 L F
0 0 0 r
.62326 .41411 m .6244 .41208 L .62601 .41083 L F
.475 .168 .365 r
.25516 .52304 m .25967 .52243 L .25837 .52117 L F
.352 .32 .683 r
.25516 .52304 m .25902 .52755 L .25967 .52243 L F
.819 .613 .624 r
.69679 .27993 m .70053 .27859 L .70008 .27655 L F
.69679 .27993 m .70071 .28078 L .70053 .27859 L F
.717 .468 0 r
.70008 .27655 m .70053 .27859 L .69959 .27411 L F
0 .002 .576 r
.33272 .54595 m .33304 .54531 L .33101 .5436 L F
.815 .919 .907 r
.24129 .58388 m .23723 .58539 L .24036 .58259 L F
.536 .6 .865 r
.24296 .58158 m .24129 .58388 L .24036 .58259 L F
.24296 .58158 m .24364 .58397 L .24129 .58388 L F
.028 .051 .548 r
.46664 .53562 m .46848 .53407 L .46656 .53379 L F
.985 .803 .578 r
.4645 .53526 m .46656 .53379 L .46664 .53562 L F
.112 .473 .895 r
.46735 .53435 m .46664 .53562 L .46486 .53532 L F
.46778 .53419 m .46768 .53431 L .46735 .53435 L F
.46768 .53431 m .46664 .53562 L .46735 .53435 L F
.46778 .53419 m .46486 .53532 L .46568 .53487 L F
.46768 .53431 m .46847 .5359 L .46664 .53562 L F
.46778 .53419 m .46787 .53441 L .46768 .53431 L F
.46787 .53441 m .46847 .5359 L .46768 .53431 L F
.348 .666 .974 r
.46778 .53419 m .47029 .53503 L .46847 .5359 L F
.485 .859 .984 r
.46641 .53442 m .46778 .53419 L .4645 .53526 L F
0 0 0 r
.46692 .53651 m .46966 .53531 L .46659 .53445 L F
.46966 .53531 m .47029 .53503 L .46858 .53477 L F
.46966 .53531 m .46858 .53477 L .46659 .53445 L F
.46642 .53448 m .46659 .53445 L .46641 .53442 L F
.46692 .53651 m .46659 .53445 L .46642 .53448 L F
.801 .597 .626 r
.46847 .5359 m .46473 .53824 L .46664 .53562 L F
.978 .718 .466 r
.46664 .53562 m .46473 .53824 L .4645 .53526 L F
.092 0 .406 r
.46473 .53824 m .46692 .53651 L .46642 .53448 L F
.46638 .5345 m .46642 .53448 L .46641 .53442 L F
.46473 .53824 m .46642 .53448 L .46638 .5345 L F
.112 .473 .895 r
.46568 .53487 m .46486 .53532 L .4645 .53526 L F
0 0 0 r
.27113 .59843 m .27395 .5966 L .27143 .59546 L F
.737 .574 .672 r
.27477 .59606 m .27143 .59546 L .27486 .59585 L F
.27448 .59684 m .27395 .5966 L .27477 .59606 L F
.27395 .5966 m .27143 .59546 L .27477 .59606 L F
.27402 .59803 m .27113 .59843 L .27313 .59715 L F
0 0 0 r
.27113 .59843 m .27137 .59831 L .27313 .59715 L F
.27113 .59843 m .27313 .59715 L .27395 .5966 L F
.737 .574 .672 r
.27313 .59715 m .27113 .59843 L .27143 .59546 L F
.27402 .59803 m .27143 .59546 L .27448 .59684 L F
0 0 0 r
.27395 .5966 m .27228 .59788 L .27512 .59585 L F
.27137 .59831 m .27228 .59788 L .27395 .5966 L F
.27395 .5966 m .27512 .59585 L .27143 .59546 L F
.666 .292 .327 r
.42865 .59005 m .42977 .59156 L .42699 .58915 L F
.586 .012 0 r
.40497 .45906 m .40356 .4591 L .40148 .45755 L F
.875 .743 .713 r
.40431 .45478 m .40497 .45906 L .40148 .45755 L F
.563 .913 .966 r
.50181 .44622 m .50173 .44485 L .50037 .44506 L F
.50181 .44622 m .50456 .44512 L .50173 .44485 L F
.657 .966 .793 r
.50502 .40458 m .50782 .40183 L .50929 .40263 L F
.50502 .40458 m .50486 .40415 L .50782 .40183 L F
0 0 0 r
.64992 .32948 m .6522 .32879 L .65321 .32721 L F
.64992 .32948 m .64871 .33036 L .6522 .32879 L F
.174 .594 .939 r
.56661 .37645 m .56463 .37712 L .56427 .37488 L F
.56661 .37645 m .56839 .37788 L .56463 .37712 L F
.766 .626 .705 r
.27143 .59546 m .27512 .59585 L .27614 .59139 L F
.633 .964 .871 r
.4847 .41756 m .48566 .41596 L .48799 .41589 L F
.4847 .41756 m .48371 .41735 L .48566 .41596 L F
.221 .164 .578 r
.25967 .52243 m .2605 .5219 L .25837 .52117 L F
.344 0 .006 r
.25837 .52117 m .2605 .5219 L .26077 .52073 L F
.681 .974 .909 r
.61678 .34928 m .62034 .34736 L .61878 .34813 L F
.498 .889 .722 r
.61878 .34813 m .62034 .34736 L .62246 .34591 L F
0 0 0 r
.65294 .33988 m .65201 .34191 L .6501 .34343 L F
.124 0 .056 r
.65491 .33954 m .65294 .33988 L .65587 .33931 L F
.65491 .33954 m .65201 .34191 L .65294 .33988 L F
.704 .639 .781 r
.62066 .41489 m .62211 .41891 L .62404 .417 L F
.832 .385 .165 r
.42104 .5588 m .42367 .56158 L .42392 .55965 L F
.871 .871 .834 r
.42652 .55628 m .42392 .55965 L .42118 .55838 L F
.123 .414 .861 r
.42367 .56158 m .42118 .55838 L .42392 .55965 L F
.267 0 .213 r
.38453 .48741 m .38126 .49053 L .38399 .49011 L F
.832 .997 .838 r
.28969 .58437 m .29274 .58277 L .29141 .58187 L F
.988 .725 .42 r
.29141 .58187 m .29274 .58277 L .29176 .57919 L F
0 0 .069 r
.2393 .58923 m .23868 .5918 L .23999 .58784 L F
.62 .941 .953 r
.53231 .48261 m .5301 .48372 L .52874 .48317 L F
.476 .861 .978 r
.34379 .55581 m .34058 .55583 L .34399 .55503 L F
.522 .184 .336 r
.34379 .55581 m .3401 .55877 L .34058 .55583 L F
.34379 .55581 m .34405 .5586 L .3401 .55877 L F
0 0 .278 r
.34518 .55706 m .34379 .55581 L .34399 .55503 L F
.34518 .55706 m .34405 .5586 L .34379 .55581 L F
.502 .814 1 r
.28819 .63697 m .29083 .63844 L .28631 .6377 L F
.564 .838 .997 r
.29308 .63773 m .29083 .63844 L .28819 .63697 L F
.758 .814 .897 r
.44944 .572 m .45316 .57203 L .45146 .57388 L F
.282 0 .284 r
.25172 .54805 m .25051 .54602 L .25285 .54592 L F
.25172 .54805 m .24929 .5492 L .25051 .54602 L F
0 0 0 r
.6522 .32879 m .65597 .32638 L .65321 .32721 L F
.79 .521 .529 r
.51304 .41063 m .51687 .40891 L .51547 .40736 L F
.51304 .41063 m .51725 .41153 L .51687 .40891 L F
.831 .862 .868 r
.51547 .40736 m .51687 .40891 L .52017 .40565 L F
.813 .781 .823 r
.6158 .41944 m .6144 .41536 L .61363 .41671 L F
.6158 .41944 m .61664 .41428 L .6144 .41536 L F
.6158 .41944 m .61844 .41638 L .61664 .41428 L F
.789 .712 .779 r
.33714 .58305 m .33992 .58196 L .33997 .5801 L F
.511 .315 .551 r
.33992 .58196 m .34234 .57879 L .33997 .5801 L F
.33992 .58196 m .34263 .58207 L .34234 .57879 L F
.009 .092 .603 r
.33992 .58196 m .34199 .58467 L .34263 .58207 L F
.947 .644 .429 r
.38349 .58496 m .38361 .58757 L .38546 .58587 L F
.998 .823 .542 r
.38546 .58587 m .38361 .58757 L .38495 .58862 L F
.862 .867 .842 r
.3863 .58148 m .38349 .58496 L .38546 .58587 L F
0 0 0 r
.62759 .38781 m .62549 .38819 L .62538 .38872 L F
.62759 .38781 m .62862 .38745 L .62549 .38819 L F
.729 .267 .151 r
.43858 .48395 m .44021 .48587 L .44188 .4844 L F
.807 .59 .03 r
.42442 .53825 m .42432 .53876 L .42463 .53962 L F
.787 .583 .016 r
.42432 .53876 m .42471 .54149 L .42463 .53962 L F
.42432 .53876 m .42453 .54143 L .42471 .54149 L F
.852 .624 .084 r
.42405 .5398 m .42453 .54143 L .42432 .53876 L F
.42416 .53961 m .42432 .53876 L .42564 .53701 L F
.42405 .5398 m .42432 .53876 L .42416 .53961 L F
.807 .59 .03 r
.42412 .53626 m .42432 .53876 L .42442 .53825 L F
.593 .889 .596 r
.66514 .3202 m .66688 .31814 L .66822 .31718 L F
.687 .92 .594 r
.66822 .31718 m .66852 .31599 L .6706 .31608 L F
.66822 .31718 m .66688 .31814 L .66852 .31599 L F
.619 .956 .905 r
.4706 .42879 m .46611 .43034 L .4692 .4281 L F
.753 .993 .809 r
.47159 .4267 m .47351 .42615 L .4706 .42879 L F
.679 .942 .963 r
.47159 .4267 m .4706 .42879 L .4692 .4281 L F
.752 .606 .696 r
.36282 .60607 m .36276 .60866 L .36363 .60468 L F
.939 .869 .742 r
.57097 .42176 m .57301 .41795 L .57141 .41679 L F
.522 .316 .542 r
.57097 .42176 m .57373 .42241 L .57301 .41795 L F
.76 .42 .408 r
.28181 .59568 m .28088 .59811 L .27827 .59509 L F
.138 0 .141 r
.28268 .5971 m .28181 .59568 L .28461 .59546 L F
.28268 .5971 m .28088 .59811 L .28181 .59568 L F
0 0 0 r
.35963 .62219 m .3564 .62416 L .3587 .62452 L F
.549 .481 .732 r
.35973 .61809 m .35963 .62219 L .35855 .61793 L F
.67 .974 .825 r
.53821 .48954 m .53897 .48799 L .53693 .48928 L F
.53821 .48954 m .54114 .48736 L .53897 .48799 L F
.918 .601 .427 r
.58946 .39574 m .58772 .39777 L .58648 .39477 L F
.58946 .39574 m .58963 .39815 L .58772 .39777 L F
.701 .483 .589 r
.46392 .57479 m .46513 .57866 L .46182 .57868 L F
.46182 .57868 m .46513 .57866 L .46392 .57479 L F
.996 .765 .442 r
.46038 .58008 m .4618 .58142 L .46182 .57868 L F
.51 0 0 r
.46223 .57779 m .46529 .5792 L .46144 .57913 L F
.988 .722 .414 r
.46038 .58008 m .46182 .57868 L .46011 .57768 L F
.362 .775 .98 r
.46182 .57868 m .46223 .57779 L .46011 .57768 L F
.704 .518 .634 r
.46011 .57768 m .46223 .57779 L .46038 .58008 L F
.58 .833 .468 r
.46038 .58008 m .46223 .57779 L .46108 .57912 L F
.51 0 0 r
.46223 .57779 m .46144 .57913 L .46108 .57912 L F
.654 .805 .362 r
.46182 .57868 m .4631 .57631 L .46223 .57779 L F
.4631 .57631 m .46392 .57479 L .46223 .57779 L F
.337 .271 .634 r
.46513 .57866 m .46738 .57792 L .46392 .57479 L F
.647 .226 .231 r
.46392 .57479 m .46738 .57792 L .46223 .57779 L F
.883 .939 .847 r
.46298 .55527 m .46109 .56002 L .46146 .55785 L F
.46298 .55527 m .46425 .5564 L .46109 .56002 L F
.573 .008 0 r
.46109 .56002 m .46066 .56117 L .46146 .55785 L F
.46109 .56002 m .46412 .56179 L .46066 .56117 L F
.396 .464 .813 r
.23235 .57254 m .23469 .57268 L .23269 .56833 L F
.695 .163 0 r
.23673 .57493 m .23432 .57465 L .23235 .57254 L F
.422 .212 .488 r
.23235 .57254 m .23432 .57465 L .23469 .57268 L F
.53 .138 .243 r
.64387 .33964 m .64156 .34211 L .63851 .34218 L F
.764 .496 .53 r
.64494 .34026 m .64156 .34211 L .64387 .33964 L F
.419 .118 .345 r
.70441 .27892 m .70429 .27991 L .70647 .27827 L F
.709 .445 0 r
.58435 .38553 m .58445 .38628 L .58274 .38442 L F
.58435 .38553 m .58501 .38838 L .58445 .38628 L F
.642 .63 .823 r
.70065 .28269 m .70245 .28564 L .70493 .28398 L F
.552 .241 .395 r
.52033 .45757 m .52048 .45471 L .52317 .45673 L F
.52317 .45673 m .52048 .45471 L .52033 .45757 L F
.899 .635 .529 r
.37923 .56778 m .38107 .56615 L .37905 .56536 L F
.37923 .56778 m .381 .56897 L .38107 .56615 L F
.946 .608 .194 r
.57912 .3785 m .57742 .37469 L .57719 .3768 L F
.041 0 .19 r
.67105 .31412 m .67246 .31464 L .67338 .31288 L F
.67105 .31412 m .6706 .31608 L .67246 .31464 L F
.825 .543 .512 r
.59946 .44165 m .59557 .4383 L .59553 .44048 L F
.844 .542 .478 r
.59972 .44445 m .59946 .44165 L .59553 .44048 L F
.778 .558 .602 r
.34848 .5431 m .34406 .54278 L .34438 .53988 L F
.649 .183 .134 r
.34848 .5431 m .34665 .54486 L .34406 .54278 L F
.253 0 0 r
.34943 .54432 m .34665 .54486 L .34848 .5431 L F
0 0 0 r
.33881 .53037 m .33889 .53009 L .34005 .52799 L F
.33881 .53037 m .33757 .53213 L .33889 .53009 L F
.598 .59 .815 r
.33806 .57302 m .3397 .56851 L .33872 .56735 L F
.33806 .57302 m .34067 .57234 L .3397 .56851 L F
0 0 .399 r
.3747 .46604 m .37539 .46748 L .37388 .46311 L F
.818 .6 .608 r
.46269 .54975 m .45851 .55195 L .46042 .55077 L F
.46269 .54975 m .46243 .5529 L .45851 .55195 L F
.861 .997 .798 r
.46321 .54737 m .46269 .54975 L .462 .54923 L F
.46321 .54737 m .46542 .54649 L .46269 .54975 L F
.808 1 .821 r
.462 .54923 m .46269 .54975 L .46042 .55077 L F
.9 .483 .126 r
.38903 .53028 m .38732 .52922 L .38629 .52637 L F
.983 .699 .379 r
.38903 .53028 m .38758 .53159 L .38732 .52922 L F
.38903 .53028 m .38908 .53283 L .38758 .53159 L F
.471 .13 .307 r
.26789 .51787 m .26971 .5188 L .27057 .51661 L F
.26789 .51787 m .26729 .51951 L .26971 .5188 L F
.037 .059 .553 r
.23592 .54291 m .2361 .54694 L .23741 .54517 L F
0 0 .38 r
.2361 .54694 m .23769 .54783 L .23741 .54517 L F
.2361 .54694 m .2359 .54956 L .23769 .54783 L F
.918 .827 .741 r
.59313 .3711 m .59654 .36947 L .5955 .36748 L F
.59313 .3711 m .59455 .37241 L .59654 .36947 L F
0 0 0 r
.36064 .61543 m .35973 .61809 L .35855 .61793 L F
.459 .878 .761 r
.662 .38783 m .66599 .38604 L .66465 .38684 L F
.402 .814 .616 r
.66465 .38684 m .66599 .38604 L .66833 .38453 L F
.512 .31 .543 r
.69599 .27741 m .69959 .27411 L .69886 .27514 L F
.783 .997 .857 r
.25402 .53088 m .25256 .53011 L .25586 .52909 L F
.25402 .53088 m .25084 .53151 L .25256 .53011 L F
.759 .727 .824 r
.5434 .45116 m .54707 .4516 L .54629 .44827 L F
.575 .511 .746 r
.54707 .4516 m .54855 .44679 L .54629 .44827 L F
.769 .398 .353 r
.35007 .55255 m .3459 .55158 L .3473 .5528 L F
.409 0 0 r
.48408 .4475 m .48829 .44799 L .4856 .44763 L F
.507 .815 1 r
.4856 .44763 m .48829 .44799 L .4908 .44731 L F
.796 .696 .154 r
.53352 .46671 m .53314 .47021 L .53334 .46992 L F
0 0 0 r
.61878 .34813 m .61586 .34893 L .61678 .34928 L F
.426 .111 .326 r
.63774 .38496 m .64146 .38237 L .63783 .38266 L F
.63774 .38496 m .64146 .38237 L .63783 .38266 L F
.94 .653 .191 r
.57525 .37278 m .57431 .37141 L .57408 .36878 L F
.786 .294 0 r
.57742 .37469 m .57431 .37141 L .57525 .37278 L F
.856 .603 .555 r
.24522 .5991 m .24441 .60162 L .24309 .59844 L F
.827 .719 .746 r
.24309 .59844 m .24522 .5991 L .24342 .59517 L F
.856 .603 .555 r
.24522 .5991 m .24441 .60162 L .24309 .59844 L F
.144 .191 .653 r
.70946 .28305 m .71037 .28216 L .7074 .27768 L F
.657 .667 .847 r
.24829 .58559 m .24651 .58603 L .24364 .58397 L F
.291 0 0 r
.55847 .38393 m .56141 .3837 L .56072 .38247 L F
0 0 .425 r
.56072 .38247 m .56176 .38102 L .56133 .37827 L F
0 0 .185 r
.56072 .38247 m .56141 .3837 L .56176 .38102 L F
.145 .689 .791 r
.61156 .34401 m .61428 .34372 L .61582 .34383 L F
.121 0 0 r
.61428 .34372 m .61845 .34278 L .61582 .34383 L F
.408 .54 .877 r
.58578 .36728 m .58646 .36919 L .58377 .36945 L F
.876 .708 .671 r
.3805 .59735 m .38451 .59614 L .38249 .59454 L F
.3805 .59735 m .38225 .60063 L .38451 .59614 L F
.815 .762 .803 r
.38249 .59454 m .38451 .59614 L .38735 .59281 L F
.772 .674 .755 r
.55793 .38571 m .55691 .38988 L .55309 .38832 L F
.287 .142 .503 r
.55516 .38962 m .55309 .38832 L .55691 .38988 L F
.279 0 0 r
.55516 .38962 m .55691 .38988 L .55969 .39083 L F
.526 .05 .07 r
.27512 .59585 m .27228 .59788 L .2771 .59733 L F
.485 .891 .762 r
.45035 .4399 m .45329 .43877 L .44888 .44113 L F
.639 .962 .807 r
.45447 .43758 m .45329 .43877 L .45035 .4399 L F
.424 .523 .854 r
.5249 .38768 m .52374 .39118 L .52224 .39085 L F
.5249 .38768 m .52662 .39162 L .52374 .39118 L F
.871 .871 .834 r
.42652 .55628 m .42118 .55838 L .42475 .55524 L F
.498 .281 .515 r
.42652 .55628 m .42669 .55169 L .42475 .55524 L F
.679 .194 .092 r
.42475 .55524 m .42903 .55579 L .42652 .55628 L F
.697 .651 .8 r
.43082 .57594 m .4293 .57212 L .42984 .57394 L F
0 0 0 r
.43101 .576 m .43082 .57594 L .42984 .57394 L F
.43101 .576 m .4336 .57575 L .43082 .57594 L F
.738 .901 .518 r
.48682 .52302 m .48545 .52465 L .48659 .52257 L F
.983 .707 .336 r
.47633 .53386 m .47726 .53208 L .47851 .53195 L F
.47633 .53386 m .47493 .5353 L .47726 .53208 L F
.47633 .53386 m .47611 .53609 L .47493 .5353 L F
.539 .797 .993 r
.4123 .60018 m .41304 .59835 L .41064 .59864 L F
.4123 .60018 m .41468 .59968 L .41304 .59835 L F
.733 .438 .481 r
.26013 .52756 m .25833 .53127 L .25586 .52909 L F
.481 .403 .691 r
.26051 .52673 m .26107 .52654 L .26263 .5213 L F
.084 0 0 r
.2634 .52554 m .26315 .52504 L .26401 .52467 L F
.606 .427 .613 r
.26732 .52253 m .26731 .52704 L .26401 .52467 L F
.26731 .52704 m .26731 .52804 L .26666 .52738 L F
.26731 .52704 m .26666 .52738 L .26401 .52467 L F
0 0 .256 r
.268 .52277 m .26745 .527 L .26732 .52253 L F
.865 .693 .666 r
.26981 .52573 m .26827 .52857 L .26739 .52787 L F
0 0 .256 r
.26742 .527 m .26731 .52804 L .26731 .52704 L F
.26741 .52723 m .26731 .52804 L .26742 .527 L F
.869 .819 .797 r
.26675 .52736 m .26731 .52804 L .26741 .52723 L F
.865 .693 .666 r
.26742 .527 m .26741 .52723 L .26675 .52736 L F
.26981 .52573 m .26739 .52787 L .26742 .527 L F
0 0 .256 r
.26745 .527 m .26741 .52723 L .26742 .527 L F
.26745 .527 m .26731 .52704 L .26732 .52253 L F
.865 .693 .666 r
.26847 .52645 m .26675 .52736 L .26963 .52586 L F
.26809 .52664 m .26675 .52736 L .26847 .52645 L F
.869 .819 .797 r
.26675 .52736 m .26741 .52723 L .26745 .527 L F
.26675 .52736 m .26745 .527 L .268 .52277 L F
.865 .693 .666 r
.26741 .52723 m .26739 .52787 L .26675 .52736 L F
.26963 .52586 m .26748 .52698 L .26939 .52604 L F
.26748 .52698 m .26675 .52736 L .26759 .52694 L F
.26748 .52698 m .26759 .52694 L .26939 .52604 L F
.26981 .52573 m .26809 .52664 L .26963 .52586 L F
0 .061 .587 r
.26401 .52467 m .26731 .52804 L .26675 .52736 L F
.26401 .52467 m .26675 .52736 L .26241 .52694 L F
0 0 .246 r
.26263 .5213 m .26345 .52566 L .26325 .52257 L F
.26345 .52566 m .26346 .52571 L .26346 .52568 L F
.26345 .52566 m .26346 .52568 L .26325 .52257 L F
.084 0 0 r
.26326 .52573 m .26177 .52562 L .26315 .52504 L F
.26326 .52573 m .26315 .52504 L .2634 .52554 L F
.481 .403 .691 r
.26107 .52654 m .26346 .52571 L .26345 .52566 L F
.081 0 0 r
.26089 .52677 m .26346 .52571 L .26241 .52694 L F
0 0 0 r
.26108 .52653 m .26013 .52756 L .2617 .5257 L F
.081 0 0 r
.26051 .52673 m .26107 .52654 L .26089 .52677 L F
.26107 .52654 m .26346 .52571 L .26089 .52677 L F
0 0 0 r
.26109 .52651 m .26108 .52653 L .26177 .52562 L F
.26108 .52653 m .2617 .5257 L .26177 .52562 L F
.084 0 0 r
.26241 .52694 m .26203 .52617 L .26326 .52573 L F
.26203 .52617 m .26177 .52562 L .26326 .52573 L F
0 0 0 r
.2602 .52769 m .26016 .52762 L .26108 .52653 L F
.26016 .52762 m .26013 .52756 L .26109 .52651 L F
.081 0 0 r
.26051 .52673 m .26089 .52677 L .2602 .52769 L F
.26089 .52677 m .26241 .52694 L .2602 .52769 L F
0 0 0 r
.2602 .52769 m .26108 .52653 L .26109 .52651 L F
.084 0 0 r
.26241 .52694 m .2602 .52769 L .26109 .52651 L F
.26203 .52617 m .26109 .52651 L .26177 .52562 L F
.481 .403 .691 r
.26107 .52654 m .26345 .52566 L .2611 .52651 L F
.084 0 0 r
.26241 .52694 m .26109 .52651 L .26203 .52617 L F
.481 .403 .691 r
.2611 .52651 m .26203 .52617 L .26315 .52407 L F
.26203 .52617 m .26345 .52566 L .26345 .52566 L F
.26203 .52617 m .26345 .52566 L .26315 .52407 L F
.26107 .52654 m .26315 .52407 L .26263 .5213 L F
0 0 0 r
.2602 .52769 m .25833 .53127 L .26013 .52756 L F
.98 .772 .552 r
.41194 .51259 m .41341 .51645 L .41425 .5139 L F
.584 .945 .884 r
.52356 .43787 m .52038 .43974 L .51877 .43962 L F
.944 .611 .367 r
.55985 .40226 m .55825 .40379 L .55621 .40072 L F
.55985 .40226 m .56011 .40474 L .55825 .40379 L F
.681 .539 .686 r
.62721 .35035 m .62786 .35292 L .63116 .35038 L F
.63116 .35038 m .62786 .35292 L .62721 .35035 L F
.41 .815 .98 r
.34562 .54863 m .3482 .54818 L .34887 .54879 L F
0 0 0 r
.34562 .54863 m .3459 .54955 L .3482 .54818 L F
.951 .955 .698 r
.3482 .54818 m .3459 .54955 L .34737 .54744 L F
.3482 .54818 m .34737 .54744 L .34773 .54691 L F
.41 .815 .98 r
.34887 .54879 m .3482 .54818 L .35006 .54885 L F
.22 .655 .954 r
.35066 .54792 m .35006 .54885 L .3482 .54818 L F
.35066 .54792 m .35236 .54905 L .35006 .54885 L F
.796 .701 .76 r
.31881 .5747 m .31799 .57586 L .32043 .5729 L F
.606 .419 .603 r
.31799 .57586 m .32051 .57575 L .32043 .5729 L F
.31799 .57586 m .32051 .57575 L .32043 .5729 L F
0 0 .291 r
.32043 .5729 m .32144 .57427 L .32291 .57273 L F
.32043 .5729 m .32051 .57575 L .32144 .57427 L F
.797 .366 .223 r
.39468 .54063 m .39135 .54057 L .39124 .53908 L F
.39468 .54063 m .39546 .54237 L .39135 .54057 L F
0 0 0 r
.55279 .40424 m .5511 .40605 L .55363 .40257 L F
.448 .804 .997 r
.34018 .53935 m .34294 .53885 L .34438 .53988 L F
.856 .801 .796 r
.34294 .53885 m .34582 .53791 L .34438 .53988 L F
.34582 .53791 m .34747 .53737 L .34569 .53881 L F
.34582 .53791 m .34569 .53881 L .34438 .53988 L F
.34294 .53885 m .34385 .54079 L .34747 .53737 L F
.685 .443 .549 r
.34357 .53842 m .34578 .53623 L .34385 .54079 L F
0 .207 .733 r
.34342 .53715 m .34385 .54079 L .34294 .53885 L F
.549 .213 .352 r
.34152 .54046 m .34366 .54219 L .3441 .54014 L F
.34089 .54054 m .34123 .54075 L .34152 .54046 L F
.34123 .54075 m .34366 .54219 L .34152 .54046 L F
.685 .443 .549 r
.34342 .53715 m .34619 .53525 L .34578 .53623 L F
.34342 .53715 m .34578 .53623 L .34357 .53842 L F
.34619 .53525 m .34722 .53454 L .34596 .53687 L F
.34619 .53525 m .34596 .53687 L .34385 .54079 L F
.103 .151 .628 r
.25886 .53245 m .25818 .53654 L .25671 .5331 L F
.25886 .53245 m .25983 .53557 L .25818 .53654 L F
0 0 0 r
.25983 .53557 m .25772 .5382 L .25818 .53654 L F
0 0 .421 r
.4286 .54736 m .42745 .54652 L .42623 .54519 L F
.4286 .54736 m .42828 .5489 L .42745 .54652 L F
.598 .897 .987 r
.45384 .49975 m .45632 .49868 L .4553 .50054 L F
.45384 .49975 m .45632 .49868 L .4553 .50054 L F
.889 .904 .832 r
.59071 .36942 m .59179 .36471 L .59318 .36677 L F
.22 .241 .67 r
.59519 .36335 m .59318 .36677 L .59179 .36471 L F
.59519 .36335 m .5955 .36748 L .59318 .36677 L F
.718 .801 .916 r
.61787 .40268 m .62215 .40301 L .62092 .40195 L F
.624 .831 .98 r
.62215 .40301 m .62503 .40232 L .6232 .40072 L F
.426 .87 .853 r
.43755 .44517 m .44228 .44397 L .43992 .44528 L F
.69 .979 .891 r
.62601 .41083 m .63018 .40904 L .62921 .40807 L F
.801 .952 .917 r
.63089 .40635 m .63018 .40904 L .63199 .40736 L F
.821 .968 .898 r
.63089 .40635 m .62921 .40807 L .63018 .40904 L F
.898 .975 .814 r
.34907 .56071 m .34728 .56321 L .34696 .56053 L F
0 0 .467 r
.34728 .56321 m .34835 .56497 L .34696 .56053 L F
.519 .842 .999 r
.44169 .58742 m .44055 .58924 L .43894 .5887 L F
.452 .265 .535 r
.44055 .58924 m .44311 .58845 L .4428 .58571 L F
.519 .842 .999 r
.44169 .58742 m .44311 .58845 L .44055 .58924 L F
.282 0 0 r
.44649 .59779 m .44848 .59833 L .4443 .59765 L F
.491 .81 1 r
.55244 .40167 m .55363 .40257 L .55059 .40217 L F
.512 .513 .793 r
.55409 .40122 m .55695 .40379 L .55279 .40424 L F
.55457 .40013 m .5551 .40095 L .55409 .40122 L F
.5551 .40095 m .55695 .40379 L .55409 .40122 L F
.491 .81 1 r
.55209 .4014 m .55244 .40167 L .54937 .40201 L F
.55244 .40167 m .55059 .40217 L .54937 .40201 L F
.305 .2 .567 r
.24752 .55543 m .24585 .55902 L .2457 .55626 L F
.508 .539 .823 r
.60498 .45112 m .60662 .44729 L .60364 .44743 L F
.988 .718 .385 r
.55046 .38908 m .55067 .39215 L .54985 .39041 L F
.478 .316 .583 r
.55328 .39126 m .55046 .38908 L .55309 .38832 L F
.55328 .39126 m .55067 .39215 L .55051 .38981 L F
.55103 .38952 m .55051 .38981 L .55046 .38908 L F
.55328 .39126 m .55051 .38981 L .55103 .38952 L F
0 0 0 r
.54985 .39041 m .5517 .38959 L .55295 .38845 L F
.55252 .38869 m .55295 .38845 L .55309 .38832 L F
.54985 .39041 m .55295 .38845 L .55252 .38869 L F
.54985 .39041 m .55309 .38832 L .55046 .38908 L F
.451 .78 .998 r
.57826 .36533 m .58268 .36628 L .57987 .36705 L F
.232 .741 .699 r
.6251 .34062 m .62644 .34013 L .62803 .34008 L F
.6251 .34062 m .62375 .34098 L .62644 .34013 L F
.945 .955 .659 r
.55887 .39602 m .55785 .39804 L .55713 .39671 L F
.889 .982 .702 r
.55887 .39602 m .55713 .39671 L .55929 .3932 L F
.925 .946 .79 r
.55929 .3932 m .55713 .39671 L .55625 .39534 L F
.021 0 0 r
.55713 .39671 m .55847 .39732 L .55652 .39558 L F
.55713 .39671 m .55652 .39558 L .55625 .39534 L F
.945 .955 .659 r
.55785 .39804 m .5573 .39911 L .55713 .39671 L F
.759 .739 .217 r
.5599 .39107 m .55887 .39602 L .55929 .3932 L F
.842 .998 .78 r
.36674 .62751 m .36735 .62839 L .36994 .62516 L F
.962 .852 .685 r
.36564 .6243 m .36674 .62751 L .36807 .62402 L F
0 0 .415 r
.36641 .62618 m .36674 .62751 L .36564 .6243 L F
.842 .998 .78 r
.36674 .62751 m .36994 .62516 L .36807 .62402 L F
0 0 .415 r
.36776 .62954 m .36674 .62751 L .36641 .62618 L F
.931 .793 .325 r
.36693 .6311 m .36721 .62933 L .36674 .62751 L F
.36721 .62933 m .36735 .62839 L .36674 .62751 L F
0 .17 .692 r
.59126 .35244 m .59207 .35066 L .58909 .34979 L F
.59126 .35244 m .59238 .35262 L .59207 .35066 L F
.815 .762 .803 r
.38249 .59454 m .38735 .59281 L .3848 .59165 L F
.77 .989 .892 r
.49844 .51038 m .49522 .51086 L .49913 .50819 L F
.871 .916 .857 r
.34475 .6467 m .34679 .64714 L .34925 .64399 L F
.476 .235 .469 r
.67928 .30654 m .68237 .30583 L .68212 .30365 L F
.691 .502 .627 r
.68237 .30583 m .68498 .30321 L .68212 .30365 L F
0 0 .252 r
.2808 .61426 m .28017 .61932 L .28157 .61746 L F
.594 .376 .555 r
.6584 .33654 m .65863 .33922 L .65587 .33931 L F
.822 .999 .791 r
.65954 .33389 m .6584 .33654 L .66127 .3334 L F
.803 .966 .653 r
.65954 .33389 m .65705 .33741 L .6584 .33654 L F
.976 .677 .377 r
.65705 .33741 m .65863 .33922 L .6584 .33654 L F
.548 .839 .998 r
.55213 .4147 m .55637 .41496 L .55486 .41382 L F
.449 .241 .503 r
.55486 .41382 m .55213 .4147 L .55637 .41496 L F
.899 .958 .826 r
.36662 .49123 m .36815 .49237 L .36626 .49458 L F
0 0 0 r
.36913 .4923 m .37036 .49089 L .36952 .49145 L F
.36913 .4923 m .36952 .49145 L .36815 .49237 L F
.36913 .4923 m .36815 .49237 L .36662 .49123 L F
.348 .571 .923 r
.36765 .48981 m .36913 .4923 L .36662 .49123 L F
.395 .601 .929 r
.36977 .48944 m .36913 .4923 L .36765 .48981 L F
.858 .877 .439 r
.36977 .48944 m .36886 .49289 L .36913 .4923 L F
.36886 .49289 m .36849 .49428 L .36913 .4923 L F
.579 .126 .141 r
.41585 .45817 m .41849 .45814 L .4169 .45998 L F
.317 0 0 r
.4169 .45998 m .41849 .45814 L .42082 .45896 L F
.967 .673 .419 r
.32401 .62165 m .32219 .62011 L .3214 .61787 L F
.32401 .62165 m .32396 .61852 L .32219 .62011 L F
.32219 .62011 m .32396 .61852 L .32401 .62165 L F
.866 .647 .603 r
.68211 .33028 m .68169 .3329 L .67969 .3291 L F
.336 .474 .851 r
.56023 .40957 m .55979 .41283 L .56061 .41229 L F
.4 .402 .746 r
.55979 .41283 m .56222 .41411 L .56061 .41229 L F
.994 .788 .522 r
.69651 .36084 m .69826 .3595 L .6971 .35806 L F
.69651 .36084 m .69788 .36225 L .69826 .3595 L F
.889 .532 .361 r
.35656 .5215 m .35923 .52051 L .35655 .51901 L F
.35656 .5215 m .35961 .5227 L .35923 .52051 L F
.902 .876 .443 r
.47694 .58011 m .47806 .57891 L .47745 .57795 L F
.47694 .58011 m .47705 .58259 L .47806 .57891 L F
.81 .333 0 r
.40264 .58937 m .40204 .59051 L .40035 .58702 L F
.548 0 0 r
.40264 .58937 m .40582 .59146 L .40204 .59051 L F
0 0 0 r
.40431 .45478 m .40604 .45353 L .40767 .45461 L F
.611 .928 .967 r
.40767 .45461 m .40858 .45294 L .4101 .4534 L F
.513 .826 1 r
.40604 .45353 m .40858 .45294 L .40767 .45461 L F
.845 .907 .879 r
.35988 .63359 m .36444 .63184 L .36259 .63122 L F
.455 .864 .958 r
.36444 .63184 m .36545 .63066 L .36259 .63122 L F
.36444 .63184 m .36693 .6311 L .36545 .63066 L F
.925 .777 .677 r
.2945 .66337 m .29638 .66743 L .29394 .66608 L F
.809 .584 .598 r
.29638 .66743 m .29191 .6697 L .29394 .66608 L F
.29638 .66743 m .29361 .67062 L .29191 .6697 L F
.673 .687 .855 r
.2986 .66405 m .29638 .66743 L .2945 .66337 L F
.885 .58 .465 r
.58138 .42785 m .58127 .4251 L .57798 .42371 L F
.323 .111 .428 r
.52608 .44296 m .52432 .44149 L .52642 .44061 L F
.174 .126 .559 r
.52608 .44296 m .52485 .44464 L .52432 .44149 L F
.957 .715 .265 r
.37621 .61181 m .37716 .61457 L .37623 .61128 L F
.902 .857 .788 r
.37479 .61831 m .37716 .61457 L .37621 .61181 L F
.862 .803 .791 r
.37623 .61128 m .37716 .61457 L .37823 .61263 L F
.675 .249 .226 r
.56131 .45088 m .56323 .45157 L .56367 .45341 L F
0 .125 .673 r
.56171 .44952 m .56131 .45088 L .56367 .45341 L F
.555 .928 .798 r
.47575 .42467 m .47351 .42615 L .47159 .4267 L F
.872 .952 .859 r
.44566 .58235 m .4428 .58571 L .44179 .5844 L F
.972 .659 .302 r
.4428 .58571 m .44311 .58845 L .44169 .58742 L F
.882 .99 .745 r
.59557 .4383 m .59633 .43502 L .59419 .4366 L F
.866 .846 .822 r
.59198 .44251 m .59491 .43907 L .59165 .43792 L F
.59491 .43907 m .59507 .43887 L .59474 .43878 L F
.59491 .43907 m .59474 .43878 L .59165 .43792 L F
.976 .694 .299 r
.59525 .43966 m .59557 .4383 L .59419 .4366 L F
.59553 .44048 m .59554 .44017 L .59525 .43966 L F
.59554 .44017 m .59557 .4383 L .59525 .43966 L F
.906 .942 .819 r
.72646 .31357 m .72852 .31068 L .72559 .31168 L F
.979 .7 .311 r
.72532 .31467 m .72646 .31357 L .72559 .31168 L F
.72532 .31467 m .72654 .31605 L .72646 .31357 L F
.668 .908 .978 r
.5961 .38059 m .59352 .3828 L .59195 .38177 L F
.768 .853 .914 r
.59071 .36942 m .58646 .36919 L .58928 .36803 L F
.889 .904 .832 r
.59071 .36942 m .58928 .36803 L .59179 .36471 L F
.599 .865 .993 r
.44528 .4549 m .44373 .45383 L .44153 .45491 L F
.588 .061 0 r
.44783 .45427 m .44373 .45383 L .44528 .4549 L F
.681 .975 .902 r
.61844 .41638 m .61963 .4146 L .61664 .41428 L F
.61844 .41638 m .62066 .41489 L .61963 .4146 L F
.827 .848 .388 r
.3062 .64064 m .30594 .64263 L .30516 .64469 L F
.847 .974 .874 r
.55967 .37058 m .55837 .37284 L .55814 .37037 L F
0 0 0 r
.55837 .37284 m .55899 .37242 L .55814 .37037 L F
.55837 .37284 m .55784 .37429 L .55899 .37242 L F
.768 .546 .598 r
.2978 .67094 m .29353 .674 L .29361 .67062 L F
.2978 .67094 m .29771 .67399 L .29353 .674 L F
.622 .448 .625 r
.30033 .67039 m .29771 .67399 L .2978 .67094 L F
.872 .974 .85 r
.45049 .45339 m .4546 .45092 L .45229 .45183 L F
.551 .925 .927 r
.4558 .44947 m .4546 .45092 L .45703 .44975 L F
.586 .937 .775 r
.45229 .45183 m .4546 .45092 L .4558 .44947 L F
0 0 0 r
.61634 .41151 m .6144 .41536 L .61664 .41428 L F
.415 .24 .533 r
.53452 .46292 m .53674 .46217 L .53697 .45937 L F
.53697 .45937 m .53674 .46217 L .53452 .46292 L F
.235 .739 .682 r
.53452 .46292 m .53674 .46217 L .53489 .46278 L F
0 0 .011 r
.53452 .46292 m .53393 .46313 L .53493 .46082 L F
.53452 .46292 m .53324 .46473 L .53393 .46313 L F
.944 .606 .35 r
.53095 .46338 m .53324 .46473 L .53452 .46292 L F
.163 0 0 r
.53299 .46341 m .53452 .46292 L .53095 .46338 L F
.944 .606 .35 r
.53095 .46338 m .53452 .46292 L .53299 .46341 L F
.235 .739 .682 r
.53452 .46292 m .53489 .46278 L .53299 .46341 L F
.944 .606 .35 r
.53095 .46338 m .53352 .46671 L .53324 .46473 L F
.217 0 .088 r
.67928 .30654 m .6812 .30763 L .68237 .30583 L F
.67928 .30654 m .67857 .30868 L .6812 .30763 L F
.928 .638 .473 r
.42271 .52964 m .42296 .5327 L .42508 .53335 L F
.897 .521 .315 r
.42296 .5327 m .42372 .53452 L .42508 .53335 L F
.887 .46 .156 r
.4209 .53196 m .42146 .53373 L .42372 .53452 L F
.272 .742 .943 r
.42372 .53452 m .42146 .53373 L .42279 .53388 L F
.986 .893 .566 r
.42372 .53452 m .42451 .53507 L .42508 .53335 L F
.887 .46 .156 r
.4209 .53196 m .42372 .53452 L .42296 .5327 L F
.272 .742 .943 r
.42372 .53452 m .42279 .53388 L .42579 .53422 L F
.986 .893 .566 r
.42372 .53452 m .42412 .53626 L .42451 .53507 L F
.706 .764 .897 r
.45898 .58487 m .4633 .58537 L .46088 .58696 L F
.113 .004 .439 r
.23592 .54291 m .23653 .54348 L .23686 .53973 L F
0 .013 .557 r
.23592 .54291 m .23741 .54517 L .23653 .54348 L F
.75 .972 .926 r
.6626 .33081 m .66127 .3334 L .66333 .33173 L F
.779 .996 .8 r
.6626 .33081 m .65954 .33389 L .66127 .3334 L F
0 0 0 r
.43913 .57209 m .43964 .57194 L .43587 .57285 L F
.682 .954 .952 r
.44179 .56943 m .44355 .56997 L .43964 .57194 L F
.613 .907 .626 r
.44179 .56943 m .43964 .57194 L .43913 .57209 L F
.932 .697 .561 r
.57674 .40406 m .57966 .40205 L .57824 .39998 L F
.57674 .40406 m .57995 .40362 L .57966 .40205 L F
.773 .979 .712 r
.51054 .40084 m .50929 .40263 L .51032 .4004 L F
.69 .927 .969 r
.50929 .40263 m .50782 .40183 L .51032 .4004 L F
.922 .929 .557 r
.48875 .45403 m .48935 .45411 L .48783 .45568 L F
.58 .94 .807 r
.48875 .45403 m .48935 .45411 L .49068 .45262 L F
.536 .831 .501 r
.48783 .45568 m .48935 .45411 L .49068 .45262 L F
.725 .929 .593 r
.66878 .36408 m .67067 .3625 L .66785 .36621 L F
.845 .912 .88 r
.67255 .35799 m .67067 .3625 L .67184 .35954 L F
.67255 .35799 m .67379 .35948 L .67067 .3625 L F
.799 .945 .595 r
.67184 .35954 m .67067 .3625 L .66878 .36408 L F
.986 .9 .624 r
.47498 .58409 m .47705 .58259 L .47694 .58011 L F
.47498 .58409 m .47599 .58504 L .47705 .58259 L F
.622 .686 .889 r
.30975 .64751 m .31345 .64851 L .31195 .64726 L F
.62 .81 .973 r
.31345 .64851 m .31605 .64776 L .31195 .64726 L F
.1 0 0 r
.58208 .34915 m .58481 .34951 L .58619 .34966 L F
.58208 .34915 m .58481 .34951 L .58619 .34966 L F
.467 .512 .821 r
.58792 .34612 m .58619 .34966 L .58481 .34951 L F
.58792 .34612 m .58909 .34979 L .58619 .34966 L F
.123 .662 .849 r
.58909 .34979 m .58481 .34951 L .58619 .34966 L F
.559 .242 .388 r
.31799 .57586 m .32051 .57575 L .32029 .57791 L F
.31799 .57586 m .32051 .57575 L .32029 .57791 L F
.565 .593 .84 r
.30396 .66253 m .30861 .66649 L .30282 .66656 L F
.672 .872 .974 r
.3078 .66605 m .30767 .6687 L .30861 .66649 L F
.3078 .66605 m .31028 .66754 L .30767 .6687 L F
.797 .701 .758 r
.69679 .27993 m .69811 .28396 L .70071 .28078 L F
.587 .392 .585 r
.69811 .28396 m .70065 .28269 L .70071 .28078 L F
.699 .558 .692 r
.70065 .28269 m .70429 .27991 L .70071 .28078 L F
.935 .585 .163 r
.66785 .36621 m .66856 .36893 L .66717 .36727 L F
.68 .821 .38 r
.66878 .36408 m .66785 .36621 L .66717 .36727 L F
.935 .585 .163 r
.66785 .36621 m .66856 .36893 L .66717 .36727 L F
0 0 0 r
.52988 .46759 m .52668 .47175 L .52944 .46915 L F
.629 .649 .851 r
.52988 .46759 m .53352 .46671 L .53095 .46338 L F
0 0 0 r
.52944 .46915 m .53352 .46671 L .52988 .46759 L F
.789 .82 .877 r
.57552 .40844 m .57613 .40926 L .57674 .40406 L F
.932 .92 .779 r
.37823 .61263 m .37914 .60829 L .37623 .61128 L F
.131 0 .21 r
.39605 .49947 m .39326 .50294 L .39408 .50074 L F
.388 .361 .707 r
.23032 .56642 m .2316 .56157 L .22984 .56209 L F
.23032 .56642 m .23182 .56617 L .2316 .56157 L F
.371 .276 .617 r
.23032 .56642 m .23269 .56833 L .23182 .56617 L F
.988 .896 .6 r
.72852 .31068 m .7288 .30557 L .72773 .30935 L F
.89 .959 .837 r
.72852 .31068 m .72773 .30935 L .72559 .31168 L F
.453 .167 .388 r
.45609 .58587 m .45765 .58376 L .45898 .58487 L F
.776 .4 .344 r
.52576 .42112 m .52266 .41849 L .52257 .42203 L F
.982 .866 .493 r
.69665 .3556 m .69729 .35322 L .69656 .35072 L F
.832 .527 .473 r
.5975 .37329 m .6017 .3718 L .59738 .37244 L F
.5975 .37329 m .60331 .37529 L .6017 .3718 L F
.549 .41 .644 r
.6017 .3718 m .60414 .37448 L .60365 .37173 L F
.6017 .3718 m .60331 .37529 L .60414 .37448 L F
.716 .417 .47 r
.28699 .58136 m .29176 .57919 L .28712 .57891 L F
.28699 .58136 m .29141 .58187 L .29176 .57919 L F
.237 .01 .352 r
.29176 .57919 m .29141 .58187 L .29355 .57837 L F
.988 .725 .42 r
.29141 .58187 m .29176 .57919 L .29355 .57837 L F
.714 .977 .76 r
.50913 .49724 m .5061 .50005 L .50711 .49817 L F
.672 .965 .93 r
.5061 .50005 m .50502 .49957 L .50711 .49817 L F
.436 0 0 r
.41177 .45847 m .41418 .4598 L .41435 .45984 L F
.538 .1 .156 r
.41585 .45817 m .41418 .4598 L .41177 .45847 L F
.699 .17 0 r
.52239 .40989 m .52441 .41109 L .52336 .40986 L F
.831 .862 .868 r
.51547 .40736 m .52017 .40565 L .5158 .40657 L F
.606 .839 .46 r
.52139 .40385 m .52017 .40565 L .52261 .40236 L F
.65 .963 .919 r
.52139 .40385 m .5158 .40657 L .52017 .40565 L F
.455 .804 .998 r
.30959 .54499 m .31346 .54554 L .31112 .54363 L F
.996 .764 .437 r
.39655 .54636 m .39506 .54785 L .39525 .54512 L F
.957 .629 .352 r
.39688 .54892 m .39506 .54785 L .39655 .54636 L F
.704 .718 .86 r
.46522 .57401 m .46703 .57222 L .4631 .57182 L F
.843 .62 .6 r
.36693 .53901 m .36921 .54241 L .36976 .53985 L F
.769 .651 .732 r
.29308 .63773 m .29469 .64139 L .29079 .64017 L F
.355 0 0 r
.29079 .64017 m .29469 .64139 L .29293 .64103 L F
.649 .503 .671 r
.29732 .63807 m .29469 .64139 L .29308 .63773 L F
.29732 .63807 m .2974 .6382 L .29469 .64139 L F
0 0 0 r
.29469 .64139 m .2974 .6382 L .29575 .64048 L F
.29469 .64139 m .29575 .64048 L .29293 .64103 L F
.486 .898 .805 r
.45035 .4399 m .44888 .44113 L .448 .44121 L F
.926 .619 .442 r
.36921 .54241 m .3702 .54585 L .37241 .54649 L F
.928 .597 .393 r
.3702 .54585 m .37233 .54886 L .37241 .54649 L F
.704 .639 .781 r
.62066 .41489 m .62404 .417 L .62326 .41411 L F
.64 .847 .979 r
.59593 .44411 m .59704 .44562 L .59972 .44445 L F
.543 .876 .991 r
.47547 .44522 m .47754 .44613 L .48042 .44505 L F
.762 .522 .57 r
.35498 .63782 m .35902 .63859 L .3575 .63805 L F
.971 .931 .666 r
.35902 .63859 m .35988 .63359 L .3575 .63805 L F
.821 .618 .629 r
.30545 .60876 m .30509 .61168 L .3029 .60813 L F
.579 .126 .141 r
.41585 .45817 m .4169 .45998 L .41418 .4598 L F
.983 .699 .378 r
.37664 .51356 m .37536 .5148 L .37454 .51254 L F
.37664 .51356 m .37697 .51644 L .37536 .5148 L F
.462 .449 .758 r
.52668 .47175 m .53035 .47293 L .52944 .46915 L F
.899 .958 .826 r
.36662 .49123 m .36626 .49458 L .36374 .49284 L F
.79 .819 .875 r
.36374 .49284 m .36626 .49458 L .36305 .49584 L F
.804 .821 .865 r
.41728 .45218 m .41259 .45234 L .41452 .45116 L F
.51 .857 .993 r
.41745 .45048 m .41728 .45218 L .41452 .45116 L F
.41745 .45048 m .4198 .45134 L .41728 .45218 L F
.95 .647 .427 r
.39134 .53647 m .3893 .53557 L .38908 .53283 L F
.919 .546 .123 r
.39124 .53908 m .3893 .53557 L .39134 .53647 L F
.467 .677 .956 r
.47087 .53769 m .47067 .5392 L .46892 .53845 L F
.47087 .53769 m .47325 .53913 L .47067 .5392 L F
0 0 0 r
.5236 .40246 m .52261 .40236 L .5241 .40008 L F
.5236 .40246 m .52139 .40385 L .52261 .40236 L F
.419 0 0 r
.44155 .59766 m .44259 .59922 L .43998 .59941 L F
.168 .702 .838 r
.43998 .59941 m .44259 .59922 L .44133 .59923 L F
.142 0 0 r
.43882 .59835 m .44155 .59766 L .43998 .59941 L F
.168 .702 .838 r
.43998 .59941 m .44133 .59923 L .4386 .59925 L F
.142 0 0 r
.43785 .59971 m .43998 .59941 L .43741 .60031 L F
.43882 .59835 m .43998 .59941 L .43785 .59971 L F
.059 .61 .829 r
.49334 .4475 m .49481 .44789 L .49371 .44753 L F
.4908 .44731 m .49226 .44752 L .49334 .4475 L F
.49226 .44752 m .49481 .44789 L .49334 .4475 L F
.188 .276 .724 r
.49212 .44263 m .49334 .4475 L .49495 .44506 L F
.49334 .4475 m .49351 .44816 L .49382 .44749 L F
.468 .88 .94 r
.49401 .44722 m .49481 .44789 L .49685 .44655 L F
.188 .276 .724 r
.49334 .4475 m .49361 .44749 L .49382 .44713 L F
.49364 .44704 m .49382 .44713 L .49495 .44506 L F
.49334 .4475 m .49382 .44713 L .49364 .44704 L F
.468 .88 .94 r
.4933 .44739 m .49361 .44749 L .49392 .44729 L F
.188 .276 .724 r
.49361 .44749 m .49392 .44729 L .49495 .44506 L F
.704 .894 .966 r
.49495 .44506 m .49392 .44729 L .4933 .44739 L F
.468 .88 .94 r
.4933 .44739 m .49392 .44729 L .49401 .44722 L F
.49361 .44749 m .49481 .44789 L .49401 .44722 L F
.188 .276 .724 r
.49361 .44749 m .49382 .44749 L .49392 .44729 L F
.704 .894 .966 r
.49392 .44729 m .49351 .44816 L .4933 .44739 L F
.468 .88 .94 r
.4933 .44739 m .49401 .44722 L .49532 .44787 L F
.439 .868 .76 r
.49481 .44789 m .49697 .44679 L .49685 .44655 L F
.49697 .44679 m .49704 .44676 L .49685 .44655 L F
.614 .908 .627 r
.49678 .44641 m .49685 .44655 L .49864 .44457 L F
.468 .88 .94 r
.49401 .44722 m .49685 .44655 L .49533 .44786 L F
.614 .908 .627 r
.49532 .44787 m .49685 .44655 L .49678 .44641 L F
.468 .88 .94 r
.49401 .44722 m .49533 .44786 L .49532 .44787 L F
.528 .514 .785 r
.4908 .44731 m .49351 .44816 L .49334 .4475 L F
.4908 .44731 m .49334 .4475 L .49212 .44263 L F
.059 .61 .829 r
.4908 .44731 m .49371 .44753 L .4933 .44739 L F
.696 .406 .48 r
.3397 .56851 m .34274 .56933 L .34307 .56583 L F
.501 .239 .449 r
.34307 .56583 m .34571 .56851 L .34579 .56575 L F
.34307 .56583 m .34274 .56933 L .34571 .56851 L F
.378 0 0 r
.41468 .59968 m .41918 .59851 L .41784 .6 L F
.711 .274 .212 r
.42213 .59949 m .41784 .6 L .41918 .59851 L F
.98 .772 .552 r
.41194 .51259 m .41147 .51529 L .41341 .51645 L F
.951 .663 .456 r
.41122 .51856 m .41341 .51645 L .41147 .51529 L F
.41122 .51856 m .41345 .51967 L .41341 .51645 L F
.336 .707 .983 r
.55663 .44793 m .55786 .44663 L .55494 .44916 L F
.55663 .44793 m .55916 .44813 L .55786 .44663 L F
.614 .449 .635 r
.53895 .415 m .53913 .41838 L .53618 .41852 L F
.48 .137 .307 r
.53913 .41838 m .53621 .42015 L .53618 .41852 L F
.683 .973 .915 r
.35117 .55906 m .34907 .56071 L .34696 .56053 L F
.866 .47 .286 r
.38629 .52637 m .38439 .52794 L .38376 .52582 L F
.38629 .52637 m .38732 .52922 L .38439 .52794 L F
.302 0 0 r
.3829 .49173 m .38126 .49053 L .38029 .493 L F
.3829 .49173 m .38399 .49011 L .38126 .49053 L F
.431 .609 .923 r
.30753 .64424 m .30975 .64751 L .31195 .64726 L F
.685 .979 .829 r
.60737 .39794 m .60287 .40047 L .60511 .39869 L F
0 .419 .754 r
.60862 .39806 m .60959 .39866 L .60737 .39794 L F
.60862 .39806 m .60737 .39794 L .60511 .39869 L F
.559 .812 .993 r
.63355 .37007 m .63482 .37146 L .63204 .37206 L F
.63204 .37206 m .63482 .37146 L .63355 .37007 L F
.755 .991 .884 r
.54114 .48736 m .54285 .48551 L .54207 .48516 L F
.772 .997 .824 r
.53897 .48799 m .54114 .48736 L .54207 .48516 L F
.928 .898 .494 r
.47941 .57082 m .47951 .57243 L .48064 .5694 L F
0 0 0 r
.48163 .56768 m .48064 .5694 L .4826 .56567 L F
.655 .867 .491 r
.48163 .56768 m .47941 .57082 L .48064 .5694 L F
.901 .641 .534 r
.37572 .56443 m .37926 .56274 L .37731 .56162 L F
.37572 .56443 m .37905 .56536 L .37926 .56274 L F
.64 .652 .846 r
.6293 .3475 m .63116 .35038 L .63258 .34818 L F
.588 .476 .694 r
.53442 .3956 m .53815 .39501 L .53656 .39246 L F
.516 .244 .44 r
.53441 .39786 m .53815 .39501 L .53442 .3956 L F
.588 .476 .694 r
.53442 .3956 m .53815 .39501 L .53656 .39246 L F
.516 .244 .44 r
.53815 .39501 m .53441 .39786 L .53442 .3956 L F
.833 1 .811 r
.33775 .58105 m .33714 .58305 L .33997 .5801 L F
.74 .983 .909 r
.33997 .5801 m .34042 .58066 L .33775 .58105 L F
.399 .091 .322 r
.3364 .57951 m .33525 .58197 L .3401 .57966 L F
.34007 .57957 m .3401 .57966 L .34028 .57957 L F
.3364 .57951 m .3401 .57966 L .34007 .57957 L F
.415 .183 .451 r
.33775 .58105 m .34042 .58066 L .3404 .58058 L F
.341 0 .231 r
.3401 .57967 m .33688 .5812 L .33775 .58105 L F
.3401 .57966 m .33525 .58197 L .3401 .57967 L F
.74 .983 .909 r
.34039 .58062 m .34029 .58026 L .34042 .58066 L F
.34029 .58026 m .33992 .5788 L .3404 .58058 L F
.34029 .58026 m .3404 .58058 L .34042 .58066 L F
.33997 .5801 m .33993 .57908 L .34039 .58062 L F
.3401 .57968 m .33992 .5788 L .34039 .58062 L F
.33993 .57908 m .33992 .5788 L .3401 .57968 L F
.341 0 .231 r
.34028 .57957 m .3401 .57966 L .3401 .57967 L F
.415 .183 .451 r
.3401 .57967 m .33992 .5788 L .34028 .57957 L F
.33775 .58105 m .33992 .5788 L .3401 .57967 L F
.33775 .58105 m .3404 .58058 L .33992 .5788 L F
.341 0 .231 r
.33688 .5812 m .33525 .58197 L .33775 .58105 L F
0 0 .16 r
.49394 .53914 m .49324 .54174 L .49161 .54265 L F
.367 .208 .53 r
.61515 .37126 m .61731 .37154 L .61687 .36892 L F
.361 .009 .226 r
.61515 .37126 m .61399 .3732 L .61731 .37154 L F
.455 .306 .589 r
.54137 .41417 m .53913 .41838 L .53895 .415 L F
.038 .297 .788 r
.60076 .38472 m .60293 .38678 L .6022 .38819 L F
0 .092 .639 r
.60293 .38678 m .60419 .39058 L .6022 .38819 L F
.73 .41 .438 r
.33409 .49866 m .33884 .49687 L .33449 .49737 L F
.33409 .49866 m .33874 .49903 L .33884 .49687 L F
.791 .464 .436 r
.33874 .49903 m .33928 .49924 L .33884 .49687 L F
.631 .945 .732 r
.66514 .3202 m .66359 .32081 L .66688 .31814 L F
.802 .771 .825 r
.40244 .48304 m .40365 .48636 L .40615 .48342 L F
.672 .706 .872 r
.60384 .35514 m .60345 .35743 L .60818 .35632 L F
.078 0 .115 r
.32063 .61849 m .31776 .62142 L .31959 .62081 L F
.654 .598 .779 r
.31776 .62142 m .32146 .62237 L .31959 .62081 L F
.873 .936 .859 r
.37193 .62116 m .37479 .61831 L .37335 .61738 L F
.902 .857 .788 r
.37479 .61831 m .37621 .61181 L .37335 .61738 L F
.856 .683 .666 r
.381 .56897 m .38072 .57206 L .38281 .57246 L F
.855 .578 .519 r
.38072 .57206 m .3806 .57451 L .38281 .57246 L F
.87 .605 .535 r
.3806 .57451 m .38273 .57549 L .38281 .57246 L F
.817 .97 .661 r
.52028 .4137 m .51931 .41649 L .52131 .41254 L F
.696 .777 .914 r
.52131 .41254 m .51931 .41649 L .52195 .41511 L F
.693 .9 .971 r
.52028 .4137 m .51931 .41649 L .52195 .41511 L F
.754 .308 .193 r
.36484 .50343 m .36287 .50485 L .36238 .50331 L F
.36484 .50343 m .36672 .50574 L .36287 .50485 L F
.721 .225 .061 r
.60191 .42767 m .60192 .42709 L .60219 .42541 L F
.653 .241 0 r
.60305 .42871 m .60192 .42684 L .60192 .42709 L F
0 .279 .678 r
.60409 .4291 m .60305 .42871 L .60192 .42709 L F
.721 .225 .061 r
.60175 .42893 m .60409 .4291 L .60192 .42709 L F
.60175 .42893 m .60192 .42709 L .60191 .42767 L F
.653 .241 0 r
.60192 .42684 m .60089 .42514 L .60192 .42709 L F
0 .279 .678 r
.60409 .4291 m .60611 .43026 L .60305 .42871 L F
.52 .782 .992 r
.25649 .61696 m .25505 .61887 L .25356 .61734 L F
.25356 .61734 m .25505 .61887 L .25649 .61696 L F
.753 .477 .514 r
.49874 .4385 m .5031 .43744 L .50018 .43914 L F
.914 .866 .777 r
.5031 .43744 m .49894 .43956 L .49874 .4385 L F
.5031 .43744 m .50065 .44178 L .4992 .4399 L F
.239 0 0 r
.50072 .43894 m .5031 .43744 L .50537 .4372 L F
.50018 .43914 m .5031 .43744 L .50072 .43894 L F
.50537 .4372 m .5031 .43744 L .50018 .43914 L F
.914 .866 .777 r
.5031 .43744 m .4992 .4399 L .49894 .43956 L F
.559 .37 .581 r
.28729 .59217 m .28753 .59508 L .28461 .59546 L F
0 0 .358 r
.28614 .58824 m .28728 .59105 L .28729 .59217 L F
0 0 .141 r
.28765 .59152 m .28729 .59217 L .28728 .59105 L F
.28765 .59152 m .28753 .59508 L .28729 .59217 L F
.724 .702 .829 r
.29535 .63468 m .29732 .63807 L .29308 .63773 L F
0 0 .485 r
.29788 .6384 m .29732 .63807 L .29975 .63977 L F
.29788 .6384 m .2974 .6382 L .29732 .63807 L F
.939 .932 .767 r
.56574 .45218 m .56363 .45625 L .56367 .45341 L F
0 0 0 r
.56753 .45132 m .56574 .45218 L .56367 .45341 L F
.56753 .45132 m .56367 .45341 L .56323 .45157 L F
.791 .348 .194 r
.67567 .34899 m .67708 .34966 L .67429 .35083 L F
.985 .834 .61 r
.67429 .35083 m .67708 .34966 L .67556 .35252 L F
.542 .674 .924 r
.32273 .64997 m .32413 .65188 L .32667 .65122 L F
.975 .764 .555 r
.28088 .59811 m .28221 .60137 L .28006 .60051 L F
.811 .58 .589 r
.28084 .60082 m .28482 .59842 L .28221 .60137 L F
.28267 .59937 m .28482 .59842 L .28084 .60082 L F
.28482 .59842 m .28493 .59837 L .28488 .59843 L F
.28482 .59842 m .28488 .59843 L .28221 .60137 L F
.403 .287 .605 r
.28617 .59694 m .28493 .59837 L .28461 .59546 L F
.28693 .59767 m .28555 .59815 L .28617 .59694 L F
.28555 .59815 m .28493 .59837 L .28617 .59694 L F
.504 .313 .555 r
.28493 .59837 m .28471 .60121 L .28221 .60137 L F
.811 .58 .589 r
.28006 .60051 m .28267 .59937 L .28084 .60082 L F
.28006 .60051 m .28471 .60121 L .28493 .59837 L F
.409 .234 .53 r
.28697 .60044 m .28471 .60121 L .28493 .59837 L F
.28697 .60044 m .28471 .60121 L .28493 .59837 L F
.556 .284 .458 r
.28409 .59824 m .28693 .59767 L .28376 .6 L F
.28461 .59546 m .28597 .59675 L .28409 .59824 L F
.28597 .59675 m .28693 .59767 L .28409 .59824 L F
.534 .286 .486 r
.28753 .59508 m .28693 .59767 L .28461 .59546 L F
.595 .344 .506 r
.28376 .6 m .28628 .59671 L .28765 .59152 L F
.28628 .59671 m .28753 .59508 L .28756 .5942 L F
.28628 .59671 m .28756 .5942 L .28765 .59152 L F
.556 .284 .458 r
.28461 .59546 m .28409 .59824 L .28268 .5971 L F
.28409 .59824 m .28376 .6 L .28301 .59798 L F
.28409 .59824 m .28301 .59798 L .28268 .5971 L F
.564 .674 .913 r
.24506 .58107 m .24669 .58375 L .24364 .58397 L F
.97 .769 .578 r
.24506 .58107 m .24501 .58137 L .24669 .58375 L F
.657 .667 .847 r
.2479 .58546 m .24364 .58397 L .24669 .58375 L F
.97 .769 .578 r
.24501 .58137 m .24457 .5841 L .24669 .58375 L F
.657 .667 .847 r
.24829 .58559 m .2479 .58546 L .24669 .58375 L F
0 .36 .829 r
.24669 .58375 m .24834 .58439 L .24829 .58559 L F
.939 .57 .215 r
.24834 .58439 m .25045 .58774 L .24829 .58559 L F
.39 .249 .566 r
.25045 .58774 m .24833 .58919 L .24829 .58559 L F
.215 0 .021 r
.65401 .38206 m .65208 .3846 L .65377 .38372 L F
.65401 .38206 m .65108 .38404 L .65191 .3845 L F
.65401 .38206 m .65191 .3845 L .65232 .38429 L F
.038 0 .068 r
.65671 .38074 m .65401 .38206 L .65377 .38372 L F
.817 .999 .835 r
.65589 .38024 m .65394 .38345 L .65243 .3823 L F
.65394 .38345 m .65377 .38372 L .65366 .38359 L F
.65394 .38345 m .65366 .38359 L .65243 .3823 L F
.215 0 .021 r
.65232 .38429 m .65191 .3845 L .65208 .3846 L F
.679 .874 .972 r
.45703 .44975 m .46151 .44925 L .45956 .44877 L F
.684 .939 .964 r
.46151 .44925 m .46279 .4473 L .45956 .44877 L F
.46151 .44925 m .464 .44801 L .46279 .4473 L F
0 0 0 r
.29575 .64048 m .2974 .6382 L .29788 .6384 L F
0 .4 .85 r
.3397 .51708 m .33889 .51501 L .33725 .515 L F
.3397 .51708 m .3402 .5167 L .33889 .51501 L F
.854 .701 .691 r
.33286 .58484 m .33714 .58305 L .33525 .58197 L F
.33286 .58484 m .33665 .58654 L .33714 .58305 L F
.625 .825 .977 r
.33525 .58197 m .33714 .58305 L .33775 .58105 L F
0 0 .104 r
.32417 .60768 m .32516 .60692 L .32585 .60199 L F
.474 .809 .999 r
.35498 .63782 m .3575 .63805 L .35478 .63649 L F
.856 .896 .863 r
.35478 .63649 m .3575 .63805 L .35988 .63359 L F
.983 .842 .626 r
.59171 .40229 m .58954 .40353 L .59017 .40085 L F
.59171 .40229 m .59091 .40484 L .58954 .40353 L F
.256 .055 .403 r
.22984 .56209 m .2316 .56157 L .23196 .55914 L F
0 0 .514 r
.5629 .43447 m .56373 .438 L .56421 .4372 L F
.613 .885 .565 r
.56421 .4372 m .56373 .438 L .56285 .4387 L F
.932 .617 .423 r
.26218 .60153 m .26273 .60366 L .26031 .60162 L F
.152 0 0 r
.26031 .60162 m .2627 .60182 L .26218 .60153 L F
.2627 .60182 m .26264 .60165 L .26218 .60153 L F
.26218 .60153 m .26355 .60189 L .26031 .60162 L F
0 .28 .745 r
.26391 .60414 m .26031 .60162 L .26221 .6009 L F
.927 .658 .509 r
.26031 .60162 m .26273 .60366 L .25991 .60432 L F
0 .28 .745 r
.26391 .60414 m .26273 .60366 L .26031 .60162 L F
.297 0 0 r
.25991 .60432 m .26273 .60366 L .26391 .60414 L F
.25991 .60432 m .26391 .60414 L .26228 .60542 L F
.793 .965 .653 r
.26319 .60432 m .26228 .60542 L .26267 .60511 L F
.26366 .60373 m .26267 .60511 L .26391 .60414 L F
.26362 .60367 m .26267 .60511 L .26366 .60373 L F
.495 .203 .4 r
.26356 .60388 m .26228 .60542 L .26385 .60384 L F
.25991 .60432 m .26228 .60542 L .26356 .60388 L F
.793 .965 .653 r
.26362 .60367 m .26228 .60542 L .26319 .60432 L F
.551 .39 .616 r
.25991 .60432 m .26356 .60388 L .26221 .6009 L F
.26356 .60388 m .26372 .60386 L .26366 .60373 L F
.26356 .60388 m .26366 .60373 L .26221 .6009 L F
.649 .264 0 r
.26271 .60185 m .26329 .60301 L .26391 .60414 L F
.26329 .60301 m .26366 .60373 L .26391 .60414 L F
.26221 .6009 m .26273 .60192 L .26271 .60185 L F
.26273 .60192 m .26362 .60367 L .26271 .60185 L F
.551 .39 .616 r
.26372 .60386 m .26385 .60384 L .26221 .6009 L F
.649 .264 0 r
.26329 .60301 m .26362 .60367 L .26366 .60373 L F
.152 0 0 r
.2627 .60182 m .26355 .60189 L .26264 .60165 L F
.632 .265 .328 r
.32844 .58476 m .33286 .58484 L .33325 .58271 L F
.201 0 .215 r
.33325 .58271 m .33286 .58484 L .33525 .58197 L F
.199 0 .212 r
.33325 .58271 m .33525 .58197 L .3364 .57951 L F
.612 .956 .847 r
.67732 .37817 m .68082 .37614 L .67897 .3764 L F
.558 .934 .843 r
.67897 .3764 m .68082 .37614 L .68311 .3747 L F
.804 .9 .91 r
.30096 .63986 m .30433 .63823 L .30217 .63729 L F
.619 .233 .29 r
.30397 .63883 m .30433 .63823 L .3062 .64064 L F
.96 .7 .496 r
.30217 .63729 m .30433 .63823 L .30397 .63883 L F
.725 .196 0 r
.3062 .64064 m .30433 .63823 L .30217 .63729 L F
.617 .451 .636 r
.34859 .59233 m .34905 .59522 L .35165 .59183 L F
.35165 .59183 m .34905 .59522 L .34859 .59233 L F
.2 .152 .576 r
.5366 .4565 m .53493 .46082 L .53494 .46028 L F
.5366 .4565 m .53697 .45937 L .53493 .46082 L F
.415 .24 .533 r
.53697 .45937 m .53452 .46292 L .53493 .46082 L F
0 0 0 r
.42194 .55446 m .42118 .55838 L .42104 .5588 L F
.832 .385 .165 r
.42202 .55983 m .42136 .56121 L .42367 .56158 L F
.42104 .5588 m .42136 .56121 L .42202 .55983 L F
.942 .708 .556 r
.42367 .56158 m .42121 .56379 L .42136 .56121 L F
.123 .414 .861 r
.42367 .56158 m .42476 .56061 L .42118 .55838 L F
.965 .775 .335 r
.42052 .56283 m .42121 .56379 L .42136 .56121 L F
.774 .508 .533 r
.42476 .56061 m .4206 .56278 L .42136 .56121 L F
.4206 .56278 m .42052 .56283 L .42136 .56121 L F
0 0 .13 r
.42118 .55838 m .42136 .56121 L .42104 .5588 L F
.76 .996 .83 r
.54484 .47474 m .54226 .47739 L .54342 .47499 L F
.754 .994 .865 r
.54342 .47499 m .54226 .47739 L .54049 .47749 L F
.099 .141 .618 r
.3221 .53729 m .32003 .5395 L .31912 .53911 L F
.3221 .53729 m .32152 .53906 L .32003 .5395 L F
.609 .952 .82 r
.49896 .40751 m .50038 .40579 L .50243 .40545 L F
.49896 .40751 m .49832 .40731 L .50038 .40579 L F
.896 .911 .826 r
.60389 .43419 m .60553 .43534 L .6052 .43205 L F
.58 .343 .522 r
.60463 .42131 m .60487 .41833 L .60267 .41749 L F
.60463 .42131 m .60702 .4206 L .60487 .41833 L F
.226 .735 .887 r
.59151 .3455 m .59465 .34523 L .59491 .3456 L F
.645 .96 .783 r
.59491 .3456 m .59697 .3433 L .59824 .34415 L F
.886 .913 .839 r
.34747 .53737 m .34722 .53454 L .34932 .53531 L F
.34747 .53737 m .34385 .54079 L .34722 .53454 L F
.956 .82 .668 r
.34932 .53531 m .34791 .53305 L .34842 .53299 L F
.34932 .53531 m .34722 .53454 L .34791 .53305 L F
.612 .956 .847 r
.67732 .37817 m .67897 .3764 L .67715 .3782 L F
.532 .31 .524 r
.2852 .55262 m .28813 .55366 L .2883 .55005 L F
.548 .26 .43 r
.2852 .55262 m .28764 .55484 L .28813 .55366 L F
.413 .529 .865 r
.35884 .61392 m .35928 .61614 L .35719 .61566 L F
.269 .091 .446 r
.23686 .53973 m .23981 .53851 L .24017 .53543 L F
.184 .062 .469 r
.23686 .53973 m .2394 .54077 L .23981 .53851 L F
.23686 .53973 m .23653 .54348 L .2394 .54077 L F
0 0 0 r
.63387 .33817 m .63766 .33644 L .63456 .33749 L F
.028 0 0 r
.62652 .34533 m .62523 .34565 L .62246 .34591 L F
.504 0 0 r
.62652 .34533 m .62889 .34606 L .62523 .34565 L F
.826 .541 .506 r
.37357 .5555 m .37731 .55844 L .37622 .55556 L F
.096 0 .34 r
.51653 .48683 m .51458 .49056 L .51621 .48937 L F
0 0 0 r
.51621 .48937 m .51458 .49056 L .5137 .49217 L F
.79 .461 .433 r
.6501 .34343 m .64942 .34523 L .64718 .34274 L F
0 0 .071 r
.65201 .34191 m .64942 .34523 L .6501 .34343 L F
.772 .674 .755 r
.55793 .38571 m .55309 .38832 L .5556 .38503 L F
.229 0 0 r
.26077 .52073 m .26263 .5213 L .26573 .51932 L F
.26077 .52073 m .2605 .5219 L .26263 .5213 L F
0 0 0 r
.64336 .39897 m .64731 .39743 L .6462 .39864 L F
.263 .763 .889 r
.64336 .39897 m .6462 .39864 L .64386 .39873 L F
.542 .914 .749 r
.64233 .39948 m .6445 .39824 L .64336 .39897 L F
.263 .763 .889 r
.64336 .39897 m .64386 .39873 L .64212 .39879 L F
.542 .914 .749 r
.64054 .4005 m .64233 .39948 L .64336 .39897 L F
0 0 0 r
.64336 .39897 m .6445 .39824 L .64731 .39743 L F
0 .102 .658 r
.58124 .38285 m .58274 .38442 L .58073 .38074 L F
.644 .37 .489 r
.68497 .30631 m .68912 .30337 L .68498 .30321 L F
.68497 .30631 m .68926 .30615 L .68912 .30337 L F
.682 .399 .487 r
.68912 .30337 m .68926 .30615 L .69189 .30573 L F
.669 .405 .513 r
.68912 .30337 m .69189 .30573 L .69191 .30351 L F
.727 .986 .794 r
.51072 .49551 m .50913 .49724 L .51015 .49526 L F
.728 .981 .761 r
.50913 .49724 m .50711 .49817 L .51015 .49526 L F
.858 .973 .864 r
.34925 .64399 m .35232 .64105 L .35085 .64047 L F
.878 .97 .845 r
.35085 .64047 m .35232 .64105 L .35498 .63782 L F
.809 .379 .222 r
.37387 .5107 m .37122 .5116 L .37112 .50908 L F
.37387 .5107 m .37454 .51254 L .37122 .5116 L F
0 0 0 r
.24561 .58963 m .24449 .59144 L .24254 .59232 L F
.777 .452 0 r
.24249 .59342 m .24342 .59517 L .24254 .59232 L F
.24249 .59342 m .24254 .59232 L .24449 .59144 L F
.904 .815 .75 r
.67307 .35525 m .67379 .35948 L .67255 .35799 L F
.602 .859 .51 r
.25075 .56593 m .25165 .56459 L .25357 .56251 L F
.407 .193 .473 r
.25303 .56522 m .25075 .56593 L .25357 .56251 L F
.458 .855 .973 r
.25303 .56522 m .25165 .56459 L .25075 .56593 L F
.862 .893 .856 r
.36233 .56006 m .35969 .56296 L .35803 .56163 L F
.974 .787 .59 r
.69635 .34438 m .6985 .34322 L .69682 .3417 L F
.69635 .34438 m .69795 .34582 L .6985 .34322 L F
.918 .688 .575 r
.40017 .57573 m .39768 .57733 L .39798 .57452 L F
.40017 .57573 m .39985 .57868 L .39768 .57733 L F
.783 .862 .908 r
.25099 .62563 m .24587 .62661 L .2481 .62619 L F
.479 .898 .861 r
.25341 .62449 m .25099 .62563 L .2481 .62619 L F
.711 .964 .941 r
.64182 .38818 m .63966 .3898 L .63757 .38932 L F
.744 .991 .808 r
.65705 .33741 m .65491 .33954 L .65587 .33931 L F
.541 .727 .96 r
.65587 .33931 m .65863 .33922 L .65705 .33741 L F
.231 0 .327 r
.65067 .3859 m .64786 .3874 L .64847 .38792 L F
.65086 .38541 m .64786 .3874 L .65067 .3859 L F
.65208 .3846 m .64847 .38792 L .65052 .38647 L F
.831 .922 .895 r
.65023 .38407 m .6505 .38632 L .6498 .38595 L F
.6505 .38632 m .65052 .38647 L .65046 .38643 L F
.6505 .38632 m .65046 .38643 L .6498 .38595 L F
.231 0 .327 r
.65208 .3846 m .65086 .38541 L .65067 .3859 L F
.915 .977 .705 r
.33446 .60522 m .33222 .60886 L .33184 .60706 L F
.993 .776 .404 r
.33446 .60522 m .33262 .6013 L .33378 .6011 L F
.33446 .60522 m .33341 .60437 L .33262 .6013 L F
.975 .921 .666 r
.33446 .60522 m .33184 .60706 L .33341 .60437 L F
.554 .035 0 r
.35556 .56669 m .35431 .56732 L .35268 .566 L F
.35431 .56732 m .35261 .56673 L .35268 .566 L F
.35556 .56669 m .35531 .56663 L .35247 .56823 L F
.372 .664 .971 r
.35531 .56663 m .35723 .56833 L .35865 .56755 L F
.35723 .56833 m .35769 .56874 L .35785 .56854 L F
.35723 .56833 m .35785 .56854 L .35865 .56755 L F
.554 .035 0 r
.35431 .56732 m .35247 .56823 L .35261 .56673 L F
.835 .97 .886 r
.55495 .47655 m .55707 .47274 L .55437 .47601 L F
.55495 .47655 m .55812 .47365 L .55707 .47274 L F
.983 .869 .502 r
.39999 .5594 m .39853 .56066 L .39859 .55812 L F
.39999 .5594 m .39927 .5624 L .39853 .56066 L F
.512 .726 .97 r
.71362 .32392 m .71483 .32128 L .71256 .32255 L F
.71362 .32392 m .71637 .3234 L .71483 .32128 L F
.744 .412 .421 r
.57798 .42371 m .57768 .42166 L .57373 .42241 L F
.935 .601 .378 r
.42992 .56079 m .43191 .55923 L .42946 .55798 L F
.42992 .56079 m .4317 .56235 L .43191 .55923 L F
.946 .797 .664 r
.41409 .52089 m .41651 .52249 L .41676 .51937 L F
.821 1 .811 r
.52494 .49884 m .52495 .50014 L .52851 .49637 L F
0 0 0 r
.39358 .50783 m .39797 .50511 L .39325 .50563 L F
.39358 .50783 m .39461 .5072 L .39797 .50511 L F
.575 .068 .011 r
.39797 .50511 m .4009 .50695 L .40091 .50558 L F
.39797 .50511 m .39461 .5072 L .4009 .50695 L F
.905 .844 .774 r
.36807 .62402 m .37193 .62116 L .37086 .62091 L F
.36807 .62402 m .36994 .62516 L .37193 .62116 L F
.873 .936 .859 r
.37193 .62116 m .37335 .61738 L .37086 .62091 L F
.953 .905 .528 r
.56285 .4387 m .56288 .44163 L .56196 .44419 L F
.996 .762 .453 r
.5873 .43937 m .58864 .44091 L .58716 .44106 L F
.87 .889 .846 r
.59126 .43728 m .58864 .44091 L .5873 .43937 L F
0 .314 .707 r
.58864 .44091 m .58895 .44075 L .58716 .44106 L F
.711 .274 .212 r
.42213 .59949 m .42152 .60062 L .41784 .6 L F
.708 .613 .748 r
.54148 .45288 m .5406 .45439 L .5434 .45116 L F
.872 .513 .366 r
.35241 .513 m .35404 .51628 L .35606 .5167 L F
.879 .533 .392 r
.35404 .51628 m .35417 .51846 L .35606 .5167 L F
.854 .492 .366 r
.35606 .5167 m .35417 .51846 L .35655 .51901 L F
0 0 .223 r
.48895 .55001 m .48703 .55276 L .4888 .54897 L F
.48895 .55001 m .48865 .55129 L .48703 .55276 L F
0 0 0 r
.48865 .55129 m .48686 .55544 L .48703 .55276 L F
.939 .869 .742 r
.57097 .42176 m .57141 .41679 L .57084 .41942 L F
.489 .009 .043 r
.57425 .42279 m .57373 .42241 L .57097 .42176 L F
.744 .412 .421 r
.57798 .42371 m .57373 .42241 L .57425 .42279 L F
.306 .459 .849 r
.57425 .42279 m .57097 .42176 L .57084 .41942 L F
.579 .877 .993 r
.44274 .58261 m .44566 .58235 L .4444 .58143 L F
.872 .952 .859 r
.44566 .58235 m .44179 .5844 L .4444 .58143 L F
.488 .345 .612 r
.34533 .5974 m .34347 .60135 L .34383 .59921 L F
.651 .921 .977 r
.25392 .63191 m .258 .63122 L .25654 .63251 L F
0 0 0 r
.25654 .63251 m .258 .63122 L .25997 .62979 L F
.284 0 .108 r
.35271 .53012 m .34842 .53299 L .35161 .53193 L F
.986 .9 .622 r
.35161 .53193 m .35214 .52822 L .35271 .53012 L F
.743 .513 .581 r
.3427 .54643 m .34133 .54911 L .3381 .54541 L F
0 0 0 r
.344 .54475 m .34133 .54911 L .3427 .54643 L F
.849 .971 .874 r
.44482 .56891 m .44179 .56943 L .44391 .56748 L F
.44482 .56891 m .44355 .56997 L .44179 .56943 L F
.817 .987 .879 r
.44798 .56544 m .44482 .56891 L .44391 .56748 L F
.316 .716 .979 r
.44924 .56942 m .44482 .56891 L .44798 .56544 L F
.946 .797 .664 r
.41409 .52089 m .41676 .51937 L .41345 .51967 L F
.237 .055 .42 r
.23868 .5918 m .24097 .59192 L .23999 .58784 L F
.224 .228 .653 r
.23999 .58784 m .24241 .58458 L .23967 .58532 L F
.23999 .58784 m .2429 .58718 L .24241 .58458 L F
.062 0 .408 r
.23999 .58784 m .24225 .58954 L .2429 .58718 L F
.23999 .58784 m .24097 .59192 L .24225 .58954 L F
.95 .807 .359 r
.52429 .39872 m .52343 .39998 L .5241 .40008 L F
.703 .744 .236 r
.52578 .39371 m .52457 .39765 L .52429 .39872 L F
.752 .85 .406 r
.52457 .39765 m .52343 .39998 L .52429 .39872 L F
.965 .93 .613 r
.32614 .53934 m .3284 .53853 L .32836 .53662 L F
.32614 .53934 m .32666 .54226 L .3284 .53853 L F
0 0 0 r
.24622 .59027 m .24561 .58963 L .24799 .58924 L F
.24622 .59027 m .24449 .59144 L .24561 .58963 L F
.24622 .59027 m .24249 .59342 L .24449 .59144 L F
.751 .62 .713 r
.24225 .58954 m .24249 .59342 L .24622 .59027 L F
.24225 .58954 m .24622 .59027 L .24393 .5919 L F
.423 .191 .454 r
.24745 .58863 m .24482 .59107 L .24622 .59027 L F
.24482 .59107 m .24393 .5919 L .24622 .59027 L F
0 0 0 r
.24622 .59027 m .24799 .58924 L .24833 .58919 L F
.377 .117 .388 r
.51844 .43129 m .5216 .42794 L .5211 .43059 L F
.607 .177 .199 r
.5216 .42794 m .52376 .42979 L .5211 .43059 L F
.5216 .42794 m .52412 .42872 L .52376 .42979 L F
.738 .795 .898 r
.45203 .56595 m .44798 .56544 L .44975 .56516 L F
.48 .22 .442 r
.45203 .56595 m .44924 .56942 L .44798 .56544 L F
.45203 .56595 m .4518 .56895 L .44924 .56942 L F
.498 .786 .997 r
.44975 .56516 m .45203 .56595 L .45474 .56245 L F
.44975 .56516 m .45329 .56407 L .45203 .56595 L F
.619 .858 .495 r
.45237 .56551 m .45329 .56407 L .45474 .56245 L F
.45203 .56595 m .45329 .56407 L .45237 .56551 L F
.03 .25 .751 r
.45421 .56243 m .45422 .56263 L .45329 .56407 L F
.764 .717 .809 r
.45329 .56407 m .45725 .56457 L .45409 .56744 L F
.469 0 0 r
.45434 .56465 m .45725 .56457 L .45329 .56407 L F
.03 .25 .751 r
.45422 .56263 m .45434 .56465 L .45329 .56407 L F
.107 .251 .73 r
.45329 .56407 m .45409 .56744 L .45203 .56595 L F
.461 .205 .438 r
.45203 .56595 m .45409 .56744 L .4518 .56895 L F
.659 .204 .16 r
.34579 .56575 m .34872 .5677 L .3501 .56634 L F
.844 .836 .838 r
.35243 .56354 m .3501 .56634 L .34835 .56497 L F
.965 .688 .458 r
.34835 .56497 m .34872 .5677 L .3501 .56634 L F
.696 .583 .724 r
.35243 .56354 m .35268 .566 L .3501 .56634 L F
.138 .315 .78 r
.35247 .56823 m .3501 .56634 L .35268 .566 L F
.051 0 0 r
.53017 .42441 m .53331 .4211 L .53184 .42284 L F
.139 0 0 r
.53184 .42284 m .53331 .4211 L .53621 .42015 L F
.871 .916 .857 r
.34475 .6467 m .34925 .64399 L .34825 .64375 L F
.858 .973 .864 r
.34925 .64399 m .35085 .64047 L .34825 .64375 L F
0 0 0 r
.53483 .41168 m .53153 .41441 L .53408 .41324 L F
.194 0 .057 r
.5377 .4103 m .53483 .41168 L .53408 .41324 L F
.124 0 .232 r
.52874 .48317 m .52625 .48637 L .52679 .48407 L F
.909 .571 .39 r
.38362 .52343 m .38147 .5247 L .38114 .52212 L F
.38362 .52343 m .38376 .52582 L .38147 .5247 L F
.85 .471 0 r
.58501 .38838 m .58666 .39173 L .58509 .39081 L F
.985 .759 .513 r
.58666 .39173 m .58483 .39307 L .58509 .39081 L F
.58666 .39173 m .58648 .39477 L .58483 .39307 L F
.737 .753 .866 r
.60156 .4082 m .60589 .40904 L .60446 .4079 L F
.618 .864 .989 r
.60446 .4079 m .60589 .40904 L .60852 .40798 L F
.759 .739 .217 r
.5599 .39107 m .55929 .3932 L .55969 .39083 L F
.972 .879 .683 r
.41527 .54484 m .41767 .54273 L .41793 .54473 L F
.646 .967 .89 r
.46097 .43449 m .4566 .43619 L .45997 .4342 L F
.664 .971 .814 r
.46215 .43271 m .46415 .43206 L .46097 .43449 L F
.646 .965 .903 r
.46215 .43271 m .46097 .43449 L .45997 .4342 L F
.62 .941 .953 r
.53231 .48261 m .52874 .48317 L .53148 .48237 L F
.671 .974 .822 r
.53231 .48261 m .53341 .48081 L .53556 .4802 L F
.53231 .48261 m .53148 .48237 L .53341 .48081 L F
.326 0 .143 r
.51844 .43129 m .52055 .43297 L .51734 .43346 L F
.51844 .43129 m .5211 .43059 L .52055 .43297 L F
.435 0 0 r
.33247 .58767 m .33532 .58783 L .33665 .58654 L F
.485 0 0 r
.33665 .58654 m .33532 .58783 L .33929 .58764 L F
.947 .945 .623 r
.55713 .39671 m .5573 .39911 L .55621 .40072 L F
.779 .663 .735 r
.4074 .50288 m .40812 .50659 L .41053 .50267 L F
.509 .291 .519 r
.2883 .55005 m .29081 .55247 L .29046 .54893 L F
.2883 .55005 m .28813 .55366 L .29081 .55247 L F
.579 .306 .465 r
.54855 .44679 m .55227 .44414 L .54901 .44449 L F
.54855 .44679 m .55182 .44625 L .55227 .44414 L F
.341 0 .168 r
.55182 .44625 m .55536 .44388 L .55227 .44414 L F
.422 .847 .954 r
.62925 .38692 m .62862 .38745 L .62759 .38781 L F
.62925 .38692 m .63084 .38705 L .62862 .38745 L F
0 .151 .673 r
.63169 .38916 m .62862 .38745 L .63084 .38705 L F
.433 .284 .577 r
.69517 .30277 m .6974 .29906 L .69516 .30021 L F
0 0 0 r
.24017 .53543 m .24172 .53459 L .24345 .53309 L F
.794 .954 .622 r
.24345 .53309 m .24368 .53165 L .2459 .53269 L F
.24345 .53309 m .24172 .53459 L .24368 .53165 L F
.862 .893 .856 r
.36233 .56006 m .35803 .56163 L .36085 .55912 L F
.677 .914 .975 r
.36455 .55874 m .36233 .56006 L .36085 .55912 L F
.758 .42 .413 r
.27827 .59509 m .28088 .59811 L .2771 .59733 L F
.793 .497 .487 r
.38216 .57836 m .3863 .58148 L .38438 .57885 L F
.693 .982 .873 r
.61983 .40909 m .61634 .41151 L .61777 .40939 L F
0 0 .319 r
.61634 .41151 m .61767 .41237 L .61777 .40939 L F
.61634 .41151 m .61664 .41428 L .61767 .41237 L F
.818 .731 .769 r
.70939 .29223 m .71071 .2939 L .71247 .28931 L F
.618 .829 .981 r
.6232 .40072 m .62503 .40232 L .62729 .40101 L F
.169 0 .215 r
.62729 .40101 m .62503 .40232 L .62443 .40416 L F
.955 .714 .534 r
.35135 .55621 m .35117 .55906 L .34904 .55583 L F
.412 .489 .829 r
.35135 .55621 m .35155 .55119 L .35007 .55255 L F
.35135 .55621 m .35355 .55656 L .35155 .55119 L F
.194 .597 .944 r
.35189 .5551 m .35135 .55621 L .34904 .55583 L F
.35189 .5551 m .35355 .55656 L .35135 .55621 L F
.482 .293 .547 r
.35355 .55656 m .35117 .55906 L .35135 .55621 L F
.266 .333 .746 r
.59107 .37729 m .5895 .38026 L .58768 .37803 L F
.59107 .37729 m .59195 .38177 L .5895 .38026 L F
.603 .883 .991 r
.45565 .59641 m .45657 .59427 L .45348 .5959 L F
.45565 .59641 m .45802 .59533 L .45657 .59427 L F
.789 .544 .567 r
.29659 .58875 m .29219 .59101 L .29521 .5891 L F
.29659 .58875 m .29644 .59154 L .29219 .59101 L F
.862 .503 .001 r
.29521 .5891 m .29644 .59154 L .29659 .58875 L F
.995 .849 .504 r
.39694 .49497 m .39851 .4936 L .39709 .49239 L F
.39694 .49497 m .39813 .49562 L .39851 .4936 L F
.982 .811 .597 r
.39851 .4936 m .3973 .48992 L .39709 .49239 L F
.595 .762 .959 r
.32146 .62237 m .32401 .62165 L .31959 .62081 L F
.446 .165 .393 r
.32241 .6236 m .32401 .62165 L .32146 .62237 L F
.32241 .6236 m .32401 .62165 L .32146 .62237 L F
.995 .778 .494 r
.41189 .53739 m .41014 .53885 L .41232 .53959 L F
.41014 .53885 m .41009 .53912 L .41232 .53959 L F
.969 .65 .335 r
.41006 .53911 m .41129 .54172 L .41232 .53959 L F
.41129 .54172 m .41179 .54207 L .41232 .53959 L F
.41006 .53942 m .41168 .54256 L .41006 .53911 L F
.216 0 .179 r
.41232 .53959 m .41168 .54256 L .41374 .54098 L F
.951 .701 .523 r
.4097 .54101 m .41168 .54256 L .41006 .53942 L F
.419 .161 .413 r
.41005 .54084 m .4097 .54101 L .4098 .54027 L F
.41006 .53911 m .4098 .54027 L .41007 .53821 L F
.41005 .54084 m .4098 .54027 L .41006 .53911 L F
.995 .778 .494 r
.41014 .53885 m .41011 .53887 L .41009 .53912 L F
.41011 .53887 m .40988 .53907 L .41006 .53911 L F
.41011 .53887 m .41006 .53911 L .41009 .53912 L F
.951 .701 .523 r
.4097 .54101 m .40988 .53907 L .41004 .53819 L F
.4097 .54101 m .41006 .53942 L .40988 .53907 L F
.419 .161 .413 r
.41212 .53984 m .41005 .54084 L .41006 .53942 L F
.896 .522 .322 r
.41011 .53887 m .41004 .53819 L .40988 .53907 L F
.41189 .53739 m .41004 .53819 L .41011 .53887 L F
.419 .161 .413 r
.41029 .53839 m .41013 .53908 L .41007 .53821 L F
.41013 .53908 m .41006 .53942 L .41007 .53842 L F
.41013 .53908 m .41007 .53842 L .41007 .53821 L F
.41212 .53984 m .41006 .53942 L .41029 .53839 L F
.805 .743 .795 r
.41374 .54098 m .41028 .54101 L .41212 .53984 L F
.41028 .54101 m .4097 .54101 L .41005 .54084 L F
.41028 .54101 m .41005 .54084 L .41212 .53984 L F
.969 .65 .335 r
.41129 .54172 m .41168 .54256 L .41179 .54207 L F
.419 .161 .413 r
.41007 .53821 m .4097 .54101 L .41004 .53819 L F
.969 .65 .335 r
.40988 .53907 m .41006 .53942 L .41006 .53911 L F
.615 .565 .776 r
.41189 .53739 m .41232 .53959 L .4143 .5383 L F
.41189 .53739 m .4143 .5383 L .41351 .53634 L F
.419 .161 .413 r
.41212 .53984 m .41023 .53834 L .41233 .53733 L F
.41023 .53834 m .41004 .53819 L .41028 .5381 L F
.41023 .53834 m .41028 .5381 L .41233 .53733 L F
.216 0 .179 r
.41232 .53959 m .41374 .54098 L .4143 .5383 L F
.455 0 0 r
.30864 .54946 m .30378 .54852 L .30351 .54976 L F
.30864 .54946 m .30635 .54975 L .30378 .54852 L F
.573 .085 .06 r
.30977 .55014 m .30635 .54975 L .30864 .54946 L F
.039 0 0 r
.31072 .54872 m .30977 .55014 L .30864 .54946 L F
.813 .635 .661 r
.25781 .59418 m .25718 .59986 L .26115 .59573 L F
.734 .615 .726 r
.53528 .42848 m .53785 .42575 L .53532 .42633 L F
.813 .962 .639 r
.53072 .4926 m .53103 .49316 L .53193 .49178 L F
.833 .98 .879 r
.53072 .4926 m .52851 .49637 L .53103 .49316 L F
.611 .653 .867 r
.50783 .41449 m .50926 .41045 L .50713 .41385 L F
.50783 .41449 m .51088 .41378 L .50926 .41045 L F
.989 .86 .502 r
.50697 .41693 m .50783 .41449 L .50713 .41385 L F
.507 .226 .423 r
.50697 .41693 m .51088 .41378 L .50783 .41449 L F
.755 .812 .897 r
.60783 .3753 m .60746 .37788 L .61208 .37569 L F
.693 .623 .774 r
.31795 .59238 m .31802 .59509 L .32066 .59172 L F
.316 0 .17 r
.61618 .39736 m .61657 .39556 L .61328 .39772 L F
.171 0 .129 r
.61906 .39433 m .61657 .39556 L .61618 .39736 L F
.802 .813 .86 r
.48408 .4475 m .4856 .44763 L .48643 .44427 L F
.65 .657 .844 r
.48643 .44427 m .4856 .44763 L .48928 .44363 L F
.507 .815 1 r
.4856 .44763 m .4908 .44731 L .48928 .44363 L F
.793 .952 .922 r
.63199 .40736 m .63423 .40375 L .63089 .40635 L F
.63199 .40736 m .63531 .40476 L .63423 .40375 L F
.224 0 .096 r
.4008 .45742 m .40148 .45755 L .40431 .45478 L F
0 0 0 r
.40431 .45478 m .40148 .45755 L .40604 .45353 L F
.40431 .45478 m .40148 .45755 L .40604 .45353 L F
.791 .348 .194 r
.67567 .34899 m .67429 .35083 L .67436 .34783 L F
.605 .4 .577 r
.69189 .30573 m .69517 .30277 L .69191 .30351 L F
.363 0 .137 r
.42293 .57307 m .42309 .57433 L .42203 .57404 L F
.69 .204 .09 r
.42293 .57307 m .42436 .57471 L .42309 .57433 L F
.708 .175 0 r
.42645 .57537 m .42436 .57471 L .42293 .57307 L F
.613 .306 .426 r
.27402 .59803 m .27089 .60101 L .27113 .59843 L F
.27402 .59803 m .27349 .60103 L .27089 .60101 L F
.674 .517 .664 r
.2771 .59733 m .27349 .60103 L .27402 .59803 L F
.983 .909 .621 r
.40158 .56601 m .39963 .56767 L .40004 .56476 L F
.40158 .56601 m .4007 .56857 L .39963 .56767 L F
.671 .539 .695 r
.70429 .27991 m .70946 .28305 L .70647 .27827 L F
.301 .052 .359 r
.24585 .55902 m .24508 .562 L .24316 .56254 L F
.305 .2 .567 r
.24752 .55543 m .24777 .55819 L .24585 .55902 L F
.572 .412 .626 r
.24777 .55819 m .24508 .562 L .24585 .55902 L F
.924 .82 .724 r
.38361 .58757 m .3848 .59165 L .38495 .58862 L F
.891 .512 .31 r
.35064 .5145 m .35241 .513 L .35015 .51247 L F
.35064 .5145 m .35404 .51628 L .35241 .513 L F
.77 .327 .198 r
.58336 .43921 m .58386 .43697 L .58313 .43645 L F
.858 .952 .874 r
.57656 .45567 m .57779 .45639 L .58018 .45376 L F
.764 .496 .53 r
.64494 .34026 m .64838 .34413 L .64156 .34211 L F
.386 .421 .775 r
.64718 .34274 m .64942 .34523 L .64797 .34119 L F
.439 .452 .776 r
.64797 .34119 m .64838 .34413 L .64494 .34026 L F
0 0 .379 r
.29289 .54818 m .2915 .55229 L .29046 .54893 L F
.451 .866 .722 r
.29292 .55121 m .29081 .55247 L .2915 .55229 L F
.738 .361 .338 r
.42436 .55316 m .42194 .55446 L .42245 .55287 L F
.42436 .55316 m .42475 .55524 L .42194 .55446 L F
.564 .674 .913 r
.24506 .58107 m .24364 .58397 L .24296 .58158 L F
.908 .9 .806 r
.45409 .56744 m .45572 .56813 L .45316 .57203 L F
.798 .878 .905 r
.45725 .56457 m .45572 .56813 L .45409 .56744 L F
.45725 .56457 m .45918 .56521 L .45572 .56813 L F
.79 .758 .823 r
.4518 .56895 m .45316 .57203 L .44944 .572 L F
.908 .9 .806 r
.45409 .56744 m .45316 .57203 L .4518 .56895 L F
0 0 0 r
.4248 .44965 m .4233 .45004 L .42221 .45035 L F
.4248 .44965 m .4259 .44932 L .4233 .45004 L F
.437 .77 .997 r
.45336 .55603 m .45406 .55423 L .45155 .55477 L F
.45336 .55603 m .45587 .55578 L .45406 .55423 L F
.45336 .55603 m .45406 .55423 L .45155 .55477 L F
.45336 .55603 m .45587 .55578 L .45406 .55423 L F
0 0 0 r
.25971 .62431 m .25623 .62703 L .25725 .62723 L F
0 0 .046 r
.25725 .62723 m .25623 .62703 L .25496 .63033 L F
.821 1 .811 r
.52494 .49884 m .52851 .49637 L .52757 .49549 L F
.833 .98 .879 r
.53072 .4926 m .52757 .49549 L .52851 .49637 L F
0 0 .08 r
.48467 .5624 m .48449 .56449 L .4826 .56567 L F
0 0 0 r
.4826 .56567 m .48449 .56449 L .48163 .56768 L F
.928 .556 .151 r
.58246 .43243 m .58327 .4313 L .58202 .42996 L F
.58246 .43243 m .58409 .43415 L .58327 .4313 L F
.3 0 0 r
.26573 .51932 m .26532 .52075 L .26729 .51951 L F
.26573 .51932 m .26263 .5213 L .26532 .52075 L F
.8 .32 .072 r
.34208 .50599 m .34616 .50923 L .34431 .50625 L F
.726 .361 0 r
.32818 .50402 m .32883 .50575 L .32712 .50197 L F
.971 .661 .288 r
.33928 .49924 m .3396 .50248 L .3409 .50305 L F
.888 .475 .059 r
.34047 .50461 m .3409 .50305 L .3396 .50248 L F
.34047 .50461 m .34208 .50599 L .3409 .50305 L F
.522 0 0 r
.31561 .63681 m .3133 .63542 L .31069 .63616 L F
.998 .809 .52 r
.25357 .56251 m .25165 .56459 L .25303 .56522 L F
.192 0 .232 r
.27982 .58906 m .27902 .5913 L .28176 .58823 L F
.906 .906 .501 r
.4009 .50695 m .40039 .50989 L .40159 .50672 L F
.619 .431 .606 r
.40039 .50989 m .40171 .51008 L .40159 .50672 L F
.948 .957 .708 r
.40259 .50219 m .40091 .50558 L .40159 .50672 L F
.961 .772 .328 r
.40091 .50558 m .4009 .50695 L .40159 .50672 L F
.717 .356 0 r
.42453 .54143 m .42623 .54519 L .42471 .54149 L F
.397 .411 .757 r
.32876 .53311 m .32948 .53625 L .33106 .53421 L F
.913 .976 .782 r
.55812 .47365 m .55961 .46932 L .55707 .47274 L F
.55812 .47365 m .5605 .47017 L .55961 .46932 L F
.7 .19 .018 r
.33244 .5994 m .33262 .6013 L .33115 .60036 L F
.831 .362 0 r
.33378 .6011 m .33262 .6013 L .33244 .5994 L F
.699 .558 .692 r
.70065 .28269 m .70493 .28398 L .70429 .27991 L F
.671 .539 .695 r
.70429 .27991 m .70493 .28398 L .70946 .28305 L F
.869 .984 .839 r
.55961 .46932 m .5605 .47017 L .56339 .46685 L F
.57 .893 .631 r
.46727 .59437 m .47095 .59137 L .46864 .59076 L F
.784 .927 .93 r
.47403 .58879 m .46864 .59076 L .47095 .59137 L F
.375 0 .032 r
.34199 .58467 m .34599 .58244 L .34263 .58207 L F
.34199 .58467 m .34468 .58441 L .34599 .58244 L F
.544 .089 .123 r
.34599 .58244 m .34822 .5842 L .34798 .58133 L F
.34599 .58244 m .34468 .58441 L .34822 .5842 L F
.594 .949 .888 r
.53193 .49178 m .53226 .49066 L .53072 .4926 L F
.53193 .49178 m .53446 .49041 L .53226 .49066 L F
.543 .883 .987 r
.62066 .41489 m .62239 .41312 L .61963 .4146 L F
.62066 .41489 m .62326 .41411 L .62239 .41312 L F
.616 .573 .783 r
.35525 .56277 m .35243 .56354 L .35117 .55906 L F
0 0 0 r
.2359 .54956 m .23549 .55118 L .23769 .54783 L F
.868 .675 .639 r
.59883 .41399 m .60085 .41488 L .59912 .41129 L F
.705 .677 .821 r
.59646 .41721 m .60047 .41781 L .60085 .41488 L F
.793 .549 .568 r
.60047 .41781 m .60267 .41749 L .60085 .41488 L F
0 0 .069 r
.57801 .39655 m .57787 .39544 L .57815 .39397 L F
.57801 .39655 m .578 .3979 L .57787 .39544 L F
.938 .707 .562 r
.36482 .53788 m .3671 .53622 L .36514 .53553 L F
.36482 .53788 m .36693 .53901 L .3671 .53622 L F
.852 .738 .736 r
.3029 .60813 m .30072 .61119 L .30303 .60993 L F
.871 .894 .847 r
.30303 .60993 m .30072 .61119 L .29895 .61014 L F
.30303 .60993 m .30072 .61119 L .29895 .61014 L F
.776 .951 .931 r
.50173 .44485 m .50456 .44512 L .50635 .44328 L F
.91 .975 .789 r
.41616 .47305 m .41575 .47322 L .41769 .47336 L F
.279 .765 .678 r
.64219 .33332 m .64624 .33176 L .64376 .33294 L F
.292 .746 .956 r
.28221 .60137 m .28471 .60121 L .28006 .60051 L F
.22 0 0 r
.42681 .60052 m .42847 .59957 L .43082 .59986 L F
.417 .858 .768 r
.49685 .44655 m .49704 .44676 L .50037 .44506 L F
.948 .634 .201 r
.43301 .58906 m .43376 .592 L .43222 .58799 L F
.232 .17 .578 r
.23326 .55284 m .23572 .55374 L .23549 .55118 L F
.23326 .55284 m .23369 .55557 L .23572 .55374 L F
.852 .456 .293 r
.34675 .51091 m .34875 .50953 L .34616 .50923 L F
.34675 .51091 m .35015 .51247 L .34875 .50953 L F
.967 .693 .46 r
.39918 .55537 m .39733 .55148 L .39915 .55255 L F
.828 .974 .889 r
.59475 .37545 m .59371 .37455 L .59453 .37369 L F
.418 0 0 r
.59666 .37304 m .59738 .37244 L .59455 .37241 L F
.397 .283 .606 r
.59455 .37241 m .59475 .37545 L .5975 .37329 L F
.828 .974 .889 r
.59548 .3734 m .59453 .37369 L .59589 .37226 L F
.59475 .37545 m .59453 .37369 L .59548 .3734 L F
.418 0 0 r
.5975 .37329 m .59743 .3728 L .59666 .37304 L F
.59743 .3728 m .59738 .37244 L .59666 .37304 L F
.065 0 .04 r
.65359 .39485 m .65662 .39191 L .6563 .39389 L F
.768 .686 .772 r
.64942 .34523 m .64686 .34892 L .64659 .346 L F
.64942 .34523 m .65067 .34922 L .64686 .34892 L F
.458 .307 .587 r
.64958 .34798 m .64659 .346 L .64942 .34523 L F
.64958 .34798 m .64686 .34892 L .64659 .346 L F
.936 .599 .368 r
.42005 .5282 m .42296 .5327 L .42271 .52964 L F
.6 .605 .829 r
.31605 .64776 m .32024 .65076 L .31845 .64739 L F
.629 .698 .895 r
.32024 .65076 m .32113 .64697 L .31845 .64739 L F
.32024 .65076 m .32273 .64997 L .32113 .64697 L F
.824 .491 .426 r
.3381 .54541 m .33727 .54811 L .33741 .54539 L F
.3381 .54541 m .34133 .54911 L .33727 .54811 L F
.878 .97 .845 r
.35085 .64047 m .35498 .63782 L .35254 .63899 L F
.854 .997 .773 r
.35254 .63899 m .35498 .63782 L .35478 .63649 L F
.119 0 .06 r
.51982 .48393 m .51653 .48683 L .51858 .48567 L F
.579 .816 .431 r
.5223 .48057 m .52075 .48266 L .52113 .48212 L F
0 0 0 r
.52469 .47937 m .5223 .48057 L .52113 .48212 L F
.52469 .47937 m .52113 .48212 L .5239 .4794 L F
.52113 .48212 m .52144 .4821 L .52162 .4814 L F
.773 .996 .8 r
.5239 .4794 m .52326 .48002 L .52197 .47995 L F
.52326 .48002 m .52113 .48212 L .52197 .47995 L F
0 0 0 r
.52113 .48212 m .52162 .4814 L .52197 .47995 L F
.074 .166 .656 r
.52144 .4821 m .52122 .47991 L .52197 .47995 L F
.52122 .47991 m .52103 .47807 L .52197 .47995 L F
.579 .816 .431 r
.52075 .48266 m .51982 .48393 L .52113 .48212 L F
0 0 0 r
.51858 .48567 m .52113 .48212 L .51982 .48393 L F
.613 .688 .896 r
.30282 .66656 m .2986 .66405 L .30125 .66334 L F
.565 .593 .84 r
.30396 .66253 m .30282 .66656 L .30125 .66334 L F
.551 .767 .978 r
.70883 .28699 m .71203 .28619 L .7105 .28473 L F
.719 .7 .832 r
.70925 .28978 m .71203 .28619 L .70883 .28699 L F
0 0 0 r
.25576 .54282 m .25443 .54491 L .25285 .54592 L F
0 0 .233 r
.25772 .5382 m .25719 .54152 L .25576 .54282 L F
0 0 0 r
.25624 .54373 m .25576 .54282 L .25719 .54152 L F
.25624 .54373 m .25443 .54491 L .25576 .54282 L F
.46243 .5529 m .45964 .55437 L .45851 .55195 L F
.46243 .5529 m .46103 .55406 L .45964 .55437 L F
.926 .545 .25 r
.46243 .5529 m .46298 .55527 L .46103 .55406 L F
.599 .09 .013 r
.31609 .57754 m .32029 .57791 L .31831 .5792 L F
.558 .025 0 r
.31907 .57841 m .32029 .57791 L .31609 .57754 L F
0 0 0 r
.32144 .57427 m .32051 .57575 L .31907 .57841 L F
.323 .779 .633 r
.65808 .38982 m .65953 .38909 L .662 .38783 L F
.11 .14 .611 r
.48512 .55865 m .48689 .56105 L .48467 .5624 L F
0 0 .091 r
.48689 .56105 m .48449 .56449 L .48467 .5624 L F
.044 0 .344 r
.24439 .56416 m .24316 .56254 L .24508 .562 L F
.24439 .56416 m .24284 .56555 L .24316 .56254 L F
.682 .967 .931 r
.4903 .41442 m .48799 .41589 L .48566 .41596 L F
.943 .85 .721 r
.69962 .33008 m .70115 .33166 L .70035 .32855 L F
.925 .859 .756 r
.69892 .3359 m .70115 .33166 L .69962 .33008 L F
.853 .815 .812 r
.70035 .32855 m .70115 .33166 L .70305 .32874 L F
.35 .093 .377 r
.25443 .54491 m .25172 .54805 L .25285 .54592 L F
0 0 .488 r
.57593 .38726 m .57841 .39131 L .57751 .38848 L F
.675 .837 .961 r
.41793 .54473 m .41726 .54644 L .41527 .54484 L F
.28 .781 .774 r
.61328 .39772 m .60959 .39866 L .61345 .40026 L F
.262 0 .018 r
.61501 .39967 m .61328 .39772 L .61345 .40026 L F
.61501 .39967 m .61618 .39736 L .61328 .39772 L F
0 0 0 r
.43327 .44721 m .43278 .44708 L .43096 .44818 L F
.43327 .44721 m .43526 .44609 L .43278 .44708 L F
.645 .532 .711 r
.54287 .44751 m .54629 .44827 L .54476 .44646 L F
.54287 .44751 m .5434 .45116 L .54629 .44827 L F
.686 .912 .973 r
.464 .44801 m .46634 .4468 L .46495 .44575 L F
.725 .951 .95 r
.46279 .4473 m .464 .44801 L .46495 .44575 L F
.742 .235 .012 r
.37018 .50715 m .36885 .50808 L .36672 .50574 L F
.839 .38 .111 r
.37018 .50715 m .37112 .50908 L .36885 .50808 L F
.703 .588 .724 r
.301 .58075 m .30464 .57913 L .30118 .57916 L F
.564 .838 .997 r
.29308 .63773 m .2884 .637 L .29096 .63662 L F
.851 .934 .88 r
.29535 .63468 m .29308 .63773 L .29096 .63662 L F
.504 .422 .696 r
.2915 .63909 m .29333 .63627 L .29096 .63662 L F
.29333 .63627 m .29348 .63603 L .29096 .63662 L F
.564 .838 .997 r
.2884 .637 m .28819 .63697 L .29096 .63662 L F
.834 .659 .665 r
.71203 .28619 m .71565 .28692 L .71361 .28359 L F
.797 .754 .813 r
.71203 .28619 m .71247 .28931 L .71565 .28692 L F
.622 .448 .625 r
.30033 .67039 m .30087 .67381 L .29771 .67399 L F
.626 .341 .465 r
.30033 .67039 m .30336 .67319 L .30087 .67381 L F
.30033 .67039 m .30417 .6699 L .30336 .67319 L F
.707 .973 .924 r
.52337 .50309 m .52257 .5025 L .51868 .50508 L F
.914 .981 .751 r
.52494 .49884 m .52257 .5025 L .52337 .50309 L F
.115 .049 .498 r
.35769 .56874 m .35909 .56791 L .35865 .56755 L F
.35769 .56874 m .35759 .57123 L .35909 .56791 L F
.327 .415 .799 r
.34819 .57745 m .35164 .57585 L .3489 .57496 L F
.032 0 .412 r
.34806 .57851 m .34984 .57966 L .34998 .57721 L F
.943 .611 .184 r
.34984 .57966 m .34901 .57805 L .34998 .57721 L F
.327 .415 .799 r
.34819 .57745 m .34998 .57721 L .35146 .57594 L F
.34819 .57745 m .34806 .57851 L .34998 .57721 L F
.34819 .57745 m .3489 .57496 L .34949 .57413 L F
.769 .741 .827 r
.34792 .57606 m .34819 .57745 L .34949 .57413 L F
.622 .516 .712 r
.34595 .57106 m .34792 .57606 L .34949 .57413 L F
.943 .611 .184 r
.34901 .57805 m .34776 .57559 L .34998 .57721 L F
.327 .415 .799 r
.35146 .57594 m .34998 .57721 L .35164 .57585 L F
.02 0 0 r
.35165 .57659 m .35164 .57585 L .34998 .57721 L F
.328 .128 .45 r
.34998 .57721 m .34984 .57966 L .35207 .57644 L F
.814 .941 .582 r
.35165 .57575 m .35063 .57793 L .34998 .57721 L F
.35063 .57793 m .34984 .57966 L .34987 .57915 L F
.35063 .57793 m .34987 .57915 L .34998 .57721 L F
.02 0 0 r
.35207 .57644 m .35198 .57631 L .35165 .57659 L F
.35198 .57631 m .35164 .57585 L .35165 .57659 L F
.35207 .57644 m .35448 .5753 L .35368 .57546 L F
.35207 .57644 m .35368 .57546 L .35164 .57585 L F
.718 .602 .726 r
.35113 .57715 m .35129 .57691 L .35207 .57644 L F
.763 .663 .752 r
.35458 .57287 m .35207 .57644 L .35055 .57265 L F
0 .147 .681 r
.35055 .57265 m .35207 .57644 L .35276 .57478 L F
.718 .602 .726 r
.35129 .57691 m .35276 .57478 L .35207 .57644 L F
.814 .941 .582 r
.35165 .57575 m .35004 .57801 L .35098 .57718 L F
.718 .602 .726 r
.35004 .57798 m .35222 .57542 L .35113 .57715 L F
.35222 .57542 m .35276 .57478 L .35113 .57715 L F
.814 .941 .582 r
.35165 .57575 m .35004 .57798 L .35004 .57801 L F
.35098 .57718 m .35004 .57801 L .34984 .57966 L F
.187 .689 .911 r
.33562 .53876 m .34018 .53935 L .33689 .53885 L F
.974 .746 .531 r
.27137 .61487 m .27118 .61758 L .26917 .61693 L F
.441 .267 .548 r
.27362 .61707 m .27115 .61796 L .27137 .61487 L F
.632 .082 0 r
.27185 .61618 m .27137 .61487 L .26917 .61693 L F
.734 .749 .864 r
.26779 .61392 m .26917 .61693 L .26706 .61449 L F
.957 .699 .502 r
.26706 .61449 m .26917 .61693 L .26721 .61639 L F
.575 .648 .885 r
.27006 .61356 m .26917 .61693 L .26779 .61392 L F
.27006 .61356 m .27185 .61618 L .26917 .61693 L F
.393 .844 .916 r
.26917 .61693 m .27064 .61588 L .26739 .61636 L F
.26917 .61693 m .26739 .61636 L .26721 .61639 L F
.974 .746 .531 r
.27118 .61758 m .27115 .61796 L .26917 .61693 L F
.632 .082 0 r
.27185 .61618 m .27313 .6166 L .27137 .61487 L F
.253 .477 .881 r
.27231 .61407 m .27185 .61618 L .27006 .61356 L F
.812 .995 .863 r
.2707 .61581 m .27185 .61618 L .27231 .61407 L F
.27064 .61588 m .27185 .61618 L .2707 .61581 L F
.632 .082 0 r
.27185 .61618 m .27362 .61707 L .27313 .6166 L F
.741 .773 .274 r
.34595 .57106 m .34463 .57565 L .34792 .57606 L F
.434 .506 .834 r
.34463 .57565 m .34819 .57745 L .34792 .57606 L F
.929 .779 .306 r
.67728 .33887 m .67701 .34243 L .67648 .33978 L F
.754 .803 .892 r
.38279 .45868 m .38426 .45987 L .38069 .46034 L F
.469 0 0 r
.38426 .45987 m .38344 .46068 L .38069 .46034 L F
.651 .292 .35 r
.38279 .45868 m .3865 .45942 L .38426 .45987 L F
.181 0 0 r
.3865 .45942 m .38524 .45994 L .38426 .45987 L F
.3865 .45942 m .38532 .46025 L .38344 .46068 L F
.38532 .46025 m .38472 .46066 L .38401 .46067 L F
.38532 .46025 m .38401 .46067 L .38344 .46068 L F
.376 .057 .291 r
.38638 .46024 m .38893 .45928 L .3865 .45942 L F
.641 .784 .95 r
.38616 .45998 m .38893 .45928 L .38638 .46024 L F
.651 .292 .35 r
.38279 .45868 m .38573 .45996 L .3865 .45942 L F
.38573 .45996 m .38638 .46024 L .3865 .45942 L F
.181 0 0 r
.38573 .45996 m .38579 .46065 L .38472 .46066 L F
.3865 .45942 m .38618 .45998 L .38573 .45996 L F
.154 .51 .913 r
.38616 .45998 m .38638 .46024 L .38573 .45996 L F
.181 0 0 r
.38618 .45998 m .38579 .46065 L .38573 .45996 L F
.154 .51 .913 r
.3861 .45991 m .38616 .45998 L .38565 .45993 L F
.38616 .45998 m .38573 .45996 L .38565 .45993 L F
.641 .784 .95 r
.38619 .45997 m .38893 .45928 L .38616 .45998 L F
.56 .199 .313 r
.38893 .45928 m .38619 .45997 L .3865 .45942 L F
.641 .784 .95 r
.38864 .45917 m .38893 .45928 L .38619 .45997 L F
.56 .199 .313 r
.38893 .45928 m .38579 .46065 L .38619 .45997 L F
.641 .784 .95 r
.38418 .45761 m .38809 .45898 L .38616 .45998 L F
.38809 .45898 m .38864 .45917 L .38798 .45939 L F
.38809 .45898 m .38798 .45939 L .38616 .45998 L F
.56 .199 .313 r
.38893 .45928 m .38821 .46111 L .38579 .46065 L F
.642 .106 0 r
.38418 .45761 m .38821 .46111 L .38893 .45928 L F
0 0 .212 r
.38821 .46111 m .3884 .4574 L .38893 .45928 L F
.38821 .46111 m .38903 .45895 L .38846 .45755 L F
.38838 .45787 m .38846 .45755 L .3884 .4574 L F
.38821 .46111 m .38846 .45755 L .38838 .45787 L F
.154 .51 .913 r
.38418 .45761 m .3861 .45991 L .38279 .45868 L F
.3861 .45991 m .38565 .45993 L .38279 .45868 L F
.181 0 0 r
.38524 .45994 m .38344 .46068 L .38415 .45998 L F
.38524 .45994 m .38415 .45998 L .38426 .45987 L F
.621 .137 .082 r
.32631 .52024 m .32731 .5213 L .32609 .52027 L F
.32929 .51977 m .32731 .5213 L .32631 .52024 L F
.32929 .51977 m .32609 .52027 L .32681 .51958 L F
.996 .824 .556 r
.32794 .51861 m .32742 .52084 L .32929 .51977 L F
.32742 .52084 m .32731 .5213 L .32753 .52113 L F
.32742 .52084 m .32753 .52113 L .32929 .51977 L F
.908 .923 .814 r
.33037 .51533 m .32794 .51861 L .32929 .51977 L F
.452 .279 .556 r
.32526 .51679 m .32794 .51861 L .32822 .51492 L F
.32526 .51679 m .32512 .51945 L .32794 .51861 L F
.438 .216 .479 r
.32822 .51492 m .32794 .51861 L .33037 .51533 L F
.022 .206 .714 r
.32512 .51945 m .32641 .51971 L .32794 .51861 L F
0 0 .085 r
.32843 .51968 m .32731 .5213 L .32794 .51861 L F
.32843 .51968 m .32794 .51861 L .32641 .51971 L F
.822 .985 .88 r
.32698 .5197 m .32679 .51579 L .32843 .51968 L F
.32641 .51971 m .32652 .51853 L .32698 .5197 L F
.32652 .51853 m .32679 .51579 L .32698 .5197 L F
.418 .244 .536 r
.32919 .52329 m .32731 .5213 L .32843 .51968 L F
.32947 .52457 m .32731 .5213 L .32919 .52329 L F
.621 .137 .082 r
.32681 .51958 m .32609 .52027 L .32512 .51945 L F
.022 .206 .714 r
.32512 .51945 m .32731 .5213 L .32641 .51971 L F
.672 .904 .566 r
.32641 .51971 m .32463 .52167 L .32433 .52147 L F
.32463 .52167 m .32309 .52337 L .32348 .52277 L F
.32463 .52167 m .32348 .52277 L .32433 .52147 L F
.748 .347 0 r
.56839 .37788 m .56994 .38148 L .57048 .38164 L F
.749 .286 0 r
.57046 .38266 m .57048 .38164 L .56994 .38148 L F
.546 .83 .998 r
.64958 .34798 m .65067 .34922 L .64686 .34892 L F
.972 .693 .283 r
.64958 .34798 m .65067 .34922 L .64942 .34523 L F
.764 .938 .94 r
.60662 .44729 m .60969 .44681 L .60901 .44602 L F
.888 .991 .765 r
.60863 .44833 m .60901 .44602 L .60662 .44729 L F
.60863 .44833 m .60969 .44681 L .60901 .44602 L F
0 .311 .784 r
.57467 .38571 m .57322 .38568 L .57185 .38403 L F
.57467 .38571 m .57593 .38726 L .57322 .38568 L F
.509 .306 .541 r
.58123 .35873 m .58127 .36204 L .57833 .36226 L F
.81 .987 .725 r
.58074 .35822 m .57955 .35906 L .57979 .35721 L F
.58123 .35873 m .57955 .35906 L .58074 .35822 L F
.825 .936 .902 r
.57955 .35906 m .57692 .36264 L .57572 .36127 L F
.57955 .35906 m .57572 .36127 L .57825 .36001 L F
.467 .836 .589 r
.57955 .35906 m .57825 .36001 L .57876 .35961 L F
.81 .987 .725 r
.58123 .35873 m .58074 .35933 L .58072 .35883 L F
.18 .057 .465 r
.58236 .36056 m .58127 .36204 L .58123 .35873 L F
0 .151 .691 r
.57979 .35721 m .58171 .3597 L .58123 .35873 L F
.58171 .3597 m .58236 .36056 L .58143 .35905 L F
.58171 .3597 m .58143 .35905 L .58123 .35873 L F
.58071 .3584 m .58216 .35943 L .58236 .36056 L F
.597 .573 .797 r
.58216 .35943 m .58127 .36204 L .58236 .36056 L F
.58191 .36017 m .58119 .36495 L .58127 .36204 L F
.58216 .35943 m .582 .36038 L .58191 .36017 L F
.582 .36038 m .58119 .36495 L .58191 .36017 L F
0 .151 .691 r
.57979 .35721 m .5807 .35806 L .58071 .3584 L F
.5807 .35806 m .58216 .35943 L .58071 .3584 L F
.81 .987 .725 r
.58072 .35883 m .57833 .36226 L .57955 .35906 L F
.58074 .35933 m .57833 .36226 L .58072 .35883 L F
.631 .261 .323 r
.57955 .35906 m .58216 .35943 L .57979 .35721 L F
.467 .836 .589 r
.57955 .35906 m .57876 .35961 L .58088 .35794 L F
.81 .998 .785 r
.57833 .36226 m .57692 .36264 L .57955 .35906 L F
.501 .282 .512 r
.58127 .36204 m .57826 .36533 L .57833 .36226 L F
.991 .757 .48 r
.3168 .62691 m .3183 .62773 L .31808 .63055 L F
.717 .93 .961 r
.32034 .6263 m .3183 .62773 L .3168 .62691 L F
.871 .755 .732 r
.71037 .28216 m .71459 .28023 L .71233 .27911 L F
.988 .886 .627 r
.58132 .45115 m .58151 .44636 L .57988 .45005 L F
.95 .88 .731 r
.57988 .45005 m .58018 .45376 L .58132 .45115 L F
.827 .848 .388 r
.3062 .64064 m .30516 .64469 L .30753 .64424 L F
.914 .513 .152 r
.39813 .49562 m .39917 .49914 L .4008 .49989 L F
.714 .288 .234 r
.39842 .50165 m .4008 .49989 L .39917 .49914 L F
.39842 .50165 m .40259 .50219 L .4008 .49989 L F
.437 .63 .936 r
.59198 .44251 m .59285 .44431 L .59488 .44338 L F
.449 .681 .964 r
.59488 .44338 m .59285 .44431 L .59593 .44411 L F
.608 .176 .195 r
.34149 .57289 m .33711 .57296 L .33785 .57204 L F
.33982 .57154 m .33785 .57204 L .33886 .57077 L F
.34149 .57289 m .33785 .57204 L .33982 .57154 L F
.603 .942 .939 r
.34198 .57101 m .34067 .57234 L .34311 .57131 L F
.34169 .57093 m .34156 .57111 L .34198 .57101 L F
.34156 .57111 m .34067 .57234 L .34198 .57101 L F
.973 .79 .595 r
.3397 .56851 m .34067 .57234 L .33886 .57077 L F
.437 .74 .991 r
.33886 .57077 m .34067 .57234 L .34169 .57093 L F
.755 .243 0 r
.64083 .38393 m .6431 .3858 L .64186 .38441 L F
.563 .254 .403 r
.34406 .54278 m .34665 .54486 L .344 .54475 L F
.94 .839 .399 r
.57408 .36878 m .57424 .36409 L .57564 .36605 L F
.57408 .36878 m .57344 .36737 L .57424 .36409 L F
0 0 .15 r
.57408 .36878 m .57447 .36934 L .57344 .36737 L F
.57408 .36878 m .57431 .37141 L .57447 .36934 L F
.526 .895 .969 r
.32403 .54306 m .32165 .54297 L .32045 .5435 L F
.455 0 0 r
.32666 .54226 m .32165 .54297 L .32403 .54306 L F
.544 .918 .765 r
.509 .43656 m .51221 .43458 L .51028 .43528 L F
.278 .073 .412 r
.23196 .55914 m .2316 .56157 L .23388 .55829 L F
.884 .649 .577 r
.67969 .3291 m .68169 .3329 L .67943 .33177 L F
.849 .707 .706 r
.68169 .3329 m .67745 .33483 L .67943 .33177 L F
.68169 .3329 m .68066 .3348 L .67745 .33483 L F
.845 .956 .884 r
.59537 .43039 m .59694 .4315 L .59361 .43428 L F
.986 .737 .468 r
.54026 .41158 m .54166 .41259 L .54071 .40843 L F
.558 .498 .743 r
.54071 .40843 m .54166 .41259 L .54379 .41023 L F
.789 .902 .921 r
.54379 .41023 m .54166 .41259 L .54026 .41158 L F
.592 .479 .694 r
.54379 .41023 m .54137 .41417 L .54166 .41259 L F
.684 .271 .256 r
.24309 .59844 m .23821 .60001 L .23882 .59747 L F
.24309 .59844 m .24237 .60048 L .23821 .60001 L F
0 0 .063 r
.24375 .59593 m .24309 .59844 L .24342 .59517 L F
0 0 0 r
.24351 .59997 m .24309 .59844 L .24375 .59593 L F
.24351 .59997 m .24237 .60048 L .24309 .59844 L F
.969 .685 .437 r
.50727 .42022 m .50923 .42134 L .50697 .41693 L F
.134 .33 .794 r
.50697 .41693 m .50923 .42134 L .51007 .41916 L F
.593 .855 .993 r
.51007 .41916 m .50923 .42134 L .50727 .42022 L F
.804 .9 .91 r
.30096 .63986 m .30217 .63729 L .29975 .63977 L F
.245 .292 .713 r
.63226 .38813 m .63169 .38916 L .63084 .38705 L F
.629 .08 0 r
.62925 .38692 m .63226 .38813 L .63084 .38705 L F
.566 .922 .952 r
.7204 .32381 m .72065 .32244 L .71852 .32269 L F
.7204 .32381 m .72322 .32255 L .72065 .32244 L F
.397 .804 .59 r
.30683 .66985 m .31028 .66754 L .3094 .6701 L F
.692 .16 0 r
.3078 .66605 m .30861 .66649 L .30396 .66253 L F
.559 .835 .997 r
.31242 .66657 m .31028 .66754 L .3078 .66605 L F
.269 .017 .334 r
.3094 .6701 m .31028 .66754 L .31242 .66657 L F
0 0 0 r
.5236 .40246 m .5241 .40008 L .52343 .39998 L F
.785 .714 .785 r
.43887 .58515 m .44274 .58261 L .44283 .58265 L F
.579 .877 .993 r
.44274 .58261 m .4444 .58143 L .44283 .58265 L F
.406 .184 .461 r
.51518 .41484 m .51531 .4118 L .51282 .41312 L F
.893 .703 .191 r
.51482 .41233 m .51531 .4118 L .51518 .41484 L F
.439 0 0 r
.51304 .41063 m .51531 .4118 L .51582 .41122 L F
.371 .125 .405 r
.51282 .41312 m .51531 .4118 L .51304 .41063 L F
.893 .703 .191 r
.51451 .41013 m .51531 .4118 L .51482 .41233 L F
.439 0 0 r
.51582 .41122 m .51531 .4118 L .51725 .41153 L F
.321 .807 .787 r
.51725 .41153 m .5189 .41063 L .52011 .41133 L F
.51725 .41153 m .51531 .4118 L .5189 .41063 L F
.328 .743 .978 r
.60849 .36449 m .60976 .36557 L .60737 .36557 L F
.60737 .36557 m .60976 .36557 L .60849 .36449 L F
0 .523 .825 r
.32667 .65122 m .33107 .65253 L .32932 .65041 L F
.764 .777 .863 r
.33107 .65253 m .3336 .65076 L .32932 .65041 L F
.544 .918 .765 r
.509 .43656 m .51028 .43528 L .50853 .43703 L F
.998 .844 .521 r
.5703 .41566 m .57215 .41373 L .57126 .41322 L F
.5703 .41566 m .57141 .41679 L .57215 .41373 L F
.939 .956 .648 r
.57142 .41228 m .57215 .41373 L .57467 .41093 L F
.57142 .41228 m .57126 .41322 L .57215 .41373 L F
.309 0 .102 r
.65021 .39758 m .65359 .39485 L .65332 .39675 L F
.08 0 .079 r
.65332 .39675 m .65359 .39485 L .6563 .39389 L F
.204 0 0 r
.59893 .43423 m .60117 .43383 L .60389 .43419 L F
.783 .376 .28 r
.37448 .49336 m .37036 .49089 L .37296 .49196 L F
.48 0 0 r
.37296 .49196 m .37036 .49089 L .36913 .4923 L F
.399 .399 .744 r
.53656 .39246 m .53815 .39501 L .53969 .39379 L F
.53969 .39379 m .53815 .39501 L .53656 .39246 L F
.439 .812 .993 r
.54823 .43084 m .55236 .43116 L .55131 .43022 L F
.54823 .43084 m .55236 .43116 L .55131 .43022 L F
.957 .948 .667 r
.55628 .45839 m .55809 .4574 L .55713 .45895 L F
.231 .63 .957 r
.41304 .59835 m .41468 .59968 L .41784 .6 L F
0 0 .249 r
.51653 .48683 m .51787 .48776 L .51858 .48567 L F
.51653 .48683 m .51621 .48937 L .51787 .48776 L F
.47 .068 .194 r
.26921 .59852 m .27228 .59788 L .27113 .59843 L F
.946 .668 .48 r
.27113 .59843 m .27089 .60101 L .26921 .59852 L F
.869 .984 .839 r
.55961 .46932 m .56339 .46685 L .56262 .4663 L F
.933 .954 .771 r
.56753 .46194 m .56826 .46273 L .57062 .45925 L F
.741 .989 .889 r
.56262 .4663 m .56339 .46685 L .56862 .46272 L F
.933 .954 .771 r
.56826 .46273 m .5685 .46299 L .56866 .46271 L F
.56826 .46273 m .56866 .46271 L .57062 .45925 L F
.741 .989 .889 r
.56861 .46272 m .56862 .46272 L .56863 .46271 L F
.56262 .4663 m .56862 .46272 L .56861 .46272 L F
.716 .763 .889 r
.31195 .64726 m .31605 .64776 L .31464 .64638 L F
.485 .685 .955 r
.31464 .64638 m .31605 .64776 L .31845 .64739 L F
.811 .935 .567 r
.49994 .52825 m .4981 .53176 L .49939 .53003 L F
.684 .332 0 r
.28651 .58943 m .28728 .59105 L .28614 .58824 L F
.895 .567 .42 r
.35953 .5256 m .35971 .528 L .36172 .52635 L F
.972 .747 .54 r
.35971 .528 m .36151 .52916 L .36172 .52635 L F
.921 .697 .581 r
.36151 .52916 m .36192 .52785 L .36172 .52635 L F
.951 .951 .658 r
.5017 .52657 m .49972 .5277 L .49994 .52825 L F
.944 .957 .664 r
.50121 .52416 m .5017 .52657 L .50244 .52472 L F
.50121 .52416 m .49972 .5277 L .5017 .52657 L F
0 0 0 r
.66651 .32905 m .6626 .33081 L .66333 .33173 L F
.896 .488 .22 r
.4212 .57679 m .42338 .5779 L .42203 .57404 L F
.988 .865 .506 r
.42444 .57881 m .42363 .57771 L .42377 .57761 L F
.969 .823 .404 r
.42331 .58103 m .42444 .57881 L .42406 .57838 L F
0 0 .058 r
.42444 .57881 m .42475 .57947 L .42363 .57771 L F
.969 .823 .404 r
.42406 .57838 m .42444 .57881 L .42409 .57826 L F
.896 .488 .22 r
.42338 .5779 m .42377 .57761 L .42203 .57404 L F
0 0 .058 r
.42363 .57771 m .42398 .57828 L .4232 .57713 L F
.42398 .57828 m .42491 .57983 L .42382 .5781 L F
.896 .488 .22 r
.42338 .5779 m .42393 .57818 L .42363 .57771 L F
0 0 .058 r
.42398 .57828 m .42382 .5781 L .4232 .57713 L F
.42444 .57881 m .42396 .58151 L .42491 .57983 L F
.42475 .57947 m .42491 .57983 L .42363 .57771 L F
.896 .488 .22 r
.42363 .57771 m .42409 .57826 L .42377 .57761 L F
.42393 .57818 m .42409 .57826 L .42363 .57771 L F
.988 .865 .506 r
.42377 .57761 m .4232 .57713 L .42334 .57683 L F
.42363 .57771 m .4232 .57713 L .42377 .57761 L F
.669 .287 0 r
.42203 .57404 m .42377 .57761 L .42444 .57881 L F
.988 .865 .506 r
.42444 .57881 m .42334 .57683 L .42436 .57471 L F
.669 .287 0 r
.42377 .57761 m .42409 .57826 L .42444 .57881 L F
.969 .823 .404 r
.42331 .58103 m .42396 .58151 L .42444 .57881 L F
.988 .865 .506 r
.42444 .57881 m .42436 .57471 L .42645 .57537 L F
.755 .995 .856 r
.50243 .40545 m .50353 .40318 L .50486 .40415 L F
.50243 .40545 m .50038 .40579 L .50353 .40318 L F
.789 .82 .877 r
.57552 .40844 m .57674 .40406 L .57424 .40729 L F
.948 .804 .667 r
.57319 .40927 m .57552 .40844 L .57424 .40729 L F
.57319 .40927 m .57467 .41093 L .57552 .40844 L F
.856 .959 .874 r
.6198 .36592 m .61687 .36892 L .61721 .36711 L F
.01 0 .463 r
.61687 .36892 m .619 .36928 L .61721 .36711 L F
.61687 .36892 m .61731 .37154 L .619 .36928 L F
0 0 .238 r
.50616 .44106 m .50853 .43703 L .50779 .43906 L F
0 0 .36 r
.50744 .44125 m .50616 .44106 L .50779 .43906 L F
.166 0 .036 r
.6632 .37543 m .66018 .37787 L .66299 .37714 L F
.059 0 .12 r
.66509 .37418 m .66602 .37217 L .6632 .37543 L F
.113 0 .204 r
.66509 .37418 m .6632 .37543 L .66299 .37714 L F
.734 .617 .728 r
.28433 .58491 m .28699 .58136 L .28468 .58208 L F
.879 .536 .038 r
.40035 .58702 m .39887 .58433 L .40026 .58518 L F
.40035 .58702 m .3995 .58678 L .39887 .58433 L F
.77 .319 0 r
.40035 .58702 m .40204 .59051 L .3995 .58678 L F
.387 .172 .461 r
.36286 .61156 m .36262 .61427 L .36514 .61086 L F
.888 .892 .827 r
.36514 .61086 m .36082 .61315 L .36286 .61156 L F
.156 0 .15 r
.52879 .41784 m .53092 .41678 L .53153 .41441 L F
.221 0 .172 r
.53153 .41441 m .53329 .41575 L .53408 .41324 L F
.53153 .41441 m .53092 .41678 L .53329 .41575 L F
.53 0 0 r
.34339 .51908 m .34186 .51813 L .3402 .5167 L F
.781 .928 .932 r
.34905 .59522 m .34533 .5974 L .34652 .59601 L F
.48 .137 .307 r
.53913 .41838 m .53893 .42041 L .53621 .42015 L F
.455 .306 .589 r
.54137 .41417 m .54207 .41781 L .53913 .41838 L F
0 0 .193 r
.54046 .41848 m .53913 .41838 L .54207 .41781 L F
.54046 .41848 m .53893 .42041 L .53913 .41838 L F
.833 .377 0 r
.40026 .58518 m .39887 .58433 L .3975 .58161 L F
.529 .911 .763 r
.31998 .63449 m .31561 .63681 L .31615 .63425 L F
.719 .7 .832 r
.70925 .28978 m .71247 .28931 L .71203 .28619 L F
.818 .731 .769 r
.70939 .29223 m .71247 .28931 L .70925 .28978 L F
.826 .6 .048 r
.42372 .53452 m .42432 .53876 L .42412 .53626 L F
.691 .502 .627 r
.68237 .30583 m .68497 .30631 L .68498 .30321 L F
.941 .963 .71 r
.69607 .36273 m .69788 .36225 L .69651 .36084 L F
.69607 .36273 m .69584 .36608 L .69788 .36225 L F
.87 .889 .846 r
.59126 .43728 m .58965 .43813 L .59087 .43795 L F
.924 .716 .603 r
.59165 .43792 m .59126 .43728 L .59087 .43795 L F
.113 .41 .859 r
.5916 .43784 m .59087 .43795 L .5899 .43536 L F
.59165 .43792 m .59087 .43795 L .5916 .43784 L F
.87 .889 .846 r
.58965 .43813 m .5873 .43937 L .59087 .43795 L F
.42 .205 .479 r
.59419 .4366 m .59361 .43428 L .59126 .43728 L F
.102 0 .205 r
.55309 .38832 m .55488 .38782 L .5556 .38503 L F
.5 0 0 r
.55309 .38832 m .55516 .38962 L .55488 .38782 L F
.287 .142 .503 r
.55516 .38962 m .55328 .39126 L .55309 .38832 L F
.5 0 0 r
.55309 .38832 m .5517 .38959 L .55516 .38962 L F
.774 .736 .817 r
.32774 .59444 m .3291 .59782 L .33133 .59484 L F
.034 0 .006 r
.65881 .32325 m .65796 .32475 L .66108 .32185 L F
.527 .854 .997 r
.32911 .6557 m .33118 .65663 L .32839 .65739 L F
.32911 .6557 m .33118 .65663 L .32839 .65739 L F
.577 .644 .88 r
.54985 .39041 m .55067 .39215 L .55328 .39126 L F
.925 .762 .66 r
.23682 .61434 m .23779 .61808 L .23512 .61679 L F
.879 .454 .185 r
.23512 .61679 m .23721 .6178 L .23694 .61842 L F
.23512 .61679 m .23709 .61855 L .23428 .61898 L F
.848 .66 .647 r
.23668 .61935 m .2364 .62105 L .23672 .61935 L F
.23581 .62047 m .2364 .62105 L .23668 .61935 L F
.84 .552 .501 r
.23428 .61898 m .23709 .61855 L .23668 .61935 L F
.848 .66 .647 r
.23428 .61898 m .23672 .61935 L .23714 .61709 L F
.867 .794 .302 r
.23685 .61863 m .23673 .61929 L .23634 .61981 L F
.23673 .61929 m .2364 .62105 L .23637 .62048 L F
.909 .585 .42 r
.23525 .62218 m .2364 .62105 L .23428 .61898 L F
.726 .245 .103 r
.2367 .61938 m .23637 .62048 L .23525 .62218 L F
.924 .954 .626 r
.23637 .62048 m .2364 .62105 L .23525 .62218 L F
.726 .245 .103 r
.23637 .62048 m .23596 .62186 L .23525 .62218 L F
.23668 .61935 m .2367 .61938 L .23525 .62218 L F
.848 .66 .647 r
.23428 .61898 m .23581 .62047 L .23668 .61935 L F
.84 .552 .501 r
.23428 .61898 m .23668 .61935 L .23525 .62218 L F
.924 .954 .626 r
.23626 .61822 m .23637 .62048 L .23525 .62218 L F
.867 .794 .302 r
.23673 .61929 m .23637 .62048 L .23634 .61981 L F
.726 .245 .103 r
.2367 .61938 m .23758 .62113 L .23596 .62186 L F
.23709 .61855 m .23713 .61877 L .23668 .61935 L F
.23713 .61877 m .23758 .62113 L .23668 .61935 L F
.867 .794 .302 r
.23714 .61709 m .23685 .61863 L .23626 .61822 L F
.23685 .61863 m .23634 .61981 L .23626 .61822 L F
.879 .454 .185 r
.23694 .61842 m .23779 .61808 L .23709 .61855 L F
.23721 .6178 m .23779 .61808 L .23694 .61842 L F
.763 .485 0 r
.23736 .61724 m .23779 .61808 L .23682 .61434 L F
.246 .508 .904 r
.23736 .61724 m .23709 .61855 L .23779 .61808 L F
0 0 0 r
.41233 .53733 m .41189 .53739 L .41351 .53634 L F
.41233 .53733 m .41004 .53819 L .41189 .53739 L F
.932 .831 .382 r
.34058 .55583 m .3401 .55877 L .33978 .55707 L F
.107 .191 .67 r
.33978 .55707 m .3387 .55468 L .34058 .55583 L F
.907 .749 .674 r
.37388 .46311 m .37539 .46748 L .3758 .46302 L F
.924 .82 .724 r
.38361 .58757 m .38197 .59126 L .3848 .59165 L F
.947 .894 .743 r
.38197 .59126 m .38249 .59454 L .3848 .59165 L F
.506 .758 .987 r
.34012 .53671 m .34294 .53885 L .34018 .53935 L F
.34012 .53671 m .34018 .53935 L .3408 .53912 L F
.187 .689 .911 r
.33562 .53876 m .3408 .53912 L .34018 .53935 L F
.828 .814 .837 r
.30217 .63729 m .30397 .63883 L .29975 .63977 L F
.539 .068 .084 r
.29975 .63977 m .30397 .63883 L .30202 .64046 L F
.476 0 0 r
.30397 .63883 m .30453 .63942 L .30202 .64046 L F
.30397 .63883 m .3062 .64064 L .30453 .63942 L F
.844 .864 .858 r
.70305 .32874 m .70301 .32583 L .70035 .32855 L F
.70305 .32874 m .70442 .32728 L .70301 .32583 L F
.825 .78 .81 r
.4008 .45742 m .39716 .45708 L .39981 .45481 L F
.426 .032 .186 r
.4008 .45742 m .39697 .45996 L .39716 .45708 L F
.4008 .45742 m .3997 .45954 L .39697 .45996 L F
.138 .204 .67 r
.40215 .45481 m .4008 .45742 L .39981 .45481 L F
.40215 .45481 m .40148 .45755 L .4008 .45742 L F
.93 .715 .59 r
.37923 .56778 m .38072 .57206 L .381 .56897 L F
.169 .01 .408 r
.69751 .29666 m .6974 .29906 L .69914 .29546 L F
.694 .31 .316 r
.29353 .674 m .29771 .67399 L .29612 .67614 L F
.696 .313 .318 r
.29771 .67399 m .30049 .67657 L .29612 .67614 L F
.6 .348 .506 r
.29771 .67399 m .30087 .67381 L .30049 .67657 L F
.752 .61 .701 r
.35801 .54002 m .35455 .54218 L .35647 .54161 L F
.876 .521 .374 r
.35801 .54002 m .35647 .54161 L .35565 .53892 L F
.64 .359 .478 r
.53095 .46338 m .53494 .46028 L .53083 .46085 L F
.53095 .46338 m .53452 .46292 L .53494 .46028 L F
.465 .678 .957 r
.53494 .46028 m .53378 .455 L .5366 .4565 L F
.53494 .46028 m .535 .45797 L .53378 .455 L F
.53494 .46028 m .53697 .45937 L .535 .45797 L F
.415 .24 .533 r
.53452 .46292 m .53697 .45937 L .53494 .46028 L F
.67 .579 .744 r
.54987 .45097 m .55182 .44625 L .54855 .44679 L F
.54987 .45097 m .55275 .45016 L .55182 .44625 L F
.936 .933 .774 r
.71915 .30535 m .72011 .30663 L .71801 .3103 L F
.865 .939 .867 r
.72299 .30355 m .72011 .30663 L .71915 .30535 L F
0 0 0 r
.55209 .4014 m .54937 .40201 L .54763 .4026 L F
.36 .017 .241 r
.55213 .4147 m .54885 .41695 L .5523 .41725 L F
.55213 .4147 m .54934 .41761 L .54885 .41695 L F
.241 .755 .843 r
.5523 .41725 m .54934 .41761 L .55213 .4147 L F
.449 .241 .503 r
.55213 .4147 m .5523 .41725 L .55486 .41382 L F
.55486 .41382 m .5523 .41725 L .55213 .4147 L F
.619 .292 .395 r
.34579 .56575 m .34571 .56851 L .34872 .5677 L F
.501 .361 .623 r
.34579 .56575 m .34872 .5677 L .34835 .56497 L F
0 0 0 r
.6522 .32879 m .65483 .32768 L .65597 .32638 L F
.65597 .32638 m .65717 .32622 L .65796 .32475 L F
.65597 .32638 m .65483 .32768 L .65717 .32622 L F
.602 .779 .965 r
.44153 .45491 m .44211 .45208 L .44005 .45371 L F
.44153 .45491 m .44373 .45383 L .44211 .45208 L F
.951 .943 .734 r
.47403 .58879 m .47599 .58504 L .47498 .58409 L F
.581 .024 0 r
.38782 .49176 m .38399 .49011 L .38762 .48815 L F
0 0 0 r
.38762 .48815 m .38399 .49011 L .3829 .49173 L F
.121 0 0 r
.61428 .34372 m .617 .34351 L .61845 .34278 L F
.32 .777 .633 r
.61845 .34278 m .61951 .34224 L .62108 .34182 L F
.61845 .34278 m .617 .34351 L .61951 .34224 L F
.792 .645 .699 r
.54476 .44646 m .54901 .44449 L .54443 .44378 L F
.54476 .44646 m .54855 .44679 L .54901 .44449 L F
.424 .226 .505 r
.33274 .51374 m .33012 .51277 L .33396 .51362 L F
.729 .989 .87 r
.61983 .40909 m .62115 .40689 L .62149 .40731 L F
.61983 .40909 m .61777 .40939 L .62115 .40689 L F
.993 .811 .558 r
.58954 .40353 m .59091 .40484 L .59001 .40757 L F
.402 .814 .616 r
.66465 .38684 m .66833 .38453 L .66707 .38575 L F
0 0 0 r
.66833 .38453 m .67181 .3824 L .67043 .38334 L F
.66707 .38575 m .66833 .38453 L .67043 .38334 L F
.787 .975 .689 r
.51054 .40084 m .51301 .39702 L .51406 .3979 L F
.842 .972 .879 r
.51406 .3979 m .51593 .39411 L .51715 .39526 L F
.51406 .3979 m .51301 .39702 L .51593 .39411 L F
.512 .862 .991 r
.61617 .36238 m .61521 .36149 L .61188 .36255 L F
.953 .95 .714 r
.61726 .35749 m .61617 .36238 L .61869 .35889 L F
.61726 .35749 m .61521 .36149 L .61617 .36238 L F
0 0 0 r
.66856 .36893 m .66602 .37217 L .66769 .37018 L F
.66769 .37018 m .66602 .37217 L .66509 .37418 L F
.27732 .59509 m .27902 .5913 L .27642 .59237 L F
.27732 .59509 m .27785 .59435 L .27902 .5913 L F
.373 .352 .707 r
.2771 .59733 m .27785 .59435 L .27732 .59509 L F
.571 .733 .952 r
.57424 .36409 m .57826 .36533 L .57564 .36605 L F
.98 .883 .661 r
.4007 .56857 m .39786 .57154 L .39963 .56767 L F
.4007 .56857 m .39925 .57325 L .39786 .57154 L F
0 0 .254 r
.52611 .44515 m .52485 .44464 L .52608 .44296 L F
.672 .706 .872 r
.60384 .35514 m .60818 .35632 L .60677 .3549 L F
.679 .194 .092 r
.42475 .55524 m .42762 .55735 L .42903 .55579 L F
.904 .517 .279 r
.42762 .55735 m .42946 .55798 L .42903 .55579 L F
.147 .458 .886 r
.29079 .64017 m .29293 .64103 L .2915 .63909 L F
.516 .899 .953 r
.2915 .63909 m .28864 .63996 L .29079 .64017 L F
.982 .866 .493 r
.69665 .3556 m .69656 .35072 L .69628 .35425 L F
.916 .594 .119 r
.69612 .35676 m .69665 .3556 L .69628 .35425 L F
.69612 .35676 m .6971 .35806 L .69665 .3556 L F
.89 .463 .113 r
.41753 .52512 m .42005 .5282 L .41915 .52634 L F
.903 .856 .785 r
.57757 .45338 m .58018 .45376 L .57988 .45005 L F
.858 .952 .874 r
.57656 .45567 m .58018 .45376 L .57757 .45338 L F
.517 .183 .34 r
.30417 .6699 m .30516 .67199 L .30336 .67319 L F
.30417 .6699 m .30683 .66985 L .30516 .67199 L F
.936 .933 .774 r
.71915 .30535 m .71801 .3103 L .71655 .30864 L F
.284 .675 .972 r
.35765 .55468 m .36068 .55533 L .35875 .55432 L F
.35765 .55468 m .35875 .55432 L .35668 .55565 L F
.763 .272 .063 r
.37697 .51644 m .37543 .51753 L .37536 .5148 L F
.37697 .51644 m .37842 .51856 L .37543 .51753 L F
.845 .956 .884 r
.5943 .43276 m .59361 .43428 L .59377 .4327 L F
0 0 .296 r
.59377 .4327 m .59361 .43428 L .59419 .4366 L F
.59377 .4327 m .59419 .4366 L .59633 .43502 L F
.663 .121 0 r
.5931 .43262 m .59377 .4327 L .59525 .43431 L F
.59205 .4318 m .59377 .4327 L .5931 .43262 L F
.845 .956 .884 r
.59537 .43039 m .5943 .43276 L .59377 .4327 L F
0 0 .141 r
.43104 .57067 m .42984 .57394 L .4293 .57212 L F
.426 .87 .853 r
.43755 .44517 m .44108 .44399 L .44228 .44397 L F
.273 .764 .691 r
.44108 .44399 m .44457 .44273 L .44228 .44397 L F
.417 0 0 r
.33732 .5271 m .33544 .52753 L .34005 .52799 L F
.523 .521 .794 r
.34311 .57131 m .34571 .56851 L .34274 .56933 L F
.34311 .57131 m .34595 .57106 L .34571 .56851 L F
.451 .78 .998 r
.57826 .36533 m .58119 .36495 L .58268 .36628 L F
.485 0 0 r
.58119 .36495 m .58482 .36486 L .58268 .36628 L F
.229 .722 .918 r
.62523 .34565 m .62889 .34606 L .62801 .34551 L F
.247 .539 .923 r
.62889 .34606 m .63057 .3446 L .62801 .34551 L F
.62889 .34606 m .63187 .34731 L .63057 .3446 L F
.565 .701 .932 r
.6293 .3475 m .63187 .34731 L .62889 .34606 L F
.951 .655 .441 r
.3459 .55158 m .34383 .55062 L .34562 .54863 L F
0 0 0 r
.34562 .54863 m .34383 .55062 L .3459 .54955 L F
.555 .928 .798 r
.47575 .42467 m .47159 .4267 L .47341 .42489 L F
.602 .931 .719 r
.47877 .42225 m .47575 .42467 L .47698 .42309 L F
.582 .944 .891 r
.47698 .42309 m .47575 .42467 L .47341 .42489 L F
.121 0 .213 r
.5556 .38503 m .55855 .38431 L .55847 .38393 L F
.5556 .38503 m .55488 .38782 L .55855 .38431 L F
.808 .607 .63 r
.60059 .42047 m .60267 .41749 L .60047 .41781 L F
.327 0 .011 r
.62246 .34591 m .61851 .34827 L .61878 .34813 L F
.62246 .34591 m .62159 .34777 L .61851 .34827 L F
.104 0 0 r
.62407 .34671 m .62246 .34591 L .62523 .34565 L F
.62407 .34671 m .62159 .34777 L .62246 .34591 L F
.97 .863 .678 r
.50421 .52306 m .50121 .52416 L .50244 .52472 L F
.858 .981 .689 r
.50472 .5206 m .50421 .52306 L .50651 .5195 L F
.839 .998 .823 r
.50472 .5206 m .50121 .52416 L .50421 .52306 L F
.893 .504 .059 r
.39694 .49497 m .39917 .49914 L .39813 .49562 L F
.498 .832 .999 r
.33994 .5229 m .33839 .52191 L .34243 .52227 L F
.33994 .5229 m .33839 .52191 L .34243 .52227 L F
.698 .981 .817 r
.46611 .43034 m .46415 .43206 L .46215 .43271 L F
.492 .322 .578 r
.33101 .5436 m .33088 .54274 L .33054 .54285 L F
.42 0 0 r
.72523 .30132 m .7273 .30236 L .72934 .30313 L F
.944 .742 .6 r
.72634 .30469 m .72934 .30313 L .7273 .30236 L F
.72634 .30469 m .7288 .30557 L .72934 .30313 L F
.208 .723 .682 r
.43596 .5735 m .43539 .57368 L .43222 .57462 L F
.195 0 0 r
.43913 .57209 m .43539 .57368 L .43701 .57318 L F
.208 .723 .682 r
.43701 .57318 m .43539 .57368 L .43596 .5735 L F
0 0 0 r
.43587 .57285 m .43517 .57375 L .43539 .57368 L F
.43517 .57375 m .4336 .57575 L .43539 .57368 L F
.195 0 0 r
.43913 .57209 m .43587 .57285 L .43539 .57368 L F
.63 .92 .647 r
.54947 .40717 m .55279 .40424 L .55191 .40655 L F
.512 .513 .793 r
.55457 .40013 m .55279 .40424 L .55209 .4014 L F
.822 .825 .851 r
.55695 .40379 m .55191 .40655 L .55279 .40424 L F
.576 .221 .33 r
.30518 .53613 m .30747 .53808 L .30792 .53614 L F
.30518 .53613 m .30747 .53808 L .30792 .53614 L F
.868 .765 .746 r
.33317 .50656 m .32897 .50776 L .32883 .50575 L F
.978 .678 .347 r
.38908 .53283 m .38779 .53432 L .38758 .53159 L F
.38908 .53283 m .3893 .53557 L .38779 .53432 L F
.138 0 0 r
.40858 .45294 m .41259 .45234 L .4101 .4534 L F
.512 .497 .777 r
.25833 .53127 m .25671 .5331 L .25586 .52909 L F
.25833 .53127 m .25886 .53245 L .25671 .5331 L F
.757 .913 .944 r
.70442 .32728 m .70568 .32461 L .70301 .32583 L F
.70442 .32728 m .70683 .32586 L .70568 .32461 L F
.361 .83 .786 r
.34842 .53299 m .35092 .53185 L .35161 .53193 L F
.34842 .53299 m .34791 .53305 L .35092 .53185 L F
.348 .666 .974 r
.58317 .34748 m .58481 .34951 L .58208 .34915 L F
.58317 .34748 m .58481 .34951 L .58208 .34915 L F
.504 .283 .512 r
.42121 .56379 m .42476 .56061 L .42367 .56158 L F
.32 0 0 r
.37529 .49431 m .37448 .49336 L .37296 .49196 L F
.37529 .49431 m .37739 .49381 L .37448 .49336 L F
0 .205 .658 r
.55904 .43109 m .56085 .43227 L .56034 .43168 L F
.407 .532 .87 r
.55904 .43109 m .5629 .43447 L .56187 .43293 L F
.884 .791 .301 r
.56034 .43168 m .55962 .43311 L .55969 .43094 L F
.278 0 .296 r
.56088 .42688 m .55891 .42828 L .55955 .42954 L F
.55891 .42828 m .55816 .42882 L .55955 .42954 L F
0 0 .366 r
.55955 .42954 m .56034 .43168 L .56015 .43073 L F
.823 .888 .463 r
.56052 .42695 m .56088 .42688 L .55955 .42954 L F
.593 .641 .868 r
.56125 .4268 m .56088 .42688 L .56053 .42375 L F
.607 .819 .418 r
.5628 .42039 m .56053 .42375 L .5618 .42178 L F
0 0 .339 r
.5618 .42178 m .56053 .42375 L .56088 .42688 L F
.823 .888 .463 r
.56148 .42439 m .56088 .42688 L .56052 .42695 L F
.593 .641 .868 r
.56164 .42842 m .56088 .42688 L .56125 .4268 L F
.823 .888 .463 r
.56148 .42439 m .56059 .42676 L .5613 .42687 L F
.56059 .42676 m .55955 .42954 L .56041 .42823 L F
.56059 .42676 m .56041 .42823 L .5613 .42687 L F
.593 .641 .868 r
.56164 .42842 m .56262 .42601 L .56088 .42688 L F
.56262 .42601 m .56164 .42842 L .56088 .42688 L F
0 0 .366 r
.56095 .4274 m .55977 .42876 L .5613 .42687 L F
.55955 .42954 m .55977 .42876 L .56095 .4274 L F
.058 .143 .638 r
.55955 .42954 m .55816 .42882 L .56034 .43168 L F
.768 .652 .095 r
.55977 .42876 m .55956 .43183 L .55922 .42939 L F
.55977 .42876 m .55922 .42939 L .55916 .42901 L F
0 0 .366 r
.55955 .42954 m .56015 .43073 L .55977 .42876 L F
.884 .791 .301 r
.56011 .43054 m .55969 .43094 L .55977 .42876 L F
.56034 .43168 m .56002 .43131 L .56011 .43054 L F
.56002 .43131 m .55969 .43094 L .56011 .43054 L F
0 .205 .658 r
.56085 .43227 m .56187 .43293 L .56034 .43168 L F
.921 .697 .581 r
.36151 .52916 m .36241 .53003 L .36192 .52785 L F
.341 0 .168 r
.55182 .44625 m .55439 .4458 L .55536 .44388 L F
.472 0 .014 r
.5578 .44488 m .55536 .44388 L .55439 .4458 L F
.5578 .44488 m .55882 .44435 L .55536 .44388 L F
.807 .964 .647 r
.28291 .61665 m .28498 .6149 L .28538 .61309 L F
.558 .209 .334 r
.52257 .42203 m .52554 .42355 L .52576 .42112 L F
.009 0 .099 r
.52879 .41784 m .52576 .42112 L .52848 .4201 L F
.271 0 .28 r
.52576 .42112 m .52793 .42237 L .52848 .4201 L F
.52576 .42112 m .52554 .42355 L .52793 .42237 L F
.956 .798 .646 r
.7105 .28473 m .71328 .28318 L .71037 .28216 L F
.7105 .28473 m .71203 .28619 L .71328 .28318 L F
.834 .659 .665 r
.71203 .28619 m .71361 .28359 L .71328 .28318 L F
.791 .897 .489 r
.59791 .42118 m .59625 .42447 L .59702 .42195 L F
0 0 0 r
.59702 .42195 m .59625 .42447 L .59562 .42685 L F
.558 .498 .743 r
.54071 .40843 m .54379 .41023 L .54341 .40719 L F
.758 .677 .773 r
.43222 .58799 m .43376 .592 L .42977 .59156 L F
.946 .608 .194 r
.57912 .3785 m .57782 .37713 L .57742 .37469 L F
0 0 .568 r
.57912 .3785 m .58043 .37913 L .57782 .37713 L F
.57912 .3785 m .58073 .38074 L .58043 .37913 L F
.686 .94 .964 r
.61364 .4036 m .61787 .40268 L .6171 .40208 L F
0 0 0 r
.61787 .40268 m .61881 .40288 L .6171 .40208 L F
.61787 .40268 m .62092 .40195 L .61881 .40288 L F
.233 0 .139 r
.35308 .5494 m .35498 .55003 L .35558 .54646 L F
.62 .616 .825 r
.35155 .55119 m .35511 .55428 L .35537 .55022 L F
.35511 .55428 m .35663 .5556 L .35595 .5527 L F
.35511 .55428 m .35595 .5527 L .35537 .55022 L F
.35663 .5556 m .35664 .55545 L .35537 .55022 L F
.811 .779 .824 r
.35555 .55024 m .35668 .55565 L .35875 .55432 L F
.744 .318 .24 r
.35548 .55099 m .35478 .55121 L .3555 .54989 L F
.811 .779 .824 r
.3553 .54992 m .35537 .55022 L .35555 .55024 L F
.35537 .55022 m .35668 .55565 L .35555 .55024 L F
.35553 .55036 m .35875 .55432 L .35632 .55186 L F
.35555 .55024 m .35875 .55432 L .35553 .55036 L F
.743 .317 .239 r
.35558 .54646 m .3555 .54989 L .35502 .54977 L F
.936 .585 .165 r
.35558 .54646 m .35558 .54653 L .35558 .54654 L F
.35558 .54646 m .35558 .54654 L .35668 .5511 L F
.35558 .54653 m .3555 .55009 L .35668 .5511 L F
.743 .317 .239 r
.35558 .54646 m .35745 .55036 L .3555 .54989 L F
.811 .779 .824 r
.3553 .54992 m .35555 .55024 L .35553 .55036 L F
.744 .318 .24 r
.35559 .54991 m .35556 .5501 L .3555 .54989 L F
.35556 .5501 m .35553 .55036 L .35552 .55009 L F
.35556 .5501 m .35552 .55009 L .3555 .54989 L F
.811 .779 .824 r
.3555 .55009 m .35745 .55036 L .35668 .5511 L F
.744 .318 .24 r
.35745 .55036 m .35548 .55079 L .35559 .54991 L F
.936 .585 .165 r
.35558 .54653 m .3553 .54992 L .3555 .55009 L F
.811 .779 .824 r
.3553 .54992 m .35745 .55036 L .3555 .55009 L F
.744 .318 .24 r
.35553 .55036 m .35549 .55036 L .3555 .54989 L F
.811 .779 .824 r
.3553 .54992 m .35553 .55036 L .35745 .55036 L F
.35553 .55036 m .35632 .55186 L .35745 .55036 L F
.744 .318 .24 r
.35553 .55036 m .35548 .55079 L .35549 .55036 L F
.35737 .55037 m .35548 .55099 L .35548 .55079 L F
.35745 .55036 m .35739 .55037 L .35737 .55037 L F
.35739 .55037 m .35548 .55099 L .35737 .55037 L F
.755 .925 .565 r
.35632 .55186 m .35564 .55228 L .35687 .55097 L F
.35657 .55153 m .35687 .55097 L .35745 .55036 L F
.35632 .55186 m .35687 .55097 L .35657 .55153 L F
.62 .616 .825 r
.35155 .55119 m .35355 .55656 L .35668 .55565 L F
.824 .839 .86 r
.35681 .55235 m .35476 .5543 L .35632 .55186 L F
.35875 .55432 m .3567 .55431 L .35681 .55235 L F
.3567 .55431 m .35476 .5543 L .35681 .55235 L F
.62 .616 .825 r
.35663 .5556 m .35668 .55565 L .35664 .55545 L F
.744 .318 .24 r
.3555 .54989 m .35533 .5502 L .35502 .54977 L F
.35533 .5502 m .35498 .55003 L .35502 .54977 L F
.62 .616 .825 r
.35498 .55003 m .35537 .55022 L .3553 .54992 L F
.35155 .55119 m .35537 .55022 L .35498 .55003 L F
.744 .318 .24 r
.35533 .5502 m .35478 .55121 L .35498 .55003 L F
.233 0 .139 r
.35498 .55003 m .35498 .55003 L .35502 .54977 L F
.35498 .55003 m .35502 .54977 L .35558 .54646 L F
.744 .318 .24 r
.35745 .55036 m .35564 .55228 L .35478 .55121 L F
.233 0 .139 r
.35155 .55119 m .35459 .55016 L .35308 .5494 L F
.35459 .55016 m .35498 .55003 L .35308 .5494 L F
.744 .318 .24 r
.35502 .54977 m .35478 .55121 L .35327 .54935 L F
.311 .309 .695 r
.35327 .54935 m .35236 .54905 L .35558 .54646 L F
.887 .89 .828 r
.35485 .54566 m .35236 .54905 L .35066 .54792 L F
.311 .309 .695 r
.35327 .54935 m .35066 .54792 L .35233 .54902 L F
.3524 .54906 m .35233 .54902 L .35236 .54905 L F
.35327 .54935 m .35233 .54902 L .3524 .54906 L F
.233 0 .139 r
.35498 .55003 m .3553 .54992 L .35558 .54646 L F
.743 .317 .239 r
.35558 .54646 m .35502 .54977 L .35327 .54935 L F
0 .163 .702 r
.60089 .42514 m .59791 .42118 L .60038 .42377 L F
.728 .2 0 r
.59702 .42195 m .60038 .42377 L .59791 .42118 L F
.375 .738 .99 r
.60364 .44743 m .60662 .44729 L .60438 .4464 L F
.222 .72 .913 r
.60442 .44614 m .60364 .44743 L .60338 .44526 L F
.652 .928 .973 r
.60662 .44729 m .60451 .44559 L .60438 .4464 L F
.222 .72 .913 r
.60451 .44622 m .60438 .4464 L .60442 .44614 L F
.60438 .4464 m .60364 .44743 L .60442 .44614 L F
.652 .928 .973 r
.60662 .44729 m .60554 .44564 L .60451 .44559 L F
.902 .837 .772 r
.60632 .44301 m .60555 .4456 L .60454 .44489 L F
.66 .718 .892 r
.60555 .4456 m .60662 .44729 L .60554 .44564 L F
.60632 .44301 m .60658 .44675 L .60555 .4456 L F
.60658 .44675 m .60662 .44729 L .60555 .4456 L F
.375 .738 .99 r
.60364 .44743 m .60288 .44579 L .60338 .44526 L F
.521 .812 .999 r
.60361 .44542 m .60533 .44548 L .60446 .445 L F
0 .074 .552 r
.60329 .44516 m .60435 .44608 L .60338 .44526 L F
.60313 .44501 m .60361 .44542 L .60329 .44516 L F
.60361 .44542 m .60435 .44608 L .60329 .44516 L F
.521 .812 .999 r
.60288 .44579 m .60388 .44567 L .60361 .44542 L F
.652 .928 .973 r
.60438 .4464 m .60442 .44614 L .60288 .44579 L F
.60442 .44614 m .60451 .44559 L .60388 .44567 L F
0 .074 .552 r
.60421 .44596 m .60442 .44614 L .60435 .44608 L F
.652 .928 .973 r
.60442 .44614 m .60388 .44567 L .60288 .44579 L F
.375 .738 .99 r
.60364 .44743 m .60438 .4464 L .60288 .44579 L F
.521 .812 .999 r
.60334 .44639 m .6041 .44582 L .60369 .44683 L F
.60388 .44567 m .60533 .44548 L .60361 .44542 L F
.652 .928 .973 r
.60554 .44564 m .60533 .44548 L .60451 .44559 L F
.902 .837 .772 r
.60554 .44564 m .60519 .4468 L .60431 .44517 L F
.60454 .44489 m .60431 .44517 L .6039 .4444 L F
.60554 .44564 m .60431 .44517 L .60454 .44489 L F
.521 .812 .999 r
.60533 .44548 m .60543 .44547 L .60446 .445 L F
.66 .718 .892 r
.60632 .44301 m .60901 .44602 L .60662 .44729 L F
.521 .812 .999 r
.60543 .44547 m .60811 .44514 L .60502 .44502 L F
.902 .837 .772 r
.60555 .4456 m .60533 .44548 L .60454 .44489 L F
.521 .812 .999 r
.60543 .44547 m .60502 .44502 L .60446 .445 L F
.60446 .445 m .60811 .44514 L .60681 .44381 L F
.60361 .44542 m .60446 .445 L .60391 .44567 L F
.902 .837 .772 r
.6039 .4444 m .60519 .4468 L .60303 .4449 L F
.521 .812 .999 r
.6041 .44582 m .60681 .44381 L .60444 .4461 L F
0 .074 .552 r
.60391 .44567 m .60519 .4468 L .60373 .44553 L F
.521 .812 .999 r
.6041 .44582 m .60444 .4461 L .60369 .44683 L F
0 .074 .552 r
.60373 .44553 m .60519 .4468 L .60442 .44614 L F
.60303 .4449 m .60391 .44567 L .60373 .44553 L F
.521 .812 .999 r
.60446 .445 m .60681 .44381 L .6041 .44582 L F
0 .074 .552 r
.60373 .44553 m .60442 .44614 L .60371 .44551 L F
.521 .812 .999 r
.60391 .44567 m .6041 .44582 L .60334 .44639 L F
.60446 .445 m .6041 .44582 L .60391 .44567 L F
0 .074 .552 r
.60371 .44551 m .60442 .44614 L .60421 .44596 L F
.60303 .4449 m .60373 .44553 L .60371 .44551 L F
.521 .812 .999 r
.60288 .44579 m .60361 .44542 L .60334 .44639 L F
.60361 .44542 m .60391 .44567 L .60334 .44639 L F
0 .074 .552 r
.60303 .4449 m .60435 .44608 L .60313 .44501 L F
.902 .837 .772 r
.60555 .4456 m .60554 .44564 L .60533 .44548 L F
.60582 .4433 m .60454 .44489 L .6039 .4444 L F
.60632 .44301 m .60454 .44489 L .60582 .4433 L F
.652 .928 .973 r
.60554 .44564 m .60543 .44547 L .60533 .44548 L F
.66 .718 .892 r
.60554 .44564 m .60662 .44729 L .60519 .4468 L F
.652 .928 .973 r
.60662 .44729 m .60811 .44514 L .60543 .44547 L F
.222 .72 .913 r
.60519 .4468 m .60364 .44743 L .60451 .44622 L F
.60519 .4468 m .60662 .44729 L .60364 .44743 L F
.803 .332 .103 r
.58772 .39777 m .58963 .39815 L .58863 .39955 L F
.953 .603 .247 r
.58963 .39815 m .59017 .40085 L .58863 .39955 L F
.504 .551 .838 r
.32685 .5301 m .32876 .53311 L .33064 .5318 L F
.397 .411 .757 r
.32876 .53311 m .33106 .53421 L .33064 .5318 L F
.782 .701 .775 r
.54629 .44827 m .54855 .44679 L .54476 .44646 L F
0 0 0 r
.35759 .57123 m .35726 .57225 L .35909 .56791 L F
.838 .439 .292 r
.67943 .33177 m .67565 .3288 L .67969 .3291 L F
.633 .914 .981 r
.54813 .47159 m .54833 .47349 L .54759 .47344 L F
.757 .993 .798 r
.55065 .47045 m .54833 .47349 L .54813 .47159 L F
.55208 .46856 m .55251 .46912 L .5523 .46933 L F
.55065 .47045 m .5523 .46933 L .54833 .47349 L F
.55208 .46856 m .5523 .46933 L .55065 .47045 L F
0 0 0 r
.54597 .47507 m .54759 .47344 L .54484 .47474 L F
.781 .924 .55 r
.54813 .47159 m .54759 .47344 L .54597 .47507 L F
.54813 .47159 m .54597 .47507 L .54887 .47419 L F
.611 .549 .761 r
.54826 .47205 m .5464 .47237 L .54813 .47159 L F
.54887 .47419 m .54706 .47286 L .54826 .47205 L F
.54706 .47286 m .5464 .47237 L .54826 .47205 L F
.5464 .47237 m .54518 .47147 L .54813 .47159 L F
.757 .993 .798 r
.55208 .46856 m .55065 .47045 L .54813 .47159 L F
.564 .812 .991 r
.63114 .39029 m .63516 .3909 L .63247 .3917 L F
.901 .726 .656 r
.36151 .52916 m .36148 .53187 L .36241 .53003 L F
.372 .811 .659 r
.69187 .36821 m .69584 .36608 L .69421 .36687 L F
.945 .956 .664 r
.69421 .36687 m .69584 .36608 L .69607 .36273 L F
.83 .96 .895 r
.63531 .40476 m .63626 .4018 L .63423 .40375 L F
.63531 .40476 m .6384 .402 L .63626 .4018 L F
.331 0 0 r
.25026 .62865 m .25032 .62899 L .2481 .62619 L F
.25026 .62865 m .25216 .62943 L .25032 .62899 L F
.931 .793 .325 r
.36693 .6311 m .36674 .62751 L .36776 .62954 L F
.594 .927 .962 r
.36545 .63066 m .36693 .6311 L .36776 .62954 L F
.958 .93 .726 r
.42562 .5505 m .42828 .5489 L .4286 .54736 L F
.42562 .5505 m .42669 .55169 L .42828 .5489 L F
.99 .862 .612 r
.69842 .33716 m .69892 .3359 L .69777 .33449 L F
.925 .859 .756 r
.69892 .3359 m .69962 .33008 L .69777 .33449 L F
.482 .892 .924 r
.4558 .44947 m .45703 .44975 L .45956 .44877 L F
.875 .482 .018 r
.39927 .5624 m .39887 .56359 L .39853 .56066 L F
.39927 .5624 m .40004 .56476 L .39887 .56359 L F
.492 0 0 r
.55852 .44487 m .56196 .44419 L .55882 .44435 L F
.953 .905 .528 r
.56285 .4387 m .56196 .44419 L .55852 .44487 L F
.84 .398 0 r
.5629 .43447 m .56228 .43518 L .56187 .43293 L F
.5629 .43447 m .56421 .4372 L .56228 .43518 L F
0 0 0 r
.52944 .46915 m .53114 .46854 L .53352 .46671 L F
0 0 .209 r
.53438 .46819 m .53314 .47021 L .53352 .46671 L F
.53438 .46819 m .53352 .46671 L .53114 .46854 L F
.556 .823 .996 r
.63644 .36931 m .63482 .37146 L .63355 .37007 L F
.63644 .36931 m .63778 .37059 L .63482 .37146 L F
.63482 .37146 m .63644 .36931 L .63355 .37007 L F
.63482 .37146 m .63778 .37059 L .63644 .36931 L F
.967 .803 .628 r
.6973 .34838 m .69795 .34582 L .69635 .34438 L F
.546 .576 .836 r
.23952 .59464 m .24097 .59192 L .23868 .5918 L F
.785 .714 .785 r
.43887 .58515 m .44283 .58265 L .44179 .5844 L F
0 0 0 r
.4444 .58143 m .44179 .5844 L .44283 .58265 L F
.8 .896 .911 r
.24036 .58259 m .23723 .58539 L .23542 .58425 L F
.372 .664 .971 r
.23723 .58539 m .2378 .58358 L .23542 .58425 L F
.23723 .58539 m .23967 .58532 L .2378 .58358 L F
.062 .597 .858 r
.41769 .47336 m .41575 .47322 L .4164 .47293 L F
.41769 .47336 m .41575 .47322 L .4164 .47293 L F
.538 .087 .129 r
.51851 .42311 m .52257 .42203 L .51912 .42072 L F
.51851 .42311 m .5226 .42312 L .52257 .42203 L F
.576 .118 .128 r
.5226 .42312 m .52554 .42355 L .52257 .42203 L F
.575 .358 .548 r
.35626 .53595 m .35565 .53892 L .35349 .53889 L F
.222 .741 .746 r
.62644 .34013 m .63064 .33924 L .62803 .34008 L F
.865 .939 .867 r
.72299 .30355 m .71915 .30535 L .72152 .30221 L F
.799 .999 .812 r
.72299 .30355 m .724 .30128 L .72523 .30132 L F
.65 .853 .978 r
.72152 .30221 m .724 .30128 L .72299 .30355 L F
.809 .389 0 r
.59049 .41041 m .59198 .41238 L .59257 .41378 L F
.426 .111 .326 r
.63774 .38496 m .64083 .38393 L .64146 .38237 L F
.63774 .38496 m .64083 .38393 L .64146 .38237 L F
0 0 .068 r
.6431 .38088 m .64083 .38393 L .64146 .38237 L F
.64146 .38237 m .64083 .38393 L .6431 .38088 L F
.856 .959 .874 r
.6198 .36592 m .61721 .36711 L .61868 .36383 L F
.544 .713 .95 r
.62135 .36332 m .6198 .36592 L .61868 .36383 L F
.253 .334 .753 r
.62135 .36332 m .62248 .36751 L .6198 .36592 L F
.767 .62 .697 r
.4655 .58818 m .46378 .59211 L .46311 .58837 L F
.386 .28 .611 r
.28631 .6377 m .28864 .63996 L .28819 .63697 L F
.88 .736 .698 r
.59727 .40991 m .59912 .41129 L .59772 .40734 L F
.93 .716 .592 r
.59727 .40991 m .59883 .41399 L .59912 .41129 L F
.739 .671 .784 r
.59772 .40734 m .59912 .41129 L .60156 .4082 L F
.684 .743 .896 r
.56023 .40957 m .56061 .41229 L .56426 .4104 L F
.623 .511 .706 r
.56061 .41229 m .56533 .41146 L .56426 .4104 L F
.56061 .41229 m .56222 .41411 L .56533 .41146 L F
.785 .741 .812 r
.32932 .65041 m .3336 .65076 L .33195 .64709 L F
.697 .7 .849 r
.33195 .64709 m .3336 .65076 L .33573 .64857 L F
.433 .776 .997 r
.3336 .65076 m .33704 .65081 L .33573 .64857 L F
.826 .541 .506 r
.37357 .5555 m .37363 .55811 L .37731 .55844 L F
.871 .604 .532 r
.37363 .55811 m .37731 .56162 L .37731 .55844 L F
.83 .62 .07 r
.58445 .38628 m .58501 .38838 L .58509 .39081 L F
.966 .651 .264 r
.66717 .36727 m .66856 .36893 L .66769 .37018 L F
.66717 .36727 m .66856 .36893 L .66769 .37018 L F
.55 .613 .869 r
.40039 .50989 m .40171 .51008 L .4009 .50695 L F
.4009 .50695 m .40171 .51008 L .40039 .50989 L F
.4009 .50695 m .40171 .51008 L .40039 .50989 L F
.492 .322 .578 r
.33101 .5436 m .33304 .54531 L .33088 .54274 L F
.667 .533 .692 r
.33088 .54274 m .33535 .54306 L .33562 .53876 L F
0 .172 .695 r
.33088 .54274 m .3334 .54318 L .33535 .54306 L F
.33088 .54274 m .33304 .54531 L .3334 .54318 L F
.787 .975 .689 r
.51054 .40084 m .51032 .4004 L .51301 .39702 L F
.536 .333 .552 r
.43894 .5887 m .43368 .5911 L .43887 .58515 L F
.478 .288 .544 r
.44169 .58742 m .43887 .58515 L .44179 .5844 L F
.44169 .58742 m .43894 .5887 L .43887 .58515 L F
.6 .909 .981 r
.53446 .49041 m .53572 .48855 L .53226 .49066 L F
.53446 .49041 m .53693 .48928 L .53572 .48855 L F
.843 .689 .69 r
.60736 .42135 m .60951 .42153 L .60702 .4206 L F
.60736 .42135 m .60885 .42456 L .60951 .42153 L F
.601 .902 .623 r
.67043 .38334 m .67181 .3824 L .67363 .38053 L F
.784 .927 .93 r
.47403 .58879 m .47262 .58776 L .46864 .59076 L F
.951 .943 .734 r
.47403 .58879 m .47498 .58409 L .47262 .58776 L F
.868 .907 .856 r
.59897 .39465 m .60201 .39205 L .59988 .39227 L F
.629 .946 .948 r
.59988 .39227 m .60201 .39205 L .60419 .39058 L F
.536 .388 .627 r
.4518 .56895 m .44944 .572 L .44924 .56942 L F
.064 0 0 r
.33128 .49921 m .33206 .50026 L .33409 .49866 L F
.33128 .49921 m .32953 .50117 L .33206 .50026 L F
.571 .94 .867 r
.53803 .47874 m .53556 .4802 L .53698 .47862 L F
.575 .94 .826 r
.53698 .47862 m .53556 .4802 L .53341 .48081 L F
.372 .811 .659 r
.69187 .36821 m .69421 .36687 L .69184 .36837 L F
0 0 0 r
.23952 .59464 m .23882 .59747 L .23973 .59624 L F
.628 .857 .486 r
.23973 .59624 m .23826 .59811 L .2393 .59673 L F
0 0 0 r
.23952 .59464 m .23973 .59624 L .2412 .59456 L F
.23952 .59464 m .24304 .59446 L .24303 .59444 L F
.546 .576 .836 r
.23952 .59464 m .24303 .59444 L .24097 .59192 L F
.24303 .59444 m .24309 .59444 L .24294 .59426 L F
.24303 .59444 m .24294 .59426 L .24097 .59192 L F
0 .115 .651 r
.24194 .59307 m .24294 .59426 L .24249 .59342 L F
0 0 .063 r
.24294 .59426 m .24296 .59429 L .24283 .59405 L F
.24303 .59444 m .24283 .59405 L .24249 .59342 L F
0 .115 .651 r
.24294 .59426 m .24309 .59444 L .24249 .59342 L F
0 0 .063 r
.24303 .59444 m .243 .59438 L .24294 .59426 L F
.243 .59438 m .24296 .59429 L .24294 .59426 L F
.24304 .59448 m .24303 .59444 L .24249 .59342 L F
.852 .996 .825 r
.24309 .59444 m .24301 .59442 L .24249 .59342 L F
.24301 .59442 m .24137 .59399 L .24249 .59342 L F
0 0 .063 r
.24331 .59506 m .24304 .59448 L .24249 .59342 L F
0 0 0 r
.24303 .59444 m .24304 .59446 L .24309 .59444 L F
0 0 .063 r
.24375 .59593 m .24342 .59517 L .24296 .59429 L F
.24375 .59593 m .24296 .59429 L .24331 .59506 L F
.04 .184 .687 r
.24436 .59419 m .24375 .59593 L .24272 .59386 L F
.2428 .59354 m .24272 .59386 L .24249 .59342 L F
.24436 .59419 m .24272 .59386 L .2428 .59354 L F
0 0 0 r
.2412 .59456 m .23973 .59624 L .24304 .59446 L F
.852 .996 .825 r
.24261 .59431 m .23973 .59624 L .24137 .59399 L F
.24309 .59444 m .2425 .59475 L .24261 .59431 L F
.2425 .59475 m .23973 .59624 L .24261 .59431 L F
.04 .184 .687 r
.24368 .59415 m .24249 .59342 L .24137 .59399 L F
.24436 .59419 m .24249 .59342 L .24368 .59415 L F
0 .115 .651 r
.24097 .59192 m .24194 .59307 L .24249 .59342 L F
.628 .857 .486 r
.23973 .59624 m .2393 .59673 L .24137 .59399 L F
0 0 0 r
.35155 .55119 m .35007 .55255 L .35236 .54905 L F
.35236 .54905 m .35007 .55255 L .35155 .55119 L F
.35155 .55119 m .35236 .54905 L .35066 .54792 L F
.682 .881 .503 r
.56011 .40474 m .55869 .40681 L .55902 .40596 L F
.928 .56 .294 r
.55825 .40379 m .56011 .40474 L .55902 .40596 L F
.495 .866 .983 r
.56168 .40525 m .55902 .40596 L .55825 .40379 L F
.485 .346 .616 r
.55825 .40379 m .55902 .40596 L .56168 .40525 L F
.495 .866 .983 r
.56168 .40525 m .55928 .40528 L .55902 .40596 L F
0 0 .487 r
.55825 .40379 m .55902 .40596 L .55824 .40547 L F
.401 .846 .744 r
.55763 .40531 m .55824 .40547 L .55902 .40596 L F
.495 .866 .983 r
.55928 .40528 m .55763 .40531 L .55902 .40596 L F
.682 .881 .503 r
.55869 .40681 m .55794 .4079 L .55902 .40596 L F
.196 .325 .768 r
.55794 .4079 m .56023 .40957 L .55902 .40596 L F
.901 .861 .792 r
.52131 .41254 m .52441 .41109 L .52239 .40989 L F
.528 .514 .785 r
.4908 .44731 m .49212 .44263 L .48928 .44363 L F
.279 .584 .944 r
.4933 .44739 m .49351 .44816 L .4908 .44731 L F
.712 .781 .906 r
.52317 .45673 m .51975 .4588 L .52033 .45757 L F
.52033 .45757 m .51975 .4588 L .52317 .45673 L F
.985 .898 .576 r
.72488 .31751 m .72654 .31605 L .72532 .31467 L F
.72488 .31751 m .7256 .31892 L .72654 .31605 L F
.595 .344 .506 r
.28376 .6 m .28693 .59767 L .28753 .59508 L F
.844 .542 .478 r
.59972 .44445 m .59553 .44048 L .59593 .44411 L F
.97 .801 .375 r
.56268 .41686 m .56148 .41748 L .56244 .41593 L F
.738 .496 0 r
.56222 .41411 m .56291 .41776 L .56268 .41686 L F
.56222 .41411 m .56268 .41686 L .56316 .41478 L F
.97 .801 .375 r
.56268 .41686 m .56244 .41593 L .563 .41502 L F
.738 .496 0 r
.56291 .41776 m .56292 .41781 L .56268 .41686 L F
.953 .916 .738 r
.37964 .59444 m .38249 .59454 L .3806 .59359 L F
.37964 .59444 m .3805 .59735 L .38249 .59454 L F
.947 .894 .743 r
.38197 .59126 m .3806 .59359 L .38249 .59454 L F
.76 .47 .492 r
.26532 .52075 m .26971 .5188 L .26729 .51951 L F
.843 .62 .6 r
.36693 .53901 m .36668 .54218 L .36921 .54241 L F
.916 .615 .458 r
.36706 .54427 m .36921 .54241 L .36668 .54218 L F
.36706 .54427 m .3702 .54585 L .36921 .54241 L F
0 0 0 r
.26971 .5188 m .27217 .51467 L .27057 .51661 L F
.48 .272 .519 r
.43753 .48621 m .44021 .48587 L .43858 .48395 L F
.824 .991 .736 r
.24889 .58687 m .24833 .58919 L .25045 .58774 L F
.24889 .58687 m .24622 .59027 L .24833 .58919 L F
0 0 .105 r
.47941 .57082 m .47973 .57428 L .47951 .57243 L F
.3 .567 .931 r
.48042 .44505 m .48408 .4475 L .48243 .44348 L F
.802 .813 .86 r
.48408 .4475 m .48643 .44427 L .48243 .44348 L F
.769 .398 .353 r
.35007 .55255 m .34852 .55425 L .3459 .55158 L F
.227 0 .245 r
.35155 .55119 m .34852 .55425 L .35007 .55255 L F
.584 .945 .884 r
.52356 .43787 m .51877 .43962 L .52167 .43947 L F
.678 .611 .774 r
.33874 .5612 m .33978 .55707 L .3401 .55877 L F
.789 .525 .539 r
.3401 .55877 m .34016 .56206 L .33874 .5612 L F
.471 .274 .53 r
.3428 .56119 m .3401 .55877 L .34405 .5586 L F
.3428 .56119 m .34016 .56206 L .3401 .55877 L F
.588 .061 0 r
.44783 .45427 m .44621 .45535 L .44373 .45383 L F
.458 .876 .937 r
.44783 .45427 m .44769 .45347 L .44621 .45535 L F
.44783 .45427 m .45049 .45339 L .44769 .45347 L F
.827 .989 .724 r
.50651 .5195 m .50913 .51614 L .50734 .51709 L F
.825 .981 .693 r
.50472 .5206 m .50651 .5195 L .50734 .51709 L F
.93 .715 .59 r
.37923 .56778 m .37857 .57133 L .38072 .57206 L F
.908 .661 .554 r
.37857 .57133 m .3806 .57451 L .38072 .57206 L F
0 0 0 r
.28157 .61746 m .28291 .61665 L .2808 .61426 L F
.814 .431 .328 r
.5975 .37329 m .59968 .376 L .60331 .37529 L F
.891 .752 .701 r
.59968 .376 m .60414 .37448 L .60331 .37529 L F
.201 .362 .802 r
.56566 .37257 m .56427 .37488 L .56239 .37091 L F
.56566 .37257 m .5654 .37446 L .56427 .37488 L F
.163 .244 .702 r
.5654 .37446 m .56661 .37645 L .56427 .37488 L F
.821 .574 .02 r
.5913 .3612 m .59179 .36471 L .59108 .36111 L F
.543 .904 .704 r
.5913 .3612 m .59305 .35954 L .59446 .36056 L F
.5913 .3612 m .59108 .36111 L .59305 .35954 L F
.557 .376 .592 r
.59519 .36335 m .5913 .3612 L .59446 .36056 L F
.59519 .36335 m .59179 .36471 L .5913 .3612 L F
.787 .331 .163 r
.40696 .46138 m .40356 .4591 L .40641 .46023 L F
.216 .126 .533 r
.23741 .54517 m .2394 .54077 L .23653 .54348 L F
.374 0 0 r
.59057 .37219 m .58964 .37366 L .58715 .3729 L F
.183 0 0 r
.59222 .37302 m .59057 .37219 L .59313 .3711 L F
.59222 .37302 m .58964 .37366 L .59057 .37219 L F
0 0 .187 r
.48686 .55544 m .48619 .55813 L .48512 .55865 L F
.11 .14 .611 r
.48512 .55865 m .48619 .55813 L .48689 .56105 L F
.565 .701 .932 r
.6293 .3475 m .63258 .34818 L .63187 .34731 L F
.172 0 .272 r
.28161 .51198 m .27903 .51544 L .27973 .51307 L F
.987 .727 .354 r
.61126 .35789 m .61056 .36026 L .6105 .35717 L F
.61126 .35789 m .61188 .36255 L .61056 .36026 L F
.426 .784 .996 r
.6105 .35717 m .61448 .3578 L .61126 .35789 L F
.243 .357 .781 r
.41351 .53634 m .4143 .5383 L .41509 .53713 L F
0 0 0 r
.4143 .5383 m .41374 .54098 L .41509 .53713 L F
.474 0 0 r
.72523 .30132 m .724 .30128 L .7273 .30236 L F
.352 .528 .89 r
.32066 .59172 m .32457 .59357 L .32361 .5912 L F
.864 .926 .866 r
.59247 .37837 m .59371 .37455 L .59475 .37545 L F
.67 .81 .95 r
.5975 .37329 m .59475 .37545 L .59589 .37226 L F
.919 .546 .123 r
.39124 .53908 m .38997 .538 L .3893 .53557 L F
.975 .718 .48 r
.39135 .54057 m .38997 .538 L .39124 .53908 L F
.566 .838 .491 r
.52749 .47612 m .52469 .47937 L .52593 .47781 L F
.622 .422 .591 r
.52749 .47612 m .52837 .4794 L .52469 .47937 L F
0 0 0 r
.52749 .47612 m .529 .47495 L .53035 .47293 L F
.168 0 .333 r
.53071 .47601 m .52837 .4794 L .52749 .47612 L F
0 0 0 r
.52749 .47612 m .52814 .4764 L .529 .47495 L F
.52749 .47612 m .52593 .47781 L .52814 .4764 L F
.849 .443 0 r
.58648 .39477 m .58617 .39592 L .58483 .39307 L F
.58648 .39477 m .58772 .39777 L .58617 .39592 L F
.891 .909 .831 r
.39985 .57868 m .39624 .58031 L .39768 .57733 L F
.39985 .57868 m .3975 .58161 L .39624 .58031 L F
.894 .656 .571 r
.37538 .56706 m .37905 .56536 L .37572 .56443 L F
.37538 .56706 m .37923 .56778 L .37905 .56536 L F
.592 .479 .694 r
.54379 .41023 m .54457 .4142 L .54137 .41417 L F
.387 .261 .585 r
.54415 .41635 m .54137 .41417 L .54457 .4142 L F
.54415 .41635 m .54207 .41781 L .54137 .41417 L F
.358 .712 .986 r
.45994 .56401 m .45918 .56521 L .45725 .56457 L F
.45994 .56401 m .46197 .56559 L .45918 .56521 L F
.795 .999 .81 r
.47851 .53195 m .47903 .53012 L .48128 .52928 L F
.47851 .53195 m .47726 .53208 L .47903 .53012 L F
.628 .602 .804 r
.55275 .45016 m .55439 .4458 L .55182 .44625 L F
.55275 .45016 m .55494 .44916 L .55439 .4458 L F
.436 .234 .506 r
.32822 .51492 m .33037 .51533 L .33012 .51277 L F
.97 .809 .626 r
.3809 .60029 m .38225 .60063 L .3805 .59735 L F
.3809 .60029 m .38188 .60207 L .38225 .60063 L F
.494 .713 .968 r
.28121 .57354 m .28281 .57523 L .28413 .57315 L F
.28121 .57354 m .28281 .57523 L .28413 .57315 L F
.462 .864 .691 r
.48107 .42076 m .47877 .42225 L .47698 .42309 L F
.887 .89 .828 r
.35485 .54566 m .35066 .54792 L .35319 .54636 L F
.95 .62 .363 r
.38067 .51941 m .379 .52091 L .37842 .51856 L F
.38067 .51941 m .38114 .52212 L .379 .52091 L F
.705 .677 .821 r
.59646 .41721 m .60036 .41909 L .60047 .41781 L F
.032 0 .412 r
.34806 .57851 m .34798 .58133 L .34984 .57966 L F
.847 .987 .713 r
.50913 .51614 m .51106 .51227 L .50981 .51336 L F
.50913 .51614 m .51158 .51271 L .51106 .51227 L F
.877 .986 .713 r
.50734 .51709 m .50913 .51614 L .50981 .51336 L F
.835 .379 0 r
.3975 .58161 m .39734 .58317 L .39624 .58031 L F
.3975 .58161 m .39887 .58433 L .39734 .58317 L F
.801 .988 .886 r
.43539 .57368 m .4336 .57575 L .43101 .576 L F
.84 .73 .743 r
.59151 .3455 m .58792 .34612 L .59032 .34559 L F
.59151 .3455 m .58909 .34979 L .58792 .34612 L F
.508 .872 .984 r
.59032 .34559 m .59465 .34523 L .59151 .3455 L F
.724 .71 .837 r
.60144 .37783 m .5984 .38194 L .59991 .38196 L F
.855 .959 .875 r
.59868 .38152 m .5984 .38194 L .59873 .3815 L F
.716 .728 .86 r
.59991 .38196 m .5984 .38194 L .59868 .38152 L F
.838 .496 .408 r
.59868 .38152 m .60076 .38472 L .59991 .38196 L F
.716 .728 .86 r
.59868 .38152 m .5984 .38194 L .5961 .38059 L F
0 .375 .779 r
.5961 .38059 m .5984 .38194 L .59813 .38171 L F
.838 .496 .408 r
.5961 .38059 m .59813 .38171 L .59868 .38152 L F
0 .375 .779 r
.5961 .38059 m .59813 .38171 L .59683 .38066 L F
.838 .496 .408 r
.5961 .38059 m .59758 .38191 L .59813 .38171 L F
.59758 .38191 m .60076 .38472 L .59868 .38152 L F
.855 .959 .875 r
.6008 .37822 m .59868 .38152 L .60144 .37783 L F
.59868 .38152 m .59873 .3815 L .60144 .37783 L F
.59683 .38066 m .5984 .38194 L .6008 .37822 L F
.724 .71 .837 r
.60144 .37783 m .59991 .38196 L .60275 .38154 L F
.645 .425 .569 r
.59991 .38196 m .60076 .38472 L .60275 .38154 L F
.617 .954 .914 r
.6706 .31608 m .67251 .31411 L .67246 .31464 L F
.6706 .31608 m .66852 .31599 L .67251 .31411 L F
.307 .787 .914 r
.31451 .52546 m .31588 .52561 L .31305 .526 L F
.524 .259 .455 r
.31588 .52561 m .31536 .52807 L .31305 .526 L F
.19 .251 .696 r
.31305 .526 m .31536 .52807 L .31451 .52546 L F
.717 .766 .891 r
.33704 .65081 m .34028 .65068 L .33902 .64834 L F
.774 .776 .854 r
.34028 .65068 m .34177 .64694 L .33902 .64834 L F
.34028 .65068 m .34356 .6481 L .34177 .64694 L F
0 0 0 r
.66651 .32905 m .66543 .32994 L .6626 .33081 L F
.627 .226 .263 r
.6693 .32826 m .66543 .32994 L .66651 .32905 L F
.139 0 0 r
.53184 .42284 m .53621 .42015 L .53498 .4207 L F
.113 .625 .893 r
.53621 .42015 m .53788 .41975 L .53498 .4207 L F
.53621 .42015 m .53893 .42041 L .53788 .41975 L F
.701 .895 .967 r
.70568 .32461 m .70683 .32586 L .70919 .32433 L F
.518 0 0 r
.3865 .48674 m .38977 .48861 L .3869 .4877 L F
.532 .441 .698 r
.38894 .48595 m .38977 .48861 L .3865 .48674 L F
.518 0 0 r
.3865 .48674 m .3869 .4877 L .38894 .48595 L F
0 .226 .747 r
.56133 .37827 m .56152 .37631 L .55927 .37481 L F
0 0 .304 r
.56133 .37827 m .56224 .3788 L .56152 .37631 L F
.56133 .37827 m .56176 .38102 L .56224 .3788 L F
.76 .687 .782 r
.47611 .53609 m .47325 .53913 L .47087 .53769 L F
0 0 0 r
.62272 .39206 m .61906 .39433 L .62238 .39454 L F
.084 0 .18 r
.62538 .38872 m .62272 .39206 L .62491 .39072 L F
.28 .067 .402 r
.6246 .39323 m .62272 .39206 L .62238 .39454 L F
.6246 .39323 m .62491 .39072 L .62272 .39206 L F
.373 .349 .703 r
.2316 .56157 m .23182 .56617 L .23434 .56392 L F
.516 .468 .742 r
.23269 .56833 m .23434 .56392 L .23182 .56617 L F
.745 .372 .346 r
.6812 .30763 m .68497 .30631 L .68237 .30583 L F
.928 .679 .54 r
.35731 .52467 m .35961 .5227 L .35656 .5215 L F
.35731 .52467 m .35953 .5256 L .35961 .5227 L F
.946 .81 .36 r
.67648 .33978 m .67701 .34243 L .67652 .34484 L F
.549 .811 .994 r
.46634 .4468 m .47245 .44683 L .47076 .44735 L F
0 0 0 r
.47076 .44735 m .47245 .44683 L .47313 .44664 L F
.127 0 0 r
.4443 .59765 m .44848 .59833 L .4471 .59812 L F
.508 .906 .924 r
.4471 .59812 m .44848 .59833 L .45087 .59731 L F
.516 .244 .44 r
.53441 .39786 m .53733 .39739 L .53815 .39501 L F
.53815 .39501 m .53733 .39739 L .53441 .39786 L F
.314 .052 .347 r
.53815 .39501 m .53969 .3964 L .53969 .39379 L F
.53815 .39501 m .53733 .39739 L .53969 .3964 L F
.53969 .3964 m .53815 .39501 L .53969 .39379 L F
.53969 .3964 m .53733 .39739 L .53815 .39501 L F
.834 .694 .708 r
.37657 .60711 m .38093 .60382 L .3796 .60263 L F
.37657 .60711 m .37914 .60829 L .38093 .60382 L F
.902 .907 .817 r
.3796 .60263 m .38093 .60382 L .38188 .60207 L F
.711 .964 .941 r
.64182 .38818 m .63757 .38932 L .64047 .38703 L F
.525 .36 .599 r
.64182 .38818 m .64455 .38767 L .6431 .3858 L F
.801 .308 0 r
.64455 .38767 m .6431 .3858 L .64182 .38818 L F
.349 0 .135 r
.36068 .55533 m .35668 .55565 L .35875 .55432 L F
.36068 .55533 m .35695 .55785 L .35668 .55565 L F
.36068 .55533 m .35901 .55754 L .35695 .55785 L F
.655 .291 .343 r
.36068 .55533 m .36175 .55658 L .35901 .55754 L F
0 0 0 r
.26917 .52054 m .26732 .52253 L .26971 .5188 L F
0 0 .005 r
.26971 .5188 m .26778 .5223 L .26917 .52054 L F
0 0 .256 r
.268 .52277 m .26732 .52253 L .26917 .52054 L F
.755 .95 .63 r
.26917 .52054 m .26778 .5223 L .2689 .52066 L F
.561 .098 .111 r
.27099 .51877 m .27034 .51936 L .26971 .5188 L F
.27418 .51871 m .27204 .52086 L .27034 .51936 L F
.27418 .51871 m .27034 .51936 L .27099 .51877 L F
0 .13 .667 r
.26971 .5188 m .27204 .52086 L .27096 .51766 L F
.755 .95 .63 r
.26934 .52027 m .2689 .52066 L .27096 .51766 L F
.26917 .52054 m .2689 .52066 L .26934 .52027 L F
.46 0 0 r
.27641 .51937 m .27204 .52086 L .27418 .51871 L F
.608 .678 .89 r
.6439 .38313 m .6431 .3858 L .64083 .38393 L F
.056 .206 .704 r
.6458 .38588 m .6431 .3858 L .6439 .38313 L F
.6458 .38588 m .64455 .38767 L .6431 .3858 L F
.113 0 .038 r
.67616 .30989 m .67543 .3113 L .67857 .30868 L F
.723 .894 .957 r
.36082 .61315 m .35928 .61614 L .35884 .61392 L F
.36082 .61315 m .36262 .61427 L .35928 .61614 L F
.927 .658 .51 r
.39733 .55148 m .39506 .54785 L .39688 .54892 L F
0 0 0 r
.67338 .31288 m .67246 .31464 L .67543 .3113 L F
.593 .641 .868 r
.56164 .42842 m .56439 .42774 L .56262 .42601 L F
.56262 .42601 m .56439 .42774 L .56164 .42842 L F
.896 .488 .22 r
.4212 .57679 m .42203 .57404 L .42309 .57433 L F
.83 .913 .894 r
.51829 .39418 m .51715 .39526 L .51766 .39216 L F
.865 .942 .867 r
.51715 .39526 m .51593 .39411 L .51766 .39216 L F
.639 .962 .807 r
.45447 .43758 m .45035 .4399 L .45247 .43854 L F
.459 .864 .693 r
.4566 .43619 m .45447 .43758 L .45247 .43854 L F
.536 .746 .972 r
.46634 .4468 m .4673 .44436 L .46495 .44575 L F
.46634 .4468 m .47076 .44735 L .4673 .44436 L F
.273 .731 .953 r
.59697 .3433 m .60094 .34393 L .59824 .34415 L F
.976 .694 .299 r
.59553 .44048 m .59419 .4366 L .59507 .43887 L F
.437 .63 .936 r
.59198 .44251 m .59553 .44048 L .59507 .43887 L F
.59198 .44251 m .59488 .44338 L .59553 .44048 L F
.893 .632 .537 r
.59488 .44338 m .59593 .44411 L .59553 .44048 L F
.735 .551 0 r
.35455 .54218 m .35463 .54391 L .35647 .54161 L F
.368 .292 .638 r
.23388 .55829 m .23572 .55374 L .23369 .55557 L F
.864 .926 .866 r
.59247 .37837 m .59107 .37729 L .59371 .37455 L F
.604 .578 .797 r
.59467 .38095 m .59107 .37729 L .59247 .37837 L F
.733 .308 .241 r
.5961 .38059 m .59467 .38095 L .59247 .37837 L F
.713 .96 .945 r
.63626 .4018 m .6384 .402 L .64054 .4005 L F
.829 .455 .348 r
.40418 .51128 m .40602 .50943 L .40425 .50983 L F
.40418 .51128 m .4078 .51219 L .40602 .50943 L F
.862 .989 .838 r
.62239 .41312 m .62326 .41411 L .62601 .41083 L F
.796 .776 .834 r
.63187 .34731 m .63258 .34818 L .63594 .34558 L F
.865 .885 .849 r
.40808 .59301 m .40774 .59051 L .40936 .59159 L F
.637 .921 .977 r
.38069 .46034 m .37903 .4598 L .38185 .45793 L F
.624 .092 0 r
.38344 .46068 m .38202 .46147 L .37962 .46013 L F
.637 .921 .977 r
.38069 .46034 m .38093 .45984 L .38148 .45972 L F
.624 .092 0 r
.38344 .46068 m .37903 .4598 L .38069 .46034 L F
.38013 .46002 m .37962 .46013 L .37903 .4598 L F
.38344 .46068 m .37962 .46013 L .38013 .46002 L F
.637 .921 .977 r
.38148 .45972 m .38185 .45793 L .38279 .45868 L F
.38093 .45984 m .38185 .45793 L .38148 .45972 L F
0 .326 .697 r
.61345 .40026 m .60959 .39866 L .60862 .39806 L F
.703 .426 .502 r
.35565 .53892 m .35233 .54114 L .35349 .53889 L F
.857 .964 .871 r
.32563 .53632 m .32331 .53787 L .32234 .53723 L F
.32563 .53632 m .32369 .53686 L .32348 .53763 L F
.32369 .53686 m .3221 .53729 L .32348 .53763 L F
0 .489 .834 r
.32203 .53702 m .32213 .53667 L .32348 .53763 L F
.857 .964 .871 r
.32331 .53787 m .3224 .53847 L .32234 .53723 L F
0 .489 .834 r
.32203 .53702 m .32348 .53763 L .3221 .53729 L F
.915 .753 .667 r
.32213 .53667 m .32309 .53906 L .32348 .53763 L F
.32309 .53906 m .32369 .54055 L .32348 .53763 L F
0 .489 .834 r
.31927 .53585 m .32104 .53636 L .32203 .53702 L F
.32104 .53636 m .32213 .53667 L .32203 .53702 L F
.857 .964 .871 r
.32234 .53723 m .3224 .53847 L .3221 .53729 L F
.3224 .53847 m .32152 .53906 L .3221 .53729 L F
0 .489 .834 r
.31927 .53585 m .32203 .53702 L .3221 .53729 L F
.915 .948 .805 r
.55967 .37058 m .55896 .36833 L .56239 .37091 L F
.55967 .37058 m .55814 .37037 L .55896 .36833 L F
.885 .58 .465 r
.58138 .42785 m .57798 .42371 L .57976 .42649 L F
.909 .507 .118 r
.58202 .42996 m .58138 .42785 L .57976 .42649 L F
.814 .897 .901 r
.24366 .57051 m .23945 .5713 L .24166 .57027 L F
.272 .38 .791 r
.24436 .56695 m .24366 .57051 L .24166 .57027 L F
.24436 .56695 m .24601 .57087 L .24366 .57051 L F
.194 0 .057 r
.5377 .4103 m .53408 .41324 L .53689 .41263 L F
.5 0 0 r
.53956 .41191 m .5377 .4103 L .53689 .41263 L F
.53956 .41191 m .54026 .41158 L .5377 .4103 L F
.939 .811 .692 r
.57319 .40927 m .57142 .41228 L .57467 .41093 L F
.762 .99 .771 r
.51072 .49551 m .51299 .49243 L .5137 .49217 L F
.51072 .49551 m .51015 .49526 L .51299 .49243 L F
.799 .444 .385 r
.35108 .52578 m .34865 .52783 L .34767 .52567 L F
.786 .424 .371 r
.35214 .52822 m .34865 .52783 L .35108 .52578 L F
.682 .967 .931 r
.4903 .41442 m .48566 .41596 L .48905 .41354 L F
.85 .959 .879 r
.4903 .41442 m .49038 .41158 L .49388 .41136 L F
.4903 .41442 m .48905 .41354 L .49038 .41158 L F
.888 .489 .259 r
.39525 .54512 m .39135 .54057 L .39546 .54237 L F
.479 .898 .861 r
.25341 .62449 m .2481 .62619 L .25094 .62576 L F
.962 .731 .544 r
.25094 .62576 m .25306 .62739 L .25341 .62449 L F
0 0 0 r
.54597 .47507 m .54484 .47474 L .54342 .47499 L F
.942 .849 .416 r
.39798 .57452 m .39786 .57154 L .39925 .57325 L F
.822 .836 .366 r
.70791 .29893 m .70771 .30062 L .7083 .29983 L F
0 .121 .651 r
.70791 .29893 m .70805 .30042 L .70771 .30062 L F
.70805 .30042 m .70842 .30413 L .70771 .30062 L F
0 0 0 r
.70771 .30062 m .70518 .30283 L .70711 .30098 L F
.70771 .30062 m .70711 .30098 L .7083 .29983 L F
.378 .404 .761 r
.70771 .30062 m .70842 .30413 L .70518 .30283 L F
.796 .776 .834 r
.63187 .34731 m .63594 .34558 L .63494 .34508 L F
.753 .715 .816 r
.34904 .55583 m .35117 .55906 L .34738 .55821 L F
.683 .973 .915 r
.35117 .55906 m .34696 .56053 L .34738 .55821 L F
.701 .618 .761 r
.35406 .55853 m .35117 .55906 L .35355 .55656 L F
.616 .573 .783 r
.35525 .56277 m .35117 .55906 L .35406 .55853 L F
.921 .694 .579 r
.36423 .54125 m .36693 .53901 L .36482 .53788 L F
.36423 .54125 m .36668 .54218 L .36693 .53901 L F
.843 .687 .689 r
.3806 .57451 m .38216 .57836 L .38273 .57549 L F
.445 .074 .24 r
.32645 .65922 m .32452 .65774 L .32383 .65994 L F
.32452 .65774 m .3245 .65772 L .32428 .65844 L F
.32452 .65774 m .32428 .65844 L .32383 .65994 L F
.335 0 .198 r
.32124 .66029 m .32428 .65844 L .32377 .65995 L F
.445 .074 .24 r
.32383 .65994 m .3245 .65772 L .32377 .65995 L F
.335 0 .198 r
.32428 .65844 m .32454 .65828 L .32377 .65995 L F
.339 0 .203 r
.32428 .65844 m .3245 .65772 L .32454 .65828 L F
.32124 .66029 m .3245 .65772 L .32428 .65844 L F
.336 0 .199 r
.32377 .65995 m .3245 .65772 L .32124 .66029 L F
.463 .066 .2 r
.32454 .65828 m .3245 .65772 L .32645 .65922 L F
.825 .622 .628 r
.32708 .59712 m .33133 .59484 L .32774 .59444 L F
.32708 .59712 m .33038 .59785 L .33133 .59484 L F
0 0 .078 r
.33133 .59484 m .33217 .59583 L .33216 .59307 L F
.33133 .59484 m .33038 .59785 L .33217 .59583 L F
.863 .734 .719 r
.25902 .52755 m .2605 .5219 L .25967 .52243 L F
.643 .967 .868 r
.54633 .48329 m .54207 .48516 L .54285 .48551 L F
.54633 .48329 m .54554 .48303 L .54207 .48516 L F
.68 .978 .852 r
.54755 .48139 m .54633 .48329 L .54813 .48164 L F
.679 .978 .857 r
.54755 .48139 m .54554 .48303 L .54633 .48329 L F
0 0 0 r
.39461 .49846 m .39326 .50294 L .39605 .49947 L F
.39461 .49846 m .39411 .5011 L .39326 .50294 L F
0 0 .341 r
.3948 .50362 m .39326 .50294 L .39411 .5011 L F
.3948 .50362 m .39325 .50563 L .39326 .50294 L F
.618 .864 .989 r
.60446 .4079 m .60852 .40798 L .60746 .40705 L F
.847 .968 .877 r
.6097 .4049 m .60852 .40798 L .611 .40686 L F
.6097 .4049 m .60746 .40705 L .60852 .40798 L F
.807 .999 .837 r
.51158 .51271 m .51226 .51029 L .51106 .51227 L F
.51158 .51271 m .51467 .50979 L .51226 .51029 L F
.904 .742 .671 r
.37157 .55459 m .37357 .5555 L .37229 .55153 L F
.9 .606 .478 r
.3714 .55702 m .37357 .5555 L .37157 .55459 L F
.3714 .55702 m .37363 .55811 L .37357 .5555 L F
.807 .892 .904 r
.32706 .52758 m .3254 .52938 L .3242 .52672 L F
0 0 .546 r
.32596 .53046 m .3242 .52672 L .3254 .52938 L F
.891 .752 .701 r
.59968 .376 m .60144 .37783 L .60414 .37448 L F
.551 .039 0 r
.60414 .37448 m .60783 .3753 L .60456 .3748 L F
.198 .256 .698 r
.52816 .43883 m .52642 .44061 L .52566 .43661 L F
.086 0 .337 r
.5284 .44155 m .52642 .44061 L .52816 .43883 L F
.5284 .44155 m .52608 .44296 L .52642 .44061 L F
.49 .796 .999 r
.33727 .54811 m .34133 .54911 L .3388 .5477 L F
.632 .564 .76 r
.3382 .54365 m .34038 .54718 L .34232 .54698 L F
.521 .809 .998 r
.3407 .54715 m .34133 .54911 L .34232 .54698 L F
.632 .564 .76 r
.34038 .54718 m .34121 .54852 L .34232 .54698 L F
.521 .809 .998 r
.34068 .54708 m .3407 .54715 L .34232 .54698 L F
.507 .511 .796 r
.33727 .54811 m .34043 .54727 L .3382 .54365 L F
.521 .809 .998 r
.338 .54725 m .3388 .5477 L .34068 .54708 L F
.3388 .5477 m .34133 .54911 L .34068 .54708 L F
.507 .511 .796 r
.3388 .5477 m .34121 .54852 L .34043 .54727 L F
.33727 .54811 m .3375 .54813 L .3388 .5477 L F
.3375 .54813 m .34121 .54852 L .3388 .5477 L F
.49 .796 .999 r
.33727 .54811 m .3388 .5477 L .338 .54725 L F
.732 .684 .804 r
.3382 .54365 m .34342 .5454 L .34089 .54054 L F
.701 .876 .482 r
.34311 .54593 m .34133 .54911 L .344 .54475 L F
.34181 .54806 m .34133 .54911 L .34311 .54593 L F
0 0 0 r
.34335 .54591 m .34232 .54698 L .34311 .54593 L F
.632 .564 .76 r
.34373 .54551 m .34232 .54698 L .34388 .54556 L F
0 0 0 r
.34344 .5459 m .34232 .54698 L .34335 .54591 L F
.34427 .54515 m .34382 .54545 L .344 .54475 L F
.34382 .54545 m .34311 .54593 L .34344 .54549 L F
.34382 .54545 m .34344 .54549 L .344 .54475 L F
.096 .342 .813 r
.34089 .54054 m .34382 .54545 L .34366 .54219 L F
.34382 .54545 m .34388 .54556 L .34387 .54545 L F
.34382 .54545 m .34387 .54545 L .34366 .54219 L F
.632 .564 .76 r
.3382 .54365 m .34232 .54698 L .34373 .54551 L F
.736 .96 .674 r
.34382 .54554 m .34232 .54698 L .34303 .54537 L F
.34388 .54556 m .34232 .54698 L .34382 .54554 L F
0 0 0 r
.34472 .54581 m .34232 .54698 L .34344 .5459 L F
.732 .684 .804 r
.34373 .54551 m .34388 .54556 L .34382 .54545 L F
0 0 0 r
.34472 .54581 m .34311 .54593 L .34427 .54515 L F
.732 .684 .804 r
.34342 .5454 m .34373 .54551 L .34361 .5451 L F
.34373 .54551 m .34382 .54545 L .34361 .5451 L F
.34342 .5454 m .34361 .5451 L .34089 .54054 L F
.701 .876 .482 r
.34232 .54698 m .34181 .54806 L .34311 .54593 L F
.677 .914 .975 r
.36455 .55874 m .36085 .55912 L .36175 .55658 L F
0 0 0 r
.66018 .37787 m .65671 .38074 L .65791 .37902 L F
.66207 .37754 m .66018 .37787 L .65791 .37902 L F
.66207 .37754 m .66299 .37714 L .66018 .37787 L F
.647 .934 .673 r
.57062 .45925 m .57218 .45789 L .57053 .45892 L F
0 0 0 r
.57053 .45892 m .57218 .45789 L .57423 .45672 L F
.839 .405 .2 r
.36238 .50331 m .36053 .50447 L .35883 .50165 L F
.77 .3 .124 r
.36287 .50485 m .36053 .50447 L .36238 .50331 L F
.688 .52 .654 r
.25638 .59796 m .25781 .59418 L .25606 .59485 L F
.25638 .59796 m .25718 .59986 L .25781 .59418 L F
.572 .501 .736 r
.35803 .56163 m .35525 .56277 L .35406 .55853 L F
.536 .382 .619 r
.29319 .54574 m .29587 .54529 L .29569 .54213 L F
.413 .133 .376 r
.29289 .54818 m .29587 .54529 L .29319 .54574 L F
.536 .382 .619 r
.29569 .54213 m .29587 .54529 L .29319 .54574 L F
.413 .133 .376 r
.29289 .54818 m .29587 .54529 L .29319 .54574 L F
.536 .382 .619 r
.29319 .54574 m .29587 .54529 L .29569 .54213 L F
.558 .934 .843 r
.67897 .3764 m .68311 .3747 L .68263 .37451 L F
.606 .95 .811 r
.68311 .3747 m .68656 .3725 L .68483 .37285 L F
.605 .949 .802 r
.68263 .37451 m .68311 .3747 L .68483 .37285 L F
.571 .47 .7 r
.25586 .52909 m .25833 .53127 L .25902 .52755 L F
0 .233 .742 r
.25615 .52815 m .25586 .52909 L .25256 .53011 L F
.613 .942 .946 r
.25618 .52832 m .25615 .52815 L .25256 .53011 L F
.797 .841 .884 r
.25886 .52704 m .25615 .52815 L .25822 .52673 L F
.613 .942 .946 r
.25828 .52728 m .25615 .52815 L .25618 .52832 L F
.863 .734 .719 r
.25902 .52755 m .26051 .52673 L .2605 .5219 L F
.247 .166 .564 r
.25902 .52755 m .25833 .53127 L .2602 .52769 L F
.797 .841 .884 r
.2602 .52769 m .2567 .52809 L .25886 .52704 L F
0 .233 .742 r
.25618 .52832 m .25833 .53127 L .25635 .52953 L F
.25615 .52815 m .25628 .52833 L .25618 .52832 L F
.25628 .52833 m .25833 .53127 L .25618 .52832 L F
.328 0 .086 r
.25243 .53028 m .25624 .52833 L .25256 .53011 L F
.797 .841 .884 r
.2602 .52769 m .25833 .53127 L .25628 .52833 L F
.328 0 .086 r
.25624 .52833 m .2567 .52809 L .25618 .52832 L F
.2567 .52809 m .25706 .52788 L .25618 .52832 L F
.797 .841 .884 r
.2567 .52809 m .25628 .52833 L .25615 .52815 L F
.2602 .52769 m .25628 .52833 L .2567 .52809 L F
.328 0 .086 r
.2567 .52809 m .25828 .52728 L .25706 .52788 L F
.25624 .52833 m .25618 .52832 L .25256 .53011 L F
0 .233 .742 r
.2561 .52831 m .25635 .52953 L .25586 .52909 L F
.25615 .52815 m .25618 .52832 L .2561 .52831 L F
.25618 .52832 m .25635 .52953 L .2561 .52831 L F
.328 0 .086 r
.25107 .53207 m .25662 .52838 L .25243 .53028 L F
.797 .841 .884 r
.2567 .52809 m .25828 .52728 L .25886 .52704 L F
.328 0 .086 r
.25662 .52838 m .25828 .52728 L .25624 .52833 L F
.25662 .52838 m .25624 .52833 L .25243 .53028 L F
.25406 .53008 m .25857 .52714 L .25828 .52728 L F
.25417 .53003 m .25857 .52714 L .25406 .53008 L F
.613 .942 .946 r
.25857 .52714 m .25615 .52815 L .25828 .52728 L F
.481 .403 .691 r
.26051 .52673 m .26263 .5213 L .2605 .5219 L F
.247 .166 .564 r
.25902 .52755 m .2602 .52769 L .26051 .52673 L F
.493 .837 .997 r
.2602 .52769 m .25822 .52673 L .26241 .52694 L F
.699 .815 .937 r
.26241 .52694 m .25822 .52673 L .26093 .52531 L F
.999 .803 .459 r
.25857 .52714 m .25822 .52673 L .25615 .52815 L F
.328 0 .086 r
.25107 .53207 m .25354 .53166 L .25857 .52714 L F
.797 .841 .884 r
.2567 .52809 m .25615 .52815 L .25828 .52728 L F
.767 .474 .491 r
.25857 .52714 m .25354 .53166 L .25778 .53197 L F
0 0 0 r
.25857 .52714 m .25354 .53166 L .25716 .52894 L F
.999 .803 .459 r
.25857 .52714 m .25716 .52894 L .25822 .52673 L F
.767 .474 .491 r
.25857 .52714 m .25778 .53197 L .25716 .52894 L F
.137 0 .019 r
.25736 .52852 m .26093 .52531 L .25822 .52673 L F
.25716 .52894 m .25782 .52831 L .25736 .52852 L F
.25782 .52831 m .26093 .52531 L .25736 .52852 L F
.328 0 .086 r
.25107 .53207 m .25417 .53003 L .25406 .53008 L F
.646 .885 .536 r
.32243 .62333 m .32401 .62165 L .32241 .6236 L F
.868 .995 .801 r
.32241 .6236 m .32034 .6263 L .3192 .62603 L F
.32241 .6236 m .3192 .62603 L .32097 .62556 L F
.822 .93 .553 r
.32139 .62459 m .32243 .62333 L .32097 .62556 L F
.969 .706 .48 r
.32219 .62011 m .3239 .62156 L .32243 .62333 L F
0 0 .17 r
.32219 .62011 m .32243 .62333 L .32269 .62154 L F
.822 .93 .553 r
.32269 .62154 m .32243 .62333 L .32139 .62459 L F
.969 .706 .48 r
.3239 .62156 m .32401 .62165 L .32243 .62333 L F
.397 .015 .192 r
.54732 .40825 m .54646 .40989 L .54379 .41023 L F
.107 0 .043 r
.54947 .40717 m .54646 .40989 L .54732 .40825 L F
.735 .967 .935 r
.49388 .41136 m .49443 .40923 L .49467 .40996 L F
.49388 .41136 m .49038 .41158 L .49443 .40923 L F
.523 .289 .501 r
.32361 .5912 m .32705 .59123 L .32718 .58823 L F
.633 .4 .547 r
.32361 .5912 m .3275 .59323 L .32705 .59123 L F
.32361 .5912 m .32457 .59357 L .3275 .59323 L F
.738 .496 0 r
.56222 .41411 m .56314 .41477 L .56533 .41146 L F
.855 .86 .844 r
.56139 .41056 m .56297 .41493 L .55867 .41388 L F
.56297 .41493 m .563 .41502 L .56291 .415 L F
.56297 .41493 m .56291 .415 L .55867 .41388 L F
.738 .496 0 r
.56314 .41477 m .56315 .41478 L .56323 .41468 L F
0 .269 .771 r
.56533 .41146 m .56705 .41232 L .56426 .4104 L F
0 .223 .709 r
.56426 .4104 m .56705 .41232 L .56561 .41084 L F
.775 .825 .892 r
.56561 .41084 m .56315 .41478 L .56139 .41056 L F
.56315 .41478 m .563 .41502 L .56297 .41493 L F
.56315 .41478 m .56297 .41493 L .56139 .41056 L F
.782 .856 .905 r
.56705 .41232 m .563 .41502 L .56315 .41478 L F
.738 .496 0 r
.56315 .41478 m .56317 .41477 L .56323 .41468 L F
.56314 .41477 m .56323 .41468 L .56533 .41146 L F
.35 .016 .251 r
.56533 .41146 m .56317 .41477 L .56705 .41232 L F
.782 .856 .905 r
.56705 .41232 m .56315 .41478 L .5666 .41185 L F
.35 .016 .251 r
.56317 .41477 m .56316 .41478 L .56705 .41232 L F
.782 .856 .905 r
.5666 .41185 m .56317 .41477 L .56561 .41084 L F
.56317 .41477 m .56315 .41478 L .56315 .41478 L F
.56317 .41477 m .56315 .41478 L .56561 .41084 L F
.738 .496 0 r
.56315 .41478 m .56316 .41478 L .56317 .41477 L F
.703 .733 .874 r
.32113 .64697 m .32273 .64997 L .32509 .6476 L F
.645 .63 .821 r
.32273 .64997 m .32667 .65122 L .32509 .6476 L F
.605 .4 .577 r
.69189 .30573 m .69505 .3053 L .69517 .30277 L F
.433 .284 .577 r
.69517 .30277 m .69753 .30176 L .6974 .29906 L F
.56 .426 .655 r
.69505 .3053 m .69753 .30176 L .69517 .30277 L F
.792 .816 .871 r
.61988 .35421 m .62138 .35594 L .62367 .35424 L F
.61988 .35421 m .62138 .35594 L .62367 .35424 L F
.372 .834 .903 r
.44975 .56516 m .44798 .56544 L .44649 .56534 L F
.44975 .56516 m .44649 .56534 L .44935 .56519 L F
.478 .818 .999 r
.45144 .56301 m .44975 .56516 L .44935 .56519 L F
.45144 .56301 m .45329 .56407 L .44975 .56516 L F
.63 .593 .793 r
.23269 .56833 m .23469 .57268 L .23684 .57147 L F
0 0 .248 r
.23469 .57268 m .23581 .57327 L .23684 .57147 L F
.23469 .57268 m .23432 .57465 L .23581 .57327 L F
.025 .309 .799 r
.40236 .50842 m .40171 .51008 L .4009 .50695 L F
.447 .028 .15 r
.40171 .51008 m .40418 .51128 L .40425 .50983 L F
.025 .309 .799 r
.40236 .50842 m .40418 .51128 L .40171 .51008 L F
.449 .804 .997 r
.60384 .35514 m .60217 .35398 L .5997 .35457 L F
.44 .68 .966 r
.60384 .35514 m .60508 .35304 L .60217 .35398 L F
.439 .822 .989 r
.64736 .38709 m .64847 .38792 L .64455 .38767 L F
.668 .971 .906 r
.65052 .38647 m .64847 .38792 L .6498 .38595 L F
.614 .91 .982 r
.6498 .38595 m .64847 .38792 L .64736 .38709 L F
.536 .13 .218 r
.64115 .34366 m .63721 .34429 L .63851 .34218 L F
.531 .141 .246 r
.64156 .34211 m .64115 .34366 L .63851 .34218 L F
.793 .542 .558 r
.25725 .62723 m .26009 .62732 L .25971 .62431 L F
.25 0 0 r
.33413 .53387 m .33297 .53423 L .33106 .53421 L F
.736 .412 .433 r
.33254 .53409 m .33106 .53421 L .3335 .53424 L F
.816 .682 .716 r
.33274 .5343 m .33091 .53483 L .33254 .53409 L F
.33611 .53804 m .33096 .53486 L .33274 .5343 L F
.33096 .53486 m .33091 .53483 L .33274 .5343 L F
.25 0 0 r
.33518 .53325 m .33413 .53387 L .33106 .53421 L F
.33413 .53387 m .3335 .53424 L .33297 .53423 L F
.853 .842 .833 r
.28949 .5858 m .28479 .587 L .28969 .58437 L F
.588 .919 .693 r
.48128 .52928 m .48262 .5277 L .48288 .52783 L F
.593 .944 .801 r
.48128 .52928 m .47903 .53012 L .48262 .5277 L F
.507 .226 .423 r
.50697 .41693 m .51008 .41662 L .51088 .41378 L F
.804 .741 .794 r
.50926 .41045 m .51088 .41378 L .51304 .41063 L F
.238 .02 .367 r
.51304 .41063 m .51088 .41378 L .51282 .41312 L F
.21 0 .299 r
.51088 .41378 m .51008 .41662 L .51282 .41312 L F
.537 0 0 r
.39605 .49947 m .39678 .50044 L .39461 .49846 L F
.39605 .49947 m .39842 .50165 L .39678 .50044 L F
.401 .363 .701 r
.25172 .54805 m .25037 .55155 L .24929 .5492 L F
.25172 .54805 m .25237 .55173 L .25037 .55155 L F
.073 .362 .831 r
.25216 .62943 m .25392 .63191 L .25654 .63251 L F
.974 .85 .657 r
.55713 .45895 m .55444 .46212 L .55628 .45839 L F
.701 .905 .547 r
.4261 .45856 m .42515 .46043 L .4267 .45827 L F
0 0 0 r
.42665 .45873 m .42536 .4589 L .4261 .45856 L F
.32 .801 .743 r
.4261 .45856 m .42415 .45906 L .4216 .46004 L F
0 0 0 r
.42536 .4589 m .42415 .45906 L .4261 .45856 L F
.701 .905 .547 r
.4261 .45856 m .4267 .45827 L .42767 .45693 L F
.726 .511 0 r
.33564 .53516 m .33611 .53804 L .33254 .53409 L F
.42 .748 .994 r
.33681 .53712 m .3408 .53912 L .33624 .53881 L F
.33681 .53712 m .33624 .53881 L .33611 .53809 L F
.298 .78 .915 r
.33623 .5393 m .33623 .5393 L .33611 .53804 L F
0 0 .107 r
.33623 .5393 m .33609 .5398 L .33623 .53931 L F
.33562 .53876 m .33597 .53953 L .33623 .5393 L F
.33597 .53953 m .33609 .5398 L .33623 .5393 L F
.33562 .53876 m .33623 .53931 L .33623 .5393 L F
.298 .78 .915 r
.33612 .53812 m .33608 .53805 L .33611 .53804 L F
.42 .748 .994 r
.33609 .53812 m .33624 .53881 L .33562 .53876 L F
.298 .78 .915 r
.33623 .5393 m .33609 .53812 L .33612 .53812 L F
.33609 .53812 m .33608 .53805 L .33612 .53812 L F
.42 .748 .994 r
.33611 .53809 m .33612 .53812 L .33609 .53812 L F
.33612 .53812 m .33624 .53881 L .33609 .53812 L F
0 0 .107 r
.33562 .53876 m .33623 .5393 L .33611 .53809 L F
.33597 .53953 m .33535 .54306 L .33609 .5398 L F
.33562 .53876 m .33553 .54024 L .33597 .53953 L F
.33553 .54024 m .33535 .54306 L .33597 .53953 L F
.298 .78 .915 r
.33623 .5393 m .33559 .53822 L .33608 .53805 L F
.33623 .5393 m .33559 .53822 L .33623 .5393 L F
.33623 .5393 m .33457 .53858 L .33559 .53822 L F
.816 .682 .716 r
.33611 .53804 m .33008 .53752 L .33091 .53483 L F
.639 .136 .037 r
.33611 .53804 m .33235 .53935 L .33008 .53752 L F
.988 .766 .374 r
.3337 .53499 m .33454 .53857 L .33623 .5393 L F
0 0 .107 r
.33623 .5393 m .33623 .53931 L .33623 .5393 L F
.726 .511 0 r
.33611 .53809 m .33623 .5393 L .33612 .53812 L F
.992 .85 .494 r
.33623 .5393 m .33562 .53788 L .33597 .53765 L F
.726 .511 0 r
.33623 .5393 m .33623 .5393 L .33611 .53809 L F
.704 .82 .937 r
.34012 .53671 m .3408 .53912 L .33681 .53712 L F
.34012 .53671 m .33681 .53712 L .33923 .53631 L F
.497 .417 .696 r
.33964 .53647 m .33719 .5385 L .33719 .5385 L F
.06 0 0 r
.33681 .53712 m .33758 .53723 L .33923 .53631 L F
.497 .417 .696 r
.33899 .53701 m .33623 .5393 L .33699 .53732 L F
.06 0 0 r
.33758 .53723 m .3388 .53684 L .33923 .53631 L F
.497 .417 .696 r
.33879 .53684 m .33699 .53732 L .33758 .53579 L F
.33899 .53701 m .33861 .53707 L .33879 .53684 L F
.33861 .53707 m .33699 .53732 L .33879 .53684 L F
.06 0 0 r
.33758 .53723 m .33788 .53727 L .33874 .53686 L F
.33788 .53727 m .33794 .53728 L .33874 .53686 L F
.33874 .53686 m .33794 .53728 L .3388 .53684 L F
.33681 .53712 m .33634 .53742 L .33758 .53723 L F
0 0 .107 r
.33611 .53809 m .33623 .5393 L .33681 .53712 L F
.726 .511 0 r
.33583 .53654 m .33623 .5393 L .33611 .53809 L F
.33564 .53516 m .33583 .53654 L .33596 .53722 L F
.33596 .5371 m .33596 .53722 L .33611 .53804 L F
.33564 .53516 m .33596 .53722 L .33596 .5371 L F
.33583 .53654 m .33612 .53812 L .33611 .53804 L F
.497 .417 .696 r
.33646 .53543 m .33623 .5393 L .33564 .53516 L F
.992 .85 .494 r
.33623 .5393 m .33634 .53742 L .33681 .53712 L F
.497 .417 .696 r
.33758 .53579 m .33623 .5393 L .33646 .53543 L F
.33623 .5393 m .33623 .5393 L .33646 .53543 L F
.992 .85 .494 r
.33623 .5393 m .33597 .53765 L .33634 .53742 L F
.33623 .5393 m .33634 .53742 L .33623 .5393 L F
.06 0 0 r
.33758 .53723 m .33597 .53765 L .33702 .53752 L F
.497 .417 .696 r
.33719 .5385 m .33623 .5393 L .33623 .5393 L F
.33719 .5385 m .33623 .5393 L .33719 .5385 L F
.992 .85 .494 r
.33623 .5393 m .33597 .53765 L .33623 .5393 L F
.717 .864 .951 r
.33577 .53823 m .33623 .5393 L .33803 .53781 L F
.497 .417 .696 r
.33946 .53662 m .33899 .53701 L .33879 .53684 L F
.717 .864 .951 r
.3387 .53695 m .33803 .53781 L .33946 .53662 L F
.33577 .53823 m .33803 .53781 L .3387 .53695 L F
.497 .417 .696 r
.33946 .53662 m .33879 .53684 L .33758 .53579 L F
.33944 .53602 m .33564 .53516 L .33821 .53324 L F
.06 0 0 r
.33634 .53742 m .33597 .53765 L .33758 .53723 L F
.717 .864 .951 r
.33447 .53518 m .33562 .53788 L .33877 .53687 L F
.376 .743 .991 r
.33946 .53599 m .33903 .53655 L .3388 .53684 L F
.497 .417 .696 r
.33964 .53647 m .33946 .53662 L .33758 .53579 L F
.717 .864 .951 r
.33447 .53518 m .33877 .53687 L .33917 .53635 L F
.3337 .53499 m .33542 .53793 L .33447 .53518 L F
.33542 .53793 m .33623 .5393 L .33562 .53788 L F
.33542 .53793 m .33562 .53788 L .33447 .53518 L F
.33623 .5393 m .33623 .5393 L .33447 .53518 L F
.992 .85 .494 r
.33623 .5393 m .33454 .53857 L .33562 .53788 L F
.06 0 0 r
.33598 .53779 m .33454 .53857 L .33599 .53811 L F
.33597 .53765 m .33562 .53788 L .33598 .53779 L F
.33562 .53788 m .33454 .53857 L .33598 .53779 L F
.717 .864 .951 r
.33562 .53788 m .33577 .53823 L .33774 .53733 L F
.06 0 0 r
.33758 .53723 m .33702 .53752 L .33794 .53728 L F
.717 .864 .951 r
.33562 .53788 m .33774 .53733 L .33877 .53687 L F
.06 0 0 r
.33794 .53728 m .3387 .53695 L .3388 .53684 L F
.717 .864 .951 r
.33774 .53733 m .33946 .53662 L .33964 .53647 L F
.33577 .53823 m .33794 .53728 L .33774 .53733 L F
.33794 .53728 m .33946 .53662 L .33774 .53733 L F
.06 0 0 r
.33702 .53752 m .33599 .53811 L .33838 .53734 L F
.33597 .53765 m .33598 .53779 L .33702 .53752 L F
.33598 .53779 m .33599 .53811 L .33702 .53752 L F
.992 .85 .494 r
.33623 .5393 m .33562 .53788 L .33623 .5393 L F
.768 .787 .869 r
.33454 .53857 m .33978 .54048 L .33838 .53734 L F
.06 0 0 r
.33794 .53728 m .33702 .53752 L .33838 .53734 L F
.756 .279 0 r
.33838 .53734 m .33839 .53894 L .3364 .53655 L F
0 .059 .625 r
.3364 .53655 m .33839 .53894 L .33823 .53861 L F
.547 .58 .839 r
.3364 .53655 m .33537 .53541 L .33917 .53635 L F
.3364 .53655 m .33917 .53635 L .33906 .53648 L F
.497 .417 .696 r
.3392 .53632 m .33564 .53516 L .33944 .53602 L F
.376 .743 .991 r
.33974 .53564 m .3392 .53632 L .3387 .53695 L F
.3392 .53632 m .3388 .53684 L .33878 .53686 L F
.3392 .53632 m .33878 .53686 L .3387 .53695 L F
.3392 .53632 m .3387 .53695 L .33838 .53734 L F
.33974 .53564 m .3387 .53695 L .3392 .53632 L F
.717 .864 .951 r
.33917 .53635 m .33877 .53687 L .33964 .53647 L F
.06 0 0 r
.33794 .53728 m .33838 .53734 L .3387 .53695 L F
.893 .961 .832 r
.33838 .53734 m .3364 .53655 L .33906 .53648 L F
.376 .743 .991 r
.33959 .53582 m .3392 .53632 L .33838 .53734 L F
.893 .961 .832 r
.33838 .53734 m .33906 .53648 L .33964 .53647 L F
.376 .743 .991 r
.34009 .53518 m .33959 .53582 L .33838 .53734 L F
0 .059 .625 r
.3364 .53655 m .33823 .53861 L .33662 .53531 L F
.547 .58 .839 r
.3364 .53655 m .3337 .53499 L .33537 .53541 L F
.33906 .53648 m .33917 .53635 L .33964 .53647 L F
.376 .743 .991 r
.33939 .5361 m .33923 .53631 L .33903 .53655 L F
.33974 .53564 m .33947 .536 L .33939 .5361 L F
.33947 .536 m .33923 .53631 L .33939 .5361 L F
.33974 .53564 m .33903 .53655 L .33946 .53599 L F
.3403 .53491 m .34159 .53634 L .33923 .53631 L F
.054 .154 .651 r
.3403 .53491 m .33964 .53647 L .33944 .53602 L F
.3403 .53491 m .33944 .53602 L .33821 .53324 L F
.497 .417 .696 r
.33964 .53647 m .3392 .53632 L .33944 .53602 L F
.376 .743 .991 r
.3403 .53491 m .34009 .53518 L .33838 .53734 L F
.34009 .53518 m .33974 .53564 L .3392 .53632 L F
0 .207 .733 r
.34342 .53715 m .34294 .53885 L .34012 .53671 L F
.683 .905 .56 r
.34213 .5385 m .34089 .54054 L .34342 .53715 L F
.648 .56 .742 r
.34089 .54054 m .3441 .54014 L .34342 .53715 L F
.233 .343 .771 r
.34213 .5385 m .34366 .54219 L .34089 .54054 L F
.806 .348 .146 r
.34231 .54107 m .33838 .53734 L .33962 .54012 L F
.34036 .54061 m .33962 .54012 L .33978 .54048 L F
.851 .934 .88 r
.33668 .54254 m .3382 .54365 L .34089 .54054 L F
.33668 .54254 m .34089 .54054 L .33978 .54048 L F
0 .247 .696 r
.34089 .54054 m .3414 .54073 L .33978 .54048 L F
.34089 .54054 m .34314 .54188 L .34231 .54107 L F
.34314 .54188 m .34366 .54219 L .34231 .54107 L F
.3414 .54073 m .34231 .54107 L .34107 .54078 L F
.3414 .54073 m .34107 .54078 L .33978 .54048 L F
.806 .348 .146 r
.34231 .54107 m .33962 .54012 L .34036 .54061 L F
.34192 .54069 m .34065 .54102 L .33838 .53734 L F
.34231 .54107 m .34065 .54102 L .34192 .54069 L F
.677 .977 .833 r
.34065 .54102 m .33835 .54234 L .33983 .54124 L F
.756 .279 0 r
.33838 .53734 m .34054 .54085 L .33839 .53894 L F
.34054 .54085 m .34065 .54102 L .34048 .54086 L F
.34054 .54085 m .34048 .54086 L .33839 .53894 L F
.665 .825 .961 r
.33839 .53894 m .34065 .54102 L .34222 .53948 L F
.677 .977 .833 r
.34065 .54102 m .33983 .54124 L .34222 .53948 L F
.711 .961 .944 r
.34231 .54107 m .34065 .54102 L .34146 .54023 L F
.34231 .54107 m .34146 .54023 L .34222 .53948 L F
.298 .78 .915 r
.33623 .5393 m .33454 .53857 L .33623 .5393 L F
.992 .85 .494 r
.33623 .5393 m .33454 .53857 L .33623 .5393 L F
.298 .78 .915 r
.33623 .5393 m .33454 .53857 L .33623 .5393 L F
.33613 .53926 m .33454 .53857 L .33611 .53931 L F
.992 .85 .494 r
.33623 .53931 m .33454 .53857 L .33623 .5393 L F
.988 .766 .374 r
.33623 .5393 m .33454 .53857 L .33623 .5393 L F
.547 .58 .839 r
.3364 .53655 m .33454 .53857 L .3337 .53499 L F
.658 .948 .707 r
.3364 .53655 m .33453 .53831 L .33454 .53857 L F
.298 .78 .915 r
.33458 .53933 m .33454 .53857 L .33235 .53935 L F
.76 .686 .78 r
.33609 .5398 m .3334 .54318 L .33235 .53935 L F
.658 .948 .707 r
.33453 .53831 m .33271 .54002 L .33454 .53857 L F
.298 .78 .915 r
.33611 .53931 m .33454 .53857 L .33458 .53933 L F
.33623 .5393 m .33613 .53926 L .33611 .53931 L F
.33623 .5393 m .33623 .5393 L .33623 .5393 L F
.992 .85 .494 r
.33609 .5398 m .33584 .5396 L .33623 .53931 L F
.33584 .5396 m .33454 .53857 L .33623 .53931 L F
.142 0 .272 r
.62538 .38872 m .62731 .38929 L .62759 .38781 L F
.62538 .38872 m .62491 .39072 L .62731 .38929 L F
.56 .603 .853 r
.52834 .38916 m .52662 .39162 L .5249 .38768 L F
0 0 .02 r
.52834 .38916 m .52578 .39371 L .52662 .39162 L F
.614 .599 .812 r
.46532 .58874 m .46378 .59211 L .46311 .58837 L F
.46532 .58874 m .46788 .59116 L .46378 .59211 L F
.598 .454 .656 r
.46428 .59255 m .46788 .59116 L .46378 .59211 L F
0 0 0 r
.61878 .34813 m .61851 .34827 L .61586 .34893 L F
.678 .213 .141 r
.29644 .59154 m .29446 .59318 L .29219 .59101 L F
.862 .503 .001 r
.29521 .5891 m .29571 .59098 L .29644 .59154 L F
.938 .953 .637 r
.29571 .59098 m .29446 .59318 L .29644 .59154 L F
0 0 .482 r
.25638 .59796 m .25754 .60118 L .25718 .59986 L F
0 0 0 r
.48865 .55129 m .48794 .5536 L .48686 .55544 L F
0 0 .035 r
.48757 .55616 m .48686 .55544 L .48794 .5536 L F
.48757 .55616 m .48619 .55813 L .48686 .55544 L F
.32 0 .181 r
.64371 .3426 m .64156 .34211 L .64838 .34413 L F
.88 .764 .73 r
.64371 .3426 m .64838 .34413 L .64797 .34119 L F
.585 .885 .991 r
.42221 .45035 m .4198 .45134 L .41745 .45048 L F
.162 0 .198 r
.31031 .53493 m .30747 .53808 L .30792 .53614 L F
.31031 .53493 m .30747 .53808 L .30792 .53614 L F
.973 .921 .676 r
.70776 .29691 m .7083 .29983 L .70911 .29498 L F
.822 .836 .366 r
.70791 .29893 m .7083 .29983 L .70776 .29691 L F
.01 0 0 r
.5211 .43059 m .52194 .43114 L .52055 .43297 L F
.5211 .43059 m .52376 .42979 L .52194 .43114 L F
.801 .998 .792 r
.62443 .40416 m .62149 .40731 L .62251 .4042 L F
.802 .963 .644 r
.62149 .40731 m .62115 .40689 L .62251 .4042 L F
.745 .372 .346 r
.6812 .30763 m .6853 .30824 L .68497 .30631 L F
.799 .629 .672 r
.6853 .30824 m .68926 .30615 L .68497 .30631 L F
.603 .551 .769 r
.35668 .55565 m .35406 .55853 L .35355 .55656 L F
.35668 .55565 m .35695 .55785 L .35406 .55853 L F
.572 .501 .736 r
.35803 .56163 m .35406 .55853 L .35695 .55785 L F
.615 .954 .811 r
.68483 .37285 m .68656 .3725 L .68866 .37086 L F
.375 0 0 r
.24669 .58375 m .24457 .5841 L .24834 .58439 L F
.789 .92 .538 r
.51538 .50758 m .51467 .50979 L .51681 .50604 L F
.797 .999 .84 r
.51226 .51029 m .51467 .50979 L .51538 .50758 L F
.194 0 0 r
.46311 .58837 m .46397 .58886 L .46145 .58903 L F
.46311 .58837 m .46532 .58874 L .46397 .58886 L F
.76 .687 .782 r
.47611 .53609 m .47087 .53769 L .47493 .5353 L F
.262 .072 .424 r
.24996 .55473 m .24777 .55819 L .24752 .55543 L F
.43 .2 .462 r
.30049 .67657 m .30087 .67381 L .30336 .67319 L F
.738 .805 .905 r
.4673 .44436 m .47076 .44735 L .47188 .44388 L F
0 0 0 r
.47076 .44735 m .47313 .44664 L .47188 .44388 L F
.865 .885 .849 r
.40808 .59301 m .40551 .59302 L .40774 .59051 L F
.913 .511 .179 r
.40808 .59301 m .40763 .59564 L .40551 .59302 L F
.752 .702 .804 r
.60144 .37783 m .60275 .38154 L .60565 .37834 L F
.615 .342 .481 r
.28034 .51049 m .28161 .51198 L .28255 .50967 L F
.28255 .50967 m .28161 .51198 L .28034 .51049 L F
.912 .978 .703 r
.49589 .5355 m .49413 .53642 L .49394 .53914 L F
.906 .984 .741 r
.49394 .53914 m .49324 .54174 L .49587 .54095 L F
.49394 .53914 m .49167 .5403 L .49324 .54174 L F
.49394 .53914 m .49413 .53642 L .49167 .5403 L F
.443 .169 .402 r
.49394 .53914 m .49587 .54095 L .49324 .54174 L F
0 0 .171 r
.33012 .51277 m .3298 .51126 L .32897 .50776 L F
0 0 .477 r
.33037 .51533 m .3298 .51126 L .33012 .51277 L F
.424 .226 .505 r
.33274 .51374 m .33037 .51533 L .33012 .51277 L F
.543 .876 .991 r
.47547 .44522 m .48042 .44505 L .4784 .44477 L F
.785 .875 .914 r
.48042 .44505 m .48055 .44234 L .4784 .44477 L F
.48042 .44505 m .48243 .44348 L .48055 .44234 L F
.618 .611 .821 r
.32667 .65122 m .32788 .64675 L .32509 .6476 L F
.32667 .65122 m .32932 .65041 L .32788 .64675 L F
.406 0 0 r
.64731 .39743 m .64882 .39898 L .6462 .39864 L F
.64731 .39743 m .65021 .39758 L .64882 .39898 L F
.99 .862 .612 r
.69842 .33716 m .69777 .33449 L .69692 .33636 L F
.984 .906 .625 r
.69598 .34051 m .69842 .33716 L .69692 .33636 L F
.69598 .34051 m .69682 .3417 L .69842 .33716 L F
.67 .943 .962 r
.51681 .50604 m .51868 .50508 L .51783 .50401 L F
.705 .897 .526 r
.51783 .50401 m .51538 .50758 L .51681 .50604 L F
0 0 0 r
.51621 .48937 m .5137 .49217 L .51536 .49119 L F
.37 .816 .682 r
.5137 .49217 m .51299 .49243 L .51536 .49119 L F
.099 .622 .88 r
.61664 .41428 m .61724 .41374 L .61767 .41237 L F
.61664 .41428 m .61963 .4146 L .61724 .41374 L F
.822 .825 .851 r
.55695 .40379 m .55824 .40547 L .55191 .40655 L F
.271 0 0 r
.55824 .40547 m .55422 .40692 L .55191 .40655 L F
0 0 .487 r
.55825 .40379 m .55824 .40547 L .55695 .40379 L F
.401 .846 .744 r
.55763 .40531 m .55422 .40692 L .55824 .40547 L F
.751 .649 .748 r
.59772 .40734 m .60156 .4082 L .60046 .40395 L F
.575 .633 .872 r
.60156 .4082 m .60331 .4053 L .60046 .40395 L F
.60156 .4082 m .60446 .4079 L .60331 .4053 L F
.455 0 0 r
.32666 .54226 m .32484 .54386 L .32165 .54297 L F
.966 .926 .601 r
.32614 .53934 m .32484 .54386 L .32666 .54226 L F
.888 .466 .175 r
.41122 .51856 m .41198 .52063 L .41345 .51967 L F
.795 .311 .065 r
.41345 .51967 m .41198 .52063 L .41409 .52089 L F
.064 0 0 r
.42767 .45693 m .42877 .45715 L .4261 .45856 L F
.42767 .45693 m .43061 .45699 L .42877 .45715 L F
.921 .606 .428 r
.33708 .50057 m .33928 .49924 L .33874 .49903 L F
.33708 .50057 m .3396 .50248 L .33928 .49924 L F
.881 .447 .094 r
.32658 .61106 m .3247 .61043 L .32417 .60768 L F
0 0 .277 r
.32417 .60768 m .3247 .61043 L .32516 .60692 L F
.928 .597 .393 r
.3702 .54585 m .37028 .54811 L .37233 .54886 L F
.921 .676 .55 r
.3703 .55024 m .37233 .54886 L .37028 .54811 L F
.3703 .55024 m .37229 .55153 L .37233 .54886 L F
.283 0 0 r
.24368 .53165 m .24841 .53223 L .2459 .53269 L F
.763 .656 .744 r
.59456 .39401 m .59897 .39465 L .5975 .39087 L F
.809 .592 .608 r
.59479 .39707 m .59897 .39465 L .59456 .39401 L F
.868 .907 .856 r
.59897 .39465 m .59988 .39227 L .5975 .39087 L F
.912 .532 .287 r
.23428 .61324 m .23682 .61434 L .23551 .61233 L F
.23428 .61324 m .23682 .61434 L .23551 .61233 L F
.523 .262 .461 r
.53733 .39739 m .53704 .39974 L .53441 .39786 L F
.478 .28 .533 r
.53441 .39786 m .53704 .39974 L .53442 .4005 L F
.523 .262 .461 r
.53733 .39739 m .53704 .39974 L .53441 .39786 L F
.478 .28 .533 r
.53441 .39786 m .53704 .39974 L .53442 .4005 L F
.93 .716 .592 r
.59727 .40991 m .59628 .41352 L .59883 .41399 L F
.92 .909 .794 r
.59516 .41593 m .59883 .41399 L .59628 .41352 L F
.947 .945 .623 r
.55713 .39671 m .55621 .40072 L .55457 .40013 L F
.696 .425 .509 r
.55621 .40072 m .55695 .40379 L .55457 .40013 L F
.55621 .40072 m .55825 .40379 L .55695 .40379 L F
.269 .77 .739 r
.51323 .40931 m .51066 .40986 L .50926 .41045 L F
.817 .657 .684 r
.50926 .41045 m .51304 .41063 L .51323 .40931 L F
.727 .987 .804 r
.51272 .40778 m .51323 .40931 L .51428 .40633 L F
.51272 .40778 m .51066 .40986 L .51323 .40931 L F
.67 .518 .67 r
.51323 .40931 m .51547 .40736 L .51428 .40633 L F
.51323 .40931 m .51304 .41063 L .51547 .40736 L F
.523 0 0 r
.41509 .53713 m .41233 .53733 L .41351 .53634 L F
.76 .47 .492 r
.26532 .52075 m .26778 .5223 L .26971 .5188 L F
0 0 0 r
.26971 .5188 m .27096 .51766 L .27217 .51467 L F
.895 .909 .827 r
.45851 .55195 m .45587 .55578 L .45406 .55423 L F
.716 .609 .737 r
.45964 .55437 m .45587 .55578 L .45851 .55195 L F
.386 0 .123 r
.45964 .55437 m .45927 .55676 L .45587 .55578 L F
.226 0 0 r
.45587 .55578 m .45653 .55611 L .45406 .55423 L F
.45587 .55578 m .45927 .55676 L .45653 .55611 L F
.902 .907 .817 r
.3796 .60263 m .38188 .60207 L .3809 .60029 L F
.887 .963 .839 r
.60849 .36449 m .60976 .36557 L .61106 .36286 L F
.61106 .36286 m .60976 .36557 L .60849 .36449 L F
.518 .497 .772 r
.42562 .5505 m .42475 .55524 L .42669 .55169 L F
.965 .799 .626 r
.35893 .53099 m .36151 .52916 L .35971 .528 L F
.35893 .53099 m .36097 .53239 L .36151 .52916 L F
.901 .726 .656 r
.36151 .52916 m .36097 .53239 L .36148 .53187 L F
.717 .93 .961 r
.32034 .6263 m .3168 .62691 L .3192 .62603 L F
.727 .698 .823 r
.39201 .48313 m .39417 .48688 L .38894 .48595 L F
.729 .484 .556 r
.39417 .48688 m .38977 .48861 L .38894 .48595 L F
.39417 .48688 m .39302 .48916 L .38977 .48861 L F
.796 .722 .782 r
.3953 .48356 m .39417 .48688 L .39201 .48313 L F
0 0 .032 r
.39417 .48688 m .39302 .48916 L .39542 .48668 L F
.735 .576 .676 r
.68926 .30615 m .6892 .30895 L .69189 .30573 L F
.701 .526 .648 r
.69189 .30573 m .6892 .30895 L .69279 .30866 L F
.553 .391 .616 r
.69279 .30866 m .69505 .3053 L .69189 .30573 L F
.543 .849 .998 r
.26917 .61693 m .27115 .61796 L .27362 .61707 L F
.839 .996 .765 r
.33535 .54306 m .3334 .54318 L .33609 .5398 L F
.597 .941 .776 r
.52593 .47781 m .52469 .47937 L .5239 .4794 L F
.402 .483 .828 r
.52874 .48317 m .52469 .47937 L .52837 .4794 L F
.31 .763 .956 r
.5158 .40657 m .51428 .40633 L .51547 .40736 L F
.925 .817 .721 r
.46103 .55406 m .45927 .55676 L .45964 .55437 L F
.626 .892 .987 r
.45657 .59427 m .45802 .59533 L .46035 .59418 L F
.27 .633 .963 r
.30866 .57659 m .31015 .57773 L .30803 .57705 L F
0 .276 .721 r
.30866 .57659 m .31055 .57786 L .31015 .57773 L F
.216 .535 .924 r
.30803 .57705 m .31055 .57786 L .30866 .57659 L F
.849 .399 0 r
.3077 .57894 m .30975 .58055 L .30803 .57705 L F
.703 .381 .428 r
.31015 .57773 m .30975 .58055 L .30803 .57705 L F
0 0 .205 r
.31055 .57786 m .30975 .58055 L .31015 .57773 L F
.849 .399 0 r
.3077 .57894 m .30803 .57705 L .31055 .57786 L F
.46 .309 .588 r
.29046 .54893 m .29292 .55121 L .29289 .54818 L F
.29046 .54893 m .29081 .55247 L .29292 .55121 L F
.511 .753 .983 r
.55131 .43022 m .54823 .43084 L .54951 .42857 L F
.55131 .43022 m .54823 .43084 L .54951 .42857 L F
0 0 .427 r
.56947 .37862 m .56839 .37788 L .56661 .37645 L F
.56947 .37862 m .56994 .38148 L .56839 .37788 L F
0 0 0 r
.4248 .44965 m .42854 .44898 L .4259 .44932 L F
.652 .948 .715 r
.32922 .52754 m .32685 .5301 L .33056 .52882 L F
.504 .551 .838 r
.32685 .5301 m .33064 .5318 L .33056 .52882 L F
.798 .538 .545 r
.4078 .51219 m .41147 .51529 L .41194 .51259 L F
.698 .981 .817 r
.46611 .43034 m .46215 .43271 L .46516 .43017 L F
.603 .943 .773 r
.46743 .42875 m .4692 .4281 L .46611 .43034 L F
.594 .949 .881 r
.46743 .42875 m .46611 .43034 L .46516 .43017 L F
.932 .785 .676 r
.38217 .5811 m .38168 .58418 L .38349 .58496 L F
.893 .594 .473 r
.38135 .58671 m .38349 .58496 L .38168 .58418 L F
.38135 .58671 m .38361 .58757 L .38349 .58496 L F
.791 .73 .796 r
.38217 .5811 m .38349 .58496 L .3863 .58148 L F
.686 .931 .627 r
.35834 .49952 m .35923 .49788 L .3611 .4964 L F
.862 .85 .83 r
.35883 .50165 m .35923 .49788 L .35834 .49952 L F
.717 .766 .891 r
.33704 .65081 m .33902 .64834 L .33573 .64857 L F
.673 .254 .242 r
.33409 .49866 m .33675 .49971 L .33874 .49903 L F
.921 .606 .428 r
.33708 .50057 m .33874 .49903 L .33675 .49971 L F
.817 .987 .879 r
.44798 .56544 m .44391 .56748 L .44649 .56534 L F
.939 .712 .567 r
.3806 .57451 m .38083 .57856 L .38216 .57836 L F
.898 .591 .457 r
.38036 .57943 m .38216 .57836 L .38083 .57856 L F
.38036 .57943 m .38217 .5811 L .38216 .57836 L F
.793 .497 .487 r
.38216 .57836 m .38217 .5811 L .3863 .58148 L F
.431 .609 .923 r
.30753 .64424 m .31195 .64726 L .31018 .64362 L F
.714 .721 .854 r
.31195 .64726 m .31282 .64289 L .31018 .64362 L F
.31195 .64726 m .31464 .64638 L .31282 .64289 L F
.445 .56 .878 r
.59238 .35262 m .59319 .35381 L .59207 .35066 L F
.751 .25 .032 r
.59573 .35293 m .59207 .35066 L .59319 .35381 L F
.644 .751 .927 r
.59319 .35381 m .59835 .35357 L .59573 .35293 L F
0 .53 .772 r
.60094 .34393 m .60353 .34431 L .60491 .34468 L F
.266 .757 .911 r
.60491 .34468 m .60353 .34431 L .60766 .34439 L F
.123 .662 .849 r
.58909 .34979 m .58767 .34935 L .58481 .34951 L F
0 .397 .687 r
.58909 .34979 m .59207 .35066 L .58767 .34935 L F
.946 .846 .712 r
.58151 .44636 m .5826 .44409 L .57992 .44509 L F
.886 .974 .832 r
.57992 .44509 m .5826 .44409 L .58414 .43987 L F
.237 .066 .435 r
.24017 .53543 m .24171 .53751 L .24172 .53459 L F
.24017 .53543 m .23981 .53851 L .24171 .53751 L F
.851 .934 .88 r
.29535 .63468 m .29096 .63662 L .29348 .63603 L F
.263 0 0 r
.29609 .63557 m .29535 .63468 L .29348 .63603 L F
.29609 .63557 m .29765 .63485 L .29535 .63468 L F
.967 .803 .628 r
.6973 .34838 m .69635 .34438 L .69574 .34736 L F
.976 .76 .546 r
.69656 .35072 m .6973 .34838 L .69574 .34736 L F
.648 .161 .081 r
.3611 .4964 m .35923 .49788 L .36339 .49833 L F
.506 .712 .964 r
.41064 .59864 m .41178 .59647 L .40958 .59654 L F
.41064 .59864 m .41304 .59835 L .41178 .59647 L F
.068 0 0 r
.2378 .58358 m .24296 .58158 L .24036 .58259 L F
.2378 .58358 m .24042 .5831 L .24296 .58158 L F
.887 .804 .761 r
.24042 .5831 m .24506 .58107 L .24296 .58158 L F
.776 .951 .931 r
.50173 .44485 m .50635 .44328 L .50592 .44328 L F
.702 .644 .789 r
.29718 .66028 m .2986 .66405 L .2945 .66337 L F
.628 .604 .807 r
.30125 .66334 m .2986 .66405 L .29718 .66028 L F
.977 .684 .389 r
.37621 .61181 m .37623 .61128 L .37471 .61049 L F
.788 .735 .804 r
.37623 .61128 m .37657 .60711 L .37471 .61049 L F
.37623 .61128 m .37914 .60829 L .37657 .60711 L F
.777 .776 .852 r
.34177 .64694 m .34356 .6481 L .34475 .6467 L F
.949 .951 .731 r
.48851 .51877 m .48574 .52141 L .48791 .51862 L F
.48851 .51877 m .48659 .52257 L .48574 .52141 L F
.646 .949 .729 r
.48978 .51698 m .49184 .51593 L .48851 .51877 L F
.648 .963 .794 r
.48978 .51698 m .48851 .51877 L .48791 .51862 L F
.851 .512 .41 r
.36118 .53439 m .36148 .53187 L .36097 .53239 L F
.36118 .53439 m .36514 .53553 L .36148 .53187 L F
0 0 0 r
.63387 .33817 m .63632 .33764 L .63766 .33644 L F
.63632 .33764 m .63977 .33476 L .63766 .33644 L F
.502 0 0 r
.57605 .4237 m .57798 .42371 L .57425 .42279 L F
.752 .279 0 r
.57835 .42528 m .57798 .42371 L .57605 .4237 L F
.57835 .42528 m .57976 .42649 L .57798 .42371 L F
0 .397 .737 r
.71852 .32269 m .71483 .32128 L .71637 .3234 L F
.577 .644 .88 r
.54985 .39041 m .55328 .39126 L .5517 .38959 L F
.834 .989 .725 r
.49467 .40996 m .49443 .40923 L .49586 .40881 L F
.708 .975 .757 r
.49586 .40881 m .49584 .40764 L .49832 .40731 L F
.49586 .40881 m .49443 .40923 L .49584 .40764 L F
.873 .719 .688 r
.29361 .67062 m .29353 .674 L .29 .67239 L F
.881 .511 .339 r
.29 .67239 m .29353 .674 L .29332 .67583 L F
.694 .31 .316 r
.29353 .674 m .29612 .67614 L .29332 .67583 L F
.506 .52 .805 r
.28699 .58136 m .28969 .58437 L .29141 .58187 L F
.699 .279 .246 r
.67334 .32866 m .67197 .33055 L .6693 .32826 L F
.672 .247 .228 r
.67612 .33082 m .67197 .33055 L .67334 .32866 L F
.626 .297 .394 r
.67565 .3288 m .67612 .33082 L .67334 .32866 L F
.894 .548 .382 r
.35101 .51711 m .35404 .51628 L .35064 .5145 L F
.35101 .51711 m .35417 .51846 L .35404 .51628 L F
.578 .739 .952 r
.61188 .36255 m .61521 .36149 L .61056 .36026 L F
.887 .784 .742 r
.32658 .61106 m .32281 .61282 L .3247 .61043 L F
.32658 .61106 m .32484 .61416 L .32281 .61282 L F
.468 .213 .443 r
.42977 .59156 m .43194 .59348 L .42921 .59424 L F
.42977 .59156 m .43194 .59348 L .42921 .59424 L F
.91 .643 .144 r
.57755 .39913 m .578 .3979 L .57801 .39655 L F
.57755 .39913 m .57824 .39998 L .578 .3979 L F
.106 .66 .75 r
.608 .39029 m .60419 .39058 L .60689 .39036 L F
.38 .222 .537 r
.60678 .39263 m .60419 .39058 L .608 .39029 L F
.527 .623 .89 r
.60995 .38775 m .608 .39029 L .60689 .39036 L F
.60995 .38775 m .61095 .39064 L .608 .39029 L F
.425 0 0 r
.608 .39029 m .60962 .39194 L .60678 .39263 L F
.608 .39029 m .61095 .39064 L .60962 .39194 L F
.871 .604 .532 r
.37363 .55811 m .37359 .5608 L .37731 .56162 L F
.849 .602 .566 r
.37329 .5638 m .37731 .56162 L .37359 .5608 L F
.37329 .5638 m .37572 .56443 L .37731 .56162 L F
.964 .938 .691 r
.31689 .63009 m .31808 .63055 L .31615 .63425 L F
0 0 .488 r
.57593 .38726 m .57769 .38963 L .57841 .39131 L F
0 0 0 r
.57846 .39155 m .57841 .39131 L .57769 .38963 L F
.57846 .39155 m .57815 .39397 L .57841 .39131 L F
.934 .786 .672 r
.72773 .30935 m .7288 .30557 L .72634 .30469 L F
.908 .943 .586 r
.48545 .52465 m .48493 .52409 L .48659 .52257 L F
.99 .874 .536 r
.48659 .52257 m .48493 .52409 L .48574 .52141 L F
.775 .697 .777 r
.23512 .61679 m .23428 .61324 L .23682 .61434 L F
0 0 .485 r
.23428 .61324 m .23736 .61724 L .23682 .61434 L F
.811 .579 .587 r
.29191 .6697 m .29361 .67062 L .29029 .66954 L F
.873 .719 .688 r
.29361 .67062 m .29 .67239 L .29029 .66954 L F
.789 .711 .779 r
.33304 .54531 m .33478 .54872 L .33741 .54539 L F
.801 .597 .626 r
.46847 .5359 m .46892 .53845 L .46473 .53824 L F
.701 .531 .654 r
.47087 .53769 m .46847 .5359 L .47029 .53503 L F
.47087 .53769 m .46892 .53845 L .46847 .5359 L F
.65 .739 .914 r
.47188 .44388 m .47313 .44664 L .47547 .44522 L F
.944 .835 .706 r
.46105 .5629 m .46197 .56559 L .45994 .56401 L F
.593 .144 .155 r
.33056 .52882 m .33171 .53065 L .33309 .52935 L F
.035 0 .454 r
.33056 .52882 m .33064 .5318 L .33171 .53065 L F
.731 .623 .738 r
.64797 .34119 m .64942 .34523 L .65201 .34191 L F
.872 .83 .803 r
.399 .48829 m .40244 .48439 L .39826 .48514 L F
.921 .704 .593 r
.37515 .56994 m .37923 .56778 L .37538 .56706 L F
.37515 .56994 m .37857 .57133 L .37923 .56778 L F
.419 0 0 r
.44155 .59766 m .4443 .59765 L .44259 .59922 L F
.824 .77 .801 r
.65971 .39418 m .66078 .39774 L .65735 .39526 L F
.769 .263 0 r
.65735 .39526 m .66078 .39774 L .6591 .39762 L F
.811 .763 .808 r
.66209 .39539 m .66078 .39774 L .65971 .39418 L F
.902 .983 .72 r
.6591 .39762 m .66078 .39774 L .66209 .39539 L F
.819 .812 .844 r
.32281 .61282 m .3214 .61787 L .32069 .6164 L F
.32281 .61282 m .32484 .61416 L .3214 .61787 L F
.967 .693 .46 r
.39918 .55537 m .39732 .55451 L .39733 .55148 L F
.935 .715 .582 r
.39918 .55537 m .39648 .5571 L .39732 .55451 L F
.39918 .55537 m .39859 .55812 L .39648 .5571 L F
.768 .725 .812 r
.32972 .57131 m .32557 .57144 L .32827 .56872 L F
.603 .515 .727 r
.32959 .57366 m .32557 .57144 L .32972 .57131 L F
.745 .716 .825 r
.33157 .56895 m .32972 .57131 L .32827 .56872 L F
.521 .217 .392 r
.32972 .57131 m .33189 .57335 L .32959 .57366 L F
.628 .541 .737 r
.33157 .56895 m .33281 .57177 L .32972 .57131 L F
.602 .199 .251 r
.33281 .57177 m .33189 .57335 L .32972 .57131 L F
.869 .561 .463 r
.36118 .53439 m .36482 .53788 L .36514 .53553 L F
.279 .765 .678 r
.64219 .33332 m .64477 .33229 L .64624 .33176 L F
0 0 0 r
.64624 .33176 m .64814 .33079 L .64871 .33036 L F
.334 .799 .693 r
.64477 .33229 m .64814 .33079 L .64624 .33176 L F
.536 .379 .615 r
.29837 .54153 m .29587 .54529 L .29569 .54213 L F
.29587 .54529 m .29837 .54153 L .29569 .54213 L F
.608 .82 .981 r
.35668 .55565 m .35355 .55656 L .35189 .5551 L F
.801 .998 .792 r
.62443 .40416 m .62251 .4042 L .62347 .40293 L F
.901 .587 .094 r
.6232 .40072 m .62443 .40416 L .62347 .40293 L F
.768 .691 .778 r
.6232 .40072 m .62729 .40101 L .62443 .40416 L F
.936 .599 .368 r
.42005 .5282 m .4209 .53196 L .42296 .5327 L F
0 0 0 r
.51858 .48567 m .52017 .48416 L .52113 .48212 L F
.51858 .48567 m .51787 .48776 L .52017 .48416 L F
.797 .941 .921 r
.50782 .40183 m .50486 .40415 L .50353 .40318 L F
.954 .925 .574 r
.42331 .58103 m .42227 .58317 L .42396 .58151 L F
.668 .899 .556 r
.42396 .58151 m .42227 .58317 L .42491 .57983 L F
0 0 0 r
.43674 .4458 m .43755 .44517 L .43526 .44609 L F
.43674 .4458 m .43526 .44609 L .43327 .44721 L F
.996 .801 .441 r
.39768 .57733 m .39648 .57636 L .39798 .57452 L F
.942 .849 .416 r
.39798 .57452 m .39741 .574 L .39786 .57154 L F
.937 .894 .491 r
.39798 .57452 m .39648 .57636 L .39741 .574 L F
.854 .565 .499 r
.35417 .51846 m .35656 .5215 L .35655 .51901 L F
.957 .934 .726 r
.55357 .46463 m .55607 .46342 L .55468 .46561 L F
.976 .846 .649 r
.55444 .46212 m .55607 .46342 L .55357 .46463 L F
.617 .294 .401 r
.40148 .45755 m .40356 .4591 L .3997 .45954 L F
.835 .917 .891 r
.40604 .45353 m .40148 .45755 L .40215 .45481 L F
.18 0 .362 r
.52879 .41784 m .5304 .41887 L .53092 .41678 L F
.52879 .41784 m .52848 .4201 L .5304 .41887 L F
.863 .98 .687 r
.72322 .32255 m .7256 .31892 L .72407 .31969 L F
.809 .96 .91 r
.72322 .32255 m .72407 .31969 L .72065 .32244 L F
.862 .989 .838 r
.62239 .41312 m .62601 .41083 L .62445 .41125 L F
.817 .964 .903 r
.62704 .40789 m .62601 .41083 L .62921 .40807 L F
.859 .995 .763 r
.62704 .40789 m .62445 .41125 L .62601 .41083 L F
.789 .711 .779 r
.33304 .54531 m .33741 .54539 L .33668 .54552 L F
.507 .511 .796 r
.33727 .54811 m .33668 .54552 L .33741 .54539 L F
.786 .294 0 r
.57742 .37469 m .57559 .37348 L .57431 .37141 L F
.893 .585 .082 r
.57742 .37469 m .57695 .37552 L .57559 .37348 L F
.57742 .37469 m .57782 .37713 L .57695 .37552 L F
.232 0 0 r
.61586 .34893 m .61455 .34938 L .61402 .34926 L F
.431 0 0 r
.61851 .34827 m .61455 .34938 L .61586 .34893 L F
.984 .902 .585 r
.72407 .31969 m .7256 .31892 L .72488 .31751 L F
.856 .769 .765 r
.2931 .6598 m .2945 .66337 L .29218 .66221 L F
.818 .662 .689 r
.2945 .66337 m .2903 .66556 L .29218 .66221 L F
.2945 .66337 m .29394 .66608 L .2903 .66556 L F
.749 .722 .827 r
.29718 .66028 m .2945 .66337 L .2931 .6598 L F
.895 .909 .827 r
.45851 .55195 m .45406 .55423 L .45655 .55323 L F
.463 .867 .701 r
.45851 .55195 m .46027 .55063 L .46042 .55077 L F
0 0 0 r
.45851 .55195 m .4591 .55227 L .46027 .55063 L F
.45851 .55195 m .45655 .55323 L .4591 .55227 L F
.796 .678 .734 r
.33886 .57077 m .33821 .56663 L .3397 .56851 L F
.211 .527 .92 r
.33982 .56676 m .3397 .56851 L .33821 .56663 L F
.692 .35 .392 r
.3397 .56851 m .34169 .57093 L .34274 .56933 L F
0 .114 .666 r
.33982 .56676 m .34169 .57093 L .3397 .56851 L F
0 0 .47 r
.60038 .42377 m .60192 .42709 L .60089 .42514 L F
.681 .406 .499 r
.30683 .66985 m .30927 .6726 L .30516 .67199 L F
.30683 .66985 m .3094 .6701 L .30927 .6726 L F
.799 .629 .672 r
.6853 .30824 m .6892 .30895 L .68926 .30615 L F
.569 .833 .995 r
.34399 .55503 m .3387 .55468 L .34155 .55395 L F
.824 .589 .583 r
.34155 .55395 m .34518 .55706 L .34399 .55503 L F
.028 .6 .722 r
.28268 .5971 m .27811 .59717 L .28088 .59811 L F
.229 0 .289 r
.28088 .59811 m .28006 .60051 L .28268 .5971 L F
.28088 .59811 m .28006 .60051 L .28268 .5971 L F
.312 .726 .976 r
.2771 .59733 m .28088 .59811 L .27811 .59717 L F
.969 .827 .647 r
.58313 .43645 m .58409 .43415 L .58246 .43243 L F
.125 .444 .879 r
.61225 .35491 m .61379 .35524 L .61326 .35679 L F
.732 .912 .546 r
.61379 .35524 m .61377 .35528 L .61326 .35679 L F
.426 .784 .996 r
.6105 .35717 m .61326 .35679 L .613 .35757 L F
.681 .968 .927 r
.6105 .35717 m .61225 .35491 L .61326 .35679 L F
.6105 .35717 m .60977 .35651 L .61225 .35491 L F
.614 .099 0 r
.61326 .35679 m .60977 .35651 L .6105 .35717 L F
.74 .633 .741 r
.61056 .36026 m .61326 .35679 L .6105 .35717 L F
.614 .099 0 r
.61326 .35679 m .61192 .3581 L .60977 .35651 L F
.732 .912 .546 r
.61377 .35528 m .61192 .3581 L .61326 .35679 L F
.426 .784 .996 r
.613 .35757 m .61326 .35679 L .61448 .3578 L F
.425 .784 .996 r
.61326 .35679 m .61726 .35749 L .61448 .3578 L F
.825 .977 .679 r
.49427 .5125 m .49184 .51593 L .49237 .51384 L F
.823 .991 .736 r
.49237 .51384 m .49184 .51593 L .48978 .51698 L F
.618 .675 .882 r
.31282 .64289 m .31464 .64638 L .31703 .64415 L F
.485 .685 .955 r
.31464 .64638 m .31845 .64739 L .31703 .64415 L F
.994 .876 .581 r
.64083 .38393 m .64047 .38703 L .63906 .38487 L F
.958 .758 .59 r
.66047 .38626 m .662 .38783 L .66065 .38387 L F
.323 .779 .633 r
.65808 .38982 m .662 .38783 L .66047 .38626 L F
.578 .579 .817 r
.66065 .38387 m .662 .38783 L .66465 .38684 L F
.667 .716 .885 r
.64797 .34119 m .65201 .34191 L .65089 .33881 L F
.8 .786 .84 r
.65089 .33881 m .65201 .34191 L .65491 .33954 L F
.8 .896 .911 r
.24036 .58259 m .23542 .58425 L .2378 .58358 L F
.856 .896 .863 r
.35478 .63649 m .35988 .63359 L .35812 .63264 L F
.828 .916 .896 r
.35988 .63359 m .36113 .63008 L .35812 .63264 L F
.35988 .63359 m .36259 .63122 L .36113 .63008 L F
.598 .454 .656 r
.46428 .59255 m .46727 .59437 L .46788 .59116 L F
.81 .775 .268 r
.57062 .41882 m .57141 .41679 L .5703 .41566 L F
.57062 .41882 m .57084 .41942 L .57141 .41679 L F
.253 .044 .39 r
.2316 .56157 m .23344 .56112 L .23388 .55829 L F
.373 .349 .703 r
.2316 .56157 m .23434 .56392 L .23344 .56112 L F
.509 .248 .453 r
.28291 .61665 m .2845 .61429 L .2808 .61426 L F
.627 .1 0 r
.58578 .36728 m .58928 .36803 L .58646 .36919 L F
.808 .733 .781 r
.54947 .42085 m .55159 .41928 L .5523 .41725 L F
.5523 .41725 m .55159 .41928 L .54947 .42085 L F
.838 .907 .885 r
.56367 .45341 m .5607 .45653 L .55924 .45535 L F
.838 .439 .292 r
.67943 .33177 m .67612 .33082 L .67565 .3288 L F
.86 .73 .718 r
.67943 .33177 m .67745 .33483 L .67612 .33082 L F
.783 .396 .322 r
.38376 .52582 m .38105 .52727 L .38147 .5247 L F
.38376 .52582 m .38439 .52794 L .38105 .52727 L F
.225 .404 .831 r
.62248 .36751 m .62411 .36841 L .62425 .3712 L F
.236 .322 .749 r
.62214 .36372 m .62248 .36751 L .62135 .36332 L F
.62424 .36478 m .62318 .36641 L .62214 .36372 L F
.62318 .36641 m .62248 .36751 L .62214 .36372 L F
.295 .401 .801 r
.62424 .36478 m .62552 .36919 L .62248 .36751 L F
.96 .684 .467 r
.62025 .36469 m .62105 .36822 L .62369 .36773 L F
.62367 .36767 m .62369 .36773 L .62373 .36773 L F
.62025 .36469 m .62369 .36773 L .62367 .36767 L F
.6237 .36767 m .62373 .36773 L .62376 .36772 L F
.62025 .36469 m .62373 .36773 L .6237 .36767 L F
.225 .404 .831 r
.62411 .36841 m .62552 .36919 L .62501 .37 L F
.62411 .36841 m .62501 .37 L .62425 .3712 L F
.682 .978 .886 r
.62552 .36919 m .62224 .37143 L .62425 .3712 L F
.171 0 .129 r
.61906 .39433 m .61618 .39736 L .61888 .39659 L F
.498 .246 .462 r
.6215 .39608 m .61906 .39433 L .61888 .39659 L F
.57 .203 .306 r
.6215 .39608 m .62238 .39454 L .61906 .39433 L F
.789 .902 .921 r
.54379 .41023 m .54026 .41158 L .54356 .40961 L F
.718 .983 .79 r
.54327 .40891 m .54356 .40961 L .5411 .41078 L F
.339 .786 .957 r
.54378 .41014 m .54356 .40961 L .54341 .40719 L F
.794 .585 .021 r
.54341 .40719 m .54379 .41023 L .54356 .40961 L F
0 0 .252 r
.54341 .40719 m .54356 .40961 L .54456 .4078 L F
.718 .983 .79 r
.54456 .4078 m .54356 .40961 L .54327 .40891 L F
.339 .786 .957 r
.54379 .41023 m .54356 .40961 L .54378 .41014 L F
.54379 .41023 m .54646 .40989 L .54356 .40961 L F
.54356 .40961 m .54646 .40989 L .54379 .41023 L F
.614 .494 .693 r
.54735 .41288 m .54379 .41023 L .54646 .40989 L F
.54735 .41288 m .54457 .4142 L .54379 .41023 L F
0 0 .141 r
.43104 .57067 m .43077 .57322 L .42984 .57394 L F
0 0 .486 r
.43077 .57322 m .43101 .576 L .42984 .57394 L F
.989 .86 .502 r
.50697 .41693 m .50713 .41385 L .50711 .41626 L F
.134 .33 .794 r
.50697 .41693 m .51007 .41916 L .51008 .41662 L F
0 0 .232 r
.50749 .41964 m .50697 .41693 L .50711 .41626 L F
.50749 .41964 m .50727 .42022 L .50697 .41693 L F
.154 .51 .913 r
.38418 .45761 m .38279 .45868 L .38185 .45793 L F
.848 .692 .689 r
.46066 .56117 m .46412 .56179 L .46105 .5629 L F
.83 .43 .291 r
.37454 .51254 m .37265 .51416 L .37122 .5116 L F
.875 .504 .339 r
.37536 .5148 m .37265 .51416 L .37454 .51254 L F
.741 .989 .889 r
.56262 .4663 m .56863 .46271 L .56683 .46229 L F
.927 .956 .781 r
.56863 .46271 m .56753 .46194 L .56683 .46229 L F
.56863 .46271 m .5685 .46299 L .56753 .46194 L F
0 0 .419 r
.58073 .38074 m .58274 .38442 L .58191 .38271 L F
0 .039 .608 r
.58274 .38442 m .58412 .38486 L .58191 .38271 L F
.58274 .38442 m .58445 .38628 L .58412 .38486 L F
.422 .134 .367 r
.28813 .55366 m .28764 .55484 L .29081 .55247 L F
.8 .786 .84 r
.65089 .33881 m .65491 .33954 L .65337 .33736 L F
.783 .849 .9 r
.65337 .33736 m .65491 .33954 L .65705 .33741 L F
.913 .848 .766 r
.34938 .57157 m .3509 .57205 L .35247 .56823 L F
.939 .796 .675 r
.34949 .57413 m .3509 .57205 L .34938 .57157 L F
.896 .576 .434 r
.38732 .52922 m .38498 .53069 L .38439 .52794 L F
.38732 .52922 m .38758 .53159 L .38498 .53069 L F
.868 .995 .801 r
.32241 .6236 m .32097 .62556 L .32243 .62333 L F
.687 .776 .919 r
.48243 .44348 m .48376 .4395 L .48055 .44234 L F
.48243 .44348 m .4858 .44206 L .48376 .4395 L F
.662 .639 .816 r
.48243 .44348 m .48643 .44427 L .4858 .44206 L F
.388 .839 .744 r
.30378 .54852 m .30476 .54784 L .30615 .5474 L F
.046 .363 .834 r
.30378 .54852 m .30635 .54975 L .30476 .54784 L F
.799 .435 .367 r
.30289 .55029 m .30459 .55079 L .30635 .54975 L F
.2 .716 .881 r
.30441 .55035 m .30419 .55034 L .30462 .55022 L F
.911 .653 .535 r
.30635 .54975 m .30515 .55046 L .30462 .55022 L F
.30515 .55046 m .30461 .55039 L .30462 .55022 L F
.2 .716 .881 r
.30844 .55051 m .30441 .55035 L .30635 .54975 L F
.30462 .55022 m .30289 .55029 L .30509 .54994 L F
.978 .727 .484 r
.30441 .55035 m .30417 .5503 L .30263 .54852 L F
.2 .716 .881 r
.30419 .55034 m .30289 .55029 L .30462 .55022 L F
.907 .907 .811 r
.30289 .55029 m .30238 .54823 L .30417 .5503 L F
.2 .716 .881 r
.30419 .55034 m .30356 .55026 L .30289 .55029 L F
.907 .907 .811 r
.30289 .55029 m .30417 .5503 L .30459 .55079 L F
.978 .727 .484 r
.30459 .55024 m .30441 .55035 L .30431 .55024 L F
.2 .716 .881 r
.30488 .5503 m .30687 .55014 L .30394 .55025 L F
.30844 .55051 m .30765 .55033 L .30488 .5503 L F
.30765 .55033 m .30687 .55014 L .30488 .5503 L F
.04 .609 .723 r
.30687 .55014 m .30462 .55018 L .30335 .55026 L F
.30394 .55025 m .30335 .55026 L .30289 .55029 L F
.2 .716 .881 r
.30441 .55035 m .30509 .54994 L .30635 .54975 L F
.04 .609 .723 r
.30687 .55014 m .30335 .55026 L .30394 .55025 L F
.978 .727 .484 r
.30462 .55022 m .30459 .55024 L .30263 .54852 L F
.30459 .55024 m .30431 .55024 L .30263 .54852 L F
.30441 .55035 m .30428 .55043 L .30417 .5503 L F
.2 .716 .881 r
.30414 .55029 m .30394 .55025 L .30356 .55026 L F
.30844 .55051 m .30394 .55025 L .30414 .55029 L F
.30844 .55051 m .30356 .55026 L .30419 .55034 L F
.911 .653 .535 r
.30515 .55046 m .30459 .55079 L .30461 .55039 L F
.30635 .54975 m .30462 .55022 L .30476 .54784 L F
.978 .727 .484 r
.30476 .54784 m .30462 .55022 L .30263 .54852 L F
.30462 .55022 m .30459 .55079 L .30428 .55043 L F
.30476 .54784 m .30263 .54852 L .30238 .54823 L F
.388 .839 .744 r
.30615 .5474 m .30476 .54784 L .30632 .54732 L F
.574 .563 .804 r
.55439 .4458 m .55494 .44916 L .55786 .44663 L F
.793 .993 .764 r
.49522 .51086 m .49427 .5125 L .49499 .51041 L F
.794 .973 .678 r
.49427 .5125 m .49237 .51384 L .49499 .51041 L F
0 0 0 r
.52566 .43661 m .52167 .43947 L .52456 .43892 L F
.198 .256 .698 r
.52816 .43883 m .52566 .43661 L .52814 .43617 L F
.292 0 .079 r
.52814 .43617 m .52566 .43661 L .52456 .43892 L F
.282 0 0 r
.60766 .34439 m .61031 .34455 L .61156 .34401 L F
.097 0 0 r
.61156 .34401 m .61031 .34455 L .61428 .34372 L F
.671 .815 .953 r
.63057 .3446 m .63187 .34731 L .63494 .34508 L F
.736 .954 .945 r
.51868 .50508 m .52141 .5017 L .51783 .50401 L F
.51868 .50508 m .52257 .5025 L .52141 .5017 L F
.977 .684 .389 r
.37621 .61181 m .37471 .61049 L .37241 .61365 L F
.921 .852 .757 r
.37153 .61627 m .37621 .61181 L .37241 .61365 L F
.37153 .61627 m .37335 .61738 L .37621 .61181 L F
.7 .202 .056 r
.36672 .50574 m .36523 .50705 L .36287 .50485 L F
.739 .254 .088 r
.36672 .50574 m .36885 .50808 L .36523 .50705 L F
.353 0 .183 r
.24284 .56555 m .24136 .56779 L .23915 .56798 L F
0 0 0 r
.24439 .56416 m .24136 .56779 L .24284 .56555 L F
.269 .017 .334 r
.3094 .6701 m .31242 .66657 L .31205 .66926 L F
.665 .461 .6 r
.31205 .66926 m .30927 .6726 L .3094 .6701 L F
.868 .877 .841 r
.67429 .35083 m .67556 .35252 L .67307 .35525 L F
.138 0 0 r
.40858 .45294 m .41158 .45275 L .41259 .45234 L F
.05 0 0 r
.41158 .45275 m .41452 .45116 L .41259 .45234 L F
.794 .988 .738 r
.31163 .54676 m .31072 .54872 L .31346 .54554 L F
.523 .919 .867 r
.31141 .54885 m .31072 .54872 L .31163 .54676 L F
.31141 .54885 m .30977 .55014 L .31072 .54872 L F
.742 .353 .315 r
.41784 .6 m .42152 .60062 L .42003 .60254 L F
.422 0 0 r
.42152 .60062 m .42236 .60214 L .42003 .60254 L F
.42152 .60062 m .42422 .60084 L .42236 .60214 L F
.491 0 0 r
.37926 .4949 m .37739 .49381 L .37529 .49431 L F
.448 .092 .268 r
.38029 .493 m .37739 .49381 L .37926 .4949 L F
.404 0 .101 r
.63064 .33924 m .6328 .34065 L .63387 .33817 L F
.111 0 0 r
.63387 .33817 m .6328 .34065 L .63632 .33764 L F
.877 .903 .845 r
.51706 .41655 m .51661 .41864 L .51441 .41991 L F
.041 0 0 r
.51441 .41991 m .51661 .41864 L .51578 .42045 L F
0 0 .398 r
.51856 .4175 m .51661 .41864 L .51706 .41655 L F
.354 0 0 r
.41435 .45984 m .40982 .46127 L .40696 .46138 L F
0 0 0 r
.41279 .46041 m .41435 .45984 L .41418 .4598 L F
.41279 .46041 m .40982 .46127 L .41435 .45984 L F
.32 .171 .517 r
.6974 .29906 m .69954 .29815 L .69914 .29546 L F
.52 .349 .59 r
.6974 .29906 m .7003 .30068 L .69954 .29815 L F
.6974 .29906 m .69753 .30176 L .7003 .30068 L F
.901 .861 .792 r
.52131 .41254 m .52239 .40989 L .52011 .41133 L F
0 0 .195 r
.52092 .41118 m .52011 .41133 L .5189 .41063 L F
.901 .861 .792 r
.52131 .41254 m .52011 .41133 L .52028 .4137 L F
0 0 .195 r
.52092 .41118 m .52028 .4137 L .52011 .41133 L F
.831 .887 .882 r
.58792 .34612 m .58481 .34951 L .58317 .34748 L F
0 .412 .772 r
.58767 .34935 m .58317 .34748 L .58481 .34951 L F
.844 .518 .437 r
.36665 .54706 m .3702 .54585 L .36706 .54427 L F
.36665 .54706 m .37028 .54811 L .3702 .54585 L F
.133 .283 .752 r
.51877 .43962 m .52016 .4436 L .52134 .44155 L F
0 0 0 r
.52599 .44421 m .52608 .44296 L .5284 .44155 L F
.367 .59 .931 r
.52486 .44483 m .52534 .44457 L .52134 .44155 L F
.57 .02 0 r
.52134 .44155 m .52541 .44462 L .52547 .44479 L F
.367 .59 .931 r
.52486 .44483 m .52611 .44515 L .52534 .44457 L F
.57 .02 0 r
.52541 .44462 m .52611 .44515 L .52547 .44479 L F
.802 .632 .075 r
.52547 .44479 m .52553 .44776 L .52528 .4458 L F
.52547 .44479 m .52528 .4458 L .52566 .44536 L F
0 0 .254 r
.52611 .44515 m .52609 .44334 L .52547 .44479 L F
.52609 .44334 m .52608 .44296 L .52547 .44479 L F
0 0 0 r
.52547 .44479 m .5284 .44155 L .52833 .44418 L F
.52547 .44479 m .52559 .44443 L .52599 .44421 L F
.52559 .44443 m .52608 .44296 L .52599 .44421 L F
.606 .595 .814 r
.52547 .44479 m .52833 .44418 L .52738 .43998 L F
.802 .632 .075 r
.52547 .44479 m .52721 .44355 L .52833 .44418 L F
.509 .322 .562 r
.52833 .44418 m .52553 .44776 L .52547 .44479 L F
.802 .632 .075 r
.52547 .44479 m .52566 .44536 L .52721 .44355 L F
.367 .59 .931 r
.52016 .4436 m .52486 .44483 L .52134 .44155 L F
.839 .503 .419 r
.62731 .38929 m .62925 .38692 L .62759 .38781 L F
.62731 .38929 m .63114 .39029 L .62925 .38692 L F
.748 .485 .534 r
.63114 .39029 m .63226 .38813 L .62925 .38692 L F
.916 .91 .8 r
.59761 .4154 m .59646 .41721 L .59516 .41593 L F
.725 .507 .595 r
.27131 .52837 m .26981 .52573 L .27208 .52577 L F
.27131 .52837 m .26827 .52857 L .26853 .52809 L F
.27041 .52679 m .26853 .52809 L .26981 .52573 L F
.27131 .52837 m .26853 .52809 L .27041 .52679 L F
.865 .693 .666 r
.26981 .52573 m .26939 .52604 L .27208 .52577 L F
.828 .985 .877 r
.27178 .52364 m .27207 .52566 L .26939 .52604 L F
.27207 .52566 m .27208 .52577 L .27188 .52579 L F
.27207 .52566 m .27188 .52579 L .26939 .52604 L F
0 .323 .81 r
.27178 .52364 m .2723 .52498 L .27208 .52577 L F
.27178 .52364 m .2723 .52498 L .27208 .52577 L F
.372 .138 .425 r
.27355 .5275 m .27208 .52577 L .2723 .52498 L F
.27355 .5275 m .27131 .52837 L .27208 .52577 L F
.671 .785 .935 r
.47493 .5353 m .47087 .53769 L .47029 .53503 L F
.337 .803 .7 r
.44614 .44189 m .448 .44121 L .44457 .44273 L F
.338 .804 .707 r
.44364 .44302 m .44614 .44189 L .44457 .44273 L F
.273 .764 .691 r
.44108 .44399 m .44364 .44302 L .44424 .44284 L F
0 0 0 r
.44181 .44381 m .44364 .44302 L .44108 .44399 L F
.38 .837 .762 r
.44261 .44332 m .44364 .44302 L .44181 .44381 L F
.44392 .44251 m .44364 .44302 L .44261 .44332 L F
.273 .764 .691 r
.44424 .44284 m .44364 .44302 L .44457 .44273 L F
.519 .505 .781 r
.34943 .54432 m .3482 .54818 L .34665 .54486 L F
0 0 .401 r
.34665 .54486 m .3482 .54818 L .34773 .54691 L F
.519 .505 .781 r
.34943 .54432 m .35066 .54792 L .3482 .54818 L F
0 0 0 r
.62801 .34551 m .62407 .34671 L .62523 .34565 L F
.314 .521 .896 r
.3272 .52494 m .32706 .52758 L .3242 .52672 L F
.3272 .52494 m .32922 .52754 L .32706 .52758 L F
.77 .794 .873 r
.34177 .64694 m .34475 .6467 L .34394 .64325 L F
.775 .797 .871 r
.34475 .6467 m .34825 .64375 L .34394 .64325 L F
.703 .426 .502 r
.35565 .53892 m .35647 .54161 L .35233 .54114 L F
.697 .7 .849 r
.33195 .64709 m .33573 .64857 L .33438 .64656 L F
.577 .689 .918 r
.33573 .64857 m .33698 .6459 L .33438 .64656 L F
.33573 .64857 m .33902 .64834 L .33698 .6459 L F
.868 .877 .841 r
.67429 .35083 m .67307 .35525 L .67103 .35401 L F
.901 .721 .649 r
.67307 .35525 m .67255 .35799 L .67103 .35401 L F
0 0 0 r
.28176 .58823 m .27902 .5913 L .28094 .59009 L F
.47 .301 .57 r
.27785 .59435 m .28094 .59009 L .27902 .5913 L F
.501 .282 .512 r
.58127 .36204 m .58119 .36495 L .57826 .36533 L F
.711 .612 .744 r
.52944 .46915 m .53035 .47293 L .53314 .47021 L F
0 .219 .742 r
.3459 .55158 m .3465 .54978 L .34383 .55062 L F
.3459 .55158 m .34852 .55425 L .3465 .54978 L F
.748 .232 0 r
.23835 .57833 m .23627 .57723 L .23432 .57465 L F
0 .078 .631 r
.23835 .57833 m .23842 .57736 L .23627 .57723 L F
.23835 .57833 m .24119 .5816 L .23842 .57736 L F
0 0 0 r
.51787 .48776 m .51621 .48937 L .51536 .49119 L F
.783 .903 .503 r
.50031 .50631 m .49913 .50819 L .5012 .50426 L F
.803 .71 .762 r
.2903 .66556 m .29191 .6697 L .29029 .66954 L F
.806 .711 .76 r
.29394 .66608 m .29191 .6697 L .2903 .66556 L F
.668 .588 .756 r
.38977 .48861 m .38782 .49176 L .38762 .48815 L F
.38977 .48861 m .39049 .49271 L .38782 .49176 L F
.6 .373 .543 r
.68939 .31187 m .69279 .30866 L .6892 .30895 L F
.68939 .31187 m .69331 .31171 L .69279 .30866 L F
.553 .391 .616 r
.69279 .30866 m .69591 .30835 L .69505 .3053 L F
.59 .397 .588 r
.69331 .31171 m .69591 .30835 L .69279 .30866 L F
.945 .629 .405 r
.35893 .53099 m .36118 .53439 L .36097 .53239 L F
.65 .682 .867 r
.48643 .44427 m .48774 .44164 L .4858 .44206 L F
.48643 .44427 m .48928 .44363 L .48774 .44164 L F
.674 .954 .951 r
.29784 .50587 m .29647 .50539 L .29851 .50403 L F
.29784 .50587 m .29647 .50539 L .29851 .50403 L F
.393 .85 .809 r
.61951 .34224 m .62375 .34098 L .62108 .34182 L F
.216 .735 .859 r
.43485 .60061 m .4351 .60007 L .43308 .60062 L F
.43485 .60061 m .43741 .60031 L .4351 .60007 L F
.811 .609 .63 r
.68507 .31095 m .6892 .30895 L .6853 .30824 L F
.68507 .31095 m .68939 .31187 L .6892 .30895 L F
.862 .99 .836 r
.35726 .57225 m .35448 .5753 L .35458 .57287 L F
.89 .99 .762 r
.35458 .57287 m .35448 .5753 L .35207 .57644 L F
.578 .776 .973 r
.61731 .37154 m .62007 .37102 L .619 .36928 L F
.554 .567 .822 r
.34696 .56053 m .34835 .56497 L .35075 .56433 L F
.16 0 .358 r
.34872 .5677 m .35075 .56433 L .34835 .56497 L F
.706 .686 .828 r
.57692 .36264 m .57826 .36533 L .57424 .36409 L F
.933 .954 .771 r
.56753 .46194 m .57062 .45925 L .57053 .45892 L F
0 0 .555 r
.57431 .37141 m .57559 .37348 L .57447 .36934 L F
.999 .839 .546 r
.69539 .35945 m .6971 .35806 L .69612 .35676 L F
.69539 .35945 m .69651 .36084 L .6971 .35806 L F
0 .095 .593 r
.59562 .42685 m .59946 .43041 L .59804 .42914 L F
.573 .883 .992 r
.59946 .43041 m .59537 .43039 L .59804 .42914 L F
.414 .02 .18 r
.28176 .58823 m .28378 .58947 L .28489 .58705 L F
.28176 .58823 m .28094 .59009 L .28378 .58947 L F
.572 .412 .626 r
.24777 .55819 m .24782 .5616 L .24508 .562 L F
.516 .175 .329 r
.24708 .56366 m .24508 .562 L .24782 .5616 L F
.24708 .56366 m .24439 .56416 L .24508 .562 L F
.926 .927 .555 r
.34722 .53454 m .34682 .53365 L .34791 .53305 L F
.302 .774 .662 r
.34682 .53365 m .35092 .53185 L .34791 .53305 L F
.89 .465 .147 r
.42437 .54293 m .42441 .54296 L .42527 .54372 L F
.837 .477 0 r
.42527 .54372 m .42623 .54519 L .42576 .54415 L F
0 .062 .567 r
.42729 .54595 m .42623 .54519 L .42527 .54372 L F
.89 .465 .147 r
.42441 .54296 m .42729 .54595 L .42527 .54372 L F
.837 .477 0 r
.42527 .54372 m .42576 .54415 L .42453 .54143 L F
0 .062 .567 r
.42729 .54595 m .4286 .54736 L .42623 .54519 L F
.796 .722 .782 r
.3953 .48356 m .39201 .48313 L .39494 .48161 L F
0 0 .275 r
.39545 .48295 m .3953 .48356 L .39494 .48161 L F
0 .322 .767 r
.39764 .48435 m .3953 .48356 L .39545 .48295 L F
.776 .275 0 r
.34136 .50672 m .34208 .50599 L .34047 .50461 L F
.34136 .50672 m .34399 .50871 L .34208 .50599 L F
.8 .32 .072 r
.34208 .50599 m .34399 .50871 L .34616 .50923 L F
.913 .848 .766 r
.34938 .57157 m .35247 .56823 L .35063 .56986 L F
.668 .96 .939 r
.35323 .56642 m .35247 .56823 L .35531 .56663 L F
.735 .937 .608 r
.35323 .56642 m .35063 .56986 L .35247 .56823 L F
.683 .836 .957 r
.5517 .38959 m .55328 .39126 L .55516 .38962 L F
.924 .716 .603 r
.59165 .43792 m .59507 .43887 L .59419 .4366 L F
.23 .343 .773 r
.59419 .4366 m .59507 .43887 L .59682 .43899 L F
.888 .892 .827 r
.36514 .61086 m .36262 .61427 L .36082 .61315 L F
0 0 .205 r
.42579 .53422 m .42432 .53876 L .42372 .53452 L F
.42579 .53422 m .42564 .53701 L .42432 .53876 L F
.32 0 .181 r
.64371 .3426 m .64115 .34366 L .64156 .34211 L F
.795 .707 .767 r
.46473 .53824 m .46892 .53845 L .46624 .54185 L F
.754 .995 .826 r
.53803 .47874 m .53886 .47674 L .54049 .47749 L F
.53803 .47874 m .53698 .47862 L .53886 .47674 L F
.423 .165 .417 r
.62092 .40195 m .62347 .40293 L .61881 .40288 L F
.62092 .40195 m .6232 .40072 L .62347 .40293 L F
.482 .892 .924 r
.4558 .44947 m .45956 .44877 L .45792 .44799 L F
.581 .936 .932 r
.45956 .44877 m .46043 .44732 L .45792 .44799 L F
.45956 .44877 m .46279 .4473 L .46043 .44732 L F
.899 .518 .297 r
.32844 .58476 m .32875 .58718 L .32654 .58614 L F
.32844 .58476 m .32875 .58718 L .32654 .58614 L F
.222 .741 .746 r
.62644 .34013 m .62918 .33943 L .63064 .33924 L F
0 .165 .704 r
.63197 .33896 m .63064 .33924 L .62918 .33943 L F
.63197 .33896 m .6328 .34065 L .63064 .33924 L F
.723 .672 .8 r
.26921 .59852 m .27089 .60101 L .26666 .60061 L F
.605 .123 .083 r
.27089 .60101 m .26894 .6026 L .26666 .60061 L F
.27089 .60101 m .2728 .60275 L .26894 .6026 L F
.553 .146 .223 r
.27349 .60103 m .2728 .60275 L .27089 .60101 L F
.453 .088 .255 r
.32377 .65995 m .32454 .65828 L .32645 .65922 L F
.925 .817 .721 r
.46103 .55406 m .46298 .55527 L .46146 .55785 L F
.948 .844 .707 r
.57988 .45005 m .58151 .44636 L .57992 .44509 L F
.811 .763 .808 r
.66209 .39539 m .65971 .39418 L .66268 .39306 L F
.902 .983 .72 r
.6591 .39762 m .66209 .39539 L .66117 .39704 L F
0 0 .177 r
.66325 .39418 m .66209 .39539 L .66268 .39306 L F
0 0 0 r
.66117 .39704 m .66209 .39539 L .66325 .39418 L F
.56 .575 .825 r
.31845 .64739 m .31945 .64301 L .31703 .64415 L F
.31845 .64739 m .32113 .64697 L .31945 .64301 L F
0 0 0 r
.52896 .42602 m .53017 .42441 L .53184 .42284 L F
.467 .879 .744 r
.47159 .4267 m .4692 .4281 L .46743 .42875 L F
.526 .771 .987 r
.36259 .63122 m .36358 .62911 L .36113 .63008 L F
.36259 .63122 m .36545 .63066 L .36358 .62911 L F
.552 .397 .625 r
.64083 .38393 m .6439 .38313 L .6431 .38088 L F
.207 .729 .721 r
.64209 .38353 m .64083 .38393 L .63906 .38487 L F
0 .488 .748 r
.64222 .3834 m .64209 .38353 L .64065 .38304 L F
.207 .729 .721 r
.64209 .38353 m .6439 .38313 L .64199 .38362 L F
.742 .263 .108 r
.6458 .38588 m .6439 .38313 L .64209 .38353 L F
0 .488 .748 r
.64468 .38398 m .64209 .38353 L .64222 .3834 L F
.207 .729 .721 r
.64209 .38353 m .64199 .38362 L .64083 .38393 L F
.039 0 .077 r
.49068 .45262 m .48875 .45403 L .48783 .45568 L F
.83 .993 .859 r
.37271 .47102 m .37269 .47301 L .37161 .4726 L F
.37271 .47102 m .37269 .47301 L .37161 .4726 L F
.455 .804 .998 r
.30959 .54499 m .31204 .54447 L .31237 .54472 L F
.31046 .54509 m .31237 .54472 L .31327 .54539 L F
.30959 .54499 m .31237 .54472 L .31046 .54509 L F
.31319 .5455 m .31327 .54539 L .31346 .54554 L F
.30959 .54499 m .31327 .54539 L .31319 .5455 L F
.725 .916 .959 r
.31346 .54554 m .31229 .54466 L .31537 .54281 L F
.31229 .54466 m .31204 .54447 L .31356 .54371 L F
.31229 .54466 m .31356 .54371 L .31537 .54281 L F
.648 .508 .679 r
.31537 .54281 m .31204 .54447 L .314 .54069 L F
.725 .916 .959 r
.31346 .54554 m .31204 .54447 L .31537 .54281 L F
.474 .275 .53 r
.31537 .54281 m .31163 .54676 L .31204 .54447 L F
.884 .533 .377 r
.314 .54069 m .3151 .54328 L .31537 .54281 L F
.485 .359 .633 r
.314 .54069 m .31487 .54274 L .31622 .5402 L F
.31487 .54274 m .3151 .54328 L .31546 .5423 L F
.31487 .54274 m .31546 .5423 L .31622 .5402 L F
.474 .275 .53 r
.31384 .54443 m .31491 .54628 L .31163 .54676 L F
.31537 .54281 m .31519 .54417 L .31384 .54443 L F
.31519 .54417 m .31491 .54628 L .31384 .54443 L F
.6 .899 .616 r
.31163 .54676 m .3151 .54328 L .31204 .54447 L F
.31163 .54676 m .31242 .54547 L .31452 .54376 L F
.31417 .54421 m .31452 .54376 L .3151 .54328 L F
.31163 .54676 m .31452 .54376 L .31417 .54421 L F
.835 .917 .891 r
.40604 .45353 m .40215 .45481 L .40434 .45496 L F
.365 0 0 r
.40434 .45496 m .40858 .45294 L .40604 .45353 L F
.809 .389 0 r
.59049 .41041 m .59257 .41378 L .59132 .4125 L F
0 .147 .656 r
.59257 .41378 m .59456 .41497 L .59132 .4125 L F
.59257 .41378 m .59516 .41593 L .59456 .41497 L F
.932 .554 .19 r
.3893 .53557 m .38835 .53679 L .38779 .53432 L F
.3893 .53557 m .38997 .538 L .38835 .53679 L F
.601 .902 .623 r
.67043 .38334 m .67363 .38053 L .67224 .38141 L F
.524 .9 .723 r
.67363 .38053 m .67715 .3782 L .6755 .37888 L F
.497 .86 .623 r
.67224 .38141 m .67363 .38053 L .6755 .37888 L F
.967 .832 .656 r
.59551 .40818 m .59772 .40734 L .59636 .40598 L F
.59551 .40818 m .59727 .40991 L .59772 .40734 L F
.883 .9 .837 r
.59636 .40598 m .59772 .40734 L .60046 .40395 L F
.142 .175 .636 r
.23432 .57465 m .23627 .57723 L .23581 .57327 L F
.938 .809 .692 r
.37964 .59444 m .3809 .60029 L .3805 .59735 L F
.244 .044 .398 r
.5955 .36748 m .59552 .37039 L .59313 .3711 L F
0 0 0 r
.59456 .37163 m .59313 .3711 L .59552 .37039 L F
.59456 .37163 m .59222 .37302 L .59313 .3711 L F
.663 .941 .963 r
.538 .4873 m .53693 .48928 L .53897 .48799 L F
.651 .929 .972 r
.53572 .48855 m .53693 .48928 L .538 .4873 L F
.944 .933 .757 r
.35788 .56924 m .35642 .57244 L .35458 .57287 L F
.35909 .56791 m .35458 .57287 L .35754 .57006 L F
.973 .715 .48 r
.35865 .56755 m .35909 .56791 L .35754 .57006 L F
0 0 0 r
.359 .56683 m .35872 .5674 L .35754 .57006 L F
.35872 .5674 m .35865 .56755 L .35849 .56791 L F
.35872 .5674 m .35849 .56791 L .35754 .57006 L F
.944 .933 .757 r
.35909 .56791 m .35726 .57225 L .35642 .57244 L F
.35909 .56791 m .35642 .57244 L .35788 .56924 L F
.799 .317 .069 r
.34399 .50871 m .34478 .51024 L .34616 .50923 L F
.851 .399 .125 r
.34616 .50923 m .34478 .51024 L .34675 .51091 L F
0 0 0 r
.55209 .4014 m .54763 .4026 L .55044 .4012 L F
.546 .928 .896 r
.55457 .40013 m .55209 .4014 L .55044 .4012 L F
.713 .96 .945 r
.63626 .4018 m .64054 .4005 L .63938 .39929 L F
.611 .863 .991 r
.63938 .39929 m .64054 .4005 L .64336 .39897 L F
.025 .237 .741 r
.46624 .54185 m .46718 .54036 L .46473 .53824 L F
.46 0 0 r
.27641 .51937 m .27464 .5208 L .27204 .52086 L F
.325 0 0 r
.27832 .52009 m .27641 .51937 L .27865 .51797 L F
.27832 .52009 m .27464 .5208 L .27641 .51937 L F
.718 .862 .95 r
.36662 .49123 m .36374 .49284 L .36216 .49164 L F
.978 .734 .497 r
.36374 .49284 m .36197 .49452 L .36216 .49164 L F
.63 .593 .793 r
.23269 .56833 m .23684 .57147 L .23497 .56781 L F
.517 .474 .747 r
.34822 .5842 m .34984 .57966 L .34798 .58133 L F
.471 .269 .524 r
.44373 .45383 m .44624 .45402 L .44211 .45208 L F
.44373 .45383 m .44621 .45535 L .44624 .45402 L F
.986 .9 .622 r
.35161 .53193 m .35092 .53185 L .35214 .52822 L F
.621 .769 .951 r
.56023 .40957 m .56426 .4104 L .5633 .40822 L F
0 .113 .664 r
.56426 .4104 m .56422 .40887 L .5633 .40822 L F
0 .223 .709 r
.56426 .4104 m .56561 .41084 L .56422 .40887 L F
.401 .783 .991 r
.634 .38994 m .63516 .3909 L .63114 .39029 L F
.692 .919 .97 r
.63757 .38932 m .63516 .3909 L .6365 .38845 L F
.698 .926 .967 r
.6365 .38845 m .63516 .3909 L .634 .38994 L F
.735 .84 .394 r
.46042 .55077 m .46207 .54669 L .462 .54923 L F
.46042 .55077 m .46027 .55063 L .46207 .54669 L F
.402 .094 .324 r
.54415 .41635 m .54457 .4142 L .54735 .41288 L F
.306 .459 .849 r
.57425 .42279 m .57084 .41942 L .57263 .42166 L F
0 0 .481 r
.57263 .42166 m .57084 .41942 L .57062 .41882 L F
.594 .588 .816 r
.30753 .64424 m .30868 .64022 L .3062 .64064 L F
.30753 .64424 m .31018 .64362 L .30868 .64022 L F
.462 .864 .691 r
.48107 .42076 m .47698 .42309 L .4789 .4216 L F
.671 .897 .549 r
.48107 .42076 m .48221 .41879 L .48371 .41735 L F
.698 .979 .796 r
.48107 .42076 m .4789 .4216 L .48221 .41879 L F
.718 .918 .568 r
.39302 .48916 m .39049 .49271 L .39338 .49226 L F
.032 .121 .625 r
.39011 .48903 m .38983 .48893 L .38977 .48861 L F
.39188 .49127 m .38977 .48861 L .39302 .48916 L F
.003 .554 .824 r
.3869 .4877 m .38977 .48861 L .38762 .48815 L F
.777 .996 .865 r
.39201 .48313 m .38894 .48595 L .39016 .48423 L F
.708 .472 .565 r
.3869 .4877 m .39016 .48423 L .38894 .48595 L F
0 0 0 r
.39188 .49127 m .39225 .49059 L .39296 .49009 L F
.39225 .49059 m .39302 .48916 L .39296 .49009 L F
.708 .472 .565 r
.3869 .4877 m .39296 .49009 L .39016 .48423 L F
.349 .723 .986 r
.39271 .48957 m .39296 .49009 L .38967 .48874 L F
.645 .734 .914 r
.39302 .48916 m .3973 .48992 L .39542 .48668 L F
.72 .532 .636 r
.39338 .49226 m .3973 .48992 L .39302 .48916 L F
0 0 0 r
.39296 .49009 m .39302 .48916 L .39542 .48668 L F
.545 .401 .637 r
.39016 .48423 m .39296 .49009 L .39399 .48634 L F
.349 .723 .986 r
.39343 .48977 m .39296 .49009 L .39271 .48957 L F
.39405 .48993 m .39296 .49009 L .39343 .48977 L F
.534 .724 .961 r
.38967 .48874 m .391 .48642 L .38807 .48805 L F
.38967 .48874 m .38807 .48805 L .38793 .48813 L F
0 .349 .688 r
.38967 .48874 m .39207 .48973 L .39071 .48919 L F
.38967 .48874 m .39071 .48919 L .3869 .4877 L F
.39207 .48973 m .39296 .49009 L .39172 .4896 L F
.39207 .48973 m .39172 .4896 L .3869 .4877 L F
0 0 0 r
.39188 .49127 m .39296 .49009 L .39405 .48993 L F
.403 .825 .651 r
.39253 .49084 m .39188 .49127 L .39405 .48993 L F
.032 .121 .625 r
.39188 .49127 m .39041 .49226 L .38983 .48893 L F
.403 .825 .651 r
.38972 .4925 m .39188 .49127 L .39253 .49084 L F
.032 .121 .625 r
.39188 .49127 m .39049 .49271 L .39041 .49226 L F
.39188 .49127 m .38983 .48893 L .39011 .48903 L F
.893 .721 .212 r
.38972 .4925 m .39049 .49271 L .39188 .49127 L F
.38972 .4925 m .39031 .49519 L .39049 .49271 L F
.645 .424 .568 r
.39031 .49519 m .39338 .49226 L .39049 .49271 L F
.629 .926 .973 r
.31763 .52435 m .31588 .52561 L .31451 .52546 L F
.14 0 .309 r
.31763 .52435 m .31536 .52807 L .31588 .52561 L F
.309 .275 .658 r
.2602 .52769 m .25886 .53245 L .25833 .53127 L F
.2602 .52769 m .26127 .53194 L .25886 .53245 L F
.296 .223 .602 r
.26127 .53194 m .26128 .53374 L .25886 .53245 L F
.249 .244 .658 r
.26128 .53374 m .25983 .53557 L .25886 .53245 L F
0 0 0 r
.34472 .54581 m .344 .54475 L .34665 .54486 L F
.472 .624 .918 r
.70561 .2933 m .70413 .29484 L .70244 .29441 L F
.70561 .2933 m .70675 .29454 L .70413 .29484 L F
.88 .764 .73 r
.64371 .3426 m .64797 .34119 L .64697 .3404 L F
.672 .976 .859 r
.65089 .33881 m .64939 .339 L .64797 .34119 L F
.634 .945 .952 r
.64939 .339 m .64697 .3404 L .64797 .34119 L F
.72 .532 .636 r
.39338 .49226 m .39709 .49239 L .3973 .48992 L F
.82 .803 .835 r
.3973 .48992 m .399 .48829 L .39826 .48514 L F
.223 0 .176 r
.53408 .41324 m .53577 .41468 L .53689 .41263 L F
.53408 .41324 m .53329 .41575 L .53577 .41468 L F
.926 .753 .648 r
.53508 .45254 m .5366 .4565 L .53378 .455 L F
.506 .839 .998 r
.53806 .45471 m .5366 .4565 L .53508 .45254 L F
.53806 .45471 m .53956 .45576 L .5366 .4565 L F
.463 .304 .579 r
.53956 .45576 m .53697 .45937 L .5366 .4565 L F
.883 .9 .837 r
.59636 .40598 m .60046 .40395 L .59874 .40441 L F
0 .424 .857 r
.60046 .40395 m .60135 .40335 L .59874 .40441 L F
.60046 .40395 m .60331 .4053 L .60135 .40335 L F
.955 .796 .35 r
.5628 .42039 m .56228 .4196 L .56268 .41686 L F
.959 .817 .383 r
.5618 .42178 m .56228 .4196 L .5628 .42039 L F
0 0 0 r
.65796 .32475 m .66021 .32339 L .66108 .32185 L F
.65796 .32475 m .65717 .32622 L .66021 .32339 L F
.559 .835 .997 r
.31242 .66657 m .3078 .66605 L .31031 .66306 L F
.491 .612 .9 r
.31453 .66593 m .31242 .66657 L .31031 .66306 L F
.612 .539 .748 r
.31453 .66593 m .31205 .66926 L .31242 .66657 L F
.386 .833 .721 r
.51028 .43528 m .51464 .43333 L .51314 .43396 L F
.044 .607 .79 r
.51464 .43333 m .51598 .43322 L .51314 .43396 L F
.51464 .43333 m .51734 .43346 L .51598 .43322 L F
.889 .982 .815 r
.462 .54923 m .46207 .54669 L .46321 .54737 L F
.627 .1 0 r
.58578 .36728 m .58766 .36902 L .58928 .36803 L F
.676 .346 0 r
.58928 .36803 m .58772 .36397 L .59179 .36471 L F
.436 .362 .675 r
.58766 .36902 m .58866 .36651 L .5888 .36685 L F
.688 .767 .912 r
.59 .36284 m .59179 .36471 L .58772 .36397 L F
.676 .346 0 r
.58902 .36734 m .5888 .36685 L .58772 .36397 L F
.004 .056 .565 r
.58772 .36397 m .5888 .36685 L .58958 .36418 L F
.436 .362 .675 r
.58866 .36651 m .58958 .36418 L .5888 .36685 L F
.676 .346 0 r
.58928 .36803 m .5888 .36685 L .58902 .36734 L F
.948 .943 .62 r
.58928 .36803 m .58766 .36902 L .5888 .36685 L F
.783 .508 .521 r
.55855 .38431 m .56141 .3837 L .55847 .38393 L F
.966 .641 .297 r
.32883 .50575 m .32753 .50487 L .32712 .50197 L F
.952 .745 .587 r
.32897 .50776 m .32753 .50487 L .32883 .50575 L F
.511 .351 .601 r
.59722 .36026 m .59519 .36335 L .59446 .36056 L F
.438 .784 .997 r
.59305 .35954 m .59519 .35931 L .59722 .36026 L F
.769 .535 .581 r
.59442 .36101 m .59177 .36363 L .59502 .36285 L F
.761 .634 .071 r
.59506 .3616 m .59506 .36176 L .59519 .36335 L F
.438 .784 .997 r
.59523 .35992 m .59722 .36026 L .59527 .36047 L F
.761 .634 .071 r
.59519 .35931 m .59519 .36335 L .59722 .36026 L F
.59519 .35939 m .59506 .3616 L .59519 .36335 L F
0 .189 .716 r
.59505 .36173 m .59676 .36444 L .59519 .36335 L F
.769 .535 .581 r
.59506 .3618 m .59502 .36285 L .59577 .36267 L F
.59442 .36101 m .59502 .36285 L .59506 .3618 L F
.761 .634 .071 r
.59506 .3616 m .59505 .36173 L .59506 .36176 L F
.59519 .35931 m .59519 .35936 L .59519 .35939 L F
.438 .784 .997 r
.59523 .35992 m .59527 .36047 L .59446 .36056 L F
.761 .634 .071 r
.59519 .35936 m .59505 .36173 L .59519 .35939 L F
.438 .784 .997 r
.59305 .35954 m .59523 .35992 L .59446 .36056 L F
.252 .395 .813 r
.60219 .42541 m .60192 .42709 L .60038 .42377 L F
.665 .764 .924 r
.6097 .4049 m .611 .40686 L .61033 .40394 L F
.867 .88 .844 r
.61033 .40394 m .611 .40686 L .61364 .4036 L F
.113 0 .204 r
.66509 .37418 m .66299 .37714 L .66487 .37624 L F
0 0 0 r
.66769 .37018 m .66509 .37418 L .66734 .37246 L F
0 0 .013 r
.66734 .37246 m .66509 .37418 L .66487 .37624 L F
.893 .613 .505 r
.35731 .52467 m .35971 .528 L .35953 .5256 L F
.911 .936 .569 r
.4981 .53176 m .49762 .5313 L .49659 .53493 L F
.885 .967 .644 r
.49972 .5277 m .4981 .53176 L .49994 .52825 L F
.49972 .5277 m .49762 .5313 L .4981 .53176 L F
.89 .906 .497 r
.5012 .50426 m .50077 .50413 L .50211 .50249 L F
.75 .986 .763 r
.50502 .49957 m .50211 .50249 L .50296 .5005 L F
.716 .881 .484 r
.50211 .50249 m .50077 .50413 L .50296 .5005 L F
.833 .772 .264 r
.47745 .57795 m .47682 .57968 L .47694 .58011 L F
.663 .965 .775 r
.47973 .57428 m .47674 .57539 L .47745 .57795 L F
.894 .765 .268 r
.47674 .57539 m .47682 .57968 L .47745 .57795 L F
.56 .426 .655 r
.69505 .3053 m .69858 .30538 L .69753 .30176 L F
.637 .507 .688 r
.69591 .30835 m .69858 .30538 L .69505 .3053 L F
.866 .846 .822 r
.59198 .44251 m .59165 .43792 L .58895 .44075 L F
.899 .506 .263 r
.34186 .51813 m .33889 .51501 L .3402 .5167 L F
.368 .292 .638 r
.23388 .55829 m .2357 .55758 L .23572 .55374 L F
.365 .138 .43 r
.23388 .55829 m .23555 .56041 L .2357 .55758 L F
.23388 .55829 m .23344 .56112 L .23555 .56041 L F
.516 .468 .742 r
.23269 .56833 m .23497 .56781 L .23434 .56392 L F
.845 .958 .884 r
.62978 .40518 m .62921 .40807 L .63089 .40635 L F
.62978 .40518 m .62704 .40789 L .62921 .40807 L F
0 0 0 r
.66108 .32185 m .66021 .32339 L .66228 .32195 L F
.924 .61 .43 r
.37122 .5116 m .36885 .50808 L .37112 .50908 L F
.427 .856 .728 r
.45035 .4399 m .448 .44121 L .44614 .44189 L F
.559 .851 .528 r
.48371 .41735 m .48507 .41573 L .48566 .41596 L F
.48371 .41735 m .48221 .41879 L .48507 .41573 L F
.839 .418 .236 r
.34675 .51091 m .34842 .51387 L .35015 .51247 L F
.873 .474 .273 r
.35015 .51247 m .34842 .51387 L .35064 .5145 L F
0 0 0 r
.59687 .39272 m .59456 .39401 L .5975 .39087 L F
.918 .761 .671 r
.6052 .43205 m .60611 .43026 L .60409 .4291 L F
.21 0 .065 r
.59941 .39201 m .5975 .39087 L .59988 .39227 L F
.59941 .39201 m .59687 .39272 L .5975 .39087 L F
.598 .574 .798 r
.60287 .40047 m .59894 .39743 L .60164 .39943 L F
.872 .91 .853 r
.36807 .62402 m .36911 .6199 L .36692 .62318 L F
.36807 .62402 m .37086 .62091 L .36911 .6199 L F
.892 .963 .833 r
.36564 .6243 m .36807 .62402 L .36692 .62318 L F
0 .152 .641 r
.41418 .4598 m .41512 .46016 L .41279 .46041 L F
.516 .042 .068 r
.4169 .45998 m .41598 .4611 L .41418 .4598 L F
0 .152 .641 r
.41418 .4598 m .41598 .4611 L .41512 .46016 L F
.831 .425 .278 r
.36465 .54347 m .36668 .54218 L .36423 .54125 L F
.36465 .54347 m .36706 .54427 L .36668 .54218 L F
.366 0 0 r
.33206 .50026 m .33675 .49971 L .33409 .49866 L F
.83 .992 .861 r
.39981 .45481 m .39716 .45708 L .39772 .45509 L F
.063 0 0 r
.39772 .45509 m .40215 .45481 L .39981 .45481 L F
.988 .806 .569 r
.59477 .41179 m .59727 .40991 L .59551 .40818 L F
.59477 .41179 m .59628 .41352 L .59727 .40991 L F
.953 .704 .523 r
.72466 .30338 m .7273 .30236 L .724 .30128 L F
.72466 .30338 m .72634 .30469 L .7273 .30236 L F
.98 .913 .648 r
.5576 .39196 m .55564 .39409 L .55582 .39314 L F
.957 .716 .532 r
.55943 .39076 m .5576 .39196 L .55516 .38962 L F
0 .112 .637 r
.55516 .38962 m .5576 .39196 L .55637 .39017 L F
.98 .913 .648 r
.5576 .39196 m .55582 .39314 L .55637 .39017 L F
.957 .716 .532 r
.55969 .39083 m .5576 .39196 L .55943 .39076 L F
.55969 .39083 m .55929 .3932 L .5576 .39196 L F
0 0 0 r
.38566 .46039 m .38344 .46068 L .38579 .46065 L F
.38566 .46039 m .38202 .46147 L .38344 .46068 L F
.993 .811 .558 r
.58954 .40353 m .59001 .40757 L .58959 .4061 L F
.967 .675 .264 r
.59001 .40757 m .58863 .40715 L .58959 .4061 L F
.59001 .40757 m .59049 .41041 L .58863 .40715 L F
.262 .072 .424 r
.24996 .55473 m .24968 .55776 L .24777 .55819 L F
.734 .541 .632 r
.25136 .56143 m .24777 .55819 L .24968 .55776 L F
.25136 .56143 m .24782 .5616 L .24777 .55819 L F
.797 .941 .921 r
.50782 .40183 m .50353 .40318 L .50565 .40131 L F
.637 .937 .964 r
.50565 .40131 m .51032 .4004 L .50782 .40183 L F
.603 .515 .727 r
.32959 .57366 m .32547 .57549 L .32557 .57144 L F
.34 .014 .257 r
.32959 .57366 m .32557 .57745 L .32547 .57549 L F
0 0 0 r
.4471 .59812 m .44781 .59823 L .44518 .59815 L F
.051 .613 .791 r
.44518 .59815 m .44781 .59823 L .44594 .59809 L F
.208 0 0 r
.4443 .59765 m .44518 .59815 L .44362 .59827 L F
.051 .613 .791 r
.44518 .59815 m .44594 .59809 L .44362 .59793 L F
.208 0 0 r
.44362 .59827 m .44518 .59815 L .44259 .59922 L F
.4443 .59765 m .4471 .59812 L .44518 .59815 L F
.759 .463 .484 r
.32695 .59995 m .33115 .60036 L .33038 .59785 L F
0 0 .514 r
.33038 .59785 m .3324 .59878 L .33217 .59583 L F
.33038 .59785 m .33115 .60036 L .3324 .59878 L F
.758 .697 .794 r
.34571 .56851 m .34595 .57106 L .34872 .5677 L F
.983 .839 .624 r
.34571 .56851 m .34404 .56994 L .34595 .57106 L F
.59 .448 .656 r
.34595 .57106 m .34938 .57157 L .34872 .5677 L F
.622 .516 .712 r
.34595 .57106 m .34949 .57413 L .34938 .57157 L F
.664 .97 .808 r
.45168 .45163 m .45049 .45339 L .45229 .45183 L F
.61 .93 .965 r
.44769 .45347 m .45049 .45339 L .45168 .45163 L F
.711 .612 .744 r
.52944 .46915 m .53314 .47021 L .53114 .46854 L F
.532 .213 .372 r
.53438 .46819 m .53114 .46854 L .53314 .47021 L F
.3 0 0 r
.32318 .57821 m .31831 .5792 L .32029 .57791 L F
.798 .679 .733 r
.39716 .45708 m .39697 .45996 L .39247 .45936 L F
.755 .244 0 r
.39664 .46233 m .39247 .45936 L .39697 .45996 L F
.52 .244 .437 r
.3997 .45954 m .39664 .46233 L .39697 .45996 L F
.908 .661 .554 r
.37857 .57133 m .37709 .57375 L .3806 .57451 L F
.894 .676 .6 r
.37654 .57655 m .3806 .57451 L .37709 .57375 L F
.37654 .57655 m .38083 .57856 L .3806 .57451 L F
.815 .812 .848 r
.34904 .55583 m .34738 .55821 L .34518 .55706 L F
.923 .674 .543 r
.34738 .55821 m .34696 .56053 L .34518 .55706 L F
.545 .697 .939 r
.29293 .64103 m .29371 .63858 L .2915 .63909 L F
.29293 .64103 m .29575 .64048 L .29371 .63858 L F
.551 .39 .616 r
.25991 .60432 m .26221 .6009 L .26031 .60162 L F
.668 .908 .978 r
.5961 .38059 m .59195 .38177 L .59467 .38095 L F
.838 .496 .408 r
.5961 .38059 m .59905 .38434 L .60076 .38472 L F
0 .139 .684 r
.59683 .38066 m .59905 .38434 L .59757 .38246 L F
.59683 .38066 m .59757 .38246 L .5961 .38059 L F
.488 .687 .955 r
.59629 .37933 m .59683 .38066 L .59675 .37886 L F
0 .375 .779 r
.5961 .38059 m .59683 .38066 L .59467 .38095 L F
0 .139 .684 r
.59683 .38066 m .5961 .38059 L .59467 .38095 L F
.488 .687 .955 r
.59467 .38095 m .59683 .38066 L .59629 .37933 L F
.727 .603 .718 r
.42475 .55524 m .42118 .55838 L .42194 .55446 L F
.518 .497 .772 r
.42562 .5505 m .42622 .55476 L .42475 .55524 L F
.475 .363 .646 r
.42622 .55476 m .42762 .55735 L .42475 .55524 L F
.701 .895 .967 r
.70568 .32461 m .70919 .32433 L .70805 .3231 L F
.727 .88 .952 r
.70805 .3231 m .70919 .32433 L .71256 .32255 L F
.863 .486 .331 r
.5935 .42631 m .59562 .42685 L .59398 .42848 L F
0 0 0 r
.59702 .42195 m .59562 .42685 L .5935 .42631 L F
.918 .771 .682 r
.59108 .36111 m .59179 .36471 L .59 .36284 L F
.59108 .36111 m .59179 .36471 L .59 .36284 L F
.89 .463 .113 r
.41753 .52512 m .41836 .52733 L .42005 .5282 L F
.94 .602 .358 r
.41828 .52946 m .42005 .5282 L .41836 .52733 L F
.41828 .52946 m .4209 .53196 L .42005 .5282 L F
.853 .503 .39 r
.4232 .57713 m .42309 .57433 L .42436 .57471 L F
.829 .896 .888 r
.65052 .38647 m .65377 .38372 L .65208 .3846 L F
.831 .922 .895 r
.65023 .38407 m .65377 .38372 L .65052 .38647 L F
.667 .958 .738 r
.6755 .37888 m .67715 .3782 L .67897 .3764 L F
.609 .582 .797 r
.53015 .47843 m .52874 .48317 L .52837 .4794 L F
.53015 .47843 m .53148 .48237 L .52874 .48317 L F
.897 .901 .821 r
.36911 .6199 m .37086 .62091 L .37335 .61738 L F
.883 .983 .822 r
.55858 .44224 m .55882 .44435 L .5578 .44488 L F
.886 .792 .302 r
.55852 .44487 m .55882 .44435 L .55858 .44224 L F
.235 .739 .682 r
.53299 .46341 m .53674 .46217 L .53452 .46292 L F
.934 .786 .672 r
.72773 .30935 m .72634 .30469 L .72593 .30753 L F
.866 .839 .817 r
.72559 .31168 m .72773 .30935 L .72593 .30753 L F
.962 .788 .622 r
.59017 .40085 m .58782 .40247 L .58863 .39955 L F
.59017 .40085 m .58954 .40353 L .58782 .40247 L F
.888 .489 .259 r
.39525 .54512 m .3931 .54433 L .39135 .54057 L F
.913 .56 .354 r
.39525 .54512 m .39348 .54669 L .3931 .54433 L F
.988 .745 .475 r
.39525 .54512 m .39506 .54785 L .39348 .54669 L F
.39525 .54512 m .39506 .54785 L .39348 .54669 L F
.994 .822 .565 r
.69506 .3429 m .69682 .3417 L .69598 .34051 L F
.69506 .3429 m .69635 .34438 L .69682 .3417 L F
.508 .906 .924 r
.4471 .59812 m .45087 .59731 L .44964 .59728 L F
.429 .858 .733 r
.45087 .59731 m .45348 .5959 L .45215 .59634 L F
.411 .862 .857 r
.45087 .59731 m .45215 .59634 L .44964 .59728 L F
.52 .782 .992 r
.25356 .61734 m .25649 .61696 L .2558 .6196 L F
.244 .754 .866 r
.25598 .61693 m .25649 .61696 L .25493 .61716 L F
.837 .952 .892 r
.25641 .61636 m .25649 .61696 L .25409 .61682 L F
.922 .832 .378 r
.2558 .6196 m .25649 .61696 L .25641 .61636 L F
.2558 .6196 m .25631 .61685 L .2579 .61729 L F
.25631 .61685 m .25641 .61636 L .25697 .61671 L F
.25631 .61685 m .25697 .61671 L .2579 .61729 L F
.244 .754 .866 r
.25409 .61682 m .25598 .61693 L .25356 .61734 L F
.25598 .61693 m .25493 .61716 L .25356 .61734 L F
0 .108 .659 r
.25356 .61734 m .2558 .6196 L .25409 .61682 L F
.927 .77 .666 r
.36879 .55344 m .37229 .55153 L .3703 .55024 L F
.36879 .55344 m .37157 .55459 L .37229 .55153 L F
.114 .325 .795 r
.60118 .38322 m .60076 .38472 L .59905 .38434 L F
.60118 .38322 m .60293 .38678 L .60076 .38472 L F
.588 .078 .006 r
.64882 .39898 m .65021 .39758 L .65293 .39929 L F
.49 .239 .46 r
.65021 .39758 m .65332 .39675 L .65293 .39929 L F
.683 .412 .506 r
.34696 .56053 m .34405 .5586 L .34518 .55706 L F
.34696 .56053 m .3428 .56119 L .34405 .5586 L F
.45 .447 .763 r
.33485 .57059 m .33281 .57177 L .33157 .56895 L F
0 0 0 r
.33485 .57059 m .33189 .57335 L .33281 .57177 L F
.801 .988 .886 r
.43539 .57368 m .43101 .576 L .43222 .57462 L F
0 0 0 r
.27217 .51467 m .27365 .51435 L .2748 .51384 L F
.27217 .51467 m .27096 .51766 L .27365 .51435 L F
.168 0 .333 r
.53071 .47601 m .53015 .47843 L .52837 .4794 L F
.54 .34 .558 r
.29975 .63977 m .30202 .64046 L .30217 .63729 L F
0 0 0 r
.32782 .59547 m .32708 .59712 L .32774 .59444 L F
.748 .679 .784 r
.32788 .64675 m .32932 .65041 L .33195 .64709 L F
.975 .718 .48 r
.39135 .54057 m .38987 .54048 L .38997 .538 L F
.883 .566 .445 r
.3931 .54433 m .38987 .54048 L .39135 .54057 L F
.241 .125 .514 r
.59731 .39375 m .59456 .39401 L .59687 .39272 L F
.59731 .39375 m .59479 .39707 L .59456 .39401 L F
.961 .925 .719 r
.25032 .62899 m .25306 .62739 L .25094 .62576 L F
.25032 .62899 m .25216 .62943 L .25306 .62739 L F
.763 .662 .751 r
.51623 .42392 m .51851 .42311 L .51912 .42072 L F
.495 .362 .628 r
.51623 .42392 m .51605 .42681 L .51854 .42582 L F
.845 .805 .812 r
.51509 .4273 m .51804 .42569 L .51509 .42732 L F
.495 .362 .628 r
.51623 .42392 m .51817 .42551 L .51851 .42311 L F
.858 .652 .623 r
.51409 .42253 m .51623 .42392 L .51441 .41991 L F
.809 .632 .663 r
.51315 .42423 m .51623 .42392 L .51409 .42253 L F
.51315 .42423 m .51605 .42681 L .51623 .42392 L F
.879 .474 .251 r
.51369 .42585 m .51605 .42681 L .51315 .42423 L F
.553 .552 .806 r
.51271 .4203 m .51181 .42589 L .51409 .42253 L F
.809 .632 .663 r
.51315 .42423 m .51409 .42253 L .51181 .42589 L F
.879 .474 .251 r
.51369 .42585 m .51315 .42423 L .51181 .42589 L F
.553 .552 .806 r
.51209 .42411 m .51369 .42585 L .51181 .42589 L F
.51369 .42585 m .51499 .42728 L .51181 .42589 L F
.659 .161 .054 r
.51181 .42589 m .51499 .42728 L .51436 .42785 L F
.879 .474 .251 r
.51436 .42785 m .5151 .4274 L .51499 .42728 L F
.659 .161 .054 r
.51499 .42728 m .51509 .42732 L .51436 .42785 L F
.879 .474 .251 r
.51436 .42785 m .51499 .42728 L .51369 .42585 L F
.51436 .42785 m .51369 .42585 L .51181 .42589 L F
.5151 .4274 m .51605 .42681 L .51369 .42585 L F
.553 .552 .806 r
.51271 .4203 m .51509 .42732 L .51499 .42728 L F
.51271 .4203 m .51499 .42728 L .51209 .42411 L F
.845 .805 .812 r
.51578 .42045 m .51801 .4256 L .51509 .4273 L F
.51801 .4256 m .51804 .42569 L .51509 .4273 L F
.495 .362 .628 r
.51817 .42551 m .51854 .42582 L .51854 .4253 L F
.51817 .42551 m .51854 .4253 L .51851 .42311 L F
0 .265 .77 r
.51873 .42295 m .51804 .42569 L .51696 .42317 L F
.51873 .42295 m .51696 .42317 L .51578 .42045 L F
0 0 0 r
.51939 .42286 m .51873 .42295 L .52066 .42156 L F
.521 .163 .3 r
.51853 .42516 m .52058 .42312 L .51851 .42311 L F
0 0 0 r
.51788 .42442 m .51873 .42295 L .51939 .42286 L F
.782 .976 .697 r
.51596 .42626 m .51799 .42571 L .51873 .42295 L F
.51799 .42571 m .51804 .42569 L .51806 .42564 L F
.51799 .42571 m .51806 .42564 L .51873 .42295 L F
.521 .163 .3 r
.51854 .42582 m .5226 .42312 L .52058 .42312 L F
.51854 .42582 m .52058 .42312 L .51853 .42516 L F
.745 .716 .825 r
.33157 .56895 m .32827 .56872 L .33051 .56767 L F
.702 .163 0 r
.33051 .56767 m .33485 .57059 L .33157 .56895 L F
.628 .604 .807 r
.30125 .66334 m .29718 .66028 L .29987 .65928 L F
.667 .639 .813 r
.30231 .65903 m .30125 .66334 L .29987 .65928 L F
.30231 .65903 m .30396 .66253 L .30125 .66334 L F
.674 .549 .705 r
.36085 .55912 m .35695 .55785 L .35901 .55754 L F
.36085 .55912 m .35803 .56163 L .35695 .55785 L F
0 0 0 r
.25983 .53557 m .25846 .53753 L .25772 .5382 L F
0 0 .195 r
.2582 .53985 m .25772 .5382 L .25846 .53753 L F
.2582 .53985 m .25719 .54152 L .25772 .5382 L F
.652 .928 .973 r
.60662 .44729 m .60901 .44602 L .60811 .44514 L F
.698 .859 .959 r
.60511 .39869 m .60287 .40047 L .6042 .39752 L F
.773 .945 .935 r
.6042 .39752 m .60287 .40047 L .60164 .39943 L F
.822 .669 .692 r
.36175 .55658 m .36085 .55912 L .35901 .55754 L F
0 0 0 r
.50818 .41236 m .50713 .41385 L .50926 .41045 L F
0 0 .337 r
.50821 .41509 m .50713 .41385 L .50818 .41236 L F
.50821 .41509 m .50711 .41626 L .50713 .41385 L F
.964 .772 .331 r
.5873 .43937 m .58716 .44106 L .58636 .44034 L F
.652 .802 .955 r
.5899 .43536 m .5873 .43937 L .58571 .43763 L F
.5899 .43536 m .59087 .43795 L .5873 .43937 L F
.969 .921 .592 r
.57651 .40118 m .57824 .39998 L .57755 .39913 L F
.57651 .40118 m .57674 .40406 L .57824 .39998 L F
.897 .901 .821 r
.36911 .6199 m .37335 .61738 L .37153 .61627 L F
.576 .404 .612 r
.42476 .56061 m .42136 .56121 L .42118 .55838 L F
.801 .545 .551 r
.27156 .59954 m .2771 .59733 L .27228 .59788 L F
.674 .517 .664 r
.2771 .59733 m .28023 .60109 L .27349 .60103 L F
.801 .545 .551 r
.27156 .59954 m .2774 .60009 L .2771 .59733 L F
.373 .352 .707 r
.2771 .59733 m .27811 .59717 L .27785 .59435 L F
.832 .359 .015 r
.27862 .60005 m .28023 .60109 L .2771 .59733 L F
0 0 .099 r
.27778 .59855 m .27788 .59957 L .27811 .59717 L F
.2774 .60009 m .27788 .59957 L .27778 .59855 L F
.832 .359 .015 r
.27788 .59957 m .27862 .60005 L .27778 .59855 L F
0 0 .099 r
.2774 .60009 m .27778 .59855 L .2771 .59733 L F
.832 .359 .015 r
.27788 .59957 m .27778 .59855 L .2771 .59733 L F
0 0 .099 r
.27778 .59855 m .27811 .59717 L .2771 .59733 L F
.832 .359 .015 r
.27788 .59957 m .2771 .59733 L .27811 .59717 L F
.736 .412 .433 r
.33254 .53409 m .33064 .5318 L .33106 .53421 L F
.966 .938 .673 r
.69962 .33008 m .70035 .32855 L .69874 .32938 L F
.823 .843 .863 r
.70035 .32855 m .70156 .32377 L .69924 .32706 L F
.70035 .32855 m .70301 .32583 L .70156 .32377 L F
.986 .894 .632 r
.69874 .32938 m .70035 .32855 L .69924 .32706 L F
.954 .657 .433 r
.38147 .5247 m .379 .52091 L .38114 .52212 L F
.488 .802 1 r
.64736 .38709 m .64455 .38767 L .6458 .38588 L F
.216 .126 .533 r
.23741 .54517 m .23863 .54561 L .2394 .54077 L F
.221 .128 .532 r
.23769 .54783 m .23863 .54561 L .23741 .54517 L F
.663 .965 .775 r
.47973 .57428 m .47939 .57399 L .47674 .57539 L F
.874 .681 .155 r
.47941 .57082 m .47939 .57399 L .47973 .57428 L F
.86 .969 .65 r
.55468 .46561 m .55208 .46856 L .55357 .46463 L F
.55468 .46561 m .55251 .46912 L .55208 .46856 L F
.867 .88 .844 r
.61033 .40394 m .61364 .4036 L .61221 .40214 L F
.629 .828 .977 r
.61221 .40214 m .61364 .4036 L .6171 .40208 L F
.508 0 0 r
.33544 .52753 m .33827 .52845 L .34005 .52799 L F
.985 .761 .516 r
.33827 .52845 m .33881 .53037 L .34005 .52799 L F
.426 .271 .567 r
.34005 .52799 m .34267 .5282 L .34229 .52497 L F
.34229 .52497 m .34267 .5282 L .34005 .52799 L F
.246 .508 .904 r
.23736 .61724 m .23999 .62028 L .23709 .61855 L F
.726 .245 .103 r
.23709 .61855 m .23999 .62028 L .23758 .62113 L F
.105 .659 .772 r
.41527 .54484 m .41793 .54473 L .41781 .54465 L F
.755 .641 .081 r
.25997 .62979 m .26009 .62732 L .26129 .62937 L F
.685 .247 .204 r
.26129 .62937 m .26009 .62732 L .25725 .62723 L F
.293 .153 .514 r
.69914 .29546 m .7024 .29532 L .70244 .29441 L F
.69914 .29546 m .69954 .29815 L .7024 .29532 L F
.604 .578 .797 r
.59467 .38095 m .59195 .38177 L .59107 .37729 L F
.838 .907 .885 r
.56367 .45341 m .55924 .45535 L .56215 .45218 L F
.963 .634 .317 r
.56171 .44952 m .56367 .45341 L .56215 .45218 L F
.939 .57 .215 r
.24834 .58439 m .24889 .58687 L .25045 .58774 L F
.794 .898 .916 r
.52224 .39085 m .51766 .39216 L .52045 .38928 L F
.809 .796 .84 r
.5249 .38768 m .52224 .39085 L .52045 .38928 L F
.679 .966 .758 r
.50502 .49957 m .50623 .49772 L .50711 .49817 L F
.50502 .49957 m .50296 .5005 L .50623 .49772 L F
0 0 0 r
.56176 .38102 m .56173 .38155 L .56224 .3788 L F
.56176 .38102 m .56141 .3837 L .56173 .38155 L F
.073 .362 .831 r
.25216 .62943 m .25654 .63251 L .25496 .63033 L F
.459 .864 .693 r
.4566 .43619 m .45247 .43854 L .45643 .43625 L F
.467 .873 .718 r
.45825 .43491 m .45997 .4342 L .4566 .43619 L F
.451 .843 .634 r
.45825 .43491 m .4566 .43619 L .45643 .43625 L F
.853 .503 .39 r
.4232 .57713 m .4212 .57679 L .42309 .57433 L F
.858 .635 .599 r
.42762 .55735 m .42992 .56079 L .42946 .55798 L F
.822 .669 .693 r
.29947 .63531 m .30217 .63729 L .29989 .63799 L F
.439 .257 .536 r
.30217 .63729 m .30202 .64046 L .30453 .63942 L F
.725 .196 0 r
.3062 .64064 m .30217 .63729 L .30453 .63942 L F
.128 .518 .914 r
.55896 .36833 m .56202 .36973 L .56239 .37091 L F
.085 .43 .872 r
.56202 .36973 m .56566 .37257 L .56239 .37091 L F
.309 .776 .655 r
.66487 .37624 m .66299 .37714 L .66207 .37754 L F
0 0 0 r
.57053 .45892 m .57423 .45672 L .57269 .45519 L F
.754 .774 .869 r
.57423 .45672 m .57563 .45206 L .57269 .45519 L F
.57423 .45672 m .57656 .45567 L .57563 .45206 L F
.413 .133 .376 r
.29289 .54818 m .29535 .54756 L .29587 .54529 L F
.29289 .54818 m .29535 .54756 L .29587 .54529 L F
.536 .379 .615 r
.29837 .54153 m .29855 .54472 L .29587 .54529 L F
.417 .118 .347 r
.29855 .54472 m .29535 .54756 L .29587 .54529 L F
.536 .379 .615 r
.29587 .54529 m .29855 .54472 L .29837 .54153 L F
.417 .118 .347 r
.29535 .54756 m .29855 .54472 L .29587 .54529 L F
.536 .379 .615 r
.29837 .54153 m .29855 .54472 L .29587 .54529 L F
.417 .118 .347 r
.29855 .54472 m .29792 .54698 L .29535 .54756 L F
.29535 .54756 m .29792 .54698 L .29855 .54472 L F
.447 .145 .359 r
.29855 .54472 m .29792 .54698 L .29587 .54529 L F
.431 .148 .382 r
.29587 .54529 m .29792 .54698 L .29535 .54756 L F
.764 .286 .103 r
.29219 .59101 m .29022 .59197 L .28993 .59079 L F
.58 .906 .98 r
.29219 .59101 m .29293 .58934 L .29521 .5891 L F
.29219 .59101 m .28993 .59079 L .29293 .58934 L F
0 .197 .716 r
.29219 .59101 m .29293 .58934 L .29022 .59197 L F
.29219 .59101 m .29446 .59318 L .29293 .58934 L F
.672 .786 .318 r
.61868 .36383 m .61721 .36711 L .61828 .36461 L F
.051 .113 .608 r
.61721 .36711 m .619 .36928 L .61828 .36461 L F
.964 .938 .691 r
.31689 .63009 m .31615 .63425 L .314 .63297 L F
.876 .709 .671 r
.31615 .63425 m .31561 .63681 L .314 .63297 L F
.273 .731 .953 r
.59697 .3433 m .59956 .34319 L .60094 .34393 L F
.078 .594 .882 r
.59956 .34319 m .60353 .34431 L .60094 .34393 L F
.394 0 0 r
.32165 .54297 m .32484 .54386 L .32046 .54373 L F
.517 0 0 r
.32484 .54386 m .32308 .5451 L .32046 .54373 L F
.193 .312 .757 r
.32046 .54373 m .32308 .5451 L .32258 .54347 L F
.32075 .54369 m .32258 .54347 L .32208 .54185 L F
.982 .763 .532 r
.32308 .5451 m .32134 .54428 L .32208 .54185 L F
.726 .93 .958 r
.32134 .54428 m .3228 .54085 L .32208 .54185 L F
.425 .666 .961 r
.31912 .54206 m .32369 .54055 L .32199 .54107 L F
.31912 .54206 m .32208 .54185 L .32369 .54055 L F
.708 .933 .615 r
.32369 .54055 m .32208 .54185 L .32299 .54041 L F
.726 .93 .958 r
.3228 .54085 m .32299 .54041 L .32208 .54185 L F
.193 .312 .757 r
.32046 .54373 m .32075 .54369 L .32208 .54185 L F
0 0 0 r
.31927 .54387 m .32046 .54373 L .31826 .54425 L F
.32165 .54297 m .32046 .54373 L .31927 .54387 L F
.884 .903 .837 r
.67745 .33483 m .6748 .33817 L .67443 .33575 L F
0 .068 .597 r
.6748 .33817 m .67542 .33831 L .67443 .33575 L F
.6748 .33817 m .67648 .33978 L .67542 .33831 L F
.746 .914 .543 r
.48288 .52783 m .48493 .52409 L .48545 .52465 L F
.627 .226 .263 r
.6693 .32826 m .66805 .33044 L .66543 .32994 L F
.687 .293 .296 r
.6693 .32826 m .67197 .33055 L .66805 .33044 L F
.284 .237 .628 r
.3948 .50362 m .39358 .50783 L .39325 .50563 L F
.686 .976 .804 r
.26666 .60061 m .2673 .59906 L .26921 .59852 L F
0 .159 .695 r
.26666 .60061 m .26894 .6026 L .2673 .59906 L F
.618 .442 .622 r
.28819 .63697 m .2915 .63909 L .29096 .63662 L F
.28819 .63697 m .28864 .63996 L .2915 .63909 L F
.348 .116 .414 r
.53969 .3964 m .53704 .39974 L .53733 .39739 L F
.53969 .3964 m .53704 .39974 L .53733 .39739 L F
.773 .703 .786 r
.25159 .55424 m .24996 .55473 L .25237 .55173 L F
.609 .268 .367 r
.25159 .55424 m .25218 .55693 L .24996 .55473 L F
.42 .15 .396 r
.2545 .55529 m .25159 .55424 L .25541 .55431 L F
.2545 .55529 m .25218 .55693 L .25159 .55424 L F
.913 .901 .493 r
.52466 .39479 m .52457 .39765 L .52578 .39371 L F
.949 .956 .711 r
.52466 .39479 m .52343 .39998 L .52457 .39765 L F
.858 .897 .862 r
.65243 .3823 m .65377 .38372 L .65023 .38407 L F
.817 .999 .835 r
.65589 .38024 m .65671 .38074 L .65377 .38372 L F
.798 .679 .733 r
.39716 .45708 m .39262 .45625 L .39516 .45541 L F
.39716 .45708 m .39247 .45936 L .39262 .45625 L F
.529 .711 .955 r
.39772 .45509 m .39716 .45708 L .39516 .45541 L F
.39772 .45509 m .39716 .45708 L .39516 .45541 L F
.78 .304 .102 r
.60257 .36771 m .60116 .36881 L .59905 .36657 L F
.648 .094 0 r
.59905 .36657 m .60183 .36785 L .60257 .36771 L F
.506 .573 .857 r
.5997 .35457 m .60217 .35398 L .60068 .35104 L F
.828 .997 .768 r
.60257 .36771 m .6047 .36367 L .60526 .36695 L F
.60257 .36771 m .60183 .36785 L .6047 .36367 L F
0 0 0 r
.60341 .36718 m .60257 .36771 L .60526 .36695 L F
.60341 .36718 m .60116 .36881 L .60257 .36771 L F
.771 .601 .667 r
.46532 .58874 m .46864 .59076 L .46816 .58968 L F
.46532 .58874 m .46788 .59116 L .46864 .59076 L F
.784 .633 .694 r
.46788 .59116 m .46727 .59437 L .46864 .59076 L F
.738 .986 .897 r
.46864 .59076 m .46832 .58938 L .46816 .58968 L F
.46864 .59076 m .47262 .58776 L .46832 .58938 L F
.678 .611 .774 r
.33874 .5612 m .34016 .56206 L .33978 .55707 L F
.561 .521 .769 r
.33978 .55707 m .34016 .56206 L .3428 .56119 L F
.856 .59 .535 r
.4041 .51395 m .4078 .51219 L .40418 .51128 L F
.4041 .51395 m .40773 .51486 L .4078 .51219 L F
.798 .538 .545 r
.4078 .51219 m .40773 .51486 L .41147 .51529 L F
.568 .937 .826 r
.54046 .41848 m .54207 .41781 L .54415 .41635 L F
.446 0 0 r
.27349 .60103 m .27541 .60227 L .2728 .60275 L F
.27349 .60103 m .28023 .60109 L .27541 .60227 L F
.52 0 0 r
.42877 .45715 m .43061 .45699 L .43284 .45849 L F
.992 .75 .458 r
.43326 .45571 m .43284 .45849 L .43061 .45699 L F
.596 .686 .905 r
.60446 .4079 m .60625 .405 L .60331 .4053 L F
.60446 .4079 m .60746 .40705 L .60625 .405 L F
.798 .54 .549 r
.6851 .31359 m .68939 .31187 L .68507 .31095 L F
.6851 .31359 m .68953 .31448 L .68939 .31187 L F
.639 .447 .608 r
.68953 .31448 m .69331 .31171 L .68939 .31187 L F
.888 .717 .664 r
.67103 .35401 m .67255 .35799 L .67045 .35676 L F
.846 .391 .113 r
.67045 .35676 m .67255 .35799 L .67162 .35901 L F
.866 .89 .463 r
.67162 .35901 m .67255 .35799 L .67184 .35954 L F
.831 .816 .835 r
.57563 .45206 m .57656 .45567 L .57757 .45338 L F
.824 .839 .86 r
.35875 .55432 m .35668 .55565 L .35476 .5543 L F
.417 .858 .768 r
.49685 .44655 m .50037 .44506 L .49864 .44457 L F
.289 .77 .922 r
.49864 .44457 m .50037 .44506 L .50173 .44485 L F
.917 .956 .8 r
.67394 .34573 m .67652 .34484 L .67436 .34783 L F
.946 .81 .36 r
.67648 .33978 m .67652 .34484 L .67564 .34351 L F
.917 .955 .799 r
.67564 .34351 m .67652 .34484 L .67394 .34573 L F
.639 .927 .973 r
.4444 .58143 m .44532 .57962 L .44264 .58092 L F
.4444 .58143 m .44532 .57962 L .44264 .58092 L F
.631 .912 .622 r
.26391 .60414 m .26327 .60484 L .26228 .60542 L F
.908 .504 .127 r
.26327 .60484 m .26435 .6075 L .26228 .60542 L F
.417 .3 .612 r
.26391 .60414 m .26435 .6075 L .26327 .60484 L F
.599 .442 .64 r
.32437 .59761 m .3275 .59323 L .32457 .59357 L F
.898 .655 .563 r
.40839 .51678 m .41147 .51529 L .40773 .51486 L F
.40839 .51678 m .41122 .51856 L .41147 .51529 L F
0 0 0 r
.54341 .40719 m .54368 .40714 L .54586 .40424 L F
0 .025 .589 r
.54377 .40486 m .54368 .40714 L .54341 .40719 L F
0 0 0 r
.54586 .40424 m .54368 .40714 L .54763 .4026 L F
.543 .146 .238 r
.54377 .40486 m .54763 .4026 L .54368 .40714 L F
0 0 .252 r
.54341 .40719 m .54456 .4078 L .54377 .40486 L F
.585 .885 .991 r
.42221 .45035 m .41745 .45048 L .4204 .4513 L F
.405 0 0 r
.4204 .4513 m .4248 .44965 L .42221 .45035 L F
.169 0 .106 r
.3829 .49173 m .38029 .493 L .37926 .4949 L F
.775 .697 .777 r
.23512 .61679 m .23714 .61709 L .23428 .61324 L F
.848 .66 .647 r
.23428 .61898 m .23714 .61709 L .23512 .61679 L F
0 0 .485 r
.23428 .61324 m .23714 .61709 L .23736 .61724 L F
.867 .794 .302 r
.23714 .61709 m .23626 .61822 L .23736 .61724 L F
.997 .792 .437 r
.39963 .56767 m .39887 .56359 L .40004 .56476 L F
.907 .872 .792 r
.72559 .31168 m .72593 .30753 L .72398 .3099 L F
.989 .741 .368 r
.72398 .3099 m .72532 .31467 L .72559 .31168 L F
.736 .412 .433 r
.33064 .5318 m .33254 .53409 L .33171 .53065 L F
.33064 .5318 m .33091 .53483 L .33254 .53409 L F
.33254 .53409 m .33091 .53483 L .33064 .5318 L F
.803 .71 .762 r
.2903 .66556 m .29029 .66954 L .28785 .66902 L F
.947 .699 .529 r
.29029 .66954 m .28763 .67091 L .28785 .66902 L F
.29029 .66954 m .29 .67239 L .28763 .67091 L F
.508 .872 .984 r
.59032 .34559 m .59339 .34447 L .59465 .34523 L F
.757 .971 .926 r
.59697 .3433 m .59465 .34523 L .59533 .3433 L F
.746 .962 .937 r
.59465 .34523 m .59339 .34447 L .59533 .3433 L F
.677 .894 .537 r
.28161 .51198 m .27903 .51544 L .28085 .51275 L F
.28085 .51275 m .27903 .51544 L .28161 .51198 L F
.28085 .51275 m .27903 .51544 L .28161 .51198 L F
.441 .194 .443 r
.28117 .51731 m .27903 .51544 L .28085 .51275 L F
.28117 .51731 m .27865 .51797 L .27903 .51544 L F
0 .361 .816 r
.57473 .42218 m .57425 .42279 L .57263 .42166 L F
.57473 .42218 m .57605 .4237 L .57425 .42279 L F
0 0 .02 r
.52834 .38916 m .52718 .393 L .52578 .39371 L F
0 0 0 r
.52718 .393 m .52466 .39479 L .52578 .39371 L F
.143 .178 .639 r
.59676 .36444 m .5955 .36748 L .59519 .36335 L F
.506 .238 .443 r
.59841 .36952 m .5955 .36748 L .59676 .36444 L F
.59841 .36952 m .59552 .37039 L .5955 .36748 L F
.165 0 0 r
.42422 .60084 m .42498 .60179 L .42236 .60214 L F
.42422 .60084 m .42681 .60052 L .42498 .60179 L F
.763 .694 .786 r
.29487 .65761 m .29718 .66028 L .2931 .6598 L F
.699 .682 .83 r
.29987 .65928 m .29718 .66028 L .29487 .65761 L F
.922 .752 .654 r
.67612 .33082 m .67745 .33483 L .67551 .33341 L F
.884 .903 .837 r
.67745 .33483 m .67443 .33575 L .67551 .33341 L F
.211 0 0 r
.61755 .39827 m .61618 .39736 L .61501 .39967 L F
.61755 .39827 m .61888 .39659 L .61618 .39736 L F
.513 .775 .991 r
.50674 .43061 m .5094 .43014 L .50636 .42859 L F
.945 .913 .537 r
.50537 .43187 m .50674 .43061 L .50636 .42859 L F
.074 0 0 r
.50793 .43113 m .50674 .43061 L .50537 .43187 L F
.50793 .43113 m .5094 .43014 L .50674 .43061 L F
.204 0 0 r
.59893 .43423 m .60389 .43419 L .60216 .43495 L F
.889 .988 .734 r
.60216 .43495 m .60389 .43419 L .6052 .43205 L F
.685 .443 .549 r
.34342 .53715 m .34682 .53365 L .34722 .53454 L F
.746 .914 .543 r
.48288 .52783 m .48262 .5277 L .48493 .52409 L F
.703 .733 .874 r
.32113 .64697 m .32509 .6476 L .32365 .64589 L F
.638 .74 .922 r
.32509 .6476 m .32788 .64675 L .32365 .64589 L F
.548 .773 .981 r
.23967 .58532 m .24042 .5831 L .2378 .58358 L F
.23967 .58532 m .24241 .58458 L .24042 .5831 L F
.594 .275 .398 r
.33247 .58767 m .33483 .58987 L .33532 .58783 L F
0 .176 .712 r
.33325 .58669 m .33483 .58987 L .33247 .58767 L F
.629 .946 .948 r
.59988 .39227 m .60419 .39058 L .60159 .39176 L F
.709 .64 .778 r
.60689 .39036 m .60419 .39058 L .60293 .38678 L F
.38 .222 .537 r
.60419 .39058 m .60678 .39263 L .60582 .39002 L F
.60419 .39058 m .6043 .3933 L .60678 .39263 L F
.60678 .39263 m .6043 .3933 L .60419 .39058 L F
.60419 .39058 m .60582 .39002 L .60159 .39176 L F
.709 .64 .778 r
.60689 .39036 m .60293 .38678 L .60547 .38664 L F
.675 .732 .893 r
.60995 .38775 m .60689 .39036 L .60547 .38664 L F
.255 .434 .846 r
.61279 .38957 m .61095 .39064 L .60995 .38775 L F
0 0 0 r
.60962 .39194 m .61095 .39064 L .61279 .38957 L F
.748 .484 .531 r
.25136 .56143 m .24708 .56366 L .24782 .5616 L F
.25136 .56143 m .25165 .56459 L .24708 .56366 L F
.832 .478 0 r
.24968 .55776 m .25063 .56044 L .25136 .56143 L F
.802 .585 .023 r
.2511 .56196 m .25136 .56143 L .25063 .56044 L F
.2511 .56196 m .25165 .56459 L .25136 .56143 L F
.953 .673 .47 r
.4164 .47293 m .41769 .47336 L .41545 .47469 L F
.074 0 0 r
.32557 .57144 m .32144 .57427 L .32423 .57379 L F
0 0 0 r
.32827 .56872 m .32557 .57144 L .32739 .56998 L F
.32739 .56998 m .32557 .57144 L .32423 .57379 L F
.092 0 .406 r
.46473 .53824 m .46641 .53442 L .4645 .53526 L F
.39 .816 .642 r
.54356 .40961 m .54026 .41158 L .53956 .41191 L F
.963 .747 .303 r
.57721 .39548 m .57815 .39397 L .57846 .39155 L F
.57721 .39548 m .57801 .39655 L .57815 .39397 L F
.851 .631 .604 r
.3714 .55702 m .37359 .5608 L .37363 .55811 L F
0 0 0 r
.33929 .58764 m .34052 .58654 L .34199 .58467 L F
.444 0 .05 r
.34199 .58467 m .34052 .58654 L .34428 .5859 L F
.425 .012 .149 r
.34199 .58467 m .34428 .5859 L .34468 .58441 L F
.665 .461 .6 r
.31205 .66926 m .31217 .67236 L .30927 .6726 L F
.612 .539 .748 r
.31453 .66593 m .31571 .66956 L .31205 .66926 L F
.653 .48 .638 r
.31571 .66956 m .31217 .67236 L .31205 .66926 L F
.711 .986 .849 r
.54813 .48164 m .55154 .47921 L .55087 .47886 L F
.795 .99 .747 r
.55154 .47921 m .55437 .47601 L .55242 .47696 L F
.793 .998 .797 r
.55087 .47886 m .55154 .47921 L .55242 .47696 L F
.981 .698 .4 r
.33956 .64543 m .34177 .64694 L .34122 .6448 L F
.34071 .64411 m .34122 .6448 L .34097 .64381 L F
.33956 .64543 m .34122 .6448 L .34071 .64411 L F
.698 .767 .905 r
.33696 .64306 m .34056 .6439 L .3358 .63868 L F
.471 .749 .99 r
.3421 .64205 m .34141 .64313 L .34394 .64325 L F
.34141 .64313 m .34097 .64381 L .34241 .64354 L F
.34141 .64313 m .34241 .64354 L .34394 .64325 L F
.259 .468 .872 r
.34141 .64313 m .34177 .64419 L .34097 .64381 L F
.77 .794 .873 r
.34177 .64694 m .34394 .64325 L .34097 .64381 L F
.259 .468 .872 r
.3421 .64205 m .34177 .64419 L .34141 .64313 L F
.698 .767 .905 r
.34056 .6439 m .34177 .64419 L .34 .64256 L F
.33936 .6423 m .34 .64256 L .33856 .64123 L F
.34056 .6439 m .34 .64256 L .33936 .6423 L F
.34056 .6439 m .33856 .64123 L .3358 .63868 L F
.607 .119 .07 r
.34097 .64381 m .34177 .64419 L .33956 .64543 L F
.83 .62 .07 r
.58445 .38628 m .58509 .39081 L .58414 .38876 L F
.814 .596 .039 r
.58483 .39307 m .58414 .38876 L .58509 .39081 L F
.927 .658 .51 r
.39733 .55148 m .39498 .55055 L .39506 .54785 L F
.952 .677 .478 r
.39733 .55148 m .39521 .55323 L .39498 .55055 L F
.39733 .55148 m .39732 .55451 L .39521 .55323 L F
.153 0 0 r
.52376 .42979 m .52599 .43089 L .52194 .43114 L F
.52376 .42979 m .52596 .42878 L .52599 .43089 L F
0 0 0 r
.63632 .33764 m .63876 .33635 L .63977 .33476 L F
.07 0 0 r
.63977 .33476 m .64136 .33535 L .64219 .33332 L F
.63977 .33476 m .63876 .33635 L .64136 .33535 L F
.657 .771 .933 r
.3221 .53729 m .31912 .53911 L .31927 .53585 L F
.918 .959 .795 r
.31912 .53911 m .31622 .5402 L .31927 .53585 L F
.696 .751 .894 r
.48928 .44363 m .49065 .43935 L .48774 .44164 L F
.48928 .44363 m .49212 .44263 L .49065 .43935 L F
.751 .529 .594 r
.39262 .45625 m .38893 .45928 L .3884 .4574 L F
.39262 .45625 m .39247 .45936 L .38893 .45928 L F
.385 0 0 r
.3884 .4574 m .39516 .45541 L .39262 .45625 L F
0 .287 .758 r
.57332 .38423 m .57467 .38571 L .57185 .38403 L F
.969 .827 .647 r
.58313 .43645 m .58246 .43243 L .58291 .43525 L F
.608 .951 .81 r
.58536 .43726 m .58313 .43645 L .58291 .43525 L F
.58536 .43726 m .58336 .43921 L .58313 .43645 L F
.677 .894 .537 r
.28161 .51198 m .28004 .51257 L .2777 .51317 L F
.28161 .51198 m .28085 .51275 L .28004 .51257 L F
.225 0 0 r
.33483 .58987 m .33929 .58764 L .33532 .58783 L F
.33483 .58987 m .33904 .59036 L .33929 .58764 L F
.676 .975 .893 r
.33904 .59036 m .34052 .58654 L .33929 .58764 L F
.972 .919 .683 r
.39768 .57733 m .39531 .57923 L .39648 .57636 L F
.39768 .57733 m .39624 .58031 L .39531 .57923 L F
.734 .983 .764 r
.44179 .56943 m .43913 .57209 L .43701 .57318 L F
.681 .969 .766 r
.51004 .43492 m .50853 .43703 L .51028 .43528 L F
0 0 0 r
.50779 .43906 m .50853 .43703 L .51004 .43492 L F
.921 .528 .201 r
.42992 .56079 m .43067 .56181 L .4317 .56235 L F
0 0 0 r
.38762 .48815 m .3829 .49173 L .38411 .49041 L F
.38762 .48815 m .38411 .49041 L .38473 .48989 L F
.003 .554 .824 r
.3869 .4877 m .38762 .48815 L .38441 .49008 L F
.442 .186 .429 r
.3868 .49054 m .38689 .48808 L .38967 .48874 L F
.38689 .48808 m .3869 .4877 L .38721 .48782 L F
.38689 .48808 m .38721 .48782 L .38967 .48874 L F
0 0 0 r
.38473 .48989 m .38411 .49041 L .38441 .49008 L F
.615 .954 .811 r
.68483 .37285 m .68866 .37086 L .68649 .37137 L F
.745 .993 .85 r
.68866 .37086 m .69184 .36837 L .69005 .36847 L F
.745 .993 .851 r
.68649 .37137 m .68866 .37086 L .69005 .36847 L F
.689 .438 .538 r
.39328 .49485 m .39709 .49239 L .39338 .49226 L F
.39328 .49485 m .39694 .49497 L .39709 .49239 L F
.487 .269 .508 r
.39709 .49239 m .39694 .49497 L .39952 .49442 L F
.39709 .49239 m .39694 .49497 L .39952 .49442 L F
.8 .327 0 r
.58772 .39777 m .58692 .39814 L .58617 .39592 L F
.58772 .39777 m .58863 .39955 L .58692 .39814 L F
.969 .934 .658 r
.697 .33327 m .69962 .33008 L .69874 .32938 L F
.697 .33327 m .69777 .33449 L .69962 .33008 L F
.994 .843 .488 r
.57424 .36409 m .57344 .36737 L .57272 .36546 L F
.783 .976 .912 r
.57424 .36409 m .57572 .36127 L .57692 .36264 L F
.57424 .36409 m .57357 .36314 L .57572 .36127 L F
.977 .885 .52 r
.57424 .36409 m .57272 .36546 L .57357 .36314 L F
0 0 .511 r
.59988 .39227 m .60157 .39065 L .59941 .39201 L F
.59988 .39227 m .60159 .39176 L .60157 .39065 L F
.722 .883 .955 r
.65602 .33582 m .65337 .33736 L .65705 .33741 L F
.009 0 0 r
.65954 .33389 m .65602 .33582 L .65705 .33741 L F
.917 .956 .8 r
.67394 .34573 m .67436 .34783 L .67355 .34662 L F
.989 .725 .415 r
.67436 .34783 m .67289 .34928 L .67355 .34662 L F
.67436 .34783 m .67429 .35083 L .67289 .34928 L F
.05 0 0 r
.67857 .30868 m .67543 .3113 L .67835 .30959 L F
.544 .262 .438 r
.67835 .30959 m .6812 .30763 L .67857 .30868 L F
0 .049 .609 r
.28268 .5971 m .28376 .6 L .28334 .59554 L F
.892 .921 .835 r
.28334 .59554 m .28376 .6 L .28765 .59152 L F
.796 .771 .831 r
.34394 .64325 m .34825 .64375 L .34579 .63962 L F
.86 .842 .827 r
.34825 .64375 m .34894 .63905 L .34579 .63962 L F
.34825 .64375 m .35085 .64047 L .34894 .63905 L F
.51 .896 .729 r
.46215 .43271 m .45997 .4342 L .45825 .43491 L F
.286 .702 .972 r
.33725 .515 m .33541 .51373 L .33274 .51374 L F
.175 .629 .938 r
.33725 .515 m .33889 .51501 L .33541 .51373 L F
.203 .006 .375 r
.62731 .38929 m .62491 .39072 L .6246 .39323 L F
.061 0 .021 r
.6246 .39323 m .62238 .39454 L .6215 .39608 L F
0 .454 .736 r
.29867 .63496 m .29947 .63531 L .29765 .63485 L F
.901 .508 .265 r
.29293 .58934 m .29571 .59098 L .29521 .5891 L F
.909 .507 .118 r
.58202 .42996 m .57976 .42649 L .5802 .42886 L F
.897 .556 .392 r
.58028 .43158 m .58202 .42996 L .5802 .42886 L F
.58028 .43158 m .58246 .43243 L .58202 .42996 L F
.626 .892 .987 r
.45657 .59427 m .46035 .59418 L .45839 .59247 L F
.831 .887 .882 r
.58792 .34612 m .58367 .34734 L .58576 .34638 L F
.58367 .34734 m .58317 .34748 L .58571 .3464 L F
.58367 .34734 m .58571 .3464 L .58576 .34638 L F
.285 .068 .399 r
.58782 .34426 m .58747 .34457 L .58539 .34507 L F
0 0 0 r
.58571 .3464 m .58783 .34448 L .58539 .34507 L F
.285 .068 .399 r
.58747 .34457 m .58534 .34643 L .58539 .34507 L F
0 0 0 r
.58783 .34448 m .58799 .34433 L .58539 .34507 L F
.709 .986 .849 r
.58792 .34612 m .58576 .34638 L .58782 .34426 L F
.58576 .34638 m .58534 .34643 L .58747 .34457 L F
.58576 .34638 m .58747 .34457 L .58782 .34426 L F
0 0 0 r
.58624 .34857 m .58746 .34561 L .58576 .34638 L F
.58572 .34643 m .58576 .34638 L .58571 .3464 L F
.58624 .34857 m .58576 .34638 L .58572 .34643 L F
.58746 .34561 m .58799 .34433 L .58571 .3464 L F
.465 .398 .697 r
.58317 .34748 m .58624 .34857 L .58571 .3464 L F
.58317 .34748 m .58571 .3464 L .58539 .34507 L F
.831 .887 .882 r
.58576 .34638 m .58317 .34748 L .58534 .34643 L F
.709 .986 .849 r
.58792 .34612 m .58782 .34426 L .59032 .34559 L F
.579 .944 .865 r
.69005 .36847 m .69184 .36837 L .69421 .36687 L F
.599 .442 .64 r
.32437 .59761 m .32708 .59712 L .3275 .59323 L F
.521 .163 .3 r
.51854 .42582 m .5215 .42565 L .5226 .42312 L F
.524 .014 0 r
.52441 .42486 m .5226 .42312 L .5215 .42565 L F
.52441 .42486 m .52554 .42355 L .5226 .42312 L F
.99 .733 .424 r
.53434 .38683 m .53307 .38593 L .53418 .38399 L F
.484 .334 .602 r
.53589 .38403 m .53418 .38399 L .53682 .38325 L F
.53589 .38403 m .53434 .38683 L .53418 .38399 L F
.185 0 0 r
.53307 .38593 m .53682 .38325 L .53418 .38399 L F
.16 0 .358 r
.34872 .5677 m .35062 .56736 L .35075 .56433 L F
.206 .155 .576 r
.34872 .5677 m .35063 .56986 L .35062 .56736 L F
.913 .848 .766 r
.34938 .57157 m .35063 .56986 L .34872 .5677 L F
.197 0 0 r
.41906 .4603 m .4169 .45998 L .42082 .45896 L F
.41906 .4603 m .41598 .4611 L .4169 .45998 L F
.513 .277 .495 r
.25218 .55693 m .24968 .55776 L .24996 .55473 L F
.835 .981 .877 r
.53959 .41858 m .53893 .42041 L .54046 .41848 L F
.842 .987 .862 r
.53788 .41975 m .53893 .42041 L .53959 .41858 L F
.711 .986 .849 r
.54813 .48164 m .55087 .47886 L .54755 .48139 L F
.989 .736 .448 r
.35941 .49236 m .35744 .49393 L .35811 .4904 L F
.559 .574 .825 r
.36035 .48781 m .35941 .49236 L .35811 .4904 L F
.36035 .48781 m .36216 .49164 L .35941 .49236 L F
.08 0 0 r
.36009 .49317 m .35941 .49236 L .36216 .49164 L F
.791 .715 .781 r
.35773 .4958 m .35319 .49603 L .35572 .4947 L F
.08 0 0 r
.36 .49307 m .35744 .49393 L .35941 .49236 L F
.318 .058 .352 r
.35811 .4904 m .35744 .49393 L .35843 .49328 L F
.791 .715 .781 r
.35831 .49371 m .35572 .4947 L .35843 .49328 L F
.08 0 0 r
.35863 .49359 m .35744 .49393 L .36 .49307 L F
.629 .527 .72 r
.36009 .49317 m .35773 .4958 L .35744 .49393 L F
.36009 .49317 m .35773 .4958 L .35744 .49393 L F
.791 .715 .781 r
.35773 .4958 m .35843 .49328 L .35744 .49393 L F
.35773 .4958 m .35572 .4947 L .35831 .49371 L F
.08 0 0 r
.36009 .49317 m .35863 .49359 L .36 .49307 L F
.571 .083 0 r
.41784 .6 m .4188 .60128 L .41593 .59949 L F
0 .262 .725 r
.41593 .59949 m .4188 .60128 L .41753 .60024 L F
.231 .63 .957 r
.4147 .59892 m .41784 .6 L .41593 .59949 L F
0 .262 .725 r
.41593 .59949 m .41753 .60024 L .41557 .59865 L F
.231 .63 .957 r
.41304 .59835 m .4147 .59892 L .41593 .59949 L F
.571 .083 0 r
.41784 .6 m .42003 .60254 L .4188 .60128 L F
.421 0 .086 r
.35563 .56579 m .35323 .56642 L .35531 .56663 L F
.372 .664 .971 r
.35531 .56663 m .35865 .56755 L .35563 .56579 L F
.309 0 0 r
.41304 .59835 m .41593 .59949 L .41422 .599 L F
.41304 .59835 m .41422 .599 L .41178 .59647 L F
.6 .951 .883 r
.49832 .40731 m .49962 .40571 L .50038 .40579 L F
.49832 .40731 m .49584 .40764 L .49962 .40571 L F
.127 0 .064 r
.54849 .4088 m .54646 .40989 L .54947 .40717 L F
.748 .87 .447 r
.54839 .40854 m .54849 .4088 L .54947 .40717 L F
.55057 .40731 m .54947 .40717 L .55191 .40655 L F
.54839 .40854 m .54913 .40761 L .55057 .40731 L F
.54913 .40761 m .54947 .40717 L .55057 .40731 L F
.54839 .40854 m .55191 .40655 L .55055 .4066 L F
.363 .794 .968 r
.55422 .40692 m .55055 .4066 L .55191 .40655 L F
.55297 .40681 m .55305 .40623 L .55055 .4066 L F
.55422 .40692 m .55376 .40665 L .55297 .40681 L F
.55376 .40665 m .55305 .40623 L .55297 .40681 L F
.566 .66 .9 r
.4858 .44206 m .48623 .43829 L .48376 .4395 L F
.4858 .44206 m .48774 .44164 L .48623 .43829 L F
.283 0 0 r
.24368 .53165 m .24625 .5324 L .24841 .53223 L F
.133 0 0 r
.24881 .53257 m .25107 .53207 L .25183 .53106 L F
.25052 .53143 m .25183 .53106 L .25256 .53011 L F
.41 0 0 r
.24739 .53231 m .25084 .53151 L .24841 .53223 L F
.24889 .53189 m .25084 .53151 L .24739 .53231 L F
.24625 .5324 m .24889 .53189 L .24739 .53231 L F
.24974 .53172 m .24865 .53265 L .25084 .53151 L F
.24625 .5324 m .24865 .53265 L .24974 .53172 L F
0 0 0 r
.24513 .53514 m .24691 .53432 L .24865 .53265 L F
.699 .917 .578 r
.24865 .53265 m .24691 .53432 L .24735 .53375 L F
0 0 0 r
.24513 .53514 m .24865 .53265 L .24625 .5324 L F
.699 .917 .578 r
.24865 .53265 m .24735 .53375 L .24975 .53064 L F
.133 0 0 r
.24865 .53265 m .25256 .53011 L .25084 .53151 L F
.24865 .53265 m .25183 .53106 L .25052 .53143 L F
.186 .659 .934 r
.24975 .53064 m .25328 .53159 L .25107 .53207 L F
.25328 .53159 m .25354 .53166 L .25107 .53207 L F
.133 0 0 r
.24865 .53265 m .25107 .53207 L .24881 .53257 L F
.777 .977 .913 r
.63089 .40635 m .6333 .403 L .62978 .40518 L F
.63089 .40635 m .63423 .40375 L .6333 .403 L F
.874 .99 .817 r
.55437 .47601 m .55508 .4731 L .55367 .475 L F
.55437 .47601 m .55707 .47274 L .55508 .4731 L F
.947 .958 .692 r
.55242 .47696 m .55437 .47601 L .55367 .475 L F
0 0 .511 r
.57694 .38794 m .57593 .38726 L .57467 .38571 L F
.57694 .38794 m .57769 .38963 L .57593 .38726 L F
.845 .813 .818 r
.56228 .43518 m .56421 .4372 L .56285 .4387 L F
.468 .3 .569 r
.29289 .54818 m .29292 .55121 L .29532 .55032 L F
.29289 .54818 m .29292 .55121 L .29532 .55032 L F
.482 .299 .557 r
.29289 .54818 m .29532 .55032 L .29535 .54756 L F
.135 .679 .706 r
.42736 .44918 m .42854 .44898 L .4248 .44965 L F
.287 .783 .756 r
.42987 .44838 m .42854 .44898 L .42736 .44918 L F
.42987 .44838 m .43096 .44818 L .42854 .44898 L F
.608 .82 .981 r
.35668 .55565 m .35189 .5551 L .35476 .5543 L F
.121 .086 .542 r
.58964 .37366 m .58768 .37803 L .58715 .3729 L F
.58964 .37366 m .58972 .37621 L .58768 .37803 L F
.558 .854 .997 r
.58768 .37803 m .58972 .37621 L .59107 .37729 L F
.782 .662 .731 r
.39842 .50165 m .40091 .50558 L .40259 .50219 L F
.786 .911 .926 r
.33902 .64834 m .34177 .64694 L .33956 .64543 L F
.905 .872 .794 r
.30796 .63641 m .3067 .63944 L .30619 .63796 L F
.816 .818 .851 r
.30519 .63476 m .30796 .63641 L .30539 .63672 L F
.905 .872 .794 r
.30796 .63641 m .30453 .63942 L .30539 .63672 L F
0 .263 .769 r
.30535 .63555 m .30705 .63819 L .30533 .63489 L F
.30539 .63672 m .30592 .63719 L .30535 .63555 L F
.30592 .63719 m .30705 .63819 L .30535 .63555 L F
.905 .872 .794 r
.30619 .63796 m .3062 .64064 L .30453 .63942 L F
.3067 .63944 m .3062 .64064 L .30619 .63796 L F
.526 .694 .945 r
.3062 .64064 m .30705 .63819 L .30453 .63942 L F
.3062 .64064 m .30868 .64022 L .30705 .63819 L F
0 0 0 r
.67312 .3139 m .67463 .31281 L .67543 .3113 L F
.251 0 .079 r
.67463 .31281 m .67835 .30959 L .67543 .3113 L F
.67463 .31281 m .67741 .3119 L .67835 .30959 L F
0 0 0 r
.67363 .3125 m .67548 .31221 L .67463 .31281 L F
.67548 .31221 m .67741 .3119 L .67463 .31281 L F
.67246 .31464 m .67463 .31281 L .67312 .3139 L F
.562 .433 .662 r
.69858 .30538 m .7003 .30068 L .69753 .30176 L F
.688 .842 .957 r
.70301 .32583 m .70442 .32298 L .70156 .32377 L F
.70301 .32583 m .70568 .32461 L .70442 .32298 L F
.359 .245 .585 r
.29837 .54153 m .30072 .54394 L .29855 .54472 L F
.29855 .54472 m .30072 .54394 L .29837 .54153 L F
.966 .712 .5 r
.39859 .55812 m .39665 .55955 L .39648 .5571 L F
.39859 .55812 m .39853 .56066 L .39665 .55955 L F
.693 .161 0 r
.41198 .52063 m .4159 .52403 L .41409 .52089 L F
.807 .331 0 r
.41409 .52089 m .4159 .52403 L .41753 .52512 L F
.711 .839 .943 r
.34894 .63905 m .35085 .64047 L .35254 .63899 L F
.43 .2 .462 r
.30049 .67657 m .30336 .67319 L .30265 .67538 L F
.687 .523 .659 r
.30516 .67199 m .30265 .67538 L .30336 .67319 L F
.728 .414 .449 r
.29612 .67614 m .30049 .67657 L .29974 .6788 L F
.702 .497 .608 r
.30265 .67538 m .29974 .6788 L .30049 .67657 L F
.436 .817 .99 r
.45631 .56368 m .45994 .56401 L .45725 .56457 L F
.701 .947 .957 r
.45434 .56465 m .45631 .56368 L .45725 .56457 L F
.436 .817 .99 r
.45631 .56368 m .45994 .56401 L .45725 .56457 L F
.929 .915 .782 r
.56285 .4387 m .55858 .44224 L .56124 .43687 L F
.56285 .4387 m .55852 .44487 L .55858 .44224 L F
.845 .813 .818 r
.56228 .43518 m .56285 .4387 L .56124 .43687 L F
.925 .817 .721 r
.46103 .55406 m .46146 .55785 L .46031 .55628 L F
.963 .884 .706 r
.45845 .56033 m .46146 .55785 L .46066 .56117 L F
.45845 .56033 m .46031 .55628 L .46146 .55785 L F
0 0 0 r
.26128 .53374 m .25846 .53753 L .25983 .53557 L F
.749 .675 .78 r
.32788 .64675 m .33195 .64709 L .3301 .64624 L F
.608 .583 .8 r
.33195 .64709 m .33291 .64266 L .3301 .64624 L F
.33195 .64709 m .33438 .64656 L .33291 .64266 L F
.916 .887 .789 r
.57757 .45338 m .57988 .45005 L .5784 .44879 L F
.948 .844 .707 r
.57988 .45005 m .57992 .44509 L .5784 .44879 L F
.926 .655 .507 r
.3685 .55663 m .37157 .55459 L .36879 .55344 L F
.3685 .55663 m .3714 .55702 L .37157 .55459 L F
.009 0 0 r
.65954 .33389 m .65862 .33506 L .65602 .33582 L F
0 0 0 r
.6626 .33081 m .66159 .33301 L .65954 .33389 L F
.179 0 .006 r
.66159 .33301 m .65862 .33506 L .65954 .33389 L F
.578 .637 .873 r
.53697 .45937 m .53806 .45471 L .535 .45797 L F
.463 .304 .579 r
.53956 .45576 m .53931 .45846 L .53697 .45937 L F
.578 .637 .873 r
.53697 .45937 m .53931 .45846 L .53806 .45471 L F
.718 .619 .746 r
.53931 .45846 m .53674 .46217 L .53697 .45937 L F
.53931 .45846 m .5406 .46235 L .53674 .46217 L F
0 0 .271 r
.53697 .45937 m .53817 .46059 L .53931 .45846 L F
0 0 .308 r
.53934 .46419 m .53885 .46455 L .53858 .46293 L F
.53934 .46419 m .53858 .46293 L .53813 .46217 L F
.312 0 0 r
.53674 .46217 m .5406 .46235 L .53858 .46293 L F
.027 .129 .635 r
.53817 .46059 m .53674 .46217 L .53858 .46293 L F
.862 .73 .716 r
.53858 .46293 m .53558 .46344 L .53817 .46059 L F
0 0 .271 r
.53691 .46015 m .53674 .46217 L .53757 .46125 L F
.833 .989 .723 r
.53817 .46059 m .53558 .46344 L .5363 .46119 L F
0 0 .308 r
.53858 .46293 m .53813 .46217 L .53744 .46105 L F
.53934 .46419 m .53813 .46217 L .53858 .46293 L F
0 0 .271 r
.53697 .45937 m .53691 .46015 L .53817 .46059 L F
.53691 .46015 m .53757 .46125 L .53817 .46059 L F
.645 .424 .568 r
.39031 .49519 m .39328 .49485 L .39338 .49226 L F
.163 .696 .847 r
.60353 .34431 m .6062 .34416 L .60766 .34439 L F
.072 .626 .818 r
.6062 .34416 m .61031 .34455 L .60766 .34439 L F
.899 .583 .441 r
.32712 .50197 m .32753 .50487 L .32505 .50368 L F
0 0 0 r
.32712 .50197 m .3282 .5014 L .32953 .50117 L F
.32712 .50197 m .32505 .50368 L .3282 .5014 L F
.887 .963 .839 r
.60849 .36449 m .61106 .36286 L .61043 .36263 L F
.61106 .36286 m .60849 .36449 L .61043 .36263 L F
.692 .962 .942 r
.33274 .51374 m .33072 .51362 L .33037 .51533 L F
0 0 .477 r
.33037 .51533 m .33072 .51362 L .3298 .51126 L F
.402 .094 .324 r
.54415 .41635 m .54735 .41288 L .54588 .41472 L F
0 0 .206 r
.54646 .40989 m .54676 .4109 L .54678 .41095 L F
.54678 .41095 m .54743 .41314 L .54735 .41288 L F
.54676 .4109 m .54743 .41314 L .54678 .41095 L F
.923 .566 .128 r
.54591 .41133 m .54743 .41314 L .54646 .40989 L F
.54591 .41133 m .54646 .40989 L .54849 .4088 L F
.54666 .41049 m .54849 .4088 L .54839 .40854 L F
.54591 .41133 m .54668 .41058 L .54666 .41049 L F
.54668 .41058 m .54849 .4088 L .54666 .41049 L F
0 0 0 r
.54735 .41288 m .54743 .41314 L .54588 .41472 L F
.056 0 .286 r
.23981 .53851 m .24081 .53997 L .24171 .53751 L F
.23981 .53851 m .2394 .54077 L .24081 .53997 L F
.655 .905 .981 r
.61724 .41374 m .61963 .4146 L .62239 .41312 L F
.855 .959 .875 r
.59683 .38066 m .60144 .37783 L .59968 .376 L F
.715 .963 .702 r
.65791 .37902 m .65671 .38074 L .65803 .37853 L F
.714 .983 .897 r
.65803 .37853 m .65671 .38074 L .65589 .38024 L F
.999 .802 .472 r
.69607 .36273 m .69651 .36084 L .69539 .35945 L F
.815 .812 .848 r
.34904 .55583 m .34518 .55706 L .34852 .55425 L F
.598 .752 .951 r
.35104 .55351 m .34904 .55583 L .34852 .55425 L F
.35104 .55351 m .35189 .5551 L .34904 .55583 L F
0 0 0 r
.64814 .33079 m .6522 .32879 L .64871 .33036 L F
.64814 .33079 m .65085 .3297 L .6522 .32879 L F
.65085 .3297 m .65483 .32768 L .6522 .32879 L F
.522 0 0 r
.31561 .63681 m .31069 .63616 L .314 .63297 L F
.907 .793 .723 r
.37946 .58972 m .38361 .58757 L .38135 .58671 L F
.37946 .58972 m .38197 .59126 L .38361 .58757 L F
.705 .97 .93 r
.46043 .44732 m .46279 .4473 L .46495 .44575 L F
.35 .093 .377 r
.25443 .54491 m .25395 .54738 L .25172 .54805 L F
.274 .029 .349 r
.2561 .5465 m .25443 .54491 L .25624 .54373 L F
.2561 .5465 m .25395 .54738 L .25443 .54491 L F
.52 .134 .25 r
.33757 .53213 m .33254 .53409 L .3335 .53424 L F
.33757 .53213 m .33564 .53516 L .33254 .53409 L F
0 0 0 r
.33821 .53324 m .33757 .53213 L .33881 .53037 L F
.33821 .53324 m .33564 .53516 L .33757 .53213 L F
.938 .809 .692 r
.37964 .59444 m .37854 .59966 L .3809 .60029 L F
.929 .831 .728 r
.37854 .59966 m .3796 .60263 L .3809 .60029 L F
0 0 0 r
.25654 .63251 m .25997 .62979 L .25938 .63324 L F
.09 0 .316 r
.25938 .63324 m .25997 .62979 L .26129 .62937 L F
.908 .983 .742 r
.52283 .49984 m .52257 .5025 L .52494 .49884 L F
.744 .949 .633 r
.5259 .49679 m .52494 .49884 L .52757 .49549 L F
.757 .988 .768 r
.5259 .49679 m .52283 .49984 L .52494 .49884 L F
.957 .83 .677 r
.35214 .52822 m .34914 .5303 L .34865 .52783 L F
.35214 .52822 m .35092 .53185 L .34914 .5303 L F
.735 .781 .89 r
.49483 .43919 m .49894 .43956 L .49734 .43794 L F
.49483 .43919 m .49894 .43956 L .49734 .43794 L F
.417 .662 .961 r
.50003 .43786 m .49894 .43956 L .49734 .43794 L F
.50003 .43786 m .49894 .43956 L .49734 .43794 L F
.918 .761 .671 r
.6052 .43205 m .60409 .4291 L .60303 .4326 L F
.889 .988 .734 r
.60216 .43495 m .6052 .43205 L .60303 .4326 L F
.65 .739 .914 r
.47188 .44388 m .47547 .44522 L .47437 .44257 L F
.523 .529 .803 r
.47547 .44522 m .47691 .44153 L .47437 .44257 L F
.47547 .44522 m .4784 .44477 L .47691 .44153 L F
.431 0 0 r
.61851 .34827 m .6178 .34968 L .61455 .34938 L F
0 0 0 r
.61987 .348 m .61851 .34827 L .62159 .34777 L F
.61987 .348 m .6178 .34968 L .61851 .34827 L F
.366 0 0 r
.33206 .50026 m .33452 .50051 L .33675 .49971 L F
.612 .081 0 r
.33675 .49971 m .33452 .50051 L .33708 .50057 L F
.622 .647 .854 r
.30591 .65989 m .30396 .66253 L .30231 .65903 L F
.30591 .65989 m .30661 .66198 L .30396 .66253 L F
.619 .596 .805 r
.30661 .66198 m .30793 .66391 L .30396 .66253 L F
.692 .16 0 r
.3078 .66605 m .30396 .66253 L .30793 .66391 L F
.893 .717 .657 r
.41509 .53713 m .41374 .54098 L .41233 .53733 L F
.507 .511 .796 r
.33727 .54811 m .3382 .54365 L .33668 .54552 L F
.385 .642 .958 r
.338 .54725 m .34121 .54852 L .33727 .54811 L F
.439 .229 .496 r
.3387 .55468 m .34102 .55698 L .34155 .55395 L F
.107 .191 .67 r
.33978 .55707 m .34102 .55698 L .3387 .55468 L F
0 0 .127 r
.32782 .59547 m .3275 .59323 L .3278 .59268 L F
.32782 .59547 m .32708 .59712 L .3275 .59323 L F
.574 .563 .804 r
.55439 .4458 m .55786 .44663 L .5578 .44488 L F
1 .819 .496 r
.51271 .4203 m .51409 .42253 L .51441 .41991 L F
.041 0 0 r
.51441 .41991 m .51578 .42045 L .51271 .4203 L F
.973 .921 .676 r
.70776 .29691 m .70911 .29498 L .70675 .29454 L F
.772 .391 0 r
.59049 .41041 m .59132 .4125 L .58863 .40715 L F
.796 .678 .734 r
.33886 .57077 m .33485 .57059 L .33821 .56663 L F
.196 0 0 r
.33886 .57077 m .3347 .57362 L .33485 .57059 L F
.289 0 0 r
.34149 .57289 m .33955 .57324 L .33711 .57296 L F
.314 .651 .97 r
.33711 .57296 m .33955 .57324 L .33911 .57278 L F
.196 0 0 r
.33886 .57077 m .33711 .57296 L .33544 .57312 L F
.314 .651 .97 r
.33711 .57296 m .33911 .57278 L .33772 .57133 L F
.196 0 0 r
.33544 .57312 m .33711 .57296 L .3347 .57362 L F
.608 .176 .195 r
.34149 .57289 m .33886 .57077 L .34169 .57093 L F
.316 .228 .595 r
.26594 .60601 m .26435 .6075 L .26391 .60414 L F
.649 .167 .095 r
.26228 .60542 m .26594 .60601 L .26391 .60414 L F
.944 .847 .717 r
.37283 .60921 m .37657 .60711 L .37438 .60609 L F
.37283 .60921 m .37471 .61049 L .37657 .60711 L F
.877 .879 .832 r
.37438 .60609 m .37657 .60711 L .3796 .60263 L F
.971 .793 .605 r
.31055 .57786 m .30975 .58055 L .3077 .57894 L F
.3077 .57894 m .30975 .58055 L .31055 .57786 L F
.543 .849 .998 r
.26917 .61693 m .27362 .61707 L .27185 .61618 L F
.581 .579 .816 r
.55902 .40596 m .56023 .40957 L .5633 .40822 L F
.857 .992 .736 r
.55707 .47274 m .55961 .46932 L .55764 .47033 L F
.838 .997 .835 r
.55508 .4731 m .55707 .47274 L .55764 .47033 L F
.583 .94 .921 r
.67246 .31464 m .67251 .31411 L .67463 .31281 L F
.887 .628 .541 r
.37486 .57282 m .37857 .57133 L .37515 .56994 L F
.37486 .57282 m .37709 .57375 L .37857 .57133 L F
.858 .729 .209 r
.66014 .38518 m .66047 .38626 L .66065 .38387 L F
0 .408 .81 r
.66065 .38387 m .66338 .38502 L .66203 .38387 L F
.578 .579 .817 r
.66065 .38387 m .66465 .38684 L .66338 .38502 L F
0 .408 .81 r
.66065 .38387 m .66203 .38387 L .66014 .38518 L F
.44 0 0 r
.2673 .59906 m .27156 .59954 L .26921 .59852 L F
.47 .068 .194 r
.26921 .59852 m .27156 .59954 L .27228 .59788 L F
0 .074 .624 r
.53121 .47379 m .53071 .47601 L .529 .47495 L F
.53121 .47379 m .53241 .47772 L .53071 .47601 L F
.348 .113 .409 r
.53241 .47772 m .53015 .47843 L .53071 .47601 L F
.855 .969 .869 r
.52141 .5017 m .52257 .5025 L .52283 .49984 L F
.863 .679 .651 r
.37654 .57655 m .38036 .57943 L .38083 .57856 L F
.882 .465 .211 r
.34767 .52567 m .34625 .52673 L .34454 .52502 L F
.34767 .52567 m .34865 .52783 L .34625 .52673 L F
.718 .862 .95 r
.36662 .49123 m .36216 .49164 L .36673 .48839 L F
.348 .571 .923 r
.36765 .48981 m .36662 .49123 L .36673 .48839 L F
.699 .682 .83 r
.29987 .65928 m .29487 .65761 L .29833 .657 L F
.546 .662 .912 r
.30049 .65585 m .29987 .65928 L .29833 .657 L F
.30049 .65585 m .30231 .65903 L .29987 .65928 L F
.826 .998 .841 r
.56028 .46694 m .55961 .46932 L .56262 .4663 L F
.843 .992 .739 r
.55764 .47033 m .55961 .46932 L .56028 .46694 L F
.888 .983 .815 r
.57432 .40486 m .57424 .40729 L .57674 .40406 L F
.879 .935 .852 r
.57432 .40486 m .57319 .40927 L .57424 .40729 L F
.874 .533 .029 r
.58191 .38271 m .58043 .37913 L .58073 .38074 L F
.417 .34 .663 r
.52045 .38928 m .52112 .38772 L .52147 .38719 L F
.824 .6 .599 r
.52263 .38546 m .52147 .38719 L .52214 .38498 L F
.69 .616 .768 r
.52805 .38628 m .5249 .38768 L .52214 .38498 L F
.52805 .38628 m .52214 .38498 L .52601 .38274 L F
.253 0 0 r
.52253 .38444 m .52601 .38274 L .52214 .38498 L F
0 0 0 r
.52214 .38498 m .52147 .38719 L .52253 .38444 L F
.417 .34 .663 r
.52112 .38772 m .52253 .38444 L .52147 .38719 L F
.824 .6 .599 r
.5249 .38768 m .52147 .38719 L .52263 .38546 L F
.809 .796 .84 r
.5249 .38768 m .52045 .38928 L .52147 .38719 L F
.56 .603 .853 r
.52834 .38916 m .5249 .38768 L .52805 .38628 L F
0 0 .171 r
.3168 .62691 m .31738 .62782 L .3192 .62603 L F
.3168 .62691 m .31689 .63009 L .31738 .62782 L F
.966 .651 .364 r
.58482 .36486 m .58377 .36591 L .58578 .36728 L F
.77 .547 .596 r
.58377 .36591 m .58766 .36902 L .58578 .36728 L F
.47 .41 .708 r
.25395 .54738 m .25237 .55173 L .25172 .54805 L F
0 .447 .839 r
.46532 .58874 m .46646 .58844 L .46397 .58886 L F
.46532 .58874 m .46816 .58968 L .46646 .58844 L F
.976 .76 .546 r
.69656 .35072 m .69574 .34736 L .69565 .34981 L F
.991 .836 .465 r
.69506 .35172 m .69656 .35072 L .69565 .34981 L F
.69506 .35172 m .69628 .35425 L .69656 .35072 L F
0 0 .508 r
.56566 .37257 m .56661 .37645 L .5654 .37446 L F
.703 .972 .752 r
.53072 .4926 m .52869 .49358 L .52757 .49549 L F
.688 .931 .625 r
.52869 .49358 m .5259 .49679 L .52757 .49549 L F
.786 .911 .926 r
.33902 .64834 m .33956 .64543 L .33698 .6459 L F
.107 0 0 r
.33051 .56767 m .32827 .56872 L .32739 .56998 L F
.989 .836 .6 r
.69574 .34736 m .69635 .34438 L .69506 .3429 L F
.3 .151 .505 r
.51066 .40986 m .50818 .41236 L .50926 .41045 L F
.786 .654 .717 r
.61326 .35679 m .61521 .36149 L .61726 .35749 L F
.47 .41 .708 r
.25395 .54738 m .25459 .55113 L .25237 .55173 L F
.469 .407 .705 r
.25459 .55113 m .25541 .55431 L .25237 .55173 L F
.727 .88 .952 r
.70805 .3231 m .71256 .32255 L .71134 .32107 L F
.675 .859 .97 r
.71256 .32255 m .71382 .31989 L .71134 .32107 L F
.71256 .32255 m .71483 .32128 L .71382 .31989 L F
.467 .879 .744 r
.47159 .4267 m .46743 .42875 L .4692 .42706 L F
.682 .967 .755 r
.47341 .42489 m .47159 .4267 L .47277 .42485 L F
.671 .975 .879 r
.47277 .42485 m .47159 .4267 L .4692 .42706 L F
.028 .6 .722 r
.28268 .5971 m .28339 .59706 L .27811 .59717 L F
0 .049 .609 r
.28268 .5971 m .28334 .59554 L .28339 .59706 L F
.064 0 .241 r
.23549 .55118 m .23692 .55054 L .23769 .54783 L F
.198 .136 .557 r
.23549 .55118 m .23724 .55323 L .23692 .55054 L F
.216 .139 .549 r
.23572 .55374 m .23724 .55323 L .23549 .55118 L F
.939 .953 .758 r
.49659 .53493 m .49762 .5313 L .49536 .53206 L F
.927 .908 .783 r
.49262 .53552 m .49659 .53493 L .49536 .53206 L F
.49262 .53552 m .49413 .53642 L .49659 .53493 L F
.587 .341 .511 r
.50762 .42124 m .51007 .41916 L .50727 .42022 L F
0 0 .279 r
.50762 .42124 m .50727 .42022 L .50749 .41964 L F
.672 .786 .318 r
.61868 .36383 m .61828 .36461 L .61734 .36273 L F
.48 .804 1 r
.61868 .36383 m .61734 .36273 L .62135 .36332 L F
.485 0 0 r
.58119 .36495 m .58377 .36591 L .58482 .36486 L F
.658 .505 .664 r
.3337 .54623 m .33304 .54531 L .33668 .54552 L F
.3337 .54623 m .3334 .54318 L .33304 .54531 L F
.107 0 .242 r
.52848 .4201 m .52793 .42237 L .5304 .41887 L F
.798 .34 .154 r
.37842 .51856 m .37686 .51991 L .37543 .51753 L F
.9 .506 .262 r
.37842 .51856 m .379 .52091 L .37686 .51991 L F
.937 .66 .489 r
.48619 .55813 m .48507 .56041 L .48689 .56105 L F
0 0 0 r
.48757 .55616 m .48507 .56041 L .48619 .55813 L F
.986 .71 .397 r
.58954 .40353 m .58812 .40487 L .58782 .40247 L F
.58954 .40353 m .58959 .4061 L .58812 .40487 L F
.898 .93 .829 r
.49167 .5403 m .48946 .54455 L .49324 .54174 L F
.843 .436 0 r
.41661 .52475 m .41753 .52512 L .4159 .52403 L F
.41661 .52475 m .41836 .52733 L .41753 .52512 L F
0 0 0 r
.51854 .42582 m .51605 .42681 L .51436 .42785 L F
.304 .782 .92 r
.51734 .43346 m .51856 .43254 L .51598 .43322 L F
.51734 .43346 m .52055 .43297 L .51856 .43254 L F
.97 .899 .694 r
.57186 .40794 m .57142 .41228 L .57319 .40927 L F
.879 .935 .852 r
.57432 .40486 m .57186 .40794 L .57319 .40927 L F
.874 .454 .209 r
.34773 .54691 m .34472 .54581 L .34665 .54486 L F
.643 .415 .558 r
.39461 .5072 m .39828 .50997 L .4009 .50695 L F
.055 0 0 r
.4009 .50695 m .40067 .50898 L .40236 .50842 L F
.4009 .50695 m .39828 .50997 L .40067 .50898 L F
.917 .974 .694 r
.46529 .5792 m .46738 .57792 L .46594 .58041 L F
.509 0 0 r
.46223 .57779 m .46738 .57792 L .46529 .5792 L F
.9 .953 .826 r
.7182 .30434 m .71915 .30535 L .71655 .30864 L F
.802 .976 .686 r
.71915 .30535 m .72053 .30225 L .72152 .30221 L F
.745 .934 .949 r
.7182 .30434 m .72053 .30225 L .71915 .30535 L F
.437 .736 .99 r
.59589 .37226 m .59889 .37227 L .5975 .37329 L F
.23 .324 .754 r
.59889 .37227 m .59968 .376 L .5975 .37329 L F
.285 .107 .455 r
.49055 .55034 m .48895 .55001 L .48943 .54676 L F
.49055 .55034 m .48865 .55129 L .48895 .55001 L F
.431 .757 .995 r
.28669 .58981 m .28993 .59079 L .28728 .59105 L F
.28651 .58943 m .28766 .58989 L .28669 .58981 L F
.28912 .59047 m .28993 .59079 L .28919 .59057 L F
.857 .712 .701 r
.28789 .58879 m .28993 .59079 L .28651 .58943 L F
.595 .688 .907 r
.29293 .58934 m .28993 .59079 L .28789 .58879 L F
0 0 .423 r
.28876 .58998 m .28918 .59055 L .292 .59025 L F
.28918 .59055 m .29022 .59197 L .29091 .5913 L F
.28918 .59055 m .29091 .5913 L .292 .59025 L F
0 0 .515 r
.28651 .58943 m .28765 .59152 L .28728 .59105 L F
.28651 .58943 m .28693 .58971 L .28765 .59152 L F
.014 0 0 r
.28651 .58943 m .28651 .59048 L .2871 .58995 L F
.28651 .58943 m .2871 .58995 L .28723 .58983 L F
.431 .757 .995 r
.28766 .58989 m .28912 .59047 L .28669 .58981 L F
0 0 .515 r
.28693 .58971 m .28718 .58987 L .28723 .59007 L F
0 0 .423 r
.28789 .58879 m .28876 .58998 L .29293 .58934 L F
.28789 .58879 m .28848 .58959 L .28876 .58998 L F
.431 .757 .995 r
.28912 .59047 m .28919 .59057 L .28669 .58981 L F
.729 .234 .061 r
.28789 .58879 m .28774 .58903 L .28865 .58982 L F
.28774 .58903 m .28699 .59021 L .28787 .59 L F
.28774 .58903 m .28787 .59 L .28865 .58982 L F
.842 .377 .009 r
.28993 .59079 m .29022 .59197 L .28792 .59038 L F
0 0 .515 r
.28693 .58971 m .28726 .59015 L .28765 .59152 L F
.892 .921 .835 r
.28334 .59554 m .28765 .59152 L .28726 .59015 L F
.28334 .59554 m .28726 .59015 L .28716 .59017 L F
.28334 .59554 m .28723 .59007 L .28692 .59025 L F
.842 .377 .009 r
.28993 .59079 m .28911 .59052 L .28766 .58989 L F
.28911 .59052 m .28789 .59011 L .28766 .58989 L F
.28789 .59011 m .28718 .58987 L .28733 .58988 L F
.28789 .59011 m .28733 .58988 L .28766 .58989 L F
.956 .75 .585 r
.29022 .59197 m .28783 .59313 L .28729 .59045 L F
.729 .234 .061 r
.28699 .59021 m .2868 .5905 L .28753 .5903 L F
.28772 .59018 m .28753 .5903 L .28801 .59016 L F
.28699 .59021 m .28753 .5903 L .28772 .59018 L F
.2868 .5905 m .28651 .59096 L .28751 .59043 L F
0 0 .515 r
.28713 .58998 m .28723 .59007 L .28726 .59015 L F
.892 .921 .835 r
.28716 .59017 m .28726 .59015 L .28723 .59007 L F
.28692 .59025 m .28723 .59007 L .28718 .58987 L F
.994 .753 .443 r
.28718 .58987 m .28729 .59045 L .28651 .59096 L F
.28729 .59045 m .28783 .59313 L .28651 .59096 L F
.729 .234 .061 r
.2868 .5905 m .28751 .59043 L .28801 .59016 L F
.956 .75 .585 r
.28792 .59038 m .28729 .59045 L .28718 .58987 L F
.29022 .59197 m .28729 .59045 L .28792 .59038 L F
.729 .234 .061 r
.28772 .59004 m .28801 .59016 L .28865 .58982 L F
.28699 .59021 m .28801 .59016 L .28772 .59004 L F
.842 .377 .009 r
.28789 .59011 m .28792 .59038 L .28718 .58987 L F
.28993 .59079 m .28792 .59038 L .28789 .59011 L F
0 0 .515 r
.28693 .58971 m .28723 .59007 L .28713 .58998 L F
0 0 .423 r
.28876 .58998 m .28984 .59143 L .29022 .59197 L F
.28848 .58959 m .28984 .59143 L .28876 .58998 L F
.729 .234 .061 r
.28865 .58982 m .28748 .59045 L .28984 .59143 L F
.28748 .59045 m .28651 .59096 L .28801 .59117 L F
.28748 .59045 m .28801 .59117 L .28984 .59143 L F
.438 .339 .646 r
.28365 .59338 m .28334 .59554 L .28692 .59025 L F
.014 0 0 r
.28651 .59048 m .28699 .59021 L .28723 .58983 L F
.438 .339 .646 r
.28679 .59026 m .28692 .59025 L .28718 .58987 L F
.28365 .59338 m .28692 .59025 L .28679 .59026 L F
.014 0 0 r
.28651 .59048 m .28651 .59096 L .28696 .59025 L F
.28692 .59025 m .28696 .59025 L .28699 .59021 L F
.28651 .59048 m .28696 .59025 L .28692 .59025 L F
.842 .377 .009 r
.28766 .58989 m .2873 .58988 L .28651 .58943 L F
.014 0 0 r
.28651 .58943 m .28723 .58983 L .28789 .58879 L F
.842 .377 .009 r
.2873 .58988 m .28718 .58987 L .28651 .58943 L F
0 0 .423 r
.28876 .58998 m .292 .59025 L .29293 .58934 L F
.803 .947 .917 r
.54342 .47499 m .54049 .47749 L .53886 .47674 L F
.537 .46 .716 r
.27091 .53097 m .26827 .52857 L .27131 .52837 L F
.39 .161 .441 r
.27321 .53022 m .27131 .52837 L .27355 .5275 L F
.27321 .53022 m .27091 .53097 L .27131 .52837 L F
.624 .726 .92 r
.66338 .38502 m .66465 .38684 L .66707 .38575 L F
.952 .745 .587 r
.32897 .50776 m .32696 .50743 L .32753 .50487 L F
.904 .54 .338 r
.32897 .50776 m .32701 .50971 L .32696 .50743 L F
.32897 .50776 m .3298 .51126 L .32701 .50971 L F
0 0 0 r
.55516 .38962 m .55855 .38431 L .55488 .38782 L F
.311 0 0 r
.43082 .59986 m .42953 .6004 L .42681 .60052 L F
.477 0 0 r
.43082 .59986 m .43161 .60119 L .42953 .6004 L F
.43082 .59986 m .43308 .60062 L .43161 .60119 L F
.16 .22 .677 r
.55927 .37481 m .56036 .37271 L .55899 .37242 L F
.55927 .37481 m .56169 .37477 L .56036 .37271 L F
.55927 .37481 m .56152 .37631 L .56169 .37477 L F
.9 .953 .826 r
.7182 .30434 m .71655 .30864 L .7154 .30701 L F
.955 .886 .724 r
.71655 .30864 m .71387 .31024 L .7154 .30701 L F
.133 .283 .752 r
.51877 .43962 m .52134 .44155 L .52167 .43947 L F
.654 .174 0 r
.23875 .61915 m .23999 .62028 L .23736 .61724 L F
.934 .962 .756 r
.23758 .62113 m .23999 .62028 L .23875 .61915 L F
.479 .274 .523 r
.2481 .62619 m .25032 .62899 L .25094 .62576 L F
.75 .317 .223 r
.33956 .64543 m .34177 .64419 L .33696 .64306 L F
.486 .696 .962 r
.3358 .63868 m .34177 .64419 L .3421 .64205 L F
.293 .057 .374 r
.51282 .41312 m .51008 .41662 L .51263 .41563 L F
.368 .184 .495 r
.51008 .41662 m .5125 .41842 L .51263 .41563 L F
.51008 .41662 m .51007 .41916 L .5125 .41842 L F
0 0 0 r
.43922 .44475 m .43755 .44517 L .43674 .4458 L F
.43922 .44475 m .44108 .44399 L .43755 .44517 L F
.233 .711 .936 r
.58636 .44034 m .58716 .44106 L .58895 .44075 L F
.694 .768 .908 r
.52889 .42741 m .52696 .42939 L .53046 .42707 L F
.774 .705 .787 r
.52896 .42602 m .53184 .42284 L .52793 .42237 L F
0 0 0 r
.5284 .42752 m .52944 .42497 L .53046 .42707 L F
.524 0 0 r
.52793 .42237 m .52969 .42401 L .52896 .42602 L F
.52969 .42401 m .52976 .42419 L .52896 .42602 L F
0 0 0 r
.52693 .42922 m .52596 .42878 L .52736 .42845 L F
.52883 .42636 m .52596 .42878 L .52896 .42602 L F
.52815 .42811 m .52736 .42845 L .52883 .42636 L F
.694 .768 .908 r
.52693 .42922 m .52696 .42939 L .5281 .42822 L F
.52818 .42804 m .5281 .42822 L .52941 .42688 L F
.52693 .42922 m .5281 .42822 L .52818 .42804 L F
0 0 0 r
.5284 .42752 m .52976 .42419 L .52944 .42497 L F
.694 .768 .908 r
.52872 .42675 m .52818 .42804 L .52941 .42688 L F
0 0 0 r
.52809 .42827 m .52837 .42758 L .5284 .42752 L F
.52837 .42758 m .52976 .42419 L .5284 .42752 L F
.52809 .42827 m .52788 .42832 L .52815 .42811 L F
.52788 .42832 m .52736 .42845 L .52815 .42811 L F
.52736 .42845 m .52596 .42878 L .52883 .42636 L F
.694 .768 .908 r
.52642 .42632 m .52691 .42909 L .52818 .42804 L F
.99 .888 .585 r
.52599 .43089 m .52696 .42939 L .52693 .42922 L F
.697 .954 .952 r
.53046 .42707 m .52696 .42939 L .52809 .42827 L F
0 0 0 r
.52599 .43089 m .52809 .42827 L .52696 .42939 L F
.52599 .43089 m .52736 .42845 L .52809 .42827 L F
.694 .768 .908 r
.52691 .42909 m .52693 .42922 L .52788 .42832 L F
.52691 .42909 m .52788 .42832 L .52818 .42804 L F
0 0 0 r
.52815 .42811 m .52896 .42602 L .52837 .42758 L F
.694 .768 .908 r
.52642 .42632 m .52818 .42804 L .52872 .42675 L F
0 0 0 r
.52837 .42758 m .52896 .42602 L .52976 .42419 L F
.52809 .42827 m .52815 .42811 L .52837 .42758 L F
.788 .628 .683 r
.52904 .42413 m .53039 .4259 L .52957 .42368 L F
0 0 0 r
.52944 .42497 m .52976 .42419 L .5298 .42411 L F
.788 .628 .683 r
.52952 .42477 m .53046 .42707 L .53039 .4259 L F
.52904 .42413 m .52944 .42497 L .52952 .42477 L F
.52944 .42497 m .53046 .42707 L .52952 .42477 L F
.524 0 0 r
.52794 .42237 m .53184 .42284 L .53008 .42393 L F
.728 .949 .646 r
.53038 .42346 m .53184 .42284 L .53299 .42057 L F
.788 .628 .683 r
.52969 .42401 m .52991 .42404 L .53024 .42313 L F
.728 .949 .646 r
.52991 .42404 m .53008 .42393 L .53027 .42364 L F
.788 .628 .683 r
.52991 .42404 m .53029 .42409 L .53027 .42364 L F
.52991 .42404 m .53027 .42364 L .53024 .42313 L F
.728 .949 .646 r
.5298 .42411 m .52991 .42404 L .53038 .42346 L F
.52991 .42404 m .53027 .42364 L .53038 .42346 L F
.53008 .42393 m .53184 .42284 L .53038 .42346 L F
.719 .986 .886 r
.53184 .42284 m .53498 .4207 L .53299 .42057 L F
.53184 .42284 m .53498 .4207 L .53299 .42057 L F
.728 .949 .646 r
.53073 .4239 m .53241 .42143 L .53375 .42321 L F
.53241 .42143 m .53335 .42184 L .53375 .42321 L F
.53038 .42346 m .53299 .42057 L .53073 .4239 L F
.551 .271 .443 r
.53299 .42057 m .5357 .42258 L .53375 .42321 L F
.565 .556 .803 r
.53046 .42707 m .53069 .42438 L .53029 .42409 L F
.788 .628 .683 r
.52969 .42401 m .53039 .4259 L .53029 .42409 L F
.539 .447 .7 r
.53073 .4239 m .53046 .42707 L .5298 .42411 L F
.53375 .42321 m .53046 .42707 L .53073 .4239 L F
.565 .556 .803 r
.53046 .42707 m .53108 .42466 L .53069 .42438 L F
.539 .447 .7 r
.53375 .42321 m .53315 .42634 L .53046 .42707 L F
.572 .479 .711 r
.53582 .42545 m .53315 .42634 L .53375 .42321 L F
.53582 .42545 m .53375 .42321 L .5357 .42258 L F
.6 .577 .8 r
.53172 .42221 m .53582 .42545 L .5357 .42258 L F
.699 .465 .565 r
.53172 .42221 m .53375 .42343 L .53387 .42257 L F
.486 0 0 r
.53387 .42257 m .53485 .4225 L .53481 .42273 L F
.53172 .42221 m .53387 .42241 L .53387 .42257 L F
.53387 .42241 m .53485 .4225 L .53387 .42257 L F
.382 .844 .876 r
.53299 .42057 m .53498 .4207 L .53788 .41975 L F
.53299 .42057 m .53788 .41975 L .53583 .42024 L F
.551 .271 .443 r
.53299 .42057 m .53583 .42024 L .5357 .42258 L F
0 0 0 r
.53424 .42002 m .53387 .42257 L .53462 .41985 L F
.53387 .42257 m .53375 .42343 L .53388 .4229 L F
.486 0 0 r
.53172 .42221 m .53286 .4224 L .53471 .42331 L F
.53286 .4224 m .53481 .42273 L .53471 .42331 L F
.158 .321 .779 r
.53462 .41985 m .53388 .4229 L .53471 .42331 L F
.53388 .4229 m .53375 .42343 L .53471 .42331 L F
0 0 0 r
.53387 .42257 m .53388 .4229 L .53462 .41985 L F
.728 .949 .646 r
.53241 .42143 m .53299 .42057 L .53335 .42184 L F
.699 .465 .565 r
.53172 .42221 m .53387 .42257 L .53424 .42002 L F
.486 0 0 r
.53485 .4225 m .5357 .42258 L .53545 .42276 L F
.53485 .4225 m .53545 .42276 L .53471 .42331 L F
.565 .556 .803 r
.53029 .42409 m .53058 .42371 L .53049 .4236 L F
.53029 .42409 m .53082 .42277 L .53027 .42364 L F
.728 .949 .646 r
.5298 .42411 m .53038 .42346 L .53073 .4239 L F
.565 .556 .803 r
.53049 .4236 m .53172 .42221 L .53082 .42277 L F
.53058 .42371 m .53172 .42221 L .53049 .4236 L F
.53027 .42364 m .53082 .42277 L .53024 .42313 L F
.53108 .42466 m .53172 .42221 L .53029 .42409 L F
.524 0 0 r
.52793 .42237 m .52794 .42237 L .52991 .42404 L F
.52794 .42237 m .53008 .42393 L .52991 .42404 L F
.52969 .42401 m .52991 .42404 L .5298 .42411 L F
.52793 .42237 m .52991 .42404 L .52969 .42401 L F
.788 .628 .683 r
.52957 .42368 m .52969 .42401 L .53024 .42313 L F
.524 0 0 r
.52969 .42401 m .5298 .42411 L .52976 .42419 L F
0 0 0 r
.52944 .42497 m .5298 .42411 L .53046 .42707 L F
.788 .628 .683 r
.52642 .42632 m .53046 .42707 L .52904 .42413 L F
0 0 0 r
.52809 .42827 m .5284 .42752 L .53046 .42707 L F
.694 .768 .908 r
.52941 .42688 m .52889 .42741 L .53046 .42707 L F
0 0 0 r
.52599 .43089 m .52598 .43011 L .52693 .42922 L F
.52598 .43011 m .52596 .42878 L .52693 .42922 L F
.99 .888 .585 r
.52599 .43089 m .52693 .42922 L .52691 .42909 L F
.52604 .43032 m .52691 .42909 L .52642 .42632 L F
.52599 .43089 m .52691 .42909 L .52604 .43032 L F
.916 .551 .322 r
.37543 .51753 m .37265 .51416 L .37536 .5148 L F
.633 .243 .287 r
.37114 .49444 m .37296 .49196 L .36913 .4923 L F
.662 .278 .306 r
.37114 .49444 m .37529 .49431 L .37296 .49196 L F
.84 .4 .179 r
.6812 .30763 m .68507 .31095 L .6853 .30824 L F
.76 .904 .515 r
.60303 .4449 m .60338 .44526 L .60288 .44579 L F
.062 .05 .529 r
.46576 .54402 m .46775 .54339 L .46718 .54036 L F
0 0 0 r
.46207 .54669 m .46515 .54459 L .46576 .54402 L F
.869 .561 .463 r
.36118 .53439 m .36075 .53867 L .36482 .53788 L F
.903 .693 .608 r
.36049 .53955 m .36482 .53788 L .36075 .53867 L F
.36049 .53955 m .36423 .54125 L .36482 .53788 L F
.504 .642 .917 r
.49065 .43935 m .49212 .44263 L .49443 .442 L F
.188 .276 .724 r
.49212 .44263 m .49495 .44506 L .49443 .442 L F
.637 .937 .964 r
.50565 .40131 m .5092 .39972 L .51032 .4004 L F
.808 .985 .714 r
.51301 .39702 m .51032 .4004 L .5112 .398 L F
.759 .974 .922 r
.51032 .4004 m .5092 .39972 L .5112 .398 L F
.664 .681 .856 r
.56316 .41478 m .56268 .41686 L .563 .41502 L F
.97 .801 .375 r
.56268 .41686 m .56228 .4196 L .56148 .41748 L F
.52 .244 .437 r
.3997 .45954 m .39936 .4619 L .39664 .46233 L F
.631 .342 .461 r
.40397 .46119 m .3997 .45954 L .40356 .4591 L F
.40397 .46119 m .39936 .4619 L .3997 .45954 L F
0 .269 .661 r
.59893 .42293 m .5991 .42307 L .59702 .42195 L F
.876 .962 .852 r
.59702 .42195 m .5935 .42631 L .59303 .42444 L F
.59702 .42195 m .59303 .42444 L .59547 .4226 L F
.05 .61 .8 r
.59547 .4226 m .59893 .42293 L .59702 .42195 L F
.59547 .4226 m .59859 .42264 L .59893 .42293 L F
.59859 .42264 m .59879 .42265 L .59893 .42293 L F
0 .269 .661 r
.59893 .42293 m .60038 .42377 L .5991 .42307 L F
.545 .013 0 r
.60122 .4248 m .60038 .42377 L .59893 .42293 L F
.60122 .4248 m .60219 .42541 L .60038 .42377 L F
.899 .708 .635 r
.38036 .57943 m .38168 .58418 L .38217 .5811 L F
0 .305 .766 r
.55786 .44663 m .56171 .44952 L .55985 .44578 L F
0 .018 .591 r
.55985 .44578 m .56171 .44952 L .56123 .44771 L F
.901 .603 .104 r
.56171 .44952 m .56127 .45087 L .56123 .44771 L F
.56171 .44952 m .56215 .45218 L .56127 .45087 L F
.898 .506 .269 r
.33708 .50057 m .34047 .50461 L .3396 .50248 L F
.974 .774 .572 r
.42922 .5665 m .43145 .56785 L .43067 .56181 L F
.682 .224 .157 r
.42868 .56932 m .43145 .56785 L .42922 .5665 L F
.799 .723 .192 r
.43104 .57067 m .43145 .56785 L .43283 .56982 L F
.682 .224 .157 r
.42868 .56932 m .43283 .56982 L .43145 .56785 L F
.974 .844 .651 r
.27411 .60143 m .27541 .60227 L .2774 .60009 L F
.522 .816 .477 r
.2774 .60009 m .27541 .60227 L .27788 .59957 L F
.864 .811 .796 r
.27541 .60227 m .28023 .60109 L .27788 .59957 L F
.974 .774 .572 r
.42922 .5665 m .43067 .56181 L .43251 .56441 L F
.906 .637 .519 r
.42757 .56263 m .43251 .56441 L .42992 .56079 L F
.903 .697 .614 r
.42922 .5665 m .43251 .56441 L .42757 .56263 L F
.921 .528 .201 r
.42992 .56079 m .43251 .56441 L .43067 .56181 L F
0 0 0 r
.44181 .44381 m .44108 .44399 L .43922 .44475 L F
0 0 .418 r
.42645 .5532 m .42622 .55476 L .42562 .5505 L F
0 0 .454 r
.42674 .55481 m .42622 .55476 L .42645 .5532 L F
.42674 .55481 m .42762 .55735 L .42622 .55476 L F
0 0 0 r
.5188 .41511 m .51706 .41655 L .52028 .4137 L F
0 0 .398 r
.51856 .4175 m .51706 .41655 L .5188 .41511 L F
.799 .649 .697 r
.38762 .4974 m .39154 .49848 L .39031 .49519 L F
.769 .348 .25 r
.38762 .4974 m .38998 .49964 L .39154 .49848 L F
.656 .565 .74 r
.39154 .49848 m .39328 .49485 L .39031 .49519 L F
.39154 .49848 m .39461 .49846 L .39328 .49485 L F
.976 .728 .493 r
.39281 .49916 m .39154 .49848 L .38998 .49964 L F
.39281 .49916 m .39461 .49846 L .39154 .49848 L F
.866 .577 .497 r
.38758 .53159 m .38453 .53311 L .38498 .53069 L F
.38758 .53159 m .38779 .53432 L .38453 .53311 L F
.84 .479 0 r
.42437 .54293 m .42453 .54143 L .42405 .5398 L F
.42437 .54293 m .42527 .54372 L .42453 .54143 L F
.663 .708 .881 r
.31018 .64362 m .31147 .64001 L .30868 .64022 L F
.31018 .64362 m .31282 .64289 L .31147 .64001 L F
.549 .443 .685 r
.30921 .54584 m .31204 .54447 L .30959 .54499 L F
.646 .158 0 r
.4629 .58291 m .46038 .58008 L .46038 .58299 L F
.783 .309 .11 r
.46038 .58299 m .46253 .58524 L .4629 .58291 L F
0 0 .33 r
.4629 .58291 m .46529 .5792 L .46594 .58041 L F
.4629 .58291 m .46544 .58192 L .46529 .5792 L F
0 0 .479 r
.46552 .58458 m .46544 .58192 L .4629 .58291 L F
.066 0 0 r
.61031 .34455 m .61323 .34422 L .61428 .34372 L F
.465 .884 .921 r
.61323 .34422 m .617 .34351 L .61428 .34372 L F
.762 .98 .724 r
.53164 .49052 m .53072 .4926 L .53226 .49066 L F
.763 .987 .755 r
.53164 .49052 m .52869 .49358 L .53072 .4926 L F
.934 .946 .772 r
.57432 .40486 m .57674 .40406 L .57651 .40118 L F
.935 .747 .623 r
.4212 .57679 m .42331 .58103 L .42409 .57826 L F
.206 0 .007 r
.39294 .48399 m .39201 .48313 L .39016 .48423 L F
.39294 .48399 m .39494 .48161 L .39201 .48313 L F
.533 .603 .869 r
.60118 .38322 m .59905 .38434 L .59683 .38066 L F
.296 0 0 r
.66114 .39521 m .66268 .39306 L .65971 .39418 L F
.409 .262 .569 r
.66482 .38978 m .66516 .39279 L .66268 .39306 L F
.204 0 0 r
.66325 .39418 m .66268 .39306 L .66114 .39521 L F
.66325 .39418 m .66516 .39279 L .66268 .39306 L F
.409 .262 .569 r
.66482 .38978 m .66516 .39279 L .66268 .39306 L F
0 0 .177 r
.66325 .39418 m .66268 .39306 L .66516 .39279 L F
.862 .85 .83 r
.35883 .50165 m .35669 .50092 L .35923 .49788 L F
.828 .409 .245 r
.35883 .50165 m .357 .50304 L .35669 .50092 L F
.35883 .50165 m .36053 .50447 L .357 .50304 L F
.137 0 0 r
.61987 .39737 m .61888 .39659 L .61755 .39827 L F
.61987 .39737 m .6215 .39608 L .61888 .39659 L F
.472 .801 .999 r
.2892 .59985 m .28697 .60044 L .28747 .59873 L F
.816 .955 .907 r
.56307 .4636 m .56262 .4663 L .56683 .46229 L F
.874 .989 .821 r
.56307 .4636 m .56028 .46694 L .56262 .4663 L F
.006 0 .073 r
.59108 .36111 m .59 .36284 L .59305 .35954 L F
.923 .734 .245 r
.69539 .35455 m .69628 .35425 L .69506 .35172 L F
.69539 .35455 m .69612 .35676 L .69628 .35425 L F
.935 .572 .296 r
.39887 .58433 m .39761 .58585 L .39734 .58317 L F
.39887 .58433 m .3995 .58678 L .39761 .58585 L F
.195 .677 .93 r
.62992 .38948 m .63114 .39029 L .62731 .38929 L F
.48 .742 .986 r
.63263 .38833 m .63114 .39029 L .62992 .38948 L F
.63263 .38833 m .634 .38994 L .63114 .39029 L F
.568 .372 .576 r
.34229 .52497 m .34267 .5282 L .34454 .52502 L F
.34229 .52497 m .34267 .5282 L .34454 .52502 L F
.915 .601 .437 r
.35101 .51711 m .35406 .52106 L .35417 .51846 L F
.854 .565 .499 r
.35417 .51846 m .35406 .52106 L .35656 .5215 L F
.3 0 0 r
.32318 .57821 m .32114 .5793 L .31831 .5792 L F
.868 .986 .712 r
.32346 .57578 m .32318 .57821 L .32557 .57745 L F
.32346 .57578 m .32114 .5793 L .32318 .57821 L F
.051 0 0 r
.42358 .45938 m .41906 .4603 L .42082 .45896 L F
.984 .711 .414 r
.45476 .49748 m .45483 .50023 L .45632 .49868 L F
0 0 0 r
.47627 .58271 m .47498 .58409 L .47694 .58011 L F
.551 .899 .674 r
.473 .58529 m .47498 .58409 L .47627 .58271 L F
.895 .983 .711 r
.47262 .58776 m .47498 .58409 L .473 .58529 L F
.687 .523 .659 r
.30516 .67199 m .30664 .67589 L .30265 .67538 L F
.702 .531 .653 r
.30516 .67199 m .30927 .6726 L .30664 .67589 L F
.969 .72 .502 r
.26845 .53164 m .26639 .53068 L .26675 .52736 L F
.851 .702 .696 r
.26827 .52857 m .26845 .53164 L .26675 .52736 L F
.537 .46 .716 r
.27091 .53097 m .26845 .53164 L .26827 .52857 L F
.62 .124 .053 r
.27091 .53097 m .26639 .53068 L .26845 .53164 L F
0 .227 .738 r
.57782 .37713 m .5777 .376 L .57695 .37552 L F
.57782 .37713 m .58043 .37913 L .5777 .376 L F
.365 0 0 r
.40434 .45496 m .40701 .45484 L .40858 .45294 L F
.513 .042 .074 r
.40858 .45294 m .40701 .45484 L .41084 .45421 L F
.49 .094 .216 r
.40858 .45294 m .41084 .45421 L .41158 .45275 L F
.595 .102 .053 r
.31609 .57754 m .31831 .5792 L .31907 .57841 L F
.84 .919 .887 r
.53897 .48799 m .54074 .48406 L .538 .4873 L F
.53897 .48799 m .54207 .48516 L .54074 .48406 L F
.546 .928 .896 r
.55457 .40013 m .55044 .4012 L .55197 .40069 L F
0 0 0 r
.55713 .39671 m .55534 .3991 L .55599 .39838 L F
.396 0 0 r
.55275 .39905 m .55638 .39795 L .55599 .39838 L F
.021 0 0 r
.55713 .39671 m .55599 .39838 L .55847 .39732 L F
.396 0 0 r
.55638 .39795 m .55847 .39732 L .55599 .39838 L F
0 0 0 r
.55534 .3991 m .55457 .40013 L .55599 .39838 L F
.625 .961 .873 r
.55599 .39838 m .55457 .40013 L .55197 .40069 L F
.887 .804 .761 r
.24042 .5831 m .24241 .58458 L .24506 .58107 L F
.655 .448 .591 r
.24506 .58107 m .24241 .58458 L .24457 .5841 L F
.668 .975 .85 r
.45229 .45183 m .45344 .45 L .45168 .45163 L F
.45229 .45183 m .4558 .44947 L .45344 .45 L F
.916 .887 .789 r
.57757 .45338 m .5784 .44879 L .57563 .45206 L F
.757 .994 .807 r
.49522 .51086 m .49818 .50748 L .49913 .50819 L F
.896 .978 .811 r
.49913 .50819 m .50077 .50413 L .5012 .50426 L F
.49913 .50819 m .49818 .50748 L .50077 .50413 L F
.321 .69 .979 r
.35563 .56579 m .35865 .56755 L .359 .56683 L F
.911 .969 .799 r
.66878 .36408 m .66717 .36727 L .66671 .3657 L F
0 .196 .71 r
.66717 .36727 m .66874 .36772 L .66671 .3657 L F
.66717 .36727 m .66913 .36881 L .66874 .36772 L F
.445 .305 .596 r
.66717 .36727 m .66769 .37018 L .66913 .36881 L F
0 0 0 r
.52793 .42237 m .52554 .42355 L .52441 .42486 L F
.42 .853 .731 r
.45215 .59634 m .45348 .5959 L .45657 .59427 L F
.786 .406 .338 r
.72053 .30225 m .724 .30128 L .72152 .30221 L F
.506 .838 .998 r
.63644 .36931 m .63226 .36907 L .63355 .37007 L F
.63644 .36931 m .63226 .36907 L .63355 .37007 L F
.453 .876 .927 r
.4386 .59925 m .43741 .60031 L .43998 .59941 L F
.45 .873 .933 r
.4351 .60007 m .43741 .60031 L .4386 .59925 L F
.975 .922 .625 r
.69692 .33636 m .69777 .33449 L .697 .33327 L F
.867 .771 .754 r
.4397 .56709 m .44179 .56943 L .43876 .56927 L F
.734 .983 .764 r
.44179 .56943 m .43701 .57318 L .43876 .56927 L F
.749 .763 .865 r
.44391 .56748 m .44179 .56943 L .4397 .56709 L F
.59 .397 .588 r
.69331 .31171 m .69598 .3112 L .69591 .30835 L F
.637 .507 .688 r
.69591 .30835 m .69856 .30787 L .69858 .30538 L F
.64 .436 .591 r
.69591 .30835 m .69879 .31061 L .69856 .30787 L F
.69591 .30835 m .69598 .3112 L .69879 .31061 L F
.704 .894 .966 r
.49495 .44506 m .4933 .44739 L .49532 .44787 L F
.709 .985 .879 r
.48678 .41393 m .48905 .41354 L .48566 .41596 L F
.72 .971 .729 r
.48566 .41596 m .48507 .41573 L .48678 .41393 L F
.883 .983 .822 r
.55858 .44224 m .5578 .44488 L .55985 .44578 L F
.519 .342 .581 r
.55786 .44663 m .55985 .44578 L .5578 .44488 L F
.004 .056 .565 r
.58772 .36397 m .58958 .36418 L .59 .36284 L F
.416 0 .132 r
.66631 .33132 m .6626 .33081 L .66543 .32994 L F
.66631 .33132 m .66159 .33301 L .6626 .33081 L F
.554 .567 .822 r
.34696 .56053 m .35075 .56433 L .34961 .56165 L F
.116 .214 .69 r
.35075 .56433 m .35102 .56134 L .34961 .56165 L F
.35075 .56433 m .35268 .5639 L .35102 .56134 L F
.544 .265 .443 r
.35075 .56433 m .35323 .56642 L .35268 .5639 L F
.35075 .56433 m .35062 .56736 L .35323 .56642 L F
.942 .577 .208 r
.56034 .43168 m .56187 .43293 L .56228 .43518 L F
.761 .729 .823 r
.4747 .57036 m .47941 .57082 L .47721 .56708 L F
.907 .626 .499 r
.47693 .57279 m .47941 .57082 L .4747 .57036 L F
.47693 .57279 m .47939 .57399 L .47941 .57082 L F
.804 .742 .795 r
.47721 .56708 m .47941 .57082 L .48163 .56768 L F
.652 .607 .791 r
.53341 .48081 m .53148 .48237 L .53015 .47843 L F
.773 .522 .556 r
.25045 .57363 m .24983 .57703 L .24917 .57332 L F
0 .488 .756 r
.24932 .57336 m .25138 .57373 L .25045 .57363 L F
.24917 .57332 m .24941 .57337 L .24932 .57336 L F
.24941 .57337 m .25138 .57373 L .24932 .57336 L F
.196 .135 .556 r
.24917 .57332 m .25093 .57295 L .25139 .57373 L F
.24917 .57332 m .24919 .57345 L .25093 .57295 L F
0 .488 .756 r
.25138 .57373 m .25138 .57373 L .25045 .57363 L F
.529 .446 .705 r
.25139 .57373 m .24983 .57703 L .25045 .57363 L F
.196 .135 .556 r
.24919 .57345 m .24983 .57703 L .25093 .57295 L F
.677 .619 .784 r
.25008 .57343 m .24983 .57703 L .24879 .57415 L F
.839 .788 .803 r
.24879 .57415 m .24796 .57642 L .24909 .57353 L F
.24879 .57415 m .24909 .57353 L .24917 .57332 L F
.135 0 0 r
.25008 .57343 m .24844 .57488 L .24879 .57415 L F
.839 .788 .803 r
.24879 .57415 m .24577 .57657 L .24796 .57642 L F
.135 0 0 r
.24844 .57488 m .24578 .57722 L .24879 .57415 L F
.677 .619 .784 r
.25093 .57295 m .25076 .57358 L .25008 .57343 L F
.135 0 0 r
.25093 .57295 m .25033 .57345 L .25008 .57343 L F
.677 .619 .784 r
.25076 .57358 m .24983 .57703 L .25008 .57343 L F
.135 0 0 r
.25033 .57345 m .24578 .57722 L .25008 .57343 L F
0 .488 .756 r
.25138 .57373 m .25139 .57373 L .25138 .57373 L F
.406 .184 .461 r
.51518 .41484 m .51282 .41312 L .51263 .41563 L F
.651 .631 .817 r
.32113 .64697 m .32208 .64224 L .31945 .64301 L F
.32113 .64697 m .32365 .64589 L .32208 .64224 L F
.856 .433 .22 r
.40551 .59302 m .40204 .59051 L .40582 .59146 L F
.634 .476 .652 r
.40774 .59051 m .40551 .59302 L .40582 .59146 L F
.97 .663 .276 r
.32069 .6164 m .32219 .62011 L .32098 .61901 L F
0 0 .17 r
.32219 .62011 m .32269 .62154 L .32098 .61901 L F
.737 .338 0 r
.39763 .49664 m .39917 .49914 L .39694 .49497 L F
.969 .829 .65 r
.39678 .50044 m .39917 .49914 L .39763 .49664 L F
.39678 .50044 m .39842 .50165 L .39917 .49914 L F
.814 .998 .846 r
.51593 .39411 m .51301 .39702 L .51379 .39451 L F
.831 .986 .712 r
.51301 .39702 m .5112 .398 L .51379 .39451 L F
.377 .135 .415 r
.2402 .60179 m .23821 .60001 L .24237 .60048 L F
.103 0 0 r
.24351 .59997 m .2402 .60179 L .24237 .60048 L F
.74 .813 .909 r
.32788 .64675 m .3301 .64624 L .32881 .64288 L F
.807 .845 .879 r
.32881 .64288 m .3301 .64624 L .33291 .64266 L F
.393 .85 .809 r
.61951 .34224 m .62236 .34106 L .62375 .34098 L F
.028 0 0 r
.62236 .34106 m .62644 .34013 L .62375 .34098 L F
.294 .015 .307 r
.53092 .41678 m .5304 .41887 L .53329 .41575 L F
.938 .647 .462 r
.35462 .5232 m .35656 .5215 L .35406 .52106 L F
.35462 .5232 m .35731 .52467 L .35656 .5215 L F
.56 .784 .983 r
.716 .29435 m .71903 .29372 L .72057 .29522 L F
.978 .787 .577 r
.72057 .29522 m .71903 .29372 L .716 .29435 L F
.72057 .29522 m .72012 .29775 L .71903 .29372 L F
.71903 .29372 m .72012 .29775 L .72057 .29522 L F
.678 .365 .437 r
.40356 .4591 m .40575 .46177 L .40397 .46119 L F
.787 .331 .163 r
.40696 .46138 m .40575 .46177 L .40356 .4591 L F
.647 .581 .767 r
.35319 .54636 m .35066 .54792 L .34943 .54432 L F
.311 .309 .695 r
.35327 .54935 m .35155 .55119 L .35066 .54792 L F
.899 .708 .635 r
.38036 .57943 m .37816 .58313 L .38168 .58418 L F
.858 .618 .574 r
.37771 .58598 m .38168 .58418 L .37816 .58313 L F
.37771 .58598 m .38135 .58671 L .38168 .58418 L F
.702 .185 0 r
.36523 .50705 m .36053 .50447 L .36287 .50485 L F
0 0 .046 r
.25725 .62723 m .25496 .63033 L .2569 .62879 L F
.685 .247 .204 r
.26129 .62937 m .25725 .62723 L .2569 .62879 L F
.58 .159 .208 r
.51747 .40609 m .51272 .40778 L .51303 .40749 L F
.5162 .40619 m .51303 .40749 L .51428 .40633 L F
.138 0 .285 r
.51694 .40588 m .5158 .40657 L .51884 .40509 L F
.5193 .40445 m .51694 .40588 L .51744 .40565 L F
.5193 .40445 m .51744 .40565 L .52139 .40385 L F
.915 .98 .748 r
.52122 .40073 m .5193 .40445 L .52139 .40385 L F
.349 .115 .411 r
.52139 .40288 m .52108 .40331 L .5193 .40445 L F
.138 0 .285 r
.51694 .40588 m .51884 .40509 L .52139 .40385 L F
.349 .115 .411 r
.52108 .40331 m .51876 .40644 L .5193 .40445 L F
.138 0 .285 r
.5193 .40445 m .51747 .40609 L .5158 .40657 L F
.31 .763 .956 r
.5158 .40657 m .51747 .40609 L .51428 .40633 L F
.58 .159 .208 r
.51747 .40609 m .51303 .40749 L .5162 .40619 L F
.915 .98 .748 r
.52122 .40073 m .52139 .40385 L .5236 .40246 L F
.814 .596 .039 r
.58483 .39307 m .58445 .39228 L .58414 .38876 L F
0 0 .441 r
.58483 .39307 m .58583 .394 L .58445 .39228 L F
.58483 .39307 m .58617 .39592 L .58583 .394 L F
.726 .458 .522 r
.29332 .67583 m .29612 .67614 L .29549 .6784 L F
.728 .414 .449 r
.29612 .67614 m .29974 .6788 L .29549 .6784 L F
0 0 .246 r
.26263 .5213 m .26325 .52257 L .26532 .52075 L F
.74 .633 .741 r
.61056 .36026 m .61521 .36149 L .61326 .35679 L F
0 0 .381 r
.34518 .55706 m .3465 .54978 L .34852 .55425 L F
.227 0 .245 r
.35155 .55119 m .35104 .55351 L .34852 .55425 L F
.63 .617 .819 r
.30878 .65931 m .30793 .66391 L .30661 .66198 L F
.30878 .65931 m .31031 .66306 L .30793 .66391 L F
.568 .422 .644 r
.31031 .66306 m .3078 .66605 L .30793 .66391 L F
.401 0 0 r
.25654 .63251 m .25938 .63324 L .25622 .63293 L F
.709 .948 .955 r
.2572 .63244 m .25938 .63324 L .25959 .63128 L F
.25622 .63293 m .25671 .63298 L .25686 .63281 L F
.401 0 0 r
.25698 .63279 m .25622 .63293 L .25705 .63283 L F
.25654 .63251 m .25622 .63293 L .25698 .63279 L F
.709 .948 .955 r
.25622 .63293 m .25686 .63281 L .2572 .63244 L F
.25671 .63298 m .25938 .63324 L .2572 .63244 L F
0 0 .501 r
.25496 .63033 m .25695 .63272 L .2569 .62879 L F
.25695 .63272 m .25705 .63283 L .25704 .63262 L F
.25695 .63272 m .25704 .63262 L .2569 .62879 L F
.25496 .63033 m .25654 .63251 L .25705 .63283 L F
.556 .544 .796 r
.27811 .59717 m .28086 .59412 L .27785 .59435 L F
.27811 .59717 m .28339 .59706 L .28086 .59412 L F
.712 .546 .662 r
.30927 .6726 m .30928 .67584 L .30664 .67589 L F
.567 .367 .569 r
.31217 .67236 m .30928 .67584 L .30927 .6726 L F
.351 .794 .633 r
.23581 .57327 m .23717 .57251 L .23945 .5713 L F
.601 .117 0 r
.60811 .44514 m .60901 .44602 L .60632 .44301 L F
.817 .721 .759 r
.2931 .6598 m .29218 .66221 L .28872 .6621 L F
.817 .723 .761 r
.29218 .66221 m .2903 .66556 L .28872 .6621 L F
.034 0 0 r
.30921 .54584 m .30476 .54784 L .30757 .54689 L F
.549 .443 .685 r
.30921 .54584 m .31163 .54676 L .31204 .54447 L F
0 .343 .761 r
.30757 .54689 m .31163 .54676 L .30921 .54584 L F
.848 .692 .689 r
.46066 .56117 m .46105 .5629 L .45994 .56401 L F
.274 .276 .68 r
.46473 .53824 m .46718 .54036 L .46692 .53651 L F
.138 .403 .851 r
.52754 .38372 m .52805 .38628 L .52601 .38274 L F
.52754 .38372 m .53022 .38674 L .52805 .38628 L F
0 0 .319 r
.53022 .38674 m .52834 .38916 L .52805 .38628 L F
.925 .946 .79 r
.55929 .3932 m .55625 .39534 L .5576 .39196 L F
.828 .727 .753 r
.28872 .6621 m .2903 .66556 L .28819 .66612 L F
.803 .71 .762 r
.2903 .66556 m .28785 .66902 L .28819 .66612 L F
.833 .97 .887 r
.47262 .58776 m .473 .58529 L .46832 .58938 L F
0 0 .319 r
.53003 .38699 m .52989 .38841 L .52834 .38916 L F
.213 0 .232 r
.5298 .39102 m .52834 .38916 L .52989 .38841 L F
.5298 .39102 m .52718 .393 L .52834 .38916 L F
.785 .588 .635 r
.52672 .38791 m .52965 .39087 L .52989 .38841 L F
.52965 .39087 m .5298 .39102 L .52989 .38841 L F
0 0 .319 r
.53022 .38674 m .52989 .38841 L .53003 .38699 L F
.911 .938 .813 r
.63906 .38487 m .63757 .38932 L .6365 .38845 L F
.793 .998 .854 r
.63535 .40124 m .63423 .40375 L .63626 .4018 L F
.765 .975 .92 r
.6333 .403 m .63423 .40375 L .63535 .40124 L F
.272 0 0 r
.59207 .35066 m .59001 .35012 L .58767 .34935 L F
.751 .25 .032 r
.59573 .35293 m .59435 .35325 L .59207 .35066 L F
0 .006 .555 r
.59207 .35066 m .59435 .35325 L .59294 .35111 L F
.59207 .35066 m .59294 .35111 L .59001 .35012 L F
.292 0 .079 r
.52814 .43617 m .52456 .43892 L .52816 .43883 L F
.868 .975 .668 r
.65808 .38982 m .66047 .38626 L .66014 .38518 L F
.062 .611 .833 r
.24372 .58612 m .24834 .58439 L .24457 .5841 L F
.24372 .58612 m .24889 .58687 L .24834 .58439 L F
.567 .906 .975 r
.59032 .34559 m .59166 .34319 L .59339 .34447 L F
.59032 .34559 m .58782 .34426 L .59166 .34319 L F
.597 .573 .797 r
.58216 .35943 m .58325 .36509 L .58119 .36495 L F
.499 .033 .079 r
.58325 .36509 m .58377 .36591 L .58119 .36495 L F
.652 .818 .963 r
.36358 .62911 m .36545 .63066 L .36776 .62954 L F
.955 .625 .352 r
.39734 .58317 m .39531 .57923 L .39624 .58031 L F
.966 .651 .363 r
.52122 .40073 m .52343 .39998 L .52272 .39901 L F
.52122 .40073 m .5236 .40246 L .52343 .39998 L F
.949 .956 .711 r
.52466 .39479 m .52272 .39901 L .52343 .39998 L F
.667 .958 .738 r
.6755 .37888 m .67897 .3764 L .67731 .37723 L F
.469 .885 .774 r
.67897 .3764 m .68263 .37451 L .68101 .37492 L F
.443 .849 .668 r
.67731 .37723 m .67897 .3764 L .68101 .37492 L F
.05 0 0 r
.41158 .45275 m .41398 .45198 L .41452 .45116 L F
.02 0 0 r
.41398 .45198 m .41745 .45048 L .41452 .45116 L F
0 0 .441 r
.50847 .41761 m .50711 .41626 L .50821 .41509 L F
0 0 0 r
.5102 .41611 m .50981 .41646 L .50847 .41761 L F
.50981 .41646 m .50727 .41875 L .50847 .41761 L F
0 0 .441 r
.50847 .41761 m .50749 .41964 L .50737 .41857 L F
.50847 .41761 m .50737 .41857 L .50711 .41626 L F
.221 .128 .532 r
.23769 .54783 m .23914 .5473 L .23863 .54561 L F
.272 .061 .399 r
.23692 .55054 m .23914 .5473 L .23769 .54783 L F
.286 .781 .746 r
.59769 .35231 m .59435 .35325 L .59573 .35293 L F
.337 .812 .755 r
.50173 .44485 m .50379 .44383 L .50118 .44455 L F
0 0 0 r
.50247 .44436 m .50118 .44455 L .50379 .44383 L F
.289 .77 .922 r
.50012 .4447 m .50173 .44485 L .50118 .44455 L F
0 0 0 r
.49958 .44552 m .50118 .44455 L .50247 .44436 L F
.289 .77 .922 r
.49864 .44457 m .50012 .4447 L .50118 .44455 L F
.337 .812 .755 r
.50173 .44485 m .50592 .44328 L .50379 .44383 L F
.764 .994 .872 r
.50711 .49817 m .50797 .49584 L .51015 .49526 L F
.50711 .49817 m .50623 .49772 L .50797 .49584 L F
.427 .856 .728 r
.45035 .4399 m .44614 .44189 L .44811 .44036 L F
.563 .936 .844 r
.45247 .43854 m .45035 .4399 L .44811 .44036 L F
.162 0 .224 r
.49055 .55034 m .48794 .5536 L .48865 .55129 L F
.938 .872 .745 r
.37908 .59252 m .38197 .59126 L .37946 .58972 L F
.37908 .59252 m .3806 .59359 L .38197 .59126 L F
.438 0 0 r
.34696 .56053 m .34408 .56246 L .3428 .56119 L F
0 .373 .756 r
.34696 .56053 m .34961 .56165 L .3478 .56057 L F
.34696 .56053 m .3478 .56057 L .34408 .56246 L F
.861 .683 .66 r
.34428 .5859 m .34822 .5842 L .34468 .58441 L F
.34428 .5859 m .34817 .58752 L .34822 .5842 L F
.517 .474 .747 r
.34822 .5842 m .35053 .58353 L .34984 .57966 L F
.486 .37 .647 r
.34822 .5842 m .35102 .58648 L .35053 .58353 L F
.484 .37 .649 r
.34911 .58492 m .34817 .58752 L .35102 .58648 L F
.34819 .58582 m .34817 .58752 L .34911 .58492 L F
0 0 0 r
.35054 .58352 m .34854 .58604 L .35201 .5825 L F
.35053 .58353 m .35052 .58355 L .35054 .58352 L F
.35052 .58355 m .34854 .58604 L .35054 .58352 L F
.484 .37 .649 r
.34822 .5842 m .34819 .58582 L .34911 .58492 L F
.943 .834 .706 r
.37854 .59966 m .37747 .60242 L .3796 .60263 L F
.877 .879 .832 r
.37438 .60609 m .3796 .60263 L .37747 .60242 L F
.993 .87 .538 r
.67103 .35401 m .66867 .35671 L .66891 .35497 L F
.67103 .35401 m .67045 .35676 L .66867 .35671 L F
.818 .866 .883 r
.67289 .34928 m .67103 .35401 L .67052 .35296 L F
.67289 .34928 m .67429 .35083 L .67103 .35401 L F
.893 .989 .777 r
.67052 .35296 m .67103 .35401 L .66891 .35497 L F
.488 .687 .955 r
.59467 .38095 m .59683 .38066 L .59675 .37886 L F
.986 .726 .442 r
.39506 .54785 m .39498 .55055 L .39348 .54669 L F
.39506 .54785 m .39498 .55055 L .39348 .54669 L F
.639 .14 .048 r
.27156 .59954 m .27411 .60143 L .2774 .60009 L F
.742 .525 .599 r
.35647 .54161 m .35224 .5435 L .35233 .54114 L F
.35647 .54161 m .35463 .54391 L .35224 .5435 L F
.856 .433 .22 r
.40551 .59302 m .4034 .59289 L .40204 .59051 L F
0 0 .508 r
.40551 .59302 m .40763 .59564 L .40603 .59328 L F
.40551 .59302 m .40603 .59328 L .4034 .59289 L F
.895 .59 .463 r
.36665 .54706 m .3703 .55024 L .37028 .54811 L F
.811 .699 .741 r
.43454 .45479 m .44005 .45371 L .43728 .45353 L F
.43454 .45479 m .43379 .45827 L .44005 .45371 L F
.753 .969 .929 r
.44005 .45371 m .43897 .45303 L .43728 .45353 L F
.44005 .45371 m .44211 .45208 L .43897 .45303 L F
.186 0 0 r
.40982 .46127 m .40575 .46177 L .40696 .46138 L F
.916 .979 .724 r
.67184 .35954 m .6689 .3628 L .67162 .35901 L F
.67184 .35954 m .66878 .36408 L .6689 .3628 L F
.595 .949 .842 r
.45344 .45 m .4558 .44947 L .45792 .44799 L F
.768 .934 .939 r
.54207 .48516 m .54297 .48259 L .54074 .48406 L F
.54207 .48516 m .54554 .48303 L .54297 .48259 L F
0 0 0 r
.62801 .34551 m .62689 .346 L .62407 .34671 L F
.62935 .34499 m .62801 .34551 L .63057 .3446 L F
.62935 .34499 m .62689 .346 L .62801 .34551 L F
.65825 .39504 m .65911 .39446 L .65735 .39526 L F
0 .136 .659 r
.65735 .39526 m .6591 .39762 L .65825 .39504 L F
.261 .226 .628 r
.65825 .39504 m .65652 .39419 L .65767 .39239 L F
.395 .12 .374 r
.65523 .39784 m .65652 .39419 L .65825 .39504 L F
0 0 .467 r
.6589 .39331 m .65825 .39504 L .65767 .39239 L F
.764 .935 .586 r
.65723 .39573 m .65825 .39504 L .6589 .39331 L F
.65703 .39603 m .65825 .39504 L .65723 .39573 L F
0 0 0 r
.65825 .39504 m .65971 .39418 L .65911 .39446 L F
.296 0 0 r
.66114 .39521 m .65971 .39418 L .65825 .39504 L F
.937 .608 .167 r
.57896 .42737 m .57976 .42649 L .57835 .42528 L F
.57896 .42737 m .5802 .42886 L .57976 .42649 L F
.886 .662 .593 r
.37306 .56612 m .37572 .56443 L .37329 .5638 L F
.37306 .56612 m .37538 .56706 L .37572 .56443 L F
.985 .734 .467 r
.38987 .54048 m .38835 .53679 L .38997 .538 L F
.676 .552 .706 r
.31451 .52546 m .31536 .52807 L .31763 .52435 L F
.903 .811 .748 r
.29609 .63557 m .29947 .63531 L .29867 .63496 L F
.29609 .63557 m .29788 .6384 L .29947 .63531 L F
.801 .561 .575 r
.24917 .57332 m .24601 .57087 L .24665 .56904 L F
0 .16 .696 r
.2488 .57095 m .24917 .57332 L .24665 .56904 L F
.003 0 0 r
.25093 .57295 m .24917 .57332 L .2488 .57095 L F
.25093 .57295 m .24879 .57415 L .24917 .57332 L F
.919 .824 .736 r
.35224 .6361 m .35478 .63649 L .35421 .63249 L F
.891 .871 .812 r
.35254 .63899 m .35478 .63649 L .35224 .6361 L F
.806 .756 .807 r
.35478 .63649 m .35812 .63264 L .35421 .63249 L F
.989 .741 .368 r
.72398 .3099 m .72417 .31288 L .72532 .31467 L F
1 .802 .491 r
.72532 .31467 m .72382 .31591 L .72488 .31751 L F
.72532 .31467 m .72417 .31288 L .72382 .31591 L F
.505 .46 .74 r
.54101 .45655 m .53806 .45471 L .53956 .45576 L F
.53931 .45846 m .54101 .45655 L .53956 .45576 L F
.705 .833 .392 r
.53378 .455 m .53399 .45441 L .53508 .45254 L F
.624 .2 .218 r
.53399 .45441 m .53806 .45471 L .53508 .45254 L F
.22 .25 .681 r
.23434 .56392 m .23497 .56781 L .23659 .56554 L F
.103 .658 .773 r
.30852 .63623 m .30796 .63641 L .30519 .63476 L F
.30852 .63623 m .31069 .63616 L .30796 .63641 L F
.556 .761 .973 r
.32365 .64589 m .32788 .64675 L .32574 .6455 L F
.74 .813 .909 r
.32788 .64675 m .32881 .64288 L .32574 .6455 L F
.206 .387 .822 r
.60415 .38478 m .60293 .38678 L .60118 .38322 L F
.406 .652 .958 r
.60415 .38478 m .60547 .38664 L .60293 .38678 L F
.783 .508 .521 r
.55855 .38431 m .56099 .38602 L .56141 .3837 L F
.582 .582 .818 r
.56099 .38602 m .56173 .38155 L .56141 .3837 L F
.388 0 .132 r
.39545 .48295 m .39494 .48161 L .39294 .48399 L F
.465 .422 .726 r
.37903 .4598 m .38202 .46147 L .38185 .45793 L F
.564 .902 .667 r
.66359 .32081 m .6654 .31895 L .66688 .31814 L F
.824 .547 .519 r
.53434 .38683 m .52989 .38841 L .53307 .38593 L F
.53434 .38683 m .53454 .38973 L .52989 .38841 L F
.386 .217 .526 r
.53684 .3885 m .53434 .38683 L .53589 .38403 L F
.53684 .3885 m .53454 .38973 L .53434 .38683 L F
.954 .657 .433 r
.38147 .5247 m .37911 .52363 L .379 .52091 L F
.962 .715 .517 r
.38147 .5247 m .37917 .52604 L .37911 .52363 L F
.38147 .5247 m .38105 .52727 L .37917 .52604 L F
0 0 .296 r
.59377 .4327 m .59564 .43439 L .59525 .43431 L F
.663 .121 0 r
.59205 .4318 m .59521 .43428 L .59429 .43442 L F
.59521 .43428 m .59525 .43431 L .59429 .43442 L F
.59205 .4318 m .59429 .43442 L .59137 .43447 L F
.55 .363 .581 r
.59137 .43447 m .59429 .43442 L .59204 .43726 L F
.891 .893 .825 r
.59537 .43039 m .59377 .4327 L .59205 .4318 L F
.59537 .43039 m .59205 .4318 L .59398 .42848 L F
.944 .92 .757 r
.59088 .42904 m .59205 .4318 L .58978 .42924 L F
.59398 .42848 m .59384 .42872 L .59088 .42904 L F
.59384 .42872 m .59205 .4318 L .59088 .42904 L F
.966 .805 .63 r
.59205 .4318 m .59025 .43234 L .58978 .42924 L F
.735 .665 .781 r
.5883 .43174 m .58978 .42924 L .59025 .43234 L F
.913 .876 .786 r
.59178 .42593 m .59341 .42755 L .58978 .42924 L F
.812 .993 .87 r
.59341 .42755 m .59398 .42848 L .59146 .42893 L F
.59145 .42846 m .59146 .42893 L .58978 .42924 L F
.59341 .42755 m .59146 .42893 L .59145 .42846 L F
.913 .876 .786 r
.59178 .42593 m .58978 .42924 L .59105 .42936 L F
.473 .506 .811 r
.59024 .42579 m .58959 .42708 L .58736 .4272 L F
.59024 .42579 m .58736 .4272 L .58787 .42673 L F
.762 .634 .719 r
.58667 .42784 m .58736 .4272 L .58675 .42757 L F
.313 .79 .708 r
.58736 .4272 m .58656 .42725 L .58675 .42757 L F
.473 .506 .811 r
.58959 .42708 m .58861 .42903 L .58656 .42725 L F
.539 .74 .969 r
.5883 .43174 m .5868 .42788 L .58861 .42903 L F
.5868 .42788 m .58656 .42725 L .58695 .42758 L F
.5868 .42788 m .58695 .42758 L .58861 .42903 L F
.5883 .43174 m .58435 .43054 L .58456 .43024 L F
.5883 .43174 m .58456 .43024 L .5868 .42788 L F
.927 .77 .292 r
.58612 .42969 m .58659 .42811 L .58656 .42725 L F
.58659 .42811 m .58675 .42757 L .58656 .42725 L F
.539 .74 .969 r
.5868 .42788 m .58659 .42811 L .58656 .42725 L F
.58659 .42811 m .58456 .43024 L .58656 .42725 L F
.762 .634 .719 r
.58685 .42784 m .58736 .4272 L .58695 .42758 L F
.58612 .42969 m .58726 .42741 L .58685 .42784 L F
.58726 .42741 m .58736 .4272 L .58685 .42784 L F
.58642 .42868 m .58695 .42758 L .58667 .42784 L F
.58612 .42969 m .58695 .42758 L .58642 .42868 L F
.58612 .42969 m .58893 .42625 L .58736 .4272 L F
.473 .506 .811 r
.58787 .42673 m .58736 .4272 L .58656 .42725 L F
.313 .79 .708 r
.58893 .42625 m .59024 .42579 L .58656 .42725 L F
.58893 .42625 m .58656 .42725 L .58736 .4272 L F
.473 .506 .811 r
.59024 .42579 m .59105 .42936 L .58861 .42903 L F
.836 .781 .277 r
.59182 .4243 m .59105 .42936 L .59024 .42579 L F
.581 .058 0 r
.58893 .42625 m .59123 .42667 L .59024 .42579 L F
.836 .781 .277 r
.59182 .4243 m .59142 .42762 L .59141 .42702 L F
.581 .058 0 r
.59123 .42667 m .59202 .42682 L .59134 .42642 L F
.59123 .42667 m .59134 .42642 L .59024 .42579 L F
.836 .781 .277 r
.59165 .42574 m .59178 .42593 L .59142 .42762 L F
.59182 .4243 m .59179 .42541 L .59165 .42574 L F
.59179 .42541 m .59178 .42593 L .59165 .42574 L F
.59141 .42702 m .59142 .42762 L .59105 .42936 L F
.131 .617 .915 r
.59105 .42936 m .58978 .42924 L .58861 .42903 L F
.735 .665 .781 r
.5883 .43174 m .58861 .42903 L .58978 .42924 L F
.5883 .43174 m .59105 .42936 L .58861 .42903 L F
.233 0 0 r
.58912 .42923 m .59105 .42936 L .59009 .42962 L F
.58861 .42903 m .58967 .42917 L .58912 .42923 L F
.58967 .42917 m .59105 .42936 L .58912 .42923 L F
.966 .805 .63 r
.59205 .4318 m .59137 .43447 L .59025 .43234 L F
.735 .665 .781 r
.5883 .43174 m .59445 .43339 L .59105 .42936 L F
.73 .759 .876 r
.59025 .43234 m .59137 .43447 L .58731 .43387 L F
.683 .955 .95 r
.5883 .43174 m .59025 .43234 L .58731 .43387 L F
.776 .549 .59 r
.59248 .43495 m .59445 .43339 L .59004 .43221 L F
.59047 .43341 m .59004 .43221 L .5883 .43174 L F
.59218 .43472 m .59004 .43221 L .59047 .43341 L F
.59221 .43465 m .59004 .43221 L .59218 .43472 L F
.113 .41 .859 r
.59165 .43792 m .5899 .43536 L .59137 .43447 L F
.375 .834 .759 r
.59125 .43953 m .59165 .43792 L .59204 .43726 L F
.59125 .43953 m .58895 .44075 L .59165 .43792 L F
.113 .41 .859 r
.59165 .43792 m .59137 .43447 L .59204 .43726 L F
.959 .75 .579 r
.59125 .43953 m .59204 .43726 L .59031 .43548 L F
.849 .995 .753 r
.59204 .43726 m .59248 .43495 L .59031 .43548 L F
.59204 .43726 m .59429 .43442 L .59248 .43495 L F
.151 .23 .692 r
.59031 .43548 m .59292 .43775 L .59125 .43953 L F
.019 .21 .718 r
.59159 .43652 m .59031 .43548 L .59168 .43904 L F
.78 .676 .749 r
.58731 .43387 m .59137 .43447 L .5899 .43536 L F
.776 .549 .59 r
.59248 .43495 m .5883 .43174 L .59031 .43548 L F
.019 .21 .718 r
.59149 .43381 m .59292 .43775 L .59031 .43548 L F
.59149 .43381 m .59091 .43463 L .59159 .43652 L F
.59091 .43463 m .59031 .43548 L .59159 .43652 L F
.646 .465 .625 r
.58747 .43899 m .59168 .43904 L .59031 .43548 L F
.019 .21 .718 r
.59149 .43381 m .59159 .43652 L .59086 .43764 L F
.59159 .43652 m .59168 .43904 L .59109 .43802 L F
.59159 .43652 m .59109 .43802 L .59086 .43764 L F
.776 .549 .59 r
.59248 .43495 m .59221 .43465 L .59218 .43472 L F
.236 .469 .88 r
.59105 .42936 m .59445 .43339 L .59447 .43034 L F
.828 .987 .873 r
.59316 .43441 m .59447 .43034 L .59445 .43339 L F
.59248 .43495 m .59276 .43429 L .59316 .43441 L F
.59276 .43429 m .59447 .43034 L .59316 .43441 L F
.617 .857 .989 r
.59429 .43442 m .59577 .43187 L .59281 .43464 L F
.59429 .43442 m .59281 .43464 L .59248 .43495 L F
.828 .987 .873 r
.59248 .43495 m .59149 .43381 L .59447 .43034 L F
.59248 .43495 m .59256 .43426 L .59149 .43381 L F
.59248 .43495 m .59305 .43441 L .59256 .43426 L F
.59305 .43441 m .59577 .43187 L .59256 .43426 L F
.204 .343 .783 r
.5946 .43626 m .59177 .43403 L .59256 .43426 L F
.59177 .43403 m .59171 .43398 L .59256 .43426 L F
.59171 .43398 m .59149 .43381 L .59233 .43416 L F
.59171 .43398 m .59233 .43416 L .59256 .43426 L F
.407 .846 .936 r
.59525 .43431 m .59701 .4332 L .59474 .43421 L F
.59525 .43431 m .59474 .43421 L .59429 .43442 L F
0 0 .296 r
.59564 .43439 m .59633 .43502 L .59525 .43431 L F
.503 .837 .998 r
.59633 .43502 m .5976 .4337 L .59525 .43431 L F
.59633 .43502 m .59893 .43423 L .5976 .4337 L F
.329 .058 .343 r
.65332 .39675 m .65652 .39419 L .65523 .39784 L F
.08 0 .079 r
.65332 .39675 m .6563 .39389 L .65652 .39419 L F
.3 .078 .4 r
.65293 .39929 m .65332 .39675 L .65523 .39784 L F
.784 .646 .71 r
.29146 .65568 m .2931 .6598 L .28884 .65919 L F
.817 .721 .759 r
.2931 .6598 m .28872 .6621 L .28884 .65919 L F
.71 .611 .745 r
.29487 .65761 m .2931 .6598 L .29146 .65568 L F
.738 .815 .912 r
.47721 .56708 m .48163 .56768 L .47995 .56619 L F
.849 .832 .83 r
.48163 .56768 m .48233 .56315 L .47995 .56619 L F
.48163 .56768 m .48449 .56449 L .48233 .56315 L F
.871 .959 .859 r
.38895 .4945 m .38762 .4974 L .39031 .49519 L F
.909 .957 .811 r
.38895 .4945 m .39031 .49519 L .38972 .4925 L F
.639 .447 .608 r
.68953 .31448 m .69352 .31436 L .69331 .31171 L F
.68 .478 .606 r
.69331 .31171 m .69614 .31397 L .69598 .3112 L F
.69331 .31171 m .69352 .31436 L .69614 .31397 L F
.881 .511 .339 r
.29 .67239 m .29332 .67583 L .28999 .67511 L F
.82 .524 .489 r
.28999 .67511 m .29332 .67583 L .29089 .67811 L F
.773 .452 .443 r
.29332 .67583 m .29549 .6784 L .29089 .67811 L F
0 0 .1 r
.35327 .54935 m .35104 .55351 L .35155 .55119 L F
.866 .826 .807 r
.48233 .56315 m .48449 .56449 L .48689 .56105 L F
.912 .943 .812 r
.55896 .36833 m .55814 .37037 L .5584 .36704 L F
0 .043 .597 r
.55814 .37037 m .55942 .37105 L .5584 .36704 L F
.55814 .37037 m .56036 .37271 L .55942 .37105 L F
.091 .176 .66 r
.55899 .37242 m .56036 .37271 L .55814 .37037 L F
.053 .62 .739 r
.59697 .3433 m .59533 .3433 L .59956 .34319 L F
.516 .349 .593 r
.41139 .56382 m .41392 .5602 L .4116 .56093 L F
.41392 .5602 m .41139 .56382 L .4116 .56093 L F
0 0 0 r
.55516 .38962 m .55719 .38763 L .55855 .38431 L F
0 .112 .637 r
.55516 .38962 m .55637 .39017 L .55719 .38763 L F
.866 .826 .807 r
.48233 .56315 m .48689 .56105 L .48507 .56041 L F
.835 .995 .849 r
.66852 .31599 m .66688 .31814 L .66776 .31526 L F
.845 .971 .656 r
.66688 .31814 m .6654 .31895 L .66776 .31526 L F
.5 .205 .396 r
.28378 .58947 m .28651 .58943 L .28489 .58705 L F
.702 .497 .608 r
.30265 .67538 m .30387 .67844 L .29974 .6788 L F
.702 .512 .628 r
.30664 .67589 m .30387 .67844 L .30265 .67538 L F
.75 .958 .657 r
.33821 .56663 m .33549 .56894 L .33648 .56671 L F
.649 .838 .973 r
.33831 .56558 m .33648 .56671 L .3381 .56541 L F
.094 0 0 r
.33821 .56663 m .33648 .56671 L .33982 .56676 L F
.649 .838 .973 r
.33982 .56676 m .33767 .56673 L .33831 .56558 L F
.33767 .56673 m .33648 .56671 L .33831 .56558 L F
.75 .958 .657 r
.3373 .56741 m .33485 .57059 L .33549 .56894 L F
.33821 .56663 m .33682 .56827 L .3373 .56741 L F
.33682 .56827 m .33485 .57059 L .3373 .56741 L F
.561 .521 .769 r
.33978 .55707 m .3428 .56119 L .34102 .55698 L F
0 0 .069 r
.24368 .53165 m .24172 .53459 L .24365 .533 L F
0 0 .367 r
.24172 .53459 m .24272 .53613 L .24365 .533 L F
.24172 .53459 m .24171 .53751 L .24272 .53613 L F
.946 .775 .64 r
.45845 .56033 m .46066 .56117 L .45994 .56401 L F
.989 .836 .6 r
.69574 .34736 m .69506 .3429 L .69486 .34534 L F
.941 .715 .243 r
.69565 .34981 m .69574 .34736 L .69486 .34534 L F
.9 .708 .201 r
.33115 .60036 m .33077 .60043 L .3324 .59878 L F
.966 .906 .706 r
.39963 .56767 m .39786 .57154 L .39715 .56912 L F
.997 .792 .437 r
.39963 .56767 m .39844 .56672 L .39887 .56359 L F
.951 .944 .735 r
.39963 .56767 m .39715 .56912 L .39844 .56672 L F
.73 .858 .941 r
.70442 .32298 m .70568 .32461 L .70805 .3231 L F
.653 .48 .638 r
.31571 .66956 m .3158 .67225 L .31217 .67236 L F
.631 .612 .813 r
.31704 .66554 m .31571 .66956 L .31453 .66593 L F
.31704 .66554 m .31845 .66919 L .31571 .66956 L F
.611 .447 .636 r
.31571 .66956 m .31845 .66919 L .3158 .67225 L F
.757 .994 .807 r
.49522 .51086 m .49499 .51041 L .49818 .50748 L F
.302 .774 .662 r
.34682 .53365 m .3476 .53329 L .34786 .5332 L F
.054 .118 .612 r
.34682 .53365 m .34871 .5358 L .3476 .53329 L F
.883 .465 .05 r
.3476 .53329 m .3471 .53451 L .34717 .53344 L F
.3476 .53329 m .34717 .53344 L .34729 .53178 L F
.302 .774 .662 r
.34786 .5332 m .3476 .53329 L .35092 .53185 L F
.945 .842 .711 r
.35092 .53185 m .3476 .53329 L .34914 .5303 L F
.852 .967 .874 r
.44459 .56477 m .44649 .56534 L .44391 .56748 L F
.193 .704 .895 r
.44935 .56519 m .44649 .56534 L .44459 .56477 L F
.051 0 0 r
.42358 .45938 m .4216 .46004 L .41906 .4603 L F
.776 .47 .469 r
.68518 .3162 m .68953 .31448 L .6851 .31359 L F
.68518 .3162 m .68946 .31676 L .68953 .31448 L F
.734 .554 .648 r
.68946 .31676 m .69352 .31436 L .68953 .31448 L F
.567 .367 .569 r
.31217 .67236 m .31258 .67531 L .30928 .67584 L F
.613 .308 .43 r
.31217 .67236 m .3155 .67455 L .31258 .67531 L F
.31217 .67236 m .3158 .67225 L .3155 .67455 L F
.816 .548 .533 r
.48836 .544 m .48943 .54676 L .48946 .54455 L F
.898 .93 .829 r
.49167 .5403 m .48836 .544 L .48946 .54455 L F
0 .11 .645 r
.54118 .46015 m .5406 .46235 L .53931 .45846 L F
.821 .999 .793 r
.53858 .46293 m .5406 .46235 L .54118 .46015 L F
.988 .896 .606 r
.56938 .41431 m .5703 .41566 L .57126 .41322 L F
.92 .955 .795 r
.57089 .41082 m .57126 .41322 L .57142 .41228 L F
.965 .938 .645 r
.56938 .41431 m .57126 .41322 L .57089 .41082 L F
.225 0 .27 r
.30072 .54394 m .29792 .54698 L .29855 .54472 L F
.30072 .54394 m .29792 .54698 L .29855 .54472 L F
.52 .579 .854 r
.34404 .56994 m .34169 .57093 L .33982 .56676 L F
.594 .219 .301 r
.34169 .57093 m .34373 .57321 L .34149 .57289 L F
.374 .204 .519 r
.34404 .56994 m .34373 .57321 L .34169 .57093 L F
.512 .485 .764 r
.59723 .39658 m .59479 .39707 L .59731 .39375 L F
.34 .014 .257 r
.32959 .57366 m .32817 .57665 L .32557 .57745 L F
.666 .786 .321 r
.32882 .57521 m .32817 .57665 L .32959 .57366 L F
.32875 .57536 m .32866 .57556 L .32882 .57521 L F
.32866 .57556 m .32817 .57665 L .32882 .57521 L F
.76 .536 .593 r
.32685 .5735 m .3294 .57398 L .32836 .5693 L F
.666 .786 .321 r
.32875 .57536 m .32959 .57366 L .33189 .57335 L F
.634 .443 .607 r
.33485 .57059 m .3347 .57362 L .33189 .57335 L F
.084 .626 .849 r
.33189 .57335 m .3347 .57362 L .33312 .57312 L F
0 0 0 r
.33312 .57312 m .33078 .57424 L .32875 .57536 L F
.084 .626 .849 r
.3293 .57501 m .33312 .57312 L .32875 .57536 L F
.33189 .57335 m .33222 .57329 L .33074 .57416 L F
.33189 .57335 m .33074 .57416 L .33038 .57432 L F
.442 .394 .71 r
.33074 .57416 m .33078 .57424 L .33312 .57312 L F
.76 .536 .593 r
.33065 .57421 m .33078 .57424 L .33074 .57416 L F
.084 .626 .849 r
.33222 .57329 m .33312 .57312 L .32995 .57469 L F
.789 .856 .901 r
.33056 .57428 m .32875 .57536 L .33078 .57424 L F
.084 .626 .849 r
.33065 .57421 m .33056 .57428 L .3293 .57501 L F
.33056 .57428 m .32952 .5749 L .3293 .57501 L F
.33038 .57432 m .33074 .57416 L .3293 .57501 L F
.789 .856 .901 r
.32599 .57512 m .32875 .57536 L .33056 .57428 L F
.084 .626 .849 r
.33056 .57428 m .32995 .57469 L .32952 .5749 L F
.789 .856 .901 r
.33056 .57428 m .33078 .57424 L .33065 .57421 L F
.084 .626 .849 r
.33222 .57329 m .32995 .57469 L .33065 .57421 L F
.789 .856 .901 r
.32599 .57512 m .33056 .57428 L .32685 .5735 L F
.33056 .57428 m .33065 .57421 L .32685 .5735 L F
.442 .394 .71 r
.32836 .5693 m .33074 .57416 L .33312 .57312 L F
.76 .536 .593 r
.3294 .57398 m .33065 .57421 L .33001 .57267 L F
.33065 .57421 m .33074 .57416 L .33001 .57267 L F
.3294 .57398 m .33001 .57267 L .32836 .5693 L F
.431 .85 .694 r
.54046 .41848 m .54242 .41707 L .53959 .41858 L F
.54046 .41848 m .54415 .41635 L .54242 .41707 L F
.907 .929 .818 r
.59107 .37729 m .59222 .37302 L .59371 .37455 L F
.59107 .37729 m .58972 .37621 L .59222 .37302 L F
0 0 0 r
.27365 .51435 m .27621 .51368 L .2777 .51317 L F
.329 .809 .886 r
.2777 .51317 m .27784 .51239 L .28004 .51257 L F
.553 .918 .746 r
.2777 .51317 m .27621 .51368 L .27784 .51239 L F
0 .121 .651 r
.70791 .29893 m .70927 .30235 L .70842 .30413 L F
0 0 .236 r
.70952 .30332 m .70842 .30413 L .70899 .30294 L F
.606 .24 .322 r
.70853 .30735 m .70431 .30909 L .70866 .31108 L F
.736 .315 .249 r
.70463 .31173 m .70866 .31108 L .70431 .30909 L F
.606 .24 .322 r
.70853 .30735 m .70629 .31102 L .70431 .30909 L F
.873 .914 .513 r
.70952 .30332 m .70629 .31102 L .70853 .30735 L F
.761 .623 .707 r
.70615 .30394 m .70629 .31102 L .70952 .30332 L F
.503 .826 1 r
.70844 .30341 m .70996 .30364 L .70952 .30332 L F
.70996 .30364 m .71255 .30403 L .70952 .30332 L F
0 0 .236 r
.70952 .30332 m .70899 .30294 L .70927 .30235 L F
0 0 0 r
.7024 .29532 m .70561 .2933 L .70244 .29441 L F
.976 .728 .493 r
.39281 .49916 m .39411 .5011 L .39461 .49846 L F
.773 .94 .595 r
.39461 .49846 m .39694 .49497 L .39328 .49485 L F
.561 .921 .747 r
.39281 .49916 m .39427 .49537 L .39524 .49655 L F
.701 .223 .11 r
.39353 .49802 m .39358 .49803 L .39524 .49655 L F
.773 .94 .595 r
.39461 .49846 m .39524 .49655 L .39683 .49513 L F
.611 .697 .905 r
.39678 .50044 m .39524 .49655 L .39461 .49846 L F
0 .185 .707 r
.39461 .49846 m .39678 .50044 L .39524 .49655 L F
0 0 .568 r
.39524 .49655 m .39678 .50044 L .39763 .49664 L F
.611 .697 .905 r
.39678 .50044 m .39281 .49916 L .39524 .49655 L F
0 0 .568 r
.39524 .49655 m .39712 .49903 L .39678 .50044 L F
.701 .223 .11 r
.39358 .49803 m .39712 .49903 L .39524 .49655 L F
.773 .94 .595 r
.39683 .49513 m .39524 .49655 L .39694 .49497 L F
0 0 0 r
.47627 .58271 m .47694 .58011 L .47682 .57968 L F
.569 .454 .683 r
.33438 .64656 m .33696 .64306 L .33291 .64266 L F
.33438 .64656 m .33698 .6459 L .33696 .64306 L F
.392 0 0 r
.42681 .60052 m .42735 .60241 L .42498 .60179 L F
.42681 .60052 m .42953 .6004 L .42735 .60241 L F
.759 .335 .243 r
.38439 .52794 m .38254 .52964 L .38105 .52727 L F
.91 .575 .397 r
.38439 .52794 m .38498 .53069 L .38254 .52964 L F
.899 .506 .263 r
.34186 .51813 m .33961 .51723 L .33889 .51501 L F
.778 .429 .395 r
.34186 .51813 m .3389 .52017 L .33961 .51723 L F
.34186 .51813 m .34248 .5212 L .3389 .52017 L F
.47 .301 .57 r
.27785 .59435 m .28086 .59412 L .28094 .59009 L F
.562 .433 .662 r
.69858 .30538 m .70172 .3046 L .7003 .30068 L F
.613 .488 .685 r
.69858 .30538 m .70145 .3073 L .70172 .3046 L F
.69858 .30538 m .69856 .30787 L .70145 .3073 L F
.633 .243 .287 r
.37114 .49444 m .36913 .4923 L .36849 .49428 L F
.924 .61 .43 r
.37122 .5116 m .36907 .5107 L .36885 .50808 L F
.798 .426 .353 r
.37122 .5116 m .36884 .5134 L .36907 .5107 L F
.37122 .5116 m .37265 .51416 L .36884 .5134 L F
0 0 0 r
.43161 .60119 m .43308 .60062 L .4351 .60007 L F
.787 .749 .818 r
.29575 .64048 m .29788 .6384 L .29371 .63858 L F
.91 .777 .701 r
.4097 .54101 m .41111 .5443 L .41168 .54256 L F
.568 .395 .607 r
.41168 .54256 m .41111 .5443 L .41374 .54098 L F
.666 .314 .366 r
.33234 .59046 m .3278 .59268 L .32888 .59014 L F
.33234 .59046 m .33216 .59307 L .3278 .59268 L F
.598 .255 .36 r
.33468 .59263 m .33216 .59307 L .33234 .59046 L F
.33468 .59263 m .33216 .59307 L .33234 .59046 L F
.636 .7 .892 r
.48623 .43829 m .48774 .44164 L .49065 .43935 L F
.893 .613 .505 r
.35731 .52467 m .35739 .52725 L .35971 .528 L F
.929 .743 .63 r
.35699 .52982 m .35971 .528 L .35739 .52725 L F
.35699 .52982 m .35893 .53099 L .35971 .528 L F
.379 0 0 r
.39247 .45936 m .38821 .46111 L .38893 .45928 L F
.39247 .45936 m .39107 .46085 L .38821 .46111 L F
.72 .271 .184 r
.39247 .45936 m .39424 .46164 L .39107 .46085 L F
.755 .244 0 r
.39664 .46233 m .39424 .46164 L .39247 .45936 L F
.618 .675 .882 r
.31282 .64289 m .31703 .64415 L .31535 .64248 L F
.656 .646 .828 r
.31703 .64415 m .31945 .64301 L .31535 .64248 L F
0 0 0 r
.2582 .53985 m .25624 .54373 L .25719 .54152 L F
.262 .764 .73 r
.59734 .35227 m .59435 .35325 L .59769 .35231 L F
.608 .835 .986 r
.59769 .35231 m .59964 .34956 L .59883 .35026 L F
.59769 .35231 m .60068 .35104 L .59964 .34956 L F
.675 .896 .545 r
.59883 .35026 m .59734 .35227 L .59769 .35231 L F
.578 .031 0 r
.44938 .59164 m .45072 .5925 L .44816 .59034 L F
.44938 .59164 m .44816 .59034 L .44801 .58996 L F
.777 .356 .251 r
.44816 .59034 m .44845 .59035 L .44801 .58996 L F
.44845 .59035 m .45215 .59045 L .44801 .58996 L F
.412 0 0 r
.45215 .59045 m .45104 .59052 L .44801 .58996 L F
.62 .677 .882 r
.44813 .58943 m .45104 .59052 L .44909 .58564 L F
.669 .704 .874 r
.44906 .58557 m .45104 .59052 L .45319 .58713 L F
.44906 .58557 m .45205 .5867 L .45179 .5863 L F
.45205 .5867 m .45319 .58713 L .45179 .5863 L F
.62 .677 .882 r
.44904 .58563 m .44909 .58564 L .44906 .58557 L F
.44813 .58943 m .44909 .58564 L .44904 .58563 L F
.44801 .58996 m .45028 .59038 L .44813 .58943 L F
.45028 .59038 m .45104 .59052 L .44813 .58943 L F
.44801 .58996 m .44906 .58557 L .44963 .58875 L F
.535 .708 .951 r
.44906 .58557 m .45179 .5863 L .45047 .58336 L F
.81 .533 .519 r
.4463 .58696 m .44963 .58875 L .44906 .58557 L F
.982 .869 .647 r
.45179 .5863 m .44918 .58671 L .45025 .58392 L F
.45179 .5863 m .45025 .58392 L .45047 .58336 L F
.728 .472 .54 r
.45155 .58818 m .44963 .58875 L .45177 .58632 L F
.45179 .58633 m .45177 .58632 L .45179 .5863 L F
.45155 .58818 m .45177 .58632 L .45179 .58633 L F
.777 .356 .251 r
.44845 .59035 m .45072 .5925 L .45174 .59103 L F
.45032 .5904 m .45174 .59103 L .45215 .59045 L F
.44845 .59035 m .45174 .59103 L .45032 .5904 L F
.44816 .59034 m .44855 .59067 L .44845 .59035 L F
.44855 .59067 m .45072 .5925 L .44845 .59035 L F
.578 .031 0 r
.44942 .5912 m .44845 .59035 L .44963 .58875 L F
.44845 .59035 m .44801 .58996 L .44826 .58977 L F
.44845 .59035 m .44826 .58977 L .44963 .58875 L F
.44938 .59164 m .44801 .58996 L .44942 .5912 L F
.837 .966 .887 r
.45319 .58713 m .45215 .59045 L .454 .58887 L F
.45319 .58713 m .45104 .59052 L .45215 .59045 L F
.162 0 .073 r
.45072 .5925 m .454 .58887 L .45215 .59045 L F
.396 .265 .583 r
.6043 .3933 m .60629 .39437 L .60678 .39263 L F
.60678 .39263 m .60629 .39437 L .6043 .3933 L F
.77 .816 .89 r
.35421 .63249 m .35812 .63264 L .35716 .62981 L F
.75 .756 .857 r
.35812 .63264 m .35947 .62839 L .35716 .62981 L F
.35812 .63264 m .36113 .63008 L .35947 .62839 L F
.869 .97 .855 r
.26325 .52257 m .26346 .52571 L .26093 .52531 L F
.678 .948 .685 r
.51299 .49243 m .51015 .49526 L .51134 .49339 L F
.685 .978 .823 r
.51015 .49526 m .50797 .49584 L .51134 .49339 L F
0 0 0 r
.6563 .39389 m .65808 .38982 L .65767 .39239 L F
.042 0 .415 r
.65767 .39239 m .65652 .39419 L .6563 .39389 L F
.896 .869 .804 r
.47726 .53208 m .47339 .53385 L .47411 .53253 L F
.47726 .53208 m .47493 .5353 L .47339 .53385 L F
.831 .989 .867 r
.47903 .53012 m .47726 .53208 L .47784 .52944 L F
.829 .988 .87 r
.47726 .53208 m .47411 .53253 L .47784 .52944 L F
.694 .174 0 r
.4041 .51395 m .40637 .51598 L .40773 .51486 L F
.873 .438 .155 r
.40773 .51486 m .40637 .51598 L .40839 .51678 L F
.668 .76 .919 r
.59398 .42848 m .59804 .42914 L .59537 .43039 L F
.649 .663 .85 r
.30878 .65931 m .30661 .66198 L .30591 .65989 L F
0 0 0 r
.4471 .59812 m .44964 .59728 L .44781 .59823 L F
.45 .337 .634 r
.23344 .56112 m .23595 .56319 L .23555 .56041 L F
.328 .335 .715 r
.23434 .56392 m .23595 .56319 L .23344 .56112 L F
.843 .479 .364 r
.34428 .5859 m .34783 .58825 L .34817 .58752 L F
.12 0 0 r
.34817 .58752 m .34783 .58825 L .35102 .58648 L F
0 0 .546 r
.32596 .53046 m .3263 .53004 L .3242 .52672 L F
0 0 0 r
.32922 .52754 m .3263 .53004 L .32596 .53046 L F
.808 .866 .891 r
.59589 .37226 m .59371 .37455 L .59222 .37302 L F
.789 .998 .853 r
.51593 .39411 m .51683 .39207 L .51766 .39216 L F
.51593 .39411 m .51379 .39451 L .51683 .39207 L F
0 .187 .706 r
.24665 .56904 m .24601 .57087 L .24436 .56695 L F
.672 .904 .566 r
.32641 .51971 m .32433 .52147 L .32375 .519 L F
.856 .61 .566 r
.32731 .5213 m .32309 .52337 L .32641 .51971 L F
.822 .985 .88 r
.32641 .51971 m .32375 .519 L .32679 .51579 L F
.385 .344 .689 r
.2357 .55758 m .23724 .55323 L .23572 .55374 L F
.856 .677 .66 r
.67612 .33082 m .67222 .33273 L .67197 .33055 L F
.67612 .33082 m .67551 .33341 L .67222 .33273 L F
.088 0 .318 r
.43284 .45849 m .43326 .45571 L .43454 .45479 L F
.945 .629 .405 r
.35893 .53099 m .35924 .53369 L .36118 .53439 L F
.982 .702 .405 r
.35956 .53639 m .36118 .53439 L .35924 .53369 L F
.35956 .53639 m .36075 .53867 L .36118 .53439 L F
.978 .677 .34 r
.39853 .56066 m .39741 .56267 L .39665 .55955 L F
.39853 .56066 m .39887 .56359 L .39741 .56267 L F
.667 .627 .8 r
.29439 .65457 m .29487 .65761 L .29146 .65568 L F
.513 .516 .796 r
.29686 .65434 m .29487 .65761 L .29439 .65457 L F
.599 .628 .852 r
.29686 .65434 m .29833 .657 L .29487 .65761 L F
.525 .117 .21 r
.53689 .41263 m .53877 .41431 L .53956 .41191 L F
.53689 .41263 m .53577 .41468 L .53877 .41431 L F
.405 0 0 r
.4204 .4513 m .42305 .45135 L .4248 .44965 L F
.14 0 0 r
.42585 .45049 m .4248 .44965 L .42305 .45135 L F
.42585 .45049 m .42736 .44918 L .4248 .44965 L F
0 .18 .703 r
.40839 .51678 m .41198 .52063 L .41122 .51856 L F
.376 .505 .861 r
.6058 .36368 m .60526 .36695 L .6047 .36367 L F
.905 .979 .791 r
.6058 .36368 m .60341 .36718 L .60526 .36695 L F
.737 .744 .858 r
.31147 .64001 m .31282 .64289 L .31449 .64071 L F
.662 .629 .806 r
.31449 .64071 m .31282 .64289 L .31535 .64248 L F
.613 .954 .819 r
.45379 .43691 m .45643 .43625 L .45247 .43854 L F
.529 .918 .807 r
.45825 .43491 m .45643 .43625 L .45379 .43691 L F
.895 .59 .463 r
.36665 .54706 m .36672 .54964 L .3703 .55024 L F
.938 .754 .627 r
.3665 .55256 m .3703 .55024 L .36672 .54964 L F
.3665 .55256 m .36879 .55344 L .3703 .55024 L F
.33 .812 .872 r
.26325 .52257 m .26778 .5223 L .26532 .52075 L F
.942 .752 .283 r
.56125 .42654 m .56148 .42439 L .5613 .42687 L F
0 0 .339 r
.5617 .42232 m .56088 .42688 L .56148 .42439 L F
.942 .752 .283 r
.56067 .42272 m .56148 .42439 L .56125 .42649 L F
.56067 .42272 m .56125 .42649 L .56124 .42649 L F
.56067 .42272 m .56124 .42649 L .56097 .42643 L F
.56124 .42649 m .5613 .42687 L .56097 .42643 L F
.8 .938 .578 r
.56091 .42642 m .56097 .42643 L .56086 .42658 L F
0 0 .387 r
.56067 .42272 m .56097 .42643 L .56172 .42391 L F
.8 .938 .578 r
.56172 .42391 m .56097 .42643 L .56091 .42642 L F
.56031 .42671 m .56086 .42658 L .55916 .42901 L F
.56172 .42391 m .56086 .42658 L .56031 .42671 L F
.942 .752 .283 r
.56124 .42649 m .56125 .42649 L .56125 .42654 L F
0 0 .339 r
.5618 .42178 m .5617 .42232 L .56148 .42439 L F
.596 .423 .618 r
.69856 .30787 m .69879 .31061 L .70145 .3073 L F
.944 .909 .755 r
.31237 .63209 m .314 .63297 L .31069 .63616 L F
.829 .884 .883 r
.31492 .62896 m .314 .63297 L .31237 .63209 L F
.31492 .62896 m .31689 .63009 L .314 .63297 L F
.707 .446 0 r
.59303 .42444 m .5935 .42631 L .59398 .42848 L F
.803 .947 .917 r
.54342 .47499 m .53886 .47674 L .54179 .47358 L F
.478 .459 .758 r
.54518 .47147 m .54342 .47499 L .54179 .47358 L F
.54518 .47147 m .54597 .47507 L .54342 .47499 L F
.824 .975 .673 r
.71299 .31429 m .71359 .31437 L .71433 .31285 L F
.781 .907 .928 r
.71299 .31429 m .71654 .31346 L .71359 .31437 L F
.822 .994 .751 r
.49038 .41158 m .48905 .41354 L .4899 .41112 L F
.803 .995 .865 r
.4899 .41112 m .48905 .41354 L .48678 .41393 L F
.062 .284 .773 r
.34102 .55698 m .3428 .56119 L .34341 .55892 L F
.998 .785 .452 r
.34408 .56246 m .34341 .55892 L .3428 .56119 L F
0 .119 .666 r
.53378 .455 m .535 .45797 L .53399 .45441 L F
.657 .711 .887 r
.53399 .45441 m .535 .45797 L .53806 .45471 L F
.479 .278 .528 r
.53682 .38325 m .53946 .38512 L .53589 .38403 L F
.479 .279 .53 r
.53946 .38512 m .53684 .3885 L .53589 .38403 L F
.491 .612 .9 r
.31453 .66593 m .31031 .66306 L .31283 .66234 L F
.506 .571 .856 r
.31704 .66554 m .31453 .66593 L .31283 .66234 L F
.851 .631 .604 r
.3714 .55702 m .36976 .56001 L .37359 .5608 L F
.871 .658 .612 r
.3696 .56266 m .37359 .5608 L .36976 .56001 L F
.3696 .56266 m .37329 .5638 L .37359 .5608 L F
.883 .485 .269 r
.39664 .46233 m .39475 .46355 L .39424 .46164 L F
.351 0 0 r
.39664 .46233 m .399 .46307 L .39475 .46355 L F
.366 0 .065 r
.39936 .4619 m .399 .46307 L .39664 .46233 L F
.881 .789 .755 r
.28623 .66545 m .28785 .66902 L .28576 .66868 L F
.874 .542 .419 r
.28576 .66868 m .28785 .66902 L .28576 .67123 L F
.867 .531 .413 r
.28576 .67123 m .28785 .66902 L .28763 .67091 L F
.682 .965 .934 r
.28647 .66668 m .28596 .66994 L .2886 .67113 L F
.28596 .66994 m .28576 .67123 L .28763 .67117 L F
.28596 .66994 m .28763 .67117 L .2886 .67113 L F
.345 .751 .982 r
.28599 .67021 m .2886 .67113 L .28604 .66999 L F
.28576 .67123 m .28763 .67117 L .28599 .67021 L F
.28763 .67117 m .2886 .67113 L .28599 .67021 L F
.758 .614 .047 r
.29 .67239 m .28995 .67251 L .28763 .67091 L F
.28995 .67251 m .28983 .67277 L .28859 .67172 L F
.28995 .67251 m .28859 .67172 L .28763 .67091 L F
.28983 .67277 m .28982 .67278 L .28971 .67269 L F
.28983 .67277 m .28971 .67269 L .28763 .67091 L F
.29 .67239 m .28999 .67511 L .28982 .67278 L F
.633 .408 .558 r
.30928 .67584 m .30651 .6788 L .30664 .67589 L F
.30928 .67584 m .30923 .67883 L .30651 .6788 L F
.551 .341 .549 r
.31204 .67772 m .30928 .67584 L .31258 .67531 L F
.31204 .67772 m .30923 .67883 L .30928 .67584 L F
.596 .944 .79 r
.68101 .37492 m .68263 .37451 L .68483 .37285 L F
.705 .97 .93 r
.46043 .44732 m .46495 .44575 L .46384 .4454 L F
.649 .955 .941 r
.46607 .44388 m .46495 .44575 L .4673 .44436 L F
.666 .969 .911 r
.46384 .4454 m .46495 .44575 L .46607 .44388 L F
0 0 .508 r
.56566 .37257 m .56721 .37522 L .56661 .37645 L F
0 .284 .786 r
.56721 .37522 m .56947 .37862 L .56661 .37645 L F
.618 .698 .901 r
.44624 .45402 m .44754 .45052 L .44615 .45146 L F
.44624 .45402 m .44769 .45347 L .44754 .45052 L F
.476 .273 .525 r
.44621 .45535 m .44769 .45347 L .44624 .45402 L F
.676 .648 .815 r
.44624 .45402 m .44615 .45146 L .44211 .45208 L F
.417 .077 .279 r
.52407 .44105 m .52167 .43947 L .52134 .44155 L F
.52407 .44105 m .52456 .43892 L .52167 .43947 L F
.374 0 .11 r
.24368 .53165 m .24365 .533 L .24625 .5324 L F
.982 .705 .415 r
.51299 .49243 m .51134 .49339 L .51125 .49062 L F
.787 .974 .687 r
.51299 .49243 m .51396 .49006 L .51536 .49119 L F
.51299 .49243 m .51134 .49339 L .51396 .49006 L F
.951 .943 .625 r
.59456 .41497 m .59628 .41352 L .59477 .41179 L F
.59456 .41497 m .59516 .41593 L .59628 .41352 L F
.961 .921 .719 r
.55628 .45839 m .5533 .46144 L .55593 .45804 L F
.55628 .45839 m .55444 .46212 L .5533 .46144 L F
.774 .993 .777 r
.55721 .4562 m .55628 .45839 L .55593 .45804 L F
.55721 .4562 m .55924 .45535 L .55628 .45839 L F
.504 .422 .696 r
.2915 .63909 m .29371 .63858 L .29348 .63603 L F
.863 .679 .651 r
.37654 .57655 m .37626 .57943 L .38036 .57943 L F
.874 .668 .621 r
.37605 .5822 m .38036 .57943 L .37626 .57943 L F
.37605 .5822 m .37816 .58313 L .38036 .57943 L F
.663 .808 .953 r
.50636 .42859 m .5094 .43014 L .51179 .42852 L F
.401 .806 .59 r
.51179 .42852 m .5094 .43014 L .50793 .43113 L F
.671 .948 .957 r
.54755 .48139 m .54297 .48259 L .54554 .48303 L F
.755 .95 .63 r
.26917 .52054 m .27096 .51766 L .27204 .52086 L F
.68 .466 .589 r
.27204 .52086 m .268 .52277 L .26917 .52054 L F
.503 .901 .932 r
.54862 .43518 m .54826 .43586 L .55121 .43478 L F
.54862 .43518 m .54826 .43586 L .55121 .43478 L F
.647 .581 .767 r
.35319 .54636 m .34943 .54432 L .35224 .5435 L F
.42 .866 .83 r
.65193 .3379 m .65089 .33881 L .65337 .33736 L F
.65193 .3379 m .64939 .339 L .65089 .33881 L F
.827 .826 .349 r
.23882 .59747 m .23821 .60001 L .23826 .59811 L F
.103 0 0 r
.24351 .59997 m .24224 .60128 L .2402 .60179 L F
.538 .066 .083 r
.24224 .60128 m .24195 .60132 L .2402 .60179 L F
.952 .702 .523 r
.2402 .60179 m .23821 .60001 L .23792 .6024 L F
.2402 .60179 m .2397 .60085 L .23821 .60001 L F
.2397 .60085 m .23826 .59811 L .23822 .59957 L F
.2397 .60085 m .23822 .59957 L .23821 .60001 L F
.377 .135 .415 r
.2402 .60179 m .23788 .60276 L .23821 .60001 L F
.952 .702 .523 r
.2402 .60179 m .23835 .60192 L .23826 .59811 L F
.538 .066 .083 r
.24195 .60132 m .23835 .60192 L .2402 .60179 L F
.952 .702 .523 r
.2402 .60179 m .23792 .6024 L .23788 .60276 L F
.538 .066 .083 r
.24053 .60156 m .24063 .60332 L .23835 .60192 L F
.24224 .60128 m .24142 .60232 L .24053 .60156 L F
.24142 .60232 m .24063 .60332 L .24053 .60156 L F
.684 .979 .831 r
.61777 .40939 m .61915 .40734 L .62115 .40689 L F
.019 0 .437 r
.61767 .41237 m .61915 .40734 L .61777 .40939 L F
.865 .969 .648 r
.5188 .41511 m .52028 .4137 L .52092 .41118 L F
.637 .764 .94 r
.26228 .60542 m .26435 .6075 L .26594 .60601 L F
.8 .77 .826 r
.60625 .405 m .60746 .40705 L .6097 .4049 L F
.981 .913 .633 r
.33091 .53483 m .3302 .53505 L .33254 .53409 L F
.785 .883 .461 r
.33254 .53409 m .3342 .52967 L .33171 .53065 L F
.33254 .53409 m .33291 .532 L .3342 .52967 L F
.778 .984 .729 r
.33254 .53409 m .3302 .53505 L .33291 .532 L F
.51 .896 .729 r
.46215 .43271 m .45825 .43491 L .46098 .43241 L F
.652 .954 .74 r
.46516 .43017 m .46215 .43271 L .46336 .43098 L F
.626 .954 .927 r
.46336 .43098 m .46215 .43271 L .46098 .43241 L F
.338 .428 .807 r
.58336 .43921 m .58536 .43726 L .58213 .43795 L F
0 .101 .594 r
.58414 .43987 m .58336 .43921 L .58213 .43795 L F
.87 .502 .347 r
.34478 .51024 m .34842 .51387 L .34675 .51091 L F
.51 .705 .958 r
.60331 .4053 m .60431 .40236 L .60135 .40335 L F
.60331 .4053 m .60625 .405 L .60431 .40236 L F
.64 .868 .984 r
.6498 .38595 m .64736 .38709 L .6458 .38588 L F
.72 .989 .854 r
.63626 .4018 m .63748 .3996 L .63535 .40124 L F
.63626 .4018 m .63938 .39929 L .63748 .3996 L F
.067 0 .455 r
.70796 .29062 m .70675 .29454 L .70561 .2933 L F
.70796 .29062 m .70847 .29269 L .70675 .29454 L F
0 0 .45 r
.70847 .29269 m .70776 .29691 L .70675 .29454 L F
.03 .25 .751 r
.45421 .56243 m .45329 .56407 L .45144 .56301 L F
.892 .973 .825 r
.50981 .51336 m .51106 .51227 L .50861 .51278 L F
.834 .997 .77 r
.51106 .51227 m .51226 .51029 L .51166 .51003 L F
.807 .994 .867 r
.50861 .51278 m .51106 .51227 L .51166 .51003 L F
.617 .876 .99 r
.31969 .61142 m .32281 .61282 L .31888 .61264 L F
.828 .702 .726 r
.31888 .61264 m .32281 .61282 L .32069 .6164 L F
.291 .728 .966 r
.32562 .61266 m .32281 .61282 L .31969 .61142 L F
.482 .839 .579 r
.50038 .40579 m .50198 .40437 L .50353 .40318 L F
.518 .915 .831 r
.50038 .40579 m .49962 .40571 L .50198 .40437 L F
.774 .787 .863 r
.29371 .63858 m .29788 .6384 L .29609 .63557 L F
.702 .512 .628 r
.30664 .67589 m .30651 .6788 L .30387 .67844 L F
.22 .25 .681 r
.23434 .56392 m .23659 .56554 L .23595 .56319 L F
.431 .355 .67 r
.69954 .29815 m .70259 .29983 L .7024 .29532 L F
.38 .373 .726 r
.7003 .30068 m .70259 .29983 L .69954 .29815 L F
0 .5 .789 r
.59956 .34319 m .60216 .34377 L .60353 .34431 L F
.168 .689 .881 r
.60216 .34377 m .6062 .34416 L .60353 .34431 L F
.037 .606 .755 r
.33541 .51373 m .33072 .51362 L .33274 .51374 L F
.385 .344 .689 r
.2357 .55758 m .23752 .55708 L .23724 .55323 L F
.332 .158 .489 r
.23555 .56041 m .23752 .55708 L .2357 .55758 L F
.107 0 0 r
.33051 .56767 m .32739 .56998 L .32836 .5693 L F
.607 .304 .43 r
.32836 .5693 m .33337 .57045 L .33051 .56767 L F
.426 .232 .512 r
.33312 .57312 m .33414 .57132 L .33337 .57045 L F
.702 .163 0 r
.3315 .56834 m .33337 .57045 L .33485 .57059 L F
.689 .972 .921 r
.33485 .57059 m .33337 .57045 L .33549 .56894 L F
.426 .232 .512 r
.33414 .57132 m .33549 .56894 L .33337 .57045 L F
.702 .163 0 r
.33051 .56767 m .33337 .57045 L .3315 .56834 L F
.225 0 0 r
.33483 .58987 m .33754 .59038 L .33904 .59036 L F
.676 .975 .893 r
.33904 .59036 m .33981 .5887 L .34052 .58654 L F
.33904 .59036 m .33754 .59038 L .33981 .5887 L F
.488 .844 .993 r
.60723 .39724 m .60511 .39869 L .6042 .39752 L F
.60723 .39724 m .60862 .39806 L .60511 .39869 L F
.975 .922 .625 r
.69692 .33636 m .697 .33327 L .69575 .33504 L F
.949 .786 .645 r
.69426 .33905 m .69692 .33636 L .69575 .33504 L F
.69426 .33905 m .69598 .34051 L .69692 .33636 L F
.933 .776 .664 r
.34658 .57573 m .34776 .57559 L .34623 .57589 L F
.987 .72 .423 r
.34814 .5735 m .3491 .57544 L .34776 .57559 L F
.21 .412 .842 r
.35165 .57575 m .34998 .57721 L .34814 .5735 L F
.987 .72 .423 r
.3491 .57544 m .34998 .57721 L .34776 .57559 L F
.639 .325 .424 r
.34776 .57559 m .35165 .57575 L .34814 .5735 L F
.933 .776 .664 r
.34888 .57474 m .34776 .57559 L .34658 .57573 L F
.948 .609 .342 r
.34913 .51594 m .35064 .5145 L .34842 .51387 L F
.34913 .51594 m .35101 .51711 L .35064 .5145 L F
.897 .878 .808 r
.37241 .61365 m .37471 .61049 L .37283 .60921 L F
.84 .4 .179 r
.6812 .30763 m .68215 .30984 L .68507 .31095 L F
.898 .662 .573 r
.68215 .30984 m .6851 .31359 L .68507 .31095 L F
.99 .769 .507 r
.57603 .3977 m .57801 .39655 L .57721 .39548 L F
.57603 .3977 m .57755 .39913 L .57801 .39655 L F
.336 .304 .674 r
.7003 .30068 m .70326 .30229 L .70259 .29983 L F
.7003 .30068 m .70172 .3046 L .70326 .30229 L F
.805 .743 .795 r
.41374 .54098 m .41111 .5443 L .4097 .54101 L F
.736 .96 .674 r
.34388 .54556 m .34303 .54537 L .34366 .54219 L F
.745 .295 .183 r
.39694 .49497 m .39763 .49664 L .39952 .49442 L F
.39694 .49497 m .39524 .49655 L .39763 .49664 L F
.737 .338 0 r
.39763 .49664 m .39694 .49497 L .39952 .49442 L F
.858 .635 .599 r
.42762 .55735 m .4264 .56015 L .42992 .56079 L F
.906 .637 .519 r
.42757 .56263 m .42992 .56079 L .4264 .56015 L F
.799 .546 .555 r
.64115 .34366 m .63743 .34592 L .63721 .34429 L F
.64115 .34366 m .64143 .34655 L .63743 .34592 L F
0 0 .424 r
.64289 .34442 m .64115 .34366 L .64371 .3426 L F
0 0 0 r
.64505 .3428 m .64289 .34442 L .64371 .3426 L F
.467 .855 .648 r
.64468 .343 m .64429 .34326 L .64289 .34442 L F
0 0 .424 r
.64289 .34442 m .64134 .3457 L .64115 .34366 L F
.467 .855 .648 r
.64429 .34326 m .64138 .34526 L .64289 .34442 L F
0 0 .424 r
.64289 .34442 m .64143 .34655 L .64134 .3457 L F
.632 .917 .979 r
.51028 .43528 m .51119 .43333 L .51004 .43492 L F
.51028 .43528 m .51314 .43396 L .51119 .43333 L F
.738 .805 .905 r
.4673 .44436 m .47188 .44388 L .47062 .44285 L F
.71 .893 .963 r
.47188 .44388 m .47308 .44146 L .47062 .44285 L F
.47188 .44388 m .47437 .44257 L .47308 .44146 L F
.671 .785 .935 r
.47493 .5353 m .47029 .53503 L .47339 .53385 L F
0 .115 .651 r
.24097 .59192 m .24249 .59342 L .24225 .58954 L F
.909 .8 .728 r
.37908 .59252 m .37964 .59444 L .3806 .59359 L F
.385 0 0 r
.3884 .4574 m .39331 .45722 L .39516 .45541 L F
.683 .339 .386 r
.39331 .45722 m .39772 .45509 L .39516 .45541 L F
.711 .839 .943 r
.34894 .63905 m .35254 .63899 L .35043 .6384 L F
.891 .871 .812 r
.35254 .63899 m .35224 .6361 L .35043 .6384 L F
.808 .351 0 r
.67045 .35676 m .67008 .3577 L .66867 .35671 L F
.67045 .35676 m .67162 .35901 L .67008 .3577 L F
.671 .815 .953 r
.63057 .3446 m .63494 .34508 L .63332 .34399 L F
.038 .45 .876 r
.63494 .34508 m .63541 .34414 L .63332 .34399 L F
.47 .089 .234 r
.63721 .34429 m .63743 .34592 L .63494 .34508 L F
.038 .45 .876 r
.63494 .34508 m .63743 .34592 L .63541 .34414 L F
.754 .756 .854 r
.44239 .56607 m .44391 .56748 L .4397 .56709 L F
.852 .967 .874 r
.44459 .56477 m .44391 .56748 L .44239 .56607 L F
0 0 0 r
.52113 .48212 m .52017 .48416 L .52144 .4821 L F
.966 .781 .343 r
.60098 .42591 m .60219 .42541 L .60122 .4248 L F
.60098 .42591 m .60175 .42893 L .60219 .42541 L F
.729 .278 .181 r
.23832 .56871 m .24136 .56779 L .24166 .57027 L F
.62 .453 .635 r
.24436 .56695 m .24136 .56779 L .24439 .56416 L F
.614 .435 .617 r
.24436 .56695 m .24166 .57027 L .24136 .56779 L F
.62 .453 .635 r
.24436 .56695 m .24136 .56779 L .24439 .56416 L F
.823 .54 0 r
.57447 .36934 m .57559 .37348 L .57493 .37181 L F
.704 .308 0 r
.57695 .37552 m .57493 .37181 L .57559 .37348 L F
.686 .949 .683 r
.35189 .5551 m .3514 .55462 L .35476 .5543 L F
.35189 .5551 m .35031 .55613 L .3514 .55462 L F
.707 .328 0 r
.3514 .55462 m .35189 .5551 L .35104 .55351 L F
.8 .77 .826 r
.60625 .405 m .6097 .4049 L .61033 .40394 L F
.856 .61 .566 r
.32731 .5213 m .3272 .52494 L .32309 .52337 L F
.418 .244 .536 r
.32947 .52457 m .3272 .52494 L .32731 .5213 L F
.766 .572 .635 r
.28877 .65608 m .28449 .65875 L .28711 .65517 L F
.28877 .65608 m .28884 .65919 L .28449 .65875 L F
.682 .795 .934 r
.28974 .65388 m .28877 .65608 L .28711 .65517 L F
.28974 .65388 m .29146 .65568 L .28877 .65608 L F
.784 .646 .71 r
.29146 .65568 m .28884 .65919 L .28877 .65608 L F
.189 0 0 r
.51683 .39207 m .52045 .38928 L .51766 .39216 L F
.782 .515 .532 r
.30975 .58055 m .30482 .58258 L .3077 .57894 L F
.30975 .58055 m .30915 .58312 L .30482 .58258 L F
0 0 0 r
.30976 .5814 m .30915 .58312 L .30975 .58055 L F
.30976 .5814 m .30975 .58055 L .3077 .57894 L F
.824 .589 .583 r
.34155 .55395 m .34102 .55698 L .34518 .55706 L F
.677 .211 .139 r
.34102 .55698 m .34341 .55892 L .34518 .55706 L F
0 0 .381 r
.34518 .55706 m .34661 .55507 L .3465 .54978 L F
.603 .863 .519 r
.34518 .55706 m .34341 .55892 L .34661 .55507 L F
.786 .406 .338 r
.72053 .30225 m .72466 .30338 L .724 .30128 L F
.274 .338 .747 r
.58497 .36117 m .58325 .36509 L .58216 .35943 L F
.939 .955 .645 r
.58497 .36117 m .58377 .36591 L .58325 .36509 L F
.905 .718 .639 r
.60303 .4326 m .60409 .4291 L .60175 .42893 L F
0 0 .211 r
.42171 .56445 m .42121 .56379 L .42052 .56283 L F
.504 .305 .543 r
.42121 .56379 m .42124 .56701 L .42352 .56587 L F
0 0 .211 r
.42171 .56445 m .42124 .56701 L .42121 .56379 L F
.504 .283 .512 r
.42121 .56379 m .42465 .56342 L .42476 .56061 L F
.504 .305 .543 r
.42121 .56379 m .42352 .56587 L .42465 .56342 L F
.806 .437 0 r
.42059 .53248 m .4209 .53196 L .41828 .52946 L F
.42059 .53248 m .42146 .53373 L .4209 .53196 L F
.624 .457 .635 r
.24708 .56366 m .24436 .56695 L .24439 .56416 L F
.581 .579 .816 r
.55902 .40596 m .5633 .40822 L .56168 .40525 L F
.709 .805 .338 r
.59 .36284 m .5919 .35806 L .59305 .35954 L F
.59 .36284 m .59027 .3619 L .59044 .36173 L F
.341 .178 .509 r
.58958 .36418 m .59027 .3619 L .59 .36284 L F
.58958 .36418 m .59177 .36363 L .59027 .3619 L F
.628 .102 0 r
.59027 .3619 m .59177 .36363 L .59005 .36211 L F
.59027 .3619 m .59005 .36211 L .58906 .36124 L F
.709 .805 .338 r
.59044 .36173 m .59027 .3619 L .5919 .35806 L F
.967 .823 .648 r
.39732 .55451 m .3948 .55601 L .39521 .55323 L F
.39732 .55451 m .39648 .5571 L .3948 .55601 L F
.185 0 0 r
.53307 .38593 m .53571 .3851 L .53682 .38325 L F
.617 .17 .167 r
.53682 .38325 m .53571 .3851 L .53946 .38512 L F
.652 .607 .791 r
.53341 .48081 m .53015 .47843 L .53241 .47772 L F
.716 .958 .946 r
.53546 .47812 m .53341 .48081 L .53241 .47772 L F
.53546 .47812 m .53698 .47862 L .53341 .48081 L F
.723 .746 .871 r
.30492 .65646 m .30231 .65903 L .30049 .65585 L F
.62 .564 .77 r
.30492 .65646 m .30591 .65989 L .30231 .65903 L F
.251 .047 .396 r
.43283 .56982 m .43077 .57322 L .43104 .57067 L F
.459 0 0 r
.39772 .45509 m .39993 .45619 L .40215 .45481 L F
.237 0 0 r
.40251 .4558 m .40215 .45481 L .39993 .45619 L F
.40251 .4558 m .40434 .45496 L .40215 .45481 L F
.868 .975 .668 r
.65808 .38982 m .6601 .38526 L .65955 .38772 L F
0 0 .102 r
.65767 .39239 m .65808 .38982 L .65955 .38772 L F
.65767 .39239 m .65955 .38772 L .65906 .39034 L F
.973 .847 .445 r
.65836 .38897 m .65931 .38878 L .65955 .38772 L F
.65899 .39021 m .65906 .39034 L .65955 .38772 L F
.65836 .38897 m .65955 .38772 L .65554 .38709 L F
.763 .716 .808 r
.65554 .38709 m .65955 .38772 L .65861 .38406 L F
.533 .846 .542 r
.65554 .38709 m .65861 .38406 L .65682 .38568 L F
.083 .324 .801 r
.65682 .38568 m .65836 .38897 L .65554 .38709 L F
.868 .975 .668 r
.6601 .38526 m .66014 .38518 L .65955 .38772 L F
.987 .807 .574 r
.65955 .38772 m .66014 .38518 L .65861 .38406 L F
.563 .656 .898 r
.65944 .38506 m .65836 .38897 L .65682 .38568 L F
.48 .267 .512 r
.6623 .38698 m .66014 .38518 L .65955 .38772 L F
.563 .656 .898 r
.65944 .38506 m .66111 .38848 L .65836 .38897 L F
.371 .813 .954 r
.65836 .38897 m .66012 .38791 L .65739 .38916 L F
.65836 .38897 m .65739 .38916 L .65683 .38943 L F
.973 .847 .445 r
.65836 .38897 m .65899 .39021 L .65931 .38878 L F
.999 .802 .472 r
.69607 .36273 m .69539 .35945 L .6958 .36217 L F
.954 .952 .689 r
.69341 .3659 m .69607 .36273 L .6958 .36217 L F
.69341 .3659 m .69421 .36687 L .69607 .36273 L F
.863 .418 .033 r
.26221 .6009 m .26385 .60384 L .26362 .60367 L F
.722 .984 .792 r
.54552 .41411 m .54415 .41635 L .54588 .41472 L F
.714 .966 .713 r
.54242 .41707 m .54415 .41635 L .54552 .41411 L F
.68 .846 .962 r
.29147 .65321 m .29146 .65568 L .28974 .65388 L F
.29147 .65321 m .29439 .65457 L .29146 .65568 L F
0 0 0 r
.50779 .43906 m .51004 .43492 L .50981 .43715 L F
0 0 .3 r
.50744 .44125 m .50779 .43906 L .50981 .43715 L F
.778 .699 .776 r
.36339 .49833 m .35923 .49788 L .36197 .49452 L F
0 .204 .678 r
.57704 .42398 m .57605 .4237 L .57473 .42218 L F
.57704 .42398 m .57835 .42528 L .57605 .4237 L F
.362 .099 .374 r
.28117 .51731 m .27832 .52009 L .27865 .51797 L F
.393 .844 .916 r
.26917 .61693 m .27185 .61618 L .27064 .61588 L F
.453 .862 .7 r
.46743 .42875 m .46516 .43017 L .46336 .43098 L F
.697 .768 .906 r
.47691 .44153 m .48055 .44234 L .47924 .44172 L F
.792 .657 .714 r
.4784 .44477 m .48055 .44234 L .47691 .44153 L F
.736 .761 .873 r
.47924 .44172 m .48055 .44234 L .48376 .4395 L F
0 0 0 r
.43259 .44765 m .43327 .44721 L .43096 .44818 L F
.221 .739 .733 r
.43259 .44765 m .43096 .44818 L .42987 .44838 L F
.868 .654 .612 r
.36753 .5594 m .3714 .55702 L .3685 .55663 L F
.36753 .5594 m .36976 .56001 L .3714 .55702 L F
.213 .014 .379 r
.32144 .57427 m .31907 .57841 L .32214 .57704 L F
.564 .444 .675 r
.31831 .5792 m .32214 .57704 L .31907 .57841 L F
.495 .31 .559 r
.29792 .54698 m .29532 .55032 L .29535 .54756 L F
.584 .584 .819 r
.32365 .64589 m .32501 .64191 L .32208 .64224 L F
.32365 .64589 m .32574 .6455 L .32501 .64191 L F
.33 .812 .872 r
.26336 .52256 m .26568 .52193 L .26778 .5223 L F
.43 .87 .887 r
.26778 .5223 m .26568 .52193 L .26809 .52103 L F
0 0 0 r
.26387 .52483 m .26769 .52139 L .26568 .52193 L F
.26769 .52139 m .26809 .52103 L .26568 .52193 L F
.33 .812 .872 r
.26325 .52257 m .26568 .52193 L .26336 .52256 L F
.778 .966 .664 r
.27096 .51766 m .26778 .5223 L .26893 .51941 L F
.337 0 .13 r
.26643 .52337 m .26708 .52289 L .26809 .52103 L F
.43 .87 .887 r
.26778 .5223 m .26809 .52103 L .26885 .51962 L F
.337 0 .13 r
.26708 .52289 m .27047 .52037 L .26809 .52103 L F
.43 .87 .887 r
.26885 .51962 m .26809 .52103 L .26893 .51941 L F
.189 0 0 r
.51683 .39207 m .51939 .39132 L .52045 .38928 L F
.417 .34 .663 r
.52045 .38928 m .52533 .38902 L .52253 .38444 L F
.476 .117 .277 r
.51939 .39132 m .52533 .38902 L .52045 .38928 L F
.486 .886 .736 r
.51509 .42732 m .51804 .42569 L .51596 .42626 L F
.538 .178 .306 r
.24241 .58458 m .24372 .58612 L .24457 .5841 L F
.045 .099 .595 r
.24241 .58458 m .2429 .58718 L .24372 .58612 L F
.504 .642 .917 r
.49065 .43935 m .49483 .43919 L .49297 .43787 L F
.49065 .43935 m .49443 .442 L .49483 .43919 L F
.726 .911 .958 r
.49483 .43919 m .49545 .43684 L .49297 .43787 L F
.49483 .43919 m .49734 .43794 L .49545 .43684 L F
.391 .051 .265 r
.4963 .44076 m .49483 .43919 L .49443 .442 L F
.4963 .44076 m .49734 .43794 L .49483 .43919 L F
.722 .638 .764 r
.35463 .54391 m .35319 .54636 L .35224 .5435 L F
.544 .262 .438 r
.67835 .30959 m .68215 .30984 L .6812 .30763 L F
.545 .401 .637 r
.39016 .48423 m .39399 .48634 L .39294 .48399 L F
.419 .161 .413 r
.41212 .53984 m .41233 .53733 L .41374 .54098 L F
.654 .969 .895 r
.41373 .47312 m .4164 .47293 L .4127 .47484 L F
.382 0 .165 r
.4164 .47293 m .41545 .47469 L .4127 .47484 L F
.974 .718 .483 r
.4164 .47293 m .41545 .47469 L .41373 .47312 L F
0 .446 .825 r
.71483 .32128 m .71673 .32141 L .71382 .31989 L F
.71483 .32128 m .71784 .32231 L .71673 .32141 L F
0 .397 .737 r
.71852 .32269 m .71784 .32231 L .71483 .32128 L F
.857 .493 0 r
.23659 .56554 m .23832 .56871 L .23778 .56555 L F
0 .162 .701 r
.23832 .56871 m .2399 .56754 L .23778 .56555 L F
.21 .183 .608 r
.23899 .56979 m .2399 .56754 L .23832 .56871 L F
.579 .944 .865 r
.69005 .36847 m .69421 .36687 L .69341 .3659 L F
.072 .626 .818 r
.6062 .34416 m .60916 .34411 L .61031 .34455 L F
.062 0 0 r
.60916 .34411 m .61323 .34422 L .61031 .34455 L F
.411 .818 .978 r
.71852 .32269 m .72044 .32162 L .71784 .32231 L F
.71852 .32269 m .72065 .32244 L .72044 .32162 L F
.901 .639 .532 r
.34625 .52673 m .34393 .52309 L .34454 .52502 L F
.946 .64 .428 r
.35462 .5232 m .35739 .52725 L .35731 .52467 L F
.611 .863 .991 r
.63938 .39929 m .64336 .39897 L .64212 .39879 L F
.404 .337 .668 r
.26268 .52936 m .2602 .52769 L .26241 .52694 L F
.26268 .52936 m .26127 .53194 L .2602 .52769 L F
.229 0 .089 r
.41158 .45275 m .41084 .45421 L .41398 .45198 L F
.511 .571 .853 r
.30868 .64022 m .30987 .63721 L .30705 .63819 L F
.30868 .64022 m .31147 .64001 L .30987 .63721 L F
.899 .746 .682 r
.29293 .58934 m .29446 .59318 L .29571 .59098 L F
.67 .953 .952 r
.47448 .42286 m .47341 .42489 L .47277 .42485 L F
.47448 .42286 m .47698 .42309 L .47341 .42489 L F
.821 1 .824 r
.42605 .54804 m .4286 .54736 L .42729 .54595 L F
0 0 0 r
.42729 .54595 m .42624 .54817 L .42605 .54804 L F
.779 .823 .351 r
.42668 .54648 m .42624 .54817 L .42668 .54725 L F
.42687 .54632 m .42668 .54725 L .42729 .54595 L F
.42668 .54648 m .42668 .54725 L .42687 .54632 L F
.821 1 .824 r
.42605 .54804 m .42562 .5505 L .42611 .54998 L F
.42654 .54791 m .42611 .54998 L .4286 .54736 L F
.42605 .54804 m .42611 .54998 L .42654 .54791 L F
.825 .895 .476 r
.42605 .54804 m .4242 .55243 L .42562 .5505 L F
.91 .538 .312 r
.42562 .5505 m .4242 .55243 L .42645 .5532 L F
.897 .878 .808 r
.37241 .61365 m .37283 .60921 L .3715 .61157 L F
.947 .81 .677 r
.36975 .61504 m .37241 .61365 L .3715 .61157 L F
.36975 .61504 m .37153 .61627 L .37241 .61365 L F
.471 .891 .812 r
.62269 .34653 m .62159 .34777 L .62407 .34671 L F
.62269 .34653 m .61987 .348 L .62159 .34777 L F
.344 0 .159 r
.64136 .33535 m .64477 .33229 L .64219 .33332 L F
.629 .828 .977 r
.61221 .40214 m .6171 .40208 L .61528 .40056 L F
.094 .424 .869 r
.6171 .40208 m .61787 .40105 L .61528 .40056 L F
.6171 .40208 m .61881 .40288 L .61787 .40105 L F
.694 .974 .918 r
.53226 .49066 m .53529 .48806 L .53164 .49052 L F
.53226 .49066 m .53572 .48855 L .53529 .48806 L F
.838 .999 .816 r
.50379 .44383 m .50592 .44328 L .50744 .44125 L F
.704 .951 .673 r
.56215 .45218 m .55924 .45535 L .56037 .45343 L F
.789 .881 .914 r
.24948 .56349 m .25165 .56459 L .2511 .56196 L F
.024 0 .026 r
.2508 .56309 m .24948 .56349 L .2511 .56196 L F
.395 .208 .505 r
.24948 .56349 m .24819 .56389 L .25165 .56459 L F
.024 0 .026 r
.25043 .56451 m .24948 .56349 L .2508 .56309 L F
.395 .208 .505 r
.24948 .56349 m .24708 .56366 L .24819 .56389 L F
.508 .688 .948 r
.59863 .36305 m .60183 .36785 L .59905 .36657 L F
.769 .805 .882 r
.6047 .36367 m .60183 .36785 L .59863 .36305 L F
.169 0 .106 r
.3829 .49173 m .37926 .4949 L .38266 .49471 L F
.022 0 .329 r
.38441 .49008 m .3829 .49173 L .38266 .49471 L F
.933 .759 .643 r
.72593 .30753 m .72634 .30469 L .72466 .30338 L F
0 0 0 r
.32922 .52754 m .3267 .52991 L .3263 .53004 L F
.379 .515 .869 r
.32947 .52457 m .32922 .52754 L .3272 .52494 L F
.32947 .52457 m .33001 .52699 L .32922 .52754 L F
.797 .456 .409 r
.33182 .52995 m .32922 .52754 L .33001 .52699 L F
.33182 .52995 m .3267 .52991 L .32922 .52754 L F
.794 .372 .246 r
.36885 .50808 m .36697 .50966 L .36523 .50705 L F
.939 .623 .413 r
.36885 .50808 m .36907 .5107 L .36697 .50966 L F
.903 .971 .81 r
.4855 .51878 m .48791 .51862 L .48574 .52141 L F
.711 .983 .895 r
.48978 .51698 m .48791 .51862 L .4855 .51878 L F
.614 .309 .43 r
.3158 .67225 m .3182 .67468 L .3155 .67455 L F
.612 .449 .637 r
.31845 .66919 m .31851 .6722 L .3158 .67225 L F
.586 .312 .468 r
.3158 .67225 m .31851 .6722 L .3182 .67468 L F
.505 .46 .74 r
.54101 .45655 m .53931 .45846 L .53806 .45471 L F
.54101 .45655 m .54258 .45807 L .53931 .45846 L F
.416 .109 .334 r
.54118 .46015 m .53931 .45846 L .53817 .46059 L F
.54118 .46015 m .54258 .45807 L .53931 .45846 L F
.505 .46 .74 r
.53931 .45846 m .54258 .45807 L .54101 .45655 L F
0 .11 .645 r
.54118 .46015 m .53931 .45846 L .54258 .45807 L F
.741 .992 .827 r
.62115 .40689 m .62234 .40464 L .62251 .4042 L F
.62115 .40689 m .61915 .40734 L .62234 .40464 L F
0 0 0 r
.62377 .39484 m .6246 .39323 L .6215 .39608 L F
.818 .979 .69 r
.62627 .3908 m .6246 .39323 L .62553 .39074 L F
.703 .8 .331 r
.62553 .39074 m .6246 .39323 L .62377 .39484 L F
.62553 .39074 m .62377 .39484 L .62522 .39302 L F
.964 .766 .324 r
.62485 .39068 m .62553 .39074 L .62522 .39302 L F
.62472 .38993 m .62553 .39074 L .62485 .39068 L F
.818 .979 .69 r
.62731 .38929 m .62627 .3908 L .62553 .39074 L F
0 0 .406 r
.27178 .52364 m .27355 .5275 L .2723 .52498 L F
.841 .929 .888 r
.36035 .48781 m .35811 .4904 L .356 .48944 L F
.825 .695 .721 r
.35795 .48954 m .36216 .49164 L .36035 .48781 L F
.637 .965 .86 r
.36673 .48839 m .36216 .49164 L .3633 .49028 L F
.472 .726 .981 r
.3633 .49028 m .36216 .49164 L .35795 .48954 L F
.859 .482 .333 r
.35795 .48954 m .36009 .49317 L .36216 .49164 L F
0 0 .097 r
.36197 .49452 m .3633 .49028 L .36216 .49164 L F
.954 .79 .641 r
.70853 .30735 m .70866 .31108 L .70955 .31051 L F
.667 .244 .232 r
.70866 .31108 m .70831 .31245 L .70955 .31051 L F
.723 .311 .265 r
.70955 .31051 m .70831 .31245 L .71433 .31285 L F
.335 .351 .729 r
.71433 .31285 m .71314 .31024 L .70955 .31051 L F
.58 .62 .857 r
.42491 .57983 m .42331 .58103 L .4212 .57679 L F
.096 0 .186 r
.42331 .58103 m .42227 .58317 L .42491 .57983 L F
.655 .905 .981 r
.61724 .41374 m .62239 .41312 L .62115 .41188 L F
.806 .906 .911 r
.62239 .41312 m .62319 .40986 L .62115 .41188 L F
.62239 .41312 m .62445 .41125 L .62319 .40986 L F
.589 .562 .791 r
.31133 .65824 m .31031 .66306 L .30878 .65931 L F
.31133 .65824 m .31283 .66234 L .31031 .66306 L F
.036 0 .438 r
.2394 .54077 m .24063 .54274 L .24081 .53997 L F
.2394 .54077 m .23863 .54561 L .24063 .54274 L F
.849 .493 .38 r
.563 .41502 m .55862 .41651 L .55867 .41388 L F
.563 .41502 m .56148 .41748 L .55862 .41651 L F
.782 .856 .905 r
.56705 .41232 m .56316 .41478 L .563 .41502 L F
.659 .161 .054 r
.51181 .42589 m .51436 .42785 L .51179 .42852 L F
.879 .474 .251 r
.51436 .42785 m .51181 .42589 L .51179 .42852 L F
.904 .633 .515 r
.58033 .43428 m .58246 .43243 L .58028 .43158 L F
.58033 .43428 m .58291 .43525 L .58246 .43243 L F
0 0 .42 r
.57344 .36737 m .57447 .36934 L .57272 .36546 L F
.828 .727 .753 r
.28872 .6621 m .28819 .66612 L .28623 .66545 L F
.959 .795 .635 r
.28819 .66612 m .28785 .66902 L .28623 .66545 L F
.991 .851 .602 r
.39786 .57154 m .39593 .57163 L .39715 .56912 L F
.39786 .57154 m .39741 .574 L .39593 .57163 L F
.675 .391 .483 r
.32348 .53763 m .32614 .53934 L .32836 .53662 L F
.32465 .53838 m .32514 .53984 L .32614 .53934 L F
.061 .055 .535 r
.32585 .53892 m .32484 .54386 L .32614 .53934 L F
.32547 .54079 m .32618 .54405 L .32484 .54386 L F
.32585 .53892 m .32608 .54259 L .32547 .54079 L F
.32608 .54259 m .32618 .54405 L .32547 .54079 L F
.675 .391 .483 r
.32348 .53763 m .32369 .54055 L .32514 .53984 L F
.32348 .53763 m .32514 .53984 L .32465 .53838 L F
.288 .181 .554 r
.24225 .58954 m .24372 .58612 L .2429 .58718 L F
.02 0 0 r
.41398 .45198 m .41625 .45137 L .41745 .45048 L F
.474 0 0 r
.41625 .45137 m .4204 .4513 L .41745 .45048 L F
.148 .087 .526 r
.23863 .54561 m .24104 .54548 L .24063 .54274 L F
.23863 .54561 m .23914 .5473 L .24104 .54548 L F
.925 .817 .721 r
.46103 .55406 m .46031 .55628 L .45927 .55676 L F
.114 .281 .757 r
.3459 .54955 m .34472 .54581 L .34773 .54691 L F
.531 .864 .592 r
.50353 .40318 m .50389 .40261 L .50565 .40131 L F
.50353 .40318 m .50198 .40437 L .50389 .40261 L F
.42 .853 .731 r
.45215 .59634 m .45657 .59427 L .45465 .59554 L F
.706 .958 .692 r
.45607 .59371 m .45657 .59427 L .45839 .59247 L F
.45607 .59371 m .45465 .59554 L .45657 .59427 L F
.616 .695 .9 r
.31535 .64248 m .31781 .64236 L .31449 .64071 L F
.31535 .64248 m .31945 .64301 L .31781 .64236 L F
0 0 .237 r
.58863 .40715 m .58812 .40487 L .58959 .4061 L F
.767 .51 .546 r
.26675 .52736 m .26268 .52936 L .26241 .52694 L F
.26675 .52736 m .26639 .53068 L .26268 .52936 L F
.869 .819 .797 r
.26675 .52736 m .268 .52277 L .26939 .52604 L F
0 0 0 r
.34383 .55062 m .3465 .54978 L .3459 .54955 L F
.667 .532 .69 r
.69598 .3112 m .69614 .31397 L .69879 .31061 L F
.868 .534 .417 r
.36089 .54228 m .36423 .54125 L .36049 .53955 L F
.36089 .54228 m .36465 .54347 L .36423 .54125 L F
.837 .952 .892 r
.25641 .61636 m .25409 .61682 L .2573 .61501 L F
.045 .206 .707 r
.2579 .61729 m .25641 .61636 L .2573 .61501 L F
0 0 .45 r
.70847 .29269 m .70881 .29657 L .70776 .29691 L F
0 0 .055 r
.70784 .29763 m .70776 .29691 L .70881 .29657 L F
.70784 .29763 m .70791 .29893 L .70776 .29691 L F
.38 .107 .369 r
.32346 .57578 m .32144 .57427 L .32214 .57704 L F
.441 .084 .263 r
.32346 .57578 m .32423 .57379 L .32144 .57427 L F
.507 .912 .853 r
.5899 .43536 m .58571 .43763 L .58536 .43726 L F
.903 .971 .81 r
.4855 .51878 m .48574 .52141 L .483 .51997 L F
.933 .74 .619 r
.48574 .52141 m .48493 .52409 L .483 .51997 L F
.613 .83 .983 r
.45595 .57998 m .46038 .58008 L .45891 .57899 L F
.671 .376 .465 r
.45582 .58287 m .46038 .58008 L .45595 .57998 L F
.45582 .58287 m .46038 .58299 L .46038 .58008 L F
.303 .682 .976 r
.46038 .58008 m .46108 .57912 L .45891 .57899 L F
.069 0 0 r
.32097 .62556 m .3192 .62603 L .31738 .62782 L F
0 0 0 r
.62377 .39484 m .6215 .39608 L .61987 .39737 L F
.65085 .3297 m .65357 .32871 L .65483 .32768 L F
.65483 .32768 m .65617 .32768 L .65717 .32622 L F
.65483 .32768 m .65357 .32871 L .65617 .32768 L F
.935 .806 .693 r
.57668 .44723 m .57992 .44509 L .57944 .44395 L F
.57668 .44723 m .5784 .44879 L .57992 .44509 L F
.914 .971 .676 r
.58157 .43995 m .57992 .44509 L .58414 .43987 L F
.58157 .43995 m .57944 .44395 L .57992 .44509 L F
.137 0 0 r
.40982 .46127 m .40828 .46191 L .40575 .46177 L F
0 0 0 r
.41279 .46041 m .4111 .46119 L .40982 .46127 L F
.342 0 0 r
.4111 .46119 m .40828 .46191 L .40982 .46127 L F
.354 .818 .919 r
.44211 .45208 m .44615 .45146 L .44349 .45125 L F
.372 .837 .791 r
.44211 .45208 m .44349 .45125 L .43897 .45303 L F
.609 .466 .662 r
.32101 .66586 m .31845 .66919 L .31704 .66554 L F
.32101 .66586 m .32111 .66871 L .31845 .66919 L F
.676 .542 .693 r
.32111 .66871 m .31851 .6722 L .31845 .66919 L F
.774 .508 .533 r
.42476 .56061 m .42465 .56342 L .42052 .56283 L F
.256 0 .301 r
.42476 .56061 m .4264 .56015 L .42762 .55735 L F
.38 .315 .659 r
.42476 .56061 m .42757 .56263 L .4264 .56015 L F
.509 .286 .512 r
.42465 .56342 m .42757 .56263 L .42476 .56061 L F
.256 0 .301 r
.42476 .56061 m .4264 .56015 L .42762 .55735 L F
.38 .315 .659 r
.42476 .56061 m .42757 .56263 L .4264 .56015 L F
.509 .286 .512 r
.42465 .56342 m .42757 .56263 L .42476 .56061 L F
.868 .529 .406 r
.34136 .50672 m .34478 .51024 L .34399 .50871 L F
.882 .665 .604 r
.36411 .54615 m .36706 .54427 L .36465 .54347 L F
.36411 .54615 m .36665 .54706 L .36706 .54427 L F
.932 .97 .735 r
.59675 .37886 m .59968 .376 L .59793 .37722 L F
.59675 .37886 m .59683 .38066 L .59968 .376 L F
.807 .888 .465 r
.60131 .37151 m .59968 .376 L .59889 .37227 L F
.60131 .37151 m .59954 .37538 L .59968 .376 L F
.761 .953 .637 r
.59954 .37538 m .59793 .37722 L .59968 .376 L F
.478 .308 .571 r
.28094 .59009 m .28365 .59338 L .28378 .58947 L F
.28094 .59009 m .28086 .59412 L .28365 .59338 L F
.989 .875 .623 r
.72407 .31969 m .72488 .31751 L .72382 .31591 L F
.835 .749 .768 r
.43278 .59567 m .43617 .59681 L .43389 .59371 L F
.837 .433 .277 r
.43423 .59878 m .43617 .59681 L .43278 .59567 L F
.297 .526 .906 r
.43389 .59371 m .43617 .59681 L .43802 .59557 L F
0 0 0 r
.43802 .59557 m .43617 .59681 L .43423 .59878 L F
.616 .953 .802 r
.52593 .47781 m .5239 .4794 L .52197 .47995 L F
.624 .726 .92 r
.66338 .38502 m .66707 .38575 L .66681 .38491 L F
.619 .95 .776 r
.66707 .38575 m .66861 .38394 L .66681 .38491 L F
.66707 .38575 m .67043 .38334 L .66861 .38394 L F
.951 .651 .43 r
.67443 .33575 m .67222 .33273 L .67551 .33341 L F
.911 .969 .799 r
.66878 .36408 m .66671 .3657 L .6689 .3628 L F
.785 .726 .798 r
.45631 .56368 m .45845 .56033 L .45994 .56401 L F
.584 .448 .662 r
.25218 .55693 m .25063 .56044 L .24968 .55776 L F
.25218 .55693 m .25063 .56044 L .24968 .55776 L F
.883 .566 .445 r
.3931 .54433 m .38966 .54372 L .38987 .54048 L F
.824 .62 .627 r
.39348 .54669 m .38966 .54372 L .3931 .54433 L F
.585 .112 .097 r
.34865 .52783 m .34441 .52896 L .34625 .52673 L F
.34865 .52783 m .34638 .52952 L .34441 .52896 L F
.856 .497 .37 r
.34865 .52783 m .34914 .5303 L .34638 .52952 L F
.416 0 .033 r
.3282 .5014 m .33206 .50026 L .32953 .50117 L F
.811 .657 .691 r
.32696 .50743 m .32505 .50368 L .32753 .50487 L F
.17 .357 .807 r
.58863 .40715 m .59132 .4125 L .5924 .41065 L F
0 .119 .58 r
.59132 .4125 m .59243 .41328 L .5924 .41065 L F
.59132 .4125 m .59456 .41497 L .59243 .41328 L F
.257 .042 .384 r
.66913 .36881 m .66769 .37018 L .66734 .37246 L F
.994 .848 .586 r
.67648 .33978 m .67442 .34192 L .67542 .33831 L F
.67648 .33978 m .67564 .34351 L .67442 .34192 L F
.465 .884 .921 r
.61323 .34422 m .61594 .34322 L .617 .34351 L F
.217 .733 .707 r
.61594 .34322 m .61951 .34224 L .617 .34351 L F
.92 .955 .795 r
.57089 .41082 m .57142 .41228 L .57186 .40794 L F
.734 .554 .648 r
.68946 .31676 m .6935 .31718 L .69352 .31436 L F
.69 .517 .648 r
.69352 .31436 m .6935 .31718 L .69614 .31397 L F
.649 .865 .981 r
.31738 .62782 m .31689 .63009 L .31492 .62896 L F
0 0 .542 r
.40236 .50842 m .40361 .50988 L .40418 .51128 L F
.952 .774 .318 r
.40361 .50988 m .4041 .51395 L .40418 .51128 L F
.908 .94 .817 r
.50472 .5206 m .50734 .51709 L .50602 .51618 L F
.916 .937 .806 r
.50602 .51618 m .50734 .51709 L .50981 .51336 L F
.543 .146 .238 r
.54377 .40486 m .54683 .40582 L .54763 .4026 L F
.362 0 .186 r
.54763 .4026 m .55058 .40464 L .55044 .4012 L F
.54763 .4026 m .54683 .40582 L .55058 .40464 L F
.874 .533 .029 r
.58191 .38271 m .58099 .38151 L .58043 .37913 L F
.576 .039 0 r
.58191 .38271 m .58251 .38372 L .58099 .38151 L F
.58191 .38271 m .58412 .38486 L .58251 .38372 L F
.857 .988 .845 r
.47903 .53012 m .48077 .52635 L .48262 .5277 L F
.47903 .53012 m .47784 .52944 L .48077 .52635 L F
.152 0 0 r
.61828 .36461 m .62135 .36332 L .61734 .36273 L F
.61828 .36461 m .62025 .36469 L .62135 .36332 L F
.515 0 0 r
.62135 .36332 m .62424 .36478 L .624 .36254 L F
.62135 .36332 m .62025 .36469 L .62424 .36478 L F
.236 .322 .749 r
.62424 .36478 m .62135 .36332 L .624 .36254 L F
.882 .89 .833 r
.54588 .41472 m .54743 .41314 L .54591 .41133 L F
.284 .237 .628 r
.3948 .50362 m .39461 .5072 L .39358 .50783 L F
.321 .202 .558 r
.39305 .51101 m .39461 .5072 L .39358 .50783 L F
.39305 .51101 m .39461 .5072 L .39358 .50783 L F
.658 .326 .4 r
.37529 .49431 m .38078 .49555 L .37926 .4949 L F
.372 0 .014 r
.38078 .49555 m .38266 .49471 L .37926 .4949 L F
.587 .341 .511 r
.50762 .42124 m .51016 .42151 L .51007 .41916 L F
.518 .367 .616 r
.51016 .42151 m .5125 .41842 L .51007 .41916 L F
.857 .664 .64 r
.37771 .58598 m .37946 .58972 L .38135 .58671 L F
.944 .942 .754 r
.49656 .5302 m .49871 .52691 L .49822 .52653 L F
.932 .888 .765 r
.49822 .52653 m .49972 .5277 L .50121 .52416 L F
0 0 0 r
.49872 .52671 m .49656 .5302 L .49822 .52653 L F
.619 .818 .408 r
.49549 .53185 m .49656 .5302 L .49872 .52671 L F
.49536 .53206 m .49656 .5302 L .49549 .53185 L F
.944 .942 .754 r
.49656 .5302 m .49972 .5277 L .49871 .52691 L F
.49656 .5302 m .49762 .5313 L .49972 .5277 L F
0 0 0 r
.51854 .42582 m .51436 .42785 L .51833 .42764 L F
.538 .177 .303 r
.52107 .42756 m .51854 .42582 L .51833 .42764 L F
.53 .184 .326 r
.52107 .42756 m .5215 .42565 L .51854 .42582 L F
.988 .877 .628 r
.5533 .46144 m .55444 .46212 L .55357 .46463 L F
.39 .816 .642 r
.54099 .41109 m .53956 .41191 L .5411 .41078 L F
.104 0 .302 r
.53956 .41191 m .54131 .41201 L .5411 .41078 L F
.39 .816 .642 r
.54356 .40961 m .54099 .41109 L .5411 .41078 L F
.354 .437 .808 r
.53877 .41431 m .54242 .41707 L .54191 .41307 L F
.53877 .41431 m .54191 .41307 L .5418 .41298 L F
.53877 .41431 m .54189 .41294 L .54136 .41235 L F
.104 0 .302 r
.53956 .41191 m .53877 .41431 L .54136 .41235 L F
.714 .966 .713 r
.54242 .41707 m .54552 .41411 L .54421 .41555 L F
.614 .583 .796 r
.54313 .41399 m .54242 .41707 L .54421 .41555 L F
.54189 .41294 m .54191 .41307 L .5431 .41397 L F
.54191 .41307 m .54242 .41707 L .54313 .41399 L F
.841 .416 .223 r
.54221 .41321 m .5431 .41397 L .54257 .4137 L F
.795 .505 .497 r
.54315 .41403 m .54257 .4137 L .5431 .41397 L F
.54391 .41497 m .54333 .41442 L .54315 .41403 L F
.54333 .41442 m .54257 .4137 L .54315 .41403 L F
.614 .583 .796 r
.54313 .41399 m .54313 .414 L .54378 .41538 L F
.54313 .414 m .54421 .41555 L .54396 .41545 L F
.54313 .414 m .54396 .41545 L .54378 .41538 L F
.795 .505 .497 r
.54378 .41538 m .54257 .4137 L .54391 .41497 L F
.841 .416 .223 r
.54116 .41085 m .54407 .41446 L .54131 .41201 L F
.614 .583 .796 r
.54177 .41203 m .54313 .41399 L .54378 .41538 L F
.841 .416 .223 r
.54131 .41201 m .54271 .41325 L .5431 .41397 L F
.54271 .41325 m .54407 .41446 L .54312 .41398 L F
.54271 .41325 m .54312 .41398 L .5431 .41397 L F
.54131 .41201 m .5431 .41397 L .54221 .41321 L F
.614 .583 .796 r
.54177 .41203 m .54189 .41294 L .54313 .41399 L F
.54189 .41294 m .5431 .41397 L .54313 .41399 L F
.795 .505 .497 r
.54401 .41465 m .5431 .41397 L .54407 .41446 L F
.54391 .41497 m .5431 .41397 L .54401 .41465 L F
.54378 .41538 m .53964 .41222 L .54257 .4137 L F
.354 .437 .808 r
.5418 .41298 m .54191 .41307 L .54189 .41294 L F
.841 .416 .223 r
.54131 .41201 m .54257 .4137 L .54138 .41237 L F
.354 .437 .808 r
.54136 .41235 m .54189 .41294 L .54177 .41203 L F
.841 .416 .223 r
.54138 .41237 m .54257 .4137 L .54151 .41317 L F
.5411 .41078 m .54116 .41085 L .54131 .41201 L F
.104 0 .302 r
.54131 .41201 m .54136 .41235 L .54177 .41203 L F
.53956 .41191 m .54136 .41235 L .54131 .41201 L F
.54131 .41201 m .54177 .41203 L .5411 .41078 L F
.841 .416 .223 r
.5411 .41078 m .54151 .41317 L .53964 .41222 L F
.611 .872 .533 r
.5411 .41078 m .53964 .41222 L .54128 .41029 L F
.5411 .41078 m .54128 .41029 L .54229 .40912 L F
.717 .804 .335 r
.42675 .55906 m .42762 .55735 L .42674 .55481 L F
.42675 .55906 m .4264 .56015 L .42762 .55735 L F
.964 .884 .498 r
.59456 .41497 m .59516 .41593 L .59384 .41723 L F
.59456 .41497 m .59516 .41593 L .59384 .41723 L F
.912 .943 .812 r
.55896 .36833 m .5584 .36704 L .55867 .36608 L F
.371 .57 .915 r
.56237 .3673 m .55896 .36833 L .55867 .36608 L F
.56237 .3673 m .56202 .36973 L .55896 .36833 L F
.73 .858 .941 r
.70442 .32298 m .70805 .3231 L .70701 .31981 L F
.712 .755 .885 r
.70701 .31981 m .70805 .3231 L .71134 .32107 L F
.046 0 .423 r
.32516 .60692 m .3247 .61043 L .32652 .60826 L F
0 0 0 r
.33171 .53065 m .3342 .52967 L .33544 .52753 L F
.33544 .52753 m .33643 .52797 L .33827 .52845 L F
.33544 .52753 m .3342 .52967 L .33643 .52797 L F
.724 .566 .676 r
.6935 .31718 m .69651 .31725 L .69614 .31397 L F
.632 .483 .662 r
.69879 .31061 m .69614 .31397 L .69939 .31331 L F
.716 .561 .677 r
.69614 .31397 m .70023 .31717 L .69939 .31331 L F
.69614 .31397 m .69651 .31725 L .70023 .31717 L F
.871 .959 .859 r
.38895 .4945 m .38613 .49748 L .38762 .4974 L F
.762 .595 .67 r
.38613 .49748 m .38998 .49964 L .38762 .4974 L F
.723 .984 .79 r
.6718 .38107 m .67043 .38334 L .67224 .38141 L F
.722 .982 .778 r
.66861 .38394 m .67043 .38334 L .6718 .38107 L F
.889 .624 .531 r
.37306 .56612 m .37515 .56994 L .37538 .56706 L F
.871 .97 .853 r
.50058 .52312 m .50472 .5206 L .50346 .51981 L F
.50058 .52312 m .50121 .52416 L .50472 .5206 L F
.908 .94 .817 r
.50472 .5206 m .50602 .51618 L .50346 .51981 L F
.828 .702 .726 r
.31888 .61264 m .32069 .6164 L .32089 .615 L F
0 0 .358 r
.32069 .6164 m .32198 .6181 L .32089 .615 L F
.32092 .61849 m .32098 .61901 L .32198 .6181 L F
0 .065 .607 r
.32198 .6181 m .32098 .61901 L .32269 .62154 L F
0 0 0 r
.3225 .6179 m .32198 .6181 L .31987 .61946 L F
.32351 .61731 m .32198 .6181 L .3225 .6179 L F
0 0 .358 r
.32069 .6164 m .32092 .61849 L .32198 .6181 L F
.299 0 0 r
.42735 .60241 m .42953 .6004 L .43161 .60119 L F
.668 .623 .796 r
.46641 .53442 m .47029 .53503 L .46778 .53419 L F
.916 .937 .806 r
.50602 .51618 m .50981 .51336 L .50861 .51278 L F
.976 .818 .406 r
.56148 .41748 m .56228 .4196 L .5618 .42178 L F
.75 .517 .579 r
.67741 .3119 m .68215 .30984 L .67835 .30959 L F
.759 .287 .122 r
.33889 .51501 m .33725 .51613 L .33541 .51373 L F
.894 .503 .276 r
.33889 .51501 m .33961 .51723 L .33725 .51613 L F
.815 .523 .496 r
.42222 .53596 m .42579 .53422 L .42146 .53373 L F
.42222 .53596 m .42564 .53701 L .42579 .53422 L F
.603 .795 .973 r
.33291 .64266 m .33626 .64276 L .33301 .64013 L F
.703 .429 .506 r
.33291 .64266 m .33696 .64306 L .33626 .64276 L F
.763 .834 .907 r
.33301 .64013 m .33626 .64276 L .3358 .63868 L F
.698 .767 .905 r
.33696 .64306 m .3358 .63868 L .33626 .64276 L F
.408 .671 .968 r
.49734 .43794 m .49842 .43576 L .49545 .43684 L F
.49734 .43794 m .50003 .43786 L .49842 .43576 L F
.413 .059 .251 r
.49805 .44002 m .49734 .43794 L .4963 .44076 L F
.49805 .44002 m .50003 .43786 L .49734 .43794 L F
.38 .837 .762 r
.44392 .44251 m .44614 .44189 L .44364 .44302 L F
.762 .78 .868 r
.60666 .36217 m .60849 .36449 L .61043 .36263 L F
.60666 .36217 m .60849 .36449 L .61043 .36263 L F
.949 .846 .707 r
.59484 .40453 m .59551 .40818 L .59636 .40598 L F
.721 .862 .948 r
.59484 .40453 m .59636 .40598 L .59874 .40441 L F
.573 .085 .06 r
.30977 .55014 m .30844 .55051 L .30635 .54975 L F
.778 .874 .918 r
.56683 .46229 m .56753 .46194 L .56602 .46053 L F
.86 .958 .87 r
.56753 .46194 m .5692 .45797 L .56602 .46053 L F
.56753 .46194 m .57053 .45892 L .5692 .45797 L F
.408 .7 .981 r
.41373 .47312 m .41545 .47469 L .4127 .47484 L F
.318 .058 .352 r
.35811 .4904 m .35843 .49328 L .356 .48944 L F
.675 .732 .893 r
.60995 .38775 m .60547 .38664 L .60823 .38609 L F
.352 .442 .814 r
.61136 .38554 m .60995 .38775 L .60823 .38609 L F
.029 0 0 r
.6157 .38825 m .61279 .38957 L .61556 .38864 L F
.525 .92 .87 r
.61388 .38894 m .61279 .38957 L .6157 .38825 L F
.536 .561 .827 r
.61388 .38894 m .61279 .38957 L .61264 .38917 L F
.525 .92 .87 r
.61189 .3897 m .61279 .38957 L .61388 .38894 L F
.536 .561 .827 r
.61556 .38864 m .61279 .38957 L .61388 .38894 L F
.525 .92 .87 r
.61455 .38882 m .6157 .38825 L .61556 .38864 L F
.61342 .38912 m .6157 .38825 L .61404 .38908 L F
.536 .561 .827 r
.61556 .38864 m .61264 .38917 L .61136 .38554 L F
.525 .92 .87 r
.61404 .38908 m .61455 .38882 L .61556 .38864 L F
.61189 .3897 m .61342 .38912 L .61404 .38908 L F
.352 .442 .814 r
.61136 .38554 m .61264 .38917 L .60995 .38775 L F
.61264 .38917 m .61279 .38957 L .6122 .38919 L F
.61264 .38917 m .6122 .38919 L .60995 .38775 L F
0 0 0 r
.59456 .37163 m .59552 .37039 L .59589 .37226 L F
.808 .866 .891 r
.59589 .37226 m .59222 .37302 L .59456 .37163 L F
.581 .486 .711 r
.59841 .36952 m .59589 .37226 L .59552 .37039 L F
.59841 .36952 m .59889 .37227 L .59589 .37226 L F
.609 .385 .552 r
.30387 .67844 m .2998 .6824 L .29974 .6788 L F
.30387 .67844 m .30406 .6808 L .2998 .6824 L F
.691 .386 .454 r
.30387 .67844 m .30624 .68114 L .30406 .6808 L F
.30387 .67844 m .30651 .6788 L .30624 .68114 L F
.778 .874 .918 r
.56683 .46229 m .56602 .46053 L .56307 .4636 L F
.977 .92 .636 r
.56127 .45087 m .56215 .45218 L .56037 .45343 L F
.645 .74 .918 r
.31945 .64301 m .32039 .63935 L .31781 .64236 L F
.31945 .64301 m .32208 .64224 L .32039 .63935 L F
.462 .57 .877 r
.44754 .45052 m .44769 .45347 L .44997 .45029 L F
.669 .867 .974 r
.44769 .45347 m .45168 .45163 L .44997 .45029 L F
.563 .597 .846 r
.27595 .52671 m .27355 .5275 L .27178 .52364 L F
.423 .194 .46 r
.27595 .52671 m .27321 .53022 L .27355 .5275 L F
.569 .898 .983 r
.5189 .41063 m .51531 .4118 L .51451 .41013 L F
.085 0 0 r
.65602 .33582 m .65193 .3379 L .65337 .33736 L F
.621 .724 .921 r
.35947 .62839 m .36113 .63008 L .36358 .62911 L F
0 0 .001 r
.43309 .5733 m .43101 .576 L .43077 .57322 L F
.43309 .5733 m .43222 .57462 L .43101 .576 L F
.97 .896 .53 r
.39741 .574 m .39611 .57412 L .39593 .57163 L F
.39741 .574 m .39648 .57636 L .39611 .57412 L F
.62 .124 .053 r
.27091 .53097 m .26876 .5324 L .26639 .53068 L F
.077 0 0 r
.27321 .53022 m .26876 .5324 L .27091 .53097 L F
.806 .359 .178 r
.38779 .53432 m .38628 .53572 L .38453 .53311 L F
.933 .574 .315 r
.38779 .53432 m .38835 .53679 L .38628 .53572 L F
0 .343 .761 r
.30757 .54689 m .31141 .54885 L .31163 .54676 L F
.819 .693 .726 r
.31491 .54628 m .31141 .54885 L .31163 .54676 L F
.818 .865 .419 r
.31141 .54885 m .31242 .54547 L .31163 .54676 L F
.929 .911 .781 r
.57053 .45892 m .57269 .45519 L .57136 .45395 L F
.849 .923 .88 r
.57136 .45395 m .57269 .45519 L .57563 .45206 L F
.976 .878 .503 r
.69539 .35945 m .69612 .35676 L .69539 .35455 L F
.898 .506 .269 r
.33708 .50057 m .33833 .50378 L .34047 .50461 L F
.889 .483 .239 r
.33833 .50378 m .33886 .50578 L .34047 .50461 L F
.813 .659 .692 r
.36564 .6243 m .36196 .62501 L .36471 .62672 L F
.621 .724 .921 r
.35947 .62839 m .36471 .62672 L .36196 .62501 L F
.35947 .62839 m .36358 .62911 L .36471 .62672 L F
.92 .831 .741 r
.36358 .62911 m .36564 .6243 L .36471 .62672 L F
0 0 .415 r
.36776 .62954 m .36564 .6243 L .36358 .62911 L F
.86 .433 .203 r
.33886 .50578 m .34136 .50672 L .34047 .50461 L F
.382 .347 .695 r
.25627 .54886 m .25395 .54738 L .2561 .5465 L F
.25627 .54886 m .25459 .55113 L .25395 .54738 L F
.97 .662 .278 r
.56933 .41748 m .5703 .41566 L .56938 .41431 L F
.56933 .41748 m .57062 .41882 L .5703 .41566 L F
.705 .256 0 r
.40204 .59051 m .40109 .58954 L .3995 .58678 L F
.731 .292 0 r
.40204 .59051 m .4034 .59289 L .40109 .58954 L F
0 0 0 r
.7024 .29532 m .70406 .29494 L .70561 .2933 L F
.393 .186 .475 r
.70561 .2933 m .70847 .29269 L .70796 .29062 L F
.618 .433 .61 r
.70689 .29392 m .70829 .29223 L .70781 .2926 L F
.63 .82 .974 r
.71006 .28914 m .70796 .29062 L .70951 .28776 L F
0 0 0 r
.71006 .28914 m .70847 .29269 L .70796 .29062 L F
.958 .942 .712 r
.70847 .29269 m .70951 .28776 L .70796 .29062 L F
.70847 .29269 m .70781 .2926 L .70951 .28776 L F
.703 .98 .902 r
.70847 .29269 m .70781 .2926 L .70958 .29066 L F
.618 .433 .61 r
.70829 .29223 m .70958 .29066 L .70781 .2926 L F
0 0 0 r
.70742 .29292 m .70781 .2926 L .70847 .29269 L F
.70561 .2933 m .70781 .2926 L .70742 .29292 L F
.70561 .2933 m .70406 .29494 L .70781 .2926 L F
.779 .453 .437 r
.67197 .33055 m .66821 .33207 L .66805 .33044 L F
.67197 .33055 m .67222 .33273 L .66821 .33207 L F
.596 .84 .471 r
.47721 .56708 m .47598 .56855 L .4747 .57036 L F
.966 .736 .297 r
.47598 .56855 m .47693 .57279 L .4747 .57036 L F
.826 .812 .837 r
.3421 .64205 m .34394 .64325 L .34579 .63962 L F
.793 .716 .779 r
.23842 .57736 m .24336 .57708 L .2414 .57772 L F
.738 .973 .927 r
.33467 .54453 m .33668 .54552 L .3382 .54365 L F
.33467 .54453 m .3337 .54623 L .33668 .54552 L F
0 .083 .628 r
.5633 .40822 m .56425 .40706 L .56168 .40525 L F
.5633 .40822 m .56422 .40887 L .56425 .40706 L F
.601 .43 .622 r
.69879 .31061 m .70169 .31017 L .70145 .3073 L F
.453 .267 .538 r
.69939 .31331 m .70169 .31017 L .69879 .31061 L F
.426 0 0 r
.52738 .43998 m .52816 .43883 L .52456 .43892 L F
.96 .689 .25 r
.52738 .43998 m .5284 .44155 L .52816 .43883 L F
.749 .305 .196 r
.45406 .55423 m .45596 .55343 L .45655 .55323 L F
.45406 .55423 m .45653 .55611 L .45284 .55593 L F
.45406 .55423 m .45284 .55593 L .45596 .55343 L F
.807 .319 .016 r
.3995 .58678 m .3986 .58786 L .39761 .58585 L F
.3995 .58678 m .40109 .58954 L .3986 .58786 L F
.54 .453 .705 r
.25795 .55315 m .25459 .55113 L .25627 .54886 L F
.25795 .55315 m .25541 .55431 L .25459 .55113 L F
.484 .27 .514 r
.24708 .56366 m .24734 .56644 L .24436 .56695 L F
.395 .208 .505 r
.24948 .56349 m .24734 .56644 L .24708 .56366 L F
.735 .52 .602 r
.69651 .31725 m .70043 .31992 L .70023 .31717 L F
.572 .545 .786 r
.70023 .31717 m .70208 .31265 L .69939 .31331 L F
.70023 .31717 m .703 .31637 L .70208 .31265 L F
.637 .538 .726 r
.70043 .31992 m .703 .31637 L .70023 .31717 L F
.75 .317 .223 r
.33956 .64543 m .33696 .64306 L .33698 .6459 L F
.613 .32 .448 r
.30651 .6788 m .30884 .68146 L .30624 .68114 L F
.30651 .6788 m .30923 .67883 L .30884 .68146 L F
.896 .843 .784 r
.72398 .3099 m .72593 .30753 L .72438 .30608 L F
.933 .759 .643 r
.72593 .30753 m .72466 .30338 L .72438 .30608 L F
.985 .734 .467 r
.38987 .54048 m .38821 .5396 L .38835 .53679 L F
.959 .654 .408 r
.38987 .54048 m .38788 .54213 L .38821 .5396 L F
.38987 .54048 m .38966 .54372 L .38788 .54213 L F
.458 .469 .782 r
.23627 .57723 m .23717 .57251 L .23581 .57327 L F
.23627 .57723 m .23842 .57736 L .23717 .57251 L F
.426 .388 .713 r
.70145 .3073 m .70326 .30229 L .70172 .3046 L F
.70145 .3073 m .7039 .3066 L .70326 .30229 L F
.41 .333 .659 r
.70145 .3073 m .70431 .30909 L .7039 .3066 L F
.453 .32 .609 r
.70145 .3073 m .70169 .31017 L .70431 .30909 L F
.523 .919 .867 r
.31141 .54885 m .30844 .55051 L .30977 .55014 L F
0 .187 .706 r
.24665 .56904 m .24436 .56695 L .24734 .56644 L F
.807 .845 .879 r
.32881 .64288 m .33291 .64266 L .33116 .64163 L F
.603 .795 .973 r
.33291 .64266 m .33301 .64013 L .33116 .64163 L F
.473 .566 .868 r
.28234 .51134 m .28085 .51275 L .28004 .51257 L F
.28234 .51134 m .28399 .5135 L .28085 .51275 L F
.56 .414 .639 r
.28399 .5135 m .28117 .51731 L .28085 .51275 L F
.2 .644 .947 r
.66203 .38387 m .66338 .38502 L .66681 .38491 L F
.711 .563 .685 r
.29549 .6784 m .29974 .6788 L .29721 .68181 L F
.676 .511 .655 r
.29974 .6788 m .2998 .6824 L .29721 .68181 L F
.882 .89 .833 r
.54589 .41378 m .54591 .41133 L .54552 .41411 L F
0 0 .207 r
.54678 .41254 m .54552 .41411 L .54591 .41133 L F
.569 .845 .504 r
.54516 .41443 m .54552 .41411 L .54678 .41254 L F
.54421 .41555 m .54552 .41411 L .54516 .41443 L F
.882 .89 .833 r
.54588 .41472 m .54589 .41378 L .54552 .41411 L F
.736 .799 .902 r
.37271 .47102 m .37161 .4726 L .37072 .47179 L F
.37123 .47081 m .37072 .47179 L .36933 .47052 L F
.37271 .47102 m .37072 .47179 L .37123 .47081 L F
.37271 .47102 m .36933 .47052 L .37164 .4702 L F
0 0 0 r
.36957 .47072 m .37164 .4702 L .36933 .47052 L F
.843 .986 .708 r
.37162 .46803 m .37164 .47003 L .36957 .47072 L F
.37164 .47003 m .37164 .4702 L .37154 .47022 L F
.37164 .47003 m .37154 .47022 L .36957 .47072 L F
.282 .612 .956 r
.36933 .47052 m .37161 .4726 L .37175 .47237 L F
.328 .157 .49 r
.37271 .47102 m .37175 .47237 L .37161 .4726 L F
.803 .799 .306 r
.58863 .39955 m .58794 .40104 L .58692 .39814 L F
.58863 .39955 m .58782 .40247 L .58794 .40104 L F
0 0 .205 r
.30519 .63476 m .30539 .63672 L .30533 .63489 L F
.532 .35 .58 r
.30453 .63942 m .30705 .63819 L .30539 .63672 L F
.991 .818 .441 r
.58445 .38628 m .5833 .38772 L .58412 .38486 L F
.58445 .38628 m .58414 .38876 L .5833 .38772 L F
.932 .888 .765 r
.49822 .52653 m .50121 .52416 L .50058 .52312 L F
.331 .801 .922 r
.63938 .39929 m .64085 .39844 L .63748 .3996 L F
.63938 .39929 m .64212 .39879 L .64085 .39844 L F
.929 .911 .781 r
.57053 .45892 m .57136 .45395 L .5692 .45797 L F
.695 .853 .958 r
.47437 .44257 m .47519 .44008 L .47308 .44146 L F
.47437 .44257 m .47691 .44153 L .47519 .44008 L F
.76 .904 .515 r
.60303 .4449 m .60288 .44579 L .60369 .44683 L F
.508 .688 .948 r
.59863 .36305 m .59905 .36657 L .59676 .36444 L F
.644 .543 .726 r
.60116 .36881 m .59676 .36444 L .59905 .36657 L F
.673 .957 .946 r
.66852 .31599 m .6704 .31342 L .67251 .31411 L F
.66852 .31599 m .66776 .31526 L .6704 .31342 L F
.393 .748 .993 r
.4188 .60128 m .42003 .60254 L .42236 .60214 L F
.532 .213 .372 r
.53438 .46819 m .53364 .47027 L .53114 .46854 L F
.53438 .46819 m .53364 .47027 L .53114 .46854 L F
.465 .812 .998 r
.53114 .46854 m .53386 .4671 L .53438 .46819 L F
.763 .642 .728 r
.3195 .6646 m .32101 .66586 L .31704 .66554 L F
.661 .664 .842 r
.32215 .66172 m .32101 .66586 L .3195 .6646 L F
.32215 .66172 m .32374 .66536 L .32101 .66586 L F
.639 .49 .664 r
.32374 .66536 m .32111 .66871 L .32101 .66586 L F
.559 .803 .99 r
.32557 .57745 m .32599 .57512 L .32346 .57578 L F
.32557 .57745 m .32817 .57665 L .32599 .57512 L F
.802 .646 .688 r
.29089 .67811 m .29549 .6784 L .2929 .68168 L F
.76 .581 .655 r
.29549 .6784 m .29721 .68181 L .2929 .68168 L F
0 .101 .594 r
.58414 .43987 m .58213 .43795 L .58157 .43995 L F
.028 0 0 r
.62236 .34106 m .62515 .34072 L .62644 .34013 L F
.362 0 0 r
.62515 .34072 m .62918 .33943 L .62644 .34013 L F
.618 .944 .947 r
.53529 .48806 m .53572 .48855 L .538 .4873 L F
.481 .764 .993 r
.5919 .35806 m .59519 .35931 L .59305 .35954 L F
.687 .372 0 r
.46837 .53598 m .46875 .53719 L .46914 .53574 L F
0 0 0 r
.46757 .53622 m .46837 .53598 L .47029 .53503 L F
.693 .931 .967 r
.47083 .5347 m .46837 .53598 L .46963 .53392 L F
.687 .372 0 r
.46837 .53598 m .46914 .53574 L .46963 .53392 L F
0 0 0 r
.46692 .53651 m .46837 .53598 L .46757 .53622 L F
.339 .79 .644 r
.47029 .53503 m .47083 .5347 L .47339 .53385 L F
.47029 .53503 m .46837 .53598 L .47083 .5347 L F
.827 .826 .349 r
.23882 .59747 m .23826 .59811 L .23973 .59624 L F
.989 .812 .573 r
.28884 .65919 m .28661 .66132 L .28449 .65875 L F
.28884 .65919 m .28872 .6621 L .28661 .66132 L F
.88 .595 .501 r
.3696 .56266 m .37306 .56612 L .37329 .5638 L F
.911 .641 .516 r
.35699 .52982 m .35924 .53369 L .35893 .53099 L F
.496 .557 .847 r
.31674 .54214 m .31826 .54425 L .31622 .5402 L F
.545 .727 .959 r
.31826 .54425 m .32046 .54373 L .31912 .54206 L F
.549 .391 .62 r
.314 .54069 m .31204 .54447 L .3151 .54328 L F
.916 .551 .322 r
.37543 .51753 m .37311 .51657 L .37265 .51416 L F
.777 .339 .212 r
.37543 .51753 m .37307 .51882 L .37311 .51657 L F
.37543 .51753 m .37686 .51991 L .37307 .51882 L F
.827 .991 .866 r
.72407 .31969 m .72044 .32162 L .72065 .32244 L F
.037 .216 .719 r
.55858 .44224 m .55985 .44578 L .55921 .44214 L F
.789 .296 0 r
.55985 .44578 m .55952 .44666 L .55921 .44214 L F
.55985 .44578 m .56123 .44771 L .55952 .44666 L F
.893 .853 .797 r
.36911 .6199 m .37153 .61627 L .36975 .61504 L F
.405 .209 .498 r
.26097 .53669 m .25846 .53753 L .26128 .53374 L F
.241 .062 .427 r
.25967 .53899 m .25846 .53753 L .26097 .53669 L F
.25967 .53899 m .2582 .53985 L .25846 .53753 L F
.58 .62 .857 r
.42491 .57983 m .4212 .57679 L .4232 .57713 L F
.675 .491 .629 r
.69378 .32012 m .69651 .31725 L .6935 .31718 L F
.69378 .32012 m .69772 .32037 L .69651 .31725 L F
.735 .52 .602 r
.69651 .31725 m .69772 .32037 L .70043 .31992 L F
.952 .746 .59 r
.39348 .54669 m .39498 .55055 L .39303 .54935 L F
.87 .66 .617 r
.39521 .55323 m .39303 .54935 L .39498 .55055 L F
.707 .846 .949 r
.6365 .38845 m .634 .38994 L .63263 .38833 L F
0 0 0 r
.62251 .4042 m .62234 .40464 L .62347 .40293 L F
.591 .12 .103 r
.62347 .40293 m .62234 .40464 L .61881 .40288 L F
.95 .938 .741 r
.49536 .53206 m .49762 .5313 L .49656 .5302 L F
.485 .665 .942 r
.29449 .65138 m .29439 .65457 L .29147 .65321 L F
.29449 .65138 m .29686 .65434 L .29439 .65457 L F
0 0 0 r
.52793 .42237 m .52441 .42486 L .52659 .42383 L F
.276 .056 .389 r
.5304 .41887 m .52793 .42237 L .5303 .42132 L F
0 0 0 r
.5303 .42132 m .52793 .42237 L .52659 .42383 L F
.992 .796 .416 r
.53792 .41786 m .53959 .41858 L .53877 .41431 L F
.804 .998 .852 r
.53788 .41975 m .53959 .41858 L .53792 .41786 L F
.354 .437 .808 r
.53877 .41431 m .53959 .41858 L .54242 .41707 L F
.044 0 .194 r
.54242 .41707 m .53959 .41858 L .53993 .42027 L F
.53993 .42027 m .53959 .41858 L .54242 .41707 L F
.8 .966 .912 r
.51856 .43254 m .52055 .43297 L .52194 .43114 L F
.915 .601 .437 r
.35101 .51711 m .35193 .52066 L .35406 .52106 L F
.85 .425 .221 r
.35193 .52066 m .35235 .52238 L .35406 .52106 L F
.876 .471 .252 r
.35406 .52106 m .35235 .52238 L .35462 .5232 L F
.68 .95 .693 r
.61033 .40394 m .61221 .40214 L .61095 .40271 L F
.347 .798 .658 r
.61095 .40271 m .61221 .40214 L .61528 .40056 L F
.673 .787 .935 r
.47691 .44153 m .47924 .44172 L .47837 .43772 L F
.783 .855 .904 r
.47837 .43772 m .47924 .44172 L .48216 .43767 L F
.736 .761 .873 r
.47924 .44172 m .48376 .4395 L .48216 .43767 L F
.577 .828 .459 r
.24745 .58863 m .24622 .59027 L .24889 .58687 L F
.494 .634 .915 r
.31449 .64071 m .31781 .64236 L .31608 .6382 L F
.607 .703 .912 r
.31608 .6382 m .31781 .64236 L .32039 .63935 L F
0 .018 .554 r
.71654 .31346 m .71387 .31024 L .71314 .31024 L F
.748 .965 .935 r
.4789 .4216 m .47698 .42309 L .47448 .42286 L F
.737 .744 .858 r
.31147 .64001 m .31449 .64071 L .31366 .63865 L F
.494 .634 .915 r
.31449 .64071 m .31608 .6382 L .31366 .63865 L F
.988 .847 .613 r
.3242 .52672 m .32256 .5264 L .32309 .52337 L F
.845 .382 .057 r
.3242 .52672 m .3263 .53004 L .32256 .5264 L F
.733 .769 .882 r
.32309 .52337 m .3272 .52494 L .3242 .52672 L F
.98 .71 .441 r
.57863 .42999 m .5802 .42886 L .57896 .42737 L F
.57863 .42999 m .58028 .43158 L .5802 .42886 L F
.944 .709 .552 r
.39665 .55955 m .3948 .55601 L .39648 .5571 L F
.97 .659 .28 r
.41661 .52475 m .41828 .52946 L .41836 .52733 L F
.649 .67 .857 r
.30718 .65732 m .30591 .65989 L .30492 .65646 L F
.30718 .65732 m .30878 .65931 L .30591 .65989 L F
.121 0 .013 r
.64697 .3404 m .6462 .34171 L .64371 .3426 L F
0 0 0 r
.64505 .3428 m .64371 .3426 L .6462 .34171 L F
.533 .603 .869 r
.60118 .38322 m .59683 .38066 L .60033 .38098 L F
.14 0 0 r
.59623 .38081 m .60033 .38098 L .59683 .38066 L F
.563 .936 .844 r
.45247 .43854 m .44811 .44036 L .45147 .43827 L F
.599 .948 .909 r
.45247 .43854 m .45147 .43827 L .45379 .43691 L F
.867 .822 .801 r
.63632 .33764 m .6328 .34065 L .63197 .33896 L F
.63632 .33764 m .63197 .33896 L .63477 .33837 L F
.051 0 0 r
.63477 .33837 m .63876 .33635 L .63632 .33764 L F
.76 .536 .593 r
.32685 .5735 m .32836 .5693 L .32739 .56998 L F
.442 .394 .71 r
.32836 .5693 m .33312 .57312 L .33337 .57045 L F
.981 .737 .494 r
.28747 .59873 m .2892 .59985 L .28728 .60187 L F
.588 .898 .626 r
.28966 .60075 m .28728 .60187 L .2892 .59985 L F
.28966 .60075 m .2892 .59985 L .28747 .59873 L F
0 0 0 r
.40397 .46119 m .399 .46307 L .39936 .4619 L F
.569 .921 .958 r
.67251 .31411 m .67363 .3125 L .67463 .31281 L F
.67251 .31411 m .6704 .31342 L .67363 .3125 L F
.96 .684 .467 r
.62025 .36469 m .62376 .36772 L .62424 .36478 L F
.49 .903 .838 r
.62073 .36836 m .62376 .36772 L .62105 .36822 L F
.62073 .36836 m .62312 .36706 L .62376 .36772 L F
0 .103 .647 r
.62569 .3669 m .62552 .36919 L .62424 .36478 L F
.089 .185 .67 r
.62376 .36772 m .62569 .3669 L .62424 .36478 L F
0 0 .091 r
.62569 .3669 m .62406 .36993 L .62376 .36772 L F
.951 .651 .43 r
.67443 .33575 m .67236 .33522 L .67222 .33273 L F
.887 .457 .106 r
.67443 .33575 m .67433 .33765 L .67236 .33522 L F
.67443 .33575 m .67542 .33831 L .67433 .33765 L F
.888 .913 .836 r
.62319 .40986 m .62445 .41125 L .62704 .40789 L F
.923 .74 .638 r
.50544 .42157 m .50762 .42124 L .50749 .41964 L F
.795 .385 .273 r
.50637 .42288 m .50762 .42124 L .50544 .42157 L F
.444 0 0 r
.50737 .42257 m .50762 .42124 L .50637 .42288 L F
.50737 .42257 m .51016 .42151 L .50762 .42124 L F
.937 .801 .684 r
.69506 .3429 m .69598 .34051 L .69426 .33905 L F
.436 0 0 r
.55719 .38763 m .56099 .38602 L .55855 .38431 L F
.96 .897 .719 r
.28661 .66132 m .28872 .6621 L .28623 .66545 L F
.656 .598 .778 r
.34232 .54698 m .34121 .54852 L .338 .54725 L F
.993 .759 .467 r
.2728 .60275 m .27153 .60583 L .26894 .6026 L F
.2728 .60275 m .27274 .60539 L .27153 .60583 L F
0 0 .254 r
.27361 .60414 m .27274 .60549 L .2728 .60275 L F
.722 .353 .351 r
.26894 .6026 m .27153 .60583 L .26706 .60536 L F
.536 0 0 r
.26706 .60536 m .27153 .60583 L .26951 .6067 L F
.617 .946 .762 r
.27006 .60636 m .27153 .60583 L .27361 .60414 L F
.26951 .6067 m .27153 .60583 L .27006 .60636 L F
.993 .759 .467 r
.27274 .60539 m .27274 .60549 L .27153 .60583 L F
0 0 .254 r
.27361 .60414 m .2728 .60275 L .27541 .60227 L F
.602 .276 .391 r
.66543 .32994 m .66821 .33207 L .66631 .33132 L F
.634 .25 .299 r
.66805 .33044 m .66821 .33207 L .66543 .32994 L F
0 0 .157 r
.24171 .53751 m .24208 .53904 L .24272 .53613 L F
.24171 .53751 m .24081 .53997 L .24208 .53904 L F
.525 .901 .959 r
.44615 .45146 m .44754 .45052 L .44349 .45125 L F
.653 .91 .98 r
.4673 .44436 m .46765 .44177 L .46607 .44388 L F
.4673 .44436 m .47062 .44285 L .46765 .44177 L F
.595 .949 .842 r
.45344 .45 m .45792 .44799 L .45723 .448 L F
.493 .861 .986 r
.45792 .44799 m .46043 .44732 L .45922 .44655 L F
.57 .932 .78 r
.45723 .448 m .45792 .44799 L .45922 .44655 L F
.846 .488 .376 r
.33461 .50228 m .33708 .50057 L .33452 .50051 L F
.33461 .50228 m .33833 .50378 L .33708 .50057 L F
.628 .961 .892 r
.49038 .41158 m .49167 .40984 L .49443 .40923 L F
.49038 .41158 m .4899 .41112 L .49167 .40984 L F
.992 .764 .489 r
.32941 .53002 m .32746 .53057 L .32749 .53009 L F
.067 0 0 r
.33139 .52995 m .32941 .53002 L .3267 .52991 L F
.992 .764 .489 r
.32941 .53002 m .3276 .52762 L .3267 .52991 L F
.32941 .53002 m .32749 .53009 L .3276 .52762 L F
.067 0 0 r
.33182 .52995 m .32941 .53002 L .33139 .52995 L F
.275 .19 .575 r
.33372 .52661 m .33182 .52995 L .33001 .52699 L F
.33372 .52661 m .3342 .52967 L .33182 .52995 L F
.276 .774 .881 r
.3342 .52967 m .32941 .53002 L .33182 .52995 L F
.782 .302 .092 r
.23626 .61822 m .23875 .61915 L .23736 .61724 L F
.912 .571 .383 r
.28999 .67511 m .28783 .6777 L .28982 .67278 L F
.28999 .67511 m .29089 .67811 L .28783 .6777 L F
.804 .979 .696 r
.50544 .42157 m .50749 .41964 L .50847 .41761 L F
.722 .98 .911 r
.35476 .5543 m .35564 .55228 L .35632 .55186 L F
.35476 .5543 m .3514 .55462 L .35564 .55228 L F
.2 0 0 r
.61455 .34938 m .61043 .34892 L .61402 .34926 L F
.503 .901 .932 r
.54862 .43518 m .55121 .43478 L .54951 .43285 L F
.54862 .43518 m .55121 .43478 L .54951 .43285 L F
.453 .806 .997 r
.55219 .43313 m .55121 .43478 L .54951 .43285 L F
.55219 .43313 m .5538 .43423 L .55121 .43478 L F
.55121 .43478 m .55219 .43313 L .54951 .43285 L F
.55121 .43478 m .5538 .43423 L .55219 .43313 L F
.55219 .43313 m .5538 .43423 L .55121 .43478 L F
0 0 0 r
.39296 .49009 m .39542 .48668 L .39399 .48634 L F
.39542 .48668 m .39656 .48666 L .39399 .48634 L F
.795 .733 .795 r
.36229 .62269 m .36692 .62318 L .36475 .62172 L F
.813 .659 .692 r
.36564 .6243 m .36692 .62318 L .36229 .62269 L F
.81 .728 .773 r
.36475 .62172 m .36692 .62318 L .36911 .6199 L F
.396 0 0 r
.25887 .55683 m .25541 .55431 L .25795 .55315 L F
.25887 .55683 m .2545 .55529 L .25541 .55431 L F
.855 .936 .561 r
.25959 .63128 m .25938 .63324 L .26129 .62937 L F
.505 0 0 r
.62224 .37143 m .62158 .37126 L .619 .36928 L F
.484 .899 .822 r
.62406 .36993 m .62224 .37143 L .62552 .36919 L F
.62406 .36993 m .62158 .37126 L .62224 .37143 L F
.516 .349 .593 r
.41139 .56382 m .41409 .56335 L .41392 .5602 L F
.41392 .5602 m .41409 .56335 L .41139 .56382 L F
.098 .068 .532 r
.49443 .442 m .49602 .44378 L .4963 .44076 L F
.49443 .442 m .49495 .44506 L .49602 .44378 L F
.981 .913 .633 r
.33091 .53483 m .32912 .53654 L .3302 .53505 L F
.33091 .53483 m .33008 .53752 L .32912 .53654 L F
.539 .841 .999 r
.41512 .46016 m .41598 .4611 L .41906 .4603 L F
0 0 .457 r
.25409 .61682 m .2558 .6196 L .25477 .61779 L F
.74 .842 .927 r
.25477 .61779 m .2558 .6196 L .2579 .61729 L F
.81 .728 .773 r
.36475 .62172 m .36911 .6199 L .36758 .6185 L F
.893 .853 .797 r
.36911 .6199 m .36975 .61504 L .36758 .6185 L F
.204 0 .221 r
.5304 .41887 m .53268 .41807 L .53329 .41575 L F
.094 0 .09 r
.53268 .41807 m .53577 .41468 L .53329 .41575 L F
.858 .888 .858 r
.65098 .38082 m .65243 .3823 L .65023 .38407 L F
.749 .887 .942 r
.65386 .37869 m .65243 .3823 L .65098 .38082 L F
.65386 .37869 m .65589 .38024 L .65243 .3823 L F
.082 .154 .64 r
.35053 .58353 m .35201 .5825 L .34984 .57966 L F
.681 .285 .291 r
.2929 .68168 m .29721 .68181 L .29514 .68413 L F
.651 .248 .268 r
.29721 .68181 m .29949 .68397 L .29514 .68413 L F
.656 .245 .254 r
.29721 .68181 m .2998 .6824 L .29949 .68397 L F
.898 .662 .573 r
.68215 .30984 m .68182 .31244 L .6851 .31359 L F
.936 .632 .441 r
.68346 .31464 m .6851 .31359 L .68182 .31244 L F
.68346 .31464 m .68518 .3162 L .6851 .31359 L F
.768 .599 .668 r
.68951 .31952 m .6935 .31718 L .68946 .31676 L F
.68951 .31952 m .69378 .32012 L .6935 .31718 L F
.907 .63 .506 r
.47674 .57539 m .47939 .57399 L .47693 .57279 L F
.501 .143 .29 r
.66111 .35886 m .65778 .36328 L .65932 .36066 L F
.59 .44 .646 r
.65889 .36109 m .65778 .36328 L .65963 .36073 L F
.65507 .36292 m .65778 .36328 L .65889 .36109 L F
.879 .808 .776 r
.65889 .36109 m .65778 .36328 L .6576 .3624 L F
.386 .068 .299 r
.65899 .36104 m .6572 .36317 L .65688 .36313 L F
.537 .588 .853 r
.6576 .3624 m .65778 .36328 L .65507 .36292 L F
.386 .068 .299 r
.65889 .36109 m .6576 .3624 L .65507 .36292 L F
.6576 .3624 m .65688 .36313 L .65507 .36292 L F
.65899 .36104 m .65688 .36313 L .65889 .36109 L F
.879 .808 .776 r
.66033 .35824 m .65889 .36109 L .65687 .35885 L F
.65889 .36109 m .6576 .3624 L .65687 .35885 L F
.66077 .35817 m .65778 .36328 L .66033 .35824 L F
.537 .588 .853 r
.65687 .35885 m .6576 .3624 L .65507 .36292 L F
.386 .068 .299 r
.65807 .3623 m .65768 .36323 L .6572 .36317 L F
.65963 .36073 m .65847 .36222 L .65807 .3623 L F
.65847 .36222 m .65768 .36323 L .65807 .3623 L F
.65963 .36073 m .6572 .36317 L .65899 .36104 L F
.501 .143 .29 r
.661 .35865 m .65932 .36066 L .66077 .35817 L F
.66111 .35886 m .65932 .36066 L .661 .35865 L F
.66111 .35886 m .65963 .36073 L .65778 .36328 L F
.66111 .35886 m .66089 .3615 L .65963 .36073 L F
.489 .754 .989 r
.66331 .35759 m .66111 .35886 L .66077 .35817 L F
.043 0 .197 r
.66331 .35759 m .66089 .3615 L .66111 .35886 L F
.934 .637 .455 r
.379 .52091 m .37695 .52251 L .37686 .51991 L F
.379 .52091 m .37911 .52363 L .37695 .52251 L F
.949 .846 .707 r
.59484 .40453 m .59343 .4077 L .59551 .40818 L F
.906 .686 .593 r
.5924 .41065 m .59551 .40818 L .59343 .4077 L F
.5924 .41065 m .59477 .41179 L .59551 .40818 L F
.8 .77 .826 r
.60625 .405 m .61033 .40394 L .60837 .404 L F
.68 .95 .693 r
.61033 .40394 m .61095 .40271 L .60837 .404 L F
.436 0 0 r
.55719 .38763 m .55969 .38786 L .56099 .38602 L F
.582 .582 .818 r
.56099 .38602 m .56374 .38539 L .56173 .38155 L F
.141 0 0 r
.56099 .38602 m .56275 .38678 L .56374 .38539 L F
.56099 .38602 m .55969 .38786 L .56275 .38678 L F
.028 .579 .828 r
.41178 .59647 m .41002 .59592 L .40763 .59564 L F
0 .091 .642 r
.41178 .59647 m .4131 .59697 L .41002 .59592 L F
.41178 .59647 m .41422 .599 L .4131 .59697 L F
.321 .202 .558 r
.39305 .51101 m .39522 .51043 L .39461 .5072 L F
.332 .239 .597 r
.39522 .51043 m .39524 .51287 L .39305 .51101 L F
.321 .202 .558 r
.39305 .51101 m .39522 .51043 L .39461 .5072 L F
.332 .239 .597 r
.39522 .51043 m .39524 .51287 L .39305 .51101 L F
0 .412 .772 r
.58767 .34935 m .58624 .34857 L .58464 .34809 L F
.79 .344 .187 r
.59001 .35012 m .58624 .34857 L .58767 .34935 L F
.59001 .35012 m .59011 .35248 L .58624 .34857 L F
.826 .856 .87 r
.59161 .3527 m .59048 .35406 L .58967 .35242 L F
.79 .344 .187 r
.59011 .35248 m .59011 .35253 L .59005 .35247 L F
.59011 .35248 m .59005 .35247 L .58624 .34857 L F
.826 .856 .87 r
.59294 .35111 m .59161 .3527 L .59032 .35223 L F
.069 0 .19 r
.59088 .35157 m .59011 .35248 L .5901 .35216 L F
.826 .856 .87 r
.59058 .35193 m .59032 .35223 L .59014 .35217 L F
.59294 .35111 m .59032 .35223 L .59058 .35193 L F
.069 0 .19 r
.59184 .35084 m .5901 .35216 L .59001 .35012 L F
.59184 .35084 m .59001 .35012 L .59294 .35111 L F
.627 .608 .811 r
.58743 .34655 m .59004 .35238 L .59111 .35012 L F
.826 .856 .87 r
.59294 .35111 m .59002 .35212 L .58998 .35177 L F
.156 .324 .782 r
.58975 .35217 m .59005 .35247 L .58985 .352 L F
.59005 .35247 m .59004 .35238 L .58995 .35218 L F
.58994 .35223 m .58995 .35218 L .58866 .34929 L F
.59005 .35247 m .58995 .35218 L .58994 .35223 L F
.58624 .34857 m .58975 .35217 L .58866 .34929 L F
.58975 .35217 m .58985 .352 L .58866 .34929 L F
.724 .899 .958 r
.59024 .35082 m .58941 .3519 L .58751 .3508 L F
.826 .856 .87 r
.59014 .35217 m .58967 .35242 L .58941 .3519 L F
.59161 .3527 m .59 .35247 L .59014 .35217 L F
.59 .35247 m .58967 .35242 L .59014 .35217 L F
.069 0 .19 r
.59015 .35245 m .59011 .35253 L .59011 .35248 L F
.59184 .35084 m .59011 .35248 L .59088 .35157 L F
.826 .856 .87 r
.59088 .35157 m .59037 .35168 L .59184 .35084 L F
.627 .608 .811 r
.59111 .35012 m .59049 .35161 L .59184 .35084 L F
.826 .856 .87 r
.59058 .35193 m .59014 .35217 L .5902 .35206 L F
.627 .608 .811 r
.59004 .35238 m .59011 .35253 L .59111 .35012 L F
.826 .856 .87 r
.59037 .35168 m .58998 .35177 L .59184 .35084 L F
.627 .608 .811 r
.59049 .35161 m .59011 .35253 L .59184 .35084 L F
.724 .899 .958 r
.59184 .35084 m .59007 .35161 L .59024 .35082 L F
.59007 .35161 m .58941 .3519 L .59024 .35082 L F
.826 .856 .87 r
.5902 .35206 m .59014 .35217 L .59002 .35212 L F
.59294 .35111 m .59088 .35157 L .59184 .35084 L F
.58998 .35177 m .58941 .3519 L .59007 .35161 L F
.58998 .35177 m .59007 .35161 L .59184 .35084 L F
.156 .324 .782 r
.59005 .35247 m .59011 .35253 L .59004 .35238 L F
.826 .856 .87 r
.58998 .35177 m .59002 .35212 L .58941 .3519 L F
.156 .324 .782 r
.58624 .34857 m .58866 .34929 L .58743 .34655 L F
0 .412 .772 r
.58464 .34809 m .58624 .34857 L .58317 .34748 L F
0 0 0 r
.32739 .56998 m .32423 .57379 L .32685 .5735 L F
.135 .403 .852 r
.57354 .42027 m .57263 .42166 L .57062 .41882 L F
.232 .538 .924 r
.57354 .42027 m .57473 .42218 L .57263 .42166 L F
.709 .976 .763 r
.53698 .47862 m .53807 .47676 L .53886 .47674 L F
.653 .942 .962 r
.53546 .47812 m .53807 .47676 L .53698 .47862 L F
.629 .562 .759 r
.26268 .52936 m .26128 .53374 L .26127 .53194 L F
.676 .542 .693 r
.32111 .66871 m .3219 .67123 L .31851 .6722 L F
.596 .33 .484 r
.31851 .6722 m .32106 .67474 L .3182 .67468 L F
.31851 .6722 m .3219 .67123 L .32106 .67474 L F
.876 .852 .816 r
.4884 .54002 m .49167 .5403 L .49086 .5373 L F
.897 .92 .829 r
.48746 .54262 m .49167 .5403 L .4884 .54002 L F
.48746 .54262 m .48836 .544 L .49167 .5403 L F
.914 .915 .804 r
.49167 .5403 m .49262 .53552 L .49086 .5373 L F
.49167 .5403 m .49413 .53642 L .49262 .53552 L F
.43 .172 .42 r
.3155 .67455 m .31204 .67772 L .31258 .67531 L F
.702 .668 .814 r
.32669 .66438 m .32794 .66579 L .32374 .66536 L F
.71 .545 .664 r
.32794 .66579 m .32517 .66893 L .32374 .66536 L F
.32794 .66579 m .32789 .66883 L .32517 .66893 L F
.724 .672 .799 r
.33014 .66291 m .32794 .66579 L .32669 .66438 L F
.695 .629 .779 r
.33014 .66291 m .33098 .66566 L .32794 .66579 L F
.666 .399 .508 r
.32794 .66579 m .33036 .66838 L .32789 .66883 L F
.32794 .66579 m .33098 .66566 L .33036 .66838 L F
.766 .512 .55 r
.53231 .39046 m .53249 .38915 L .53454 .38973 L F
.511 .912 .831 r
.53442 .38934 m .53231 .39046 L .53454 .38973 L F
.356 .057 .313 r
.53442 .38934 m .53202 .39256 L .53231 .39046 L F
.53202 .39256 m .53173 .39295 L .53231 .39046 L F
.766 .512 .55 r
.53231 .39046 m .52989 .38841 L .53249 .38915 L F
.511 .912 .831 r
.53442 .38934 m .53454 .38973 L .53684 .3885 L F
.796 .304 0 r
.38105 .52727 m .38067 .52858 L .37917 .52604 L F
.38105 .52727 m .38254 .52964 L .38067 .52858 L F
.505 .377 .64 r
.3247 .61043 m .32823 .61201 L .32652 .60826 L F
.3247 .61043 m .32562 .61266 L .32823 .61201 L F
.721 .894 .958 r
.66086 .37619 m .66207 .37754 L .65791 .37902 L F
.677 .853 .966 r
.66354 .3748 m .66207 .37754 L .66086 .37619 L F
.66354 .3748 m .66487 .37624 L .66207 .37754 L F
0 .239 .754 r
.60196 .38192 m .60118 .38322 L .60033 .38098 L F
.60238 .38235 m .60118 .38322 L .60196 .38192 L F
.028 .376 .842 r
.60337 .38307 m .60118 .38322 L .60252 .38224 L F
.60337 .38307 m .60415 .38478 L .60118 .38322 L F
.766 .391 .345 r
.60288 .38524 m .60331 .38332 L .59877 .38227 L F
.60331 .38332 m .60337 .38307 L .60302 .38301 L F
.60331 .38332 m .60302 .38301 L .59877 .38227 L F
0 .239 .754 r
.60252 .38224 m .60238 .38235 L .60196 .38192 L F
.915 .713 .216 r
.49532 .44787 m .49499 .44866 L .49495 .44506 L F
.787 .768 .258 r
.49493 .44848 m .49499 .44866 L .49532 .44787 L F
.749 .703 .808 r
.49495 .44506 m .49532 .44787 L .49864 .44457 L F
.117 0 .156 r
.49864 .44457 m .49532 .44787 L .49495 .44506 L F
.49864 .44457 m .49786 .44718 L .49532 .44787 L F
.095 0 .089 r
.49532 .44787 m .49689 .4489 L .49493 .44848 L F
.49532 .44787 m .49786 .44718 L .49689 .4489 L F
0 0 0 r
.40397 .46119 m .40155 .46229 L .399 .46307 L F
.028 0 0 r
.40575 .46177 m .40155 .46229 L .40397 .46119 L F
.197 .671 .936 r
.60723 .39724 m .61119 .39823 L .60862 .39806 L F
0 .326 .697 r
.61345 .40026 m .60862 .39806 L .61119 .39823 L F
.942 .577 .208 r
.56034 .43168 m .56228 .43518 L .5599 .43451 L F
.841 .73 .741 r
.56228 .43518 m .56124 .43687 L .5599 .43451 L F
0 .018 .554 r
.71563 .31236 m .71547 .31196 L .71387 .31024 L F
.632 .961 .821 r
.71523 .31133 m .71547 .31196 L .71442 .31194 L F
.957 .89 .723 r
.7154 .30701 m .71387 .31024 L .71418 .30555 L F
.967 .879 .492 r
.71418 .30555 m .71387 .31024 L .71337 .30861 L F
.232 .429 .85 r
.71337 .30861 m .71547 .31196 L .71696 .31003 L F
.632 .961 .821 r
.71696 .31003 m .71547 .31196 L .71523 .31133 L F
0 .018 .554 r
.71654 .31346 m .71547 .31196 L .71563 .31236 L F
.781 .907 .928 r
.71299 .31429 m .71547 .31196 L .71654 .31346 L F
.287 .362 .766 r
.33827 .52845 m .34048 .53002 L .33881 .53037 L F
.156 0 .227 r
.34019 .532 m .33881 .53037 L .34048 .53002 L F
.34019 .532 m .33821 .53324 L .33881 .53037 L F
.529 .446 .705 r
.25139 .57373 m .25251 .57661 L .24983 .57703 L F
.533 .472 .733 r
.24983 .57703 m .25251 .57661 L .25093 .57295 L F
.253 0 0 r
.52253 .38444 m .52487 .3843 L .52601 .38274 L F
.554 .09 .107 r
.52601 .38274 m .52487 .3843 L .52754 .38372 L F
.671 .948 .957 r
.54755 .48139 m .54644 .48071 L .54297 .48259 L F
.789 .978 .908 r
.54755 .48139 m .55087 .47886 L .54817 .47909 L F
.788 .977 .909 r
.54817 .47909 m .54644 .48071 L .54755 .48139 L F
.776 .877 .921 r
.62551 .4064 m .62704 .40789 L .62613 .40555 L F
.888 .913 .836 r
.62319 .40986 m .62704 .40789 L .62551 .4064 L F
.84 .903 .882 r
.62613 .40555 m .62704 .40789 L .62978 .40518 L F
.685 .247 .204 r
.26129 .62937 m .2569 .62879 L .2608 .62905 L F
.699 .983 .856 r
.26188 .62779 m .26129 .62937 L .2608 .62905 L F
.728 .906 .535 r
.25959 .63128 m .26129 .62937 L .26188 .62779 L F
.158 0 .365 r
.58539 .34507 m .58317 .34748 L .58208 .34551 L F
.58539 .34507 m .58534 .34643 L .58317 .34748 L F
.465 .398 .697 r
.58317 .34748 m .58539 .34507 L .58208 .34551 L F
.453 .881 .802 r
.42877 .45715 m .42663 .458 L .4261 .45856 L F
0 0 0 r
.42665 .45873 m .4261 .45856 L .42663 .458 L F
.629 .615 .818 r
.32501 .64191 m .32574 .6455 L .32881 .64288 L F
0 0 0 r
.24605 .59664 m .2453 .59758 L .24436 .59853 L F
.2453 .59758 m .24334 .60005 L .24436 .59853 L F
0 0 .333 r
.24355 .59935 m .24436 .59853 L .24351 .59997 L F
.24375 .59593 m .24436 .59853 L .24355 .59935 L F
.652 .884 .531 r
.24436 .59853 m .24224 .60128 L .24351 .59997 L F
.477 .211 .431 r
.5304 .41887 m .53299 .42057 L .53268 .41807 L F
.5304 .41887 m .5303 .42132 L .53299 .42057 L F
.771 .997 .819 r
.51166 .51003 m .51538 .50758 L .51486 .50696 L F
.51166 .51003 m .51226 .51029 L .51538 .50758 L F
.876 .985 .708 r
.51721 .50345 m .51538 .50758 L .51783 .50401 L F
.51721 .50345 m .51486 .50696 L .51538 .50758 L F
.385 .183 .479 r
.59731 .39375 m .59687 .39272 L .59941 .39201 L F
.838 .999 .816 r
.50379 .44383 m .50744 .44125 L .50626 .4429 L F
0 0 .3 r
.50744 .44125 m .50981 .43715 L .50999 .4407 L F
0 0 0 r
.50626 .4429 m .50744 .44125 L .50999 .4407 L F
.646 .909 .981 r
.34579 .63962 m .34894 .63905 L .34723 .63814 L F
.664 .759 .921 r
.34894 .63905 m .35004 .6352 L .34723 .63814 L F
.34894 .63905 m .35043 .6384 L .35004 .6352 L F
.721 .894 .958 r
.66086 .37619 m .65791 .37902 L .65803 .37853 L F
.3 .151 .505 r
.51066 .40986 m .51065 .41107 L .50818 .41236 L F
.225 .068 .448 r
.51065 .41107 m .50821 .41509 L .50818 .41236 L F
0 0 0 r
.25218 .55693 m .25108 .55994 L .25063 .56044 L F
0 0 .309 r
.25108 .55994 m .2511 .56196 L .25063 .56044 L F
.596 .944 .79 r
.68101 .37492 m .68483 .37285 L .6828 .37322 L F
.677 .974 .807 r
.68639 .37074 m .68483 .37285 L .68649 .37137 L F
.678 .978 .857 r
.6828 .37322 m .68483 .37285 L .68639 .37074 L F
.973 .927 .666 r
.33008 .53752 m .32826 .53843 L .32912 .53654 L F
.64 .129 .015 r
.33008 .53752 m .33235 .53935 L .32826 .53843 L F
.782 .576 .622 r
.32618 .54405 m .32308 .5451 L .32484 .54386 L F
.142 .247 .713 r
.56947 .37862 m .57046 .38266 L .56994 .38148 L F
.815 .727 .768 r
.63845 .34949 m .63512 .34867 L .63743 .34592 L F
0 .483 .748 r
.63845 .34949 m .63798 .34926 L .63512 .34867 L F
.208 .33 .769 r
.63743 .34592 m .63995 .34751 L .63845 .34949 L F
.66 .96 .755 r
.63995 .34751 m .63798 .34926 L .63845 .34949 L F
.942 .725 .58 r
.45595 .57998 m .45377 .58347 L .45245 .58335 L F
.45595 .57998 m .45401 .58313 L .45582 .58287 L F
0 0 0 r
.45724 .57927 m .45595 .57998 L .45891 .57899 L F
.528 0 0 r
.45401 .58313 m .45417 .58382 L .45582 .58287 L F
0 0 0 r
.454 .58319 m .45391 .5833 L .45401 .58313 L F
.362 0 0 r
.45377 .58347 m .45417 .58382 L .45245 .58335 L F
.528 0 0 r
.45245 .58335 m .45388 .58374 L .45401 .58313 L F
.546 .512 .769 r
.4539 .58323 m .45417 .58382 L .45377 .58347 L F
.528 0 0 r
.45396 .58337 m .45417 .58382 L .45401 .58313 L F
0 0 0 r
.45724 .57927 m .454 .58319 L .45595 .57998 L F
.454 .58319 m .45401 .58313 L .45595 .57998 L F
.45391 .5833 m .45377 .58347 L .45595 .57998 L F
.942 .725 .58 r
.45595 .57998 m .45245 .58335 L .45401 .58313 L F
.803 .994 .76 r
.4555 .5803 m .45377 .58347 L .45724 .57927 L F
.546 .512 .769 r
.4555 .5803 m .45417 .58382 L .4539 .58323 L F
.528 0 0 r
.45388 .58374 m .45417 .58382 L .45396 .58337 L F
.607 .955 .866 r
.49443 .40923 m .4964 .40691 L .49584 .40764 L F
.49443 .40923 m .49167 .40984 L .4964 .40691 L F
.618 .864 .989 r
.54571 .44984 m .54472 .45218 L .5471 .45105 L F
.222 .639 .955 r
.34159 .53634 m .34012 .53671 L .33923 .53631 L F
.34159 .53634 m .34342 .53715 L .34012 .53671 L F
0 0 0 r
.59714 .34448 m .59655 .34544 L .59722 .34479 L F
.333 0 0 r
.59681 .34326 m .59714 .34448 L .59956 .34319 L F
0 0 0 r
.59956 .34319 m .6021 .3425 L .60216 .34377 L F
.59956 .34319 m .59714 .34448 L .6021 .3425 L F
.6016 .3427 m .60019 .3419 L .6021 .3425 L F
.813 .895 .901 r
.59833 .34083 m .59834 .3408 L .60019 .3419 L F
.614 .297 .41 r
.59835 .34081 m .60019 .3419 L .59834 .3408 L F
0 0 0 r
.59714 .34448 m .60019 .3419 L .60157 .34271 L F
.59714 .34448 m .59722 .34479 L .60019 .3419 L F
.333 0 0 r
.59533 .3433 m .59714 .34448 L .59681 .34326 L F
.347 0 0 r
.59166 .34319 m .59533 .3433 L .59459 .34375 L F
.59166 .34319 m .59459 .34375 L .59339 .34447 L F
.135 0 .33 r
.58894 .34394 m .58989 .34284 L .59166 .34319 L F
.58782 .34426 m .58989 .34284 L .58894 .34394 L F
.758 .344 .266 r
.58989 .34284 m .59025 .34292 L .59166 .34319 L F
.59025 .34292 m .59419 .34374 L .59166 .34319 L F
.347 0 0 r
.59166 .34319 m .59419 .34374 L .59533 .3433 L F
.124 .638 .893 r
.59088 .3442 m .59655 .34544 L .59419 .34374 L F
.59108 .34436 m .59655 .34544 L .59088 .3442 L F
.758 .344 .266 r
.58989 .34284 m .59088 .3442 L .59419 .34374 L F
.603 .482 .687 r
.59456 .34099 m .59147 .34349 L .59145 .34088 L F
.521 .313 .538 r
.58989 .34284 m .59148 .34396 L .59147 .34349 L F
.59046 .34213 m .59147 .34349 L .59145 .34088 L F
.58989 .34284 m .59147 .34349 L .59046 .34213 L F
.649 .282 .335 r
.59419 .34374 m .59714 .34448 L .59533 .3433 L F
.603 .482 .687 r
.59255 .34393 m .59441 .34471 L .59219 .34445 L F
.649 .282 .335 r
.59419 .34374 m .59655 .34544 L .59714 .34448 L F
.603 .482 .687 r
.59456 .34099 m .59442 .34443 L .59255 .34393 L F
.59442 .34443 m .59441 .34471 L .59255 .34393 L F
.521 .313 .538 r
.59088 .3442 m .59081 .34434 L .59099 .34436 L F
.58993 .34344 m .59009 .34583 L .59088 .3442 L F
.124 .638 .893 r
.59052 .34425 m .59108 .34436 L .59088 .3442 L F
.59321 .34478 m .59441 .34471 L .59655 .34544 L F
.59167 .34448 m .59369 .34465 L .59321 .34478 L F
.59369 .34465 m .59441 .34471 L .59321 .34478 L F
.59224 .34446 m .59441 .34471 L .59108 .34436 L F
.585 .467 .684 r
.59834 .3408 m .59441 .34471 L .59456 .34099 L F
0 0 .305 r
.59282 .3449 m .59373 .34466 L .59473 .34437 L F
.59393 .34459 m .59473 .34437 L .59556 .34412 L F
.59282 .3449 m .59473 .34437 L .59393 .34459 L F
.124 .638 .893 r
.59108 .34436 m .59201 .34446 L .59167 .34448 L F
.59201 .34446 m .59441 .34471 L .59167 .34448 L F
.521 .313 .538 r
.58989 .34284 m .59167 .34529 L .59282 .3449 L F
.603 .482 .687 r
.59147 .34349 m .59219 .34445 L .59052 .34425 L F
.59456 .34099 m .59219 .34445 L .59147 .34349 L F
.521 .313 .538 r
.58989 .34284 m .58993 .34344 L .59088 .3442 L F
.758 .344 .266 r
.58989 .34284 m .59052 .34425 L .59088 .3442 L F
.603 .482 .687 r
.59147 .34349 m .59052 .34425 L .59145 .34088 L F
.521 .313 .538 r
.59148 .34396 m .59218 .34445 L .59145 .34088 L F
.59218 .34445 m .59282 .3449 L .59266 .34443 L F
.59218 .34445 m .59266 .34443 L .59145 .34088 L F
.124 .638 .893 r
.59052 .34425 m .59224 .34446 L .59108 .34436 L F
.521 .313 .538 r
.59099 .34436 m .59009 .34583 L .59167 .34529 L F
.59081 .34434 m .59009 .34583 L .59099 .34436 L F
0 .003 .504 r
.59145 .34088 m .59139 .34111 L .58989 .34284 L F
.59139 .34111 m .59052 .34425 L .58989 .34284 L F
.813 .895 .901 r
.59655 .34544 m .59833 .34083 L .60019 .3419 L F
.614 .297 .41 r
.59945 .34372 m .60019 .3419 L .59835 .34081 L F
0 0 0 r
.60157 .34271 m .60019 .3419 L .6016 .3427 L F
.68 .548 .697 r
.32374 .66536 m .32517 .66893 L .32111 .66871 L F
.638 .466 .634 r
.32517 .66893 m .3219 .67123 L .32111 .66871 L F
.785 .741 .812 r
.31774 .66098 m .3195 .6646 L .31704 .66554 L F
.671 .69 .86 r
.32215 .66172 m .3195 .6646 L .31774 .66098 L F
.667 .691 .863 r
.51314 .43396 m .51461 .43049 L .51119 .43333 L F
.51314 .43396 m .51598 .43322 L .51461 .43049 L F
.514 .518 .798 r
.33319 .66478 m .33098 .66566 L .33014 .66291 L F
.571 .39 .597 r
.33319 .66478 m .33036 .66838 L .33098 .66566 L F
.477 .488 .791 r
.3358 .5853 m .33483 .58987 L .33325 .58669 L F
.3358 .5853 m .33754 .59038 L .33483 .58987 L F
.225 0 0 r
.64882 .39898 m .65293 .39929 L .6514 .39949 L F
.54 .925 .826 r
.6514 .39949 m .65293 .39929 L .65523 .39784 L F
.319 .801 .751 r
.44964 .59728 m .45009 .59684 L .44781 .59823 L F
.44964 .59728 m .45215 .59634 L .45009 .59684 L F
.68 .466 .589 r
.27204 .52086 m .27178 .52364 L .268 .52277 L F
.539 .271 .458 r
.27464 .5208 m .27178 .52364 L .27204 .52086 L F
.978 .741 .51 r
.39887 .56359 m .3967 .56555 L .39741 .56267 L F
.39887 .56359 m .39844 .56672 L .3967 .56555 L F
.64 .868 .984 r
.64913 .38593 m .6458 .38588 L .64921 .38521 L F
.134 0 0 r
.6477 .38639 m .64921 .38521 L .6458 .38588 L F
.757 .949 .626 r
.64928 .38462 m .64921 .38521 L .6477 .38639 L F
.65052 .38323 m .64921 .38521 L .64928 .38462 L F
.64 .868 .984 r
.6498 .38595 m .64913 .38593 L .64921 .38521 L F
0 0 0 r
.65023 .38407 m .6498 .38595 L .65052 .38323 L F
.847 .998 .805 r
.65052 .38323 m .6498 .38595 L .64921 .38521 L F
.493 .843 .995 r
.3347 .57362 m .3353 .57207 L .33312 .57312 L F
.3347 .57362 m .33711 .57296 L .3353 .57207 L F
.197 0 .215 r
.46145 .58903 m .45839 .59247 L .46061 .59034 L F
0 0 .017 r
.46204 .59029 m .46145 .58903 L .46397 .58886 L F
.845 .805 .812 r
.51578 .42045 m .51509 .42732 L .51271 .4203 L F
.486 .886 .736 r
.51509 .42732 m .51596 .42626 L .51436 .42785 L F
.062 .611 .833 r
.24372 .58612 m .2466 .5864 L .24889 .58687 L F
.879 .513 .348 r
.2466 .5864 m .24745 .58863 L .24889 .58687 L F
.2466 .5864 m .24745 .58863 L .24889 .58687 L F
.272 .061 .399 r
.23692 .55054 m .23857 .55017 L .23914 .5473 L F
.407 .316 .64 r
.23724 .55323 m .23857 .55017 L .23692 .55054 L F
.453 .267 .538 r
.69939 .31331 m .70208 .31265 L .70169 .31017 L F
.595 .626 .852 r
.30049 .65585 m .29833 .657 L .29686 .65434 L F
.528 .843 .999 r
.34961 .56165 m .3496 .5603 L .3478 .56057 L F
.34961 .56165 m .35102 .56134 L .3496 .5603 L F
.878 .684 .637 r
.37486 .57282 m .37654 .57655 L .37709 .57375 L F
.887 .651 .577 r
.5809 .43803 m .58291 .43525 L .58033 .43428 L F
.5809 .43803 m .58213 .43795 L .58291 .43525 L F
.608 .951 .81 r
.58536 .43726 m .58291 .43525 L .58213 .43795 L F
.046 .57 .866 r
.38579 .46065 m .38821 .46111 L .38566 .46039 L F
.849 .923 .88 r
.57136 .45395 m .57563 .45206 L .57398 .4505 L F
.85 .836 .831 r
.57563 .45206 m .57668 .44723 L .57398 .4505 L F
.57563 .45206 m .5784 .44879 L .57668 .44723 L F
.827 .991 .866 r
.72407 .31969 m .72351 .31865 L .72044 .32162 L F
.989 .875 .623 r
.72407 .31969 m .72382 .31591 L .72351 .31865 L F
.817 1 .82 r
.51837 .5016 m .51783 .50401 L .52141 .5017 L F
.51837 .5016 m .51721 .50345 L .51783 .50401 L F
0 .262 .725 r
.41593 .59949 m .41557 .59865 L .41422 .599 L F
.591 .051 0 r
.64143 .34655 m .63995 .34751 L .63743 .34592 L F
.666 .932 .646 r
.64289 .34442 m .63995 .34751 L .64143 .34655 L F
.34 .702 .983 r
.62813 .38811 m .62731 .38929 L .62553 .39074 L F
.62813 .38811 m .62992 .38948 L .62731 .38929 L F
.629 .562 .759 r
.26268 .52936 m .26425 .53375 L .26128 .53374 L F
.557 .337 .538 r
.26365 .53606 m .26128 .53374 L .26425 .53375 L F
.26365 .53606 m .26097 .53669 L .26128 .53374 L F
.555 .591 .845 r
.6472 .36146 m .64567 .36629 L .64439 .36484 L F
.6472 .36146 m .64841 .36576 L .64567 .36629 L F
.394 .755 .993 r
.64841 .36576 m .64439 .36484 L .64567 .36629 L F
.939 .918 .766 r
.55208 .46856 m .55278 .46367 L .55357 .46463 L F
.988 .877 .628 r
.5533 .46144 m .55357 .46463 L .55278 .46367 L F
0 0 .469 r
.57042 .38092 m .57046 .38266 L .56947 .37862 L F
.761 .644 .732 r
.69772 .32037 m .69766 .32324 L .70043 .31992 L F
.724 .587 .701 r
.69766 .32324 m .70156 .32377 L .70043 .31992 L F
.637 .538 .726 r
.70043 .31992 m .70426 .32012 L .703 .31637 L F
.611 .52 .727 r
.70043 .31992 m .70442 .32298 L .70426 .32012 L F
.70043 .31992 m .70156 .32377 L .70442 .32298 L F
.961 .945 .684 r
.66913 .36881 m .6666 .37129 L .66874 .36772 L F
.66913 .36881 m .66734 .37246 L .6666 .37129 L F
.724 .586 .701 r
.69766 .32324 m .69924 .32706 L .70156 .32377 L F
.489 0 0 r
.60164 .39943 m .59723 .39658 L .59847 .39618 L F
.763 .829 .903 r
.60287 .39565 m .60164 .39943 L .59847 .39618 L F
.60287 .39565 m .6042 .39752 L .60164 .39943 L F
.692 .831 .95 r
.54679 .46988 m .54813 .47159 L .54518 .47147 L F
.81 .868 .89 r
.55208 .46856 m .54813 .47159 L .54679 .46988 L F
.125 .674 .79 r
.64212 .39879 m .6462 .39864 L .64477 .39859 L F
.105 0 0 r
.6462 .39864 m .64786 .39889 L .64477 .39859 L F
.6462 .39864 m .64882 .39898 L .64786 .39889 L F
.956 .66 .436 r
.38453 .53311 m .38254 .52964 L .38498 .53069 L F
0 0 .169 r
.28378 .58947 m .28429 .59199 L .28651 .58943 L F
.28378 .58947 m .28365 .59338 L .28429 .59199 L F
.961 .917 .721 r
.71164 .313 m .71433 .31285 L .70831 .31245 L F
.71164 .313 m .71299 .31429 L .71433 .31285 L F
.555 .296 .479 r
.31204 .67772 m .30884 .68146 L .30923 .67883 L F
.703 .169 0 r
.36053 .50447 m .35919 .50522 L .357 .50304 L F
.695 .159 0 r
.36053 .50447 m .36275 .50658 L .35919 .50522 L F
.702 .185 0 r
.36523 .50705 m .36275 .50658 L .36053 .50447 L F
.899 .918 .825 r
.51787 .48776 m .51536 .49119 L .51396 .49006 L F
.417 .212 .492 r
.29532 .55032 m .29763 .54967 L .29792 .54698 L F
.29792 .54698 m .29763 .54967 L .29532 .55032 L F
.979 .754 .529 r
.29873 .58334 m .29978 .58667 L .29794 .58543 L F
.588 .517 .742 r
.30235 .58618 m .29978 .58667 L .30168 .58295 L F
.983 .767 .361 r
.30203 .5887 m .30235 .58618 L .29978 .58667 L F
.588 .517 .742 r
.30235 .58618 m .29978 .58667 L .30168 .58295 L F
.508 .246 .452 r
.30235 .58618 m .30203 .5887 L .29978 .58667 L F
.693 .271 .24 r
.3151 .54328 m .31242 .54547 L .31369 .54551 L F
0 0 .401 r
.3151 .54328 m .31491 .54628 L .31536 .54286 L F
.3151 .54328 m .31592 .54559 L .31491 .54628 L F
.693 .271 .24 r
.3151 .54328 m .31369 .54551 L .31592 .54559 L F
0 0 .401 r
.3151 .54328 m .31536 .54286 L .31537 .54281 L F
0 0 0 r
.50565 .40131 m .50763 .40084 L .5092 .39972 L F
.50565 .40131 m .50389 .40261 L .50763 .40084 L F
.77 .577 .638 r
.68951 .31952 m .69093 .32268 L .69378 .32012 L F
.735 .519 .6 r
.69093 .32268 m .69378 .32296 L .69378 .32012 L F
.763 .542 .598 r
.69378 .32012 m .69766 .32324 L .69772 .32037 L F
.69378 .32012 m .69378 .32296 L .69766 .32324 L F
.562 .465 .703 r
.29348 .63603 m .29371 .63858 L .29609 .63557 L F
.614 .591 .804 r
.59893 .43423 m .59992 .43088 L .5976 .4337 L F
.59893 .43423 m .60216 .43495 L .59992 .43088 L F
.192 .208 .648 r
.59847 .39618 m .59723 .39658 L .59731 .39375 L F
.861 .779 .769 r
.31622 .5402 m .3151 .54328 L .31674 .54214 L F
.706 .692 .834 r
.32612 .66226 m .32374 .66536 L .32215 .66172 L F
.32612 .66226 m .32669 .66438 L .32374 .66536 L F
.683 .339 .386 r
.39331 .45722 m .3977 .45687 L .39772 .45509 L F
.384 .105 .361 r
.3977 .45687 m .39993 .45619 L .39772 .45509 L F
.664 .942 .962 r
.4422 .5653 m .44239 .56607 L .4397 .56709 L F
.61 .911 .981 r
.44459 .56477 m .44239 .56607 L .4422 .5653 L F
0 0 0 r
.42839 .4496 m .42736 .44918 L .42585 .45049 L F
.42839 .4496 m .42987 .44838 L .42736 .44918 L F
.896 .843 .784 r
.72398 .3099 m .72438 .30608 L .72352 .30874 L F
.958 .72 .271 r
.72336 .31141 m .72398 .3099 L .72352 .30874 L F
.72336 .31141 m .72417 .31288 L .72398 .3099 L F
.467 .836 .589 r
.57955 .35906 m .58088 .35794 L .58216 .35943 L F
.561 .928 .93 r
.28004 .51257 m .28039 .51112 L .28234 .51134 L F
.28004 .51257 m .27784 .51239 L .28039 .51112 L F
0 0 .077 r
.25305 .55793 m .25218 .55693 L .2545 .55529 L F
.25305 .55793 m .25108 .55994 L .25218 .55693 L F
.819 .724 .76 r
.56124 .43687 m .55752 .43764 L .5599 .43451 L F
.816 .688 .723 r
.56124 .43687 m .55858 .44224 L .55752 .43764 L F
.673 .787 .935 r
.47691 .44153 m .47837 .43772 L .47519 .44008 L F
.577 .069 0 r
.57332 .38423 m .57694 .38794 L .57467 .38571 L F
.98 .913 .648 r
.5576 .39196 m .55625 .39534 L .55564 .39409 L F
.168 .689 .881 r
.60216 .34377 m .60516 .34356 L .6062 .34416 L F
.153 0 0 r
.60516 .34356 m .60916 .34411 L .6062 .34416 L F
.426 0 0 r
.52738 .43998 m .52456 .43892 L .52407 .44105 L F
.941 .715 .243 r
.69565 .34981 m .69486 .34534 L .69436 .34808 L F
.994 .751 .421 r
.69506 .35172 m .69565 .34981 L .69436 .34808 L F
.071 .265 .755 r
.41392 .5602 m .4167 .56273 L .415 .55864 L F
.486 .327 .59 r
.4167 .56273 m .41392 .5602 L .415 .55864 L F
.4167 .56273 m .41409 .56335 L .41392 .5602 L F
.41392 .5602 m .41409 .56335 L .4167 .56273 L F
.825 .601 .599 r
.68537 .31866 m .68946 .31676 L .68518 .3162 L F
.68537 .31866 m .68951 .31952 L .68946 .31676 L F
.764 .684 .774 r
.48636 .54977 m .49055 .55034 L .48943 .54676 L F
.771 .663 .744 r
.48636 .54977 m .48794 .5536 L .49055 .55034 L F
.935 .825 .712 r
.69684 .32884 m .69874 .32938 L .69924 .32706 L F
.935 .824 .71 r
.697 .33327 m .69874 .32938 L .69684 .32884 L F
.06 0 .407 r
.51263 .41563 m .5145 .41669 L .51518 .41484 L F
.51263 .41563 m .5125 .41842 L .5145 .41669 L F
.905 .718 .639 r
.60303 .4326 m .60175 .42893 L .59992 .43088 L F
.838 .672 .677 r
.59992 .43088 m .60216 .43495 L .60303 .4326 L F
.527 .225 .397 r
.2998 .6824 m .30196 .68455 L .29949 .68397 L F
.2998 .6824 m .30406 .6808 L .30196 .68455 L F
.23 .424 .846 r
.56237 .3673 m .56555 .37124 L .56202 .36973 L F
.085 .43 .872 r
.56202 .36973 m .56555 .37124 L .56566 .37257 L F
.833 .751 .234 r
.56555 .37124 m .5655 .37092 L .56566 .37257 L F
0 0 .505 r
.56672 .37292 m .56566 .37257 L .5655 .37092 L F
.56672 .37292 m .56721 .37522 L .56566 .37257 L F
.837 .966 .641 r
.52017 .48416 m .51787 .48776 L .51844 .48536 L F
.68 .934 .641 r
.52144 .4821 m .52017 .48416 L .51844 .48536 L F
0 0 .18 r
.58794 .40104 m .58782 .40247 L .58812 .40487 L F
.638 .466 .634 r
.32517 .66893 m .32461 .67125 L .3219 .67123 L F
.592 .258 .373 r
.3219 .67123 m .32358 .6743 L .32106 .67474 L F
.3219 .67123 m .32461 .67125 L .32358 .6743 L F
.923 .948 .606 r
.43876 .56927 m .43794 .56906 L .4397 .56709 L F
.495 .194 .385 r
.43794 .56906 m .4422 .5653 L .4397 .56709 L F
.817 .999 .84 r
.30476 .54784 m .30592 .54494 L .30757 .54689 L F
.30476 .54784 m .30238 .54823 L .30592 .54494 L F
.885 .857 .809 r
.48493 .52409 m .48262 .5277 L .48077 .52635 L F
.742 .598 .696 r
.45927 .55676 m .46031 .55628 L .45653 .55611 L F
.742 .568 .658 r
.45653 .55611 m .46031 .55628 L .45845 .56033 L F
.899 .918 .825 r
.51787 .48776 m .51396 .49006 L .51725 .48719 L F
.822 1 .819 r
.51844 .48536 m .51787 .48776 L .51725 .48719 L F
.738 .973 .927 r
.33467 .54453 m .3382 .54365 L .33668 .54254 L F
0 0 .021 r
.46027 .55063 m .46118 .54936 L .46207 .54669 L F
.304 0 .037 r
.45793 .55181 m .46027 .55063 L .4591 .55227 L F
.45793 .55181 m .46118 .54936 L .46027 .55063 L F
.178 0 .377 r
.34627 .58919 m .34639 .59137 L .34644 .59125 L F
.843 .479 .364 r
.34611 .58711 m .34627 .58919 L .34783 .58825 L F
.594 .925 .706 r
.34783 .58825 m .34627 .58919 L .34807 .58755 L F
.178 0 .377 r
.34627 .58919 m .34644 .59125 L .34807 .58755 L F
.843 .479 .364 r
.34428 .5859 m .34627 .58919 L .34611 .58711 L F
.594 .925 .706 r
.34783 .58825 m .34854 .58604 L .35102 .58648 L F
.34783 .58825 m .34807 .58755 L .34854 .58604 L F
.736 .315 .249 r
.70463 .31173 m .70831 .31245 L .70866 .31108 L F
.882 .788 .752 r
.35669 .50092 m .35436 .50052 L .35537 .49795 L F
.825 .406 .247 r
.35669 .50092 m .3548 .50228 L .35436 .50052 L F
.822 .769 .803 r
.35923 .49788 m .35669 .50092 L .35537 .49795 L F
.901 .537 .34 r
.357 .50304 m .3548 .50228 L .35669 .50092 L F
.42 .174 .434 r
.27705 .52249 m .27464 .5208 L .27832 .52009 L F
.362 .099 .374 r
.28117 .51731 m .28075 .51937 L .27832 .52009 L F
0 0 0 r
.28075 .51937 m .27705 .52249 L .27832 .52009 L F
.65023 .38407 m .65052 .38323 L .65098 .38082 L F
.332 .158 .489 r
.23555 .56041 m .23746 .55989 L .23752 .55708 L F
.28 .179 .557 r
.23595 .56319 m .23746 .55989 L .23555 .56041 L F
.879 .576 .47 r
.3643 .54886 m .36665 .54706 L .36411 .54615 L F
.3643 .54886 m .36672 .54964 L .36665 .54706 L F
.233 .073 .448 r
.2582 .53985 m .2586 .54357 L .25624 .54373 L F
.244 .148 .542 r
.2586 .54357 m .25806 .54579 L .25624 .54373 L F
.32 .159 .501 r
.25624 .54373 m .25806 .54579 L .2561 .5465 L F
.905 .982 .778 r
.67564 .34351 m .6734 .34442 L .67442 .34192 L F
.67564 .34351 m .67394 .34573 L .6734 .34442 L F
.539 .271 .458 r
.27464 .5208 m .27446 .52323 L .27178 .52364 L F
.42 .174 .434 r
.27705 .52249 m .27446 .52323 L .27464 .5208 L F
.915 .805 .723 r
.43876 .56927 m .43512 .57178 L .43794 .56906 L F
.43876 .56927 m .43701 .57318 L .43512 .57178 L F
.822 .769 .803 r
.35923 .49788 m .35537 .49795 L .35773 .4958 L F
.833 .796 .816 r
.36197 .49452 m .35923 .49788 L .35773 .4958 L F
.925 .974 .732 r
.6734 .34442 m .67394 .34573 L .67355 .34662 L F
.919 .838 .385 r
.67355 .34662 m .67262 .34684 L .6734 .34442 L F
.67355 .34662 m .67289 .34928 L .67262 .34684 L F
.763 .861 .425 r
.57651 .40118 m .57755 .39913 L .57654 .40057 L F
.966 .641 .288 r
.57654 .40057 m .57755 .39913 L .57603 .3977 L F
.282 .612 .956 r
.36933 .47052 m .37175 .47237 L .36777 .47332 L F
.963 .732 .543 r
.36777 .47332 m .37175 .47237 L .36948 .47589 L F
.328 .157 .49 r
.37271 .47102 m .3733 .47346 L .37175 .47237 L F
.532 .04 .033 r
.37175 .47237 m .37126 .47464 L .36948 .47589 L F
.37175 .47237 m .3733 .47346 L .37126 .47464 L F
.287 0 0 r
.63332 .34399 m .62935 .34499 L .63057 .3446 L F
.536 .252 .431 r
.52107 .42756 m .52441 .42486 L .5215 .42565 L F
.158 .175 .627 r
.619 .36928 m .62025 .36469 L .61828 .36461 L F
.619 .36928 m .62105 .36822 L .62025 .36469 L F
.625 .072 0 r
.619 .36928 m .62073 .36836 L .62088 .36831 L F
.619 .36928 m .62158 .37126 L .61851 .37049 L F
.619 .36928 m .61851 .37049 L .62073 .36836 L F
.698 .957 .698 r
.62073 .36836 m .61851 .37049 L .61964 .36875 L F
.62073 .36836 m .61964 .36875 L .61975 .36859 L F
.625 .072 0 r
.62088 .36831 m .62073 .36836 L .62105 .36822 L F
.62 .092 0 r
.65282 .36342 m .65507 .36292 L .65097 .36215 L F
.537 .588 .853 r
.65291 .36332 m .65507 .36292 L .65282 .36342 L F
.579 .029 0 r
.65291 .36332 m .65507 .36292 L .65384 .36387 L F
.65097 .36215 m .65507 .36292 L .65291 .36332 L F
.537 .588 .853 r
.65687 .35885 m .65507 .36292 L .65291 .36332 L F
.579 .029 0 r
.65097 .36215 m .65282 .36342 L .65122 .36505 L F
.65282 .36342 m .65362 .36398 L .65148 .36494 L F
.65282 .36342 m .65148 .36494 L .65122 .36505 L F
.65097 .36215 m .65291 .36332 L .65282 .36342 L F
.86 .989 .84 r
.65679 .35891 m .65274 .36344 L .65238 .36219 L F
.65679 .35891 m .65238 .36219 L .65262 .36181 L F
.65687 .35885 m .65232 .36202 L .65607 .35803 L F
.669 .54 .698 r
.65607 .35803 m .65232 .36202 L .6509 .35936 L F
.617 .498 .695 r
.65385 .35993 m .6547 .36098 L .65508 .36016 L F
.6509 .35936 m .6535 .36047 L .65385 .35993 L F
.6535 .36047 m .6547 .36098 L .65385 .35993 L F
.86 .989 .84 r
.65262 .36181 m .65238 .36219 L .65232 .36202 L F
.65687 .35885 m .65539 .36051 L .65679 .35891 L F
.65539 .36051 m .65274 .36344 L .65679 .35891 L F
.537 .588 .853 r
.65539 .36051 m .65282 .36342 L .65274 .36344 L F
.65687 .35885 m .65282 .36342 L .65539 .36051 L F
.579 .029 0 r
.65282 .36342 m .65384 .36387 L .65362 .36398 L F
.65291 .36332 m .65384 .36387 L .65282 .36342 L F
.62 .092 0 r
.65274 .36344 m .65282 .36342 L .65097 .36215 L F
.056 .575 .875 r
.65507 .36292 m .65613 .3625 L .65384 .36387 L F
.65507 .36292 m .65768 .36323 L .65613 .3625 L F
0 .074 .624 r
.53121 .47379 m .529 .47495 L .52814 .4764 L F
.707 .347 0 r
.57272 .36546 m .57447 .36934 L .57366 .36773 L F
0 .057 .613 r
.57493 .37181 m .57366 .36773 L .57447 .36934 L F
.841 .929 .888 r
.36035 .48781 m .356 .48944 L .35865 .48896 L F
.446 .83 .599 r
.35865 .48896 m .35795 .48954 L .36035 .48781 L F
.833 .633 .633 r
.69777 .32638 m .69924 .32706 L .69766 .32324 L F
.935 .825 .712 r
.69684 .32884 m .69924 .32706 L .69777 .32638 L F
.943 .611 .184 r
.34984 .57966 m .34905 .57944 L .34776 .57559 L F
.941 .957 .657 r
.34984 .57966 m .34759 .58143 L .34905 .57944 L F
.809 .97 .662 r
.34984 .57966 m .35004 .57798 L .35207 .57644 L F
0 .037 .607 r
.34984 .57966 m .35201 .5825 L .35004 .57798 L F
.791 .611 .658 r
.34776 .57559 m .34905 .57944 L .34315 .57804 L F
.807 .513 .491 r
.34759 .58143 m .34315 .57804 L .34905 .57944 L F
.808 .971 .666 r
.35004 .57798 m .34759 .58143 L .34984 .57966 L F
.571 .53 .77 r
.31418 .65748 m .31283 .66234 L .31133 .65824 L F
.31418 .65748 m .31537 .66168 L .31283 .66234 L F
.506 .571 .856 r
.31704 .66554 m .31283 .66234 L .31537 .66168 L F
.697 .772 .909 r
.48376 .4395 m .48623 .43829 L .48216 .43767 L F
.827 .972 .89 r
.54817 .47909 m .55087 .47886 L .55242 .47696 L F
.596 .665 .887 r
.32208 .64224 m .3228 .63823 L .32039 .63935 L F
.32208 .64224 m .32501 .64191 L .3228 .63823 L F
.685 .443 .549 r
.34342 .53715 m .34623 .53667 L .34682 .53365 L F
.393 .175 .46 r
.34682 .53365 m .34623 .53667 L .34871 .5358 L F
.723 .746 .871 r
.30492 .65646 m .30049 .65585 L .303 .65526 L F
.311 .538 .91 r
.30538 .6543 m .30492 .65646 L .303 .65526 L F
.30538 .6543 m .30718 .65732 L .30492 .65646 L F
.79 .908 .923 r
.57572 .36127 m .57357 .36314 L .57297 .36128 L F
.906 .874 .44 r
.57357 .36314 m .57274 .36369 L .57297 .36128 L F
.57357 .36314 m .57272 .36546 L .57274 .36369 L F
.453 .862 .7 r
.46743 .42875 m .46336 .43098 L .4652 .42934 L F
.615 .929 .693 r
.4692 .42706 m .46743 .42875 L .46872 .4271 L F
.62 .957 .826 r
.46872 .4271 m .46743 .42875 L .4652 .42934 L F
.82 .623 .636 r
.69383 .32555 m .69766 .32324 L .69378 .32296 L F
.69383 .32555 m .69777 .32638 L .69766 .32324 L F
.909 .8 .728 r
.37908 .59252 m .3769 .59588 L .37964 .59444 L F
.914 .782 .702 r
.3764 .59866 m .37964 .59444 L .3769 .59588 L F
.3764 .59866 m .37854 .59966 L .37964 .59444 L F
.546 .723 .956 r
.60431 .40236 m .60625 .405 L .60837 .404 L F
.952 .893 .734 r
.35224 .6361 m .35421 .63249 L .35163 .63458 L F
.73 .99 .826 r
.35497 .63074 m .35421 .63249 L .35716 .62981 L F
.742 .974 .717 r
.35163 .63458 m .35421 .63249 L .35497 .63074 L F
.767 .471 .484 r
.38202 .46147 m .37749 .46277 L .37953 .46154 L F
.38202 .46147 m .38144 .46416 L .37749 .46277 L F
.605 .533 .747 r
.38185 .45793 m .38202 .46147 L .38566 .46039 L F
.229 .748 .773 r
.37953 .46154 m .38566 .46039 L .38202 .46147 L F
.455 .167 .386 r
.38566 .46039 m .38144 .46416 L .38202 .46147 L F
.776 .666 .741 r
.48298 .55293 m .48794 .5536 L .48636 .54977 L F
.697 .466 .568 r
.48405 .55609 m .48794 .5536 L .48298 .55293 L F
.48405 .55609 m .48757 .55616 L .48794 .5536 L F
.403 0 .154 r
.32599 .57512 m .32423 .57379 L .32346 .57578 L F
.32599 .57512 m .32685 .5735 L .32423 .57379 L F
.611 .697 .905 r
.39678 .50044 m .39411 .5011 L .39281 .49916 L F
.567 .428 .651 r
.39678 .50044 m .3948 .50362 L .39411 .5011 L F
.39678 .50044 m .3948 .50362 L .39411 .5011 L F
.028 0 0 r
.40575 .46177 m .40396 .46216 L .40155 .46229 L F
.006 .574 .783 r
.40575 .46177 m .40677 .4616 L .40396 .46216 L F
.40575 .46177 m .40828 .46191 L .40677 .4616 L F
.653 .321 .398 r
.32517 .66893 m .32789 .66883 L .32721 .6709 L F
.412 .081 .291 r
.32789 .66883 m .32978 .6705 L .32721 .6709 L F
.32789 .66883 m .33036 .66838 L .32978 .6705 L F
.946 .64 .428 r
.35462 .5232 m .35489 .52623 L .35739 .52725 L F
.932 .731 .609 r
.35489 .52623 m .35699 .52982 L .35739 .52725 L F
.813 .659 .692 r
.36564 .6243 m .36229 .62269 L .36196 .62501 L F
.162 0 .073 r
.45072 .5925 m .45299 .59147 L .454 .58887 L F
0 .314 .804 r
.45319 .58713 m .454 .58887 L .45426 .58817 L F
.665 .749 .257 r
.454 .58887 m .45299 .59147 L .45426 .58817 L F
.747 .87 .936 r
.45421 .56243 m .45631 .56368 L .45434 .56465 L F
.085 0 0 r
.65602 .33582 m .6548 .33717 L .65193 .3379 L F
.257 0 0 r
.65862 .33506 m .6548 .33717 L .65602 .33582 L F
.953 .738 .574 r
.483 .51997 m .48493 .52409 L .48285 .52261 L F
.885 .857 .809 r
.48493 .52409 m .48077 .52635 L .48285 .52261 L F
.288 .181 .554 r
.24225 .58954 m .24385 .58875 L .24372 .58612 L F
.751 .62 .713 r
.24225 .58954 m .24393 .5919 L .24385 .58875 L F
.894 .494 .067 r
.3298 .51126 m .32918 .5122 L .32701 .50971 L F
.3298 .51126 m .33072 .51362 L .32918 .5122 L F
.077 0 0 r
.46052 .59161 m .45607 .59371 L .45839 .59247 L F
.059 0 0 r
.64939 .339 m .6462 .34171 L .64697 .3404 L F
.696 .213 .095 r
.359 .56683 m .35561 .56629 L .35563 .56579 L F
.954 .87 .716 r
.359 .56683 m .35579 .56869 L .35561 .56629 L F
.359 .56683 m .35754 .57006 L .35579 .56869 L F
.789 .824 .879 r
.28499 .65348 m .28711 .65517 L .28337 .65492 L F
0 0 .574 r
.28449 .65875 m .28337 .65492 L .28711 .65517 L F
.7 .812 .935 r
.28974 .65388 m .28711 .65517 L .28499 .65348 L F
.84 .903 .882 r
.62613 .40555 m .62978 .40518 L .62891 .40435 L F
.717 .967 .937 r
.62978 .40518 m .631 .40275 L .62891 .40435 L F
.62978 .40518 m .6333 .403 L .631 .40275 L F
.216 .604 .95 r
.60068 .35104 m .60409 .35033 L .59964 .34956 L F
.594 .565 .792 r
.33259 .52273 m .33001 .52699 L .32947 .52457 L F
.33259 .52273 m .33372 .52661 L .33001 .52699 L F
.735 .274 .155 r
.37265 .51416 m .37086 .51563 L .36884 .5134 L F
.907 .544 .336 r
.37311 .51657 m .37086 .51563 L .37265 .51416 L F
.453 .267 .538 r
.70169 .31017 m .70463 .31173 L .70431 .30909 L F
.70169 .31017 m .70208 .31265 L .70463 .31173 L F
.143 0 .344 r
.23914 .5473 m .24098 .54829 L .24104 .54548 L F
.23914 .5473 m .23857 .55017 L .24098 .54829 L F
.089 0 0 r
.41512 .46016 m .4111 .46119 L .41279 .46041 L F
.731 .846 .935 r
.47587 .56587 m .47995 .56619 L .4787 .56333 L F
.47587 .56587 m .47721 .56708 L .47995 .56619 L F
.781 .829 .889 r
.48096 .56193 m .47995 .56619 L .48233 .56315 L F
.48096 .56193 m .4787 .56333 L .47995 .56619 L F
.535 .778 .987 r
.60676 .38458 m .60547 .38664 L .60415 .38478 L F
.60676 .38458 m .60823 .38609 L .60547 .38664 L F
.396 0 0 r
.25887 .55683 m .25681 .55636 L .25586 .55577 L F
0 0 .409 r
.25965 .55236 m .25887 .55683 L .25795 .55315 L F
.25965 .55236 m .25994 .5554 L .25887 .55683 L F
.262 0 .03 r
.25994 .5554 m .25681 .55636 L .25887 .55683 L F
.25994 .5554 m .25786 .55702 L .25681 .55636 L F
.25786 .55702 m .25586 .55858 L .25681 .55636 L F
.396 0 0 r
.25586 .55577 m .25681 .55636 L .2545 .55529 L F
.653 .321 .398 r
.32517 .66893 m .32721 .6709 L .32461 .67125 L F
0 0 .318 r
.58617 .39592 m .58692 .39814 L .58583 .394 L F
.972 .812 .626 r
.69332 .34141 m .69506 .3429 L .69426 .33905 L F
.984 .726 .454 r
.69486 .34534 m .69506 .3429 L .69332 .34141 L F
.758 .65 .742 r
.28532 .59973 m .28612 .60258 L .28249 .60224 L F
.588 .078 .008 r
.28249 .60224 m .28612 .60258 L .28551 .60327 L F
.981 .737 .494 r
.28747 .59873 m .28612 .60258 L .28532 .59973 L F
.28747 .59873 m .28728 .60187 L .28612 .60258 L F
0 0 0 r
.28551 .60327 m .28612 .60258 L .28728 .60187 L F
.649 .838 .973 r
.33982 .56676 m .33648 .56671 L .3381 .56541 L F
.578 .812 .988 r
.34253 .566 m .33982 .56676 L .3381 .56541 L F
.52 .579 .854 r
.34404 .56994 m .33982 .56676 L .34253 .566 L F
.775 .971 .685 r
.49237 .51384 m .49055 .51513 L .49089 .51243 L F
.49237 .51384 m .48978 .51698 L .49055 .51513 L F
.884 .896 .834 r
.49499 .51041 m .49237 .51384 L .49089 .51243 L F
.833 .796 .816 r
.36197 .49452 m .35773 .4958 L .36009 .49317 L F
0 0 .097 r
.36197 .49452 m .363 .49307 L .3633 .49028 L F
.404 .739 .992 r
.36009 .49317 m .363 .49307 L .36197 .49452 L F
.088 0 .318 r
.43284 .45849 m .43454 .45479 L .43326 .456 L F
0 0 0 r
.43454 .45479 m .437 .454 L .43326 .456 L F
.43454 .45479 m .43728 .45353 L .437 .454 L F
.978 .691 .404 r
.47587 .56587 m .47598 .56855 L .47721 .56708 L F
.811 .657 .691 r
.32696 .50743 m .32301 .50685 L .32505 .50368 L F
.254 0 0 r
.32696 .50743 m .32254 .50966 L .32301 .50685 L F
.32696 .50743 m .32507 .50931 L .32254 .50966 L F
.879 .521 .365 r
.32701 .50971 m .32507 .50931 L .32696 .50743 L F
.976 .878 .503 r
.69539 .35945 m .69539 .35455 L .69454 .35796 L F
.954 .641 .217 r
.69461 .36078 m .69539 .35945 L .69454 .35796 L F
.69461 .36078 m .6958 .36217 L .69539 .35945 L F
.916 .66 .165 r
.58414 .38876 m .58375 .39068 L .5833 .38772 L F
.58414 .38876 m .58445 .39228 L .58375 .39068 L F
.56 .414 .639 r
.28399 .5135 m .28374 .51685 L .28117 .51731 L F
0 0 0 r
.28374 .51685 m .28075 .51937 L .28117 .51731 L F
.81 .868 .89 r
.55208 .46856 m .54679 .46988 L .54924 .4689 L F
.939 .918 .766 r
.55208 .46856 m .55059 .46709 L .55278 .46367 L F
.835 .931 .893 r
.55208 .46856 m .54924 .4689 L .55059 .46709 L F
.831 .708 .729 r
.4811 .55923 m .48507 .56041 L .48405 .55609 L F
.814 .735 .778 r
.48233 .56315 m .48507 .56041 L .4811 .55923 L F
.702 .631 .774 r
.48405 .55609 m .48507 .56041 L .48757 .55616 L F
.472 .748 .99 r
.59421 .44498 m .59712 .44472 L .59556 .44309 L F
.59421 .44498 m .59712 .44472 L .59556 .44309 L F
.625 .416 .578 r
.27541 .60227 m .27792 .60223 L .27788 .59957 L F
.544 0 0 r
.33643 .52797 m .34048 .53002 L .33827 .52845 L F
.759 .624 .711 r
.29328 .59823 m .29566 .59955 L .29166 .59927 L F
.7 .316 .316 r
.29166 .59927 m .29566 .59955 L .29455 .60199 L F
0 .418 .823 r
.29624 .59945 m .29566 .59955 L .29335 .59827 L F
.29624 .59945 m .29335 .59827 L .29344 .5983 L F
.51 .374 .631 r
.29537 .59796 m .29624 .59945 L .29328 .59823 L F
.7 .316 .316 r
.29166 .59927 m .29455 .60199 L .2916 .60256 L F
.339 0 .132 r
.29214 .60128 m .29469 .59866 L .29166 .59927 L F
.29469 .59866 m .29537 .59796 L .29397 .59845 L F
.29469 .59866 m .29397 .59845 L .29166 .59927 L F
0 .418 .823 r
.29344 .5983 m .29335 .59827 L .29328 .59823 L F
.867 .42 .082 r
.29591 .5995 m .29624 .59945 L .29537 .59796 L F
0 0 0 r
.29455 .60199 m .29624 .59945 L .2964 .60088 L F
.867 .42 .082 r
.2964 .60088 m .29624 .59945 L .29591 .5995 L F
.117 .666 .704 r
.29566 .59955 m .29704 .59933 L .29624 .59945 L F
.29704 .59933 m .29872 .59907 L .29624 .59945 L F
0 0 0 r
.29455 .60199 m .29566 .59955 L .29624 .59945 L F
.785 .741 .812 r
.31774 .66098 m .31704 .66554 L .31537 .66168 L F
.712 .755 .885 r
.70701 .31981 m .71134 .32107 L .70981 .31907 L F
.493 .791 .998 r
.71382 .31989 m .70981 .31907 L .71134 .32107 L F
.059 .239 .734 r
.34492 .56818 m .34404 .56994 L .34253 .566 L F
0 .108 .636 r
.34492 .56818 m .34577 .57161 L .34404 .56994 L F
.286 .131 .489 r
.34577 .57161 m .34373 .57321 L .34404 .56994 L F
.724 .828 .929 r
.61225 .35491 m .60977 .35651 L .60783 .35486 L F
.111 .268 .745 r
.60977 .35651 m .60788 .35745 L .60783 .35486 L F
.724 .828 .929 r
.61225 .35491 m .61183 .3549 L .61053 .3541 L F
.61183 .3549 m .60783 .35486 L .61053 .3541 L F
.53 .41 .661 r
.61007 .35133 m .61053 .3541 L .60783 .35486 L F
.868 .917 .86 r
.6095 .35288 m .60933 .35336 L .61053 .3541 L F
.60933 .35336 m .60788 .35745 L .61053 .3541 L F
.111 .268 .745 r
.60977 .35651 m .61053 .3541 L .60788 .35745 L F
.60977 .35651 m .61192 .3581 L .61053 .3541 L F
0 0 .559 r
.41198 .52063 m .41175 .51963 L .41066 .51811 L F
0 .009 .562 r
.41134 .51928 m .41198 .52063 L .41124 .51922 L F
0 .18 .703 r
.40839 .51678 m .41134 .51928 L .41198 .52063 L F
.797 .395 .29 r
.40865 .52266 m .41135 .51928 L .40898 .52081 L F
0 .18 .703 r
.41134 .51928 m .41175 .51963 L .41198 .52063 L F
0 .009 .562 r
.41137 .51925 m .41198 .52063 L .41115 .51889 L F
.862 .421 .148 r
.41066 .51811 m .41175 .51963 L .41137 .51931 L F
0 .009 .562 r
.41125 .5191 m .41134 .51928 L .41066 .51811 L F
.41134 .51928 m .41124 .51922 L .41066 .51811 L F
.797 .395 .29 r
.40865 .52266 m .41296 .52367 L .41214 .52139 L F
.41094 .51979 m .41214 .52139 L .41137 .51925 L F
.40865 .52266 m .41214 .52139 L .41094 .51979 L F
.862 .421 .148 r
.41066 .51811 m .41137 .51931 L .40907 .51731 L F
.40877 .51691 m .40907 .51731 L .40816 .51652 L F
.41066 .51811 m .40907 .51731 L .40877 .51691 L F
0 .009 .562 r
.41115 .51889 m .41125 .5191 L .41066 .51811 L F
.797 .395 .29 r
.41135 .51928 m .41137 .51925 L .41134 .51927 L F
.41135 .51928 m .41134 .51927 L .40898 .52081 L F
0 .075 .553 r
.40826 .51664 m .41137 .51931 L .40839 .51678 L F
.40816 .51652 m .41037 .51844 L .40826 .51664 L F
.41037 .51844 m .41137 .51931 L .40826 .51664 L F
.41137 .51931 m .41175 .51963 L .41134 .51928 L F
.41137 .51931 m .41134 .51928 L .40839 .51678 L F
.693 .161 0 r
.4153 .52351 m .41413 .52307 L .4159 .52403 L F
.41198 .52063 m .41413 .52307 L .4153 .52351 L F
0 .009 .562 r
.41137 .51925 m .41413 .52307 L .41198 .52063 L F
.913 .514 .138 r
.41137 .51925 m .41253 .52246 L .41413 .52307 L F
.41253 .52246 m .41296 .52367 L .41413 .52307 L F
.976 .673 .331 r
.48732 .54537 m .48836 .544 L .48746 .54262 L F
.48732 .54537 m .48872 .5469 L .48836 .544 L F
.816 .548 .533 r
.48836 .544 m .48872 .5469 L .48943 .54676 L F
.675 .678 .845 r
.31133 .65824 m .30878 .65931 L .30718 .65732 L F
.663 .808 .953 r
.50636 .42859 m .51179 .42852 L .51038 .42723 L F
.401 .806 .59 r
.51179 .42852 m .50793 .43113 L .51038 .42723 L F
.539 .398 .637 r
.51179 .42852 m .51461 .43049 L .51436 .42785 L F
0 .169 .619 r
.513 .42921 m .51179 .42852 L .51436 .42785 L F
.513 .42921 m .51461 .43049 L .51179 .42852 L F
.127 .421 .865 r
.61881 .40288 m .62222 .40302 L .61787 .40105 L F
.61881 .40288 m .62234 .40464 L .62222 .40302 L F
.655 .555 .729 r
.27178 .52364 m .26939 .52604 L .268 .52277 L F
.238 0 0 r
.43326 .456 m .43114 .45688 L .43146 .45753 L F
.52 0 0 r
.42877 .45715 m .43174 .45813 L .43146 .45753 L F
.238 0 0 r
.43114 .45688 m .42931 .45764 L .43146 .45753 L F
.52 0 0 r
.43174 .45813 m .43284 .45849 L .43146 .45753 L F
.744 .927 .95 r
.43146 .45753 m .43284 .45849 L .43326 .456 L F
.524 .343 .578 r
.42124 .56701 m .42195 .56941 L .42352 .56587 L F
0 .008 .528 r
.42171 .56445 m .42195 .56941 L .42124 .56701 L F
.673 .949 .695 r
.71804 .30361 m .7182 .30434 L .7154 .30701 L F
0 0 0 r
.71936 .30387 m .72053 .30225 L .7182 .30434 L F
.71936 .30387 m .7182 .30434 L .71804 .30361 L F
.052 .601 .835 r
.26228 .60542 m .26594 .60601 L .26436 .60555 L F
.269 .75 .929 r
.26706 .60536 m .26594 .60601 L .26436 .60555 L F
.26436 .60555 m .26594 .60601 L .26706 .60536 L F
.721 .862 .948 r
.59484 .40453 m .59874 .40441 L .59752 .40256 L F
.665 .824 .96 r
.59874 .40441 m .60026 .40152 L .59752 .40256 L F
.59874 .40441 m .60135 .40335 L .60026 .40152 L F
.711 .983 .895 r
.48978 .51698 m .4855 .51878 L .48761 .51781 L F
.774 .997 .813 r
.48978 .51698 m .48761 .51781 L .49055 .51513 L F
0 .289 .788 r
.46816 .58968 m .4675 .58702 L .46646 .58844 L F
.46816 .58968 m .46832 .58938 L .4675 .58702 L F
.611 .549 .761 r
.54887 .47419 m .54597 .47507 L .54518 .47147 L F
.726 .704 .829 r
.32897 .66149 m .32669 .66438 L .32612 .66226 L F
.724 .672 .799 r
.33014 .66291 m .32669 .66438 L .32897 .66149 L F
.673 .949 .695 r
.71804 .30361 m .7154 .30701 L .71418 .30555 L F
.811 .912 .908 r
.66681 .38491 m .666 .38807 L .66482 .38805 L F
.707 .216 .076 r
.66482 .38805 m .666 .38807 L .66638 .39022 L F
.797 .888 .91 r
.66569 .38542 m .66482 .38805 L .6623 .38698 L F
.66681 .38491 m .66581 .38648 L .66569 .38542 L F
.66581 .38648 m .66482 .38805 L .66569 .38542 L F
.901 .986 .768 r
.66571 .38538 m .666 .38807 L .66681 .38491 L F
.2 .644 .947 r
.66203 .38387 m .66681 .38491 L .6649 .38351 L F
.797 .888 .91 r
.66549 .38394 m .6623 .38698 L .6649 .38351 L F
.66681 .38491 m .66569 .38542 L .66549 .38394 L F
.66569 .38542 m .6623 .38698 L .66549 .38394 L F
0 0 .132 r
.66638 .39022 m .66622 .38931 L .66571 .38538 L F
.66622 .38931 m .66601 .38812 L .66582 .38641 L F
.66622 .38931 m .66582 .38641 L .66571 .38538 L F
.66601 .38812 m .666 .38807 L .66597 .38779 L F
.66601 .38812 m .66597 .38779 L .66571 .38538 L F
.29 .772 .679 r
.43494 .44647 m .43327 .44721 L .43259 .44765 L F
.43494 .44647 m .43674 .4458 L .43327 .44721 L F
0 .126 .673 r
.2673 .59906 m .26947 .60158 L .27156 .59954 L F
.625 .185 .184 r
.26947 .60158 m .27411 .60143 L .27156 .59954 L F
0 0 .574 r
.28449 .65875 m .28507 .65763 L .28337 .65492 L F
0 .069 .631 r
.28449 .65875 m .28661 .66132 L .28507 .65763 L F
.804 .998 .852 r
.53788 .41975 m .53993 .42027 L .53583 .42024 L F
.53788 .41975 m .53845 .41905 L .53993 .42027 L F
.53788 .41975 m .53792 .41786 L .53845 .41905 L F
.865 .767 .752 r
.3764 .59866 m .37747 .60242 L .37854 .59966 L F
.902 .837 .772 r
.60632 .44301 m .60303 .4449 L .60666 .44065 L F
.488 .505 .801 r
.60899 .44013 m .60632 .44301 L .60666 .44065 L F
.607 .122 0 r
.60681 .44381 m .60811 .44514 L .60632 .44301 L F
.60681 .44381 m .60632 .44301 L .60899 .44013 L F
.655 .518 .684 r
.35323 .56642 m .35063 .56986 L .35062 .56736 L F
.91 .505 .185 r
.36629 .49164 m .36788 .4936 L .36834 .49311 L F
.858 .877 .439 r
.36898 .49242 m .36834 .49311 L .36849 .49428 L F
.478 0 .022 r
.36849 .49428 m .37089 .49556 L .37114 .49444 L F
.88 .474 .25 r
.36834 .49311 m .37089 .49556 L .36849 .49428 L F
.91 .505 .185 r
.36788 .4936 m .36916 .49517 L .36834 .49311 L F
.858 .877 .439 r
.36977 .48944 m .36834 .49311 L .36898 .49242 L F
.861 .994 .823 r
.55396 .47268 m .55367 .475 L .55508 .4731 L F
.887 .962 .629 r
.55242 .47696 m .55367 .475 L .55396 .47268 L F
.945 .636 .419 r
.34913 .51594 m .35193 .52066 L .35101 .51711 L F
.233 .711 .936 r
.58636 .44034 m .58895 .44075 L .58881 .44063 L F
.375 .834 .759 r
.59125 .43953 m .58881 .44063 L .58895 .44075 L F
.615 .064 0 r
.41413 .52307 m .41661 .52475 L .4159 .52403 L F
.583 .879 .993 r
.34303 .54537 m .34232 .54698 L .34444 .54594 L F
.757 .336 .25 r
.34513 .54708 m .34148 .54475 L .34303 .54537 L F
.34148 .54475 m .34078 .5443 L .34303 .54537 L F
.583 .879 .993 r
.34303 .54537 m .34444 .54594 L .34472 .54581 L F
.691 .529 .663 r
.30806 .58457 m .30482 .58258 L .30915 .58312 L F
0 0 .349 r
.30976 .5814 m .30806 .58457 L .30915 .58312 L F
.344 0 .159 r
.64136 .33535 m .64417 .33469 L .64477 .33229 L F
.113 0 0 r
.64477 .33229 m .64727 .33198 L .64814 .33079 L F
.239 0 .129 r
.64477 .33229 m .64679 .33365 L .64727 .33198 L F
.64477 .33229 m .64417 .33469 L .64679 .33365 L F
.924 .954 .626 r
.23626 .61822 m .23525 .62218 L .23758 .62113 L F
.892 .853 .797 r
.26385 .60384 m .26228 .60542 L .26362 .60367 L F
.281 0 0 r
.51451 .41013 m .52092 .41118 L .5189 .41063 L F
.955 .625 .352 r
.39734 .58317 m .39563 .58249 L .39531 .57923 L F
.921 .645 .159 r
.39734 .58317 m .39679 .58445 L .39563 .58249 L F
.39734 .58317 m .39761 .58585 L .39679 .58445 L F
.876 .612 .087 r
.59303 .42444 m .59398 .42848 L .59341 .42755 L F
.247 .761 .781 r
.62407 .34671 m .62531 .3461 L .62269 .34653 L F
.62407 .34671 m .62689 .346 L .62531 .3461 L F
.407 .846 .936 r
.59525 .43431 m .5976 .4337 L .59701 .4332 L F
0 0 .486 r
.5777 .376 m .58027 .37895 L .57956 .37809 L F
.292 .352 .753 r
.57844 .3803 m .57888 .37727 L .57956 .37809 L F
0 .148 .692 r
.5777 .376 m .57956 .37809 L .57907 .37592 L F
.292 .352 .753 r
.57888 .37727 m .57907 .37592 L .57956 .37809 L F
0 0 .486 r
.58027 .37895 m .58043 .37913 L .57956 .37809 L F
.887 .522 .345 r
.58043 .37913 m .57844 .3803 L .57956 .37809 L F
.58043 .37913 m .58099 .38151 L .57844 .3803 L F
.093 0 0 r
.40816 .51652 m .40721 .51679 L .40852 .5166 L F
.862 .421 .148 r
.41066 .51811 m .40816 .51652 L .40887 .51654 L F
.093 0 0 r
.40816 .51652 m .40852 .5166 L .40887 .51654 L F
0 .075 .553 r
.40816 .51652 m .40839 .51678 L .40731 .51635 L F
.40816 .51652 m .40731 .51635 L .40637 .51598 L F
.724 .64 .764 r
.45419 .55965 m .45631 .56368 L .45421 .56243 L F
.45419 .55965 m .45845 .56033 L .45631 .56368 L F
.847 .88 .864 r
.35004 .6352 m .35043 .6384 L .35224 .6361 L F
.884 .896 .834 r
.49499 .51041 m .49089 .51243 L .49426 .5098 L F
.852 .997 .812 r
.49499 .51041 m .49548 .50801 L .49818 .50748 L F
.49499 .51041 m .49426 .5098 L .49548 .50801 L F
.857 .605 .557 r
.36595 .55535 m .36879 .55344 L .3665 .55256 L F
.36595 .55535 m .3685 .55663 L .36879 .55344 L F
.616 .953 .802 r
.52593 .47781 m .52197 .47995 L .52499 .47777 L F
.598 .95 .843 r
.52814 .4764 m .52593 .47781 L .52499 .47777 L F
.748 .965 .935 r
.4789 .4216 m .47448 .42286 L .47807 .42089 L F
.808 .992 .873 r
.4789 .4216 m .47944 .41911 L .48221 .41879 L F
.4789 .4216 m .47807 .42089 L .47944 .41911 L F
.895 .869 .805 r
.3742 .60229 m .37166 .60567 L .37438 .60609 L F
.886 .73 .683 r
.37085 .60796 m .37438 .60609 L .37166 .60567 L F
.37085 .60796 m .37283 .60921 L .37438 .60609 L F
.838 .831 .84 r
.3742 .60229 m .37438 .60609 L .37747 .60242 L F
.077 0 0 r
.25681 .55636 m .25305 .55793 L .2545 .55529 L F
.518 0 0 r
.61455 .34938 m .61251 .35028 L .61043 .34892 L F
.595 .924 .967 r
.6178 .34968 m .61251 .35028 L .61455 .34938 L F
.287 0 0 r
.49864 .44457 m .49958 .44552 L .49786 .44718 L F
.49864 .44457 m .50118 .44455 L .49958 .44552 L F
.256 0 0 r
.35102 .56134 m .35046 .56174 L .3496 .5603 L F
.406 .335 .664 r
.35102 .56134 m .35268 .5639 L .3542 .56207 L F
.256 0 0 r
.35102 .56134 m .3542 .56207 L .35046 .56174 L F
.78 .437 .406 r
.37089 .49556 m .37529 .49431 L .37114 .49444 L F
.37089 .49556 m .37513 .49625 L .37529 .49431 L F
.658 .326 .4 r
.37529 .49431 m .37513 .49625 L .38078 .49555 L F
.056 0 0 r
.40508 .45526 m .40434 .45496 L .40251 .4558 L F
.40508 .45526 m .40701 .45484 L .40434 .45496 L F
.193 .704 .895 r
.44935 .56519 m .44459 .56477 L .44763 .56308 L F
.772 .832 .898 r
.45144 .56301 m .44935 .56519 L .44763 .56308 L F
.644 .543 .726 r
.60116 .36881 m .59841 .36952 L .59676 .36444 L F
.405 .235 .534 r
.60116 .36881 m .59889 .37227 L .59841 .36952 L F
.791 .982 .902 r
.53438 .46819 m .53386 .4671 L .53581 .46598 L F
0 0 0 r
.53438 .46819 m .53364 .47027 L .53581 .46598 L F
.53581 .46598 m .53364 .47027 L .53438 .46819 L F
.748 .887 .942 r
.65803 .37853 m .65589 .38024 L .65386 .37869 L F
0 .199 .726 r
.42868 .56932 m .43077 .57322 L .43283 .56982 L F
.42868 .56932 m .43123 .57158 L .43077 .57322 L F
.272 .611 .956 r
.43123 .57158 m .43309 .5733 L .43077 .57322 L F
0 .014 .581 r
.5609 .40327 m .56154 .40419 L .56168 .40525 L F
.495 .866 .983 r
.56168 .40525 m .56089 .40437 L .55763 .40531 L F
0 0 0 r
.56089 .40437 m .55567 .40518 L .55763 .40531 L F
.592 .036 0 r
.56128 .40422 m .56074 .4042 L .5609 .40327 L F
.56168 .40525 m .56083 .40431 L .56128 .40422 L F
.56083 .40431 m .56074 .4042 L .56128 .40422 L F
0 0 0 r
.56077 .40432 m .55567 .40518 L .56089 .40437 L F
.56077 .40432 m .55884 .40466 L .55567 .40518 L F
.56154 .40419 m .56077 .40432 L .56089 .40437 L F
.56154 .40419 m .56051 .40437 L .56077 .40432 L F
.56072 .40433 m .55884 .40466 L .56077 .40432 L F
.964 .719 .517 r
.5609 .40327 m .56072 .40433 L .55884 .40466 L F
.56072 .40433 m .56038 .40638 L .55884 .40466 L F
0 0 0 r
.56051 .40437 m .55884 .40466 L .56072 .40433 L F
.592 .036 0 r
.56168 .40525 m .56038 .40638 L .56073 .4043 L F
.56089 .40437 m .56073 .4043 L .56074 .4042 L F
.56168 .40525 m .56073 .4043 L .56089 .40437 L F
.495 .866 .983 r
.56168 .40525 m .56154 .40419 L .56089 .40437 L F
.592 .036 0 r
.56168 .40525 m .56425 .40706 L .56038 .40638 L F
.114 .281 .757 r
.3459 .54955 m .3473 .54836 L .34472 .54581 L F
.103 .052 .509 r
.3465 .54978 m .3473 .54836 L .3459 .54955 L F
0 0 0 r
.46207 .54669 m .46404 .5456 L .46515 .54459 L F
.46207 .54669 m .46228 .54716 L .46404 .5456 L F
.46207 .54669 m .46118 .54936 L .46228 .54716 L F
.517 .916 .883 r
.59823 .363 m .59676 .36444 L .59505 .36173 L F
.59823 .363 m .59863 .36305 L .59676 .36444 L F
.704 .308 0 r
.57695 .37552 m .57631 .37471 L .57493 .37181 L F
0 .182 .657 r
.57695 .37552 m .5777 .376 L .57631 .37471 L F
.987 .829 .445 r
.4762 .57409 m .47682 .57968 L .47674 .57539 L F
.4762 .57409 m .47588 .57869 L .47682 .57968 L F
.992 .78 .516 r
.47458 .58165 m .47682 .57968 L .47588 .57869 L F
.47458 .58165 m .47627 .58271 L .47682 .57968 L F
.69 .164 0 r
.40067 .50898 m .40361 .50988 L .40236 .50842 L F
.598 .272 .389 r
.30406 .6808 m .30673 .68332 L .30196 .68455 L F
.30406 .6808 m .30624 .68114 L .30673 .68332 L F
.928 .699 .571 r
.36133 .54471 m .36465 .54347 L .36089 .54228 L F
.36133 .54471 m .36411 .54615 L .36465 .54347 L F
0 .126 .673 r
.2673 .59906 m .26894 .6026 L .26947 .60158 L F
.722 .353 .351 r
.26894 .6026 m .26706 .60536 L .26781 .60161 L F
.925 .942 .792 r
.63774 .38346 m .63906 .38487 L .63719 .38638 L F
.913 .965 .798 r
.63719 .38638 m .63906 .38487 L .63807 .38626 L F
.63719 .38638 m .63807 .38626 L .63683 .38798 L F
.63719 .38638 m .6365 .38845 L .6353 .38649 L F
.324 0 0 r
.63583 .38658 m .63719 .38638 L .6353 .38649 L F
.913 .965 .798 r
.63719 .38638 m .63683 .38798 L .6365 .38845 L F
.324 0 0 r
.63801 .38692 m .63719 .38638 L .63583 .38658 L F
0 0 .41 r
.63777 .38384 m .63719 .38638 L .63801 .38692 L F
.63774 .38346 m .63719 .38638 L .63777 .38384 L F
.581 .942 .901 r
.64065 .38304 m .63906 .38487 L .63774 .38346 L F
.64065 .38304 m .64209 .38353 L .63906 .38487 L F
.532 0 0 r
.58139 .35987 m .58216 .35943 L .58088 .35794 L F
.58139 .35987 m .58497 .36117 L .58216 .35943 L F
.726 .985 .895 r
.52283 .49984 m .51837 .5016 L .52141 .5017 L F
.617 .955 .908 r
.30988 .54841 m .30687 .55014 L .31122 .5488 L F
.818 .865 .419 r
.31141 .54884 m .31145 .54806 L .31242 .54547 L F
.31141 .54885 m .31141 .54883 L .31141 .54884 L F
0 .343 .761 r
.30757 .54689 m .31032 .54815 L .31048 .54838 L F
0 .34 .755 r
.31004 .54776 m .31129 .54855 L .31029 .5481 L F
.31004 .54776 m .31029 .5481 L .30757 .54689 L F
.31129 .54855 m .31131 .5486 L .30757 .54689 L F
.861 .966 .64 r
.30989 .54756 m .30939 .54842 L .30988 .54841 L F
.174 .576 .936 r
.3099 .54668 m .31153 .5487 L .30811 .54655 L F
.861 .966 .64 r
.30989 .54752 m .30988 .54754 L .30989 .54756 L F
.30988 .54754 m .30939 .54842 L .30989 .54756 L F
.30972 .54728 m .30939 .54842 L .30989 .54752 L F
0 .343 .761 r
.31032 .54815 m .31153 .5487 L .31048 .54838 L F
.818 .865 .419 r
.31141 .54883 m .31148 .54759 L .31141 .54884 L F
.819 .693 .726 r
.31491 .54628 m .31528 .54999 L .31141 .54885 L F
.818 .865 .419 r
.31145 .54806 m .31192 .5466 L .31242 .54547 L F
.554 0 0 r
.31204 .54904 m .31375 .54998 L .31141 .54885 L F
.31528 .54999 m .31375 .54998 L .31204 .54904 L F
.726 .396 .421 r
.31671 .55008 m .31717 .55246 L .31375 .54998 L F
.166 .426 .863 r
.31375 .54998 m .31717 .55246 L .31661 .55157 L F
.236 .282 .708 r
.31592 .54559 m .31528 .54999 L .31491 .54628 L F
.31592 .54559 m .31671 .55008 L .31528 .54999 L F
.726 .396 .421 r
.31671 .55008 m .31375 .54998 L .31528 .54999 L F
.166 .426 .863 r
.31375 .54998 m .31661 .55157 L .31421 .54778 L F
.124 .494 .904 r
.31141 .54885 m .31375 .54998 L .31148 .54759 L F
.31141 .54885 m .31375 .54998 L .31148 .54759 L F
0 .34 .755 r
.31129 .54855 m .31153 .5487 L .31131 .5486 L F
.861 .966 .64 r
.3099 .54668 m .30988 .54841 L .31153 .5487 L F
.775 .916 .934 r
.31148 .54759 m .31153 .5487 L .3099 .54668 L F
.141 .255 .721 r
.30971 .54732 m .31229 .54862 L .30939 .54842 L F
.861 .966 .64 r
.3099 .54668 m .30972 .54728 L .30989 .54752 L F
.141 .255 .721 r
.3099 .54668 m .31165 .54811 L .30971 .54732 L F
.31165 .54811 m .31229 .54862 L .30971 .54732 L F
0 .34 .755 r
.30799 .54662 m .31004 .54776 L .30757 .54689 L F
.30811 .54655 m .30865 .54689 L .30799 .54662 L F
.30865 .54689 m .31004 .54776 L .30799 .54662 L F
0 .343 .761 r
.31048 .54838 m .31153 .5487 L .31141 .54885 L F
.617 .955 .908 r
.31126 .54865 m .31123 .54876 L .31153 .5487 L F
.31123 .54876 m .31122 .5488 L .31153 .5487 L F
.30988 .54841 m .31122 .5488 L .31126 .54865 L F
.818 .865 .419 r
.31145 .54806 m .31148 .54759 L .31192 .5466 L F
.512 .896 .955 r
.31153 .5487 m .30844 .55051 L .31141 .54885 L F
.286 0 .086 r
.30939 .54842 m .30915 .54869 L .30988 .54841 L F
.512 .896 .955 r
.30955 .54986 m .30687 .55014 L .30844 .55051 L F
.30938 .54936 m .30687 .55014 L .30955 .54986 L F
.617 .955 .908 r
.30988 .54841 m .30462 .55018 L .30687 .55014 L F
.463 0 .033 r
.30988 .54841 m .30748 .55053 L .30462 .55018 L F
.286 0 .086 r
.30915 .54869 m .30748 .55053 L .30925 .54898 L F
.30915 .54869 m .30925 .54898 L .30988 .54841 L F
.512 .896 .955 r
.31153 .5487 m .30938 .54936 L .30955 .54986 L F
.058 0 0 r
.24577 .57657 m .24345 .57749 L .2414 .57772 L F
.258 0 0 r
.24879 .57415 m .24578 .57722 L .24345 .57749 L F
.833 .468 .363 r
.59442 .36101 m .59519 .35931 L .5919 .35806 L F
.59442 .36101 m .59505 .36173 L .59519 .35931 L F
.952 .774 .318 r
.40361 .50988 m .40316 .51232 L .4041 .51395 L F
.94 .598 .349 r
.40316 .51232 m .40637 .51598 L .4041 .51395 L F
.742 .263 .108 r
.6458 .38588 m .64209 .38353 L .64468 .38398 L F
.477 .588 .886 r
.51461 .43049 m .51598 .43322 L .51856 .43254 L F
.98 .784 .567 r
.31729 .60859 m .31888 .61264 L .31702 .61171 L F
.762 .355 .28 r
.32513 .61446 m .32562 .61266 L .32075 .61164 L F
.31998 .61158 m .32075 .61164 L .31969 .61142 L F
.32513 .61446 m .32075 .61164 L .31998 .61158 L F
.32513 .61446 m .31969 .61142 L .31977 .61167 L F
.32263 .61478 m .31977 .61167 L .32089 .615 L F
.32513 .61446 m .31977 .61167 L .32263 .61478 L F
.255 .417 .832 r
.31905 .61089 m .31888 .61264 L .31766 .60953 L F
.3182 .60996 m .31766 .60953 L .31755 .60926 L F
.31905 .61089 m .31766 .60953 L .3182 .60996 L F
.676 .419 .525 r
.31856 .61025 m .31995 .61135 L .31978 .60909 L F
.255 .417 .832 r
.31973 .61162 m .31967 .61169 L .31905 .61089 L F
.036 .086 .585 r
.31969 .61142 m .31888 .61264 L .31995 .61135 L F
.255 .417 .832 r
.31967 .61169 m .31888 .61264 L .31905 .61089 L F
.676 .419 .525 r
.31856 .61025 m .31978 .60909 L .31729 .60859 L F
.255 .417 .832 r
.31995 .61135 m .31973 .61162 L .31729 .60859 L F
.31973 .61162 m .31755 .60926 L .31729 .60859 L F
.676 .419 .525 r
.31702 .61171 m .31995 .61135 L .31856 .61025 L F
.31702 .61171 m .31856 .61025 L .31729 .60859 L F
.559 .868 .995 r
.31702 .61171 m .31888 .61264 L .31977 .61157 L F
.31878 .61149 m .31977 .61157 L .31995 .61135 L F
.31702 .61171 m .31977 .61157 L .31878 .61149 L F
0 0 .514 r
.32044 .61144 m .31969 .61142 L .32195 .61031 L F
0 0 .201 r
.32006 .61173 m .3201 .61187 L .32195 .61031 L F
.32006 .61173 m .32089 .615 L .3201 .61187 L F
.3201 .61187 m .32073 .61274 L .32195 .61031 L F
0 0 .514 r
.32127 .61349 m .32089 .615 L .32023 .61242 L F
.32073 .61274 m .32023 .61242 L .3201 .61187 L F
.32127 .61349 m .32023 .61242 L .32073 .61274 L F
0 0 .242 r
.32195 .61031 m .32073 .61274 L .32136 .61316 L F
.32073 .61274 m .32047 .61326 L .32136 .61316 L F
.166 .021 .426 r
.32195 .61031 m .32006 .61173 L .32047 .61326 L F
0 0 .514 r
.32136 .61316 m .32127 .61349 L .32073 .61274 L F
0 0 .242 r
.32136 .61316 m .32047 .61326 L .32073 .61274 L F
.32136 .61316 m .32073 .61274 L .32195 .61031 L F
0 0 .514 r
.32136 .61316 m .32073 .61274 L .32001 .61176 L F
.32009 .61184 m .32006 .61173 L .32171 .61148 L F
.32006 .61173 m .31998 .61146 L .32041 .61146 L F
.32006 .61173 m .32041 .61146 L .32171 .61148 L F
.31972 .61145 m .31969 .61142 L .32044 .61144 L F
.32041 .61146 m .32044 .61144 L .32171 .61148 L F
.31972 .61145 m .32044 .61144 L .32041 .61146 L F
.166 .021 .426 r
.32195 .61031 m .31995 .61135 L .32006 .61173 L F
0 0 .201 r
.31995 .61135 m .31998 .61146 L .32006 .61173 L F
.31998 .61146 m .32089 .615 L .32006 .61173 L F
0 0 .514 r
.32136 .61316 m .32009 .61184 L .32171 .61148 L F
.095 .176 .658 r
.31998 .61146 m .31979 .61166 L .32089 .615 L F
0 0 .514 r
.31972 .61145 m .32089 .615 L .31969 .61142 L F
.095 .176 .658 r
.31979 .61166 m .31888 .61264 L .32089 .615 L F
0 0 .514 r
.32001 .61176 m .32089 .615 L .31972 .61145 L F
.32009 .61184 m .31972 .61145 L .31998 .61146 L F
.3201 .61187 m .32089 .615 L .32001 .61176 L F
0 0 .201 r
.3201 .61187 m .32089 .615 L .32047 .61326 L F
.3201 .61187 m .32047 .61326 L .32073 .61274 L F
.31995 .61135 m .32006 .61173 L .32195 .61031 L F
0 0 .514 r
.32171 .61148 m .32044 .61144 L .32195 .61031 L F
.095 .176 .658 r
.31995 .61135 m .31987 .61146 L .31998 .61146 L F
.31987 .61146 m .31888 .61264 L .31998 .61146 L F
.98 .685 .354 r
.42222 .53596 m .42405 .5398 L .42564 .53701 L F
.42222 .53596 m .42218 .53872 L .42405 .5398 L F
.911 .546 .329 r
.42218 .54165 m .42405 .5398 L .42218 .53872 L F
.42218 .54165 m .42437 .54293 L .42405 .5398 L F
.872 .659 .61 r
.29089 .67811 m .2929 .68168 L .29068 .68185 L F
.794 .421 .349 r
.29068 .68185 m .2929 .68168 L .29064 .68394 L F
.693 .282 .261 r
.2929 .68168 m .29514 .68413 L .29064 .68394 L F
.405 .235 .534 r
.60116 .36881 m .60131 .37151 L .59889 .37227 L F
0 0 0 r
.66021 .32339 m .65717 .32622 L .65949 .32461 L F
.075 0 .043 r
.65949 .32461 m .66228 .32195 L .66021 .32339 L F
.626 .211 .237 r
.33541 .51373 m .33045 .51566 L .33072 .51362 L F
.33541 .51373 m .33316 .51604 L .33045 .51566 L F
.695 .3 .294 r
.33725 .51613 m .33316 .51604 L .33541 .51373 L F
.982 .733 .482 r
.36907 .5107 m .36722 .51217 L .36697 .50966 L F
.36907 .5107 m .36884 .5134 L .36722 .51217 L F
.48 .691 .961 r
.37561 .46966 m .37271 .47102 L .37164 .4702 L F
.329 .157 .49 r
.37502 .47182 m .37271 .47102 L .37561 .46966 L F
.37502 .47182 m .3733 .47346 L .37271 .47102 L F
.867 .754 .736 r
.45284 .55593 m .45653 .55611 L .45419 .55965 L F
.741 .568 .659 r
.45653 .55611 m .45845 .56033 L .45419 .55965 L F
.49 .33 .591 r
.48052 .52098 m .48285 .52261 L .483 .51997 L F
.953 .738 .574 r
.483 .51997 m .48285 .52261 L .48052 .52098 L F
.28 .44 .843 r
.28086 .59412 m .28334 .59554 L .28365 .59338 L F
.28086 .59412 m .28339 .59706 L .28334 .59554 L F
.687 .341 0 r
.57694 .38794 m .57846 .39155 L .57769 .38963 L F
0 0 0 r
.41084 .45421 m .41208 .45336 L .41398 .45198 L F
.104 0 0 r
.41398 .45198 m .41575 .45212 L .41625 .45137 L F
.41398 .45198 m .41208 .45336 L .41575 .45212 L F
.826 .812 .837 r
.3421 .64205 m .34579 .63962 L .34469 .6387 L F
.646 .909 .981 r
.34579 .63962 m .34723 .63814 L .34469 .6387 L F
.319 .267 .641 r
.3948 .50362 m .39726 .50623 L .39461 .5072 L F
.643 .415 .558 r
.39494 .50745 m .39522 .51043 L .39828 .50997 L F
.39461 .5072 m .39522 .51043 L .39494 .50745 L F
.668 .507 .658 r
.39522 .51043 m .39524 .51287 L .39828 .50997 L F
.971 .687 .432 r
.39616 .50853 m .39539 .51218 L .39522 .51043 L F
.39539 .51218 m .39524 .51287 L .39522 .51043 L F
0 0 .442 r
.39616 .50853 m .39591 .50673 L .39726 .50623 L F
.971 .687 .432 r
.39616 .50853 m .39828 .50997 L .39524 .51287 L F
.39616 .50853 m .39637 .51123 L .39828 .50997 L F
.861 .938 .566 r
.39816 .50443 m .39616 .50853 L .39726 .50623 L F
.2 .242 .681 r
.39622 .50325 m .39726 .50623 L .3948 .50362 L F
.257 .278 .691 r
.39816 .50443 m .39726 .50623 L .39622 .50325 L F
.861 .938 .566 r
.39816 .50443 m .39626 .50648 L .39616 .50853 L F
0 0 .147 r
.39626 .50648 m .39634 .50975 L .39616 .50853 L F
.39634 .50975 m .39637 .51123 L .39616 .50853 L F
0 0 .442 r
.39616 .50853 m .39461 .5072 L .39591 .50673 L F
.39616 .50853 m .39522 .51043 L .39461 .5072 L F
.382 .341 .689 r
.23724 .55323 m .23752 .55708 L .23992 .5556 L F
.255 .099 .467 r
.23752 .55708 m .23976 .55841 L .23992 .5556 L F
.23752 .55708 m .23746 .55989 L .23976 .55841 L F
.97 .707 .478 r
.42059 .53248 m .42222 .53596 L .42146 .53373 L F
.217 .733 .707 r
.61594 .34322 m .61868 .34243 L .61951 .34224 L F
.223 0 0 r
.61868 .34243 m .62236 .34106 L .61951 .34224 L F
.062 0 0 r
.60916 .34411 m .61178 .34423 L .61323 .34422 L F
.352 .828 .83 r
.61323 .34422 m .61445 .34333 L .61594 .34322 L F
.61323 .34422 m .61178 .34423 L .61445 .34333 L F
.907 .957 .622 r
.62569 .3669 m .62406 .36993 L .62552 .36919 L F
0 0 .357 r
.52833 .44418 m .5284 .44155 L .52965 .44036 L F
.024 0 0 r
.64727 .33198 m .65085 .3297 L .64814 .33079 L F
0 .108 .587 r
.59879 .42265 m .60122 .4248 L .59893 .42293 L F
0 .144 .648 r
.4242 .55243 m .42674 .55481 L .42645 .5532 L F
.67 .7 .869 r
.32897 .66149 m .33304 .66211 L .33014 .66291 L F
.514 .518 .798 r
.33319 .66478 m .33014 .66291 L .33304 .66211 L F
0 .34 .755 r
.30811 .54655 m .30757 .54689 L .30592 .54494 L F
.642 .961 .793 r
.27153 .60583 m .27274 .60549 L .27361 .60414 L F
.396 .723 .989 r
.27274 .60549 m .27544 .60555 L .27361 .60414 L F
.993 .769 .491 r
.58208 .36707 m .58359 .36863 L .58377 .36591 L F
.939 .955 .645 r
.58497 .36117 m .58326 .3649 L .58377 .36591 L F
.94 .953 .64 r
.58326 .3649 m .58208 .36707 L .58377 .36591 L F
.77 .547 .596 r
.58377 .36591 m .58359 .36863 L .58766 .36902 L F
.069 0 0 r
.32097 .62556 m .31738 .62782 L .31987 .62758 L F
.822 .93 .553 r
.32269 .62154 m .32097 .62556 L .32097 .62508 L F
.756 .833 .374 r
.32097 .62508 m .32097 .62556 L .31987 .62758 L F
.884 .791 .301 r
.56034 .43168 m .5599 .43451 L .55962 .43311 L F
.502 .233 .439 r
.3868 .49054 m .3869 .4877 L .38441 .49008 L F
.442 .186 .429 r
.38967 .48874 m .3869 .4877 L .3868 .49054 L F
.38967 .48874 m .3869 .4877 L .3868 .49054 L F
.38967 .48874 m .3869 .4877 L .3868 .49054 L F
.682 .856 .966 r
.6353 .38649 m .6365 .38845 L .63263 .38833 L F
.992 .87 .602 r
.66734 .37246 m .6657 .37295 L .6666 .37129 L F
0 0 .013 r
.66734 .37246 m .66487 .37624 L .66673 .37448 L F
.992 .87 .602 r
.66734 .37246 m .66673 .37448 L .6657 .37295 L F
.651 .638 .824 r
.30987 .63721 m .31147 .64001 L .31366 .63865 L F
0 0 .326 r
.24436 .59419 m .24436 .59853 L .24375 .59593 L F
.618 .944 .947 r
.53529 .48806 m .538 .4873 L .53721 .48664 L F
.843 .998 .781 r
.538 .4873 m .54009 .48347 L .53721 .48664 L F
.538 .4873 m .54074 .48406 L .54009 .48347 L F
.996 .763 .446 r
.48096 .56193 m .48233 .56315 L .4811 .55923 L F
.57 .02 0 r
.52134 .44155 m .52547 .44479 L .52407 .44105 L F
.518 .367 .616 r
.51016 .42151 m .51271 .4203 L .5125 .41842 L F
.344 .804 .688 r
.51195 .42055 m .51016 .42151 L .50737 .42257 L F
.51195 .42055 m .51271 .4203 L .51016 .42151 L F
.898 .97 .659 r
.55715 .44058 m .5555 .44201 L .55568 .44164 L F
.99 .761 .495 r
.55752 .43764 m .55805 .43993 L .55715 .44058 L F
0 0 0 r
.55752 .43764 m .55715 .44058 L .55767 .43755 L F
.894 .71 .646 r
.55798 .44295 m .55454 .44424 L .55483 .44244 L F
.55561 .44136 m .55483 .44244 L .55507 .441 L F
.898 .97 .659 r
.55715 .44058 m .55568 .44164 L .55625 .44046 L F
.838 .464 .342 r
.55715 .44058 m .55798 .44295 L .5555 .44201 L F
.55715 .44058 m .55798 .44295 L .5555 .44201 L F
.917 .921 .801 r
.55767 .43755 m .5555 .44201 L .55464 .43943 L F
.62 .781 .958 r
.5555 .44201 m .55798 .44295 L .55519 .44108 L F
.5555 .44201 m .55519 .44108 L .55507 .441 L F
.97 .9 .695 r
.55394 .43986 m .55507 .441 L .55329 .44098 L F
.941 .784 .658 r
.55507 .441 m .55486 .44121 L .55329 .44098 L F
.55486 .44121 m .55295 .4431 L .55317 .44174 L F
.55486 .44121 m .55317 .44174 L .55329 .44098 L F
.917 .921 .801 r
.55464 .43943 m .5552 .4411 L .55394 .43986 L F
.941 .784 .658 r
.55507 .441 m .55454 .44424 L .5532 .44328 L F
.55507 .441 m .5532 .44328 L .55295 .4431 L F
.97 .9 .695 r
.55394 .43986 m .55491 .4412 L .55507 .441 L F
.55491 .4412 m .5555 .44201 L .55507 .441 L F
.917 .921 .801 r
.5552 .4411 m .5555 .44201 L .55491 .4412 L F
.5552 .4411 m .55491 .4412 L .55394 .43986 L F
.894 .71 .646 r
.55798 .44295 m .55483 .44244 L .55561 .44136 L F
.898 .97 .659 r
.55746 .43878 m .55625 .44046 L .55767 .43755 L F
.55715 .44058 m .55625 .44046 L .55746 .43878 L F
.99 .761 .495 r
.55805 .43993 m .55858 .44224 L .55715 .44058 L F
.876 .473 .023 r
.55858 .44224 m .55798 .44295 L .55715 .44058 L F
0 0 0 r
.55921 .44214 m .55798 .44295 L .55858 .44224 L F
.718 .766 .89 r
.35259 .5698 m .35458 .57287 L .35055 .57265 L F
.848 .909 .877 r
.35579 .56869 m .35458 .57287 L .35259 .5698 L F
.35579 .56869 m .35754 .57006 L .35458 .57287 L F
.776 .608 .672 r
.42052 .56283 m .42465 .56342 L .42352 .56587 L F
.763 .994 .874 r
.67224 .38141 m .67479 .37832 L .6718 .38107 L F
.67224 .38141 m .6755 .37888 L .67479 .37832 L F
.774 .374 .294 r
.36523 .50705 m .36299 .50881 L .36275 .50658 L F
.36523 .50705 m .36697 .50966 L .36299 .50881 L F
.636 .7 .892 r
.48623 .43829 m .49065 .43935 L .48893 .43745 L F
.756 .745 .842 r
.49065 .43935 m .49297 .43787 L .48893 .43745 L F
.762 .595 .67 r
.38613 .49748 m .3864 .50043 L .38998 .49964 L F
.404 .133 .385 r
.3864 .50043 m .38842 .50231 L .38998 .49964 L F
.61 .461 .654 r
.39086 .50149 m .39255 .49929 L .39192 .49937 L F
.561 .921 .747 r
.39281 .49916 m .39353 .49802 L .39427 .49537 L F
.39281 .49916 m .39192 .49937 L .39353 .49802 L F
.61 .461 .654 r
.39255 .49929 m .39353 .49802 L .39192 .49937 L F
0 0 0 r
.39072 .49951 m .39192 .49937 L .39281 .49916 L F
.38998 .49964 m .39192 .49937 L .39072 .49951 L F
.191 0 0 r
.38998 .49964 m .39086 .50149 L .39192 .49937 L F
.38998 .49964 m .38842 .50231 L .39086 .50149 L F
0 0 0 r
.65717 .32622 m .65866 .32651 L .65949 .32461 L F
.65717 .32622 m .65617 .32768 L .65866 .32651 L F
.613 .482 .678 r
.60678 .39263 m .60629 .39437 L .60962 .39194 L F
.60678 .39263 m .60629 .39437 L .60962 .39194 L F
.396 .188 .475 r
.624 .36254 m .62679 .36177 L .62664 .35897 L F
.592 .437 .641 r
.62424 .36478 m .62679 .36177 L .624 .36254 L F
.396 .188 .475 r
.624 .36254 m .62679 .36177 L .62664 .35897 L F
.592 .437 .641 r
.62679 .36177 m .62424 .36478 L .624 .36254 L F
.389 .17 .457 r
.624 .36254 m .62424 .36478 L .62679 .36177 L F
.58 .159 .208 r
.51747 .40609 m .5161 .40813 L .51272 .40778 L F
.001 0 0 r
.51876 .40644 m .51747 .40609 L .5193 .40445 L F
.51876 .40644 m .5161 .40813 L .51747 .40609 L F
.646 .663 .852 r
.60678 .39263 m .60844 .38904 L .60582 .39002 L F
.60678 .39263 m .60962 .39194 L .60844 .38904 L F
.794 .52 .522 r
.58359 .36863 m .58778 .37175 L .58766 .36902 L F
.436 .362 .675 r
.58766 .36902 m .5898 .36916 L .58958 .36418 L F
.712 .668 .805 r
.58778 .37175 m .5898 .36916 L .58766 .36902 L F
.425 .1 .31 r
.32461 .67125 m .32604 .67389 L .32358 .6743 L F
.32461 .67125 m .32721 .6709 L .32604 .67389 L F
.888 .967 .646 r
.35105 .5517 m .35104 .55351 L .35327 .54935 L F
0 0 .191 r
.35105 .5517 m .3514 .55462 L .35104 .55351 L F
.903 .657 .556 r
.36739 .56197 m .36976 .56001 L .36753 .5594 L F
.36739 .56197 m .3696 .56266 L .36976 .56001 L F
.726 .614 .732 r
.26639 .53068 m .26425 .53375 L .26268 .52936 L F
.614 .831 .439 r
.26628 .53078 m .26425 .53375 L .26639 .53068 L F
.353 .264 .615 r
.26628 .53078 m .26626 .53583 L .26425 .53375 L F
.55 .279 .458 r
.26425 .53375 m .26626 .53583 L .26365 .53606 L F
.363 .832 .792 r
.53886 .47674 m .54064 .47575 L .54179 .47358 L F
.53886 .47674 m .53807 .47676 L .54064 .47575 L F
.31 0 .149 r
.32823 .61201 m .32562 .61266 L .32513 .61446 L F
.303 .12 .459 r
.2598 .54204 m .2582 .53985 L .25967 .53899 L F
.2598 .54204 m .2586 .54357 L .2582 .53985 L F
.965 .924 .705 r
.39531 .57923 m .39392 .57813 L .39648 .57636 L F
.953 .948 .721 r
.39648 .57636 m .39392 .57813 L .39611 .57412 L F
.41 .753 .994 r
.60606 .39614 m .6042 .39752 L .60287 .39565 L F
.60606 .39614 m .60723 .39724 L .6042 .39752 L F
.421 0 .086 r
.35563 .56579 m .35561 .56629 L .35323 .56642 L F
.358 .002 .216 r
.53307 .38593 m .52989 .38841 L .53259 .38767 L F
.353 0 .214 r
.53259 .38767 m .53526 .38702 L .53307 .38593 L F
.341 .012 .253 r
.53307 .38593 m .53526 .38702 L .53571 .3851 L F
.311 .787 .696 r
.4373 .44543 m .43674 .4458 L .43494 .44647 L F
.4373 .44543 m .43922 .44475 L .43674 .4458 L F
.625 .959 .823 r
.44811 .44036 m .44614 .44189 L .44392 .44251 L F
.697 .747 .89 r
.61724 .41374 m .61916 .40975 L .61767 .41237 L F
.61724 .41374 m .62115 .41188 L .61916 .40975 L F
.424 .18 .438 r
.26362 .60367 m .26228 .60542 L .26436 .60555 L F
.605 .533 .747 r
.38185 .45793 m .38566 .46039 L .38418 .45761 L F
.824 .668 .689 r
.37527 .57601 m .37654 .57655 L .37486 .57282 L F
.893 .707 .643 r
.3748 .57831 m .37654 .57655 L .37527 .57601 L F
.3748 .57831 m .37626 .57943 L .37654 .57655 L F
.596 .871 .544 r
.46515 .54459 m .46539 .54401 L .46775 .54339 L F
.46515 .54459 m .46404 .5456 L .46539 .54401 L F
.858 .995 .755 r
.50077 .50413 m .49818 .50748 L .49875 .50507 L F
.821 .988 .876 r
.49818 .50748 m .49548 .50801 L .49875 .50507 L F
.606 .595 .814 r
.52547 .44479 m .52738 .43998 L .52407 .44105 L F
.805 .592 .614 r
.72438 .30608 m .72466 .30338 L .72053 .30225 L F
.069 .185 .678 r
.52253 .38444 m .52493 .38739 L .52487 .3843 L F
.52253 .38444 m .52533 .38902 L .52493 .38739 L F
.976 .818 .406 r
.56148 .41748 m .5618 .42178 L .56006 .42041 L F
.976 .741 .517 r
.56006 .42041 m .5618 .42178 L .56148 .42439 L F
.78 .679 .752 r
.3633 .49028 m .36765 .48981 L .36673 .48839 L F
.212 0 .324 r
.3633 .49028 m .36569 .49095 L .36765 .48981 L F
.946 .799 .666 r
.36629 .49164 m .36765 .48981 L .36569 .49095 L F
.36629 .49164 m .36977 .48944 L .36765 .48981 L F
.293 .776 .916 r
.4386 .59925 m .44259 .59922 L .44125 .59884 L F
.514 .901 .948 r
.44259 .59922 m .44518 .59815 L .44362 .59793 L F
.508 .895 .954 r
.44125 .59884 m .44259 .59922 L .44362 .59793 L F
.657 .72 .895 r
.35207 .5636 m .35323 .56642 L .35075 .56547 L F
.782 .359 .246 r
.35323 .56642 m .35143 .56815 L .35075 .56547 L F
.979 .825 .619 r
.35268 .5639 m .35323 .56642 L .35207 .5636 L F
.733 .392 .403 r
.35561 .56629 m .35143 .56815 L .35323 .56642 L F
.846 .595 .559 r
.69381 .328 m .69777 .32638 L .69383 .32555 L F
.69381 .328 m .69684 .32884 L .69777 .32638 L F
.821 .615 .625 r
.37306 .56612 m .37278 .56962 L .37515 .56994 L F
.871 .677 .637 r
.37313 .57174 m .37515 .56994 L .37278 .56962 L F
.37313 .57174 m .37486 .57282 L .37515 .56994 L F
.393 .029 .223 r
.29537 .59796 m .29328 .59823 L .29166 .59927 L F
.555 .296 .479 r
.31204 .67772 m .31164 .68116 L .30884 .68146 L F
.43 .172 .42 r
.3155 .67455 m .31433 .67755 L .31204 .67772 L F
.547 .331 .538 r
.31433 .67755 m .31164 .68116 L .31204 .67772 L F
0 0 0 r
.50077 .50413 m .502 .5024 L .50296 .5005 L F
.642 .953 .753 r
.50077 .50413 m .49875 .50507 L .502 .5024 L F
.911 .969 .799 r
.67162 .35901 m .66904 .35963 L .67008 .3577 L F
.67162 .35901 m .6689 .3628 L .66904 .35963 L F
.28 .179 .557 r
.23595 .56319 m .23767 .56241 L .23746 .55989 L F
.23595 .56319 m .23778 .56555 L .23767 .56241 L F
.126 .138 .602 r
.23659 .56554 m .23778 .56555 L .23595 .56319 L F
.862 .445 0 r
.42631 .56161 m .4264 .56015 L .42675 .55906 L F
.42631 .56161 m .42757 .56263 L .4264 .56015 L F
.722 .952 .951 r
.54074 .48406 m .54145 .4816 L .54009 .48347 L F
.54074 .48406 m .54297 .48259 L .54145 .4816 L F
.989 .811 .426 r
.72382 .31591 m .72417 .31288 L .72336 .31141 L F
.563 .597 .846 r
.27595 .52671 m .27178 .52364 L .27446 .52323 L F
.564 .815 .441 r
.27595 .52671 m .27416 .52898 L .27321 .53022 L F
0 0 .238 r
.27705 .52249 m .27595 .52671 L .27446 .52323 L F
.27705 .52249 m .27704 .52537 L .27595 .52671 L F
0 0 0 r
.27704 .52537 m .27416 .52898 L .27595 .52671 L F
.87 .994 .759 r
.6689 .3628 m .66671 .3657 L .66686 .36354 L F
0 .163 .698 r
.66686 .36354 m .66671 .3657 L .66874 .36772 L F
.773 .859 .914 r
.43701 .57318 m .43309 .5733 L .43512 .57178 L F
.43701 .57318 m .43222 .57462 L .43309 .5733 L F
.881 .617 .534 r
.57705 .43362 m .58028 .43158 L .57863 .42999 L F
.57705 .43362 m .58033 .43428 L .58028 .43158 L F
.407 .316 .64 r
.23724 .55323 m .23923 .5527 L .23857 .55017 L F
.382 .341 .689 r
.23724 .55323 m .23992 .5556 L .23923 .5527 L F
.857 .944 .874 r
.28225 .59927 m .28532 .59973 L .28249 .60224 L F
.551 .908 .966 r
.28534 .59895 m .28532 .59973 L .28225 .59927 L F
.28747 .59873 m .28225 .59927 L .28445 .59804 L F
.815 .332 0 r
.28362 .59942 m .28592 .60083 L .28486 .59881 L F
.28411 .5986 m .28486 .59881 L .28445 .59804 L F
.28362 .59942 m .28486 .59881 L .28411 .5986 L F
.551 .908 .966 r
.28747 .59873 m .28637 .59924 L .28534 .59895 L F
.28637 .59924 m .28532 .59973 L .28534 .59895 L F
.567 .381 .588 r
.35055 .57265 m .35165 .57575 L .34814 .5735 L F
.988 .787 .544 r
.27361 .60414 m .27541 .60227 L .27411 .60143 L F
.416 0 .033 r
.3282 .5014 m .33029 .50223 L .33206 .50026 L F
.647 .207 .191 r
.33206 .50026 m .33461 .50228 L .33452 .50051 L F
.33206 .50026 m .33029 .50223 L .33461 .50228 L F
.386 0 0 r
.38903 .45895 m .39331 .45722 L .3884 .4574 L F
.959 .817 .66 r
.35746 .62745 m .35947 .62839 L .35797 .62485 L F
.832 .909 .891 r
.35716 .62981 m .35947 .62839 L .35746 .62745 L F
.838 .794 .809 r
.35797 .62485 m .35947 .62839 L .36196 .62501 L F
.94 .675 .508 r
.31026 .60646 m .31153 .60933 L .30856 .60936 L F
.31026 .60646 m .31153 .60933 L .30856 .60936 L F
.963 .63 .289 r
.31026 .60646 m .31153 .60933 L .30897 .6051 L F
.484 .204 .412 r
.31153 .60933 m .30801 .61233 L .30856 .60936 L F
0 0 .295 r
.30856 .60936 m .30881 .61064 L .31153 .60933 L F
.484 .204 .412 r
.31153 .60933 m .31104 .61203 L .30801 .61233 L F
.366 .419 .784 r
.31026 .60646 m .31327 .60856 L .31153 .60933 L F
.884 .858 .81 r
.30881 .61064 m .31327 .60856 L .31153 .60933 L F
.366 .419 .784 r
.31026 .60646 m .31327 .60856 L .31153 .60933 L F
.148 0 .298 r
.31327 .60856 m .31104 .61203 L .31153 .60933 L F
0 0 .082 r
.34052 .58654 m .34119 .58765 L .34428 .5859 L F
.839 .479 .372 r
.34119 .58765 m .34627 .58919 L .34428 .5859 L F
.721 .932 .959 r
.46043 .44732 m .46163 .44476 L .45922 .44655 L F
.46043 .44732 m .46384 .4454 L .46163 .44476 L F
.966 .641 .31 r
.39531 .57923 m .39391 .5811 L .39392 .57813 L F
.39531 .57923 m .39563 .58249 L .39391 .5811 L F
.88 .595 .501 r
.3696 .56266 m .36965 .56589 L .37306 .56612 L F
.84 .633 .623 r
.36902 .56861 m .37306 .56612 L .36965 .56589 L F
.36902 .56861 m .37278 .56962 L .37306 .56612 L F
.425 .666 .961 r
.31912 .54206 m .32046 .54373 L .32208 .54185 L F
.499 0 0 r
.26639 .53068 m .26876 .5324 L .26628 .53078 L F
.357 .831 .833 r
.55044 .4012 m .55247 .40017 L .55197 .40069 L F
0 0 .07 r
.55197 .40069 m .55247 .39963 L .55599 .39838 L F
.55247 .39963 m .55275 .39905 L .55317 .39897 L F
.55247 .39963 m .55317 .39897 L .55599 .39838 L F
0 0 .225 r
.55129 .40077 m .55156 .40265 L .55247 .40017 L F
.55044 .4012 m .55061 .40142 L .55129 .40077 L F
.55061 .40142 m .55156 .40265 L .55129 .40077 L F
.55044 .4012 m .55058 .40464 L .55156 .40265 L F
0 0 .467 r
.6589 .39331 m .65767 .39239 L .65906 .39034 L F
.027 0 0 r
.59435 .35325 m .59048 .35406 L .59294 .35111 L F
.59435 .35325 m .59353 .35372 L .59048 .35406 L F
.724 .916 .561 r
.59567 .35059 m .59435 .35325 L .59734 .35227 L F
.59567 .35059 m .59353 .35372 L .59435 .35325 L F
.415 .852 .741 r
.38078 .49555 m .38017 .49561 L .38266 .49471 L F
.022 0 .329 r
.38441 .49008 m .38266 .49471 L .38664 .49274 L F
.823 1 .809 r
.38266 .49471 m .38298 .49276 L .38664 .49274 L F
.38266 .49471 m .38017 .49561 L .38298 .49276 L F
.681 .917 .973 r
.46765 .44177 m .47062 .44285 L .47308 .44146 L F
.821 .892 .893 r
.66673 .37448 m .66487 .37624 L .66354 .3748 L F
.935 .968 .718 r
.66904 .35963 m .6689 .3628 L .66686 .36354 L F
.968 .885 .695 r
.57072 .40698 m .57089 .41082 L .57186 .40794 L F
.642 .914 .98 r
.57293 .40574 m .57186 .40794 L .57432 .40486 L F
.57293 .40574 m .57072 .40698 L .57186 .40794 L F
.856 .664 .642 r
.37766 .58929 m .37946 .58972 L .37771 .58598 L F
.794 .661 .717 r
.37766 .58929 m .37908 .59252 L .37946 .58972 L F
.446 .417 .733 r
.703 .31637 m .70463 .31173 L .70208 .31265 L F
.703 .31637 m .70545 .3158 L .70463 .31173 L F
.596 .579 .804 r
.70426 .32012 m .70545 .3158 L .703 .31637 L F
.564 .444 .675 r
.31831 .5792 m .32114 .5793 L .32214 .57704 L F
.596 .579 .804 r
.70426 .32012 m .70701 .31981 L .70545 .3158 L F
.588 .477 .694 r
.70426 .32012 m .70442 .32298 L .70701 .31981 L F
0 0 0 r
.31927 .53585 m .31622 .5402 L .31754 .53866 L F
.31927 .53585 m .31754 .53866 L .31793 .53643 L F
.562 .91 .696 r
.31927 .53585 m .31983 .53495 L .32213 .53667 L F
.31927 .53585 m .31793 .53643 L .31983 .53495 L F
.307 .783 .923 r
.34373 .57321 m .33955 .57324 L .34149 .57289 L F
.517 .865 .61 r
.5092 .39972 m .50957 .39915 L .5112 .398 L F
.5092 .39972 m .50763 .40084 L .50957 .39915 L F
.71 .985 .877 r
.67694 .37665 m .6755 .37888 L .67731 .37723 L F
.704 .979 .905 r
.67479 .37832 m .6755 .37888 L .67694 .37665 L F
.61 .049 0 r
.55625 .39534 m .55497 .3958 L .55564 .39409 L F
.55625 .39534 m .55847 .39732 L .55497 .3958 L F
.865 .767 .752 r
.3764 .59866 m .3742 .60229 L .37747 .60242 L F
.87 .502 .347 r
.34478 .51024 m .34635 .51357 L .34842 .51387 L F
.882 .535 .388 r
.34635 .51357 m .34652 .51564 L .34842 .51387 L F
.809 .418 .313 r
.34842 .51387 m .34652 .51564 L .34913 .51594 L F
.911 .894 .799 r
.59992 .43088 m .60175 .42893 L .60098 .42591 L F
0 0 .082 r
.34052 .58654 m .33981 .5887 L .34119 .58765 L F
0 0 0 r
.40701 .45484 m .4099 .45444 L .41084 .45421 L F
.404 .849 .752 r
.41084 .45421 m .4099 .45444 L .41208 .45336 L F
.714 .986 .875 r
.26711 .61381 m .26779 .61392 L .26706 .61449 L F
0 0 .124 r
.26706 .61449 m .26721 .61639 L .26711 .61381 L F
.629 .17 0 r
.52071 .39912 m .52078 .39921 L .52148 .39979 L F
.838 .956 .613 r
.52148 .39979 m .52122 .40073 L .52181 .40006 L F
.158 .01 .416 r
.52139 .40288 m .52122 .40073 L .52148 .39979 L F
.471 .368 .655 r
.52148 .39979 m .52339 .40251 L .52139 .40288 L F
.629 .17 0 r
.52078 .39921 m .52339 .40251 L .52148 .39979 L F
.838 .956 .613 r
.52148 .39979 m .52181 .40006 L .52272 .39901 L F
.693 .807 .348 r
.52356 .39688 m .52272 .39901 L .52466 .39479 L F
.771 .952 .628 r
.52356 .39688 m .52148 .39979 L .52272 .39901 L F
.335 .406 .787 r
.53449 .47559 m .53241 .47772 L .53121 .47379 L F
.443 .58 .895 r
.53449 .47559 m .53546 .47812 L .53241 .47772 L F
.361 .789 .971 r
.44711 .4896 m .44976 .49016 L .4466 .49029 L F
.627 .086 0 r
.4466 .49029 m .44953 .49309 L .44755 .49181 L F
.624 .377 .523 r
.4466 .49029 m .44976 .49016 L .44953 .49309 L F
.627 .086 0 r
.4466 .49029 m .44755 .49181 L .44711 .4896 L F
.824 .62 .627 r
.39348 .54669 m .3898 .54645 L .38966 .54372 L F
.865 .65 .61 r
.39348 .54669 m .38956 .54766 L .3898 .54645 L F
.39348 .54669 m .39303 .54935 L .38956 .54766 L F
.618 .388 .546 r
.31328 .53233 m .31312 .53505 L .31084 .53449 L F
.31079 .53398 m .31084 .53449 L .31024 .53434 L F
.957 .646 .398 r
.31043 .53071 m .31165 .53349 L .31097 .53025 L F
.31066 .53281 m .31165 .53349 L .31043 .53071 L F
.359 .265 .611 r
.31097 .53025 m .31165 .53349 L .31328 .53233 L F
.31328 .53233 m .31165 .53349 L .31097 .53025 L F
.953 .76 .605 r
.30918 .53179 m .31024 .53434 L .31165 .53349 L F
.46 .854 .657 r
.31328 .53233 m .31024 .53434 L .31165 .53349 L F
.618 .388 .546 r
.31328 .53233 m .31084 .53449 L .31079 .53398 L F
.957 .646 .398 r
.30918 .53179 m .31066 .53281 L .31043 .53071 L F
.67 .188 .098 r
.31097 .53025 m .30918 .53179 L .31328 .53233 L F
.953 .615 .327 r
.25093 .57295 m .25251 .57661 L .25139 .57373 L F
.56 .308 .491 r
.62664 .35897 m .62951 .36109 L .62945 .3585 L F
.62664 .35897 m .62679 .36177 L .62951 .36109 L F
.62951 .36109 m .62664 .35897 L .62945 .3585 L F
.62951 .36109 m .62679 .36177 L .62664 .35897 L F
.888 .967 .646 r
.35105 .5517 m .35327 .54935 L .35111 .54916 L F
.708 .325 .321 r
.35327 .54935 m .35105 .5517 L .35111 .54916 L F
.35327 .54935 m .35564 .55228 L .35105 .5517 L F
.245 .278 .697 r
.46718 .54036 m .46837 .53598 L .46692 .53651 L F
.46718 .54036 m .46929 .53864 L .46837 .53598 L F
0 0 .218 r
.46813 .53962 m .46929 .53864 L .46718 .54036 L F
.082 .063 .534 r
.46718 .54036 m .46775 .54339 L .46813 .53962 L F
.931 .73 .248 r
.58905 .37552 m .58964 .37366 L .58778 .37175 L F
.58937 .3745 m .58972 .37621 L .58964 .37366 L F
.58911 .37557 m .58972 .37621 L .58937 .3745 L F
.689 .532 .668 r
.59222 .37302 m .58972 .37621 L .58964 .37366 L F
.859 .994 .752 r
.58905 .37552 m .58795 .37699 L .58972 .37621 L F
.808 .995 .762 r
.58972 .37621 m .58795 .37699 L .5908 .37377 L F
0 0 .01 r
.5908 .37377 m .58907 .37572 L .5896 .37603 L F
.58907 .37572 m .58795 .37699 L .58889 .37645 L F
.58907 .37572 m .58889 .37645 L .5896 .37603 L F
.931 .73 .248 r
.58905 .37552 m .58911 .37557 L .58937 .3745 L F
.716 .663 .796 r
.58778 .37175 m .58964 .37366 L .59222 .37302 L F
.606 .282 .394 r
.3155 .67455 m .31776 .67723 L .31433 .67755 L F
.3155 .67455 m .3182 .67468 L .31776 .67723 L F
.595 .779 .968 r
.28541 .51146 m .28399 .5135 L .28234 .51134 L F
.28541 .51146 m .28687 .51338 L .28399 .5135 L F
.669 .509 .658 r
.28687 .51338 m .28374 .51685 L .28399 .5135 L F
.697 .695 .844 r
.30533 .63489 m .30705 .63819 L .30852 .63623 L F
.66 .64 .819 r
.30705 .63819 m .30987 .63721 L .30852 .63623 L F
.214 .727 .882 r
.64212 .39879 m .64426 .39807 L .64085 .39844 L F
.64212 .39879 m .64477 .39859 L .64426 .39807 L F
.734 .885 .949 r
.44997 .45029 m .45168 .45163 L .45344 .45 L F
.351 .567 .919 r
.30785 .63432 m .30519 .63476 L .30611 .63228 L F
.3064 .63456 m .30852 .63623 L .30519 .63476 L F
.30785 .63432 m .3083 .63562 L .3064 .63456 L F
.3083 .63562 m .30852 .63623 L .3064 .63456 L F
0 0 .205 r
.30519 .63476 m .30533 .63489 L .30611 .63228 L F
.737 .46 .51 r
.30296 .63229 m .30611 .63228 L .30556 .6341 L F
.30365 .63304 m .30556 .6341 L .30533 .63489 L F
.30296 .63229 m .30556 .6341 L .30365 .63304 L F
.385 .183 .479 r
.59731 .39375 m .59941 .39201 L .59857 .39352 L F
.192 .208 .648 r
.59847 .39618 m .59731 .39375 L .59857 .39352 L F
.362 0 0 r
.62515 .34072 m .62796 .34074 L .62918 .33943 L F
.233 0 0 r
.62796 .34074 m .63197 .33896 L .62918 .33943 L F
.969 .692 .453 r
.56123 .44771 m .55949 .44966 L .55952 .44666 L F
.56123 .44771 m .56127 .45087 L .55949 .44966 L F
0 .104 .657 r
.71387 .31024 m .71547 .31196 L .71337 .30861 L F
.093 0 .279 r
.39678 .50044 m .39622 .50325 L .3948 .50362 L F
.841 .616 .598 r
.68522 .32133 m .68951 .31952 L .68537 .31866 L F
.68522 .32133 m .68752 .32208 L .68951 .31952 L F
.83 .599 .589 r
.68951 .31952 m .68752 .32208 L .69093 .32268 L F
0 0 0 r
.54179 .47358 m .5437 .47262 L .54518 .47147 L F
.729 .981 .912 r
.54518 .47147 m .54618 .46916 L .54679 .46988 L F
.753 .939 .602 r
.54518 .47147 m .5437 .47262 L .54618 .46916 L F
.05 .382 .845 r
.40763 .59564 m .40838 .59448 L .40603 .59328 L F
.246 .641 .961 r
.40763 .59564 m .41002 .59592 L .40838 .59448 L F
.1 0 0 r
.48893 .43745 m .49297 .43787 L .49147 .43774 L F
.494 .898 .927 r
.49147 .43774 m .49297 .43787 L .49545 .43684 L F
.159 0 0 r
.64786 .39889 m .64882 .39898 L .6514 .39949 L F
.745 .993 .851 r
.68649 .37137 m .68955 .36788 L .68639 .37074 L F
.68649 .37137 m .69005 .36847 L .68955 .36788 L F
.863 .695 .671 r
.37605 .5822 m .37771 .58598 L .37816 .58313 L F
.916 .731 .637 r
.33961 .51723 m .3389 .52017 L .33725 .51613 L F
.97 .659 .28 r
.41661 .52475 m .41722 .52871 L .41828 .52946 L F
.729 .225 0 r
.41882 .5312 m .41828 .52946 L .41722 .52871 L F
.41882 .5312 m .42059 .53248 L .41828 .52946 L F
.963 .707 .5 r
.38835 .53679 m .38621 .5384 L .38628 .53572 L F
.38835 .53679 m .38821 .5396 L .38621 .5384 L F
.921 .717 .225 r
.49495 .44506 m .49499 .44866 L .49436 .44685 L F
0 0 0 r
.49602 .44378 m .49495 .44506 L .49436 .44685 L F
.91 .742 .661 r
.33077 .60043 m .32449 .59984 L .32768 .59818 L F
.817 .552 .538 r
.32449 .59984 m .3324 .59878 L .33077 .60043 L F
.73 .599 .71 r
.2964 .58089 m .29873 .58334 L .29603 .58265 L F
.88 .716 .674 r
.29603 .58265 m .29444 .58343 L .29415 .57975 L F
.602 .949 .813 r
.29603 .58265 m .29451 .58331 L .29444 .58343 L F
.815 .406 .273 r
.29403 .58352 m .29033 .58133 L .29444 .58343 L F
.602 .949 .813 r
.29451 .58331 m .29403 .58352 L .29437 .58345 L F
.29451 .58331 m .29437 .58345 L .29444 .58343 L F
.746 .44 .464 r
.29457 .5835 m .29451 .58331 L .29603 .58265 L F
.675 .595 .758 r
.30168 .58295 m .29873 .58334 L .2964 .58089 L F
.73 .599 .71 r
.2964 .58089 m .29603 .58265 L .29415 .57975 L F
.811 .561 .56 r
.29763 .57883 m .30067 .58213 L .2964 .58089 L F
.675 .595 .758 r
.30168 .58295 m .29695 .5811 L .30067 .58213 L F
.29695 .5811 m .2964 .58089 L .29697 .58106 L F
.29695 .5811 m .29697 .58106 L .30067 .58213 L F
.811 .561 .56 r
.30008 .58149 m .29695 .58189 L .30067 .58213 L F
.29763 .57883 m .29695 .58189 L .30008 .58149 L F
0 0 0 r
.29765 .57996 m .29695 .58189 L .29725 .58055 L F
.057 0 .414 r
.29765 .57996 m .29586 .58203 L .29695 .58189 L F
.29586 .58203 m .29458 .58352 L .29695 .58189 L F
0 0 0 r
.29765 .57981 m .29725 .58055 L .29763 .57883 L F
.29765 .57996 m .29725 .58055 L .29765 .57981 L F
.746 .44 .464 r
.29873 .58334 m .29429 .58386 L .29403 .58352 L F
.057 0 .414 r
.29458 .58352 m .29429 .58386 L .29477 .58351 L F
.29458 .58352 m .29477 .58351 L .29695 .58189 L F
.746 .44 .464 r
.29809 .58318 m .29523 .58344 L .29603 .58265 L F
.29523 .58344 m .29482 .58348 L .295 .58335 L F
.29523 .58344 m .295 .58335 L .29603 .58265 L F
.29873 .58334 m .29794 .58543 L .29429 .58386 L F
.081 0 .162 r
.30067 .58213 m .29873 .58334 L .30168 .58295 L F
.30067 .58213 m .29794 .58543 L .29873 .58334 L F
.69 .566 .709 r
.29429 .58386 m .29794 .58543 L .2986 .58463 L F
.746 .44 .464 r
.29873 .58334 m .29501 .58348 L .29809 .58318 L F
.69 .566 .709 r
.2955 .58353 m .2986 .58463 L .30067 .58213 L F
.29429 .58386 m .2986 .58463 L .2955 .58353 L F
.746 .44 .464 r
.29501 .58348 m .29457 .5835 L .29809 .58318 L F
.556 .314 .503 r
.2965 .58343 m .29526 .5845 L .29426 .58444 L F
.517 .118 .225 r
.2952 .58455 m .29419 .58602 L .29526 .58455 L F
.556 .314 .503 r
.29521 .58453 m .29422 .5854 L .29423 .58521 L F
.2952 .58455 m .29422 .5854 L .29521 .58453 L F
.29526 .5845 m .29423 .58521 L .29426 .58444 L F
.557 .006 0 r
.29429 .58386 m .29419 .58602 L .292 .58457 L F
.517 .118 .225 r
.292 .58457 m .29419 .58602 L .2952 .58455 L F
.556 .314 .503 r
.29526 .5845 m .2952 .58455 L .29521 .58453 L F
.424 .276 .574 r
.29526 .5845 m .29526 .58455 L .29742 .58302 L F
.605 .427 .614 r
.2952 .58455 m .29526 .58455 L .29526 .5845 L F
.556 .314 .503 r
.29742 .58302 m .29422 .5854 L .2965 .58343 L F
.29742 .58302 m .29426 .58444 L .29466 .58376 L F
.746 .44 .464 r
.29482 .58348 m .29493 .58329 L .29603 .58265 L F
.69 .566 .709 r
.29429 .58386 m .30067 .58213 L .29695 .58189 L F
.057 0 .414 r
.29582 .58208 m .29742 .58302 L .29466 .58376 L F
.746 .44 .464 r
.29482 .58348 m .29457 .5835 L .29493 .58329 L F
.057 0 .414 r
.29582 .58208 m .29466 .58376 L .29458 .58352 L F
.29765 .57996 m .29762 .58039 L .29582 .58208 L F
.29762 .58039 m .29742 .58302 L .29582 .58208 L F
.702 .772 .906 r
.29763 .57883 m .2964 .58089 L .29415 .57975 L F
.424 .276 .574 r
.29555 .57935 m .29526 .5845 L .29742 .58302 L F
.556 .314 .503 r
.29466 .58376 m .29426 .58444 L .29429 .58386 L F
.746 .44 .464 r
.29457 .5835 m .29403 .58352 L .29451 .58331 L F
.057 0 .414 r
.29458 .58352 m .29466 .58376 L .29429 .58386 L F
.707 .374 .411 r
.29033 .58133 m .29415 .57975 L .29444 .58343 L F
.975 .905 .68 r
.29429 .58386 m .29331 .58416 L .29403 .58352 L F
.29331 .58416 m .292 .58457 L .29324 .58393 L F
.29331 .58416 m .29324 .58393 L .29403 .58352 L F
.815 .406 .273 r
.29403 .58352 m .292 .58457 L .29046 .58252 L F
.707 .374 .411 r
.29033 .58133 m .29422 .58373 L .29415 .57975 L F
.234 .475 .885 r
.29132 .58092 m .29275 .5823 L .29033 .58133 L F
.29032 .57994 m .29132 .58092 L .29033 .58133 L F
.605 .427 .614 r
.292 .58457 m .2952 .58455 L .29524 .58388 L F
0 0 .292 r
.29415 .57975 m .29422 .58373 L .29555 .57935 L F
.744 .615 .715 r
.29555 .57935 m .29422 .58373 L .29032 .57994 L F
.605 .427 .614 r
.29324 .58275 m .29524 .58388 L .29555 .57935 L F
.234 .475 .885 r
.29281 .58251 m .29422 .58373 L .29294 .58294 L F
.29318 .58271 m .29422 .58373 L .29281 .58251 L F
.815 .406 .273 r
.29403 .58352 m .29046 .58252 L .29033 .58133 L F
.605 .427 .614 r
.292 .58457 m .29524 .58388 L .29324 .58275 L F
.234 .475 .885 r
.29275 .5823 m .29318 .58271 L .29281 .58251 L F
.29275 .5823 m .29294 .58294 L .29033 .58133 L F
.605 .427 .614 r
.2952 .58455 m .29526 .5845 L .29555 .57935 L F
0 0 0 r
.29419 .58602 m .29742 .58302 L .29526 .58455 L F
.556 .314 .503 r
.29742 .58302 m .29419 .58602 L .29422 .5854 L F
.077 0 0 r
.27321 .53022 m .27092 .53196 L .26876 .5324 L F
.59 .899 .626 r
.27416 .52898 m .27092 .53196 L .27321 .53022 L F
.937 .877 .751 r
.32505 .50368 m .32226 .50451 L .32334 .50229 L F
.32505 .50368 m .32301 .50685 L .32226 .50451 L F
.353 0 0 r
.32334 .50229 m .3282 .5014 L .32505 .50368 L F
.196 .385 .824 r
.40603 .59328 m .40708 .5916 L .40402 .59206 L F
.268 0 0 r
.40395 .59198 m .4061 .5929 L .40336 .59206 L F
.40708 .5916 m .4039 .59199 L .40402 .59206 L F
0 .211 .736 r
.40229 .59129 m .4034 .59289 L .40391 .59196 L F
.268 0 0 r
.4039 .59199 m .40336 .59206 L .40402 .59206 L F
.693 .185 .026 r
.4006 .59017 m .40402 .59206 L .40019 .59069 L F
0 .211 .736 r
.40109 .58954 m .40229 .59129 L .40391 .59196 L F
.693 .185 .026 r
.40109 .58954 m .40402 .59206 L .4006 .59017 L F
.268 0 0 r
.40708 .5916 m .40611 .59289 L .40395 .59198 L F
.40611 .59289 m .4061 .5929 L .40395 .59198 L F
0 .211 .736 r
.40391 .59196 m .4034 .59289 L .40402 .59206 L F
.136 .593 .925 r
.4034 .59289 m .40603 .59328 L .40402 .59206 L F
.712 .668 .805 r
.58778 .37175 m .59222 .37302 L .5898 .36916 L F
.796 .972 .675 r
.59222 .37302 m .58972 .37621 L .5908 .37377 L F
0 .277 .663 r
.59456 .37163 m .5898 .36916 L .59222 .37302 L F
.59372 .37119 m .59374 .37114 L .5898 .36916 L F
.59456 .37163 m .59374 .37114 L .59372 .37119 L F
.326 0 .138 r
.59232 .37213 m .59375 .3711 L .59374 .37114 L F
.565 .5 .741 r
.5926 .3669 m .59374 .37114 L .59593 .36954 L F
.326 0 .138 r
.59375 .3711 m .59593 .36954 L .59374 .37114 L F
.623 .929 .683 r
.59222 .37302 m .59374 .37114 L .59456 .37163 L F
.59222 .37302 m .5908 .37377 L .59374 .37114 L F
.623 .801 .968 r
.48216 .43767 m .48623 .43829 L .48482 .43671 L F
.609 .796 .971 r
.48623 .43829 m .48893 .43745 L .48482 .43671 L F
.48623 .43829 m .48893 .43745 L .48482 .43671 L F
.879 .808 .776 r
.66077 .35817 m .65687 .35885 L .65939 .35986 L F
.66077 .35817 m .65939 .35986 L .6584 .35889 L F
0 0 0 r
.66077 .35817 m .6584 .35889 L .66331 .35759 L F
.896 .97 .658 r
.69575 .33504 m .697 .33327 L .69547 .3342 L F
.935 .824 .71 r
.697 .33327 m .69684 .32884 L .69621 .33162 L F
.992 .881 .566 r
.69547 .3342 m .697 .33327 L .69621 .33162 L F
.454 .834 .988 r
.30296 .63229 m .30611 .63228 L .30367 .6314 L F
.548 .874 .992 r
.30367 .6314 m .30611 .63228 L .30622 .6306 L F
0 .024 .597 r
.30785 .63432 m .30611 .63228 L .30622 .6306 L F
.812 .989 .879 r
.50623 .49772 m .50296 .5005 L .50284 .49936 L F
.883 .829 .358 r
.50296 .5005 m .502 .5024 L .50284 .49936 L F
0 0 0 r
.60962 .39194 m .61279 .38957 L .61189 .3897 L F
.389 .735 .991 r
.25761 .62732 m .2608 .62905 L .2569 .62879 L F
.715 .639 .772 r
.25622 .63293 m .25708 .63251 L .25705 .63283 L F
.25708 .63251 m .25959 .63128 L .25705 .63283 L F
.724 .662 .788 r
.25705 .63283 m .25761 .62732 L .25755 .62745 L F
.25705 .63283 m .25755 .62745 L .2569 .62879 L F
.79 .908 .923 r
.57572 .36127 m .5715 .35877 L .57427 .35806 L F
0 0 .475 r
.57274 .36369 m .57259 .36253 L .57297 .36128 L F
.57259 .36253 m .57218 .35952 L .57297 .36128 L F
.79 .908 .923 r
.57339 .35989 m .57297 .36128 L .5715 .35877 L F
.57572 .36127 m .57297 .36128 L .57339 .35989 L F
0 .331 .713 r
.57427 .35806 m .57825 .36001 L .57572 .36127 L F
.848 .766 .771 r
.35797 .62485 m .36196 .62501 L .36229 .62269 L F
.944 .709 .552 r
.39665 .55955 m .39452 .55888 L .3948 .55601 L F
.919 .571 .363 r
.39665 .55955 m .39485 .56135 L .39452 .55888 L F
.39665 .55955 m .39741 .56267 L .39485 .56135 L F
.522 .764 .985 r
.42181 .575 m .4212 .57679 L .41923 .57549 L F
.42181 .575 m .4212 .57679 L .41923 .57549 L F
.944 .895 .499 r
.33104 .60185 m .33055 .60609 L .33085 .60588 L F
.543 .513 .772 r
.3307 .60865 m .33261 .60482 L .33085 .60588 L F
.667 .607 .779 r
.61119 .39823 m .61501 .39967 L .61345 .40026 L F
.952 .893 .734 r
.35224 .6361 m .35163 .63458 L .35004 .6352 L F
.802 .8 .85 r
.36229 .62269 m .36475 .62172 L .36325 .61842 L F
.844 .815 .822 r
.36325 .61842 m .36475 .62172 L .36758 .6185 L F
.767 .972 .922 r
.631 .40275 m .6333 .403 L .63535 .40124 L F
.801 .995 .867 r
.55716 .46985 m .55508 .4731 L .55764 .47033 L F
.55716 .46985 m .55396 .47268 L .55508 .4731 L F
.73 .474 .54 r
.69093 .32268 m .69383 .32555 L .69378 .32296 L F
.816 .855 .877 r
.36325 .61842 m .36758 .6185 L .36635 .61661 L F
.855 .863 .846 r
.36635 .61661 m .36758 .6185 L .36975 .61504 L F
0 0 .545 r
.23717 .57251 m .23842 .57736 L .23876 .57509 L F
.327 .577 .932 r
.23842 .57736 m .2414 .57772 L .23876 .57509 L F
.911 .641 .516 r
.35699 .52982 m .35701 .53299 L .35924 .53369 L F
.903 .59 .443 r
.35701 .53299 m .35738 .53493 L .35924 .53369 L F
.872 .528 .398 r
.35738 .53493 m .35956 .53639 L .35924 .53369 L F
.707 .727 .866 r
.2799 .59971 m .28249 .60224 L .27792 .60223 L F
.652 .269 .307 r
.27792 .60223 m .28249 .60224 L .28065 .60485 L F
.857 .944 .874 r
.28225 .59927 m .28249 .60224 L .28018 .59999 L F
0 0 0 r
.28269 .59912 m .28225 .59927 L .28125 .59999 L F
.28445 .59804 m .28225 .59927 L .28269 .59912 L F
.857 .944 .874 r
.28225 .59927 m .28018 .59999 L .2799 .59971 L F
.553 .009 0 r
.28249 .60224 m .28306 .60404 L .28065 .60485 L F
.28249 .60224 m .28551 .60327 L .28306 .60404 L F
.767 .966 .67 r
.27365 .51435 m .27096 .51766 L .27208 .51594 L F
.071 0 0 r
.27365 .51435 m .27456 .51468 L .27621 .51368 L F
.27365 .51435 m .27208 .51594 L .27456 .51468 L F
.27 .433 .84 r
.31622 .5402 m .31912 .54206 L .31754 .53866 L F
.973 .676 .29 r
.28452 .66813 m .28576 .66868 L .28576 .67123 L F
0 0 .075 r
.28623 .66545 m .28576 .66868 L .28647 .66668 L F
.682 .965 .934 r
.28647 .66668 m .28576 .66868 L .28452 .66813 L F
.28647 .66668 m .28576 .66868 L .28452 .66813 L F
.172 .232 .684 r
.56152 .37631 m .56224 .3788 L .56169 .37477 L F
.789 .856 .901 r
.32599 .57512 m .32817 .57665 L .32875 .57536 L F
0 0 0 r
.27096 .51766 m .27116 .5184 L .27208 .51594 L F
.27096 .51766 m .26893 .51941 L .27116 .5184 L F
.11 .395 .85 r
.56721 .37522 m .56989 .37665 L .56947 .37862 L F
0 0 .464 r
.57064 .37915 m .56947 .37862 L .56989 .37665 L F
.57064 .37915 m .57042 .38092 L .56947 .37862 L F
.685 .726 .212 r
.50613 .42927 m .50537 .43187 L .50636 .42859 L F
0 0 0 r
.50636 .42859 m .50845 .42856 L .50613 .42927 L F
.50636 .42859 m .51038 .42723 L .50845 .42856 L F
.561 0 0 r
.34248 .5212 m .34162 .52191 L .3389 .52017 L F
.337 .817 .798 r
.43897 .45303 m .43919 .45259 L .43728 .45353 L F
.417 .865 .84 r
.43897 .45303 m .44139 .45141 L .43919 .45259 L F
.43897 .45303 m .44349 .45125 L .44139 .45141 L F
.868 .529 .406 r
.34136 .50672 m .34238 .50981 L .34478 .51024 L F
.862 .508 .38 r
.34238 .50981 m .34257 .51202 L .34478 .51024 L F
.857 .5 .374 r
.34257 .51202 m .34635 .51357 L .34478 .51024 L F
.8 .966 .912 r
.51856 .43254 m .52194 .43114 L .52172 .43076 L F
.221 .719 .912 r
.52172 .43076 m .52194 .43114 L .52599 .43089 L F
.207 0 0 r
.25222 .57472 m .25074 .57612 L .24815 .57654 L F
.2528 .57447 m .25074 .57612 L .25222 .57472 L F
.245 .195 .601 r
.24948 .57812 m .25078 .58013 L .2493 .58062 L F
.805 .685 .732 r
.25078 .58013 m .25013 .57914 L .24948 .57812 L F
.548 .043 .009 r
.24915 .57761 m .24948 .57812 L .24881 .57793 L F
.25074 .57612 m .24981 .57623 L .24815 .57654 L F
.135 0 0 r
.25093 .57295 m .24815 .57654 L .24616 .57691 L F
.207 0 0 r
.2528 .57447 m .24815 .57654 L .25093 .57295 L F
.548 .043 .009 r
.24981 .57623 m .2451 .57682 L .24815 .57654 L F
.135 0 0 r
.24616 .57691 m .24815 .57654 L .24578 .57722 L F
.28 .783 .819 r
.24815 .57654 m .24377 .57738 L .24578 .57722 L F
.24815 .57654 m .2451 .57682 L .24377 .57738 L F
.548 .043 .009 r
.25074 .57612 m .24881 .57793 L .2451 .57682 L F
.608 .051 0 r
.24948 .57812 m .24475 .57446 L .2451 .57682 L F
.807 .686 .732 r
.24829 .57775 m .24686 .57991 L .24795 .57973 L F
.608 .051 0 r
.24948 .57812 m .24841 .57783 L .24475 .57446 L F
.805 .685 .732 r
.25078 .58013 m .24829 .57775 L .24992 .57883 L F
.608 .051 0 r
.24841 .57783 m .24839 .57782 L .24836 .5778 L F
.408 .327 .653 r
.24635 .57458 m .24839 .57782 L .24849 .57664 L F
.807 .686 .732 r
.24849 .57664 m .24802 .57757 L .24829 .57775 L F
.24802 .57757 m .24686 .57991 L .24829 .57775 L F
.608 .051 0 r
.24841 .57783 m .24836 .5778 L .24475 .57446 L F
.805 .685 .732 r
.25078 .58013 m .24795 .57973 L .24829 .57775 L F
.24841 .57783 m .24829 .57775 L .24849 .57664 L F
.995 .854 .512 r
.24849 .57664 m .24839 .57782 L .24841 .57783 L F
.24849 .57664 m .24841 .57783 L .24948 .57812 L F
.805 .685 .732 r
.24992 .57883 m .24841 .57783 L .24849 .57664 L F
.25013 .57914 m .24849 .57664 L .24948 .57812 L F
.548 .043 .009 r
.25074 .57612 m .24948 .57812 L .24915 .57761 L F
0 .054 .615 r
.25138 .57044 m .25093 .57295 L .2488 .57095 L F
.25138 .57044 m .2528 .57447 L .25093 .57295 L F
.019 0 .437 r
.61767 .41237 m .61916 .40975 L .61915 .40734 L F
.675 .678 .845 r
.31133 .65824 m .30718 .65732 L .30977 .65637 L F
.624 .756 .941 r
.31213 .6551 m .31133 .65824 L .30977 .65637 L F
.31213 .6551 m .31418 .65748 L .31133 .65824 L F
.983 .767 .361 r
.30203 .5887 m .30112 .58839 L .30235 .58618 L F
.579 .444 .661 r
.30482 .58258 m .30235 .58618 L .30168 .58295 L F
.30482 .58258 m .30504 .58607 L .30235 .58618 L F
.383 .062 .291 r
.30504 .58607 m .30203 .5887 L .30235 .58618 L F
.30504 .58607 m .30452 .58812 L .30203 .5887 L F
0 0 0 r
.30235 .58618 m .30343 .58715 L .3045 .58609 L F
.30343 .58715 m .30452 .58812 L .3045 .58609 L F
.579 .444 .661 r
.30482 .58258 m .30504 .58607 L .30235 .58618 L F
0 0 0 r
.30235 .58618 m .30413 .58582 L .30452 .58812 L F
.933 .964 .672 r
.30203 .5887 m .29996 .59013 L .30112 .58839 L F
.744 .965 .683 r
.30413 .58582 m .29996 .59013 L .30141 .58913 L F
.3025 .58806 m .30141 .58913 L .30203 .5887 L F
.30413 .58582 m .30141 .58913 L .3025 .58806 L F
0 0 0 r
.3045 .58609 m .30452 .58812 L .30504 .58607 L F
.30235 .58618 m .30112 .58839 L .30413 .58582 L F
.579 .444 .661 r
.30482 .58258 m .30235 .58618 L .30168 .58295 L F
.126 .236 .708 r
.56275 .38678 m .56277 .38386 L .5629 .38392 L F
.673 .285 0 r
.56173 .38155 m .563 .38397 L .5629 .38392 L F
0 0 .437 r
.56173 .38155 m .5629 .38392 L .56278 .38231 L F
.126 .236 .708 r
.56277 .38386 m .56278 .38231 L .5629 .38392 L F
.673 .285 0 r
.563 .38397 m .56374 .38539 L .5629 .38392 L F
.978 .776 .358 r
.56374 .38539 m .56275 .38678 L .5629 .38392 L F
.588 .898 .626 r
.28966 .60075 m .29166 .59927 L .28882 .60177 L F
.774 .571 .625 r
.29166 .59927 m .2916 .60256 L .28882 .60177 L F
.339 0 .132 r
.29214 .60128 m .29166 .59927 L .28966 .60075 L F
.766 .988 .757 r
.48507 .41573 m .48221 .41879 L .48323 .41664 L F
.74 .984 .906 r
.48221 .41879 m .47944 .41911 L .48323 .41664 L F
.553 .782 .984 r
.50613 .42927 m .50793 .43113 L .50537 .43187 L F
.989 .84 .468 r
.56173 .38155 m .56091 .38004 L .56224 .3788 L F
0 0 .24 r
.56169 .37477 m .56224 .3788 L .56213 .37611 L F
.937 .91 .524 r
.56224 .3788 m .56091 .38004 L .56213 .37611 L F
.225 .068 .448 r
.51065 .41107 m .51061 .41377 L .50821 .41509 L F
0 0 .178 r
.51061 .41377 m .50847 .41761 L .50821 .41509 L F
.229 0 0 r
.41625 .45137 m .4186 .45187 L .4204 .4513 L F
.283 0 0 r
.4186 .45187 m .42305 .45135 L .4204 .4513 L F
.789 .303 .061 r
.67236 .33522 m .66821 .33207 L .67222 .33273 L F
.907 .526 .091 r
.57763 .42605 m .57835 .42528 L .57704 .42398 L F
.57763 .42605 m .57896 .42737 L .57835 .42528 L F
.7 .812 .935 r
.28974 .65388 m .28499 .65348 L .28802 .65084 L F
.55 .644 .896 r
.29052 .65037 m .28974 .65388 L .28802 .65084 L F
.29052 .65037 m .29147 .65321 L .28974 .65388 L F
0 0 .1 r
.33648 .56671 m .33549 .56894 L .3381 .56541 L F
.699 .765 .272 r
.5261 .3906 m .52466 .39479 L .52718 .393 L F
.5261 .3906 m .52481 .39419 L .52466 .39479 L F
.703 .811 .351 r
.52481 .39419 m .52356 .39688 L .52466 .39479 L F
.325 .317 .696 r
.25879 .5499 m .25795 .55315 L .25627 .54886 L F
.25879 .5499 m .25965 .55236 L .25795 .55315 L F
.529 .918 .807 r
.45825 .43491 m .45379 .43691 L .45774 .43459 L F
.592 .905 .642 r
.46098 .43241 m .45825 .43491 L .4598 .43313 L F
.618 .942 .95 r
.4598 .43313 m .45825 .43491 L .45774 .43459 L F
.051 0 0 r
.63477 .33837 m .63751 .33759 L .63876 .33635 L F
.039 0 0 r
.63876 .33635 m .64026 .33679 L .64136 .33535 L F
.63876 .33635 m .63751 .33759 L .64026 .33679 L F
.388 0 .132 r
.39545 .48295 m .39294 .48399 L .39764 .48435 L F
.915 .753 .667 r
.32213 .53667 m .32199 .54107 L .32369 .54055 L F
.708 .933 .615 r
.32369 .54055 m .32299 .54041 L .32585 .53892 L F
.522 .823 1 r
.26783 .61221 m .26779 .61392 L .26711 .61381 L F
.26783 .61221 m .27006 .61356 L .26779 .61392 L F
0 .135 .68 r
.2886 .67113 m .28763 .67091 L .28982 .67278 L F
.414 .708 .983 r
.55552 .36475 m .55901 .36475 L .55867 .36608 L F
.43 0 0 r
.55867 .36608 m .5589 .36647 L .55552 .36475 L F
0 0 0 r
.5584 .36704 m .5589 .36647 L .55867 .36608 L F
.075 .506 .899 r
.56094 .36579 m .56237 .3673 L .56033 .36663 L F
.55958 .36597 m .56033 .36663 L .55867 .36608 L F
.56094 .36579 m .56033 .36663 L .55958 .36597 L F
.529 .546 .816 r
.55666 .36019 m .55901 .36475 L .55552 .36475 L F
.959 .787 .626 r
.55666 .36307 m .5572 .36389 L .55901 .36475 L F
0 0 .096 r
.55901 .36475 m .5589 .36647 L .55867 .36608 L F
.959 .787 .626 r
.5572 .36389 m .5589 .36647 L .55896 .36543 L F
.5572 .36389 m .55896 .36543 L .55901 .36475 L F
.075 .506 .899 r
.56094 .36579 m .55867 .36608 L .5589 .36647 L F
.792 .343 0 r
.3589 .49218 m .36009 .49317 L .3586 .49064 L F
.3583 .49051 m .3586 .49064 L .35795 .48954 L F
.3589 .49218 m .3586 .49064 L .3583 .49051 L F
.919 .587 .398 r
.356 .48944 m .35843 .49328 L .35433 .49154 L F
.228 0 0 r
.35621 .49125 m .35865 .48896 L .356 .48944 L F
.916 .967 .66 r
.35711 .48904 m .35865 .48896 L .35741 .49013 L F
.35678 .48986 m .35741 .49013 L .35621 .49125 L F
.35711 .48904 m .35741 .49013 L .35678 .48986 L F
.792 .343 0 r
.3589 .49218 m .35795 .48954 L .35865 .48896 L F
.656 .323 .396 r
.34569 .53021 m .34275 .53195 L .34441 .52896 L F
.867 .714 .691 r
.34914 .5303 m .3476 .53329 L .34644 .52971 L F
0 0 .345 r
.34638 .52952 m .3476 .53329 L .34729 .53178 L F
.656 .323 .396 r
.34729 .53178 m .34309 .53193 L .34569 .53021 L F
.34309 .53193 m .34275 .53195 L .34569 .53021 L F
.867 .714 .691 r
.34662 .52959 m .34644 .52971 L .34638 .52952 L F
.34914 .5303 m .34644 .52971 L .34662 .52959 L F
.692 .98 .89 r
.60341 .36718 m .60253 .36671 L .60116 .36881 L F
.707 .546 0 r
.60119 .36948 m .60116 .36881 L .60253 .36671 L F
.60119 .36948 m .60131 .37151 L .60116 .36881 L F
.812 .989 .879 r
.50623 .49772 m .50284 .49936 L .50376 .49815 L F
.778 .965 .924 r
.50797 .49584 m .50623 .49772 L .50693 .4952 L F
.824 .996 .853 r
.50623 .49772 m .50376 .49815 L .50693 .4952 L F
.75 .517 .579 r
.67741 .3119 m .68182 .31244 L .68215 .30984 L F
.78 .414 .363 r
.38441 .49008 m .38664 .49274 L .38298 .49276 L F
.817 .642 .665 r
.38298 .49276 m .3868 .49054 L .38441 .49008 L F
.835 .628 .622 r
.52754 .38372 m .52989 .38841 L .53022 .38674 L F
.913 .697 .596 r
.29089 .67811 m .2875 .68008 L .28783 .6777 L F
.29089 .67811 m .29068 .68185 L .2875 .68008 L F
.588 .934 .944 r
.45655 .55323 m .45793 .55181 L .4591 .55227 L F
.573 .919 .714 r
.45596 .55343 m .45793 .55181 L .45655 .55323 L F
.54 .726 .96 r
.29679 .65115 m .29686 .65434 L .29449 .65138 L F
.29679 .65115 m .29899 .6537 L .29686 .65434 L F
.54 .639 .897 r
.29899 .6537 m .30049 .65585 L .29686 .65434 L F
.078 0 0 r
.63148 .38998 m .63263 .38833 L .62992 .38948 L F
.63148 .38998 m .62992 .38948 L .62813 .38811 L F
0 0 .237 r
.58863 .40715 m .58877 .40738 L .58812 .40487 L F
0 .167 .668 r
.5924 .41065 m .58877 .40738 L .58863 .40715 L F
.256 .761 .728 r
.45009 .59684 m .45215 .59634 L .45465 .59554 L F
0 0 .304 r
.3278 .59268 m .32915 .59144 L .32957 .58847 L F
.766 .611 .687 r
.32782 .59547 m .33216 .59307 L .3278 .59268 L F
0 0 .264 r
.32782 .59547 m .32915 .59144 L .3278 .59268 L F
.398 0 0 r
.45663 .58354 m .45582 .58287 L .45417 .58382 L F
.45663 .58354 m .45846 .58443 L .45582 .58287 L F
.567 .115 .137 r
.45582 .58287 m .45846 .58443 L .46038 .58299 L F
.743 .395 .392 r
.39424 .46164 m .39063 .46324 L .39107 .46085 L F
.39424 .46164 m .39475 .46355 L .39063 .46324 L F
.805 1 .811 r
.48268 .55233 m .48636 .54977 L .48475 .54841 L F
.48268 .55233 m .48298 .55293 L .48636 .54977 L F
.849 .874 .859 r
.48475 .54841 m .48636 .54977 L .48872 .5469 L F
.764 .684 .774 r
.48636 .54977 m .48943 .54676 L .48872 .5469 L F
0 0 0 r
.24948 .56349 m .24817 .56573 L .24734 .56644 L F
0 0 .147 r
.24813 .56754 m .24734 .56644 L .24817 .56573 L F
.24813 .56754 m .24665 .56904 L .24734 .56644 L F
.539 .841 .999 r
.41512 .46016 m .41906 .4603 L .41748 .46067 L F
.015 0 0 r
.41906 .4603 m .4216 .46004 L .41748 .46067 L F
.347 .798 .658 r
.61367 .40136 m .61528 .40056 L .61394 .40113 L F
0 .521 .797 r
.61528 .40056 m .61667 .40057 L .61394 .40113 L F
.213 0 .055 r
.61667 .40057 m .61501 .39967 L .61394 .40113 L F
.725 .299 .235 r
.61394 .40113 m .61501 .39967 L .61119 .39823 L F
.213 0 .055 r
.61667 .40057 m .61755 .39827 L .61501 .39967 L F
.558 .607 .858 r
.61542 .39669 m .61667 .40057 L .61394 .40113 L F
0 0 0 r
.61394 .40113 m .61529 .4009 L .61456 .4006 L F
.598 .077 0 r
.61197 .39951 m .61394 .40113 L .61119 .39823 L F
.558 .607 .858 r
.61542 .39669 m .61394 .40113 L .61197 .39951 L F
0 0 0 r
.61394 .40113 m .61456 .4006 L .61197 .39951 L F
.347 .798 .658 r
.61095 .40271 m .61367 .40136 L .61394 .40113 L F
.241 0 .087 r
.61893 .40002 m .61755 .39827 L .61667 .40057 L F
.528 .588 .858 r
.61893 .40002 m .61667 .40057 L .61542 .39669 L F
.167 .697 .688 r
.61708 .40047 m .61667 .40057 L .61893 .40002 L F
0 .521 .797 r
.61528 .40056 m .61609 .40071 L .61667 .40057 L F
0 0 0 r
.61394 .40113 m .61667 .40057 L .61529 .4009 L F
.167 .697 .688 r
.61529 .4009 m .61667 .40057 L .61708 .40047 L F
0 .521 .797 r
.61609 .40071 m .61787 .40105 L .61667 .40057 L F
.519 .498 .773 r
.65825 .39504 m .6591 .39762 L .66117 .39704 L F
.812 .469 .407 r
.46108 .57912 m .45724 .57927 L .45891 .57899 L F
0 .387 .713 r
.24987 .61526 m .25409 .61682 L .25271 .61623 L F
.24987 .61526 m .25409 .61682 L .25271 .61623 L F
.696 .918 .969 r
.25599 .61376 m .25409 .61682 L .25271 .61623 L F
.25599 .61376 m .2573 .61501 L .25409 .61682 L F
0 0 .468 r
.25409 .61682 m .25481 .61735 L .25271 .61623 L F
.25409 .61682 m .25477 .61779 L .25481 .61735 L F
.167 .515 .916 r
.49842 .43576 m .50003 .43786 L .50026 .43643 L F
.794 .971 .672 r
.50026 .43643 m .50003 .43786 L .49805 .44002 L F
.669 .401 .507 r
.38798 .46242 m .38566 .46039 L .38674 .46028 L F
.137 0 0 r
.3826 .46081 m .38477 .46086 L .38674 .46028 L F
.515 .077 .144 r
.38477 .46086 m .38616 .46024 L .38674 .46028 L F
.642 .106 0 r
.38418 .45761 m .38674 .46028 L .38729 .46031 L F
.042 .217 .719 r
.38566 .46039 m .38674 .46028 L .38418 .45761 L F
.515 .077 .144 r
.38616 .46024 m .38903 .45895 L .38674 .46028 L F
.642 .106 0 r
.38729 .46031 m .38674 .46028 L .38821 .46111 L F
.66 .922 .975 r
.38821 .46111 m .38674 .46028 L .38903 .45895 L F
.633 .232 .266 r
.38821 .46111 m .39063 .46324 L .38798 .46242 L F
.965 .637 .286 r
.38821 .46111 m .38798 .46242 L .38674 .46028 L F
.57 .259 .402 r
.39107 .46085 m .39063 .46324 L .38821 .46111 L F
.294 .627 .962 r
.58636 .44034 m .58747 .43899 L .58536 .43726 L F
.58636 .44034 m .58881 .44063 L .58747 .43899 L F
.86 .979 .682 r
.6712 .35036 m .67289 .34928 L .67052 .35296 L F
.861 .992 .742 r
.6712 .35036 m .67052 .35296 L .66891 .35497 L F
.237 .201 .614 r
.7024 .29532 m .70471 .29769 L .70406 .29494 L F
.7024 .29532 m .70259 .29983 L .70471 .29769 L F
.769 .805 .882 r
.6047 .36367 m .59863 .36305 L .60225 .3652 L F
0 0 0 r
.6047 .36367 m .60535 .36394 L .6058 .36368 L F
.6047 .36367 m .60225 .3652 L .60535 .36394 L F
.903 .697 .614 r
.42922 .5665 m .42757 .56263 L .42972 .56487 L F
0 0 .076 r
.42964 .56761 m .42922 .5665 L .42972 .56487 L F
.42964 .56761 m .42868 .56932 L .42922 .5665 L F
.313 0 0 r
.66631 .33132 m .66137 .3341 L .66159 .33301 L F
.66631 .33132 m .66437 .33362 L .66137 .3341 L F
.569 .117 .141 r
.66821 .33207 m .66437 .33362 L .66631 .33132 L F
.769 .912 .528 r
.57511 .40262 m .57651 .40118 L .57654 .40057 L F
.57511 .40262 m .57432 .40486 L .57651 .40118 L F
0 0 0 r
.54179 .47358 m .54064 .47575 L .5437 .47262 L F
.486 .696 .962 r
.3358 .63868 m .3421 .64205 L .34071 .63837 L F
.736 .628 .739 r
.3421 .64205 m .34469 .6387 L .34071 .63837 L F
.87 .66 .617 r
.39521 .55323 m .39282 .55268 L .39303 .54935 L F
.927 .71 .589 r
.39521 .55323 m .39264 .55504 L .39282 .55268 L F
.39521 .55323 m .3948 .55601 L .39264 .55504 L F
.865 .969 .648 r
.5188 .41511 m .52092 .41118 L .52127 .41423 L F
.252 .02 .355 r
.52075 .41621 m .5188 .41511 L .52127 .41423 L F
.324 .028 .299 r
.52075 .41621 m .5237 .4133 L .52329 .41536 L F
.451 .863 .956 r
.52279 .41538 m .52075 .41621 L .52329 .41536 L F
.252 .02 .355 r
.52075 .41621 m .5186 .41708 L .5188 .41511 L F
.302 .001 .277 r
.52127 .41423 m .5237 .4133 L .52075 .41621 L F
.451 .863 .956 r
.51784 .41559 m .52075 .41621 L .52279 .41538 L F
.252 .02 .355 r
.52075 .41621 m .51856 .4175 L .5186 .41708 L F
.598 .95 .843 r
.52814 .4764 m .52499 .47777 L .52738 .47625 L F
.681 .97 .774 r
.52814 .4764 m .53012 .47391 L .53121 .47379 L F
.52814 .4764 m .52738 .47625 L .53012 .47391 L F
.956 .66 .436 r
.38453 .53311 m .38268 .53227 L .38254 .52964 L F
.853 .524 .43 r
.38628 .53572 m .38268 .53227 L .38453 .53311 L F
.809 .525 .508 r
.38524 .49646 m .3853 .49644 L .38748 .49535 L F
.739 .973 .717 r
.38748 .49535 m .38613 .49748 L .38876 .49471 L F
.565 .562 .809 r
.38748 .49535 m .3864 .50043 L .38613 .49748 L F
.38748 .49535 m .38935 .5003 L .3864 .50043 L F
0 .011 .584 r
.38929 .49748 m .38935 .5003 L .38748 .49535 L F
.38929 .49748 m .38748 .49535 L .38967 .495 L F
.809 .525 .508 r
.3853 .49644 m .38967 .495 L .38748 .49535 L F
.739 .973 .717 r
.38748 .49535 m .38876 .49471 L .38895 .4945 L F
.336 .807 .727 r
.47339 .53385 m .47329 .53365 L .47411 .53253 L F
.47339 .53385 m .47083 .5347 L .47329 .53365 L F
.152 0 .173 r
.24272 .53613 m .24625 .5324 L .24365 .533 L F
.901 .985 .778 r
.5599 .43451 m .55734 .43604 L .55962 .43311 L F
.5599 .43451 m .55752 .43764 L .55734 .43604 L F
.776 .608 .672 r
.42052 .56283 m .42352 .56587 L .42171 .56445 L F
.832 .701 .719 r
.42352 .56587 m .42195 .56941 L .42171 .56445 L F
.707 .563 .69 r
.33216 .59307 m .33217 .59583 L .33468 .59263 L F
.33216 .59307 m .33217 .59583 L .33468 .59263 L F
.742 .992 .863 r
.33754 .59038 m .33484 .59085 L .33468 .59263 L F
.54 .332 .546 r
.33754 .59038 m .33745 .59268 L .33468 .59263 L F
.359 .717 .987 r
.33468 .59263 m .33745 .59268 L .33484 .59085 L F
.543 .639 .895 r
.3228 .63823 m .32501 .64191 L .32739 .64118 L F
.629 .615 .818 r
.32501 .64191 m .32881 .64288 L .32739 .64118 L F
.827 .972 .89 r
.54817 .47909 m .55242 .47696 L .55167 .47634 L F
.887 .962 .629 r
.55242 .47696 m .55396 .47268 L .55167 .47634 L F
.591 .866 .537 r
.28687 .51338 m .28472 .51552 L .28374 .51685 L F
0 .215 .721 r
.28541 .51146 m .28747 .51282 L .28687 .51338 L F
0 0 0 r
.28685 .51439 m .28687 .51338 L .28747 .51282 L F
.28685 .51439 m .28472 .51552 L .28687 .51338 L F
.794 .661 .717 r
.37766 .58929 m .37496 .59207 L .37908 .59252 L F
.845 .693 .694 r
.37463 .59491 m .37908 .59252 L .37496 .59207 L F
.37463 .59491 m .3769 .59588 L .37908 .59252 L F
.189 .056 .458 r
.24063 .54274 m .24208 .53904 L .24081 .53997 L F
.924 .552 .29 r
.34018 .50863 m .34136 .50672 L .33886 .50578 L F
.34018 .50863 m .34238 .50981 L .34136 .50672 L F
.673 .443 .564 r
.39656 .48666 m .39294 .48399 L .39399 .48634 L F
.39656 .48666 m .39764 .48435 L .39294 .48399 L F
.659 .711 .886 r
.33227 .66166 m .33304 .66211 L .32897 .66149 L F
.687 .76 .907 r
.33465 .66091 m .33304 .66211 L .33227 .66166 L F
.33465 .66091 m .336 .66168 L .33304 .66211 L F
.651 .401 .527 r
.33304 .66211 m .33582 .66434 L .33319 .66478 L F
.33304 .66211 m .336 .66168 L .33582 .66434 L F
0 .315 .732 r
.57197 .41915 m .57062 .41882 L .56933 .41748 L F
.57197 .41915 m .57354 .42027 L .57062 .41882 L F
.584 .374 .562 r
.24385 .58875 m .2466 .5864 L .24372 .58612 L F
.836 .946 .587 r
.43278 .59567 m .43389 .59371 L .43269 .59457 L F
0 .438 .846 r
.43389 .59371 m .43802 .59557 L .43594 .59405 L F
.43389 .59371 m .43594 .59405 L .43269 .59457 L F
.766 .611 .687 r
.32782 .59547 m .33217 .59583 L .33216 .59307 L F
.87 .666 .623 r
.3748 .57831 m .37605 .5822 L .37626 .57943 L F
.935 .719 .586 r
.38742 .49484 m .38895 .4945 L .3868 .49054 L F
.639 .131 .026 r
.38742 .49484 m .38748 .49535 L .38895 .4945 L F
.646 .641 .831 r
.3868 .49054 m .38895 .4945 L .38972 .4925 L F
.756 .993 .8 r
.28984 .59143 m .28783 .59313 L .29022 .59197 L F
.821 .892 .893 r
.66673 .37448 m .66354 .3748 L .6657 .37295 L F
.788 .959 .638 r
.57511 .40262 m .57293 .40574 L .57432 .40486 L F
.783 .49 .492 r
.68738 .32448 m .69093 .32268 L .68752 .32208 L F
.68738 .32448 m .69115 .32508 L .69093 .32268 L F
.752 .467 .499 r
.69115 .32508 m .69383 .32555 L .69093 .32268 L F
.654 .713 .891 r
.62753 .38045 m .62806 .38258 L .62436 .3817 L F
.551 0 0 r
.62687 .3823 m .62806 .38258 L .62712 .38263 L F
.62436 .3817 m .62687 .3823 L .62592 .38268 L F
.62687 .3823 m .62712 .38263 L .62592 .38268 L F
.924 .86 .759 r
.62592 .38268 m .62806 .38258 L .62753 .38045 L F
0 0 .376 r
.62891 .37832 m .6275 .38312 L .62753 .38045 L F
.6275 .38312 m .62746 .38327 L .62746 .38307 L F
.6275 .38312 m .62746 .38307 L .62753 .38045 L F
.944 .909 .755 r
.31237 .63209 m .31069 .63616 L .30852 .63623 L F
.381 0 0 r
.60959 .39806 m .61119 .39823 L .60723 .39724 L F
.598 .077 0 r
.61197 .39951 m .61119 .39823 L .60959 .39806 L F
.836 .946 .587 r
.43278 .59567 m .43269 .59457 L .43017 .5952 L F
0 0 .4 r
.43269 .59457 m .43278 .59567 L .43017 .5952 L F
.43269 .59457 m .43423 .59878 L .43278 .59567 L F
.726 .985 .895 r
.52283 .49984 m .52215 .49923 L .51837 .5016 L F
.873 .994 .767 r
.52472 .49582 m .52283 .49984 L .5259 .49679 L F
.52472 .49582 m .52215 .49923 L .52283 .49984 L F
.52 .844 .998 r
.71784 .32231 m .71961 .32052 L .71673 .32141 L F
.71784 .32231 m .72044 .32162 L .71961 .32052 L F
.944 .582 .232 r
.37917 .52604 m .37695 .52251 L .37911 .52363 L F
.344 .326 .695 r
.70326 .30229 m .70471 .29769 L .70259 .29983 L F
.183 .698 .891 r
.30087 .6319 m .30296 .63229 L .29964 .63214 L F
.673 .439 .558 r
.30296 .63229 m .30076 .63354 L .29964 .63214 L F
.163 .289 .747 r
.29964 .63214 m .30076 .63354 L .30087 .6319 L F
.847 .775 .781 r
.63512 .34867 m .63541 .34414 L .63743 .34592 L F
.832 .909 .891 r
.35716 .62981 m .35746 .62745 L .35497 .63074 L F
0 0 0 r
.43728 .45353 m .43919 .45259 L .437 .454 L F
0 0 .393 r
.5125 .41842 m .51375 .41848 L .5145 .41669 L F
.5125 .41842 m .51271 .4203 L .51375 .41848 L F
.682 .153 0 r
.461 .58439 m .46038 .58299 L .45846 .58443 L F
.461 .58439 m .46253 .58524 L .46038 .58299 L F
.566 .772 .976 r
.60026 .40152 m .60135 .40335 L .60431 .40236 L F
0 .474 .796 r
.61053 .3541 m .61379 .35524 L .61225 .35491 L F
.595 .226 .313 r
.30624 .68114 m .30845 .68337 L .30673 .68332 L F
.30624 .68114 m .30884 .68146 L .30845 .68337 L F
.788 .999 .842 r
.37455 .46656 m .37164 .4702 L .37162 .46803 L F
.48 .691 .961 r
.37561 .46966 m .37164 .4702 L .37455 .46656 L F
.681 .742 .897 r
.34071 .63837 m .34469 .6387 L .34327 .63555 L F
.531 .657 .916 r
.34327 .63555 m .34469 .6387 L .34723 .63814 L F
.5 .457 .741 r
.25806 .54579 m .25627 .54886 L .2561 .5465 L F
.949 .733 .576 r
.59243 .41328 m .59477 .41179 L .5924 .41065 L F
.59243 .41328 m .59456 .41497 L .59477 .41179 L F
.88 .706 .661 r
.37085 .57495 m .37527 .57601 L .37486 .57282 L F
.875 .668 .62 r
.37085 .57495 m .3748 .57831 L .37527 .57601 L F
.569 .667 .905 r
.30107 .65167 m .30049 .65585 L .29899 .6537 L F
.30107 .65167 m .303 .65526 L .30049 .65585 L F
.262 .021 .348 r
.39819 .50217 m .39678 .50044 L .39712 .49903 L F
.39819 .50217 m .39622 .50325 L .39678 .50044 L F
.907 .609 .468 r
.68223 .31726 m .68518 .3162 L .68346 .31464 L F
.68223 .31726 m .68537 .31866 L .68518 .3162 L F
.893 .703 .191 r
.51451 .41013 m .51518 .41484 L .51691 .41357 L F
0 0 0 r
.51518 .41484 m .5145 .41669 L .51691 .41357 L F
.946 .953 .65 r
.67262 .34684 m .67289 .34928 L .6712 .35036 L F
0 0 0 r
.65618 .37376 m .65411 .37552 L .65596 .37469 L F
.65596 .37469 m .65411 .37552 L .65618 .37376 L F
0 0 .295 r
.30856 .60936 m .30801 .61233 L .30881 .61064 L F
.417 .036 .206 r
.30801 .61233 m .30894 .61415 L .30787 .61509 L F
.30801 .61233 m .31104 .61203 L .30894 .61415 L F
0 0 .136 r
.30881 .61064 m .30801 .61233 L .30787 .61509 L F
.592 .829 .989 r
.30482 .58258 m .30168 .58295 L .30067 .58213 L F
.402 .839 .709 r
.49584 .40764 m .49788 .40637 L .49962 .40571 L F
.428 .871 .83 r
.49584 .40764 m .4964 .40691 L .49788 .40637 L F
.994 .771 .493 r
.3334 .54318 m .33189 .54225 L .33235 .53935 L F
.658 .505 .664 r
.3334 .54318 m .33132 .54646 L .3337 .54623 L F
.3337 .54623 m .33132 .54646 L .3334 .54318 L F
.3334 .54318 m .3337 .54623 L .33189 .54225 L F
.8 .93 .919 r
.69005 .36847 m .69241 .36448 L .68955 .36788 L F
.69005 .36847 m .69341 .3659 L .69241 .36448 L F
.708 .982 .803 r
.71442 .31194 m .71299 .31429 L .71164 .313 L F
.71442 .31194 m .71547 .31196 L .71299 .31429 L F
.501 .234 .441 r
.26365 .53606 m .25967 .53899 L .26097 .53669 L F
.912 .706 .611 r
.37594 .58481 m .37771 .58598 L .37605 .5822 L F
.864 .696 .672 r
.37594 .58481 m .37766 .58929 L .37771 .58598 L F
.314 .651 .97 r
.33711 .57296 m .33772 .57133 L .3353 .57207 L F
.726 .605 .721 r
.48298 .55293 m .48164 .55641 L .48405 .55609 L F
.831 .708 .729 r
.4811 .55923 m .48405 .55609 L .48164 .55641 L F
.543 .8 .993 r
.57283 .35656 m .57427 .35806 L .5715 .35877 L F
.973 .849 .448 r
.57297 .36128 m .57283 .35656 L .5715 .35877 L F
.606 .775 .961 r
.30774 .65413 m .30718 .65732 L .30538 .6543 L F
.30774 .65413 m .30977 .65637 L .30718 .65732 L F
.017 0 .344 r
.50981 .43715 m .51004 .43492 L .51119 .43333 L F
.428 .793 .995 r
.55219 .43313 m .55627 .43373 L .5538 .43423 L F
.5538 .43423 m .55627 .43373 L .55219 .43313 L F
.822 .72 .752 r
.54832 .44377 m .54518 .44695 L .54567 .44447 L F
0 0 .131 r
.54567 .44447 m .5469 .44514 L .54832 .44377 L F
.54567 .44447 m .54518 .44695 L .5469 .44514 L F
.78 .816 .881 r
.64938 .36094 m .65097 .36215 L .6472 .36146 L F
.832 .757 .781 r
.65097 .36215 m .64841 .36576 L .6472 .36146 L F
.49 .288 .533 r
.65097 .36215 m .65122 .36505 L .64841 .36576 L F
0 .234 .748 r
.65232 .36202 m .65097 .36215 L .64938 .36094 L F
.65232 .36202 m .65274 .36344 L .65097 .36215 L F
.522 .624 .894 r
.33615 .65723 m .336 .66168 L .33465 .66091 L F
.33615 .65723 m .33851 .66132 L .336 .66168 L F
.444 .17 .402 r
.336 .66168 m .33789 .66377 L .33582 .66434 L F
.336 .66168 m .33851 .66132 L .33789 .66377 L F
.019 .555 .848 r
.6021 .3425 m .60516 .34356 L .60216 .34377 L F
.287 0 0 r
.63332 .34399 m .63177 .34487 L .62935 .34499 L F
.295 0 0 r
.63541 .34414 m .63177 .34487 L .63332 .34399 L F
.731 .203 0 r
.6623 .38698 m .66482 .38805 L .66638 .39022 L F
0 0 .397 r
.5584 .36704 m .55942 .37105 L .5589 .36647 L F
.493 .791 .998 r
.71382 .31989 m .71261 .31855 L .70981 .31907 L F
.13 .384 .839 r
.71382 .31989 m .71545 .31924 L .71261 .31855 L F
.71382 .31989 m .71673 .32141 L .71545 .31924 L F
.501 .279 .508 r
.27792 .60223 m .27798 .60512 L .27544 .60555 L F
.27792 .60223 m .27798 .60512 L .27544 .60555 L F
0 0 .146 r
.2799 .59971 m .27792 .60223 L .28011 .60062 L F
.652 .269 .307 r
.27792 .60223 m .28065 .60485 L .27798 .60512 L F
.558 .496 .742 r
.27798 .60512 m .28011 .60062 L .27792 .60223 L F
0 0 0 r
.28374 .51685 m .28184 .51848 L .28075 .51937 L F
.597 .887 .585 r
.28472 .51552 m .28184 .51848 L .28374 .51685 L F
.77 .711 .796 r
.45284 .55593 m .45419 .55965 L .45005 .5591 L F
.478 .258 .5 r
.45419 .55965 m .45144 .56301 L .45005 .5591 L F
.45419 .55965 m .45421 .56243 L .45144 .56301 L F
.034 0 .369 r
.32866 .59576 m .32782 .59547 L .33217 .59583 L F
.731 .93 .956 r
.33321 .59338 m .32866 .59576 L .33217 .59583 L F
.166 .184 .634 r
.3324 .59878 m .33321 .59338 L .33217 .59583 L F
.829 .988 .722 r
.55716 .46985 m .55764 .47033 L .56028 .46694 L F
.457 0 0 r
.57465 .4222 m .57473 .42218 L .57354 .42027 L F
.57465 .4222 m .57704 .42398 L .57473 .42218 L F
.515 .218 .401 r
.51461 .43049 m .51833 .42764 L .51436 .42785 L F
.51461 .43049 m .51736 .43018 L .51833 .42764 L F
.705 .488 .592 r
.51736 .43018 m .52107 .42756 L .51833 .42764 L F
.651 .96 .929 r
.473 .58529 m .4675 .58702 L .46832 .58938 L F
.88 .706 .661 r
.37085 .57495 m .37486 .57282 L .37313 .57174 L F
.134 0 0 r
.6477 .38639 m .6458 .38588 L .64481 .38696 L F
0 0 0 r
.6157 .38825 m .61556 .38864 L .61763 .38697 L F
.6157 .38825 m .61556 .38864 L .61763 .38697 L F
.829 .581 .564 r
.56422 .40887 m .56139 .41056 L .56425 .40706 L F
.56422 .40887 m .56561 .41084 L .56139 .41056 L F
.806 .968 .907 r
.35207 .5636 m .35075 .56547 L .34902 .56433 L F
.773 .352 .252 r
.35075 .56547 m .34749 .56751 L .34902 .56433 L F
.35075 .56547 m .35143 .56815 L .34749 .56751 L F
.435 .795 .996 r
.26721 .61639 m .26766 .61418 L .26711 .61381 L F
.26721 .61639 m .27064 .61588 L .26766 .61418 L F
.662 .662 .839 r
.31629 .65721 m .31537 .66168 L .31418 .65748 L F
.31629 .65721 m .31774 .66098 L .31537 .66168 L F
.552 .107 .146 r
.25477 .61779 m .2579 .61729 L .25704 .61875 L F
.045 .206 .707 r
.2579 .61729 m .2573 .61501 L .25847 .6172 L F
.256 .542 .924 r
.2579 .61729 m .26067 .61847 L .25847 .6172 L F
.067 0 0 r
.25704 .61875 m .2579 .61729 L .25847 .6172 L F
.829 .988 .722 r
.55716 .46985 m .56028 .46694 L .55989 .46641 L F
.88 .935 .559 r
.56173 .46248 m .56028 .46694 L .56307 .4636 L F
.56173 .46248 m .55989 .46641 L .56028 .46694 L F
.438 .339 .646 r
.28365 .59338 m .28699 .59006 L .28429 .59199 L F
.014 0 0 r
.28651 .58943 m .28429 .59199 L .28651 .5904 L F
.438 .339 .646 r
.28699 .59006 m .28718 .58987 L .28429 .59199 L F
.014 0 0 r
.28651 .5904 m .28429 .59199 L .28651 .59096 L F
.932 .731 .609 r
.35489 .52623 m .35432 .52876 L .35699 .52982 L F
.931 .66 .502 r
.35415 .53155 m .35699 .52982 L .35432 .52876 L F
.35415 .53155 m .35701 .53299 L .35699 .52982 L F
.722 .639 .765 r
.32544 .65948 m .32612 .66226 L .32215 .66172 L F
.725 .688 .814 r
.32721 .65774 m .32612 .66226 L .32544 .65948 L F
.32721 .65774 m .32897 .66149 L .32612 .66226 L F
.75 .784 .29 r
.57775 .39314 m .57721 .39548 L .57846 .39155 L F
.226 .38 .809 r
.57694 .38794 m .57995 .38964 L .57846 .39155 L F
0 0 0 r
.57995 .38964 m .57775 .39314 L .57846 .39155 L F
.887 .652 .577 r
.58157 .43995 m .58213 .43795 L .5809 .43803 L F
0 0 0 r
.46336 .43098 m .46098 .43241 L .4598 .43313 L F
.5 .457 .741 r
.25806 .54579 m .25879 .5499 L .25627 .54886 L F
.7 .22 .106 r
.4188 .60128 m .42236 .60214 L .42109 .60391 L F
.436 .107 .308 r
.42236 .60214 m .42457 .60396 L .42109 .60391 L F
.42236 .60214 m .42498 .60179 L .42457 .60396 L F
.832 .956 .895 r
.52799 .4929 m .5259 .49679 L .52869 .49358 L F
.52799 .4929 m .52472 .49582 L .5259 .49679 L F
.474 .169 .368 r
.65963 .36073 m .66089 .3615 L .65768 .36323 L F
0 0 0 r
.43079 .44863 m .42987 .44838 L .42839 .4496 L F
.43079 .44863 m .43259 .44765 L .42987 .44838 L F
.094 0 .09 r
.53268 .41807 m .535 .41717 L .53577 .41468 L F
.709 .316 .301 r
.535 .41717 m .53792 .41786 L .53577 .41468 L F
.992 .796 .416 r
.53792 .41786 m .53715 .41451 L .53577 .41468 L F
.829 .498 0 r
.537 .41592 m .53792 .41786 L .535 .41717 L F
.537 .41592 m .53793 .41793 L .53792 .41786 L F
.53793 .41793 m .53845 .41905 L .53792 .41786 L F
.992 .796 .416 r
.53792 .41786 m .53877 .41431 L .53715 .41451 L F
.536 .252 .431 r
.52107 .42756 m .524 .42704 L .52441 .42486 L F
.336 .078 .367 r
.52441 .42486 m .52642 .42632 L .52659 .42383 L F
.52441 .42486 m .524 .42704 L .52642 .42632 L F
.816 .426 .316 r
.66891 .35497 m .66624 .35525 L .6685 .35321 L F
.66891 .35497 m .66867 .35671 L .66624 .35525 L F
.861 .992 .742 r
.6712 .35036 m .66891 .35497 L .6685 .35321 L F
.394 .755 .993 r
.64841 .36576 m .6471 .36461 L .64439 .36484 L F
.527 .821 .999 r
.64841 .36576 m .64999 .36384 L .6471 .36461 L F
.64841 .36576 m .65122 .36505 L .64999 .36384 L F
.137 .377 .832 r
.56169 .37477 m .55942 .37105 L .56036 .37271 L F
.511 .912 .831 r
.53442 .38934 m .53684 .3885 L .53526 .38702 L F
.42 .078 .278 r
.53571 .3851 m .53684 .3885 L .53946 .38512 L F
.53571 .3851 m .53802 .38636 L .53684 .3885 L F
.563 .82 .994 r
.53802 .38636 m .53526 .38702 L .53684 .3885 L F
.404 .133 .385 r
.3864 .50043 m .38593 .50303 L .38679 .50278 L F
.38776 .50169 m .38679 .50278 L .38842 .50231 L F
.3864 .50043 m .38679 .50278 L .38776 .50169 L F
0 0 0 r
.38664 .50083 m .3864 .50043 L .38935 .5003 L F
.775 .69 .769 r
.38929 .49748 m .38664 .50083 L .38891 .50038 L F
.38934 .49989 m .38891 .50038 L .38935 .5003 L F
.38929 .49748 m .38891 .50038 L .38934 .49989 L F
0 0 0 r
.38664 .50083 m .38593 .50303 L .3864 .50043 L F
.179 0 .006 r
.66159 .33301 m .66137 .3341 L .65862 .33506 L F
.692 .636 .789 r
.33102 .65822 m .32897 .66149 L .32721 .65774 L F
.33102 .65822 m .33227 .66166 L .32897 .66149 L F
.895 .624 .52 r
.44953 .49309 m .44976 .49016 L .44711 .4896 L F
.395 .12 .374 r
.65523 .39784 m .65825 .39504 L .65703 .39603 L F
.519 .498 .773 r
.65825 .39504 m .66117 .39704 L .66114 .39521 L F
.883 .793 .757 r
.47946 .55545 m .48164 .55641 L .48298 .55293 L F
.919 .723 .622 r
.47946 .55545 m .4811 .55923 L .48164 .55641 L F
.722 .703 .832 r
.60844 .38904 m .60962 .39194 L .61189 .3897 L F
.569 .904 .979 r
.55567 .40518 m .55422 .40692 L .55763 .40531 L F
.55567 .40518 m .55305 .40623 L .55422 .40692 L F
.592 .269 .391 r
.3182 .67468 m .32047 .67703 L .31776 .67723 L F
.589 .269 .395 r
.3182 .67468 m .32106 .67474 L .32047 .67703 L F
.54 .925 .826 r
.6514 .39949 m .65523 .39784 L .65495 .39791 L F
.542 .871 .6 r
.65495 .39791 m .65523 .39784 L .65703 .39603 L F
0 0 0 r
.55752 .43764 m .55767 .43755 L .55734 .43604 L F
.97 .704 .471 r
.33045 .51566 m .32918 .5122 L .33072 .51362 L F
.615 .064 0 r
.41413 .52307 m .41563 .52443 L .41661 .52475 L F
.966 .654 .371 r
.41529 .52759 m .41661 .52475 L .41563 .52443 L F
.41529 .52759 m .41722 .52871 L .41661 .52475 L F
.488 .886 .731 r
.49962 .40571 m .50007 .40495 L .50198 .40437 L F
.49962 .40571 m .49788 .40637 L .50007 .40495 L F
.61 .151 .137 r
.63512 .34867 m .63345 .35037 L .63067 .34856 L F
.303 0 0 r
.63067 .34856 m .63287 .34878 L .63512 .34867 L F
.847 .775 .781 r
.63512 .34867 m .63287 .34878 L .63541 .34414 L F
0 0 0 r
.63576 .34846 m .63512 .34867 L .63798 .34926 L F
.63576 .34846 m .63345 .35037 L .63512 .34867 L F
.864 .751 .736 r
.3715 .61157 m .37283 .60921 L .37085 .60796 L F
.805 .998 .785 r
.35259 .5698 m .35055 .57265 L .35106 .57076 L F
0 .045 .57 r
.35055 .57265 m .35047 .57219 L .35106 .57076 L F
.35055 .57265 m .35276 .57478 L .35047 .57219 L F
0 0 .319 r
.57366 .36773 m .57274 .36369 L .57272 .36546 L F
.848 .766 .771 r
.35797 .62485 m .36229 .62269 L .35978 .62116 L F
.802 .8 .85 r
.36229 .62269 m .36325 .61842 L .35978 .62116 L F
.307 .783 .923 r
.34373 .57321 m .34222 .57278 L .33955 .57324 L F
.049 .174 .674 r
.34492 .56818 m .34707 .57039 L .34577 .57161 L F
0 0 0 r
.34707 .57039 m .34443 .57374 L .34577 .57161 L F
.343 .223 .569 r
.34668 .56999 m .3455 .57222 L .34707 .57039 L F
.34492 .56818 m .34533 .57106 L .34668 .56999 L F
.34533 .57106 m .3455 .57222 L .34668 .56999 L F
.48 .035 .112 r
.34577 .57161 m .34382 .57226 L .34373 .57321 L F
.34382 .57226 m .34222 .57278 L .3429 .57298 L F
.34382 .57226 m .3429 .57298 L .34373 .57321 L F
.82 .7 .733 r
.45005 .5591 m .45144 .56301 L .44763 .56308 L F
.578 .812 .988 r
.34253 .566 m .3381 .56541 L .34122 .56324 L F
0 .259 .768 r
.34223 .56302 m .34253 .566 L .34122 .56324 L F
.34226 .56332 m .34381 .56675 L .34253 .566 L F
.34236 .56333 m .34381 .56675 L .34226 .56332 L F
.557 .921 .752 r
.34122 .56324 m .3381 .56541 L .33962 .56402 L F
.517 .659 .925 r
.34582 .5636 m .34381 .56675 L .34236 .56333 L F
.998 .785 .452 r
.34408 .56246 m .34223 .56302 L .34341 .55892 L F
.468 .88 .746 r
.34582 .56118 m .34223 .56302 L .34408 .56246 L F
.34582 .56118 m .34408 .56246 L .3478 .56057 L F
.628 .317 .425 r
.34287 .56313 m .34582 .5636 L .34582 .56118 L F
.517 .659 .925 r
.34582 .5636 m .34236 .56333 L .34314 .56317 L F
.628 .317 .425 r
.34251 .56337 m .34582 .5636 L .34287 .56313 L F
.517 .659 .925 r
.34582 .5636 m .34314 .56317 L .34315 .56317 L F
.34582 .5636 m .34288 .56313 L .34582 .56118 L F
.628 .317 .425 r
.34251 .56337 m .34582 .56118 L .34414 .56264 L F
.34251 .56337 m .34582 .56118 L .34251 .56337 L F
.517 .659 .925 r
.34288 .56313 m .34223 .56302 L .34582 .56118 L F
.628 .317 .425 r
.34251 .56337 m .34414 .56264 L .34333 .56168 L F
.994 .806 .435 r
.34341 .55892 m .34223 .56302 L .34212 .56028 L F
.628 .317 .425 r
.34244 .56282 m .34333 .56168 L .34212 .56028 L F
.517 .659 .925 r
.34315 .56317 m .34236 .56333 L .34225 .56306 L F
.34315 .56317 m .34225 .56306 L .34228 .56303 L F
.628 .317 .425 r
.34251 .56337 m .34333 .56168 L .34244 .56282 L F
.517 .659 .925 r
.34228 .56303 m .34225 .56306 L .34223 .56302 L F
0 .122 .661 r
.34251 .56337 m .34226 .56335 L .33962 .56402 L F
.34226 .56335 m .34156 .56327 L .34042 .56371 L F
.34226 .56335 m .34042 .56371 L .33962 .56402 L F
.34156 .56327 m .34122 .56324 L .3412 .56325 L F
.34156 .56327 m .3412 .56325 L .33962 .56402 L F
0 .259 .768 r
.34223 .56302 m .34236 .56333 L .34226 .56332 L F
.093 .246 .731 r
.34381 .56675 m .34492 .56818 L .34253 .566 L F
.666 .696 .868 r
.3335 .65769 m .33227 .66166 L .33102 .65822 L F
.3335 .65769 m .33465 .66091 L .33227 .66166 L F
.924 .865 .762 r
.39844 .56672 m .39545 .56794 L .3967 .56555 L F
.39844 .56672 m .39715 .56912 L .39545 .56794 L F
.8 .614 .651 r
.60615 .35081 m .61043 .34892 L .61007 .35133 L F
.393 .11 .36 r
.61251 .35028 m .61007 .35133 L .61043 .34892 L F
.833 .786 .807 r
.60157 .39065 m .60582 .39002 L .60407 .38969 L F
.60157 .39065 m .60159 .39176 L .60582 .39002 L F
.539 .887 .983 r
.60582 .39002 m .60616 .38836 L .60407 .38969 L F
.60582 .39002 m .60844 .38904 L .60616 .38836 L F
.735 .981 .756 r
.48507 .41573 m .48633 .41361 L .48678 .41393 L F
.48507 .41573 m .48323 .41664 L .48633 .41361 L F
.639 .966 .853 r
.47052 .42529 m .4692 .42706 L .46872 .4271 L F
.47052 .42529 m .47277 .42485 L .4692 .42706 L F
.571 .39 .597 r
.33319 .66478 m .33304 .6682 L .33036 .66838 L F
.485 .318 .58 r
.33577 .66735 m .33319 .66478 L .33582 .66434 L F
.33577 .66735 m .33304 .6682 L .33319 .66478 L F
.488 .149 .318 r
.32978 .6705 m .33036 .66838 L .33248 .67018 L F
.497 .147 .303 r
.33036 .66838 m .33304 .6682 L .33248 .67018 L F
.901 .639 .532 r
.34625 .52673 m .34359 .52632 L .34393 .52309 L F
.883 .81 .772 r
.34625 .52673 m .34441 .52896 L .34359 .52632 L F
.835 .628 .622 r
.52754 .38372 m .52672 .38791 L .52989 .38841 L F
.766 .512 .55 r
.53231 .39046 m .5298 .39102 L .52989 .38841 L F
.53231 .39046 m .5298 .39102 L .52989 .38841 L F
.412 .182 .453 r
.5298 .39102 m .53259 .38767 L .52989 .38841 L F
0 0 .07 r
.55197 .40069 m .55247 .40017 L .55275 .39905 L F
.229 .748 .773 r
.37953 .46154 m .3826 .46081 L .38566 .46039 L F
.455 .167 .386 r
.38566 .46039 m .38401 .46365 L .38144 .46416 L F
.137 0 0 r
.3826 .46081 m .38674 .46028 L .38566 .46039 L F
.669 .401 .507 r
.38798 .46242 m .38401 .46365 L .38566 .46039 L F
.883 .793 .757 r
.47946 .55545 m .48298 .55293 L .48268 .55233 L F
.61 .569 .783 r
.33981 .5887 m .33754 .59038 L .3358 .5853 L F
.427 .24 .523 r
.33976 .59158 m .33745 .59268 L .33754 .59038 L F
.514 0 0 r
.33976 .59158 m .33484 .59085 L .33754 .59038 L F
0 0 0 r
.513 .42921 m .51436 .42785 L .51596 .42626 L F
.454 .834 .988 r
.30296 .63229 m .30367 .6314 L .30087 .6319 L F
.737 .46 .51 r
.30296 .63229 m .30367 .6314 L .30076 .63354 L F
.30296 .63229 m .30533 .63489 L .30367 .6314 L F
.351 .738 .986 r
.34366 .54219 m .3478 .54349 L .34669 .54238 L F
.878 .644 .58 r
.34409 .54395 m .3478 .54349 L .34366 .54219 L F
.34409 .54395 m .3463 .54524 L .3478 .54349 L F
.547 .853 .998 r
.34644 .54213 m .3478 .54349 L .35009 .5425 L F
.773 .739 .822 r
.34847 .54289 m .3463 .54524 L .34409 .54395 L F
.35009 .5425 m .34925 .54311 L .34847 .54289 L F
.081 0 0 r
.3478 .54349 m .3463 .54524 L .35009 .5425 L F
.773 .739 .822 r
.34925 .54311 m .3463 .54524 L .34847 .54289 L F
.351 .738 .986 r
.34585 .54214 m .34669 .54238 L .34644 .54213 L F
.34366 .54219 m .34669 .54238 L .34585 .54214 L F
.474 .673 .951 r
.30987 .63721 m .31366 .63865 L .31205 .63697 L F
.51 .689 .948 r
.31205 .63697 m .31366 .63865 L .31608 .6382 L F
.803 .966 .91 r
.46646 .58844 m .46204 .59029 L .46397 .58886 L F
0 0 0 r
.43161 .60119 m .4351 .60007 L .43423 .59878 L F
.673 .837 .962 r
.4351 .60007 m .43694 .59759 L .43423 .59878 L F
.4351 .60007 m .4386 .59925 L .43694 .59759 L F
.344 .248 .6 r
.54377 .40486 m .54631 .40593 L .54683 .40582 L F
.54377 .40486 m .54456 .4078 L .54631 .40593 L F
.121 .662 .841 r
.28039 .51112 m .28541 .51146 L .28234 .51134 L F
.798 .974 .907 r
.53164 .49052 m .53529 .48806 L .53231 .48803 L F
.608 .943 .94 r
.53231 .48803 m .53529 .48806 L .53721 .48664 L F
.887 .983 .816 r
.5976 .4337 m .59992 .43088 L .59932 .42968 L F
.911 .894 .799 r
.59992 .43088 m .60098 .42591 L .59932 .42968 L F
.976 .706 .301 r
.58251 .36962 m .58359 .36863 L .58208 .36707 L F
.58251 .36962 m .58367 .37137 L .58359 .36863 L F
.794 .52 .522 r
.58359 .36863 m .58367 .37137 L .58778 .37175 L F
.024 0 .026 r
.25043 .56451 m .24817 .56573 L .24948 .56349 L F
.059 0 0 r
.64939 .339 m .64873 .34109 L .6462 .34171 L F
.042 0 0 r
.6511 .33963 m .64939 .339 L .65193 .3379 L F
.6511 .33963 m .64873 .34109 L .64939 .339 L F
.966 .736 .297 r
.47598 .56855 m .47594 .57145 L .47693 .57279 L F
.973 .7 .452 r
.47544 .57411 m .47693 .57279 L .47594 .57145 L F
.47544 .57411 m .4762 .57409 L .47693 .57279 L F
.907 .63 .506 r
.47674 .57539 m .47693 .57279 L .4762 .57409 L F
.748 .887 .942 r
.65803 .37853 m .65386 .37869 L .65714 .3777 L F
.76 .813 .895 r
.66086 .37619 m .65803 .37853 L .65819 .37461 L F
.963 .942 .676 r
.65819 .37461 m .65803 .37853 L .65714 .3777 L F
.83 .74 .765 r
.23626 .61822 m .23758 .62113 L .23875 .61915 L F
.922 .62 .454 r
.35244 .52507 m .35462 .5232 L .35235 .52238 L F
.35244 .52507 m .35489 .52623 L .35462 .5232 L F
.06 .15 .645 r
.34342 .53715 m .3441 .54014 L .34467 .53965 L F
.34342 .53715 m .34467 .53965 L .34495 .53888 L F
.597 .233 .323 r
.34342 .53715 m .34521 .53919 L .34623 .53667 L F
.97 .652 .305 r
.34231 .54107 m .34366 .54219 L .34213 .5385 L F
.842 .998 .784 r
.34566 .53796 m .34231 .54107 L .34213 .5385 L F
.34509 .53849 m .34222 .53948 L .34231 .54107 L F
.34566 .53796 m .34521 .53816 L .34509 .53849 L F
.34521 .53816 m .34222 .53948 L .34509 .53849 L F
.06 .15 .645 r
.34495 .53888 m .34467 .53965 L .34521 .53919 L F
0 0 .062 r
.3441 .54014 m .34366 .54219 L .34521 .53919 L F
.805 .592 .614 r
.72438 .30608 m .72053 .30225 L .72258 .30486 L F
.965 .75 .563 r
.72258 .30486 m .72352 .30874 L .72438 .30608 L F
.86 .995 .82 r
.47458 .58165 m .473 .58529 L .47627 .58271 L F
.47458 .58165 m .472 .58481 L .473 .58529 L F
.702 .919 .581 r
.47281 .58315 m .472 .58481 L .47293 .583 L F
.651 .96 .929 r
.47155 .58575 m .472 .58481 L .4675 .58702 L F
0 0 0 r
.4675 .58702 m .47186 .58488 L .47028 .58641 L F
.47186 .58488 m .472 .58481 L .47028 .58641 L F
.4675 .58702 m .47028 .58641 L .4679 .58381 L F
.522 .543 .818 r
.4675 .58702 m .46552 .58458 L .46514 .58771 L F
.4675 .58702 m .4679 .58381 L .46552 .58458 L F
.728 .321 .276 r
.4679 .58381 m .47028 .58641 L .46612 .58585 L F
0 0 .407 r
.4689 .58242 m .47028 .58641 L .47293 .583 L F
.4689 .58242 m .4699 .5846 L .47028 .58641 L F
.669 .194 .115 r
.46612 .58585 m .47028 .58641 L .46868 .58803 L F
.18 .688 .903 r
.46981 .58635 m .46949 .58589 L .46612 .58585 L F
.47028 .58641 m .46949 .58589 L .46981 .58635 L F
.522 .279 .487 r
.46612 .58585 m .46949 .58589 L .46868 .58803 L F
.878 .877 .44 r
.46946 .58584 m .46949 .58589 L .46868 .58803 L F
.425 .276 .574 r
.4689 .58242 m .46949 .58589 L .4699 .5846 L F
.878 .877 .44 r
.4699 .5846 m .46949 .58589 L .46946 .58584 L F
.964 .91 .553 r
.47028 .58641 m .4699 .5846 L .46871 .58794 L F
.47028 .58641 m .46871 .58794 L .46868 .58803 L F
.702 .919 .581 r
.47028 .58641 m .472 .58481 L .47281 .58315 L F
.651 .96 .929 r
.473 .58529 m .472 .58481 L .47155 .58575 L F
.887 .983 .816 r
.5976 .4337 m .59932 .42968 L .59701 .4332 L F
.86 .843 .826 r
.31024 .63105 m .31237 .63209 L .30852 .63623 L F
.855 .846 .834 r
.31492 .62896 m .31237 .63209 L .31024 .63105 L F
0 .057 .613 r
.57493 .37181 m .57535 .36981 L .57366 .36773 L F
0 0 .321 r
.57493 .37181 m .5754 .37263 L .57535 .36981 L F
.57493 .37181 m .57631 .37471 L .5754 .37263 L F
.694 .93 .967 r
.54297 .48259 m .54515 .47985 L .54145 .4816 L F
.54297 .48259 m .54644 .48071 L .54515 .47985 L F
.864 .963 .864 r
.56307 .4636 m .56483 .45963 L .56173 .46248 L F
.56307 .4636 m .56602 .46053 L .56483 .45963 L F
.568 .396 .609 r
.3077 .57894 m .30482 .58258 L .30871 .58185 L F
.691 .529 .663 r
.30806 .58457 m .30504 .58607 L .30482 .58258 L F
0 0 .181 r
.30482 .58258 m .30535 .58366 L .30871 .58185 L F
.30482 .58258 m .30504 .58607 L .30535 .58366 L F
.899 .488 .199 r
.58661 .37313 m .58778 .37175 L .58367 .37137 L F
.58661 .37313 m .58905 .37552 L .58778 .37175 L F
.658 .141 0 r
.60676 .38458 m .61136 .38554 L .60823 .38609 L F
.753 .994 .86 r
.59434 .42172 m .59547 .4226 L .59303 .42444 L F
.155 .643 .919 r
.59661 .42179 m .59547 .4226 L .59434 .42172 L F
.59661 .42179 m .59879 .42265 L .59547 .4226 L F
.726 .73 .853 r
.32881 .64288 m .33116 .64163 L .32739 .64118 L F
.849 .874 .859 r
.48475 .54841 m .48872 .5469 L .48732 .54537 L F
.353 0 0 r
.32334 .50229 m .32615 .50245 L .3282 .5014 L F
.41 0 0 r
.3282 .5014 m .32615 .50245 L .33029 .50223 L F
.96 .897 .719 r
.28661 .66132 m .28623 .66545 L .29048 .66398 L F
0 0 .075 r
.28623 .66545 m .28647 .66668 L .29048 .66398 L F
.968 .885 .695 r
.57072 .40698 m .56998 .41082 L .57089 .41082 L F
.966 .937 .648 r
.56874 .41309 m .57089 .41082 L .56998 .41082 L F
.56874 .41309 m .56938 .41431 L .57089 .41082 L F
.515 .843 .552 r
.52545 .45011 m .52528 .4458 L .52553 .44776 L F
.509 .322 .562 r
.52833 .44418 m .52851 .44727 L .52553 .44776 L F
.479 .231 .459 r
.52553 .44776 m .52851 .44727 L .52545 .45011 L F
.671 .358 .435 r
.37513 .49625 m .3774 .49724 L .38078 .49555 L F
.453 .871 .738 r
.38078 .49555 m .3774 .49724 L .38017 .49561 L F
.595 .924 .967 r
.6178 .34968 m .61409 .34903 L .61251 .35028 L F
.631 .935 .965 r
.6188 .34773 m .6178 .34968 L .61987 .348 L F
.6188 .34773 m .61409 .34903 L .6178 .34968 L F
.717 .931 .961 r
.46163 .44476 m .46384 .4454 L .46607 .44388 L F
.474 .673 .951 r
.30987 .63721 m .31205 .63697 L .30852 .63623 L F
0 0 .134 r
.33436 .52169 m .33372 .52661 L .33259 .52273 L F
.33436 .52169 m .3343 .52495 L .33372 .52661 L F
.371 .256 .591 r
.33643 .52797 m .33372 .52661 L .3343 .52495 L F
.33643 .52797 m .3342 .52967 L .33372 .52661 L F
0 0 .18 r
.58794 .40104 m .58812 .40487 L .58751 .40332 L F
.879 .545 .043 r
.58812 .40487 m .58773 .40585 L .58751 .40332 L F
.58812 .40487 m .58877 .40738 L .58773 .40585 L F
.285 .068 .399 r
.58782 .34426 m .58539 .34507 L .58799 .34433 L F
.984 .726 .454 r
.69486 .34534 m .69332 .34141 L .69287 .34445 L F
.857 .651 .623 r
.69141 .34744 m .69486 .34534 L .69287 .34445 L F
.69141 .34744 m .69436 .34808 L .69486 .34534 L F
.355 .336 .699 r
.70326 .30229 m .7039 .3066 L .70615 .30394 L F
.286 .241 .632 r
.70431 .30909 m .70615 .30394 L .7039 .3066 L F
0 0 0 r
.71006 .28914 m .70958 .29066 L .70847 .29269 L F
.139 .297 .763 r
.70958 .29066 m .71098 .29489 L .70847 .29269 L F
.444 .337 .639 r
.71098 .29489 m .70881 .29657 L .70847 .29269 L F
0 0 0 r
.34623 .53667 m .34676 .53731 L .34871 .5358 L F
.34623 .53667 m .34521 .53919 L .34676 .53731 L F
.073 .007 .469 r
.25305 .55793 m .2511 .56196 L .25108 .55994 L F
.802 .594 .62 r
.52493 .38739 m .52754 .38372 L .52487 .3843 L F
.52493 .38739 m .52672 .38791 L .52754 .38372 L F
.785 .285 0 r
.33461 .50228 m .33886 .50578 L .33833 .50378 L F
.024 0 0 r
.64727 .33198 m .64984 .33103 L .65085 .3297 L F
.004 0 0 r
.65085 .3297 m .65246 .32998 L .65357 .32871 L F
.65085 .3297 m .64984 .33103 L .65246 .32998 L F
.51 .229 .424 r
.62436 .3817 m .62078 .38181 L .62287 .38026 L F
.62436 .3817 m .62132 .38441 L .62078 .38181 L F
.62436 .3817 m .624 .38397 L .62132 .38441 L F
.652 .839 .972 r
.62753 .38045 m .62436 .3817 L .62287 .38026 L F
0 0 0 r
.62592 .38268 m .624 .38397 L .62436 .3817 L F
.733 .392 .403 r
.35561 .56629 m .35579 .56869 L .35143 .56815 L F
.923 .919 .793 r
.69341 .3659 m .6958 .36217 L .69461 .36078 L F
.872 .74 .714 r
.60441 .43725 m .60666 .44065 L .6028 .44043 L F
.862 .786 .775 r
.6028 .44043 m .60666 .44065 L .60303 .4449 L F
.497 .611 .896 r
.60899 .44013 m .60666 .44065 L .60441 .43725 L F
.849 .998 .813 r
.52911 .49123 m .52869 .49358 L .53164 .49052 L F
.52911 .49123 m .52799 .4929 L .52869 .49358 L F
.867 .625 .571 r
.36423 .55149 m .36672 .54964 L .3643 .54886 L F
.36423 .55149 m .3665 .55256 L .36672 .54964 L F
0 0 0 r
.51683 .39207 m .51379 .39451 L .51612 .3931 L F
.51683 .39207 m .51792 .39075 L .51939 .39132 L F
.51683 .39207 m .51612 .3931 L .51792 .39075 L F
.735 .8 .904 r
.33629 .63777 m .34071 .63837 L .33905 .63549 L F
.798 .721 .779 r
.3358 .63868 m .34071 .63837 L .33629 .63777 L F
.707 .788 .915 r
.33905 .63549 m .34071 .63837 L .34327 .63555 L F
.85 .996 .76 r
.55447 .45943 m .55553 .45856 L .5533 .46144 L F
0 0 .169 r
.55447 .45943 m .5533 .46144 L .55278 .46367 L F
.55447 .45943 m .55278 .46367 L .55108 .4621 L F
.55447 .45943 m .55108 .4621 L .5524 .46114 L F
.55447 .45943 m .5524 .46114 L .55498 .45925 L F
.85 .996 .76 r
.55447 .45943 m .55593 .45804 L .55553 .45856 L F
.716 .392 .429 r
.46529 .5792 m .46112 .58144 L .46108 .57912 L F
.46529 .5792 m .46544 .58192 L .46112 .58144 L F
.176 0 .277 r
.39908 .48327 m .39764 .48435 L .39656 .48666 L F
.405 .194 .477 r
.52718 .393 m .5298 .39102 L .5261 .3906 L F
.52718 .393 m .53004 .3937 L .5298 .39102 L F
.5298 .39102 m .53004 .3937 L .52718 .393 L F
0 0 0 r
.5303 .42132 m .52659 .42383 L .53024 .42313 L F
0 0 .242 r
.5303 .42132 m .53172 .42221 L .53299 .42057 L F
.5303 .42132 m .53024 .42313 L .53172 .42221 L F
.63 .823 .975 r
.59556 .44309 m .59712 .44472 L .59959 .44359 L F
.59959 .44359 m .59712 .44472 L .59556 .44309 L F
.739 .857 .424 r
.57683 .39545 m .57721 .39548 L .57775 .39314 L F
.57683 .39545 m .57603 .3977 L .57721 .39548 L F
.845 .591 .555 r
.36902 .56861 m .37313 .57174 L .37278 .56962 L F
.973 .661 .31 r
.59303 .42444 m .59178 .42593 L .59434 .42172 L F
.59303 .42444 m .59341 .42755 L .59178 .42593 L F
.939 .826 .706 r
.39593 .57163 m .39545 .56794 L .39715 .56912 L F
.527 .114 .2 r
.42877 .45715 m .43146 .45753 L .42663 .458 L F
.86 .579 .048 r
.58583 .394 m .58692 .39814 L .58623 .39663 L F
.878 .501 .025 r
.58692 .39814 m .58645 .3991 L .58623 .39663 L F
.58692 .39814 m .58794 .40104 L .58645 .3991 L F
.797 .891 .912 r
.56602 .46053 m .56797 .45632 L .56483 .45963 L F
.56602 .46053 m .5692 .45797 L .56797 .45632 L F
.752 .988 .776 r
.47448 .42286 m .47277 .42485 L .47377 .42274 L F
.742 .993 .852 r
.47377 .42274 m .47277 .42485 L .47052 .42529 L F
.063 .304 .789 r
.3337 .54623 m .33457 .54408 L .33189 .54225 L F
.739 .96 .671 r
.33467 .54453 m .33457 .54408 L .3337 .54623 L F
0 0 0 r
.40773 .45486 m .40701 .45484 L .40508 .45526 L F
.40773 .45486 m .4099 .45444 L .40701 .45484 L F
.241 0 .087 r
.61893 .40002 m .61987 .39737 L .61755 .39827 L F
.932 .863 .432 r
.5833 .38772 m .583 .38634 L .58412 .38486 L F
.958 .617 .291 r
.58412 .38486 m .583 .38634 L .58251 .38372 L F
.58412 .38486 m .583 .38634 L .58251 .38372 L F
.381 0 0 r
.39331 .45722 m .3956 .45799 L .3977 .45687 L F
.059 0 0 r
.3956 .45799 m .39993 .45619 L .3977 .45687 L F
.945 .636 .419 r
.34913 .51594 m .35005 .51996 L .35193 .52066 L F
.887 .546 .398 r
.35005 .51996 m .35235 .52238 L .35193 .52066 L F
.858 .575 .509 r
.36725 .56467 m .3696 .56266 L .36739 .56197 L F
.36725 .56467 m .36965 .56589 L .3696 .56266 L F
.712 .623 .757 r
.32069 .65749 m .32215 .66172 L .31774 .66098 L F
.777 .783 .858 r
.32297 .65728 m .32215 .66172 L .32069 .65749 L F
.32297 .65728 m .32544 .65948 L .32215 .66172 L F
.262 .223 .625 r
.23857 .55017 m .24079 .55234 L .24098 .54829 L F
.23857 .55017 m .23923 .5527 L .24079 .55234 L F
.952 .927 .74 r
.26393 .55288 m .26497 .54789 L .26656 .54954 L F
.26393 .55288 m .2626 .5527 L .26497 .54789 L F
.522 .909 .935 r
.26487 .55166 m .2626 .5527 L .26393 .55288 L F
.207 0 0 r
.26487 .55166 m .26266 .55268 L .2626 .5527 L F
0 .52 .719 r
.25965 .55236 m .2626 .5527 L .26255 .55271 L F
.25965 .55236 m .2626 .5527 L .26393 .55288 L F
.611 .44 .626 r
.2626 .5527 m .25994 .5554 L .25965 .55236 L F
.2626 .5527 m .25994 .5554 L .25965 .55236 L F
.79 .997 .792 r
.2626 .5527 m .26014 .55385 L .25994 .5554 L F
.207 0 0 r
.26266 .55268 m .26014 .55385 L .2626 .5527 L F
0 .52 .719 r
.26255 .55271 m .2626 .5527 L .26393 .55288 L F
.952 .927 .74 r
.26393 .55288 m .26656 .54954 L .26487 .55166 L F
.855 .846 .834 r
.31492 .62896 m .31024 .63105 L .31258 .62804 L F
0 0 0 r
.31538 .62988 m .31492 .62896 L .31258 .62804 L F
.31538 .62988 m .31738 .62782 L .31492 .62896 L F
.949 .904 .52 r
.69332 .34141 m .69426 .33905 L .69296 .34012 L F
.961 .942 .648 r
.69419 .33566 m .69426 .33905 L .69575 .33504 L F
.952 .901 .517 r
.69296 .34012 m .69426 .33905 L .69419 .33566 L F
.955 .635 .219 r
.33725 .51613 m .3389 .52017 L .33761 .51871 L F
.582 .052 0 r
.3389 .52017 m .3372 .52138 L .33761 .51871 L F
.3389 .52017 m .34162 .52191 L .3372 .52138 L F
.838 .997 .769 r
.54591 .41133 m .54839 .40854 L .54649 .40894 L F
.778 .947 .931 r
.54901 .40572 m .54839 .40854 L .55055 .4066 L F
.869 .993 .753 r
.54649 .40894 m .54839 .40854 L .54901 .40572 L F
.283 .235 .625 r
.30871 .58185 m .30976 .5814 L .3077 .57894 L F
.88 .654 .59 r
.36133 .54471 m .3643 .54886 L .36411 .54615 L F
.894 .651 .563 r
.39282 .55268 m .38956 .54766 L .39303 .54935 L F
.975 .822 .627 r
.67542 .33831 m .67294 .34043 L .67433 .33765 L F
.67542 .33831 m .67442 .34192 L .67294 .34043 L F
0 0 .06 r
.32301 .50685 m .32343 .50779 L .32226 .50451 L F
.32301 .50685 m .32254 .50966 L .32343 .50779 L F
.307 .615 .956 r
.3263 .53004 m .32535 .52806 L .32256 .5264 L F
.3263 .53004 m .3267 .52991 L .32535 .52806 L F
0 0 0 r
.28075 .51937 m .2789 .52163 L .27705 .52249 L F
.058 0 .209 r
.28407 .51654 m .28302 .51973 L .28012 .52028 L F
0 0 0 r
.28012 .52028 m .2789 .52163 L .28184 .51848 L F
.28184 .51848 m .2789 .52163 L .28075 .51937 L F
.723 .196 0 r
.35919 .50522 m .3548 .50228 L .357 .50304 L F
.804 .979 .696 r
.50544 .42157 m .50847 .41761 L .50727 .41875 L F
.579 .797 .982 r
.50719 .42071 m .50544 .42157 L .50727 .41875 L F
.50719 .42071 m .50637 .42288 L .50544 .42157 L F
.765 .747 .836 r
.62115 .41188 m .61915 .40734 L .61916 .40975 L F
.62115 .41188 m .62209 .40648 L .61915 .40734 L F
.507 .24 .445 r
.62229 .40311 m .62234 .40464 L .62222 .40302 L F
.852 .802 .802 r
.62353 .40526 m .62352 .40542 L .62551 .4064 L F
.507 .24 .445 r
.62477 .40611 m .62347 .40532 L .6234 .40519 L F
.852 .802 .802 r
.62263 .40613 m .62319 .40986 L .62353 .40526 L F
.62241 .40462 m .6234 .40519 L .62477 .40611 L F
.6234 .40519 m .62551 .4064 L .62477 .40611 L F
.507 .24 .445 r
.62477 .40611 m .6234 .40519 L .62229 .40311 L F
.62347 .40532 m .62234 .40464 L .62229 .40311 L F
.852 .802 .802 r
.62352 .40542 m .62319 .40986 L .62469 .40762 L F
.62352 .40542 m .62469 .40762 L .62551 .4064 L F
.507 .24 .445 r
.62338 .40541 m .62114 .40659 L .62234 .40464 L F
.62299 .40579 m .62114 .40659 L .62338 .40541 L F
.852 .802 .802 r
.62241 .40462 m .62263 .40613 L .62353 .40526 L F
.507 .24 .445 r
.62356 .40554 m .62299 .40579 L .62338 .40541 L F
.765 .747 .836 r
.62115 .41188 m .62319 .40986 L .62263 .40613 L F
.62115 .41188 m .62263 .40613 L .62209 .40648 L F
.507 .24 .445 r
.62447 .40621 m .62209 .40648 L .62356 .40554 L F
.62209 .40648 m .62114 .40659 L .62356 .40554 L F
.765 .747 .836 r
.62209 .40648 m .62263 .40613 L .62241 .40462 L F
.62209 .40648 m .62213 .40621 L .62114 .40659 L F
.62209 .40648 m .62114 .40659 L .61915 .40734 L F
.507 .24 .445 r
.62477 .40611 m .62447 .40621 L .62234 .40464 L F
.62447 .40621 m .62055 .40755 L .62114 .40659 L F
.367 .087 .35 r
.61915 .40734 m .62055 .40755 L .62114 .40659 L F
.61915 .40734 m .62114 .40659 L .62234 .40464 L F
.765 .747 .836 r
.62213 .40621 m .62241 .40462 L .61915 .40734 L F
.9 .901 .817 r
.49672 .52537 m .49822 .52653 L .50057 .52314 L F
.49672 .52537 m .50057 .52314 L .50058 .52312 L F
.427 0 .091 r
.49244 .5276 m .49301 .52752 L .49672 .52537 L F
0 0 0 r
.49872 .52671 m .49822 .52653 L .49672 .52537 L F
.427 0 .091 r
.49301 .52752 m .49872 .52671 L .49672 .52537 L F
.905 .755 .685 r
.35956 .53639 m .36049 .53955 L .36075 .53867 L F
.717 .503 .598 r
.37749 .46277 m .37455 .46656 L .37468 .46376 L F
.98 .685 .352 r
.37468 .46376 m .37691 .46308 L .37749 .46277 L F
.37468 .46376 m .37455 .46656 L .37326 .46554 L F
.37468 .46376 m .37326 .46554 L .37691 .46308 L F
0 .507 .859 r
.27231 .61407 m .27006 .61356 L .26783 .61221 L F
.428 .251 .537 r
.51298 .41032 m .51066 .40986 L .51272 .40778 L F
.51298 .41032 m .51065 .41107 L .51066 .40986 L F
.852 .494 .375 r
.34159 .53634 m .34213 .5385 L .34342 .53715 L F
.975 .916 .676 r
.59265 .40561 m .59484 .40453 L .59392 .40344 L F
.59265 .40561 m .59343 .4077 L .59484 .40453 L F
.772 .899 .931 r
.59484 .40453 m .59623 .4012 L .59392 .40344 L F
.59484 .40453 m .59752 .40256 L .59623 .4012 L F
.864 .696 .672 r
.37594 .58481 m .37353 .58825 L .37766 .58929 L F
.842 .754 .765 r
.37353 .58825 m .37496 .59207 L .37766 .58929 L F
0 0 0 r
.44349 .45125 m .44754 .45052 L .44484 .45105 L F
.44484 .45105 m .44754 .45052 L .44997 .45029 L F
.492 .72 .973 r
.4386 .59925 m .43964 .59703 L .43694 .59759 L F
.4386 .59925 m .44125 .59884 L .43964 .59703 L F
.276 0 0 r
.41575 .45212 m .4186 .45187 L .41625 .45137 L F
0 0 .528 r
.52738 .43998 m .52833 .44418 L .52885 .44185 L F
0 0 .357 r
.52833 .44418 m .52965 .44036 L .52885 .44185 L F
.705 .966 .937 r
.52885 .44185 m .52833 .44418 L .52721 .44355 L F
0 .117 .663 r
.52972 .4451 m .52833 .44418 L .52885 .44185 L F
.13 .042 .48 r
.52972 .4451 m .52851 .44727 L .52833 .44418 L F
.684 .943 .665 r
.51375 .41848 m .51271 .4203 L .51195 .42055 L F
.003 0 0 r
.59857 .39352 m .59941 .39201 L .60157 .39065 L F
.447 0 0 r
.399 .46307 m .39656 .46481 L .39475 .46355 L F
.333 0 0 r
.40155 .46229 m .39656 .46481 L .399 .46307 L F
.045 .227 .727 r
.42964 .56761 m .43123 .57158 L .42868 .56932 L F
0 0 0 r
.5112 .398 m .5129 .39648 L .51379 .39451 L F
.492 .851 .601 r
.5112 .398 m .50957 .39915 L .5129 .39648 L F
.923 .919 .793 r
.69341 .3659 m .69461 .36078 L .69241 .36448 L F
.989 .811 .426 r
.72382 .31591 m .72336 .31141 L .72225 .31452 L F
.986 .766 .522 r
.72225 .31452 m .72351 .31865 L .72382 .31591 L F
.61 .911 .981 r
.44459 .56477 m .4422 .5653 L .44328 .5647 L F
0 0 0 r
.44587 .56432 m .44459 .56477 L .44328 .5647 L F
.44587 .56432 m .44763 .56308 L .44459 .56477 L F
.507 .912 .853 r
.5899 .43536 m .58536 .43726 L .58731 .43387 L F
.212 0 .324 r
.3633 .49028 m .363 .49307 L .36569 .49095 L F
.644 .605 .796 r
.70545 .3158 m .70701 .31981 L .70981 .31907 L F
.377 .842 .836 r
.4395 .44408 m .43922 .44475 L .4373 .44543 L F
.4395 .44408 m .44181 .44381 L .43922 .44475 L F
.501 .738 .979 r
.70951 .28776 m .71233 .28748 L .71006 .28914 L F
.436 0 0 r
.71199 .29041 m .71006 .28914 L .71233 .28748 L F
.71199 .29041 m .70958 .29066 L .71006 .28914 L F
.749 .906 .946 r
.65861 .38406 m .66014 .38518 L .66203 .38387 L F
.344 .326 .695 r
.70326 .30229 m .70551 .30147 L .70471 .29769 L F
.348 .337 .706 r
.70326 .30229 m .70615 .30394 L .70551 .30147 L F
.855 .863 .846 r
.36635 .61661 m .36975 .61504 L .36822 .61442 L F
.906 .85 .778 r
.36822 .61442 m .36975 .61504 L .3715 .61157 L F
.701 .308 0 r
.3986 .58786 m .39679 .58445 L .39761 .58585 L F
.824 .995 .755 r
.48285 .52261 m .4855 .51878 L .483 .51997 L F
.792 .377 .264 r
.37686 .51991 m .37487 .52154 L .37307 .51882 L F
.946 .65 .448 r
.37686 .51991 m .37695 .52251 L .37487 .52154 L F
.701 .227 .121 r
.42585 .56416 m .42757 .56263 L .42631 .56161 L F
.42585 .56416 m .42972 .56487 L .42757 .56263 L F
.697 .695 .844 r
.30533 .63489 m .30852 .63623 L .30785 .63432 L F
.86 .843 .826 r
.31024 .63105 m .30852 .63623 L .30785 .63432 L F
.482 .627 .915 r
.30852 .63623 m .31028 .63382 L .30785 .63432 L F
.30852 .63623 m .31205 .63697 L .31028 .63382 L F
.9 .901 .817 r
.49672 .52537 m .50058 .52312 L .49985 .52242 L F
.856 .995 .821 r
.50086 .52098 m .50058 .52312 L .50346 .51981 L F
.50086 .52098 m .49985 .52242 L .50058 .52312 L F
.304 0 .037 r
.45793 .55181 m .46063 .55133 L .46118 .54936 L F
0 0 0 r
.46118 .54936 m .46063 .55133 L .46228 .54716 L F
0 .049 .609 r
.58445 .39228 m .58583 .394 L .58375 .39068 L F
.681 .393 .478 r
.53173 .39295 m .5298 .39102 L .53231 .39046 L F
.961 .942 .648 r
.69419 .33566 m .69575 .33504 L .69547 .3342 L F
.699 .165 0 r
.36884 .5134 m .3688 .51448 L .36722 .51217 L F
.36884 .5134 m .37086 .51563 L .3688 .51448 L F
.89 .465 .147 r
.42437 .54293 m .4254 .54508 L .42729 .54595 L F
.779 .823 .351 r
.42668 .54648 m .42729 .54595 L .4254 .54508 L F
.433 .733 .99 r
.28882 .60177 m .2916 .60256 L .28966 .60075 L F
.535 .026 0 r
.28966 .60075 m .2916 .60256 L .29147 .6026 L F
0 0 0 r
.2916 .60256 m .29455 .60199 L .29147 .6026 L F
.481 .716 .974 r
.26769 .54758 m .26656 .54954 L .26497 .54789 L F
0 0 0 r
.26701 .55057 m .26656 .54954 L .26769 .54758 L F
.26701 .55057 m .26487 .55166 L .26656 .54954 L F
.836 .997 .839 r
.53231 .48803 m .52911 .49123 L .53164 .49052 L F
.864 .751 .736 r
.3715 .61157 m .37085 .60796 L .36854 .61144 L F
.906 .85 .778 r
.36822 .61442 m .3715 .61157 L .36854 .61144 L F
.723 .835 .389 r
.36827 .47232 m .36933 .47052 L .36777 .47332 L F
0 0 0 r
.36957 .47072 m .36933 .47052 L .36827 .47232 L F
.152 0 .173 r
.24272 .53613 m .24513 .53514 L .24625 .5324 L F
.229 .034 .395 r
.24208 .53904 m .24513 .53514 L .24272 .53613 L F
.785 .998 .843 r
.60535 .36394 m .60341 .36718 L .6058 .36368 L F
.60535 .36394 m .60253 .36671 L .60341 .36718 L F
.526 .435 .695 r
.28725 .63166 m .28526 .63519 L .28348 .63459 L F
.28725 .63166 m .28772 .63462 L .28526 .63519 L F
.445 .833 .985 r
.28526 .63519 m .28593 .63391 L .28348 .63459 L F
.28526 .63519 m .28772 .63462 L .28593 .63391 L F
.681 .917 .973 r
.46765 .44177 m .47308 .44146 L .47159 .44082 L F
.671 .972 .903 r
.47308 .44146 m .47519 .44008 L .47436 .43954 L F
.599 .893 .989 r
.47159 .44082 m .47308 .44146 L .47436 .43954 L F
0 0 0 r
.6462 .34171 m .64873 .34109 L .64505 .3428 L F
.767 .972 .922 r
.631 .40275 m .63535 .40124 L .63456 .40071 L F
.703 .981 .897 r
.63669 .39906 m .63535 .40124 L .63748 .3996 L F
.7 .979 .906 r
.63456 .40071 m .63535 .40124 L .63669 .39906 L F
.257 0 0 r
.65862 .33506 m .65762 .33669 L .6548 .33717 L F
.123 0 0 r
.66035 .33581 m .65862 .33506 L .66137 .3341 L F
.66035 .33581 m .65762 .33669 L .65862 .33506 L F
.254 0 0 r
.62935 .34499 m .62531 .3461 L .62689 .346 L F
.157 .649 .918 r
.35031 .55613 m .34932 .55539 L .34661 .55507 L F
.799 .372 .235 r
.34661 .55507 m .34841 .5577 L .35031 .55613 L F
.985 .901 .592 r
.35031 .55613 m .34841 .5577 L .34932 .55539 L F
0 .148 .692 r
.5777 .376 m .57907 .37592 L .57631 .37471 L F
.812 .688 .729 r
.36595 .55535 m .36753 .5594 L .3685 .55663 L F
.344 .081 .364 r
.59623 .38081 m .59877 .38227 L .60033 .38098 L F
.79 .662 .722 r
.59877 .38227 m .60252 .38224 L .60033 .38098 L F
.783 .935 .93 r
.35207 .5636 m .35268 .5639 L .3542 .56207 L F
.967 .733 .532 r
.38966 .54372 m .38794 .54501 L .38788 .54213 L F
.38966 .54372 m .3898 .54645 L .38794 .54501 L F
.745 .929 .581 r
.50346 .51981 m .50602 .51618 L .50442 .51763 L F
.597 .837 .463 r
.50602 .51618 m .50861 .51278 L .50714 .51456 L F
.618 .885 .56 r
.50442 .51763 m .50602 .51618 L .50714 .51456 L F
.971 .789 .601 r
.34341 .55892 m .34255 .55489 L .34447 .55672 L F
.085 0 .194 r
.34447 .55672 m .34341 .55892 L .34661 .55507 L F
.646 .784 .948 r
.34255 .55489 m .34447 .55672 L .34661 .55507 L F
.268 .412 .822 r
.5325 .47188 m .53121 .47379 L .53012 .47391 L F
.5325 .47188 m .53449 .47559 L .53121 .47379 L F
.857 .649 .621 r
.57636 .43605 m .58033 .43428 L .57705 .43362 L F
.57636 .43605 m .5809 .43803 L .58033 .43428 L F
.216 .132 .54 r
.23746 .55989 m .23972 .56079 L .23976 .55841 L F
.23746 .55989 m .23767 .56241 L .23972 .56079 L F
.817 .715 .753 r
.35877 .53926 m .36049 .53955 L .35956 .53639 L F
.859 .576 .508 r
.35877 .53926 m .36089 .54228 L .36049 .53955 L F
.315 0 0 r
.61445 .34333 m .61868 .34243 L .61594 .34322 L F
.922 .844 .749 r
.35537 .49795 m .35211 .49916 L .35319 .49603 L F
.35537 .49795 m .35436 .50052 L .35211 .49916 L F
.788 .733 .802 r
.35773 .4958 m .35537 .49795 L .35319 .49603 L F
.63 .723 .915 r
.30087 .6319 m .30076 .63354 L .30367 .6314 L F
.867 .42 .082 r
.2964 .60088 m .29537 .59796 L .29214 .60128 L F
.764 .441 0 r
.56072 .42226 m .56148 .42439 L .56067 .42272 L F
0 0 .387 r
.56067 .42272 m .56172 .42391 L .56063 .42319 L F
.56067 .42272 m .56063 .42319 L .55867 .42191 L F
.764 .441 0 r
.56006 .42041 m .56072 .42226 L .56067 .42272 L F
.913 .519 .231 r
.3548 .50228 m .35211 .49916 L .35436 .50052 L F
.883 .465 .05 r
.3476 .53329 m .34871 .5358 L .3471 .53451 L F
.636 .229 .254 r
.41512 .46016 m .41101 .46186 L .4111 .46119 L F
.41512 .46016 m .41354 .46227 L .41101 .46186 L F
.673 .36 .437 r
.41748 .46067 m .41354 .46227 L .41512 .46016 L F
.762 .995 .818 r
.50442 .51763 m .50086 .52098 L .50346 .51981 L F
.579 .211 .309 r
.30845 .68337 m .30884 .68146 L .31109 .68351 L F
.529 .223 .393 r
.30884 .68146 m .31164 .68116 L .31109 .68351 L F
.846 .434 .254 r
.71936 .30387 m .72258 .30486 L .72053 .30225 L F
.873 .986 .828 r
.55721 .4562 m .55593 .45804 L .55621 .45556 L F
.891 .989 .78 r
.55621 .45556 m .55593 .45804 L .55447 .45943 L F
.77 .717 .803 r
.32069 .65749 m .31774 .66098 L .31629 .65721 L F
0 0 0 r
.58624 .34857 m .58743 .34655 L .58799 .34433 L F
.936 .602 .377 r
.37307 .51882 m .37086 .51563 L .37311 .51657 L F
.137 .377 .832 r
.56169 .37477 m .56242 .37276 L .55942 .37105 L F
.955 .881 .482 r
.56213 .37611 m .56242 .37276 L .56169 .37477 L F
.625 .959 .823 r
.44811 .44036 m .44392 .44251 L .44728 .44044 L F
.531 .912 .762 r
.44957 .43895 m .45147 .43827 L .44811 .44036 L F
.531 .912 .764 r
.44957 .43895 m .44811 .44036 L .44728 .44044 L F
.907 .907 .811 r
.30289 .55029 m .29992 .55178 L .30238 .54823 L F
.349 0 0 r
.30289 .55029 m .30266 .55175 L .29992 .55178 L F
0 0 0 r
.30462 .55018 m .30266 .55175 L .30289 .55029 L F
.615 .8 .971 r
.32739 .64118 m .33116 .64163 L .3302 .6411 L F
.708 .813 .93 r
.3302 .6411 m .33116 .64163 L .33301 .64013 L F
.584 .374 .562 r
.24385 .58875 m .24745 .58863 L .2466 .5864 L F
0 .024 .553 r
.2466 .5864 m .24822 .5876 L .24745 .58863 L F
.24745 .58863 m .24822 .5876 L .2466 .5864 L F
.783 .855 .904 r
.47837 .43772 m .48216 .43767 L .48062 .43619 L F
.626 .765 .946 r
.48216 .43767 m .48337 .43489 L .48062 .43619 L F
.48216 .43767 m .48482 .43671 L .48337 .43489 L F
.885 .716 .668 r
.36348 .55787 m .36753 .5594 L .36595 .55535 L F
.927 .646 .489 r
.36511 .561 m .36753 .5594 L .36348 .55787 L F
.36511 .561 m .36739 .56197 L .36753 .5594 L F
.944 .582 .232 r
.37917 .52604 m .37761 .52519 L .37695 .52251 L F
.79 .341 .177 r
.37917 .52604 m .37731 .52766 L .37761 .52519 L F
.37917 .52604 m .38067 .52858 L .37731 .52766 L F
.72 .777 .898 r
.32721 .65774 m .32544 .65948 L .32297 .65728 L F
.905 .949 .82 r
.57021 .45279 m .57398 .4505 L .57258 .44902 L F
.57021 .45279 m .57136 .45395 L .57398 .4505 L F
.853 .845 .836 r
.57258 .44902 m .57398 .4505 L .57668 .44723 L F
.789 .998 .851 r
.48746 .41165 m .4899 .41112 L .48678 .41393 L F
.811 .969 .66 r
.48678 .41393 m .48633 .41361 L .48746 .41165 L F
.255 .417 .832 r
.31995 .61135 m .31729 .60859 L .31978 .60909 L F
.759 .995 .856 r
.5946 .37916 m .59335 .38157 L .59675 .37886 L F
.651 .484 .644 r
.59623 .38081 m .59335 .38157 L .59675 .37886 L F
.553 .246 .401 r
.59335 .38157 m .59608 .38343 L .59623 .38081 L F
.199 .322 .765 r
.5946 .37916 m .59608 .38343 L .59335 .38157 L F
0 0 0 r
.30568 .58651 m .30504 .58607 L .30806 .58457 L F
0 0 .349 r
.30976 .5814 m .3096 .58416 L .30806 .58457 L F
0 0 0 r
.3096 .58416 m .30568 .58651 L .30806 .58457 L F
.286 .241 .632 r
.70431 .30909 m .70629 .31102 L .70615 .30394 L F
0 0 .437 r
.56173 .38155 m .56278 .38231 L .56091 .38004 L F
.424 .661 .96 r
.31629 .65721 m .31418 .65748 L .31213 .6551 L F
0 0 0 r
.6353 .38649 m .63263 .38833 L .63148 .38998 L F
.423 .191 .454 r
.24393 .5919 m .24745 .58863 L .24385 .58875 L F
.676 .364 0 r
.49436 .44685 m .49499 .44866 L .49493 .44848 L F
.628 .819 .974 r
.26188 .62779 m .2608 .62905 L .25761 .62732 L F
.535 0 0 r
.51935 .41186 m .52092 .41118 L .51575 .41033 L F
.51935 .41186 m .51575 .41033 L .51584 .4106 L F
.51935 .41186 m .51451 .41013 L .51691 .41357 L F
.773 .517 .548 r
.51935 .41186 m .51586 .41226 L .51627 .40946 L F
0 0 .114 r
.51697 .41053 m .51621 .41171 L .51627 .40946 L F
.51621 .41171 m .51586 .41226 L .51602 .41114 L F
.51621 .41171 m .51602 .41114 L .51627 .40946 L F
.535 0 0 r
.51584 .4106 m .51575 .41033 L .51451 .41013 L F
.443 .284 .569 r
.52355 .41046 m .52127 .41423 L .52092 .41118 L F
0 0 0 r
.52202 .41158 m .52092 .41118 L .51935 .41186 L F
.52202 .41158 m .52355 .41046 L .52092 .41118 L F
.17 .118 .552 r
.23717 .57251 m .23876 .57509 L .23899 .56979 L F
.751 .993 .811 r
.51166 .51003 m .50961 .51067 L .50861 .51278 L F
.706 .881 .489 r
.50861 .51278 m .50961 .51067 L .50714 .51456 L F
0 0 0 r
.51379 .39451 m .51572 .39333 L .51612 .3931 L F
.51379 .39451 m .5129 .39648 L .51572 .39333 L F
.955 .699 .51 r
.34393 .52309 m .34141 .52469 L .34162 .52191 L F
.34393 .52309 m .34359 .52632 L .34141 .52469 L F
.012 0 .325 r
.53299 .42057 m .535 .41717 L .53268 .41807 L F
.88 .8 .766 r
.5919 .35806 m .59027 .3619 L .58762 .36057 L F
.4 .334 .667 r
.58958 .36418 m .5926 .3669 L .59177 .36363 L F
.989 .741 .462 r
.59012 .36431 m .58879 .361 L .58906 .36124 L F
0 0 .554 r
.59048 .35406 m .5919 .35806 L .59182 .35626 L F
.59182 .35626 m .5919 .35806 L .59048 .35406 L F
.88 .8 .766 r
.5919 .35806 m .58762 .36057 L .59182 .35626 L F
.776 .992 .772 r
.59182 .35626 m .58937 .35877 L .58877 .35813 L F
.58937 .35877 m .58762 .36057 L .58877 .35813 L F
.489 .78 .996 r
.58877 .35813 m .58472 .35701 L .58625 .35577 L F
.873 .505 .346 r
.58618 .35372 m .58943 .35759 L .58625 .35577 L F
.489 .78 .996 r
.58877 .35813 m .58625 .35577 L .58943 .35759 L F
.58877 .35813 m .58825 .35673 L .58472 .35701 L F
.879 .73 .216 r
.58906 .36124 m .58877 .35813 L .58762 .36057 L F
.58906 .36124 m .5883 .3598 L .58877 .35813 L F
0 0 0 r
.5883 .3598 m .58844 .35967 L .58877 .35813 L F
.885 .665 .145 r
.58877 .35813 m .58844 .35967 L .5883 .35762 L F
.58877 .35813 m .5883 .35762 L .58825 .35673 L F
.989 .741 .462 r
.58879 .361 m .5883 .3598 L .58906 .36124 L F
.628 .102 0 r
.58918 .36135 m .58906 .36124 L .58762 .36057 L F
.59027 .3619 m .58906 .36124 L .58918 .36135 L F
.95 .932 .744 r
.5692 .45797 m .57136 .45395 L .57021 .45279 L F
.546 .723 .956 r
.60431 .40236 m .60837 .404 L .60727 .40152 L F
.675 .826 .956 r
.60837 .404 m .61019 .40075 L .60727 .40152 L F
.60837 .404 m .61095 .40271 L .61019 .40075 L F
0 .369 .762 r
.25477 .61779 m .25704 .61875 L .25481 .61735 L F
.752 .994 .85 r
.46775 .54339 m .46859 .54134 L .46813 .53962 L F
.46775 .54339 m .46539 .54401 L .46859 .54134 L F
.996 .827 .557 r
.34854 .58604 m .34662 .58561 L .34759 .58143 L F
.763 .331 0 r
.34807 .58755 m .34662 .58561 L .34854 .58604 L F
.736 .71 .826 r
.35201 .5825 m .34854 .58604 L .34759 .58143 L F
.158 .01 .416 r
.52139 .40288 m .5193 .40445 L .52122 .40073 L F
.495 .194 .385 r
.43794 .56906 m .44094 .56872 L .4422 .5653 L F
.295 .006 .292 r
.4422 .5653 m .44334 .56767 L .44328 .5647 L F
.4422 .5653 m .44094 .56872 L .44334 .56767 L F
.764 .678 .767 r
.32214 .57704 m .32114 .5793 L .32346 .57578 L F
.289 .731 .964 r
.48482 .43671 m .48893 .43745 L .48728 .4366 L F
.209 .658 .948 r
.48893 .43745 m .49312 .43717 L .48728 .4366 L F
.48893 .43745 m .49147 .43774 L .49312 .43717 L F
.669 .557 .719 r
.33259 .52273 m .32947 .52457 L .32843 .51968 L F
0 0 .178 r
.51061 .41377 m .5102 .41611 L .50847 .41761 L F
.581 .804 .984 r
.60095 .39424 m .59847 .39618 L .59857 .39352 L F
.60095 .39424 m .60287 .39565 L .59847 .39618 L F
.792 .998 .848 r
.5946 .37916 m .59675 .37886 L .59793 .37722 L F
.905 .535 .321 r
.2875 .68008 m .29068 .68185 L .29064 .68394 L F
0 0 0 r
.30504 .58607 m .30568 .58651 L .30535 .58366 L F
.30504 .58607 m .30452 .58812 L .30568 .58651 L F
.30568 .58651 m .30452 .58812 L .30504 .58607 L F
.732 .735 .854 r
.34441 .52896 m .34048 .53002 L .34359 .52632 L F
.571 .228 .348 r
.34441 .52896 m .34019 .532 L .34048 .53002 L F
.34441 .52896 m .34275 .53195 L .34019 .532 L F
.656 .323 .396 r
.34729 .53178 m .34441 .52896 L .34638 .52952 L F
.966 .658 .387 r
.38268 .53227 m .38067 .52858 L .38254 .52964 L F
0 0 .207 r
.54678 .41254 m .54591 .41133 L .54649 .40894 L F
.691 .525 .657 r
.66117 .39704 m .66325 .39418 L .66114 .39521 L F
0 0 0 r
.32585 .53892 m .32672 .53856 L .32826 .53843 L F
.6 .483 .691 r
.32826 .53843 m .32618 .54405 L .32585 .53892 L F
0 0 0 r
.32585 .53892 m .32299 .54041 L .32672 .53856 L F
.046 .533 .885 r
.33643 .52797 m .33913 .52878 L .34048 .53002 L F
.823 .918 .901 r
.34359 .52632 m .34048 .53002 L .34024 .52636 L F
.921 .961 .789 r
.34048 .53002 m .33913 .52878 L .34024 .52636 L F
.983 .728 .464 r
.55921 .44214 m .55952 .44666 L .55798 .44295 L F
.223 0 0 r
.61868 .34243 m .62106 .34279 L .62236 .34106 L F
.315 0 0 r
.62236 .34106 m .62391 .34241 L .62515 .34072 L F
.62236 .34106 m .62106 .34279 L .62391 .34241 L F
.579 .644 .879 r
.33615 .65723 m .33465 .66091 L .3335 .65769 L F
0 0 .435 r
.58099 .38151 m .58152 .38207 L .57844 .3803 L F
.58099 .38151 m .58251 .38372 L .58152 .38207 L F
.613 .954 .821 r
.28306 .60404 m .28551 .60327 L .28728 .60187 L F
.941 .753 .621 r
.59384 .41723 m .59456 .41497 L .59243 .41328 L F
.59384 .41723 m .59456 .41497 L .59243 .41328 L F
.862 .954 .869 r
.51124 .4332 m .51461 .43049 L .513 .42921 L F
.51128 .43325 m .51461 .43049 L .51124 .4332 L F
.51119 .43333 m .51124 .4332 L .51081 .43251 L F
.51124 .4332 m .513 .42921 L .51081 .43251 L F
.881 .866 .819 r
.50964 .43072 m .51081 .43251 L .513 .42921 L F
0 0 .407 r
.51048 .43198 m .51081 .43251 L .50985 .43104 L F
.51263 .4352 m .51081 .43251 L .51048 .43198 L F
.50972 .43084 m .50985 .43104 L .50964 .43072 L F
.51263 .4352 m .50985 .43104 L .50972 .43084 L F
.862 .954 .869 r
.51119 .43333 m .51128 .43325 L .51124 .4332 L F
.477 .588 .886 r
.51461 .43049 m .51856 .43254 L .51736 .43018 L F
.529 .546 .816 r
.55666 .36019 m .55552 .36475 L .55531 .36271 L F
.178 .465 .887 r
.55552 .36475 m .55666 .36307 L .55531 .36271 L F
.55552 .36475 m .5589 .36647 L .55666 .36307 L F
.501 .234 .441 r
.26365 .53606 m .26378 .53856 L .25967 .53899 L F
.702 .479 .582 r
.26626 .53583 m .26378 .53856 L .26365 .53606 L F
.439 .165 .4 r
.32721 .6709 m .32933 .67298 L .32604 .67389 L F
.32721 .6709 m .32978 .6705 L .32933 .67298 L F
.683 .972 .916 r
.59456 .37163 m .59374 .37114 L .59593 .36954 L F
.59456 .37163 m .59374 .37114 L .59593 .36954 L F
0 0 0 r
.60797 .3627 m .60535 .36394 L .6058 .36368 L F
.60797 .3627 m .60535 .36394 L .6058 .36368 L F
.932 .695 .558 r
.3948 .55601 m .39238 .55756 L .39264 .55504 L F
.3948 .55601 m .39452 .55888 L .39238 .55756 L F
.218 0 .006 r
.49764 .4419 m .4963 .44076 L .49602 .44378 L F
.49764 .4419 m .49805 .44002 L .4963 .44076 L F
.226 .179 .593 r
.3305 .58802 m .33192 .58522 L .33325 .58669 L F
.3303 .58747 m .33192 .58522 L .3305 .58802 L F
.396 .812 .974 r
.32902 .58555 m .32982 .58438 L .33192 .58522 L F
.226 .179 .593 r
.32957 .58847 m .32902 .58555 L .33192 .58522 L F
0 .122 .667 r
.3294 .58499 m .33119 .5877 L .32982 .58438 L F
.32902 .58555 m .32993 .58645 L .3294 .58499 L F
.32993 .58645 m .33119 .5877 L .3294 .58499 L F
.226 .179 .593 r
.32957 .58847 m .3303 .58747 L .3305 .58802 L F
.735 .734 .85 r
.3358 .5853 m .33325 .58669 L .33192 .58522 L F
.994 .751 .421 r
.69506 .35172 m .69436 .34808 L .69371 .35062 L F
.981 .697 .331 r
.69453 .35372 m .69506 .35172 L .69371 .35062 L F
.69453 .35372 m .69539 .35455 L .69506 .35172 L F
.81 .896 .904 r
.28499 .65348 m .28337 .65492 L .2818 .65344 L F
.809 .324 0 r
.28337 .65492 m .28307 .65639 L .2818 .65344 L F
.28337 .65492 m .28507 .65763 L .28307 .65639 L F
.87 .666 .623 r
.3748 .57831 m .37224 .58163 L .37605 .5822 L F
.843 .686 .687 r
.37224 .58163 m .37594 .58481 L .37605 .5822 L F
.42 .078 .278 r
.53571 .3851 m .53526 .38702 L .53802 .38636 L F
.233 0 0 r
.62796 .34074 m .63085 .34033 L .63197 .33896 L F
.058 0 0 r
.63197 .33896 m .63342 .33951 L .63477 .33837 L F
.63197 .33896 m .63085 .34033 L .63342 .33951 L F
.705 .488 .592 r
.51736 .43018 m .52172 .43076 L .52107 .42756 L F
.221 .719 .912 r
.52172 .43076 m .524 .42704 L .52107 .42756 L F
.669 .232 .203 r
.67741 .3119 m .68018 .314 L .68182 .31244 L F
.871 .522 .388 r
.68182 .31244 m .68018 .314 L .68346 .31464 L F
.795 .788 .846 r
.33045 .51566 m .32843 .51968 L .32679 .51579 L F
.518 .446 .714 r
.33131 .51878 m .32843 .51968 L .33045 .51566 L F
.669 .557 .719 r
.33259 .52273 m .32843 .51968 L .33131 .51878 L F
.817 .552 .538 r
.32449 .59984 m .33104 .60185 L .3324 .59878 L F
.166 .184 .634 r
.3324 .59878 m .33369 .59807 L .33321 .59338 L F
0 0 0 r
.3324 .59878 m .33276 .59817 L .33369 .59807 L F
.3324 .59878 m .33104 .60185 L .33276 .59817 L F
.177 .52 .918 r
.25066 .61382 m .24987 .61526 L .248 .6143 L F
.25066 .61382 m .25271 .61623 L .24987 .61526 L F
.25066 .61382 m .24987 .61526 L .248 .6143 L F
.25066 .61382 m .25271 .61623 L .24987 .61526 L F
.536 .479 .739 r
.70463 .31173 m .70759 .31236 L .70831 .31245 L F
.134 .647 .894 r
.70759 .31236 m .71164 .313 L .70831 .31245 L F
.666 .126 0 r
.34472 .54581 m .34513 .54708 L .34303 .54537 L F
.34472 .54581 m .3473 .54836 L .34513 .54708 L F
.75 .354 0 r
.59182 .35626 m .59442 .36101 L .5919 .35806 L F
.585 .207 .292 r
.63067 .34856 m .63345 .35037 L .63287 .34878 L F
.931 .775 .667 r
.47413 .56241 m .47395 .56529 L .47587 .56587 L F
.917 .63 .483 r
.47384 .56777 m .47587 .56587 L .47395 .56529 L F
.47384 .56777 m .47598 .56855 L .47587 .56587 L F
.75 .782 .879 r
.47587 .56587 m .47696 .56161 L .47413 .56241 L F
.47587 .56587 m .4787 .56333 L .47696 .56161 L F
.734 .885 .949 r
.44997 .45029 m .45344 .45 L .45219 .44905 L F
.747 .935 .948 r
.45344 .45 m .45566 .44695 L .45219 .44905 L F
.45344 .45 m .45723 .448 L .45566 .44695 L F
.678 .977 .878 r
.67731 .37723 m .67888 .37513 L .67694 .37665 L F
.67731 .37723 m .68101 .37492 L .67888 .37513 L F
.389 0 .137 r
.38144 .46416 m .37738 .46671 L .37749 .46277 L F
.38144 .46416 m .38026 .46616 L .37738 .46671 L F
.301 0 .07 r
.38401 .46365 m .38026 .46616 L .38144 .46416 L F
.077 0 0 r
.46052 .59161 m .46028 .59216 L .45607 .59371 L F
0 0 0 r
.46204 .59029 m .46028 .59216 L .46052 .59161 L F
.283 0 0 r
.4186 .45187 m .42129 .45208 L .42305 .45135 L F
0 0 0 r
.42129 .45208 m .42585 .45049 L .42305 .45135 L F
.04 .585 .842 r
.64426 .39807 m .64477 .39859 L .64786 .39889 L F
.988 .735 .454 r
.38821 .5396 m .38657 .54138 L .38621 .5384 L F
.38821 .5396 m .38788 .54213 L .38657 .54138 L F
0 0 0 r
.27621 .51368 m .27755 .51326 L .27784 .51239 L F
.27621 .51368 m .27456 .51468 L .27755 .51326 L F
.97 .707 .478 r
.42059 .53248 m .42038 .53518 L .42222 .53596 L F
.901 .587 .444 r
.41991 .5378 m .42222 .53596 L .42038 .53518 L F
.41991 .5378 m .42218 .53872 L .42222 .53596 L F
.486 .248 .478 r
.26378 .53856 m .2598 .54204 L .25967 .53899 L F
.31 0 .149 r
.32823 .61201 m .32513 .61446 L .32621 .61369 L F
.92 .559 .121 r
.32652 .60826 m .32823 .61201 L .32707 .61105 L F
.994 .869 .586 r
.32707 .61105 m .32823 .61201 L .32621 .61369 L F
.451 .165 .387 r
.32106 .67474 m .3231 .67667 L .32047 .67703 L F
.32106 .67474 m .32358 .6743 L .3231 .67667 L F
.808 .471 .418 r
.45426 .58817 m .45155 .58818 L .45319 .58713 L F
.892 .633 .539 r
.45319 .58713 m .45155 .58818 L .45179 .5863 L F
.955 .612 .245 r
.53196 .43612 m .53349 .43741 L .53174 .43843 L F
.53174 .43843 m .53349 .43741 L .53196 .43612 L F
.658 .2 .152 r
.28592 .60083 m .28747 .59873 L .28445 .59804 L F
.28592 .60083 m .28966 .60075 L .28747 .59873 L F
.569 .117 .141 r
.66821 .33207 m .6668 .33394 L .66437 .33362 L F
.76 .347 .267 r
.66821 .33207 m .67047 .33482 L .6668 .33394 L F
.789 .303 .061 r
.67236 .33522 m .67047 .33482 L .66821 .33207 L F
.073 .007 .469 r
.25305 .55793 m .25321 .56101 L .2511 .56196 L F
.185 0 .11 r
.25268 .56361 m .2511 .56196 L .25321 .56101 L F
.25268 .56361 m .25043 .56451 L .2511 .56196 L F
.774 .918 .54 r
.58731 .43387 m .58536 .43726 L .58597 .43522 L F
0 .18 .705 r
.58597 .43522 m .58536 .43726 L .58747 .43899 L F
.515 .837 .536 r
.66228 .32195 m .6642 .32002 L .6654 .31895 L F
0 0 0 r
.6654 .31895 m .66702 .31693 L .66776 .31526 L F
.588 .869 .546 r
.6654 .31895 m .6642 .32002 L .66702 .31693 L F
.855 .784 .782 r
.57496 .44592 m .57668 .44723 L .5756 .44361 L F
.853 .845 .836 r
.57258 .44902 m .57668 .44723 L .57496 .44592 L F
.81 .763 .809 r
.5756 .44361 m .57668 .44723 L .57944 .44395 L F
.929 .63 .454 r
.25481 .61735 m .25847 .6172 L .2573 .61501 L F
.956 .799 .647 r
.25704 .61875 m .25847 .6172 L .25481 .61735 L F
.988 .74 .36 r
.56824 .41561 m .56933 .41748 L .56938 .41431 L F
.973 .832 .422 r
.56824 .41561 m .56938 .41431 L .56874 .41309 L F
.92 .559 .121 r
.32652 .60826 m .32935 .6087 L .3307 .60865 L F
0 0 .264 r
.32782 .59547 m .32889 .59438 L .32915 .59144 L F
.034 0 .369 r
.32782 .59547 m .32866 .59576 L .32889 .59438 L F
.32782 .59547 m .32768 .59818 L .32866 .59576 L F
.32866 .59576 m .32768 .59818 L .32782 .59547 L F
.543 .513 .772 r
.3307 .60865 m .33319 .60807 L .33261 .60482 L F
.451 .884 .86 r
.3307 .60865 m .33188 .6076 L .33319 .60807 L F
.3307 .60865 m .32935 .6087 L .33188 .6076 L F
.875 .668 .62 r
.37085 .57495 m .37046 .57781 L .3748 .57831 L F
.875 .674 .627 r
.37046 .57781 m .37224 .58163 L .3748 .57831 L F
.638 .123 .004 r
.37089 .49556 m .37351 .49664 L .37513 .49625 L F
.183 .687 .907 r
.37351 .49664 m .3774 .49724 L .37513 .49625 L F
.494 .872 .663 r
.65386 .37869 m .65098 .38082 L .65288 .3792 L F
0 0 .17 r
.65288 .3792 m .65098 .38082 L .65052 .38323 L F
.672 .669 .839 r
.53885 .46455 m .53558 .46344 L .53858 .46293 L F
.761 .667 .758 r
.53817 .46059 m .53858 .46293 L .54118 .46015 L F
.966 .731 .294 r
.53744 .46105 m .53858 .46293 L .53817 .46059 L F
.075 0 .043 r
.65949 .32461 m .66205 .32403 L .66228 .32195 L F
0 0 .01 r
.66228 .32195 m .66381 .3219 L .6642 .32002 L F
.66228 .32195 m .66205 .32403 L .66381 .3219 L F
.648 .902 .578 r
.50969 .47018 m .50805 .47162 L .5069 .47342 L F
.528 .341 .572 r
.5069 .47342 m .5099 .47323 L .50969 .47018 L F
.444 .74 .991 r
.5069 .47342 m .5099 .47323 L .50805 .47162 L F
.646 .641 .831 r
.3868 .49054 m .38972 .4925 L .38967 .48874 L F
.349 .723 .986 r
.39405 .48993 m .38967 .48874 L .3923 .48824 L F
.787 .851 .899 r
.38972 .4925 m .3923 .48824 L .38967 .48874 L F
.38972 .4925 m .39405 .48993 L .3923 .48824 L F
.758 .477 .507 r
.6902 .32762 m .69383 .32555 L .69115 .32508 L F
.6902 .32762 m .69381 .328 L .69383 .32555 L F
.672 .72 .885 r
.29449 .65138 m .29147 .65321 L .29052 .65037 L F
.722 .703 .832 r
.60844 .38904 m .61189 .3897 L .61063 .38829 L F
0 0 0 r
.61189 .3897 m .61556 .38864 L .61507 .38897 L F
.61189 .3897 m .61507 .38897 L .61063 .38829 L F
.564 .087 .081 r
.29514 .68413 m .29949 .68397 L .29718 .68594 L F
.564 .065 .029 r
.29949 .68397 m .30005 .68613 L .29718 .68594 L F
.29949 .68397 m .30196 .68455 L .30005 .68613 L F
0 0 .438 r
.70888 .30055 m .70791 .29893 L .70784 .29763 L F
.70888 .30055 m .70927 .30235 L .70835 .30004 L F
0 .161 .671 r
.70888 .30055 m .70952 .30332 L .70927 .30235 L F
.70888 .30055 m .71255 .30403 L .70952 .30332 L F
0 .151 .656 r
.70985 .30147 m .70888 .30055 L .70844 .30341 L F
.71015 .30106 m .7118 .30288 L .70888 .30055 L F
.71015 .30106 m .70888 .30055 L .70985 .30147 L F
0 0 .438 r
.70888 .30055 m .70835 .30004 L .70791 .29893 L F
.205 0 .095 r
.27208 .51594 m .27337 .51762 L .27456 .51468 L F
.27208 .51594 m .27116 .5184 L .27337 .51762 L F
.617 .236 .298 r
.49086 .5373 m .48613 .53875 L .4884 .54002 L F
.12 .275 .749 r
.48613 .53875 m .48746 .54262 L .4884 .54002 L F
.617 .236 .298 r
.49086 .5373 m .48803 .5403 L .48613 .53875 L F
.931 .967 .683 r
.49117 .53455 m .48805 .54005 L .49086 .5373 L F
.12 .275 .749 r
.48613 .53875 m .4881 .54036 L .48746 .54262 L F
.4881 .54036 m .4887 .54085 L .48828 .54146 L F
.4881 .54036 m .48828 .54146 L .48746 .54262 L F
.48613 .53875 m .48803 .5403 L .48803 .5403 L F
.617 .236 .298 r
.48803 .5403 m .48772 .54063 L .48613 .53875 L F
.659 .182 .108 r
.48477 .54013 m .48729 .54059 L .48613 .53875 L F
.931 .866 .752 r
.4877 .54048 m .48772 .54063 L .48783 .54044 L F
.12 .275 .749 r
.48803 .5403 m .4887 .54085 L .4887 .54085 L F
.48803 .5403 m .4887 .54085 L .48803 .5403 L F
.659 .182 .108 r
.48729 .54059 m .4887 .54085 L .4881 .54036 L F
.931 .967 .683 r
.48803 .5403 m .48772 .54063 L .48803 .5403 L F
.659 .182 .108 r
.48783 .54044 m .48803 .5403 L .48613 .53875 L F
.931 .967 .683 r
.48805 .54005 m .48783 .54044 L .48803 .5403 L F
.48783 .54044 m .48772 .54063 L .48803 .5403 L F
0 .102 .642 r
.48613 .53875 m .48772 .54063 L .4877 .54048 L F
.659 .182 .108 r
.4877 .54048 m .48783 .54044 L .48613 .53875 L F
0 .102 .642 r
.48613 .53875 m .4877 .54048 L .48716 .53705 L F
.659 .182 .108 r
.48729 .54059 m .4877 .54048 L .48613 .53875 L F
.48783 .54044 m .4881 .54036 L .48803 .5403 L F
.931 .866 .752 r
.48716 .53705 m .4877 .54048 L .48805 .54005 L F
.4877 .54048 m .48783 .54044 L .48805 .54005 L F
.48754 .53681 m .48805 .54005 L .49117 .53455 L F
.48716 .53705 m .48805 .54005 L .48754 .53681 L F
.931 .967 .683 r
.48805 .54005 m .48803 .5403 L .49086 .5373 L F
.49117 .53455 m .49086 .5373 L .49262 .53552 L F
.844 .694 .696 r
.37463 .59491 m .3764 .59866 L .3769 .59588 L F
.766 .673 .761 r
.47946 .55545 m .47747 .55925 L .4811 .55923 L F
.793 .486 .469 r
.47747 .55925 m .48096 .56193 L .4811 .55923 L F
.846 .61 .581 r
.69381 .328 m .69621 .33162 L .69684 .32884 L F
.737 .754 .866 r
.62078 .38181 m .62132 .38441 L .61773 .3843 L F
.501 0 0 r
.62132 .38441 m .62073 .38497 L .61773 .3843 L F
.338 .817 .785 r
.624 .38397 m .62073 .38497 L .62132 .38441 L F
.321 .141 .474 r
.51273 .4127 m .51065 .41107 L .51298 .41032 L F
.51273 .4127 m .51061 .41377 L .51065 .41107 L F
0 0 0 r
.66776 .31526 m .66992 .31376 L .6704 .31342 L F
.66776 .31526 m .66702 .31693 L .66992 .31376 L F
.23 .184 .597 r
.32256 .5264 m .32433 .52147 L .32309 .52337 L F
.494 .898 .927 r
.49147 .43774 m .49545 .43684 L .49479 .43712 L F
.483 .888 .94 r
.49678 .43559 m .49545 .43684 L .49842 .43576 L F
.508 .879 .667 r
.49479 .43712 m .49545 .43684 L .49678 .43559 L F
.944 .641 .193 r
.34511 .5884 m .34591 .58908 L .34119 .58765 L F
0 0 0 r
.34152 .59019 m .34511 .5884 L .34119 .58765 L F
.34152 .59019 m .34314 .58958 L .34511 .5884 L F
.34314 .58958 m .34348 .58945 L .34413 .58903 L F
.34314 .58958 m .34413 .58903 L .34511 .5884 L F
.655 .916 .978 r
.33976 .59158 m .33842 .59051 L .34152 .59019 L F
.346 .456 .83 r
.34119 .58765 m .33981 .5887 L .33886 .58546 L F
0 0 0 r
.34152 .59019 m .34119 .58765 L .34073 .58721 L F
.61 .569 .783 r
.33981 .5887 m .3358 .5853 L .33886 .58546 L F
.826 .718 .746 r
.34073 .58721 m .33842 .59051 L .34152 .59019 L F
.933 .859 .745 r
.34131 .58819 m .34171 .59037 L .34023 .59071 L F
.228 0 0 r
.33976 .59158 m .34033 .5933 L .34152 .59019 L F
.073 0 .087 r
.34152 .59019 m .34033 .5933 L .34198 .59183 L F
.933 .859 .745 r
.34171 .59037 m .34198 .59183 L .34063 .59097 L F
.34171 .59037 m .34063 .59097 L .34023 .59071 L F
.94 .939 .596 r
.34511 .5884 m .34348 .58945 L .34443 .58781 L F
.34511 .5884 m .34443 .58781 L .34554 .5859 L F
.944 .641 .193 r
.34511 .5884 m .34627 .58919 L .34591 .58908 L F
.34511 .5884 m .34639 .59137 L .34627 .58919 L F
.769 .981 .91 r
.68213 .3724 m .68101 .37492 L .6828 .37322 L F
.789 .997 .86 r
.67888 .37513 m .68101 .37492 L .68213 .3724 L F
.918 .977 .713 r
.70881 .29657 m .70714 .2967 L .70784 .29763 L F
.858 .995 .763 r
.70978 .29339 m .70881 .29657 L .71098 .29489 L F
.70978 .29339 m .70714 .2967 L .70881 .29657 L F
.411 .777 .994 r
.25716 .61357 m .2573 .61501 L .25599 .61376 L F
.929 .63 .454 r
.25481 .61735 m .2573 .61501 L .25716 .61357 L F
.726 .21 0 r
.41557 .59865 m .4188 .60128 L .41713 .60037 L F
.667 .133 0 r
.41713 .60037 m .4188 .60128 L .42109 .60391 L F
.812 .469 .407 r
.46108 .57912 m .45915 .58121 L .45724 .57927 L F
.46108 .57912 m .46112 .58144 L .45915 .58121 L F
0 0 0 r
.60036 .37364 m .60005 .37427 L .60131 .37151 L F
0 0 .283 r
.60119 .36948 m .60036 .37364 L .60131 .37151 L F
.60119 .36948 m .60124 .37184 L .60036 .37364 L F
.60124 .37184 m .60125 .37244 L .60036 .37364 L F
0 0 0 r
.60036 .37364 m .59954 .37538 L .60005 .37427 L F
.53 .5 .768 r
.45155 .58818 m .45072 .5925 L .44938 .59164 L F
.45155 .58818 m .45299 .59147 L .45072 .5925 L F
.226 .179 .593 r
.32957 .58847 m .33119 .5877 L .32902 .58555 L F
.464 .878 .746 r
.45379 .43691 m .45147 .43827 L .44957 .43895 L F
.691 .147 0 r
.32918 .5122 m .32507 .50931 L .32701 .50971 L F
.706 .366 .4 r
.41748 .46067 m .4216 .46004 L .42057 .46328 L F
.187 0 0 r
.4216 .46004 m .42282 .46153 L .42057 .46328 L F
.4216 .46004 m .42415 .45906 L .42282 .46153 L F
.602 .952 .852 r
.49167 .40984 m .4899 .41112 L .48746 .41165 L F
.658 .141 0 r
.60676 .38458 m .60941 .38675 L .61136 .38554 L F
.617 .921 .662 r
.61136 .38554 m .61304 .38345 L .6137 .38391 L F
.61136 .38554 m .60941 .38675 L .61304 .38345 L F
.536 .561 .827 r
.61556 .38864 m .61136 .38554 L .6137 .38391 L F
.4 .334 .667 r
.58958 .36418 m .5898 .36916 L .5926 .3669 L F
.845 .591 .555 r
.36902 .56861 m .36884 .57133 L .37313 .57174 L F
.85 .646 .625 r
.36884 .57133 m .37085 .57495 L .37313 .57174 L F
.592 .437 .641 r
.62424 .36478 m .62686 .36444 L .62679 .36177 L F
.62679 .36177 m .62686 .36444 L .62424 .36478 L F
.788 .999 .826 r
.51246 .50781 m .51166 .51003 L .51486 .50696 L F
.792 .998 .807 r
.51246 .50781 m .50961 .51067 L .51166 .51003 L F
.588 .898 .626 r
.28966 .60075 m .28882 .60177 L .28728 .60187 L F
.433 .733 .99 r
.28882 .60177 m .28966 .60075 L .28728 .60187 L F
.344 .081 .364 r
.59623 .38081 m .59608 .38343 L .59877 .38227 L F
.722 .197 0 r
.67236 .33522 m .67159 .33631 L .67047 .33482 L F
.828 .352 .024 r
.67433 .33765 m .67159 .33631 L .67236 .33522 L F
.958 .625 .327 r
.59957 .42485 m .60122 .4248 L .59879 .42265 L F
.59957 .42485 m .60098 .42591 L .60122 .4248 L F
.703 .924 .966 r
.45566 .44695 m .45723 .448 L .45922 .44655 L F
.547 .331 .538 r
.31433 .67755 m .31438 .68083 L .31164 .68116 L F
.535 .322 .537 r
.31714 .67977 m .31433 .67755 L .31776 .67723 L F
.31714 .67977 m .31438 .68083 L .31433 .67755 L F
.934 .823 .712 r
.56127 .45087 m .56037 .45343 L .55949 .44966 L F
.792 .995 .774 r
.62613 .40555 m .62477 .40611 L .62551 .4064 L F
.938 .872 .746 r
.60524 .35806 m .60133 .36079 L .60467 .35564 L F
.845 .833 .835 r
.60783 .35486 m .60524 .35806 L .60467 .35564 L F
.464 .268 .528 r
.60783 .35486 m .60788 .35745 L .60524 .35806 L F
.659 .954 .73 r
.6066 .35611 m .60524 .35806 L .60788 .35745 L F
.539 .529 .793 r
.60106 .36059 m .60225 .3652 L .59863 .36305 L F
.946 .898 .747 r
.60467 .35564 m .60133 .36079 L .60143 .36033 L F
.60449 .35549 m .60143 .36033 L .60284 .35406 L F
.60467 .35564 m .60143 .36033 L .60449 .35549 L F
.639 .595 .788 r
.60535 .36394 m .60225 .3652 L .60106 .36059 L F
.845 .833 .835 r
.60783 .35486 m .60467 .35564 L .60475 .35404 L F
.963 .884 .705 r
.60475 .35404 m .60467 .35564 L .60284 .35406 L F
.741 .684 .796 r
.60284 .35406 m .60133 .36079 L .6066 .35611 L F
.659 .954 .73 r
.6063 .35653 m .60133 .36079 L .60524 .35806 L F
.60259 .35967 m .60133 .36079 L .6063 .35653 L F
.639 .595 .788 r
.60535 .36394 m .60195 .36128 L .60386 .36216 L F
.60195 .36128 m .60106 .36059 L .60386 .36216 L F
.699 .774 .91 r
.60797 .3627 m .60535 .36394 L .60386 .36216 L F
.60797 .3627 m .60535 .36394 L .60386 .36216 L F
.476 .293 .553 r
.60386 .36216 m .60422 .36498 L .60554 .36293 L F
.699 .774 .91 r
.60797 .3627 m .60386 .36216 L .60662 .36124 L F
.60797 .3627 m .60386 .36216 L .60662 .36124 L F
.476 .293 .553 r
.60386 .36216 m .60554 .36293 L .60662 .36124 L F
.595 .372 .548 r
.60027 .36217 m .60386 .36216 L .60132 .36074 L F
.60025 .36219 m .60025 .36219 L .60027 .36217 L F
.60025 .36219 m .60386 .36216 L .60027 .36217 L F
.60073 .36123 m .60132 .36074 L .60106 .36059 L F
.60025 .36219 m .60132 .36074 L .60073 .36123 L F
.659 .954 .73 r
.6066 .35611 m .60259 .35967 L .6063 .35653 L F
.639 .077 0 r
.4131 .59697 m .40838 .59448 L .41002 .59592 L F
.816 .42 .303 r
.57673 .43877 m .5809 .43803 L .57636 .43605 L F
.57673 .43877 m .58004 .43845 L .5809 .43803 L F
.887 .652 .577 r
.58157 .43995 m .5809 .43803 L .58004 .43845 L F
.393 .696 .981 r
.39436 .48796 m .39405 .48993 L .3923 .48824 L F
.39436 .48796 m .39405 .48993 L .3923 .48824 L F
.195 .258 .701 r
.24813 .56754 m .2488 .57095 L .24665 .56904 L F
.017 0 .344 r
.50981 .43715 m .51119 .43333 L .51143 .4365 L F
.428 .278 .574 r
.51209 .43942 m .50981 .43715 L .51143 .4365 L F
.51209 .43942 m .50999 .4407 L .50981 .43715 L F
.599 .84 .99 r
.31552 .51505 m .31728 .51631 L .32004 .51536 L F
.32004 .51536 m .31728 .51631 L .31552 .51505 L F
.033 0 0 r
.60558 .38499 m .60676 .38458 L .60415 .38478 L F
.60558 .38499 m .60415 .38478 L .60337 .38307 L F
.457 .431 .741 r
.5898 .36916 m .59374 .37114 L .5926 .3669 L F
.87 .435 .159 r
.57042 .38092 m .57151 .38376 L .57332 .38423 L F
.693 .349 0 r
.57059 .38165 m .57042 .38092 L .57064 .37915 L F
.47 .717 .977 r
.32535 .52806 m .3267 .52991 L .3276 .52762 L F
.46 .744 .99 r
.28878 .55409 m .29097 .5559 L .28814 .55605 L F
.28814 .55605 m .29097 .5559 L .28878 .55409 L F
.946 .753 .61 r
.57596 .42928 m .57896 .42737 L .57763 .42605 L F
.57596 .42928 m .57863 .42999 L .57896 .42737 L F
0 0 .292 r
.29415 .57975 m .29555 .57935 L .29763 .57883 L F
.494 .071 .165 r
.39637 .51123 m .40067 .50898 L .39828 .50997 L F
.653 .954 .74 r
.37126 .47464 m .3733 .47346 L .37502 .47182 L F
0 0 0 r
.47411 .53253 m .47673 .53133 L .47784 .52944 L F
.521 .823 .495 r
.47784 .52944 m .47926 .52792 L .48077 .52635 L F
0 0 0 r
.47784 .52944 m .47673 .53133 L .47926 .52792 L F
.891 .989 .754 r
.54679 .46988 m .54861 .46564 L .54924 .4689 L F
.54679 .46988 m .54618 .46916 L .54861 .46564 L F
.189 .056 .458 r
.24063 .54274 m .24204 .54268 L .24208 .53904 L F
.199 .19 .623 r
.24063 .54274 m .24267 .54488 L .24204 .54268 L F
.273 .202 .592 r
.24104 .54548 m .24267 .54488 L .24063 .54274 L F
.783 .804 .87 r
.5756 .44361 m .57944 .44395 L .5776 .44247 L F
.865 .793 .778 r
.5776 .44247 m .57944 .44395 L .58157 .43995 L F
.858 .505 .384 r
.36299 .50881 m .35919 .50522 L .36275 .50658 L F
.85 .401 .141 r
.40109 .58954 m .40019 .59069 L .3986 .58786 L F
.806 .969 .907 r
.51134 .49339 m .50693 .4952 L .51032 .49264 L F
.51134 .49339 m .50797 .49584 L .50693 .4952 L F
.947 .951 .737 r
.51134 .49339 m .51233 .4887 L .51396 .49006 L F
.51134 .49339 m .51032 .49264 L .51233 .4887 L F
.965 .75 .563 r
.72258 .30486 m .72146 .30764 L .72352 .30874 L F
.96 .725 .54 r
.72123 .31036 m .72352 .30874 L .72146 .30764 L F
.72123 .31036 m .72336 .31141 L .72352 .30874 L F
.95 .932 .744 r
.5692 .45797 m .57021 .45279 L .56797 .45632 L F
.853 .648 .625 r
.45426 .58817 m .45299 .59147 L .45155 .58818 L F
.822 .72 .752 r
.54832 .44377 m .548 .44575 L .54518 .44695 L F
.653 .492 .653 r
.54894 .44696 m .54518 .44695 L .548 .44575 L F
.191 .131 .555 r
.54832 .44377 m .54894 .44696 L .548 .44575 L F
.259 0 0 r
.60801 .3976 m .60723 .39724 L .60606 .39614 L F
.60801 .3976 m .60959 .39806 L .60723 .39724 L F
.67 .248 .234 r
.3496 .5603 m .34582 .56118 L .3478 .56057 L F
0 .158 .695 r
.4131 .59697 m .41422 .599 L .41436 .59801 L F
.297 .731 .968 r
.41436 .59801 m .41422 .599 L .41557 .59865 L F
.939 .708 .562 r
.38956 .54766 m .38794 .54501 L .3898 .54645 L F
.747 .655 .76 r
.32968 .65656 m .33102 .65822 L .32721 .65774 L F
.513 .526 .806 r
.33243 .65423 m .33102 .65822 L .32968 .65656 L F
.33243 .65423 m .3335 .65769 L .33102 .65822 L F
.045 0 0 r
.65949 .32461 m .65866 .32651 L .66205 .32403 L F
.704 .925 .596 r
.59947 .37458 m .59954 .37538 L .60036 .37364 L F
.59947 .37458 m .59793 .37722 L .59954 .37538 L F
.865 .793 .778 r
.5776 .44247 m .58157 .43995 L .58004 .43845 L F
.704 .978 .909 r
.35843 .49328 m .35417 .49347 L .35433 .49154 L F
.35843 .49328 m .35319 .49603 L .35417 .49347 L F
.788 .763 .83 r
.72044 .32162 m .7215 .31691 L .71961 .32052 L F
.72044 .32162 m .72351 .31865 L .7215 .31691 L F
.858 .626 .586 r
.69371 .35062 m .69436 .34808 L .69141 .34744 L F
.884 .934 .847 r
.49394 .53124 m .49262 .53552 L .49536 .53206 L F
.49394 .53124 m .49117 .53455 L .49262 .53552 L F
.76 .813 .895 r
.66086 .37619 m .65819 .37461 L .65915 .37387 L F
.677 .665 .831 r
.66203 .37234 m .66086 .37619 L .65915 .37387 L F
.66203 .37234 m .66354 .3748 L .66086 .37619 L F
.51 .366 .621 r
.64439 .36484 m .6471 .36461 L .6472 .36146 L F
.024 0 0 r
.64136 .33535 m .64291 .3358 L .64417 .33469 L F
.64136 .33535 m .64026 .33679 L .64291 .3358 L F
.924 .78 .682 r
.37287 .59108 m .37496 .59207 L .37353 .58825 L F
.885 .715 .665 r
.37287 .59108 m .37463 .59491 L .37496 .59207 L F
.876 .702 .664 r
.37463 .59491 m .37273 .5984 L .3764 .59866 L F
.906 .837 .767 r
.37232 .60106 m .3764 .59866 L .37273 .5984 L F
.37232 .60106 m .3742 .60229 L .3764 .59866 L F
.256 .761 .728 r
.45009 .59684 m .45465 .59554 L .45249 .59573 L F
.733 .979 .751 r
.45553 .59367 m .45465 .59554 L .45607 .59371 L F
.709 .985 .878 r
.45249 .59573 m .45465 .59554 L .45553 .59367 L F
.749 .906 .946 r
.65861 .38406 m .66203 .38387 L .66076 .38252 L F
.436 .752 .994 r
.66076 .38252 m .66203 .38387 L .6649 .38351 L F
.981 .893 .548 r
.59265 .40561 m .5924 .41065 L .59343 .4077 L F
.741 .218 0 r
.33518 .58348 m .33446 .58447 L .33487 .5828 L F
.43 .821 .986 r
.33388 .58526 m .33446 .58447 L .3358 .5853 L F
.013 0 0 r
.33407 .58713 m .3358 .5853 L .33446 .58447 L F
.33407 .58713 m .33886 .58546 L .3358 .5853 L F
.33868 .58552 m .33662 .5866 L .33886 .58546 L F
.33407 .58713 m .33662 .5866 L .33868 .58552 L F
.09 .158 .64 r
.33407 .58713 m .33639 .58936 L .33662 .5866 L F
.95 .665 .463 r
.33662 .5866 m .33639 .58936 L .33527 .58731 L F
.741 .218 0 r
.33662 .5866 m .33407 .58713 L .33446 .58447 L F
.43 .821 .986 r
.33192 .58522 m .33446 .58447 L .33388 .58526 L F
.616 .911 .981 r
.33192 .58522 m .33226 .58328 L .33446 .58447 L F
.741 .218 0 r
.33662 .5866 m .33226 .58328 L .33407 .58713 L F
.95 .665 .463 r
.33662 .5866 m .33527 .58731 L .33449 .58587 L F
.741 .218 0 r
.33662 .5866 m .33446 .58447 L .33518 .58348 L F
.714 .798 .917 r
.31869 .65591 m .32069 .65749 L .31629 .65721 L F
.396 .689 .978 r
.32297 .65728 m .32069 .65749 L .31869 .65591 L F
.618 .48 .671 r
.26876 .5324 m .26626 .53583 L .26628 .53078 L F
.602 .753 .95 r
.30107 .65167 m .29899 .6537 L .29679 .65115 L F
.924 .593 .395 r
.68018 .314 m .68223 .31726 L .68346 .31464 L F
.978 .695 .416 r
.50969 .47018 m .5099 .47323 L .50805 .47162 L F
.825 .351 .059 r
.33189 .54225 m .32826 .53843 L .33235 .53935 L F
.717 .503 .598 r
.37749 .46277 m .37738 .46671 L .37455 .46656 L F
0 0 0 r
.37691 .46308 m .37953 .46154 L .37749 .46277 L F
.813 .929 .553 r
.48285 .52261 m .48077 .52635 L .48132 .52423 L F
.813 .93 .555 r
.48077 .52635 m .47926 .52792 L .48132 .52423 L F
.791 .611 .658 r
.34776 .57559 m .34315 .57804 L .34623 .57589 L F
.933 .776 .664 r
.34888 .57474 m .35165 .57575 L .34776 .57559 L F
.284 0 .033 r
.42282 .46153 m .42415 .45906 L .42665 .45873 L F
.526 .877 .637 r
.42498 .45985 m .42665 .45873 L .4276 .45775 L F
.42757 .45774 m .4276 .45775 L .4278 .45755 L F
.042 0 0 r
.42785 .45783 m .42663 .458 L .42796 .45787 L F
.42931 .45764 m .42665 .45873 L .42663 .458 L F
.526 .877 .637 r
.42498 .45985 m .4276 .45775 L .42757 .45774 L F
.042 0 0 r
.42931 .45764 m .42785 .45783 L .43146 .45753 L F
.42785 .45783 m .42796 .45787 L .43146 .45753 L F
.81 .896 .904 r
.28499 .65348 m .2818 .65344 L .28324 .6524 L F
.823 .909 .898 r
.28802 .65084 m .28499 .65348 L .28324 .6524 L F
.409 .808 .585 r
.55637 .39017 m .55969 .38786 L .55719 .38763 L F
0 0 .121 r
.51038 .42723 m .50793 .43113 L .50996 .42942 L F
.568 .789 .982 r
.50996 .42942 m .50793 .43113 L .50613 .42927 L F
.824 .995 .755 r
.48285 .52261 m .48487 .5191 L .4855 .51878 L F
.48285 .52261 m .48248 .52193 L .48487 .5191 L F
.9 .931 .554 r
.48285 .52261 m .48132 .52423 L .48248 .52193 L F
.265 .237 .64 r
.23923 .5527 m .24138 .5547 L .24079 .55234 L F
.253 .236 .645 r
.23992 .5556 m .24138 .5547 L .23923 .5527 L F
.417 .533 .867 r
.3338 .52122 m .33259 .52273 L .33131 .51878 L F
.3338 .52122 m .33436 .52169 L .33259 .52273 L F
.701 .223 .11 r
.39353 .49802 m .39524 .49655 L .39427 .49537 L F
.386 0 0 r
.38903 .45895 m .39157 .45893 L .39331 .45722 L F
.395 0 0 r
.39331 .45722 m .39157 .45893 L .3956 .45799 L F
.626 .835 .98 r
.33976 .59158 m .33745 .59268 L .33484 .59085 L F
.337 .006 .247 r
.33248 .67018 m .33304 .6682 L .33577 .66735 L F
0 0 0 r
.53665 .47795 m .53807 .47676 L .53546 .47812 L F
.53665 .47795 m .53546 .47812 L .53449 .47559 L F
.228 0 0 r
.35621 .49125 m .356 .48944 L .35433 .49154 L F
.944 .691 .524 r
.68253 .31964 m .68537 .31866 L .68223 .31726 L F
.68253 .31964 m .68522 .32133 L .68537 .31866 L F
.61 .842 .987 r
.59623 .4012 m .59752 .40256 L .60026 .40152 L F
.846 .882 .866 r
.59567 .35059 m .59734 .35227 L .59883 .35026 L F
.7 .664 .812 r
.6028 .44043 m .60303 .4449 L .59959 .44359 L F
.881 .521 .035 r
.60303 .4449 m .60224 .44398 L .59959 .44359 L F
.60303 .4449 m .60369 .44683 L .60224 .44398 L F
.591 .078 0 r
.57407 .3854 m .57332 .38423 L .57151 .38376 L F
.57407 .3854 m .5756 .38672 L .57332 .38423 L F
.43 0 0 r
.57485 .38647 m .57547 .38683 L .5756 .38672 L F
.577 .069 0 r
.57568 .38665 m .5756 .38672 L .57694 .38794 L F
0 .259 .687 r
.57907 .38892 m .57694 .38794 L .5756 .38672 L F
.43 0 0 r
.57547 .38683 m .57907 .38892 L .5756 .38672 L F
.577 .069 0 r
.57332 .38423 m .5756 .38672 L .57568 .38665 L F
.612 .69 .898 r
.30538 .6543 m .303 .65526 L .30107 .65167 L F
.08 0 0 r
.50229 .44489 m .50505 .44483 L .50284 .44499 L F
0 0 0 r
.49958 .44552 m .50149 .44475 L .50229 .44489 L F
.267 .774 .82 r
.49958 .44552 m .50229 .44489 L .49929 .44524 L F
.08 0 0 r
.50229 .44489 m .50284 .44499 L .49929 .44524 L F
0 0 0 r
.50149 .44475 m .50379 .44383 L .50229 .44489 L F
.50229 .44489 m .50379 .44383 L .50626 .4429 L F
0 .331 .713 r
.57427 .35806 m .57687 .35919 L .57825 .36001 L F
.331 0 0 r
.57687 .35919 m .58088 .35794 L .57825 .36001 L F
.809 .663 .701 r
.31754 .53866 m .32213 .53667 L .31983 .53495 L F
.31754 .53866 m .32199 .54107 L .32213 .53667 L F
.512 .759 .986 r
.32264 .53457 m .32213 .53667 L .31983 .53495 L F
.32264 .53457 m .32213 .53667 L .31983 .53495 L F
.939 .961 .742 r
.45005 .5591 m .44763 .56308 L .44752 .56037 L F
.892 .982 .703 r
.45005 .5591 m .45023 .55687 L .45284 .55593 L F
.45005 .5591 m .44948 .55849 L .45023 .55687 L F
.841 .998 .782 r
.45005 .5591 m .44752 .56037 L .44948 .55849 L F
.644 .605 .796 r
.70545 .3158 m .70981 .31907 L .70891 .31682 L F
.415 .586 .912 r
.70891 .31682 m .70981 .31907 L .71145 .3168 L F
.529 .746 .975 r
.70981 .31907 m .71261 .31855 L .71145 .3168 L F
.693 .979 .894 r
.47436 .43954 m .47519 .44008 L .47837 .43772 L F
.743 .704 .814 r
.31754 .53866 m .31912 .54206 L .32199 .54107 L F
.84 .705 .715 r
.56148 .41748 m .56006 .42041 L .55862 .41651 L F
.824 .83 .853 r
.55852 .45254 m .55721 .4562 L .55621 .45556 L F
.55852 .45254 m .56037 .45343 L .55721 .4562 L F
.531 .322 .542 r
.26436 .60555 m .26706 .60536 L .26781 .60161 L F
.269 .75 .929 r
.26706 .60536 m .26436 .60555 L .26781 .60161 L F
.481 .295 .55 r
.26706 .60536 m .26947 .60158 L .26781 .60161 L F
.23 .184 .597 r
.32256 .5264 m .32481 .52508 L .32433 .52147 L F
.319 .369 .757 r
.32256 .5264 m .32535 .52806 L .32481 .52508 L F
.894 .651 .563 r
.39282 .55268 m .38934 .55424 L .38956 .54766 L F
.945 .699 .535 r
.38956 .54766 m .38934 .55424 L .38722 .55272 L F
.934 .802 .691 r
.38929 .55419 m .38934 .55424 L .39282 .55268 L F
.38929 .55419 m .39282 .55268 L .39264 .55504 L F
.794 .971 .672 r
.50026 .43643 m .49805 .44002 L .5009 .4388 L F
0 0 0 r
.5009 .4388 m .49805 .44002 L .49764 .4419 L F
.854 .539 .455 r
.53259 .38767 m .53442 .38934 L .53526 .38702 L F
.53259 .38767 m .5326 .39029 L .53442 .38934 L F
.946 .91 .752 r
.5326 .39029 m .53173 .39295 L .53442 .38934 L F
0 0 0 r
.46336 .43098 m .4598 .43313 L .46135 .43181 L F
.629 .95 .759 r
.4652 .42934 m .46336 .43098 L .46135 .43181 L F
.793 .952 .922 r
.54515 .47985 m .54644 .48071 L .54817 .47909 L F
.808 .762 .81 r
.4867 .54241 m .48732 .54537 L .48746 .54262 L F
.651 .97 .85 r
.4887 .54085 m .4867 .54241 L .48746 .54262 L F
0 0 .049 r
.3381 .56541 m .33549 .56894 L .33751 .56761 L F
.633 .485 .663 r
.33751 .56761 m .33962 .56402 L .3381 .56541 L F
.643 .363 .479 r
.34566 .53796 m .34159 .53634 L .3403 .53491 L F
.34566 .53796 m .34213 .5385 L .34159 .53634 L F
0 0 .274 r
.57669 .39794 m .57603 .3977 L .57683 .39545 L F
.57669 .39794 m .57654 .40057 L .57603 .3977 L F
0 .024 .597 r
.30785 .63432 m .30367 .6314 L .30533 .63489 L F
.619 .956 .819 r
.455 .43526 m .45774 .43459 L .45379 .43691 L F
.543 .924 .809 r
.4598 .43313 m .45774 .43459 L .455 .43526 L F
.782 .576 .622 r
.32618 .54405 m .32632 .54631 L .32308 .5451 L F
.537 .925 .839 r
.3317 .54234 m .33205 .54267 L .33189 .54225 L F
.6 .483 .691 r
.32806 .53897 m .3317 .54234 L .32618 .54405 L F
.3317 .54234 m .33205 .54267 L .33132 .54284 L F
.3317 .54234 m .33132 .54284 L .32618 .54405 L F
.32826 .53843 m .33205 .54267 L .32806 .53897 L F
.825 .351 .059 r
.33189 .54225 m .33205 .54267 L .33173 .5423 L F
.33189 .54225 m .33173 .5423 L .32826 .53843 L F
.81 .988 .729 r
.33171 .54231 m .33014 .54305 L .3317 .54234 L F
.33271 .54002 m .33043 .54271 L .33171 .54231 L F
.33043 .54271 m .33014 .54305 L .33171 .54231 L F
.33201 .54194 m .3317 .54234 L .33189 .54225 L F
.33271 .54002 m .3317 .54234 L .33201 .54194 L F
.537 .925 .839 r
.33014 .54305 m .33205 .54267 L .3317 .54234 L F
.036 .012 .496 r
.32794 .54436 m .32618 .54405 L .33205 .54267 L F
.79 .697 .762 r
.32869 .53991 m .32994 .54261 L .33271 .54002 L F
.32994 .54261 m .33014 .54305 L .33159 .54133 L F
.32994 .54261 m .33159 .54133 L .33271 .54002 L F
.254 .402 .819 r
.33091 .54155 m .33014 .54305 L .32869 .53991 L F
.705 .546 .671 r
.33091 .54155 m .32978 .54244 L .3287 .54356 L F
.32916 .54321 m .3287 .54356 L .32794 .54436 L F
.33091 .54155 m .3287 .54356 L .32916 .54321 L F
.036 .012 .496 r
.32794 .54436 m .32631 .54607 L .32618 .54405 L F
.705 .546 .671 r
.32978 .54244 m .326 .54537 L .32794 .54436 L F
.036 .012 .496 r
.32794 .54436 m .32632 .54631 L .32631 .54607 L F
.804 .994 .868 r
.62813 .38811 m .62553 .39074 L .62472 .38993 L F
.89 .606 .5 r
.3465 .51797 m .34913 .51594 L .34652 .51564 L F
.3465 .51797 m .35005 .51996 L .34913 .51594 L F
.837 .902 .884 r
.51546 .48605 m .51396 .49006 L .51233 .4887 L F
.51546 .48605 m .51725 .48719 L .51396 .49006 L F
.785 .503 .51 r
.68738 .32448 m .6902 .32762 L .69115 .32508 L F
.786 .815 .876 r
.43512 .57178 m .43309 .5733 L .43123 .57158 L F
.054 .154 .651 r
.3403 .53491 m .33821 .53324 L .34019 .532 L F
.888 .571 .442 r
.40114 .51108 m .40361 .50988 L .40067 .50898 L F
.40114 .51108 m .40316 .51232 L .40361 .50988 L F
.939 .826 .706 r
.39593 .57163 m .39395 .57108 L .39545 .56794 L F
.948 .685 .504 r
.39611 .57412 m .39395 .57108 L .39593 .57163 L F
.594 .77 .964 r
.31213 .6551 m .30977 .65637 L .30774 .65413 L F
.878 .799 .769 r
.55949 .44966 m .56037 .45343 L .55852 .45254 L F
0 0 .136 r
.30881 .61064 m .30787 .61509 L .30894 .61415 L F
.629 .173 .151 r
.53583 .42024 m .53993 .42027 L .53849 .42217 L F
.044 0 .194 r
.54242 .41707 m .53993 .42027 L .53845 .41905 L F
.345 0 0 r
.53993 .42027 m .54159 .42177 L .53849 .42217 L F
.53993 .42027 m .54277 .42021 L .54159 .42177 L F
.044 0 .194 r
.53993 .42027 m .54242 .41707 L .54277 .42021 L F
.446 .216 .471 r
.36649 .47935 m .36406 .48018 L .36681 .47676 L F
.36681 .47676 m .36406 .48018 L .36649 .47935 L F
.684 .715 .195 r
.36777 .47332 m .36681 .47676 L .3674 .47463 L F
.963 .732 .543 r
.36704 .47593 m .36948 .47589 L .36681 .47676 L F
.36777 .47332 m .36903 .47521 L .36704 .47593 L F
.36903 .47521 m .36948 .47589 L .36704 .47593 L F
.705 .882 .963 r
.3674 .47463 m .36991 .47464 L .36941 .47368 L F
.3674 .47463 m .36948 .47589 L .37126 .47464 L F
.201 0 .258 r
.36827 .47232 m .3674 .47463 L .36941 .47368 L F
.439 0 .046 r
.36941 .47368 m .3689 .47503 L .36894 .47279 L F
.692 .954 .692 r
.36957 .47072 m .36827 .47232 L .36951 .47028 L F
0 0 .45 r
.36827 .47232 m .36941 .47368 L .36951 .47028 L F
.439 0 .046 r
.36941 .47368 m .36894 .47279 L .36895 .47231 L F
.705 .882 .963 r
.36991 .47464 m .3706 .47464 L .36941 .47368 L F
.3706 .47464 m .37126 .47464 L .37099 .4745 L F
.3706 .47464 m .37099 .4745 L .36941 .47368 L F
.765 .67 .758 r
.36948 .47589 m .36649 .47935 L .36681 .47676 L F
0 0 .091 r
.36681 .47676 m .36748 .47717 L .3674 .47463 L F
.36681 .47676 m .36649 .47935 L .36748 .47717 L F
0 0 0 r
.32195 .61031 m .31969 .61142 L .31995 .61135 L F
.765 .795 .877 r
.55059 .46709 m .54924 .4689 L .54861 .46564 L F
.717 .931 .961 r
.46163 .44476 m .46607 .44388 L .46455 .44272 L F
.731 .901 .955 r
.46455 .44272 m .46607 .44388 L .46765 .44177 L F
.643 .946 .718 r
.5411 .41078 m .54229 .40912 L .54456 .4078 L F
.723 .227 0 r
.54177 .41203 m .54407 .41446 L .5411 .41078 L F
.958 .754 .586 r
.39741 .56267 m .39478 .56426 L .39485 .56135 L F
.39741 .56267 m .3967 .56555 L .39478 .56426 L F
.426 .232 .512 r
.33312 .57312 m .3353 .57207 L .33549 .56894 L F
.475 .763 .994 r
.32254 .50966 m .32507 .50931 L .32343 .50779 L F
.507 .417 .689 r
.3353 .57207 m .33751 .56761 L .33549 .56894 L F
.673 .889 .529 r
.23826 .59811 m .23906 .59657 L .24137 .59399 L F
.628 .442 .612 r
.24137 .59399 m .24436 .59419 L .24393 .5919 L F
0 0 0 r
.24137 .59399 m .23906 .59657 L .2423 .59431 L F
.727 .974 .734 r
.2423 .59431 m .24032 .59538 L .24109 .59449 L F
.04 .184 .687 r
.24436 .59419 m .24137 .59399 L .24393 .5919 L F
.727 .974 .734 r
.2423 .59431 m .24109 .59449 L .24226 .59315 L F
0 0 0 r
.2435 .59413 m .2423 .59431 L .24436 .59419 L F
.24137 .59399 m .2423 .59431 L .2435 .59413 L F
.901 .986 .745 r
.51502 .50448 m .51486 .50696 L .51721 .50345 L F
.82 .996 .853 r
.5177 .50116 m .51721 .50345 L .51837 .5016 L F
.846 .996 .762 r
.5177 .50116 m .51502 .50448 L .51721 .50345 L F
.512 .624 .899 r
.33955 .57324 m .34047 .57031 L .33772 .57133 L F
.33955 .57324 m .34222 .57278 L .34047 .57031 L F
.686 .618 .774 r
.51856 .43254 m .52172 .43076 L .51736 .43018 L F
.889 .542 .383 r
.34324 .51415 m .34635 .51357 L .34257 .51202 L F
.34324 .51415 m .34652 .51564 L .34635 .51357 L F
.423 .191 .454 r
.24393 .5919 m .24679 .59119 L .24745 .58863 L F
.748 .967 .689 r
.24436 .59419 m .24679 .59119 L .24393 .5919 L F
.423 .191 .454 r
.24745 .58863 m .24679 .59119 L .24393 .5919 L F
.35 .175 .498 r
.24436 .59419 m .24679 .59119 L .24393 .5919 L F
.843 .686 .687 r
.37224 .58163 m .37178 .58443 L .37594 .58481 L F
.844 .664 .658 r
.37178 .58443 m .37353 .58825 L .37594 .58481 L F
.615 .456 .643 r
.62679 .36177 m .62686 .36444 L .62951 .36109 L F
.62951 .36109 m .62686 .36444 L .62679 .36177 L F
.927 .916 .785 r
.65939 .35986 m .66331 .35759 L .6584 .35889 L F
.65939 .35986 m .66089 .3615 L .66331 .35759 L F
.358 .129 .424 r
.66331 .35759 m .66585 .3573 L .66624 .35525 L F
.66331 .35759 m .66585 .3573 L .66624 .35525 L F
.858 .786 .779 r
.35004 .6352 m .35163 .63458 L .35067 .63052 L F
.741 .719 .831 r
.35163 .63458 m .35497 .63074 L .35067 .63052 L F
.962 .638 .348 r
.5469 .44514 m .54894 .44696 L .54832 .44377 L F
.871 .595 .516 r
.68522 .32133 m .68738 .32448 L .68752 .32208 L F
0 0 .319 r
.57366 .36773 m .57368 .36626 L .57274 .36369 L F
0 .006 .582 r
.57366 .36773 m .57535 .36981 L .57368 .36626 L F
.115 .443 .879 r
.61787 .40105 m .61893 .40002 L .61667 .40057 L F
.61787 .40105 m .62222 .40302 L .61893 .40002 L F
.523 .785 .992 r
.24975 .53064 m .25107 .53207 L .24865 .53265 L F
.744 .965 .683 r
.30413 .58582 m .30203 .5887 L .30452 .58812 L F
.659 .199 .15 r
.39475 .46355 m .39304 .46537 L .39063 .46324 L F
.43 0 0 r
.39656 .46481 m .39304 .46537 L .39475 .46355 L F
.763 .906 .939 r
.65768 .36323 m .65939 .35986 L .65613 .3625 L F
.65768 .36323 m .66089 .3615 L .65939 .35986 L F
.469 .879 .741 r
.35919 .49522 m .363 .49307 L .36009 .49317 L F
0 0 0 r
.32826 .53843 m .3302 .53505 L .32912 .53654 L F
.893 .8 .75 r
.35583 .538 m .35877 .53926 L .35956 .53639 L F
.916 .63 .488 r
.35555 .5408 m .35877 .53926 L .35583 .538 L F
.35555 .5408 m .35868 .54202 L .35877 .53926 L F
.859 .576 .508 r
.35877 .53926 m .35868 .54202 L .36089 .54228 L F
.739 .822 .916 r
.59048 .35406 m .58618 .35372 L .58941 .3519 L F
.704 .552 .678 r
.59182 .35626 m .58618 .35372 L .59048 .35406 L F
0 0 .554 r
.59182 .35626 m .59048 .35406 L .59353 .35372 L F
.579 .797 .982 r
.50719 .42071 m .50737 .42257 L .50637 .42288 L F
.885 .989 .8 r
.51502 .50448 m .51246 .50781 L .51486 .50696 L F
0 0 0 r
.29765 .57996 m .29763 .57883 L .29555 .57935 L F
.803 .966 .91 r
.46646 .58844 m .46514 .58771 L .46204 .59029 L F
.522 .543 .818 r
.4675 .58702 m .46514 .58771 L .46646 .58844 L F
.276 .774 .881 r
.3342 .52967 m .33208 .52959 L .32941 .53002 L F
.376 0 0 r
.33169 .53063 m .32746 .53057 L .32941 .53002 L F
.934 .745 .624 r
.33378 .53044 m .33291 .532 L .33241 .53056 L F
.33378 .53044 m .33241 .53056 L .33208 .52959 L F
.127 .274 .746 r
.33208 .52959 m .33291 .532 L .33419 .53024 L F
.376 0 0 r
.33295 .53097 m .33022 .53077 L .33169 .53063 L F
.33022 .53077 m .32746 .53057 L .33169 .53063 L F
.934 .745 .624 r
.3342 .52967 m .33378 .53044 L .33208 .52959 L F
.609 .806 .975 r
.58747 .43899 m .58881 .44063 L .59125 .43953 L F
.709 .227 .103 r
.36697 .50966 m .36528 .51106 L .36299 .50881 L F
.955 .632 .372 r
.36722 .51217 m .36528 .51106 L .36697 .50966 L F
.817 .642 .665 r
.38298 .49276 m .38742 .49484 L .3868 .49054 L F
.442 .186 .429 r
.3868 .49054 m .38967 .48874 L .38793 .48813 L F
.737 .948 .949 r
.38793 .48813 m .3868 .49054 L .38967 .48874 L F
.38967 .48874 m .3868 .49054 L .38793 .48813 L F
.774 .918 .54 r
.58731 .43387 m .58597 .43522 L .58595 .43249 L F
.683 .955 .95 r
.5883 .43174 m .58731 .43387 L .58595 .43249 L F
.077 0 0 r
.25681 .55636 m .25518 .55753 L .25305 .55793 L F
0 0 0 r
.25681 .55636 m .25586 .55858 L .25795 .55675 L F
.25681 .55636 m .25795 .55675 L .25518 .55753 L F
0 0 .218 r
.46813 .53962 m .46859 .54134 L .46929 .53864 L F
.92 .559 .121 r
.32652 .60826 m .32707 .61105 L .32935 .6087 L F
0 0 0 r
.67363 .3125 m .67656 .31224 L .67741 .3119 L F
.6 .029 0 r
.67656 .31224 m .68018 .314 L .67741 .3119 L F
.174 .386 .831 r
.29048 .66398 m .28912 .66071 L .28661 .66132 L F
.29048 .66398 m .29094 .66451 L .28912 .66071 L F
.868 .517 .385 r
.29023 .66668 m .29048 .66398 L .28647 .66668 L F
.29023 .66668 m .29094 .66451 L .29048 .66398 L F
.795 .7 .761 r
.63472 .3454 m .63287 .34878 L .63192 .34541 L F
0 0 .512 r
.63177 .34487 m .63199 .34563 L .63265 .34612 L F
.63199 .34563 m .63287 .34878 L .63265 .34612 L F
.271 .049 .383 r
.63287 .34878 m .63527 .34717 L .63265 .34612 L F
0 .467 .765 r
.63527 .34717 m .63329 .3466 L .63265 .34612 L F
.452 0 0 r
.63265 .34612 m .62809 .34605 L .62886 .34541 L F
.273 .762 .913 r
.63265 .34612 m .63052 .34579 L .62809 .34605 L F
0 .467 .765 r
.63329 .3466 m .63052 .34579 L .63265 .34612 L F
.452 0 0 r
.63057 .34541 m .62886 .34541 L .62935 .34499 L F
.63265 .34612 m .62886 .34541 L .63057 .34541 L F
.795 .7 .761 r
.63541 .34414 m .63472 .3454 L .63177 .34487 L F
.63472 .3454 m .63192 .34541 L .63177 .34487 L F
.271 .049 .383 r
.63287 .34878 m .63576 .34846 L .63527 .34717 L F
.63287 .34878 m .63345 .35037 L .63576 .34846 L F
.703 .985 .848 r
.50198 .40437 m .50316 .40234 L .50389 .40261 L F
.708 .981 .792 r
.50198 .40437 m .50007 .40495 L .50316 .40234 L F
.737 .563 .657 r
.46112 .58144 m .46552 .58458 L .46253 .58524 L F
.46112 .58144 m .46253 .58524 L .46358 .58368 L F
.505 .848 .996 r
.461 .58439 m .46358 .58368 L .46253 .58524 L F
.358 .213 .543 r
.62241 .40462 m .62055 .40755 L .61915 .40734 L F
.376 0 0 r
.53744 .46105 m .53817 .46059 L .5363 .46119 L F
.53744 .46105 m .53817 .46059 L .5363 .46119 L F
.138 .393 .844 r
.57606 .35692 m .57427 .35806 L .57283 .35656 L F
.57606 .35692 m .57687 .35919 L .57427 .35806 L F
.18 .699 .883 r
.44349 .45125 m .44381 .45052 L .44139 .45141 L F
.44349 .45125 m .44484 .45105 L .44381 .45052 L F
.842 .617 .072 r
.51081 .43251 m .51143 .4365 L .51119 .43333 L F
.336 .175 .51 r
.33775 .66654 m .33582 .66434 L .33789 .66377 L F
.33775 .66654 m .33577 .66735 L .33582 .66434 L F
.543 .639 .895 r
.3228 .63823 m .32739 .64118 L .32536 .6374 L F
.694 .688 .84 r
.32739 .64118 m .32793 .63626 L .32536 .6374 L F
.32739 .64118 m .3302 .6411 L .32793 .63626 L F
.839 .789 .804 r
.53581 .46598 m .53386 .4671 L .53558 .46344 L F
.724 .481 .559 r
.53581 .46598 m .53241 .4692 L .53386 .4671 L F
.53581 .46598 m .53508 .46924 L .53241 .4692 L F
.672 .669 .839 r
.53885 .46455 m .53581 .46598 L .53558 .46344 L F
.64 .879 .528 r
.53885 .46455 m .53508 .46924 L .53581 .46598 L F
.238 0 .102 r
.28225 .59927 m .2799 .59971 L .28011 .60062 L F
.785 .588 .635 r
.52672 .38791 m .5261 .3906 L .5298 .39102 L F
.412 .182 .453 r
.5298 .39102 m .5326 .39029 L .53259 .38767 L F
.681 .393 .478 r
.5298 .39102 m .53173 .39295 L .5326 .39029 L F
.5298 .39102 m .53004 .3937 L .53173 .39295 L F
.53173 .39295 m .53004 .3937 L .5298 .39102 L F
.491 .451 .74 r
.26095 .54785 m .25879 .5499 L .25806 .54579 L F
.594 .538 .762 r
.26095 .54785 m .25965 .55236 L .25879 .5499 L F
.496 .159 .325 r
.42457 .60396 m .42498 .60179 L .42742 .60363 L F
.578 .095 .073 r
.42498 .60179 m .42735 .60241 L .42742 .60363 L F
.595 .022 0 r
.58877 .40738 m .58948 .40897 L .58773 .40585 L F
0 .167 .668 r
.5924 .41065 m .59166 .40961 L .58877 .40738 L F
.595 .022 0 r
.58877 .40738 m .59166 .40961 L .58948 .40897 L F
.638 .66 .855 r
.32793 .63626 m .3302 .6411 L .33222 .6374 L F
.708 .813 .93 r
.3302 .6411 m .33301 .64013 L .33222 .6374 L F
.756 .679 .777 r
.61053 .3541 m .61192 .3581 L .61379 .35524 L F
.796 .743 .804 r
.28912 .66071 m .29094 .66451 L .29347 .66094 L F
.685 .579 .73 r
.29094 .66451 m .29454 .66437 L .29347 .66094 L F
.693 .374 .43 r
.29023 .66668 m .29454 .66437 L .29094 .66451 L F
.59 .574 .804 r
.61763 .38697 m .61556 .38864 L .6137 .38391 L F
.468 .834 .583 r
.61507 .38897 m .61556 .38864 L .61763 .38697 L F
.137 0 .019 r
.25716 .52894 m .25917 .52839 L .26093 .52531 L F
.441 .249 .523 r
.26093 .52531 m .26326 .52534 L .26325 .52257 L F
0 0 0 r
.26093 .52531 m .26111 .52712 L .26326 .52534 L F
.26093 .52531 m .25917 .52839 L .26111 .52712 L F
.333 0 0 r
.40155 .46229 m .39949 .46451 L .39656 .46481 L F
.171 0 0 r
.40396 .46216 m .39949 .46451 L .40155 .46229 L F
.33 .253 .617 r
.23778 .56555 m .23972 .56079 L .23767 .56241 L F
.75 .354 0 r
.59205 .3567 m .59267 .35849 L .59442 .36101 L F
.846 .666 .659 r
.58906 .36124 m .59442 .36101 L .59267 .35849 L F
.019 0 .269 r
.59442 .35931 m .5933 .36031 L .59267 .35849 L F
.846 .666 .659 r
.58906 .36124 m .59177 .36363 L .59442 .36101 L F
.019 0 .269 r
.5933 .36031 m .59234 .36119 L .59267 .35849 L F
.75 .354 0 r
.59182 .35626 m .59267 .35849 L .59205 .3567 L F
.769 .535 .581 r
.59442 .36101 m .59577 .36267 L .59505 .36173 L F
.012 0 .325 r
.53299 .42057 m .53424 .42002 L .535 .41717 L F
0 0 0 r
.53172 .42221 m .53424 .42002 L .53299 .42057 L F
.372 .823 .707 r
.43293 .44724 m .43259 .44765 L .43079 .44863 L F
.43293 .44724 m .43494 .44647 L .43259 .44765 L F
.94 .598 .349 r
.40316 .51232 m .40457 .51551 L .40637 .51598 L F
.427 0 0 r
.40457 .51551 m .40816 .51652 L .40637 .51598 L F
.785 .902 .924 r
.51844 .48536 m .51725 .48719 L .51546 .48605 L F
.884 .858 .81 r
.30881 .61064 m .31104 .61203 L .31327 .60856 L F
.937 .819 .702 r
.30894 .61415 m .31104 .61203 L .30881 .61064 L F
.808 .981 .702 r
.26783 .61221 m .26711 .61381 L .26648 .61307 L F
0 .052 .55 r
.26648 .61307 m .26711 .61381 L .26766 .61418 L F
.607 .703 .912 r
.31608 .6382 m .32039 .63935 L .31864 .63759 L F
.701 .76 .898 r
.32039 .63935 m .3228 .63823 L .31864 .63759 L F
.582 .655 .887 r
.34105 .6603 m .33851 .66132 L .33615 .65723 L F
.62 .439 .615 r
.34105 .6603 m .33789 .66377 L .33851 .66132 L F
.977 .887 .671 r
.67442 .34192 m .67232 .34309 L .67294 .34043 L F
.67442 .34192 m .6734 .34442 L .67232 .34309 L F
.652 .839 .972 r
.62753 .38045 m .62287 .38026 L .62601 .37852 L F
0 0 .376 r
.62891 .37832 m .62753 .38045 L .62601 .37852 L F
.46 .464 .775 r
.63142 .37805 m .63114 .37842 L .62891 .37832 L F
.63114 .37842 m .62746 .38327 L .62825 .38058 L F
.63114 .37842 m .62825 .38058 L .62891 .37832 L F
0 0 0 r
.62862 .38156 m .62753 .38045 L .62746 .38327 L F
.62862 .38156 m .62592 .38268 L .6265 .38188 L F
.62791 .38083 m .6265 .38188 L .62753 .38045 L F
.62862 .38156 m .6265 .38188 L .62791 .38083 L F
0 .259 .687 r
.57907 .38892 m .57995 .38964 L .57694 .38794 L F
.454 0 0 r
.54456 .4078 m .54649 .40894 L .54631 .40593 L F
.54456 .4078 m .54229 .40912 L .54649 .40894 L F
.925 .605 .416 r
.34018 .50863 m .34257 .51202 L .34238 .50981 L F
.449 .78 .998 r
.55055 .4066 m .55156 .40265 L .55058 .40464 L F
.216 .739 .821 r
.55567 .40518 m .55884 .40466 L .55431 .40511 L F
.597 .889 .99 r
.5529 .40529 m .55305 .40623 L .55567 .40518 L F
.449 .78 .998 r
.55071 .40596 m .5529 .40529 L .55156 .40265 L F
.55055 .4066 m .55241 .40556 L .55071 .40596 L F
.55241 .40556 m .5529 .40529 L .55071 .40596 L F
.55055 .4066 m .55305 .40623 L .5529 .40529 L F
.628 .423 .586 r
.54901 .40572 m .55009 .40781 L .5529 .40529 L F
.55009 .40781 m .55052 .40865 L .55116 .40773 L F
.55009 .40781 m .55116 .40773 L .5529 .40529 L F
.747 .583 .672 r
.5529 .40529 m .55052 .40865 L .5532 .40824 L F
.411 .002 .151 r
.54631 .40593 m .55058 .40464 L .54683 .40582 L F
.54631 .40593 m .54901 .40572 L .55058 .40464 L F
.642 .487 .658 r
.54901 .40572 m .5529 .40529 L .55156 .40265 L F
.931 .964 .763 r
.5513 .40592 m .55052 .40865 L .54999 .40644 L F
.5529 .40529 m .55116 .40773 L .5513 .40592 L F
.55116 .40773 m .55052 .40865 L .5513 .40592 L F
.747 .583 .672 r
.5532 .40824 m .55052 .40865 L .5529 .40529 L F
.5532 .40824 m .55052 .40865 L .5529 .40529 L F
.615 .725 .924 r
.55278 .40762 m .5532 .40824 L .55313 .4076 L F
.55278 .40762 m .55313 .4076 L .5529 .40529 L F
.844 .999 .807 r
.55145 .40561 m .5529 .40529 L .5513 .40592 L F
.615 .725 .924 r
.55145 .40561 m .55278 .40762 L .5529 .40529 L F
.55145 .40561 m .55434 .40751 L .55278 .40762 L F
.55131 .4054 m .55145 .40561 L .5529 .40529 L F
.55134 .40545 m .55148 .40554 L .55145 .40561 L F
.55148 .40554 m .55434 .40751 L .55145 .40561 L F
.844 .999 .807 r
.55055 .4058 m .55145 .40561 L .54999 .40644 L F
.55145 .40561 m .5513 .40592 L .54999 .40644 L F
.615 .725 .924 r
.55131 .4054 m .55134 .40542 L .55134 .40545 L F
.55134 .40542 m .55148 .40552 L .55134 .40545 L F
.55148 .40552 m .55434 .40751 L .55148 .40554 L F
.55148 .40552 m .55148 .40554 L .55134 .40545 L F
.597 .889 .99 r
.5529 .40529 m .55567 .40518 L .55174 .40538 L F
.5529 .40529 m .55174 .40538 L .55131 .4054 L F
.216 .739 .821 r
.55567 .40518 m .55431 .40511 L .55354 .40529 L F
.791 .724 .79 r
.55884 .40466 m .55574 .40849 L .55148 .40552 L F
.55162 .40537 m .55148 .40552 L .55131 .4054 L F
.844 .999 .807 r
.55152 .40549 m .5529 .40529 L .55145 .40561 L F
.5516 .40539 m .5529 .40529 L .55152 .40549 L F
0 0 .564 r
.55156 .40265 m .5529 .40529 L .5529 .40395 L F
.55257 .40303 m .5529 .40395 L .5529 .40315 L F
.55156 .40265 m .5529 .40395 L .55257 .40303 L F
.791 .724 .79 r
.55335 .4052 m .55148 .40552 L .55162 .40537 L F
.55884 .40466 m .55338 .4053 L .55335 .4052 L F
.216 .739 .821 r
.55354 .40529 m .55431 .40511 L .55162 .40537 L F
.55174 .40538 m .55162 .40537 L .55131 .4054 L F
.55354 .40529 m .55162 .40537 L .55174 .40538 L F
.844 .999 .807 r
.5529 .40315 m .55159 .40537 L .5522 .40393 L F
.55159 .40537 m .55145 .40561 L .55155 .40537 L F
.55159 .40537 m .55155 .40537 L .5522 .40393 L F
.791 .724 .79 r
.55338 .4053 m .55148 .40552 L .55335 .4052 L F
.844 .999 .807 r
.5529 .40315 m .5529 .40529 L .55157 .40539 L F
.55157 .40539 m .5516 .40539 L .55152 .40549 L F
.5522 .40393 m .55145 .40561 L .55055 .4058 L F
.615 .725 .924 r
.55278 .40762 m .55574 .40849 L .5532 .40824 L F
.55434 .40751 m .55574 .40849 L .55278 .40762 L F
0 0 0 r
.62241 .39621 m .62377 .39484 L .61987 .39737 L F
.62241 .39621 m .61987 .39737 L .61893 .40002 L F
.47 .506 .813 r
.3203 .54324 m .32096 .547 L .31876 .54754 L F
.382 0 0 r
.32096 .547 m .32051 .54702 L .31876 .54754 L F
.372 .384 .743 r
.31876 .54754 m .31639 .54824 L .31592 .54559 L F
.141 .366 .822 r
.31664 .54376 m .31876 .54754 L .31592 .54559 L F
.47 .506 .813 r
.3203 .54324 m .31876 .54754 L .31664 .54376 L F
.382 0 0 r
.32051 .54702 m .31646 .54721 L .31876 .54754 L F
.372 .384 .743 r
.31876 .54754 m .31671 .55008 L .31639 .54824 L F
.088 0 .44 r
.31876 .54754 m .31717 .55246 L .31671 .55008 L F
.908 .651 .538 r
.35415 .53155 m .35738 .53493 L .35701 .53299 L F
.531 .657 .916 r
.34327 .63555 m .34723 .63814 L .34592 .63424 L F
.754 .715 .816 r
.34723 .63814 m .34808 .63375 L .34592 .63424 L F
.34723 .63814 m .35004 .6352 L .34808 .63375 L F
0 0 .536 r
.58375 .39068 m .58583 .394 L .5852 .39252 L F
0 0 .144 r
.58583 .394 m .58607 .3947 L .5852 .39252 L F
.58583 .394 m .58623 .39663 L .58607 .3947 L F
.449 .222 .477 r
.36406 .48018 m .36632 .4819 L .36649 .47935 L F
.36406 .48018 m .36632 .4819 L .36649 .47935 L F
.411 .741 .993 r
.3099 .60356 m .31148 .60493 L .30897 .6051 L F
.3099 .60356 m .31148 .60493 L .30897 .6051 L F
0 0 0 r
.47411 .53253 m .47329 .53365 L .47673 .53133 L F
.536 .479 .739 r
.70463 .31173 m .70545 .3158 L .70759 .31236 L F
.532 .474 .736 r
.70545 .3158 m .70891 .31682 L .70759 .31236 L F
.649 .874 .982 r
.65384 .36387 m .64999 .36384 L .65122 .36505 L F
.874 .704 .668 r
.36423 .55149 m .36595 .55535 L .3665 .55256 L F
.283 0 0 r
.31802 .62943 m .31738 .62782 L .31538 .62988 L F
.31786 .62901 m .31987 .62758 L .31738 .62782 L F
.31849 .62897 m .31987 .62758 L .31786 .62901 L F
.978 .913 .599 r
.32007 .62303 m .32097 .62508 L .31987 .62758 L F
.32007 .62303 m .31987 .62758 L .31804 .62643 L F
.283 0 0 r
.31802 .62943 m .31849 .62897 L .31786 .62901 L F
.98 .754 .525 r
.31804 .62643 m .31987 .62758 L .31802 .62943 L F
.31804 .62643 m .32043 .62882 L .32037 .62622 L F
.32043 .62882 m .3208 .62919 L .32074 .6288 L F
.32043 .62882 m .32074 .6288 L .32037 .62622 L F
.853 .548 .472 r
.35868 .54202 m .3588 .54456 L .36089 .54228 L F
.839 .525 .458 r
.36089 .54228 m .3588 .54456 L .36133 .54471 L F
.803 .902 .911 r
.52368 .47872 m .52197 .47995 L .52103 .47807 L F
.074 .166 .656 r
.52144 .4821 m .52298 .48072 L .52103 .47807 L F
.801 .498 .477 r
.52298 .48072 m .51889 .47754 L .52103 .47807 L F
.51889 .47754 m .51881 .47748 L .52103 .47807 L F
.803 .902 .911 r
.52499 .47777 m .52368 .47872 L .52103 .47807 L F
0 .144 .648 r
.4242 .55243 m .42666 .55439 L .42674 .55481 L F
.912 .738 .243 r
.42609 .55689 m .42674 .55481 L .42666 .55439 L F
.42609 .55689 m .42675 .55906 L .42674 .55481 L F
.521 .127 .234 r
.38798 .46242 m .3863 .46509 L .38401 .46365 L F
.572 .182 .264 r
.3897 .46488 m .38798 .46242 L .39063 .46324 L F
.3897 .46488 m .3863 .46509 L .38798 .46242 L F
.946 .799 .666 r
.36629 .49164 m .36834 .49311 L .36977 .48944 L F
.999 .825 .488 r
.48942 .51425 m .49089 .51243 L .49055 .51513 L F
.662 .967 .787 r
.49426 .5098 m .49089 .51243 L .49047 .51213 L F
.873 .92 .525 r
.49047 .51213 m .49089 .51243 L .48942 .51425 L F
.877 .743 .71 r
.7215 .31691 m .72351 .31865 L .72225 .31452 L F
.697 .157 0 r
.41413 .52307 m .41296 .52367 L .41563 .52443 L F
.881 .618 .537 r
.40887 .51654 m .41137 .51925 L .41066 .51811 L F
.915 .786 .306 r
.69287 .34445 m .69332 .34141 L .69296 .34012 L F
.184 0 .213 r
.51749 .42015 m .51578 .42045 L .51856 .4175 L F
.301 .331 .726 r
.51749 .42015 m .51873 .42295 L .51578 .42045 L F
0 0 0 r
.49602 .44378 m .49436 .44685 L .4954 .4451 L F
.49764 .4419 m .49602 .44378 L .4954 .4451 L F
.504 .204 .391 r
.31164 .68116 m .31383 .6834 L .31109 .68351 L F
.31164 .68116 m .31438 .68083 L .31383 .6834 L F
.92 .581 .38 r
.39679 .58445 m .39391 .5811 L .39563 .58249 L F
.549 .914 .953 r
.63748 .3996 m .63977 .39759 L .63669 .39906 L F
.63748 .3996 m .64085 .39844 L .63977 .39759 L F
.229 .034 .395 r
.24208 .53904 m .24466 .53793 L .24513 .53514 L F
.246 .1 .476 r
.24208 .53904 m .24449 .54033 L .24466 .53793 L F
.24208 .53904 m .24204 .54268 L .24449 .54033 L F
.526 .919 .895 r
.48681 .5175 m .48761 .51781 L .4855 .51878 L F
.519 .875 .639 r
.4855 .51878 m .48487 .5191 L .48681 .5175 L F
.907 .82 .749 r
.35207 .5636 m .35046 .56174 L .3542 .56207 L F
.35207 .5636 m .34902 .56433 L .35046 .56174 L F
.961 .798 .634 r
.71418 .30555 m .71337 .30861 L .71255 .30403 L F
.631 .807 .967 r
.71804 .30361 m .71418 .30555 L .71255 .30403 L F
.611 .868 .523 r
.62522 .39302 m .62377 .39484 L .62241 .39621 L F
.78 .822 .886 r
.43512 .57178 m .43123 .57158 L .43377 .56893 L F
.817 .836 .864 r
.43794 .56906 m .43512 .57178 L .43377 .56893 L F
.617 .857 .989 r
.59429 .43442 m .59701 .4332 L .59577 .43187 L F
.443 .284 .569 r
.52355 .41046 m .5237 .4133 L .52127 .41423 L F
.834 .944 .895 r
.45596 .55343 m .45284 .55593 L .45356 .55297 L F
.729 .896 .955 r
.45637 .55067 m .45596 .55343 L .45356 .55297 L F
.45637 .55067 m .45793 .55181 L .45596 .55343 L F
.891 .989 .78 r
.55621 .45556 m .55447 .45943 L .55526 .45806 L F
.789 .98 .905 r
.55207 .45949 m .55467 .45928 L .55108 .4621 L F
.55467 .45928 m .55498 .45925 L .55453 .45958 L F
.55467 .45928 m .55453 .45958 L .55108 .4621 L F
.891 .989 .78 r
.55531 .45796 m .55526 .45806 L .5553 .45801 L F
.55621 .45556 m .55526 .45806 L .55531 .45796 L F
0 0 .495 r
.5553 .45801 m .55447 .45943 L .55498 .45925 L F
.962 .819 .657 r
.54073 .3825 m .54046 .38411 L .54211 .38437 L F
.565 .737 .957 r
.54351 .38149 m .54211 .38437 L .54073 .3825 L F
.753 .957 .938 r
.54351 .38149 m .54046 .38411 L .54211 .38437 L F
.808 .538 .529 r
.5833 .38772 m .58375 .39068 L .57995 .38964 L F
.5833 .38772 m .57995 .38964 L .58206 .38944 L F
.5833 .38772 m .58206 .38944 L .583 .38634 L F
.619 .818 .408 r
.49536 .53206 m .49872 .52671 L .49394 .53124 L F
.322 .212 .57 r
.6472 .36146 m .6488 .36049 L .64938 .36094 L F
.232 .326 .756 r
.6509 .35936 m .65232 .36202 L .64938 .36094 L F
.554 .471 .715 r
.6488 .36049 m .6509 .35936 L .64938 .36094 L F
.872 .773 .75 r
.55278 .46367 m .54861 .46564 L .55108 .4621 L F
.55278 .46367 m .55059 .46709 L .54861 .46564 L F
.251 .629 .96 r
.60353 .39476 m .60287 .39565 L .60095 .39424 L F
.60353 .39476 m .60606 .39614 L .60287 .39565 L F
.982 .895 .557 r
.55637 .39017 m .55564 .39409 L .55458 .39227 L F
0 0 0 r
.55564 .39409 m .55276 .39568 L .55458 .39227 L F
.68 .537 .684 r
.55497 .3958 m .55963 .3963 L .55869 .39284 L F
0 0 0 r
.55603 .39495 m .55497 .3958 L .55604 .39498 L F
.55564 .39409 m .55497 .3958 L .55603 .39495 L F
.55564 .39409 m .55603 .39495 L .55276 .39568 L F
.68 .537 .684 r
.55497 .3958 m .55603 .39495 L .55573 .39505 L F
.361 .755 .986 r
.55506 .39568 m .55276 .39568 L .55573 .39505 L F
.55282 .39779 m .55281 .39728 L .55506 .39568 L F
.55281 .39728 m .55276 .39568 L .55506 .39568 L F
.68 .537 .684 r
.55497 .3958 m .55506 .39568 L .55604 .39498 L F
.55506 .39568 m .55573 .39505 L .55547 .39512 L F
.55497 .3958 m .55573 .39505 L .55506 .39568 L F
0 0 0 r
.55603 .39495 m .55604 .39498 L .55573 .39505 L F
.55603 .39495 m .55573 .39505 L .55276 .39568 L F
.68 .537 .684 r
.55547 .39512 m .55869 .39284 L .55828 .39135 L F
.55603 .39495 m .55869 .39284 L .55547 .39512 L F
.55506 .39568 m .55828 .39135 L .55604 .39498 L F
.238 .706 .945 r
.55497 .3958 m .55847 .39732 L .55927 .39662 L F
.55562 .39587 m .55927 .39662 L .55963 .3963 L F
.55497 .3958 m .55927 .39662 L .55562 .39587 L F
.361 .755 .986 r
.55283 .39815 m .55282 .39779 L .55604 .39498 L F
.55282 .39779 m .55573 .39505 L .55604 .39498 L F
.774 .794 .302 r
.55275 .39905 m .55283 .39815 L .55276 .39568 L F
.361 .755 .986 r
.55283 .39815 m .55275 .39905 L .55276 .39568 L F
.805 .709 .759 r
.55184 .39154 m .55276 .39568 L .54892 .39516 L F
.97 .651 .306 r
.55276 .39568 m .55135 .39539 L .54892 .39516 L F
.55276 .39568 m .55283 .39815 L .55135 .39539 L F
.76 .682 .775 r
.55458 .39227 m .55276 .39568 L .55184 .39154 L F
.784 .71 .782 r
.55135 .39539 m .55283 .39815 L .55522 .39579 L F
.5527 .39528 m .55522 .39579 L .55604 .39498 L F
.55135 .39539 m .55522 .39579 L .5527 .39528 L F
.499 .87 .981 r
.60616 .38836 m .60844 .38904 L .61063 .38829 L F
0 0 0 r
.65933 .37119 m .65762 .37131 L .65915 .37387 L F
.729 .549 .648 r
.66209 .37054 m .65915 .37387 L .65933 .37119 L F
0 0 0 r
.65933 .37119 m .66083 .37139 L .65762 .37131 L F
.65933 .37119 m .66209 .37054 L .66083 .37139 L F
.764 .274 .066 r
.38298 .49276 m .38748 .49535 L .38742 .49484 L F
.884 .983 .822 r
.45356 .55297 m .45284 .55593 L .45023 .55687 L F
.485 .899 .893 r
.63995 .34751 m .63576 .34846 L .63798 .34926 L F
.782 .825 .886 r
.3281 .65369 m .32968 .65656 L .32721 .65774 L F
.675 .779 .928 r
.33243 .65423 m .32968 .65656 L .3281 .65369 L F
.758 .526 .582 r
.27361 .60414 m .27411 .60143 L .26947 .60158 L F
.893 .8 .75 r
.35583 .538 m .35956 .53639 L .35738 .53493 L F
.971 .91 .565 r
.69417 .35618 m .69454 .35796 L .69539 .35455 L F
.84 .646 .102 r
.69461 .36078 m .69454 .35796 L .69417 .35618 L F
.823 .909 .898 r
.28802 .65084 m .28324 .6524 L .28621 .6493 L F
.532 .722 .961 r
.28919 .64857 m .28802 .65084 L .28621 .6493 L F
.28919 .64857 m .29052 .65037 L .28802 .65084 L F
.196 .385 .824 r
.40603 .59328 m .40838 .59448 L .40708 .5916 L F
.853 .778 .778 r
.36692 .60776 m .37085 .60796 L .36949 .60436 L F
.864 .723 .705 r
.36854 .61144 m .37085 .60796 L .36692 .60776 L F
.85 .777 .781 r
.36949 .60436 m .37085 .60796 L .37166 .60567 L F
.679 .968 .925 r
.47559 .42094 m .47448 .42286 L .47377 .42274 L F
.47559 .42094 m .47807 .42089 L .47448 .42286 L F
0 0 0 r
.65357 .32871 m .65501 .32895 L .65617 .32768 L F
.65357 .32871 m .65246 .32998 L .65501 .32895 L F
.367 0 0 r
.30005 .68613 m .30196 .68455 L .30398 .68556 L F
.347 0 .003 r
.30196 .68455 m .30673 .68332 L .30398 .68556 L F
.973 .849 .448 r
.57297 .36128 m .57218 .35952 L .57283 .35656 L F
.702 .955 .685 r
.66011 .39646 m .66051 .39686 L .6593 .39756 L F
.956 .625 .344 r
.66051 .39686 m .66118 .40042 L .6593 .39756 L F
.518 .905 .755 r
.66363 .39481 m .66051 .39686 L .66258 .39501 L F
.523 .915 .807 r
.66258 .39501 m .66051 .39686 L .66011 .39646 L F
.623 .599 .805 r
.66363 .39481 m .66397 .39683 L .66051 .39686 L F
.587 .357 .535 r
.66397 .39683 m .66118 .40042 L .66051 .39686 L F
.645 .958 .77 r
.62706 .40447 m .62613 .40555 L .62891 .40435 L F
.62706 .40447 m .62477 .40611 L .62613 .40555 L F
.85 .777 .78 r
.36949 .60436 m .3742 .60229 L .37232 .60106 L F
.36949 .60436 m .37166 .60567 L .3742 .60229 L F
.568 .061 .011 r
.33725 .51613 m .33528 .51749 L .33316 .51604 L F
.928 .599 .395 r
.33725 .51613 m .33761 .51871 L .33528 .51749 L F
.342 0 0 r
.4111 .46119 m .41101 .46186 L .40828 .46191 L F
.973 .676 .29 r
.28452 .66813 m .28576 .67123 L .28324 .66851 L F
.968 .722 .51 r
.28324 .66851 m .28576 .67123 L .28358 .67286 L F
.682 .965 .934 r
.28605 .66936 m .28604 .66999 L .28576 .67123 L F
.252 .746 .912 r
.28603 .67054 m .28604 .66999 L .2846 .67131 L F
.583 .578 .813 r
.28647 .66668 m .2886 .67113 L .29127 .66907 L F
.705 .879 .962 r
.29127 .66907 m .2886 .67113 L .28604 .66999 L F
.29127 .66907 m .2883 .66959 L .28868 .66984 L F
.2883 .66959 m .28604 .66999 L .28868 .66984 L F
.388 0 0 r
.28939 .67031 m .28868 .66984 L .28799 .66949 L F
.29097 .67124 m .28868 .66984 L .28939 .67031 L F
.252 .746 .912 r
.28799 .66949 m .28604 .66999 L .28603 .67054 L F
.682 .965 .934 r
.28647 .66668 m .28604 .66999 L .28605 .66936 L F
.959 .897 .722 r
.28982 .67278 m .28783 .6777 L .28736 .67702 L F
.28982 .67278 m .28736 .67702 L .29003 .67362 L F
.566 .079 .058 r
.28358 .67286 m .28576 .67123 L .29003 .67362 L F
.819 .805 .838 r
.33454 .53857 m .33409 .54265 L .33668 .54254 L F
.645 .171 .112 r
.33409 .54265 m .33457 .54408 L .33668 .54254 L F
.736 .961 .676 r
.33668 .54254 m .33457 .54408 L .33467 .54453 L F
.768 .787 .869 r
.33454 .53857 m .33668 .54254 L .33978 .54048 L F
.433 .469 .797 r
.59505 .36173 m .59577 .36267 L .59823 .363 L F
.8 .604 .637 r
.52493 .38739 m .5261 .3906 L .52672 .38791 L F
.64 .102 0 r
.58251 .36962 m .58661 .37313 L .58367 .37137 L F
.784 .534 .557 r
.30535 .58366 m .30976 .5814 L .30871 .58185 L F
.049 0 0 r
.65362 .33846 m .65193 .3379 L .6548 .33717 L F
.65362 .33846 m .6511 .33963 L .65193 .3379 L F
.103 .052 .509 r
.3465 .54978 m .34776 .55094 L .3473 .54836 L F
.558 .534 .784 r
.34661 .55507 m .34776 .55094 L .3465 .54978 L F
.221 .719 .912 r
.52172 .43076 m .52599 .43089 L .524 .42704 L F
.99 .888 .585 r
.52599 .43089 m .52642 .42632 L .524 .42704 L F
.558 .496 .742 r
.27798 .60512 m .28065 .60485 L .28011 .60062 L F
.971 .789 .601 r
.34341 .55892 m .34184 .55959 L .34255 .55489 L F
.994 .806 .435 r
.34341 .55892 m .34212 .56028 L .34184 .55959 L F
.354 .012 .239 r
.5161 .40813 m .51298 .41032 L .51272 .40778 L F
.154 0 .198 r
.51749 .42015 m .51856 .4175 L .52075 .41621 L F
.933 .776 .664 r
.34888 .57474 m .35004 .57798 L .35165 .57575 L F
.565 .481 .719 r
.43694 .59759 m .43964 .59703 L .4394 .59683 L F
0 0 0 r
.43802 .59557 m .43487 .59824 L .43694 .59759 L F
.901 .92 .53 r
.43802 .59557 m .43694 .59759 L .43767 .5954 L F
.565 .481 .719 r
.43694 .59759 m .4394 .59683 L .43767 .5954 L F
0 0 0 r
.43487 .59824 m .43423 .59878 L .43694 .59759 L F
.504 0 0 r
.43802 .59557 m .43767 .5954 L .43594 .59405 L F
.702 .479 .582 r
.26626 .53583 m .26597 .53876 L .26378 .53856 L F
.553 .394 .62 r
.26889 .5351 m .26626 .53583 L .26876 .5324 L F
.604 .427 .616 r
.26889 .5351 m .26597 .53876 L .26626 .53583 L F
.969 .744 .543 r
.44905 .49572 m .44953 .49309 L .44755 .49181 L F
.895 .624 .52 r
.44953 .49309 m .44711 .4896 L .44755 .49181 L F
.969 .744 .543 r
.44905 .49572 m .44953 .49309 L .44755 .49181 L F
.503 .639 .915 r
.31028 .63382 m .31205 .63697 L .31473 .63654 L F
.51 .689 .948 r
.31205 .63697 m .31608 .6382 L .31473 .63654 L F
.077 0 0 r
.70406 .29494 m .70689 .29392 L .70781 .2926 L F
.079 0 .416 r
.70951 .28776 m .70781 .2926 L .70958 .29066 L F
.183 .687 .907 r
.37351 .49664 m .37589 .49649 L .3774 .49724 L F
.614 .169 .171 r
.37589 .49649 m .38017 .49561 L .3774 .49724 L F
.942 .951 .752 r
.45179 .5863 m .44963 .58875 L .44918 .58671 L F
.71 .808 .926 r
.45417 .58382 m .45179 .5863 L .45047 .58336 L F
.982 .869 .647 r
.45179 .5863 m .45047 .58336 L .45417 .58382 L F
.917 .673 .554 r
.71944 .30646 m .72258 .30486 L .71936 .30387 L F
.71944 .30646 m .72146 .30764 L .72258 .30486 L F
.227 0 0 r
.62158 .37126 m .62015 .37095 L .61851 .37049 L F
.669 .935 .968 r
.62406 .36993 m .62015 .37095 L .62158 .37126 L F
0 0 0 r
.42558 .55058 m .4242 .55243 L .42605 .54804 L F
.144 .265 .731 r
.42558 .55058 m .42666 .55439 L .4242 .55243 L F
.874 .704 .668 r
.36423 .55149 m .36191 .55469 L .36595 .55535 L F
.884 .715 .667 r
.36181 .55755 m .36595 .55535 L .36191 .55469 L F
.36181 .55755 m .36348 .55787 L .36595 .55535 L F
.938 .799 .68 r
.57705 .43362 m .57863 .42999 L .57596 .42928 L F
.898 .814 .757 r
.35606 .62357 m .35978 .62116 L .35848 .62017 L F
.35606 .62357 m .35797 .62485 L .35978 .62116 L F
.781 .814 .879 r
.35978 .62116 m .36129 .61703 L .35848 .62017 L F
.35978 .62116 m .36325 .61842 L .36129 .61703 L F
.881 .836 .369 r
.56978 .4087 m .56998 .41082 L .57072 .40698 L F
.853 .902 .488 r
.56876 .41144 m .56998 .41082 L .56978 .4087 L F
.56876 .41144 m .56874 .41309 L .56998 .41082 L F
.059 0 0 r
.3956 .45799 m .39841 .45738 L .39993 .45619 L F
.512 .047 .086 r
.39841 .45738 m .40251 .4558 L .39993 .45619 L F
.693 .374 .43 r
.29023 .66668 m .29373 .66681 L .29454 .66437 L F
.283 .194 .575 r
.29454 .66437 m .29616 .66044 L .29347 .66094 L F
.29454 .66437 m .29675 .66355 L .29616 .66044 L F
.212 0 .234 r
.29454 .66437 m .29601 .6659 L .29675 .66355 L F
.29454 .66437 m .29373 .66681 L .29601 .6659 L F
.19 .592 .943 r
.52077 .39008 m .51939 .39132 L .51792 .39075 L F
.476 .117 .277 r
.51939 .39132 m .52246 .3911 L .52533 .38902 L F
.227 0 0 r
.51939 .39132 m .52239 .39153 L .52246 .3911 L F
.19 .592 .943 r
.52077 .39008 m .52239 .39153 L .51939 .39132 L F
.558 .73 .956 r
.31608 .6382 m .31686 .63606 L .31473 .63654 L F
.31608 .6382 m .31864 .63759 L .31686 .63606 L F
.82 .707 .74 r
.47326 .55827 m .47747 .55925 L .47547 .55478 L F
.741 .432 .459 r
.47265 .56065 m .47747 .55925 L .47326 .55827 L F
.47265 .56065 m .47696 .56161 L .47747 .55925 L F
.779 .691 .766 r
.47547 .55478 m .47747 .55925 L .47946 .55545 L F
.793 .486 .469 r
.47747 .55925 m .47696 .56161 L .48096 .56193 L F
.331 0 0 r
.57687 .35919 m .57956 .35929 L .58088 .35794 L F
.907 .514 .254 r
.58088 .35794 m .57956 .35929 L .58139 .35987 L F
.981 .893 .548 r
.59265 .40561 m .59166 .40961 L .5924 .41065 L F
.653 .942 .692 r
.6028 .44043 m .59959 .44359 L .60088 .44174 L F
.361 .607 .943 r
.59959 .44359 m .60224 .44398 L .60088 .44174 L F
.526 .435 .695 r
.28725 .63166 m .28348 .63459 L .28769 .63124 L F
.597 .947 .808 r
.28855 .63023 m .28769 .63124 L .28411 .63255 L F
.584 .906 .654 r
.28855 .63023 m .28725 .63166 L .28769 .63124 L F
0 0 .407 r
.28837 .63325 m .28725 .63166 L .28855 .63023 L F
.28837 .63325 m .28772 .63462 L .28725 .63166 L F
.906 .729 .65 r
.55862 .41651 m .56006 .42041 L .55732 .41867 L F
.904 .513 .264 r
.55732 .41867 m .56006 .42041 L .55867 .42191 L F
.845 .414 .205 r
.55867 .42191 m .56006 .42041 L .56067 .42272 L F
.27 .115 .478 r
.23992 .5556 m .24158 .55752 L .24138 .5547 L F
.23992 .5556 m .23976 .55841 L .24158 .55752 L F
.676 .974 .9 r
.63034 .40225 m .62891 .40435 L .631 .40275 L F
.654 .951 .95 r
.63034 .40225 m .62706 .40447 L .62891 .40435 L F
.81 .533 .519 r
.4463 .58696 m .44906 .58557 L .44764 .58469 L F
.535 .708 .951 r
.44906 .58557 m .45047 .58336 L .44764 .58469 L F
.953 .952 .672 r
.44752 .56037 m .44763 .56308 L .44587 .56432 L F
0 0 .203 r
.58751 .40332 m .58645 .3991 L .58794 .40104 L F
.702 .77 .905 r
.61773 .3843 m .6137 .38391 L .61589 .3823 L F
.59 .574 .804 r
.61763 .38697 m .6137 .38391 L .61773 .3843 L F
.748 .781 .88 r
.62078 .38181 m .61773 .3843 L .61589 .3823 L F
0 0 0 r
.62073 .38497 m .61763 .38697 L .61773 .3843 L F
.513 .412 .678 r
.59177 .36363 m .59469 .36561 L .59577 .36267 L F
.673 .411 .517 r
.59469 .36561 m .59823 .363 L .59577 .36267 L F
.566 .772 .976 r
.60026 .40152 m .60431 .40236 L .60331 .40086 L F
.584 .751 .957 r
.60431 .40236 m .60598 .39975 L .60331 .40086 L F
.60431 .40236 m .60727 .40152 L .60598 .39975 L F
.652 .198 .161 r
.29064 .68394 m .29514 .68413 L .29311 .68602 L F
.561 .088 .089 r
.29311 .68602 m .29514 .68413 L .29718 .68594 L F
.76 .726 .821 r
.3252 .65601 m .32721 .65774 L .32297 .65728 L F
.782 .825 .886 r
.3281 .65369 m .32721 .65774 L .3252 .65601 L F
.358 0 0 r
.42735 .60241 m .43161 .60119 L .42949 .60325 L F
.488 .284 .529 r
.43161 .60119 m .43423 .59878 L .43401 .60069 L F
.11 0 0 r
.43161 .60119 m .43169 .60269 L .42949 .60325 L F
.43161 .60119 m .43401 .60069 L .43169 .60269 L F
.971 .91 .565 r
.69417 .35618 m .69539 .35455 L .69453 .35372 L F
.315 0 0 r
.61445 .34333 m .61726 .34339 L .61868 .34243 L F
.203 0 0 r
.61868 .34243 m .61726 .34339 L .62106 .34279 L F
0 .364 .823 r
.56458 .36963 m .56555 .37124 L .56387 .36914 L F
.64 .497 .672 r
.56243 .37022 m .56242 .37276 L .56458 .36963 L F
0 .364 .823 r
.56458 .36963 m .56387 .36914 L .56237 .3673 L F
.659 .567 .741 r
.56094 .36579 m .56243 .37022 L .56458 .36963 L F
.854 .985 .705 r
.56458 .36963 m .56242 .37276 L .56334 .36965 L F
.416 .767 .996 r
.56334 .36965 m .56535 .37016 L .56458 .36963 L F
.085 .338 .812 r
.56779 .37079 m .5655 .37092 L .56458 .36963 L F
.416 .767 .996 r
.56535 .37016 m .56779 .37079 L .56458 .36963 L F
0 .364 .823 r
.56458 .36963 m .5655 .37092 L .56555 .37124 L F
.905 .714 .633 r
.35244 .52507 m .35432 .52876 L .35489 .52623 L F
.82 .841 .864 r
.66681 .38491 m .66861 .38394 L .66714 .38226 L F
.839 .962 .887 r
.66861 .38394 m .6708 .37994 L .66714 .38226 L F
.66861 .38394 m .6718 .38107 L .6708 .37994 L F
.208 0 0 r
.62269 .34653 m .6188 .34773 L .61987 .348 L F
.784 .797 .863 r
.33301 .64013 m .33629 .63777 L .33222 .6374 L F
.763 .834 .907 r
.33301 .64013 m .3358 .63868 L .33629 .63777 L F
.78 .761 .836 r
.59883 .35026 m .59829 .34698 L .59711 .34822 L F
.59883 .35026 m .59964 .34956 L .59829 .34698 L F
.846 .882 .866 r
.59567 .35059 m .59883 .35026 L .59711 .34822 L F
0 0 0 r
.24436 .59853 m .24334 .60005 L .24224 .60128 L F
.24334 .60005 m .24063 .60332 L .24224 .60128 L F
.992 .762 .486 r
.42469 .56045 m .42675 .55906 L .42609 .55689 L F
.42469 .56045 m .42631 .56161 L .42675 .55906 L F
.128 .668 .844 r
.40828 .46191 m .41101 .46186 L .40677 .4616 L F
.515 .843 .552 r
.52545 .45011 m .52485 .4505 L .52528 .4458 L F
.52545 .45011 m .52851 .44727 L .52485 .4505 L F
.813 .97 .661 r
.52485 .4505 m .52851 .44727 L .52972 .4451 L F
0 0 .03 r
.23826 .59811 m .23835 .59988 L .23906 .59657 L F
.23826 .59811 m .23835 .60192 L .23835 .59988 L F
.725 .85 .941 r
.61095 .40271 m .61197 .39951 L .61019 .40075 L F
.61095 .40271 m .61394 .40113 L .61197 .39951 L F
.736 .71 .826 r
.35201 .5825 m .34759 .58143 L .34998 .58097 L F
.575 .581 .822 r
.35004 .57798 m .35281 .58213 L .35288 .58022 L F
.718 .602 .726 r
.35004 .57798 m .35345 .57861 L .35276 .57478 L F
.575 .581 .822 r
.35004 .57798 m .35438 .58141 L .35345 .57861 L F
.977 .902 .671 r
.35296 .57783 m .35185 .5804 L .3527 .57741 L F
.35345 .57861 m .35292 .57921 L .35296 .57783 L F
.35292 .57921 m .35185 .5804 L .35296 .57783 L F
.575 .581 .822 r
.35004 .57798 m .35201 .5825 L .35281 .58213 L F
.35288 .58022 m .35281 .58213 L .35438 .58141 L F
.616 .852 .988 r
.35438 .58141 m .35201 .5825 L .34998 .58097 L F
.765 .67 .758 r
.36948 .47589 m .37065 .47978 L .36649 .47935 L F
.393 .789 .987 r
.36649 .47935 m .37065 .47978 L .36944 .4789 L F
.986 .716 .35 r
.36944 .4789 m .37065 .47978 L .36948 .47589 L F
.468 .364 .654 r
.26048 .54492 m .25806 .54579 L .2586 .54357 L F
.491 .451 .74 r
.26095 .54785 m .25806 .54579 L .26048 .54492 L F
.788 .628 .683 r
.52642 .42632 m .53024 .42313 L .52659 .42383 L F
.803 .902 .911 r
.52499 .47777 m .52103 .47807 L .52311 .47618 L F
.681 .861 .968 r
.52738 .47625 m .52499 .47777 L .52311 .47618 L F
.598 .248 .347 r
.32351 .61731 m .32089 .615 L .32198 .6181 L F
.32351 .61731 m .32513 .61446 L .32089 .615 L F
0 0 0 r
.32826 .53843 m .32958 .53743 L .3302 .53505 L F
.487 .2 .403 r
.32672 .53856 m .32958 .53743 L .32826 .53843 L F
.881 .944 .85 r
.56139 .41056 m .55867 .41388 L .55826 .4122 L F
.723 .6 .028 r
.55867 .41388 m .55865 .41239 L .55826 .4122 L F
.55867 .41388 m .55862 .41651 L .55865 .41239 L F
.254 0 0 r
.62935 .34499 m .62809 .34605 L .62531 .3461 L F
.505 .123 .25 r
.63177 .34487 m .63265 .34612 L .62935 .34499 L F
.727 .492 .57 r
.52533 .38902 m .5261 .3906 L .52493 .38739 L F
.52533 .38902 m .52246 .3911 L .5261 .3906 L F
.824 .466 .376 r
.42217 .54442 m .42437 .54293 L .42218 .54165 L F
.42217 .54442 m .4254 .54508 L .42437 .54293 L F
.564 .937 .859 r
.44301 .44242 m .44181 .44381 L .4395 .44408 L F
.44301 .44242 m .44392 .44251 L .44181 .44381 L F
0 0 0 r
.32794 .54436 m .32654 .54506 L .32623 .54571 L F
.251 .649 .963 r
.326 .54619 m .32623 .54571 L .32308 .5451 L F
.579 .363 .552 r
.324 .54633 m .32308 .5451 L .32623 .54571 L F
0 0 0 r
.32654 .54506 m .324 .54633 L .32623 .54571 L F
.251 .649 .963 r
.32632 .54631 m .32623 .54571 L .326 .54619 L F
.665 .956 .945 r
.32794 .54436 m .32623 .54571 L .32632 .54631 L F
.594 .538 .762 r
.26095 .54785 m .2626 .5527 L .25965 .55236 L F
.955 .911 .734 r
.58287 .3608 m .58497 .36117 L .58139 .35987 L F
.58287 .3608 m .58326 .3649 L .58497 .36117 L F
.837 .948 .892 r
.60369 .44683 m .6056 .44285 L .60224 .44398 L F
.60369 .44683 m .60681 .44381 L .6056 .44285 L F
.486 .59 .883 r
.48482 .43671 m .48631 .43415 L .48337 .43489 L F
.48482 .43671 m .48728 .4366 L .48631 .43415 L F
0 .507 .859 r
.27231 .61407 m .26783 .61221 L .26925 .61428 L F
.815 .907 .904 r
.26798 .61436 m .27064 .61588 L .27188 .61453 L F
.26925 .61428 m .27188 .61453 L .27231 .61407 L F
.26798 .61436 m .27188 .61453 L .26925 .61428 L F
.828 .41 .248 r
.26648 .61307 m .26832 .61419 L .26783 .61221 L F
.26832 .61419 m .26925 .61428 L .26783 .61221 L F
.815 .907 .904 r
.26766 .61418 m .26798 .61436 L .27036 .6142 L F
.26766 .61418 m .27036 .6142 L .27231 .61407 L F
.839 .476 .366 r
.26766 .61418 m .26982 .6151 L .26832 .61419 L F
.26766 .61418 m .26832 .61419 L .26648 .61307 L F
.828 .41 .248 r
.26832 .61419 m .26982 .6151 L .26925 .61428 L F
0 .507 .859 r
.27231 .61407 m .26925 .61428 L .26982 .6151 L F
.616 .911 .981 r
.33192 .58522 m .32982 .58438 L .33226 .58328 L F
.257 .278 .691 r
.39816 .50443 m .39622 .50325 L .39819 .50217 L F
.861 .523 .41 r
.41529 .52759 m .41882 .5312 L .41722 .52871 L F
.27 .397 .808 r
.5684 .37272 m .56721 .37522 L .56672 .37292 L F
.5684 .37272 m .56989 .37665 L .56721 .37522 L F
.67 .248 .234 r
.3496 .5603 m .35046 .56174 L .34582 .56118 L F
.709 .616 .751 r
.52941 .43727 m .52965 .44036 L .52738 .43998 L F
.955 .612 .245 r
.53196 .43612 m .52965 .44036 L .52941 .43727 L F
.53196 .43612 m .53174 .43843 L .52965 .44036 L F
0 0 0 r
.52885 .44185 m .52965 .44036 L .53174 .43843 L F
.687 .834 .953 r
.31854 .62148 m .32269 .62154 L .31987 .61946 L F
.951 .951 .722 r
.32269 .62154 m .32007 .62303 L .31854 .62148 L F
.32269 .62154 m .32097 .62508 L .32007 .62303 L F
.662 .967 .787 r
.49426 .5098 m .49047 .51213 L .49185 .5101 L F
.86 .979 .856 r
.49548 .50801 m .49426 .5098 L .49456 .50716 L F
.853 .976 .867 r
.49426 .5098 m .49185 .5101 L .49456 .50716 L F
.158 .597 .934 r
.59964 .34956 m .60108 .34891 L .59829 .34698 L F
.59964 .34956 m .60409 .35033 L .60108 .34891 L F
.772 .785 .864 r
.47696 .56161 m .4787 .56333 L .48096 .56193 L F
.466 .287 .553 r
.32957 .58847 m .33142 .59076 L .33119 .5877 L F
.32957 .58847 m .32915 .59144 L .33142 .59076 L F
.287 .163 .532 r
.24098 .54829 m .24267 .54488 L .24104 .54548 L F
.604 .812 .98 r
.31409 .61953 m .31591 .6212 L .31083 .62028 L F
.804 .523 .512 r
.31083 .62028 m .31591 .6212 L .31498 .62399 L F
.398 .677 .973 r
.31663 .61949 m .31591 .6212 L .31409 .61953 L F
.31663 .61949 m .31854 .62148 L .31591 .6212 L F
.503 .057 .123 r
.31591 .6212 m .31723 .62285 L .31498 .62399 L F
.31591 .6212 m .31854 .62148 L .31723 .62285 L F
.633 .072 0 r
.24345 .57749 m .23876 .57509 L .2414 .57772 L F
.866 .753 .735 r
.55692 .38727 m .55697 .38742 L .55597 .39018 L F
.409 .808 .585 r
.55637 .39017 m .55819 .38889 L .55969 .38786 L F
.445 .234 .498 r
.55597 .39018 m .55819 .38889 L .55637 .39017 L F
.55597 .39018 m .55828 .39135 L .55819 .38889 L F
.866 .753 .735 r
.55697 .38742 m .55828 .39135 L .55597 .39018 L F
.982 .895 .557 r
.55637 .39017 m .55569 .39097 L .55597 .39018 L F
.55569 .39097 m .55458 .39227 L .55597 .39018 L F
0 0 0 r
.49689 .4489 m .49786 .44718 L .49958 .44552 L F
.491 .863 .984 r
.70784 .29763 m .70714 .2967 L .70471 .29769 L F
.605 .379 .546 r
.70551 .30147 m .70784 .29763 L .70471 .29769 L F
.70551 .30147 m .70888 .30055 L .70784 .29763 L F
.591 .928 .959 r
.51008 .4199 m .50737 .42257 L .50719 .42071 L F
.51008 .4199 m .51195 .42055 L .50737 .42257 L F
.977 .921 .644 r
.55916 .42901 m .5613 .42687 L .55977 .42876 L F
.891 .968 .651 r
.56097 .42643 m .5613 .42687 L .55916 .42901 L F
0 0 .04 r
.24822 .5876 m .24679 .59119 L .24745 .58863 L F
.24822 .5876 m .24679 .59119 L .24745 .58863 L F
.98 .721 .465 r
.41868 .53422 m .42059 .53248 L .41882 .5312 L F
.41868 .53422 m .42038 .53518 L .42059 .53248 L F
0 0 0 r
.32621 .61369 m .32513 .61446 L .32351 .61731 L F
.796 .743 .804 r
.28912 .66071 m .29347 .66094 L .29152 .6598 L F
.11 0 .434 r
.26325 .52257 m .26387 .52483 L .26568 .52193 L F
.26325 .52257 m .26326 .52534 L .26387 .52483 L F
.576 .689 .918 r
.29347 .66094 m .29457 .65744 L .29152 .6598 L F
.29347 .66094 m .29616 .66044 L .29457 .65744 L F
.911 .562 .364 r
.37695 .52251 m .3751 .5241 L .37487 .52154 L F
.37695 .52251 m .37761 .52519 L .3751 .5241 L F
.88 .654 .59 r
.36133 .54471 m .36067 .54826 L .3643 .54886 L F
.827 .685 .706 r
.36067 .54826 m .36423 .55149 L .3643 .54886 L F
.487 .853 .989 r
.28593 .63391 m .28772 .63462 L .28837 .63325 L F
.99 .869 .618 r
.60615 .35081 m .60475 .35404 L .60356 .35303 L F
0 .163 .698 r
.66686 .36354 m .66874 .36772 L .66689 .36708 L F
.803 .698 .749 r
.66874 .36772 m .66535 .36978 L .66689 .36708 L F
.66874 .36772 m .6666 .37129 L .66535 .36978 L F
.703 .211 0 r
.34318 .56657 m .34492 .56818 L .34381 .56675 L F
.744 .979 .736 r
.34582 .5636 m .34318 .56657 L .34381 .56675 L F
.703 .211 0 r
.34318 .56657 m .34492 .56818 L .34381 .56675 L F
.925 .745 .639 r
.55798 .44295 m .55952 .44666 L .5574 .44593 L F
.905 .543 .343 r
.55952 .44666 m .5579 .44839 L .5574 .44593 L F
.983 .718 .445 r
.55952 .44666 m .55949 .44966 L .5579 .44839 L F
0 0 0 r
.28445 .59804 m .28125 .59999 L .28362 .59942 L F
0 0 .077 r
.52941 .43727 m .52738 .43998 L .52874 .43924 L F
.1 .006 .451 r
.52874 .43924 m .52738 .43998 L .52885 .44185 L F
.48 .035 .112 r
.34577 .57161 m .34443 .57374 L .34222 .57278 L F
.828 .5 .434 r
.39452 .55888 m .39239 .56089 L .39238 .55756 L F
.39452 .55888 m .39485 .56135 L .39239 .56089 L F
.975 .806 .609 r
.67433 .33765 m .6714 .33902 L .67159 .33631 L F
.67433 .33765 m .67294 .34043 L .6714 .33902 L F
.833 .708 .175 r
.4919 .5513 m .49173 .55151 L .49204 .54966 L F
.4919 .5513 m .49173 .55151 L .49204 .54966 L F
.721 .682 .812 r
.6657 .37295 m .66354 .3748 L .66203 .37234 L F
.93 .783 .677 r
.35746 .62745 m .35797 .62485 L .35606 .62357 L F
.828 .983 .879 r
.6718 .38107 m .67269 .37817 L .6708 .37994 L F
.6718 .38107 m .67479 .37832 L .67269 .37817 L F
.992 .773 .506 r
.34871 .5358 m .34676 .53731 L .3471 .53451 L F
.853 .524 .43 r
.38628 .53572 m .38305 .53507 L .38268 .53227 L F
.848 .612 .582 r
.38621 .5384 m .38305 .53507 L .38628 .53572 L F
.793 .737 .801 r
.36325 .61842 m .36635 .61661 L .36402 .61381 L F
.781 .736 .811 r
.36635 .61661 m .36822 .61442 L .36402 .61381 L F
.586 .256 .377 r
.43638 .56751 m .43747 .56548 L .43388 .56537 L F
.43638 .56751 m .43747 .56548 L .43388 .56537 L F
.817 .836 .864 r
.43794 .56906 m .43377 .56893 L .43638 .56751 L F
.476 .783 .998 r
.438 .56716 m .43794 .56906 L .43638 .56751 L F
.438 .56716 m .44094 .56872 L .43794 .56906 L F
.773 .739 .822 r
.35009 .5425 m .34409 .54395 L .34644 .54213 L F
.338 .817 .785 r
.624 .38397 m .62338 .38399 L .62073 .38497 L F
0 0 0 r
.62592 .38268 m .62636 .38312 L .624 .38397 L F
.28 .781 .777 r
.624 .38397 m .62636 .38312 L .62338 .38399 L F
0 0 0 r
.49322 .43762 m .49479 .43712 L .49352 .43759 L F
.49147 .43774 m .49414 .43724 L .49322 .43762 L F
.49414 .43724 m .49479 .43712 L .49322 .43762 L F
.956 .784 .335 r
.49255 .44009 m .49166 .4413 L .4927 .43783 L F
.49278 .4378 m .4927 .43783 L .49281 .43745 L F
.49255 .44009 m .4927 .43783 L .49278 .4378 L F
0 0 0 r
.49147 .43774 m .49352 .43759 L .49312 .43717 L F
.805 .998 .785 r
.35259 .5698 m .35106 .57076 L .35143 .56815 L F
.705 .73 .87 r
.35143 .56815 m .35579 .56869 L .35259 .5698 L F
.745 .975 .72 r
.47944 .41911 m .47807 .42089 L .47912 .41878 L F
.713 .975 .922 r
.47912 .41878 m .47807 .42089 L .47559 .42094 L F
.445 0 0 r
.33029 .50223 m .33274 .50329 L .33461 .50228 L F
.36 0 0 r
.33274 .50329 m .33675 .50502 L .33461 .50228 L F
.785 .285 0 r
.33461 .50228 m .33675 .50502 L .33886 .50578 L F
.528 .532 .803 r
.28661 .66132 m .28807 .65712 L .28507 .65763 L F
.28661 .66132 m .28912 .66071 L .28807 .65712 L F
.299 .121 .464 r
.2789 .52163 m .27704 .52537 L .27705 .52249 L F
.137 0 .141 r
.64727 .33198 m .64915 .33224 L .64984 .33103 L F
.64727 .33198 m .64679 .33365 L .64915 .33224 L F
.396 0 0 r
.55275 .39905 m .55688 .39903 L .55847 .39732 L F
.007 0 0 r
.55847 .39732 m .55974 .39785 L .55963 .3963 L F
.55847 .39732 m .55688 .39903 L .55974 .39785 L F
.768 .969 .925 r
.6828 .37322 m .6855 .36984 L .68213 .3724 L F
.6828 .37322 m .68639 .37074 L .6855 .36984 L F
.525 .417 .674 r
.27092 .53196 m .26889 .5351 L .26876 .5324 L F
.762 .761 .25 r
.50284 .49936 m .50248 .49976 L .50376 .49815 L F
.50284 .49936 m .502 .5024 L .50248 .49976 L F
.724 .662 .788 r
.25705 .63283 m .25959 .63128 L .25761 .62732 L F
.995 .87 .569 r
.35319 .49603 m .35211 .49916 L .35148 .49603 L F
.734 .991 .848 r
.35319 .49603 m .35148 .49603 L .35417 .49347 L F
.888 .722 .67 r
.47302 .57749 m .4762 .57409 L .47544 .57411 L F
.47302 .57749 m .47588 .57869 L .4762 .57409 L F
.46 .887 .821 r
.41208 .45336 m .4099 .45444 L .40773 .45486 L F
.937 .961 .747 r
.53558 .46344 m .53386 .4671 L .53329 .46426 L F
.953 .948 .651 r
.53241 .4692 m .53329 .46426 L .53386 .4671 L F
.943 .8 .672 r
.72225 .31452 m .72336 .31141 L .72123 .31036 L F
.789 .999 .829 r
.28411 .63255 m .28769 .63124 L .28348 .63459 L F
.547 .802 .992 r
.38842 .50231 m .38593 .50303 L .38664 .50083 L F
.001 .003 .504 r
.24605 .59664 m .24436 .59853 L .24436 .59419 L F
.468 .364 .654 r
.26048 .54492 m .2586 .54357 L .2598 .54204 L F
.742 .748 .856 r
.47547 .55478 m .47946 .55545 L .47856 .55176 L F
.798 .78 .837 r
.47856 .55176 m .47946 .55545 L .48268 .55233 L F
.969 .907 .556 r
.58287 .3608 m .58208 .36707 L .58326 .3649 L F
.987 .714 .369 r
.31777 .55211 m .31805 .55551 L .31669 .55365 L F
.353 .23 .571 r
.32001 .55441 m .31805 .55551 L .31777 .55211 L F
.679 .202 .112 r
.31669 .55365 m .32001 .55441 L .31777 .55211 L F
.497 .611 .896 r
.60899 .44013 m .60441 .43725 L .60795 .43893 L F
.942 .942 .759 r
.6067 .44085 m .60899 .44013 L .60795 .43893 L F
.6067 .44085 m .60681 .44381 L .60899 .44013 L F
.715 .684 .819 r
.66535 .36978 m .6666 .37129 L .66209 .37054 L F
.752 .573 .654 r
.66209 .37054 m .6666 .37129 L .6657 .37295 L F
.823 .713 .743 r
.33222 .6374 m .33629 .63777 L .33475 .63397 L F
.661 .636 .814 r
.33475 .63397 m .33629 .63777 L .33905 .63549 L F
.61 .775 .959 r
.43964 .59703 m .44125 .59884 L .44362 .59793 L F
.887 .468 .197 r
.33731 .50674 m .33886 .50578 L .33675 .50502 L F
.33731 .50674 m .34018 .50863 L .33886 .50578 L F
.936 .602 .377 r
.37307 .51882 m .37115 .51807 L .37086 .51563 L F
.854 .502 .385 r
.37487 .52154 m .37115 .51807 L .37307 .51882 L F
.793 .952 .922 r
.54515 .47985 m .54817 .47909 L .54735 .47826 L F
.79 .841 .89 r
.54817 .47909 m .54987 .47481 L .54735 .47826 L F
.54817 .47909 m .55167 .47634 L .54987 .47481 L F
.301 0 .07 r
.38401 .46365 m .38451 .46498 L .38026 .46616 L F
.556 .033 0 r
.38401 .46365 m .3863 .46509 L .38451 .46498 L F
.804 .88 .901 r
.34327 .63555 m .34592 .63424 L .34364 .63281 L F
.574 .587 .828 r
.34592 .63424 m .34702 .63048 L .34364 .63281 L F
.34592 .63424 m .34808 .63375 L .34702 .63048 L F
.419 0 .005 r
.30673 .68332 m .30647 .68536 L .30398 .68556 L F
.30673 .68332 m .30845 .68337 L .30647 .68536 L F
.467 .281 .544 r
.52626 .40973 m .5237 .4133 L .52355 .41046 L F
.006 0 0 r
.52626 .40973 m .52355 .41046 L .52202 .41158 L F
.966 .658 .387 r
.38268 .53227 m .38082 .53115 L .38067 .52858 L F
.933 .591 .358 r
.38268 .53227 m .38096 .53391 L .38082 .53115 L F
.38268 .53227 m .38305 .53507 L .38096 .53391 L F
.804 .541 .541 r
.67008 .3577 m .66624 .35525 L .66867 .35671 L F
.67008 .3577 m .66585 .3573 L .66624 .35525 L F
0 .313 .77 r
.66904 .35963 m .66585 .3573 L .67008 .3577 L F
.653 .492 .653 r
.54518 .44695 m .54894 .44696 L .5469 .44514 L F
.54518 .44695 m .54571 .44984 L .54894 .44696 L F
.54894 .44696 m .54571 .44984 L .54518 .44695 L F
.166 .426 .863 r
.31375 .54998 m .31421 .54778 L .31148 .54759 L F
.508 .875 .981 r
.63132 .38061 m .62746 .38327 L .63142 .37805 L F
.63132 .38061 m .62862 .38156 L .62746 .38327 L F
.725 .739 .863 r
.31864 .63759 m .3228 .63823 L .32165 .63636 L F
.629 .741 .928 r
.3228 .63823 m .32405 .63552 L .32165 .63636 L F
.3228 .63823 m .32536 .6374 L .32405 .63552 L F
.534 .724 .961 r
.38967 .48874 m .3923 .48824 L .391 .48642 L F
.391 .48642 m .38967 .48874 L .38793 .48813 L F
.391 .48642 m .3923 .48824 L .38967 .48874 L F
.389 .815 .967 r
.38793 .48813 m .3923 .48824 L .38967 .48874 L F
.322 .212 .57 r
.6472 .36146 m .6471 .36461 L .6488 .36049 L F
.549 .684 .928 r
.53969 .41499 m .53845 .41905 L .537 .41592 L F
.044 0 .194 r
.54242 .41707 m .53845 .41905 L .54214 .41763 L F
.549 .684 .928 r
.53969 .41499 m .54214 .41763 L .53845 .41905 L F
.999 .837 .527 r
.6734 .34442 m .6719 .34607 L .67232 .34309 L F
.6734 .34442 m .67262 .34684 L .6719 .34607 L F
.536 .925 .881 r
.29147 .6026 m .29455 .60199 L .2964 .60088 L F
.727 .974 .734 r
.2423 .59431 m .24226 .59315 L .24432 .59295 L F
.114 .666 .741 r
.24226 .59315 m .24363 .59302 L .24432 .59295 L F
.748 .967 .689 r
.24436 .59419 m .24432 .59295 L .24546 .59284 L F
.35 .175 .498 r
.24436 .59419 m .24661 .59409 L .24679 .59119 L F
0 0 .27 r
.24742 .59205 m .24661 .59409 L .24679 .59119 L F
0 0 .001 r
.24742 .59205 m .24605 .59664 L .24661 .59409 L F
0 0 0 r
.24723 .59267 m .24675 .59504 L .24605 .59664 L F
.24742 .59205 m .24728 .59266 L .24723 .59267 L F
.24728 .59266 m .24675 .59504 L .24723 .59267 L F
.748 .967 .689 r
.24546 .59284 m .24432 .59295 L .24679 .59119 L F
.832 .983 .7 r
.24679 .59119 m .24432 .59295 L .2469 .58943 L F
0 0 .386 r
.2469 .58943 m .24742 .59205 L .24679 .59119 L F
.604 .44 .633 r
.24432 .59295 m .24757 .59264 L .2469 .58943 L F
.24757 .59264 m .24781 .59261 L .24772 .59229 L F
.114 .666 .741 r
.2476 .59263 m .24781 .59261 L .24757 .59264 L F
0 0 0 r
.24775 .59244 m .24728 .59266 L .24742 .59205 L F
.24805 .59154 m .24772 .59229 L .24742 .59205 L F
.24859 .5911 m .24768 .59237 L .24805 .59154 L F
.24976 .58918 m .24742 .59205 L .2469 .58943 L F
.24976 .58918 m .24859 .5911 L .24805 .59154 L F
.24959 .58938 m .24805 .59154 L .24742 .59205 L F
.24976 .58918 m .24805 .59154 L .24959 .58938 L F
.24772 .59229 m .24768 .59237 L .24767 .59235 L F
.604 .44 .633 r
.24757 .59264 m .24772 .59229 L .24766 .59208 L F
.2475 .59231 m .24766 .59208 L .2469 .58943 L F
0 0 0 r
.24772 .59229 m .24767 .59235 L .24742 .59205 L F
.604 .44 .633 r
.24757 .59264 m .24766 .59208 L .2475 .59231 L F
.116 .138 .606 r
.2469 .58943 m .24772 .59229 L .24859 .5911 L F
.24772 .59229 m .24781 .59261 L .24859 .5911 L F
.683 .296 0 r
.24763 .59263 m .24859 .5911 L .24781 .59261 L F
0 0 0 r
.24789 .59261 m .24763 .59263 L .24775 .59244 L F
.24763 .59263 m .24728 .59266 L .24775 .59244 L F
.683 .296 0 r
.24552 .59277 m .24859 .5911 L .24763 .59263 L F
0 0 0 r
.24859 .5911 m .24789 .59261 L .24768 .59237 L F
.24789 .59261 m .24675 .59504 L .24728 .59266 L F
.114 .666 .741 r
.24739 .59265 m .2476 .59263 L .24737 .59266 L F
.2476 .59263 m .24757 .59264 L .24737 .59266 L F
.24363 .59302 m .24739 .59265 L .24432 .59295 L F
.24739 .59265 m .24737 .59266 L .24432 .59295 L F
.604 .953 .881 r
.24436 .59419 m .2423 .59431 L .24432 .59295 L F
.001 .003 .504 r
.24605 .59664 m .24436 .59419 L .24661 .59409 L F
.876 .704 .666 r
.36482 .568 m .36902 .56861 L .36725 .56467 L F
.839 .586 .556 r
.36477 .5703 m .36902 .56861 L .36482 .568 L F
.36477 .5703 m .36884 .57133 L .36902 .56861 L F
.808 .682 .725 r
.36725 .56467 m .36902 .56861 L .36965 .56589 L F
.82 .841 .864 r
.66681 .38491 m .66714 .38226 L .6649 .38351 L F
.885 .521 .349 r
.66571 .38538 m .66681 .38491 L .6649 .38351 L F
.896 .807 .753 r
.48265 .54755 m .48475 .54841 L .48354 .54488 L F
.891 .809 .76 r
.48064 .55076 m .48475 .54841 L .48265 .54755 L F
.48064 .55076 m .48268 .55233 L .48475 .54841 L F
.804 .769 .821 r
.48354 .54488 m .48475 .54841 L .48732 .54537 L F
.747 .29 .163 r
.56038 .40638 m .56425 .40706 L .56276 .40838 L F
.686 .917 .588 r
.56425 .40706 m .56139 .41056 L .56276 .40838 L F
.884 .644 .572 r
.36336 .56408 m .36739 .56197 L .36511 .561 L F
.36336 .56408 m .36725 .56467 L .36739 .56197 L F
.621 .884 .556 r
.51612 .3931 m .51572 .39333 L .51792 .39075 L F
0 0 0 r
.54064 .47575 m .53807 .47676 L .53665 .47795 L F
.268 0 0 r
.63342 .33951 m .63751 .33759 L .63477 .33837 L F
.159 0 0 r
.64786 .39889 m .6514 .39949 L .65037 .39897 L F
.427 .867 .797 r
.6514 .39949 m .65312 .39831 L .65037 .39897 L F
.6514 .39949 m .65495 .39791 L .65312 .39831 L F
.858 .786 .779 r
.35004 .6352 m .35067 .63052 L .34808 .63375 L F
.881 .944 .85 r
.56139 .41056 m .55826 .4122 L .56109 .40842 L F
.388 .531 .878 r
.56276 .40838 m .56139 .41056 L .56109 .40842 L F
.923 .916 .529 r
.54269 .41806 m .54242 .41707 L .54214 .41763 L F
.502 .394 .663 r
.54421 .41555 m .54277 .42021 L .54242 .41707 L F
.923 .916 .529 r
.54269 .41806 m .54421 .41555 L .54242 .41707 L F
0 .122 .661 r
.34251 .56337 m .34223 .56302 L .34122 .56324 L F
.885 .715 .665 r
.37287 .59108 m .3712 .5944 L .37463 .59491 L F
.859 .678 .656 r
.37049 .5971 m .37463 .59491 L .3712 .5944 L F
.37049 .5971 m .37273 .5984 L .37463 .59491 L F
.466 .191 .412 r
.32358 .6743 m .32571 .67634 L .3231 .67667 L F
.32358 .6743 m .32604 .67389 L .32571 .67634 L F
0 0 0 r
.62862 .38156 m .62636 .38312 L .62592 .38268 L F
.907 .574 .402 r
.47384 .56777 m .47407 .56994 L .47598 .56855 L F
.958 .689 .484 r
.47407 .56994 m .47594 .57145 L .47598 .56855 L F
.263 .74 .936 r
.63977 .39759 m .64085 .39844 L .64426 .39807 L F
0 0 0 r
.59857 .39352 m .60157 .39065 L .60134 .39175 L F
.549 .588 .845 r
.60168 .3916 m .60353 .39476 L .60095 .39424 L F
.062 0 0 r
.60195 .39129 m .60157 .39065 L .60407 .38969 L F
.60141 .3917 m .60147 .39129 L .60195 .39129 L F
.60147 .39129 m .60157 .39065 L .60195 .39129 L F
.244 .571 .94 r
.60585 .3933 m .60353 .39476 L .60255 .39129 L F
.062 0 0 r
.60134 .39175 m .60135 .39173 L .60141 .3917 L F
.60134 .39175 m .60407 .38969 L .60215 .38989 L F
.244 .571 .94 r
.60367 .39128 m .60255 .39129 L .60215 .38989 L F
.60585 .3933 m .60255 .39129 L .60367 .39128 L F
.549 .588 .845 r
.60215 .38989 m .60255 .39129 L .60168 .3916 L F
.60255 .39129 m .60353 .39476 L .60168 .3916 L F
.062 0 0 r
.60135 .39173 m .60157 .39065 L .60141 .3917 L F
.653 .954 .74 r
.37126 .47464 m .37502 .47182 L .3749 .47263 L F
0 0 .263 r
.3766 .46977 m .37502 .47182 L .37561 .46966 L F
0 0 0 r
.3749 .47263 m .37502 .47182 L .3766 .46977 L F
.78 .711 .787 r
.30918 .53179 m .31024 .53434 L .31328 .53233 L F
.613 .954 .821 r
.28306 .60404 m .28728 .60187 L .28592 .60083 L F
.618 .89 .989 r
.28592 .60083 m .28728 .60187 L .28966 .60075 L F
.439 0 0 r
.61197 .39951 m .60959 .39806 L .60801 .3976 L F
.585 .602 .836 r
.44781 .59823 m .45009 .59684 L .44889 .59382 L F
.44804 .59775 m .44889 .59382 L .44935 .59503 L F
.44781 .59823 m .44788 .59796 L .44804 .59775 L F
.44788 .59796 m .44889 .59382 L .44804 .59775 L F
.334 .4 .781 r
.44896 .59684 m .44781 .59823 L .44935 .59503 L F
.598 .851 .992 r
.44362 .59793 m .44871 .59689 L .44469 .59595 L F
.44871 .59689 m .44896 .59684 L .44877 .5968 L F
.44871 .59689 m .44877 .5968 L .44469 .59595 L F
.62 .834 .982 r
.44362 .59793 m .44781 .59823 L .44896 .59684 L F
.962 .708 .505 r
.44164 .58334 m .44281 .58698 L .44493 .58505 L F
.472 .492 .798 r
.44493 .58505 m .44591 .58054 L .44164 .58334 L F
.44493 .58505 m .44764 .58469 L .44591 .58054 L F
.764 .356 .279 r
.44493 .58505 m .4463 .58696 L .44764 .58469 L F
.44493 .58505 m .44281 .58698 L .4463 .58696 L F
.403 .456 .801 r
.60134 .39175 m .60095 .39424 L .59857 .39352 L F
.93 .783 .677 r
.35746 .62745 m .35606 .62357 L .3536 .62724 L F
.807 .696 .743 r
.3536 .62724 m .35497 .63074 L .35746 .62745 L F
.984 .726 .457 r
.40703 .58777 m .40857 .59161 L .40821 .58982 L F
.723 .729 .855 r
.40703 .58777 m .40821 .58982 L .41188 .58876 L F
.439 .175 .414 r
.40857 .59161 m .41188 .58876 L .40821 .58982 L F
0 0 0 r
.42558 .55058 m .42605 .54804 L .42624 .54817 L F
.659 .567 .741 r
.56094 .36579 m .56458 .36963 L .56237 .3673 L F
.748 .612 .707 r
.35564 .55228 m .3514 .55462 L .35105 .5517 L F
.793 .939 .924 r
.61212 .35063 m .61007 .35133 L .61251 .35028 L F
.61212 .35063 m .61053 .3541 L .61007 .35133 L F
.091 0 .222 r
.25043 .56451 m .24813 .56754 L .24817 .56573 L F
.948 .685 .504 r
.39611 .57412 m .39383 .5744 L .39395 .57108 L F
.944 .894 .749 r
.39611 .57412 m .39245 .57702 L .39383 .5744 L F
.39611 .57412 m .39392 .57813 L .39245 .57702 L F
.804 .994 .868 r
.62813 .38811 m .62472 .38993 L .62699 .3895 L F
.646 .219 .22 r
.62699 .3895 m .63148 .38998 L .62813 .38811 L F
.898 .751 .69 r
.34366 .54219 m .34078 .5443 L .34231 .54107 L F
.34366 .54219 m .34303 .54537 L .34078 .5443 L F
.539 .441 .692 r
.34366 .54219 m .34644 .54213 L .34521 .53919 L F
0 0 .442 r
.34458 .54122 m .34366 .54219 L .34231 .54107 L F
.34458 .54122 m .34409 .54395 L .34366 .54219 L F
.91 .508 .208 r
.65618 .37376 m .65596 .37469 L .65612 .37691 L F
.499 .653 .928 r
.65762 .37131 m .65915 .37387 L .65618 .37376 L F
.964 .937 .696 r
.65819 .37461 m .65714 .3777 L .65516 .37808 L F
.046 0 0 r
.65915 .37387 m .65612 .37691 L .65618 .37376 L F
.499 .653 .928 r
.65762 .37131 m .65618 .37376 L .65596 .37469 L F
.812 .901 .49 r
.60355 .43793 m .60441 .43725 L .6028 .44043 L F
0 .376 .803 r
.6063 .43754 m .60795 .43893 L .60441 .43725 L F
.6063 .43754 m .60441 .43725 L .60355 .43793 L F
.792 .998 .848 r
.5946 .37916 m .59793 .37722 L .59804 .37673 L F
.677 .886 .517 r
.59947 .37458 m .59804 .37673 L .59793 .37722 L F
.649 .616 .803 r
.43694 .59759 m .43423 .59878 L .43269 .59457 L F
.524 .316 .539 r
.43401 .60069 m .43423 .59878 L .43694 .59759 L F
.358 0 0 r
.42735 .60241 m .42949 .60325 L .42742 .60363 L F
.464 .878 .746 r
.45379 .43691 m .44957 .43895 L .45143 .43725 L F
.608 .955 .874 r
.455 .43526 m .45379 .43691 L .45143 .43725 L F
.965 .716 .511 r
.65724 .39268 m .65906 .39034 L .65836 .38897 L F
.65724 .39268 m .6589 .39331 L .65906 .39034 L F
.922 .761 .277 r
.3589 .49218 m .35863 .4953 L .35919 .49522 L F
.469 .879 .741 r
.35919 .49522 m .36075 .49395 L .363 .49307 L F
.468 .873 .714 r
.35919 .49522 m .35863 .4953 L .36075 .49395 L F
.764 .692 .783 r
.63801 .38692 m .64202 .38745 L .64065 .38304 L F
.074 .622 .836 r
.64087 .38709 m .64067 .38727 L .63801 .38692 L F
.152 0 0 r
.63957 .38742 m .64087 .38709 L .63801 .38692 L F
.33 .803 .725 r
.64115 .38683 m .64087 .38709 L .63957 .38742 L F
.787 .704 .773 r
.64065 .38304 m .64202 .38745 L .64468 .38398 L F
.522 .333 .566 r
.64202 .38745 m .64481 .38696 L .64468 .38398 L F
.33 .803 .725 r
.64343 .38598 m .64087 .38709 L .64115 .38683 L F
.074 .622 .836 r
.64087 .38709 m .64202 .38745 L .64067 .38727 L F
.434 .819 .989 r
.64343 .38598 m .64202 .38745 L .64087 .38709 L F
.64343 .38598 m .64481 .38696 L .64202 .38745 L F
.912 .843 .763 r
.57673 .43877 m .5776 .44247 L .58004 .43845 L F
0 0 0 r
.42129 .45208 m .42396 .45145 L .42585 .45049 L F
.333 .784 .634 r
.42585 .45049 m .42623 .45026 L .42839 .4496 L F
.42585 .45049 m .42396 .45145 L .42623 .45026 L F
.153 0 0 r
.60516 .34356 m .60772 .34397 L .60916 .34411 L F
.028 .597 .769 r
.60916 .34411 m .60772 .34397 L .61178 .34423 L F
.939 .708 .562 r
.38956 .54766 m .38755 .54762 L .38794 .54501 L F
.945 .699 .535 r
.38956 .54766 m .38722 .55272 L .38755 .54762 L F
.439 .175 .414 r
.40857 .59161 m .41112 .59103 L .41188 .58876 L F
.789 .296 .028 r
.40703 .58777 m .41112 .59103 L .40857 .59161 L F
0 0 0 r
.44484 .45105 m .44997 .45029 L .44862 .44932 L F
.694 .875 .966 r
.45085 .44773 m .44997 .45029 L .45219 .44905 L F
.746 .928 .949 r
.44862 .44932 m .44997 .45029 L .45085 .44773 L F
0 .365 .751 r
.65724 .35875 m .65687 .35885 L .65607 .35803 L F
.65724 .35875 m .65939 .35986 L .65687 .35885 L F
.865 .77 .754 r
.59634 .38958 m .60061 .39083 L .59972 .38631 L F
.368 0 0 r
.59894 .39076 m .60061 .39083 L .59634 .38958 L F
.052 .186 .685 r
.59972 .38631 m .60061 .39083 L .60219 .38728 L F
.807 .882 .9 r
.59894 .39076 m .60219 .38728 L .60061 .39083 L F
.579 .839 .482 r
.60125 .37244 m .59947 .37458 L .60036 .37364 L F
.716 .976 .921 r
.67269 .37817 m .67479 .37832 L .67694 .37665 L F
.775 .997 .814 r
.49055 .51513 m .48761 .51781 L .48681 .5175 L F
.85 .61 .575 r
.69384 .33063 m .69621 .33162 L .69381 .328 L F
.884 .701 .649 r
.69355 .33305 m .69621 .33162 L .69384 .33063 L F
.69355 .33305 m .69547 .3342 L .69621 .33162 L F
.775 .997 .814 r
.49055 .51513 m .48681 .5175 L .48942 .51425 L F
.88 .474 .25 r
.36834 .49311 m .36916 .49517 L .37089 .49556 L F
.298 0 0 r
.36916 .49517 m .37351 .49664 L .37089 .49556 L F
.52 .308 .532 r
.32584 .57787 m .32872 .57745 L .32599 .57512 L F
.93 .952 .622 r
.3327 .60578 m .3322 .60546 L .33256 .60514 L F
.729 .496 0 r
.33261 .60482 m .3327 .60578 L .33418 .60371 L F
.93 .952 .622 r
.3327 .60578 m .33256 .60514 L .33418 .60371 L F
.729 .496 0 r
.33261 .60482 m .33316 .60788 L .3327 .60578 L F
.33316 .60788 m .33319 .60807 L .3327 .60578 L F
.834 .979 .879 r
.33319 .60807 m .33188 .6076 L .3327 .60578 L F
.887 .546 .398 r
.35005 .51996 m .3503 .52218 L .35235 .52238 L F
.834 .415 .245 r
.3503 .52218 m .35059 .52382 L .35235 .52238 L F
.96 .656 .407 r
.35059 .52382 m .35244 .52507 L .35235 .52238 L F
.796 .701 .76 r
.36402 .61381 m .36822 .61442 L .36854 .61144 L F
.776 .683 .761 r
.25761 .62732 m .25959 .63128 L .26188 .62779 L F
.193 0 0 r
.62391 .34241 m .62796 .34074 L .62515 .34072 L F
.385 0 .055 r
.66437 .33362 m .66035 .33581 L .66137 .3341 L F
.673 .36 .437 r
.41748 .46067 m .41751 .46236 L .41354 .46227 L F
.706 .366 .4 r
.41748 .46067 m .42057 .46328 L .41751 .46236 L F
.528 .25 .437 r
.32978 .6705 m .33204 .67267 L .32933 .67298 L F
.32978 .6705 m .33248 .67018 L .33204 .67267 L F
0 0 0 r
.50626 .4429 m .50999 .4407 L .50891 .44204 L F
.50891 .44204 m .50999 .4407 L .51209 .43942 L F
.599 .84 .99 r
.31552 .51505 m .32004 .51536 L .31803 .51433 L F
.32004 .51536 m .31552 .51505 L .31803 .51433 L F
.672 .72 .885 r
.29449 .65138 m .29052 .65037 L .2929 .64997 L F
.391 .722 .989 r
.29521 .64981 m .29449 .65138 L .2929 .64997 L F
.29521 .64981 m .29679 .65115 L .29449 .65138 L F
.926 .541 .169 r
.57595 .42444 m .57704 .42398 L .57465 .4222 L F
.57595 .42444 m .57763 .42605 L .57704 .42398 L F
.488 .182 .373 r
.27337 .51762 m .27755 .51326 L .27456 .51468 L F
.278 .777 .756 r
.65516 .37808 m .65714 .3777 L .65386 .37869 L F
.65516 .37808 m .65386 .37869 L .65288 .3792 L F
.703 .924 .966 r
.45566 .44695 m .45922 .44655 L .45771 .44536 L F
.76 .905 .94 r
.45771 .44536 m .45922 .44655 L .46163 .44476 L F
.54 .261 .442 r
.53583 .42024 m .53849 .42217 L .5357 .42258 L F
.33 .253 .617 r
.23778 .56555 m .23926 .56528 L .23972 .56079 L F
.328 .244 .607 r
.23778 .56555 m .2399 .56754 L .23926 .56528 L F
.315 0 .247 r
.53196 .43612 m .52941 .43727 L .52874 .43924 L F
.938 .962 .676 r
.30913 .62446 m .30749 .62822 L .30692 .6262 L F
0 0 0 r
.30803 .62814 m .30749 .62822 L .30913 .62446 L F
.81 .548 .543 r
.311 .62433 m .30813 .62828 L .30913 .62446 L F
.30813 .62828 m .30803 .62814 L .30913 .62446 L F
.311 .62433 m .31258 .62804 L .30841 .62855 L F
0 .037 .602 r
.30749 .62822 m .3087 .6294 L .3081 .62824 L F
.81 .548 .543 r
.30813 .62828 m .30841 .62855 L .30788 .62861 L F
.311 .62433 m .30841 .62855 L .30813 .62828 L F
.365 .52 .879 r
.30813 .62828 m .31021 .62819 L .30692 .6262 L F
.812 .854 .88 r
.31258 .62804 m .30876 .62952 L .30843 .62879 L F
.365 .52 .879 r
.30843 .62879 m .3084 .62845 L .30813 .62828 L F
.812 .854 .88 r
.30841 .62855 m .30843 .62879 L .30832 .62856 L F
.31258 .62804 m .30843 .62879 L .30841 .62855 L F
.365 .52 .879 r
.30889 .62958 m .30938 .62906 L .3084 .62845 L F
.30889 .62958 m .3084 .62845 L .30843 .62879 L F
.30938 .62906 m .31021 .62819 L .30813 .62828 L F
.81 .548 .543 r
.30813 .62828 m .30788 .62861 L .30803 .62814 L F
0 .037 .602 r
.30803 .62814 m .3081 .62824 L .30805 .62814 L F
.30749 .62822 m .3081 .62824 L .30803 .62814 L F
.3087 .6294 m .30889 .62958 L .30843 .62879 L F
.3087 .6294 m .30843 .62879 L .30805 .62814 L F
.812 .854 .88 r
.31258 .62804 m .31024 .63105 L .30876 .62952 L F
.3087 .6294 m .30876 .62952 L .30788 .62861 L F
.494 0 0 r
.30788 .62861 m .30889 .62958 L .3087 .6294 L F
.30788 .62861 m .3087 .6294 L .30749 .62822 L F
.812 .854 .88 r
.30832 .62856 m .3087 .6294 L .30788 .62861 L F
0 0 0 r
.30788 .62861 m .30749 .62822 L .30803 .62814 L F
0 .037 .602 r
.30749 .62822 m .30805 .62814 L .30692 .6262 L F
.723 .729 .855 r
.40703 .58777 m .41188 .58876 L .4094 .58524 L F
.571 .658 .896 r
.4094 .58524 m .41188 .58876 L .41301 .58765 L F
0 0 .169 r
.41188 .58876 m .41112 .59103 L .41301 .58765 L F
.748 .792 .889 r
.31592 .54559 m .31242 .54547 L .31515 .54354 L F
.184 .419 .854 r
.31664 .54376 m .31592 .54559 L .31518 .54361 L F
.411 0 .015 r
.31497 .54521 m .31842 .54394 L .31664 .54376 L F
.31842 .54394 m .3203 .54324 L .31664 .54376 L F
.184 .419 .854 r
.31664 .54376 m .31518 .54361 L .31515 .54354 L F
.581 .797 .981 r
.29336 .55513 m .29097 .5559 L .28878 .55409 L F
.28878 .55409 m .29097 .5559 L .29336 .55513 L F
.893 .707 .643 r
.47302 .57749 m .47458 .58165 L .47588 .57869 L F
0 0 0 r
.57139 .40714 m .57072 .40698 L .57293 .40574 L F
.57139 .40714 m .56978 .4087 L .57072 .40698 L F
.893 .961 .832 r
.33838 .53734 m .33964 .53647 L .3403 .53491 L F
.602 .952 .852 r
.49167 .40984 m .48746 .41165 L .49122 .40954 L F
.591 .948 .849 r
.4964 .40691 m .49167 .40984 L .49337 .40805 L F
.591 .947 .838 r
.49167 .40984 m .49122 .40954 L .49337 .40805 L F
.871 .595 .516 r
.68522 .32133 m .68528 .3238 L .68738 .32448 L F
.799 .499 .481 r
.68563 .32651 m .68738 .32448 L .68528 .3238 L F
.68563 .32651 m .6902 .32762 L .68738 .32448 L F
.795 .788 .846 r
.33045 .51566 m .32679 .51579 L .32909 .51505 L F
.97 .704 .471 r
.33045 .51566 m .32909 .51505 L .32918 .5122 L F
.673 .542 .696 r
.33316 .51604 m .33131 .51878 L .33045 .51566 L F
.793 .737 .801 r
.36325 .61842 m .36402 .61381 L .36129 .61703 L F
.477 .46 .76 r
.55942 .37105 m .56094 .36579 L .5589 .36647 L F
.55942 .37105 m .56243 .37022 L .56094 .36579 L F
.442 .336 .639 r
.55942 .37105 m .56242 .37276 L .56243 .37022 L F
.701 .308 0 r
.3986 .58786 m .39819 .58742 L .39679 .58445 L F
.668 .252 0 r
.3986 .58786 m .40019 .59069 L .39819 .58742 L F
0 0 .099 r
.53561 .468 m .53616 .46758 L .5341 .46654 L F
.64 .879 .528 r
.53683 .46706 m .53616 .46758 L .53508 .46924 L F
0 0 .348 r
.53616 .46758 m .53569 .47165 L .53508 .46924 L F
0 0 .099 r
.53642 .46878 m .53569 .47165 L .5359 .46979 L F
.282 .656 .969 r
.53775 .46763 m .5393 .46904 L .53642 .46878 L F
.648 .616 .803 r
.5393 .46904 m .53657 .46874 L .53642 .46878 L F
0 0 .099 r
.53642 .46878 m .53601 .46888 L .53616 .46758 L F
.648 .616 .803 r
.53657 .46874 m .5355 .46863 L .53642 .46878 L F
0 0 .099 r
.53642 .46878 m .5359 .46979 L .53601 .46888 L F
.53642 .46878 m .53616 .46758 L .53561 .468 L F
.708 .17 0 r
.53475 .46825 m .53642 .46878 L .5341 .46654 L F
.282 .656 .969 r
.53691 .46781 m .53642 .46878 L .53475 .46825 L F
.53775 .46763 m .53642 .46878 L .53691 .46781 L F
.64 .879 .528 r
.53885 .46455 m .53616 .46758 L .53683 .46706 L F
0 0 0 r
.53934 .46419 m .53616 .46758 L .53885 .46455 L F
.964 .719 .517 r
.5609 .40327 m .55884 .40466 L .56154 .40419 L F
.792 .313 0 r
.57465 .4222 m .57354 .42027 L .57197 .41915 L F
.858 .626 .586 r
.69371 .35062 m .69141 .34744 L .69124 .35055 L F
.953 .619 .343 r
.69231 .35177 m .69371 .35062 L .69124 .35055 L F
.69231 .35177 m .69453 .35372 L .69371 .35062 L F
.354 .012 .239 r
.5161 .40813 m .51627 .40946 L .51298 .41032 L F
.264 0 .241 r
.51876 .40644 m .51627 .40946 L .5161 .40813 L F
.363 0 0 r
.49493 .44848 m .4954 .4451 L .49436 .44685 L F
.49493 .44848 m .49288 .44869 L .4954 .4451 L F
.49493 .44848 m .49689 .4489 L .49288 .44869 L F
.877 .969 .846 r
.53721 .48664 m .54009 .48347 L .53759 .48388 L F
.724 .949 .649 r
.54009 .48347 m .54145 .4816 L .54099 .48166 L F
.701 .98 .902 r
.54009 .48347 m .54099 .48166 L .53759 .48388 L F
.953 .67 .461 r
.68358 .3217 m .68522 .32133 L .68253 .31964 L F
.68358 .3217 m .68528 .3238 L .68522 .32133 L F
.424 .661 .96 r
.31629 .65721 m .31213 .6551 L .31444 .6544 L F
.715 .803 .92 r
.31717 .65342 m .31629 .65721 L .31444 .6544 L F
.31717 .65342 m .31869 .65591 L .31629 .65721 L F
.485 .899 .893 r
.63995 .34751 m .63733 .34764 L .63576 .34846 L F
.694 .949 .675 r
.64138 .34526 m .63995 .34751 L .64289 .34442 L F
.7 .978 .909 r
.64138 .34526 m .63733 .34764 L .63995 .34751 L F
.608 .943 .94 r
.53231 .48803 m .53721 .48664 L .53587 .48542 L F
.803 .917 .916 r
.53587 .48542 m .53721 .48664 L .53759 .48388 L F
.376 0 0 r
.33295 .53097 m .32941 .53002 L .33208 .52959 L F
.439 0 0 r
.56946 .41781 m .56933 .41748 L .56824 .41561 L F
.56946 .41781 m .57197 .41915 L .56933 .41748 L F
.823 .918 .901 r
.34359 .52632 m .34024 .52636 L .34141 .52469 L F
.554 .056 .026 r
.34255 .55489 m .3442 .55559 L .34661 .55507 L F
.558 .534 .784 r
.34661 .55507 m .34932 .55539 L .34776 .55094 L F
0 .076 .631 r
.34752 .55447 m .34661 .55507 L .3442 .55559 L F
.34752 .55447 m .34841 .5577 L .34661 .55507 L F
.767 .541 .591 r
.69384 .33063 m .69381 .328 L .6902 .32762 L F
.923 .936 .795 r
.6056 .44285 m .60681 .44381 L .6067 .44085 L F
.565 .556 .803 r
.53046 .42707 m .53315 .42634 L .53172 .42221 L F
.961 .876 .706 r
.52309 .3924 m .5261 .3906 L .52246 .3911 L F
.52309 .3924 m .52481 .39419 L .5261 .3906 L F
.555 .038 0 r
.55819 .38889 m .56196 .38925 L .55969 .38786 L F
.465 .189 .41 r
.55969 .38786 m .56196 .38925 L .56275 .38678 L F
.244 .001 .333 r
.51273 .4127 m .5102 .41611 L .51061 .41377 L F
.583 .247 .365 r
.31776 .67723 m .31913 .67982 L .31714 .67977 L F
.31776 .67723 m .32047 .67703 L .31913 .67982 L F
.121 .662 .841 r
.28039 .51112 m .28276 .51109 L .28541 .51146 L F
.519 0 0 r
.28276 .51109 m .28747 .51282 L .28541 .51146 L F
.892 .826 .775 r
.57179 .44569 m .57496 .44592 L .5756 .44361 L F
.88 .848 .808 r
.57258 .44902 m .57496 .44592 L .57179 .44569 L F
.798 .78 .837 r
.47856 .55176 m .48268 .55233 L .48064 .55076 L F
.908 .651 .538 r
.35415 .53155 m .35406 .53422 L .35738 .53493 L F
.953 .789 .642 r
.35387 .53719 m .35738 .53493 L .35406 .53422 L F
.35387 .53719 m .35583 .538 L .35738 .53493 L F
.86 .843 .826 r
.31024 .63105 m .30785 .63432 L .31028 .63382 L F
.571 .623 .865 r
.31028 .63382 m .30889 .62958 L .31024 .63105 L F
.043 0 .356 r
.55531 .36271 m .55666 .36307 L .55666 .36019 L F
.565 .797 .986 r
.51075 .47088 m .5099 .47323 L .50805 .47162 L F
.644 .215 .213 r
.39063 .46324 m .39304 .46537 L .3897 .46488 L F
.579 .363 .552 r
.324 .54633 m .32134 .54428 L .32308 .5451 L F
.974 .753 .544 r
.38794 .54501 m .38657 .54138 L .38788 .54213 L F
.454 .826 .576 r
.6704 .31342 m .67211 .31204 L .67363 .3125 L F
.431 .862 .932 r
.67363 .3125 m .67544 .31105 L .67656 .31224 L F
.67363 .3125 m .67211 .31204 L .67544 .31105 L F
.365 .038 .271 r
.27755 .51326 m .28039 .51112 L .27784 .51239 L F
.382 .416 .772 r
.71255 .30403 m .71337 .30861 L .71528 .30575 L F
.356 .381 .75 r
.71337 .30861 m .71696 .31003 L .71528 .30575 L F
.612 .69 .898 r
.30538 .6543 m .30107 .65167 L .30436 .65228 L F
.412 .587 .914 r
.3064 .65224 m .30538 .6543 L .30436 .65228 L F
.445 .628 .931 r
.30774 .65413 m .30538 .6543 L .3064 .65224 L F
0 0 0 r
.6353 .38649 m .63148 .38998 L .63413 .38911 L F
.487 0 0 r
.63685 .38834 m .6353 .38649 L .63413 .38911 L F
.63685 .38834 m .63801 .38692 L .6353 .38649 L F
.379 0 0 r
.49842 .43576 m .50026 .43643 L .49678 .43559 L F
.312 .354 .745 r
.37701 .46875 m .37561 .46966 L .37455 .46656 L F
0 0 .263 r
.3766 .46977 m .37561 .46966 L .37701 .46875 L F
.931 .83 .723 r
.59932 .42968 m .60098 .42591 L .59957 .42485 L F
.816 .991 .874 r
.68639 .37074 m .68955 .36788 L .68725 .36802 L F
.794 .975 .909 r
.6855 .36984 m .68639 .37074 L .68725 .36802 L F
.707 .788 .915 r
.33905 .63549 m .34327 .63555 L .34069 .63568 L F
.804 .88 .901 r
.34327 .63555 m .34364 .63281 L .34069 .63568 L F
.587 .357 .535 r
.66397 .39683 m .66454 .39733 L .66118 .40042 L F
.431 .459 .788 r
.66697 .39559 m .66397 .39683 L .66363 .39481 L F
0 .244 .759 r
.6664 .39791 m .66397 .39683 L .66697 .39559 L F
.6664 .39791 m .66454 .39733 L .66397 .39683 L F
.539 .529 .793 r
.60106 .36059 m .59863 .36305 L .59823 .363 L F
.493 .31 .56 r
.46112 .58144 m .45846 .58443 L .45663 .58354 L F
.46112 .58144 m .461 .58439 L .45846 .58443 L F
.752 .573 .654 r
.66209 .37054 m .6657 .37295 L .66203 .37234 L F
.808 .762 .81 r
.4867 .54241 m .48354 .54488 L .48732 .54537 L F
.554 .407 .637 r
.63774 .38346 m .63801 .38692 L .64065 .38304 L F
.913 .519 .231 r
.3548 .50228 m .3529 .50143 L .35211 .49916 L F
.726 .207 0 r
.3548 .50228 m .35548 .50413 L .3529 .50143 L F
.3548 .50228 m .35704 .50463 L .35548 .50413 L F
.723 .196 0 r
.35919 .50522 m .35704 .50463 L .3548 .50228 L F
0 0 .475 r
.57274 .36369 m .57312 .36189 L .57218 .35952 L F
0 0 .253 r
.57274 .36369 m .57302 .36429 L .57312 .36189 L F
.57274 .36369 m .57368 .36626 L .57302 .36429 L F
.747 .676 .782 r
.31083 .62028 m .311 .62433 L .30913 .62446 L F
.804 .523 .512 r
.31083 .62028 m .31498 .62399 L .311 .62433 L F
.411 .356 .686 r
.31527 .62719 m .311 .62433 L .31498 .62399 L F
.31527 .62719 m .31258 .62804 L .311 .62433 L F
.936 .9 .765 r
.71199 .29041 m .71098 .29489 L .70958 .29066 L F
.724 .682 .809 r
.71199 .29041 m .71098 .29489 L .70958 .29066 L F
.936 .9 .765 r
.71199 .29041 m .70978 .29339 L .71098 .29489 L F
.757 .949 .626 r
.65052 .38323 m .6477 .38639 L .6503 .38529 L F
0 0 .023 r
.6529 .38174 m .6503 .38529 L .65296 .38416 L F
.851 .567 .508 r
.65293 .38413 m .6529 .38174 L .65296 .38416 L F
0 0 .17 r
.65286 .37922 m .65052 .38323 L .6529 .38174 L F
0 0 .023 r
.6529 .38174 m .65052 .38323 L .6503 .38529 L F
.851 .567 .508 r
.64935 .38052 m .6529 .38174 L .65293 .38413 L F
0 0 .17 r
.65288 .3792 m .65286 .37922 L .6529 .38174 L F
.61 .842 .987 r
.59623 .4012 m .60026 .40152 L .5989 .40017 L F
.511 .793 .996 r
.5989 .40017 m .60026 .40152 L .60331 .40086 L F
.351 .103 .391 r
.66585 .3573 m .6685 .35321 L .66624 .35525 L F
.312 .354 .745 r
.37701 .46875 m .37455 .46656 L .37738 .46671 L F
.408 .062 .263 r
.38026 .46616 m .37701 .46875 L .37738 .46671 L F
.457 .839 .613 r
.64505 .3428 m .64468 .343 L .64289 .34442 L F
0 0 0 r
.64417 .33469 m .64557 .33483 L .64679 .33365 L F
.64417 .33469 m .64291 .3358 L .64557 .33483 L F
.292 .352 .753 r
.57844 .3803 m .57993 .381 L .57907 .37592 L F
.338 .332 .706 r
.57844 .3803 m .58152 .38207 L .57993 .381 L F
.759 .631 .719 r
.26497 .54789 m .26048 .54492 L .26321 .54453 L F
.26497 .54789 m .26095 .54785 L .26048 .54492 L F
.759 .63 .717 r
.26497 .54789 m .2626 .5527 L .26095 .54785 L F
.526 .521 .793 r
.26584 .54384 m .26497 .54789 L .26321 .54453 L F
.26584 .54384 m .26769 .54758 L .26497 .54789 L F
.343 .134 .445 r
.33316 .51604 m .33348 .51916 L .33131 .51878 L F
.246 .4 .82 r
.33348 .51916 m .3338 .52122 L .33131 .51878 L F
.5 .268 .494 r
.51627 .40946 m .51273 .4127 L .51298 .41032 L F
.659 .182 .108 r
.48477 .54013 m .48613 .53875 L .48716 .53705 L F
.486 .248 .478 r
.26378 .53856 m .2628 .54179 L .2598 .54204 L F
.632 .45 .618 r
.26321 .54453 m .2598 .54204 L .2628 .54179 L F
.26321 .54453 m .26048 .54492 L .2598 .54204 L F
0 0 .455 r
.55818 .36272 m .55901 .36475 L .55666 .36019 L F
.959 .787 .626 r
.55666 .36307 m .55901 .36475 L .55818 .36272 L F
.815 .907 .904 r
.26766 .61418 m .27231 .61407 L .26982 .6151 L F
.997 .853 .563 r
.33842 .59051 m .33741 .5942 L .33976 .59158 L F
.228 0 0 r
.33976 .59158 m .33741 .5942 L .34033 .5933 L F
.758 .991 .785 r
.3127 .60252 m .31365 .603 L .31148 .60493 L F
.13 0 0 r
.3149 .60416 m .3142 .60457 L .31668 .6038 L F
.443 .207 .46 r
.31668 .6038 m .3151 .60429 L .31365 .603 L F
.398 0 .14 r
.31148 .60493 m .3142 .60457 L .3149 .60416 L F
.443 .207 .46 r
.31487 .60432 m .3142 .60457 L .31415 .60441 L F
.398 0 .14 r
.31415 .60441 m .3149 .60416 L .31447 .60434 L F
.511 .243 .444 r
.31415 .60441 m .31418 .60449 L .31148 .60493 L F
.31418 .60449 m .3142 .60457 L .31396 .6046 L F
.31418 .60449 m .31396 .6046 L .31148 .60493 L F
.398 0 .14 r
.31148 .60493 m .3134 .6045 L .31415 .60441 L F
.511 .243 .444 r
.31365 .603 m .31415 .60441 L .31148 .60493 L F
0 .439 .742 r
.3127 .60252 m .31668 .6038 L .31365 .603 L F
.577 .784 .977 r
.31668 .6038 m .3151 .60429 L .3127 .60252 L F
.31487 .60433 m .3142 .60457 L .31414 .60448 L F
.459 .881 .776 r
.31447 .60434 m .3149 .60416 L .31471 .60422 L F
.394 0 0 r
.31463 .60425 m .3149 .60416 L .3149 .60432 L F
.398 0 .14 r
.3134 .6045 m .3149 .60416 L .31415 .60441 L F
.443 .207 .46 r
.3151 .60429 m .31415 .60441 L .31365 .603 L F
.394 0 0 r
.31442 .60432 m .31463 .60425 L .31464 .60433 L F
.577 .784 .977 r
.31482 .60409 m .31414 .60448 L .3127 .60252 L F
.459 .881 .776 r
.31447 .60434 m .31471 .60422 L .31442 .60432 L F
.31447 .60434 m .31442 .60432 L .31428 .60441 L F
.394 0 0 r
.31463 .60425 m .3149 .60432 L .3149 .60434 L F
.443 .207 .46 r
.31495 .60434 m .3142 .60457 L .31487 .60432 L F
.577 .784 .977 r
.31495 .60434 m .3142 .60457 L .31487 .60433 L F
.394 0 0 r
.31464 .60433 m .3149 .60434 L .31484 .60572 L F
.31463 .60425 m .3149 .60434 L .31464 .60433 L F
.443 .207 .46 r
.3151 .60429 m .31495 .60434 L .3149 .60432 L F
.13 0 0 r
.3149 .60416 m .31668 .6038 L .3149 .60432 L F
.443 .207 .46 r
.31495 .60431 m .3149 .60432 L .31487 .60432 L F
.3151 .60429 m .3149 .60432 L .31495 .60431 L F
.577 .784 .977 r
.3151 .60429 m .31495 .60434 L .3149 .60434 L F
.13 0 0 r
.3149 .60432 m .31668 .6038 L .3149 .60434 L F
.577 .784 .977 r
.31495 .60432 m .3149 .60434 L .31487 .60433 L F
.3151 .60429 m .3149 .60434 L .31495 .60432 L F
.13 0 0 r
.3149 .60434 m .31668 .6038 L .31484 .60572 L F
.577 .784 .977 r
.3151 .60429 m .31487 .60433 L .31482 .60409 L F
.31487 .60433 m .31416 .60448 L .31442 .60432 L F
.31487 .60433 m .31442 .60432 L .31482 .60409 L F
.31416 .60448 m .31414 .60448 L .31482 .60409 L F
.398 0 .14 r
.31136 .60503 m .31395 .60452 L .31057 .60566 L F
.459 .881 .776 r
.31428 .60441 m .31442 .60432 L .30955 .606 L F
.30954 .60647 m .31447 .60434 L .30955 .606 L F
.394 0 0 r
.30955 .606 m .31442 .60432 L .31484 .60572 L F
.31442 .60432 m .31464 .60433 L .31484 .60572 L F
.398 0 .14 r
.31148 .60493 m .31447 .60434 L .31395 .60452 L F
.31148 .60493 m .31395 .60452 L .31136 .60503 L F
0 .024 .597 r
.30785 .63432 m .30622 .6306 L .30367 .6314 L F
.197 .726 .758 r
.70952 .30332 m .70844 .30341 L .70615 .30394 L F
.889 .634 .547 r
.32226 .50451 m .31935 .50187 L .32334 .50229 L F
.32226 .50451 m .31925 .50482 L .31935 .50187 L F
.852 .446 .268 r
.32226 .50451 m .321 .50695 L .31925 .50482 L F
.32226 .50451 m .32343 .50779 L .321 .50695 L F
.763 .331 0 r
.34807 .58755 m .34731 .58694 L .34662 .58561 L F
.892 .795 .746 r
.34807 .58755 m .34511 .5884 L .34731 .58694 L F
.34807 .58755 m .34639 .59137 L .34511 .5884 L F
.923 .916 .529 r
.54269 .41806 m .54277 .42021 L .54421 .41555 L F
.909 .879 .45 r
.54159 .42177 m .54277 .42021 L .54269 .41806 L F
.543 .83 .998 r
.40655 .55484 m .41074 .55522 L .40982 .55397 L F
.668 .21 .156 r
.40655 .55484 m .40977 .55719 L .41074 .55522 L F
.983 .764 .359 r
.41074 .55522 m .40977 .55719 L .40982 .55397 L F
.693 .979 .894 r
.47436 .43954 m .47837 .43772 L .47561 .43812 L F
.774 .926 .935 r
.47837 .43772 m .47918 .43514 L .47561 .43812 L F
.47837 .43772 m .48062 .43619 L .47918 .43514 L F
.685 .424 .522 r
.70951 .28776 m .71199 .29041 L .71233 .28748 L F
.70951 .28776 m .70958 .29066 L .71199 .29041 L F
.186 0 0 r
.41208 .45336 m .41481 .45289 L .41575 .45212 L F
.188 0 0 r
.41575 .45212 m .41672 .45313 L .4186 .45187 L F
.41575 .45212 m .41481 .45289 L .41672 .45313 L F
.737 .563 .657 r
.46112 .58144 m .46544 .58192 L .46552 .58458 L F
.462 .346 .636 r
.46552 .58458 m .4679 .58381 L .46544 .58192 L F
.46552 .58458 m .4679 .58381 L .46544 .58192 L F
.884 .833 .792 r
.54987 .47481 m .55396 .47268 L .55291 .47189 L F
.54987 .47481 m .55167 .47634 L .55396 .47268 L F
.823 .98 .886 r
.55291 .47189 m .55396 .47268 L .55716 .46985 L F
.756 .673 .77 r
.35067 .63052 m .35497 .63074 L .3536 .62724 L F
.967 .85 .674 r
.39545 .56794 m .39478 .56426 L .3967 .56555 L F
.868 .917 .86 r
.6095 .35288 m .6066 .35611 L .60788 .35745 L F
.704 .882 .493 r
.57511 .40262 m .57654 .40057 L .57541 .40183 L F
.89 .897 .479 r
.57541 .40183 m .57654 .40057 L .57669 .39794 L F
.718 .799 .915 r
.25599 .61376 m .25271 .61623 L .25066 .61382 L F
.173 0 0 r
.25716 .61357 m .25599 .61376 L .25316 .61556 L F
0 .287 .773 r
.25247 .61536 m .25271 .61623 L .25481 .61735 L F
.25066 .61382 m .2518 .61516 L .25247 .61536 L F
.25066 .61382 m .25481 .61735 L .25267 .61587 L F
.173 0 0 r
.25323 .61558 m .25316 .61556 L .25267 .61587 L F
.25716 .61357 m .25316 .61556 L .25323 .61558 L F
0 .287 .773 r
.2518 .61516 m .25271 .61623 L .25247 .61536 L F
.71 .97 .932 r
.61589 .3823 m .6137 .38391 L .61499 .38162 L F
.735 .991 .856 r
.61499 .38162 m .6137 .38391 L .61304 .38345 L F
.628 .124 .033 r
.31935 .50187 m .32152 .5037 L .32334 .50229 L F
.496 0 0 r
.32152 .5037 m .32615 .50245 L .32334 .50229 L F
.585 .591 .825 r
.71673 .32141 m .71844 .31646 L .71545 .31924 L F
.71673 .32141 m .71961 .32052 L .71844 .31646 L F
.135 0 .33 r
.58782 .34426 m .58799 .34433 L .58989 .34284 L F
.421 .811 .988 r
.29336 .55513 m .29582 .55444 L .29755 .55539 L F
.29336 .55513 m .29582 .55444 L .29755 .55539 L F
.785 .943 .928 r
.29832 .55381 m .29582 .55444 L .29755 .55539 L F
.29832 .55381 m .29582 .55444 L .29755 .55539 L F
.617 .946 .762 r
.27069 .60399 m .27361 .60414 L .27098 .60331 L F
.481 .295 .55 r
.26706 .60536 m .27049 .60465 L .26947 .60158 L F
.617 .946 .762 r
.26951 .6067 m .26998 .60641 L .27049 .60465 L F
.453 .216 .463 r
.26951 .6067 m .27078 .60459 L .27049 .60465 L F
.26951 .6067 m .27049 .60465 L .26706 .60536 L F
.531 .319 .536 r
.27062 .60422 m .27098 .60331 L .26947 .60158 L F
.617 .946 .762 r
.26998 .60641 m .27361 .60414 L .27069 .60399 L F
.531 .319 .536 r
.27078 .60459 m .27098 .60331 L .27062 .60422 L F
.617 .946 .762 r
.26951 .6067 m .27023 .6052 L .27069 .60399 L F
.27023 .6052 m .27049 .60465 L .27062 .60422 L F
.481 .295 .55 r
.27049 .60465 m .27062 .60422 L .26947 .60158 L F
.617 .946 .762 r
.27023 .6052 m .27062 .60422 L .27069 .60399 L F
.481 .295 .55 r
.27049 .60465 m .27078 .60459 L .27062 .60422 L F
.905 .859 .785 r
.57091 .44674 m .57258 .44902 L .57179 .44569 L F
.928 .855 .749 r
.57021 .45279 m .57258 .44902 L .57091 .44674 L F
.788 .999 .842 r
.37455 .46656 m .37162 .46803 L .37326 .46554 L F
0 .217 .741 r
.60836 .38462 m .60941 .38675 L .60676 .38458 L F
.60836 .38462 m .60676 .38458 L .60558 .38499 L F
.749 .988 .775 r
.32469 .51801 m .32375 .519 L .3245 .51715 L F
0 0 .394 r
.32433 .52147 m .32494 .51983 L .3245 .51715 L F
0 .05 .611 r
.32494 .51983 m .3243 .51628 L .3245 .51715 L F
.3243 .51628 m .32417 .51558 L .3245 .51715 L F
.749 .988 .775 r
.32679 .51579 m .32469 .51801 L .3245 .51715 L F
0 0 .394 r
.32433 .52147 m .3245 .51715 L .32375 .519 L F
.908 .565 .38 r
.34704 .52011 m .35005 .51996 L .3465 .51797 L F
.34704 .52011 m .3503 .52218 L .35005 .51996 L F
0 0 0 r
.37691 .46308 m .37757 .46318 L .37953 .46154 L F
.37953 .46154 m .38082 .46167 L .3826 .46081 L F
.37953 .46154 m .37757 .46318 L .38082 .46167 L F
.758 .526 .582 r
.27361 .60414 m .26947 .60158 L .27098 .60331 L F
.454 .826 .576 r
.6704 .31342 m .66992 .31376 L .67211 .31204 L F
.494 .071 .165 r
.39637 .51123 m .39804 .51159 L .40067 .50898 L F
.749 .394 .379 r
.40067 .50898 m .39804 .51159 L .40114 .51108 L F
.449 .156 .373 r
.31383 .6834 m .31438 .68083 L .31714 .67977 L F
.539 .881 .632 r
.25795 .55675 m .25994 .5554 L .26014 .55385 L F
.25795 .55675 m .25586 .55858 L .25994 .5554 L F
.428 .192 .453 r
.33528 .51749 m .33348 .51916 L .33316 .51604 L F
.474 .343 .621 r
.70406 .29494 m .70714 .2967 L .70689 .29392 L F
.422 .363 .687 r
.70471 .29769 m .70714 .2967 L .70406 .29494 L F
.729 .549 .648 r
.66209 .37054 m .66203 .37234 L .65915 .37387 L F
.553 .898 .978 r
.66535 .36978 m .66209 .37054 L .66423 .36869 L F
.489 .85 .602 r
.66423 .36869 m .66209 .37054 L .66083 .37139 L F
.629 .95 .759 r
.4652 .42934 m .46135 .43181 L .46475 .42935 L F
.673 .976 .87 r
.46872 .4271 m .4652 .42934 L .46647 .42742 L F
.667 .939 .668 r
.4652 .42934 m .46475 .42935 L .46647 .42742 L F
.53 .5 .768 r
.45155 .58818 m .44938 .59164 L .44963 .58875 L F
.927 .919 .787 r
.56076 .46161 m .55989 .46641 L .56173 .46248 L F
.823 .976 .89 r
.56173 .46248 m .56404 .45847 L .56076 .46161 L F
.56173 .46248 m .56483 .45963 L .56404 .45847 L F
.851 .83 .826 r
.28651 .59096 m .28783 .59313 L .28984 .59143 L F
.81 .988 .729 r
.33271 .54002 m .33189 .54225 L .33409 .54265 L F
.764 .274 .066 r
.38298 .49276 m .38547 .49551 L .38748 .49535 L F
.807 .344 .134 r
.38547 .49551 m .38524 .49646 L .38748 .49535 L F
.828 1 .805 r
.53558 .46344 m .53329 .46426 L .5363 .46119 L F
.938 .822 .703 r
.5219 .39502 m .52481 .39419 L .52309 .3924 L F
.5219 .39502 m .52356 .39688 L .52481 .39419 L F
.827 .685 .706 r
.36067 .54826 m .36034 .55092 L .36423 .55149 L F
.832 .636 .638 r
.36034 .55092 m .36191 .55469 L .36423 .55149 L F
.705 .209 .063 r
.32507 .50931 m .32315 .51045 L .32343 .50779 L F
.32507 .50931 m .32704 .51138 L .32315 .51045 L F
.691 .147 0 r
.32918 .5122 m .32704 .51138 L .32507 .50931 L F
.905 .714 .633 r
.35244 .52507 m .35193 .52792 L .35432 .52876 L F
.911 .644 .52 r
.35182 .53063 m .35432 .52876 L .35193 .52792 L F
.35182 .53063 m .35415 .53155 L .35432 .52876 L F
.891 .763 .715 r
.54635 .39031 m .5422 .39234 L .54457 .39063 L F
.54635 .39031 m .54366 .39313 L .5422 .39234 L F
.754 .522 .58 r
.54635 .39031 m .54646 .39316 L .54366 .39313 L F
.618 .958 .849 r
.54635 .39031 m .54741 .38873 L .549 .38953 L F
.54635 .39031 m .54457 .39063 L .54741 .38873 L F
.513 .347 .593 r
.549 .38953 m .54646 .39316 L .54635 .39031 L F
.649 .874 .982 r
.65384 .36387 m .65262 .36262 L .64999 .36384 L F
.787 .919 .926 r
.6547 .36098 m .65384 .36387 L .65613 .3625 L F
.6547 .36098 m .65262 .36262 L .65384 .36387 L F
.375 .814 .664 r
.43326 .456 m .437 .454 L .4351 .45491 L F
0 0 0 r
.43919 .45259 m .4351 .45491 L .437 .454 L F
.449 .595 .905 r
.71261 .31855 m .71436 .31595 L .71145 .3168 L F
.71261 .31855 m .71545 .31924 L .71436 .31595 L F
.545 .454 .704 r
.6471 .36461 m .64999 .36384 L .6488 .36049 L F
.748 .505 .563 r
.34047 .57031 m .34492 .56818 L .34318 .56657 L F
.34047 .57031 m .3455 .57222 L .34492 .56818 L F
.366 .225 .554 r
.34492 .56818 m .34707 .57039 L .34749 .56751 L F
.805 .975 .903 r
.49548 .50801 m .49779 .50451 L .49875 .50507 L F
.49548 .50801 m .49456 .50716 L .49779 .50451 L F
0 0 0 r
.61975 .36859 m .62312 .36706 L .62073 .36836 L F
.793 .939 .924 r
.61212 .35063 m .6095 .35288 L .61053 .3541 L F
0 0 0 r
.30238 .54823 m .30407 .5472 L .30592 .54494 L F
.593 .173 .214 r
.30592 .54494 m .30407 .5472 L .30811 .54655 L F
.337 .006 .247 r
.33248 .67018 m .33577 .66735 L .33524 .67008 L F
.276 .052 .382 r
.33524 .67008 m .33577 .66735 L .33775 .66654 L F
.604 .427 .616 r
.26889 .5351 m .27084 .53861 L .26597 .53876 L F
.525 .417 .674 r
.27092 .53196 m .27149 .53453 L .26889 .5351 L F
.628 .436 .604 r
.27121 .53726 m .26889 .5351 L .27149 .53453 L F
.27121 .53726 m .27084 .53861 L .26889 .5351 L F
.072 .383 .845 r
.57631 .37471 m .57855 .37422 L .5754 .37263 L F
.57631 .37471 m .57907 .37592 L .57855 .37422 L F
.748 .781 .88 r
.62078 .38181 m .61589 .3823 L .6188 .38091 L F
.407 .858 .884 r
.6188 .38091 m .62287 .38026 L .62078 .38181 L F
0 0 .375 r
.35992 .49008 m .3589 .49218 L .35886 .4917 L F
.35992 .49008 m .35886 .4917 L .35865 .48896 L F
.35992 .49008 m .35865 .48896 L .35621 .49125 L F
.447 .689 .969 r
.35711 .48904 m .36046 .48927 L .35992 .49008 L F
.36046 .48927 m .36179 .48937 L .35992 .49008 L F
.342 .024 .273 r
.26809 .52103 m .27116 .5184 L .26893 .51941 L F
.987 .749 .488 r
.42056 .54038 m .42218 .53872 L .41991 .5378 L F
.42056 .54038 m .42218 .54165 L .42218 .53872 L F
.91 .653 .537 r
.37115 .51807 m .3688 .51448 L .37086 .51563 L F
.772 .358 .265 r
.45724 .57927 m .45915 .58121 L .4555 .5803 L F
.776 .597 .656 r
.53173 .39295 m .53006 .39643 L .53004 .3937 L F
.53173 .39295 m .53006 .39643 L .53004 .3937 L F
.566 .476 .711 r
.33504 .6532 m .3335 .65769 L .33243 .65423 L F
.33504 .6532 m .33615 .65723 L .3335 .65769 L F
.791 .958 .921 r
.51837 .5016 m .52215 .49923 L .52094 .49834 L F
.902 .956 .822 r
.52094 .49834 m .52215 .49923 L .52472 .49582 L F
.238 0 0 r
.43326 .456 m .43181 .45741 L .42931 .45764 L F
0 0 0 r
.43326 .456 m .43347 .45641 L .43181 .45741 L F
.43326 .456 m .4351 .45491 L .43347 .45641 L F
.938 .962 .676 r
.30913 .62446 m .30692 .6262 L .30746 .62336 L F
.914 .889 .793 r
.31083 .62028 m .30913 .62446 L .30746 .62336 L F
.925 .974 .738 r
.66689 .36708 m .66535 .36978 L .66423 .36869 L F
.458 .23 .479 r
.36649 .47935 m .36944 .4789 L .36748 .47717 L F
.36649 .47935 m .36632 .4819 L .36944 .4789 L F
.393 .789 .987 r
.36649 .47935 m .36944 .4789 L .36632 .4819 L F
0 0 0 r
.62073 .38497 m .61965 .38596 L .61763 .38697 L F
.471 .881 .744 r
.62338 .38399 m .61965 .38596 L .62073 .38497 L F
.507 .417 .689 r
.3353 .57207 m .33772 .57133 L .33751 .56761 L F
.407 .858 .884 r
.6188 .38091 m .62293 .37978 L .62287 .38026 L F
.633 .959 .913 r
.62287 .38026 m .62447 .37828 L .62601 .37852 L F
.623 .933 .697 r
.62287 .38026 m .62293 .37978 L .62447 .37828 L F
.577 .337 .516 r
.26552 .54124 m .26378 .53856 L .26597 .53876 L F
.26552 .54124 m .2628 .54179 L .26378 .53856 L F
.956 .945 .646 r
.55674 .41757 m .55862 .41651 L .55732 .41867 L F
.968 .932 .633 r
.55865 .41239 m .55862 .41651 L .55674 .41757 L F
.894 .768 .715 r
.4205 .57266 m .41948 .57454 L .42181 .575 L F
.844 .438 .272 r
.41948 .57454 m .42007 .5766 L .42181 .575 L F
.556 .641 .89 r
.4205 .57266 m .42181 .575 L .42384 .5736 L F
0 0 0 r
.42181 .575 m .42193 .57504 L .42384 .5736 L F
.42181 .575 m .42007 .5766 L .42193 .57504 L F
.676 .977 .858 r
.50389 .40261 m .50495 .40078 L .50763 .40084 L F
.50389 .40261 m .50316 .40234 L .50495 .40078 L F
.702 .478 .58 r
.32915 .59144 m .33321 .59338 L .33142 .59076 L F
.32915 .59144 m .32889 .59438 L .33321 .59338 L F
.896 .598 .474 r
.39238 .55756 m .38929 .55419 L .39264 .55504 L F
.953 .66 .444 r
.36748 .47717 m .36948 .47589 L .3674 .47463 L F
.36748 .47717 m .36944 .4789 L .36948 .47589 L F
.687 .372 0 r
.46837 .53598 m .46929 .53864 L .46875 .53719 L F
.826 .998 .781 r
.68955 .36788 m .69241 .36448 L .69056 .3652 L F
.806 .991 .878 r
.68725 .36802 m .68955 .36788 L .69056 .3652 L F
.468 .834 .583 r
.61507 .38897 m .61735 .38719 L .61664 .3875 L F
.633 .1 0 r
.61664 .3875 m .61793 .38929 L .61608 .38775 L F
.553 .772 .98 r
.61415 .38714 m .61664 .3875 L .61512 .38694 L F
.633 .1 0 r
.61664 .3875 m .61608 .38775 L .61512 .38694 L F
.468 .834 .583 r
.61735 .38719 m .61763 .38697 L .61664 .3875 L F
.643 .304 .382 r
.61965 .38596 m .61664 .3875 L .61763 .38697 L F
.993 .75 .448 r
.68986 .34878 m .69124 .35055 L .69141 .34744 L F
.937 .967 .702 r
.6909 .3462 m .69141 .34744 L .69287 .34445 L F
.96 .919 .569 r
.68986 .34878 m .69141 .34744 L .6909 .3462 L F
.969 .907 .556 r
.58287 .3608 m .58156 .36557 L .58208 .36707 L F
.803 .537 0 r
.58196 .36799 m .58208 .36707 L .58156 .36557 L F
.58196 .36799 m .58251 .36962 L .58208 .36707 L F
.306 .047 .347 r
.3302 .53505 m .3337 .53499 L .33291 .532 L F
0 0 .081 r
.3302 .53505 m .33143 .53629 L .33233 .53578 L F
.33256 .53553 m .33233 .53578 L .33271 .53556 L F
.3302 .53505 m .33233 .53578 L .33256 .53553 L F
.3302 .53505 m .33271 .53556 L .33341 .535 L F
.748 .711 .817 r
.33188 .53632 m .33271 .54002 L .3364 .53655 L F
.33143 .53629 m .33158 .53672 L .33188 .53632 L F
.33158 .53672 m .33271 .54002 L .33188 .53632 L F
.289 0 .025 r
.33143 .53629 m .33245 .53562 L .33314 .53484 L F
.842 .52 .443 r
.33314 .53484 m .33245 .53562 L .32671 .53155 L F
.89 .909 .833 r
.33245 .53562 m .33143 .53629 L .33198 .53573 L F
.842 .52 .443 r
.33245 .53562 m .33216 .53594 L .33183 .53577 L F
.33245 .53562 m .33159 .53582 L .32671 .53155 L F
0 0 .293 r
.33291 .532 m .3337 .53499 L .33387 .53308 L F
.833 .585 .564 r
.33295 .53097 m .33314 .53484 L .32671 .53155 L F
0 0 .293 r
.33291 .532 m .33387 .53308 L .33419 .53024 L F
0 0 .402 r
.33387 .53308 m .33314 .53484 L .33295 .53097 L F
.89 .909 .833 r
.33245 .53562 m .33198 .53573 L .3338 .53384 L F
.671 .894 .542 r
.33309 .53478 m .33314 .53484 L .33387 .53308 L F
.89 .909 .833 r
.3338 .53384 m .33327 .5344 L .33387 .53308 L F
.33327 .5344 m .33143 .53629 L .33387 .53308 L F
.76 .666 .758 r
.33387 .53308 m .33183 .53577 L .33224 .53584 L F
.33387 .53308 m .33224 .53584 L .33307 .53475 L F
.671 .894 .542 r
.3332 .53396 m .3331 .53468 L .33387 .53308 L F
.3331 .53468 m .33309 .53478 L .33387 .53308 L F
.76 .666 .758 r
.33387 .53308 m .33307 .53475 L .3341 .5334 L F
.671 .894 .542 r
.33306 .53472 m .33228 .53576 L .33225 .53583 L F
0 0 .081 r
.33341 .535 m .33271 .53556 L .3337 .53499 L F
.89 .909 .833 r
.3337 .53499 m .33143 .53629 L .33372 .53478 L F
.76 .666 .758 r
.33224 .53584 m .33293 .53637 L .3364 .53655 L F
.33183 .53577 m .33216 .53594 L .33224 .53584 L F
.33216 .53594 m .33293 .53637 L .33224 .53584 L F
.33216 .53594 m .33143 .53629 L .33293 .53637 L F
.289 0 .025 r
.33143 .53629 m .33216 .53594 L .33245 .53562 L F
.76 .666 .758 r
.33183 .53577 m .33143 .53629 L .33216 .53594 L F
.289 0 .025 r
.33143 .53629 m .33168 .53648 L .33216 .53594 L F
.842 .52 .443 r
.33197 .53616 m .33168 .53648 L .33163 .53643 L F
.671 .894 .542 r
.33171 .53643 m .33197 .53616 L .33216 .53594 L F
.33222 .53587 m .33216 .53594 L .33314 .53484 L F
.842 .52 .443 r
.33216 .53594 m .33197 .53616 L .33183 .53577 L F
.671 .894 .542 r
.33171 .53643 m .33216 .53594 L .33222 .53587 L F
.33228 .53576 m .33216 .53593 L .33225 .53583 L F
.33225 .53583 m .33216 .53593 L .33222 .53587 L F
.33279 .53511 m .33222 .53587 L .33249 .53557 L F
.33306 .53472 m .33222 .53587 L .33279 .53511 L F
.33309 .53478 m .33249 .53557 L .33314 .53484 L F
.33306 .53472 m .33249 .53557 L .33309 .53478 L F
.89 .909 .833 r
.33372 .53478 m .33245 .53562 L .3338 .53384 L F
.76 .666 .758 r
.3341 .5334 m .33224 .53584 L .3364 .53655 L F
.983 .697 .372 r
.33236 .53736 m .33191 .53625 L .33371 .53368 L F
.842 .52 .443 r
.33183 .53577 m .33197 .53616 L .33159 .53582 L F
.671 .894 .542 r
.33272 .53469 m .33212 .53571 L .33235 .53551 L F
.842 .52 .443 r
.33197 .53616 m .33163 .53643 L .32671 .53155 L F
.453 0 .042 r
.32781 .5328 m .32505 .53584 L .3238 .53387 L F
.539 .031 0 r
.32671 .53155 m .33168 .53648 L .3278 .53279 L F
.32755 .53251 m .3278 .53279 L .32775 .53274 L F
.32671 .53155 m .3278 .53279 L .32755 .53251 L F
.389 0 0 r
.32878 .53506 m .32505 .53584 L .32822 .53324 L F
.392 .666 .969 r
.32838 .53281 m .33168 .53648 L .33264 .53478 L F
.539 .031 0 r
.32767 .53264 m .32775 .53274 L .32772 .53271 L F
.65 .863 .98 r
.32746 .53057 m .32407 .53066 L .3257 .52917 L F
0 0 0 r
.3257 .52917 m .32407 .53066 L .32746 .53057 L F
.593 .197 .262 r
.32781 .5328 m .3238 .53387 L .32552 .53041 L F
.539 .031 0 r
.32715 .53211 m .32772 .53271 L .32731 .53231 L F
.833 .585 .564 r
.33295 .53097 m .32671 .53155 L .32746 .53057 L F
0 0 0 r
.3257 .52917 m .32746 .53057 L .32671 .53155 L F
.947 .718 .558 r
.3257 .52917 m .32671 .53155 L .32554 .53036 L F
.593 .197 .262 r
.32922 .53243 m .32798 .53276 L .32554 .53036 L F
.392 .666 .969 r
.32772 .53271 m .3278 .53279 L .32824 .53281 L F
.593 .197 .262 r
.32798 .53276 m .32781 .5328 L .32773 .53271 L F
.539 .031 0 r
.32671 .53155 m .32775 .53274 L .32767 .53264 L F
.32671 .53155 m .32772 .53271 L .32715 .53211 L F
.32671 .53155 m .32731 .53231 L .32554 .53036 L F
.593 .197 .262 r
.32798 .53276 m .32773 .53271 L .32554 .53036 L F
.392 .666 .969 r
.32731 .53231 m .32772 .53271 L .32838 .53281 L F
.3278 .53279 m .33168 .53648 L .32838 .53281 L F
.453 0 .042 r
.32798 .53276 m .32822 .53324 L .32781 .5328 L F
.32922 .53243 m .32873 .53283 L .32863 .53282 L F
.32922 .53243 m .32863 .53282 L .32808 .53273 L F
.389 0 0 r
.32915 .53284 m .32873 .53283 L .32922 .53243 L F
.392 .666 .969 r
.32858 .5328 m .32863 .53282 L .33063 .5331 L F
.983 .697 .372 r
.3314 .53369 m .33063 .5331 L .33139 .53356 L F
.392 .666 .969 r
.32872 .53283 m .33189 .53405 L .33068 .53314 L F
.32864 .53282 m .3319 .53406 L .32872 .53283 L F
.983 .697 .372 r
.33264 .53478 m .33139 .53356 L .3329 .5345 L F
.392 .666 .969 r
.3319 .53406 m .33285 .53442 L .33189 .53405 L F
.3319 .53406 m .33189 .53405 L .32872 .53283 L F
.32731 .53231 m .33264 .53478 L .3319 .53406 L F
.983 .697 .372 r
.33173 .5358 m .3314 .53369 L .33264 .53478 L F
.3314 .53369 m .33139 .53356 L .3319 .53406 L F
.3314 .53369 m .3319 .53406 L .33264 .53478 L F
.33173 .5358 m .33063 .5331 L .3314 .53369 L F
.3329 .5345 m .33063 .5331 L .33339 .53362 L F
.392 .666 .969 r
.33068 .53314 m .33285 .53442 L .3307 .53314 L F
.33189 .53405 m .33285 .53442 L .33068 .53314 L F
.32863 .53282 m .32864 .53282 L .32872 .53283 L F
.389 0 0 r
.32914 .53288 m .32873 .53283 L .32915 .53284 L F
.32895 .53405 m .32873 .53283 L .32914 .53288 L F
.32873 .53283 m .32873 .53283 L .32914 .53288 L F
.392 .666 .969 r
.32863 .53282 m .3307 .53314 L .33063 .5331 L F
.389 0 0 r
.32878 .53506 m .32914 .53288 L .33063 .5331 L F
.32914 .53288 m .32922 .53243 L .33063 .5331 L F
.392 .666 .969 r
.32731 .53231 m .32858 .5328 L .33063 .5331 L F
.453 0 .042 r
.32808 .53273 m .32863 .53282 L .32798 .53276 L F
.392 .666 .969 r
.3281 .53277 m .32824 .53281 L .32838 .53281 L F
.32798 .53276 m .32824 .53281 L .3281 .53277 L F
.453 0 .042 r
.32873 .53283 m .32822 .53324 L .32798 .53276 L F
.392 .666 .969 r
.32772 .53271 m .32798 .53276 L .3281 .53277 L F
.389 0 0 r
.32895 .53405 m .32822 .53324 L .32873 .53283 L F
.32878 .53506 m .32822 .53324 L .32895 .53405 L F
.453 0 .042 r
.32822 .53324 m .32505 .53584 L .32781 .5328 L F
.593 .197 .262 r
.32781 .5328 m .32552 .53041 L .32554 .53036 L F
.392 .666 .969 r
.3319 .53406 m .33264 .53478 L .33285 .53442 L F
.671 .894 .542 r
.33285 .53442 m .33264 .53478 L .33272 .53469 L F
.33264 .53478 m .33212 .53571 L .33272 .53469 L F
.33212 .53571 m .33171 .53643 L .33235 .53551 L F
.33235 .53551 m .33171 .53643 L .33216 .53593 L F
.983 .697 .372 r
.33191 .53625 m .33173 .5358 L .3329 .5345 L F
.671 .894 .542 r
.3329 .5345 m .33309 .53478 L .3332 .53396 L F
.3329 .5345 m .33216 .53593 L .33306 .53472 L F
.33285 .53442 m .33272 .53469 L .3329 .5345 L F
.33272 .53469 m .33216 .53593 L .3329 .5345 L F
.983 .697 .372 r
.33191 .53625 m .3329 .5345 L .33371 .53368 L F
.3329 .5345 m .3332 .53396 L .33356 .53376 L F
.671 .894 .542 r
.33285 .53442 m .3329 .5345 L .3332 .53396 L F
.158 0 0 r
.33371 .53368 m .33285 .53442 L .3332 .53396 L F
.33371 .53368 m .3332 .53396 L .33387 .53308 L F
.983 .697 .372 r
.33356 .53376 m .33339 .53362 L .33365 .53366 L F
.3332 .53396 m .33339 .53362 L .33356 .53376 L F
.3329 .5345 m .33365 .53366 L .33371 .53368 L F
.671 .894 .542 r
.33171 .53643 m .33168 .53648 L .33197 .53616 L F
0 0 .081 r
.3302 .53505 m .32958 .53743 L .33143 .53629 L F
.085 .338 .812 r
.56779 .37079 m .5684 .37272 L .5655 .37092 L F
.259 .343 .76 r
.5655 .37092 m .5684 .37272 L .56672 .37292 L F
.97 .788 .602 r
.34255 .55489 m .33955 .55703 L .34022 .55427 L F
.34255 .55489 m .34184 .55959 L .33955 .55703 L F
.088 .45 .882 r
.34269 .55335 m .34255 .55489 L .34022 .55427 L F
.34269 .55335 m .3442 .55559 L .34255 .55489 L F
.653 .923 .975 r
.46765 .44177 m .47159 .44082 L .46907 .44016 L F
.587 .904 .983 r
.46907 .44016 m .47159 .44082 L .47436 .43954 L F
.312 .772 .947 r
.60772 .34397 m .61051 .34365 L .61178 .34423 L F
.102 0 0 r
.61051 .34365 m .61445 .34333 L .61178 .34423 L F
.771 .688 .772 r
.36703 .61045 m .36854 .61144 L .36692 .60776 L F
.796 .701 .76 r
.36402 .61381 m .36854 .61144 L .36703 .61045 L F
.955 .832 .684 r
.44799 .58808 m .44938 .59164 L .44963 .58875 L F
.44963 .58875 m .44938 .59164 L .44799 .58808 L F
.969 .723 .508 r
.28324 .66851 m .28352 .6722 L .28171 .67186 L F
.28352 .6722 m .28358 .67286 L .28171 .67186 L F
.385 0 .078 r
.27998 .67154 m .28171 .67186 L .2794 .67143 L F
.2861 .67266 m .2846 .67131 L .28171 .67186 L F
.2861 .67266 m .28171 .67186 L .27998 .67154 L F
.333 0 0 r
.28195 .66902 m .28452 .66813 L .28324 .66851 L F
.969 .723 .508 r
.28324 .66851 m .28171 .67186 L .28195 .66902 L F
.655 .145 .021 r
.28604 .66999 m .28452 .66813 L .28195 .66902 L F
.682 .965 .934 r
.28647 .66668 m .28452 .66813 L .28604 .66999 L F
0 0 0 r
.50229 .44489 m .50626 .4429 L .50505 .44483 L F
.184 0 0 r
.50505 .44483 m .50626 .4429 L .50891 .44204 L F
.986 .718 .422 r
.39392 .57813 m .39236 .57965 L .39245 .57702 L F
.39392 .57813 m .39391 .5811 L .39236 .57965 L F
.467 .17 .377 r
.26815 .54063 m .26597 .53876 L .27084 .53861 L F
.26815 .54063 m .26552 .54124 L .26597 .53876 L F
.397 .851 .796 r
.4351 .44587 m .43494 .44647 L .43293 .44724 L F
.4351 .44587 m .4373 .44543 L .43494 .44647 L F
.469 .876 .724 r
.46647 .42742 m .47052 .42529 L .46872 .4271 L F
.852 .706 .699 r
.4703 .56432 m .47395 .56529 L .47413 .56241 L F
.539 .32 .53 r
.47163 .56814 m .47395 .56529 L .4703 .56432 L F
.47163 .56814 m .47384 .56777 L .47395 .56529 L F
0 .226 .743 r
.36179 .48937 m .36321 .49098 L .36339 .4918 L F
.731 .987 .793 r
.36357 .49262 m .36339 .4918 L .36569 .49095 L F
.696 .319 .33 r
.36569 .49095 m .36339 .4918 L .36629 .49164 L F
.898 .509 .277 r
.365 .493 m .36629 .49164 L .36339 .4918 L F
0 .226 .743 r
.36321 .49098 m .365 .493 L .36339 .4918 L F
.731 .987 .793 r
.363 .49307 m .36339 .4918 L .36357 .49262 L F
.363 .49307 m .36075 .49395 L .36339 .4918 L F
.512 .052 .098 r
.30845 .68337 m .3092 .68561 L .30647 .68536 L F
.30845 .68337 m .31109 .68351 L .3092 .68561 L F
.876 .527 .384 r
.29124 .67565 m .29228 .67384 L .28999 .6753 L F
.514 .341 .584 r
.29228 .67384 m .29502 .67333 L .2948 .67035 L F
0 0 .267 r
.2948 .67035 m .29511 .67095 L .29514 .67089 L F
.29522 .67114 m .29502 .67333 L .29564 .67195 L F
.2948 .67035 m .29498 .67283 L .29522 .67114 L F
.29498 .67283 m .29502 .67333 L .29522 .67114 L F
0 0 .057 r
.295 .67066 m .29453 .67072 L .2948 .67035 L F
.29514 .67089 m .29453 .67072 L .295 .67066 L F
.29514 .67089 m .29228 .67384 L .29453 .67072 L F
.29609 .66991 m .29514 .67089 L .2948 .67035 L F
0 0 .267 r
.2948 .67035 m .29503 .66987 L .29494 .66935 L F
.29478 .66894 m .29494 .66935 L .29477 .66834 L F
.2948 .67035 m .29494 .66935 L .29478 .66894 L F
0 0 .057 r
.29609 .66991 m .2948 .67035 L .2951 .66974 L F
0 0 .267 r
.29522 .67101 m .29525 .6703 L .29477 .66834 L F
.831 .691 .709 r
.29127 .66907 m .2948 .67035 L .29373 .66681 L F
.183 .283 .733 r
.29373 .66681 m .2948 .67035 L .29477 .66834 L F
0 0 .057 r
.2951 .66974 m .2948 .67035 L .29127 .66907 L F
.55 .056 .036 r
.29513 .66982 m .29609 .66991 L .2951 .66974 L F
.29543 .67008 m .29609 .66991 L .29513 .66982 L F
.648 .943 .701 r
.29523 .67067 m .29514 .67089 L .29609 .66991 L F
.332 .113 .424 r
.29477 .66834 m .29513 .66982 L .29776 .67123 L F
.858 .916 .87 r
.29529 .67061 m .29609 .66991 L .29543 .67008 L F
.332 .113 .424 r
.29513 .66982 m .29525 .6703 L .29543 .67008 L F
.858 .916 .87 r
.29535 .67018 m .29543 .67008 L .29536 .6701 L F
.29529 .67061 m .29543 .67008 L .29535 .67018 L F
.332 .113 .424 r
.29543 .67008 m .29564 .67195 L .29707 .67147 L F
.29525 .6703 m .29564 .67195 L .29543 .67008 L F
.29513 .66982 m .29707 .67147 L .29776 .67123 L F
.55 .056 .036 r
.29525 .67013 m .29543 .67008 L .29513 .66982 L F
.491 .557 .851 r
.29776 .67123 m .29707 .67147 L .29349 .66787 L F
0 0 .267 r
.29514 .67089 m .29564 .67195 L .29554 .67152 L F
.29511 .67095 m .29564 .67195 L .29514 .67089 L F
.491 .557 .851 r
.29707 .67147 m .29564 .67195 L .29512 .67096 L F
.55 .056 .036 r
.29115 .66992 m .29525 .67013 L .29127 .66907 L F
.29358 .67056 m .29525 .67013 L .29115 .66992 L F
.29525 .67013 m .2951 .66974 L .29127 .66907 L F
0 0 .267 r
.2948 .67035 m .29522 .67101 L .29503 .66987 L F
.858 .916 .87 r
.29523 .67067 m .29529 .67061 L .29524 .67062 L F
0 0 .267 r
.29522 .67101 m .29554 .67152 L .29525 .6703 L F
.858 .916 .87 r
.28999 .6753 m .29316 .6725 L .29097 .67124 L F
.29316 .6725 m .29523 .67067 L .29351 .6709 L F
.29316 .6725 m .29351 .6709 L .29097 .67124 L F
.29523 .67067 m .29524 .67062 L .29097 .67124 L F
.29529 .67061 m .29536 .6701 L .29097 .67124 L F
.648 .943 .701 r
.28999 .6753 m .29228 .67384 L .29514 .67089 L F
.28999 .6753 m .29514 .67089 L .29523 .67067 L F
.491 .557 .851 r
.29707 .67147 m .29512 .67096 L .29397 .66878 L F
.29405 .66843 m .29397 .66878 L .29349 .66787 L F
.29707 .67147 m .29397 .66878 L .29405 .66843 L F
.55 .056 .036 r
.29097 .67124 m .29358 .67056 L .29115 .66992 L F
.473 .221 .451 r
.29439 .67598 m .29228 .67384 L .29124 .67565 L F
.29439 .67598 m .29502 .67333 L .29228 .67384 L F
.476 .166 .36 r
.32047 .67703 m .32241 .67895 L .31913 .67982 L F
.32047 .67703 m .3231 .67667 L .32241 .67895 L F
.715 .627 .759 r
.34093 .58266 m .34194 .58559 L .33886 .58546 L F
.346 .456 .83 r
.34119 .58765 m .33886 .58546 L .34194 .58559 L F
.311 .381 .773 r
.34325 .58395 m .34194 .58559 L .34093 .58266 L F
.886 .99 .794 r
.34325 .58395 m .34119 .58765 L .34194 .58559 L F
.902 .956 .822 r
.52094 .49834 m .52472 .49582 L .52387 .49552 L F
.746 .992 .813 r
.52799 .4929 m .52571 .49376 L .52472 .49582 L F
.74 .992 .849 r
.52571 .49376 m .52387 .49552 L .52472 .49582 L F
.351 .103 .391 r
.66585 .3573 m .66786 .35632 L .6685 .35321 L F
.703 .959 .698 r
.66967 .35112 m .6712 .35036 L .6685 .35321 L F
0 0 0 r
.6685 .35321 m .66844 .3553 L .66967 .35112 L F
.6685 .35321 m .66786 .35632 L .66844 .3553 L F
.552 .607 .862 r
.45939 .5477 m .45793 .55181 L .45637 .55067 L F
.45939 .5477 m .46063 .55133 L .45793 .55181 L F
.92 .65 .513 r
.32918 .5122 m .32689 .51333 L .32704 .51138 L F
.32918 .5122 m .32909 .51505 L .32689 .51333 L F
.852 .706 .699 r
.4703 .56432 m .47413 .56241 L .47265 .56065 L F
.657 .697 .876 r
.47265 .56065 m .47413 .56241 L .47696 .56161 L F
.019 .555 .848 r
.6021 .3425 m .60362 .3429 L .60516 .34356 L F
.075 .597 .876 r
.60362 .3429 m .60772 .34397 L .60516 .34356 L F
.521 .333 .566 r
.29992 .55178 m .30266 .55175 L .30238 .54823 L F
.386 .234 .55 r
.30238 .54823 m .30462 .55018 L .30407 .5472 L F
.30238 .54823 m .30266 .55175 L .30462 .55018 L F
.667 .937 .661 r
.46404 .5456 m .46228 .54716 L .46539 .54401 L F
0 0 .167 r
.58251 .38372 m .58267 .3835 L .58191 .38257 L F
.58251 .38372 m .58191 .38257 L .58171 .38239 L F
0 0 .468 r
.58152 .38207 m .58267 .3835 L .58238 .38275 L F
0 0 .086 r
.58125 .38753 m .58238 .38275 L .58267 .3835 L F
.58125 .38753 m .5821 .38558 L .58236 .38294 L F
.58233 .38292 m .58236 .38294 L .58238 .38275 L F
.58125 .38753 m .58236 .38294 L .58233 .38292 L F
0 0 .167 r
.58171 .38239 m .58191 .38257 L .58152 .38207 L F
.58251 .38372 m .583 .38634 L .58267 .3835 L F
.858 .505 .384 r
.36299 .50881 m .36074 .50864 L .35919 .50522 L F
.784 .34 .193 r
.36299 .50881 m .36127 .51025 L .36074 .50864 L F
.706 .232 .122 r
.36299 .50881 m .36528 .51106 L .36127 .51025 L F
.978 .873 .662 r
.39395 .57108 m .39381 .56691 L .39545 .56794 L F
.967 .85 .674 r
.39545 .56794 m .39381 .56691 L .39478 .56426 L F
.945 .583 .236 r
.41296 .52367 m .41529 .52759 L .41563 .52443 L F
.458 .253 .513 r
.66533 .38631 m .6649 .38351 L .6623 .38698 L F
.731 .203 0 r
.6623 .38698 m .66638 .39022 L .66533 .38631 L F
.906 .767 .697 r
.66686 .36354 m .66689 .36708 L .66369 .36558 L F
.925 .974 .738 r
.66689 .36708 m .66423 .36869 L .66369 .36558 L F
.892 .826 .775 r
.57179 .44569 m .5756 .44361 L .57416 .44219 L F
.777 .773 .85 r
.5756 .44361 m .57673 .43877 L .57416 .44219 L F
.5756 .44361 m .5776 .44247 L .57673 .43877 L F
.914 .979 .763 r
.33504 .64898 m .33535 .65037 L .33243 .65423 L F
.673 .479 .615 r
.33535 .65037 m .33504 .6532 L .33243 .65423 L F
.413 .705 .982 r
.33747 .6499 m .33535 .65037 L .33504 .64898 L F
.609 .535 .746 r
.33747 .6499 m .33504 .6532 L .33535 .65037 L F
.932 .812 .705 r
.7215 .31691 m .72225 .31452 L .72058 .31314 L F
.943 .8 .672 r
.72225 .31452 m .72123 .31036 L .72058 .31314 L F
.938 .799 .68 r
.57705 .43362 m .57596 .42928 L .57549 .43211 L F
.961 .823 .662 r
.57549 .43211 m .57636 .43605 L .57705 .43362 L F
.785 .902 .924 r
.51844 .48536 m .51546 .48605 L .5175 .48442 L F
.876 .948 .856 r
.52144 .4821 m .51844 .48536 L .5175 .48442 L F
.769 .332 .213 r
.41935 .56339 m .4213 .56659 L .42299 .56487 L F
.648 .956 .754 r
.42436 .56298 m .42229 .56492 L .42299 .56487 L F
0 0 0 r
.42436 .56298 m .42249 .56518 L .42229 .56492 L F
.42249 .56518 m .4213 .56659 L .42229 .56492 L F
.462 0 0 r
.42191 .56443 m .42229 .56492 L .42299 .56487 L F
.41935 .56339 m .42229 .56492 L .42191 .56443 L F
.608 .869 .529 r
.42299 .56487 m .4213 .56659 L .42436 .56298 L F
.863 .525 .409 r
.3688 .51448 m .36528 .51106 L .36722 .51217 L F
.643 .363 .479 r
.34566 .53796 m .3403 .53491 L .34213 .53414 L F
0 0 .267 r
.3471 .53451 m .34566 .53796 L .34213 .53414 L F
.3471 .53451 m .34676 .53731 L .34566 .53796 L F
.867 .779 .762 r
.34676 .53731 m .34222 .53948 L .34566 .53796 L F
.314 .075 .383 r
.43638 .56751 m .43903 .56416 L .43747 .56548 L F
.43903 .56416 m .43638 .56751 L .43747 .56548 L F
.823 .98 .886 r
.55291 .47189 m .55716 .46985 L .55589 .46852 L F
.902 .939 .825 r
.55842 .46512 m .55716 .46985 L .55989 .46641 L F
.55842 .46512 m .55589 .46852 L .55716 .46985 L F
.747 .799 .894 r
.32889 .59438 m .32866 .59576 L .33321 .59338 L F
.759 .981 .912 r
.50763 .40084 m .50856 .39833 L .50957 .39915 L F
.50763 .40084 m .50495 .40078 L .50856 .39833 L F
.409 .75 .994 r
.57995 .38964 m .58375 .39068 L .58206 .38944 L F
.661 .158 0 r
.58375 .39068 m .58365 .39118 L .58206 .38944 L F
.58375 .39068 m .5852 .39252 L .58365 .39118 L F
.614 .583 .796 r
.54177 .41203 m .54378 .41538 L .54407 .41446 L F
.758 .991 .785 r
.3127 .60252 m .31148 .60493 L .3099 .60356 L F
.698 .253 .192 r
.59125 .43953 m .59003 .44145 L .58747 .43899 L F
.467 .269 .527 r
.59292 .43775 m .59003 .44145 L .59125 .43953 L F
.862 .991 .733 r
.60355 .43793 m .6028 .44043 L .60088 .44174 L F
.743 .45 0 r
.55734 .43604 m .55739 .43697 L .55796 .43444 L F
.969 .841 .43 r
.5574 .43475 m .55796 .43444 L .55739 .43697 L F
.55742 .43181 m .55796 .43444 L .5574 .43475 L F
.731 .94 .617 r
.55904 .43385 m .55796 .43444 L .55962 .43311 L F
.55734 .43604 m .55796 .43444 L .55904 .43385 L F
.743 .45 0 r
.55734 .43604 m .55767 .43755 L .55739 .43697 L F
.508 .459 .738 r
.28011 .60062 m .28065 .60485 L .28306 .60404 L F
.686 .896 .973 r
.66331 .38259 m .66714 .38226 L .66621 .38116 L F
0 0 0 r
.66461 .38217 m .66331 .38259 L .66621 .38116 L F
.436 .752 .994 r
.66236 .3829 m .6649 .38351 L .66331 .38259 L F
.686 .896 .973 r
.66331 .38259 m .6649 .38351 L .66714 .38226 L F
.955 .611 .302 r
.66331 .38259 m .6649 .38351 L .66533 .38631 L F
0 0 0 r
.66251 .38349 m .66331 .38259 L .66461 .38217 L F
.436 .752 .994 r
.66076 .38252 m .66236 .3829 L .66331 .38259 L F
.885 .521 .349 r
.66571 .38538 m .6649 .38351 L .66533 .38631 L F
.067 0 .008 r
.66118 .40042 m .66454 .39733 L .66313 .40038 L F
.182 0 .059 r
.66313 .40038 m .66454 .39733 L .6664 .39791 L F
.396 .689 .978 r
.32297 .65728 m .31869 .65591 L .32142 .65373 L F
.756 .715 .813 r
.32386 .65251 m .32297 .65728 L .32142 .65373 L F
.32386 .65251 m .3252 .65601 L .32297 .65728 L F
.924 .837 .741 r
.31793 .53643 m .31754 .53866 L .31548 .53651 L F
.663 .648 .825 r
.31529 .5325 m .31757 .53589 L .31312 .53505 L F
.31757 .53589 m .31793 .53643 L .31697 .53615 L F
.31757 .53589 m .31697 .53615 L .31312 .53505 L F
.924 .837 .741 r
.31793 .53643 m .31548 .53651 L .31312 .53505 L F
.724 .669 .796 r
.31983 .53495 m .31793 .53643 L .31529 .5325 L F
.857 .849 .834 r
.31548 .53651 m .31914 .5352 L .31784 .53539 L F
.31914 .5352 m .31983 .53495 L .31957 .53501 L F
.31914 .5352 m .31957 .53501 L .31784 .53539 L F
.31548 .53651 m .31754 .53866 L .31983 .53495 L F
.666 .402 .512 r
.34213 .53414 m .34019 .532 L .34275 .53195 L F
.34213 .53414 m .3403 .53491 L .34019 .532 L F
.79 .668 .729 r
.34776 .55094 m .34513 .54708 L .3473 .54836 L F
.437 .271 .558 r
.34961 .54775 m .34776 .55094 L .3473 .54836 L F
.34961 .54775 m .34776 .55094 L .3473 .54836 L F
.92 .892 .785 r
.33271 .54002 m .33409 .54265 L .33454 .53857 L F
.635 .557 .75 r
.62477 .40611 m .62055 .40755 L .62241 .40462 L F
.905 .535 .321 r
.2875 .68008 m .29064 .68394 L .28884 .68305 L F
.613 .047 0 r
.29064 .68394 m .29112 .6853 L .28884 .68305 L F
.29064 .68394 m .29283 .68579 L .29112 .6853 L F
.692 .149 0 r
.28884 .68305 m .29112 .6853 L .2891 .68485 L F
.276 .758 .924 r
.28958 .68486 m .29112 .6853 L .29364 .68499 L F
.2891 .68485 m .29112 .6853 L .28958 .68486 L F
.613 .047 0 r
.29283 .68579 m .29311 .68602 L .29112 .6853 L F
0 0 .064 r
.52721 .44355 m .52528 .4458 L .52648 .4456 L F
0 0 .217 r
.52648 .4456 m .52528 .4458 L .52485 .4505 L F
0 0 .242 r
.23972 .56079 m .24158 .55752 L .23976 .55841 L F
.889 .628 .537 r
.35555 .5408 m .3588 .54456 L .35868 .54202 L F
0 0 0 r
.34315 .57804 m .34493 .57711 L .34623 .57589 L F
.807 .513 .491 r
.34759 .58143 m .3419 .58101 L .34315 .57804 L F
0 0 0 r
.34315 .57804 m .34218 .58036 L .34493 .57711 L F
.34315 .57804 m .34193 .58093 L .34218 .58036 L F
.813 .663 .697 r
.33572 .57697 m .33899 .58417 L .33307 .58055 L F
.33899 .58417 m .33903 .58427 L .33896 .58422 L F
.33899 .58417 m .33896 .58422 L .33307 .58055 L F
.53 .808 .997 r
.33487 .5828 m .33307 .58055 L .33896 .58422 L F
.33892 .58423 m .33896 .58422 L .33903 .58427 L F
.33487 .5828 m .33896 .58422 L .33892 .58423 L F
.974 .91 .684 r
.33868 .58489 m .33662 .5866 L .3375 .58434 L F
.673 .871 .974 r
.33806 .58293 m .33487 .5828 L .33903 .58427 L F
.974 .91 .684 r
.33848 .58426 m .3375 .58434 L .33806 .58293 L F
.33868 .58489 m .3375 .58434 L .33848 .58426 L F
.33886 .58546 m .33834 .58573 L .33868 .58489 L F
.33834 .58573 m .33662 .5866 L .33868 .58489 L F
0 .142 .68 r
.338 .57943 m .33883 .58333 L .33572 .57697 L F
.33883 .58333 m .33903 .58427 L .33878 .5837 L F
.33883 .58333 m .33878 .5837 L .33572 .57697 L F
.733 .96 .942 r
.34093 .58266 m .33891 .58285 L .34218 .58036 L F
.673 .871 .974 r
.33806 .58293 m .33903 .58427 L .338 .57943 L F
.733 .96 .942 r
.33891 .58285 m .33806 .58293 L .33899 .58235 L F
.33891 .58285 m .33899 .58235 L .34218 .58036 L F
.715 .274 .202 r
.338 .57943 m .34218 .58036 L .33806 .58293 L F
.338 .57943 m .33981 .58182 L .34218 .58036 L F
.708 .969 .731 r
.34218 .58036 m .33981 .58182 L .34285 .57885 L F
.34218 .58036 m .34285 .57885 L .34308 .57862 L F
0 0 0 r
.34193 .58093 m .3419 .58101 L .34218 .58036 L F
.396 .433 .781 r
.33104 .60185 m .33261 .60482 L .33418 .60371 L F
.611 .868 .523 r
.62522 .39302 m .62241 .39621 L .62448 .39454 L F
.267 .366 .779 r
.62472 .38993 m .62522 .39302 L .62748 .39171 L F
0 0 0 r
.62748 .39171 m .62522 .39302 L .62448 .39454 L F
.805 .586 .605 r
.34759 .58143 m .34325 .58395 L .3419 .58101 L F
.34759 .58143 m .34662 .58561 L .34325 .58395 L F
.365 .159 .461 r
.35004 .57798 m .34998 .58097 L .34759 .58143 L F
0 .135 .68 r
.2886 .67113 m .28982 .67278 L .29003 .67362 L F
.861 .633 .591 r
.3588 .54456 m .36067 .54826 L .36133 .54471 L F
.876 .948 .856 r
.52144 .4821 m .5175 .48442 L .51974 .48309 L F
.503 .877 .668 r
.52144 .4821 m .51974 .48309 L .52298 .48072 L F
.292 .779 .711 r
.45607 .59371 m .45565 .59367 L .45553 .59367 L F
.45607 .59371 m .46028 .59216 L .45565 .59367 L F
.513 .33 .57 r
.44905 .49572 m .45215 .49758 L .44908 .49869 L F
.423 0 0 r
.45 .49654 m .44905 .49572 L .44908 .49869 L F
.45 .49654 m .45215 .49758 L .44905 .49572 L F
.903 .543 .347 r
.34324 .51415 m .3465 .51797 L .34652 .51564 L F
.337 .436 .815 r
.33104 .60185 m .33418 .60371 L .33276 .59817 L F
.298 0 0 r
.36916 .49517 m .37194 .49626 L .37351 .49664 L F
.584 .057 0 r
.37194 .49626 m .37589 .49649 L .37351 .49664 L F
.287 .163 .532 r
.24098 .54829 m .24277 .54757 L .24267 .54488 L F
.171 .107 .537 r
.24098 .54829 m .2427 .55033 L .24277 .54757 L F
.24098 .54829 m .24079 .55234 L .2427 .55033 L F
.171 0 0 r
.40396 .46216 m .40218 .4639 L .39949 .46451 L F
.361 0 0 r
.40677 .4616 m .40218 .4639 L .40396 .46216 L F
.286 .081 .417 r
.24513 .53514 m .24664 .53709 L .24691 .53432 L F
.24513 .53514 m .24466 .53793 L .24664 .53709 L F
.89 .649 .568 r
.36851 .57415 m .37085 .57495 L .36884 .57133 L F
.931 .726 .605 r
.36834 .57657 m .37085 .57495 L .36851 .57415 L F
.36834 .57657 m .37046 .57781 L .37085 .57495 L F
.499 .87 .981 r
.60616 .38836 m .61063 .38829 L .60941 .38675 L F
.433 .695 .975 r
.61063 .38829 m .61415 .38714 L .60941 .38675 L F
.61063 .38829 m .61507 .38897 L .61415 .38714 L F
.875 .904 .848 r
.34093 .58266 m .33886 .58546 L .33806 .58293 L F
.643 .655 .846 r
.3281 .65369 m .3252 .65601 L .32386 .65251 L F
.415 .809 .987 r
.25354 .53166 m .25613 .53115 L .25778 .53197 L F
.863 .934 .868 r
.25778 .53197 m .25917 .52839 L .25716 .52894 L F
.25778 .53197 m .25613 .53115 L .25917 .52839 L F
.49 .276 .515 r
.27924 .63353 m .28176 .63373 L .27938 .63087 L F
.791 .958 .921 r
.51837 .5016 m .52094 .49834 L .5177 .50116 L F
.8 .994 .873 r
.49875 .50507 m .50091 .50168 L .502 .5024 L F
.49875 .50507 m .49779 .50451 L .50091 .50168 L F
.493 .31 .56 r
.46112 .58144 m .45663 .58354 L .45915 .58121 L F
.46112 .58144 m .46358 .58368 L .461 .58439 L F
.849 .665 .653 r
.37127 .58737 m .37353 .58825 L .37178 .58443 L F
.854 .69 .679 r
.37127 .58737 m .37287 .59108 L .37353 .58825 L F
.915 .786 .306 r
.69287 .34445 m .69296 .34012 L .69215 .3426 L F
.937 .967 .702 r
.6909 .3462 m .69287 .34445 L .69215 .3426 L F
.469 .742 .988 r
.29119 .64848 m .29052 .65037 L .28919 .64857 L F
.29119 .64848 m .2929 .64997 L .29052 .65037 L F
.997 .793 .51 r
.66533 .38631 m .66638 .39022 L .66571 .38538 L F
.927 .919 .787 r
.56076 .46161 m .55842 .46512 L .55989 .46641 L F
.427 0 .091 r
.49244 .5276 m .49672 .52537 L .49519 .52415 L F
.839 .901 .881 r
.49519 .52415 m .49672 .52537 L .49985 .52242 L F
.87 .508 .36 r
.35919 .50522 m .35722 .50707 L .35704 .50463 L F
.35919 .50522 m .36074 .50864 L .35722 .50707 L F
.466 .161 .364 r
.53508 .46924 m .5325 .47188 L .53241 .4692 L F
.53508 .46924 m .53569 .47165 L .5325 .47188 L F
.808 .999 .844 r
.45565 .59367 m .46028 .59216 L .46204 .59029 L F
.918 .851 .761 r
.55949 .44966 m .55852 .45254 L .55593 .45162 L F
.92 .849 .756 r
.55593 .45162 m .55852 .45254 L .55621 .45556 L F
.662 .798 .947 r
.31987 .61946 m .31854 .62148 L .31663 .61949 L F
.552 .112 .158 r
.31723 .62285 m .31854 .62148 L .32007 .62303 L F
.06 0 .22 r
.58799 .34433 m .58743 .34655 L .58989 .34284 L F
.103 0 0 r
.46552 .58458 m .46612 .58585 L .46514 .58771 L F
.46552 .58458 m .4679 .58381 L .46612 .58585 L F
.486 0 0 r
.32615 .50245 m .3284 .50369 L .33029 .50223 L F
0 0 0 r
.3284 .50369 m .33274 .50329 L .33029 .50223 L F
0 0 .203 r
.58751 .40332 m .58709 .4014 L .58645 .3991 L F
0 0 .259 r
.58773 .40585 m .58709 .4014 L .58751 .40332 L F
.582 .655 .887 r
.34105 .6603 m .33615 .65723 L .33876 .65662 L F
.62 .439 .615 r
.34105 .6603 m .34123 .66356 L .33789 .66377 L F
.267 .475 .875 r
.34245 .65992 m .34105 .6603 L .33876 .65662 L F
.352 .235 .578 r
.34327 .66254 m .34105 .6603 L .34245 .65992 L F
.34327 .66254 m .34123 .66356 L .34105 .6603 L F
.784 .534 .557 r
.30535 .58366 m .3096 .58416 L .30976 .5814 L F
.745 .993 .832 r
.65312 .39831 m .65495 .39791 L .65703 .39603 L F
.678 .897 .975 r
.48062 .43619 m .48147 .43377 L .47918 .43514 L F
.48062 .43619 m .48337 .43489 L .48147 .43377 L F
.961 .876 .706 r
.52309 .3924 m .52246 .3911 L .52239 .39153 L F
.867 .964 .634 r
.69314 .36176 m .69241 .36448 L .69461 .36078 L F
.84 .646 .102 r
.69461 .36078 m .69417 .35618 L .6943 .35757 L F
.972 .912 .572 r
.69314 .36176 m .69461 .36078 L .6943 .35757 L F
.948 .687 .508 r
.24063 .60332 m .23835 .59988 L .23835 .60192 L F
.524 .316 .539 r
.43401 .60069 m .43694 .59759 L .43629 .59932 L F
0 0 0 r
.43169 .60269 m .43401 .60069 L .43629 .59932 L F
.967 .711 .279 r
.35276 .57478 m .35345 .57861 L .3527 .57741 L F
.898 .652 .559 r
.35345 .57861 m .35438 .58141 L .35185 .5804 L F
.943 .591 .309 r
.34521 .53919 m .34644 .54213 L .34458 .54122 L F
.34521 .53919 m .34458 .54122 L .34676 .53731 L F
.878 .71 .669 r
.69419 .33566 m .69547 .3342 L .69355 .33305 L F
.785 .909 .926 r
.34644 .54213 m .34409 .54395 L .34458 .54122 L F
.712 .969 .933 r
.631 .40275 m .63212 .4006 L .63034 .40225 L F
.631 .40275 m .63456 .40071 L .63212 .4006 L F
.704 .525 0 r
.58607 .3947 m .58623 .39663 L .58645 .3991 L F
.692 .202 .077 r
.67047 .33482 m .66741 .33531 L .6668 .33394 L F
.67047 .33482 m .67159 .33631 L .66741 .33531 L F
0 .044 .612 r
.53453 .4741 m .53449 .47559 L .5325 .47188 L F
0 .012 .56 r
.53534 .47601 m .53449 .47559 L .53453 .4741 L F
.53534 .47601 m .53665 .47795 L .53449 .47559 L F
.459 .124 .309 r
.34222 .57278 m .3455 .57222 L .34047 .57031 L F
.34222 .57278 m .34443 .57374 L .3455 .57222 L F
.881 .618 .537 r
.40887 .51654 m .40898 .52081 L .41137 .51925 L F
.297 .731 .968 r
.41436 .59801 m .41557 .59865 L .4149 .60016 L F
.817 .372 .18 r
.41557 .59865 m .41713 .60037 L .4149 .60016 L F
.861 .804 .793 r
.59701 .4332 m .59932 .42968 L .59728 .42861 L F
.931 .83 .723 r
.59932 .42968 m .59957 .42485 L .59728 .42861 L F
0 .057 .592 r
.51263 .4352 m .51143 .4365 L .51081 .43251 L F
.125 .371 .83 r
.51263 .4352 m .5145 .43852 L .51143 .4365 L F
.468 .374 .667 r
.5145 .43852 m .51209 .43942 L .51143 .4365 L F
.512 .047 .086 r
.39841 .45738 m .40097 .45773 L .40251 .4558 L F
.324 0 .02 r
.40097 .45773 m .40508 .45526 L .40251 .4558 L F
.969 .747 .548 r
.46929 .53864 m .46681 .53978 L .46875 .53719 L F
.46929 .53864 m .46859 .54134 L .46681 .53978 L F
.246 0 0 r
.65501 .32895 m .65866 .32651 L .65617 .32768 L F
.698 .754 .895 r
.31971 .6524 m .31869 .65591 L .31717 .65342 L F
.31971 .6524 m .32142 .65373 L .31869 .65591 L F
.134 .647 .894 r
.70759 .31236 m .71009 .31235 L .71164 .313 L F
.561 .894 .984 r
.71164 .313 m .71009 .31235 L .71442 .31194 L F
.649 .616 .803 r
.43694 .59759 m .43269 .59457 L .43594 .59405 L F
.674 .598 .762 r
.43767 .5954 m .43694 .59759 L .43594 .59405 L F
.474 .133 .306 r
.43964 .59703 m .43629 .59932 L .43694 .59759 L F
.721 .713 .843 r
.31864 .63759 m .31954 .63312 L .31686 .63606 L F
.31864 .63759 m .32165 .63636 L .31954 .63312 L F
.861 .804 .793 r
.59701 .4332 m .59728 .42861 L .59577 .43187 L F
.524 .312 .534 r
.54631 .40593 m .54649 .40894 L .54901 .40572 L F
.881 .887 .833 r
.58628 .37645 m .58795 .37699 L .58905 .37552 L F
.916 .543 .302 r
.58628 .37645 m .58656 .37847 L .58795 .37699 L F
.485 .13 .288 r
.58656 .37847 m .5896 .37603 L .58795 .37699 L F
.716 .892 .96 r
.29032 .57994 m .28801 .58089 L .29033 .58133 L F
.164 .265 .722 r
.29046 .58252 m .29032 .57994 L .29033 .58133 L F
.96 .919 .568 r
.52467 .45314 m .52556 .45284 L .52396 .45416 L F
.627 .942 .726 r
.52706 .45098 m .52556 .45284 L .52467 .45314 L F
.595 .886 .583 r
.52396 .45416 m .52556 .45284 L .52706 .45098 L F
.545 .91 .726 r
.66005 .38271 m .65861 .38406 L .66076 .38252 L F
.488 .823 .528 r
.65682 .38568 m .65861 .38406 L .66005 .38271 L F
.281 .048 .372 r
.70615 .30394 m .70888 .30055 L .70551 .30147 L F
.02 0 .202 r
.28024 .52236 m .2789 .52163 L .28012 .52028 L F
.058 0 .209 r
.28407 .51654 m .28012 .52028 L .28184 .51848 L F
.691 .613 .764 r
.28302 .51973 m .28024 .52236 L .28012 .52028 L F
.784 .643 .706 r
.58625 .35577 m .58478 .35208 L .58618 .35372 L F
.742 .85 .93 r
.58941 .3519 m .58618 .35372 L .58478 .35208 L F
.704 .552 .678 r
.59182 .35626 m .58943 .35759 L .58618 .35372 L F
.465 .626 .922 r
.29457 .65744 m .29616 .66044 L .29852 .65945 L F
0 0 .141 r
.29616 .66044 m .2964 .66153 L .29852 .65945 L F
.29619 .66061 m .29675 .66355 L .2964 .66153 L F
.91 .848 .397 r
.2964 .66153 m .29675 .66355 L .29601 .6659 L F
.2964 .66153 m .29601 .6659 L .29484 .66545 L F
.884 .776 .737 r
.2964 .66153 m .29211 .66433 L .29436 .66229 L F
.2964 .66153 m .29484 .66545 L .29211 .66433 L F
.139 0 0 r
.2966 .66238 m .2964 .66153 L .29436 .66229 L F
.29708 .6624 m .2964 .66153 L .2966 .66238 L F
0 0 .141 r
.29616 .66044 m .29619 .66061 L .2964 .66153 L F
.768 .652 .095 r
.55977 .42876 m .55962 .43311 L .55956 .43183 L F
.889 .956 .615 r
.55962 .43311 m .55796 .43444 L .55956 .43183 L F
.709 .937 .627 r
.47293 .583 m .472 .58481 L .47458 .58165 L F
.057 0 0 r
.65638 .33764 m .6548 .33717 L .65762 .33669 L F
.65638 .33764 m .65362 .33846 L .6548 .33717 L F
.521 .908 .765 r
.44543 .44112 m .44728 .44044 L .44392 .44251 L F
.521 .918 .86 r
.44543 .44112 m .44392 .44251 L .44301 .44242 L F
.686 .756 .905 r
.32536 .6374 m .32636 .63346 L .32405 .63552 L F
.32536 .6374 m .32793 .63626 L .32636 .63346 L F
.879 .71 .668 r
.36314 .56684 m .36725 .56467 L .36336 .56408 L F
.36314 .56684 m .36482 .568 L .36725 .56467 L F
.914 .844 .393 r
.5219 .39502 m .52148 .39979 L .52356 .39688 L F
.5219 .39502 m .52071 .39912 L .52148 .39979 L F
.513 .412 .678 r
.59177 .36363 m .5926 .3669 L .59469 .36561 L F
.932 .812 .705 r
.7215 .31691 m .72058 .31314 L .71844 .31646 L F
.891 .763 .714 r
.71961 .32052 m .7215 .31691 L .71844 .31646 L F
.764 .314 .181 r
.42217 .54442 m .4237 .54661 L .4254 .54508 L F
.835 .525 .465 r
.42585 .56416 m .42964 .56761 L .42972 .56487 L F
.568 .067 .023 r
.4254 .54508 m .4237 .54661 L .42668 .54648 L F
.233 .504 .904 r
.33321 .59338 m .33571 .59423 L .33543 .59269 L F
.118 .147 .615 r
.33321 .59338 m .33455 .59448 L .33571 .59423 L F
.247 0 .07 r
.33571 .59423 m .33562 .59535 L .33659 .59458 L F
.272 0 0 r
.33659 .59458 m .33557 .59509 L .33571 .59423 L F
.118 .147 .615 r
.33455 .59448 m .33468 .59668 L .33557 .59542 L F
.84 .751 .764 r
.33659 .59458 m .33557 .5965 L .33557 .59509 L F
.118 .147 .615 r
.33557 .59532 m .33557 .59542 L .33562 .59535 L F
.33455 .59448 m .33557 .59542 L .33557 .59532 L F
.33445 .59474 m .33369 .59807 L .33468 .59668 L F
.33442 .59472 m .33369 .59807 L .33445 .59474 L F
.33441 .59437 m .33468 .59668 L .33455 .59448 L F
.33437 .59459 m .33369 .59807 L .33444 .59462 L F
.33348 .59605 m .33369 .59807 L .33441 .59437 L F
.77 .675 .758 r
.33276 .59817 m .33513 .59583 L .33369 .59807 L F
.84 .751 .764 r
.33557 .5965 m .33435 .59879 L .33557 .59509 L F
.77 .675 .758 r
.33513 .59583 m .33562 .59535 L .33557 .59542 L F
.33513 .59583 m .33557 .59542 L .33369 .59807 L F
.84 .751 .764 r
.33557 .59509 m .33542 .59557 L .33412 .59582 L F
.33542 .59557 m .33435 .59879 L .33513 .59583 L F
.77 .675 .758 r
.33513 .59583 m .33435 .59879 L .33562 .59535 L F
.33276 .59817 m .33435 .59879 L .33513 .59583 L F
.84 .751 .764 r
.33513 .59583 m .33435 .59879 L .33419 .59672 L F
.33542 .59557 m .33419 .59672 L .33412 .59582 L F
.272 0 0 r
.33557 .59509 m .33412 .59582 L .33502 .59491 L F
.33512 .59494 m .33502 .59491 L .33571 .59423 L F
.378 0 .013 r
.33571 .59423 m .33502 .59491 L .33456 .59468 L F
.33571 .59423 m .33456 .59468 L .33455 .59448 L F
.118 .147 .615 r
.33455 .59448 m .33512 .59494 L .33571 .59423 L F
.33512 .59494 m .33562 .59535 L .33571 .59423 L F
.272 0 0 r
.33557 .59509 m .33512 .59494 L .33571 .59423 L F
.118 .147 .615 r
.33444 .59462 m .33442 .59472 L .33445 .59474 L F
.33441 .59437 m .33437 .59459 L .33444 .59462 L F
.33321 .59338 m .33348 .59605 L .33441 .59437 L F
.378 0 .013 r
.33456 .59468 m .33412 .59582 L .33159 .59585 L F
.33502 .59491 m .33412 .59582 L .33456 .59468 L F
.33455 .59448 m .33159 .59585 L .33156 .59512 L F
.33456 .59468 m .33159 .59585 L .33455 .59448 L F
.33571 .59423 m .33156 .59512 L .33152 .59396 L F
.33571 .59423 m .33453 .59415 L .33543 .59269 L F
.33453 .59415 m .33152 .59396 L .33531 .59272 L F
.33453 .59415 m .33531 .59272 L .33543 .59269 L F
.773 .703 .785 r
.34702 .63048 m .34808 .63375 L .35067 .63052 L F
.802 .559 .571 r
.68753 .3298 m .6902 .32762 L .68563 .32651 L F
.77 .504 .533 r
.68753 .3298 m .69178 .33041 L .6902 .32762 L F
.767 .541 .591 r
.69384 .33063 m .6902 .32762 L .69178 .33041 L F
0 .313 .77 r
.66904 .35963 m .66868 .35892 L .66585 .3573 L F
.842 .995 .754 r
.66605 .36223 m .66904 .35963 L .66686 .36354 L F
.66605 .36223 m .66868 .35892 L .66904 .35963 L F
.596 .337 .494 r
.33789 .66377 m .34053 .66626 L .33775 .66654 L F
.33789 .66377 m .34123 .66356 L .34053 .66626 L F
.719 .959 .945 r
.66579 .39191 m .66363 .39481 L .66258 .39501 L F
.66579 .39191 m .66668 .39284 L .66363 .39481 L F
.431 .459 .788 r
.66697 .39559 m .66363 .39481 L .66668 .39284 L F
.853 .513 .408 r
.38067 .52858 m .3784 .53047 L .37731 .52766 L F
.897 .591 .46 r
.38082 .53115 m .3784 .53047 L .38067 .52858 L F
.935 .689 .543 r
.33761 .51871 m .3372 .52138 L .33528 .51749 L F
.366 .066 .316 r
.5237 .4133 m .52591 .41468 L .52329 .41536 L F
.5237 .4133 m .52624 .41249 L .52591 .41468 L F
.467 .281 .544 r
.52626 .40973 m .52624 .41249 L .5237 .4133 L F
.569 .845 .504 r
.54421 .41555 m .54678 .41254 L .54378 .41538 L F
.05 0 0 r
.28507 .65763 m .28535 .6582 L .28307 .65639 L F
.28507 .65763 m .28807 .65712 L .28535 .6582 L F
.836 .656 .659 r
.35106 .57076 m .34749 .56751 L .35143 .56815 L F
.942 .784 .657 r
.47042 .56772 m .47163 .56814 L .4703 .56432 L F
.936 .614 .402 r
.47042 .56772 m .47054 .57004 L .47163 .56814 L F
.632 .21 .225 r
.47163 .56814 m .47407 .56994 L .47384 .56777 L F
.47163 .56814 m .47054 .57004 L .47407 .56994 L F
.708 .927 .598 r
.51691 .41357 m .5145 .41669 L .51587 .41443 L F
0 0 0 r
.51587 .41443 m .5145 .41669 L .51375 .41848 L F
.76 .905 .94 r
.45771 .44536 m .46163 .44476 L .46008 .44397 L F
.742 .968 .933 r
.46163 .44476 m .46337 .44209 L .46008 .44397 L F
.46163 .44476 m .46455 .44272 L .46337 .44209 L F
.702 .961 .944 r
.45219 .44905 m .45318 .44678 L .45085 .44773 L F
.45219 .44905 m .45566 .44695 L .45318 .44678 L F
.881 .887 .833 r
.58628 .37645 m .58905 .37552 L .58661 .37313 L F
.451 .457 .773 r
.70891 .31682 m .71009 .31235 L .70759 .31236 L F
.70891 .31682 m .71145 .3168 L .71009 .31235 L F
.306 .017 .299 r
.38298 .49276 m .38017 .49561 L .38338 .49415 L F
.76 .293 .136 r
.38338 .49415 m .38547 .49551 L .38298 .49276 L F
.594 .77 .964 r
.31213 .6551 m .30774 .65413 L .31049 .65381 L F
.517 .799 .997 r
.31444 .6544 m .31213 .6551 L .31049 .65381 L F
0 0 0 r
.28783 .6777 m .28784 .679 L .28736 .67702 L F
.668 .58 .748 r
.28609 .67733 m .28774 .67963 L .28726 .67777 L F
.28774 .67963 m .28885 .68117 L .28784 .679 L F
0 0 0 r
.28783 .6777 m .2875 .68008 L .28777 .67945 L F
.668 .58 .748 r
.28774 .67963 m .28784 .679 L .28726 .67777 L F
0 0 0 r
.28784 .679 m .28777 .67945 L .28784 .67929 L F
.28783 .6777 m .28777 .67945 L .28784 .679 L F
.28784 .679 m .28784 .67917 L .28777 .67886 L F
.28784 .679 m .28777 .67886 L .28736 .67702 L F
.668 .58 .748 r
.28785 .67977 m .28841 .68214 L .28885 .68117 L F
.653 .294 0 r
.28777 .67945 m .28841 .68214 L .28784 .67929 L F
.2875 .68008 m .28884 .68305 L .28841 .68214 L F
.2875 .68008 m .28841 .68214 L .28777 .67945 L F
.668 .58 .748 r
.28609 .67733 m .28841 .68214 L .28785 .67977 L F
0 0 0 r
.28784 .67917 m .28778 .67903 L .28736 .67702 L F
.713 .512 .616 r
.28609 .67733 m .28695 .67688 L .28602 .67499 L F
.82 .453 0 r
.28602 .67499 m .28621 .67527 L .28643 .67583 L F
.2873 .67778 m .28736 .67702 L .28773 .67877 L F
.713 .512 .616 r
.2869 .67691 m .28698 .67695 L .28695 .67688 L F
.82 .453 0 r
.28621 .67527 m .28649 .67571 L .2873 .67778 L F
.28649 .67571 m .28736 .67702 L .2873 .67778 L F
.827 .924 .898 r
.29003 .67362 m .28736 .67702 L .28602 .67499 L F
.713 .512 .616 r
.28695 .67688 m .28992 .67877 L .28999 .6753 L F
.28698 .67695 m .28992 .67877 L .28695 .67688 L F
.28695 .67688 m .28999 .6753 L .28602 .67499 L F
.82 .453 0 r
.28602 .67499 m .28643 .67583 L .28784 .67929 L F
.668 .58 .748 r
.28726 .67777 m .28773 .67877 L .2873 .67778 L F
.82 .453 0 r
.28621 .67527 m .28773 .67877 L .28784 .67929 L F
.668 .58 .748 r
.2873 .67778 m .28885 .68117 L .28992 .67877 L F
.28773 .67877 m .28885 .68117 L .2873 .67778 L F
.713 .512 .616 r
.28609 .67733 m .28726 .67777 L .2869 .67691 L F
.28726 .67777 m .28992 .67877 L .2869 .67691 L F
0 0 0 r
.28784 .67917 m .28784 .67929 L .28778 .67903 L F
.405 .176 .449 r
.35276 .57478 m .35004 .57798 L .34888 .57474 L F
.35276 .57478 m .3527 .57741 L .35004 .57798 L F
.626 .365 .503 r
.35185 .5804 m .35004 .57798 L .3527 .57741 L F
.35185 .5804 m .34998 .58097 L .35004 .57798 L F
.281 .048 .372 r
.70615 .30394 m .70844 .30341 L .70888 .30055 L F
.669 .935 .968 r
.62406 .36993 m .62078 .3692 L .62015 .37095 L F
.118 .166 .637 r
.62476 .36637 m .62406 .36993 L .62312 .36706 L F
.62476 .36637 m .62596 .36864 L .62406 .36993 L F
.448 .854 .967 r
.62596 .36864 m .62078 .3692 L .62406 .36993 L F
.852 .954 .879 r
.56506 .45694 m .56483 .45963 L .56797 .45632 L F
.903 .978 .799 r
.56404 .45847 m .56483 .45963 L .56506 .45694 L F
.311 0 0 r
.44331 .58884 m .44799 .58808 L .4463 .58696 L F
.44331 .58884 m .44582 .58903 L .44799 .58808 L F
.837 .999 .789 r
.44799 .58808 m .44582 .58903 L .44684 .58782 L F
.955 .832 .684 r
.44799 .58808 m .44868 .58823 L .4463 .58696 L F
.837 .999 .789 r
.44799 .58808 m .44684 .58782 L .4487 .58561 L F
.955 .832 .684 r
.44799 .58808 m .44963 .58875 L .44868 .58823 L F
.44963 .58875 m .44799 .58808 L .44918 .58671 L F
.816 .99 .734 r
.52869 .49071 m .52799 .4929 L .52911 .49123 L F
.808 1 .81 r
.52869 .49071 m .52571 .49376 L .52799 .4929 L F
.639 .077 0 r
.4131 .59697 m .41093 .59655 L .40838 .59448 L F
.597 .024 0 r
.4131 .59697 m .41436 .59801 L .41093 .59655 L F
.616 .852 .988 r
.35438 .58141 m .34998 .58097 L .35185 .5804 L F
.537 .925 .839 r
.33014 .54305 m .32794 .54436 L .33205 .54267 L F
.572 .756 .965 r
.31669 .55365 m .31805 .55551 L .32001 .55441 L F
0 0 0 r
.31788 .55653 m .31805 .55551 L .32001 .55441 L F
.372 .541 .893 r
.61975 .36859 m .62015 .37095 L .61851 .37049 L F
.603 .634 .854 r
.60727 .40152 m .60801 .3976 L .60598 .39975 L F
.60727 .40152 m .61019 .40075 L .60801 .3976 L F
.825 .66 .677 r
.36985 .58069 m .37224 .58163 L .37046 .57781 L F
.895 .738 .68 r
.36955 .58362 m .37224 .58163 L .36985 .58069 L F
.36955 .58362 m .37178 .58443 L .37224 .58163 L F
.153 .644 .917 r
.27924 .63353 m .28348 .63459 L .28176 .63373 L F
.27924 .63353 m .28348 .63459 L .28176 .63373 L F
.789 .999 .829 r
.28411 .63255 m .28348 .63459 L .28176 .63373 L F
.498 .845 .995 r
.28176 .63373 m .28348 .63459 L .28593 .63391 L F
.681 .861 .968 r
.52738 .47625 m .52311 .47618 L .52586 .47488 L F
.813 .896 .901 r
.53012 .47391 m .52738 .47625 L .52586 .47488 L F
.92 .581 .38 r
.39679 .58445 m .39445 .58364 L .39391 .5811 L F
.729 .216 0 r
.39819 .58742 m .39445 .58364 L .39679 .58445 L F
.46 .887 .821 r
.41208 .45336 m .40773 .45486 L .4105 .45475 L F
.188 0 0 r
.41307 .45434 m .41208 .45336 L .4105 .45475 L F
.41307 .45434 m .41481 .45289 L .41208 .45336 L F
.761 .383 0 r
.59282 .40482 m .59316 .40455 L .59206 .40307 L F
.665 .83 .405 r
.59338 .40437 m .59316 .40455 L .59265 .40561 L F
0 0 .214 r
.59231 .40842 m .59265 .40561 L .59316 .40455 L F
.761 .383 0 r
.59308 .40543 m .59316 .40455 L .59282 .40482 L F
.665 .83 .405 r
.59392 .40344 m .59316 .40455 L .59338 .40437 L F
.831 .953 .896 r
.5951 .40034 m .59623 .4012 L .59418 .40047 L F
.5951 .40034 m .59496 .40071 L .59623 .4012 L F
.748 .846 .4 r
.59496 .40071 m .59316 .40455 L .59392 .40344 L F
.5951 .40034 m .595 .40056 L .59496 .40071 L F
.562 .896 .983 r
.59418 .40047 m .59623 .4012 L .59432 .40046 L F
.748 .846 .4 r
.595 .40056 m .59316 .40455 L .59496 .40071 L F
.562 .896 .983 r
.59503 .40041 m .59623 .4012 L .5989 .40017 L F
.888 .873 .816 r
.59272 .39993 m .5951 .40034 L .59418 .40047 L F
.562 .896 .983 r
.59428 .40041 m .5989 .40017 L .59738 .39853 L F
.59418 .40047 m .59435 .40046 L .59428 .40041 L F
.59435 .40046 m .5989 .40017 L .59428 .40041 L F
.996 .842 .498 r
.59272 .39993 m .59275 .4002 L .59406 .40028 L F
.5938 .40011 m .59406 .40028 L .5951 .40034 L F
.59272 .39993 m .59406 .40028 L .5938 .40011 L F
.562 .896 .983 r
.59432 .40046 m .59496 .40071 L .595 .40056 L F
.59432 .40046 m .595 .40056 L .59435 .40046 L F
.996 .842 .498 r
.59275 .4002 m .59316 .40455 L .595 .40056 L F
.754 .906 .944 r
.59272 .39993 m .59418 .40047 L .59428 .40041 L F
.59272 .39993 m .59428 .40041 L .59738 .39853 L F
.996 .842 .498 r
.59379 .40026 m .595 .40056 L .5951 .40034 L F
.59275 .4002 m .59451 .40048 L .59379 .40026 L F
.59451 .40048 m .595 .40056 L .59379 .40026 L F
.562 .896 .983 r
.59435 .40046 m .595 .40056 L .59503 .40041 L F
.59496 .40071 m .59623 .4012 L .59503 .40041 L F
.831 .953 .896 r
.59496 .40071 m .59392 .40344 L .59623 .4012 L F
.848 .612 .582 r
.38621 .5384 m .38248 .53776 L .38305 .53507 L F
.807 .485 .445 r
.38621 .5384 m .3819 .53971 L .38248 .53776 L F
.38621 .5384 m .38433 .54028 L .3819 .53971 L F
.861 .573 .499 r
.38621 .5384 m .38657 .54138 L .38433 .54028 L F
.974 .725 .498 r
.53241 .4692 m .53065 .47007 L .53159 .4684 L F
.53241 .4692 m .5325 .47188 L .53065 .47007 L F
.953 .948 .651 r
.53241 .4692 m .53159 .4684 L .53329 .46426 L F
.847 .748 .753 r
.47145 .55505 m .47547 .55478 L .47396 .55379 L F
.47145 .55505 m .47326 .55827 L .47547 .55478 L F
.929 .919 .783 r
.4763 .55055 m .47547 .55478 L .47856 .55176 L F
.4763 .55055 m .47396 .55379 L .47547 .55478 L F
0 0 0 r
.26326 .52534 m .26319 .5256 L .26387 .52483 L F
.26326 .52534 m .26111 .52712 L .26319 .5256 L F
.595 .91 .655 r
.59374 .37114 m .5908 .37377 L .59232 .37213 L F
.339 .148 .468 r
.5896 .37603 m .59232 .37213 L .5908 .37377 L F
.599 .825 .986 r
.44334 .56767 m .44094 .56872 L .438 .56716 L F
.639 .083 0 r
.57956 .35929 m .58287 .3608 L .58139 .35987 L F
.152 0 0 r
.63957 .38742 m .63801 .38692 L .63685 .38834 L F
.594 .934 .95 r
.61409 .34903 m .61469 .34829 L .61251 .35028 L F
.476 .816 .524 r
.61469 .34829 m .61212 .35063 L .61251 .35028 L F
0 .117 .663 r
.52972 .4451 m .52885 .44185 L .5293 .44486 L F
.813 .97 .661 r
.52485 .4505 m .52972 .4451 L .5293 .44486 L F
.894 .71 .646 r
.55798 .44295 m .5574 .44593 L .55454 .44424 L F
0 .29 .789 r
.3343 .52495 m .33704 .52687 L .33643 .52797 L F
.975 .769 .564 r
.33704 .52687 m .33913 .52878 L .33643 .52797 L F
.427 0 0 r
.40457 .51551 m .40721 .51679 L .40816 .51652 L F
.328 .244 .606 r
.24267 .54488 m .24449 .54033 L .24204 .54268 L F
.193 0 0 r
.62391 .34241 m .62674 .34199 L .62796 .34074 L F
.234 0 0 r
.62674 .34199 m .63085 .34033 L .62796 .34074 L F
.731 .975 .734 r
.47944 .41911 m .48065 .41695 L .48323 .41664 L F
.47944 .41911 m .47912 .41878 L .48065 .41695 L F
.993 .788 .523 r
.42436 .56298 m .42631 .56161 L .42469 .56045 L F
.42436 .56298 m .42585 .56416 L .42631 .56161 L F
.349 .115 .411 r
.52139 .40288 m .52113 .40566 L .51876 .40644 L F
.371 .119 .397 r
.52339 .40251 m .52113 .40566 L .52139 .40288 L F
.874 .994 .767 r
.69056 .3652 m .69241 .36448 L .69314 .36176 L F
.405 .176 .449 r
.35276 .57478 m .34888 .57474 L .35047 .57219 L F
.26 0 .202 r
.27416 .52898 m .27312 .53123 L .27092 .53196 L F
0 0 0 r
.27564 .52753 m .27416 .52898 L .27704 .52537 L F
.496 .273 .506 r
.27564 .52753 m .27312 .53123 L .27416 .52898 L F
.661 .636 .814 r
.33475 .63397 m .33905 .63549 L .33748 .63343 L F
.167 .433 .868 r
.33748 .63343 m .33905 .63549 L .34069 .63568 L F
.918 .851 .761 r
.55949 .44966 m .55593 .45162 L .5579 .44839 L F
.12 .141 .608 r
.24079 .55234 m .24284 .55286 L .2427 .55033 L F
.24079 .55234 m .24138 .5547 L .24284 .55286 L F
.925 .605 .416 r
.34018 .50863 m .34045 .51115 L .34257 .51202 L F
.914 .56 .352 r
.34045 .51115 m .34072 .51352 L .34257 .51202 L F
.848 .443 .273 r
.34257 .51202 m .34072 .51352 L .34324 .51415 L F
.854 .69 .679 r
.37127 .58737 m .36926 .59049 L .37287 .59108 L F
.839 .65 .647 r
.36871 .59332 m .37287 .59108 L .36926 .59049 L F
.36871 .59332 m .3712 .5944 L .37287 .59108 L F
.839 .901 .881 r
.49519 .52415 m .49985 .52242 L .49816 .52132 L F
.811 .914 .909 r
.50019 .51939 m .49985 .52242 L .50086 .52098 L F
.50019 .51939 m .49816 .52132 L .49985 .52242 L F
.524 .191 .346 r
.33248 .67018 m .33444 .67226 L .33204 .67267 L F
.33248 .67018 m .33524 .67008 L .33444 .67226 L F
.906 .767 .697 r
.66686 .36354 m .66369 .36558 L .66605 .36223 L F
.592 .804 .981 r
.60224 .44398 m .6039 .44123 L .60088 .44174 L F
.60224 .44398 m .6056 .44285 L .6039 .44123 L F
.614 .169 .171 r
.37589 .49649 m .37827 .49736 L .38017 .49561 L F
.572 .119 .138 r
.38017 .49561 m .38451 .49729 L .38338 .49415 L F
.38017 .49561 m .37827 .49736 L .38451 .49729 L F
.61 .775 .959 r
.43964 .59703 m .44362 .59793 L .44211 .59684 L F
.598 .851 .992 r
.44362 .59793 m .44469 .59595 L .44211 .59684 L F
.836 .578 .55 r
.69178 .33041 m .69355 .33305 L .69384 .33063 L F
.812 .746 .79 r
.29121 .62683 m .29209 .62955 L .28855 .63023 L F
.688 .328 .358 r
.28855 .63023 m .29209 .62955 L .29109 .63309 L F
.695 .195 .052 r
.29121 .62683 m .29351 .6287 L .29209 .62955 L F
.567 .77 .974 r
.29349 .62617 m .29522 .62794 L .29121 .62683 L F
.695 .195 .052 r
.29121 .62683 m .29522 .62794 L .29407 .62916 L F
.565 .775 .977 r
.29349 .62617 m .29121 .62683 L .29014 .62562 L F
.29061 .62466 m .29014 .62562 L .28818 .6234 L F
.29349 .62617 m .29014 .62562 L .29061 .62466 L F
.29349 .62617 m .28818 .6234 L .29206 .62249 L F
.676 .265 .259 r
.28994 .62514 m .29206 .62249 L .28818 .6234 L F
.719 .894 .511 r
.29271 .62086 m .29206 .62249 L .29105 .62376 L F
.29169 .62243 m .29105 .62376 L .28994 .62514 L F
.29271 .62086 m .29105 .62376 L .29169 .62243 L F
.969 .649 .297 r
.29241 .62861 m .29311 .62704 L .29258 .62496 L F
.29311 .62704 m .29349 .62617 L .29261 .625 L F
.29311 .62704 m .29261 .625 L .29258 .62496 L F
.695 .195 .052 r
.29351 .6287 m .29407 .62916 L .29364 .62925 L F
.29351 .6287 m .29364 .62925 L .29209 .62955 L F
.025 0 .123 r
.29109 .63309 m .29209 .62955 L .29407 .62916 L F
.543 .924 .809 r
.4598 .43313 m .455 .43526 L .45701 .43351 L F
.639 .964 .892 r
.46135 .43181 m .4598 .43313 L .45701 .43351 L F
.918 .796 .71 r
.47407 .56994 m .47544 .57411 L .47594 .57145 L F
.47407 .56994 m .4722 .5738 L .47544 .57411 L F
.922 .844 .75 r
.47127 .57642 m .47544 .57411 L .4722 .5738 L F
.47127 .57642 m .47302 .57749 L .47544 .57411 L F
.754 .759 .248 r
.535 .41717 m .53607 .41518 L .537 .41592 L F
.535 .41717 m .53482 .41679 L .53607 .41518 L F
.535 .41717 m .53424 .42002 L .53482 .41679 L F
.883 .963 .634 r
.59428 .38594 m .59608 .38343 L .59439 .38446 L F
.85 .637 .614 r
.59428 .38594 m .59739 .38665 L .59608 .38343 L F
.558 .558 .809 r
.59877 .38227 m .59608 .38343 L .5946 .37916 L F
.623 .58 .785 r
.59739 .38665 m .59877 .38227 L .59608 .38343 L F
0 0 0 r
.59439 .38446 m .59608 .38343 L .59877 .38227 L F
.59353 .35372 m .59239 .35606 L .59182 .35626 L F
.872 .898 .848 r
.59245 .35208 m .59353 .35372 L .59567 .35059 L F
0 0 0 r
.59453 .35352 m .59353 .35372 L .59245 .35208 L F
.59453 .35352 m .59239 .35606 L .59353 .35372 L F
.932 .814 .707 r
.57472 .43589 m .57636 .43605 L .57549 .43211 L F
.897 .546 .37 r
.57673 .43877 m .57636 .43605 L .57472 .43589 L F
.487 .288 .535 r
.44334 .56767 m .44587 .56432 L .44328 .5647 L F
.684 .255 .224 r
.41101 .46186 m .40909 .46397 L .40677 .4616 L F
.675 .385 .474 r
.41101 .46186 m .41109 .46384 L .40909 .46397 L F
.41101 .46186 m .41354 .46227 L .41109 .46384 L F
.208 0 0 r
.62269 .34653 m .62122 .3479 L .6188 .34773 L F
.382 0 0 r
.62531 .3461 m .62122 .3479 L .62269 .34653 L F
.898 .658 .566 r
.3649 .5738 m .36884 .57133 L .36477 .5703 L F
.3649 .5738 m .36851 .57415 L .36884 .57133 L F
.85 .585 .538 r
.59428 .38594 m .59634 .38958 L .59739 .38665 L F
.623 .58 .785 r
.59739 .38665 m .59972 .38631 L .59877 .38227 L F
.865 .77 .754 r
.59634 .38958 m .59972 .38631 L .59739 .38665 L F
.955 .881 .482 r
.56213 .37611 m .56158 .37536 L .56242 .37276 L F
.896 .855 .405 r
.56091 .38004 m .56158 .37536 L .56213 .37611 L F
.637 .609 .805 r
.49839 .44707 m .4996 .45124 L .49661 .44924 L F
0 0 .53 r
.49992 .44964 m .49965 .45101 L .49839 .44707 L F
.49965 .45101 m .4996 .45124 L .4995 .45089 L F
.49965 .45101 m .4995 .45089 L .49839 .44707 L F
0 0 .095 r
.49986 .45122 m .4996 .45124 L .49965 .45101 L F
.49986 .45122 m .49965 .45101 L .49992 .44964 L F
.449 0 0 r
.49997 .45133 m .49986 .45122 L .50115 .45223 L F
0 .233 .688 r
.49807 .44989 m .49661 .44924 L .49967 .45111 L F
.637 .609 .805 r
.49839 .44707 m .49661 .44924 L .49689 .4489 L F
.449 0 0 r
.49654 .44874 m .49986 .45122 L .49997 .45133 L F
.50123 .45229 m .50115 .45223 L .50137 .45239 L F
.49654 .44874 m .50115 .45223 L .50123 .45229 L F
0 .233 .688 r
.49654 .44874 m .49661 .44924 L .49812 .44991 L F
.258 0 0 r
.49288 .44869 m .49571 .44884 L .49661 .44924 L F
.49571 .44884 m .49689 .4489 L .49661 .44924 L F
0 0 0 r
.49839 .44707 m .49689 .4489 L .49958 .44552 L F
.544 .627 .884 r
.48631 .43415 m .48728 .4366 L .48918 .43381 L F
.522 .596 .869 r
.48728 .4366 m .49312 .43717 L .48918 .43381 L F
.634 .923 .651 r
.48323 .41664 m .48448 .41491 L .48633 .41361 L F
.632 .962 .896 r
.48323 .41664 m .48065 .41695 L .48448 .41491 L F
.781 .531 .558 r
.34162 .52191 m .33702 .52408 L .3372 .52138 L F
.34162 .52191 m .34141 .52469 L .33702 .52408 L F
.72 .971 .932 r
.63212 .4006 m .63456 .40071 L .63669 .39906 L F
.677 .432 .543 r
.34729 .53178 m .34213 .53414 L .34275 .53195 L F
.34729 .53178 m .3471 .53451 L .34213 .53414 L F
.974 .753 .544 r
.38794 .54501 m .38609 .54392 L .38657 .54138 L F
.984 .743 .493 r
.38755 .54762 m .38609 .54392 L .38794 .54501 L F
.981 .775 .552 r
.41868 .53422 m .41991 .5378 L .42038 .53518 L F
.386 .464 .818 r
.39712 .49903 m .4005 .50086 L .39819 .50217 L F
0 0 0 r
.4005 .50086 m .39816 .50443 L .39819 .50217 L F
.56 .927 .933 r
.44484 .45105 m .44601 .44918 L .44381 .45052 L F
.44484 .45105 m .44862 .44932 L .44601 .44918 L F
.772 .794 .871 r
.33064 .63368 m .33475 .63397 L .33251 .63239 L F
.813 .697 .736 r
.33222 .6374 m .33475 .63397 L .33064 .63368 L F
.618 .646 .856 r
.33475 .63397 m .33563 .62963 L .33251 .63239 L F
.33475 .63397 m .33748 .63343 L .33563 .62963 L F
.949 .595 .273 r
.6593 .39756 m .66118 .40042 L .66041 .40104 L F
.067 0 .008 r
.66118 .40042 m .66313 .40038 L .66041 .40104 L F
0 0 .149 r
.6712 .35036 m .6719 .34607 L .67262 .34684 L F
.6712 .35036 m .6717 .34847 L .6719 .34607 L F
.88 .973 .662 r
.66967 .35112 m .6717 .34847 L .6712 .35036 L F
.716 .976 .921 r
.67269 .37817 m .67694 .37665 L .67621 .37637 L F
.561 .919 .734 r
.67875 .37485 m .67694 .37665 L .67888 .37513 L F
.577 .943 .862 r
.67621 .37637 m .67694 .37665 L .67875 .37485 L F
.776 .992 .772 r
.59182 .35626 m .58877 .35813 L .58943 .35759 L F
0 0 .39 r
.59239 .35606 m .59267 .35849 L .59182 .35626 L F
.733 .96 .942 r
.34093 .58266 m .34218 .58036 L .3419 .58101 L F
.311 .381 .773 r
.34325 .58395 m .34093 .58266 L .3419 .58101 L F
.238 0 .102 r
.28225 .59927 m .28011 .60062 L .28125 .59999 L F
.508 .459 .738 r
.28011 .60062 m .28306 .60404 L .28125 .59999 L F
.994 .753 .443 r
.28718 .58987 m .28651 .59096 L .28429 .59199 L F
.487 .158 .335 r
.32604 .67389 m .32817 .67585 L .32571 .67634 L F
.32604 .67389 m .32933 .67298 L .32817 .67585 L F
.669 .9 .557 r
.5167 .4087 m .51627 .40946 L .51876 .40644 L F
0 0 0 r
.52113 .40566 m .5167 .4087 L .51876 .40644 L F
.154 0 .198 r
.51749 .42015 m .52075 .41621 L .51784 .41559 L F
.04 .585 .842 r
.64426 .39807 m .64786 .39889 L .64635 .39838 L F
.124 .652 .873 r
.64786 .39889 m .65037 .39897 L .64635 .39838 L F
.819 .725 .761 r
.36244 .60993 m .36703 .61045 L .36692 .60776 L F
.817 .73 .768 r
.36244 .60993 m .36402 .61381 L .36703 .61045 L F
0 0 0 r
.52885 .44185 m .52721 .44355 L .52648 .4456 L F
.67 .619 .789 r
.43377 .56893 m .43083 .57058 L .42964 .56761 L F
.43377 .56893 m .42964 .56761 L .43211 .5696 L F
.596 .198 .259 r
.43211 .5696 m .43578 .56781 L .43377 .56893 L F
.43578 .56781 m .43638 .56751 L .43377 .56893 L F
.67 .619 .789 r
.43377 .56893 m .43123 .57158 L .43083 .57058 L F
.006 0 0 r
.52626 .40973 m .52202 .41158 L .52478 .41119 L F
0 .133 .619 r
.52737 .41031 m .52928 .41215 L .52626 .40973 L F
.567 .36 .56 r
.52626 .40973 m .52928 .41215 L .52624 .41249 L F
0 .133 .619 r
.52737 .41031 m .52626 .40973 L .52478 .41119 L F
.567 .649 .891 r
.31954 .63312 m .32165 .63636 L .32405 .63552 L F
.819 .754 .791 r
.31421 .54778 m .31717 .55246 L .31876 .54754 L F
.586 .313 .469 r
.30112 .58839 m .29996 .59013 L .30413 .58582 L F
.77 .716 .802 r
.34702 .63048 m .35067 .63052 L .34922 .62665 L F
.785 .724 .795 r
.35067 .63052 m .3536 .62724 L .34922 .62665 L F
.503 .639 .915 r
.31028 .63382 m .31473 .63654 L .3128 .63322 L F
.549 .573 .831 r
.31473 .63654 m .31592 .63298 L .3128 .63322 L F
.31473 .63654 m .31686 .63606 L .31592 .63298 L F
.496 .252 .474 r
.31148 .54759 m .31515 .54354 L .31242 .54547 L F
.392 .689 .979 r
.60784 .39566 m .60606 .39614 L .60353 .39476 L F
.32 .251 .62 r
.60801 .3976 m .60606 .39614 L .60784 .39566 L F
.956 .683 .479 r
.30076 .678 m .30278 .67616 L .30081 .67505 L F
.529 .589 .859 r
.30278 .67616 m .30393 .67278 L .30081 .67505 L F
.30278 .67616 m .30521 .67571 L .30393 .67278 L F
.148 0 0 r
.30237 .67754 m .30278 .67616 L .30076 .678 L F
.30237 .67754 m .30521 .67571 L .30278 .67616 L F
.21 .183 .608 r
.23899 .56979 m .24055 .57016 L .2399 .56754 L F
.224 .164 .575 r
.23899 .56979 m .24101 .57294 L .24055 .57016 L F
.23899 .56979 m .23876 .57509 L .24101 .57294 L F
.534 .882 .985 r
.46963 .53392 m .47329 .53365 L .47083 .5347 L F
.707 .765 .897 r
.3219 .55286 m .32445 .55498 L .32061 .55427 L F
.671 .307 .348 r
.32445 .55498 m .32001 .55441 L .32061 .55427 L F
.32445 .55498 m .3196 .55507 L .32001 .55441 L F
.32445 .55498 m .32345 .55643 L .3196 .55507 L F
.563 .729 .952 r
.32603 .55354 m .32445 .55498 L .3219 .55286 L F
0 0 .029 r
.32603 .55354 m .32345 .55643 L .32445 .55498 L F
0 0 0 r
.65819 .37461 m .65841 .3754 L .65915 .37387 L F
.964 .937 .696 r
.65819 .37461 m .65516 .37808 L .65841 .3754 L F
.929 .643 .477 r
.37761 .52519 m .3752 .52677 L .3751 .5241 L F
.37761 .52519 m .37731 .52766 L .3752 .52677 L F
.784 .998 .809 r
.31529 .5325 m .31312 .53505 L .31449 .5329 L F
.299 .313 .707 r
.31312 .53505 m .31548 .53651 L .31449 .5329 L F
.187 .396 .836 r
.40114 .51108 m .40457 .51551 L .40316 .51232 L F
.57 .812 .99 r
.39086 .50149 m .38842 .50231 L .38664 .50083 L F
.808 .823 .862 r
.33528 .51749 m .3338 .52122 L .33348 .51916 L F
.6 .579 .801 r
.33528 .51749 m .33436 .52169 L .3338 .52122 L F
.633 .072 0 r
.24345 .57749 m .24155 .57723 L .23876 .57509 L F
.153 0 0 r
.24578 .57722 m .24155 .57723 L .24345 .57749 L F
.546 .569 .829 r
.24971 .56675 m .2488 .57095 L .24813 .56754 L F
.24971 .56675 m .25138 .57044 L .2488 .57095 L F
0 0 0 r
.54064 .47575 m .53665 .47795 L .538 .47604 L F
.833 .998 .836 r
.5437 .47262 m .54064 .47575 L .54193 .47266 L F
.833 .997 .837 r
.54193 .47266 m .54064 .47575 L .538 .47604 L F
.315 0 .247 r
.53196 .43612 m .52874 .43924 L .53174 .43843 L F
.187 .277 .725 r
.53319 .43592 m .53196 .43612 L .53343 .43368 L F
.642 .243 .272 r
.53196 .43612 m .53472 .43825 L .53174 .43843 L F
.955 .612 .245 r
.53174 .43843 m .53196 .43612 L .53472 .43825 L F
0 0 0 r
.50376 .49815 m .50531 .49679 L .50693 .4952 L F
.50376 .49815 m .50248 .49976 L .50531 .49679 L F
.233 .504 .904 r
.33321 .59338 m .33484 .59085 L .33142 .59076 L F
.33321 .59338 m .33543 .59269 L .33484 .59085 L F
.902 .885 .806 r
.65703 .39603 m .6589 .39331 L .65724 .39268 L F
.535 .026 0 r
.28966 .60075 m .29147 .6026 L .29214 .60128 L F
.126 .236 .708 r
.56275 .38678 m .56423 .38475 L .56278 .38231 L F
0 0 0 r
.56275 .38678 m .56298 .38745 L .56423 .38475 L F
.56275 .38678 m .56196 .38925 L .56298 .38745 L F
.888 .828 .783 r
.55108 .4621 m .54696 .46411 L .55009 .46135 L F
.55108 .4621 m .54861 .46564 L .54696 .46411 L F
.789 .98 .905 r
.55207 .45949 m .55108 .4621 L .55009 .46135 L F
.969 .649 .323 r
.29407 .62916 m .29522 .62794 L .29349 .62617 L F
.82 .697 .729 r
.36955 .58362 m .37127 .58737 L .37178 .58443 L F
.325 .388 .773 r
.34776 .55094 m .34932 .55539 L .3496 .55183 L F
.969 .822 .642 r
.34932 .55539 m .34752 .55447 L .3496 .55183 L F
.34932 .55539 m .34841 .5577 L .34752 .55447 L F
.381 0 .01 r
.31109 .68351 m .31201 .68547 L .3092 .68561 L F
.31109 .68351 m .31383 .6834 L .31201 .68547 L F
.449 .156 .373 r
.31383 .6834 m .31714 .67977 L .3163 .68282 L F
.374 .093 .352 r
.31714 .67977 m .3188 .68221 L .3163 .68282 L F
.31714 .67977 m .31913 .67982 L .3188 .68221 L F
.76 .865 .926 r
.6547 .36098 m .65613 .3625 L .65939 .35986 L F
.6 .579 .801 r
.33528 .51749 m .3372 .52138 L .33436 .52169 L F
.534 .343 .568 r
.33702 .52408 m .33436 .52169 L .3372 .52138 L F
.33702 .52408 m .3343 .52495 L .33436 .52169 L F
.802 .738 .792 r
.58597 .43522 m .59031 .43548 L .5883 .43174 L F
.81 .711 .756 r
.58747 .43899 m .59031 .43548 L .58597 .43522 L F
.896 .855 .405 r
.56091 .38004 m .56074 .37788 L .56158 .37536 L F
.915 .92 .534 r
.56091 .38004 m .5597 .38111 L .56074 .37788 L F
.703 .197 .03 r
.56091 .38004 m .56278 .38231 L .5597 .38111 L F
.849 .944 .582 r
.34623 .57589 m .34572 .57506 L .34888 .57474 L F
.34623 .57589 m .34493 .57711 L .34572 .57506 L F
.999 .826 .526 r
.69302 .35438 m .69453 .35372 L .69231 .35177 L F
.69302 .35438 m .69417 .35618 L .69453 .35372 L F
.504 .87 .644 r
.51032 .49264 m .50693 .4952 L .50848 .49379 L F
0 0 0 r
.50693 .4952 m .50531 .49679 L .50848 .49379 L F
.315 .802 .874 r
.51008 .4199 m .50719 .42071 L .50861 .41986 L F
.266 0 0 r
.50861 .41986 m .50865 .41986 L .51008 .4199 L F
.50865 .41986 m .51251 .4204 L .51008 .4199 L F
.814 .981 .891 r
.51375 .41848 m .51245 .41998 L .51008 .4199 L F
.51245 .41998 m .51195 .42055 L .51008 .4199 L F
.54 .922 .916 r
.62601 .37852 m .62717 .37696 L .62891 .37832 L F
.62601 .37852 m .62447 .37828 L .62717 .37696 L F
.884 .508 .323 r
.35211 .49916 m .35059 .50027 L .35148 .49603 L F
.35211 .49916 m .3529 .50143 L .35059 .50027 L F
.268 0 0 r
.63342 .33951 m .63644 .33908 L .63751 .33759 L F
.073 0 0 r
.63644 .33908 m .64026 .33679 L .63751 .33759 L F
.046 0 0 r
.65915 .37387 m .65841 .3754 L .65612 .37691 L F
.5 .872 .655 r
.49352 .43759 m .49479 .43712 L .49678 .43559 L F
.408 .062 .263 r
.38026 .46616 m .37948 .46826 L .37701 .46875 L F
.544 .265 .443 r
.38451 .46498 m .37948 .46826 L .38026 .46616 L F
.414 .657 .96 r
.39436 .48796 m .3923 .48824 L .391 .48642 L F
.391 .48642 m .3923 .48824 L .39436 .48796 L F
.39436 .48796 m .3923 .48824 L .391 .48642 L F
.731 .813 .915 r
.391 .48642 m .3923 .48824 L .38793 .48813 L F
.827 .952 .899 r
.40639 .5864 m .40703 .58777 L .4094 .58524 L F
.789 .296 .028 r
.41043 .59048 m .40942 .59092 L .41112 .59103 L F
.40703 .58777 m .40942 .59092 L .41043 .59048 L F
.873 .439 .045 r
.40639 .5864 m .40942 .59092 L .40703 .58777 L F
.40639 .5864 m .40819 .59049 L .40942 .59092 L F
.571 .658 .896 r
.4094 .58524 m .41301 .58765 L .41263 .58691 L F
.209 .447 .87 r
.4094 .58524 m .41263 .58691 L .40955 .58342 L F
.921 .969 .776 r
.40942 .59092 m .41113 .58581 L .41263 .58691 L F
.40942 .59092 m .40819 .59049 L .41113 .58581 L F
.629 .938 .706 r
.41025 .58954 m .40755 .59174 L .40942 .59092 L F
.569 .609 .853 r
.40838 .59448 m .40942 .59092 L .40708 .5916 L F
0 0 0 r
.40942 .59092 m .4061 .5929 L .40708 .5916 L F
.569 .609 .853 r
.40838 .59448 m .41073 .59375 L .40942 .59092 L F
.42 .09 .298 r
.40944 .59253 m .40708 .59241 L .40767 .59441 L F
0 0 0 r
.40942 .59092 m .40604 .59299 L .4061 .5929 L F
.40604 .59299 m .40602 .593 L .40602 .593 L F
.40602 .593 m .40599 .59302 L .40599 .59302 L F
.629 .938 .706 r
.40755 .59174 m .40599 .59302 L .40942 .59092 L F
.42 .09 .298 r
.40708 .59241 m .40653 .59238 L .40667 .59264 L F
.40708 .59241 m .40667 .59264 L .40767 .59441 L F
0 0 0 r
.40604 .59299 m .40602 .593 L .4061 .5929 L F
.40602 .593 m .40599 .59302 L .4061 .5929 L F
.389 .568 .908 r
.40875 .59326 m .40767 .59441 L .40697 .59258 L F
0 0 0 r
.4061 .5929 m .4029 .59407 L .40336 .59206 L F
.40599 .59302 m .40501 .5936 L .4061 .5929 L F
.576 .074 .025 r
.40336 .59206 m .4029 .59407 L .40028 .59274 L F
0 0 0 r
.4061 .5929 m .40501 .5936 L .4029 .59407 L F
.691 .956 .95 r
.40594 .59226 m .40374 .59329 L .40501 .5936 L F
.40634 .59168 m .40516 .59241 L .40594 .59226 L F
.40516 .59241 m .40374 .59329 L .40594 .59226 L F
.823 .494 .432 r
.40336 .59206 m .40028 .59274 L .40019 .59069 L F
.549 0 0 r
.40374 .59329 m .40067 .5922 L .40104 .59292 L F
.823 .494 .432 r
.40336 .59206 m .40019 .59069 L .40402 .59206 L F
.12 .36 .822 r
.40019 .59069 m .40142 .58941 L .39819 .58742 L F
.835 .909 .888 r
.40028 .59274 m .40142 .58941 L .40019 .59069 L F
.40028 .59274 m .3987 .59177 L .40142 .58941 L F
.549 0 0 r
.40067 .5922 m .39975 .59188 L .39996 .59205 L F
.40067 .5922 m .39996 .59205 L .40104 .59292 L F
0 .532 .769 r
.40501 .5936 m .40104 .59292 L .4029 .59407 L F
.40501 .5936 m .40374 .59329 L .40104 .59292 L F
.542 .037 .004 r
.40345 .59282 m .4041 .59452 L .40181 .59306 L F
.691 .956 .95 r
.40617 .59231 m .40545 .59334 L .40605 .59279 L F
.40634 .59168 m .40602 .59228 L .40617 .59231 L F
.40602 .59228 m .40545 .59334 L .40617 .59231 L F
.542 .037 .004 r
.40647 .5924 m .40607 .59245 L .40584 .59261 L F
.839 .99 .859 r
.40624 .59206 m .40617 .59231 L .40665 .59151 L F
.40617 .59231 m .40599 .59302 L .40632 .59226 L F
.40617 .59231 m .40632 .59226 L .40665 .59151 L F
.549 0 0 r
.40374 .59329 m .40169 .59299 L .39975 .59188 L F
.542 .037 .004 r
.4057 .59249 m .40169 .59299 L .40584 .59261 L F
.4057 .59249 m .40181 .59306 L .40307 .59281 L F
.699 .747 .888 r
.40516 .59241 m .4061 .59244 L .40374 .59329 L F
.691 .956 .95 r
.40634 .59168 m .40501 .5936 L .40545 .59334 L F
.542 .037 .004 r
.40607 .59245 m .4057 .59249 L .40578 .59255 L F
.40649 .59239 m .4057 .59249 L .40647 .5924 L F
.40653 .59238 m .40563 .59251 L .4057 .59249 L F
.40563 .59251 m .40181 .59306 L .4057 .59249 L F
.699 .747 .888 r
.40634 .59168 m .40662 .59225 L .4061 .59244 L F
.40634 .59168 m .4061 .59244 L .40516 .59241 L F
.542 .037 .004 r
.40607 .59245 m .40578 .59255 L .40584 .59261 L F
.839 .99 .859 r
.40665 .59151 m .40608 .59282 L .41025 .58954 L F
.542 .037 .004 r
.40649 .59239 m .40642 .59245 L .40614 .59244 L F
.839 .99 .859 r
.40608 .59282 m .40615 .59289 L .41025 .58954 L F
.719 .736 .865 r
.40584 .59261 m .40767 .59441 L .40653 .59238 L F
.542 .037 .004 r
.40653 .59238 m .40652 .5924 L .40649 .59239 L F
.691 .956 .95 r
.40605 .59279 m .40545 .59334 L .40599 .59302 L F
.839 .99 .859 r
.40608 .59282 m .40599 .59302 L .40615 .59289 L F
.719 .736 .865 r
.40374 .59329 m .40506 .59366 L .40584 .59261 L F
.40506 .59366 m .40767 .59441 L .40584 .59261 L F
.699 .747 .888 r
.4061 .59244 m .40767 .59441 L .40374 .59329 L F
.542 .037 .004 r
.40653 .59238 m .40649 .59239 L .40647 .5924 L F
.40652 .5924 m .40646 .59245 L .40649 .59239 L F
.40646 .59245 m .40642 .59245 L .40649 .59239 L F
.341 .772 .97 r
.40655 .59241 m .40651 .5924 L .40653 .59238 L F
.699 .747 .888 r
.40662 .59225 m .40672 .59246 L .4061 .59244 L F
.40646 .59245 m .40767 .59441 L .4061 .59244 L F
.40673 .59248 m .40767 .59441 L .40646 .59245 L F
.341 .772 .97 r
.40845 .59495 m .4041 .59452 L .40646 .59245 L F
.40656 .59246 m .40646 .59245 L .40651 .5924 L F
.389 .568 .908 r
.40697 .59258 m .40767 .59441 L .40678 .59258 L F
.341 .772 .97 r
.40845 .59495 m .40646 .59245 L .40656 .59246 L F
.699 .747 .888 r
.40672 .59246 m .40673 .59248 L .40659 .59246 L F
.389 .568 .908 r
.40944 .59253 m .40875 .59326 L .40697 .59258 L F
.479 .308 .571 r
.40838 .59448 m .41093 .59655 L .41073 .59375 L F
.42 .09 .298 r
.40944 .59253 m .40845 .59495 L .40659 .59246 L F
.40676 .5924 m .40659 .59246 L .40653 .59238 L F
.699 .747 .888 r
.40672 .59246 m .40659 .59246 L .40662 .59245 L F
.389 .568 .908 r
.40944 .59253 m .40678 .59258 L .40704 .59243 L F
.42 .09 .298 r
.40944 .59253 m .4067 .59242 L .40676 .5924 L F
.389 .568 .908 r
.40944 .59253 m .40704 .59243 L .40771 .59206 L F
.42 .09 .298 r
.40944 .59253 m .40659 .59246 L .4067 .59242 L F
.699 .747 .888 r
.40662 .59245 m .40659 .59246 L .40646 .59245 L F
.542 .037 .004 r
.40646 .59245 m .40551 .59328 L .40642 .59245 L F
.40584 .59261 m .40345 .59283 L .40447 .59305 L F
.40345 .59283 m .40169 .59299 L .40447 .59305 L F
.40447 .59305 m .40169 .59299 L .40374 .59329 L F
.40614 .59244 m .40551 .59328 L .40345 .59282 L F
.40642 .59245 m .40551 .59328 L .40614 .59244 L F
.40551 .59328 m .4041 .59452 L .40345 .59282 L F
.40307 .59281 m .40181 .59306 L .40169 .59299 L F
.839 .99 .859 r
.40634 .59168 m .40624 .59206 L .40665 .59151 L F
.341 .772 .97 r
.40845 .59495 m .40651 .5924 L .40655 .59241 L F
.389 .568 .908 r
.40771 .59206 m .40678 .59258 L .40634 .59168 L F
.844 .982 .868 r
.502 .5024 m .50091 .50168 L .50248 .49976 L F
.731 .901 .955 r
.46455 .44272 m .46765 .44177 L .46662 .44138 L F
.653 .923 .975 r
.46765 .44177 m .46907 .44016 L .46662 .44138 L F
.975 .924 .65 r
.60116 .36744 m .60119 .36948 L .60253 .36671 L F
.6011 .36748 m .60086 .36797 L .60116 .36744 L F
.614 .389 .552 r
.60169 .36622 m .60111 .36747 L .60211 .36661 L F
.60111 .36747 m .6018 .36696 L .60211 .36661 L F
.59823 .363 m .60086 .36797 L .60169 .36622 L F
.60086 .36797 m .60087 .36798 L .60169 .36622 L F
.673 .411 .517 r
.59469 .36561 m .60071 .36792 L .59823 .363 L F
.60071 .36792 m .60086 .36798 L .60072 .36771 L F
.60071 .36792 m .60072 .36771 L .59823 .363 L F
.985 .78 .378 r
.60071 .36824 m .60125 .37244 L .60119 .36948 L F
.802 .574 .592 r
.59731 .37025 m .60034 .37111 L .60051 .36812 L F
.60019 .36804 m .60051 .36812 L .60053 .36778 L F
.59731 .37025 m .60051 .36812 L .60019 .36804 L F
.208 .276 .714 r
.59469 .36561 m .59764 .36741 L .60069 .36795 L F
.59764 .36741 m .5977 .36745 L .59797 .36749 L F
.59764 .36741 m .59797 .36749 L .60069 .36795 L F
.60071 .36792 m .60069 .36795 L .60085 .36798 L F
.60071 .36792 m .60085 .36798 L .60086 .36798 L F
.59469 .36561 m .60069 .36795 L .60071 .36792 L F
.975 .924 .65 r
.60053 .36778 m .60084 .36797 L .60086 .36797 L F
.60071 .36824 m .60119 .36948 L .60116 .36744 L F
.208 .276 .714 r
.60086 .36798 m .60085 .36798 L .60087 .36798 L F
.284 .75 .945 r
.60087 .36798 m .60085 .36798 L .60053 .36778 L F
.60085 .36798 m .5977 .36745 L .60053 .36778 L F
.975 .924 .65 r
.60053 .36778 m .60062 .36803 L .60084 .36797 L F
.60062 .36803 m .60071 .36824 L .60086 .36798 L F
.60062 .36803 m .60086 .36798 L .60086 .36797 L F
.985 .78 .378 r
.60062 .36803 m .6007 .36889 L .60071 .36824 L F
.60053 .36778 m .60057 .36808 L .60062 .36803 L F
.60057 .36808 m .6007 .36889 L .60062 .36803 L F
.6007 .36889 m .60125 .37244 L .60071 .36824 L F
.673 .411 .517 r
.60086 .36798 m .60086 .36797 L .59823 .363 L F
.614 .389 .552 r
.59823 .363 m .60211 .36661 L .60025 .36219 L F
.492 .407 .688 r
.60025 .36219 m .60211 .36661 L .60422 .36498 L F
.284 .75 .945 r
.6018 .36696 m .60053 .36778 L .60211 .36661 L F
.564 .912 .702 r
.60153 .36713 m .60053 .36778 L .6011 .36748 L F
.614 .389 .552 r
.60111 .36747 m .60087 .36798 L .6018 .36696 L F
.975 .924 .65 r
.60053 .36778 m .60086 .36797 L .6011 .36748 L F
.673 .411 .517 r
.60086 .36798 m .60087 .36798 L .60086 .36797 L F
.284 .75 .945 r
.60087 .36798 m .60053 .36778 L .6018 .36696 L F
.458 .834 .596 r
.60422 .36498 m .60053 .36778 L .60211 .36661 L F
.564 .912 .702 r
.60422 .36498 m .60053 .36778 L .60153 .36713 L F
.60359 .36563 m .6011 .36748 L .60253 .36671 L F
.60422 .36498 m .6011 .36748 L .60359 .36563 L F
.312 .068 .374 r
.59823 .363 m .60025 .36219 L .60106 .36059 L F
.824 .744 .777 r
.62326 .40344 m .62706 .40447 L .62629 .40221 L F
.62326 .40344 m .62477 .40611 L .62706 .40447 L F
.673 .864 .972 r
.62629 .40221 m .62706 .40447 L .63034 .40225 L F
.839 .599 .576 r
.36181 .55755 m .36511 .561 L .36348 .55787 L F
.658 .371 .473 r
.55666 .36019 m .55666 .36307 L .55818 .36272 L F
.81 .473 .418 r
.49678 .43559 m .50026 .43643 L .5009 .4388 L F
.594 .288 .421 r
.42229 .56492 m .4213 .56659 L .41935 .56339 L F
.963 .884 .705 r
.60475 .35404 m .60284 .35406 L .60356 .35303 L F
.497 .814 1 r
.64579 .38483 m .64481 .38696 L .64343 .38598 L F
.64579 .38483 m .6477 .38639 L .64481 .38696 L F
.654 .611 .794 r
.28807 .65712 m .28912 .66071 L .29152 .6598 L F
.779 .98 .908 r
.5553 .45801 m .55498 .45925 L .55207 .45949 L F
.774 .794 .302 r
.55275 .39905 m .55247 .40017 L .55283 .39815 L F
.361 .755 .986 r
.55283 .39815 m .55688 .39903 L .55275 .39905 L F
.103 0 .287 r
.55247 .40017 m .55329 .40169 L .55283 .39815 L F
.55247 .40017 m .55156 .40265 L .55329 .40169 L F
.79 .662 .722 r
.59877 .38227 m .60337 .38307 L .60252 .38224 L F
.57 .2 .299 r
.60558 .38499 m .60337 .38307 L .60288 .38524 L F
.421 .386 .714 r
.31258 .62804 m .31538 .62988 L .31527 .62719 L F
.745 .993 .832 r
.65312 .39831 m .65703 .39603 L .65688 .39567 L F
.902 .885 .806 r
.65703 .39603 m .65724 .39268 L .65688 .39567 L F
.923 .675 .544 r
.68358 .3217 m .68563 .32651 L .68528 .3238 L F
.304 .53 .906 r
.43594 .59405 m .43767 .5954 L .438 .59371 L F
.194 .411 .846 r
.43767 .5954 m .43964 .59703 L .438 .59371 L F
0 0 .142 r
.56975 .41366 m .56874 .41309 L .56876 .41144 L F
.56975 .41366 m .56824 .41561 L .56874 .41309 L F
.91 .879 .792 r
.56641 .45503 m .57021 .45279 L .56841 .45137 L F
.56641 .45503 m .56797 .45632 L .57021 .45279 L F
.928 .855 .749 r
.57021 .45279 m .57091 .44674 L .56841 .45137 L F
.541 .342 .56 r
.2818 .65344 m .28307 .65639 L .28324 .6524 L F
.869 .907 .854 r
.32726 .60753 m .32935 .6087 L .32707 .61105 L F
.607 .873 .992 r
.33188 .6076 m .32935 .6087 L .32726 .60753 L F
.335 .335 .711 r
.23876 .57509 m .24155 .57723 L .24101 .57294 L F
.66 .933 .657 r
.48633 .41361 m .48739 .41133 L .48746 .41165 L F
.48633 .41361 m .48614 .41304 L .48739 .41133 L F
.48633 .41361 m .48448 .41491 L .48614 .41304 L F
.886 .99 .794 r
.34325 .58395 m .34073 .58721 L .34119 .58765 L F
.22 .161 .575 r
.33208 .52959 m .33419 .53024 L .33295 .53097 L F
.901 .803 .742 r
.28444 .64638 m .28621 .6493 L .28335 .64868 L F
0 .056 .584 r
.28324 .6524 m .28335 .64868 L .28621 .6493 L F
.582 .694 .918 r
.28919 .64857 m .28621 .6493 L .28444 .64638 L F
.903 .586 .436 r
.59668 .42442 m .59879 .42265 L .59661 .42179 L F
.59668 .42442 m .59957 .42485 L .59879 .42265 L F
.924 .593 .395 r
.68018 .314 m .68039 .31636 L .68223 .31726 L F
.918 .605 .437 r
.68039 .31636 m .68253 .31964 L .68223 .31726 L F
.808 .999 .844 r
.45565 .59367 m .46204 .59029 L .46063 .58932 L F
.803 .966 .91 r
.46204 .59029 m .46371 .58709 L .46063 .58932 L F
.46204 .59029 m .46514 .58771 L .46371 .58709 L F
0 .161 .671 r
.70888 .30055 m .7118 .30288 L .71255 .30403 L F
.581 .797 .981 r
.29336 .55513 m .28878 .55409 L .29124 .55348 L F
.28878 .55409 m .29336 .55513 L .29124 .55348 L F
.459 .762 .995 r
.29124 .55348 m .29582 .55444 L .29336 .55513 L F
.29124 .55348 m .29582 .55444 L .29336 .55513 L F
.403 .781 .992 r
.31383 .51369 m .31803 .51433 L .31552 .51505 L F
.31803 .51433 m .31383 .51369 L .31552 .51505 L F
.546 .806 .994 r
.31803 .51433 m .31552 .51505 L .31383 .51369 L F
.78 .882 .461 r
.49839 .44707 m .49958 .44552 L .49929 .44524 L F
.981 .717 .452 r
.4205 .54318 m .42218 .54165 L .42056 .54038 L F
.4205 .54318 m .42217 .54442 L .42218 .54165 L F
.588 .947 .874 r
.60215 .38989 m .60407 .38969 L .60616 .38836 L F
.89 .965 .833 r
.41112 .59103 m .41263 .58691 L .41301 .58765 L F
.914 .889 .793 r
.31083 .62028 m .30746 .62336 L .3101 .62055 L F
.272 .76 .674 r
.31083 .62028 m .31244 .61962 L .31409 .61953 L F
.31083 .62028 m .3101 .62055 L .31244 .61962 L F
.49 .54 .835 r
.32535 .52806 m .32596 .52378 L .32481 .52508 L F
.32535 .52806 m .3276 .52762 L .32596 .52378 L F
.851 .688 .68 r
.37049 .5971 m .37232 .60106 L .37273 .5984 L F
0 0 .074 r
.27804 .52418 m .27704 .52537 L .2789 .52163 L F
.558 .411 .637 r
.27804 .52418 m .27564 .52753 L .27704 .52537 L F
.89 .965 .833 r
.41112 .59103 m .40942 .59092 L .41263 .58691 L F
.127 0 0 r
.64984 .33103 m .64915 .33224 L .65246 .32998 L F
.941 .718 .571 r
.47336 .58159 m .47458 .58165 L .47302 .57749 L F
.709 .937 .627 r
.47293 .583 m .47458 .58165 L .47336 .58159 L F
.546 .512 .769 r
.4555 .5803 m .45663 .58354 L .45417 .58382 L F
.785 .724 .795 r
.34922 .62665 m .3536 .62724 L .35187 .62325 L F
.793 .727 .791 r
.35187 .62325 m .3536 .62724 L .35606 .62357 L F
0 0 0 r
.50891 .44204 m .51209 .43942 L .51171 .44188 L F
.346 .103 .395 r
.51171 .44188 m .51209 .43942 L .5145 .43852 L F
.385 0 .055 r
.66437 .33362 m .66298 .33556 L .66035 .33581 L F
.583 .143 .171 r
.66741 .33531 m .66298 .33556 L .66437 .33362 L F
.582 .148 .183 r
.6668 .33394 m .66741 .33531 L .66437 .33362 L F
.848 .595 .556 r
.39485 .56135 m .39231 .56351 L .39239 .56089 L F
.39485 .56135 m .39478 .56426 L .39231 .56351 L F
.936 .817 .703 r
.57596 .42928 m .57763 .42605 L .57595 .42444 L F
.516 .834 .527 r
.60535 .36394 m .60422 .36498 L .60253 .36671 L F
.648 .964 .801 r
.42839 .4496 m .42929 .44798 L .43079 .44863 L F
.42839 .4496 m .42623 .45026 L .42929 .44798 L F
.593 .762 .959 r
.28651 .59096 m .28429 .59199 L .28236 .59005 L F
.28651 .59096 m .28429 .59199 L .28236 .59005 L F
.973 .915 .586 r
.5437 .47262 m .54425 .46767 L .54618 .46916 L F
.5437 .47262 m .54292 .47166 L .54425 .46767 L F
.898 .984 .79 r
.5437 .47262 m .54193 .47266 L .54292 .47166 L F
.782 .73 .804 r
.47145 .55505 m .46895 .55773 L .47326 .55827 L F
.786 .632 .69 r
.46856 .5605 m .47326 .55827 L .46895 .55773 L F
.46856 .5605 m .47265 .56065 L .47326 .55827 L F
.752 .519 .579 r
.41354 .46227 m .41331 .465 L .41109 .46384 L F
.734 .538 .627 r
.41751 .46236 m .41331 .465 L .41354 .46227 L F
.743 .871 .939 r
.51935 .41186 m .51691 .41357 L .51586 .41226 L F
.869 .907 .854 r
.32726 .60753 m .32707 .61105 L .32435 .60974 L F
.907 .716 .633 r
.32435 .60974 m .32707 .61105 L .32621 .61369 L F
.609 .535 .746 r
.33747 .6499 m .33783 .65284 L .33504 .6532 L F
.569 .46 .69 r
.33783 .65284 m .33615 .65723 L .33504 .6532 L F
0 0 0 r
.59711 .34822 m .59681 .34866 L .59829 .34698 L F
.634 .194 .187 r
.60108 .34891 m .59681 .34866 L .59829 .34698 L F
0 .276 .776 r
.57312 .38364 m .57151 .38376 L .57059 .38165 L F
.57312 .38364 m .57407 .3854 L .57151 .38376 L F
0 0 0 r
.66708 .35749 m .66585 .3573 L .6677 .35836 L F
.934 .947 .613 r
.66563 .35837 m .66649 .35668 L .66708 .35749 L F
0 0 0 r
.66708 .35749 m .66786 .35632 L .66585 .3573 L F
.934 .947 .613 r
.66649 .35668 m .66673 .35621 L .66708 .35749 L F
0 0 0 r
.66708 .35749 m .6677 .35836 L .66868 .35892 L F
.724 .669 .796 r
.31983 .53495 m .31529 .5325 L .31674 .53193 L F
.31983 .53495 m .31674 .53193 L .31788 .53169 L F
.566 .557 .802 r
.32077 .53019 m .31983 .53495 L .31778 .53153 L F
.162 0 0 r
.31697 .53235 m .31904 .53213 L .31979 .53129 L F
.31825 .53162 m .31979 .53129 L .32077 .53019 L F
.31697 .53235 m .31979 .53129 L .31825 .53162 L F
.724 .669 .796 r
.31788 .53169 m .31674 .53193 L .31778 .53153 L F
.566 .557 .802 r
.32077 .53019 m .32264 .53457 L .31983 .53495 L F
.172 0 0 r
.32264 .53457 m .31784 .53539 L .31983 .53495 L F
.06 .537 .893 r
.34702 .65322 m .34577 .65367 L .34416 .65259 L F
.34702 .65322 m .34577 .65367 L .34416 .65259 L F
.734 .538 .627 r
.41751 .46236 m .41779 .46536 L .41331 .465 L F
.677 .272 .271 r
.41751 .46236 m .42057 .46328 L .41934 .46425 L F
.385 .28 .611 r
.41934 .46425 m .41779 .46536 L .41751 .46236 L F
.194 .097 .509 r
.25467 .56 m .25305 .55793 L .25518 .55753 L F
.25467 .56 m .25321 .56101 L .25305 .55793 L F
.565 .162 .236 r
.29147 .6026 m .2964 .60088 L .29214 .60128 L F
0 0 .01 r
.57541 .40183 m .57293 .40574 L .57511 .40262 L F
.57541 .40183 m .57453 .4042 L .57293 .40574 L F
.495 .826 .528 r
.57293 .40574 m .57453 .4042 L .57139 .40714 L F
.565 .92 .956 r
.45009 .59684 m .45141 .59527 L .44889 .59382 L F
.45009 .59684 m .45249 .59573 L .45141 .59527 L F
.612 .153 .139 r
.42109 .60391 m .42457 .60396 L .42352 .6058 L F
.536 .263 .447 r
.42457 .60396 m .42733 .60595 L .42352 .6058 L F
.42457 .60396 m .42742 .60363 L .42733 .60595 L F
.506 .882 .973 r
.61589 .3823 m .61768 .3807 L .6188 .38091 L F
.61589 .3823 m .61499 .38162 L .61768 .3807 L F
.857 .514 .403 r
.34902 .56433 m .34582 .56118 L .35046 .56174 L F
.164 .265 .722 r
.29046 .58252 m .292 .58457 L .29032 .57994 L F
.805 .726 .777 r
.54073 .3825 m .53657 .38237 L .5393 .37891 L F
.956 .813 .662 r
.53738 .3824 m .53887 .38161 L .53657 .38237 L F
.54073 .3825 m .53899 .38166 L .53738 .3824 L F
.53899 .38166 m .53887 .38161 L .53738 .3824 L F
.717 .571 .688 r
.54046 .38411 m .53802 .38636 L .54073 .3825 L F
.956 .813 .662 r
.54073 .3825 m .54046 .38411 L .53868 .38219 L F
.528 .33 .556 r
.53657 .38237 m .53801 .38257 L .53887 .38161 L F
.53801 .38257 m .53853 .38264 L .53868 .38219 L F
.53801 .38257 m .53868 .38219 L .53887 .38161 L F
.956 .813 .662 r
.54073 .3825 m .53868 .38219 L .53887 .38161 L F
.97 .714 .49 r
.54189 .37826 m .5409 .38188 L .5393 .37891 L F
.5409 .38188 m .54073 .3825 L .54051 .38194 L F
.5409 .38188 m .54051 .38194 L .5393 .37891 L F
.54189 .37826 m .54351 .38149 L .54073 .3825 L F
.435 .27 .558 r
.54138 .38057 m .54113 .38103 L .54179 .3809 L F
.728 .824 .924 r
.54023 .38121 m .54349 .38149 L .54179 .3809 L F
.54037 .38122 m .54046 .38411 L .54351 .38149 L F
.53985 .38152 m .54046 .38411 L .54037 .38122 L F
.53868 .38219 m .53882 .38234 L .53985 .38152 L F
.53882 .38234 m .54046 .38411 L .53985 .38152 L F
.435 .27 .558 r
.54057 .38094 m .54013 .38286 L .54138 .38057 L F
.5398 .38129 m .53985 .38152 L .54057 .38094 L F
.53985 .38152 m .54013 .38286 L .54057 .38094 L F
.54113 .38103 m .54013 .38286 L .54179 .3809 L F
.5393 .37891 m .5398 .38129 L .54057 .38094 L F
.5412 .38044 m .54057 .38094 L .54138 .38057 L F
.5393 .37891 m .54057 .38094 L .5412 .38044 L F
.528 .33 .556 r
.53657 .38237 m .5398 .38129 L .5393 .37891 L F
.956 .813 .662 r
.53887 .38161 m .53757 .38099 L .53657 .38237 L F
.53887 .38161 m .53868 .38219 L .53757 .38099 L F
.728 .824 .924 r
.53757 .38099 m .53868 .38219 L .53985 .38152 L F
.54023 .38121 m .53985 .38152 L .54037 .38122 L F
.53757 .38099 m .53985 .38152 L .54023 .38121 L F
.53757 .38099 m .54023 .38121 L .54179 .3809 L F
.54349 .38149 m .54351 .38149 L .5435 .38148 L F
.54349 .38149 m .5435 .38148 L .54179 .3809 L F
.528 .33 .556 r
.53887 .38161 m .54013 .38286 L .5398 .38129 L F
.53853 .38264 m .54013 .38286 L .53887 .38161 L F
.836 .656 .659 r
.35106 .57076 m .34707 .57039 L .34749 .56751 L F
.949 .714 .549 r
.34817 .57144 m .34586 .57247 L .34589 .57224 L F
.935 .731 .603 r
.35031 .57069 m .34817 .57144 L .34707 .57039 L F
0 0 0 r
.3455 .57222 m .34443 .57374 L .34707 .57039 L F
.991 .848 .483 r
.34749 .56751 m .34707 .57039 L .34647 .56803 L F
.949 .714 .549 r
.34817 .57144 m .34647 .56803 L .34707 .57039 L F
.34817 .57144 m .34589 .57224 L .34647 .56803 L F
.935 .731 .603 r
.35106 .57076 m .34817 .57144 L .35031 .57069 L F
.35106 .57076 m .35047 .57219 L .34817 .57144 L F
.565 .5 .741 r
.5926 .3669 m .59593 .36954 L .59469 .36561 L F
.907 .759 .686 r
.36781 .60292 m .36949 .60436 L .36782 .60049 L F
.82 .722 .757 r
.36537 .60653 m .36949 .60436 L .36781 .60292 L F
.36537 .60653 m .36692 .60776 L .36949 .60436 L F
.783 .717 .791 r
.36782 .60049 m .36949 .60436 L .37232 .60106 L F
.443 .327 .627 r
.27312 .53123 m .2735 .53388 L .27092 .53196 L F
.397 .332 .668 r
.27092 .53196 m .2735 .53388 L .27149 .53453 L F
.978 .873 .662 r
.39395 .57108 m .39256 .57064 L .39381 .56691 L F
.945 .682 .506 r
.39395 .57108 m .39178 .57313 L .39256 .57064 L F
.39395 .57108 m .39383 .5744 L .39178 .57313 L F
.514 .341 .583 r
.40982 .55397 m .40977 .55719 L .40655 .55484 L F
.82 .6 .605 r
.71873 .30942 m .72146 .30764 L .71944 .30646 L F
.71873 .30942 m .72123 .31036 L .72146 .30764 L F
.727 .733 .856 r
.33067 .65242 m .33243 .65423 L .3281 .65369 L F
.914 .979 .763 r
.33504 .64898 m .33243 .65423 L .33067 .65242 L F
.496 0 0 r
.32152 .5037 m .32455 .50404 L .32615 .50245 L F
.484 0 0 r
.32615 .50245 m .32455 .50404 L .3284 .50369 L F
.813 .896 .901 r
.53012 .47391 m .52586 .47488 L .52762 .4728 L F
.823 .926 .902 r
.5325 .47188 m .53012 .47391 L .52762 .4728 L F
.554 .471 .715 r
.6488 .36049 m .65262 .36262 L .6509 .35936 L F
.565 .466 .701 r
.64999 .36384 m .65262 .36262 L .6488 .36049 L F
.748 .449 .477 r
.67629 .31587 m .68018 .314 L .67656 .31224 L F
.67629 .31587 m .68039 .31636 L .68018 .314 L F
.02 0 .202 r
.28024 .52236 m .27804 .52418 L .2789 .52163 L F
.442 .41 .727 r
.52066 .42156 m .51749 .42015 L .51784 .41559 L F
.52066 .42156 m .51873 .42295 L .51749 .42015 L F
0 .029 .583 r
.32433 .52147 m .32596 .52378 L .32494 .51983 L F
.134 .115 .569 r
.32433 .52147 m .32481 .52508 L .32596 .52378 L F
.604 .95 .909 r
.54145 .4816 m .54301 .47992 L .54099 .48166 L F
.54145 .4816 m .54515 .47985 L .54301 .47992 L F
.108 0 0 r
.66076 .38252 m .66331 .38259 L .66005 .38271 L F
.311 0 0 r
.44331 .58884 m .4463 .58696 L .44281 .58698 L F
0 0 0 r
.51233 .4887 m .51032 .49264 L .51152 .49068 L F
.645 .95 .735 r
.51546 .48605 m .51233 .4887 L .51365 .48691 L F
0 0 0 r
.51152 .49068 m .51365 .48691 L .51233 .4887 L F
.505 .251 .462 r
.54646 .39316 m .54352 .39605 L .54366 .39313 L F
.54646 .39316 m .54628 .39567 L .54352 .39605 L F
.513 .347 .593 r
.549 .38953 m .54918 .39243 L .54646 .39316 L F
.481 .241 .473 r
.54918 .39243 m .54628 .39567 L .54646 .39316 L F
.947 .939 .748 r
.32679 .51579 m .32689 .51333 L .32909 .51505 L F
.32679 .51579 m .3245 .51715 L .32689 .51333 L F
.852 .954 .879 r
.56506 .45694 m .56797 .45632 L .56641 .45503 L F
.657 .94 .68 r
.51032 .49264 m .51151 .49088 L .51152 .49068 L F
.51032 .49264 m .50848 .49379 L .51151 .49088 L F
.838 .731 .746 r
.36834 .57657 m .36985 .58069 L .37046 .57781 L F
.365 .038 .271 r
.27755 .51326 m .27939 .51416 L .28039 .51112 L F
.583 .242 .356 r
.28039 .51112 m .28427 .513 L .28276 .51109 L F
.28039 .51112 m .27939 .51416 L .28429 .51304 L F
.807 .334 .092 r
.28276 .51109 m .28507 .51403 L .28685 .51439 L F
.583 .242 .356 r
.28427 .513 m .28429 .51304 L .28433 .51303 L F
.28039 .51112 m .28429 .51304 L .28427 .513 L F
0 0 .167 r
.27939 .51416 m .28428 .51306 L .28429 .51304 L F
.27939 .51416 m .28031 .51504 L .28386 .51326 L F
.28378 .51317 m .28386 .51326 L .28428 .51306 L F
.27939 .51416 m .28386 .51326 L .28378 .51317 L F
.807 .334 .092 r
.28427 .513 m .28474 .51396 L .28507 .51403 L F
0 0 .167 r
.28429 .51304 m .28428 .51306 L .28433 .51303 L F
.666 .972 .815 r
.28428 .51306 m .28031 .51504 L .28228 .51355 L F
.807 .334 .092 r
.28276 .51109 m .28474 .51396 L .28427 .513 L F
.666 .972 .815 r
.28433 .51303 m .28428 .51306 L .28425 .51305 L F
.807 .334 .092 r
.28414 .51309 m .28418 .51323 L .2842 .51318 L F
.28409 .5131 m .28418 .51323 L .28414 .51309 L F
.2842 .51318 m .28465 .51394 L .28474 .51396 L F
.28418 .51323 m .28465 .51394 L .2842 .51318 L F
.801 .34 .139 r
.28433 .51303 m .28465 .51394 L .28409 .5131 L F
.807 .334 .092 r
.28276 .51109 m .28409 .5131 L .28414 .51309 L F
.583 .242 .356 r
.28427 .513 m .28433 .51303 L .28276 .51109 L F
.801 .34 .139 r
.28433 .51303 m .28409 .5131 L .28276 .51109 L F
.666 .972 .815 r
.28433 .51303 m .28425 .51305 L .28304 .51297 L F
.28428 .51306 m .28228 .51355 L .28304 .51297 L F
.735 .699 .817 r
.28276 .51319 m .28031 .51504 L .28414 .51381 L F
.574 .593 .834 r
.28465 .51394 m .28472 .51552 L .28685 .51439 L F
0 0 0 r
.28407 .51654 m .28184 .51848 L .28472 .51552 L F
.574 .593 .834 r
.28465 .51394 m .28407 .51654 L .28472 .51552 L F
.28465 .51394 m .28628 .51674 L .28407 .51654 L F
.196 .387 .825 r
.28465 .51394 m .28779 .51549 L .28628 .51674 L F
.285 .018 .321 r
.28541 .51869 m .28407 .51654 L .28628 .51674 L F
.28541 .51869 m .28302 .51973 L .28407 .51654 L F
0 0 0 r
.28779 .51549 m .28541 .51869 L .28628 .51674 L F
.742 .944 .622 r
.2875 .51572 m .28541 .51869 L .28779 .51549 L F
.353 0 0 r
.28564 .51451 m .28779 .51549 L .28653 .51487 L F
.28543 .51443 m .28709 .51519 L .28564 .51451 L F
.28424 .51385 m .28653 .51487 L .28465 .51394 L F
.722 .851 .419 r
.28509 .51425 m .28629 .51461 L .28489 .51357 L F
.504 .774 .993 r
.28652 .51447 m .28784 .51521 L .28624 .51464 L F
.28809 .51359 m .28789 .51484 L .28652 .51447 L F
.28789 .51484 m .28784 .51521 L .28652 .51447 L F
.722 .851 .419 r
.28629 .51461 m .28652 .51447 L .28489 .51357 L F
.353 0 0 r
.28437 .51388 m .28465 .51394 L .2842 .51367 L F
.688 .373 .437 r
.28414 .51381 m .28509 .51425 L .28489 .51357 L F
.467 0 0 r
.28489 .51357 m .28652 .51447 L .28374 .51374 L F
.722 .851 .419 r
.28629 .51461 m .28729 .5149 L .28652 .51447 L F
.807 .334 .092 r
.28276 .51109 m .28685 .51439 L .28747 .51282 L F
.666 .972 .815 r
.28433 .51303 m .28304 .51297 L .28465 .51394 L F
.504 .774 .993 r
.28809 .51359 m .28624 .51464 L .28374 .51374 L F
.467 0 0 r
.28652 .51447 m .28729 .5149 L .28374 .51374 L F
.504 .774 .993 r
.2881 .51348 m .28809 .51359 L .28374 .51374 L F
.28784 .51521 m .28779 .51549 L .28709 .51519 L F
.688 .373 .437 r
.28066 .51499 m .28531 .51513 L .28509 .51425 L F
.28585 .51739 m .28585 .51676 L .28509 .51425 L F
.353 0 0 r
.28374 .51374 m .28605 .51474 L .28543 .51443 L F
.28605 .51474 m .28709 .51519 L .28543 .51443 L F
.722 .851 .419 r
.28607 .51747 m .28711 .51528 L .28605 .51474 L F
.28536 .51513 m .28605 .51474 L .28509 .51425 L F
.28607 .51747 m .28605 .51474 L .28536 .51513 L F
.353 0 0 r
.28709 .51519 m .28779 .51549 L .28564 .51451 L F
.504 .774 .993 r
.28784 .51521 m .28709 .51519 L .28605 .51474 L F
.28784 .51521 m .28605 .51474 L .28624 .51464 L F
.722 .851 .419 r
.28711 .51528 m .28729 .5149 L .28509 .51425 L F
.688 .373 .437 r
.28031 .51504 m .28509 .51425 L .28414 .51381 L F
.353 0 0 r
.28374 .51374 m .28653 .51487 L .28424 .51385 L F
.504 .774 .993 r
.28624 .51464 m .28605 .51474 L .28374 .51374 L F
.688 .373 .437 r
.28031 .51504 m .28585 .51739 L .28531 .51513 L F
.28031 .51504 m .28531 .51513 L .28066 .51499 L F
.28585 .51739 m .28606 .51748 L .28585 .51676 L F
.742 .944 .622 r
.28586 .51773 m .28541 .51869 L .2875 .51572 L F
.652 .653 .838 r
.28541 .51869 m .28672 .5217 L .28385 .52308 L F
.093 .604 .89 r
.28571 .52091 m .28672 .5217 L .28541 .51869 L F
.812 .777 .821 r
.28586 .51773 m .28571 .52091 L .28541 .51869 L F
.722 .851 .419 r
.28607 .51748 m .28611 .5174 L .28607 .51747 L F
.688 .373 .437 r
.28606 .51748 m .28607 .51747 L .28509 .51425 L F
.28031 .51504 m .2794 .51976 L .28607 .51748 L F
.734 .988 .89 r
.28605 .51748 m .28403 .51694 L .28638 .5166 L F
.742 .944 .622 r
.28638 .5166 m .28586 .51773 L .28604 .5175 L F
.28638 .5166 m .28604 .5175 L .28607 .51747 L F
.688 .373 .437 r
.28606 .51748 m .28607 .51748 L .28607 .51747 L F
.734 .988 .89 r
.28607 .51748 m .28605 .51748 L .28638 .5166 L F
.722 .851 .419 r
.28611 .5174 m .28729 .5149 L .28607 .51747 L F
.742 .944 .622 r
.28638 .5166 m .28607 .51747 L .28611 .5174 L F
.722 .851 .419 r
.28646 .51667 m .28638 .5166 L .28729 .5149 L F
.28611 .5174 m .28638 .5166 L .28646 .51667 L F
.652 .247 0 r
.28594 .51606 m .28638 .5166 L .28403 .51694 L F
.742 .944 .622 r
.28638 .5166 m .28611 .5174 L .28652 .51677 L F
.722 .851 .419 r
.28607 .51748 m .28638 .5166 L .28611 .5174 L F
.812 .777 .821 r
.28638 .5166 m .28588 .51984 L .28586 .51773 L F
.742 .944 .622 r
.28652 .51677 m .28607 .51747 L .28658 .51685 L F
.812 .777 .821 r
.28638 .5166 m .28677 .52126 L .28571 .52091 L F
.093 .604 .89 r
.28644 .52148 m .28863 .52187 L .28672 .5217 L F
.28571 .52091 m .28677 .52126 L .28644 .52148 L F
.28677 .52126 m .28863 .52187 L .28644 .52148 L F
0 0 .416 r
.28745 .51865 m .2869 .52117 L .28638 .5166 L F
0 0 .147 r
.28571 .52091 m .28672 .5217 L .28713 .52174 L F
.28695 .52131 m .28713 .52174 L .28877 .52189 L F
.28571 .52091 m .28713 .52174 L .28695 .52131 L F
0 0 .416 r
.2869 .52117 m .2868 .52161 L .28677 .52126 L F
.682 .805 .941 r
.28672 .5217 m .28836 .52358 L .28385 .52308 L F
.504 .304 .543 r
.28672 .5217 m .28385 .52308 L .28836 .52358 L F
.28672 .5217 m .28405 .52606 L .28385 .52308 L F
0 0 0 r
.28514 .5247 m .28405 .52606 L .28672 .5217 L F
0 0 .147 r
.28571 .52091 m .28514 .5247 L .28672 .5217 L F
.28516 .52456 m .28567 .52407 L .28514 .5247 L F
.28571 .52091 m .28569 .52287 L .28516 .52456 L F
.28569 .52287 m .28567 .52407 L .28516 .52456 L F
.849 .662 .124 r
.28532 .52245 m .28567 .52407 L .28571 .52091 L F
.28532 .52245 m .28571 .52091 L .2868 .52161 L F
.814 .939 .576 r
.2869 .52117 m .28599 .52191 L .2868 .52161 L F
.28599 .52191 m .28532 .52245 L .28593 .52211 L F
.28599 .52191 m .28593 .52211 L .2868 .52161 L F
0 0 .416 r
.2869 .52117 m .28677 .52126 L .28638 .5166 L F
.814 .939 .576 r
.28745 .51865 m .28653 .5203 L .2869 .52117 L F
.812 .777 .821 r
.28677 .52126 m .2868 .52161 L .28571 .52091 L F
.093 .604 .89 r
.28571 .52091 m .28877 .52189 L .28863 .52187 L F
.814 .939 .576 r
.28653 .5203 m .28532 .52245 L .2869 .52117 L F
.552 .7 .938 r
.28365 .51711 m .28594 .51606 L .28403 .51694 L F
.28365 .51711 m .28668 .5173 L .28594 .51606 L F
.652 .247 0 r
.28597 .51611 m .28616 .51643 L .28638 .5166 L F
.2863 .51654 m .28745 .51865 L .28638 .5166 L F
.28615 .51642 m .28676 .51747 L .2863 .51654 L F
.742 .944 .622 r
.28638 .5166 m .28658 .51685 L .2875 .51572 L F
.847 .96 .622 r
.2881 .51348 m .28638 .5166 L .28779 .51549 L F
0 0 0 r
.28729 .5149 m .28638 .5166 L .2881 .51348 L F
.488 .714 .971 r
.28711 .51733 m .28816 .51566 L .28594 .51606 L F
.28711 .51733 m .28955 .5169 L .28816 .51566 L F
.558 .684 .924 r
.28816 .51566 m .28776 .51737 L .28594 .51606 L F
.652 .247 0 r
.28678 .5175 m .28745 .51865 L .28662 .51713 L F
.558 .684 .924 r
.28776 .51737 m .28745 .51865 L .28678 .5175 L F
.652 .247 0 r
.28676 .51747 m .28678 .5175 L .2863 .51654 L F
.28678 .5175 m .28662 .51713 L .2863 .51654 L F
0 0 .021 r
.28668 .5173 m .28676 .51747 L .28711 .51733 L F
.558 .684 .924 r
.28689 .51749 m .28678 .5175 L .28676 .51747 L F
0 0 .021 r
.28676 .51747 m .2868 .51754 L .28688 .51749 L F
.28676 .51747 m .28688 .51749 L .28711 .51733 L F
.652 .247 0 r
.28594 .51606 m .28597 .5161 L .28638 .5166 L F
.552 .7 .938 r
.28668 .5173 m .28711 .51733 L .28594 .51606 L F
.558 .684 .924 r
.28776 .51737 m .28689 .51749 L .28594 .51606 L F
.652 .247 0 r
.28597 .5161 m .28615 .51642 L .28616 .51643 L F
.28597 .5161 m .28616 .51643 L .28597 .51611 L F
.558 .684 .924 r
.28689 .51749 m .28676 .51747 L .28594 .51606 L F
.312 .628 .961 r
.28955 .5169 m .29111 .51609 L .28816 .51566 L F
.711 .454 .536 r
.28933 .51706 m .29111 .51609 L .28955 .5169 L F
.39 .598 .929 r
.29073 .5169 m .29007 .51827 L .2892 .51707 L F
.29073 .5169 m .2892 .51707 L .28816 .51566 L F
.129 0 0 r
.28711 .51733 m .28708 .51746 L .28839 .51716 L F
.28743 .51727 m .28839 .51716 L .28955 .5169 L F
.28711 .51733 m .28839 .51716 L .28743 .51727 L F
.558 .684 .924 r
.28776 .51737 m .29007 .51827 L .28745 .51865 L F
.129 0 0 r
.28708 .51746 m .28872 .51723 L .28955 .5169 L F
.558 .684 .924 r
.28816 .51566 m .2892 .51707 L .28776 .51737 L F
.2892 .51707 m .29007 .51827 L .28776 .51737 L F
.129 0 0 r
.28776 .51737 m .28697 .51793 L .28872 .51723 L F
.28708 .51746 m .28707 .51751 L .28776 .51737 L F
.28707 .51751 m .28697 .51793 L .28776 .51737 L F
.711 .454 .536 r
.28675 .51885 m .29111 .51609 L .28933 .51706 L F
.39 .598 .929 r
.29111 .51609 m .29073 .5169 L .29014 .51662 L F
.29111 .51609 m .29014 .51662 L .28816 .51566 L F
.129 0 0 r
.28697 .51793 m .28675 .51885 L .28722 .51852 L F
.28697 .51793 m .28722 .51852 L .28955 .5169 L F
.812 .777 .821 r
.28588 .51984 m .28571 .52091 L .28586 .51773 L F
.652 .653 .838 r
.28541 .51869 m .28385 .52308 L .28302 .51973 L F
0 0 .159 r
.2794 .51976 m .28094 .51904 L .28607 .51748 L F
.734 .988 .89 r
.28607 .51748 m .28189 .51875 L .28377 .51712 L F
.28189 .51875 m .28131 .51893 L .2834 .51739 L F
.28189 .51875 m .2834 .51739 L .28377 .51712 L F
.691 .613 .764 r
.28302 .51973 m .28385 .52308 L .28024 .52236 L F
0 0 .021 r
.28366 .51716 m .28242 .52066 L .28407 .51943 L F
.634 .446 .611 r
.28403 .51694 m .28377 .51712 L .28365 .51711 L F
.28377 .51712 m .28094 .51904 L .28365 .51711 L F
.734 .988 .89 r
.28607 .51748 m .28377 .51712 L .28417 .51698 L F
0 0 .021 r
.28365 .51711 m .2868 .51754 L .28668 .51731 L F
.28365 .51711 m .28668 .51731 L .28668 .5173 L F
.28365 .51711 m .28362 .51719 L .28366 .51716 L F
.28362 .51719 m .28242 .52066 L .28366 .51716 L F
.151 0 .098 r
.27981 .52109 m .28242 .52066 L .28362 .51719 L F
.28344 .51733 m .28362 .51719 L .28365 .51711 L F
.27981 .52109 m .28362 .51719 L .28344 .51733 L F
.734 .988 .89 r
.28131 .51893 m .28094 .51904 L .28322 .51749 L F
.28131 .51893 m .28322 .51749 L .28377 .51712 L F
.28417 .51698 m .28377 .51712 L .28403 .51694 L F
0 0 .021 r
.28375 .51713 m .28407 .51943 L .2868 .51754 L F
.28365 .51711 m .28366 .51716 L .28375 .51713 L F
.28366 .51716 m .28407 .51943 L .28375 .51713 L F
.735 .699 .817 r
.28304 .51297 m .28276 .51319 L .28417 .5138 L F
.28276 .51319 m .28414 .51381 L .28417 .5138 L F
.353 0 0 r
.28424 .51385 m .28437 .51388 L .28304 .51297 L F
.28437 .51388 m .2842 .51367 L .28304 .51297 L F
.735 .699 .817 r
.28304 .51297 m .28417 .5138 L .28489 .51357 L F
.353 0 0 r
.28374 .51374 m .28424 .51385 L .28304 .51297 L F
.503 .826 1 r
.70844 .30341 m .7118 .30288 L .71255 .30403 L F
.514 .833 .999 r
.7118 .30288 m .71565 .30316 L .71255 .30403 L F
.508 .392 .656 r
.71255 .30403 m .71565 .30316 L .7118 .30288 L F
.631 .807 .967 r
.71804 .30361 m .71255 .30403 L .71565 .30316 L F
.508 .392 .656 r
.71255 .30403 m .71528 .30575 L .71565 .30316 L F
.602 .753 .95 r
.30107 .65167 m .29679 .65115 L .29936 .6509 L F
.472 .72 .978 r
.30209 .65004 m .30107 .65167 L .29936 .6509 L F
.30209 .65004 m .30436 .65228 L .30107 .65167 L F
.291 .386 .788 r
.25396 .57321 m .2528 .57447 L .25138 .57044 L F
.698 .448 .542 r
.25396 .57321 m .25074 .57612 L .2528 .57447 L F
.831 .691 .709 r
.29127 .66907 m .29373 .66681 L .29023 .66668 L F
.183 .283 .733 r
.29373 .66681 m .29477 .66834 L .29601 .6659 L F
.742 .85 .93 r
.58941 .3519 m .58478 .35208 L .58751 .3508 L F
.853 .743 .741 r
.35999 .61347 m .36402 .61381 L .36244 .60993 L F
.845 .772 .781 r
.36129 .61703 m .36402 .61381 L .35999 .61347 L F
.6 .577 .8 r
.53172 .42221 m .53315 .42634 L .53582 .42545 L F
.44 .862 .727 r
.37126 .47464 m .3727 .47353 L .36941 .47368 L F
.661 .842 .432 r
.37272 .47322 m .3727 .47353 L .37381 .47144 L F
.44 .862 .727 r
.37126 .47464 m .37268 .47386 L .3727 .47353 L F
.439 0 .046 r
.36941 .47368 m .3727 .47353 L .37126 .47558 L F
.661 .842 .432 r
.37126 .47558 m .3727 .47353 L .37272 .47322 L F
.44 .862 .727 r
.37268 .47386 m .3749 .47263 L .3727 .47353 L F
.864 .826 .808 r
.54861 .46564 m .54618 .46916 L .54425 .46767 L F
.928 .59 .141 r
.40721 .51679 m .40898 .52081 L .40887 .51654 L F
.896 .598 .474 r
.39238 .55756 m .38877 .55659 L .38929 .55419 L F
.917 .678 .563 r
.39238 .55756 m .38925 .55955 L .38877 .55659 L F
.39238 .55756 m .39239 .56089 L .38925 .55955 L F
0 .056 .584 r
.28324 .6524 m .28461 .65176 L .28335 .64868 L F
0 0 .319 r
.28324 .6524 m .28424 .65493 L .28461 .65176 L F
.28324 .6524 m .28307 .65639 L .28424 .65493 L F
.212 0 0 r
.41934 .45249 m .4186 .45187 L .41672 .45313 L F
.41934 .45249 m .42129 .45208 L .4186 .45187 L F
.204 .174 .6 r
.24158 .55752 m .24284 .55286 L .24138 .5547 L F
.515 .077 .144 r
.38477 .46086 m .38733 .46087 L .38903 .45895 L F
.453 .008 .101 r
.38903 .45895 m .39229 .45987 L .39157 .45893 L F
.38903 .45895 m .38733 .46087 L .39229 .45987 L F
.715 .765 .892 r
.71436 .31595 m .71545 .31924 L .71844 .31646 L F
.973 .81 .619 r
.67294 .34043 m .67232 .34309 L .6714 .33902 L F
0 0 0 r
.53424 .42002 m .53462 .41985 L .53482 .41679 L F
.931 .866 .752 r
.48716 .53705 m .49117 .53455 L .48925 .53428 L F
.88 .918 .847 r
.48925 .53428 m .49117 .53455 L .49394 .53124 L F
.494 .837 .997 r
.30514 .60603 m .30467 .60758 L .30705 .60691 L F
.30514 .60603 m .30467 .60758 L .30705 .60691 L F
.549 .588 .845 r
.60215 .38989 m .60095 .39424 L .60134 .39175 L F
0 .027 .527 r
.58747 .43899 m .58872 .44012 L .59168 .43904 L F
.58747 .43899 m .59003 .44145 L .58872 .44012 L F
.612 .783 .963 r
.48337 .43489 m .48476 .43203 L .48147 .43377 L F
.48337 .43489 m .48631 .43415 L .48476 .43203 L F
.731 .268 0 r
.34184 .55959 m .34212 .56028 L .33955 .55703 L F
0 .056 .62 r
.45201 .53576 m .45359 .53852 L .45239 .53786 L F
.79 .338 .172 r
.45239 .53786 m .4504 .53949 L .45201 .53576 L F
.45239 .53786 m .45342 .54025 L .4504 .53949 L F
0 0 .452 r
.45239 .53786 m .45359 .53852 L .45342 .54025 L F
.395 .219 .521 r
.31935 .50187 m .31925 .50482 L .32152 .5037 L F
.729 .557 .658 r
.31723 .62285 m .31527 .62719 L .31498 .62399 L F
.75 .784 .881 r
.32636 .63346 m .32793 .63626 L .33064 .63368 L F
.67 .631 .801 r
.32793 .63626 m .33222 .6374 L .33064 .63368 L F
.944 .622 .391 r
.3384 .50994 m .34018 .50863 L .33731 .50674 L F
.3384 .50994 m .34045 .51115 L .34018 .50863 L F
.954 .77 .614 r
.35059 .52382 m .35193 .52792 L .35244 .52507 L F
.73 .955 .946 r
.66714 .38226 m .66961 .37922 L .66621 .38116 L F
.66714 .38226 m .6708 .37994 L .66961 .37922 L F
0 0 .465 r
.32136 .61316 m .32047 .61326 L .32158 .61597 L F
.96 .703 .503 r
.32136 .61316 m .32158 .61597 L .32047 .61326 L F
.63 .963 .863 r
.4964 .40691 m .49663 .40649 L .49788 .40637 L F
0 0 0 r
.49663 .40649 m .50007 .40495 L .49788 .40637 L F
.558 0 0 r
.65491 .37671 m .65612 .37691 L .65233 .37515 L F
.905 .501 .213 r
.65491 .37671 m .65502 .3765 L .65612 .37691 L F
.413 0 0 r
.65233 .37515 m .65612 .37691 L .65433 .37625 L F
.833 .826 .348 r
.65653 .37091 m .65596 .37469 L .65502 .3765 L F
.65496 .37651 m .65502 .3765 L .65491 .37671 L F
.65653 .37091 m .65502 .3765 L .65496 .37651 L F
.413 0 0 r
.65433 .37625 m .65502 .3765 L .65482 .37646 L F
.65433 .37625 m .65482 .37646 L .65456 .37637 L F
.407 0 0 r
.65334 .37586 m .65491 .37671 L .65233 .37515 L F
.974 .865 .668 r
.65653 .37091 m .65496 .37651 L .65404 .37618 L F
.604 .878 .992 r
.65377 .37599 m .6545 .3765 L .653 .37561 L F
.407 0 0 r
.65346 .37595 m .6545 .3765 L .65334 .37586 L F
.65457 .37653 m .65491 .37671 L .6545 .3765 L F
.974 .865 .668 r
.65496 .37651 m .65491 .37671 L .65457 .37653 L F
.604 .878 .992 r
.65451 .3765 m .6545 .3765 L .65377 .37599 L F
.407 0 0 r
.6545 .3765 m .65491 .37671 L .65334 .37586 L F
.958 .807 .65 r
.65233 .37515 m .65153 .37774 L .65057 .374 L F
.407 0 0 r
.65339 .3759 m .65233 .37515 L .65057 .374 L F
.604 .878 .992 r
.6545 .3765 m .65153 .37774 L .65295 .37567 L F
.6545 .3765 m .65153 .37774 L .65295 .37567 L F
.407 0 0 r
.65352 .37598 m .65346 .37595 L .65339 .3759 L F
.65346 .37595 m .65233 .37515 L .65339 .3759 L F
.38 .443 .8 r
.65348 .37583 m .65339 .3759 L .65057 .374 L F
.604 .878 .992 r
.65344 .37587 m .65316 .37574 L .653 .37561 L F
.65344 .37587 m .65319 .37577 L .65316 .37574 L F
.65319 .37577 m .65295 .37567 L .65298 .37563 L F
.65319 .37577 m .65298 .37563 L .653 .37561 L F
.6545 .3765 m .65339 .37591 L .65344 .37587 L F
.65339 .37591 m .65295 .37567 L .65344 .37587 L F
.38 .443 .8 r
.6518 .36992 m .65348 .37583 L .65057 .374 L F
.604 .878 .992 r
.6545 .3765 m .65295 .37567 L .653 .37561 L F
.38 .443 .8 r
.65348 .37583 m .65352 .37598 L .65339 .3759 L F
.407 0 0 r
.65453 .37651 m .65457 .37653 L .6545 .3765 L F
.604 .878 .992 r
.65451 .3765 m .6545 .3765 L .65377 .37599 L F
.407 0 0 r
.65352 .37598 m .65453 .37651 L .6545 .3765 L F
.65352 .37598 m .6545 .3765 L .65346 .37595 L F
.974 .865 .668 r
.6541 .37622 m .65457 .37653 L .6537 .37608 L F
.65496 .37651 m .65457 .37653 L .65451 .3765 L F
.624 .826 .978 r
.65466 .37643 m .65472 .37662 L .65453 .37651 L F
.65451 .3765 m .65453 .37651 L .6545 .3765 L F
.974 .865 .668 r
.65496 .37651 m .65451 .3765 L .65435 .3763 L F
.624 .826 .978 r
.65466 .37643 m .65453 .37651 L .65451 .3765 L F
.974 .865 .668 r
.65435 .3763 m .65451 .3765 L .6541 .37622 L F
.604 .878 .992 r
.65377 .37599 m .6545 .3765 L .653 .37561 L F
.65466 .37643 m .65451 .3765 L .65377 .37599 L F
.974 .865 .668 r
.65359 .37587 m .65404 .37618 L .65352 .37598 L F
.65653 .37091 m .65404 .37618 L .65359 .37587 L F
.604 .878 .992 r
.65466 .37643 m .65451 .3765 L .65377 .37599 L F
.624 .826 .978 r
.6545 .3765 m .65516 .37808 L .65153 .37774 L F
.65472 .37662 m .65516 .37808 L .6545 .3765 L F
.974 .865 .668 r
.65496 .37651 m .6537 .37608 L .65352 .37598 L F
.413 0 0 r
.65456 .37637 m .65482 .37646 L .65466 .37643 L F
.65502 .3765 m .65612 .37691 L .65493 .37652 L F
.65502 .3765 m .65493 .37652 L .65466 .37643 L F
.905 .501 .213 r
.65502 .3765 m .65596 .37469 L .65612 .37691 L F
.894 .974 .82 r
.65762 .37131 m .65596 .37469 L .65653 .37091 L F
.761 .253 0 r
.41713 .60037 m .41736 .60217 L .4149 .60016 L F
.41713 .60037 m .41912 .60307 L .41736 .60217 L F
.667 .133 0 r
.41713 .60037 m .42109 .60391 L .41912 .60307 L F
.151 0 0 r
.71565 .30316 m .71936 .30387 L .71804 .30361 L F
.535 .915 .769 r
.44957 .43895 m .44728 .44044 L .44543 .44112 L F
.905 .694 .188 r
.58595 .43249 m .58513 .43352 L .58435 .43054 L F
.783 .358 .242 r
.58435 .43054 m .58508 .43344 L .58314 .43268 L F
.776 .671 .747 r
.5849 .43376 m .58494 .43339 L .58314 .43268 L F
.938 .78 .314 r
.58513 .43375 m .58555 .4368 L .58493 .43376 L F
.776 .671 .747 r
.58513 .43391 m .58507 .43375 L .5849 .43376 L F
.58507 .43375 m .58494 .43339 L .5849 .43376 L F
.938 .78 .314 r
.58493 .43376 m .58555 .4368 L .58193 .43728 L F
.776 .671 .747 r
.58513 .43354 m .58475 .43288 L .58513 .43391 L F
.938 .78 .314 r
.58511 .43355 m .58513 .43375 L .58493 .43376 L F
.783 .358 .242 r
.58508 .43344 m .58511 .43355 L .58314 .43268 L F
.776 .671 .747 r
.58494 .43339 m .58475 .43288 L .58314 .43268 L F
.938 .78 .314 r
.58513 .4336 m .58597 .43522 L .58513 .43375 L F
.776 .671 .747 r
.58547 .43411 m .58513 .43354 L .58513 .43391 L F
.58339 .43519 m .58491 .43377 L .58314 .43268 L F
.76 .99 .774 r
.58511 .43355 m .58493 .43376 L .58339 .43519 L F
.58493 .43376 m .58193 .43728 L .58339 .43519 L F
.938 .78 .314 r
.58513 .43375 m .58521 .43388 L .58519 .43418 L F
.776 .671 .747 r
.58339 .43519 m .58547 .43411 L .58491 .43377 L F
.777 .598 .656 r
.58474 .43695 m .58504 .4367 L .58339 .43519 L F
.938 .78 .314 r
.58519 .43418 m .58597 .43522 L .58555 .4368 L F
0 0 0 r
.58555 .4368 m .58597 .43522 L .58709 .43346 L F
.802 .738 .792 r
.58597 .43522 m .5883 .43174 L .58595 .43249 L F
0 0 0 r
.58691 .43391 m .58709 .43346 L .58726 .43319 L F
.58555 .4368 m .58709 .43346 L .58691 .43391 L F
.58555 .4368 m .58726 .43319 L .58684 .43524 L F
.777 .598 .656 r
.58504 .4367 m .58622 .43575 L .58513 .43522 L F
.58622 .43575 m .58684 .43524 L .58641 .43524 L F
.58622 .43575 m .58641 .43524 L .58513 .43522 L F
.58504 .4367 m .58513 .43522 L .58339 .43519 L F
.938 .78 .314 r
.58521 .43388 m .58597 .43522 L .58519 .43418 L F
.58511 .43355 m .58513 .4336 L .58513 .43375 L F
.905 .694 .188 r
.58513 .43352 m .58511 .43354 L .58509 .43347 L F
.58513 .43352 m .58509 .43347 L .58435 .43054 L F
.58511 .43354 m .5851 .43351 L .58435 .43054 L F
.58595 .43249 m .58597 .43522 L .58513 .4336 L F
.58513 .43352 m .58513 .4336 L .58511 .43355 L F
.58595 .43249 m .58513 .4336 L .58513 .43352 L F
0 0 .294 r
.58726 .43319 m .58597 .43522 L .58595 .43249 L F
.776 .671 .747 r
.58547 .43411 m .58726 .43319 L .58506 .43292 L F
.58513 .43352 m .58506 .43292 L .58475 .43288 L F
.58547 .43411 m .58506 .43292 L .58513 .43352 L F
.539 .74 .969 r
.5883 .43174 m .58595 .43249 L .58435 .43054 L F
0 0 .294 r
.58726 .43319 m .58595 .43249 L .5883 .43174 L F
.774 .616 .684 r
.58412 .43171 m .58726 .43319 L .58612 .42969 L F
.58314 .43268 m .58475 .43288 L .58412 .43171 L F
.58475 .43288 m .58726 .43319 L .58412 .43171 L F
.905 .694 .188 r
.58511 .43354 m .58511 .43355 L .5851 .43351 L F
.765 .861 .921 r
.5025 .42213 m .50727 .41875 L .50589 .41796 L F
.5025 .42213 m .50719 .42071 L .50727 .41875 L F
.837 .955 .891 r
.50589 .41796 m .50727 .41875 L .5102 .41611 L F
.864 .826 .808 r
.54861 .46564 m .54425 .46767 L .54696 .46411 L F
.569 .46 .69 r
.33783 .65284 m .33876 .65662 L .33615 .65723 L F
.43 0 0 r
.57485 .38647 m .5756 .38672 L .57407 .3854 L F
.786 .62 .675 r
.46856 .5605 m .4703 .56432 L .47265 .56065 L F
.859 .691 .672 r
.37008 .59989 m .37232 .60106 L .37049 .5971 L F
.783 .717 .791 r
.36782 .60049 m .37232 .60106 L .37008 .59989 L F
.833 .939 .896 r
.50019 .51939 m .50086 .52098 L .50442 .51763 L F
.374 0 .124 r
.27076 .53981 m .27084 .53861 L .27121 .53726 L F
.258 .147 .531 r
.2735 .53388 m .27121 .53726 L .27149 .53453 L F
.2735 .53388 m .2737 .53648 L .27121 .53726 L F
.562 .414 .638 r
.2737 .53648 m .27076 .53981 L .27121 .53726 L F
.328 .244 .606 r
.24267 .54488 m .24444 .54441 L .24449 .54033 L F
.202 .061 .455 r
.24277 .54757 m .24444 .54441 L .24267 .54488 L F
.514 .344 .589 r
.34327 .66254 m .34053 .66626 L .34123 .66356 L F
.956 .739 .569 r
.38305 .53507 m .38066 .5367 L .38096 .53391 L F
.38305 .53507 m .38248 .53776 L .38066 .5367 L F
.686 .922 .971 r
.46546 .44047 m .46455 .44272 L .46662 .44138 L F
.734 .966 .936 r
.46337 .44209 m .46455 .44272 L .46546 .44047 L F
.284 0 .033 r
.42282 .46153 m .42665 .45873 L .42498 .45985 L F
.493 .899 .921 r
.4278 .45755 m .42665 .45873 L .42931 .45764 L F
.488 .182 .373 r
.27337 .51762 m .27614 .51731 L .27755 .51326 L F
.37 .076 .33 r
.27614 .51731 m .27939 .51416 L .27755 .51326 L F
.187 .396 .836 r
.40114 .51108 m .40546 .51572 L .40457 .51551 L F
.818 .41 .274 r
.40152 .51536 m .40311 .51733 L .40457 .51551 L F
.497 .022 .057 r
.40457 .51551 m .40311 .51733 L .40721 .51679 L F
.818 .41 .274 r
.40152 .51536 m .40457 .51551 L .40546 .51572 L F
.878 .71 .669 r
.69419 .33566 m .69355 .33305 L .69196 .33612 L F
.928 .808 .706 r
.69125 .33861 m .69419 .33566 L .69196 .33612 L F
.69125 .33861 m .69296 .34012 L .69419 .33566 L F
.332 .255 .618 r
.23972 .56079 m .23926 .56528 L .24191 .56332 L F
.163 .143 .587 r
.23926 .56528 m .24175 .56567 L .24191 .56332 L F
.23926 .56528 m .2399 .56754 L .24175 .56567 L F
.887 .531 .364 r
.5574 .44593 m .55548 .44662 L .55454 .44424 L F
.5574 .44593 m .5579 .44839 L .55548 .44662 L F
.536 .809 .996 r
.39202 .49413 m .39427 .49537 L .38967 .495 L F
.781 .552 .588 r
.39427 .49537 m .38929 .49748 L .38967 .495 L F
.39427 .49537 m .39353 .49802 L .38929 .49748 L F
.943 .743 .603 r
.39202 .49413 m .39353 .49802 L .39427 .49537 L F
.911 .51 .212 r
.55732 .41867 m .5569 .42116 L .55674 .41757 L F
.55732 .41867 m .55867 .42191 L .5569 .42116 L F
.474 .758 .992 r
.29779 .64946 m .29679 .65115 L .29521 .64981 L F
.29779 .64946 m .29936 .6509 L .29679 .65115 L F
.839 .43 .264 r
.50323 .42438 m .50473 .42266 L .5025 .42213 L F
.765 .861 .921 r
.5025 .42213 m .50473 .42266 L .50719 .42071 L F
0 0 0 r
.50719 .42071 m .50473 .42266 L .50323 .42438 L F
.63 .963 .863 r
.4964 .40691 m .49337 .40805 L .49663 .40649 L F
.805 .653 .694 r
.45915 .58121 m .45663 .58354 L .4555 .5803 L F
.863 .975 .669 r
.57809 .3909 m .57775 .39314 L .57995 .38964 L F
.816 .845 .383 r
.57683 .39545 m .57775 .39314 L .57809 .3909 L F
.686 .746 .897 r
.59506 .3474 m .59184 .35084 L .59567 .35059 L F
.872 .898 .848 r
.59245 .35208 m .59567 .35059 L .59184 .35084 L F
.432 .56 .884 r
.59506 .3474 m .59567 .35059 L .59681 .34866 L F
.624 .811 .391 r
.59681 .34866 m .59567 .35059 L .59711 .34822 L F
.425 .06 .24 r
.3231 .67667 m .32481 .67825 L .32241 .67895 L F
.3231 .67667 m .32571 .67634 L .32481 .67825 L F
.223 0 0 r
.60362 .3429 m .60638 .34372 L .60772 .34397 L F
.298 0 0 r
.60638 .34372 m .61051 .34365 L .60772 .34397 L F
0 0 0 r
.43919 .45259 m .4374 .45387 L .4351 .45491 L F
.43919 .45259 m .43947 .4526 L .4374 .45387 L F
.43919 .45259 m .44139 .45141 L .43947 .4526 L F
.638 .551 .74 r
.26552 .54124 m .26321 .54453 L .2628 .54179 L F
.65 .567 .748 r
.26584 .54384 m .26321 .54453 L .26552 .54124 L F
.226 .301 .732 r
.57907 .37592 m .57993 .381 L .58052 .37806 L F
0 0 .353 r
.58152 .38207 m .58052 .37806 L .57993 .381 L F
.313 0 .055 r
.64557 .33483 m .64915 .33224 L .64679 .33365 L F
.746 .625 .725 r
.48208 .54089 m .4867 .54241 L .48477 .54013 L F
.48208 .54089 m .48354 .54488 L .4867 .54241 L F
.672 .732 .895 r
.48477 .54013 m .4867 .54241 L .4887 .54085 L F
.79 .971 .914 r
.54735 .47826 m .54301 .47992 L .54515 .47985 L F
.837 .716 .731 r
.49358 .528 m .49394 .53124 L .49244 .5276 L F
.88 .918 .847 r
.49301 .52884 m .49394 .53124 L .49358 .528 L F
.651 .629 .815 r
.49252 .52759 m .49253 .52761 L .4932 .52751 L F
.4932 .52749 m .4932 .52751 L .49872 .52671 L F
.49252 .52759 m .4932 .52751 L .4932 .52749 L F
.904 .892 .808 r
.49315 .52771 m .49301 .52822 L .49358 .528 L F
.49315 .52771 m .49358 .528 L .49244 .5276 L F
.91 .837 .76 r
.49301 .52822 m .49301 .52884 L .49358 .528 L F
.651 .629 .815 r
.49302 .52769 m .49394 .53124 L .497 .52833 L F
.49253 .52761 m .49301 .52884 L .49302 .52769 L F
.49301 .52884 m .49394 .53124 L .49302 .52769 L F
.49244 .5276 m .49394 .53124 L .49252 .52759 L F
.91 .837 .76 r
.48878 .52987 m .48925 .53428 L .49301 .52884 L F
.48878 .52987 m .49301 .52884 L .49301 .52822 L F
.904 .892 .808 r
.49132 .52649 m .48878 .52987 L .49301 .52822 L F
.651 .629 .815 r
.49253 .52761 m .497 .52833 L .49872 .52671 L F
.922 .95 .794 r
.49367 .52297 m .49244 .5276 L .49519 .52415 L F
.49367 .52297 m .49132 .52649 L .49244 .5276 L F
.904 .892 .808 r
.49132 .52649 m .49315 .52771 L .49244 .5276 L F
.49132 .52649 m .49301 .52822 L .49315 .52771 L F
.88 .918 .847 r
.48925 .53428 m .49394 .53124 L .49301 .52884 L F
.502 .524 .812 r
.57811 .35505 m .57687 .35919 L .57606 .35692 L F
.57811 .35505 m .57956 .35929 L .57687 .35919 L F
.781 .707 .782 r
.55884 .40466 m .56109 .40842 L .55574 .40849 L F
.879 .992 .755 r
.56109 .40842 m .55745 .41161 L .55574 .40849 L F
.56109 .40842 m .55826 .4122 L .55745 .41161 L F
.969 .685 .439 r
.56038 .40638 m .56109 .40842 L .55884 .40466 L F
.627 .608 .811 r
.58743 .34655 m .59184 .35084 L .59009 .34583 L F
.724 .899 .958 r
.59184 .35084 m .58751 .3508 L .5909 .34953 L F
.63 .649 .85 r
.59009 .34583 m .59184 .35084 L .59506 .3474 L F
0 0 .445 r
.593 .35027 m .59184 .35084 L .5909 .34953 L F
.593 .35027 m .59245 .35208 L .59184 .35084 L F
.75 .797 .891 r
.35187 .62325 m .35606 .62357 L .35483 .62167 L F
.819 .76 .797 r
.35606 .62357 m .3575 .61889 L .35483 .62167 L F
.35606 .62357 m .35848 .62017 L .3575 .61889 L F
.823 .926 .902 r
.5325 .47188 m .52762 .4728 L .53065 .47007 L F
0 .044 .612 r
.53453 .4741 m .5325 .47188 L .53569 .47165 L F
.568 .789 .982 r
.50996 .42942 m .50613 .42927 L .50964 .43072 L F
.434 .429 .755 r
.50845 .42856 m .50964 .43072 L .50613 .42927 L F
.695 .718 .197 r
.42668 .54648 m .42558 .55058 L .42624 .54817 L F
.545 .577 .838 r
.34537 .55248 m .3442 .55559 L .34269 .55335 L F
.34537 .55248 m .34752 .55447 L .3442 .55559 L F
.53 .808 .997 r
.33487 .5828 m .33446 .58447 L .33226 .58328 L F
.583 .578 .813 r
.28647 .66668 m .29127 .66907 L .29023 .66668 L F
.909 .908 .808 r
.65312 .39831 m .65688 .39567 L .65419 .39344 L F
.927 .901 .781 r
.65419 .39344 m .65688 .39567 L .65724 .39268 L F
.766 .391 .345 r
.60288 .38524 m .59877 .38227 L .59972 .38631 L F
.052 .186 .685 r
.59972 .38631 m .60219 .38728 L .60288 .38524 L F
.734 .968 .702 r
.32001 .55441 m .3196 .55507 L .31788 .55653 L F
.785 .486 .483 r
.3196 .55507 m .31996 .55818 L .31788 .55653 L F
.401 .838 .704 r
.32345 .55643 m .31996 .55818 L .3196 .55507 L F
.588 .796 .978 r
.50996 .42942 m .51093 .42717 L .50845 .42856 L F
.50996 .42942 m .513 .42921 L .51093 .42717 L F
.881 .866 .819 r
.50964 .43072 m .513 .42921 L .50996 .42942 L F
0 .072 .632 r
.56965 .37485 m .56989 .37665 L .5684 .37272 L F
0 0 .36 r
.56965 .37485 m .57064 .37915 L .56989 .37665 L F
.884 .978 .829 r
.48487 .5191 m .48248 .52193 L .48235 .51951 L F
.925 .929 .56 r
.48132 .52423 m .48235 .51951 L .48248 .52193 L F
.571 .623 .865 r
.31028 .63382 m .31116 .62971 L .30889 .62958 L F
.31028 .63382 m .3128 .63322 L .31116 .62971 L F
.184 0 0 r
.50505 .44483 m .50891 .44204 L .50759 .4439 L F
.311 0 0 r
.50891 .44204 m .5104 .44337 L .50759 .4439 L F
.50891 .44204 m .51171 .44188 L .5104 .44337 L F
0 0 .214 r
.59231 .40842 m .59166 .40961 L .59265 .40561 L F
.863 .975 .669 r
.57809 .3909 m .57995 .38964 L .57907 .38892 L F
.657 .939 .965 r
.58125 .38753 m .57995 .38964 L .57907 .38892 L F
.467 .703 .971 r
.57995 .38964 m .58206 .38944 L .58125 .38753 L F
.57995 .38964 m .58206 .38944 L .58125 .38753 L F
.657 .939 .965 r
.58125 .38753 m .57995 .38964 L .57907 .38892 L F
.57907 .38892 m .57995 .38964 L .58125 .38753 L F
.486 .031 .095 r
.39157 .45893 m .394 .46022 L .3956 .45799 L F
.383 0 .111 r
.394 .46022 m .39841 .45738 L .3956 .45799 L F
.738 .488 .551 r
.71528 .30575 m .71936 .30387 L .71565 .30316 L F
.71528 .30575 m .71944 .30646 L .71936 .30387 L F
.988 .805 .571 r
.55621 .45556 m .55437 .45689 L .55532 .45434 L F
.55621 .45556 m .5553 .45801 L .55437 .45689 L F
.92 .849 .756 r
.55593 .45162 m .55621 .45556 L .55532 .45434 L F
.819 .725 .761 r
.36244 .60993 m .36692 .60776 L .36537 .60653 L F
.16 0 0 r
.5357 .42258 m .53675 .42327 L .53471 .42331 L F
.5357 .42258 m .53849 .42217 L .53675 .42327 L F
.358 .028 .261 r
.44908 .49869 m .45215 .49758 L .45033 .49967 L F
0 .098 .627 r
.45033 .49967 m .45 .49654 L .44908 .49869 L F
.875 .982 .836 r
.48487 .5191 m .48522 .51636 L .48681 .5175 L F
.48487 .5191 m .48235 .51951 L .48522 .51636 L F
.899 .957 .827 r
.45023 .55687 m .44948 .55849 L .44915 .55595 L F
.858 .997 .792 r
.44948 .55849 m .44689 .55963 L .44915 .55595 L F
.44948 .55849 m .44752 .56037 L .44689 .55963 L F
.553 .772 .98 r
.61415 .38714 m .61507 .38897 L .61664 .3875 L F
.186 .659 .934 r
.25009 .53073 m .25161 .53068 L .25354 .53166 L F
.485 .815 1 r
.25161 .53068 m .25613 .53115 L .25354 .53166 L F
.25313 .53083 m .2542 .53006 L .25613 .53115 L F
.25161 .53068 m .2542 .53006 L .25313 .53083 L F
.788 .9 .922 r
.25613 .53115 m .2542 .53006 L .25629 .52823 L F
.308 0 .196 r
.25296 .53149 m .25497 .52952 L .2542 .53006 L F
.25497 .52952 m .25629 .52823 L .2542 .53006 L F
.219 0 0 r
.25052 .53195 m .25312 .53062 L .25161 .53068 L F
.25312 .53062 m .2542 .53006 L .25161 .53068 L F
.186 .659 .934 r
.24975 .53064 m .25161 .53068 L .25009 .53073 L F
.907 .823 .357 r
.57283 .35656 m .57203 .35769 L .57157 .35449 L F
.57283 .35656 m .57218 .35952 L .57203 .35769 L F
.467 .644 .935 r
.57408 .35425 m .57283 .35656 L .57157 .35449 L F
.401 .562 .898 r
.57408 .35425 m .57606 .35692 L .57283 .35656 L F
.684 .715 .195 r
.36777 .47332 m .3674 .47463 L .36827 .47232 L F
.309 .774 .645 r
.64873 .34109 m .64468 .343 L .64505 .3428 L F
.64873 .34109 m .64721 .34179 L .64468 .343 L F
0 0 0 r
.64988 .34084 m .64873 .34109 L .6511 .33963 L F
.64988 .34084 m .64721 .34179 L .64873 .34109 L F
.355 .659 .97 r
.3064 .65224 m .30436 .65228 L .30209 .65004 L F
.091 0 .222 r
.25043 .56451 m .24971 .56675 L .24813 .56754 L F
0 0 0 r
.4005 .50086 m .3995 .50293 L .39816 .50443 L F
.529 .821 .482 r
.3995 .50293 m .39626 .50648 L .39816 .50443 L F
.857 .514 .403 r
.34902 .56433 m .34582 .5636 L .34582 .56118 L F
.914 .776 .694 r
.34902 .56433 m .34561 .56643 L .34582 .5636 L F
.34902 .56433 m .34749 .56751 L .34561 .56643 L F
.706 .5 .607 r
.70958 .29066 m .70978 .29339 L .71199 .29041 L F
0 0 .29 r
.66763 .39321 m .66668 .39284 L .66579 .39191 L F
.66763 .39321 m .66697 .39559 L .66668 .39284 L F
.778 .994 .781 r
.52869 .49071 m .52911 .49123 L .53231 .48803 L F
.507 .24 .445 r
.62477 .40611 m .62222 .40302 L .62326 .40344 L F
.947 .608 .345 r
.35182 .53063 m .35406 .53422 L .35415 .53155 L F
.668 .563 .727 r
.33142 .59076 m .33407 .58713 L .33119 .5877 L F
.33142 .59076 m .33484 .59085 L .33407 .58713 L F
.82 .697 .729 r
.36955 .58362 m .36729 .58671 L .37127 .58737 L F
.828 .652 .664 r
.36729 .58671 m .36926 .59049 L .37127 .58737 L F
0 0 .452 r
.26833 .54441 m .26769 .54758 L .26584 .54384 L F
.26833 .54441 m .26871 .54726 L .26769 .54758 L F
.354 .123 .419 r
.26921 .54968 m .26769 .54758 L .26871 .54726 L F
.26921 .54968 m .26701 .55057 L .26769 .54758 L F
0 .204 .726 r
.57368 .36626 m .57535 .36981 L .5754 .367 L F
.838 .652 .108 r
.57535 .36981 m .57506 .37077 L .5754 .367 L F
.57535 .36981 m .5754 .37263 L .57506 .37077 L F
.729 .977 .742 r
.51546 .48605 m .51655 .48403 L .5175 .48442 L F
.51546 .48605 m .51365 .48691 L .51655 .48403 L F
.782 .976 .697 r
.51596 .42626 m .51873 .42295 L .51788 .42442 L F
.888 .561 .062 r
.53635 .36321 m .53532 .36257 L .53482 .35951 L F
.53532 .36257 m .53524 .36241 L .53482 .35951 L F
.53524 .36241 m .53523 .36239 L .53523 .36238 L F
.53524 .36241 m .53523 .36238 L .53482 .35951 L F
.801 .761 .816 r
.53311 .36103 m .5349 .36443 L .53518 .36316 L F
.942 .918 .546 r
.53635 .36321 m .5349 .36443 L .5353 .36257 L F
0 0 0 r
.53673 .36338 m .5349 .36443 L .53635 .36321 L F
.801 .761 .816 r
.53311 .36103 m .53587 .36387 L .53524 .36241 L F
.942 .918 .546 r
.5353 .36257 m .5349 .36443 L .53525 .36253 L F
.801 .761 .816 r
.53518 .36316 m .5349 .36443 L .53587 .36387 L F
.53524 .36241 m .53587 .36387 L .53673 .36338 L F
0 0 .482 r
.53748 .35842 m .53635 .36321 L .53482 .35951 L F
.53748 .35842 m .53816 .36126 L .53635 .36321 L F
0 0 0 r
.53673 .36338 m .53635 .36321 L .53816 .36126 L F
.891 .495 .264 r
.53482 .35951 m .53523 .36239 L .53311 .36103 L F
.53523 .36239 m .53525 .36253 L .53311 .36103 L F
.801 .761 .816 r
.53435 .36063 m .53668 .36332 L .53643 .35994 L F
.53668 .36332 m .53673 .36338 L .53673 .36335 L F
.53668 .36332 m .53673 .36335 L .53643 .35994 L F
.53311 .36103 m .53524 .36241 L .53435 .36063 L F
.53524 .36241 m .53673 .36338 L .53435 .36063 L F
.888 .561 .062 r
.53532 .36257 m .53525 .36253 L .53523 .36239 L F
.765 .525 .57 r
.68763 .33253 m .69178 .33041 L .68753 .3298 L F
.68763 .33253 m .69202 .33316 L .69178 .33041 L F
.836 .578 .55 r
.69178 .33041 m .69202 .33316 L .69355 .33305 L F
.49 .138 .296 r
.32933 .67298 m .33078 .67551 L .32817 .67585 L F
.32933 .67298 m .33204 .67267 L .33078 .67551 L F
.523 .65 .914 r
.30883 .65171 m .30774 .65413 L .3064 .65224 L F
.30883 .65171 m .31049 .65381 L .30774 .65413 L F
.75 .967 .932 r
.45318 .44678 m .45566 .44695 L .45771 .44536 L F
.952 .617 .347 r
.34582 .56118 m .34582 .5636 L .34414 .56264 L F
.889 .627 .536 r
.35312 .53995 m .35583 .538 L .35387 .53719 L F
.35312 .53995 m .35555 .5408 L .35583 .538 L F
.315 .786 .929 r
.54741 .38873 m .55152 .38874 L .549 .38953 L F
.505 .341 .592 r
.55184 .39154 m .549 .38953 L .55152 .38874 L F
.55184 .39154 m .54918 .39243 L .549 .38953 L F
.79 .681 .745 r
.47899 .54703 m .48265 .54755 L .48354 .54488 L F
.795 .66 .715 r
.47899 .54703 m .48064 .55076 L .48265 .54755 L F
.778 .994 .781 r
.52869 .49071 m .53231 .48803 L .53178 .4877 L F
.756 .974 .923 r
.53231 .48803 m .53341 .48545 L .53178 .4877 L F
.53231 .48803 m .53587 .48542 L .53341 .48545 L F
.496 .252 .474 r
.31148 .54759 m .31421 .54778 L .31515 .54354 L F
0 0 0 r
.31515 .54354 m .31497 .54521 L .31664 .54376 L F
.31515 .54354 m .31421 .54778 L .31497 .54521 L F
.26387 .52483 m .26643 .52337 L .26809 .52103 L F
.428 .064 .243 r
.26319 .5256 m .26643 .52337 L .26387 .52483 L F
.469 .876 .724 r
.46647 .42742 m .46985 .42546 L .47052 .42529 L F
0 0 0 r
.47377 .42274 m .47052 .42529 L .47225 .42411 L F
.425 .854 .723 r
.47052 .42529 m .46985 .42546 L .47225 .42411 L F
0 0 .242 r
.23972 .56079 m .24096 .56033 L .24158 .55752 L F
.332 .255 .618 r
.23972 .56079 m .24191 .56332 L .24096 .56033 L F
0 0 0 r
.41934 .46425 m .42057 .46328 L .42282 .46153 L F
.869 .517 .016 r
.6943 .35757 m .69417 .35618 L .69302 .35438 L F
0 0 0 r
.61979 .36857 m .62121 .36817 L .62312 .36706 L F
.718 .776 .899 r
.62062 .36841 m .62078 .3692 L .62132 .36813 L F
0 0 0 r
.62121 .36817 m .62123 .36817 L .62124 .36817 L F
.62121 .36817 m .62124 .36817 L .62312 .36706 L F
.718 .776 .899 r
.62132 .36813 m .62078 .3692 L .62596 .36864 L F
.62108 .36811 m .62119 .36818 L .62132 .36813 L F
.62077 .36794 m .62132 .36813 L .62398 .36638 L F
0 0 0 r
.61975 .36859 m .61989 .36855 L .61979 .36857 L F
.61989 .36855 m .62193 .36797 L .61979 .36857 L F
.353 .667 .974 r
.62066 .36782 m .62119 .36818 L .61975 .36859 L F
.718 .776 .899 r
.62055 .36805 m .62108 .36811 L .62077 .36794 L F
.62108 .36811 m .62132 .36813 L .62077 .36794 L F
.62132 .36813 m .62596 .36864 L .62441 .36688 L F
0 0 0 r
.62123 .36817 m .62193 .36797 L .62218 .36778 L F
.353 .667 .974 r
.62071 .36778 m .62193 .36797 L .62121 .36818 L F
.62113 .36814 m .62121 .36818 L .62119 .36818 L F
.62071 .36778 m .62121 .36818 L .62113 .36814 L F
.62071 .36778 m .62119 .36818 L .62066 .36782 L F
.718 .776 .899 r
.62055 .36805 m .62062 .36841 L .62119 .36818 L F
.62055 .36805 m .62119 .36818 L .62108 .36811 L F
0 0 0 r
.62123 .36817 m .62218 .36778 L .62312 .36706 L F
.438 .813 .56 r
.62312 .36706 m .62398 .36638 L .62476 .36637 L F
.62312 .36706 m .62218 .36778 L .62398 .36638 L F
.718 .776 .899 r
.62132 .36813 m .62218 .36778 L .62398 .36638 L F
.438 .813 .56 r
.62218 .36778 m .62193 .36797 L .62398 .36638 L F
.718 .776 .899 r
.62218 .36778 m .62441 .36688 L .62398 .36638 L F
.072 .276 .764 r
.62015 .37095 m .62078 .3692 L .62062 .36841 L F
.6205 .36843 m .62062 .36841 L .62055 .36805 L F
.62015 .37095 m .62062 .36841 L .6205 .36843 L F
.62015 .37095 m .62055 .36805 L .61975 .36859 L F
.837 .955 .891 r
.50589 .41796 m .5102 .41611 L .50839 .41708 L F
.696 .907 .556 r
.51134 .41399 m .5102 .41611 L .51273 .4127 L F
.725 .969 .713 r
.50839 .41708 m .5102 .41611 L .51134 .41399 L F
0 .287 .773 r
.25066 .61382 m .25267 .61587 L .25599 .61376 L F
.954 .623 .222 r
.69034 .35131 m .69124 .35055 L .68986 .34878 L F
.702 .168 0 r
.69034 .35131 m .69231 .35177 L .69124 .35055 L F
.633 .485 .663 r
.33751 .56761 m .34085 .5684 L .33962 .56402 L F
.681 .553 .702 r
.33751 .56761 m .34047 .57031 L .34085 .5684 L F
.33751 .56761 m .33772 .57133 L .34047 .57031 L F
.767 .697 .786 r
.5422 .39234 m .54352 .39605 L .5393 .39609 L F
.014 .589 .713 r
.5393 .39609 m .54352 .39605 L .54247 .39605 L F
.898 .754 .694 r
.54366 .39313 m .54352 .39605 L .5422 .39234 L F
.352 .798 .956 r
.54352 .39605 m .54512 .39504 L .54247 .39605 L F
.54352 .39605 m .54628 .39567 L .54512 .39504 L F
.511 .793 .996 r
.5989 .40017 m .60331 .40086 L .60193 .39958 L F
.611 .901 .986 r
.60331 .40086 m .6048 .39881 L .60193 .39958 L F
.60331 .40086 m .60598 .39975 L .6048 .39881 L F
.854 .502 .385 r
.37487 .52154 m .37177 .5207 L .37115 .51807 L F
.848 .577 .528 r
.3751 .5241 m .37177 .5207 L .37487 .52154 L F
.556 .641 .89 r
.4205 .57266 m .42384 .5736 L .4229 .5703 L F
0 0 0 r
.42155 .5714 m .41948 .57454 L .4205 .57266 L F
.4229 .5703 m .42155 .5714 L .4205 .57266 L F
.856 .617 .577 r
.35417 .49347 m .3589 .49218 L .35621 .49125 L F
.35417 .49347 m .35863 .4953 L .3589 .49218 L F
.125 .203 .674 r
.35992 .49008 m .36075 .49395 L .3589 .49218 L F
.797 .408 .318 r
.36075 .49395 m .35621 .49125 L .3589 .49218 L F
.666 .505 .656 r
.33962 .56402 m .34318 .56657 L .34251 .56337 L F
.33962 .56402 m .34085 .5684 L .34318 .56657 L F
.839 .599 .576 r
.36181 .55755 m .36157 .5603 L .36511 .561 L F
.84 .625 .612 r
.36157 .5603 m .36336 .56408 L .36511 .561 L F
.655 .593 .773 r
.44591 .58054 m .44764 .58469 L .45047 .58336 L F
.207 0 0 r
.26487 .55166 m .26274 .55345 L .26014 .55385 L F
.264 0 0 r
.26563 .55291 m .26487 .55166 L .26701 .55057 L F
.26563 .55291 m .26274 .55345 L .26487 .55166 L F
0 .208 .631 r
.55745 .41161 m .55826 .4122 L .55865 .41239 L F
.495 .326 .58 r
.46612 .58585 m .46371 .58709 L .46514 .58771 L F
.654 .611 .794 r
.28807 .65712 m .29152 .6598 L .29095 .65586 L F
.752 .909 .946 r
.29152 .6598 m .29278 .65654 L .29095 .65586 L F
.29152 .6598 m .29457 .65744 L .29278 .65654 L F
.91 .505 .185 r
.36629 .49164 m .36731 .49419 L .36916 .49517 L F
.481 0 0 r
.36731 .49419 m .37194 .49626 L .36916 .49517 L F
.618 .433 .61 r
.70689 .29392 m .70978 .29339 L .70958 .29066 L F
.947 .739 .589 r
.3575 .61889 m .35848 .62017 L .35765 .61711 L F
.745 .639 .743 r
.35848 .62017 m .36129 .61703 L .35765 .61711 L F
.829 .411 .248 r
.34944 .52345 m .3503 .52218 L .34704 .52011 L F
.34944 .52345 m .35059 .52382 L .3503 .52218 L F
.838 .731 .746 r
.36834 .57657 m .36611 .58004 L .36985 .58069 L F
.836 .611 .597 r
.36585 .58287 m .36985 .58069 L .36611 .58004 L F
.36585 .58287 m .36955 .58362 L .36985 .58069 L F
.67 .634 .805 r
.32982 .58438 m .33119 .5877 L .33407 .58713 L F
.858 .987 .846 r
.513 .42921 m .51596 .42626 L .51337 .42636 L F
.73 .986 .895 r
.51337 .42636 m .51596 .42626 L .51788 .42442 L F
.732 .719 .838 r
.35765 .61711 m .36129 .61703 L .35999 .61347 L F
.92 .695 .581 r
.39445 .58364 m .39236 .57965 L .39391 .5811 L F
.102 0 0 r
.61051 .34365 m .61357 .34389 L .61445 .34333 L F
0 0 0 r
.61445 .34333 m .61593 .34342 L .61726 .34339 L F
.61445 .34333 m .61357 .34389 L .61593 .34342 L F
.703 .806 .929 r
.54847 .35618 m .54432 .35566 L .54745 .35405 L F
.54847 .35618 m .54432 .35566 L .54745 .35405 L F
.201 .658 .944 r
.55148 .35524 m .54745 .35405 L .54847 .35618 L F
.54745 .35405 m .55148 .35524 L .54847 .35618 L F
.869 .94 .863 r
.46539 .54401 m .46134 .54619 L .46404 .54321 L F
.46539 .54401 m .46228 .54716 L .46134 .54619 L F
.895 .942 .834 r
.46539 .54401 m .46681 .53978 L .46859 .54134 L F
.46539 .54401 m .46404 .54321 L .46681 .53978 L F
0 0 0 r
.29564 .67195 m .29502 .67333 L .29439 .67598 L F
.384 .801 .976 r
.51273 .4127 m .51415 .41152 L .51134 .41399 L F
.5 .268 .494 r
.51627 .40946 m .51586 .41226 L .51273 .4127 L F
.384 .801 .976 r
.51273 .4127 m .51586 .41226 L .51415 .41152 L F
.953 .781 .631 r
.69215 .3426 m .69296 .34012 L .69125 .33861 L F
0 0 .343 r
.52874 .43924 m .53051 .43981 L .53174 .43843 L F
.52874 .43924 m .52934 .44081 L .53051 .43981 L F
.52874 .43924 m .52885 .44185 L .52934 .44081 L F
.767 .832 .902 r
.44469 .59595 m .44896 .59684 L .44935 .59503 L F
.79 .668 .729 r
.34776 .55094 m .34282 .55051 L .34513 .54708 L F
.732 .49 .562 r
.34537 .55248 m .34282 .55051 L .34776 .55094 L F
.562 .144 .206 r
.34776 .55094 m .3496 .55183 L .34537 .55248 L F
.58 .363 .55 r
.26951 .6067 m .27098 .60331 L .27078 .60459 L F
.792 .313 0 r
.57465 .4222 m .57197 .41915 L .57274 .42095 L F
.821 .354 0 r
.5744 .42335 m .57465 .4222 L .57274 .42095 L F
.5744 .42335 m .57595 .42444 L .57465 .4222 L F
.877 .782 .753 r
.46228 .54716 m .46063 .55133 L .45939 .5477 L F
.611 .077 0 r
.58306 .37105 m .58251 .36962 L .58196 .36799 L F
.58306 .37105 m .58329 .37117 L .58251 .36962 L F
.58329 .37117 m .58483 .37192 L .58264 .36975 L F
.58329 .37117 m .58264 .36975 L .58251 .36962 L F
.58306 .37105 m .58579 .37287 L .58483 .37192 L F
.64 .102 0 r
.58251 .36962 m .58579 .37287 L .58661 .37313 L F
.983 .721 .453 r
.58387 .37253 m .58579 .37287 L .58332 .37123 L F
.43 .723 .987 r
.58332 .37123 m .58387 .37253 L .58329 .37117 L F
.948 .634 .199 r
.58329 .37117 m .58387 .37253 L .58306 .37105 L F
.983 .721 .453 r
.58387 .37253 m .58332 .37123 L .58306 .37105 L F
.43 .723 .987 r
.58342 .37145 m .58387 .37253 L .58332 .37123 L F
.58319 .37089 m .58342 .37145 L .58229 .36879 L F
.58342 .37145 m .58329 .37117 L .58229 .36879 L F
.948 .634 .199 r
.58229 .36879 m .58329 .37117 L .58306 .37105 L F
.804 .934 .917 r
.46228 .54716 m .45939 .5477 L .46134 .54619 L F
.91 .653 .537 r
.37115 .51807 m .36871 .5174 L .3688 .51448 L F
.863 .465 .283 r
.37115 .51807 m .36936 .51967 L .36871 .5174 L F
.903 .535 .328 r
.37115 .51807 m .37177 .5207 L .36936 .51967 L F
.374 0 .124 r
.27076 .53981 m .26815 .54063 L .27084 .53861 L F
0 0 0 r
.4351 .44587 m .4395 .44408 L .4373 .44543 L F
.791 .646 .702 r
.48208 .54089 m .47944 .54444 L .48354 .54488 L F
.79 .681 .745 r
.47899 .54703 m .48354 .54488 L .47944 .54444 L F
.783 .655 .722 r
.30535 .58366 m .30568 .58651 L .3096 .58416 L F
.993 .878 .573 r
.583 .38634 m .58125 .38753 L .58267 .3835 L F
.583 .38634 m .58206 .38944 L .58125 .38753 L F
.556 0 0 r
.41912 .60307 m .42109 .60391 L .42352 .6058 L F
.692 .683 .837 r
.33563 .62963 m .33748 .63343 L .33994 .63024 L F
.642 .609 .801 r
.33748 .63343 m .34163 .63446 L .33994 .63024 L F
.167 .433 .868 r
.33748 .63343 m .34069 .63568 L .34163 .63446 L F
.601 .908 .641 r
.47377 .42274 m .47515 .42104 L .47559 .42094 L F
.58 .869 .553 r
.47225 .42411 m .47515 .42104 L .47377 .42274 L F
.471 .881 .744 r
.62338 .38399 m .62205 .38436 L .61965 .38596 L F
.713 .972 .74 r
.62312 .38286 m .62338 .38399 L .62636 .38312 L F
.62312 .38286 m .62205 .38436 L .62338 .38399 L F
.474 .133 .306 r
.43964 .59703 m .43832 .59952 L .43629 .59932 L F
.171 0 0 r
.43964 .59703 m .44042 .59797 L .43832 .59952 L F
.43964 .59703 m .44211 .59684 L .44042 .59797 L F
.903 .827 .761 r
.59728 .42861 m .59957 .42485 L .59668 .42442 L F
.844 .976 .874 r
.50957 .39915 m .51152 .39525 L .5129 .39648 L F
.50957 .39915 m .50856 .39833 L .51152 .39525 L F
.848 .631 .609 r
.69202 .33316 m .69196 .33612 L .69355 .33305 L F
.261 .025 .354 r
.59267 .35849 m .59234 .36119 L .58906 .36124 L F
.336 .057 .334 r
.59218 .36237 m .58906 .36124 L .59234 .36119 L F
.59218 .36237 m .59012 .36431 L .58906 .36124 L F
.856 .526 .427 r
.60108 .34891 m .60409 .35033 L .60441 .34994 L F
.77 .762 .251 r
.60441 .34994 m .60413 .35018 L .60108 .34891 L F
.342 .024 .273 r
.26809 .52103 m .27047 .52037 L .27116 .5184 L F
.28 0 .246 r
.27116 .5184 m .27047 .52037 L .27337 .51762 L F
.327 .006 .259 r
.33444 .67226 m .33524 .67008 L .3376 .66939 L F
.276 .052 .382 r
.33524 .67008 m .33775 .66654 L .3376 .66939 L F
0 0 .114 r
.51697 .41053 m .51627 .40946 L .5167 .4087 L F
.338 0 0 r
.6298 .39048 m .63148 .38998 L .62699 .3895 L F
.231 .738 .688 r
.63413 .38911 m .63148 .38998 L .6298 .39048 L F
.36 0 0 r
.33274 .50329 m .3347 .50421 L .33675 .50502 L F
.877 .446 .165 r
.3347 .50421 m .33534 .50598 L .33675 .50502 L F
.868 .431 .154 r
.33675 .50502 m .33534 .50598 L .33731 .50674 L F
.733 .727 .845 r
.34253 .63003 m .34702 .63048 L .34501 .62643 L F
.766 .629 .708 r
.34364 .63281 m .34702 .63048 L .34253 .63003 L F
.795 .752 .813 r
.34501 .62643 m .34702 .63048 L .34922 .62665 L F
.267 0 0 r
.66035 .33581 m .65638 .33764 L .65762 .33669 L F
.972 .71 .291 r
.58579 .37287 m .58601 .37478 L .58661 .37313 L F
.983 .721 .453 r
.58387 .37253 m .58601 .37478 L .58579 .37287 L F
.563 .764 .973 r
.58572 .37306 m .58601 .37478 L .58387 .37253 L F
.909 .777 .291 r
.58601 .37478 m .58628 .37642 L .58661 .37313 L F
.563 .764 .973 r
.58792 .37369 m .58601 .37478 L .58572 .37306 L F
.909 .777 .291 r
.58601 .37478 m .58628 .37645 L .58628 .37642 L F
.822 .632 .647 r
.3585 .55427 m .36191 .55469 L .36034 .55092 L F
.812 .635 .662 r
.35769 .55688 m .36191 .55469 L .3585 .55427 L F
.35769 .55688 m .36181 .55755 L .36191 .55469 L F
.829 .743 .77 r
.34231 .54107 m .34078 .5443 L .33728 .54308 L F
.309 0 0 r
.34078 .5443 m .33675 .54563 L .33728 .54308 L F
.34078 .5443 m .33929 .54563 L .33675 .54563 L F
.854 .406 .131 r
.34078 .5443 m .34167 .54711 L .33929 .54563 L F
.757 .336 .25 r
.34513 .54708 m .34167 .54711 L .34078 .5443 L F
.073 0 .087 r
.34152 .59019 m .34198 .59183 L .34348 .58945 L F
.886 .963 .84 r
.49185 .5101 m .49047 .51213 L .4904 .50945 L F
.945 .939 .602 r
.4904 .50945 m .49047 .51213 L .48942 .51425 L F
.732 .601 .711 r
.41331 .465 m .41779 .46536 L .4148 .46871 L F
.475 .24 .477 r
.4148 .46871 m .41779 .46536 L .41757 .46808 L F
.25 .06 .416 r
.41757 .46808 m .41779 .46536 L .41934 .46425 L F
.233 0 0 r
.58861 .42903 m .59009 .42962 L .5883 .43174 L F
.3 .122 .464 r
.24449 .54033 m .24664 .53709 L .24466 .53793 L F
.858 .987 .846 r
.513 .42921 m .51337 .42636 L .51093 .42717 L F
.835 .525 .465 r
.42585 .56416 m .42661 .56714 L .42964 .56761 L F
.809 .438 .353 r
.42661 .56714 m .42777 .5698 L .42964 .56761 L F
.618 .19 .207 r
.42964 .56761 m .42777 .5698 L .43211 .5696 L F
.818 .887 .893 r
.52311 .47618 m .52103 .47807 L .51881 .47748 L F
.82 .623 .636 r
.35853 .54727 m .36067 .54826 L .3588 .54456 L F
.866 .722 .701 r
.35682 .55017 m .36067 .54826 L .35853 .54727 L F
.35682 .55017 m .36034 .55092 L .36067 .54826 L F
.587 .904 .983 r
.46907 .44016 m .47436 .43954 L .47299 .43858 L F
.83 .935 .898 r
.47448 .4368 m .47436 .43954 L .47561 .43812 L F
.854 .95 .877 r
.47299 .43858 m .47436 .43954 L .47448 .4368 L F
.954 .728 .558 r
.42363 .55545 m .42666 .55439 L .42581 .55371 L F
.42363 .55545 m .42609 .55689 L .42666 .55439 L F
.95 .672 .221 r
.42581 .55371 m .42666 .55439 L .42558 .55058 L F
.922 .595 .404 r
.5363 .46119 m .53934 .46419 L .53744 .46105 L F
.733 .726 .844 r
.4763 .55055 m .47856 .55176 L .48064 .55076 L F
.268 .2 .592 r
.29601 .6659 m .29477 .66834 L .29788 .66833 L F
.332 .113 .424 r
.29477 .66834 m .29776 .67123 L .29788 .66833 L F
.971 .776 .583 r
.23782 .60996 m .23973 .61052 L .23881 .60709 L F
.968 .708 .487 r
.23782 .60996 m .23973 .61052 L .2379 .61292 L F
.971 .776 .583 r
.23881 .60709 m .23973 .61052 L .23782 .60996 L F
0 0 .259 r
.58773 .40585 m .58765 .40372 L .58709 .4014 L F
0 0 .432 r
.58773 .40585 m .58849 .40656 L .58765 .40372 L F
.58773 .40585 m .58948 .40897 L .58849 .40656 L F
.361 0 0 r
.40677 .4616 m .40488 .46364 L .40218 .4639 L F
.685 .254 .219 r
.40677 .4616 m .40909 .46397 L .40488 .46364 L F
.452 0 .016 r
.38082 .46167 m .38477 .46086 L .3826 .46081 L F
.819 .754 .791 r
.31421 .54778 m .31876 .54754 L .31646 .54721 L F
.868 .919 .86 r
.51572 .39333 m .5129 .39648 L .51298 .39291 L F
.913 .944 .81 r
.5129 .39648 m .51152 .39525 L .51298 .39291 L F
.821 .436 0 r
.66041 .40104 m .65911 .39836 L .6593 .39756 L F
.702 .955 .685 r
.66011 .39646 m .6593 .39756 L .65911 .39836 L F
.623 .454 .632 r
.70689 .29392 m .70714 .2967 L .70978 .29339 L F
.934 .712 .579 r
.47072 .57901 m .47302 .57749 L .47127 .57642 L F
.47072 .57901 m .47336 .58159 L .47302 .57749 L F
.975 .769 .564 r
.33704 .52687 m .33669 .52961 L .33913 .52878 L F
.33913 .52878 m .33704 .52687 L .34024 .52636 L F
.33913 .52878 m .33669 .52961 L .33704 .52687 L F
.919 .779 .69 r
.35648 .55329 m .36034 .55092 L .35682 .55017 L F
.35648 .55329 m .3585 .55427 L .36034 .55092 L F
.943 .587 .297 r
.42442 .56569 m .42585 .56416 L .42436 .56298 L F
.42442 .56569 m .42661 .56714 L .42585 .56416 L F
.475 .262 .511 r
.71145 .3168 m .71442 .31194 L .71009 .31235 L F
.71145 .3168 m .71436 .31595 L .71442 .31194 L F
.443 .262 .539 r
.71442 .31194 m .71698 .31238 L .71696 .31003 L F
.446 .24 .505 r
.71436 .31595 m .71698 .31238 L .71442 .31194 L F
.976 .675 .364 r
.55008 .37953 m .54865 .38076 L .54831 .37769 L F
.516 .746 .979 r
.5513 .37723 m .55008 .37953 L .54831 .37769 L F
.515 0 0 r
.55262 .38093 m .55008 .37953 L .5513 .37723 L F
.55262 .38093 m .54865 .38076 L .55008 .37953 L F
0 0 .564 r
.55156 .40265 m .5529 .40315 L .55329 .40169 L F
.664 .657 .833 r
.60801 .3976 m .61019 .40075 L .61197 .39951 L F
.892 .763 .712 r
.41868 .53422 m .41775 .53714 L .41991 .5378 L F
.899 .58 .434 r
.41775 .53714 m .41805 .54006 L .41991 .5378 L F
.855 .508 .395 r
.41805 .54006 m .42056 .54038 L .41991 .5378 L F
.778 .724 .802 r
.34085 .5684 m .34047 .57031 L .34318 .56657 L F
.827 .952 .899 r
.40639 .5864 m .4094 .58524 L .4086 .58316 L F
.209 .447 .87 r
.4094 .58524 m .40955 .58342 L .4086 .58316 L F
.923 .675 .544 r
.68358 .3217 m .68252 .32526 L .68563 .32651 L F
.909 .635 .511 r
.68252 .32526 m .6857 .32906 L .68563 .32651 L F
.802 .559 .571 r
.68753 .3298 m .68563 .32651 L .6857 .32906 L F
.646 .864 .982 r
.62315 .38872 m .62472 .38993 L .62699 .3895 L F
.62315 .38872 m .62472 .38993 L .62699 .3895 L F
.267 .366 .779 r
.62472 .38993 m .62748 .39171 L .62699 .3895 L F
.324 0 .02 r
.40097 .45773 m .40366 .45726 L .40508 .45526 L F
.298 0 .005 r
.40508 .45526 m .40585 .45679 L .40773 .45486 L F
.40508 .45526 m .40366 .45726 L .40585 .45679 L F
.922 .595 .404 r
.5363 .46119 m .53643 .46401 L .53934 .46419 L F
.929 .881 .766 r
.53643 .46401 m .53616 .46758 L .53934 .46419 L F
.493 .128 .274 r
.39354 .50116 m .39712 .49903 L .39353 .49802 L F
.39354 .50116 m .3963 .50091 L .39712 .49903 L F
.648 .287 .344 r
.39712 .49903 m .3963 .50091 L .4005 .50086 L F
.189 0 0 r
.41672 .45313 m .41481 .45289 L .41307 .45434 L F
.646 .864 .982 r
.62315 .38872 m .62699 .3895 L .62597 .38844 L F
.62315 .38872 m .62699 .3895 L .62597 .38844 L F
.478 .847 .989 r
.62927 .38783 m .62699 .3895 L .62597 .38844 L F
.62597 .38844 m .62699 .3895 L .62927 .38783 L F
.338 0 0 r
.6298 .39048 m .62699 .3895 L .62748 .39171 L F
.889 .628 .537 r
.35555 .5408 m .35521 .54348 L .3588 .54456 L F
.857 .696 .681 r
.35521 .54348 m .35853 .54727 L .3588 .54456 L F
.246 0 0 r
.65501 .32895 m .65786 .32826 L .65866 .32651 L F
0 0 0 r
.65866 .32651 m .66094 .32534 L .66205 .32403 L F
.155 0 0 r
.65866 .32651 m .66055 .32733 L .66094 .32534 L F
.65866 .32651 m .65786 .32826 L .66055 .32733 L F
.836 .515 .445 r
.39882 .51329 m .40114 .51108 L .39804 .51159 L F
.39882 .51329 m .40546 .51572 L .40114 .51108 L F
.797 .567 .589 r
.55597 .39018 m .55152 .38874 L .5552 .38827 L F
.55597 .39018 m .55184 .39154 L .55152 .38874 L F
.55597 .39018 m .55458 .39227 L .55184 .39154 L F
.866 .753 .735 r
.55692 .38727 m .55597 .39018 L .5552 .38827 L F
.984 .743 .493 r
.38755 .54762 m .38588 .54659 L .38609 .54392 L F
.996 .762 .439 r
.38755 .54762 m .3858 .54976 L .38588 .54659 L F
.38755 .54762 m .38722 .55272 L .3858 .54976 L F
.72 .971 .932 r
.63212 .4006 m .63669 .39906 L .63589 .39873 L F
.563 .922 .95 r
.63829 .39742 m .63669 .39906 L .63977 .39759 L F
.575 .939 .908 r
.63589 .39873 m .63669 .39906 L .63829 .39742 L F
.382 .01 .203 r
.37701 .46875 m .37908 .46973 L .3766 .46977 L F
.37701 .46875 m .37948 .46826 L .37908 .46973 L F
.732 .658 .777 r
.28125 .59999 m .28306 .60404 L .28592 .60083 L F
.553 .296 .479 r
.33775 .66654 m .34023 .66898 L .3376 .66939 L F
.33775 .66654 m .34053 .66626 L .34023 .66898 L F
.351 .093 .376 r
.25268 .56361 m .24971 .56675 L .25043 .56451 L F
.77 .91 .936 r
.58948 .40897 m .59166 .40961 L .59231 .40842 L F
.71 .984 .884 r
.5958 .37706 m .5946 .37916 L .59804 .37673 L F
.948 .665 .468 r
.5958 .37706 m .59785 .38061 L .5946 .37916 L F
.558 .558 .809 r
.59877 .38227 m .5946 .37916 L .59785 .38061 L F
.762 .757 .848 r
.32147 .65121 m .32142 .65373 L .31971 .6524 L F
.752 .749 .849 r
.32386 .65251 m .32142 .65373 L .32147 .65121 L F
.234 0 0 r
.62674 .34199 m .62961 .34165 L .63085 .34033 L F
.089 0 0 r
.62961 .34165 m .63342 .33951 L .63085 .34033 L F
.935 .859 .741 r
.34888 .57474 m .34817 .57144 L .35047 .57219 L F
.508 .762 .988 r
.28825 .65498 m .28807 .65712 L .29095 .65586 L F
.845 .997 .822 r
.28535 .6582 m .28807 .65712 L .28825 .65498 L F
.09 .158 .64 r
.33407 .58713 m .33484 .59085 L .33639 .58936 L F
.929 .734 .619 r
.33586 .59214 m .33741 .5942 L .33842 .59051 L F
.33538 .59244 m .33577 .59278 L .33586 .59214 L F
.33577 .59278 m .33741 .5942 L .33586 .59214 L F
0 0 .303 r
.33484 .59085 m .33539 .59257 L .33612 .59029 L F
.33539 .59257 m .33546 .59256 L .33612 .59029 L F
.33484 .59085 m .33612 .59029 L .33623 .58951 L F
.9 .851 .785 r
.33639 .58936 m .34073 .58721 L .33813 .58816 L F
.33639 .58936 m .33842 .59051 L .34073 .58721 L F
.929 .734 .619 r
.33538 .59244 m .33842 .59051 L .33639 .58936 L F
.842 .631 .617 r
.33813 .58816 m .33817 .59278 L .33466 .59113 L F
.012 .571 .809 r
.33591 .59253 m .33649 .59258 L .34033 .5933 L F
.33649 .59258 m .33761 .59267 L .33798 .59276 L F
.33649 .59258 m .33798 .59276 L .34033 .5933 L F
.84 .918 .886 r
.34033 .5933 m .33827 .59279 L .34023 .59071 L F
.543 .389 .622 r
.34023 .59071 m .33839 .59267 L .33813 .58816 L F
.33839 .59281 m .33817 .59278 L .33813 .58816 L F
.84 .918 .886 r
.33827 .59279 m .33787 .59269 L .34023 .59071 L F
.543 .389 .622 r
.34023 .59071 m .33839 .59281 L .33839 .59267 L F
.33839 .59281 m .33817 .59306 L .33817 .59278 L F
.842 .631 .617 r
.33817 .59278 m .33817 .59306 L .33738 .59263 L F
.33817 .59278 m .33755 .59266 L .33466 .59113 L F
.43 .687 .972 r
.33466 .59113 m .33787 .59269 L .33755 .59266 L F
.33466 .59113 m .33755 .59266 L .33538 .59244 L F
.842 .631 .617 r
.33755 .59266 m .33738 .59263 L .33466 .59113 L F
.012 .571 .809 r
.33761 .59267 m .33787 .59269 L .33842 .59283 L F
.33761 .59267 m .33842 .59283 L .34033 .5933 L F
.33538 .59244 m .33614 .59252 L .33591 .59253 L F
.33614 .59252 m .33787 .59269 L .33591 .59253 L F
0 0 .303 r
.33539 .59257 m .33543 .59269 L .33546 .59256 L F
.33623 .58951 m .33612 .59029 L .33639 .58936 L F
.707 .765 .897 r
.3219 .55286 m .32061 .55427 L .32001 .55441 L F
.856 .43 .208 r
.34662 .58561 m .34554 .5859 L .34325 .58395 L F
.34662 .58561 m .34731 .58694 L .34554 .5859 L F
.361 0 0 r
.6188 .34773 m .61469 .34829 L .61409 .34903 L F
.6188 .34773 m .61726 .34841 L .61469 .34829 L F
.166 0 0 r
.62122 .3479 m .61726 .34841 L .6188 .34773 L F
.829 .743 .77 r
.34231 .54107 m .33835 .54234 L .34065 .54102 L F
.34231 .54107 m .33728 .54308 L .33835 .54234 L F
.296 .641 .966 r
.34222 .53948 m .34458 .54122 L .34231 .54107 L F
.605 .427 .614 r
.292 .58457 m .29555 .57935 L .29032 .57994 L F
.458 .319 .603 r
.29555 .57935 m .29765 .57996 L .29718 .57715 L F
.424 .276 .574 r
.29555 .57935 m .29742 .58302 L .29765 .57996 L F
0 0 0 r
.29765 .57996 m .29555 .57935 L .29718 .57715 L F
.477 .746 .988 r
.29382 .64811 m .2929 .64997 L .29119 .64848 L F
.405 .661 .963 r
.29382 .64811 m .29521 .64981 L .2929 .64997 L F
.897 .642 .544 r
.46618 .56344 m .47042 .56772 L .4703 .56432 L F
.46618 .56344 m .46608 .56641 L .47042 .56772 L F
.889 .724 .672 r
.47042 .56772 m .46589 .56928 L .47054 .57004 L F
.47042 .56772 m .46608 .56641 L .46589 .56928 L F
.838 .574 .541 r
.36457 .57623 m .36851 .57415 L .3649 .5738 L F
.36457 .57623 m .36834 .57657 L .36851 .57415 L F
.631 .513 .7 r
.34031 .64928 m .33783 .65284 L .33747 .6499 L F
.34031 .64928 m .34133 .65309 L .33783 .65284 L F
.507 .337 .585 r
.34133 .65309 m .33876 .65662 L .33783 .65284 L F
.833 .939 .896 r
.50019 .51939 m .50442 .51763 L .5032 .51691 L F
.873 .918 .855 r
.50442 .51763 m .50577 .51345 L .5032 .51691 L F
.50442 .51763 m .50714 .51456 L .50577 .51345 L F
.97 .809 .626 r
.6714 .33902 m .67232 .34309 L .67077 .34165 L F
.979 .788 .576 r
.67077 .34165 m .67232 .34309 L .6719 .34607 L F
.597 .947 .808 r
.28855 .63023 m .28411 .63255 L .28837 .63325 L F
.777 .687 .765 r
.28718 .62599 m .29121 .62683 L .28855 .63023 L F
.28718 .62599 m .28855 .63023 L .28921 .62865 L F
.688 .328 .358 r
.28855 .63023 m .29109 .63309 L .28837 .63325 L F
0 0 .16 r
.28855 .63023 m .28923 .6312 L .28921 .62865 L F
.28855 .63023 m .28837 .63325 L .28923 .6312 L F
.604 .542 .758 r
.26815 .54063 m .26584 .54384 L .26552 .54124 L F
.26815 .54063 m .26833 .54441 L .26584 .54384 L F
.098 .434 .875 r
.62222 .40302 m .62173 .40114 L .61893 .40002 L F
.075 .413 .863 r
.62222 .40302 m .62326 .40344 L .62173 .40114 L F
.494 .172 .349 r
.52591 .41468 m .52624 .41249 L .5287 .41412 L F
.5 .167 .334 r
.52624 .41249 m .52928 .41215 L .5287 .41412 L F
.577 .106 .1 r
.51935 .41186 m .51586 .41226 L .51788 .4138 L F
.215 0 0 r
.5205 .41308 m .51935 .41186 L .51788 .4138 L F
.5205 .41308 m .52202 .41158 L .51935 .41186 L F
.969 .654 .356 r
.41331 .465 m .4148 .46871 L .41365 .46899 L F
.753 .344 0 r
.41109 .46384 m .41134 .46436 L .41186 .46618 L F
.41134 .46436 m .41365 .46899 L .41271 .46752 L F
.41183 .46547 m .41271 .46752 L .41201 .46642 L F
.41186 .46618 m .41347 .4687 L .41292 .46804 L F
.044 .006 .484 r
.41298 .46814 m .41204 .46657 L .41127 .46704 L F
.753 .344 0 r
.41192 .46636 m .41292 .46804 L .41217 .46713 L F
.41186 .46618 m .41292 .46804 L .41192 .46636 L F
.044 .006 .484 r
.41278 .4687 m .41298 .46814 L .41127 .46704 L F
.969 .654 .356 r
.41331 .465 m .41363 .46874 L .41109 .46384 L F
.41363 .46874 m .41365 .46899 L .41356 .46879 L F
.41363 .46874 m .41356 .46879 L .41109 .46384 L F
.431 .839 .972 r
.414 .4685 m .41351 .46735 L .41303 .46824 L F
.4148 .46871 m .41437 .46826 L .414 .4685 L F
.41437 .46826 m .41351 .46735 L .414 .4685 L F
.044 .006 .484 r
.41298 .46814 m .41398 .46536 L .41204 .46657 L F
.41278 .4687 m .41299 .46816 L .41298 .46814 L F
.893 .965 .829 r
.41217 .46713 m .41299 .46816 L .41278 .4687 L F
.431 .839 .972 r
.41347 .4687 m .41321 .46843 L .41278 .4687 L F
.893 .965 .829 r
.41299 .46816 m .41321 .46843 L .41278 .4687 L F
.431 .839 .972 r
.41321 .46843 m .41303 .46824 L .41278 .4687 L F
.99 .735 .434 r
.41365 .46899 m .41347 .4687 L .41278 .4687 L F
.893 .965 .829 r
.41321 .46843 m .41365 .46899 L .41278 .4687 L F
.044 .006 .484 r
.41278 .4687 m .41303 .46824 L .41299 .46816 L F
.01 0 0 r
.41221 .46744 m .41398 .46536 L .41255 .46759 L F
.893 .965 .829 r
.41217 .46713 m .41278 .4687 L .41127 .46704 L F
.072 0 0 r
.41217 .46713 m .41127 .46704 L .41205 .46715 L F
.01 0 0 r
.41127 .46704 m .41213 .46706 L .41205 .46715 L F
.41127 .46704 m .41205 .46715 L .41189 .46731 L F
.658 .179 .105 r
.4076 .46777 m .41127 .46704 L .40946 .46974 L F
.047 0 0 r
.40946 .46974 m .41127 .46704 L .41255 .46759 L F
.072 0 0 r
.41205 .46715 m .41127 .46704 L .4076 .46777 L F
.41209 .4671 m .4076 .46777 L .40748 .4653 L F
.41217 .46713 m .41205 .46715 L .41209 .4671 L F
.41205 .46715 m .4076 .46777 L .41209 .4671 L F
.01 0 0 r
.41127 .46704 m .41204 .46657 L .41212 .46699 L F
.665 .161 .038 r
.40748 .4653 m .40909 .46397 L .4121 .46706 L F
.41209 .4671 m .4121 .46706 L .41217 .46713 L F
.40748 .4653 m .4121 .46706 L .41209 .4671 L F
.753 .344 0 r
.41109 .46384 m .41217 .46713 L .40909 .46397 L F
.01 0 0 r
.4121 .46706 m .41212 .46699 L .41213 .46706 L F
.41127 .46704 m .41212 .46699 L .4121 .46706 L F
.41189 .46731 m .41213 .46706 L .41221 .46744 L F
.41204 .46657 m .41398 .46536 L .41221 .46744 L F
.753 .344 0 r
.41134 .46436 m .41183 .46547 L .41186 .46618 L F
.41183 .46547 m .41201 .46642 L .41186 .46618 L F
.044 .006 .484 r
.41298 .46814 m .41351 .46735 L .41398 .46536 L F
.41303 .46824 m .41351 .46735 L .41298 .46814 L F
.431 .839 .972 r
.4148 .46871 m .41303 .46824 L .41347 .4687 L F
.753 .344 0 r
.41347 .4687 m .41365 .46899 L .41321 .46843 L F
.41347 .4687 m .41321 .46843 L .41217 .46713 L F
.99 .735 .434 r
.41365 .46899 m .4148 .46871 L .41347 .4687 L F
.431 .839 .972 r
.4148 .46871 m .41757 .46808 L .41351 .46735 L F
.913 .892 .795 r
.50714 .51456 m .50961 .51067 L .50819 .50959 L F
.849 .906 .875 r
.50819 .50959 m .50961 .51067 L .51246 .50781 L F
.804 .644 .684 r
.71873 .30942 m .72058 .31314 L .72123 .31036 L F
.256 .734 .935 r
.31488 .61889 m .31409 .61953 L .31244 .61962 L F
.31488 .61889 m .31663 .61949 L .31409 .61953 L F
.498 .845 .995 r
.28176 .63373 m .28593 .63391 L .28411 .63255 L F
.552 .805 .992 r
.28593 .63391 m .28837 .63325 L .28411 .63255 L F
.809 .525 .508 r
.38524 .49646 m .38929 .49748 L .38967 .495 L F
.534 .815 .998 r
.39202 .49413 m .38967 .495 L .39028 .49291 L F
0 0 .387 r
.38929 .49748 m .39028 .49291 L .38967 .495 L F
.935 .859 .741 r
.34888 .57474 m .34572 .57506 L .34817 .57144 L F
.852 .394 .077 r
.33338 .64671 m .33504 .64898 L .33197 .64661 L F
.046 .308 .795 r
.33412 .64522 m .33338 .64671 L .33197 .64661 L F
.33412 .64522 m .33518 .64827 L .33338 .64671 L F
.861 .523 .41 r
.41529 .52759 m .41641 .53089 L .41882 .5312 L F
.82 .412 .275 r
.41641 .53089 m .41708 .53302 L .41882 .5312 L F
.986 .736 .467 r
.41708 .53302 m .41868 .53422 L .41882 .5312 L F
.608 .794 .971 r
.28818 .6234 m .29121 .62683 L .28718 .62599 L F
.784 .681 .751 r
.32435 .60974 m .32136 .61316 L .32195 .61031 L F
0 0 0 r
.32221 .61083 m .32195 .61031 L .32136 .61316 L F
.32221 .61083 m .32435 .60974 L .32195 .61031 L F
.596 .198 .259 r
.43211 .5696 m .43522 .56962 L .43638 .56751 L F
.314 .075 .383 r
.43638 .56751 m .438 .56716 L .43903 .56416 L F
.724 .494 .577 r
.43522 .56962 m .438 .56716 L .43638 .56751 L F
.314 .075 .383 r
.43903 .56416 m .438 .56716 L .43638 .56751 L F
.909 .759 .683 r
.35013 .52718 m .35193 .52792 L .35059 .52382 L F
.903 .657 .556 r
.35013 .52718 m .35182 .53063 L .35193 .52792 L F
.757 .645 .737 r
.47899 .54703 m .4763 .55055 L .48064 .55076 L F
.737 .687 .803 r
.31592 .63298 m .31686 .63606 L .31954 .63312 L F
.823 .681 .707 r
.36871 .59332 m .37049 .5971 L .3712 .5944 L F
.845 .904 .492 r
.25486 .59872 m .25546 .5985 L .25751 .59689 L F
.589 .363 .541 r
.25518 .59942 m .25751 .59689 L .25546 .5985 L F
.25518 .59942 m .25725 .60037 L .25751 .59689 L F
.303 0 0 r
.25751 .59689 m .25486 .59872 L .25703 .59826 L F
.86 .715 .191 r
.25703 .59826 m .25725 .60037 L .25751 .59689 L F
0 0 0 r
.25741 .59781 m .25703 .59826 L .25751 .59689 L F
.382 0 0 r
.62531 .3461 m .62406 .34774 L .62122 .3479 L F
.435 0 .02 r
.62809 .34605 m .62406 .34774 L .62531 .3461 L F
.814 .981 .891 r
.51375 .41848 m .51008 .4199 L .51251 .4204 L F
0 0 0 r
.51587 .41443 m .51375 .41848 L .51609 .41706 L F
.51609 .41706 m .51375 .41848 L .51251 .4204 L F
.667 .635 .808 r
.32426 .64944 m .32386 .65251 L .32147 .65121 L F
.32426 .64944 m .3281 .65369 L .32386 .65251 L F
.903 .985 .738 r
.59434 .42172 m .59178 .42593 L .59182 .4243 L F
.952 .655 .437 r
.38082 .53115 m .37895 .53284 L .3784 .53047 L F
.38082 .53115 m .38096 .53391 L .37895 .53284 L F
.727 .733 .856 r
.329 .64906 m .3281 .65369 L .32426 .64944 L F
.329 .64906 m .33067 .65242 L .3281 .65369 L F
.118 .237 .712 r
.42384 .5736 m .4254 .57274 L .4229 .5703 L F
0 0 0 r
.42384 .5736 m .42193 .57504 L .4254 .57274 L F
.937 .962 .747 r
.59086 .43764 m .59168 .43904 L .58872 .44012 L F
.704 .525 0 r
.58607 .3947 m .58645 .3991 L .58561 .39796 L F
.721 .414 0 r
.58645 .3991 m .58664 .40016 L .58561 .39796 L F
.162 .187 .639 r
.58664 .40016 m .59037 .3994 L .58602 .39851 L F
.708 .322 0 r
.58561 .39796 m .58664 .40016 L .58564 .39843 L F
.162 .187 .639 r
.58664 .40016 m .58602 .39851 L .58564 .39843 L F
.721 .414 0 r
.58645 .3991 m .58706 .40127 L .58664 .40016 L F
.58706 .40127 m .58709 .4014 L .58664 .40016 L F
.839 .838 .845 r
.5182 .40146 m .51946 .40362 L .52201 .40089 L F
.738 .971 .712 r
.52201 .40089 m .51978 .40328 L .52048 .4016 L F
.51978 .40328 m .51946 .40362 L .52048 .4016 L F
.839 .838 .845 r
.5182 .40146 m .52201 .40089 L .52048 .4016 L F
.941 .945 .759 r
.51986 .40047 m .5182 .40146 L .52048 .4016 L F
.51832 .39768 m .51824 .40029 L .51986 .40047 L F
.51824 .40029 m .5182 .40146 L .51986 .40047 L F
.629 .17 0 r
.52204 .40081 m .52201 .40089 L .52339 .40251 L F
.435 .705 .979 r
.52451 .39996 m .52339 .40251 L .52324 .40234 L F
.52451 .39996 m .52324 .40234 L .52201 .40089 L F
.254 .409 .825 r
.52582 .39768 m .52451 .39996 L .52297 .39596 L F
.394 .172 .455 r
.52582 .39768 m .52557 .39799 L .52451 .39996 L F
.006 0 0 r
.52195 .401 m .52451 .39996 L .52201 .40089 L F
.993 .851 .497 r
.51968 .39688 m .52071 .39912 L .5219 .39502 L F
.591 .735 .943 r
.52451 .39996 m .52201 .40089 L .52004 .3976 L F
.006 0 0 r
.52048 .4016 m .52451 .39996 L .52201 .40089 L F
.591 .735 .943 r
.52451 .39996 m .52004 .3976 L .52297 .39596 L F
.006 0 0 r
.52048 .4016 m .52311 .40096 L .52451 .39996 L F
.52048 .4016 m .52311 .40096 L .52451 .39996 L F
.394 .172 .455 r
.52557 .39799 m .52352 .40047 L .52451 .39996 L F
.52352 .40047 m .52311 .40096 L .52451 .39996 L F
.629 .17 0 r
.52071 .39912 m .52201 .40089 L .52204 .40081 L F
0 0 .548 r
.52004 .3976 m .52201 .40089 L .52071 .39912 L F
.941 .945 .759 r
.51832 .39768 m .52048 .4016 L .52004 .3976 L F
0 0 .548 r
.52004 .3976 m .52071 .39912 L .51968 .39688 L F
.51 .42 .69 r
.52048 .4016 m .52279 .39818 L .52004 .3976 L F
.006 0 0 r
.52048 .4016 m .52195 .401 L .52201 .40089 L F
.51 .42 .69 r
.52048 .4016 m .52311 .40096 L .52279 .39818 L F
.067 .6 .863 r
.51824 .3997 m .52161 .40027 L .52273 .40079 L F
.52222 .40073 m .52273 .40079 L .52311 .40096 L F
.51824 .3997 m .52273 .40079 L .52222 .40073 L F
.51824 .3997 m .52098 .40041 L .52048 .4016 L F
.52098 .40041 m .52311 .40096 L .52048 .4016 L F
.371 .119 .397 r
.52339 .40251 m .52378 .40466 L .52113 .40566 L F
.476 .328 .6 r
.52339 .40251 m .52676 .40219 L .52629 .40052 L F
.198 .015 .392 r
.52602 .40177 m .52339 .40251 L .52629 .40052 L F
.435 .705 .979 r
.52602 .40177 m .52676 .40219 L .52339 .40251 L F
.413 .289 .602 r
.52629 .40052 m .52676 .40219 L .52905 .40103 L F
.429 .117 .333 r
.5278 .40136 m .52602 .40177 L .52629 .40052 L F
.59 .777 .969 r
.52905 .40103 m .52676 .40219 L .52631 .40175 L F
.429 .117 .333 r
.52823 .4016 m .52631 .40175 L .5278 .40136 L F
.52631 .40175 m .52602 .40177 L .5278 .40136 L F
.52905 .40103 m .52823 .4016 L .52629 .40052 L F
.59 .777 .969 r
.52905 .40103 m .52631 .40175 L .52451 .39996 L F
.435 .705 .979 r
.52627 .4017 m .52631 .40175 L .52602 .40177 L F
.52631 .40175 m .52676 .40219 L .52602 .40177 L F
.429 .117 .333 r
.52823 .4016 m .52566 .40339 L .52602 .40177 L F
.198 .015 .392 r
.52566 .40339 m .52339 .40251 L .52602 .40177 L F
.435 .705 .979 r
.52451 .39996 m .52627 .4017 L .52339 .40251 L F
.198 .015 .392 r
.52566 .40339 m .52378 .40466 L .52339 .40251 L F
.829 .549 .515 r
.34024 .52636 m .33702 .52408 L .34141 .52469 L F
.945 .583 .236 r
.41296 .52367 m .41342 .52635 L .41529 .52759 L F
.942 .643 .445 r
.41342 .52635 m .41641 .53089 L .41529 .52759 L F
.855 .613 .571 r
.38657 .54138 m .38609 .54392 L .38433 .54028 L F
.159 0 0 r
.54229 .40912 m .54514 .4092 L .54649 .40894 L F
.163 .371 .821 r
.54849 .40835 m .54649 .40894 L .54514 .4092 L F
.54849 .40835 m .54881 .40972 L .54649 .40894 L F
.327 .234 .594 r
.54881 .40972 m .54678 .41254 L .54649 .40894 L F
0 0 0 r
.55827 .38601 m .5552 .38827 L .5575 .38473 L F
.55827 .38601 m .55692 .38727 L .5552 .38827 L F
.99 .838 .465 r
.5575 .38473 m .55692 .38727 L .55827 .38601 L F
.903 .543 .347 r
.34324 .51415 m .3444 .5173 L .3465 .51797 L F
.915 .584 .403 r
.3444 .5173 m .34456 .51966 L .3465 .51797 L F
.85 .469 .327 r
.3465 .51797 m .34456 .51966 L .34704 .52011 L F
.784 .681 .751 r
.32435 .60974 m .32621 .61369 L .32136 .61316 L F
.491 .29 .534 r
.32621 .61369 m .32351 .61731 L .32136 .61316 L F
.32621 .61369 m .32602 .61649 L .32351 .61731 L F
0 0 0 r
.32621 .61369 m .32351 .61731 L .32602 .61649 L F
.833 .422 .264 r
.36127 .51025 m .35722 .50707 L .36074 .50864 L F
.392 .689 .979 r
.60784 .39566 m .60353 .39476 L .60724 .39604 L F
.244 .571 .94 r
.60585 .3933 m .60724 .39604 L .60353 .39476 L F
.712 .982 .791 r
.67888 .37513 m .68179 .37186 L .67875 .37485 L F
.67888 .37513 m .68213 .3724 L .68179 .37186 L F
.868 .919 .86 r
.51572 .39333 m .51298 .39291 L .51417 .3916 L F
.833 .899 .887 r
.51792 .39075 m .51572 .39333 L .51417 .3916 L F
.148 .033 .455 r
.42155 .5714 m .42007 .5766 L .41948 .57454 L F
.629 .899 .589 r
.66702 .31693 m .6642 .32002 L .66587 .31785 L F
.121 0 .277 r
.6642 .32002 m .66608 .32058 L .66587 .31785 L F
.6642 .32002 m .66381 .3219 L .66608 .32058 L F
.698 .809 .934 r
.38722 .55272 m .38934 .55424 L .38929 .55419 L F
.484 .201 .408 r
.42742 .60363 m .42932 .60581 L .42733 .60595 L F
.42742 .60363 m .42949 .60325 L .42932 .60581 L F
.94 .939 .596 r
.34511 .5884 m .34554 .5859 L .34731 .58694 L F
.67 .634 .805 r
.32982 .58438 m .33407 .58713 L .33226 .58328 L F
0 .094 .651 r
.33407 .58713 m .33449 .58587 L .33226 .58328 L F
.268 .046 .38 r
.4954 .4451 m .49288 .44869 L .49529 .44796 L F
.439 .631 .935 r
.49288 .44869 m .49661 .44924 L .49529 .44796 L F
.844 .823 .828 r
.35363 .61619 m .35765 .61711 L .35595 .61351 L F
.897 .689 .613 r
.3575 .61889 m .35765 .61711 L .35363 .61619 L F
.789 .803 .864 r
.35595 .61351 m .35765 .61711 L .35999 .61347 L F
.762 .985 .903 r
.68213 .3724 m .6855 .36984 L .68325 .36983 L F
.784 .979 .705 r
.68179 .37186 m .68213 .3724 L .68325 .36983 L F
.936 .817 .703 r
.57596 .42928 m .57595 .42444 L .5742 .4282 L F
.905 .731 .655 r
.57342 .43073 m .57596 .42928 L .5742 .4282 L F
.57342 .43073 m .57549 .43211 L .57596 .42928 L F
.326 0 .138 r
.59232 .37213 m .59561 .37156 L .59593 .36954 L F
.208 .276 .714 r
.59469 .36561 m .59593 .36954 L .5977 .36745 L F
0 0 .065 r
.59593 .36954 m .59731 .37025 L .5977 .36745 L F
.59593 .36954 m .59561 .37156 L .59731 .37025 L F
.688 .591 .741 r
.34163 .63446 m .34253 .63003 L .33994 .63024 L F
.34163 .63446 m .34364 .63281 L .34253 .63003 L F
.093 0 .048 r
.34069 .63568 m .34364 .63281 L .34163 .63446 L F
.96 .703 .503 r
.32136 .61316 m .32351 .61731 L .32158 .61597 L F
.818 .844 .869 r
.32158 .61597 m .32351 .61731 L .31987 .61946 L F
.535 .915 .769 r
.44957 .43895 m .44543 .44112 L .44703 .43929 L F
.614 .935 .715 r
.45143 .43725 m .44957 .43895 L .45075 .43742 L F
.602 .952 .882 r
.45075 .43742 m .44957 .43895 L .44703 .43929 L F
.434 .248 .529 r
.58743 .34655 m .59009 .34583 L .58989 .34284 L F
.913 .892 .795 r
.50714 .51456 m .50819 .50959 L .50577 .51345 L F
.923 .896 .784 r
.47813 .54338 m .48208 .54089 L .4803 .53962 L F
.47813 .54338 m .47944 .54444 L .48208 .54089 L F
.575 .844 .996 r
.4803 .53962 m .48208 .54089 L .48477 .54013 L F
0 0 .509 r
.56943 .41624 m .56824 .41561 L .56975 .41366 L F
.56943 .41624 m .56946 .41781 L .56824 .41561 L F
.767 .696 .784 r
.44168 .56381 m .438 .56716 L .43903 .56416 L F
0 0 0 r
.43903 .56416 m .43984 .56483 L .44168 .56381 L F
.43903 .56416 m .43849 .566 L .43984 .56483 L F
.43903 .56416 m .438 .56716 L .43849 .566 L F
.197 0 0 r
.31201 .68547 m .31383 .6834 L .3163 .68282 L F
.512 .291 .516 r
.33702 .52408 m .33704 .52687 L .3343 .52495 L F
.832 .592 .576 r
.35757 .55964 m .36181 .55755 L .35769 .55688 L F
.35757 .55964 m .36157 .5603 L .36181 .55755 L F
.698 .809 .934 r
.38722 .55272 m .38929 .55419 L .38733 .55324 L F
.898 .681 .601 r
.38877 .55659 m .38733 .55324 L .38929 .55419 L F
.885 .864 .814 r
.45356 .55297 m .4504 .55373 L .45247 .55066 L F
.893 .791 .74 r
.44915 .55595 m .45356 .55297 L .45023 .55687 L F
.44915 .55595 m .4504 .55373 L .45356 .55297 L F
.765 .781 .866 r
.45495 .54887 m .45356 .55297 L .45247 .55066 L F
.45495 .54887 m .45637 .55067 L .45356 .55297 L F
.496 .273 .506 r
.27564 .52753 m .27631 .53108 L .27312 .53123 L F
.558 .411 .637 r
.27804 .52418 m .28132 .52946 L .27564 .52753 L F
.529 .295 .504 r
.27855 .52988 m .27564 .52753 L .28132 .52946 L F
.27855 .52988 m .27631 .53108 L .27564 .52753 L F
.617 .894 .988 r
.64206 .37831 m .63929 .37936 L .64072 .37723 L F
.64072 .37723 m .63929 .37936 L .64206 .37831 L F
.866 .751 .733 r
.33572 .57697 m .33307 .58055 L .33071 .57957 L F
.33572 .57697 m .33071 .57957 L .33317 .57884 L F
.33572 .57697 m .33317 .57884 L .33324 .57676 L F
.628 .096 0 r
.33588 .57779 m .33572 .57697 L .33324 .57676 L F
.33588 .57779 m .338 .57943 L .33572 .57697 L F
.517 .799 .997 r
.31444 .6544 m .31049 .65381 L .31288 .65265 L F
.641 .732 .914 r
.31497 .65193 m .31444 .6544 L .31288 .65265 L F
.31497 .65193 m .31717 .65342 L .31444 .6544 L F
.925 .853 .753 r
.6067 .44085 m .60795 .43893 L .6063 .43754 L F
.767 .696 .784 r
.44168 .56381 m .44334 .56767 L .438 .56716 L F
.791 .706 .771 r
.44168 .56381 m .44587 .56432 L .44334 .56767 L F
.881 .467 .042 r
.5852 .39252 m .5847 .39367 L .58365 .39118 L F
.5852 .39252 m .58607 .3947 L .5847 .39367 L F
.669 .54 .698 r
.65607 .35803 m .6509 .35936 L .65508 .36016 L F
.617 .498 .695 r
.6509 .35936 m .65262 .36262 L .6547 .36098 L F
.818 .887 .893 r
.52311 .47618 m .51881 .47748 L .52156 .4748 L F
.647 .917 .979 r
.52411 .47421 m .52311 .47618 L .52156 .4748 L F
.52411 .47421 m .52586 .47488 L .52311 .47618 L F
.796 .306 .031 r
.57094 .42011 m .57197 .41915 L .56946 .41781 L F
.864 .416 .1 r
.57274 .42095 m .57197 .41915 L .57094 .42011 L F
.219 0 .041 r
.31449 .5329 m .31778 .53153 L .31529 .5325 L F
.72 .907 .541 r
.48746 .41165 m .48861 .4093 L .49122 .40954 L F
.48746 .41165 m .48739 .41133 L .48861 .4093 L F
0 .088 .568 r
.54206 .41743 m .54214 .41763 L .53969 .41499 L F
.54206 .41743 m .54269 .41806 L .54214 .41763 L F
.881 .992 .777 r
.3727 .47353 m .3749 .47263 L .3766 .46977 L F
.799 .678 .731 r
.44596 .561 m .44587 .56432 L .44168 .56381 L F
0 0 .528 r
.44711 .56276 m .44832 .56254 L .44804 .562 L F
0 0 0 r
.44752 .56037 m .44621 .5635 L .44711 .56276 L F
.653 .957 .94 r
.44689 .55963 m .44752 .56037 L .44596 .561 L F
0 0 0 r
.44752 .56037 m .44711 .56276 L .44689 .55963 L F
.501 .768 .991 r
.44689 .55963 m .44596 .561 L .44395 .56035 L F
.799 .678 .731 r
.44596 .561 m .44168 .56381 L .44395 .56035 L F
.936 .792 .677 r
.44362 .56188 m .44596 .561 L .44689 .55963 L F
.34 .021 .269 r
.44689 .55963 m .44395 .56035 L .44362 .56188 L F
0 0 .528 r
.44711 .56276 m .44606 .55818 L .44689 .55963 L F
.44711 .56276 m .44804 .562 L .44606 .55818 L F
0 0 0 r
.44621 .5635 m .44587 .56432 L .44711 .56276 L F
.936 .792 .677 r
.44362 .56188 m .44587 .56432 L .44596 .561 L F
.322 .616 .955 r
.44711 .56276 m .44587 .56432 L .44362 .56188 L F
.876 .548 .425 r
.4205 .54318 m .4237 .54661 L .42217 .54442 L F
.737 .992 .837 r
.67219 .37766 m .6708 .37994 L .67269 .37817 L F
.695 .946 .959 r
.66961 .37922 m .6708 .37994 L .67219 .37766 L F
.553 .876 .993 r
.63576 .34846 m .63732 .34679 L .63527 .34717 L F
.63576 .34846 m .63733 .34764 L .63732 .34679 L F
.771 .557 .609 r
.3863 .46509 m .38223 .46813 L .38451 .46498 L F
.3863 .46509 m .38631 .46823 L .38223 .46813 L F
.714 .541 .654 r
.3897 .46488 m .38631 .46823 L .3863 .46509 L F
0 .038 .605 r
.52294 .39022 m .52239 .39153 L .52077 .39008 L F
.52294 .39022 m .52309 .3924 L .52239 .39153 L F
.55 .056 .036 r
.29097 .67124 m .29127 .66907 L .28868 .66984 L F
.76 .865 .926 r
.6547 .36098 m .65939 .35986 L .65724 .35875 L F
.832 .684 .699 r
.36871 .59332 m .36651 .59683 L .37049 .5971 L F
.754 .683 .784 r
.36651 .59683 m .37008 .59989 L .37049 .5971 L F
.588 .947 .874 r
.60215 .38989 m .60616 .38836 L .60588 .38881 L F
.398 .84 .724 r
.60616 .38836 m .60941 .38675 L .60834 .38706 L F
0 0 0 r
.60834 .38706 m .60588 .38881 L .60616 .38836 L F
.204 .174 .6 r
.24158 .55752 m .24305 .55664 L .24284 .55286 L F
.256 .025 .359 r
.24158 .55752 m .24269 .55981 L .24305 .55664 L F
.24158 .55752 m .24096 .56033 L .24269 .55981 L F
.685 .91 .973 r
.44764 .59436 m .44935 .59503 L .44889 .59382 L F
0 .286 .759 r
.44889 .59382 m .45141 .59527 L .45021 .59396 L F
.44889 .59382 m .45021 .59396 L .44764 .59436 L F
.631 .816 .397 r
.66844 .3553 m .66786 .35632 L .66708 .35749 L F
0 0 0 r
.50719 .42071 m .50461 .4231 L .50558 .42255 L F
.50861 .41986 m .50719 .42071 L .50558 .42255 L F
.62 .42 .59 r
.50558 .42255 m .50853 .42269 L .50861 .41986 L F
.256 .719 .949 r
.50435 .42195 m .50608 .42226 L .50558 .42255 L F
.50608 .42226 m .50853 .42269 L .50558 .42255 L F
0 0 0 r
.50461 .4231 m .50323 .42438 L .50558 .42255 L F
.164 .484 .9 r
.53471 .42331 m .53375 .42343 L .53172 .42221 L F
.768 .701 .788 r
.25467 .56 m .25268 .56361 L .25321 .56101 L F
.775 .69 .769 r
.38929 .49748 m .39086 .50149 L .38664 .50083 L F
.802 .571 .588 r
.38524 .49646 m .38938 .49859 L .38929 .49748 L F
.708 .53 0 r
.38929 .49748 m .38945 .49938 L .38938 .49859 L F
.552 0 0 r
.3912 .50228 m .39086 .50149 L .38945 .49939 L F
.935 .614 .163 r
.38955 .49893 m .39086 .50149 L .38966 .49842 L F
.745 .866 .44 r
.38938 .49859 m .38945 .49939 L .38955 .49893 L F
.935 .614 .163 r
.38945 .49938 m .38945 .49939 L .38955 .49893 L F
.38945 .49939 m .39086 .50149 L .38955 .49893 L F
.745 .866 .44 r
.38938 .49859 m .38915 .49889 L .38945 .49939 L F
.38955 .49893 m .38945 .49939 L .3912 .50228 L F
.616 .196 .223 r
.385 .49981 m .38741 .50167 L .38813 .50055 L F
.38549 .49967 m .38813 .50055 L .38938 .49859 L F
.385 .49981 m .38813 .50055 L .38549 .49967 L F
.745 .866 .44 r
.38938 .49859 m .38741 .50167 L .38834 .49995 L F
.38915 .49889 m .38834 .49995 L .3912 .50228 L F
.552 0 0 r
.3912 .50228 m .38945 .49939 L .38945 .49938 L F
.745 .866 .44 r
.38955 .49893 m .3912 .50228 L .38945 .49938 L F
.61 .461 .654 r
.39086 .50149 m .39354 .50116 L .39353 .49802 L F
.559 .281 .451 r
.39086 .50149 m .39338 .50357 L .39354 .50116 L F
.324 .578 .933 r
.38834 .49995 m .39251 .50036 L .3916 .50169 L F
.38971 .50107 m .3916 .50169 L .3912 .50228 L F
.38834 .49995 m .3916 .50169 L .38971 .50107 L F
.745 .866 .44 r
.38938 .49859 m .38955 .49893 L .38945 .49938 L F
.935 .614 .163 r
.38945 .49938 m .38966 .49842 L .38929 .49748 L F
.552 0 0 r
.3912 .50228 m .39338 .50357 L .39086 .50149 L F
0 0 0 r
.51152 .49068 m .51269 .48899 L .51365 .48691 L F
.51152 .49068 m .51151 .49088 L .51269 .48899 L F
.919 .654 .519 r
.39231 .56351 m .38925 .55955 L .39239 .56089 L F
.021 0 0 r
.66205 .32403 m .66354 .3242 L .66381 .3219 L F
.66205 .32403 m .66094 .32534 L .66354 .3242 L F
.5 .872 .655 r
.49352 .43759 m .49678 .43559 L .49521 .43673 L F
.81 .473 .418 r
.49678 .43559 m .5009 .4388 L .50024 .43729 L F
.541 .004 0 r
.49521 .43673 m .49678 .43559 L .50024 .43729 L F
.268 .775 .819 r
.4216 .45157 m .42129 .45208 L .41934 .45249 L F
.4216 .45157 m .42396 .45145 L .42129 .45208 L F
.487 .028 .089 r
.39229 .45987 m .394 .46022 L .39157 .45893 L F
.716 .974 .926 r
.44601 .44918 m .44862 .44932 L .45085 .44773 L F
.912 .669 .558 r
.68059 .31886 m .68358 .3217 L .68253 .31964 L F
.68059 .31886 m .68054 .32159 L .68358 .3217 L F
.949 .711 .544 r
.68069 .32408 m .68358 .3217 L .68054 .32159 L F
.68069 .32408 m .68252 .32526 L .68358 .3217 L F
.886 .684 .625 r
.39381 .56691 m .39231 .56351 L .39478 .56426 L F
.534 .882 .985 r
.46963 .53392 m .47218 .53303 L .47329 .53365 L F
.768 .961 .93 r
.47329 .53365 m .47561 .53056 L .47673 .53133 L F
.47329 .53365 m .47218 .53303 L .47561 .53056 L F
.263 .74 .936 r
.63977 .39759 m .64426 .39807 L .64235 .39767 L F
0 .51 .742 r
.64426 .39807 m .64635 .39838 L .64235 .39767 L F
.849 .906 .875 r
.50819 .50959 m .51246 .50781 L .51094 .50649 L F
.868 .859 .83 r
.51094 .50649 m .51246 .50781 L .51502 .50448 L F
0 0 .312 r
.33418 .60371 m .33435 .59879 L .33276 .59817 L F
.33418 .60371 m .33502 .60211 L .33435 .59879 L F
0 0 0 r
.33418 .60371 m .33396 .60403 L .33502 .60211 L F
.33418 .60371 m .3322 .60546 L .33396 .60403 L F
.634 .793 .959 r
.48476 .43203 m .48631 .43415 L .48835 .43279 L F
.544 .627 .884 r
.48631 .43415 m .48918 .43381 L .48835 .43279 L F
.894 .822 .769 r
.5947 .42766 m .59728 .42861 L .59668 .42442 L F
.974 .898 .682 r
.59447 .43034 m .59728 .42861 L .5947 .42766 L F
.59447 .43034 m .59577 .43187 L .59728 .42861 L F
.567 .649 .891 r
.31954 .63312 m .32405 .63552 L .3236 .63413 L F
.632 .636 .836 r
.3236 .63413 m .32405 .63552 L .32636 .63346 L F
0 .084 .644 r
.30393 .67278 m .30521 .67571 L .30609 .67509 L F
.4 .809 .604 r
.30609 .67509 m .30521 .67571 L .30237 .67754 L F
.964 .938 .692 r
.54835 .47336 m .54735 .47826 L .54987 .47481 L F
.738 .947 .948 r
.55291 .47189 m .54835 .47336 L .54987 .47481 L F
.939 .569 .208 r
.41436 .59801 m .41324 .59905 L .41093 .59655 L F
.41436 .59801 m .4149 .60016 L .41324 .59905 L F
.706 .694 .836 r
.33518 .64827 m .33747 .6499 L .33504 .64898 L F
.713 .694 .83 r
.33936 .6477 m .33747 .6499 L .33518 .64827 L F
.701 .673 .82 r
.33936 .6477 m .34031 .64928 L .33747 .6499 L F
.508 .063 .128 r
.39656 .46481 m .39552 .46663 L .39304 .46537 L F
.479 .062 .17 r
.39949 .46451 m .39552 .46663 L .39656 .46481 L F
.253 .309 .728 r
.25193 .56615 m .25138 .57044 L .24971 .56675 L F
.25193 .56615 m .25295 .57106 L .25138 .57044 L F
.291 .386 .788 r
.25396 .57321 m .25138 .57044 L .25295 .57106 L F
.967 .936 .682 r
.47673 .53133 m .47581 .52879 L .47926 .52792 L F
.47673 .53133 m .47561 .53056 L .47581 .52879 L F
.814 .588 .596 r
.56242 .37276 m .56158 .37536 L .55807 .37466 L F
.725 .464 .531 r
.56158 .37536 m .55847 .37725 L .55807 .37466 L F
.723 .604 .724 r
.55934 .37513 m .55941 .37505 L .55956 .3742 L F
.814 .588 .596 r
.56242 .37276 m .5596 .37399 L .55956 .3742 L F
.841 .996 .836 r
.56242 .37276 m .55956 .3742 L .56334 .36965 L F
.723 .604 .724 r
.55941 .37505 m .56252 .37131 L .55956 .3742 L F
.814 .588 .596 r
.5596 .37399 m .55807 .37466 L .55956 .3742 L F
.82 .632 .649 r
.46618 .56344 m .4703 .56432 L .46856 .5605 L F
.666 .971 .81 r
.44205 .58273 m .44164 .58334 L .44591 .58054 L F
.44205 .58273 m .44591 .58054 L .44531 .58216 L F
.655 .593 .773 r
.44591 .58054 m .45047 .58336 L .44814 .57965 L F
.354 .076 .346 r
.44814 .57965 m .44531 .58216 L .44591 .58054 L F
.17 0 .296 r
.49764 .4419 m .4954 .4451 L .49772 .44443 L F
.192 0 .36 r
.49772 .44443 m .4954 .4451 L .49529 .44796 L F
.887 .701 .645 r
.36314 .56684 m .36477 .5703 L .36482 .568 L F
.071 .054 .53 r
.24055 .57016 m .24175 .56567 L .2399 .56754 L F
.871 .966 .855 r
.49185 .5101 m .4933 .50626 L .49456 .50716 L F
.49185 .5101 m .4904 .50945 L .4933 .50626 L F
.75 .967 .932 r
.45318 .44678 m .45771 .44536 L .45511 .4459 L F
.579 .943 .871 r
.45901 .44386 m .45771 .44536 L .46008 .44397 L F
.58 .944 .862 r
.45511 .4459 m .45771 .44536 L .45901 .44386 L F
.602 .863 .992 r
.6503 .38529 m .6477 .38639 L .64579 .38483 L F
0 0 0 r
.37162 .46803 m .37691 .46308 L .37326 .46554 L F
.153 0 0 r
.24578 .57722 m .24377 .57738 L .24155 .57723 L F
.81 .406 .284 r
.3529 .50143 m .34908 .50169 L .35059 .50027 L F
.3529 .50143 m .35329 .50331 L .34908 .50169 L F
.811 .406 .283 r
.3529 .50143 m .35548 .50413 L .35329 .50331 L F
.823 .413 .268 r
.35417 .49347 m .35234 .49318 L .35433 .49154 L F
.35417 .49347 m .35234 .49318 L .35433 .49154 L F
.517 .894 .708 r
.45249 .59573 m .45394 .59439 L .45141 .59527 L F
.45249 .59573 m .45553 .59367 L .45394 .59439 L F
0 0 .36 r
.56965 .37485 m .57074 .3777 L .57064 .37915 L F
0 0 .403 r
.57074 .3777 m .57059 .38165 L .57064 .37915 L F
.202 .061 .455 r
.24277 .54757 m .24442 .54682 L .24444 .54441 L F
.159 .023 .434 r
.2427 .55033 m .24442 .54682 L .24277 .54757 L F
0 .267 .773 r
.44814 .57965 m .45047 .58336 L .45111 .58219 L F
.894 .987 .74 r
.44918 .58671 m .45111 .58219 L .45047 .58336 L F
.808 .385 0 r
.59441 .38725 m .59428 .38594 L .59439 .38446 L F
.59441 .38725 m .59634 .38958 L .59428 .38594 L F
.836 .654 .656 r
.71698 .31238 m .72058 .31314 L .71873 .30942 L F
.825 .699 .726 r
.71844 .31646 m .72058 .31314 L .71698 .31238 L F
.137 .683 .758 r
.53849 .42217 m .53954 .4219 L .53675 .42327 L F
.53849 .42217 m .54159 .42177 L .53954 .4219 L F
.026 0 .139 r
.24691 .53432 m .24812 .53362 L .24975 .53064 L F
.215 .053 .433 r
.24691 .53432 m .24832 .53618 L .24812 .53362 L F
.24691 .53432 m .24664 .53709 L .24832 .53618 L F
.327 .758 .971 r
.64635 .39838 m .65037 .39897 L .64923 .39817 L F
.534 .804 .996 r
.65037 .39897 m .65183 .39696 L .64923 .39817 L F
.65037 .39897 m .65312 .39831 L .65183 .39696 L F
.172 0 0 r
.32264 .53457 m .32038 .53535 L .31784 .53539 L F
0 0 0 r
.3257 .52917 m .32288 .53203 L .32407 .53066 L F
.74 .942 .949 r
.32554 .53036 m .32288 .53203 L .3257 .52917 L F
.32554 .53036 m .32302 .53096 L .32288 .53203 L F
0 .163 .692 r
.32288 .53203 m .32256 .53438 L .32077 .53019 L F
.32288 .53203 m .32077 .53019 L .32407 .53066 L F
.74 .942 .949 r
.32302 .53096 m .3213 .53137 L .32288 .53203 L F
0 .163 .692 r
.32288 .53203 m .32264 .53457 L .32256 .53438 L F
.875 .994 .79 r
.32288 .53203 m .32038 .53535 L .32264 .53457 L F
.073 0 0 r
.63644 .33908 m .63928 .33815 L .64026 .33679 L F
0 0 0 r
.64026 .33679 m .64173 .33695 L .64291 .3358 L F
.64026 .33679 m .63928 .33815 L .64173 .33695 L F
.79 .971 .914 r
.54735 .47826 m .54636 .47737 L .54301 .47992 L F
.964 .938 .692 r
.54835 .47336 m .54636 .47737 L .54735 .47826 L F
.796 .975 .907 r
.47561 .43812 m .4779 .43454 L .47448 .4368 L F
.47561 .43812 m .47918 .43514 L .4779 .43454 L F
.173 0 0 r
.25716 .61357 m .25267 .61587 L .25481 .61735 L F
.888 .969 .652 r
.48132 .52423 m .47926 .52792 L .47956 .52544 L F
.838 .986 .866 r
.47926 .52792 m .47581 .52879 L .47956 .52544 L F
.753 .976 .715 r
.66992 .31376 m .66702 .31693 L .66849 .31436 L F
.48 .313 .577 r
.66587 .31785 m .66849 .31436 L .66702 .31693 L F
.607 .873 .992 r
.33188 .6076 m .32726 .60753 L .3296 .60638 L F
.766 .897 .935 r
.3327 .60578 m .33188 .6076 L .3296 .60638 L F
.925 .929 .56 r
.48132 .52423 m .48085 .52348 L .48235 .51951 L F
.905 .965 .647 r
.48132 .52423 m .47956 .52544 L .48085 .52348 L F
0 0 0 r
.59439 .38446 m .59877 .38227 L .59785 .38061 L F
.788 .987 .894 r
.53587 .48542 m .53656 .48321 L .53341 .48545 L F
.53587 .48542 m .53759 .48388 L .53656 .48321 L F
.286 0 .086 r
.30939 .54842 m .31008 .54993 L .30748 .55053 L F
.165 0 .136 r
.31229 .54862 m .31008 .54993 L .30939 .54842 L F
0 .486 .759 r
.62717 .37696 m .63142 .37805 L .62891 .37832 L F
0 0 .402 r
.33387 .53308 m .33295 .53097 L .33419 .53024 L F
.797 .622 .664 r
.47072 .57901 m .47293 .583 L .47336 .58159 L F
.488 .757 .99 r
.31757 .55276 m .32001 .55441 L .31669 .55365 L F
0 0 .455 r
.31788 .55653 m .31669 .55365 L .32001 .55441 L F
.684 .817 .946 r
.32164 .55158 m .32001 .55441 L .31757 .55276 L F
.791 .964 .919 r
.3219 .55286 m .32001 .55441 L .32164 .55158 L F
0 0 0 r
.37162 .46803 m .37408 .46672 L .37691 .46308 L F
.37691 .46308 m .37611 .46546 L .37757 .46318 L F
.37691 .46308 m .37408 .46672 L .37611 .46546 L F
.856 .726 .719 r
.36105 .60613 m .36537 .60653 L .36379 .60274 L F
.844 .771 .781 r
.36105 .60613 m .36244 .60993 L .36537 .60653 L F
.777 .695 .773 r
.36379 .60274 m .36537 .60653 L .36781 .60292 L F
.403 .781 .992 r
.31383 .51369 m .31623 .51333 L .31803 .51433 L F
.31803 .51433 m .31623 .51333 L .31383 .51369 L F
.773 .753 .834 r
.329 .64906 m .33504 .64898 L .33067 .65242 L F
.507 .337 .585 r
.34133 .65309 m .34127 .65611 L .33876 .65662 L F
.267 .475 .875 r
.34245 .65992 m .33876 .65662 L .34127 .65611 L F
0 0 .147 r
.39631 .50858 m .39648 .50974 L .39637 .51123 L F
0 .096 .589 r
.39745 .51192 m .39637 .51123 L .39648 .50974 L F
.819 .341 .052 r
.39355 .50849 m .3967 .51126 L .39648 .50974 L F
.3967 .51126 m .39745 .51192 L .39648 .50974 L F
0 0 .147 r
.39626 .50648 m .39648 .50974 L .39631 .50858 L F
.513 .265 .476 r
.39637 .51123 m .39882 .51329 L .39804 .51159 L F
0 .096 .589 r
.39745 .51192 m .39882 .51329 L .39637 .51123 L F
.918 .605 .437 r
.68039 .31636 m .68059 .31886 L .68253 .31964 L F
.888 .865 .81 r
.6039 .44123 m .6056 .44285 L .6067 .44085 L F
.795 .792 .849 r
.25423 .584 m .25083 .58338 L .25214 .58125 L F
.805 .553 .558 r
.25306 .58519 m .25083 .58338 L .25423 .584 L F
.266 .545 .924 r
.25475 .58212 m .25423 .584 L .25214 .58125 L F
.01 0 .39 r
.25475 .58212 m .25306 .58519 L .25423 .584 L F
.75 .784 .881 r
.32636 .63346 m .33064 .63368 L .32863 .63254 L F
.752 .733 .835 r
.33064 .63368 m .33138 .62914 L .32863 .63254 L F
.33064 .63368 m .33251 .63239 L .33138 .62914 L F
.786 .691 .759 r
.25795 .55675 m .25467 .56 L .25518 .55753 L F
.732 .658 .777 r
.28125 .59999 m .28592 .60083 L .28362 .59942 L F
.86 .611 .562 r
.6857 .32906 m .68763 .33253 L .68753 .3298 L F
.582 .694 .918 r
.28919 .64857 m .28444 .64638 L .28719 .64566 L F
.393 .576 .912 r
.28912 .64558 m .28919 .64857 L .28719 .64566 L F
.28912 .64558 m .29119 .64848 L .28919 .64857 L F
.868 .859 .83 r
.51094 .50649 m .51502 .50448 L .5136 .50329 L F
.881 .897 .838 r
.5136 .50329 m .51502 .50448 L .5177 .50116 L F
.879 .615 .535 r
.39882 .51329 m .40152 .51536 L .40546 .51572 L F
.643 .574 .762 r
.34251 .56337 m .34318 .56657 L .34582 .5636 L F
.408 .067 .273 r
.33204 .67267 m .33337 .67518 L .33078 .67551 L F
.33204 .67267 m .33444 .67226 L .33337 .67518 L F
.863 .551 .458 r
.35722 .50707 m .35548 .50413 L .35704 .50463 L F
.89 .754 .705 r
.46693 .55648 m .46856 .5605 L .46895 .55773 L F
.46693 .55648 m .465 .56011 L .46856 .5605 L F
.803 .605 .635 r
.464 .56301 m .46856 .5605 L .465 .56011 L F
.464 .56301 m .46618 .56344 L .46856 .5605 L F
.789 .567 .6 r
.55828 .39135 m .56196 .38925 L .55819 .38889 L F
.55828 .39135 m .5631 .3917 L .56196 .38925 L F
0 .307 .778 r
.56196 .38925 m .56383 .38964 L .56298 .38745 L F
.56196 .38925 m .56506 .39113 L .56383 .38964 L F
.392 .381 .727 r
.5631 .3917 m .56506 .39113 L .56196 .38925 L F
.784 .643 .706 r
.58625 .35577 m .58251 .35561 L .58478 .35208 L F
.567 .05 0 r
.58625 .35577 m .58472 .35701 L .58251 .35561 L F
.101 .314 .789 r
.41073 .59375 m .41179 .59185 L .40942 .59092 L F
.98 .699 .414 r
.41073 .59375 m .4093 .59548 L .41179 .59185 L F
.41073 .59375 m .41093 .59655 L .4093 .59548 L F
.302 .79 .893 r
.5989 .40017 m .60017 .39931 L .59738 .39853 L F
.5989 .40017 m .60193 .39958 L .60017 .39931 L F
.67 .958 .944 r
.49337 .40805 m .49122 .40954 L .48861 .4093 L F
.836 .982 .695 r
.66992 .31376 m .67093 .31093 L .67211 .31204 L F
.66992 .31376 m .66849 .31436 L .67093 .31093 L F
.991 .848 .483 r
.34749 .56751 m .34647 .56803 L .34561 .56643 L F
.863 .525 .409 r
.3688 .51448 m .3657 .5136 L .36528 .51106 L F
.892 .636 .545 r
.3688 .51448 m .36565 .51604 L .3657 .5136 L F
.3688 .51448 m .36871 .5174 L .36565 .51604 L F
.714 .541 .654 r
.3897 .46488 m .39132 .47021 L .38631 .46823 L F
.603 .477 .681 r
.39548 .46759 m .3897 .46488 L .39304 .46537 L F
.39548 .46759 m .39132 .47021 L .3897 .46488 L F
0 .442 .702 r
.45343 .59314 m .45553 .59367 L .45565 .59367 L F
.999 .8 .492 r
.45394 .59439 m .45553 .59367 L .45343 .59314 L F
.903 .985 .738 r
.59434 .42172 m .59182 .4243 L .59254 .42119 L F
.261 .728 .946 r
.59254 .42119 m .59661 .42179 L .59434 .42172 L F
.401 .838 .704 r
.32345 .55643 m .32082 .55744 L .31996 .55818 L F
0 0 .029 r
.32603 .55354 m .32515 .55609 L .3236 .55626 L F
0 0 .019 r
.32747 .55312 m .32515 .55609 L .32603 .55354 L F
.563 .729 .952 r
.32603 .55354 m .3219 .55286 L .32458 .5511 L F
.142 .389 .84 r
.32458 .5511 m .32747 .55312 L .32603 .55354 L F
.81 .721 .766 r
.32312 .55227 m .32515 .55609 L .32747 .55312 L F
.843 .988 .719 r
.32515 .55609 m .32548 .55399 L .3262 .55598 L F
.32515 .55609 m .3262 .55598 L .32622 .55603 L F
0 0 .029 r
.3236 .55626 m .32515 .55609 L .32345 .55643 L F
0 0 0 r
.32515 .55609 m .32082 .55744 L .32345 .55643 L F
.715 .499 0 r
.58601 .37478 m .58656 .37847 L .58628 .37645 L F
.768 .701 .788 r
.25467 .56 m .25676 .56409 L .25268 .56361 L F
.921 .527 .201 r
.25676 .56409 m .25193 .56615 L .25268 .56361 L F
.25676 .56409 m .2548 .56332 L .25193 .56615 L F
.25676 .56409 m .25664 .56641 L .2548 .56332 L F
.978 .698 .421 r
.25467 .56 m .2548 .56332 L .25676 .56409 L F
.921 .527 .201 r
.25676 .56409 m .25664 .56641 L .2548 .56332 L F
.645 .587 .775 r
.25606 .56944 m .25295 .57106 L .25193 .56615 L F
.25606 .56944 m .25193 .56615 L .25398 .56785 L F
.563 .241 .381 r
.25569 .56667 m .25398 .56785 L .25193 .56615 L F
.885 .818 .777 r
.25664 .56641 m .25398 .56785 L .25511 .56707 L F
.563 .241 .381 r
.25599 .56672 m .25398 .56785 L .25569 .56667 L F
.885 .818 .777 r
.25511 .56707 m .25398 .56785 L .25437 .56739 L F
.626 .205 .225 r
.25676 .56409 m .25869 .56553 L .25664 .56641 L F
.57 .414 .63 r
.2548 .56332 m .2559 .56645 L .25193 .56615 L F
.885 .818 .777 r
.25664 .56641 m .25563 .56685 L .25747 .56477 L F
.25563 .56685 m .25545 .56692 L .2559 .56645 L F
.25563 .56685 m .2559 .56645 L .25747 .56477 L F
.407 .168 .436 r
.25924 .56202 m .25829 .56297 L .25633 .5628 L F
.621 .476 .663 r
.25829 .56297 m .25884 .56207 L .25633 .5628 L F
.885 .818 .777 r
.25849 .56276 m .25829 .56297 L .25884 .56207 L F
.741 .816 .91 r
.25891 .56247 m .25953 .56615 L .25849 .56276 L F
.407 .168 .436 r
.25849 .56276 m .2591 .56304 L .25829 .56297 L F
.25924 .56202 m .2592 .56227 L .25849 .56276 L F
.2592 .56227 m .2591 .56304 L .25849 .56276 L F
.626 .205 .225 r
.25869 .56553 m .25953 .56615 L .25664 .56641 L F
.741 .816 .91 r
.25849 .56276 m .25953 .56615 L .25664 .56641 L F
.25884 .56207 m .25891 .56247 L .25849 .56276 L F
.621 .476 .663 r
.2591 .56304 m .25884 .56207 L .25829 .56297 L F
.414 .326 .647 r
.25884 .56207 m .2559 .56645 L .2548 .56332 L F
.885 .818 .777 r
.25829 .56297 m .25701 .56426 L .25884 .56207 L F
.57 .414 .63 r
.2559 .56645 m .25569 .56667 L .25193 .56615 L F
.885 .818 .777 r
.25722 .56449 m .25437 .56739 L .25701 .56426 L F
.25747 .56477 m .25644 .56564 L .25722 .56449 L F
.25644 .56564 m .25437 .56739 L .25722 .56449 L F
.25747 .56477 m .25701 .56426 L .25849 .56276 L F
.786 .691 .759 r
.25795 .55675 m .25934 .5609 L .25467 .56 L F
.239 .708 .944 r
.25545 .56015 m .2577 .56001 L .25467 .56 L F
.25934 .5609 m .2577 .56001 L .25545 .56015 L F
.534 .546 .814 r
.2615 .55996 m .25934 .5609 L .25795 .55675 L F
.688 .935 .966 r
.25966 .55884 m .2577 .56001 L .25934 .5609 L F
.407 .168 .436 r
.25966 .55884 m .25873 .55995 L .2577 .56001 L F
.25873 .55995 m .25633 .5628 L .2577 .56001 L F
.25966 .55884 m .25924 .56202 L .25633 .5628 L F
.885 .818 .777 r
.25545 .56692 m .25437 .56739 L .25747 .56477 L F
.414 .326 .647 r
.25884 .56207 m .25599 .56672 L .2559 .56645 L F
.57 .414 .63 r
.2559 .56645 m .25599 .56672 L .25569 .56667 L F
.451 .863 .956 r
.51784 .41559 m .52329 .41536 L .52326 .41768 L F
.409 .154 .413 r
.52326 .41768 m .52329 .41536 L .52591 .41468 L F
.522 .845 .548 r
.49946 .44006 m .5009 .4388 L .49764 .4419 L F
0 0 .234 r
.49946 .44006 m .49764 .4419 L .49772 .44443 L F
.059 0 0 r
.29311 .68602 m .29718 .68594 L .29571 .68606 L F
.323 .742 .976 r
.29718 .68594 m .2981 .68511 L .29571 .68606 L F
.29718 .68594 m .30005 .68613 L .2981 .68511 L F
.492 .407 .688 r
.60025 .36219 m .60422 .36498 L .60386 .36216 L F
.687 .552 .697 r
.53964 .41222 m .54241 .41385 L .54229 .40912 L F
.795 .505 .497 r
.54378 .41538 m .53969 .41499 L .53964 .41222 L F
.416 0 .02 r
.53969 .41499 m .54241 .41385 L .53964 .41222 L F
.845 .904 .492 r
.25486 .59872 m .25518 .59942 L .25546 .5985 L F
0 .387 .794 r
.25518 .59942 m .25725 .60037 L .25486 .59872 L F
.726 .93 .958 r
.32134 .54428 m .32207 .54175 L .32299 .54041 L F
.32134 .54428 m .3203 .54324 L .32207 .54175 L F
.998 .807 .462 r
.32134 .54428 m .32096 .547 L .3203 .54324 L F
.579 .363 .552 r
.324 .54633 m .32096 .547 L .32134 .54428 L F
.911 .792 .715 r
.57172 .43429 m .57472 .43589 L .57549 .43211 L F
.894 .81 .759 r
.5725 .43807 m .57472 .43589 L .57172 .43429 L F
.897 .546 .37 r
.57673 .43877 m .57472 .43589 L .5725 .43807 L F
.832 .993 .857 r
.59874 .37421 m .59804 .37673 L .59947 .37458 L F
.59874 .37421 m .5958 .37706 L .59804 .37673 L F
.591 .597 .826 r
.34238 .64718 m .34031 .64928 L .33936 .6477 L F
.34238 .64718 m .34378 .64958 L .34031 .64928 L F
.671 .578 .742 r
.34378 .64958 m .34133 .65309 L .34031 .64928 L F
.365 .52 .879 r
.30889 .62958 m .31116 .62971 L .31021 .62819 L F
.867 .518 .387 r
.37731 .52766 m .37526 .52926 L .3752 .52677 L F
.37731 .52766 m .3784 .53047 L .37526 .52926 L F
.481 .241 .473 r
.54918 .39243 m .54892 .39516 L .54628 .39567 L F
.805 .709 .759 r
.55184 .39154 m .54892 .39516 L .54918 .39243 L F
.851 .57 .512 r
.65288 .3792 m .64935 .38052 L .65153 .37774 L F
.65288 .3792 m .6529 .38174 L .64935 .38052 L F
.599 .829 .987 r
.65516 .37808 m .65288 .3792 L .65153 .37774 L F
.702 .921 .587 r
.5422 .39234 m .5393 .39609 L .54076 .39353 L F
.464 .674 .955 r
.5393 .39609 m .54247 .39605 L .54076 .39353 L F
.639 .964 .892 r
.46135 .43181 m .45701 .43351 L .46059 .43135 L F
.599 .939 .757 r
.46274 .43018 m .46475 .42935 L .46135 .43181 L F
.592 .947 .9 r
.46274 .43018 m .46135 .43181 L .46059 .43135 L F
.857 .696 .681 r
.35521 .54348 m .35465 .54651 L .35853 .54727 L F
.861 .659 .629 r
.35465 .54651 m .35682 .55017 L .35853 .54727 L F
.767 .683 .77 r
.38929 .49748 m .39353 .49802 L .39202 .49413 L F
.944 .917 .756 r
.41893 .59032 m .41837 .59044 L .42062 .59029 L F
.41893 .59032 m .41705 .59198 L .41837 .59044 L F
.943 .671 .493 r
.41837 .59044 m .41844 .59053 L .41872 .59042 L F
.918 .974 .771 r
.41841 .59055 m .41705 .59198 L .41891 .59034 L F
.901 .582 .432 r
.41705 .59198 m .41841 .59055 L .41837 .59044 L F
.918 .974 .771 r
.41664 .59129 m .41705 .59198 L .41841 .59055 L F
.901 .582 .432 r
.41705 .59198 m .41978 .59472 L .41841 .59055 L F
.934 .685 .538 r
.41844 .59053 m .41978 .59472 L .42101 .59374 L F
.41837 .59044 m .41841 .59055 L .41844 .59053 L F
.41841 .59055 m .41978 .59472 L .41844 .59053 L F
.918 .974 .771 r
.41635 .59081 m .41664 .59129 L .4185 .5905 L F
.41879 .59035 m .4185 .5905 L .41893 .59032 L F
.41635 .59081 m .4185 .5905 L .41879 .59035 L F
.41664 .59129 m .41891 .59034 L .41893 .59032 L F
.943 .671 .493 r
.41872 .59042 m .42101 .59374 L .42062 .59029 L F
.249 .169 .566 r
.42062 .59029 m .42101 .59374 L .42248 .59233 L F
.541 .872 .602 r
.42101 .59374 m .41978 .59472 L .42248 .59233 L F
.073 0 0 r
.41995 .59457 m .4221 .59458 L .42248 .59233 L F
.41978 .59472 m .41991 .59471 L .41995 .59457 L F
.41991 .59471 m .4221 .59458 L .41995 .59457 L F
.943 .671 .493 r
.41844 .59053 m .42037 .59294 L .41872 .59042 L F
.42037 .59294 m .42101 .59374 L .4204 .59285 L F
.42037 .59294 m .4204 .59285 L .41872 .59042 L F
0 .056 .622 r
.42062 .59029 m .42248 .59233 L .42162 .5906 L F
.42062 .59029 m .42162 .5906 L .41893 .59032 L F
.881 .897 .838 r
.5136 .50329 m .5177 .50116 L .51675 .50032 L F
.88 .978 .836 r
.51725 .49924 m .5177 .50116 L .52094 .49834 L F
.51725 .49924 m .51675 .50032 L .5177 .50116 L F
.666 .904 .979 r
.46662 .44138 m .46744 .43921 L .46546 .44047 L F
.46662 .44138 m .46907 .44016 L .46744 .43921 L F
.609 .118 0 r
.31925 .50482 m .321 .50695 L .31927 .50522 L F
.31925 .50482 m .31927 .50522 L .32152 .5037 L F
0 .505 .792 r
.60019 .3419 m .60362 .3429 L .6021 .3425 L F
.72 .215 .03 r
.60019 .3419 m .60234 .344 L .60362 .3429 L F
.333 .801 .926 r
.60234 .344 m .60638 .34372 L .60362 .3429 L F
.48 .303 .563 r
.30594 .61736 m .30859 .61682 L .30848 .61341 L F
.30594 .61736 m .30859 .61682 L .30848 .61341 L F
0 0 0 r
.30462 .55018 m .30811 .54655 L .30407 .5472 L F
.30462 .55018 m .30637 .54896 L .30811 .54655 L F
.04 0 0 r
.30811 .54655 m .30896 .54785 L .3099 .54668 L F
.30811 .54655 m .30637 .54896 L .30896 .54785 L F
.981 .887 .535 r
.50024 .43729 m .5009 .4388 L .49946 .44006 L F
.897 .689 .613 r
.3575 .61889 m .35363 .61619 L .3528 .61894 L F
.862 .788 .777 r
.35483 .62167 m .3575 .61889 L .3528 .61894 L F
.647 .963 .916 r
.51974 .48309 m .5175 .48442 L .51655 .48403 L F
.19 .316 .763 r
.39552 .46663 m .39548 .46759 L .39304 .46537 L F
.812 .787 .83 r
.46693 .55648 m .46895 .55773 L .47145 .55505 L F
.797 .707 .766 r
.32693 .54872 m .32747 .55312 L .32616 .54863 L F
.689 .588 .737 r
.32877 .54888 m .32761 .55155 L .32675 .54827 L F
.797 .707 .766 r
.32817 .55195 m .32807 .5518 L .32901 .54896 L F
.32996 .54907 m .32868 .55015 L .32953 .54902 L F
.659 .166 .07 r
.32953 .54902 m .32981 .5492 L .32996 .54907 L F
.797 .707 .766 r
.32953 .54902 m .32868 .55015 L .32901 .54896 L F
.659 .166 .07 r
.32901 .54896 m .32947 .5491 L .32953 .54902 L F
.32947 .5491 m .32981 .5492 L .32953 .54902 L F
0 0 0 r
.32777 .55135 m .32761 .55155 L .32857 .55029 L F
.561 .622 .87 r
.32745 .55086 m .32761 .55155 L .32777 .55135 L F
.689 .588 .737 r
.32857 .55029 m .32761 .55155 L .32989 .54629 L F
.797 .707 .766 r
.32901 .54896 m .32785 .55246 L .32693 .54872 L F
0 0 0 r
.32906 .54971 m .32777 .55135 L .32945 .54914 L F
.561 .622 .87 r
.32703 .54898 m .32703 .54901 L .3287 .54958 L F
.32703 .54901 m .32745 .55086 L .32865 .54963 L F
.32703 .54901 m .32865 .54963 L .3287 .54958 L F
.689 .588 .737 r
.33134 .54664 m .32947 .5491 L .32989 .54629 L F
.32947 .5491 m .32857 .55029 L .32901 .54896 L F
.32947 .5491 m .32901 .54896 L .32989 .54629 L F
0 0 .28 r
.32679 .54837 m .32761 .55155 L .32745 .55086 L F
.689 .588 .737 r
.32877 .54888 m .32675 .54827 L .326 .54537 L F
0 0 .28 r
.326 .54537 m .32675 .54827 L .32679 .54837 L F
.32675 .54827 m .32761 .55155 L .32679 .54837 L F
.659 .166 .07 r
.32616 .54863 m .32647 .54879 L .32697 .54885 L F
.32694 .54875 m .32697 .54885 L .32944 .54915 L F
.32616 .54863 m .32697 .54885 L .32694 .54875 L F
.797 .707 .766 r
.32786 .55249 m .32747 .55312 L .32693 .54872 L F
.561 .622 .87 r
.32745 .55086 m .32906 .54971 L .3287 .54958 L F
0 0 0 r
.32777 .55135 m .32947 .5491 L .32945 .54914 L F
.689 .588 .737 r
.32989 .54629 m .32877 .54888 L .326 .54537 L F
0 0 0 r
.32794 .54436 m .326 .54537 L .32581 .54542 L F
.668 .907 .978 r
.33091 .54155 m .32794 .54436 L .33014 .54305 L F
.705 .546 .671 r
.33091 .54155 m .33134 .54664 L .326 .54537 L F
0 0 .28 r
.32609 .54534 m .32693 .54872 L .32619 .54531 L F
.32693 .54876 m .32745 .55086 L .32703 .54901 L F
.326 .54537 m .32679 .54837 L .32609 .54534 L F
.32679 .54837 m .32745 .55086 L .32693 .54872 L F
.32679 .54837 m .32693 .54872 L .32609 .54534 L F
.659 .166 .07 r
.32697 .54885 m .32906 .54971 L .32944 .54915 L F
0 0 .28 r
.32693 .54876 m .32703 .54901 L .32703 .54898 L F
.659 .166 .07 r
.32647 .54879 m .32703 .54898 L .32697 .54885 L F
.32703 .54898 m .32906 .54971 L .32697 .54885 L F
.838 .676 .682 r
.324 .54633 m .32458 .5511 L .32142 .54956 L F
.162 .178 .629 r
.32616 .54863 m .32458 .5511 L .32405 .54674 L F
.32424 .54659 m .32405 .54674 L .324 .54633 L F
.32616 .54863 m .32405 .54674 L .32424 .54659 L F
0 0 0 r
.32581 .54542 m .326 .54537 L .324 .54633 L F
.838 .676 .682 r
.324 .54633 m .32142 .54956 L .32096 .547 L F
.162 .178 .629 r
.32616 .54863 m .324 .54633 L .326 .54537 L F
.169 .707 .784 r
.32854 .54 m .33091 .54155 L .32869 .53991 L F
.32476 .54222 m .32744 .54193 L .32854 .54 L F
.32744 .54193 m .33091 .54155 L .32854 .54 L F
.32818 .54185 m .32712 .54185 L .33091 .54155 L F
.32476 .54222 m .32712 .54185 L .32818 .54185 L F
.842 .902 .487 r
.326 .54537 m .32712 .54185 L .32476 .54222 L F
0 0 .406 r
.32577 .54478 m .32612 .54513 L .326 .54537 L F
.32476 .54222 m .32563 .54408 L .32577 .54478 L F
.32563 .54408 m .32612 .54513 L .32577 .54478 L F
.871 .995 .789 r
.32712 .54185 m .32533 .54251 L .32547 .54184 L F
.32533 .54251 m .32479 .54271 L .32526 .54211 L F
.32533 .54251 m .32526 .54211 L .32547 .54184 L F
.583 .091 .051 r
.32672 .53856 m .32503 .53974 L .32869 .53991 L F
.169 .707 .784 r
.32476 .54222 m .32869 .53991 L .32503 .53974 L F
.871 .995 .789 r
.32712 .54185 m .32547 .54184 L .32751 .53925 L F
.842 .902 .487 r
.32665 .54332 m .32591 .54408 L .32712 .54185 L F
.326 .54537 m .32594 .54456 L .32665 .54332 L F
.32594 .54456 m .32591 .54408 L .32665 .54332 L F
.806 .592 .612 r
.32155 .54795 m .32544 .54569 L .32612 .54513 L F
.32544 .54569 m .326 .54537 L .32608 .54522 L F
.32544 .54569 m .32608 .54522 L .32612 .54513 L F
.346 .421 .797 r
.32616 .54863 m .32747 .55312 L .32458 .5511 L F
.664 .161 .04 r
.32437 .54997 m .32762 .55053 L .32623 .5487 L F
.32762 .55053 m .32814 .55062 L .32734 .54982 L F
.32762 .55053 m .32734 .54982 L .32623 .5487 L F
0 0 .28 r
.32693 .54872 m .32693 .54876 L .32703 .54898 L F
.659 .166 .07 r
.32616 .54863 m .32981 .5492 L .32901 .54896 L F
0 0 .28 r
.32693 .54872 m .32703 .54898 L .32619 .54531 L F
.659 .166 .07 r
.32703 .54898 m .32887 .55 L .32906 .54971 L F
.32647 .54879 m .32706 .54909 L .32703 .54898 L F
.32706 .54909 m .32887 .55 L .32703 .54898 L F
0 0 0 r
.32777 .55135 m .32857 .55029 L .32947 .5491 L F
.561 .622 .87 r
.32745 .55086 m .32777 .55135 L .32906 .54971 L F
0 0 0 r
.32945 .54914 m .32947 .5491 L .33134 .54664 L F
.33116 .54706 m .32906 .54971 L .33134 .54664 L F
.32906 .54971 m .32945 .54914 L .33134 .54664 L F
.561 .622 .87 r
.3287 .54958 m .32906 .54971 L .33116 .54706 L F
.664 .161 .04 r
.32612 .54866 m .32623 .5487 L .32616 .54863 L F
.32437 .54997 m .32623 .5487 L .32612 .54866 L F
.561 .622 .87 r
.32591 .54408 m .32703 .54898 L .33116 .54706 L F
.32703 .54898 m .3287 .54958 L .33116 .54706 L F
.659 .166 .07 r
.32647 .54879 m .32814 .55062 L .32887 .55 L F
.32616 .54863 m .32623 .5487 L .32647 .54879 L F
.32623 .5487 m .32814 .55062 L .32647 .54879 L F
.32944 .54915 m .32887 .55 L .32981 .5492 L F
.797 .707 .766 r
.32996 .54907 m .32817 .55195 L .32868 .55015 L F
.32817 .55195 m .32785 .55246 L .32807 .5518 L F
.32996 .54907 m .32786 .55249 L .32785 .55246 L F
0 0 .28 r
.326 .54537 m .32619 .54531 L .32591 .54408 L F
.537 .922 .809 r
.49337 .40805 m .4949 .40661 L .49663 .40649 L F
0 0 0 r
.49663 .40649 m .49942 .40526 L .50007 .40495 L F
.58 .94 .807 r
.49663 .40649 m .49706 .40508 L .49942 .40526 L F
.49663 .40649 m .4949 .40661 L .49706 .40508 L F
.891 .808 .76 r
.39579 .48283 m .39741 .48467 L .39356 .48572 L F
.39356 .48572 m .39741 .48467 L .39579 .48283 L F
.197 .531 .923 r
.39832 .48383 m .39741 .48467 L .39579 .48283 L F
.39579 .48283 m .39741 .48467 L .39832 .48383 L F
.506 .395 .661 r
.54241 .41385 m .54514 .4092 L .54229 .40912 L F
0 0 0 r
.43169 .60269 m .43629 .59932 L .43535 .60072 L F
.301 0 0 r
.43629 .59932 m .43714 .60034 L .43535 .60072 L F
.43629 .59932 m .43832 .59952 L .43714 .60034 L F
.95 .721 .556 r
.3819 .53971 m .38066 .5367 L .38248 .53776 L F
.896 .658 .571 r
.67159 .33631 m .66926 .33784 L .66741 .33531 L F
.67159 .33631 m .6714 .33902 L .66926 .33784 L F
.714 .841 .943 r
.34501 .62643 m .34922 .62665 L .34738 .62531 L F
.852 .845 .837 r
.34738 .62531 m .34922 .62665 L .35187 .62325 L F
.879 .699 .655 r
.36314 .56684 m .36251 .57025 L .36477 .5703 L F
.82 .456 .366 r
.36251 .57025 m .36286 .57232 L .36477 .5703 L F
.896 .578 .439 r
.36286 .57232 m .3649 .5738 L .36477 .5703 L F
.865 .471 .291 r
.32689 .51333 m .32315 .51045 L .32704 .51138 L F
.953 .781 .631 r
.69215 .3426 m .69125 .33861 L .69122 .34127 L F
.936 .916 .536 r
.69092 .34354 m .69215 .3426 L .69122 .34127 L F
.69092 .34354 m .6909 .3462 L .69215 .3426 L F
.566 .806 .989 r
.6107 .36192 m .60797 .3627 L .60662 .36124 L F
.6107 .36192 m .60797 .3627 L .60662 .36124 L F
.729 .557 .658 r
.31723 .62285 m .31804 .62643 L .31527 .62719 L F
.647 .505 .675 r
.32007 .62303 m .31804 .62643 L .31723 .62285 L F
.542 .791 .99 r
.30209 .65004 m .29936 .6509 L .29779 .64946 L F
.902 .542 .35 r
.34133 .51566 m .34324 .51415 L .34072 .51352 L F
.34133 .51566 m .3444 .5173 L .34324 .51415 L F
.913 .884 .791 r
.57091 .44674 m .57179 .44569 L .57037 .44425 L F
.841 .78 .793 r
.57179 .44569 m .57218 .44073 L .57037 .44425 L F
.57179 .44569 m .57416 .44219 L .57218 .44073 L F
0 0 0 r
.52113 .40566 m .51955 .40705 L .5167 .4087 L F
.52196 .40613 m .52113 .40566 L .52378 .40466 L F
.52196 .40613 m .51955 .40705 L .52113 .40566 L F
.593 .762 .959 r
.28651 .59096 m .28236 .59005 L .2845 .59018 L F
.28651 .59096 m .28236 .59005 L .2845 .59018 L F
.869 .856 .827 r
.48778 .51285 m .48681 .5175 L .48522 .51636 L F
.48778 .51285 m .48942 .51425 L .48681 .5175 L F
.643 .304 .382 r
.61965 .38596 m .61948 .38912 L .61664 .3875 L F
.096 0 .28 r
.62205 .38436 m .61948 .38912 L .61965 .38596 L F
0 0 0 r
.32299 .54041 m .32503 .53974 L .32672 .53856 L F
.487 .2 .403 r
.32672 .53856 m .32869 .53991 L .32958 .53743 L F
.911 .792 .715 r
.57172 .43429 m .57549 .43211 L .57342 .43073 L F
.754 .683 .784 r
.36651 .59683 m .36782 .60049 L .37008 .59989 L F
.64 .942 .959 r
.43165 .44679 m .43079 .44863 L .42929 .44798 L F
.43165 .44679 m .43293 .44724 L .43079 .44863 L F
.783 .576 .62 r
.68756 .33512 m .69202 .33316 L .68763 .33253 L F
.68756 .33512 m .69196 .33612 L .69202 .33316 L F
.418 .357 .683 r
.2812 .52661 m .27804 .52418 L .28024 .52236 L F
.2812 .52661 m .28132 .52946 L .27804 .52418 L F
.047 0 .153 r
.24975 .53064 m .25052 .53195 L .25161 .53068 L F
.24975 .53064 m .24812 .53362 L .25052 .53195 L F
.662 .798 .947 r
.31987 .61946 m .31663 .61949 L .31931 .61908 L F
.818 .844 .869 r
.32158 .61597 m .31987 .61946 L .31931 .61908 L F
.195 .214 .653 r
.38338 .49415 m .38524 .49646 L .38547 .49551 L F
.38338 .49415 m .38451 .49729 L .38524 .49646 L F
0 0 .475 r
.34296 .65898 m .34245 .65992 L .34127 .65611 L F
.34376 .6611 m .34245 .65992 L .34296 .65898 L F
.34376 .6611 m .34327 .66254 L .34245 .65992 L F
.945 .939 .602 r
.4904 .50945 m .48942 .51425 L .48778 .51285 L F
0 0 .431 r
.57218 .35952 m .57312 .36189 L .57203 .35769 L F
.217 0 0 r
.61593 .34342 m .62139 .3435 L .61726 .34339 L F
.294 0 0 r
.61726 .34339 m .62139 .3435 L .62106 .34279 L F
.278 .21 .599 r
.59453 .35352 m .59267 .35849 L .59239 .35606 L F
.022 0 0 r
.65246 .32998 m .64915 .33224 L .65169 .33108 L F
.008 0 0 r
.65169 .33108 m .65501 .32895 L .65246 .32998 L F
.732 .991 .856 r
.61433 .39649 m .61542 .39669 L .61197 .39951 L F
.376 .42 .779 r
.61197 .39951 m .61529 .4009 L .61433 .39649 L F
.741 .684 .796 r
.60284 .35406 m .6066 .35611 L .60502 .35451 L F
.846 .852 .847 r
.60502 .35451 m .6066 .35611 L .6095 .35288 L F
.256 .594 .949 r
.33571 .59423 m .33741 .5942 L .33538 .59244 L F
.33571 .59423 m .33741 .5942 L .33538 .59244 L F
.25 0 .054 r
.33571 .59423 m .33659 .59458 L .33741 .5942 L F
.628 .317 .425 r
.34251 .56337 m .34212 .56028 L .34223 .56302 L F
.544 .265 .443 r
.38451 .46498 m .38223 .46813 L .37948 .46826 L F
.833 .782 .803 r
.57218 .44073 m .57416 .44219 L .57673 .43877 L F
.435 .27 .558 r
.5393 .37891 m .54179 .3809 L .54189 .37826 L F
.887 .801 .758 r
.39383 .5744 m .39245 .57702 L .39178 .57313 L F
.947 .608 .345 r
.35182 .53063 m .35215 .53323 L .35406 .53422 L F
.942 .69 .527 r
.3517 .53602 m .35406 .53422 L .35215 .53323 L F
.3517 .53602 m .35387 .53719 L .35406 .53422 L F
.523 .478 .747 r
.27114 .54273 m .26833 .54441 L .26815 .54063 L F
.403 .246 .552 r
.27114 .54273 m .26871 .54726 L .26833 .54441 L F
.324 0 .13 r
.32571 .67634 m .32652 .67853 L .32481 .67825 L F
.32571 .67634 m .32817 .67585 L .32652 .67853 L F
.822 .7 .73 r
.36585 .58287 m .36729 .58671 L .36955 .58362 L F
.829 .549 .515 r
.34024 .52636 m .33704 .52687 L .33702 .52408 L F
.783 .658 .724 r
.36379 .60274 m .36781 .60292 L .36782 .60049 L F
.986 .711 .366 r
.55916 .42901 m .55798 .42989 L .55839 .42699 L F
.55916 .42901 m .55956 .43183 L .55798 .42989 L F
.8 .938 .578 r
.56172 .42391 m .55916 .42901 L .55839 .42699 L F
.925 .853 .753 r
.6067 .44085 m .6063 .43754 L .6039 .44123 L F
.485 .13 .288 r
.58656 .37847 m .58987 .37825 L .5896 .37603 L F
.339 .148 .468 r
.5896 .37603 m .59268 .37483 L .59232 .37213 L F
.17 0 .286 r
.5896 .37603 m .59194 .37668 L .59268 .37483 L F
.5896 .37603 m .58987 .37825 L .59194 .37668 L F
.846 .963 .881 r
.6048 .39881 m .60598 .39975 L .60801 .3976 L F
.649 .952 .735 r
.50007 .40495 m .50125 .40324 L .50316 .40234 L F
.648 .946 .713 r
.50007 .40495 m .49942 .40526 L .50125 .40324 L F
.459 .044 .165 r
.3415 .58653 m .34131 .58819 L .34042 .58818 L F
0 0 0 r
.34284 .58448 m .3415 .58653 L .34073 .58721 L F
.459 .044 .165 r
.3415 .58653 m .33813 .58816 L .34073 .58721 L F
.3415 .58653 m .34042 .58818 L .33813 .58816 L F
0 0 0 r
.34325 .58395 m .3415 .58653 L .34284 .58448 L F
.65 .863 .98 r
.32746 .53057 m .3257 .52917 L .3269 .52819 L F
.32756 .52857 m .3269 .52819 L .3276 .52762 L F
.32746 .53057 m .3269 .52819 L .32756 .52857 L F
.453 0 0 r
.3276 .52762 m .3257 .52917 L .32762 .52844 L F
0 .402 .767 r
.32493 .52706 m .3265 .52747 L .32762 .52844 L F
.32281 .52598 m .32359 .52629 L .32493 .52706 L F
.32359 .52629 m .3265 .52747 L .32493 .52706 L F
.591 .598 .827 r
.32596 .52378 m .3276 .52762 L .32977 .52685 L F
.453 0 0 r
.3276 .52762 m .32762 .52844 L .32977 .52685 L F
.739 .726 .84 r
.33138 .62914 m .33251 .63239 L .33563 .62963 L F
.898 .509 .277 r
.365 .493 m .36731 .49419 L .36629 .49164 L F
.414 .657 .96 r
.39436 .48796 m .391 .48642 L .39393 .48631 L F
.391 .48642 m .39436 .48796 L .39393 .48631 L F
.731 .589 .698 r
.71528 .30575 m .71696 .31003 L .71944 .30646 L F
.732 .591 .698 r
.71696 .31003 m .71873 .30942 L .71944 .30646 L F
.688 .935 .966 r
.25966 .55884 m .25934 .5609 L .2615 .55996 L F
.754 .778 .873 r
.33994 .63024 m .34253 .63003 L .34067 .62618 L F
.772 .786 .864 r
.34067 .62618 m .34253 .63003 L .34501 .62643 L F
.709 .438 .512 r
.67661 .31858 m .68039 .31636 L .67629 .31587 L F
.67661 .31858 m .68059 .31886 L .68039 .31636 L F
0 0 .259 r
.27001 .60871 m .26972 .61026 L .26951 .6067 L F
.26951 .6067 m .26972 .61026 L .27001 .60871 L F
.199 .708 .896 r
.54378 .41538 m .54249 .41496 L .53969 .41499 L F
.401 .599 .927 r
.53757 .38099 m .54013 .38286 L .53657 .38237 L F
.582 .891 .61 r
.54678 .41254 m .54507 .41384 L .54378 .41538 L F
.562 .915 .962 r
.54507 .41384 m .54249 .41496 L .54378 .41538 L F
.255 .766 .798 r
.61768 .3807 m .62293 .37978 L .6188 .38091 L F
.788 .987 .894 r
.68325 .36983 m .6855 .36984 L .68725 .36802 L F
.349 0 0 r
.66005 .38271 m .66331 .38259 L .66251 .38349 L F
.595 .38 .559 r
.27732 .6133 m .28034 .61367 L .28092 .60995 L F
.28092 .60995 m .28034 .61367 L .27732 .6133 L F
.793 .723 .191 r
.28092 .60995 m .28034 .61367 L .28042 .61111 L F
.403 .21 .501 r
.28092 .60995 m .28285 .61265 L .2821 .60956 L F
.28092 .60995 m .28034 .61367 L .28285 .61265 L F
.793 .723 .191 r
.28092 .60995 m .28042 .61111 L .2821 .60956 L F
.958 .85 .692 r
.65529 .39114 m .65836 .38897 L .65683 .38943 L F
.65529 .39114 m .65724 .39268 L .65836 .38897 L F
.371 .813 .954 r
.65836 .38897 m .66111 .38848 L .66012 .38791 L F
.33 .083 .38 r
.51171 .44188 m .5145 .43852 L .51401 .44073 L F
0 0 0 r
.5104 .44337 m .51171 .44188 L .51401 .44073 L F
.742 .665 .774 r
.31592 .63298 m .31954 .63312 L .31802 .62943 L F
.691 .67 .825 r
.31954 .63312 m .3208 .62919 L .31802 .62943 L F
.31954 .63312 m .32228 .6332 L .3208 .62919 L F
.706 .528 .645 r
.31954 .63312 m .3236 .63413 L .32228 .6332 L F
0 .068 .626 r
.58206 .38944 m .58305 .38939 L .58125 .38753 L F
.58206 .38944 m .58301 .39048 L .58305 .38939 L F
0 .137 .665 r
.58125 .38753 m .58305 .38939 L .5821 .38558 L F
0 0 .504 r
.5827 .38799 m .58323 .38818 L .5821 .38558 L F
.58305 .38939 m .58323 .38818 L .5827 .38799 L F
.778 .801 .313 r
.58305 .38939 m .58233 .39085 L .58308 .38861 L F
.58305 .38939 m .58308 .38861 L .58323 .38818 L F
0 .068 .626 r
.58301 .39048 m .58365 .39118 L .58305 .38939 L F
.877 .453 .038 r
.58365 .39118 m .58345 .39305 L .58305 .38939 L F
.956 .687 .241 r
.58305 .38939 m .58345 .39305 L .58233 .39085 L F
0 0 .108 r
.58323 .38818 m .58233 .39085 L .58459 .38868 L F
.58323 .38818 m .58459 .38868 L .58466 .38861 L F
.891 .836 .785 r
.47813 .54338 m .47899 .54703 L .47944 .54444 L F
.47813 .54338 m .477 .54639 L .47899 .54703 L F
.84 .782 .795 r
.47383 .54892 m .47899 .54703 L .477 .54639 L F
.47383 .54892 m .4763 .55055 L .47899 .54703 L F
.59 .612 .843 r
.3208 .62919 m .32228 .6332 L .32491 .63225 L F
.631 .632 .833 r
.3236 .63413 m .32491 .63225 L .32228 .6332 L F
.886 .623 .535 r
.32343 .50779 m .32081 .50968 L .321 .50695 L F
.32343 .50779 m .32315 .51045 L .32081 .50968 L F
.732 .983 .771 r
.46647 .42742 m .46475 .42935 L .46274 .43018 L F
.733 .393 .404 r
.34554 .5859 m .3415 .58653 L .34325 .58395 L F
.721 .263 .162 r
.36528 .51106 m .36342 .51262 L .36127 .51025 L F
.913 .564 .362 r
.36528 .51106 m .3657 .5136 L .36342 .51262 L F
.496 .294 .535 r
.3099 .60356 m .30954 .60647 L .30705 .60691 L F
0 0 0 r
.30785 .60618 m .3099 .60356 L .30705 .60691 L F
.30785 .60618 m .30705 .60691 L .30514 .60603 L F
.304 .789 .903 r
.30705 .60691 m .30785 .60618 L .30514 .60603 L F
.30705 .60691 m .30954 .60647 L .30785 .60618 L F
.917 .921 .801 r
.55767 .43755 m .55394 .43986 L .55739 .43697 L F
.833 .782 .803 r
.57218 .44073 m .57673 .43877 L .5725 .43807 L F
.851 .658 .641 r
.36662 .58972 m .36926 .59049 L .36729 .58671 L F
.881 .685 .632 r
.36662 .58972 m .36871 .59332 L .36926 .59049 L F
.747 .735 .841 r
.33899 .55053 m .34022 .55427 L .33582 .55353 L F
.579 .033 0 r
.34022 .55427 m .33932 .55539 L .33582 .55353 L F
.547 .615 .872 r
.34269 .55335 m .34022 .55427 L .33899 .55053 L F
.567 .414 .634 r
.27625 .53329 m .27312 .53123 L .27631 .53108 L F
.27625 .53329 m .2735 .53388 L .27312 .53123 L F
.624 .345 .475 r
.32207 .54175 m .32503 .53974 L .32299 .54041 L F
.436 .27 .556 r
.30848 .61341 m .30859 .61682 L .31079 .61563 L F
.31079 .61563 m .30859 .61682 L .30848 .61341 L F
.792 .73 .794 r
.31116 .62971 m .3128 .63322 L .31538 .62988 L F
.657 .526 .693 r
.3128 .63322 m .31592 .63298 L .31538 .62988 L F
.416 0 .02 r
.53969 .41499 m .54249 .41496 L .54241 .41385 L F
.444 .138 .351 r
.54881 .40972 m .54821 .41039 L .54804 .41064 L F
.54877 .40978 m .54804 .41064 L .54678 .41254 L F
.54881 .40972 m .54804 .41064 L .54877 .40978 L F
.54821 .41039 m .54692 .41221 L .54678 .41254 L F
.652 .483 .642 r
.54798 .41072 m .54621 .41295 L .54879 .41115 L F
.54514 .4092 m .54617 .41284 L .54798 .41072 L F
.444 .138 .351 r
.54821 .41039 m .54726 .41143 L .54692 .41221 L F
.54726 .41143 m .54588 .41322 L .54678 .41254 L F
.652 .483 .642 r
.54617 .41284 m .54621 .41295 L .54798 .41072 L F
.506 .395 .661 r
.54241 .41385 m .54606 .41299 L .54514 .4092 L F
.54606 .41299 m .54617 .41284 L .54514 .4092 L F
.444 .138 .351 r
.54606 .41299 m .54507 .41384 L .54588 .41322 L F
.187 0 .034 r
.54241 .41385 m .54507 .41384 L .54606 .41299 L F
.444 .138 .351 r
.54726 .41143 m .54507 .41384 L .54606 .41299 L F
.187 0 .034 r
.54606 .41299 m .54507 .41384 L .54621 .41295 L F
.506 .395 .661 r
.54606 .41299 m .54621 .41295 L .54617 .41284 L F
.365 0 .165 r
.54507 .41384 m .54795 .41176 L .54621 .41295 L F
.54795 .41176 m .54879 .41115 L .54774 .41188 L F
.54795 .41176 m .54774 .41188 L .54621 .41295 L F
.654 .259 .283 r
.55052 .40865 m .54849 .40835 L .54999 .40644 L F
.55052 .40865 m .54881 .40972 L .54849 .40835 L F
.55052 .40865 m .55162 .41041 L .54886 .40974 L F
.55162 .41041 m .55176 .41063 L .55084 .41035 L F
.55162 .41041 m .55084 .41035 L .54886 .40974 L F
.54884 .4097 m .54886 .40974 L .54881 .40972 L F
0 0 .418 r
.54868 .41018 m .54999 .40644 L .54849 .40835 L F
.54879 .41115 m .54903 .4102 L .54879 .41019 L F
.54879 .41115 m .54879 .41019 L .5487 .41033 L F
.654 .259 .283 r
.55052 .40865 m .54886 .40974 L .54884 .4097 L F
0 0 .418 r
.54903 .4102 m .54974 .41125 L .54979 .41027 L F
0 0 .188 r
.54979 .41027 m .54961 .41002 L .55176 .41063 L F
.54911 .40988 m .54886 .40974 L .55084 .41035 L F
.54911 .40988 m .55084 .41035 L .55176 .41063 L F
0 0 .126 r
.54999 .40644 m .54979 .41027 L .55053 .40716 L F
.54979 .41027 m .54974 .41125 L .5499 .41042 L F
.54979 .41027 m .5499 .41042 L .55053 .40716 L F
0 0 .188 r
.55086 .41088 m .54979 .41027 L .55176 .41063 L F
.54979 .41027 m .54911 .40988 L .54961 .41002 L F
0 0 .418 r
.54903 .4102 m .54911 .40988 L .54868 .41018 L F
.54911 .40988 m .54999 .40644 L .54881 .4098 L F
0 0 .188 r
.54902 .40986 m .5487 .41032 L .54881 .40972 L F
0 0 .418 r
.54911 .40988 m .54881 .4098 L .54868 .41018 L F
.54911 .40988 m .54979 .41027 L .54999 .40644 L F
.54903 .4102 m .54979 .41027 L .54911 .40988 L F
0 0 .188 r
.55068 .41093 m .54886 .40974 L .55086 .41088 L F
.626 .251 .314 r
.5532 .40824 m .55176 .41063 L .55052 .40865 L F
0 0 .438 r
.55053 .40716 m .5499 .41042 L .55068 .41093 L F
.5499 .41042 m .54974 .41125 L .55068 .41093 L F
0 0 .188 r
.55068 .41093 m .54881 .40972 L .54886 .40974 L F
.55068 .41093 m .54886 .40974 L .54886 .40974 L F
0 0 .418 r
.54879 .41115 m .5494 .41122 L .54903 .4102 L F
.5494 .41122 m .54974 .41125 L .54903 .4102 L F
0 0 .188 r
.55004 .41052 m .54851 .41143 L .5487 .41032 L F
.55004 .41052 m .5487 .41032 L .54902 .40986 L F
0 0 .418 r
.5487 .41033 m .54879 .41019 L .54868 .41018 L F
0 0 0 r
.54879 .41115 m .55068 .41093 L .54974 .41125 L F
.54879 .41115 m .54819 .41322 L .55068 .41093 L F
0 0 .188 r
.55068 .41093 m .54819 .41322 L .54851 .41143 L F
.55068 .41093 m .54851 .41143 L .55004 .41052 L F
.365 0 .165 r
.54507 .41384 m .54819 .41322 L .54879 .41115 L F
.444 .138 .351 r
.54821 .41039 m .54819 .41322 L .54507 .41384 L F
.54881 .40972 m .5487 .41032 L .54821 .41039 L F
.652 .483 .642 r
.54798 .41072 m .54879 .41115 L .54864 .40977 L F
.444 .138 .351 r
.5487 .41032 m .54819 .41322 L .54821 .41039 L F
.652 .483 .642 r
.54514 .4092 m .54752 .41047 L .54849 .40835 L F
.54752 .41047 m .54798 .41072 L .54804 .41041 L F
.54752 .41047 m .54804 .41041 L .54849 .40835 L F
.54798 .41072 m .54864 .40977 L .54849 .40835 L F
.187 0 .034 r
.54241 .41385 m .54249 .41496 L .54507 .41384 L F
.639 .083 0 r
.57979 .35939 m .58154 .36112 L .58287 .3608 L F
0 0 .432 r
.58154 .36112 m .58156 .36557 L .58287 .3608 L F
.131 .08 .527 r
.58377 .35893 m .58262 .36218 L .58154 .36112 L F
.58262 .36218 m .58217 .36345 L .58154 .36112 L F
.639 .083 0 r
.57956 .35929 m .58154 .36112 L .57979 .35939 L F
.987 .791 .555 r
.30746 .62336 m .30692 .6262 L .30533 .62512 L F
.841 .999 .815 r
.30787 .62107 m .30746 .62336 L .30624 .62244 L F
.30787 .62107 m .3101 .62055 L .30746 .62336 L F
.991 .879 .612 r
.30624 .62244 m .30746 .62336 L .30533 .62512 L F
.606 .658 .874 r
.51626 .43664 m .5145 .43852 L .51263 .4352 L F
.038 0 .256 r
.51401 .44073 m .5145 .43852 L .51626 .43664 L F
.153 .694 .811 r
.42931 .45764 m .43181 .45741 L .4278 .45755 L F
0 0 0 r
.62139 .3435 m .62391 .34241 L .62106 .34279 L F
.588 .577 .808 r
.59145 .34088 m .59477 .3435 L .59456 .34099 L F
.813 .895 .901 r
.59655 .34544 m .59441 .34471 L .5959 .34322 L F
.59756 .34282 m .5959 .34322 L .59834 .3408 L F
.59655 .34544 m .5959 .34322 L .59756 .34282 L F
.184 0 .259 r
.59441 .34471 m .59556 .34412 L .59834 .3408 L F
.588 .577 .808 r
.59477 .3435 m .59556 .34412 L .59532 .34336 L F
.59477 .3435 m .59532 .34336 L .59456 .34099 L F
.631 .953 .771 r
.36957 .47072 m .37075 .4691 L .37162 .46803 L F
0 0 0 r
.37162 .46803 m .37075 .4691 L .37408 .46672 L F
.34 .815 .766 r
.31244 .61962 m .3101 .62055 L .30787 .62107 L F
.931 .594 .374 r
.3384 .50994 m .34072 .51352 L .34045 .51115 L F
.797 .377 .25 r
.31484 .60572 m .31668 .6038 L .3127 .60252 L F
.479 .119 .276 r
.31913 .67982 m .32145 .68173 L .3188 .68221 L F
.31913 .67982 m .32241 .67895 L .32145 .68173 L F
.956 .653 .418 r
.59441 .38725 m .59647 .39011 L .59634 .38958 L F
.368 0 0 r
.59894 .39076 m .59634 .38958 L .59647 .39011 L F
.861 .856 .835 r
.62057 .39435 m .62241 .39621 L .61893 .40002 L F
.706 .831 .942 r
.62448 .39454 m .62241 .39621 L .62057 .39435 L F
.772 .651 .094 r
.57662 .39702 m .57669 .39794 L .57683 .39545 L F
.816 .845 .383 r
.57683 .39545 m .57809 .3909 L .57802 .39314 L F
0 0 0 r
.57802 .39314 m .57662 .39702 L .57683 .39545 L F
.367 0 0 r
.30005 .68613 m .30398 .68556 L .30292 .6862 L F
.229 0 0 r
.30398 .68556 m .30647 .68536 L .30292 .6862 L F
.979 .788 .576 r
.67077 .34165 m .6719 .34607 L .66934 .34446 L F
.996 .829 .56 r
.6719 .34607 m .66995 .34759 L .66934 .34446 L F
.6719 .34607 m .6717 .34847 L .66995 .34759 L F
.719 .494 .584 r
.65508 .36016 m .65724 .35875 L .65607 .35803 L F
.665 .808 .952 r
.32596 .52378 m .33025 .52427 L .32888 .52264 L F
.591 .598 .827 r
.32596 .52378 m .32977 .52685 L .33025 .52427 L F
.379 .665 .97 r
.32888 .52264 m .33025 .52427 L .331 .52246 L F
0 0 .197 r
.32977 .52685 m .331 .52246 L .33025 .52427 L F
.533 .906 .956 r
.33457 .54408 m .33567 .5427 L .33728 .54308 L F
.431 .138 .365 r
.33728 .54308 m .33675 .54563 L .33457 .54408 L F
.034 .207 .712 r
.33457 .54408 m .33675 .54563 L .33567 .5427 L F
.819 .711 .746 r
.34513 .54708 m .34046 .54985 L .34167 .54711 L F
.34513 .54708 m .34282 .55051 L .34046 .54985 L F
.584 .057 0 r
.37194 .49626 m .37406 .49686 L .37589 .49649 L F
.563 .029 0 r
.37406 .49686 m .37827 .49736 L .37589 .49649 L F
0 .309 .727 r
.5754 .37263 m .57687 .37303 L .57506 .37077 L F
.5754 .37263 m .57855 .37422 L .57687 .37303 L F
.818 .883 .892 r
.45777 .54655 m .45637 .55067 L .45495 .54887 L F
.45777 .54655 m .45939 .5477 L .45637 .55067 L F
.969 .713 .492 r
.28171 .67186 m .28358 .67286 L .28148 .67486 L F
.666 .22 .183 r
.28358 .67286 m .28602 .67499 L .28148 .67486 L F
.827 .924 .898 r
.29003 .67362 m .28602 .67499 L .28358 .67286 L F
.418 .295 .605 r
.42193 .57504 m .42007 .5766 L .42155 .5714 L F
.42193 .57504 m .42155 .5714 L .42118 .57212 L F
0 0 0 r
.4229 .5703 m .42118 .57212 L .42155 .5714 L F
.694 .233 .153 r
.4229 .5703 m .4254 .57274 L .42118 .57212 L F
.116 0 0 r
.65362 .33846 m .64988 .34084 L .6511 .33963 L F
.671 .578 .742 r
.34378 .64958 m .34416 .65259 L .34133 .65309 L F
.585 .288 .432 r
.34133 .65309 m .34335 .65504 L .34127 .65611 L F
.34133 .65309 m .34416 .65259 L .34335 .65504 L F
.702 .794 .922 r
.47237 .54969 m .4763 .55055 L .47383 .54892 L F
.812 .679 .718 r
.47237 .54969 m .47396 .55379 L .4763 .55055 L F
.509 .075 .152 r
.55574 .40849 m .55176 .41063 L .5532 .40824 L F
.926 .851 .749 r
.45033 .49967 m .45215 .49758 L .45 .49654 L F
.812 .787 .83 r
.46693 .55648 m .47145 .55505 L .46995 .55345 L F
.713 .81 .925 r
.47145 .55505 m .47396 .55379 L .46995 .55345 L F
.531 .882 .985 r
.53969 .41499 m .537 .41592 L .53607 .41518 L F
.836 .654 .656 r
.71698 .31238 m .71873 .30942 L .71696 .31003 L F
.826 .409 .25 r
.35417 .49347 m .35677 .49649 L .35863 .4953 L F
.869 .984 .7 r
.35863 .4953 m .35731 .49332 L .36075 .49395 L F
.35863 .4953 m .35677 .49649 L .35741 .4948 L F
.052 .563 .878 r
.35715 .49628 m .35718 .49626 L .35741 .4948 L F
.869 .984 .7 r
.35863 .4953 m .35741 .4948 L .35759 .49373 L F
.052 .563 .878 r
.35718 .49626 m .36001 .49387 L .35741 .4948 L F
.869 .984 .7 r
.35759 .49373 m .35741 .4948 L .35731 .49332 L F
.501 .799 .999 r
.54628 .39567 m .54735 .39366 L .54512 .39504 L F
.54628 .39567 m .54892 .39516 L .54735 .39366 L F
.154 .254 .715 r
.28307 .65639 m .28535 .6582 L .28424 .65493 L F
.798 .705 .763 r
.36651 .59683 m .36389 .60013 L .36782 .60049 L F
.783 .658 .724 r
.36379 .60274 m .36782 .60049 L .36389 .60013 L F
.537 .904 .714 r
.50316 .40234 m .50465 .40089 L .50495 .40078 L F
.50316 .40234 m .50125 .40324 L .50465 .40089 L F
.826 .812 .836 r
.61304 .38345 m .60941 .38675 L .60836 .38462 L F
.61304 .38345 m .60836 .38462 L .61112 .38403 L F
.72 .988 .834 r
.61499 .38162 m .61304 .38345 L .61112 .38403 L F
.816 .948 .908 r
.49779 .50451 m .49456 .50716 L .4933 .50626 L F
.326 .788 .664 r
.44118 .44322 m .44301 .44242 L .4395 .44408 L F
0 0 0 r
.43889 .44453 m .44118 .44322 L .4395 .44408 L F
.4351 .44587 m .43889 .44453 L .4395 .44408 L F
.837 .999 .789 r
.44799 .58808 m .4487 .58561 L .44918 .58671 L F
.862 .95 .87 r
.25917 .52839 m .25613 .53115 L .25629 .52823 L F
.813 .963 .906 r
.25917 .52839 m .25916 .52574 L .26111 .52712 L F
.25917 .52839 m .25629 .52823 L .25916 .52574 L F
.002 .336 .818 r
.34212 .56028 m .34236 .55879 L .33955 .55703 L F
0 .067 .63 r
.34212 .56028 m .34414 .56264 L .34236 .55879 L F
.559 .897 .656 r
.47559 .42094 m .47701 .41939 L .47912 .41878 L F
.47559 .42094 m .47515 .42104 L .47701 .41939 L F
.901 .886 .809 r
.32598 .59967 m .32138 .60222 L .32428 .59894 L F
.32598 .59967 m .32313 .60321 L .32138 .60222 L F
.686 .514 .647 r
.32598 .59967 m .32657 .60347 L .32313 .60321 L F
.866 .96 .863 r
.32847 .59655 m .32598 .59967 L .32428 .59894 L F
.56 .432 .663 r
.32847 .59655 m .32869 .59943 L .32598 .59967 L F
.542 .405 .644 r
.32869 .59943 m .32657 .60347 L .32598 .59967 L F
0 .002 .507 r
.60983 .3963 m .60784 .39566 L .61102 .39463 L F
.60983 .3963 m .60801 .3976 L .60792 .39664 L F
.6084 .39584 m .60792 .39664 L .60784 .39566 L F
.60983 .3963 m .60792 .39664 L .6084 .39584 L F
.532 .716 .957 r
.60844 .39231 m .60977 .39359 L .60724 .39604 L F
0 0 0 r
.61072 .39499 m .60784 .39566 L .60724 .39604 L F
.61111 .39487 m .61074 .39496 L .61072 .39499 L F
.61074 .39496 m .60784 .39566 L .61072 .39499 L F
.61074 .39496 m .61102 .39463 L .60784 .39566 L F
.61111 .39487 m .61102 .39463 L .61074 .39496 L F
.643 .833 .423 r
.61092 .39474 m .61102 .39463 L .61109 .3945 L F
.61126 .39405 m .61109 .3945 L .61195 .39296 L F
.532 .716 .957 r
.6109 .39467 m .61072 .39499 L .60852 .39565 L F
.643 .833 .423 r
.61042 .39537 m .61072 .39499 L .61126 .39405 L F
.61072 .39499 m .61109 .3945 L .61126 .39405 L F
.532 .716 .957 r
.60977 .39359 m .6109 .39467 L .60852 .39565 L F
.643 .833 .423 r
.61038 .39552 m .61102 .39463 L .61092 .39474 L F
.532 .716 .957 r
.6109 .39467 m .61111 .39487 L .61072 .39499 L F
0 0 0 r
.61195 .39296 m .61102 .39463 L .61111 .39487 L F
.762 .782 .87 r
.61195 .39296 m .61111 .39487 L .6109 .39467 L F
.61195 .39296 m .6109 .39467 L .60844 .39231 L F
.643 .833 .423 r
.60983 .3963 m .61033 .3956 L .61038 .39552 L F
.61033 .3956 m .61102 .39463 L .61038 .39552 L F
.60983 .3963 m .61109 .3945 L .61042 .39537 L F
.532 .716 .957 r
.60977 .39359 m .60852 .39565 L .60724 .39604 L F
.888 .801 .758 r
.39178 .57313 m .39245 .57702 L .38978 .57601 L F
.932 .667 .513 r
.39245 .57702 m .3903 .57858 L .38978 .57601 L F
.39245 .57702 m .39236 .57965 L .3903 .57858 L F
.959 .756 .586 r
.23881 .60709 m .23782 .60996 L .23588 .6082 L F
.965 .878 .488 r
.23809 .60619 m .23782 .60996 L .23881 .60709 L F
.23809 .60619 m .23782 .60996 L .23881 .60709 L F
.896 .669 .586 r
.28999 .6753 m .28992 .67877 L .29124 .67565 L F
.639 .257 .304 r
.29314 .67858 m .29124 .67565 L .28992 .67877 L F
.29314 .67858 m .29439 .67598 L .29124 .67565 L F
.514 .344 .589 r
.34327 .66254 m .3432 .66598 L .34053 .66626 L F
.429 .084 .276 r
.34053 .66626 m .34233 .66798 L .34023 .66898 L F
.34053 .66626 m .3432 .66598 L .34233 .66798 L F
.699 .965 .939 r
.62735 .3806 m .62636 .38312 L .62862 .38156 L F
.62735 .3806 m .62312 .38286 L .62636 .38312 L F
0 0 0 r
.6664 .39791 m .66697 .39559 L .66763 .39321 L F
.777 .741 .82 r
.33197 .64661 m .33504 .64898 L .329 .64906 L F
.846 .852 .847 r
.60502 .35451 m .6095 .35288 L .60797 .35149 L F
.735 .878 .947 r
.61083 .34967 m .6095 .35288 L .61212 .35063 L F
.61083 .34967 m .60797 .35149 L .6095 .35288 L F
.528 .588 .858 r
.61893 .40002 m .61542 .39669 L .61791 .39532 L F
.861 .856 .835 r
.62057 .39435 m .61893 .40002 L .61791 .39532 L F
.167 .697 .688 r
.61529 .4009 m .61893 .40002 L .61885 .39845 L F
.097 .434 .875 r
.61893 .40002 m .62081 .39934 L .61885 .39845 L F
.61893 .40002 m .62173 .40114 L .62081 .39934 L F
.753 .572 .651 r
.47054 .57004 m .4722 .5738 L .47407 .56994 L F
0 0 .353 r
.58152 .38207 m .58154 .38005 L .58052 .37806 L F
0 0 .468 r
.58152 .38207 m .58238 .38275 L .58154 .38005 L F
.869 .781 .762 r
.35871 .60976 m .36244 .60993 L .36105 .60613 L F
.871 .773 .751 r
.35999 .61347 m .36244 .60993 L .35871 .60976 L F
0 .242 .757 r
.5754 .367 m .57302 .36429 L .57368 .36626 L F
.791 .602 .645 r
.55828 .39135 m .55963 .3963 L .5631 .3917 L F
.556 .289 .465 r
.55963 .3963 m .56371 .39488 L .5631 .3917 L F
0 0 .422 r
.5631 .3917 m .56426 .39372 L .56506 .39113 L F
.5631 .3917 m .56371 .39488 L .56426 .39372 L F
.738 .947 .948 r
.55291 .47189 m .55173 .47098 L .54835 .47336 L F
.867 .973 .856 r
.55589 .46852 m .55321 .46918 L .55291 .47189 L F
.85 .963 .877 r
.55321 .46918 m .55173 .47098 L .55291 .47189 L F
.569 .865 .996 r
.3127 .60252 m .3099 .60356 L .31047 .60173 L F
.766 .909 .523 r
.31047 .60173 m .3099 .60356 L .30785 .60618 L F
0 0 0 r
.52885 .44185 m .52648 .4456 L .5293 .44486 L F
.52885 .44185 m .53174 .43843 L .53232 .44168 L F
.662 .489 .641 r
.52885 .44185 m .53232 .44168 L .5293 .44486 L F
0 0 .46 r
.52885 .44185 m .53046 .44298 L .52934 .44081 L F
.52885 .44185 m .5293 .44486 L .53046 .44298 L F
.913 .884 .791 r
.57091 .44674 m .57037 .44425 L .56726 .44755 L F
.82 .715 .75 r
.56726 .44755 m .56841 .45137 L .57091 .44674 L F
.701 .918 .968 r
.32458 .5511 m .3219 .55286 L .32164 .55158 L F
.973 .906 .687 r
.42581 .54831 m .42558 .55058 L .42668 .54648 L F
.916 .608 .446 r
.42291 .55211 m .42558 .55058 L .42581 .54831 L F
.42291 .55211 m .42581 .55371 L .42558 .55058 L F
.886 .684 .625 r
.39381 .56691 m .39006 .56629 L .39231 .56351 L F
.906 .763 .692 r
.39381 .56691 m .39011 .56918 L .39006 .56629 L F
.39381 .56691 m .39256 .57064 L .39011 .56918 L F
.509 .075 .152 r
.55574 .40849 m .5544 .41089 L .55176 .41063 L F
.836 .453 .326 r
.55574 .40849 m .55745 .41161 L .5544 .41089 L F
.537 .84 .999 r
.56567 .40752 m .56276 .40838 L .56387 .40637 L F
.56567 .40752 m .56276 .40838 L .56387 .40637 L F
.561 .653 .898 r
.60941 .38675 m .61112 .38403 L .60836 .38462 L F
.60941 .38675 m .61415 .38714 L .61112 .38403 L F
.631 .632 .833 r
.3236 .63413 m .32636 .63346 L .32491 .63225 L F
.832 .909 .89 r
.49367 .52297 m .49519 .52415 L .49816 .52132 L F
.942 .951 .634 r
.45422 .53586 m .45614 .53412 L .45359 .53852 L F
.615 .358 .505 r
.45614 .53412 m .45637 .53715 L .45359 .53852 L F
.919 .599 .421 r
.45422 .53586 m .45637 .53715 L .45614 .53412 L F
.855 .75 .746 r
.58478 .35208 m .58049 .35418 L .58394 .35181 L F
.58478 .35208 m .58251 .35561 L .58049 .35418 L F
.546 .926 .913 r
.58478 .35208 m .58629 .35051 L .58751 .3508 L F
.549 .929 .9 r
.58478 .35208 m .58394 .35181 L .58629 .35051 L F
.363 .623 .952 r
.28841 .68214 m .28884 .68305 L .29019 .68156 L F
.692 .149 0 r
.28884 .68305 m .2891 .68485 L .29019 .68156 L F
.13 .375 .832 r
.56779 .37079 m .5691 .37085 L .5684 .37272 L F
0 .161 .686 r
.5691 .37085 m .56965 .37485 L .5684 .37272 L F
.746 .65 .093 r
.67644 .31239 m .67656 .31224 L .67544 .31105 L F
.67644 .31239 m .67629 .31587 L .67656 .31224 L F
.3 .122 .464 r
.24449 .54033 m .24642 .53969 L .24664 .53709 L F
.409 .31 .63 r
.24449 .54033 m .24688 .54245 L .24642 .53969 L F
.24449 .54033 m .24444 .54441 L .24688 .54245 L F
.854 .854 .84 r
.51792 .39075 m .51417 .3916 L .5168 .38886 L F
.54 .6 .863 r
.51888 .387 m .51792 .39075 L .5168 .38886 L F
.51888 .387 m .52077 .39008 L .51792 .39075 L F
.298 0 0 r
.60638 .34372 m .60914 .34406 L .61051 .34365 L F
.523 .125 .228 r
.60914 .34406 m .61357 .34389 L .61051 .34365 L F
.543 .765 .979 r
.3171 .61787 m .31663 .61949 L .31488 .61889 L F
.3171 .61787 m .31931 .61908 L .31663 .61949 L F
.852 .845 .837 r
.34738 .62531 m .35187 .62325 L .35014 .62217 L F
.744 .766 .871 r
.35187 .62325 m .3528 .61894 L .35014 .62217 L F
.35187 .62325 m .35483 .62167 L .3528 .61894 L F
.952 .94 .616 r
.53157 .43578 m .53319 .43592 L .53343 .43368 L F
.019 0 .487 r
.31669 .55365 m .31802 .55585 L .31757 .55276 L F
0 0 .455 r
.31788 .55653 m .31802 .55585 L .31669 .55365 L F
.749 .966 .933 r
.53759 .48388 m .53983 .48078 L .53656 .48321 L F
.53759 .48388 m .54099 .48166 L .53983 .48078 L F
.97 .714 .49 r
.54189 .37826 m .54179 .3809 L .54351 .38149 L F
.192 .691 .913 r
.54179 .3809 m .54599 .38151 L .54351 .38149 L F
.54179 .3809 m .54599 .38151 L .54351 .38149 L F
.771 .674 .756 r
.71436 .31595 m .71844 .31646 L .71698 .31238 L F
0 0 0 r
.58726 .43319 m .5883 .43174 L .59009 .42962 L F
.201 .658 .944 r
.55148 .35524 m .54965 .3541 L .54745 .35405 L F
.54745 .35405 m .54965 .3541 L .55148 .35524 L F
.383 .769 .989 r
.55148 .35524 m .55374 .35483 L .54965 .3541 L F
.55148 .35524 m .55374 .35483 L .54965 .3541 L F
.201 .658 .944 r
.55148 .35524 m .54965 .3541 L .54745 .35405 L F
.85 .972 .872 r
.52387 .49552 m .52146 .49551 L .52094 .49834 L F
.831 .959 .894 r
.52094 .49834 m .52146 .49551 L .51725 .49924 L F
.584 .765 .965 r
.70844 .30341 m .7118 .30288 L .71015 .30106 L F
.569 .566 .81 r
.5821 .35827 m .57956 .35929 L .57811 .35505 L F
.412 .185 .457 r
.5821 .35827 m .58154 .36112 L .57956 .35929 L F
.003 0 0 r
.5422 .39234 m .54333 .39274 L .54457 .39063 L F
.5422 .39234 m .54076 .39353 L .54333 .39274 L F
.135 .665 .869 r
.30005 .68613 m .3004 .68558 L .2981 .68511 L F
.30005 .68613 m .30292 .6862 L .3004 .68558 L F
.862 .891 .855 r
.65508 .36016 m .6547 .36098 L .65724 .35875 L F
.969 .924 .601 r
.46963 .53392 m .46875 .53719 L .46786 .53528 L F
.81 .839 .873 r
.46681 .53978 m .46786 .53528 L .46875 .53719 L F
.903 .643 .535 r
.35306 .54263 m .35555 .5408 L .35312 .53995 L F
.35306 .54263 m .35521 .54348 L .35555 .5408 L F
.767 .91 .937 r
.29278 .65654 m .29457 .65744 L .29702 .65606 L F
.465 .626 .922 r
.29457 .65744 m .29852 .65945 L .29702 .65606 L F
.166 .012 .413 r
.4318 .60223 m .42949 .60325 L .43169 .60269 L F
.125 0 .319 r
.42932 .60581 m .42949 .60325 L .4318 .60223 L F
.961 .915 .72 r
.66995 .34759 m .6717 .34847 L .66967 .35112 L F
.581 .345 .524 r
.52485 .4505 m .5293 .44486 L .52648 .4456 L F
.286 .705 .971 r
.62629 .40221 m .62173 .40114 L .62326 .40344 L F
.175 .672 .915 r
.29112 .6853 m .29311 .68602 L .29571 .68606 L F
.936 .915 .535 r
.68986 .34878 m .6909 .3462 L .69092 .34354 L F
.928 .59 .141 r
.40721 .51679 m .408 .52004 L .40898 .52081 L F
.901 .747 .681 r
.408 .52004 m .40865 .52266 L .40898 .52081 L F
.562 .283 .451 r
.39354 .50116 m .3958 .50259 L .3963 .50091 L F
.39354 .50116 m .39338 .50357 L .3958 .50259 L F
.635 .702 .894 r
.29852 .65945 m .29831 .65641 L .29702 .65606 L F
.29852 .65945 m .30092 .65972 L .29831 .65641 L F
.529 .008 0 r
.29891 .66118 m .29852 .65945 L .2964 .66153 L F
.29891 .66118 m .30092 .65972 L .29852 .65945 L F
.905 .861 .787 r
.55682 .46368 m .56076 .46161 L .55963 .46068 L F
.55682 .46368 m .55842 .46512 L .56076 .46161 L F
.832 .964 .892 r
.55963 .46068 m .56076 .46161 L .56404 .45847 L F
.807 .882 .9 r
.59894 .39076 m .60134 .39175 L .60215 .38989 L F
.60215 .38989 m .60134 .39175 L .59894 .39076 L F
.792 .73 .794 r
.31116 .62971 m .31538 .62988 L .31369 .62804 L F
.742 .665 .774 r
.31592 .63298 m .31802 .62943 L .31538 .62988 L F
0 0 .432 r
.58154 .36112 m .58217 .36345 L .58156 .36557 L F
.865 .77 .266 r
.58217 .36345 m .58196 .36799 L .58156 .36557 L F
.578 .249 .375 r
.27957 .61546 m .28034 .61367 L .27732 .6133 L F
.27732 .6133 m .28034 .61367 L .27957 .61546 L F
.27957 .61546 m .28034 .61367 L .27732 .6133 L F
.313 0 .055 r
.64557 .33483 m .64838 .33424 L .64915 .33224 L F
.368 .008 .214 r
.64838 .33424 m .65169 .33108 L .64915 .33224 L F
.92 .695 .581 r
.39445 .58364 m .39222 .58286 L .39236 .57965 L F
.836 .546 .499 r
.39484 .58541 m .39222 .58286 L .39445 .58364 L F
.73 .341 .313 r
.39445 .58364 m .39675 .58655 L .39484 .58541 L F
.729 .216 0 r
.39819 .58742 m .39675 .58655 L .39695 .58616 L F
.083 .355 .825 r
.39819 .58742 m .39915 .58642 L .39675 .58655 L F
.2 .722 .708 r
.39915 .58642 m .39648 .58708 L .39675 .58655 L F
.39648 .58708 m .39526 .58738 L .39675 .58655 L F
.729 .216 0 r
.39695 .58616 m .39675 .58655 L .39445 .58364 L F
.927 .901 .781 r
.65419 .39344 m .65724 .39268 L .65529 .39114 L F
.659 .704 .88 r
.30883 .65171 m .31288 .65265 L .31049 .65381 L F
.779 .98 .908 r
.5553 .45801 m .55207 .45949 L .55437 .45689 L F
.927 .574 .139 r
.58052 .37806 m .57855 .37422 L .57907 .37592 L F
.631 .953 .771 r
.36957 .47072 m .36951 .47028 L .37075 .4691 L F
.902 .611 .484 r
.45197 .57281 m .45379 .5704 L .45269 .56872 L F
.45197 .57281 m .45408 .57265 L .45379 .5704 L F
.615 .71 .913 r
.45379 .5704 m .45459 .56814 L .45269 .56872 L F
.45379 .5704 m .45656 .56992 L .45459 .56814 L F
.577 .378 .574 r
.45408 .57265 m .45656 .56992 L .45379 .5704 L F
.355 .659 .97 r
.3064 .65224 m .30209 .65004 L .30436 .64917 L F
.551 .68 .924 r
.30708 .64871 m .3064 .65224 L .30436 .64917 L F
.30708 .64871 m .30883 .65171 L .3064 .65224 L F
.561 .823 .995 r
.54562 .35347 m .54432 .35566 L .54745 .35405 L F
.54562 .35347 m .54287 .35431 L .54432 .35566 L F
.54562 .35347 m .54432 .35566 L .54745 .35405 L F
.54562 .35347 m .54287 .35431 L .54432 .35566 L F
.546 .816 .996 r
.54432 .35566 m .54287 .35431 L .54013 .35496 L F
.933 .902 .771 r
.50058 .42471 m .5025 .42213 L .50077 .42085 L F
.839 .43 .264 r
.50323 .42438 m .5025 .42213 L .50058 .42471 L F
.859 .922 .87 r
.50077 .42085 m .5025 .42213 L .50589 .41796 L F
.546 .79 .989 r
.52737 .41031 m .53189 .4113 L .52928 .41215 L F
.315 .002 .264 r
.52928 .41215 m .53189 .4113 L .5287 .41412 L F
.862 .614 .562 r
.38433 .54028 m .38264 .54256 L .3819 .53971 L F
.38433 .54028 m .38609 .54392 L .38264 .54256 L F
.783 .98 .907 r
.52472 .49299 m .52387 .49552 L .52571 .49376 L F
.52472 .49299 m .52146 .49551 L .52387 .49552 L F
.975 .747 .532 r
.52251 .45021 m .52467 .45314 L .52396 .45416 L F
.705 .761 .895 r
.52706 .45098 m .52467 .45314 L .52251 .45021 L F
.788 .513 .521 r
.59668 .42442 m .59661 .42179 L .59254 .42119 L F
.916 .966 .793 r
.66605 .36223 m .66318 .36442 L .6647 .36069 L F
.66605 .36223 m .66369 .36558 L .66318 .36442 L F
.873 .877 .836 r
.66708 .35749 m .66605 .36223 L .6647 .36069 L F
.66708 .35749 m .66868 .35892 L .66605 .36223 L F
.166 .684 .886 r
.65653 .37091 m .66083 .37139 L .65762 .37131 L F
.953 .768 .615 r
.56652 .45026 m .56841 .45137 L .56726 .44755 L F
.913 .83 .75 r
.56641 .45503 m .56841 .45137 L .56652 .45026 L F
.853 .585 .532 r
.29696 .67721 m .30081 .67505 L .29922 .67468 L F
.29696 .67721 m .30076 .678 L .30081 .67505 L F
.784 .871 .912 r
.30081 .67505 m .30197 .67159 L .29922 .67468 L F
.30081 .67505 m .30393 .67278 L .30197 .67159 L F
.255 .766 .798 r
.61768 .3807 m .62042 .38003 L .62293 .37978 L F
.341 0 0 r
.62042 .38003 m .62447 .37828 L .62293 .37978 L F
0 .313 .792 r
.31788 .55653 m .31996 .55818 L .31802 .55585 L F
.77 .91 .936 r
.58948 .40897 m .59231 .40842 L .59125 .41026 L F
0 0 .221 r
.59316 .40455 m .59385 .40697 L .59231 .40842 L F
.375 .104 .369 r
.59125 .41026 m .59541 .40951 L .59235 .41253 L F
0 0 .346 r
.59235 .41253 m .59154 .41039 L .59144 .41058 L F
.483 .56 .858 r
.59385 .40697 m .59541 .40951 L .59514 .40956 L F
.59385 .40697 m .59514 .40956 L .59125 .41026 L F
.906 .515 .093 r
.59308 .40543 m .59385 .40697 L .59308 .40543 L F
.483 .56 .858 r
.59385 .40697 m .59126 .41026 L .59231 .40842 L F
.906 .515 .093 r
.5938 .40805 m .59385 .40697 L .59308 .40543 L F
0 0 .346 r
.59154 .41039 m .59096 .40888 L .59136 .41031 L F
.59154 .41039 m .59136 .41031 L .59144 .41058 L F
.483 .56 .858 r
.59126 .41026 m .59125 .41026 L .59126 .41026 L F
.59126 .41026 m .59126 .41026 L .59231 .40842 L F
.427 .623 .934 r
.30462 .55018 m .30748 .55053 L .30637 .54896 L F
.941 .926 .764 r
.66789 .38811 m .66738 .39065 L .66579 .39191 L F
.561 .17 .258 r
.66579 .39191 m .66738 .39065 L .66763 .39321 L F
0 0 .394 r
.66851 .39068 m .66738 .39065 L .66789 .38811 L F
0 0 .223 r
.66763 .39321 m .66738 .39065 L .66851 .39068 L F
.821 .436 0 r
.66041 .40104 m .66037 .40168 L .65911 .39836 L F
.229 .748 .77 r
.66041 .40104 m .66313 .40038 L .66283 .40033 L F
0 0 0 r
.66283 .40033 m .66037 .40168 L .66041 .40104 L F
.691 .942 .962 r
.67269 .37817 m .67424 .37577 L .67219 .37766 L F
.67269 .37817 m .67621 .37637 L .67424 .37577 L F
.404 .029 .21 r
.37908 .46973 m .37948 .46826 L .38175 .46939 L F
.428 0 .087 r
.37948 .46826 m .38223 .46813 L .38175 .46939 L F
.158 0 0 r
.31527 .62719 m .31804 .62643 L .31571 .62745 L F
.852 .983 .86 r
.31571 .62745 m .31804 .62643 L .3179 .62472 L F
.431 .699 .977 r
.3179 .62472 m .31804 .62643 L .32037 .62622 L F
.98 .754 .525 r
.31804 .62643 m .31802 .62943 L .3208 .62919 L F
.797 .395 .29 r
.40865 .52266 m .41117 .52391 L .41296 .52367 L F
.858 .462 .291 r
.41117 .52391 m .41342 .52635 L .41296 .52367 L F
.545 .665 .916 r
.29831 .65641 m .30092 .65972 L .30334 .65881 L F
0 0 0 r
.30334 .65881 m .30092 .65972 L .29891 .66118 L F
.383 0 .111 r
.394 .46022 m .3966 .45995 L .39841 .45738 L F
.434 0 .078 r
.3966 .45995 m .40097 .45773 L .39841 .45738 L F
.812 .691 .731 r
.5579 .44839 m .55328 .45116 L .55548 .44662 L F
.5579 .44839 m .55593 .45162 L .55328 .45116 L F
.655 .948 .955 r
.48032 .43316 m .47918 .43514 L .48147 .43377 L F
.649 .941 .962 r
.4779 .43454 m .47918 .43514 L .48032 .43316 L F
.336 .816 .785 r
.44139 .45141 m .44303 .45056 L .43947 .4526 L F
.44139 .45141 m .44381 .45052 L .44303 .45056 L F
.96 .941 .702 r
.41663 .46685 m .41934 .46425 L .41764 .4635 L F
.41663 .46685 m .41757 .46808 L .41934 .46425 L F
.789 .825 .881 r
.41934 .46425 m .42094 .45966 L .41764 .4635 L F
.41934 .46425 m .42282 .46153 L .42094 .45966 L F
.848 .577 .528 r
.3751 .5241 m .37185 .52369 L .37177 .5207 L F
.831 .55 .514 r
.3751 .5241 m .37127 .52527 L .37185 .52369 L F
.3751 .5241 m .3752 .52677 L .37127 .52527 L F
0 .213 .674 r
.55867 .42191 m .55938 .42207 L .5569 .42116 L F
.55867 .42191 m .56172 .42391 L .55938 .42207 L F
.301 0 .168 r
.26921 .54968 m .26563 .55291 L .26701 .55057 L F
.942 .885 .747 r
.65862 .39532 m .66011 .39646 L .65911 .39836 L F
.7 .892 .967 r
.66258 .39501 m .66011 .39646 L .65862 .39532 L F
.555 .856 .997 r
.64206 .37831 m .64343 .37627 L .64072 .37723 L F
.64206 .37831 m .64479 .37764 L .64343 .37627 L F
.64343 .37627 m .64206 .37831 L .64072 .37723 L F
.64343 .37627 m .64479 .37764 L .64206 .37831 L F
.685 .91 .973 r
.44764 .59436 m .44469 .59595 L .44935 .59503 L F
.993 .851 .497 r
.51968 .39688 m .5219 .39502 L .52012 .39361 L F
.906 .86 .784 r
.52012 .39361 m .5219 .39502 L .52309 .3924 L F
.869 .899 .482 r
.42462 .55899 m .42609 .55689 L .42363 .55545 L F
.861 .445 0 r
.42324 .55767 m .42422 .55916 L .42462 .55899 L F
.869 .899 .482 r
.42462 .55899 m .42469 .56045 L .42539 .55867 L F
.019 0 .35 r
.42501 .5622 m .42469 .56045 L .42462 .55899 L F
0 .088 .62 r
.4259 .56173 m .42501 .5622 L .42462 .55899 L F
.861 .445 0 r
.42422 .55916 m .4259 .56173 L .42462 .55899 L F
.869 .899 .482 r
.42462 .55899 m .42539 .55867 L .42609 .55689 L F
.716 .974 .926 r
.44601 .44918 m .45085 .44773 L .44967 .44772 L F
.416 .864 .863 r
.44967 .44772 m .45085 .44773 L .45318 .44678 L F
.766 .714 .804 r
.31971 .6524 m .31497 .65193 L .31813 .6484 L F
.757 .732 .829 r
.31971 .6524 m .31717 .65342 L .31497 .65193 L F
.642 .65 .843 r
.32232 .64856 m .31971 .6524 L .31813 .6484 L F
.762 .757 .848 r
.32147 .65121 m .31971 .6524 L .32232 .64856 L F
.315 .786 .929 r
.54741 .38873 m .55009 .38832 L .55152 .38874 L F
.413 .834 .965 r
.55152 .38874 m .55248 .3878 L .5552 .38827 L F
.429 .852 .953 r
.55152 .38874 m .55009 .38832 L .55248 .3878 L F
.611 .83 .439 r
.60355 .43793 m .60088 .44174 L .60229 .43961 L F
.496 .728 .976 r
.60088 .44174 m .6039 .44123 L .60229 .43961 L F
0 .108 .66 r
.29506 .6745 m .29576 .67389 L .29556 .67385 L F
0 0 0 r
.29564 .67195 m .2947 .67497 L .29506 .6745 L F
.306 .056 .362 r
.29776 .67123 m .29564 .67195 L .29506 .6745 L F
.29776 .67123 m .29564 .67195 L .29506 .6745 L F
0 .108 .66 r
.29506 .6745 m .29556 .67385 L .29335 .67339 L F
0 0 0 r
.2947 .67497 m .29439 .67598 L .29506 .6745 L F
.649 .777 .312 r
.29506 .6745 m .29439 .67598 L .29314 .67858 L F
.881 .685 .632 r
.36662 .58972 m .36501 .59296 L .36871 .59332 L F
.855 .719 .712 r
.36455 .59532 m .36871 .59332 L .36501 .59296 L F
.36455 .59532 m .36651 .59683 L .36871 .59332 L F
.846 .963 .881 r
.6048 .39881 m .60801 .3976 L .60738 .39747 L F
.444 .878 .813 r
.60738 .39747 m .60801 .3976 L .60983 .3963 L F
.427 0 .081 r
.40585 .45679 m .4105 .45475 L .40773 .45486 L F
.849 .403 0 r
.62398 .36638 m .62596 .36864 L .62476 .36637 L F
.865 .471 .291 r
.32689 .51333 m .32449 .51318 L .32315 .51045 L F
.839 .707 .175 r
.3245 .51715 m .32449 .51318 L .32689 .51333 L F
.831 .683 .699 r
.34046 .54985 m .34282 .55051 L .33899 .55053 L F
.547 .615 .872 r
.34269 .55335 m .33899 .55053 L .34282 .55051 L F
.732 .49 .562 r
.34537 .55248 m .34269 .55335 L .34282 .55051 L F
.672 .25 .235 r
.38223 .46813 m .38631 .46823 L .38613 .46974 L F
.699 .219 .108 r
.38631 .46823 m .38883 .47066 L .38613 .46974 L F
.38631 .46823 m .39132 .47021 L .38883 .47066 L F
.767 .91 .937 r
.29278 .65654 m .29702 .65606 L .2951 .65505 L F
0 .338 .819 r
.29702 .65606 m .29732 .6546 L .2951 .65505 L F
.29702 .65606 m .29831 .65641 L .29732 .6546 L F
.73 .986 .895 r
.51337 .42636 m .51788 .42442 L .51502 .42575 L F
.566 .863 .551 r
.51788 .42442 m .52066 .42156 L .5192 .42286 L F
.598 .939 .761 r
.51502 .42575 m .51788 .42442 L .5192 .42286 L F
.912 .91 .511 r
.5355 .46863 m .53569 .47165 L .53642 .46878 L F
.5355 .46863 m .53453 .4741 L .53569 .47165 L F
.231 .738 .688 r
.63413 .38911 m .6298 .39048 L .63294 .38859 L F
.483 .853 .987 r
.63561 .38756 m .63413 .38911 L .63294 .38859 L F
.63561 .38756 m .63685 .38834 L .63413 .38911 L F
.113 .239 .716 r
.593 .35027 m .59453 .35352 L .59245 .35208 L F
.071 .054 .53 r
.24055 .57016 m .24138 .56973 L .24175 .56567 L F
.047 0 .475 r
.24055 .57016 m .2418 .57258 L .24138 .56973 L F
0 0 .479 r
.24101 .57294 m .2418 .57258 L .24055 .57016 L F
.921 .776 .684 r
.35648 .55329 m .35769 .55688 L .3585 .55427 L F
.837 .729 .745 r
.36457 .57623 m .36611 .58004 L .36834 .57657 L F
.601 .527 .743 r
.34637 .64974 m .34416 .65259 L .34378 .64958 L F
.363 0 0 r
.34416 .65259 m .34482 .65398 L .34335 .65504 L F
.34416 .65259 m .34702 .65322 L .34482 .65398 L F
.06 .537 .893 r
.34702 .65322 m .34416 .65259 L .34637 .64974 L F
.569 .889 .989 r
.51415 .41152 m .51586 .41226 L .51697 .41053 L F
.316 .209 .57 r
.51586 .41226 m .51587 .41443 L .51788 .4138 L F
.713 .694 .83 r
.33936 .6477 m .33518 .64827 L .33773 .6472 L F
.569 .791 .983 r
.34108 .64561 m .33936 .6477 L .33773 .6472 L F
.34108 .64561 m .34238 .64718 L .33936 .6477 L F
.883 .602 .085 r
.66369 .36558 m .66343 .36698 L .66318 .36442 L F
.66369 .36558 m .66423 .36869 L .66343 .36698 L F
.219 0 .041 r
.31449 .5329 m .31697 .53235 L .31778 .53153 L F
.547 .517 .773 r
.31548 .53651 m .31697 .53235 L .31449 .5329 L F
.267 0 0 r
.66035 .33581 m .65918 .33726 L .65638 .33764 L F
.455 0 0 r
.66344 .33706 m .66035 .33581 L .66298 .33556 L F
.66344 .33706 m .65918 .33726 L .66035 .33581 L F
.882 .724 .681 r
.33307 .58055 m .33226 .58328 L .33071 .57957 L F
.53 .808 .997 r
.33487 .5828 m .33226 .58328 L .33307 .58055 L F
.576 .7 .927 r
.33773 .6472 m .33518 .64827 L .33412 .64522 L F
.74 .592 .692 r
.3496 .55183 m .34752 .55447 L .34537 .55248 L F
.575 .844 .996 r
.4803 .53962 m .48477 .54013 L .48391 .53721 L F
.648 .617 .804 r
.48477 .54013 m .48539 .53478 L .48391 .53721 L F
.48477 .54013 m .48716 .53705 L .48539 .53478 L F
.48477 .54013 m .48637 .53911 L .48716 .53705 L F
.659 .182 .108 r
.48477 .54013 m .48716 .53705 L .48637 .53911 L F
.75 .937 .597 r
.23902 .59751 m .24066 .59488 L .24032 .59538 L F
.632 .904 .597 r
.24174 .59375 m .24114 .5941 L .24226 .59315 L F
.24032 .59538 m .24114 .5941 L .24174 .59375 L F
.892 .978 .687 r
.24114 .5941 m .239 .59665 L .23954 .59494 L F
.431 .859 .734 r
.23954 .59494 m .24045 .59451 L .24114 .5941 L F
.114 .666 .741 r
.24226 .59315 m .24552 .59277 L .24781 .59261 L F
.374 .84 .812 r
.24114 .5941 m .24552 .59277 L .24226 .59315 L F
.24114 .5941 m .24298 .59331 L .24552 .59277 L F
.431 .859 .734 r
.24045 .59451 m .24298 .59331 L .24114 .5941 L F
.75 .937 .597 r
.24066 .59488 m .24114 .5941 L .24032 .59538 L F
.512 .886 .689 r
.2399 .59599 m .24032 .59538 L .2423 .59431 L F
.23906 .59657 m .24032 .59538 L .2399 .59599 L F
0 0 0 r
.23906 .59657 m .23902 .59751 L .24032 .59538 L F
.23906 .59657 m .23835 .59988 L .23902 .59751 L F
.673 .864 .972 r
.62629 .40221 m .63034 .40225 L .62898 .4012 L F
.748 .991 .883 r
.63156 .39994 m .63034 .40225 L .63212 .4006 L F
.658 .895 .981 r
.63156 .39994 m .62898 .4012 L .63034 .40225 L F
.948 .687 .508 r
.24063 .60332 m .23834 .60421 L .23835 .59988 L F
.931 .962 .765 r
.23967 .59992 m .24063 .60332 L .24334 .60005 L F
.23967 .59992 m .23834 .60421 L .24063 .60332 L F
.38 .822 .683 r
.44543 .44112 m .44301 .44242 L .44118 .44322 L F
.068 0 0 r
.55329 .40169 m .55688 .39903 L .55283 .39815 L F
.55329 .40169 m .55622 .40074 L .55688 .39903 L F
0 0 0 r
.55688 .39903 m .55837 .39924 L .55974 .39785 L F
.55688 .39903 m .55622 .40074 L .55837 .39924 L F
.482 0 0 r
.48918 .43381 m .49312 .43717 L .49352 .43759 L F
.809 .892 .903 r
.32426 .64944 m .32232 .64856 L .3248 .64865 L F
.32426 .64944 m .32147 .65121 L .32232 .64856 L F
.45 .802 .998 r
.3248 .64865 m .329 .64906 L .32426 .64944 L F
.861 .931 .87 r
.59256 .43426 m .59577 .43187 L .59447 .43034 L F
.623 .893 .578 r
.52762 .4728 m .52586 .47488 L .52719 .47307 L F
.598 .901 .986 r
.52719 .47307 m .52586 .47488 L .52411 .47421 L F
.083 .355 .825 r
.39819 .58742 m .40142 .58941 L .39915 .58642 L F
.327 .006 .259 r
.33444 .67226 m .3376 .66939 L .3369 .67157 L F
.402 .038 .227 r
.3376 .66939 m .33923 .67089 L .3369 .67157 L F
.3376 .66939 m .34023 .66898 L .33923 .67089 L F
.985 .78 .378 r
.60053 .36778 m .60034 .37111 L .60125 .37244 L F
.563 .403 .622 r
.60034 .37111 m .59947 .37458 L .60125 .37244 L F
.545 .028 0 r
.28266 .62594 m .28718 .62599 L .2843 .62724 L F
.488 0 0 r
.28266 .62594 m .28718 .62599 L .28557 .62664 L F
.534 .037 .022 r
.2843 .62724 m .28557 .62664 L .28266 .62594 L F
0 .024 .597 r
.28557 .62664 m .28682 .62541 L .28457 .62704 L F
.28718 .62599 m .28713 .6259 L .28557 .62664 L F
.798 .944 .594 r
.28818 .6234 m .28718 .62599 L .28691 .62556 L F
.28818 .6234 m .28691 .62556 L .2875 .62493 L F
0 .024 .597 r
.28713 .6259 m .28691 .62556 L .28618 .62635 L F
.798 .944 .594 r
.28691 .62556 m .28718 .62599 L .28619 .62679 L F
0 .024 .597 r
.28718 .62599 m .28457 .62704 L .2843 .62724 L F
.798 .944 .594 r
.28691 .62556 m .28619 .62679 L .2875 .62493 L F
0 .024 .597 r
.28618 .62635 m .28682 .62541 L .28557 .62664 L F
.28691 .62556 m .28682 .62541 L .28618 .62635 L F
.534 .037 .022 r
.2843 .62724 m .28619 .62679 L .28557 .62664 L F
0 .024 .597 r
.28718 .62599 m .2875 .62493 L .28682 .62541 L F
.488 0 0 r
.28557 .62664 m .28718 .62599 L .28619 .62679 L F
0 .024 .597 r
.28718 .62599 m .28921 .62865 L .2875 .62493 L F
.715 .197 0 r
.29484 .66545 m .29601 .6659 L .29788 .66833 L F
.727 .294 .222 r
.2846 .67131 m .28604 .66999 L .28195 .66902 L F
.252 .746 .912 r
.28799 .66949 m .28868 .66984 L .28604 .66999 L F
.477 .723 .978 r
.28837 .63325 m .29109 .63309 L .28923 .6312 L F
.349 .79 .961 r
.4086 .58316 m .40673 .58239 L .40386 .58285 L F
.836 .969 .652 r
.40652 .58505 m .4086 .58316 L .40386 .58285 L F
.40652 .58505 m .40639 .5864 L .4086 .58316 L F
.701 .363 .402 r
.40955 .58342 m .40673 .58239 L .4086 .58316 L F
.777 .503 .52 r
.32958 .53743 m .33271 .54002 L .33143 .53629 L F
.32958 .53743 m .32869 .53991 L .33271 .54002 L F
.816 .948 .908 r
.49779 .50451 m .4933 .50626 L .49648 .50367 L F
.825 .962 .898 r
.50091 .50168 m .49779 .50451 L .49837 .50179 L F
.821 .959 .902 r
.49779 .50451 m .49648 .50367 L .49837 .50179 L F
.89 .726 .673 r
.36585 .58287 m .36392 .58626 L .36729 .58671 L F
.847 .709 .71 r
.36392 .58626 m .36662 .58972 L .36729 .58671 L F
.547 .517 .773 r
.31548 .53651 m .31784 .53539 L .31697 .53235 L F
.741 .981 .751 r
.48065 .41695 m .47912 .41878 L .48018 .41669 L F
.739 .991 .817 r
.47912 .41878 m .47701 .41939 L .48018 .41669 L F
.965 .93 .702 r
.55956 .43183 m .55742 .43181 L .55798 .42989 L F
.55956 .43183 m .55796 .43444 L .55742 .43181 L F
.725 .97 .719 r
.538 .47604 m .53665 .47795 L .53769 .47591 L F
.375 .628 .952 r
.53769 .47591 m .53665 .47795 L .53534 .47601 L F
.53769 .47591 m .53665 .47795 L .53534 .47601 L F
.694 .679 .831 r
.33563 .62963 m .33994 .63024 L .3383 .62907 L F
.754 .778 .873 r
.33994 .63024 m .34067 .62618 L .3383 .62907 L F
0 .134 .678 r
.34376 .6611 m .34564 .66521 L .34327 .66254 L F
.435 .281 .572 r
.34564 .66521 m .3432 .66598 L .34327 .66254 L F
.647 .963 .916 r
.51974 .48309 m .51655 .48403 L .51904 .48018 L F
.744 .787 .887 r
.52298 .48072 m .51974 .48309 L .51904 .48018 L F
.95 .856 .712 r
.5742 .4282 m .57595 .42444 L .5744 .42335 L F
.841 .641 .632 r
.35736 .56254 m .36157 .5603 L .35757 .55964 L F
.35736 .56254 m .36108 .56308 L .36157 .5603 L F
.819 .618 .631 r
.36108 .56308 m .36336 .56408 L .36157 .5603 L F
.766 .842 .909 r
.32339 .6069 m .32726 .60753 L .32435 .60974 L F
.733 .604 .713 r
.32311 .60621 m .32334 .60768 L .32013 .61011 L F
.979 .894 .665 r
.32348 .60717 m .32435 .60974 L .32324 .61031 L F
.32279 .60972 m .32324 .61031 L .32254 .61066 L F
.192 .215 .655 r
.32339 .6069 m .32365 .60959 L .32334 .60768 L F
.32339 .6069 m .32334 .60768 L .32311 .60621 L F
.979 .894 .665 r
.32348 .60717 m .32324 .61031 L .32319 .61024 L F
.32334 .60768 m .32319 .61024 L .32279 .60972 L F
.32348 .60717 m .32319 .61024 L .32334 .60768 L F
.733 .604 .713 r
.32334 .60768 m .32279 .60972 L .32013 .61011 L F
.32311 .60621 m .32013 .61011 L .3188 .6056 L F
.655 .865 .979 r
.32013 .61011 m .32279 .60972 L .32058 .60934 L F
.733 .604 .713 r
.32334 .60768 m .32365 .60959 L .32279 .60972 L F
.655 .865 .979 r
.32279 .60972 m .32263 .60951 L .32058 .60934 L F
.979 .894 .665 r
.32348 .60717 m .32254 .61066 L .32221 .61083 L F
.655 .865 .979 r
.32279 .60972 m .32365 .60959 L .32263 .60951 L F
.83 .691 .709 r
.32058 .60934 m .32263 .60951 L .32221 .61083 L F
.32263 .60951 m .32365 .60959 L .32221 .61083 L F
.979 .894 .665 r
.32339 .6069 m .32343 .60701 L .32221 .61083 L F
.32343 .60701 m .32348 .60717 L .32221 .61083 L F
0 0 0 r
.62139 .3435 m .62261 .34327 L .62391 .34241 L F
.62261 .34327 m .62674 .34199 L .62391 .34241 L F
.322 .423 .81 r
.59105 .42936 m .59202 .42682 L .59009 .42962 L F
.59105 .42936 m .59447 .43034 L .59202 .42682 L F
.885 .551 .054 r
.6922 .35387 m .69231 .35177 L .69034 .35131 L F
.6922 .35387 m .69302 .35438 L .69231 .35177 L F
.246 0 .286 r
.59268 .37483 m .59561 .37156 L .59232 .37213 L F
.878 .55 .044 r
.29258 .62496 m .29349 .62617 L .29206 .62249 L F
.969 .649 .297 r
.29241 .62861 m .29407 .62916 L .29349 .62617 L F
.435 0 .02 r
.62809 .34605 m .62656 .34782 L .62406 .34774 L F
.344 0 0 r
.63065 .34676 m .62809 .34605 L .63052 .34579 L F
.63065 .34676 m .62656 .34782 L .62809 .34605 L F
.899 .926 .827 r
.55465 .46723 m .55589 .46852 L .55842 .46512 L F
.922 .921 .794 r
.55465 .46723 m .55321 .46918 L .55589 .46852 L F
.318 0 .211 r
.32145 .68173 m .32241 .67895 L .32481 .67825 L F
.867 .707 .681 r
.3595 .56643 m .36336 .56408 L .36108 .56308 L F
.3595 .56643 m .36314 .56684 L .36336 .56408 L F
.887 .458 .121 r
.38588 .54659 m .38264 .54256 L .38609 .54392 L F
.867 .779 .762 r
.34676 .53731 m .34458 .54122 L .34222 .53948 L F
0 .065 .571 r
.43919 .58347 m .44281 .58698 L .44164 .58334 L F
.43919 .58347 m .44163 .58564 L .44281 .58698 L F
.82 .673 .701 r
.43908 .58628 m .44281 .58698 L .44163 .58564 L F
.43908 .58628 m .44146 .59076 L .44281 .58698 L F
.064 0 0 r
.44181 .58876 m .44485 .58896 L .44331 .58884 L F
.44485 .58896 m .44582 .58903 L .44331 .58884 L F
.345 .169 .494 r
.44281 .58698 m .44218 .58875 L .44331 .58884 L F
.44218 .58875 m .44146 .59076 L .44331 .58884 L F
.366 .211 .535 r
.24442 .54682 m .24688 .54245 L .24444 .54441 L F
.514 .815 1 r
.43919 .58347 m .44164 .58334 L .44205 .58273 L F
.429 .179 .431 r
.44205 .58273 m .44163 .58564 L .43919 .58347 L F
.973 .906 .687 r
.42581 .54831 m .42668 .54648 L .4237 .54661 L F
.458 .856 .666 r
.54457 .39063 m .54721 .38856 L .54741 .38873 L F
.716 .709 .842 r
.54333 .39274 m .54721 .38856 L .54457 .39063 L F
.078 0 .043 r
.27337 .51762 m .27047 .52037 L .27281 .51898 L F
.39 .001 .176 r
.27281 .51898 m .27522 .51868 L .27337 .51762 L F
.402 0 .137 r
.27337 .51762 m .27522 .51868 L .27614 .51731 L F
.881 .992 .777 r
.3741 .47218 m .3766 .46977 L .37441 .4718 L F
0 0 0 r
.37908 .46973 m .37441 .4718 L .3766 .46977 L F
.37908 .46973 m .37554 .47144 L .37441 .4718 L F
.074 0 0 r
.37908 .46973 m .38245 .4697 L .37612 .47139 L F
.37908 .46973 m .37612 .47139 L .37554 .47144 L F
.37908 .46973 m .38175 .46939 L .38245 .4697 L F
.157 0 0 r
.37468 .47091 m .37568 .47094 L .37624 .46823 L F
.767 .65 .732 r
.37566 .47099 m .38245 .4697 L .37855 .46776 L F
.37558 .47127 m .38245 .4697 L .37566 .47099 L F
.37612 .47139 m .38245 .4697 L .37537 .47132 L F
.37537 .47132 m .37558 .47127 L .37566 .47099 L F
0 0 0 r
.37554 .47144 m .37588 .47137 L .37579 .47136 L F
.37441 .4718 m .37606 .4714 L .37554 .47144 L F
.37441 .4718 m .37505 .47168 L .37606 .4714 L F
.074 0 0 r
.37554 .47144 m .37606 .4714 L .37505 .47168 L F
.37606 .4714 m .37612 .47139 L .37505 .47168 L F
0 0 0 r
.37606 .4714 m .37505 .47168 L .3777 .471 L F
.767 .65 .732 r
.37505 .47168 m .37612 .47139 L .37537 .47132 L F
0 0 0 r
.37579 .47136 m .3777 .471 L .37634 .47119 L F
.37588 .47137 m .3777 .471 L .37579 .47136 L F
.37606 .4714 m .3777 .471 L .37554 .47144 L F
.767 .65 .732 r
.37537 .47132 m .37855 .46776 L .3777 .471 L F
.157 0 0 r
.37568 .47094 m .37707 .47098 L .37642 .46857 L F
.37707 .47098 m .3777 .471 L .37751 .47063 L F
.37707 .47098 m .37751 .47063 L .37642 .46857 L F
.557 .169 .262 r
.37838 .46992 m .37961 .46895 L .37896 .46962 L F
0 0 0 r
.37441 .4718 m .3765 .47113 L .3748 .47133 L F
.157 0 0 r
.37468 .47091 m .37381 .47144 L .3777 .471 L F
.564 .21 .327 r
.37624 .46823 m .37751 .47063 L .37855 .46776 L F
.557 .169 .262 r
.37734 .47073 m .37785 .47042 L .37754 .47064 L F
.564 .21 .327 r
.37751 .47063 m .3777 .471 L .37785 .47042 L F
.37751 .47063 m .37785 .47042 L .37855 .46776 L F
.979 .782 .367 r
.37785 .47042 m .37827 .47034 L .37855 .46776 L F
.3777 .471 m .37827 .47034 L .37785 .47042 L F
.557 .169 .262 r
.3746 .47189 m .37716 .47056 L .37785 .47042 L F
.37716 .47056 m .37896 .46962 L .37785 .47042 L F
.767 .65 .732 r
.37505 .47168 m .37537 .47132 L .3769 .47111 L F
.557 .169 .262 r
.3746 .47189 m .37785 .47042 L .37734 .47073 L F
.3746 .47189 m .37949 .46902 L .37838 .46992 L F
.37949 .46902 m .37961 .46895 L .37838 .46992 L F
.37754 .47064 m .37896 .46962 L .37827 .47034 L F
.767 .65 .732 r
.37669 .47125 m .3769 .47111 L .3777 .471 L F
.37505 .47168 m .3769 .47111 L .37669 .47125 L F
0 0 0 r
.37634 .47119 m .3777 .471 L .3765 .47113 L F
.157 0 0 r
.37568 .47094 m .37642 .46857 L .37624 .46823 L F
0 0 0 r
.37554 .47144 m .37505 .47168 L .37441 .4718 L F
.37441 .4718 m .3748 .47133 L .37381 .47144 L F
.881 .992 .777 r
.3727 .47353 m .3741 .47218 L .37441 .4718 L F
.041 0 .168 r
.44395 .56035 m .44168 .56381 L .44362 .56188 L F
.582 .835 .471 r
.24473 .5983 m .24434 .59868 L .24334 .60005 L F
.2453 .59759 m .24434 .59868 L .24473 .5983 L F
.558 .927 .93 r
.24406 .59906 m .23967 .59992 L .24334 .60005 L F
.24434 .59868 m .24313 .599 L .24406 .59906 L F
.24313 .599 m .23967 .59992 L .24406 .59906 L F
.606 .068 0 r
.24434 .59868 m .23902 .59751 L .23967 .59992 L F
.529 0 0 r
.24279 .59985 m .24482 .60058 L .24277 .59991 L F
.24166 .5989 m .24482 .60058 L .23976 .59877 L F
.606 .068 0 r
.24434 .59868 m .24335 .5998 L .24294 .59958 L F
.24382 .59857 m .24294 .59958 L .23902 .59751 L F
.24434 .59868 m .24294 .59958 L .24382 .59857 L F
.775 .322 0 r
.24375 .59912 m .24381 .5992 L .24434 .59868 L F
.606 .068 0 r
.24434 .59868 m .24482 .60058 L .24335 .5998 L F
.775 .322 0 r
.24381 .5992 m .24482 .60058 L .24434 .59868 L F
.529 0 0 r
.23976 .59877 m .24279 .59985 L .23987 .59896 L F
.24279 .59985 m .24277 .59991 L .23987 .59896 L F
.805 .663 .705 r
.23987 .59896 m .24482 .60058 L .24375 .59912 L F
.787 .688 .755 r
.2457 .59801 m .2424 .60057 L .24375 .59912 L F
.2424 .60057 m .24215 .60076 L .24248 .60043 L F
.2424 .60057 m .24248 .60043 L .24375 .59912 L F
.529 0 0 r
.23902 .59751 m .24166 .5989 L .23976 .59877 L F
.582 .835 .471 r
.24605 .59664 m .24434 .59868 L .2453 .59759 L F
.162 0 0 r
.31697 .53235 m .32077 .53019 L .31778 .53153 L F
0 0 .227 r
.32077 .53019 m .32107 .52641 L .32407 .53066 L F
.32077 .53019 m .32133 .53072 L .32107 .52641 L F
.041 0 0 r
.32077 .53019 m .3213 .53137 L .32133 .53072 L F
.32077 .53019 m .31904 .53213 L .3213 .53137 L F
.629 .915 .98 r
.57157 .35449 m .57226 .3523 L .57408 .35425 L F
.57157 .35449 m .56974 .35355 L .57226 .3523 L F
0 .114 .667 r
.57203 .35769 m .56974 .35355 L .57157 .35449 L F
.669 .93 .639 r
.5293 .44486 m .53232 .44168 L .53046 .44298 L F
.758 .655 .747 r
.53174 .43843 m .53472 .43825 L .53232 .44168 L F
.389 0 0 r
.53342 .43944 m .53472 .43825 L .53174 .43843 L F
.05 .245 .742 r
.53408 .4371 m .53342 .43944 L .53254 .4377 L F
.53408 .4371 m .53254 .4377 L .53157 .43578 L F
.301 0 .188 r
.53535 .43538 m .53848 .43616 L .53408 .4371 L F
.387 .836 .929 r
.53408 .4371 m .53848 .43616 L .53641 .43599 L F
.53408 .4371 m .53641 .43599 L .53554 .43652 L F
.721 .775 .282 r
.53355 .43874 m .53342 .43944 L .53408 .4371 L F
.389 0 0 r
.53342 .43944 m .53174 .43843 L .53051 .43981 L F
.84 .655 .652 r
.53092 .43853 m .53342 .43944 L .53062 .43979 L F
.53182 .43626 m .53342 .43944 L .53092 .43853 L F
.736 .95 .644 r
.53046 .44298 m .53232 .44168 L .53342 .43944 L F
.716 .909 .548 r
.53232 .44168 m .53325 .44035 L .53342 .43944 L F
.736 .95 .644 r
.53046 .44298 m .53342 .43944 L .53254 .44187 L F
.428 .204 .47 r
.53221 .4414 m .53335 .43767 L .53092 .43853 L F
.53071 .43908 m .53092 .43853 L .5299 .43889 L F
.463 .281 .547 r
.5299 .43889 m .53092 .43853 L .53157 .43578 L F
.84 .655 .652 r
.53157 .43578 m .53071 .43908 L .5299 .43889 L F
.53071 .43908 m .53051 .43981 L .5299 .43889 L F
.428 .204 .47 r
.53051 .43956 m .53071 .43908 L .5299 .43889 L F
.84 .655 .652 r
.53157 .43578 m .53062 .43979 L .53051 .43981 L F
.428 .204 .47 r
.53221 .4414 m .53092 .43853 L .53051 .43956 L F
.84 .655 .652 r
.53157 .43578 m .53182 .43626 L .53092 .43853 L F
.463 .281 .547 r
.53092 .43853 m .53335 .43767 L .53157 .43578 L F
.721 .775 .282 r
.53254 .44187 m .53408 .4371 L .53353 .43829 L F
0 0 .148 r
.53221 .4414 m .53335 .43767 L .53408 .4371 L F
.53221 .4414 m .53408 .4371 L .53353 .43829 L F
.387 .836 .929 r
.53408 .4371 m .53554 .43652 L .53272 .43827 L F
.721 .775 .282 r
.53254 .44187 m .53342 .43944 L .53355 .43874 L F
.716 .909 .548 r
.53325 .44035 m .53472 .43825 L .53342 .43944 L F
.157 .337 .794 r
.52226 .42019 m .52066 .42156 L .51857 .41713 L F
.52226 .42019 m .51857 .41713 L .51918 .41698 L F
.52226 .42019 m .51784 .41559 L .52326 .41768 L F
.501 .058 .129 r
.51669 .4183 m .52039 .41667 L .51833 .41739 L F
.52039 .41667 m .52088 .41646 L .52008 .41675 L F
.52039 .41667 m .52008 .41675 L .51833 .41739 L F
.157 .337 .794 r
.51918 .41698 m .51857 .41713 L .51784 .41559 L F
0 0 0 r
.5192 .42286 m .52066 .42156 L .52226 .42019 L F
.964 .861 .689 r
.41592 .5354 m .41868 .53422 L .41708 .53302 L F
.41592 .5354 m .41775 .53714 L .41868 .53422 L F
.089 0 0 r
.62961 .34165 m .6321 .34098 L .63342 .33951 L F
.143 0 0 r
.6321 .34098 m .63644 .33908 L .63342 .33951 L F
.909 .635 .511 r
.68252 .32526 m .6825 .32788 L .6857 .32906 L F
.896 .649 .557 r
.68229 .33058 m .6857 .32906 L .6825 .32788 L F
.68229 .33058 m .68597 .33186 L .6857 .32906 L F
.843 .609 .585 r
.68597 .33186 m .68763 .33253 L .6857 .32906 L F
0 0 0 r
.31996 .55818 m .32086 .55671 L .31802 .55585 L F
.31996 .55818 m .32082 .55744 L .32086 .55671 L F
.459 .826 .569 r
.46963 .53392 m .47102 .53275 L .47218 .53303 L F
.46963 .53392 m .46786 .53528 L .47102 .53275 L F
.679 .971 .917 r
.3911 .46961 m .39132 .47021 L .39548 .46759 L F
.38883 .47066 m .38954 .47053 L .3911 .46961 L F
.38954 .47053 m .39132 .47021 L .3911 .46961 L F
.38883 .47066 m .39548 .46759 L .39166 .4701 L F
.912 .934 .811 r
.39166 .4701 m .39548 .46759 L .39552 .46663 L F
.39166 .4701 m .39431 .46772 L .39412 .46911 L F
.39431 .46772 m .39552 .46663 L .3952 .4672 L F
.39431 .46772 m .3952 .4672 L .39412 .46911 L F
.523 .478 .747 r
.27114 .54273 m .26815 .54063 L .27076 .53981 L F
0 0 0 r
.3284 .50369 m .3309 .50348 L .33274 .50329 L F
.606 .062 0 r
.3309 .50348 m .3347 .50421 L .33274 .50329 L F
.576 .256 .388 r
.32313 .60321 m .32311 .60621 L .32138 .60222 L F
.534 .447 .704 r
.3258 .605 m .32726 .60753 L .32346 .60691 L F
.32754 .60413 m .32726 .60753 L .32572 .60486 L F
.32758 .60355 m .3296 .60638 L .32726 .60753 L F
.639 .485 .657 r
.32797 .60324 m .32745 .60366 L .32657 .60347 L F
.32745 .60366 m .32622 .60466 L .32639 .60407 L F
.32745 .60366 m .32639 .60407 L .32657 .60347 L F
.32897 .60307 m .3296 .60638 L .3278 .60352 L F
.534 .447 .704 r
.3278 .60352 m .3296 .60638 L .32758 .60355 L F
.63 .243 .293 r
.32657 .60347 m .32622 .60466 L .32565 .60439 L F
.32551 .60339 m .32565 .60439 L .32313 .60321 L F
.32657 .60347 m .32565 .60439 L .32551 .60339 L F
.534 .447 .704 r
.32761 .60321 m .32754 .60413 L .32683 .60442 L F
.639 .485 .657 r
.32694 .60425 m .32622 .60466 L .32717 .60389 L F
.32694 .60425 m .32717 .60389 L .32797 .60324 L F
.32897 .60307 m .32694 .60425 L .32797 .60324 L F
.32829 .60346 m .32587 .60588 L .32622 .60466 L F
.63 .243 .293 r
.32622 .60466 m .32509 .60512 L .32313 .60321 L F
.473 .135 .312 r
.32761 .60321 m .32572 .60486 L .32587 .60588 L F
.534 .447 .704 r
.32572 .60486 m .3258 .605 L .32339 .6069 L F
.3258 .605 m .32346 .60691 L .32339 .6069 L F
.473 .135 .312 r
.32572 .60486 m .32339 .6069 L .32587 .60588 L F
.639 .485 .657 r
.32897 .60307 m .3278 .60352 L .32761 .60321 L F
.534 .447 .704 r
.32761 .60321 m .3278 .60352 L .32758 .60355 L F
.639 .485 .657 r
.32897 .60307 m .32857 .60342 L .32829 .60346 L F
.32857 .60342 m .32587 .60588 L .32829 .60346 L F
.63 .243 .293 r
.32622 .60466 m .32587 .60588 L .32509 .60512 L F
.576 .256 .388 r
.32313 .60321 m .32587 .60588 L .32311 .60621 L F
.906 .86 .784 r
.52012 .39361 m .52309 .3924 L .52294 .39022 L F
.754 .504 .553 r
.28285 .64745 m .28444 .64638 L .28024 .64616 L F
.639 .733 .916 r
.28315 .64685 m .28444 .64638 L .28285 .64745 L F
.94 .954 .644 r
.28444 .64638 m .28315 .64685 L .28024 .64616 L F
.849 .892 .868 r
.28494 .64325 m .28315 .64685 L .28076 .64473 L F
.28315 .64685 m .28285 .64745 L .28249 .64699 L F
.94 .954 .644 r
.28315 .64685 m .28249 .64699 L .28024 .64616 L F
.849 .892 .868 r
.28315 .64685 m .28249 .64699 L .28076 .64473 L F
.94 .954 .644 r
.28315 .64685 m .28262 .64703 L .28249 .64699 L F
.21 .568 .939 r
.28249 .64699 m .28285 .64745 L .28024 .64616 L F
.94 .954 .644 r
.28262 .64703 m .28163 .64739 L .28024 .64616 L F
.21 .568 .939 r
.28076 .64473 m .28249 .64699 L .28024 .64616 L F
.639 .733 .916 r
.28494 .64325 m .28444 .64638 L .28315 .64685 L F
.94 .954 .644 r
.28444 .64638 m .28249 .64814 L .28163 .64739 L F
.28444 .64638 m .28335 .64868 L .28249 .64814 L F
.639 .733 .916 r
.28494 .64325 m .28719 .64566 L .28444 .64638 L F
.903 .657 .556 r
.35013 .52718 m .34958 .52989 L .35182 .53063 L F
.859 .534 .436 r
.34981 .53255 m .35182 .53063 L .34958 .52989 L F
.34981 .53255 m .35215 .53323 L .35182 .53063 L F
.233 0 0 r
.52376 .41227 m .52202 .41158 L .5205 .41308 L F
.52376 .41227 m .52478 .41119 L .52202 .41158 L F
.888 .99 .785 r
.54696 .46411 m .54357 .46672 L .54627 .4638 L F
.54696 .46411 m .54425 .46767 L .54357 .46672 L F
.782 .994 .875 r
.55009 .46135 m .54696 .46411 L .54755 .46179 L F
.821 .99 .73 r
.54696 .46411 m .54627 .4638 L .54755 .46179 L F
.891 .495 .264 r
.53482 .35951 m .53311 .36103 L .53301 .3584 L F
.662 .759 .922 r
.53748 .35842 m .53482 .35951 L .53301 .3584 L F
.942 .885 .747 r
.65862 .39532 m .65911 .39836 L .65683 .39731 L F
.833 .484 .394 r
.65911 .39836 m .65622 .39976 L .65683 .39731 L F
.65911 .39836 m .66037 .40168 L .65622 .39976 L F
.603 .953 .876 r
.46008 .44397 m .46122 .44237 L .45901 .44386 L F
.46008 .44397 m .46337 .44209 L .46122 .44237 L F
.824 .685 .71 r
.33806 .58293 m .33662 .5866 L .33487 .5828 L F
0 0 .25 r
.54268 .42034 m .54159 .42177 L .54269 .41806 L F
.54268 .42034 m .54269 .41806 L .54206 .41743 L F
.678 .917 .974 r
.41351 .46735 m .41757 .46808 L .41663 .46685 L F
.899 .926 .827 r
.55465 .46723 m .55842 .46512 L .55682 .46368 L F
.982 .888 .655 r
.54425 .46767 m .54178 .46868 L .54357 .46672 L F
.54425 .46767 m .54292 .47166 L .54178 .46868 L F
.982 .698 .333 r
.67481 .31634 m .67661 .31858 L .67629 .31587 L F
.94 .943 .607 r
.67644 .31239 m .67481 .31634 L .67629 .31587 L F
.878 .534 .395 r
.68756 .33512 m .69125 .33861 L .69196 .33612 L F
.479 .062 .17 r
.39949 .46451 m .39801 .46683 L .39552 .46663 L F
.616 .289 .394 r
.40218 .4639 m .39801 .46683 L .39949 .46451 L F
0 0 0 r
.44211 .59684 m .44248 .59708 L .44042 .59797 L F
.44211 .59684 m .44469 .59595 L .44248 .59708 L F
.708 .893 .514 r
.24675 .59504 m .24434 .59868 L .24605 .59664 L F
.881 .448 .078 r
.42595 .56878 m .42661 .56714 L .42442 .56569 L F
.42595 .56878 m .42777 .5698 L .42661 .56714 L F
.832 .909 .89 r
.49367 .52297 m .49816 .52132 L .49678 .52015 L F
.811 .915 .909 r
.49678 .52015 m .49816 .52132 L .50019 .51939 L F
.696 .794 .926 r
.61647 .39335 m .61542 .39669 L .61433 .39649 L F
.61647 .39335 m .61791 .39532 L .61542 .39669 L F
.917 .767 .68 r
.35148 .49603 m .34761 .49896 L .34957 .49573 L F
.35148 .49603 m .35059 .50027 L .34761 .49896 L F
.837 .951 .892 r
.35148 .49603 m .35234 .49318 L .35417 .49347 L F
.35148 .49603 m .34957 .49573 L .35234 .49318 L F
.158 0 0 r
.31527 .62719 m .31571 .62745 L .31369 .62804 L F
.615 .41 .581 r
.27563 .53506 m .2735 .53388 L .27625 .53329 L F
.27563 .53506 m .2737 .53648 L .2735 .53388 L F
.346 .794 .954 r
.53555 .4537 m .53785 .45427 L .53483 .45463 L F
.139 .685 .766 r
.53483 .45463 m .53676 .4542 L .53555 .4537 L F
.53483 .45463 m .53785 .45427 L .53676 .4542 L F
.866 .624 .57 r
.68441 .33395 m .68763 .33253 L .68597 .33186 L F
.68441 .33395 m .68756 .33512 L .68763 .33253 L F
.412 .839 .688 r
.45311 .43612 m .45143 .43725 L .45075 .43742 L F
.45311 .43612 m .455 .43526 L .45143 .43725 L F
.894 .987 .74 r
.44918 .58671 m .4487 .58561 L .45111 .58219 L F
.001 0 .129 r
.51891 .40875 m .5167 .4087 L .51955 .40705 L F
.51891 .40875 m .51697 .41053 L .5167 .4087 L F
0 .285 .69 r
.40028 .59274 m .40104 .59292 L .3987 .59177 L F
.40028 .59274 m .4029 .59407 L .40104 .59292 L F
.919 .654 .519 r
.39231 .56351 m .38894 .56309 L .38925 .55955 L F
.909 .729 .646 r
.39231 .56351 m .38845 .56534 L .38894 .56309 L F
.39231 .56351 m .39006 .56629 L .38845 .56534 L F
.834 .653 .657 r
.35878 .56905 m .36314 .56684 L .3595 .56643 L F
.35878 .56905 m .36251 .57025 L .36314 .56684 L F
.739 .963 .938 r
.53983 .48078 m .54099 .48166 L .54301 .47992 L F
.489 .245 .471 r
.53329 .46426 m .53643 .46401 L .5363 .46119 L F
.388 .051 .268 r
.66381 .3219 m .66661 .32324 L .66608 .32058 L F
.66381 .3219 m .66354 .3242 L .66661 .32324 L F
.937 .583 .32 r
.55454 .44424 m .55301 .44394 L .55295 .4431 L F
.55454 .44424 m .55548 .44662 L .55301 .44394 L F
.351 .093 .376 r
.25268 .56361 m .25193 .56615 L .24971 .56675 L F
.819 .651 .675 r
.46589 .56928 m .46747 .57253 L .47054 .57004 L F
.784 .584 .63 r
.46747 .57253 m .4722 .5738 L .47054 .57004 L F
.795 .672 .728 r
.46995 .55345 m .47396 .55379 L .47237 .54969 L F
.985 .827 .604 r
.55593 .45162 m .55385 .45304 L .55328 .45116 L F
.55593 .45162 m .55532 .45434 L .55385 .45304 L F
.146 .19 .65 r
.24101 .57294 m .24155 .57723 L .24281 .57462 L F
.482 .598 .892 r
.24155 .57723 m .24377 .57738 L .24281 .57462 L F
.725 .464 .531 r
.56158 .37536 m .56074 .37788 L .55847 .37725 L F
.547 .526 .784 r
.58472 .35701 m .58049 .35418 L .58251 .35561 L F
.951 .713 .542 r
.38096 .53391 m .37862 .53561 L .37895 .53284 L F
.38096 .53391 m .38066 .5367 L .37862 .53561 L F
.439 .764 .996 r
.31449 .51204 m .31623 .51333 L .31383 .51369 L F
.31449 .51204 m .31623 .51333 L .31383 .51369 L F
.698 .448 .542 r
.25396 .57321 m .2556 .57637 L .25074 .57612 L F
.662 .626 .803 r
.25572 .57151 m .25396 .57321 L .25295 .57106 L F
0 0 .127 r
.25572 .57151 m .2556 .57637 L .25396 .57321 L F
.869 .557 .458 r
.35548 .50413 m .35118 .50528 L .35329 .50331 L F
.35548 .50413 m .35492 .50674 L .35118 .50528 L F
.863 .551 .458 r
.35722 .50707 m .35492 .50674 L .35548 .50413 L F
.019 0 .35 r
.42501 .5622 m .42436 .56298 L .42469 .56045 L F
.943 .794 .666 r
.34776 .52564 m .35059 .52382 L .34944 .52345 L F
.34776 .52564 m .35013 .52718 L .35059 .52382 L F
.89 .826 .778 r
.60229 .43961 m .6063 .43754 L .60355 .43793 L F
.78 .656 .726 r
.36339 .4918 m .35992 .49008 L .36179 .48937 L F
.36339 .4918 m .36075 .49395 L .35992 .49008 L F
.567 .625 .869 r
.34549 .64759 m .34378 .64958 L .34238 .64718 L F
.34549 .64759 m .34637 .64974 L .34378 .64958 L F
0 0 0 r
.60288 .38524 m .60263 .38712 L .60558 .38499 L F
.60288 .38524 m .60219 .38728 L .60263 .38712 L F
.897 .62 .508 r
.37177 .5207 m .36908 .52241 L .36936 .51967 L F
.37177 .5207 m .37185 .52369 L .36908 .52241 L F
.803 .94 .917 r
.67211 .31204 m .67281 .30908 L .67544 .31105 L F
.67211 .31204 m .67093 .31093 L .67281 .30908 L F
.974 .764 .559 r
.32089 .5688 m .32265 .57017 L .32069 .57207 L F
.5 .779 .995 r
.32372 .56832 m .32265 .57017 L .32089 .5688 L F
.682 .917 .592 r
.32069 .57207 m .32265 .57017 L .32372 .56832 L F
.63 .911 .982 r
.46907 .44016 m .47049 .43817 L .46744 .43921 L F
.46907 .44016 m .47299 .43858 L .47049 .43817 L F
.159 .023 .434 r
.2427 .55033 m .24426 .54964 L .24442 .54682 L F
.233 .193 .607 r
.2427 .55033 m .24472 .55241 L .24426 .54964 L F
.321 .204 .561 r
.24284 .55286 m .24472 .55241 L .2427 .55033 L F
.337 0 .13 r
.26643 .52337 m .26897 .52286 L .27047 .52037 L F
.313 0 .116 r
.27047 .52037 m .27165 .52216 L .27281 .51898 L F
.27047 .52037 m .26897 .52286 L .27165 .52216 L F
.933 .568 .294 r
.33709 .50888 m .33731 .50674 L .33534 .50598 L F
.33709 .50888 m .3384 .50994 L .33731 .50674 L F
.532 .147 .256 r
.37827 .50008 m .38451 .49729 L .37827 .49736 L F
.37827 .50008 m .382 .49977 L .38451 .49729 L F
.7 .48 .586 r
.382 .49977 m .38524 .49646 L .38451 .49729 L F
0 0 .465 r
.32136 .61316 m .32158 .61597 L .31984 .61478 L F
.805 .936 .571 r
.32221 .61083 m .32136 .61316 L .31984 .61478 L F
0 .113 .661 r
.50991 .42851 m .50845 .42856 L .51093 .42717 L F
.50991 .42851 m .50964 .43072 L .50845 .42856 L F
.197 0 0 r
.31201 .68547 m .3163 .68282 L .3145 .6849 L F
.216 0 0 r
.3145 .6849 m .3163 .68282 L .3188 .68221 L F
0 .514 .746 r
.64235 .39767 m .64635 .39838 L .6454 .39807 L F
0 0 0 r
.64635 .39838 m .64767 .39836 L .6454 .39807 L F
.64635 .39838 m .64923 .39817 L .64767 .39836 L F
.724 .494 .577 r
.43522 .56962 m .43917 .56968 L .438 .56716 L F
0 0 .567 r
.438 .56716 m .43909 .56592 L .43849 .566 L F
.438 .56716 m .43917 .56968 L .43909 .56592 L F
.865 .423 .031 r
.41805 .54006 m .4205 .54318 L .42056 .54038 L F
.737 .729 .844 r
.33138 .62914 m .33563 .62963 L .33411 .62616 L F
.694 .675 .827 r
.33563 .62963 m .33688 .62512 L .33411 .62616 L F
.33563 .62963 m .3383 .62907 L .33688 .62512 L F
.242 .297 .721 r
.60356 .35303 m .60502 .35451 L .60413 .35018 L F
.57 .342 .532 r
.60284 .35406 m .60502 .35451 L .60356 .35303 L F
.723 .382 .401 r
.60048 .35104 m .59681 .34866 L .60108 .34891 L F
.344 .822 .859 r
.60413 .35018 m .60048 .35104 L .60108 .34891 L F
0 0 .454 r
.40652 .58505 m .40819 .59049 L .40639 .5864 L F
.972 .76 .558 r
.34582 .5636 m .34377 .56542 L .34414 .56264 L F
.34582 .5636 m .34561 .56643 L .34377 .56542 L F
.802 .883 .904 r
.46134 .54619 m .45939 .5477 L .45777 .54655 L F
.264 .029 .358 r
.30605 .67183 m .30393 .67278 L .3064 .66921 L F
.30605 .67183 m .30393 .67278 L .3064 .66921 L F
.556 .272 .439 r
.30605 .67183 m .30871 .67151 L .3064 .66921 L F
.30605 .67183 m .30871 .67151 L .3064 .66921 L F
.532 .716 .957 r
.60844 .39231 m .60724 .39604 L .60585 .3933 L F
.875 .668 .62 r
.56892 .4403 m .5725 .43807 L .5709 .43658 L F
.56892 .4403 m .57218 .44073 L .5725 .43807 L F
.894 .81 .759 r
.5725 .43807 m .57172 .43429 L .5709 .43658 L F
.865 .81 .793 r
.48668 .53384 m .48925 .53428 L .48878 .52987 L F
.553 .287 .467 r
.48716 .53705 m .48925 .53428 L .48668 .53384 L F
.48716 .53705 m .48984 .53634 L .48925 .53428 L F
.931 .866 .752 r
.48716 .53705 m .48925 .53428 L .48984 .53634 L F
.596 .85 .495 r
.39202 .49413 m .39057 .49572 L .38929 .49748 L F
0 0 .387 r
.38929 .49748 m .39057 .49572 L .39028 .49291 L F
0 .09 .648 r
.41093 .59655 m .41246 .59724 L .4093 .59548 L F
.41093 .59655 m .41324 .59905 L .41246 .59724 L F
.955 .769 .613 r
.39256 .57064 m .38988 .57194 L .39011 .56918 L F
.39256 .57064 m .39178 .57313 L .38988 .57194 L F
.058 0 .219 r
.56876 .41144 m .56978 .4087 L .57139 .40714 L F
.897 .717 .651 r
.6714 .33902 m .6678 .34089 L .66926 .33784 L F
.6714 .33902 m .67077 .34165 L .6678 .34089 L F
.789 .803 .864 r
.35595 .61351 m .35999 .61347 L .3582 .61188 L F
.871 .773 .751 r
.35999 .61347 m .35871 .60976 L .3582 .61188 L F
0 .217 .656 r
.49661 .44924 m .4996 .45124 L .49986 .45122 L F
.234 0 .313 r
.29659 .56609 m .29395 .56944 L .29466 .56701 L F
.29659 .56609 m .29395 .56944 L .29466 .56701 L F
.542 .405 .644 r
.32869 .59943 m .32897 .60307 L .32657 .60347 L F
.382 0 0 r
.32096 .547 m .32003 .54791 L .31646 .54721 L F
0 0 .214 r
.32096 .547 m .32142 .54956 L .32155 .54795 L F
.32096 .547 m .32155 .54795 L .32003 .54791 L F
.259 .101 .468 r
.24642 .53969 m .24832 .53618 L .24664 .53709 L F
.036 .603 .774 r
.63977 .39759 m .64235 .39767 L .63829 .39742 L F
.489 0 0 r
.41324 .59905 m .4149 .60016 L .41736 .60217 L F
.996 .764 .456 r
.5847 .39367 m .58607 .3947 L .58561 .39796 L F
.845 .45 0 r
.28335 .64868 m .28461 .65176 L .28249 .64814 L F
.91 .589 .425 r
.41494 .53888 m .41775 .53714 L .41592 .5354 L F
.41494 .53888 m .41805 .54006 L .41775 .53714 L F
.413 .248 .547 r
.29765 .57996 m .29742 .58302 L .29943 .58232 L F
.29765 .57996 m .29742 .58302 L .29943 .58232 L F
.506 .875 .981 r
.5552 .38827 m .55543 .38326 L .5575 .38473 L F
.5552 .38827 m .55692 .38727 L .55543 .38326 L F
.5552 .38827 m .55248 .3878 L .55692 .38727 L F
.918 .906 .796 r
.56506 .45694 m .56641 .45503 L .56512 .45364 L F
.913 .83 .75 r
.56641 .45503 m .56652 .45026 L .56512 .45364 L F
.488 .823 .528 r
.65745 .3851 m .66005 .38271 L .65944 .38506 L F
.349 0 0 r
.66005 .38271 m .66251 .38349 L .65944 .38506 L F
.742 .768 .874 r
.65944 .38506 m .66251 .38349 L .65841 .38295 L F
.793 .515 .516 r
.65841 .38295 m .66122 .38503 L .65944 .38506 L F
.66122 .38503 m .66275 .38616 L .65944 .38506 L F
.488 .823 .528 r
.65682 .38568 m .65745 .3851 L .65944 .38506 L F
.886 .746 .702 r
.36385 .57904 m .36611 .58004 L .36457 .57623 L F
.835 .688 .7 r
.36385 .57904 m .36585 .58287 L .36611 .58004 L F
.832 .964 .892 r
.55963 .46068 m .56404 .45847 L .56128 .45871 L F
.891 .911 .833 r
.56128 .45871 m .56404 .45847 L .56506 .45694 L F
.971 .727 .511 r
.34776 .52564 m .34958 .52989 L .35013 .52718 L F
.755 .854 .924 r
.42282 .46153 m .42442 .45749 L .42094 .45966 L F
.42282 .46153 m .42498 .45985 L .42442 .45749 L F
.863 .775 .763 r
.32745 .59326 m .32847 .59655 L .32625 .5954 L F
.866 .96 .863 r
.32847 .59655 m .32428 .59894 L .32625 .5954 L F
.743 .714 .824 r
.33152 .59396 m .32847 .59655 L .32745 .59326 L F
.681 .593 .751 r
.33159 .59585 m .32847 .59655 L .33152 .59396 L F
.628 .483 .666 r
.33276 .59817 m .32847 .59655 L .33159 .59585 L F
.33276 .59817 m .32869 .59943 L .32847 .59655 L F
.544 .816 .996 r
.30197 .67159 m .30393 .67278 L .30605 .67183 L F
0 .084 .644 r
.30393 .67278 m .30609 .67509 L .30605 .67183 L F
.714 .838 .941 r
.25486 .59872 m .25725 .60037 L .25703 .59826 L F
.628 .234 .277 r
.43984 .56483 m .44362 .56188 L .44168 .56381 L F
.865 .757 .741 r
.35575 .55615 m .35769 .55688 L .35648 .55329 L F
.848 .621 .594 r
.35575 .55615 m .35757 .55964 L .35769 .55688 L F
0 .161 .686 r
.5691 .37085 m .57041 .37304 L .56965 .37485 L F
0 0 .392 r
.5707 .3756 m .56965 .37485 L .57041 .37304 L F
0 0 .278 r
.57091 .37308 m .5709 .37332 L .5707 .3756 L F
0 0 .392 r
.5707 .3756 m .57074 .3777 L .57056 .37724 L F
0 0 .278 r
.5709 .37332 m .57061 .37788 L .5707 .3756 L F
0 0 .392 r
.5707 .3756 m .57056 .37724 L .56965 .37485 L F
.736 .698 .816 r
.57811 .35505 m .57606 .35692 L .57408 .35425 L F
.429 .354 .67 r
.51587 .41443 m .51784 .41559 L .51788 .4138 L F
.51587 .41443 m .51609 .41706 L .51784 .41559 L F
.717 .977 .919 r
.63732 .34679 m .63733 .34764 L .64138 .34526 L F
.02 0 0 r
.4351 .45491 m .4374 .45387 L .43347 .45641 L F
.606 .948 .923 r
.4216 .45157 m .42623 .45026 L .42396 .45145 L F
.617 .904 .985 r
.53159 .4684 m .52965 .46781 L .53215 .46692 L F
.506 0 0 r
.53215 .46692 m .53095 .46808 L .5316 .46811 L F
.678 .773 .294 r
.53159 .4684 m .53215 .46692 L .5326 .46594 L F
.506 0 0 r
.53215 .46692 m .5316 .46811 L .53475 .46825 L F
.678 .773 .294 r
.5326 .46594 m .53215 .46692 L .53329 .46426 L F
.773 .412 .373 r
.53329 .46426 m .5341 .46654 L .53643 .46401 L F
.53329 .46426 m .53215 .46692 L .5341 .46654 L F
.452 0 .016 r
.38082 .46167 m .38275 .46272 L .38477 .46086 L F
.731 .305 .237 r
.38477 .46086 m .38275 .46272 L .38662 .4623 L F
.457 .218 .462 r
.38662 .4623 m .38733 .46087 L .38477 .46086 L F
.915 .877 .784 r
.45565 .59367 m .46063 .58932 L .45929 .58795 L F
.777 .946 .932 r
.46063 .58932 m .46117 .58743 L .45929 .58795 L F
.46063 .58932 m .46371 .58709 L .46117 .58743 L F
.942 .885 .748 r
.53065 .47007 m .52965 .46781 L .53159 .4684 L F
.53065 .47007 m .52787 .46935 L .52965 .46781 L F
.552 .872 .591 r
.53065 .47007 m .52719 .47307 L .52787 .46935 L F
.53065 .47007 m .52762 .4728 L .52719 .47307 L F
.393 .797 .983 r
.29559 .64873 m .29521 .64981 L .29382 .64811 L F
.29559 .64873 m .29779 .64946 L .29521 .64981 L F
.596 .15 .161 r
.44531 .58216 m .44402 .58486 L .44205 .58273 L F
.354 .076 .346 r
.44814 .57965 m .44769 .58255 L .44531 .58216 L F
.815 .619 .637 r
.44769 .58255 m .44402 .58486 L .44531 .58216 L F
.783 .358 .242 r
.58435 .43054 m .58314 .43268 L .58319 .4299 L F
.927 .77 .292 r
.58612 .42969 m .58656 .42725 L .58435 .43054 L F
.58612 .42969 m .58435 .43054 L .58319 .4299 L F
.341 .03 .285 r
.33444 .67226 m .33589 .67467 L .33337 .67518 L F
.33444 .67226 m .3369 .67157 L .33589 .67467 L F
.629 .938 .706 r
.41025 .58954 m .40942 .59092 L .41179 .59185 L F
0 0 .403 r
.57074 .3777 m .57146 .38005 L .57064 .3802 L F
.742 .418 0 r
.57061 .37788 m .57146 .38005 L .57074 .3777 L F
0 .178 .707 r
.57244 .37987 m .57146 .38005 L .57061 .37788 L F
.57271 .38016 m .57146 .38005 L .57244 .37987 L F
0 0 .403 r
.57064 .3802 m .57146 .38005 L .57059 .38165 L F
0 .254 .76 r
.57146 .38005 m .57312 .38364 L .57059 .38165 L F
.845 .812 .818 r
.5341 .46654 m .53616 .46758 L .53643 .46401 L F
0 0 .529 r
.56943 .41624 m .57094 .42011 L .56946 .41781 L F
.084 .644 .735 r
.49929 .44524 m .50505 .44483 L .50353 .44485 L F
.347 .823 .8 r
.50353 .44485 m .50505 .44483 L .50759 .4439 L F
.878 .534 .395 r
.68756 .33512 m .68794 .33764 L .69125 .33861 L F
.863 .576 .5 r
.6879 .34023 m .69125 .33861 L .68794 .33764 L F
.6879 .34023 m .69122 .34127 L .69125 .33861 L F
.292 0 0 r
.33101 .58166 m .33039 .58217 L .32635 .58232 L F
.949 .624 .202 r
.33226 .58328 m .33114 .58149 L .33138 .58118 L F
.753 .604 .692 r
.33101 .58166 m .32635 .58232 L .3308 .58103 L F
.949 .624 .202 r
.33155 .58329 m .33095 .5833 L .3308 .58103 L F
.33155 .58329 m .3308 .58103 L .33071 .57957 L F
.292 0 0 r
.33051 .58232 m .32955 .58286 L .33101 .58166 L F
.753 .604 .692 r
.3308 .58103 m .32635 .58232 L .32675 .57912 L F
.3308 .58103 m .32675 .57912 L .33071 .57957 L F
.949 .624 .202 r
.33095 .5833 m .33074 .5833 L .33071 .57957 L F
.292 0 0 r
.33188 .58154 m .33051 .58232 L .33101 .58166 L F
.949 .624 .202 r
.33138 .58118 m .33114 .58149 L .33071 .57957 L F
.753 .604 .692 r
.33188 .58154 m .33101 .58166 L .3308 .58103 L F
.33188 .58154 m .3308 .58103 L .33071 .57957 L F
.829 .445 .325 r
.33071 .57957 m .33073 .58203 L .33188 .58154 L F
.949 .624 .202 r
.33226 .58328 m .33155 .58329 L .33114 .58149 L F
.829 .445 .325 r
.33073 .58203 m .33074 .5833 L .33188 .58154 L F
.292 0 0 r
.33039 .58217 m .32955 .58286 L .32899 .58277 L F
.33039 .58217 m .32899 .58277 L .32635 .58232 L F
.757 .244 0 r
.33449 .58587 m .33074 .5833 L .33226 .58328 L F
.741 .218 0 r
.33662 .5866 m .33449 .58587 L .33226 .58328 L F
.788 .987 .894 r
.68325 .36983 m .68725 .36802 L .68712 .36758 L F
.767 .997 .844 r
.68725 .36802 m .68854 .36559 L .68712 .36758 L F
.68725 .36802 m .69056 .3652 L .68854 .36559 L F
.461 0 .051 r
.61469 .34829 m .61083 .34967 L .61212 .35063 L F
.906 .497 .18 r
.36871 .5174 m .36748 .51858 L .36565 .51604 L F
.36871 .5174 m .36936 .51967 L .36748 .51858 L F
.966 .891 .703 r
.55829 .41285 m .55674 .41757 L .55545 .41635 L F
.55865 .41239 m .55846 .41292 L .55829 .41285 L F
.55846 .41292 m .55674 .41757 L .55829 .41285 L F
.719 .211 .021 r
.5544 .41089 m .55669 .41218 L .55552 .4116 L F
.966 .891 .703 r
.55865 .41239 m .55829 .41285 L .55854 .41322 L F
.55829 .41285 m .55545 .41635 L .55854 .41322 L F
.719 .211 .021 r
.55669 .41218 m .55854 .41322 L .55631 .41202 L F
.55669 .41218 m .55631 .41202 L .55552 .4116 L F
0 .208 .631 r
.55745 .41161 m .55865 .41239 L .55854 .41322 L F
.469 0 0 r
.55854 .41322 m .56264 .41371 L .55865 .41239 L F
.511 .886 .69 r
.64468 .343 m .64316 .34374 L .64138 .34526 L F
.306 0 0 r
.64721 .34179 m .64316 .34374 L .64468 .343 L F
0 .119 .619 r
.49529 .44796 m .49661 .44924 L .49654 .44874 L F
.42 .525 .858 r
.48835 .43279 m .48918 .43381 L .49133 .43337 L F
.482 0 0 r
.48918 .43381 m .49352 .43759 L .49133 .43337 L F
0 0 .197 r
.32977 .52685 m .33085 .52518 L .331 .52246 L F
.648 .952 .736 r
.32977 .52685 m .32762 .52844 L .33085 .52518 L F
.366 .133 .423 r
.34299 .65867 m .34127 .65611 L .34335 .65504 L F
.34296 .65898 m .34335 .65504 L .34247 .65649 L F
.576 .59 .83 r
.34495 .65662 m .34443 .65857 L .34247 .65649 L F
.34443 .65857 m .34376 .6611 L .34308 .65866 L F
.34443 .65857 m .34308 .65866 L .34247 .65649 L F
.366 .133 .423 r
.34296 .65898 m .34279 .65868 L .34299 .65867 L F
.34279 .65868 m .34127 .65611 L .34299 .65867 L F
.635 .248 .292 r
.66741 .33531 m .66567 .33743 L .66298 .33556 L F
.791 .45 .41 r
.66926 .33784 m .66567 .33743 L .66741 .33531 L F
.859 .557 .475 r
.60605 .38687 m .60558 .38499 L .60263 .38712 L F
.60605 .38687 m .60836 .38462 L .60558 .38499 L F
.534 .305 .514 r
.44053 .59275 m .44146 .59076 L .438 .59371 L F
.807 .706 .753 r
.36171 .59819 m .35924 .60225 L .36379 .60274 L F
.815 .658 .687 r
.35924 .60225 m .36105 .60613 L .36379 .60274 L F
.802 .704 .757 r
.36171 .59819 m .36379 .60274 L .36389 .60013 L F
.909 .908 .808 r
.65312 .39831 m .65419 .39344 L .65183 .39696 L F
.972 .669 .383 r
.39028 .49291 m .39057 .49572 L .39202 .49413 L F
.717 .977 .919 r
.63732 .34679 m .64138 .34526 L .6406 .34506 L F
.534 .917 .784 r
.64316 .34374 m .6406 .34506 L .64156 .34511 L F
.118 .67 .756 r
.64266 .34484 m .6406 .34506 L .64316 .34374 L F
.64266 .34484 m .64027 .34504 L .6406 .34506 L F
.64027 .34504 m .63904 .34514 L .6406 .34506 L F
.534 .917 .784 r
.64156 .34511 m .6406 .34506 L .64138 .34526 L F
.745 .711 .82 r
.32636 .63346 m .32716 .62863 L .32491 .63225 L F
.32636 .63346 m .32863 .63254 L .32716 .62863 L F
.602 .863 .992 r
.6503 .38529 m .64579 .38483 L .64888 .38417 L F
.598 .887 .991 r
.65296 .38416 m .6503 .38529 L .64888 .38417 L F
.761 .719 .813 r
.32716 .62863 m .32863 .63254 L .33138 .62914 L F
.624 .941 .954 r
.33728 .54308 m .33724 .54171 L .33835 .54234 L F
.33728 .54308 m .33567 .5427 L .33724 .54171 L F
.662 .363 .455 r
.3958 .50259 m .4005 .50086 L .3963 .50091 L F
.3958 .50259 m .3995 .50293 L .4005 .50086 L F
.731 .777 .283 r
.57601 .39953 m .57541 .40183 L .57669 .39794 L F
.919 .882 .461 r
.57431 .40286 m .57541 .40183 L .57601 .39953 L F
.57431 .40286 m .57453 .4042 L .57541 .40183 L F
.813 .839 .372 r
.50853 .43365 m .50964 .43072 L .50991 .42851 L F
0 0 .407 r
.51263 .4352 m .50964 .43072 L .50853 .43365 L F
.562 .414 .638 r
.2737 .53648 m .27346 .53954 L .27076 .53981 L F
.463 .284 .551 r
.27346 .53954 m .27114 .54273 L .27076 .53981 L F
.06 .62 .798 r
.28602 .67499 m .28999 .6753 L .28832 .67499 L F
.858 .916 .87 r
.28999 .6753 m .29097 .67124 L .29062 .67224 L F
.823 .994 .858 r
.28832 .67499 m .28999 .6753 L .29062 .67224 L F
.802 .967 .911 r
.50091 .50168 m .5015 .49918 L .50248 .49976 L F
.50091 .50168 m .49837 .50179 L .5015 .49918 L F
.949 .677 .486 r
.43821 .58872 m .44066 .59032 L .43908 .58628 L F
.43813 .58893 m .4385 .58913 L .43821 .58872 L F
.4385 .58913 m .44066 .59032 L .43821 .58872 L F
.44066 .59032 m .44121 .59028 L .43908 .58628 L F
.926 .787 .688 r
.43933 .59061 m .44066 .59032 L .4385 .58913 L F
.829 .785 .81 r
.4397 .5904 m .4391 .59065 L .43942 .59042 L F
.926 .787 .688 r
.44053 .59275 m .43886 .59008 L .43904 .59068 L F
.668 .673 .846 r
.43884 .59006 m .43886 .59008 L .43904 .59068 L F
.926 .787 .688 r
.43884 .59006 m .4385 .58913 L .43813 .58893 L F
.896 .789 .735 r
.4383 .58837 m .43884 .59006 L .43813 .58893 L F
.43884 .59006 m .43904 .59068 L .43813 .58893 L F
.926 .787 .688 r
.43886 .59008 m .43884 .59006 L .43813 .58893 L F
.43886 .59008 m .43813 .58893 L .43904 .59068 L F
.668 .673 .846 r
.43886 .59008 m .43907 .59066 L .43904 .59068 L F
.829 .785 .81 r
.4391 .59065 m .43904 .59068 L .43907 .59066 L F
.926 .787 .688 r
.44053 .59275 m .4385 .58913 L .43886 .59008 L F
.829 .785 .81 r
.4391 .59065 m .43907 .59066 L .43942 .59042 L F
.926 .787 .688 r
.44053 .59275 m .44146 .59076 L .44066 .59032 L F
.44053 .59275 m .44066 .59032 L .43933 .59061 L F
.668 .673 .846 r
.43859 .58925 m .43942 .59042 L .43907 .59066 L F
.43859 .58925 m .43907 .59066 L .43884 .59006 L F
.4383 .58837 m .44181 .58876 L .43942 .59042 L F
.4383 .58837 m .43942 .59042 L .43859 .58925 L F
.829 .785 .81 r
.44331 .58884 m .4397 .5904 L .44181 .58876 L F
.4397 .5904 m .43942 .59042 L .44181 .58876 L F
.949 .677 .486 r
.44066 .59032 m .44146 .59076 L .44121 .59028 L F
.143 0 .274 r
.44331 .58884 m .44146 .59076 L .44053 .59275 L F
.261 .589 .947 r
.28836 .52358 m .28877 .52189 L .28672 .5217 L F
.28672 .5217 m .28877 .52189 L .28836 .52358 L F
0 0 0 r
.64291 .3358 m .64435 .33598 L .64557 .33483 L F
.64291 .3358 m .64173 .33695 L .64435 .33598 L F
0 0 .542 r
.57312 .38364 m .57485 .38647 L .57407 .3854 L F
.942 .643 .445 r
.41342 .52635 m .41425 .52999 L .41641 .53089 L F
.884 .536 .385 r
.41425 .52999 m .41708 .53302 L .41641 .53089 L F
.621 .633 .841 r
.33688 .62512 m .3383 .62907 L .34067 .62618 L F
.591 .103 .064 r
.42352 .6058 m .42733 .60595 L .4258 .60722 L F
.286 0 0 r
.42733 .60595 m .4281 .60714 L .4258 .60722 L F
.42733 .60595 m .42932 .60581 L .4281 .60714 L F
.217 0 0 r
.31646 .54721 m .31497 .54521 L .31421 .54778 L F
0 .176 .618 r
.41912 .60307 m .41949 .6032 L .41736 .60217 L F
.556 0 0 r
.41912 .60307 m .42352 .6058 L .4218 .60485 L F
0 .176 .618 r
.41912 .60307 m .4218 .60485 L .41949 .6032 L F
0 0 .002 r
.26014 .55385 m .25922 .55599 L .25795 .55675 L F
.321 0 .17 r
.26274 .55345 m .25922 .55599 L .26014 .55385 L F
.874 .498 .33 r
.4237 .54661 m .42195 .54834 L .42581 .54831 L F
.942 .778 .649 r
.42195 .54834 m .42291 .55211 L .42581 .54831 L F
.933 .902 .771 r
.50058 .42471 m .50077 .42085 L .50217 .42239 L F
.518 .72 .964 r
.50217 .42239 m .50323 .42438 L .50058 .42471 L F
.661 .631 .809 r
.48984 .53634 m .48637 .53911 L .48716 .53705 L F
.48716 .53705 m .48637 .53911 L .48984 .53634 L F
0 0 0 r
.51609 .41706 m .51421 .41882 L .51442 .41875 L F
.51462 .4187 m .51442 .41875 L .51393 .41883 L F
.51669 .4183 m .51833 .41739 L .51442 .41875 L F
.51669 .4183 m .51442 .41875 L .51462 .4187 L F
.51421 .41882 m .51251 .4204 L .51442 .41875 L F
.586 .279 .415 r
.51442 .41875 m .51784 .41559 L .51609 .41706 L F
.684 .94 .963 r
.67424 .37577 m .67621 .37637 L .67875 .37485 L F
.67 .958 .944 r
.49337 .40805 m .48861 .4093 L .49244 .40787 L F
.534 .923 .895 r
.49337 .40805 m .49244 .40787 L .4949 .40661 L F
.11 .663 .787 r
.3331 .55973 m .32888 .55982 L .33058 .56012 L F
.3331 .55973 m .32888 .55982 L .33058 .56012 L F
.922 .728 .622 r
.34554 .5859 m .34131 .58819 L .3415 .58653 L F
.34554 .5859 m .34348 .58945 L .34131 .58819 L F
.876 .541 .412 r
.34456 .51966 m .34944 .52345 L .34704 .52011 L F
.873 .586 .5 r
.46747 .57253 m .47127 .57642 L .4722 .5738 L F
.278 .21 .599 r
.59453 .35352 m .59527 .35709 L .59267 .35849 L F
.019 0 .269 r
.59442 .35931 m .59267 .35849 L .59527 .35709 L F
.918 .906 .796 r
.56506 .45694 m .56512 .45364 L .56382 .45588 L F
.891 .911 .833 r
.56128 .45871 m .56506 .45694 L .56382 .45588 L F
.763 .274 0 r
.57271 .42212 m .57274 .42095 L .57094 .42011 L F
.57271 .42212 m .5744 .42335 L .57274 .42095 L F
.861 .923 .868 r
.46404 .54321 m .46134 .54619 L .45998 .545 L F
.802 .883 .904 r
.46134 .54619 m .45777 .54655 L .45998 .545 L F
0 0 .258 r
.61975 .36859 m .62055 .36805 L .62071 .36778 L F
.563 .403 .622 r
.60034 .37111 m .59874 .37421 L .59947 .37458 L F
.761 .484 .513 r
.37406 .49686 m .37827 .50008 L .37827 .49736 L F
.307 .128 .468 r
.24812 .53362 m .25023 .53502 L .25052 .53195 L F
.24812 .53362 m .24832 .53618 L .25023 .53502 L F
.23 .474 .884 r
.30692 .6262 m .30781 .62447 L .30533 .62512 L F
.30692 .6262 m .31021 .62819 L .30781 .62447 L F
.936 .915 .535 r
.68986 .34878 m .69092 .34354 L .69019 .34724 L F
.695 .461 0 r
.69005 .34978 m .68986 .34878 L .69019 .34724 L F
.69005 .34978 m .69034 .35131 L .68986 .34878 L F
.869 .517 .016 r
.6943 .35757 m .69302 .35438 L .69342 .35639 L F
.973 .912 .575 r
.69243 .3607 m .6943 .35757 L .69342 .35639 L F
.69243 .3607 m .69314 .36176 L .6943 .35757 L F
.55 .814 .995 r
.59003 .44145 m .59145 .4392 L .58872 .44012 L F
.467 .269 .527 r
.59292 .43775 m .59288 .44061 L .59003 .44145 L F
.55 .814 .995 r
.59003 .44145 m .59288 .44061 L .59145 .4392 L F
.731 .777 .283 r
.57601 .39953 m .57669 .39794 L .57662 .39702 L F
.948 .702 .531 r
.34908 .50169 m .34761 .49896 L .35059 .50027 L F
.629 .451 .622 r
.45408 .57265 m .45656 .57341 L .45656 .56992 L F
.499 .344 .601 r
.45656 .56992 m .45553 .56642 L .45459 .56814 L F
.45656 .56992 m .45898 .56652 L .45553 .56642 L F
.45656 .56992 m .45914 .56937 L .45898 .56652 L F
.674 .567 .727 r
.45656 .57341 m .45914 .56937 L .45656 .56992 L F
.63 .649 .85 r
.59009 .34583 m .59506 .3474 L .59282 .3449 L F
.927 .574 .139 r
.58052 .37806 m .57922 .37676 L .57855 .37422 L F
0 0 .347 r
.58052 .37806 m .58115 .3787 L .57922 .37676 L F
.58052 .37806 m .58154 .38005 L .58115 .3787 L F
.639 .951 .748 r
.45701 .43351 m .455 .43526 L .45311 .43612 L F
.804 .557 .566 r
.464 .56301 m .46608 .56641 L .46618 .56344 L F
.534 .546 .814 r
.2615 .55996 m .25834 .5571 L .25966 .55884 L F
.25834 .5571 m .25795 .55675 L .25966 .55884 L F
.319 .095 .408 r
.26189 .5598 m .2611 .56072 L .25966 .55884 L F
.2611 .56072 m .2591 .56304 L .25966 .55884 L F
.169 .135 .574 r
.25922 .55599 m .25966 .55884 L .25795 .55675 L F
.896 .983 .801 r
.69056 .3652 m .69243 .3607 L .69014 .36424 L F
.69056 .3652 m .69314 .36176 L .69243 .3607 L F
.795 .999 .838 r
.68854 .36559 m .69056 .3652 L .69014 .36424 L F
.95 .721 .556 r
.3819 .53971 m .38037 .53935 L .38066 .5367 L F
.933 .595 .371 r
.38264 .54256 m .38037 .53935 L .3819 .53971 L F
.879 .615 .535 r
.39882 .51329 m .39871 .51601 L .40152 .51536 L F
.59 .023 0 r
.39871 .51601 m .40311 .51733 L .40152 .51536 L F
.634 .793 .959 r
.48476 .43203 m .48835 .43279 L .48698 .43071 L F
.402 .539 .879 r
.48835 .43279 m .4896 .43 L .48698 .43071 L F
.48835 .43279 m .49133 .43337 L .4896 .43 L F
.429 .818 .587 r
.43714 .60034 m .43832 .59952 L .44042 .59797 L F
.72 .988 .834 r
.61499 .38162 m .61112 .38403 L .61404 .3835 L F
.193 0 0 r
.61768 .3807 m .61499 .38162 L .61404 .3835 L F
.855 .881 .447 r
.27001 .60871 m .26972 .61026 L .26877 .61234 L F
.26877 .61234 m .26972 .61026 L .27001 .60871 L F
.749 .983 .909 r
.53954 .4219 m .54159 .42177 L .54268 .42034 L F
.757 .272 0 r
.41263 .58691 m .41113 .58581 L .40955 .58342 L F
.839 .707 .175 r
.3245 .51715 m .32417 .51558 L .32449 .51407 L F
0 .05 .611 r
.32494 .51983 m .32546 .5179 L .32417 .51558 L F
.893 .475 .183 r
.32417 .51558 m .32546 .5179 L .324 .5164 L F
.32417 .51558 m .324 .5164 L .32277 .51512 L F
.839 .707 .175 r
.32449 .51407 m .32417 .51558 L .32449 .51318 L F
.926 .761 .658 r
.3517 .53602 m .35312 .53995 L .35387 .53719 L F
.647 .328 .419 r
.44814 .57965 m .45111 .58219 L .44769 .58255 L F
.874 .567 .465 r
.59681 .34866 m .59282 .3449 L .59506 .3474 L F
.376 .35 .703 r
.24096 .56033 m .24362 .56241 L .24269 .55981 L F
.359 .35 .713 r
.24096 .56033 m .24191 .56332 L .24362 .56241 L F
.557 .931 .912 r
.58761 .35076 m .5887 .34924 L .5909 .34953 L F
.797 .975 .907 r
.5909 .34953 m .5887 .34924 L .59196 .34661 L F
.703 .983 .821 r
.5887 .34924 m .59005 .34712 L .59196 .34661 L F
0 0 0 r
.5887 .34924 m .58818 .3508 L .58964 .34792 L F
.5887 .34924 m .58964 .34792 L .59005 .34712 L F
.557 .931 .912 r
.58751 .3508 m .5887 .34924 L .58761 .35076 L F
.58751 .3508 m .58629 .35051 L .5887 .34924 L F
0 0 .346 r
.57312 .36189 m .57283 .35876 L .57203 .35769 L F
0 0 .298 r
.57311 .3621 m .57283 .35876 L .57312 .36189 L F
.57302 .36429 m .57293 .36173 L .57311 .3621 L F
.57293 .36173 m .57283 .35876 L .57311 .3621 L F
.57302 .36429 m .57337 .36265 L .57283 .35876 L F
.984 .747 .348 r
.57283 .35876 m .57337 .36265 L .57257 .36096 L F
.597 .146 0 r
.57337 .36265 m .57351 .36294 L .5727 .36124 L F
.57273 .36131 m .5727 .36124 L .57257 .36096 L F
.57337 .36265 m .5727 .36124 L .57273 .36131 L F
.873 .501 .339 r
.3784 .53047 m .37644 .53194 L .37526 .52926 L F
.3784 .53047 m .37895 .53284 L .37644 .53194 L F
.566 .806 .989 r
.6107 .36192 m .60662 .36124 L .60946 .36066 L F
.6107 .36192 m .60662 .36124 L .60946 .36066 L F
.627 .567 .768 r
.32494 .51983 m .32596 .52378 L .32888 .52264 L F
.633 .1 0 r
.61664 .3875 m .61948 .38912 L .61793 .38929 L F
.793 .946 .923 r
.64736 .37504 m .64479 .37764 L .64343 .37627 L F
.124 .309 .779 r
.64479 .37764 m .64614 .37543 L .64343 .37627 L F
.634 .605 .803 r
.64736 .37504 m .64866 .37804 L .64479 .37764 L F
.804 .543 .543 r
.64866 .37804 m .64736 .37986 L .64479 .37764 L F
.124 .309 .779 r
.64479 .37764 m .64736 .37986 L .64614 .37543 L F
.688 .961 .723 r
.52156 .4748 m .51881 .47748 L .52 .47554 L F
.037 0 .417 r
.51881 .47748 m .52062 .4785 L .52 .47554 L F
.801 .498 .477 r
.52298 .48072 m .51904 .48018 L .51881 .47748 L F
.037 0 .417 r
.51881 .47748 m .51904 .48018 L .52062 .4785 L F
.683 .684 .845 r
.31126 .64903 m .31288 .65265 L .30883 .65171 L F
.678 .668 .832 r
.31351 .64812 m .31288 .65265 L .31126 .64903 L F
.31351 .64812 m .31497 .65193 L .31288 .65265 L F
.603 .398 .576 r
.65612 .37691 m .65841 .3754 L .65516 .37808 L F
.513 .841 .998 r
.33155 .55333 m .33582 .55353 L .33411 .55255 L F
.33155 .55333 m .33582 .55353 L .33411 .55255 L F
.816 .923 .907 r
.33899 .55053 m .33582 .55353 L .33411 .55255 L F
0 .379 .839 r
.33582 .55353 m .33564 .55212 L .33411 .55255 L F
.33582 .55353 m .33932 .55539 L .33564 .55212 L F
.513 .841 .998 r
.33411 .55255 m .33582 .55353 L .33155 .55333 L F
.755 .689 .788 r
.33412 .59582 m .33276 .59817 L .33159 .59585 L F
.861 .931 .87 r
.59256 .43426 m .59447 .43034 L .59483 .43255 L F
.014 .071 .577 r
.59516 .43379 m .59256 .43426 L .59483 .43255 L F
.59516 .43379 m .5946 .43626 L .59256 .43426 L F
.742 .222 0 r
.57485 .38647 m .57757 .38934 L .57907 .38892 L F
.981 .906 .586 r
.57757 .38934 m .57809 .3909 L .57907 .38892 L F
.797 .408 .318 r
.36075 .49395 m .35731 .49332 L .35621 .49125 L F
.818 .769 .807 r
.32158 .61597 m .31931 .61908 L .3171 .61787 L F
.403 .246 .552 r
.27114 .54273 m .27099 .5472 L .26871 .54726 L F
.334 .266 .63 r
.27105 .54866 m .26871 .54726 L .27099 .5472 L F
.27105 .54866 m .26921 .54968 L .26871 .54726 L F
.732 .983 .771 r
.46647 .42742 m .46274 .43018 L .4647 .42886 L F
.378 .808 .635 r
.46808 .42642 m .46985 .42546 L .46647 .42742 L F
0 0 0 r
.4647 .42886 m .46808 .42642 L .46647 .42742 L F
.726 .266 .157 r
.45285 .57464 m .45408 .57265 L .45197 .57281 L F
.45285 .57464 m .45649 .57525 L .45408 .57265 L F
.648 .296 .361 r
.45649 .57525 m .45656 .57341 L .45408 .57265 L F
.859 .922 .87 r
.50077 .42085 m .50589 .41796 L .50488 .41718 L F
.525 .881 .982 r
.50488 .41718 m .50589 .41796 L .50839 .41708 L F
.187 .712 .861 r
.30785 .60618 m .30954 .60647 L .30955 .606 L F
.552 .701 .938 r
.5597 .38111 m .56278 .38231 L .56251 .38043 L F
0 0 .47 r
.56278 .38231 m .56306 .38204 L .56251 .38043 L F
.56278 .38231 m .56423 .38475 L .56306 .38204 L F
.137 .683 .799 r
.4278 .45755 m .43181 .45741 L .43074 .4573 L F
.538 .924 .826 r
.43347 .45641 m .43315 .45605 L .43181 .45741 L F
.529 .921 .884 r
.43181 .45741 m .43315 .45605 L .43074 .4573 L F
.982 .906 .592 r
.54193 .47266 m .54178 .46868 L .54292 .47166 L F
.101 .636 .861 r
.54965 .3541 m .54562 .35347 L .54745 .35405 L F
.54965 .3541 m .54562 .35347 L .54745 .35405 L F
.874 .567 .465 r
.59681 .34866 m .59316 .34761 L .59282 .3449 L F
.669 .34 .408 r
.59681 .34866 m .593 .35027 L .59316 .34761 L F
.59681 .34866 m .59697 .35085 L .593 .35027 L F
.723 .382 .401 r
.60048 .35104 m .59697 .35085 L .59681 .34866 L F
.483 .285 .534 r
.33276 .59817 m .32897 .60307 L .32869 .59943 L F
.833 .422 .264 r
.36127 .51025 m .35886 .50996 L .35722 .50707 L F
.841 .441 .286 r
.36127 .51025 m .35932 .51187 L .35886 .50996 L F
.72 .264 .168 r
.36127 .51025 m .36342 .51262 L .35932 .51187 L F
.401 .011 .181 r
.32817 .67585 m .32995 .67732 L .32652 .67853 L F
.32817 .67585 m .33078 .67551 L .32995 .67732 L F
.772 .997 .843 r
.55207 .45949 m .55009 .46135 L .55107 .45908 L F
.761 .992 .879 r
.55009 .46135 m .54755 .46179 L .55107 .45908 L F
.591 .671 .895 r
.664 .38757 m .66111 .38848 L .65944 .38506 L F
.474 .873 .962 r
.66012 .38791 m .66111 .38848 L .664 .38757 L F
.701 .932 .616 r
.34493 .57711 m .34218 .58036 L .34308 .57862 L F
.997 .789 .498 r
.34493 .57711 m .34326 .57493 L .34572 .57506 L F
.34493 .57711 m .34308 .57862 L .34326 .57493 L F
.887 .688 .629 r
.35724 .56522 m .36108 .56308 L .35736 .56254 L F
.35724 .56522 m .3595 .56643 L .36108 .56308 L F
.811 .383 .23 r
.45342 .54025 m .45181 .54184 L .4504 .53949 L F
.782 .774 .846 r
.45359 .53852 m .45637 .53715 L .45342 .54025 L F
.663 .934 .657 r
.45342 .54025 m .45637 .53715 L .4546 .53844 L F
.421 .202 .473 r
.4546 .53844 m .45181 .54184 L .45342 .54025 L F
.811 .915 .909 r
.49678 .52015 m .50019 .51939 L .49894 .51821 L F
.801 .888 .908 r
.49894 .51821 m .50019 .51939 L .5032 .51691 L F
.802 .571 .588 r
.38524 .49646 m .385 .49981 L .38938 .49859 L F
.59 .612 .843 r
.3208 .62919 m .32491 .63225 L .32551 .63043 L F
.863 .938 .869 r
.32551 .63043 m .32491 .63225 L .32716 .62863 L F
.146 .19 .65 r
.24101 .57294 m .24281 .57462 L .2418 .57258 L F
.898 .681 .601 r
.38877 .55659 m .38701 .55634 L .38733 .55324 L F
.928 .547 .244 r
.38925 .55955 m .38701 .55634 L .38877 .55659 L F
.434 0 .078 r
.3966 .45995 m .39932 .4599 L .40097 .45773 L F
.317 0 .01 r
.40097 .45773 m .40377 .4583 L .40366 .45726 L F
.40097 .45773 m .39932 .4599 L .40377 .4583 L F
.603 .033 0 r
.35621 .49125 m .35537 .49168 L .35442 .49059 L F
.869 .857 .827 r
.35711 .48904 m .35621 .49125 L .35442 .49059 L F
.826 .369 0 r
.35621 .49125 m .35684 .49242 L .35537 .49168 L F
.107 .629 .882 r
.35537 .49168 m .35734 .4918 L .35466 .49132 L F
.829 .386 .178 r
.35537 .49168 m .35317 .49105 L .35281 .48989 L F
.107 .629 .882 r
.35537 .49168 m .35466 .49132 L .35317 .49105 L F
.826 .369 0 r
.35684 .49242 m .35731 .49332 L .35537 .49168 L F
0 0 .375 r
.35992 .49008 m .35621 .49125 L .35711 .48904 L F
.934 .703 .566 r
.39222 .58286 m .3903 .57858 L .39236 .57965 L F
.837 .99 .86 r
.52869 .49071 m .52472 .49299 L .52571 .49376 L F
.107 0 0 r
.30292 .6862 m .30647 .68536 L .30554 .68588 L F
.453 0 0 r
.30647 .68536 m .30721 .68699 L .30554 .68588 L F
.30647 .68536 m .3092 .68561 L .30721 .68699 L F
.727 .294 .222 r
.2846 .67131 m .28195 .66902 L .28171 .67186 L F
.797 .704 .762 r
.36171 .59819 m .36651 .59683 L .36455 .59532 L F
.36171 .59819 m .36389 .60013 L .36651 .59683 L F
.847 .709 .71 r
.36392 .58626 m .36317 .58893 L .36662 .58972 L F
.853 .644 .62 r
.36314 .59151 m .36662 .58972 L .36317 .58893 L F
.36314 .59151 m .36501 .59296 L .36662 .58972 L F
.354 .793 .627 r
.47225 .42411 m .46985 .42546 L .46808 .42642 L F
.732 .855 .939 r
.32587 .60588 m .32726 .60753 L .32339 .6069 L F
.107 0 0 r
.55329 .40169 m .5529 .40315 L .55622 .40074 L F
.805 .553 .558 r
.25306 .58519 m .24993 .58631 L .25083 .58338 L F
.423 .337 .654 r
.25185 .58832 m .24993 .58631 L .25306 .58519 L F
.01 0 .39 r
.25475 .58212 m .25462 .58517 L .25306 .58519 L F
.006 0 .063 r
.25462 .58517 m .25185 .58832 L .25306 .58519 L F
.408 .218 .508 r
.31049 .61844 m .30859 .61682 L .31079 .61563 L F
.514 .024 .03 r
.32152 .5037 m .31927 .50522 L .3235 .5049 L F
.513 .026 .036 r
.32152 .5037 m .3235 .5049 L .32455 .50404 L F
.806 .651 .689 r
.35459 .54941 m .35682 .55017 L .35465 .54651 L F
.827 .603 .6 r
.3525 .55226 m .35682 .55017 L .35459 .54941 L F
.3525 .55226 m .35648 .55329 L .35682 .55017 L F
.409 .154 .413 r
.52326 .41768 m .52591 .41468 L .52462 .41677 L F
.006 0 0 r
.52591 .41468 m .52492 .41631 L .52462 .41677 L F
.52591 .41468 m .52716 .4148 L .52492 .41631 L F
.52591 .41468 m .5287 .41412 L .52716 .4148 L F
.873 .586 .5 r
.46747 .57253 m .46792 .57623 L .47127 .57642 L F
.804 .618 .649 r
.46725 .57902 m .47127 .57642 L .46792 .57623 L F
.46725 .57902 m .47072 .57901 L .47127 .57642 L F
.988 .721 .374 r
.55674 .41757 m .55546 .41944 L .55545 .41635 L F
.55674 .41757 m .5569 .42116 L .55546 .41944 L F
.95 .856 .712 r
.5742 .4282 m .5744 .42335 L .57317 .42725 L F
.963 .862 .692 r
.57194 .42914 m .5742 .4282 L .57317 .42725 L F
.57194 .42914 m .57342 .43073 L .5742 .4282 L F
.117 0 0 r
.32315 .51045 m .31883 .51252 L .32081 .50968 L F
.32315 .51045 m .32121 .51204 L .31883 .51252 L F
.854 .47 .318 r
.32315 .51045 m .32449 .51318 L .32121 .51204 L F
.274 .37 .78 r
.28784 .67929 m .28841 .68214 L .28609 .67733 L F
.363 .623 .952 r
.28841 .68214 m .29019 .68156 L .28992 .67877 L F
.86 .535 .436 r
.34396 .52023 m .3444 .5173 L .34133 .51566 L F
.34396 .52023 m .34456 .51966 L .3444 .5173 L F
.921 .649 .507 r
.68229 .33058 m .68441 .33395 L .68597 .33186 L F
.204 .343 .783 r
.5946 .43626 m .59292 .43775 L .59149 .43381 L F
.991 .731 .401 r
.59145 .4392 m .59288 .44061 L .59292 .43775 L F
.59145 .4392 m .59292 .43775 L .5946 .43626 L F
.687 .98 .878 r
.46122 .44237 m .46337 .44209 L .46546 .44047 L F
0 0 0 r
.66251 .38349 m .66621 .38116 L .66535 .38056 L F
.619 .958 .889 r
.66621 .38116 m .66961 .37922 L .66779 .37927 L F
.6 .936 .95 r
.66535 .38056 m .66621 .38116 L .66779 .37927 L F
.008 0 0 r
.65169 .33108 m .6544 .32985 L .65501 .32895 L F
.307 0 .005 r
.6544 .32985 m .65786 .32826 L .65501 .32895 L F
.662 .626 .803 r
.25572 .57151 m .25295 .57106 L .25606 .56944 L F
.706 .831 .942 r
.62448 .39454 m .62057 .39435 L .62353 .39384 L F
.803 1 .831 r
.62552 .39198 m .62748 .39171 L .62448 .39454 L F
.774 .98 .91 r
.62552 .39198 m .62448 .39454 L .62353 .39384 L F
.37 .076 .33 r
.27614 .51731 m .27875 .51662 L .27939 .51416 L F
0 0 .167 r
.27939 .51416 m .27875 .51662 L .28031 .51504 L F
.672 .25 .235 r
.38223 .46813 m .3841 .46924 L .38175 .46939 L F
.986 .721 .347 r
.3841 .46924 m .38272 .46787 L .38254 .46909 L F
.3841 .46924 m .38295 .46956 L .38175 .46939 L F
.38295 .46956 m .38245 .4697 L .38188 .46945 L F
.38295 .46956 m .38188 .46945 L .38175 .46939 L F
.588 .195 .266 r
.38613 .46974 m .38413 .47231 L .3841 .46924 L F
.099 .256 .738 r
.38503 .46978 m .38413 .47231 L .38516 .46988 L F
.672 .25 .235 r
.38223 .46813 m .38484 .46921 L .3841 .46924 L F
.38484 .46921 m .38517 .46934 L .3841 .46924 L F
.986 .721 .347 r
.3841 .46924 m .38413 .47231 L .38317 .46928 L F
.3841 .46924 m .38317 .46928 L .38272 .46787 L F
.099 .256 .738 r
.38272 .46787 m .38327 .46959 L .38503 .46978 L F
.38327 .46959 m .38413 .47231 L .38503 .46978 L F
.986 .721 .347 r
.3841 .46924 m .38254 .46909 L .38245 .4697 L F
.672 .25 .235 r
.38517 .46934 m .38613 .46974 L .3841 .46924 L F
.776 .995 .871 r
.49942 .40526 m .50044 .40229 L .50125 .40324 L F
.49942 .40526 m .49706 .40508 L .50044 .40229 L F
.839 .471 .357 r
.35722 .50707 m .35509 .50881 L .35492 .50674 L F
.807 .421 .323 r
.35722 .50707 m .35886 .50996 L .35509 .50881 L F
.34 .815 .766 r
.31244 .61962 m .30787 .62107 L .31049 .61844 L F
.545 .821 .997 r
.31488 .61889 m .31244 .61962 L .31049 .61844 L F
.882 .783 .747 r
.55548 .44662 m .5501 .44926 L .55301 .44394 L F
.902 .763 .698 r
.5501 .44926 m .55147 .44893 L .5502 .44985 L F
.763 .566 .632 r
.55147 .44893 m .55074 .45006 L .5502 .44985 L F
.55074 .45006 m .54911 .4526 L .54958 .4514 L F
.55074 .45006 m .54958 .4514 L .5502 .44985 L F
.902 .763 .698 r
.55099 .44979 m .55328 .45116 L .55147 .44893 L F
.882 .783 .747 r
.55171 .44929 m .55328 .45116 L .55099 .44979 L F
.861 .436 0 r
.55328 .45116 m .5516 .44915 L .55147 .44893 L F
.882 .783 .747 r
.55548 .44662 m .55099 .44979 L .55104 .44975 L F
.55548 .44662 m .55098 .44979 L .55243 .44812 L F
.861 .436 0 r
.55328 .45116 m .55385 .45304 L .5516 .44915 L F
.882 .783 .747 r
.55548 .44662 m .55328 .45116 L .55171 .44929 L F
.763 .566 .632 r
.55147 .44893 m .5516 .44915 L .55099 .44979 L F
.882 .783 .747 r
.55104 .44975 m .55099 .44979 L .55098 .44979 L F
.763 .566 .632 r
.55099 .44979 m .55385 .45304 L .54942 .45263 L F
.5516 .44915 m .55385 .45304 L .55099 .44979 L F
.55147 .44893 m .54942 .45263 L .54911 .4526 L F
.902 .763 .698 r
.5501 .44926 m .55099 .44979 L .55147 .44893 L F
.882 .783 .747 r
.55243 .44812 m .55098 .44979 L .5501 .44926 L F
.811 .505 .472 r
.35878 .56905 m .36286 .57232 L .36251 .57025 L F
.925 .626 .458 r
.365 .493 m .36533 .49594 L .36731 .49419 L F
.566 .102 .112 r
.36731 .49419 m .36533 .49594 L .37 .49578 L F
.481 0 0 r
.36731 .49419 m .37 .49578 L .37194 .49626 L F
.927 .556 .286 r
.38722 .55272 m .38534 .55213 L .3858 .54976 L F
.38722 .55272 m .38733 .55324 L .38534 .55213 L F
.733 .493 .564 r
.67661 .31858 m .68054 .32159 L .68059 .31886 L F
.874 .865 .419 r
.28042 .61111 m .28034 .61367 L .27957 .61546 L F
.26 0 .22 r
.28285 .61265 m .28034 .61367 L .27957 .61546 L F
.17 .687 .889 r
.65979 .37098 m .66083 .37139 L .65653 .37091 L F
.489 .85 .602 r
.66423 .36869 m .66083 .37139 L .66313 .37038 L F
.549 .913 .956 r
.66313 .37038 m .66083 .37139 L .65979 .37098 L F
.485 .736 .982 r
.29231 .6465 m .29119 .64848 L .28912 .64558 L F
.29231 .6465 m .29382 .64811 L .29119 .64848 L F
.842 .761 .773 r
.46531 .55518 m .465 .56011 L .46693 .55648 L F
.827 .881 .883 r
.46531 .55518 m .46693 .55648 L .46995 .55345 L F
.339 .622 .956 r
.54892 .39516 m .54999 .39315 L .54735 .39366 L F
.54892 .39516 m .55135 .39539 L .54999 .39315 L F
.653 .762 .929 r
.57696 .353 m .57811 .35505 L .57408 .35425 L F
.655 .763 .929 r
.58049 .35418 m .57811 .35505 L .57696 .353 L F
.569 .566 .81 r
.5821 .35827 m .57811 .35505 L .58049 .35418 L F
0 0 0 r
.5104 .44337 m .51401 .44073 L .51261 .442 L F
.102 .059 .519 r
.51831 .43581 m .51626 .43664 L .51707 .43703 L F
.458 .634 .931 r
.51831 .43581 m .51707 .43703 L .51687 .43681 L F
0 0 .167 r
.51831 .43581 m .5175 .43638 L .51626 .43664 L F
.606 .658 .874 r
.51626 .43664 m .51672 .43688 L .51707 .43703 L F
0 0 .167 r
.51803 .43626 m .51672 .43688 L .51626 .43664 L F
.51672 .43688 m .51622 .43712 L .51626 .43664 L F
.606 .658 .874 r
.51626 .43664 m .51263 .4352 L .51672 .43688 L F
.458 .634 .931 r
.51831 .43581 m .51687 .43681 L .51365 .43351 L F
0 0 .167 r
.51831 .43581 m .51803 .43626 L .5175 .43638 L F
.318 .568 .928 r
.51687 .43681 m .51707 .43703 L .51672 .43688 L F
0 0 .167 r
.51803 .43626 m .51602 .43949 L .51622 .43712 L F
.318 .568 .928 r
.51682 .43676 m .51687 .43681 L .51666 .43686 L F
.51687 .43681 m .51672 .43688 L .51666 .43686 L F
.51365 .43351 m .51682 .43676 L .51263 .4352 L F
.51682 .43676 m .51666 .43686 L .51263 .4352 L F
.038 0 .256 r
.51401 .44073 m .51589 .43732 L .51602 .43949 L F
.51589 .43732 m .51626 .43664 L .51622 .43712 L F
.51589 .43732 m .51622 .43712 L .51602 .43949 L F
0 0 0 r
.51261 .442 m .51401 .44073 L .51602 .43949 L F
.978 .916 .66 r
.66343 .36698 m .66423 .36869 L .66313 .37038 L F
0 .189 .72 r
.28076 .64473 m .28024 .64616 L .28249 .64814 L F
.7 .892 .967 r
.66258 .39501 m .65862 .39532 L .66133 .39396 L F
.753 .99 .782 r
.66455 .39178 m .66258 .39501 L .66133 .39396 L F
.66455 .39178 m .66579 .39191 L .66258 .39501 L F
0 .467 .765 r
.63527 .34717 m .63353 .34648 L .63052 .34579 L F
.42 .819 .982 r
.63732 .34679 m .63353 .34648 L .63527 .34717 L F
.223 .739 .719 r
.43165 .44679 m .4351 .44587 L .43293 .44724 L F
.485 .9 .838 r
.6298 .39048 m .62748 .39171 L .62552 .39198 L F
.135 0 0 r
.32455 .50404 m .32686 .50367 L .3284 .50369 L F
.245 0 0 r
.32686 .50367 m .3309 .50348 L .3284 .50369 L F
.531 .882 .985 r
.53969 .41499 m .53607 .41518 L .53815 .41372 L F
0 .15 .693 r
.5412 .41516 m .53969 .41499 L .53815 .41372 L F
.5412 .41516 m .54206 .41743 L .53969 .41499 L F
.33 .803 .725 r
.64343 .38598 m .63957 .38742 L .64274 .38402 L F
.591 .794 .977 r
.64579 .38483 m .64343 .38598 L .64274 .38402 L F
.596 .023 0 r
.3309 .50348 m .33534 .50598 L .3347 .50421 L F
.614 .297 .41 r
.59945 .34372 m .60234 .344 L .60019 .3419 L F
.589 .747 .952 r
.60193 .39958 m .60353 .3967 L .60017 .39931 L F
.60193 .39958 m .6048 .39881 L .60353 .3967 L F
.518 .583 .859 r
.34356 .64431 m .34238 .64718 L .34108 .64561 L F
.34356 .64431 m .34549 .64759 L .34238 .64718 L F
.2 .029 .412 r
.24362 .56241 m .24191 .56332 L .24175 .56567 L F
.059 .136 .63 r
.58806 .37554 m .58656 .37847 L .58601 .37478 L F
.523 .719 .962 r
.58806 .37554 m .58987 .37825 L .58656 .37847 L F
.996 .842 .498 r
.59272 .39993 m .59206 .40307 L .59316 .40455 L F
.761 .383 0 r
.59308 .40543 m .59385 .40697 L .59316 .40455 L F
0 .036 .593 r
.53051 .43981 m .52934 .44081 L .5299 .43889 L F
0 0 .415 r
.5299 .43889 m .52934 .44081 L .53046 .44298 L F
.972 .883 .684 r
.55532 .45434 m .55294 .45559 L .55385 .45304 L F
.55532 .45434 m .55437 .45689 L .55294 .45559 L F
.766 .897 .935 r
.3327 .60578 m .3296 .60638 L .3322 .60546 L F
.868 .514 .014 r
.69342 .35639 m .69302 .35438 L .6922 .35387 L F
.027 .172 .68 r
.61415 .38714 m .61404 .3835 L .61112 .38403 L F
.61415 .38714 m .61512 .38694 L .61404 .3835 L F
0 0 0 r
.66313 .40038 m .6664 .39791 L .66504 .39895 L F
.6664 .39791 m .66763 .39321 L .66641 .39702 L F
.768 .948 .617 r
.66504 .39895 m .6664 .39791 L .66641 .39702 L F
.347 .603 .944 r
.28912 .64558 m .28719 .64566 L .28494 .64325 L F
.592 .732 .941 r
.54247 .39605 m .54333 .39274 L .54076 .39353 L F
.54247 .39605 m .54512 .39504 L .54333 .39274 L F
.876 .541 .412 r
.34456 .51966 m .34466 .52209 L .34944 .52345 L F
.886 .638 .558 r
.34466 .52209 m .34776 .52564 L .34944 .52345 L F
.548 .93 .858 r
.63212 .4006 m .63418 .39878 L .63156 .39994 L F
.63212 .4006 m .63589 .39873 L .63418 .39878 L F
.772 .786 .864 r
.34067 .62618 m .34501 .62643 L .34328 .62517 L F
.701 .718 .862 r
.34501 .62643 m .34604 .62177 L .34328 .62517 L F
.34501 .62643 m .34738 .62531 L .34604 .62177 L F
.427 0 .081 r
.40585 .45679 m .40986 .45592 L .4105 .45475 L F
.288 0 .018 r
.40986 .45592 m .41224 .45548 L .4105 .45475 L F
.295 0 0 r
.4105 .45475 m .41224 .45548 L .41307 .45434 L F
.516 .319 .552 r
.2577 .56001 m .2548 .56332 L .25467 .56 L F
.998 .832 .544 r
.25083 .58338 m .24755 .58392 L .25051 .58255 L F
.24755 .58392 m .24752 .58393 L .24756 .58391 L F
.24755 .58392 m .24756 .58391 L .25051 .58255 L F
.691 .277 .256 r
.24756 .58391 m .24778 .58386 L .25051 .58255 L F
.593 .483 .697 r
.24993 .58631 m .24976 .58918 L .2469 .58943 L F
.24993 .58631 m .24976 .58918 L .2469 .58943 L F
.423 .337 .654 r
.25185 .58832 m .24976 .58918 L .24993 .58631 L F
0 0 .036 r
.24993 .58631 m .24976 .58918 L .25009 .58719 L F
.24993 .58631 m .25009 .58719 L .24752 .58393 L F
0 0 .438 r
.24752 .58393 m .24923 .5861 L .24756 .58391 L F
.691 .277 .256 r
.24752 .58393 m .24756 .58391 L .24756 .58391 L F
0 0 .438 r
.24752 .58393 m .24756 .58391 L .24751 .58384 L F
.691 .277 .256 r
.24752 .58393 m .24757 .58391 L .24756 .58391 L F
.24757 .58391 m .24778 .58386 L .24756 .58391 L F
.734 .658 .775 r
.25078 .58013 m .24758 .58386 L .2493 .58062 L F
.506 .539 .825 r
.24756 .58391 m .24757 .58387 L .24751 .58384 L F
.308 .035 .326 r
.2493 .58062 m .24756 .58386 L .24751 .58384 L F
.506 .539 .825 r
.24757 .58387 m .24764 .58367 L .24751 .58384 L F
.308 .035 .326 r
.24756 .58386 m .24752 .58393 L .24751 .58384 L F
.734 .658 .775 r
.24758 .58386 m .24752 .58393 L .24756 .58386 L F
.24758 .58386 m .24756 .58386 L .2493 .58062 L F
.506 .539 .825 r
.24756 .58391 m .24758 .58386 L .24756 .58391 L F
.24758 .58386 m .24764 .58367 L .24757 .58386 L F
.24758 .58386 m .24757 .58386 L .24756 .58391 L F
.24923 .5861 m .24785 .58399 L .24756 .58391 L F
.874 .993 .762 r
.25083 .58338 m .25051 .58255 L .25168 .58199 L F
.691 .277 .256 r
.24967 .58295 m .25475 .58212 L .25051 .58255 L F
.24778 .58386 m .25063 .58315 L .24967 .58295 L F
.25063 .58315 m .25475 .58212 L .24967 .58295 L F
.874 .993 .762 r
.25168 .58199 m .25051 .58255 L .25214 .58125 L F
.583 .182 .248 r
.25214 .58125 m .25051 .58255 L .25475 .58212 L F
.998 .832 .544 r
.25083 .58338 m .24993 .58631 L .24752 .58393 L F
.691 .277 .256 r
.24752 .58393 m .25246 .5846 L .25475 .58212 L F
.236 .356 .783 r
.25373 .58235 m .25301 .58363 L .25078 .58013 L F
.25301 .58363 m .25246 .5846 L .25202 .58343 L F
.25301 .58363 m .25202 .58343 L .25078 .58013 L F
.734 .658 .775 r
.25078 .58013 m .25246 .5846 L .24759 .58394 L F
.506 .539 .825 r
.24759 .58392 m .24758 .58385 L .24756 .58391 L F
.734 .658 .775 r
.24758 .58386 m .24759 .58394 L .24752 .58393 L F
.25078 .58013 m .24759 .58394 L .24758 .58386 L F
.506 .539 .825 r
.24785 .58399 m .24764 .58367 L .24758 .58385 L F
.24785 .58399 m .24758 .58385 L .24759 .58392 L F
.24923 .5861 m .24917 .58163 L .24764 .58367 L F
.889 .824 .778 r
.44916 .56886 m .45269 .56872 L .45103 .56578 L F
.888 .647 .568 r
.45197 .57281 m .45269 .56872 L .44916 .56886 L F
.72 .717 .847 r
.45459 .56814 m .45103 .56578 L .45269 .56872 L F
.861 .923 .868 r
.46404 .54321 m .45998 .545 L .46254 .54201 L F
.886 .903 .834 r
.46681 .53978 m .46404 .54321 L .46254 .54201 L F
.804 .403 .292 r
.46681 .53978 m .46342 .53962 L .46484 .53955 L F
.886 .903 .834 r
.46681 .53978 m .46254 .54201 L .46342 .53962 L F
.81 .839 .873 r
.46681 .53978 m .46484 .53955 L .46786 .53528 L F
.788 .513 .521 r
.59668 .42442 m .59254 .42119 L .59182 .4243 L F
.639 .948 .95 r
.44561 .59408 m .44469 .59595 L .44764 .59436 L F
.712 .974 .751 r
.44248 .59708 m .44469 .59595 L .44561 .59408 L F
.71 .921 .964 r
.48147 .43377 m .4826 .43121 L .48032 .43316 L F
.48147 .43377 m .48476 .43203 L .4826 .43121 L F
.116 0 0 r
.65362 .33846 m .65253 .34 L .64988 .34084 L F
.445 .026 .149 r
.65638 .33764 m .65253 .34 L .65362 .33846 L F
.457 .218 .462 r
.38662 .4623 m .38733 .46365 L .38733 .46087 L F
.375 .001 .194 r
.38733 .46365 m .39229 .45987 L .38733 .46087 L F
.656 .191 .137 r
.66298 .33556 m .66567 .33743 L .66344 .33706 L F
.327 0 .097 r
.52566 .40339 m .52196 .40613 L .52378 .40466 L F
.857 .792 .786 r
.33929 .54563 m .34046 .54985 L .33899 .55053 L F
.803 .764 .818 r
.34167 .54711 m .34046 .54985 L .33929 .54563 L F
.894 .734 .677 r
.6678 .34089 m .67077 .34165 L .66934 .34446 L F
.952 .931 .74 r
.34817 .57144 m .34572 .57506 L .34586 .57247 L F
.375 .001 .194 r
.38733 .46365 m .38996 .4632 L .39229 .45987 L F
.189 0 0 r
.38996 .4632 m .394 .46022 L .39229 .45987 L F
.341 0 0 r
.62042 .38003 m .62339 .37978 L .62447 .37828 L F
.179 0 0 r
.62447 .37828 m .6261 .37898 L .62717 .37696 L F
.62447 .37828 m .62339 .37978 L .6261 .37898 L F
.43 .829 .619 r
.50495 .40078 m .50687 .39938 L .50856 .39833 L F
.434 .835 .634 r
.50495 .40078 m .50465 .40089 L .50687 .39938 L F
.758 .689 .785 r
.32969 .59179 m .33152 .59396 L .32745 .59326 L F
.01 .571 .805 r
.32969 .59179 m .33543 .59269 L .33152 .59396 L F
.671 .946 .959 r
.62996 .37934 m .62862 .38156 L .63132 .38061 L F
.62996 .37934 m .62735 .3806 L .62862 .38156 L F
.996 .848 .57 r
.56652 .45026 m .56726 .44755 L .56596 .4463 L F
.843 .939 .887 r
.56596 .4463 m .56726 .44755 L .57037 .44425 L F
.701 .918 .968 r
.32458 .5511 m .32164 .55158 L .32142 .54956 L F
.837 .99 .86 r
.52869 .49071 m .5258 .49114 L .52472 .49299 L F
.722 .975 .742 r
.52977 .48872 m .52869 .49071 L .53178 .4877 L F
.704 .982 .89 r
.52977 .48872 m .5258 .49114 L .52869 .49071 L F
.818 .769 .807 r
.32158 .61597 m .3171 .61787 L .31984 .61478 L F
.915 .765 .681 r
.56974 .43287 m .57342 .43073 L .57194 .42914 L F
.56974 .43287 m .57172 .43429 L .57342 .43073 L F
.866 .753 .735 r
.55692 .38727 m .55475 .391 L .55828 .39135 L F
.859 .778 .771 r
.55475 .391 m .55604 .39498 L .55828 .39135 L F
.274 0 .2 r
.34233 .66798 m .3432 .66598 L .34564 .66521 L F
0 0 .127 r
.25572 .57151 m .2559 .5752 L .2556 .57637 L F
.349 .168 .49 r
.25876 .56895 m .25572 .57151 L .25606 .56944 L F
.25876 .56895 m .25882 .57195 L .25572 .57151 L F
0 0 .104 r
.25621 .57278 m .25572 .57151 L .2585 .5719 L F
.884 .991 .758 r
.25822 .56988 m .2559 .5729 L .25621 .57278 L F
0 0 .104 r
.25621 .57278 m .2559 .5752 L .25572 .57151 L F
.884 .991 .758 r
.2559 .5729 m .25564 .57325 L .25621 .57278 L F
0 0 .104 r
.25621 .57278 m .2585 .5719 L .25882 .57195 L F
.919 .88 .78 r
.67481 .31634 m .67392 .31999 L .67661 .31858 L F
.835 .573 .543 r
.67392 .31999 m .67677 .32163 L .67661 .31858 L F
.733 .493 .564 r
.67661 .31858 m .67677 .32163 L .68054 .32159 L F
0 0 0 r
.66789 .38811 m .66579 .39191 L .66638 .39093 L F
.578 .278 .422 r
.66851 .39068 m .66789 .38811 L .66638 .39093 L F
.86 .89 .857 r
.50531 .51019 m .50819 .50959 L .5064 .5081 L F
.882 .814 .778 r
.50577 .51345 m .50819 .50959 L .50531 .51019 L F
.869 .889 .847 r
.5064 .5081 m .50819 .50959 L .51094 .50649 L F
.869 .738 .716 r
.57037 .44425 m .57218 .44073 L .56892 .4403 L F
.825 .462 .369 r
.35329 .50331 m .35118 .50528 L .34908 .50169 L F
.506 .589 .871 r
.34833 .64734 m .34637 .64974 L .34549 .64759 L F
.355 .369 .736 r
.34839 .64766 m .34905 .65139 L .34698 .65012 L F
.34833 .64734 m .34839 .64766 L .34637 .64974 L F
.34839 .64766 m .34698 .65012 L .34637 .64974 L F
.475 .337 .614 r
.34905 .65139 m .34702 .65322 L .34637 .64974 L F
.868 .721 .698 r
.34712 .65132 m .34905 .65139 L .34833 .64734 L F
0 0 0 r
.34828 .6491 m .34841 .64762 L .35005 .64534 L F
.34841 .64762 m .34842 .64755 L .34858 .64733 L F
.34841 .64762 m .34858 .64733 L .35005 .64534 L F
0 .486 .759 r
.62717 .37696 m .62984 .37756 L .63142 .37805 L F
.357 .092 .368 r
.62984 .37756 m .63267 .37632 L .63142 .37805 L F
0 0 .268 r
.63267 .37632 m .63132 .38061 L .63142 .37805 L F
.327 .27 .639 r
.24284 .55286 m .24524 .55536 L .24472 .55241 L F
.24284 .55286 m .24305 .55664 L .24524 .55536 L F
.104 .04 .493 r
.54831 .37769 m .55032 .37904 L .5513 .37723 L F
.54831 .37769 m .54865 .38076 L .55032 .37904 L F
.767 .425 .407 r
.34561 .56643 m .34336 .56876 L .34377 .56542 L F
.34561 .56643 m .34647 .56803 L .34336 .56876 L F
.77 .91 .936 r
.58948 .40897 m .59125 .41026 L .59144 .41058 L F
0 .123 .668 r
.59144 .41058 m .58849 .40656 L .58948 .40897 L F
.835 .688 .7 r
.36385 .57904 m .36181 .5823 L .36585 .58287 L F
.823 .628 .64 r
.36163 .58513 m .36585 .58287 L .36181 .5823 L F
.36163 .58513 m .36392 .58626 L .36585 .58287 L F
.662 .759 .922 r
.53748 .35842 m .53301 .3584 L .53632 .3547 L F
.579 .602 .84 r
.53985 .35739 m .53748 .35842 L .53632 .3547 L F
.83 .875 .877 r
.53781 .35851 m .53748 .35842 L .53985 .35739 L F
.53781 .35851 m .53816 .36126 L .53748 .35842 L F
.219 0 .119 r
.52226 .42019 m .52326 .41768 L .52462 .41677 L F
.865 .77 .266 r
.58217 .36345 m .58166 .36632 L .58196 .36799 L F
0 0 .246 r
.58229 .36879 m .58196 .36799 L .58166 .36632 L F
.58229 .36879 m .58306 .37105 L .58196 .36799 L F
.542 .791 .99 r
.30209 .65004 m .29779 .64946 L .29998 .64929 L F
.403 .83 .961 r
.29998 .64929 m .30436 .64917 L .30209 .65004 L F
.195 .724 .754 r
.54741 .38873 m .54844 .38835 L .55009 .38832 L F
.54741 .38873 m .54721 .38856 L .54844 .38835 L F
.495 .326 .58 r
.46371 .58709 m .46401 .58525 L .46117 .58743 L F
.46371 .58709 m .46612 .58585 L .46401 .58525 L F
.46371 .58709 m .46632 .58873 L .46612 .58585 L F
.46612 .58585 m .46632 .58873 L .46371 .58709 L F
.638 .771 .943 r
.61647 .39335 m .62057 .39435 L .61791 .39532 L F
.904 .85 .78 r
.46826 .55208 m .47237 .54969 L .47087 .54816 L F
.46826 .55208 m .46995 .55345 L .47237 .54969 L F
.686 .715 .871 r
.47237 .54969 m .47353 .54534 L .47087 .54816 L F
.47237 .54969 m .47383 .54892 L .47353 .54534 L F
.807 .882 .9 r
.59894 .39076 m .60215 .38989 L .60219 .38728 L F
.60215 .38989 m .59894 .39317 L .60165 .39243 L F
.60215 .38989 m .59894 .39076 L .59894 .39317 L F
0 0 0 r
.60215 .38989 m .60588 .38881 L .60438 .38933 L F
.60215 .38989 m .60438 .38933 L .60219 .38728 L F
.173 .279 .733 r
.60438 .38933 m .60585 .3933 L .60215 .38989 L F
.697 .25 .186 r
.60165 .39243 m .60585 .3933 L .60215 .38989 L F
.173 .279 .733 r
.60438 .38933 m .60585 .3933 L .60215 .38989 L F
.60438 .38933 m .60215 .38989 L .60165 .39243 L F
.766 .685 .774 r
.52396 .45416 m .52706 .45098 L .52251 .45021 L F
.027 0 0 r
.30292 .6862 m .30291 .68671 L .3004 .68558 L F
.30292 .6862 m .30554 .68588 L .30291 .68671 L F
.462 0 0 r
.40311 .51733 m .40554 .51849 L .40721 .51679 L F
.936 .607 .387 r
.40554 .51849 m .408 .52004 L .40721 .51679 L F
.876 .548 .425 r
.4205 .54318 m .42184 .5467 L .4237 .54661 L F
.814 .405 .272 r
.42184 .5467 m .42195 .54834 L .4237 .54661 L F
.874 .8 .774 r
.33562 .59535 m .33435 .59879 L .33659 .59458 L F
.55 .323 .523 r
.33741 .5942 m .33659 .59458 L .34033 .5933 L F
.869 .889 .847 r
.5064 .5081 m .51094 .50649 L .50945 .50535 L F
.874 .94 .858 r
.50945 .50535 m .51094 .50649 L .5136 .50329 L F
.833 .5 .424 r
.68611 .33703 m .68756 .33512 L .68441 .33395 L F
.68611 .33703 m .68794 .33764 L .68756 .33512 L F
.547 .526 .784 r
.58472 .35701 m .5821 .35827 L .58049 .35418 L F
0 0 .264 r
.58377 .35893 m .5821 .35827 L .58472 .35701 L F
.58377 .35893 m .58154 .36112 L .5821 .35827 L F
.888 .728 .678 r
.35306 .54263 m .35465 .54651 L .35521 .54348 L F
.73 .765 .881 r
.31126 .64903 m .30883 .65171 L .30708 .64871 L F
.797 .622 .664 r
.47072 .57901 m .4689 .58242 L .47293 .583 L F
.225 0 0 r
.37 .49578 m .37406 .49686 L .37194 .49626 L F
.432 .851 .694 r
.43169 .60269 m .43535 .60072 L .43375 .60141 L F
0 0 0 r
.43375 .60141 m .43535 .60072 L .43714 .60034 L F
.894 .776 .724 r
.54488 .47368 m .54835 .47336 L .54701 .47217 L F
.54488 .47368 m .54636 .47737 L .54835 .47336 L F
.746 .915 .95 r
.54835 .47336 m .5504 .46986 L .54701 .47217 L F
.54835 .47336 m .55173 .47098 L .5504 .46986 L F
.4 0 .009 r
.63052 .34579 m .63353 .34648 L .63065 .34676 L F
.822 .344 .04 r
.31234 .60357 m .3127 .60252 L .31047 .60173 L F
.31234 .60357 m .31484 .60572 L .3127 .60252 L F
0 .233 .751 r
.3364 .53655 m .33662 .53531 L .33387 .53308 L F
.755 .689 .788 r
.33412 .59582 m .33435 .59879 L .33276 .59817 L F
.594 .389 .572 r
.33276 .59817 m .33502 .60211 L .33435 .59879 L F
.783 .947 .608 r
.4504 .55373 m .45095 .55198 L .45247 .55066 L F
.929 .957 .776 r
.45095 .55198 m .45495 .54887 L .45247 .55066 L F
.45095 .55198 m .45324 .5484 L .45495 .54887 L F
.826 .935 .901 r
.45324 .5484 m .45777 .54655 L .45495 .54887 L F
.943 .69 .524 r
.321 .50695 m .31825 .50842 L .31927 .50522 L F
.321 .50695 m .32081 .50968 L .31825 .50842 L F
.831 .548 .51 r
.34236 .55879 m .33932 .55539 L .33955 .55703 L F
.765 .712 .803 r
.31813 .6484 m .31497 .65193 L .31351 .64812 L F
.616 .558 .766 r
.3208 .62919 m .32305 .62555 L .32037 .62622 L F
.3208 .62919 m .32551 .63043 L .32305 .62555 L F
.025 0 .123 r
.29109 .63309 m .29407 .62916 L .29344 .63219 L F
.999 .809 .507 r
.29344 .63219 m .29407 .62916 L .29241 .62861 L F
.397 .202 .495 r
.27563 .53506 m .27346 .53954 L .2737 .53648 L F
.27563 .53506 m .27633 .53898 L .27346 .53954 L F
.601 .468 .672 r
.27894 .53373 m .27563 .53506 L .27625 .53329 L F
.007 0 .439 r
.27744 .53717 m .27563 .53506 L .27894 .53373 L F
.27744 .53717 m .27633 .53898 L .27563 .53506 L F
.761 .432 .429 r
.43522 .56962 m .4394 .57272 L .43917 .56968 L F
.43619 .57034 m .43547 .57252 L .4394 .57272 L F
.43522 .56962 m .43547 .57252 L .43619 .57034 L F
0 0 .039 r
.43547 .57252 m .43456 .57466 L .43498 .57397 L F
.71 .819 .932 r
.4394 .57272 m .43547 .57252 L .43683 .57092 L F
0 0 .039 r
.43547 .57252 m .43498 .57397 L .43683 .57092 L F
.95 .658 .449 r
.43917 .56968 m .43683 .57092 L .43909 .56592 L F
.43917 .56968 m .4394 .57272 L .43683 .57092 L F
0 0 0 r
.62261 .34327 m .62539 .34258 L .62674 .34199 L F
.041 0 0 r
.62539 .34258 m .62961 .34165 L .62674 .34199 L F
.91 .658 .545 r
.36565 .51604 m .36342 .51262 L .3657 .5136 L F
.829 .785 .81 r
.44331 .58884 m .44053 .59275 L .43904 .59068 L F
.887 .458 .121 r
.38588 .54659 m .38402 .54552 L .38264 .54256 L F
.97 .744 .54 r
.38588 .54659 m .38392 .54804 L .38402 .54552 L F
.921 .618 .451 r
.38588 .54659 m .3858 .54976 L .38392 .54804 L F
.76 .803 .888 r
.54013 .35496 m .53632 .3547 L .53918 .35296 L F
.579 .602 .84 r
.53985 .35739 m .53632 .3547 L .54013 .35496 L F
.553 .807 .993 r
.54143 .35289 m .54013 .35496 L .53918 .35296 L F
.54143 .35289 m .54287 .35431 L .54013 .35496 L F
.548 .852 .54 r
.54287 .35431 m .53985 .35739 L .54013 .35496 L F
.158 .321 .779 r
.53462 .41985 m .53471 .42331 L .53675 .42327 L F
.791 .873 .909 r
.42442 .45749 m .42498 .45985 L .4278 .45755 L F
.783 .996 .795 r
.51152 .39525 m .50856 .39833 L .50956 .39604 L F
.778 .971 .683 r
.50856 .39833 m .50687 .39938 L .50956 .39604 L F
.849 .439 .26 r
.53301 .3584 m .53048 .36006 L .53167 .3563 L F
.53301 .3584 m .53311 .36103 L .53048 .36006 L F
.818 .903 .9 r
.53632 .3547 m .53301 .3584 L .53167 .3563 L F
.655 .542 .714 r
.27855 .52988 m .27625 .53329 L .27631 .53108 L F
.352 .165 .481 r
.27855 .52988 m .27838 .5326 L .27625 .53329 L F
.27855 .52988 m .27838 .5326 L .27625 .53329 L F
.601 .468 .672 r
.27894 .53373 m .27625 .53329 L .27838 .5326 L F
.715 .56 .677 r
.5947 .42766 m .59668 .42442 L .59182 .4243 L F
.785 .645 .707 r
.55847 .37725 m .5597 .38111 L .55555 .3806 L F
.453 .806 .997 r
.5597 .38111 m .55811 .37997 L .55555 .3806 L F
.688 .592 .743 r
.56074 .37788 m .5597 .38111 L .55847 .37725 L F
.654 .896 .982 r
.5613 .37855 m .5597 .38111 L .56251 .38043 L F
.5613 .37855 m .55811 .37997 L .5597 .38111 L F
.743 .981 .749 r
.48065 .41695 m .4816 .41485 L .48448 .41491 L F
.48065 .41695 m .48018 .41669 L .4816 .41485 L F
.778 .929 .564 r
.44865 .55567 m .4504 .55373 L .44915 .55595 L F
.44865 .55567 m .45095 .55198 L .4504 .55373 L F
.153 .277 .739 r
.66638 .39093 m .66579 .39191 L .66763 .39321 L F
.512 0 0 r
.66763 .39321 m .66579 .39191 L .66455 .39178 L F
.569 .045 0 r
.40488 .46364 m .40909 .46397 L .40748 .4653 L F
.848 .603 .568 r
.23782 .60996 m .23401 .61149 L .23588 .6082 L F
.23782 .60996 m .2379 .61292 L .23401 .61149 L F
.605 .78 .964 r
.23954 .60893 m .23782 .60996 L .23588 .6082 L F
.45 .288 .569 r
.24022 .61187 m .23782 .60996 L .23954 .60893 L F
.24022 .61187 m .2379 .61292 L .23782 .60996 L F
.639 .485 .657 r
.32897 .60307 m .32761 .60321 L .32587 .60588 L F
.747 .699 .807 r
.31021 .62819 m .31116 .62971 L .31369 .62804 L F
.82 .737 .773 r
.45553 .56642 m .45898 .56652 L .45777 .56548 L F
.86 .668 .641 r
.46177 .56599 m .45777 .56548 L .45898 .56652 L F
.546 .38 .607 r
.45914 .56937 m .46177 .56599 L .45898 .56652 L F
.569 .936 .909 r
.44514 .44902 m .44381 .45052 L .44601 .44918 L F
.583 .939 .792 r
.44303 .45056 m .44381 .45052 L .44514 .44902 L F
.366 .211 .535 r
.24442 .54682 m .2463 .5464 L .24688 .54245 L F
.438 .275 .562 r
.24426 .54964 m .2463 .5464 L .24442 .54682 L F
.57 .001 0 r
.29944 .67832 m .30076 .678 L .29696 .67721 L F
.472 .819 .998 r
.30237 .67754 m .30076 .678 L .30072 .6767 L F
.814 .997 .777 r
.30072 .6767 m .30076 .678 L .29944 .67832 L F
.829 .508 .446 r
.3752 .52677 m .37238 .5266 L .37127 .52527 L F
.734 .218 0 r
.37526 .52926 m .37238 .5266 L .3752 .52677 L F
0 0 .15 r
.42501 .5622 m .42442 .56569 L .42436 .56298 L F
.93 .714 .589 r
.38733 .55324 m .38472 .55525 L .38534 .55213 L F
.38733 .55324 m .38701 .55634 L .38472 .55525 L F
.656 .846 .973 r
.26319 .5256 m .26111 .52712 L .25916 .52574 L F
.616 .289 .394 r
.40218 .4639 m .40023 .46674 L .39801 .46683 L F
.506 .167 .328 r
.40488 .46364 m .40023 .46674 L .40218 .4639 L F
.82 .453 0 r
.28602 .67499 m .28784 .67929 L .28609 .67733 L F
.694 .79 .924 r
.32716 .62863 m .33138 .62914 L .32986 .62843 L F
.765 .78 .865 r
.32986 .62843 m .33138 .62914 L .33411 .62616 L F
.38 .822 .683 r
.44543 .44112 m .44118 .44322 L .44299 .44164 L F
.686 .956 .705 r
.44703 .43929 m .44543 .44112 L .44653 .43929 L F
.681 .979 .851 r
.44653 .43929 m .44543 .44112 L .44299 .44164 L F
.133 0 0 r
.37757 .46318 m .38131 .46194 L .38082 .46167 L F
.348 0 0 r
.38131 .46194 m .38275 .46272 L .38082 .46167 L F
.544 .696 .939 r
.30748 .55053 m .30896 .54785 L .30637 .54896 L F
.30748 .55053 m .31008 .54993 L .30896 .54785 L F
.788 .745 .814 r
.55358 .39359 m .55604 .39498 L .55475 .391 L F
.784 .71 .782 r
.55135 .39539 m .55604 .39498 L .55358 .39359 L F
.238 0 .043 r
.27614 .51731 m .27522 .51868 L .27875 .51662 L F
.212 .659 .949 r
.4218 .60485 m .42352 .6058 L .42391 .60496 L F
0 .297 .791 r
.42352 .6058 m .4258 .60722 L .42391 .60496 L F
.818 .995 .763 r
.53251 .4854 m .53178 .4877 L .53341 .48545 L F
.82 .992 .742 r
.53251 .4854 m .52977 .48872 L .53178 .4877 L F
.234 .077 .453 r
.24305 .55664 m .24506 .55819 L .24524 .55536 L F
.24305 .55664 m .24269 .55981 L .24506 .55819 L F
.645 .126 0 r
.30896 .54785 m .31229 .54862 L .3099 .54668 L F
.864 .756 .742 r
.39393 .48631 m .39579 .48283 L .39356 .48572 L F
.263 .769 .86 r
.39579 .48283 m .39865 .48238 L .39838 .48211 L F
.197 .531 .923 r
.39579 .48283 m .39832 .48383 L .39865 .48238 L F
.39832 .48383 m .39579 .48283 L .39838 .48211 L F
.219 0 .119 r
.52226 .42019 m .52462 .41677 L .52434 .4182 L F
0 0 0 r
.52434 .4182 m .52462 .41677 L .52492 .41631 L F
.66313 .40038 m .66504 .39895 L .66283 .40033 L F
.921 .974 .763 r
.50248 .49976 m .50395 .49546 L .50531 .49679 L F
.50248 .49976 m .5015 .49918 L .50395 .49546 L F
.012 .571 .809 r
.33538 .59244 m .34033 .5933 L .33741 .5942 L F
.748 .97 .7 r
.538 .47604 m .5406 .47252 L .54193 .47266 L F
.982 .906 .592 r
.54193 .47266 m .5406 .47252 L .54178 .46868 L F
.592 .776 .967 r
.28923 .6312 m .29109 .63309 L .29344 .63219 L F
.119 0 .076 r
.33923 .67089 m .34023 .66898 L .34233 .66798 L F
0 0 0 r
.58193 .43728 m .58555 .4368 L .58474 .43695 L F
.686 .965 .741 r
.58474 .43695 m .58555 .4368 L .58684 .43524 L F
.879 .925 .85 r
.55294 .45559 m .55207 .45949 L .55107 .45908 L F
.55294 .45559 m .55437 .45689 L .55207 .45949 L F
.463 .284 .551 r
.27346 .53954 m .27431 .54328 L .27114 .54273 L F
.239 .116 .503 r
.27327 .54495 m .27114 .54273 L .27431 .54328 L F
.27327 .54495 m .27099 .5472 L .27114 .54273 L F
.461 0 .051 r
.61469 .34829 m .61295 .35005 L .61083 .34967 L F
.672 .237 .208 r
.61733 .35037 m .61295 .35005 L .61469 .34829 L F
.63 .284 .366 r
.61726 .34841 m .61733 .35037 L .61469 .34829 L F
.931 .594 .374 r
.3384 .50994 m .33863 .51259 L .34072 .51352 L F
.941 .639 .439 r
.33863 .51259 m .33874 .51516 L .34072 .51352 L F
.837 .448 .311 r
.34072 .51352 m .33874 .51516 L .34133 .51566 L F
.836 .781 .277 r
.59182 .4243 m .59024 .42579 L .59202 .42682 L F
.534 .627 .89 r
.3257 .52917 m .32407 .53066 L .32107 .52641 L F
.89 .826 .778 r
.60229 .43961 m .6039 .44123 L .6063 .43754 L F
.143 0 0 r
.6321 .34098 m .63523 .34053 L .63644 .33908 L F
0 0 0 r
.63644 .33908 m .63799 .33946 L .63928 .33815 L F
.63644 .33908 m .63523 .34053 L .63799 .33946 L F
.192 0 .36 r
.49735 .44497 m .49529 .44796 L .49622 .44628 L F
0 .119 .619 r
.49529 .44796 m .49654 .44874 L .49622 .44628 L F
.858 .527 .425 r
.49528 .44737 m .49622 .44628 L .49654 .44874 L F
.4928 .4447 m .49622 .44628 L .49528 .44737 L F
.192 0 .36 r
.49772 .44443 m .49735 .44497 L .49622 .44628 L F
.625 .203 .222 r
.42777 .5698 m .43026 .57183 L .43211 .5696 L F
.828 .468 .375 r
.43211 .5696 m .43026 .57183 L .43244 .5717 L F
.66 .355 .445 r
.43244 .5717 m .43522 .56962 L .43211 .5696 L F
.101 .574 .91 r
.51161 .4342 m .51263 .4352 L .50853 .43365 L F
.318 .568 .928 r
.51365 .43351 m .51263 .4352 L .51161 .4342 L F
.981 .912 .608 r
.66967 .35112 m .66802 .35253 L .66936 .35025 L F
.66967 .35112 m .66844 .3553 L .66802 .35253 L F
.961 .915 .72 r
.66995 .34759 m .66967 .35112 L .66936 .35025 L F
.829 .766 .793 r
.465 .56011 m .4629 .55877 L .464 .56301 L F
.771 .734 .819 r
.464 .56301 m .46022 .56203 L .46206 .56308 L F
.464 .56301 m .4629 .55877 L .46022 .56203 L F
.745 .545 .625 r
.46177 .56599 m .464 .56301 L .46206 .56308 L F
.46177 .56599 m .46608 .56641 L .464 .56301 L F
.649 .948 .721 r
.52156 .4748 m .52371 .47245 L .52411 .47421 L F
.52156 .4748 m .52 .47554 L .52371 .47245 L F
.715 .56 .677 r
.5947 .42766 m .59182 .4243 L .59202 .42682 L F
.529 .922 .857 r
.63418 .39878 m .63589 .39873 L .63829 .39742 L F
.738 .696 .811 r
.32733 .6455 m .329 .64906 L .3248 .64865 L F
.761 .706 .8 r
.33197 .64661 m .329 .64906 L .32733 .6455 L F
.922 .76 .664 r
.35096 .53911 m .35312 .53995 L .3517 .53602 L F
.925 .658 .513 r
.35096 .53911 m .35306 .54263 L .35312 .53995 L F
.556 .314 .503 r
.29742 .58302 m .29705 .5857 L .29419 .58602 L F
0 0 0 r
.29419 .58602 m .29528 .58531 L .29742 .58302 L F
.363 .145 .443 r
.29943 .58232 m .29705 .5857 L .29742 .58302 L F
.29943 .58232 m .29925 .58501 L .29705 .5857 L F
.597 .154 .168 r
.29742 .58302 m .29925 .58501 L .29943 .58232 L F
.29742 .58302 m .29528 .58531 L .29925 .58501 L F
.839 .788 .803 r
.50367 .51215 m .50577 .51345 L .50531 .51019 L F
.844 .786 .795 r
.5032 .51691 m .50577 .51345 L .50367 .51215 L F
.384 0 .021 r
.3092 .68561 m .31036 .68758 L .30721 .68699 L F
.3092 .68561 m .31201 .68547 L .31036 .68758 L F
.046 .323 .807 r
.32494 .51983 m .326 .51957 L .32546 .5179 L F
.627 .567 .768 r
.32494 .51983 m .32888 .52264 L .326 .51957 L F
.911 .638 .509 r
.68051 .32677 m .68252 .32526 L .68069 .32408 L F
.68051 .32677 m .6825 .32788 L .68252 .32526 L F
.904 .983 .781 r
.47218 .53303 m .47351 .52894 L .47561 .53056 L F
.47218 .53303 m .47102 .53275 L .47351 .52894 L F
.877 .453 .038 r
.58365 .39118 m .5847 .39367 L .58345 .39305 L F
.208 0 0 r
.561 .3989 m .55974 .39785 L .55837 .39924 L F
.561 .3989 m .56257 .39739 L .55974 .39785 L F
.493 .271 .505 r
.55974 .39785 m .56371 .39488 L .55963 .3963 L F
.55974 .39785 m .56257 .39739 L .56371 .39488 L F
.84 .901 .88 r
.47049 .43817 m .47299 .43858 L .47448 .4368 L F
.052 .164 .663 r
.24377 .57738 m .24475 .57446 L .24281 .57462 L F
.24377 .57738 m .2451 .57682 L .24475 .57446 L F
.301 0 .168 r
.26921 .54968 m .26826 .55228 L .26563 .55291 L F
0 0 .036 r
.27002 .55115 m .26921 .54968 L .27105 .54866 L F
.27002 .55115 m .26826 .55228 L .26921 .54968 L F
.368 .008 .214 r
.64838 .33424 m .65121 .33355 L .65169 .33108 L F
.299 0 .196 r
.65169 .33108 m .65391 .3326 L .6544 .32985 L F
.65169 .33108 m .65121 .33355 L .65391 .3326 L F
.674 .924 .973 r
.53943 .45259 m .53785 .45427 L .53555 .4537 L F
.53943 .45259 m .53555 .4537 L .53869 .44926 L F
.666 .509 .662 r
.53555 .4537 m .53868 .453 L .53869 .44926 L F
.744 .508 .573 r
.53993 .45277 m .53928 .45528 L .54014 .45267 L F
.475 .325 .596 r
.53976 .45341 m .53928 .45528 L .53936 .45385 L F
.53965 .45246 m .53936 .45385 L .53943 .45259 L F
.54016 .45216 m .53989 .45273 L .53965 .45246 L F
.53989 .45273 m .53936 .45385 L .53965 .45246 L F
.649 .96 .773 r
.53843 .45319 m .53785 .45427 L .53943 .45259 L F
.53676 .4542 m .53709 .45422 L .53843 .45319 L F
.53709 .45422 m .53785 .45427 L .53843 .45319 L F
.53676 .4542 m .53943 .45259 L .53928 .45528 L F
.744 .508 .573 r
.53676 .4542 m .53993 .45277 L .53555 .4537 L F
.53993 .45277 m .54014 .45267 L .53989 .45273 L F
.53993 .45277 m .53989 .45273 L .53555 .4537 L F
.666 .509 .662 r
.53989 .45273 m .54014 .45267 L .54004 .45243 L F
.475 .325 .596 r
.54175 .45125 m .54004 .45243 L .54016 .45216 L F
.363 .366 .729 r
.54175 .45125 m .53943 .45259 L .53869 .44926 L F
.387 .363 .71 r
.53869 .44926 m .54004 .45243 L .54175 .45125 L F
.54004 .45243 m .54014 .45267 L .54175 .45125 L F
.475 .325 .596 r
.54175 .45125 m .53977 .45298 L .54004 .45243 L F
.732 .769 .269 r
.54014 .45267 m .54013 .45267 L .54175 .45125 L F
.475 .325 .596 r
.53995 .4532 m .53936 .45385 L .54013 .45267 L F
.732 .769 .269 r
.54014 .45267 m .53928 .45528 L .54013 .45267 L F
.475 .325 .596 r
.54175 .45125 m .53928 .45528 L .53976 .45341 L F
.732 .769 .269 r
.54013 .45267 m .53928 .45528 L .53991 .45267 L F
.475 .325 .596 r
.54013 .45267 m .53936 .45385 L .53977 .45298 L F
.54175 .45125 m .53995 .4532 L .54013 .45267 L F
.732 .769 .269 r
.54013 .45267 m .53991 .45267 L .54175 .45125 L F
.744 .508 .573 r
.53676 .4542 m .53928 .45528 L .53993 .45277 L F
.666 .509 .662 r
.53868 .453 m .53989 .45273 L .53988 .45207 L F
.53989 .45273 m .54004 .45243 L .53988 .45207 L F
.53868 .453 m .53988 .45207 L .53869 .44926 L F
.804 .618 .649 r
.46725 .57902 m .46951 .57984 L .47072 .57901 L F
.822 .655 .676 r
.46951 .57984 m .4689 .58242 L .47072 .57901 L F
.628 .096 0 r
.33588 .57779 m .33324 .57676 L .33317 .57884 L F
.031 0 0 r
.52737 .41031 m .52478 .41119 L .52376 .41227 L F
.786 .816 .876 r
.52109 .38414 m .51888 .387 L .52173 .3841 L F
.412 .42 .758 r
.52109 .38414 m .52106 .3847 L .51888 .387 L F
.782 .998 .83 r
.52173 .3841 m .51888 .387 L .52157 .38416 L F
.71 .567 .691 r
.52151 .38402 m .52132 .38437 L .52109 .38414 L F
.52151 .38402 m .52109 .38414 L .52173 .3841 L F
.782 .998 .83 r
.52173 .3841 m .52161 .38412 L .52151 .38402 L F
.52173 .3841 m .52151 .38402 L .52137 .38387 L F
.891 .689 .623 r
.52013 .37985 m .52173 .3841 L .51979 .38283 L F
.703 .606 .746 r
.52477 .38309 m .52173 .3841 L .52013 .37985 L F
.71 .567 .691 r
.52477 .38309 m .52151 .38402 L .52173 .3841 L F
.52183 .38393 m .52161 .38412 L .52151 .38402 L F
.52161 .38412 m .52132 .38437 L .52151 .38402 L F
.782 .998 .83 r
.52137 .38387 m .5202 .38431 L .51979 .38283 L F
.52161 .38412 m .5202 .38431 L .52137 .38387 L F
.52161 .38412 m .52157 .38416 L .5216 .38412 L F
.52173 .3841 m .52157 .38416 L .52161 .38412 L F
.71 .567 .691 r
.52477 .38309 m .52516 .38808 L .52132 .38437 L F
.52477 .38309 m .52132 .38437 L .52183 .38393 L F
.412 .42 .758 r
.52106 .3847 m .52294 .39022 L .52077 .39008 L F
.52109 .38414 m .5212 .3845 L .52106 .3847 L F
.5212 .3845 m .52294 .39022 L .52106 .3847 L F
.64 .563 .752 r
.52603 .38966 m .52294 .39022 L .5212 .3845 L F
.52131 .38439 m .5212 .3845 L .52109 .38414 L F
.52603 .38966 m .5212 .3845 L .52131 .38439 L F
.52603 .38966 m .52131 .38439 L .52516 .38808 L F
.52131 .38439 m .52109 .38414 L .52132 .38437 L F
.52131 .38439 m .52132 .38437 L .52516 .38808 L F
.782 .998 .83 r
.52145 .38414 m .52063 .38505 L .5202 .38431 L F
.52063 .38505 m .52022 .38551 L .52022 .38546 L F
.52063 .38505 m .52022 .38546 L .5202 .38431 L F
.52022 .38551 m .51888 .387 L .51898 .38679 L F
.52022 .38551 m .51898 .38679 L .5202 .38431 L F
.5216 .38412 m .52106 .3847 L .52145 .38414 L F
.52106 .3847 m .51888 .387 L .52145 .38414 L F
.412 .42 .758 r
.52106 .3847 m .52077 .39008 L .51888 .387 L F
.804 .543 .543 r
.64866 .37804 m .64935 .38052 L .64736 .37986 L F
.654 .649 .832 r
.65057 .374 m .64866 .37804 L .64736 .37504 L F
.65057 .374 m .65153 .37774 L .64866 .37804 L F
.636 .445 .608 r
.64866 .37804 m .65153 .37774 L .64935 .38052 L F
.527 .906 .74 r
.60438 .38933 m .60588 .38881 L .60834 .38706 L F
.511 .151 .292 r
.37611 .46546 m .38131 .46194 L .37757 .46318 L F
.884 .82 .78 r
.38978 .57601 m .38988 .57194 L .39178 .57313 L F
.522 .674 .933 r
.65573 .38361 m .65682 .38568 L .65944 .38506 L F
.65573 .38361 m .65682 .38568 L .65944 .38506 L F
.8 .736 .793 r
.3179 .62472 m .32037 .62622 L .31897 .62366 L F
.589 .73 .941 r
.32037 .62622 m .32192 .62418 L .31897 .62366 L F
.32037 .62622 m .32305 .62555 L .32192 .62418 L F
.286 .705 .971 r
.62629 .40221 m .62524 .40125 L .62173 .40114 L F
.597 .884 .991 r
.62795 .40014 m .62629 .40221 L .62898 .4012 L F
.62795 .40014 m .62524 .40125 L .62629 .40221 L F
.512 .881 .977 r
.63838 .38678 m .63685 .38834 L .63561 .38756 L F
.63838 .38678 m .63957 .38742 L .63685 .38834 L F
.995 .769 .413 r
.42291 .55211 m .42363 .55545 L .42581 .55371 L F
.968 .712 .492 r
.38037 .53935 m .37862 .53561 L .38066 .5367 L F
.513 .913 .834 r
.41788 .58994 m .41893 .59032 L .42162 .5906 L F
.41788 .58994 m .41635 .59081 L .41893 .59032 L F
.747 .699 .807 r
.31021 .62819 m .31369 .62804 L .31196 .62631 L F
.66 .82 .96 r
.31369 .62804 m .31488 .62487 L .31196 .62631 L F
.31369 .62804 m .31571 .62745 L .31488 .62487 L F
.531 .86 .995 r
.29271 .62086 m .29471 .62174 L .29206 .62249 L F
.878 .55 .044 r
.29258 .62496 m .29206 .62249 L .29471 .62174 L F
.865 .423 .031 r
.41805 .54006 m .41853 .54228 L .4205 .54318 L F
.929 .544 .188 r
.41945 .54494 m .4205 .54318 L .41853 .54228 L F
.41945 .54494 m .42184 .5467 L .4205 .54318 L F
.79 .7 .765 r
.48539 .53478 m .48716 .53705 L .48668 .53384 L F
.428 .443 .774 r
.5355 .46863 m .53534 .47601 L .53453 .4741 L F
.801 .888 .908 r
.49894 .51821 m .5032 .51691 L .50123 .51562 L F
.844 .786 .795 r
.5032 .51691 m .50367 .51215 L .50123 .51562 L F
.965 .684 .449 r
.55555 .3806 m .5575 .38473 L .55543 .38326 L F
.963 .746 .563 r
.55543 .38326 m .55692 .38727 L .5575 .38473 L F
.318 0 .211 r
.32145 .68173 m .32481 .67825 L .32325 .68065 L F
.248 0 .018 r
.32325 .68065 m .32481 .67825 L .32652 .67853 L F
.525 .573 .846 r
.31784 .53539 m .31904 .53213 L .31697 .53235 L F
.31784 .53539 m .32038 .53535 L .31904 .53213 L F
.961 .716 .521 r
.53156 .43208 m .53343 .43368 L .53157 .43578 L F
.457 .72 .981 r
.5346 .43249 m .53343 .43368 L .53156 .43208 L F
.65 .551 .73 r
.53156 .43208 m .5347 .43239 L .53436 .42944 L F
0 0 .297 r
.53156 .43208 m .53286 .43341 L .5347 .43239 L F
0 0 .41 r
.53436 .42944 m .5347 .43239 L .53471 .43237 L F
.457 .72 .981 r
.5349 .43217 m .53468 .43216 L .53436 .42944 L F
.5346 .43249 m .53156 .43208 L .5349 .43217 L F
.573 .58 .822 r
.53675 .42862 m .53498 .43254 L .53436 .42944 L F
0 0 .41 r
.53436 .42944 m .53471 .43237 L .53562 .43061 L F
.457 .72 .981 r
.53468 .43216 m .53156 .43208 L .53436 .42944 L F
.674 .938 .657 r
.53471 .43237 m .5347 .43239 L .53469 .43239 L F
.457 .72 .981 r
.53498 .43254 m .5346 .43249 L .5349 .43217 L F
.674 .938 .657 r
.53484 .43211 m .53471 .43237 L .53465 .43242 L F
.53471 .43237 m .53469 .43239 L .53465 .43242 L F
.53562 .43061 m .53484 .43211 L .53286 .43341 L F
.53484 .43211 m .53465 .43242 L .53286 .43341 L F
.457 .72 .981 r
.53498 .43254 m .5342 .43311 L .5346 .43249 L F
.5342 .43311 m .53343 .43368 L .5346 .43249 L F
0 0 0 r
.53157 .43578 m .53343 .43368 L .53498 .43254 L F
.799 .401 .299 r
.40865 .52266 m .4111 .52571 L .41117 .52391 L F
.858 .462 .291 r
.41117 .52391 m .4111 .52571 L .41342 .52635 L F
0 0 .35 r
.23835 .59988 m .23967 .59992 L .23902 .59751 L F
.23835 .59988 m .23834 .60421 L .23967 .59992 L F
.739 .976 .922 r
.48448 .41491 m .48546 .41256 L .48614 .41304 L F
.48448 .41491 m .4816 .41485 L .48546 .41256 L F
.956 .653 .418 r
.59441 .38725 m .59483 .38992 L .59647 .39011 L F
.282 0 0 r
.59483 .38992 m .59894 .39076 L .59647 .39011 L F
.811 .346 .124 r
.38536 .46448 m .38662 .4623 L .38275 .46272 L F
.38536 .46448 m .38733 .46365 L .38662 .4623 L F
.815 .812 .848 r
.47641 .54223 m .477 .54639 L .47813 .54338 L F
.47641 .54223 m .47353 .54534 L .477 .54639 L F
.818 .81 .843 r
.47353 .54534 m .47383 .54892 L .477 .54639 L F
.859 .557 .475 r
.60605 .38687 m .60834 .38706 L .60836 .38462 L F
.832 .999 .787 r
.48861 .4093 m .48739 .41133 L .48794 .40898 L F
.883 .989 .736 r
.48614 .41304 m .48794 .40898 L .48739 .41133 L F
.991 .735 .387 r
.55847 .37725 m .55661 .37531 L .55807 .37466 L F
.178 0 0 r
.55661 .37531 m .55956 .3742 L .55807 .37466 L F
.697 .643 .791 r
.54179 .3809 m .54013 .38286 L .53757 .38099 L F
.483 .285 .534 r
.33276 .59817 m .3318 .60263 L .32897 .60307 L F
.58 .445 .661 r
.3322 .60546 m .32897 .60307 L .3318 .60263 L F
.3322 .60546 m .3296 .60638 L .32897 .60307 L F
0 .565 .733 r
.63829 .39742 m .64235 .39767 L .64095 .39755 L F
.101 0 0 r
.64095 .39755 m .64235 .39767 L .6454 .39807 L F
.791 .512 .514 r
.36986 .49912 m .37406 .49686 L .37 .49578 L F
.36986 .49912 m .37377 .49968 L .37406 .49686 L F
.761 .484 .513 r
.37406 .49686 m .37377 .49968 L .37827 .50008 L F
.686 .964 .739 r
.5287 .41412 m .53189 .4113 L .53092 .41177 L F
.138 0 0 r
.53092 .41177 m .53189 .4113 L .53005 .41239 L F
.6 .052 0 r
.53005 .41239 m .53189 .4113 L .52737 .41031 L F
.639 .951 .748 r
.45701 .43351 m .45311 .43612 L .45596 .4332 L F
.533 .918 .791 r
.45841 .43212 m .45701 .43351 L .45596 .4332 L F
.45841 .43212 m .46059 .43135 L .45701 .43351 L F
.836 .969 .652 r
.40652 .58505 m .40386 .58285 L .40673 .58239 L F
.794 .765 .827 r
.34738 .62531 m .35014 .62217 L .34604 .62177 L F
.739 .963 .938 r
.53983 .48078 m .54301 .47992 L .54164 .47891 L F
.767 .756 .843 r
.54301 .47992 m .54415 .47586 L .54164 .47891 L F
.54301 .47992 m .54636 .47737 L .54415 .47586 L F
.897 .713 .645 r
.33396 .60403 m .3318 .60263 L .33502 .60211 L F
.33396 .60403 m .3322 .60546 L .3318 .60263 L F
.951 .737 .578 r
.35266 .54532 m .35465 .54651 L .35306 .54263 L F
.937 .761 .638 r
.35242 .54646 m .35465 .54651 L .35266 .54532 L F
.35242 .54646 m .35459 .54941 L .35465 .54651 L F
.846 .666 .659 r
.3912 .50228 m .39323 .50601 L .39338 .50357 L F
.774 .57 .622 r
.39323 .50601 m .3958 .50259 L .39338 .50357 L F
.701 .363 .402 r
.40955 .58342 m .40652 .58505 L .40673 .58239 L F
.40955 .58342 m .41113 .58581 L .40652 .58505 L F
.719 .211 .021 r
.5544 .41089 m .55745 .41161 L .55854 .41322 L F
.064 0 0 r
.44181 .58876 m .44582 .58903 L .44331 .58884 L F
.34 .163 .489 r
.28992 .67877 m .29224 .68069 L .29314 .67858 L F
.28992 .67877 m .29019 .68156 L .29224 .68069 L F
.827 .881 .883 r
.46531 .55518 m .46995 .55345 L .46826 .55208 L F
.66 .355 .445 r
.43244 .5717 m .43547 .57252 L .43522 .56962 L F
.823 .779 .811 r
.3238 .58232 m .32283 .57978 L .32394 .57953 L F
.568 .931 .782 r
.32394 .57953 m .32477 .57833 L .32675 .57912 L F
.32394 .57953 m .32283 .57978 L .32477 .57833 L F
.584 .449 .664 r
.32675 .57912 m .3238 .58232 L .32394 .57953 L F
.917 .585 .398 r
.4546 .53844 m .45637 .53715 L .45422 .53586 L F
.4546 .53844 m .45637 .53715 L .45422 .53586 L F
.416 .864 .863 r
.44967 .44772 m .45318 .44678 L .45237 .44707 L F
.353 .817 .728 r
.45491 .44584 m .45318 .44678 L .45511 .4459 L F
.349 .808 .695 r
.45237 .44707 m .45318 .44678 L .45491 .44584 L F
.674 .567 .727 r
.45656 .57341 m .45976 .57245 L .45914 .56937 L F
.696 .444 .539 r
.45649 .57525 m .45976 .57245 L .45656 .57341 L F
.845 .888 .871 r
.50848 .49379 m .50531 .49679 L .50395 .49546 L F
0 .402 .767 r
.32281 .52598 m .32762 .52844 L .3257 .52917 L F
.419 .855 .932 r
.32762 .52844 m .32831 .52507 L .3305 .52554 L F
.32762 .52844 m .32895 .52673 L .32831 .52507 L F
.557 .585 .837 r
.32895 .52673 m .32642 .52467 L .32831 .52507 L F
.32642 .52467 m .32494 .52346 L .32831 .52507 L F
.419 .855 .932 r
.3305 .52554 m .32831 .52507 L .33085 .52518 L F
.32762 .52844 m .3265 .52747 L .32895 .52673 L F
.869 .857 .827 r
.35711 .48904 m .35442 .49059 L .35743 .48658 L F
.291 .706 .973 r
.3598 .48827 m .35711 .48904 L .35743 .48658 L F
.3598 .48827 m .36179 .48937 L .35711 .48904 L F
.416 .767 .996 r
.56334 .36965 m .56614 .36953 L .56779 .37079 L F
.058 .534 .893 r
.56614 .36953 m .5691 .37085 L .56779 .37079 L F
0 0 .211 r
.49971 .44645 m .49839 .44707 L .49929 .44524 L F
.282 0 .138 r
.49971 .44645 m .49929 .44524 L .50353 .44485 L F
.874 .94 .858 r
.50945 .50535 m .5136 .50329 L .51276 .50262 L F
.87 .994 .801 r
.51549 .49932 m .5136 .50329 L .51675 .50032 L F
.51549 .49932 m .51276 .50262 L .5136 .50329 L F
.947 .634 .408 r
.2821 .60956 m .28285 .61265 L .28042 .61111 L F
.116 .138 .606 r
.2469 .58943 m .24859 .5911 L .24976 .58918 L F
.761 .706 .8 r
.33197 .64661 m .32733 .6455 L .3299 .64443 L F
.658 .735 .907 r
.33412 .64522 m .33197 .64661 L .3299 .64443 L F
.327 .011 .267 r
.66094 .32534 m .66321 .32636 L .66354 .3242 L F
.66094 .32534 m .66055 .32733 L .66321 .32636 L F
.333 0 0 r
.29095 .65586 m .29278 .65654 L .28825 .65498 L F
.059 .136 .63 r
.58806 .37554 m .58601 .37478 L .58792 .37369 L F
.802 .574 .592 r
.59731 .37025 m .60053 .36778 L .5977 .36745 L F
.184 0 0 r
.5977 .36745 m .59979 .3678 L .60053 .36778 L F
.5977 .36745 m .59979 .3678 L .60053 .36778 L F
.216 0 0 r
.3145 .6849 m .3188 .68221 L .3174 .6843 L F
.284 0 .023 r
.3188 .68221 m .32038 .68366 L .3174 .6843 L F
.3188 .68221 m .32145 .68173 L .32038 .68366 L F
.618 .409 .577 r
.31757 .55276 m .31802 .55585 L .32164 .55158 L F
.951 .818 .377 r
.36951 .47028 m .36941 .47368 L .36895 .47231 L F
.439 0 .046 r
.36941 .47368 m .37126 .47558 L .3689 .47503 L F
.345 .074 .351 r
.61992 .3491 m .61726 .34841 L .62122 .3479 L F
.61992 .3491 m .61733 .35037 L .61726 .34841 L F
.055 .041 .521 r
.24175 .56567 m .24138 .56973 L .24324 .56789 L F
0 0 .454 r
.24138 .56973 m .24333 .57056 L .24324 .56789 L F
.24138 .56973 m .2418 .57258 L .24333 .57056 L F
.877 .99 .74 r
.48778 .51285 m .48552 .51387 L .48695 .51217 L F
.48778 .51285 m .48522 .51636 L .48552 .51387 L F
.866 .996 .791 r
.4904 .50945 m .48778 .51285 L .48695 .51217 L F
.259 .101 .468 r
.24642 .53969 m .24818 .53918 L .24832 .53618 L F
.378 .337 .686 r
.24688 .54245 m .24818 .53918 L .24642 .53969 L F
.858 .586 .526 r
.59202 .42682 m .59447 .43034 L .5947 .42766 L F
.744 .764 .259 r
.56506 .39113 m .56457 .39227 L .56383 .38964 L F
.56506 .39113 m .56426 .39372 L .56457 .39227 L F
.757 .787 .293 r
.4383 .58837 m .43813 .58893 L .43908 .58628 L F
.707 .535 .653 r
.44163 .58564 m .4383 .58837 L .43908 .58628 L F
.8 .999 .837 r
.30198 .65854 m .29913 .65947 L .3004 .65832 L F
.545 .665 .916 r
.29831 .65641 m .3031 .6587 L .30198 .65854 L F
.265 .432 .841 r
.29831 .65641 m .30198 .65854 L .29928 .65431 L F
.431 .521 .85 r
.29928 .65431 m .30198 .65854 L .3025 .65746 L F
.29928 .65431 m .3025 .65746 L .30285 .65609 L F
.8 .999 .837 r
.30198 .65854 m .3004 .65832 L .30285 .65609 L F
.545 .665 .916 r
.3031 .6587 m .30334 .65881 L .30198 .65854 L F
0 0 0 r
.30334 .65881 m .29891 .66118 L .30198 .65854 L F
.82 .992 .868 r
.30198 .65854 m .30334 .65881 L .3025 .65746 L F
.3025 .65746 m .30334 .65881 L .30198 .65854 L F
.567 .931 .783 r
.43347 .45641 m .43528 .45461 L .43315 .45605 L F
.43347 .45641 m .4374 .45387 L .43528 .45461 L F
.217 0 0 r
.31646 .54721 m .31229 .54862 L .31497 .54521 L F
.31646 .54721 m .31496 .54838 L .31229 .54862 L F
0 0 0 r
.31728 .54746 m .31701 .54787 L .31734 .54751 L F
.31728 .54746 m .31818 .5466 L .31827 .54673 L F
.31818 .5466 m .31728 .54746 L .31827 .54673 L F
.31728 .54746 m .31734 .54751 L .31818 .5466 L F
.31728 .54746 m .31646 .54721 L .31718 .54735 L F
.31728 .54746 m .31726 .54736 L .32003 .54791 L F
.662 .915 .977 r
.31818 .5466 m .31701 .54787 L .31697 .54784 L F
0 0 0 r
.31818 .5466 m .3173 .54751 L .31728 .54746 L F
.31728 .54746 m .31718 .54735 L .31726 .54736 L F
.31728 .54746 m .31496 .54838 L .31646 .54721 L F
.658 .757 .923 r
.30896 .54785 m .31008 .54993 L .31229 .54862 L F
.351 0 0 r
.30896 .54785 m .31097 .54859 L .31229 .54862 L F
.30896 .54785 m .31097 .54859 L .31229 .54862 L F
.344 .776 .97 r
.31229 .54862 m .31136 .54819 L .31097 .54859 L F
.402 .856 .87 r
.31229 .54862 m .31115 .54839 L .31138 .54819 L F
.31229 .54862 m .31138 .54819 L .31497 .54521 L F
.344 .776 .97 r
.31229 .54862 m .31234 .54783 L .31138 .54819 L F
.31229 .54862 m .31496 .54838 L .31399 .54791 L F
.31229 .54862 m .31399 .54791 L .31379 .54792 L F
.31229 .54862 m .31391 .54786 L .31234 .54783 L F
.208 0 0 r
.31254 .54784 m .31728 .54746 L .31618 .54639 L F
.31452 .54788 m .31728 .54746 L .31254 .54784 L F
.31138 .54819 m .31618 .54639 L .31497 .54521 L F
.31115 .54839 m .31618 .54639 L .31138 .54819 L F
.756 .316 .206 r
.31728 .54746 m .31239 .54712 L .31391 .54786 L F
.31728 .54746 m .31391 .54786 L .31496 .54838 L F
.344 .776 .97 r
.31379 .54792 m .31399 .54791 L .31391 .54786 L F
.208 0 0 r
.31115 .54839 m .31452 .54788 L .31391 .54786 L F
.31184 .54811 m .31391 .54786 L .31254 .54784 L F
.31115 .54839 m .31391 .54786 L .31184 .54811 L F
.756 .316 .206 r
.31728 .54746 m .31672 .54809 L .31589 .54797 L F
.208 0 0 r
.31115 .54839 m .31589 .54797 L .3163 .54782 L F
.31115 .54839 m .3171 .54773 L .31452 .54788 L F
.344 .776 .97 r
.31234 .54783 m .31391 .54786 L .31239 .54712 L F
.449 .823 .992 r
.31306 .54756 m .31589 .54797 L .31387 .54815 L F
.208 0 0 r
.31452 .54788 m .3171 .54773 L .31728 .54746 L F
.756 .316 .206 r
.31728 .54746 m .31447 .54849 L .31239 .54712 L F
.31589 .54797 m .31566 .54928 L .31447 .54849 L F
0 .191 .626 r
.31448 .54849 m .31566 .54928 L .3145 .54849 L F
.31448 .54849 m .3145 .54849 L .31373 .54797 L F
.208 0 0 r
.3163 .54782 m .31701 .54787 L .3171 .54773 L F
.31589 .54797 m .31701 .54787 L .3163 .54782 L F
.449 .823 .992 r
.31519 .54704 m .31701 .54787 L .31589 .54797 L F
.31541 .54705 m .31701 .54787 L .31519 .54704 L F
.3155 .54696 m .31701 .54787 L .31508 .54688 L F
.411 0 .015 r
.31497 .54521 m .31789 .54508 L .3203 .54324 L F
.556 .262 .424 r
.31497 .54521 m .31728 .54746 L .31789 .54508 L F
.788 .708 .776 r
.31459 .54679 m .31818 .5466 L .31624 .54454 L F
.3153 .54692 m .31818 .5466 L .31459 .54679 L F
.449 .823 .992 r
.31443 .54645 m .31296 .54749 L .31192 .54579 L F
.164 .531 .922 r
.31263 .54479 m .31483 .54655 L .31192 .54579 L F
.31483 .54655 m .31483 .54656 L .31483 .54656 L F
.31483 .54655 m .31483 .54656 L .31192 .54579 L F
.449 .823 .992 r
.31443 .54676 m .31453 .54685 L .31288 .54754 L F
.31453 .54685 m .31589 .54797 L .31372 .54766 L F
.31453 .54685 m .31372 .54766 L .31288 .54754 L F
0 0 0 r
.31466 .5467 m .31469 .54669 L .31459 .54679 L F
.449 .823 .992 r
.31483 .54656 m .31508 .54688 L .31443 .54676 L F
.31508 .54688 m .31589 .54797 L .31443 .54676 L F
.788 .708 .776 r
.31442 .54776 m .31644 .54714 L .31487 .54705 L F
.31442 .54711 m .31487 .54705 L .31442 .54702 L F
.31442 .54776 m .31487 .54705 L .31442 .54711 L F
.662 .915 .977 r
.31818 .5466 m .31697 .54784 L .3155 .54696 L F
.31818 .5466 m .3155 .54696 L .31483 .54656 L F
.788 .708 .776 r
.31442 .54702 m .3153 .54692 L .31459 .54679 L F
0 0 0 r
.31459 .54679 m .31532 .54653 L .31373 .54797 L F
.31469 .54669 m .31532 .54653 L .31459 .54679 L F
.662 .915 .977 r
.31818 .5466 m .31483 .54656 L .31624 .54454 L F
0 0 0 r
.31624 .54454 m .31563 .54587 L .31466 .5467 L F
.31563 .54587 m .31532 .54653 L .31466 .5467 L F
0 .212 .734 r
.31192 .54579 m .31305 .54715 L .31263 .54479 L F
.449 .823 .992 r
.31443 .54676 m .31288 .54754 L .31288 .54753 L F
.31443 .54676 m .31296 .54749 L .31443 .54645 L F
0 .212 .734 r
.31305 .54715 m .31373 .54797 L .31328 .54666 L F
.31305 .54715 m .31328 .54666 L .31263 .54479 L F
.449 .823 .992 r
.31288 .54753 m .31288 .54754 L .31287 .54753 L F
.788 .708 .776 r
.31644 .54714 m .31818 .5466 L .3153 .54692 L F
.449 .823 .992 r
.31508 .54688 m .31541 .54705 L .31519 .54704 L F
.788 .708 .776 r
.31644 .54714 m .3153 .54692 L .31442 .54702 L F
.756 .316 .206 r
.31672 .54809 m .31566 .54928 L .31589 .54797 L F
0 0 0 r
.3173 .54753 m .31566 .54928 L .31728 .54746 L F
.788 .708 .776 r
.31373 .54797 m .31566 .54928 L .31759 .54723 L F
0 0 0 r
.31818 .5466 m .3173 .54753 L .3173 .54751 L F
.788 .708 .776 r
.31644 .54714 m .31759 .54723 L .31818 .5466 L F
.31373 .54797 m .31759 .54723 L .31644 .54714 L F
.449 .823 .992 r
.31483 .54656 m .3155 .54696 L .31508 .54688 L F
.788 .708 .776 r
.31373 .54797 m .31442 .54776 L .31442 .54702 L F
.449 .823 .992 r
.31483 .54656 m .31443 .54676 L .31443 .54645 L F
0 .191 .626 r
.31239 .54712 m .31306 .54756 L .31286 .54742 L F
.344 .776 .97 r
.31138 .54819 m .31239 .54712 L .31136 .54819 L F
.31234 .54783 m .31239 .54712 L .31138 .54819 L F
0 .191 .626 r
.31239 .54712 m .31192 .54579 L .31151 .54718 L F
.385 .598 .93 r
.31186 .54716 m .31097 .54859 L .31239 .54712 L F
0 .191 .626 r
.31239 .54712 m .31151 .54718 L .31115 .54839 L F
.385 .598 .93 r
.31194 .54702 m .31186 .54716 L .31239 .54712 L F
.30926 .54646 m .31021 .54764 L .31194 .54702 L F
.31021 .54764 m .31097 .54859 L .31194 .54702 L F
.449 .823 .992 r
.31296 .54749 m .31115 .54839 L .31151 .54718 L F
.31214 .54695 m .31151 .54718 L .31167 .54664 L F
.31181 .54724 m .31151 .54718 L .31194 .54702 L F
.385 .598 .93 r
.30926 .54646 m .31194 .54702 L .31115 .54839 L F
.31194 .54702 m .31239 .54712 L .31115 .54839 L F
.449 .823 .992 r
.31296 .54749 m .31181 .54724 L .31214 .54695 L F
.31181 .54724 m .31194 .54702 L .31214 .54695 L F
0 .191 .626 r
.31239 .54712 m .31256 .54723 L .31192 .54579 L F
.449 .823 .992 r
.31296 .54749 m .31256 .54723 L .31192 .54579 L F
0 .191 .626 r
.31256 .54723 m .31286 .54742 L .31192 .54579 L F
.449 .823 .992 r
.31256 .54723 m .31167 .54664 L .31192 .54579 L F
0 .191 .626 r
.31286 .54742 m .31359 .5479 L .31373 .54797 L F
.31359 .5479 m .31448 .54849 L .3143 .54836 L F
0 0 0 r
.31445 .54826 m .31373 .54797 L .31532 .54653 L F
0 .191 .626 r
.31362 .54792 m .3143 .54836 L .31373 .54797 L F
.31306 .54756 m .31566 .54928 L .31286 .54742 L F
0 0 0 r
.31413 .5489 m .31373 .54797 L .31445 .54826 L F
0 .191 .626 r
.31359 .5479 m .31362 .54792 L .31373 .54797 L F
.449 .823 .992 r
.31287 .54753 m .31306 .54756 L .31224 .54829 L F
.31306 .54756 m .31387 .54815 L .31224 .54829 L F
.31273 .5476 m .31224 .54829 L .31115 .54839 L F
.31287 .54753 m .31224 .54829 L .31273 .5476 L F
0 .191 .626 r
.31286 .54742 m .31373 .54797 L .31305 .54715 L F
.31286 .54742 m .31305 .54715 L .31192 .54579 L F
.175 .672 .915 r
.29112 .6853 m .29571 .68606 L .29364 .68499 L F
.435 .875 .854 r
.29571 .68606 m .29666 .6852 L .29364 .68499 L F
.29571 .68606 m .2981 .68511 L .29666 .6852 L F
0 0 0 r
.51093 .42717 m .51337 .42636 L .51281 .42665 L F
.50991 .42851 m .51093 .42717 L .51281 .42665 L F
.706 .623 .762 r
.60413 .35018 m .60502 .35451 L .60797 .35149 L F
.114 .104 .568 r
.49992 .44964 m .49839 .44707 L .49971 .44645 L F
.881 .687 .635 r
.3501 .55148 m .35459 .54941 L .35242 .54646 L F
.3501 .55148 m .3525 .55226 L .35459 .54941 L F
.928 .547 .244 r
.38925 .55955 m .38745 .55864 L .38701 .55634 L F
.96 .7 .497 r
.38925 .55955 m .38715 .56162 L .38745 .55864 L F
.38925 .55955 m .38894 .56309 L .38715 .56162 L F
.885 .836 .793 r
.55847 .37725 m .55518 .37813 L .55661 .37531 L F
.55847 .37725 m .55555 .3806 L .55518 .37813 L F
.926 .891 .777 r
.44915 .55595 m .44606 .55818 L .44865 .55567 L F
.44915 .55595 m .44689 .55963 L .44606 .55818 L F
.784 .796 .863 r
.33071 .57957 m .32675 .57912 L .32901 .5781 L F
.555 .742 .964 r
.33317 .57884 m .33071 .57957 L .32901 .5781 L F
.055 0 0 r
.62299 .3482 m .62122 .3479 L .62406 .34774 L F
.62299 .3482 m .61992 .3491 L .62122 .3479 L F
.7 .48 .586 r
.382 .49977 m .385 .49981 L .38524 .49646 L F
.843 .682 .682 r
.36286 .57232 m .36457 .57623 L .3649 .5738 L F
.91 .787 .305 r
.56957 .40902 m .57 .40875 L .56965 .40758 L F
.058 0 .219 r
.56876 .41144 m .57066 .40833 L .57 .40875 L F
0 0 .42 r
.56944 .41151 m .56876 .41144 L .57 .40875 L F
.91 .787 .305 r
.56944 .41151 m .57 .40875 L .56957 .40902 L F
.058 0 .219 r
.57066 .40833 m .57139 .40714 L .57 .40875 L F
.763 .994 .799 r
.57139 .40714 m .57259 .40487 L .57137 .40664 L F
.57139 .40714 m .57453 .4042 L .57259 .40487 L F
.751 .899 .508 r
.57139 .40714 m .57137 .40664 L .57 .40875 L F
.938 .91 .524 r
.66708 .35749 m .66802 .35253 L .66844 .3553 L F
.135 0 0 r
.32455 .50404 m .3235 .5049 L .32686 .50367 L F
.594 .389 .572 r
.33276 .59817 m .3318 .60263 L .33502 .60211 L F
.774 .57 .622 r
.39323 .50601 m .39626 .50648 L .3958 .50259 L F
.677 .5 .639 r
.3958 .50259 m .39626 .50648 L .3995 .50293 L F
.85 .569 .512 r
.46569 .57481 m .46792 .57623 L .46747 .57253 L F
.812 .649 .681 r
.46349 .57235 m .46747 .57253 L .46589 .56928 L F
.784 .472 .46 r
.46569 .57481 m .46747 .57253 L .46349 .57235 L F
.628 .234 .277 r
.43984 .56483 m .4424 .56475 L .44362 .56188 L F
.149 0 0 r
.4424 .56475 m .44711 .56276 L .44362 .56188 L F
.684 .94 .963 r
.67424 .37577 m .67875 .37485 L .67776 .37375 L F
.847 .967 .878 r
.67875 .37485 m .67951 .37178 L .67776 .37375 L F
.67875 .37485 m .68179 .37186 L .67951 .37178 L F
.169 .099 .528 r
.27553 .54146 m .27346 .53954 L .27633 .53898 L F
.27553 .54146 m .27431 .54328 L .27346 .53954 L F
.588 .577 .808 r
.59145 .34088 m .59282 .3449 L .59556 .34412 L F
0 0 .305 r
.59282 .3449 m .59316 .34761 L .59373 .34466 L F
.784 .286 0 r
.33564 .55212 m .33932 .55539 L .33714 .55418 L F
.962 .688 .467 r
.33714 .55418 m .33612 .55216 L .33564 .55212 L F
.816 .923 .907 r
.33899 .55053 m .33524 .55208 L .33564 .55212 L F
.932 .819 .71 r
.33899 .55053 m .33564 .55212 L .3376 .54761 L F
.963 .937 .631 r
.3376 .54761 m .33564 .55212 L .33527 .55047 L F
.962 .688 .467 r
.33612 .55216 m .33527 .55047 L .33564 .55212 L F
.816 .923 .907 r
.33524 .55208 m .33411 .55255 L .33564 .55212 L F
.857 .792 .786 r
.33929 .54563 m .33899 .55053 L .3376 .54761 L F
.797 .962 .645 r
.55394 .43986 m .55329 .44098 L .55388 .43924 L F
.866 .785 .288 r
.55329 .44098 m .55268 .44143 L .55388 .43924 L F
.55329 .44098 m .55295 .4431 L .55268 .44143 L F
.576 .7 .927 r
.33773 .6472 m .33412 .64522 L .33654 .6442 L F
.62 .659 .866 r
.34108 .64561 m .33773 .6472 L .33654 .6442 L F
.929 .627 .449 r
.37127 .52527 m .36908 .52241 L .37185 .52369 L F
.639 .961 .914 r
.66961 .37922 m .66984 .37778 L .66779 .37927 L F
.66961 .37922 m .67219 .37766 L .66984 .37778 L F
.01 .571 .805 r
.32969 .59179 m .3347 .5923 L .33543 .59269 L F
.933 .778 .307 r
.33543 .59269 m .33466 .59113 L .33538 .59244 L F
.33543 .59269 m .3347 .5923 L .33466 .59113 L F
.202 0 0 r
.41307 .45434 m .41582 .45372 L .41672 .45313 L F
0 0 0 r
.41672 .45313 m .41819 .45267 L .41934 .45249 L F
.41672 .45313 m .41582 .45372 L .41819 .45267 L F
.687 .965 .741 r
.52716 .4148 m .5287 .41412 L .53092 .41177 L F
.836 .546 .499 r
.39484 .58541 m .39244 .58567 L .39222 .58286 L F
.627 .137 .069 r
.39484 .58541 m .39304 .58711 L .39244 .58567 L F
.375 0 0 r
.39675 .58655 m .39304 .58711 L .39484 .58541 L F
.927 .61 .421 r
.33709 .50888 m .33863 .51259 L .3384 .50994 L F
.822 .4 .24 r
.35234 .49318 m .35677 .49649 L .35417 .49347 L F
.277 .723 .961 r
.32888 .52264 m .32796 .52163 L .326 .51957 L F
.32888 .52264 m .331 .52246 L .32796 .52163 L F
.948 .665 .468 r
.5958 .37706 m .59602 .38017 L .59785 .38061 L F
.173 0 .207 r
.59723 .38283 m .59439 .38446 L .59785 .38061 L F
0 0 .116 r
.4427 .58396 m .44205 .58273 L .44402 .58486 L F
.4427 .58396 m .44163 .58564 L .44205 .58273 L F
0 0 0 r
.34247 .65649 m .34335 .65504 L .34482 .65398 L F
.62 .691 .895 r
.45141 .59527 m .45267 .5917 L .45021 .59396 L F
.45141 .59527 m .45394 .59439 L .45267 .5917 L F
.845 .888 .871 r
.50848 .49379 m .50395 .49546 L .50722 .49302 L F
.84 .985 .866 r
.51151 .49088 m .50848 .49379 L .50885 .49114 L F
.819 .974 .894 r
.50885 .49114 m .50848 .49379 L .50722 .49302 L F
.368 .273 .615 r
.31921 .5267 m .32133 .53072 L .32107 .52641 L F
.781 .854 .405 r
.56423 .38475 m .56326 .38623 L .56306 .38204 L F
.56423 .38475 m .56298 .38745 L .56326 .38623 L F
.621 .155 .127 r
.55262 .38093 m .55152 .38226 L .54865 .38076 L F
.634 .671 .868 r
.55518 .37813 m .55262 .38093 L .5513 .37723 L F
.55518 .37813 m .55555 .3806 L .55262 .38093 L F
0 0 0 r
.55555 .3806 m .55152 .38226 L .55262 .38093 L F
.59 .023 0 r
.39871 .51601 m .40233 .5182 L .40311 .51733 L F
.444 0 0 r
.40311 .51733 m .40233 .5182 L .40554 .51849 L F
.857 .67 .648 r
.35933 .6053 m .36105 .60613 L .35924 .60225 L F
.835 .726 .745 r
.35651 .60831 m .36105 .60613 L .35933 .6053 L F
.35651 .60831 m .35871 .60976 L .36105 .60613 L F
.915 .868 .778 r
.47641 .54223 m .4803 .53962 L .47964 .53931 L F
.47641 .54223 m .47813 .54338 L .4803 .53962 L F
.754 .966 .932 r
.48107 .53745 m .4803 .53962 L .48391 .53721 L F
.815 .996 .767 r
.48107 .53745 m .47964 .53931 L .4803 .53962 L F
.786 .729 .8 r
.35373 .61167 m .3582 .61188 L .35651 .60831 L F
.791 .708 .773 r
.35595 .61351 m .3582 .61188 L .35373 .61167 L F
.81 .738 .785 r
.35651 .60831 m .3582 .61188 L .35871 .60976 L F
.697 .577 .717 r
.2812 .52661 m .27855 .52988 L .28132 .52946 L F
.637 .491 .668 r
.28197 .52901 m .27855 .52988 L .2812 .52661 L F
.725 .476 .549 r
.28217 .53268 m .27855 .52988 L .28197 .52901 L F
.28217 .53268 m .27838 .5326 L .27855 .52988 L F
.748 .748 .852 r
.31649 .64537 m .31813 .6484 L .31351 .64812 L F
.758 .752 .847 r
.32074 .64543 m .31813 .6484 L .31649 .64537 L F
.631 .546 .74 r
.32074 .64543 m .32001 .64827 L .31813 .6484 L F
.642 .65 .843 r
.32232 .64856 m .31813 .6484 L .32001 .64827 L F
.352 .747 .985 r
.29857 .64822 m .29779 .64946 L .29559 .64873 L F
.29857 .64822 m .29998 .64929 L .29779 .64946 L F
.655 .763 .929 r
.58049 .35418 m .57696 .353 L .57968 .35214 L F
0 0 0 r
.57968 .35214 m .58394 .35181 L .58049 .35418 L F
.942 .951 .634 r
.45422 .53586 m .45359 .53852 L .45201 .53576 L F
0 0 .312 r
.59569 .3849 m .59439 .38446 L .59723 .38283 L F
.59569 .3849 m .59441 .38725 L .59439 .38446 L F
.579 .412 .619 r
.59456 .34099 m .59556 .34412 L .59834 .3408 L F
.878 .674 .623 r
.66926 .33784 m .66564 .33973 L .66567 .33743 L F
.66926 .33784 m .6678 .34089 L .66564 .33973 L F
.987 .768 .521 r
.31618 .51868 m .31794 .52027 L .31585 .52164 L F
.31618 .51868 m .31794 .52027 L .31585 .52164 L F
.584 .829 .991 r
.31883 .51252 m .31623 .51333 L .31449 .51204 L F
.934 .703 .566 r
.39222 .58286 m .38936 .58191 L .3903 .57858 L F
.859 .565 .489 r
.39222 .58286 m .38864 .58442 L .38936 .58191 L F
.39222 .58286 m .39244 .58567 L .38864 .58442 L F
.801 .993 .756 r
.48235 .51951 m .48278 .51767 L .48522 .51636 L F
.876 .992 .748 r
.48522 .51636 m .48278 .51767 L .48552 .51387 L F
.733 .271 .153 r
.33553 .58086 m .338 .57943 L .33588 .57779 L F
.33553 .58086 m .33981 .58182 L .338 .57943 L F
.306 0 0 r
.64721 .34179 m .64607 .34344 L .64316 .34374 L F
.281 0 .012 r
.64988 .34084 m .64607 .34344 L .64721 .34179 L F
.653 .826 .966 r
.57696 .353 m .57408 .35425 L .57226 .3523 L F
0 0 .42 r
.56944 .41151 m .56975 .41366 L .56876 .41144 L F
.777 .483 0 r
.58709 .4014 m .58765 .40372 L .58664 .40016 L F
.66 .166 .067 r
.25299 .57813 m .24948 .57812 L .25074 .57612 L F
.621 .206 .233 r
.2556 .57637 m .25299 .57813 L .25074 .57612 L F
.882 .658 .595 r
.34974 .53463 m .35215 .53323 L .34981 .53255 L F
.34974 .53463 m .3517 .53602 L .35215 .53323 L F
.916 .979 .755 r
.51152 .39525 m .5119 .39239 L .51298 .39291 L F
.51152 .39525 m .50956 .39604 L .5119 .39239 L F
.894 .989 .763 r
.57259 .40487 m .57453 .4042 L .57431 .40286 L F
.141 .54 .922 r
.67281 .30908 m .67482 .30975 L .67544 .31105 L F
0 0 .534 r
.6772 .31174 m .67544 .31105 L .67482 .30975 L F
.6772 .31174 m .67644 .31239 L .67544 .31105 L F
.871 .911 .855 r
.5168 .38886 m .5129 .39004 L .51441 .38842 L F
.5168 .38886 m .51417 .3916 L .5129 .39004 L F
.774 .945 .934 r
.5168 .38886 m .51754 .38618 L .51888 .387 L F
.5168 .38886 m .51441 .38842 L .51754 .38618 L F
.777 .992 .771 r
.2559 .5752 m .25299 .57813 L .2556 .57637 L F
.917 .661 .535 r
.3525 .55226 m .35575 .55615 L .35648 .55329 L F
.3525 .55226 m .35222 .55526 L .35575 .55615 L F
.902 .7 .62 r
.35172 .55815 m .35575 .55615 L .35222 .55526 L F
.35172 .55815 m .35403 .55924 L .35575 .55615 L F
.848 .621 .594 r
.35575 .55615 m .35403 .55924 L .35757 .55964 L F
.933 .595 .371 r
.38264 .54256 m .38063 .5418 L .38037 .53935 L F
.851 .59 .544 r
.38402 .54552 m .38063 .5418 L .38264 .54256 L F
.814 .716 .757 r
.56812 .44317 m .57037 .44425 L .56892 .4403 L F
.843 .939 .887 r
.56596 .4463 m .57037 .44425 L .56812 .44317 L F
.68 .915 .974 r
.4826 .43121 m .48476 .43203 L .48698 .43071 L F
.819 .608 .618 r
.35318 .5618 m .35757 .55964 L .35403 .55924 L F
.35318 .5618 m .35736 .56254 L .35757 .55964 L F
.125 0 .319 r
.42932 .60581 m .4318 .60223 L .43157 .60515 L F
0 0 0 r
.4281 .60714 m .42932 .60581 L .43157 .60515 L F
.46 .51 .823 r
.58193 .43728 m .58474 .43695 L .58339 .43519 L F
.797 .975 .907 r
.5909 .34953 m .59196 .34661 L .59316 .34761 L F
0 0 .445 r
.593 .35027 m .5909 .34953 L .59316 .34761 L F
.808 .863 .418 r
.51269 .48899 m .51252 .48866 L .51365 .48691 L F
0 0 0 r
.51655 .48403 m .51365 .48691 L .51505 .48583 L F
.51365 .48691 m .51252 .48866 L .51505 .48583 L F
.313 0 .199 r
.27165 .52216 m .27522 .51868 L .27281 .51898 L F
.441 .179 .418 r
.29705 .5857 m .29402 .58878 L .29419 .58602 L F
0 0 .128 r
.29402 .58878 m .29528 .58531 L .29419 .58602 L F
.707 .572 .701 r
.28385 .52308 m .2812 .52661 L .28024 .52236 L F
.872 .604 .531 r
.4109 .52854 m .41342 .52635 L .4111 .52571 L F
.4109 .52854 m .41425 .52999 L .41342 .52635 L F
.823 .724 .757 r
.5943 .39764 m .59738 .39853 L .59637 .3945 L F
.754 .906 .944 r
.59272 .39993 m .59738 .39853 L .5943 .39764 L F
.516 .478 .753 r
.59738 .39853 m .59894 .39317 L .59637 .3945 L F
.59738 .39853 m .60045 .39795 L .59894 .39317 L F
.47 .288 .551 r
.59738 .39853 m .60017 .39931 L .60045 .39795 L F
.971 .727 .511 r
.34776 .52564 m .34754 .529 L .34958 .52989 L F
.965 .663 .405 r
.34751 .53039 m .34958 .52989 L .34754 .529 L F
.34751 .53039 m .34981 .53255 L .34958 .52989 L F
.979 .912 .657 r
.33835 .54234 m .33839 .53894 L .34222 .53948 L F
.33835 .54234 m .33724 .54171 L .33839 .53894 L F
.947 .74 .275 r
.39807 .51479 m .39882 .51329 L .39745 .51192 L F
.39807 .51479 m .39871 .51601 L .39882 .51329 L F
0 0 .354 r
.59125 .41026 m .59235 .41253 L .59144 .41058 L F
.606 .948 .923 r
.4216 .45157 m .42508 .44997 L .42623 .45026 L F
.621 .95 .774 r
.42623 .45026 m .42742 .44869 L .42929 .44798 L F
.592 .943 .924 r
.42508 .44997 m .42742 .44869 L .42623 .45026 L F
.86 .668 .641 r
.46177 .56599 m .46206 .56308 L .46022 .56203 L F
.993 .844 .59 r
.41663 .46685 m .41764 .4635 L .41608 .4619 L F
.852 .92 .876 r
.41608 .4619 m .41764 .4635 L .42094 .45966 L F
.901 .747 .681 r
.408 .52004 m .40688 .52252 L .40865 .52266 L F
.816 .381 .208 r
.4074 .52398 m .40865 .52266 L .40688 .52252 L F
.4074 .52398 m .4111 .52571 L .40865 .52266 L F
.507 .307 .543 r
.28385 .52308 m .28405 .52606 L .2812 .52661 L F
.881 .988 .812 r
.51298 .39291 m .5119 .39239 L .51417 .3916 L F
.965 .889 .704 r
.51417 .3916 m .5119 .39239 L .5129 .39004 L F
.779 .497 .508 r
.67665 .32352 m .68054 .32159 L .67677 .32163 L F
.67665 .32352 m .68069 .32408 L .68054 .32159 L F
.738 .986 .899 r
.51151 .49088 m .51252 .48866 L .51269 .48899 L F
.51151 .49088 m .50885 .49114 L .51252 .48866 L F
.885 .818 .777 r
.25664 .56641 m .25606 .56944 L .25398 .56785 L F
.592 .531 .755 r
.25876 .56895 m .25606 .56944 L .25664 .56641 L F
.337 .501 .873 r
.28249 .64814 m .28461 .65176 L .28631 .65145 L F
.695 .665 .816 r
.28424 .65493 m .28631 .65145 L .28461 .65176 L F
.178 0 0 r
.55661 .37531 m .55934 .37513 L .55956 .3742 L F
0 .05 .601 r
.56252 .37131 m .56379 .37195 L .56328 .37123 L F
0 0 0 r
.56334 .36965 m .5619 .37139 L .56252 .37131 L F
.56334 .36965 m .56466 .36865 L .56614 .36953 L F
.56334 .36965 m .56252 .37131 L .56466 .36865 L F
.769 .696 .154 r
.56252 .37131 m .56294 .36697 L .56466 .36865 L F
.56252 .37131 m .56248 .3701 L .56294 .36697 L F
0 .05 .601 r
.56252 .37131 m .56328 .37123 L .56248 .3701 L F
0 0 0 r
.5619 .37139 m .55956 .3742 L .56252 .37131 L F
.925 .929 .559 r
.48235 .51951 m .48085 .52348 L .48081 .52095 L F
.805 .937 .573 r
.48235 .51951 m .48081 .52095 L .48278 .51767 L F
.429 .869 .802 r
.64767 .39836 m .64923 .39817 L .65183 .39696 L F
.378 .422 .78 r
.61433 .39649 m .61529 .4009 L .61885 .39845 L F
.84 .913 .885 r
.31488 .62487 m .31571 .62745 L .3179 .62472 L F
.804 .667 .713 r
.36286 .57232 m .36054 .57563 L .36457 .57623 L F
.835 .689 .702 r
.36013 .57848 m .36457 .57623 L .36054 .57563 L F
.36013 .57848 m .36385 .57904 L .36457 .57623 L F
.687 .98 .878 r
.46122 .44237 m .46546 .44047 L .46351 .44106 L F
.664 .951 .953 r
.46652 .43848 m .46546 .44047 L .46744 .43921 L F
.721 .986 .802 r
.46351 .44106 m .46546 .44047 L .46652 .43848 L F
.654 .796 .951 r
.50558 .42255 m .50323 .42438 L .50217 .42239 L F
.84 .901 .88 r
.47049 .43817 m .47448 .4368 L .47375 .43623 L F
.73 .972 .929 r
.47448 .4368 m .47525 .43445 L .47375 .43623 L F
.47448 .4368 m .4779 .43454 L .47525 .43445 L F
0 0 .542 r
.57312 .38364 m .57493 .38588 L .57485 .38647 L F
.6 .079 0 r
.5759 .38801 m .57485 .38647 L .57493 .38588 L F
.872 .444 .031 r
.57438 .38686 m .5759 .38801 L .57493 .38588 L F
0 0 .371 r
.5745 .38694 m .5759 .38801 L .57438 .38686 L F
.6 .079 0 r
.5759 .38801 m .57739 .38915 L .57485 .38647 L F
0 0 .371 r
.57771 .38925 m .5759 .38801 L .5745 .38694 L F
.6 .079 0 r
.5759 .38801 m .57757 .38934 L .57739 .38915 L F
.765 .663 .749 r
.32996 .54907 m .33155 .55333 L .32747 .55312 L F
.292 .762 .939 r
.33155 .55333 m .32978 .55275 L .32747 .55312 L F
.552 .602 .857 r
.33162 .55046 m .33155 .55333 L .32996 .54907 L F
.33162 .55046 m .33411 .55255 L .33155 .55333 L F
.938 .907 .766 r
.33162 .55046 m .33155 .55333 L .33411 .55255 L F
.33162 .55046 m .32978 .55275 L .33155 .55333 L F
0 0 0 r
.3203 .54324 m .32004 .5442 L .32207 .54175 L F
.3203 .54324 m .31789 .54508 L .32004 .5442 L F
.347 .823 .8 r
.50353 .44485 m .50759 .4439 L .50594 .4453 L F
.105 0 0 r
.50759 .4439 m .50876 .4446 L .50594 .4453 L F
.50759 .4439 m .5104 .44337 L .50876 .4446 L F
.791 .873 .909 r
.42442 .45749 m .4278 .45755 L .42616 .45663 L F
.401 .766 .994 r
.4278 .45755 m .42868 .45612 L .42616 .45663 L F
.4278 .45755 m .43074 .4573 L .42868 .45612 L F
0 0 .562 r
.6922 .35387 m .69034 .35131 L .69005 .34978 L F
.966 .938 .667 r
.65073 .38236 m .6519 .38329 L .65013 .38373 L F
.851 .567 .508 r
.64935 .38052 m .65282 .38403 L .6519 .38329 L F
0 .055 .603 r
.64935 .38052 m .6519 .38329 L .65123 .38197 L F
.966 .938 .667 r
.65169 .38135 m .6519 .38329 L .65086 .38247 L F
0 .055 .603 r
.65123 .38197 m .6519 .38329 L .65137 .38207 L F
.966 .938 .667 r
.65159 .38043 m .65169 .38135 L .65118 .38188 L F
0 .055 .603 r
.64935 .38052 m .65123 .38197 L .64881 .38248 L F
.966 .938 .667 r
.65106 .38163 m .65118 .38188 L .65073 .38236 L F
.65159 .38043 m .65118 .38188 L .65106 .38163 L F
0 .055 .603 r
.65123 .38197 m .65137 .38207 L .65112 .38211 L F
.65123 .38197 m .65112 .38211 L .64881 .38248 L F
.966 .938 .667 r
.65169 .38135 m .65086 .38247 L .65073 .38236 L F
.851 .567 .508 r
.65282 .38403 m .65296 .38416 L .6519 .38329 L F
.598 .887 .991 r
.65296 .38416 m .64888 .38417 L .6519 .38329 L F
.477 .224 .451 r
.28405 .52606 m .2832 .52888 L .2812 .52661 L F
.086 .153 .638 r
.2812 .52661 m .2832 .52888 L .28197 .52901 L F
.477 .224 .451 r
.28405 .52606 m .2832 .52888 L .2812 .52661 L F
.743 .595 .691 r
.46589 .56928 m .46608 .56641 L .46177 .56599 L F
.978 .722 .478 r
.3007 .61094 m .30261 .60911 L .30083 .60805 L F
.729 .94 .62 r
.30237 .59253 m .29972 .59588 L .30041 .59423 L F
.621 .463 .647 r
.29972 .59588 m .30288 .59512 L .30237 .59253 L F
.555 .876 .992 r
.30041 .59423 m .30288 .59512 L .29972 .59588 L F
.978 .722 .478 r
.3007 .61094 m .30261 .60911 L .30083 .60805 L F
.784 .709 .781 r
.35363 .61619 m .35373 .61167 L .35097 .61475 L F
.35363 .61619 m .35595 .61351 L .35373 .61167 L F
.841 .687 .691 r
.35097 .61475 m .3528 .61894 L .35363 .61619 L F
.842 .761 .773 r
.46531 .55518 m .4629 .55877 L .465 .56011 L F
.813 .839 .372 r
.50853 .43365 m .50991 .42851 L .50755 .43267 L F
.44 0 .061 r
.51052 .43537 m .50853 .43365 L .5073 .43563 L F
.51052 .43537 m .51161 .4342 L .50853 .43365 L F
.72 .717 .847 r
.45459 .56814 m .45553 .56642 L .45103 .56578 L F
.812 .747 .791 r
.54415 .47586 m .54636 .47737 L .54488 .47368 L F
0 .114 .667 r
.57173 .35715 m .57178 .35525 L .56974 .35355 L F
.74 .686 .141 r
.57178 .35525 m .57226 .3523 L .56974 .35355 L F
.987 .759 .366 r
.57178 .35525 m .57107 .3569 L .57179 .35462 L F
.57178 .35525 m .57179 .35462 L .57186 .35441 L F
0 .114 .667 r
.57203 .35769 m .57178 .35525 L .57173 .35715 L F
.475 0 0 r
.57203 .35769 m .57207 .3585 L .57178 .35525 L F
.57203 .35769 m .57283 .35876 L .57207 .3585 L F
.268 0 0 r
.40377 .4583 m .40585 .45679 L .40366 .45726 L F
.696 .444 .539 r
.45649 .57525 m .46018 .57474 L .45976 .57245 L F
.602 .49 .699 r
.45976 .57245 m .4621 .56885 L .45914 .56937 L F
.45976 .57245 m .46349 .57235 L .4621 .56885 L F
.592 .395 .584 r
.4631 .57525 m .45976 .57245 L .46018 .57474 L F
.4631 .57525 m .46349 .57235 L .45976 .57245 L F
.594 .678 .899 r
.30781 .62447 m .31021 .62819 L .31196 .62631 L F
.807 .334 .095 r
.32622 .55603 m .33134 .55965 L .32888 .55982 L F
.11 .663 .787 r
.33245 .55974 m .33134 .55965 L .32888 .55982 L F
.3331 .55973 m .33134 .55965 L .32888 .55982 L F
0 0 0 r
.32988 .56038 m .32888 .55982 L .33134 .55965 L F
.807 .334 .095 r
.32622 .55603 m .3294 .55998 L .33134 .55965 L F
.883 .99 .797 r
.33134 .55965 m .3294 .55998 L .32974 .55953 L F
.33134 .55965 m .32974 .55953 L .33166 .55695 L F
.11 .663 .787 r
.3331 .55973 m .33134 .55965 L .33245 .55974 L F
.751 .979 .916 r
.3332 .55797 m .33134 .55965 L .3331 .55973 L F
.3331 .55973 m .33134 .55965 L .3332 .55797 L F
.3332 .55797 m .33134 .55965 L .3331 .55973 L F
.403 .83 .961 r
.29998 .64929 m .3025 .64849 L .30436 .64917 L F
.531 .894 .972 r
.30436 .64917 m .30553 .64759 L .30708 .64871 L F
.30436 .64917 m .3025 .64849 L .30553 .64759 L F
.824 .658 .676 r
.46538 .58231 m .46951 .57984 L .46725 .57902 L F
.46538 .58231 m .4689 .58242 L .46951 .57984 L F
.592 .531 .755 r
.25876 .56895 m .25664 .56641 L .25953 .56615 L F
.723 .503 0 r
.25922 .56458 m .25953 .56615 L .25884 .56207 L F
0 .137 .677 r
.25922 .56458 m .26153 .56796 L .25953 .56615 L F
.45 .244 .508 r
.26153 .56796 m .25876 .56895 L .25953 .56615 L F
.127 0 0 r
.64435 .33598 m .64838 .33424 L .64557 .33483 L F
.832 .875 .875 r
.53643 .35994 m .53673 .36338 L .53816 .36126 L F
.931 .895 .77 r
.6181 .389 m .62205 .38436 L .62098 .38382 L F
.61793 .38929 m .61799 .38923 L .61798 .3892 L F
.666 .965 .928 r
.61813 .38916 m .61853 .38963 L .61632 .39082 L F
.677 .571 .728 r
.61948 .38912 m .61981 .39142 L .61632 .39082 L F
.329 .166 .503 r
.61632 .39082 m .61918 .39117 L .61813 .38916 L F
.701 .608 .749 r
.61792 .38923 m .61793 .38929 L .61798 .3892 L F
.61792 .38923 m .61798 .3892 L .62098 .38382 L F
.931 .895 .77 r
.61793 .38929 m .61948 .38912 L .62205 .38436 L F
.704 .904 .967 r
.61812 .38915 m .61813 .38916 L .61809 .38916 L F
.61812 .38915 m .61809 .38916 L .61797 .38916 L F
.701 .608 .749 r
.61738 .38461 m .61792 .38923 L .61809 .38894 L F
.575 .041 0 r
.61465 .38915 m .61801 .38916 L .61763 .39045 L F
.61693 .39061 m .61763 .39045 L .61747 .39096 L F
.61465 .38915 m .61763 .39045 L .61693 .39061 L F
.515 .494 .772 r
.61393 .39119 m .61514 .39479 L .61349 .39131 L F
0 0 0 r
.61271 .39155 m .61349 .39131 L .61593 .39084 L F
.931 .895 .77 r
.61799 .38923 m .61813 .38906 L .61798 .3892 L F
.575 .041 0 r
.61801 .38916 m .61813 .38916 L .61811 .3892 L F
.61801 .38916 m .61811 .3892 L .61747 .39096 L F
.536 .486 .747 r
.61512 .38694 m .61757 .38899 L .61738 .38461 L F
.61757 .38899 m .61793 .38929 L .61791 .38912 L F
.61757 .38899 m .61791 .38912 L .61738 .38461 L F
.704 .904 .967 r
.61713 .38707 m .61777 .38841 L .61465 .38915 L F
.61777 .38841 m .61797 .38916 L .61465 .38915 L F
.914 .672 .174 r
.61747 .39096 m .61812 .38917 L .61783 .38882 L F
.61738 .38995 m .61783 .38882 L .61722 .38811 L F
.61747 .39096 m .61783 .38882 L .61738 .38995 L F
.575 .041 0 r
.61465 .38915 m .61624 .39017 L .61393 .39119 L F
.788 .632 .688 r
.61981 .39142 m .61812 .3924 L .61632 .39082 L F
.61812 .3924 m .61647 .39335 L .61637 .39163 L F
.61812 .3924 m .61637 .39163 L .61632 .39082 L F
.61981 .39142 m .62057 .39435 L .61647 .39335 L F
.906 .609 .114 r
.61918 .39117 m .62057 .39435 L .61981 .39142 L F
.513 .775 .991 r
.62208 .39236 m .62073 .39325 L .61918 .39117 L F
.62107 .3937 m .6201 .39327 L .61918 .39117 L F
.368 .347 .704 r
.62204 .38903 m .61981 .39142 L .61948 .38912 L F
.906 .609 .114 r
.61918 .39117 m .61981 .39142 L .62204 .38903 L F
.657 .456 .6 r
.61918 .39117 m .62208 .39236 L .62204 .38903 L F
.906 .609 .114 r
.61918 .39117 m .62204 .38903 L .62208 .39236 L F
.493 .325 .582 r
.62204 .38903 m .62208 .39213 L .62472 .39116 L F
.62208 .39213 m .62208 .39236 L .62472 .39116 L F
.474 .203 .422 r
.62552 .39198 m .62934 .38845 L .62597 .38844 L F
.512 .891 .965 r
.62718 .39027 m .62472 .39116 L .62357 .39061 L F
.62728 .39026 m .62472 .39116 L .62718 .39027 L F
.528 0 0 r
.6197 .39253 m .62208 .39236 L .61918 .39117 L F
.474 .895 .866 r
.62332 .39154 m .62208 .39236 L .6197 .39253 L F
.62472 .39116 m .62208 .39236 L .62332 .39154 L F
.513 .775 .991 r
.62208 .39236 m .62107 .3937 L .62073 .39325 L F
.62107 .3937 m .62057 .39435 L .6201 .39327 L F
.329 .166 .503 r
.61632 .39082 m .61647 .39335 L .61918 .39117 L F
.575 .041 0 r
.61624 .39017 m .61747 .39096 L .61393 .39119 L F
.914 .672 .174 r
.61812 .38917 m .61813 .38916 L .61812 .38916 L F
.61812 .38917 m .61812 .38916 L .61722 .38811 L F
.701 .608 .749 r
.61738 .38461 m .61809 .38894 L .62098 .38382 L F
.931 .895 .77 r
.61798 .3892 m .61813 .38906 L .6181 .389 L F
.704 .904 .967 r
.61777 .38841 m .61812 .38915 L .61797 .38916 L F
.914 .672 .174 r
.61722 .38811 m .6181 .38913 L .61777 .38841 L F
.6181 .38913 m .61813 .38916 L .6181 .3891 L F
.6181 .38913 m .6181 .3891 L .61777 .38841 L F
.931 .895 .77 r
.61813 .38906 m .62205 .38436 L .6181 .389 L F
.914 .672 .174 r
.61715 .3873 m .61777 .38841 L .61713 .38707 L F
.61722 .38811 m .61777 .38841 L .61715 .3873 L F
.666 .965 .928 r
.61813 .38916 m .61948 .38912 L .61853 .38963 L F
.029 .6 .712 r
.62204 .38903 m .61948 .38912 L .61813 .38916 L F
.657 .456 .6 r
.61918 .39117 m .62204 .38903 L .61813 .38916 L F
.876 .439 .072 r
.61747 .39096 m .61918 .39117 L .61813 .38916 L F
.914 .672 .174 r
.61747 .39096 m .61713 .38707 L .61934 .38933 L F
.294 .76 .943 r
.61393 .39119 m .61747 .39096 L .61782 .39047 L F
.61393 .39119 m .61713 .3906 L .61379 .39125 L F
.61393 .39119 m .61379 .39125 L .61349 .39131 L F
.61713 .3906 m .61782 .39047 L .61712 .39061 L F
.61713 .3906 m .61712 .39061 L .61349 .39131 L F
0 0 0 r
.6143 .39121 m .61593 .39084 L .61782 .39047 L F
.61271 .39155 m .61593 .39084 L .6143 .39121 L F
.701 .608 .749 r
.61716 .38273 m .61738 .38461 L .62098 .38382 L F
.536 .486 .747 r
.6171 .38285 m .61738 .38461 L .61716 .38273 L F
.61512 .38694 m .61738 .38461 L .6171 .38285 L F
.922 .682 .558 r
.68816 .34277 m .69122 .34127 L .6879 .34023 L F
.68816 .34277 m .69092 .34354 L .69122 .34127 L F
0 .234 .753 r
.57302 .36429 m .57557 .36629 L .57337 .36265 L F
0 .242 .757 r
.5754 .367 m .57557 .36629 L .57302 .36429 L F
.993 .749 .448 r
.28171 .67186 m .28008 .67353 L .2794 .67143 L F
.28171 .67186 m .28148 .67486 L .28008 .67353 L F
.246 0 .286 r
.59268 .37483 m .59491 .37375 L .59561 .37156 L F
.172 0 .153 r
.59268 .37483 m .59194 .37668 L .59491 .37375 L F
.917 .954 .801 r
.47956 .52544 m .48081 .52095 L .48085 .52348 L F
.985 .885 .54 r
.59149 .43381 m .59086 .43764 L .58987 .4353 L F
.943 .95 .75 r
.58987 .4353 m .59086 .43764 L .58872 .44012 L F
.853 .965 .874 r
.67951 .37178 m .68179 .37186 L .68325 .36983 L F
.805 .848 .883 r
.32969 .59179 m .3252 .59198 L .32772 .58831 L F
.32969 .59179 m .32745 .59326 L .3252 .59198 L F
.24 .634 .959 r
.32972 .59001 m .32969 .59179 L .32772 .58831 L F
.32972 .59001 m .3347 .5923 L .32969 .59179 L F
.378 .337 .686 r
.24688 .54245 m .24892 .54179 L .24818 .53918 L F
.434 .271 .559 r
.24688 .54245 m .24928 .54517 L .24892 .54179 L F
.24688 .54245 m .2463 .5464 L .24928 .54517 L F
.817 .703 .74 r
.34604 .62177 m .35014 .62217 L .34857 .61847 L F
.753 .677 .776 r
.35014 .62217 m .3528 .61894 L .34857 .61847 L F
.866 .996 .791 r
.4904 .50945 m .48695 .51217 L .48911 .50834 L F
.87 .93 .861 r
.4933 .50626 m .4904 .50945 L .48911 .50834 L F
.742 .682 .793 r
.32315 .64416 m .3248 .64583 L .32074 .64543 L F
.713 .575 .698 r
.3248 .64583 m .32001 .64827 L .32074 .64543 L F
.3248 .64583 m .3248 .64865 L .32001 .64827 L F
.594 .635 .861 r
.32542 .64253 m .3248 .64583 L .32315 .64416 L F
.32542 .64253 m .32733 .6455 L .3248 .64583 L F
.586 .471 .689 r
.32733 .6455 m .3248 .64865 L .3248 .64583 L F
.871 .788 .765 r
.32745 .59326 m .32333 .59444 L .3252 .59198 L F
.32745 .59326 m .32625 .5954 L .32333 .59444 L F
.855 .941 .877 r
.51647 .49797 m .51675 .50032 L .51725 .49924 L F
.51647 .49797 m .51549 .49932 L .51675 .50032 L F
.884 .82 .78 r
.38978 .57601 m .38765 .57529 L .38988 .57194 L F
.875 .68 .635 r
.3903 .57858 m .38765 .57529 L .38978 .57601 L F
0 0 .156 r
.57506 .37077 m .57557 .36629 L .5754 .367 L F
.57506 .37077 m .57561 .3689 L .57557 .36629 L F
0 .081 .63 r
.57506 .37077 m .57687 .37303 L .57561 .3689 L F
.324 0 .018 r
.33078 .67551 m .33231 .67672 L .32995 .67732 L F
.33078 .67551 m .33337 .67518 L .33231 .67672 L F
.428 .064 .243 r
.26319 .5256 m .26568 .52537 L .26643 .52337 L F
.426 .08 .274 r
.26568 .52537 m .26897 .52286 L .26643 .52337 L F
.319 .26 .633 r
.30468 .59472 m .30288 .59512 L .30237 .59253 L F
.675 .213 .146 r
.30237 .59253 m .30468 .59472 L .30041 .59423 L F
.996 .848 .57 r
.56652 .45026 m .56596 .4463 L .56365 .44949 L F
.893 .739 .684 r
.56512 .45364 m .56652 .45026 L .56365 .44949 L F
0 0 .213 r
.40445 .5577 m .40208 .56241 L .40572 .5592 L F
.641 .413 .556 r
.40208 .56241 m .40532 .56152 L .40572 .5592 L F
.618 .862 .989 r
.40445 .5577 m .40572 .5592 L .40685 .55822 L F
.548 .706 .944 r
.40572 .5592 m .40707 .55904 L .40685 .55822 L F
.655 .468 .618 r
.40532 .56152 m .40707 .55904 L .40572 .5592 L F
.586 .279 .415 r
.51442 .41875 m .51833 .41739 L .51784 .41559 L F
.404 .335 .666 r
.51784 .41559 m .5205 .41308 L .51788 .4138 L F
.51784 .41559 m .52088 .41646 L .5205 .41308 L F
.459 .204 .44 r
.51784 .41559 m .51833 .41739 L .52088 .41646 L F
.76 .732 .827 r
.4254 .57274 m .42193 .57504 L .42118 .57212 L F
.966 .659 .384 r
.55295 .4431 m .55122 .44514 L .55268 .44143 L F
.55295 .4431 m .55301 .44394 L .55122 .44514 L F
.821 .746 .78 r
.45553 .56642 m .45777 .56548 L .45604 .56179 L F
.77 .726 .812 r
.45777 .56548 m .46022 .56203 L .45604 .56179 L F
.86 .668 .641 r
.46177 .56599 m .46022 .56203 L .45777 .56548 L F
.381 .072 .311 r
.3369 .67157 m .33844 .6742 L .33589 .67467 L F
.3369 .67157 m .33923 .67089 L .33844 .6742 L F
.894 .734 .677 r
.6678 .34089 m .66934 .34446 L .66706 .3439 L F
.9 .61 .485 r
.66934 .34446 m .6673 .34623 L .66706 .3439 L F
.66934 .34446 m .66995 .34759 L .6673 .34623 L F
0 .169 .69 r
.42917 .5701 m .42777 .5698 L .42595 .56878 L F
.42917 .5701 m .43026 .57183 L .42777 .5698 L F
.989 .724 .403 r
.57677 .39221 m .57809 .3909 L .57757 .38934 L F
.57677 .39221 m .57802 .39314 L .57809 .3909 L F
.901 .582 .432 r
.41705 .59198 m .41795 .59529 L .41978 .59472 L F
.073 0 0 r
.41978 .59472 m .41795 .59529 L .4221 .59458 L F
.388 0 0 r
.60048 .35104 m .59924 .35172 L .59697 .35085 L F
.344 .822 .859 r
.60413 .35018 m .60235 .35018 L .60048 .35104 L F
0 0 0 r
.60235 .35018 m .59924 .35172 L .60048 .35104 L F
.932 .815 .708 r
.56924 .43556 m .5709 .43658 L .56974 .43287 L F
.954 .862 .711 r
.56746 .43908 m .5709 .43658 L .56924 .43556 L F
.56746 .43908 m .56892 .4403 L .5709 .43658 L F
.873 .795 .771 r
.56974 .43287 m .5709 .43658 L .57172 .43429 L F
.305 .024 .312 r
.59561 .37156 m .59702 .37304 L .59731 .37025 L F
.59561 .37156 m .59491 .37375 L .59702 .37304 L F
.321 0 .17 r
.26274 .55345 m .2623 .55531 L .25922 .55599 L F
.558 .156 .236 r
.26497 .55515 m .2623 .55531 L .26274 .55345 L F
.509 .186 .354 r
.26563 .55291 m .26497 .55515 L .26274 .55345 L F
.743 .595 .691 r
.46589 .56928 m .46177 .56599 L .4621 .56885 L F
.758 .567 .639 r
.4621 .56885 m .46349 .57235 L .46589 .56928 L F
.453 .602 .909 r
.30514 .60603 m .30785 .60618 L .30619 .60381 L F
.30514 .60603 m .30785 .60618 L .30619 .60381 L F
0 0 .234 r
.49946 .44006 m .49772 .44443 L .49812 .44383 L F
.737 .664 .779 r
.49517 .43941 m .49781 .44425 L .49234 .44319 L F
.49781 .44425 m .49773 .44436 L .49234 .44319 L F
.663 .881 .516 r
.49768 .44443 m .49772 .44443 L .49731 .44494 L F
.49812 .44383 m .49794 .4441 L .49775 .44434 L F
.49812 .44383 m .49775 .44434 L .49781 .44425 L F
.541 .576 .839 r
.49886 .44269 m .49794 .44449 L .49781 .44425 L F
0 0 .234 r
.49923 .44106 m .49812 .44383 L .49886 .44269 L F
.49946 .44006 m .49812 .44383 L .49923 .44106 L F
.541 .576 .839 r
.49886 .44269 m .49781 .44425 L .49517 .43941 L F
.663 .881 .516 r
.49781 .44425 m .49775 .44434 L .49768 .44443 L F
.49794 .4441 m .49772 .44443 L .49768 .44443 L F
.772 .523 .559 r
.49234 .44319 m .49768 .44443 L .49622 .44628 L F
.49768 .44443 m .49794 .44449 L .49622 .44628 L F
.737 .664 .779 r
.49789 .44439 m .49786 .44447 L .49234 .44319 L F
.663 .881 .516 r
.49886 .44269 m .49812 .44383 L .49622 .44628 L F
.49812 .44383 m .49731 .44494 L .49622 .44628 L F
.737 .664 .779 r
.49781 .44425 m .49789 .44439 L .49773 .44436 L F
.49789 .44439 m .49794 .44449 L .49786 .44447 L F
.659 .207 .168 r
.28148 .67486 m .28602 .67499 L .28376 .67725 L F
.323 .607 .95 r
.28602 .67499 m .28832 .67499 L .28606 .67271 L F
.892 .953 .607 r
.28376 .67725 m .28602 .67499 L .28606 .67271 L F
.588 .195 .266 r
.38613 .46974 m .38817 .47136 L .38413 .47231 L F
.633 .138 .06 r
.38613 .46974 m .38883 .47066 L .38817 .47136 L F
.84 .918 .886 r
.34033 .5933 m .34023 .59071 L .34198 .59183 L F
.639 .505 .683 r
.4621 .56885 m .46177 .56599 L .45914 .56937 L F
.478 .847 .989 r
.62927 .38783 m .62597 .38844 L .62874 .3852 L F
0 0 0 r
.62874 .3852 m .62597 .38844 L .62846 .38555 L F
.478 .847 .989 r
.62597 .38844 m .62927 .38783 L .62934 .38845 L F
.484 .534 .833 r
.62597 .38844 m .62934 .38845 L .62846 .38555 L F
.796 .693 .752 r
.36314 .59151 m .3604 .59492 L .36455 .59532 L F
.789 .715 .782 r
.3604 .59492 m .36171 .59819 L .36455 .59532 L F
.775 .684 .762 r
.36314 .59151 m .36455 .59532 L .36501 .59296 L F
.193 0 0 r
.61768 .3807 m .61404 .3835 L .61716 .38273 L F
.272 0 .034 r
.62002 .38158 m .61768 .3807 L .61716 .38273 L F
.62002 .38158 m .62042 .38003 L .61768 .3807 L F
.844 .843 .843 r
.47581 .52879 m .47561 .53056 L .47351 .52894 L F
.549 .913 .956 r
.66313 .37038 m .65979 .37098 L .66284 .36988 L F
.978 .916 .66 r
.66343 .36698 m .66313 .37038 L .66284 .36988 L F
.637 .221 .236 r
.32001 .64827 m .3248 .64865 L .32232 .64856 L F
.743 .908 .531 r
.43909 .56592 m .43984 .56483 L .43849 .566 L F
.189 0 0 r
.38996 .4632 m .39248 .46245 L .394 .46022 L F
.088 0 0 r
.39248 .46245 m .3966 .45995 L .394 .46022 L F
.265 .432 .841 r
.29831 .65641 m .29928 .65431 L .29732 .6546 L F
.525 .881 .982 r
.50488 .41718 m .50839 .41708 L .50682 .41538 L F
.841 .854 .854 r
.50839 .41708 m .50959 .41245 L .50682 .41538 L F
.50839 .41708 m .51134 .41399 L .50959 .41245 L F
.337 .141 .46 r
.51904 .48018 m .51655 .48403 L .51818 .48194 L F
.581 .831 .462 r
.51818 .48194 m .51655 .48403 L .51505 .48583 L F
.4 0 0 r
.39552 .46663 m .39634 .46828 L .39412 .46911 L F
.39552 .46663 m .39801 .46683 L .39634 .46828 L F
0 0 0 r
.56371 .39488 m .56257 .39739 L .56426 .39372 L F
.858 .808 .322 r
.39838 .48211 m .39865 .48238 L .39832 .48383 L F
.83 .373 .131 r
.41494 .53888 m .41643 .541 L .41805 .54006 L F
.815 .349 .113 r
.41643 .541 m .41853 .54228 L .41805 .54006 L F
.898 .658 .566 r
.34647 .56803 m .34334 .5708 L .34336 .56876 L F
.34647 .56803 m .34586 .57247 L .34334 .5708 L F
.835 .688 .701 r
.36013 .57848 m .36181 .5823 L .36385 .57904 L F
.359 .79 .968 r
.44764 .59436 m .44824 .59327 L .44561 .59408 L F
.44764 .59436 m .45021 .59396 L .44824 .59327 L F
.599 .026 0 r
.66037 .40168 m .65803 .40112 L .65622 .39976 L F
.623 .923 .974 r
.66283 .40033 m .65803 .40112 L .66037 .40168 L F
.724 .559 .667 r
.31802 .55585 m .32086 .55671 L .32164 .55158 L F
0 0 .521 r
.32164 .55158 m .32155 .54795 L .32142 .54956 L F
.32164 .55158 m .32244 .55068 L .32155 .54795 L F
0 .247 .761 r
.32164 .55158 m .32312 .55227 L .32244 .55068 L F
.692 .53 .662 r
.32164 .55158 m .32515 .55609 L .32312 .55227 L F
.32164 .55158 m .32086 .55671 L .32515 .55609 L F
.395 .689 .979 r
.62173 .40114 m .62355 .39938 L .62081 .39934 L F
.62173 .40114 m .62524 .40125 L .62355 .39938 L F
.799 .609 .645 r
.50024 .43729 m .49517 .43941 L .49521 .43673 L F
.50024 .43729 m .49946 .44006 L .49517 .43941 L F
.873 .682 .642 r
.55839 .42699 m .55468 .4291 L .55728 .42566 L F
.55839 .42699 m .55798 .42989 L .55468 .4291 L F
.767 .731 .819 r
.55938 .42207 m .55839 .42699 L .55728 .42566 L F
.55938 .42207 m .56172 .42391 L .55839 .42699 L F
.79 .694 .759 r
.29349 .66787 m .29564 .67195 L .29097 .67124 L F
.678 .193 .092 r
.29097 .67124 m .29564 .67195 L .29335 .67339 L F
.484 .149 .322 r
.28217 .53268 m .27894 .53373 L .27838 .5326 L F
.28217 .53268 m .281 .53563 L .27894 .53373 L F
.512 .144 .277 r
.281 .53563 m .27744 .53717 L .27894 .53373 L F
.623 .81 .972 r
.3013 .58063 m .30357 .58257 L .29943 .58232 L F
.406 .179 .454 r
.30161 .58424 m .29943 .58232 L .30357 .58257 L F
.331 .673 .977 r
.3013 .58063 m .30464 .58152 L .30357 .58257 L F
0 0 0 r
.30361 .58349 m .30357 .58257 L .30464 .58152 L F
.30361 .58349 m .30161 .58424 L .30357 .58257 L F
.847 .739 .744 r
.3604 .59492 m .35781 .59861 L .36171 .59819 L F
.846 .764 .772 r
.35781 .59861 m .35924 .60225 L .36171 .59819 L F
.217 0 0 r
.61593 .34342 m .61864 .34367 L .62139 .3435 L F
.174 .71 .791 r
.62139 .3435 m .61864 .34367 L .62261 .34327 L F
.92 .837 .747 r
.32625 .5954 m .32227 .5978 L .32333 .59444 L F
.32625 .5954 m .32428 .59894 L .32227 .5978 L F
.651 .361 .467 r
.33143 .53629 m .33144 .53955 L .33328 .53868 L F
0 .053 .619 r
.42248 .59233 m .4227 .59133 L .42162 .5906 L F
0 0 .446 r
.4221 .59458 m .4227 .59133 L .42248 .59233 L F
.974 .865 .668 r
.65653 .37091 m .65352 .37598 L .65644 .37093 L F
.249 .72 .943 r
.65876 .37026 m .65653 .37091 L .65644 .37093 L F
.65876 .37026 m .65979 .37098 L .65653 .37091 L F
0 0 .15 r
.42501 .5622 m .42533 .56432 L .42442 .56569 L F
0 0 .157 r
.4259 .56173 m .42533 .56432 L .42501 .5622 L F
.513 .775 .991 r
.62208 .39236 m .62353 .39384 L .62057 .39435 L F
0 0 0 r
.6647 .36069 m .66318 .36442 L .66412 .36225 L F
.735 .537 0 r
.66318 .36442 m .6631 .36467 L .66412 .36225 L F
.66318 .36442 m .66343 .36698 L .6631 .36467 L F
.484 .697 .963 r
.60413 .35018 m .60797 .35149 L .60665 .34956 L F
.726 .813 .919 r
.60665 .34956 m .60797 .35149 L .61083 .34967 L F
.60665 .34956 m .60797 .35149 L .61083 .34967 L F
.793 .946 .923 r
.64736 .37504 m .64343 .37627 L .64614 .37543 L F
.23 .738 .688 r
.64906 .37444 m .64736 .37504 L .64614 .37543 L F
.64906 .37444 m .65057 .374 L .64736 .37504 L F
.69 .947 .671 r
.62334 .38228 m .62205 .38436 L .62312 .38286 L F
.694 .586 .731 r
.62339 .37978 m .62317 .38234 L .62735 .3806 L F
.62317 .38234 m .62312 .38286 L .62352 .38265 L F
.62317 .38234 m .62352 .38265 L .62735 .3806 L F
0 0 .088 r
.62317 .38234 m .62334 .38228 L .62312 .38286 L F
.62339 .37978 m .62334 .38228 L .62317 .38234 L F
.556 .295 .475 r
.62042 .38003 m .62334 .38228 L .62339 .37978 L F
0 .163 .657 r
.62199 .38081 m .62334 .38228 L .62134 .38074 L F
.62068 .38016 m .62134 .38074 L .62042 .38003 L F
.62199 .38081 m .62134 .38074 L .62068 .38016 L F
.672 .961 .938 r
.62098 .38382 m .62205 .38436 L .62334 .38228 L F
.87 .93 .861 r
.4933 .50626 m .48911 .50834 L .49224 .50561 L F
.826 .988 .873 r
.4933 .50626 m .49372 .50375 L .49648 .50367 L F
.4933 .50626 m .49224 .50561 L .49372 .50375 L F
.724 .724 .85 r
.32716 .62863 m .32986 .62843 L .32833 .62425 L F
.769 .747 .834 r
.32833 .62425 m .32986 .62843 L .33226 .62486 L F
.765 .78 .865 r
.32986 .62843 m .33411 .62616 L .33226 .62486 L F
.533 .348 .577 r
.46612 .58585 m .46538 .58231 L .46401 .58525 L F
.46612 .58585 m .4689 .58242 L .46538 .58231 L F
.46612 .58585 m .46949 .58589 L .4689 .58242 L F
.522 .279 .487 r
.46612 .58585 m .46868 .58803 L .46632 .58873 L F
.669 .194 .115 r
.46612 .58585 m .46868 .58803 L .46632 .58873 L F
.931 .633 .456 r
.38701 .55634 m .38504 .55781 L .38472 .55525 L F
.852 .482 .351 r
.38701 .55634 m .38745 .55864 L .38504 .55781 L F
.307 0 .005 r
.6544 .32985 m .65697 .33005 L .65786 .32826 L F
.258 0 .038 r
.65697 .33005 m .66055 .32733 L .65786 .32826 L F
.428 .443 .774 r
.5355 .46863 m .53769 .47591 L .53534 .47601 L F
.749 .678 .781 r
.32551 .63043 m .32564 .62484 L .32305 .62555 L F
.32551 .63043 m .32716 .62863 L .32564 .62484 L F
.597 .949 .825 r
.43947 .4526 m .43528 .45461 L .4374 .45387 L F
.029 0 0 r
.53815 .41372 m .53607 .41518 L .53482 .41679 L F
.353 .676 .977 r
.28825 .65498 m .29278 .65654 L .29105 .65499 L F
.774 .839 .901 r
.29105 .65499 m .29278 .65654 L .2951 .65505 L F
.904 .961 .817 r
.49277 .52219 m .49132 .52649 L .49367 .52297 L F
.859 .989 .841 r
.49553 .51907 m .49367 .52297 L .49678 .52015 L F
.49553 .51907 m .49277 .52219 L .49367 .52297 L F
.753 .743 .843 r
.53525 .36253 m .5349 .36443 L .53311 .36103 L F
.609 .165 .17 r
.374 .50161 m .37827 .50008 L .37377 .49968 L F
.374 .50161 m .37842 .50181 L .37827 .50008 L F
.858 .695 .679 r
.37842 .50181 m .382 .49977 L .37827 .50008 L F
.354 .793 .627 r
.47225 .42411 m .46808 .42642 L .47033 .42495 L F
.61 .891 .583 r
.4736 .42232 m .47515 .42104 L .47225 .42411 L F
.635 .949 .745 r
.4736 .42232 m .47225 .42411 L .47033 .42495 L F
.856 .946 .876 r
.59296 .43127 m .59149 .43381 L .59061 .43274 L F
.59387 .43071 m .59304 .43179 L .59296 .43127 L F
.59304 .43179 m .59149 .43381 L .59296 .43127 L F
.59406 .43081 m .59149 .43381 L .59387 .43071 L F
.59447 .43034 m .59061 .43274 L .59202 .42944 L F
.59447 .43034 m .59406 .43081 L .59387 .43071 L F
.789 .324 .135 r
.59483 .43255 m .59447 .43034 L .59202 .42944 L F
.59483 .43255 m .59282 .43033 L .59433 .43136 L F
.59282 .43033 m .59202 .42944 L .59278 .43008 L F
.59282 .43033 m .59278 .43008 L .59433 .43136 L F
.794 .866 .426 r
.59155 .42945 m .59202 .42944 L .59195 .42961 L F
.59155 .42945 m .59195 .42961 L .59061 .43274 L F
.711 .607 .739 r
.59009 .42962 m .59202 .42682 L .58893 .42625 L F
.976 .708 .457 r
.59155 .42945 m .58994 .42917 L .59001 .42645 L F
0 .521 .737 r
.58994 .42917 m .59155 .42945 L .59001 .42645 L F
.58994 .42917 m .59135 .42938 L .59155 .42945 L F
.59135 .42938 m .59403 .42977 L .59155 .42945 L F
.518 0 0 r
.59433 .43136 m .59278 .43008 L .59155 .42945 L F
.59278 .43008 m .59202 .42944 L .59169 .42945 L F
.59278 .43008 m .59169 .42945 L .59155 .42945 L F
.999 .836 .507 r
.59061 .43274 m .59149 .43381 L .58987 .4353 L F
.48 .313 .577 r
.66587 .31785 m .66863 .31698 L .66849 .31436 L F
.576 .466 .691 r
.66608 .32058 m .66863 .31698 L .66587 .31785 L F
.706 .597 .732 r
.28424 .65493 m .28535 .6582 L .28825 .65498 L F
.513 .484 .762 r
.34743 .64548 m .34549 .64759 L .34356 .64431 L F
.34743 .64548 m .34833 .64734 L .34549 .64759 L F
.996 .764 .456 r
.5847 .39367 m .58561 .39796 L .58492 .39623 L F
.708 .322 0 r
.58561 .39796 m .58564 .39843 L .58492 .39623 L F
.268 .72 .957 r
.46178 .53844 m .46484 .53955 L .46342 .53962 L F
.935 .849 .733 r
.46342 .53962 m .46076 .54034 L .46178 .53844 L F
0 0 0 r
.46268 .53709 m .46239 .53772 L .46178 .53844 L F
.669 .968 .918 r
.46076 .54034 m .46268 .53709 L .46178 .53844 L F
.46076 .54034 m .46172 .53853 L .46233 .53762 L F
.46221 .53788 m .46233 .53762 L .46268 .53709 L F
.46076 .54034 m .46233 .53762 L .46221 .53788 L F
.268 .72 .957 r
.46193 .5385 m .46239 .53772 L .46484 .53955 L F
.46178 .53844 m .46216 .53799 L .46193 .5385 L F
.46216 .53799 m .46239 .53772 L .46193 .5385 L F
.783 .971 .917 r
.46484 .53955 m .46679 .53548 L .46786 .53528 L F
.46484 .53955 m .46239 .53772 L .46679 .53548 L F
.544 .816 .996 r
.30197 .67159 m .30605 .67183 L .30609 .67509 L F
.592 .383 .566 r
.30605 .67183 m .30871 .67151 L .30609 .67509 L F
.30605 .67183 m .30871 .67151 L .30609 .67509 L F
.202 0 0 r
.41307 .45434 m .41224 .45548 L .41582 .45372 L F
.2 .029 .412 r
.24362 .56241 m .24175 .56567 L .24266 .56516 L F
.055 .041 .521 r
.24175 .56567 m .24324 .56789 L .24266 .56516 L F
.545 .821 .997 r
.31488 .61889 m .31049 .61844 L .31324 .61524 L F
.755 .752 .849 r
.31585 .61431 m .31488 .61889 L .31324 .61524 L F
.31585 .61431 m .3171 .61787 L .31488 .61889 L F
.528 0 0 r
.34482 .65398 m .34702 .65322 L .34909 .6545 L F
.368 .181 .49 r
.34909 .6545 m .34702 .65322 L .34905 .65139 L F
0 .216 .739 r
.57922 .37676 m .57687 .37303 L .57855 .37422 L F
.375 0 0 r
.39675 .58655 m .39526 .58738 L .39539 .58675 L F
.2 .722 .708 r
.39915 .58642 m .39825 .58658 L .39526 .58738 L F
.962 .749 .569 r
.39526 .58738 m .39673 .59144 L .39479 .59043 L F
.685 .64 .799 r
.39976 .58867 m .39673 .59144 L .39646 .59069 L F
.39976 .58867 m .39646 .59069 L .39526 .58738 L F
.19 .417 .851 r
.39915 .58642 m .40142 .58941 L .40202 .58729 L F
.685 .64 .799 r
.39976 .58867 m .39526 .58738 L .39789 .5896 L F
.534 .403 .648 r
.39789 .5896 m .39825 .58658 L .40202 .58729 L F
.39789 .5896 m .40041 .58819 L .39976 .58867 L F
.40041 .58819 m .40062 .58814 L .39976 .58867 L F
.40182 .5874 m .40202 .58729 L .39976 .58867 L F
.802 .952 .916 r
.3987 .59177 m .39976 .58867 L .40142 .58941 L F
.3987 .59177 m .39673 .59144 L .39976 .58867 L F
.727 .962 .942 r
.40142 .58941 m .39976 .58867 L .40202 .58729 L F
.534 .403 .648 r
.39789 .5896 m .40112 .58946 L .39825 .58658 L F
.689 .155 0 r
.39825 .58658 m .39996 .5883 L .39829 .58749 L F
.39996 .5883 m .40112 .58946 L .39959 .58839 L F
.39996 .5883 m .39959 .58839 L .39829 .58749 L F
.534 .403 .648 r
.40041 .58819 m .40182 .5874 L .40062 .58814 L F
0 0 0 r
.3963 .58536 m .39526 .58738 L .39825 .58658 L F
.852 .628 .598 r
.39526 .58738 m .39479 .59043 L .39395 .59013 L F
.39285 .58831 m .39395 .59013 L .39092 .58906 L F
.39526 .58738 m .39395 .59013 L .39285 .58831 L F
.699 .205 .067 r
.39487 .5886 m .39399 .58893 L .39473 .58906 L F
0 0 0 r
.39488 .58859 m .39487 .5886 L .39526 .58738 L F
.39487 .5886 m .39485 .58864 L .39487 .5886 L F
.644 .153 .07 r
.39526 .58738 m .39485 .58864 L .39422 .58835 L F
.852 .628 .598 r
.39422 .58835 m .39092 .58906 L .39358 .58895 L F
.39526 .58738 m .39285 .58831 L .39422 .58835 L F
.39285 .58831 m .39092 .58906 L .39422 .58835 L F
.644 .153 .07 r
.39526 .58738 m .39422 .58835 L .39105 .58688 L F
.852 .628 .598 r
.39446 .58836 m .39358 .58895 L .39399 .58893 L F
.39526 .58738 m .39422 .58835 L .39446 .58836 L F
.39422 .58835 m .39358 .58895 L .39446 .58836 L F
.699 .205 .067 r
.39526 .58738 m .39446 .58836 L .39482 .58857 L F
.633 .582 .78 r
.39482 .58857 m .39485 .58864 L .39488 .58859 L F
.699 .205 .067 r
.39488 .58859 m .39482 .58857 L .39487 .5886 L F
.39526 .58738 m .39482 .58857 L .39488 .58859 L F
.39526 .58738 m .39473 .58906 L .39789 .5896 L F
0 0 0 r
.3963 .58536 m .39512 .58805 L .39526 .58738 L F
.375 0 0 r
.39539 .58675 m .39526 .58738 L .39304 .58711 L F
.644 .153 .07 r
.39526 .58738 m .39105 .58688 L .39304 .58711 L F
.633 .582 .78 r
.39211 .58228 m .39482 .58857 L .3963 .58536 L F
0 0 0 r
.39512 .58805 m .39488 .58859 L .39526 .58738 L F
.633 .582 .78 r
.39482 .58857 m .39488 .58859 L .3963 .58536 L F
.494 .507 .799 r
.39463 .58845 m .39482 .58857 L .39473 .58836 L F
.39459 .58836 m .39473 .58836 L .39211 .58228 L F
.39463 .58845 m .39473 .58836 L .39459 .58836 L F
.741 .251 .075 r
.39304 .58711 m .38864 .58442 L .39244 .58567 L F
.494 .507 .799 r
.39131 .58574 m .39451 .58836 L .39211 .58228 L F
.39451 .58836 m .39463 .58845 L .39459 .58836 L F
.39451 .58836 m .39459 .58836 L .39211 .58228 L F
.39463 .58845 m .39485 .58864 L .39482 .58857 L F
.699 .205 .067 r
.39446 .58836 m .39399 .58893 L .39487 .5886 L F
.741 .251 .075 r
.39303 .5871 m .39105 .58688 L .38864 .58442 L F
.39304 .58711 m .39105 .58688 L .39303 .5871 L F
.67 .204 .139 r
.39105 .58688 m .38706 .58643 L .38864 .58442 L F
.494 .507 .799 r
.39105 .58688 m .39211 .58228 L .38915 .58667 L F
.67 .204 .139 r
.39105 .58688 m .38883 .58715 L .38706 .58643 L F
.494 .507 .799 r
.39105 .58688 m .38915 .58667 L .38883 .58715 L F
.39105 .58688 m .39236 .58749 L .39131 .58574 L F
.39236 .58749 m .39485 .58864 L .39131 .58574 L F
.828 .981 .882 r
.55667 .4359 m .55739 .43697 L .55394 .43986 L F
.969 .841 .43 r
.55742 .43181 m .55739 .43697 L .55667 .4359 L F
.701 .801 .928 r
.6048 .39881 m .60738 .39747 L .60353 .3967 L F
.506 .167 .328 r
.40488 .46364 m .40673 .46596 L .40023 .46674 L F
.511 .168 .323 r
.40488 .46364 m .40748 .4653 L .40673 .46596 L F
.777 .969 .921 r
.53341 .48545 m .5362 .48199 L .53251 .4854 L F
.53341 .48545 m .53656 .48321 L .5362 .48199 L F
.708 .17 0 r
.53475 .46825 m .5341 .46654 L .53215 .46692 L F
.793 .515 .516 r
.65841 .38295 m .66251 .38349 L .66275 .38616 L F
.882 .987 .812 r
.6622 .38504 m .66275 .38616 L .66222 .38501 L F
.591 .671 .895 r
.66324 .38715 m .65944 .38506 L .66275 .38616 L F
.657 .966 .915 r
.65838 .38758 m .66012 .38791 L .66275 .38616 L F
.65838 .38758 m .6602 .38699 L .66019 .38705 L F
.6602 .38699 m .66275 .38616 L .66019 .38705 L F
.514 .855 .995 r
.65838 .38758 m .66019 .38705 L .66025 .38598 L F
.65838 .38758 m .66019 .38705 L .66025 .38598 L F
.712 .622 .056 r
.66017 .38714 m .66019 .38705 L .66025 .38598 L F
.591 .671 .895 r
.664 .38757 m .66324 .38715 L .66275 .38616 L F
.474 .873 .962 r
.66012 .38791 m .664 .38757 L .66275 .38616 L F
.574 .936 .923 r
.65683 .38943 m .66012 .38791 L .65838 .38758 L F
.6 .592 .816 r
.66019 .38705 m .66007 .39232 L .65838 .38758 L F
.712 .622 .056 r
.66006 .38866 m .66019 .38705 L .66017 .38714 L F
.882 .987 .812 r
.66019 .38705 m .66275 .38616 L .6622 .38504 L F
.547 .93 .877 r
.43878 .44345 m .43889 .44453 L .43684 .44512 L F
.43878 .44345 m .44118 .44322 L .43889 .44453 L F
.291 .78 .718 r
.43684 .44512 m .43889 .44453 L .4351 .44587 L F
.624 .345 .475 r
.32207 .54175 m .32476 .54222 L .32503 .53974 L F
.659 .787 .943 r
.59194 .37668 m .58987 .37825 L .58806 .37554 L F
.158 0 0 r
.33371 .53368 m .33387 .53308 L .33662 .53531 L F
.831 .847 .859 r
.34572 .57506 m .34326 .57493 L .34586 .57247 L F
.414 0 0 r
.5569 .42116 m .55646 .42192 L .55546 .41944 L F
.5569 .42116 m .55938 .42207 L .55646 .42192 L F
.866 .806 .79 r
.48683 .52855 m .49132 .52649 L .49011 .52568 L F
.48683 .52855 m .48878 .52987 L .49132 .52649 L F
.904 .961 .817 r
.49277 .52219 m .49011 .52568 L .49132 .52649 L F
0 0 .037 r
.64935 .38052 m .64572 .38387 L .64736 .37986 L F
.64935 .38052 m .64579 .38483 L .64572 .38387 L F
.64935 .38052 m .64881 .38248 L .64579 .38483 L F
.245 0 0 r
.32686 .50367 m .32911 .50413 L .3309 .50348 L F
.632 .084 0 r
.32911 .50413 m .33319 .50531 L .3309 .50348 L F
.596 .023 0 r
.3309 .50348 m .33319 .50531 L .33534 .50598 L F
.837 .761 .779 r
.35781 .59861 m .35524 .60197 L .35924 .60225 L F
.798 .624 .665 r
.3547 .60494 m .35924 .60225 L .35524 .60197 L F
.3547 .60494 m .35933 .6053 L .35924 .60225 L F
.742 .745 .854 r
.31984 .61478 m .3171 .61787 L .31585 .61431 L F
.882 .918 .846 r
.48356 .53444 m .48391 .53721 L .48539 .53478 L F
.48356 .53444 m .48107 .53745 L .48391 .53721 L F
.759 .604 .686 r
.23401 .61149 m .23673 .61354 L .23667 .61316 L F
.823 .424 .293 r
.23667 .61316 m .2379 .61292 L .23728 .61354 L F
.23401 .61149 m .23657 .61243 L .23667 .61316 L F
.23657 .61243 m .2379 .61292 L .23667 .61316 L F
.759 .604 .686 r
.23401 .61149 m .23667 .61316 L .23588 .6082 L F
.731 .506 0 r
.23588 .6082 m .23667 .61316 L .23611 .61018 L F
.23667 .61316 m .23673 .61354 L .2367 .61336 L F
.813 .341 .091 r
.2362 .61359 m .23673 .61354 L .23401 .61149 L F
.823 .424 .293 r
.23401 .61149 m .23687 .61328 L .2362 .61359 L F
.23401 .61149 m .23672 .61409 L .23608 .61472 L F
.813 .341 .091 r
.23432 .61376 m .23401 .61149 L .235 .61422 L F
.823 .424 .293 r
.23401 .61149 m .23556 .6139 L .235 .61422 L F
.23556 .6139 m .23608 .61472 L .23543 .61442 L F
.23556 .6139 m .23543 .61442 L .235 .61422 L F
.813 .341 .091 r
.23432 .61376 m .2362 .61359 L .23513 .61257 L F
.23432 .61376 m .23499 .61243 L .23401 .61149 L F
.96 .93 .72 r
.23611 .61018 m .23625 .61093 L .23432 .61376 L F
.23625 .61093 m .2367 .61336 L .23564 .61354 L F
.23625 .61093 m .23564 .61354 L .23432 .61376 L F
.2367 .61336 m .23673 .61354 L .2362 .61359 L F
.2367 .61336 m .2362 .61359 L .23432 .61376 L F
.823 .424 .293 r
.2362 .61359 m .23728 .61354 L .23672 .61409 L F
.23687 .61328 m .23728 .61354 L .2362 .61359 L F
.731 .506 0 r
.23667 .61316 m .2367 .61336 L .23611 .61018 L F
0 0 0 r
.23608 .61472 m .2379 .61292 L .24022 .61187 L F
.324 .155 .491 r
.24818 .53918 m .25023 .53502 L .24832 .53618 L F
.754 .708 .809 r
.33226 .62486 m .33688 .62512 L .33496 .62136 L F
.75 .72 .824 r
.33411 .62616 m .33688 .62512 L .33226 .62486 L F
.581 .557 .792 r
.33688 .62512 m .33923 .6221 L .33496 .62136 L F
.33688 .62512 m .33934 .62447 L .33923 .6221 L F
.621 .633 .841 r
.33688 .62512 m .34067 .62618 L .33934 .62447 L F
.748 .97 .7 r
.538 .47604 m .53769 .47591 L .5406 .47252 L F
.829 .965 .894 r
.48539 .53478 m .48668 .53384 L .48356 .53444 L F
.911 .884 .795 r
.48505 .53245 m .48668 .53384 L .48878 .52987 L F
.91 .884 .796 r
.48356 .53444 m .48668 .53384 L .48505 .53245 L F
.913 .721 .629 r
.39006 .56629 m .39011 .56918 L .38845 .56534 L F
.706 .25 .166 r
.51137 .42217 m .51251 .4204 L .50861 .41986 L F
.599 .936 .746 r
.51442 .41875 m .51251 .4204 L .51393 .41883 L F
0 0 0 r
.51393 .41883 m .51251 .4204 L .51137 .42217 L F
.868 .471 .282 r
.5544 .41089 m .55068 .41093 L .55176 .41063 L F
.678 .543 .694 r
.59697 .35085 m .59453 .35352 L .593 .35027 L F
.042 0 0 r
.42742 .44869 m .43165 .44679 L .42929 .44798 L F
.209 .37 .806 r
.33449 .58587 m .33639 .58936 L .33628 .58753 L F
.816 .854 .876 r
.50959 .41245 m .51134 .41399 L .51415 .41152 L F
.491 .835 .557 r
.47701 .41939 m .47515 .42104 L .4736 .42232 L F
0 0 0 r
.58149 .352 m .5821 .35202 L .58394 .35181 L F
.283 0 0 r
.5821 .35202 m .58629 .35051 L .58394 .35181 L F
.5821 .35202 m .5851 .35171 L .58629 .35051 L F
0 .224 .745 r
.58275 .35204 m .5821 .35202 L .58055 .35092 L F
.539 0 0 r
.5821 .35202 m .5868 .35541 L .5851 .35171 L F
0 .224 .745 r
.58352 .35244 m .5821 .35202 L .58275 .35204 L F
0 0 0 r
.57968 .35214 m .5821 .35202 L .58149 .352 L F
.76 .655 .746 r
.34857 .61847 m .3528 .61894 L .35097 .61475 L F
.379 .609 .94 r
.52048 .4016 m .51946 .40362 L .5182 .40146 L F
.519 .412 .672 r
.28454 .53186 m .28197 .52901 L .2832 .52888 L F
.28454 .53186 m .28217 .53268 L .28197 .52901 L F
.727 .839 .934 r
.30787 .62107 m .30624 .62244 L .3041 .62102 L F
.731 .213 0 r
.3041 .62102 m .30624 .62244 L .30781 .62447 L F
0 0 .515 r
.54206 .41743 m .54309 .41987 L .54268 .42034 L F
.749 .983 .909 r
.53954 .4219 m .54268 .42034 L .54309 .41987 L F
.843 .476 .357 r
.67392 .31999 m .67665 .32352 L .67677 .32163 L F
.828 .981 .882 r
.55667 .4359 m .55394 .43986 L .55388 .43924 L F
.077 0 .199 r
.5221 .39262 m .52012 .39361 L .52294 .39022 L F
0 0 0 r
.51989 .39584 m .52012 .39361 L .5221 .39262 L F
.494 .817 .507 r
.52092 .39382 m .52013 .39499 L .51989 .39584 L F
.52013 .39499 m .51832 .39768 L .51989 .39584 L F
0 0 0 r
.51989 .39584 m .51968 .39688 L .51976 .39633 L F
.51989 .39584 m .51976 .39633 L .52012 .39361 L F
.55555 .3806 m .55369 .38148 L .55152 .38226 L F
.816 .993 .75 r
.55653 .37845 m .55555 .3806 L .55811 .37997 L F
.55653 .37845 m .55369 .38148 L .55555 .3806 L F
.97 .699 .28 r
.59791 .39255 m .59894 .39076 L .59483 .38992 L F
.59791 .39255 m .59894 .39285 L .59894 .39076 L F
.021 .244 .748 r
.5962 .38866 m .5978 .39229 L .59483 .38992 L F
.5978 .39229 m .59791 .39255 L .59782 .39248 L F
.5978 .39229 m .59782 .39248 L .59483 .38992 L F
.746 .69 .798 r
.5962 .38866 m .59791 .39255 L .60095 .39003 L F
.5962 .38866 m .59848 .38932 L .5982 .38946 L F
.59848 .38932 m .60095 .39003 L .5982 .38946 L F
.97 .931 .675 r
.59747 .38984 m .5982 .38946 L .59733 .38875 L F
.59756 .39049 m .5982 .38946 L .59747 .38984 L F
0 .483 .841 r
.59676 .3883 m .5982 .38946 L .5962 .38866 L F
.97 .931 .675 r
.59604 .39289 m .59756 .39049 L .59676 .3883 L F
.59756 .39049 m .59733 .38875 L .59676 .3883 L F
.743 .993 .842 r
.59704 .3923 m .59791 .39255 L .60095 .39003 L F
.59604 .39289 m .59791 .39255 L .59704 .3923 L F
.97 .699 .28 r
.59791 .39255 m .59894 .39317 L .59894 .39285 L F
.996 .763 .452 r
.43097 .58791 m .4311 .59111 L .43229 .58908 L F
.458 .764 .996 r
.4311 .59111 m .43097 .58791 L .43229 .58908 L F
.951 .818 .377 r
.36951 .47028 m .36895 .47231 L .37075 .4691 L F
.223 .739 .719 r
.43165 .44679 m .43429 .44603 L .4351 .44587 L F
.291 .78 .718 r
.43684 .44512 m .4351 .44587 L .43429 .44603 L F
.989 .873 .622 r
.57199 .42575 m .5744 .42335 L .57271 .42212 L F
.57199 .42575 m .57317 .42725 L .5744 .42335 L F
0 0 .061 r
.35731 .49332 m .35734 .4918 L .35537 .49168 L F
.35731 .49332 m .35741 .4948 L .35734 .4918 L F
.955 .849 .699 r
.31883 .51252 m .31825 .50842 L .32081 .50968 L F
.445 .026 .149 r
.65638 .33764 m .65531 .33972 L .65253 .34 L F
.514 .094 .182 r
.65928 .33909 m .65638 .33764 L .65918 .33726 L F
.65928 .33909 m .65531 .33972 L .65638 .33764 L F
.228 .586 .946 r
.29437 .64673 m .29382 .64811 L .29231 .6465 L F
.109 .442 .879 r
.29437 .64673 m .29559 .64873 L .29382 .64811 L F
.965 .732 .534 r
.36936 .51967 m .36908 .52241 L .36748 .51858 L F
.546 .929 .882 r
.44601 .44918 m .44967 .44772 L .44761 .44772 L F
.25 .763 .793 r
.44967 .44772 m .45027 .44722 L .44761 .44772 L F
.44967 .44772 m .45237 .44707 L .45027 .44722 L F
.795 .967 .661 r
.66708 .35749 m .6647 .36069 L .66563 .35837 L F
.938 .91 .524 r
.66708 .35749 m .66673 .35621 L .66802 .35253 L F
.873 .994 .771 r
.65716 .39542 m .65862 .39532 L .65683 .39731 L F
.494 .905 .842 r
.66133 .39396 m .65862 .39532 L .65716 .39542 L F
.748 .659 .762 r
.59834 .3408 m .59556 .34412 L .59945 .34372 L F
.439 0 0 r
.59556 .34412 m .59847 .34446 L .59945 .34372 L F
0 0 0 r
.59945 .34372 m .60106 .34337 L .60234 .344 L F
.59945 .34372 m .59847 .34446 L .60106 .34337 L F
.7 .704 .85 r
.30391 .67414 m .30237 .67754 L .30072 .6767 L F
.30391 .67414 m .30609 .67509 L .30237 .67754 L F
0 0 0 r
.6647 .36069 m .66412 .36225 L .66563 .35837 L F
.107 0 .3 r
.51904 .48018 m .52097 .48103 L .52062 .4785 L F
.51904 .48018 m .51818 .48194 L .52097 .48103 L F
.724 .724 .85 r
.32716 .62863 m .32833 .62425 L .32564 .62484 L F
.36 .432 .8 r
.54865 .38076 m .55152 .38226 L .55032 .37904 L F
.548 .852 .54 r
.54287 .35431 m .54148 .35558 L .53985 .35739 L F
.566 .813 .991 r
.54143 .35289 m .54287 .35431 L .54562 .35347 L F
.987 .713 .384 r
.54143 .35289 m .54287 .35431 L .54562 .35347 L F
.54143 .35289 m .54148 .35558 L .54287 .35431 L F
.844 .929 .886 r
.5504 .46986 m .55173 .47098 L .55321 .46918 L F
.968 .712 .492 r
.38037 .53935 m .37848 .53835 L .37862 .53561 L F
.934 .653 .483 r
.38063 .5418 m .37848 .53835 L .38037 .53935 L F
.713 .984 .89 r
.37381 .47144 m .3727 .47353 L .37441 .4718 L F
.041 0 0 r
.62539 .34258 m .62817 .34227 L .62961 .34165 L F
0 0 0 r
.62961 .34165 m .6309 .34139 L .6321 .34098 L F
.62961 .34165 m .62817 .34227 L .6309 .34139 L F
.973 .701 .454 r
.34236 .55879 m .34414 .56264 L .34231 .56151 L F
.987 .77 .526 r
.34414 .56264 m .34211 .56435 L .34231 .56151 L F
.34414 .56264 m .34377 .56542 L .34211 .56435 L F
.267 .774 .833 r
.60665 .34956 m .60235 .35018 L .60413 .35018 L F
.469 .885 .773 r
.46055 .43086 m .46059 .43135 L .45841 .43212 L F
.46055 .43086 m .46274 .43018 L .46059 .43135 L F
.85 .481 .352 r
.35492 .50674 m .3517 .50755 L .35118 .50528 L F
.35492 .50674 m .35509 .50881 L .3517 .50755 L F
.485 .9 .838 r
.6298 .39048 m .62552 .39198 L .62934 .38845 L F
.767 .805 .884 r
.63225 .38676 m .6298 .39048 L .62927 .38783 L F
.63225 .38676 m .63294 .38859 L .6298 .39048 L F
.316 .487 .869 r
.63147 .38858 m .6298 .39048 L .62934 .38845 L F
.63147 .38858 m .6298 .39048 L .62934 .38845 L F
.599 .884 .575 r
.44699 .54148 m .44869 .53956 L .45032 .53817 L F
0 0 0 r
.44869 .53956 m .44907 .53943 L .45032 .53817 L F
.878 .922 .53 r
.4504 .53949 m .45032 .53817 L .45147 .537 L F
.657 .353 .446 r
.4504 .53949 m .44773 .54081 L .45032 .53817 L F
.765 .472 .489 r
.45032 .53817 m .4546 .53844 L .45422 .53586 L F
.067 .626 .799 r
.45255 .53819 m .4546 .53844 L .45032 .53817 L F
0 0 0 r
.44907 .53943 m .45255 .53819 L .45032 .53817 L F
.878 .922 .53 r
.45147 .537 m .45032 .53817 L .45201 .53576 L F
.765 .472 .489 r
.45032 .53817 m .45422 .53586 L .45201 .53576 L F
.874 .865 .419 r
.28042 .61111 m .27957 .61546 L .28285 .61265 L F
.91 .658 .545 r
.36565 .51604 m .36323 .51539 L .36342 .51262 L F
.758 .335 .244 r
.36565 .51604 m .36338 .51762 L .36323 .51539 L F
.36565 .51604 m .36748 .51858 L .36338 .51762 L F
.693 .337 .368 r
.6261 .37898 m .62984 .37756 L .62717 .37696 L F
.356 0 0 r
.62406 .34774 m .62688 .34871 L .62299 .3482 L F
.439 0 .03 r
.62656 .34782 m .62688 .34871 L .62406 .34774 L F
.337 .09 .385 r
.2577 .56001 m .25633 .5628 L .2548 .56332 L F
.075 0 0 r
.25633 .5628 m .25884 .56207 L .2548 .56332 L F
.6 .932 .725 r
.54148 .35558 m .53781 .35851 L .53985 .35739 L F
.857 .733 .725 r
.35724 .56522 m .35878 .56905 L .3595 .56643 L F
.219 0 0 r
.25052 .53195 m .25296 .53149 L .2542 .53006 L F
.897 .552 .382 r
.32449 .51318 m .32149 .51393 L .32121 .51204 L F
.32449 .51318 m .32417 .51558 L .32149 .51393 L F
.926 .974 .734 r
.5549 .46448 m .55465 .46723 L .55682 .46368 L F
.837 .999 .814 r
.55736 .46135 m .55682 .46368 L .55963 .46068 L F
.847 .997 .77 r
.55736 .46135 m .5549 .46448 L .55682 .46368 L F
.821 .504 .454 r
.34396 .52023 m .34466 .52209 L .34456 .51966 L F
.23 0 0 r
.29666 .6852 m .2981 .68511 L .3004 .68558 L F
.438 .275 .562 r
.24426 .54964 m .24647 .54959 L .2463 .5464 L F
.603 .54 .756 r
.24472 .55241 m .24647 .54959 L .24426 .54964 L F
.873 .568 .05 r
.40554 .51849 m .40688 .52252 L .408 .52004 L F
.642 .753 .93 r
.54333 .39274 m .54512 .39504 L .54735 .39366 L F
.104 .182 .661 r
.24269 .55981 m .24504 .56104 L .24506 .55819 L F
.24269 .55981 m .24362 .56241 L .24504 .56104 L F
.695 .665 .816 r
.28424 .65493 m .28825 .65498 L .28631 .65145 L F
.926 .955 .631 r
.55122 .44514 m .55301 .44394 L .5501 .44926 L F
0 .251 .76 r
.28631 .65145 m .28825 .65498 L .28892 .65366 L F
.291 0 0 r
.28825 .65498 m .29038 .65499 L .28874 .65648 L F
.29038 .65499 m .29105 .65499 L .28874 .65648 L F
.28825 .65498 m .28874 .65648 L .28892 .65366 L F
.939 .683 .523 r
.28874 .65648 m .29105 .65499 L .28892 .65366 L F
.774 .526 .56 r
.28892 .65366 m .28874 .65648 L .28446 .65639 L F
0 0 .188 r
.28966 .65536 m .28874 .65648 L .28892 .65366 L F
.635 .172 .135 r
.28446 .65639 m .28874 .65648 L .28675 .65832 L F
.557 .859 .55 r
.28703 .65803 m .28874 .65648 L .28966 .65536 L F
.28675 .65832 m .28874 .65648 L .28703 .65803 L F
.909 .502 .166 r
.33426 .50703 m .33534 .50598 L .33319 .50531 L F
.33426 .50703 m .33709 .50888 L .33534 .50598 L F
.904 .658 .557 r
.37862 .53561 m .37644 .53194 L .37895 .53284 L F
.829 .619 .618 r
.29326 .65475 m .29105 .65499 L .2951 .65505 L F
.475 .644 .931 r
.2951 .65505 m .29609 .65167 L .29326 .65475 L F
.2951 .65505 m .29732 .6546 L .29609 .65167 L F
.892 .715 .656 r
.39355 .50849 m .39626 .50648 L .39323 .50601 L F
.39355 .50849 m .39648 .50974 L .39626 .50648 L F
.801 .658 .705 r
.36163 .58513 m .36317 .58893 L .36392 .58626 L F
.82 .875 .885 r
.54999 .39315 m .55135 .39539 L .55358 .39359 L F
.836 .81 .826 r
.34348 .58945 m .34198 .59183 L .34131 .58819 L F
.853 .731 .728 r
.35724 .56522 m .35526 .56853 L .35878 .56905 L F
.775 .474 .477 r
.35449 .5712 m .35878 .56905 L .35526 .56853 L F
.35449 .5712 m .35876 .57183 L .35878 .56905 L F
.811 .505 .472 r
.35878 .56905 m .35876 .57183 L .36286 .57232 L F
.137 .682 .732 r
.54844 .38835 m .55248 .3878 L .55009 .38832 L F
.448 .567 .882 r
.4896 .43 m .49133 .43337 L .49293 .43262 L F
.258 .108 .479 r
.49293 .43262 m .49133 .43337 L .49291 .43536 L F
.934 .805 .694 r
.49352 .43759 m .49291 .43536 L .49133 .43337 L F
.81 .999 .792 r
.56053 .45831 m .55963 .46068 L .56128 .45871 L F
.806 1 .822 r
.56053 .45831 m .55736 .46135 L .55963 .46068 L F
.529 .922 .857 r
.63418 .39878 m .63829 .39742 L .63703 .39834 L F
.293 0 0 r
.64095 .39755 m .63703 .39834 L .63829 .39742 L F
.9 .718 .647 r
.38845 .56534 m .39011 .56918 L .38771 .56836 L F
.906 .665 .563 r
.39011 .56918 m .38767 .57063 L .38771 .56836 L F
.39011 .56918 m .38988 .57194 L .38767 .57063 L F
.734 .218 0 r
.37526 .52926 m .37363 .52837 L .37238 .5266 L F
.889 .63 .541 r
.37644 .53194 m .37363 .52837 L .37526 .52926 L F
.154 0 .096 r
.24976 .58918 m .25185 .58832 L .25009 .58719 L F
.24976 .58918 m .24859 .5911 L .25185 .58832 L F
.25185 .58832 m .24859 .5911 L .24976 .58918 L F
.083 .601 .882 r
.60219 .38728 m .60335 .38645 L .60263 .38712 L F
.687 .159 0 r
.60219 .38728 m .60231 .38699 L .60335 .38645 L F
.60219 .38728 m .60142 .3886 L .60231 .38699 L F
.60219 .38728 m .60438 .38933 L .60142 .3886 L F
.083 .601 .882 r
.60219 .38728 m .60335 .38645 L .60263 .38712 L F
.085 .574 .9 r
.40104 .59292 m .39673 .59144 L .3987 .59177 L F
.581 .831 .462 r
.51818 .48194 m .51505 .48583 L .51658 .48386 L F
0 0 0 r
.52097 .48103 m .51818 .48194 L .51658 .48386 L F
.412 0 0 r
.55032 .37904 m .55518 .37813 L .5513 .37723 L F
.826 .935 .901 r
.45324 .5484 m .45613 .54537 L .45777 .54655 L F
.761 .902 .939 r
.45777 .54655 m .45805 .54389 L .45998 .545 L F
.804 .934 .917 r
.45613 .54537 m .45805 .54389 L .45777 .54655 L F
.946 .716 .558 r
.43683 .57092 m .43874 .57516 L .4394 .57272 L F
.43683 .57092 m .43874 .57516 L .4394 .57272 L F
.51 .25 .457 r
.4394 .57272 m .44159 .57496 L .43874 .57516 L F
.4394 .57272 m .44159 .57496 L .43874 .57516 L F
.991 .85 .488 r
.3188 .6056 m .31823 .60911 L .31733 .60769 L F
.768 .584 .649 r
.3188 .6056 m .32013 .61011 L .31823 .60911 L F
.556 .908 .7 r
.31981 .60376 m .31969 .60411 L .3172 .60554 L F
.642 .872 .509 r
.31969 .60411 m .32138 .60222 L .31951 .60467 L F
.686 .547 .691 r
.32138 .60222 m .32311 .60621 L .3188 .6056 L F
0 0 0 r
.32351 .60051 m .32138 .60222 L .31969 .60411 L F
.556 .908 .7 r
.32153 .60258 m .31969 .60411 L .31981 .60376 L F
.642 .872 .509 r
.31969 .60411 m .31951 .60467 L .3188 .6056 L F
.623 .826 .422 r
.31969 .60411 m .3188 .6056 L .31733 .60769 L F
.157 0 .212 r
.32428 .59894 m .32138 .60222 L .32351 .60051 L F
.681 .682 .844 r
.34067 .62618 m .34328 .62517 L .33934 .62447 L F
.553 .439 .678 r
.62927 .38783 m .63233 .38416 L .62874 .3852 L F
0 0 0 r
.63233 .38416 m .62874 .3852 L .62846 .38555 L F
.884 .536 .385 r
.41425 .52999 m .41464 .53236 L .41708 .53302 L F
.9 .728 .661 r
.41464 .53236 m .41592 .5354 L .41708 .53302 L F
.41464 .53236 m .41592 .5354 L .41708 .53302 L F
.948 .702 .531 r
.34908 .50169 m .34755 .5015 L .34761 .49896 L F
.862 .509 .382 r
.35118 .50528 m .34755 .5015 L .34908 .50169 L F
0 0 0 r
.29696 .67721 m .29922 .67468 L .29738 .67687 L F
.356 .112 .4 r
.29922 .67468 m .30197 .67159 L .30108 .67504 L F
.853 .734 .732 r
.30108 .67504 m .29738 .67687 L .29922 .67468 L F
.761 .926 .942 r
.62071 .36778 m .62055 .36805 L .62398 .36638 L F
.59 .28 .413 r
.62398 .36638 m .62193 .36797 L .62071 .36778 L F
.737 .937 .952 r
.63027 .39853 m .62898 .4012 L .63156 .39994 L F
.63027 .39853 m .62795 .40014 L .62898 .4012 L F
.73 .765 .881 r
.31126 .64903 m .30708 .64871 L .30949 .64773 L F
.721 .821 .927 r
.30949 .64773 m .31351 .64812 L .31126 .64903 L F
0 .544 .817 r
.59722 .36699 m .5977 .36745 L .59684 .36632 L F
.625 .063 0 r
.59979 .3678 m .59684 .36632 L .5977 .36745 L F
0 .544 .817 r
.59722 .36699 m .59979 .3678 L .5977 .36745 L F
.911 .884 .795 r
.48505 .53245 m .48878 .52987 L .48683 .52855 L F
.9 .638 .532 r
.28994 .62514 m .29258 .62496 L .29242 .62432 L F
.28994 .62514 m .29241 .62861 L .29258 .62496 L F
.639 .113 0 r
.29148 .62511 m .29242 .62432 L .29352 .62526 L F
.875 .981 .691 r
.29271 .62086 m .28994 .62514 L .2898 .62407 L F
.259 .761 .718 r
.28994 .62514 m .29242 .62432 L .28993 .625 L F
.639 .113 0 r
.28993 .625 m .29242 .62432 L .29148 .62511 L F
.78 .934 .575 r
.29258 .62496 m .29372 .62324 L .29242 .62432 L F
.29372 .62324 m .29471 .62174 L .29242 .62432 L F
.504 .848 .995 r
.29718 .62031 m .29471 .62174 L .29271 .62086 L F
.747 .784 .883 r
.29779 .61828 m .29855 .61931 L .29518 .62034 L F
.29855 .61931 m .29954 .62067 L .29702 .62048 L F
.29855 .61931 m .29702 .62048 L .29518 .62034 L F
0 0 0 r
.2964 .62097 m .29471 .62174 L .29718 .62031 L F
.29242 .62432 m .29327 .62337 L .2964 .62097 L F
.29327 .62337 m .29471 .62174 L .2964 .62097 L F
.995 .769 .413 r
.42291 .55211 m .42278 .55544 L .42363 .55545 L F
.95 .607 .216 r
.42324 .55767 m .42363 .55545 L .42278 .55544 L F
.42324 .55767 m .42462 .55899 L .42363 .55545 L F
.982 .704 .327 r
.59475 .37772 m .59602 .38017 L .5958 .37706 L F
.76 .687 .782 r
.59491 .37375 m .5958 .37706 L .59874 .37421 L F
.636 .912 .981 r
.60136 .37592 m .59903 .37612 L .59764 .37537 L F
.369 .432 .795 r
.59764 .37537 m .5958 .37706 L .59496 .37392 L F
.543 .883 .635 r
.59764 .37537 m .59513 .37741 L .5958 .37706 L F
.59513 .37741 m .59475 .37772 L .59488 .37764 L F
.59513 .37741 m .59488 .37764 L .5958 .37706 L F
.59764 .37537 m .59626 .37635 L .59475 .37772 L F
.636 .912 .981 r
.59903 .37612 m .59626 .37635 L .59764 .37537 L F
.614 .133 .089 r
.59874 .37421 m .60136 .37592 L .59764 .37537 L F
.636 .912 .981 r
.60136 .37592 m .5989 .37476 L .59635 .37629 L F
.59629 .37635 m .59635 .37629 L .59626 .37635 L F
.60136 .37592 m .59635 .37629 L .59629 .37635 L F
.369 .432 .795 r
.59764 .37537 m .59496 .37392 L .59491 .37375 L F
.797 .651 .7 r
.3547 .60494 m .35651 .60831 L .35933 .6053 L F
.607 .749 .945 r
.32305 .62555 m .32359 .6242 L .32192 .62418 L F
.32305 .62555 m .32564 .62484 L .32359 .6242 L F
.338 .084 .374 r
.59697 .35085 m .59666 .35292 L .59453 .35352 L F
.59697 .35085 m .59666 .35292 L .59453 .35352 L F
.428 .309 .616 r
.59666 .35292 m .59527 .35709 L .59453 .35352 L F
.824 .559 .538 r
.35304 .56459 m .35736 .56254 L .35318 .5618 L F
.35304 .56459 m .35724 .56522 L .35736 .56254 L F
.503 .867 .985 r
.63904 .34514 m .6363 .34598 L .63732 .34679 L F
.294 0 0 r
.63904 .34514 m .63845 .34537 L .6363 .34598 L F
.42 .819 .982 r
.63732 .34679 m .6363 .34598 L .63429 .34654 L F
.294 0 0 r
.63845 .34537 m .63496 .34671 L .6363 .34598 L F
.42 .819 .982 r
.63429 .34654 m .6363 .34598 L .63353 .34648 L F
.503 .867 .985 r
.63904 .34514 m .63732 .34679 L .6406 .34506 L F
.752 .661 .76 r
.33675 .54563 m .3327 .54568 L .33567 .5427 L F
.607 .158 .158 r
.33675 .54563 m .33542 .54766 L .3327 .54568 L F
.859 .474 .314 r
.3376 .54761 m .33675 .54563 L .33929 .54563 L F
.3376 .54761 m .33542 .54766 L .33675 .54563 L F
.626 .948 .941 r
.47525 .43445 m .4779 .43454 L .48032 .43316 L F
.929 .627 .449 r
.37127 .52527 m .36926 .525 L .36908 .52241 L F
.873 .475 .276 r
.37238 .5266 m .36926 .525 L .37127 .52527 L F
0 0 0 r
.51281 .42665 m .51337 .42636 L .51502 .42575 L F
.655 .468 .618 r
.40532 .56152 m .40859 .56228 L .40707 .55904 L F
.434 .327 .634 r
.40707 .55904 m .40994 .55508 L .40685 .55822 L F
.40707 .55904 m .41078 .5583 L .40994 .55508 L F
.644 .613 .804 r
.40859 .56228 m .41078 .5583 L .40707 .55904 L F
.838 .987 .714 r
.49622 .44628 m .49794 .44449 L .49886 .44269 L F
.613 .892 .989 r
.52553 .47186 m .52411 .47421 L .52371 .47245 L F
.52553 .47186 m .52719 .47307 L .52411 .47421 L F
.996 .791 .511 r
.32069 .57207 m .31897 .5707 L .32089 .5688 L F
.32089 .5688 m .32069 .57207 L .32372 .56832 L F
.32089 .5688 m .31897 .5707 L .32069 .57207 L F
.321 0 0 r
.31036 .68758 m .31201 .68547 L .31381 .68664 L F
.296 0 .045 r
.31201 .68547 m .3145 .6849 L .31381 .68664 L F
.905 .679 .586 r
.68051 .32677 m .68229 .33058 L .6825 .32788 L F
.307 .757 .959 r
.30468 .59472 m .30288 .59512 L .30041 .59423 L F
.739 .674 .786 r
.46569 .57481 m .46725 .57902 L .46792 .57623 L F
.834 .718 .736 r
.46313 .57814 m .46725 .57902 L .46569 .57481 L F
.847 .671 .664 r
.46538 .58231 m .46725 .57902 L .46313 .57814 L F
.786 .916 .927 r
.53656 .48321 m .53719 .4803 L .5362 .48199 L F
.53656 .48321 m .53983 .48078 L .53719 .4803 L F
.715 .986 .821 r
.67372 .37537 m .67219 .37766 L .67424 .37577 L F
.708 .979 .91 r
.66984 .37778 m .67219 .37766 L .67372 .37537 L F
.724 .943 .954 r
.51888 .387 m .51754 .38618 L .5202 .38431 L F
.473 .177 .381 r
.28454 .53186 m .281 .53563 L .28217 .53268 L F
.821 .694 .724 r
.35876 .57183 m .36054 .57563 L .36286 .57232 L F
.211 .116 .523 r
.59442 .35931 m .59218 .36237 L .59234 .36119 L F
.947 .597 .206 r
.62996 .37934 m .63132 .38061 L .62984 .37756 L F
.677 .623 .787 r
.63267 .37632 m .63559 .38131 L .63132 .38061 L F
.741 .479 .533 r
.63487 .3827 m .63132 .38061 L .63559 .38131 L F
0 0 .434 r
.63132 .38061 m .63272 .38138 L .62996 .37934 L F
.741 .479 .533 r
.63487 .3827 m .63233 .38416 L .63132 .38061 L F
0 0 .434 r
.63132 .38061 m .63233 .38416 L .63272 .38138 L F
.778 .691 .768 r
.55854 .41322 m .56264 .41371 L .56121 .40973 L F
.519 .821 1 r
.56144 .41241 m .56264 .41371 L .55854 .41322 L F
.96 .661 .239 r
.56121 .40973 m .56264 .41371 L .56144 .41241 L F
.715 .197 0 r
.29484 .66545 m .29788 .66833 L .29349 .66787 L F
.491 .557 .851 r
.29776 .67123 m .29349 .66787 L .29788 .66833 L F
.468 .538 .845 r
.28921 .62865 m .28994 .62514 L .2875 .62493 L F
.28921 .62865 m .29241 .62861 L .28994 .62514 L F
.446 .266 .542 r
.28921 .62865 m .2914 .6314 L .29241 .62861 L F
.28921 .62865 m .28923 .6312 L .2914 .6314 L F
.605 .78 .964 r
.23954 .60893 m .23588 .6082 L .23855 .60503 L F
.841 .565 .022 r
.23896 .60756 m .23954 .60893 L .23855 .60503 L F
0 0 .182 r
.23985 .60998 m .23954 .60893 L .23896 .60756 L F
.23985 .60998 m .24022 .61187 L .23954 .60893 L F
.805 .943 .916 r
.2875 .62493 m .28619 .62679 L .2843 .62724 L F
.016 0 0 r
.38883 .47066 m .39012 .47081 L .38817 .47136 L F
.38883 .47066 m .39166 .4701 L .39012 .47081 L F
.816 .854 .876 r
.50959 .41245 m .51415 .41152 L .51211 .40967 L F
.295 .743 .96 r
.51697 .41053 m .51211 .40967 L .51415 .41152 L F
.139 0 0 r
.29708 .6624 m .29891 .66118 L .2964 .66153 L F
.86 .839 .824 r
.54999 .39315 m .55358 .39359 L .55475 .391 L F
.592 .776 .967 r
.28923 .6312 m .29344 .63219 L .2914 .6314 L F
.999 .809 .507 r
.29344 .63219 m .29241 .62861 L .2914 .6314 L F
.793 .704 .766 r
.64572 .38387 m .64579 .38483 L .64274 .38402 L F
.623 .707 .906 r
.64881 .38248 m .64888 .38417 L .64579 .38483 L F
.862 .785 .774 r
.32115 .58569 m .31731 .58475 L .32002 .58231 L F
.472 .034 .125 r
.32115 .58569 m .31672 .58791 L .31731 .58475 L F
.32115 .58569 m .31987 .5879 L .31672 .58791 L F
.826 .769 .799 r
.3238 .58232 m .32115 .58569 L .32002 .58231 L F
0 0 0 r
.32148 .58661 m .32115 .58569 L .32372 .58525 L F
.32148 .58661 m .31987 .5879 L .32115 .58569 L F
.489 .286 .531 r
.3238 .58232 m .32372 .58525 L .32115 .58569 L F
.818 .903 .9 r
.53632 .3547 m .53167 .3563 L .53465 .35298 L F
.762 .816 .895 r
.53918 .35296 m .53632 .3547 L .53465 .35298 L F
.924 .852 .753 r
.55324 .38959 m .55692 .38727 L .55248 .3878 L F
.55324 .38959 m .55475 .391 L .55692 .38727 L F
.875 .68 .635 r
.3903 .57858 m .38714 .57808 L .38765 .57529 L F
.822 .568 .555 r
.3903 .57858 m .38734 .58107 L .38714 .57808 L F
.3903 .57858 m .38936 .58191 L .38734 .58107 L F
.835 .945 .894 r
.49553 .51907 m .49678 .52015 L .49894 .51821 L F
.657 .353 .446 r
.4504 .53949 m .44911 .54198 L .44773 .54081 L F
.4504 .53949 m .45181 .54184 L .44911 .54198 L F
.829 .386 .178 r
.35537 .49168 m .35281 .48989 L .35442 .49059 L F
.883 .956 .847 r
.35743 .48658 m .35442 .49059 L .35281 .48989 L F
.633 .962 .9 r
.28485 .66999 m .28799 .66949 L .2846 .67131 L F
.28488 .66983 m .28512 .6698 L .28485 .66999 L F
.28512 .6698 m .28799 .66949 L .28485 .66999 L F
.574 .567 .808 r
.28122 .66668 m .28426 .6704 L .2794 .67143 L F
.28426 .6704 m .2861 .67266 L .28208 .67192 L F
.28426 .6704 m .28208 .67192 L .2794 .67143 L F
.633 .962 .9 r
.28488 .66983 m .2846 .67131 L .2861 .67266 L F
.758 .752 .847 r
.32074 .64543 m .31649 .64537 L .31889 .6441 L F
.773 .882 .925 r
.32125 .64285 m .32074 .64543 L .31889 .6441 L F
.32125 .64285 m .32315 .64416 L .32074 .64543 L F
.762 .634 .719 r
.58612 .42969 m .59009 .42962 L .58893 .42625 L F
.761 .61 .69 r
.58726 .43319 m .59009 .42962 L .58612 .42969 L F
.661 .835 .418 r
.34761 .49896 m .34789 .49826 L .34957 .49573 L F
0 0 0 r
.34957 .49573 m .35002 .49556 L .35234 .49318 L F
.671 .251 .238 r
.34957 .49573 m .35207 .49828 L .35002 .49556 L F
.34957 .49573 m .34789 .49826 L .35207 .49828 L F
.852 .92 .876 r
.41608 .4619 m .42094 .45966 L .41654 .4622 L F
.457 .863 .697 r
.42442 .45749 m .42223 .45862 L .42094 .45966 L F
.456 .857 .674 r
.42223 .45862 m .41654 .4622 L .42094 .45966 L F
.823 .779 .811 r
.3238 .58232 m .32002 .58231 L .32283 .57978 L F
.584 .449 .664 r
.32675 .57912 m .32635 .58232 L .3238 .58232 L F
.573 .354 .544 r
.32635 .58232 m .32372 .58525 L .3238 .58232 L F
.491 0 0 r
.30291 .68671 m .30554 .68588 L .30721 .68699 L F
.854 .87 .852 r
.45553 .5886 m .45929 .58795 L .45775 .58677 L F
.862 .849 .828 r
.45343 .59314 m .45929 .58795 L .45553 .5886 L F
.915 .877 .784 r
.45565 .59367 m .45929 .58795 L .45343 .59314 L F
.69 .773 .915 r
.45929 .58795 m .46041 .58427 L .45775 .58677 L F
.45929 .58795 m .46117 .58743 L .46041 .58427 L F
0 .123 .668 r
.59144 .41058 m .59096 .40888 L .58849 .40656 L F
.883 .989 .736 r
.48614 .41304 m .48546 .41256 L .48794 .40898 L F
.398 .848 .77 r
.59924 .35172 m .59666 .35292 L .59697 .35085 L F
.989 .741 .462 r
.59012 .36431 m .58854 .36361 L .5883 .3598 L F
.58854 .36361 m .58853 .36354 L .5883 .3598 L F
.99 .749 .473 r
.59012 .36431 m .58908 .36602 L .58853 .3636 L F
.867 .659 .128 r
.5883 .3598 m .58842 .36165 L .58831 .36165 L F
.58842 .36165 m .58853 .3636 L .58831 .36165 L F
.673 .166 .031 r
.59051 .36321 m .58831 .36165 L .589 .36554 L F
.526 .031 0 r
.58831 .36165 m .58903 .36247 L .58777 .36163 L F
.58831 .36165 m .58777 .36163 L .58629 .36063 L F
.673 .166 .031 r
.5891 .36598 m .589 .36554 L .58908 .36602 L F
.59051 .36321 m .589 .36554 L .5891 .36598 L F
.989 .741 .462 r
.58854 .36361 m .58853 .3636 L .58853 .36354 L F
.679 .83 .399 r
.59051 .36321 m .59012 .36431 L .59218 .36237 L F
.458 .441 .752 r
.58853 .3636 m .58908 .36602 L .58831 .36165 L F
.679 .83 .399 r
.59032 .36374 m .58908 .36602 L .59012 .36431 L F
.59026 .3637 m .58908 .36602 L .59032 .36374 L F
.849 .724 .725 r
.58903 .36247 m .59045 .3665 L .5867 .36502 L F
0 0 0 r
.58903 .36247 m .58777 .36378 L .58906 .36256 L F
.679 .83 .399 r
.59051 .36321 m .59026 .3637 L .59032 .36374 L F
.673 .166 .031 r
.59051 .36321 m .59041 .36388 L .58831 .36165 L F
.526 .031 0 r
.58901 .36239 m .59021 .36367 L .58903 .36247 L F
.59021 .36367 m .59041 .36388 L .59019 .36366 L F
.59021 .36367 m .59019 .36366 L .58903 .36247 L F
.211 .116 .523 r
.59442 .35931 m .59512 .36228 L .59218 .36237 L F
.04 0 0 r
.59218 .36237 m .59512 .36228 L .59051 .36321 L F
0 0 0 r
.59367 .36083 m .59051 .36321 L .59512 .36228 L F
.59367 .36083 m .59041 .36388 L .59051 .36321 L F
.825 .901 .894 r
.58903 .36247 m .59041 .36388 L .59367 .36083 L F
.58903 .36247 m .59367 .36083 L .59255 .36133 L F
.852 .865 .851 r
.59036 .35763 m .58903 .36247 L .59255 .36133 L F
0 0 0 r
.58903 .36247 m .58949 .36215 L .59255 .36133 L F
.58903 .36247 m .58906 .36256 L .58949 .36215 L F
.526 .031 0 r
.58831 .36165 m .58901 .36239 L .58903 .36247 L F
.732 .528 .616 r
.26011 .55728 m .25922 .55599 L .2623 .55531 L F
.26011 .55728 m .25966 .55884 L .25922 .55599 L F
.599 .951 .88 r
.44855 .4376 m .44703 .43929 L .44653 .43929 L F
.44855 .4376 m .45075 .43742 L .44703 .43929 L F
.924 .932 .793 r
.55212 .46812 m .55465 .46723 L .5549 .46448 L F
.55212 .46812 m .55321 .46918 L .55465 .46723 L F
.925 .658 .513 r
.35096 .53911 m .3509 .54188 L .35306 .54263 L F
.945 .73 .581 r
.35055 .54415 m .35306 .54263 L .3509 .54188 L F
.35055 .54415 m .35266 .54532 L .35306 .54263 L F
.838 .673 .678 r
.36163 .58513 m .35929 .58857 L .36317 .58893 L F
.797 .664 .717 r
.35929 .58857 m .36314 .59151 L .36317 .58893 L F
.861 .996 .805 r
.65529 .39114 m .65683 .38943 L .65589 .38886 L F
.574 .936 .923 r
.65683 .38943 m .65838 .38758 L .65589 .38886 L F
.534 .924 .873 r
.45311 .43612 m .45075 .43742 L .44855 .4376 L F
.333 .801 .926 r
.60234 .344 m .60501 .34351 L .60638 .34372 L F
0 .53 .738 r
.60638 .34372 m .60501 .34351 L .60914 .34406 L F
.774 .705 .787 r
.31904 .53213 m .32038 .53535 L .32288 .53203 L F
.829 .966 .893 r
.51725 .49924 m .52023 .49475 L .51647 .49797 L F
.51725 .49924 m .52146 .49551 L .52023 .49475 L F
.777 .477 .479 r
.59702 .37304 m .60034 .37111 L .59731 .37025 L F
.563 .403 .622 r
.60034 .37111 m .60158 .37339 L .59874 .37421 L F
.777 .477 .479 r
.59702 .37304 m .60158 .37339 L .60034 .37111 L F
.114 0 .031 r
.34233 .66798 m .34564 .66521 L .34438 .667 L F
.331 .436 .818 r
.34825 .6631 m .34564 .66521 L .34376 .6611 L F
0 0 0 r
.34438 .667 m .34564 .66521 L .34825 .6631 L F
.691 .867 .965 r
.32542 .64253 m .32315 .64416 L .32125 .64285 L F
.744 .676 .784 r
.45103 .56578 m .45553 .56642 L .45339 .56229 L F
.821 .746 .78 r
.45553 .56642 m .45604 .56179 L .45339 .56229 L F
.347 .603 .944 r
.28912 .64558 m .28494 .64325 L .28835 .64374 L F
.248 .488 .89 r
.29004 .64377 m .28912 .64558 L .28835 .64374 L F
.296 .549 .921 r
.29004 .64377 m .29231 .6465 L .28912 .64558 L F
0 0 0 r
.63928 .33815 m .6405 .33814 L .64173 .33695 L F
.63928 .33815 m .63799 .33946 L .6405 .33814 L F
.81 .721 .766 r
.32312 .55227 m .32747 .55312 L .32564 .55124 L F
.428 .666 .961 r
.32747 .55312 m .32814 .55062 L .32564 .55124 L F
.32747 .55312 m .32978 .55275 L .32814 .55062 L F
.686 .423 .518 r
.30197 .67159 m .30391 .67414 L .30108 .67504 L F
.544 .816 .996 r
.30197 .67159 m .30609 .67509 L .30391 .67414 L F
.858 .695 .679 r
.37842 .50181 m .38234 .50291 L .382 .49977 L F
.865 .527 .41 r
.37842 .50181 m .38109 .50398 L .38234 .50291 L F
.707 .587 .719 r
.382 .49977 m .38234 .50291 L .385 .49981 L F
.509 .06 .12 r
.38109 .50398 m .38355 .50418 L .38234 .50291 L F
.605 .438 .63 r
.38234 .50291 m .38553 .50309 L .385 .49981 L F
.505 .06 .126 r
.38234 .50291 m .38355 .50418 L .38553 .50309 L F
0 .22 .735 r
.33074 .5833 m .32955 .58286 L .33112 .58272 L F
.33074 .5833 m .33131 .58319 L .32955 .58286 L F
.277 0 0 r
.33131 .58319 m .32819 .58299 L .32955 .58286 L F
.32819 .58299 m .32694 .58291 L .32955 .58286 L F
0 .22 .735 r
.33112 .58272 m .32955 .58286 L .33188 .58154 L F
.605 .715 .922 r
.63561 .38756 m .63294 .38859 L .63225 .38676 L F
0 0 .25 r
.27327 .54495 m .27105 .54866 L .27099 .5472 L F
.859 .887 .856 r
.3179 .62472 m .31897 .62366 L .3163 .62335 L F
.46 .626 .924 r
.31897 .62366 m .31973 .62077 L .3163 .62335 L F
.31897 .62366 m .32192 .62418 L .31973 .62077 L F
.699 .703 .851 r
.33265 .64186 m .33412 .64522 L .3299 .64443 L F
.68 .662 .826 r
.33488 .64041 m .33412 .64522 L .33265 .64186 L F
.33488 .64041 m .33654 .6442 L .33412 .64522 L F
.873 .597 .518 r
.55468 .4291 m .55798 .42989 L .55742 .43181 L F
.881 .944 .85 r
.49648 .50367 m .49529 .50239 L .49837 .50179 L F
.49648 .50367 m .49372 .50375 L .49529 .50239 L F
.954 .782 .631 r
.32227 .5978 m .32428 .59894 L .32351 .60051 L F
.459 .789 .999 r
.58825 .35673 m .5868 .35541 L .58472 .35701 L F
.515 .37 .622 r
.5868 .35541 m .58377 .35893 L .58472 .35701 L F
.956 .784 .335 r
.49255 .44009 m .49281 .43745 L .49517 .43941 L F
.49255 .44009 m .49234 .44319 L .49166 .4413 L F
.737 .664 .779 r
.49517 .43941 m .49234 .44319 L .49255 .44009 L F
.83 .875 .877 r
.53781 .35851 m .53643 .35994 L .53816 .36126 L F
.837 .705 .718 r
.32221 .61083 m .32365 .60959 L .32339 .6069 L F
.699 .605 .747 r
.32339 .6069 m .32365 .60959 L .32587 .60588 L F
.762 .746 .838 r
.46022 .56203 m .45884 .5584 L .45604 .56179 L F
.783 .756 .828 r
.46022 .56203 m .4629 .55877 L .45884 .5584 L F
.76 .687 .782 r
.59491 .37375 m .5968 .37398 L .59702 .37304 L F
.813 .91 .51 r
.59491 .37375 m .59731 .37025 L .59702 .37304 L F
.76 .687 .782 r
.5968 .37398 m .59874 .37421 L .59702 .37304 L F
.369 .432 .795 r
.59764 .37537 m .59491 .37375 L .59702 .37304 L F
.001 0 0 r
.59342 .37437 m .59702 .37304 L .59491 .37375 L F
.59342 .37437 m .59702 .37304 L .59491 .37375 L F
.749 .633 .731 r
.59378 .37365 m .59194 .37668 L .5913 .37342 L F
.59491 .37375 m .59429 .37437 L .59378 .37365 L F
.59429 .37437 m .59194 .37668 L .59378 .37365 L F
.646 .117 0 r
.59092 .37007 m .59491 .37375 L .5913 .37342 L F
.59092 .37007 m .59457 .37379 L .59491 .37375 L F
0 .21 .736 r
.59155 .36869 m .59457 .37379 L .5921 .37127 L F
.59105 .36979 m .5921 .37127 L .59092 .37007 L F
.59155 .36869 m .5921 .37127 L .59105 .36979 L F
.001 0 0 r
.59342 .37437 m .59603 .37379 L .59702 .37304 L F
.59342 .37437 m .59603 .37379 L .59702 .37304 L F
.799 .922 .54 r
.59702 .37304 m .59603 .37379 L .59747 .37108 L F
0 0 .045 r
.59792 .37024 m .59702 .37304 L .59731 .37025 L F
.799 .922 .54 r
.59702 .37304 m .59747 .37108 L .59792 .37024 L F
.511 .273 .49 r
.60158 .37339 m .60136 .37592 L .59874 .37421 L F
.965 .927 .704 r
.64736 .37986 m .64433 .3821 L .64666 .37932 L F
.64736 .37986 m .64572 .38387 L .64433 .3821 L F
.195 .364 .806 r
.64614 .37543 m .64736 .37986 L .64867 .3777 L F
.704 .981 .804 r
.64867 .3777 m .64736 .37986 L .64666 .37932 L F
.718 .692 .825 r
.63717 .37857 m .63559 .38131 L .63267 .37632 L F
.63717 .37857 m .63791 .38043 L .63559 .38131 L F
.576 .316 .484 r
.63559 .38131 m .63708 .3825 L .63487 .3827 L F
.63559 .38131 m .63791 .38043 L .63708 .3825 L F
.085 0 .176 r
.64274 .38402 m .63957 .38742 L .64193 .38517 L F
.787 .974 .912 r
.64193 .38517 m .63957 .38742 L .63838 .38678 L F
.158 .321 .779 r
.53462 .41985 m .53675 .42327 L .53567 .42236 L F
.669 .94 .965 r
.53675 .42327 m .538 .42101 L .53567 .42236 L F
.53675 .42327 m .53954 .4219 L .538 .42101 L F
.59 .777 .969 r
.52905 .40103 m .52451 .39996 L .52753 .40011 L F
.762 .681 .773 r
.52451 .39996 m .52905 .40103 L .52753 .40011 L F
.52451 .39996 m .52566 .40339 L .52905 .40103 L F
.659 .824 .963 r
.53124 .3996 m .52905 .40103 L .52753 .40011 L F
.53124 .3996 m .52905 .40103 L .52753 .40011 L F
.577 .943 .859 r
.45511 .4459 m .45649 .4443 L .45491 .44584 L F
.45511 .4459 m .45901 .44386 L .45649 .4443 L F
.441 .179 .418 r
.29705 .5857 m .29653 .58824 L .29402 .58878 L F
.337 .088 .381 r
.29925 .58501 m .29653 .58824 L .29705 .5857 L F
0 0 0 r
.54197 .43512 m .54048 .4374 L .54269 .43307 L F
.54197 .43512 m .54048 .4374 L .54269 .43307 L F
.993 .839 .478 r
.54137 .43138 m .54269 .43307 L .54197 .43512 L F
.539 .804 .994 r
.54402 .43066 m .54269 .43307 L .54137 .43138 L F
.54402 .43066 m .54551 .43233 L .54269 .43307 L F
.386 .075 .31 r
.54269 .43307 m .54551 .43233 L .54197 .43512 L F
.065 .328 .808 r
.45267 .5917 m .45394 .59439 L .45343 .59314 L F
.859 .887 .856 r
.3179 .62472 m .3163 .62335 L .31488 .62487 L F
.812 .331 0 r
.56251 .38043 m .56155 .381 L .56137 .37928 L F
0 0 0 r
.56054 .38067 m .5613 .37855 L .56155 .381 L F
.56083 .38022 m .56115 .37985 L .56222 .37807 L F
.56054 .38067 m .56067 .38049 L .56083 .38022 L F
.56067 .38049 m .56115 .37985 L .56083 .38022 L F
.812 .331 0 r
.56156 .37896 m .56137 .37928 L .5613 .37855 L F
.56251 .38043 m .56137 .37928 L .56156 .37896 L F
.56251 .38043 m .56306 .38204 L .56155 .381 L F
.268 0 0 r
.40377 .4583 m .40575 .45793 L .40585 .45679 L F
.358 0 0 r
.40575 .45793 m .40829 .4577 L .40585 .45679 L F
.359 0 0 r
.40585 .45679 m .40829 .4577 L .40986 .45592 L F
.576 .466 .691 r
.66608 .32058 m .66969 .31988 L .66863 .31698 L F
.437 .204 .462 r
.66661 .32324 m .66969 .31988 L .66608 .32058 L F
0 0 0 r
.67093 .31093 m .66849 .31436 L .67083 .31192 L F
.335 .291 .66 r
.66849 .31436 m .67113 .31619 L .67083 .31192 L F
.425 .272 .568 r
.66863 .31698 m .67113 .31619 L .66849 .31436 L F
.5 .575 .862 r
.29943 .58232 m .30285 .58304 L .3013 .58063 L F
.406 .179 .454 r
.29943 .58232 m .30161 .58424 L .30285 .58304 L F
.29943 .58232 m .29925 .58501 L .30161 .58424 L F
.30161 .58424 m .29925 .58501 L .29943 .58232 L F
0 0 .427 r
.5962 .38866 m .59441 .38725 L .59569 .3849 L F
.5962 .38866 m .59483 .38992 L .59441 .38725 L F
.33 .171 .508 r
.56426 .39372 m .56257 .39739 L .56436 .39607 L F
0 0 0 r
.56436 .39607 m .56257 .39739 L .561 .3989 L F
.921 .649 .507 r
.68229 .33058 m .68236 .33319 L .68441 .33395 L F
.892 .544 .38 r
.68268 .33562 m .68441 .33395 L .68236 .33319 L F
.68268 .33562 m .68611 .33703 L .68441 .33395 L F
.847 .733 .212 r
.56943 .41624 m .56975 .41366 L .56944 .41151 L F
.031 0 0 r
.52737 .41031 m .52376 .41227 L .52587 .41173 L F
.588 .101 .065 r
.53005 .41239 m .52737 .41031 L .52587 .41173 L F
0 .047 .582 r
.42533 .56432 m .42595 .56878 L .42442 .56569 L F
.281 0 0 r
.32086 .55671 m .32082 .55744 L .32515 .55609 L F
.904 .74 .667 r
.34802 .53804 m .3517 .53602 L .34974 .53463 L F
.34802 .53804 m .35096 .53911 L .3517 .53602 L F
0 0 .327 r
.57037 .41842 m .57094 .42011 L .56943 .41624 L F
0 .053 .617 r
.57271 .42212 m .57094 .42011 L .57037 .41842 L F
.235 0 .247 r
.26706 .55418 m .26563 .55291 L .26826 .55228 L F
.26706 .55418 m .26497 .55515 L .26563 .55291 L F
0 .142 .607 r
.42144 .59057 m .42099 .5899 L .41788 .58994 L F
.437 .78 .997 r
.42099 .5899 m .41783 .58895 L .41788 .58994 L F
.42099 .5899 m .42061 .58869 L .41783 .58895 L F
.953 .835 .69 r
.42132 .59281 m .42076 .58957 L .42099 .5899 L F
.42076 .58957 m .42061 .58869 L .42099 .5899 L F
0 .142 .607 r
.42162 .5906 m .42099 .5899 L .42144 .59057 L F
.42162 .5906 m .4227 .59133 L .42099 .5899 L F
.518 .52 .797 r
.65589 .38886 m .65419 .39344 L .65529 .39114 L F
.804 .427 .342 r
.35932 .51187 m .35509 .50881 L .35886 .50996 L F
.755 .292 .152 r
.32996 .54907 m .33162 .55046 L .33122 .54749 L F
.32996 .54907 m .32814 .55062 L .33162 .55046 L F
.565 .825 .46 r
.33122 .54749 m .32996 .54907 L .3327 .54568 L F
.552 .602 .857 r
.33162 .55046 m .32996 .54907 L .33122 .54749 L F
.432 .851 .694 r
.43169 .60269 m .43375 .60141 L .4318 .60223 L F
.255 .05 .398 r
.4318 .60223 m .43375 .60141 L .43157 .60515 L F
.61 .714 .919 r
.29387 .59886 m .29299 .60236 L .29292 .59872 L F
.29409 .59889 m .29389 .5995 L .29387 .59886 L F
.29389 .5995 m .29299 .60236 L .29387 .59886 L F
.2936 .60045 m .29585 .60151 L .29299 .60236 L F
.29409 .59889 m .29485 .60002 L .2936 .60045 L F
.29485 .60002 m .29585 .60151 L .2936 .60045 L F
.422 .12 .345 r
.29299 .60236 m .29585 .60151 L .29494 .60373 L F
0 .201 .724 r
.29383 .60137 m .29299 .60236 L .29494 .60373 L F
.2931 .59981 m .29305 .60101 L .29383 .60137 L F
.29305 .60101 m .29299 .60236 L .29383 .60137 L F
.672 .741 .902 r
.2967 .59923 m .29585 .60151 L .29409 .59889 L F
0 .201 .724 r
.29396 .60164 m .29494 .60373 L .29401 .60325 L F
.29396 .60164 m .29401 .60325 L .29316 .60281 L F
.935 .877 .755 r
.29434 .60162 m .29494 .60373 L .2967 .59923 L F
.29316 .60281 m .29476 .60364 L .29434 .60162 L F
.29476 .60364 m .29494 .60373 L .29434 .60162 L F
.29547 .60212 m .29646 .59947 L .29561 .60208 L F
.29435 .60161 m .29646 .59947 L .29547 .60212 L F
0 0 .058 r
.29292 .59872 m .2931 .59981 L .29409 .59889 L F
.696 .779 .298 r
.29494 .60373 m .29585 .60151 L .2967 .59923 L F
.718 .685 .817 r
.29596 .59651 m .2967 .59923 L .29409 .59889 L F
.29596 .59651 m .29409 .59889 L .2931 .59981 L F
.678 .922 .608 r
.29399 .59822 m .29596 .59651 L .2931 .59981 L F
.48 .302 .562 r
.29372 .5987 m .29561 .60208 L .29399 .59822 L F
.2931 .59981 m .29416 .60076 L .29372 .5987 L F
.29416 .60076 m .29561 .60208 L .29372 .5987 L F
.935 .877 .755 r
.29316 .60281 m .29435 .60161 L .29547 .60212 L F
.29646 .59947 m .2967 .59923 L .29663 .59941 L F
.29646 .59947 m .29663 .59941 L .29561 .60208 L F
0 .201 .724 r
.2931 .59981 m .29396 .60164 L .29316 .60281 L F
0 0 .058 r
.29292 .59872 m .29299 .60236 L .2931 .59981 L F
0 .226 .743 r
.36179 .48937 m .36473 .49169 L .365 .493 L F
.977 .673 .33 r
.36358 .49409 m .365 .493 L .36473 .49169 L F
.36358 .49409 m .36533 .49594 L .365 .493 L F
.965 .652 .375 r
.33426 .50703 m .33686 .51205 L .33709 .50888 L F
.927 .61 .421 r
.33709 .50888 m .33686 .51205 L .33863 .51259 L F
.045 0 0 r
.38796 .46415 m .38733 .46365 L .38536 .46448 L F
.38796 .46415 m .38996 .4632 L .38733 .46365 L F
.837 .6 .58 r
.6879 .34023 m .68794 .33764 L .68611 .33703 L F
.918 .581 .119 r
.42083 .54702 m .42184 .5467 L .41945 .54494 L F
.42083 .54702 m .42195 .54834 L .42184 .5467 L F
.45 .245 .509 r
.26153 .56796 m .25882 .57195 L .25876 .56895 L F
.38 .283 .618 r
.385 .49981 m .38553 .50309 L .38741 .50167 L F
.714 .825 .933 r
.31155 .64665 m .31351 .64812 L .30949 .64773 L F
.784 .832 .889 r
.31649 .64537 m .31351 .64812 L .31155 .64665 L F
0 0 .213 r
.40445 .5577 m .40348 .56157 L .40208 .56241 L F
.805 .599 .624 r
.40247 .56465 m .40532 .56152 L .40208 .56241 L F
.855 .905 .492 r
.40348 .56157 m .40247 .56465 L .40208 .56241 L F
.304 .12 .458 r
.4093 .59548 m .41146 .59463 L .41179 .59185 L F
.429 .423 .751 r
.4093 .59548 m .41246 .59724 L .41146 .59463 L F
.63 .813 .971 r
.39234 .52113 m .39341 .52272 L .38921 .52219 L F
.39234 .52113 m .39341 .52272 L .38921 .52219 L F
.823 .93 .903 r
.50222 .41763 m .50077 .42085 L .50488 .41718 L F
.267 .271 .678 r
.50222 .41763 m .50217 .42239 L .50077 .42085 L F
.159 0 0 r
.27522 .51868 m .27768 .51768 L .27875 .51662 L F
.294 .025 .324 r
.27768 .51768 m .28031 .51504 L .27875 .51662 L F
.898 .547 .371 r
.41187 .53066 m .41425 .52999 L .4109 .52854 L F
.41187 .53066 m .41464 .53236 L .41425 .52999 L F
.541 .576 .839 r
.49886 .44269 m .49517 .43941 L .49946 .44006 L F
.873 .475 .276 r
.37238 .5266 m .3707 .52795 L .36926 .525 L F
.722 .249 .125 r
.37363 .52837 m .3707 .52795 L .37238 .5266 L F
.28 0 .234 r
.6544 .32985 m .65651 .33151 L .65697 .33005 L F
.6544 .32985 m .65391 .3326 L .65651 .33151 L F
.558 .902 .976 r
.25741 .59781 m .25486 .59872 L .25703 .59826 L F
.934 .805 .694 r
.49352 .43759 m .49521 .43673 L .49291 .43536 L F
.96 .685 .469 r
.49291 .43536 m .49521 .43673 L .49517 .43941 L F
.888 .647 .568 r
.45197 .57281 m .44916 .56886 L .44952 .57097 L F
.738 .311 .236 r
.45021 .57442 m .45197 .57281 L .44952 .57097 L F
.45021 .57442 m .45285 .57464 L .45197 .57281 L F
.192 .215 .655 r
.32339 .6069 m .32311 .60621 L .32587 .60588 L F
.835 .945 .894 r
.49553 .51907 m .49894 .51821 L .49819 .51575 L F
.851 .9 .87 r
.49819 .51575 m .49894 .51821 L .50123 .51562 L F
.937 .832 .387 r
.59162 .40112 m .59272 .39993 L .59224 .39855 L F
.59162 .40112 m .59206 .40307 L .59272 .39993 L F
.882 .992 .788 r
.59224 .39855 m .59272 .39993 L .5943 .39764 L F
.68 .915 .974 r
.4826 .43121 m .48698 .43071 L .4855 .42964 L F
.509 .831 .999 r
.4855 .42964 m .48698 .43071 L .4896 .43 L F
.381 .836 .748 r
.59556 .34412 m .59711 .34311 L .59847 .34446 L F
.59556 .34412 m .59373 .34466 L .59711 .34311 L F
0 0 .103 r
.24362 .56241 m .24456 .56342 L .24504 .56104 L F
.24362 .56241 m .24266 .56516 L .24456 .56342 L F
.364 .052 .296 r
.66354 .3242 m .66593 .32549 L .66661 .32324 L F
.66354 .3242 m .66321 .32636 L .66593 .32549 L F
.853 .965 .874 r
.67951 .37178 m .68325 .36983 L .68271 .36909 L F
.748 .906 .947 r
.68325 .36983 m .68586 .36629 L .68271 .36909 L F
.68325 .36983 m .68712 .36758 L .68586 .36629 L F
.638 .882 .986 r
.64433 .3821 m .64572 .38387 L .64274 .38402 L F
.327 0 .097 r
.52566 .40339 m .52508 .40546 L .52196 .40613 L F
0 .179 .695 r
.52451 .39996 m .52653 .40173 L .52566 .40339 L F
0 0 0 r
.52607 .40352 m .52566 .40339 L .52653 .40173 L F
.52607 .40352 m .52508 .40546 L .52566 .40339 L F
.773 .728 .811 r
.44402 .58486 m .44582 .58903 L .44181 .58876 L F
.785 .733 .805 r
.4487 .58561 m .44582 .58903 L .44402 .58486 L F
.893 .763 .711 r
.29211 .66433 m .29484 .66545 L .29349 .66787 L F
.511 .151 .292 r
.37611 .46546 m .37897 .4652 L .38131 .46194 L F
.613 .28 .383 r
.37897 .4652 m .38275 .46272 L .38131 .46194 L F
.946 .869 .731 r
.56812 .44317 m .56746 .43908 L .56643 .44135 L F
.56812 .44317 m .56892 .4403 L .56746 .43908 L F
.918 .831 .744 r
.56418 .44488 m .56812 .44317 L .56643 .44135 L F
.56418 .44488 m .56596 .4463 L .56812 .44317 L F
.464 .815 .998 r
.31449 .51204 m .31696 .51149 L .31883 .51252 L F
.31449 .51204 m .31696 .51149 L .31883 .51252 L F
.955 .849 .699 r
.31883 .51252 m .31696 .51149 L .31825 .50842 L F
.638 .14 .051 r
.32121 .51204 m .31696 .51149 L .31883 .51252 L F
.896 .55 .382 r
.32515 .55609 m .32509 .55863 L .3233 .55729 L F
.843 .988 .719 r
.32515 .55609 m .3233 .55729 L .32548 .55399 L F
.855 .899 .866 r
.47956 .52544 m .47509 .52759 L .47846 .52463 L F
.47956 .52544 m .47581 .52879 L .47509 .52759 L F
.917 .954 .801 r
.47956 .52544 m .47846 .52463 L .48081 .52095 L F
.53 .888 .978 r
.259 .62711 m .258 .62853 L .25621 .62804 L F
.25621 .62804 m .258 .62853 L .259 .62711 L F
.714 .76 .888 r
.32851 .64162 m .32733 .6455 L .32542 .64253 L F
.32851 .64162 m .3299 .64443 L .32733 .6455 L F
.803 .968 .909 r
.67281 .30908 m .67093 .31093 L .67086 .30939 L F
.275 .225 .62 r
.67083 .31192 m .67086 .30939 L .67093 .31093 L F
.365 .22 .548 r
.2463 .5464 m .24898 .54761 L .24928 .54517 L F
.2463 .5464 m .24647 .54959 L .24898 .54761 L F
.14 0 0 r
.40986 .45592 m .41087 .45695 L .41224 .45548 L F
.40986 .45592 m .40829 .4577 L .41087 .45695 L F
.596 .894 .989 r
.46744 .43921 m .46846 .43737 L .46652 .43848 L F
.46744 .43921 m .47049 .43817 L .46846 .43737 L F
.653 .826 .966 r
.57696 .353 m .57226 .3523 L .57748 .35169 L F
.139 .593 .926 r
.57748 .35169 m .57968 .35214 L .57696 .353 L F
.873 .732 .704 r
.56276 .45246 m .56512 .45364 L .56365 .44949 L F
.861 .746 .735 r
.56382 .45588 m .56512 .45364 L .56276 .45246 L F
.742 .805 .902 r
.46117 .58743 m .46401 .58525 L .46041 .58427 L F
0 0 0 r
.41934 .45249 m .42075 .45193 L .4216 .45157 L F
.259 .766 .758 r
.41819 .45267 m .42075 .45193 L .41934 .45249 L F
0 0 0 r
.52787 .46935 m .52844 .46885 L .52965 .46781 L F
.52844 .46885 m .53215 .46692 L .52965 .46781 L F
.963 .817 .65 r
.68816 .34541 m .69092 .34354 L .68816 .34277 L F
.68816 .34541 m .69019 .34724 L .69092 .34354 L F
.822 .912 .899 r
.33091 .54155 m .33012 .53929 L .33144 .53955 L F
.33091 .54155 m .32712 .54185 L .33012 .53929 L F
.331 .373 .754 r
.33144 .53955 m .33163 .54174 L .33091 .54155 L F
.748 .578 .665 r
.3327 .54568 m .33091 .54155 L .33163 .54174 L F
.3327 .54568 m .33134 .54664 L .33091 .54155 L F
.646 .518 .694 r
.66638 .39093 m .66763 .39321 L .66851 .39068 L F
.119 0 .076 r
.33923 .67089 m .34233 .66798 L .34193 .67079 L F
.205 0 .185 r
.34193 .67079 m .34233 .66798 L .34438 .667 L F
0 0 .565 r
.58664 .40016 m .58765 .40372 L .58771 .40239 L F
.697 .402 0 r
.58765 .40372 m .58802 .40509 L .58771 .40239 L F
.58765 .40372 m .58849 .40656 L .58802 .40509 L F
.937 .599 .362 r
.41577 .59378 m .41705 .59198 L .41635 .59081 L F
.41577 .59378 m .41795 .59529 L .41705 .59198 L F
.962 .66 .41 r
.39028 .49291 m .39057 .49572 L .38851 .49439 L F
.39028 .49291 m .39057 .49572 L .38851 .49439 L F
.849 .892 .868 r
.28494 .64325 m .28076 .64473 L .28148 .64281 L F
.315 .659 .972 r
.28668 .6421 m .28494 .64325 L .28148 .64281 L F
.28668 .6421 m .28835 .64374 L .28494 .64325 L F
.546 .929 .882 r
.44601 .44918 m .44761 .44772 L .44514 .44902 L F
.603 .63 .851 r
.64047 .37947 m .63791 .38043 L .63717 .37857 L F
.64047 .37947 m .63717 .37857 L .63994 .378 L F
0 0 .161 r
.63994 .378 m .63791 .38043 L .64047 .37947 L F
.63994 .378 m .63708 .3825 L .63791 .38043 L F
.656 .846 .973 r
.26319 .5256 m .25916 .52574 L .26173 .52488 L F
.364 .773 .982 r
.26173 .52488 m .26568 .52537 L .26319 .5256 L F
.319 .095 .408 r
.26189 .5598 m .25966 .55884 L .26011 .55728 L F
.361 .043 .284 r
.26497 .55515 m .26011 .55728 L .2623 .55531 L F
.26497 .55515 m .26409 .55771 L .26011 .55728 L F
.596 .45 .654 r
.26409 .55771 m .26189 .5598 L .26011 .55728 L F
.737 .986 .896 r
.28959 .66761 m .28799 .66949 L .28488 .66983 L F
.388 0 0 r
.29097 .67124 m .28799 .66949 L .28959 .66761 L F
.73 .728 .848 r
.39694 .52977 m .39479 .53239 L .3989 .53256 L F
.366 0 .019 r
.39463 .53483 m .3989 .53256 L .39479 .53239 L F
.39463 .53483 m .39788 .5345 L .3989 .53256 L F
0 .153 .688 r
.39694 .52977 m .3989 .53256 L .39769 .53017 L F
.984 .78 .378 r
.3989 .53256 m .39788 .5345 L .39769 .53017 L F
.822 .4 .24 r
.35234 .49318 m .35379 .49631 L .35677 .49649 L F
.803 .363 .199 r
.35379 .49631 m .35462 .49769 L .35677 .49649 L F
0 0 0 r
.35677 .49649 m .35715 .49628 L .35741 .4948 L F
.35677 .49649 m .35462 .49769 L .35715 .49628 L F
.866 .698 .672 r
.35977 .58124 m .36181 .5823 L .36013 .57848 L F
.778 .665 .738 r
.35977 .58124 m .36163 .58513 L .36181 .5823 L F
.6 .952 .863 r
.45649 .4443 m .45901 .44386 L .46122 .44237 L F
.527 .906 .74 r
.60438 .38933 m .60834 .38706 L .60605 .38687 L F
.937 .787 .668 r
.65683 .39731 m .65438 .39921 L .65716 .39542 L F
.65683 .39731 m .65622 .39976 L .65438 .39921 L F
.405 .229 .527 r
.25023 .53502 m .25296 .53149 L .25052 .53195 L F
.805 .599 .624 r
.40247 .56465 m .40631 .5655 L .40532 .56152 L F
.646 .503 .674 r
.40532 .56152 m .40631 .5655 L .40859 .56228 L F
.56 .933 .907 r
.48861 .4093 m .49029 .40771 L .49244 .40787 L F
.48861 .4093 m .48794 .40898 L .49029 .40771 L F
.966 .646 .267 r
.58345 .39305 m .5847 .39367 L .58492 .39623 L F
.488 .796 .999 r
.36135 .49768 m .36315 .49897 L .36071 .4996 L F
.36135 .49768 m .36315 .49897 L .36071 .4996 L F
.941 .891 .752 r
.28124 .65701 m .28459 .65504 L .28196 .65452 L F
.089 0 0 r
.28239 .65679 m .28459 .65504 L .28124 .65701 L F
.965 .69 .464 r
.28237 .65681 m .28239 .65679 L .28248 .65741 L F
.28239 .65679 m .28459 .65504 L .28299 .65684 L F
.28239 .65679 m .28299 .65684 L .28248 .65741 L F
0 0 0 r
.28248 .65741 m .283 .65683 L .28446 .65639 L F
.491 0 0 r
.28478 .65675 m .28446 .65639 L .28675 .65832 L F
0 0 0 r
.283 .65683 m .28393 .65578 L .28446 .65639 L F
.28393 .65578 m .28459 .65504 L .28446 .65639 L F
.089 0 0 r
.28446 .65639 m .28459 .65504 L .28379 .65568 L F
.28446 .65639 m .28379 .65568 L .28239 .65679 L F
.965 .69 .464 r
.28196 .65452 m .28459 .65504 L .28237 .65681 L F
.957 .686 .481 r
.28085 .65668 m .28248 .65741 L .27998 .6584 L F
.28196 .65452 m .28111 .6567 L .28085 .65668 L F
.793 .814 .332 r
.28101 .65644 m .28111 .6567 L .28196 .65452 L F
.28111 .6567 m .28124 .65701 L .28196 .65452 L F
.957 .686 .481 r
.28196 .65452 m .28237 .65679 L .28111 .6567 L F
.257 .763 .869 r
.28239 .65679 m .28124 .65701 L .2811 .65668 L F
.957 .686 .481 r
.28237 .65679 m .28248 .65741 L .28085 .65668 L F
.257 .763 .869 r
.28446 .65639 m .2824 .65679 L .28101 .65644 L F
.2824 .65679 m .28239 .65679 L .28239 .65679 L F
.2824 .65679 m .28239 .65679 L .28101 .65644 L F
.381 .829 .712 r
.27998 .6584 m .28248 .65741 L .28446 .65639 L F
.27998 .6584 m .28248 .65741 L .28446 .65639 L F
.257 .763 .869 r
.28446 .65639 m .28101 .65644 L .28264 .65503 L F
.28239 .65679 m .2811 .65668 L .28101 .65644 L F
.381 .829 .712 r
.27998 .6584 m .28446 .65639 L .28264 .65503 L F
.874 .875 .833 r
.27998 .6584 m .28446 .65639 L .28264 .65503 L F
.491 0 0 r
.28264 .65503 m .28446 .65639 L .28478 .65675 L F
.774 .526 .56 r
.28892 .65366 m .28446 .65639 L .28755 .65685 L F
.274 .675 .97 r
.28638 .65581 m .28446 .65639 L .28264 .65503 L F
.28646 .65582 m .28446 .65639 L .28638 .65581 L F
.715 .567 .687 r
.45111 .58219 m .4487 .58561 L .44769 .58255 L F
.649 .777 .312 r
.29506 .6745 m .29314 .67858 L .29696 .67721 L F
.293 0 0 r
.29382 .67955 m .29314 .67858 L .29224 .68069 L F
.29382 .67955 m .29696 .67721 L .29314 .67858 L F
.888 .909 .835 r
.50367 .51215 m .50531 .51019 L .5027 .51014 L F
.881 .985 .711 r
.50563 .50785 m .50531 .51019 L .5064 .5081 L F
.779 .955 .928 r
.5027 .51014 m .50531 .51019 L .50563 .50785 L F
.541 .283 .473 r
.35002 .49556 m .35379 .49631 L .35234 .49318 L F
.66 .381 .487 r
.43244 .5717 m .43456 .57466 L .43547 .57252 L F
0 .025 .597 r
.43433 .57366 m .43456 .57466 L .43244 .5717 L F
.43433 .57366 m .43244 .5717 L .43026 .57183 L F
.844 .929 .886 r
.5504 .46986 m .55321 .46918 L .55212 .46812 L F
0 0 0 r
.6533 .39486 m .65183 .39696 L .65419 .39344 L F
.518 .52 .797 r
.65589 .38886 m .65833 .39404 L .65419 .39344 L F
.554 .265 .43 r
.65419 .39344 m .65716 .39542 L .6533 .39486 L F
.65419 .39344 m .65833 .39404 L .65716 .39542 L F
.277 .379 .788 r
.2418 .57258 m .24475 .57446 L .24333 .57056 L F
.356 .376 .744 r
.24281 .57462 m .24475 .57446 L .2418 .57258 L F
0 0 .181 r
.56426 .39372 m .56489 .39445 L .56457 .39227 L F
.56426 .39372 m .56436 .39607 L .56489 .39445 L F
.429 .869 .802 r
.64767 .39836 m .65183 .39696 L .65097 .39766 L F
.17 .288 .743 r
.6533 .39486 m .65438 .39921 L .65183 .39696 L F
.657 .101 0 r
.65183 .39696 m .65438 .39921 L .65097 .39766 L F
.149 0 0 r
.4424 .56475 m .4452 .5644 L .44711 .56276 L F
0 0 0 r
.44711 .56276 m .4452 .5644 L .44832 .56254 L F
.828 .743 .77 r
.32622 .55603 m .32888 .55982 L .32509 .55863 L F
.404 0 0 r
.32888 .55982 m .3245 .56146 L .32509 .55863 L F
.32888 .55982 m .3276 .56154 L .3245 .56146 L F
0 0 0 r
.32988 .56038 m .3276 .56154 L .32888 .55982 L F
.313 0 .199 r
.27165 .52216 m .27402 .52153 L .27522 .51868 L F
.389 .05 .265 r
.27402 .52153 m .27768 .51768 L .27522 .51868 L F
.868 .514 .014 r
.69342 .35639 m .6922 .35387 L .69272 .35528 L F
.991 .884 .566 r
.69155 .35943 m .69342 .35639 L .69272 .35528 L F
.69155 .35943 m .69243 .3607 L .69342 .35639 L F
.553 .439 .678 r
.62927 .38783 m .63225 .38676 L .63233 .38416 L F
.782 .351 0 r
.50137 .45239 m .502 .45278 L .49992 .44964 L F
.50137 .45239 m .50236 .45333 L .49992 .44964 L F
.133 .179 .644 r
.50262 .45051 m .50137 .45239 L .49992 .44964 L F
.449 0 0 r
.49654 .44874 m .50137 .45239 L .49782 .45077 L F
.729 .99 .856 r
.50056 .45189 m .50137 .45239 L .50262 .45051 L F
.736 .225 .001 r
.49782 .45077 m .50137 .45239 L .49933 .45271 L F
.729 .99 .856 r
.49933 .45271 m .50137 .45239 L .50056 .45189 L F
.782 .351 0 r
.50137 .45239 m .50236 .45333 L .502 .45278 L F
.655 .865 .979 r
.32013 .61011 m .32058 .60934 L .31823 .60911 L F
.762 .816 .895 r
.53918 .35296 m .53465 .35298 L .53781 .35112 L F
.319 .666 .974 r
.53953 .35142 m .53918 .35296 L .53781 .35112 L F
.53953 .35142 m .54143 .35289 L .53918 .35296 L F
.757 .244 0 r
.33449 .58587 m .33393 .5864 L .33074 .5833 L F
.656 .862 .478 r
.33449 .58587 m .33329 .58721 L .33393 .5864 L F
.768 .271 .035 r
.33628 .58753 m .33329 .58721 L .33449 .58587 L F
0 0 0 r
.32038 .68366 m .32145 .68173 L .32325 .68065 L F
0 0 .128 r
.29402 .58878 m .29508 .58772 L .29528 .58531 L F
.385 .824 .952 r
.29653 .58824 m .29508 .58772 L .29402 .58878 L F
.899 .87 .801 r
.49985 .51419 m .50367 .51215 L .5027 .51014 L F
.49985 .51419 m .50123 .51562 L .50367 .51215 L F
.324 .249 .615 r
.63414 .38521 m .63233 .38416 L .63487 .3827 L F
.149 0 .11 r
.63634 .38397 m .63487 .3827 L .63708 .3825 L F
.63634 .38397 m .63414 .38521 L .63487 .3827 L F
0 .232 .668 r
.39756 .51496 m .39871 .51601 L .39807 .51479 L F
.39756 .51496 m .40233 .5182 L .39871 .51601 L F
.811 .66 .695 r
.40629 .56776 m .41027 .56893 L .40891 .5652 L F
.765 .388 .341 r
.40435 .56788 m .40528 .57174 L .40912 .56904 L F
.751 .98 .733 r
.40912 .56904 m .40528 .57174 L .40754 .56943 L F
.521 0 0 r
.40629 .56776 m .40912 .56904 L .40996 .56884 L F
0 .008 .539 r
.41027 .56893 m .41 .56522 L .40891 .5652 L F
.765 .388 .341 r
.40435 .56788 m .40912 .56904 L .40629 .56776 L F
.751 .98 .733 r
.40912 .56904 m .40754 .56943 L .41002 .56689 L F
.521 0 0 r
.40996 .56884 m .40912 .56904 L .41027 .56893 L F
0 .008 .539 r
.41027 .56893 m .41158 .56766 L .41 .56522 L F
.515 .915 .837 r
.41027 .56893 m .40912 .56904 L .41158 .56766 L F
.467 .752 .991 r
.30078 .64724 m .29998 .64929 L .29857 .64822 L F
.30078 .64724 m .3025 .64849 L .29998 .64929 L F
.603 .54 .756 r
.24472 .55241 m .2474 .5521 L .24647 .54959 L F
.534 .248 .427 r
.24472 .55241 m .24688 .55454 L .2474 .5521 L F
.293 .239 .624 r
.24524 .55536 m .24688 .55454 L .24472 .55241 L F
.685 .413 .504 r
.45861 .57828 m .46018 .57474 L .45649 .57525 L F
.611 .442 .629 r
.46313 .57814 m .46018 .57474 L .45861 .57828 L F
.46313 .57814 m .4631 .57525 L .46018 .57474 L F
.742 .418 0 r
.57061 .37788 m .57074 .3777 L .5707 .3756 L F
.798 .714 .771 r
.60353 .3967 m .60738 .39747 L .60585 .3933 L F
.613 .615 .829 r
.60585 .3933 m .60738 .39747 L .60983 .3963 L F
.916 .519 .142 r
.56298 .38745 m .56383 .38964 L .56217 .38812 L F
.806 .91 .51 r
.56298 .38745 m .56217 .38812 L .56326 .38623 L F
.916 .519 .142 r
.56298 .38745 m .56383 .38964 L .56217 .38812 L F
.836 .945 .893 r
.59316 .34761 m .59196 .34661 L .59373 .34466 L F
.522 .674 .933 r
.65573 .38361 m .65944 .38506 L .65841 .38295 L F
.65573 .38361 m .65944 .38506 L .65841 .38295 L F
.934 .731 .606 r
.34751 .53039 m .34974 .53463 L .34981 .53255 L F
.431 .829 .981 r
.60106 .34337 m .60501 .34351 L .60234 .344 L F
.882 .6 .505 r
.33868 .51778 m .34133 .51566 L .33874 .51516 L F
.33868 .51778 m .34396 .52023 L .34133 .51566 L F
.555 .742 .964 r
.33317 .57884 m .32901 .5781 L .33379 .57719 L F
.705 .788 .916 r
.33588 .57779 m .33317 .57884 L .33379 .57719 L F
.661 .965 .924 r
.49244 .40787 m .49352 .40592 L .4949 .40661 L F
.49244 .40787 m .49029 .40771 L .49352 .40592 L F
.416 0 0 r
.61083 .34967 m .60895 .34999 L .60665 .34956 L F
.232 0 0 r
.61295 .35005 m .60895 .34999 L .61083 .34967 L F
.612 .426 .607 r
.30726 .5721 m .30465 .57548 L .30742 .57514 L F
.30742 .57514 m .30465 .57548 L .30726 .5721 L F
.39 .258 .578 r
.31 .57416 m .30726 .5721 L .30971 .5714 L F
.31 .57416 m .30742 .57514 L .30726 .5721 L F
.31 .57416 m .30726 .5721 L .30971 .5714 L F
.31 .57416 m .30742 .57514 L .30726 .5721 L F
.923 .972 .762 r
.59461 .39473 m .5943 .39764 L .59637 .3945 L F
.63 .949 .944 r
.59637 .3945 m .59791 .39255 L .59461 .39473 L F
.59637 .3945 m .59894 .39317 L .59791 .39255 L F
.844 .843 .843 r
.47581 .52879 m .47351 .52894 L .47509 .52759 L F
.738 .431 .461 r
.32004 .5442 m .32476 .54222 L .32207 .54175 L F
.993 .844 .59 r
.41663 .46685 m .41608 .4619 L .41398 .46536 L F
.807 .765 .815 r
.41351 .46735 m .41663 .46685 L .41398 .46536 L F
.963 .713 .511 r
.25475 .58212 m .25246 .5846 L .25462 .58517 L F
.815 .619 .637 r
.44769 .58255 m .4487 .58561 L .44402 .58486 L F
.823 .905 .897 r
.54178 .46868 m .54122 .46751 L .54357 .46672 L F
.868 .903 .855 r
.54627 .4638 m .54357 .46672 L .54351 .46405 L F
.93 .936 .784 r
.54357 .46672 m .54122 .46751 L .54351 .46405 L F
.686 .883 .504 r
.61647 .39335 m .61433 .39649 L .61514 .39479 L F
.129 .405 .854 r
.61514 .39479 m .61433 .39649 L .61806 .39807 L F
.378 .422 .78 r
.61433 .39649 m .61885 .39845 L .61806 .39807 L F
.69 .484 .604 r
.4631 .57525 m .46569 .57481 L .46349 .57235 L F
.306 .531 .907 r
.41246 .59724 m .41324 .59905 L .41434 .59715 L F
.206 .399 .832 r
.41324 .59905 m .41621 .60093 L .41434 .59715 L F
.489 0 0 r
.41324 .59905 m .41736 .60217 L .41621 .60093 L F
0 .248 .756 r
.57146 .38005 m .57353 .38186 L .57312 .38364 L F
0 0 .571 r
.57431 .38416 m .57312 .38364 L .57353 .38186 L F
.57431 .38416 m .57493 .38588 L .57312 .38364 L F
.846 .666 .659 r
.3912 .50228 m .3907 .50549 L .39323 .50601 L F
.712 .43 .497 r
.38895 .50812 m .39323 .50601 L .3907 .50549 L F
.38895 .50812 m .39355 .50849 L .39323 .50601 L F
0 0 0 r
.35097 .61475 m .35373 .61167 L .35314 .61253 L F
.987 .79 .395 r
.35314 .61253 m .35373 .61167 L .35284 .60842 L F
.836 .823 .836 r
.35284 .60842 m .35373 .61167 L .35651 .60831 L F
.919 .88 .78 r
.67481 .31634 m .67265 .3201 L .67392 .31999 L F
.777 .496 .509 r
.6724 .32283 m .67392 .31999 L .67265 .3201 L F
.6724 .32283 m .67665 .32352 L .67392 .31999 L F
.159 .419 .859 r
.41736 .60217 m .41828 .60048 L .41621 .60093 L F
.41736 .60217 m .41949 .6032 L .41828 .60048 L F
.819 .998 .785 r
.56053 .45831 m .56128 .45871 L .56382 .45588 L F
.65 .967 .897 r
.52472 .49299 m .52023 .49475 L .52146 .49551 L F
.713 .631 .765 r
.33934 .62447 m .34328 .62517 L .34179 .6212 L F
.718 .634 .763 r
.34179 .6212 m .34328 .62517 L .34604 .62177 L F
.76 .723 .818 r
.34433 .61797 m .34857 .61847 L .34693 .61489 L F
.784 .651 .716 r
.34604 .62177 m .34857 .61847 L .34433 .61797 L F
.823 .749 .781 r
.34693 .61489 m .34857 .61847 L .35097 .61475 L F
.773 .383 .315 r
.36975 .50085 m .37377 .49968 L .36986 .49912 L F
.36975 .50085 m .374 .50161 L .37377 .49968 L F
.774 .616 .684 r
.58314 .43268 m .58612 .42969 L .58319 .4299 L F
.774 .456 .449 r
.66564 .33973 m .66344 .33706 L .66567 .33743 L F
0 0 0 r
.50876 .4446 m .5104 .44337 L .51261 .442 L F
.776 .671 .747 r
.58339 .43519 m .58684 .43524 L .58726 .43319 L F
.886 .638 .558 r
.34466 .52209 m .34445 .52478 L .34776 .52564 L F
.923 .676 .546 r
.34463 .52737 m .34776 .52564 L .34445 .52478 L F
.34463 .52737 m .34754 .529 L .34776 .52564 L F
.825 .729 .759 r
.3106 .66548 m .314 .66481 L .31079 .66541 L F
.30996 .66561 m .31143 .66815 L .314 .66481 L F
.527 .309 .526 r
.31143 .66815 m .31443 .66786 L .314 .66481 L F
.954 .621 .346 r
.314 .66481 m .31257 .66687 L .31079 .66541 L F
.041 .2 .703 r
.31196 .665 m .31079 .66541 L .31257 .66687 L F
.31134 .66309 m .31079 .66541 L .31196 .665 L F
.825 .729 .759 r
.30996 .66561 m .3106 .66548 L .31079 .66541 L F
.568 .772 .975 r
.30533 .62512 m .30781 .62447 L .30432 .62337 L F
.954 .621 .346 r
.314 .66481 m .31443 .66786 L .31257 .66687 L F
.535 .918 .789 r
.4647 .42886 m .46274 .43018 L .46055 .43086 L F
0 0 .066 r
.52403 .39078 m .52294 .39022 L .52603 .38966 L F
.52403 .39078 m .5221 .39262 L .52294 .39022 L F
.281 0 .012 r
.64988 .34084 m .64893 .34269 L .64607 .34344 L F
.368 0 .049 r
.6526 .34161 m .64988 .34084 L .65253 .34 L F
.6526 .34161 m .64893 .34269 L .64988 .34084 L F
.887 .689 .63 r
.66995 .34759 m .66936 .35025 L .6673 .34623 L F
.97 .926 .685 r
.57568 .39399 m .57662 .39702 L .57802 .39314 L F
.98 .845 .454 r
.57601 .39953 m .57662 .39702 L .57568 .39399 L F
.797 .664 .717 r
.35929 .58857 m .35889 .5912 L .36314 .59151 L F
.793 .689 .75 r
.35889 .5912 m .3604 .59492 L .36314 .59151 L F
.881 .892 .835 r
.45998 .545 m .46076 .54034 L .46254 .54201 L F
.45998 .545 m .45805 .54389 L .46076 .54034 L F
.127 0 0 r
.64435 .33598 m .64715 .33545 L .64838 .33424 L F
.019 0 0 r
.64838 .33424 m .64989 .33461 L .65121 .33355 L F
.64838 .33424 m .64715 .33545 L .64989 .33461 L F
.868 .903 .855 r
.54627 .4638 m .54351 .46405 L .54435 .46187 L F
.777 .831 .894 r
.54755 .46179 m .54627 .4638 L .54435 .46187 L F
.591 .796 .978 r
.55402 .387 m .55134 .38788 L .55001 .38624 L F
0 0 0 r
.55179 .38773 m .55134 .38788 L .55001 .38624 L F
.137 .682 .732 r
.55099 .38801 m .55134 .38788 L .55248 .3878 L F
.813 .345 0 r
.55134 .38788 m .55324 .38959 L .55248 .3878 L F
.596 .768 .962 r
.55134 .38788 m .55324 .38959 L .55402 .387 L F
.55134 .38788 m .55324 .38959 L .55402 .387 L F
0 0 0 r
.5526 .3884 m .55134 .38788 L .55179 .38773 L F
.137 .682 .732 r
.54844 .38835 m .55134 .38788 L .55099 .38801 L F
.536 .486 .747 r
.61512 .38694 m .61716 .38273 L .61404 .3835 L F
.524 .565 .839 r
.3235 .52504 m .32281 .52598 L .32184 .52686 L F
.32494 .52346 m .32281 .52598 L .3235 .52504 L F
.534 .627 .89 r
.3257 .52917 m .32206 .527 L .32281 .52598 L F
.32206 .527 m .32107 .52641 L .32281 .52598 L F
.099 .639 .851 r
.60501 .34351 m .60758 .34362 L .60914 .34406 L F
.523 .125 .228 r
.60914 .34406 m .61216 .34422 L .61357 .34389 L F
.101 0 0 r
.60758 .34362 m .61216 .34422 L .60914 .34406 L F
.308 0 .196 r
.25296 .53149 m .25549 .53093 L .25629 .52823 L F
0 0 0 r
.25629 .52823 m .258 .52782 L .25916 .52574 L F
.118 0 .126 r
.25629 .52823 m .25735 .53001 L .258 .52782 L F
.25629 .52823 m .25549 .53093 L .25735 .53001 L F
.831 .534 .487 r
.67665 .32352 m .68051 .32677 L .68069 .32408 L F
.029 0 0 r
.53815 .41372 m .53482 .41679 L .54022 .41507 L F
.569 .04 0 r
.54022 .41507 m .5412 .41516 L .53815 .41372 L F
.279 .042 .365 r
.29224 .68069 m .29019 .68156 L .2891 .68485 L F
.97 .926 .685 r
.57568 .39399 m .57802 .39314 L .57677 .39221 L F
.855 .702 .693 r
.3858 .54976 m .38534 .55213 L .38392 .54804 L F
.733 .95 .949 r
.32901 .5781 m .32675 .57912 L .32715 .57717 L F
.564 .894 .985 r
.32901 .5781 m .32947 .57614 L .33379 .57719 L F
.32901 .5781 m .32715 .57717 L .32947 .57614 L F
0 0 0 r
.33116 .54706 m .33134 .54664 L .3327 .54568 L F
.726 .615 .734 r
.33567 .5427 m .3327 .54568 L .33163 .54174 L F
.621 .108 .006 r
.3327 .54568 m .33542 .54766 L .33116 .54706 L F
.742 .474 .523 r
.34482 .65398 m .34905 .65139 L .34712 .65132 L F
.34482 .65398 m .34909 .6545 L .34905 .65139 L F
.823 .749 .781 r
.34693 .61489 m .35097 .61475 L .34942 .61375 L F
0 0 0 r
.35097 .61475 m .35314 .61253 L .34942 .61375 L F
.884 .834 .792 r
.46178 .5558 m .46531 .55518 L .46408 .55435 L F
.46178 .5558 m .4629 .55877 L .46531 .55518 L F
.848 .974 .872 r
.46408 .55435 m .46531 .55518 L .46826 .55208 L F
.706 .585 .717 r
.41113 .58581 m .40819 .59049 L .40652 .58505 L F
.873 .568 .05 r
.40554 .51849 m .40616 .52154 L .40688 .52252 L F
.965 .928 .603 r
.40616 .52154 m .40505 .52417 L .40688 .52252 L F
.749 .309 .208 r
.40688 .52252 m .40505 .52417 L .4074 .52398 L F
.857 .462 .291 r
.36323 .51539 m .35932 .51187 L .36342 .51262 L F
.248 0 .263 r
.33844 .6742 m .33923 .67089 L .34193 .67079 L F
0 0 0 r
.61918 .39117 m .61647 .39335 L .61514 .39479 L F
.864 .707 .685 r
.35833 .57465 m .36054 .57563 L .35876 .57183 L F
.896 .707 .638 r
.35821 .57758 m .36054 .57563 L .35833 .57465 L F
.35821 .57758 m .36013 .57848 L .36054 .57563 L F
0 0 .183 r
.28533 .52669 m .28405 .52606 L .28514 .5247 L F
.28533 .52669 m .2832 .52888 L .28405 .52606 L F
0 0 0 r
.29696 .67721 m .29738 .67687 L .29506 .6745 L F
0 .435 .832 r
.29738 .67687 m .29696 .67721 L .29382 .67955 L F
.29738 .67687 m .29944 .67832 L .29696 .67721 L F
.751 .768 .867 r
.32833 .62425 m .33226 .62486 L .33064 .6211 L F
.804 .791 .841 r
.33064 .6211 m .33226 .62486 L .33496 .62136 L F
.833 .788 .808 r
.30964 .61556 m .31049 .61844 L .30656 .61807 L F
.826 .799 .826 r
.30656 .61807 m .31049 .61844 L .30787 .62107 L F
.802 .772 .825 r
.31324 .61524 m .31049 .61844 L .30964 .61556 L F
.727 .839 .934 r
.30787 .62107 m .3041 .62102 L .30656 .61807 L F
0 0 .295 r
.53482 .41679 m .53462 .41985 L .53541 .41759 L F
0 0 .225 r
.53482 .41679 m .53666 .41741 L .54022 .41507 L F
.53482 .41679 m .53541 .41759 L .53666 .41741 L F
.693 .337 .368 r
.6261 .37898 m .62996 .37934 L .62984 .37756 L F
.357 .092 .368 r
.62984 .37756 m .63264 .37816 L .63267 .37632 L F
.62984 .37756 m .62996 .37934 L .63264 .37816 L F
.851 .717 .715 r
.6678 .34089 m .66706 .3439 L .66564 .33973 L F
.512 0 0 r
.66763 .39321 m .66455 .39178 L .66662 .39187 L F
.992 .879 .599 r
.66641 .39702 m .66763 .39321 L .66662 .39187 L F
.829 .814 .836 r
.28892 .65366 m .29326 .65475 L .29073 .65217 L F
.28892 .65366 m .29105 .65499 L .29326 .65475 L F
.651 .821 .965 r
.29073 .65217 m .29326 .65475 L .29609 .65167 L F
.778 .665 .738 r
.35977 .58124 m .35769 .5852 L .36163 .58513 L F
.843 .681 .681 r
.35701 .58719 m .36163 .58513 L .35769 .5852 L F
.35701 .58719 m .35929 .58857 L .36163 .58513 L F
.724 .724 .85 r
.31884 .61072 m .32149 .61085 L .31757 .61334 L F
.472 0 .018 r
.31791 .61264 m .31884 .61072 L .31789 .6128 L F
.31823 .60911 m .31884 .61072 L .31791 .61264 L F
.963 .736 .293 r
.31733 .60769 m .31747 .60792 L .31786 .61247 L F
.724 .724 .85 r
.31791 .61264 m .31757 .61334 L .31786 .61247 L F
.31786 .61247 m .31757 .61334 L .31727 .61353 L F
.31786 .61247 m .31727 .61353 L .31789 .6128 L F
.963 .736 .293 r
.31785 .61241 m .31786 .61247 L .31789 .6128 L F
.31733 .60769 m .31786 .61247 L .31785 .61241 L F
.724 .724 .85 r
.31884 .61072 m .31791 .61264 L .31786 .61247 L F
.31884 .61072 m .31786 .61247 L .31789 .6128 L F
.963 .736 .293 r
.31747 .60792 m .31823 .60911 L .31789 .6128 L F
.472 0 .018 r
.31823 .60911 m .32058 .60934 L .31884 .61072 L F
.509 .881 .976 r
.66284 .36988 m .65979 .37098 L .65876 .37026 L F
.722 .624 .748 r
.33328 .53868 m .33567 .5427 L .33163 .54174 L F
.546 .553 .813 r
.33724 .54171 m .33567 .5427 L .33328 .53868 L F
.83 .962 .894 r
.53983 .48078 m .54041 .47799 L .53719 .4803 L F
.53983 .48078 m .54164 .47891 L .54041 .47799 L F
.426 .08 .274 r
.26568 .52537 m .26829 .52486 L .26897 .52286 L F
.534 .245 .422 r
.26829 .52486 m .27165 .52216 L .26897 .52286 L F
.702 .673 .819 r
.33919 .6414 m .33654 .6442 L .33488 .64041 L F
.672 .622 .791 r
.33919 .6414 m .34108 .64561 L .33654 .6442 L F
.851 .9 .87 r
.49819 .51575 m .50123 .51562 L .49985 .51419 L F
.088 0 0 r
.39248 .46245 m .3951 .46157 L .3966 .45995 L F
.191 0 0 r
.3951 .46157 m .39932 .4599 L .3966 .45995 L F
.75 .733 .837 r
.34179 .64074 m .34108 .64561 L .33919 .6414 L F
.34179 .64074 m .34356 .64431 L .34108 .64561 L F
.861 .746 .735 r
.56382 .45588 m .56276 .45246 L .56273 .45501 L F
.819 .998 .785 r
.56053 .45831 m .56382 .45588 L .56273 .45501 L F
.324 .638 .965 r
.41949 .6032 m .4218 .60485 L .42391 .60496 L F
.73 .767 .882 r
.33265 .64186 m .3299 .64443 L .32851 .64162 L F
.882 .992 .788 r
.59224 .39855 m .5943 .39764 L .59461 .39473 L F
.86 .839 .824 r
.54999 .39315 m .55475 .391 L .55324 .38959 L F
.261 0 0 r
.33231 .67672 m .33337 .67518 L .33485 .67601 L F
.26 0 0 r
.33337 .67518 m .33589 .67467 L .33485 .67601 L F
.404 0 0 r
.39634 .46828 m .39801 .46683 L .40071 .46757 L F
.398 0 0 r
.39801 .46683 m .40023 .46674 L .40071 .46757 L F
.96 .673 .447 r
.3598 .48827 m .35994 .49095 L .36179 .48937 L F
.665 .197 .133 r
.35994 .49095 m .36473 .49169 L .36179 .48937 L F
.838 .978 .878 r
.50125 .40324 m .50277 .39989 L .50465 .40089 L F
.50125 .40324 m .50044 .40229 L .50277 .39989 L F
.891 .599 .487 r
.3388 .52025 m .34396 .52023 L .33868 .51778 L F
.3388 .52025 m .34306 .52205 L .34396 .52023 L F
.821 .504 .454 r
.34396 .52023 m .34306 .52205 L .34466 .52209 L F
.958 .937 .72 r
.54296 .47448 m .54415 .47586 L .54488 .47368 L F
.913 .953 .807 r
.54041 .47799 m .54415 .47586 L .54296 .47448 L F
.54041 .47799 m .54164 .47891 L .54415 .47586 L F
.863 .789 .776 r
.32221 .61083 m .31727 .61353 L .32149 .61085 L F
.32221 .61083 m .31984 .61478 L .31727 .61353 L F
.727 .219 0 r
.32058 .60934 m .32221 .61083 L .32149 .61085 L F
.5 .882 .969 r
.57226 .3523 m .57392 .35085 L .57748 .35169 L F
.491 .849 .992 r
.57392 .35085 m .57814 .3509 L .57748 .35169 L F
.139 .593 .926 r
.57748 .35169 m .57814 .3509 L .57968 .35214 L F
.687 .965 .741 r
.52716 .4148 m .53092 .41177 L .53005 .41239 L F
0 0 0 r
.53005 .41239 m .53092 .41177 L .53267 .4115 L F
.53005 .41239 m .53092 .41177 L .53267 .4115 L F
.563 .764 .973 r
.58792 .37369 m .5844 .37268 L .58606 .37198 L F
.876 .895 .842 r
.59092 .37007 m .58792 .37369 L .58606 .37198 L F
.59092 .37007 m .58606 .37198 L .58907 .36953 L F
.815 .674 .708 r
.5913 .37342 m .58806 .37554 L .58792 .37369 L F
.5913 .37342 m .59194 .37668 L .58806 .37554 L F
.743 .466 .512 r
.59177 .37503 m .59095 .37452 L .58896 .37452 L F
.739 .835 .384 r
.58705 .37422 m .58839 .371 L .58606 .37198 L F
.58711 .37422 m .58839 .371 L .58705 .37422 L F
.622 .464 .647 r
.59092 .37007 m .5913 .37342 L .58792 .37369 L F
.739 .835 .384 r
.58738 .37355 m .58762 .37247 L .58869 .37026 L F
.58708 .3743 m .58762 .37247 L .58738 .37355 L F
.58839 .371 m .58869 .37026 L .58606 .37198 L F
0 0 0 r
.58606 .37198 m .58869 .37026 L .58907 .36953 L F
.777 .604 .037 r
.58762 .37247 m .58728 .36787 L .58869 .37026 L F
.743 .466 .512 r
.59095 .37452 m .58762 .37247 L .58885 .37436 L F
.59095 .37452 m .58885 .37436 L .58896 .37452 L F
.93 .585 .146 r
.58792 .37369 m .58806 .37554 L .58708 .3743 L F
.224 .519 .915 r
.58708 .3743 m .58896 .37452 L .58762 .37247 L F
.997 .795 .506 r
.58708 .3743 m .58631 .37756 L .58806 .37554 L F
.513 .307 .538 r
.58631 .37756 m .58708 .3743 L .58806 .37554 L F
.58631 .37756 m .58896 .37452 L .58708 .3743 L F
.58631 .37756 m .58922 .37695 L .58896 .37452 L F
.822 .57 .558 r
.58922 .37695 m .59177 .37503 L .58896 .37452 L F
.743 .466 .512 r
.59177 .37503 m .58793 .37531 L .58762 .37247 L F
.484 .279 .526 r
.58762 .37247 m .59056 .37437 L .58793 .37105 L F
.58762 .37247 m .58793 .37105 L .58725 .37019 L F
.739 .835 .384 r
.58708 .3743 m .58711 .37422 L .58705 .37422 L F
.563 .764 .973 r
.5844 .37268 m .58387 .37253 L .58606 .37198 L F
0 0 .25 r
.27327 .54495 m .27274 .54763 L .27105 .54866 L F
0 0 0 r
.27274 .54763 m .27002 .55115 L .27105 .54866 L F
.926 .955 .631 r
.55122 .44514 m .5501 .44926 L .54978 .4472 L F
.329 .55 .914 r
.5501 .44926 m .5502 .44985 L .54978 .4472 L F
.972 .915 .583 r
.54978 .4472 m .5502 .44985 L .54911 .4526 L F
.6 .62 .843 r
.31809 .57517 m .31897 .5707 L .32069 .57207 L F
.583 .362 .545 r
.32069 .57207 m .32089 .57499 L .31809 .57517 L F
0 .208 .728 r
.31897 .5707 m .32106 .57236 L .32069 .57207 L F
.529 .569 .84 r
.32106 .57236 m .32089 .57499 L .32069 .57207 L F
.868 .471 .282 r
.5544 .41089 m .55281 .41201 L .55068 .41093 L F
.601 .094 .018 r
.55552 .4116 m .55281 .41201 L .5544 .41089 L F
.97 .929 .679 r
.57199 .42575 m .57194 .42914 L .57317 .42725 L F
.875 .874 .832 r
.49837 .50179 m .49529 .50239 L .49781 .49892 L F
.789 .828 .882 r
.5015 .49918 m .49837 .50179 L .49781 .49892 L F
.938 .646 .461 r
.33932 .55539 m .33675 .55735 L .33714 .55418 L F
.33932 .55539 m .33935 .55874 L .33675 .55735 L F
.831 .548 .51 r
.34236 .55879 m .33935 .55874 L .33932 .55539 L F
.806 .592 .612 r
.32155 .54795 m .32616 .54863 L .326 .54537 L F
.236 0 .157 r
.52167 .40737 m .51955 .40705 L .52196 .40613 L F
.52167 .40737 m .51891 .40875 L .51955 .40705 L F
0 0 .121 r
.30701 .57772 m .30742 .57514 L .30465 .57548 L F
.587 .341 .511 r
.30742 .57514 m .30701 .57772 L .30465 .57548 L F
.591 .932 .951 r
.43074 .4573 m .43103 .45589 L .42868 .45612 L F
.43074 .4573 m .43315 .45605 L .43103 .45589 L F
.842 .631 .617 r
.33813 .58816 m .33466 .59113 L .33628 .58753 L F
.543 .389 .622 r
.34023 .59071 m .33813 .58816 L .34131 .58819 L F
.042 0 0 r
.42742 .44869 m .43007 .44801 L .43165 .44679 L F
.195 .715 .682 r
.43222 .44662 m .43165 .44679 L .43007 .44801 L F
.43222 .44662 m .43429 .44603 L .43165 .44679 L F
.531 .119 .204 r
.63065 .34676 m .62688 .34871 L .62656 .34782 L F
.63065 .34676 m .62968 .34893 L .62688 .34871 L F
.211 0 .067 r
.63231 .34792 m .63065 .34676 L .63353 .34648 L F
.63231 .34792 m .62968 .34893 L .63065 .34676 L F
.686 .919 .972 r
.50687 .39938 m .50465 .40089 L .50277 .39989 L F
.935 .849 .733 r
.46342 .53962 m .46254 .54201 L .46076 .54034 L F
.261 0 0 r
.3235 .5049 m .32622 .50449 L .32686 .50367 L F
.312 0 0 r
.32622 .50449 m .32911 .50413 L .32686 .50367 L F
.989 .75 .371 r
.6889 .34807 m .69019 .34724 L .68816 .34541 L F
.6889 .34807 m .69005 .34978 L .69019 .34724 L F
.753 .692 .793 r
.33923 .6221 m .33934 .62447 L .34179 .6212 L F
.779 .451 .432 r
.45283 .57707 m .45649 .57525 L .45285 .57464 L F
.45283 .57707 m .45458 .57786 L .45649 .57525 L F
.756 .42 .416 r
.45458 .57786 m .45861 .57828 L .45649 .57525 L F
.924 .638 .481 r
.34802 .53804 m .3509 .54188 L .35096 .53911 L F
.969 .749 .552 r
.66706 .3439 m .66536 .34287 L .66564 .33973 L F
.94 .604 .366 r
.66706 .3439 m .66529 .34468 L .66536 .34287 L F
.66706 .3439 m .6673 .34623 L .66529 .34468 L F
.634 .281 .354 r
.66344 .33706 m .66178 .33941 L .65918 .33726 L F
.774 .456 .449 r
.66564 .33973 m .66178 .33941 L .66344 .33706 L F
0 .266 .652 r
.65803 .40112 m .65438 .39921 L .65622 .39976 L F
.883 .956 .847 r
.35743 .48658 m .35281 .48989 L .3562 .48589 L F
0 .19 .673 r
.3575 .48624 m .35743 .48658 L .3562 .48589 L F
.3575 .48624 m .3598 .48827 L .35743 .48658 L F
.671 .971 .911 r
.43947 .4526 m .44303 .45056 L .44061 .45063 L F
.699 .978 .788 r
.43947 .4526 m .44061 .45063 L .43882 .45242 L F
.597 .949 .825 r
.43947 .4526 m .43882 .45242 L .43528 .45461 L F
.623 .923 .974 r
.66283 .40033 m .66175 .39957 L .65803 .40112 L F
.72 .884 .957 r
.66373 .39762 m .66283 .40033 L .66504 .39895 L F
.816 .976 .895 r
.66373 .39762 m .66175 .39957 L .66283 .40033 L F
.538 .033 0 r
.28008 .67353 m .28148 .67486 L .28376 .67725 L F
.678 .906 .567 r
.61733 .35037 m .61467 .35374 L .61604 .35149 L F
.589 .42 .621 r
.61775 .35279 m .61467 .35374 L .61733 .35037 L F
.69 .499 .624 r
.61819 .35653 m .61467 .35374 L .61775 .35279 L F
0 0 .294 r
.61467 .35374 m .61592 .35398 L .61604 .35149 L F
.69 .499 .624 r
.61819 .35653 m .6146 .35694 L .61467 .35374 L F
0 0 .294 r
.61467 .35374 m .6146 .35694 L .61592 .35398 L F
.396 0 0 r
.31927 .50522 m .32212 .50561 L .3235 .5049 L F
.263 0 0 r
.32212 .50561 m .32622 .50449 L .3235 .5049 L F
.795 .87 .903 r
.46884 .54707 m .46713 .5481 L .47087 .54816 L F
.913 .885 .792 r
.46665 .55091 m .47087 .54816 L .46713 .5481 L F
.46665 .55091 m .46826 .55208 L .47087 .54816 L F
.835 .864 .867 r
.46884 .54707 m .47087 .54816 L .47353 .54534 L F
.878 .602 .515 r
.33085 .52518 m .32796 .52163 L .331 .52246 L F
.687 .945 .96 r
.538 .42101 m .53954 .4219 L .54309 .41987 L F
0 .002 .559 r
.54364 .41738 m .54206 .41743 L .5412 .41516 L F
.54364 .41738 m .54309 .41987 L .54206 .41743 L F
.922 .783 .69 r
.38894 .56309 m .38845 .56534 L .38715 .56162 L F
.851 .997 .815 r
.5529 .40315 m .54999 .40644 L .5503 .40479 L F
0 0 .126 r
.54999 .40644 m .55053 .40716 L .5503 .40479 L F
.988 .72 .4 r
.55545 .41635 m .55408 .41796 L .55452 .41521 L F
.55545 .41635 m .55546 .41944 L .55408 .41796 L F
.734 .652 .769 r
.55552 .4116 m .55545 .41635 L .55452 .41521 L F
.55552 .4116 m .55854 .41322 L .55545 .41635 L F
.656 .887 .982 r
.32715 .57717 m .32675 .57912 L .32477 .57833 L F
.764 .784 .87 r
.45884 .5584 m .4629 .55877 L .46178 .5558 L F
.849 .918 .878 r
.59325 .43474 m .5946 .43626 L .59516 .43379 L F
.943 .95 .75 r
.58987 .4353 m .58872 .44012 L .59115 .4393 L F
.58987 .4353 m .59115 .4393 L .59133 .4389 L F
.863 .907 .862 r
.59145 .4392 m .58998 .43636 L .58987 .4353 L F
0 0 0 r
.58987 .4353 m .59075 .43562 L .59062 .43313 L F
.849 .918 .878 r
.59076 .43598 m .59253 .43631 L .59325 .43474 L F
.58998 .43636 m .59516 .43379 L .59502 .43361 L F
.832 .998 .836 r
.59502 .43361 m .59142 .43587 L .58998 .43636 L F
0 0 0 r
.59075 .43562 m .59142 .43587 L .59071 .43344 L F
.59075 .43562 m .59071 .43344 L .59062 .43313 L F
.849 .918 .878 r
.58998 .43636 m .59076 .43635 L .59076 .43598 L F
.59076 .43635 m .59253 .43631 L .59076 .43598 L F
.59253 .43631 m .5946 .43626 L .59325 .43474 L F
.943 .95 .75 r
.59133 .4389 m .59115 .4393 L .59145 .4392 L F
.883 .714 .667 r
.38392 .54804 m .38534 .55213 L .38235 .55147 L F
.919 .688 .573 r
.38472 .55525 m .38235 .55147 L .38534 .55213 L F
0 .216 .739 r
.57922 .37676 m .57937 .37503 L .57687 .37303 L F
.978 .713 .457 r
.58115 .3787 m .57937 .37503 L .57922 .37676 L F
.589 .853 .506 r
.23588 .6082 m .23682 .60687 L .23855 .60503 L F
.731 .506 0 r
.23588 .6082 m .23611 .61018 L .23682 .60687 L F
.869 .888 .846 r
.34755 .5015 m .34789 .49826 L .34761 .49896 L F
.639 .278 .341 r
.65918 .33726 m .66178 .33941 L .65928 .33909 L F
.689 .706 .86 r
.34574 .6418 m .34356 .64431 L .34179 .64074 L F
.627 .606 .809 r
.34574 .6418 m .34743 .64548 L .34356 .64431 L F
.908 .68 .582 r
.68049 .32968 m .68229 .33058 L .68051 .32677 L F
.914 .642 .512 r
.68069 .33268 m .68229 .33058 L .68049 .32968 L F
.68069 .33268 m .68236 .33319 L .68229 .33058 L F
.763 .573 .641 r
.54911 .4526 m .55385 .45304 L .55294 .45559 L F
0 0 .297 r
.53156 .43208 m .53157 .43578 L .53286 .43341 L F
0 .163 .657 r
.62199 .38081 m .62042 .38003 L .62002 .38158 L F
0 .062 .583 r
.58849 .40656 m .589 .40665 L .58802 .40509 L F
.58849 .40656 m .59096 .40888 L .589 .40665 L F
.546 .848 .532 r
.66251 .38349 m .66535 .38056 L .66425 .38156 L F
0 0 .414 r
.66275 .38616 m .66251 .38349 L .66425 .38156 L F
.827 .572 .553 r
.35004 .55418 m .3525 .55226 L .3501 .55148 L F
.35004 .55418 m .35222 .55526 L .3525 .55226 L F
.841 .709 .717 r
.35889 .5912 m .35637 .59468 L .3604 .59492 L F
.839 .725 .739 r
.35637 .59468 m .35781 .59861 L .3604 .59492 L F
.618 .862 .989 r
.40445 .5577 m .40685 .55822 L .40573 .55459 L F
.74 .72 .832 r
.40573 .55459 m .40685 .55822 L .40994 .55508 L F
.856 .665 .643 r
.35284 .60842 m .35651 .60831 L .3547 .60494 L F
.932 .63 .448 r
.33664 .51393 m .33863 .51259 L .33686 .51205 L F
.33664 .51393 m .33874 .51516 L .33863 .51259 L F
.918 .733 .637 r
.36908 .52241 m .36676 .52157 L .36748 .51858 L F
.9 .538 .345 r
.36908 .52241 m .36726 .52398 L .36676 .52157 L F
.954 .65 .419 r
.36908 .52241 m .36926 .525 L .36726 .52398 L F
.162 .187 .639 r
.58664 .40016 m .58771 .40239 L .59037 .3994 L F
.612 .817 .979 r
.31727 .61353 m .31984 .61478 L .31585 .61431 L F
.969 .742 .54 r
.59092 .37007 m .58907 .36953 L .58908 .36602 L F
.59092 .37007 m .58907 .36953 L .58908 .36602 L F
0 .21 .736 r
.59155 .36869 m .59092 .37007 L .58907 .36953 L F
0 0 .094 r
.32107 .52641 m .32133 .53072 L .32119 .52719 L F
0 0 0 r
.32119 .52719 m .32281 .52598 L .32107 .52641 L F
.38 .443 .8 r
.6518 .36992 m .65057 .374 L .65211 .37346 L F
.58 .667 .898 r
.65211 .37346 m .65175 .37368 L .65171 .37359 L F
.65211 .37346 m .65171 .37359 L .65002 .37033 L F
.826 .722 .75 r
.65644 .37093 m .65352 .37598 L .6518 .36992 L F
.972 .707 .47 r
.6518 .36992 m .65211 .37346 L .65002 .37033 L F
.579 .71 .932 r
.65171 .37359 m .65283 .37033 L .65002 .37033 L F
.65175 .37368 m .65179 .37356 L .65171 .37359 L F
.65179 .37356 m .65283 .37033 L .65171 .37359 L F
.229 .737 .687 r
.65211 .37346 m .65057 .374 L .6495 .37431 L F
.65171 .37359 m .6495 .37431 L .64929 .37438 L F
.65211 .37346 m .6495 .37431 L .65171 .37359 L F
.579 .71 .932 r
.65175 .37368 m .65468 .37323 L .65436 .37273 L F
.65179 .37356 m .65436 .37273 L .65283 .37033 L F
.65175 .37368 m .65436 .37273 L .65179 .37356 L F
.229 .737 .687 r
.65199 .3735 m .64929 .37438 L .64906 .37444 L F
.65211 .37346 m .64974 .37423 L .65199 .3735 L F
.64974 .37423 m .64929 .37438 L .65199 .3735 L F
.409 .764 .995 r
.4258 .60722 m .4266 .60604 L .42391 .60496 L F
.4258 .60722 m .4281 .60714 L .4266 .60604 L F
.269 0 0 r
.40202 .58729 m .39825 .58658 L .39915 .58642 L F
.494 .905 .842 r
.66133 .39396 m .65716 .39542 L .66007 .39232 L F
.693 .909 .971 r
.66455 .39178 m .66133 .39396 L .66288 .39127 L F
.619 .815 .976 r
.66288 .39127 m .66133 .39396 L .66007 .39232 L F
.428 .753 .995 r
.27821 .62841 m .28128 .62832 L .27883 .62674 L F
.27821 .62841 m .28128 .62832 L .27883 .62674 L F
.678 .906 .567 r
.61733 .35037 m .61604 .35149 L .61295 .35005 L F
.387 .282 .612 r
.61733 .35037 m .62022 .35228 L .61775 .35279 L F
.597 .065 0 r
.61604 .35149 m .62022 .35228 L .61733 .35037 L F
.61604 .35149 m .61733 .35037 L .61992 .3491 L F
.941 .879 .746 r
.34211 .56435 m .34377 .56542 L .34167 .5684 L F
.816 .645 .67 r
.34377 .56542 m .34336 .56876 L .34167 .5684 L F
0 0 0 r
.52844 .46885 m .53095 .46808 L .53215 .46692 L F
.707 .535 .653 r
.44163 .58564 m .44181 .58876 L .4383 .58837 L F
.482 .362 .639 r
.44402 .58486 m .44163 .58564 L .4427 .58396 L F
.44402 .58486 m .44181 .58876 L .44163 .58564 L F
0 0 0 r
.41553 .53719 m .41494 .53888 L .41592 .5354 L F
0 0 .491 r
.41464 .53236 m .41594 .5344 L .41592 .5354 L F
.756 .696 .154 r
.41594 .5344 m .41553 .53719 L .41592 .5354 L F
.712 .594 .722 r
.40859 .56228 m .40631 .5655 L .40891 .5652 L F
.811 .66 .695 r
.40629 .56776 m .40891 .5652 L .40631 .5655 L F
.643 .55 .734 r
.40891 .5652 m .41148 .56169 L .40859 .56228 L F
.40891 .5652 m .41 .56522 L .41148 .56169 L F
.893 .832 .779 r
.44689 .56769 m .45103 .56578 L .44939 .56452 L F
.44689 .56769 m .44916 .56886 L .45103 .56578 L F
.848 .84 .837 r
.45103 .56578 m .45202 .56115 L .44939 .56452 L F
.45103 .56578 m .45339 .56229 L .45202 .56115 L F
.776 .515 .541 r
.34236 .55879 m .33794 .56103 L .33935 .55874 L F
.34236 .55879 m .34231 .56151 L .33794 .56103 L F
.813 .91 .51 r
.59491 .37375 m .59705 .36865 L .59731 .37025 L F
.547 .799 .992 r
.59705 .36865 m .59731 .37025 L .59837 .36777 L F
0 0 .045 r
.59792 .37024 m .59731 .37025 L .59837 .36777 L F
.908 .596 .444 r
.30988 .67097 m .31143 .66815 L .31001 .67205 L F
.31041 .6692 m .31143 .66815 L .31045 .66992 L F
.31027 .66966 m .31045 .66992 L .30999 .67076 L F
.31027 .66966 m .30999 .67076 L .30999 .6706 L F
.845 .658 .65 r
.30533 .66533 m .31027 .66966 L .31017 .6684 L F
.908 .596 .444 r
.30975 .66987 m .31041 .6692 L .30988 .67097 L F
.932 .81 .702 r
.30997 .66925 m .31049 .66985 L .31027 .66966 L F
.30997 .66925 m .31027 .66966 L .30533 .66533 L F
.845 .658 .65 r
.30533 .66533 m .31017 .6684 L .30729 .66545 L F
.932 .81 .702 r
.30789 .66679 m .30997 .66925 L .30724 .66695 L F
.30789 .66679 m .30724 .66695 L .30533 .66533 L F
.30989 .66915 m .31001 .67205 L .30997 .66925 L F
.30883 .66913 m .31001 .67205 L .30989 .66915 L F
.845 .658 .65 r
.31027 .66966 m .31041 .6692 L .30996 .66561 L F
.953 .73 .564 r
.31041 .6692 m .31143 .66815 L .30996 .66561 L F
.908 .596 .444 r
.30969 .66934 m .31143 .66815 L .31035 .66925 L F
.30969 .66934 m .31012 .66949 L .30975 .66987 L F
.932 .81 .702 r
.30997 .66925 m .31001 .67205 L .31049 .66985 L F
.908 .596 .444 r
.31041 .6692 m .31045 .66992 L .31027 .66966 L F
.845 .658 .65 r
.31027 .66966 m .31049 .66985 L .31041 .6692 L F
.985 .896 .573 r
.31054 .66992 m .31143 .66815 L .3105 .66982 L F
.3105 .67071 m .31143 .66815 L .31042 .67017 L F
.953 .73 .564 r
.31049 .66985 m .31143 .66815 L .31041 .6692 L F
.908 .596 .444 r
.30997 .66915 m .31094 .66917 L .31053 .66876 L F
.404 .171 .444 r
.31131 .67044 m .31135 .66973 L .31001 .67205 L F
.31135 .66973 m .31143 .66815 L .31066 .67026 L F
.31135 .66973 m .31066 .67026 L .31001 .67205 L F
.908 .596 .444 r
.31053 .66876 m .31159 .66974 L .31143 .66815 L F
.893 .59 .466 r
.31131 .67044 m .31204 .67015 L .31143 .66815 L F
.908 .596 .444 r
.31159 .66974 m .31204 .67015 L .31193 .66981 L F
.31159 .66974 m .31193 .66981 L .31143 .66815 L F
.31182 .67008 m .31204 .67015 L .31053 .66876 L F
.548 .401 .634 r
.31143 .66815 m .31204 .67015 L .31443 .66786 L F
.797 .85 .89 r
.31405 .66766 m .31027 .66916 L .31257 .66687 L F
.31443 .66786 m .31335 .6682 L .31405 .66766 L F
.31335 .6682 m .31027 .66916 L .31405 .66766 L F
.31027 .66916 m .30969 .66934 L .31018 .66892 L F
.31027 .66916 m .31018 .66892 L .31257 .66687 L F
.985 .896 .573 r
.31042 .67017 m .31054 .66992 L .31049 .66985 L F
.31054 .66992 m .3105 .66982 L .31049 .66985 L F
.31001 .67205 m .3105 .67071 L .31042 .67017 L F
.908 .596 .444 r
.30969 .66934 m .31182 .67008 L .31094 .66917 L F
.797 .85 .89 r
.31443 .66786 m .31204 .67015 L .31033 .66956 L F
.908 .596 .444 r
.30969 .66934 m .31094 .66917 L .30997 .66915 L F
.797 .85 .89 r
.31027 .66916 m .31033 .66956 L .30969 .66934 L F
.31443 .66786 m .31033 .66956 L .31027 .66916 L F
.932 .81 .702 r
.30789 .66679 m .30883 .66913 L .30989 .66915 L F
.845 .658 .65 r
.30729 .66545 m .31017 .6684 L .30996 .66561 L F
.896 .803 .749 r
.30969 .66934 m .31001 .67205 L .30789 .66679 L F
.30969 .66934 m .30789 .66679 L .3103 .66571 L F
0 0 0 r
.30863 .66662 m .30789 .66679 L .30582 .66814 L F
.3103 .66571 m .30789 .66679 L .30863 .66662 L F
.908 .596 .444 r
.30999 .6706 m .30999 .67076 L .30988 .67097 L F
.702 .392 0 r
.49166 .4413 m .49234 .44319 L .4928 .4447 L F
.772 .523 .559 r
.49234 .44319 m .49622 .44628 L .4928 .4447 L F
0 .148 .692 r
.28076 .64473 m .28249 .64814 L .28273 .6466 L F
.008 .336 .818 r
.28249 .64814 m .28509 .64978 L .28273 .6466 L F
.337 .501 .873 r
.28249 .64814 m .28631 .65145 L .28509 .64978 L F
.831 .744 .769 r
.31047 .60173 m .30785 .60618 L .30619 .60381 L F
.31047 .60173 m .30619 .60381 L .31041 .60513 L F
.76 .494 .531 r
.31041 .60513 m .31234 .60357 L .31047 .60173 L F
.641 .353 .467 r
.40673 .46596 m .40071 .46757 L .40023 .46674 L F
.845 .441 .277 r
.40247 .56465 m .40629 .56776 L .40631 .5655 L F
.676 .265 .259 r
.28994 .62514 m .28818 .6234 L .2875 .62493 L F
.837 .921 .89 r
.43714 .60034 m .44042 .59797 L .43887 .59691 L F
.607 .87 .992 r
.43887 .59691 m .44042 .59797 L .44248 .59708 L F
.802 .729 .783 r
.29211 .66433 m .29349 .66787 L .28959 .66761 L F
.805 .718 .769 r
.29349 .66787 m .29097 .67124 L .28959 .66761 L F
.766 .873 .926 r
.62552 .39198 m .62353 .39384 L .62208 .39236 L F
.651 .878 .982 r
.30949 .64773 m .30708 .64871 L .30553 .64759 L F
.866 .592 .062 r
.42235 .55118 m .42291 .55211 L .42195 .54834 L F
.991 .815 .434 r
.42235 .55118 m .42278 .55544 L .42291 .55211 L F
.866 .592 .062 r
.42235 .55118 m .42291 .55211 L .42195 .54834 L F
0 .074 .636 r
.33446 .57513 m .33497 .57626 L .33444 .57679 L F
.705 .788 .916 r
.33588 .57779 m .33398 .57725 L .33444 .57679 L F
0 0 .07 r
.33634 .57927 m .33553 .58086 L .33588 .57779 L F
.33634 .57927 m .33588 .57779 L .33444 .57679 L F
0 .074 .636 r
.33497 .57626 m .33634 .57927 L .33444 .57679 L F
.705 .788 .916 r
.33398 .57725 m .33379 .57719 L .33444 .57679 L F
.782 .618 .677 r
.30955 .606 m .31484 .60572 L .31234 .60357 L F
.898 .935 .83 r
.35013 .64445 m .34842 .64755 L .34833 .64734 L F
.815 .516 0 r
.34833 .64734 m .34842 .64755 L .34828 .6491 L F
0 0 0 r
.35005 .64534 m .34842 .64755 L .35013 .64445 L F
.912 .53 .279 r
.4074 .52398 m .4109 .52854 L .4111 .52571 L F
.934 .669 .512 r
.683 .33813 m .68611 .33703 L .68268 .33562 L F
.683 .33813 m .68588 .33981 L .68611 .33703 L F
.837 .6 .58 r
.6879 .34023 m .68611 .33703 L .68588 .33981 L F
.477 .276 .527 r
.35207 .49828 m .35379 .49631 L .35002 .49556 L F
.904 .658 .557 r
.37862 .53561 m .37624 .53485 L .37644 .53194 L F
.909 .641 .519 r
.37848 .53835 m .37624 .53485 L .37862 .53561 L F
.851 .59 .544 r
.38402 .54552 m .38055 .54499 L .38063 .5418 L F
.828 .649 .661 r
.38392 .54804 m .38055 .54499 L .38402 .54552 L F
.887 .773 .73 r
.38715 .56162 m .38845 .56534 L .38621 .56438 L F
.936 .761 .641 r
.38845 .56534 m .38564 .56728 L .38621 .56438 L F
.38845 .56534 m .38771 .56836 L .38564 .56728 L F
.714 .948 .955 r
.67424 .37577 m .67537 .37331 L .67372 .37537 L F
.67424 .37577 m .67776 .37375 L .67537 .37331 L F
.483 .454 .749 r
.50435 .42195 m .50217 .42239 L .5022 .41938 L F
.50276 .41873 m .5022 .41938 L .50222 .41763 L F
.50435 .42195 m .5022 .41938 L .50276 .41873 L F
.709 .969 .733 r
.50492 .41621 m .50488 .41718 L .50576 .41539 L F
.483 .454 .749 r
.50435 .42195 m .50222 .41763 L .50253 .41852 L F
.823 .93 .903 r
.50222 .41763 m .50488 .41718 L .50253 .41852 L F
.709 .969 .733 r
.50253 .41852 m .50333 .41806 L .50492 .41621 L F
.50333 .41806 m .50488 .41718 L .50492 .41621 L F
.708 .975 .758 r
.50576 .41539 m .50488 .41718 L .50682 .41538 L F
.65 .967 .897 r
.52472 .49299 m .52292 .49315 L .52023 .49475 L F
.837 .998 .825 r
.52472 .49299 m .5258 .49114 L .52533 .49064 L F
.82 .992 .867 r
.52533 .49064 m .52292 .49315 L .52472 .49299 L F
.972 .896 .688 r
.52787 .46935 m .52719 .47307 L .52553 .47186 L F
.562 .655 .898 r
.30619 .60381 m .30785 .60618 L .31041 .60513 L F
.187 .712 .861 r
.30785 .60618 m .30955 .606 L .31041 .60513 L F
.599 .031 0 r
.41437 .5913 m .41025 .58954 L .41179 .59185 L F
0 0 0 r
.41146 .59463 m .41437 .5913 L .41179 .59185 L F
.258 0 .038 r
.65697 .33005 m .65959 .32933 L .66055 .32733 L F
.327 0 .067 r
.66055 .32733 m .66322 .32793 L .66321 .32636 L F
.66055 .32733 m .65959 .32933 L .66322 .32793 L F
.93 .938 .782 r
.69014 .36424 m .69243 .3607 L .69021 .36082 L F
.905 .959 .816 r
.69021 .36082 m .69243 .3607 L .69155 .35943 L F
.571 .331 .513 r
.37075 .4691 m .37468 .47091 L .37408 .46672 L F
.219 .093 .487 r
.37408 .46672 m .37624 .46823 L .37611 .46546 L F
.37408 .46672 m .37468 .47091 L .37624 .46823 L F
.882 .96 .846 r
.68712 .36758 m .68854 .36559 L .68763 .36443 L F
.831 .922 .895 r
.68586 .36629 m .68712 .36758 L .68763 .36443 L F
.881 .794 .304 r
.66343 .36698 m .66287 .36676 L .6631 .36467 L F
.66343 .36698 m .66284 .36988 L .66287 .36676 L F
.324 .155 .491 r
.24818 .53918 m .25013 .53885 L .25023 .53502 L F
.355 .275 .626 r
.24818 .53918 m .2505 .54121 L .25013 .53885 L F
.275 .27 .673 r
.24892 .54179 m .2505 .54121 L .24818 .53918 L F
.706 .25 .166 r
.51137 .42217 m .50861 .41986 L .50853 .42269 L F
.851 .997 .815 r
.5529 .40315 m .5503 .40479 L .55083 .40373 L F
.592 .933 .744 r
.55622 .40074 m .5529 .40315 L .55429 .40156 L F
.596 .947 .811 r
.55429 .40156 m .5529 .40315 L .55083 .40373 L F
.888 .828 .782 r
.38988 .57194 m .3856 .57422 L .38767 .57063 L F
.38988 .57194 m .38765 .57529 L .3856 .57422 L F
.844 .642 .63 r
.36581 .49786 m .37 .49578 L .36533 .49594 L F
.36581 .49786 m .36986 .49912 L .37 .49578 L F
.223 .737 .708 r
.65013 .38373 m .64888 .38417 L .64881 .38248 L F
.65013 .38373 m .6519 .38329 L .64888 .38417 L F
.608 .658 .873 r
.32564 .62484 m .32646 .62056 L .32359 .6242 L F
.32564 .62484 m .32833 .62425 L .32646 .62056 L F
.768 .663 .747 r
.32002 .58231 m .32351 .58277 L .32283 .57978 L F
.665 .256 .258 r
.3182 .58459 m .32351 .58277 L .32002 .58231 L F
.3182 .58459 m .32268 .58506 L .32351 .58277 L F
.835 .862 .412 r
.32351 .58277 m .32477 .57833 L .32283 .57978 L F
.32351 .58277 m .32322 .58295 L .32477 .57833 L F
.289 0 .227 r
.32322 .58295 m .3252 .58293 L .3255 .57896 L F
.693 .934 .63 r
.32635 .58232 m .32489 .5834 L .32372 .58525 L F
0 0 0 r
.32694 .58291 m .32635 .58232 L .32955 .58286 L F
.289 0 .227 r
.3252 .58293 m .32694 .58291 L .32634 .58126 L F
.3252 .58293 m .32634 .58126 L .3255 .57896 L F
.693 .934 .63 r
.32489 .5834 m .32452 .58366 L .324 .58469 L F
.32489 .5834 m .324 .58469 L .32372 .58525 L F
0 0 0 r
.32694 .58291 m .32452 .58366 L .32635 .58232 L F
.833 .89 .882 r
.25884 .56207 m .25398 .56785 L .25599 .56672 L F
0 0 0 r
.23608 .61472 m .24022 .61187 L .23798 .61344 L F
.93 .967 .682 r
.23798 .61344 m .24022 .61187 L .23985 .60998 L F
.813 .91 .51 r
.59491 .37375 m .59457 .37379 L .59705 .36865 L F
.385 .837 .746 r
.45237 .44707 m .45271 .44653 L .45027 .44722 L F
.45237 .44707 m .45491 .44584 L .45271 .44653 L F
.607 .833 .986 r
.63027 .39853 m .63156 .39994 L .63418 .39878 L F
.63027 .39853 m .63156 .39994 L .63418 .39878 L F
.792 .933 .925 r
.44824 .59327 m .45021 .59396 L .45267 .5917 L F
.722 .624 .748 r
.33328 .53868 m .33163 .54174 L .33144 .53955 L F
.678 .977 .884 r
.44299 .44164 m .44118 .44322 L .43878 .44345 L F
.934 .893 .765 r
.56835 .43161 m .57194 .42914 L .57088 .42815 L F
.56835 .43161 m .56974 .43287 L .57194 .42914 L F
.97 .929 .679 r
.57199 .42575 m .57088 .42815 L .57194 .42914 L F
.984 .789 .563 r
.39279 .53048 m .39463 .53483 L .39479 .53239 L F
.833 .936 .895 r
.39279 .53048 m .39479 .53239 L .39694 .52977 L F
.902 .783 .719 r
.35055 .54415 m .35242 .54646 L .35266 .54532 L F
.038 0 0 r
.55622 .40074 m .55801 .4009 L .55837 .39924 L F
.55622 .40074 m .55429 .40156 L .55801 .4009 L F
.887 .735 .687 r
.35172 .55815 m .35318 .5618 L .35403 .55924 L F
.64 .586 .778 r
.60045 .39795 m .60165 .39243 L .59894 .39317 L F
.60045 .39795 m .60353 .3967 L .60165 .39243 L F
.553 .365 .58 r
.60017 .39931 m .60353 .3967 L .60045 .39795 L F
0 0 0 r
.32351 .60051 m .31969 .60411 L .32153 .60258 L F
.954 .782 .631 r
.32227 .5978 m .32351 .60051 L .32497 .60047 L F
0 0 0 r
.32497 .60047 m .32351 .60051 L .32153 .60258 L F
.749 .774 .873 r
.28606 .67271 m .29062 .67224 L .29097 .67124 L F
.28606 .67271 m .29097 .67124 L .28878 .67234 L F
.28606 .67271 m .28832 .67499 L .29062 .67224 L F
.597 .04 0 r
.29097 .67124 m .29145 .67239 L .28878 .67234 L F
.29097 .67124 m .29197 .67214 L .29145 .67239 L F
.679 .863 .969 r
.28869 .67763 m .28566 .67976 L .28672 .67341 L F
.456 .352 .647 r
.28672 .67341 m .28566 .67976 L .28376 .67725 L F
.538 .033 0 r
.28008 .67353 m .28376 .67725 L .28216 .67425 L F
.892 .953 .607 r
.28376 .67725 m .28606 .67271 L .28672 .67341 L F
.691 .682 .837 r
.28521 .67369 m .28376 .67725 L .28672 .67341 L F
.28515 .67371 m .28376 .67725 L .28521 .67369 L F
.28231 .67453 m .28376 .67725 L .28515 .6737 L F
.892 .767 .717 r
.28619 .67408 m .28566 .67976 L .2829 .6782 L F
.28661 .67405 m .28566 .67976 L .28619 .67408 L F
.887 .47 .065 r
.28687 .67592 m .28678 .67438 L .28636 .67639 L F
.28678 .67438 m .28631 .67411 L .28486 .67658 L F
.28636 .67639 m .28678 .67438 L .28486 .67658 L F
.892 .767 .717 r
.28672 .67341 m .2829 .6782 L .28486 .67658 L F
.235 0 0 r
.28652 .67499 m .28494 .674 L .2862 .6734 L F
.28494 .674 m .28469 .67385 L .28521 .67369 L F
.28494 .674 m .28521 .67369 L .2862 .6734 L F
.691 .682 .837 r
.28216 .67425 m .28606 .67271 L .28465 .67388 L F
.28216 .67425 m .28521 .67369 L .28606 .67271 L F
.28521 .67369 m .28672 .67341 L .28606 .67271 L F
.892 .767 .717 r
.28672 .67341 m .28661 .67405 L .28619 .67408 L F
.887 .47 .065 r
.28678 .67438 m .28672 .67341 L .28631 .67411 L F
.28689 .67632 m .28869 .67763 L .28672 .67341 L F
.235 0 0 r
.28652 .67499 m .2862 .6734 L .28844 .67274 L F
0 .023 .591 r
.28996 .67437 m .29072 .67567 L .28992 .67463 L F
.601 .163 .181 r
.29145 .67239 m .28992 .67463 L .28652 .67499 L F
.426 .636 .943 r
.29145 .67239 m .29098 .67261 L .28992 .67463 L F
.601 .163 .181 r
.29145 .67239 m .28909 .67363 L .28878 .67234 L F
.841 .938 .567 r
.29017 .67292 m .28992 .67463 L .29104 .67249 L F
.29117 .67161 m .29104 .67249 L .2923 .67011 L F
.29017 .67292 m .29104 .67249 L .29117 .67161 L F
.426 .636 .943 r
.29145 .67239 m .2923 .67011 L .29098 .67261 L F
.29145 .67239 m .29404 .67242 L .2923 .67011 L F
.961 .742 .562 r
.29025 .67018 m .29017 .67292 L .2923 .67011 L F
.864 .995 .762 r
.29211 .66433 m .28959 .66761 L .29007 .66506 L F
.672 .415 .524 r
.29007 .66506 m .29274 .66868 L .29283 .66573 L F
0 0 .498 r
.29235 .66771 m .29274 .66868 L .29007 .66506 L F
.667 .482 .626 r
.29266 .66782 m .29265 .66812 L .29253 .66795 L F
0 0 .498 r
.29264 .66804 m .29265 .66812 L .29235 .66771 L F
.29265 .66812 m .29274 .66868 L .29235 .66771 L F
.667 .482 .626 r
.29253 .66795 m .29265 .66838 L .29248 .668 L F
.772 .77 .262 r
.2923 .67011 m .29258 .6684 L .29025 .67018 L F
.667 .482 .626 r
.29265 .66812 m .29265 .66835 L .29253 .66795 L F
.29265 .66835 m .29264 .66835 L .29253 .66795 L F
.424 .635 .943 r
.2923 .67011 m .29404 .67242 L .29491 .67042 L F
.55 .271 .445 r
.2923 .67011 m .29538 .66826 L .29274 .66868 L F
.2923 .67011 m .29491 .67042 L .29538 .66826 L F
.189 0 0 r
.29117 .67015 m .29491 .67042 L .2923 .67011 L F
.29025 .67018 m .29185 .67026 L .29117 .67015 L F
.29185 .67026 m .29491 .67042 L .29117 .67015 L F
.468 .194 .415 r
.29274 .66868 m .29622 .66537 L .29283 .66573 L F
.29274 .66868 m .29538 .66826 L .29622 .66537 L F
.189 0 0 r
.29025 .67018 m .29491 .67042 L .2923 .67011 L F
.462 .594 .898 r
.29266 .66782 m .29491 .67042 L .2971 .67003 L F
.29266 .66782 m .2971 .67003 L .2954 .66867 L F
.36 .233 .569 r
.2954 .66867 m .29381 .67059 L .29266 .66782 L F
.29381 .67059 m .29259 .67206 L .29261 .67039 L F
.29381 .67059 m .29261 .67039 L .29266 .66782 L F
.667 .482 .626 r
.29248 .668 m .29259 .67206 L .29025 .67018 L F
.772 .77 .262 r
.2923 .67011 m .29274 .66868 L .29265 .66812 L F
.2923 .67011 m .29265 .66812 L .29258 .6684 L F
.667 .482 .626 r
.29265 .66838 m .29259 .67206 L .2925 .6687 L F
.29261 .66829 m .2925 .6687 L .29248 .668 L F
.29265 .66838 m .2925 .6687 L .29261 .66829 L F
.772 .77 .262 r
.29258 .6684 m .29265 .66812 L .29264 .66804 L F
.29258 .6684 m .29264 .66804 L .29025 .67018 L F
.667 .482 .626 r
.29265 .66835 m .29265 .66838 L .29264 .66835 L F
.695 .976 .786 r
.29397 .66215 m .29211 .66433 L .29007 .66506 L F
.718 .988 .866 r
.29436 .66229 m .29211 .66433 L .29397 .66215 L F
.695 .976 .786 r
.29397 .66215 m .29007 .66506 L .29283 .66573 L F
.798 .43 .361 r
.29068 .66443 m .29266 .66782 L .29236 .66766 L F
0 0 .498 r
.29181 .66662 m .29007 .66506 L .29068 .66443 L F
.29235 .66771 m .29007 .66506 L .29192 .66671 L F
.752 .94 .945 r
.29007 .66506 m .28959 .66761 L .28767 .66702 L F
.798 .43 .361 r
.29068 .66443 m .29236 .66766 L .28941 .66612 L F
0 0 .498 r
.29192 .66671 m .29181 .66662 L .29068 .66443 L F
.29264 .66804 m .29235 .66771 L .29192 .66671 L F
.43 .317 .623 r
.2954 .66867 m .29292 .67214 L .29259 .67206 L F
.119 .398 .85 r
.29259 .67206 m .29292 .67214 L .29126 .67093 L F
.29125 .67099 m .29126 .67093 L .29025 .67018 L F
.29259 .67206 m .29126 .67093 L .29125 .67099 L F
0 .023 .591 r
.29017 .67292 m .29057 .67489 L .28996 .67437 L F
.29057 .67489 m .29072 .67567 L .28996 .67437 L F
.601 .163 .181 r
.28909 .67363 m .28652 .67499 L .28827 .67293 L F
.28909 .67363 m .28827 .67293 L .28878 .67234 L F
.77 .772 .855 r
.28652 .67499 m .28805 .67483 L .28774 .67472 L F
.28652 .67499 m .28774 .67472 L .28564 .67403 L F
.28805 .67483 m .28992 .67463 L .28848 .67442 L F
.28805 .67483 m .28848 .67442 L .28564 .67403 L F
.887 .47 .065 r
.28689 .67632 m .28687 .67592 L .28636 .67639 L F
.329 0 0 r
.2827 .67453 m .28351 .67426 L .28652 .67499 L F
.28351 .67426 m .28465 .67388 L .28511 .67415 L F
.28351 .67426 m .28511 .67415 L .28652 .67499 L F
.235 0 0 r
.28515 .67413 m .28465 .67388 L .28469 .67385 L F
.28652 .67499 m .28511 .67415 L .28515 .67413 L F
.28511 .67415 m .28465 .67388 L .28515 .67413 L F
.2862 .6734 m .28469 .67385 L .28606 .67271 L F
.691 .682 .837 r
.28515 .6737 m .28515 .67371 L .28521 .67369 L F
.28216 .67425 m .28231 .67453 L .28515 .6737 L F
.235 0 0 r
.28844 .67274 m .28606 .67271 L .28878 .67234 L F
.2862 .6734 m .28606 .67271 L .28844 .67274 L F
.597 .04 0 r
.29197 .67214 m .29335 .67339 L .29145 .67239 L F
.637 .223 0 r
.56849 .36991 m .5691 .37085 L .56614 .36953 L F
.56849 .36991 m .57041 .37304 L .5691 .37085 L F
.721 .624 .75 r
.34179 .6212 m .34604 .62177 L .34433 .61797 L F
0 0 0 r
.66425 .38156 m .66535 .38056 L .66779 .37927 L F
.644 .613 .804 r
.40859 .56228 m .41148 .56169 L .41078 .5583 L F
.482 .306 .565 r
.3238 .53387 m .3213 .53137 L .32554 .53036 L F
.593 .197 .262 r
.32922 .53243 m .32554 .53036 L .32731 .53231 L F
.703 .606 .746 r
.52477 .38309 m .52013 .37985 L .52257 .37956 L F
.353 .612 .947 r
.52482 .38079 m .52477 .38309 L .52257 .37956 L F
.352 .186 .511 r
.52687 .37963 m .52671 .38291 L .52477 .38309 L F
.353 .612 .947 r
.52482 .38079 m .52671 .38291 L .52477 .38309 L F
0 .014 .522 r
.52653 .38442 m .52477 .38309 L .52671 .38291 L F
.52653 .38442 m .52516 .38808 L .52479 .38328 L F
0 0 .315 r
.52653 .38442 m .52603 .38966 L .52516 .38808 L F
.119 0 0 r
.52961 .38701 m .52727 .3884 L .52702 .38836 L F
0 0 .315 r
.52616 .38822 m .52702 .38836 L .52603 .38966 L F
.549 .9 .68 r
.52702 .38836 m .52403 .39078 L .52603 .38966 L F
.119 0 0 r
.52727 .3884 m .5256 .38939 L .52702 .38836 L F
0 0 .315 r
.5265 .38471 m .52702 .38836 L .52616 .38822 L F
.52653 .38442 m .52657 .3848 L .5265 .38471 L F
.52657 .3848 m .52702 .38836 L .5265 .38471 L F
.597 .392 .573 r
.52961 .38701 m .52653 .38442 L .52961 .38394 L F
.52961 .38701 m .52702 .38836 L .52653 .38442 L F
.166 0 0 r
.52702 .38528 m .52806 .38549 L .52961 .38394 L F
.52538 .38613 m .52736 .38566 L .52702 .38528 L F
.52736 .38566 m .52806 .38549 L .52702 .38528 L F
.52538 .38613 m .52748 .38504 L .52653 .38442 L F
.52748 .38504 m .52961 .38394 L .52653 .38442 L F
0 .014 .522 r
.52653 .38442 m .52479 .38328 L .52477 .38309 L F
.011 0 .016 r
.32351 .58277 m .32268 .58506 L .32452 .58366 L F
.32351 .58277 m .32452 .58366 L .32322 .58295 L F
.491 .835 .557 r
.47701 .41939 m .4736 .42232 L .47514 .42056 L F
.579 .906 .662 r
.47701 .41939 m .47844 .41776 L .48018 .41669 L F
.47701 .41939 m .47514 .42056 L .47844 .41776 L F
.131 .08 .527 r
.58377 .35893 m .58424 .36203 L .58217 .36345 L F
0 0 .198 r
.58355 .36397 m .58217 .36345 L .58424 .36203 L F
.58355 .36397 m .58166 .36632 L .58217 .36345 L F
.319 .185 .537 r
.24506 .55819 m .24688 .55454 L .24524 .55536 L F
.802 .772 .825 r
.31324 .61524 m .30964 .61556 L .31143 .61388 L F
.652 .681 .864 r
.31436 .61086 m .31324 .61524 L .31143 .61388 L F
.31436 .61086 m .31585 .61431 L .31324 .61524 L F
.915 .832 .749 r
.32814 .55062 m .32978 .55275 L .33162 .55046 L F
.77 .898 .496 r
.37075 .4691 m .36895 .47231 L .36935 .47073 L F
.792 .705 .769 r
.36935 .47073 m .37468 .47091 L .37075 .4691 L F
.012 0 .02 r
.27543 .54381 m .27431 .54328 L .27553 .54146 L F
.27543 .54381 m .27327 .54495 L .27431 .54328 L F
.539 .213 .364 r
.3145 .6849 m .31641 .68713 L .31381 .68664 L F
.3145 .6849 m .3174 .6843 L .31641 .68713 L F
.948 .618 .368 r
.23855 .60503 m .23682 .60687 L .23896 .60756 L F
.563 .845 .997 r
.26173 .52488 m .25916 .52574 L .25977 .52384 L F
.394 0 .163 r
.25916 .52574 m .26181 .5256 L .25977 .52384 L F
.25916 .52574 m .258 .52782 L .26181 .5256 L F
.667 .623 .796 r
.66969 .31988 m .67113 .31619 L .66863 .31698 L F
.803 .968 .909 r
.67281 .30908 m .67086 .30939 L .67231 .30634 L F
.259 .452 .86 r
.67231 .30634 m .67482 .30975 L .67281 .30908 L F
.522 .901 .956 r
.61357 .34389 m .61216 .34422 L .61593 .34342 L F
.162 0 0 r
.61216 .34422 m .61466 .34436 L .61593 .34342 L F
.319 0 0 r
.61466 .34436 m .61864 .34367 L .61593 .34342 L F
.535 .909 .74 r
.38553 .50309 m .38355 .50418 L .38741 .50167 L F
0 0 0 r
.51502 .42575 m .5192 .42286 L .51781 .42433 L F
.5192 .42286 m .52226 .42019 L .52111 .42156 L F
.51781 .42433 m .5192 .42286 L .52111 .42156 L F
.891 .569 .433 r
.44686 .57023 m .44916 .56886 L .44689 .56769 L F
.44686 .57023 m .44952 .57097 L .44916 .56886 L F
.821 .502 .451 r
.68617 .34211 m .6879 .34023 L .68588 .33981 L F
.68617 .34211 m .68816 .34277 L .6879 .34023 L F
0 0 .255 r
.41 .56522 m .41198 .5638 L .41148 .56169 L F
.059 .048 .528 r
.41 .56522 m .41158 .56766 L .41198 .5638 L F
.848 .974 .872 r
.46408 .55435 m .46826 .55208 L .46665 .55091 L F
.626 .948 .941 r
.47525 .43445 m .48032 .43316 L .47887 .43193 L F
.776 .913 .933 r
.47887 .43193 m .48032 .43316 L .4826 .43121 L F
.784 .832 .889 r
.31649 .64537 m .31155 .64665 L .31465 .64401 L F
.712 .856 .951 r
.31465 .64401 m .31889 .6441 L .31649 .64537 L F
0 .108 .66 r
.29506 .6745 m .29738 .67687 L .29576 .67389 L F
0 .547 .722 r
.59989 .37324 m .60158 .37339 L .59702 .37304 L F
.284 0 0 r
.59989 .37324 m .60422 .37249 L .60158 .37339 L F
.393 .175 .461 r
.60422 .37249 m .60136 .37592 L .60158 .37339 L F
.217 0 0 r
.61864 .34367 m .62109 .34419 L .62261 .34327 L F
0 0 0 r
.62261 .34327 m .62405 .34344 L .62539 .34258 L F
.62261 .34327 m .62109 .34419 L .62405 .34344 L F
.295 .743 .96 r
.51697 .41053 m .51454 .40969 L .51211 .40967 L F
.065 0 0 r
.51891 .40875 m .51454 .40969 L .51697 .41053 L F
.884 .9 .484 r
.59539 .35457 m .59527 .35709 L .59666 .35292 L F
0 0 0 r
.59537 .35692 m .59527 .35709 L .59539 .35457 L F
.59537 .35692 m .59442 .35931 L .59527 .35709 L F
.548 .817 .458 r
.64305 .38364 m .64274 .38402 L .64193 .38517 L F
.64305 .38364 m .64433 .3821 L .64274 .38402 L F
.778 .777 .852 r
.50395 .49546 m .50004 .49517 L .50296 .49238 L F
.807 .706 .754 r
.50395 .49546 m .5015 .49918 L .50004 .49517 L F
.743 .758 .865 r
.50722 .49302 m .50395 .49546 L .50296 .49238 L F
.446 .239 .503 r
.56144 .41241 m .55854 .41322 L .56121 .40973 L F
.624 .956 .8 r
.54488 .47368 m .54645 .47196 L .54296 .47448 L F
.54488 .47368 m .54701 .47217 L .54645 .47196 L F
.72 .897 .959 r
.59745 .36685 m .59979 .3678 L .59722 .36699 L F
.625 .063 0 r
.59979 .3678 m .59745 .36685 L .59684 .36632 L F
.623 .569 .772 r
.60129 .36441 m .59745 .36685 L .59869 .36438 L F
.59745 .36685 m .59722 .36699 L .59734 .36678 L F
.59745 .36685 m .59734 .36678 L .59869 .36438 L F
.625 .063 0 r
.59745 .36685 m .5974 .36683 L .59734 .36678 L F
.59745 .36685 m .59734 .36678 L .59684 .36632 L F
.347 .236 .582 r
.59734 .36678 m .59722 .36699 L .59684 .36632 L F
.625 .063 0 r
.5974 .36683 m .59737 .36681 L .59684 .36632 L F
.347 .236 .582 r
.59869 .36438 m .59734 .36678 L .59684 .36632 L F
.72 .897 .959 r
.60129 .36441 m .59979 .3678 L .59745 .36685 L F
.625 .063 0 r
.59979 .3678 m .59837 .36777 L .59737 .36681 L F
.819 .995 .761 r
.60129 .36441 m .59837 .36777 L .59979 .3678 L F
.708 .65 .79 r
.33662 .53531 m .33839 .53894 L .33328 .53868 L F
.546 .553 .813 r
.33724 .54171 m .33328 .53868 L .33839 .53894 L F
.786 .747 .818 r
.45343 .59314 m .45553 .5886 L .45267 .5917 L F
.327 .288 .661 r
.50679 .42116 m .50435 .42195 L .50678 .4211 L F
.388 .798 .98 r
.50435 .42195 m .50558 .42255 L .50291 .42242 L F
.633 .113 0 r
.50693 .42389 m .50853 .42269 L .50435 .42195 L F
.327 .288 .661 r
.50693 .42389 m .50435 .42195 L .50679 .42116 L F
.388 .798 .98 r
.50435 .42195 m .50291 .42242 L .50217 .42239 L F
0 .267 .731 r
.59602 .38017 m .60016 .38318 L .59723 .38283 L F
.59602 .38017 m .59914 .38205 L .60016 .38318 L F
0 0 0 r
.59914 .38205 m .59723 .38283 L .60016 .38318 L F
.59914 .38205 m .59569 .3849 L .59723 .38283 L F
.673 .971 .911 r
.44061 .45063 m .44303 .45056 L .44514 .44902 L F
.893 .976 .678 r
.39251 .50036 m .3907 .50549 L .3912 .50228 L F
.271 .757 .919 r
.63264 .37816 m .63717 .37857 L .63267 .37632 L F
.63264 .37816 m .63541 .37793 L .63717 .37857 L F
.299 .775 .927 r
.63717 .37857 m .63541 .37793 L .63994 .378 L F
.169 0 0 r
.5851 .35171 m .5887 .34924 L .58629 .35051 L F
.717 .929 .961 r
.47049 .43817 m .47229 .43526 L .46846 .43737 L F
.47049 .43817 m .47375 .43623 L .47229 .43526 L F
.902 .783 .719 r
.35055 .54415 m .34865 .54763 L .35242 .54646 L F
.901 .767 .705 r
.34865 .54763 m .3501 .55148 L .35242 .54646 L F
.405 .229 .527 r
.25023 .53502 m .25202 .53427 L .25296 .53149 L F
.388 .203 .504 r
.25013 .53885 m .25202 .53427 L .25023 .53502 L F
.752 .993 .813 r
.50945 .50535 m .50563 .50785 L .5064 .5081 L F
.774 .997 .829 r
.4816 .41485 m .48018 .41669 L .48111 .41443 L F
.778 .971 .682 r
.48018 .41669 m .47844 .41776 L .48111 .41443 L F
.467 .832 .577 r
.47102 .53275 m .46786 .53528 L .46924 .53409 L F
.468 .882 .76 r
.46924 .53409 m .46786 .53528 L .46679 .53548 L F
.898 .706 .635 r
.34247 .65649 m .34376 .6611 L .34296 .65898 L F
.576 .59 .83 r
.34495 .65662 m .34627 .6605 L .34376 .6611 L F
.331 .436 .818 r
.34825 .6631 m .34376 .6611 L .34627 .6605 L F
.376 .829 .929 r
.30018 .67063 m .29776 .67123 L .29783 .67058 L F
.30018 .67063 m .29776 .67123 L .29783 .67058 L F
0 0 0 r
.24531 .59757 m .24434 .59868 L .24675 .59504 L F
.775 .322 0 r
.24375 .59912 m .24434 .59868 L .24531 .59757 L F
.276 .758 .924 r
.2891 .68485 m .29364 .68499 L .29188 .68636 L F
.152 0 0 r
.29364 .68499 m .29444 .68542 L .29188 .68636 L F
.29364 .68499 m .29666 .6852 L .29444 .68542 L F
.856 .673 .654 r
.46298 .58066 m .46538 .58231 L .46313 .57814 L F
.816 .703 .74 r
.46401 .58525 m .46538 .58231 L .46298 .58066 L F
.963 .937 .631 r
.3376 .54761 m .33527 .55047 L .33542 .54766 L F
.412 .658 .96 r
.28509 .64978 m .28631 .65145 L .2874 .64968 L F
.135 .287 .755 r
.28631 .65145 m .28892 .65366 L .2874 .64968 L F
.737 .979 .746 r
.50576 .41539 m .50696 .41523 L .50959 .41245 L F
.50576 .41539 m .50959 .41245 L .50818 .41403 L F
.485 .894 .779 r
.50493 .4155 m .50576 .41539 L .50818 .41403 L F
.50447 .41571 m .50576 .41539 L .50493 .4155 L F
.737 .979 .746 r
.50576 .41539 m .50682 .41538 L .50696 .41523 L F
.412 0 0 r
.55032 .37904 m .55417 .37917 L .55518 .37813 L F
.419 0 0 r
.55518 .37813 m .55417 .37917 L .55653 .37845 L F
.411 .356 .686 r
.55518 .37813 m .55653 .37845 L .55661 .37531 L F
.835 .864 .867 r
.46884 .54707 m .47353 .54534 L .47215 .54442 L F
.853 .951 .878 r
.47554 .54103 m .47353 .54534 L .47641 .54223 L F
.47554 .54103 m .47215 .54442 L .47353 .54534 L F
.027 .454 .874 r
.63363 .34036 m .6321 .34098 L .6309 .34139 L F
0 0 0 r
.6321 .34098 m .6345 .34091 L .63523 .34053 L F
.027 .454 .874 r
.63363 .34036 m .6345 .34091 L .6321 .34098 L F
.934 .731 .606 r
.34751 .53039 m .34647 .53434 L .34974 .53463 L F
.926 .736 .626 r
.34575 .53693 m .34974 .53463 L .34647 .53434 L F
.34575 .53693 m .34802 .53804 L .34974 .53463 L F
.526 .845 .546 r
.44606 .55818 m .4468 .55734 L .44865 .55567 L F
0 0 0 r
.44489 .56033 m .44606 .55818 L .44824 .56239 L F
.44817 .56242 m .44824 .56239 L .4483 .5625 L F
.44489 .56033 m .44824 .56239 L .44817 .56242 L F
.44489 .56033 m .4483 .5625 L .44824 .56249 L F
.775 .69 .77 r
.44489 .56033 m .44824 .56249 L .44739 .56304 L F
.815 .944 .909 r
.44861 .56254 m .44806 .56246 L .44739 .56304 L F
.775 .69 .77 r
.44824 .56249 m .44832 .56254 L .44739 .56304 L F
.815 .944 .909 r
.44851 .56231 m .45073 .56013 L .44806 .56246 L F
.45202 .56115 m .45123 .56053 L .44851 .56231 L F
.45123 .56053 m .45073 .56013 L .44851 .56231 L F
.66 .958 .747 r
.44766 .56263 m .45073 .56013 L .44851 .56129 L F
.44739 .56304 m .44806 .56246 L .44766 .56263 L F
.44806 .56246 m .45073 .56013 L .44766 .56263 L F
.815 .944 .909 r
.45202 .56115 m .44806 .56246 L .44861 .56254 L F
0 0 0 r
.44824 .56249 m .4483 .5625 L .44832 .56254 L F
.44489 .56033 m .4468 .55734 L .44606 .55818 L F
0 .272 .739 r
.59743 .38042 m .59602 .38017 L .59475 .37772 L F
.59743 .38042 m .59914 .38205 L .59602 .38017 L F
.85 .71 .708 r
.35821 .57758 m .35977 .58124 L .36013 .57848 L F
.68 .858 .967 r
.35014 .6433 m .34743 .64548 L .34574 .6418 L F
.35014 .6433 m .35013 .64445 L .34743 .64548 L F
.898 .935 .83 r
.35013 .64445 m .34833 .64734 L .34743 .64548 L F
.685 .652 .812 r
.30781 .62447 m .31196 .62631 L .30995 .62172 L F
.61 .604 .82 r
.31196 .62631 m .31288 .62094 L .30995 .62172 L F
.31196 .62631 m .31488 .62487 L .31288 .62094 L F
0 0 0 r
.27756 .53712 m .27633 .53898 L .27744 .53717 L F
.27675 .53987 m .27633 .53898 L .27756 .53712 L F
.27675 .53987 m .27553 .54146 L .27633 .53898 L F
.856 .959 .873 r
.68763 .36443 m .69014 .36424 L .69021 .36082 L F
.68763 .36443 m .68854 .36559 L .69014 .36424 L F
.628 .681 .881 r
.32192 .62418 m .32233 .61966 L .31973 .62077 L F
.32192 .62418 m .32359 .6242 L .32233 .61966 L F
.89 .844 .793 r
.56365 .44949 m .56596 .4463 L .56418 .44488 L F
.815 .516 0 r
.34833 .64734 m .34828 .6491 L .34712 .65132 L F
.293 0 0 r
.64095 .39755 m .64 .39844 L .63703 .39834 L F
.101 0 0 r
.64095 .39755 m .64376 .39788 L .64383 .39776 L F
.64376 .39788 m .6454 .39807 L .64383 .39776 L F
.265 .673 .968 r
.64383 .39776 m .6458 .39691 L .64394 .39758 L F
.214 0 0 r
.64383 .39776 m .64 .39844 L .64095 .39755 L F
.265 .673 .968 r
.64383 .39776 m .64394 .39758 L .64297 .39793 L F
.28 .373 .78 r
.32003 .54791 m .32004 .5442 L .31789 .54508 L F
.32003 .54791 m .32155 .54795 L .32004 .5442 L F
.843 .889 .873 r
.34586 .57247 m .34326 .57493 L .34153 .57396 L F
.982 .704 .33 r
.34308 .57862 m .34153 .57396 L .34326 .57493 L F
.716 .709 .842 r
.54333 .39274 m .54735 .39366 L .54721 .38856 L F
.823 .784 .816 r
.54812 .39151 m .55324 .38959 L .55134 .38788 L F
.949 .629 .201 r
.54949 .39035 m .54812 .39151 L .55028 .38959 L F
.945 .607 .35 r
.54999 .39315 m .54812 .39151 L .54735 .39366 L F
.516 .718 .964 r
.54735 .39366 m .54999 .39315 L .54812 .39151 L F
.945 .607 .35 r
.54999 .39315 m .54847 .39406 L .54812 .39151 L F
.823 .784 .816 r
.54812 .39151 m .54999 .39315 L .55324 .38959 L F
.945 .607 .35 r
.54812 .39151 m .54847 .39406 L .54999 .39315 L F
0 .051 .582 r
.54731 .3922 m .54735 .39366 L .54812 .39151 L F
.949 .629 .201 r
.54724 .39252 m .54847 .39406 L .54812 .39151 L F
.54724 .39252 m .54847 .39406 L .54812 .39151 L F
.54724 .39252 m .54812 .39151 L .54949 .39035 L F
0 .051 .582 r
.54721 .38856 m .54731 .3922 L .54812 .39151 L F
.738 .431 .461 r
.32004 .5442 m .32612 .54513 L .32476 .54222 L F
.473 .177 .381 r
.28454 .53186 m .2839 .53494 L .281 .53563 L F
.302 .418 .814 r
.2832 .52888 m .28607 .53061 L .28454 .53186 L F
.286 .017 .318 r
.28599 .53412 m .28454 .53186 L .28607 .53061 L F
.28599 .53412 m .2839 .53494 L .28454 .53186 L F
.865 .75 .734 r
.35282 .56748 m .35724 .56522 L .35304 .56459 L F
.35282 .56748 m .35526 .56853 L .35724 .56522 L F
.787 .974 .912 r
.64193 .38517 m .63838 .38678 L .64138 .38574 L F
.588 .841 .48 r
.64193 .38517 m .64138 .38574 L .64305 .38364 L F
.58 .689 .916 r
.59894 .39317 m .60095 .39003 L .59791 .39255 L F
.59894 .39317 m .60165 .39243 L .60095 .39003 L F
.59894 .39317 m .60095 .39003 L .59791 .39255 L F
.59894 .39317 m .60165 .39243 L .60095 .39003 L F
0 0 0 r
.43375 .60141 m .43714 .60034 L .43597 .60015 L F
.837 .921 .89 r
.43714 .60034 m .43887 .59691 L .43597 .60015 L F
.822 .727 .76 r
.45604 .56179 m .45202 .56115 L .45339 .56229 L F
.45604 .56179 m .45474 .55743 L .45202 .56115 L F
.714 .668 .803 r
.45604 .56179 m .45884 .5584 L .45474 .55743 L F
.6 .62 .843 r
.31809 .57517 m .32089 .57499 L .31897 .5707 L F
.553 .259 .422 r
.32089 .57499 m .32042 .57733 L .31809 .57517 L F
.32089 .57499 m .32042 .57733 L .31809 .57517 L F
.63 .099 0 r
.52311 .40096 m .52653 .40173 L .52451 .39996 L F
.76 .99 .774 r
.58511 .43355 m .58339 .43519 L .58314 .43268 L F
.099 0 0 r
.42616 .45663 m .42223 .45862 L .42442 .45749 L F
.627 .806 .969 r
.62355 .39938 m .62524 .40125 L .62795 .40014 L F
.878 .637 .57 r
.58825 .35673 m .58532 .35862 L .5868 .35541 L F
.58825 .35673 m .58844 .35967 L .58532 .35862 L F
.974 .76 .552 r
.30025 .66613 m .30341 .66449 L .30171 .66418 L F
.30025 .66613 m .30283 .66763 L .30341 .66449 L F
.639 .949 .948 r
.30171 .66418 m .30341 .66449 L .30411 .66281 L F
.003 .23 .74 r
.30411 .66281 m .30341 .66449 L .30533 .66533 L F
.237 .05 .412 r
.30341 .66449 m .30283 .66763 L .30533 .66533 L F
0 0 0 r
.50991 .42851 m .51281 .42665 L .51257 .42847 L F
.51281 .42665 m .51502 .42575 L .51601 .42562 L F
.393 .112 .363 r
.51281 .42665 m .51547 .42786 L .51257 .42847 L F
.51281 .42665 m .51601 .42562 L .51547 .42786 L F
.592 .452 .659 r
.53869 .44926 m .54232 .44906 L .54125 .44655 L F
0 0 0 r
.54125 .44655 m .53869 .44926 L .541 .44759 L F
.363 .366 .729 r
.54175 .45125 m .53869 .44926 L .54232 .44906 L F
.387 .363 .71 r
.53869 .44926 m .54175 .45125 L .541 .44759 L F
.402 .856 .87 r
.31229 .54862 m .31097 .54859 L .31115 .54839 L F
.683 .296 0 r
.24552 .59277 m .24675 .59504 L .24859 .5911 L F
.24552 .59277 m .2457 .59328 L .24675 .59504 L F
.664 .817 .381 r
.24631 .59556 m .24675 .59504 L .2457 .59328 L F
.24631 .59556 m .24531 .59757 L .24675 .59504 L F
.932 .848 .737 r
.55646 .42192 m .55938 .42207 L .55728 .42566 L F
.816 .703 .74 r
.46401 .58525 m .46298 .58066 L .46041 .58427 L F
.248 0 .018 r
.32325 .68065 m .32652 .67853 L .32557 .68008 L F
.143 0 0 r
.32652 .67853 m .3274 .67934 L .32557 .68008 L F
.32652 .67853 m .32995 .67732 L .3274 .67934 L F
.94 .752 .621 r
.38765 .57529 m .38714 .57808 L .3856 .57422 L F
0 0 0 r
.41582 .45372 m .41224 .45548 L .41451 .45471 L F
.41451 .45471 m .41819 .45267 L .41582 .45372 L F
.757 .717 .815 r
.33923 .6221 m .34179 .6212 L .34008 .61752 L F
.787 .73 .799 r
.34008 .61752 m .34179 .6212 L .34433 .61797 L F
.431 .439 .767 r
.24647 .54959 m .2474 .5521 L .24939 .55109 L F
.187 0 .303 r
.2474 .5521 m .24688 .55454 L .24939 .55109 L F
.841 .721 .732 r
.5015 .49918 m .49781 .49892 L .50004 .49517 L F
.698 .512 .633 r
.46313 .57814 m .46569 .57481 L .4631 .57525 L F
.886 .677 .614 r
.33628 .58753 m .33205 .58967 L .33329 .58721 L F
.33628 .58753 m .33466 .59113 L .33205 .58967 L F
.808 .475 .426 r
.34167 .5684 m .34336 .56876 L .34334 .5708 L F
.785 .949 .927 r
.33328 .53868 m .33012 .53929 L .33236 .53736 L F
.33328 .53868 m .33144 .53955 L .33012 .53929 L F
.983 .866 .496 r
.33328 .53868 m .33371 .53368 L .33662 .53531 L F
.33328 .53868 m .33236 .53736 L .33371 .53368 L F
0 0 0 r
.39166 .4701 m .39205 .47032 L .39012 .47081 L F
.39166 .4701 m .39412 .46911 L .39205 .47032 L F
.754 .995 .841 r
.30198 .65854 m .29891 .66118 L .29913 .65947 L F
.805 .975 .679 r
.29913 .65947 m .29891 .66118 L .29708 .6624 L F
.646 .124 0 r
.326 .51957 m .32625 .52037 L .32546 .5179 L F
.326 .51957 m .32796 .52163 L .32625 .52037 L F
.362 .133 .426 r
.31904 .53213 m .31865 .53473 L .3213 .53137 L F
.932 .689 .549 r
.6673 .34623 m .66936 .35025 L .66712 .34892 L F
.936 .871 .749 r
.66936 .35025 m .66647 .35119 L .66712 .34892 L F
.66936 .35025 m .66802 .35253 L .66647 .35119 L F
.081 0 .322 r
.67644 .31239 m .67721 .31536 L .67481 .31634 L F
.244 0 .314 r
.6796 .31381 m .67644 .31239 L .6772 .31174 L F
.6796 .31381 m .67721 .31536 L .67644 .31239 L F
.322 0 .053 r
.64316 .34374 m .64592 .34434 L .64266 .34484 L F
.314 0 0 r
.64607 .34344 m .64592 .34434 L .64316 .34374 L F
.957 .843 .689 r
.56699 .43414 m .56924 .43556 L .56974 .43287 L F
.971 .858 .671 r
.56592 .43773 m .56924 .43556 L .56699 .43414 L F
.56592 .43773 m .56746 .43908 L .56924 .43556 L F
.379 .277 .612 r
.24892 .54179 m .25111 .54428 L .2505 .54121 L F
.24892 .54179 m .24928 .54517 L .25111 .54428 L F
.831 .534 .487 r
.67665 .32352 m .67676 .32596 L .68051 .32677 L F
.893 .667 .589 r
.67701 .32837 m .68051 .32677 L .67676 .32596 L F
.67701 .32837 m .68049 .32968 L .68051 .32677 L F
.813 .709 .749 r
.60844 .39231 m .60983 .3963 L .61195 .39296 L F
0 0 .161 r
.63994 .378 m .63807 .38214 L .63708 .3825 L F
.7 .687 .834 r
.63944 .38203 m .63708 .3825 L .63807 .38214 L F
.63944 .38203 m .63634 .38397 L .63708 .3825 L F
.695 .959 .706 r
.32452 .58366 m .32148 .58661 L .32372 .58525 L F
.457 .803 .998 r
.29284 .60993 m .29439 .61118 L .29148 .61162 L F
.562 .835 .487 r
.29284 .60993 m .29148 .61162 L .28966 .61364 L F
.175 0 0 r
.29148 .61162 m .29202 .61275 L .28966 .61364 L F
.29148 .61162 m .29439 .61118 L .29202 .61275 L F
.934 .653 .483 r
.38063 .5418 m .37847 .54104 L .37848 .53835 L F
.945 .679 .502 r
.38063 .5418 m .37846 .5438 L .37847 .54104 L F
.38063 .5418 m .38055 .54499 L .37846 .5438 L F
.282 0 .138 r
.49971 .44645 m .50353 .44485 L .50226 .44528 L F
.098 .093 .562 r
.50187 .44731 m .49971 .44645 L .50226 .44528 L F
.50187 .44731 m .49992 .44964 L .49971 .44645 L F
.871 .625 .565 r
.38745 .55864 m .38715 .56162 L .38504 .55781 L F
.389 .05 .265 r
.27402 .52153 m .27664 .52085 L .27768 .51768 L F
.294 .025 .324 r
.27768 .51768 m .2794 .51976 L .28031 .51504 L F
.347 0 .214 r
.27664 .52085 m .2794 .51976 L .27768 .51768 L F
.586 .122 .119 r
.30742 .57514 m .30987 .57715 L .31 .57416 L F
.30742 .57514 m .30834 .57614 L .30987 .57715 L F
.436 .253 .534 r
.30834 .57614 m .30987 .57715 L .30701 .57772 L F
.586 .122 .119 r
.30834 .57614 m .30939 .5773 L .30987 .57715 L F
.436 .253 .534 r
.31 .57416 m .30987 .57715 L .30834 .57614 L F
.31 .57416 m .30834 .57614 L .30742 .57514 L F
.30834 .57614 m .30701 .57772 L .30742 .57514 L F
0 0 .308 r
.30795 .57831 m .30701 .57772 L .30987 .57715 L F
.586 .122 .119 r
.30742 .57514 m .30767 .57782 L .30939 .5773 L F
0 0 .121 r
.30701 .57772 m .30767 .57782 L .30742 .57514 L F
.811 .709 .753 r
.35071 .60422 m .3547 .60494 L .35524 .60197 L F
.863 .675 .646 r
.35076 .60655 m .3547 .60494 L .35071 .60422 L F
.35076 .60655 m .35284 .60842 L .3547 .60494 L F
.804 .791 .841 r
.33064 .6211 m .33496 .62136 L .33307 .61993 L F
.692 .686 .84 r
.33496 .62136 m .33597 .61714 L .33307 .61993 L F
.33496 .62136 m .33794 .62032 L .33597 .61714 L F
.68 .625 .787 r
.33496 .62136 m .33923 .6221 L .33794 .62032 L F
.843 .889 .873 r
.34586 .57247 m .34153 .57396 L .34334 .5708 L F
.679 .502 .639 r
.52088 .41646 m .52376 .41227 L .5205 .41308 L F
.52088 .41646 m .52492 .41631 L .52376 .41227 L F
.782 .71 .784 r
.52492 .41631 m .52587 .41173 L .52376 .41227 L F
0 0 0 r
.53157 .43578 m .53498 .43254 L .53535 .43538 L F
.573 .58 .822 r
.53675 .42862 m .53811 .43221 L .53498 .43254 L F
.377 .141 .423 r
.53811 .43221 m .53535 .43538 L .53498 .43254 L F
.993 .745 .4 r
.36895 .47231 m .36767 .47165 L .36935 .47073 L F
.36895 .47231 m .3689 .47503 L .36767 .47165 L F
.815 .853 .877 r
.30072 .6767 m .29944 .67832 L .29738 .67687 L F
0 0 0 r
.5198 .38129 m .52013 .37985 L .51979 .38283 L F
.5198 .38129 m .52257 .37956 L .52013 .37985 L F
.829 .999 .791 r
.31041 .60513 m .31234 .60357 L .3108 .60334 L F
.782 .618 .677 r
.30955 .606 m .31234 .60357 L .31041 .60513 L F
.493 .745 .984 r
.29671 .64656 m .29559 .64873 L .29437 .64673 L F
.29671 .64656 m .29857 .64822 L .29559 .64873 L F
.613 .28 .383 r
.37897 .4652 m .38315 .46552 L .38275 .46272 L F
.507 .207 .393 r
.38315 .46552 m .38536 .46448 L .38275 .46272 L F
.446 .312 .605 r
.41795 .59529 m .421 .59664 L .4221 .59458 L F
0 0 .446 r
.4221 .59458 m .42308 .5942 L .4227 .59133 L F
0 0 0 r
.4221 .59458 m .421 .59664 L .42308 .5942 L F
.813 .381 0 r
.59174 .40394 m .59206 .40307 L .59162 .40112 L F
.59174 .40394 m .59308 .40543 L .59206 .40307 L F
0 0 0 r
.63496 .34671 m .63353 .34648 L .6363 .34598 L F
.63496 .34671 m .63231 .34792 L .63353 .34648 L F
.534 .924 .873 r
.45311 .43612 m .44855 .4376 L .45179 .43586 L F
.539 .843 .526 r
.45444 .43465 m .45596 .4332 L .45311 .43612 L F
.544 .92 .934 r
.45444 .43465 m .45311 .43612 L .45179 .43586 L F
.752 .993 .813 r
.50945 .50535 m .50874 .50506 L .50563 .50785 L F
.79 .989 .888 r
.51276 .50262 m .51014 .50301 L .50945 .50535 L F
.827 .995 .756 r
.51014 .50301 m .50874 .50506 L .50945 .50535 L F
0 0 0 r
.31825 .50842 m .31868 .50722 L .31927 .50522 L F
.009 0 0 r
.31868 .50722 m .32212 .50561 L .31927 .50522 L F
.847 .733 .212 r
.56943 .41624 m .56944 .41151 L .56927 .41404 L F
.718 .346 0 r
.56977 .41757 m .56943 .41624 L .56927 .41404 L F
.56977 .41757 m .57037 .41842 L .56943 .41624 L F
.876 .989 .728 r
.47351 .52894 m .47102 .53275 L .47156 .53032 L F
.869 .96 .621 r
.47156 .53032 m .47102 .53275 L .46924 .53409 L F
.698 .612 .757 r
.5406 .47252 m .53769 .47591 L .5355 .46863 L F
.873 .597 .518 r
.55468 .4291 m .55742 .43181 L .5552 .43144 L F
.998 .844 .551 r
.55742 .43181 m .55546 .43467 L .5552 .43144 L F
.55742 .43181 m .55667 .4359 L .55546 .43467 L F
.437 .204 .462 r
.66661 .32324 m .66924 .32271 L .66969 .31988 L F
.389 .045 .256 r
.66661 .32324 m .66871 .32474 L .66924 .32271 L F
.66661 .32324 m .66593 .32549 L .66871 .32474 L F
0 0 0 r
.4565 .43301 m .45596 .4332 L .45444 .43465 L F
.4565 .43301 m .45841 .43212 L .45596 .4332 L F
.72 .976 .922 r
.54701 .47217 m .5504 .46986 L .54789 .47009 L F
.765 .979 .718 r
.54701 .47217 m .54789 .47009 L .54645 .47196 L F
.957 .843 .689 r
.56699 .43414 m .56974 .43287 L .56835 .43161 L F
.666 .705 .876 r
.32233 .61966 m .32359 .6242 L .32646 .62056 L F
.934 .575 .163 r
.56383 .38964 m .5628 .39018 L .56217 .38812 L F
.56383 .38964 m .56457 .39227 L .5628 .39018 L F
.558 .372 .585 r
.32772 .58831 m .3252 .59198 L .3286 .58961 L F
0 .153 .672 r
.3286 .58961 m .32972 .59001 L .32772 .58831 L F
.822 .701 .731 r
.55653 .37845 m .55811 .37997 L .55661 .37531 L F
.635 .599 .796 r
.55661 .37531 m .55811 .37997 L .5613 .37855 L F
0 0 0 r
.51502 .42575 m .51781 .42433 L .51601 .42562 L F
.757 .717 .815 r
.33923 .6221 m .34008 .61752 L .33794 .62032 L F
.83 .722 .745 r
.35633 .59694 m .35781 .59861 L .35637 .59468 L F
.806 .708 .757 r
.35336 .60056 m .35781 .59861 L .35633 .59694 L F
.35336 .60056 m .35524 .60197 L .35781 .59861 L F
.763 .573 .641 r
.54911 .4526 m .55294 .45559 L .54964 .45507 L F
.837 .718 .733 r
.55294 .45559 m .55107 .45908 L .54964 .45507 L F
.506 .837 .545 r
.62728 .39026 m .62934 .38845 L .62552 .39198 L F
.338 .434 .813 r
.62846 .38555 m .62934 .38845 L .63147 .38858 L F
.259 0 0 r
.63147 .38858 m .62934 .38845 L .62728 .39026 L F
.622 .164 .143 r
.31884 .61072 m .32058 .60934 L .32149 .61085 L F
.431 .439 .767 r
.24647 .54959 m .24939 .55109 L .24898 .54761 L F
.856 .724 .716 r
.35149 .5613 m .35318 .5618 L .35172 .55815 L F
.818 .541 .52 r
.3489 .56361 m .35318 .5618 L .35149 .5613 L F
.3489 .56361 m .35304 .56459 L .35318 .5618 L F
.617 .628 .839 r
.3013 .58063 m .30285 .58304 L .30464 .58152 L F
.028 0 0 r
.30361 .58349 m .30285 .58304 L .30464 .58152 L F
.30361 .58349 m .30161 .58424 L .30285 .58304 L F
.605 .715 .922 r
.63561 .38756 m .63225 .38676 L .63414 .38521 L F
.592 .702 .919 r
.63634 .38397 m .63561 .38756 L .63414 .38521 L F
.63634 .38397 m .63838 .38678 L .63561 .38756 L F
.264 .755 .913 r
.59711 .34311 m .60106 .34337 L .59847 .34446 L F
.766 .645 .728 r
.30108 .67504 m .30391 .67414 L .30072 .6767 L F
0 0 .41 r
.53436 .42944 m .53562 .43061 L .53675 .42862 L F
.823 .905 .897 r
.54178 .46868 m .5393 .46904 L .54122 .46751 L F
.872 .724 .695 r
.54178 .46868 m .5406 .47252 L .5393 .46904 L F
0 0 0 r
.42326 .451 m .4216 .45157 L .42075 .45193 L F
.42326 .451 m .42508 .44997 L .4216 .45157 L F
.56436 .39607 m .561 .3989 L .56384 .39857 L F
.56436 .39607 m .56519 .39586 L .56489 .39445 L F
.56436 .39607 m .56384 .39857 L .56519 .39586 L F
.96 .685 .469 r
.49291 .43536 m .49517 .43941 L .49281 .43745 L F
.449 .732 .988 r
.29732 .6546 m .29962 .6533 L .29609 .65167 L F
.29732 .6546 m .29928 .65431 L .29962 .6533 L F
0 0 0 r
.52111 .42156 m .52226 .42019 L .52434 .4182 L F
.224 .74 .863 r
.60263 .38712 m .60335 .38645 L .60605 .38687 L F
.644 .136 .024 r
.32155 .54795 m .32437 .54997 L .32616 .54863 L F
.187 0 0 r
.51354 .43436 m .51161 .4342 L .51052 .43537 L F
.51354 .43436 m .51365 .43351 L .51161 .4342 L F
.91 .874 .789 r
.36135 .49768 m .36533 .49594 L .36358 .49409 L F
.36135 .49768 m .36315 .49897 L .36533 .49594 L F
.372 .122 .4 r
.36533 .49594 m .36315 .49897 L .36581 .49786 L F
.995 .81 .545 r
.27897 .66743 m .2794 .67143 L .27804 .67165 L F
.891 .484 .232 r
.2794 .67143 m .27794 .67296 L .27804 .67165 L F
.2794 .67143 m .28008 .67353 L .27794 .67296 L F
.574 .567 .808 r
.28122 .66668 m .2794 .67143 L .27897 .66743 L F
.85 .71 .708 r
.35821 .57758 m .35579 .58072 L .35977 .58124 L F
.84 .749 .763 r
.35579 .58072 m .35769 .5852 L .35977 .58124 L F
.164 0 0 r
.41087 .45695 m .41451 .45471 L .41224 .45548 L F
.347 .033 .283 r
.31641 .68713 m .3174 .6843 L .32038 .68366 L F
.352 .024 .262 r
.52371 .47245 m .52 .47554 L .52244 .47509 L F
0 0 .057 r
.52371 .47245 m .52432 .47318 L .52553 .47186 L F
.52371 .47245 m .52244 .47509 L .52432 .47318 L F
.691 .867 .965 r
.32542 .64253 m .32125 .64285 L .32422 .64085 L F
.603 .675 .891 r
.32647 .63948 m .32542 .64253 L .32422 .64085 L F
.32647 .63948 m .32851 .64162 L .32542 .64253 L F
.667 .623 .796 r
.66969 .31988 m .67265 .3201 L .67113 .31619 L F
.738 .477 .535 r
.66969 .31988 m .6724 .32283 L .67265 .3201 L F
.66969 .31988 m .66924 .32271 L .6724 .32283 L F
.109 0 0 r
.39082 .46404 m .38996 .4632 L .38796 .46415 L F
.39082 .46404 m .39248 .46245 L .38996 .4632 L F
.398 .848 .77 r
.59924 .35172 m .59863 .35175 L .59666 .35292 L F
0 0 0 r
.59863 .35175 m .59539 .35457 L .59666 .35292 L F
.952 .832 .689 r
.56112 .45089 m .56365 .44949 L .56208 .44826 L F
.56112 .45089 m .56276 .45246 L .56365 .44949 L F
.89 .844 .793 r
.56365 .44949 m .56418 .44488 L .56208 .44826 L F
.681 .602 .761 r
.44773 .54081 m .44911 .54198 L .44504 .54178 L F
0 0 0 r
.44504 .54178 m .44699 .54148 L .44773 .54081 L F
.548 .077 .088 r
.44555 .5418 m .44767 .54351 L .44504 .54178 L F
.44911 .54198 m .44767 .54351 L .44555 .5418 L F
.781 .37 .273 r
.45169 .54447 m .45037 .54695 L .44767 .54351 L F
.45169 .54447 m .45037 .54695 L .44767 .54351 L F
0 .161 .691 r
.44767 .54351 m .45037 .54695 L .44961 .54507 L F
.825 .552 .525 r
.45181 .54184 m .44767 .54351 L .44911 .54198 L F
.45181 .54184 m .45169 .54447 L .44767 .54351 L F
0 .161 .691 r
.44767 .54351 m .44961 .54507 L .44849 .54231 L F
.121 .255 .73 r
.44504 .54178 m .44767 .54351 L .44699 .54148 L F
.558 .019 0 r
.26173 .52488 m .26441 .52629 L .26568 .52537 L F
.77 .481 .497 r
.26441 .52629 m .26829 .52486 L .26568 .52537 L F
.889 .63 .541 r
.37644 .53194 m .37331 .53105 L .37363 .52837 L F
.891 .646 .561 r
.37644 .53194 m .37303 .53381 L .37331 .53105 L F
.37644 .53194 m .37624 .53485 L .37303 .53381 L F
0 0 0 r
.64173 .33695 m .64311 .33707 L .64435 .33598 L F
.64173 .33695 m .6405 .33814 L .64311 .33707 L F
.133 .179 .644 r
.50262 .45051 m .49992 .44964 L .50187 .44731 L F
.427 0 0 r
.6146 .35694 m .61429 .35711 L .61592 .35398 L F
.6146 .35694 m .61773 .3588 L .61429 .35711 L F
.566 .173 .256 r
.61819 .35653 m .61773 .3588 L .6146 .35694 L F
.613 .615 .829 r
.60585 .3933 m .60983 .3963 L .60844 .39231 L F
.742 .707 .819 r
.35528 .58381 m .35769 .5852 L .35579 .58072 L F
.86 .587 .523 r
.35528 .58381 m .35701 .58719 L .35769 .5852 L F
.873 .905 .85 r
.25009 .58719 m .25185 .58832 L .25462 .58517 L F
.917 .834 .748 r
.38851 .49439 m .38834 .49995 L .39057 .49572 L F
.38851 .49439 m .38834 .49995 L .39057 .49572 L F
.765 .48 .501 r
.67254 .32546 m .67665 .32352 L .6724 .32283 L F
.67254 .32546 m .67676 .32596 L .67665 .32352 L F
.763 .609 .041 r
.32133 .53072 m .3213 .53137 L .32119 .52719 L F
.89 .91 .833 r
.66373 .39762 m .66504 .39895 L .66641 .39702 L F
.448 .567 .882 r
.4896 .43 m .49293 .43262 L .4918 .42964 L F
0 .215 .731 r
.4918 .42964 m .49293 .43262 L .49343 .43114 L F
0 0 .036 r
.49293 .43262 m .49307 .43357 L .49343 .43114 L F
.49293 .43262 m .49291 .43536 L .49307 .43357 L F
0 0 0 r
.63233 .38416 m .62846 .38555 L .63006 .38454 L F
.86 .99 .838 r
.63272 .38138 m .63233 .38416 L .63006 .38454 L F
.324 .249 .615 r
.63414 .38521 m .63225 .38676 L .63233 .38416 L F
.89 .604 .496 r
.34306 .52205 m .34445 .52478 L .34466 .52209 L F
.468 .427 .729 r
.62022 .35228 m .61819 .35653 L .61775 .35279 L F
.386 .756 .992 r
.61604 .35149 m .62022 .35228 L .61775 .35279 L F
.331 .588 .938 r
.56729 .3677 m .56614 .36953 L .56466 .36865 L F
.56729 .3677 m .56849 .36991 L .56614 .36953 L F
.628 .489 .674 r
.50755 .43267 m .5073 .43563 L .50459 .43601 L F
.574 .301 .464 r
.50495 .43853 m .50459 .43601 L .50459 .43859 L F
.50745 .4381 m .50606 .43708 L .50495 .43853 L F
.50606 .43708 m .50459 .43601 L .50495 .43853 L F
.50745 .4381 m .5073 .43563 L .50459 .43601 L F
.051 0 0 r
.50459 .43601 m .5049 .43597 L .505 .43643 L F
.5049 .43597 m .5073 .43563 L .505 .43643 L F
.628 .489 .674 r
.50755 .43267 m .5073 .43563 L .50459 .43601 L F
.902 .986 .754 r
.505 .43643 m .50712 .43569 L .50652 .43447 L F
0 0 0 r
.5051 .43689 m .505 .43643 L .50696 .43463 L F
.051 0 0 r
.50459 .43601 m .505 .43643 L .50459 .43859 L F
.712 .222 .079 r
.50325 .44011 m .50459 .43859 L .505 .43643 L F
0 0 0 r
.50423 .43795 m .505 .43643 L .5051 .43689 L F
.902 .986 .754 r
.50712 .43569 m .5073 .43563 L .50724 .43554 L F
.50712 .43569 m .50724 .43554 L .50652 .43447 L F
.84 .911 .884 r
.54197 .43512 m .54551 .43233 L .54402 .43066 L F
.51 .755 .984 r
.52519 .36433 m .52726 .36612 L .52401 .3665 L F
.968 .667 .398 r
.52726 .36612 m .52519 .36433 L .52401 .3665 L F
.919 .688 .573 r
.38472 .55525 m .38193 .55442 L .38235 .55147 L F
.835 .671 .678 r
.38504 .55781 m .38193 .55442 L .38472 .55525 L F
.121 0 0 r
.32995 .67732 m .33012 .67923 L .3274 .67934 L F
.32995 .67732 m .33231 .67672 L .33012 .67923 L F
.468 .427 .729 r
.62022 .35228 m .62033 .35606 L .61819 .35653 L F
.257 0 .177 r
.62047 .35759 m .61819 .35653 L .62033 .35606 L F
.62037 .35763 m .61819 .35653 L .62047 .35759 L F
.62048 .35768 m .61773 .3588 L .61819 .35653 L F
.529 0 0 r
.61773 .3588 m .61569 .35813 L .61429 .35711 L F
.581 .909 .978 r
.61954 .35673 m .61569 .35813 L .61761 .35876 L F
.61785 .35866 m .61761 .35876 L .61773 .3588 L F
.61954 .35673 m .61761 .35876 L .61785 .35866 L F
.257 0 .177 r
.62048 .35768 m .62037 .35763 L .62047 .35759 L F
.6 .952 .863 r
.45649 .4443 m .46122 .44237 L .46028 .44237 L F
.553 .933 .868 r
.46258 .44092 m .46122 .44237 L .46351 .44106 L F
.558 .933 .828 r
.46028 .44237 m .46122 .44237 L .46258 .44092 L F
.816 .381 .209 r
.35509 .50881 m .35333 .51021 L .3517 .50755 L F
.841 .421 .236 r
.35509 .50881 m .35704 .51193 L .35333 .51021 L F
.804 .427 .342 r
.35932 .51187 m .35704 .51193 L .35509 .50881 L F
.799 .688 .743 r
.67113 .31619 m .67481 .31634 L .67406 .31628 L F
.67113 .31619 m .67265 .3201 L .67481 .31634 L F
.318 .807 .819 r
.67481 .31634 m .67721 .31536 L .67406 .31628 L F
.596 .835 .459 r
.32333 .59444 m .3237 .59384 L .3252 .59198 L F
0 0 0 r
.3252 .59198 m .32647 .59102 L .3286 .58961 L F
.3252 .59198 m .3237 .59384 L .32647 .59102 L F
.101 0 0 r
.60758 .34362 m .61056 .34403 L .61216 .34422 L F
0 .556 .734 r
.61216 .34422 m .61056 .34403 L .61466 .34436 L F
.503 .448 .729 r
.55152 .38226 m .55417 .37917 L .55032 .37904 L F
.55152 .38226 m .55369 .38148 L .55417 .37917 L F
.828 .649 .661 r
.38392 .54804 m .37981 .54771 L .38055 .54499 L F
.903 .743 .672 r
.38392 .54804 m .37991 .55037 L .37981 .54771 L F
.38392 .54804 m .38235 .55147 L .37991 .55037 L F
.776 .752 .831 r
.34008 .61752 m .34433 .61797 L .34273 .61434 L F
.34273 .61434 m .34433 .61797 L .34693 .61489 L F
.846 .957 .883 r
.47554 .54103 m .47641 .54223 L .47964 .53931 L F
.879 .553 .047 r
.54911 .4526 m .54964 .45507 L .54818 .45118 L F
.972 .915 .583 r
.54978 .4472 m .54911 .4526 L .54818 .45118 L F
.879 .553 .047 r
.54911 .4526 m .54964 .45507 L .54818 .45118 L F
0 0 0 r
.34247 .65649 m .34482 .65398 L .34495 .65662 L F
.509 .831 .999 r
.4855 .42964 m .4896 .43 L .48812 .42874 L F
.428 .764 .996 r
.48812 .42874 m .4896 .43 L .4918 .42964 L F
.795 .343 .168 r
.36581 .49786 m .36975 .50085 L .36986 .49912 L F
.798 .798 .851 r
.54755 .46179 m .54435 .46187 L .54731 .45894 L F
.792 .793 .853 r
.55107 .45908 m .54755 .46179 L .54731 .45894 L F
.785 .485 .48 r
.41434 .59715 m .41795 .59529 L .41577 .59378 L F
.41434 .59715 m .41892 .59785 L .41795 .59529 L F
.446 .312 .605 r
.41795 .59529 m .41892 .59785 L .421 .59664 L F
.797 .98 .701 r
.57218 .4044 m .57137 .40664 L .57259 .40487 L F
.767 .908 .521 r
.57 .40875 m .57137 .40664 L .57218 .4044 L F
.237 .443 .859 r
.57066 .36981 m .57041 .37304 L .56849 .36991 L F
0 0 .188 r
.57091 .37308 m .57041 .37304 L .57066 .36981 L F
.57091 .37308 m .5707 .3756 L .57041 .37304 L F
.873 .905 .85 r
.25009 .58719 m .25462 .58517 L .25246 .5846 L F
.467 0 0 r
.28489 .51357 m .28374 .51374 L .28304 .51297 L F
.915 .977 .773 r
.25822 .56988 m .25882 .57195 L .26153 .56796 L F
0 0 .067 r
.26083 .56607 m .26037 .56674 L .26039 .56654 L F
.943 .948 .751 r
.26039 .56654 m .25822 .56988 L .26153 .56796 L F
0 0 .067 r
.26037 .56674 m .25822 .56988 L .26039 .56654 L F
.679 .244 0 r
.26042 .56634 m .26039 .56654 L .26153 .56796 L F
.25922 .56458 m .26039 .56654 L .26042 .56634 L F
.869 .888 .846 r
.34755 .5015 m .34532 .50097 L .34789 .49826 L F
.882 .516 .348 r
.34755 .5015 m .34542 .50322 L .34532 .50097 L F
.34755 .5015 m .34883 .50477 L .34542 .50322 L F
.862 .509 .382 r
.35118 .50528 m .34883 .50477 L .34755 .5015 L F
.068 0 0 r
.60665 .34956 m .60507 .35011 L .60235 .35018 L F
.224 .743 .84 r
.60895 .34999 m .60507 .35011 L .60665 .34956 L F
.205 0 .185 r
.34193 .67079 m .34438 .667 L .34367 .66996 L F
0 0 0 r
.34438 .667 m .34825 .6631 L .34662 .66662 L F
.002 0 .096 r
.34367 .66996 m .34438 .667 L .34662 .66662 L F
.843 .597 .567 r
.35449 .5712 m .35833 .57465 L .35876 .57183 L F
.685 .181 .036 r
.33553 .58086 m .33759 .58264 L .33981 .58182 L F
.827 .993 .859 r
.34308 .57862 m .33981 .58182 L .34023 .5794 L F
.854 .998 .789 r
.33981 .58182 m .33759 .58264 L .34023 .5794 L F
.819 .341 .052 r
.39355 .50849 m .39525 .51106 L .39745 .51192 L F
.916 .517 .185 r
.39525 .51106 m .39807 .51479 L .39745 .51192 L F
.761 .986 .754 r
.67901 .37142 m .67776 .37375 L .67951 .37178 L F
.714 .948 .955 r
.67537 .37331 m .67776 .37375 L .67901 .37142 L F
.236 0 0 r
.38413 .47231 m .38817 .47136 L .38596 .47296 L F
0 0 0 r
.38967 .47112 m .38817 .47136 L .39012 .47081 L F
.38596 .47296 m .38817 .47136 L .38967 .47112 L F
.191 0 0 r
.3951 .46157 m .39759 .46127 L .39932 .4599 L F
.262 0 0 r
.39759 .46127 m .40155 .46032 L .39932 .4599 L F
.281 0 0 r
.39932 .4599 m .40155 .46032 L .40377 .4583 L F
.294 0 0 r
.40155 .46032 m .40575 .45793 L .40377 .4583 L F
.789 .808 .868 r
.30949 .64773 m .30553 .64759 L .30738 .64609 L F
.712 .802 .921 r
.31155 .64665 m .30949 .64773 L .30738 .64609 L F
.583 .814 .987 r
.53048 .36006 m .53311 .36103 L .53264 .35977 L F
.654 .857 .977 r
.53264 .35977 m .53311 .36103 L .53643 .35994 L F
.761 .914 .941 r
.4281 .60714 m .42984 .60383 L .4266 .60604 L F
.4281 .60714 m .43157 .60515 L .42984 .60383 L F
.972 .896 .688 r
.52787 .46935 m .5272 .4699 L .52844 .46885 L F
.52787 .46935 m .52553 .47186 L .5272 .4699 L F
.8 .999 .837 r
.30198 .65854 m .30285 .65609 L .3025 .65746 L F
.731 .213 0 r
.3041 .62102 m .30781 .62447 L .30432 .62337 L F
.301 0 0 r
.30432 .62337 m .30781 .62447 L .30644 .62417 L F
.846 .95 .884 r
.30764 .62197 m .30781 .62447 L .30995 .62172 L F
.919 .972 .776 r
.30644 .62417 m .30781 .62447 L .30764 .62197 L F
.568 .868 .563 r
.2559 .5752 m .25395 .57694 L .25299 .57813 L F
.875 .993 .757 r
.25564 .57325 m .2559 .5752 L .25621 .57278 L F
0 0 0 r
.25564 .57557 m .2559 .5752 L .25564 .57325 L F
.25564 .57557 m .25395 .57694 L .2559 .5752 L F
.685 .69 .849 r
.33779 .63819 m .33919 .6414 L .33488 .64041 L F
.586 .594 .827 r
.34021 .63695 m .33919 .6414 L .33779 .63819 L F
.34021 .63695 m .34179 .64074 L .33919 .6414 L F
0 0 0 r
.39039 .50397 m .38895 .50812 L .3907 .50549 L F
.893 .976 .678 r
.39251 .50036 m .39039 .50397 L .3907 .50549 L F
.897 .718 .652 r
.38767 .57063 m .38564 .56728 L .38771 .56836 L F
.811 .709 .753 r
.35071 .60422 m .35524 .60197 L .35336 .60056 L F
.984 .801 .577 r
.41078 .5583 m .41148 .56169 L .40986 .56048 L F
.846 .414 0 r
.41148 .56169 m .41115 .56311 L .40986 .56048 L F
.41148 .56169 m .41198 .5638 L .41115 .56311 L F
.846 .957 .883 r
.47554 .54103 m .47964 .53931 L .47774 .53823 L F
.844 .913 .882 r
.47774 .53823 m .47964 .53931 L .48107 .53745 L F
.694 .949 .956 r
.49706 .40508 m .4949 .40661 L .49352 .40592 L F
.751 .963 .672 r
.29717 .58651 m .29653 .58824 L .29925 .58501 L F
.641 .942 .959 r
.29717 .58651 m .29508 .58772 L .29653 .58824 L F
0 0 0 r
.32333 .59444 m .32301 .59614 L .3237 .59384 L F
.32333 .59444 m .32227 .5978 L .32301 .59614 L F
.865 .527 .41 r
.37842 .50181 m .38052 .50525 L .38109 .50398 L F
0 0 0 r
.38052 .50525 m .38003 .5067 L .38109 .50398 L F
.369 0 .152 r
.38109 .50398 m .38299 .50605 L .38355 .50418 L F
.38109 .50398 m .38003 .5067 L .38299 .50605 L F
.757 .341 .26 r
.25299 .57813 m .25078 .58013 L .24948 .57812 L F
.568 .869 .564 r
.25395 .57694 m .25078 .58013 L .25299 .57813 L F
.25395 .57694 m .25078 .58013 L .25299 .57813 L F
.948 .949 .738 r
.57401 .39973 m .57431 .40286 L .57601 .39953 L F
.98 .845 .454 r
.57601 .39953 m .57568 .39399 L .5756 .39691 L F
.929 .966 .764 r
.5756 .39691 m .57401 .39973 L .57601 .39953 L F
.874 .62 .552 r
.55552 .4116 m .55452 .41521 L .55281 .41201 L F
.995 .864 .54 r
.57583 .39079 m .57677 .39221 L .57757 .38934 L F
.987 .728 .444 r
.5759 .38801 m .57583 .39079 L .57757 .38934 L F
.857 .462 .291 r
.36323 .51539 m .36099 .51504 L .35932 .51187 L F
.825 .39 .206 r
.36323 .51539 m .36156 .5168 L .36099 .51504 L F
.948 .614 .355 r
.36338 .51762 m .36156 .5168 L .36323 .51539 L F
.751 .963 .672 r
.29717 .58651 m .29925 .58501 L .29528 .58531 L F
.539 .812 .996 r
.40573 .55459 m .40994 .55508 L .40956 .55383 L F
.426 .835 .646 r
.40792 .55415 m .40502 .55659 L .40573 .55459 L F
.40956 .55383 m .40853 .55445 L .40792 .55415 L F
.483 .498 .797 r
.40647 .55637 m .40743 .56058 L .40588 .56093 L F
.40657 .55557 m .40671 .55635 L .40647 .55637 L F
.40671 .55635 m .40743 .56058 L .40647 .55637 L F
.426 .835 .646 r
.40853 .55445 m .40521 .55647 L .40792 .55415 L F
.40521 .55647 m .40502 .55659 L .40515 .55648 L F
.40521 .55647 m .40515 .55648 L .40792 .55415 L F
.40649 .55569 m .40657 .55557 L .40502 .55659 L F
.483 .498 .797 r
.40657 .55557 m .40588 .56093 L .40502 .55659 L F
.337 .278 .643 r
.40547 .55766 m .40669 .55539 L .40657 .55557 L F
.40669 .55539 m .40762 .55365 L .40657 .55557 L F
.426 .835 .646 r
.40853 .55445 m .40657 .55557 L .40649 .55569 L F
.40956 .55383 m .40852 .55445 L .40853 .55445 L F
.874 .978 .841 r
.40994 .55508 m .40852 .55445 L .40956 .55383 L F
.40852 .55445 m .40805 .55424 L .40956 .55383 L F
.426 .835 .646 r
.40956 .55383 m .40849 .55445 L .40852 .55445 L F
.40849 .55445 m .40657 .55557 L .40853 .55445 L F
.548 .056 0 r
.40855 .55447 m .40915 .55476 L .40847 .55444 L F
.40852 .55445 m .40847 .55444 L .40805 .55424 L F
.40855 .55447 m .40847 .55444 L .40852 .55445 L F
.65 .192 .153 r
.40985 .55509 m .40657 .55557 L .40849 .55445 L F
.548 .056 0 r
.40994 .55508 m .40985 .55509 L .40919 .55478 L F
.40994 .55508 m .40915 .55476 L .40855 .55447 L F
.65 .192 .153 r
.40985 .55509 m .40849 .55445 L .40956 .55383 L F
.548 .056 0 r
.40919 .55478 m .40985 .55509 L .40915 .55476 L F
0 0 .256 r
.40994 .55508 m .41078 .5583 L .41024 .55549 L F
.548 .056 0 r
.40994 .55508 m .41024 .55549 L .40985 .55509 L F
.876 .564 .455 r
.35118 .50528 m .34898 .50728 L .34883 .50477 L F
.823 .475 .397 r
.3517 .50755 m .34898 .50728 L .35118 .50528 L F
0 0 0 r
.34482 .65398 m .34712 .65132 L .34739 .65293 L F
0 0 .068 r
.34739 .65293 m .34712 .65132 L .34828 .6491 L F
.93 .844 .737 r
.48318 .53101 m .48683 .52855 L .48583 .52798 L F
.48318 .53101 m .48505 .53245 L .48683 .52855 L F
.907 .982 .774 r
.48829 .5242 m .48683 .52855 L .49011 .52568 L F
.48829 .5242 m .48583 .52798 L .48683 .52855 L F
.694 .586 .731 r
.62339 .37978 m .62735 .3806 L .6261 .37898 L F
.43 .723 .987 r
.58319 .37089 m .58606 .37198 L .58387 .37253 L F
.925 .948 .789 r
.57259 .40487 m .57431 .40286 L .57401 .39973 L F
0 0 .422 r
.5299 .43889 m .53046 .44298 L .53056 .44112 L F
.665 .752 .916 r
.53046 .44298 m .53254 .44187 L .53056 .44112 L F
.884 .991 .758 r
.25822 .56988 m .25621 .57278 L .25882 .57195 L F
.232 0 0 r
.61295 .35005 m .61215 .35055 L .60895 .34999 L F
.454 0 0 r
.61295 .35005 m .61604 .35149 L .61215 .35055 L F
.992 .879 .599 r
.66641 .39702 m .66662 .39187 L .66494 .39554 L F
.89 .91 .833 r
.66373 .39762 m .66641 .39702 L .66494 .39554 L F
.84 .911 .884 r
.54197 .43512 m .54402 .43066 L .54137 .43138 L F
.259 .228 .633 r
.53462 .41985 m .53567 .42236 L .53541 .41759 L F
.638 .14 .051 r
.32121 .51204 m .3193 .51345 L .31696 .51149 L F
.861 .458 .27 r
.32149 .51393 m .3193 .51345 L .32121 .51204 L F
0 .24 .661 r
.34925 .64271 m .35014 .6433 L .34817 .64208 L F
.623 .813 .973 r
.35218 .64267 m .3509 .64379 L .35014 .6433 L F
0 0 0 r
.35005 .64534 m .35013 .64445 L .3509 .64379 L F
.35122 .64388 m .3509 .64379 L .35218 .64267 L F
.35005 .64534 m .3509 .64379 L .35122 .64388 L F
.623 .813 .973 r
.35218 .64267 m .35014 .6433 L .35133 .64393 L F
0 .24 .661 r
.35126 .64389 m .35014 .6433 L .34925 .64271 L F
0 0 0 r
.35005 .64534 m .35218 .64267 L .35133 .64393 L F
0 .24 .661 r
.35133 .64393 m .35124 .64388 L .35126 .64389 L F
.35124 .64388 m .35014 .6433 L .35126 .64389 L F
.623 .813 .973 r
.3509 .64379 m .35013 .64445 L .35014 .6433 L F
0 0 .562 r
.6922 .35387 m .69005 .34978 L .69027 .35179 L F
.884 .454 .148 r
.69141 .35464 m .6922 .35387 L .69027 .35179 L F
.69141 .35464 m .69272 .35528 L .6922 .35387 L F
.984 .896 .643 r
.66802 .35253 m .66562 .35502 L .66647 .35119 L F
.66802 .35253 m .66673 .35621 L .66562 .35502 L F
.757 .826 .905 r
.31723 .64271 m .31889 .6441 L .31465 .64401 L F
.699 .83 .945 r
.32006 .64085 m .31889 .6441 L .31723 .64271 L F
.32006 .64085 m .32125 .64285 L .31889 .6441 L F
.23 0 0 r
.29666 .6852 m .3004 .68558 L .2988 .6859 L F
.482 0 0 r
.3004 .68558 m .30291 .68671 L .2988 .6859 L F
.692 .151 0 r
.41187 .53066 m .41394 .53298 L .41464 .53236 L F
.761 .257 0 r
.41394 .53298 m .41594 .5344 L .41464 .53236 L F
.682 .716 .197 r
.59155 .42945 m .59061 .43274 L .58987 .4353 L F
.091 .524 .907 r
.33224 .57516 m .33379 .57719 L .32947 .57614 L F
.33224 .57516 m .33444 .57679 L .33379 .57719 L F
.43 .687 .972 r
.33466 .59113 m .33817 .59306 L .33787 .59269 L F
.828 .848 .863 r
.33787 .59269 m .33817 .59306 L .34023 .59071 L F
.209 .181 .606 r
.24324 .56789 m .24456 .56342 L .24266 .56516 L F
.431 .829 .981 r
.60106 .34337 m .60349 .34285 L .60501 .34351 L F
.367 0 0 r
.60349 .34285 m .60758 .34362 L .60501 .34351 L F
.889 .97 .831 r
.51181 .50157 m .51276 .50262 L .51549 .49932 L F
.878 .971 .845 r
.51181 .50157 m .51014 .50301 L .51276 .50262 L F
0 .12 .637 r
.54347 .44747 m .54232 .44906 L .54125 .44655 L F
.267 0 0 r
.54347 .44747 m .54125 .44655 L .541 .44759 L F
.187 .577 .939 r
.29004 .64377 m .28835 .64374 L .28668 .6421 L F
.292 .703 .974 r
.57814 .3509 m .5821 .35202 L .57968 .35214 L F
0 0 0 r
.31731 .58475 m .3182 .58459 L .32002 .58231 L F
.883 .99 .797 r
.33134 .55965 m .33166 .55695 L .3332 .55797 L F
.288 0 0 r
.33371 .56019 m .33134 .55965 L .3332 .55797 L F
.33371 .56019 m .32988 .56038 L .33134 .55965 L F
0 0 0 r
.5119 .39239 m .51441 .38842 L .5129 .39004 L F
.829 .824 .345 r
.53167 .3563 m .53083 .35746 L .53145 .3558 L F
.53167 .3563 m .53048 .36006 L .53083 .35746 L F
.551 .836 .498 r
.53167 .3563 m .53341 .35426 L .53465 .35298 L F
.618 .957 .84 r
.53167 .3563 m .53145 .3558 L .53341 .35426 L F
.524 .154 .279 r
.65253 .34 m .6553 .34154 L .6526 .34161 L F
.513 .171 .324 r
.65531 .33972 m .6553 .34154 L .65253 .34 L F
.807 .619 .648 r
.38936 .58191 m .38864 .58442 L .38734 .58107 L F
.229 .123 .52 r
.35741 .4948 m .35994 .49095 L .35734 .4918 L F
.35741 .4948 m .36001 .49387 L .35994 .49095 L F
0 0 0 r
.48695 .51217 m .48802 .51035 L .48911 .50834 L F
.516 .857 .588 r
.48911 .50834 m .49066 .50681 L .49224 .50561 L F
0 0 0 r
.48911 .50834 m .48802 .51035 L .49066 .50681 L F
.908 .634 .51 r
.34463 .52737 m .34751 .53039 L .34754 .529 L F
.421 .202 .473 r
.4546 .53844 m .45431 .54109 L .45181 .54184 L F
.428 .218 .491 r
.45431 .54109 m .45169 .54447 L .45181 .54184 L F
.941 .945 .759 r
.51832 .39768 m .51638 .40142 L .5182 .40146 L F
.647 .964 .911 r
.5182 .40146 m .51824 .3997 L .52048 .4016 L F
.5182 .40146 m .51638 .40142 L .51824 .3997 L F
.815 .488 0 r
.60567 .38726 m .60605 .38687 L .60335 .38645 L F
.527 .906 .74 r
.60438 .38933 m .60516 .38818 L .60603 .38794 L F
.60516 .38818 m .60605 .38687 L .60603 .38794 L F
.267 0 0 r
.60666 .38777 m .60603 .38794 L .60567 .38726 L F
.62 .554 .759 r
.60844 .39231 m .60438 .38933 L .60603 .38794 L F
.60844 .39231 m .60753 .39065 L .60711 .39124 L F
.60753 .39065 m .60603 .38794 L .60711 .39124 L F
.60844 .39231 m .60585 .3933 L .60438 .38933 L F
.661 .799 .949 r
.60437 .39168 m .60585 .3933 L .60844 .39231 L F
.60437 .39168 m .60844 .39231 L .60711 .39124 L F
.071 0 0 r
.60711 .39124 m .60857 .39183 L .60599 .39287 L F
.60711 .39124 m .60599 .39287 L .60581 .39294 L F
.495 .298 .543 r
.60981 .38741 m .60711 .39124 L .60603 .38794 L F
.267 0 0 r
.6084 .38866 m .60981 .38741 L .60603 .38794 L F
.6084 .38866 m .60603 .38794 L .60666 .38777 L F
.815 .488 0 r
.60567 .38726 m .60603 .38794 L .60605 .38687 L F
.174 0 0 r
.64989 .33461 m .65391 .3326 L .65121 .33355 L F
.794 .986 .894 r
.47509 .52759 m .47351 .52894 L .47421 .52688 L F
.828 .989 .726 r
.47351 .52894 m .47156 .53032 L .47421 .52688 L F
0 0 0 r
.27002 .55115 m .26706 .55418 L .26826 .55228 L F
.845 .441 .277 r
.40247 .56465 m .40435 .56788 L .40629 .56776 L F
0 0 0 r
.426 .45044 m .42508 .44997 L .42326 .451 L F
.426 .45044 m .42742 .44869 L .42508 .44997 L F
0 .347 .705 r
.62081 .39934 m .61806 .39807 L .61885 .39845 L F
.62081 .39934 m .6191 .3985 L .61806 .39807 L F
.262 .702 .961 r
.62355 .39938 m .6191 .3985 L .62081 .39934 L F
.566 .633 .877 r
.31727 .61353 m .31585 .61431 L .31436 .61086 L F
.889 .97 .831 r
.51181 .50157 m .51549 .49932 L .51229 .50056 L F
.86 .959 .87 r
.51554 .49675 m .51549 .49932 L .51647 .49797 L F
.869 .963 .859 r
.51554 .49675 m .51229 .50056 L .51549 .49932 L F
.704 .68 .824 r
.6261 .37898 m .62735 .3806 L .62996 .37934 L F
.891 .699 .636 r
.35282 .56748 m .35449 .5712 L .35526 .56853 L F
.085 .574 .9 r
.40104 .59292 m .39975 .59188 L .39673 .59144 L F
.703 .691 .835 r
.33597 .61714 m .33794 .62032 L .34008 .61752 L F
.864 .705 .683 r
.35701 .58719 m .35488 .59096 L .35889 .5912 L F
.86 .74 .729 r
.35488 .59096 m .35637 .59468 L .35889 .5912 L F
.828 .694 .716 r
.35701 .58719 m .35889 .5912 L .35929 .58857 L F
.91 .686 .588 r
.66564 .33973 m .66226 .34123 L .66178 .33941 L F
.66564 .33973 m .66536 .34287 L .66226 .34123 L F
.535 .918 .789 r
.4647 .42886 m .46055 .43086 L .46266 .42944 L F
.618 .949 .775 r
.46613 .42713 m .46808 .42642 L .4647 .42886 L F
.619 .956 .815 r
.46613 .42713 m .4647 .42886 L .46266 .42944 L F
.981 .694 .392 r
.56273 .45501 m .56276 .45246 L .56112 .45089 L F
.821 .711 .744 r
.54964 .45507 m .55107 .45908 L .54731 .45894 L F
.867 .659 .128 r
.5883 .3598 m .58831 .36165 L .58844 .35967 L F
.534 .245 .422 r
.26829 .52486 m .2711 .5246 L .27165 .52216 L F
.342 .075 .357 r
.27165 .52216 m .27338 .52375 L .27402 .52153 L F
.27165 .52216 m .2711 .5246 L .27338 .52375 L F
.746 .636 .738 r
.60165 .39243 m .60353 .3967 L .60585 .3933 L F
.054 0 0 r
.50961 .42317 m .50853 .42269 L .50693 .42389 L F
.50961 .42317 m .51137 .42217 L .50853 .42269 L F
.893 .562 .415 r
.68079 .33491 m .68236 .33319 L .68069 .33268 L F
.68079 .33491 m .68268 .33562 L .68236 .33319 L F
.928 .905 .781 r
.44964 .55083 m .45324 .5484 L .45095 .55198 L F
.44964 .55083 m .45171 .5474 L .45324 .5484 L F
.759 .764 .857 r
.4551 .54384 m .45324 .5484 L .45171 .5474 L F
.4551 .54384 m .45613 .54537 L .45324 .5484 L F
.099 0 0 r
.42616 .45663 m .42499 .4579 L .42223 .45862 L F
0 0 0 r
.42616 .45663 m .42713 .45668 L .42499 .4579 L F
.42616 .45663 m .42868 .45612 L .42713 .45668 L F
.641 .797 .957 r
.30184 .61976 m .3041 .62102 L .29954 .62067 L F
.29954 .62067 m .3041 .62102 L .30184 .61976 L F
.788 .797 .86 r
.30656 .61807 m .3041 .62102 L .30184 .61976 L F
.275 .434 .839 r
.30432 .62337 m .30184 .61976 L .3041 .62102 L F
.686 .392 0 r
.57561 .3689 m .57687 .37303 L .57626 .37108 L F
.04 .24 .74 r
.57687 .37303 m .57901 .37275 L .57626 .37108 L F
.57687 .37303 m .57937 .37503 L .57901 .37275 L F
.294 .548 .921 r
.29437 .64673 m .29231 .6465 L .29004 .64377 L F
.988 .738 .358 r
.32548 .55399 m .32312 .55227 L .32564 .55124 L F
.32548 .55399 m .32244 .55068 L .32312 .55227 L F
.843 .597 .567 r
.35449 .5712 m .35436 .5741 L .35833 .57465 L F
.81 .656 .692 r
.35436 .5741 m .35821 .57758 L .35833 .57465 L F
.743 .758 .865 r
.50722 .49302 m .50296 .49238 L .50555 .49061 L F
.689 .685 .841 r
.50885 .49114 m .50722 .49302 L .50555 .49061 L F
.766 .873 .926 r
.62552 .39198 m .62208 .39236 L .62472 .39116 L F
.506 .837 .545 r
.62728 .39026 m .62552 .39198 L .62472 .39116 L F
.68 .942 .665 r
.51082 .41052 m .50959 .41245 L .51211 .40967 L F
.544 .349 .568 r
.51082 .41052 m .50818 .41403 L .50959 .41245 L F
.853 .734 .732 r
.30108 .67504 m .30072 .6767 L .29738 .67687 L F
.941 .879 .746 r
.34211 .56435 m .34167 .5684 L .34016 .56767 L F
.809 .475 .423 r
.34167 .5684 m .33953 .57036 L .34016 .56767 L F
.34167 .5684 m .34334 .5708 L .33953 .57036 L F
.687 .945 .96 r
.538 .42101 m .54309 .41987 L .54013 .41995 L F
.775 .962 .927 r
.54013 .41995 m .54309 .41987 L .54364 .41738 L F
0 0 0 r
.41146 .59463 m .41337 .59364 L .41423 .59163 L F
.41407 .59164 m .41423 .59163 L .41437 .5913 L F
.41146 .59463 m .41423 .59163 L .41407 .59164 L F
.78 .409 .355 r
.41437 .5913 m .41337 .59364 L .41475 .59372 L F
.41464 .59178 m .41475 .59372 L .41577 .59378 L F
.41437 .5913 m .41475 .59372 L .41464 .59178 L F
.41437 .5913 m .41577 .59378 L .41635 .59081 L F
0 0 .194 r
.41537 .59265 m .41577 .59378 L .41337 .59364 L F
.41537 .59265 m .4146 .59604 L .41577 .59378 L F
.4146 .59604 m .41434 .59715 L .41493 .59576 L F
.4146 .59604 m .41493 .59576 L .41577 .59378 L F
.766 .714 .804 r
.41434 .59715 m .41621 .60093 L .41892 .59785 L F
.714 .22 .065 r
.41477 .59688 m .41542 .59863 L .41357 .5969 L F
.221 .654 .954 r
.41229 .59678 m .41337 .59364 L .41146 .59463 L F
.41246 .59724 m .41257 .59683 L .41229 .59678 L F
.41257 .59683 m .41337 .59364 L .41229 .59678 L F
0 0 .194 r
.41482 .59504 m .41477 .59688 L .41434 .59715 L F
.221 .654 .954 r
.41295 .59533 m .41263 .59602 L .41337 .59364 L F
.41246 .59724 m .41263 .59602 L .41295 .59533 L F
.41246 .59724 m .41434 .59715 L .41263 .59602 L F
.684 .138 0 r
.41263 .59602 m .41542 .59863 L .41221 .59694 L F
.41263 .59602 m .41221 .59694 L .41141 .59652 L F
0 0 0 r
.41577 .59378 m .41477 .59688 L .41434 .59715 L F
.714 .22 .065 r
.41477 .59688 m .41263 .59602 L .41429 .59711 L F
.41438 .59713 m .41429 .59711 L .41434 .59715 L F
.41477 .59688 m .41429 .59711 L .41438 .59713 L F
.41397 .59656 m .41357 .5969 L .41263 .59602 L F
.41477 .59688 m .41357 .5969 L .41397 .59656 L F
0 0 .194 r
.41537 .59265 m .41488 .59609 L .41482 .59504 L F
.41488 .59609 m .41477 .59688 L .41482 .59504 L F
.839 .99 .859 r
.40634 .59168 m .40761 .59099 L .40826 .59023 L F
.40761 .59099 m .41025 .58954 L .40826 .59023 L F
.073 .609 .858 r
.41447 .5916 m .40826 .59023 L .41025 .58954 L F
0 0 .024 r
.40953 .58823 m .40949 .59016 L .40826 .59023 L F
.073 .609 .858 r
.41446 .5916 m .40967 .59015 L .40949 .59016 L F
.40943 .59049 m .40949 .59016 L .40826 .59023 L F
.41446 .5916 m .40949 .59016 L .40943 .59049 L F
0 0 .024 r
.40949 .59016 m .40953 .59107 L .40944 .59253 L F
.40953 .58823 m .4095 .59009 L .40949 .59016 L F
.788 .755 .823 r
.40953 .58823 m .40948 .59009 L .4095 .59008 L F
.599 .031 0 r
.41437 .5913 m .41447 .5916 L .41025 .58954 L F
.788 .755 .823 r
.40953 .58823 m .4095 .59008 L .41441 .5883 L F
0 0 .024 r
.40953 .58823 m .40953 .58992 L .4095 .59009 L F
.40953 .58992 m .40953 .59107 L .40949 .59016 L F
.40949 .59016 m .40944 .59253 L .40826 .59023 L F
.073 .609 .858 r
.40967 .59015 m .40948 .59009 L .40826 .59023 L F
0 .066 .579 r
.40826 .59023 m .40948 .59009 L .40951 .58876 L F
.40826 .59023 m .40951 .58876 L .40953 .58823 L F
.073 .609 .858 r
.41447 .5916 m .41446 .5916 L .41446 .5916 L F
.41446 .5916 m .40948 .59009 L .41446 .5916 L F
.523 .242 .43 r
.41635 .59081 m .41447 .5916 L .41437 .5913 L F
0 0 0 r
.44894 .53947 m .45122 .53877 L .45255 .53819 L F
.44869 .53956 m .44892 .53949 L .44894 .53947 L F
.44892 .53949 m .45122 .53877 L .44894 .53947 L F
.599 .884 .575 r
.44699 .54148 m .44919 .53929 L .44773 .54081 L F
.44919 .53929 m .45032 .53817 L .44929 .53922 L F
.44919 .53929 m .44929 .53922 L .44773 .54081 L F
.05 .245 .742 r
.53408 .4371 m .53157 .43578 L .53535 .43538 L F
.69 .149 0 r
.53157 .43578 m .5312 .43662 L .53286 .43341 L F
.53157 .43578 m .53335 .43767 L .5312 .43662 L F
.912 .53 .279 r
.4074 .52398 m .40884 .52769 L .4109 .52854 L F
.897 .493 .23 r
.40884 .52769 m .40939 .52973 L .4109 .52854 L F
.871 .445 .197 r
.4109 .52854 m .40939 .52973 L .41187 .53066 L F
.73 .767 .882 r
.33265 .64186 m .32851 .64162 L .3308 .64019 L F
.766 .782 .866 r
.3308 .64019 m .33488 .64041 L .33265 .64186 L F
.922 .97 .773 r
.44816 .55351 m .45095 .55198 L .44865 .55567 L F
.208 .062 .452 r
.4468 .55734 m .44816 .55351 L .44865 .55567 L F
.863 .907 .862 r
.59145 .4392 m .5946 .43626 L .58998 .43636 L F
.732 .281 .182 r
.35932 .51187 m .35753 .51348 L .35704 .51193 L F
.855 .462 .298 r
.35932 .51187 m .36099 .51504 L .35753 .51348 L F
.792 .563 0 r
.58771 .40239 m .58793 .40429 L .58763 .40327 L F
.58793 .40429 m .58802 .40509 L .58763 .40327 L F
.849 .993 .84 r
.58716 .40167 m .58763 .40327 L .58617 .40236 L F
.792 .563 0 r
.58771 .40239 m .58763 .40327 L .59037 .3994 L F
.849 .993 .84 r
.59037 .3994 m .58763 .40327 L .58716 .40167 L F
.213 0 0 r
.38895 .50812 m .39146 .50838 L .39355 .50849 L F
0 0 .491 r
.39448 .50925 m .39525 .51106 L .39355 .50849 L F
.39448 .50925 m .39355 .50849 L .39146 .50838 L F
0 0 .558 r
.57337 .36265 m .57557 .36629 L .57486 .3647 L F
0 0 .212 r
.57557 .36629 m .57643 .36674 L .57486 .3647 L F
.57557 .36629 m .57561 .3689 L .57643 .36674 L F
.714 .709 .845 r
.32646 .62056 m .32833 .62425 L .33064 .6211 L F
.746 .636 .738 r
.60165 .39243 m .60585 .3933 L .60437 .39168 L F
.364 .161 .466 r
.25202 .53427 m .25549 .53093 L .25296 .53149 L F
.95 .854 .431 r
.65159 .38043 m .6519 .38329 L .65137 .38207 L F
.593 .852 .993 r
.36581 .49786 m .36315 .49897 L .36399 .4968 L F
.575 .833 .994 r
.36399 .4968 m .36315 .49897 L .36135 .49768 L F
.924 .638 .481 r
.34802 .53804 m .34795 .54082 L .3509 .54188 L F
.873 .701 .667 r
.34795 .54082 m .35055 .54415 L .3509 .54188 L F
.792 .933 .925 r
.44824 .59327 m .45267 .5917 L .45095 .5906 L F
.828 .834 .852 r
.45267 .5917 m .45363 .58714 L .45095 .5906 L F
.45267 .5917 m .45553 .5886 L .45363 .58714 L F
.492 .261 .492 r
.4546 .53844 m .45699 .54052 L .45431 .54109 L F
.945 .683 .51 r
.45255 .53819 m .45431 .54109 L .4546 .53844 L F
0 0 0 r
.50868 .43082 m .50755 .43267 L .50991 .42851 L F
.957 .815 .378 r
.50652 .43447 m .50755 .43267 L .50868 .43082 L F
.50652 .43447 m .5073 .43563 L .50755 .43267 L F
.683 .95 .956 r
.53781 .35112 m .53465 .35298 L .53597 .35078 L F
.61 .075 0 r
.53465 .35298 m .5374 .35493 L .53597 .35078 L F
.53465 .35298 m .53341 .35426 L .5374 .35493 L F
.607 .87 .992 r
.43887 .59691 m .44248 .59708 L .44118 .59634 L F
.838 .925 .89 r
.44248 .59708 m .44396 .59318 L .44118 .59634 L F
.44248 .59708 m .44561 .59408 L .44396 .59318 L F
.942 .763 .631 r
.36748 .51858 m .36475 .52049 L .36338 .51762 L F
.36748 .51858 m .36676 .52157 L .36475 .52049 L F
0 0 0 r
.51261 .442 m .51602 .43949 L .51437 .4414 L F
.458 .634 .931 r
.51831 .43581 m .51454 .43395 L .51633 .43368 L F
.51454 .43395 m .51365 .43351 L .51633 .43368 L F
.485 .762 .992 r
.51971 .43359 m .51831 .43581 L .51633 .43368 L F
.237 .733 .912 r
.51808 .43325 m .51971 .43359 L .51633 .43368 L F
.51779 .43347 m .51633 .43368 L .51499 .43556 L F
.51808 .43325 m .51633 .43368 L .51779 .43347 L F
.783 .934 .575 r
.51796 .43541 m .51602 .43949 L .51831 .43581 L F
.51755 .43578 m .51602 .43949 L .51796 .43541 L F
.785 .937 .581 r
.51437 .4414 m .51602 .43949 L .51779 .4352 L F
.51437 .4414 m .5174 .43591 L .51748 .43741 L F
.783 .934 .575 r
.51779 .4352 m .51755 .43578 L .51796 .43541 L F
.785 .937 .581 r
.5174 .43591 m .51779 .4352 L .51776 .4363 L F
.5174 .43591 m .51776 .4363 L .51764 .44017 L F
0 0 .32 r
.51799 .43855 m .51764 .44017 L .51775 .43647 L F
.51783 .43582 m .51775 .43647 L .51779 .4352 L F
.749 .671 .774 r
.51777 .43633 m .51779 .43633 L .51788 .43538 L F
0 0 0 r
.51799 .43855 m .51906 .4361 L .51837 .43813 L F
.749 .671 .774 r
.51779 .43633 m .51875 .4366 L .51871 .43642 L F
0 0 .32 r
.51887 .43652 m .51865 .43625 L .51906 .4361 L F
.682 .957 .712 r
.5183 .43478 m .51831 .43581 L .51971 .43359 L F
.51779 .4352 m .51792 .43536 L .5183 .43478 L F
.51792 .43536 m .51831 .43581 L .5183 .43478 L F
.51779 .4352 m .51971 .43359 L .51906 .4361 L F
.194 .348 .791 r
.521 .43522 m .51906 .4361 L .5185 .43447 L F
.51893 .43382 m .5185 .43447 L .51808 .43325 L F
.521 .43522 m .5185 .43447 L .51893 .43382 L F
0 0 .32 r
.51865 .43625 m .51779 .4352 L .51842 .43565 L F
.51888 .43617 m .51893 .43601 L .51906 .4361 L F
.194 .348 .791 r
.521 .43522 m .51808 .43325 L .5204 .4327 L F
.52062 .43268 m .5204 .4327 L .52061 .43265 L F
.521 .43522 m .5204 .4327 L .52062 .43268 L F
.543 .537 .799 r
.52329 .43386 m .52061 .43265 L .52332 .43102 L F
.421 .218 .498 r
.52329 .43386 m .52332 .43102 L .52582 .43022 L F
.117 0 0 r
.52582 .43022 m .52332 .43102 L .52117 .43261 L F
.543 .537 .799 r
.52329 .43386 m .521 .43522 L .52061 .43265 L F
.117 0 0 r
.52159 .43256 m .52117 .43261 L .5202 .43333 L F
.52582 .43022 m .52117 .43261 L .52159 .43256 L F
0 0 0 r
.51837 .43813 m .51906 .4361 L .521 .43522 L F
.51993 .4336 m .51837 .43813 L .521 .43522 L F
.156 0 0 r
.5202 .43333 m .52332 .43102 L .52061 .43265 L F
.117 0 0 r
.52582 .43022 m .5202 .43333 L .52458 .43004 L F
.622 .958 .826 r
.52458 .43004 m .5202 .43333 L .52307 .43025 L F
.121 .144 .61 r
.52307 .43025 m .5202 .43333 L .52136 .43447 L F
.499 .904 .808 r
.52152 .43462 m .521 .43522 L .52329 .43386 L F
.52073 .43496 m .52086 .43508 L .52152 .43462 L F
.52086 .43508 m .521 .43522 L .52152 .43462 L F
.51932 .43557 m .52018 .43539 L .52073 .43496 L F
.52018 .43539 m .521 .43522 L .52073 .43496 L F
.51913 .43565 m .5193 .43561 L .51932 .43557 L F
.5193 .43561 m .521 .43522 L .51932 .43557 L F
.51913 .43565 m .52329 .43386 L .52203 .43513 L F
.92 .919 .535 r
.52203 .43513 m .52329 .43386 L .5239 .43154 L F
.52203 .43513 m .52272 .43379 L .52386 .43369 L F
.52272 .43379 m .5239 .43154 L .52387 .433 L F
.117 0 0 r
.52582 .43022 m .5239 .43154 L .52329 .43386 L F
.92 .919 .535 r
.52272 .43379 m .52387 .433 L .52386 .43369 L F
.121 .144 .61 r
.52233 .43373 m .52136 .43447 L .52203 .43513 L F
.52307 .43025 m .52136 .43447 L .52233 .43373 L F
0 0 0 r
.51993 .4336 m .51877 .43656 L .51872 .43675 L F
.51912 .43596 m .51872 .43675 L .51837 .43813 L F
.51993 .4336 m .51872 .43675 L .51912 .43596 L F
.51877 .43656 m .51875 .4366 L .51873 .43668 L F
.51877 .43656 m .51873 .43668 L .51837 .43813 L F
0 0 .32 r
.51865 .43625 m .51842 .43565 L .51893 .43601 L F
.51865 .43625 m .51893 .43601 L .51888 .43617 L F
0 .036 .585 r
.51808 .43325 m .51871 .43642 L .51993 .4336 L F
.51871 .43642 m .51875 .4366 L .51877 .43656 L F
.51871 .43642 m .51877 .43656 L .51993 .4336 L F
0 0 .32 r
.51854 .4363 m .51779 .4352 L .51887 .43652 L F
.749 .671 .774 r
.51792 .43588 m .51871 .43642 L .51832 .43446 L F
.51779 .43633 m .51871 .43642 L .51792 .43588 L F
0 0 .32 r
.5188 .43668 m .51854 .4363 L .51887 .43652 L F
.51799 .43855 m .51788 .43661 L .5188 .43668 L F
.51788 .43661 m .51779 .4352 L .5188 .43668 L F
.687 .188 .054 r
.51837 .43813 m .51841 .43799 L .51743 .43657 L F
.5174 .43657 m .51743 .43657 L .51714 .43615 L F
.51837 .43813 m .51743 .43657 L .5174 .43657 L F
.51841 .43799 m .5186 .43721 L .51792 .43671 L F
0 0 .32 r
.51799 .43855 m .51775 .43647 L .51777 .43633 L F
.51799 .43855 m .51777 .43633 L .51788 .43661 L F
.687 .188 .054 r
.51841 .43799 m .51792 .43671 L .51714 .43615 L F
0 0 .32 r
.51788 .43661 m .51777 .43633 L .51783 .43582 L F
.749 .671 .774 r
.51499 .43556 m .51777 .43633 L .51808 .43325 L F
.51777 .43633 m .51788 .43538 L .51808 .43325 L F
.51779 .43633 m .51832 .43446 L .51808 .43325 L F
.785 .937 .581 r
.51658 .44057 m .51748 .43741 L .51764 .44017 L F
.51437 .4414 m .51748 .43741 L .51658 .44057 L F
.687 .188 .054 r
.5186 .43721 m .51875 .4366 L .51779 .43633 L F
.5186 .43721 m .51779 .43633 L .51714 .43615 L F
.51651 .43671 m .51714 .43615 L .51499 .43556 L F
.51837 .43813 m .51714 .43615 L .51651 .43671 L F
.878 .602 .515 r
.33085 .52518 m .32831 .52507 L .32796 .52163 L F
.319 0 0 r
.61466 .34436 m .61734 .34456 L .61864 .34367 L F
.224 0 0 r
.61864 .34367 m .61734 .34456 L .62109 .34419 L F
0 0 0 r
.5119 .39239 m .51363 .39084 L .51441 .38842 L F
.593 .939 .771 r
.51441 .38842 m .51576 .38677 L .51754 .38618 L F
0 0 0 r
.51441 .38842 m .51554 .38677 L .51576 .38677 L F
.51441 .38842 m .51363 .39084 L .51554 .38677 L F
.50876 .4446 m .51261 .442 L .51103 .44297 L F
.51103 .44297 m .51261 .442 L .51437 .4414 L F
0 0 .102 r
.57107 .3569 m .57177 .35459 L .57186 .35441 L F
.74 .686 .141 r
.57194 .35424 m .57186 .35441 L .57226 .3523 L F
0 0 0 r
.57226 .3523 m .57186 .35441 L .57392 .35085 L F
0 0 .102 r
.57177 .35459 m .57254 .35204 L .57186 .35441 L F
.74 .686 .141 r
.57178 .35525 m .57186 .35441 L .57194 .35424 L F
.921 .977 .729 r
.48695 .51217 m .48552 .51387 L .48482 .51321 L F
.68 .966 .753 r
.48482 .51321 m .48802 .51035 L .48695 .51217 L F
.739 .57 .664 r
.46298 .58066 m .46313 .57814 L .45861 .57828 L F
.496 .886 .96 r
.43526 .44471 m .43429 .44603 L .43222 .44662 L F
.43526 .44471 m .43684 .44512 L .43429 .44603 L F
.875 .977 .842 r
.55667 .4359 m .55388 .43924 L .55393 .43676 L F
.922 .934 .57 r
.55393 .43676 m .55388 .43924 L .55268 .44143 L F
.501 .058 .129 r
.51669 .4183 m .52249 .41738 L .52088 .41646 L F
.13 .272 .743 r
.52088 .41646 m .52249 .41738 L .52321 .41763 L F
.969 .934 .665 r
.52252 .41728 m .5245 .41632 L .52088 .41646 L F
.315 0 0 r
.51845 .4192 m .52167 .41775 L .51669 .4183 L F
.52167 .41775 m .52249 .41738 L .5216 .41752 L F
.52167 .41775 m .5216 .41752 L .51669 .4183 L F
0 0 0 r
.52111 .42156 m .5219 .42007 L .52185 .41837 L F
.5219 .42007 m .52321 .41763 L .52185 .41837 L F
.837 .995 .844 r
.52171 .41628 m .52245 .41732 L .51845 .4192 L F
.52245 .41732 m .52249 .41738 L .52008 .41846 L F
.52245 .41732 m .52008 .41846 L .51845 .4192 L F
0 .371 .801 r
.52321 .41763 m .52249 .41738 L .52171 .41628 L F
.961 .857 .692 r
.52185 .41837 m .52321 .41763 L .52171 .41628 L F
.52185 .41837 m .52185 .41828 L .52185 .4183 L F
.52185 .41837 m .52185 .4183 L .52211 .41968 L F
.52185 .41828 m .52171 .41628 L .522 .41875 L F
.52185 .41828 m .522 .41875 L .52211 .41968 L F
.969 .934 .665 r
.52321 .41763 m .52492 .41631 L .5245 .41632 L F
.52321 .41763 m .5245 .41632 L .52252 .41728 L F
.87 .736 .712 r
.38714 .57808 m .38361 .57761 L .3856 .57422 L F
.842 .688 .692 r
.38734 .58107 m .38361 .57761 L .38714 .57808 L F
.314 .8 .762 r
.43528 .45461 m .43103 .45589 L .43315 .45605 L F
.223 .506 .907 r
.43179 .5702 m .43026 .57183 L .42917 .5701 L F
.43179 .5702 m .43433 .57366 L .43026 .57183 L F
.029 .175 .682 r
.41553 .53719 m .41643 .541 L .41494 .53888 L F
.776 .913 .933 r
.47887 .43193 m .4826 .43121 L .48113 .43005 L F
.716 .821 .93 r
.4826 .43121 m .48395 .42782 L .48113 .43005 L F
.4826 .43121 m .4855 .42964 L .48395 .42782 L F
.428 .204 .47 r
.53221 .4414 m .5299 .43889 L .53056 .44112 L F
.935 .621 .165 r
.69027 .35179 m .69005 .34978 L .6889 .34807 L F
.182 0 0 r
.33589 .67467 m .337 .67535 L .33485 .67601 L F
.33589 .67467 m .33844 .6742 L .337 .67535 L F
.121 .441 .878 r
.30926 .54646 m .31097 .54859 L .30896 .54785 L F
.30926 .54646 m .31097 .54859 L .30896 .54785 L F
.62 .829 .981 r
.27883 .62674 m .28128 .62832 L .28313 .62715 L F
.28313 .62715 m .28128 .62832 L .27883 .62674 L F
.933 .959 .764 r
.43157 .60515 m .43248 .60075 L .42984 .60383 L F
.43157 .60515 m .43375 .60141 L .43248 .60075 L F
.396 .412 .759 r
.28533 .52669 m .28607 .53061 L .2832 .52888 L F
.966 .646 .267 r
.58345 .39305 m .58492 .39623 L .58456 .39448 L F
0 0 .294 r
.58492 .39623 m .58564 .39843 L .58456 .39448 L F
.259 .452 .86 r
.67231 .30634 m .67556 .30773 L .67482 .30975 L F
.122 .289 .761 r
.67556 .30773 m .6772 .31174 L .67482 .30975 L F
.383 .289 .623 r
.52062 .4785 m .52244 .47509 L .52 .47554 L F
.116 0 0 r
.40107 .5208 m .40554 .51849 L .40233 .5182 L F
.40107 .5208 m .40363 .52016 L .40554 .51849 L F
.926 .603 .411 r
.40363 .52016 m .40616 .52154 L .40554 .51849 L F
.96 .903 .72 r
.44964 .55083 m .45095 .55198 L .44816 .55351 L F
.648 .616 .803 r
.5393 .46904 m .5406 .47252 L .5355 .46863 L F
.511 .901 .755 r
.47033 .42495 m .46808 .42642 L .46613 .42713 L F
.982 .704 .33 r
.34308 .57862 m .34171 .57754 L .34153 .57396 L F
.924 .944 .793 r
.34308 .57862 m .34023 .5794 L .34171 .57754 L F
.826 .722 .75 r
.65644 .37093 m .6518 .36992 L .65463 .36871 L F
.5 .833 .999 r
.65612 .36889 m .65644 .37093 L .65483 .36896 L F
.65612 .36889 m .65876 .37026 L .65644 .37093 L F
.642 .739 .92 r
.65969 .36675 m .65876 .37026 L .65612 .36889 L F
.278 .049 .376 r
.6548 .37135 m .65659 .36887 L .65612 .36889 L F
.791 .734 .8 r
.65969 .36675 m .65612 .36889 L .6557 .36621 L F
.278 .049 .376 r
.65659 .36887 m .65795 .36696 L .65612 .36889 L F
.5 .833 .999 r
.65612 .36889 m .65483 .36896 L .65463 .36871 L F
.833 .936 .895 r
.39279 .53048 m .39694 .52977 L .39572 .53021 L F
.333 0 0 r
.39769 .53017 m .39572 .53021 L .39694 .52977 L F
.769 .913 .937 r
.45775 .58677 m .45363 .58714 L .45553 .5886 L F
.45775 .58677 m .45623 .58654 L .45363 .58714 L F
.846 .884 .868 r
.45836 .58311 m .45775 .58677 L .46041 .58427 L F
.45836 .58311 m .45623 .58654 L .45775 .58677 L F
.969 .934 .665 r
.52321 .41763 m .52434 .4182 L .52492 .41631 L F
0 0 0 r
.52111 .42156 m .52434 .4182 L .52321 .41763 L F
.855 .905 .492 r
.40348 .56157 m .4023 .5635 L .40247 .56465 L F
0 0 .462 r
.40352 .56585 m .40247 .56465 L .4023 .5635 L F
.40352 .56585 m .40435 .56788 L .40247 .56465 L F
.609 .929 .965 r
.43248 .60075 m .43375 .60141 L .43597 .60015 L F
.867 .437 .187 r
.33063 .5331 m .33285 .53442 L .33371 .53368 L F
.568 .028 0 r
.42014 .55537 m .42071 .55544 L .42181 .55448 L F
.991 .815 .434 r
.42262 .55378 m .42181 .55448 L .42278 .55544 L F
.907 .573 .096 r
.42181 .55448 m .42324 .55767 L .42278 .55544 L F
.17 .367 .816 r
.42434 .55589 m .42324 .55767 L .42181 .55448 L F
.568 .028 0 r
.42071 .55544 m .42434 .55589 L .42181 .55448 L F
.991 .815 .434 r
.42235 .55118 m .42181 .55448 L .42262 .55378 L F
.686 .919 .972 r
.50687 .39938 m .50277 .39989 L .50567 .39862 L F
.856 .997 .775 r
.50956 .39604 m .50687 .39938 L .50746 .39672 L F
.793 .971 .912 r
.50687 .39938 m .50567 .39862 L .50746 .39672 L F
.206 0 0 r
.50991 .42851 m .51062 .42926 L .50868 .43082 L F
.51077 .42849 m .51257 .42847 L .51062 .42926 L F
.554 .775 .981 r
.51257 .42847 m .5146 .42658 L .51062 .42926 L F
.897 .897 .819 r
.51777 .42433 m .51483 .42645 L .51781 .42433 L F
.51384 .42424 m .51479 .42635 L .51777 .42433 L F
.51479 .42635 m .51483 .42645 L .51777 .42433 L F
.08 0 .237 r
.51547 .42786 m .51601 .42562 L .51781 .42433 L F
.897 .897 .819 r
.51483 .42645 m .51547 .42786 L .51739 .42496 L F
.51483 .42645 m .51739 .42496 L .51781 .42433 L F
.303 .568 .931 r
.51522 .42601 m .51547 .42786 L .51479 .42635 L F
.51522 .42601 m .51479 .42635 L .51384 .42424 L F
.46 .847 .634 r
.51191 .42829 m .51522 .42601 L .51226 .42792 L F
.51062 .42926 m .51352 .42721 L .51127 .42874 L F
.51352 .42721 m .51522 .42601 L .51127 .42874 L F
.554 .775 .981 r
.5146 .42658 m .51352 .42721 L .51062 .42926 L F
.51257 .42847 m .51547 .42786 L .51522 .42601 L F
.953 .771 .62 r
.51226 .42792 m .51522 .42601 L .51384 .42424 L F
.005 0 0 r
.51226 .42792 m .51503 .4271 L .51393 .42815 L F
.51226 .42792 m .51393 .42815 L .51277 .4274 L F
.953 .771 .62 r
.51226 .42792 m .51384 .42424 L .51294 .42531 L F
.554 .775 .981 r
.5146 .42658 m .51522 .42601 L .51352 .42721 L F
.953 .771 .62 r
.51226 .42792 m .51294 .42531 L .51503 .4271 L F
.005 0 0 r
.51226 .42792 m .51277 .4274 L .51105 .42629 L F
.46 .847 .634 r
.51127 .42874 m .51191 .42829 L .51226 .42792 L F
0 0 0 r
.51045 .43008 m .51062 .42926 L .51226 .42792 L F
.50954 .43116 m .51062 .42926 L .51045 .43008 L F
.206 0 0 r
.50991 .42851 m .51077 .42849 L .51062 .42926 L F
.845 .658 .65 r
.30533 .66533 m .30996 .66561 L .308 .66328 L F
.646 .717 .9 r
.30996 .66561 m .31079 .66541 L .308 .66328 L F
.968 .645 .301 r
.42078 .55006 m .42195 .54834 L .42083 .54702 L F
.42078 .55006 m .42235 .55118 L .42195 .54834 L F
0 0 .253 r
.58154 .38005 m .58238 .38275 L .58115 .3787 L F
.186 .306 .755 r
.58238 .38275 m .58384 .38066 L .58115 .3787 L F
0 0 .043 r
.58238 .38275 m .58277 .38359 L .58384 .38066 L F
.58238 .38275 m .5821 .38558 L .58277 .38359 L F
.47 .551 .856 r
.5202 .38431 m .5198 .38129 L .51979 .38283 L F
.861 .445 0 r
.42324 .55767 m .42443 .56052 L .4259 .56173 L F
.982 .831 .619 r
.42443 .56052 m .42533 .56432 L .4259 .56173 L F
.826 .351 0 r
.58831 .36165 m .58532 .35862 L .58844 .35967 L F
.782 .71 .784 r
.52492 .41631 m .52716 .4148 L .52587 .41173 L F
.651 .646 .832 r
.52587 .41173 m .52716 .4148 L .53005 .41239 L F
.918 .643 .506 r
.67722 .33087 m .68049 .32968 L .67701 .32837 L F
.67722 .33087 m .68069 .33268 L .68049 .32968 L F
.896 .923 .83 r
.29224 .68069 m .2891 .68485 L .28826 .68306 L F
0 .347 .824 r
.28826 .68306 m .2891 .68485 L .29188 .68636 L F
.262 0 .241 r
.26579 .55682 m .26497 .55515 L .26706 .55418 L F
.26579 .55682 m .26409 .55771 L .26497 .55515 L F
.529 .569 .84 r
.32106 .57236 m .32393 .57446 L .32089 .57499 L F
0 .208 .728 r
.31897 .5707 m .32149 .57245 L .32106 .57236 L F
0 .359 .82 r
.32245 .57223 m .3214 .57261 L .32153 .57231 L F
.32245 .57223 m .32153 .57231 L .32149 .57245 L F
.32153 .57231 m .3214 .57261 L .32106 .57236 L F
.32153 .57231 m .32106 .57236 L .32149 .57245 L F
0 .208 .728 r
.31897 .5707 m .32089 .57499 L .32149 .57245 L F
.901 .743 .243 r
.32207 .57573 m .32089 .57499 L .32042 .57733 L F
.32207 .57573 m .32204 .57559 L .32089 .57499 L F
.097 0 .022 r
.32393 .57446 m .32207 .57573 L .32042 .57733 L F
.32393 .57446 m .32235 .57575 L .32204 .57559 L F
.32216 .57477 m .32204 .57559 L .32089 .57499 L F
.32335 .57456 m .32204 .57559 L .32216 .57477 L F
.901 .743 .243 r
.32207 .57573 m .32202 .57576 L .32204 .57559 L F
.537 .865 .587 r
.32211 .57567 m .32202 .57576 L .32207 .57573 L F
.097 0 .022 r
.32235 .57575 m .32042 .57733 L .32089 .57499 L F
.901 .743 .243 r
.32202 .57576 m .32138 .57611 L .32204 .57559 L F
.537 .865 .587 r
.32293 .57463 m .32138 .57611 L .32202 .57576 L F
.097 0 .022 r
.32253 .5753 m .32204 .57559 L .32335 .57456 L F
.537 .865 .587 r
.32293 .57463 m .32202 .57576 L .32211 .57567 L F
.097 0 .022 r
.32393 .57446 m .32253 .5753 L .32335 .57456 L F
.901 .743 .243 r
.32204 .57559 m .32149 .57245 L .32089 .57499 L F
.32204 .57559 m .32138 .57611 L .32149 .57245 L F
.979 .799 .387 r
.32149 .57245 m .32138 .57611 L .32075 .57429 L F
.32149 .57245 m .32075 .57429 L .32144 .57263 L F
.477 .791 .999 r
.32205 .57115 m .32245 .57223 L .32149 .57245 L F
.979 .799 .387 r
.32149 .57245 m .32151 .57245 L .322 .57126 L F
.32149 .57245 m .32144 .57263 L .32151 .57245 L F
.784 .511 0 r
.32205 .57115 m .3221 .57135 L .32245 .57223 L F
0 .359 .82 r
.32245 .57223 m .32311 .57386 L .3214 .57261 L F
.784 .511 0 r
.3221 .57135 m .32293 .57463 L .32245 .57223 L F
0 .359 .82 r
.32245 .57223 m .32393 .57446 L .32311 .57386 L F
.979 .799 .387 r
.32196 .57135 m .322 .57126 L .32205 .57115 L F
.32149 .57245 m .322 .57126 L .32196 .57135 L F
.597 .716 .927 r
.41828 .60048 m .41949 .6032 L .4223 .60194 L F
.324 .638 .965 r
.41949 .6032 m .42391 .60496 L .4223 .60194 L F
.536 .232 .398 r
.52508 .40546 m .52167 .40737 L .52196 .40613 L F
0 .302 .687 r
.235 .61422 m .23608 .61472 L .23432 .61376 L F
.898 .978 .807 r
.55728 .42566 m .55468 .4291 L .55397 .42795 L F
.837 .517 0 r
.55397 .42795 m .55468 .4291 L .5552 .43144 L F
0 0 0 r
.51989 .39584 m .5221 .39262 L .52209 .39249 L F
.53 .87 .609 r
.52403 .39078 m .52209 .39249 L .5221 .39262 L F
.893 .475 .183 r
.32417 .51558 m .32277 .51512 L .32149 .51393 L F
.838 .99 .86 r
.47509 .52759 m .47714 .52369 L .47846 .52463 L F
.47509 .52759 m .47421 .52688 L .47714 .52369 L F
.35 .17 .491 r
.24898 .54761 m .25111 .54428 L .24928 .54517 L F
.87 .475 .285 r
.36926 .525 m .3675 .52654 L .36726 .52398 L F
.36926 .525 m .3707 .52795 L .3675 .52654 L F
.909 .641 .519 r
.37848 .53835 m .37606 .53762 L .37624 .53485 L F
.886 .526 .358 r
.37848 .53835 m .3765 .54001 L .37606 .53762 L F
.96 .679 .46 r
.37847 .54104 m .3765 .54001 L .37848 .53835 L F
0 0 .414 r
.66275 .38616 m .66425 .38156 L .66222 .38501 L F
.489 .598 .889 r
.42391 .60496 m .42578 .60289 L .4223 .60194 L F
.381 .431 .788 r
.42391 .60496 m .4266 .60604 L .42578 .60289 L F
0 0 0 r
.41398 .46536 m .41608 .4619 L .41576 .46375 L F
.732 .615 .727 r
.41576 .46375 m .41255 .46759 L .41398 .46536 L F
.906 .515 .093 r
.5938 .40805 m .59541 .40951 L .59385 .40697 L F
.862 .909 .863 r
.59235 .41253 m .59541 .40951 L .5938 .40805 L F
.787 .95 .926 r
.47431 .43356 m .47375 .43623 L .47525 .43445 L F
.775 .941 .934 r
.47229 .43526 m .47375 .43623 L .47431 .43356 L F
.558 .33 .525 r
.38834 .49995 m .38741 .50167 L .39088 .50088 L F
.402 .484 .83 r
.39088 .50088 m .39251 .50036 L .38834 .49995 L F
.597 .065 0 r
.61604 .35149 m .61992 .3491 L .61917 .35015 L F
.885 .842 .798 r
.62299 .3482 m .61917 .35015 L .61992 .3491 L F
.898 .978 .807 r
.55728 .42566 m .55397 .42795 L .55596 .42446 L F
.932 .848 .737 r
.55646 .42192 m .55728 .42566 L .55596 .42446 L F
.757 .794 .883 r
.33342 .63775 m .33488 .64041 L .3308 .64019 L F
.721 .779 .898 r
.33779 .63819 m .33488 .64041 L .33342 .63775 L F
.644 .091 0 r
.38908 .50822 m .39146 .50838 L .38895 .50812 L F
0 0 0 r
.39039 .50397 m .38908 .50822 L .38895 .50812 L F
.985 .753 .502 r
.42901 .58969 m .43097 .58791 L .42909 .58691 L F
.42901 .58969 m .4311 .59111 L .43097 .58791 L F
.552 0 0 r
.43097 .58791 m .42901 .58969 L .42909 .58691 L F
.458 .764 .996 r
.4311 .59111 m .43364 .59027 L .43097 .58791 L F
.552 0 0 r
.43097 .58791 m .43168 .58901 L .42901 .58969 L F
.43097 .58791 m .43364 .59027 L .43168 .58901 L F
.758 .514 .564 r
.34231 .56151 m .33768 .56405 L .33794 .56103 L F
.34231 .56151 m .34211 .56435 L .33768 .56405 L F
.728 .246 .1 r
.32911 .50413 m .33143 .50659 L .33319 .50531 L F
.798 .346 .168 r
.33319 .50531 m .33143 .50659 L .33426 .50703 L F
0 0 0 r
.50956 .39604 m .511 .39431 L .5119 .39239 L F
.5119 .39239 m .51224 .39177 L .51363 .39084 L F
.5119 .39239 m .511 .39431 L .51224 .39177 L F
.319 .185 .537 r
.24506 .55819 m .24696 .55739 L .24688 .55454 L F
.147 .025 .444 r
.24506 .55819 m .24651 .56002 L .24696 .55739 L F
.24506 .55819 m .24504 .56104 L .24651 .56002 L F
.802 .627 .665 r
.35004 .55418 m .35172 .55815 L .35222 .55526 L F
.862 .909 .863 r
.59235 .41253 m .5938 .40805 L .59096 .40888 L F
.985 .753 .503 r
.31399 .55846 m .31342 .56081 L .31204 .558 L F
.601 .929 .962 r
.31399 .55846 m .31464 .55671 L .31608 .55745 L F
.31399 .55846 m .31204 .558 L .31464 .55671 L F
.256 .008 .333 r
.31608 .55745 m .31342 .56081 L .31399 .55846 L F
.731 .983 .906 r
.52533 .49064 m .52977 .48872 L .52876 .48766 L F
.52533 .49064 m .5258 .49114 L .52977 .48872 L F
.877 .687 .641 r
.53251 .4854 m .52876 .48766 L .52977 .48872 L F
.9 .86 .792 r
.48356 .53444 m .48505 .53245 L .48318 .53101 L F
.972 .661 .299 r
.55408 .41796 m .55546 .41944 L .55431 .42036 L F
.864 .42 .129 r
.55431 .42036 m .55546 .41944 L .55646 .42192 L F
.883 .652 .583 r
.33664 .51393 m .33868 .51778 L .33874 .51516 L F
.737 .658 .772 r
.34438 .63751 m .34574 .6418 L .34179 .64074 L F
.492 .441 .728 r
.34709 .63674 m .34574 .6418 L .34438 .63751 L F
.34709 .63674 m .34817 .64208 L .34574 .6418 L F
.371 .61 .942 r
.34817 .64208 m .35014 .6433 L .34574 .6418 L F
.511 .238 .436 r
.50745 .4381 m .51052 .43537 L .5073 .43563 L F
.67 .311 .355 r
.29011 .57694 m .28895 .57996 L .28906 .57806 L F
.784 .955 .63 r
.29011 .57694 m .29178 .57399 L .29238 .57692 L F
.29011 .57694 m .28906 .57806 L .29178 .57399 L F
.095 0 .109 r
.29146 .57819 m .29011 .57694 L .29238 .57692 L F
.29146 .57819 m .28895 .57996 L .29011 .57694 L F
.62 .953 .794 r
.50956 .39604 m .50746 .39672 L .511 .39431 L F
.916 .624 .477 r
.44728 .57361 m .44952 .57097 L .44686 .57023 L F
.44728 .57361 m .45021 .57442 L .44952 .57097 L F
.804 .484 .447 r
.45021 .57442 m .45039 .57693 L .45285 .57464 L F
.846 .552 .491 r
.45039 .57693 m .45283 .57707 L .45285 .57464 L F
.93 .616 .423 r
.42303 .56583 m .42562 .56688 L .42533 .56432 L F
0 .058 .623 r
.4254 .56604 m .42562 .56688 L .42303 .56583 L F
.748 .535 0 r
.42562 .56688 m .42575 .56735 L .42533 .56432 L F
0 .058 .623 r
.42606 .5661 m .42562 .56688 L .4254 .56604 L F
.748 .535 0 r
.42562 .56688 m .42595 .56878 L .42575 .56735 L F
0 .42 .843 r
.42699 .5684 m .42595 .56878 L .42562 .56688 L F
.42699 .5684 m .42917 .5701 L .42595 .56878 L F
.804 .662 .707 r
.53953 .35142 m .54148 .35558 L .54143 .35289 L F
.896 .923 .83 r
.29224 .68069 m .28826 .68306 L .29034 .67941 L F
.697 .842 .952 r
.29382 .67955 m .29224 .68069 L .29034 .67941 L F
.94 .698 .544 r
.66529 .34468 m .6673 .34623 L .66712 .34892 L F
.616 .735 .931 r
.45474 .55743 m .45884 .5584 L .45695 .55668 L F
.787 .844 .895 r
.45884 .5584 m .46019 .55426 L .45695 .55668 L F
.45884 .5584 m .46178 .5558 L .46019 .55426 L F
.519 .517 .793 r
.31696 .51149 m .31868 .50722 L .31825 .50842 L F
.712 .802 .921 r
.31155 .64665 m .30738 .64609 L .31038 .64341 L F
.721 .736 .863 r
.31465 .64401 m .31155 .64665 L .31038 .64341 L F
.223 0 0 r
.51633 .43368 m .51365 .43351 L .51354 .43436 L F
.018 .019 .514 r
.28567 .52407 m .28533 .52669 L .28514 .5247 L F
0 0 0 r
.66425 .38156 m .66779 .37927 L .666 .38007 L F
.585 .939 .787 r
.66963 .37741 m .66779 .37927 L .66984 .37778 L F
.573 .921 .725 r
.666 .38007 m .66779 .37927 L .66963 .37741 L F
.45 .838 .619 r
.3286 .58961 m .32848 .58955 L .32972 .59001 L F
.3286 .58961 m .32647 .59102 L .32848 .58955 L F
0 0 0 r
.27897 .66743 m .27882 .66854 L .28122 .66668 L F
.27897 .66743 m .27804 .67165 L .27882 .66854 L F
.263 0 0 r
.32212 .50561 m .32454 .506 L .32622 .50449 L F
.465 .001 .066 r
.32454 .506 m .32911 .50413 L .32622 .50449 L F
.705 .425 .497 r
.374 .50161 m .37606 .5044 L .37842 .50181 L F
.772 .521 .555 r
.37606 .5044 m .38052 .50525 L .37842 .50181 L F
.701 .608 .749 r
.61716 .38273 m .62098 .38382 L .62002 .38158 L F
.664 .697 .871 r
.62002 .38158 m .62098 .38382 L .62334 .38228 L F
0 0 0 r
.32038 .68366 m .32325 .68065 L .32181 .68297 L F
.187 0 0 r
.32325 .68065 m .32385 .68211 L .32181 .68297 L F
.32325 .68065 m .32557 .68008 L .32385 .68211 L F
.831 .973 .887 r
.54789 .47009 m .5504 .46986 L .55212 .46812 L F
0 0 .024 r
.41576 .46375 m .41608 .4619 L .41654 .4622 L F
0 0 .242 r
.57381 .37771 m .57341 .38015 L .57271 .38016 L F
0 .178 .707 r
.57271 .38016 m .57353 .38186 L .57161 .38018 L F
.976 .68 .307 r
.57271 .38016 m .57431 .38416 L .57353 .38186 L F
.57271 .38016 m .57298 .38277 L .57431 .38416 L F
0 0 .242 r
.57341 .38015 m .57298 .38277 L .57271 .38016 L F
0 .178 .707 r
.57271 .38016 m .57161 .38018 L .57146 .38005 L F
.431 .859 .734 r
.24032 .59457 m .24044 .59429 L .24298 .59331 L F
.23954 .59494 m .24005 .59457 L .24032 .59457 L F
.24005 .59457 m .24044 .59429 L .24032 .59457 L F
.75 .937 .597 r
.23902 .59751 m .239 .59665 L .24075 .59456 L F
.24086 .59456 m .24075 .59456 L .24114 .5941 L F
.23902 .59751 m .24075 .59456 L .24086 .59456 L F
.529 0 0 r
.23902 .59751 m .23987 .59896 L .239 .59665 L F
.873 .815 .789 r
.55417 .37917 m .55369 .38148 L .55653 .37845 L F
.478 .674 .951 r
.308 .66328 m .31079 .66541 L .31134 .66309 L F
.877 .687 .641 r
.53251 .4854 m .52849 .48789 L .52876 .48766 L F
.795 .999 .842 r
.53251 .4854 m .5362 .48199 L .53335 .48305 L F
.812 .919 .91 r
.52392 .48946 m .52533 .49064 L .52876 .48766 L F
.52392 .48946 m .52876 .48766 L .52744 .48671 L F
.52699 .48675 m .52744 .48671 L .52722 .48655 L F
.52392 .48946 m .52744 .48671 L .52699 .48675 L F
.932 .948 .776 r
.52876 .48766 m .52851 .48509 L .52722 .48655 L F
.52876 .48766 m .52849 .48789 L .52851 .48509 L F
.837 .895 .881 r
.52851 .48509 m .5285 .48661 L .53335 .48305 L F
.5285 .48661 m .52849 .48789 L .52991 .48648 L F
.5285 .48661 m .52991 .48648 L .53335 .48305 L F
.798 1 .827 r
.53335 .48305 m .52849 .48789 L .53251 .4854 L F
.851 .844 .837 r
.3074 .61386 m .30964 .61556 L .30656 .61807 L F
.764 .845 .913 r
.31143 .61388 m .30964 .61556 L .3074 .61386 L F
.882 .872 .822 r
.48829 .5242 m .49277 .52219 L .49133 .52121 L F
.48829 .5242 m .49011 .52568 L .49277 .52219 L F
.868 .943 .864 r
.49275 .51926 m .49277 .52219 L .49553 .51907 L F
.879 .948 .852 r
.49275 .51926 m .49133 .52121 L .49277 .52219 L F
.433 .236 .511 r
.62996 .37934 m .63272 .38138 L .63264 .37816 L F
.826 .966 .895 r
.49372 .50375 m .49224 .50561 L .49263 .50314 L F
.891 .958 .619 r
.49224 .50561 m .49066 .50681 L .49263 .50314 L F
.925 .62 .446 r
.68319 .341 m .68588 .33981 L .683 .33813 L F
.68319 .341 m .68617 .34211 L .68588 .33981 L F
.776 .752 .831 r
.34273 .61434 m .34693 .61489 L .34588 .61389 L F
.645 .605 .795 r
.34693 .61489 m .34798 .61041 L .34588 .61389 L F
.34693 .61489 m .34942 .61375 L .34798 .61041 L F
.873 .855 .821 r
.60438 .38933 m .60095 .39003 L .60142 .3886 L F
.093 0 .303 r
.60142 .3886 m .60157 .38897 L .60231 .38699 L F
.873 .855 .821 r
.60438 .38933 m .60165 .39243 L .60104 .39036 L F
.60438 .38933 m .60104 .39036 L .60119 .38998 L F
.093 0 .303 r
.60157 .38897 m .60218 .39042 L .60231 .38702 L F
.60157 .38897 m .60231 .38702 L .60231 .38699 L F
.873 .855 .821 r
.60119 .38998 m .60104 .39036 L .60095 .39003 L F
.604 .564 .783 r
.66007 .39232 m .65833 .39404 L .65589 .38886 L F
0 0 0 r
.65716 .39542 m .65833 .39404 L .66007 .39232 L F
.822 .5 .445 r
.4051 .52673 m .4074 .52398 L .40505 .52417 L F
.4051 .52673 m .40884 .52769 L .4074 .52398 L F
.891 .764 .715 r
.34798 .55035 m .3501 .55148 L .34865 .54763 L F
.917 .713 .613 r
.34798 .55035 m .35004 .55418 L .3501 .55148 L F
.509 .881 .976 r
.66284 .36988 m .65876 .37026 L .66156 .36873 L F
.907 .933 .817 r
.66287 .36676 m .66284 .36988 L .66156 .36873 L F
.383 .289 .623 r
.52062 .4785 m .52315 .47775 L .52244 .47509 L F
0 0 .408 r
.52062 .4785 m .52193 .47969 L .52315 .47775 L F
.52062 .4785 m .52097 .48103 L .52193 .47969 L F
.673 .971 .911 r
.44061 .45063 m .44514 .44902 L .44296 .44956 L F
.444 .874 .783 r
.44296 .44956 m .44514 .44902 L .44761 .44772 L F
.135 .049 .485 r
.34633 .65538 m .34495 .65662 L .34482 .65398 L F
.34713 .65612 m .34585 .65641 L .34633 .65538 L F
.34585 .65641 m .34495 .65662 L .34633 .65538 L F
.778 .797 .869 r
.3456 .65695 m .34896 .65784 L .34627 .6605 L F
.34546 .65625 m .34584 .65642 L .3456 .65695 L F
.34584 .65642 m .34896 .65784 L .3456 .65695 L F
.235 .664 .958 r
.34546 .65625 m .34495 .65662 L .34599 .65638 L F
.888 .534 .368 r
.34918 .6572 m .34584 .65634 L .34913 .65584 L F
.34584 .65634 m .34546 .65625 L .34591 .65619 L F
.34584 .65634 m .34591 .65619 L .34913 .65584 L F
.135 .049 .485 r
.34734 .65349 m .34482 .65398 L .34739 .65293 L F
0 0 0 r
.34713 .65612 m .34913 .65584 L .34546 .65625 L F
.135 .049 .485 r
.34713 .65612 m .34634 .65539 L .34734 .65349 L F
.34634 .65539 m .34482 .65398 L .34734 .65349 L F
.235 .664 .958 r
.34546 .65625 m .34599 .65638 L .34713 .65612 L F
.397 .191 .479 r
.34627 .6605 m .34896 .65784 L .34929 .65995 L F
.888 .534 .368 r
.34929 .65995 m .34896 .65784 L .34546 .65625 L F
.34929 .65995 m .34546 .65625 L .34918 .6572 L F
.778 .797 .869 r
.34546 .65625 m .34627 .6605 L .34495 .65662 L F
.007 0 .351 r
.34929 .65995 m .34825 .6631 L .34627 .6605 L F
.223 .737 .708 r
.65013 .38373 m .64881 .38248 L .65137 .38207 L F
.953 .701 .519 r
.37363 .52837 m .37126 .53002 L .3707 .52795 L F
.37363 .52837 m .37331 .53105 L .37126 .53002 L F
.188 0 .355 r
.27543 .54381 m .27274 .54763 L .27327 .54495 L F
.597 .922 .692 r
.67951 .37178 m .68125 .36978 L .67901 .37142 L F
.67951 .37178 m .68271 .36909 L .68125 .36978 L F
.739 .57 .664 r
.46298 .58066 m .45861 .57828 L .45889 .58043 L F
.834 .708 .726 r
.46041 .58427 m .46298 .58066 L .45889 .58043 L F
.388 .203 .504 r
.25013 .53885 m .25276 .53817 L .25202 .53427 L F
.364 .161 .466 r
.25202 .53427 m .25499 .53374 L .25549 .53093 L F
.397 .209 .505 r
.25202 .53427 m .25495 .53634 L .25499 .53374 L F
.25202 .53427 m .25276 .53817 L .25495 .53634 L F
.653 .327 .408 r
.23611 .61018 m .23896 .60756 L .23682 .60687 L F
.23611 .61018 m .23985 .60998 L .23896 .60756 L F
.935 .69 .542 r
.31131 .67044 m .31142 .67387 L .30925 .67285 L F
.30925 .67285 m .31142 .67387 L .31131 .67044 L F
.844 .913 .882 r
.47774 .53823 m .48107 .53745 L .47973 .53636 L F
.886 .939 .845 r
.47973 .53636 m .48107 .53745 L .48356 .53444 L F
.923 .935 .795 r
.55546 .43467 m .55667 .4359 L .55393 .43676 L F
.806 .971 .905 r
.51647 .49797 m .51904 .49399 L .51554 .49675 L F
.51647 .49797 m .52023 .49475 L .51904 .49399 L F
0 .053 .617 r
.57271 .42212 m .57037 .41842 L .57127 .42058 L F
.988 .815 .583 r
.5705 .42451 m .57271 .42212 L .57127 .42058 L F
.5705 .42451 m .57199 .42575 L .57271 .42212 L F
.737 .986 .896 r
.28959 .66761 m .28488 .66983 L .28767 .66702 L F
.562 .184 .282 r
.66322 .32793 m .66601 .32806 L .66321 .32636 L F
.468 .268 .525 r
.66321 .32636 m .66601 .32806 L .66593 .32549 L F
.313 .51 .889 r
.39673 .59144 m .39789 .5896 L .39479 .59043 L F
.39673 .59144 m .39975 .59188 L .39789 .5896 L F
.61 .307 .431 r
.37611 .46546 m .37624 .46823 L .37855 .46776 L F
.573 .314 .485 r
.37611 .46546 m .37855 .46776 L .37897 .4652 L F
0 0 0 r
.55837 .39924 m .55955 .39957 L .561 .3989 L F
.55837 .39924 m .55801 .4009 L .55955 .39957 L F
.685 .78 .923 r
.31672 .58791 m .31313 .58777 L .31422 .58657 L F
.491 .09 .208 r
.31672 .58791 m .31257 .59032 L .31313 .58777 L F
.31672 .58791 m .31481 .59033 L .31257 .59032 L F
.842 .737 .748 r
.31731 .58475 m .31672 .58791 L .31422 .58657 L F
.443 .038 .175 r
.31873 .58921 m .31481 .59033 L .31672 .58791 L F
.464 .019 .104 r
.31987 .5879 m .31873 .58921 L .31672 .58791 L F
.444 .312 .606 r
.26181 .5256 m .26173 .52488 L .25977 .52384 L F
.26181 .5256 m .26441 .52629 L .26173 .52488 L F
.78 .663 .734 r
.34798 .61041 m .35314 .61253 L .35284 .60842 L F
.776 .667 .744 r
.34942 .61375 m .35314 .61253 L .34798 .61041 L F
.858 .861 .842 r
.28148 .64281 m .28076 .64473 L .27909 .6433 L F
.52 0 0 r
.27909 .6433 m .28076 .64473 L .28273 .6466 L F
0 0 0 r
.40573 .55459 m .40502 .55659 L .40445 .5577 L F
0 0 .446 r
.40502 .55659 m .40588 .56093 L .40445 .5577 L F
.408 .212 .5 r
.40445 .5577 m .40588 .56093 L .40348 .56157 L F
.929 .967 .763 r
.43683 .57092 m .43433 .57366 L .43616 .57066 L F
.43683 .57092 m .43456 .57466 L .43433 .57366 L F
.891 .968 .65 r
.43683 .57092 m .43828 .56683 L .43909 .56592 L F
.43683 .57092 m .43616 .57066 L .43828 .56683 L F
.842 .688 .692 r
.38734 .58107 m .38291 .58035 L .38361 .57761 L F
.867 .625 .57 r
.38492 .58305 m .38291 .58035 L .38734 .58107 L F
.851 .637 .613 r
.38734 .58107 m .38864 .58442 L .38492 .58305 L F
.828 .686 .705 r
.32509 .55863 m .3245 .56146 L .3233 .55729 L F
.654 .857 .977 r
.53264 .35977 m .53643 .35994 L .53443 .35815 L F
.789 .778 .843 r
.53443 .35815 m .53643 .35994 L .53781 .35851 L F
.791 .669 .73 r
.35205 .59422 m .35633 .59694 L .35637 .59468 L F
.35205 .59422 m .35156 .5971 L .35633 .59694 L F
.79 .689 .754 r
.35156 .5971 m .35336 .60056 L .35633 .59694 L F
.224 .743 .84 r
.60895 .34999 m .60848 .3498 L .60507 .35011 L F
.60848 .3498 m .60748 .34974 L .60507 .35011 L F
.485 .83 .998 r
.60809 .34964 m .60388 .34937 L .60507 .35011 L F
.60388 .34937 m .60382 .34936 L .60384 .34937 L F
.60388 .34937 m .60384 .34937 L .60507 .35011 L F
.60809 .34964 m .60641 .34882 L .60382 .34936 L F
.572 .563 .805 r
.60636 .34905 m .60798 .35296 L .60523 .35368 L F
.60641 .34882 m .60649 .34903 L .60636 .34905 L F
.60649 .34903 m .60798 .35296 L .60636 .34905 L F
.60594 .34964 m .60523 .35368 L .60451 .35209 L F
.60641 .34882 m .60621 .34965 L .60594 .34964 L F
.60621 .34965 m .60523 .35368 L .60594 .34964 L F
.224 .743 .84 r
.60848 .3498 m .60809 .34964 L .60748 .34974 L F
0 .491 .748 r
.60895 .34999 m .61215 .35055 L .60809 .34964 L F
.48 .868 .674 r
.44465 .44028 m .44653 .43929 L .44299 .44164 L F
.561 .909 .695 r
.44855 .4376 m .44653 .43929 L .44465 .44028 L F
.107 .629 .882 r
.35537 .49168 m .35734 .4918 L .35317 .49105 L F
.721 .272 .186 r
.65438 .39921 m .65478 .40076 L .65141 .40046 L F
0 .266 .652 r
.65803 .40112 m .65775 .40092 L .65685 .40046 L F
.65751 .40085 m .65685 .40046 L .65438 .39921 L F
.65803 .40112 m .65685 .40046 L .65751 .40085 L F
.559 .165 .25 r
.65438 .39921 m .65775 .40092 L .65478 .40076 L F
.378 .745 .991 r
.65478 .40076 m .65619 .40008 L .65356 .40069 L F
.65619 .40008 m .65682 .39977 L .65604 .39999 L F
.65619 .40008 m .65604 .39999 L .65356 .40069 L F
.597 .928 .962 r
.65803 .40112 m .65964 .39914 L .65775 .40092 L F
.65803 .40112 m .66175 .39957 L .65964 .39914 L F
.925 .948 .789 r
.57278 .40417 m .57401 .39973 L .57218 .4044 L F
0 0 .003 r
.57376 .40233 m .57218 .4044 L .57401 .39973 L F
.627 .92 .65 r
.57129 .40475 m .57218 .4044 L .57376 .40233 L F
.57055 .40547 m .57218 .4044 L .57129 .40475 L F
.925 .948 .789 r
.57259 .40487 m .57278 .40417 L .57218 .4044 L F
.897 .718 .652 r
.38767 .57063 m .38428 .57034 L .38564 .56728 L F
.891 .769 .72 r
.38767 .57063 m .3856 .57422 L .38428 .57034 L F
.169 0 0 r
.5851 .35171 m .58818 .3508 L .5887 .34924 L F
.609 .711 .917 r
.44561 .59408 m .44659 .59024 L .44396 .59318 L F
.44561 .59408 m .44824 .59327 L .44659 .59024 L F
.913 .634 .5 r
.3391 .52278 m .34306 .52205 L .3388 .52025 L F
.3391 .52278 m .34236 .52426 L .34306 .52205 L F
.89 .604 .496 r
.34306 .52205 m .34236 .52426 L .34445 .52478 L F
.001 .578 .716 r
.39802 .58125 m .39715 .58123 L .39374 .5812 L F
.39802 .58125 m .39715 .58123 L .39374 .5812 L F
.937 .945 .609 r
.39772 .57911 m .39715 .58123 L .39802 .58125 L F
.39802 .58125 m .39715 .58123 L .39772 .57911 L F
.39772 .57911 m .39715 .58123 L .39802 .58125 L F
.458 .764 .996 r
.4311 .59111 m .43515 .59176 L .43364 .59027 L F
0 0 .025 r
.4311 .59111 m .43194 .5918 L .43515 .59176 L F
.952 .882 .728 r
.43515 .59176 m .43194 .5918 L .43364 .59027 L F
.272 .027 .348 r
.41892 .59785 m .41621 .60093 L .41828 .60048 L F
.075 0 0 r
.62405 .34344 m .62817 .34227 L .62539 .34258 L F
.739 .859 .428 r
.39073 .52412 m .39082 .5235 L .39234 .52113 L F
.39073 .52412 m .39082 .5235 L .39234 .52113 L F
.868 .735 .713 r
.34735 .56027 m .35149 .5613 L .35172 .55815 L F
.892 .723 .665 r
.34697 .56341 m .35149 .5613 L .34735 .56027 L F
.34697 .56341 m .3489 .56361 L .35149 .5613 L F
.84 .468 .348 r
.38864 .58442 m .38706 .58643 L .38492 .58305 L F
.888 .609 .509 r
.32796 .52163 m .32494 .52346 L .32625 .52037 L F
.32796 .52163 m .32831 .52507 L .32494 .52346 L F
.888 .853 .803 r
.48356 .53444 m .48318 .53101 L .48174 .53355 L F
.886 .939 .845 r
.47973 .53636 m .48356 .53444 L .48174 .53355 L F
.906 .784 .716 r
.33935 .55874 m .33794 .56103 L .33675 .55735 L F
.197 .474 .89 r
.32301 .59614 m .32227 .5978 L .3239 .59751 L F
.954 .782 .631 r
.32227 .5978 m .32497 .60047 L .3239 .59751 L F
.799 .468 .427 r
.36975 .50085 m .37203 .50365 L .374 .50161 L F
.771 .426 .402 r
.37203 .50365 m .37606 .5044 L .374 .50161 L F
.32 0 0 r
.29444 .68542 m .29666 .6852 L .2988 .6859 L F
.551 .557 .813 r
.59626 .37635 m .5989 .37476 L .5989 .37391 L F
.59841 .37388 m .5989 .37391 L .59889 .37332 L F
.59626 .37635 m .5989 .37391 L .59841 .37388 L F
.142 .686 .731 r
.59611 .37373 m .59989 .37324 L .59702 .37304 L F
.59603 .37379 m .59636 .37375 L .59611 .37373 L F
.59636 .37375 m .59989 .37324 L .59611 .37373 L F
.027 .585 .812 r
.64767 .39836 m .64383 .39776 L .6454 .39807 L F
0 0 .007 r
.54175 .45125 m .54232 .44906 L .54347 .44747 L F
.742 .707 .819 r
.35528 .58381 m .35579 .58072 L .35314 .58408 L F
.781 .604 .66 r
.35314 .58408 m .35701 .58719 L .35528 .58381 L F
.214 .72 .9 r
.63418 .39878 m .63302 .39839 L .63027 .39853 L F
.323 .793 .929 r
.63703 .39834 m .63302 .39839 L .63418 .39878 L F
.678 .397 .489 r
.40673 .46596 m .40748 .4653 L .4076 .46777 L F
.668 .911 .586 r
.60284 .37361 m .60136 .37592 L .60422 .37249 L F
.64 .914 .98 r
.60284 .37361 m .5989 .37476 L .60136 .37592 L F
0 .098 .622 r
.38516 .46988 m .38413 .47231 L .38596 .47296 L F
.775 .428 .398 r
.45477 .5799 m .45861 .57828 L .45458 .57786 L F
.45477 .5799 m .45889 .58043 L .45861 .57828 L F
.008 .044 .549 r
.58376 .36667 m .58166 .36632 L .58355 .36397 L F
.58376 .36667 m .58229 .36879 L .58166 .36632 L F
.377 .141 .423 r
.53811 .43221 m .53794 .43495 L .53535 .43538 L F
.301 0 .188 r
.53535 .43538 m .53794 .43495 L .53848 .43616 L F
.972 .913 .688 r
.66562 .35502 m .66673 .35621 L .66563 .35837 L F
0 0 0 r
.61918 .39117 m .61514 .39479 L .61808 .39413 L F
.528 0 0 r
.6197 .39253 m .61918 .39117 L .61808 .39413 L F
.678 .977 .884 r
.44299 .44164 m .43878 .44345 L .44238 .44166 L F
.499 .901 .783 r
.44299 .44164 m .44238 .44166 L .44465 .44028 L F
.881 .778 .743 r
.36767 .47165 m .3689 .47503 L .36615 .47474 L F
.29 .627 .962 r
.3689 .47503 m .36895 .47347 L .36615 .47474 L F
.3689 .47503 m .37126 .47558 L .36895 .47347 L F
0 0 0 r
.38355 .50418 m .38582 .50322 L .38741 .50167 L F
.707 .548 .671 r
.38299 .50605 m .38582 .50322 L .38355 .50418 L F
.635 .599 .796 r
.55661 .37531 m .5613 .37855 L .55934 .37513 L F
.127 .09 .543 r
.5613 .37855 m .56209 .37549 L .55934 .37513 L F
.5613 .37855 m .56222 .37807 L .56209 .37549 L F
0 0 0 r
.56054 .38067 m .56222 .37807 L .5613 .37855 L F
.704 .775 .908 r
.54676 .34874 m .55087 .3494 L .54981 .3473 L F
.54981 .3473 m .55087 .3494 L .54676 .34874 L F
.435 .624 .932 r
.55226 .34705 m .55087 .3494 L .54981 .3473 L F
.55226 .34705 m .55087 .3494 L .54981 .3473 L F
0 0 .08 r
.29804 .67316 m .29801 .67207 L .29753 .6748 L F
.741 .274 .139 r
.29797 .67058 m .30018 .67063 L .29801 .67207 L F
.972 .696 .448 r
.30072 .66929 m .29783 .67058 L .30018 .67063 L F
.685 .946 .674 r
.30072 .66929 m .30018 .67063 L .29801 .67207 L F
.747 .98 .738 r
.30072 .66929 m .29999 .67004 L .29901 .67011 L F
.29999 .67004 m .29801 .67207 L .29901 .67011 L F
0 0 .08 r
.29901 .67011 m .29801 .67207 L .29804 .67316 L F
.399 .301 .627 r
.30072 .66929 m .29783 .67058 L .30025 .66613 L F
.972 .696 .448 r
.30072 .66929 m .30025 .66613 L .29783 .67058 L F
.409 .861 .839 r
.29578 .67071 m .29783 .67058 L .30072 .66929 L F
0 0 .08 r
.29901 .67011 m .29753 .6748 L .29979 .67343 L F
0 0 .495 r
.29901 .67011 m .29979 .67343 L .30016 .67354 L F
.29989 .67215 m .30016 .67354 L .30055 .67366 L F
.29901 .67011 m .29991 .6728 L .29989 .67215 L F
.29901 .67011 m .30055 .67366 L .30139 .67047 L F
.171 0 0 r
.29901 .67011 m .30139 .67047 L .29836 .67016 L F
.893 .988 .784 r
.30046 .66991 m .30139 .67047 L .30004 .67131 L F
.30013 .6703 m .30004 .67131 L .29846 .67229 L F
.30046 .66991 m .30004 .67131 L .30013 .6703 L F
0 0 .495 r
.29991 .6728 m .30016 .67354 L .29994 .67242 L F
.29991 .6728 m .29994 .67242 L .29989 .67215 L F
.972 .696 .448 r
.30072 .66929 m .30283 .66763 L .30025 .66613 L F
.525 .86 .587 r
.30533 .66533 m .30283 .66763 L .30072 .66929 L F
.30533 .66533 m .30072 .66929 L .30336 .6686 L F
.084 0 0 r
.30025 .66613 m .30171 .66418 L .30411 .66281 L F
.30025 .66613 m .30411 .66281 L .30049 .66357 L F
.30009 .6641 m .30049 .66357 L .30006 .66367 L F
.30025 .66613 m .30049 .66357 L .30009 .6641 L F
.719 .623 .749 r
.30475 .66171 m .30411 .66281 L .3018 .66168 L F
.30475 .66171 m .3007 .6634 L .30411 .66281 L F
.3007 .6634 m .30006 .66367 L .30049 .66357 L F
.3007 .6634 m .30049 .66357 L .30411 .66281 L F
.575 .328 .504 r
.3018 .66168 m .30475 .66171 L .30509 .65861 L F
.323 .743 .976 r
.30311 .66076 m .30475 .66171 L .3018 .66168 L F
.30311 .66076 m .30215 .66143 L .3013 .6629 L F
.802 .685 .736 r
.30533 .66533 m .308 .66328 L .30411 .66281 L F
.672 .188 .093 r
.30582 .66814 m .30533 .66533 L .30336 .6686 L F
.3057 .66744 m .30789 .66679 L .30533 .66533 L F
.30582 .66814 m .30654 .66767 L .3057 .66744 L F
.30654 .66767 m .30789 .66679 L .3057 .66744 L F
.458 .302 .58 r
.3062 .66538 m .30463 .66716 L .30026 .66397 L F
.30463 .66716 m .30336 .6686 L .3019 .66642 L F
.30463 .66716 m .3019 .66642 L .30026 .66397 L F
.30042 .66377 m .30026 .66397 L .30006 .66367 L F
.3062 .66538 m .30026 .66397 L .30042 .66377 L F
.323 .743 .976 r
.30215 .66143 m .30152 .66225 L .30135 .6626 L F
.667 .18 .084 r
.30411 .66281 m .308 .66328 L .3062 .66538 L F
0 .015 .587 r
.30411 .66281 m .3062 .66538 L .30475 .66171 L F
.719 .623 .749 r
.30475 .66171 m .3062 .66538 L .30006 .66367 L F
.323 .743 .976 r
.30181 .66201 m .30135 .6626 L .30072 .66389 L F
.30215 .66143 m .30135 .6626 L .30181 .66201 L F
.3018 .66248 m .3013 .6629 L .30072 .66389 L F
.30311 .66076 m .3013 .6629 L .3018 .66248 L F
.30215 .66143 m .3018 .66168 L .30152 .66225 L F
.616 .621 .833 r
.30006 .66367 m .30072 .66929 L .30025 .66613 L F
.409 .861 .839 r
.29578 .67071 m .30072 .66929 L .29901 .67011 L F
.616 .621 .833 r
.30006 .66367 m .30336 .6686 L .30072 .66929 L F
.777 .683 .76 r
.29907 .6679 m .30139 .67047 L .30027 .66661 L F
.262 .763 .889 r
.2971 .67003 m .29578 .67071 L .29611 .67065 L F
.2971 .67003 m .29611 .67065 L .29901 .67011 L F
.744 .971 .704 r
.2971 .67003 m .30027 .66661 L .29932 .66682 L F
0 0 .564 r
.29779 .66852 m .29796 .66949 L .2971 .67003 L F
.171 0 0 r
.29901 .67011 m .29836 .67016 L .2971 .67003 L F
.777 .683 .76 r
.2971 .67003 m .29953 .67028 L .29907 .6679 L F
0 0 .564 r
.29796 .66949 m .29811 .67032 L .2971 .67003 L F
.741 .274 .139 r
.29783 .67058 m .29797 .67058 L .29801 .67207 L F
.849 .39 .091 r
.29801 .67207 m .29783 .67058 L .29578 .67071 L F
0 0 .564 r
.29811 .67032 m .29846 .67229 L .2971 .67003 L F
.777 .683 .76 r
.29953 .67028 m .30139 .67047 L .29907 .6679 L F
.767 .673 .759 r
.31288 .62094 m .3163 .62335 L .3155 .61997 L F
.31288 .62094 m .31488 .62487 L .3163 .62335 L F
.704 .709 .852 r
.3155 .61997 m .3163 .62335 L .31973 .62077 L F
.33 .073 .364 r
.29528 .58531 m .29508 .58772 L .29717 .58651 L F
.627 .806 .969 r
.62355 .39938 m .62795 .40014 L .62632 .39827 L F
.731 .827 .924 r
.62632 .39827 m .62795 .40014 L .63027 .39853 L F
.669 .964 .932 r
.38422 .49657 m .38225 .49806 L .38331 .49841 L F
.38422 .49657 m .38225 .49806 L .38331 .49841 L F
.793 .519 .522 r
.66871 .32474 m .6724 .32283 L .66924 .32271 L F
.66871 .32474 m .67254 .32546 L .6724 .32283 L F
.863 .958 .616 r
.50004 .49517 m .49781 .49892 L .49836 .49661 L F
.766 .996 .822 r
.50296 .49238 m .50004 .49517 L .5009 .49309 L F
.761 .944 .612 r
.5009 .49309 m .50004 .49517 L .49836 .49661 L F
.776 .658 .732 r
.3233 .55729 m .3245 .56146 L .32018 .56077 L F
.704 .5 .61 r
.32325 .56251 m .32018 .56077 L .3245 .56146 L F
0 0 0 r
.326 .56138 m .32325 .56251 L .3245 .56146 L F
.019 .591 .752 r
.3245 .56146 m .3276 .56154 L .326 .56138 L F
.81 .656 .692 r
.35436 .5741 m .35433 .57706 L .35821 .57758 L F
.811 .646 .678 r
.35433 .57706 m .35579 .58072 L .35821 .57758 L F
.892 .982 .811 r
.53593 .47975 m .5362 .48199 L .53719 .4803 L F
.89 .981 .815 r
.53335 .48305 m .5362 .48199 L .53593 .47975 L F
.493 .9 .796 r
.281 .53563 m .27756 .53712 L .27744 .53717 L F
.281 .53563 m .27863 .53627 L .27756 .53712 L F
.432 0 0 r
.28278 .53663 m .27863 .53627 L .281 .53563 L F
.367 0 .15 r
.2839 .53494 m .28278 .53663 L .281 .53563 L F
.935 .573 .168 r
.59367 .36083 m .59442 .35931 L .59537 .35692 L F
.59367 .36083 m .59512 .36228 L .59442 .35931 L F
0 0 0 r
.60165 .39243 m .60437 .39168 L .60342 .39252 L F
.60165 .39243 m .60342 .39252 L .60095 .39003 L F
.561 .873 .994 r
.32036 .558 m .32107 .55622 L .3233 .55729 L F
.776 .658 .732 r
.3233 .55729 m .32018 .56077 L .32036 .558 L F
0 0 .277 r
.32018 .56077 m .32044 .55943 L .32027 .55933 L F
.32018 .56077 m .32109 .55953 L .32107 .55622 L F
.474 .868 .969 r
.32018 .56077 m .31843 .56025 L .32109 .55953 L F
0 0 0 r
.31843 .56025 m .31898 .5606 L .32085 .55965 L F
.32078 .55961 m .32085 .55965 L .32109 .55953 L F
.31843 .56025 m .32085 .55965 L .32078 .55961 L F
0 0 .277 r
.32027 .55933 m .32107 .55622 L .32036 .558 L F
.32044 .55943 m .32107 .55622 L .32027 .55933 L F
.394 .094 .334 r
.258 .52782 m .25974 .52932 L .26181 .5256 L F
.397 0 .159 r
.25974 .52932 m .26441 .52629 L .26181 .5256 L F
.065 0 0 r
.51891 .40875 m .51697 .40946 L .51454 .40969 L F
.332 .801 .707 r
.52082 .4078 m .51891 .40875 L .52167 .40737 L F
.52082 .4078 m .51697 .40946 L .51891 .40875 L F
.338 .434 .813 r
.62846 .38555 m .63147 .38858 L .63006 .38454 L F
.965 .652 .375 r
.33426 .50703 m .33464 .5108 L .33686 .51205 L F
.975 .689 .419 r
.33469 .51237 m .33686 .51205 L .33464 .5108 L F
.33469 .51237 m .33664 .51393 L .33686 .51205 L F
0 .162 .696 r
.32787 .55668 m .32622 .55603 L .32548 .55399 L F
.32852 .55808 m .3293 .55976 L .32775 .55794 L F
.3293 .55976 m .3294 .55998 L .32929 .55984 L F
.3293 .55976 m .32929 .55984 L .32775 .55794 L F
.745 .658 .764 r
.33166 .55695 m .3294 .55998 L .32787 .55668 L F
.092 0 0 r
.3291 .55819 m .32946 .55825 L .33166 .55695 L F
0 .162 .696 r
.32787 .55668 m .32852 .55808 L .32622 .55603 L F
.32852 .55808 m .32775 .55794 L .32622 .55603 L F
.092 0 0 r
.32768 .55888 m .33166 .55695 L .32787 .55668 L F
.847 .998 .794 r
.33166 .55695 m .32946 .55825 L .33198 .55497 L F
.092 0 0 r
.32768 .55888 m .32946 .55825 L .3291 .55819 L F
.847 .998 .794 r
.32946 .55825 m .32845 .55885 L .32952 .55768 L F
.32946 .55825 m .32952 .55768 L .33198 .55497 L F
.092 0 0 r
.32768 .55888 m .32845 .55885 L .32946 .55825 L F
.644 .091 0 r
.38908 .50822 m .38964 .50916 L .39146 .50838 L F
.301 0 0 r
.39146 .50838 m .38964 .50916 L .39448 .50925 L F
.875 .625 .558 r
.38504 .55781 m .38715 .56162 L .38481 .56035 L F
.902 .792 .729 r
.38715 .56162 m .38354 .56349 L .38481 .56035 L F
.38715 .56162 m .38621 .56438 L .38354 .56349 L F
.199 .314 .757 r
.24475 .57446 m .245 .57042 L .24333 .57056 L F
.24475 .57446 m .24635 .57458 L .245 .57042 L F
.214 .247 .68 r
.24475 .57446 m .24839 .57782 L .24635 .57458 L F
.843 .514 0 r
.56457 .39227 m .56425 .39342 L .5628 .39018 L F
.56457 .39227 m .56489 .39445 L .56425 .39342 L F
.719 .839 .938 r
.32422 .64085 m .32125 .64285 L .32006 .64085 L F
.743 .908 .531 r
.43909 .56592 m .43828 .56683 L .43984 .56483 L F
.702 .362 .398 r
.43828 .56683 m .4424 .56475 L .43984 .56483 L F
.43828 .56683 m .442 .56701 L .4424 .56475 L F
.426 .699 .978 r
.44354 .56285 m .4452 .5644 L .4424 .56475 L F
.44354 .56285 m .4452 .5644 L .4424 .56475 L F
.374 .072 .319 r
.4424 .56475 m .442 .56701 L .4452 .5644 L F
.4424 .56475 m .442 .56701 L .4452 .5644 L F
.504 .848 .995 r
.29718 .62031 m .29271 .62086 L .29518 .62034 L F
0 0 0 r
.29242 .62432 m .29718 .62031 L .29518 .62034 L F
.797 .662 .714 r
.29518 .62034 m .29954 .62067 L .29664 .62379 L F
.616 .386 .545 r
.29954 .62067 m .29949 .62394 L .29664 .62379 L F
.594 .898 .987 r
.30025 .61881 m .29954 .62067 L .29779 .61828 L F
.30025 .61881 m .30184 .61976 L .29954 .62067 L F
.641 .797 .957 r
.29954 .62067 m .30184 .61976 L .29949 .62394 L F
.209 .181 .606 r
.24324 .56789 m .24451 .56712 L .24456 .56342 L F
.23 .14 .542 r
.24333 .57056 m .24451 .56712 L .24324 .56789 L F
.464 .062 .192 r
.64893 .34269 m .64592 .34434 L .64607 .34344 L F
.143 .651 .901 r
.51727 .38411 m .51794 .38424 L .51859 .38469 L F
.631 .954 .774 r
.51912 .38507 m .51859 .38469 L .5202 .38431 L F
.086 0 0 r
.51859 .38469 m .52262 .38493 L .5202 .38431 L F
.51859 .38469 m .52165 .38497 L .52262 .38493 L F
.143 .651 .901 r
.51794 .38424 m .52165 .38497 L .51859 .38469 L F
.631 .954 .774 r
.51754 .38618 m .51859 .38469 L .51912 .38507 L F
.51754 .38618 m .51576 .38677 L .51859 .38469 L F
.875 .981 .691 r
.29271 .62086 m .2898 .62407 L .29076 .62462 L F
.358 .814 .936 r
.29393 .61988 m .29518 .62034 L .29271 .62086 L F
.29393 .61988 m .29271 .62086 L .29076 .62462 L F
.702 .392 0 r
.49166 .4413 m .4928 .4447 L .49316 .44374 L F
0 .344 .815 r
.4928 .4447 m .49667 .44719 L .49316 .44374 L F
.858 .527 .425 r
.4928 .4447 m .49654 .44874 L .49667 .44719 L F
.77 .481 .497 r
.26441 .52629 m .26785 .52692 L .26829 .52486 L F
.231 0 .083 r
.26785 .52692 m .2711 .5246 L .26829 .52486 L F
.984 .789 .563 r
.39279 .53048 m .39249 .53379 L .39463 .53483 L F
.926 .538 .208 r
.39249 .53379 m .39261 .53503 L .39463 .53483 L F
.501 0 0 r
.39544 .53573 m .39463 .53483 L .39261 .53503 L F
.39544 .53573 m .3971 .5369 L .39463 .53483 L F
.526 .258 .451 r
.39463 .53483 m .3971 .5369 L .39788 .5345 L F
.413 .219 .505 r
.30701 .57772 m .307 .58108 L .30464 .58152 L F
0 0 .308 r
.30795 .57831 m .307 .58108 L .30701 .57772 L F
.767 .987 .898 r
.30464 .58152 m .30767 .57782 L .30701 .57772 L F
.30464 .58152 m .30438 .57957 L .30767 .57782 L F
.3 0 .172 r
.30464 .58152 m .307 .58108 L .30438 .57957 L F
.30464 .58152 m .30361 .58349 L .307 .58108 L F
.307 .58108 m .30361 .58349 L .30464 .58152 L F
.768 .515 .553 r
.41624 .54429 m .41853 .54228 L .41643 .541 L F
.41624 .54429 m .41945 .54494 L .41853 .54228 L F
.712 .338 0 r
.57127 .42058 m .57037 .41842 L .56977 .41757 L F
.828 .701 .724 r
.35156 .5971 m .34914 .60019 L .35336 .60056 L F
.823 .726 .758 r
.34914 .60019 m .35071 .60422 L .35336 .60056 L F
.991 .852 .605 r
.29202 .61275 m .29439 .61118 L .29284 .60993 L F
.36 0 .075 r
.65928 .33909 m .6553 .34154 L .65531 .33972 L F
.671 .973 .811 r
.45271 .44653 m .45491 .44584 L .45649 .4443 L F
0 0 0 r
.39412 .46911 m .39634 .46828 L .39205 .47032 L F
.88 .949 .851 r
.4955 .51629 m .49553 .51907 L .49819 .51575 L F
.868 .943 .864 r
.49275 .51926 m .49553 .51907 L .4955 .51629 L F
.1 .197 .679 r
.27675 .53987 m .27762 .54354 L .27553 .54146 L F
.541 .239 .404 r
.27553 .54146 m .27762 .54354 L .27543 .54381 L F
.86 .648 .615 r
.35004 .55418 m .34816 .55762 L .35172 .55815 L F
.868 .735 .713 r
.34735 .56027 m .35172 .55815 L .34816 .55762 L F
.585 .568 .801 r
.53938 .4283 m .53811 .43221 L .53675 .42862 L F
.53938 .4283 m .54137 .43138 L .53811 .43221 L F
.24 .035 .388 r
.54042 .43329 m .53811 .43221 L .54137 .43138 L F
.54042 .43329 m .53794 .43495 L .53811 .43221 L F
.082 0 0 r
.38582 .50322 m .39088 .50088 L .38741 .50167 L F
.65 .819 .964 r
.30553 .64759 m .3025 .64849 L .30078 .64724 L F
.676 .877 .499 r
.48546 .41256 m .48655 .41056 L .48794 .40898 L F
0 0 0 r
.48794 .40898 m .48922 .40764 L .49029 .40771 L F
.48794 .40898 m .48655 .41056 L .48922 .40764 L F
.835 .671 .678 r
.38504 .55781 m .38108 .5572 L .38193 .55442 L F
.883 .634 .556 r
.38504 .55781 m .3813 .55972 L .38108 .5572 L F
.38504 .55781 m .38481 .56035 L .3813 .55972 L F
.598 .087 .008 r
.53943 .41667 m .5412 .41516 L .54022 .41507 L F
0 .002 .559 r
.54364 .41738 m .5412 .41516 L .54357 .41464 L F
.058 0 0 r
.54357 .41464 m .5412 .41516 L .53943 .41667 L F
.725 .989 .863 r
.4816 .41485 m .48276 .41284 L .48546 .41256 L F
.69 .975 .91 r
.48546 .41256 m .48276 .41284 L .48655 .41056 L F
.789 .778 .843 r
.53443 .35815 m .53781 .35851 L .5374 .35493 L F
.756 .761 .857 r
.5374 .35493 m .53781 .35851 L .54148 .35558 L F
0 .513 .841 r
.53056 .44112 m .53254 .44187 L .53221 .4414 L F
.849 .955 .609 r
.53221 .4414 m .53254 .44187 L .53353 .43829 L F
.89 .602 .493 r
.34236 .52426 m .34225 .52667 L .34445 .52478 L F
.869 .563 .467 r
.34225 .52667 m .34463 .52737 L .34445 .52478 L F
.721 .272 .186 r
.65438 .39921 m .65141 .40046 L .65097 .39766 L F
.781 .707 .782 r
.65716 .39542 m .65438 .39921 L .6533 .39486 L F
.878 .61 .529 r
.37624 .53485 m .37283 .53646 L .37303 .53381 L F
.37624 .53485 m .37606 .53762 L .37283 .53646 L F
0 0 .149 r
.56306 .38204 m .56326 .38623 L .56341 .38368 L F
.56306 .38204 m .56341 .38368 L .56155 .381 L F
.36 0 .075 r
.65928 .33909 m .65791 .34112 L .6553 .34154 L F
.646 .231 .241 r
.66226 .34123 m .65928 .33909 L .66178 .33941 L F
.66226 .34123 m .65791 .34112 L .65928 .33909 L F
.767 .908 .521 r
.57 .40875 m .57218 .4044 L .56965 .40758 L F
.842 .737 .748 r
.31731 .58475 m .31616 .58593 L .3182 .58459 L F
.31731 .58475 m .31422 .58657 L .31616 .58593 L F
.41 .855 .77 r
.6012 .35052 m .59924 .35172 L .60235 .35018 L F
.329 .799 .706 r
.60382 .34936 m .60235 .35018 L .60507 .35011 L F
.60382 .34936 m .6012 .35052 L .60235 .35018 L F
0 0 0 r
.56326 .38623 m .56355 .38581 L .56341 .38368 L F
.56326 .38623 m .56217 .38812 L .56355 .38581 L F
.294 0 0 r
.40155 .46032 m .40404 .45999 L .40575 .45793 L F
.144 0 0 r
.40575 .45793 m .40661 .45916 L .40829 .4577 L F
.40575 .45793 m .40404 .45999 L .40661 .45916 L F
.852 .615 .58 r
.68474 .3444 m .68816 .34277 L .68617 .34211 L F
.68474 .3444 m .68816 .34541 L .68816 .34277 L F
.632 .693 .889 r
.54293 .34765 m .54418 .35021 L .53986 .34873 L F
.459 .262 .525 r
.54223 .34978 m .53986 .34873 L .54253 .34964 L F
.54223 .34978 m .53953 .35142 L .53986 .34873 L F
.54223 .34978 m .53953 .35142 L .53986 .34873 L F
.825 .564 .544 r
.53953 .35142 m .53587 .34821 L .53986 .34873 L F
.489 0 0 r
.54223 .34978 m .53838 .35013 L .53953 .35142 L F
.54223 .34978 m .54099 .35104 L .53838 .35013 L F
.674 .883 .513 r
.54301 .34818 m .54172 .35001 L .54223 .34978 L F
.54172 .35001 m .54099 .35104 L .54223 .34978 L F
.459 .262 .525 r
.54223 .34978 m .54253 .34964 L .54418 .35021 L F
.48 .607 .901 r
.54554 .34719 m .54418 .35021 L .54293 .34765 L F
.777 .953 .93 r
.54554 .34719 m .54223 .34978 L .54418 .35021 L F
.227 .712 .929 r
.66288 .39127 m .66662 .39187 L .66455 .39178 L F
.663 .267 .284 r
.50353 .44485 m .50594 .4453 L .50226 .44528 L F
.259 .761 .718 r
.28994 .62514 m .28993 .625 L .2898 .62407 L F
.831 .973 .887 r
.54789 .47009 m .55212 .46812 L .551 .46707 L F
.893 .959 .833 r
.551 .46707 m .55212 .46812 L .5549 .46448 L F
.901 .701 .623 r
.35245 .57051 m .35449 .5712 L .35282 .56748 L F
.907 .657 .548 r
.35222 .57293 m .35449 .5712 L .35245 .57051 L F
.35222 .57293 m .35436 .5741 L .35449 .5712 L F
.852 .959 .877 r
.47846 .52463 m .48007 .52054 L .48081 .52095 L F
.47846 .52463 m .47714 .52369 L .48007 .52054 L F
0 0 0 r
.41451 .45471 m .41672 .45384 L .41819 .45267 L F
.257 0 0 r
.41672 .45384 m .42075 .45193 L .41819 .45267 L F
.725 .989 .863 r
.4816 .41485 m .48111 .41443 L .48276 .41284 L F
.972 .772 .577 r
.38621 .56438 m .38362 .56655 L .38354 .56349 L F
.38621 .56438 m .38564 .56728 L .38362 .56655 L F
.401 .067 .279 r
.62688 .34871 m .62311 .35205 L .62299 .3482 L F
.62688 .34871 m .62631 .35147 L .62311 .35205 L F
.165 0 .205 r
.62859 .35019 m .62688 .34871 L .62968 .34893 L F
.62859 .35019 m .62631 .35147 L .62688 .34871 L F
.3 .499 .885 r
.49667 .44719 m .49654 .44874 L .49771 .44669 L F
.791 .314 0 r
.49654 .44874 m .49782 .45077 L .49636 .44986 L F
.49654 .44874 m .49636 .44986 L .49771 .44669 L F
.754 .701 .802 r
.33466 .59113 m .3347 .5923 L .32972 .59001 L F
.763 .996 .855 r
.68271 .36909 m .68586 .36629 L .68377 .36678 L F
.766 .969 .683 r
.68125 .36978 m .68271 .36909 L .68377 .36678 L F
.343 0 0 r
.30291 .68671 m .30721 .68699 L .30517 .68727 L F
.506 0 0 r
.30517 .68727 m .30721 .68699 L .31168 .68927 L F
.534 .028 0 r
.30721 .68699 m .31036 .68758 L .31163 .68921 L F
.451 .06 .206 r
.31036 .68758 m .31206 .68906 L .31168 .68927 L F
.31036 .68758 m .31381 .68664 L .31206 .68906 L F
.878 .975 .841 r
.31041 .68856 m .31205 .68905 L .31194 .68747 L F
.31205 .68905 m .31206 .68906 L .31206 .68904 L F
.31205 .68905 m .31206 .68904 L .31194 .68747 L F
.534 .028 0 r
.31159 .68922 m .31163 .68921 L .31168 .68927 L F
.30721 .68699 m .31163 .68921 L .31159 .68922 L F
0 .156 .698 r
.52872 .35962 m .52985 .3622 L .52934 .35992 L F
.52934 .35992 m .52985 .3622 L .52872 .35962 L F
.95 .596 .261 r
.42901 .58969 m .43068 .59315 L .4311 .59111 L F
0 0 .025 r
.4311 .59111 m .43068 .59315 L .43194 .5918 L F
.626 .717 .912 r
.63634 .38397 m .64138 .38574 L .63838 .38678 L F
.907 .895 .805 r
.45202 .56115 m .45474 .55743 L .45284 .55634 L F
.782 .8 .867 r
.45695 .55668 m .45284 .55634 L .45474 .55743 L F
.984 .801 .577 r
.41078 .5583 m .40986 .56048 L .41024 .55549 L F
.937 .778 .659 r
.38055 .54499 m .37771 .54669 L .37846 .5438 L F
.38055 .54499 m .37981 .54771 L .37771 .54669 L F
.277 0 .129 r
.65697 .33005 m .65926 .33061 L .65959 .32933 L F
.65697 .33005 m .65651 .33151 L .65926 .33061 L F
.471 .223 .455 r
.25621 .62804 m .259 .62711 L .25839 .62975 L F
.53 .888 .978 r
.25621 .62804 m .259 .62711 L .25839 .62975 L F
.504 .79 .997 r
.29962 .6533 m .29928 .65431 L .30063 .65249 L F
.436 0 0 r
.29928 .65431 m .30285 .65609 L .30069 .65554 L F
.29928 .65431 m .30069 .65554 L .30063 .65249 L F
.877 .877 .831 r
.51505 .48583 m .51071 .48721 L .51319 .48359 L F
.51505 .48583 m .51252 .48866 L .51071 .48721 L F
.677 .759 .913 r
.51658 .48386 m .51505 .48583 L .51319 .48359 L F
.866 .959 .863 r
.49852 .51306 m .49819 .51575 L .49985 .51419 L F
.906 .96 .815 r
.49852 .51306 m .49985 .51419 L .5027 .51014 L F
0 0 .089 r
.32477 .57833 m .32322 .58295 L .3255 .57896 L F
.289 0 .227 r
.32322 .58295 m .32452 .58366 L .32694 .58291 L F
.699 .977 .781 r
.46351 .44106 m .4646 .43913 L .46258 .44092 L F
.46351 .44106 m .46652 .43848 L .4646 .43913 L F
.917 .713 .613 r
.34798 .55035 m .34663 .5535 L .35004 .55418 L F
.926 .75 .645 r
.34593 .55662 m .35004 .55418 L .34663 .5535 L F
.34593 .55662 m .34816 .55762 L .35004 .55418 L F
.623 .79 .962 r
.30995 .62172 m .31115 .61945 L .30764 .62197 L F
.30995 .62172 m .31288 .62094 L .31115 .61945 L F
.768 .702 .79 r
.35205 .59422 m .35637 .59468 L .35488 .59096 L F
.531 .344 .573 r
.31865 .53473 m .32131 .5347 L .3213 .53137 L F
.31865 .53473 m .32131 .5347 L .3213 .53137 L F
.936 .888 .759 r
.56643 .44135 m .56592 .43773 L .56363 .44116 L F
.56643 .44135 m .56746 .43908 L .56592 .43773 L F
.911 .846 .766 r
.56251 .44366 m .56643 .44135 L .56363 .44116 L F
.56251 .44366 m .56418 .44488 L .56643 .44135 L F
.946 .719 .563 r
.38235 .55147 m .37985 .55324 L .37991 .55037 L F
.38235 .55147 m .38193 .55442 L .37985 .55324 L F
.788 .797 .86 r
.30656 .61807 m .30184 .61976 L .30512 .61732 L F
.851 .844 .837 r
.3074 .61386 m .30656 .61807 L .30512 .61732 L F
0 0 .17 r
.67113 .31619 m .67277 .31147 L .67083 .31192 L F
.67113 .31619 m .67248 .31417 L .67277 .31147 L F
.442 .692 .971 r
.67113 .31619 m .67406 .31628 L .67248 .31417 L F
.275 .225 .62 r
.67083 .31192 m .67277 .31147 L .67086 .30939 L F
0 0 0 r
.49307 .43357 m .49291 .43536 L .49281 .43745 L F
.284 0 0 r
.59989 .37324 m .60284 .37361 L .60422 .37249 L F
.534 .426 .677 r
.64614 .37543 m .64867 .3777 L .64906 .37444 L F
.874 .626 .561 r
.36726 .52398 m .36475 .52049 L .36676 .52157 L F
.92 .834 .743 r
.54351 .46405 m .54253 .46054 L .54435 .46187 L F
.54351 .46405 m .54052 .46422 L .54253 .46054 L F
.908 .87 .789 r
.54351 .46405 m .54122 .46751 L .54052 .46422 L F
0 0 .325 r
.41447 .5916 m .41441 .5883 L .40948 .59009 L F
.523 .242 .43 r
.41635 .59081 m .41481 .59268 L .41447 .5916 L F
0 0 .325 r
.41447 .5916 m .4146 .59202 L .41456 .59125 L F
.41446 .5914 m .41456 .59125 L .41441 .5883 L F
.41447 .5916 m .41456 .59125 L .41446 .5914 L F
.4146 .59202 m .41471 .59159 L .41441 .5883 L F
.664 .748 .913 r
.41441 .5883 m .41481 .59268 L .41783 .58895 L F
.945 .662 .205 r
.41468 .58989 m .41523 .59016 L .41296 .59028 L F
0 0 .325 r
.4146 .59202 m .41481 .59268 L .41471 .59159 L F
.842 .796 .807 r
.41631 .5908 m .41091 .59418 L .40953 .59107 L F
.41651 .59079 m .41614 .59102 L .41631 .5908 L F
.41614 .59102 m .41091 .59418 L .41631 .5908 L F
.562 .825 .464 r
.41769 .58912 m .41617 .59101 L .41635 .59081 L F
.41783 .58895 m .41748 .58938 L .41769 .58912 L F
.41748 .58938 m .41617 .59101 L .41769 .58912 L F
.41617 .59101 m .41481 .59268 L .41594 .59131 L F
.41617 .59101 m .41594 .59131 L .41635 .59081 L F
.945 .662 .205 r
.41523 .59016 m .41637 .59073 L .41497 .59057 L F
.562 .825 .464 r
.41783 .58895 m .41635 .59081 L .41788 .58994 L F
.945 .662 .205 r
.41637 .59073 m .41651 .59079 L .41634 .59077 L F
.41637 .59073 m .41634 .59077 L .41497 .59057 L F
.41523 .59016 m .41497 .59057 L .41296 .59028 L F
.842 .796 .807 r
.41497 .59057 m .40953 .59107 L .41296 .59028 L F
.41651 .59079 m .4149 .59086 L .41497 .59057 L F
.4149 .59086 m .40953 .59107 L .41497 .59057 L F
.409 .836 .681 r
.46055 .43086 m .45841 .43212 L .4565 .43301 L F
.812 .751 .796 r
.57583 .39079 m .57568 .39399 L .57677 .39221 L F
.41 .855 .77 r
.6012 .35052 m .59863 .35175 L .59924 .35172 L F
.689 .685 .841 r
.50885 .49114 m .50555 .49061 L .50753 .48831 L F
.796 .839 .884 r
.51252 .48866 m .50885 .49114 L .50753 .48831 L F
.923 .569 .342 r
.66529 .34468 m .66226 .34123 L .66536 .34287 L F
.375 0 0 r
.34789 .49826 m .35026 .49926 L .35207 .49828 L F
.477 .276 .527 r
.35207 .49828 m .35462 .49769 L .35379 .49631 L F
.612 .163 .16 r
.35026 .49926 m .35462 .49769 L .35207 .49828 L F
.593 .774 .966 r
.48395 .42782 m .4855 .42964 L .48812 .42874 L F
0 .22 .735 r
.33074 .5833 m .33393 .5864 L .33131 .58319 L F
.75 .679 .782 r
.34438 .63751 m .34179 .64074 L .34021 .63695 L F
.275 .434 .839 r
.30432 .62337 m .30487 .62076 L .30184 .61976 L F
.30432 .62337 m .30644 .62417 L .30487 .62076 L F
.484 .284 .532 r
.58179 .42865 m .57913 .43202 L .57787 .43028 L F
.58179 .42865 m .58182 .43131 L .57913 .43202 L F
.499 .845 .996 r
.57913 .43202 m .58065 .43012 L .57787 .43028 L F
.57913 .43202 m .58182 .43131 L .58065 .43012 L F
0 0 .2 r
.67086 .30939 m .67079 .3065 L .67231 .30634 L F
.67086 .30939 m .67106 .30731 L .67079 .3065 L F
0 .03 .602 r
.67277 .31147 m .67106 .30731 L .67086 .30939 L F
.707 .57 .698 r
.52482 .38079 m .52653 .38442 L .52671 .38291 L F
.42 .047 .222 r
.52653 .38442 m .52961 .38394 L .52671 .38291 L F
.52653 .38442 m .52961 .38394 L .52671 .38291 L F
.78 .663 .734 r
.34798 .61041 m .35284 .60842 L .35076 .60655 L F
.566 .633 .877 r
.31727 .61353 m .31436 .61086 L .31789 .6128 L F
.908 .634 .51 r
.34463 .52737 m .34452 .53027 L .34751 .53039 L F
.93 .727 .607 r
.34421 .5331 m .34751 .53039 L .34452 .53027 L F
.34421 .5331 m .34647 .53434 L .34751 .53039 L F
.697 .699 .848 r
.32647 .63948 m .3308 .64019 L .32851 .64162 L F
.9 .962 .822 r
.49781 .49892 m .49529 .50239 L .49534 .49972 L F
.876 .962 .852 r
.49529 .50239 m .49263 .50314 L .49534 .49972 L F
.49529 .50239 m .49372 .50375 L .49263 .50314 L F
.886 .528 .362 r
.51968 .39688 m .51832 .39768 L .52004 .3976 L F
.955 .951 .697 r
.51989 .39584 m .51832 .39768 L .51968 .39688 L F
.751 .98 .733 r
.40912 .56904 m .41002 .56689 L .41158 .56766 L F
.009 0 0 r
.31868 .50722 m .32041 .50678 L .32212 .50561 L F
.248 0 0 r
.32212 .50561 m .32041 .50678 L .32454 .506 L F
.94 .706 .556 r
.34153 .57396 m .33953 .57036 L .34334 .5708 L F
.483 0 0 r
.50226 .44528 m .50594 .4453 L .50649 .44603 L F
.50226 .44528 m .50649 .44603 L .50549 .44617 L F
.50226 .44528 m .50549 .44617 L .50187 .44731 L F
.50549 .44617 m .50674 .44651 L .50449 .44691 L F
.50674 .44651 m .50688 .44655 L .50591 .44669 L F
.50674 .44651 m .50591 .44669 L .50449 .44691 L F
.50549 .44617 m .50649 .44603 L .50688 .44655 L F
.288 0 .092 r
.50688 .44655 m .50594 .4453 L .50876 .4446 L F
.50688 .44655 m .50876 .4446 L .50778 .44666 L F
.488 .371 .646 r
.50433 .44804 m .50568 .4475 L .50498 .44692 L F
.603 .35 .506 r
.50187 .44731 m .50349 .44706 L .50416 .44799 L F
.50349 .44821 m .50416 .44799 L .50488 .44898 L F
.50187 .44731 m .50416 .44799 L .50349 .44821 L F
.078 .553 .901 r
.50416 .44799 m .50568 .4475 L .50433 .44804 L F
.603 .35 .506 r
.50488 .44898 m .50489 .44685 L .50524 .44918 L F
.719 .227 0 r
.50416 .44799 m .50433 .44804 L .50385 .44757 L F
.603 .35 .506 r
.50349 .44706 m .50489 .44685 L .50489 .44695 L F
.488 .371 .646 r
.50433 .44804 m .50498 .44692 L .50431 .44709 L F
.603 .35 .506 r
.50363 .44726 m .50431 .44709 L .50385 .44757 L F
.854 .752 .749 r
.50375 .44746 m .50385 .44757 L .50431 .44704 L F
.50385 .44757 m .50433 .44804 L .50431 .44709 L F
.50385 .44757 m .50431 .44709 L .50431 .44704 L F
.603 .35 .506 r
.50385 .44757 m .50489 .44695 L .50488 .44898 L F
.50431 .44709 m .50489 .44695 L .50385 .44757 L F
.50349 .44706 m .50489 .44695 L .50363 .44726 L F
.488 .371 .646 r
.50431 .44709 m .505 .44689 L .50431 .44704 L F
.50498 .44692 m .505 .44689 L .50431 .44709 L F
.603 .35 .506 r
.50489 .44685 m .50688 .44655 L .50608 .44782 L F
.50489 .44685 m .50608 .44782 L .50524 .44918 L F
.488 .371 .646 r
.50498 .44692 m .50614 .44731 L .505 .44689 L F
.50568 .4475 m .50614 .44731 L .50498 .44692 L F
.184 0 .217 r
.50524 .44918 m .50688 .44655 L .50778 .44666 L F
.488 .371 .646 r
.50614 .44731 m .50778 .44666 L .505 .44689 L F
.483 0 0 r
.50334 .44684 m .50349 .44706 L .50187 .44731 L F
.719 .227 0 r
.50314 .44768 m .50407 .44796 L .50143 .44516 L F
.50407 .44796 m .50375 .44746 L .50143 .44516 L F
.078 .553 .901 r
.50314 .44768 m .50778 .44666 L .50568 .4475 L F
.719 .227 0 r
.50407 .44796 m .50416 .44799 L .50375 .44746 L F
.50416 .44799 m .50385 .44757 L .50375 .44746 L F
.078 .553 .901 r
.50314 .44768 m .50568 .4475 L .50416 .44799 L F
.488 .371 .646 r
.505 .44689 m .50778 .44666 L .50717 .4432 L F
.483 0 0 r
.50438 .44666 m .50449 .44691 L .50349 .44706 L F
.50549 .44617 m .50468 .44677 L .50438 .44666 L F
.50468 .44677 m .50449 .44691 L .50438 .44666 L F
.50549 .44617 m .50349 .44706 L .50334 .44684 L F
.488 .371 .646 r
.50431 .44704 m .50717 .4432 L .50425 .44364 L F
.505 .44689 m .50717 .4432 L .50431 .44704 L F
.854 .752 .749 r
.50281 .44653 m .50375 .44746 L .5043 .44633 L F
.50375 .44746 m .50431 .44704 L .5043 .44633 L F
.50143 .44516 m .50281 .44653 L .50425 .44364 L F
.50281 .44653 m .5043 .44633 L .50425 .44364 L F
.35 .223 .564 r
.2505 .54121 m .25276 .53817 L .25013 .53885 L F
.641 .353 .467 r
.40673 .46596 m .40317 .4682 L .40071 .46757 L F
.678 .397 .489 r
.40673 .46596 m .4076 .46777 L .40317 .4682 L F
.77 .767 .85 r
.4551 .54384 m .45805 .54389 L .45613 .54537 L F
0 0 .377 r
.3213 .53137 m .32184 .52686 L .32119 .52719 L F
0 0 .253 r
.32328 .53002 m .32401 .53057 L .32337 .53006 L F
.32289 .52996 m .32311 .53085 L .32401 .53057 L F
.32224 .52961 m .32311 .53085 L .32289 .52996 L F
.482 .306 .565 r
.3238 .53387 m .32131 .5347 L .3213 .53137 L F
.73 .59 .016 r
.3213 .53137 m .32131 .5347 L .32124 .53293 L F
.557 .854 .997 r
.32124 .53293 m .32131 .5347 L .3238 .53387 L F
.638 .08 0 r
.3238 .53387 m .32151 .53399 L .32124 .53293 L F
.3238 .53387 m .32505 .53584 L .32151 .53399 L F
.615 .049 0 r
.32151 .53399 m .32505 .53584 L .32429 .53556 L F
.616 .516 .717 r
.32151 .53399 m .32429 .53556 L .32311 .53085 L F
.775 .494 0 r
.32311 .53085 m .32429 .53556 L .32349 .53303 L F
.32311 .53085 m .32349 .53303 L .3235 .53239 L F
0 0 .377 r
.32154 .52932 m .32224 .52961 L .32184 .52686 L F
0 0 0 r
.32204 .52655 m .32184 .52686 L .32281 .52598 L F
.32119 .52719 m .32184 .52686 L .32204 .52655 L F
.989 .781 .391 r
.32217 .52911 m .32163 .52717 L .32184 .52686 L F
.32163 .52717 m .3208 .52412 L .32184 .52686 L F
.32224 .52961 m .32209 .52905 L .32217 .52911 L F
.32209 .52905 m .3208 .52412 L .32217 .52911 L F
1 .807 .495 r
.32133 .52843 m .31964 .52705 L .32019 .52404 L F
.879 .522 .368 r
.32176 .52877 m .31964 .52705 L .32133 .52843 L F
.989 .781 .391 r
.32224 .52961 m .32133 .52843 L .3208 .52412 L F
.879 .522 .368 r
.32334 .53003 m .32145 .52851 L .32176 .52877 L F
.32145 .52851 m .31964 .52705 L .32176 .52877 L F
.32401 .53057 m .32347 .53013 L .32334 .53003 L F
.32347 .53013 m .31964 .52705 L .32334 .53003 L F
0 0 .253 r
.32224 .52961 m .32289 .52996 L .32328 .53002 L F
.32224 .52961 m .32337 .53006 L .32133 .52843 L F
0 0 .377 r
.3213 .53137 m .32224 .52961 L .32154 .52932 L F
.73 .59 .016 r
.3213 .53137 m .32124 .53293 L .32224 .52961 L F
0 0 .253 r
.32224 .52961 m .32124 .53293 L .32311 .53085 L F
.879 .522 .368 r
.32347 .53013 m .32072 .52966 L .31964 .52705 L F
0 0 .253 r
.32289 .52996 m .32401 .53057 L .32328 .53002 L F
.245 .537 .922 r
.32347 .53013 m .32401 .53057 L .32311 .53085 L F
.879 .522 .368 r
.32401 .53057 m .32347 .53013 L .32347 .53013 L F
.245 .537 .922 r
.32356 .52994 m .32401 .53057 L .32347 .53013 L F
.879 .522 .368 r
.32401 .53057 m .32349 .53043 L .32347 .53013 L F
.775 .494 0 r
.32311 .53085 m .32354 .53011 L .3235 .53006 L F
.841 .825 .832 r
.32356 .52994 m .32349 .53043 L .32401 .53057 L F
.775 .494 0 r
.32354 .53011 m .32356 .53007 L .32355 .53007 L F
.32354 .53011 m .32355 .53007 L .3235 .53006 L F
.879 .522 .368 r
.32349 .53043 m .32072 .52966 L .32347 .53013 L F
.775 .494 0 r
.3235 .53006 m .32356 .53007 L .32356 .52994 L F
.841 .825 .832 r
.32356 .52994 m .32072 .52966 L .32349 .53043 L F
.775 .494 0 r
.32311 .53085 m .3235 .53239 L .32354 .53095 L F
.32348 .53031 m .32354 .53095 L .32356 .5302 L F
.32311 .53085 m .32354 .53095 L .32348 .53031 L F
.32351 .53016 m .32356 .5302 L .32356 .53007 L F
.32311 .53085 m .32356 .5302 L .32351 .53016 L F
.519 .517 .793 r
.31696 .51149 m .31929 .5119 L .31868 .50722 L F
.557 .209 .334 r
.31696 .51149 m .3193 .51345 L .31929 .5119 L F
.988 .738 .358 r
.32437 .54997 m .32564 .55124 L .32814 .55062 L F
.32437 .54997 m .32548 .55399 L .32564 .55124 L F
.598 .087 .008 r
.53943 .41667 m .54022 .41507 L .53666 .41741 L F
.535 .279 .473 r
.31313 .58777 m .31257 .59032 L .30981 .59078 L F
.31313 .58777 m .31257 .59032 L .30981 .59078 L F
0 0 .145 r
.31313 .58777 m .31401 .58901 L .31422 .58657 L F
.31313 .58777 m .31257 .59032 L .31401 .58901 L F
.48 .892 .783 r
.41892 .59785 m .42066 .59648 L .421 .59664 L F
0 0 0 r
.41933 .59885 m .41892 .59785 L .42066 .59648 L F
.41933 .59885 m .41828 .60048 L .41892 .59785 L F
.872 .98 .842 r
.3562 .48589 m .35281 .48989 L .35525 .48636 L F
.509 .189 .361 r
.35281 .48989 m .356 .48997 L .35525 .48636 L F
.35281 .48989 m .35317 .49105 L .356 .48997 L F
.205 0 0 r
.39421 .46295 m .39248 .46245 L .39082 .46404 L F
.39421 .46295 m .3951 .46157 L .39248 .46245 L F
.971 .672 .395 r
.4227 .59133 m .42132 .59281 L .42099 .5899 L F
.4227 .59133 m .42308 .5942 L .42132 .59281 L F
.777 .997 .814 r
.59196 .34661 m .59312 .34421 L .59373 .34466 L F
.59196 .34661 m .59005 .34712 L .59312 .34421 L F
.895 .903 .824 r
.48313 .51508 m .48278 .51767 L .48127 .5171 L F
.949 .898 .509 r
.48081 .52095 m .48127 .5171 L .48278 .51767 L F
.898 .906 .822 r
.48552 .51387 m .48278 .51767 L .48313 .51508 L F
.819 .85 .871 r
.54731 .45894 m .54435 .46187 L .54253 .46054 L F
.288 0 0 r
.33371 .56019 m .3332 .55797 L .33166 .55695 L F
.546 .455 .702 r
.53541 .41759 m .53567 .42236 L .538 .42101 L F
.798 .345 .164 r
.50984 .4086 m .51082 .41052 L .51211 .40967 L F
.442 0 0 r
.51211 .40967 m .51103 .40942 L .50984 .4086 L F
.485 .9 .887 r
.51211 .40967 m .51459 .40804 L .51103 .40942 L F
.457 .75 .992 r
.51211 .40967 m .51454 .40969 L .51459 .40804 L F
.916 .517 .185 r
.39525 .51106 m .39606 .51361 L .39807 .51479 L F
.498 0 0 r
.39606 .51361 m .39756 .51496 L .39807 .51479 L F
0 0 0 r
.51393 .41883 m .51137 .42217 L .51376 .42112 L F
.36 0 .149 r
.51594 .42013 m .51393 .41883 L .51376 .42112 L F
.51594 .42013 m .51669 .4183 L .51393 .41883 L F
.988 .879 .625 r
.69107 .35635 m .69272 .35528 L .69141 .35464 L F
.69107 .35635 m .69155 .35943 L .69272 .35528 L F
.968 .667 .398 r
.52726 .36612 m .52516 .36693 L .52519 .36433 L F
.52519 .36433 m .52516 .36693 L .52726 .36612 L F
.733 .978 .92 r
.46775 .54634 m .46713 .5481 L .46884 .54707 L F
.822 .992 .866 r
.47081 .54339 m .46884 .54707 L .47215 .54442 L F
.47081 .54339 m .46775 .54634 L .46884 .54707 L F
.735 .635 .748 r
.32004 .5442 m .32155 .54795 L .32612 .54513 L F
0 0 0 r
.426 .45044 m .43007 .44801 L .42742 .44869 L F
.03 .439 .87 r
.67432 .30607 m .67231 .30634 L .67079 .3065 L F
.67432 .30607 m .67556 .30773 L .67231 .30634 L F
.694 .949 .956 r
.49706 .40508 m .49352 .40592 L .49595 .40455 L F
.8 .986 .891 r
.49706 .40508 m .49775 .40261 L .50044 .40229 L F
.49706 .40508 m .49595 .40455 L .49775 .40261 L F
.781 .604 .66 r
.35314 .58408 m .35264 .58714 L .35701 .58719 L F
.81 .628 .656 r
.35257 .58939 m .35701 .58719 L .35264 .58714 L F
.35257 .58939 m .35488 .59096 L .35701 .58719 L F
.712 .222 .079 r
.50325 .44011 m .50725 .44093 L .50459 .43859 L F
.553 .335 .539 r
.50459 .43859 m .50725 .44093 L .50745 .4381 L F
.981 .815 .605 r
.46509 .54966 m .46713 .5481 L .46775 .54634 L F
.46509 .54966 m .46665 .55091 L .46713 .5481 L F
.484 .284 .532 r
.58179 .42865 m .57787 .43028 L .58077 .42709 L F
0 0 .303 r
.58314 .42928 m .58179 .42865 L .58077 .42709 L F
.58314 .42928 m .58182 .43131 L .58179 .42865 L F
.768 .47 .482 r
.67287 .3278 m .67676 .32596 L .67254 .32546 L F
.67287 .3278 m .67701 .32837 L .67676 .32596 L F
.949 .898 .509 r
.48081 .52095 m .48007 .52054 L .48127 .5171 L F
0 0 0 r
.5198 .38129 m .52169 .38064 L .52257 .37956 L F
.655 .842 .436 r
.52257 .37956 m .52289 .37884 L .52482 .38079 L F
.52257 .37956 m .52169 .38064 L .52289 .37884 L F
.52257 .37956 m .52169 .38064 L .52289 .37884 L F
.546 .455 .702 r
.53541 .41759 m .538 .42101 L .53666 .41741 L F
.898 .702 .629 r
.35071 .56705 m .35304 .56459 L .3489 .56361 L F
.35071 .56705 m .35282 .56748 L .35304 .56459 L F
.414 .213 .497 r
.24939 .55109 m .24688 .55454 L .24945 .55363 L F
.318 .184 .536 r
.24688 .55454 m .24912 .55578 L .24945 .55363 L F
.24688 .55454 m .24696 .55739 L .24912 .55578 L F
.816 .723 .763 r
.34657 .60358 m .35071 .60422 L .34914 .60019 L F
.69 .466 .578 r
.3481 .60767 m .35071 .60422 L .34657 .60358 L F
.3481 .60767 m .35076 .60655 L .35071 .60422 L F
.898 .906 .822 r
.48552 .51387 m .48313 .51508 L .48482 .51321 L F
.693 .652 .805 r
.356 .48997 m .3598 .48827 L .3575 .48624 L F
.356 .48997 m .35994 .49095 L .3598 .48827 L F
.796 .839 .884 r
.51252 .48866 m .50753 .48831 L .51071 .48721 L F
0 0 .089 r
.32477 .57833 m .3255 .57896 L .32715 .57717 L F
.494 .285 .525 r
.51465 .47086 m .51129 .47432 L .51181 .4717 L F
.51129 .47432 m .51465 .47086 L .51181 .4717 L F
.118 0 0 r
.64311 .33707 m .64715 .33545 L .64435 .33598 L F
.075 0 0 r
.52844 .46885 m .5272 .4699 L .53095 .46808 L F
.814 .705 .745 r
.4452 .5644 m .44939 .56452 L .44739 .56304 L F
.4452 .5644 m .44689 .56769 L .44939 .56452 L F
.815 .944 .909 r
.45202 .56115 m .44739 .56304 L .44939 .56452 L F
.441 .727 .987 r
.61246 .38729 m .61165 .38839 L .60981 .38741 L F
.068 0 0 r
.61177 .38818 m .61246 .38729 L .61137 .38829 L F
.574 .815 .432 r
.61246 .38729 m .61303 .38655 L .61165 .38839 L F
.791 .597 .639 r
.61378 .38557 m .61465 .38915 L .61165 .38839 L F
.068 0 0 r
.61393 .38758 m .61246 .38729 L .61177 .38818 L F
.574 .815 .432 r
.61246 .38729 m .61378 .38557 L .61303 .38655 L F
.704 .904 .967 r
.61713 .38707 m .61465 .38915 L .61378 .38557 L F
.573 .092 .074 r
.61246 .38729 m .61713 .38707 L .61378 .38557 L F
.357 .33 .692 r
.32244 .55068 m .32437 .54997 L .32155 .54795 L F
.893 .959 .833 r
.551 .46707 m .5549 .46448 L .55383 .46392 L F
.88 .984 .824 r
.55383 .46392 m .5549 .46448 L .55736 .46135 L F
.264 .755 .913 r
.59711 .34311 m .6 .34265 L .60106 .34337 L F
.451 0 0 r
.6 .34265 m .60349 .34285 L .60106 .34337 L F
.82 .882 .889 r
.54122 .46751 m .5393 .46904 L .53775 .46763 L F
.984 .836 .616 r
.32712 .54185 m .32591 .54408 L .32479 .54271 L F
.814 .973 .899 r
.33012 .53929 m .32712 .54185 L .32751 .53925 L F
.447 .596 .907 r
.28273 .6466 m .28509 .64978 L .2874 .64968 L F
.872 .444 .031 r
.57438 .38686 m .57493 .38588 L .57431 .38416 L F
.761 .84 .912 r
.46019 .55426 m .46178 .5558 L .46408 .55435 L F
0 .371 .798 r
.40068 .51677 m .40233 .5182 L .39756 .51496 L F
.539 .787 .99 r
.40216 .51869 m .40233 .5182 L .40068 .51677 L F
.40216 .51869 m .40107 .5208 L .40233 .5182 L F
.651 .765 .933 r
.64906 .37444 m .653 .37561 L .65175 .37368 L F
.814 .576 .579 r
.65113 .37801 m .653 .37561 L .64906 .37444 L F
.573 .727 .947 r
.65175 .37368 m .653 .37561 L .65468 .37323 L F
.607 .842 .468 r
.65468 .37323 m .653 .37561 L .65113 .37801 L F
.614 .895 .988 r
.65838 .38758 m .65589 .38886 L .65737 .38674 L F
.65838 .38758 m .65589 .38886 L .65737 .38674 L F
.604 .564 .783 r
.66007 .39232 m .65589 .38886 L .65838 .38758 L F
.633 .947 .949 r
.46774 .43663 m .46652 .43848 L .46846 .43737 L F
.674 .969 .78 r
.4646 .43913 m .46652 .43848 L .46774 .43663 L F
.756 .462 .487 r
.53676 .4542 m .5393 .45804 L .53603 .45801 L F
.53676 .4542 m .53928 .45528 L .5393 .45804 L F
.645 .101 0 r
.53847 .45623 m .53676 .4542 L .53603 .45801 L F
.53847 .45623 m .53928 .45528 L .53676 .4542 L F
.906 .96 .815 r
.49852 .51306 m .5027 .51014 L .50118 .50934 L F
.775 .964 .926 r
.5027 .51014 m .50458 .50691 L .50118 .50934 L F
.5027 .51014 m .50563 .50785 L .50458 .50691 L F
.774 .997 .821 r
.50296 .49238 m .50404 .49017 L .50555 .49061 L F
.794 .993 .875 r
.50555 .49061 m .50704 .48754 L .50753 .48831 L F
.50555 .49061 m .50404 .49017 L .50704 .48754 L F
.746 .925 .95 r
.52023 .49475 m .52138 .49211 L .51904 .49399 L F
.52023 .49475 m .52292 .49315 L .52138 .49211 L F
.184 .595 .942 r
.57047 .36917 m .56849 .36991 L .56729 .3677 L F
.57047 .36917 m .57066 .36981 L .56849 .36991 L F
.821 .744 .779 r
.54723 .38463 m .54844 .38835 L .54497 .38694 L F
0 .051 .582 r
.54721 .38856 m .54812 .39151 L .54844 .38835 L F
.996 .773 .477 r
.54844 .38835 m .54671 .39017 L .54497 .38694 L F
.54844 .38835 m .54812 .39151 L .54671 .39017 L F
.479 .738 .984 r
.55001 .38624 m .54844 .38835 L .54723 .38463 L F
.55001 .38624 m .55134 .38788 L .54844 .38835 L F
.788 .87 .435 r
.53991 .45267 m .53928 .45528 L .53847 .45623 L F
.475 .325 .596 r
.54175 .45125 m .54215 .45404 L .53928 .45528 L F
.371 .118 .395 r
.53928 .45528 m .54158 .45677 L .5393 .45804 L F
.53928 .45528 m .54215 .45404 L .54158 .45677 L F
.709 .678 .818 r
.33597 .61714 m .34008 .61752 L .33862 .61385 L F
.743 .695 .806 r
.33862 .61385 m .34008 .61752 L .34273 .61434 L F
.907 .895 .805 r
.45202 .56115 m .45284 .55634 L .45073 .56013 L F
.866 .959 .863 r
.49852 .51306 m .4955 .51629 L .49819 .51575 L F
.595 .093 0 r
.32277 .51512 m .32546 .5179 L .32435 .51695 L F
.872 .475 .278 r
.32546 .5179 m .32355 .51949 L .32435 .51695 L F
.32546 .5179 m .32625 .52037 L .32355 .51949 L F
.592 .787 .973 r
.30078 .64724 m .29857 .64822 L .29671 .64656 L F
.942 .656 .469 r
.34584 .53956 m .34802 .53804 L .34575 .53693 L F
.34584 .53956 m .34795 .54082 L .34802 .53804 L F
0 0 0 r
.51376 .42112 m .51137 .42217 L .50961 .42317 L F
.398 .526 .87 r
.50678 .4211 m .50435 .42195 L .50253 .41852 L F
.873 .701 .667 r
.34795 .54082 m .34712 .54376 L .35055 .54415 L F
.869 .731 .708 r
.34712 .54376 m .34865 .54763 L .35055 .54415 L F
.75 .685 .789 r
.41229 .54014 m .41229 .5444 L .41375 .54449 L F
.852 .631 .602 r
.40891 .5461 m .41375 .54449 L .41229 .5444 L F
.40891 .5461 m .41341 .54749 L .41375 .54449 L F
.773 .697 .779 r
.41229 .54014 m .41375 .54449 L .41643 .541 L F
.558 .393 .613 r
.41375 .54449 m .41624 .54429 L .41643 .541 L F
.551 .356 .57 r
.41375 .54449 m .41341 .54749 L .41624 .54429 L F
0 .474 .704 r
.53781 .35112 m .53597 .35078 L .53953 .35142 L F
.826 .351 0 r
.58831 .36165 m .58629 .36063 L .58532 .35862 L F
.84 .717 .728 r
.54818 .45118 m .54964 .45507 L .54661 .45399 L F
.832 .728 .75 r
.54661 .45399 m .54964 .45507 L .54731 .45894 L F
.812 .735 .78 r
.59705 .36865 m .59457 .37379 L .59155 .36869 L F
.428 .764 .996 r
.48812 .42874 m .4918 .42964 L .4906 .42788 L F
0 .196 .724 r
.4918 .42964 m .49331 .42946 L .4906 .42788 L F
.4918 .42964 m .49343 .43114 L .49331 .42946 L F
.027 .585 .812 r
.64767 .39836 m .64671 .39804 L .64383 .39776 L F
.604 .945 .932 r
.64931 .39662 m .64767 .39836 L .65097 .39766 L F
.64931 .39662 m .64671 .39804 L .64767 .39836 L F
.341 0 0 r
.28008 .67353 m .27993 .67416 L .27794 .67296 L F
.28008 .67353 m .28216 .67425 L .27993 .67416 L F
.314 .8 .762 r
.43528 .45461 m .43478 .45461 L .43103 .45589 L F
.597 .948 .825 r
.43528 .45461 m .43882 .45242 L .43656 .45304 L F
.598 .932 .727 r
.43528 .45461 m .43656 .45304 L .43478 .45461 L F
.621 .476 .663 r
.2591 .56304 m .25922 .56458 L .25884 .56207 L F
.807 .788 .835 r
.30996 .61045 m .31143 .61388 L .3074 .61386 L F
.786 .779 .846 r
.31436 .61086 m .31143 .61388 L .30996 .61045 L F
.898 .73 .665 r
.45836 .58311 m .46041 .58427 L .45889 .58043 L F
.82 .882 .889 r
.54122 .46751 m .53775 .46763 L .54052 .46422 L F
.536 .258 .441 r
.52004 .3976 m .52279 .39818 L .52297 .39596 L F
.294 0 0 r
.64266 .34484 m .64166 .34531 L .63904 .34514 L F
.372 0 0 r
.64592 .34434 m .64166 .34531 L .64266 .34484 L F
.991 .747 .46 r
.59342 .37437 m .59318 .37817 L .59475 .37772 L F
.523 .568 .842 r
.59475 .37772 m .59603 .37379 L .59342 .37437 L F
.59475 .37772 m .59626 .37635 L .59603 .37379 L F
0 .402 .808 r
.59318 .37817 m .59743 .38042 L .59475 .37772 L F
.321 .198 .553 r
.59684 .36632 m .59837 .36777 L .59869 .36438 L F
.265 .195 .588 r
.59684 .36632 m .59705 .36865 L .59837 .36777 L F
.697 .842 .952 r
.29382 .67955 m .29034 .67941 L .29298 .67743 L F
.784 .966 .92 r
.29578 .67637 m .29382 .67955 L .29298 .67743 L F
.29578 .67637 m .29738 .67687 L .29382 .67955 L F
.598 .31 .451 r
.52297 .39596 m .52279 .39818 L .52582 .39768 L F
.862 .849 .829 r
.66563 .35837 m .66316 .35792 L .66562 .35502 L F
.959 .884 .714 r
.66563 .35837 m .66271 .36072 L .66316 .35792 L F
.66563 .35837 m .66412 .36225 L .66271 .36072 L F
0 0 .544 r
.58345 .39305 m .58456 .39448 L .58233 .39085 L F
.426 .393 .719 r
.62322 .35441 m .62033 .35606 L .62022 .35228 L F
.09 0 .138 r
.62322 .35441 m .62048 .35768 L .62033 .35606 L F
.754 .701 .802 r
.33466 .59113 m .32972 .59001 L .33205 .58967 L F
.515 .37 .622 r
.5868 .35541 m .58532 .35862 L .58377 .35893 L F
.357 .234 .573 r
.58629 .36063 m .58377 .35893 L .58532 .35862 L F
.58629 .36063 m .58424 .36203 L .58377 .35893 L F
.845 .99 .854 r
.49781 .49892 m .49534 .49972 L .49836 .49661 L F
0 0 .022 r
.57626 .37108 m .57643 .36674 L .57561 .3689 L F
.858 .861 .842 r
.28148 .64281 m .27909 .6433 L .2792 .64318 L F
.377 .82 .95 r
.28367 .64162 m .28148 .64281 L .2792 .64318 L F
.058 .615 .81 r
.28841 .64214 m .28668 .6421 L .28441 .64174 L F
.28437 .6417 m .28441 .64174 L .28367 .64162 L F
.28841 .64214 m .28441 .64174 L .28437 .6417 L F
.519 .628 .898 r
.2849 .64073 m .28428 .64159 L .2843 .6413 L F
.377 .82 .95 r
.28367 .64162 m .28441 .64174 L .28148 .64281 L F
.28441 .64174 m .28668 .6421 L .28405 .64246 L F
.058 .615 .81 r
.28841 .64214 m .28367 .64162 L .28396 .64205 L F
.519 .628 .898 r
.28428 .64159 m .28396 .64205 L .28421 .6415 L F
.28428 .64159 m .28421 .6415 L .2843 .6413 L F
.28737 .63841 m .28458 .64138 L .2849 .64073 L F
.28458 .64138 m .28396 .64205 L .2849 .64073 L F
.377 .82 .95 r
.28441 .64174 m .28405 .64246 L .28148 .64281 L F
.797 .73 .789 r
.46076 .54034 m .45805 .54389 L .45699 .54052 L F
.239 .743 .892 r
.4551 .54384 m .45718 .54351 L .45805 .54389 L F
.261 0 0 r
.33231 .67672 m .33485 .67601 L .33433 .67667 L F
.148 0 0 r
.33012 .67923 m .33231 .67672 L .33433 .67667 L F
.367 0 0 r
.60349 .34285 m .60643 .34387 L .60758 .34362 L F
.182 0 0 r
.60758 .34362 m .60643 .34387 L .61056 .34403 L F
.753 .625 .718 r
.37855 .46776 m .38315 .46552 L .37897 .4652 L F
.77 .706 .791 r
.34273 .61434 m .34588 .61389 L .34552 .611 L F
.757 .697 .795 r
.34552 .611 m .34588 .61389 L .34798 .61041 L F
.771 .861 .916 r
.53719 .4803 m .53878 .47645 L .53593 .47975 L F
.53719 .4803 m .54041 .47799 L .53878 .47645 L F
.774 .997 .821 r
.50296 .49238 m .5009 .49309 L .50404 .49017 L F
0 0 0 r
.63523 .34053 m .6345 .34091 L .63799 .33946 L F
.692 .405 .483 r
.37606 .5044 m .38003 .5067 L .38052 .50525 L F
.396 .339 .676 r
.24939 .55109 m .25092 .54688 L .24898 .54761 L F
.24939 .55109 m .25151 .55069 L .25092 .54688 L F
.65 .545 .722 r
.24945 .55363 m .25151 .55069 L .24939 .55109 L F
.631 .944 .952 r
.45171 .5474 m .45037 .54695 L .45169 .54447 L F
.611 .454 .644 r
.45431 .54109 m .4551 .54384 L .45169 .54447 L F
.759 .764 .857 r
.4551 .54384 m .45171 .5474 L .45169 .54447 L F
.99 .728 .407 r
.45171 .5474 m .45037 .54695 L .45169 .54447 L F
.654 .828 .967 r
.53986 .34873 m .53587 .34821 L .53845 .34706 L F
.627 .817 .973 r
.54293 .34765 m .53986 .34873 L .53845 .34706 L F
.094 .265 .748 r
.33634 .57927 m .33759 .58264 L .33553 .58086 L F
.792 .99 .884 r
.55083 .40373 m .5503 .40479 L .55004 .40307 L F
.728 .529 0 r
.55004 .40307 m .5503 .40479 L .55053 .40716 L F
.813 .649 .679 r
.66494 .39554 m .66662 .39187 L .66288 .39127 L F
.769 .722 .809 r
.33675 .55735 m .33794 .56103 L .33371 .56019 L F
.994 .778 .501 r
.33794 .56103 m .33609 .56266 L .33371 .56019 L F
.33794 .56103 m .33768 .56405 L .33609 .56266 L F
.638 .838 .977 r
.23432 .61376 m .23608 .61472 L .23798 .61344 L F
.62 .187 0 r
.58802 .40509 m .58833 .40574 L .58763 .40327 L F
.58802 .40509 m .589 .40665 L .58833 .40574 L F
.529 .86 .995 r
.3233 .55729 m .32349 .55553 L .32548 .55399 L F
.3233 .55729 m .32107 .55622 L .32349 .55553 L F
.94 .698 .544 r
.66529 .34468 m .66712 .34892 L .66483 .3475 L F
.977 .718 .472 r
.66647 .35119 m .66483 .3475 L .66712 .34892 L F
0 0 .234 r
.58564 .39843 m .58518 .39621 L .58456 .39448 L F
.257 0 0 r
.58564 .39843 m .59037 .3994 L .58603 .39913 L F
.58564 .39843 m .58603 .39913 L .58518 .39621 L F
.655 .78 .315 r
.58907 .36953 m .59045 .3665 L .59155 .36869 L F
.58907 .36953 m .58869 .37026 L .59045 .3665 L F
.833 .825 .841 r
.27515 .64108 m .27663 .64385 L .27296 .64356 L F
.793 .388 .284 r
.27296 .64356 m .27663 .64385 L .27533 .64607 L F
.546 .564 .824 r
.27752 .63949 m .27663 .64385 L .27515 .64108 L F
.27752 .63949 m .27909 .6433 L .27663 .64385 L F
0 0 0 r
.27663 .64385 m .27726 .644 L .27533 .64607 L F
.27663 .64385 m .27909 .6433 L .27726 .644 L F
.174 0 0 r
.64989 .33461 m .65278 .33401 L .65391 .3326 L F
.077 0 0 r
.65391 .3326 m .65552 .33315 L .65651 .33151 L F
.65391 .3326 m .65278 .33401 L .65552 .33315 L F
.772 .935 .936 r
.66984 .37778 m .6725 .37414 L .66963 .37741 L F
.66984 .37778 m .67372 .37537 L .6725 .37414 L F
.35 .17 .491 r
.24898 .54761 m .25092 .54688 L .25111 .54428 L F
.935 .624 .166 r
.59062 .43313 m .59142 .43587 L .59055 .43345 L F
.682 .716 .197 r
.59099 .43139 m .58987 .4353 L .59062 .43313 L F
.935 .624 .166 r
.59062 .43313 m .59055 .43345 L .58997 .43183 L F
.682 .716 .197 r
.59155 .42945 m .59099 .43139 L .59062 .43313 L F
0 0 0 r
.58987 .4353 m .58998 .43636 L .59142 .43587 L F
.892 .571 .434 r
.6772 .33345 m .68069 .33268 L .67722 .33087 L F
.6772 .33345 m .68079 .33491 L .68069 .33268 L F
.511 .901 .755 r
.47033 .42495 m .46613 .42713 L .46821 .42535 L F
0 0 0 r
.47225 .42347 m .4736 .42232 L .47033 .42495 L F
.469 .891 .825 r
.47033 .42495 m .47188 .42372 L .47225 .42347 L F
.47033 .42495 m .46821 .42535 L .47188 .42372 L F
.115 0 0 r
.42868 .45612 m .43002 .45664 L .42713 .45668 L F
.42868 .45612 m .43103 .45589 L .43002 .45664 L F
.798 .999 .824 r
.50277 .39989 m .50044 .40229 L .50121 .40005 L F
.768 .986 .9 r
.50044 .40229 m .49775 .40261 L .50121 .40005 L F
.879 .475 .254 r
.36338 .51762 m .36203 .51944 L .36156 .5168 L F
.36338 .51762 m .36475 .52049 L .36203 .51944 L F
.978 .713 .457 r
.58115 .3787 m .57946 .37768 L .57937 .37503 L F
.733 .21 0 r
.58384 .38066 m .57946 .37768 L .58115 .3787 L F
.753 .672 .772 r
.34281 .6338 m .34438 .63751 L .34021 .63695 L F
.672 .67 .84 r
.34537 .63302 m .34438 .63751 L .34281 .6338 L F
.34537 .63302 m .34709 .63674 L .34438 .63751 L F
.513 .24 .439 r
.27338 .52375 m .27664 .52085 L .27402 .52153 L F
.537 .865 .587 r
.32293 .57463 m .32207 .57573 L .32393 .57446 L F
.982 .831 .619 r
.42443 .56052 m .42364 .56316 L .42533 .56432 L F
.93 .616 .423 r
.42303 .56583 m .42533 .56432 L .42364 .56316 L F
.547 .401 .634 r
.26189 .5598 m .25922 .56458 L .2591 .56304 L F
.6 .592 .816 r
.66019 .38705 m .66288 .39127 L .66007 .39232 L F
.81 .67 .708 r
.55268 .44143 m .54913 .44369 L .55183 .4403 L F
.55268 .44143 m .55122 .44514 L .54913 .44369 L F
.922 .934 .57 r
.55393 .43676 m .55268 .44143 L .55183 .4403 L F
.366 0 0 r
.24552 .59277 m .24298 .59331 L .2457 .59328 L F
.776 .451 .436 r
.35333 .51021 m .34898 .50728 L .3517 .50755 L F
.737 .931 .591 r
.24631 .59556 m .24375 .59912 L .24531 .59757 L F
.53 .083 .134 r
.40071 .46757 m .39865 .46976 L .39634 .46828 L F
.668 .248 .238 r
.40301 .46999 m .40071 .46757 L .40317 .4682 L F
.40301 .46999 m .39865 .46976 L .40071 .46757 L F
.609 .943 .759 r
.43684 .44512 m .438 .44361 L .43878 .44345 L F
.549 .909 .963 r
.43526 .44471 m .438 .44361 L .43684 .44512 L F
.928 .738 .626 r
.31142 .67387 m .31086 .67665 L .30925 .67285 L F
.31142 .67387 m .31086 .67665 L .30925 .67285 L F
.78 .552 .59 r
.35994 .49095 m .36358 .49409 L .36473 .49169 L F
.071 .32 .8 r
.45255 .53819 m .45574 .54036 L .45431 .54109 L F
.303 .794 .873 r
.45431 .54109 m .45574 .54036 L .45699 .54052 L F
.541 .412 .653 r
.45699 .54052 m .4551 .54384 L .45431 .54109 L F
.738 .661 .774 r
.32646 .62056 m .33064 .6211 L .32902 .6173 L F
.729 .683 .806 r
.33064 .6211 m .33159 .61643 L .32902 .6173 L F
.33064 .6211 m .33307 .61993 L .33159 .61643 L F
.763 .451 .457 r
.44638 .57646 m .45021 .57442 L .44728 .57361 L F
.44638 .57646 m .45039 .57693 L .45021 .57442 L F
.524 .565 .839 r
.32494 .52346 m .3265 .52747 L .32281 .52598 L F
.473 0 .037 r
.35525 .48636 m .3575 .48624 L .3562 .48589 L F
.981 .694 .392 r
.56273 .45501 m .56112 .45089 L .55967 .4543 L F
.919 .943 .801 r
.55928 .45707 m .56273 .45501 L .55967 .4543 L F
.55928 .45707 m .56053 .45831 L .56273 .45501 L F
.902 .506 .252 r
.34898 .50728 m .34542 .50322 L .34883 .50477 L F
.32 .798 .909 r
.45699 .54052 m .45968 .54001 L .46076 .54034 L F
.669 .968 .918 r
.46076 .54034 m .45968 .54001 L .46172 .53853 L F
.721 .779 .898 r
.33779 .63819 m .33342 .63775 L .33603 .63669 L F
.705 .826 .939 r
.33603 .63669 m .34021 .63695 L .33779 .63819 L F
.885 .854 .806 r
.53264 .35977 m .53083 .35746 L .53048 .36006 L F
.883 .992 .78 r
.55928 .45707 m .55736 .46135 L .56053 .45831 L F
.664 .697 .871 r
.62002 .38158 m .62334 .38228 L .62199 .38081 L F
.949 .671 .476 r
.37981 .54771 m .37772 .54949 L .37771 .54669 L F
.918 .778 .69 r
.38428 .57034 m .3856 .57422 L .38366 .57272 L F
.878 .749 .716 r
.3856 .57422 m .38136 .57645 L .38366 .57272 L F
.3856 .57422 m .38361 .57761 L .38136 .57645 L F
.933 .634 .452 r
.37981 .54771 m .37991 .55037 L .37772 .54949 L F
.93 .716 .592 r
.68474 .3444 m .68617 .34211 L .68319 .341 L F
.956 .844 .693 r
.40948 .54184 m .41229 .5444 L .41229 .54014 L F
.833 .541 .496 r
.40829 .54559 m .41229 .5444 L .40948 .54184 L F
.40829 .54559 m .40891 .5461 L .41229 .5444 L F
.866 .551 .452 r
.68095 .33745 m .68268 .33562 L .68079 .33491 L F
.68095 .33745 m .683 .33813 L .68268 .33562 L F
.773 .697 .779 r
.41229 .54014 m .41643 .541 L .41543 .53984 L F
.979 .738 .327 r
.41553 .53719 m .41543 .53984 L .41643 .541 L F
.188 .075 .485 r
.29462 .57325 m .29238 .57692 L .29178 .57399 L F
.29462 .57325 m .29463 .57622 L .29238 .57692 L F
.575 .309 .477 r
.29463 .57622 m .29146 .57819 L .29238 .57692 L F
.941 .843 .718 r
.56933 .42665 m .57199 .42575 L .5705 .42451 L F
.56933 .42665 m .57088 .42815 L .57199 .42575 L F
.88 .984 .824 r
.55383 .46392 m .55736 .46135 L .55683 .46056 L F
.883 .992 .78 r
.55928 .45707 m .55683 .46056 L .55736 .46135 L F
.936 .933 .772 r
.56085 .44711 m .56418 .44488 L .56251 .44366 L F
.56085 .44711 m .56208 .44826 L .56418 .44488 L F
0 0 0 r
.29242 .62432 m .29518 .62034 L .29664 .62379 L F
.584 .179 .241 r
.29242 .62432 m .29664 .62379 L .29352 .62526 L F
.425 .742 .993 r
.29664 .62379 m .29949 .62394 L .29741 .62249 L F
.655 .971 .858 r
.29352 .62526 m .29664 .62379 L .29741 .62249 L F
.736 .606 .713 r
.31733 .60769 m .31789 .6128 L .31436 .61086 L F
.589 .393 .583 r
.31257 .59032 m .30969 .59359 L .30981 .59078 L F
.30969 .59359 m .31257 .59032 L .30981 .59078 L F
.766 .748 .837 r
.33159 .61643 m .33597 .61714 L .33424 .61331 L F
.788 .71 .778 r
.33307 .61993 m .33597 .61714 L .33159 .61643 L F
.747 .739 .845 r
.33424 .61331 m .33597 .61714 L .33862 .61385 L F
.908 .856 .779 r
.34211 .56435 m .3381 .5666 L .33768 .56405 L F
.34211 .56435 m .34016 .56767 L .3381 .5666 L F
0 0 .504 r
.58376 .36667 m .58319 .37089 L .58229 .36879 L F
.938 .758 .633 r
.3915 .58007 m .39374 .5812 L .3922 .57693 L F
.908 .516 .252 r
.3915 .58007 m .39211 .58228 L .39374 .5812 L F
.408 .688 .976 r
.39374 .5812 m .39474 .57914 L .3922 .57693 L F
.39374 .5812 m .39715 .58123 L .39474 .57914 L F
.72 .948 .647 r
.39374 .5812 m .39474 .57914 L .39715 .58123 L F
.39374 .5812 m .39211 .58228 L .39474 .57914 L F
0 0 0 r
.32148 .58661 m .31873 .58921 L .31987 .5879 L F
.65 .819 .964 r
.30553 .64759 m .30078 .64724 L .30359 .64644 L F
.807 .873 .896 r
.30738 .64609 m .30553 .64759 L .30359 .64644 L F
.806 .974 .903 r
.33012 .53929 m .33086 .53641 L .33236 .53736 L F
.33012 .53929 m .32751 .53925 L .33086 .53641 L F
.768 .44 .432 r
.33542 .54766 m .33221 .54939 L .33116 .54706 L F
.85 .602 .563 r
.33542 .54766 m .33527 .55047 L .33221 .54939 L F
.709 .901 .534 r
.29178 .57399 m .28906 .57806 L .2905 .57545 L F
.224 0 .287 r
.28906 .57806 m .29146 .57819 L .2905 .57545 L F
.28906 .57806 m .28895 .57996 L .29146 .57819 L F
.7 .843 .951 r
.62903 .39695 m .62632 .39827 L .63027 .39853 L F
.538 .769 .983 r
.62903 .39695 m .63027 .39853 L .63172 .39632 L F
.479 .689 .96 r
.63027 .39853 m .63302 .39839 L .63172 .39632 L F
.94 .706 .556 r
.34153 .57396 m .33918 .57318 L .33953 .57036 L F
.833 .561 .528 r
.34153 .57396 m .33888 .57614 L .33918 .57318 L F
.34153 .57396 m .34171 .57754 L .33888 .57614 L F
.511 .238 .436 r
.50745 .4381 m .51034 .43761 L .51052 .43537 L F
.389 .139 .41 r
.51052 .43537 m .51301 .43699 L .51354 .43436 L F
.51052 .43537 m .51034 .43761 L .51301 .43699 L F
.819 .967 .899 r
.65964 .39914 m .66175 .39957 L .66373 .39762 L F
.35 .223 .564 r
.2505 .54121 m .25287 .54039 L .25276 .53817 L F
.423 .431 .763 r
.2505 .54121 m .25349 .54307 L .25287 .54039 L F
.503 .415 .689 r
.2505 .54121 m .25111 .54428 L .25349 .54307 L F
.74 .71 .823 r
.31294 .64064 m .31465 .64401 L .31038 .64341 L F
.75 .768 .867 r
.31555 .63964 m .31465 .64401 L .31294 .64064 L F
.31555 .63964 m .31723 .64271 L .31465 .64401 L F
.826 .771 .8 r
.45363 .58714 m .45623 .58654 L .45486 .58254 L F
.747 .731 .838 r
.45486 .58254 m .45623 .58654 L .45836 .58311 L F
.905 .754 .683 r
.40363 .52016 m .40505 .52417 L .40616 .52154 L F
.792 .487 .473 r
.61465 .38915 m .61393 .39119 L .61165 .38839 L F
.76 .847 .917 r
.31257 .66687 m .30969 .66934 L .3103 .66571 L F
.852 .829 .824 r
.43597 .60015 m .43887 .59691 L .4375 .59519 L F
.549 .73 .958 r
.4375 .59519 m .43887 .59691 L .44118 .59634 L F
.786 .955 .629 r
.52092 .39382 m .51989 .39584 L .52209 .39249 L F
.718 .192 0 r
.41152 .53226 m .41187 .53066 L .40939 .52973 L F
.41152 .53226 m .41394 .53298 L .41187 .53066 L F
.819 .85 .871 r
.54731 .45894 m .54253 .46054 L .54575 .45747 L F
.832 .728 .75 r
.54661 .45399 m .54731 .45894 L .54575 .45747 L F
.776 .972 .919 r
.47525 .43445 m .47769 .43128 L .47431 .43356 L F
.47525 .43445 m .47887 .43193 L .47769 .43128 L F
.661 .842 .432 r
.37126 .47558 m .37381 .47144 L .37322 .47412 L F
.657 .797 .949 r
.36895 .47347 m .37126 .47558 L .37322 .47412 L F
.986 .851 .621 r
.66271 .36072 m .66412 .36225 L .6631 .36467 L F
.792 .705 .769 r
.36935 .47073 m .37381 .47144 L .37468 .47091 L F
.988 .738 .358 r
.32548 .55399 m .32437 .54997 L .32244 .55068 L F
.766 .689 .777 r
.442 .56701 m .44689 .56769 L .4452 .5644 L F
.732 .335 .298 r
.442 .56701 m .44497 .56964 L .44689 .56769 L F
.962 .724 .532 r
.44497 .56964 m .44686 .57023 L .44689 .56769 L F
.939 .66 .483 r
.37847 .54104 m .3763 .54269 L .3765 .54001 L F
.37847 .54104 m .37846 .5438 L .3763 .54269 L F
.705 .341 0 r
.42327 .55815 m .42443 .56052 L .42324 .55767 L F
.42327 .55815 m .42324 .55767 L .42434 .55589 L F
.801 .788 .84 r
.46019 .55426 m .46408 .55435 L .46229 .55277 L F
.839 .786 .801 r
.46229 .55277 m .46408 .55435 L .46665 .55091 L F
.642 .739 .92 r
.65969 .36675 m .66156 .36873 L .65876 .37026 L F
.637 .155 0 r
.36629 .4989 m .36581 .49786 L .36399 .4968 L F
.36629 .4989 m .36794 .50063 L .36581 .49786 L F
.795 .343 .168 r
.36581 .49786 m .36794 .50063 L .36975 .50085 L F
.097 0 .325 r
.24456 .56342 m .24651 .56002 L .24504 .56104 L F
.714 .27 .194 r
.35704 .51193 m .35335 .51282 L .35333 .51021 L F
.35704 .51193 m .35753 .51348 L .35335 .51282 L F
.935 .621 .165 r
.69027 .35179 m .6889 .34807 L .68933 .35084 L F
.932 .558 .258 r
.6891 .3533 m .69027 .35179 L .68933 .35084 L F
.6891 .3533 m .69141 .35464 L .69027 .35179 L F
.804 .662 .707 r
.53953 .35142 m .5374 .35493 L .54148 .35558 L F
.823 .892 .891 r
.68586 .36629 m .68645 .36325 L .68377 .36678 L F
.68586 .36629 m .68763 .36443 L .68645 .36325 L F
0 0 0 r
.59366 .39654 m .59224 .39855 L .59461 .39473 L F
.867 .972 .657 r
.59366 .39654 m .59162 .40112 L .59224 .39855 L F
.839 .786 .801 r
.46229 .55277 m .46665 .55091 L .46509 .54966 L F
0 .005 .565 r
.5821 .38558 m .58377 .38594 L .58277 .38359 L F
.5821 .38558 m .58323 .38818 L .58377 .38594 L F
.426 .513 .845 r
.28488 .66983 m .2861 .67266 L .28122 .66668 L F
.198 0 0 r
.561 .3989 m .56399 .39892 L .56384 .39857 L F
0 0 0 r
.56176 .39891 m .5622 .39845 L .56399 .39892 L F
.561 .3989 m .5622 .39845 L .56176 .39891 L F
.484 .565 .862 r
.56147 .40266 m .5622 .39845 L .55955 .39957 L F
.56147 .40266 m .56427 .40264 L .5622 .39845 L F
.396 .698 .982 r
.56427 .40264 m .56483 .40062 L .5622 .39845 L F
.672 .197 .116 r
.5622 .39845 m .56483 .40062 L .56103 .39996 L F
0 0 0 r
.5622 .39845 m .56103 .39996 L .56255 .39809 L F
.581 .899 .636 r
.56517 .39577 m .56375 .39706 L .56357 .39683 L F
.56375 .39706 m .5622 .39845 L .56357 .39683 L F
.063 0 0 r
.56341 .39663 m .56357 .39683 L .56215 .3962 L F
0 0 .014 r
.56384 .39857 m .56399 .39892 L .56519 .39586 L F
.833 .973 .886 r
.56399 .39892 m .56517 .39577 L .56519 .39586 L F
.56399 .39892 m .5622 .39845 L .56517 .39577 L F
0 0 .146 r
.56489 .39445 m .56519 .39585 L .56517 .39577 L F
.651 .927 .646 r
.56517 .39577 m .56357 .39683 L .56507 .39525 L F
.152 .265 .728 r
.56403 .39141 m .56517 .39577 L .56698 .39324 L F
.651 .927 .646 r
.56517 .39577 m .56507 .39525 L .56698 .39324 L F
0 0 .146 r
.56519 .39585 m .56519 .39586 L .56517 .39577 L F
.56489 .39445 m .56517 .39577 L .56425 .39342 L F
0 0 .452 r
.5628 .39018 m .56425 .39342 L .56403 .39141 L F
0 0 .426 r
.56425 .39342 m .56517 .39577 L .56403 .39141 L F
.568 .761 .969 r
.56357 .39683 m .56302 .39264 L .56698 .39324 L F
.56357 .39683 m .5644 .39409 L .56302 .39264 L F
.063 0 0 r
.5653 .39727 m .56632 .39607 L .56357 .39683 L F
.5653 .39727 m .56357 .39683 L .56341 .39663 L F
0 0 0 r
.5622 .39845 m .56255 .39809 L .56357 .39683 L F
.561 .3989 m .55955 .39957 L .5622 .39845 L F
.546 .859 .563 r
.43882 .45242 m .43904 .45197 L .43656 .45304 L F
.43882 .45242 m .44061 .45063 L .43904 .45197 L F
.679 .947 .681 r
.47514 .42056 m .4736 .42232 L .47225 .42347 L F
.88 .638 .569 r
.41826 .55253 m .42235 .55118 L .42078 .55006 L F
.41826 .55253 m .42181 .55448 L .42235 .55118 L F
.347 .033 .283 r
.31641 .68713 m .32038 .68366 L .31854 .68564 L F
0 0 0 r
.31854 .68564 m .32038 .68366 L .32181 .68297 L F
.775 .391 .328 r
.45283 .57707 m .45477 .5799 L .45458 .57786 L F
.609 .929 .965 r
.43248 .60075 m .43597 .60015 L .4347 .59874 L F
.852 .829 .824 r
.43597 .60015 m .4375 .59519 L .4347 .59874 L F
.536 .232 .398 r
.52508 .40546 m .52395 .40701 L .52167 .40737 L F
.72 .9 .524 r
.52607 .40352 m .52395 .40701 L .52508 .40546 L F
.951 .653 .437 r
.33393 .5864 m .33329 .58721 L .33131 .58319 L F
.465 .001 .066 r
.32454 .506 m .32711 .50619 L .32911 .50413 L F
.697 .275 .24 r
.32911 .50413 m .32711 .50619 L .33143 .50659 L F
.921 .722 .616 r
.34995 .56813 m .35282 .56748 L .35071 .56705 L F
.34995 .56813 m .35245 .57051 L .35282 .56748 L F
.547 .401 .634 r
.26189 .5598 m .26174 .56382 L .25922 .56458 L F
.52 .329 .562 r
.26174 .56382 m .26039 .56654 L .25922 .56458 L F
.248 0 .263 r
.33844 .6742 m .34193 .67079 L .34088 .67343 L F
.044 0 0 r
.33844 .6742 m .34088 .67343 L .337 .67535 L F
.638 .965 .872 r
.59373 .34466 m .59575 .34234 L .59711 .34311 L F
.59373 .34466 m .59312 .34421 L .59575 .34234 L F
.259 0 0 r
.63147 .38858 m .62728 .39026 L .6302 .3873 L F
.982 .705 .33 r
.63006 .38454 m .63147 .38858 L .6302 .3873 L F
.63006 .38454 m .63147 .38858 L .6302 .3873 L F
.037 0 .445 r
.5628 .39018 m .56355 .38581 L .56217 .38812 L F
.827 .763 .792 r
.35149 .58342 m .35314 .58408 L .35185 .58043 L F
.851 .686 .677 r
.35149 .58342 m .35264 .58714 L .35314 .58408 L F
.816 .758 .798 r
.35185 .58043 m .35314 .58408 L .35579 .58072 L F
0 .511 .844 r
.29145 .67239 m .29335 .67339 L .29576 .67389 L F
.882 .924 .846 r
.3153 .60703 m .31733 .60769 L .31436 .61086 L F
.901 .986 .744 r
.31969 .60411 m .31733 .60769 L .3172 .60554 L F
.746 .939 .948 r
.3172 .60554 m .31733 .60769 L .3153 .60703 L F
.727 .651 .774 r
.32933 .63635 m .3308 .64019 L .32647 .63948 L F
.669 .621 .792 r
.33342 .63775 m .3308 .64019 L .32933 .63635 L F
.233 0 .076 r
.40588 .56093 m .4023 .5635 L .40348 .56157 L F
.292 .703 .974 r
.57814 .3509 m .58055 .35092 L .5821 .35202 L F
.539 0 0 r
.5821 .35202 m .58477 .35422 L .5868 .35541 L F
0 .224 .745 r
.58352 .35244 m .58477 .35422 L .5821 .35202 L F
.646 .61 .799 r
.2874 .64968 m .28892 .65366 L .29073 .65217 L F
0 0 .188 r
.28966 .65536 m .28892 .65366 L .28755 .65685 L F
.506 .827 1 r
.27883 .62674 m .28313 .62715 L .28131 .62612 L F
.846 .528 .449 r
.68648 .34754 m .68816 .34541 L .68474 .3444 L F
.873 .569 .471 r
.68648 .34754 m .6889 .34807 L .68816 .34541 L F
.726 .971 .721 r
.27002 .55115 m .26777 .5525 L .26706 .55418 L F
.401 .354 .69 r
.26777 .5525 m .26579 .55682 L .26706 .55418 L F
.904 .822 .755 r
.29741 .62249 m .30184 .61976 L .30025 .61881 L F
.29741 .62249 m .29949 .62394 L .30184 .61976 L F
.75 .946 .945 r
.30512 .61732 m .30184 .61976 L .30025 .61881 L F
.168 .472 .892 r
.30184 .61976 m .30271 .61829 L .30025 .61881 L F
.30184 .61976 m .30487 .62076 L .30271 .61829 L F
.832 .935 .897 r
.52138 .49211 m .52292 .49315 L .52533 .49064 L F
.777 .768 .845 r
.44824 .59327 m .44896 .58908 L .44659 .59024 L F
.44824 .59327 m .45095 .5906 L .44896 .58908 L F
.635 .964 .847 r
.59461 .39473 m .59791 .39255 L .59604 .39289 L F
0 0 0 r
.59604 .39289 m .59366 .39654 L .59461 .39473 L F
.962 .688 .467 r
.33714 .55418 m .33516 .55321 L .33527 .55047 L F
.953 .719 .547 r
.33714 .55418 m .33469 .55604 L .33516 .55321 L F
.33714 .55418 m .33675 .55735 L .33469 .55604 L F
.394 .094 .334 r
.258 .52782 m .25735 .53001 L .25974 .52932 L F
.822 .43 .309 r
.41799 .54622 m .41945 .54494 L .41624 .54429 L F
.41799 .54622 m .42083 .54702 L .41945 .54494 L F
.657 .797 .949 r
.36895 .47347 m .37322 .47412 L .37149 .47279 L F
.676 .383 .47 r
.37079 .47429 m .3703 .47525 L .37156 .47416 L F
.36713 .47491 m .3703 .47525 L .37079 .47429 L F
.645 .311 .392 r
.37156 .47416 m .37087 .47538 L .37072 .47528 L F
.515 .395 .654 r
.3703 .47525 m .37067 .47525 L .3704 .47508 L F
.645 .311 .392 r
.3711 .47424 m .36947 .47694 L .37079 .47429 L F
.37156 .47416 m .37057 .47548 L .3711 .47424 L F
.191 0 0 r
.36982 .47723 m .37067 .47525 L .3703 .47525 L F
.645 .311 .392 r
.37057 .47548 m .36947 .47694 L .3711 .47424 L F
.37087 .47538 m .36982 .47723 L .37072 .47528 L F
.069 0 0 r
.3739 .4753 m .37177 .47631 L .37156 .47416 L F
.37177 .47631 m .36982 .47723 L .37087 .47538 L F
.37177 .47631 m .37087 .47538 L .37156 .47416 L F
.694 .218 .117 r
.37215 .47118 m .37149 .47279 L .37381 .47144 L F
.433 .199 .458 r
.37381 .47144 m .37572 .47336 L .37322 .47412 L F
.653 .163 .076 r
.37488 .47368 m .37381 .47144 L .37149 .47279 L F
.116 0 0 r
.37322 .47412 m .3739 .4753 L .37149 .47279 L F
.37322 .47412 m .37572 .47336 L .3739 .4753 L F
.414 .16 .417 r
.37572 .47336 m .37776 .47483 L .3739 .4753 L F
.266 .673 .968 r
.37229 .47188 m .37488 .47368 L .37149 .47279 L F
.709 .279 .227 r
.37149 .47279 m .3739 .4753 L .37156 .47416 L F
.071 0 0 r
.3739 .4753 m .37776 .47483 L .37633 .47531 L F
.871 .924 .533 r
.37569 .47514 m .3739 .4753 L .37633 .47531 L F
.515 .395 .654 r
.37061 .47473 m .37363 .47497 L .37229 .47188 L F
.37363 .47497 m .3745 .47504 L .37393 .47423 L F
.37363 .47497 m .37393 .47423 L .37229 .47188 L F
.871 .924 .533 r
.37366 .47501 m .37323 .47594 L .3739 .4753 L F
.37363 .47497 m .37351 .47528 L .37366 .47501 L F
.37351 .47528 m .37323 .47594 L .37366 .47501 L F
.069 0 0 r
.3739 .4753 m .37264 .47652 L .36982 .47723 L F
.191 0 0 r
.36982 .47723 m .37313 .4759 L .37067 .47525 L F
.37313 .4759 m .37467 .47529 L .37351 .47528 L F
.37313 .4759 m .37351 .47528 L .37067 .47525 L F
.871 .924 .533 r
.3745 .47504 m .3739 .4753 L .37569 .47514 L F
.37363 .47497 m .37372 .47508 L .3745 .47504 L F
.37372 .47508 m .3739 .4753 L .3745 .47504 L F
.653 .163 .076 r
.37488 .47368 m .37572 .47336 L .37381 .47144 L F
.287 .685 .973 r
.3746 .47189 m .37488 .47368 L .37229 .47188 L F
.199 .276 .718 r
.37229 .47188 m .3745 .47504 L .37499 .47285 L F
.3745 .47504 m .37467 .47529 L .3747 .47503 L F
.3745 .47504 m .3747 .47503 L .37499 .47285 L F
.515 .395 .654 r
.37046 .47497 m .37467 .47529 L .3745 .47504 L F
.37046 .47497 m .3745 .47504 L .37061 .47473 L F
.37058 .47509 m .37467 .47529 L .37046 .47497 L F
.37067 .47525 m .37467 .47529 L .3704 .47508 L F
.871 .924 .533 r
.37324 .47577 m .37264 .47652 L .37323 .47594 L F
.191 0 0 r
.37313 .4759 m .37264 .47652 L .37467 .47529 L F
.36982 .47723 m .37264 .47652 L .37313 .4759 L F
.871 .924 .533 r
.37325 .47451 m .37264 .47652 L .37324 .47577 L F
.37325 .47451 m .37323 .47594 L .37363 .47497 L F
.878 .924 .851 r
.3747 .47503 m .37325 .47451 L .37499 .47285 L F
.871 .924 .533 r
.37325 .47451 m .37363 .47497 L .3748 .47507 L F
.878 .924 .851 r
.37467 .47529 m .37325 .47451 L .3747 .47503 L F
.871 .924 .533 r
.37325 .47451 m .3748 .47507 L .37569 .47514 L F
.515 .395 .654 r
.3704 .47508 m .37058 .47509 L .37046 .47497 L F
.645 .311 .392 r
.37072 .47528 m .36982 .47723 L .36947 .47694 L F
0 0 0 r
.37079 .47429 m .3703 .47525 L .3704 .47508 L F
.657 .305 .365 r
.36713 .47491 m .36982 .47723 L .3703 .47525 L F
.645 .311 .392 r
.37079 .47429 m .36947 .47694 L .36713 .47491 L F
0 0 0 r
.37121 .47349 m .37079 .47429 L .37092 .4742 L F
.37079 .47429 m .3704 .47508 L .37092 .4742 L F
.37149 .47279 m .3703 .47525 L .37121 .47349 L F
.37149 .47279 m .37092 .4742 L .37229 .47188 L F
.694 .218 .117 r
.36935 .47073 m .37149 .47279 L .37215 .47118 L F
.883 .652 .583 r
.33664 .51393 m .33725 .51783 L .33868 .51778 L F
.846 .545 .479 r
.33725 .51783 m .3388 .52025 L .33868 .51778 L F
.885 .842 .798 r
.62299 .3482 m .62022 .35228 L .61917 .35015 L F
.684 .535 .678 r
.62311 .35205 m .62022 .35228 L .62299 .3482 L F
.892 .677 .606 r
.34016 .56767 m .33702 .56921 L .3381 .5666 L F
.34016 .56767 m .33953 .57036 L .33702 .56921 L F
.231 0 .083 r
.26785 .52692 m .2703 .52628 L .2711 .5246 L F
.49 .087 .202 r
.2703 .52628 m .27296 .52621 L .2711 .5246 L F
.36 .111 .394 r
.2711 .5246 m .27296 .52621 L .27338 .52375 L F
.509 .325 .566 r
.59096 .40888 m .59308 .40543 L .59174 .40394 L F
.59096 .40888 m .5938 .40805 L .59308 .40543 L F
.959 .849 .691 r
.2493 .58062 m .24751 .58384 L .24686 .57991 L F
.338 .789 .952 r
.2493 .58062 m .24686 .57991 L .25078 .58013 L F
.656 .726 .901 r
.32006 .64085 m .31723 .64271 L .31555 .63964 L F
.818 .944 .907 r
.6725 .37414 m .67372 .37537 L .67537 .37331 L F
.763 .391 .35 r
.45073 .5794 m .45283 .57707 L .45039 .57693 L F
.45073 .5794 m .45477 .5799 L .45283 .57707 L F
.894 .853 .795 r
.69021 .36082 m .69155 .35943 L .69107 .35635 L F
.23 .14 .542 r
.24333 .57056 m .245 .57042 L .24451 .56712 L F
.048 0 0 r
.32761 .67979 m .32557 .68008 L .3274 .67934 L F
.022 0 0 r
.32385 .68211 m .32557 .68008 L .32761 .67979 L F
.311 .492 .875 r
.59577 .36624 m .59649 .3674 L .59464 .36812 L F
.812 .735 .78 r
.59705 .36865 m .59321 .36868 L .59464 .36812 L F
.047 .466 .882 r
.59464 .36812 m .59837 .36777 L .59705 .36865 L F
.59464 .36812 m .59792 .37024 L .59837 .36777 L F
.311 .492 .875 r
.59649 .3674 m .59776 .36942 L .59464 .36812 L F
.812 .735 .78 r
.59321 .36868 m .59155 .36869 L .59464 .36812 L F
.594 .924 .703 r
.28599 .53412 m .28278 .53663 L .2839 .53494 L F
.082 0 0 r
.38582 .50322 m .38831 .50274 L .39088 .50088 L F
.971 .72 .499 r
.39088 .50088 m .39039 .50397 L .39251 .50036 L F
.39088 .50088 m .38831 .50274 L .39039 .50397 L F
.768 .721 .809 r
.63006 .38454 m .63414 .38521 L .63272 .38138 L F
.28 .734 .956 r
.63279 .38453 m .63414 .38521 L .63006 .38454 L F
.6 .629 .852 r
.63272 .38138 m .63414 .38521 L .63634 .38397 L F
.64 .914 .98 r
.63634 .38397 m .63414 .38521 L .63279 .38453 L F
.834 .655 .66 r
.35433 .57706 m .35185 .58043 L .35579 .58072 L F
.831 .752 .776 r
.32033 .56372 m .31843 .56025 L .32018 .56077 L F
.704 .5 .61 r
.32325 .56251 m .32033 .56372 L .32018 .56077 L F
.751 .46 0 r
.59502 .43361 m .59483 .43255 L .59433 .43136 L F
.59502 .43361 m .59516 .43379 L .59483 .43255 L F
.953 .709 .532 r
.37331 .53105 m .37303 .53381 L .37126 .53002 L F
.602 .51 .722 r
.3504 .63678 m .34817 .64208 L .34709 .63674 L F
.3504 .63678 m .35184 .64255 L .34817 .64208 L F
0 .24 .661 r
.35133 .64393 m .34817 .64208 L .35184 .64255 L F
.807 .873 .896 r
.30738 .64609 m .30359 .64644 L .30628 .64317 L F
.783 .804 .87 r
.31038 .64341 m .30738 .64609 L .30628 .64317 L F
.978 .916 .652 r
.51697 .40946 m .51459 .40804 L .51454 .40969 L F
0 0 .165 r
.52315 .47775 m .52432 .47318 L .52244 .47509 L F
.433 .428 .754 r
.541 .44759 m .54175 .45125 L .54347 .44747 L F
.948 .936 .597 r
.5411 .45031 m .54175 .45125 L .53991 .45267 L F
.319 .205 .563 r
.54426 .45313 m .54175 .45125 L .54411 .45032 L F
.306 .207 .575 r
.54426 .45313 m .54215 .45404 L .54175 .45125 L F
.385 .372 .722 r
.54411 .45032 m .54175 .45125 L .54347 .44747 L F
.51 .356 .608 r
.25499 .53374 m .25735 .53001 L .25549 .53093 L F
.748 .664 .767 r
.37855 .46776 m .38245 .4697 L .38272 .46787 L F
.497 .84 .997 r
.53095 .46808 m .53368 .4672 L .53475 .46825 L F
.446 .81 .995 r
.53475 .46825 m .53368 .4672 L .53775 .46763 L F
.702 .87 .961 r
.54981 .3473 m .54676 .34874 L .54554 .34719 L F
.54554 .34719 m .54676 .34874 L .54981 .3473 L F
.294 .548 .921 r
.29437 .64673 m .29004 .64377 L .29242 .64329 L F
.454 .568 .88 r
.29671 .64656 m .29437 .64673 L .29242 .64329 L F
.887 .8 .758 r
.6355 .38046 m .63994 .378 L .63541 .37793 L F
.6355 .38046 m .63807 .38214 L .63994 .378 L F
.29 0 0 r
.40661 .45916 m .41087 .45695 L .40829 .4577 L F
.464 .062 .192 r
.64893 .34269 m .64858 .34413 L .64592 .34434 L F
.327 0 .051 r
.6526 .34161 m .64858 .34413 L .64893 .34269 L F
.759 .244 0 r
.32149 .51393 m .32163 .51564 L .3193 .51345 L F
.32149 .51393 m .32277 .51512 L .32163 .51564 L F
.699 .916 .576 r
.27274 .54763 m .27082 .54947 L .27002 .55115 L F
.704 .964 .717 r
.27082 .54947 m .26777 .5525 L .27002 .55115 L F
0 0 0 r
.63087 .34859 m .62968 .34893 L .63231 .34792 L F
.63087 .34859 m .62859 .35019 L .62968 .34893 L F
0 .135 .642 r
.50984 .4086 m .51103 .40942 L .50917 .40747 L F
.653 .264 0 r
.50917 .40747 m .51082 .41052 L .50984 .4086 L F
.509 .325 .566 r
.59096 .40888 m .59174 .40394 L .589 .40665 L F
.673 .805 .945 r
.31288 .62094 m .3155 .61997 L .31115 .61945 L F
.907 .502 .206 r
.33143 .50659 m .33464 .5108 L .33426 .50703 L F
.73 .746 .865 r
.55829 .40433 m .56277 .4049 L .56147 .40266 L F
.452 0 0 r
.55854 .40627 m .56132 .40683 L .56037 .40552 L F
.016 0 0 r
.56096 .40549 m .56037 .40552 L .56277 .4049 L F
.55854 .40627 m .56037 .40552 L .56096 .40549 L F
.146 0 .26 r
.56037 .40552 m .56096 .4055 L .56096 .40549 L F
.016 0 0 r
.56104 .40503 m .56277 .4049 L .5611 .40469 L F
.146 0 .26 r
.56037 .40552 m .56104 .40503 L .56277 .4049 L F
.016 0 0 r
.56096 .40549 m .56277 .4049 L .56104 .40503 L F
.463 .614 .914 r
.56147 .40266 m .56277 .4049 L .56427 .40264 L F
.146 0 .26 r
.56104 .40503 m .56427 .40264 L .56277 .4049 L F
.56037 .40552 m .56358 .40533 L .56427 .40264 L F
.016 0 0 r
.55854 .40627 m .56096 .40549 L .55829 .40433 L F
.56096 .40549 m .5611 .40469 L .55829 .40433 L F
.146 0 .26 r
.56096 .40549 m .56356 .4054 L .56358 .40533 L F
.56096 .4055 m .56356 .4054 L .56096 .40549 L F
.777 .978 .912 r
.47967 .42954 m .47887 .43193 L .48113 .43005 L F
.768 .971 .923 r
.47769 .43128 m .47887 .43193 L .47967 .42954 L F
.814 .755 .797 r
.31204 .558 m .31342 .56081 L .31608 .55745 L F
.142 .686 .731 r
.59603 .37379 m .59889 .37332 L .59989 .37324 L F
.134 0 0 r
.59989 .37324 m .59889 .37332 L .60284 .37361 L F
.946 .823 .692 r
.55943 .44981 m .56208 .44826 L .56085 .44711 L F
.55943 .44981 m .56112 .45089 L .56208 .44826 L F
.323 .793 .929 r
.63703 .39834 m .63565 .39796 L .63302 .39839 L F
.256 .714 .952 r
.63703 .39834 m .63867 .39736 L .63565 .39796 L F
.63703 .39834 m .64 .39844 L .63867 .39736 L F
.723 .604 .724 r
.55934 .37513 m .56209 .37549 L .56252 .37131 L F
.309 .237 .611 r
.56252 .37131 m .56209 .37549 L .56471 .37362 L F
.088 .06 .527 r
.56209 .37549 m .56427 .37583 L .56471 .37362 L F
.56209 .37549 m .56222 .37807 L .56427 .37583 L F
.929 .834 .384 r
.56874 .41256 m .56927 .41404 L .56944 .41151 L F
.789 .536 0 r
.56977 .41757 m .56927 .41404 L .56874 .41256 L F
.778 .36 .257 r
.36099 .51504 m .35772 .5159 L .35753 .51348 L F
.36099 .51504 m .36156 .5168 L .35772 .5159 L F
.059 .344 .82 r
.29638 .67504 m .29738 .67687 L .29753 .6748 L F
.732 .96 .942 r
.29753 .6748 m .29738 .67687 L .29578 .67637 L F
0 0 0 r
.29866 .67457 m .29753 .6748 L .2958 .67745 L F
.29979 .67343 m .29753 .6748 L .29866 .67457 L F
.059 .344 .82 r
.29576 .67389 m .29638 .67504 L .29753 .6748 L F
.789 .68 .744 r
.54913 .44369 m .55122 .44514 L .54754 .44433 L F
.791 .675 .736 r
.54754 .44433 m .55122 .44514 L .54978 .4472 L F
.52 .356 .598 r
.25092 .54688 m .25349 .54307 L .25111 .54428 L F
.782 .8 .867 r
.45695 .55668 m .45608 .5539 L .45284 .55634 L F
.687 .71 .865 r
.45695 .55668 m .4581 .5517 L .45608 .5539 L F
.45695 .55668 m .46019 .55426 L .4581 .5517 L F
.722 .688 .816 r
.3155 .61997 m .31973 .62077 L .31786 .61684 L F
.682 .683 .844 r
.31973 .62077 m .32059 .61615 L .31786 .61684 L F
.31973 .62077 m .32233 .61966 L .32059 .61615 L F
.795 .299 0 r
.58319 .37089 m .58708 .3743 L .58606 .37198 L F
.885 .854 .806 r
.53264 .35977 m .52934 .35992 L .53083 .35746 L F
.53083 .35746 m .53264 .35977 L .53443 .35815 L F
.53083 .35746 m .52934 .35992 L .53264 .35977 L F
.837 .517 0 r
.55397 .42795 m .5552 .43144 L .55335 .43045 L F
.827 .563 .54 r
.5552 .43144 m .55276 .43324 L .55335 .43045 L F
.5552 .43144 m .55546 .43467 L .55276 .43324 L F
.267 .729 .95 r
.39073 .52412 m .39082 .5235 L .38758 .52349 L F
.719 .234 .091 r
.38758 .52349 m .38988 .52582 L .39073 .52412 L F
.738 .806 .33 r
.39073 .52412 m .38988 .52582 L .39082 .5235 L F
.786 .779 .846 r
.31436 .61086 m .30996 .61045 L .31213 .60963 L F
.882 .924 .846 r
.3153 .60703 m .31436 .61086 L .31213 .60963 L F
.256 0 0 r
.308 .66328 m .30858 .66473 L .3062 .66538 L F
.308 .66328 m .31134 .66309 L .30858 .66473 L F
.532 .303 .513 r
.63272 .38138 m .63541 .37793 L .63264 .37816 L F
.613 .437 .62 r
.66601 .32806 m .66871 .32474 L .66593 .32549 L F
.282 .094 .438 r
.27498 .54591 m .27274 .54763 L .27543 .54381 L F
0 0 0 r
.27276 .54812 m .27274 .54763 L .27498 .54591 L F
.27276 .54812 m .27082 .54947 L .27274 .54763 L F
.48 .256 .496 r
.61604 .35149 m .61917 .35015 L .62022 .35228 L F
.426 .393 .719 r
.62322 .35441 m .62022 .35228 L .62311 .35205 L F
.919 .734 .637 r
.38481 .56035 m .38105 .56258 L .3813 .55972 L F
.38481 .56035 m .38354 .56349 L .38105 .56258 L F
.184 .606 .943 r
.63944 .38203 m .63807 .38214 L .6355 .38046 L F
.075 0 0 r
.62405 .34344 m .62686 .34305 L .62817 .34227 L F
.448 0 .018 r
.62686 .34305 m .6309 .34139 L .62817 .34227 L F
.637 .113 0 r
.2988 .6859 m .30291 .68671 L .30128 .68775 L F
0 .448 .733 r
.30291 .68671 m .30336 .68669 L .30128 .68775 L F
.30291 .68671 m .30517 .68727 L .30336 .68669 L F
.782 .661 .729 r
.34714 .59637 m .35156 .5971 L .35205 .59422 L F
.788 .637 .694 r
.34714 .59637 m .34914 .60019 L .35156 .5971 L F
.754 .514 .57 r
.53562 .43061 m .53938 .4283 L .53675 .42862 L F
.916 .618 .465 r
.55281 .41201 m .5525 .41388 L .55068 .41093 L F
.55281 .41201 m .55452 .41521 L .5525 .41388 L F
.726 .99 .843 r
.50277 .39989 m .50309 .39825 L .50567 .39862 L F
.50277 .39989 m .50121 .40005 L .50309 .39825 L F
.983 .877 .648 r
.38564 .56728 m .38307 .56938 L .38362 .56655 L F
.38564 .56728 m .38428 .57034 L .38307 .56938 L F
.838 .527 .463 r
.37126 .53002 m .3675 .52654 L .3707 .52795 L F
.597 .146 0 r
.57337 .36265 m .57486 .3647 L .57351 .36294 L F
.444 .874 .783 r
.44296 .44956 m .44761 .44772 L .44554 .44855 L F
0 0 0 r
.44761 .44772 m .449 .44752 L .44554 .44855 L F
.44761 .44772 m .45027 .44722 L .449 .44752 L F
.751 .675 .777 r
.33862 .61385 m .34273 .61434 L .34112 .61056 L F
.77 .706 .791 r
.34273 .61434 m .34552 .611 L .34112 .61056 L F
.561 .909 .695 r
.44855 .4376 m .44465 .44028 L .44765 .43743 L F
.606 .954 .875 r
.44983 .43599 m .45179 .43586 L .44855 .4376 L F
.606 .954 .878 r
.44983 .43599 m .44855 .4376 L .44765 .43743 L F
.567 .844 .997 r
.44102 .54394 m .43699 .54377 L .4391 .54262 L F
.687 .402 .485 r
.43976 .5458 m .43699 .54377 L .44102 .54394 L F
.326 .722 .981 r
.4391 .54262 m .4421 .54307 L .44102 .54394 L F
0 0 .126 r
.4421 .54307 m .43976 .5458 L .44102 .54394 L F
.032 0 0 r
.42223 .45862 m .42187 .45931 L .41654 .4622 L F
.266 0 0 r
.42499 .4579 m .42187 .45931 L .42223 .45862 L F
.47 .551 .856 r
.5202 .38431 m .52169 .38064 L .5198 .38129 L F
.5202 .38431 m .52262 .38493 L .52169 .38064 L F
.986 .786 .551 r
.39769 .53017 m .39592 .53295 L .39572 .53021 L F
.39769 .53017 m .39788 .5345 L .39592 .53295 L F
.036 .602 .781 r
.29511 .66215 m .29436 .66229 L .29397 .66215 L F
.29511 .66215 m .29708 .6624 L .29436 .66229 L F
.187 .577 .939 r
.29004 .64377 m .28668 .6421 L .28841 .64214 L F
.515 .643 .913 r
.29111 .64153 m .29004 .64377 L .28841 .64214 L F
.29111 .64153 m .29242 .64329 L .29004 .64377 L F
.814 .755 .797 r
.31204 .558 m .31608 .55745 L .31464 .55671 L F
.327 0 .051 r
.6526 .34161 m .65137 .34365 L .64858 .34413 L F
.425 0 .075 r
.6553 .34154 m .65137 .34365 L .6526 .34161 L F
.597 .716 .927 r
.41828 .60048 m .4223 .60194 L .421 .60005 L F
.441 .615 .924 r
.4223 .60194 m .42374 .59972 L .421 .60005 L F
.4223 .60194 m .42578 .60289 L .42374 .59972 L F
.977 .799 .597 r
.55452 .41521 m .55243 .41677 L .5525 .41388 L F
.55452 .41521 m .55408 .41796 L .55243 .41677 L F
.689 .678 .834 r
.34965 .63414 m .34709 .63674 L .34537 .63302 L F
.613 .552 .761 r
.34965 .63414 m .3504 .63678 L .34709 .63674 L F
0 0 0 r
.49281 .43745 m .49166 .4413 L .49262 .4393 L F
0 0 .54 r
.49262 .4393 m .49166 .4413 L .49316 .44374 L F
.836 .924 .891 r
.50563 .50785 m .50721 .5037 L .50458 .50691 L F
.50563 .50785 m .50874 .50506 L .50721 .5037 L F
.239 0 .321 r
.34088 .67343 m .34193 .67079 L .34367 .66996 L F
.488 .839 .995 r
.52167 .40737 m .52395 .40701 L .52272 .40602 L F
.603 .917 .668 r
.52272 .40602 m .52082 .4078 L .52167 .40737 L F
.884 .864 .815 r
.56835 .43161 m .57088 .42815 L .56933 .42665 L F
.712 .658 .794 r
.35317 .49105 m .35734 .4918 L .356 .48997 L F
.693 .652 .805 r
.356 .48997 m .35734 .4918 L .35994 .49095 L F
0 .334 .815 r
.31115 .54839 m .31097 .54859 L .30926 .54646 L F
.541 .169 .286 r
.5393 .45804 m .53864 .46056 L .53603 .45801 L F
.261 .173 .563 r
.53603 .45801 m .53864 .46056 L .53847 .45623 L F
.293 .175 .543 r
.53603 .45801 m .53864 .46056 L .53629 .46084 L F
.53603 .45801 m .53864 .46056 L .53629 .46084 L F
.245 .041 .392 r
.39012 .47081 m .39228 .47043 L .38967 .47112 L F
.39012 .47081 m .39205 .47032 L .39228 .47043 L F
.537 .865 .587 r
.32293 .57463 m .32393 .57446 L .32245 .57223 L F
.719 .839 .938 r
.32422 .64085 m .32006 .64085 L .32223 .63898 L F
.772 .804 .879 r
.32488 .63642 m .32422 .64085 L .32223 .63898 L F
.32488 .63642 m .32647 .63948 L .32422 .64085 L F
.262 .702 .961 r
.62355 .39938 m .62227 .39849 L .6191 .3985 L F
.596 .886 .991 r
.62508 .39746 m .62355 .39938 L .62632 .39827 L F
.62508 .39746 m .62227 .39849 L .62355 .39938 L F
.846 .685 .684 r
.35 .57634 m .35436 .5741 L .35222 .57293 L F
.35 .57634 m .35433 .57706 L .35436 .5741 L F
.751 .65 .749 r
.34552 .611 m .34798 .61041 L .3481 .60767 L F
.765 .662 .748 r
.34798 .61041 m .35076 .60655 L .3481 .60767 L F
0 0 0 r
.49307 .43357 m .49281 .43745 L .49315 .4366 L F
.49315 .4366 m .49281 .43745 L .49262 .4393 L F
.731 .528 .617 r
.66871 .32474 m .67287 .3278 L .67254 .32546 L F
.954 .875 .72 r
.56699 .43414 m .56835 .43161 L .56692 .43029 L F
.884 .864 .815 r
.56835 .43161 m .56933 .42665 L .56692 .43029 L F
.131 0 .132 r
.56037 .40552 m .56132 .40683 L .56356 .4054 L F
.833 .944 .895 r
.47277 .54146 m .47215 .54442 L .47554 .54103 L F
.47277 .54146 m .47081 .54339 L .47215 .54442 L F
.73 .967 .701 r
.34532 .50097 m .34601 .49935 L .34789 .49826 L F
.036 0 0 r
.34789 .49826 m .34802 .4988 L .35026 .49926 L F
.34789 .49826 m .34601 .49935 L .34802 .4988 L F
.983 .789 .566 r
.39788 .5345 m .39544 .53573 L .39592 .53295 L F
.39788 .5345 m .3971 .5369 L .39544 .53573 L F
.596 .45 .654 r
.26409 .55771 m .26529 .56331 L .26189 .5598 L F
.472 .832 .994 r
.26529 .56331 m .26174 .56382 L .26189 .5598 L F
.409 0 0 r
.31381 .68664 m .31641 .68713 L .31342 .68731 L F
.611 .95 .922 r
.31342 .68731 m .31641 .68713 L .31854 .68564 L F
.369 .822 .934 r
.31422 .58657 m .31645 .58538 L .31616 .58593 L F
.076 0 0 r
.3182 .58459 m .3205 .58401 L .322 .58473 L F
.3218 .58497 m .322 .58473 L .32268 .58506 L F
.3182 .58459 m .322 .58473 L .3218 .58497 L F
0 0 0 r
.32452 .58366 m .32148 .58661 L .32268 .58506 L F
.263 0 .242 r
.32452 .58366 m .32431 .5858 L .32196 .58647 L F
.32217 .58593 m .32196 .58647 L .32148 .58661 L F
.32452 .58366 m .32196 .58647 L .32217 .58593 L F
.693 .769 .281 r
.32299 .58356 m .32111 .58867 L .32148 .58661 L F
.32303 .58351 m .32111 .58867 L .32299 .58356 L F
.402 .126 .376 r
.32148 .58661 m .32111 .58867 L .31873 .58921 L F
.109 0 0 r
.32111 .58867 m .31677 .59106 L .31873 .58921 L F
.3211 .58868 m .3195 .59037 L .31677 .59106 L F
.32111 .58867 m .3195 .59037 L .3211 .58868 L F
.988 .725 .426 r
.3195 .59037 m .31988 .59402 L .31886 .59105 L F
.472 .829 .995 r
.31677 .59106 m .3195 .59037 L .3184 .58971 L F
.988 .725 .426 r
.3195 .59037 m .31886 .59105 L .3184 .58971 L F
.693 .769 .281 r
.32308 .58338 m .32097 .58893 L .32106 .58876 L F
.32133 .58806 m .32106 .58876 L .32111 .58867 L F
.32308 .58338 m .32106 .58876 L .32133 .58806 L F
.32308 .58338 m .32303 .58351 L .32299 .58356 L F
.076 0 0 r
.3182 .58459 m .31616 .58593 L .3205 .58401 L F
.469 .893 .875 r
.31616 .58593 m .31833 .58438 L .3205 .58401 L F
.018 0 .1 r
.31422 .58657 m .31592 .5878 L .31645 .58538 L F
.31422 .58657 m .31401 .58901 L .31592 .5878 L F
.791 .675 .736 r
.54754 .44433 m .54978 .4472 L .54697 .44713 L F
.956 .875 .716 r
.54978 .4472 m .54674 .4499 L .54697 .44713 L F
.54978 .4472 m .54818 .45118 L .54674 .4499 L F
.808 .72 .768 r
.3481 .59352 m .35205 .59422 L .35043 .59041 L F
.782 .661 .729 r
.34714 .59637 m .35205 .59422 L .3481 .59352 L F
.769 .703 .79 r
.35043 .59041 m .35205 .59422 L .35488 .59096 L F
.5 .597 .882 r
.28651 .52667 m .28607 .53061 L .28533 .52669 L F
.28651 .52667 m .28838 .53002 L .28607 .53061 L F
.409 .244 .543 r
.28855 .53311 m .28607 .53061 L .28838 .53002 L F
.28855 .53311 m .28599 .53412 L .28607 .53061 L F
0 .05 .601 r
.56252 .37131 m .56471 .37362 L .56379 .37195 L F
.201 0 0 r
.60437 .39168 m .60581 .39294 L .60342 .39252 L F
.60437 .39168 m .60711 .39124 L .60581 .39294 L F
0 0 .276 r
.59599 .38663 m .59586 .386 L .594 .38402 L F
0 .483 .841 r
.59676 .3883 m .5962 .38866 L .59586 .386 L F
0 0 .276 r
.59644 .38723 m .59586 .386 L .59599 .38663 L F
0 0 .106 r
.59586 .386 m .5962 .38866 L .5958 .38573 L F
.59586 .386 m .5958 .38573 L .59569 .3849 L F
.096 .041 .499 r
.59743 .38042 m .59569 .3849 L .59914 .38205 L F
.59743 .38042 m .59827 .3826 L .59569 .3849 L F
0 0 .037 r
.59827 .3826 m .59586 .386 L .59569 .3849 L F
.883 .866 .817 r
.53878 .47645 m .54296 .47448 L .54222 .4738 L F
.53878 .47645 m .54041 .47799 L .54296 .47448 L F
.837 .998 .828 r
.54499 .47088 m .54296 .47448 L .54645 .47196 L F
.54499 .47088 m .54222 .4738 L .54296 .47448 L F
.523 .917 .903 r
.326 .56138 m .3276 .56154 L .32988 .56038 L F
.509 .232 .43 r
.51018 .44028 m .50745 .4381 L .50725 .44093 L F
.51018 .44028 m .51034 .43761 L .50745 .4381 L F
.586 .064 0 r
.6191 .3985 m .61514 .39479 L .61806 .39807 L F
.903 .761 .695 r
.40174 .57356 m .40046 .57702 L .4032 .57627 L F
.635 .171 .133 r
.40046 .57702 m .40178 .57738 L .4032 .57627 L F
.547 .391 .621 r
.4032 .57627 m .4055 .57423 L .40174 .57356 L F
.4032 .57627 m .40582 .57676 L .4055 .57423 L F
.49 0 .018 r
.40178 .57738 m .40582 .57676 L .4032 .57627 L F
.774 .778 .856 r
.43616 .57066 m .43433 .57366 L .43179 .5702 L F
.957 .686 .481 r
.28196 .65452 m .27777 .65894 L .27878 .65671 L F
.28196 .65452 m .27998 .6584 L .27777 .65894 L F
.793 .814 .332 r
.28101 .65644 m .28196 .65452 L .27878 .65671 L F
.896 .836 .779 r
.58477 .35422 m .58532 .35862 L .5868 .35541 L F
.5868 .35541 m .58532 .35862 L .58477 .35422 L F
.421 0 0 r
.32731 .53231 m .33063 .5331 L .32922 .53243 L F
.847 .675 .669 r
.34964 .57903 m .35433 .57706 L .35 .57634 L F
.34964 .57903 m .35185 .58043 L .35433 .57706 L F
.681 .693 .855 r
.32233 .61966 m .32646 .62056 L .32521 .6171 L F
.796 .754 .814 r
.32521 .6171 m .32646 .62056 L .32902 .6173 L F
.863 .765 .258 r
.52593 .40305 m .52653 .40173 L .52577 .40015 L F
.52593 .40305 m .52607 .40352 L .52653 .40173 L F
.903 .509 .088 r
.39463 .51233 m .39525 .51106 L .39448 .50925 L F
.39463 .51233 m .39606 .51361 L .39525 .51106 L F
.159 0 .383 r
.62441 .35248 m .62311 .35205 L .6257 .35158 L F
.62508 .3527 m .62322 .35441 L .62311 .35205 L F
.895 .981 .807 r
.62371 .35144 m .62227 .35317 L .62268 .35369 L F
.62343 .35317 m .62268 .35369 L .62322 .35441 L F
.62371 .35144 m .62268 .35369 L .62343 .35317 L F
.159 0 .383 r
.62508 .3527 m .62441 .35248 L .62631 .35147 L F
.62441 .35248 m .6257 .35158 L .62631 .35147 L F
0 0 .329 r
.40541 .56856 m .40435 .56788 L .40352 .56585 L F
.40541 .56856 m .40528 .57174 L .40468 .56925 L F
.722 .485 .567 r
.40535 .5654 m .40541 .56856 L .40352 .56585 L F
0 0 .329 r
.40541 .56856 m .40468 .56925 L .40435 .56788 L F
.722 .485 .567 r
.40535 .5654 m .40102 .56788 L .40541 .56856 L F
.305 .784 .918 r
.40705 .56701 m .40394 .56811 L .40535 .5654 L F
.836 .797 .814 r
.41002 .56689 m .40528 .57174 L .40541 .56856 L F
.41002 .56689 m .40541 .56856 L .40789 .56781 L F
.305 .784 .918 r
.40789 .56781 m .40606 .56795 L .40705 .56701 L F
.40606 .56795 m .40394 .56811 L .40705 .56701 L F
.40422 .56809 m .40664 .5674 L .40394 .56811 L F
.40789 .56781 m .40664 .5674 L .40422 .56809 L F
.40789 .56781 m .40535 .5654 L .40768 .56494 L F
0 0 0 r
.40541 .56856 m .40664 .5674 L .40789 .56781 L F
.13 0 .097 r
.40561 .56904 m .40761 .56712 L .40664 .5674 L F
.923 .598 .408 r
.41002 .56689 m .40789 .56781 L .40768 .56494 L F
.66 .96 .935 r
.40877 .56601 m .40664 .5674 L .40789 .56781 L F
.40877 .56601 m .40664 .5674 L .40789 .56781 L F
.13 0 .097 r
.40761 .56712 m .40877 .56601 L .40664 .5674 L F
0 0 0 r
.40571 .56828 m .40371 .57017 L .40624 .56778 L F
.40541 .56856 m .40453 .5694 L .40571 .56828 L F
.40453 .5694 m .40371 .57017 L .40571 .56828 L F
.40541 .56856 m .40624 .56778 L .40664 .5674 L F
.925 .779 .681 r
.38193 .55442 m .38108 .5572 L .37985 .55324 L F
.489 .894 .771 r
.49029 .40771 m .49178 .40644 L .49352 .40592 L F
.482 .899 .872 r
.49029 .40771 m .48922 .40764 L .49178 .40644 L F
.463 .025 .119 r
.39205 .47032 m .39634 .46828 L .39629 .46969 L F
.532 .079 .123 r
.39634 .46828 m .39865 .46976 L .39629 .46969 L F
.954 .801 .355 r
.49666 .43098 m .49737 .42812 L .49718 .42658 L F
.613 .616 .831 r
.49737 .42812 m .50029 .42548 L .49718 .42658 L F
.49737 .42812 m .50084 .42757 L .50029 .42548 L F
.686 .449 .557 r
.49666 .43098 m .50084 .42757 L .49737 .42812 L F
.948 .693 .518 r
.33467 .51768 m .33664 .51393 L .33469 .51237 L F
.33467 .51768 m .33725 .51783 L .33664 .51393 L F
.923 .569 .342 r
.66529 .34468 m .66261 .34359 L .66226 .34123 L F
.975 .738 .515 r
.66529 .34468 m .66287 .34621 L .66261 .34359 L F
.66529 .34468 m .66483 .3475 L .66287 .34621 L F
.409 0 0 r
.31381 .68664 m .31342 .68731 L .31206 .68906 L F
.665 .958 .941 r
.46846 .43737 m .46938 .43502 L .46774 .43663 L F
.46846 .43737 m .47229 .43526 L .46938 .43502 L F
.868 .731 .709 r
.34669 .54664 m .34865 .54763 L .34712 .54376 L F
.903 .778 .713 r
.34468 .54962 m .34865 .54763 L .34669 .54664 L F
.34468 .54962 m .34798 .55035 L .34865 .54763 L F
.474 .895 .861 r
.45444 .43465 m .45179 .43586 L .44983 .43599 L F
.954 .932 .733 r
.31929 .5119 m .31706 .51256 L .31829 .51056 L F
.599 .901 .986 r
.31706 .51256 m .31798 .51117 L .31829 .51056 L F
.994 .802 .432 r
.31894 .50925 m .31929 .5119 L .31829 .51056 L F
.599 .901 .986 r
.31798 .51117 m .32018 .50785 L .31829 .51056 L F
.994 .802 .432 r
.31868 .50722 m .31894 .50925 L .31829 .51056 L F
.874 .487 .303 r
.31929 .5119 m .3193 .51345 L .31706 .51256 L F
.257 0 0 r
.41672 .45384 m .4192 .45338 L .42075 .45193 L F
.417 .003 .144 r
.4192 .45338 m .42326 .451 L .42075 .45193 L F
.879 .816 .782 r
.34542 .50322 m .34601 .49935 L .34532 .50097 L F
.753 .982 .91 r
.29779 .61828 m .29518 .62034 L .29393 .61988 L F
.851 .998 .789 r
.64666 .37932 m .64433 .3821 L .64498 .3794 L F
.858 .985 .705 r
.64498 .3794 m .64433 .3821 L .64305 .38364 L F
.7 .687 .834 r
.63944 .38203 m .64138 .38574 L .63634 .38397 L F
.728 .699 .823 r
.64305 .38364 m .64138 .38574 L .63944 .38203 L F
.651 .155 .059 r
.26441 .52629 m .26608 .5274 L .26785 .52692 L F
.596 .195 .253 r
.26608 .5274 m .2703 .52628 L .26785 .52692 L F
.753 .987 .898 r
.52092 .48062 m .52097 .48103 L .51658 .48386 L F
.72 .974 .925 r
.52193 .47969 m .52097 .48103 L .52092 .48062 L F
.753 .625 .718 r
.37855 .46776 m .38272 .46787 L .38315 .46552 L F
.684 .559 .707 r
.38272 .46787 m .38536 .46448 L .38315 .46552 L F
.194 .268 .712 r
.38516 .46988 m .38457 .47163 L .38272 .46787 L F
.567 0 0 r
.38181 .46809 m .38272 .46787 L .3808 .46809 L F
.38181 .46809 m .38516 .46988 L .38272 .46787 L F
.627 .478 .661 r
.38272 .46787 m .38565 .46786 L .38536 .46448 L F
.574 .235 .358 r
.38272 .46787 m .38516 .46988 L .38565 .46786 L F
.984 .747 .348 r
.57283 .35876 m .57257 .36096 L .57207 .3585 L F
.73 .201 0 r
.32277 .51512 m .32435 .51695 L .32163 .51564 L F
.843 .487 .379 r
.36794 .50063 m .37203 .50365 L .36975 .50085 L F
0 0 .255 r
.24696 .55739 m .2482 .55854 L .24912 .55578 L F
.24696 .55739 m .24651 .56002 L .2482 .55854 L F
.325 .185 .532 r
.42066 .59648 m .42308 .5942 L .421 .59664 L F
.42066 .59648 m .42132 .59281 L .42308 .5942 L F
0 .254 .747 r
.27815 .67355 m .27993 .67416 L .27857 .67428 L F
0 0 0 r
.27818 .67174 m .27804 .67165 L .27794 .67296 L F
.27882 .66854 m .2782 .67101 L .27818 .67174 L F
.2782 .67101 m .27804 .67165 L .27818 .67174 L F
.27882 .66854 m .27794 .67296 L .27698 .67155 L F
0 .254 .747 r
.27698 .67155 m .27794 .67296 L .27993 .67416 L F
.27698 .67155 m .27816 .6726 L .27815 .67355 L F
.27816 .6726 m .27993 .67416 L .27815 .67355 L F
.226 0 0 r
.3255 .57896 m .32947 .57614 L .32715 .57717 L F
.743 .446 .478 r
.37197 .50643 m .37606 .5044 L .37203 .50365 L F
.37197 .50643 m .37616 .50688 L .37606 .5044 L F
.692 .405 .483 r
.37606 .5044 m .37616 .50688 L .38003 .5067 L F
.895 .892 .819 r
.68763 .36443 m .68755 .3613 L .68645 .36325 L F
.68763 .36443 m .69021 .36082 L .68755 .3613 L F
.819 .967 .899 r
.65964 .39914 m .66373 .39762 L .6625 .39623 L F
.923 .91 .789 r
.6625 .39623 m .66373 .39762 L .66494 .39554 L F
.741 .826 .917 r
.4266 .60604 m .42771 .60247 L .42578 .60289 L F
.4266 .60604 m .42984 .60383 L .42771 .60247 L F
0 0 .278 r
.57091 .37308 m .57123 .37619 L .57061 .37788 L F
0 .112 .659 r
.57123 .37619 m .57271 .38016 L .57061 .37788 L F
0 0 0 r
.64383 .39776 m .64297 .39793 L .64 .39844 L F
.265 .673 .968 r
.64383 .39776 m .64671 .39804 L .6458 .39691 L F
.819 .821 .851 r
.32933 .63635 m .32647 .63948 L .32488 .63642 L F
.573 .189 .276 r
.4076 .46777 m .40301 .46999 L .40317 .4682 L F
.4076 .46777 m .40547 .47034 L .40301 .46999 L F
.579 .197 .281 r
.40946 .46974 m .40547 .47034 L .4076 .46777 L F
.883 .912 .842 r
.68755 .3613 m .69021 .36082 L .68916 .35962 L F
.894 .853 .795 r
.69021 .36082 m .69107 .35635 L .68916 .35962 L F
.813 .649 .679 r
.66494 .39554 m .66288 .39127 L .66352 .3941 L F
.923 .91 .789 r
.6625 .39623 m .66494 .39554 L .66352 .3941 L F
.473 .773 .996 r
.28325 .66602 m .28122 .66668 L .28153 .66471 L F
.83 .976 .674 r
.28153 .66471 m .28122 .66668 L .27882 .66854 L F
.426 .513 .845 r
.28488 .66983 m .28122 .66668 L .28325 .66602 L F
.363 .204 .527 r
.45699 .54052 m .45718 .54351 L .4551 .54384 L F
.505 .132 .266 r
.65926 .33061 m .66322 .32793 L .65959 .32933 L F
.918 .715 .613 r
.34421 .55252 m .34798 .55035 L .34468 .54962 L F
.34421 .55252 m .34663 .5535 L .34798 .55035 L F
.854 .502 .386 r
.37606 .53762 m .37333 .53889 L .37283 .53646 L F
.37606 .53762 m .3765 .54001 L .37333 .53889 L F
.851 .686 .677 r
.35149 .58342 m .34882 .58638 L .35264 .58714 L F
.851 .682 .672 r
.34882 .58638 m .35043 .59041 L .35264 .58714 L F
.726 .503 .588 r
.35264 .58714 m .35043 .59041 L .35257 .58939 L F
.203 0 0 r
.35218 .64267 m .35366 .64309 L .35133 .64393 L F
.35218 .64267 m .35476 .64297 L .35373 .64308 L F
.35218 .64267 m .35366 .64309 L .35133 .64393 L F
0 0 .332 r
.35297 .64306 m .35288 .64335 L .35288 .64301 L F
.96 .775 .609 r
.35133 .64393 m .35184 .64255 L .34892 .64138 L F
.976 .694 .424 r
.34948 .64446 m .35133 .64393 L .34892 .64138 L F
.916 .98 .738 r
.35005 .64534 m .35133 .64393 L .34948 .64446 L F
.787 .315 .112 r
.34892 .64138 m .34904 .64144 L .35085 .64439 L F
.34904 .64144 m .35288 .64335 L .35085 .64439 L F
.814 .984 .709 r
.35085 .64439 m .35288 .64335 L .35297 .64306 L F
.203 0 0 r
.35218 .64267 m .35224 .64268 L .35227 .6427 L F
.35224 .64268 m .35476 .64297 L .35227 .6427 L F
.35227 .6427 m .35399 .64289 L .35334 .643 L F
0 0 .332 r
.35374 .64046 m .35297 .64306 L .35287 .63917 L F
.35297 .64306 m .35288 .64301 L .35287 .63917 L F
.104 .173 .651 r
.35287 .63917 m .35184 .64255 L .3504 .63678 L F
.791 .911 .922 r
.34892 .64138 m .35184 .64255 L .35287 .63917 L F
.34892 .64138 m .35287 .63917 L .35288 .64301 L F
.35207 .64295 m .35288 .64301 L .35288 .64335 L F
.34892 .64138 m .35288 .64301 L .35207 .64295 L F
.814 .984 .709 r
.35167 .64328 m .35297 .64306 L .35374 .64046 L F
.35085 .64439 m .35297 .64306 L .35167 .64328 L F
.35085 .64439 m .35311 .64132 L .35231 .64222 L F
.35311 .64132 m .35374 .64046 L .35231 .64222 L F
.958 .617 .29 r
.3515 .64312 m .35231 .64222 L .35081 .64175 L F
.515 .52 .799 r
.35231 .64222 m .35166 .64571 L .35085 .64439 L F
.203 0 0 r
.35218 .64267 m .35373 .64308 L .3536 .64307 L F
.617 .612 .823 r
.34948 .64446 m .34828 .6491 L .35005 .64534 L F
.34948 .64446 m .35455 .64983 L .34828 .6491 L F
.656 .154 0 r
.35142 .647 m .35455 .64983 L .34948 .64446 L F
.515 .52 .799 r
.35231 .64222 m .35403 .64654 L .35142 .647 L F
.958 .617 .29 r
.35217 .64447 m .35231 .64222 L .3515 .64312 L F
.515 .52 .799 r
.35166 .64571 m .35142 .647 L .35085 .64439 L F
.203 0 0 r
.35334 .643 m .35476 .64297 L .35366 .64309 L F
.35399 .64289 m .35476 .64297 L .35334 .643 L F
.3536 .64307 m .35373 .64308 L .35366 .64309 L F
.221 0 0 r
.39704 .46195 m .3951 .46157 L .39421 .46295 L F
.39704 .46195 m .39759 .46127 L .3951 .46157 L F
.063 .297 .783 r
.54152 .43063 m .54137 .43138 L .53938 .4283 L F
.619 .871 .989 r
.54152 .43063 m .54402 .43066 L .54137 .43138 L F
.754 .514 .57 r
.53562 .43061 m .5413 .43123 L .53938 .4283 L F
.789 .842 .382 r
.54148 .4308 m .54135 .43111 L .54137 .43138 L F
.517 0 0 r
.53851 .43217 m .54125 .43131 L .53562 .43061 L F
.789 .842 .382 r
.54135 .43111 m .54103 .43205 L .54137 .43138 L F
.517 0 0 r
.54125 .43131 m .54145 .43124 L .5413 .43123 L F
.54125 .43131 m .5413 .43123 L .53562 .43061 L F
.789 .842 .382 r
.54132 .4312 m .54056 .433 L .54103 .43205 L F
.54135 .43111 m .5413 .43123 L .54132 .4312 L F
.5413 .43123 m .54056 .433 L .54132 .4312 L F
.508 .449 .726 r
.53938 .4283 m .54135 .43111 L .54152 .43063 L F
.54135 .43111 m .54145 .43124 L .54152 .43063 L F
.754 .514 .57 r
.5413 .43123 m .54145 .43124 L .54135 .43111 L F
.5413 .43123 m .54135 .43111 L .53938 .4283 L F
.789 .842 .382 r
.54152 .43063 m .54093 .43212 L .54148 .4308 L F
.972 .874 .678 r
.54152 .43063 m .54145 .43124 L .54125 .43131 L F
.54152 .43063 m .54125 .43131 L .53851 .43217 L F
.789 .842 .382 r
.54152 .43063 m .54056 .433 L .54093 .43212 L F
.54152 .43063 m .54042 .43329 L .54056 .433 L F
.217 .729 .686 r
.33485 .67601 m .337 .67535 L .33634 .67554 L F
.33485 .67601 m .33634 .67554 L .33433 .67667 L F
.647 .674 .862 r
.538 .42101 m .53943 .41667 L .53666 .41741 L F
.538 .42101 m .54013 .41995 L .53943 .41667 L F
.294 0 0 r
.63904 .34514 m .6378 .34649 L .63496 .34671 L F
.371 0 0 r
.64172 .34596 m .63904 .34514 L .64166 .34531 L F
.64172 .34596 m .6378 .34649 L .63904 .34514 L F
.748 .309 .209 r
.30285 .65609 m .30509 .65861 L .30657 .65679 L F
.233 0 0 r
.30285 .65609 m .30657 .65679 L .30618 .65692 L F
.661 .88 .515 r
.30618 .65692 m .30657 .65679 L .30726 .65544 L F
.657 .863 .478 r
.30657 .65679 m .30509 .65861 L .30726 .65544 L F
.924 .58 .365 r
.41207 .54929 m .41341 .54749 L .40891 .5461 L F
.41207 .54929 m .41343 .54995 L .41341 .54749 L F
.69 .934 .631 r
.41624 .54429 m .41341 .54749 L .41457 .54545 L F
.404 .672 .97 r
.41341 .54749 m .41634 .54684 L .41457 .54545 L F
.291 .061 .383 r
.41341 .54749 m .41343 .54995 L .41634 .54684 L F
.41341 .54749 m .41343 .54995 L .41634 .54684 L F
.18 .66 .929 r
.67721 .31536 m .67248 .31417 L .67406 .31628 L F
.782 .737 .812 r
.33861 .63338 m .34021 .63695 L .33603 .63669 L F
.795 .743 .804 r
.34281 .6338 m .34021 .63695 L .33861 .63338 L F
.955 .738 .569 r
.30928 .67526 m .31086 .67665 L .30925 .67285 L F
.093 0 .303 r
.60142 .3886 m .60095 .39003 L .60218 .39042 L F
.856 .79 .786 r
.53341 .35426 m .53083 .35746 L .53443 .35815 L F
.765 .741 .831 r
.53341 .35426 m .53443 .35815 L .5374 .35493 L F
.65 .192 .153 r
.40985 .55509 m .40956 .55383 L .40805 .55424 L F
0 0 .024 r
.41576 .46375 m .41654 .4622 L .41798 .46303 L F
.14 0 0 r
.41654 .4622 m .42014 .46196 L .41798 .46303 L F
.41654 .4622 m .42187 .45931 L .42014 .46196 L F
0 0 0 r
.56222 .37807 m .56115 .37985 L .56427 .37583 L F
.081 .243 .731 r
.5851 .35171 m .5868 .35541 L .58762 .35328 L F
.896 .836 .779 r
.5868 .35541 m .58477 .35422 L .58762 .35328 L F
.84 .924 .888 r
.50721 .5037 m .50874 .50506 L .51014 .50301 L F
.325 .811 .815 r
.64666 .37932 m .64764 .37856 L .64867 .3777 L F
.64666 .37932 m .64498 .3794 L .64764 .37856 L F
.729 .23 .047 r
.41624 .54429 m .41457 .54545 L .41799 .54622 L F
.122 0 .407 r
.3218 .56518 m .32033 .56372 L .32325 .56251 L F
0 0 0 r
.326 .56138 m .32484 .56188 L .32325 .56251 L F
.32484 .56188 m .3218 .56518 L .32325 .56251 L F
.972 .679 .283 r
.41394 .53298 m .41553 .53719 L .41594 .5344 L F
.988 .738 .358 r
.32548 .55399 m .32439 .55298 L .32437 .54997 L F
.99 .883 .612 r
.32439 .55298 m .32349 .55553 L .32548 .55399 L F
.988 .738 .358 r
.32437 .54997 m .32439 .55298 L .32548 .55399 L F
.99 .883 .612 r
.32439 .55298 m .32349 .55553 L .32548 .55399 L F
.77 .346 .243 r
.32349 .55553 m .32787 .55668 L .32548 .55399 L F
.784 .699 .771 r
.23953 .62066 m .2388 .62309 L .2331 .62189 L F
.692 .202 .078 r
.2331 .62189 m .2388 .62309 L .23527 .62328 L F
0 0 .02 r
.23913 .62282 m .2388 .62309 L .23953 .62066 L F
.286 .785 .857 r
.23527 .62328 m .2388 .62309 L .23913 .62282 L F
.762 .633 .719 r
.34112 .61056 m .34552 .611 L .34386 .60709 L F
.751 .65 .749 r
.34552 .611 m .3481 .60767 L .34386 .60709 L F
.8 .426 .349 r
.40514 .52872 m .40884 .52769 L .4051 .52673 L F
.40514 .52872 m .40939 .52973 L .40884 .52769 L F
.784 .704 .776 r
.40092 .52354 m .40505 .52417 L .40363 .52016 L F
.805 .515 .499 r
.40147 .52597 m .40505 .52417 L .40092 .52354 L F
.40147 .52597 m .4051 .52673 L .40505 .52417 L F
.681 .541 .688 r
.35525 .48636 m .356 .48997 L .3575 .48624 L F
.841 .57 .53 r
.34228 .52969 m .34463 .52737 L .34225 .52667 L F
.34228 .52969 m .34452 .53027 L .34463 .52737 L F
.867 .744 .725 r
.44896 .58908 m .45095 .5906 L .44952 .58661 L F
.778 .704 .782 r
.45095 .5906 m .45363 .58714 L .44952 .58661 L F
.798 .485 .46 r
.61165 .38839 m .6097 .39063 L .60981 .38741 L F
.61165 .38839 m .61393 .39119 L .6097 .39063 L F
.683 .166 0 r
.49636 .44986 m .49782 .45077 L .49933 .45271 L F
.78 .552 .59 r
.35994 .49095 m .36001 .49387 L .36358 .49409 L F
.861 .518 .007 r
.67599 .30961 m .6772 .31174 L .67556 .30773 L F
.47 0 0 r
.6777 .31221 m .6772 .31174 L .67599 .30961 L F
.6777 .31221 m .6796 .31381 L .6772 .31174 L F
.612 .163 .16 r
.35026 .49926 m .35306 .49966 L .35462 .49769 L F
.088 0 0 r
.35462 .49769 m .35554 .49875 L .35715 .49628 L F
.35462 .49769 m .35306 .49966 L .35554 .49875 L F
.593 .774 .966 r
.48395 .42782 m .48812 .42874 L .48658 .42672 L F
.604 .735 .937 r
.48812 .42874 m .4906 .42788 L .48658 .42672 L F
.91 .628 .497 r
.3391 .52278 m .34225 .52667 L .34236 .52426 L F
0 0 .438 r
.24752 .58393 m .25009 .58719 L .24923 .5861 L F
.712 .956 .679 r
.25246 .5846 m .25066 .58589 L .25009 .58719 L F
.428 .764 .996 r
.25009 .58719 m .25066 .58589 L .24923 .5861 L F
.25009 .58719 m .25066 .58589 L .24923 .5861 L F
.906 .625 .126 r
.44629 .57156 m .44686 .57023 L .44497 .56964 L F
.44629 .57156 m .44728 .57361 L .44686 .57023 L F
.47 .361 .648 r
.38536 .46448 m .38809 .46702 L .38796 .46415 L F
.38536 .46448 m .38565 .46786 L .38809 .46702 L F
.942 .88 .744 r
.36767 .47165 m .36615 .47474 L .36472 .47289 L F
.79 .57 .602 r
.36472 .47289 m .36935 .47073 L .36767 .47165 L F
.651 .821 .965 r
.29073 .65217 m .29609 .65167 L .29428 .65068 L F
0 .45 .843 r
.29609 .65167 m .29703 .6514 L .29428 .65068 L F
.29609 .65167 m .29962 .6533 L .29703 .6514 L F
.814 .576 .579 r
.65113 .37801 m .64906 .37444 L .64867 .3777 L F
.513 .002 0 r
.64867 .3777 m .65182 .37946 L .65113 .37801 L F
0 .286 .778 r
.65051 .37762 m .65182 .37946 L .64867 .3777 L F
.65051 .37762 m .64867 .3777 L .64764 .37856 L F
.867 .625 .57 r
.38492 .58305 m .38274 .58394 L .38291 .58035 L F
0 .274 .685 r
.38706 .58643 m .38274 .58394 L .38492 .58305 L F
.671 .973 .811 r
.45271 .44653 m .45649 .4443 L .45496 .44521 L F
.637 .962 .908 r
.45649 .4443 m .46028 .44237 L .45792 .44247 L F
.627 .928 .675 r
.45496 .44521 m .45649 .4443 L .45792 .44247 L F
.164 0 0 r
.41087 .45695 m .41331 .45623 L .41451 .45471 L F
.138 0 0 r
.41451 .45471 m .41576 .45545 L .41672 .45384 L F
.41451 .45471 m .41331 .45623 L .41576 .45545 L F
.614 .904 .985 r
.58065 .43012 m .58182 .43131 L .58314 .42928 L F
.977 .718 .472 r
.66647 .35119 m .66478 .3505 L .66483 .3475 L F
.992 .836 .589 r
.66647 .35119 m .66427 .35354 L .66478 .3505 L F
.66647 .35119 m .66562 .35502 L .66427 .35354 L F
.951 .814 .672 r
.55967 .4543 m .56112 .45089 L .55943 .44981 L F
.889 .959 .838 r
.47534 .53831 m .47554 .54103 L .47774 .53823 L F
.867 .951 .865 r
.47277 .54146 m .47554 .54103 L .47534 .53831 L F
.992 .804 .55 r
.33609 .56266 m .33768 .56405 L .33566 .56543 L F
.893 .532 .35 r
.33768 .56405 m .3381 .5666 L .33566 .56543 L F
.992 .804 .55 r
.33609 .56266 m .33768 .56405 L .33566 .56543 L F
.987 .759 .366 r
.57178 .35525 m .57207 .3585 L .57107 .3569 L F
.539 .787 .99 r
.40216 .51869 m .40363 .52016 L .40107 .5208 L F
.882 .717 .202 r
.40042 .52161 m .40092 .52354 L .40107 .5208 L F
.784 .704 .776 r
.40092 .52354 m .40363 .52016 L .40107 .5208 L F
.882 .717 .202 r
.40042 .52161 m .40107 .5208 L .40363 .52016 L F
.315 0 0 r
.51845 .4192 m .51669 .4183 L .51594 .42013 L F
.343 0 0 r
.63363 .34036 m .63799 .33946 L .6345 .34091 L F
.63363 .34036 m .63651 .34053 L .63799 .33946 L F
.246 0 0 r
.63651 .34053 m .6405 .33814 L .63799 .33946 L F
.781 .659 .728 r
.36001 .49387 m .36135 .49768 L .36358 .49409 L F
.468 .264 .52 r
.36358 .49409 m .36135 .49768 L .36399 .4968 L F
0 0 .098 r
.41198 .5638 m .41158 .56766 L .41214 .56548 L F
.713 .949 .954 r
.41158 .56766 m .41002 .56689 L .41214 .56548 L F
.743 .97 .701 r
.23453 .61759 m .23268 .62007 L .23314 .6185 L F
.65 .689 .874 r
.23453 .61759 m .23953 .62066 L .23268 .62007 L F
.784 .699 .771 r
.23953 .62066 m .2331 .62189 L .23268 .62007 L F
.361 .452 .82 r
.2331 .62189 m .23314 .6185 L .23268 .62007 L F
.769 .703 .79 r
.35043 .59041 m .35488 .59096 L .35257 .58939 L F
.825 .564 .544 r
.53953 .35142 m .53597 .35078 L .53587 .34821 L F
.457 .806 .998 r
.53953 .35142 m .53838 .35013 L .53597 .35078 L F
.819 .684 .715 r
.53597 .35078 m .5374 .35493 L .53953 .35142 L F
.277 .779 .857 r
.40986 .56048 m .40743 .56058 L .40588 .56093 L F
.40986 .56048 m .40743 .56058 L .40588 .56093 L F
.908 .823 .751 r
.40986 .56048 m .40985 .55509 L .41024 .55549 L F
.40986 .56048 m .40743 .56058 L .40985 .55509 L F
.829 .387 .185 r
.40986 .56048 m .4082 .56214 L .40743 .56058 L F
.40986 .56048 m .41115 .56311 L .4082 .56214 L F
.851 .678 .667 r
.34995 .56813 m .35222 .57293 L .35245 .57051 L F
.888 .534 .368 r
.34929 .65995 m .34913 .65584 L .35131 .6567 L F
.34929 .65995 m .35131 .6567 L .34989 .65887 L F
.428 .768 .996 r
.35278 .65541 m .35131 .6567 L .34913 .65584 L F
0 0 0 r
.34989 .65887 m .35131 .6567 L .35278 .65541 L F
.803 .631 .668 r
.45836 .58311 m .45889 .58043 L .45477 .5799 L F
.73 .622 .738 r
.34386 .60709 m .3481 .60767 L .34657 .60358 L F
.872 .948 .86 r
.5272 .4699 m .52553 .47186 L .5256 .46997 L F
0 0 0 r
.52432 .47318 m .5256 .46997 L .52553 .47186 L F
.831 .943 .897 r
.54645 .47196 m .54674 .46893 L .54499 .47088 L F
.54645 .47196 m .54789 .47009 L .54674 .46893 L F
.886 .738 .692 r
.38361 .57761 m .38291 .58035 L .38136 .57645 L F
.384 .691 .98 r
.33446 .57513 m .33444 .57679 L .33224 .57516 L F
.735 .991 .84 r
.6518 .36992 m .65391 .36711 L .65463 .36871 L F
.6518 .36992 m .65002 .37033 L .65391 .36711 L F
.533 .337 .561 r
.29451 .57049 m .29178 .57399 L .29462 .57325 L F
.29451 .57049 m .29178 .57399 L .29462 .57325 L F
0 0 0 r
.52403 .39078 m .52092 .39382 L .52209 .39249 L F
.159 0 .294 r
.2785 .53905 m .27756 .53712 L .27863 .53627 L F
.2785 .53905 m .27675 .53987 L .27756 .53712 L F
.118 0 0 r
.64311 .33707 m .6459 .33657 L .64715 .33545 L F
.219 0 0 r
.6459 .33657 m .64989 .33461 L .64715 .33545 L F
.505 .132 .266 r
.65926 .33061 m .66219 .33044 L .66322 .32793 L F
.556 .183 .288 r
.66322 .32793 m .66603 .32963 L .66601 .32806 L F
.66322 .32793 m .66219 .33044 L .66603 .32963 L F
.451 0 0 r
.6 .34265 m .60235 .34331 L .60349 .34285 L F
.401 0 0 r
.60235 .34331 m .60643 .34387 L .60349 .34285 L F
.939 .887 .753 r
.54674 .4499 m .54818 .45118 L .54661 .45399 L F
.599 .033 0 r
.45122 .53877 m .45574 .54036 L .45255 .53819 L F
.679 .863 .969 r
.28869 .67763 m .29034 .67941 L .28566 .67976 L F
.775 .643 .716 r
.28566 .67976 m .29034 .67941 L .28826 .68306 L F
.752 .887 .94 r
.29298 .67743 m .29034 .67941 L .28869 .67763 L F
.291 0 0 r
.61767 .39738 m .61711 .39759 L .6168 .39688 L F
.586 .064 0 r
.6177 .39719 m .61767 .39738 L .61514 .39479 L F
.61828 .39773 m .61767 .39738 L .6177 .39719 L F
.6191 .3985 m .61767 .39738 L .61828 .39773 L F
.284 0 0 r
.62227 .39849 m .61767 .39738 L .6191 .3985 L F
.291 0 0 r
.61767 .39738 m .62068 .39834 L .61762 .3977 L F
.61767 .39738 m .61762 .3977 L .61711 .39759 L F
.61767 .39738 m .6168 .39688 L .61626 .39566 L F
.813 .748 .792 r
.30877 .63998 m .31038 .64341 L .30628 .64317 L F
.746 .721 .829 r
.31294 .64064 m .31038 .64341 L .30877 .63998 L F
0 .04 .553 r
.26583 .55936 m .26409 .55771 L .26579 .55682 L F
.26583 .55936 m .26529 .56331 L .26409 .55771 L F
.832 .935 .897 r
.52138 .49211 m .52533 .49064 L .52392 .48946 L F
0 0 0 r
.426 .45044 m .42834 .44934 L .43007 .44801 L F
.42834 .44934 m .43222 .44662 L .43007 .44801 L F
.589 .393 .583 r
.31257 .59032 m .31275 .59313 L .30969 .59359 L F
.30969 .59359 m .31275 .59313 L .31257 .59032 L F
.345 .211 .551 r
.31476 .59245 m .31257 .59032 L .31481 .59033 L F
.31257 .59032 m .31476 .59245 L .31401 .58901 L F
.31257 .59032 m .31275 .59313 L .31476 .59245 L F
.31476 .59245 m .31275 .59313 L .31257 .59032 L F
.409 .836 .681 r
.46055 .43086 m .4565 .43301 L .45977 .4308 L F
.526 .908 .755 r
.46266 .42944 m .46055 .43086 L .46209 .42943 L F
.532 .922 .839 r
.46209 .42943 m .46055 .43086 L .45977 .4308 L F
.92 .59 .125 r
.57207 .3585 m .57144 .3594 L .57107 .3569 L F
.57207 .3585 m .57257 .36096 L .57144 .3594 L F
.557 .585 .837 r
.32895 .52673 m .3265 .52747 L .32494 .52346 L F
0 0 .371 r
.57771 .38925 m .57583 .39079 L .5759 .38801 L F
.954 .724 .552 r
.56356 .3648 m .56466 .36865 L .56294 .36697 L F
.579 .527 .76 r
.56729 .3677 m .56466 .36865 L .56356 .3648 L F
.839 .563 .02 r
.29654 .59974 m .2967 .59923 L .29596 .59651 L F
0 0 0 r
.29561 .60208 m .2967 .59923 L .29654 .59974 L F
.007 0 .351 r
.34929 .65995 m .34879 .66303 L .34825 .6631 L F
0 0 .138 r
.34825 .6631 m .34879 .66303 L .34662 .66662 L F
.738 .507 .579 r
.2905 .57545 m .29462 .57325 L .29178 .57399 L F
.589 .948 .866 r
.46028 .44237 m .46028 .4412 L .45792 .44247 L F
.46028 .44237 m .46258 .44092 L .46028 .4412 L F
0 0 .022 r
.57626 .37108 m .57639 .36954 L .57643 .36674 L F
0 .338 .819 r
.57626 .37108 m .57901 .37275 L .57639 .36954 L F
.646 .61 .799 r
.2874 .64968 m .29073 .65217 L .28979 .64927 L F
.612 .666 .878 r
.28979 .64927 m .29073 .65217 L .29428 .65068 L F
.822 .865 .878 r
.30438 .57957 m .307 .58108 L .30795 .57831 L F
.12 0 .22 r
.51354 .43436 m .51499 .43556 L .51633 .43368 L F
.51354 .43436 m .51301 .43699 L .51499 .43556 L F
.673 .679 .847 r
.32059 .61615 m .32233 .61966 L .32521 .6171 L F
0 0 .443 r
.56155 .381 m .56257 .38227 L .56054 .38067 L F
.56155 .381 m .56341 .38368 L .56257 .38227 L F
.949 .629 .201 r
.54724 .39252 m .54812 .39151 L .54671 .39017 L F
0 0 0 r
.55134 .38788 m .55028 .38959 L .54812 .39151 L F
.499 .793 .998 r
.54812 .39151 m .55028 .38959 L .54671 .39017 L F
.058 0 0 r
.54357 .41464 m .54212 .41596 L .54364 .41738 L F
.54357 .41464 m .54083 .41598 L .54212 .41596 L F
.54083 .41598 m .54004 .41637 L .54212 .41596 L F
.448 .693 .97 r
.54456 .41547 m .54515 .41624 L .54212 .41596 L F
.365 .708 .986 r
.54515 .41624 m .54364 .41738 L .54212 .41596 L F
.54212 .41596 m .54364 .41738 L .54515 .41624 L F
.54212 .41596 m .54515 .41624 L .5448 .41789 L F
.152 .303 .764 r
.54212 .41596 m .5448 .41789 L .54409 .41592 L F
.448 .693 .97 r
.54335 .41389 m .54456 .41547 L .54212 .41596 L F
.152 .303 .764 r
.54212 .41596 m .54409 .41592 L .54335 .41389 L F
.058 0 0 r
.54004 .41637 m .53943 .41667 L .54212 .41596 L F
.756 .986 .902 r
.48113 .43005 m .48267 .42757 L .47967 .42954 L F
.48113 .43005 m .48395 .42782 L .48267 .42757 L F
.795 .743 .804 r
.34281 .6338 m .33861 .63338 L .34108 .63218 L F
.603 .663 .88 r
.34405 .62986 m .34281 .6338 L .34108 .63218 L F
.34405 .62986 m .34537 .63302 L .34281 .6338 L F
0 0 0 r
.25286 .58485 m .25246 .5846 L .25373 .58235 L F
.25286 .58485 m .25066 .58589 L .25246 .5846 L F
0 0 .165 r
.52315 .47775 m .5245 .47595 L .52432 .47318 L F
0 0 0 r
.52432 .47318 m .52497 .47211 L .5256 .46997 L F
0 0 .12 r
.52432 .47318 m .5245 .47595 L .52497 .47211 L F
.686 .751 .901 r
.51262 .48106 m .51658 .48386 L .51319 .48359 L F
.753 .987 .898 r
.52092 .48062 m .51658 .48386 L .51262 .48106 L F
.077 0 .152 r
.58629 .36063 m .58355 .36397 L .58424 .36203 L F
0 0 0 r
.50916 .4451 m .51055 .44331 L .5104 .44368 L F
.50778 .44666 m .51103 .44297 L .51 .44535 L F
0 0 .443 r
.51018 .44028 m .51028 .44401 L .51166 .44115 L F
.51028 .44401 m .51028 .44401 L .51028 .44401 L F
.51028 .44401 m .51028 .44401 L .51166 .44115 L F
0 0 0 r
.50916 .4451 m .50876 .4446 L .50957 .44402 L F
.51001 .44401 m .50957 .44402 L .51055 .44331 L F
.50916 .4451 m .50957 .44402 L .51001 .44401 L F
.5104 .44368 m .51055 .44331 L .51103 .44297 L F
.654 .199 .159 r
.51 .44535 m .51028 .44401 L .51027 .44401 L F
.50979 .44519 m .51027 .44401 L .50717 .4432 L F
.51 .44535 m .51027 .44401 L .50979 .44519 L F
.681 .549 .698 r
.50717 .4432 m .51027 .44401 L .51018 .44028 L F
.51027 .44401 m .51028 .44401 L .51028 .44401 L F
.51027 .44401 m .51028 .44401 L .51018 .44028 L F
0 0 0 r
.50778 .44666 m .50797 .44625 L .50916 .4451 L F
.50797 .44625 m .50876 .4446 L .50916 .4451 L F
.081 .243 .731 r
.5851 .35171 m .58762 .35328 L .58818 .3508 L F
.796 .754 .814 r
.32521 .6171 m .32902 .6173 L .32755 .61603 L F
.686 .687 .846 r
.32902 .6173 m .33004 .61276 L .32755 .61603 L F
.32902 .6173 m .33159 .61643 L .33004 .61276 L F
.716 .78 .903 r
.31115 .61945 m .3155 .61997 L .31361 .61822 L F
.786 .79 .856 r
.31361 .61822 m .3155 .61997 L .31786 .61684 L F
.518 0 0 r
.59433 .43136 m .59155 .42945 L .59403 .42977 L F
0 0 .265 r
.59403 .42977 m .59502 .43361 L .59433 .43136 L F
.627 .817 .973 r
.54293 .34765 m .53845 .34706 L .54159 .34569 L F
.841 .861 .858 r
.54542 .34477 m .54293 .34765 L .54159 .34569 L F
.414 .209 .49 r
.54542 .34477 m .54554 .34719 L .54293 .34765 L F
.767 .727 .816 r
.44952 .58661 m .45363 .58714 L .45241 .58357 L F
.826 .771 .8 r
.45363 .58714 m .45486 .58254 L .45241 .58357 L F
.494 .285 .525 r
.51465 .47086 m .51445 .47356 L .51129 .47432 L F
.506 .317 .558 r
.51148 .47707 m .51445 .47356 L .51129 .47432 L F
.494 .285 .525 r
.51129 .47432 m .51445 .47356 L .51465 .47086 L F
.506 .317 .558 r
.51445 .47356 m .51148 .47707 L .51129 .47432 L F
0 0 0 r
.51103 .44297 m .51437 .4414 L .51376 .44283 L F
.51376 .44283 m .51437 .4414 L .51764 .44017 L F
.866 .962 .862 r
.52272 .40602 m .52395 .40701 L .52607 .40352 L F
.903 .567 .399 r
.34748 .56599 m .3489 .56361 L .34697 .56341 L F
.34748 .56599 m .35071 .56705 L .3489 .56361 L F
.806 .506 .482 r
.67321 .33 m .67701 .32837 L .67287 .3278 L F
.67321 .33 m .67722 .33087 L .67701 .32837 L F
.971 .655 .331 r
.55408 .41796 m .55268 .41871 L .55243 .41677 L F
.55408 .41796 m .55431 .42036 L .55268 .41871 L F
.795 .299 0 r
.58319 .37089 m .5859 .37471 L .58708 .3743 L F
.99 .829 .452 r
.5859 .37471 m .58631 .37756 L .58708 .3743 L F
.702 .87 .961 r
.54554 .34719 m .54981 .3473 L .54744 .34488 L F
.54832 .34519 m .54771 .34476 L .54793 .34464 L F
.54792 .34509 m .54753 .34464 L .54832 .34519 L F
.54753 .34464 m .54753 .34463 L .54753 .34464 L F
.54753 .34464 m .54753 .34464 L .54832 .34519 L F
.54981 .3473 m .54792 .34509 L .54832 .34519 L F
.449 .564 .879 r
.55007 .34319 m .54981 .3473 L .54774 .34436 L F
.55007 .34319 m .55226 .34705 L .54981 .3473 L F
.712 .201 .009 r
.55226 .34705 m .54792 .34509 L .54981 .3473 L F
.54792 .34509 m .54744 .34488 L .54981 .3473 L F
.037 .214 .717 r
.54744 .34488 m .54758 .34501 L .54756 .34484 L F
.711 .985 .817 r
.54514 .34639 m .54554 .34719 L .54744 .34488 L F
.037 .214 .717 r
.54744 .34488 m .54756 .34484 L .54725 .34501 L F
.712 .201 .009 r
.54792 .34509 m .54758 .34501 L .54744 .34488 L F
.702 .87 .961 r
.54981 .3473 m .54554 .34719 L .54753 .34463 L F
.712 .201 .009 r
.55226 .34705 m .54987 .34728 L .54758 .34501 L F
.55226 .34705 m .54758 .34501 L .54792 .34509 L F
.037 .214 .717 r
.54756 .34484 m .54987 .34728 L .54914 .34429 L F
.54758 .34501 m .54987 .34728 L .54756 .34484 L F
.54725 .34501 m .54914 .34429 L .54514 .34639 L F
.54756 .34484 m .54914 .34429 L .54725 .34501 L F
.702 .87 .961 r
.54793 .34464 m .54753 .34463 L .54774 .34436 L F
.54771 .34476 m .54753 .34463 L .54793 .34464 L F
.578 .564 .802 r
.33041 .5885 m .33007 .58894 L .32694 .58291 L F
.3301 .589 m .32964 .58922 L .32694 .58291 L F
.815 .678 .713 r
.32694 .58291 m .32971 .5894 L .32431 .5858 L F
.814 .967 .903 r
.32972 .59001 m .32935 .58987 L .32998 .58906 L F
.815 .678 .713 r
.32971 .5894 m .32977 .58953 L .32964 .58944 L F
.32971 .5894 m .32964 .58944 L .32431 .5858 L F
.788 .288 0 r
.32431 .5858 m .32964 .58944 L .32656 .58832 L F
.814 .967 .903 r
.32905 .58976 m .32848 .58955 L .32971 .5894 L F
.788 .288 0 r
.32964 .58944 m .32977 .58953 L .32939 .58939 L F
.32964 .58944 m .32939 .58939 L .32656 .58832 L F
.578 .564 .802 r
.3301 .589 m .32977 .58953 L .32964 .58922 L F
.814 .967 .903 r
.32971 .5894 m .32954 .58942 L .32998 .58906 L F
.32954 .58942 m .32848 .58955 L .32913 .58933 L F
.823 .877 .885 r
.33021 .58821 m .32656 .58832 L .32939 .58939 L F
.814 .967 .903 r
.32954 .58942 m .32939 .58939 L .32998 .58906 L F
.32939 .58939 m .32952 .58921 L .32998 .58906 L F
.32998 .58906 m .32848 .58955 L .33021 .58821 L F
.823 .877 .885 r
.33021 .58821 m .32939 .58939 L .32977 .58953 L F
.814 .967 .903 r
.32939 .58939 m .32913 .58933 L .32952 .58921 L F
.32935 .58987 m .32905 .58976 L .32971 .5894 L F
.875 .813 .785 r
.33329 .58721 m .33205 .58967 L .3308 .58868 L F
.33082 .58801 m .3308 .58868 L .33021 .58821 L F
.33329 .58721 m .3308 .58868 L .33082 .58801 L F
.578 .564 .802 r
.3309 .58598 m .33041 .5885 L .32694 .58291 L F
.33162 .58654 m .33083 .58782 L .3309 .58598 L F
.33083 .58782 m .33041 .5885 L .3309 .58598 L F
.33041 .5885 m .3301 .589 L .33007 .58894 L F
.814 .967 .903 r
.32972 .59001 m .32998 .58906 L .33205 .58967 L F
.32998 .58906 m .33021 .58821 L .3308 .58868 L F
.32998 .58906 m .3308 .58868 L .33205 .58967 L F
.937 .769 .647 r
.3437 .53593 m .34647 .53434 L .34421 .5331 L F
.3437 .53593 m .34575 .53693 L .34647 .53434 L F
.826 .983 .88 r
.44749 .54956 m .45171 .5474 L .44964 .55083 L F
.44749 .54956 m .45037 .54695 L .45171 .5474 L F
.631 .944 .952 r
.45171 .5474 m .45298 .54554 L .45037 .54695 L F
.448 .234 .495 r
.45037 .54695 m .45298 .54554 L .45171 .5474 L F
.711 .56 .681 r
.23611 .61018 m .23798 .61344 L .23985 .60998 L F
.874 .626 .561 r
.36726 .52398 m .36466 .52339 L .36475 .52049 L F
.863 .545 .448 r
.36726 .52398 m .36492 .52608 L .36466 .52339 L F
.871 .56 .458 r
.3675 .52654 m .36492 .52608 L .36726 .52398 L F
.96 .93 .717 r
.5113 .49876 m .51181 .50157 L .51229 .50056 L F
.867 .94 .865 r
.5113 .49876 m .51229 .50056 L .51554 .49675 L F
.872 .707 .674 r
.55646 .42192 m .55596 .42446 L .55431 .42036 L F
.806 .982 .894 r
.47534 .53831 m .47774 .53823 L .47973 .53636 L F
.736 .316 0 r
.58349 .3927 m .5848 .39546 L .58369 .39394 L F
.58349 .3927 m .58369 .39394 L .58373 .39301 L F
.58349 .3927 m .58373 .39301 L .58383 .39115 L F
0 0 .387 r
.58233 .39085 m .58339 .39257 L .58349 .3927 L F
.58339 .39257 m .58456 .39448 L .58349 .3927 L F
.696 .321 0 r
.58456 .39448 m .5848 .39546 L .58349 .3927 L F
.58456 .39448 m .58518 .39621 L .5848 .39546 L F
.938 .966 .705 r
.28022 .63892 m .2792 .64318 L .27909 .6433 L F
.524 .556 .83 r
.28367 .64162 m .2792 .64318 L .28022 .63892 L F
.743 .531 .607 r
.46679 .53548 m .46239 .53772 L .46268 .53709 L F
.46679 .53548 m .46268 .53709 L .46535 .5362 L F
.907 .979 .704 r
.46679 .53548 m .46747 .53251 L .46924 .53409 L F
.46679 .53548 m .46535 .5362 L .46747 .53251 L F
.812 .751 .796 r
.57583 .39079 m .57316 .39416 L .57568 .39399 L F
.881 .513 .343 r
.57316 .39416 m .5756 .39691 L .57568 .39399 L F
.581 .909 .978 r
.61954 .35673 m .61773 .3588 L .62048 .35768 L F
.974 .715 .477 r
.68909 .35636 m .69141 .35464 L .6891 .3533 L F
.68909 .35636 m .69107 .35635 L .69141 .35464 L F
.885 .765 .724 r
.38108 .5572 m .37832 .55654 L .37985 .55324 L F
.882 .545 .408 r
.38108 .5572 m .37892 .5588 L .37832 .55654 L F
.888 .557 .416 r
.38108 .5572 m .3813 .55972 L .37892 .5588 L F
.513 .24 .439 r
.27338 .52375 m .27622 .52334 L .27664 .52085 L F
.347 0 .214 r
.27664 .52085 m .27939 .52032 L .2794 .51976 L F
.294 .055 .37 r
.27664 .52085 m .27838 .52248 L .27939 .52032 L F
.27664 .52085 m .27622 .52334 L .27838 .52248 L F
.6 .652 .874 r
.28374 .51374 m .28729 .5149 L .2881 .51348 L F
.561 .622 .87 r
.32591 .54408 m .33116 .54706 L .32896 .54648 L F
.755 .245 0 r
.33221 .54939 m .32896 .54648 L .33116 .54706 L F
.052 .563 .878 r
.35715 .49628 m .36135 .49768 L .36001 .49387 L F
.35715 .49628 m .35959 .49674 L .36135 .49768 L F
.677 .255 .235 r
.35959 .49674 m .36399 .4968 L .36135 .49768 L F
.872 .948 .86 r
.5272 .4699 m .5256 .46997 L .52656 .46675 L F
.741 .707 .819 r
.53095 .46808 m .5272 .4699 L .52656 .46675 L F
.9 .876 .803 r
.48174 .53355 m .48153 .52971 L .48055 .53135 L F
.48174 .53355 m .48318 .53101 L .48153 .52971 L F
.919 .879 .78 r
.47801 .53553 m .48174 .53355 L .48055 .53135 L F
.47801 .53553 m .47973 .53636 L .48174 .53355 L F
.831 .752 .776 r
.32033 .56372 m .31599 .56299 L .31843 .56025 L F
.826 .762 .792 r
.32033 .56372 m .3181 .56455 L .31599 .56299 L F
.721 .446 .509 r
.32033 .56372 m .32033 .56685 L .3181 .56455 L F
.122 0 .407 r
.3218 .56518 m .32033 .56685 L .32033 .56372 L F
.383 .371 .723 r
.24451 .56712 m .24601 .56287 L .24456 .56342 L F
.24451 .56712 m .24692 .56594 L .24601 .56287 L F
.384 .279 .611 r
.245 .57042 m .24692 .56594 L .24451 .56712 L F
.622 .812 .973 r
.36615 .47474 m .36895 .47347 L .36472 .47289 L F
.654 .131 0 r
.61604 .35149 m .61502 .35279 L .61215 .35055 L F
.977 .743 .325 r
.61592 .35398 m .61502 .35279 L .61604 .35149 L F
.48 .256 .496 r
.61917 .35015 m .61592 .35398 L .61604 .35149 L F
.61604 .35149 m .61592 .35398 L .61917 .35015 L F
.474 .895 .866 r
.62472 .39116 m .6197 .39253 L .62357 .39061 L F
0 0 .145 r
.54042 .43329 m .53848 .43616 L .53794 .43495 L F
.592 .787 .973 r
.30078 .64724 m .29671 .64656 L .29905 .64555 L F
.61 .715 .919 r
.30359 .64644 m .30078 .64724 L .29905 .64555 L F
.96 .93 .72 r
.23611 .61018 m .23432 .61376 L .23798 .61344 L F
.446 0 0 r
.23705 .61925 m .23953 .62066 L .23453 .61759 L F
0 0 .02 r
.23913 .62282 m .23953 .62066 L .23705 .61925 L F
0 0 0 r
.55004 .40307 m .55429 .40156 L .55083 .40373 L F
.797 .894 .913 r
.5475 .44187 m .54913 .44369 L .54754 .44433 L F
.843 .901 .878 r
.55183 .4403 m .54913 .44369 L .5475 .44187 L F
.769 .631 .707 r
.34487 .59963 m .34914 .60019 L .34714 .59637 L F
.766 .645 .728 r
.34487 .59963 m .34657 .60358 L .34914 .60019 L F
.819 .821 .851 r
.32933 .63635 m .32488 .63642 L .32726 .63521 L F
.804 .898 .909 r
.3312 .63373 m .32933 .63635 L .32726 .63521 L F
.642 .641 .834 r
.3312 .63373 m .33342 .63775 L .32933 .63635 L F
.744 .989 .79 r
.49352 .40592 m .49484 .40365 L .49595 .40455 L F
.49352 .40592 m .49178 .40644 L .49484 .40365 L F
.644 .647 .838 r
.33463 .63311 m .33342 .63775 L .3312 .63373 L F
.33463 .63311 m .33603 .63669 L .33342 .63775 L F
.494 .799 .999 r
.41828 .60048 m .421 .60005 L .41933 .59885 L F
.923 .766 .669 r
.34964 .57903 m .35149 .58342 L .35185 .58043 L F
.34964 .57903 m .34785 .58288 L .35149 .58342 L F
.878 .738 .703 r
.3469 .58512 m .35149 .58342 L .34785 .58288 L F
.3469 .58512 m .34882 .58638 L .35149 .58342 L F
.954 .875 .72 r
.56699 .43414 m .56692 .43029 L .56569 .43212 L F
.914 .748 .662 r
.56404 .43626 m .56699 .43414 L .56569 .43212 L F
.56404 .43626 m .56592 .43773 L .56699 .43414 L F
.133 .361 .82 r
.57643 .36674 m .57351 .36294 L .57486 .3647 L F
.707 .742 .879 r
.40174 .57356 m .4055 .57423 L .40518 .57241 L F
.305 .442 .835 r
.40518 .57241 m .4055 .57423 L .4069 .57222 L F
0 0 .279 r
.4055 .57423 m .40622 .575 L .4069 .57222 L F
.4055 .57423 m .40582 .57676 L .40622 .575 L F
.851 .575 .52 r
.33527 .55047 m .33516 .55321 L .33221 .54939 L F
.846 .953 .604 r
.66222 .38501 m .66425 .38156 L .66281 .38261 L F
.494 .848 .59 r
.66281 .38261 m .66425 .38156 L .666 .38007 L F
.877 .882 .834 r
.48153 .52971 m .48583 .52798 L .48435 .52723 L F
.48153 .52971 m .48318 .53101 L .48583 .52798 L F
.846 .977 .676 r
.48645 .52558 m .48583 .52798 L .48829 .5242 L F
.758 .954 .939 r
.48435 .52723 m .48583 .52798 L .48645 .52558 L F
.888 .894 .828 r
.50879 .50205 m .51181 .50157 L .5113 .49876 L F
.50879 .50205 m .51014 .50301 L .51181 .50157 L F
0 0 0 r
.26174 .56382 m .26083 .56607 L .26039 .56654 L F
.546 .848 .998 r
.26505 .56148 m .26429 .56322 L .26529 .56331 L F
0 0 0 r
.26502 .56179 m .26429 .56322 L .26505 .56148 L F
.472 .832 .994 r
.26529 .56331 m .26429 .56322 L .26416 .56347 L F
0 0 0 r
.26475 .56407 m .26429 .56322 L .26502 .56179 L F
.472 .832 .994 r
.26416 .56347 m .26429 .56322 L .26174 .56382 L F
0 0 0 r
.26429 .56322 m .26083 .56607 L .26174 .56382 L F
.679 .947 .681 r
.47514 .42056 m .47225 .42347 L .4737 .42192 L F
.533 .85 .551 r
.47225 .42347 m .47188 .42372 L .4737 .42192 L F
.896 .906 .825 r
.48313 .51508 m .48127 .5171 L .48011 .51545 L F
.781 .969 .92 r
.48313 .51508 m .48376 .51257 L .48482 .51321 L F
.48313 .51508 m .48011 .51545 L .48376 .51257 L F
.461 .887 .82 r
.35617 .64186 m .35476 .64297 L .35366 .64309 L F
.35366 .64309 m .35476 .64297 L .35617 .64186 L F
0 0 .399 r
.66214 .39006 m .66288 .39127 L .66019 .38705 L F
.928 .568 .32 r
.66145 .39263 m .66288 .39127 L .66214 .39006 L F
.66145 .39263 m .66352 .3941 L .66288 .39127 L F
.062 .627 .73 r
.3317 .56027 m .32988 .56038 L .33371 .56019 L F
.735 .656 .771 r
.33675 .55735 m .33371 .56019 L .33166 .55695 L F
.682 .14 0 r
.33371 .56019 m .33394 .56149 L .3317 .56027 L F
.33371 .56019 m .33609 .56266 L .33394 .56149 L F
.773 .688 .77 r
.33424 .61331 m .33862 .61385 L .33692 .60983 L F
.754 .679 .779 r
.33862 .61385 m .34112 .61056 L .33692 .60983 L F
.743 .993 .842 r
.59604 .39289 m .60095 .39003 L .5982 .38946 L F
0 .167 .698 r
.60095 .39003 m .60342 .39252 L .60218 .39042 L F
.514 .855 .995 r
.65838 .38758 m .66025 .38598 L .65737 .38674 L F
.65838 .38758 m .66025 .38598 L .65737 .38674 L F
.506 .907 .91 r
.45699 .54052 m .45859 .53908 L .45968 .54001 L F
.45699 .54052 m .45574 .54036 L .45859 .53908 L F
0 0 .027 r
.53145 .3558 m .53083 .35746 L .53341 .35426 L F
.842 .803 .814 r
.47068 .52677 m .47156 .53032 L .46734 .52982 L F
.867 .739 .719 r
.46734 .52982 m .47156 .53032 L .46924 .53409 L F
.836 .801 .817 r
.47421 .52688 m .47156 .53032 L .47068 .52677 L F
.956 .844 .693 r
.40948 .54184 m .41229 .54014 L .41079 .5409 L F
.318 0 0 r
.41543 .53984 m .41079 .5409 L .41229 .54014 L F
.921 .746 .648 r
.38136 .57645 m .38291 .58035 L .38084 .57924 L F
.911 .666 .555 r
.38291 .58035 m .37933 .58046 L .38084 .57924 L F
.38291 .58035 m .38274 .58394 L .37933 .58046 L F
.771 .714 .799 r
.30487 .62076 m .30644 .62417 L .30764 .62197 L F
.632 .895 .986 r
.53587 .34821 m .53708 .346 L .53845 .34706 L F
.485 .501 .799 r
.53597 .35078 m .53708 .346 L .53587 .34821 L F
.938 .966 .705 r
.28022 .63892 m .27909 .6433 L .27752 .63949 L F
.714 .192 0 r
.27726 .644 m .27909 .6433 L .28131 .64561 L F
.52 0 0 r
.27909 .6433 m .28222 .64613 L .28131 .64561 L F
0 .335 .791 r
.28131 .64561 m .28237 .64541 L .28021 .64499 L F
.28131 .64561 m .28021 .64499 L .27894 .64474 L F
.52 0 0 r
.28222 .64613 m .28273 .6466 L .28131 .64561 L F
.745 .676 .784 r
.28325 .66602 m .28767 .66702 L .28488 .66983 L F
.871 .94 .571 r
.52315 .47775 m .52209 .47756 L .5245 .47595 L F
.52315 .47775 m .52193 .47969 L .52209 .47756 L F
.65 .545 .722 r
.24945 .55363 m .25221 .55389 L .25151 .55069 L F
.552 .291 .474 r
.24912 .55578 m .25167 .55562 L .24945 .55363 L F
.623 .272 .354 r
.24945 .55363 m .25167 .55562 L .25221 .55389 L F
.822 .57 .558 r
.58922 .37695 m .59342 .37437 L .59177 .37503 L F
.58922 .37695 m .59318 .37817 L .59342 .37437 L F
.512 .781 .993 r
.59342 .37437 m .59603 .37379 L .59448 .37214 L F
.741 .968 .698 r
.59448 .37214 m .59177 .37503 L .59342 .37437 L F
.491 .078 .184 r
.32591 .54408 m .32228 .54621 L .32479 .54271 L F
.32591 .54408 m .32485 .54638 L .32228 .54621 L F
.686 .28 .271 r
.32896 .54648 m .32485 .54638 L .32591 .54408 L F
.93 .771 .663 r
.34515 .54254 m .34795 .54082 L .34584 .53956 L F
.34515 .54254 m .34712 .54376 L .34795 .54082 L F
.447 .596 .907 r
.28273 .6466 m .2874 .64968 L .28572 .6497 L F
.199 .728 .804 r
.28572 .6497 m .2874 .64968 L .28979 .64927 L F
.787 .601 .649 r
.30767 .57782 m .30795 .57831 L .30987 .57715 L F
.983 .697 .372 r
.33236 .53736 m .33086 .53641 L .33063 .5331 L F
.92 .604 .428 r
.68683 .34957 m .6889 .34807 L .68648 .34754 L F
.68683 .34957 m .68933 .35084 L .6889 .34807 L F
0 0 .167 r
.34979 .6618 m .34929 .65995 L .34989 .65887 L F
.34979 .6618 m .34879 .66303 L .34929 .65995 L F
.948 .836 .699 r
.66271 .36072 m .6631 .36467 L .66179 .36342 L F
.838 .636 .63 r
.6631 .36467 m .65969 .36675 L .66179 .36342 L F
.6631 .36467 m .66287 .36676 L .65969 .36675 L F
.989 .72 .387 r
.59035 .40226 m .59174 .40394 L .59162 .40112 L F
.867 .972 .657 r
.59366 .39654 m .59157 .39997 L .59162 .40112 L F
.874 .935 .559 r
.59157 .39997 m .59035 .40226 L .59162 .40112 L F
.425 0 .075 r
.6553 .34154 m .65426 .34353 L .65137 .34365 L F
.506 .053 .111 r
.6589 .34293 m .6553 .34154 L .65791 .34112 L F
.6589 .34293 m .65426 .34353 L .6553 .34154 L F
.041 .2 .703 r
.31134 .66309 m .31257 .66687 L .3103 .66571 L F
0 .058 .623 r
.42606 .5661 m .42699 .5684 L .42562 .56688 L F
.754 .82 .904 r
.44354 .56285 m .4452 .5644 L .44739 .56304 L F
.44354 .56285 m .4452 .5644 L .44739 .56304 L F
0 0 .504 r
.58376 .36667 m .58446 .36978 L .58319 .37089 L F
.642 .175 0 r
.58341 .3716 m .5859 .37471 L .58319 .37089 L F
.58341 .3716 m .58319 .37089 L .58446 .36978 L F
.737 .655 .769 r
.33937 .60639 m .34386 .60709 L .34225 .60309 L F
.749 .615 .709 r
.34112 .61056 m .34386 .60709 L .33937 .60639 L F
.758 .665 .759 r
.34225 .60309 m .34386 .60709 L .34657 .60358 L F
.58 .362 .548 r
.27762 .54354 m .27498 .54591 L .27543 .54381 L F
.775 .643 .716 r
.28566 .67976 m .28826 .68306 L .28592 .68218 L F
.926 .584 .367 r
.28592 .68218 m .28826 .68306 L .2883 .685 L F
0 .347 .824 r
.28826 .68306 m .29188 .68636 L .2883 .685 L F
0 0 .108 r
.58323 .38818 m .58466 .38861 L .58377 .38594 L F
.853 .653 .632 r
.33918 .57318 m .33702 .56921 L .33953 .57036 L F
.491 .849 .992 r
.57392 .35085 m .57663 .35013 L .57814 .3509 L F
.226 .696 .942 r
.57663 .35013 m .58055 .35092 L .57814 .3509 L F
.918 .771 .684 r
.34593 .55662 m .34735 .56027 L .34816 .55762 L F
.626 .461 .639 r
.59869 .36438 m .59837 .36777 L .60129 .36441 L F
0 0 0 r
.55004 .40307 m .55282 .40243 L .55429 .40156 L F
.746 .24 .013 r
.55282 .40243 m .55688 .40441 L .55429 .40156 L F
.995 .823 .562 r
.55688 .40441 m .55801 .4009 L .55429 .40156 L F
.94 .654 .47 r
.33467 .51768 m .33682 .5203 L .33725 .51783 L F
.846 .545 .479 r
.33725 .51783 m .33682 .5203 L .3388 .52025 L F
.929 .948 .783 r
.43014 .58246 m .42762 .58647 L .42909 .58691 L F
.026 .598 .742 r
.42835 .58732 m .4305 .58735 L .43001 .58565 L F
.4305 .58735 m .43296 .58739 L .43001 .58565 L F
.929 .948 .783 r
.43014 .58246 m .42967 .58447 L .43001 .58565 L F
.42967 .58447 m .42909 .58691 L .43001 .58565 L F
.495 .885 .96 r
.42909 .58691 m .42762 .58647 L .43001 .58565 L F
.299 0 0 r
.61056 .34403 m .61329 .34453 L .61466 .34436 L F
.3 0 0 r
.61329 .34453 m .61734 .34456 L .61466 .34436 L F
.192 0 .325 r
.54158 .45677 m .54215 .45404 L .54426 .45313 L F
.915 .803 .721 r
.44749 .54956 m .44964 .55083 L .44816 .55351 L F
0 0 0 r
.51376 .42112 m .50961 .42317 L .5138 .42271 L F
.697 .528 .655 r
.5138 .42271 m .51594 .42013 L .51376 .42112 L F
.718 .418 .469 r
.44045 .56956 m .442 .56701 L .43828 .56683 L F
.44045 .56956 m .44233 .56993 L .442 .56701 L F
.667 .381 .477 r
.44233 .56993 m .44497 .56964 L .442 .56701 L F
.607 .842 .468 r
.65468 .37323 m .65113 .37801 L .65428 .37595 L F
.054 0 .194 r
.65113 .37801 m .65182 .37946 L .65428 .37595 L F
.551 .557 .813 r
.59626 .37635 m .59889 .37332 L .59603 .37379 L F
.756 .99 .782 r
.50253 .41852 m .50447 .41571 L .50155 .41647 L F
.50253 .41852 m .50576 .41539 L .50447 .41571 L F
.467 .537 .846 r
.50447 .41571 m .50253 .41852 L .50155 .41647 L F
.50447 .41571 m .50602 .41917 L .50253 .41852 L F
.398 .526 .87 r
.50678 .4211 m .50253 .41852 L .50602 .41917 L F
.173 0 0 r
.39985 .46148 m .40155 .46032 L .39759 .46127 L F
.215 0 0 r
.40237 .46161 m .40155 .46032 L .39985 .46148 L F
.40237 .46161 m .40404 .45999 L .40155 .46032 L F
.818 .404 .259 r
.39479 .59043 m .39318 .59203 L .39092 .58906 L F
.433 .266 .553 r
.39399 .58893 m .39479 .59043 L .39789 .5896 L F
.39399 .58893 m .39318 .59203 L .39479 .59043 L F
.618 .642 .852 r
.39479 .59043 m .39975 .59188 L .39789 .5896 L F
.972 .679 .283 r
.41394 .53298 m .41395 .53575 L .41553 .53719 L F
.994 .779 .502 r
.41395 .53575 m .41543 .53984 L .41553 .53719 L F
.397 0 .159 r
.25974 .52932 m .26239 .52886 L .26441 .52629 L F
.584 .187 .255 r
.26239 .52886 m .26608 .5274 L .26441 .52629 L F
.663 .748 .913 r
.52919 .46581 m .53095 .46808 L .52656 .46675 L F
.532 .602 .869 r
.53199 .46348 m .53095 .46808 L .52919 .46581 L F
.53199 .46348 m .53368 .4672 L .53095 .46808 L F
.803 .631 .668 r
.45836 .58311 m .45477 .5799 L .45486 .58254 L F
.728 .699 .823 r
.64305 .38364 m .63944 .38203 L .6428 .38119 L F
.858 .985 .705 r
.64498 .3794 m .64305 .38364 L .6428 .38119 L F
.733 .969 .706 r
.54723 .38463 m .54497 .38694 L .54543 .38567 L F
.585 .059 0 r
.54543 .38567 m .55001 .38624 L .54723 .38463 L F
.91 .787 .305 r
.56944 .41151 m .56965 .40758 L .56918 .41014 L F
.929 .834 .384 r
.56874 .41256 m .56944 .41151 L .56918 .41014 L F
.549 .73 .958 r
.4375 .59519 m .44118 .59634 L .43997 .59299 L F
.801 .757 .812 r
.44118 .59634 m .44396 .59318 L .43997 .59299 L F
.571 0 0 r
.2883 .685 m .29188 .68636 L .29026 .6862 L F
.457 .88 .92 r
.29026 .6862 m .29188 .68636 L .29444 .68542 L F
.301 0 .267 r
.38565 .46786 m .38516 .46988 L .38809 .46702 L F
.119 .309 .78 r
.57937 .37503 m .58154 .37371 L .57901 .37275 L F
0 0 .426 r
.57937 .37503 m .58121 .37523 L .58154 .37371 L F
.119 .309 .78 r
.58154 .37371 m .58152 .37356 L .57901 .37275 L F
.88 .66 .6 r
.58151 .37348 m .58012 .37317 L .58162 .37455 L F
.58142 .37255 m .58012 .37317 L .58151 .37348 L F
0 .393 .764 r
.57901 .37275 m .5817 .37362 L .57904 .37236 L F
.836 .908 .887 r
.58131 .37343 m .58012 .37317 L .57904 .37236 L F
.5817 .37362 m .58012 .37317 L .58131 .37343 L F
0 0 .426 r
.58154 .37371 m .58121 .37523 L .5817 .37362 L F
.88 .66 .6 r
.58162 .37455 m .5814 .37434 L .58121 .37523 L F
.5814 .37434 m .58012 .37317 L .58121 .37523 L F
.58341 .3716 m .58142 .37255 L .58162 .37455 L F
.119 .309 .78 r
.58154 .37371 m .5817 .37362 L .58152 .37356 L F
0 0 .426 r
.57937 .37503 m .57946 .37768 L .58121 .37523 L F
.899 .609 .487 r
.67734 .33601 m .68079 .33491 L .6772 .33345 L F
.67734 .33601 m .68095 .33745 L .68079 .33491 L F
.409 .481 .823 r
.43021 .56616 m .42917 .5701 L .42699 .5684 L F
.43021 .56616 m .43179 .5702 L .42917 .5701 L F
.939 .887 .753 r
.54674 .4499 m .54661 .45399 L .54426 .45313 L F
.977 .813 .612 r
.54661 .45399 m .54421 .45601 L .54426 .45313 L F
.54661 .45399 m .54575 .45747 L .54421 .45601 L F
0 0 0 r
.47514 .42056 m .47689 .41912 L .47844 .41776 L F
.47514 .42056 m .4737 .42192 L .47689 .41912 L F
.018 .019 .514 r
.28567 .52407 m .28651 .52667 L .28543 .52594 L F
.916 .516 .176 r
.28468 .52531 m .28651 .52667 L .28567 .52407 L F
.512 0 0 r
.28468 .52531 m .28747 .52732 L .28651 .52667 L F
.28747 .52732 m .28851 .52807 L .28651 .52667 L F
.018 .019 .514 r
.28543 .52594 m .28651 .52667 L .28533 .52669 L F
.499 .438 .719 r
.35153 .6333 m .3504 .63678 L .34965 .63414 L F
.35153 .6333 m .3531 .63595 L .3504 .63678 L F
.104 .173 .651 r
.35287 .63917 m .3504 .63678 L .3531 .63595 L F
.394 .172 .455 r
.52311 .40096 m .52582 .39768 L .52279 .39818 L F
.917 .838 .384 r
.56356 .3648 m .56294 .36697 L .56283 .36613 L F
.56299 .36436 m .56283 .36613 L .56253 .364 L F
.56356 .3648 m .56283 .36613 L .56299 .36436 L F
.56356 .3648 m .56299 .36436 L .56327 .3651 L F
.923 .867 .766 r
.563 .36439 m .56327 .3651 L .56298 .36445 L F
.946 .708 .547 r
.56253 .364 m .56154 .3612 L .56327 .3651 L F
.917 .838 .384 r
.56299 .36436 m .56253 .364 L .56327 .3651 L F
.923 .867 .766 r
.56429 .36028 m .56327 .3651 L .563 .36439 L F
.56335 .3606 m .56298 .36445 L .56154 .3612 L F
.56429 .36028 m .56298 .36445 L .56335 .3606 L F
.579 .527 .76 r
.56729 .3677 m .56356 .3648 L .56645 .36364 L F
0 0 0 r
.56356 .3648 m .56327 .3651 L .56645 .36364 L F
.712 .338 0 r
.57127 .42058 m .56977 .41757 L .57056 .41943 L F
.974 .849 .451 r
.56983 .42044 m .57127 .42058 L .57056 .41943 L F
.56983 .42044 m .5705 .42451 L .57127 .42058 L F
.818 .944 .907 r
.6725 .37414 m .67537 .37331 L .6747 .37233 L F
.659 .962 .929 r
.67537 .37331 m .67811 .37087 L .6747 .37233 L F
.67537 .37331 m .67901 .37142 L .67811 .37087 L F
.975 .667 .323 r
.40458 .5867 m .40634 .59168 L .40473 .58956 L F
.601 .539 .757 r
.40458 .5867 m .40634 .59168 L .40826 .59023 L F
.716 .792 .911 r
.40826 .59023 m .40634 .59168 L .40473 .58956 L F
.389 .568 .908 r
.40944 .59253 m .40634 .59168 L .40826 .59023 L F
.875 .886 .839 r
.44767 .54351 m .44869 .53956 L .44699 .54148 L F
.44767 .54351 m .44597 .54284 L .44869 .53956 L F
0 .161 .691 r
.44767 .54351 m .44849 .54231 L .44597 .54284 L F
.262 0 0 r
.65552 .33315 m .65926 .33061 L .65651 .33151 L F
0 0 .194 r
.41537 .59265 m .41337 .59364 L .41263 .59602 L F
0 0 0 r
.43103 .45589 m .43262 .4557 L .43002 .45664 L F
.43103 .45589 m .43478 .45461 L .43262 .4557 L F
.722 .471 .547 r
.41642 .54969 m .42083 .54702 L .41799 .54622 L F
.41642 .54969 m .42078 .55006 L .42083 .54702 L F
.513 .821 1 r
.27883 .62674 m .28131 .62612 L .27702 .62565 L F
.27883 .62674 m .28131 .62612 L .27702 .62565 L F
.848 .921 .88 r
.57916 .42589 m .57787 .43028 L .57805 .42862 L F
.57916 .42589 m .58077 .42709 L .57787 .43028 L F
.336 .563 .92 r
.57787 .43028 m .58065 .43012 L .57805 .42862 L F
0 0 0 r
.43904 .45197 m .44061 .45063 L .44296 .44956 L F
.891 .822 .773 r
.52169 .38064 m .52482 .38079 L .52289 .37884 L F
.52169 .38064 m .52262 .38493 L .52482 .38079 L F
.707 .57 .698 r
.52482 .38079 m .52262 .38493 L .52653 .38442 L F
.515 .861 .601 r
.51781 .42433 m .52111 .42156 L .51947 .42274 L F
.934 .945 .606 r
.51947 .42274 m .52111 .42156 L .52185 .41837 L F
.097 0 .325 r
.24456 .56342 m .24601 .56287 L .24651 .56002 L F
.981 .718 .457 r
.37991 .55037 m .37814 .55209 L .37772 .54949 L F
.37991 .55037 m .37985 .55324 L .37814 .55209 L F
.325 .571 .929 r
.49316 .44374 m .49667 .44719 L .49771 .44669 L F
.995 .823 .562 r
.55688 .40441 m .55829 .40433 L .55801 .4009 L F
.937 .574 .29 r
.55854 .40627 m .55829 .40433 L .55688 .40441 L F
.689 .615 .768 r
.55801 .4009 m .55829 .40433 L .56147 .40266 L F
0 .104 .648 r
.28273 .6466 m .28396 .64717 L .28131 .64561 L F
.28273 .6466 m .28572 .6497 L .28396 .64717 L F
.687 .402 .485 r
.43976 .5458 m .43653 .5463 L .43699 .54377 L F
.307 .096 .421 r
.43653 .5463 m .4391 .54262 L .43699 .54377 L F
.764 .644 .729 r
.34225 .60309 m .34657 .60358 L .34487 .59963 L F
.504 .788 .996 r
.29703 .6514 m .29962 .6533 L .30063 .65249 L F
.928 .751 .643 r
.37846 .5438 m .37771 .54669 L .3763 .54269 L F
.753 .982 .91 r
.29779 .61828 m .29393 .61988 L .29595 .61777 L F
.106 .552 .914 r
.29854 .61751 m .29779 .61828 L .29595 .61777 L F
.29854 .61751 m .30025 .61881 L .29779 .61828 L F
0 0 0 r
.61393 .39119 m .61349 .39131 L .61271 .39155 L F
.837 .799 .815 r
.47421 .52688 m .47068 .52677 L .47319 .52332 L F
.78 .77 .844 r
.47714 .52369 m .47421 .52688 L .47319 .52332 L F
.897 .897 .819 r
.51384 .42424 m .51781 .42433 L .51606 .42351 L F
.505 .844 .997 r
.51606 .42351 m .51781 .42433 L .51947 .42274 L F
.735 .681 .798 r
.3808 .46809 m .38457 .47163 L .37827 .47034 L F
.767 .469 .48 r
.37827 .47034 m .38457 .47163 L .38249 .47325 L F
.872 .994 .787 r
.38249 .47325 m .38457 .47163 L .38516 .46988 L F
.973 .881 .681 r
.31315 .53042 m .31126 .52934 L .31336 .52864 L F
.971 .71 .478 r
.31315 .53042 m .3112 .53127 L .31126 .52934 L F
.31315 .53042 m .31288 .53349 L .3112 .53127 L F
0 0 .364 r
.31387 .52913 m .31315 .53042 L .31336 .52864 L F
.149 0 .389 r
.31492 .53126 m .31315 .53042 L .31387 .52913 L F
.31492 .53126 m .31288 .53349 L .31315 .53042 L F
.85 .573 .518 r
.68113 .34025 m .683 .33813 L .68095 .33745 L F
.68113 .34025 m .68319 .341 L .683 .33813 L F
0 0 0 r
.5526 .3884 m .55028 .38959 L .55134 .38788 L F
.372 0 0 r
.64592 .34434 m .64446 .34591 L .64166 .34531 L F
.034 0 0 r
.64716 .34485 m .64592 .34434 L .64858 .34413 L F
.64716 .34485 m .64446 .34591 L .64592 .34434 L F
.372 .831 .749 r
.43878 .44345 m .44043 .44251 L .44238 .44166 L F
.43878 .44345 m .438 .44361 L .44043 .44251 L F
.432 .072 .252 r
.54146 .45935 m .5393 .45804 L .54158 .45677 L F
.54146 .45935 m .53864 .46056 L .5393 .45804 L F
.534 .708 .951 r
.63302 .39839 m .63446 .39566 L .63172 .39632 L F
.63302 .39839 m .63565 .39796 L .63446 .39566 L F
.175 0 0 r
.65478 .40076 m .65356 .40069 L .65141 .40046 L F
.378 .745 .991 r
.65478 .40076 m .65775 .40092 L .65682 .39977 L F
.75 .946 .945 r
.30512 .61732 m .30025 .61881 L .30271 .61829 L F
.905 .901 .81 r
.3074 .61386 m .30512 .61732 L .30375 .61587 L F
.956 .88 .719 r
.30375 .61587 m .30512 .61732 L .30271 .61829 L F
.916 .858 .769 r
.51319 .48359 m .50906 .48585 L .51141 .48227 L F
.51319 .48359 m .51071 .48721 L .50906 .48585 L F
.966 .887 .701 r
.51262 .48106 m .51319 .48359 L .51141 .48227 L F
.84 .735 .212 r
.49331 .42946 m .49343 .43114 L .49307 .43357 L F
.485 .225 .444 r
.38809 .46702 m .39082 .46404 L .38796 .46415 L F
.532 .303 .513 r
.63272 .38138 m .6355 .38046 L .63541 .37793 L F
.821 .688 .717 r
.55431 .42036 m .55596 .42446 L .55255 .42382 L F
.883 .823 .784 r
.55596 .42446 m .55185 .42646 L .55255 .42382 L F
.55596 .42446 m .55397 .42795 L .55185 .42646 L F
.32 .794 .921 r
.64 .39844 m .64123 .39739 L .63867 .39736 L F
.64 .39844 m .64297 .39793 L .64123 .39739 L F
.841 .861 .858 r
.54542 .34477 m .54159 .34569 L .54388 .34328 L F
.345 .559 .916 r
.54664 .34253 m .54542 .34477 L .54388 .34328 L F
.54664 .34253 m .54774 .34436 L .54542 .34477 L F
.849 .998 .788 r
.66019 .38705 m .66222 .38501 L .66281 .38261 L F
.52 .356 .598 r
.25092 .54688 m .25378 .54639 L .25349 .54307 L F
.452 .338 .633 r
.25151 .55069 m .25378 .54639 L .25092 .54688 L F
.738 .955 .944 r
.50567 .39862 m .50665 .39616 L .50746 .39672 L F
.50567 .39862 m .50309 .39825 L .50665 .39616 L F
.865 .703 .679 r
.37126 .53002 m .37303 .53381 L .37046 .53306 L F
.867 .62 .562 r
.37303 .53381 m .37013 .53598 L .37046 .53306 L F
.37303 .53381 m .37283 .53646 L .37013 .53598 L F
.951 .856 .434 r
.3922 .57693 m .39065 .57875 L .3915 .58007 L F
.39065 .57875 m .39064 .57883 L .3915 .58007 L F
.963 .842 .676 r
.39064 .57883 m .39211 .58228 L .3915 .58007 L F
.39069 .57897 m .39211 .58228 L .39064 .57883 L F
.39069 .57897 m .39036 .5814 L .39211 .58228 L F
.73 .617 .732 r
.39072 .57873 m .39029 .58128 L .39065 .57875 L F
.39039 .58117 m .39029 .58128 L .39072 .57873 L F
.963 .842 .676 r
.39061 .5788 m .39036 .5814 L .39069 .57897 L F
.73 .617 .732 r
.39304 .57796 m .39039 .58117 L .39072 .57873 L F
.151 0 0 r
.39304 .57796 m .39065 .57875 L .3922 .57693 L F
.73 .617 .732 r
.39304 .57796 m .39065 .57875 L .39075 .57802 L F
.151 0 0 r
.39304 .57796 m .39061 .5788 L .39065 .57875 L F
.963 .842 .676 r
.39061 .5788 m .39069 .57897 L .39064 .57883 L F
.73 .617 .732 r
.39115 .58025 m .39036 .5814 L .39029 .58128 L F
.39304 .57796 m .39118 .58034 L .39115 .58025 L F
.39118 .58034 m .39036 .5814 L .39115 .58025 L F
.39075 .57802 m .39029 .58128 L .3886 .57808 L F
.951 .856 .434 r
.39065 .57875 m .39061 .5788 L .39064 .57883 L F
.151 0 0 r
.39304 .57796 m .3922 .57693 L .39474 .57914 L F
.03 0 0 r
.44043 .44251 m .44465 .44028 L .44238 .44166 L F
.218 .327 .762 r
.245 .57042 m .24635 .57458 L .2474 .57227 L F
.408 .327 .653 r
.24635 .57458 m .24849 .57664 L .2474 .57227 L F
.51 .356 .608 r
.25499 .53374 m .25741 .5332 L .25735 .53001 L F
.449 .247 .513 r
.25495 .53634 m .25741 .5332 L .25499 .53374 L F
.817 .935 .908 r
.48857 .52167 m .48829 .5242 L .49133 .52121 L F
.48857 .52167 m .48726 .52298 L .48829 .5242 L F
.993 .874 .599 r
.48726 .52298 m .48645 .52558 L .48829 .5242 L F
.716 .935 .615 r
.48111 .41443 m .47844 .41776 L .47951 .4157 L F
.71 .922 .585 r
.47844 .41776 m .47689 .41912 L .47951 .4157 L F
.484 .027 .091 r
.52262 .38493 m .52538 .38613 L .52653 .38442 L F
.902 .506 .252 r
.34898 .50728 m .34669 .50635 L .34542 .50322 L F
.88 .643 .577 r
.34909 .50964 m .34669 .50635 L .34898 .50728 L F
.776 .451 .436 r
.35333 .51021 m .34909 .50964 L .34898 .50728 L F
.958 .641 .381 r
.33329 .58721 m .33162 .58654 L .33131 .58319 L F
.823 .877 .885 r
.33021 .58821 m .32977 .58953 L .33162 .58654 L F
.875 .813 .785 r
.33329 .58721 m .33021 .58821 L .33162 .58654 L F
.951 .746 .59 r
.55185 .42646 m .55397 .42795 L .55335 .43045 L F
.749 .719 .824 r
.33004 .61276 m .33159 .61643 L .33424 .61331 L F
.905 .901 .81 r
.3074 .61386 m .30375 .61587 L .30572 .61272 L F
.859 .888 .857 r
.30996 .61045 m .3074 .61386 L .30572 .61272 L F
.394 .172 .455 r
.52311 .40096 m .52577 .40015 L .52582 .39768 L F
.52582 .39768 m .52577 .40015 L .52311 .40096 L F
.577 .913 .973 r
.52311 .40096 m .52449 .39912 L .52577 .40015 L F
.52311 .40096 m .52161 .40027 L .52449 .39912 L F
.226 .716 .922 r
.63154 .38383 m .63279 .38453 L .63006 .38454 L F
.63154 .38383 m .63006 .38454 L .62888 .3852 L F
.563 .349 .547 r
.6302 .3873 m .63279 .38453 L .63006 .38454 L F
.356 0 0 r
.52165 .38497 m .52538 .38613 L .52262 .38493 L F
.735 .656 .771 r
.33675 .55735 m .33166 .55695 L .33469 .55604 L F
0 0 .205 r
.51824 .3997 m .51638 .40142 L .51832 .39768 L F
.858 .655 .627 r
.54754 .44433 m .54443 .4458 L .5475 .44187 L F
.54754 .44433 m .54697 .44713 L .54443 .4458 L F
.6 .898 .987 r
.62777 .3964 m .62632 .39827 L .62903 .39695 L F
.62777 .3964 m .62508 .39746 L .62632 .39827 L F
.548 .405 .639 r
.25287 .54039 m .25495 .53634 L .25276 .53817 L F
.864 .885 .85 r
.42578 .60289 m .42579 .59836 L .42374 .59972 L F
.42578 .60289 m .42812 .60008 L .42579 .59836 L F
.238 0 .316 r
.42771 .60247 m .42812 .60008 L .42578 .60289 L F
.884 .943 .847 r
.29913 .65947 m .29708 .6624 L .29511 .66215 L F
.379 0 0 r
.59575 .34234 m .6 .34265 L .59711 .34311 L F
.765 .975 .919 r
.46938 .43502 m .47229 .43526 L .47431 .43356 L F
.892 .773 .724 r
.65013 .38373 m .65137 .38207 L .65159 .38043 L F
.6 .629 .852 r
.63272 .38138 m .63634 .38397 L .6355 .38046 L F
.64 .914 .98 r
.63634 .38397 m .63279 .38453 L .63594 .38376 L F
.209 .32 .759 r
.6355 .38046 m .63634 .38397 L .63811 .38205 L F
.604 .942 .766 r
.63634 .38397 m .63594 .38376 L .63811 .38205 L F
.911 .731 .646 r
.48127 .5171 m .47812 .51894 L .48011 .51545 L F
.48127 .5171 m .48007 .52054 L .47812 .51894 L F
.917 .666 .544 r
.36475 .52049 m .36174 .52208 L .36203 .51944 L F
.36475 .52049 m .36466 .52339 L .36174 .52208 L F
.237 .349 .776 r
.24686 .57991 m .24751 .58384 L .24917 .58163 L F
.707 .72 .86 r
.28665 .66599 m .28767 .66702 L .28325 .66602 L F
.686 .716 .871 r
.29007 .66506 m .28767 .66702 L .28665 .66599 L F
0 .254 .676 r
.39975 .59188 m .40112 .58946 L .39789 .5896 L F
.39975 .59188 m .39972 .59167 L .40112 .58946 L F
.39975 .59188 m .40169 .59299 L .39972 .59167 L F
.613 .437 .62 r
.66601 .32806 m .66889 .32779 L .66871 .32474 L F
.731 .528 .617 r
.66871 .32474 m .66889 .32779 L .67287 .3278 L F
.787 .784 .85 r
.43997 .59299 m .44396 .59318 L .44253 .59141 L F
.723 .704 .832 r
.44396 .59318 m .44486 .58899 L .44253 .59141 L F
.44396 .59318 m .44659 .59024 L .44486 .58899 L F
.786 .887 .918 r
.54013 .41995 m .54212 .41596 L .53943 .41667 L F
.54013 .41995 m .54364 .41738 L .54212 .41596 L F
.26 .035 .37 r
.53864 .46056 m .53613 .46337 L .53629 .46084 L F
.913 .767 .685 r
.32625 .52037 m .3228 .52217 L .32355 .51949 L F
.32625 .52037 m .32494 .52346 L .3228 .52217 L F
.568 .888 .619 r
.48111 .41443 m .48257 .41279 L .48276 .41284 L F
.561 .875 .588 r
.48111 .41443 m .47951 .4157 L .48257 .41279 L F
.772 .624 .697 r
.33692 .60983 m .34112 .61056 L .33937 .60639 L F
.794 .725 .788 r
.34332 .59575 m .34714 .59637 L .3481 .59352 L F
.808 .688 .732 r
.34332 .59575 m .34487 .59963 L .34714 .59637 L F
.29 0 0 r
.40661 .45916 m .40926 .45885 L .41087 .45695 L F
.279 0 0 r
.40926 .45885 m .41331 .45623 L .41087 .45695 L F
.828 .775 .802 r
.66287 .36676 m .66156 .36873 L .65969 .36675 L F
0 .007 .576 r
.54497 .38694 m .54671 .39017 L .54543 .38567 L F
.657 .703 .881 r
.42812 .60008 m .43248 .60075 L .43007 .59661 L F
.718 .59 .712 r
.42984 .60383 m .43248 .60075 L .42812 .60008 L F
.743 .704 .814 r
.43248 .60075 m .43285 .59582 L .43007 .59661 L F
.43248 .60075 m .4347 .59874 L .43285 .59582 L F
.33 .38 .762 r
.51992 .37622 m .52169 .38064 L .5198 .38129 L F
.51992 .37622 m .5198 .38129 L .52012 .37926 L F
.393 .705 .984 r
.5198 .38129 m .52169 .38064 L .52012 .37926 L F
.852 .425 .21 r
.42014 .55537 m .42181 .55448 L .41826 .55253 L F
.212 .73 .708 r
.449 .44752 m .45027 .44722 L .45271 .44653 L F
.556 .908 .7 r
.32153 .60258 m .3172 .60554 L .32064 .60309 L F
.375 .798 .607 r
.32271 .60185 m .32497 .60047 L .32153 .60258 L F
.374 .802 .621 r
.32271 .60185 m .32153 .60258 L .32064 .60309 L F
.981 .863 .648 r
.38428 .57034 m .38366 .57272 L .38211 .57158 L F
.979 .885 .665 r
.38307 .56938 m .38428 .57034 L .38211 .57158 L F
0 0 .098 r
.41198 .5638 m .41214 .56548 L .41115 .56311 L F
.387 .136 .406 r
.51301 .43699 m .51034 .43761 L .51018 .44028 L F
.879 .766 .733 r
.54253 .46054 m .53864 .46056 L .54146 .45935 L F
.54253 .46054 m .54052 .46422 L .53864 .46056 L F
.885 .958 .843 r
.54253 .46054 m .54421 .45601 L .54575 .45747 L F
.54253 .46054 m .54146 .45935 L .54421 .45601 L F
.745 .98 .74 r
.32647 .59102 m .3237 .59384 L .32485 .59173 L F
0 0 0 r
.32485 .59173 m .3237 .59384 L .32301 .59614 L F
0 0 .438 r
.55053 .40716 m .55068 .41093 L .54988 .41039 L F
.915 .571 .373 r
.55068 .41093 m .54961 .41247 L .54988 .41039 L F
.55068 .41093 m .5525 .41388 L .54961 .41247 L F
.733 .805 .909 r
.52092 .48062 m .5144 .4791 L .51629 .47772 L F
.52092 .48062 m .51262 .48106 L .5144 .4791 L F
.331 .613 .952 r
.51786 .477 m .52092 .48062 L .51629 .47772 L F
.72 .974 .925 r
.52193 .47969 m .52092 .48062 L .52214 .47953 L F
0 0 .258 r
.52193 .47969 m .52214 .47953 L .52209 .47756 L F
.331 .613 .952 r
.51786 .477 m .52214 .47953 L .52092 .48062 L F
.465 0 0 r
.29444 .68542 m .2988 .6859 L .29657 .68609 L F
.552 0 0 r
.2988 .6859 m .29942 .68702 L .29657 .68609 L F
.2988 .6859 m .30128 .68775 L .29942 .68702 L F
.405 .203 .489 r
.29284 .60993 m .28966 .61364 L .29202 .61275 L F
.771 .714 .799 r
.30487 .62076 m .30764 .62197 L .30691 .61916 L F
.761 .772 .862 r
.30764 .62197 m .31115 .61945 L .30691 .61916 L F
.614 .22 .273 r
.66603 .32963 m .66888 .33 L .66601 .32806 L F
.565 .272 .428 r
.66601 .32806 m .66888 .33 L .66889 .32779 L F
.604 .508 .719 r
.29283 .66573 m .29511 .66215 L .29397 .66215 L F
.775 .69 .77 r
.44489 .56033 m .44739 .56304 L .44615 .56185 L F
.66 .958 .747 r
.44739 .56304 m .44851 .56129 L .44615 .56185 L F
.494 .817 .507 r
.52092 .39382 m .51858 .3961 L .51832 .39768 L F
0 0 .205 r
.51824 .3997 m .51832 .39768 L .51858 .3961 L F
.718 .59 .712 r
.42984 .60383 m .42812 .60008 L .42771 .60247 L F
.508 .235 .436 r
.27296 .52621 m .27622 .52334 L .27338 .52375 L F
.843 .487 .379 r
.36794 .50063 m .36811 .50275 L .37203 .50365 L F
.9 .655 .559 r
.36811 .50275 m .3697 .50607 L .37203 .50365 L F
.813 .557 .552 r
.3697 .50607 m .37197 .50643 L .37203 .50365 L F
.806 .982 .894 r
.47534 .53831 m .47973 .53636 L .47801 .53553 L F
.689 .678 .834 r
.34965 .63414 m .34537 .63302 L .34784 .63261 L F
.653 .75 .921 r
.35085 .63127 m .34965 .63414 L .34784 .63261 L F
.35085 .63127 m .35153 .6333 L .34965 .63414 L F
.792 .647 .703 r
.34171 .57754 m .34023 .5794 L .33888 .57614 L F
.169 0 .012 r
.31562 .5271 m .31387 .52913 L .31336 .52864 L F
.2 0 .034 r
.31799 .52638 m .31387 .52913 L .31562 .5271 L F
.31799 .52638 m .31387 .52913 L .31562 .5271 L F
.123 0 .296 r
.52872 .35962 m .52934 .35992 L .53083 .35746 L F
.396 .836 .71 r
.337 .67535 m .34088 .67343 L .33845 .67442 L F
.239 0 .321 r
.34088 .67343 m .34367 .66996 L .34265 .6721 L F
.546 .918 .759 r
.33845 .67442 m .34088 .67343 L .34265 .6721 L F
.542 .473 .728 r
.25151 .55069 m .25221 .55389 L .25476 .55312 L F
.489 .204 .408 r
.25167 .55562 m .25476 .55312 L .25221 .55389 L F
.867 .94 .865 r
.5113 .49876 m .51554 .49675 L .51487 .49609 L F
.802 1 .829 r
.51655 .49366 m .51554 .49675 L .51904 .49399 L F
.51655 .49366 m .51487 .49609 L .51554 .49675 L F
0 0 0 r
.61393 .39119 m .61271 .39155 L .6097 .39063 L F
.747 .42 .43 r
.44637 .5789 m .45039 .57693 L .44638 .57646 L F
.44637 .5789 m .45073 .5794 L .45039 .57693 L F
.732 .615 .727 r
.41576 .46375 m .41655 .46733 L .41255 .46759 L F
0 0 0 r
.4161 .4673 m .41331 .46996 L .41396 .46877 L F
.71 .845 .413 r
.41396 .46877 m .41221 .47218 L .41226 .46944 L F
.41396 .46877 m .41294 .47031 L .41221 .47218 L F
0 0 0 r
.41331 .46996 m .41294 .47031 L .41396 .46877 L F
.404 0 0 r
.41255 .46759 m .41469 .46745 L .41396 .46877 L F
.41469 .46745 m .41655 .46733 L .41396 .46877 L F
0 0 0 r
.41829 .46499 m .41756 .4655 L .41922 .46402 L F
0 .052 .588 r
.41756 .4655 m .41655 .46733 L .41633 .46636 L F
.702 .97 .742 r
.41396 .46877 m .41655 .46733 L .41756 .4655 L F
0 0 0 r
.4161 .4673 m .41756 .4655 L .41829 .46499 L F
0 .052 .588 r
.41756 .4655 m .41633 .46636 L .41576 .46375 L F
.039 .23 .732 r
.43874 .56453 m .43828 .56683 L .43675 .56295 L F
0 .124 .668 r
.43675 .56295 m .43828 .56683 L .43824 .56523 L F
.811 .711 .755 r
.43828 .56683 m .43439 .56947 L .43824 .56523 L F
.43828 .56683 m .43616 .57066 L .43439 .56947 L F
.992 .762 .482 r
.43874 .56453 m .44045 .56956 L .43828 .56683 L F
.362 .581 .926 r
.43874 .56453 m .43828 .56683 L .43824 .56523 L F
.344 .376 .751 r
.3239 .59751 m .32497 .60047 L .32458 .59753 L F
.989 .82 .582 r
.324 .59887 m .32497 .60047 L .32271 .60185 L F
.32458 .59753 m .32475 .59884 L .324 .59887 L F
.32475 .59884 m .32497 .60047 L .324 .59887 L F
.32458 .59753 m .32271 .60185 L .32561 .60151 L F
.791 .301 .04 r
.32329 .59885 m .32271 .60185 L .32084 .59783 L F
.32329 .59885 m .32253 .60019 L .32271 .60185 L F
.32327 .59889 m .32561 .60151 L .32253 .60019 L F
.32329 .59885 m .32332 .59889 L .32327 .59889 L F
.32332 .59889 m .32561 .60151 L .32327 .59889 L F
.822 .895 .893 r
.46019 .55426 m .46229 .55277 L .46046 .55127 L F
.831 .895 .887 r
.46046 .55127 m .46229 .55277 L .46509 .54966 L F
.738 .806 .906 r
.31088 .60642 m .31213 .60963 L .30811 .60901 L F
.799 .741 .799 r
.30811 .60901 m .31213 .60963 L .30996 .61045 L F
.743 .809 .904 r
.3153 .60703 m .31213 .60963 L .31088 .60642 L F
.686 .449 .557 r
.49666 .43098 m .50138 .43019 L .50084 .42757 L F
.552 .576 .832 r
.50029 .42548 m .50084 .42757 L .50353 .42679 L F
.051 .036 .518 r
.50084 .42757 m .50287 .42871 L .50353 .42679 L F
.50084 .42757 m .50138 .43019 L .50287 .42871 L F
.777 .644 .715 r
.55276 .43324 m .55546 .43467 L .55393 .43676 L F
.746 .721 .829 r
.31294 .64064 m .30877 .63998 L .31128 .6388 L F
.66 .741 .91 r
.31128 .6388 m .31555 .63964 L .31294 .64064 L F
.145 0 0 r
.59863 .35175 m .59499 .35303 L .59539 .35457 L F
.849 .505 .403 r
.59499 .35303 m .59537 .35692 L .59539 .35457 L F
.824 .606 .608 r
.49331 .42946 m .49718 .42658 L .49585 .42581 L F
.49331 .42946 m .49666 .43098 L .49718 .42658 L F
.638 .878 .986 r
.49718 .42658 m .49827 .42439 L .49585 .42581 L F
.49718 .42658 m .50029 .42548 L .49827 .42439 L F
0 0 0 r
.6338 .34739 m .63231 .34792 L .63496 .34671 L F
.6338 .34739 m .63087 .34859 L .63231 .34792 L F
.859 .899 .862 r
.50879 .50205 m .50721 .5037 L .51014 .50301 L F
.535 .916 .933 r
.48267 .42757 m .48395 .42782 L .48658 .42672 L F
.448 0 .018 r
.62686 .34305 m .62992 .34313 L .6309 .34139 L F
.075 0 0 r
.6309 .34139 m .6325 .34209 L .63363 .34036 L F
.6309 .34139 m .63003 .34293 L .6325 .34209 L F
.129 0 0 r
.63363 .34036 m .6325 .34209 L .63517 .34122 L F
.242 0 0 r
.63108 .34222 m .63468 .34134 L .6325 .34209 L F
.63468 .34134 m .63517 .34122 L .6325 .34209 L F
.075 0 0 r
.63003 .34293 m .62992 .34313 L .6325 .34209 L F
.917 .662 .537 r
.34995 .56813 m .35071 .56705 L .34748 .56599 L F
.838 .625 .615 r
.40367 .54923 m .4064 .54748 L .40537 .54618 L F
.40367 .54923 m .4069 .55029 L .4064 .54748 L F
.655 .707 .886 r
.40537 .54618 m .4064 .54748 L .40891 .5461 L F
.357 .299 .655 r
.4064 .54748 m .40856 .54892 L .40891 .5461 L F
.4064 .54748 m .4069 .55029 L .40856 .54892 L F
.116 .385 .842 r
.28961 .62192 m .29076 .62462 L .2898 .62407 L F
.855 .846 .833 r
.29393 .61988 m .29076 .62462 L .28961 .62192 L F
.639 .113 0 r
.28993 .625 m .29352 .62526 L .29344 .62304 L F
.753 .909 .945 r
.29344 .62304 m .29352 .62526 L .29741 .62249 L F
.452 .338 .633 r
.25151 .55069 m .25396 .55025 L .25378 .54639 L F
.542 .473 .728 r
.25151 .55069 m .25476 .55312 L .25396 .55025 L F
.821 .475 .401 r
.33682 .5203 m .33651 .52225 L .3388 .52025 L F
.86 .54 .443 r
.3388 .52025 m .33651 .52225 L .3391 .52278 L F
.834 .567 .534 r
.38354 .56349 m .38074 .56555 L .38105 .56258 L F
.38354 .56349 m .38362 .56655 L .38074 .56555 L F
.858 .754 .747 r
.34523 .55913 m .34735 .56027 L .34593 .55662 L F
.879 .681 .631 r
.34354 .56197 m .34735 .56027 L .34523 .55913 L F
.34354 .56197 m .34697 .56341 L .34735 .56027 L F
.79 .57 .602 r
.36472 .47289 m .36895 .47347 L .36935 .47073 L F
.475 .281 .537 r
.36895 .47347 m .37149 .47279 L .36935 .47073 L F
.822 .895 .893 r
.46019 .55426 m .46046 .55127 L .4581 .5517 L F
.515 .895 .716 r
.32848 .58955 m .32647 .59102 L .32485 .59173 L F
0 0 0 r
.38596 .47296 m .38967 .47112 L .38738 .47265 L F
.26 0 0 r
.38738 .47265 m .38967 .47112 L .39175 .4715 L F
.281 0 .067 r
.38967 .47112 m .39228 .47043 L .39175 .4715 L F
.774 .778 .856 r
.43616 .57066 m .43179 .5702 L .43439 .56947 L F
.782 .459 .441 r
.66226 .34123 m .6589 .34293 L .65791 .34112 L F
.66226 .34123 m .66261 .34359 L .6589 .34293 L F
.417 .003 .144 r
.4192 .45338 m .4224 .45242 L .42326 .451 L F
.176 0 .015 r
.42326 .451 m .42503 .4512 L .426 .45044 L F
.42326 .451 m .4224 .45242 L .42503 .4512 L F
.601 .539 .757 r
.40458 .5867 m .40826 .59023 L .40473 .58956 L F
.988 .716 .394 r
.27077 .64563 m .27237 .6461 L .27228 .64927 L F
.975 .91 .677 r
.27296 .64356 m .27237 .6461 L .27077 .64563 L F
.793 .388 .284 r
.27296 .64356 m .27533 .64607 L .27237 .6461 L F
.497 .269 .498 r
.27237 .6461 m .27533 .64607 L .27228 .64927 L F
.901 .912 .82 r
.49007 .51988 m .49133 .52121 L .49275 .51926 L F
.49007 .51988 m .48857 .52167 L .49133 .52121 L F
0 0 0 r
.52403 .39078 m .52302 .39274 L .52092 .39382 L F
0 .189 .626 r
.52137 .38879 m .52401 .39054 L .5256 .38939 L F
0 0 0 r
.52478 .39105 m .52403 .39078 L .5256 .38939 L F
0 .189 .626 r
.52401 .39054 m .52478 .39105 L .5256 .38939 L F
.495 .855 .611 r
.52698 .38839 m .5256 .38939 L .52403 .39078 L F
.52702 .38836 m .5256 .38939 L .52698 .38839 L F
0 0 0 r
.52478 .39105 m .52302 .39274 L .52403 .39078 L F
.547 .302 .496 r
.43127 .59171 m .43364 .59027 L .43194 .5918 L F
0 .175 .697 r
.43127 .59171 m .43068 .59315 L .42901 .58969 L F
.433 .203 .463 r
.43168 .58901 m .43127 .59171 L .42901 .58969 L F
.922 .784 .691 r
.42992 .59279 m .43127 .59171 L .43164 .59119 L F
.42818 .59441 m .43127 .59171 L .42992 .59279 L F
.547 .302 .496 r
.43127 .59171 m .43168 .58901 L .43332 .59006 L F
.43127 .59171 m .43332 .59006 L .43364 .59027 L F
.898 .601 .474 r
.34349 .53873 m .34575 .53693 L .3437 .53593 L F
.34349 .53873 m .34584 .53956 L .34575 .53693 L F
.3 0 .251 r
.32694 .58291 m .32431 .5858 L .32452 .58366 L F
.32694 .58291 m .32431 .5858 L .32452 .58366 L F
.792 .886 .914 r
.42579 .59836 m .42812 .60008 L .43007 .59661 L F
.848 .388 .075 r
.58763 .40327 m .58647 .40493 L .58617 .40236 L F
.58763 .40327 m .58833 .40574 L .58647 .40493 L F
.645 .967 .888 r
.68072 .36935 m .67901 .37142 L .68125 .36978 L F
.636 .954 .935 r
.67811 .37087 m .67901 .37142 L .68072 .36935 L F
.459 .392 .694 r
.25349 .54307 m .25543 .54005 L .25287 .54039 L F
.25349 .54307 m .25576 .5426 L .25543 .54005 L F
.286 .184 .56 r
.25349 .54307 m .25548 .54549 L .25576 .5426 L F
.25349 .54307 m .25378 .54639 L .25548 .54549 L F
.347 0 0 r
.64166 .34531 m .64446 .34591 L .64172 .34596 L F
.848 .944 .883 r
.54674 .46893 m .54789 .47009 L .551 .46707 L F
.021 0 0 r
.28216 .67425 m .2827 .67453 L .27993 .67416 L F
.28216 .67425 m .28465 .67388 L .2827 .67453 L F
.594 .924 .703 r
.28599 .53412 m .28377 .53543 L .28278 .53663 L F
0 0 0 r
.28855 .53311 m .28377 .53543 L .28599 .53412 L F
.149 0 .297 r
.31677 .59106 m .31481 .59033 L .31873 .58921 L F
.31677 .59106 m .31476 .59245 L .31481 .59033 L F
.641 .149 .068 r
.43675 .56295 m .43929 .56395 L .44095 .56346 L F
.039 .23 .732 r
.43933 .56392 m .43675 .56295 L .44095 .56346 L F
.565 .616 .862 r
.44209 .56207 m .43933 .56392 L .43825 .55895 L F
.43933 .56392 m .43929 .56395 L .43928 .5639 L F
.43933 .56392 m .43928 .5639 L .43825 .55895 L F
.039 .23 .732 r
.43933 .56392 m .43928 .5639 L .43933 .56392 L F
.43928 .5639 m .43675 .56295 L .43933 .56392 L F
.501 .57 .857 r
.43928 .5639 m .43929 .56395 L .43675 .56295 L F
.039 .23 .732 r
.43833 .56421 m .43675 .56295 L .43933 .56392 L F
.501 .57 .857 r
.43825 .55895 m .43928 .5639 L .43675 .56295 L F
.566 .938 .85 r
.44209 .56207 m .43933 .56392 L .44095 .56346 L F
.43933 .56392 m .43929 .56395 L .44095 .56346 L F
.039 .23 .732 r
.43874 .56453 m .43833 .56421 L .44095 .56346 L F
.566 .938 .85 r
.44209 .56207 m .44095 .56346 L .44354 .56285 L F
.579 .927 .74 r
.44209 .56207 m .44095 .56346 L .44354 .56285 L F
.44209 .56207 m .43874 .56453 L .44095 .56346 L F
.813 .747 .791 r
.32312 .61547 m .32755 .61603 L .32586 .61228 L F
.816 .739 .779 r
.32521 .6171 m .32755 .61603 L .32312 .61547 L F
.701 .698 .843 r
.32586 .61228 m .32755 .61603 L .33004 .61276 L F
.656 .726 .901 r
.32006 .64085 m .31555 .63964 L .31783 .63858 L F
.757 .691 .789 r
.31783 .63858 m .32223 .63898 L .32006 .64085 L F
.827 .509 .451 r
.50717 .4432 m .50725 .44093 L .50325 .44011 L F
.415 .166 .425 r
.51018 .44028 m .50725 .44093 L .50717 .4432 L F
.037 .152 .656 r
.54235 .43529 m .54034 .43507 L .54042 .43329 L F
.421 .008 .147 r
.54059 .4366 m .54034 .43507 L .53924 .43813 L F
0 0 .145 r
.54056 .43605 m .54059 .4366 L .54003 .43648 L F
.54056 .43605 m .54034 .43507 L .54059 .4366 L F
.238 0 0 r
.53848 .43616 m .54003 .43648 L .53641 .43599 L F
.54003 .43648 m .54018 .43654 L .53641 .43599 L F
0 0 .145 r
.54042 .43329 m .54034 .43507 L .54056 .43605 L F
.54042 .43329 m .54056 .43605 L .53848 .43616 L F
.238 0 0 r
.54003 .43648 m .54059 .4366 L .54018 .43654 L F
.788 .697 .764 r
.54018 .43654 m .54059 .4366 L .54045 .4363 L F
.093 0 .03 r
.53985 .43642 m .54034 .43507 L .5406 .43622 L F
.54007 .4365 m .5406 .43622 L .54072 .43674 L F
.53985 .43642 m .5406 .43622 L .54007 .4365 L F
0 0 .145 r
.54056 .43605 m .5404 .43618 L .54034 .43606 L F
.5404 .43618 m .54003 .43648 L .54034 .43606 L F
.54034 .43606 m .54003 .43648 L .53848 .43616 L F
.093 0 .03 r
.54056 .43605 m .54034 .43507 L .5416 .43521 L F
.54056 .43605 m .5416 .43521 L .54235 .43529 L F
.559 .588 .839 r
.53851 .43217 m .54045 .4363 L .54235 .43529 L F
.54045 .4363 m .54059 .4366 L .54235 .43529 L F
.496 .25 .471 r
.53814 .43303 m .53562 .43061 L .53286 .43341 L F
.349 .247 .595 r
.53851 .43217 m .53562 .43061 L .53814 .43303 L F
.731 .605 .716 r
.53241 .43607 m .53814 .43303 L .53286 .43341 L F
.238 0 0 r
.53848 .43616 m .54059 .4366 L .53641 .43599 L F
.731 .605 .716 r
.53241 .43607 m .53641 .43599 L .53814 .43303 L F
.932 .968 .747 r
.53814 .43303 m .53641 .43599 L .53851 .43217 L F
.788 .697 .764 r
.53641 .43599 m .54018 .43654 L .53851 .43217 L F
.54018 .43654 m .54045 .4363 L .53851 .43217 L F
.093 0 .03 r
.53924 .43813 m .53964 .43703 L .54073 .43677 L F
.53964 .43703 m .53985 .43642 L .54017 .43655 L F
.53964 .43703 m .54017 .43655 L .54073 .43677 L F
.53985 .43642 m .54072 .43674 L .54073 .43677 L F
0 0 0 r
.54235 .43529 m .54059 .4366 L .53924 .43813 L F
.093 0 .03 r
.54073 .43677 m .54056 .43605 L .54235 .43529 L F
.912 .62 .478 r
.5525 .41388 m .54949 .41555 L .54961 .41247 L F
.5525 .41388 m .55243 .41677 L .54949 .41555 L F
.401 .354 .69 r
.26777 .5525 m .26885 .55565 L .26579 .55682 L F
.382 .155 .441 r
.26885 .55565 m .26583 .55936 L .26579 .55682 L F
.266 0 0 r
.42499 .4579 m .42404 .45893 L .42187 .45931 L F
.056 0 .004 r
.42499 .4579 m .42652 .45772 L .42404 .45893 L F
.42499 .4579 m .42713 .45668 L .42652 .45772 L F
0 0 .003 r
.57376 .40233 m .57401 .39973 L .57271 .39911 L F
.903 .897 .812 r
.57362 .39694 m .57401 .39973 L .5756 .39691 L F
.57362 .39694 m .57271 .39911 L .57401 .39973 L F
.93 .716 .592 r
.68474 .3444 m .68319 .341 L .68261 .34368 L F
.838 .527 .462 r
.68265 .34635 m .68474 .3444 L .68261 .34368 L F
.68265 .34635 m .68648 .34754 L .68474 .3444 L F
.889 .944 .841 r
.66562 .35502 m .66234 .35659 L .66427 .35354 L F
.66562 .35502 m .66316 .35792 L .66234 .35659 L F
0 0 .341 r
.39389 .53183 m .39279 .53048 L .39572 .53021 L F
.39389 .53183 m .39249 .53379 L .39279 .53048 L F
.269 0 0 r
.3239 .59751 m .32329 .59885 L .32301 .59614 L F
.3239 .59751 m .32458 .59753 L .32329 .59885 L F
.763 .685 .777 r
.34023 .5794 m .33759 .58264 L .33634 .57927 L F
.381 0 0 r
.31336 .52864 m .31126 .52934 L .31387 .52913 L F
.984 .837 .616 r
.42217 .56193 m .42443 .56052 L .42327 .55815 L F
.42217 .56193 m .42364 .56316 L .42443 .56052 L F
.488 .706 .966 r
.38758 .52349 m .39082 .5235 L .38801 .52269 L F
.118 .234 .71 r
.38801 .52269 m .38988 .52582 L .38758 .52349 L F
1 .824 .502 r
.66316 .35792 m .66161 .35945 L .66234 .35659 L F
.66316 .35792 m .66271 .36072 L .66161 .35945 L F
.015 0 0 r
.40588 .56093 m .40472 .56256 L .4023 .5635 L F
.417 0 .054 r
.4082 .56214 m .40588 .56093 L .40743 .56058 L F
.4082 .56214 m .40472 .56256 L .40588 .56093 L F
0 .03 .602 r
.67277 .31147 m .6729 .31052 L .67106 .30731 L F
.967 .771 .335 r
.67277 .31147 m .67248 .31417 L .67188 .31148 L F
.755 .978 .724 r
.67416 .30882 m .6729 .31052 L .67277 .31147 L F
.49 .469 .761 r
.67106 .30731 m .6729 .31052 L .67416 .30882 L F
.755 .977 .719 r
.67277 .31147 m .67188 .31148 L .67416 .30882 L F
.825 .81 .836 r
.39474 .57914 m .39715 .58123 L .39772 .57911 L F
.39474 .57914 m .39715 .58123 L .39772 .57911 L F
.58 .362 .548 r
.27762 .54354 m .27747 .54637 L .27498 .54591 L F
0 0 .072 r
.2785 .53905 m .27762 .54354 L .27675 .53987 L F
.2785 .53905 m .27826 .54192 L .27762 .54354 L F
0 .179 .707 r
.27826 .54192 m .27978 .54553 L .27762 .54354 L F
.425 .234 .517 r
.27978 .54553 m .27747 .54637 L .27762 .54354 L F
.459 .741 .989 r
.64931 .39662 m .65097 .39766 L .6523 .39635 L F
.933 .635 .455 r
.65097 .39766 m .64931 .39662 L .6523 .39635 L F
.65097 .39766 m .65141 .40046 L .64931 .39662 L F
.87 .743 .72 r
.3181 .56455 m .31546 .56589 L .31599 .56299 L F
.386 .057 .28 r
.3181 .56455 m .31314 .5695 L .31546 .56589 L F
.3181 .56455 m .31574 .56892 L .31314 .5695 L F
.26 0 .207 r
.31899 .56754 m .3181 .56455 L .32033 .56685 L F
.31806 .56675 m .3181 .56455 L .31899 .56754 L F
.31803 .56803 m .31574 .56892 L .31681 .56695 L F
.31806 .56675 m .31681 .56695 L .3181 .56455 L F
.31803 .56803 m .31681 .56695 L .31806 .56675 L F
.259 0 0 r
.31398 .56183 m .31843 .56025 L .31599 .56299 L F
.399 .493 .839 r
.31577 .56481 m .32008 .56642 L .31661 .56183 L F
.26 0 .207 r
.31803 .56803 m .31806 .56675 L .31899 .56754 L F
.404 .204 .492 r
.31546 .56589 m .31803 .56803 L .3202 .56682 L F
0 0 0 r
.32025 .56697 m .32033 .56685 L .3218 .56518 L F
.32036 .56685 m .3218 .56518 L .32031 .5666 L F
.32032 .56653 m .32119 .56451 L .32072 .564 L F
.32031 .5666 m .32119 .56451 L .32032 .56653 L F
.32025 .56697 m .32036 .56685 L .32031 .5666 L F
.743 .803 .9 r
.32059 .56661 m .32025 .56697 L .32072 .564 L F
.404 .204 .492 r
.32031 .56657 m .3202 .56682 L .32047 .56667 L F
.32031 .56657 m .32047 .56667 L .32053 .5666 L F
.31546 .56589 m .3202 .56682 L .32031 .56657 L F
0 0 0 r
.32031 .5666 m .3218 .56518 L .32119 .56451 L F
.399 .493 .839 r
.32027 .56639 m .32059 .56661 L .32039 .56637 L F
.32029 .5665 m .32059 .56661 L .32027 .56639 L F
.32008 .56642 m .32039 .56637 L .31661 .56183 L F
.31736 .56615 m .32059 .56661 L .31577 .56481 L F
0 0 0 r
.32025 .56697 m .31803 .56803 L .32033 .56685 L F
.743 .803 .9 r
.32059 .56661 m .31803 .56803 L .32025 .56697 L F
.877 .645 .583 r
.32025 .56697 m .31891 .57055 L .31803 .56803 L F
0 0 .266 r
.31803 .56803 m .31846 .56884 L .32025 .56697 L F
.762 .591 .665 r
.31661 .56183 m .32055 .56656 L .32072 .564 L F
.32055 .56656 m .32059 .56661 L .32059 .56651 L F
.32055 .56656 m .32059 .56651 L .32072 .564 L F
.648 .876 .516 r
.3203 .56689 m .31846 .56884 L .32104 .56544 L F
.32029 .5669 m .32027 .56692 L .3203 .56689 L F
.32027 .56692 m .31846 .56884 L .3203 .56689 L F
.32025 .56697 m .32014 .56709 L .32029 .5669 L F
.32014 .56709 m .31846 .56884 L .32029 .5669 L F
.404 .204 .492 r
.32053 .5666 m .32047 .56667 L .32059 .56661 L F
.399 .493 .839 r
.32008 .56642 m .32029 .5665 L .32027 .56639 L F
.31546 .56589 m .31736 .56615 L .31577 .56481 L F
.474 .895 .861 r
.45444 .43465 m .44983 .43599 L .4523 .43496 L F
.658 .972 .861 r
.4565 .43301 m .45444 .43465 L .4523 .43496 L F
.49 0 .018 r
.40178 .57738 m .40418 .57849 L .40582 .57676 L F
.802 .932 .563 r
.40582 .57676 m .40418 .57849 L .40622 .575 L F
.778 .806 .875 r
.33532 .60616 m .33937 .60639 L .33756 .60462 L F
.821 .7 .73 r
.33692 .60983 m .33937 .60639 L .33532 .60616 L F
.823 .809 .838 r
.33756 .60462 m .33937 .60639 L .34225 .60309 L F
.947 .811 .677 r
.34446 .54492 m .34712 .54376 L .34515 .54254 L F
.34446 .54492 m .34669 .54664 L .34712 .54376 L F
.495 .298 .543 r
.60981 .38741 m .6097 .39063 L .60711 .39124 L F
.227 0 0 r
.61137 .38829 m .60981 .38741 L .6084 .38866 L F
.61137 .38829 m .61246 .38729 L .60981 .38741 L F
.935 .8 .687 r
.3429 .54861 m .34669 .54664 L .34446 .54492 L F
.3429 .54861 m .34468 .54962 L .34669 .54664 L F
.603 .35 .506 r
.50187 .44731 m .50524 .44918 L .50262 .45051 L F
.689 .615 .768 r
.55801 .4009 m .56147 .40266 L .55955 .39957 L F
.513 .559 .84 r
.32308 .58338 m .32148 .58661 L .3205 .58401 L F
.783 .831 .889 r
.43285 .59582 m .4375 .59519 L .43625 .59235 L F
.807 .721 .771 r
.4347 .59874 m .4375 .59519 L .43285 .59582 L F
.717 .768 .893 r
.4375 .59519 m .43799 .59142 L .43625 .59235 L F
.4375 .59519 m .43997 .59299 L .43799 .59142 L F
.887 .796 .753 r
.38366 .57272 m .37939 .57545 L .38211 .57158 L F
.38366 .57272 m .38136 .57645 L .37939 .57545 L F
.974 .709 .466 r
.67432 .30607 m .67599 .30961 L .67556 .30773 L F
.534 .388 .628 r
.25741 .5332 m .25974 .52932 L .25735 .53001 L F
.002 0 .096 r
.34367 .66996 m .34662 .66662 L .345 .66876 L F
0 0 .062 r
.34265 .6721 m .34367 .66996 L .345 .66876 L F
.578 .564 .802 r
.33162 .58654 m .32694 .58291 L .33131 .58319 L F
.942 .676 .503 r
.25643 .63019 m .25844 .63287 L .25839 .62975 L F
.25643 .63019 m .25844 .63287 L .25839 .62975 L F
.763 .961 .66 r
.57055 .40547 m .56965 .40758 L .57218 .4044 L F
0 0 .003 r
.56918 .41014 m .56965 .40758 L .57055 .40547 L F
.649 .759 .929 r
.31464 .55671 m .31204 .558 L .31004 .5558 L F
.31004 .5558 m .31204 .558 L .31464 .55671 L F
.198 .033 .419 r
.60231 .38699 m .60432 .38897 L .60567 .38726 L F
.60231 .38699 m .60218 .39042 L .60432 .38897 L F
.815 .488 0 r
.60567 .38726 m .60335 .38645 L .60231 .38699 L F
.545 .83 .998 r
.25155 .57824 m .25078 .58013 L .25395 .57694 L F
.654 .316 .388 r
.25564 .57557 m .25155 .57824 L .25395 .57694 L F
.943 .625 .405 r
.39572 .53021 m .39592 .53295 L .39389 .53183 L F
.718 .758 .885 r
.32081 .63601 m .32223 .63898 L .31783 .63858 L F
.711 .756 .887 r
.32488 .63642 m .32223 .63898 L .32081 .63601 L F
.535 .608 .872 r
.29316 .63985 m .29242 .64329 L .29111 .64153 L F
.29316 .63985 m .29506 .64285 L .29242 .64329 L F
.454 .568 .88 r
.29671 .64656 m .29242 .64329 L .29506 .64285 L F
.18 .66 .929 r
.67721 .31536 m .67493 .31426 L .67248 .31417 L F
.8 .918 .917 r
.6777 .31221 m .67721 .31536 L .6796 .31381 L F
.6777 .31221 m .67493 .31426 L .67721 .31536 L F
.145 0 0 r
.59863 .35175 m .59722 .35307 L .59499 .35303 L F
0 0 0 r
.59977 .35206 m .59863 .35175 L .6012 .35052 L F
.59977 .35206 m .59722 .35307 L .59863 .35175 L F
.246 0 0 r
.63651 .34053 m .63937 .33993 L .6405 .33814 L F
.217 0 0 r
.6405 .33814 m .64227 .33857 L .64311 .33707 L F
.6405 .33814 m .63937 .33993 L .64227 .33857 L F
.678 .632 .796 r
.29767 .64184 m .29671 .64656 L .29506 .64285 L F
.29767 .64184 m .29905 .64555 L .29671 .64656 L F
.071 0 0 r
.60711 .39124 m .6097 .39063 L .60857 .39183 L F
.721 .983 .9 r
.46535 .42667 m .46266 .42944 L .46209 .42943 L F
.46535 .42667 m .46613 .42713 L .46266 .42944 L F
0 0 .096 r
.28961 .62192 m .2898 .62407 L .28993 .625 L F
.013 0 .066 r
.28803 .62653 m .2898 .62407 L .28993 .625 L F
.93 .844 .737 r
.44472 .55571 m .4468 .55734 L .44489 .56033 L F
.208 .062 .452 r
.4468 .55734 m .4485 .55572 L .44816 .55351 L F
.686 .852 .962 r
.44472 .55571 m .4485 .55572 L .4468 .55734 L F
.658 .968 .809 r
.54554 .34719 m .54301 .34818 L .54223 .34978 L F
.752 .887 .94 r
.29298 .67743 m .28869 .67763 L .29096 .67743 L F
0 0 0 r
.29394 .6772 m .29298 .67743 L .29096 .67743 L F
.29394 .6772 m .29578 .67637 L .29298 .67743 L F
.194 0 0 r
.32761 .67979 m .3274 .67934 L .33012 .67923 L F
.429 .309 .615 r
.31196 .67527 m .30928 .67526 L .30925 .67285 L F
.31196 .67527 m .30928 .67526 L .30925 .67285 L F
.194 0 0 r
.39985 .46148 m .39759 .46127 L .39704 .46195 L F
.951 .814 .672 r
.55967 .4543 m .55943 .44981 L .5576 .45302 L F
.922 .705 .591 r
.5576 .45302 m .55928 .45707 L .55967 .4543 L F
.433 0 0 r
.37616 .50688 m .37879 .50806 L .38003 .5067 L F
.848 .65 .635 r
.37879 .50806 m .38299 .50605 L .38003 .5067 L F
.498 0 0 r
.39606 .51361 m .39822 .51562 L .39756 .51496 L F
.471 0 0 r
.39822 .51562 m .40068 .51677 L .39756 .51496 L F
.851 .678 .667 r
.34995 .56813 m .3484 .57248 L .35222 .57293 L F
.846 .717 .721 r
.3484 .57248 m .35 .57634 L .35222 .57293 L F
.037 0 .445 r
.5628 .39018 m .56422 .38971 L .56355 .38581 L F
0 0 .452 r
.5628 .39018 m .56403 .39141 L .56422 .38971 L F
.92 .571 .36 r
.2829 .6782 m .28566 .67976 L .28592 .68218 L F
.856 .77 .766 r
.44512 .55269 m .44749 .54956 L .44816 .55351 L F
.754 .429 .435 r
.44816 .55351 m .44472 .55571 L .44512 .55269 L F
.44816 .55351 m .4485 .55572 L .44472 .55571 L F
.264 0 0 r
.42187 .45931 m .42264 .46117 L .42014 .46196 L F
.42187 .45931 m .42404 .45893 L .42264 .46117 L F
.875 .69 .648 r
.55276 .43324 m .55393 .43676 L .55088 .43656 L F
.862 .783 .773 r
.55393 .43676 m .55183 .4403 L .55088 .43656 L F
.686 .369 .433 r
.66889 .32779 m .67321 .33 L .67287 .3278 L F
0 .052 .588 r
.41756 .4655 m .41576 .46375 L .41798 .46303 L F
.047 0 0 r
.40946 .46974 m .41255 .46759 L .41226 .46944 L F
.404 0 0 r
.41255 .46759 m .41396 .46877 L .41226 .46944 L F
.921 .787 .695 r
.39847 .5756 m .40174 .57356 L .4012 .57194 L F
.39847 .5756 m .40046 .57702 L .40174 .57356 L F
.607 .917 .977 r
.40518 .57241 m .40245 .57183 L .40174 .57356 L F
.156 .416 .858 r
.40174 .57356 m .40245 .57183 L .4012 .57194 L F
.052 .619 .723 r
.61508 .38715 m .61713 .38707 L .61246 .38729 L F
.694 .174 0 r
.61934 .38933 m .61713 .38707 L .61508 .38715 L F
0 0 .159 r
.2794 .51976 m .27939 .52032 L .28094 .51904 L F
.817 .443 .348 r
.35335 .51282 m .34909 .50964 L .35333 .51021 L F
.469 .836 .586 r
.51851 .39908 m .51625 .40077 L .51457 .40219 L F
.51871 .39893 m .51857 .39903 L .51851 .39908 L F
.51857 .39903 m .51625 .40077 L .51851 .39908 L F
0 0 0 r
.51824 .3997 m .51847 .39945 L .51871 .39893 L F
.51847 .39945 m .51889 .39899 L .51871 .39893 L F
0 0 .276 r
.51828 .39928 m .5185 .39918 L .51824 .3997 L F
.694 .562 .702 r
.51851 .39908 m .51847 .39945 L .51871 .39893 L F
.363 .031 .262 r
.51821 .40283 m .52161 .40027 L .51824 .3997 L F
.694 .562 .702 r
.51847 .39945 m .51821 .40283 L .51871 .39893 L F
.51705 .40263 m .51814 .40282 L .51847 .39945 L F
.51814 .40282 m .51821 .40283 L .51847 .39945 L F
0 0 0 r
.51865 .39994 m .5187 .39908 L .51889 .39899 L F
.5187 .39908 m .51871 .39893 L .51889 .39899 L F
0 0 .276 r
.51851 .39916 m .5187 .39908 L .5185 .39918 L F
.51851 .39908 m .5185 .39918 L .51828 .39928 L F
.5185 .39918 m .51847 .39945 L .51824 .3997 L F
.694 .562 .702 r
.51457 .40219 m .51705 .40263 L .51847 .39945 L F
.51457 .40219 m .51847 .39945 L .51851 .39908 L F
0 0 0 r
.51865 .39994 m .51625 .40077 L .51857 .39903 L F
.5187 .39908 m .51857 .39903 L .51871 .39893 L F
0 0 .276 r
.5187 .39908 m .5187 .39908 L .5185 .39918 L F
.5185 .39918 m .51889 .39899 L .51847 .39945 L F
0 0 0 r
.51865 .39994 m .51857 .39903 L .5187 .39908 L F
0 0 .276 r
.5187 .39908 m .51889 .39899 L .5187 .39908 L F
.51886 .39877 m .51889 .39899 L .51851 .39916 L F
.51886 .39877 m .5185 .39918 L .51851 .39908 L F
.51858 .3961 m .51886 .39877 L .51828 .39928 L F
.763 .555 .616 r
.51463 .4054 m .51821 .40283 L .51457 .40219 L F
.51464 .40583 m .51493 .40559 L .51463 .4054 L F
.51493 .40559 m .51821 .40283 L .51463 .4054 L F
.376 .527 .88 r
.51374 .40485 m .51588 .40685 L .51575 .40666 L F
.51293 .40412 m .51367 .4048 L .51374 .40485 L F
.51367 .4048 m .51588 .40685 L .51374 .40485 L F
.795 .842 .38 r
.51625 .40077 m .51488 .40507 L .51457 .40219 L F
.51488 .40507 m .51464 .40583 L .51463 .4054 L F
.51488 .40507 m .51463 .4054 L .51457 .40219 L F
.376 .527 .88 r
.5145 .40557 m .51459 .40804 L .51588 .40685 L F
.51293 .40412 m .51388 .40637 L .5145 .40557 L F
.51388 .40637 m .51459 .40804 L .5145 .40557 L F
.765 .699 .79 r
.51533 .40634 m .51711 .40735 L .51882 .40576 L F
.51483 .40643 m .51617 .40697 L .51533 .40634 L F
.51617 .40697 m .51711 .40735 L .51533 .40634 L F
.376 .527 .88 r
.51293 .40412 m .51575 .40666 L .51464 .40583 L F
.51575 .40666 m .51592 .40681 L .51464 .40583 L F
.51575 .40666 m .51588 .40685 L .51592 .40681 L F
.765 .699 .79 r
.51464 .40583 m .51483 .40643 L .51553 .40631 L F
.51521 .40582 m .51553 .40631 L .51882 .40576 L F
.51464 .40583 m .51553 .40631 L .51521 .40582 L F
.978 .916 .652 r
.51697 .40946 m .51595 .40688 L .51459 .40804 L F
.51595 .40688 m .51588 .40685 L .51459 .40804 L F
.765 .699 .79 r
.51483 .40643 m .5156 .40877 L .51595 .40688 L F
.978 .916 .652 r
.51595 .40688 m .51592 .40681 L .51588 .40685 L F
.51595 .40688 m .5156 .40877 L .51592 .40681 L F
.51697 .40946 m .5156 .40877 L .51595 .40688 L F
.765 .699 .79 r
.51595 .40688 m .5156 .40877 L .51711 .40735 L F
.832 .987 .87 r
.51882 .40576 m .51697 .40946 L .52082 .4078 L F
.51882 .40576 m .5156 .40877 L .51697 .40946 L F
.839 .859 .859 r
.326 .56138 m .32988 .56038 L .32768 .55888 L F
.679 .148 0 r
.3317 .56027 m .32768 .55888 L .32988 .56038 L F
.775 .697 .777 r
.53775 .46763 m .53368 .4672 L .53613 .46337 L F
.768 .694 .78 r
.54052 .46422 m .53775 .46763 L .53613 .46337 L F
.74 .654 .764 r
.48658 .42672 m .4906 .42788 L .48925 .42351 L F
.494 .505 .797 r
.48925 .42351 m .4906 .42788 L .49354 .42712 L F
.453 .343 .639 r
.4906 .42788 m .49331 .42946 L .49354 .42712 L F
.087 0 0 r
.2757 .54661 m .27498 .54591 L .27747 .54637 L F
.2757 .54661 m .27276 .54812 L .27498 .54591 L F
.78 .655 .725 r
.30652 .67945 m .30975 .67874 L .30928 .67526 L F
.405 0 0 r
.3058 .68024 m .30975 .67874 L .30652 .67945 L F
0 0 .497 r
.30928 .67526 m .30975 .67874 L .31056 .67735 L F
.64 .966 .882 r
.31056 .67735 m .30975 .67874 L .3058 .68024 L F
.991 .744 .449 r
.57916 .42589 m .58077 .42709 L .57937 .42322 L F
.57937 .42322 m .58077 .42709 L .57916 .42589 L F
.659 .588 .765 r
.57916 .42589 m .58314 .42928 L .58077 .42709 L F
.777 .639 .709 r
.38561 .50609 m .39039 .50397 L .38831 .50274 L F
.38561 .50609 m .38908 .50822 L .39039 .50397 L F
.972 .874 .678 r
.54152 .43063 m .53851 .43217 L .54042 .43329 L F
.994 .802 .432 r
.31868 .50722 m .31829 .51056 L .32041 .50678 L F
.82 .635 .651 r
.65391 .36711 m .65612 .36889 L .65463 .36871 L F
.769 .69 .776 r
.31592 .61589 m .31786 .61684 L .31712 .6142 L F
.786 .79 .856 r
.31361 .61822 m .31786 .61684 L .31592 .61589 L F
.651 .645 .831 r
.31786 .61684 m .31901 .61251 L .31712 .6142 L F
.31786 .61684 m .32059 .61615 L .31901 .61251 L F
.777 .675 .75 r
.34332 .59575 m .34067 .59923 L .34487 .59963 L F
.779 .667 .74 r
.34067 .59923 m .34225 .60309 L .34487 .59963 L F
.804 .663 .707 r
.34828 .58936 m .35043 .59041 L .34882 .58638 L F
.813 .729 .771 r
.34594 .59237 m .35043 .59041 L .34828 .58936 L F
.34594 .59237 m .3481 .59352 L .35043 .59041 L F
.893 .545 .062 r
.24513 .59302 m .2457 .59328 L .24298 .59331 L F
.24513 .59302 m .24631 .59556 L .2457 .59328 L F
.942 .681 .512 r
.66483 .3475 m .66261 .3492 L .66287 .34621 L F
.66483 .3475 m .66478 .3505 L .66261 .3492 L F
.665 .913 .977 r
.6458 .39691 m .64671 .39804 L .64931 .39662 L F
.428 .215 .486 r
.64931 .39662 m .64907 .39931 L .64671 .39804 L F
.881 .513 .343 r
.57316 .39416 m .57362 .39694 L .5756 .39691 L F
.738 .507 .579 r
.2905 .57545 m .29463 .57622 L .29462 .57325 L F
.373 .263 .598 r
.24601 .56287 m .2482 .55854 L .24651 .56002 L F
.765 .71 .8 r
.33861 .63338 m .33603 .63669 L .33463 .63311 L F
.021 .573 .826 r
.30336 .68669 m .30517 .68727 L .30881 .68764 L F
.506 0 0 r
.30517 .68727 m .31168 .68927 L .30881 .68764 L F
0 0 .242 r
.51917 .39464 m .51907 .39562 L .51858 .3961 L F
.821 .741 .777 r
.51917 .39464 m .51879 .39589 L .51906 .39569 L F
.494 .817 .507 r
.52092 .39382 m .519 .39569 L .51858 .3961 L F
0 0 0 r
.52302 .39274 m .51906 .39569 L .52092 .39382 L F
0 0 .242 r
.519 .39569 m .51889 .39899 L .51858 .3961 L F
0 0 0 r
.51906 .39569 m .51879 .39589 L .519 .39569 L F
.51906 .39569 m .519 .39569 L .52092 .39382 L F
.821 .741 .777 r
.51917 .39464 m .51906 .39569 L .52302 .39274 L F
0 0 .242 r
.51911 .39558 m .5191 .39569 L .519 .39569 L F
.5191 .39569 m .51889 .39899 L .519 .39569 L F
.51917 .39464 m .51911 .39558 L .51907 .39562 L F
.494 .817 .507 r
.519 .39569 m .51879 .39589 L .51858 .3961 L F
.859 .783 .776 r
.56363 .44116 m .56592 .43773 L .56404 .43626 L F
0 0 .085 r
.57459 .39328 m .57316 .39416 L .57583 .39079 L F
.916 .543 .3 r
.57169 .39542 m .57362 .39694 L .57316 .39416 L F
.57169 .39542 m .57316 .39416 L .57459 .39328 L F
.94 .628 .42 r
.29399 .59822 m .29654 .59974 L .29596 .59651 L F
.915 .549 .108 r
.2635 .62582 m .2655 .62965 L .26483 .62988 L F
.951 .823 .383 r
.26483 .62988 m .2655 .62965 L .26491 .63274 L F
0 .174 .709 r
.26586 .62809 m .2655 .62965 L .2635 .62582 L F
0 0 0 r
.26491 .63274 m .2655 .62965 L .26586 .62809 L F
.622 .944 .741 r
.46392 .43923 m .46258 .44092 L .4646 .43913 L F
.62 .959 .868 r
.46028 .4412 m .46258 .44092 L .46392 .43923 L F
.881 .553 .05 r
.40056 .5246 m .40092 .52354 L .40042 .52161 L F
.40056 .5246 m .40147 .52597 L .40092 .52354 L F
.226 0 0 r
.3255 .57896 m .32808 .5784 L .32947 .57614 L F
.401 .856 .846 r
.32947 .57614 m .33062 .57525 L .33224 .57516 L F
0 0 0 r
.32947 .57614 m .32808 .5784 L .33062 .57525 L F
.653 .152 .045 r
.5312 .43662 m .53408 .4371 L .53272 .43827 L F
.769 .643 .723 r
.34023 .5794 m .33662 .57657 L .33888 .57614 L F
.34023 .5794 m .33634 .57927 L .33662 .57657 L F
.848 .944 .883 r
.54674 .46893 m .551 .46707 L .54958 .46579 L F
.868 .911 .858 r
.54958 .46579 m .551 .46707 L .55383 .46392 L F
.818 .898 .898 r
.48649 .50906 m .48482 .51321 L .48376 .51257 L F
.48649 .50906 m .48802 .51035 L .48482 .51321 L F
0 0 0 r
.35715 .49628 m .35777 .49757 L .35959 .49674 L F
.35715 .49628 m .35554 .49875 L .35777 .49757 L F
.847 .998 .794 r
.33166 .55695 m .33198 .55497 L .33469 .55604 L F
.48 .302 .562 r
.2931 .59981 m .29316 .60281 L .29561 .60208 L F
.919 .839 .75 r
.55945 .44298 m .56251 .44366 L .56177 .43977 L F
.932 .809 .7 r
.56085 .44711 m .56251 .44366 L .55945 .44298 L F
.883 .822 .783 r
.56177 .43977 m .56251 .44366 L .56363 .44116 L F
.948 .681 .498 r
.32212 .54896 m .32439 .55298 L .32437 .54997 L F
.32212 .54896 m .32439 .55298 L .32437 .54997 L F
.664 .838 .421 r
.34662 .66662 m .34879 .66303 L .34745 .66506 L F
0 0 0 r
.34745 .66506 m .34879 .66303 L .34979 .6618 L F
.396 .836 .71 r
.337 .67535 m .33845 .67442 L .33634 .67554 L F
.849 .998 .788 r
.66019 .38705 m .66281 .38261 L .66025 .38598 L F
.838 .37 .017 r
.66006 .38866 m .66214 .39006 L .66019 .38705 L F
0 0 .47 r
.56809 .3626 m .56729 .3677 L .56645 .36364 L F
.56809 .3626 m .56846 .36559 L .56729 .3677 L F
.256 .446 .856 r
.56846 .36559 m .57047 .36917 L .56729 .3677 L F
.546 .848 .998 r
.26505 .56148 m .26529 .56331 L .26583 .55936 L F
.924 .972 .695 r
.45073 .56013 m .45284 .55634 L .45053 .55766 L F
.749 .99 .886 r
.45284 .55634 m .45608 .5539 L .45344 .55432 L F
.793 .985 .723 r
.45284 .55634 m .45344 .55432 L .45053 .55766 L F
.942 .962 .699 r
.49263 .50314 m .49028 .50532 L .49111 .50195 L F
.49263 .50314 m .49066 .50681 L .49028 .50532 L F
.875 .908 .85 r
.49534 .49972 m .49263 .50314 L .49111 .50195 L F
.501 .601 .885 r
.34784 .63261 m .34537 .63302 L .34405 .62986 L F
.515 .521 .8 r
.29913 .65947 m .30069 .65554 L .30285 .65609 L F
.373 .486 .846 r
.30285 .65609 m .30274 .65229 L .30069 .65554 L F
.3054 .65673 m .30618 .65692 L .30583 .65645 L F
.714 .613 .742 r
.30274 .65229 m .30618 .65692 L .30726 .65544 L F
.806 .966 .65 r
.30726 .65544 m .30509 .65861 L .30527 .65707 L F
0 0 0 r
.30787 .65516 m .30527 .65707 L .30808 .65507 L F
.30726 .65544 m .30667 .65593 L .30787 .65516 L F
.30667 .65593 m .30527 .65707 L .30787 .65516 L F
.373 .486 .846 r
.30285 .65609 m .3054 .65673 L .30274 .65229 L F
.3054 .65673 m .30583 .65645 L .30274 .65229 L F
.618 .336 .469 r
.3019 .65889 m .30285 .65609 L .30069 .65554 L F
.3019 .65889 m .30509 .65861 L .30285 .65609 L F
.77 .307 .146 r
.40367 .54923 m .40506 .55223 L .4069 .55029 L F
.40506 .55223 m .40526 .55238 L .4069 .55029 L F
0 0 0 r
.4069 .55029 m .40526 .55238 L .4076 .55105 L F
.40526 .55238 m .40518 .55249 L .40543 .55234 L F
.40526 .55238 m .40543 .55234 L .4076 .55105 L F
.296 .477 .868 r
.4061 .55301 m .40762 .55365 L .40677 .552 L F
.77 .307 .146 r
.40506 .55223 m .40518 .55249 L .40526 .55238 L F
.908 .783 .711 r
.40101 .54808 m .40367 .54923 L .40537 .54618 L F
.686 .297 0 r
.40302 .54832 m .40367 .54923 L .40101 .54808 L F
.40302 .54832 m .40518 .55249 L .40367 .54923 L F
.742 .616 .718 r
.4076 .55105 m .40518 .55249 L .40302 .54832 L F
.296 .477 .868 r
.40613 .55217 m .40677 .552 L .40616 .55081 L F
.4061 .55301 m .40677 .552 L .40613 .55217 L F
.40608 .55383 m .40705 .55372 L .4061 .55301 L F
.40705 .55372 m .40762 .55365 L .4061 .55301 L F
0 0 0 r
.4069 .55029 m .4076 .55105 L .40856 .54892 L F
.728 .686 .809 r
.43895 .57609 m .44384 .57643 L .44253 .57308 L F
.522 .277 .485 r
.43895 .57609 m .4411 .57822 L .44384 .57643 L F
.869 .451 .223 r
.44638 .57646 m .44253 .57308 L .44384 .57643 L F
.591 .056 0 r
.44422 .57786 m .44384 .57643 L .4411 .57822 L F
.44464 .57781 m .44452 .5776 L .44422 .57786 L F
.44452 .5776 m .44384 .57643 L .44422 .57786 L F
.44472 .5777 m .44637 .5789 L .44553 .57807 L F
.4446 .57753 m .44553 .57807 L .44384 .57643 L F
.44472 .5777 m .44553 .57807 L .4446 .57753 L F
.616 .327 .456 r
.44384 .57643 m .44637 .5789 L .44638 .57646 L F
.869 .451 .223 r
.44592 .57605 m .44427 .57732 L .44253 .57308 L F
.44427 .57732 m .44391 .57702 L .44253 .57308 L F
.591 .056 0 r
.44472 .5777 m .44384 .57643 L .44464 .57781 L F
.869 .451 .223 r
.44526 .57695 m .44407 .57747 L .44592 .57605 L F
.985 .902 .619 r
.44629 .57156 m .44415 .57726 L .44526 .57695 L F
.869 .451 .223 r
.44427 .57732 m .44407 .57747 L .44391 .57702 L F
.985 .902 .619 r
.44415 .57726 m .44407 .57747 L .44432 .57736 L F
.44415 .57726 m .44432 .57736 L .44526 .57695 L F
.44629 .57156 m .44526 .57695 L .44637 .57598 L F
.795 .419 0 r
.44253 .57308 m .44397 .57719 L .44312 .57586 L F
.44253 .57308 m .44312 .57586 L .44296 .57553 L F
.041 .488 .885 r
.44306 .5699 m .44629 .57156 L .44497 .56964 L F
.44306 .5699 m .44529 .57036 L .44629 .57156 L F
.977 .86 .657 r
.44298 .57565 m .44629 .57156 L .44529 .57036 L F
.44311 .57548 m .44341 .57611 L .44629 .57156 L F
.46 .491 .804 r
.44314 .57582 m .44312 .57586 L .44298 .57565 L F
.44314 .57582 m .44315 .57594 L .44312 .57586 L F
.795 .419 0 r
.44296 .57553 m .44312 .57586 L .44298 .57565 L F
.977 .86 .657 r
.44298 .57565 m .44315 .57594 L .44311 .57548 L F
.46 .491 .804 r
.44478 .57333 m .44314 .57582 L .44298 .57565 L F
.977 .86 .657 r
.44341 .57611 m .44407 .57747 L .44425 .57699 L F
.44341 .57611 m .44425 .57699 L .44629 .57156 L F
.795 .419 0 r
.44397 .57719 m .44407 .57747 L .44298 .57565 L F
.977 .86 .657 r
.44315 .57594 m .44407 .57747 L .44311 .57548 L F
.46 .491 .804 r
.44478 .57333 m .44342 .5765 L .44315 .57594 L F
.44478 .57333 m .44315 .57594 L .44314 .57582 L F
.44478 .57333 m .44624 .57643 L .44342 .5765 L F
.44312 .57586 m .44342 .5765 L .44268 .57652 L F
.44312 .57586 m .44268 .57652 L .44298 .57565 L F
.35 .687 .98 r
.44396 .5773 m .44624 .57643 L .44478 .5778 L F
.44268 .57652 m .44348 .5765 L .44396 .5773 L F
.869 .451 .223 r
.44638 .57646 m .44526 .57695 L .44592 .57605 L F
.985 .902 .619 r
.44637 .57598 m .44526 .57695 L .44638 .57646 L F
.35 .687 .98 r
.44348 .5765 m .44624 .57643 L .44396 .5773 L F
.985 .902 .619 r
.44407 .57747 m .44407 .57747 L .44407 .57747 L F
.44407 .57747 m .44407 .57747 L .44432 .57736 L F
.591 .056 0 r
.44478 .5778 m .44505 .57798 L .44478 .57776 L F
.44505 .57798 m .44637 .5789 L .44472 .5777 L F
.874 .515 .365 r
.44364 .58002 m .44637 .5789 L .44478 .5778 L F
0 0 0 r
.44624 .57643 m .44479 .57825 L .44478 .5778 L F
.717 .834 .389 r
.44478 .5778 m .44365 .57967 L .44364 .58002 L F
0 0 0 r
.44479 .57825 m .44365 .57967 L .44478 .5778 L F
.591 .056 0 r
.44478 .5778 m .44478 .57776 L .44472 .5777 L F
.44478 .5778 m .44472 .5777 L .44464 .57781 L F
.875 .79 .763 r
.55088 .43656 m .55183 .4403 L .54877 .4403 L F
.843 .901 .878 r
.55183 .4403 m .5475 .44187 L .54877 .4403 L F
.2 0 .051 r
.46268 .53709 m .46172 .53853 L .46535 .5362 L F
.831 .999 .798 r
.2732 .64211 m .27515 .64108 L .27296 .64356 L F
.975 .91 .677 r
.27296 .64356 m .27077 .64563 L .2732 .64211 L F
.916 .516 .176 r
.28468 .52531 m .28567 .52407 L .28532 .52245 L F
.867 .739 .719 r
.46734 .52982 m .46924 .53409 L .46747 .53251 L F
.986 .713 .361 r
.57298 .38277 m .57438 .38686 L .57431 .38416 L F
.884 .943 .847 r
.29913 .65947 m .29511 .66215 L .29892 .66206 L F
.515 .521 .8 r
.29913 .65947 m .3019 .65889 L .30069 .65554 L F
.519 .325 .558 r
.29892 .66206 m .3019 .65889 L .29913 .65947 L F
.794 .725 .788 r
.34332 .59575 m .3481 .59352 L .34594 .59237 L F
.786 .762 .832 r
.47714 .52369 m .47319 .52332 L .4757 .52016 L F
.783 .761 .833 r
.48007 .52054 m .47714 .52369 L .4757 .52016 L F
.835 .993 .853 r
.5899 .40491 m .589 .40665 L .59174 .40394 L F
.58833 .40574 m .59174 .40394 L .59035 .40226 L F
.452 0 0 r
.59099 .40344 m .59507 .40574 L .59217 .4056 L F
.59035 .40226 m .59133 .40299 L .59099 .40344 L F
.59133 .40299 m .59507 .40574 L .59099 .40344 L F
.835 .993 .853 r
.58833 .40574 m .5888 .40638 L .5899 .40491 L F
.5888 .40638 m .589 .40665 L .5899 .40491 L F
.805 .493 .462 r
.35753 .51348 m .35375 .51492 L .35335 .51282 L F
.35753 .51348 m .35772 .5159 L .35375 .51492 L F
.639 .946 .727 r
.31854 .68564 m .32181 .68297 L .31938 .68433 L F
0 0 0 r
.31938 .68433 m .32181 .68297 L .32385 .68211 L F
.211 0 0 r
.28278 .53663 m .2785 .53905 L .27863 .53627 L F
.28278 .53663 m .28097 .53852 L .2785 .53905 L F
.13 0 0 r
.28377 .53543 m .28236 .53592 L .28278 .53663 L F
.671 .595 .762 r
.2834 .53594 m .28278 .53663 L .28236 .53592 L F
.2834 .53594 m .28097 .53852 L .28278 .53663 L F
.752 .99 .886 r
.65775 .40092 m .65964 .39914 L .65889 .39855 L F
.665 .906 .979 r
.65682 .39977 m .65775 .40092 L .65889 .39855 L F
0 0 0 r
.57459 .39328 m .57583 .39079 L .57771 .38925 L F
.973 .819 .628 r
.30858 .66473 m .31134 .66309 L .3103 .66571 L F
.879 .816 .782 r
.34542 .50322 m .34497 .49975 L .34601 .49935 L F
.34542 .50322 m .34313 .50277 L .34497 .49975 L F
.901 .506 .256 r
.34542 .50322 m .34363 .5044 L .34313 .50277 L F
.34542 .50322 m .34669 .50635 L .34363 .5044 L F
.859 .888 .857 r
.30996 .61045 m .30572 .61272 L .30811 .60901 L F
.996 .784 .502 r
.61808 .39413 m .61767 .39738 L .61626 .39566 L F
.532 .855 .565 r
.6197 .39253 m .61808 .39413 L .61626 .39566 L F
.822 .689 .718 r
.36629 .4989 m .36811 .50275 L .36794 .50063 L F
.736 .885 .949 r
.51071 .48721 m .50704 .48754 L .50906 .48585 L F
.51071 .48721 m .50753 .48831 L .50704 .48754 L F
.557 .764 .975 r
.39629 .49197 m .39783 .49362 L .39398 .49292 L F
.308 .062 .369 r
.39629 .49197 m .39398 .49292 L .39783 .49362 L F
.882 .717 .202 r
.40042 .52161 m .40363 .52016 L .40216 .51869 L F
.91 .628 .497 r
.3391 .52278 m .33924 .52575 L .34225 .52667 L F
.906 .658 .551 r
.33881 .52831 m .34225 .52667 L .33924 .52575 L F
.33881 .52831 m .34228 .52969 L .34225 .52667 L F
.8 .422 .34 r
.36156 .5168 m .35948 .51854 L .35772 .5159 L F
.86 .519 .405 r
.36156 .5168 m .36203 .51944 L .35948 .51854 L F
.237 .349 .776 r
.24686 .57991 m .24917 .58163 L .25078 .58013 L F
.545 .83 .998 r
.25155 .57824 m .24795 .57973 L .25078 .58013 L F
.12 .336 .803 r
.25155 .57824 m .25078 .58013 L .24917 .58163 L F
.25155 .57824 m .25373 .58235 L .25078 .58013 L F
.826 .706 .732 r
.45018 .5821 m .45477 .5799 L .45073 .5794 L F
.45018 .5821 m .45241 .58357 L .45477 .5799 L F
.768 .621 .697 r
.45477 .5799 m .45241 .58357 L .45486 .58254 L F
.257 0 0 r
.67079 .3065 m .67106 .30731 L .67432 .30607 L F
.893 .741 .686 r
.3763 .54269 m .37771 .54669 L .37475 .54615 L F
.827 .56 .535 r
.37771 .54669 m .37384 .54859 L .37475 .54615 L F
.37771 .54669 m .37772 .54949 L .37384 .54859 L F
.003 .102 .616 r
.56355 .38581 m .56546 .38625 L .56341 .38368 L F
.666 .153 .012 r
.56966 .3879 m .56546 .38625 L .56641 .38883 L F
.479 .061 .169 r
.56641 .38883 m .5687 .39112 L .56966 .3879 L F
.666 .153 .012 r
.56966 .3879 m .56998 .38881 L .56972 .38866 L F
.104 0 .052 r
.56966 .3879 m .56937 .38888 L .56972 .38866 L F
.666 .153 .012 r
.56966 .3879 m .56972 .38866 L .56766 .38749 L F
.263 .064 .412 r
.56755 .38747 m .5687 .39112 L .56641 .38883 L F
.666 .153 .012 r
.56933 .38777 m .56766 .38749 L .5675 .3874 L F
.56933 .38777 m .5675 .3874 L .56714 .38691 L F
.56966 .3879 m .56766 .38749 L .56933 .38777 L F
.56714 .38691 m .5675 .3874 L .56546 .38625 L F
.55 .461 .706 r
.56546 .38625 m .56972 .38866 L .56876 .38604 L F
.263 .064 .412 r
.56876 .38604 m .56873 .38909 L .56755 .38747 L F
.56873 .38909 m .5687 .39112 L .56755 .38747 L F
.413 .364 .694 r
.56422 .38971 m .56546 .38625 L .5636 .38613 L F
.56422 .38971 m .56641 .38883 L .56546 .38625 L F
.263 .064 .412 r
.56876 .38604 m .56755 .38747 L .56515 .38647 L F
.56755 .38747 m .56641 .38883 L .56551 .38714 L F
.56755 .38747 m .56551 .38714 L .56515 .38647 L F
.55 .461 .706 r
.56972 .38866 m .56998 .38881 L .56988 .38857 L F
.56972 .38866 m .56988 .38857 L .56876 .38604 L F
.104 0 .052 r
.56972 .38866 m .5687 .39112 L .56982 .38987 L F
.56937 .38888 m .5687 .39112 L .56972 .38866 L F
.157 0 .205 r
.57218 .38723 m .56998 .38881 L .56966 .3879 L F
.104 0 .052 r
.56966 .3879 m .56972 .38865 L .57218 .38723 L F
.524 .447 .711 r
.56876 .38604 m .56988 .38857 L .57218 .38723 L F
.56988 .38857 m .56998 .38881 L .57218 .38723 L F
.104 0 .052 r
.56972 .38865 m .56982 .38987 L .57218 .38723 L F
.55 .461 .706 r
.56546 .38625 m .56876 .38604 L .56649 .38631 L F
.56546 .38625 m .56649 .38631 L .56515 .38647 L F
.413 .364 .694 r
.5636 .38613 m .56546 .38625 L .56355 .38581 L F
.689 .155 0 r
.39825 .58658 m .39829 .58749 L .3963 .58536 L F
0 .28 .78 r
.28851 .52807 m .28838 .53002 L .28651 .52667 L F
.947 .874 .733 r
.28851 .52807 m .28855 .53311 L .28838 .53002 L F
.078 0 .149 r
.25843 .5707 m .25564 .57325 L .25822 .56988 L F
0 0 .067 r
.26083 .56607 m .26007 .56837 L .25822 .56988 L F
0 0 .324 r
.26007 .56837 m .25843 .5707 L .25822 .56988 L F
.74 .987 .782 r
.49775 .40261 m .49595 .40455 L .49707 .40238 L F
.635 .902 .984 r
.49707 .40238 m .49595 .40455 L .49484 .40365 L F
.886 .88 .823 r
.49155 .51805 m .49007 .51988 L .49275 .51926 L F
.854 .882 .858 r
.49155 .51805 m .49275 .51926 L .4955 .51629 L F
.757 .777 .87 r
.30691 .61916 m .31115 .61945 L .30935 .61774 L F
.707 .73 .869 r
.31115 .61945 m .31204 .61513 L .30935 .61774 L F
.31115 .61945 m .31361 .61822 L .31204 .61513 L F
.841 .621 .605 r
.34228 .52969 m .34421 .5331 L .34452 .53027 L F
.506 .317 .558 r
.51148 .47707 m .51435 .47635 L .51445 .47356 L F
.49 .303 .554 r
.51175 .47978 m .51435 .47635 L .51148 .47707 L F
.506 .317 .558 r
.51445 .47356 m .51435 .47635 L .51148 .47707 L F
.49 .303 .554 r
.51175 .47978 m .51435 .47635 L .51148 .47707 L F
.506 .317 .558 r
.51148 .47707 m .51435 .47635 L .51445 .47356 L F
.483 .83 .997 r
.2839 .66451 m .28665 .66599 L .28325 .66602 L F
.856 .919 .872 r
.28736 .66385 m .28665 .66599 L .2839 .66451 L F
.686 .716 .871 r
.29007 .66506 m .28665 .66599 L .28736 .66385 L F
.548 .405 .639 r
.25287 .54039 m .25543 .54005 L .25495 .53634 L F
0 .172 .649 r
.54212 .41596 m .54364 .41738 L .5448 .41789 L F
.871 .955 .859 r
.32494 .52346 m .32184 .52686 L .3208 .52412 L F
.785 .693 .763 r
.44486 .58899 m .44896 .58908 L .44952 .58661 L F
.44486 .58899 m .44659 .59024 L .44896 .58908 L F
0 0 0 r
.62859 .35019 m .62508 .3527 L .62631 .35147 L F
.219 0 0 r
.6459 .33657 m .64864 .3362 L .64989 .33461 L F
.217 0 0 r
.64864 .3362 m .65278 .33401 L .64989 .33461 L F
.761 .351 .274 r
.40147 .52597 m .40235 .52828 L .4051 .52673 L F
.828 .461 .36 r
.4051 .52673 m .40235 .52828 L .40514 .52872 L F
.785 .693 .763 r
.44486 .58899 m .44952 .58661 L .44756 .58548 L F
.816 .828 .859 r
.44756 .58548 m .44952 .58661 L .45241 .58357 L F
.82 .574 .568 r
.31923 .51582 m .31706 .51256 L .3193 .51345 L F
.572 .276 .427 r
.3193 .51345 m .32163 .51564 L .31923 .51582 L F
.013 .264 .766 r
.57351 .36294 m .57144 .3594 L .57257 .36096 L F
.564 .039 0 r
.37197 .50643 m .37433 .50823 L .37616 .50688 L F
.432 0 0 r
.37616 .50688 m .37433 .50823 L .37879 .50806 L F
.907 .502 .206 r
.33143 .50659 m .33299 .51012 L .33464 .5108 L F
.959 .657 .413 r
.33286 .51089 m .33464 .5108 L .33299 .51012 L F
.33286 .51089 m .33469 .51237 L .33464 .5108 L F
.189 .717 .729 r
.28861 .642 m .28841 .64214 L .28396 .64205 L F
.28861 .642 m .29111 .64153 L .28841 .64214 L F
.832 .689 .706 r
.34067 .59923 m .3381 .60282 L .34225 .60309 L F
.823 .809 .838 r
.33756 .60462 m .34225 .60309 L .3381 .60282 L F
.544 .349 .568 r
.51082 .41052 m .51134 .41355 L .50818 .41403 L F
.69 .715 .868 r
.51103 .40942 m .51293 .40412 L .50917 .40747 L F
.51103 .40942 m .51459 .40804 L .51293 .40412 L F
.536 .604 .869 r
.51219 .40665 m .51082 .41052 L .50917 .40747 L F
.51219 .40665 m .51426 .41034 L .51082 .41052 L F
.329 .206 .556 r
.51315 .41218 m .51082 .41052 L .51426 .41034 L F
.51315 .41218 m .51134 .41355 L .51082 .41052 L F
.619 .492 .686 r
.38561 .50609 m .38964 .50916 L .38908 .50822 L F
.49 .304 .555 r
.61071 .35214 m .60809 .34964 L .61215 .35055 L F
0 .172 .677 r
.61215 .35055 m .61502 .35279 L .61347 .35096 L F
.61215 .35055 m .61347 .35096 L .61071 .35214 L F
.061 0 0 r
.43656 .45304 m .43262 .4557 L .43478 .45461 L F
.671 .973 .817 r
.46821 .42535 m .46613 .42713 L .46737 .42528 L F
.646 .96 .926 r
.46737 .42528 m .46613 .42713 L .46535 .42667 L F
.709 .507 .613 r
.39822 .51562 m .40216 .51869 L .40068 .51677 L F
.947 .919 .752 r
.68784 .3584 m .69107 .35635 L .68909 .35636 L F
.68784 .3584 m .68916 .35962 L .69107 .35635 L F
.91 .978 .706 r
.50774 .43203 m .50652 .43447 L .50868 .43082 L F
0 0 0 r
.50774 .43203 m .50868 .43082 L .51062 .42926 L F
.917 .765 .677 r
.38273 .4899 m .3832 .4944 L .38146 .49289 L F
.773 .285 0 r
.3832 .4944 m .383 .49495 L .38146 .49289 L F
.252 .271 .686 r
.38517 .49194 m .3832 .4944 L .38273 .4899 L F
.832 .425 0 r
.383 .49495 m .38422 .49657 L .3832 .4944 L F
0 0 0 r
.38517 .49194 m .383 .49495 L .3832 .4944 L F
.677 .662 .827 r
.30203 .64284 m .30359 .64644 L .29905 .64555 L F
.768 .705 .792 r
.30628 .64317 m .30359 .64644 L .30203 .64284 L F
.748 .724 .83 r
.53864 .46056 m .54052 .46422 L .53613 .46337 L F
.733 .21 0 r
.58384 .38066 m .58316 .38127 L .57946 .37768 L F
0 .044 .555 r
.57946 .37768 m .58065 .37859 L .58121 .37523 L F
.57946 .37768 m .58316 .38127 L .58065 .37859 L F
.485 .501 .799 r
.53597 .35078 m .53838 .35013 L .53708 .346 L F
0 0 0 r
.65137 .34365 m .64716 .34485 L .64858 .34413 L F
.567 .867 .996 r
.53845 .34706 m .53977 .34501 L .54159 .34569 L F
.53845 .34706 m .53708 .346 L .53977 .34501 L F
.868 .911 .858 r
.54958 .46579 m .55383 .46392 L .55299 .46289 L F
.954 .952 .7 r
.55488 .45908 m .55383 .46392 L .55683 .46056 L F
.55488 .45908 m .55299 .46289 L .55383 .46392 L F
.836 .692 .703 r
.41343 .54995 m .41318 .55353 L .41408 .55314 L F
.638 .274 .337 r
.41318 .55353 m .41336 .55547 L .41408 .55314 L F
.329 .153 .485 r
.41408 .55314 m .41642 .54969 L .41343 .54995 L F
.41408 .55314 m .41622 .55278 L .41642 .54969 L F
.247 0 .195 r
.41408 .55314 m .41336 .55547 L .41622 .55278 L F
.665 .145 0 r
.39533 .51494 m .39606 .51361 L .39463 .51233 L F
.39533 .51494 m .39822 .51562 L .39606 .51361 L F
.472 .83 .995 r
.62903 .39695 m .63172 .39632 L .63044 .39543 L F
.52 .895 .965 r
.63044 .39543 m .62777 .3964 L .62903 .39695 L F
.422 .761 .996 r
.421 .60005 m .42194 .59852 L .41933 .59885 L F
.421 .60005 m .42374 .59972 L .42194 .59852 L F
.512 .891 .965 r
.62728 .39026 m .62357 .39061 L .62626 .38945 L F
.969 .693 .273 r
.62608 .38655 m .62728 .39026 L .62626 .38945 L F
.751 .695 .799 r
.62608 .38655 m .6302 .3873 L .62728 .39026 L F
.528 .191 .341 r
.3108 .60334 m .31424 .60312 L .31334 .6052 L F
.3108 .60334 m .31424 .60312 L .31334 .6052 L F
.859 .783 .776 r
.56363 .44116 m .56404 .43626 L .56177 .43977 L F
.813 .938 .575 r
.57392 .35085 m .57186 .35441 L .57254 .35204 L F
.3 0 0 r
.61329 .34453 m .61603 .34518 L .61734 .34456 L F
.319 0 0 r
.61734 .34456 m .61603 .34518 L .62013 .34527 L F
.399 0 0 r
.61734 .34456 m .62013 .34527 L .62109 .34419 L F
.914 .98 .741 r
.45073 .56013 m .45053 .55766 L .44851 .56129 L F
.832 .998 .836 r
.59502 .43361 m .59451 .43267 L .59142 .43587 L F
.835 .561 .015 r
.59403 .42977 m .59451 .43267 L .59502 .43361 L F
.925 .96 .782 r
.505 .43643 m .50652 .43447 L .50774 .43203 L F
.774 .656 .733 r
.33004 .61276 m .33424 .61331 L .33267 .60932 L F
.743 .641 .748 r
.33424 .61331 m .33692 .60983 L .33267 .60932 L F
.476 .864 .665 r
.27458 .64124 m .27752 .63949 L .27515 .64108 L F
.488 .798 .999 r
.27814 .63771 m .28022 .63892 L .27752 .63949 L F
.751 .987 .768 r
.27814 .63771 m .27752 .63949 L .27458 .64124 L F
.972 .735 .521 r
.38396 .58436 m .38533 .58529 L .38397 .58432 L F
0 .274 .685 r
.38669 .58621 m .38533 .58529 L .38274 .58394 L F
.539 0 0 r
.38533 .58529 m .38098 .58494 L .38274 .58394 L F
.972 .735 .521 r
.38533 .58529 m .38356 .58566 L .38098 .58494 L F
.38356 .58566 m .38533 .58529 L .38396 .58436 L F
0 .274 .685 r
.38706 .58643 m .38533 .58529 L .38669 .58621 L F
.983 .738 .487 r
.38706 .58643 m .38505 .58807 L .38533 .58529 L F
.38706 .58643 m .38679 .58935 L .38505 .58807 L F
.536 .572 .838 r
.38706 .58643 m .38782 .58196 L .38533 .58529 L F
.38706 .58643 m .38883 .58715 L .38782 .58196 L F
.666 .193 .12 r
.38505 .58807 m .38706 .58643 L .38533 .58529 L F
.449 .24 .502 r
.38927 .58857 m .38679 .58935 L .38706 .58643 L F
.666 .193 .12 r
.38505 .58807 m .38927 .58857 L .38706 .58643 L F
.899 .699 .624 r
.34383 .55516 m .34663 .5535 L .34421 .55252 L F
.34383 .55516 m .34593 .55662 L .34663 .5535 L F
.74 .745 .855 r
.54443 .4458 m .54697 .44713 L .54262 .4467 L F
.584 .375 .563 r
.54697 .44713 m .54411 .45032 L .54262 .4467 L F
.54697 .44713 m .54674 .4499 L .54411 .45032 L F
.765 .975 .919 r
.46938 .43502 m .47431 .43356 L .47355 .43333 L F
.689 .98 .886 r
.47431 .43356 m .47769 .43128 L .4754 .43158 L F
.703 .984 .832 r
.47355 .43333 m .47431 .43356 L .4754 .43158 L F
.485 .225 .444 r
.38809 .46702 m .3907 .46678 L .39082 .46404 L F
.324 .099 .41 r
.39082 .46404 m .39309 .46547 L .39421 .46295 L F
.39082 .46404 m .3907 .46678 L .39309 .46547 L F
.457 .642 .937 r
.30214 .60078 m .30438 .60316 L .30348 .60111 L F
.107 .452 .884 r
.3027 .60097 m .30301 .60137 L .30214 .60078 L F
.30303 .6014 m .30438 .60316 L .30279 .60147 L F
.30363 .60189 m .30438 .60316 L .30324 .60168 L F
.30325 .60151 m .30324 .60168 L .3027 .60097 L F
.30363 .60189 m .30324 .60168 L .30325 .60151 L F
1 .814 .496 r
.30311 .60137 m .30061 .60511 L .30042 .60328 L F
0 0 0 r
.30086 .60373 m .30326 .60133 L .30042 .60328 L F
.835 .965 .639 r
.30172 .60236 m .3023 .60195 L .30086 .60373 L F
.337 0 0 r
.30327 .60116 m .30348 .60111 L .30465 .60162 L F
.30214 .60078 m .30348 .60111 L .30327 .60116 L F
.835 .965 .639 r
.30308 .6002 m .3033 .60071 L .30286 .60126 L F
.107 .452 .884 r
.30301 .60137 m .30303 .6014 L .30243 .60108 L F
.30303 .6014 m .30279 .60147 L .30243 .60108 L F
.835 .965 .639 r
.30258 .60133 m .30286 .60126 L .3023 .60195 L F
.30308 .6002 m .30286 .60126 L .30258 .60133 L F
.30308 .6002 m .3023 .60195 L .30172 .60236 L F
1 .814 .496 r
.30348 .60111 m .30322 .60148 L .30311 .60137 L F
0 0 0 r
.30326 .60133 m .30348 .60111 L .30311 .60137 L F
.835 .965 .639 r
.3033 .60071 m .30348 .60111 L .30326 .60133 L F
0 0 0 r
.30326 .60133 m .30311 .60137 L .30042 .60328 L F
.107 .452 .884 r
.30301 .60137 m .30243 .60108 L .30214 .60078 L F
.30319 .60113 m .30363 .60189 L .3027 .60097 L F
.835 .965 .639 r
.3033 .60071 m .30326 .60133 L .30086 .60373 L F
1 .814 .496 r
.30322 .60148 m .30336 .60627 L .30061 .60511 L F
.30348 .60111 m .30347 .6016 L .30322 .60148 L F
.30347 .6016 m .30336 .60627 L .30322 .60148 L F
.30322 .60148 m .30061 .60511 L .30311 .60137 L F
.30348 .60111 m .30438 .60316 L .30347 .6016 L F
.107 .452 .884 r
.30465 .60162 m .30438 .60316 L .30319 .60113 L F
1 .814 .496 r
.30347 .6016 m .30438 .60316 L .30336 .60627 L F
.743 .768 .265 r
.30336 .60627 m .30438 .60316 L .30465 .60162 L F
.771 .753 .837 r
.35245 .65235 m .34913 .65584 L .34818 .65195 L F
.428 .768 .996 r
.35278 .65541 m .34913 .65584 L .35245 .65235 L F
.184 .606 .943 r
.63944 .38203 m .6355 .38046 L .63811 .38205 L F
.399 .846 .922 r
.64112 .38043 m .63944 .38203 L .63811 .38205 L F
.64112 .38043 m .6428 .38119 L .63944 .38203 L F
.549 .465 .712 r
.50933 .42057 m .50693 .42389 L .50678 .4211 L F
.50933 .42057 m .50961 .42317 L .50693 .42389 L F
.879 .614 .535 r
.3763 .54269 m .37333 .53889 L .3765 .54001 L F
.686 .369 .433 r
.66889 .32779 m .66888 .33 L .67321 .33 L F
.998 .779 .473 r
.59155 .42945 m .58997 .43183 L .58994 .42917 L F
.59155 .42945 m .59062 .43313 L .58997 .43183 L F
.611 .95 .922 r
.31342 .68731 m .31854 .68564 L .31712 .68502 L F
.639 .946 .727 r
.31854 .68564 m .31938 .68433 L .31712 .68502 L F
.763 .924 .559 r
.30652 .67945 m .30928 .67526 L .30739 .67746 L F
0 0 .497 r
.30928 .67526 m .31056 .67735 L .31196 .67527 L F
.324 0 .031 r
.30739 .67746 m .30928 .67526 L .31196 .67527 L F
.476 .864 .665 r
.27458 .64124 m .27515 .64108 L .2732 .64211 L F
.699 .916 .576 r
.57392 .35085 m .57385 .35 L .57663 .35013 L F
.57392 .35085 m .57254 .35204 L .57385 .35 L F
.528 0 0 r
.60643 .34387 m .60923 .34532 L .61056 .34403 L F
.397 0 0 r
.60923 .34532 m .61329 .34453 L .61056 .34403 L F
.548 .721 .953 r
.59305 .36623 m .59155 .36869 L .59045 .3665 L F
.59305 .36623 m .59464 .36812 L .59155 .36869 L F
0 .019 .591 r
.58233 .39085 m .58383 .39115 L .58466 .38861 L F
.58233 .39085 m .58349 .3927 L .58383 .39115 L F
.485 .894 .779 r
.50447 .41571 m .50818 .41403 L .50679 .41548 L F
.271 0 0 r
.50818 .41403 m .50795 .41523 L .50679 .41548 L F
.204 0 0 r
.50818 .41403 m .51134 .41355 L .50795 .41523 L F
.853 .738 .736 r
.55335 .43045 m .55276 .43324 L .55127 .43324 L F
.875 .69 .648 r
.55276 .43324 m .55088 .43656 L .55127 .43324 L F
.853 .653 .632 r
.33918 .57318 m .33563 .57297 L .33702 .56921 L F
.83 .717 .74 r
.33918 .57318 m .33446 .57513 L .33563 .57297 L F
.33918 .57318 m .33662 .57657 L .33446 .57513 L F
.775 .63 .7 r
.33888 .57614 m .33662 .57657 L .33918 .57318 L F
.596 .195 .253 r
.26608 .5274 m .26908 .52884 L .2703 .52628 L F
.494 .156 .322 r
.2703 .52628 m .27183 .5282 L .27296 .52621 L F
.2703 .52628 m .26908 .52884 L .27183 .5282 L F
.894 .977 .816 r
.62078 .3549 m .62322 .35441 L .62227 .35317 L F
.62078 .3549 m .62048 .35768 L .62322 .35441 L F
.895 .981 .807 r
.62371 .35144 m .62322 .35441 L .62508 .3527 L F
.502 .434 .712 r
.43068 .59315 m .43285 .59582 L .43194 .5918 L F
0 0 .545 r
.43163 .59408 m .43068 .59315 L .43127 .59171 L F
.43163 .59408 m .43285 .59582 L .43068 .59315 L F
.751 .991 .884 r
.51904 .49399 m .52138 .49211 L .52004 .4918 L F
.735 .979 .917 r
.51904 .49399 m .52004 .4918 L .51655 .49366 L F
.937 .865 .743 r
.55431 .42036 m .55089 .42264 L .55268 .41871 L F
.55431 .42036 m .55255 .42382 L .55089 .42264 L F
.148 0 0 r
.33012 .67923 m .33433 .67667 L .33226 .67841 L F
0 0 0 r
.33226 .67841 m .33433 .67667 L .33634 .67554 L F
.654 .619 .802 r
.30203 .64284 m .29905 .64555 L .29767 .64184 L F
.171 .692 .879 r
.4069 .57222 m .40245 .57183 L .40518 .57241 L F
.854 .882 .858 r
.49155 .51805 m .4955 .51629 L .49426 .51501 L F
.851 .875 .857 r
.49426 .51501 m .4955 .51629 L .49852 .51306 L F
.352 .825 .782 r
.31827 .54673 m .3214 .54533 L .32228 .54621 L F
.31827 .54673 m .31818 .5466 L .3214 .54533 L F
.318 0 0 r
.32228 .54621 m .31818 .5466 L .31827 .54673 L F
.188 .154 .586 r
.40472 .56256 m .40352 .56585 L .4023 .5635 L F
.871 .955 .859 r
.32494 .52346 m .3208 .52412 L .3228 .52217 L F
.677 .255 .235 r
.35959 .49674 m .36255 .49833 L .36399 .4968 L F
.652 .223 .215 r
.36255 .49833 m .36629 .4989 L .36399 .4968 L F
.223 0 0 r
.62013 .34527 m .62405 .34344 L .62109 .34419 L F
.673 .679 .847 r
.32059 .61615 m .32521 .6171 L .32312 .61547 L F
.566 .653 .894 r
.50847 .4192 m .50678 .4211 L .50602 .41917 L F
.50847 .4192 m .50933 .42057 L .50678 .4211 L F
.483 .83 .997 r
.2839 .66451 m .28325 .66602 L .28153 .66471 L F
.244 .464 .873 r
.35272 .63167 m .35153 .6333 L .35085 .63127 L F
.082 .229 .718 r
.35336 .6347 m .35153 .6333 L .35272 .63167 L F
.071 .229 .721 r
.35336 .6347 m .3531 .63595 L .35153 .6333 L F
.864 .836 .367 r
.61429 .35711 m .61502 .35279 L .61592 .35398 L F
0 .511 .844 r
.29145 .67239 m .29576 .67389 L .29404 .67242 L F
0 .309 .762 r
.29404 .67242 m .29576 .67389 L .29753 .6748 L F
.879 .531 .387 r
.34517 .56445 m .34697 .56341 L .34354 .56197 L F
.857 .491 .356 r
.34517 .56445 m .34748 .56599 L .34697 .56341 L F
.857 .847 .832 r
.55488 .45908 m .55683 .46056 L .55928 .45707 L F
.79 .396 .308 r
.40514 .52872 m .40742 .53169 L .40939 .52973 L F
.736 .32 .26 r
.40742 .53169 m .41152 .53226 L .40939 .52973 L F
.838 .527 .463 r
.37126 .53002 m .3678 .52937 L .3675 .52654 L F
.874 .713 .679 r
.37126 .53002 m .36717 .53205 L .3678 .52937 L F
.37126 .53002 m .37046 .53306 L .36717 .53205 L F
.944 .907 .755 r
.56798 .42538 m .5705 .42451 L .56983 .42044 L F
.56798 .42538 m .56933 .42665 L .5705 .42451 L F
.729 .99 .856 r
.49933 .45271 m .50262 .45051 L .50202 .45309 L F
.762 .66 .749 r
.50524 .44918 m .50202 .45309 L .50262 .45051 L F
.9 .833 .77 r
.5256 .46997 m .52516 .46567 L .52656 .46675 L F
.854 .932 .877 r
.52656 .46675 m .52792 .46295 L .52919 .46581 L F
.52656 .46675 m .52516 .46567 L .52792 .46295 L F
.736 .664 .779 r
.33267 .60932 m .33692 .60983 L .33532 .60616 L F
.91 .871 .436 r
.58384 .38066 m .58286 .38176 L .58316 .38127 L F
.58384 .38066 m .58277 .38359 L .58286 .38176 L F
.899 .892 .814 r
.49066 .50681 m .48649 .50906 L .49028 .50532 L F
.49066 .50681 m .48802 .51035 L .48649 .50906 L F
.875 .908 .85 r
.49534 .49972 m .49111 .50195 L .49439 .49891 L F
.856 .985 .851 r
.49534 .49972 m .49726 .49583 L .49836 .49661 L F
.49534 .49972 m .49439 .49891 L .49726 .49583 L F
.129 0 .184 r
.24912 .55578 m .24998 .55766 L .25167 .55562 L F
.24912 .55578 m .2482 .55854 L .24998 .55766 L F
.964 .675 .437 r
.33063 .5331 m .33086 .53641 L .32878 .53506 L F
.741 .965 .688 r
.51224 .39177 m .51184 .39186 L .51363 .39084 L F
.922 .951 .615 r
.51576 .38677 m .51427 .38775 L .51533 .38609 L F
.487 .854 .616 r
.51554 .38677 m .51427 .38775 L .51576 .38677 L F
.883 .973 .665 r
.51363 .39084 m .51427 .38775 L .51554 .38677 L F
.51363 .39084 m .51184 .39186 L .51427 .38775 L F
.989 .82 .582 r
.32458 .59753 m .32561 .60151 L .32329 .59885 L F
0 0 0 r
.42834 .44934 m .43064 .44814 L .43222 .44662 L F
.43448 .44551 m .43526 .44471 L .43222 .44662 L F
.43064 .44814 m .43448 .44551 L .43222 .44662 L F
.815 .996 .859 r
.50746 .39672 m .50946 .39335 L .511 .39431 L F
.717 .945 .955 r
.511 .39431 m .51184 .39186 L .51224 .39177 L F
.511 .39431 m .50946 .39335 L .51184 .39186 L F
.449 .247 .513 r
.25495 .53634 m .2572 .53577 L .25741 .5332 L F
.541 .42 .664 r
.25543 .54005 m .2572 .53577 L .25495 .53634 L F
.894 .667 .587 r
.32435 .51695 m .32128 .51858 L .32163 .51564 L F
.32435 .51695 m .32355 .51949 L .32128 .51858 L F
.826 .982 .882 r
.45608 .5539 m .45665 .55128 L .45344 .55432 L F
.45608 .5539 m .4581 .5517 L .45665 .55128 L F
.384 .279 .611 r
.245 .57042 m .24697 .57071 L .24692 .56594 L F
.369 .336 .691 r
.245 .57042 m .2474 .57227 L .24697 .57071 L F
0 0 0 r
.26429 .56322 m .26249 .56525 L .26083 .56607 L F
.26475 .56407 m .26249 .56525 L .26429 .56322 L F
.82 .535 .507 r
.67321 .33 m .6772 .33345 L .67722 .33087 L F
.918 .525 .223 r
.39249 .53379 m .39186 .53532 L .39261 .53503 L F
.6 .599 .822 r
.39389 .53183 m .39261 .53503 L .39249 .53379 L F
.498 .311 .557 r
.51435 .47635 m .51704 .47566 L .51445 .47356 L F
.51435 .47635 m .51704 .47566 L .51445 .47356 L F
.458 .642 .937 r
.50029 .42548 m .50116 .42269 L .49827 .42439 L F
.50029 .42548 m .50336 .42546 L .50116 .42269 L F
.552 .576 .832 r
.50029 .42548 m .50353 .42679 L .50336 .42546 L F
.469 .893 .875 r
.31616 .58593 m .31645 .58538 L .31833 .58438 L F
.898 .74 .678 r
.38084 .57924 m .37939 .57545 L .38136 .57645 L F
.985 .902 .619 r
.44629 .57156 m .44638 .57646 L .44728 .57361 L F
.916 .591 .413 r
.3675 .52654 m .36542 .52834 L .36492 .52608 L F
.3675 .52654 m .3678 .52937 L .36542 .52834 L F
.924 .891 .779 r
.55189 .42912 m .55335 .43045 L .55127 .43324 L F
.951 .746 .59 r
.55185 .42646 m .55335 .43045 L .55189 .42912 L F
.755 .245 0 r
.33221 .54939 m .33035 .54842 L .32896 .54648 L F
.991 .807 .559 r
.33221 .54939 m .32979 .55094 L .33035 .54842 L F
.33221 .54939 m .33115 .55242 L .32979 .55094 L F
.837 .579 .549 r
.33516 .55321 m .33115 .55242 L .33221 .54939 L F
.929 .577 .34 r
.38274 .58394 m .38098 .58494 L .37933 .58046 L F
.702 .939 .962 r
.46172 .53853 m .45968 .54001 L .45859 .53908 L F
.831 .895 .887 r
.46046 .55127 m .46509 .54966 L .46388 .54908 L F
.67 .974 .825 r
.46775 .54634 m .46564 .54704 L .46509 .54966 L F
.873 .992 .807 r
.46564 .54704 m .46388 .54908 L .46509 .54966 L F
.53 .865 .595 r
.3808 .46809 m .37827 .47034 L .37961 .46895 L F
.767 .469 .48 r
.37827 .47034 m .38249 .47325 L .37835 .47261 L F
.844 .502 .406 r
.37283 .53646 m .37054 .53841 L .37013 .53598 L F
.858 .525 .421 r
.37333 .53889 m .37054 .53841 L .37283 .53646 L F
.925 .651 .503 r
.67766 .33863 m .68095 .33745 L .67734 .33601 L F
.67766 .33863 m .68113 .34025 L .68095 .33745 L F
.221 .028 .393 r
.25843 .5707 m .25564 .57557 L .25564 .57325 L F
.266 0 0 r
.41576 .45545 m .4192 .45338 L .41672 .45384 L F
.485 .028 .092 r
.32041 .50678 m .32266 .50818 L .32454 .506 L F
.574 .156 .211 r
.32266 .50818 m .32711 .50619 L .32454 .506 L F
.274 .675 .97 r
.28646 .65582 m .28755 .65685 L .28446 .65639 L F
.404 .832 .958 r
.63594 .38376 m .63279 .38453 L .63154 .38383 L F
.688 .722 .875 r
.3136 .63799 m .31555 .63964 L .31128 .6388 L F
.734 .793 .9 r
.31625 .63572 m .31555 .63964 L .3136 .63799 L F
.31625 .63572 m .31783 .63858 L .31555 .63964 L F
.815 .996 .859 r
.50746 .39672 m .50665 .39616 L .50946 .39335 L F
.494 .848 .59 r
.66281 .38261 m .666 .38007 L .66614 .37976 L F
.7 .984 .843 r
.666 .38007 m .66963 .37741 L .66753 .37785 L F
.606 .837 .458 r
.66614 .37976 m .666 .38007 L .66753 .37785 L F
.584 .187 .255 r
.26239 .52886 m .26636 .52917 L .26608 .5274 L F
.596 .195 .253 r
.26608 .5274 m .26636 .52917 L .26908 .52884 L F
.978 .75 .526 r
.27505 .65964 m .27305 .66243 L .27334 .65923 L F
.27505 .65964 m .27491 .66276 L .27305 .66243 L F
.652 .713 .893 r
.27575 .65645 m .27505 .65964 L .27334 .65923 L F
.27575 .65645 m .27777 .65894 L .27505 .65964 L F
.695 .545 .68 r
.27777 .65894 m .27491 .66276 L .27505 .65964 L F
.908 .783 .711 r
.40101 .54808 m .40537 .54618 L .40372 .54509 L F
.599 .049 0 r
.40829 .54559 m .40372 .54509 L .40537 .54618 L F
.655 .707 .886 r
.40537 .54618 m .40891 .5461 L .40829 .54559 L F
.924 .648 .5 r
.6891 .3533 m .68933 .35084 L .68683 .34957 L F
.772 .687 .769 r
.33686 .63172 m .33861 .63338 L .33463 .63311 L F
.733 .776 .887 r
.33981 .62949 m .33861 .63338 L .33686 .63172 L F
.33981 .62949 m .34108 .63218 L .33861 .63338 L F
.887 .662 .593 r
.33516 .55321 m .33198 .55497 L .33115 .55242 L F
.33516 .55321 m .33469 .55604 L .33198 .55497 L F
.985 .744 .489 r
.30294 .56146 m .30475 .56287 L .30489 .55978 L F
.30294 .56146 m .30475 .56287 L .30489 .55978 L F
0 0 0 r
.4365 .44507 m .43526 .44471 L .43448 .44551 L F
.4365 .44507 m .438 .44361 L .43526 .44471 L F
0 0 .36 r
.57228 .37061 m .57066 .36981 L .57047 .36917 L F
.57228 .37061 m .57091 .37308 L .57066 .36981 L F
.728 .529 0 r
.55004 .40307 m .55053 .40716 L .55019 .40568 L F
.949 .856 .432 r
.55053 .40716 m .54942 .40863 L .55019 .40568 L F
.55053 .40716 m .54988 .41039 L .54942 .40863 L F
.308 .062 .369 r
.39398 .49292 m .39351 .49577 L .39629 .49197 L F
.39629 .49197 m .39351 .49577 L .39398 .49292 L F
.361 .452 .82 r
.2331 .62189 m .23527 .62328 L .23314 .6185 L F
.685 .211 .12 r
.23314 .6185 m .23705 .61925 L .23453 .61759 L F
.463 .025 .119 r
.39205 .47032 m .39629 .46969 L .39228 .47043 L F
0 0 .005 r
.56294 .36697 m .56372 .36658 L .56253 .364 L F
.56294 .36697 m .56248 .3701 L .56372 .36658 L F
.892 .88 .816 r
.49852 .51306 m .50118 .50934 L .49968 .50812 L F
.783 .903 .925 r
.50118 .50934 m .50306 .50564 L .49968 .50812 L F
.50118 .50934 m .50458 .50691 L .50306 .50564 L F
.286 .785 .857 r
.23527 .62328 m .23913 .62282 L .23745 .62214 L F
.97 .663 .373 r
.23745 .62214 m .23913 .62282 L .23705 .61925 L F
.723 .338 .319 r
.32711 .50619 m .32928 .50871 L .33143 .50659 L F
.83 .493 .418 r
.32928 .50871 m .33299 .51012 L .33143 .50659 L F
0 .484 .811 r
.58803 .34634 m .58898 .34669 L .58931 .34706 L F
.798 .923 .92 r
.5898 .34761 m .58931 .34706 L .59005 .34712 L F
.753 .965 .677 r
.59005 .34712 m .58931 .34706 L .59112 .34484 L F
.758 .992 .795 r
.59312 .34421 m .59005 .34712 L .59112 .34484 L F
.509 .34 .587 r
.58931 .34706 m .59155 .34766 L .59112 .34484 L F
0 .484 .811 r
.58898 .34669 m .59155 .34766 L .58931 .34706 L F
.798 .923 .92 r
.58818 .3508 m .58931 .34706 L .5898 .34761 L F
.58818 .3508 m .58635 .34934 L .58931 .34706 L F
.996 .77 .475 r
.58818 .3508 m .58762 .35328 L .58635 .34934 L F
.908 .643 .526 r
.64931 .39662 m .65141 .40046 L .64907 .39931 L F
0 0 0 r
.64911 .39884 m .6523 .39635 L .64931 .39662 L F
.64942 .39874 m .6523 .39635 L .64911 .39884 L F
.64961 .39882 m .6523 .39635 L .6491 .39901 L F
.653 .768 .934 r
.65093 .39832 m .6514 .39815 L .651 .39767 L F
.65082 .39782 m .651 .39767 L .65071 .39733 L F
.65093 .39832 m .651 .39767 L .65082 .39782 L F
.65141 .40046 m .65082 .39782 L .64907 .39931 L F
0 0 0 r
.64907 .39931 m .65188 .39696 L .64982 .39862 L F
.653 .768 .934 r
.65082 .39782 m .65071 .39733 L .64907 .39931 L F
0 0 0 r
.64982 .39862 m .65089 .39776 L .6523 .39635 L F
.65089 .39776 m .651 .39767 L .65103 .39764 L F
.65089 .39776 m .65103 .39764 L .6523 .39635 L F
.651 .39767 m .65188 .39696 L .65191 .39693 L F
.651 .39767 m .65191 .39693 L .6523 .39635 L F
.64907 .39931 m .65155 .39745 L .65188 .39696 L F
.527 .642 .906 r
.6514 .39815 m .6563 .3953 L .65202 .39686 L F
.651 .39767 m .65202 .39686 L .65071 .39733 L F
.6514 .39815 m .65202 .39686 L .651 .39767 L F
.65356 .40069 m .65547 .39692 L .6514 .39815 L F
.65547 .39692 m .6563 .3953 L .6514 .39815 L F
0 0 0 r
.6491 .39901 m .64942 .39874 L .64911 .39884 L F
.64907 .39931 m .64961 .39882 L .6491 .39901 L F
.653 .768 .934 r
.65141 .40046 m .65356 .40069 L .6514 .39815 L F
.65141 .40046 m .6514 .39815 L .65093 .39832 L F
.527 .642 .906 r
.65356 .40069 m .65682 .39977 L .6563 .3953 L F
.837 .895 .881 r
.52851 .48509 m .53335 .48305 L .53255 .48267 L F
.837 .992 .74 r
.53335 .48305 m .53414 .4805 L .53255 .48267 L F
.53335 .48305 m .53593 .47975 L .53414 .4805 L F
.891 .976 .822 r
.62078 .3549 m .61954 .35673 L .62048 .35768 L F
.772 .87 .92 r
.6258 .3673 m .62306 .3679 L .62397 .36547 L F
.753 .424 .428 r
.62545 .36947 m .62306 .3679 L .6258 .3673 L F
.876 .878 .833 r
.62852 .36395 m .6258 .3673 L .62397 .36547 L F
0 0 .137 r
.62684 .36726 m .6258 .3673 L .6288 .36679 L F
.62684 .36726 m .62545 .36947 L .6258 .3673 L F
.537 .344 .567 r
.62852 .36395 m .6288 .36679 L .6258 .3673 L F
.701 .442 .528 r
.43976 .5458 m .43952 .55163 L .43653 .5463 L F
0 0 .126 r
.4421 .54307 m .44171 .54516 L .43976 .5458 L F
.073 0 .384 r
.44171 .54516 m .43952 .55163 L .43976 .5458 L F
.043 0 0 r
.40661 .45916 m .40404 .45999 L .40237 .46161 L F
.851 .875 .857 r
.49426 .51501 m .49852 .51306 L .49707 .51203 L F
.892 .88 .816 r
.49852 .51306 m .49968 .50812 L .49707 .51203 L F
.804 .7 .75 r
.43439 .56947 m .43021 .56616 L .43435 .56663 L F
.43439 .56947 m .43179 .5702 L .43021 .56616 L F
.73 .692 .813 r
.43824 .56523 m .43439 .56947 L .43435 .56663 L F
.709 .91 .554 r
.345 .66876 m .34662 .66662 L .34745 .66506 L F
.911 .896 .8 r
.68377 .36678 m .68645 .36325 L .68514 .36179 L F
.897 .898 .82 r
.68514 .36179 m .68645 .36325 L .68755 .3613 L F
.898 .896 .818 r
.59448 .37214 m .59603 .37379 L .59792 .37024 L F
.941 .854 .727 r
.37985 .55324 m .37683 .55483 L .37814 .55209 L F
.37985 .55324 m .37832 .55654 L .37683 .55483 L F
.759 .521 .573 r
.32349 .55553 m .32768 .55888 L .32787 .55668 L F
.891 .569 .431 r
.36466 .52339 m .36185 .52476 L .36174 .52208 L F
.36466 .52339 m .36492 .52608 L .36185 .52476 L F
.638 .95 .945 r
.6277 .3639 m .62397 .36547 L .62608 .36366 L F
.163 0 0 r
.62608 .36366 m .62706 .36383 L .6277 .3639 L F
.876 .878 .833 r
.62844 .36397 m .62397 .36547 L .6277 .3639 L F
.482 .304 .563 r
.63122 .36316 m .6288 .36679 L .62852 .36395 L F
.163 0 0 r
.62706 .36383 m .62996 .36436 L .6277 .3639 L F
.876 .878 .833 r
.62852 .36395 m .62844 .36397 L .6277 .3639 L F
.726 .908 .539 r
.62996 .36436 m .62852 .36395 L .6277 .3639 L F
.62996 .36436 m .63122 .36316 L .62852 .36395 L F
.368 0 0 r
.27702 .62565 m .28131 .62612 L .27899 .62651 L F
0 0 0 r
.27937 .62588 m .27895 .62585 L .27899 .62651 L F
.551 .648 .898 r
.28198 .62291 m .28131 .62612 L .27895 .62585 L F
0 0 0 r
.28052 .62396 m .27895 .62585 L .27937 .62588 L F
0 .522 .715 r
.27895 .62585 m .28131 .62612 L .27875 .62584 L F
.27895 .62585 m .27875 .62584 L .27702 .62565 L F
.551 .648 .898 r
.28198 .62291 m .28378 .62556 L .28131 .62612 L F
.17 0 0 r
.28131 .62612 m .2819 .62747 L .27899 .62651 L F
.28131 .62612 m .28378 .62556 L .2819 .62747 L F
.804 .898 .909 r
.3312 .63373 m .32726 .63521 L .33013 .63239 L F
.623 .736 .928 r
.33249 .63134 m .3312 .63373 L .33013 .63239 L F
.33249 .63134 m .33463 .63311 L .3312 .63373 L F
.617 .106 .011 r
.58629 .36063 m .58903 .36247 L .58583 .36204 L F
.327 .621 .957 r
.58583 .36204 m .58733 .36245 L .58679 .36138 L F
0 0 0 r
.58493 .36228 m .58583 .36204 L .58423 .36314 L F
.58629 .36063 m .58583 .36204 L .58493 .36228 L F
.327 .621 .957 r
.58583 .36204 m .58679 .36138 L .58592 .35969 L F
0 .094 .65 r
.58592 .35969 m .58686 .36176 L .58583 .36204 L F
.446 0 0 r
.58903 .36247 m .58733 .36245 L .58583 .36204 L F
.58903 .36247 m .58733 .36245 L .58583 .36204 L F
0 .094 .65 r
.58686 .36176 m .58777 .36378 L .58583 .36204 L F
0 0 0 r
.58423 .36314 m .58583 .36204 L .58355 .36397 L F
.347 .214 .554 r
.5867 .36502 m .58355 .36397 L .58583 .36204 L F
.5867 .36502 m .58376 .36667 L .58355 .36397 L F
.57 .381 .586 r
.40233 .47165 m .39865 .46976 L .40301 .46999 L F
0 0 0 r
.40547 .47034 m .40233 .47165 L .40301 .46999 L F
.77 .699 .784 r
.30471 .63973 m .30628 .64317 L .30203 .64284 L F
.788 .706 .774 r
.30877 .63998 m .30628 .64317 L .30471 .63973 L F
.687 .142 0 r
.39847 .5756 m .40178 .57738 L .40046 .57702 L F
.787 .601 .649 r
.30767 .57782 m .30438 .57957 L .30795 .57831 L F
.988 .849 .478 r
.42228 .56454 m .42364 .56316 L .42217 .56193 L F
.42228 .56454 m .42303 .56583 L .42364 .56316 L F
0 0 0 r
.59677 .35708 m .59477 .35858 L .59537 .35692 L F
.782 .503 .514 r
.59677 .35708 m .59536 .35737 L .59477 .35858 L F
0 0 0 r
.59477 .35858 m .59377 .36061 L .59537 .35692 L F
.782 .503 .514 r
.59536 .35737 m .59278 .35788 L .59477 .35858 L F
0 0 0 r
.59477 .35858 m .59367 .36083 L .59377 .36061 L F
.849 .505 .403 r
.59499 .35303 m .59847 .35635 L .59537 .35692 L F
0 0 0 r
.59677 .35708 m .59537 .35692 L .59847 .35635 L F
.773 .658 .736 r
.54262 .4467 m .54411 .45032 L .5411 .45031 L F
.319 .205 .563 r
.54426 .45313 m .54411 .45032 L .54258 .45197 L F
.596 .415 .607 r
.54411 .45032 m .54426 .45313 L .54258 .45197 L F
.54411 .45032 m .54674 .4499 L .54426 .45313 L F
.83 .717 .74 r
.3469 .58512 m .34828 .58936 L .34882 .58638 L F
.882 .665 .604 r
.52289 .37884 m .52169 .38064 L .51992 .37622 L F
.52289 .37884 m .51992 .37622 L .52012 .37926 L F
.955 .802 .651 r
.52012 .37926 m .52169 .38064 L .52289 .37884 L F
.922 .917 .793 r
.56692 .43029 m .56933 .42665 L .56798 .42538 L F
.817 .765 .804 r
.31592 .61589 m .31467 .61177 L .31204 .61513 L F
.31592 .61589 m .31712 .6142 L .31467 .61177 L F
.822 .777 .81 r
.31361 .61822 m .31592 .61589 L .31204 .61513 L F
.652 .745 .917 r
.65283 .37033 m .65468 .37323 L .6548 .37135 L F
0 0 .219 r
.65468 .37323 m .65652 .37422 L .6548 .37135 L F
.65468 .37323 m .65428 .37595 L .65652 .37422 L F
.708 .756 .89 r
.5798 .34863 m .58055 .35092 L .57663 .35013 L F
.398 .554 .893 r
.58205 .34858 m .58055 .35092 L .5798 .34863 L F
.422 .587 .909 r
.58205 .34858 m .58352 .35244 L .58055 .35092 L F
.866 .751 .734 r
.3381 .5666 m .33702 .56921 L .33566 .56543 L F
.588 .564 .795 r
.32059 .61615 m .3215 .61151 L .31901 .61251 L F
.32059 .61615 m .32312 .61547 L .3215 .61151 L F
.535 .916 .933 r
.48267 .42757 m .48658 .42672 L .48576 .42675 L F
.608 .866 .521 r
.48782 .42496 m .48658 .42672 L .48925 .42351 L F
.641 .957 .771 r
.48576 .42675 m .48658 .42672 L .48782 .42496 L F
.457 .88 .92 r
.29026 .6862 m .29444 .68542 L .29249 .68538 L F
.265 0 0 r
.29444 .68542 m .29454 .68562 L .29249 .68538 L F
.29444 .68542 m .29657 .68609 L .29454 .68562 L F
0 0 .068 r
.34739 .65293 m .34828 .6491 L .34818 .65195 L F
0 0 .307 r
.34765 .65533 m .34739 .65293 L .34818 .65195 L F
.34765 .65533 m .34713 .65612 L .34739 .65293 L F
.861 .757 .746 r
.40985 .55509 m .40743 .56058 L .40657 .55557 L F
.999 .845 .542 r
.4118 .55128 m .41318 .55353 L .41343 .54995 L F
.902 .58 .091 r
.4118 .55128 m .41336 .55547 L .41318 .55353 L F
.612 .666 .878 r
.28979 .64927 m .29428 .65068 L .29167 .65125 L F
.31 0 0 r
.29428 .65068 m .29473 .65128 L .29167 .65125 L F
.29428 .65068 m .29703 .6514 L .29473 .65128 L F
.534 .388 .628 r
.25741 .5332 m .26258 .53481 L .25974 .52932 L F
.568 .375 .58 r
.2572 .53577 m .26258 .53481 L .25741 .5332 L F
.923 .574 .355 r
.41207 .54929 m .4118 .55128 L .41343 .54995 L F
.675 .598 .761 r
.41343 .54995 m .41642 .54969 L .41634 .54684 L F
.697 .714 .862 r
.30271 .61829 m .30487 .62076 L .30691 .61916 L F
.318 0 0 r
.41543 .53984 m .41303 .54155 L .41079 .5409 L F
.994 .779 .502 r
.41395 .53575 m .41392 .53897 L .41543 .53984 L F
.982 .86 .643 r
.41392 .53897 m .41303 .54155 L .41543 .53984 L F
.9 .723 .653 r
.6809 .34222 m .68319 .341 L .68113 .34025 L F
.6809 .34222 m .68261 .34368 L .68319 .341 L F
.199 .728 .804 r
.28706 .64956 m .28979 .64927 L .28778 .64879 L F
.615 .047 0 r
.28778 .64879 m .28979 .64927 L .29167 .65125 L F
.28778 .64879 m .29167 .65125 L .29025 .65058 L F
.16 .285 .744 r
.2892 .64728 m .28778 .64879 L .29025 .65058 L F
.28899 .64665 m .28778 .64879 L .2892 .64728 L F
.199 .728 .804 r
.28572 .6497 m .28706 .64956 L .28778 .64879 L F
.864 .836 .367 r
.61429 .35711 m .61416 .35521 L .61502 .35279 L F
.902 .571 .087 r
.61569 .35813 m .61416 .35521 L .61429 .35711 L F
.788 .706 .774 r
.30877 .63998 m .30471 .63973 L .30684 .63849 L F
.717 .779 .901 r
.30684 .63849 m .31128 .6388 L .30877 .63998 L F
.188 .154 .586 r
.40472 .56256 m .40535 .5654 L .40352 .56585 L F
.918 .934 .567 r
.43806 .57512 m .437 .57959 L .43895 .57609 L F
.428 .241 .523 r
.437 .57959 m .43977 .57914 L .43895 .57609 L F
.43977 .57914 m .44036 .57867 L .43895 .57609 L F
.522 .277 .485 r
.43895 .57609 m .44056 .57902 L .4411 .57822 L F
.89 .755 .706 r
.44104 .57812 m .43816 .57827 L .44023 .5768 L F
.4411 .57822 m .44091 .57822 L .44104 .57812 L F
.44091 .57822 m .43816 .57827 L .44104 .57812 L F
.428 .241 .523 r
.43977 .57914 m .44056 .57902 L .44036 .57867 L F
.047 0 .168 r
.44018 .57122 m .43918 .57305 L .43843 .57222 L F
.991 .87 .531 r
.43918 .57305 m .43895 .57609 L .44064 .57467 L F
.43843 .57222 m .43863 .57368 L .43918 .57305 L F
.43863 .57368 m .43895 .57609 L .43918 .57305 L F
.43843 .57222 m .43806 .57512 L .43895 .57609 L F
.047 0 .168 r
.43918 .57305 m .44013 .57423 L .43806 .57512 L F
.799 .628 .67 r
.44233 .56993 m .44253 .57308 L .44018 .57122 L F
.44233 .56993 m .44018 .57122 L .4406 .57102 L F
.848 .665 .655 r
.4405 .57108 m .44253 .57308 L .44243 .57148 L F
.4406 .57102 m .44243 .57148 L .44233 .56993 L F
.4405 .57108 m .44243 .57148 L .4406 .57102 L F
.799 .628 .67 r
.44233 .56993 m .4406 .57102 L .44306 .5699 L F
.848 .665 .655 r
.44045 .57103 m .4405 .57108 L .44233 .56993 L F
.43949 .57082 m .44096 .57042 L .44045 .56956 L F
.43936 .57099 m .4397 .57087 L .43949 .57082 L F
.4397 .57087 m .44096 .57042 L .43949 .57082 L F
.44096 .57042 m .44201 .56987 L .44045 .56956 L F
.44051 .571 m .44233 .56993 L .43936 .57099 L F
.992 .762 .482 r
.43874 .56453 m .43852 .56872 L .44045 .56956 L F
.903 .681 .593 r
.43669 .57143 m .44045 .56956 L .43852 .56872 L F
.43669 .57143 m .43843 .57222 L .44045 .56956 L F
.637 .826 .973 r
.4415 .56803 m .44027 .571 L .43852 .56872 L F
.44027 .571 m .44018 .57122 L .43999 .57094 L F
.44027 .571 m .43999 .57094 L .43852 .56872 L F
.886 .842 .796 r
.43999 .57094 m .43669 .57143 L .43852 .56872 L F
.44018 .57122 m .43937 .57127 L .43999 .57094 L F
.43937 .57127 m .43669 .57143 L .43999 .57094 L F
.848 .665 .655 r
.44096 .57042 m .44233 .56993 L .44201 .56987 L F
.637 .826 .973 r
.44029 .57094 m .4406 .57102 L .44018 .57122 L F
.848 .665 .655 r
.43843 .57222 m .43964 .571 L .43936 .57099 L F
.897 .702 .631 r
.43937 .57127 m .43843 .57222 L .43669 .57143 L F
.44018 .57122 m .43843 .57222 L .43937 .57127 L F
.848 .665 .655 r
.43843 .57222 m .44051 .571 L .43964 .571 L F
.637 .826 .973 r
.4415 .56803 m .44306 .5699 L .44065 .571 L F
.44061 .571 m .44065 .571 L .4406 .57102 L F
.4415 .56803 m .44065 .571 L .44061 .571 L F
.4415 .56803 m .4406 .57102 L .44029 .57094 L F
.047 0 .168 r
.44018 .57122 m .44017 .57157 L .43918 .57305 L F
.44017 .57157 m .43969 .57248 L .43918 .57305 L F
.848 .665 .655 r
.43843 .57222 m .43969 .57248 L .44045 .57103 L F
.43969 .57248 m .44253 .57308 L .44038 .57154 L F
.683 .253 .221 r
.44018 .57122 m .44038 .57154 L .44017 .57157 L F
.848 .665 .655 r
.44017 .57157 m .44038 .57154 L .44024 .57144 L F
.43969 .57248 m .44038 .57154 L .44017 .57157 L F
.991 .87 .531 r
.43843 .57222 m .44064 .57467 L .44253 .57308 L F
.683 .253 .221 r
.44017 .57157 m .44298 .57565 L .44013 .57423 L F
.44038 .57154 m .44298 .57565 L .44017 .57157 L F
.795 .419 0 r
.44253 .57308 m .44298 .57565 L .44038 .57154 L F
.44253 .57308 m .44038 .57154 L .44018 .57122 L F
.848 .665 .655 r
.44024 .57144 m .44253 .57308 L .44045 .57103 L F
.047 0 .168 r
.44017 .57157 m .44017 .57195 L .43969 .57248 L F
.44017 .57195 m .44013 .57423 L .43918 .57305 L F
.43918 .57305 m .43806 .57512 L .43843 .57222 L F
.825 .709 .738 r
.3484 .57248 m .34598 .576 L .35 .57634 L F
.79 .674 .736 r
.34598 .576 m .34964 .57903 L .35 .57634 L F
.866 .962 .862 r
.52272 .40602 m .52607 .40352 L .52593 .40305 L F
.443 .652 .948 r
.63446 .39566 m .63565 .39796 L .63867 .39736 L F
.085 .558 .904 r
.29068 .66443 m .29007 .66506 L .28736 .66385 L F
.783 .761 .833 r
.48007 .52054 m .4757 .52016 L .47812 .51894 L F
.989 .763 .505 r
.52806 .38549 m .52961 .38701 L .52961 .38394 L F
.609 .106 .032 r
.24375 .59912 m .24215 .60076 L .23987 .59896 L F
0 0 .028 r
.24631 .59556 m .2457 .59801 L .24375 .59912 L F
.508 .235 .436 r
.27296 .52621 m .27568 .52582 L .27622 .52334 L F
.288 .042 .357 r
.27622 .52334 m .27568 .52582 L .27838 .52248 L F
.67 .974 .825 r
.46775 .54634 m .46668 .54627 L .46564 .54704 L F
.604 .906 .631 r
.47081 .54339 m .46894 .54478 L .46775 .54634 L F
.608 .954 .836 r
.46894 .54478 m .46668 .54627 L .46775 .54634 L F
.816 .828 .859 r
.44756 .58548 m .45241 .58357 L .45018 .5821 L F
.03 0 0 r
.44043 .44251 m .44303 .44172 L .44465 .44028 L F
0 0 0 r
.44765 .43743 m .44465 .44028 L .44609 .43913 L F
.44465 .44028 m .44502 .44004 L .44609 .43913 L F
.44465 .44028 m .44303 .44172 L .44502 .44004 L F
.123 .384 .84 r
.24629 .59092 m .24778 .59429 L .24513 .59302 L F
.24629 .59092 m .24513 .59302 L .24591 .59234 L F
0 0 0 r
.24298 .59331 m .24591 .59234 L .24513 .59302 L F
.24298 .59331 m .24044 .59429 L .24591 .59234 L F
.984 .701 .354 r
.30491 .67775 m .30652 .67945 L .30481 .67525 L F
.30539 .67884 m .30652 .67945 L .30491 .67775 L F
.763 .924 .559 r
.30652 .67945 m .30495 .67861 L .30481 .67525 L F
.30652 .67945 m .30739 .67746 L .30495 .67861 L F
.997 .774 .458 r
.3058 .68024 m .30652 .67945 L .30495 .67861 L F
.714 .686 .822 r
.30739 .67746 m .31056 .67735 L .30595 .68015 L F
.30591 .68005 m .30595 .68015 L .3058 .68024 L F
.30739 .67746 m .30595 .68015 L .30591 .68005 L F
.984 .701 .354 r
.30495 .67861 m .30539 .67884 L .30491 .67775 L F
.792 .99 .749 r
.66963 .37741 m .6725 .37414 L .67077 .37486 L F
.79 .999 .831 r
.66753 .37785 m .66963 .37741 L .67077 .37486 L F
.771 .732 .817 r
.38782 .58196 m .38883 .58715 L .39211 .58228 L F
.708 .86 .954 r
.28625 .62499 m .28803 .62653 L .28993 .625 L F
.28625 .62499 m .28803 .62653 L .28993 .625 L F
.515 .787 .994 r
.28378 .62556 m .28803 .62653 L .28625 .62499 L F
.905 .86 .786 r
.66179 .36342 m .66161 .35945 L .66271 .36072 L F
0 0 .006 r
.27939 .52032 m .27838 .52248 L .28094 .51904 L F
.872 .978 .845 r
.49836 .49661 m .49995 .49293 L .5009 .49309 L F
.49836 .49661 m .49726 .49583 L .49995 .49293 L F
.895 .652 .563 r
.3813 .55972 m .38105 .56258 L .37892 .5588 L F
.585 .89 .607 r
.48276 .41284 m .48427 .41103 L .48655 .41056 L F
.48276 .41284 m .48257 .41279 L .48427 .41103 L F
.821 .996 .766 r
.53674 .47718 m .53593 .47975 L .53878 .47645 L F
.823 .992 .743 r
.53414 .4805 m .53593 .47975 L .53674 .47718 L F
.708 .745 .881 r
.62888 .3852 m .6302 .3873 L .62608 .38655 L F
.262 0 0 r
.65552 .33315 m .65817 .3325 L .65926 .33061 L F
.459 .006 .086 r
.65926 .33061 m .66216 .33169 L .66219 .33044 L F
.65926 .33061 m .65817 .3325 L .66216 .33169 L F
.777 .457 .446 r
.41147 .53511 m .41394 .53298 L .41152 .53226 L F
.41147 .53511 m .41395 .53575 L .41394 .53298 L F
.926 .584 .367 r
.28592 .68218 m .2883 .685 L .28867 .68388 L F
.007 .373 .839 r
.2883 .685 m .29026 .6862 L .28867 .68388 L F
.885 .938 .845 r
.68755 .3613 m .68916 .35962 L .68784 .3584 L F
.657 .783 .32 r
.50325 .44011 m .505 .43643 L .50423 .43795 L F
.925 .96 .782 r
.505 .43643 m .50774 .43203 L .50696 .43463 L F
.83 .717 .74 r
.3469 .58512 m .34432 .58864 L .34828 .58936 L F
.829 .721 .746 r
.34432 .58864 m .34594 .59237 L .34828 .58936 L F
.707 .548 .671 r
.38299 .50605 m .38561 .50609 L .38582 .50322 L F
.777 .639 .709 r
.38561 .50609 m .38831 .50274 L .38582 .50322 L F
.851 .755 .757 r
.41799 .54622 m .41634 .54684 L .41457 .54545 L F
.722 .471 .547 r
.41642 .54969 m .41799 .54622 L .41634 .54684 L F
.851 .755 .757 r
.41457 .54545 m .41634 .54684 L .41799 .54622 L F
.804 .554 .56 r
.41642 .54969 m .41826 .55253 L .42078 .55006 L F
.73 .375 .377 r
.68277 .34921 m .68648 .34754 L .68265 .34635 L F
.68277 .34921 m .68683 .34957 L .68648 .34754 L F
.063 .616 .824 r
.437 .57959 m .43655 .57937 L .43283 .57908 L F
.556 .016 0 r
.43283 .57908 m .43692 .5825 L .437 .57959 L F
.918 .934 .567 r
.43806 .57512 m .43655 .57937 L .437 .57959 L F
.785 .533 .556 r
.437 .57959 m .44111 .58286 L .44056 .57902 L F
.437 .57959 m .43692 .5825 L .44111 .58286 L F
0 .065 .629 r
.40953 .59107 m .41091 .59418 L .40944 .59253 L F
.676 .746 .903 r
.31467 .61177 m .31712 .6142 L .31901 .61251 L F
.768 .379 .318 r
.4041 .59452 m .39972 .59167 L .40169 .59299 L F
.341 .252 .608 r
.25378 .54639 m .25559 .54793 L .25548 .54549 L F
.25378 .54639 m .25396 .55025 L .25559 .54793 L F
.727 .675 .799 r
.43824 .56523 m .43435 .56663 L .43272 .5632 L F
.43824 .56523 m .43272 .5632 L .43519 .56189 L F
.971 .734 .523 r
.43672 .56687 m .43852 .56872 L .43874 .56453 L F
.249 .762 .822 r
.44216 .56611 m .43809 .56668 L .43874 .56453 L F
.43809 .56668 m .43672 .56687 L .43773 .56571 L F
.43809 .56668 m .43773 .56571 L .43874 .56453 L F
.727 .675 .799 r
.43824 .56523 m .4371 .56398 L .43675 .56295 L F
.4371 .56398 m .43519 .56189 L .43671 .56292 L F
.4371 .56398 m .43671 .56292 L .43675 .56295 L F
.501 .57 .857 r
.43825 .55895 m .43675 .56295 L .43519 .56189 L F
.547 .869 .586 r
.5009 .49309 m .50237 .4915 L .50404 .49017 L F
.571 .94 .879 r
.5009 .49309 m .49995 .49293 L .50237 .4915 L F
.917 .662 .537 r
.34995 .56813 m .34748 .56599 L .34673 .56867 L F
.853 .68 .667 r
.34673 .56867 m .3484 .57248 L .34995 .56813 L F
.697 .481 .59 r
.40856 .54892 m .41207 .54929 L .40891 .5461 L F
.32 0 .144 r
.39565 .46476 m .39421 .46295 L .39309 .46547 L F
.39565 .46476 m .39704 .46195 L .39421 .46295 L F
.545 .136 .217 r
.49857 .43217 m .50138 .43019 L .49666 .43098 L F
.49953 .43276 m .49666 .43098 L .49782 .43219 L F
.281 .643 .966 r
.49852 .43083 m .49789 .43205 L .49617 .43068 L F
.49789 .43205 m .49782 .43219 L .4976 .432 L F
.716 .191 0 r
.49782 .43219 m .49666 .43098 L .49331 .42946 L F
.281 .643 .966 r
.49789 .43205 m .4976 .432 L .49617 .43068 L F
.545 .136 .217 r
.49953 .43276 m .4998 .43238 L .49857 .43217 L F
.4998 .43238 m .50138 .43019 L .49857 .43217 L F
0 0 0 r
.50287 .42871 m .50138 .43019 L .49953 .43276 L F
.732 .792 .9 r
.32081 .63601 m .31783 .63858 L .31625 .63572 L F
.869 .993 .811 r
.33224 .57516 m .33345 .57165 L .33446 .57513 L F
.33224 .57516 m .33062 .57525 L .33345 .57165 L F
.93 .844 .737 r
.44472 .55571 m .44489 .56033 L .44228 .55895 L F
0 .319 .777 r
.44615 .56185 m .44228 .55895 L .44489 .56033 L F
.329 0 0 r
.51103 .44297 m .51052 .44435 L .51 .44535 L F
.51103 .44297 m .51376 .44283 L .51052 .44435 L F
.975 .808 .612 r
.55089 .42264 m .55255 .42382 L .55185 .42646 L F
.065 .095 .582 r
.239 .59665 m .23987 .59896 L .23954 .59494 L F
.68 .763 .914 r
.59177 .37503 m .59318 .37817 L .58922 .37695 L F
.148 .245 .708 r
.59451 .37527 m .59318 .37817 L .59177 .37503 L F
.59451 .37527 m .59532 .37881 L .59318 .37817 L F
0 0 .276 r
.59588 .37772 m .59574 .37876 L .59532 .37881 L F
0 .402 .808 r
.59455 .3789 m .59532 .37881 L .59743 .38042 L F
.872 .434 .134 r
.59546 .38081 m .59743 .38042 L .59532 .37881 L F
0 0 .276 r
.59574 .37876 m .59546 .38081 L .59532 .37881 L F
0 .402 .808 r
.59318 .37817 m .59532 .37881 L .59455 .3789 L F
.953 .835 .69 r
.42132 .59281 m .4197 .59327 L .42061 .58869 L F
.325 .185 .532 r
.42132 .59281 m .42066 .59648 L .4197 .59327 L F
.42132 .59281 m .42224 .59522 L .42066 .59648 L F
.42066 .59648 m .42224 .59522 L .42132 .59281 L F
.687 .142 0 r
.39847 .5756 m .39961 .57717 L .40178 .57738 L F
.327 .731 .98 r
.39961 .57717 m .40418 .57849 L .40178 .57738 L F
.711 .985 .817 r
.54514 .34639 m .54301 .34818 L .54554 .34719 L F
.199 .724 .732 r
.3205 .58401 m .31833 .58438 L .32308 .58338 L F
.689 .23 .156 r
.36775 .50761 m .37197 .50643 L .3697 .50607 L F
.36775 .50761 m .37012 .50831 L .37197 .50643 L F
.548 .062 .053 r
.37197 .50643 m .37012 .50831 L .37433 .50823 L F
.882 .773 .737 r
.66145 .39263 m .6625 .39623 L .66352 .3941 L F
.442 .854 .962 r
.3746 .47189 m .37572 .47336 L .37488 .47368 L F
.3746 .47189 m .37835 .47261 L .37572 .47336 L F
.414 .16 .417 r
.37572 .47336 m .37835 .47261 L .37776 .47483 L F
0 0 0 r
.50774 .43203 m .51035 .42952 L .50954 .43116 L F
.50696 .43463 m .50774 .43203 L .50954 .43116 L F
.50867 .4332 m .50696 .43463 L .50954 .43116 L F
.955 .691 .243 r
.50867 .43293 m .50954 .43116 L .50858 .42948 L F
.50867 .4332 m .50954 .43116 L .50867 .43293 L F
0 0 0 r
.51035 .42952 m .51062 .42926 L .50954 .43116 L F
.895 .7 .63 r
.5572 .45567 m .55928 .45707 L .5576 .45302 L F
.857 .847 .832 r
.55488 .45908 m .55928 .45707 L .5572 .45567 L F
.761 .993 .875 r
.51576 .38677 m .51727 .38411 L .51859 .38469 L F
.776 .983 .904 r
.54222 .4738 m .53935 .47428 L .53878 .47645 L F
.828 .996 .764 r
.53878 .47645 m .53935 .47428 L .53674 .47718 L F
.906 .765 .694 r
.33566 .56543 m .33702 .56921 L .33427 .56865 L F
.93 .755 .644 r
.33702 .56921 m .33345 .57165 L .33427 .56865 L F
.33702 .56921 m .33563 .57297 L .33345 .57165 L F
.937 .574 .29 r
.55854 .40627 m .55688 .40441 L .55736 .40534 L F
.282 0 0 r
.55913 .40705 m .55854 .40627 L .55736 .40534 L F
.55913 .40705 m .56132 .40683 L .55854 .40627 L F
.237 .437 .855 r
.55007 .34319 m .55336 .34498 L .55226 .34705 L F
.7 .978 .906 r
.55336 .34498 m .54987 .34728 L .55226 .34705 L F
.842 .71 .718 r
.33662 .57657 m .33634 .57927 L .33446 .57513 L F
.829 .921 .896 r
.56645 .36364 m .56716 .35983 L .56809 .3626 L F
.56645 .36364 m .56327 .3651 L .56716 .35983 L F
.845 .812 .818 r
.38809 .46702 m .38516 .46988 L .38181 .46809 L F
.872 .994 .787 r
.38249 .47325 m .38516 .46988 L .38533 .4719 L F
.263 0 0 r
.37835 .47261 m .38249 .47325 L .37974 .47314 L F
.53 .917 .919 r
.38247 .47254 m .38249 .47325 L .38533 .4719 L F
.37974 .47314 m .38123 .4732 L .38247 .47254 L F
.38123 .4732 m .38249 .47325 L .38247 .47254 L F
0 0 0 r
.38561 .47162 m .38533 .4719 L .38516 .46988 L F
.38596 .47296 m .38533 .4719 L .38561 .47162 L F
.38596 .47296 m .38738 .47265 L .38533 .4719 L F
.686 .318 .343 r
.38533 .4719 m .38738 .47265 L .38749 .47459 L F
0 .026 .595 r
.38533 .4719 m .38749 .47459 L .38626 .47214 L F
.38533 .4719 m .38626 .47214 L .38479 .47247 L F
.38533 .4719 m .38479 .47247 L .38382 .47269 L F
.53 .917 .919 r
.37974 .47314 m .38533 .4719 L .38382 .47269 L F
.475 .443 .743 r
.38517 .47108 m .38382 .47269 L .38626 .47214 L F
.845 .812 .818 r
.38809 .46702 m .38181 .46809 L .38298 .46801 L F
.38747 .46725 m .38298 .46801 L .38608 .46779 L F
.136 .682 .798 r
.38204 .46803 m .38608 .46779 L .38181 .46809 L F
.475 .443 .743 r
.38204 .46803 m .38354 .47196 L .38517 .47108 L F
.38354 .47196 m .38382 .47269 L .38517 .47108 L F
.829 .627 .63 r
.37932 .47078 m .38382 .47269 L .38209 .46816 L F
.38188 .46819 m .38209 .46816 L .38204 .46803 L F
.37932 .47078 m .38209 .46816 L .38188 .46819 L F
.845 .812 .818 r
.38809 .46702 m .38298 .46801 L .38747 .46725 L F
.184 0 0 r
.3887 .46801 m .38809 .46702 L .38608 .46779 L F
.3887 .46801 m .3907 .46678 L .38809 .46702 L F
0 0 .079 r
.53286 .43341 m .5312 .43662 L .53241 .43607 L F
0 .103 .625 r
.53241 .43607 m .5312 .43662 L .53272 .43827 L F
.761 .993 .875 r
.51576 .38677 m .51533 .38609 L .51727 .38411 L F
.872 .434 .134 r
.59546 .38081 m .59827 .3826 L .59743 .38042 L F
.341 .163 .489 r
.59743 .38042 m .59827 .3826 L .59966 .3805 L F
.259 .37 .787 r
.58793 .37531 m .58631 .37756 L .5859 .37471 L F
.549 .777 .983 r
.58793 .37531 m .58922 .37695 L .58631 .37756 L F
0 0 0 r
.32485 .59173 m .32301 .59614 L .32158 .59508 L F
.99 .842 .6 r
.32158 .59508 m .32301 .59614 L .32084 .59783 L F
.907 .584 .424 r
.32301 .59614 m .32329 .59885 L .32084 .59783 L F
.599 .049 0 r
.40829 .54559 m .40363 .54539 L .40372 .54509 L F
.855 .881 .857 r
.40683 .5424 m .40829 .54559 L .40948 .54184 L F
.40683 .5424 m .40363 .54539 L .40829 .54559 L F
.676 .656 .822 r
.4197 .59327 m .41477 .59688 L .41537 .59265 L F
.4197 .59327 m .42066 .59648 L .41477 .59688 L F
.281 0 .264 r
.41772 .59745 m .41477 .59688 L .42066 .59648 L F
.41772 .59745 m .41542 .59863 L .41477 .59688 L F
.93 .775 .667 r
.40845 .53867 m .41079 .5409 L .41005 .53607 L F
.921 .766 .672 r
.40845 .53867 m .40948 .54184 L .41079 .5409 L F
.494 .479 .769 r
.41005 .53607 m .41079 .5409 L .41392 .53897 L F
.272 .07 .412 r
.41079 .5409 m .41303 .54155 L .41392 .53897 L F
.449 .817 .994 r
.43692 .5825 m .43962 .58187 L .44111 .58286 L F
.972 .89 .686 r
.44111 .58286 m .4411 .57822 L .44056 .57902 L F
.44111 .58286 m .43962 .58187 L .4411 .57822 L F
0 0 0 r
.44983 .43599 m .44765 .43743 L .44609 .43913 L F
.823 .997 .847 r
.52004 .4918 m .52138 .49211 L .52392 .48946 L F
.9 .833 .77 r
.5256 .46997 m .52331 .46901 L .52516 .46567 L F
.875 .561 .453 r
.5256 .46997 m .52242 .47156 L .52331 .46901 L F
.5256 .46997 m .52497 .47211 L .52242 .47156 L F
.731 .775 .888 r
.34405 .62986 m .34108 .63218 L .33981 .62949 L F
.284 0 0 r
.62227 .39849 m .62068 .39834 L .61767 .39738 L F
.518 .914 .907 r
.62302 .39723 m .62227 .39849 L .62508 .39746 L F
.62302 .39723 m .62068 .39834 L .62227 .39849 L F
.84 .735 .212 r
.49331 .42946 m .49307 .43357 L .49066 .43281 L F
.603 .085 0 r
.4866 .43229 m .48986 .43322 L .48655 .43521 L F
.48986 .43322 m .49112 .43358 L .49046 .43382 L F
.48986 .43322 m .49046 .43382 L .48655 .43521 L F
.385 0 .046 r
.48655 .43521 m .49046 .43382 L .48962 .43513 L F
.49046 .43382 m .49112 .43358 L .49014 .43459 L F
.49046 .43382 m .49014 .43459 L .48962 .43513 L F
.987 .726 .439 r
.49307 .43357 m .49155 .43493 L .49076 .43306 L F
.49084 .43287 m .49076 .43306 L .49066 .43281 L F
.49307 .43357 m .49076 .43306 L .49084 .43287 L F
.49155 .43493 m .49142 .43505 L .49128 .43466 L F
.49155 .43493 m .49128 .43466 L .49066 .43281 L F
.49307 .43357 m .49315 .4366 L .49142 .43505 L F
.897 .898 .82 r
.68514 .36179 m .68755 .3613 L .68784 .3584 L F
.944 .904 .754 r
.56569 .43212 m .56692 .43029 L .56557 .42909 L F
.922 .917 .793 r
.56692 .43029 m .56798 .42538 L .56557 .42909 L F
.741 .99 .882 r
.4754 .43158 m .47769 .43128 L .47967 .42954 L F
.743 .809 .904 r
.3153 .60703 m .31088 .60642 L .31334 .6052 L F
.725 .815 .921 r
.3172 .60554 m .3153 .60703 L .31334 .6052 L F
.662 .189 .12 r
.52171 .41628 m .52582 .41675 L .52457 .41851 L F
.507 0 0 r
.52468 .41688 m .52582 .41675 L .52171 .41628 L F
.634 .955 .93 r
.52829 .41514 m .52582 .41675 L .52468 .41688 L F
0 0 0 r
.52457 .41851 m .52582 .41675 L .52829 .41514 L F
0 0 .426 r
.38204 .46803 m .38181 .46809 L .3808 .46809 L F
.38204 .46803 m .3808 .46809 L .37961 .46895 L F
.509 .895 .729 r
.45156 .44651 m .45189 .4466 L .45411 .44507 L F
.212 .73 .708 r
.449 .44752 m .45219 .44667 L .45189 .4466 L F
.509 .895 .729 r
.45 .44739 m .45189 .4466 L .45156 .44651 L F
.212 .73 .708 r
.45219 .44667 m .45271 .44653 L .45189 .4466 L F
.552 .932 .857 r
.45411 .44507 m .45271 .44653 L .45496 .44521 L F
.556 .928 .792 r
.45189 .4466 m .45271 .44653 L .45411 .44507 L F
.581 .558 .793 r
.58762 .35328 m .58477 .35422 L .58352 .35244 L F
.212 .737 .809 r
.6458 .39691 m .64123 .39739 L .64297 .39793 L F
.84 .764 .778 r
.55617 .44907 m .55943 .44981 L .56085 .44711 L F
.857 .727 .719 r
.5576 .45302 m .55943 .44981 L .55617 .44907 L F
.438 .259 .54 r
.54421 .45601 m .54158 .45677 L .54426 .45313 L F
.911 .673 .565 r
.37046 .53306 m .36727 .53471 L .36717 .53205 L F
.37046 .53306 m .37013 .53598 L .36727 .53471 L F
.754 .824 .907 r
.51882 .40576 m .52082 .4078 L .52272 .40602 L F
.688 .478 .597 r
.38146 .49289 m .38358 .49349 L .38273 .4899 L F
.367 .274 .617 r
.38273 .4899 m .38358 .49349 L .38517 .49194 L F
.545 .147 .237 r
.39629 .46969 m .39175 .4715 L .39228 .47043 L F
.489 .204 .408 r
.25167 .55562 m .25419 .55565 L .25476 .55312 L F
.5 .489 .776 r
.25396 .55025 m .25476 .55312 L .25711 .55229 L F
.258 .004 .324 r
.25476 .55312 m .25626 .55461 L .25711 .55229 L F
.25476 .55312 m .25419 .55565 L .25626 .55461 L F
.494 .505 .797 r
.48925 .42351 m .49354 .42712 L .49136 .42313 L F
.073 0 0 r
.48782 .42496 m .48925 .42351 L .49136 .42313 L F
.617 .942 .741 r
.29753 .6748 m .29578 .67637 L .29394 .6772 L F
.84 .717 .727 r
.33923 .59543 m .34332 .59575 L .34187 .59165 L F
.829 .759 .786 r
.33923 .59543 m .34067 .59923 L .34332 .59575 L F
.76 .679 .772 r
.34187 .59165 m .34332 .59575 L .34594 .59237 L F
.809 .772 .818 r
.59966 .3805 m .60156 .38368 L .59827 .3826 L F
.758 .267 .062 r
.60156 .38368 m .59976 .38367 L .59827 .3826 L F
.355 .551 .907 r
.60297 .38157 m .60156 .38368 L .59966 .3805 L F
.666 .958 .942 r
.60297 .38157 m .59976 .38367 L .60156 .38368 L F
.789 .536 0 r
.56977 .41757 m .56874 .41256 L .5685 .41626 L F
.891 .466 .133 r
.56888 .41839 m .56977 .41757 L .5685 .41626 L F
.56888 .41839 m .57056 .41943 L .56977 .41757 L F
0 0 0 r
.43904 .45197 m .44296 .44956 L .44155 .4511 L F
.026 0 0 r
.44296 .44956 m .44406 .45007 L .44155 .4511 L F
.44296 .44956 m .44554 .44855 L .44406 .45007 L F
.651 .723 .901 r
.3112 .53127 m .31288 .53349 L .31492 .53126 L F
0 0 0 r
.32041 .50678 m .31829 .51056 L .32018 .50785 L F
.489 .022 .071 r
.32018 .50785 m .32266 .50818 L .32041 .50678 L F
.307 .096 .421 r
.43653 .5463 m .43889 .54581 L .4391 .54262 L F
.372 .314 .662 r
.43653 .5463 m .43952 .55163 L .43889 .54581 L F
.94 .654 .47 r
.33467 .51768 m .33437 .51946 L .33682 .5203 L F
.911 .577 .399 r
.33488 .52097 m .33682 .5203 L .33437 .51946 L F
.33488 .52097 m .33651 .52225 L .33682 .5203 L F
.521 .058 .094 r
.60567 .38726 m .60432 .38897 L .6084 .38866 L F
.259 0 0 r
.31398 .56183 m .31661 .56183 L .31843 .56025 L F
0 0 0 r
.31843 .56025 m .31661 .56183 L .31898 .5606 L F
.668 .973 .894 r
.29316 .63985 m .29111 .64153 L .28861 .642 L F
.804 .554 .56 r
.41642 .54969 m .41622 .55278 L .41826 .55253 L F
.545 .147 .237 r
.39629 .46969 m .39443 .47206 L .39175 .4715 L F
.798 .549 .561 r
.39865 .46976 m .39443 .47206 L .39629 .46969 L F
.753 .909 .945 r
.29344 .62304 m .29741 .62249 L .29578 .62169 L F
.893 .935 .836 r
.29578 .62169 m .29741 .62249 L .30025 .61881 L F
.53 .097 .163 r
.27978 .54553 m .2757 .54661 L .27747 .54637 L F
.813 .769 .812 r
.32875 .60902 m .33267 .60932 L .33119 .60593 L F
.825 .738 .769 r
.33004 .61276 m .33267 .60932 L .32875 .60902 L F
.791 .757 .822 r
.33267 .60932 m .3335 .6045 L .33119 .60593 L F
.33267 .60932 m .33532 .60616 L .3335 .6045 L F
.898 .74 .678 r
.38084 .57924 m .37748 .57876 L .37939 .57545 L F
.881 .713 .67 r
.37933 .58046 m .37748 .57876 L .38084 .57924 L F
.623 .946 .748 r
.67077 .37486 m .6725 .37414 L .6747 .37233 L F
0 0 .034 r
.35336 .6347 m .35287 .63917 L .3531 .63595 L F
.73 .204 0 r
.56341 .38368 m .56248 .38456 L .56257 .38227 L F
.56341 .38368 m .56546 .38625 L .56248 .38456 L F
.74 .493 .557 r
.39082 .5235 m .38988 .52582 L .38801 .52269 L F
.544 .893 .663 r
.61782 .39047 m .61747 .39096 L .61934 .38933 L F
.957 .67 .451 r
.30063 .65249 m .29866 .65432 L .29867 .65329 L F
.331 .088 .386 r
.29892 .65404 m .29867 .65329 L .29866 .65432 L F
.504 .788 .996 r
.29817 .65175 m .30063 .65249 L .29867 .65329 L F
.331 .088 .386 r
.30135 .65135 m .29867 .65329 L .29892 .65404 L F
.504 .788 .996 r
.29703 .6514 m .29817 .65175 L .29867 .65329 L F
.957 .67 .451 r
.30063 .65249 m .30069 .65554 L .29866 .65432 L F
.689 .202 0 r
.39092 .58906 m .39318 .59203 L .39172 .59076 L F
.39092 .58906 m .39172 .59076 L .39399 .58893 L F
.542 .451 .701 r
.38964 .50916 m .39193 .51185 L .39448 .50925 L F
.776 .494 .509 r
.39193 .51185 m .39463 .51233 L .39448 .50925 L F
.84 .764 .778 r
.55617 .44907 m .56085 .44711 L .55896 .44578 L F
.932 .809 .7 r
.56085 .44711 m .55945 .44298 L .55896 .44578 L F
.129 0 0 r
.63363 .34036 m .63517 .34122 L .63651 .34053 L F
.79 .674 .736 r
.34598 .576 m .34534 .57902 L .34964 .57903 L F
.849 .66 .647 r
.34538 .58132 m .34964 .57903 L .34534 .57902 L F
.34538 .58132 m .34785 .58288 L .34964 .57903 L F
.989 .834 .456 r
.56874 .41256 m .56918 .41014 L .56786 .4115 L F
0 0 .003 r
.56918 .41014 m .57055 .40547 L .56833 .40892 L F
.993 .817 .444 r
.56786 .4115 m .56918 .41014 L .56833 .40892 L F
.905 .86 .786 r
.66179 .36342 m .65922 .36297 L .66161 .35945 L F
.982 .888 .655 r
.65969 .36675 m .65922 .36297 L .66179 .36342 L F
.474 .594 .893 r
.50679 .41548 m .50602 .41917 L .50447 .41571 L F
.50679 .41548 m .50847 .4192 L .50602 .41917 L F
.506 .539 .825 r
.24923 .5861 m .25066 .58589 L .24917 .58163 L F
.323 0 .122 r
.25066 .58589 m .24986 .5876 L .24923 .5861 L F
.25066 .58589 m .24986 .5876 L .24923 .5861 L F
.325 .571 .929 r
.49316 .44374 m .49771 .44669 L .49617 .44543 L F
0 0 .126 r
.49636 .44986 m .49617 .44543 L .49771 .44669 L F
.895 .624 .519 r
.34198 .53222 m .34421 .5331 L .34228 .52969 L F
.901 .704 .627 r
.34161 .53504 m .34421 .5331 L .34198 .53222 L F
.34161 .53504 m .3437 .53593 L .34421 .5331 L F
.64 .726 .91 r
.58635 .34934 m .58352 .35244 L .58205 .34858 L F
.581 .558 .793 r
.58762 .35328 m .58352 .35244 L .58635 .34934 L F
.913 .767 .279 r
.54942 .40863 m .54988 .41039 L .54961 .41247 L F
.799 .847 .887 r
.43997 .59299 m .44253 .59141 L .44105 .58909 L F
.836 .857 .86 r
.44105 .58909 m .44253 .59141 L .44486 .58899 L F
.712 .539 .653 r
.38288 .50922 m .38561 .50609 L .38299 .50605 L F
.38288 .50922 m .38746 .51072 L .38561 .50609 L F
.619 .492 .686 r
.38561 .50609 m .38746 .51072 L .38964 .50916 L F
.279 0 0 r
.40926 .45885 m .41192 .45835 L .41331 .45623 L F
0 0 0 r
.41192 .45835 m .41576 .45545 L .41331 .45623 L F
.732 .705 .825 r
.59889 .37332 m .5989 .37476 L .60284 .37361 L F
.874 .777 .751 r
.33823 .59805 m .34067 .59923 L .33923 .59543 L F
.866 .746 .728 r
.33615 .60137 m .34067 .59923 L .33823 .59805 L F
.33615 .60137 m .3381 .60282 L .34067 .59923 L F
.803 .738 .792 r
.53613 .46337 m .53368 .4672 L .53199 .46348 L F
.848 .65 .635 r
.37879 .50806 m .38288 .50922 L .38299 .50605 L F
.829 .616 .615 r
.38362 .56655 m .38307 .56938 L .38074 .56555 L F
.799 .628 .67 r
.44233 .56993 m .44306 .5699 L .44497 .56964 L F
.694 .769 .909 r
.43021 .56616 m .42699 .5684 L .42606 .5661 L F
.763 .651 .738 r
.50202 .45309 m .50585 .45316 L .50448 .45157 L F
.762 .66 .749 r
.50524 .44918 m .50552 .45104 L .50391 .45079 L F
.50561 .45158 m .50585 .45316 L .50455 .45158 L F
.337 .353 .73 r
.50768 .45216 m .50585 .45316 L .50524 .44918 L F
.421 .55 .88 r
.50455 .45158 m .50585 .45316 L .50768 .45216 L F
.50451 .45158 m .50768 .45216 L .50725 .453 L F
.50448 .45157 m .50585 .45316 L .50455 .45158 L F
.50448 .45157 m .50455 .45158 L .50451 .45158 L F
.50455 .45158 m .50768 .45216 L .50451 .45158 L F
.762 .66 .749 r
.50552 .45104 m .50561 .45158 L .50454 .45156 L F
.50561 .45158 m .50455 .45158 L .50454 .45156 L F
.50552 .45104 m .50454 .45156 L .50391 .45079 L F
.305 0 .075 r
.50447 .4516 m .50448 .45157 L .50451 .45158 L F
.262 0 .069 r
.50202 .45309 m .50448 .45157 L .50447 .4516 L F
.762 .66 .749 r
.50391 .45079 m .50454 .45156 L .50202 .45309 L F
.50454 .45156 m .50585 .45316 L .50202 .45309 L F
.262 0 .069 r
.50202 .45309 m .50447 .4516 L .5042 .45374 L F
.305 0 .075 r
.5042 .45374 m .50447 .4516 L .50725 .453 L F
.50447 .4516 m .50451 .45158 L .50725 .453 L F
.595 .413 .606 r
.25974 .52932 m .26386 .53262 L .26239 .52886 L F
.25974 .52932 m .26258 .53481 L .26386 .53262 L F
.497 .278 .513 r
.32439 .55298 m .32107 .55622 L .32349 .55553 L F
.514 .344 .588 r
.32109 .55953 m .32349 .55553 L .32107 .55622 L F
.683 .166 0 r
.49639 .44992 m .49933 .45271 L .49798 .45263 L F
.49636 .44986 m .49639 .44989 L .49639 .44992 L F
.49639 .44989 m .49933 .45271 L .49639 .44992 L F
.49636 .44986 m .49798 .45263 L .49668 .45085 L F
.707 .441 .519 r
.49636 .44986 m .49725 .45259 L .49643 .45064 L F
.237 .206 .619 r
.49649 .45059 m .49962 .45061 L .49946 .44804 L F
.49643 .45064 m .4965 .45064 L .49649 .45059 L F
.4965 .45064 m .49962 .45061 L .49649 .45059 L F
.475 .471 .773 r
.49617 .44543 m .49642 .45049 L .49946 .44804 L F
.49642 .45049 m .49643 .45064 L .49649 .45059 L F
.49642 .45049 m .49649 .45059 L .49946 .44804 L F
.683 .166 0 r
.49668 .45085 m .49798 .45263 L .49725 .45259 L F
.515 .019 .016 r
.49933 .45271 m .50068 .45513 L .49725 .45259 L F
.49933 .45271 m .50146 .45416 L .50068 .45513 L F
.49933 .45271 m .50202 .45309 L .50146 .45416 L F
.945 .721 .569 r
.33165 .51452 m .33469 .51237 L .33286 .51089 L F
.33165 .51452 m .33467 .51768 L .33469 .51237 L F
.702 .955 .951 r
.59575 .34234 m .59312 .34421 L .59409 .34225 L F
.757 .992 .795 r
.59312 .34421 m .59112 .34484 L .59409 .34225 L F
.892 .944 .837 r
.68125 .36978 m .68377 .36678 L .68282 .36555 L F
.911 .896 .8 r
.68377 .36678 m .68514 .36179 L .68282 .36555 L F
.923 .789 .695 r
.66145 .39263 m .65898 .39743 L .6625 .39623 L F
.925 .833 .736 r
.6625 .39623 m .65889 .39855 L .65964 .39914 L F
.6625 .39623 m .65898 .39743 L .65889 .39855 L F
.223 0 0 r
.62013 .34527 m .62282 .3449 L .62405 .34344 L F
.209 0 0 r
.62282 .3449 m .62686 .34305 L .62405 .34344 L F
.799 .847 .887 r
.43997 .59299 m .44105 .58909 L .43799 .59142 L F
.559 .588 .839 r
.53851 .43217 m .54235 .43529 L .54042 .43329 L F
.645 .153 .068 r
.35017 .65378 m .35245 .65235 L .34818 .65195 L F
0 0 .437 r
.35359 .65395 m .35245 .65235 L .3549 .65185 L F
.35359 .65395 m .35278 .65541 L .35266 .65431 L F
.35306 .65321 m .35266 .65431 L .35245 .65235 L F
.35359 .65395 m .35266 .65431 L .35306 .65321 L F
.648 .398 .526 r
.34828 .6491 m .35198 .6527 L .34818 .65195 L F
.34828 .6491 m .35455 .64983 L .35198 .6527 L F
.911 .844 .765 r
.35198 .6527 m .35455 .64983 L .35142 .647 L F
.598 .185 .231 r
.34818 .65195 m .35198 .6527 L .35017 .65378 L F
.911 .844 .765 r
.35198 .6527 m .35142 .647 L .35276 .65164 L F
.705 .981 .799 r
.35017 .65378 m .35198 .6527 L .35276 .65164 L F
.047 0 0 r
.35362 .65172 m .35017 .65378 L .35276 .65164 L F
.3549 .65185 m .35333 .65249 L .35362 .65172 L F
.3549 .65185 m .35245 .65235 L .35174 .65279 L F
.35263 .65277 m .35174 .65279 L .35017 .65378 L F
.3549 .65185 m .35174 .65279 L .35263 .65277 L F
.35333 .65249 m .35017 .65378 L .35362 .65172 L F
.951 .767 .619 r
.35359 .65395 m .3549 .65185 L .35276 .65164 L F
.131 .296 .765 r
.35518 .65302 m .35359 .65395 L .35317 .65276 L F
.35468 .65273 m .35317 .65276 L .35276 .65164 L F
.35518 .65302 m .35317 .65276 L .35468 .65273 L F
.961 .647 .384 r
.52306 .37288 m .52108 .37284 L .52251 .37033 L F
.52251 .37033 m .52108 .37284 L .52306 .37288 L F
.52306 .37288 m .52108 .37284 L .52251 .37033 L F
.575 .309 .477 r
.29146 .57819 m .29463 .57622 L .2905 .57545 L F
.29146 .57819 m .29398 .57884 L .29463 .57622 L F
.29463 .57622 m .29398 .57884 L .29146 .57819 L F
.662 .189 .12 r
.52171 .41628 m .52457 .41851 L .52211 .41968 L F
.606 .742 .941 r
.52433 .41844 m .52211 .41968 L .52457 .41851 L F
.52128 .41766 m .52211 .41968 L .52433 .41844 L F
.934 .945 .606 r
.51947 .42274 m .52071 .42046 L .52211 .41968 L F
.52071 .42046 m .52185 .41837 L .52211 .41968 L F
.749 .773 .873 r
.40845 .59495 m .41263 .59602 L .41091 .59418 L F
.421 0 0 r
.41542 .59863 m .41314 .59757 L .41141 .59652 L F
.211 .337 .774 r
.41141 .59652 m .41314 .59757 L .41308 .59744 L F
.501 0 0 r
.41263 .59602 m .41141 .59652 L .40869 .59501 L F
.825 .782 .812 r
.41537 .59265 m .41263 .59602 L .41091 .59418 L F
.211 .337 .774 r
.41141 .59652 m .41308 .59744 L .41171 .59464 L F
.501 0 0 r
.40869 .59501 m .41141 .59652 L .40845 .59495 L F
.76 .722 .817 r
.30042 .60328 m .30061 .60511 L .29921 .60439 L F
.861 .602 .547 r
.29921 .60439 m .30061 .60511 L .29978 .60793 L F
.687 .506 .636 r
.30336 .60627 m .29978 .60793 L .30061 .60511 L F
.197 .378 .817 r
.24513 .59302 m .24778 .59429 L .24631 .59556 L F
.688 .7 .171 r
.24599 .5968 m .2457 .59801 L .24581 .59757 L F
.24599 .5968 m .24581 .59757 L .24631 .59556 L F
.24599 .5968 m .24631 .59556 L .24778 .59429 L F
.71 .882 .49 r
.24778 .59429 m .24606 .59651 L .24599 .5968 L F
.24606 .59651 m .24597 .59662 L .24599 .5968 L F
.825 .782 .812 r
.41537 .59265 m .41091 .59418 L .41651 .59079 L F
.136 .635 .909 r
.4158 .59204 m .41537 .59265 L .41651 .59079 L F
.945 .662 .205 r
.41468 .58989 m .4158 .59204 L .41651 .59079 L F
.74 .991 .82 r
.50704 .48754 m .50404 .49017 L .50505 .48812 L F
.73 .942 .624 r
.50404 .49017 m .50237 .4915 L .50505 .48812 L F
.737 .425 .454 r
.41115 .56311 m .40768 .56494 L .4082 .56214 L F
.41115 .56311 m .41214 .56548 L .40768 .56494 L F
.068 0 0 r
.61393 .38758 m .61508 .38715 L .61246 .38729 L F
.649 .759 .929 r
.31464 .55671 m .31004 .5558 L .31249 .5556 L F
.31004 .5558 m .31464 .55671 L .31249 .5556 L F
.59 .852 .994 r
.31464 .55671 m .31249 .5556 L .31529 .55475 L F
.31464 .55671 m .31249 .5556 L .31529 .55475 L F
.83 .916 .894 r
.47118 .5405 m .47081 .54339 L .47277 .54146 L F
.932 .961 .657 r
.47118 .5405 m .46894 .54478 L .47081 .54339 L F
.893 .551 .393 r
.37832 .55654 m .37607 .5579 L .37683 .55483 L F
.37832 .55654 m .37892 .5588 L .37607 .5579 L F
.734 .623 .735 r
.50246 .44319 m .50425 .44364 L .50325 .44011 L F
.854 .752 .749 r
.50143 .44516 m .50425 .44364 L .50246 .44319 L F
.827 .509 .451 r
.50717 .4432 m .50325 .44011 L .50425 .44364 L F
.196 0 0 r
.42503 .4512 m .42834 .44934 L .426 .45044 L F
.658 .972 .861 r
.4565 .43301 m .4523 .43496 L .45553 .43299 L F
.506 .886 .697 r
.45797 .43168 m .45977 .4308 L .4565 .43301 L F
.512 .914 .851 r
.4565 .43301 m .45553 .43299 L .45797 .43168 L F
.723 .959 .682 r
.48922 .40764 m .48655 .41056 L .48767 .40849 L F
.726 .99 .849 r
.48655 .41056 m .48427 .41103 L .48767 .40849 L F
.892 .944 .837 r
.68125 .36978 m .68282 .36555 L .68072 .36935 L F
.214 0 0 r
.60382 .34936 m .59977 .35206 L .6012 .35052 L F
.893 .716 .655 r
.34349 .53873 m .34515 .54254 L .34584 .53956 L F
.532 .888 .665 r
.48922 .40764 m .48961 .40689 L .49178 .40644 L F
.48922 .40764 m .48767 .40849 L .48961 .40689 L F
.9 .794 .31 r
.56471 .37362 m .56402 .3724 L .56379 .37195 L F
.56471 .37362 m .56427 .37583 L .56402 .3724 L F
.546 .918 .759 r
.33845 .67442 m .34265 .6721 L .34048 .67372 L F
0 0 0 r
.34265 .6721 m .345 .66876 L .34385 .67094 L F
.506 .857 .602 r
.34048 .67372 m .34265 .6721 L .34385 .67094 L F
.922 .613 .44 r
.33881 .52831 m .34198 .53222 L .34228 .52969 L F
.43 .33 .64 r
.24849 .57664 m .24795 .57973 L .25155 .57824 L F
.994 .818 .561 r
.395 .51824 m .39528 .51933 L .39529 .5178 L F
.459 .272 .539 r
.39528 .51933 m .39776 .51843 L .39531 .51635 L F
.994 .818 .561 r
.39516 .51884 m .39377 .51909 L .39528 .51933 L F
.39441 .51593 m .39377 .51909 L .39516 .51884 L F
.999 .81 .509 r
.39664 .51912 m .39179 .51944 L .39377 .51909 L F
.39179 .51944 m .39172 .51944 L .39377 .51909 L F
.427 0 0 r
.39377 .51909 m .39776 .51843 L .39528 .51933 L F
.39453 .51896 m .39664 .51912 L .39776 .51843 L F
.39377 .51909 m .39444 .51909 L .39453 .51896 L F
.39444 .51909 m .39664 .51912 L .39453 .51896 L F
.994 .818 .561 r
.39441 .51593 m .395 .51824 L .39531 .51635 L F
.395 .51824 m .39529 .5178 L .39531 .51635 L F
.453 .272 .545 r
.39531 .51635 m .39533 .51494 L .39441 .51593 L F
.39531 .51635 m .39822 .51562 L .39533 .51494 L F
.39531 .51635 m .39776 .51843 L .39822 .51562 L F
.978 .898 .67 r
.31168 .68927 m .31206 .68906 L .31041 .68856 L F
.812 .947 .911 r
.31194 .68747 m .31206 .68906 L .31342 .68731 L F
.438 0 0 r
.60857 .39183 m .6097 .39063 L .61271 .39155 L F
.855 .618 .58 r
.3214 .54533 m .32479 .54271 L .32228 .54621 L F
.3214 .54533 m .32485 .54638 L .32479 .54271 L F
0 0 0 r
.32751 .53925 m .32479 .54271 L .32636 .54081 L F
.477 .315 .582 r
.32479 .54271 m .32563 .54566 L .32636 .54081 L F
.32479 .54271 m .32485 .54638 L .32563 .54566 L F
.891 .791 .744 r
.34192 .55849 m .34523 .55913 L .34593 .55662 L F
.905 .739 .666 r
.34354 .56197 m .34523 .55913 L .34192 .55849 L F
.924 .891 .779 r
.55189 .42912 m .55127 .43324 L .54999 .43285 L F
.897 .701 .629 r
.55127 .43324 m .54854 .43511 L .54999 .43285 L F
.55127 .43324 m .55088 .43656 L .54854 .43511 L F
.196 .356 .798 r
.50336 .42546 m .50353 .42679 L .50499 .42501 L F
0 0 0 r
.50499 .42501 m .50353 .42679 L .50287 .42871 L F
.709 .91 .554 r
.345 .66876 m .34745 .66506 L .3469 .66775 L F
0 0 0 r
.34385 .67094 m .345 .66876 L .3469 .66775 L F
.665 .913 .977 r
.6458 .39691 m .64931 .39662 L .64829 .39505 L F
.482 .72 .975 r
.64931 .39662 m .65116 .39455 L .64829 .39505 L F
.64931 .39662 m .6523 .39635 L .65116 .39455 L F
.88 .643 .577 r
.34909 .50964 m .34671 .50929 L .34669 .50635 L F
.84 .473 .359 r
.34909 .50964 m .34708 .51151 L .34671 .50929 L F
.821 .443 .339 r
.34909 .50964 m .35103 .51283 L .34708 .51151 L F
.817 .443 .348 r
.35335 .51282 m .35103 .51283 L .34909 .50964 L F
.003 0 0 r
.42652 .45772 m .42264 .46117 L .42404 .45893 L F
.318 0 0 r
.32228 .54621 m .3204 .54708 L .31818 .5466 L F
.242 .692 .954 r
.32228 .54621 m .3214 .54533 L .3204 .54708 L F
.32228 .54621 m .32485 .54638 L .3214 .54533 L F
.707 .788 .915 r
.30999 .6364 m .31128 .6388 L .30684 .63849 L F
.69 .78 .92 r
.3136 .63799 m .31128 .6388 L .30999 .6364 L F
.515 .895 .716 r
.32848 .58955 m .32485 .59173 L .32656 .58832 L F
.823 .877 .885 r
.33021 .58821 m .32848 .58955 L .32656 .58832 L F
.697 .528 .655 r
.5138 .42271 m .51606 .42351 L .51594 .42013 L F
.57 .455 .683 r
.51606 .42351 m .51845 .4192 L .51594 .42013 L F
0 0 .296 r
.52703 .4011 m .52577 .40015 L .52692 .39925 L F
.52703 .4011 m .52593 .40305 L .52577 .40015 L F
.604 .508 .719 r
.29283 .66573 m .29622 .66537 L .29511 .66215 L F
0 .393 .764 r
.57901 .37275 m .57904 .37236 L .57639 .36954 L F
.874 .925 .856 r
.50458 .50691 m .50581 .50267 L .50306 .50564 L F
.50458 .50691 m .50721 .5037 L .50581 .50267 L F
.893 .935 .836 r
.29578 .62169 m .30025 .61881 L .29854 .61751 L F
.192 .609 .945 r
.30089 .61779 m .30025 .61881 L .29854 .61751 L F
.29854 .61751 m .30025 .61881 L .30089 .61779 L F
.072 .24 .731 r
.56054 .38067 m .56257 .38227 L .56115 .37985 L F
.48 .221 .443 r
.56054 .38067 m .55943 .3831 L .56257 .38227 L F
.85 .755 .757 r
.27878 .65671 m .27998 .6584 L .28101 .65644 L F
.27878 .65671 m .27777 .65894 L .27575 .65645 L F
.27878 .65671 m .27765 .65776 L .27998 .6584 L F
.27878 .65671 m .27575 .65645 L .27765 .65776 L F
.534 .924 .854 r
.49775 .40261 m .4994 .40109 L .50121 .40005 L F
.49775 .40261 m .49707 .40238 L .4994 .40109 L F
.567 .023 0 r
.60235 .34331 m .60511 .34496 L .60643 .34387 L F
.521 0 0 r
.60643 .34387 m .60511 .34496 L .60923 .34532 L F
.695 .545 .68 r
.27777 .65894 m .27846 .66194 L .27491 .66276 L F
.456 .392 .697 r
.27998 .6584 m .27846 .66194 L .27777 .65894 L F
.967 .758 .569 r
.66478 .3505 m .66252 .35184 L .66261 .3492 L F
.66478 .3505 m .66427 .35354 L .66252 .35184 L F
.671 .721 .887 r
.53199 .46348 m .52919 .46581 L .52792 .46295 L F
.456 .098 .267 r
.27183 .5282 m .27568 .52582 L .27296 .52621 L F
.788 .87 .435 r
.53991 .45267 m .53847 .45623 L .54005 .45539 L F
.653 .475 .631 r
.53847 .45623 m .54146 .45935 L .54005 .45539 L F
.53847 .45623 m .53864 .46056 L .54146 .45935 L F
.36 0 0 r
.42713 .45668 m .42829 .45831 L .42652 .45772 L F
.42713 .45668 m .43002 .45664 L .42829 .45831 L F
.961 .672 .244 r
.43127 .59171 m .43285 .59582 L .43194 .5918 L F
.895 .615 .506 r
.33653 .52476 m .3391 .52278 L .33651 .52225 L F
.33653 .52476 m .33924 .52575 L .3391 .52278 L F
0 .295 .773 r
.65626 .36466 m .65767 .36658 L .65811 .36673 L F
.65767 .36658 m .65795 .36696 L .65811 .36673 L F
.248 0 0 r
.65719 .36641 m .65811 .36673 L .65969 .36675 L F
.6557 .36621 m .65811 .36673 L .65719 .36641 L F
.982 .888 .655 r
.65969 .36675 m .65811 .36673 L .65922 .36297 L F
.754 .691 .791 r
.34187 .59165 m .34594 .59237 L .34432 .58864 L F
.047 .466 .882 r
.59464 .36812 m .59776 .36942 L .59792 .37024 L F
.898 .896 .818 r
.59448 .37214 m .59792 .37024 L .59776 .36942 L F
.675 .882 .975 r
.46046 .55127 m .45665 .55128 L .4581 .5517 L F
.857 .649 .621 r
.6809 .34222 m .68265 .34635 L .68261 .34368 L F
.136 .635 .909 r
.4158 .59204 m .4197 .59327 L .41537 .59265 L F
.753 .805 .895 r
.29404 .67242 m .29801 .67207 L .29578 .67071 L F
0 .309 .762 r
.29404 .67242 m .29753 .6748 L .29801 .67207 L F
0 0 0 r
.6378 .34649 m .6338 .34739 L .63496 .34671 L F
.49 .303 .554 r
.51175 .47978 m .5144 .4791 L .51435 .47635 L F
.51175 .47978 m .5144 .4791 L .51435 .47635 L F
.399 .579 .912 r
.67248 .31417 m .67428 .31172 L .67188 .31148 L F
.67248 .31417 m .67493 .31426 L .67428 .31172 L F
0 0 0 r
.3103 .66571 m .30582 .66814 L .30858 .66473 L F
.839 .859 .859 r
.326 .56138 m .32768 .55888 L .32484 .56188 L F
.784 .71 .781 r
.32391 .55929 m .32484 .56188 L .32768 .55888 L F
.661 .207 .164 r
.32768 .55888 m .33004 .56102 L .3265 .55938 L F
.792 .549 .569 r
.32989 .56377 m .32718 .56026 L .33004 .56102 L F
.32702 .56005 m .3265 .55938 L .32733 .55977 L F
.932 .937 .779 r
.32695 .55921 m .32666 .55961 L .32819 .55896 L F
.32695 .55921 m .32819 .55896 L .32824 .5589 L F
.038 0 0 r
.32676 .56031 m .32484 .56188 L .3265 .55938 L F
.792 .549 .569 r
.32989 .56377 m .32713 .56165 L .32676 .56031 L F
.32702 .56005 m .32672 .56017 L .3265 .55938 L F
.932 .937 .779 r
.32666 .55961 m .3261 .5604 L .32699 .55982 L F
.32711 .55957 m .32699 .55982 L .3274 .55955 L F
.32666 .55961 m .32699 .55982 L .32711 .55957 L F
.32666 .55961 m .3274 .55955 L .32845 .55885 L F
.679 .148 0 r
.32919 .5594 m .32833 .55947 L .32768 .55888 L F
.759 .521 .573 r
.32349 .55553 m .32391 .55929 L .32768 .55888 L F
.932 .937 .779 r
.32695 .55921 m .32845 .55885 L .32768 .55888 L F
.765 .992 .782 r
.3285 .55872 m .32613 .5604 L .32902 .55734 L F
.932 .937 .779 r
.3261 .5604 m .32608 .56043 L .32614 .56039 L F
.765 .992 .782 r
.32613 .5604 m .32608 .56043 L .3261 .56041 L F
.32613 .5604 m .3261 .56041 L .32902 .55734 L F
.792 .549 .569 r
.32718 .56026 m .32676 .56031 L .32672 .56017 L F
.32718 .56026 m .32672 .56017 L .32702 .56005 L F
.32989 .56377 m .32676 .56031 L .32718 .56026 L F
.932 .937 .779 r
.3261 .5604 m .32614 .56039 L .32699 .55982 L F
.038 0 0 r
.32713 .56165 m .32608 .56176 L .32676 .56031 L F
.32608 .56176 m .32484 .56188 L .32676 .56031 L F
.932 .937 .779 r
.32824 .5589 m .32819 .55896 L .32845 .55885 L F
.765 .992 .782 r
.32845 .55885 m .32809 .55909 L .3285 .55872 L F
.32809 .55909 m .32608 .56043 L .3285 .55872 L F
.792 .549 .569 r
.32718 .56026 m .32702 .56005 L .3275 .55985 L F
.32702 .56005 m .32733 .55977 L .3275 .55985 L F
.32718 .56026 m .3275 .55985 L .33004 .56102 L F
.679 .148 0 r
.3317 .56027 m .33004 .56102 L .32833 .55947 L F
.3317 .56027 m .32833 .55947 L .32919 .5594 L F
.515 0 0 r
.33394 .56149 m .33004 .56102 L .3317 .56027 L F
.551 .292 .476 r
.4391 .54262 m .44171 .54516 L .4421 .54307 L F
.4391 .54262 m .43889 .54581 L .44171 .54516 L F
.02 0 0 r
.64227 .33857 m .6459 .33657 L .64311 .33707 L F
.711 .68 .819 r
.32586 .61228 m .33004 .61276 L .32875 .60902 L F
.891 .791 .744 r
.34192 .55849 m .34593 .55662 L .34383 .55516 L F
.796 .777 .836 r
.30587 .60787 m .30811 .60901 L .30404 .60843 L F
.826 .713 .74 r
.30404 .60843 m .30811 .60901 L .30572 .61272 L F
.731 .791 .9 r
.31088 .60642 m .30811 .60901 L .30587 .60787 L F
.469 .25 .498 r
.31314 .5695 m .31574 .56892 L .31546 .56589 L F
.399 .493 .839 r
.31546 .56589 m .31398 .56183 L .31599 .56299 L F
.31546 .56589 m .31661 .56183 L .31398 .56183 L F
.404 .204 .492 r
.31546 .56589 m .31574 .56892 L .31803 .56803 L F
.828 .9 .89 r
.594 .38402 m .59586 .386 L .59827 .3826 L F
0 0 .276 r
.59644 .38723 m .59676 .3883 L .59586 .386 L F
.67 .285 .306 r
.40931 .47217 m .40547 .47034 L .40946 .46974 L F
.67 .436 .558 r
.41226 .46944 m .40931 .47217 L .40946 .46974 L F
.401 .828 .668 r
.46209 .42943 m .45977 .4308 L .45797 .43168 L F
.423 .199 .467 r
.44597 .54284 m .44849 .54231 L .44869 .53956 L F
.541 .42 .664 r
.25543 .54005 m .25778 .53958 L .2572 .53577 L F
.314 .165 .513 r
.25576 .5426 m .25778 .53958 L .25543 .54005 L F
.15 .261 .724 r
.2474 .57227 m .24849 .57664 L .24982 .57437 L F
.43 .33 .64 r
.24849 .57664 m .25155 .57824 L .24982 .57437 L F
.941 .936 .589 r
.54076 .44825 m .5411 .45031 L .53991 .45267 L F
.939 .952 .634 r
.54176 .44874 m .5411 .45031 L .54076 .44825 L F
.941 .936 .589 r
.54076 .44825 m .53991 .45267 L .54258 .45197 L F
.881 .507 .032 r
.54015 .44796 m .54076 .44825 L .54138 .45045 L F
.53949 .44661 m .54076 .44825 L .54015 .44796 L F
.939 .952 .634 r
.54262 .4467 m .54176 .44874 L .54076 .44825 L F
.817 .861 .88 r
.33565 .62927 m .33686 .63172 L .33463 .63311 L F
.691 .806 .936 r
.33981 .62949 m .33686 .63172 L .33565 .62927 L F
.741 .781 .886 r
.32505 .53584 m .32674 .53919 L .32479 .53631 L F
.32479 .53631 m .32674 .53919 L .32333 .53894 L F
.734 .772 .883 r
.32568 .53763 m .32333 .53894 L .32505 .53584 L F
.74 .775 .882 r
.32505 .53584 m .32568 .53763 L .32429 .53556 L F
0 0 .412 r
.32568 .53763 m .32525 .53694 L .32429 .53557 L F
.32462 .53605 m .32429 .53557 L .32429 .53556 L F
.32568 .53763 m .32429 .53557 L .32462 .53605 L F
.741 .781 .886 r
.32505 .53584 m .32751 .53925 L .32674 .53919 L F
0 0 0 r
.32751 .53925 m .32636 .54081 L .32333 .53894 L F
.783 .793 .861 r
.33086 .53641 m .32751 .53925 L .32505 .53584 L F
0 0 .536 r
.49262 .4393 m .49316 .44374 L .49436 .44166 L F
.191 .399 .836 r
.49316 .44374 m .49617 .44543 L .49436 .44166 L F
.328 .265 .633 r
.2635 .62582 m .26483 .62988 L .26586 .62809 L F
.78 .447 .425 r
.66261 .34359 m .66059 .34566 L .6589 .34293 L F
.861 .574 .502 r
.66287 .34621 m .66059 .34566 L .66261 .34359 L F
.897 .872 .435 r
.50208 .44233 m .50246 .44319 L .50325 .44011 L F
.891 .925 .537 r
.50143 .44516 m .50246 .44319 L .50208 .44233 L F
.532 .584 .852 r
.31597 .60172 m .31424 .60312 L .31427 .59852 L F
.92 .891 .785 r
.31427 .59852 m .31424 .60312 L .31206 .60205 L F
.979 .753 .525 r
.31206 .60205 m .31424 .60312 L .31334 .6052 L F
.8 .704 .759 r
.31597 .60172 m .31334 .6052 L .31424 .60312 L F
.866 .958 .863 r
.54247 .47086 m .54222 .4738 L .54499 .47088 L F
.87 .96 .859 r
.54247 .47086 m .53935 .47428 L .54222 .4738 L F
.613 .061 0 r
.60798 .35296 m .60451 .35209 L .60523 .35368 L F
.73 .579 .686 r
.47068 .52677 m .46669 .52932 L .46912 .52575 L F
.47068 .52677 m .46734 .52982 L .46669 .52932 L F
.891 .914 .833 r
.47319 .52332 m .47068 .52677 L .46912 .52575 L F
.836 .857 .86 r
.44105 .58909 m .44486 .58899 L .44356 .58803 L F
.876 .984 .832 r
.44356 .58803 m .44486 .58899 L .44756 .58548 L F
.283 .754 .939 r
.54159 .34569 m .54283 .34521 L .54388 .34328 L F
.54159 .34569 m .53977 .34501 L .54283 .34521 L F
.596 .926 .706 r
.4646 .43913 m .46588 .43759 L .46392 .43923 L F
.4646 .43913 m .46774 .43663 L .46588 .43759 L F
0 0 0 r
.32694 .58291 m .32431 .5858 L .32578 .58498 L F
0 0 .495 r
.3255 .57896 m .32694 .58291 L .32683 .58112 L F
.883 .87 .428 r
.32694 .58291 m .32637 .58235 L .32683 .58112 L F
.32694 .58291 m .32578 .58498 L .32637 .58235 L F
0 0 .403 r
.40056 .5246 m .40235 .52828 L .40147 .52597 L F
.142 0 0 r
.24998 .55766 m .25419 .55565 L .25167 .55562 L F
.755 .315 .206 r
.35335 .51282 m .35146 .51446 L .35103 .51283 L F
.886 .518 .339 r
.35375 .51492 m .35146 .51446 L .35335 .51282 L F
.726 .687 .813 r
.2978 .63989 m .29506 .64285 L .29316 .63985 L F
.736 .704 .821 r
.2978 .63989 m .29767 .64184 L .29506 .64285 L F
.932 .738 .618 r
.29561 .60208 m .29654 .59974 L .29399 .59822 L F
.979 .68 .338 r
.27114 .65754 m .27334 .65923 L .27305 .66243 L F
.799 .924 .92 r
.27575 .65645 m .27114 .65754 L .27338 .65524 L F
.463 0 0 r
.27765 .65776 m .27575 .65645 L .27338 .65524 L F
.27765 .65776 m .27347 .65529 L .27609 .65667 L F
.27347 .65529 m .27338 .65524 L .27343 .65527 L F
.27347 .65529 m .27343 .65527 L .27609 .65667 L F
.799 .924 .92 r
.27531 .65655 m .27334 .65923 L .27114 .65754 L F
.27575 .65645 m .27553 .6567 L .27531 .65655 L F
.27553 .6567 m .27334 .65923 L .27531 .65655 L F
.708 .947 .956 r
.54357 .44452 m .54443 .4458 L .54262 .4467 L F
.768 .955 .636 r
.54357 .44452 m .54262 .4467 L .54076 .44825 L F
.951 .823 .383 r
.26483 .62988 m .26491 .63274 L .2631 .63151 L F
.852 .996 .766 r
.26586 .62809 m .26483 .62988 L .2631 .63151 L F
0 0 0 r
.26491 .63274 m .26586 .62809 L .2631 .63151 L F
.974 .709 .466 r
.67432 .30607 m .67416 .30882 L .67599 .30961 L F
.861 .567 .491 r
.67416 .30882 m .6777 .31221 L .67599 .30961 L F
.57 .939 .835 r
.46821 .42535 m .46928 .42394 L .47188 .42372 L F
.46821 .42535 m .46737 .42528 L .46928 .42394 L F
.119 0 0 r
.52961 .38701 m .52854 .38853 L .5256 .38939 L F
0 0 0 r
.52961 .38701 m .52984 .38677 L .52806 .38549 L F
.52961 .38701 m .52854 .38853 L .52984 .38677 L F
.266 0 0 r
.41576 .45545 m .4184 .45483 L .4192 .45338 L F
.091 0 0 r
.4184 .45483 m .4224 .45242 L .4192 .45338 L F
.78 .983 .725 r
.59477 .35858 m .59255 .36133 L .59367 .36083 L F
.617 .145 .11 r
.32896 .54648 m .32674 .54779 L .32485 .54638 L F
.732 .303 .232 r
.32896 .54648 m .33035 .54842 L .32674 .54779 L F
.798 .549 .561 r
.39865 .46976 m .39894 .47267 L .39443 .47206 L F
.57 .381 .586 r
.40233 .47165 m .39894 .47267 L .39865 .46976 L F
.506 .267 .485 r
.44849 .54231 m .45132 .54155 L .44869 .53956 L F
.463 .279 .544 r
.44869 .53956 m .45132 .54155 L .45122 .53877 L F
.44869 .53956 m .45132 .54155 L .45122 .53877 L F
.744 .709 .819 r
.32312 .63443 m .32488 .63642 L .32081 .63601 L F
.715 .704 .838 r
.32726 .63521 m .32488 .63642 L .32312 .63443 L F
.198 .328 .771 r
.57577 .38462 m .57438 .38686 L .57298 .38277 L F
.396 .592 .923 r
.57577 .38462 m .57638 .38697 L .57438 .38686 L F
0 0 .371 r
.57771 .38925 m .57438 .38686 L .57638 .38697 L F
0 0 0 r
.51219 .43852 m .51301 .43699 L .51018 .44028 L F
0 0 .002 r
.51499 .43556 m .51301 .43699 L .51219 .43852 L F
.314 .165 .513 r
.25576 .5426 m .25795 .54197 L .25778 .53958 L F
.334 .22 .571 r
.25576 .5426 m .25783 .54482 L .25795 .54197 L F
.434 .231 .504 r
.25548 .54549 m .25783 .54482 L .25576 .5426 L F
.826 1 .802 r
.27228 .64927 m .27533 .64607 L .27253 .64723 L F
.705 .981 .801 r
.27528 .64539 m .27533 .64607 L .27707 .6442 L F
.27253 .64723 m .27351 .64683 L .27528 .64539 L F
.27351 .64683 m .27533 .64607 L .27528 .64539 L F
.27253 .64723 m .27707 .6442 L .27667 .6444 L F
.27253 .64723 m .27726 .644 L .27616 .64447 L F
.602 .132 .109 r
.27609 .64474 m .27785 .64686 L .27537 .6474 L F
.27616 .64447 m .27626 .64461 L .27609 .64474 L F
.27626 .64461 m .27785 .64686 L .27609 .64474 L F
.27626 .64461 m .27894 .64474 L .27785 .64686 L F
.27616 .64447 m .27646 .6445 L .27626 .64461 L F
.27646 .6445 m .27894 .64474 L .27626 .64461 L F
.705 .981 .801 r
.27667 .6444 m .27707 .6442 L .27726 .644 L F
.855 .846 .833 r
.29393 .61988 m .28961 .62192 L .29177 .61841 L F
.807 .892 .904 r
.29595 .61777 m .29393 .61988 L .29177 .61841 L F
.631 .963 .878 r
.62306 .3679 m .61906 .37004 L .62045 .36817 L F
.37 0 .177 r
.62306 .3679 m .62144 .37025 L .61906 .37004 L F
.166 0 0 r
.62045 .36817 m .62397 .36547 L .62306 .3679 L F
.753 .424 .428 r
.62545 .36947 m .62144 .37025 L .62306 .3679 L F
.654 .199 .159 r
.51 .44535 m .50717 .4432 L .50778 .44666 L F
.905 .575 .41 r
.54949 .41555 m .55243 .41677 L .55268 .41871 L F
.81 .783 .828 r
.43007 .59661 m .43285 .59582 L .43163 .59408 L F
.762 .784 .871 r
.43285 .59582 m .43401 .59106 L .43127 .59171 L F
.43285 .59582 m .43625 .59235 L .43401 .59106 L F
.927 .787 .686 r
.43163 .59408 m .43285 .59582 L .43127 .59171 L F
0 0 0 r
.32097 .58893 m .3195 .59037 L .32111 .58867 L F
.988 .738 .458 r
.57916 .42589 m .57937 .42322 L .5778 .4222 L F
.57916 .42589 m .57937 .42322 L .5778 .4222 L F
.879 .614 .535 r
.3763 .54269 m .37317 .54215 L .37333 .53889 L F
.9 .751 .687 r
.3763 .54269 m .37245 .5449 L .37317 .54215 L F
.3763 .54269 m .37475 .54615 L .37245 .5449 L F
0 0 .102 r
.57107 .3569 m .57224 .35462 L .57254 .35204 L F
0 0 .429 r
.57107 .3569 m .57294 .35723 L .57224 .35462 L F
.57107 .3569 m .57144 .3594 L .57294 .35723 L F
.966 .887 .701 r
.51262 .48106 m .51141 .48227 L .5144 .4791 L F
.014 0 0 r
.42224 .59522 m .41772 .59745 L .42066 .59648 L F
.003 0 .089 r
.42224 .59522 m .41933 .59885 L .42066 .59648 L F
.673 .588 .752 r
.30019 .63859 m .29767 .64184 L .2978 .63989 L F
.30019 .63859 m .30203 .64284 L .29767 .64184 L F
.973 .726 .501 r
.60809 .34964 m .60798 .35296 L .60641 .34882 L F
.49 .304 .555 r
.61071 .35214 m .60798 .35296 L .60809 .34964 L F
.944 .904 .754 r
.56569 .43212 m .56557 .42909 L .5628 .43229 L F
.875 .766 .738 r
.5628 .43229 m .56404 .43626 L .56569 .43212 L F
.955 .752 .59 r
.34237 .55146 m .34468 .54962 L .3429 .54861 L F
.34237 .55146 m .34421 .55252 L .34468 .54962 L F
.589 .92 .697 r
.46915 .435 m .46774 .43663 L .46938 .43502 L F
.59 .923 .705 r
.46588 .43759 m .46774 .43663 L .46915 .435 L F
.823 .997 .847 r
.52004 .4918 m .52392 .48946 L .52255 .4883 L F
.81 .934 .913 r
.52722 .48655 m .52255 .4883 L .52392 .48946 L F
.5 .489 .776 r
.25396 .55025 m .25711 .55229 L .25559 .54793 L F
.803 .738 .792 r
.53613 .46337 m .53199 .46348 L .53467 .46219 L F
.824 .879 .885 r
.53864 .46056 m .53613 .46337 L .53467 .46219 L F
.121 .29 .763 r
.57381 .37771 m .57271 .38016 L .57123 .37619 L F
.283 0 0 r
.27491 .66276 m .27789 .66286 L .27552 .66433 L F
.527 0 0 r
.27552 .66433 m .27789 .66286 L .27974 .66416 L F
.283 0 0 r
.27491 .66276 m .27552 .66433 L .27391 .66309 L F
.2733 .66248 m .27391 .66309 L .27305 .66243 L F
.27491 .66276 m .27391 .66309 L .2733 .66248 L F
.979 .68 .338 r
.27114 .65754 m .27305 .66243 L .27149 .65992 L F
0 .123 .668 r
.27149 .65992 m .27305 .66243 L .27552 .66433 L F
.813 .905 .905 r
.27974 .66416 m .27703 .66693 L .27552 .66433 L F
.487 .078 .191 r
.27491 .66276 m .27846 .66194 L .27789 .66286 L F
.456 .392 .697 r
.27998 .6584 m .28014 .66208 L .27846 .66194 L F
.425 .041 .204 r
.27846 .66194 m .27974 .66416 L .27789 .66286 L F
.27846 .66194 m .28014 .66208 L .27974 .66416 L F
.527 0 0 r
.27552 .66433 m .27974 .66416 L .27795 .66038 L F
.813 .905 .905 r
.27974 .66416 m .27552 .66433 L .27767 .66193 L F
0 .123 .668 r
.27149 .65992 m .27552 .66433 L .27391 .65966 L F
.794 .575 .605 r
.27552 .66433 m .27795 .66038 L .27391 .65966 L F
.941 .959 .742 r
.27539 .66312 m .27552 .66433 L .27431 .66672 L F
.27539 .66312 m .27505 .66425 L .27585 .66492 L F
.686 .855 .963 r
.27552 .66433 m .27447 .66797 L .27431 .66672 L F
.27552 .66433 m .27703 .66693 L .27447 .66797 L F
.941 .959 .742 r
.27505 .66425 m .27431 .66672 L .27578 .66499 L F
.27505 .66425 m .27578 .66499 L .27585 .66492 L F
.217 0 0 r
.64864 .3362 m .65148 .33572 L .65278 .33401 L F
.144 0 0 r
.65278 .33401 m .65512 .33403 L .65552 .33315 L F
.65278 .33401 m .65148 .33572 L .65512 .33403 L F
.988 .716 .394 r
.27077 .64563 m .27228 .64927 L .27029 .64871 L F
.701 .945 .959 r
.27029 .64871 m .27228 .64927 L .27253 .64723 L F
0 0 0 r
.40547 .47034 m .40388 .47123 L .40233 .47165 L F
.506 0 0 r
.40547 .47034 m .40609 .47108 L .40388 .47123 L F
.40552 .47038 m .40814 .47277 L .40609 .47108 L F
.67 .285 .306 r
.40931 .47217 m .40814 .47277 L .40547 .47034 L F
.356 0 0 r
.40931 .47217 m .4089 .47365 L .40814 .47277 L F
.558 .038 0 r
.40814 .47277 m .4089 .47365 L .40609 .47108 L F
.495 .586 .875 r
.40628 .47126 m .40881 .47017 L .40609 .47108 L F
.4089 .47365 m .40881 .47017 L .40628 .47126 L F
.67 .436 .558 r
.41226 .46944 m .41221 .47218 L .40931 .47217 L F
.595 .645 .87 r
.40881 .47017 m .41294 .47031 L .41154 .4688 L F
0 0 0 r
.41049 .46945 m .40881 .47017 L .41154 .4688 L F
.819 .477 .408 r
.41221 .47218 m .4089 .47365 L .40931 .47217 L F
.41221 .47218 m .41206 .47407 L .4089 .47365 L F
.41206 .47407 m .41203 .47436 L .4118 .4743 L F
.41206 .47407 m .4118 .4743 L .4089 .47365 L F
.473 .839 .59 r
.41076 .4754 m .41132 .47481 L .41091 .47511 L F
.41089 .47513 m .41091 .47511 L .41089 .47512 L F
.41076 .4754 m .41091 .47511 L .41089 .47513 L F
.495 .586 .875 r
.4089 .47365 m .41089 .47512 L .41064 .47452 L F
.688 .177 .018 r
.4118 .4743 m .41132 .47481 L .4089 .47365 L F
.595 .645 .87 r
.41064 .47452 m .41089 .47512 L .41132 .47481 L F
.688 .177 .018 r
.41132 .47481 m .41129 .47484 L .41064 .47452 L F
.41132 .47481 m .41064 .47452 L .4089 .47365 L F
.4 .687 .977 r
.41294 .47031 m .41361 .47179 L .41221 .47218 L F
.227 0 .319 r
.41221 .47218 m .41361 .47179 L .41203 .47436 L F
.63 .441 .608 r
.41361 .47179 m .41522 .4744 L .41203 .47436 L F
.595 .645 .87 r
.40881 .47017 m .41064 .47452 L .41408 .47278 L F
.41064 .47452 m .41132 .47481 L .41408 .47278 L F
.495 .586 .875 r
.4089 .47365 m .41064 .47452 L .40881 .47017 L F
.617 .062 0 r
.4089 .47365 m .41076 .4754 L .41089 .47512 L F
.688 .177 .018 r
.41129 .47484 m .41076 .4754 L .4089 .47365 L F
.41203 .47436 m .41076 .4754 L .4118 .4743 L F
.473 .839 .59 r
.41076 .4754 m .41408 .47278 L .41132 .47481 L F
.644 .218 0 r
.41408 .47278 m .41361 .47179 L .41294 .47031 L F
.595 .645 .87 r
.40881 .47017 m .41408 .47278 L .41294 .47031 L F
0 0 0 r
.40722 .47144 m .40881 .47017 L .41049 .46945 L F
.012 0 0 r
.40609 .47108 m .40722 .47144 L .40644 .47152 L F
.754 .502 .551 r
.40528 .47487 m .40233 .47165 L .40388 .47123 L F
.40528 .47487 m .40134 .47491 L .40233 .47165 L F
.993 .744 .412 r
.40397 .47406 m .40528 .47487 L .40508 .47437 L F
.40397 .47406 m .40508 .47437 L .40388 .47123 L F
.8 .991 .88 r
.40231 .47359 m .40397 .47406 L .40455 .47172 L F
.742 .339 .287 r
.39443 .47206 m .39894 .47267 L .39817 .47444 L F
.696 .441 .533 r
.40233 .47165 m .39817 .47444 L .39894 .47267 L F
.40233 .47165 m .40134 .47491 L .39817 .47444 L F
.506 .825 1 r
.39742 .47346 m .40134 .47491 L .40397 .47406 L F
.39742 .47346 m .40284 .47395 L .40158 .47419 L F
.40284 .47395 m .40397 .47406 L .40158 .47419 L F
.667 .179 .08 r
.40158 .47419 m .39842 .47359 L .39742 .47346 L F
.226 .691 .946 r
.39817 .47444 m .40134 .47491 L .39742 .47346 L F
.667 .179 .08 r
.40158 .47419 m .40002 .47492 L .39842 .47359 L F
.616 .294 .402 r
.40455 .47172 m .40086 .47433 L .40158 .47419 L F
.40086 .47433 m .40002 .47492 L .40158 .47419 L F
.8 .991 .88 r
.40158 .47419 m .40397 .47406 L .40231 .47359 L F
.839 .992 .737 r
.40397 .47406 m .40609 .47108 L .40455 .47172 L F
.012 0 0 r
.40609 .47108 m .40644 .47152 L .40455 .47172 L F
.506 0 0 r
.40547 .47034 m .40552 .47038 L .40609 .47108 L F
.816 .343 0 r
.41681 .5528 m .41826 .55253 L .41622 .55278 L F
.41681 .5528 m .42014 .55537 L .41826 .55253 L F
.828 .506 .445 r
.37772 .54949 m .37427 .5513 L .37384 .54859 L F
.37772 .54949 m .37814 .55209 L .37427 .5513 L F
.691 .98 .888 r
.4432 .55168 m .44749 .54956 L .44512 .55269 L F
.4432 .55168 m .44611 .54958 L .44749 .54956 L F
0 0 0 r
.44749 .54956 m .44919 .54842 L .45037 .54695 L F
.44788 .54947 m .44749 .54956 L .44611 .54958 L F
.44788 .54947 m .44919 .54842 L .44749 .54956 L F
.654 .316 .388 r
.25564 .57557 m .25577 .5784 L .25155 .57824 L F
.221 .028 .393 r
.25843 .5707 m .25724 .5756 L .25564 .57557 L F
.477 .183 .387 r
.25745 .57761 m .25564 .57557 L .25724 .5756 L F
.25745 .57761 m .25577 .5784 L .25564 .57557 L F
.022 0 0 r
.32385 .68211 m .32761 .67979 L .32445 .6823 L F
.194 0 0 r
.32761 .67979 m .33012 .67923 L .32988 .67916 L F
.278 0 .062 r
.32445 .6823 m .32761 .67979 L .32988 .67916 L F
.943 .744 .605 r
.39592 .53295 m .39544 .53573 L .39389 .53183 L F
.438 .259 .54 r
.54421 .45601 m .54426 .45313 L .54258 .45197 L F
.976 .721 .481 r
.54426 .45313 m .54421 .45601 L .54258 .45197 L F
.785 .999 .822 r
.54499 .47088 m .54583 .4687 L .54247 .47086 L F
.54499 .47088 m .54674 .46893 L .54583 .4687 L F
.859 .502 .374 r
.44637 .5789 m .45018 .5821 L .45073 .5794 L F
.564 .883 .609 r
.50121 .40005 m .50284 .39825 L .50309 .39825 L F
.58 .913 .682 r
.50121 .40005 m .4994 .40109 L .50284 .39825 L F
.532 .347 .575 r
.54671 .39017 m .55001 .38624 L .54543 .38567 L F
.54671 .39017 m .55028 .38959 L .55001 .38624 L F
.516 .294 .516 r
.55028 .38959 m .54724 .39252 L .54671 .39017 L F
.396 .698 .982 r
.56427 .40264 m .56642 .4022 L .56483 .40062 L F
.284 .015 .318 r
.56427 .40264 m .56356 .4054 L .56642 .4022 L F
.717 .986 .881 r
.64498 .3794 m .6428 .38119 L .64112 .38043 L F
.267 .133 .506 r
.51435 .47635 m .51629 .47772 L .51704 .47566 L F
.51435 .47635 m .5144 .4791 L .51629 .47772 L F
.51435 .47635 m .51629 .47772 L .51704 .47566 L F
.51435 .47635 m .5144 .4791 L .51629 .47772 L F
0 0 0 r
.28666 .53183 m .28377 .53543 L .28855 .53311 L F
.947 .874 .733 r
.28851 .52807 m .28666 .53183 L .28855 .53311 L F
.646 .239 .258 r
.29511 .66215 m .29745 .66435 L .29892 .66206 L F
.519 .325 .558 r
.29892 .66206 m .3018 .66168 L .3019 .65889 L F
.386 0 .124 r
.29745 .66435 m .3018 .66168 L .29892 .66206 L F
.752 .727 .829 r
.33532 .60616 m .33615 .60137 L .3335 .6045 L F
.33532 .60616 m .33756 .60462 L .33615 .60137 L F
.589 .855 .994 r
.30443 .61603 m .30527 .61726 L .30713 .61636 L F
.956 .88 .719 r
.30375 .61587 m .30271 .61829 L .30691 .61916 L F
.547 .012 0 r
.30375 .61587 m .30089 .61779 L .301 .6148 L F
.30375 .61587 m .30341 .6159 L .30089 .61779 L F
.30375 .61587 m .30527 .61726 L .30341 .6159 L F
.589 .855 .994 r
.30341 .6159 m .30527 .61726 L .30443 .61603 L F
.956 .88 .719 r
.30375 .61587 m .30572 .61793 L .30527 .61726 L F
.30572 .61793 m .30691 .61916 L .30527 .61726 L F
.769 .868 .921 r
.30691 .61916 m .30713 .61636 L .30527 .61726 L F
.30691 .61916 m .30935 .61774 L .30713 .61636 L F
0 0 0 r
.65137 .34365 m .65022 .3442 L .64716 .34485 L F
.519 0 0 r
.65426 .34353 m .65022 .3442 L .65137 .34365 L F
.876 .984 .83 r
.5475 .44187 m .54443 .4458 L .54357 .44452 L F
.373 .263 .598 r
.24601 .56287 m .24819 .56234 L .2482 .55854 L F
.412 .413 .75 r
.24601 .56287 m .24889 .56484 L .24819 .56234 L F
.444 .411 .727 r
.24601 .56287 m .24692 .56594 L .24889 .56484 L F
.817 .861 .88 r
.33565 .62927 m .33463 .63311 L .33249 .63134 L F
.663 .885 .979 r
.28966 .65536 m .28755 .65685 L .28646 .65582 L F
.917 .71 .608 r
.33609 .56266 m .33364 .56453 L .33394 .56149 L F
.33609 .56266 m .33566 .56543 L .33364 .56453 L F
.669 .801 .348 r
.50208 .44233 m .50325 .44011 L .50423 .43795 L F
.488 .023 .077 r
.51265 .42429 m .5138 .42271 L .50961 .42317 L F
.71 .3 .268 r
.51384 .42424 m .5138 .42271 L .51265 .42429 L F
.51384 .42424 m .51606 .42351 L .5138 .42271 L F
.397 0 0 r
.60923 .34532 m .6121 .34549 L .61329 .34453 L F
.355 0 0 r
.61329 .34453 m .6121 .34549 L .61603 .34518 L F
0 0 .443 r
.51018 .44028 m .51166 .44115 L .51219 .43852 L F
.533 .14 .242 r
.66219 .33044 m .66492 .33196 L .66603 .32963 L F
.633 .245 .29 r
.66603 .32963 m .66914 .33193 L .66888 .33 L F
.66603 .32963 m .66492 .33196 L .66914 .33193 L F
.853 .998 .798 r
.50704 .48754 m .5078 .48483 L .50906 .48585 L F
.50704 .48754 m .50505 .48812 L .5078 .48483 L F
.858 .913 .869 r
.47118 .5405 m .47277 .54146 L .47534 .53831 L F
.664 .748 .913 r
.41441 .5883 m .41783 .58895 L .41645 .5881 L F
.207 .701 .919 r
.42061 .58869 m .41645 .5881 L .41783 .58895 L F
0 0 .126 r
.49636 .44986 m .49643 .45064 L .49617 .44543 L F
.091 0 0 r
.4184 .45483 m .42104 .45398 L .4224 .45242 L F
.105 0 0 r
.42104 .45398 m .42503 .4512 L .4224 .45242 L F
.781 .746 .821 r
.56912 .39854 m .57271 .39911 L .57169 .39542 L F
.359 0 0 r
.57216 .39962 m .57271 .39911 L .56912 .39854 L F
.795 .754 .815 r
.57169 .39542 m .57271 .39911 L .57362 .39694 L F
0 0 .455 r
.57472 .39993 m .57376 .40233 L .57271 .39911 L F
.57472 .39993 m .57271 .39911 L .57216 .39962 L F
.133 .361 .82 r
.57643 .36674 m .57682 .36521 L .57351 .36294 L F
.066 .283 .771 r
.57643 .36674 m .57727 .36467 L .57682 .36521 L F
0 0 .342 r
.57643 .36674 m .57823 .3672 L .57727 .36467 L F
.57643 .36674 m .57639 .36954 L .57823 .3672 L F
.634 .096 0 r
.35959 .49674 m .35777 .49757 L .36255 .49833 L F
.913 .683 .576 r
.67766 .33863 m .6809 .34222 L .68113 .34025 L F
.849 .993 .84 r
.59037 .3994 m .58617 .40236 L .58603 .39913 L F
.669 .405 .513 r
.3112 .53127 m .31387 .52913 L .31126 .52934 L F
.3112 .53127 m .31492 .53126 L .31387 .52913 L F
.863 .916 .865 r
.5072 .50091 m .50721 .5037 L .50879 .50205 L F
.877 .925 .852 r
.50581 .50267 m .50721 .5037 L .5072 .50091 L F
.574 .156 .211 r
.32266 .50818 m .3254 .50839 L .32711 .50619 L F
.725 .337 .315 r
.32711 .50619 m .3254 .50839 L .32928 .50871 L F
.916 .747 .657 r
.55621 .45144 m .5576 .45302 L .55617 .44907 L F
.931 .737 .62 r
.5572 .45567 m .5576 .45302 L .55621 .45144 L F
0 0 .169 r
.50961 .42201 m .50961 .42317 L .50933 .42057 L F
.137 .436 .873 r
.51265 .42429 m .50961 .42317 L .50961 .42201 L F
.891 .914 .833 r
.47319 .52332 m .46912 .52575 L .47122 .5219 L F
.79 .77 .835 r
.4757 .52016 m .47319 .52332 L .47122 .5219 L F
.555 .458 .699 r
.24697 .57071 m .24889 .56484 L .24692 .56594 L F
.554 .923 .769 r
.50795 .41523 m .51134 .41355 L .51315 .41218 L F
0 0 0 r
.31938 .68433 m .32385 .68211 L .32382 .68299 L F
.031 0 .044 r
.32382 .68299 m .32385 .68211 L .32445 .6823 L F
.384 .371 .721 r
.62144 .37025 m .62169 .37167 L .61906 .37004 L F
.19 .377 .819 r
.61906 .37004 m .62169 .37167 L .62045 .36817 L F
0 0 0 r
.34989 .65887 m .35278 .65541 L .3523 .65816 L F
0 0 .341 r
.35111 .66043 m .34989 .65887 L .3523 .65816 L F
.35111 .66043 m .34979 .6618 L .34989 .65887 L F
.027 0 0 r
.43656 .45304 m .43764 .45384 L .43518 .45472 L F
.43656 .45304 m .43904 .45197 L .43764 .45384 L F
.061 0 0 r
.43656 .45304 m .43518 .45472 L .43262 .4557 L F
.952 .921 .74 r
.47905 .53064 m .48055 .53135 L .48153 .52971 L F
.822 .98 .887 r
.48171 .52751 m .48153 .52971 L .48435 .52723 L F
.863 .994 .819 r
.47905 .53064 m .48153 .52971 L .48171 .52751 L F
.547 .103 .147 r
.66216 .33169 m .66492 .33196 L .66219 .33044 L F
.545 .642 .897 r
.51021 .41768 m .50933 .42057 L .50847 .4192 L F
0 0 .169 r
.50961 .42201 m .50933 .42057 L .51021 .41768 L F
.395 .307 .638 r
.5867 .36502 m .58728 .36787 L .58376 .36667 L F
.407 .291 .607 r
.58728 .36787 m .58446 .36978 L .58376 .36667 L F
.92 .571 .36 r
.2829 .6782 m .28592 .68218 L .28436 .68106 L F
0 .207 .64 r
.28436 .68106 m .28592 .68218 L .28867 .68388 L F
.82 .635 .651 r
.65391 .36711 m .65283 .37033 L .65612 .36889 L F
.652 .745 .917 r
.65283 .37033 m .6548 .37135 L .65612 .36889 L F
.551 .85 .534 r
.65612 .36889 m .65811 .36673 L .6557 .36621 L F
.65612 .36889 m .65795 .36696 L .65811 .36673 L F
.69 .78 .92 r
.3136 .63799 m .30999 .6364 L .31211 .63497 L F
.676 .768 .92 r
.31625 .63572 m .3136 .63799 L .31211 .63497 L F
.773 .603 .667 r
.39595 .56906 m .4012 .57194 L .39877 .56808 L F
.39595 .56906 m .39561 .57197 L .4012 .57194 L F
.813 .603 .618 r
.39561 .57197 m .39847 .5756 L .4012 .57194 L F
.155 .299 .76 r
.4012 .57194 m .40102 .56788 L .39877 .56808 L F
.4012 .57194 m .40245 .57183 L .40102 .56788 L F
.551 .823 .996 r
.38505 .58807 m .38679 .58935 L .38927 .58857 L F
.856 .919 .872 r
.28736 .66385 m .2839 .66451 L .28653 .66311 L F
0 .529 .824 r
.29068 .66443 m .28736 .66385 L .28653 .66311 L F
.918 .782 .695 r
.56091 .43567 m .56404 .43626 L .5628 .43229 L F
.901 .825 .762 r
.56177 .43977 m .56404 .43626 L .56091 .43567 L F
.753 .24 0 r
.37879 .50806 m .3829 .51184 L .38288 .50922 L F
.815 .83 .862 r
.3829 .51184 m .38746 .51072 L .38288 .50922 L F
0 0 0 r
.51166 .44115 m .51028 .44401 L .51 .44535 L F
.9 .655 .559 r
.36811 .50275 m .36783 .5055 L .3697 .50607 L F
.689 .23 .156 r
.36775 .50761 m .3697 .50607 L .36783 .5055 L F
0 .073 .634 r
.23314 .6185 m .23527 .62328 L .23542 .6213 L F
.596 .881 .992 r
.23542 .6213 m .23527 .62328 L .23745 .62214 L F
.475 .832 .995 r
.63044 .39543 m .63172 .39632 L .63446 .39566 L F
.702 .904 .968 r
.62758 .3838 m .62608 .38655 L .62551 .38578 L F
.62758 .3838 m .62888 .3852 L .62608 .38655 L F
.898 .658 .147 r
.62608 .38655 m .62626 .38945 L .62551 .38578 L F
.772 .368 .286 r
.35772 .5159 m .35554 .51768 L .35375 .51492 L F
.808 .421 .323 r
.35772 .5159 m .35948 .51854 L .35554 .51768 L F
.76 .689 .783 r
.43272 .5632 m .43435 .56663 L .43021 .56616 L F
.877 .914 .849 r
.5072 .50091 m .50879 .50205 L .5113 .49876 L F
.696 .738 .883 r
.3215 .61151 m .32586 .61228 L .32426 .60872 L F
.756 .65 .744 r
.32312 .61547 m .32586 .61228 L .3215 .61151 L F
.762 .769 .859 r
.32426 .60872 m .32586 .61228 L .32875 .60902 L F
.774 .495 .513 r
.58997 .43183 m .59403 .42977 L .58994 .42917 L F
.58997 .43183 m .59451 .43267 L .59403 .42977 L F
.69 .831 .951 r
.46669 .52932 m .46364 .53005 L .46185 .52808 L F
.699 .588 .727 r
.46669 .52932 m .46734 .52982 L .46364 .53005 L F
.884 .699 .647 r
.46734 .52982 m .46516 .53161 L .46364 .53005 L F
0 .159 .677 r
.46516 .53161 m .46185 .52808 L .46364 .53005 L F
.928 .797 .696 r
.55089 .42264 m .55185 .42646 L .54896 .42728 L F
.872 .593 .513 r
.55185 .42646 m .54964 .42861 L .54896 .42728 L F
.55185 .42646 m .55189 .42912 L .54964 .42861 L F
.501 .601 .885 r
.34784 .63261 m .34405 .62986 L .3463 .62875 L F
.678 .617 .78 r
.34946 .6281 m .34784 .63261 L .3463 .62875 L F
.34946 .6281 m .35085 .63127 L .34784 .63261 L F
.63 .612 .814 r
.45037 .54695 m .45132 .54155 L .44849 .54231 L F
.45037 .54695 m .45298 .54554 L .45132 .54155 L F
0 .222 .627 r
.45064 .54706 m .45037 .54695 L .44919 .54842 L F
.448 .234 .495 r
.45037 .54695 m .45262 .54823 L .45298 .54554 L F
0 .222 .627 r
.45064 .54706 m .45262 .54823 L .45037 .54695 L F
.672 .357 .433 r
.55004 .40307 m .54597 .40575 L .5484 .40174 L F
.55004 .40307 m .55019 .40568 L .54597 .40575 L F
.536 .78 .988 r
.5484 .40174 m .55282 .40243 L .55004 .40307 L F
.565 .114 .141 r
.54597 .40575 m .55019 .40568 L .54917 .40675 L F
.916 .565 .359 r
.55004 .40307 m .55019 .40568 L .54967 .40587 L F
.54967 .40587 m .55019 .40568 L .55004 .40307 L F
.718 .596 .719 r
.38478 .51276 m .38739 .51343 L .38746 .51072 L F
.661 .178 .094 r
.38478 .51276 m .38694 .51469 L .38739 .51343 L F
.616 .511 .712 r
.38746 .51072 m .38739 .51343 L .39035 .51237 L F
.73 .462 .523 r
.38694 .51469 m .39035 .51237 L .38739 .51343 L F
.713 .608 .737 r
.30019 .63859 m .30471 .63973 L .30203 .64284 L F
.82 .535 .507 r
.67321 .33 m .67342 .3327 L .6772 .33345 L F
.801 .522 .516 r
.6734 .33522 m .6772 .33345 L .67342 .3327 L F
.6734 .33522 m .67734 .33601 L .6772 .33345 L F
.623 .946 .748 r
.67077 .37486 m .6747 .37233 L .67422 .37229 L F
.599 .934 .953 r
.6747 .37233 m .67811 .37087 L .67614 .37041 L F
.631 .937 .701 r
.67422 .37229 m .6747 .37233 L .67614 .37041 L F
.48 .894 .911 r
.57663 .35013 m .57835 .34878 L .5798 .34863 L F
.57663 .35013 m .57385 .35 L .57835 .34878 L F
.731 .987 .793 r
.29792 .60439 m .30042 .60328 L .29921 .60439 L F
.97 .673 .274 r
.29921 .60439 m .29978 .60793 L .29792 .60439 L F
0 0 0 r
.44043 .44251 m .438 .44361 L .4365 .44507 L F
.702 .939 .962 r
.46172 .53853 m .45859 .53908 L .46055 .53749 L F
.536 .922 .91 r
.46055 .53749 m .46535 .5362 L .46172 .53853 L F
.76 .281 .101 r
.42228 .56454 m .42606 .5661 L .42303 .56583 L F
.628 .787 .958 r
.45859 .53908 m .45574 .54036 L .45389 .53832 L F
.508 .733 .975 r
.45389 .53832 m .45382 .53969 L .45122 .53877 L F
.902 .981 .71 r
.45389 .53832 m .45188 .5394 L .454 .53598 L F
.45389 .53832 m .454 .53598 L .45425 .53557 L F
.508 .733 .975 r
.45389 .53832 m .45574 .54036 L .45382 .53969 L F
.916 .543 .3 r
.57169 .39542 m .57459 .39328 L .57513 .39261 L F
0 0 0 r
.57459 .39328 m .57771 .38925 L .57513 .39261 L F
.434 .274 .564 r
.55001 .38624 m .55028 .38959 L .5526 .3884 L F
.978 .898 .67 r
.31168 .68927 m .31041 .68856 L .30881 .68764 L F
.57 .455 .683 r
.51606 .42351 m .51947 .42274 L .51845 .4192 L F
.714 .192 0 r
.27726 .644 m .28131 .64561 L .27894 .64474 L F
0 .335 .791 r
.28131 .64561 m .28396 .64717 L .28237 .64541 L F
.383 0 0 r
.27702 .62565 m .27895 .62585 L .27899 .62651 L F
.882 .713 .668 r
.32355 .51949 m .3228 .52217 L .32128 .51858 L F
0 0 0 r
.64904 .3688 m .65391 .36711 L .65002 .37033 L F
.446 .682 .965 r
.65149 .36829 m .65002 .37033 L .64904 .3688 L F
.65149 .36829 m .65283 .37033 L .65002 .37033 L F
.662 .97 .9 r
.47188 .42372 m .47307 .42185 L .4737 .42192 L F
.47188 .42372 m .46928 .42394 L .47307 .42185 L F
.854 .776 .774 r
.30572 .61272 m .301 .6148 L .30396 .61162 L F
.30572 .61272 m .30375 .61587 L .301 .6148 L F
.826 .713 .74 r
.30404 .60843 m .30572 .61272 L .30396 .61162 L F
.832 .76 .783 r
.33615 .60137 m .33756 .60462 L .3381 .60282 L F
.715 .704 .838 r
.32726 .63521 m .32312 .63443 L .32577 .63225 L F
.797 .802 .855 r
.33013 .63239 m .32726 .63521 L .32577 .63225 L F
.262 0 0 r
.29454 .68562 m .29657 .68609 L .29942 .68702 L F
.692 .733 .882 r
.41214 .56548 m .41002 .56689 L .40768 .56494 L F
.323 .717 .981 r
.28036 .63755 m .28022 .63892 L .27814 .63771 L F
.524 .556 .83 r
.28367 .64162 m .28022 .63892 L .282 .64096 L F
0 .055 .621 r
.282 .64096 m .28022 .63892 L .28036 .63755 L F
.241 .006 .343 r
.41798 .46303 m .42014 .46196 L .41756 .4655 L F
.358 0 .12 r
.39817 .46411 m .39704 .46195 L .39565 .46476 L F
.39817 .46411 m .39985 .46148 L .39704 .46195 L F
.792 .868 .905 r
.30713 .61636 m .30935 .61774 L .31204 .61513 L F
0 0 0 r
.62228 .39141 m .62357 .39061 L .6197 .39253 L F
.632 .781 .952 r
.62626 .38945 m .62357 .39061 L .62195 .3888 L F
0 0 0 r
.51858 .3961 m .51879 .39589 L .51917 .39464 L F
.44554 .44855 m .449 .44752 L .44747 .4484 L F
.44554 .44855 m .44747 .4484 L .44406 .45007 L F
.784 .507 .517 r
.66914 .33193 m .67321 .33 L .66888 .33 L F
.66914 .33193 m .67342 .3327 L .67321 .33 L F
.925 .727 .617 r
.31427 .51131 m .31472 .51219 L .31706 .51256 L F
.599 .901 .986 r
.31706 .51256 m .31472 .51219 L .3149 .51209 L F
.977 .726 .487 r
.31706 .51256 m .3149 .51209 L .31427 .51131 L F
.3149 .51209 m .31438 .51197 L .31436 .51185 L F
.3149 .51209 m .31436 .51185 L .31427 .51131 L F
.61 .843 .988 r
.31822 .51026 m .3149 .51209 L .31367 .51003 L F
.3149 .51209 m .31472 .51219 L .31461 .51196 L F
.3149 .51209 m .31461 .51196 L .31367 .51003 L F
.599 .901 .986 r
.31706 .51256 m .3149 .51209 L .31822 .51026 L F
.977 .726 .487 r
.31706 .51256 m .31476 .51448 L .31438 .51197 L F
.31706 .51256 m .31695 .5159 L .31476 .51448 L F
.82 .574 .568 r
.31923 .51582 m .31695 .5159 L .31706 .51256 L F
.599 .901 .986 r
.31706 .51256 m .31822 .51026 L .32018 .50785 L F
.184 0 .217 r
.50524 .44918 m .50778 .44666 L .50656 .44917 L F
.078 .553 .901 r
.50314 .44768 m .50524 .44918 L .50656 .44917 L F
.50656 .44917 m .50524 .44918 L .50314 .44768 L F
.337 .353 .73 r
.50768 .45216 m .50524 .44918 L .50656 .44917 L F
.995 .86 .532 r
.39186 .53532 m .39111 .53795 L .39261 .53503 L F
.6 .599 .822 r
.39389 .53183 m .39544 .53573 L .39261 .53503 L F
.995 .86 .532 r
.39186 .53532 m .39111 .53795 L .39261 .53503 L F
0 .167 .698 r
.60218 .39042 m .60435 .39094 L .60432 .38897 L F
.60218 .39042 m .60342 .39252 L .60435 .39094 L F
.451 .44 .755 r
.31401 .58901 m .31476 .59245 L .31677 .59106 L F
0 0 0 r
.43304 .44712 m .4365 .44507 L .43448 .44551 L F
.43064 .44814 m .43304 .44712 L .43448 .44551 L F
.884 .699 .647 r
.46734 .52982 m .46747 .53251 L .46516 .53161 L F
.568 .375 .58 r
.2572 .53577 m .26086 .53626 L .26258 .53481 L F
.514 .401 .662 r
.2572 .53577 m .26041 .53867 L .26086 .53626 L F
.2572 .53577 m .25778 .53958 L .26041 .53867 L F
.815 .83 .862 r
.3829 .51184 m .38478 .51276 L .38746 .51072 L F
.616 .511 .712 r
.38746 .51072 m .39035 .51237 L .38964 .50916 L F
.812 .664 .699 r
.41985 .55817 m .42434 .55589 L .42014 .55537 L F
.41985 .55817 m .42327 .55815 L .42434 .55589 L F
.888 .841 .793 r
.42586 .58473 m .42762 .58647 L .43014 .58246 L F
.42586 .58473 m .43014 .58246 L .42768 .58413 L F
0 .148 .619 r
.43426 .58573 m .43014 .58246 L .43001 .58565 L F
.43426 .58573 m .43366 .58509 L .43014 .58246 L F
.159 .661 .909 r
.43366 .58509 m .42768 .58413 L .43014 .58246 L F
.684 .255 .224 r
.40856 .54892 m .4118 .55128 L .41207 .54929 L F
.40856 .54892 m .4076 .55105 L .4118 .55128 L F
.928 .89 .774 r
.59045 .3665 m .58869 .37026 L .58728 .36787 L F
.936 .755 .632 r
.66145 .39263 m .66214 .39006 L .66006 .38866 L F
.536 .922 .91 r
.46055 .53749 m .46225 .53673 L .46535 .5362 L F
.996 .864 .572 r
.46535 .5362 m .46516 .53161 L .46747 .53251 L F
.46535 .5362 m .46402 .53522 L .46516 .53161 L F
.789 .965 .919 r
.46535 .5362 m .46225 .53673 L .46402 .53522 L F
.69 .831 .951 r
.46669 .52932 m .46185 .52808 L .46401 .52465 L F
.696 .718 .866 r
.46912 .52575 m .46669 .52932 L .46401 .52465 L F
.262 0 .069 r
.50202 .45309 m .5042 .45374 L .50146 .45416 L F
.924 .546 .271 r
.57491 .42541 m .57805 .42862 L .57589 .42847 L F
.981 .862 .648 r
.57496 .43075 m .57805 .42862 L .57589 .42847 L F
.924 .546 .271 r
.57491 .42541 m .57805 .42862 L .57589 .42847 L F
.981 .862 .648 r
.57496 .43075 m .57805 .42862 L .57589 .42847 L F
.624 .569 .772 r
.57805 .42862 m .58065 .43012 L .57916 .42589 L F
.747 .711 .818 r
.57916 .42589 m .57805 .42862 L .57491 .42541 L F
.764 .289 .111 r
.3829 .51184 m .38694 .51469 L .38478 .51276 L F
0 0 .451 r
.57276 .37403 m .57091 .37308 L .57228 .37061 L F
.57276 .37403 m .57123 .37619 L .57091 .37308 L F
0 0 .324 r
.26007 .56837 m .25969 .57152 L .25843 .5707 L F
0 0 .188 r
.25893 .57389 m .25843 .5707 L .25969 .57152 L F
.25893 .57389 m .25724 .5756 L .25843 .5707 L F
.8 .704 .759 r
.31597 .60172 m .3172 .60554 L .31334 .6052 L F
.783 .778 .849 r
.31853 .60132 m .3172 .60554 L .31597 .60172 L F
.31853 .60132 m .32064 .60309 L .3172 .60554 L F
.928 .721 .603 r
.34315 .54168 m .34515 .54254 L .34349 .53873 L F
.943 .762 .628 r
.34273 .54385 m .34515 .54254 L .34315 .54168 L F
.34273 .54385 m .34446 .54492 L .34515 .54254 L F
.311 .492 .875 r
.59577 .36624 m .59464 .36812 L .59305 .36623 L F
.645 .429 .576 r
.3019 .65889 m .3018 .66168 L .30509 .65861 L F
.726 .908 .539 r
.62996 .36436 m .6288 .36679 L .63122 .36316 L F
.761 .996 .841 r
.62996 .36436 m .62684 .36726 L .6288 .36679 L F
0 0 0 r
.51052 .44435 m .51376 .44283 L .51585 .442 L F
.51376 .44283 m .51764 .44017 L .51585 .442 L F
.741 .99 .882 r
.4754 .43158 m .47967 .42954 L .47695 .43033 L F
.698 .981 .891 r
.47967 .42954 m .48267 .42757 L .48077 .42752 L F
.714 .986 .827 r
.47695 .43033 m .47967 .42954 L .48077 .42752 L F
.581 .627 .863 r
.5156 .40877 m .51426 .41034 L .51219 .40665 L F
0 0 0 r
.5156 .40877 m .51315 .41218 L .51426 .41034 L F
.913 .677 .568 r
.34155 .53784 m .3437 .53593 L .34161 .53504 L F
.34155 .53784 m .34349 .53873 L .3437 .53593 L F
.73 .839 .932 r
.52148 .40426 m .51882 .40576 L .52272 .40602 L F
.819 .867 .882 r
.52148 .40426 m .52272 .40602 L .52593 .40305 L F
.69 .864 .965 r
.42194 .59852 m .42374 .59972 L .42579 .59836 L F
.859 .502 .374 r
.44637 .5789 m .44667 .58142 L .45018 .5821 L F
.997 .812 .455 r
.44667 .58142 m .44756 .58548 L .45018 .5821 L F
.806 .94 .582 r
.59224 .39773 m .59366 .39654 L .5919 .39516 L F
.59224 .39773 m .59157 .39997 L .59366 .39654 L F
.877 .854 .816 r
.5919 .39516 m .59366 .39654 L .59604 .39289 L F
.447 0 0 r
.64172 .34596 m .64046 .34736 L .6378 .34649 L F
0 0 0 r
.64446 .34591 m .64046 .34736 L .64172 .34596 L F
.771 .732 .817 r
.38782 .58196 m .39211 .58228 L .39036 .5814 L F
.889 .909 .834 r
.39211 .58228 m .39304 .57796 L .39474 .57914 L F
.39211 .58228 m .39036 .5814 L .39304 .57796 L F
0 0 .534 r
.39211 .58228 m .39314 .58295 L .39036 .5814 L F
.633 .582 .78 r
.39211 .58228 m .3963 .58536 L .39424 .58485 L F
0 0 .534 r
.39211 .58228 m .39424 .58485 L .39314 .58295 L F
.849 .649 .631 r
.37892 .5588 m .38105 .56258 L .37854 .56152 L F
.894 .726 .667 r
.38105 .56258 m .37735 .56479 L .37854 .56152 L F
.38105 .56258 m .38074 .56555 L .37735 .56479 L F
0 0 0 r
.34313 .50277 m .34601 .49935 L .34497 .49975 L F
.868 .63 .575 r
.36203 .51944 m .36174 .52208 L .35948 .51854 L F
.013 .264 .766 r
.57351 .36294 m .57397 .36133 L .57144 .3594 L F
.085 .351 .822 r
.57351 .36294 m .57682 .36521 L .57397 .36133 L F
0 0 0 r
.5921 .40048 m .59157 .39997 L .59224 .39773 L F
.5921 .40048 m .59035 .40226 L .59157 .39997 L F
.893 .654 .571 r
.34669 .50635 m .34313 .50778 L .34363 .5044 L F
.34669 .50635 m .34671 .50929 L .34313 .50778 L F
.783 .793 .861 r
.33086 .53641 m .32505 .53584 L .32878 .53506 L F
.822 .689 .718 r
.36629 .4989 m .36378 .50201 L .36811 .50275 L F
.803 .603 .632 r
.36378 .50201 m .36783 .5055 L .36811 .50275 L F
.826 .949 .901 r
.48645 .52558 m .48171 .52751 L .48435 .52723 L F
.592 .519 .741 r
.6249 .36896 m .62144 .37025 L .62545 .36947 L F
.747 .99 .793 r
.62684 .36726 m .6249 .36896 L .62545 .36947 L F
.694 .444 .541 r
.38146 .49289 m .383 .49495 L .38358 .49349 L F
0 0 0 r
.30086 .60373 m .30042 .60328 L .29792 .60439 L F
.726 .274 .178 r
.42586 .58473 m .43001 .58565 L .42762 .58647 L F
.572 .652 .89 r
.28396 .64717 m .28572 .6497 L .28778 .64879 L F
.926 .88 .77 r
.55088 .43656 m .54722 .43866 L .54854 .43511 L F
.55088 .43656 m .54877 .4403 L .54722 .43866 L F
.384 .735 .991 r
.43283 .57908 m .43462 .57749 L .4312 .57798 L F
.43283 .57908 m .43655 .57937 L .43462 .57749 L F
.538 .004 0 r
.4338 .58027 m .43283 .57908 L .4312 .57798 L F
.681 .575 .729 r
.4338 .58027 m .4324 .58267 L .4297 .57864 L F
.538 .004 0 r
.4338 .58027 m .43471 .58082 L .43283 .57908 L F
.556 .016 0 r
.43283 .57908 m .4356 .58165 L .43692 .5825 L F
.681 .575 .729 r
.4338 .58027 m .43462 .57749 L .4312 .57798 L F
.4338 .58027 m .43183 .57948 L .4332 .57906 L F
.43183 .57948 m .4297 .57864 L .4332 .57906 L F
.974 .865 .477 r
.4338 .58027 m .43249 .58201 L .43303 .57979 L F
.4338 .58027 m .43303 .57979 L .4332 .57906 L F
.681 .575 .729 r
.4338 .58027 m .4332 .57906 L .43462 .57749 L F
.975 .896 .54 r
.43462 .57749 m .4338 .58027 L .4332 .57906 L F
.233 .098 .483 r
.43249 .58201 m .43405 .5788 L .4332 .57906 L F
.43405 .5788 m .43452 .57784 L .4332 .57906 L F
.538 .004 0 r
.4338 .58027 m .4356 .58165 L .43471 .58082 L F
0 .172 .708 r
.2843 .6413 m .28396 .64205 L .28367 .64162 L F
.519 .628 .898 r
.28737 .63841 m .28861 .642 L .28396 .64205 L F
.549 .031 0 r
.43001 .58565 m .43296 .58739 L .43426 .58573 L F
.949 .852 .426 r
.43426 .58573 m .43296 .58739 L .43366 .58509 L F
.962 .705 .499 r
.40742 .53169 m .40759 .53503 L .41005 .53607 L F
.866 .777 .761 r
.40759 .53503 m .40845 .53867 L .41005 .53607 L F
.781 .71 .785 r
.40742 .53169 m .41005 .53607 L .41152 .53226 L F
.317 .202 .56 r
.41005 .53607 m .41147 .53511 L .41152 .53226 L F
.494 .479 .769 r
.41005 .53607 m .41392 .53897 L .41147 .53511 L F
.619 .882 .989 r
.41147 .53511 m .40759 .53503 L .41005 .53607 L F
.924 .648 .5 r
.6891 .3533 m .68683 .34957 L .68679 .35232 L F
.953 .679 .48 r
.6871 .35475 m .6891 .3533 L .68679 .35232 L F
.6871 .35475 m .68909 .35636 L .6891 .3533 L F
.752 .25 .029 r
.55736 .40534 m .55688 .40441 L .55282 .40243 L F
.884 .689 .634 r
.34616 .57164 m .3484 .57248 L .34673 .56867 L F
.886 .814 .772 r
.34407 .57482 m .3484 .57248 L .34616 .57164 L F
.34407 .57482 m .34598 .576 L .3484 .57248 L F
.811 .907 .907 r
.48659 .52215 m .48726 .52298 L .48857 .52167 L F
.99 .861 .613 r
.48659 .52215 m .48645 .52558 L .48726 .52298 L F
.512 .163 .313 r
.33226 .67841 m .33634 .67554 L .33455 .67828 L F
.082 0 .039 r
.33455 .67828 m .33634 .67554 L .33845 .67442 L F
.822 .876 .885 r
.47521 .53421 m .47559 .53558 L .47801 .53553 L F
.965 .912 .709 r
.47559 .53558 m .47534 .53831 L .47801 .53553 L F
.851 .868 .854 r
.47905 .53064 m .47801 .53553 L .48055 .53135 L F
.936 .818 .703 r
.47231 .53645 m .47521 .53568 L .47509 .53285 L F
.47521 .53568 m .47559 .53558 L .47552 .5352 L F
.851 .868 .854 r
.47759 .532 m .47521 .53421 L .47593 .53455 L F
.852 .976 .867 r
.47509 .53285 m .47521 .53421 L .47905 .53064 L F
0 .212 .736 r
.47509 .53285 m .47559 .53558 L .47521 .53421 L F
.936 .818 .703 r
.47521 .53568 m .47552 .5352 L .47509 .53285 L F
.851 .868 .854 r
.47905 .53064 m .47759 .532 L .47801 .53553 L F
.47759 .532 m .47593 .53455 L .47801 .53553 L F
.92 .961 .79 r
.52306 .37288 m .52066 .37513 L .52108 .37284 L F
.826 .869 .877 r
.62466 .34929 m .62859 .35019 L .62723 .34809 L F
.62466 .34929 m .62508 .3527 L .62859 .35019 L F
.656 .966 .914 r
.63087 .34859 m .62977 .34831 L .62859 .35019 L F
.372 .627 .952 r
.62859 .35019 m .62977 .34831 L .62723 .34809 L F
.62859 .35019 m .62977 .34831 L .62723 .34809 L F
.601 .754 .951 r
.28867 .68388 m .29026 .6862 L .29249 .68538 L F
.664 .67 .846 r
.30237 .63622 m .30471 .63973 L .30019 .63859 L F
.742 .747 .856 r
.3052 .63511 m .30471 .63973 L .30237 .63622 L F
.3052 .63511 m .30684 .63849 L .30471 .63973 L F
.532 .855 .565 r
.6197 .39253 m .61814 .39395 L .61985 .39284 L F
0 0 0 r
.62228 .39141 m .6197 .39253 L .61985 .39284 L F
.663 .852 .972 r
.62207 .3914 m .61985 .39284 L .61781 .39112 L F
.62228 .39141 m .61985 .39284 L .62207 .3914 L F
.532 .855 .565 r
.61814 .39395 m .61626 .39566 L .61985 .39284 L F
.379 0 0 r
.59575 .34234 m .59818 .3428 L .6 .34265 L F
.561 .018 0 r
.6 .34265 m .59818 .3428 L .60235 .34331 L F
.871 .671 .63 r
.44512 .55269 m .44472 .55571 L .4432 .55168 L F
.731 .834 .928 r
.28993 .625 m .29156 .62122 L .28961 .62192 L F
.28993 .625 m .29344 .62304 L .29156 .62122 L F
.468 0 0 r
.39829 .58749 m .39424 .58485 L .3963 .58536 L F
.997 .798 .444 r
.56707 .41448 m .56874 .41256 L .56786 .4115 L F
.56707 .41448 m .5685 .41626 L .56874 .41256 L F
.745 .617 .717 r
.34802 .4988 m .35026 .49926 L .34899 .49612 L F
.424 0 .041 r
.34882 .50106 m .35026 .49926 L .34802 .4988 L F
.34882 .50106 m .35306 .49966 L .35026 .49926 L F
.919 .654 .519 r
.37333 .53889 m .37074 .54095 L .37054 .53841 L F
.37333 .53889 m .37317 .54215 L .37074 .54095 L F
0 0 0 r
.54388 .34328 m .54508 .34275 L .54664 .34253 L F
.54388 .34328 m .54283 .34521 L .54508 .34275 L F
.971 .757 .557 r
.25066 .58589 m .24954 .58749 L .24917 .58163 L F
0 0 .276 r
.24917 .58163 m .24947 .58639 L .25004 .58292 L F
.24947 .58639 m .24954 .58749 L .24958 .58712 L F
.906 .567 .392 r
.24989 .58713 m .24948 .58645 L .25066 .58589 L F
0 0 .25 r
.24813 .58709 m .24958 .58712 L .24954 .58749 L F
.449 .169 .395 r
.24994 .58717 m .24813 .58709 L .24954 .58749 L F
.906 .567 .392 r
.24987 .58717 m .24958 .58712 L .24989 .58713 L F
.24959 .58716 m .24958 .58712 L .24987 .58717 L F
.24958 .58712 m .24948 .58645 L .24989 .58713 L F
0 0 .276 r
.24947 .58639 m .24958 .58712 L .24972 .58584 L F
.24979 .58448 m .24972 .58584 L .25004 .58292 L F
.24947 .58639 m .24972 .58584 L .24979 .58448 L F
.063 0 .005 r
.25286 .58485 m .24986 .5876 L .25066 .58589 L F
.25286 .58485 m .24986 .5876 L .25066 .58589 L F
.449 .169 .395 r
.25286 .58485 m .24986 .5876 L .24964 .58753 L F
0 0 .25 r
.24813 .58709 m .25004 .58292 L .24972 .58584 L F
.906 .567 .392 r
.24964 .58753 m .24813 .58709 L .24948 .58645 L F
0 0 .25 r
.24813 .58709 m .24972 .58584 L .24958 .58712 L F
.906 .567 .392 r
.24986 .5876 m .24964 .58753 L .25066 .58589 L F
.449 .169 .395 r
.25286 .58485 m .24813 .58709 L .24994 .58717 L F
.2497 .58634 m .24964 .58753 L .24813 .58709 L F
.906 .567 .392 r
.24964 .58753 m .24959 .58716 L .24987 .58717 L F
.449 .169 .395 r
.25286 .58485 m .24964 .58753 L .2497 .58634 L F
.407 .83 .964 r
.28517 .62436 m .28378 .62556 L .28198 .62291 L F
.28517 .62436 m .28625 .62499 L .28378 .62556 L F
.28378 .62556 m .28625 .62499 L .28517 .62436 L F
.28378 .62556 m .28517 .62436 L .2819 .62747 L F
0 0 .495 r
.3255 .57896 m .32683 .58112 L .32808 .5784 L F
0 0 .536 r
.49302 .43759 m .49262 .4393 L .49436 .44166 L F
.192 .282 .728 r
.49302 .43759 m .49436 .44166 L .4957 .43965 L F
.504 0 0 r
.49302 .43781 m .49302 .43759 L .4957 .43965 L F
.49147 .43674 m .49302 .43759 L .49302 .43781 L F
0 0 0 r
.49315 .4366 m .49303 .43724 L .49302 .43759 L F
.49303 .43724 m .49262 .4393 L .49302 .43759 L F
.758 .994 .815 r
.28303 .67722 m .28486 .67658 L .2829 .6782 L F
0 0 0 r
.28689 .67632 m .28486 .67658 L .28303 .67722 L F
.731 .775 .888 r
.34405 .62986 m .33981 .62949 L .34197 .628 L F
.66 .741 .909 r
.34197 .628 m .3463 .62875 L .34405 .62986 L F
.58 .934 .938 r
.62652 .39585 m .62508 .39746 L .62777 .3964 L F
.62652 .39585 m .62302 .39723 L .62508 .39746 L F
.547 .355 .572 r
.27082 .54947 m .26866 .554 L .26777 .5525 L F
.12 0 .297 r
.27208 .55022 m .26883 .554 L .27082 .54947 L F
.112 .175 .65 r
.26795 .55303 m .26944 .55532 L .26885 .55565 L F
.26777 .5525 m .26834 .55346 L .26795 .55303 L F
.26834 .55346 m .26944 .55532 L .26795 .55303 L F
.26866 .554 m .26981 .5551 L .26944 .55532 L F
.26895 .55401 m .26981 .5551 L .26866 .554 L F
.319 .173 .52 r
.26883 .554 m .26981 .5551 L .26844 .55446 L F
.27208 .55022 m .26981 .5551 L .26883 .554 L F
.12 0 .297 r
.26883 .554 m .26844 .55446 L .26866 .554 L F
.26883 .554 m .26866 .554 L .27082 .54947 L F
.112 .175 .65 r
.26777 .5525 m .26895 .55401 L .26866 .554 L F
.547 .355 .572 r
.26866 .554 m .26844 .55446 L .26777 .5525 L F
.346 .243 .592 r
.26844 .55446 m .26981 .5551 L .26777 .5525 L F
.881 .717 .673 r
.40112 .58946 m .39972 .59167 L .39829 .58749 L F
.575 .519 .754 r
.56716 .35983 m .56327 .3651 L .56429 .36028 L F
0 0 0 r
.52128 .41766 m .52171 .41628 L .51845 .4192 L F
.422 .726 .988 r
.52388 .41487 m .52437 .4161 L .52171 .41628 L F
.52437 .4161 m .5242 .41679 L .52171 .41628 L F
.811 .952 .911 r
.52736 .41369 m .52468 .41688 L .52437 .4161 L F
.52502 .41448 m .52437 .4161 L .52388 .41487 L F
.52736 .41369 m .52437 .4161 L .52502 .41448 L F
.52736 .41369 m .52388 .41487 L .52554 .41364 L F
.721 .436 .493 r
.52554 .41364 m .52388 .41487 L .5229 .41769 L F
.79 .913 .522 r
.52485 .41416 m .52529 .41383 L .52463 .41503 L F
.52529 .41383 m .52554 .41364 L .52508 .41435 L F
.52529 .41383 m .52508 .41435 L .52463 .41503 L F
.524 .41478 m .52485 .41416 L .5229 .41769 L F
.52485 .41416 m .52463 .41503 L .5229 .41769 L F
.422 .726 .988 r
.52437 .4161 m .52468 .41688 L .5242 .41679 L F
0 0 0 r
.52388 .41487 m .52171 .41628 L .52128 .41766 L F
.876 .984 .832 r
.44356 .58803 m .44756 .58548 L .44633 .5845 L F
.997 .812 .455 r
.44667 .58142 m .44633 .5845 L .44756 .58548 L F
.106 .661 .759 r
.28936 .67745 m .28869 .67763 L .28689 .67632 L F
.28936 .67745 m .29096 .67743 L .28869 .67763 L F
0 0 0 r
.34313 .50277 m .34486 .50161 L .34601 .49935 L F
.998 .832 .548 r
.34139 .5041 m .34088 .50706 L .33946 .50552 L F
.458 .053 .182 r
.33946 .50552 m .33976 .50532 L .34139 .5041 L F
.764 .297 .138 r
.34363 .5044 m .34139 .5041 L .34314 .5028 L F
.892 .693 .627 r
.34363 .5044 m .34313 .50778 L .34139 .5041 L F
.887 .692 .633 r
.34139 .5041 m .34313 .50778 L .34088 .50706 L F
.458 .053 .182 r
.33976 .50532 m .34378 .50258 L .34139 .5041 L F
.764 .297 .138 r
.34314 .5028 m .34139 .5041 L .34313 .50277 L F
0 0 0 r
.34313 .50277 m .34378 .50258 L .34486 .50161 L F
.34313 .50277 m .34139 .5041 L .34378 .50258 L F
.237 .206 .619 r
.49643 .45064 m .49725 .45259 L .49962 .45061 L F
.043 0 0 r
.40661 .45916 m .40237 .46161 L .40503 .46115 L F
.293 0 0 r
.40775 .46068 m .40661 .45916 L .40503 .46115 L F
.40775 .46068 m .40926 .45885 L .40661 .45916 L F
0 0 0 r
.49315 .4366 m .49302 .43759 L .49142 .43505 L F
.928 .89 .774 r
.59045 .3665 m .58728 .36787 L .5867 .36502 L F
.483 .417 .706 r
.59255 .36133 m .59045 .3665 L .58903 .36247 L F
.59255 .36133 m .59305 .36623 L .59045 .3665 L F
.856 .618 .579 r
.38074 .56555 m .38307 .56938 L .38222 .56898 L F
.824 .646 .662 r
.38211 .57158 m .38222 .56898 L .38307 .56938 L F
.635 .756 .935 r
.32271 .60185 m .32064 .60309 L .31853 .60132 L F
.547 .302 .496 r
.43127 .59171 m .43401 .59106 L .43168 .58901 L F
.622 .063 0 r
.43168 .58901 m .43192 .58992 L .43127 .59171 L F
.43192 .58992 m .43175 .5906 L .43127 .59171 L F
.866 .848 .824 r
.42595 .59317 m .4316 .5912 L .42945 .58878 L F
0 0 .136 r
.43197 .5901 m .43164 .59119 L .43127 .59171 L F
.866 .848 .824 r
.4316 .5912 m .43164 .59119 L .43161 .59116 L F
.4316 .5912 m .43161 .59116 L .42945 .58878 L F
.622 .063 0 r
.43192 .58992 m .43197 .5901 L .43175 .5906 L F
.43168 .58901 m .43401 .59106 L .43197 .5901 L F
.932 .897 .771 r
.48011 .51545 m .47666 .51762 L .47956 .51455 L F
.48011 .51545 m .47812 .51894 L .47666 .51762 L F
.8 .998 .852 r
.48011 .51545 m .48265 .51157 L .48376 .51257 L F
.48011 .51545 m .47956 .51455 L .48265 .51157 L F
.059 0 0 r
.32109 .55953 m .32182 .56008 L .32391 .55929 L F
.32109 .55953 m .31898 .5606 L .32182 .56008 L F
.514 .344 .588 r
.32109 .55953 m .32391 .55929 L .32349 .55553 L F
.806 .727 .777 r
.34538 .58132 m .34271 .58487 L .3469 .58512 L F
.814 .69 .728 r
.34271 .58487 m .34432 .58864 L .3469 .58512 L F
.771 .711 .796 r
.34538 .58132 m .3469 .58512 L .34785 .58288 L F
.479 .497 .799 r
.53708 .346 m .53838 .35013 L .53989 .34685 L F
.413 .42 .757 r
.53838 .35013 m .54099 .35104 L .53989 .34685 L F
0 0 0 r
.44747 .4484 m .449 .44752 L .45189 .4466 L F
.645 .139 .028 r
.54664 .34253 m .55007 .34319 L .54774 .34436 L F
.705 .633 .773 r
.49136 .42313 m .49354 .42712 L .49585 .42581 L F
.657 .523 .689 r
.49354 .42712 m .49331 .42946 L .49585 .42581 L F
.855 .803 .313 r
.23987 .59896 m .24044 .59429 L .23954 .59494 L F
.23987 .59896 m .23946 .59826 L .24044 .59429 L F
.498 0 0 r
.23987 .59896 m .24069 .59994 L .23946 .59826 L F
.23987 .59896 m .24215 .60076 L .24069 .59994 L F
.198 .53 .922 r
.60435 .39094 m .60342 .39252 L .60581 .39294 L F
.764 .522 .568 r
.40235 .52828 m .40742 .53169 L .40514 .52872 L F
.563 .936 .886 r
.30128 .68775 m .30191 .68651 L .29942 .68702 L F
.30128 .68775 m .30336 .68669 L .30191 .68651 L F
.436 .821 .988 r
.43692 .5825 m .4356 .58165 L .43962 .58187 L F
.292 .727 .967 r
.23314 .6185 m .23587 .61837 L .23705 .61925 L F
0 0 .271 r
.2376 .61995 m .23745 .62214 L .23705 .61925 L F
.23783 .62024 m .23772 .6208 L .2376 .61995 L F
.23772 .6208 m .23745 .62214 L .2376 .61995 L F
.23783 .62024 m .2376 .61995 L .23701 .61941 L F
.347 .044 .301 r
.23701 .61941 m .23783 .62024 L .23818 .61803 L F
.23542 .6213 m .23783 .62024 L .23701 .61941 L F
.23542 .6213 m .23701 .61941 L .23587 .61837 L F
0 0 .271 r
.23783 .62024 m .23701 .61941 L .23587 .61837 L F
.2376 .61995 m .23705 .61925 L .23587 .61837 L F
.347 .044 .301 r
.23701 .61941 m .23746 .61888 L .23587 .61837 L F
.23746 .61888 m .23818 .61803 L .23736 .61815 L F
.23746 .61888 m .23736 .61815 L .23587 .61837 L F
.716 .298 .254 r
.31923 .51582 m .31728 .51752 L .31695 .5159 L F
.84 .646 .641 r
.32163 .51564 m .31728 .51752 L .31923 .51582 L F
.634 .955 .93 r
.52829 .41514 m .52468 .41688 L .52736 .41369 L F
.669 .469 .606 r
.26239 .52886 m .26592 .53192 L .26636 .52917 L F
.26239 .52886 m .26386 .53262 L .26592 .53192 L F
0 .172 .708 r
.2843 .6413 m .28367 .64162 L .282 .64096 L F
.902 .947 .824 r
.48995 .51717 m .49007 .51988 L .49155 .51805 L F
.891 .95 .838 r
.49254 .51396 m .49155 .51805 L .49426 .51501 L F
.49254 .51396 m .48995 .51717 L .49155 .51805 L F
.728 .694 .818 r
.31467 .61177 m .31901 .61251 L .31764 .60905 L F
.693 .667 .821 r
.31901 .61251 m .32008 .60774 L .31764 .60905 L F
.31901 .61251 m .3215 .61151 L .32008 .60774 L F
.877 .854 .816 r
.5919 .39516 m .59604 .39289 L .59466 .39137 L F
.97 .931 .675 r
.59604 .39289 m .59676 .3883 L .59466 .39137 L F
.659 .588 .765 r
.57916 .42589 m .58065 .43012 L .58314 .42928 L F
.877 .914 .849 r
.5072 .50091 m .5113 .49876 L .51032 .49779 L F
.788 .965 .919 r
.51359 .49526 m .5113 .49876 L .51487 .49609 L F
.51359 .49526 m .51032 .49779 L .5113 .49876 L F
.859 .513 .396 r
.37013 .53598 m .36745 .53742 L .36727 .53471 L F
.37013 .53598 m .37054 .53841 L .36745 .53742 L F
.81 .934 .913 r
.52722 .48655 m .52575 .48554 L .52255 .4883 L F
.854 .968 .872 r
.52751 .48385 m .52722 .48655 L .52851 .48509 L F
.801 .934 .919 r
.52751 .48385 m .52575 .48554 L .52722 .48655 L F
.177 .246 .697 r
.29511 .66215 m .29622 .66537 L .29745 .66435 L F
.84 .735 .212 r
.49331 .42946 m .49066 .43281 L .49323 .43205 L F
.716 .191 0 r
.49782 .43219 m .49331 .42946 L .49323 .43205 L F
.661 .949 .71 r
.45496 .44521 m .45603 .44352 L .45411 .44507 L F
.45496 .44521 m .45792 .44247 L .45603 .44352 L F
.87 .623 .562 r
.38074 .56555 m .37668 .56767 L .37735 .56479 L F
.38074 .56555 m .38222 .56898 L .37668 .56767 L F
.968 .655 .364 r
.51992 .37622 m .51821 .37746 L .51824 .37468 L F
.51992 .37622 m .52012 .37926 L .51821 .37746 L F
.679 .853 .966 r
.52066 .37513 m .51992 .37622 L .51824 .37468 L F
0 0 .104 r
.52019 .37634 m .51992 .37622 L .52066 .37513 L F
.52019 .37634 m .52012 .37926 L .51992 .37622 L F
.625 .942 .953 r
.25036 .62721 m .24978 .62881 L .24833 .62839 L F
.25036 .62721 m .24978 .62881 L .24833 .62839 L F
.717 .797 .915 r
.62371 .35144 m .62508 .3527 L .62466 .34929 L F
.209 0 .303 r
.26249 .56525 m .26007 .56837 L .26083 .56607 L F
.704 .973 .924 r
.29872 .63822 m .30019 .63859 L .2978 .63989 L F
.79 .99 .885 r
.30237 .63622 m .30019 .63859 L .30056 .63644 L F
.783 .987 .895 r
.30056 .63644 m .30019 .63859 L .29872 .63822 L F
.788 .755 .823 r
.40953 .58823 m .41441 .5883 L .4122 .5877 L F
.228 .723 .916 r
.41645 .5881 m .4122 .5877 L .41441 .5883 L F
.01 0 .181 r
.38358 .49349 m .383 .49495 L .38517 .49194 L F
.876 .984 .83 r
.5475 .44187 m .54357 .44452 L .54628 .44092 L F
.879 .889 .836 r
.54722 .43866 m .5475 .44187 L .54628 .44092 L F
.54722 .43866 m .54877 .4403 L .5475 .44187 L F
.918 .72 .621 r
.3678 .52937 m .36717 .53205 L .36542 .52834 L F
0 0 0 r
.44983 .43599 m .44609 .43913 L .44843 .43777 L F
.44983 .43599 m .45035 .43591 L .4523 .43496 L F
.44983 .43599 m .44843 .43777 L .45035 .43591 L F
.872 .815 .79 r
.33563 .57297 m .33446 .57513 L .33345 .57165 L F
.078 .553 .901 r
.50314 .44768 m .50656 .44917 L .50778 .44666 L F
.113 0 .144 r
.51 .44535 m .50778 .44666 L .50656 .44917 L F
.51 .44535 m .50778 .44666 L .50656 .44917 L F
.894 .887 .817 r
.48634 .52073 m .49007 .51988 L .48995 .51717 L F
.48634 .52073 m .48857 .52167 L .49007 .51988 L F
.707 .848 .95 r
.59177 .37503 m .58922 .37695 L .58793 .37531 L F
.57 .94 .851 r
.56356 .4054 m .56132 .40683 L .55913 .40705 L F
.424 0 .041 r
.34882 .50106 m .35198 .50083 L .35306 .49966 L F
.232 0 .006 r
.35198 .50083 m .35554 .49875 L .35306 .49966 L F
.921 .766 .672 r
.40845 .53867 m .40683 .5424 L .40948 .54184 L F
.328 .813 .856 r
.48077 .42752 m .48267 .42757 L .48576 .42675 L F
.821 .781 .815 r
.33755 .59171 m .34187 .59165 L .34016 .58829 L F
.835 .708 .724 r
.33923 .59543 m .34187 .59165 L .33755 .59171 L F
.804 .775 .826 r
.34016 .58829 m .34187 .59165 L .34432 .58864 L F
.807 .892 .904 r
.29595 .61777 m .29177 .61841 L .2941 .61692 L F
.436 .775 .997 r
.2966 .61612 m .29595 .61777 L .2941 .61692 L F
.2966 .61612 m .29854 .61751 L .29595 .61777 L F
.433 .266 .553 r
.39399 .58893 m .39515 .59026 L .39318 .59203 L F
.667 .116 0 r
.39864 .59317 m .3984 .59302 L .39608 .59132 L F
.433 .266 .553 r
.39493 .59048 m .39608 .59132 L .39353 .59194 L F
.39515 .59026 m .39353 .59194 L .39318 .59203 L F
.39515 .59026 m .39608 .59132 L .39493 .59048 L F
.699 .271 .228 r
.39172 .59076 m .39608 .59132 L .39399 .58893 L F
.463 .8 .999 r
.39318 .59203 m .39608 .59132 L .39172 .59076 L F
.651 .791 .95 r
.39172 .59076 m .39608 .59132 L .39355 .59005 L F
.39172 .59076 m .39608 .59132 L .39355 .59005 L F
.667 .116 0 r
.3984 .59302 m .39355 .59005 L .39608 .59132 L F
.86 .733 .722 r
.39796 .58731 m .39355 .59005 L .39696 .58679 L F
.39829 .58749 m .39727 .58804 L .39796 .58731 L F
.39727 .58804 m .39355 .59005 L .39796 .58731 L F
.81 .622 .649 r
.41985 .55817 m .42217 .56193 L .42327 .55815 L F
.209 0 0 r
.62282 .3449 m .62563 .34446 L .62686 .34305 L F
0 0 0 r
.62686 .34305 m .62563 .34446 L .62824 .34326 L F
.237 .738 .669 r
.62745 .3435 m .62794 .34333 L .62824 .34326 L F
.62794 .34333 m .63108 .34222 L .62824 .34326 L F
0 0 0 r
.62893 .3431 m .62824 .34326 L .62992 .34313 L F
.62686 .34305 m .62824 .34326 L .62893 .3431 L F
.913 .767 .279 r
.54942 .40863 m .54961 .41247 L .54911 .4103 L F
.975 .709 .462 r
.54961 .41247 m .54819 .41284 L .54911 .4103 L F
.54961 .41247 m .54949 .41555 L .54819 .41284 L F
.767 .256 0 r
.32431 .5858 m .32656 .58832 L .32439 .58704 L F
.32431 .5858 m .32439 .58704 L .32578 .58498 L F
.726 .687 .813 r
.2978 .63989 m .29316 .63985 L .29506 .63989 L F
.704 .973 .924 r
.29872 .63822 m .2978 .63989 L .29506 .63989 L F
.732 .792 .9 r
.32081 .63601 m .31625 .63572 L .31899 .63465 L F
.743 .706 .817 r
.32174 .6311 m .32081 .63601 L .31899 .63465 L F
.32174 .6311 m .32312 .63443 L .32081 .63601 L F
.918 .973 .777 r
.66427 .35354 m .66234 .35659 L .66206 .35459 L F
.918 .843 .392 r
.66234 .35659 m .6615 .35698 L .66206 .35459 L F
.66234 .35659 m .66161 .35945 L .6615 .35698 L F
.75 .341 .275 r
.34601 .49935 m .34529 .50076 L .34863 .50179 L F
.34529 .50076 m .34627 .50168 L .34863 .50179 L F
.34554 .50099 m .34486 .50161 L .34627 .50168 L F
.34529 .50076 m .34486 .50161 L .34554 .50099 L F
.964 .638 .332 r
.34392 .50248 m .34486 .50161 L .34378 .50258 L F
.34608 .50074 m .34863 .50179 L .34499 .50162 L F
.34608 .50074 m .34486 .50161 L .34392 .50248 L F
.34608 .50074 m .34884 .50432 L .34863 .50179 L F
0 .168 .693 r
.34608 .50074 m .348 .50247 L .34864 .50388 L F
.34814 .50342 m .34864 .50388 L .34884 .50432 L F
.34608 .50074 m .34864 .50388 L .34814 .50342 L F
.664 .395 .504 r
.34601 .49935 m .34882 .50106 L .34802 .4988 L F
.34601 .49935 m .34863 .50179 L .34882 .50106 L F
.553 .811 .994 r
.48944 .43138 m .49066 .43281 L .4866 .43229 L F
0 0 .403 r
.49112 .43358 m .49066 .43281 L .49142 .43505 L F
.603 .085 0 r
.4866 .43229 m .49066 .43281 L .49112 .43358 L F
.549 .809 .994 r
.49323 .43205 m .49066 .43281 L .48944 .43138 L F
0 0 0 r
.39309 .46547 m .3907 .46678 L .3887 .46801 L F
.792 .886 .914 r
.42579 .59836 m .43007 .59661 L .42809 .59711 L F
.81 .783 .828 r
.43007 .59661 m .43163 .59408 L .42809 .59711 L F
.23 .514 .911 r
.50116 .42269 m .50336 .42546 L .50499 .42501 L F
.599 .779 .966 r
.3214 .54533 m .31818 .5466 L .31624 .54454 L F
.206 .462 .881 r
.31818 .5466 m .31809 .54489 L .31624 .54454 L F
.31818 .5466 m .3204 .54708 L .31809 .54489 L F
.949 .608 .335 r
.56983 .42044 m .57056 .41943 L .56888 .41839 L F
0 .055 .599 r
.58277 .38359 m .58377 .38594 L .58286 .38176 L F
.858 .913 .869 r
.47118 .5405 m .47534 .53831 L .47409 .5379 L F
.965 .912 .709 r
.47559 .53558 m .47409 .5379 L .47534 .53831 L F
.768 .996 .86 r
.29491 .67042 m .29404 .67242 L .29578 .67071 L F
.685 .72 .876 r
.30999 .6364 m .30684 .63849 L .3052 .63511 L F
.986 .736 .466 r
.30509 .65861 m .30311 .66076 L .30527 .65707 L F
.30509 .65861 m .30475 .66171 L .30311 .66076 L F
.812 .947 .911 r
.31194 .68747 m .31342 .68731 L .31274 .68446 L F
.775 .826 .892 r
.31342 .68731 m .31712 .68502 L .31274 .68446 L F
0 0 .506 r
.2829 .6782 m .28436 .68106 L .28303 .67722 L F
.824 .879 .885 r
.53864 .46056 m .53467 .46219 L .53778 .45957 L F
.736 .884 .948 r
.54146 .45935 m .53864 .46056 L .53778 .45957 L F
.847 .462 .318 r
.36492 .52608 m .36288 .52738 L .36185 .52476 L F
.36492 .52608 m .36542 .52834 L .36288 .52738 L F
.12 0 .297 r
.27208 .55022 m .27082 .54947 L .27276 .54812 L F
.931 .737 .62 r
.5572 .45567 m .55621 .45144 L .55446 .45542 L F
.905 .856 .782 r
.55325 .45769 m .5572 .45567 L .55446 .45542 L F
.55325 .45769 m .55488 .45908 L .5572 .45567 L F
.902 .571 .087 r
.61569 .35813 m .61497 .35805 L .61416 .35521 L F
.667 .96 .746 r
.61817 .35521 m .61569 .35813 L .61954 .35673 L F
.61817 .35521 m .61497 .35805 L .61569 .35813 L F
.761 .625 .709 r
.59035 .40226 m .59217 .4056 L .58833 .40574 L F
.198 0 0 r
.59217 .4056 m .59124 .40589 L .58833 .40574 L F
.564 .88 .992 r
.59124 .40589 m .59507 .40574 L .59217 .4056 L F
.838 .778 .795 r
.37939 .57545 m .3756 .57489 L .37806 .57164 L F
.863 .687 .661 r
.37939 .57545 m .37748 .57876 L .3756 .57489 L F
.813 .767 .81 r
.38211 .57158 m .37939 .57545 L .37806 .57164 L F
.617 .942 .741 r
.29753 .6748 m .29394 .6772 L .2958 .67745 L F
0 0 0 r
.6378 .34649 m .63658 .347 L .6338 .34739 L F
.297 .761 .946 r
.64046 .34736 m .63658 .347 L .6378 .34649 L F
0 0 0 r
.35216 .6288 m .35099 .63025 L .35319 .62644 L F
.58 .942 .83 r
.35113 .62949 m .35099 .63025 L .35216 .6288 L F
.066 .516 .897 r
.35099 .63025 m .35081 .63117 L .34946 .6281 L F
.35099 .63025 m .34946 .6281 L .35185 .62857 L F
.58 .942 .83 r
.35001 .63025 m .35099 .63025 L .35113 .62949 L F
.066 .516 .897 r
.35099 .63025 m .35085 .63127 L .35081 .63117 L F
.35099 .63025 m .35272 .63167 L .35085 .63127 L F
.575 .483 .713 r
.51219 .40665 m .50917 .40747 L .51293 .40412 L F
0 0 .093 r
.3523 .65816 m .35278 .65541 L .35359 .65395 L F
.451 .44 .755 r
.31401 .58901 m .31677 .59106 L .31592 .5878 L F
0 0 .112 r
.29622 .66537 m .29538 .66826 L .29745 .66435 L F
.599 .846 .991 r
.47812 .51894 m .47403 .51855 L .47666 .51762 L F
.77 .769 .852 r
.47812 .51894 m .4757 .52016 L .47403 .51855 L F
.964 .688 .46 r
.33186 .51743 m .33467 .51768 L .33165 .51452 L F
.33186 .51743 m .33437 .51946 L .33467 .51768 L F
.493 .793 .998 r
.44615 .56185 m .44851 .56129 L .44497 .56052 L F
.042 .586 .841 r
.44832 .56125 m .44755 .56081 L .44497 .56052 L F
.44851 .56129 m .44755 .56081 L .44832 .56125 L F
.872 .994 .762 r
.44755 .56081 m .44786 .55848 L .44654 .56024 L F
.339 0 0 r
.44497 .56052 m .44755 .56081 L .44673 .56121 L F
.44497 .56052 m .44673 .56121 L .44529 .56193 L F
0 .319 .777 r
.44615 .56185 m .44497 .56052 L .44369 .56001 L F
.872 .994 .762 r
.44755 .56081 m .44654 .56024 L .44529 .56193 L F
0 .319 .777 r
.44369 .56001 m .44497 .56052 L .44228 .55895 L F
.906 .812 .743 r
.55945 .44298 m .56177 .43977 L .56002 .43829 L F
.901 .825 .762 r
.56177 .43977 m .56091 .43567 L .56002 .43829 L F
.28 .408 .814 r
.59499 .35303 m .59722 .35307 L .59601 .35077 L F
.849 .505 .403 r
.59499 .35303 m .59661 .35656 L .59847 .35635 L F
.055 .132 .628 r
.59601 .35077 m .59661 .35656 L .59499 .35303 L F
.086 0 0 r
.63517 .34122 m .63937 .33993 L .63651 .34053 L F
.458 .302 .58 r
.3062 .66538 m .30582 .66814 L .30336 .6686 L F
.632 .876 .987 r
.63154 .38383 m .62888 .3852 L .62758 .3838 L F
.87 .782 .761 r
.34407 .57482 m .34534 .57902 L .34598 .576 L F
.34407 .57482 m .34177 .57835 L .34534 .57902 L F
.772 .488 .505 r
.34128 .58084 m .34534 .57902 L .34177 .57835 L F
.34128 .58084 m .34538 .58132 L .34534 .57902 L F
.79 .77 .835 r
.4757 .52016 m .47122 .5219 L .47403 .51855 L F
0 0 0 r
.64904 .3688 m .65149 .36829 L .65391 .36711 L F
0 0 .001 r
.65457 .36727 m .65283 .37033 L .65391 .36711 L F
.65457 .36727 m .65391 .36711 L .65149 .36829 L F
.833 .935 .895 r
.49569 .51099 m .49426 .51501 L .49707 .51203 L F
.49569 .51099 m .49254 .51396 L .49426 .51501 L F
.542 .451 .701 r
.38964 .50916 m .39035 .51237 L .39193 .51185 L F
.797 .802 .855 r
.33013 .63239 m .32577 .63225 L .32836 .63114 L F
.678 .86 .969 r
.33249 .63134 m .33013 .63239 L .32836 .63114 L F
0 .181 .716 r
.56846 .36559 m .57087 .36785 L .57047 .36917 L F
0 .05 .617 r
.57087 .36785 m .57228 .37061 L .57047 .36917 L F
0 .296 .752 r
.30465 .60162 m .30348 .60111 L .30308 .6002 L F
.456 .098 .267 r
.27183 .5282 m .27474 .52779 L .27568 .52582 L F
0 0 .031 r
.27838 .52248 m .27568 .52582 L .2772 .52481 L F
.275 0 .176 r
.27568 .52582 m .27643 .52702 L .2772 .52481 L F
.27568 .52582 m .27474 .52779 L .27643 .52702 L F
.705 .633 .773 r
.49136 .42313 m .49585 .42581 L .49439 .42272 L F
.691 .738 .887 r
.49439 .42272 m .49585 .42581 L .49827 .42439 L F
.527 .299 .512 r
.2809 .54063 m .27826 .54192 L .2785 .53905 L F
.501 .311 .555 r
.28097 .53852 m .2809 .54063 L .2785 .53905 L F
.1 0 .276 r
.37776 .47483 m .37835 .47261 L .37974 .47314 L F
.278 .049 .376 r
.6548 .37135 m .6589 .37062 L .65795 .36696 L F
.287 .074 .406 r
.6548 .37135 m .65652 .37422 L .6589 .37062 L F
.438 .258 .538 r
.32485 .54638 m .32674 .54779 L .32563 .54566 L F
.857 .922 .872 r
.59847 .35635 m .59977 .35206 L .60129 .35581 L F
.59847 .35635 m .59661 .35656 L .59977 .35206 L F
0 0 0 r
.59992 .35584 m .59847 .35635 L .60129 .35581 L F
.59992 .35584 m .59677 .35708 L .59847 .35635 L F
.935 .694 .549 r
.37854 .56152 m .37607 .5579 L .37892 .5588 L F
.918 .973 .777 r
.66427 .35354 m .66206 .35459 L .66252 .35184 L F
0 0 0 r
.50208 .41671 m .50276 .41551 L .50131 .41736 L F
.979 .713 .453 r
.50361 .41402 m .50276 .41551 L .50447 .41571 L F
.306 .635 .964 r
.50447 .41571 m .50534 .41397 L .50253 .41193 L F
.50534 .41397 m .50447 .41571 L .50276 .41551 L F
0 0 0 r
.50534 .41397 m .50276 .41551 L .50208 .41671 L F
.979 .713 .453 r
.50253 .41193 m .50276 .41551 L .50361 .41402 L F
.306 .635 .964 r
.50447 .41571 m .50679 .41548 L .50534 .41397 L F
.50534 .41397 m .50679 .41548 L .50447 .41571 L F
.555 .458 .699 r
.24748 .57075 m .25136 .56893 L .24889 .56484 L F
.25 .57093 m .25255 .57111 L .25189 .56989 L F
.25255 .57111 m .25269 .57112 L .25259 .57096 L F
.25255 .57111 m .25259 .57096 L .25136 .56893 L F
.804 .361 0 r
.24889 .56484 m .25259 .57096 L .25116 .56873 L F
.25259 .57096 m .25269 .57112 L .25259 .57096 L F
.25259 .57096 m .25259 .57096 L .25116 .56873 L F
.064 .615 .829 r
.25252 .57109 m .25269 .57112 L .25255 .57111 L F
.103 0 0 r
.25099 .57225 m .25248 .57231 L .25291 .57082 L F
.555 .458 .699 r
.24748 .57075 m .25 .57093 L .25136 .56893 L F
.737 .529 .612 r
.25116 .56873 m .25248 .57099 L .25356 .56856 L F
.555 .458 .699 r
.25 .57093 m .25189 .56989 L .25136 .56893 L F
.785 .541 .567 r
.24816 .57048 m .25116 .56873 L .25269 .57112 L F
.24816 .57048 m .25248 .57099 L .25116 .56873 L F
.103 0 0 r
.25205 .57073 m .25309 .56924 L .25251 .57092 L F
.25309 .56924 m .25278 .57033 L .25248 .57099 L F
.25206 .57085 m .25291 .57082 L .25342 .56906 L F
.064 .615 .829 r
.25252 .57109 m .25255 .57111 L .24697 .57071 L F
.103 0 0 r
.25242 .57105 m .25205 .57073 L .25248 .57099 L F
.064 .615 .829 r
.24816 .57048 m .25105 .57089 L .24697 .57071 L F
.25105 .57089 m .25252 .57109 L .25006 .57092 L F
.25105 .57089 m .25006 .57092 L .24697 .57071 L F
.241 .383 .806 r
.24816 .57048 m .25099 .57225 L .25248 .57099 L F
.103 0 0 r
.25099 .57225 m .25196 .57085 L .25242 .57105 L F
.25196 .57085 m .25205 .57073 L .25242 .57105 L F
.25205 .57073 m .25251 .57092 L .25248 .57099 L F
.25099 .57225 m .25291 .57082 L .25206 .57085 L F
.25309 .56924 m .25356 .56856 L .25278 .57033 L F
.25309 .56924 m .25342 .56906 L .25356 .56856 L F
.25099 .57225 m .25342 .56906 L .25309 .56924 L F
.737 .529 .612 r
.25116 .56873 m .25189 .56868 L .25435 .56681 L F
.25189 .56868 m .25356 .56856 L .25394 .56772 L F
.25189 .56868 m .25394 .56772 L .25435 .56681 L F
.555 .458 .699 r
.24697 .57071 m .24748 .57075 L .24889 .56484 L F
.064 .615 .829 r
.24816 .57048 m .24697 .57071 L .2474 .57227 L F
.887 .711 .659 r
.33198 .55497 m .32979 .55094 L .33115 .55242 L F
.874 .515 .365 r
.44364 .58002 m .44667 .58142 L .44637 .5789 L F
.735 .98 .914 r
.44057 .55232 m .44242 .54984 L .4432 .55168 L F
.44057 .55232 m .43962 .55163 L .44242 .54984 L F
.864 .515 .389 r
.44057 .55232 m .43817 .55314 L .43962 .55163 L F
.44057 .55232 m .44093 .55527 L .43817 .55314 L F
.841 .66 .657 r
.4432 .55168 m .44093 .55527 L .44057 .55232 L F
.348 0 0 r
.59818 .3428 m .60106 .34375 L .60235 .34331 L F
.528 0 0 r
.60106 .34375 m .60511 .34496 L .60235 .34331 L F
.925 .752 .649 r
.342 .55428 m .34421 .55252 L .34237 .55146 L F
.342 .55428 m .34383 .55516 L .34421 .55252 L F
.819 .867 .882 r
.52148 .40426 m .52593 .40305 L .52381 .40353 L F
.654 .971 .865 r
.52381 .40353 m .52593 .40305 L .52703 .4011 L F
.832 .487 .402 r
.32928 .50871 m .33286 .51089 L .33299 .51012 L F
.951 .722 .556 r
.32128 .51858 m .3228 .52217 L .32076 .52114 L F
.999 .797 .468 r
.3208 .52412 m .32076 .52114 L .3228 .52217 L F
.795 .698 .758 r
.41622 .55278 m .4118 .55128 L .41433 .55121 L F
.41622 .55278 m .41336 .55547 L .4118 .55128 L F
.589 .015 0 r
.41433 .55121 m .41681 .5528 L .41622 .55278 L F
.968 .699 .276 r
.53991 .45267 m .54138 .45045 L .54258 .45197 L F
.53991 .45267 m .53888 .45398 L .54138 .45045 L F
.53991 .45267 m .54005 .45539 L .53888 .45398 L F
.404 .832 .958 r
.63594 .38376 m .63281 .38381 L .63368 .38327 L F
.744 .952 .944 r
.63811 .38205 m .63594 .38376 L .63368 .38327 L F
.63811 .38205 m .63368 .38327 L .63744 .382 L F
.405 .859 .849 r
.63557 .38207 m .63744 .382 L .63368 .38327 L F
.63556 .38208 m .63368 .38327 L .63351 .38369 L F
.63557 .38207 m .63368 .38327 L .63556 .38208 L F
.404 .832 .958 r
.63281 .38381 m .63154 .38383 L .63368 .38327 L F
.906 .765 .694 r
.33566 .56543 m .33169 .56762 L .33364 .56453 L F
.33566 .56543 m .33427 .56865 L .33169 .56762 L F
.801 .612 .645 r
.52165 .38497 m .5256 .38939 L .52538 .38613 L F
.487 .341 .608 r
.5256 .38939 m .52806 .38549 L .52538 .38613 L F
.003 0 0 r
.42652 .45772 m .42492 .46008 L .42264 .46117 L F
.206 0 0 r
.42652 .45772 m .42829 .45831 L .42492 .46008 L F
.506 .053 .111 r
.6589 .34293 m .65674 .34479 L .65426 .34353 L F
.805 .449 .384 r
.6589 .34293 m .66059 .34566 L .65674 .34479 L F
.525 .816 .476 r
.5482 .46731 m .54674 .46893 L .54958 .46579 L F
.576 .942 .887 r
.54583 .4687 m .54674 .46893 L .5482 .46731 L F
.902 .749 .681 r
.37475 .54615 m .37384 .54859 L .37245 .5449 L F
.321 .463 .847 r
.25503 .58129 m .25373 .58235 L .25155 .57824 L F
.167 0 .266 r
.25533 .58299 m .25373 .58235 L .25503 .58129 L F
.25533 .58299 m .25286 .58485 L .25373 .58235 L F
.845 .714 .719 r
.25155 .57824 m .25373 .58235 L .25035 .58049 L F
.857 .649 .621 r
.6809 .34222 m .67905 .34558 L .68265 .34635 L F
.905 .647 .538 r
.67949 .34761 m .68265 .34635 L .67905 .34558 L F
.67949 .34761 m .68277 .34921 L .68265 .34635 L F
.788 .644 .702 r
.34517 .56445 m .34673 .56867 L .34748 .56599 L F
.856 .728 .721 r
.38222 .56898 m .37806 .57164 L .37668 .56767 L F
.824 .646 .662 r
.38211 .57158 m .37806 .57164 L .38222 .56898 L F
.811 .907 .907 r
.48659 .52215 m .48857 .52167 L .48634 .52073 L F
.716 .191 0 r
.49782 .43219 m .49323 .43205 L .49617 .43068 L F
.112 .431 .872 r
.49953 .43276 m .49782 .43219 L .49852 .43083 L F
.831 .413 .248 r
.32654 .569 m .32457 .57054 L .32431 .56891 L F
.703 .944 .959 r
.32654 .569 m .32763 .56752 L .32859 .56792 L F
.32654 .569 m .32431 .56891 L .32763 .56752 L F
.457 0 0 r
.32915 .57038 m .32654 .569 L .32859 .56792 L F
.32915 .57038 m .32457 .57054 L .32654 .569 L F
.891 .925 .537 r
.50143 .44516 m .50057 .44336 L .49895 .44493 L F
.50143 .44516 m .50208 .44233 L .50057 .44336 L F
.781 .292 .058 r
.50314 .44768 m .50143 .44516 L .49895 .44493 L F
0 0 .371 r
.56332 .37748 m .56462 .37797 L .56444 .37669 L F
.56332 .37748 m .56444 .37669 L .56421 .37509 L F
0 0 0 r
.56427 .37583 m .56257 .37802 L .56332 .37748 L F
.56257 .37802 m .56115 .37985 L .56332 .37748 L F
.919 .826 .366 r
.56427 .37583 m .56332 .37748 L .56402 .3724 L F
.881 .713 .67 r
.37933 .58046 m .37685 .58147 L .37748 .57876 L F
.912 .533 .103 r
.37933 .58046 m .37946 .58306 L .37685 .58147 L F
.38023 .58288 m .38098 .58494 L .37946 .58306 L F
.345 .629 .958 r
.37946 .58306 m .38098 .58494 L .3818 .5831 L F
.37946 .58306 m .38098 .58494 L .3818 .5831 L F
.539 .03 0 r
.3818 .5831 m .37878 .58321 L .37946 .58306 L F
.517 .325 .56 r
.37946 .58306 m .37672 .58434 L .37685 .58147 L F
.415 .835 .964 r
.37747 .58326 m .37672 .58434 L .37946 .58306 L F
.539 .03 0 r
.37878 .58321 m .37747 .58326 L .37946 .58306 L F
.912 .533 .103 r
.37933 .58046 m .38023 .58288 L .37946 .58306 L F
.921 .75 .653 r
.54005 .45539 m .54146 .45935 L .53939 .45782 L F
.736 .884 .948 r
.54146 .45935 m .53778 .45957 L .53939 .45782 L F
.766 .687 .775 r
.54421 .45601 m .54146 .45935 L .54005 .45539 L F
.462 .273 .537 r
.25778 .53958 m .25795 .54197 L .26041 .53867 L F
.45 .882 .824 r
.5798 .34863 m .58077 .3476 L .58205 .34858 L F
.5798 .34863 m .57835 .34878 L .58077 .3476 L F
.896 .947 .832 r
.50906 .48585 m .51031 .48167 L .51141 .48227 L F
.50906 .48585 m .5078 .48483 L .51031 .48167 L F
.382 .155 .441 r
.26885 .55565 m .26774 .559 L .26583 .55936 L F
.197 0 .217 r
.26715 .56047 m .26583 .55936 L .26774 .559 L F
.26715 .56047 m .26505 .56148 L .26583 .55936 L F
.694 .174 0 r
.61934 .38933 m .61508 .38715 L .6186 .38847 L F
.405 0 0 r
.6186 .38847 m .61508 .38715 L .61393 .38758 L F
.49 .469 .761 r
.67106 .30731 m .67416 .30882 L .67432 .30607 L F
0 0 0 r
.28094 .51904 m .27838 .52248 L .27981 .52109 L F
.586 .271 .401 r
.27838 .52248 m .28081 .52318 L .27981 .52109 L F
.27838 .52248 m .2772 .52481 L .28081 .52318 L F
.732 .94 .953 r
.52751 .48385 m .52851 .48509 L .53255 .48267 L F
.441 .173 .41 r
.48335 .49868 m .48326 .50102 L .48086 .49939 L F
.48335 .49868 m .48326 .50102 L .48086 .49939 L F
.717 .986 .881 r
.64498 .3794 m .64112 .38043 L .64385 .38023 L F
.345 0 0 r
.64385 .38023 m .64764 .37856 L .64498 .3794 L F
.934 .732 .606 r
.4069 .57222 m .40423 .57408 L .40245 .57183 L F
.4069 .57222 m .40622 .575 L .40423 .57408 L F
.997 .774 .458 r
.3058 .68024 m .30495 .67861 L .30739 .67746 L F
.53 .097 .163 r
.27978 .54553 m .27791 .54789 L .2757 .54661 L F
.405 .376 .713 r
.2809 .54063 m .27978 .54553 L .27826 .54192 L F
.2809 .54063 m .28158 .54499 L .27978 .54553 L F
.594 .169 .206 r
.28175 .54732 m .27978 .54553 L .28158 .54499 L F
.28175 .54732 m .27791 .54789 L .27978 .54553 L F
.312 .769 .951 r
.52941 .39407 m .52848 .39335 L .5306 .39353 L F
.53132 .39383 m .5306 .39353 L .53245 .39369 L F
.52941 .39407 m .5306 .39353 L .53132 .39383 L F
.61 .305 .428 r
.52847 .39342 m .53245 .39369 L .52848 .39335 L F
0 0 0 r
.52638 .39662 m .52848 .39335 L .52941 .39407 L F
.462 .608 .91 r
.52945 .39521 m .52638 .39662 L .52941 .39407 L F
.61 .305 .428 r
.52934 .39553 m .52955 .3954 L .52836 .39461 L F
.462 .608 .91 r
.52945 .39533 m .52923 .39542 L .52945 .39521 L F
.52923 .39542 m .52638 .39662 L .52945 .39521 L F
.61 .305 .428 r
.52836 .39461 m .52938 .39528 L .52847 .39342 L F
.52938 .39528 m .52955 .3954 L .52945 .39521 L F
.52938 .39528 m .52945 .39521 L .52847 .39342 L F
.462 .608 .91 r
.52911 .39547 m .52692 .39925 L .52638 .39662 L F
.52923 .39542 m .52919 .39549 L .52911 .39547 L F
.52919 .39549 m .52692 .39925 L .52911 .39547 L F
.52955 .39539 m .52941 .39407 L .53105 .39629 L F
.52955 .39539 m .52954 .39537 L .52955 .39539 L F
.52954 .39537 m .52941 .39407 L .52955 .39539 L F
.647 .789 .95 r
.53339 .39504 m .53105 .39629 L .52941 .39407 L F
.472 0 0 r
.53339 .39504 m .52978 .39531 L .53105 .39629 L F
.462 .608 .91 r
.52945 .39521 m .52941 .39407 L .52955 .39539 L F
.647 .789 .95 r
.53339 .39504 m .52941 .39407 L .53245 .39369 L F
.61 .305 .428 r
.52955 .39539 m .53245 .39369 L .52847 .39342 L F
.472 0 0 r
.52961 .39537 m .52955 .39539 L .52955 .39539 L F
.52978 .39531 m .52955 .39539 L .53105 .39629 L F
.61 .305 .428 r
.52955 .3954 m .52961 .39537 L .52955 .39539 L F
.52961 .39537 m .53245 .39369 L .52955 .39539 L F
.472 0 0 r
.52978 .39531 m .52945 .39533 L .52955 .39539 L F
.61 .305 .428 r
.52961 .39537 m .53233 .39441 L .53245 .39369 L F
.472 0 0 r
.52978 .39531 m .52955 .39539 L .52961 .39537 L F
.61 .305 .428 r
.52955 .3954 m .53206 .39604 L .5298 .39531 L F
.472 0 0 r
.52978 .39531 m .53206 .39604 L .52945 .39533 L F
.53339 .39504 m .53206 .39604 L .52978 .39531 L F
.61 .305 .428 r
.5298 .39531 m .53206 .39604 L .53233 .39441 L F
.52955 .3954 m .53233 .39441 L .52961 .39537 L F
.52934 .39553 m .52961 .39558 L .52955 .3954 L F
.52961 .39558 m .53206 .39604 L .52955 .3954 L F
.462 .608 .91 r
.52933 .39552 m .52692 .39925 L .52923 .39542 L F
.121 0 0 r
.5296 .39845 m .52692 .39925 L .52933 .39552 L F
.52946 .39556 m .52933 .39552 L .52945 .39533 L F
.5296 .39845 m .52933 .39552 L .52946 .39556 L F
.492 .625 .909 r
.53206 .39604 m .5296 .39845 L .52946 .39556 L F
.61 .305 .428 r
.5296 .39558 m .52961 .39559 L .52934 .39553 L F
.492 .625 .909 r
.53206 .39604 m .52946 .39556 L .52945 .39533 L F
.61 .305 .428 r
.52934 .39553 m .5296 .39558 L .52934 .39553 L F
.5296 .39558 m .53169 .39605 L .52961 .39559 L F
.5282 .3962 m .53136 .39607 L .52934 .39553 L F
.53136 .39607 m .53169 .39605 L .52934 .39553 L F
.53169 .39605 m .53206 .39604 L .52934 .39553 L F
.5282 .3962 m .52934 .39553 L .52836 .39461 L F
.462 .608 .91 r
.52945 .39533 m .52933 .39552 L .52923 .39542 L F
0 0 0 r
.52638 .39662 m .5282 .3962 L .52848 .39335 L F
.517 .422 .686 r
.52835 .3947 m .52525 .39384 L .52848 .39335 L F
.5282 .3962 m .52738 .39554 L .52835 .3947 L F
.52738 .39554 m .52525 .39384 L .52835 .3947 L F
.776 .605 .667 r
.52525 .39384 m .5257 .39703 L .52157 .39656 L F
.76 .817 .898 r
.52692 .39925 m .52449 .39912 L .52638 .39662 L F
0 0 0 r
.52638 .39662 m .5257 .39703 L .5282 .3962 L F
.517 .422 .686 r
.5282 .3962 m .5257 .39703 L .52525 .39384 L F
0 .089 .646 r
.52308 .39784 m .52157 .39656 L .5257 .39703 L F
.7 .983 .839 r
.52683 .39488 m .52308 .39784 L .52565 .39705 L F
.52573 .39698 m .52565 .39705 L .5257 .39703 L F
.52683 .39488 m .52565 .39705 L .52573 .39698 L F
.909 .944 .814 r
.52935 .39133 m .5282 .3962 L .52848 .39335 L F
.52899 .39287 m .52683 .39488 L .5282 .3962 L F
0 0 0 r
.52854 .38853 m .52478 .39105 L .5256 .38939 L F
.52854 .38853 m .52478 .39105 L .5256 .38939 L F
.52854 .38853 m .52621 .39035 L .52478 .39105 L F
.52854 .38853 m .52621 .39035 L .52478 .39105 L F
.487 .341 .608 r
.5256 .38939 m .52854 .38853 L .52806 .38549 L F
.173 .124 .558 r
.52984 .38677 m .52854 .38853 L .52806 .38549 L F
.698 .949 .671 r
.52984 .38677 m .52621 .39035 L .52854 .38853 L F
.52854 .38853 m .52621 .39035 L .52984 .38677 L F
.184 .336 .783 r
.52935 .39133 m .52848 .39335 L .52671 .38961 L F
.909 .944 .814 r
.52935 .39133 m .52842 .39264 L .52899 .39287 L F
.543 .548 .809 r
.52671 .38961 m .52848 .39335 L .52525 .39384 L F
.909 .944 .814 r
.52842 .39264 m .52683 .39488 L .52899 .39287 L F
.462 .608 .91 r
.52945 .39533 m .52945 .39521 L .52955 .39539 L F
.541 .635 .893 r
.51021 .41768 m .50847 .4192 L .50679 .41548 L F
.074 .584 .886 r
.65795 .36696 m .6614 .36715 L .65811 .36673 L F
.275 .047 .376 r
.65795 .36696 m .6589 .37062 L .6614 .36715 L F
.774 .583 .64 r
.58121 .37523 m .5859 .37471 L .58341 .3716 L F
.58121 .37523 m .58651 .37586 L .5859 .37471 L F
.279 .353 .761 r
.58651 .37586 m .58793 .37531 L .5859 .37471 L F
.383 .208 .517 r
.5859 .37471 m .58793 .37531 L .58762 .37247 L F
.618 .64 .85 r
.32577 .63225 m .32312 .63443 L .32174 .6311 L F
.744 .736 .845 r
.40272 .55543 m .39964 .55824 L .40332 .55819 L F
.379 .117 .386 r
.40036 .56168 m .40332 .55819 L .39964 .55824 L F
.40036 .56168 m .4027 .56137 L .40332 .55819 L F
.804 .542 .542 r
.40547 .55766 m .40272 .55543 L .40332 .55819 L F
.287 .039 .353 r
.40332 .55819 m .40519 .56033 L .40547 .55766 L F
.40332 .55819 m .4027 .56137 L .40519 .56033 L F
.675 .882 .975 r
.46046 .55127 m .45906 .55002 L .45665 .55128 L F
.824 .917 .9 r
.46203 .54747 m .46046 .55127 L .46388 .54908 L F
.46203 .54747 m .45906 .55002 L .46046 .55127 L F
.37 .815 .675 r
.45968 .44144 m .45792 .44247 L .46028 .4412 L F
.361 .796 .624 r
.45603 .44352 m .45792 .44247 L .45968 .44144 L F
0 0 0 r
.52457 .41851 m .52787 .41551 L .52661 .41632 L F
.692 .973 .772 r
.52558 .41676 m .52457 .41851 L .52661 .41632 L F
.116 0 0 r
.52661 .41632 m .52907 .41615 L .52604 .41668 L F
.52661 .41632 m .52604 .41668 L .52558 .41676 L F
0 0 0 r
.52787 .41551 m .52829 .41514 L .52661 .41632 L F
.525 .606 .876 r
.52993 .41278 m .52829 .41514 L .52736 .41369 L F
.52993 .41278 m .5311 .41532 L .52829 .41514 L F
.257 0 0 r
.52829 .41514 m .52907 .41615 L .52661 .41632 L F
.52829 .41514 m .5311 .41532 L .52907 .41615 L F
.365 0 .014 r
.32484 .56188 m .32072 .564 L .3218 .56518 L F
.709 .507 .613 r
.39822 .51562 m .40055 .51822 L .40216 .51869 L F
.967 .905 .705 r
.39916 .52014 m .40216 .51869 L .40055 .51822 L F
.39916 .52014 m .40042 .52161 L .40216 .51869 L F
.324 0 .031 r
.30739 .67746 m .31196 .67527 L .31056 .67735 L F
.616 .917 .654 r
.28198 .62291 m .27895 .62585 L .28052 .62396 L F
.245 0 0 r
.59409 .34225 m .59818 .3428 L .59575 .34234 L F
.779 .781 .855 r
.54514 .39631 m .54089 .3954 L .54379 .39317 L F
.742 .447 .481 r
.54514 .39631 m .54022 .39801 L .54089 .3954 L F
.54514 .39631 m .54459 .39859 L .54022 .39801 L F
.464 .717 .978 r
.54574 .39387 m .54514 .39631 L .54379 .39317 L F
.54574 .39387 m .54664 .39554 L .54514 .39631 L F
.522 .235 .419 r
.54744 .3979 m .54514 .39631 L .54664 .39554 L F
.54744 .3979 m .54459 .39859 L .54514 .39631 L F
.214 0 0 r
.60382 .34936 m .60285 .35127 L .59977 .35206 L F
0 0 0 r
.60382 .34936 m .60451 .35209 L .60641 .34882 L F
.60382 .34936 m .60437 .34956 L .60451 .35209 L F
.60382 .34936 m .60285 .35127 L .60437 .34956 L F
.278 0 .062 r
.32445 .6823 m .32988 .67916 L .3287 .68174 L F
.392 .067 .29 r
.33012 .67923 m .3317 .67882 L .32988 .67916 L F
.255 0 0 r
.32988 .67916 m .33041 .67998 L .3287 .68174 L F
.32988 .67916 m .3317 .67882 L .33041 .67998 L F
.348 .219 .559 r
.35017 .65378 m .34765 .65533 L .34818 .65195 L F
.35017 .65378 m .34765 .65533 L .34818 .65195 L F
.363 .031 .262 r
.51821 .40283 m .52083 .40241 L .52161 .40027 L F
.058 0 .124 r
.52161 .40027 m .52332 .40061 L .52449 .39912 L F
.52161 .40027 m .52083 .40241 L .52332 .40061 L F
.64 .638 .833 r
.32008 .60774 m .3215 .61151 L .32426 .60872 L F
.892 .715 .655 r
.39406 .56771 m .39561 .57197 L .39595 .56906 L F
.692 .765 .907 r
.39406 .56771 m .39595 .56906 L .39877 .56808 L F
.743 .833 .92 r
.40272 .55543 m .40657 .55557 L .40608 .55383 L F
.804 .542 .542 r
.40547 .55766 m .40657 .55557 L .40272 .55543 L F
.293 .518 .901 r
.40608 .55383 m .40657 .55557 L .40762 .55365 L F
.078 0 0 r
.38738 .47265 m .39175 .4715 L .38922 .47279 L F
0 .484 .75 r
.39175 .4715 m .39297 .47161 L .38922 .47279 L F
.39175 .4715 m .39443 .47206 L .39297 .47161 L F
.616 .516 .717 r
.32151 .53399 m .32311 .53085 L .32124 .53293 L F
.692 .898 .971 r
.67811 .37087 m .67965 .36813 L .67614 .37041 L F
.67811 .37087 m .68072 .36935 L .67965 .36813 L F
.031 .238 .741 r
.2474 .57227 m .24982 .57437 L .24816 .57048 L F
.905 .739 .666 r
.34354 .56197 m .34192 .55849 L .34161 .56144 L F
.839 .541 .486 r
.34094 .56421 m .34354 .56197 L .34161 .56144 L F
.34094 .56421 m .34517 .56445 L .34354 .56197 L F
.365 0 .014 r
.32484 .56188 m .32338 .56385 L .32072 .564 L F
.657 .642 .824 r
.3265 .55938 m .32484 .56188 L .32391 .55929 L F
.038 0 0 r
.32713 .56165 m .32338 .56385 L .32484 .56188 L F
.024 0 .267 r
.65071 .39733 m .65155 .39745 L .64907 .39931 L F
.58 .896 .628 r
.49484 .40365 m .49178 .40644 L .49384 .40446 L F
.582 .943 .833 r
.49178 .40644 m .49309 .40495 L .49384 .40446 L F
.49178 .40644 m .48961 .40689 L .49309 .40495 L F
.87 .87 .835 r
.51947 .42274 m .52128 .41766 L .51845 .4192 L F
.528 .256 .446 r
.58121 .37523 m .58065 .37859 L .58337 .37577 L F
.899 .972 .816 r
.58337 .37577 m .58135 .37638 L .58112 .37578 L F
.528 .256 .446 r
.58121 .37523 m .58337 .37577 L .58561 .37575 L F
.836 .908 .887 r
.5817 .37362 m .58121 .37523 L .58012 .37317 L F
.899 .972 .816 r
.58337 .37577 m .58112 .37578 L .58012 .37317 L F
.528 .256 .446 r
.58561 .37575 m .58337 .37577 L .58651 .37586 L F
.317 0 0 r
.58337 .37577 m .58793 .37531 L .58651 .37586 L F
.913 .683 .576 r
.67766 .33863 m .67754 .34143 L .6809 .34222 L F
.933 .768 .655 r
.67732 .34421 m .6809 .34222 L .67754 .34143 L F
.67732 .34421 m .67905 .34558 L .6809 .34222 L F
.452 .036 .158 r
.43262 .4557 m .42829 .45831 L .43002 .45664 L F
.535 .314 .526 r
.32333 .53894 m .32636 .54081 L .32568 .53763 L F
.714 .495 .591 r
.40768 .56494 m .40472 .56256 L .4082 .56214 L F
.40768 .56494 m .40535 .5654 L .40472 .56256 L F
.73 .462 .523 r
.38694 .51469 m .38993 .51549 L .39035 .51237 L F
.724 .534 .633 r
.38993 .51549 m .39193 .51185 L .39035 .51237 L F
.863 .85 .829 r
.29866 .65432 m .30069 .65554 L .30274 .65229 L F
.995 .798 .528 r
.66287 .34621 m .66124 .34773 L .66059 .34566 L F
.66287 .34621 m .66261 .3492 L .66124 .34773 L F
.95 .926 .573 r
.32049 .5868 m .32308 .58338 L .31833 .58438 L F
.32049 .5868 m .32097 .58893 L .32308 .58338 L F
.881 .871 .822 r
.65428 .37595 m .65182 .37946 L .65051 .37762 L F
.922 .613 .44 r
.33881 .52831 m .34 .53154 L .34198 .53222 L F
.945 .738 .592 r
.33952 .53332 m .34198 .53222 L .34 .53154 L F
.33952 .53332 m .34161 .53504 L .34198 .53222 L F
0 0 0 r
.64446 .34591 m .64323 .34671 L .64046 .34736 L F
.64583 .34569 m .64446 .34591 L .64716 .34485 L F
.64583 .34569 m .64323 .34671 L .64446 .34591 L F
.905 .575 .41 r
.54949 .41555 m .55268 .41871 L .54929 .41824 L F
.931 .827 .721 r
.55268 .41871 m .54908 .42118 L .54929 .41824 L F
.55268 .41871 m .55089 .42264 L .54908 .42118 L F
.714 .613 .742 r
.30274 .65229 m .30726 .65544 L .30544 .65424 L F
.55 .051 .024 r
.30967 .65421 m .30544 .65424 L .30726 .65544 L F
0 0 0 r
.30726 .65544 m .30808 .65507 L .30967 .65421 L F
.825 .577 .564 r
.68294 .35143 m .68683 .34957 L .68277 .34921 L F
.68294 .35143 m .68679 .35232 L .68683 .34957 L F
.55 .664 .912 r
.52209 .47756 m .52214 .47953 L .51786 .477 L F
.621 .388 .542 r
.26592 .53192 m .26908 .52884 L .26636 .52917 L F
.26592 .53192 m .2688 .53185 L .26908 .52884 L F
.539 .317 .526 r
.26908 .52884 m .27166 .53129 L .27183 .5282 L F
.26908 .52884 m .2688 .53185 L .27166 .53129 L F
0 0 0 r
.55299 .46289 m .55131 .4644 L .54958 .46579 L F
.54958 .46579 m .55131 .4644 L .5482 .46731 L F
.936 .632 .441 r
.33653 .52476 m .33881 .52831 L .33924 .52575 L F
.519 0 0 r
.65426 .34353 m .65272 .34483 L .65022 .3442 L F
.507 0 0 r
.65674 .34479 m .65272 .34483 L .65426 .34353 L F
.556 .326 .521 r
.27106 .55633 m .26885 .55565 L .26981 .5551 L F
.27106 .55633 m .26774 .559 L .26885 .55565 L F
.964 .827 .661 r
.49111 .50195 m .48824 .5039 L .48968 .50059 L F
.49111 .50195 m .49028 .50532 L .48824 .5039 L F
.824 .916 .899 r
.49439 .49891 m .49111 .50195 L .48968 .50059 L F
.75 .305 .195 r
.31274 .68446 m .31712 .68502 L .31523 .68508 L F
.848 .517 .427 r
.31523 .68508 m .31712 .68502 L .31502 .68833 L F
.75 .305 .195 r
.31274 .68446 m .31712 .68502 L .31523 .68508 L F
.256 0 .074 r
.31502 .68833 m .31712 .68502 L .31938 .68433 L F
.826 .661 .678 r
.34255 .5681 m .34673 .56867 L .34517 .56445 L F
.802 .637 .678 r
.34255 .5681 m .34616 .57164 L .34673 .56867 L F
.105 0 0 r
.42104 .45398 m .42347 .45317 L .42503 .4512 L F
.196 0 0 r
.42503 .4512 m .42749 .45101 L .42834 .44934 L F
.118 0 0 r
.42605 .45209 m .42503 .4512 L .42347 .45317 L F
.42605 .45209 m .42749 .45101 L .42503 .4512 L F
.151 0 .098 r
.27981 .52109 m .28365 .51711 L .28094 .51904 L F
.808 .731 .779 r
.43401 .59106 m .43799 .59142 L .43706 .58797 L F
.783 .78 .85 r
.43401 .59106 m .43625 .59235 L .43799 .59142 L F
.673 .652 .821 r
.43706 .58797 m .43799 .59142 L .44105 .58909 L F
0 0 0 r
.49384 .40446 m .49707 .40238 L .49484 .40365 L F
.121 0 0 r
.5296 .39845 m .52703 .4011 L .52692 .39925 L F
0 0 .242 r
.57381 .37771 m .57392 .38097 L .57298 .38277 L F
.062 .316 .799 r
.57392 .38097 m .57577 .38462 L .57298 .38277 L F
.694 .769 .909 r
.43021 .56616 m .42606 .5661 L .42823 .56462 L F
.822 .799 .83 r
.43272 .5632 m .43021 .56616 L .42823 .56462 L F
.34 .375 .752 r
.25559 .54793 m .25711 .55229 L .25865 .55109 L F
0 0 .093 r
.25711 .55229 m .25626 .55461 L .25865 .55109 L F
.795 .951 .921 r
.51543 .49334 m .51487 .49609 L .51655 .49366 L F
.817 .967 .901 r
.51359 .49526 m .51487 .49609 L .51543 .49334 L F
.02 0 0 r
.64227 .33857 m .64493 .33797 L .6459 .33657 L F
.115 0 0 r
.6459 .33657 m .64752 .33721 L .64864 .3362 L F
.6459 .33657 m .64493 .33797 L .64752 .33721 L F
.096 0 0 r
.42749 .45101 m .43064 .44814 L .42834 .44934 L F
0 0 .121 r
.32636 .54081 m .32563 .54566 L .32626 .5438 L F
.97 .801 .375 r
.32674 .54779 m .32626 .5438 L .32563 .54566 L F
.838 .715 .186 r
.56379 .37195 m .56372 .36658 L .56248 .3701 L F
0 0 0 r
.41192 .45835 m .4143 .45719 L .41576 .45545 L F
.073 0 0 r
.4143 .45719 m .4184 .45483 L .41576 .45545 L F
.603 .512 .724 r
.51464 .40583 m .51293 .40412 L .51457 .40219 L F
.376 .527 .88 r
.51293 .40412 m .51464 .40583 L .51457 .40219 L F
.401 .828 .668 r
.46209 .42943 m .45797 .43168 L .45998 .43006 L F
.592 .915 .674 r
.46209 .42943 m .46339 .42788 L .46535 .42667 L F
.601 .947 .799 r
.45998 .43006 m .46339 .42788 L .46209 .42943 L F
.952 .757 .603 r
.65958 .39112 m .66145 .39263 L .66006 .38866 L F
.881 .724 .682 r
.65762 .39465 m .66145 .39263 L .65958 .39112 L F
.65762 .39465 m .65898 .39743 L .66145 .39263 L F
.452 0 0 r
.59447 .4053 m .5938 .40488 L .59507 .40574 L F
.59035 .40226 m .5938 .40488 L .59447 .4053 L F
.155 .311 .771 r
.5921 .40048 m .5938 .40488 L .59035 .40226 L F
.576 .582 .822 r
.59652 .40383 m .5938 .40488 L .5921 .40048 L F
.473 .888 .925 r
.59309 .40443 m .5938 .40488 L .59652 .40383 L F
.59198 .40463 m .5938 .40488 L .59309 .40443 L F
.011 .584 .752 r
.30191 .68651 m .30336 .68669 L .30611 .68677 L F
.021 .573 .826 r
.30336 .68669 m .30881 .68764 L .30611 .68677 L F
.341 .173 .503 r
.28756 .52135 m .28532 .52245 L .28745 .51865 L F
.165 0 .344 r
.28631 .52366 m .28532 .52245 L .28756 .52135 L F
.28631 .52366 m .28468 .52531 L .28532 .52245 L F
.801 .996 .776 r
.51141 .48227 m .5122 .48012 L .5144 .4791 L F
.595 .936 .751 r
.5144 .4791 m .51586 .47742 L .51629 .47772 L F
.5144 .4791 m .5122 .48012 L .51586 .47742 L F
.829 .696 .717 r
.34271 .58487 m .34016 .58829 L .34432 .58864 L F
.687 .506 .636 r
.30336 .60627 m .30404 .60843 L .29978 .60793 L F
.743 .768 .265 r
.30336 .60627 m .30465 .60162 L .3066 .60586 L F
.794 .805 .86 r
.3066 .60586 m .30404 .60843 L .30336 .60627 L F
.965 .826 .657 r
.34273 .54385 m .3429 .54861 L .34446 .54492 L F
.668 .973 .894 r
.29316 .63985 m .28861 .642 L .29168 .63857 L F
.434 .673 .963 r
.29421 .63774 m .29316 .63985 L .29168 .63857 L F
.29421 .63774 m .29506 .63989 L .29316 .63985 L F
.84 .646 .641 r
.32163 .51564 m .32128 .51858 L .31728 .51752 L F
.745 .969 .931 r
.51141 .48227 m .51031 .48167 L .5122 .48012 L F
.562 .883 .61 r
.50309 .39825 m .50447 .39669 L .50665 .39616 L F
.50309 .39825 m .50284 .39825 L .50447 .39669 L F
.651 .835 .971 r
.41542 .59863 m .41933 .59885 L .41772 .59745 L F
.781 .972 .682 r
.42224 .59522 m .41933 .59885 L .42029 .59664 L F
.49 .698 .961 r
.41933 .59885 m .42194 .59852 L .42029 .59664 L F
.596 .525 .746 r
.25559 .54793 m .25783 .54482 L .25548 .54549 L F
.613 .061 0 r
.60798 .35296 m .60642 .3537 L .60451 .35209 L F
.611 .929 .698 r
.60792 .35224 m .60798 .35296 L .61071 .35214 L F
.60792 .35224 m .60642 .3537 L .60798 .35296 L F
.082 .229 .718 r
.35336 .6347 m .35272 .63167 L .35303 .63391 L F
.709 .641 .082 r
.35313 .63661 m .35336 .6347 L .35303 .63391 L F
.35313 .63661 m .35287 .63917 L .35336 .6347 L F
.937 .615 .401 r
.3826 .51727 m .38506 .5191 L .38399 .51618 L F
.38399 .51618 m .38506 .5191 L .3826 .51727 L F
.971 .857 .671 r
.42061 .58869 m .4197 .59327 L .41789 .58974 L F
.752 .819 .905 r
.41789 .58974 m .4197 .59327 L .4158 .59204 L F
.813 .603 .618 r
.39561 .57197 m .39458 .57544 L .39847 .5756 L F
.437 .836 .979 r
.39561 .57736 m .39847 .5756 L .39458 .57544 L F
.39561 .57736 m .39961 .57717 L .39847 .5756 L F
.13 0 0 r
.28377 .53543 m .2834 .53594 L .28236 .53592 L F
.79 .343 .186 r
.29703 .6514 m .29867 .65329 L .29473 .65128 L F
.014 0 0 r
.42224 .59522 m .42029 .59664 L .41772 .59745 L F
0 0 0 r
.55007 .34319 m .55063 .34282 L .55192 .34093 L F
.371 .727 .989 r
.54896 .34173 m .55045 .34271 L .54664 .34253 L F
.553 .82 .46 r
.55074 .34235 m .55037 .3428 L .55007 .34319 L F
.371 .727 .989 r
.55045 .34271 m .55063 .34282 L .55037 .3428 L F
.55045 .34271 m .55037 .3428 L .54664 .34253 L F
.553 .82 .46 r
.55192 .34093 m .55054 .3426 L .55007 .34319 L F
.759 .862 .925 r
.55192 .34093 m .55063 .34282 L .55045 .34271 L F
.55192 .34093 m .55045 .34271 L .54896 .34173 L F
.553 .82 .46 r
.55192 .34093 m .55074 .34235 L .55054 .3426 L F
.55074 .34235 m .55058 .34254 L .55037 .3428 L F
.645 .139 .028 r
.54971 .34312 m .54914 .34429 L .54664 .34253 L F
.55007 .34319 m .54914 .34429 L .54971 .34312 L F
.235 .701 .945 r
.54664 .34253 m .55037 .3428 L .55007 .34319 L F
.645 .139 .028 r
.54664 .34253 m .54914 .34429 L .55007 .34319 L F
.294 .342 .742 r
.54664 .34253 m .54914 .34429 L .54896 .34173 L F
0 .243 .738 r
.5479 .34255 m .54914 .34429 L .54664 .34253 L F
0 .09 .605 r
.54925 .34693 m .54514 .34639 L .54914 .34429 L F
.968 .693 .271 r
.5479 .34255 m .54871 .34517 L .54914 .34429 L F
.54871 .34517 m .54925 .34693 L .54914 .34429 L F
.553 .82 .46 r
.55058 .34254 m .54914 .34429 L .55007 .34319 L F
.235 .701 .945 r
.55037 .3428 m .55063 .34282 L .55007 .34319 L F
.622 .111 .013 r
.54914 .34429 m .55336 .34498 L .55007 .34319 L F
.553 .82 .46 r
.55192 .34093 m .54914 .34429 L .55007 .34319 L F
.841 .66 .657 r
.4432 .55168 m .44472 .55571 L .44093 .55527 L F
.754 .324 .231 r
.44093 .55527 m .44472 .55571 L .44325 .55758 L F
.589 .828 .449 r
.44325 .55758 m .44472 .55571 L .44228 .55895 L F
.45 .88 .803 r
.65186 .39691 m .65155 .39745 L .65071 .39733 L F
.6563 .3953 m .65155 .39745 L .65186 .39691 L F
.967 .685 .267 r
.65223 .39625 m .65155 .39745 L .65116 .39455 L F
.6523 .39635 m .65155 .39745 L .65223 .39625 L F
.126 0 .233 r
.27154 .64626 m .2732 .64211 L .27077 .64563 L F
.154 0 .249 r
.27458 .64124 m .2732 .64211 L .27154 .64626 L F
.826 .949 .901 r
.48645 .52558 m .48507 .5246 L .48171 .52751 L F
.99 .861 .613 r
.48659 .52215 m .48507 .5246 L .48645 .52558 L F
0 0 0 r
.46339 .42788 m .46411 .42795 L .46574 .4266 L F
.498 .839 .56 r
.46574 .4266 m .46411 .42795 L .46426 .42781 L F
0 0 0 r
.46535 .42667 m .46574 .4266 L .46725 .42537 L F
.498 .839 .56 r
.46574 .4266 m .46426 .42781 L .46723 .42519 L F
0 0 0 r
.46725 .42537 m .46574 .4266 L .46737 .42528 L F
.46535 .42667 m .46339 .42788 L .46574 .4266 L F
.276 .648 .967 r
.27993 .67416 m .28037 .67178 L .27857 .67428 L F
.27993 .67416 m .2827 .67453 L .28037 .67178 L F
.466 .401 .699 r
.27998 .6584 m .28255 .66085 L .28014 .66208 L F
.49 .479 .772 r
.2839 .66451 m .28014 .66208 L .28255 .66085 L F
.2839 .66451 m .28153 .66471 L .28014 .66208 L F
.951 .907 .741 r
.55196 .46116 m .55488 .45908 L .55325 .45769 L F
.55196 .46116 m .55299 .46289 L .55488 .45908 L F
.913 .932 .81 r
.27974 .66416 m .28153 .66471 L .27882 .66854 L F
0 0 .332 r
.35374 .64046 m .35287 .63917 L .35313 .63661 L F
.303 .593 .946 r
.65578 .36504 m .65811 .36673 L .6557 .36621 L F
.129 .508 .91 r
.65626 .36466 m .65811 .36673 L .65578 .36504 L F
.262 .597 .951 r
.65626 .36466 m .6557 .36621 L .65578 .36504 L F
.65626 .36466 m .65811 .36673 L .6557 .36621 L F
.6557 .36621 m .65626 .36466 L .65578 .36504 L F
.6557 .36621 m .65811 .36673 L .65626 .36466 L F
.207 .701 .919 r
.42061 .58869 m .42007 .58814 L .41645 .5881 L F
.772 .997 .826 r
.42061 .58869 m .41789 .58974 L .42007 .58814 L F
.881 .871 .822 r
.65428 .37595 m .65051 .37762 L .65318 .37651 L F
.465 .854 .648 r
.65652 .37422 m .65428 .37595 L .65318 .37651 L F
.794 .805 .86 r
.3066 .60586 m .30587 .60787 L .30404 .60843 L F
.722 .722 .85 r
.30898 .60463 m .30587 .60787 L .3066 .60586 L F
.731 .791 .9 r
.31088 .60642 m .30587 .60787 L .30898 .60463 L F
.959 .883 .714 r
.34046 .5578 m .34383 .55516 L .342 .55428 L F
.34046 .5578 m .34192 .55849 L .34383 .55516 L F
.721 .742 .869 r
.30898 .60463 m .31334 .6052 L .31088 .60642 L F
.697 .526 .652 r
.39193 .51185 m .39533 .51494 L .39463 .51233 L F
.198 0 .223 r
.56422 .38971 m .56403 .39141 L .56641 .38883 L F
.263 0 0 r
.57628 .38727 m .57638 .38697 L .57577 .38462 L F
.456 .353 .649 r
.57638 .38697 m .57983 .38792 L .57771 .38925 L F
.263 0 0 r
.57628 .38727 m .57983 .38792 L .57638 .38697 L F
.212 .737 .809 r
.6458 .39691 m .64397 .39693 L .64123 .39739 L F
.496 .905 .893 r
.64702 .39554 m .6458 .39691 L .64829 .39505 L F
.64702 .39554 m .64397 .39693 L .6458 .39691 L F
.294 0 .055 r
.6582 .33352 m .65552 .33315 L .65512 .33403 L F
.6582 .33352 m .65817 .3325 L .65552 .33315 L F
.571 .397 .606 r
.28101 .65644 m .27998 .6584 L .28264 .65503 L F
.844 .99 .853 r
.61782 .39047 m .61934 .38933 L .6186 .38847 L F
.456 .834 .989 r
.6186 .38847 m .62195 .3888 L .61934 .38933 L F
.6186 .38847 m .62195 .3888 L .61934 .38933 L F
.142 0 0 r
.24998 .55766 m .25255 .55707 L .25419 .55565 L F
.109 0 0 r
.25255 .55707 m .25626 .55461 L .25419 .55565 L F
.9 .872 .801 r
.27882 .66854 m .27698 .67155 L .27516 .67005 L F
.774 .295 0 r
.27516 .67005 m .27698 .67155 L .27857 .67428 L F
.195 .287 .732 r
.57144 .3594 m .57397 .36133 L .57294 .35723 L F
.936 .798 .682 r
.52497 .47211 m .5245 .47595 L .52242 .47432 L F
.908 .821 .749 r
.5245 .47595 m .52209 .47756 L .52242 .47432 L F
.908 .928 .816 r
.51585 .442 m .51764 .44017 L .51799 .43855 L F
.777 .587 .643 r
.41147 .53511 m .41392 .53897 L .41395 .53575 L F
.828 .464 .366 r
.34671 .50929 m .34308 .5102 L .34313 .50778 L F
.34671 .50929 m .34708 .51151 L .34308 .5102 L F
.763 .555 .616 r
.51464 .40583 m .51882 .40576 L .51821 .40283 L F
.591 .443 .649 r
.51821 .40283 m .52148 .40426 L .52083 .40241 L F
.51821 .40283 m .51882 .40576 L .52148 .40426 L F
.669 .881 .977 r
.65682 .39977 m .6578 .39718 L .6563 .3953 L F
.65682 .39977 m .65889 .39855 L .6578 .39718 L F
.792 .868 .905 r
.30713 .61636 m .31204 .61513 L .30985 .61379 L F
.847 .808 .812 r
.31204 .61513 m .31056 .61235 L .30985 .61379 L F
.31204 .61513 m .31467 .61177 L .31056 .61235 L F
.82 .525 .49 r
.43806 .57512 m .43462 .57749 L .43655 .57937 L F
.392 .067 .29 r
.33012 .67923 m .33226 .67841 L .3317 .67882 L F
.922 .784 .691 r
.42818 .59441 m .43163 .59408 L .43127 .59171 L F
.813 1 .826 r
.42702 .59684 m .43163 .59408 L .42818 .59441 L F
.42702 .59684 m .42809 .59711 L .43163 .59408 L F
.882 .539 .044 r
.45298 .54554 m .45213 .5447 L .45132 .54155 L F
.938 .966 .719 r
.45064 .54706 m .45298 .54554 L .45262 .54823 L F
.45064 .54706 m .45213 .5447 L .45298 .54554 L F
.889 .983 .813 r
.49968 .50812 m .49569 .51099 L .49707 .51203 L F
.49968 .50812 m .49841 .50761 L .49569 .51099 L F
.743 .975 .923 r
.49968 .50812 m .50073 .50573 L .49841 .50761 L F
.49968 .50812 m .50306 .50564 L .50073 .50573 L F
.06 0 .093 r
.58728 .36787 m .58341 .3716 L .58446 .36978 L F
.978 .919 .63 r
.29686 .61011 m .29978 .60793 L .29788 .61164 L F
.768 .534 .58 r
.29978 .60793 m .30143 .61278 L .29788 .61164 L F
0 .236 .754 r
.29792 .60439 m .29978 .60793 L .30079 .60695 L F
.482 .843 .59 r
.30079 .60695 m .29978 .60793 L .29686 .61011 L F
.641 .434 .588 r
.30404 .60843 m .30143 .61278 L .29978 .60793 L F
.694 .783 .919 r
.27703 .66693 m .27882 .66854 L .27447 .66797 L F
.9 .872 .801 r
.27882 .66854 m .27516 .67005 L .27447 .66797 L F
.913 .932 .81 r
.27974 .66416 m .27882 .66854 L .27703 .66693 L F
.979 .796 .587 r
.55386 .45034 m .55621 .45144 L .55617 .44907 L F
.976 .814 .618 r
.55446 .45542 m .55621 .45144 L .55386 .45034 L F
.699 .825 .943 r
.29156 .62122 m .29344 .62304 L .29578 .62169 L F
.936 .798 .682 r
.52497 .47211 m .52242 .47432 L .52242 .47156 L F
.849 .795 .798 r
.31056 .61235 m .31467 .61177 L .3131 .60865 L F
.763 .765 .855 r
.3131 .60865 m .31467 .61177 L .31764 .60905 L F
.779 .473 .47 r
.51786 .477 m .51704 .47566 L .52004 .47564 L F
.51786 .477 m .51629 .47772 L .51704 .47566 L F
.839 .988 .717 r
.51629 .47772 m .52004 .47564 L .51704 .47566 L F
.828 .9 .89 r
.594 .38402 m .59827 .3826 L .59546 .38081 L F
0 0 0 r
.59966 .3805 m .59827 .3826 L .59935 .38108 L F
.476 .53 .833 r
.59827 .3826 m .59976 .38367 L .59935 .38108 L F
0 0 .002 r
.51499 .43556 m .51219 .43852 L .51578 .43798 L F
.331 0 .237 r
.51578 .43798 m .51219 .43852 L .51166 .44115 L F
.762 .769 .859 r
.32426 .60872 m .32875 .60902 L .32655 .60771 L F
.795 .738 .8 r
.32655 .60771 m .32875 .60902 L .33119 .60593 L F
.865 .59 .521 r
.33488 .52097 m .33653 .52476 L .33651 .52225 L F
.85 .992 .739 r
.66025 .38598 m .66225 .38208 L .65915 .38477 L F
.66025 .38598 m .66281 .38261 L .66225 .38208 L F
.996 .78 .42 r
.65915 .38477 m .66006 .38866 L .66025 .38598 L F
.721 .605 .727 r
.39728 .55956 m .40036 .56168 L .39964 .55824 L F
.39728 .55956 m .39684 .5625 L .40036 .56168 L F
.737 .42 .445 r
.39746 .56355 m .40036 .56168 L .39684 .5625 L F
.39746 .56355 m .39943 .56419 L .40036 .56168 L F
.637 .435 .593 r
.39943 .56419 m .4027 .56137 L .40036 .56168 L F
.751 .676 .778 r
.59142 .43587 m .59451 .43267 L .58997 .43183 L F
.979 .796 .587 r
.55386 .45034 m .55617 .44907 L .55437 .4478 L F
.85 .856 .847 r
.55437 .4478 m .55617 .44907 L .55896 .44578 L F
.953 .748 .589 r
.34113 .54035 m .34349 .53873 L .34155 .53784 L F
.34113 .54035 m .34315 .54168 L .34349 .53873 L F
.341 .772 .97 r
.40845 .59495 m .40686 .59435 L .4041 .59452 L F
0 .36 .829 r
.40845 .59495 m .40958 .59469 L .40686 .59435 L F
.40845 .59495 m .41141 .59652 L .40958 .59469 L F
.179 .284 .735 r
.57276 .37403 m .57381 .37771 L .57123 .37619 L F
.51 .418 .687 r
.24819 .56234 m .24998 .55766 L .2482 .55854 L F
.893 .964 .831 r
.48649 .50906 m .48376 .51257 L .48265 .51157 L F
.596 .525 .746 r
.25559 .54793 m .25867 .54834 L .25783 .54482 L F
.34 .375 .752 r
.25559 .54793 m .25865 .55109 L .25867 .54834 L F
.474 .714 .975 r
.29072 .67567 m .29096 .67743 L .28936 .67745 L F
.29072 .67567 m .29394 .6772 L .29096 .67743 L F
.818 .744 .782 r
.32931 .60434 m .3335 .6045 L .33218 .60095 L F
.803 .783 .834 r
.33119 .60593 m .3335 .6045 L .32931 .60434 L F
.761 .717 .811 r
.33218 .60095 m .3335 .6045 L .33615 .60137 L F
.386 0 .124 r
.29745 .66435 m .30072 .66389 L .3018 .66168 L F
.908 .58 .413 r
.27795 .66038 m .27998 .6584 L .27765 .65776 L F
.659 .118 0 r
.28078 .66011 m .27998 .6584 L .27795 .66038 L F
.28078 .66011 m .28255 .66085 L .27998 .6584 L F
.869 .593 .517 r
.35809 .49987 m .36255 .49833 L .35777 .49757 L F
.35809 .49987 m .36183 .50161 L .36255 .49833 L F
.881 .606 .517 r
.36255 .49833 m .36378 .50201 L .36629 .4989 L F
.36255 .49833 m .36183 .50161 L .36378 .50201 L F
.752 .994 .852 r
.66281 .38261 m .66614 .37976 L .66412 .38018 L F
.754 .995 .838 r
.66225 .38208 m .66281 .38261 L .66412 .38018 L F
.685 .829 .952 r
.56483 .40062 m .56912 .39854 L .56724 .39733 L F
.56483 .40062 m .5685 .4004 L .56912 .39854 L F
.863 .919 .866 r
.56724 .39733 m .56912 .39854 L .57169 .39542 L F
.359 0 0 r
.57216 .39962 m .56912 .39854 L .5685 .4004 L F
.787 .315 .112 r
.34892 .64138 m .35085 .64439 L .34948 .64446 L F
.822 .799 .83 r
.43272 .5632 m .42823 .56462 L .43122 .5617 L F
.727 .824 .925 r
.43519 .56189 m .43272 .5632 L .43122 .5617 L F
0 .06 .571 r
.27154 .64626 m .27077 .64563 L .27253 .64723 L F
.4 .185 .468 r
.27253 .64723 m .27077 .64563 L .27029 .64871 L F
.774 .368 .281 r
.35375 .51492 m .35143 .51679 L .35146 .51446 L F
.35375 .51492 m .35554 .51768 L .35143 .51679 L F
.671 .721 .887 r
.53199 .46348 m .52792 .46295 L .53033 .46166 L F
.715 .789 .91 r
.53467 .46219 m .53199 .46348 L .53033 .46166 L F
.865 .63 .58 r
.36174 .52208 m .35912 .52165 L .35948 .51854 L F
.846 .516 .429 r
.36174 .52208 m .35932 .52405 L .35912 .52165 L F
.895 .605 .489 r
.36185 .52476 m .35932 .52405 L .36174 .52208 L F
.892 .715 .655 r
.39406 .56771 m .39244 .57148 L .39561 .57197 L F
.851 .646 .625 r
.39149 .57445 m .39561 .57197 L .39244 .57148 L F
.39149 .57445 m .39458 .57544 L .39561 .57197 L F
.221 .002 .355 r
.34774 .65764 m .34765 .65533 L .35017 .65378 L F
.34774 .65764 m .34765 .65533 L .35017 .65378 L F
.896 .667 .584 r
.30843 .68712 m .31192 .68527 L .31274 .68446 L F
.30843 .68712 m .31194 .68747 L .31192 .68527 L F
.812 .947 .911 r
.31194 .68747 m .31274 .68446 L .31192 .68527 L F
.718 .684 .816 r
.34476 .62537 m .3463 .62875 L .34197 .628 L F
.725 .687 .814 r
.34937 .62596 m .3463 .62875 L .34476 .62537 L F
.72 .678 .809 r
.34937 .62596 m .34946 .6281 L .3463 .62875 L F
.073 0 0 r
.48782 .42496 m .49136 .42313 L .4902 .42174 L F
.521 .652 .917 r
.49136 .42313 m .49245 .41849 L .4902 .42174 L F
.49136 .42313 m .49439 .42272 L .49245 .41849 L F
.578 .46 .683 r
.35184 .62468 m .34946 .6281 L .34937 .62596 L F
.35184 .62468 m .35185 .62857 L .34946 .6281 L F
.871 .567 .047 r
.56799 .41684 m .5685 .41626 L .56707 .41448 L F
.56799 .41684 m .56888 .41839 L .5685 .41626 L F
.896 .483 .195 r
.58647 .40493 m .58833 .40574 L .58635 .40697 L F
.152 0 0 r
.58833 .40574 m .5894 .40623 L .58635 .40697 L F
.589 .40577 m .59124 .40589 L .5894 .40623 L F
.479 .891 .925 r
.59124 .40589 m .59198 .40463 L .5894 .40623 L F
.453 .861 .695 r
.59133 .40481 m .5894 .40623 L .59198 .40463 L F
0 0 0 r
.58971 .40658 m .5894 .40623 L .59133 .40481 L F
.58873 .40766 m .5894 .40623 L .58971 .40658 L F
.152 0 0 r
.58833 .40574 m .589 .40577 L .5894 .40623 L F
.938 .749 .621 r
.41733 .55687 m .42014 .55537 L .41681 .5528 L F
.41733 .55687 m .41985 .55817 L .42014 .55537 L F
.849 .727 .729 r
.39374 .55964 m .39684 .5625 L .39728 .55956 L F
.706 .187 0 r
.39588 .56251 m .39684 .5625 L .39374 .55964 L F
.39588 .56251 m .39746 .56355 L .39684 .5625 L F
.709 .507 .613 r
.39822 .51562 m .39776 .51843 L .40055 .51822 L F
.687 .188 .054 r
.51837 .43813 m .51499 .43556 L .51578 .43798 L F
.609 .922 .676 r
.4737 .42192 m .47507 .42021 L .47689 .41912 L F
.619 .951 .783 r
.4737 .42192 m .47307 .42185 L .47507 .42021 L F
.361 0 0 r
.61603 .34518 m .619 .34563 L .62013 .34527 L F
0 0 0 r
.619 .34563 m .62282 .3449 L .62013 .34527 L F
.465 .263 .521 r
.23314 .6185 m .23542 .6213 L .23587 .61837 L F
.836 .697 .711 r
.39972 .59167 m .39608 .59132 L .39829 .58749 L F
.634 .116 0 r
.39972 .59167 m .39864 .59317 L .39608 .59132 L F
.857 .412 .143 r
.39972 .59167 m .40087 .59424 L .39864 .59317 L F
.768 .379 .318 r
.4041 .59452 m .40087 .59424 L .39972 .59167 L F
.853 .732 .729 r
.37245 .5449 m .37384 .54859 L .37127 .54817 L F
.851 .548 .475 r
.37384 .54859 m .37151 .55075 L .37127 .54817 L F
.807 .476 .428 r
.37384 .54859 m .37427 .5513 L .37151 .55075 L F
.926 .844 .744 r
.55189 .42912 m .54908 .42981 L .54964 .42861 L F
.55189 .42912 m .54999 .43285 L .54908 .42981 L F
.972 .735 .521 r
.38533 .58529 m .38505 .58807 L .38356 .58566 L F
.994 .751 .426 r
.384 .58123 m .38533 .58529 L .38782 .58196 L F
.384 .58123 m .38397 .58432 L .38533 .58529 L F
.972 .735 .521 r
.38356 .58566 m .38505 .58807 L .38533 .58529 L F
0 .107 .659 r
.57639 .36954 m .57768 .36962 L .57823 .3672 L F
.57639 .36954 m .57904 .37236 L .57768 .36962 L F
.928 .676 .191 r
.32636 .54081 m .32525 .53694 L .32568 .53763 L F
.532 .584 .852 r
.31597 .60172 m .31427 .59852 L .3145 .5979 L F
.617 .689 .895 r
.31696 .59761 m .31597 .60172 L .3145 .5979 L F
.31696 .59761 m .31853 .60132 L .31597 .60172 L F
.75 .311 .209 r
.35103 .51283 m .3474 .51362 L .34708 .51151 L F
.35103 .51283 m .35146 .51446 L .3474 .51362 L F
.162 0 .336 r
.31645 .58538 m .3185 .58615 L .31833 .58438 L F
.31645 .58538 m .31592 .5878 L .3185 .58615 L F
.479 .497 .799 r
.53708 .346 m .53989 .34685 L .53977 .34501 L F
.491 0 0 r
.28264 .65503 m .28675 .65832 L .28646 .65582 L F
.284 .343 .748 r
.58286 .38176 m .58377 .38594 L .5857 .38359 L F
.908 .509 .227 r
.58377 .38594 m .58392 .38645 L .5857 .38359 L F
.58377 .38594 m .58466 .38861 L .58254 .38717 L F
.58377 .38594 m .58254 .38717 L .58392 .38645 L F
.313 .634 .963 r
.61502 .35279 m .61603 .35139 L .61347 .35096 L F
.999 .806 .507 r
.61502 .35279 m .61393 .35349 L .61603 .35139 L F
.61502 .35279 m .61416 .35521 L .61393 .35349 L F
.832 .487 .402 r
.32928 .50871 m .32931 .51095 L .33286 .51089 L F
.889 .656 .58 r
.32912 .51374 m .33286 .51089 L .32931 .51095 L F
.32912 .51374 m .33165 .51452 L .33286 .51089 L F
.841 .777 .79 r
.32217 .59019 m .32485 .59173 L .32158 .59508 L F
.83 .782 .806 r
.32656 .58832 m .32485 .59173 L .32217 .59019 L F
.859 .758 .75 r
.33468 .59766 m .33823 .59805 L .33923 .59543 L F
.859 .756 .748 r
.33615 .60137 m .33823 .59805 L .33468 .59766 L F
.623 .499 .691 r
.43889 .54581 m .43952 .55163 L .44171 .54516 L F
.176 .711 .754 r
.43811 .55047 m .439 .55031 L .44242 .54984 L F
.736 .792 .897 r
.44424 .54718 m .44367 .54967 L .44242 .54984 L F
.994 .754 .449 r
.44293 .5496 m .44424 .54718 L .44242 .54984 L F
.44295 .54959 m .44297 .54954 L .44293 .5496 L F
.44297 .54954 m .44424 .54718 L .44293 .5496 L F
.736 .792 .897 r
.44424 .54718 m .44611 .54958 L .4432 .55168 L F
0 0 0 r
.4463 .54974 m .44611 .54958 L .44424 .54718 L F
.994 .754 .449 r
.44295 .54959 m .44266 .54903 L .44424 .54718 L F
.711 .256 .17 r
.44266 .54903 m .4463 .54974 L .44436 .54733 L F
.44266 .54903 m .44436 .54733 L .44424 .54718 L F
.994 .765 .481 r
.44295 .54875 m .44266 .54903 L .44295 .54609 L F
.44295 .54959 m .44266 .54903 L .44295 .54875 L F
.683 .772 .919 r
.44513 .54783 m .4463 .54974 L .44326 .54915 L F
.44372 .54852 m .44326 .54915 L .44266 .54903 L F
.44513 .54783 m .44326 .54915 L .44372 .54852 L F
.176 .711 .754 r
.439 .55031 m .44295 .54959 L .44242 .54984 L F
.736 .792 .897 r
.44367 .54967 m .4432 .55168 L .44242 .54984 L F
.585 .83 .456 r
.52341 .44228 m .52075 .44574 L .52219 .44376 L F
.551 .375 .597 r
.52075 .44574 m .52376 .44545 L .52341 .44228 L F
.52341 .44228 m .52376 .44545 L .52075 .44574 L F
.488 .758 .99 r
.52075 .44574 m .52376 .44545 L .52219 .44376 L F
0 .294 .791 r
.49725 .45259 m .49958 .45292 L .49962 .45061 L F
.49919 .45403 m .50068 .45513 L .49958 .45292 L F
.977 .751 .332 r
.50068 .45513 m .50024 .45672 L .49958 .45292 L F
.343 .083 .368 r
.50203 .44992 m .49962 .45061 L .49958 .45292 L F
.50203 .44992 m .50122 .45091 L .50084 .45139 L F
.50122 .45091 m .49958 .45292 L .50084 .45139 L F
.778 .99 .888 r
.50084 .45139 m .49958 .45292 L .49989 .45076 L F
.42 .825 .978 r
.50018 .45222 m .50084 .45139 L .49989 .45076 L F
.50062 .45448 m .50084 .45139 L .50018 .45222 L F
.043 .153 .655 r
.50004 .45525 m .49993 .45196 L .49958 .45292 L F
.49993 .45196 m .49989 .45076 L .49958 .45292 L F
0 .294 .791 r
.49725 .45259 m .49919 .45403 L .49958 .45292 L F
.817 .515 .48 r
.67575 .33788 m .67734 .33601 L .6734 .33522 L F
.67575 .33788 m .67766 .33863 L .67734 .33601 L F
.107 0 0 r
.43764 .45384 m .43904 .45197 L .44155 .4511 L F
.078 0 0 r
.38738 .47265 m .38922 .47279 L .38749 .47459 L F
.63 .956 .925 r
.46938 .43502 m .47355 .43333 L .47091 .43339 L F
.747 .981 .913 r
.47091 .43339 m .47355 .43333 L .4754 .43158 L F
.856 .96 .623 r
.68282 .36555 m .68514 .36179 L .68477 .36085 L F
.87 .915 .857 r
.68514 .36179 m .68659 .35772 L .68477 .36085 L F
.68514 .36179 m .68784 .3584 L .68659 .35772 L F
.69 .864 .965 r
.42194 .59852 m .42579 .59836 L .42515 .59838 L F
.597 .949 .899 r
.42579 .59836 m .42809 .59711 L .42702 .59684 L F
.61 .945 .77 r
.42579 .59836 m .42702 .59684 L .42515 .59838 L F
.859 .758 .75 r
.33468 .59766 m .33923 .59543 L .3374 .59431 L F
.835 .708 .724 r
.33923 .59543 m .33755 .59171 L .3374 .59431 L F
.935 .694 .549 r
.37854 .56152 m .37577 .56083 L .37607 .5579 L F
.961 .773 .605 r
.37854 .56152 m .3754 .56383 L .37577 .56083 L F
.37854 .56152 m .37735 .56479 L .3754 .56383 L F
.783 .62 .678 r
.47122 .5219 m .46912 .52575 L .46738 .52148 L F
.774 .493 .51 r
.46738 .52148 m .46903 .52226 L .47122 .5219 L F
.811 .836 .869 r
.47122 .5219 m .47242 .51707 L .47403 .51855 L F
.47122 .5219 m .46903 .52226 L .47242 .51707 L F
0 .036 .585 r
.51808 .43325 m .51993 .4336 L .52061 .43265 L F
.777 .604 .037 r
.58762 .37247 m .58725 .37019 L .58744 .36999 L F
.362 .563 .913 r
.58725 .37019 m .59056 .37437 L .59189 .37221 L F
.078 .502 .899 r
.58725 .37019 m .59189 .37221 L .59059 .37076 L F
.58725 .37019 m .59059 .37076 L .58715 .3703 L F
.58725 .37019 m .58715 .3703 L .58665 .37023 L F
.777 .604 .037 r
.58744 .36999 m .58725 .37019 L .58728 .36787 L F
.484 .279 .526 r
.58762 .37247 m .58793 .37531 L .59056 .37437 L F
.858 .712 .7 r
.34094 .56421 m .34255 .5681 L .34517 .56445 L F
.726 .274 .178 r
.42586 .58473 m .42835 .58732 L .43001 .58565 L F
.803 .603 .632 r
.36378 .50201 m .36355 .5049 L .36783 .5055 L F
.793 .446 .4 r
.36389 .50656 m .36783 .5055 L .36355 .5049 L F
.36389 .50656 m .36775 .50761 L .36783 .5055 L F
.792 .844 .891 r
.67428 .31172 m .67493 .31426 L .6777 .31221 L F
.859 .892 .859 r
.48824 .5039 m .49028 .50532 L .48649 .50906 L F
.678 .86 .969 r
.33249 .63134 m .32836 .63114 L .33094 .6283 L F
.721 .782 .901 r
.33353 .62721 m .33249 .63134 L .33094 .6283 L F
.33353 .62721 m .33565 .62927 L .33249 .63134 L F
.347 .82 .895 r
.63044 .39543 m .62652 .39585 L .62777 .3964 L F
.533 .107 .178 r
.31822 .51026 m .32266 .50818 L .32018 .50785 L F
.863 .85 .829 r
.29866 .65432 m .30274 .65229 L .30135 .65135 L F
.217 .366 .8 r
.30274 .65229 m .30381 .65041 L .30135 .65135 L F
.30274 .65229 m .30544 .65424 L .30381 .65041 L F
.943 .959 .73 r
.52516 .46567 m .52331 .46901 L .52306 .46648 L F
.754 .988 .772 r
.52792 .46295 m .52516 .46567 L .5261 .46359 L F
.752 .992 .797 r
.52516 .46567 m .52306 .46648 L .5261 .46359 L F
0 0 0 r
.44043 .44251 m .4365 .44507 L .43878 .44385 L F
.231 .742 .711 r
.44083 .44228 m .44043 .44251 L .43878 .44385 L F
.44083 .44228 m .44303 .44172 L .44043 .44251 L F
.262 .763 .889 r
.2971 .67003 m .29491 .67042 L .29578 .67071 L F
.692 .765 .907 r
.39406 .56771 m .39877 .56808 L .39746 .56355 L F
.428 .434 .764 r
.39877 .56808 m .39943 .56419 L .39746 .56355 L F
.39877 .56808 m .40102 .56788 L .39943 .56419 L F
.87 .87 .835 r
.51947 .42274 m .52211 .41968 L .52128 .41766 L F
.86 .71 .695 r
.36542 .52834 m .36717 .53205 L .3633 .53014 L F
.887 .556 .416 r
.36717 .53205 m .36496 .53379 L .3633 .53014 L F
.932 .648 .479 r
.36717 .53205 m .36727 .53471 L .36496 .53379 L F
.801 .612 .645 r
.52165 .38497 m .52137 .38879 L .5256 .38939 L F
.125 0 0 r
.63937 .33993 m .64226 .33912 L .64227 .33857 L F
.04 0 0 r
.64227 .33857 m .64226 .33912 L .64493 .33797 L F
.999 .845 .541 r
.55196 .46116 m .55131 .4644 L .55299 .46289 L F
.89 .755 .706 r
.4411 .57822 m .43962 .58187 L .43816 .57827 L F
.492 .744 .984 r
.44268 .57652 m .4411 .57822 L .44023 .5768 L F
.44268 .57652 m .44478 .5778 L .4411 .57822 L F
.717 .982 .786 r
.23794 .61294 m .2358 .61513 L .23728 .61287 L F
.645 .633 .823 r
.23794 .61294 m .23843 .6151 L .2358 .61513 L F
.656 .408 .532 r
.2358 .61513 m .23818 .61803 L .23843 .6151 L F
.2358 .61513 m .23818 .61803 L .23728 .61287 L F
.2358 .61513 m .23587 .61837 L .23818 .61803 L F
.2358 .61513 m .23587 .61837 L .23818 .61803 L F
.565 .616 .862 r
.44209 .56207 m .44176 .55716 L .44228 .55895 L F
.118 .291 .765 r
.44176 .55716 m .44325 .55758 L .44228 .55895 L F
.522 .367 .612 r
.44497 .56052 m .44209 .56207 L .44228 .55895 L F
.911 .683 .581 r
.37683 .55483 m .37427 .5513 L .37814 .55209 L F
.464 .045 .158 r
.40117 .46383 m .39985 .46148 L .39817 .46411 L F
.40117 .46383 m .40237 .46161 L .39985 .46148 L F
0 .264 .702 r
.30881 .68764 m .30843 .68712 L .30611 .68677 L F
.30881 .68764 m .31041 .68856 L .30843 .68712 L F
.893 .964 .831 r
.48649 .50906 m .48265 .51157 L .4852 .50806 L F
.859 .892 .859 r
.48824 .5039 m .48649 .50906 L .4852 .50806 L F
.727 .979 .754 r
.50946 .39335 m .50665 .39616 L .50782 .39402 L F
.724 .989 .841 r
.50665 .39616 m .50447 .39669 L .50782 .39402 L F
0 0 0 r
.28666 .53183 m .2834 .53594 L .28377 .53543 L F
.737 .696 .811 r
.62551 .38578 m .62626 .38945 L .62195 .3888 L F
.757 .773 .866 r
.384 .58123 m .38782 .58196 L .38679 .57834 L F
.705 .607 .745 r
.39061 .5788 m .39036 .5814 L .3886 .57808 L F
.934 .562 .182 r
.3886 .57808 m .38902 .57887 L .38881 .58014 L F
.38902 .57887 m .39036 .5814 L .38881 .58014 L F
.51 .805 .999 r
.38782 .58196 m .39036 .5814 L .38881 .58014 L F
.659 .199 .147 r
.39156 .58212 m .38849 .58216 L .38881 .58014 L F
.51 .805 .999 r
.38782 .58196 m .38881 .58014 L .38692 .57878 L F
.659 .199 .147 r
.38849 .58216 m .38701 .58218 L .38881 .58014 L F
0 .295 .766 r
.39036 .5814 m .39242 .5821 L .38881 .58014 L F
.659 .199 .147 r
.39242 .5821 m .39156 .58212 L .38881 .58014 L F
.51 .805 .999 r
.38692 .57878 m .38881 .58014 L .38679 .57834 L F
.522 .309 .531 r
.29007 .51827 m .28756 .52135 L .28745 .51865 L F
.795 .738 .8 r
.32655 .60771 m .33119 .60593 L .32931 .60434 L F
.169 .671 .909 r
.55137 .40177 m .55282 .40243 L .5484 .40174 L F
.163 .361 .813 r
.55456 .40109 m .55282 .40243 L .55137 .40177 L F
.752 .25 .029 r
.55736 .40534 m .55282 .40243 L .55665 .40468 L F
.844 .684 .684 r
.55823 .40075 m .55665 .40468 L .55456 .40109 L F
.924 .947 .791 r
.55489 .40552 m .55702 .40395 L .55689 .40403 L F
.55702 .40395 m .55794 .40327 L .5576 .40351 L F
.55702 .40395 m .5576 .40351 L .55689 .40403 L F
.163 .361 .813 r
.55456 .40109 m .55646 .40436 L .55282 .40243 L F
.55646 .40436 m .55665 .40468 L .5563 .40448 L F
.55646 .40436 m .5563 .40448 L .55282 .40243 L F
.801 .654 .699 r
.28675 .65832 m .28255 .66085 L .28515 .65664 L F
.28675 .65832 m .28487 .6629 L .28255 .66085 L F
.663 .885 .979 r
.28966 .65536 m .28646 .65582 L .28807 .65417 L F
.854 .877 .856 r
.28675 .65832 m .28807 .65417 L .28646 .65582 L F
.28731 .65654 m .28966 .65536 L .28807 .65417 L F
.28675 .65832 m .28856 .65647 L .28731 .65654 L F
.28856 .65647 m .28966 .65536 L .28731 .65654 L F
.263 .603 .953 r
.28732 .65677 m .28675 .65832 L .28515 .65664 L F
.908 .964 .81 r
.28515 .65664 m .28255 .66085 L .28078 .66011 L F
.28515 .65664 m .28078 .66011 L .28371 .65688 L F
.114 0 0 r
.28732 .65677 m .28539 .65666 L .28371 .65688 L F
.28539 .65666 m .28515 .65664 L .28489 .65669 L F
.28539 .65666 m .28489 .65669 L .28371 .65688 L F
0 0 .106 r
.28743 .65985 m .28675 .65832 L .28732 .65677 L F
.28743 .65985 m .28487 .6629 L .28675 .65832 L F
.901 .485 .146 r
.31728 .51752 m .31476 .51448 L .31695 .5159 L F
.601 .754 .951 r
.28867 .68388 m .29249 .68538 L .29055 .68461 L F
.148 .621 .925 r
.29249 .68538 m .29269 .68434 L .29055 .68461 L F
.29249 .68538 m .29454 .68562 L .29269 .68434 L F
.76 .281 .101 r
.42228 .56454 m .42236 .56716 L .42606 .5661 L F
.66 .246 .248 r
.4229 .56701 m .42761 .56489 L .42606 .5661 L F
.42236 .56716 m .423 .56688 L .4229 .56701 L F
.423 .56688 m .42761 .56489 L .4229 .56701 L F
.283 .598 .95 r
.42336 .56427 m .42433 .56523 L .42238 .56637 L F
.66 .246 .248 r
.42761 .56489 m .42735 .56522 L .42606 .5661 L F
.42761 .56489 m .42823 .56462 L .42735 .56522 L F
.42545 .56582 m .42596 .56777 L .42823 .56462 L F
.42543 .5685 m .42568 .56845 L .42823 .56462 L F
.634 .824 .411 r
.42823 .56462 m .42601 .56797 L .42921 .56291 L F
.42601 .56797 m .4256 .56857 L .42631 .56745 L F
.42601 .56797 m .42631 .56745 L .42921 .56291 L F
.66 .246 .248 r
.42236 .56716 m .42543 .5685 L .42596 .56777 L F
.42236 .56716 m .42596 .56777 L .42545 .56582 L F
.42543 .5685 m .4256 .56857 L .42568 .56845 L F
.43 .535 .863 r
.4256 .56664 m .4256 .56785 L .42414 .56687 L F
.283 .598 .95 r
.42346 .56633 m .42364 .56643 L .42339 .56642 L F
.42444 .56516 m .42364 .56643 L .42346 .56633 L F
.814 .801 .839 r
.42658 .56458 m .42593 .56681 L .42768 .56468 L F
.42516 .56444 m .42576 .5663 L .42658 .56458 L F
.42576 .5663 m .42593 .56681 L .42658 .56458 L F
.43 .535 .863 r
.42565 .56653 m .42403 .56684 L .42238 .56637 L F
.4256 .56664 m .42414 .56687 L .42565 .56653 L F
.42414 .56687 m .42236 .56716 L .42403 .56684 L F
.42414 .56687 m .42403 .56684 L .42565 .56653 L F
.183 .475 .893 r
.42238 .56637 m .42457 .56716 L .42414 .56687 L F
.814 .801 .839 r
.42336 .56427 m .42556 .56644 L .42516 .56444 L F
.283 .598 .95 r
.42444 .56516 m .42339 .56642 L .42238 .56637 L F
.183 .475 .893 r
.42238 .56637 m .42414 .56687 L .42262 .56585 L F
.814 .801 .839 r
.42556 .56644 m .42593 .56681 L .42516 .56444 L F
.283 .598 .95 r
.42444 .56516 m .42612 .56656 L .42364 .56643 L F
.183 .475 .893 r
.42262 .56585 m .42469 .56703 L .42336 .56427 L F
.42469 .56703 m .42552 .5675 L .42533 .56721 L F
.42469 .56703 m .42533 .56721 L .42336 .56427 L F
.43 .535 .863 r
.42403 .56684 m .42236 .56716 L .42238 .56637 L F
.42612 .56656 m .4256 .56664 L .42565 .56653 L F
.183 .475 .893 r
.42457 .56716 m .42552 .5675 L .42262 .56585 L F
.43 .535 .863 r
.42414 .56687 m .4256 .56857 L .42236 .56716 L F
.4256 .56785 m .4256 .56857 L .42414 .56687 L F
.814 .801 .839 r
.42336 .56427 m .42552 .5675 L .426 .56688 L F
.43 .535 .863 r
.42612 .56656 m .42582 .56775 L .4256 .56664 L F
.89 .966 .642 r
.42921 .56291 m .4256 .56857 L .42574 .56802 L F
0 0 .332 r
.42581 .56786 m .42647 .56626 L .42572 .56724 L F
.89 .966 .642 r
.42589 .56766 m .42574 .56802 L .42581 .56779 L F
.42921 .56291 m .42574 .56802 L .42589 .56766 L F
.42921 .56291 m .42581 .56779 L .42582 .56774 L F
.42921 .56291 m .42582 .56775 L .42658 .56602 L F
0 0 .332 r
.42599 .56897 m .42768 .56468 L .42647 .56626 L F
.42599 .56897 m .42647 .56626 L .42581 .56786 L F
.43 .535 .863 r
.42572 .56724 m .4256 .56857 L .4256 .56664 L F
.42574 .56802 m .4256 .56857 L .42572 .56724 L F
0 0 .332 r
.42575 .56823 m .42572 .56724 L .42552 .5675 L F
.42599 .56897 m .42572 .56724 L .42575 .56823 L F
.43 .535 .863 r
.42582 .56775 m .42574 .56802 L .42572 .56724 L F
.585 .423 .628 r
.42362 .57014 m .42536 .56928 L .42552 .5675 L F
.42536 .56928 m .42599 .56897 L .42571 .5681 L F
.42536 .56928 m .42571 .5681 L .42552 .5675 L F
.89 .966 .642 r
.42582 .56774 m .42581 .56779 L .42582 .56775 L F
.814 .801 .839 r
.42593 .56681 m .426 .56688 L .42647 .56626 L F
.42593 .56681 m .42647 .56626 L .42658 .56602 L F
.89 .966 .642 r
.42658 .56602 m .42582 .56775 L .42612 .56656 L F
.814 .801 .839 r
.42658 .56602 m .42647 .56626 L .42768 .56468 L F
0 0 .332 r
.42616 .56854 m .42765 .56747 L .42768 .56518 L F
.42711 .56612 m .42768 .56518 L .42768 .56468 L F
.42616 .56854 m .42768 .56518 L .42711 .56612 L F
.42599 .56897 m .42621 .56877 L .42616 .56854 L F
.42621 .56877 m .42765 .56747 L .42616 .56854 L F
.585 .423 .628 r
.42362 .57014 m .42472 .56862 L .42262 .56915 L F
.42472 .56862 m .42552 .5675 L .42305 .5689 L F
.42472 .56862 m .42305 .5689 L .42262 .56915 L F
.89 .966 .642 r
.42877 .56342 m .42664 .56594 L .42768 .56468 L F
.42664 .56594 m .42612 .56656 L .42768 .56468 L F
.283 .598 .95 r
.42336 .56427 m .42444 .56516 L .42433 .56523 L F
.89 .966 .642 r
.42921 .56291 m .42867 .56354 L .42877 .56342 L F
.42867 .56354 m .42612 .56656 L .42877 .56342 L F
.775 .929 .935 r
.39538 .55944 m .39728 .55956 L .39964 .55824 L F
.39538 .55944 m .39964 .55824 L .39875 .55867 L F
.796 .986 .893 r
.39967 .55611 m .39964 .55824 L .40272 .55543 L F
.885 .945 .585 r
.39875 .55867 m .39964 .55824 L .39967 .55611 L F
.51 .839 .998 r
.63044 .39543 m .63446 .39566 L .6331 .39472 L F
.373 .736 .99 r
.63446 .39566 m .63582 .39432 L .6331 .39472 L F
.63446 .39566 m .63705 .39542 L .63582 .39432 L F
.443 .652 .948 r
.63446 .39566 m .63867 .39736 L .63705 .39542 L F
.849 .727 .729 r
.39374 .55964 m .39728 .55956 L .39538 .55944 L F
.691 .806 .936 r
.33981 .62949 m .33565 .62927 L .33778 .62775 L F
.763 .804 .886 r
.33778 .62775 m .34197 .628 L .33981 .62949 L F
.268 .125 .495 r
.29177 .61841 m .28961 .62192 L .29156 .62122 L F
.569 .816 .438 r
.47951 .4157 m .47689 .41912 L .47822 .41735 L F
.629 .93 .679 r
.47689 .41912 m .47507 .42021 L .47822 .41735 L F
.631 .644 .845 r
.59935 .38108 m .59976 .38367 L .60297 .38157 L F
.564 .88 .992 r
.59124 .40589 m .5938 .40488 L .59507 .40574 L F
.562 .88 .992 r
.59507 .40574 m .59652 .40383 L .5981 .40527 L F
.59507 .40574 m .5938 .40488 L .59652 .40383 L F
.59507 .40574 m .59652 .40383 L .5981 .40527 L F
.59507 .40574 m .5938 .40488 L .59652 .40383 L F
.641 .434 .588 r
.30404 .60843 m .30396 .61162 L .30143 .61278 L F
.88 .772 .272 r
.31329 .57517 m .31295 .57313 L .31535 .57418 L F
.31329 .57517 m .31293 .57457 L .31295 .57313 L F
0 0 0 r
.31295 .57313 m .31264 .57451 L .31293 .57448 L F
.88 .772 .272 r
.31293 .57457 m .31278 .57433 L .31295 .57313 L F
0 0 0 r
.31295 .57313 m .31293 .57448 L .31535 .57418 L F
.256 .739 .928 r
.31011 .57522 m .31237 .57447 L .3126 .57464 L F
.31242 .57518 m .3126 .57464 L .31329 .57517 L F
.31011 .57522 m .3126 .57464 L .31242 .57518 L F
.31237 .57447 m .31293 .57457 L .31329 .57517 L F
.538 .165 .282 r
.31329 .57517 m .31205 .57717 L .31011 .57522 L F
.07 0 .008 r
.31535 .57418 m .31205 .57717 L .31329 .57517 L F
0 0 0 r
.31264 .57451 m .31205 .57717 L .3146 .57487 L F
.256 .739 .928 r
.31237 .57447 m .31278 .57433 L .31293 .57457 L F
.92 .976 .71 r
.31205 .57717 m .31278 .57433 L .31269 .57436 L F
0 0 0 r
.31264 .57451 m .31258 .57488 L .31205 .57717 L F
.92 .976 .71 r
.31205 .57717 m .31269 .57436 L .31011 .57522 L F
0 0 0 r
.31258 .57488 m .31255 .57501 L .31205 .57717 L F
.92 .976 .71 r
.31205 .57717 m .31114 .57705 L .31266 .57453 L F
.31205 .57717 m .31266 .57453 L .31278 .57433 L F
0 0 0 r
.31255 .57501 m .31226 .57659 L .31205 .57717 L F
.505 .318 .561 r
.31295 .57313 m .31278 .57433 L .31271 .57429 L F
0 0 0 r
.31295 .57313 m .3127 .57433 L .31264 .57451 L F
.505 .318 .561 r
.31295 .57313 m .31271 .57429 L .31012 .57285 L F
0 0 0 r
.31295 .57313 m .31272 .57427 L .3127 .57433 L F
.31272 .57427 m .31226 .57659 L .31264 .57451 L F
.31264 .57451 m .3146 .57487 L .31535 .57418 L F
.545 .347 .564 r
.44209 .56207 m .44216 .56611 L .43874 .56453 L F
.525 .351 .588 r
.48655 .43521 m .48944 .43138 L .4866 .43229 L F
.85 .856 .847 r
.55437 .4478 m .55896 .44578 L .55706 .44419 L F
.883 .764 .726 r
.55706 .44419 m .55896 .44578 L .55945 .44298 L F
.461 .228 .473 r
.27183 .5282 m .27426 .53044 L .27474 .52779 L F
.27183 .5282 m .27166 .53129 L .27426 .53044 L F
.993 .808 .434 r
.58316 .38127 m .58195 .37968 L .58065 .37859 L F
.58316 .38127 m .58286 .38176 L .58195 .37968 L F
.688 .859 .964 r
.28807 .65417 m .28966 .65536 L .29062 .65347 L F
.28807 .65417 m .28966 .65536 L .29062 .65347 L F
.874 .947 .857 r
.31108 .54853 m .31263 .54479 L .31373 .54797 L F
.31108 .54853 m .30935 .54811 L .31263 .54479 L F
.659 .17 .077 r
.31373 .54797 m .30935 .54811 L .31108 .54853 L F
.31373 .54797 m .31214 .55015 L .30935 .54811 L F
0 0 0 r
.31413 .5489 m .31214 .55015 L .31373 .54797 L F
.75 .698 .802 r
.31206 .60205 m .31334 .6052 L .30898 .60463 L F
.808 .558 .561 r
.66958 .33434 m .67342 .3327 L .66914 .33193 L F
.66958 .33434 m .6734 .33522 L .67342 .3327 L F
.323 .212 .569 r
.52551 .44395 m .52376 .44545 L .52341 .44228 L F
.604 .096 .017 r
.52551 .44395 m .52341 .44228 L .52219 .44376 L F
.354 .828 .808 r
.62992 .34313 m .63108 .34222 L .6325 .34209 L F
.62992 .34313 m .62824 .34326 L .63108 .34222 L F
.85 .627 .6 r
.41959 .56128 m .42217 .56193 L .41985 .55817 L F
.862 .579 .508 r
.41959 .56128 m .42228 .56454 L .42217 .56193 L F
.925 .722 .611 r
.33427 .56865 m .33126 .57044 L .33169 .56762 L F
.33427 .56865 m .33345 .57165 L .33126 .57044 L F
0 0 .419 r
.56257 .38227 m .56332 .37748 L .56115 .37985 L F
.691 .738 .887 r
.49439 .42272 m .49827 .42439 L .49699 .42176 L F
.694 .793 .926 r
.49699 .42176 m .49827 .42439 L .50116 .42269 L F
0 0 0 r
.51143 .41375 m .50795 .41523 L .51315 .41218 L F
.5156 .40877 m .51473 .41043 L .51315 .41218 L F
.549 .854 .546 r
.51473 .41043 m .51143 .41375 L .51315 .41218 L F
.652 .792 .95 r
.65149 .36829 m .65283 .37033 L .65457 .36727 L F
.565 .078 .058 r
.59935 .38108 m .60297 .38157 L .59966 .3805 L F
0 0 0 r
.34745 .66506 m .34979 .6618 L .34899 .66402 L F
.068 0 .276 r
.3469 .66775 m .34745 .66506 L .34899 .66402 L F
.384 .197 .499 r
.67188 .31148 m .67428 .31172 L .67416 .30882 L F
.435 .664 .958 r
.63867 .39736 m .63963 .39515 L .63705 .39542 L F
.63867 .39736 m .64123 .39739 L .63963 .39515 L F
.336 0 0 r
.65116 .39455 m .64702 .39554 L .64829 .39505 L F
.735 .716 .834 r
.45686 .53566 m .45859 .53908 L .45389 .53832 L F
.717 .709 .841 r
.46055 .53749 m .45859 .53908 L .45686 .53566 L F
.619 .753 .942 r
.51831 .38765 m .51895 .38969 L .52137 .38879 L F
.768 .442 .434 r
.51831 .38765 m .52137 .38879 L .51895 .38969 L F
.824 .916 .899 r
.49439 .49891 m .48968 .50059 L .4925 .49737 L F
.819 .801 .834 r
.49726 .49583 m .49439 .49891 L .4925 .49737 L F
.804 .759 .811 r
.53033 .46166 m .52732 .46136 L .52937 .4596 L F
.863 .996 .774 r
.5261 .46359 m .52817 .45958 L .52844 .45958 L F
.52815 .46108 m .52844 .45958 L .52937 .4596 L F
.962 .943 .667 r
.52784 .46272 m .52732 .46136 L .52809 .46143 L F
.52792 .46295 m .5261 .46359 L .52732 .46136 L F
.863 .996 .774 r
.5261 .46359 m .52937 .4596 L .52732 .46136 L F
.5261 .46359 m .52844 .45958 L .52815 .46108 L F
.962 .943 .667 r
.52792 .46295 m .52784 .46272 L .53033 .46166 L F
.52784 .46272 m .52809 .46143 L .53033 .46166 L F
.572 .652 .89 r
.28396 .64717 m .28778 .64879 L .28632 .64448 L F
.253 .686 .962 r
.29023 .64628 m .28899 .64665 L .29085 .64644 L F
.179 .31 .761 r
.28632 .64448 m .28723 .64717 L .28899 .64665 L F
.548 0 0 r
.28632 .64448 m .28691 .64496 L .28684 .64544 L F
.28691 .64496 m .28899 .64665 L .28684 .64544 L F
.253 .686 .962 r
.28684 .64544 m .29085 .64644 L .28942 .64477 L F
.625 .961 .861 r
.28784 .64494 m .28942 .64477 L .28985 .64351 L F
0 0 0 r
.28891 .64419 m .28784 .64494 L .28985 .64351 L F
.255 .766 .781 r
.2868 .64568 m .28784 .64494 L .28677 .64586 L F
.253 .686 .962 r
.28684 .64544 m .28899 .64665 L .29023 .64628 L F
.255 .766 .781 r
.28684 .64544 m .2873 .64532 L .28784 .64494 L F
.2873 .64532 m .28942 .64477 L .28784 .64494 L F
0 0 0 r
.28818 .64471 m .28784 .64494 L .28891 .64419 L F
.255 .766 .781 r
.28684 .64544 m .28677 .64586 L .28479 .64757 L F
.54 .876 .617 r
.28479 .64757 m .28784 .64494 L .28558 .64657 L F
0 0 0 r
.28558 .64657 m .28784 .64494 L .28818 .64471 L F
.255 .766 .781 r
.28684 .64544 m .28784 .64494 L .2868 .64568 L F
.179 .31 .761 r
.28723 .64717 m .28778 .64879 L .28899 .64665 L F
.537 .856 .563 r
.47951 .4157 m .48098 .41414 L .48257 .41279 L F
0 0 0 r
.47951 .4157 m .47822 .41735 L .48098 .41414 L F
.741 .687 .799 r
.51464 .40583 m .5156 .40877 L .51592 .40681 L F
.581 .627 .863 r
.5156 .40877 m .51219 .40665 L .51464 .40583 L F
.767 .683 .77 r
.51464 .40583 m .51592 .40681 L .51659 .40657 L F
.51694 .40579 m .51659 .40657 L .51882 .40576 L F
.51464 .40583 m .51659 .40657 L .51694 .40579 L F
.086 .254 .74 r
.51662 .40621 m .5156 .40877 L .51464 .40583 L F
.689 .801 .339 r
.51662 .40621 m .51473 .41043 L .51555 .40887 L F
.51566 .40863 m .51555 .40887 L .5156 .40877 L F
.51662 .40621 m .51555 .40887 L .51566 .40863 L F
.031 0 .044 r
.32382 .68299 m .32445 .6823 L .32507 .68229 L F
0 0 0 r
.32445 .6823 m .32662 .68208 L .32507 .68229 L F
.32632 .68205 m .3287 .68174 L .32662 .68208 L F
.752 .893 .942 r
.32662 .68208 m .3287 .68174 L .32971 .67953 L F
0 0 0 r
.32735 .68214 m .32662 .68208 L .32778 .68154 L F
.32507 .68539 m .32662 .68208 L .32735 .68214 L F
.32445 .6823 m .32632 .68205 L .32662 .68208 L F
.783 .998 .836 r
.55794 .40327 m .55736 .40534 L .55665 .40468 L F
0 .06 .611 r
.55913 .40705 m .55736 .40534 L .55794 .40327 L F
.896 .661 .574 r
.35948 .51854 m .35575 .52044 L .35554 .51768 L F
.35948 .51854 m .35912 .52165 L .35575 .52044 L F
.543 .832 .496 r
.5867 .36502 m .58777 .36378 L .58903 .36247 L F
.852 .865 .851 r
.59036 .35763 m .58733 .36245 L .58903 .36247 L F
.543 .832 .496 r
.5867 .36502 m .58777 .36378 L .58903 .36247 L F
.993 .743 .422 r
.66261 .3492 m .66252 .35184 L .66124 .34773 L F
.823 .584 .577 r
.52331 .46901 m .52014 .47057 L .52306 .46648 L F
.52331 .46901 m .52242 .47156 L .52014 .47057 L F
.819 .588 .589 r
.41147 .53511 m .40742 .53169 L .409 .5324 L F
.41147 .53511 m .40759 .53503 L .40742 .53169 L F
.521 .868 .99 r
.41043 .53395 m .40759 .53503 L .41147 .53511 L F
0 0 .486 r
.409 .5324 m .41043 .53395 L .41147 .53511 L F
.622 .889 .988 r
.23542 .6213 m .23745 .62214 L .23783 .62024 L F
.941 .818 .695 r
.54908 .42118 m .55089 .42264 L .54896 .42728 L F
.145 0 0 r
.4102 .45978 m .40926 .45885 L .40775 .46068 L F
.4102 .45978 m .41192 .45835 L .40926 .45885 L F
0 0 0 r
.6338 .34739 m .62977 .34831 L .63087 .34859 L F
.925 .715 .601 r
.3826 .51727 m .38409 .52137 L .38506 .5191 L F
.38506 .5191 m .38409 .52137 L .3826 .51727 L F
.977 .759 .542 r
.32128 .51858 m .31885 .51966 L .31728 .51752 L F
.32128 .51858 m .32076 .52114 L .31885 .51966 L F
.774 .543 .584 r
.32979 .55094 m .32674 .54779 L .33035 .54842 L F
.653 .856 .977 r
.52876 .43816 m .53272 .43827 L .53161 .43699 L F
.52876 .43816 m .53272 .43827 L .53161 .43699 L F
.725 .679 .806 r
.53272 .43827 m .53641 .43599 L .53241 .43607 L F
.464 .761 .994 r
.5342 .43666 m .53272 .43827 L .53161 .43699 L F
.328 .549 .913 r
.5342 .43666 m .53585 .43892 L .53272 .43827 L F
.666 .642 .816 r
.53585 .43892 m .53284 .4418 L .53272 .43827 L F
.813 .904 .904 r
.28237 .64541 m .28396 .64717 L .28632 .64448 L F
.701 .383 .435 r
.27726 .644 m .27894 .64474 L .27616 .64447 L F
.775 .935 .934 r
.51727 .38411 m .51533 .38609 L .51539 .38331 L F
.884 .925 .845 r
.51427 .38775 m .51539 .38331 L .51533 .38609 L F
.548 .501 .755 r
.24819 .56234 m .24889 .56484 L .25138 .56414 L F
.804 .361 0 r
.24889 .56484 m .25116 .56873 L .25138 .56414 L F
.927 .942 .788 r
.56441 .42801 m .56798 .42538 L .56649 .42392 L F
.56441 .42801 m .56557 .42909 L .56798 .42538 L F
.903 .867 .793 r
.56649 .42392 m .56798 .42538 L .56983 .42044 L F
.936 .815 .701 r
.56091 .43567 m .5628 .43229 L .56102 .4311 L F
.88 .952 .851 r
.5628 .43229 m .56441 .42801 L .56102 .4311 L F
.5628 .43229 m .56557 .42909 L .56441 .42801 L F
.923 .974 .758 r
.66161 .35945 m .65922 .36297 L .65957 .36025 L F
.938 .962 .744 r
.6615 .35698 m .66161 .35945 L .65957 .36025 L F
.887 .589 .079 r
.58518 .39621 m .58603 .39913 L .58534 .39786 L F
.924 .711 .221 r
.58603 .39913 m .58551 .40049 L .58534 .39786 L F
.58603 .39913 m .58617 .40236 L .58551 .40049 L F
.906 .812 .743 r
.55945 .44298 m .56002 .43829 L .55815 .44218 L F
.883 .764 .726 r
.55706 .44419 m .55945 .44298 L .55815 .44218 L F
.866 .777 .761 r
.40759 .53503 m .40485 .53786 L .40845 .53867 L F
.886 .716 .665 r
.40485 .53786 m .40683 .5424 L .40845 .53867 L F
.735 .603 .709 r
.56338 .35549 m .56429 .36028 L .56045 .35887 L F
.849 .799 .802 r
.56118 .36359 m .56119 .36244 L .56154 .3612 L F
.923 .867 .766 r
.56204 .35946 m .56154 .3612 L .56045 .35887 L F
0 0 .418 r
.56045 .35887 m .56068 .35935 L .56122 .35907 L F
.56068 .35935 m .56154 .3612 L .56122 .35907 L F
.849 .799 .802 r
.56119 .36244 m .56122 .35907 L .56154 .3612 L F
.56118 .36359 m .55845 .36296 L .56122 .35907 L F
0 0 0 r
.56122 .35907 m .56034 .3613 L .56173 .35882 L F
.56122 .35907 m .56173 .35882 L .56276 .35699 L F
.923 .867 .766 r
.56429 .36028 m .56154 .3612 L .56204 .35946 L F
.579 .564 .801 r
.56521 .35514 m .56429 .36028 L .56338 .35549 L F
.56521 .35514 m .56716 .35983 L .56429 .36028 L F
.609 .932 .961 r
.28692 .62339 m .28625 .62499 L .28517 .62436 L F
.28692 .62339 m .28625 .62499 L .28517 .62436 L F
.874 .792 .767 r
.6871 .35475 m .68784 .3584 L .68909 .35636 L F
.887 .711 .659 r
.33198 .55497 m .32896 .55419 L .32979 .55094 L F
.77 .979 .716 r
.33198 .55497 m .32902 .55734 L .32896 .55419 L F
.33198 .55497 m .32845 .55885 L .32902 .55734 L F
.724 .534 .633 r
.38993 .51549 m .39441 .51593 L .39193 .51185 L F
.697 .526 .652 r
.39193 .51185 m .39441 .51593 L .39533 .51494 L F
.725 .648 .773 r
.32084 .59783 m .32271 .60185 L .31853 .60132 L F
.918 .96 .638 r
.32093 .60337 m .32271 .60185 L .32253 .60019 L F
.661 .194 .134 r
.32504 .60392 m .32271 .60185 L .32093 .60337 L F
.543 .254 .426 r
.32504 .60392 m .32561 .60151 L .32271 .60185 L F
.617 .444 .625 r
.30858 .66473 m .30582 .66814 L .3062 .66538 L F
0 0 .001 r
.34899 .66402 m .34979 .6618 L .35111 .66043 L F
.732 .94 .953 r
.52751 .48385 m .53255 .48267 L .53112 .4814 L F
.844 .931 .886 r
.53112 .4814 m .53255 .48267 L .53414 .4805 L F
.058 0 0 r
.31938 .68433 m .32382 .68299 L .32012 .68487 L F
.352 .798 .647 r
.32012 .68487 m .32382 .68299 L .32507 .68229 L F
0 0 0 r
.61271 .39155 m .61782 .39047 L .61605 .39198 L F
.844 .99 .853 r
.61782 .39047 m .6186 .38847 L .61605 .39198 L F
.084 .243 .731 r
.50891 .45095 m .50768 .45216 L .50656 .44917 L F
0 0 0 r
.50725 .453 m .50768 .45216 L .50891 .45095 L F
.066 0 .229 r
.25155 .57824 m .24917 .58163 L .25035 .58049 L F
0 0 .276 r
.24917 .58163 m .25004 .58292 L .25035 .58049 L F
.95 .844 .414 r
.48589 .51968 m .48659 .52215 L .48634 .52073 L F
.97 .788 .601 r
.48338 .52322 m .48659 .52215 L .48589 .51968 L F
.48338 .52322 m .48507 .5246 L .48659 .52215 L F
.577 .397 .601 r
.26386 .53262 m .26569 .53466 L .26592 .53192 L F
.551 .325 .525 r
.26592 .53192 m .26833 .53413 L .2688 .53185 L F
.26592 .53192 m .26569 .53466 L .26833 .53413 L F
0 0 0 r
.51052 .44435 m .51585 .442 L .51565 .44175 L F
.882 .986 .716 r
.51663 .43932 m .51585 .442 L .51799 .43855 L F
.814 .885 .459 r
.51565 .44175 m .51585 .442 L .51663 .43932 L F
.821 .741 .777 r
.51917 .39464 m .52302 .39274 L .52143 .39395 L F
0 .189 .626 r
.52336 .3901 m .52388 .39038 L .52478 .39105 L F
.52137 .38879 m .52388 .39038 L .52336 .3901 L F
.691 .636 .789 r
.52388 .39038 m .52302 .39274 L .52478 .39105 L F
.52388 .39038 m .52143 .39395 L .52302 .39274 L F
.52388 .39038 m .52525 .39384 L .52143 .39395 L F
.776 .605 .667 r
.52525 .39384 m .52157 .39656 L .52143 .39395 L F
.543 .548 .809 r
.52671 .38961 m .52525 .39384 L .52388 .39038 L F
0 0 .363 r
.52388 .39038 m .52412 .39413 L .52489 .39092 L F
.52388 .39038 m .52489 .39092 L .52497 .39058 L F
.598 .423 .615 r
.26258 .53481 m .26307 .5353 L .26386 .53262 L F
.577 .397 .601 r
.26386 .53262 m .26307 .5353 L .26569 .53466 L F
.457 .479 .794 r
.31487 .55732 m .31398 .56183 L .3122 .5607 L F
.31487 .55732 m .31661 .56183 L .31398 .56183 L F
.263 .692 .965 r
.31398 .56183 m .31511 .56076 L .3122 .5607 L F
.31398 .56183 m .31661 .56183 L .31511 .56076 L F
.488 .831 .549 r
.48257 .41279 m .4829 .41242 L .48427 .41103 L F
.48257 .41279 m .48098 .41414 L .4829 .41242 L F
.129 0 0 r
.28711 .51733 m .28407 .51943 L .28675 .51885 L F
.976 .847 .65 r
.41163 .54012 m .41303 .54155 L .41392 .53897 L F
.82 .525 .49 r
.43806 .57512 m .43816 .57827 L .43462 .57749 L F
.26 .268 .679 r
.44013 .57423 m .44023 .5768 L .43806 .57512 L F
.466 .246 .496 r
.44023 .5768 m .43816 .57827 L .43806 .57512 L F
.878 .919 .85 r
.61817 .35521 m .61954 .35673 L .62078 .3549 L F
.861 .567 .491 r
.67416 .30882 m .67428 .31172 L .6777 .31221 L F
.569 .352 .547 r
.59448 .37214 m .59451 .37527 L .59177 .37503 L F
.495 .848 .589 r
.59776 .36942 m .59631 .37048 L .59448 .37214 L F
0 0 .393 r
.59633 .37311 m .59448 .37214 L .59631 .37048 L F
.59633 .37311 m .59451 .37527 L .59448 .37214 L F
.85 .502 .393 r
.68176 .35053 m .68277 .34921 L .67949 .34761 L F
.68176 .35053 m .68294 .35143 L .68277 .34921 L F
.802 .637 .678 r
.34255 .5681 m .34211 .57119 L .34616 .57164 L F
.802 .632 .672 r
.34211 .57119 m .34407 .57482 L .34616 .57164 L F
.946 .711 .551 r
.33952 .53332 m .34155 .53784 L .34161 .53504 L F
.913 .884 .791 r
.29578 .62169 m .29854 .61751 L .2966 .61612 L F
.847 .9 .874 r
.29892 .61542 m .29854 .61751 L .2966 .61612 L F
.29928 .61669 m .29854 .61751 L .29892 .61542 L F
.301 .6148 m .2966 .61612 L .29868 .61445 L F
.86 .576 .507 r
.29788 .61164 m .29868 .61445 L .29491 .61326 L F
.598 .809 .981 r
.29491 .61326 m .29868 .61445 L .29806 .61242 L F
.547 .237 .394 r
.29902 .61673 m .29868 .61445 L .2966 .61612 L F
.785 .523 0 r
.29806 .61242 m .29819 .61284 L .29902 .61673 L F
.29819 .61284 m .29868 .61445 L .29872 .61472 L F
.29819 .61284 m .29872 .61472 L .29902 .61673 L F
.847 .9 .874 r
.301 .6148 m .29928 .61669 L .29892 .61542 L F
.192 .609 .945 r
.30089 .61779 m .29854 .61751 L .301 .6148 L F
.16 .608 .934 r
.2966 .61612 m .29854 .61751 L .30089 .61779 L F
.621 .353 .49 r
.34863 .50179 m .34884 .50432 L .34882 .50106 L F
.186 0 .138 r
.34884 .50432 m .35198 .50083 L .34882 .50106 L F
.419 .862 .792 r
.64112 .38043 m .63811 .38205 L .64004 .38085 L F
.422 .866 .809 r
.64004 .38085 m .63811 .38205 L .63744 .382 L F
.598 .423 .615 r
.26258 .53481 m .26086 .53626 L .26307 .5353 L F
.64 .469 .636 r
.26086 .53626 m .26317 .53807 L .26307 .5353 L F
.26086 .53626 m .26041 .53867 L .26317 .53807 L F
.494 .266 .497 r
.4658 .51195 m .4684 .51404 L .46842 .51114 L F
.4658 .51195 m .46564 .51466 L .4684 .51404 L F
.4658 .51195 m .4684 .51404 L .46842 .51114 L F
.4658 .51195 m .46564 .51466 L .4684 .51404 L F
.965 .826 .657 r
.34273 .54385 m .34109 .54776 L .3429 .54861 L F
.976 .779 .574 r
.34109 .54776 m .34237 .55146 L .3429 .54861 L F
.622 .563 .768 r
.52242 .47432 m .51786 .477 L .52004 .47564 L F
.52242 .47432 m .52209 .47756 L .51786 .477 L F
.679 .853 .966 r
.52066 .37513 m .51824 .37468 L .52108 .37284 L F
.194 .266 .71 r
.52108 .37284 m .52288 .37414 L .52066 .37513 L F
.583 .347 .523 r
.52288 .37414 m .52019 .37634 L .52066 .37513 L F
.073 .479 .892 r
.4415 .56803 m .44529 .57036 L .44306 .5699 L F
.257 0 .043 r
.27619 .54721 m .27276 .54812 L .2757 .54661 L F
.573 .351 .541 r
.27619 .54721 m .27208 .55022 L .27276 .54812 L F
.753 .24 0 r
.37879 .50806 m .38101 .51081 L .3829 .51184 L F
.744 .306 .211 r
.38095 .51352 m .3829 .51184 L .38101 .51081 L F
.38095 .51352 m .38509 .51447 L .3829 .51184 L F
.764 .289 .111 r
.3829 .51184 m .38509 .51447 L .38694 .51469 L F
.336 .519 .888 r
.56467 .35316 m .56338 .35549 L .56093 .35168 L F
0 .21 .736 r
.56263 .35395 m .56338 .35549 L .56093 .35168 L F
.867 .842 .818 r
.56338 .35549 m .55852 .35687 L .56263 .35395 L F
.56338 .35549 m .56045 .35887 L .55852 .35687 L F
.351 .538 .898 r
.56467 .35316 m .56521 .35514 L .56338 .35549 L F
.974 .691 .429 r
.41733 .55687 m .41959 .56128 L .41985 .55817 L F
.327 .731 .98 r
.39961 .57717 m .40255 .57734 L .40418 .57849 L F
.96 .882 .712 r
.40418 .57849 m .40423 .57408 L .40622 .575 L F
.40418 .57849 m .40255 .57734 L .40423 .57408 L F
.166 0 0 r
.62045 .36817 m .62323 .36717 L .62397 .36547 L F
.687 .209 .112 r
.62397 .36547 m .62684 .36726 L .62608 .36366 L F
.62397 .36547 m .62323 .36717 L .62684 .36726 L F
0 0 0 r
.41396 .46877 m .41756 .4655 L .4161 .4673 L F
0 0 .052 r
.41756 .4655 m .42014 .46196 L .41922 .46402 L F
0 .243 .738 r
.5479 .34255 m .54664 .34253 L .54508 .34275 L F
.87 .897 .85 r
.49995 .49293 m .49556 .49448 L .4973 .49293 L F
.49995 .49293 m .49726 .49583 L .49556 .49448 L F
.626 .949 .94 r
.50237 .4915 m .49995 .49293 L .4973 .49293 L F
.772 .777 .856 r
.43519 .56189 m .43122 .5617 L .43305 .55938 L F
.77 .776 .858 r
.43825 .55895 m .43519 .56189 L .43305 .55938 L F
.71 .3 .268 r
.51384 .42424 m .51265 .42429 L .51294 .42531 L F
.428 .253 .54 r
.46185 .52808 m .46426 .52736 L .46401 .52465 L F
.44 .283 .571 r
.46185 .52808 m .46441 .53018 L .46426 .52736 L F
0 0 .305 r
.46401 .52465 m .46426 .52736 L .465 .52567 L F
.988 .719 .399 r
.46426 .52736 m .46326 .52868 L .465 .52567 L F
.46326 .52868 m .46295 .52908 L .46327 .52855 L F
.46326 .52868 m .46327 .52855 L .465 .52567 L F
0 .159 .677 r
.46516 .53161 m .46441 .53018 L .4632 .52918 L F
.46316 .52948 m .4632 .52918 L .46185 .52808 L F
.46516 .53161 m .4632 .52918 L .46316 .52948 L F
.856 .645 .616 r
.46516 .53161 m .46187 .53348 L .46441 .53018 L F
.46516 .53161 m .46402 .53522 L .46187 .53348 L F
.186 0 0 r
.59409 .34225 m .59706 .34287 L .59818 .3428 L F
.29 0 0 r
.59706 .34287 m .60106 .34375 L .59818 .3428 L F
.518 0 0 r
.2757 .54661 m .27791 .54789 L .27619 .54721 L F
.142 .29 .756 r
.40102 .56788 m .40371 .57017 L .40541 .56856 L F
.955 .785 .633 r
.37317 .54215 m .37053 .54374 L .37074 .54095 L F
.37317 .54215 m .37245 .5449 L .37053 .54374 L F
.863 .919 .866 r
.56724 .39733 m .57169 .39542 L .57026 .39383 L F
.813 .892 .9 r
.57026 .39383 m .57169 .39542 L .57513 .39261 L F
.976 .863 .662 r
.3184 .58971 m .32097 .58893 L .32049 .5868 L F
.3184 .58971 m .3195 .59037 L .32097 .58893 L F
.629 .239 .286 r
.32097 .58893 m .32217 .59019 L .3195 .59037 L F
.603 .512 .724 r
.51464 .40583 m .51219 .40665 L .51293 .40412 L F
.887 .789 .747 r
.31041 .68856 m .31194 .68747 L .30843 .68712 L F
.819 .801 .834 r
.49726 .49583 m .4925 .49737 L .49556 .49448 L F
.595 .868 .994 r
.24766 .6111 m .24535 .61207 L .24348 .61096 L F
.24766 .6111 m .24535 .61207 L .24348 .61096 L F
.34 .437 .815 r
.56909 .36035 m .56809 .3626 L .56716 .35983 L F
0 0 0 r
.56909 .36035 m .56846 .36559 L .56809 .3626 L F
.911 .683 .581 r
.37683 .55483 m .37407 .55421 L .37427 .5513 L F
.92 .71 .601 r
.37607 .5579 m .37407 .55421 L .37683 .55483 L F
.787 .688 .755 r
.2457 .59801 m .24642 .60165 L .24215 .60076 L F
.4 0 0 r
.24515 .60128 m .24069 .59994 L .24215 .60076 L F
0 .51 .759 r
.24564 .60149 m .24515 .60128 L .24215 .60076 L F
.4 0 0 r
.24515 .60128 m .24371 .60145 L .24069 .59994 L F
.058 .275 .766 r
.24069 .59994 m .24315 .60117 L .24127 .59832 L F
.24315 .60117 m .24371 .60145 L .24318 .60077 L F
.24315 .60117 m .24318 .60077 L .24127 .59832 L F
.847 .682 .677 r
.24061 .5959 m .24388 .59922 L .24737 .59462 L F
.394 0 0 r
.24127 .59832 m .24388 .59922 L .24061 .5959 L F
.24366 .59914 m .24356 .59921 L .24388 .59922 L F
.24127 .59832 m .24356 .59921 L .24366 .59914 L F
.889 .471 .195 r
.24356 .59921 m .24465 .60055 L .24425 .60062 L F
.695 .508 .63 r
.24347 .59945 m .24371 .60145 L .24432 .60072 L F
.24318 .60077 m .24371 .60145 L .24347 .59945 L F
.889 .471 .195 r
.24347 .59945 m .24425 .60062 L .24298 .60084 L F
.24356 .59921 m .24425 .60062 L .24347 .59945 L F
.8 .976 .686 r
.24502 .60037 m .24462 .60061 L .24515 .60128 L F
0 .51 .759 r
.24642 .60165 m .24515 .60128 L .24564 .60149 L F
.983 .905 .637 r
.24599 .5968 m .24642 .60165 L .2457 .59801 L F
.24599 .5968 m .24515 .60128 L .24642 .60165 L F
.826 .798 .303 r
.24597 .59662 m .24515 .60128 L .24599 .5968 L F
.24597 .59662 m .24496 .59995 L .24515 .60128 L F
.422 .493 .828 r
.24498 .5999 m .24465 .60055 L .24356 .59921 L F
.826 .798 .303 r
.24496 .59995 m .24496 .59995 L .24496 .59995 L F
.24496 .59995 m .24496 .59995 L .24515 .60128 L F
.422 .493 .828 r
.24748 .60112 m .24615 .60239 L .24484 .60078 L F
.24486 .6006 m .24484 .60078 L .24465 .60055 L F
.24748 .60112 m .24484 .60078 L .24486 .6006 L F
.8 .976 .686 r
.24496 .59995 m .24432 .60072 L .24502 .60037 L F
.422 .493 .828 r
.24748 .60112 m .24465 .60055 L .24498 .5999 L F
.8 .976 .686 r
.24462 .60061 m .24419 .60087 L .24443 .60098 L F
.24462 .60061 m .24443 .60098 L .24515 .60128 L F
.695 .508 .63 r
.24347 .59945 m .24432 .60072 L .2448 .60014 L F
.24127 .59832 m .24318 .60077 L .24347 .59945 L F
.723 .251 .128 r
.24127 .59832 m .24298 .60084 L .24347 .59945 L F
.24127 .59832 m .24347 .59945 L .24356 .59921 L F
.695 .508 .63 r
.24351 .5993 m .2448 .60014 L .24496 .59995 L F
.889 .471 .195 r
.24356 .59921 m .24298 .60084 L .24127 .59832 L F
.695 .508 .63 r
.24127 .59832 m .24347 .59945 L .24351 .5993 L F
.24347 .59945 m .2448 .60014 L .24351 .5993 L F
.566 0 0 r
.24127 .59832 m .24351 .5993 L .24356 .59921 L F
.24351 .5993 m .24496 .59995 L .24356 .59921 L F
.523 .55 .825 r
.24347 .59945 m .24351 .5993 L .24356 .59921 L F
.24351 .5993 m .24352 .59924 L .24356 .59921 L F
.24333 .59937 m .24369 .59635 L .24357 .59903 L F
.24352 .59924 m .24357 .59903 L .24356 .59921 L F
.24333 .59937 m .24357 .59903 L .24352 .59924 L F
.24325 .6001 m .24333 .59937 L .24352 .59924 L F
.24325 .6001 m .24352 .59924 L .24347 .59945 L F
.24298 .60084 m .24344 .59795 L .24325 .6001 L F
.24344 .59795 m .24369 .59635 L .24325 .6001 L F
.8 .976 .686 r
.24432 .60072 m .24419 .60087 L .24502 .60037 L F
.24419 .60087 m .24371 .60145 L .24515 .60128 L F
.889 .471 .195 r
.24465 .60055 m .24615 .60239 L .24354 .60112 L F
.24465 .60055 m .24354 .60112 L .24298 .60084 L F
0 0 .294 r
.23856 .61469 m .23843 .6151 L .23794 .61294 L F
.288 .114 .463 r
.24056 .61677 m .23843 .6151 L .23856 .61469 L F
.24056 .61677 m .23818 .61803 L .23843 .6151 L F
.512 .163 .313 r
.33226 .67841 m .33455 .67828 L .3317 .67882 L F
.715 .789 .91 r
.53467 .46219 m .53033 .46166 L .53321 .46088 L F
.816 .909 .903 r
.53778 .45957 m .53467 .46219 L .53321 .46088 L F
0 0 .043 r
.55852 .40905 m .56173 .40629 L .55913 .40705 L F
.55852 .40905 m .56066 .40681 L .56173 .40629 L F
.57 .94 .851 r
.56355 .4054 m .55913 .40705 L .56173 .40629 L F
0 0 .043 r
.56066 .40681 m .56133 .40611 L .56173 .40629 L F
.57 .94 .851 r
.56356 .4054 m .56355 .4054 L .56173 .40629 L F
0 0 0 r
.56642 .4022 m .56356 .4054 L .5655 .40396 L F
.454 .859 .684 r
.5655 .40396 m .56356 .4054 L .56173 .40629 L F
.892 .857 .8 r
.54999 .43285 m .54686 .43369 L .54908 .42981 L F
.54999 .43285 m .54854 .43511 L .54686 .43369 L F
.762 .715 .808 r
.33218 .60095 m .33615 .60137 L .33468 .59766 L F
.722 .485 .567 r
.40535 .5654 m .40394 .56811 L .40102 .56788 L F
.614 .071 0 r
.3241 .55922 m .32463 .55971 L .32608 .56043 L F
0 0 0 r
.32391 .55929 m .3241 .55922 L .32428 .55928 L F
.714 .651 .786 r
.32182 .56008 m .32492 .561 L .3241 .55922 L F
.32492 .561 m .32713 .56165 L .32506 .55999 L F
.32492 .561 m .32506 .55999 L .3241 .55922 L F
0 0 0 r
.32428 .55928 m .3241 .55922 L .32695 .55921 L F
.657 .642 .824 r
.3265 .55938 m .32391 .55929 L .32695 .55921 L F
.614 .071 0 r
.3241 .55922 m .32608 .56043 L .32695 .55921 L F
.862 .98 .854 r
.32608 .56043 m .32507 .55993 L .32755 .55648 L F
.32507 .55993 m .32463 .55971 L .32519 .55909 L F
.32507 .55993 m .32519 .55909 L .32755 .55648 L F
.331 .373 .754 r
.32507 .55484 m .32464 .55966 L .3241 .55922 L F
.32464 .55966 m .32463 .55971 L .3241 .55922 L F
.824 .816 .842 r
.32755 .55648 m .32466 .55968 L .32507 .55484 L F
.32466 .55968 m .32463 .55971 L .32464 .55966 L F
.32466 .55968 m .32464 .55966 L .32507 .55484 L F
.955 .941 .724 r
.32713 .56165 m .32705 .56159 L .3241 .55922 L F
.32705 .56159 m .32576 .56059 L .32464 .55966 L F
.32705 .56159 m .32464 .55966 L .3241 .55922 L F
.32576 .56059 m .32545 .56034 L .3241 .55922 L F
.863 .639 .598 r
.32545 .56034 m .32401 .55919 L .3241 .55922 L F
.32401 .55919 m .32314 .55849 L .3241 .55922 L F
0 0 0 r
.32391 .55929 m .32182 .56008 L .3241 .55922 L F
.45391 .4342 m .45553 .43299 L .4523 .43496 L F
.45035 .43591 m .45391 .4342 L .4523 .43496 L F
.936 .818 .703 r
.47231 .53645 m .47409 .5379 L .47559 .53558 L F
.676 .768 .92 r
.31625 .63572 m .31211 .63497 L .31467 .63391 L F
.661 .756 .92 r
.31899 .63465 m .31625 .63572 L .31467 .63391 L F
.971 .832 .648 r
.68659 .35772 m .68784 .3584 L .6871 .35475 L F
.549 .058 .043 r
.28052 .62396 m .28517 .62436 L .28198 .62291 L F
.51 .418 .687 r
.24819 .56234 m .25081 .56189 L .24998 .55766 L F
.548 .501 .755 r
.24819 .56234 m .25138 .56414 L .25081 .56189 L F
.774 .791 .867 r
.34076 .625 m .34197 .628 L .33778 .62775 L F
.77 .789 .869 r
.34476 .62537 m .34197 .628 L .34076 .625 L F
.961 .807 .644 r
.54686 .43369 m .54854 .43511 L .54722 .43866 L F
.082 0 .039 r
.33455 .67828 m .33845 .67442 L .33642 .6765 L F
.055 0 0 r
.33642 .6765 m .33845 .67442 L .34048 .67372 L F
.841 .777 .79 r
.32217 .59019 m .32158 .59508 L .31988 .59402 L F
.993 .874 .548 r
.32158 .59508 m .31961 .5977 L .31988 .59402 L F
.32158 .59508 m .32084 .59783 L .31961 .5977 L F
.133 .13 .588 r
.35085 .64439 m .35142 .647 L .34948 .64446 L F
.85 .996 .825 r
.66412 .38018 m .66614 .37976 L .66753 .37785 L F
0 0 0 r
.44907 .44775 m .45189 .4466 L .45 .44739 L F
.509 .895 .729 r
.45 .44739 m .45411 .44507 L .45209 .44591 L F
0 0 0 r
.4509 .44705 m .45 .44739 L .45209 .44591 L F
.44887 .449 m .45 .44739 L .4509 .44705 L F
.44747 .4484 m .44907 .44775 L .45 .44739 L F
.086 0 0 r
.63517 .34122 m .63818 .34077 L .63937 .33993 L F
0 0 0 r
.63937 .33993 m .64073 .33973 L .64226 .33912 L F
.63937 .33993 m .63818 .34077 L .64073 .33973 L F
.685 .829 .952 r
.56483 .40062 m .56642 .4022 L .5685 .4004 L F
0 0 0 r
.5685 .4004 m .56642 .4022 L .5655 .40396 L F
.883 .985 .712 r
.56862 .4065 m .56833 .40892 L .57055 .40547 L F
.87 .777 .277 r
.56764 .41042 m .56833 .40892 L .56862 .4065 L F
.56764 .41042 m .56786 .4115 L .56833 .40892 L F
.537 .249 .425 r
.3317 .67882 m .3335 .67943 L .33041 .67998 L F
.3317 .67882 m .33455 .67828 L .3335 .67943 L F
.671 .595 .762 r
.2834 .53594 m .28273 .53853 L .28097 .53852 L F
.188 0 .162 r
.28273 .53853 m .2809 .54063 L .28097 .53852 L F
.328 .813 .856 r
.48077 .42752 m .48576 .42675 L .48311 .42591 L F
.754 .947 .943 r
.48311 .42591 m .48576 .42675 L .48782 .42496 L F
.685 .72 .876 r
.30999 .6364 m .3052 .63511 L .30787 .63415 L F
.683 .729 .885 r
.31211 .63497 m .30999 .6364 L .30787 .63415 L F
.939 .929 .767 r
.67965 .36813 m .68282 .36555 L .68213 .36431 L F
.67965 .36813 m .68072 .36935 L .68282 .36555 L F
.856 .96 .623 r
.68282 .36555 m .68477 .36085 L .68213 .36431 L F
.438 0 0 r
.60857 .39183 m .61271 .39155 L .61201 .38986 L F
.60857 .39183 m .61201 .38986 L .61023 .38972 L F
.60857 .39183 m .61137 .38829 L .6084 .38866 L F
.60857 .39183 m .6084 .38866 L .61124 .39072 L F
.656 .161 .064 r
.60717 .39014 m .61124 .39072 L .60982 .38969 L F
.60767 .38953 m .60982 .38969 L .6084 .38866 L F
.60717 .39014 m .60982 .38969 L .60767 .38953 L F
.438 0 0 r
.61023 .38972 m .61201 .38986 L .61137 .38829 L F
.344 .655 .97 r
.61271 .39155 m .61393 .38758 L .61137 .38829 L F
.61271 .39155 m .61397 .38997 L .61393 .38758 L F
.61271 .39155 m .61605 .39198 L .61397 .38997 L F
.656 .847 .973 r
.30352 .63397 m .30237 .63622 L .30056 .63644 L F
.30352 .63397 m .3052 .63511 L .30237 .63622 L F
.946 .716 .557 r
.33186 .51743 m .33488 .52097 L .33437 .51946 L F
.944 .744 .602 r
.39186 .53532 m .39111 .53795 L .38955 .53404 L F
.39186 .53532 m .39111 .53795 L .38955 .53404 L F
.82 .869 .882 r
.623 .34926 m .62371 .35144 L .62466 .34929 L F
.623 .34926 m .62048 .35118 L .62371 .35144 L F
.863 .817 .802 r
.62048 .35118 m .62227 .35317 L .62371 .35144 L F
.724 .95 .651 r
.52638 .39662 m .52449 .39912 L .5257 .39703 L F
0 0 0 r
.52449 .39912 m .52514 .39959 L .5257 .39703 L F
.52449 .39912 m .52332 .40061 L .52514 .39959 L F
.704 .593 .729 r
.25795 .54197 m .26114 .54199 L .26041 .53867 L F
.579 .422 .633 r
.25795 .54197 m .26035 .54423 L .26114 .54199 L F
.25795 .54197 m .25783 .54482 L .26035 .54423 L F
.1 0 .276 r
.37776 .47483 m .37974 .47314 L .37769 .47338 L F
.844 .984 .703 r
.37633 .47531 m .37776 .47483 L .37769 .47338 L F
0 0 .419 r
.56257 .38227 m .56374 .38029 L .56332 .37748 L F
.955 .65 .417 r
.56257 .38227 m .56252 .38229 L .56374 .38029 L F
.56257 .38227 m .56065 .38327 L .56252 .38229 L F
.56257 .38227 m .56248 .38456 L .56065 .38327 L F
.83 .782 .806 r
.32656 .58832 m .32217 .59019 L .32439 .58704 L F
.763 .765 .855 r
.3131 .60865 m .31764 .60905 L .31562 .60743 L F
.741 .82 .913 r
.31764 .60905 m .32008 .60774 L .31562 .60743 L F
.461 .431 .739 r
.26041 .53867 m .26114 .54199 L .26312 .54089 L F
.56 .393 .611 r
.26035 .54423 m .26312 .54089 L .26114 .54199 L F
.504 .598 .881 r
.49436 .44166 m .49617 .44543 L .49895 .44493 L F
.475 .471 .773 r
.49617 .44543 m .49946 .44804 L .49895 .44493 L F
.778 .97 .92 r
.48335 .49868 m .48396 .49572 L .48606 .4978 L F
.48335 .49868 m .48248 .49757 L .48396 .49572 L F
.97 .93 .634 r
.48335 .49868 m .48131 .49952 L .48248 .49757 L F
.966 .653 .368 r
.48335 .49868 m .48326 .50102 L .48131 .49952 L F
.659 .349 .437 r
.48828 .50039 m .48335 .49868 L .48606 .4978 L F
.48828 .50039 m .48326 .50102 L .48335 .49868 L F
.442 .262 .541 r
.49147 .43338 m .49396 .43762 L .49383 .43582 L F
.685 .201 .094 r
.49147 .43338 m .49323 .43205 L .48955 .4314 L F
.585 .933 .945 r
.49462 .43035 m .49617 .43068 L .49323 .43205 L F
.442 .262 .541 r
.49147 .43338 m .49383 .43582 L .4935 .43158 L F
.685 .201 .094 r
.49147 .43338 m .48955 .4314 L .48944 .43138 L F
.593 .897 .617 r
.49462 .43035 m .49323 .43205 L .49147 .43338 L F
.771 .671 .752 r
.34128 .58084 m .34271 .58487 L .34538 .58132 L F
.155 0 0 r
.42014 .46196 m .42131 .46315 L .41922 .46402 L F
.42014 .46196 m .42264 .46117 L .42131 .46315 L F
.778 .66 .733 r
.3756 .57489 m .37748 .57876 L .37529 .5782 L F
.952 .798 .652 r
.37748 .57876 m .37442 .58011 L .37529 .5782 L F
.37748 .57876 m .37685 .58147 L .37442 .58011 L F
0 0 0 r
.49384 .40446 m .49578 .40378 L .49707 .40238 L F
.49384 .40446 m .49309 .40495 L .49578 .40378 L F
.069 0 0 r
.27643 .52702 m .28081 .52318 L .2772 .52481 L F
.27643 .52702 m .27912 .52633 L .28081 .52318 L F
0 0 0 r
.28081 .52318 m .28242 .52066 L .27981 .52109 L F
.28081 .52318 m .28146 .52285 L .28242 .52066 L F
.309 .102 .428 r
.27912 .52633 m .28146 .52285 L .28081 .52318 L F
.81 .689 .732 r
.33852 .58427 m .34271 .58487 L .34128 .58084 L F
.814 .671 .706 r
.33852 .58427 m .34016 .58829 L .34271 .58487 L F
.143 .651 .901 r
.51727 .38411 m .51934 .38421 L .52165 .38497 L F
.937 .738 .608 r
.51934 .38421 m .52137 .38879 L .52165 .38497 L F
.899 .809 .75 r
.39916 .52014 m .40056 .5246 L .40042 .52161 L F
.425 0 .116 r
.37417 .51056 m .37879 .50806 L .37433 .50823 L F
.37417 .51056 m .37684 .51044 L .37879 .50806 L F
.731 .351 .331 r
.37879 .50806 m .37684 .51044 L .38101 .51081 L F
.94 .747 .615 r
.34113 .54035 m .34273 .54385 L .34315 .54168 L F
.259 .438 .848 r
.53299 .41402 m .5311 .41532 L .52993 .41278 L F
.432 .853 .702 r
.52907 .41615 m .5311 .41532 L .53299 .41402 L F
.66 .772 .932 r
.29657 .63636 m .29506 .63989 L .29421 .63774 L F
.29657 .63636 m .29872 .63822 L .29506 .63989 L F
.967 .905 .705 r
.39916 .52014 m .40055 .51822 L .39776 .51843 L F
.232 0 .006 r
.35198 .50083 m .35413 .50088 L .35554 .49875 L F
.432 0 .114 r
.35554 .49875 m .35809 .49987 L .35777 .49757 L F
.35554 .49875 m .35413 .50088 L .35809 .49987 L F
.923 .545 .275 r
.57353 .42676 m .57589 .42847 L .57491 .42541 L F
.528 .844 .542 r
.57222 .40372 m .57055 .40547 L .57376 .40233 L F
.566 .912 .699 r
.57222 .40372 m .56862 .4065 L .57055 .40547 L F
.923 .545 .275 r
.57491 .42541 m .57589 .42847 L .57353 .42676 L F
0 .287 .786 r
.59744 .36694 m .59776 .36942 L .59577 .36624 L F
.347 .23 .575 r
.59744 .36694 m .59631 .37048 L .59776 .36942 L F
.592 .519 .741 r
.6249 .36896 m .62169 .37167 L .62144 .37025 L F
.696 .714 .863 r
.62045 .36817 m .62169 .37167 L .6249 .36896 L F
0 0 0 r
.45797 .43168 m .45553 .43299 L .45391 .4342 L F
.63 .956 .925 r
.46938 .43502 m .47091 .43339 L .46915 .435 L F
.8 .486 .46 r
.68305 .35399 m .68679 .35232 L .68294 .35143 L F
.68305 .35399 m .6871 .35475 L .68679 .35232 L F
.768 .43 .414 r
.32504 .51038 m .32928 .50871 L .3254 .50839 L F
.32504 .51038 m .32931 .51095 L .32928 .50871 L F
.993 .878 .564 r
.53939 .45782 m .53838 .4566 L .54005 .45539 L F
.997 .858 .548 r
.54005 .45539 m .53838 .4566 L .53888 .45398 L F
.472 .829 .995 r
.31677 .59106 m .3184 .58971 L .31592 .5878 L F
.965 .93 .612 r
.32683 .58112 m .32612 .58003 L .32808 .5784 L F
.888 .95 .842 r
.33062 .57525 m .32808 .5784 L .32722 .57622 L F
.982 .907 .595 r
.32808 .5784 m .32612 .58003 L .32722 .57622 L F
.743 .982 .754 r
.50946 .39335 m .51088 .39097 L .51184 .39186 L F
.50946 .39335 m .50782 .39402 L .51088 .39097 L F
.883 .577 .464 r
.32358 .57754 m .32075 .57429 L .32293 .57463 L F
.341 .412 .79 r
.32497 .57364 m .32293 .57463 L .32205 .57115 L F
0 0 .262 r
.32497 .57364 m .32358 .57754 L .32293 .57463 L F
.716 .667 .801 r
.54819 .41284 m .54949 .41555 L .54515 .41624 L F
.423 0 .007 r
.54515 .41624 m .54949 .41555 L .54742 .41727 L F
.954 .711 .532 r
.54949 .41555 m .54929 .41824 L .54742 .41727 L F
.976 .678 .375 r
.56045 .35887 m .55897 .36013 L .55852 .35687 L F
0 0 .418 r
.56045 .35887 m .56122 .35907 L .55897 .36013 L F
.838 .715 .186 r
.56379 .37195 m .5635 .36969 L .56372 .36658 L F
.877 .659 .134 r
.56402 .3724 m .5635 .36969 L .56379 .37195 L F
0 0 .403 r
.40056 .5246 m .40203 .52727 L .40235 .52828 L F
.995 .761 .41 r
.40099 .53005 m .40235 .52828 L .40203 .52727 L F
.40099 .53005 m .40219 .53158 L .40235 .52828 L F
.764 .522 .568 r
.40235 .52828 m .40219 .53158 L .40742 .53169 L F
.362 0 0 r
.27894 .64474 m .28034 .6462 L .27785 .64686 L F
.27894 .64474 m .28237 .64541 L .28034 .6462 L F
.812 .848 .876 r
.54819 .41284 m .54515 .41624 L .54335 .41389 L F
.423 0 .007 r
.54515 .41624 m .54742 .41727 L .5448 .41789 L F
.793 .702 .764 r
.54744 .3979 m .5484 .40174 L .54453 .40114 L F
.798 .689 .744 r
.5484 .40174 m .54597 .40575 L .54453 .40114 L F
0 0 .543 r
.54914 .40065 m .5484 .40174 L .54744 .3979 L F
.006 .582 .727 r
.54853 .40166 m .5484 .40174 L .54914 .40065 L F
.54853 .40166 m .55137 .40177 L .5484 .40174 L F
.794 .733 .795 r
.34927 .621 m .35184 .62468 L .34724 .62428 L F
.771 .775 .856 r
.34724 .62428 m .35184 .62468 L .34937 .62596 L F
.479 .611 .904 r
.35408 .62411 m .35184 .62468 L .34927 .621 L F
.037 .022 .508 r
.35319 .62644 m .35184 .62468 L .35408 .62411 L F
.35319 .62644 m .35185 .62857 L .35184 .62468 L F
.725 .687 .814 r
.34937 .62596 m .34476 .62537 L .34724 .62428 L F
.999 .808 .465 r
.36267 .50327 m .36378 .50201 L .36183 .50161 L F
.36267 .50327 m .36355 .5049 L .36378 .50201 L F
.565 .616 .862 r
.44209 .56207 m .43825 .55895 L .44176 .55716 L F
0 0 0 r
.44497 .56052 m .44216 .56611 L .44209 .56207 L F
.871 .502 .013 r
.54076 .44825 m .54258 .45197 L .54138 .45045 L F
.923 .975 .748 r
.45053 .55766 m .44755 .56081 L .44851 .56129 L F
.314 .328 .715 r
.25893 .57389 m .25745 .57761 L .25724 .5756 L F
.51 .572 .855 r
.59351 .36137 m .59305 .36623 L .59255 .36133 L F
.59351 .36137 m .59577 .36624 L .59305 .36623 L F
.871 .618 .554 r
.33364 .56453 m .33004 .56102 L .33394 .56149 L F
.614 .809 .975 r
.47666 .51762 m .47403 .51855 L .47242 .51707 L F
.512 .091 .179 r
.65817 .3325 m .66094 .3339 L .66216 .33169 L F
.632 .218 .24 r
.66216 .33169 m .66522 .33382 L .66492 .33196 L F
.66216 .33169 m .66094 .3339 L .66522 .33382 L F
.329 0 0 r
.41772 .59745 m .41314 .59757 L .41542 .59863 L F
.452 .036 .158 r
.43262 .4557 m .43224 .45706 L .42829 .45831 L F
.47 .052 .163 r
.43262 .4557 m .43473 .457 L .43224 .45706 L F
.388 .12 .38 r
.43518 .45472 m .43473 .457 L .43262 .4557 L F
.722 .722 .85 r
.30697 .6018 m .3066 .60586 L .30465 .60162 L F
.30697 .6018 m .30898 .60463 L .3066 .60586 L F
.83 .362 0 r
.49142 .43505 m .48962 .43513 L .49112 .43358 L F
.772 .709 .793 r
.43962 .58187 m .4356 .58165 L .43816 .57827 L F
.947 .83 .696 r
.65922 .36297 m .65626 .36466 L .65957 .36025 L F
.65922 .36297 m .65811 .36673 L .65626 .36466 L F
.946 .716 .557 r
.33186 .51743 m .33144 .52028 L .33488 .52097 L F
.917 .641 .503 r
.3308 .52253 m .33488 .52097 L .33144 .52028 L F
.3308 .52253 m .33473 .52451 L .33488 .52097 L F
.865 .59 .521 r
.33488 .52097 m .33473 .52451 L .33653 .52476 L F
.188 0 .162 r
.28273 .53853 m .28325 .53977 L .2809 .54063 L F
.535 .457 .715 r
.28633 .53697 m .28273 .53853 L .2834 .53594 L F
.435 .13 .347 r
.28633 .53697 m .28325 .53977 L .28273 .53853 L F
.936 .632 .441 r
.33653 .52476 m .33664 .52741 L .33881 .52831 L F
.906 .609 .473 r
.3364 .53024 m .33881 .52831 L .33664 .52741 L F
.3364 .53024 m .34 .53154 L .33881 .52831 L F
.851 .817 .815 r
.62078 .3549 m .62227 .35317 L .62048 .35118 L F
.142 .108 .556 r
.28653 .66311 m .28487 .6629 L .28743 .65985 L F
.04 .413 .861 r
.28255 .66085 m .28487 .6629 L .28653 .66311 L F
.819 .79 .824 r
.32084 .59783 m .31853 .60132 L .31696 .59761 L F
.638 .33 .434 r
.53245 .39369 m .53206 .39604 L .53339 .39504 L F
.809 .681 .723 r
.29156 .62122 m .29578 .62169 L .2941 .61692 L F
.913 .884 .791 r
.29578 .62169 m .2966 .61612 L .2941 .61692 L F
.882 .986 .716 r
.51663 .43932 m .51799 .43855 L .51837 .43813 L F
.801 .901 .913 r
.46564 .54704 m .46404 .54584 L .46203 .54747 L F
.46564 .54704 m .46668 .54627 L .46404 .54584 L F
.834 .777 .798 r
.46203 .54747 m .46388 .54908 L .46564 .54704 L F
.986 .868 .635 r
.54967 .40587 m .54942 .40863 L .55019 .40568 L F
.54967 .40587 m .54942 .40863 L .55019 .40568 L F
.99 .889 .595 r
.55019 .40568 m .54942 .40863 L .54917 .40675 L F
.627 .141 .079 r
.39664 .51912 m .39916 .52014 L .39776 .51843 L F
.673 .652 .821 r
.43706 .58797 m .44105 .58909 L .43962 .58675 L F
.627 .688 .888 r
.43962 .58675 m .44105 .58909 L .44356 .58803 L F
.753 .584 .666 r
.3991 .54264 m .40372 .54509 L .40222 .54392 L F
.3991 .54264 m .40174 .5463 L .40372 .54509 L F
.825 .769 .8 r
.40174 .5463 m .40101 .54808 L .40372 .54509 L F
0 0 0 r
.40372 .54509 m .40258 .54129 L .40222 .54392 L F
.40372 .54509 m .40683 .5424 L .40258 .54129 L F
.40372 .54509 m .40363 .54539 L .40683 .5424 L F
.74 .556 .645 r
.53989 .34685 m .54283 .34521 L .53977 .34501 L F
.53989 .34685 m .54301 .34818 L .54283 .34521 L F
.594 .444 .648 r
.54283 .34521 m .54514 .34639 L .54508 .34275 L F
.54283 .34521 m .54301 .34818 L .54514 .34639 L F
.613 .636 .849 r
.60352 .35344 m .60129 .35581 L .59977 .35206 L F
.322 0 .058 r
.60352 .35344 m .59992 .35584 L .60129 .35581 L F
.256 0 .074 r
.31502 .68833 m .31938 .68433 L .31732 .68777 L F
0 0 0 r
.31732 .68777 m .31938 .68433 L .32012 .68487 L F
.209 0 .303 r
.26249 .56525 m .26225 .5675 L .26007 .56837 L F
.314 .12 .45 r
.26171 .57029 m .26007 .56837 L .26225 .5675 L F
.26171 .57029 m .25969 .57152 L .26007 .56837 L F
.864 .957 .867 r
.50306 .50564 m .50581 .50267 L .50333 .50281 L F
.867 .958 .863 r
.50306 .50564 m .50333 .50281 L .50073 .50573 L F
0 0 0 r
.39309 .46547 m .3887 .46801 L .39132 .46839 L F
.097 0 .107 r
.39309 .46547 m .39391 .46703 L .39565 .46476 L F
.39309 .46547 m .39132 .46839 L .39391 .46703 L F
.142 .29 .756 r
.40102 .56788 m .40245 .57183 L .40371 .57017 L F
.998 .849 .533 r
.40423 .57408 m .40371 .57017 L .40245 .57183 L F
.761 .362 .298 r
.4041 .59452 m .40254 .59674 L .40087 .59424 L F
0 0 0 r
.40686 .59435 m .40254 .59674 L .4041 .59452 L F
.817 .505 .462 r
.37054 .53841 m .3671 .54012 L .36745 .53742 L F
.37054 .53841 m .37074 .54095 L .3671 .54012 L F
0 0 .021 r
.50992 .42092 m .50961 .42201 L .51021 .41768 L F
.137 .436 .873 r
.51265 .42429 m .51083 .42293 L .50994 .42368 L F
.51083 .42293 m .50961 .42201 L .50994 .42368 L F
0 0 .146 r
.50994 .42368 m .50961 .42201 L .50992 .42092 L F
0 0 .246 r
.51072 .42196 m .50994 .42368 L .50994 .42331 L F
.51072 .42196 m .50994 .42331 L .50992 .42092 L F
.072 0 .408 r
.51327 .41981 m .51072 .42196 L .51093 .41913 L F
.824 .847 .865 r
.51121 .42113 m .51072 .42196 L .51137 .42106 L F
0 0 .246 r
.51072 .42196 m .50992 .42092 L .51093 .41913 L F
.824 .847 .865 r
.50722 .42267 m .51072 .42196 L .51121 .42113 L F
.727 .906 .534 r
.50933 .42419 m .50994 .42368 L .51072 .42196 L F
.876 .994 .783 r
.5076 .42567 m .50798 .42659 L .50994 .42368 L F
.5076 .42567 m .50994 .42368 L .50926 .42431 L F
.727 .906 .534 r
.50926 .42431 m .50994 .42368 L .50933 .42419 L F
.851 .817 .815 r
.62078 .3549 m .62048 .35118 L .6195 .35336 L F
.878 .919 .85 r
.61817 .35521 m .62078 .3549 L .6195 .35336 L F
.896 .988 .769 r
.30962 .65211 m .30967 .65421 L .31284 .65165 L F
.616 .388 .549 r
.30967 .65421 m .31294 .65399 L .31284 .65165 L F
.635 .934 .967 r
.31329 .64987 m .31284 .65165 L .31491 .65057 L F
.704 .978 .911 r
.30962 .65211 m .31284 .65165 L .31329 .64987 L F
.394 .147 .418 r
.31284 .65165 m .3146 .65383 L .31491 .65057 L F
.263 .124 .496 r
.31294 .65399 m .3146 .65383 L .31284 .65165 L F
0 0 .196 r
.35361 .65697 m .3523 .65816 L .35359 .65395 L F
0 0 0 r
.35111 .66043 m .3523 .65816 L .35361 .65697 L F
.705 .981 .801 r
.27253 .64723 m .27616 .64447 L .27537 .6474 L F
.689 .919 .59 r
.50128 .43006 m .50287 .42871 L .49953 .43276 L F
0 0 .041 r
.50499 .42501 m .50287 .42871 L .50454 .42721 L F
.477 .824 .545 r
.50454 .42721 m .50287 .42871 L .50128 .43006 L F
.855 .441 .243 r
.66059 .34566 m .65879 .34639 L .65674 .34479 L F
.66059 .34566 m .66124 .34773 L .65879 .34639 L F
.283 0 0 r
.40889 .58894 m .40739 .58911 L .40953 .58823 L F
.815 .599 .611 r
.40392 .58615 m .40824 .58858 L .40766 .58456 L F
.40824 .58858 m .40889 .58894 L .40873 .58834 L F
.40824 .58858 m .40873 .58834 L .40766 .58456 L F
.608 .813 .979 r
.40591 .58752 m .40779 .58838 L .40392 .58615 L F
.40813 .58858 m .40824 .58858 L .40392 .58615 L F
.965 .644 .266 r
.40766 .58456 m .40873 .58834 L .40953 .58823 L F
.431 0 0 r
.4122 .5877 m .40766 .58456 L .40953 .58823 L F
.696 .847 .955 r
.4109 .58686 m .40821 .58858 L .40591 .58752 L F
.40821 .58858 m .40739 .58911 L .40591 .58752 L F
.608 .813 .979 r
.40591 .58752 m .40813 .58858 L .40779 .58838 L F
.40813 .58858 m .40889 .58894 L .40824 .58858 L F
.535 .919 .792 r
.40832 .58858 m .40739 .58911 L .40813 .58863 L F
.40953 .58823 m .40868 .58858 L .40832 .58858 L F
.40868 .58858 m .40739 .58911 L .40832 .58858 L F
.40873 .58834 m .40813 .58863 L .40854 .58837 L F
.40953 .58823 m .40813 .58863 L .40873 .58834 L F
.40953 .58823 m .40854 .58837 L .4109 .58686 L F
.965 .644 .266 r
.40873 .58834 m .40889 .58894 L .40953 .58823 L F
.535 .919 .792 r
.40953 .58823 m .4109 .58686 L .4122 .5877 L F
.611 .403 .575 r
.41296 .59028 m .40953 .58823 L .4122 .5877 L F
.41296 .59028 m .40953 .59107 L .40953 .58823 L F
.961 .923 .581 r
.39197 .5696 m .39406 .56771 L .39275 .56688 L F
.859 .98 .856 r
.39275 .56688 m .39406 .56771 L .39746 .56355 L F
.39275 .56688 m .39746 .56355 L .39477 .56505 L F
.735 .979 .916 r
.39328 .56458 m .39275 .56688 L .39477 .56505 L F
0 0 .383 r
.39328 .56458 m .39389 .56817 L .39293 .56708 L F
.39295 .56603 m .39293 .56708 L .39275 .56688 L F
.39328 .56458 m .39293 .56708 L .39295 .56603 L F
.961 .923 .581 r
.39197 .5696 m .39244 .57148 L .39289 .57044 L F
.39291 .56875 m .39289 .57044 L .39406 .56771 L F
.39197 .5696 m .39289 .57044 L .39291 .56875 L F
.461 .431 .739 r
.26041 .53867 m .26312 .54089 L .26317 .53807 L F
.528 .916 .796 r
.46028 .4412 m .46392 .43923 L .46172 .43988 L F
.646 .965 .815 r
.46172 .43988 m .46392 .43923 L .46588 .43759 L F
.749 .718 .823 r
.59036 .35763 m .59255 .36133 L .59477 .35858 L F
.468 .889 .81 r
.59255 .36133 m .59323 .36035 L .59351 .36137 L F
.59255 .36133 m .58949 .36215 L .59323 .36035 L F
.375 .04 .264 r
.27106 .55633 m .26715 .56047 L .26774 .559 L F
.27106 .55633 m .26961 .55999 L .26715 .56047 L F
0 .245 .738 r
.26981 .5551 m .27236 .55677 L .27106 .55633 L F
.052 0 .11 r
.27236 .55677 m .26961 .55999 L .27106 .55633 L F
.509 .468 .747 r
.25783 .54482 m .25867 .54834 L .26091 .54758 L F
.304 .172 .531 r
.25867 .54834 m .26043 .55023 L .26091 .54758 L F
.25867 .54834 m .25865 .55109 L .26043 .55023 L F
.717 .709 .841 r
.46055 .53749 m .45686 .53566 L .45912 .53416 L F
.582 .454 .671 r
.46402 .53522 m .46055 .53749 L .45912 .53416 L F
.46402 .53522 m .46225 .53673 L .46055 .53749 L F
.824 .886 .888 r
.61781 .39112 m .61626 .39566 L .61581 .39421 L F
.61781 .39112 m .61985 .39284 L .61626 .39566 L F
0 0 .332 r
.61626 .39566 m .61711 .39759 L .61581 .39421 L F
.61626 .39566 m .61711 .39759 L .61581 .39421 L F
.345 0 0 r
.64385 .38023 m .64663 .38014 L .64764 .37856 L F
.573 .881 .992 r
.64764 .37856 m .64928 .37668 L .65051 .37762 L F
0 0 0 r
.64764 .37856 m .64663 .38014 L .64928 .37668 L F
.887 .589 .079 r
.58518 .39621 m .58534 .39786 L .5848 .39546 L F
.632 .876 .987 r
.63154 .38383 m .62758 .3838 L .63042 .3832 L F
.388 .825 .953 r
.63368 .38327 m .63154 .38383 L .63042 .3832 L F
.578 .137 .166 r
.65022 .3442 m .64583 .34569 L .64716 .34485 L F
.921 .696 .579 r
.33934 .56031 m .34192 .55849 L .34046 .5578 L F
.33934 .56031 m .34161 .56144 L .34192 .55849 L F
.073 0 0 r
.4143 .45719 m .41686 .45643 L .4184 .45483 L F
.181 0 0 r
.41686 .45643 m .42104 .45398 L .4184 .45483 L F
0 .291 .776 r
.39443 .47206 m .39603 .47209 L .39297 .47161 L F
.39443 .47206 m .39705 .4736 L .39603 .47209 L F
.742 .339 .287 r
.39443 .47206 m .39817 .47444 L .39705 .4736 L F
.595 .454 .659 r
.26307 .5353 m .26317 .53807 L .26569 .53466 L F
.875 .793 .765 r
.30143 .61278 m .301 .6148 L .29868 .61445 L F
.726 .641 .764 r
.30396 .61162 m .301 .6148 L .30143 .61278 L F
.337 0 0 r
.30758 .59838 m .30947 .59824 L .30587 .5994 L F
.921 .773 .68 r
.30587 .5994 m .30947 .59824 L .30697 .6018 L F
.704 .718 .86 r
.30758 .59838 m .31246 .59734 L .30947 .59824 L F
.657 .524 .69 r
.30947 .59824 m .30898 .60463 L .30697 .6018 L F
.30947 .59824 m .31206 .60205 L .30898 .60463 L F
.681 .6 .758 r
.3145 .5979 m .30947 .59824 L .31246 .59734 L F
.3145 .5979 m .31427 .59852 L .30947 .59824 L F
.687 .532 .67 r
.30947 .59824 m .31427 .59852 L .31206 .60205 L F
.763 .611 .69 r
.46738 .52148 m .46912 .52575 L .46401 .52465 L F
.958 .926 .727 r
.33062 .57525 m .33126 .57044 L .33345 .57165 L F
.33062 .57525 m .32906 .57519 L .33126 .57044 L F
.767 .989 .893 r
.33062 .57525 m .32722 .57622 L .32906 .57519 L F
.449 .169 .395 r
.25286 .58485 m .25179 .58732 L .24986 .5876 L F
.195 0 .278 r
.25533 .58299 m .25179 .58732 L .25286 .58485 L F
.596 .196 .255 r
.6084 .38866 m .60435 .39094 L .60717 .39014 L F
.6084 .38866 m .60432 .38897 L .60435 .39094 L F
.154 0 .249 r
.27458 .64124 m .27154 .64626 L .27327 .64511 L F
0 0 0 r
.27632 .63967 m .27814 .63771 L .27458 .64124 L F
.805 .759 .811 r
.27327 .64511 m .27632 .63967 L .27458 .64124 L F
0 0 0 r
.35099 .63025 m .35185 .62857 L .35319 .62644 L F
.779 .725 .802 r
.65616 .388 m .66006 .38866 L .65915 .38477 L F
.981 .796 .582 r
.65797 .3901 m .66006 .38866 L .65616 .388 L F
.65797 .3901 m .65958 .39112 L .66006 .38866 L F
.006 0 0 r
.41645 .5881 m .41296 .59028 L .4122 .5877 L F
.41645 .5881 m .41468 .58989 L .41296 .59028 L F
.63 .158 .115 r
.41789 .58974 m .41645 .5881 L .42007 .58814 L F
.41789 .58974 m .41468 .58989 L .41645 .5881 L F
.624 .726 .92 r
.52847 .41014 m .52736 .41369 L .52554 .41364 L F
.52847 .41014 m .52993 .41278 L .52736 .41369 L F
.58 .926 .955 r
.46894 .54478 m .46404 .54584 L .46668 .54627 L F
.859 .719 .706 r
.54453 .40114 m .54597 .40575 L .54246 .40447 L F
.853 .464 .307 r
.54246 .40447 m .54597 .40575 L .54555 .40761 L F
.578 .178 .249 r
.54597 .40575 m .54917 .40675 L .54555 .40761 L F
.991 .742 .38 r
.39521 .54477 m .39673 .54805 L .39679 .54507 L F
.39521 .54477 m .39452 .54644 L .39673 .54805 L F
.932 .962 .764 r
.39452 .54644 m .39402 .55125 L .39673 .54805 L F
.705 .513 .626 r
.39402 .55125 m .39805 .55012 L .39673 .54805 L F
.704 .624 .765 r
.39673 .54805 m .40174 .5463 L .39679 .54507 L F
.39673 .54805 m .40101 .54808 L .40174 .5463 L F
.659 .434 .567 r
.39805 .55012 m .40101 .54808 L .39673 .54805 L F
.39805 .55012 m .40053 .55197 L .40101 .54808 L F
0 0 .161 r
.40101 .54808 m .40208 .54855 L .40302 .54832 L F
.40101 .54808 m .40053 .55197 L .40208 .54855 L F
.468 0 0 r
.39829 .58749 m .39696 .58679 L .39424 .58485 L F
.86 .733 .722 r
.39829 .58749 m .39608 .59132 L .39355 .59005 L F
.9 .977 .806 r
.57539 .3895 m .57513 .39261 L .57771 .38925 L F
.972 .898 .69 r
.57628 .38727 m .57771 .38925 L .57983 .38792 L F
.57628 .38727 m .57539 .3895 L .57771 .38925 L F
.512 0 0 r
.28468 .52531 m .28691 .52712 L .28851 .52807 L F
.885 .938 .568 r
.28678 .52984 m .28851 .52807 L .28691 .52712 L F
.28678 .52984 m .28666 .53183 L .28851 .52807 L F
.866 .864 .835 r
.5917 .39142 m .59466 .39137 L .59368 .38868 L F
.879 .841 .804 r
.5919 .39516 m .59466 .39137 L .5917 .39142 L F
.88 .869 .823 r
.59368 .38868 m .59466 .39137 L .59676 .3883 L F
1 .807 .495 r
.32133 .52843 m .32019 .52404 L .3208 .52412 L F
.7 .605 .747 r
.53989 .34685 m .54099 .35104 L .54301 .34818 L F
0 0 .56 r
.24982 .57437 m .25155 .57824 L .25142 .57643 L F
0 0 .154 r
.25035 .58049 m .25142 .57643 L .25155 .57824 L F
.321 .463 .847 r
.25503 .58129 m .25155 .57824 L .25577 .5784 L F
.371 0 0 r
.40314 .53384 m .40742 .53169 L .40219 .53158 L F
.40314 .53384 m .40562 .53408 L .40742 .53169 L F
.014 0 0 r
.40742 .53169 m .40852 .53268 L .409 .5324 L F
.40742 .53169 m .40562 .53408 L .40852 .53268 L F
.827 .948 .9 r
.30843 .59674 m .30587 .5994 L .30373 .59852 L F
0 0 0 r
.30715 .59752 m .30843 .59674 L .30631 .5979 L F
.687 .936 .64 r
.30955 .59606 m .30758 .59838 L .30843 .59674 L F
.688 .956 .704 r
.30843 .59674 m .30758 .59838 L .30587 .5994 L F
.704 .669 .814 r
.30995 .5956 m .31246 .59734 L .30758 .59838 L F
.581 .669 .899 r
.31304 .59487 m .31246 .59734 L .31102 .59634 L F
.31304 .59487 m .31102 .59634 L .30995 .5956 L F
.524 .906 .747 r
.3142 .59403 m .31304 .59487 L .31084 .59585 L F
.31531 .59343 m .31304 .59487 L .3142 .59403 L F
0 0 0 r
.31084 .59585 m .30843 .59674 L .30715 .59752 L F
.687 .936 .64 r
.30995 .5956 m .30955 .59606 L .30843 .59674 L F
.974 .709 .464 r
.52012 .37926 m .51808 .37992 L .51821 .37746 L F
.6 .451 .65 r
.52019 .37634 m .51808 .37992 L .52012 .37926 L F
.704 .981 .805 r
.62348 .38646 m .62551 .38578 L .62195 .3888 L F
0 0 .394 r
.62348 .38646 m .62195 .3888 L .62228 .39141 L F
.664 .932 .648 r
.39779 .54351 m .39679 .54507 L .3991 .54264 L F
.628 .944 .951 r
.39779 .54351 m .39521 .54477 L .39679 .54507 L F
.683 .569 .72 r
.39679 .54507 m .40174 .5463 L .3991 .54264 L F
.686 .686 .844 r
.58496 .34738 m .58635 .34934 L .58205 .34858 L F
.736 .701 .818 r
.58931 .34706 m .58635 .34934 L .58496 .34738 L F
.237 .593 .949 r
.46825 .5197 m .46903 .52226 L .46738 .52148 L F
.875 .987 .826 r
.47242 .51707 m .46903 .52226 L .46825 .5197 L F
.667 .612 .784 r
.59601 .35077 m .59722 .35307 L .59977 .35206 L F
.59977 .35206 m .59661 .35656 L .59601 .35077 L F
.816 .703 .74 r
.311 .65694 m .3139 .65805 L .31294 .65399 L F
.832 .441 .308 r
.31154 .66088 m .3139 .65805 L .311 .65694 L F
.324 .376 .762 r
.31294 .65399 m .3139 .65805 L .31589 .65716 L F
0 0 0 r
.31589 .65716 m .3139 .65805 L .31154 .66088 L F
.734 .404 0 r
.27447 .66797 m .27474 .66941 L .27431 .66672 L F
.27447 .66797 m .27516 .67005 L .27474 .66941 L F
.753 .683 .784 r
.65889 .39855 m .65762 .39465 L .6578 .39718 L F
.65889 .39855 m .65898 .39743 L .65762 .39465 L F
0 0 0 r
.51166 .44115 m .51 .44535 L .51052 .44435 L F
.337 .278 .643 r
.40547 .55766 m .40803 .55704 L .40762 .55365 L F
.494 .285 .525 r
.40519 .56033 m .40803 .55704 L .40547 .55766 L F
.545 .144 .233 r
.60451 .35209 m .60285 .35127 L .60437 .34956 L F
.60451 .35209 m .60352 .35344 L .60285 .35127 L F
.60451 .35209 m .60642 .3537 L .60352 .35344 L F
.813 .892 .9 r
.57026 .39383 m .57513 .39261 L .57351 .39133 L F
.831 .94 .897 r
.57351 .39133 m .57513 .39261 L .57539 .3895 L F
.815 .807 .843 r
.43541 .5851 m .43296 .58739 L .43706 .58797 L F
.865 .866 .837 r
.43197 .5901 m .43706 .58797 L .43296 .58739 L F
.43197 .5901 m .43401 .59106 L .43706 .58797 L F
.632 .732 .92 r
.43541 .5851 m .43706 .58797 L .43962 .58675 L F
.899 .809 .75 r
.39916 .52014 m .39758 .5239 L .40056 .5246 L F
.828 .352 .034 r
.39978 .5262 m .40056 .5246 L .39758 .5239 L F
.39978 .5262 m .40203 .52727 L .40056 .5246 L F
.52 .038 .053 r
.6582 .33352 m .66094 .3339 L .65817 .3325 L F
0 0 0 r
.4463 .54974 m .44788 .54947 L .44611 .54958 L F
.967 .667 .263 r
.58617 .40236 m .58498 .40312 L .58551 .40049 L F
.58617 .40236 m .58647 .40493 L .58498 .40312 L F
.571 .322 .499 r
.26833 .53413 m .27166 .53129 L .2688 .53185 L F
.659 .673 .852 r
.29473 .65128 m .29867 .65329 L .29714 .65026 L F
.672 .679 .848 r
.29714 .65026 m .29867 .65329 L .30135 .65135 L F
0 0 .336 r
.31367 .51003 m .31472 .51219 L .31427 .51131 L F
0 0 0 r
.56909 .36035 m .56876 .36384 L .56846 .36559 L F
0 .095 .625 r
.56966 .36612 m .56846 .36559 L .56876 .36384 L F
.56966 .36612 m .57087 .36785 L .56846 .36559 L F
.562 .836 .996 r
.29059 .55158 m .28697 .55156 L .28926 .55031 L F
.369 0 .045 r
.29059 .55158 m .28621 .55401 L .28697 .55156 L F
.29059 .55158 m .2893 .55369 L .28621 .55401 L F
.994 .755 .456 r
.28926 .55031 m .2893 .55369 L .29059 .55158 L F
.898 .92 .827 r
.47079 .53766 m .46876 .5407 L .47118 .5405 L F
.957 .944 .712 r
.46862 .5423 m .47118 .5405 L .46876 .5407 L F
.46862 .5423 m .46894 .54478 L .47118 .5405 L F
.81 .875 .894 r
.47079 .53766 m .47118 .5405 L .47409 .5379 L F
.816 .909 .903 r
.53778 .45957 m .53321 .46088 L .53592 .45801 L F
.842 .894 .875 r
.53939 .45782 m .53778 .45957 L .53592 .45801 L F
.801 .46 .411 r
.26626 .56809 m .26249 .56525 L .26475 .56407 L F
.26626 .56809 m .26225 .5675 L .26249 .56525 L F
.268 .536 .918 r
.38098 .58494 m .38356 .58566 L .3818 .5831 L F
.9 .985 .732 r
.48782 .42496 m .4902 .42174 L .48833 .42185 L F
.757 .991 .882 r
.49115 .41912 m .4902 .42174 L .49245 .41849 L F
.781 .997 .805 r
.48833 .42185 m .4902 .42174 L .49115 .41912 L F
.041 .164 .667 r
.59588 .37772 m .59532 .37881 L .59451 .37527 L F
.965 .642 .269 r
.53284 .4418 m .53328 .44459 L .53142 .4429 L F
.904 .634 .13 r
.53161 .43699 m .53284 .4418 L .5317 .43993 L F
.977 .826 .42 r
.5317 .43993 m .53284 .4418 L .53142 .4429 L F
.666 .642 .816 r
.53585 .43892 m .53588 .44173 L .53284 .4418 L F
.483 .192 .395 r
.53588 .44173 m .53328 .44459 L .53284 .4418 L F
.723 .904 .959 r
.46738 .52148 m .46485 .52176 L .46603 .52043 L F
.763 .611 .69 r
.46738 .52148 m .46401 .52465 L .46485 .52176 L F
.237 .593 .949 r
.46825 .5197 m .46738 .52148 L .46603 .52043 L F
.826 .799 .826 r
.3192 .62979 m .32174 .6311 L .31766 .63117 L F
.839 .752 .767 r
.32174 .6311 m .31899 .63465 L .31766 .63117 L F
.593 .675 .898 r
.32244 .62707 m .32174 .6311 L .3192 .62979 L F
.32244 .62707 m .32429 .6305 L .32174 .6311 L F
.618 .64 .85 r
.32577 .63225 m .32174 .6311 L .32429 .6305 L F
.815 .989 .729 r
.45132 .54155 m .45188 .5394 L .45389 .53832 L F
.945 .582 .248 r
.45132 .54155 m .45007 .54333 L .45188 .5394 L F
.45132 .54155 m .45213 .5447 L .45007 .54333 L F
.866 .62 .564 r
.49879 .41416 m .50253 .41193 L .50141 .41095 L F
.49879 .41416 m .50276 .41551 L .50253 .41193 L F
.344 .291 .654 r
.50253 .41193 m .50462 .4115 L .50141 .41095 L F
.50253 .41193 m .50534 .41397 L .50462 .4115 L F
.792 .652 .708 r
.43817 .55314 m .44176 .55716 L .43563 .55688 L F
.777 .729 .808 r
.44176 .55716 m .43825 .55895 L .43563 .55688 L F
.712 .646 .782 r
.44093 .55527 m .44176 .55716 L .43817 .55314 L F
.117 .292 .765 r
.44093 .55527 m .44325 .55758 L .44176 .55716 L F
.806 .477 .431 r
.31274 .68446 m .31523 .68508 L .31502 .68833 L F
.971 .845 .659 r
.2492 .58814 m .24813 .58709 L .24986 .5876 L F
.2492 .58814 m .24629 .59092 L .24813 .58709 L F
0 0 0 r
.2492 .58814 m .24778 .59429 L .24629 .59092 L F
.2492 .58814 m .24846 .59323 L .24778 .59429 L F
.465 .248 .499 r
.25179 .58732 m .2492 .58814 L .24986 .5876 L F
.25179 .58732 m .25014 .59001 L .2492 .58814 L F
0 0 .153 r
.24993 .59098 m .2492 .58814 L .25014 .59001 L F
.24993 .59098 m .24846 .59323 L .2492 .58814 L F
.559 .562 .814 r
.32989 .56377 m .32859 .56792 L .32763 .56752 L F
.32989 .56377 m .33169 .56762 L .32859 .56792 L F
.669 .465 .599 r
.33169 .56762 m .32915 .57038 L .32859 .56792 L F
.886 .716 .666 r
.40057 .55449 m .40272 .55543 L .40053 .55197 L F
.796 .986 .893 r
.39967 .55611 m .40272 .55543 L .40057 .55449 L F
.718 .68 .813 r
.40053 .55197 m .40272 .55543 L .40608 .55383 L F
.88 .66 .6 r
.58341 .3716 m .58337 .37577 L .58012 .37317 L F
0 0 .022 r
.58728 .36787 m .58603 .37031 L .58341 .3716 L F
0 0 .293 r
.58469 .37187 m .58341 .3716 L .58603 .37031 L F
.58469 .37187 m .58337 .37577 L .58341 .3716 L F
.694 .949 .956 r
.61347 .35096 m .60792 .35224 L .61071 .35214 L F
.817 .89 .896 r
.51655 .49366 m .52004 .4918 L .51845 .49045 L F
.892 .885 .819 r
.51845 .49045 m .52004 .4918 L .52255 .4883 L F
.528 .916 .796 r
.46028 .4412 m .46172 .43988 L .45968 .44144 L F
.881 .881 .829 r
.45053 .55766 m .45344 .55432 L .45204 .55326 L F
.846 .901 .875 r
.45665 .55128 m .45204 .55326 L .45344 .55432 L F
.095 .409 .86 r
.58286 .38176 m .58375 .38013 L .58195 .37968 L F
.035 .328 .811 r
.58286 .38176 m .5857 .38359 L .58375 .38013 L F
.599 .779 .966 r
.3214 .54533 m .31624 .54454 L .31809 .54489 L F
.778 .601 .66 r
.31809 .54489 m .3204 .54708 L .3214 .54533 L F
.779 .779 .852 r
.31562 .60743 m .32008 .60774 L .31843 .60451 L F
.593 .621 .849 r
.32008 .60774 m .32093 .60337 L .31843 .60451 L F
.32008 .60774 m .3226 .60713 L .32093 .60337 L F
.64 .638 .833 r
.32008 .60774 m .32426 .60872 L .3226 .60713 L F
0 .104 .622 r
.58583 .36204 m .58777 .36378 L .5867 .36502 L F
.56 .926 .937 r
.4118 .55128 m .41034 .55104 L .41274 .54988 L F
0 0 0 r
.41034 .55104 m .41101 .55133 L .41161 .55082 L F
.41034 .55104 m .41161 .55082 L .41274 .54988 L F
.087 .641 .809 r
.40964 .55116 m .41034 .55104 L .4118 .55128 L F
.4076 .55105 m .41034 .55104 L .40964 .55116 L F
.56 .926 .937 r
.4118 .55128 m .41274 .54988 L .41433 .55121 L F
.111 0 0 r
.45906 .55002 m .45549 .54974 L .45665 .55128 L F
.846 .901 .875 r
.45665 .55128 m .45549 .54974 L .45204 .55326 L F
0 0 0 r
.46928 .42394 m .46737 .42528 L .46574 .4266 L F
.871 .618 .554 r
.33364 .56453 m .32989 .56377 L .33004 .56102 L F
.869 .696 .665 r
.33364 .56453 m .33169 .56762 L .32989 .56377 L F
.58 .844 .493 r
.49707 .40238 m .49853 .40036 L .4994 .40109 L F
.49707 .40238 m .49726 .40196 L .49853 .40036 L F
.49707 .40238 m .49578 .40378 L .49726 .40196 L F
.892 .885 .819 r
.51845 .49045 m .52255 .4883 L .52144 .48752 L F
.81 .938 .913 r
.52255 .4883 m .52452 .48438 L .52144 .48752 L F
.52255 .4883 m .52575 .48554 L .52452 .48438 L F
.756 .72 .819 r
.3226 .60713 m .32655 .60771 L .32504 .60392 L F
.766 .7 .789 r
.32426 .60872 m .32655 .60771 L .3226 .60713 L F
.767 .726 .814 r
.32504 .60392 m .32655 .60771 L .32931 .60434 L F
.883 .577 .464 r
.32358 .57754 m .31974 .57671 L .32075 .57429 L F
.573 0 0 r
.32358 .57754 m .32205 .57771 L .31974 .57671 L F
0 0 .262 r
.32497 .57364 m .3247 .57729 L .32358 .57754 L F
.489 .151 .32 r
.3247 .57729 m .32205 .57771 L .32358 .57754 L F
.078 .553 .901 r
.50656 .44917 m .50314 .44768 L .50632 .44927 L F
.487 0 0 r
.50891 .45095 m .50656 .44917 L .50632 .44927 L F
.383 .265 .593 r
.28631 .52366 m .28691 .52712 L .28468 .52531 L F
.78 .782 .854 r
.29168 .63857 m .28861 .642 L .28737 .63841 L F
.343 .166 .491 r
.25728 .58002 m .25577 .5784 L .25745 .57761 L F
.25728 .58002 m .25503 .58129 L .25577 .5784 L F
.933 .555 .198 r
.35303 .63391 m .35272 .63167 L .35099 .63025 L F
.196 .592 .944 r
.65811 .36673 m .66011 .36574 L .65626 .36466 L F
.65811 .36673 m .6614 .36715 L .66011 .36574 L F
.726 .715 .84 r
.54914 .34429 m .54987 .34728 L .55336 .34498 L F
.012 .569 .816 r
.62068 .39834 m .62062 .3982 L .61711 .39759 L F
.453 .878 .779 r
.62276 .39692 m .62068 .39834 L .62302 .39723 L F
.62276 .39692 m .62062 .3982 L .62068 .39834 L F
.934 .596 .369 r
.59023 .39646 m .5919 .39516 L .59016 .39387 L F
.59023 .39646 m .59224 .39773 L .5919 .39516 L F
.879 .841 .804 r
.5919 .39516 m .5917 .39142 L .59016 .39387 L F
.882 .946 .849 r
.50333 .50281 m .50581 .50267 L .5072 .50091 L F
.88 .857 .814 r
.29745 .66435 m .29538 .66826 L .29266 .66782 L F
.748 .967 .688 r
.57385 .35 m .57254 .35204 L .57366 .34976 L F
0 0 .26 r
.57224 .35462 m .57366 .34976 L .57254 .35204 L F
.237 0 0 r
.60511 .34496 m .60784 .34557 L .60923 .34532 L F
0 .528 .708 r
.60784 .34557 m .61176 .34592 L .60923 .34532 L F
.387 0 0 r
.61176 .34592 m .6121 .34549 L .60923 .34532 L F
.817 .605 .615 r
.38942 .51686 m .39441 .51593 L .38993 .51549 L F
.38942 .51686 m .39377 .51909 L .39441 .51593 L F
.699 .777 .912 r
.33778 .62775 m .33565 .62927 L .33353 .62721 L F
.712 .49 .585 r
.54459 .39859 m .54044 .40108 L .54022 .39801 L F
.54459 .39859 m .54453 .40114 L .54044 .40108 L F
.793 .702 .764 r
.54744 .3979 m .54453 .40114 L .54459 .39859 L F
.509 .468 .747 r
.25783 .54482 m .26091 .54758 L .26035 .54423 L F
.2 0 0 r
.64752 .33721 m .65148 .33572 L .64864 .3362 L F
.88 .869 .823 r
.59368 .38868 m .59676 .3883 L .59644 .38723 L F
.088 .14 .622 r
.2809 .54063 m .28311 .54335 L .28158 .54499 L F
0 0 .178 r
.28199 .5453 m .28158 .54499 L .28311 .54335 L F
.28199 .5453 m .28175 .54732 L .28158 .54499 L F
.977 .681 .381 r
.37672 .58434 m .37442 .58011 L .37685 .58147 L F
.096 0 0 r
.42749 .45101 m .42979 .45014 L .43064 .44814 L F
0 0 0 r
.42979 .45014 m .43304 .44712 L .43064 .44814 L F
.581 .588 .825 r
.52148 .40426 m .52332 .40061 L .52083 .40241 L F
.52148 .40426 m .52381 .40353 L .52332 .40061 L F
.467 .77 .996 r
.28037 .67178 m .2827 .67453 L .28564 .67403 L F
.329 0 0 r
.2827 .67453 m .28652 .67499 L .28564 .67403 L F
.587 .755 .958 r
.50128 .43006 m .49953 .43276 L .49852 .43083 L F
.031 0 .322 r
.26643 .56219 m .26505 .56148 L .26715 .56047 L F
.26643 .56219 m .26475 .56407 L .26505 .56148 L F
.533 .107 .178 r
.31822 .51026 m .32072 .5104 L .32266 .50818 L F
.647 .241 .261 r
.32266 .50818 m .32072 .5104 L .32504 .51038 L F
.611 .257 .346 r
.32266 .50818 m .32504 .51038 L .3254 .50839 L F
.549 .785 .986 r
.65677 .34977 m .65845 .35176 L .65564 .35199 L F
0 .154 .624 r
.65564 .35199 m .65529 .35147 L .65677 .34977 L F
.577 .282 .431 r
.65845 .35176 m .65843 .35406 L .65564 .35199 L F
0 .154 .624 r
.65564 .35199 m .65843 .35406 L .65529 .35147 L F
.513 .71 .96 r
.42194 .59852 m .42515 .59838 L .42029 .59664 L F
.13 .254 .725 r
.28303 .67722 m .28436 .68106 L .28554 .68127 L F
0 .207 .64 r
.28436 .68106 m .28867 .68388 L .28657 .68292 L F
.135 .243 .712 r
.28554 .68127 m .28436 .68106 L .28657 .68292 L F
.689 .27 0 r
.39379 .57444 m .39458 .57544 L .39149 .57445 L F
.39379 .57444 m .39561 .57736 L .39458 .57544 L F
.787 .942 .594 r
.57472 .39993 m .57222 .40372 L .57376 .40233 L F
.949 .793 .34 r
.54917 .40675 m .54942 .40863 L .54911 .4103 L F
.502 .601 .884 r
.54917 .40675 m .54942 .40863 L .54972 .40665 L F
.54917 .40675 m .54942 .40863 L .54972 .40665 L F
.986 .767 .524 r
.3633 .53014 m .36288 .52738 L .36542 .52834 L F
.625 .229 .273 r
.50146 .45416 m .50024 .45672 L .50068 .45513 L F
.429 .045 .207 r
.5042 .45374 m .50024 .45672 L .50146 .45416 L F
.186 0 .138 r
.34884 .50432 m .35096 .50357 L .35198 .50083 L F
.313 0 .225 r
.35096 .50357 m .35413 .50088 L .35198 .50083 L F
.123 0 0 r
.56546 .38625 m .5624 .38652 L .56248 .38456 L F
.56546 .38625 m .56515 .38647 L .5624 .38652 L F
.844 .737 .745 r
.33531 .59025 m .33755 .59171 L .33594 .58771 L F
.744 .509 .574 r
.33296 .59371 m .33755 .59171 L .33531 .59025 L F
.33296 .59371 m .3374 .59431 L .33755 .59171 L F
.779 .71 .787 r
.33594 .58771 m .33755 .59171 L .34016 .58829 L F
.625 .101 0 r
.40222 .54392 m .39779 .54351 L .3991 .54264 L F
.581 .669 .899 r
.31304 .59487 m .3145 .5979 L .31246 .59734 L F
.972 .741 .53 r
.42433 .58086 m .42586 .58473 L .42768 .58413 L F
.42433 .58086 m .42403 .584 L .42586 .58473 L F
.603 .077 0 r
.42588 .5855 m .42586 .58473 L .42403 .584 L F
.42588 .5855 m .42681 .58571 L .42586 .58473 L F
.136 0 .387 r
.42593 .58275 m .42588 .5855 L .42403 .584 L F
.972 .741 .53 r
.42433 .58086 m .42768 .58413 L .42719 .58052 L F
.49 .249 .475 r
.42768 .58413 m .4324 .58267 L .42719 .58052 L F
0 0 .089 r
.42908 .58238 m .42588 .5855 L .42593 .58275 L F
.599 .548 .768 r
.42719 .58052 m .4324 .58267 L .4297 .57864 L F
.825 .748 .779 r
.42929 .58196 m .42908 .58238 L .43051 .58076 L F
.42908 .58238 m .42895 .58281 L .43051 .58076 L F
.512 .255 .462 r
.43051 .58076 m .4293 .58235 L .42918 .58206 L F
.016 0 0 r
.4297 .57864 m .42529 .57915 L .42719 .58052 L F
.512 .255 .462 r
.43051 .58076 m .42918 .58206 L .42797 .57899 L F
.825 .748 .779 r
.42973 .58107 m .42929 .58196 L .43051 .58076 L F
.159 .661 .909 r
.43338 .58505 m .43196 .58433 L .43127 .58471 L F
0 0 0 r
.43196 .58433 m .43189 .58544 L .43239 .58409 L F
.958 .895 .722 r
.43366 .58509 m .43196 .58433 L .4338 .58027 L F
0 0 0 r
.43196 .58433 m .43239 .58409 L .4338 .58027 L F
.159 .661 .909 r
.43127 .58471 m .43196 .58433 L .42768 .58413 L F
.43366 .58509 m .43322 .58489 L .43338 .58505 L F
.43322 .58489 m .43196 .58433 L .43338 .58505 L F
.086 0 .293 r
.4324 .58267 m .43196 .58433 L .4338 .58027 L F
.952 .884 .484 r
.4338 .58027 m .43239 .58409 L .43249 .58201 L F
.43239 .58409 m .43189 .58544 L .43217 .58387 L F
.43239 .58409 m .43217 .58387 L .43249 .58201 L F
.49 .249 .475 r
.42768 .58413 m .43196 .58433 L .4324 .58267 L F
0 0 .089 r
.42893 .58269 m .42777 .58436 L .42588 .5855 L F
.825 .748 .779 r
.42903 .58255 m .42873 .5831 L .42895 .58281 L F
.42893 .58269 m .42873 .5831 L .42903 .58255 L F
0 0 .089 r
.42893 .58269 m .42588 .5855 L .42908 .58238 L F
.825 .748 .779 r
.42569 .58268 m .42777 .58436 L .42873 .5831 L F
0 0 0 r
.43051 .58076 m .42777 .58436 L .4293 .58235 L F
0 0 .089 r
.4293 .58235 m .42777 .58436 L .42893 .58269 L F
.825 .748 .779 r
.42908 .58238 m .42893 .58269 L .42903 .58255 L F
.208 .105 .51 r
.42797 .57899 m .42905 .58172 L .42593 .58275 L F
.523 .845 .998 r
.42719 .58052 m .42529 .57915 L .42433 .58086 L F
.162 .023 .432 r
.42593 .58275 m .42433 .58086 L .42529 .57915 L F
.42593 .58275 m .42403 .584 L .42433 .58086 L F
.208 .105 .51 r
.42797 .57899 m .42593 .58275 L .42529 .57915 L F
.825 .748 .779 r
.42569 .58268 m .42946 .58118 L .42906 .57986 L F
.42946 .58118 m .43051 .58076 L .43001 .58045 L F
.42946 .58118 m .43001 .58045 L .42906 .57986 L F
.208 .105 .51 r
.42905 .58172 m .42918 .58206 L .42872 .58216 L F
.42905 .58172 m .42872 .58216 L .42593 .58275 L F
.42918 .58206 m .4293 .58235 L .42908 .58238 L F
.42918 .58206 m .42908 .58238 L .42593 .58275 L F
0 0 .089 r
.4293 .58235 m .42893 .58269 L .42908 .58238 L F
.825 .748 .779 r
.42569 .58268 m .42873 .5831 L .42973 .58107 L F
.437 .871 .787 r
.42777 .58436 m .42554 .58542 L .42588 .5855 L F
.42554 .58542 m .42518 .58559 L .42588 .5855 L F
.603 .077 0 r
.42588 .5855 m .42835 .58732 L .42681 .58571 L F
.248 0 0 r
.28036 .63755 m .27814 .63771 L .27632 .63967 L F
.487 .589 .881 r
.28269 .6373 m .282 .64096 L .28036 .63755 L F
.28269 .6373 m .2843 .6413 L .282 .64096 L F
.96 .632 .246 r
.37529 .5782 m .37312 .57398 L .3756 .57489 L F
.37529 .5782 m .37379 .57774 L .37312 .57398 L F
.993 .755 .397 r
.37529 .5782 m .37442 .58011 L .37379 .57774 L F
.799 .476 .442 r
.66958 .33434 m .67154 .33734 L .6734 .33522 L F
.802 .479 .444 r
.6734 .33522 m .67154 .33734 L .67575 .33788 L F
.994 .752 .4 r
.56711 .41851 m .56888 .41839 L .56799 .41684 L F
.56711 .41851 m .56897 .41919 L .56888 .41839 L F
.949 .608 .335 r
.56983 .42044 m .56888 .41839 L .56897 .41919 L F
.875 .793 .765 r
.30143 .61278 m .29868 .61445 L .29788 .61164 L F
.55 .051 .024 r
.30967 .65421 m .30808 .65507 L .30544 .65424 L F
.896 .988 .769 r
.30962 .65211 m .30808 .65507 L .30967 .65421 L F
0 .345 .77 r
.30808 .65507 m .311 .65694 L .30967 .65421 L F
.816 .703 .74 r
.311 .65694 m .31294 .65399 L .30967 .65421 L F
.582 .645 .878 r
.32561 .60151 m .32619 .5968 L .32253 .60019 L F
.32561 .60151 m .32786 .60054 L .32619 .5968 L F
.785 .672 .739 r
.32504 .60392 m .32786 .60054 L .32561 .60151 L F
.808 .698 .743 r
.28564 .67403 m .28992 .67463 L .28689 .67632 L F
.417 .185 .451 r
.28992 .67463 m .29072 .67567 L .28936 .67745 L F
.685 .43 .531 r
.28689 .67632 m .28992 .67463 L .28936 .67745 L F
.766 .494 .521 r
.66522 .33382 m .66914 .33193 L .66492 .33196 L F
.66522 .33382 m .66958 .33434 L .66914 .33193 L F
.639 .924 .975 r
.58205 .34858 m .58337 .3464 L .58496 .34738 L F
.619 .902 .986 r
.58205 .34858 m .58077 .3476 L .58337 .3464 L F
.914 .792 .712 r
.55623 .44056 m .56002 .43829 L .55856 .43652 L F
.55623 .44056 m .55815 .44218 L .56002 .43829 L F
.903 .836 .77 r
.55856 .43652 m .56002 .43829 L .56091 .43567 L F
.703 .688 .832 r
.32429 .6305 m .32836 .63114 L .32577 .63225 L F
.253 .199 .601 r
.52157 .39656 m .51889 .39899 L .51917 .39464 L F
.496 0 0 r
.52332 .40061 m .51889 .39899 L .52157 .39656 L F
.52332 .40061 m .51865 .39994 L .51889 .39899 L F
.559 .406 .63 r
.26317 .53807 m .26582 .53754 L .26569 .53466 L F
.533 .346 .573 r
.26317 .53807 m .26574 .54036 L .26582 .53754 L F
.26317 .53807 m .26312 .54089 L .26574 .54036 L F
.557 .169 .262 r
.3746 .47189 m .37932 .47078 L .37961 .46895 L F
.829 .627 .63 r
.37932 .47078 m .38204 .46803 L .37961 .46895 L F
.808 .948 .913 r
.45686 .53566 m .45389 .53832 L .45425 .53557 L F
.04 .413 .861 r
.28255 .66085 m .28653 .66311 L .2839 .66451 L F
.844 .931 .886 r
.53112 .4814 m .53414 .4805 L .53309 .47928 L F
.793 .992 .879 r
.53674 .47718 m .53309 .47928 L .53414 .4805 L F
.699 .549 .68 r
.29007 .51827 m .29 .52181 L .28756 .52135 L F
.421 .636 .944 r
.29111 .51609 m .29155 .518 L .29007 .51827 L F
.431 .327 .636 r
.29297 .52079 m .29007 .51827 L .29155 .518 L F
.29297 .52079 m .29 .52181 L .29007 .51827 L F
.966 .937 .685 r
.56649 .42392 m .56897 .41919 L .56711 .41851 L F
.903 .867 .793 r
.56649 .42392 m .56983 .42044 L .56897 .41919 L F
.347 .82 .895 r
.63044 .39543 m .62941 .39516 L .62652 .39585 L F
.418 .856 .926 r
.6331 .39472 m .62941 .39516 L .63044 .39543 L F
.327 .049 .33 r
.27426 .53044 m .27643 .52702 L .27474 .52779 L F
.658 .813 .958 r
.60581 .39294 m .60717 .39014 L .60435 .39094 L F
.60581 .39294 m .60857 .39183 L .60717 .39014 L F
.797 .504 .492 r
.37009 .50987 m .37433 .50823 L .37012 .50831 L F
.37009 .50987 m .37417 .51056 L .37433 .50823 L F
.923 .975 .748 r
.45053 .55766 m .44983 .55712 L .44755 .56081 L F
.881 .881 .829 r
.45053 .55766 m .45204 .55326 L .44983 .55712 L F
.87 .549 .44 r
.36288 .52738 m .35932 .52405 L .36185 .52476 L F
.94 .848 .724 r
.37245 .5449 m .3694 .54661 L .37053 .54374 L F
.37245 .5449 m .37127 .54817 L .3694 .54661 L F
0 0 .209 r
.31427 .51131 m .31483 .51307 L .31367 .51003 L F
.31427 .51131 m .31476 .51448 L .31483 .51307 L F
.329 .246 .608 r
.31592 .5878 m .3184 .58971 L .3185 .58615 L F
.709 .236 .125 r
.38614 .51624 m .38694 .51469 L .38509 .51447 L F
.38614 .51624 m .38942 .51686 L .38694 .51469 L F
.694 .268 .23 r
.38694 .51469 m .38942 .51686 L .38993 .51549 L F
0 0 0 r
.44843 .43777 m .44609 .43913 L .44502 .44004 L F
.671 .842 .965 r
.52219 .44376 m .52376 .44545 L .52551 .44395 L F
0 0 0 r
.61176 .34592 m .61603 .34518 L .6121 .34549 L F
.61176 .34592 m .61473 .34547 L .61603 .34518 L F
.134 .635 .907 r
.61763 .34467 m .61603 .34518 L .61473 .34547 L F
.61763 .34467 m .619 .34563 L .61603 .34518 L F
.862 .579 .508 r
.41959 .56128 m .41837 .56391 L .42228 .56454 L F
.798 .38 .254 r
.41837 .56391 m .41988 .56597 L .42228 .56454 L F
0 0 .031 r
.42238 .56637 m .42236 .56716 L .42228 .56454 L F
.42238 .56637 m .42228 .56454 L .41988 .56597 L F
.387 .165 .451 r
.28666 .53183 m .2856 .53534 L .2834 .53594 L F
.493 .492 .784 r
.2856 .53534 m .28633 .53697 L .2834 .53594 L F
0 0 0 r
.3335 .67943 m .33455 .67828 L .33642 .6765 L F
.939 .646 .459 r
.36727 .53471 m .36511 .53641 L .36496 .53379 L F
.36727 .53471 m .36745 .53742 L .36511 .53641 L F
.842 .894 .875 r
.53939 .45782 m .53592 .45801 L .53838 .4566 L F
0 0 .154 r
.25035 .58049 m .25135 .57915 L .25142 .57643 L F
0 0 .343 r
.25004 .58292 m .25135 .57915 L .25035 .58049 L F
.94 .571 .222 r
.67803 .34645 m .67905 .34558 L .67732 .34421 L F
.67803 .34645 m .67949 .34761 L .67905 .34558 L F
.48 .847 .99 r
.40397 .47406 m .40134 .47491 L .40528 .47487 L F
0 0 .318 r
.57682 .36521 m .57785 .36323 L .57397 .36133 L F
.57682 .36521 m .57727 .36467 L .57785 .36323 L F
.882 .946 .849 r
.50333 .50281 m .5072 .50091 L .50584 .49969 L F
.665 .973 .882 r
.51032 .49779 m .50584 .49969 L .5072 .50091 L F
.77 .776 .858 r
.43825 .55895 m .43305 .55938 L .43563 .55688 L F
.427 .577 .9 r
.31696 .59761 m .3145 .5979 L .31304 .59487 L F
0 0 0 r
.62723 .34809 m .623 .34926 L .62466 .34929 L F
.62723 .34809 m .62623 .34871 L .623 .34926 L F
.081 .64 .705 r
.62977 .34831 m .62623 .34871 L .62723 .34809 L F
.262 0 0 r
.29454 .68562 m .29942 .68702 L .29758 .68594 L F
.411 .774 .995 r
.29758 .68594 m .29942 .68702 L .30191 .68651 L F
.429 .544 .871 r
.30587 .5994 m .30465 .60162 L .30308 .6002 L F
.30587 .5994 m .30697 .6018 L .30465 .60162 L F
.747 .981 .913 r
.47091 .43339 m .4754 .43158 L .4721 .43255 L F
.548 .919 .761 r
.4769 .43009 m .4754 .43158 L .47695 .43033 L F
.55 .931 .848 r
.4721 .43255 m .4754 .43158 L .4769 .43009 L F
.85 .996 .825 r
.66412 .38018 m .66753 .37785 L .66711 .37715 L F
.71 .974 .752 r
.66753 .37785 m .66894 .37564 L .66711 .37715 L F
.66753 .37785 m .67077 .37486 L .66894 .37564 L F
.426 0 .062 r
.26626 .56809 m .26171 .57029 L .26225 .5675 L F
.26626 .56809 m .2648 .57013 L .26171 .57029 L F
.479 .789 .999 r
.26684 .5663 m .26626 .56809 L .26475 .56407 L F
.26684 .5663 m .26884 .56761 L .26626 .56809 L F
0 0 0 r
.26659 .56904 m .26626 .56809 L .26884 .56761 L F
.26659 .56904 m .2648 .57013 L .26626 .56809 L F
.483 .192 .395 r
.53588 .44173 m .53654 .44404 L .53328 .44459 L F
.426 .443 .774 r
.5386 .44044 m .53588 .44173 L .53585 .43892 L F
.254 .065 .42 r
.5379 .44263 m .53588 .44173 L .5386 .44044 L F
.5379 .44263 m .53654 .44404 L .53588 .44173 L F
.107 0 0 r
.43764 .45384 m .44155 .4511 L .43996 .45235 L F
0 0 0 r
.44155 .4511 m .44279 .45124 L .43996 .45235 L F
.44155 .4511 m .44406 .45007 L .44279 .45124 L F
.314 .328 .715 r
.25893 .57389 m .25934 .57695 L .25745 .57761 L F
.351 .152 .464 r
.25934 .57695 m .25728 .58002 L .25745 .57761 L F
.109 0 0 r
.25255 .55707 m .25478 .55635 L .25626 .55461 L F
0 0 0 r
.25626 .55461 m .25746 .55354 L .25865 .55109 L F
.458 .208 .447 r
.25478 .55635 m .25746 .55354 L .25626 .55461 L F
.314 0 .025 r
.40391 .46313 m .40237 .46161 L .40117 .46383 L F
.40391 .46313 m .40503 .46115 L .40237 .46161 L F
.795 .842 .38 r
.51625 .40077 m .51504 .40326 L .51464 .40583 L F
.045 .329 .811 r
.51504 .40326 m .51662 .40621 L .51464 .40583 L F
.479 .891 .925 r
.59124 .40589 m .5938 .40488 L .59198 .40463 L F
0 0 .229 r
.35361 .65697 m .35359 .65395 L .35518 .65302 L F
.81 .596 .613 r
.44153 .58518 m .44667 .58142 L .44364 .58002 L F
.44153 .58518 m .44633 .5845 L .44667 .58142 L F
.84 .398 0 r
.23728 .61287 m .23856 .61469 L .23794 .61294 L F
.61 .91 .982 r
.30363 .55967 m .3013 .56076 L .30294 .56146 L F
.30363 .55967 m .3013 .56076 L .30294 .56146 L F
.892 .722 .665 r
.34025 .56718 m .34255 .5681 L .34094 .56421 L F
.935 .77 .654 r
.33961 .5699 m .34255 .5681 L .34025 .56718 L F
.33961 .5699 m .34211 .57119 L .34255 .5681 L F
.354 .204 .534 r
.28325 .53977 m .28311 .54335 L .2809 .54063 L F
.971 .714 .487 r
.32674 .54779 m .32432 .5495 L .32583 .54676 L F
.32674 .54779 m .32679 .55126 L .32432 .5495 L F
.97 .801 .375 r
.32674 .54779 m .32583 .54676 L .32626 .5438 L F
.774 .543 .584 r
.32979 .55094 m .32679 .55126 L .32674 .54779 L F
.946 .711 .551 r
.33952 .53332 m .33863 .53672 L .34155 .53784 L F
.937 .691 .54 r
.33863 .53672 m .34113 .54035 L .34155 .53784 L F
.77 .789 .869 r
.34476 .62537 m .34076 .625 L .34299 .62387 L F
.656 .823 .964 r
.34299 .62387 m .34724 .62428 L .34476 .62537 L F
0 0 .545 r
.54574 .39387 m .54744 .3979 L .54664 .39554 L F
.023 0 .397 r
.25356 .56856 m .25619 .56603 L .25435 .56681 L F
.25356 .56856 m .25612 .56905 L .25619 .56603 L F
0 0 0 r
.25356 .56856 m .25408 .57101 L .25498 .57014 L F
.25356 .56856 m .25248 .57231 L .25408 .57101 L F
.25582 .569 m .25498 .57014 L .25612 .56905 L F
.25356 .56856 m .25498 .57014 L .25582 .569 L F
0 0 .32 r
.25619 .56603 m .25612 .56905 L .25694 .56799 L F
.606 .882 .562 r
.25612 .56905 m .25408 .57101 L .25694 .56799 L F
.501 .673 .941 r
.25408 .57101 m .25248 .57231 L .25415 .57042 L F
.898 .985 .785 r
.25694 .56799 m .25408 .57101 L .25415 .57042 L F
.324 .4 .786 r
.25248 .57231 m .25517 .57421 L .25415 .57042 L F
.993 .749 .395 r
.25415 .57042 m .25432 .57105 L .25394 .5711 L F
.25432 .57105 m .25517 .57421 L .25406 .5714 L F
.25432 .57105 m .25406 .5714 L .25394 .5711 L F
.887 .648 .572 r
.34166 .57385 m .34407 .57482 L .34211 .57119 L F
.818 .699 .733 r
.33966 .57701 m .34407 .57482 L .34166 .57385 L F
.33966 .57701 m .34177 .57835 L .34407 .57482 L F
.619 .753 .942 r
.51831 .38765 m .52137 .38879 L .51934 .38421 L F
.768 .442 .434 r
.51831 .38765 m .52151 .39036 L .52137 .38879 L F
.484 .132 .292 r
.52151 .39036 m .52388 .39038 L .52137 .38879 L F
.007 .582 .743 r
.31961 .5977 m .32084 .59783 L .31696 .59761 L F
.941 .818 .695 r
.54908 .42118 m .54896 .42728 L .54752 .42474 L F
.927 .546 .164 r
.54896 .42728 m .54787 .42744 L .54752 .42474 L F
.54896 .42728 m .54964 .42861 L .54787 .42744 L F
.589 .855 .994 r
.30341 .6159 m .30713 .61636 L .30599 .61366 L F
.808 .81 .853 r
.30713 .61636 m .30985 .61379 L .30599 .61366 L F
.694 .793 .926 r
.49699 .42176 m .50116 .42269 L .49976 .42048 L F
.514 .658 .925 r
.50116 .42269 m .50243 .41993 L .49976 .42048 L F
.50116 .42269 m .50375 .42241 L .50243 .41993 L F
.23 .514 .911 r
.50116 .42269 m .50499 .42501 L .50375 .42241 L F
.041 0 0 r
.59409 .34225 m .59112 .34484 L .59388 .34337 L F
.347 0 .005 r
.59388 .34337 m .59706 .34287 L .59409 .34225 L F
.541 .635 .893 r
.51021 .41768 m .50679 .41548 L .50795 .41523 L F
.256 .455 .863 r
.51134 .41602 m .51021 .41768 L .50795 .41523 L F
0 0 .157 r
.51093 .41913 m .51021 .41768 L .51134 .41602 L F
.51093 .41913 m .50992 .42092 L .51021 .41768 L F
.995 .783 .507 r
.54787 .42744 m .54964 .42861 L .54908 .42981 L F
.763 .94 .94 r
.29194 .61687 m .2941 .61692 L .29177 .61841 L F
.29194 .61687 m .2941 .61692 L .29177 .61841 L F
.571 .378 .58 r
.29156 .62122 m .2941 .61692 L .29177 .61841 L F
.718 .68 .813 r
.40053 .55197 m .40608 .55383 L .40336 .55123 L F
.296 .477 .868 r
.40608 .55383 m .40616 .55081 L .40336 .55123 L F
.925 .594 .394 r
.51105 .42629 m .51265 .42429 L .50994 .42368 L F
0 .158 .664 r
.51278 .42458 m .51265 .42429 L .51105 .42629 L F
.51278 .42458 m .51294 .42531 L .51265 .42429 L F
.948 .715 .554 r
.36267 .50327 m .36389 .50656 L .36355 .5049 L F
.547 .175 .287 r
.39402 .55125 m .39644 .55337 L .39805 .55012 L F
.864 .698 .675 r
.39644 .55337 m .40053 .55197 L .39805 .55012 L F
.964 .94 .687 r
.51184 .39186 m .51262 .38663 L .51427 .38775 L F
.884 .925 .845 r
.51427 .38775 m .51262 .38663 L .51539 .38331 L F
.776 .736 .816 r
.31624 .54454 m .31483 .54656 L .31263 .54479 L F
0 .295 .766 r
.39036 .5814 m .39314 .58295 L .39242 .5821 L F
.609 .744 .941 r
.56093 .35168 m .55913 .35249 L .55831 .35072 L F
.684 .956 .709 r
.42823 .56462 m .42921 .56291 L .43122 .5617 L F
.844 .723 .731 r
.37668 .56767 m .37806 .57164 L .37561 .57007 L F
.836 .775 .793 r
.37806 .57164 m .37312 .57398 L .37561 .57007 L F
.37806 .57164 m .3756 .57489 L .37312 .57398 L F
.887 .682 .62 r
.3364 .53024 m .33952 .53332 L .34 .53154 L F
.747 .674 .78 r
.32568 .56584 m .32338 .56385 L .3251 .5641 L F
.32763 .56752 m .32431 .56891 L .32338 .56385 L F
.714 .651 .786 r
.32182 .56008 m .32338 .56385 L .32713 .56165 L F
0 0 0 r
.32338 .56385 m .32356 .5645 L .3251 .5641 L F
.964 .939 .656 r
.3251 .5641 m .32356 .5645 L .32452 .56238 L F
.3251 .5641 m .32452 .56238 L .32545 .56034 L F
.747 .674 .78 r
.32763 .56752 m .32568 .56584 L .3251 .5641 L F
.782 .82 .882 r
.32989 .56377 m .32763 .56752 L .3251 .5641 L F
.131 .576 .924 r
.2958 .67745 m .29394 .6772 L .29072 .67567 L F
0 0 0 r
.29979 .67343 m .2958 .67745 L .29832 .67695 L F
0 0 .01 r
.30055 .67366 m .29979 .67343 L .29832 .67695 L F
.879 .761 .728 r
.34109 .54776 m .34043 .55097 L .34237 .55146 L F
.941 .798 .675 r
.33878 .5513 m .34237 .55146 L .34043 .55097 L F
.33878 .5513 m .342 .55428 L .34237 .55146 L F
.874 .576 .481 r
.33432 .52657 m .33653 .52476 L .33473 .52451 L F
.33432 .52657 m .33664 .52741 L .33653 .52476 L F
.556 .388 .609 r
.28621 .55401 m .28926 .55031 L .28697 .55156 L F
.726 .699 .825 r
.31766 .63117 m .31899 .63465 L .31467 .63391 L F
.727 .665 .788 r
.66124 .34773 m .66252 .35184 L .65845 .35176 L F
.802 .47 .426 r
.66206 .35459 m .65845 .35176 L .66252 .35184 L F
.736 .701 .818 r
.58931 .34706 m .58496 .34738 L .58803 .34634 L F
.892 .92 .834 r
.53674 .47718 m .53935 .47428 L .53806 .47316 L F
.867 .923 .862 r
.53806 .47316 m .53935 .47428 L .54247 .47086 L F
.974 .691 .429 r
.41733 .55687 m .41732 .5602 L .41959 .56128 L F
.998 .845 .547 r
.41738 .56235 m .41959 .56128 L .41732 .5602 L F
.41738 .56235 m .41837 .56391 L .41959 .56128 L F
.646 .966 .826 r
.44502 .44004 m .44303 .44172 L .44083 .44228 L F
.699 .983 .833 r
.67077 .37486 m .67422 .37229 L .67229 .37264 L F
.693 .969 .752 r
.66894 .37564 m .67077 .37486 L .67229 .37264 L F
.935 .749 .628 r
.33804 .55649 m .342 .55428 L .33878 .5513 L F
.33804 .55649 m .34046 .5578 L .342 .55428 L F
.969 .787 .603 r
.32075 .57429 m .31891 .57055 L .32205 .57115 L F
.32075 .57429 m .31826 .57382 L .31891 .57055 L F
.813 .698 .739 r
.31974 .57671 m .31826 .57382 L .32075 .57429 L F
.829 .502 .436 r
.35912 .52165 m .35548 .52302 L .35575 .52044 L F
.35912 .52165 m .35932 .52405 L .35548 .52302 L F
.924 .608 .425 r
.37127 .54817 m .36898 .54949 L .3694 .54661 L F
.37127 .54817 m .37151 .55075 L .36898 .54949 L F
.549 .311 .507 r
.2878 .5216 m .28974 .5237 L .28749 .52367 L F
0 0 0 r
.28792 .52252 m .28631 .52366 L .28974 .5237 L F
.28792 .52252 m .28748 .5254 L .28702 .52678 L F
.2871 .52624 m .28702 .52678 L .28691 .52712 L F
.28792 .52252 m .28702 .52678 L .2871 .52624 L F
.549 .311 .507 r
.28756 .52135 m .2878 .5216 L .28631 .52366 L F
.2878 .5216 m .28749 .52367 L .28631 .52366 L F
.681 .301 .321 r
.29 .52181 m .28974 .5237 L .28756 .52135 L F
.964 .94 .687 r
.51184 .39186 m .51088 .39097 L .51262 .38663 L F
0 .407 .798 r
.28867 .68388 m .289 .68351 L .28657 .68292 L F
.28867 .68388 m .29055 .68461 L .289 .68351 L F
0 0 .008 r
.2872 .53245 m .28666 .53183 L .28678 .52984 L F
.2872 .53245 m .2856 .53534 L .28666 .53183 L F
.82 .518 .479 r
.28269 .6455 m .28356 .64927 L .27979 .64856 L F
0 0 0 r
.28034 .6462 m .28237 .64541 L .28298 .64533 L F
.454 0 .04 r
.28301 .64539 m .28479 .64757 L .28356 .64927 L F
0 0 0 r
.28298 .64539 m .28298 .64533 L .28333 .64528 L F
.454 0 .04 r
.28299 .64519 m .28314 .64538 L .28301 .64539 L F
.28314 .64538 m .28479 .64757 L .28301 .64539 L F
0 0 0 r
.28277 .64545 m .28288 .64539 L .28298 .64539 L F
.28288 .64539 m .28298 .64533 L .28298 .64539 L F
.28034 .6462 m .28298 .64533 L .28277 .64545 L F
.28034 .6462 m .28333 .64528 L .28269 .6455 L F
.82 .518 .479 r
.28301 .64539 m .28356 .64927 L .28269 .6455 L F
.28277 .64542 m .27979 .64856 L .28184 .64563 L F
0 0 0 r
.28034 .6462 m .28348 .64526 L .28361 .64524 L F
.28155 .64587 m .28361 .64524 L .28398 .64519 L F
.28034 .6462 m .28361 .64524 L .28155 .64587 L F
.454 0 .04 r
.28314 .64538 m .28684 .64544 L .28479 .64757 L F
0 0 0 r
.28269 .6455 m .28333 .64528 L .28348 .64526 L F
.813 .904 .904 r
.28237 .64541 m .28451 .64503 L .28348 .64526 L F
.454 0 .04 r
.28299 .64519 m .28365 .64523 L .28314 .64538 L F
.28365 .64523 m .28684 .64544 L .28314 .64538 L F
.82 .518 .479 r
.28299 .64519 m .28277 .64542 L .28184 .64563 L F
.795 .952 .921 r
.28034 .6462 m .28299 .64519 L .28147 .64331 L F
.82 .518 .479 r
.28184 .64563 m .28173 .64578 L .28034 .6462 L F
.28173 .64578 m .27979 .64856 L .28034 .6462 L F
.28299 .64519 m .28301 .64539 L .28269 .6455 L F
0 0 0 r
.28034 .6462 m .28398 .64519 L .28299 .64519 L F
.028 0 0 r
.28059 .64702 m .28299 .64519 L .28044 .64616 L F
.28059 .64702 m .28044 .64616 L .28034 .6462 L F
.18 .604 .942 r
.28147 .64331 m .28299 .64519 L .28335 .64336 L F
.737 .933 .597 r
.28335 .64336 m .28299 .64519 L .28216 .64582 L F
.28094 .64655 m .28216 .64582 L .28059 .64702 L F
.28335 .64336 m .28216 .64582 L .28094 .64655 L F
.813 .904 .904 r
.28237 .64541 m .28632 .64448 L .28451 .64503 L F
.28348 .64526 m .28451 .64503 L .28398 .64519 L F
.128 .652 .88 r
.28398 .64519 m .28684 .64544 L .28299 .64519 L F
.737 .933 .597 r
.28335 .64336 m .28059 .64702 L .28479 .64757 L F
.798 .656 .705 r
.28139 .65246 m .27721 .65478 L .27978 .65102 L F
.841 .807 .818 r
.28356 .64927 m .28139 .65246 L .27978 .65102 L F
.28356 .64927 m .27978 .65102 L .27979 .64856 L F
.818 .766 .804 r
.27978 .65102 m .27721 .65478 L .27536 .65136 L F
.824 .698 .726 r
.27979 .64856 m .27978 .65102 L .27536 .65136 L F
.791 .519 .524 r
.27973 .65112 m .28479 .64757 L .28059 .64702 L F
0 0 0 r
.28119 .64554 m .28067 .64751 L .28059 .64702 L F
.28064 .64736 m .27973 .65112 L .28059 .64702 L F
.28059 .64763 m .27973 .65112 L .28064 .64736 L F
.28061 .64764 m .27973 .65112 L .28065 .64739 L F
.28031 .64889 m .27973 .65112 L .28066 .64744 L F
.353 .006 .23 r
.27785 .64686 m .28034 .6462 L .27979 .64856 L F
.27785 .64686 m .28034 .6462 L .27979 .64856 L F
.824 .698 .726 r
.27979 .64856 m .27536 .65136 L .27894 .64737 L F
.562 .842 .504 r
.27612 .65039 m .27894 .64737 L .27536 .65136 L F
.69 .599 .75 r
.28301 .64523 m .28166 .64765 L .28119 .64554 L F
.2807 .64937 m .27973 .65112 L .28086 .64826 L F
.548 0 0 r
.28632 .64448 m .28684 .64544 L .28398 .64519 L F
.54 .876 .617 r
.28479 .64757 m .28558 .64657 L .28335 .64336 L F
0 .295 .792 r
.28558 .64657 m .28479 .64757 L .28083 .65034 L F
.2805 .65051 m .28083 .65034 L .27973 .65112 L F
.28558 .64657 m .28083 .65034 L .2805 .65051 L F
.97 .893 .524 r
.27954 .65175 m .27988 .65313 L .2804 .65057 L F
.69 .599 .75 r
.28301 .64523 m .28558 .64657 L .27973 .65112 L F
.97 .893 .524 r
.27989 .65083 m .2804 .65057 L .28083 .64842 L F
.27954 .65175 m .2804 .65057 L .27989 .65083 L F
.28086 .64826 m .28083 .64842 L .28088 .6482 L F
.27954 .65175 m .28083 .64842 L .28086 .64826 L F
.69 .599 .75 r
.28086 .64826 m .27973 .65112 L .28038 .64862 L F
.28166 .64765 m .2807 .64937 L .28086 .64826 L F
.912 .961 .638 r
.2806 .64767 m .28042 .64841 L .28088 .6482 L F
.897 .511 .288 r
.2806 .64767 m .28088 .6482 L .28085 .64821 L F
.69 .599 .75 r
.28088 .64824 m .28038 .64862 L .28055 .64796 L F
.897 .511 .288 r
.28055 .64796 m .28085 .64821 L .28049 .64837 L F
.2806 .64767 m .28085 .64821 L .28055 .64796 L F
.69 .599 .75 r
.28166 .64765 m .28088 .64824 L .28119 .64554 L F
.28088 .64824 m .28055 .64796 L .28119 .64554 L F
0 0 0 r
.28065 .64739 m .28059 .64763 L .28064 .64736 L F
.28066 .64744 m .28061 .64764 L .28065 .64739 L F
.572 .706 .932 r
.27785 .64686 m .28034 .6462 L .27733 .64261 L F
.028 0 0 r
.28059 .64702 m .28034 .6462 L .27894 .64737 L F
.26 .501 .897 r
.28059 .64702 m .27894 .64737 L .27902 .64466 L F
.912 .961 .638 r
.27902 .64466 m .27894 .64737 L .27612 .65039 L F
.27902 .64466 m .27612 .65039 L .28042 .64841 L F
.27902 .64466 m .28042 .64841 L .2806 .64767 L F
.897 .511 .288 r
.27902 .64466 m .2806 .64767 L .27993 .64861 L F
0 0 0 r
.28067 .64751 m .28031 .64889 L .28066 .64744 L F
.897 .511 .288 r
.2806 .64767 m .28055 .64796 L .27993 .64861 L F
.935 .917 .537 r
.28055 .64796 m .28038 .64862 L .27993 .64861 L F
.897 .511 .288 r
.28055 .64796 m .28049 .64837 L .27993 .64861 L F
.935 .917 .537 r
.28119 .64554 m .28055 .64796 L .27993 .64861 L F
.28038 .64862 m .27973 .65112 L .27983 .64985 L F
.97 .893 .524 r
.27996 .65063 m .28042 .64841 L .27612 .65039 L F
.935 .917 .537 r
.28038 .64862 m .27983 .64985 L .27993 .64861 L F
.97 .893 .524 r
.27954 .65175 m .27996 .65063 L .27949 .6506 L F
.27912 .65143 m .27949 .6506 L .27789 .6505 L F
.27954 .65175 m .27949 .6506 L .27912 .65143 L F
.27737 .65089 m .27789 .6505 L .27612 .65039 L F
.27954 .65175 m .27789 .6505 L .27737 .65089 L F
.27996 .65063 m .28088 .6482 L .28042 .64841 L F
.809 .382 .233 r
.28865 .66474 m .29068 .66443 L .28653 .66311 L F
.667 .482 .626 r
.29266 .66782 m .29025 .67018 L .28941 .66612 L F
.769 .392 .34 r
.29156 .66739 m .29234 .66749 L .29068 .66443 L F
.649 .232 0 r
.2908 .66485 m .29266 .66782 L .29068 .66443 L F
.791 .742 .808 r
.29547 .66374 m .29285 .66755 L .2908 .66485 L F
.29285 .66755 m .29266 .66782 L .29246 .6675 L F
.29285 .66755 m .29246 .6675 L .2908 .66485 L F
.769 .392 .34 r
.28941 .66612 m .29156 .66739 L .29068 .66443 L F
.29156 .66739 m .29264 .66804 L .29234 .66749 L F
.908 .598 .447 r
.28941 .66612 m .29068 .66443 L .28865 .66474 L F
.649 .232 0 r
.2908 .66485 m .29068 .66443 L .28865 .66474 L F
.94 .747 .615 r
.34113 .54035 m .33973 .54383 L .34273 .54385 L F
.906 .731 .655 r
.33884 .54643 m .34273 .54385 L .33973 .54383 L F
.33884 .54643 m .34109 .54776 L .34273 .54385 L F
0 0 0 r
.619 .34563 m .62198 .34515 L .62282 .3449 L F
.62282 .3449 m .62568 .34446 L .62563 .34446 L F
.62282 .3449 m .62198 .34515 L .62568 .34446 L F
.253 .199 .601 r
.52157 .39656 m .51917 .39464 L .52143 .39395 L F
.98 .901 .566 r
.54022 .39801 m .53935 .39669 L .54089 .3954 L F
.635 .955 .771 r
.54089 .3954 m .54175 .39415 L .54379 .39317 L F
.625 .899 .59 r
.54089 .3954 m .53935 .39669 L .54175 .39415 L F
.619 .899 .986 r
.30611 .63334 m .3052 .63511 L .30352 .63397 L F
.30611 .63334 m .30787 .63415 L .3052 .63511 L F
.728 .574 .681 r
.3886 .57808 m .39061 .5788 L .39304 .57796 L F
.525 .351 .588 r
.48655 .43521 m .48962 .43513 L .48944 .43138 L F
.144 .618 .923 r
.29269 .68434 m .29454 .68562 L .29758 .68594 L F
.646 .75 .925 r
.31038 .63324 m .31211 .63497 L .30787 .63415 L F
.686 .798 .934 r
.31288 .63269 m .31211 .63497 L .31038 .63324 L F
.31288 .63269 m .31467 .63391 L .31211 .63497 L F
.794 .663 .719 r
.33594 .58771 m .34016 .58829 L .33852 .58427 L F
.839 .988 .717 r
.51629 .47772 m .5185 .47383 L .52004 .47564 L F
.51629 .47772 m .51586 .47742 L .5185 .47383 L F
.836 .903 .885 r
.48844 .49463 m .48606 .4978 L .48396 .49572 L F
.65 .596 .781 r
.48844 .49463 m .49023 .49823 L .48606 .4978 L F
.664 .51 .665 r
.49023 .49823 m .48828 .50039 L .48606 .4978 L F
.891 .662 .585 r
.67608 .34161 m .67766 .33863 L .67575 .33788 L F
.67608 .34161 m .67754 .34143 L .67766 .33863 L F
.631 .487 .668 r
.46564 .51466 m .46527 .51803 L .4626 .5176 L F
.635 .462 .631 r
.46527 .51803 m .46369 .52018 L .4626 .5176 L F
.631 .487 .668 r
.46564 .51466 m .46527 .51803 L .4626 .5176 L F
.635 .462 .631 r
.4626 .5176 m .46369 .52018 L .46527 .51803 L F
.615 .759 .948 r
.29167 .65125 m .29231 .64969 L .29025 .65058 L F
.29167 .65125 m .29473 .65128 L .29231 .64969 L F
.879 .918 .848 r
.58592 .35969 m .58733 .36245 L .59036 .35763 L F
.295 .393 .794 r
.56816 .35668 m .56716 .35983 L .56521 .35514 L F
.336 .439 .819 r
.56816 .35668 m .56909 .36035 L .56716 .35983 L F
.757 .714 .812 r
.32786 .60054 m .33218 .60095 L .33034 .59724 L F
.773 .667 .746 r
.32931 .60434 m .33218 .60095 L .32786 .60054 L F
.763 .717 .809 r
.33034 .59724 m .33218 .60095 L .33468 .59766 L F
.927 .673 .535 r
.32076 .52114 m .31725 .52257 L .31885 .51966 L F
.32076 .52114 m .32019 .52404 L .31725 .52257 L F
.999 .797 .468 r
.3208 .52412 m .32019 .52404 L .32076 .52114 L F
.319 .173 .52 r
.27208 .55022 m .2725 .55519 L .26981 .5551 L F
.316 .289 .669 r
.2725 .55519 m .27236 .55677 L .26981 .5551 L F
.681 .63 .792 r
.32338 .56385 m .32431 .56891 L .32025 .56697 L F
.735 .591 .696 r
.32431 .56891 m .32205 .57115 L .32025 .56697 L F
.383 .095 .347 r
.32431 .56891 m .32457 .57054 L .32205 .57115 L F
.733 .989 .805 r
.62758 .3838 m .62551 .38578 L .62348 .38646 L F
.713 .986 .832 r
.67229 .37264 m .67422 .37229 L .67614 .37041 L F
.936 .815 .701 r
.56091 .43567 m .56102 .4311 L .56016 .43234 L F
.903 .836 .77 r
.55856 .43652 m .56091 .43567 L .56016 .43234 L F
.258 0 .236 r
.29297 .52079 m .28974 .5237 L .29 .52181 L F
.81 .875 .894 r
.47079 .53766 m .47409 .5379 L .47231 .53645 L F
.937 .61 .167 r
.5848 .39546 m .58534 .39786 L .58479 .39656 L F
.58445 .39499 m .58479 .39656 L .58369 .39394 L F
.5848 .39546 m .58479 .39656 L .58445 .39499 L F
0 .036 .606 r
.58369 .39394 m .58534 .39786 L .58503 .39617 L F
0 0 .346 r
.58551 .40049 m .58503 .39617 L .58534 .39786 L F
.58536 .39921 m .58616 .39774 L .58503 .39617 L F
.58551 .40049 m .58558 .40019 L .58536 .39921 L F
.58558 .40019 m .58616 .39774 L .58536 .39921 L F
.793 .651 .706 r
.52014 .47057 m .52242 .47156 L .51876 .47094 L F
.827 .623 .626 r
.52242 .47156 m .5185 .47383 L .51876 .47094 L F
.52242 .47156 m .52242 .47432 L .5185 .47383 L F
.92 .71 .601 r
.37607 .5579 m .37359 .55708 L .37407 .55421 L F
.828 .587 .574 r
.37607 .5579 m .37298 .56011 L .37359 .55708 L F
.37607 .5579 m .37577 .56083 L .37298 .56011 L F
.729 .822 .922 r
.52242 .47432 m .52004 .47564 L .5185 .47383 L F
.256 .455 .863 r
.51134 .41602 m .50795 .41523 L .51143 .41375 L F
.809 .69 .734 r
.40258 .54129 m .40683 .5424 L .40485 .53786 L F
.317 0 0 r
.58579 .37552 m .58649 .37637 L .58792 .37531 L F
.58337 .37577 m .58649 .37637 L .58579 .37552 L F
.157 .155 .605 r
.58642 .37902 m .58704 .37703 L .58649 .37637 L F
.317 0 0 r
.58792 .37531 m .58649 .37637 L .58793 .37531 L F
.494 .848 .59 r
.58793 .37531 m .58649 .37637 L .58978 .37364 L F
.708 .982 .799 r
.58649 .37637 m .58802 .37384 L .58978 .37364 L F
.157 .155 .605 r
.58704 .37703 m .58802 .37384 L .58649 .37637 L F
.098 .524 .909 r
.58486 .37474 m .58649 .37637 L .58337 .37577 L F
.794 .701 .762 r
.58486 .37474 m .58567 .37697 L .58649 .37637 L F
.58567 .37697 m .58642 .37902 L .58649 .37637 L F
.494 .848 .59 r
.58793 .37531 m .58978 .37364 L .59056 .37437 L F
.718 .756 .883 r
.51052 .44435 m .51435 .44035 L .51166 .44115 L F
.51052 .44435 m .51565 .44175 L .51435 .44035 L F
.823 .445 .339 r
.34708 .51151 m .34497 .51332 L .34308 .5102 L F
.813 .429 .328 r
.3474 .51362 m .34497 .51332 L .34708 .51151 L F
.525 .428 .687 r
.24998 .55766 m .25311 .56108 L .25255 .55707 L F
.24998 .55766 m .25081 .56189 L .25311 .56108 L F
.918 .791 .705 r
.38052 .57821 m .38054 .58113 L .384 .58123 L F
.89 .572 .439 r
.38054 .58113 m .3818 .5831 L .384 .58123 L F
.778 .817 .883 r
.38052 .57821 m .384 .58123 L .38679 .57834 L F
.95 .699 .522 r
.3818 .5831 m .38397 .58432 L .384 .58123 L F
.59 .692 .913 r
.49245 .41849 m .49439 .42272 L .49679 .42053 L F
.604 .719 .926 r
.49439 .42272 m .49699 .42176 L .49679 .42053 L F
.606 .742 .941 r
.52128 .41766 m .52457 .41851 L .5229 .41769 L F
.595 .906 .983 r
.5229 .41769 m .52457 .41851 L .52558 .41676 L F
.133 0 0 r
.59469 .35796 m .59402 .35799 L .59278 .35788 L F
.749 .718 .823 r
.5906 .35768 m .59442 .3585 L .59278 .35788 L F
.59442 .3585 m .59477 .35858 L .59278 .35788 L F
.694 .156 0 r
.59278 .35788 m .58925 .35538 L .59036 .35763 L F
.59278 .35788 m .59176 .35809 L .5909 .35716 L F
.59278 .35788 m .5909 .35716 L .58925 .35538 L F
.133 0 0 r
.59402 .35799 m .59176 .35809 L .59278 .35788 L F
.749 .718 .823 r
.59036 .35763 m .5906 .35768 L .59278 .35788 L F
.58 .926 .955 r
.46894 .54478 m .46747 .54441 L .46404 .54584 L F
.933 .946 .775 r
.46862 .5423 m .46747 .54441 L .46894 .54478 L F
.069 0 .195 r
.43852 .56872 m .43669 .57143 L .43942 .56991 L F
.902 .875 .8 r
.43483 .57036 m .43852 .56872 L .43672 .56687 L F
.43483 .57036 m .43669 .57143 L .43852 .56872 L F
.374 0 .141 r
.43942 .56991 m .4415 .56803 L .43852 .56872 L F
.814 .706 .745 r
.33966 .57701 m .34128 .58084 L .34177 .57835 L F
.33966 .57701 m .33687 .58041 L .34128 .58084 L F
.816 .699 .736 r
.33687 .58041 m .33852 .58427 L .34128 .58084 L F
.464 .509 .82 r
.51808 .37992 m .51727 .38411 L .51539 .38331 L F
.51808 .37992 m .51934 .38421 L .51727 .38411 L F
0 0 0 r
.6338 .34739 m .63268 .34771 L .62977 .34831 L F
.63658 .347 m .63268 .34771 L .6338 .34739 L F
.532 .497 .762 r
.25138 .56414 m .25311 .56108 L .25081 .56189 L F
.25138 .56414 m .25397 .56359 L .25311 .56108 L F
.471 .373 .662 r
.25138 .56414 m .25435 .56681 L .25397 .56359 L F
.25138 .56414 m .25116 .56873 L .25435 .56681 L F
.451 .816 .995 r
.64123 .39739 m .64274 .39598 L .63963 .39515 L F
.64123 .39739 m .64397 .39693 L .64274 .39598 L F
.786 .867 .43 r
.31721 .57159 m .31722 .57078 L .31846 .56884 L F
0 0 0 r
.31846 .56884 m .31722 .57078 L .31864 .56898 L F
.877 .645 .583 r
.32025 .56697 m .32205 .57115 L .31891 .57055 L F
.64 .93 .666 r
.32025 .56697 m .32104 .56544 L .32338 .56385 L F
.379 .167 .461 r
.32104 .56544 m .31846 .56884 L .3204 .56773 L F
0 0 0 r
.31846 .56884 m .31978 .56755 L .3204 .56773 L F
.31846 .56884 m .31864 .56898 L .31978 .56755 L F
0 0 .266 r
.31803 .56803 m .31825 .56867 L .31846 .56884 L F
.31825 .56867 m .31891 .57055 L .31846 .56884 L F
.961 .836 .412 r
.32637 .58235 m .32612 .58003 L .32683 .58112 L F
0 0 0 r
.41281 .45913 m .41192 .45835 L .4102 .45978 L F
.41281 .45913 m .4143 .45719 L .41192 .45835 L F
.817 .89 .896 r
.51655 .49366 m .51845 .49045 L .51543 .49334 L F
.605 .834 .452 r
.24846 .59323 m .24597 .59662 L .24778 .59429 L F
.669 .801 .348 r
.50208 .44233 m .50379 .43885 L .50318 .43991 L F
.846 .996 .761 r
.50169 .4425 m .50318 .43991 L .50326 .44215 L F
.876 .991 .809 r
.50057 .44336 m .50208 .44233 L .50318 .43991 L F
.846 .996 .761 r
.4998 .44291 m .50057 .44336 L .50318 .43991 L F
.4998 .44291 m .50318 .43991 L .50169 .4425 L F
.669 .801 .348 r
.50379 .43885 m .50423 .43795 L .50318 .43991 L F
.637 .435 .593 r
.39943 .56419 m .40284 .56455 L .4027 .56137 L F
.32 .194 .548 r
.4027 .56137 m .40537 .56303 L .40519 .56033 L F
.4027 .56137 m .40284 .56455 L .40537 .56303 L F
.812 .848 .876 r
.54819 .41284 m .54335 .41389 L .54621 .4107 L F
.848 .809 .811 r
.54911 .4103 m .54819 .41284 L .54621 .4107 L F
.83 .362 0 r
.49142 .43505 m .49147 .43674 L .48962 .43513 L F
.49142 .43505 m .49302 .43759 L .49147 .43674 L F
.588 .419 .62 r
.5139 .45113 m .51658 .44774 L .5138 .44834 L F
.5139 .45113 m .51658 .44774 L .5138 .44834 L F
.978 .919 .63 r
.29686 .61011 m .29788 .61164 L .29509 .61046 L F
.86 .576 .507 r
.29788 .61164 m .29491 .61326 L .29509 .61046 L F
.936 .876 .752 r
.65762 .39465 m .65958 .39112 L .65797 .3901 L F
.56 .406 .63 r
.26569 .53466 m .2685 .53699 L .26833 .53413 L F
.26569 .53466 m .26582 .53754 L .2685 .53699 L F
.681 .714 .873 r
.32696 .6278 m .32836 .63114 L .32429 .6305 L F
.759 .753 .847 r
.33094 .6283 m .32836 .63114 L .32696 .6278 L F
.908 .706 .619 r
.37735 .56479 m .3746 .56649 L .3754 .56383 L F
.37735 .56479 m .37668 .56767 L .3746 .56649 L F
0 .192 .675 r
.39424 .58485 m .39406 .5843 L .39314 .58295 L F
.39424 .58485 m .39696 .58679 L .39406 .5843 L F
.912 .53 .279 r
.32896 .55419 m .32679 .55126 L .32979 .55094 L F
.867 .923 .862 r
.53806 .47316 m .54247 .47086 L .54129 .47 L F
.777 .859 .911 r
.54247 .47086 m .54401 .46693 L .54129 .47 L F
.54247 .47086 m .54583 .4687 L .54401 .46693 L F
.924 .908 .512 r
.53842 .40134 m .53935 .39669 L .54022 .39801 L F
.773 .584 .643 r
.54044 .40108 m .53842 .40134 L .54022 .39801 L F
.958 .928 .725 r
.32578 .58498 m .32439 .58704 L .32637 .58235 L F
.655 .655 .838 r
.29473 .65128 m .29555 .64645 L .29231 .64969 L F
.29473 .65128 m .29714 .65026 L .29555 .64645 L F
.88 .857 .814 r
.29745 .66435 m .29266 .66782 L .29547 .66374 L F
.631 .067 0 r
.29932 .66682 m .29745 .66435 L .29547 .66374 L F
.29932 .66682 m .30021 .66656 L .29745 .66435 L F
.535 .324 .541 r
.29745 .66435 m .30027 .66661 L .30072 .66389 L F
.197 .335 .778 r
.29673 .66182 m .29932 .66682 L .29547 .66374 L F
.57 .538 .78 r
.30046 .66514 m .29932 .66682 L .29673 .66182 L F
.765 .962 .659 r
.29907 .6669 m .29932 .66682 L .30046 .66514 L F
.744 .971 .704 r
.2971 .67003 m .29874 .66765 L .2954 .66867 L F
.29874 .66765 m .29932 .66682 L .29812 .66739 L F
.29874 .66765 m .29812 .66739 L .2954 .66867 L F
.926 .623 .449 r
.29885 .6677 m .30046 .66991 L .29779 .66852 L F
.30027 .66661 m .30037 .66834 L .29885 .6677 L F
.30037 .66834 m .30046 .66991 L .29885 .6677 L F
.411 .084 .298 r
.2954 .66867 m .29932 .66682 L .29779 .66852 L F
.765 .962 .659 r
.29779 .66852 m .29932 .66682 L .29907 .6669 L F
.631 .067 0 r
.29932 .66682 m .30027 .66661 L .30021 .66656 L F
.785 .838 .892 r
.30599 .61366 m .30985 .61379 L .30883 .61138 L F
.885 .873 .82 r
.30883 .61138 m .30985 .61379 L .31056 .61235 L F
.891 .721 .664 r
.33961 .5699 m .34166 .57385 L .34211 .57119 L F
.971 .851 .448 r
.24044 .59429 m .23946 .59826 L .23923 .59633 L F
.307 .793 .738 r
.24044 .59429 m .24159 .59372 L .24591 .59234 L F
0 0 0 r
.23923 .59633 m .24159 .59372 L .24044 .59429 L F
.932 .962 .764 r
.39452 .54644 m .39286 .55068 L .39402 .55125 L F
.504 .187 .362 r
.39343 .55423 m .39402 .55125 L .39286 .55068 L F
.39343 .55423 m .39644 .55337 L .39402 .55125 L F
.915 .618 .131 r
.56403 .39141 m .56515 .38647 L .56641 .38883 L F
.785 .672 .739 r
.32504 .60392 m .32931 .60434 L .32786 .60054 L F
.015 .582 .786 r
.49852 .43083 m .49617 .43068 L .49462 .43035 L F
.762 .591 .665 r
.31661 .56183 m .32072 .564 L .31898 .5606 L F
.545 .561 .821 r
.32072 .564 m .32182 .56008 L .31898 .5606 L F
.32072 .564 m .32338 .56385 L .32182 .56008 L F
.594 .073 0 r
.30191 .68651 m .30611 .68677 L .3044 .68747 L F
0 .502 .729 r
.30611 .68677 m .30707 .68684 L .3044 .68747 L F
.30611 .68677 m .30843 .68712 L .30707 .68684 L F
.956 .642 .226 r
.59339 .38152 m .59389 .38275 L .59444 .38219 L F
.793 .887 .466 r
.59517 .38144 m .59444 .38219 L .594 .38402 L F
.633 .154 0 r
.59514 .38584 m .59644 .38723 L .59489 .38518 L F
.59514 .38584 m .59489 .38518 L .594 .38402 L F
0 0 0 r
.59531 .38627 m .59514 .38584 L .59692 .384 L F
.59 .855 .509 r
.59421 .38782 m .59644 .38723 L .59514 .38584 L F
0 0 0 r
.59421 .38782 m .59514 .38584 L .59531 .38627 L F
.633 .154 0 r
.59514 .38584 m .594 .38402 L .59444 .38219 L F
.956 .642 .226 r
.59389 .38275 m .59514 .38584 L .59444 .38219 L F
.793 .887 .466 r
.59546 .38081 m .59444 .38219 L .59517 .38144 L F
.496 .588 .876 r
.31491 .65057 m .31572 .64675 L .31329 .64987 L F
.31491 .65057 m .31783 .6504 L .31572 .64675 L F
.479 .217 .438 r
.31491 .65057 m .31722 .65307 L .31783 .6504 L F
.31491 .65057 m .3146 .65383 L .31722 .65307 L F
.915 .618 .131 r
.56403 .39141 m .5624 .38652 L .56515 .38647 L F
.56403 .39141 m .56291 .38992 L .5624 .38652 L F
.541 0 0 r
.56403 .39141 m .56302 .39264 L .56291 .38992 L F
.56403 .39141 m .56698 .39324 L .56302 .39264 L F
.56403 .39141 m .56698 .39324 L .56302 .39264 L F
.605 .331 .475 r
.43483 .57036 m .43942 .56991 L .43669 .57143 L F
.486 .361 .635 r
.25728 .58002 m .25533 .58299 L .25503 .58129 L F
.386 .036 .245 r
.25865 .55109 m .26032 .55288 L .26043 .55023 L F
.25865 .55109 m .25746 .55354 L .26032 .55288 L F
.644 .218 0 r
.41408 .47278 m .41522 .4744 L .41361 .47179 L F
0 .09 .605 r
.54925 .34693 m .54508 .34275 L .54514 .34639 L F
.754 .947 .943 r
.48311 .42591 m .48782 .42496 L .48672 .42406 L F
.9 .985 .732 r
.48782 .42496 m .48833 .42185 L .48672 .42406 L F
0 0 .271 r
.23783 .62024 m .23587 .61837 L .23818 .61803 L F
.816 .967 .902 r
.4363 .55456 m .43686 .5522 L .43962 .55163 L F
.952 .952 .671 r
.43563 .55688 m .43686 .5522 L .4363 .55456 L F
.564 .394 .61 r
.43962 .55163 m .43817 .55314 L .4363 .55456 L F
.792 .652 .708 r
.43817 .55314 m .43563 .55688 L .4363 .55456 L F
.801 .937 .919 r
.52452 .48438 m .52575 .48554 L .52751 .48385 L F
.428 .858 .939 r
.29194 .61687 m .2941 .61692 L .2966 .61612 L F
.2966 .61612 m .2941 .61692 L .29194 .61687 L F
.793 .992 .879 r
.53674 .47718 m .53586 .47675 L .53309 .47928 L F
.892 .92 .834 r
.53674 .47718 m .53806 .47316 L .53586 .47675 L F
.712 .649 .785 r
.40102 .56788 m .40394 .56811 L .40284 .56455 L F
.347 .368 .741 r
.40394 .56811 m .40537 .56303 L .40284 .56455 L F
.40394 .56811 m .40664 .5674 L .40537 .56303 L F
.163 0 0 r
.65148 .33572 m .65419 .33557 L .65512 .33403 L F
.516 .082 .153 r
.65419 .33557 m .6582 .33352 L .65512 .33403 L F
.626 .949 .94 r
.50237 .4915 m .4973 .49293 L .50122 .4907 L F
.892 .972 .825 r
.50505 .48812 m .50237 .4915 L .50122 .4907 L F
.65 .144 0 r
.32429 .53556 m .32362 .53546 L .32349 .53303 L F
.32429 .53556 m .32525 .53694 L .32362 .53546 L F
0 0 0 r
.28052 .62396 m .27899 .62651 L .2819 .62747 L F
.999 .797 .472 r
.54929 .41824 m .54787 .42024 L .54742 .41727 L F
.54929 .41824 m .54908 .42118 L .54787 .42024 L F
0 0 .116 r
.46401 .52465 m .46603 .52043 L .46485 .52176 L F
.46401 .52465 m .46569 .52307 L .46603 .52043 L F
0 0 .305 r
.46401 .52465 m .465 .52567 L .46569 .52307 L F
.475 .443 .743 r
.38204 .46803 m .38626 .47214 L .38608 .46779 L F
.128 0 .003 r
.51824 .37468 m .52109 .37378 L .52108 .37284 L F
.359 .173 .487 r
.51824 .37468 m .52019 .37634 L .52109 .37378 L F
.51824 .37468 m .51821 .37746 L .52019 .37634 L F
.514 .888 .97 r
.33041 .67998 m .3335 .67943 L .33331 .67842 L F
.722 .989 .859 r
.33331 .67842 m .3335 .67943 L .33642 .6765 L F
.891 .838 .786 r
.55406 .44434 m .55706 .44419 L .55623 .44056 L F
.885 .854 .806 r
.55437 .4478 m .55706 .44419 L .55406 .44434 L F
.847 .816 .819 r
.55623 .44056 m .55706 .44419 L .55815 .44218 L F
.13 .254 .725 r
.28303 .67722 m .28554 .68127 L .2849 .67706 L F
0 .092 .609 r
.2849 .67706 m .28554 .68127 L .28584 .67947 L F
.925 .542 .157 r
.2849 .67706 m .28584 .67947 L .28414 .67764 L F
.2849 .67706 m .28414 .67764 L .28354 .677 L F
0 0 0 r
.28689 .67632 m .28541 .67667 L .2849 .67706 L F
.28541 .67667 m .28303 .67722 L .2849 .67706 L F
.313 .205 .567 r
.59112 .34484 m .59322 .34619 L .59388 .34337 L F
.59112 .34484 m .59155 .34766 L .59322 .34619 L F
.958 .895 .722 r
.43366 .58509 m .4338 .58027 L .4356 .58165 L F
.976 .883 .513 r
.43366 .58509 m .4338 .58027 L .4356 .58165 L F
.862 .87 .844 r
.43816 .57827 m .4356 .58165 L .4338 .58027 L F
.662 .924 .628 r
.52847 .41014 m .52554 .41364 L .5268 .41133 L F
.658 .897 .559 r
.5268 .41133 m .52554 .41364 L .524 .41478 L F
.94 .839 .398 r
.56707 .41448 m .56786 .4115 L .56688 .41273 L F
.898 .864 .421 r
.56688 .41273 m .56786 .4115 L .56764 .41042 L F
.393 .251 .567 r
.48944 .43138 m .48962 .43513 L .49147 .43338 L F
.595 .658 .882 r
.53321 .46088 m .53033 .46166 L .52937 .4596 L F
.864 .89 .853 r
.66124 .34773 m .65845 .35176 L .65677 .34977 L F
.802 .47 .426 r
.66206 .35459 m .65843 .35406 L .65845 .35176 L F
.673 .728 .22 r
.58466 .38861 m .5846 .38879 L .58254 .38717 L F
.58466 .38861 m .58383 .39115 L .5846 .38879 L F
0 .057 .615 r
.59616 .37551 m .59451 .37527 L .59633 .37311 L F
.796 .975 .686 r
.59785 .37429 m .59706 .37558 L .59616 .37551 L F
0 .057 .615 r
.59616 .37551 m .59588 .37772 L .59457 .37539 L F
.985 .864 .498 r
.59616 .37551 m .59621 .37957 L .59588 .37772 L F
.59616 .37551 m .59546 .37819 L .59621 .37957 L F
.796 .975 .686 r
.59706 .37558 m .59546 .37819 L .59616 .37551 L F
0 .057 .615 r
.59616 .37551 m .59457 .37539 L .59451 .37527 L F
0 0 .443 r
.23728 .61287 m .23818 .61803 L .23857 .61574 L F
.17 0 .249 r
.23818 .61803 m .24056 .61677 L .23857 .61574 L F
.23818 .61803 m .23783 .62024 L .24056 .61677 L F
.23818 .61803 m .23783 .62024 L .24056 .61677 L F
.442 0 0 r
.54379 .39317 m .54175 .39415 L .54574 .39387 L F
.135 .682 .747 r
.39538 .55944 m .39389 .55952 L .39374 .55964 L F
.62 .702 .904 r
.39538 .55944 m .39687 .55617 L .39403 .55755 L F
.39538 .55944 m .39875 .55867 L .39687 .55617 L F
.055 0 0 r
.33642 .6765 m .34048 .67372 L .33989 .6741 L F
0 0 0 r
.34048 .67372 m .34385 .67094 L .34187 .67274 L F
.409 .811 .594 r
.33989 .6741 m .34048 .67372 L .34187 .67274 L F
.852 .976 .867 r
.47509 .53285 m .47905 .53064 L .47808 .53004 L F
.85 .998 .801 r
.47905 .53064 m .48111 .52681 L .47808 .53004 L F
.47905 .53064 m .48171 .52751 L .48111 .52681 L F
.976 .883 .513 r
.43366 .58509 m .43189 .58544 L .4338 .58027 L F
.913 .963 .802 r
.43296 .58739 m .43189 .58544 L .43366 .58509 L F
0 0 0 r
.40686 .59435 m .40349 .5965 L .40254 .59674 L F
.40798 .59412 m .40686 .59435 L .40958 .59469 L F
.40798 .59412 m .40349 .5965 L .40686 .59435 L F
0 0 .545 r
.54574 .39387 m .54742 .39623 L .54744 .3979 L F
.674 .22 0 r
.54748 .39859 m .54744 .3979 L .54742 .39623 L F
.54748 .39859 m .54914 .40065 L .54744 .3979 L F
.46 .838 .604 r
.48427 .41103 m .48596 .40966 L .48767 .40849 L F
.201 0 0 r
.48596 .40966 m .48961 .40689 L .48767 .40849 L F
.776 .736 .816 r
.31624 .54454 m .31263 .54479 L .31454 .54324 L F
.646 .507 .679 r
.31836 .54141 m .31816 .54162 L .31697 .54275 L F
.479 .785 .998 r
.31697 .54275 m .31624 .54454 L .3156 .54405 L F
.929 .957 .64 r
.3154 .54451 m .31532 .54653 L .31697 .54275 L F
.646 .507 .679 r
.31816 .54162 m .3154 .54451 L .31697 .54275 L F
.479 .785 .998 r
.31697 .54275 m .3156 .54405 L .31454 .54324 L F
.667 .775 .302 r
.31697 .54275 m .31532 .54653 L .31624 .54454 L F
.341 .412 .79 r
.32497 .57364 m .32205 .57115 L .32457 .57054 L F
0 0 0 r
.34385 .67094 m .3469 .66775 L .34491 .66993 L F
.49 .824 .529 r
.34187 .67274 m .34385 .67094 L .34491 .66993 L F
.591 .935 .753 r
.45209 .44591 m .45411 .44507 L .45603 .44352 L F
.297 .761 .946 r
.64046 .34736 m .63931 .34676 L .63658 .347 L F
.376 .819 .949 r
.64323 .34671 m .63931 .34676 L .64046 .34736 L F
0 0 0 r
.48427 .41103 m .4829 .41242 L .48596 .40966 L F
.806 .477 .431 r
.31274 .68446 m .31502 .68833 L .31359 .6856 L F
.31274 .68446 m .31359 .6856 L .31138 .68557 L F
.061 .619 .803 r
.31211 .68548 m .31138 .68557 L .31359 .6856 L F
.896 .667 .584 r
.31084 .68563 m .31274 .68446 L .31138 .68557 L F
.061 .619 .803 r
.30893 .68522 m .31138 .68557 L .31211 .68548 L F
.896 .667 .584 r
.30843 .68712 m .31084 .68563 L .31138 .68557 L F
.961 .807 .644 r
.54686 .43369 m .54722 .43866 L .54534 .43714 L F
.964 .917 .711 r
.54722 .43866 m .54504 .43993 L .54534 .43714 L F
.54722 .43866 m .54628 .44092 L .54504 .43993 L F
.707 .278 .227 r
.36775 .50761 m .37009 .50987 L .37012 .50831 L F
.711 .939 .63 r
.43305 .55938 m .43122 .5617 L .43223 .55981 L F
.722 .968 .715 r
.43122 .5617 m .42921 .56291 L .43223 .55981 L F
.855 .63 .597 r
.37427 .5513 m .37128 .55321 L .37151 .55075 L F
.37427 .5513 m .37407 .55421 L .37128 .55321 L F
.665 .973 .882 r
.51032 .49779 m .50953 .49739 L .50584 .49969 L F
.766 .985 .902 r
.51359 .49526 m .5109 .49569 L .51032 .49779 L F
.808 .999 .804 r
.5109 .49569 m .50953 .49739 L .51032 .49779 L F
.908 .74 .661 r
.33934 .56031 m .34094 .56421 L .34161 .56144 L F
.649 .759 .93 r
.24615 .62641 m .24833 .62839 L .25036 .62721 L F
.24615 .62641 m .24833 .62839 L .25036 .62721 L F
.345 .717 .985 r
.63963 .39515 m .63582 .39432 L .63705 .39542 L F
.892 .972 .825 r
.50505 .48812 m .50122 .4907 L .5037 .48713 L F
.806 .948 .915 r
.50505 .48812 m .50535 .48531 L .5078 .48483 L F
.50505 .48812 m .5037 .48713 L .50535 .48531 L F
.677 .286 .298 r
.3185 .58615 m .32049 .5868 L .31833 .58438 L F
.739 .286 .176 r
.36389 .50656 m .36594 .50913 L .36775 .50761 L F
.722 .255 .14 r
.36749 .50906 m .36775 .50761 L .36594 .50913 L F
.36749 .50906 m .37009 .50987 L .36775 .50761 L F
.781 .292 .058 r
.50314 .44768 m .49895 .44493 L .49946 .44804 L F
.543 .127 .203 r
.50203 .44992 m .49946 .44804 L .49962 .45061 L F
.50203 .44992 m .50314 .44768 L .49946 .44804 L F
.544 .884 .987 r
.58496 .34738 m .58612 .34541 L .58803 .34634 L F
.58496 .34738 m .58337 .3464 L .58612 .34541 L F
.614 .809 .975 r
.47666 .51762 m .47242 .51707 L .47541 .51416 L F
.818 .792 .828 r
.47956 .51455 m .47666 .51762 L .47541 .51416 L F
0 0 0 r
.44385 .56281 m .44529 .56193 L .44376 .56311 L F
.44392 .56261 m .44385 .56281 L .44216 .56611 L F
.888 .991 .766 r
.44216 .56611 m .44385 .56281 L .44117 .56512 L F
0 0 0 r
.44385 .56281 m .44376 .56311 L .44117 .56512 L F
.44497 .56052 m .44385 .56281 L .44392 .56261 L F
.339 0 0 r
.44497 .56052 m .44529 .56193 L .44385 .56281 L F
.9 .922 .824 r
.54223 .44328 m .54357 .44452 L .54076 .44825 L F
.897 .922 .828 r
.54628 .44092 m .54357 .44452 L .54223 .44328 L F
.332 0 .204 r
.58728 .36787 m .58725 .37019 L .58603 .37031 L F
.562 .876 .993 r
.65051 .37762 m .65182 .37562 L .65318 .37651 L F
.65051 .37762 m .64928 .37668 L .65182 .37562 L F
.9 .922 .824 r
.54223 .44328 m .54076 .44825 L .53949 .44661 L F
.746 .721 .828 r
.37974 .47314 m .38382 .47269 L .37932 .47078 L F
.324 .376 .762 r
.31294 .65399 m .31589 .65716 L .3146 .65383 L F
0 0 0 r
.31084 .59585 m .30995 .5956 L .30843 .59674 L F
.31084 .59585 m .31304 .59487 L .30995 .5956 L F
.803 .654 .698 r
.40314 .53384 m .40759 .53503 L .40562 .53408 L F
.40314 .53384 m .40485 .53786 L .40759 .53503 L F
.519 .87 .989 r
.40562 .53408 m .40759 .53503 L .41043 .53395 L F
.533 .865 .591 r
.44788 .54947 m .45064 .54706 L .44919 .54842 L F
.928 .676 .191 r
.32636 .54081 m .32532 .53926 L .32525 .53694 L F
.965 .689 .463 r
.32636 .54081 m .32399 .5426 L .32532 .53926 L F
.32636 .54081 m .32626 .5438 L .32399 .5426 L F
.741 .884 .479 r
.34744 .66614 m .3469 .66775 L .34899 .66402 L F
.752 .923 .562 r
.34491 .66993 m .3469 .66775 L .34744 .66614 L F
.712 .649 .785 r
.40102 .56788 m .40284 .56455 L .39943 .56419 L F
.599 .457 .659 r
.61416 .35521 m .61817 .35521 L .61393 .35349 L F
.61416 .35521 m .61497 .35805 L .61817 .35521 L F
.559 .705 .938 r
.43962 .58675 m .44356 .58803 L .44212 .58601 L F
.83 .803 .825 r
.44212 .58601 m .44356 .58803 L .44633 .5845 L F
.329 0 0 r
.41772 .59745 m .41635 .59788 L .41314 .59757 L F
.555 .925 .777 r
.41877 .59614 m .41772 .59745 L .42029 .59664 L F
.41877 .59614 m .41635 .59788 L .41772 .59745 L F
.56 .393 .611 r
.26035 .54423 m .26323 .54384 L .26312 .54089 L F
.448 .306 .594 r
.26091 .54758 m .26323 .54384 L .26035 .54423 L F
.063 0 0 r
.64073 .33973 m .64493 .33797 L .64226 .33912 L F
0 .49 .815 r
.39746 .56355 m .39651 .56293 L .39588 .56251 L F
.39746 .56355 m .39943 .56419 L .39651 .56293 L F
.39746 .56355 m .39651 .56293 L .39477 .56505 L F
.39746 .56355 m .39943 .56419 L .39651 .56293 L F
.833 .804 .823 r
.62323 .36717 m .6249 .36896 L .62684 .36726 L F
.707 .659 .8 r
.62608 .36366 m .62684 .36726 L .62996 .36436 L F
.695 .687 .839 r
.46187 .53348 m .46402 .53522 L .45912 .53416 L F
.882 .801 .764 r
.55233 .45388 m .55027 .45707 L .55325 .45769 L F
.965 .762 .579 r
.55027 .45707 m .55196 .46116 L .55325 .45769 L F
.859 .789 .782 r
.55233 .45388 m .55325 .45769 L .55446 .45542 L F
0 .279 .78 r
.6557 .36258 m .65626 .36466 L .65578 .36504 L F
.6557 .36258 m .65626 .36466 L .65578 .36504 L F
.897 .922 .828 r
.54628 .44092 m .54223 .44328 L .54504 .43993 L F
.226 .691 .946 r
.39817 .47444 m .39742 .47346 L .39705 .4736 L F
.327 .049 .33 r
.27426 .53044 m .27656 .52981 L .27643 .52702 L F
.369 .167 .47 r
.27656 .52981 m .27912 .52633 L .27643 .52702 L F
.629 .095 0 r
.40852 .53268 m .41043 .53395 L .409 .5324 L F
.925 .634 .473 r
.32933 .51618 m .33165 .51452 L .32912 .51374 L F
.32933 .51618 m .33186 .51743 L .33165 .51452 L F
0 .335 .688 r
.52845 .41203 m .52993 .41278 L .52847 .41014 L F
.52845 .41203 m .53299 .41402 L .52993 .41278 L F
0 0 0 r
.45797 .43168 m .45391 .4342 L .45629 .43294 L F
.457 .827 .575 r
.45998 .43006 m .45797 .43168 L .45629 .43294 L F
.965 .641 .272 r
.27795 .66038 m .27765 .65776 L .27609 .65667 L F
.571 .322 .499 r
.26833 .53413 m .27115 .53384 L .27166 .53129 L F
.455 .216 .461 r
.27115 .53384 m .27426 .53044 L .27166 .53129 L F
0 0 .488 r
.39389 .55952 m .39588 .56251 L .39374 .55964 L F
.867 .545 .438 r
.56263 .35395 m .55831 .35072 L .56093 .35168 L F
.56263 .35395 m .55835 .35316 L .55831 .35072 L F
.245 .309 .731 r
.55852 .35687 m .55835 .35316 L .56263 .35395 L F
.732 .631 .747 r
.4925 .49737 m .48844 .49463 L .49137 .49402 L F
.4925 .49737 m .49023 .49823 L .48844 .49463 L F
.705 .551 .675 r
.4925 .49737 m .48968 .50059 L .49023 .49823 L F
.738 .751 .863 r
.49556 .49448 m .4925 .49737 L .49137 .49402 L F
.865 .841 .82 r
.55162 .44692 m .55437 .4478 L .55406 .44434 L F
.927 .686 .554 r
.55386 .45034 m .55437 .4478 L .55162 .44692 L F
.559 .144 .21 r
.50203 .44992 m .50632 .44927 L .50314 .44768 L F
.889 .871 .814 r
.30883 .61138 m .31056 .61235 L .3131 .60865 L F
.725 .743 .866 r
.32049 .5868 m .32217 .59019 L .3195 .59037 L F
.841 .777 .79 r
.32217 .59019 m .31988 .59402 L .3195 .59037 L F
.812 .778 .821 r
.32439 .58704 m .32217 .59019 L .32049 .5868 L F
.731 .537 .63 r
.3195 .59037 m .32217 .59019 L .31988 .59402 L F
.225 .387 .816 r
.27154 .64626 m .27282 .64657 L .27327 .64511 L F
.27154 .64626 m .27253 .64723 L .27282 .64657 L F
.096 0 0 r
.42492 .46008 m .42131 .46315 L .42264 .46117 L F
.426 .528 .859 r
.30544 .65424 m .30545 .65045 L .30381 .65041 L F
.30544 .65424 m .30808 .65507 L .30545 .65045 L F
.85 .582 .534 r
.6718 .33966 m .67575 .33788 L .67154 .33734 L F
.6718 .33966 m .67608 .34161 L .67575 .33788 L F
.976 .814 .618 r
.55446 .45542 m .55386 .45034 L .55233 .45388 L F
.586 .042 0 r
.40212 .54391 m .40054 .54535 L .39779 .54351 L F
.502 .208 .4 r
.40054 .54535 m .39743 .54605 L .39779 .54351 L F
.592 .452 .659 r
.40054 .54535 m .39771 .54929 L .39743 .54605 L F
.986 .709 .361 r
.39923 .54396 m .39992 .54592 L .40054 .54535 L F
.722 .63 .754 r
.40208 .54855 m .39771 .54929 L .40054 .54535 L F
.986 .709 .361 r
.39992 .54592 m .40075 .54829 L .40054 .54535 L F
.586 .042 0 r
.40222 .54392 m .40054 .54535 L .40212 .54391 L F
.9 .617 .113 r
.40082 .53984 m .40222 .54392 L .40258 .54129 L F
.40082 .53984 m .40131 .54292 L .40222 .54392 L F
.965 .87 .472 r
.40131 .54292 m .40054 .54535 L .40222 .54392 L F
.78 .782 .854 r
.29168 .63857 m .28737 .63841 L .28988 .63698 L F
.566 .793 .985 r
.29421 .63774 m .29168 .63857 L .28988 .63698 L F
.431 0 0 r
.4122 .5877 m .4109 .58686 L .40766 .58456 L F
.626 .691 .891 r
.38626 .47214 m .38749 .47459 L .38922 .47279 L F
.703 .166 0 r
.35809 .49987 m .36036 .50211 L .36183 .50161 L F
.842 .377 .05 r
.36183 .50161 m .36036 .50211 L .36267 .50327 L F
.836 .995 .752 r
.3287 .68174 m .33041 .67998 L .32971 .67953 L F
.514 .888 .97 r
.33041 .67998 m .33331 .67842 L .32971 .67953 L F
.716 .519 .622 r
.54453 .40114 m .54246 .40447 L .54044 .40108 L F
0 .192 .717 r
.50375 .42241 m .50499 .42501 L .50602 .42449 L F
0 0 .031 r
.50602 .42449 m .50499 .42501 L .50454 .42721 L F
.899 .972 .816 r
.58337 .37577 m .58065 .37859 L .58135 .37638 L F
.098 .524 .909 r
.58486 .37474 m .58337 .37577 L .58469 .37187 L F
.34 .079 .364 r
.43518 .45472 m .43764 .45384 L .43473 .457 L F
.111 0 0 r
.45906 .55002 m .45799 .55002 L .45549 .54974 L F
.794 .996 .783 r
.46104 .54676 m .45906 .55002 L .46203 .54747 L F
.46104 .54676 m .45799 .55002 L .45906 .55002 L F
.799 .444 .385 r
.35146 .51446 m .34907 .51652 L .3474 .51362 L F
.862 .548 .454 r
.35143 .51679 m .34907 .51652 L .35146 .51446 L F
.951 .602 .231 r
.54657 .35294 m .54821 .35449 L .54736 .35177 L F
.972 .726 .302 r
.54656 .35032 m .54657 .35294 L .54736 .35177 L F
.951 .602 .231 r
.54736 .35177 m .54821 .35449 L .54657 .35294 L F
.972 .726 .302 r
.54736 .35177 m .54657 .35294 L .54656 .35032 L F
.889 .871 .814 r
.30883 .61138 m .3131 .60865 L .3117 .60729 L F
.758 .738 .834 r
.31368 .60773 m .31562 .60743 L .31843 .60451 L F
.708 .856 .953 r
.3131 .60865 m .31365 .60838 L .31237 .60794 L F
.758 .738 .834 r
.31339 .6078 m .31843 .60451 L .31639 .60251 L F
.708 .856 .953 r
.31365 .60838 m .31368 .60773 L .31339 .6078 L F
.758 .738 .834 r
.31327 .60801 m .31368 .60773 L .31339 .6078 L F
.31368 .60773 m .31843 .60451 L .31339 .6078 L F
.708 .856 .953 r
.31365 .60838 m .31562 .60743 L .31368 .60773 L F
.31339 .6078 m .31368 .60773 L .31338 .60778 L F
.31365 .60838 m .31338 .60778 L .31237 .60794 L F
.894 .924 .832 r
.31277 .60434 m .31339 .6078 L .31639 .60251 L F
.312 .60473 m .31318 .60734 L .31277 .60434 L F
.31318 .60734 m .31339 .6078 L .31277 .60434 L F
.708 .856 .953 r
.31237 .60794 m .31293 .60785 L .3117 .60729 L F
.31324 .6078 m .31562 .60743 L .31318 .60734 L F
.741 .838 .924 r
.3117 .60729 m .31318 .60734 L .31327 .60801 L F
.758 .738 .834 r
.31327 .60801 m .31562 .60743 L .31368 .60773 L F
.741 .838 .924 r
.31318 .60734 m .31562 .60743 L .31327 .60801 L F
.894 .924 .832 r
.31145 .605 m .31327 .60801 L .31339 .6078 L F
.31145 .605 m .31339 .6078 L .312 .60473 L F
.817 .867 .884 r
.48171 .52751 m .48338 .52322 L .48111 .52681 L F
.48171 .52751 m .48507 .5246 L .48338 .52322 L F
.848 .704 .704 r
.47956 .51455 m .47541 .51416 L .4779 .51052 L F
.716 .647 .779 r
.48265 .51157 m .47956 .51455 L .4779 .51052 L F
.808 .698 .743 r
.28564 .67403 m .28689 .67632 L .2849 .67706 L F
.818 .945 .907 r
.45686 .53566 m .45752 .53293 L .45912 .53416 L F
.45686 .53566 m .45425 .53557 L .45752 .53293 L F
.895 .478 .094 r
.40148 .53266 m .40219 .53158 L .40099 .53005 L F
.40148 .53266 m .40314 .53384 L .40219 .53158 L F
.766 .849 .913 r
.41789 .58974 m .4158 .59204 L .41468 .58989 L F
.664 .51 .665 r
.49023 .49823 m .48968 .50059 L .48828 .50039 L F
.587 .854 .994 r
.53193 .3826 m .53073 .38474 L .53362 .38378 L F
.984 .711 .42 r
.53362 .38378 m .53193 .3826 L .53073 .38474 L F
.241 .383 .806 r
.24816 .57048 m .24982 .57437 L .25099 .57225 L F
.006 .073 .584 r
.24982 .57437 m .25142 .57643 L .25099 .57225 L F
.643 .261 .305 r
.28175 .54732 m .27887 .55135 L .27791 .54789 L F
.882 .934 .557 r
.28199 .5453 m .27887 .55135 L .28175 .54732 L F
.685 .72 .876 r
.32696 .6278 m .32429 .6305 L .32244 .62707 L F
.306 .178 .538 r
.38608 .46779 m .38833 .47029 L .3887 .46801 L F
.38608 .46779 m .38626 .47214 L .38833 .47029 L F
.747 .618 .715 r
.24159 .59372 m .24629 .59092 L .24591 .59234 L F
.181 0 0 r
.41686 .45643 m .41945 .45583 L .42104 .45398 L F
0 0 0 r
.41945 .45583 m .42347 .45317 L .42104 .45398 L F
.74 .696 .809 r
.32093 .60337 m .3226 .60713 L .32504 .60392 L F
0 .41 .702 r
.60106 .34375 m .60349 .34444 L .60364 .34452 L F
0 .525 .715 r
.59989 .34406 m .60349 .34444 L .60106 .34375 L F
.346 .801 .944 r
.60244 .34431 m .60324 .34431 L .60349 .34444 L F
.60324 .34431 m .607 .34435 L .60349 .34444 L F
0 .41 .702 r
.60364 .34452 m .60349 .34444 L .60511 .34496 L F
.097 .486 .898 r
.607 .34435 m .60511 .34496 L .60349 .34444 L F
.607 .34435 m .60784 .34557 L .60511 .34496 L F
.726 .53 .626 r
.48828 .50039 m .48317 .50387 L .48326 .50102 L F
.48828 .50039 m .48824 .5039 L .48317 .50387 L F
.667 .481 .625 r
.48968 .50059 m .48824 .5039 L .48828 .50039 L F
.901 .485 .146 r
.31728 .51752 m .31551 .51657 L .31476 .51448 L F
.783 .607 .662 r
.31885 .51966 m .31551 .51657 L .31728 .51752 L F
.336 0 0 r
.65116 .39455 m .64971 .39572 L .64702 .39554 L F
.982 .696 .384 r
.65116 .39455 m .65155 .39745 L .64971 .39572 L F
.677 .871 .972 r
.54583 .4687 m .54673 .46601 L .54401 .46693 L F
.54583 .4687 m .5482 .46731 L .54673 .46601 L F
.888 .988 .797 r
.48853 .51625 m .48634 .52073 L .48995 .51717 L F
.89 .94 .839 r
.48853 .51625 m .48995 .51717 L .49254 .51396 L F
.806 .468 .416 r
.35554 .51768 m .35316 .51976 L .35143 .51679 L F
.847 .535 .461 r
.35554 .51768 m .35575 .52044 L .35316 .51976 L F
.897 .616 .502 r
.34308 .5102 m .34088 .50706 L .34313 .50778 L F
.672 .679 .848 r
.29714 .65026 m .30135 .65135 L .30094 .64973 L F
0 .162 .7 r
.30094 .64973 m .30135 .65135 L .3019 .65025 L F
0 0 0 r
.30135 .65135 m .30166 .6515 L .3019 .65025 L F
.30135 .65135 m .30381 .65041 L .30166 .6515 L F
.869 .995 .782 r
.51031 .48167 m .5078 .48483 L .50823 .48228 L F
.849 .992 .843 r
.5078 .48483 m .50535 .48531 L .50823 .48228 L F
.746 .729 .836 r
.33619 .62438 m .33778 .62775 L .33353 .62721 L F
.764 .768 .856 r
.33871 .62321 m .33778 .62775 L .33619 .62438 L F
.33871 .62321 m .34076 .625 L .33778 .62775 L F
0 0 0 r
.4161 .4673 m .41922 .46402 L .41827 .466 L F
.41922 .46402 m .42131 .46315 L .41827 .466 L F
.373 .809 .96 r
.61763 .34467 m .62198 .34515 L .619 .34563 L F
0 0 0 r
.52388 .41487 m .52128 .41766 L .5229 .41769 L F
.808 .519 .5 r
.67926 .35327 m .68294 .35143 L .68176 .35053 L F
.67926 .35327 m .68305 .35399 L .68294 .35143 L F
.742 .788 .89 r
.30056 .63644 m .29872 .63822 L .29657 .63636 L F
.696 .714 .863 r
.62045 .36817 m .6249 .36896 L .62323 .36717 L F
.742 .616 .718 r
.4072 .55081 m .40302 .54832 L .40616 .55081 L F
.657 .101 0 r
.40347 .54944 m .40616 .55081 L .40302 .54832 L F
.83 .386 .173 r
.4057 .55088 m .4022 .5488 L .40336 .55123 L F
.40616 .55081 m .40347 .54944 L .4057 .55088 L F
.40347 .54944 m .4022 .5488 L .4057 .55088 L F
.40616 .55081 m .40208 .54855 L .4022 .5488 L F
.657 .101 0 r
.40354 .54964 m .40347 .54944 L .40208 .54855 L F
.40354 .54964 m .40616 .55081 L .40347 .54944 L F
.83 .386 .173 r
.40616 .55081 m .40546 .55107 L .40354 .54964 L F
.657 .101 0 r
.40364 .54989 m .40616 .55081 L .40354 .54964 L F
.83 .386 .173 r
.40616 .55081 m .40354 .54964 L .40208 .54855 L F
.019 0 0 r
.40616 .55081 m .4042 .55152 L .40336 .55123 L F
.83 .386 .173 r
.40546 .55107 m .4042 .55152 L .40208 .54855 L F
.657 .101 0 r
.40364 .54989 m .40354 .54964 L .40208 .54855 L F
.40347 .54944 m .40302 .54832 L .40208 .54855 L F
.68 .867 .97 r
.40688 .54814 m .40616 .55081 L .40364 .54989 L F
.854 .996 .765 r
.40688 .54814 m .40477 .55081 L .40616 .55081 L F
.40477 .55081 m .4042 .55152 L .40616 .55081 L F
.742 .616 .718 r
.4076 .55105 m .4072 .55081 L .40616 .55081 L F
.986 .716 .417 r
.40616 .55081 m .40762 .55365 L .4076 .55105 L F
.505 .305 .542 r
.4076 .55105 m .40762 .55365 L .41034 .55104 L F
.667 .15 .001 r
.41203 .47436 m .41377 .4761 L .41076 .4754 L F
.566 .194 .295 r
.41522 .4744 m .41377 .4761 L .41203 .47436 L F
.654 .65 .834 r
.59768 .3639 m .59577 .36624 L .59351 .36137 L F
0 0 .031 r
.59768 .3639 m .59744 .36694 L .59577 .36624 L F
.737 .7 .162 r
.50563 .43593 m .50569 .43598 L .50603 .43345 L F
0 0 0 r
.50318 .43991 m .50569 .43598 L .50521 .43856 L F
.737 .7 .162 r
.50521 .43856 m .50569 .43598 L .50563 .43593 L F
.594 .851 .498 r
.50423 .43795 m .50578 .43607 L .50569 .43598 L F
.50578 .43607 m .50696 .43463 L .50569 .43598 L F
0 0 0 r
.50318 .43991 m .50423 .43795 L .50569 .43598 L F
.646 .965 .815 r
.46172 .43988 m .46588 .43759 L .46404 .43833 L F
.622 .942 .736 r
.46588 .43759 m .46915 .435 L .46715 .43592 L F
.622 .946 .749 r
.46404 .43833 m .46588 .43759 L .46715 .43592 L F
.571 .577 .82 r
.49879 .41416 m .50131 .41736 L .50276 .41551 L F
.951 .631 .384 r
.56248 .38456 m .5624 .38652 L .56065 .38327 L F
.78 .986 .898 r
.4994 .40109 m .50028 .39861 L .50284 .39825 L F
.4994 .40109 m .49853 .40036 L .50028 .39861 L F
.851 .833 .828 r
.61397 .38997 m .61605 .39198 L .6186 .38847 L F
.202 .001 .368 r
.61781 .39112 m .61605 .39198 L .61581 .39421 L F
.4 .014 .187 r
.39391 .46703 m .39817 .46411 L .39565 .46476 L F
.755 .252 .023 r
.38942 .51686 m .39172 .51944 L .39377 .51909 L F
0 0 0 r
.35046 .66299 m .34899 .66402 L .35111 .66043 L F
.34744 .66614 m .34899 .66402 L .35046 .66299 L F
.872 .457 .229 r
.6615 .35698 m .65843 .35406 L .66206 .35459 L F
.934 .596 .157 r
.58579 .4054 m .58647 .40493 L .58635 .40697 L F
.58498 .40312 m .58582 .40547 L .58547 .40578 L F
.58582 .40547 m .58635 .40697 L .58547 .40578 L F
.72 .915 .56 r
.58418 .4069 m .58547 .40578 L .58412 .407 L F
.934 .596 .157 r
.58498 .40312 m .5861 .40449 L .58579 .4054 L F
0 0 .357 r
.58498 .40312 m .58547 .40578 L .58638 .40349 L F
.72 .915 .56 r
.58638 .40349 m .58547 .40578 L .58418 .4069 L F
.73 .771 .886 r
.58635 .40697 m .5894 .40623 L .58547 .40578 L F
.278 .385 .793 r
.58873 .40766 m .58563 .40587 L .5894 .40623 L F
.58563 .40587 m .58547 .40578 L .58566 .4058 L F
.58563 .40587 m .58566 .4058 L .5894 .40623 L F
.934 .596 .157 r
.5861 .40449 m .58647 .40493 L .58579 .4054 L F
.823 .673 .697 r
.5257 .39703 m .5296 .39845 L .5282 .3962 L F
.5257 .39703 m .52514 .39959 L .5296 .39845 L F
.786 .544 .571 r
.52514 .39959 m .52703 .4011 L .5296 .39845 L F
.576 .774 .973 r
.5282 .3962 m .5296 .39845 L .53206 .39604 L F
.752 .993 .811 r
.51031 .48167 m .51147 .4794 L .5122 .48012 L F
.51031 .48167 m .50823 .48228 L .51147 .4794 L F
.625 .857 .986 r
.30794 .63225 m .30787 .63415 L .30611 .63334 L F
.30794 .63225 m .31038 .63324 L .30787 .63415 L F
.573 .351 .541 r
.27619 .54721 m .27553 .55208 L .27208 .55022 L F
.456 .272 .541 r
.27446 .55343 m .27208 .55022 L .27553 .55208 L F
.27446 .55343 m .2725 .55519 L .27208 .55022 L F
.977 .681 .381 r
.37672 .58434 m .37471 .58363 L .37442 .58011 L F
.415 .835 .964 r
.37747 .58326 m .37471 .58363 L .37672 .58434 L F
.411 .092 .312 r
.39114 .56015 m .39403 .55755 L .39234 .5584 L F
.39235 .55906 m .39389 .55952 L .39403 .55755 L F
.39114 .56015 m .39267 .5598 L .39235 .55906 L F
.39267 .5598 m .39389 .55952 L .39235 .55906 L F
0 0 0 r
.39234 .5584 m .39195 .55954 L .39215 .55939 L F
.39234 .5584 m .39198 .55893 L .39195 .55954 L F
.39226 .55883 m .39215 .55939 L .39201 .55825 L F
.568 .713 .939 r
.39215 .55939 m .39267 .5598 L .39114 .56015 L F
0 0 0 r
.39215 .55939 m .39195 .55954 L .3919 .56066 L F
.914 .799 .719 r
.39166 .56095 m .39173 .56115 L .39193 .56063 L F
0 0 0 r
.3919 .56065 m .3919 .56066 L .3919 .56068 L F
.39215 .55939 m .3919 .56066 L .3919 .56065 L F
.39215 .55939 m .3919 .56065 L .39196 .55925 L F
.3919 .56065 m .3919 .56068 L .3919 .56065 L F
.3919 .56065 m .3919 .56065 L .39196 .55925 L F
.39215 .55939 m .39196 .55925 L .39201 .55825 L F
.141 .619 .921 r
.3927 .5585 m .39389 .55952 L .39142 .55883 L F
.39085 .55853 m .39142 .55883 L .39037 .55854 L F
0 0 0 r
.39201 .55825 m .392 .55845 L .38985 .55755 L F
.392 .55845 m .39095 .55837 L .38985 .55755 L F
.39201 .55825 m .38985 .55755 L .38983 .55752 L F
.38961 .55718 m .38983 .55752 L .38959 .55717 L F
.39201 .55825 m .38983 .55752 L .38961 .55718 L F
.23 .488 .894 r
.39064 .55834 m .39037 .55854 L .39038 .55832 L F
0 0 0 r
.39197 .55912 m .39146 .55885 L .38976 .55752 L F
.38957 .55734 m .38976 .55752 L .38895 .55688 L F
.39197 .55912 m .38976 .55752 L .38957 .55734 L F
.23 .488 .894 r
.39064 .55834 m .39085 .55853 L .39037 .55854 L F
0 0 .465 r
.39037 .55854 m .38983 .55752 L .39038 .55832 L F
.568 .713 .939 r
.39037 .55854 m .39142 .55883 L .39115 .56009 L F
.39037 .55854 m .39115 .56009 L .39114 .56015 L F
.39142 .55883 m .39215 .55939 L .39114 .56015 L F
0 0 .465 r
.39037 .55854 m .39188 .56064 L .38995 .55771 L F
.39037 .55854 m .38995 .55771 L .38983 .55752 L F
.39188 .56064 m .39187 .56063 L .38983 .55752 L F
0 0 0 r
.39196 .55925 m .3919 .56065 L .38905 .55701 L F
.914 .799 .719 r
.39166 .56095 m .3919 .56065 L .39181 .56059 L F
0 0 .465 r
.39188 .56064 m .3919 .56068 L .39187 .56063 L F
0 0 0 r
.3919 .56065 m .3919 .56068 L .39186 .56062 L F
.3913 .55991 m .39114 .56015 L .3919 .56068 L F
.568 .713 .939 r
.39037 .55854 m .39114 .56015 L .39189 .56067 L F
.39188 .56064 m .39189 .56067 L .3919 .56068 L F
.39037 .55854 m .39189 .56067 L .39188 .56064 L F
.914 .799 .719 r
.39144 .56038 m .39181 .56059 L .39183 .56055 L F
.39161 .56012 m .39183 .56055 L .3927 .5585 L F
.39144 .56038 m .39183 .56055 L .39161 .56012 L F
.915 .799 .717 r
.39144 .56038 m .3895 .56055 L .39173 .56115 L F
0 0 0 r
.3919 .56065 m .39186 .56062 L .38905 .55701 L F
.3919 .56065 m .39186 .56062 L .39186 .56062 L F
.39196 .55925 m .38905 .55701 L .38895 .55688 L F
.954 .851 .702 r
.39159 .55347 m .38926 .55648 L .39234 .5584 L F
.38926 .55648 m .38926 .5565 L .39234 .5584 L F
.38925 .55649 m .38959 .55717 L .39234 .5584 L F
.948 .832 .696 r
.38856 .55513 m .38895 .55688 L .39159 .55347 L F
0 0 .465 r
.39038 .55832 m .38868 .55534 L .39039 .55817 L F
.38868 .55534 m .38865 .55528 L .39039 .55817 L F
.38983 .55752 m .38856 .55513 L .39038 .55832 L F
.38983 .55752 m .39187 .56063 L .38864 .55525 L F
.38868 .55534 m .38856 .55513 L .38865 .55528 L F
.3888 .55557 m .38864 .55525 L .38856 .55513 L F
.38983 .55752 m .38864 .55525 L .3888 .55557 L F
.954 .851 .702 r
.38926 .55648 m .38925 .55649 L .38926 .5565 L F
.38925 .55649 m .38895 .55688 L .38959 .55717 L F
0 0 .465 r
.39039 .55817 m .38856 .55513 L .39041 .55762 L F
.39187 .56063 m .3919 .56068 L .39185 .5606 L F
.39187 .56063 m .39185 .5606 L .38856 .55513 L F
.914 .799 .719 r
.39183 .56055 m .39193 .56063 L .3927 .5585 L F
0 0 0 r
.38959 .55717 m .38985 .55755 L .38895 .55688 L F
.08 .24 .729 r
.38856 .55513 m .39185 .5606 L .38895 .55688 L F
.914 .799 .719 r
.39185 .56061 m .39186 .56061 L .39185 .5606 L F
.08 .24 .729 r
.39185 .5606 m .3919 .56068 L .39186 .56062 L F
.39185 .5606 m .39186 .56062 L .38895 .55688 L F
.914 .799 .719 r
.39181 .56059 m .39185 .56061 L .39183 .56055 L F
.39185 .56061 m .39185 .5606 L .39183 .56055 L F
.39186 .56061 m .39193 .56063 L .39183 .56055 L F
.23 .488 .894 r
.39064 .55834 m .39038 .55832 L .39041 .55762 L F
.915 .799 .717 r
.39041 .55762 m .38985 .55942 L .39144 .56038 L F
.38985 .55942 m .3895 .56055 L .39144 .56038 L F
0 0 0 r
.3919 .56065 m .39186 .56062 L .3919 .56065 L F
.914 .799 .719 r
.3919 .56065 m .39193 .56063 L .39181 .56059 L F
0 0 0 r
.39234 .5584 m .39226 .55883 L .39201 .55825 L F
.954 .851 .702 r
.39159 .55347 m .39234 .5584 L .39403 .55755 L F
.23 .488 .894 r
.39293 .55664 m .3927 .5585 L .39085 .55853 L F
.39293 .55664 m .39085 .55853 L .39064 .55834 L F
.39293 .55664 m .39064 .55834 L .39041 .55762 L F
.914 .799 .719 r
.39041 .55762 m .39072 .55844 L .3927 .5585 L F
.39072 .55844 m .39144 .56038 L .39161 .56013 L F
0 0 0 r
.392 .55845 m .39197 .55912 L .39095 .55837 L F
.141 .619 .921 r
.3927 .5585 m .39142 .55883 L .39085 .55853 L F
0 0 0 r
.39197 .55912 m .39196 .55925 L .39146 .55885 L F
.568 .713 .939 r
.39142 .55883 m .39249 .55913 L .39215 .55939 L F
.914 .799 .719 r
.39072 .55844 m .39161 .56013 L .3927 .5585 L F
.39144 .56038 m .39166 .56095 L .39181 .56059 L F
.568 .713 .939 r
.39249 .55913 m .39389 .55952 L .39267 .5598 L F
.39249 .55913 m .39267 .5598 L .39215 .55939 L F
.356 .424 .795 r
.35411 .65049 m .35276 .65164 L .35142 .647 L F
.265 .27 .678 r
.35518 .65302 m .35276 .65164 L .35411 .65049 L F
.777 .286 0 r
.40087 .59424 m .40082 .59555 L .39864 .59317 L F
.40087 .59424 m .40254 .59674 L .40082 .59555 L F
.936 .876 .752 r
.65762 .39465 m .65797 .3901 L .65552 .39371 L F
.755 .933 .586 r
.6556 .39357 m .65552 .39371 L .65568 .39348 L F
.656 .81 .957 r
.6556 .39357 m .65762 .39465 L .65552 .39371 L F
.907 .598 .448 r
.6546 .39574 m .65762 .39465 L .6556 .39357 L F
.656 .81 .957 r
.65522 .39336 m .6556 .39357 L .65552 .39371 L F
.573 .896 .637 r
.65552 .39371 m .65282 .3957 L .6546 .39574 L F
.65552 .39371 m .6546 .39574 L .65504 .39404 L F
.65552 .39371 m .65504 .39404 L .65522 .39336 L F
.65552 .39371 m .6547 .39401 L .65352 .39508 L F
.65552 .39371 m .65352 .39508 L .65282 .3957 L F
.907 .598 .448 r
.655 .39421 m .65558 .39359 L .65522 .39336 L F
.65558 .39359 m .6556 .39357 L .65522 .39336 L F
.748 .921 .559 r
.6569 .39069 m .6547 .39401 L .65545 .39374 L F
.65558 .39359 m .65545 .39374 L .65552 .39371 L F
.6569 .39069 m .65545 .39374 L .65558 .39359 L F
.907 .598 .448 r
.65558 .39359 m .6556 .39357 L .6556 .39357 L F
.6546 .39574 m .6556 .39357 L .655 .39421 L F
.755 .933 .586 r
.65716 .39055 m .6556 .39357 L .65797 .3901 L F
.6556 .39357 m .65568 .39348 L .65797 .3901 L F
.6569 .39069 m .65552 .39371 L .65716 .39055 L F
.45 .88 .803 r
.6563 .3953 m .6546 .39574 L .65155 .39745 L F
.894 .532 .348 r
.6563 .3953 m .6578 .39718 L .6546 .39574 L F
.907 .598 .448 r
.6546 .39574 m .6578 .39718 L .65762 .39465 L F
.672 .548 .705 r
.65915 .38477 m .65787 .38785 L .65616 .388 L F
.136 0 0 r
.65616 .388 m .65734 .38855 L .65797 .3901 L F
.65616 .388 m .65787 .38785 L .65734 .38855 L F
.794 .712 .774 r
.50891 .45095 m .51124 .45446 L .50725 .453 L F
.76 .582 .656 r
.51092 .45673 m .50725 .453 L .51124 .45446 L F
.563 .628 .875 r
.51396 .45379 m .51124 .45446 L .50891 .45095 L F
.303 .067 .38 r
.51271 .45589 m .51124 .45446 L .51396 .45379 L F
.51271 .45589 m .51092 .45673 L .51124 .45446 L F
.751 .744 .846 r
.5104 .45206 m .51124 .45446 L .50725 .453 L F
.774 .804 .877 r
.31766 .63117 m .31467 .63391 L .31288 .63269 L F
.783 .643 .708 r
.33034 .59724 m .33468 .59766 L .33296 .59371 L F
.735 .623 .734 r
.33468 .59766 m .3374 .59431 L .33296 .59371 L F
.726 .522 .614 r
.54044 .40108 m .53772 .40397 L .53842 .40134 L F
.54044 .40108 m .54246 .40447 L .53772 .40397 L F
.16 .608 .934 r
.2966 .61612 m .30089 .61779 L .29902 .61673 L F
.715 .982 .901 r
.30153 .61598 m .30089 .61779 L .30341 .6159 L F
.543 .841 .999 r
.29902 .61673 m .30089 .61779 L .30153 .61598 L F
.857 .709 .697 r
.68308 .35678 m .6871 .35475 L .68305 .35399 L F
.68308 .35678 m .68659 .35772 L .6871 .35475 L F
0 0 0 r
.5685 .4004 m .5655 .40396 L .56783 .40113 L F
.041 0 0 r
.57098 .4003 m .5685 .4004 L .56783 .40113 L F
.57098 .4003 m .57216 .39962 L .5685 .4004 L F
.862 .87 .844 r
.43816 .57827 m .4338 .58027 L .43462 .57749 L F
.626 .577 .779 r
.31898 .5606 m .31661 .56183 L .31487 .55732 L F
.679 .901 .975 r
.31511 .56076 m .31661 .56183 L .31898 .5606 L F
.888 .988 .797 r
.48853 .51625 m .48589 .51968 L .48634 .52073 L F
0 0 .276 r
.59588 .37772 m .59621 .37957 L .59546 .38081 L F
.624 .832 .434 r
.59621 .37957 m .59444 .38219 L .59546 .38081 L F
.709 .717 .856 r
.28737 .63841 m .2843 .6413 L .28269 .6373 L F
0 .345 .77 r
.30808 .65507 m .31027 .65599 L .311 .65694 L F
.929 .547 .185 r
.30998 .65898 m .311 .65694 L .31027 .65599 L F
.30998 .65898 m .31154 .66088 L .311 .65694 L F
0 0 .371 r
.57392 .38097 m .57517 .38331 L .57577 .38462 L F
.935 .567 .176 r
.57484 .38582 m .57577 .38462 L .57517 .38331 L F
.57484 .38582 m .57628 .38727 L .57577 .38462 L F
.92 .729 .628 r
.33645 .58282 m .33852 .58427 L .33687 .58041 L F
.782 .645 .711 r
.33459 .58717 m .33852 .58427 L .33645 .58282 L F
.33459 .58717 m .33594 .58771 L .33852 .58427 L F
0 0 0 r
.28792 .52252 m .28691 .52712 L .28631 .52366 L F
.601 .087 0 r
.52109 .37378 m .52288 .37414 L .52108 .37284 L F
0 0 0 r
.50569 .43598 m .50696 .43463 L .50867 .4332 L F
.89 .94 .839 r
.48853 .51625 m .49254 .51396 L .49109 .51281 L F
.872 .92 .856 r
.49398 .50957 m .49254 .51396 L .49569 .51099 L F
.49398 .50957 m .49109 .51281 L .49254 .51396 L F
0 0 0 r
.39222 .57245 m .39244 .57148 L .39197 .5696 L F
.39222 .57245 m .39149 .57445 L .39244 .57148 L F
.652 .811 .959 r
.60857 .39183 m .61124 .39072 L .60717 .39014 L F
.471 .288 .551 r
.26323 .54384 m .26574 .54036 L .26312 .54089 L F
.632 .732 .92 r
.43541 .5851 m .43962 .58675 L .43785 .58413 L F
.559 .706 .939 r
.43785 .58413 m .43962 .58675 L .44212 .58601 L F
.66 .943 .961 r
.52014 .47057 m .51876 .47094 L .51949 .46916 L F
.882 .678 .157 r
.52014 .47057 m .51949 .46916 L .51945 .46645 L F
.801 .797 .849 r
.52306 .46648 m .52014 .47057 L .51945 .46645 L F
.882 .678 .157 r
.52014 .47057 m .51949 .46916 L .51945 .46645 L F
.114 0 0 r
.28732 .65677 m .28515 .65664 L .28371 .65688 L F
0 0 .259 r
.27713 .54871 m .27619 .54721 L .27791 .54789 L F
.27713 .54871 m .27553 .55208 L .27619 .54721 L F
.83 .803 .825 r
.44212 .58601 m .44633 .5845 L .44153 .58518 L F
.626 .62 .825 r
.52332 .40061 m .52381 .40353 L .52703 .4011 L F
.429 .122 .341 r
.26143 .57322 m .25969 .57152 L .26171 .57029 L F
.26143 .57322 m .25893 .57389 L .25969 .57152 L F
.448 .306 .594 r
.26091 .54758 m .26302 .54678 L .26323 .54384 L F
.422 .215 .491 r
.26043 .55023 m .26302 .54678 L .26091 .54758 L F
.725 .743 .866 r
.32049 .5868 m .3195 .59037 L .3184 .58971 L F
.988 .725 .426 r
.3195 .59037 m .31988 .59402 L .3184 .58971 L F
.195 0 .278 r
.25533 .58299 m .25417 .58669 L .25179 .58732 L F
.175 0 .269 r
.25417 .58669 m .25014 .59001 L .25179 .58732 L F
.497 .289 .527 r
.26574 .54036 m .2685 .53699 L .26582 .53754 L F
.54 .559 .823 r
.54335 .41389 m .5448 .41789 L .54742 .41727 L F
.677 .954 .708 r
.27338 .65524 m .27114 .65754 L .27192 .65606 L F
.051 .301 .789 r
.27114 .65754 m .27391 .65966 L .27192 .65606 L F
.442 .332 .633 r
.27114 .65754 m .27149 .65992 L .27391 .65966 L F
.621 .942 .736 r
.46715 .43592 m .46915 .435 L .47091 .43339 L F
.949 .793 .34 r
.54917 .40675 m .54911 .4103 L .54621 .4107 L F
.857 .409 .019 r
.67849 .34771 m .68176 .35053 L .67949 .34761 L F
.944 .782 .652 r
.67758 .35202 m .68176 .35053 L .67849 .34771 L F
.67758 .35202 m .67926 .35327 L .68176 .35053 L F
.733 .989 .805 r
.62758 .3838 m .62382 .38624 L .62604 .38529 L F
.096 0 0 r
.63042 .3832 m .62758 .3838 L .62604 .38529 L F
.63042 .3832 m .62604 .38529 L .62885 .38467 L F
.535 .828 .999 r
.62752 .38323 m .62846 .38425 L .62604 .38529 L F
.62846 .38425 m .62885 .38467 L .62604 .38529 L F
.733 .989 .805 r
.62382 .38624 m .62348 .38646 L .62604 .38529 L F
.598 .936 .948 r
.62652 .39585 m .62487 .39531 L .62302 .39723 L F
.599 .946 .795 r
.62487 .39531 m .62276 .39692 L .62302 .39723 L F
.648 .469 .628 r
.61393 .35349 m .619 .3506 L .61603 .35139 L F
.61393 .35349 m .62048 .35118 L .619 .3506 L F
.61393 .35349 m .6195 .35336 L .62048 .35118 L F
.652 .505 .67 r
.61393 .35349 m .61817 .35521 L .6195 .35336 L F
.44 0 0 r
.65674 .34479 m .65555 .34582 L .65272 .34483 L F
.684 .164 0 r
.65879 .34639 m .65555 .34582 L .65674 .34479 L F
0 0 0 r
.4348 .44634 m .4365 .44507 L .43304 .44712 L F
.43878 .44385 m .4365 .44507 L .4348 .44634 L F
.866 .848 .824 r
.42595 .59317 m .42818 .59441 L .43164 .59119 L F
.655 .784 .943 r
.42945 .58878 m .43164 .59119 L .43197 .5901 L F
.916 .748 .658 r
.57496 .43075 m .57589 .42847 L .57353 .42676 L F
.57353 .42676 m .57589 .42847 L .57496 .43075 L F
.357 .831 .839 r
.29014 .65345 m .29062 .65347 L .28807 .65417 L F
.795 .738 .8 r
.58427 .41099 m .58565 .41454 L .58338 .41252 L F
.684 .17 0 r
.58338 .41252 m .58565 .41454 L .58567 .41548 L F
.561 .612 .861 r
.5879 .41383 m .58565 .41454 L .58427 .41099 L F
.86 .563 .035 r
.5879 .41383 m .58567 .41548 L .58565 .41454 L F
.176 .711 .754 r
.43811 .55047 m .44242 .54984 L .43962 .55163 L F
.888 .913 .837 r
.43962 .55163 m .43686 .5522 L .43811 .55047 L F
.986 .767 .524 r
.3633 .53014 m .36232 .53029 L .36288 .52738 L F
.868 .622 .564 r
.36496 .53379 m .36232 .53029 L .3633 .53014 L F
.249 .762 .822 r
.44216 .56611 m .44021 .56613 L .43672 .56687 L F
.888 .991 .766 r
.44216 .56611 m .44117 .56512 L .44021 .56613 L F
0 0 0 r
.42605 .45209 m .42979 .45014 L .42749 .45101 L F
.881 .911 .844 r
.53142 .4429 m .53328 .44459 L .53019 .44752 L F
.525 .264 .462 r
.53019 .44752 m .53328 .44459 L .53307 .44708 L F
.479 .182 .383 r
.53328 .44459 m .53563 .44612 L .53307 .44708 L F
.53328 .44459 m .53654 .44404 L .53563 .44612 L F
.967 .646 .339 r
.67608 .34161 m .67732 .34421 L .67754 .34143 L F
.56 .061 0 r
.50789 .42888 m .50858 .42948 L .50735 .42831 L F
.878 .901 .842 r
.50954 .43116 m .50913 .42997 L .50858 .42948 L F
.50954 .43116 m .51105 .42629 L .50798 .42659 L F
.50954 .43116 m .51226 .42792 L .51105 .42629 L F
.955 .691 .243 r
.50867 .4332 m .50858 .42948 L .51068 .4318 L F
.56 .061 0 r
.51068 .4318 m .50858 .42948 L .50789 .42888 L F
.878 .901 .842 r
.50913 .42997 m .50798 .42659 L .50858 .42948 L F
.76 .744 .838 r
.34605 .62103 m .34724 .62428 L .34299 .62387 L F
.821 .773 .808 r
.34927 .621 m .34724 .62428 L .34605 .62103 L F
.234 .316 .744 r
.57294 .35723 m .57397 .36133 L .57564 .35897 L F
.337 .459 .837 r
.57397 .36133 m .57785 .36323 L .57564 .35897 L F
0 0 .321 r
.51941 .38629 m .51831 .38765 L .51934 .38421 L F
.768 .442 .434 r
.51831 .38765 m .51757 .3902 L .52151 .39036 L F
0 0 .039 r
.51941 .38629 m .51757 .3902 L .51831 .38765 L F
.663 .852 .972 r
.62228 .39141 m .61781 .39112 L .62114 .3904 L F
0 0 .394 r
.62297 .38856 m .62228 .39141 L .62254 .38902 L F
.932 .952 .773 r
.62276 .38708 m .62228 .39141 L .62114 .3904 L F
0 0 0 r
.62122 .39042 m .62007 .39243 L .62263 .39081 L F
.62114 .3904 m .62102 .39064 L .62122 .39042 L F
.62102 .39064 m .62007 .39243 L .62122 .39042 L F
0 0 .394 r
.62348 .38646 m .62297 .38856 L .62276 .38708 L F
.62297 .38856 m .62254 .38902 L .62276 .38708 L F
.578 .137 .166 r
.65022 .3442 m .64883 .34625 L .64583 .34569 L F
.532 .07 .102 r
.65272 .34483 m .64883 .34625 L .65022 .3442 L F
.737 .823 .362 r
.65836 .38611 m .65787 .38785 L .65915 .38477 L F
.729 .807 .335 r
.65734 .38855 m .65787 .38785 L .65836 .38611 L F
.382 0 .152 r
.37229 .47188 m .37499 .47285 L .3746 .47189 L F
.864 .682 .655 r
.68308 .35678 m .68477 .36085 L .68659 .35772 L F
.667 .612 .784 r
.59601 .35077 m .59977 .35206 L .59841 .35011 L F
.59977 .35206 m .59601 .35077 L .59841 .35011 L F
.774 .295 0 r
.27516 .67005 m .27857 .67428 L .27697 .67253 L F
0 0 .428 r
.27516 .67005 m .27697 .67253 L .27474 .66941 L F
.595 .298 .435 r
.27253 .64723 m .27537 .6474 L .27486 .64975 L F
.082 .211 .699 r
.27253 .64723 m .27486 .64975 L .27282 .64657 L F
.744 .399 .397 r
.66522 .33382 m .66782 .33671 L .66958 .33434 L F
.801 .476 .438 r
.66958 .33434 m .66782 .33671 L .67154 .33734 L F
.866 .617 .561 r
.37074 .54095 m .36802 .54288 L .3671 .54012 L F
.37074 .54095 m .37053 .54374 L .36802 .54288 L F
.7 .726 .87 r
.53822 .43737 m .53585 .43892 L .5342 .43666 L F
.426 .443 .774 r
.5386 .44044 m .53585 .43892 L .53822 .43737 L F
.669 .465 .599 r
.33169 .56762 m .33126 .57044 L .32915 .57038 L F
.746 .721 .828 r
.37974 .47314 m .37932 .47078 L .37769 .47338 L F
.998 .849 .533 r
.40423 .57408 m .40259 .57248 L .40371 .57017 L F
.866 .719 .697 r
.40423 .57408 m .40095 .57653 L .40259 .57248 L F
0 .411 .775 r
.39578 .57417 m .39733 .57478 L .40095 .57653 L F
.866 .719 .697 r
.40423 .57408 m .40257 .57731 L .40095 .57653 L F
0 .155 .685 r
.40253 .57264 m .40197 .575 L .40259 .57248 L F
.40095 .57653 m .40197 .575 L .40253 .57264 L F
.40095 .57653 m .40278 .57691 L .40197 .575 L F
0 .411 .775 r
.39733 .57478 m .40269 .57688 L .40095 .57653 L F
.40269 .57688 m .40278 .57691 L .40273 .5769 L F
.40269 .57688 m .40273 .5769 L .40095 .57653 L F
.866 .719 .697 r
.40257 .57731 m .40255 .57734 L .40095 .57653 L F
.063 .51 .895 r
.39758 .57376 m .40271 .57687 L .39578 .57417 L F
.40271 .57687 m .40278 .57691 L .40239 .57676 L F
.40271 .57687 m .40239 .57676 L .39578 .57417 L F
.863 .926 .867 r
.40267 .57685 m .40457 .57461 L .40197 .575 L F
.40322 .57833 m .40364 .57719 L .40267 .57685 L F
.40364 .57719 m .40457 .57461 L .40267 .57685 L F
.979 .684 .362 r
.40322 .57833 m .40168 .5773 L .4018 .57635 L F
.40267 .57686 m .40264 .57684 L .40197 .575 L F
.842 .676 .677 r
.40197 .575 m .40278 .57691 L .40263 .57682 L F
.40197 .575 m .40263 .57682 L .39758 .57376 L F
.979 .684 .362 r
.40264 .57684 m .4018 .57635 L .40197 .575 L F
.40322 .57833 m .4018 .57635 L .40267 .57686 L F
.425 .732 .99 r
.40095 .57653 m .39961 .57717 L .39817 .57675 L F
.40095 .57653 m .40255 .57734 L .39961 .57717 L F
0 .411 .775 r
.39578 .57417 m .40095 .57653 L .39817 .57675 L F
.722 .195 0 r
.39758 .57376 m .40147 .57712 L .40197 .575 L F
.40147 .57712 m .40168 .5773 L .40197 .575 L F
.388 .825 .953 r
.63368 .38327 m .63042 .3832 L .63351 .38369 L F
.437 .836 .979 r
.39561 .57736 m .39817 .57675 L .39961 .57717 L F
.525 .721 .963 r
.27697 .67253 m .27857 .67428 L .28037 .67178 L F
.504 .598 .881 r
.49436 .44166 m .49895 .44493 L .49816 .44271 L F
.767 .997 .829 r
.4998 .44291 m .49895 .44493 L .50057 .44336 L F
.221 .412 .839 r
.49816 .44271 m .49895 .44493 L .4998 .44291 L F
.867 .99 .827 r
.46215 .54529 m .46203 .54747 L .46404 .54584 L F
.46215 .54529 m .46104 .54676 L .46203 .54747 L F
.808 .583 .598 r
.48326 .50102 m .4789 .50317 L .48131 .49952 L F
.48326 .50102 m .48317 .50387 L .4789 .50317 L F
.211 .337 .774 r
.41141 .59652 m .41171 .59464 L .40958 .59469 L F
.912 .53 .279 r
.32896 .55419 m .32683 .55323 L .32679 .55126 L F
.991 .734 .417 r
.32896 .55419 m .32755 .55648 L .32683 .55323 L F
.32896 .55419 m .32902 .55734 L .32755 .55648 L F
.999 .831 .54 r
.56016 .43234 m .56102 .4311 L .5597 .42947 L F
.819 .959 .903 r
.56102 .4311 m .56211 .42854 L .5597 .42947 L F
.56102 .4311 m .56441 .42801 L .56211 .42854 L F
.913 .741 .654 r
.33864 .56328 m .34094 .56421 L .33934 .56031 L F
.881 .737 .699 r
.33864 .56328 m .34025 .56718 L .34094 .56421 L F
.946 .708 .547 r
.56253 .364 m .56118 .36359 L .56154 .3612 L F
.704 .207 0 r
.56372 .36658 m .56118 .36359 L .56253 .364 L F
.864 .698 .675 r
.39644 .55337 m .40057 .55449 L .40053 .55197 L F
.587 .741 .949 r
.40208 .54855 m .40053 .55197 L .40336 .55123 L F
.655 .688 .869 r
.42029 .59664 m .42515 .59838 L .42252 .5944 L F
.629 .646 .848 r
.42515 .59838 m .42595 .59317 L .42252 .5944 L F
.42515 .59838 m .42702 .59684 L .42595 .59317 L F
.654 .142 .012 r
.34634 .50551 m .34884 .50432 L .348 .50247 L F
.34634 .50551 m .35091 .50644 L .34884 .50432 L F
.348 .174 .498 r
.34884 .50432 m .35091 .50644 L .35096 .50357 L F
.429 .045 .207 r
.5042 .45374 m .50299 .45642 L .50024 .45672 L F
.748 .378 .353 r
.50699 .45679 m .5042 .45374 L .50725 .453 L F
.50699 .45679 m .50299 .45642 L .5042 .45374 L F
0 0 0 r
.43134 .44876 m .4348 .44634 L .43304 .44712 L F
.42979 .45014 m .43134 .44876 L .43304 .44712 L F
.87 .966 .857 r
.51398 .49243 m .51359 .49526 L .51543 .49334 L F
.51398 .49243 m .5109 .49569 L .51359 .49526 L F
0 .158 .664 r
.51278 .42458 m .51503 .4271 L .51294 .42531 L F
.887 .682 .62 r
.3364 .53024 m .33598 .53312 L .33952 .53332 L F
.913 .667 .553 r
.33598 .53569 m .33952 .53332 L .33598 .53312 L F
.33598 .53569 m .33863 .53672 L .33952 .53332 L F
0 .268 .774 r
.4148 .54985 m .41433 .55121 L .41274 .54988 L F
.589 .015 0 r
.41433 .55121 m .41688 .55309 L .41681 .5528 L F
0 .268 .774 r
.4148 .54985 m .41688 .55309 L .41433 .55121 L F
.723 .712 .84 r
.55917 .34773 m .56093 .35168 L .55831 .35072 L F
.496 .588 .876 r
.56323 .34916 m .56093 .35168 L .55917 .34773 L F
.437 .495 .822 r
.56323 .34916 m .56467 .35316 L .56093 .35168 L F
.577 .73 .947 r
.29714 .65026 m .29819 .64662 L .29555 .64645 L F
.29714 .65026 m .30094 .64973 L .29819 .64662 L F
.801 .937 .919 r
.52452 .48438 m .52751 .48385 L .52606 .48282 L F
.772 .905 .933 r
.52606 .48282 m .52751 .48385 L .53112 .4814 L F
.596 .765 .96 r
.6012 .34939 m .59977 .35206 L .59841 .35011 L F
.6012 .34939 m .60285 .35127 L .59977 .35206 L F
.6012 .34939 m .59977 .35206 L .59841 .35011 L F
.6012 .34939 m .60285 .35127 L .59977 .35206 L F
.613 .636 .849 r
.60352 .35344 m .59977 .35206 L .60285 .35127 L F
0 0 .062 r
.58383 .39115 m .58402 .39196 L .5846 .38879 L F
.58383 .39115 m .58369 .39394 L .58402 .39196 L F
.479 .611 .904 r
.35408 .62411 m .34927 .621 L .35238 .62301 L F
.976 .814 .616 r
.35319 .62644 m .35408 .62411 L .35238 .62301 L F
0 0 0 r
.35111 .66043 m .35361 .65697 L .35241 .65914 L F
.35046 .66299 m .35111 .66043 L .35241 .65914 L F
.861 .727 .713 r
.61581 .39421 m .61711 .39759 L .61502 .39663 L F
.029 .58 .829 r
.61711 .39759 m .61799 .39733 L .61502 .39663 L F
.61711 .39759 m .62062 .3982 L .61799 .39733 L F
.851 .833 .828 r
.61397 .38997 m .6186 .38847 L .61393 .38758 L F
.703 .355 .384 r
.39687 .55617 m .40057 .55449 L .39644 .55337 L F
.39687 .55617 m .39967 .55611 L .40057 .55449 L F
.668 .723 .89 r
.40361 .58429 m .40766 .58456 L .40585 .58114 L F
.815 .599 .611 r
.40392 .58615 m .40766 .58456 L .40361 .58429 L F
.357 .546 .902 r
.40585 .58114 m .40766 .58456 L .4078 .58321 L F
.807 .532 .523 r
.4109 .58686 m .4078 .58321 L .40766 .58456 L F
.637 .868 .985 r
.46187 .53348 m .45912 .53416 L .45752 .53293 L F
.805 .759 .811 r
.27327 .64511 m .27575 .64616 L .27632 .63967 L F
.413 0 0 r
.27282 .64657 m .27575 .64616 L .27327 .64511 L F
.27282 .64657 m .27785 .64686 L .27575 .64616 L F
.795 .952 .921 r
.28034 .6462 m .28147 .64331 L .27733 .64261 L F
.32 0 0 r
.27733 .64261 m .28147 .64331 L .27891 .64337 L F
.27733 .64261 m .27891 .64337 L .27798 .64242 L F
0 0 .344 r
.27632 .63967 m .27603 .64298 L .27733 .64261 L F
0 0 .356 r
.27758 .63904 m .27632 .63967 L .27733 .64261 L F
.27758 .63904 m .27733 .64261 L .2741 .64141 L F
.32 0 0 r
.27733 .64261 m .27798 .64242 L .27622 .64061 L F
0 0 .344 r
.27603 .64298 m .27575 .64616 L .27733 .64261 L F
.572 .706 .932 r
.27785 .64686 m .27733 .64261 L .27575 .64616 L F
.483 .267 .51 r
.2685 .53699 m .27115 .53384 L .26833 .53413 L F
.813 .567 .567 r
.32494 .51296 m .32931 .51095 L .32504 .51038 L F
.32494 .51296 m .32912 .51374 L .32931 .51095 L F
.887 .711 .657 r
.27795 .66038 m .27974 .66416 L .27767 .66193 L F
.762 .764 .854 r
.32527 .5837 m .32304 .58614 L .32197 .58312 L F
.605 .887 .576 r
.32527 .5837 m .32409 .58467 L .32304 .58614 L F
.863 .793 .78 r
.32409 .58467 m .3241 .58471 L .32304 .58614 L F
.812 .778 .821 r
.32439 .58704 m .32245 .58692 L .32304 .58614 L F
.835 .97 .886 r
.32439 .58704 m .325 .58473 L .32637 .58235 L F
.325 .58473 m .32527 .5837 L .3259 .58293 L F
.325 .58473 m .3259 .58293 L .32637 .58235 L F
.32439 .58704 m .32304 .58614 L .32527 .5837 L F
.928 .698 .571 r
.32478 .58865 m .32565 .58594 L .32435 .58604 L F
.32377 .5872 m .32435 .58604 L .32304 .58614 L F
.32478 .58865 m .32435 .58604 L .32377 .5872 L F
.638 .556 .746 r
.32304 .58614 m .32565 .58594 L .32527 .5837 L F
.863 .793 .78 r
.3241 .58471 m .32478 .58865 L .32304 .58614 L F
.812 .778 .821 r
.32245 .58692 m .32049 .5868 L .32304 .58614 L F
.019 0 0 r
.44406 .45007 m .44747 .4484 L .44588 .45007 L F
.022 0 0 r
.44406 .45007 m .44532 .45091 L .44279 .45124 L F
.44406 .45007 m .44588 .45007 L .44532 .45091 L F
.617 .928 .689 r
.65915 .38477 m .66225 .38208 L .66074 .38287 L F
.737 .823 .362 r
.65836 .38611 m .65915 .38477 L .66074 .38287 L F
.847 .66 .649 r
.4955 .4171 m .49976 .42048 L .49966 .41853 L F
.4955 .4171 m .49679 .42053 L .49976 .42048 L F
.8 .852 .889 r
.49679 .42053 m .49699 .42176 L .49976 .42048 L F
.42 .368 .694 r
.49976 .42048 m .50243 .41993 L .49966 .41853 L F
.692 .979 .897 r
.50284 .39825 m .50416 .3962 L .50447 .39669 L F
.50284 .39825 m .50028 .39861 L .50416 .3962 L F
.2 0 0 r
.64752 .33721 m .65054 .33681 L .65148 .33572 L F
.131 0 0 r
.65148 .33572 m .65054 .33681 L .65419 .33557 L F
.694 .949 .956 r
.61347 .35096 m .6121 .35044 L .60792 .35224 L F
.222 .632 .955 r
.61347 .35096 m .61424 .35003 L .6121 .35044 L F
.61347 .35096 m .61603 .35139 L .61424 .35003 L F
.87 .549 .44 r
.36288 .52738 m .35939 .5265 L .35932 .52405 L F
.904 .659 .557 r
.36288 .52738 m .35937 .52924 L .35939 .5265 L F
.36288 .52738 m .36232 .53029 L .35937 .52924 L F
.702 .449 .538 r
.51663 .43932 m .51837 .43813 L .51578 .43798 L F
.23 .4 .826 r
.56648 .35289 m .56521 .35514 L .56467 .35316 L F
.56648 .35289 m .56816 .35668 L .56521 .35514 L F
.548 .898 .977 r
.61799 .39733 m .62062 .3982 L .62276 .39692 L F
.911 .621 .481 r
.3308 .52253 m .33432 .52657 L .33473 .52451 L F
.999 .81 .509 r
.39664 .51912 m .39505 .51606 L .39172 .51944 L F
.39664 .51912 m .39447 .51931 L .39505 .51606 L F
.841 .602 .577 r
.39167 .52236 m .39664 .51912 L .39447 .51931 L F
.39167 .52236 m .3938 .5233 L .39664 .51912 L F
.845 .608 .58 r
.39664 .51912 m .3938 .5233 L .39758 .5239 L F
.602 .45 .648 r
.39664 .51912 m .39758 .5239 L .39916 .52014 L F
0 .236 .754 r
.29792 .60439 m .30079 .60695 L .30086 .60373 L F
.331 0 .237 r
.51578 .43798 m .51166 .44115 L .51435 .44035 L F
.702 .449 .538 r
.51663 .43932 m .51578 .43798 L .51435 .44035 L F
.174 0 0 r
.4061 .46212 m .40503 .46115 L .40391 .46313 L F
.4061 .46212 m .40775 .46068 L .40503 .46115 L F
.759 .753 .847 r
.33094 .6283 m .32696 .6278 L .32921 .62655 L F
.688 .712 .866 r
.32921 .62655 m .33353 .62721 L .33094 .6283 L F
.209 .732 .844 r
.5332 .43641 m .53161 .43699 L .52886 .43833 L F
.5332 .43641 m .5342 .43666 L .53161 .43699 L F
.958 .688 .483 r
.3671 .54012 m .36511 .53641 L .36745 .53742 L F
.83 .701 .721 r
.54908 .42118 m .54469 .4231 L .54787 .42024 L F
.54908 .42118 m .54752 .42474 L .54469 .4231 L F
.602 .673 .89 r
.29411 .67369 m .29072 .67567 L .29017 .67292 L F
.131 .576 .924 r
.2958 .67745 m .29072 .67567 L .29411 .67369 L F
.775 .743 .823 r
.32619 .5968 m .32786 .60054 L .33034 .59724 L F
0 0 .26 r
.57224 .35462 m .57356 .35254 L .57366 .34976 L F
.207 .264 .702 r
.57294 .35723 m .57356 .35254 L .57224 .35462 L F
0 0 0 r
.54782 .40919 m .54816 .40857 L .54792 .40884 L F
.54782 .40919 m .54792 .40884 L .54621 .4107 L F
.54816 .40857 m .54851 .40763 L .54621 .4107 L F
.6 .71 .921 r
.54782 .40919 m .54621 .4107 L .544 .40852 L F
.54782 .40919 m .544 .40852 L .54742 .41057 L F
.54782 .40919 m .54742 .41057 L .54744 .41058 L F
.866 .928 .864 r
.54621 .4107 m .54225 .41239 L .544 .40852 L F
.573 .086 .06 r
.54742 .41058 m .544 .40852 L .54308 .4106 L F
.54744 .41058 m .54742 .41057 L .54742 .41058 L F
.54742 .41057 m .544 .40852 L .54742 .41058 L F
0 0 0 r
.54816 .40857 m .54917 .40675 L .54851 .40763 L F
.172 .702 .695 r
.54555 .40761 m .54917 .40675 L .54791 .40703 L F
.957 .947 .697 r
.56441 .42801 m .56649 .42392 L .56548 .42301 L F
.966 .937 .685 r
.56649 .42392 m .56711 .41851 L .56548 .42301 L F
.926 .65 .499 r
.32683 .55323 m .32432 .5495 L .32679 .55126 L F
0 0 .565 r
.29304 .51841 m .29155 .518 L .29111 .51609 L F
.29304 .51841 m .29297 .52079 L .29155 .518 L F
.276 .221 .613 r
.26643 .56219 m .26684 .5663 L .26475 .56407 L F
.844 .684 .684 r
.55823 .40075 m .55456 .40109 L .55667 .39909 L F
.598 .832 .988 r
.55918 .39829 m .55823 .40075 L .55667 .39909 L F
.55918 .39829 m .56103 .39996 L .55823 .40075 L F
.498 .24 .455 r
.56103 .39996 m .55794 .40327 L .55823 .40075 L F
.322 0 .058 r
.60352 .35344 m .60242 .35559 L .59992 .35584 L F
0 0 0 r
.60375 .35401 m .60352 .35344 L .60642 .3537 L F
.60375 .35401 m .60242 .35559 L .60352 .35344 L F
.46928 .42394 m .46574 .4266 L .46967 .42365 L F
.466 .878 .74 r
.47307 .42185 m .46928 .42394 L .47121 .42253 L F
.419 .811 .579 r
.47121 .42253 m .46928 .42394 L .46967 .42365 L F
.486 .361 .635 r
.25728 .58002 m .25759 .58314 L .25533 .58299 L F
.516 .23 .419 r
.25691 .58387 m .25533 .58299 L .25759 .58314 L F
.25691 .58387 m .25417 .58669 L .25533 .58299 L F
.418 .856 .926 r
.6331 .39472 m .63203 .39437 L .62941 .39516 L F
.53 .866 .993 r
.63582 .39432 m .63203 .39437 L .6331 .39472 L F
.965 .762 .579 r
.55027 .45707 m .54986 .46006 L .55196 .46116 L F
.962 .779 .61 r
.54986 .46006 m .55131 .4644 L .55196 .46116 L F
.961 .836 .412 r
.32637 .58235 m .32527 .5837 L .32612 .58003 L F
.605 .95 .813 r
.57385 .35 m .57626 .34786 L .57835 .34878 L F
.623 .919 .977 r
.57835 .34878 m .57928 .34682 L .58077 .3476 L F
.57835 .34878 m .57626 .34786 L .57928 .34682 L F
.995 .783 .507 r
.54787 .42744 m .54908 .42981 L .54859 .429 L F
.927 .973 .714 r
.54908 .42981 m .54617 .4325 L .54859 .429 L F
.54908 .42981 m .54686 .43369 L .54617 .4325 L F
.779 .726 .803 r
.54896 .34173 m .54914 .34429 L .55192 .34093 L F
.997 .857 .566 r
.5479 .34255 m .54914 .34429 L .54896 .34173 L F
.032 0 0 r
.44747 .4484 m .44887 .449 L .44588 .45007 L F
.44747 .4484 m .45 .44739 L .44887 .449 L F
.678 .906 .566 r
.40478 .58222 m .40361 .58429 L .40585 .58114 L F
.471 .504 .81 r
.40478 .58222 m .40392 .58615 L .40361 .58429 L F
.719 .981 .774 r
.47307 .42185 m .47411 .41987 L .47507 .42021 L F
.47307 .42185 m .47121 .42253 L .47411 .41987 L F
.833 .725 .745 r
.33143 .58993 m .33531 .59025 L .33594 .58771 L F
.827 .747 .776 r
.33143 .58993 m .33296 .59371 L .33531 .59025 L F
.933 .872 .754 r
.45007 .54333 m .45213 .5447 L .45064 .54706 L F
.785 .719 .79 r
.4955 .4171 m .49966 .41853 L .49879 .41416 L F
.571 .577 .82 r
.49879 .41416 m .49966 .41853 L .50131 .41736 L F
.452 .352 .651 r
.49966 .41853 m .50243 .41993 L .50131 .41736 L F
.906 .81 .742 r
.3818 .5831 m .38356 .58566 L .38397 .58432 L F
.431 .609 .923 r
.49436 .44166 m .49816 .44271 L .4957 .43965 L F
.91 .776 .701 r
.37561 .57007 m .3746 .56649 L .37668 .56767 L F
.822 .771 .804 r
.51435 .44035 m .51565 .44175 L .51663 .43932 L F
.942 .663 .483 r
.59023 .39646 m .5921 .40048 L .59224 .39773 L F
.604 .838 .46 r
.43094 .56194 m .4316 .56103 L .43223 .55981 L F
.803 .772 .825 r
.43563 .55688 m .43305 .55938 L .43251 .55714 L F
.604 .838 .46 r
.4316 .56103 m .43356 .55835 L .43223 .55981 L F
.981 .768 .359 r
.43286 .55859 m .43223 .55981 L .43251 .55714 L F
.43305 .55938 m .43223 .55981 L .43286 .55859 L F
.831 .709 .176 r
.51876 .47094 m .51833 .47142 L .51949 .46916 L F
.51876 .47094 m .5185 .47383 L .51833 .47142 L F
.857 .409 .019 r
.67849 .34771 m .67949 .34761 L .67803 .34645 L F
.368 .64 .96 r
.39222 .57245 m .39379 .57444 L .39149 .57445 L F
.175 0 .269 r
.25417 .58669 m .2535 .58911 L .25014 .59001 L F
.008 0 0 r
.2535 .58911 m .24993 .59098 L .25014 .59001 L F
.687 .583 .733 r
.2819 .62747 m .28517 .62436 L .28052 .62396 L F
.716 .647 .779 r
.48265 .51157 m .4779 .51052 L .48052 .50965 L F
.79 .703 .768 r
.4852 .50806 m .48265 .51157 L .48052 .50965 L F
.236 .192 .604 r
.38278 .57885 m .38396 .58196 L .3818 .5831 L F
.38288 .57842 m .38306 .57901 L .38278 .57885 L F
.38306 .57901 m .38396 .58196 L .38278 .57885 L F
.778 .817 .883 r
.38227 .57855 m .38679 .57834 L .38436 .57897 L F
.38052 .57821 m .3817 .57823 L .38227 .57855 L F
.3817 .57823 m .38679 .57834 L .38227 .57855 L F
.755 .288 .139 r
.38679 .57834 m .38881 .58014 L .38436 .57897 L F
.653 .942 .692 r
.66074 .38287 m .66225 .38208 L .66412 .38018 L F
.494 .89 .95 r
.62766 .39432 m .62652 .39585 L .62941 .39516 L F
.62766 .39432 m .62487 .39531 L .62652 .39585 L F
.435 .13 .347 r
.28633 .53697 m .28559 .53964 L .28386 .53974 L F
.28633 .53697 m .28386 .53974 L .28385 .53922 L F
.231 .106 .495 r
.28382 .54114 m .28325 .53977 L .28559 .53964 L F
.747 .994 .832 r
.28529 .5379 m .28382 .54114 L .28559 .53964 L F
.994 .759 .464 r
.28484 .53678 m .28479 .53797 L .28603 .53781 L F
.747 .994 .832 r
.28528 .53786 m .28526 .53791 L .28529 .5379 L F
.28526 .53791 m .28382 .54114 L .28529 .5379 L F
0 0 .153 r
.28526 .53791 m .28433 .54221 L .28391 .54133 L F
.28526 .53798 m .28433 .54221 L .28526 .53791 L F
.328 .187 .531 r
.28473 .53962 m .28433 .54221 L .28526 .53798 L F
.994 .759 .464 r
.28479 .53797 m .28473 .53962 L .28523 .53806 L F
.28479 .53797 m .28578 .53817 L .28529 .5379 L F
0 0 .153 r
.28528 .53786 m .28526 .53798 L .28526 .53791 L F
.328 .187 .531 r
.28473 .53962 m .28526 .53798 L .28528 .53786 L F
.994 .759 .464 r
.28523 .53806 m .28473 .53962 L .28578 .53817 L F
.28529 .5379 m .28578 .53817 L .28603 .53781 L F
.484 .232 .456 r
.28873 .53645 m .28559 .53964 L .28633 .53697 L F
.28873 .53645 m .28817 .53924 L .28559 .53964 L F
.747 .994 .832 r
.28529 .5379 m .28559 .53964 L .28775 .53931 L F
.28608 .53833 m .28775 .53931 L .28786 .53929 L F
.28529 .5379 m .28775 .53931 L .28608 .53833 L F
.994 .759 .464 r
.28603 .53781 m .28591 .53799 L .28635 .53807 L F
.28578 .53816 m .28518 .53899 L .28605 .53831 L F
.998 .784 .48 r
.28635 .53807 m .28608 .53833 L .28528 .53786 L F
.994 .759 .464 r
.28518 .53899 m .28473 .53962 L .28517 .5392 L F
.28518 .53899 m .28517 .5392 L .28635 .53807 L F
.998 .784 .48 r
.28608 .53833 m .28473 .53962 L .28528 .53786 L F
.747 .994 .832 r
.28528 .53786 m .28529 .5379 L .28817 .53924 L F
.28529 .5379 m .28786 .53929 L .28817 .53924 L F
0 0 .153 r
.2839 .54097 m .28391 .54133 L .28382 .54114 L F
.28528 .53786 m .28391 .54133 L .2839 .54097 L F
.435 .13 .347 r
.28385 .53922 m .28386 .53974 L .28325 .53977 L F
.475 .533 .837 r
.2872 .53245 m .28633 .53697 L .2856 .53534 L F
.2872 .53245 m .28873 .53645 L .28633 .53697 L F
.274 0 0 r
.3887 .46801 m .39142 .46882 L .39132 .46839 L F
.469 .076 .21 r
.39142 .46882 m .39391 .46703 L .39132 .46839 L F
.864 .89 .853 r
.66124 .34773 m .65677 .34977 L .65879 .34639 L F
.836 .903 .885 r
.48844 .49463 m .48396 .49572 L .48714 .49454 L F
.609 .886 .99 r
.48714 .49454 m .49137 .49402 L .48844 .49463 L F
.79 .703 .768 r
.4852 .50806 m .48071 .50726 L .48309 .50666 L F
.4852 .50806 m .48052 .50965 L .48071 .50726 L F
.786 .711 .781 r
.48824 .5039 m .4852 .50806 L .48309 .50666 L F
.779 .726 .804 r
.32874 .59325 m .33296 .59371 L .33143 .58993 L F
.797 .665 .718 r
.32874 .59325 m .33034 .59724 L .33296 .59371 L F
.924 .908 .512 r
.53842 .40134 m .53817 .39965 L .53935 .39669 L F
0 0 .05 r
.53842 .40134 m .53901 .40188 L .53817 .39965 L F
.53842 .40134 m .53772 .40397 L .53901 .40188 L F
0 0 0 r
.26659 .56904 m .26884 .56761 L .26684 .5663 L F
.802 .716 .77 r
.553 .41069 m .55697 .411 L .55558 .40693 L F
.685 .223 .15 r
.55605 .41277 m .55697 .411 L .553 .41069 L F
.514 .551 .832 r
.55558 .40693 m .55697 .411 L .55852 .40905 L F
0 0 0 r
.55852 .40905 m .55697 .411 L .55605 .41277 L F
.591 .316 .468 r
.57218 .38723 m .5687 .39112 L .56876 .38604 L F
.536 .821 .998 r
.38044 .52611 m .38131 .52748 L .38444 .5268 L F
0 .08 .641 r
.38044 .52611 m .38218 .52935 L .38131 .52748 L F
.791 .626 .677 r
.38218 .52935 m .38444 .5268 L .38131 .52748 L F
.828 .784 .811 r
.31263 .54479 m .30727 .54444 L .31067 .5436 L F
.31263 .54479 m .30935 .54811 L .30727 .54444 L F
.694 .935 .965 r
.31454 .54324 m .31263 .54479 L .31067 .5436 L F
.731 .367 .36 r
.31746 .57679 m .3149 .57709 L .31535 .57418 L F
.31746 .57679 m .3149 .57709 L .31535 .57418 L F
.136 0 0 r
.37009 .50987 m .37256 .51031 L .37417 .51056 L F
.181 .706 .862 r
.37256 .51031 m .37684 .51044 L .37417 .51056 L F
.458 .845 .983 r
.58012 .37317 m .57768 .36962 L .57904 .37236 L F
.602 .735 .938 r
.44298 .57565 m .44023 .5768 L .44013 .57423 L F
.44298 .57565 m .44268 .57652 L .44023 .5768 L F
.08 .22 .71 r
.50375 .42241 m .50565 .42144 L .50243 .41993 L F
.50375 .42241 m .50602 .42449 L .50565 .42144 L F
.666 .948 .957 r
.59056 .37437 m .58978 .37364 L .59189 .37221 L F
.862 .98 .854 r
.32608 .56043 m .32755 .55648 L .32902 .55734 L F
.414 0 .098 r
.42829 .45831 m .43224 .45706 L .43051 .45929 L F
.503 .085 .18 r
.43473 .457 m .43051 .45929 L .43224 .45706 L F
.573 .918 .71 r
.47695 .43033 m .48077 .42752 L .47895 .42837 L F
.473 .869 .69 r
.47895 .42837 m .48077 .42752 L .48311 .42591 L F
.957 .932 .6 r
.54617 .4325 m .54686 .43369 L .54534 .43714 L F
.854 .638 .61 r
.37407 .55421 m .37359 .55708 L .37128 .55321 L F
.882 .99 .802 r
.49569 .51099 m .49841 .50761 L .49744 .50701 L F
.776 .934 .934 r
.49841 .50761 m .50073 .50573 L .49916 .50485 L F
.854 .994 .83 r
.49744 .50701 m .49841 .50761 L .49916 .50485 L F
.828 .586 .572 r
.37577 .56083 m .3754 .56383 L .37298 .56011 L F
.882 .99 .802 r
.49569 .51099 m .49744 .50701 L .49398 .50957 L F
.449 .122 .318 r
.26961 .55999 m .26643 .56219 L .26715 .56047 L F
0 0 .09 r
.24813 .58709 m .24629 .59092 L .24807 .58929 L F
0 0 .25 r
.24813 .58709 m .2497 .58566 L .25004 .58292 L F
.008 0 0 r
.2535 .58911 m .25245 .59021 L .24993 .59098 L F
.714 .225 .083 r
.25245 .59021 m .2498 .58837 L .24993 .59098 L F
.25245 .59021 m .25103 .59048 L .2498 .58837 L F
0 0 .416 r
.2498 .58837 m .25103 .59048 L .25072 .58976 L F
.091 0 .11 r
.24864 .58662 m .2498 .58837 L .2497 .58566 L F
.063 0 .418 r
.2497 .58566 m .2498 .58837 L .25087 .58463 L F
.921 .907 .508 r
.2498 .58837 m .24936 .58659 L .25087 .58463 L F
0 0 .416 r
.2498 .58837 m .25072 .58976 L .24936 .58659 L F
.091 0 .11 r
.24813 .58709 m .2498 .58837 L .24864 .58662 L F
.24813 .58709 m .24807 .58929 L .2498 .58837 L F
.765 .968 .927 r
.56381 .40304 m .5655 .40396 L .56316 .40347 L F
.657 .169 .08 r
.56103 .39996 m .56483 .40062 L .56419 .40298 L F
.56103 .39996 m .56419 .40298 L .56413 .40299 L F
.793 .727 .197 r
.56419 .40294 m .56483 .40062 L .56472 .39976 L F
.765 .968 .927 r
.56589 .40271 m .5655 .40396 L .56381 .40304 L F
.657 .169 .08 r
.56413 .40299 m .56419 .40298 L .56418 .40304 L F
.793 .727 .197 r
.56418 .40304 m .56419 .40298 L .56419 .40294 L F
.56419 .40298 m .56483 .40062 L .56419 .40294 L F
.765 .968 .927 r
.56631 .4014 m .56589 .40271 L .56419 .40298 L F
.582 .201 .286 r
.56103 .39996 m .56413 .40299 L .56043 .40236 L F
.56413 .40299 m .56418 .40304 L .56407 .40302 L F
.56413 .40299 m .56407 .40302 L .56043 .40236 L F
.765 .968 .927 r
.5642 .40279 m .56419 .40297 L .56381 .40304 L F
.56419 .40297 m .56419 .40298 L .56413 .40299 L F
.56419 .40297 m .56413 .40299 L .56381 .40304 L F
.56631 .4014 m .56419 .40298 L .56419 .40294 L F
.501 .292 .527 r
.56419 .40294 m .56631 .4014 L .56418 .40304 L F
.777 .957 .638 r
.56472 .39976 m .56483 .40062 L .56724 .39733 L F
.501 .292 .527 r
.56472 .39976 m .56631 .4014 L .56419 .40294 L F
.765 .968 .927 r
.56631 .4014 m .56419 .40294 L .5642 .40279 L F
0 0 0 r
.55354 .40133 m .55456 .40109 L .55137 .40177 L F
.5533 .40134 m .55137 .40177 L .55304 .40134 L F
.536 .037 .017 r
.55218 .40163 m .55274 .40151 L .55248 .40136 L F
.425 .415 .744 r
.55136 .40071 m .55371 .4013 L .54853 .40166 L F
.536 .037 .017 r
.55195 .40137 m .55248 .40136 L .55136 .40071 L F
0 0 0 r
.55304 .40134 m .55137 .40177 L .54853 .40166 L F
.536 .037 .017 r
.55218 .40163 m .55248 .40136 L .55195 .40137 L F
0 0 0 r
.55337 .40132 m .5533 .40134 L .55304 .40134 L F
.55365 .40131 m .5538 .40127 L .55354 .40133 L F
.55374 .40129 m .5538 .40127 L .55365 .40131 L F
.5538 .40127 m .55456 .40109 L .55354 .40133 L F
.405 0 0 r
.55526 .39987 m .55381 .4012 L .55136 .40071 L F
.517 .101 .192 r
.55136 .40071 m .55248 .40136 L .55426 .40085 L F
.564 .883 .608 r
.55446 .40073 m .55374 .40129 L .55388 .40117 L F
.55667 .39909 m .55414 .40099 L .55446 .40073 L F
.55414 .40099 m .55374 .40129 L .55446 .40073 L F
.55667 .39909 m .55456 .40109 L .55374 .40129 L F
0 0 0 r
.5557 .39977 m .55456 .40077 L .5564 .39961 L F
.564 .883 .608 r
.55667 .39909 m .55388 .40117 L .55526 .39987 L F
0 0 0 r
.55526 .39987 m .55477 .4005 L .5557 .39977 L F
.55477 .4005 m .55456 .40077 L .5557 .39977 L F
.517 .101 .192 r
.55437 .40076 m .55426 .40085 L .55456 .40077 L F
.55136 .40071 m .55426 .40085 L .55437 .40076 L F
.55358 .40132 m .55438 .40115 L .55452 .40084 L F
.564 .883 .608 r
.55388 .40117 m .55374 .40129 L .55371 .4013 L F
.517 .101 .192 r
.55248 .40136 m .55318 .40133 L .55456 .40077 L F
.405 0 0 r
.55381 .4012 m .55371 .4013 L .55136 .40071 L F
0 0 0 r
.55365 .40131 m .55137 .40177 L .55337 .40132 L F
.517 .101 .192 r
.55274 .40151 m .55358 .40132 L .55379 .4012 L F
.55359 .40116 m .55379 .4012 L .55456 .40077 L F
.55274 .40151 m .55379 .4012 L .55359 .40116 L F
.55358 .40132 m .55452 .40084 L .55456 .40077 L F
.564 .883 .608 r
.55388 .40117 m .55371 .4013 L .55381 .4012 L F
.55388 .40117 m .55381 .4012 L .55526 .39987 L F
.517 .101 .192 r
.55274 .40151 m .55391 .40219 L .55438 .40115 L F
0 0 0 r
.55371 .4013 m .55374 .40129 L .55365 .40131 L F
.55371 .4013 m .55365 .40131 L .55337 .40132 L F
.517 .101 .192 r
.55248 .40136 m .55274 .40151 L .55318 .40133 L F
.536 .037 .017 r
.55233 .4018 m .55391 .40219 L .55274 .40151 L F
.55233 .4018 m .55274 .40151 L .55218 .40163 L F
.821 .773 .808 r
.34927 .621 m .34605 .62103 L .34841 .61953 L F
.418 .639 .948 r
.35146 .61957 m .34927 .621 L .34841 .61953 L F
.304 .392 .788 r
.35146 .61957 m .35238 .62301 L .34927 .621 L F
.817 .545 .527 r
.33101 .58709 m .33594 .58771 L .33459 .58717 L F
.833 .725 .745 r
.33143 .58993 m .33594 .58771 L .33101 .58709 L F
.374 .828 .727 r
.62568 .34446 m .62824 .34326 L .62563 .34446 L F
.637 .868 .985 r
.46187 .53348 m .45752 .53293 L .45953 .53208 L F
.827 .913 .896 r
.46187 .53348 m .46295 .52908 L .46441 .53018 L F
.46187 .53348 m .45953 .53208 L .46295 .52908 L F
.969 .698 .463 r
.37906 .51238 m .38101 .51081 L .37684 .51044 L F
.37906 .51238 m .38095 .51352 L .38101 .51081 L F
.118 .67 .753 r
.43251 .55714 m .43456 .5569 L .43459 .55697 L F
.416 .188 .457 r
.43251 .55714 m .43223 .55981 L .43456 .5569 L F
.651 .828 .409 r
.43456 .5569 m .43356 .55835 L .4345 .55678 L F
.952 .952 .671 r
.43563 .55688 m .43456 .5569 L .43686 .5522 L F
0 0 0 r
.43686 .5522 m .43456 .5569 L .43582 .55458 L F
.651 .828 .409 r
.43456 .5569 m .4345 .55678 L .43582 .55458 L F
.118 .67 .753 r
.43459 .55697 m .43456 .5569 L .43563 .55688 L F
.879 .918 .848 r
.58592 .35969 m .59036 .35763 L .58925 .35538 L F
.507 .407 .676 r
.25255 .55707 m .25537 .56013 L .25478 .55635 L F
.25255 .55707 m .25311 .56108 L .25537 .56013 L F
.256 .338 .756 r
.57276 .37403 m .57548 .376 L .57381 .37771 L F
0 0 .377 r
.57548 .376 m .57392 .38097 L .57381 .37771 L F
.941 .829 .705 r
.33799 .54896 m .34043 .55097 L .34109 .54776 L F
0 .101 .648 r
.33799 .54896 m .33878 .5513 L .34043 .55097 L F
.698 .754 .895 r
.29025 .65058 m .29085 .64644 L .28899 .64665 L F
.29025 .65058 m .29231 .64969 L .29085 .64644 L F
.868 .677 .643 r
.40251 .53661 m .40485 .53786 L .40314 .53384 L F
.862 .774 .763 r
.40082 .53984 m .40485 .53786 L .40251 .53661 L F
.40082 .53984 m .40258 .54129 L .40485 .53786 L F
.737 .29 .19 r
.38095 .51352 m .38331 .51597 L .38509 .51447 L F
.77 .336 .22 r
.38509 .51447 m .38331 .51597 L .38614 .51624 L F
.611 .895 .988 r
.64274 .39598 m .64397 .39693 L .64702 .39554 L F
.081 .64 .705 r
.62977 .34831 m .62831 .34847 L .62623 .34871 L F
.232 .749 .755 r
.63106 .34777 m .62977 .34831 L .63268 .34771 L F
.63106 .34777 m .62831 .34847 L .62977 .34831 L F
0 0 .287 r
.41408 .47278 m .41377 .4761 L .41522 .4744 L F
.558 .684 .924 r
.39578 .57417 m .39561 .57736 L .39379 .57444 L F
.39578 .57417 m .39817 .57675 L .39561 .57736 L F
.85 .802 .804 r
.33817 .57325 m .33557 .57665 L .33966 .57701 L F
.858 .786 .779 r
.33557 .57665 m .33687 .58041 L .33966 .57701 L F
.863 .807 .794 r
.33817 .57325 m .33966 .57701 L .34166 .57385 L F
.573 .918 .712 r
.31907 .64629 m .31807 .64746 L .31967 .64616 L F
.932 .734 .612 r
.31572 .64675 m .31807 .64746 L .31907 .64629 L F
.31572 .64675 m .31783 .6504 L .31807 .64746 L F
.627 .498 .686 r
.31783 .6504 m .31967 .64616 L .31807 .64746 L F
.937 .691 .54 r
.33863 .53672 m .33814 .53977 L .34113 .54035 L F
.896 .683 .607 r
.33732 .54245 m .34113 .54035 L .33814 .53977 L F
.33732 .54245 m .33973 .54383 L .34113 .54035 L F
.467 .77 .996 r
.28037 .67178 m .28564 .67403 L .2837 .67023 L F
.278 0 0 r
.28037 .67178 m .28145 .6721 L .27955 .67216 L F
.28037 .67178 m .27955 .67216 L .27876 .67218 L F
.467 .77 .996 r
.28037 .67178 m .2837 .67023 L .28366 .67017 L F
0 .187 .715 r
.28366 .67017 m .28564 .67403 L .28601 .67244 L F
.826 .708 .735 r
.28393 .6762 m .28564 .67403 L .2849 .67706 L F
.28393 .6762 m .28601 .67244 L .28564 .67403 L F
.306 .714 .976 r
.289 .68351 m .29055 .68461 L .29269 .68434 L F
.238 .626 .958 r
.57318 .39846 m .57472 .39993 L .57216 .39962 L F
.538 .888 .655 r
.57318 .39846 m .57216 .39962 L .57098 .4003 L F
.91 .776 .701 r
.37561 .57007 m .37247 .57006 L .3746 .56649 L F
.897 .85 .79 r
.37561 .57007 m .37161 .57256 L .37247 .57006 L F
.37561 .57007 m .37312 .57398 L .37161 .57256 L F
0 0 .181 r
.57823 .3672 m .57785 .36323 L .57727 .36467 L F
.55 .901 .683 r
.62251 .34963 m .62171 .34989 L .62048 .35118 L F
.484 .852 .989 r
.62048 .35118 m .62171 .34989 L .619 .3506 L F
.068 0 0 r
.62442 .34996 m .62082 .35017 L .62171 .34989 L F
.053 0 0 r
.62171 .34989 m .61762 .35029 L .619 .3506 L F
.068 0 0 r
.62082 .35017 m .62035 .3502 L .62171 .34989 L F
.55 .901 .683 r
.623 .34926 m .62171 .34989 L .62251 .34963 L F
.891 .721 .664 r
.33961 .5699 m .33817 .57325 L .34166 .57385 L F
.468 .263 .518 r
.3122 .5607 m .31511 .56076 L .31487 .55732 L F
.775 .755 .835 r
.52514 .4414 m .52551 .44395 L .52219 .44376 L F
.632 .143 .073 r
.52219 .44376 m .52551 .44395 L .52457 .44564 L F
0 0 .454 r
.52643 .44231 m .52551 .44395 L .52514 .4414 L F
.829 .494 0 r
.52643 .44231 m .52811 .44544 L .52457 .44564 L F
.772 .396 .345 r
.52457 .44564 m .52811 .44544 L .52841 .44677 L F
.52703 .44691 m .52841 .44677 L .52864 .44774 L F
.52457 .44564 m .52841 .44677 L .52703 .44691 L F
.859 .818 .808 r
.53142 .4429 m .52943 .44666 L .52643 .44231 L F
.95 .638 .407 r
.52885 .44775 m .53019 .44752 L .52811 .44544 L F
.881 .911 .844 r
.52915 .4472 m .53019 .44752 L .52885 .44775 L F
.878 .444 .067 r
.52811 .44544 m .53019 .44752 L .52944 .44729 L F
.52811 .44544 m .52974 .44771 L .52862 .44675 L F
.881 .911 .844 r
.53142 .4429 m .53019 .44752 L .52915 .4472 L F
.878 .444 .067 r
.52944 .44729 m .53019 .44752 L .52974 .44771 L F
.859 .818 .808 r
.52915 .4472 m .52885 .44775 L .52862 .44675 L F
.878 .444 .067 r
.52862 .44675 m .52974 .44771 L .5291 .44798 L F
.829 .494 0 r
.52841 .44677 m .52885 .44775 L .52811 .44544 L F
.859 .818 .808 r
.52862 .44675 m .52885 .44775 L .52841 .44677 L F
.52943 .44666 m .52915 .4472 L .52862 .44675 L F
.829 .494 0 r
.52704 .44346 m .52841 .44677 L .52811 .44544 L F
.52643 .44231 m .52709 .4438 L .52704 .44346 L F
.52709 .4438 m .52841 .44677 L .52704 .44346 L F
.859 .818 .808 r
.52943 .44666 m .52841 .44677 L .52643 .44231 L F
0 .024 .597 r
.52721 .44457 m .52791 .44566 L .52855 .44294 L F
.52666 .44524 m .52733 .44547 L .52721 .44457 L F
.52733 .44547 m .52791 .44566 L .52721 .44457 L F
.772 .396 .345 r
.52864 .44774 m .52811 .44544 L .5291 .44798 L F
.889 .713 .657 r
.5317 .43993 m .52643 .44231 L .52726 .43956 L F
.5317 .43993 m .53142 .4429 L .52643 .44231 L F
.273 .332 .742 r
.52676 .44171 m .52666 .44524 L .52855 .44294 L F
0 0 .454 r
.52643 .44231 m .52514 .4414 L .52726 .43956 L F
.273 .332 .742 r
.5257 .44098 m .52612 .44286 L .52676 .44171 L F
.52612 .44286 m .52666 .44524 L .52676 .44171 L F
.829 .494 0 r
.52643 .44231 m .52608 .44294 L .52551 .44395 L F
.52608 .44294 m .52457 .44564 L .52474 .44533 L F
.52608 .44294 m .52474 .44533 L .52551 .44395 L F
.775 .755 .835 r
.52514 .4414 m .52551 .44395 L .52219 .44376 L F
.248 0 0 r
.28036 .63755 m .27632 .63967 L .27882 .63701 L F
.261 .741 .931 r
.28269 .6373 m .28036 .63755 L .27882 .63701 L F
.971 .788 .359 r
.34115 .66707 m .34184 .66539 L .34128 .66471 L F
0 .244 .713 r
.34128 .66471 m .34184 .66539 L .34309 .66579 L F
0 0 0 r
.34309 .66579 m .34184 .66539 L .34115 .66707 L F
.042 .434 .871 r
.58195 .37968 m .58135 .37638 L .58065 .37859 L F
.751 .459 .489 r
.58803 .34634 m .59009 .34959 L .59155 .34766 L F
0 0 0 r
.59155 .34766 m .59365 .3461 L .59322 .34619 L F
.59155 .34766 m .59009 .34959 L .59365 .3461 L F
.937 .676 .517 r
.37151 .55075 m .36919 .55214 L .36898 .54949 L F
.37151 .55075 m .37128 .55321 L .36919 .55214 L F
.827 .573 .556 r
.33469 .52972 m .33664 .52741 L .33432 .52657 L F
.33469 .52972 m .3364 .53024 L .33664 .52741 L F
.553 0 0 r
.5291 .44798 m .53019 .44752 L .53304 .44934 L F
.515 .237 .431 r
.53019 .44752 m .53307 .44708 L .53304 .44934 L F
.694 .759 .901 r
.34299 .62387 m .34076 .625 L .33871 .62321 L F
0 0 0 r
.62623 .34871 m .62171 .34989 L .623 .34926 L F
.943 .795 .667 r
.30727 .54444 m .30935 .54811 L .30563 .54562 L F
.94 .579 .287 r
.30935 .54811 m .30745 .5488 L .30563 .54562 L F
.644 .099 0 r
.30935 .54811 m .31214 .55015 L .30745 .5488 L F
0 0 0 r
.44674 .43921 m .44843 .43777 L .44502 .44004 L F
.53 .853 .562 r
.45035 .43591 m .44843 .43777 L .44674 .43921 L F
.646 .966 .826 r
.44502 .44004 m .44083 .44228 L .44433 .44049 L F
0 0 0 r
.44502 .44004 m .44433 .44049 L .44674 .43921 L F
.344 .014 .254 r
.38833 .47029 m .39142 .46882 L .3887 .46801 L F
.875 .987 .826 r
.47242 .51707 m .46825 .5197 L .47089 .51885 L F
.753 .995 .839 r
.47541 .51416 m .47242 .51707 L .473 .51516 L F
.766 .905 .513 r
.47242 .51707 m .47089 .51885 L .473 .51516 L F
.923 .592 .395 r
.54752 .42474 m .54522 .42567 L .54469 .4231 L F
.54752 .42474 m .54787 .42744 L .54522 .42567 L F
.777 .957 .638 r
.56472 .39976 m .56724 .39733 L .56632 .39607 L F
.881 .962 .847 r
.56632 .39607 m .56724 .39733 L .57026 .39383 L F
.73 .292 .211 r
.5624 .38652 m .55796 .38426 L .56065 .38327 L F
.56023 .38541 m .56037 .38666 L .55796 .38426 L F
.5624 .38652 m .56037 .38666 L .56023 .38541 L F
.754 .525 0 r
.56037 .38666 m .56065 .38886 L .56056 .3884 L F
.56037 .38666 m .56056 .3884 L .56005 .38605 L F
.517 .342 .582 r
.55796 .38426 m .56037 .38666 L .56065 .38327 L F
0 0 .16 r
.52133 .37961 m .51934 .38421 L .51808 .37992 L F
.52133 .37961 m .52096 .38208 L .51934 .38421 L F
.306 .097 .424 r
.52172 .38508 m .51934 .38421 L .52096 .38208 L F
.52172 .38508 m .51941 .38629 L .51934 .38421 L F
.941 .829 .705 r
.33799 .54896 m .34109 .54776 L .33884 .54643 L F
.746 .746 .851 r
.39687 .55617 m .39875 .55867 L .39967 .55611 L F
.72 .417 0 r
.27791 .54789 m .27812 .54912 L .27713 .54871 L F
.27791 .54789 m .27887 .55135 L .27812 .54912 L F
.03 .601 .74 r
.6546 .39574 m .64971 .39572 L .65155 .39745 L F
.948 .715 .554 r
.36267 .50327 m .36194 .50627 L .36389 .50656 L F
.774 .492 .507 r
.36194 .50627 m .36594 .50913 L .36389 .50656 L F
.926 .801 .703 r
.42595 .59317 m .42702 .59684 L .42818 .59441 L F
.786 .711 .781 r
.48824 .5039 m .48309 .50666 L .48317 .50387 L F
.842 .961 .627 r
.3204 .56773 m .31978 .56755 L .32065 .56613 L F
.32127 .56567 m .32065 .56613 L .32202 .56391 L F
.3204 .56773 m .32356 .5645 L .32104 .56544 L F
.3204 .56773 m .32065 .56613 L .32127 .56567 L F
0 0 0 r
.32338 .56385 m .32104 .56544 L .3221 .56504 L F
.32343 .56404 m .3221 .56504 L .32356 .5645 L F
.32338 .56385 m .3221 .56504 L .32343 .56404 L F
.843 .848 .848 r
.31837 .62653 m .3192 .62979 L .31766 .63117 L F
.732 .787 .896 r
.32244 .62707 m .3192 .62979 L .31837 .62653 L F
.621 .828 .98 r
.3117 .60729 m .31327 .60801 L .31145 .605 L F
.713 .986 .832 r
.67229 .37264 m .67614 .37041 L .6759 .37018 L F
.729 .983 .907 r
.67614 .37041 m .67965 .36813 L .67767 .368 L F
.705 .945 .652 r
.6759 .37018 m .67614 .37041 L .67767 .368 L F
.468 .263 .518 r
.31487 .55732 m .31511 .56076 L .31721 .55947 L F
.626 .577 .779 r
.31898 .5606 m .31487 .55732 L .31721 .55947 L F
.681 .487 .618 r
.54246 .40447 m .53914 .40693 L .53772 .40397 L F
.54246 .40447 m .54193 .40706 L .53914 .40693 L F
.853 .464 .307 r
.54246 .40447 m .54555 .40761 L .54193 .40706 L F
.951 .86 .713 r
.41688 .55309 m .41733 .55687 L .41681 .5528 L F
.41688 .55309 m .41533 .5563 L .41733 .55687 L F
.986 .709 .393 r
.41638 .55917 m .41733 .55687 L .41533 .5563 L F
.41638 .55917 m .41732 .5602 L .41733 .55687 L F
.771 .736 .821 r
.29919 .6333 m .30056 .63644 L .29657 .63636 L F
.8 .857 .892 r
.30174 .63256 m .30056 .63644 L .29919 .6333 L F
.30174 .63256 m .30352 .63397 L .30056 .63644 L F
.25 0 0 r
.42829 .45831 m .42832 .45949 L .42492 .46008 L F
.422 0 0 r
.42829 .45831 m .43051 .45929 L .42832 .45949 L F
.608 .813 .979 r
.40591 .58752 m .40739 .58911 L .40889 .58894 L F
.717 .937 .62 r
.45204 .55326 m .45007 .55485 L .44983 .55712 L F
.45204 .55326 m .4516 .55324 L .45007 .55485 L F
0 0 0 r
.45549 .54974 m .4516 .55324 L .45204 .55326 L F
.591 .935 .753 r
.45209 .44591 m .45603 .44352 L .45395 .44478 L F
.549 .927 .806 r
.45603 .44352 m .45968 .44144 L .45751 .44202 L F
.538 .892 .669 r
.45395 .44478 m .45603 .44352 L .45751 .44202 L F
.881 .737 .699 r
.33864 .56328 m .33664 .56639 L .34025 .56718 L F
.843 .673 .672 r
.33664 .56639 m .33961 .5699 L .34025 .56718 L F
.242 0 0 r
.63108 .34222 m .63389 .34218 L .63517 .34122 L F
.072 0 0 r
.63389 .34218 m .63818 .34077 L .63517 .34122 L F
.516 .082 .153 r
.65419 .33557 m .65696 .33572 L .6582 .33352 L F
.567 .135 .18 r
.6582 .33352 m .6613 .33527 L .66094 .3339 L F
.6582 .33352 m .65696 .33572 L .6613 .33527 L F
.913 .97 .669 r
.52937 .4596 m .53023 .45564 L .53227 .45681 L F
.52937 .4596 m .52817 .45958 L .53023 .45564 L F
.595 .658 .882 r
.53321 .46088 m .52937 .4596 L .53227 .45681 L F
.18 0 0 r
.41545 .45854 m .4143 .45719 L .41281 .45913 L F
.41545 .45854 m .41686 .45643 L .4143 .45719 L F
.298 .52 .9 r
.28657 .68292 m .28584 .67947 L .28554 .68127 L F
.878 .988 .818 r
.30311 .66076 m .30072 .66389 L .29972 .66264 L F
.716 .677 .131 r
.30072 .66389 m .30046 .66514 L .29972 .66264 L F
.30072 .66389 m .30027 .66661 L .30046 .66514 L F
.503 .344 .597 r
.55628 .3609 m .55897 .36013 L .55852 .35687 L F
.55628 .3609 m .55897 .36013 L .55852 .35687 L F
.649 .851 .977 r
.63848 .37914 m .63744 .382 L .63557 .38207 L F
.63848 .37914 m .64004 .38085 L .63744 .382 L F
.941 .753 .62 r
.29846 .67229 m .30139 .67047 L .30055 .67366 L F
.964 .686 .258 r
.30027 .66661 m .30139 .67047 L .30046 .66991 L F
.373 .809 .96 r
.61763 .34467 m .62025 .34412 L .62198 .34515 L F
.271 .766 .898 r
.62025 .34412 m .62568 .34446 L .62198 .34515 L F
.073 .479 .892 r
.4415 .56803 m .44552 .5696 L .44529 .57036 L F
0 0 .094 r
.44529 .57036 m .44478 .57333 L .44298 .57565 L F
.107 0 .185 r
.44717 .57179 m .44529 .57036 L .44552 .5696 L F
.44717 .57179 m .44478 .57333 L .44529 .57036 L F
.774 .804 .877 r
.31766 .63117 m .31288 .63269 L .31552 .62952 L F
.843 .848 .848 r
.31837 .62653 m .31766 .63117 L .31552 .62952 L F
.945 .823 .693 r
.44039 .58325 m .44364 .58002 L .44365 .57967 L F
.44039 .58325 m .44153 .58518 L .44364 .58002 L F
.471 .288 .551 r
.26323 .54384 m .26569 .54321 L .26574 .54036 L F
.43 .265 .555 r
.26302 .54678 m .26569 .54321 L .26323 .54384 L F
.352 .193 .521 r
.49147 .43338 m .48962 .43513 L .49147 .43674 L F
.988 .719 .399 r
.46426 .52736 m .46441 .53018 L .46295 .52908 L F
.706 .552 .677 r
.32915 .57038 m .32497 .57364 L .32457 .57054 L F
.32915 .57038 m .32906 .57519 L .32497 .57364 L F
.673 .525 .675 r
.33126 .57044 m .32906 .57519 L .32915 .57038 L F
.967 .646 .339 r
.67608 .34161 m .67597 .3434 L .67732 .34421 L F
.954 .607 .284 r
.67597 .3434 m .67618 .34556 L .67732 .34421 L F
.905 .503 .223 r
.67732 .34421 m .67618 .34556 L .67803 .34645 L F
.178 .711 .741 r
.63658 .347 m .63537 .34716 L .63268 .34771 L F
.198 .726 .749 r
.63774 .34655 m .63658 .347 L .63931 .34676 L F
.63774 .34655 m .63537 .34716 L .63658 .347 L F
.222 .15 .56 r
.25397 .56359 m .25537 .56013 L .25311 .56108 L F
.25397 .56359 m .25549 .56324 L .25537 .56013 L F
.331 .28 .65 r
.25435 .56681 m .25549 .56324 L .25397 .56359 L F
.775 .499 .518 r
.37312 .57398 m .36935 .57663 L .37161 .57256 L F
.37312 .57398 m .37379 .57774 L .36935 .57663 L F
0 0 .401 r
.31476 .51448 m .31551 .51657 L .31483 .51307 L F
.301 0 0 r
.32012 .68487 m .32507 .68229 L .32217 .68562 L F
.417 0 .125 r
.32507 .68229 m .32507 .68539 L .32217 .68562 L F
.32507 .68229 m .32662 .68208 L .32507 .68539 L F
.653 .564 .742 r
.53592 .45801 m .53321 .46088 L .53227 .45681 L F
.639 .749 .928 r
.31118 .62946 m .31038 .63324 L .30794 .63225 L F
.31118 .62946 m .31288 .63269 L .31038 .63324 L F
.812 .997 .853 r
.5122 .48012 m .51465 .47637 L .51586 .47742 L F
.5122 .48012 m .51147 .4794 L .51465 .47637 L F
.679 .901 .975 r
.31511 .56076 m .31898 .5606 L .31721 .55947 L F
0 0 0 r
.30341 .6159 m .30402 .61541 L .30153 .61598 L F
.30341 .6159 m .30599 .61366 L .30402 .61541 L F
.812 .985 .886 r
.4219 .59332 m .42029 .59664 L .42252 .5944 L F
.4219 .59332 m .41877 .59614 L .42029 .59664 L F
.514 .582 .861 r
.29832 .67695 m .2958 .67745 L .29411 .67369 L F
.792 .847 .892 r
.56698 .39324 m .57026 .39383 L .5687 .39112 L F
.881 .962 .847 r
.56632 .39607 m .57026 .39383 L .56698 .39324 L F
.757 .834 .911 r
.5687 .39112 m .57026 .39383 L .57351 .39133 L F
.734 .654 .77 r
.3184 .58971 m .31988 .59402 L .31531 .59343 L F
.556 .354 .562 r
.31988 .59402 m .31696 .59761 L .31531 .59343 L F
.31988 .59402 m .31961 .5977 L .31696 .59761 L F
.427 .246 .531 r
.31988 .59402 m .31961 .5977 L .32182 .5962 L F
.366 .835 .865 r
.31226 .57659 m .31114 .57705 L .31205 .57717 L F
0 0 .051 r
.56925 .36175 m .56876 .36384 L .56909 .36035 L F
0 0 .57 r
.56816 .35668 m .56948 .35927 L .56909 .36035 L F
0 0 .054 r
.56948 .35927 m .56925 .36175 L .56909 .36035 L F
.933 .555 .198 r
.35303 .63391 m .35099 .63025 L .35146 .63438 L F
.485 0 0 r
.35159 .63479 m .35303 .63391 L .35146 .63438 L F
0 0 .248 r
.35375 .63556 m .35313 .63661 L .35303 .63391 L F
.35375 .63556 m .35303 .63391 L .35159 .63479 L F
.943 .899 .752 r
.4779 .51052 m .47448 .51302 L .47676 .50968 L F
.4779 .51052 m .47541 .51416 L .47448 .51302 L F
.843 .982 .869 r
.48071 .50726 m .4779 .51052 L .47676 .50968 L F
.645 .567 .752 r
.48052 .50965 m .4779 .51052 L .48071 .50726 L F
.855 .535 .446 r
.35932 .52405 m .35691 .52551 L .35548 .52302 L F
.35932 .52405 m .35939 .5265 L .35691 .52551 L F
.782 .503 .514 r
.59677 .35708 m .59469 .35796 L .59278 .35788 L F
.59677 .35708 m .597 .3603 L .59469 .35796 L F
.318 .158 .501 r
.59886 .35914 m .59677 .35708 L .59992 .35584 L F
.59886 .35914 m .597 .3603 L .59677 .35708 L F
.257 .201 .601 r
.28731 .59006 m .28891 .5894 L .28696 .58712 L F
.28731 .59006 m .28891 .5894 L .28696 .58712 L F
.822 .757 .791 r
.33101 .58709 m .33459 .58717 L .33259 .58268 L F
.811 .753 .798 r
.33259 .58268 m .33459 .58717 L .33645 .58282 L F
.436 .452 .778 r
.38054 .58113 m .3818 .5831 L .37946 .58306 L F
0 0 .333 r
.56332 .37748 m .56378 .37366 L .56389 .37331 L F
.56332 .37748 m .56421 .37509 L .56378 .37366 L F
.776 .417 0 r
.56378 .37366 m .56421 .37509 L .5637 .37392 L F
.56378 .37366 m .5637 .37392 L .56286 .37199 L F
0 0 .333 r
.56389 .37331 m .56378 .37366 L .56402 .3724 L F
0 0 .371 r
.56332 .37748 m .56374 .38029 L .56462 .37797 L F
.738 .751 .863 r
.49416 .49259 m .49556 .49448 L .49137 .49402 L F
.737 .751 .864 r
.4973 .49293 m .49556 .49448 L .49416 .49259 L F
0 .528 .708 r
.60784 .34557 m .61066 .34581 L .61176 .34592 L F
.444 .88 .863 r
.61176 .34592 m .61345 .34464 L .61473 .34547 L F
.61176 .34592 m .61066 .34581 L .61345 .34464 L F
.696 .703 .852 r
.33214 .62402 m .33353 .62721 L .32921 .62655 L F
.758 .751 .846 r
.33449 .62256 m .33353 .62721 L .33214 .62402 L F
.33449 .62256 m .33619 .62438 L .33353 .62721 L F
.957 .947 .697 r
.56441 .42801 m .56548 .42301 L .56339 .42673 L F
.821 .958 .902 r
.56211 .42854 m .56441 .42801 L .56339 .42673 L F
.967 .744 .55 r
.32019 .52404 m .31816 .52439 L .31725 .52257 L F
.32019 .52404 m .31964 .52705 L .31816 .52439 L F
.772 .905 .933 r
.52606 .48282 m .53112 .4814 L .52966 .4803 L F
.862 .953 .869 r
.53169 .47831 m .53112 .4814 L .53309 .47928 L F
.824 .924 .901 r
.52966 .4803 m .53112 .4814 L .53169 .47831 L F
.739 .934 .596 r
.59265 .38984 m .5917 .39142 L .59368 .38868 L F
0 0 0 r
.59216 .3916 m .5917 .39142 L .59265 .38984 L F
.59216 .3916 m .59016 .39387 L .5917 .39142 L F
.573 .918 .71 r
.47695 .43033 m .47895 .42837 L .4769 .43009 L F
.964 .816 .649 r
.4482 .54959 m .45064 .54706 L .44788 .54947 L F
.4482 .54959 m .44832 .5444 L .45064 .54706 L F
.933 .872 .754 r
.45007 .54333 m .45064 .54706 L .44832 .5444 L F
.683 .944 .961 r
.30843 .68712 m .31138 .68557 L .30893 .68522 L F
.746 .985 .902 r
.30707 .68684 m .30843 .68712 L .30893 .68522 L F
.391 .115 .37 r
.27486 .64975 m .27537 .6474 L .27785 .64686 L F
.455 .216 .461 r
.27115 .53384 m .2739 .5333 L .27426 .53044 L F
.377 .153 .443 r
.2739 .5333 m .27656 .52981 L .27426 .53044 L F
.727 .701 .825 r
.50141 .41095 m .50462 .4115 L .5038 .40938 L F
.709 .691 .831 r
.5038 .40938 m .50462 .4115 L .50664 .40909 L F
.037 .096 .595 r
.50462 .4115 m .50663 .41179 L .50664 .40909 L F
.50462 .4115 m .50534 .41397 L .50663 .41179 L F
.743 .855 .42 r
.51808 .37992 m .52019 .37634 L .51821 .37746 L F
.605 .95 .813 r
.57385 .35 m .57366 .34976 L .57626 .34786 L F
.86 .981 .689 r
.67965 .36813 m .68213 .36431 L .68045 .36526 L F
.836 .988 .864 r
.67767 .368 m .67965 .36813 L .68045 .36526 L F
.872 .457 .229 r
.6615 .35698 m .65912 .35657 L .65843 .35406 L F
.909 .884 .796 r
.65809 .3586 m .6615 .35698 L .65957 .36025 L F
.65809 .3586 m .65912 .35657 L .6615 .35698 L F
.271 .766 .898 r
.62025 .34412 m .62296 .34373 L .62568 .34446 L F
.298 .791 .874 r
.62296 .34373 m .62745 .3435 L .62568 .34446 L F
.374 .828 .727 r
.62568 .34446 m .62745 .3435 L .62824 .34326 L F
0 0 0 r
.55917 .34773 m .55831 .35072 L .55899 .34868 L F
0 0 .287 r
.55831 .35072 m .55958 .35116 L .55899 .34868 L F
.55831 .35072 m .55835 .35316 L .55958 .35116 L F
.376 .819 .949 r
.64323 .34671 m .64206 .34622 L .63931 .34676 L F
.262 0 0 r
.64583 .34569 m .64206 .34622 L .64323 .34671 L F
.608 .952 .815 r
.45751 .44202 m .45968 .44144 L .46172 .43988 L F
.063 0 0 r
.64073 .33973 m .64351 .33911 L .64493 .33797 L F
.135 0 0 r
.64493 .33797 m .64701 .3381 L .64752 .33721 L F
.64493 .33797 m .64351 .33911 L .64701 .3381 L F
.92 .8 .711 r
.33738 .55909 m .34046 .5578 L .33804 .55649 L F
.33738 .55909 m .33934 .56031 L .34046 .5578 L F
.676 .745 .903 r
.53646 .43558 m .53822 .43737 L .5342 .43666 L F
.439 .559 .879 r
.53954 .4349 m .53822 .43737 L .53646 .43558 L F
.53954 .4349 m .54116 .43791 L .53822 .43737 L F
.545 .327 .535 r
.54116 .43791 m .54099 .43937 L .53822 .43737 L F
.475 .347 .626 r
.54099 .43937 m .5386 .44044 L .53822 .43737 L F
.773 .585 .645 r
.53772 .40397 m .53914 .40693 L .53573 .40751 L F
0 0 0 r
.53772 .40397 m .53573 .40751 L .5369 .40598 L F
.056 0 0 r
.53772 .40397 m .53919 .40498 L .53901 .40188 L F
.53772 .40397 m .5369 .40598 L .53919 .40498 L F
.847 .963 .88 r
.51543 .49334 m .51724 .4895 L .51398 .49243 L F
.51543 .49334 m .51845 .49045 L .51724 .4895 L F
.512 .314 .548 r
.31278 .57433 m .31114 .57705 L .31012 .57285 L F
.267 .163 .545 r
.31012 .57285 m .31226 .57659 L .31295 .57313 L F
.31012 .57285 m .31114 .57705 L .31226 .57659 L F
.556 .388 .609 r
.28621 .55401 m .2893 .55369 L .28926 .55031 L F
.341 0 0 r
.28621 .55401 m .28819 .55487 L .2893 .55369 L F
.2893 .55369 m .28819 .55487 L .28621 .55401 L F
.411 .774 .995 r
.29758 .68594 m .30191 .68651 L .30104 .68556 L F
0 .171 .655 r
.30104 .68556 m .30191 .68651 L .30199 .68616 L F
0 .41 .772 r
.30191 .68651 m .3044 .68747 L .30199 .68616 L F
.678 .745 .901 r
.46404 .54584 m .46568 .54219 L .46215 .54529 L F
.46404 .54584 m .46747 .54441 L .46568 .54219 L F
.245 .309 .731 r
.55852 .35687 m .56052 .35512 L .55835 .35316 L F
.447 .304 .593 r
.55852 .35687 m .56122 .35907 L .56052 .35512 L F
.55852 .35687 m .55897 .36013 L .56122 .35907 L F
.897 .616 .502 r
.34308 .5102 m .34083 .51002 L .34088 .50706 L F
.852 .44 .251 r
.34308 .5102 m .34142 .51193 L .34083 .51002 L F
.34308 .5102 m .34497 .51332 L .34142 .51193 L F
.578 .456 .677 r
.29491 .61326 m .29686 .61011 L .29509 .61046 L F
.734 .975 .731 r
.30141 .65974 m .30332 .65896 L .29972 .66264 L F
.249 0 0 r
.30177 .65987 m .30332 .65896 L .30141 .65974 L F
.852 .956 .611 r
.3046 .65821 m .30311 .66076 L .30332 .65896 L F
.818 1 .821 r
.30332 .65896 m .30311 .66076 L .29972 .66264 L F
.249 0 0 r
.30408 .66074 m .30332 .65896 L .30177 .65987 L F
.852 .956 .611 r
.30527 .65707 m .3046 .65821 L .30332 .65896 L F
.159 0 0 r
.30166 .6515 m .30381 .65041 L .30545 .65045 L F
0 0 0 r
.30527 .65707 m .30644 .65625 L .30808 .65507 L F
0 0 .02 r
.30582 .65843 m .30527 .65707 L .30332 .65896 L F
.30582 .65843 m .30644 .65625 L .30527 .65707 L F
.159 .66 .91 r
.239 .61009 m .24264 .61033 L .24348 .61096 L F
.702 .248 .17 r
.24348 .61096 m .24124 .61236 L .23997 .61108 L F
.24138 .61074 m .23997 .61108 L .23943 .61052 L F
.24348 .61096 m .23997 .61108 L .24138 .61074 L F
.981 .766 .539 r
.23899 .61085 m .23898 .61159 L .23821 .61169 L F
.466 .891 .849 r
.23822 .61168 m .23868 .61139 L .23871 .61137 L F
.23789 .6119 m .23821 .61169 L .23822 .61168 L F
.23821 .61169 m .23868 .61139 L .23822 .61168 L F
.775 .538 .577 r
.23481 .60956 m .23789 .6119 L .239 .61009 L F
.513 .529 .809 r
.23825 .61072 m .239 .61009 L .23789 .6119 L F
.699 .16 0 r
.23481 .60956 m .2369 .61188 L .23789 .6119 L F
.981 .766 .539 r
.23777 .60994 m .23688 .61186 L .23481 .60956 L F
.239 .61009 m .23825 .61072 L .23777 .60994 L F
.23825 .61072 m .23688 .61186 L .23777 .60994 L F
.513 .529 .809 r
.23978 .60569 m .239 .61009 L .23825 .61072 L F
.702 .248 .17 r
.23968 .61022 m .23943 .61052 L .239 .61009 L F
.24348 .61096 m .23943 .61052 L .23968 .61022 L F
.513 .529 .809 r
.23978 .60569 m .24264 .61033 L .239 .61009 L F
.403 .282 .6 r
.24124 .61236 m .23896 .61322 L .239 .61009 L F
.158 .073 .502 r
.23825 .61072 m .24013 .61044 L .23978 .60569 L F
.981 .766 .539 r
.239 .61009 m .23899 .61085 L .23824 .61122 L F
.158 .073 .502 r
.23822 .61168 m .23825 .61072 L .23825 .61072 L F
.981 .766 .539 r
.23825 .61072 m .23824 .61122 L .2369 .61188 L F
.239 .61009 m .23824 .61122 L .23825 .61072 L F
.158 .073 .502 r
.23789 .6119 m .23822 .61168 L .23825 .61072 L F
.981 .766 .539 r
.23899 .61085 m .23821 .61169 L .2369 .61188 L F
.158 .073 .502 r
.23822 .61168 m .23866 .6114 L .23825 .61072 L F
.23866 .6114 m .24013 .61044 L .23825 .61072 L F
.981 .766 .539 r
.239 .61009 m .2369 .61188 L .23688 .61186 L F
.466 .891 .849 r
.23789 .6119 m .2369 .61188 L .23738 .61181 L F
.981 .766 .539 r
.23898 .61159 m .23896 .61322 L .2369 .61188 L F
.466 .891 .849 r
.23738 .61181 m .2369 .61188 L .23715 .61177 L F
.23871 .61137 m .2402 .61043 L .24013 .61044 L F
.23868 .61139 m .2402 .61043 L .23871 .61137 L F
.23868 .61139 m .23715 .61177 L .2402 .61043 L F
.23789 .6119 m .23715 .61177 L .23868 .61139 L F
.651 .957 .938 r
.24348 .61096 m .24382 .60949 L .24418 .60958 L F
.24348 .61096 m .24264 .61033 L .24382 .60949 L F
.24418 .60958 m .24382 .60949 L .24444 .60905 L F
.712 .968 .724 r
.24444 .60905 m .24286 .61068 L .24348 .61096 L F
.24286 .61068 m .24124 .61236 L .24162 .61212 L F
.24286 .61068 m .24162 .61212 L .24348 .61096 L F
.546 .543 .803 r
.24444 .60905 m .24264 .61033 L .24178 .60893 L F
.24294 .60797 m .24178 .60893 L .23978 .60569 L F
.24444 .60905 m .24373 .60902 L .24372 .60876 L F
.652 .442 .586 r
.24682 .60777 m .24444 .60905 L .24372 .60876 L F
.546 .543 .803 r
.24444 .60905 m .24372 .60876 L .24372 .60853 L F
.24373 .60902 m .24178 .60893 L .24372 .60853 L F
.652 .442 .586 r
.24372 .60876 m .24444 .60905 L .243 .60899 L F
.546 .543 .803 r
.24444 .60905 m .24372 .60853 L .243 .60899 L F
.24372 .60853 m .24178 .60893 L .24294 .60797 L F
.24372 .60853 m .23978 .60569 L .243 .60899 L F
.652 .442 .586 r
.24682 .60777 m .24372 .60876 L .2438 .60848 L F
.2463 .60688 m .2438 .60848 L .24488 .60447 L F
.24682 .60777 m .2438 .60848 L .2463 .60688 L F
.24372 .60876 m .243 .60899 L .24369 .60735 L F
.24372 .60876 m .24369 .60735 L .24488 .60447 L F
.445 .37 .679 r
.243 .60899 m .24377 .60962 L .24439 .60677 L F
.24369 .60735 m .24439 .60677 L .24488 .60447 L F
.243 .60899 m .24439 .60677 L .24369 .60735 L F
.784 .534 .559 r
.24824 .60946 m .24398 .61164 L .24444 .60905 L F
.24398 .61164 m .24369 .61179 L .24392 .61095 L F
.24398 .61164 m .24421 .60989 L .24428 .60993 L F
.477 .294 .553 r
.24444 .60905 m .24369 .61179 L .24124 .61236 L F
.14 0 .021 r
.24381 .60965 m .24393 .6107 L .24457 .61028 L F
.24352 .60941 m .24354 .6095 L .24381 .60965 L F
.24354 .6095 m .24393 .6107 L .24381 .60965 L F
.784 .534 .559 r
.24398 .61164 m .24392 .61095 L .24421 .60989 L F
.24428 .60993 m .24421 .60989 L .24444 .60905 L F
.445 .37 .679 r
.2438 .60959 m .24457 .61028 L .24466 .6086 L F
.24377 .60962 m .24381 .60965 L .2438 .60959 L F
.24381 .60965 m .24457 .61028 L .2438 .60959 L F
.24377 .60962 m .24466 .6086 L .24488 .60447 L F
.14 0 .021 r
.243 .60899 m .24319 .60933 L .24352 .60941 L F
.24319 .60933 m .24393 .6107 L .24352 .60941 L F
0 0 .21 r
.30178 .60227 m .30086 .60373 L .30079 .60695 L F
.30178 .60227 m .30079 .60695 L .30104 .60489 L F
0 0 0 r
.30251 .60111 m .30178 .60227 L .30104 .60489 L F
.30308 .6002 m .30086 .60372 L .30178 .60227 L F
.30308 .6002 m .30178 .60227 L .30128 .59926 L F
.30272 .60059 m .30178 .60227 L .30251 .60111 L F
.30086 .60372 m .30086 .60373 L .30178 .60227 L F
.942 .876 .742 r
.55623 .44056 m .55856 .43652 L .55681 .43523 L F
.919 .89 .787 r
.55681 .43523 m .55856 .43652 L .56016 .43234 L F
.026 .598 .742 r
.42835 .58732 m .43151 .58732 L .43296 .58739 L F
.764 .994 .802 r
.43356 .58573 m .43296 .58739 L .43541 .5851 L F
.913 .963 .802 r
.43296 .58739 m .43151 .58732 L .43189 .58544 L F
.43296 .58739 m .43151 .58732 L .43189 .58544 L F
.97 .899 .695 r
.43151 .58732 m .43296 .58739 L .43356 .58573 L F
.43151 .58732 m .43197 .5901 L .43296 .58739 L F
.927 .686 .554 r
.55386 .45034 m .55162 .44692 L .55102 .44947 L F
.915 .799 .717 r
.55102 .44947 m .55233 .45388 L .55386 .45034 L F
0 0 0 r
.48961 .40689 m .49158 .40589 L .49309 .40495 L F
.4939 .40468 m .49249 .40617 L .4944 .40453 L F
.49323 .40489 m .4939 .40468 L .49578 .40378 L F
.625 .941 .724 r
.49578 .40378 m .4939 .40468 L .49723 .40196 L F
0 0 0 r
.4939 .40468 m .4944 .40453 L .49553 .40356 L F
.49309 .40495 m .4939 .40468 L .49323 .40489 L F
.49309 .40495 m .49158 .40589 L .4939 .40468 L F
.156 0 0 r
.5202 .43333 m .52061 .43265 L .51993 .4336 L F
.58 .889 .608 r
.41034 .55104 m .40762 .55365 L .40967 .5515 L F
.409 .417 .757 r
.40762 .55365 m .41139 .55566 L .40967 .5515 L F
.584 .809 .985 r
.40803 .55704 m .41139 .55566 L .40762 .55365 L F
.984 .711 .42 r
.53362 .38378 m .53198 .38527 L .53193 .3826 L F
.53362 .38378 m .53198 .38527 L .53193 .3826 L F
.828 .646 .655 r
.51757 .3902 m .52143 .39395 L .52151 .39036 L F
.649 .577 .761 r
.52143 .39395 m .52388 .39038 L .52151 .39036 L F
.374 0 .141 r
.43942 .56991 m .44071 .57001 L .4415 .56803 L F
.58 .166 .222 r
.44071 .57001 m .44552 .5696 L .4415 .56803 L F
.406 .43 .773 r
.27461 .65269 m .27338 .65524 L .27192 .65606 L F
.27461 .65269 m .27609 .65667 L .27338 .65524 L F
.787 .796 .86 r
.29085 .64644 m .29231 .64969 L .29555 .64645 L F
.877 .659 .134 r
.56402 .3724 m .56378 .37366 L .5635 .36969 L F
.64 .168 .116 r
.54555 .40761 m .544 .40852 L .54193 .40706 L F
.172 .702 .695 r
.54555 .40761 m .54791 .40703 L .544 .40852 L F
.95 .859 .439 r
.39355 .59005 m .39406 .5843 L .39696 .58679 L F
.39355 .59005 m .39284 .589 L .39406 .5843 L F
.667 .116 0 r
.39864 .59317 m .39655 .59273 L .39355 .59005 L F
.869 .434 .162 r
.39655 .59273 m .39284 .589 L .39355 .59005 L F
.934 .7 .221 r
.58938 .3949 m .59023 .39646 L .59016 .39387 L F
0 0 0 r
.59216 .3916 m .58938 .3949 L .59016 .39387 L F
.792 .549 .569 r
.32989 .56377 m .3251 .5641 L .32713 .56165 L F
.427 .577 .9 r
.31696 .59761 m .31304 .59487 L .31531 .59343 L F
.657 .273 .306 r
.66094 .3339 m .66378 .33619 L .66522 .33382 L F
.758 .394 .365 r
.66522 .33382 m .66378 .33619 L .66782 .33671 L F
.483 .267 .51 r
.2685 .53699 m .27109 .53654 L .27115 .53384 L F
.415 .187 .457 r
.27109 .53654 m .2739 .5333 L .27115 .53384 L F
.963 .736 .547 r
.32946 .519 m .33186 .51743 L .32933 .51618 L F
.32946 .519 m .33144 .52028 L .33186 .51743 L F
.8 .667 .716 r
.32619 .5968 m .33034 .59724 L .32874 .59325 L F
.751 .54 .61 r
.64004 .38085 m .64385 .38023 L .64112 .38043 L F
.455 .873 .94 r
.64265 .37993 m .64385 .38023 L .64004 .38085 L F
.4 .751 .994 r
.64533 .37891 m .64385 .38023 L .64265 .37993 L F
.64533 .37891 m .64663 .38014 L .64385 .38023 L F
.796 .764 .824 r
.5482 .46731 m .54915 .46274 L .54673 .46601 L F
.5482 .46731 m .55131 .4644 L .54915 .46274 L F
.497 .289 .527 r
.26574 .54036 m .26837 .53983 L .2685 .53699 L F
.407 .18 .454 r
.26837 .53983 m .27109 .53654 L .2685 .53699 L F
.873 .77 .745 r
.48317 .50387 m .47856 .50578 L .4789 .50317 L F
.48317 .50387 m .48071 .50726 L .47856 .50578 L F
.754 .583 .664 r
.48317 .50387 m .48309 .50666 L .48071 .50726 L F
.532 .07 .102 r
.65272 .34483 m .65292 .34621 L .64883 .34625 L F
.478 .032 .11 r
.65555 .34582 m .65292 .34621 L .65272 .34483 L F
.629 .912 .981 r
.65318 .37651 m .65401 .37448 L .65652 .37422 L F
.65318 .37651 m .65182 .37562 L .65401 .37448 L F
0 .559 .768 r
.41171 .59464 m .40798 .59412 L .40958 .59469 L F
.593 .947 .823 r
.31225 .65038 m .30962 .65211 L .31329 .64987 L F
.679 .652 .817 r
.30545 .65045 m .30728 .65365 L .30962 .65211 L F
.30545 .65045 m .30962 .65211 L .30864 .65216 L F
.593 .947 .823 r
.30864 .65216 m .30962 .65211 L .31225 .65038 L F
.679 .652 .817 r
.30728 .65365 m .30808 .65507 L .30962 .65211 L F
.439 0 0 r
.30808 .65507 m .30644 .65625 L .31027 .65599 L F
.453 .248 .511 r
.26569 .54321 m .26837 .53983 L .26574 .54036 L F
.132 0 .243 r
.46603 .52043 m .46569 .52307 L .46825 .5197 L F
.207 .264 .702 r
.57294 .35723 m .57445 .35675 L .57356 .35254 L F
.223 .317 .75 r
.57294 .35723 m .57564 .35897 L .57445 .35675 L F
.201 0 0 r
.48596 .40966 m .48864 .40888 L .48961 .40689 L F
0 0 0 r
.48961 .40689 m .48864 .40888 L .49158 .40589 L F
.73 .493 .569 r
.32722 .57622 m .32497 .57364 L .32906 .57519 L F
.32722 .57622 m .3247 .57729 L .32497 .57364 L F
.828 .646 .655 r
.51757 .3902 m .5169 .393 L .52143 .39395 L F
0 0 0 r
.51699 .39548 m .52143 .39395 L .5169 .393 L F
.51699 .39548 m .51972 .3948 L .52143 .39395 L F
.649 .577 .761 r
.52143 .39395 m .52412 .39413 L .52388 .39038 L F
.941 .926 .563 r
.52601 .39406 m .52308 .39784 L .52683 .39488 L F
.834 .997 .772 r
.52417 .39391 m .52231 .39377 L .52441 .39125 L F
.52412 .39413 m .52333 .39397 L .52417 .39391 L F
.52333 .39397 m .52231 .39377 L .52417 .39391 L F
0 0 0 r
.52143 .39395 m .52229 .39378 L .52412 .39413 L F
.52229 .39378 m .52231 .39377 L .52238 .39378 L F
.52229 .39378 m .52238 .39378 L .52412 .39413 L F
.52143 .39395 m .51972 .3948 L .52231 .39377 L F
.569 .534 .776 r
.52231 .39377 m .51972 .3948 L .51887 .39037 L F
.52231 .39377 m .51887 .39037 L .52069 .3909 L F
.538 .015 0 r
.52069 .3909 m .52497 .39058 L .52231 .39377 L F
.918 .766 .678 r
.52072 .39417 m .52243 .39686 L .52433 .39238 L F
.52024 .39441 m .52032 .39449 L .52072 .39417 L F
.52032 .39449 m .52243 .39686 L .52072 .39417 L F
.834 .997 .772 r
.5249 .39086 m .52441 .39125 L .52497 .39058 L F
.52417 .39391 m .52441 .39125 L .5249 .39086 L F
0 0 .363 r
.52388 .39038 m .52497 .39058 L .52671 .38961 L F
.538 .015 0 r
.52457 .39061 m .52358 .39193 L .52497 .39058 L F
.52069 .3909 m .52358 .39193 L .52457 .39061 L F
.918 .766 .678 r
.52055 .39418 m .523 .39302 L .52358 .39193 L F
.52072 .39417 m .52433 .39238 L .52055 .39418 L F
.538 .015 0 r
.52069 .3909 m .52358 .39193 L .52497 .39058 L F
.32 .516 .891 r
.52164 .38904 m .52358 .39193 L .52069 .3909 L F
.574 .537 .776 r
.51887 .39037 m .51972 .3948 L .51699 .39548 L F
.227 0 0 r
.52358 .39193 m .51944 .39433 L .52024 .39441 L F
.52358 .39193 m .52229 .39371 L .51944 .39433 L F
.304 .507 .889 r
.52478 .38979 m .52358 .39193 L .52164 .38904 L F
.479 .308 .571 r
.52449 .39026 m .52255 .3933 L .52358 .39193 L F
.52255 .3933 m .52229 .39371 L .52358 .39193 L F
.52478 .38979 m .52449 .39026 L .52358 .39193 L F
.918 .766 .678 r
.523 .39302 m .52433 .39238 L .52358 .39193 L F
.52024 .39441 m .52072 .39417 L .52055 .39418 L F
.941 .926 .563 r
.52433 .39238 m .52398 .39391 L .52601 .39406 L F
.52398 .39391 m .52308 .39784 L .52601 .39406 L F
.954 .851 .702 r
.39159 .55347 m .39403 .55755 L .39343 .55423 L F
.667 .623 .795 r
.39343 .55423 m .39403 .55755 L .39644 .55337 L F
.569 .498 .736 r
.39644 .55337 m .39403 .55755 L .39687 .55617 L F
0 .036 .606 r
.57087 .36785 m .57387 .37196 L .57228 .37061 L F
0 0 .51 r
.57378 .37184 m .57228 .37061 L .57387 .37196 L F
.57378 .37184 m .57276 .37403 L .57228 .37061 L F
.893 .799 .749 r
.33481 .57955 m .33687 .58041 L .33557 .57665 L F
.82 .714 .747 r
.33481 .57955 m .33645 .58282 L .33687 .58041 L F
.745 .488 .541 r
.38614 .51624 m .38938 .51954 L .38942 .51686 L F
.63 .32 .428 r
.38938 .51954 m .39172 .51944 L .38942 .51686 L F
.881 .784 .75 r
.40148 .53266 m .40251 .53661 L .40314 .53384 L F
.476 .76 .993 r
.3952 .49196 m .39721 .49356 L .39441 .49388 L F
.974 .702 .449 r
.39721 .49356 m .3952 .49196 L .39441 .49388 L F
.383 .511 .863 r
.40266 .52974 m .40314 .53384 L .40148 .53266 L F
.40266 .52974 m .40562 .53408 L .40314 .53384 L F
.273 .604 .953 r
.40314 .53384 m .40425 .53237 L .40148 .53266 L F
.40314 .53384 m .40562 .53408 L .40425 .53237 L F
.415 0 0 r
.59706 .34287 m .59989 .34406 L .60106 .34375 L F
.74 .766 .874 r
.49687 .42908 m .49852 .43083 L .49462 .43035 L F
.368 .62 .949 r
.49958 .42893 m .49852 .43083 L .49687 .42908 L F
.546 .837 .998 r
.49958 .42893 m .50128 .43006 L .49852 .43083 L F
.231 .106 .495 r
.28382 .54114 m .28311 .54335 L .28325 .53977 L F
0 .052 .618 r
.57249 .36811 m .57087 .36785 L .56966 .36612 L F
.57249 .36811 m .57387 .37196 L .57087 .36785 L F
0 0 0 r
.45998 .43006 m .46169 .42912 L .46339 .42788 L F
.46339 .42788 m .46169 .42912 L .46411 .42795 L F
.823 .789 .82 r
.68213 .36431 m .68283 .35964 L .68137 .36294 L F
.68213 .36431 m .68477 .36085 L .68283 .35964 L F
.98 .913 .609 r
.68045 .36526 m .68213 .36431 L .68137 .36294 L F
.561 .891 .986 r
.30373 .59852 m .30308 .6002 L .30128 .59926 L F
.30373 .59852 m .30587 .5994 L .30308 .6002 L F
.626 .886 .988 r
.52306 .46648 m .51945 .46645 L .52182 .46533 L F
.773 .936 .936 r
.52306 .46648 m .52546 .46292 L .5261 .46359 L F
.52306 .46648 m .52182 .46533 L .52546 .46292 L F
.955 .941 .724 r
.32713 .56165 m .3251 .5641 L .32545 .56034 L F
.351 .152 .464 r
.25934 .57695 m .25969 .57927 L .25728 .58002 L F
.606 .539 .753 r
.25969 .57927 m .25759 .58314 L .25728 .58002 L F
.745 .991 .803 r
.43561 .58329 m .43541 .5851 L .43785 .58413 L F
.43561 .58329 m .43356 .58573 L .43541 .5851 L F
.748 .52 .585 r
.39828 .5298 m .40203 .52727 L .39978 .5262 L F
.39828 .5298 m .40099 .53005 L .40203 .52727 L F
.9 .917 .823 r
.53227 .45681 m .53276 .45221 L .53431 .45339 L F
.53227 .45681 m .53023 .45564 L .53276 .45221 L F
.398 .282 .604 r
.53431 .45339 m .53434 .45603 L .53227 .45681 L F
.653 .564 .742 r
.53592 .45801 m .53227 .45681 L .53434 .45603 L F
.4 .014 .187 r
.39391 .46703 m .39791 .46602 L .39817 .46411 L F
.472 .072 .2 r
.39791 .46602 m .40041 .46555 L .39817 .46411 L F
.465 .078 .219 r
.39817 .46411 m .40041 .46555 L .40117 .46383 L F
0 0 .086 r
.50326 .44215 m .50318 .43991 L .50521 .43856 L F
.819 .593 .596 r
.3469 .63316 m .35099 .63025 L .35001 .63025 L F
.3469 .63316 m .35146 .63438 L .35099 .63025 L F
.88 .977 .678 r
.44755 .56081 m .44983 .55712 L .44786 .55848 L F
.875 .978 .679 r
.44983 .55712 m .45007 .55485 L .44786 .55848 L F
.816 .927 .908 r
.53309 .47928 m .53454 .4756 L .53169 .47831 L F
.53309 .47928 m .53586 .47675 L .53454 .4756 L F
.627 .498 .686 r
.31783 .6504 m .32065 .64911 L .31967 .64616 L F
.504 .246 .457 r
.31783 .6504 m .31994 .65259 L .32065 .64911 L F
.31783 .6504 m .31722 .65307 L .31994 .65259 L F
.91 .924 .813 r
.65957 .36025 m .6557 .36258 L .65809 .3586 L F
.65737 .36319 m .65626 .36466 L .6557 .36258 L F
0 .464 .793 r
.65626 .36466 m .65658 .36441 L .6557 .36258 L F
.872 .566 .467 r
.65658 .36441 m .65463 .36219 L .6557 .36258 L F
.65463 .36219 m .65397 .36144 L .6557 .36258 L F
.91 .924 .813 r
.65957 .36025 m .65737 .36319 L .6557 .36258 L F
.489 .208 .415 r
.53914 .40693 m .53538 .40984 L .53573 .40751 L F
.53914 .40693 m .53797 .41007 L .53538 .40984 L F
.633 .273 .343 r
.53914 .40693 m .541 .4097 L .53797 .41007 L F
.53914 .40693 m .54193 .40706 L .541 .4097 L F
0 0 0 r
.41945 .45583 m .42188 .45487 L .42347 .45317 L F
.42347 .45317 m .42532 .45291 L .42605 .45209 L F
.42404 .4538 m .42347 .45317 L .42188 .45487 L F
.42404 .4538 m .42532 .45291 L .42347 .45317 L F
.932 .687 .545 r
.32626 .5438 m .32344 .54541 L .32399 .5426 L F
.32626 .5438 m .32583 .54676 L .32344 .54541 L F
.4 .495 .841 r
.23896 .61322 m .23856 .61469 L .23728 .61287 L F
.353 .445 .816 r
.23896 .61322 m .24056 .61677 L .23856 .61469 L F
.628 .818 .973 r
.54326 .42131 m .54213 .42394 L .54065 .42253 L F
.54326 .42131 m .54469 .4231 L .54213 .42394 L F
.088 0 0 r
.54213 .42394 m .54469 .4231 L .54328 .42472 L F
.54213 .42394 m .54328 .42472 L .54065 .42253 L F
.291 0 0 r
.52332 .40061 m .51851 .40222 L .51865 .39994 L F
.52332 .40061 m .51933 .40229 L .51851 .40222 L F
0 .089 .646 r
.52308 .39784 m .52332 .40061 L .52157 .39656 L F
.883 .974 .835 r
.52308 .39784 m .51933 .40229 L .52332 .40061 L F
.626 .62 .825 r
.52332 .40061 m .52703 .4011 L .52514 .39959 L F
.621 .43 .603 r
.27486 .64975 m .27785 .64686 L .27282 .64657 L F
.852 .394 .036 r
.27282 .64657 m .27486 .64975 L .27302 .64875 L F
.685 .692 .851 r
.31924 .59916 m .32253 .60019 L .32182 .5962 L F
.754 .616 .706 r
.31924 .59916 m .32093 .60337 L .32253 .60019 L F
.729 .722 .844 r
.32182 .5962 m .32253 .60019 L .32619 .5968 L F
.297 .781 .709 r
.45799 .55002 m .45342 .55165 L .45549 .54974 L F
.764 .988 .896 r
.45496 .55033 m .45342 .55165 L .45559 .5508 L F
0 0 0 r
.45549 .54974 m .45342 .55165 L .45199 .55288 L F
.764 .988 .896 r
.45427 .54982 m .45342 .55165 L .45496 .55033 L F
0 0 0 r
.45199 .55288 m .45342 .55165 L .4516 .55324 L F
.902 .986 .76 r
.6589 .37062 m .65652 .37422 L .65701 .37106 L F
.884 .982 .823 r
.65701 .37106 m .65652 .37422 L .65401 .37448 L F
.745 .705 .813 r
.2926 .63565 m .29421 .63774 L .28988 .63698 L F
.711 .731 .867 r
.29509 .63346 m .29421 .63774 L .2926 .63565 L F
.29509 .63346 m .29657 .63636 L .29421 .63774 L F
.654 .65 .834 r
.59768 .3639 m .59351 .36137 L .597 .3603 L F
0 0 .031 r
.59768 .3639 m .59766 .36676 L .59744 .36694 L F
.285 .366 .771 r
.597 .3603 m .59968 .36198 L .59768 .3639 L F
0 0 .124 r
.59968 .36198 m .59766 .36676 L .59768 .3639 L F
.79 .686 .75 r
.31639 .60251 m .31843 .60451 L .31712 .60061 L F
.689 .585 .733 r
.31843 .60451 m .31924 .59916 L .31712 .60061 L F
.31843 .60451 m .32093 .60337 L .31924 .59916 L F
.811 .983 .89 r
.52144 .48752 m .51724 .4895 L .51845 .49045 L F
.868 .622 .564 r
.36496 .53379 m .36243 .53312 L .36232 .53029 L F
.846 .576 .53 r
.36511 .53641 m .36243 .53312 L .36496 .53379 L F
.796 .822 .872 r
.43036 .5885 m .43197 .5901 L .43151 .58732 L F
.655 .784 .943 r
.42945 .58878 m .43197 .5901 L .43036 .5885 L F
.457 .827 .575 r
.45998 .43006 m .45629 .43294 L .4582 .4313 L F
0 0 0 r
.4582 .4313 m .46169 .42912 L .45998 .43006 L F
0 0 .466 r
.56688 .41273 m .56799 .41684 L .56707 .41448 L F
.59 .855 .509 r
.59421 .38782 m .59368 .38868 L .59644 .38723 L F
.59421 .38782 m .59265 .38984 L .59368 .38868 L F
0 .179 .698 r
.23946 .59826 m .24069 .59994 L .23923 .59633 L F
.881 .507 .032 r
.53949 .44661 m .54138 .45045 L .537 .45005 L F
.757 .633 .724 r
.537 .45005 m .54138 .45045 L .53888 .45398 L F
.584 .809 .985 r
.40803 .55704 m .41163 .55709 L .41139 .55566 L F
.716 .475 .559 r
.40803 .55704 m .41151 .56 L .41163 .55709 L F
.342 .616 .952 r
.41163 .55709 m .41328 .55532 L .41139 .55566 L F
0 0 .226 r
.41163 .55709 m .41267 .55804 L .41328 .55532 L F
.41163 .55709 m .41151 .56 L .41267 .55804 L F
.117 0 .4 r
.28907 .52827 m .28691 .52712 L .28748 .5254 L F
.28907 .52827 m .28678 .52984 L .28691 .52712 L F
0 0 0 r
.31589 .65716 m .31154 .66088 L .31539 .65817 L F
.343 0 .054 r
.31477 .66022 m .31539 .65817 L .31154 .66088 L F
0 0 .071 r
.31589 .65716 m .31539 .65817 L .316 .65909 L F
0 0 0 r
.316 .65909 m .31539 .65817 L .31477 .66022 L F
.805 .404 .292 r
.39315 .54585 m .39452 .54644 L .39521 .54477 L F
.687 .372 .437 r
.39779 .54351 m .39315 .54585 L .39521 .54477 L F
.965 .831 .661 r
.41163 .54012 m .41126 .5422 L .40974 .54022 L F
.41163 .54012 m .41126 .5422 L .40974 .54022 L F
.422 .215 .491 r
.26043 .55023 m .26322 .54989 L .26302 .54678 L F
.354 .094 .375 r
.26032 .55288 m .26322 .54989 L .26043 .55023 L F
.855 .748 .745 r
.54915 .46274 m .55131 .4644 L .54986 .46006 L F
.959 .732 .551 r
.36036 .50211 m .36194 .50627 L .36267 .50327 L F
.798 .45 .398 r
.6719 .34232 m .67608 .34161 L .6718 .33966 L F
.6719 .34232 m .67597 .3434 L .67608 .34161 L F
.108 .162 .638 r
.5857 .38359 m .58642 .37902 L .58375 .38013 L F
.5857 .38359 m .58755 .38233 L .58642 .37902 L F
0 0 0 r
.58392 .38645 m .58755 .38233 L .5857 .38359 L F
.544 .79 .989 r
.30174 .63256 m .30611 .63334 L .30352 .63397 L F
.163 .283 .741 r
.3146 .65383 m .31589 .65716 L .317 .65588 L F
0 0 .071 r
.31589 .65716 m .316 .65909 L .317 .65588 L F
.9 .925 .826 r
.46815 .53828 m .46876 .5407 L .47079 .53766 L F
.845 .572 .526 r
.46568 .54219 m .46876 .5407 L .46815 .53828 L F
.46568 .54219 m .46862 .5423 L .46876 .5407 L F
.866 .928 .864 r
.54621 .4107 m .54335 .41389 L .54225 .41239 L F
0 .239 .733 r
.54225 .41239 m .54335 .41389 L .546 .41563 L F
.54 .559 .823 r
.54335 .41389 m .54742 .41727 L .546 .41563 L F
.859 .721 .709 r
.37499 .47285 m .37932 .47078 L .3746 .47189 L F
.37499 .47285 m .37769 .47338 L .37932 .47078 L F
0 0 0 r
.32778 .68154 m .32662 .68208 L .32971 .67953 L F
.142 .108 .556 r
.28653 .66311 m .28743 .65985 L .28816 .66245 L F
.781 .291 .051 r
.28704 .66561 m .28865 .66474 L .28653 .66311 L F
.28704 .66561 m .28653 .66311 L .28816 .66245 L F
.81 .585 .597 r
.6791 .35606 m .68305 .35399 L .67926 .35327 L F
.6791 .35606 m .68308 .35678 L .68305 .35399 L F
.096 0 0 r
.42492 .46008 m .42368 .46218 L .42131 .46315 L F
.317 0 .147 r
.42492 .46008 m .42642 .46206 L .42368 .46218 L F
.42492 .46008 m .42832 .45949 L .42642 .46206 L F
.709 .907 .965 r
.60725 .35146 m .60642 .3537 L .60792 .35224 L F
.803 .992 .877 r
.60725 .35146 m .60375 .35401 L .60642 .3537 L F
.182 0 .162 r
.56043 .40236 m .55794 .40327 L .56103 .39996 L F
.849 .895 .87 r
.56357 .39683 m .56103 .39996 L .55918 .39829 L F
.815 .446 .357 r
.3474 .51362 m .34518 .51548 L .34497 .51332 L F
.3474 .51362 m .34907 .51652 L .34518 .51548 L F
.936 .816 .702 r
.37053 .54374 m .36716 .54588 L .36802 .54288 L F
.37053 .54374 m .3694 .54661 L .36716 .54588 L F
.767 .696 .784 r
.27609 .65667 m .27795 .66038 L .27391 .65966 L F
.965 .641 .272 r
.27795 .66038 m .27609 .65667 L .27391 .65966 L F
.974 .81 .617 r
.27795 .66038 m .27539 .66312 L .27391 .65966 L F
.27795 .66038 m .27767 .66193 L .27539 .66312 L F
.522 .614 .885 r
.27923 .65674 m .27795 .66038 L .27609 .65667 L F
.27923 .65674 m .28078 .66011 L .27795 .66038 L F
.767 .696 .784 r
.27609 .65667 m .27795 .66038 L .27391 .65966 L F
.908 .896 .483 r
.61502 .39663 m .61453 .39578 L .61581 .39421 L F
0 0 0 r
.61581 .39421 m .6164 .39403 L .61781 .39112 L F
.61581 .39421 m .61657 .39381 L .6164 .39403 L F
.61581 .39421 m .61453 .39578 L .61657 .39381 L F
.475 .077 .204 r
.51851 .40222 m .51625 .40077 L .51865 .39994 L F
.51851 .40222 m .51504 .40326 L .51625 .40077 L F
.494 .285 .525 r
.40519 .56033 m .4078 .56014 L .40803 .55704 L F
.311 .146 .489 r
.40519 .56033 m .4074 .56211 L .4078 .56014 L F
.40519 .56033 m .40537 .56303 L .4074 .56211 L F
0 .06 .611 r
.55913 .40705 m .55794 .40327 L .55558 .40693 L F
.514 .551 .832 r
.55558 .40693 m .55852 .40905 L .55913 .40705 L F
.7 .755 .894 r
.34122 .62232 m .34299 .62387 L .33871 .62321 L F
.769 .762 .847 r
.34385 .61919 m .34299 .62387 L .34122 .62232 L F
.34385 .61919 m .34605 .62103 L .34299 .62387 L F
.808 .768 .816 r
.30233 .6132 m .30599 .61366 L .30446 .61065 L F
.746 .308 .211 r
.30402 .61541 m .30599 .61366 L .30233 .6132 L F
.55 .833 .998 r
.29251 .53966 m .28999 .5404 L .28817 .53924 L F
.778 .816 .883 r
.30599 .61366 m .30687 .60941 L .30446 .61065 L F
.30599 .61366 m .30883 .61138 L .30687 .60941 L F
0 .037 .57 r
.40974 .54022 m .41074 .54116 L .41126 .5422 L F
.892 .786 .296 r
.41074 .54116 m .41065 .54176 L .41126 .5422 L F
.851 .393 .066 r
.40811 .54061 m .4107 .54204 L .40974 .54022 L F
.892 .786 .296 r
.4108 .54187 m .41021 .54497 L .41126 .5422 L F
.851 .393 .066 r
.4107 .54204 m .41103 .54222 L .4108 .54187 L F
.4107 .54204 m .4108 .54187 L .40974 .54022 L F
.892 .786 .296 r
.41065 .54176 m .41059 .54223 L .4108 .54187 L F
.98 .699 .412 r
.40813 .54365 m .41021 .54497 L .40811 .54061 L F
.985 .786 .555 r
.4107 .54204 m .40813 .54365 L .40811 .54061 L F
.41103 .54222 m .41061 .54243 L .4107 .54204 L F
.41061 .54243 m .40813 .54365 L .4107 .54204 L F
.892 .786 .296 r
.4107 .54204 m .41021 .54497 L .4108 .54187 L F
.41059 .54223 m .41049 .54294 L .4107 .54204 L F
.985 .786 .555 r
.41061 .54243 m .41021 .54497 L .40813 .54365 L F
.892 .786 .296 r
.41061 .54243 m .41021 .54497 L .4107 .54204 L F
.985 .786 .555 r
.41103 .54222 m .41021 .54497 L .41061 .54243 L F
.892 .786 .296 r
.41049 .54294 m .41021 .54497 L .41061 .54243 L F
.672 .226 0 r
.41126 .5422 m .41103 .54222 L .4108 .54187 L F
.41126 .5422 m .4108 .54187 L .40974 .54022 L F
.775 .778 .275 r
.41126 .5422 m .41021 .54497 L .41103 .54222 L F
.135 0 0 r
.31483 .51307 m .31822 .51026 L .31367 .51003 L F
.31483 .51307 m .31616 .51268 L .31822 .51026 L F
.601 .21 .274 r
.31822 .51026 m .31616 .51268 L .32086 .51243 L F
.577 .224 .334 r
.31822 .51026 m .32086 .51243 L .32072 .5104 L F
.866 .966 .86 r
.50073 .50573 m .50202 .50208 L .49916 .50485 L F
.50073 .50573 m .50333 .50281 L .50202 .50208 L F
.994 .755 .456 r
.2893 .55369 m .28858 .55388 L .28926 .55031 L F
.28926 .55031 m .28858 .55388 L .2893 .55369 L F
.976 .814 .616 r
.35319 .62644 m .35238 .62301 L .35319 .62622 L F
.705 .782 .3 r
.35216 .6288 m .35319 .62644 L .35319 .62622 L F
.887 .99 .784 r
.5185 .47383 m .51586 .47742 L .51639 .47471 L F
.819 .952 .905 r
.51639 .47471 m .51586 .47742 L .51465 .47637 L F
.356 .424 .795 r
.35411 .65049 m .35142 .647 L .35403 .64654 L F
.042 .434 .871 r
.58195 .37968 m .58257 .37865 L .58135 .37638 L F
.58195 .37968 m .58375 .38013 L .58257 .37865 L F
.509 .632 .907 r
.31359 .6856 m .31502 .68833 L .31732 .68777 L F
.266 0 .127 r
.31732 .68777 m .31502 .68833 L .31438 .6901 L F
.31438 .6901 m .31502 .68833 L .31732 .68777 L F
.858 .405 .084 r
.65843 .35406 m .65733 .35497 L .65529 .35147 L F
.901 .485 .138 r
.65843 .35406 m .65912 .35657 L .65733 .35497 L F
.709 .717 .856 r
.28737 .63841 m .28269 .6373 L .28527 .63701 L F
.711 .897 .963 r
.28811 .63597 m .28737 .63841 L .28527 .63701 L F
.28811 .63597 m .28988 .63698 L .28737 .63841 L F
.752 .993 .867 r
.50782 .39402 m .50447 .39669 L .50555 .39434 L F
.765 .986 .749 r
.50447 .39669 m .50416 .3962 L .50555 .39434 L F
0 .244 .743 r
.39603 .47209 m .39705 .4736 L .39742 .47346 L F
.626 .691 .891 r
.38626 .47214 m .38829 .47258 L .3886 .47221 L F
.333 .22 .572 r
.38833 .47029 m .38626 .47214 L .3886 .47221 L F
0 0 .371 r
.38833 .47029 m .3886 .47221 L .38941 .47136 L F
.736 .354 .327 r
.3886 .47221 m .38636 .47398 L .38901 .47171 L F
.3886 .47221 m .38901 .47171 L .38941 .47136 L F
.626 .691 .891 r
.38829 .47258 m .38922 .47279 L .3886 .47221 L F
.061 0 0 r
.38922 .47279 m .39297 .47161 L .39111 .47269 L F
.38922 .47279 m .39111 .47269 L .3886 .47221 L F
.809 .657 .695 r
.3938 .5233 m .39784 .52668 L .39758 .5239 L F
.376 .288 .628 r
.39784 .52668 m .39978 .5262 L .39758 .5239 L F
.557 .745 .965 r
.51724 .42612 m .51503 .4271 L .51278 .42458 L F
0 0 0 r
.51393 .42815 m .51503 .4271 L .51724 .42612 L F
.561 .612 .861 r
.5879 .41383 m .58427 .41099 L .5869 .40989 L F
.86 .563 .035 r
.5879 .41383 m .58776 .41547 L .58567 .41548 L F
.5879 .41383 m .5884 .41647 L .58776 .41547 L F
.013 .168 .681 r
.58883 .4117 m .5879 .41383 L .5869 .40989 L F
.86 .563 .035 r
.58776 .41547 m .5884 .41647 L .5879 .41383 L F
.58776 .41547 m .5879 .41383 L .58883 .4117 L F
.901 .981 .797 r
.6614 .36715 m .6589 .37062 L .65881 .36854 L F
.918 .978 .747 r
.6589 .37062 m .65701 .37106 L .65881 .36854 L F
.563 .628 .875 r
.51396 .45379 m .50891 .45095 L .51264 .45208 L F
0 0 .512 r
.51264 .45208 m .51271 .45589 L .51396 .45379 L F
.841 .47 .349 r
.35143 .51679 m .34945 .51871 L .34907 .51652 L F
.35143 .51679 m .35316 .51976 L .34945 .51871 L F
.621 .942 .736 r
.46715 .43592 m .47091 .43339 L .47025 .43321 L F
.61 .949 .926 r
.47226 .43163 m .47091 .43339 L .4721 .43255 L F
.631 .961 .828 r
.47025 .43321 m .47091 .43339 L .47226 .43163 L F
.624 .919 .977 r
.5076 .42567 m .50798 .42659 L .50454 .42721 L F
.947 .618 .194 r
.50735 .42831 m .50798 .42659 L .5076 .42567 L F
.50735 .42831 m .50858 .42948 L .50798 .42659 L F
.925 .594 .394 r
.51105 .42629 m .50994 .42368 L .50798 .42659 L F
.927 .645 .487 r
.34088 .50706 m .33846 .50902 L .33946 .50552 L F
.34088 .50706 m .34083 .51002 L .33846 .50902 L F
.804 .314 0 r
.41669 .56356 m .41837 .56391 L .41738 .56235 L F
.41669 .56356 m .41988 .56597 L .41837 .56391 L F
.724 .793 .907 r
.3278 .62378 m .32921 .62655 L .325 .62603 L F
.778 .729 .808 r
.325 .62603 m .32921 .62655 L .32696 .6278 L F
.74 .801 .901 r
.33214 .62402 m .32921 .62655 L .3278 .62378 L F
.43 .265 .555 r
.26302 .54678 m .26564 .54629 L .26569 .54321 L F
.392 .183 .474 r
.26322 .54989 m .26564 .54629 L .26302 .54678 L F
0 0 .165 r
.35371 .63972 m .35374 .64046 L .35313 .63661 L F
.827 .939 .571 r
.35371 .63972 m .35231 .64222 L .35374 .64046 L F
.473 .877 .723 r
.31907 .64629 m .31967 .64616 L .32209 .64465 L F
.656 .677 .858 r
.31967 .64616 m .32371 .64637 L .32209 .64465 L F
.321 .014 .278 r
.32065 .64911 m .32371 .64637 L .31967 .64616 L F
.729 .61 .724 r
.50891 .45095 m .5104 .45206 L .50725 .453 L F
.05 0 0 r
.50834 .45298 m .5104 .45206 L .50741 .45301 L F
0 0 0 r
.50741 .45301 m .5104 .45206 L .50725 .453 L F
.288 .544 .919 r
.50891 .45095 m .5104 .45206 L .51264 .45208 L F
.526 .076 .124 r
.50834 .45298 m .51264 .45208 L .5104 .45206 L F
.991 .798 .549 r
.42588 .5855 m .42655 .58906 L .42835 .58732 L F
.6 .145 .143 r
.42835 .58732 m .42655 .58906 L .43036 .5885 L F
.481 .306 .565 r
.42835 .58732 m .43036 .5885 L .43151 .58732 L F
.687 .663 .82 r
.26143 .57322 m .25934 .57695 L .25893 .57389 L F
.26143 .57322 m .26317 .57695 L .25934 .57695 L F
0 0 0 r
.26317 .57695 m .25969 .57927 L .25934 .57695 L F
.601 .241 .33 r
.54193 .40706 m .544 .40852 L .541 .4097 L F
0 0 .297 r
.35371 .63972 m .35313 .63661 L .35375 .63556 L F
.97 .722 .505 r
.57378 .37184 m .57548 .376 L .57276 .37403 L F
0 0 0 r
.48131 .49952 m .48396 .49572 L .48248 .49757 L F
.304 .034 .329 r
.43764 .45384 m .43686 .4558 L .43473 .457 L F
0 0 0 r
.43686 .4558 m .43414 .45928 L .43473 .457 L F
.503 .085 .18 r
.43473 .457 m .43414 .45928 L .43051 .45929 L F
.381 .625 .949 r
.31206 .58794 m .3134 .5898 L .31125 .58994 L F
.814 .466 .397 r
.5624 .38652 m .56065 .38886 L .56037 .38666 L F
.889 .579 .455 r
.5624 .38652 m .56291 .38992 L .56065 .38886 L F
.716 .475 .559 r
.40803 .55704 m .4078 .56014 L .41151 .56 L F
.619 .934 .704 r
.43672 .56687 m .43351 .56911 L .43483 .57036 L F
.43672 .56687 m .43405 .56832 L .43351 .56911 L F
.46 .856 .664 r
.43877 .56527 m .43672 .56687 L .44021 .56613 L F
0 0 0 r
.43409 .57009 m .43351 .56911 L .43432 .56814 L F
.592 .94 .779 r
.43476 .56761 m .43405 .56832 L .43877 .56527 L F
0 0 0 r
.43471 .56781 m .43432 .56814 L .43476 .56761 L F
.46 .856 .664 r
.43877 .56527 m .43428 .56817 L .43672 .56687 L F
0 0 0 r
.43409 .57009 m .43432 .56814 L .43471 .56781 L F
.46 .856 .664 r
.43428 .56817 m .43405 .56832 L .4342 .56824 L F
.43428 .56817 m .4342 .56824 L .43672 .56687 L F
.758 .823 .903 r
.28979 .6503 m .29014 .65345 L .28599 .65313 L F
.819 .721 .756 r
.28599 .65313 m .29014 .65345 L .28732 .65677 L F
.565 .344 .539 r
.29014 .65345 m .29007 .65623 L .28732 .65677 L F
0 0 .442 r
.29054 .65193 m .29014 .65345 L .28987 .65104 L F
0 0 .278 r
.29143 .65489 m .29014 .65345 L .29054 .65193 L F
0 0 .485 r
.29198 .6537 m .29143 .65489 L .29054 .65193 L F
.29168 .65345 m .29054 .65193 L .28889 .65111 L F
.29198 .6537 m .29054 .65193 L .29168 .65345 L F
0 0 .442 r
.29054 .65193 m .28987 .65104 L .28979 .6503 L F
0 0 .278 r
.29143 .65489 m .29007 .65623 L .29014 .65345 L F
0 0 0 r
.41034 .55104 m .40967 .5515 L .41101 .55133 L F
.868 .536 .42 r
.66829 .33852 m .67154 .33734 L .66782 .33671 L F
.66829 .33852 m .6718 .33966 L .67154 .33734 L F
.792 .466 .435 r
.32498 .51546 m .32912 .51374 L .32494 .51296 L F
.32498 .51546 m .32933 .51618 L .32912 .51374 L F
.458 .845 .983 r
.58012 .37317 m .57552 .37321 L .57768 .36962 L F
.58012 .37317 m .57794 .37252 L .57642 .3732 L F
.039 .379 .844 r
.58135 .37638 m .57794 .37252 L .58012 .37317 L F
.363 .392 .757 r
.57794 .37252 m .58127 .37442 L .58069 .37127 L F
.57794 .37252 m .58069 .37127 L .58052 .37037 L F
.458 .845 .983 r
.57642 .3732 m .57794 .37252 L .57552 .37321 L F
.786 .725 .795 r
.3134 .5898 m .31531 .59343 L .3134 .5909 L F
.524 .906 .747 r
.31531 .59343 m .31084 .59585 L .3134 .5909 L F
.774 .72 .802 r
.3184 .58971 m .31531 .59343 L .3134 .5898 L F
.298 .52 .9 r
.28657 .68292 m .28764 .68143 L .28584 .67947 L F
.28657 .68292 m .289 .68351 L .28764 .68143 L F
.757 .633 .724 r
.537 .45005 m .53888 .45398 L .53607 .45304 L F
.807 .627 .658 r
.53888 .45398 m .53838 .4566 L .53607 .45304 L F
0 0 0 r
.43996 .45235 m .43686 .4558 L .43764 .45384 L F
0 .191 .721 r
.57834 .36586 m .57992 .36744 L .5784 .36527 L F
0 0 .181 r
.57822 .36711 m .57834 .36586 L .57785 .36323 L F
.817 .501 0 r
.57785 .36323 m .57834 .36586 L .57749 .36396 L F
0 .191 .721 r
.57834 .36586 m .5784 .36527 L .57749 .36396 L F
0 0 .181 r
.57823 .3672 m .57834 .36586 L .57822 .36711 L F
0 0 .199 r
.57823 .3672 m .57992 .36744 L .57834 .36586 L F
.57823 .3672 m .57768 .36962 L .57992 .36744 L F
.341 .211 .555 r
.58254 .38717 m .5846 .38879 L .58392 .38645 L F
.764 .615 .694 r
.5379 .44263 m .53563 .44612 L .53654 .44404 L F
.753 .362 .313 r
.32072 .5104 m .32494 .51296 L .32504 .51038 L F
.841 .893 .877 r
.28792 .52252 m .28974 .5237 L .29297 .52079 L F
0 0 0 r
.58551 .40049 m .58562 .40074 L .58616 .39774 L F
.58551 .40049 m .58498 .40312 L .58562 .40074 L F
0 0 .443 r
.23728 .61287 m .23857 .61574 L .23896 .61322 L F
.253 .018 .352 r
.53508 .41266 m .53299 .41402 L .53322 .41361 L F
.53508 .41266 m .53322 .41361 L .53538 .40984 L F
.434 .002 .116 r
.53538 .40984 m .53774 .41168 L .53508 .41266 L F
.53538 .40984 m .53797 .41007 L .53774 .41168 L F
.393 .282 .607 r
.53754 .4114 m .53508 .41266 L .53774 .41168 L F
.253 .018 .352 r
.53508 .41266 m .53299 .41402 L .53538 .40984 L F
.875 .72 .203 r
.5352 .40818 m .53538 .40984 L .53508 .41266 L F
.981 .908 .592 r
.53573 .40751 m .53538 .40984 L .5352 .40818 L F
.393 .282 .607 r
.5352 .40818 m .53508 .41266 L .53754 .4114 L F
.736 .816 .914 r
.6012 .34939 m .60285 .35127 L .60437 .34956 L F
.60437 .34956 m .60285 .35127 L .6012 .34939 L F
.796 .819 .87 r
.31552 .62952 m .31288 .63269 L .31118 .62946 L F
0 .464 .793 r
.65626 .36466 m .66011 .36574 L .65658 .36441 L F
.76 .582 .656 r
.51092 .45673 m .50699 .45679 L .50725 .453 L F
.413 0 0 r
.51092 .45673 m .50954 .45842 L .50699 .45679 L F
.325 0 0 r
.5124 .45795 m .51092 .45673 L .51271 .45589 L F
.5124 .45795 m .50954 .45842 L .51092 .45673 L F
.056 .374 .84 r
.44039 .58325 m .44212 .58601 L .44153 .58518 L F
.559 .706 .939 r
.43785 .58413 m .44212 .58601 L .44039 .58325 L F
.802 .63 .669 r
.37128 .55321 m .37359 .55708 L .36964 .55618 L F
.893 .755 .703 r
.37359 .55708 m .36962 .5593 L .36964 .55618 L F
.37359 .55708 m .37298 .56011 L .36962 .5593 L F
0 0 .301 r
.59388 .34337 m .59565 .34384 L .59706 .34287 L F
.59388 .34337 m .59322 .34619 L .59565 .34384 L F
.653 .942 .692 r
.66074 .38287 m .66412 .38018 L .66354 .38018 L F
0 0 0 r
.66412 .38018 m .66711 .37715 L .66612 .37863 L F
.487 .893 .77 r
.66412 .38018 m .66612 .37863 L .66354 .38018 L F
.935 .767 .649 r
.33636 .56221 m .33934 .56031 L .33738 .55909 L F
.33636 .56221 m .33864 .56328 L .33934 .56031 L F
.278 0 0 r
.28037 .67178 m .28366 .67017 L .28145 .6721 L F
.689 .227 .149 r
.28366 .67017 m .28601 .67244 L .28145 .6721 L F
.369 0 0 r
.39297 .47161 m .39603 .47209 L .39111 .47269 L F
.144 .618 .923 r
.29269 .68434 m .29758 .68594 L .29554 .68577 L F
.465 .764 .995 r
.29758 .68594 m .29834 .6844 L .29554 .68577 L F
.29758 .68594 m .30104 .68556 L .29834 .6844 L F
0 0 0 r
.26317 .57695 m .26111 .57862 L .25969 .57927 L F
.433 .22 .488 r
.26373 .57244 m .26143 .57322 L .26171 .57029 L F
.541 .224 .379 r
.2648 .57013 m .26373 .57244 L .26171 .57029 L F
0 0 .258 r
.26373 .57244 m .26317 .57695 L .26143 .57322 L F
.26373 .57244 m .26388 .57541 L .26317 .57695 L F
.703 .938 .634 r
.26388 .57541 m .26111 .57862 L .26317 .57695 L F
.227 0 0 r
.54175 .39415 m .54449 .39456 L .54574 .39387 L F
.764 .255 0 r
.54449 .39456 m .54742 .39623 L .54574 .39387 L F
.847 .719 .193 r
.3019 .65025 m .30224 .64702 L .30221 .64633 L F
.603 .697 .909 r
.30224 .64702 m .30512 .64556 L .30221 .64633 L F
.30224 .64702 m .30542 .6467 L .30512 .64556 L F
.559 .277 .444 r
.30367 .65061 m .30224 .64702 L .3019 .65025 L F
.30342 .64997 m .30542 .6467 L .30224 .64702 L F
.858 .8 .793 r
.29819 .64662 m .30094 .64973 L .30221 .64633 L F
.143 .024 .446 r
.30221 .64633 m .30094 .64973 L .3019 .65025 L F
.327 .516 .889 r
.30253 .64743 m .30194 .65003 L .30019 .64804 L F
.30194 .65003 m .3019 .65025 L .30174 .65004 L F
.30194 .65003 m .30174 .65004 L .30019 .64804 L F
.559 .277 .444 r
.30367 .65061 m .30397 .64994 L .30342 .64997 L F
.30397 .64994 m .30542 .6467 L .30342 .64997 L F
.919 .696 .585 r
.68283 .35964 m .68477 .36085 L .68308 .35678 L F
.212 0 0 r
.2908 .66485 m .28865 .66474 L .28704 .66561 L F
.737 .751 .864 r
.4973 .49293 m .49416 .49259 L .49598 .49149 L F
.735 .919 .955 r
.49958 .48955 m .4973 .49293 L .49598 .49149 L F
.49958 .48955 m .50122 .4907 L .4973 .49293 L F
.313 0 .225 r
.35096 .50357 m .35348 .50283 L .35413 .50088 L F
.078 0 .127 r
.355 .50066 m .35664 .50065 L .35809 .49987 L F
.641 .094 0 r
.35733 .5001 m .35809 .49987 L .35566 .50117 L F
.35743 .50007 m .36036 .50211 L .35809 .49987 L F
.35733 .5001 m .35782 .50042 L .35743 .50007 L F
.35782 .50042 m .36036 .50211 L .35743 .50007 L F
.547 .367 .589 r
.35566 .50117 m .35565 .50476 L .35873 .50128 L F
.193 .586 .942 r
.3592 .50075 m .36036 .50211 L .35814 .50064 L F
.547 .367 .589 r
.35829 .50086 m .35873 .50128 L .3592 .50075 L F
.35566 .50117 m .35873 .50128 L .35829 .50086 L F
.193 .586 .942 r
.35884 .50063 m .35814 .50064 L .35733 .5001 L F
.3592 .50075 m .35814 .50064 L .35884 .50063 L F
.078 0 .127 r
.35413 .50088 m .35566 .50117 L .35664 .50065 L F
.35413 .50088 m .35664 .50065 L .355 .50066 L F
.35413 .50088 m .35348 .50283 L .35566 .50117 L F
.901 .981 .797 r
.6614 .36715 m .65881 .36854 L .66011 .36574 L F
.892 .934 .837 r
.47086 .53507 m .47079 .53766 L .47231 .53645 L F
.875 .902 .846 r
.47086 .53507 m .47231 .53645 L .47509 .53285 L F
.876 .993 .766 r
.49935 .41173 m .49879 .41416 L .50141 .41095 L F
.771 .921 .937 r
.50199 .40819 m .50141 .41095 L .5038 .40938 L F
.883 .992 .763 r
.50199 .40819 m .49935 .41173 L .50141 .41095 L F
.575 .817 .99 r
.61424 .35003 m .61603 .35139 L .619 .3506 L F
.567 .1 .104 r
.52076 .36009 m .52448 .36093 L .52495 .35988 L F
.055 .621 .723 r
.52495 .35988 m .52519 .35981 L .52076 .36009 L F
0 0 0 r
.52495 .35988 m .52696 .3585 L .52773 .3601 L F
.52495 .35988 m .52555 .35988 L .52696 .3585 L F
.821 .611 .619 r
.52519 .35981 m .52696 .3585 L .52555 .35988 L F
.911 .521 .255 r
.52597 .35996 m .52555 .35988 L .52495 .35988 L F
.52581 .35988 m .52519 .35981 L .52495 .35988 L F
0 0 0 r
.52495 .35988 m .52448 .36093 L .52555 .35988 L F
.821 .611 .619 r
.52519 .35981 m .52555 .35988 L .52448 .36093 L F
.911 .521 .255 r
.52773 .3601 m .52581 .35988 L .52555 .35988 L F
.52773 .3601 m .52555 .35988 L .52597 .35996 L F
.331 .28 .65 r
.25435 .56681 m .25619 .56603 L .25549 .56324 L F
.958 .688 .483 r
.3671 .54012 m .36505 .53928 L .36511 .53641 L F
.874 .67 .624 r
.36802 .54288 m .36505 .53928 L .3671 .54012 L F
0 0 .408 r
.54742 .41727 m .54866 .41734 L .546 .41563 L F
.54742 .41727 m .54787 .42024 L .54866 .41734 L F
0 0 0 r
.50534 .41397 m .50131 .41736 L .50444 .41559 L F
.283 .263 .659 r
.50131 .41736 m .50471 .41823 L .50444 .41559 L F
.50131 .41736 m .50243 .41993 L .50471 .41823 L F
.7 .983 .839 r
.52683 .39488 m .5257 .39703 L .5282 .3962 L F
.976 .848 .65 r
.5257 .39703 m .52514 .39959 L .52308 .39784 L F
.919 .975 .766 r
.5185 .47383 m .51639 .47471 L .51833 .47142 L F
.957 .932 .6 r
.54617 .4325 m .54534 .43714 L .54412 .43622 L F
.999 .799 .493 r
.54534 .43714 m .54504 .43993 L .54412 .43622 L F
.685 .72 .876 r
.32696 .6278 m .32244 .62707 L .325 .62603 L F
.853 .622 .588 r
.35575 .52044 m .35548 .52302 L .35316 .51976 L F
.519 .87 .989 r
.40562 .53408 m .41043 .53395 L .40852 .53268 L F
0 0 .528 r
.58369 .39394 m .58488 .39461 L .58402 .39196 L F
.58369 .39394 m .58503 .39617 L .58488 .39461 L F
.253 .428 .842 r
.61502 .39663 m .61657 .39381 L .61453 .39578 L F
.26 0 .055 r
.61781 .39112 m .61641 .39402 L .62007 .39243 L F
.61641 .39402 m .6164 .39403 L .61643 .39402 L F
.61641 .39402 m .61643 .39402 L .62007 .39243 L F
.253 .428 .842 r
.61502 .39663 m .61799 .39733 L .61666 .39403 L F
.238 0 0 r
.61657 .39381 m .62007 .39243 L .6164 .39403 L F
.253 .428 .842 r
.61646 .39402 m .61666 .39403 L .61657 .39381 L F
.61502 .39663 m .61666 .39403 L .61646 .39402 L F
.813 .698 .739 r
.31974 .57671 m .31746 .57679 L .31826 .57382 L F
0 0 0 r
.32205 .57771 m .31746 .57679 L .31974 .57671 L F
.811 .983 .89 r
.52144 .48752 m .52027 .48683 L .51724 .4895 L F
.825 .994 .859 r
.52144 .48752 m .52452 .48438 L .52216 .485 L F
.806 .982 .894 r
.52216 .485 m .52027 .48683 L .52144 .48752 L F
.913 .98 .765 r
.58427 .41099 m .58338 .41252 L .58208 .41175 L F
.669 .16 0 r
.58208 .41175 m .58338 .41252 L .58567 .41548 L F
.773 .678 .758 r
.50725 .453 m .50891 .45095 L .50632 .44927 L F
.841 .893 .877 r
.28792 .52252 m .29297 .52079 L .29085 .51977 L F
.711 .912 .964 r
.29304 .51841 m .29085 .51977 L .29297 .52079 L F
.773 .678 .758 r
.50725 .453 m .50632 .44927 L .50741 .45301 L F
.887 .893 .471 r
.51902 .44671 m .51924 .44704 L .51805 .44857 L F
.583 .861 .531 r
.52063 .44526 m .51924 .44704 L .51902 .44671 L F
.52063 .44526 m .52219 .44376 L .51924 .44704 L F
.223 0 0 r
.51805 .44857 m .51924 .44704 L .52194 .44669 L F
.466 .246 .496 r
.51924 .44704 m .52219 .44376 L .52194 .44669 L F
.999 .843 .541 r
.31891 .57055 m .31721 .57159 L .31846 .56884 L F
.31891 .57055 m .31826 .57382 L .31721 .57159 L F
.417 .29 .599 r
.50444 .41559 m .50663 .41179 L .50534 .41397 L F
0 0 0 r
.51473 .41043 m .51334 .41188 L .51143 .41375 L F
0 0 .378 r
.51334 .41188 m .51134 .41602 L .51143 .41375 L F
0 0 0 r
.43878 .44385 m .4348 .44634 L .43698 .44503 L F
.615 .955 .826 r
.43878 .44385 m .44003 .44224 L .44083 .44228 L F
.608 .914 .653 r
.43698 .44503 m .44003 .44224 L .43878 .44385 L F
.936 .96 .757 r
.53586 .47675 m .53806 .47316 L .5371 .47208 L F
.839 .972 .882 r
.5371 .47208 m .53806 .47316 L .54129 .47 L F
.908 .739 .661 r
.37298 .56011 m .36893 .56208 L .36962 .5593 L F
.37298 .56011 m .37105 .56309 L .36893 .56208 L F
.808 .584 .599 r
.37298 .56011 m .3754 .56383 L .37105 .56309 L F
.665 .548 .712 r
.29025 .67018 m .29264 .66804 L .28941 .66612 L F
.686 .226 .156 r
.6613 .33527 m .66378 .33619 L .66094 .3339 L F
.519 0 0 r
.50735 .40714 m .50845 .40794 L .51036 .40697 L F
.576 .92 .713 r
.51036 .40697 m .50845 .40794 L .50957 .40708 L F
.001 0 0 r
.51036 .40697 m .50984 .40704 L .50735 .40714 L F
.546 .751 .972 r
.50735 .40714 m .50984 .40704 L .50731 .4044 L F
.576 .92 .713 r
.51036 .40697 m .50984 .40704 L .51188 .40532 L F
.546 .751 .972 r
.50984 .40704 m .50999 .40704 L .50992 .40697 L F
.50984 .40704 m .50992 .40697 L .50731 .4044 L F
.695 .805 .933 r
.50731 .4044 m .50992 .40697 L .51188 .40532 L F
.50992 .40697 m .50999 .40704 L .51188 .40532 L F
.576 .92 .713 r
.50992 .40697 m .50957 .40708 L .51072 .40621 L F
.50984 .40704 m .50983 .40704 L .50992 .40697 L F
.50983 .40704 m .50957 .40708 L .50992 .40697 L F
.50984 .40704 m .51072 .40621 L .51188 .40532 L F
.001 0 0 r
.51036 .40697 m .50999 .40704 L .50984 .40704 L F
.566 .899 .656 r
.51188 .40532 m .50999 .40704 L .51036 .40697 L F
.941 .959 .742 r
.27539 .66312 m .27767 .66193 L .27552 .66433 L F
.892 .934 .837 r
.47086 .53507 m .46815 .53828 L .47079 .53766 L F
0 0 0 r
.4102 .45978 m .40775 .46068 L .4061 .46212 L F
.791 .623 .672 r
.55017 .41644 m .5543 .41705 L .55249 .41348 L F
.179 .685 .906 r
.5534 .41652 m .5543 .41705 L .553 .41686 L F
.158 .302 .761 r
.55249 .41348 m .5543 .41705 L .55539 .41469 L F
0 0 0 r
.55391 .41609 m .5534 .41652 L .55228 .41765 L F
.749 .986 .901 r
.55539 .41469 m .5543 .41705 L .5534 .41652 L F
0 0 0 r
.55539 .41469 m .5534 .41652 L .55391 .41609 L F
.179 .685 .906 r
.5534 .41652 m .553 .41686 L .55017 .41644 L F
.737 .726 .841 r
.53838 .4566 m .53592 .45801 L .53434 .45603 L F
.994 .85 .501 r
.28393 .6762 m .2849 .67706 L .28354 .677 L F
.663 .605 .779 r
.29292 .67214 m .29017 .67292 L .29025 .67018 L F
.181 .706 .862 r
.37256 .51031 m .37499 .51014 L .37684 .51044 L F
.603 .037 0 r
.37673 .51125 m .37684 .51044 L .37499 .51014 L F
.37673 .51125 m .37906 .51238 L .37684 .51044 L F
.903 .49 .138 r
.32349 .53303 m .32072 .52966 L .32356 .52994 L F
.661 .95 .712 r
.47507 .42021 m .47633 .41835 L .47822 .41735 L F
.648 .965 .907 r
.47507 .42021 m .47411 .41987 L .47633 .41835 L F
.632 .158 0 r
.56118 .36359 m .5617 .36461 L .55845 .36296 L F
.56118 .36359 m .56251 .36538 L .5617 .36461 L F
.704 .207 0 r
.56372 .36658 m .56346 .36666 L .56118 .36359 L F
.128 0 0 r
.5586 .36133 m .56122 .35907 L .55845 .36296 L F
.729 .223 0 r
.5617 .36461 m .5586 .36133 L .55845 .36296 L F
.56046 .36329 m .56045 .36394 L .5586 .36133 L F
.5617 .36461 m .56045 .36394 L .56046 .36329 L F
.914 .891 .793 r
.56123 .36691 m .55856 .36618 L .56045 .36394 L F
.644 .89 .55 r
.55856 .36618 m .55908 .36524 L .56045 .36394 L F
.13 0 0 r
.56045 .36394 m .55908 .36524 L .56045 .36469 L F
.561 .857 .997 r
.561 .36395 m .56045 .36394 L .5617 .36461 L F
.914 .891 .793 r
.56123 .36691 m .56045 .36394 L .5617 .36461 L F
.13 0 0 r
.56045 .36394 m .56045 .36469 L .56185 .36414 L F
.561 .857 .997 r
.56471 .36396 m .561 .36395 L .5617 .36461 L F
.632 .158 0 r
.56251 .36538 m .56346 .36666 L .5617 .36461 L F
.863 .996 .774 r
.5261 .46359 m .52546 .46292 L .52817 .45958 L F
.846 .77 .777 r
.55038 .45235 m .55233 .45388 L .55102 .44947 L F
.867 .774 .757 r
.54805 .45594 m .55233 .45388 L .55038 .45235 L F
.54805 .45594 m .55027 .45707 L .55233 .45388 L F
0 0 0 r
.66612 .37863 m .66711 .37715 L .66894 .37564 L F
.791 .369 .247 r
.38881 .58014 m .38701 .58218 L .38436 .57897 L F
.868 .73 .707 r
.65879 .34639 m .65677 .34977 L .65555 .34582 L F
.62 .934 .962 r
.53646 .43558 m .5342 .43666 L .53522 .43468 L F
.689 .981 .849 r
.53522 .43468 m .5342 .43666 L .5332 .43641 L F
.321 .014 .278 r
.32065 .64911 m .32325 .65001 L .32371 .64637 L F
.32328 .64976 m .32392 .64915 L .32371 .64637 L F
.32325 .65001 m .32339 .64984 L .32328 .64976 L F
.32339 .64984 m .32392 .64915 L .32328 .64976 L F
.248 .04 .388 r
.324 .65027 m .3222 .65195 L .32339 .64984 L F
.321 .014 .278 r
.32325 .65001 m .324 .65027 L .32392 .64915 L F
.248 .04 .388 r
.324 .65027 m .32339 .64984 L .32404 .64867 L F
.552 .58 .835 r
.32339 .64984 m .32307 .64769 L .32404 .64867 L F
.427 .294 .596 r
.31994 .65259 m .32261 .65107 L .32065 .64911 L F
.552 .58 .835 r
.32258 .65112 m .32325 .65001 L .32339 .64984 L F
.427 .294 .596 r
.31994 .65259 m .3222 .65195 L .32261 .65107 L F
.552 .58 .835 r
.32226 .65163 m .32261 .65107 L .32258 .65112 L F
.32261 .65107 m .32325 .65001 L .32258 .65112 L F
.3222 .65195 m .32226 .65163 L .32339 .64984 L F
.427 .294 .596 r
.32261 .65107 m .3222 .65195 L .324 .65027 L F
.32261 .65107 m .324 .65027 L .32325 .65001 L F
.32261 .65107 m .32325 .65001 L .32065 .64911 L F
.552 .58 .835 r
.32226 .65163 m .32236 .65118 L .32325 .65001 L F
.32236 .65118 m .32307 .64769 L .32339 .64984 L F
.465 .82 .996 r
.32371 .64637 m .32499 .64526 L .32209 .64465 L F
.32371 .64637 m .32662 .64627 L .32499 .64526 L F
0 0 .171 r
.32371 .64637 m .32404 .64867 L .32662 .64627 L F
.32371 .64637 m .32393 .64933 L .32404 .64867 L F
.992 .884 .576 r
.32452 .64586 m .32404 .64867 L .32307 .64769 L F
.32499 .64526 m .32404 .64867 L .32452 .64586 L F
0 0 .171 r
.32393 .64933 m .324 .65027 L .32404 .64867 L F
.18 .469 .889 r
.4957 .43965 m .49816 .44271 L .4998 .44291 L F
.65 .511 .681 r
.3185 .58615 m .3184 .58971 L .32049 .5868 L F
.717 .825 .372 r
.51567 .4079 m .51473 .41043 L .51662 .40621 L F
.507 .365 .623 r
.51567 .4079 m .51334 .41188 L .51473 .41043 L F
.964 .816 .649 r
.4482 .54959 m .44788 .54947 L .4463 .54974 L F
.515 .298 .522 r
.3146 .65383 m .317 .65588 L .31722 .65307 L F
.638 .33 .434 r
.53245 .39369 m .53485 .39594 L .53206 .39604 L F
.53245 .39369 m .53485 .39594 L .53206 .39604 L F
.724 .989 .838 r
.52343 .44172 m .52514 .4414 L .52219 .44376 L F
.674 .897 .547 r
.52343 .44172 m .52219 .44376 L .52063 .44526 L F
.632 .143 .073 r
.52219 .44376 m .52457 .44564 L .52194 .44669 L F
.807 .681 .725 r
.53563 .44612 m .53304 .44934 L .53307 .44708 L F
.311 0 .222 r
.29341 .65996 m .29443 .65731 L .29716 .65636 L F
.29716 .65636 m .29443 .65731 L .29341 .65996 L F
0 .119 .667 r
.24008 .61428 m .24056 .61677 L .23896 .61322 L F
.98 .716 .455 r
.2369 .61188 m .23896 .61322 L .23857 .61574 L F
0 .119 .667 r
.24102 .61517 m .23896 .61322 L .24124 .61236 L F
.464 .259 .515 r
.23857 .61574 m .23996 .61399 L .2369 .61188 L F
.23996 .61399 m .24124 .61236 L .23917 .61213 L F
.23996 .61399 m .23917 .61213 L .2369 .61188 L F
0 .119 .667 r
.24102 .61517 m .24079 .61596 L .24008 .61428 L F
.24079 .61596 m .24056 .61677 L .24008 .61428 L F
.479 .819 .999 r
.23857 .61574 m .24056 .61677 L .24102 .61517 L F
.827 .996 .849 r
.50584 .49969 m .50202 .50208 L .50333 .50281 L F
.447 .852 .969 r
.63203 .39437 m .62766 .39432 L .62941 .39516 L F
.842 .809 .818 r
.31712 .60061 m .31924 .59916 L .31961 .5977 L F
.685 .692 .851 r
.31924 .59916 m .32182 .5962 L .31961 .5977 L F
.832 .995 .849 r
.51088 .39097 m .50782 .39402 L .50855 .39134 L F
.835 .996 .843 r
.50782 .39402 m .50555 .39434 L .50855 .39134 L F
.901 .649 .548 r
.36232 .53029 m .35915 .53198 L .35937 .52924 L F
.36232 .53029 m .36243 .53312 L .35915 .53198 L F
.82 .714 .747 r
.33481 .57955 m .33259 .58268 L .33645 .58282 L F
.016 0 0 r
.4297 .57864 m .42797 .57899 L .42529 .57915 L F
.884 .989 .738 r
.43102 .57483 m .4297 .57864 L .4332 .57906 L F
.43102 .57483 m .42797 .57899 L .4297 .57864 L F
.693 .628 .779 r
.54099 .43937 m .5379 .44263 L .5386 .44044 L F
.158 0 0 r
.63136 .38352 m .63042 .3832 L .62885 .38467 L F
.63136 .38352 m .63351 .38369 L .63042 .3832 L F
.345 .717 .985 r
.63963 .39515 m .63891 .39433 L .63582 .39432 L F
.283 .588 .946 r
.63963 .39515 m .64155 .39408 L .63891 .39433 L F
.63963 .39515 m .64274 .39598 L .64155 .39408 L F
.536 .821 .998 r
.38044 .52611 m .38444 .5268 L .38237 .5228 L F
.791 .626 .677 r
.38218 .52935 m .3852 .53007 L .38444 .5268 L F
.972 .929 .643 r
.38444 .5268 m .38473 .52261 L .38237 .5228 L F
.38444 .5268 m .38344 .52587 L .38473 .52261 L F
.855 .434 .227 r
.38444 .5268 m .3825 .52831 L .38344 .52587 L F
0 0 .494 r
.38444 .5268 m .3852 .53007 L .38545 .52911 L F
.855 .434 .227 r
.38444 .5268 m .38545 .52911 L .3825 .52831 L F
.674 .918 .6 r
.48098 .41414 m .47822 .41735 L .47938 .41543 L F
.691 .96 .715 r
.47822 .41735 m .47633 .41835 L .47938 .41543 L F
.26 0 .055 r
.61781 .39112 m .62007 .39243 L .62114 .3904 L F
.9 .592 .454 r
.63891 .37673 m .63848 .37914 L .63858 .37434 L F
.63891 .37673 m .63848 .37914 L .63858 .37434 L F
.942 .64 .188 r
.63858 .37434 m .63891 .37673 L .63831 .37353 L F
.63858 .37434 m .63891 .37673 L .63831 .37353 L F
.781 .438 .406 r
.36749 .50906 m .36817 .51223 L .37009 .50987 L F
.566 .178 .266 r
.36817 .51223 m .37256 .51031 L .37009 .50987 L F
.633 .902 .593 r
.48098 .41414 m .48104 .41347 L .4829 .41242 L F
.48098 .41414 m .47938 .41543 L .48104 .41347 L F
.711 .742 .876 r
.33871 .62321 m .33619 .62438 L .33449 .62256 L F
.348 .039 .291 r
.38477 .53247 m .38387 .53231 L .3852 .53007 L F
.3852 .53007 m .38387 .53231 L .38477 .53247 L F
.38477 .53247 m .3852 .53007 L .38218 .52935 L F
.3852 .53007 m .38477 .53247 L .38545 .52911 L F
.458 .208 .447 r
.25478 .55635 m .25718 .556 L .25746 .55354 L F
.528 .296 .506 r
.25718 .556 m .26032 .55288 L .25746 .55354 L F
.517 .877 .648 r
.46574 .4266 m .46723 .42519 L .46967 .42365 L F
.405 .814 .609 r
.46967 .42365 m .46937 .42376 L .47121 .42253 L F
.46967 .42365 m .46723 .42519 L .46937 .42376 L F
0 0 0 r
.32205 .57771 m .31767 .57913 L .31746 .57679 L F
.32205 .57771 m .32004 .57865 L .31767 .57913 L F
.626 .083 0 r
.32205 .57771 m .32422 .57969 L .32004 .57865 L F
.489 .151 .32 r
.3247 .57729 m .32422 .57969 L .32205 .57771 L F
.863 .74 .725 r
.32497 .59329 m .32874 .59325 L .32716 .58938 L F
.86 .764 .755 r
.32619 .5968 m .32874 .59325 L .32497 .59329 L F
.762 .699 .791 r
.32716 .58938 m .32874 .59325 L .33143 .58993 L F
.838 .65 .649 r
.3746 .56649 m .37105 .56309 L .3754 .56383 L F
.913 .98 .765 r
.58427 .41099 m .58208 .41175 L .58279 .40907 L F
.667 .769 .926 r
.58279 .40907 m .5869 .40989 L .58427 .41099 L F
.336 .031 .29 r
.25691 .58387 m .2535 .58911 L .25417 .58669 L F
.25691 .58387 m .25601 .58837 L .2535 .58911 L F
.382 0 .091 r
.26034 .58315 m .25691 .58387 L .25759 .58314 L F
.26034 .58315 m .25863 .58559 L .25691 .58387 L F
.238 0 .258 r
.25863 .58559 m .25601 .58837 L .25691 .58387 L F
.988 .891 .572 r
.55141 .4117 m .55249 .41348 L .553 .41069 L F
.933 .954 .771 r
.55017 .41644 m .55249 .41348 L .55141 .4117 L F
.685 .223 .15 r
.55605 .41277 m .553 .41069 L .55249 .41348 L F
.158 .302 .761 r
.55249 .41348 m .55539 .41469 L .55605 .41277 L F
.926 .623 .449 r
.30027 .66661 m .29779 .66852 L .30046 .66514 L F
.755 .933 .586 r
.6569 .39069 m .65797 .3901 L .65734 .38855 L F
0 0 .285 r
.56065 .38327 m .56205 .38407 L .56252 .38229 L F
.56065 .38327 m .56037 .38666 L .56205 .38407 L F
.606 .539 .753 r
.25969 .57927 m .26034 .58315 L .25759 .58314 L F
.153 .17 .624 r
.39328 .56458 m .39197 .5696 L .39275 .56688 L F
.115 .277 .753 r
.41314 .59757 m .41407 .59629 L .41171 .59464 L F
.444 .741 .991 r
.41314 .59757 m .41635 .59788 L .41407 .59629 L F
.878 .924 .851 r
.37467 .47529 m .37264 .47652 L .37325 .47451 L F
.395 .842 .924 r
.57928 .34682 m .58337 .3464 L .58077 .3476 L F
.332 .747 .978 r
.32499 .64526 m .32662 .64627 L .32759 .64522 L F
.524 .842 .539 r
.32759 .64522 m .32662 .64627 L .32404 .64867 L F
.59 .692 .913 r
.49245 .41849 m .49679 .42053 L .4955 .4171 L F
0 .087 .632 r
.37442 .58011 m .37515 .57845 L .37379 .57774 L F
0 0 .206 r
.37442 .58011 m .37511 .58201 L .37515 .57845 L F
.37442 .58011 m .37471 .58363 L .37511 .58201 L F
.786 .763 .832 r
.29919 .6333 m .29657 .63636 L .29509 .63346 L F
.512 .322 .559 r
.28146 .52285 m .28407 .51943 L .28242 .52066 L F
0 .274 .779 r
.39651 .56293 m .39588 .56251 L .39389 .55952 L F
.809 .657 .695 r
.3938 .5233 m .39324 .5261 L .39784 .52668 L F
.809 .651 .686 r
.39324 .5261 m .39502 .52934 L .39784 .52668 L F
.736 .526 .608 r
.39502 .52934 m .39828 .5298 L .39784 .52668 L F
.748 .52 .585 r
.39828 .5298 m .39978 .5262 L .39784 .52668 L F
.195 0 0 r
.37661 .51564 m .38095 .51352 L .37906 .51238 L F
.37661 .51564 m .37882 .51522 L .38095 .51352 L F
.727 .301 .236 r
.37882 .51522 m .38331 .51597 L .38095 .51352 L F
.149 0 0 r
.4161 .4673 m .41154 .4688 L .41294 .47031 L F
.936 .96 .757 r
.53586 .47675 m .5371 .47208 L .53454 .4756 L F
.783 .607 .662 r
.31885 .51966 m .3152 .51997 L .31551 .51657 L F
.856 .5 .377 r
.31725 .52257 m .3152 .51997 L .31885 .51966 L F
.787 .796 .86 r
.29085 .64644 m .29555 .64645 L .29351 .64598 L F
.016 .578 .802 r
.29351 .64598 m .29555 .64645 L .29819 .64662 L F
.452 .884 .835 r
.63391 .34641 m .63268 .34771 L .63537 .34716 L F
.63391 .34641 m .63106 .34777 L .63268 .34771 L F
.458 .053 .182 r
.33946 .50552 m .34224 .50558 L .34378 .50258 L F
.038 .058 .55 r
.34378 .50258 m .34482 .49883 L .34608 .50074 L F
.34378 .50258 m .3459 .5005 L .34482 .49883 L F
.694 .301 .3 r
.34378 .50258 m .34634 .50551 L .3459 .5005 L F
.34378 .50258 m .34224 .50558 L .34634 .50551 L F
.964 .922 .709 r
.37128 .55321 m .36845 .55544 L .36919 .55214 L F
.37128 .55321 m .36964 .55618 L .36845 .55544 L F
.999 .831 .54 r
.56016 .43234 m .5597 .42947 L .55816 .43361 L F
.919 .89 .787 r
.55681 .43523 m .56016 .43234 L .55816 .43361 L F
0 .17 .695 r
.59183 .39835 m .5921 .40048 L .59023 .39646 L F
0 .114 .616 r
.59384 .40158 m .5921 .40048 L .59183 .39835 L F
.576 .582 .822 r
.59652 .40383 m .59431 .40215 L .59535 .40325 L F
.59431 .40215 m .5921 .40048 L .59406 .40215 L F
.59431 .40215 m .59406 .40215 L .59535 .40325 L F
.683 .87 .97 r
.59198 .40463 m .5935 .40213 L .59133 .40481 L F
0 .114 .616 r
.59384 .40158 m .59535 .40325 L .5921 .40048 L F
.683 .87 .97 r
.5935 .40213 m .59384 .40158 L .59341 .40213 L F
.5935 .40213 m .59341 .40213 L .59133 .40481 L F
.149 0 0 r
.4161 .4673 m .41415 .46847 L .41154 .4688 L F
0 0 0 r
.41644 .46736 m .4161 .4673 L .41827 .466 L F
.41644 .46736 m .41415 .46847 L .4161 .4673 L F
.648 .861 .98 r
.597 .3603 m .59351 .36137 L .59323 .36035 L F
.881 .784 .75 r
.40148 .53266 m .39925 .53588 L .40251 .53661 L F
.951 .885 .731 r
.39954 .53823 m .40251 .53661 L .39925 .53588 L F
.39954 .53823 m .40082 .53984 L .40251 .53661 L F
.941 .744 .608 r
.36898 .54949 m .36716 .54588 L .3694 .54661 L F
.562 .812 .992 r
.64265 .37993 m .64004 .38085 L .63848 .37914 L F
.756 .967 .93 r
.56316 .40347 m .5655 .40396 L .56173 .40629 L F
.765 .958 .648 r
.56173 .40629 m .56133 .40611 L .56316 .40347 L F
.268 .745 .934 r
.54508 .34275 m .54366 .34221 L .5479 .34255 L F
.504 .292 .525 r
.54508 .34275 m .5479 .34255 L .54366 .34221 L F
.54508 .34275 m .54805 .34543 L .5479 .34255 L F
0 .09 .605 r
.54925 .34693 m .54805 .34543 L .54508 .34275 L F
.117 0 0 r
.52582 .43022 m .52458 .43004 L .5239 .43154 L F
.802 .713 .766 r
.28599 .65313 m .28732 .65677 L .28371 .65688 L F
.53 .343 .572 r
.29007 .65623 m .28743 .65985 L .28732 .65677 L F
.934 .931 .777 r
.55298 .4429 m .55623 .44056 L .55416 .43899 L F
.55298 .4429 m .55406 .44434 L .55623 .44056 L F
.942 .876 .742 r
.55623 .44056 m .55681 .43523 L .55416 .43899 L F
.728 .201 0 r
.39864 .59317 m .39802 .59384 L .39655 .59273 L F
.39864 .59317 m .40082 .59555 L .39802 .59384 L F
.757 .834 .911 r
.5687 .39112 m .57351 .39133 L .57169 .3897 L F
.8 .826 .872 r
.57169 .3897 m .57351 .39133 L .57539 .3895 L F
.362 .043 .283 r
.32682 .57847 m .32722 .57622 L .32612 .58003 L F
.32682 .57847 m .3247 .57729 L .32722 .57622 L F
.875 .902 .846 r
.47086 .53507 m .47509 .53285 L .47377 .53216 L F
.854 .969 .87 r
.47681 .52901 m .47509 .53285 L .47808 .53004 L F
.47681 .52901 m .47377 .53216 L .47509 .53285 L F
.53 .866 .993 r
.63582 .39432 m .63449 .39348 L .63203 .39437 L F
.174 .669 .917 r
.63891 .39433 m .63449 .39348 L .63582 .39432 L F
.843 .982 .869 r
.48071 .50726 m .47676 .50968 L .47856 .50578 L F
.523 .303 .522 r
.30055 .67366 m .29681 .67316 L .29846 .67229 L F
.30055 .67366 m .29832 .67695 L .29681 .67316 L F
.30055 .67366 m .30113 .67623 L .29832 .67695 L F
0 0 .01 r
.30055 .67366 m .29832 .67695 L .30113 .67623 L F
.709 .691 .831 r
.5038 .40938 m .50664 .40909 L .50735 .40714 L F
.131 .13 .589 r
.50735 .40714 m .50664 .40909 L .50845 .40794 L F
0 0 .212 r
.50664 .40909 m .50663 .41179 L .50845 .40794 L F
.924 .947 .791 r
.55489 .40552 m .55558 .40693 L .55794 .40327 L F
.571 .028 0 r
.55844 .40407 m .55873 .40494 L .55689 .40408 L F
0 0 0 r
.55689 .40403 m .55794 .40327 L .55977 .4026 L F
.55689 .40403 m .55977 .4026 L .55806 .40348 L F
.55689 .40403 m .56043 .40236 L .55844 .40407 L F
.722 .616 .739 r
.55689 .40403 m .55844 .40407 L .55553 .40344 L F
.571 .028 0 r
.55736 .40384 m .55689 .40408 L .55553 .40344 L F
.55844 .40407 m .55689 .40408 L .55736 .40384 L F
0 0 0 r
.55806 .40348 m .55977 .4026 L .56043 .40236 L F
.86 .82 .808 r
.30687 .60941 m .30883 .61138 L .3117 .60729 L F
.005 0 .148 r
.55465 .40903 m .553 .41069 L .55558 .40693 L F
.617 .92 .658 r
.55141 .4117 m .553 .41069 L .55465 .40903 L F
.909 .648 .531 r
.33469 .52972 m .33598 .53312 L .3364 .53024 L F
.774 .72 .802 r
.3184 .58971 m .3134 .5898 L .3178 .58826 L F
.842 .986 .708 r
.32049 .5868 m .3184 .58971 L .31817 .58833 L F
0 .138 .677 r
.31817 .58833 m .3184 .58971 L .3178 .58826 L F
.997 .784 .486 r
.43351 .56911 m .43266 .57151 L .43483 .57036 L F
.419 0 0 r
.43266 .57151 m .43763 .57069 L .43483 .57036 L F
.605 .331 .475 r
.43483 .57036 m .43763 .57069 L .43942 .56991 L F
.714 .91 .963 r
.50199 .40819 m .5038 .40938 L .50735 .40714 L F
.369 .365 .724 r
.35685 .64884 m .35411 .65049 L .35403 .64654 L F
.006 .119 .633 r
.35649 .65167 m .35411 .65049 L .35685 .64884 L F
.35649 .65167 m .35518 .65302 L .35411 .65049 L F
.968 .693 .271 r
.5479 .34255 m .54805 .34543 L .54925 .34693 L F
.871 .924 .533 r
.37325 .47451 m .37633 .47531 L .37499 .47285 L F
.833 .779 .801 r
.37499 .47285 m .37633 .47531 L .37769 .47338 L F
.776 .621 .688 r
.53607 .45304 m .53838 .4566 L .53434 .45603 L F
0 0 0 r
.27236 .55677 m .27046 .55955 L .26961 .55999 L F
.43 .304 .607 r
.27446 .55343 m .27236 .55677 L .2725 .55519 L F
.27446 .55343 m .27487 .55609 L .27236 .55677 L F
.61 .425 .606 r
.27487 .55609 m .27046 .55955 L .27236 .55677 L F
.69 .972 .77 r
.2971 .67003 m .29508 .67115 L .29779 .66852 L F
.746 .337 .276 r
.29508 .67115 m .29846 .67229 L .2971 .67003 L F
.878 .981 .832 r
.55162 .44692 m .55406 .44434 L .55168 .44547 L F
.922 .934 .796 r
.55168 .44547 m .55406 .44434 L .55298 .4429 L F
.449 .122 .318 r
.26961 .55999 m .26765 .56189 L .26643 .56219 L F
.27 0 .294 r
.27046 .55955 m .26765 .56189 L .26961 .55999 L F
.473 .888 .925 r
.59198 .40463 m .59652 .40383 L .59535 .40325 L F
.597 .923 .968 r
.59535 .40325 m .59652 .40383 L .59804 .40202 L F
.59535 .40325 m .59652 .40383 L .59804 .40202 L F
.987 .896 .591 r
.55465 .40903 m .55558 .40693 L .55489 .40552 L F
.926 .855 .753 r
.30944 .64502 m .31224 .64286 L .31035 .64082 L F
.881 .535 .388 r
.30944 .64502 m .3126 .64661 L .31224 .64286 L F
.342 .66 .972 r
.31035 .64082 m .31224 .64286 L .31415 .64257 L F
.624 .597 .803 r
.3126 .64661 m .31415 .64257 L .31224 .64286 L F
.457 .876 .753 r
.48311 .42591 m .48672 .42406 L .48454 .42482 L F
.786 .988 .743 r
.48755 .42183 m .48672 .42406 L .48833 .42185 L F
.782 .996 .794 r
.48454 .42482 m .48672 .42406 L .48755 .42183 L F
.687 .372 .437 r
.39779 .54351 m .39743 .54605 L .39315 .54585 L F
0 0 0 r
.4935 .43158 m .49462 .43035 L .49147 .43338 L F
.442 .262 .541 r
.49147 .43338 m .49147 .43674 L .49396 .43762 L F
0 0 .027 r
.39704 .57934 m .39803 .5799 L .39817 .57675 L F
.079 0 0 r
.39954 .57803 m .39817 .57675 L .39803 .5799 L F
.39954 .57803 m .39704 .57934 L .39817 .57675 L F
.199 .525 .92 r
.40254 .59674 m .40118 .59416 L .40082 .59555 L F
.40254 .59674 m .40349 .5965 L .40118 .59416 L F
.911 .621 .481 r
.3308 .52253 m .33089 .52553 L .33432 .52657 L F
.909 .685 .587 r
.33089 .52553 m .33469 .52972 L .33432 .52657 L F
.657 .751 .263 r
.51262 .38663 m .51088 .39097 L .51184 .38856 L F
.789 .996 .863 r
.51088 .39097 m .50855 .39134 L .51184 .38856 L F
.791 .742 .808 r
.29547 .66374 m .2908 .66485 L .2943 .66205 L F
.438 .662 .956 r
.29673 .66182 m .29547 .66374 L .2943 .66205 L F
.722 .989 .859 r
.33331 .67842 m .33642 .6765 L .33554 .67664 L F
.591 .937 .763 r
.33642 .6765 m .33989 .6741 L .33748 .67515 L F
.589 .939 .781 r
.33554 .67664 m .33642 .6765 L .33748 .67515 L F
.747 .618 .715 r
.24159 .59372 m .24737 .59462 L .24629 .59092 L F
.847 .682 .677 r
.24061 .5959 m .24737 .59462 L .24159 .59372 L F
.421 .417 .749 r
.24629 .59092 m .24737 .59462 L .24846 .59323 L F
.736 .921 .567 r
.24737 .59462 m .24684 .59464 L .24846 .59323 L F
.24463 .59806 m .24388 .59922 L .24462 .59807 L F
.24674 .59545 m .24637 .59594 L .24463 .59806 L F
.24637 .59594 m .24388 .59922 L .24463 .59806 L F
.658 .342 .426 r
.24463 .59806 m .24496 .59995 L .24597 .59662 L F
.24366 .59927 m .24496 .59995 L .24463 .59806 L F
.866 .957 .614 r
.24463 .59807 m .24369 .59635 L .24684 .59464 L F
.24388 .59922 m .24386 .59883 L .24461 .59808 L F
.658 .342 .426 r
.24356 .59921 m .24366 .59927 L .24462 .59807 L F
.24461 .59808 m .24462 .59807 L .24463 .59806 L F
.24356 .59921 m .24462 .59807 L .24461 .59808 L F
.866 .957 .614 r
.24462 .59807 m .24461 .59808 L .24463 .59807 L F
.24388 .59922 m .24461 .59808 L .24462 .59807 L F
.24386 .59883 m .24369 .59635 L .24463 .59807 L F
.24388 .59922 m .24356 .59921 L .24369 .59635 L F
.372 0 .188 r
.24727 .59825 m .24372 .59917 L .24516 .59754 L F
.24603 .59669 m .24516 .59754 L .24597 .59662 L F
.24727 .59825 m .24516 .59754 L .24603 .59669 L F
.24372 .59917 m .24356 .59921 L .24463 .59806 L F
.24372 .59917 m .24463 .59806 L .24597 .59662 L F
.736 .921 .567 r
.24737 .59462 m .24674 .59545 L .24684 .59464 L F
.24674 .59545 m .24462 .59807 L .24684 .59464 L F
.458 .805 .998 r
.30199 .68616 m .3044 .68747 L .30707 .68684 L F
.914 .592 .42 r
.4078 .58321 m .40478 .58222 L .40585 .58114 L F
.925 .666 .527 r
.4078 .58321 m .40708 .5866 L .40478 .58222 L F
.807 .532 .523 r
.4109 .58686 m .40708 .5866 L .4078 .58321 L F
.609 .886 .99 r
.48714 .49454 m .49005 .49303 L .49137 .49402 L F
.748 .871 .936 r
.49416 .49259 m .49137 .49402 L .49185 .49094 L F
.838 .944 .891 r
.49137 .49402 m .49005 .49303 L .49185 .49094 L F
.838 .65 .649 r
.3746 .56649 m .37056 .56599 L .37105 .56309 L F
.837 .662 .665 r
.3746 .56649 m .37247 .57006 L .37056 .56599 L F
.807 .681 .725 r
.53563 .44612 m .537 .45005 L .53304 .44934 L F
.802 .695 .746 r
.53304 .44934 m .537 .45005 L .53431 .45339 L F
.709 .552 .673 r
.537 .45005 m .53607 .45304 L .53431 .45339 L F
.755 .656 .751 r
.53949 .44661 m .537 .45005 L .53563 .44612 L F
.691 .981 .84 r
.52726 .43956 m .52514 .4414 L .52343 .44172 L F
0 0 0 r
.58665 .37023 m .58603 .37031 L .58725 .37019 L F
.58665 .37023 m .58469 .37187 L .58603 .37031 L F
.294 .179 .547 r
.25537 .56013 m .25718 .556 L .25478 .55635 L F
.347 .173 .498 r
.35096 .50357 m .35307 .50531 L .35348 .50283 L F
.35096 .50357 m .35091 .50644 L .35307 .50531 L F
.949 .897 .742 r
.47541 .51416 m .473 .51516 L .47448 .51302 L F
.918 .537 .275 r
.52845 .41203 m .52847 .41014 L .5268 .41133 L F
.91 .886 .796 r
.30751 .52682 m .30827 .52277 L .31009 .52339 L F
.30751 .52682 m .31009 .52339 L .30857 .52532 L F
.30751 .52682 m .30559 .52589 L .30827 .52277 L F
.492 .167 .343 r
.30857 .52532 m .30559 .52589 L .30751 .52682 L F
.608 .866 .521 r
.51262 .38663 m .51401 .38472 L .51539 .38331 L F
0 0 0 r
.51262 .38663 m .51184 .38856 L .51401 .38472 L F
.845 .781 .789 r
.46568 .54219 m .46747 .54441 L .46862 .5423 L F
0 0 .377 r
.57548 .376 m .57572 .3794 L .57392 .38097 L F
0 0 .576 r
.57514 .38068 m .57392 .38097 L .57572 .3794 L F
.57514 .38068 m .57517 .38331 L .57392 .38097 L F
.893 .855 .403 r
.5676 .40794 m .56764 .41042 L .56862 .4065 L F
.476 .845 .605 r
.57063 .40481 m .56862 .4065 L .57222 .40372 L F
0 0 0 r
.5676 .40794 m .56862 .4065 L .57063 .40481 L F
.776 .762 .841 r
.34385 .61919 m .34841 .61953 L .34605 .62103 L F
.753 .362 .313 r
.32072 .5104 m .32086 .51243 L .32494 .51296 L F
.845 .88 .866 r
.4944 .41628 m .49879 .41416 L .49622 .41476 L F
.4944 .41628 m .4955 .4171 L .49879 .41416 L F
.85 .986 .857 r
.49622 .41476 m .49879 .41416 L .49935 .41173 L F
.86 .82 .808 r
.30687 .60941 m .3117 .60729 L .30904 .60767 L F
.868 .972 .855 r
.30904 .60767 m .3117 .60729 L .31145 .605 L F
.829 .992 .742 r
.56783 .40113 m .5655 .40396 L .56631 .4014 L F
.421 .848 .95 r
.56996 .39908 m .56783 .40113 L .56631 .4014 L F
.56996 .39908 m .57098 .4003 L .56783 .40113 L F
.511 .898 .74 r
.33748 .67515 m .33989 .6741 L .34187 .67274 L F
.975 .918 .669 r
.57435 .38855 m .57628 .38727 L .57484 .38582 L F
.57435 .38855 m .57539 .3895 L .57628 .38727 L F
.872 .69 .165 r
.58751 .34804 m .58803 .34634 L .58612 .34541 L F
.58751 .34804 m .58789 .34981 L .58803 .34634 L F
.751 .459 .489 r
.58803 .34634 m .58789 .34981 L .59009 .34959 L F
.829 .983 .699 r
.52019 .37634 m .52288 .37414 L .52109 .37378 L F
.52019 .37634 m .52187 .37304 L .52288 .37414 L F
.583 .347 .523 r
.52288 .37414 m .52461 .37649 L .52019 .37634 L F
.013 .465 .871 r
.52351 .37343 m .52288 .37414 L .52187 .37304 L F
.52351 .37343 m .52633 .37529 L .52288 .37414 L F
.446 .312 .605 r
.52633 .37529 m .52461 .37649 L .52288 .37414 L F
.843 .673 .672 r
.33664 .56639 m .33645 .56929 L .33961 .5699 L F
.845 .659 .651 r
.33645 .56929 m .33817 .57325 L .33961 .5699 L F
.415 .307 .623 r
.64114 .3754 m .63891 .37673 L .63831 .37353 L F
.64114 .3754 m .63891 .37673 L .63831 .37353 L F
.262 .725 .949 r
.63126 .35966 m .63481 .35959 L .63556 .36032 L F
.63126 .35966 m .63481 .35959 L .63556 .36032 L F
.935 .677 .2 r
.63456 .35758 m .63481 .35959 L .63556 .36032 L F
.63456 .35758 m .63481 .35959 L .63556 .36032 L F
.525 .721 .963 r
.27697 .67253 m .27875 .67214 L .27876 .67218 L F
.27875 .67214 m .28037 .67178 L .27876 .67218 L F
.151 0 0 r
.27876 .67218 m .27988 .67257 L .2788 .6723 L F
.329 .538 .905 r
.27474 .66941 m .27697 .67253 L .27876 .67218 L F
.151 0 0 r
.27876 .67218 m .2788 .6723 L .27718 .6719 L F
.694 .935 .965 r
.31454 .54324 m .31067 .5436 L .31361 .5404 L F
.002 0 0 r
.31593 .54307 m .31697 .54275 L .31454 .54324 L F
.31593 .54307 m .31454 .54324 L .31361 .5404 L F
.347 .23 .575 r
.59744 .36694 m .59792 .36961 L .59631 .37048 L F
.33 .197 .544 r
.59792 .36961 m .59633 .37311 L .59631 .37048 L F
.849 .895 .87 r
.56357 .39683 m .55918 .39829 L .56215 .3962 L F
.568 .761 .969 r
.56357 .39683 m .56632 .39607 L .5644 .39409 L F
.989 .889 .574 r
.56711 .41851 m .56799 .41684 L .56626 .41802 L F
.777 .495 0 r
.56757 .4159 m .56799 .41684 L .56688 .41273 L F
.913 .962 .642 r
.56626 .41802 m .56799 .41684 L .56757 .4159 L F
.547 .443 .687 r
.27713 .54871 m .27446 .55343 L .27553 .55208 L F
0 0 0 r
.49115 .41912 m .49245 .41849 L .4955 .4171 L F
.49115 .41912 m .4955 .4171 L .4944 .41628 L F
.981 .908 .592 r
.53573 .40751 m .53645 .40796 L .5369 .40598 L F
.53573 .40751 m .5352 .40818 L .53645 .40796 L F
.969 .837 .659 r
.59469 .35796 m .59323 .36035 L .59176 .35809 L F
.648 .861 .98 r
.597 .3603 m .59323 .36035 L .59469 .35796 L F
.072 0 0 r
.63389 .34218 m .63679 .34169 L .63818 .34077 L F
0 0 0 r
.63818 .34077 m .63946 .34077 L .64073 .33973 L F
.63818 .34077 m .63679 .34169 L .63946 .34077 L F
.158 0 0 r
.34563 .61965 m .34841 .61953 L .34385 .61919 L F
.34599 .61967 m .34841 .61953 L .34563 .61965 L F
.433 .621 .931 r
.34884 .6168 m .34841 .61953 L .34599 .61967 L F
.158 0 0 r
.34577 .61968 m .34599 .61967 L .34563 .61965 L F
.433 .621 .931 r
.34646 .61904 m .34599 .61967 L .34577 .61968 L F
.34884 .6168 m .34599 .61967 L .34646 .61904 L F
.34884 .6168 m .35146 .61957 L .34841 .61953 L F
.267 .538 .92 r
.35053 .61753 m .35146 .61957 L .34884 .6168 L F
.967 .899 .704 r
.34731 .61693 m .34884 .6168 L .34577 .61968 L F
.844 .714 .72 r
.34807 .61981 m .35053 .61753 L .34795 .61705 L F
.3475 .61765 m .34795 .61705 L .34731 .61693 L F
.34807 .61981 m .34795 .61705 L .3475 .61765 L F
.34866 .62207 m .34955 .6199 L .34807 .61981 L F
.34955 .6199 m .35053 .61753 L .34807 .61981 L F
.827 .996 .849 r
.50584 .49969 m .50508 .49907 L .50202 .50208 L F
.836 .996 .841 r
.50614 .49752 m .50584 .49969 L .50953 .49739 L F
.50614 .49752 m .50508 .49907 L .50584 .49969 L F
.775 .629 .698 r
.39159 .55347 m .39343 .55423 L .39286 .55068 L F
.842 .986 .708 r
.32049 .5868 m .31817 .58833 L .31763 .58606 L F
.575 .656 .891 r
.32197 .58312 m .32049 .5868 L .31763 .58606 L F
.32197 .58312 m .32304 .58614 L .32049 .5868 L F
.816 .652 .68 r
.32532 .53926 m .32362 .53546 L .32525 .53694 L F
0 0 0 r
.45238 .43545 m .45391 .4342 L .45035 .43591 L F
.45629 .43294 m .45391 .4342 L .45238 .43545 L F
.839 .972 .882 r
.5371 .47208 m .54129 .47 L .54004 .46897 L F
.851 .885 .863 r
.54129 .47 m .54265 .46546 L .54004 .46897 L F
.54129 .47 m .54401 .46693 L .54265 .46546 L F
.086 .024 .483 r
.56252 .38229 m .56462 .37797 L .56374 .38029 L F
.911 .701 .606 r
.54805 .45594 m .54986 .46006 L .55027 .45707 L F
.865 .663 .628 r
.39406 .5843 m .39242 .5821 L .39314 .58295 L F
.792 .872 .906 r
.31009 .52339 m .31154 .51929 L .313 .52005 L F
.31009 .52339 m .30827 .52277 L .31154 .51929 L F
0 0 0 r
.31065 .52436 m .31009 .52339 L .313 .52005 L F
.31065 .52436 m .30857 .52532 L .31009 .52339 L F
.803 .892 .908 r
.54582 .41867 m .54469 .4231 L .54326 .42131 L F
.54582 .41867 m .54787 .42024 L .54469 .4231 L F
.906 .514 .258 r
.54328 .42472 m .54469 .4231 L .54522 .42567 L F
.764 .615 .694 r
.5379 .44263 m .53949 .44661 L .53563 .44612 L F
.706 .588 .721 r
.5379 .44263 m .54223 .44328 L .53949 .44661 L F
0 0 0 r
.42769 .45183 m .42979 .45014 L .42605 .45209 L F
.037 0 0 r
.42769 .45183 m .43134 .44876 L .42979 .45014 L F
0 .353 .73 r
.39222 .57245 m .39578 .57417 L .39379 .57444 L F
0 0 0 r
.40664 .5674 m .40371 .57017 L .40561 .56904 L F
.322 .045 .329 r
.40259 .57248 m .40561 .56904 L .40371 .57017 L F
0 .148 .625 r
.41097 .59437 m .41094 .59407 L .41052 .59414 L F
0 .559 .768 r
.41147 .59461 m .41097 .59437 L .40798 .59412 L F
.766 .76 .847 r
.40118 .59416 m .40349 .5965 L .40798 .59412 L F
.171 0 0 r
.41097 .59437 m .406 .59426 L .40798 .59412 L F
0 .148 .625 r
.41097 .59437 m .41052 .59414 L .40874 .59447 L F
0 .559 .768 r
.41171 .59464 m .41097 .59437 L .41147 .59461 L F
.445 0 0 r
.41171 .59464 m .41331 .59576 L .41097 .59437 L F
.41331 .59576 m .41299 .59562 L .41097 .59437 L F
.536 0 0 r
.41097 .59437 m .41407 .59629 L .41238 .59544 L F
.71 .924 .964 r
.41249 .5954 m .41694 .59428 L .41565 .5942 L F
.41238 .59544 m .41251 .59541 L .41249 .5954 L F
.41251 .59541 m .41694 .59428 L .41249 .5954 L F
.445 0 0 r
.41331 .59576 m .41407 .59629 L .41299 .59562 L F
0 0 0 r
.51539 .38331 m .51717 .38206 L .51808 .37992 L F
.51539 .38331 m .51401 .38472 L .51717 .38206 L F
.803 .655 .699 r
.32075 .62635 m .32244 .62707 L .31837 .62653 L F
.686 .742 .894 r
.32359 .62301 m .32244 .62707 L .32075 .62635 L F
.32359 .62301 m .325 .62603 L .32244 .62707 L F
.611 .895 .988 r
.64274 .39598 m .64702 .39554 L .64553 .39548 L F
.296 .685 .975 r
.64702 .39554 m .64835 .39451 L .64553 .39548 L F
.64702 .39554 m .64971 .39572 L .64835 .39451 L F
.837 .854 .857 r
.29819 .64662 m .30221 .64633 L .30034 .64496 L F
.602 .637 .858 r
.30221 .64633 m .30308 .64213 L .30034 .64496 L F
.30221 .64633 m .30512 .64556 L .30308 .64213 L F
.312 .437 .828 r
.56483 .34932 m .56467 .35316 L .56323 .34916 L F
.56483 .34932 m .56648 .35289 L .56467 .35316 L F
.909 .836 .761 r
.31422 .60265 m .31639 .60251 L .31712 .60061 L F
.894 .924 .832 r
.31145 .605 m .31639 .60251 L .31422 .60265 L F
.799 .709 .766 r
.52907 .41615 m .53299 .41402 L .52845 .41203 L F
.911 .811 .736 r
.38899 .55244 m .39286 .55068 L .39098 .54996 L F
.38899 .55244 m .39159 .55347 L .39286 .55068 L F
0 0 0 r
.39315 .54585 m .39286 .55068 L .39452 .54644 L F
.774 .507 .531 r
.39771 .54929 m .39315 .54585 L .39743 .54605 L F
.39771 .54929 m .39299 .549 L .39315 .54585 L F
.713 .946 .647 r
.39424 .54662 m .39309 .548 L .39299 .549 L F
0 0 0 r
.39315 .54585 m .39299 .549 L .39291 .54973 L F
.297 0 0 r
.39299 .549 m .38907 .54984 L .39098 .54996 L F
.39194 .54922 m .39147 .54995 L .38907 .54984 L F
.39299 .549 m .39147 .54995 L .39194 .54922 L F
0 0 0 r
.39291 .54973 m .39299 .549 L .39286 .55068 L F
.634 .909 .982 r
.39299 .549 m .39098 .54996 L .39286 .55068 L F
.613 .871 .53 r
.39424 .54662 m .39261 .54831 L .39147 .54995 L F
0 0 0 r
.39261 .54831 m .39089 .55084 L .39147 .54995 L F
.39089 .55084 m .39015 .55193 L .39147 .54995 L F
.713 .946 .647 r
.39309 .548 m .39147 .54995 L .39299 .549 L F
.251 .385 .805 r
.58901 .36147 m .58777 .36378 L .58592 .35969 L F
.758 .995 .837 r
.58949 .36215 m .58777 .36378 L .58901 .36147 L F
.872 .723 .694 r
.33475 .56517 m .33864 .56328 L .33636 .56221 L F
.33475 .56517 m .33664 .56639 L .33864 .56328 L F
.81 .592 .607 r
.68283 .35964 m .68308 .35678 L .6791 .35606 L F
.937 .69 .54 r
.33597 .53864 m .33863 .53672 L .33598 .53569 L F
.33597 .53864 m .33814 .53977 L .33863 .53672 L F
0 0 .057 r
.5999 .35776 m .59992 .35584 L .60242 .35559 L F
.5999 .35776 m .59886 .35914 L .59992 .35584 L F
.213 0 0 r
.64701 .3381 m .65018 .33741 L .64752 .33721 L F
.182 0 0 r
.64752 .33721 m .65018 .33741 L .65054 .33681 L F
.473 .869 .69 r
.47895 .42837 m .48311 .42591 L .48128 .42739 L F
0 0 0 r
.48311 .42591 m .48454 .42482 L .48128 .42739 L F
.903 .49 .138 r
.32349 .53303 m .3215 .53205 L .32072 .52966 L F
.918 .71 .606 r
.32362 .53546 m .3215 .53205 L .32349 .53303 L F
.471 .504 .81 r
.40478 .58222 m .40708 .5866 L .40392 .58615 L F
.499 .441 .723 r
.40708 .5866 m .40591 .58752 L .40392 .58615 L F
.825 .994 .859 r
.52216 .485 m .52452 .48438 L .52606 .48282 L F
.837 .466 .35 r
.50299 .45642 m .50122 .45829 L .50045 .4573 L F
.5003 .45655 m .50045 .4573 L .49987 .45657 L F
.50299 .45642 m .50045 .4573 L .5003 .45655 L F
0 0 .164 r
.49958 .45292 m .49965 .45333 L .50004 .45525 L F
.49965 .45333 m .50024 .45672 L .50005 .45532 L F
.49965 .45333 m .50005 .45532 L .50004 .45525 L F
.837 .466 .35 r
.50299 .45642 m .50004 .45525 L .50024 .45672 L F
.743 .855 .42 r
.51808 .37992 m .51988 .37577 L .52019 .37634 L F
.51808 .37992 m .51828 .3791 L .51988 .37577 L F
.6 .451 .65 r
.52019 .37634 m .52133 .37961 L .51808 .37992 L F
.018 0 0 r
.51808 .37992 m .51947 .38069 L .51828 .3791 L F
.51808 .37992 m .51717 .38206 L .51947 .38069 L F
.377 .793 .977 r
.50699 .45679 m .5053 .45597 L .50299 .45642 L F
.421 0 0 r
.50699 .45679 m .50836 .45847 L .5053 .45597 L F
.50699 .45679 m .50954 .45842 L .50836 .45847 L F
0 .171 .693 r
.23923 .59633 m .24069 .59994 L .24127 .59832 L F
.881 .535 .388 r
.30944 .64502 m .31176 .6469 L .3126 .64661 L F
.894 .562 .413 r
.3126 .64661 m .31176 .6469 L .31131 .64878 L F
.624 .597 .803 r
.3126 .64661 m .31572 .64675 L .31415 .64257 L F
.871 .88 .84 r
.31131 .64878 m .31572 .64675 L .3126 .64661 L F
0 0 .397 r
.27585 .66492 m .27431 .66672 L .27474 .66941 L F
0 0 .039 r
.51941 .38629 m .51928 .38837 L .51757 .3902 L F
0 0 .055 r
.52051 .3871 m .51941 .38629 L .52172 .38508 L F
.52051 .3871 m .51928 .38837 L .51941 .38629 L F
.763 .878 .93 r
.29014 .63431 m .28988 .63698 L .28811 .63597 L F
.29014 .63431 m .2926 .63565 L .28988 .63698 L F
.427 .082 .275 r
.40041 .46555 m .40391 .46313 L .40117 .46383 L F
.453 .248 .511 r
.26569 .54321 m .2682 .54267 L .26837 .53983 L F
.365 .214 .539 r
.26569 .54321 m .26792 .54541 L .2682 .54267 L F
.26569 .54321 m .26564 .54629 L .26792 .54541 L F
0 0 0 r
.59322 .34619 m .59365 .3461 L .59565 .34384 L F
.519 .826 .505 r
.42524 .48817 m .42634 .48704 L .42654 .48686 L F
.241 .46 .871 r
.42466 .48363 m .42834 .48498 L .42695 .48669 L F
.812 .368 0 r
.42685 .48656 m .42654 .48686 L .42466 .48363 L F
.426 .37 .692 r
.42654 .48686 m .42834 .48498 L .42466 .48363 L F
.519 .826 .505 r
.42634 .48704 m .42834 .48498 L .42654 .48686 L F
.812 .368 0 r
.42695 .48669 m .42654 .48686 L .42685 .48656 L F
.658 .909 .587 r
.42524 .48817 m .42654 .48686 L .42695 .48669 L F
.581 .875 .569 r
.42695 .48669 m .42834 .48498 L .42524 .48817 L F
.421 .417 .749 r
.24629 .59092 m .24846 .59323 L .24807 .58929 L F
0 0 .229 r
.35361 .65697 m .35518 .65302 L .35445 .65539 L F
.633 .794 .352 r
.35241 .65914 m .35361 .65697 L .35445 .65539 L F
.909 .836 .761 r
.31422 .60265 m .31712 .60061 L .31545 .5995 L F
.883 .918 .843 r
.31712 .60061 m .31816 .59654 L .31545 .5995 L F
.31712 .60061 m .31961 .5977 L .31816 .59654 L F
.713 .9 .963 r
.31816 .59654 m .31961 .5977 L .32182 .5962 L F
.327 .642 .966 r
.52076 .36009 m .52519 .35981 L .52448 .36093 L F
.7 .159 0 r
.34869 .63343 m .35146 .63438 L .3469 .63316 L F
.34869 .63343 m .35159 .63479 L .35146 .63438 L F
0 .128 .67 r
.58938 .3949 m .59183 .39835 L .59023 .39646 L F
0 0 0 r
.64206 .34622 m .63774 .34655 L .63931 .34676 L F
.968 .731 .527 r
.54964 .44895 m .55162 .44692 L .55168 .44547 L F
.54964 .44895 m .55102 .44947 L .55162 .44692 L F
.07 0 0 r
.61345 .34464 m .61763 .34467 L .61473 .34547 L F
.214 0 0 r
.418 .45776 m .41686 .45643 L .41545 .45854 L F
.418 .45776 m .41945 .45583 L .41686 .45643 L F
.994 .873 .58 r
.28858 .55388 m .28819 .55487 L .2893 .55369 L F
.28858 .55388 m .28819 .55487 L .2893 .55369 L F
.634 .082 0 r
.2893 .55369 m .2909 .55534 L .28858 .55388 L F
.693 .628 .779 r
.54099 .43937 m .54223 .44328 L .5379 .44263 L F
.75 .66 .761 r
.54099 .43937 m .54504 .43993 L .54223 .44328 L F
.77 .68 .764 r
.32716 .58938 m .33143 .58993 L .32975 .586 L F
.886 .722 .674 r
.32975 .586 m .33143 .58993 L .33101 .58709 L F
.663 .605 .779 r
.29292 .67214 m .29411 .67369 L .29017 .67292 L F
.79 .444 .401 r
.36388 .51146 m .36749 .50906 L .36594 .50913 L F
.36388 .51146 m .36817 .51223 L .36749 .50906 L F
.871 .544 .032 r
.2872 .53245 m .28777 .53543 L .28873 .53645 L F
.979 .746 .515 r
.28635 .53807 m .28873 .53645 L .28777 .53543 L F
.28635 .53807 m .28817 .53924 L .28873 .53645 L F
.979 .753 .526 r
.32946 .519 m .3308 .52253 L .33144 .52028 L F
.741 .876 .942 r
.29509 .63346 m .2926 .63565 L .29014 .63431 L F
.578 .456 .677 r
.29491 .61326 m .29806 .61242 L .29686 .61011 L F
.039 .379 .844 r
.58135 .37638 m .58127 .37442 L .57794 .37252 L F
.794 .685 .745 r
.58257 .37865 m .58127 .37442 L .58135 .37638 L F
.689 .76 .906 r
.33701 .62143 m .33871 .62321 L .33449 .62256 L F
.7 .761 .899 r
.33965 .61912 m .33871 .62321 L .33701 .62143 L F
.33965 .61912 m .34122 .62232 L .33871 .62321 L F
.912 .871 .437 r
.56645 .41065 m .56764 .41042 L .5676 .40794 L F
.56645 .41065 m .56688 .41273 L .56764 .41042 L F
.907 .635 .513 r
.38332 .51831 m .38614 .51624 L .38331 .51597 L F
.38332 .51831 m .386 .51989 L .38614 .51624 L F
.745 .488 .541 r
.38614 .51624 m .386 .51989 L .38938 .51954 L F
.849 .513 .417 r
.31964 .52705 m .3164 .528 L .31816 .52439 L F
.31964 .52705 m .32072 .52966 L .3164 .528 L F
.847 .386 .073 r
.54522 .42567 m .54787 .42744 L .54859 .429 L F
.86 .907 .864 r
.47808 .53004 m .47941 .52564 L .47681 .52901 L F
.47808 .53004 m .48111 .52681 L .47941 .52564 L F
.22 0 .073 r
.49615 .43126 m .49462 .43035 L .4935 .43158 L F
.49615 .43126 m .49687 .42908 L .49462 .43035 L F
0 0 .032 r
.32612 .58003 m .32527 .5837 L .32582 .58286 L F
.762 .764 .854 r
.32527 .5837 m .32197 .58312 L .32562 .58288 L F
.734 .929 .586 r
.32581 .58265 m .32562 .58288 L .32527 .5837 L F
0 0 .032 r
.32584 .58263 m .32584 .58266 L .32581 .58265 L F
.734 .929 .586 r
.32648 .58136 m .32581 .58265 L .32803 .58263 L F
.32581 .58265 m .32527 .5837 L .32672 .58314 L F
.32581 .58265 m .32672 .58314 L .32803 .58263 L F
0 0 .032 r
.32581 .58265 m .32582 .58286 L .32574 .58271 L F
.32584 .58266 m .32582 .58286 L .32581 .58265 L F
.762 .764 .854 r
.32527 .5837 m .32562 .58288 L .32582 .58286 L F
.734 .929 .586 r
.32562 .58288 m .32409 .58467 L .32527 .5837 L F
0 0 .032 r
.32612 .58003 m .32584 .58263 L .32422 .57969 L F
.32584 .58263 m .32574 .58271 L .32422 .57969 L F
.733 .515 .597 r
.32422 .57969 m .32574 .58271 L .32012 .58115 L F
.32574 .58271 m .32582 .58286 L .32566 .58282 L F
.32574 .58271 m .32566 .58282 L .32012 .58115 L F
.661 .641 .819 r
.32566 .58282 m .32197 .58312 L .32012 .58115 L F
.32582 .58286 m .32562 .58288 L .32566 .58282 L F
.32562 .58288 m .32197 .58312 L .32566 .58282 L F
.734 .929 .586 r
.32648 .58136 m .32512 .58324 L .32571 .58274 L F
.32581 .58259 m .32571 .58274 L .32574 .58271 L F
.32648 .58136 m .32571 .58274 L .32581 .58259 L F
.32586 .58256 m .32574 .58271 L .32581 .58265 L F
.32648 .58136 m .32574 .58271 L .32586 .58256 L F
.32512 .58324 m .32409 .58467 L .32581 .58265 L F
.618 .935 .961 r
.32612 .58003 m .32422 .57969 L .32682 .57847 L F
.692 .909 .564 r
.64928 .37668 m .64663 .38014 L .648 .37778 L F
.62 .864 .989 r
.648 .37778 m .64663 .38014 L .64533 .37891 L F
.53 .853 .562 r
.45035 .43591 m .44674 .43921 L .44908 .43799 L F
0 0 0 r
.44908 .43799 m .45238 .43545 L .45035 .43591 L F
.829 .983 .699 r
.52019 .37634 m .51988 .37577 L .52187 .37304 L F
.469 .377 .668 r
.52364 .37869 m .52019 .37634 L .52461 .37649 L F
.52364 .37869 m .52133 .37961 L .52019 .37634 L F
.294 .179 .547 r
.25537 .56013 m .25777 .55935 L .25718 .556 L F
0 0 .321 r
.25537 .56013 m .25633 .56125 L .25777 .55935 L F
.25537 .56013 m .25549 .56324 L .25633 .56125 L F
.776 .621 .688 r
.53607 .45304 m .53434 .45603 L .53431 .45339 L F
.631 .842 .981 r
.49598 .49149 m .49416 .49259 L .49185 .49094 L F
.952 .651 .428 r
.39277 .51485 m .39505 .51606 L .39473 .51328 L F
.39473 .51328 m .39505 .51606 L .39277 .51485 L F
.771 .364 .281 r
.41377 .4761 m .41291 .47846 L .41076 .4754 L F
0 0 .287 r
.41408 .47278 m .41418 .47579 L .41377 .4761 L F
0 0 0 r
.41418 .47579 m .41291 .47846 L .41377 .4761 L F
.261 .741 .931 r
.28269 .6373 m .27882 .63701 L .2811 .6362 L F
.469 .757 .993 r
.28362 .63562 m .28269 .6373 L .2811 .6362 L F
.28362 .63562 m .28527 .63701 L .28269 .6373 L F
.894 .657 .142 r
.55917 .34773 m .55899 .34868 L .55876 .34602 L F
.387 .786 .986 r
.55899 .34868 m .56323 .34916 L .55917 .34773 L F
.583 .142 .168 r
.52203 .43513 m .5202 .43333 L .51993 .4336 L F
.75 .919 .554 r
.57326 .40135 m .57222 .40372 L .57472 .39993 L F
.986 .712 .392 r
.57326 .40135 m .57472 .39993 L .57318 .39846 L F
.951 .893 .736 r
.28035 .54443 m .28199 .5453 L .28311 .54335 L F
.953 .884 .727 r
.28035 .54443 m .28311 .54335 L .28382 .54114 L F
.8 .826 .872 r
.57169 .3897 m .57539 .3895 L .57435 .38855 L F
.909 .978 .786 r
.5037 .48713 m .50122 .4907 L .5014 .48786 L F
.816 .931 .909 r
.5014 .48786 m .50122 .4907 L .49958 .48955 L F
.528 .827 .499 r
.5399 .39606 m .54051 .39541 L .54175 .39415 L F
.596 .523 .744 r
.53901 .40188 m .54157 .40151 L .54086 .39537 L F
.485 0 .002 r
.54053 .39539 m .54449 .39456 L .54175 .39415 L F
.596 .523 .744 r
.54079 .39538 m .54086 .39537 L .54084 .39519 L F
.53901 .40188 m .54086 .39537 L .54079 .39538 L F
.528 .827 .499 r
.53935 .39669 m .5399 .39606 L .54175 .39415 L F
.485 0 .002 r
.54051 .39541 m .54062 .39538 L .54053 .39539 L F
.54062 .39538 m .54449 .39456 L .54053 .39539 L F
.596 .523 .744 r
.53901 .40188 m .54079 .39538 L .54061 .3954 L F
.485 0 .002 r
.54077 .39538 m .54061 .39539 L .54051 .39541 L F
.608 .533 .744 r
.54103 .39536 m .54157 .40151 L .54484 .39879 L F
.54086 .39537 m .54157 .40151 L .54103 .39536 L F
.596 .523 .744 r
.54045 .39606 m .54064 .39528 L .53994 .39602 L F
.983 .907 .602 r
.53935 .39669 m .53817 .39965 L .53797 .39645 L F
.596 .523 .744 r
.54045 .39606 m .53994 .39602 L .53823 .39784 L F
.53901 .40188 m .54045 .39606 L .53823 .39784 L F
.015 0 0 r
.53797 .39645 m .5399 .39606 L .53935 .39669 L F
.596 .523 .744 r
.53823 .39784 m .5399 .39606 L .53797 .39645 L F
.5399 .39606 m .54064 .39528 L .53797 .39645 L F
.015 0 0 r
.53797 .39645 m .54012 .39581 L .5399 .39606 L F
.528 .827 .499 r
.5399 .39606 m .54012 .39581 L .54051 .39541 L F
.485 0 .002 r
.54132 .39546 m .54313 .39627 L .54449 .39456 L F
.608 .533 .744 r
.54269 .3962 m .54484 .39879 L .54288 .39631 L F
.54147 .39554 m .54188 .39594 L .54269 .3962 L F
.54188 .39594 m .54484 .39879 L .54269 .3962 L F
.722 .261 .155 r
.54284 .39625 m .54623 .3965 L .54611 .39638 L F
.246 0 0 r
.54284 .39625 m .54307 .39626 L .54269 .3962 L F
.722 .261 .155 r
.54284 .39625 m .54611 .39638 L .54449 .39456 L F
.246 0 0 r
.54284 .39625 m .54313 .39627 L .54307 .39626 L F
.608 .533 .744 r
.54103 .39536 m .54484 .39879 L .54142 .3955 L F
.246 0 0 r
.54284 .39625 m .54269 .3962 L .54012 .39581 L F
.485 0 .002 r
.54012 .39581 m .54269 .3962 L .54132 .39546 L F
.54269 .3962 m .54313 .39627 L .54132 .39546 L F
.608 .533 .744 r
.54142 .3955 m .54147 .39554 L .54284 .39625 L F
.54147 .39554 m .54288 .39631 L .54284 .39625 L F
.485 0 .002 r
.54144 .39543 m .54146 .3953 L .54051 .39541 L F
.608 .533 .744 r
.54084 .39519 m .54103 .39536 L .54142 .3955 L F
.485 0 .002 r
.54012 .39581 m .54132 .39546 L .54051 .39541 L F
.54132 .39546 m .54144 .39543 L .54121 .39542 L F
.54132 .39546 m .54121 .39542 L .54051 .39541 L F
.54144 .39543 m .54221 .39521 L .54146 .3953 L F
.608 .533 .744 r
.54084 .39519 m .54086 .39537 L .54103 .39536 L F
.596 .523 .744 r
.54061 .3954 m .54084 .39519 L .54064 .39528 L F
.54079 .39538 m .54084 .39519 L .54061 .3954 L F
.015 0 0 r
.53797 .39645 m .54084 .39519 L .54012 .39581 L F
.47 0 0 r
.54084 .39519 m .54142 .3955 L .53895 .39593 L F
.246 0 0 r
.54284 .39625 m .54012 .39581 L .54084 .39519 L F
.47 0 0 r
.54142 .3955 m .54284 .39625 L .54131 .39613 L F
.54142 .3955 m .54131 .39613 L .53895 .39593 L F
.53895 .39593 m .54131 .39613 L .54084 .39519 L F
.54131 .39613 m .54284 .39625 L .54142 .3955 L F
.54131 .39613 m .54142 .3955 L .54084 .39519 L F
.485 0 .002 r
.54221 .39521 m .54449 .39456 L .54148 .3952 L F
.54146 .39529 m .54148 .3952 L .54061 .39539 L F
.54221 .39521 m .54148 .3952 L .54146 .39529 L F
.54221 .39521 m .54061 .39539 L .54077 .39538 L F
0 0 0 r
.50454 .42721 m .50128 .43006 L .50372 .42832 L F
.064 0 0 r
.5076 .42567 m .50454 .42721 L .50372 .42832 L F
0 0 .031 r
.50602 .42449 m .50454 .42721 L .5076 .42567 L F
.861 .775 .765 r
.3152 .51997 m .31381 .51555 L .31551 .51657 L F
.574 .864 .996 r
.31551 .51657 m .31616 .51268 L .31483 .51307 L F
.31551 .51657 m .31637 .51455 L .31616 .51268 L F
.31551 .51657 m .31381 .51555 L .31637 .51455 L F
.608 .952 .815 r
.45751 .44202 m .46172 .43988 L .4597 .44067 L F
.535 .916 .778 r
.46404 .43833 m .46317 .43846 L .46172 .43988 L F
.533 .911 .751 r
.46172 .43988 m .46317 .43846 L .4597 .44067 L F
0 0 0 r
.64928 .37668 m .65067 .37676 L .65182 .37562 L F
.64928 .37668 m .648 .37778 L .65067 .37676 L F
.55852 .40905 m .55605 .41277 L .55807 .41152 L F
0 0 .068 r
.55807 .41152 m .55911 .40922 L .55852 .40905 L F
.815 .867 .424 r
.55814 .4113 m .55911 .40922 L .55807 .41152 L F
0 0 .043 r
.55852 .40905 m .55911 .40922 L .55984 .40767 L F
.815 .867 .424 r
.55955 .40686 m .55911 .40922 L .55814 .4113 L F
0 0 .043 r
.55984 .40767 m .55911 .40922 L .56133 .40611 L F
.675 .822 .954 r
.41407 .59629 m .41635 .59788 L .41877 .59614 L F
.711 .454 .533 r
.39833 .53223 m .40099 .53005 L .39828 .5298 L F
.39833 .53223 m .40148 .53266 L .40099 .53005 L F
0 0 0 r
.56372 .36658 m .5635 .36969 L .56363 .36849 L F
.56372 .36658 m .56363 .36849 L .56346 .36666 L F
0 0 .223 r
.51887 .39037 m .51757 .3902 L .51928 .38837 L F
.51887 .39037 m .5169 .393 L .51757 .3902 L F
.802 .695 .746 r
.53304 .44934 m .53431 .45339 L .53276 .45221 L F
.536 0 0 r
.58503 .39617 m .58483 .39725 L .58488 .39461 L F
.58503 .39617 m .58616 .39774 L .58483 .39725 L F
.407 .18 .454 r
.26837 .53983 m .27088 .53915 L .27109 .53654 L F
.401 .196 .483 r
.2682 .54267 m .27088 .53915 L .26837 .53983 L F
.625 .941 .724 r
.49578 .40378 m .49723 .40196 L .49726 .40196 L F
0 0 0 r
.59421 .38782 m .59216 .3916 L .59265 .38984 L F
.447 .872 .928 r
.43785 .58413 m .43859 .58296 L .43561 .58329 L F
.43785 .58413 m .44039 .58325 L .43859 .58296 L F
.858 .74 .731 r
.33732 .54245 m .33884 .54643 L .33973 .54383 L F
.012 0 0 r
.40609 .47108 m .40881 .47017 L .40722 .47144 L F
.826 .552 .002 r
.59729 .36729 m .59744 .36694 L .59766 .36676 L F
.59729 .36729 m .59792 .36961 L .59744 .36694 L F
.37 .29 .635 r
.2679 .56276 m .26643 .56219 L .26765 .56189 L F
.2679 .56276 m .26684 .5663 L .26643 .56219 L F
.665 .936 .661 r
.5037 .48713 m .50492 .4853 L .50535 .48531 L F
.677 .976 .831 r
.5037 .48713 m .5014 .48786 L .50492 .4853 L F
.993 .867 .598 r
.30512 .64556 m .30542 .6467 L .30367 .65061 L F
0 0 0 r
.5229 .41769 m .52415 .41727 L .524 .41478 L F
.5229 .41769 m .52558 .41676 L .52415 .41727 L F
.734 .905 .954 r
.31746 .57679 m .3149 .57709 L .31593 .5751 L F
.549 .503 .757 r
.31767 .57913 m .3149 .57709 L .31746 .57679 L F
.975 .895 .681 r
.31826 .57382 m .31746 .57679 L .31593 .5751 L F
.772 .96 .65 r
.57063 .40481 m .57222 .40372 L .57326 .40135 L F
.706 .892 .965 r
.50372 .42832 m .50128 .43006 L .49958 .42893 L F
.926 .65 .499 r
.32683 .55323 m .32452 .55254 L .32432 .5495 L F
.885 .495 .29 r
.32683 .55323 m .32507 .55484 L .32452 .55254 L F
.934 .588 .349 r
.32683 .55323 m .32755 .55648 L .32507 .55484 L F
0 .002 .573 r
.27192 .65606 m .27391 .65966 L .27397 .65859 L F
.753 .945 .618 r
.27609 .65667 m .27391 .65966 L .27397 .65859 L F
0 0 .384 r
.27391 .65966 m .27539 .66312 L .27397 .65859 L F
.893 .481 .208 r
.67618 .34556 m .67849 .34771 L .67803 .34645 L F
.663 .88 .979 r
.4219 .59332 m .42252 .5944 L .42595 .59317 L F
.099 .368 .832 r
.51504 .40326 m .5173 .40506 L .51662 .40621 L F
0 0 0 r
.5173 .40506 m .51567 .4079 L .51662 .40621 L F
.739 .706 .82 r
.32182 .5962 m .32619 .5968 L .32497 .59329 L F
.732 .7 .82 r
.54412 .43622 m .54504 .43993 L .54099 .43937 L F
.786 .763 .832 r
.29919 .6333 m .29509 .63346 L .29747 .63233 L F
.532 .866 .993 r
.30002 .63173 m .30174 .63256 L .29919 .6333 L F
.489 .82 .999 r
.30002 .63173 m .29919 .6333 L .29747 .63233 L F
.415 .187 .457 r
.27109 .53654 m .27361 .53594 L .2739 .5333 L F
.203 0 .26 r
.27088 .53915 m .27361 .53594 L .27109 .53654 L F
.03 .263 .762 r
.57785 .36323 m .57837 .36103 L .57564 .35897 L F
.817 .501 0 r
.57785 .36323 m .57749 .36396 L .57837 .36103 L F
0 0 .532 r
.28584 .67947 m .28565 .67888 L .28354 .677 L F
.28584 .67947 m .28764 .68143 L .28565 .67888 L F
.501 .811 1 r
.53809 .43336 m .53646 .43558 L .53522 .43468 L F
.53809 .43336 m .53954 .4349 L .53646 .43558 L F
.196 .691 .918 r
.6476 .3533 m .64585 .35257 L .64353 .35264 L F
.64353 .35264 m .64585 .35257 L .6476 .3533 L F
.544 .888 .984 r
.64919 .35165 m .64585 .35257 L .6476 .3533 L F
.64919 .35165 m .64585 .35257 L .6476 .3533 L F
.21 0 .244 r
.4078 .56014 m .40969 .56098 L .41151 .56 L F
.687 .954 .698 r
.41151 .56 m .40969 .56098 L .41267 .55804 L F
.953 .884 .727 r
.28035 .54443 m .28382 .54114 L .28433 .54221 L F
0 0 0 r
.42769 .45183 m .42605 .45209 L .42532 .45291 L F
.514 .582 .861 r
.29832 .67695 m .29411 .67369 L .29681 .67316 L F
0 .525 .715 r
.59989 .34406 m .60244 .34431 L .60349 .34444 L F
.974 .702 .449 r
.39721 .49356 m .39536 .49495 L .3952 .49196 L F
.373 .803 .967 r
.3952 .49196 m .3991 .49211 L .39721 .49356 L F
0 0 0 r
.39787 .4941 m .39721 .49356 L .3991 .49211 L F
.39787 .4941 m .39536 .49495 L .39721 .49356 L F
.149 .683 .853 r
.59565 .34384 m .59989 .34406 L .59706 .34287 L F
.517 .914 .819 r
.4721 .43255 m .47353 .4308 L .47226 .43163 L F
.4721 .43255 m .4769 .43009 L .47353 .4308 L F
.911 .893 .799 r
.47941 .52564 m .48338 .52322 L .48162 .52188 L F
.47941 .52564 m .48111 .52681 L .48338 .52322 L F
.875 .843 .81 r
.48162 .52188 m .48338 .52322 L .48589 .51968 L F
.48162 .52188 m .48589 .51968 L .48452 .51864 L F
.897 .934 .831 r
.48452 .51864 m .48589 .51968 L .48853 .51625 L F
.978 .68 .345 r
.41622 .56126 m .41732 .5602 L .41638 .55917 L F
.41622 .56126 m .41738 .56235 L .41732 .5602 L F
.767 .543 .594 r
.50084 .45139 m .50632 .44927 L .50203 .44992 L F
.50084 .45139 m .50741 .45301 L .50632 .44927 L F
.785 .523 0 r
.29806 .61242 m .29902 .61673 L .30153 .61598 L F
.887 .614 .519 r
.35548 .52302 m .35289 .5224 L .35316 .51976 L F
.886 .606 .507 r
.35548 .52302 m .353 .52513 L .35289 .5224 L F
.812 .477 .421 r
.35691 .52551 m .353 .52513 L .35548 .52302 L F
.948 .832 .696 r
.38856 .55513 m .39159 .55347 L .38899 .55244 L F
.937 .761 .638 r
.33701 .54529 m .33884 .54643 L .33732 .54245 L F
.922 .729 .624 r
.33701 .54529 m .33799 .54896 L .33884 .54643 L F
.825 .994 .859 r
.52216 .485 m .52606 .48282 L .5246 .48135 L F
.736 .92 .954 r
.52966 .4803 m .5246 .48135 L .52606 .48282 L F
.912 .625 .132 r
.40014 .5407 m .40082 .53984 L .39954 .53823 L F
.40014 .5407 m .40131 .54292 L .40082 .53984 L F
.473 .877 .723 r
.31907 .64629 m .32209 .64465 L .32101 .645 L F
.289 0 0 r
.32209 .64465 m .32499 .64526 L .32101 .645 L F
.841 .973 .879 r
.43686 .5522 m .43905 .54886 L .43811 .55047 L F
.43686 .5522 m .43833 .55018 L .43905 .54886 L F
.586 .727 .941 r
.43827 .55019 m .44295 .54959 L .43811 .55047 L F
.43905 .54886 m .44154 .54933 L .43827 .55019 L F
.44154 .54933 m .44295 .54959 L .43827 .55019 L F
.629 .706 .901 r
.43905 .54886 m .44266 .54903 L .44295 .54959 L F
.109 0 .091 r
.43582 .55458 m .43891 .55171 L .43833 .55018 L F
0 0 .172 r
.43891 .55171 m .44011 .54975 L .43833 .55018 L F
.884 .992 .781 r
.4368 .55278 m .43873 .55013 L .44011 .54975 L F
0 0 0 r
.43833 .55018 m .44266 .54903 L .43905 .54886 L F
.884 .992 .781 r
.43873 .55013 m .43935 .54929 L .44011 .54975 L F
0 0 0 r
.44239 .54911 m .44011 .54975 L .44259 .54905 L F
.43833 .55018 m .44011 .54975 L .44239 .54911 L F
.44174 .54928 m .44259 .54905 L .44266 .54903 L F
.43833 .55018 m .44259 .54905 L .44174 .54928 L F
.109 0 .091 r
.43582 .55458 m .43833 .55018 L .43686 .5522 L F
.617 .819 .978 r
.54265 .46546 m .54401 .46693 L .54673 .46601 L F
0 0 .106 r
.4789 .50317 m .4811 .50171 L .48131 .49952 L F
0 0 .046 r
.4789 .50317 m .4794 .50333 L .4811 .50171 L F
.4789 .50317 m .47856 .50578 L .4794 .50333 L F
.049 0 .114 r
.26659 .56904 m .26373 .57244 L .2648 .57013 L F
.786 .832 .887 r
.31382 .62824 m .31552 .62952 L .31118 .62946 L F
.794 .832 .881 r
.31837 .62653 m .31552 .62952 L .31382 .62824 L F
.965 .808 .377 r
.3802 .57934 m .38054 .58113 L .38052 .57821 L F
.008 .23 .738 r
.3802 .57934 m .3818 .5831 L .38054 .58113 L F
.83 .936 .898 r
.50614 .49752 m .50953 .49739 L .5109 .49569 L F
.911 .521 .255 r
.52773 .3601 m .52632 .36129 L .52519 .35981 L F
.988 .858 .496 r
.52696 .3585 m .52632 .36129 L .52773 .3601 L F
0 .035 .562 r
.56925 .36175 m .56966 .36612 L .56876 .36384 L F
.975 .895 .681 r
.31826 .57382 m .31593 .5751 L .31721 .57159 L F
.696 .847 .955 r
.4109 .58686 m .40591 .58752 L .40708 .5866 L F
.897 .934 .831 r
.48452 .51864 m .48853 .51625 L .48698 .515 L F
.89 .888 .823 r
.48698 .515 m .48853 .51625 L .49109 .51281 L F
.813 .54 .525 r
.35939 .5265 m .35548 .5285 L .35691 .52551 L F
.35939 .5265 m .35937 .52924 L .35548 .5285 L F
0 0 .378 r
.51334 .41188 m .51335 .41437 L .51134 .41602 L F
.093 0 .346 r
.51356 .41727 m .51134 .41602 L .51335 .41437 L F
.51356 .41727 m .51093 .41913 L .51134 .41602 L F
0 .274 .779 r
.39651 .56293 m .39389 .55952 L .39399 .56218 L F
.58 .288 .436 r
.39399 .56218 m .39477 .56505 L .39651 .56293 L F
.822 .757 .791 r
.33101 .58709 m .33259 .58268 L .32975 .586 L F
.362 .407 .774 r
.50243 .41993 m .50565 .42144 L .50471 .41823 L F
.628 .66 .862 r
.54412 .43622 m .54116 .43791 L .53954 .4349 L F
.414 .215 .499 r
.54412 .43622 m .54099 .43937 L .54116 .43791 L F
.909 .685 .587 r
.33089 .52553 m .33063 .5284 L .33469 .52972 L F
.91 .649 .531 r
.33033 .53104 m .33469 .52972 L .33063 .5284 L F
.33033 .53104 m .33452 .53335 L .33469 .52972 L F
.909 .648 .531 r
.33469 .52972 m .33452 .53335 L .33598 .53312 L F
.856 .968 .647 r
.45425 .53557 m .4522 .53683 L .45329 .53525 L F
.45425 .53557 m .45188 .5394 L .4522 .53683 L F
.552 .928 .915 r
.45425 .53557 m .45544 .534 L .45752 .53293 L F
.45425 .53557 m .45329 .53525 L .45544 .534 L F
.862 .962 .627 r
.30081 .60717 m .29965 .60798 L .30078 .60745 L F
.30104 .60489 m .30079 .60695 L .29965 .60798 L F
.30104 .60489 m .29965 .60798 L .30081 .60717 L F
0 0 0 r
.29965 .60798 m .30079 .60695 L .29856 .60874 L F
.29965 .60798 m .29856 .60874 L .29686 .61011 L F
.571 .513 .751 r
.40537 .56303 m .40664 .5674 L .40877 .56601 L F
0 0 0 r
.43686 .4558 m .43554 .45776 L .43414 .45928 L F
.43996 .45235 m .43876 .45501 L .43686 .4558 L F
.43876 .45501 m .43554 .45776 L .43686 .4558 L F
.89 .888 .823 r
.48698 .515 m .49109 .51281 L .48991 .51189 L F
.875 .965 .852 r
.48991 .51189 m .49109 .51281 L .49398 .50957 L F
.528 .56 .831 r
.29508 .67115 m .29411 .67369 L .29292 .67214 L F
.564 .6 .848 r
.29508 .67115 m .29681 .67316 L .29411 .67369 L F
.262 0 0 r
.64583 .34569 m .64493 .3462 L .64206 .34622 L F
.454 0 0 r
.64883 .34625 m .64493 .3462 L .64583 .34569 L F
.422 .347 .667 r
.59886 .35914 m .59968 .36198 L .597 .3603 L F
.673 .761 .917 r
.30408 .63174 m .30611 .63334 L .30174 .63256 L F
.72 .794 .91 r
.30702 .62948 m .30611 .63334 L .30408 .63174 L F
.30702 .62948 m .30794 .63225 L .30611 .63334 L F
.2 0 0 r
.54561 .40224 m .54914 .40065 L .54748 .39859 L F
.54561 .40224 m .54853 .40166 L .54914 .40065 L F
.377 .153 .443 r
.2739 .5333 m .27625 .53257 L .27656 .52981 L F
.304 .096 .424 r
.2739 .5333 m .27571 .53507 L .27625 .53257 L F
.2739 .5333 m .27361 .53594 L .27571 .53507 L F
.999 .788 .474 r
.32432 .5495 m .32344 .54541 L .32583 .54676 L F
.444 .272 .552 r
.57552 .37321 m .57794 .37252 L .57768 .36962 L F
.454 .718 .981 r
.30169 .5888 m .3 .5898 L .29838 .58831 L F
.29838 .58831 m .3 .5898 L .30169 .5888 L F
.302 .308 .7 r
.25099 .57225 m .25142 .57643 L .25362 .5749 L F
.568 .31 .485 r
.25142 .57643 m .25432 .57872 L .25362 .5749 L F
.25142 .57643 m .25135 .57915 L .25432 .57872 L F
0 .08 .641 r
.38044 .52611 m .3825 .52831 L .38218 .52935 L F
.793 .297 0 r
.38214 .53106 m .38477 .53247 L .38218 .52935 L F
.38214 .53106 m .38218 .52935 L .3825 .52831 L F
.475 .693 .963 r
.37593 .51757 m .37882 .51522 L .37661 .51564 L F
.37574 .51813 m .37627 .51763 L .37593 .51757 L F
.37627 .51763 m .37688 .51705 L .37593 .51757 L F
.37688 .51705 m .37881 .51657 L .37882 .51522 L F
.024 0 .358 r
.37714 .51778 m .37664 .51769 L .37663 .51768 L F
.475 .693 .963 r
.37663 .51768 m .377 .51749 L .37627 .51763 L F
.024 0 .358 r
.37707 .51774 m .37663 .51768 L .37632 .51734 L F
.37714 .51778 m .37663 .51768 L .37707 .51774 L F
.475 .693 .963 r
.37627 .51763 m .377 .51749 L .37688 .51705 L F
.37574 .51813 m .37663 .51768 L .37627 .51763 L F
.377 .51749 m .37881 .51657 L .37688 .51705 L F
.691 .804 .935 r
.37663 .51768 m .3786 .51984 L .37574 .51813 L F
.024 0 .358 r
.37911 .51888 m .3786 .51984 L .37664 .51769 L F
.357 .699 .983 r
.3786 .51984 m .37982 .5191 L .37913 .51885 L F
.024 0 .358 r
.37994 .51928 m .3786 .51984 L .37911 .51888 L F
.357 .699 .983 r
.3786 .51984 m .37913 .51885 L .37574 .51813 L F
.37913 .51885 m .37919 .51873 L .37851 .51861 L F
.37913 .51885 m .37851 .51861 L .37574 .51813 L F
.475 .693 .963 r
.377 .51749 m .3788 .51784 L .37881 .51657 L F
.37574 .51813 m .37713 .518 L .377 .51749 L F
.024 0 .358 r
.37969 .51915 m .37664 .51769 L .37714 .51778 L F
.988 .743 .467 r
.38237 .5228 m .38015 .5189 L .3786 .51984 L F
.024 0 .358 r
.37994 .51928 m .37973 .51918 L .37969 .51915 L F
.37973 .51918 m .37664 .51769 L .37969 .51915 L F
.475 .693 .963 r
.37818 .5179 m .38015 .5189 L .3788 .51784 L F
.81 .462 .397 r
.37714 .51778 m .37723 .51804 L .37913 .51885 L F
.475 .693 .963 r
.37574 .51813 m .37851 .51861 L .37713 .518 L F
.81 .462 .397 r
.37723 .51804 m .37727 .51815 L .37851 .51861 L F
.37723 .51804 m .37851 .51861 L .37913 .51885 L F
.475 .693 .963 r
.37713 .518 m .37919 .51873 L .37818 .5179 L F
.37851 .51861 m .37919 .51873 L .37713 .518 L F
.37919 .51873 m .38015 .5189 L .37818 .5179 L F
.81 .462 .397 r
.37707 .51774 m .37708 .5178 L .37714 .51778 L F
.475 .693 .963 r
.37713 .518 m .3788 .51784 L .377 .51749 L F
.81 .462 .397 r
.37632 .51734 m .37668 .51793 L .37708 .5178 L F
.37632 .51734 m .37708 .5178 L .37707 .51774 L F
.37668 .51793 m .37788 .51993 L .37727 .51815 L F
.37668 .51793 m .37727 .51815 L .37714 .51778 L F
.37913 .51885 m .37857 .51933 L .37994 .51928 L F
.37857 .51933 m .3789 .51961 L .37994 .51928 L F
.357 .699 .983 r
.37913 .51885 m .38015 .5189 L .37919 .51873 L F
.37982 .5191 m .38015 .5189 L .37913 .51885 L F
.988 .743 .467 r
.38237 .5228 m .3786 .51984 L .37835 .52288 L F
.024 0 .358 r
.37994 .51928 m .37835 .52288 L .3786 .51984 L F
.988 .743 .467 r
.38237 .5228 m .38066 .52225 L .38015 .5189 L F
.9 .625 .512 r
.37865 .52003 m .37835 .52288 L .37994 .51928 L F
.37374 .52289 m .37797 .52288 L .37865 .52003 L F
.37797 .52288 m .37835 .52288 L .37865 .52003 L F
.157 0 .081 r
.37551 .52067 m .37374 .52289 L .37865 .52003 L F
.3789 .51961 m .37865 .52003 L .37994 .51928 L F
.37551 .52067 m .37865 .52003 L .3789 .51961 L F
.904 .697 .613 r
.38015 .5189 m .38066 .52225 L .3788 .51784 L F
.543 .535 .796 r
.37944 .51869 m .37992 .52048 L .38178 .52184 L F
.37908 .51822 m .37933 .51888 L .37944 .51869 L F
.37933 .51888 m .37992 .52048 L .37944 .51869 L F
.3788 .51784 m .37904 .5184 L .37908 .51822 L F
.37904 .5184 m .37992 .52048 L .37908 .51822 L F
.37992 .52048 m .38066 .52225 L .38158 .52191 L F
.37992 .52048 m .38158 .52191 L .38178 .52184 L F
.81 .462 .397 r
.37857 .51933 m .37788 .51993 L .3789 .51961 L F
.37727 .51815 m .37788 .51993 L .37913 .51885 L F
.37682 .51834 m .37551 .52067 L .37766 .52 L F
0 0 0 r
.37658 .51938 m .37452 .52245 L .37551 .52067 L F
.37452 .52245 m .37422 .5229 L .37551 .52067 L F
.81 .462 .397 r
.37632 .51734 m .37551 .52067 L .37682 .51834 L F
.37746 .51922 m .37766 .52 L .37788 .51993 L F
.37632 .51734 m .37766 .52 L .37746 .51922 L F
.691 .804 .935 r
.37632 .51734 m .37663 .51768 L .37574 .51813 L F
.475 .693 .963 r
.37688 .51705 m .37882 .51522 L .37682 .51685 L F
.37688 .51705 m .37682 .51685 L .37593 .51757 L F
.826 .71 .737 r
.65677 .34977 m .65317 .34895 L .65555 .34582 L F
.926 .653 .503 r
.65529 .35147 m .65317 .34895 L .65677 .34977 L F
.962 .733 .547 r
.67758 .35202 m .6791 .35606 L .67926 .35327 L F
0 .045 .613 r
.56648 .35289 m .5685 .35544 L .56816 .35668 L F
0 .029 .599 r
.5685 .35544 m .56948 .35927 L .56816 .35668 L F
.593 .947 .823 r
.30864 .65216 m .31329 .64987 L .31131 .64878 L F
.871 .88 .84 r
.31131 .64878 m .31329 .64987 L .31572 .64675 L F
.548 .898 .977 r
.61799 .39733 m .62276 .39692 L .61962 .39517 L F
.095 0 0 r
.62487 .39531 m .61962 .39517 L .62276 .39692 L F
.534 .069 .098 r
.41101 .55133 m .4148 .54985 L .41274 .54988 L F
.362 .043 .283 r
.32682 .57847 m .32422 .57969 L .3247 .57729 L F
0 0 .202 r
.28907 .52827 m .2872 .53245 L .28678 .52984 L F
.24 .308 .732 r
.55835 .35316 m .56052 .35512 L .55958 .35116 L F
.286 .307 .708 r
.2615 .58187 m .26034 .58315 L .25969 .57927 L F
.185 0 0 r
.26144 .58466 m .26034 .58315 L .2615 .58187 L F
.26144 .58466 m .25863 .58559 L .26034 .58315 L F
.235 .354 .782 r
.52681 .43074 m .5239 .43154 L .52458 .43004 L F
.018 0 .011 r
.52386 .43369 m .5239 .43154 L .52681 .43074 L F
.846 .576 .53 r
.36511 .53641 m .36154 .53577 L .36243 .53312 L F
.835 .572 .541 r
.36511 .53641 m .36138 .53849 L .36154 .53577 L F
.36511 .53641 m .36505 .53928 L .36138 .53849 L F
.303 0 .1 r
.49958 .42893 m .49687 .42908 L .49615 .43126 L F
.874 .67 .624 r
.36802 .54288 m .36447 .5421 L .36505 .53928 L F
.847 .59 .551 r
.36802 .54288 m .36413 .54496 L .36447 .5421 L F
.36802 .54288 m .36716 .54588 L .36413 .54496 L F
.554 .011 0 r
.30554 .58337 m .30773 .58542 L .30586 .58413 L F
.419 .22 .501 r
.30796 .58246 m .30773 .58542 L .30554 .58337 L F
.554 .011 0 r
.30554 .58337 m .30586 .58413 L .30796 .58246 L F
.369 .167 .47 r
.27656 .52981 m .27885 .5291 L .27912 .52633 L F
.29 .059 .38 r
.27625 .53257 m .27885 .5291 L .27656 .52981 L F
.841 .9 .485 r
.45188 .5394 m .4514 .53955 L .4522 .53683 L F
.872 .736 .71 r
.45188 .5394 m .44791 .54201 L .4514 .53955 L F
.45188 .5394 m .45007 .54333 L .44791 .54201 L F
.404 .739 .992 r
.36935 .57663 m .37379 .57774 L .3724 .57627 L F
.021 0 .487 r
.37379 .57774 m .37531 .5746 L .37585 .57492 L F
.37379 .57774 m .37585 .57492 L .37525 .57516 L F
.37379 .57774 m .37529 .57508 L .37531 .5746 L F
.928 .863 .756 r
.37161 .57256 m .36935 .57663 L .36759 .57492 L F
.741 .846 .929 r
.37037 .57468 m .3724 .57627 L .37525 .57516 L F
.277 .22 .612 r
.37529 .57506 m .3754 .5749 L .37531 .5746 L F
.795 .791 .849 r
.37511 .57354 m .37037 .57468 L .3754 .5749 L F
.281 .58 .942 r
.37531 .5746 m .37552 .57457 L .37585 .57492 L F
.795 .791 .849 r
.37558 .57441 m .37552 .57457 L .37585 .57492 L F
.101 .173 .652 r
.37585 .57492 m .37591 .56999 L .37511 .57354 L F
.37585 .57492 m .37689 .57433 L .37591 .56999 L F
.281 .58 .942 r
.37552 .57457 m .37689 .57433 L .37585 .57492 L F
.795 .791 .849 r
.37552 .57457 m .3754 .5749 L .37585 .57492 L F
.277 .22 .612 r
.3754 .5749 m .37552 .57457 L .37531 .5746 L F
.795 .791 .849 r
.37511 .57354 m .3754 .5749 L .37558 .57441 L F
.277 .22 .612 r
.3754 .5749 m .37562 .57455 L .37552 .57457 L F
.37515 .57845 m .37689 .57433 L .37562 .57455 L F
.741 .846 .929 r
.3754 .5749 m .37525 .57516 L .37585 .57492 L F
.37529 .57506 m .37525 .57516 L .3754 .5749 L F
.277 .22 .612 r
.37515 .57845 m .37562 .57455 L .37529 .57506 L F
.741 .846 .929 r
.37537 .5749 m .37529 .57506 L .3754 .5749 L F
.37037 .57468 m .37525 .57516 L .37537 .5749 L F
.021 0 .487 r
.37525 .57516 m .37515 .57845 L .37529 .57508 L F
.37379 .57774 m .37402 .57786 L .37525 .57516 L F
.37402 .57786 m .37515 .57845 L .37525 .57516 L F
.37379 .57774 m .37525 .57516 L .3724 .57627 L F
0 0 0 r
.48396 .49572 m .48616 .49496 L .48714 .49454 L F
.378 .825 .701 r
.48616 .49496 m .49005 .49303 L .48714 .49454 L F
.965 .774 .598 r
.27486 .64975 m .27236 .65119 L .27302 .64875 L F
.27486 .64975 m .27461 .65269 L .27236 .65119 L F
.27486 .64975 m .27236 .65119 L .27302 .64875 L F
.27486 .64975 m .27461 .65269 L .27236 .65119 L F
.306 .714 .976 r
.289 .68351 m .29269 .68434 L .29153 .68232 L F
.32 .462 .846 r
.29269 .68434 m .29376 .68212 L .29153 .68232 L F
.29269 .68434 m .29554 .68577 L .29376 .68212 L F
.928 .683 .546 r
.36243 .53312 m .35927 .53466 L .35915 .53198 L F
.36243 .53312 m .36154 .53577 L .35927 .53466 L F
0 0 0 r
.48131 .49952 m .48326 .49816 L .48396 .49572 L F
0 0 .073 r
.48131 .49952 m .48226 .50051 L .48326 .49816 L F
.48131 .49952 m .4811 .50171 L .48226 .50051 L F
.711 .454 .536 r
.28675 .51885 m .29085 .51977 L .29111 .51609 L F
.436 .223 .49 r
.29111 .51609 m .29085 .51977 L .29304 .51841 L F
.016 0 0 r
.44097 .45366 m .43996 .45235 L .44279 .45124 L F
.44097 .45366 m .43876 .45501 L .43996 .45235 L F
0 0 0 r
.51278 .42458 m .51105 .42629 L .51254 .42499 L F
.251 .346 .766 r
.51105 .42629 m .51393 .42815 L .51254 .42499 L F
.723 .871 .951 r
.31773 .62436 m .32075 .62635 L .31837 .62653 L F
.755 .876 .934 r
.32359 .62301 m .32075 .62635 L .31773 .62436 L F
0 0 0 r
.58404 .38632 m .58663 .38431 L .58755 .38233 L F
.58405 .38635 m .58663 .38431 L .58404 .38632 L F
0 0 .345 r
.58392 .38645 m .58473 .38777 L .58663 .38431 L F
.916 .976 .702 r
.58663 .38431 m .58508 .38714 L .58429 .3859 L F
.58508 .38714 m .58473 .38777 L .58429 .3859 L F
0 0 .047 r
.58465 .3874 m .58516 .38821 L .58429 .3859 L F
.749 .393 0 r
.58429 .3859 m .58516 .38821 L .58378 .3851 L F
.58429 .3859 m .58378 .3851 L .58352 .38452 L F
0 0 .047 r
.58473 .38777 m .58503 .38808 L .58465 .3874 L F
.58503 .38808 m .58516 .38821 L .58465 .3874 L F
0 0 0 r
.58392 .38645 m .58405 .38635 L .58404 .38632 L F
0 0 .345 r
.58392 .38645 m .5846 .38879 L .58473 .38777 L F
.539 .03 0 r
.3818 .5831 m .38046 .58478 L .37747 .58326 L F
.212 0 .218 r
.38281 .57632 m .38052 .57821 L .38436 .57897 L F
.236 .192 .604 r
.38288 .57842 m .3818 .5831 L .3802 .57934 L F
.587 .165 .208 r
.3887 .58592 m .38557 .58601 L .38701 .58218 L F
.38557 .58601 m .38421 .58605 L .38439 .58579 L F
.38557 .58601 m .38439 .58579 L .38701 .58218 L F
.3887 .58592 m .38511 .58615 L .38421 .58605 L F
.319 .378 .766 r
.38192 .58304 m .38421 .58605 L .3818 .5831 L F
.38419 .58573 m .38421 .58605 L .38192 .58304 L F
.673 .665 .834 r
.38701 .58218 m .38421 .58605 L .38396 .58196 L F
.434 .725 .987 r
.38421 .58605 m .38511 .58615 L .38208 .58535 L F
.768 .484 .504 r
.38438 .58596 m .38376 .5885 L .38208 .58536 L F
.38219 .58538 m .38208 .58536 L .38208 .58535 L F
.38438 .58596 m .38208 .58536 L .38219 .58538 L F
.38511 .58615 m .38488 .58655 L .38438 .58596 L F
.38488 .58655 m .38376 .5885 L .38438 .58596 L F
.319 .378 .766 r
.38396 .58196 m .38419 .58573 L .38192 .58304 L F
.951 .604 .306 r
.38208 .58535 m .38046 .58478 L .3818 .5831 L F
.74 .801 .901 r
.33214 .62402 m .3278 .62378 L .33021 .62248 L F
.752 .83 .912 r
.33449 .62256 m .33214 .62402 L .33021 .62248 L F
0 0 0 r
.39476 .5805 m .39403 .58192 L .39538 .57951 L F
0 0 .027 r
.39704 .57934 m .39538 .57951 L .39803 .5799 L F
0 0 0 r
.39538 .57951 m .39704 .57934 L .39803 .5799 L F
0 0 .027 r
.39704 .57934 m .39476 .5805 L .39538 .57951 L F
0 0 0 r
.39538 .57951 m .39403 .58192 L .39704 .57934 L F
.959 .743 .57 r
.33874 .66519 m .34115 .66707 L .34128 .66471 L F
.8 .993 .876 r
.33874 .66519 m .34128 .66471 L .34318 .66277 L F
0 .244 .713 r
.34128 .66471 m .34309 .66579 L .34318 .66277 L F
.789 .8 .861 r
.34385 .61919 m .34122 .62232 L .33965 .61912 L F
.719 .937 .958 r
.60792 .35224 m .6121 .35044 L .60916 .35022 L F
.097 .654 .766 r
.61424 .35003 m .60916 .35022 L .6121 .35044 L F
.827 .948 .9 r
.30843 .59674 m .30373 .59852 L .30631 .5979 L F
.53 .343 .572 r
.29007 .65623 m .29005 .65937 L .28743 .65985 L F
.693 .461 .567 r
.29005 .65937 m .28816 .66245 L .28743 .65985 L F
.967 .69 .458 r
.36964 .55618 m .36773 .55816 L .36845 .55544 L F
.36964 .55618 m .36962 .5593 L .36773 .55816 L F
0 0 0 r
.27882 .63701 m .27632 .63967 L .27758 .63904 L F
.841 .803 .311 r
.35445 .65539 m .35518 .65302 L .35425 .65539 L F
0 0 0 r
.35425 .65539 m .35518 .65302 L .35649 .65167 L F
.731 .989 .815 r
.49853 .40036 m .49946 .39854 L .50028 .39861 L F
0 0 0 r
.49726 .40196 m .49946 .39854 L .49853 .40036 L F
.892 .987 .795 r
.58663 .41715 m .5884 .41647 L .58776 .41547 L F
.927 .628 .455 r
.58663 .41715 m .58868 .41919 L .5884 .41647 L F
.892 .987 .795 r
.58663 .41715 m .5884 .41647 L .58776 .41547 L F
.927 .628 .455 r
.58663 .41715 m .58868 .41919 L .5884 .41647 L F
.537 .322 .536 r
.317 .65588 m .31994 .65259 L .31722 .65307 L F
.333 0 .046 r
.43763 .57069 m .44071 .57001 L .43942 .56991 L F
.8 .419 .336 r
.38753 .54198 m .38912 .54505 L .39033 .54288 L F
.431 0 0 r
.39033 .54288 m .39038 .54315 L .38753 .54198 L F
.042 .495 .886 r
.38753 .54198 m .39038 .54315 L .38755 .54113 L F
.431 0 0 r
.39033 .54288 m .3905 .5432 L .39038 .54315 L F
.042 .495 .886 r
.39038 .54315 m .3905 .5432 L .3904 .54313 L F
.39038 .54315 m .3904 .54313 L .38755 .54113 L F
0 0 0 r
.39038 .54315 m .38912 .54505 L .39041 .54332 L F
.39033 .54288 m .39008 .54332 L .39038 .54315 L F
.39008 .54332 m .38912 .54505 L .39038 .54315 L F
.39174 .54155 m .3905 .5432 L .39033 .54288 L F
.39033 .54288 m .39038 .54316 L .39174 .54155 L F
.725 .793 .906 r
.38755 .54113 m .3904 .54313 L .39174 .54155 L F
.3904 .54313 m .3905 .5432 L .39174 .54155 L F
0 0 0 r
.39038 .54316 m .39041 .54332 L .39174 .54155 L F
.061 .25 .743 r
.29143 .65489 m .29227 .65818 L .29007 .65623 L F
.47 .295 .561 r
.29227 .65818 m .29005 .65937 L .29007 .65623 L F
.875 .965 .852 r
.48991 .51189 m .49398 .50957 L .49271 .50862 L F
.785 .942 .929 r
.49398 .50957 m .49358 .50757 L .49271 .50862 L F
.49398 .50957 m .49744 .50701 L .49358 .50757 L F
.762 .682 .774 r
.58547 .40578 m .5869 .40989 L .58279 .40907 L F
.278 .385 .793 r
.58873 .40766 m .5869 .40989 L .58547 .40578 L F
.145 .188 .649 r
.58883 .4117 m .5869 .40989 L .58873 .40766 L F
.924 .81 .715 r
.41328 .55532 m .41688 .55309 L .41589 .55282 L F
.41328 .55532 m .41533 .5563 L .41688 .55309 L F
.164 .392 .838 r
.41783 .55133 m .41688 .55309 L .4148 .54985 L F
.674 .976 .883 r
.41783 .55133 m .41589 .55282 L .41688 .55309 L F
.469 .076 .21 r
.39142 .46882 m .39364 .46878 L .39391 .46703 L F
.326 0 .109 r
.39364 .46878 m .39791 .46602 L .39391 .46703 L F
.772 .885 .927 r
.5597 .42947 m .56211 .42854 L .56172 .42555 L F
.792 .897 .917 r
.56172 .42555 m .56211 .42854 L .56339 .42673 L F
.736 .503 .576 r
.39502 .52934 m .39833 .53223 L .39828 .5298 L F
.894 .59 .463 r
.33452 .53335 m .33598 .53569 L .33598 .53312 L F
.758 .897 .939 r
.51945 .46645 m .52015 .46269 L .52182 .46533 L F
.51945 .46645 m .51778 .46534 L .52015 .46269 L F
.968 .651 .279 r
.51949 .46916 m .51778 .46534 L .51945 .46645 L F
.828 .995 .759 r
.58949 .36215 m .59176 .35809 L .59323 .36035 L F
.58949 .36215 m .58901 .36147 L .59176 .35809 L F
.968 .875 .691 r
.62215 .38508 m .62348 .38646 L .62276 .38708 L F
.602 .836 .988 r
.62604 .38529 m .62348 .38646 L .62215 .38508 L F
0 0 0 r
.57536 .38339 m .57517 .38331 L .57514 .38068 L F
.57536 .38339 m .57484 .38582 L .57517 .38331 L F
.159 0 0 r
.30166 .6515 m .30545 .65045 L .3044 .65172 L F
.592 .054 0 r
.30545 .65045 m .30864 .65216 L .3044 .65172 L F
.575 .817 .99 r
.61424 .35003 m .619 .3506 L .61762 .35029 L F
.923 .969 .773 r
.59339 .38152 m .59621 .37957 L .59546 .37819 L F
.59339 .38152 m .59444 .38219 L .59621 .37957 L F
0 .18 .706 r
.34679 .50046 m .34608 .50074 L .34482 .49883 L F
.34679 .50046 m .348 .50247 L .34608 .50074 L F
0 0 0 r
.57366 .34976 m .57612 .34817 L .57626 .34786 L F
0 0 .358 r
.57366 .34976 m .57556 .35016 L .57612 .34817 L F
.57366 .34976 m .57356 .35254 L .57556 .35016 L F
0 0 0 r
.23923 .59633 m .24061 .5959 L .24159 .59372 L F
.708 .753 .888 r
.3278 .62378 m .325 .62603 L .32359 .62301 L F
.156 .27 .731 r
.27721 .65478 m .27609 .65667 L .27461 .65269 L F
.418 .615 .932 r
.27721 .65478 m .27923 .65674 L .27609 .65667 L F
.827 .463 .366 r
.34497 .51332 m .34135 .51446 L .34142 .51193 L F
.34497 .51332 m .34518 .51548 L .34135 .51446 L F
.583 .142 .168 r
.52203 .43513 m .51993 .4336 L .51913 .43565 L F
.805 .756 .808 r
.54289 .38311 m .539 .38287 L .54104 .38131 L F
.386 0 .125 r
.54289 .38311 m .53933 .38489 L .539 .38287 L F
.54289 .38311 m .54213 .38529 L .53933 .38489 L F
.381 .627 .95 r
.54384 .38101 m .54289 .38311 L .54104 .38131 L F
0 0 0 r
.54367 .3835 m .54289 .38311 L .54384 .38101 L F
.54367 .3835 m .54213 .38529 L .54289 .38311 L F
.933 .954 .771 r
.55017 .41644 m .55141 .4117 L .54838 .41863 L F
.261 0 0 r
.55201 .41771 m .55017 .41644 L .54838 .41863 L F
.55213 .41757 m .55017 .41644 L .55201 .41771 L F
.55213 .41757 m .5534 .41652 L .55017 .41644 L F
.55228 .41765 m .55242 .4175 L .55213 .41757 L F
.55242 .4175 m .5534 .41652 L .55213 .41757 L F
.879 .886 .835 r
.55098 .41538 m .55396 .41542 L .55195 .41761 L F
.818 .971 .661 r
.54866 .41734 m .55031 .41384 L .54749 .41661 L F
.75 .981 .739 r
.54749 .41661 m .54819 .41593 L .54813 .41521 L F
.54819 .41593 m .55031 .41384 L .54813 .41521 L F
.7 .808 .348 r
.55031 .41384 m .54912 .4168 L .55125 .41206 L F
.54912 .4168 m .54838 .41863 L .54978 .41544 L F
.54912 .4168 m .54978 .41544 L .55141 .4117 L F
.818 .971 .661 r
.54866 .41734 m .54838 .41863 L .55031 .41384 L F
.312 .004 .271 r
.54749 .41661 m .55031 .41384 L .55098 .41538 L F
.621 .152 .118 r
.54954 .4153 m .55031 .41384 L .54813 .41521 L F
.786 .385 .294 r
.54813 .41521 m .55031 .41384 L .54583 .41253 L F
.772 .347 .24 r
.54583 .41253 m .55031 .41384 L .54795 .41044 L F
0 0 .5 r
.54795 .41044 m .55031 .41384 L .54953 .41203 L F
.962 .936 .707 r
.54953 .41203 m .55031 .41384 L .54813 .41521 L F
.974 .789 .592 r
.54977 .41531 m .54878 .41686 L .54813 .41521 L F
.55098 .41538 m .54878 .41686 L .54977 .41531 L F
.803 .892 .908 r
.54866 .41734 m .54787 .42024 L .54582 .41867 L F
.391 0 0 r
.546 .41563 m .5486 .4173 L .54749 .41661 L F
.5486 .4173 m .54866 .41734 L .54749 .41661 L F
.917 .977 .716 r
.54664 .41609 m .54749 .41661 L .54669 .41593 L F
.813 .523 .499 r
.54227 .41507 m .546 .41563 L .54582 .41867 L F
.391 0 0 r
.546 .41563 m .54749 .41661 L .54582 .41867 L F
.685 .671 .831 r
.54582 .41867 m .54326 .42131 L .5419 .41791 L F
.685 .971 .92 r
.54582 .41867 m .54866 .41734 L .54749 .41661 L F
.813 .523 .499 r
.54227 .41507 m .54582 .41867 L .5419 .41791 L F
.917 .977 .716 r
.54522 .41995 m .54749 .41661 L .54664 .41609 L F
.837 .704 .717 r
.54522 .41995 m .54864 .41981 L .54749 .41661 L F
.709 .849 .423 r
.5475 .41883 m .54878 .41686 L .54732 .41952 L F
0 0 0 r
.54763 .41866 m .54878 .41686 L .5475 .41883 L F
.621 .152 .118 r
.55098 .41538 m .55031 .41384 L .54954 .4153 L F
.768 .413 .381 r
.54714 .4222 m .54864 .41981 L .54522 .41995 L F
.839 .877 .869 r
.54878 .41686 m .54714 .4222 L .54732 .41952 L F
.261 0 0 r
.55196 .41762 m .54838 .41863 L .54866 .41734 L F
.55201 .41771 m .54838 .41863 L .55196 .41762 L F
.411 .079 .289 r
.5506 .41908 m .5488 .41746 L .54864 .41981 L F
.5488 .41746 m .54866 .41734 L .54866 .41775 L F
.5488 .41746 m .54866 .41775 L .54864 .41981 L F
.261 0 0 r
.55228 .41765 m .55213 .41757 L .55201 .41771 L F
.55228 .41765 m .55201 .41771 L .55199 .41768 L F
.174 0 .146 r
.55199 .41768 m .55421 .41542 L .55228 .41765 L F
.261 0 0 r
.55228 .41765 m .55199 .41768 L .55196 .41762 L F
.174 0 .146 r
.5506 .41908 m .55199 .41768 L .55228 .41765 L F
.361 .085 .353 r
.55228 .41765 m .55196 .41762 L .5506 .41908 L F
.55196 .41762 m .54866 .41734 L .5506 .41908 L F
.879 .886 .835 r
.55396 .41542 m .5534 .41608 L .5506 .41908 L F
.5534 .41608 m .55236 .4173 L .5506 .41908 L F
.492 .899 .916 r
.55074 .41841 m .5506 .41908 L .54864 .41981 L F
.879 .886 .835 r
.55097 .41555 m .55195 .41761 L .55073 .41789 L F
.55098 .41538 m .5506 .41908 L .55074 .41841 L F
.492 .899 .916 r
.55074 .41841 m .54864 .41981 L .54714 .4222 L F
.839 .877 .869 r
.54878 .41686 m .55074 .41841 L .54714 .4222 L F
.974 .789 .592 r
.55098 .41538 m .55074 .41841 L .54878 .41686 L F
0 0 0 r
.55038 .41501 m .54878 .41686 L .54763 .41866 L F
.852 .911 .506 r
.54953 .41203 m .54813 .41521 L .54797 .41387 L F
0 0 .29 r
.54804 .41415 m .54813 .41521 L .54878 .41686 L F
.54797 .41387 m .54813 .41521 L .54804 .41415 L F
.7 .808 .348 r
.55031 .41384 m .55125 .41206 L .55141 .4117 L F
.879 .886 .835 r
.55098 .41538 m .55192 .41753 L .55097 .41555 L F
.55192 .41753 m .55195 .41761 L .55097 .41555 L F
.55073 .41789 m .55195 .41761 L .5506 .41908 L F
.55396 .41542 m .55421 .41542 L .55236 .4173 L F
.92 .634 .485 r
.35026 .62514 m .35238 .62301 L .35028 .62236 L F
.909 .772 .697 r
.35028 .62236 m .35238 .62301 L .35146 .61957 L F
.896 .589 .459 r
.35026 .62514 m .35319 .62622 L .35238 .62301 L F
0 0 .512 r
.51264 .45208 m .51406 .45373 L .51271 .45589 L F
0 0 0 r
.51406 .45373 m .5124 .45795 L .51271 .45589 L F
.754 .525 0 r
.56037 .38666 m .56005 .38605 L .56205 .38407 L F
.158 .604 .934 r
.607 .34435 m .61066 .34581 L .60784 .34557 L F
0 0 0 r
.66612 .37863 m .66894 .37564 L .66752 .37693 L F
.585 .903 .642 r
.66894 .37564 m .67229 .37264 L .67077 .3736 L F
.554 .855 .542 r
.67077 .3736 m .66752 .37693 L .66894 .37564 L F
.43 .317 .623 r
.2954 .66867 m .29508 .67115 L .29292 .67214 L F
.719 .937 .958 r
.60792 .35224 m .60916 .35022 L .60725 .35146 L F
.21 0 .244 r
.4078 .56014 m .4074 .56211 L .40969 .56098 L F
.297 .781 .709 r
.45799 .55002 m .45559 .5508 L .45342 .55165 L F
.805 .999 .795 r
.46104 .54676 m .4587 .54778 L .45799 .55002 L F
.8 1 .821 r
.4587 .54778 m .45559 .5508 L .45799 .55002 L F
.837 .766 .784 r
.42361 .59192 m .42945 .58878 L .42655 .58906 L F
.42361 .59192 m .42595 .59317 L .42945 .58878 L F
.455 .877 .929 r
.43036 .5885 m .42655 .58906 L .42945 .58878 L F
.754 .316 .212 r
.66416 .33746 m .66782 .33671 L .66378 .33619 L F
.66416 .33746 m .66829 .33852 L .66782 .33671 L F
.956 .86 .704 r
.27812 .54912 m .28199 .5453 L .28035 .54443 L F
.27812 .54912 m .27887 .55135 L .28199 .5453 L F
.103 0 0 r
.32971 .67953 m .32989 .68089 L .32778 .68154 L F
.32971 .67953 m .33331 .67842 L .32989 .68089 L F
.308 0 .055 r
.43266 .57151 m .42891 .57397 L .43102 .57483 L F
.158 .05 .471 r
.433 .57373 m .43371 .57333 L .43153 .57381 L F
.43153 .57381 m .43371 .57333 L .43266 .57151 L F
.385 .453 .808 r
.43102 .57483 m .43375 .57344 L .43371 .57333 L F
.776 .69 .768 r
.4336 .57307 m .43359 .57369 L .43155 .57345 L F
.798 .857 .894 r
.43372 .5733 m .43445 .57232 L .43266 .57151 L F
.158 .05 .471 r
.43371 .57333 m .43372 .5733 L .43266 .57151 L F
.776 .69 .768 r
.43506 .57231 m .43522 .57269 L .43238 .57235 L F
.798 .857 .894 r
.43378 .57335 m .43501 .57409 L .43498 .5728 L F
.43501 .57409 m .43716 .57539 L .43576 .57373 L F
.43501 .57409 m .43576 .57373 L .43498 .5728 L F
.129 0 0 r
.43578 .57396 m .43832 .57339 L .43988 .57177 L F
.43825 .57255 m .43988 .57177 L .44021 .57142 L F
.43578 .57396 m .43988 .57177 L .43825 .57255 L F
.776 .69 .768 r
.43522 .57269 m .43578 .57396 L .43414 .57318 L F
.43522 .57269 m .43414 .57318 L .43238 .57235 L F
.798 .857 .894 r
.43373 .57332 m .43378 .57335 L .43465 .57241 L F
.43378 .57335 m .43498 .5728 L .43465 .57241 L F
.43373 .57332 m .43465 .57241 L .43445 .57232 L F
.43373 .57332 m .43445 .57232 L .43372 .5733 L F
.776 .69 .768 r
.43381 .57303 m .43372 .5733 L .4336 .57307 L F
.43372 .5733 m .43371 .57333 L .4337 .57332 L F
.43372 .5733 m .4337 .57332 L .4336 .57307 L F
.43371 .57333 m .43359 .57369 L .4336 .57307 L F
.43381 .57303 m .43388 .57306 L .43359 .57369 L F
.635 .36 .485 r
.43452 .57784 m .43716 .57539 L .43467 .57388 L F
.43385 .57373 m .43467 .57388 L .43378 .57335 L F
.43452 .57784 m .43467 .57388 L .43385 .57373 L F
.4338 .57373 m .43378 .57335 L .43375 .57344 L F
.43452 .57784 m .43385 .57373 L .4338 .57373 L F
.43385 .57373 m .43378 .57335 L .4338 .57373 L F
.08 .628 .835 r
.43359 .57369 m .4336 .57369 L .43155 .57345 L F
.385 .453 .808 r
.43319 .57373 m .4338 .57373 L .43375 .57344 L F
.08 .628 .835 r
.4336 .57369 m .43409 .57355 L .43246 .57348 L F
.776 .69 .768 r
.43238 .57235 m .43381 .57303 L .43155 .57345 L F
.419 0 0 r
.43266 .57151 m .43445 .57232 L .43763 .57069 L F
.43445 .57232 m .43483 .57231 L .43763 .57069 L F
.312 0 0 r
.43763 .57069 m .43483 .57231 L .43509 .57227 L F
.43805 .57081 m .43509 .57227 L .44021 .57142 L F
.43763 .57069 m .43509 .57227 L .43805 .57081 L F
.776 .69 .768 r
.43388 .57306 m .43578 .57396 L .43367 .5737 L F
.343 .803 .936 r
.43409 .57355 m .43578 .57396 L .43431 .57326 L F
.43493 .57245 m .43578 .57396 L .43505 .57229 L F
.129 0 0 r
.43578 .57396 m .44021 .57142 L .43488 .57237 L F
.43578 .57396 m .43488 .57237 L .43465 .57241 L F
.343 .803 .936 r
.43431 .57326 m .43578 .57396 L .43493 .57245 L F
.776 .69 .768 r
.43409 .57009 m .43505 .57229 L .43238 .57235 L F
.43505 .57229 m .43506 .57231 L .43483 .57231 L F
.43505 .57229 m .43483 .57231 L .43238 .57235 L F
.419 0 0 r
.43445 .57232 m .43465 .57241 L .43483 .57231 L F
.343 .803 .936 r
.43409 .57276 m .43505 .57229 L .43409 .57009 L F
.43409 .57355 m .43505 .57229 L .43409 .57276 L F
.312 0 0 r
.43483 .57231 m .43465 .57241 L .43574 .57222 L F
.43483 .57231 m .43574 .57222 L .44021 .57142 L F
0 0 0 r
.43409 .57009 m .43266 .57151 L .43351 .56911 L F
.776 .69 .768 r
.43409 .57009 m .43155 .57345 L .43266 .57151 L F
.785 .544 .573 r
.43191 .57319 m .43409 .57009 L .43465 .56787 L F
.385 .453 .808 r
.43102 .57483 m .43452 .57784 L .4338 .57373 L F
.43102 .57483 m .4338 .57373 L .43319 .57373 L F
.158 .05 .471 r
.43102 .57483 m .433 .57373 L .43153 .57381 L F
.385 .453 .808 r
.43102 .57483 m .4332 .57906 L .43452 .57784 L F
.027 0 0 r
.432 .57402 m .43055 .57581 L .43155 .57345 L F
.069 0 0 r
.43154 .57461 m .43258 .57476 L .43409 .57355 L F
.027 0 0 r
.43258 .57476 m .43062 .57577 L .43154 .57461 L F
.069 0 0 r
.43108 .57479 m .43258 .57476 L .43154 .57461 L F
.027 0 0 r
.43258 .57476 m .43154 .57461 L .432 .57402 L F
.43062 .57577 m .43055 .57581 L .432 .57402 L F
.08 .628 .835 r
.43228 .57353 m .43222 .57347 L .43155 .57345 L F
.776 .69 .768 r
.43388 .57306 m .43367 .5737 L .43359 .57369 L F
.08 .628 .835 r
.43367 .5737 m .43361 .57369 L .43359 .57369 L F
.43387 .57373 m .43361 .57369 L .43367 .5737 L F
.027 0 0 r
.43258 .57476 m .432 .57402 L .43409 .57355 L F
.08 .628 .835 r
.4336 .57369 m .43246 .57348 L .43222 .57347 L F
.4336 .57369 m .43222 .57347 L .43228 .57353 L F
.027 0 0 r
.432 .57402 m .43155 .57345 L .43409 .57355 L F
.785 .544 .573 r
.43108 .57479 m .43154 .57461 L .43185 .57406 L F
.43151 .57413 m .43185 .57406 L .43409 .57009 L F
.43108 .57479 m .43185 .57406 L .43151 .57413 L F
.635 .36 .485 r
.43375 .57344 m .43378 .57335 L .43373 .57332 L F
.385 .453 .808 r
.43371 .57333 m .43375 .57344 L .43373 .57332 L F
.158 .05 .471 r
.43371 .57333 m .43373 .57332 L .43372 .5733 L F
.785 .544 .573 r
.43154 .57461 m .43409 .57355 L .43409 .57138 L F
.43154 .57461 m .43409 .57138 L .43409 .57009 L F
.43108 .57479 m .43204 .57331 L .43191 .57319 L F
.43204 .57331 m .43409 .57009 L .43191 .57319 L F
.08 .628 .835 r
.43387 .57373 m .43447 .57364 L .43361 .57369 L F
.43578 .57396 m .43482 .57373 L .43387 .57373 L F
.43482 .57373 m .43447 .57364 L .43387 .57373 L F
.43447 .57364 m .43409 .57355 L .43359 .57369 L F
.333 0 .046 r
.43763 .57069 m .44021 .57142 L .44071 .57001 L F
.907 .564 .384 r
.41669 .56356 m .41789 .56773 L .41988 .56597 L F
.29 0 0 r
.41789 .56773 m .42238 .56637 L .41988 .56597 L F
.381 .363 .715 r
.29686 .61011 m .3004 .61231 L .29965 .60798 L F
.29686 .61011 m .29806 .61242 L .3004 .61231 L F
.941 .744 .608 r
.36898 .54949 m .3665 .54875 L .36716 .54588 L F
.872 .705 .671 r
.36919 .55214 m .3665 .54875 L .36898 .54949 L F
.968 .722 .29 r
.5635 .36969 m .56286 .37199 L .56363 .36849 L F
.5635 .36969 m .56378 .37366 L .56286 .37199 L F
.27 0 .294 r
.27046 .55955 m .27115 .56139 L .26765 .56189 L F
.318 .107 .428 r
.27115 .56139 m .2679 .56276 L .26765 .56189 L F
.989 .861 .503 r
.3134 .5909 m .31189 .59192 L .3134 .5898 L F
.936 .827 .712 r
.3134 .5909 m .30876 .59519 L .31189 .59192 L F
.3134 .5909 m .31084 .59585 L .30876 .59519 L F
.892 .754 .703 r
.54772 .45876 m .54915 .46274 L .54986 .46006 L F
.54772 .45876 m .54584 .46247 L .54915 .46274 L F
.883 .795 .758 r
.54915 .46274 m .54584 .46247 L .54673 .46601 L F
.174 .079 .498 r
.57768 .36962 m .58052 .37037 L .57992 .36744 L F
.57768 .36962 m .57794 .37252 L .58052 .37037 L F
.571 .513 .751 r
.40537 .56303 m .40877 .56601 L .4074 .56211 L F
.787 .736 .806 r
.28112 .65495 m .28078 .66011 L .27923 .65674 L F
.28112 .65495 m .28371 .65688 L .28078 .66011 L F
.869 .595 .522 r
.35316 .51976 m .34942 .52138 L .34945 .51871 L F
.35316 .51976 m .35289 .5224 L .34942 .52138 L F
.559 .895 .983 r
.45752 .53293 m .45867 .53124 L .45953 .53208 L F
.646 .946 .715 r
.45752 .53293 m .45544 .534 L .45867 .53124 L F
.861 .775 .765 r
.3152 .51997 m .31154 .51929 L .31381 .51555 L F
.796 .441 .386 r
.3152 .51997 m .313 .52005 L .31154 .51929 L F
.3152 .51997 m .3151 .52211 L .313 .52005 L F
.856 .5 .377 r
.31725 .52257 m .3151 .52211 L .3152 .51997 L F
.078 .246 .735 r
.31415 .64257 m .31572 .64675 L .31647 .64451 L F
.428 0 0 r
.31572 .64675 m .31785 .64781 L .31633 .64768 L F
.932 .734 .612 r
.31572 .64675 m .31907 .64629 L .31785 .64781 L F
.428 0 0 r
.31572 .64675 m .31633 .64768 L .31647 .64451 L F
.891 .606 .498 r
.34131 .64255 m .34151 .63982 L .33729 .63819 L F
.818 .362 .148 r
.33729 .63819 m .34151 .63982 L .3386 .6395 L F
.612 .925 .971 r
.33845 .63922 m .34151 .63982 L .34227 .63782 L F
.818 .362 .148 r
.33729 .63819 m .3386 .6395 L .33833 .63947 L F
.719 .417 .466 r
.33543 .641 m .33948 .64088 L .33729 .63819 L F
.818 .362 .148 r
.33729 .63819 m .33833 .63947 L .33792 .63942 L F
.612 .925 .971 r
.33792 .63942 m .33833 .63947 L .33845 .63922 L F
.891 .606 .498 r
.34131 .64255 m .33729 .63819 L .34027 .64116 L F
.612 .925 .971 r
.33833 .63947 m .3386 .6395 L .33856 .63942 L F
.891 .606 .498 r
.3386 .6395 m .33729 .63819 L .33856 .63942 L F
.719 .417 .466 r
.33833 .63947 m .33856 .63942 L .33729 .63819 L F
.612 .925 .971 r
.33833 .63947 m .33856 .63942 L .33845 .63922 L F
.891 .606 .498 r
.34027 .64116 m .34009 .64099 L .34005 .64087 L F
.34009 .64099 m .3386 .6395 L .34005 .64087 L F
.3386 .6395 m .33856 .63942 L .34005 .64087 L F
.719 .417 .466 r
.33948 .64088 m .34005 .64087 L .33856 .63942 L F
.33948 .64088 m .33856 .63942 L .33833 .63947 L F
.043 0 0 r
.33633 .64449 m .34005 .64087 L .33543 .641 L F
.33633 .64449 m .33802 .64381 L .34005 .64087 L F
.869 .916 .516 r
.34005 .64087 m .33802 .64381 L .33968 .63994 L F
.612 .925 .971 r
.3386 .6395 m .34151 .63982 L .33845 .63922 L F
.869 .916 .516 r
.34005 .64087 m .33968 .63994 L .33998 .63924 L F
0 0 .076 r
.34227 .63782 m .34151 .63982 L .34135 .64209 L F
.34227 .63782 m .34135 .64209 L .34147 .64178 L F
.34227 .63782 m .34131 .64255 L .34238 .64061 L F
.869 .916 .516 r
.34005 .64087 m .33998 .63924 L .34201 .6404 L F
.34191 .64066 m .34201 .6404 L .34238 .64061 L F
.34005 .64087 m .34201 .6404 L .34191 .64066 L F
0 0 .076 r
.34147 .64178 m .34135 .64209 L .34131 .64255 L F
.736 .428 .46 r
.32058 .51512 m .32494 .51296 L .32086 .51243 L F
.32058 .51512 m .32498 .51546 L .32494 .51296 L F
.841 .773 .786 r
.37247 .57006 m .37161 .57256 L .36785 .57208 L F
.928 .863 .756 r
.37161 .57256 m .36759 .57492 L .36785 .57208 L F
.826 .708 .735 r
.28393 .6762 m .28747 .67633 L .28601 .67244 L F
.723 .295 .233 r
.28565 .67888 m .28747 .67633 L .28393 .6762 L F
.602 .593 .815 r
.28601 .67244 m .28747 .67633 L .28923 .67544 L F
.018 0 0 r
.28923 .67544 m .28747 .67633 L .28565 .67888 L F
.783 .45 .425 r
.67215 .34482 m .67597 .3434 L .6719 .34232 L F
.67215 .34482 m .67618 .34556 L .67597 .3434 L F
.121 .201 .674 r
.23923 .59633 m .24127 .59832 L .24061 .5959 L F
.887 .703 .648 r
.38856 .58884 m .3869 .58899 L .39005 .58967 L F
.885 .713 .663 r
.38955 .58827 m .38739 .58815 L .3887 .58592 L F
.39005 .58967 m .38859 .58884 L .38955 .58827 L F
.38859 .58884 m .38739 .58815 L .38955 .58827 L F
.49 .429 .716 r
.39177 .5853 m .39005 .58967 L .3887 .58592 L F
.39177 .5853 m .39284 .589 L .39005 .58967 L F
.554 .138 .206 r
.39284 .589 m .38859 .58884 L .39005 .58967 L F
.38859 .58884 m .38856 .58884 L .39005 .58967 L F
.38859 .58884 m .38857 .58885 L .38856 .58884 L F
.336 0 0 r
.38856 .58884 m .38376 .5885 L .3869 .58899 L F
.885 .713 .663 r
.39005 .58967 m .3869 .58899 L .387 .58881 L F
.38859 .58884 m .387 .58881 L .38739 .58815 L F
.39005 .58967 m .387 .58881 L .38855 .58884 L F
.66 .105 0 r
.3886 .58889 m .39086 .59135 L .38697 .58954 L F
.38857 .58885 m .39086 .59135 L .38855 .58884 L F
.38856 .58884 m .38857 .58885 L .38855 .58884 L F
.885 .713 .663 r
.38866 .58888 m .38855 .58884 L .38859 .58884 L F
.39005 .58967 m .38855 .58884 L .38866 .58888 L F
.554 .138 .206 r
.39284 .589 m .39086 .59135 L .38857 .58885 L F
0 .34 .706 r
.39086 .59135 m .391 .59115 L .38697 .58954 L F
.384 0 0 r
.38697 .58954 m .391 .59115 L .3859 .58996 L F
.38697 .58954 m .3859 .58996 L .385 .58975 L F
.66 .105 0 r
.38855 .58884 m .3886 .58889 L .38697 .58954 L F
.336 0 0 r
.38856 .58884 m .38855 .58884 L .38571 .58864 L F
.38856 .58884 m .38571 .58864 L .38568 .58863 L F
.38855 .58884 m .38713 .58882 L .38376 .5885 L F
.768 .484 .504 r
.38677 .58878 m .3869 .58899 L .38376 .5885 L F
.336 0 0 r
.38713 .58882 m .38461 .58877 L .38376 .5885 L F
.38568 .58863 m .38571 .58864 L .38376 .5885 L F
.768 .484 .504 r
.38511 .58615 m .38677 .58878 L .38376 .5885 L F
.709 .472 .564 r
.3887 .58592 m .387 .58881 L .38511 .58615 L F
.387 .58881 m .3869 .58899 L .38677 .58878 L F
.387 .58881 m .38677 .58878 L .38511 .58615 L F
.336 0 0 r
.38855 .58884 m .38697 .58954 L .38461 .58877 L F
.554 .138 .206 r
.39284 .589 m .38857 .58885 L .38859 .58884 L F
0 0 .264 r
.59768 .37161 m .59633 .37311 L .59792 .36961 L F
.025 0 .314 r
.59786 .37273 m .59633 .37311 L .59768 .37161 L F
.59786 .37273 m .59616 .37551 L .59633 .37311 L F
.836 .701 .714 r
.36036 .50211 m .35875 .50598 L .36194 .50627 L F
.805 .558 .565 r
.35875 .50598 m .3617 .50868 L .36194 .50627 L F
.774 .492 .507 r
.36194 .50627 m .3617 .50868 L .36594 .50913 L F
.902 .53 .318 r
.34083 .51002 m .33899 .51134 L .33846 .50902 L F
.802 .363 .2 r
.34083 .51002 m .34142 .51193 L .33899 .51134 L F
.865 .663 .628 r
.39406 .5843 m .39177 .5853 L .39242 .5821 L F
.858 .643 .61 r
.39406 .5843 m .39284 .589 L .39177 .5853 L F
0 0 0 r
.3814 .52473 m .38044 .52611 L .38237 .5228 L F
.3814 .52473 m .38237 .5228 L .37835 .52288 L F
.498 .881 .969 r
.38178 .52184 m .38237 .5228 L .38473 .52261 L F
.543 .535 .796 r
.3788 .51784 m .38178 .52184 L .38332 .51831 L F
.89 .823 .35 r
.38165 .51988 m .38142 .52091 L .38178 .52184 L F
.498 .881 .969 r
.38178 .52184 m .38066 .52225 L .38212 .52272 L F
.38178 .52184 m .38212 .52272 L .38237 .5228 L F
.825 .68 .703 r
.38473 .52261 m .38186 .52236 L .38178 .52184 L F
.38186 .52236 m .38066 .52225 L .38178 .52184 L F
.89 .823 .35 r
.38165 .51988 m .38154 .52035 L .38178 .52184 L F
.825 .68 .703 r
.38473 .52261 m .3814 .52473 L .38066 .52225 L F
.329 0 0 r
.3787 .52255 m .38178 .52184 L .38066 .52225 L F
0 0 0 r
.37835 .52288 m .3787 .52255 L .38066 .52225 L F
.3814 .52473 m .37835 .52288 L .38066 .52225 L F
.329 0 0 r
.3787 .52255 m .38101 .52274 L .38178 .52184 L F
.89 .823 .35 r
.38154 .52035 m .38101 .52274 L .38178 .52184 L F
.38142 .52091 m .38101 .52274 L .38178 .52184 L F
.644 .966 .834 r
.47353 .4308 m .4769 .43009 L .47895 .42837 L F
0 .115 .64 r
.25549 .56324 m .25728 .56516 L .25633 .56125 L F
.124 .145 .61 r
.25619 .56603 m .25728 .56516 L .25549 .56324 L F
0 0 .357 r
.58498 .40312 m .58638 .40349 L .58562 .40074 L F
0 .138 .673 r
.35472 .64514 m .35403 .64654 L .35231 .64222 L F
.558 .902 .976 r
.35718 .64562 m .35602 .64596 L .3564 .64547 L F
.369 .365 .724 r
.35685 .64884 m .35403 .64654 L .35718 .64562 L F
.86 .931 .871 r
.35718 .64562 m .35472 .64514 L .35699 .64295 L F
.85 .722 .197 r
.35699 .64295 m .35694 .64499 L .35718 .64562 L F
.35694 .64499 m .35685 .64884 L .35714 .64601 L F
.35694 .64499 m .35714 .64601 L .35718 .64562 L F
.582 .879 .993 r
.35593 .64315 m .35666 .64351 L .35472 .64514 L F
0 0 .404 r
.35759 .64395 m .35695 .64477 L .35699 .64295 L F
.366 .093 .36 r
.35472 .64514 m .3576 .64398 L .35699 .64295 L F
.582 .879 .993 r
.35666 .64351 m .3576 .64398 L .35681 .6443 L F
.35666 .64351 m .35681 .6443 L .35472 .64514 L F
0 0 .404 r
.3576 .64398 m .35685 .64884 L .35695 .64477 L F
.3576 .64398 m .35695 .64477 L .35759 .64395 L F
.558 .902 .976 r
.3564 .64547 m .35403 .64654 L .35472 .64514 L F
.35602 .64596 m .35403 .64654 L .3564 .64547 L F
.509 .632 .907 r
.31359 .6856 m .31732 .68777 L .31655 .68795 L F
.266 0 .127 r
.31732 .68777 m .31438 .6901 L .31577 .68839 L F
.31438 .6901 m .31732 .68777 L .31797 .6894 L F
.31708 .68985 m .31797 .6894 L .31811 .68976 L F
.31438 .6901 m .31797 .6894 L .31708 .68985 L F
.229 .042 .406 r
.31811 .68976 m .31732 .68777 L .31985 .68871 L F
.553 .704 .94 r
.31577 .68839 m .31699 .68997 L .31985 .68871 L F
.31699 .68997 m .31779 .69101 L .31809 .68978 L F
.758 .782 .872 r
.31488 .69271 m .31779 .69101 L .31699 .68997 L F
.766 .909 .938 r
.31809 .68978 m .31779 .69101 L .31488 .69271 L F
.31811 .68976 m .31779 .69101 L .31809 .68978 L F
.547 .695 .936 r
.31985 .68871 m .31779 .69101 L .31811 .68976 L F
.553 .704 .94 r
.31809 .68978 m .31779 .69101 L .31904 .68962 L F
.31699 .68997 m .31904 .68962 L .31985 .68871 L F
.766 .909 .938 r
.31708 .68985 m .31699 .68997 L .31438 .6901 L F
.31699 .68997 m .31488 .69271 L .31444 .6904 L F
.31699 .68997 m .31444 .6904 L .31438 .6901 L F
.31811 .68976 m .31488 .69271 L .31708 .68985 L F
.758 .782 .872 r
.31488 .69271 m .31699 .68997 L .31695 .68992 L F
.31528 .69075 m .31695 .68992 L .31577 .68839 L F
.31488 .69271 m .31695 .68992 L .31528 .69075 L F
.321 0 0 r
.31985 .68871 m .31732 .68777 L .31577 .68839 L F
.31752 .68852 m .31577 .68839 L .31639 .68786 L F
.509 .632 .907 r
.31647 .68791 m .31655 .68795 L .31653 .68796 L F
.31359 .6856 m .31655 .68795 L .31647 .68791 L F
0 0 0 r
.31732 .68777 m .32012 .68487 L .31951 .68669 L F
.334 .802 .706 r
.3172 .68767 m .31732 .68777 L .31951 .68669 L F
.31655 .68795 m .31732 .68777 L .3172 .68767 L F
.3172 .68767 m .31951 .68669 L .31919 .68552 L F
.321 0 0 r
.31752 .68852 m .31679 .6881 L .31919 .68552 L F
.31679 .6881 m .31639 .68786 L .31919 .68552 L F
.334 .802 .706 r
.31696 .68777 m .31655 .68795 L .3172 .68767 L F
.525 .44 .702 r
.31658 .68793 m .31696 .68777 L .31919 .68552 L F
.334 .802 .706 r
.31647 .68797 m .31653 .68796 L .31696 .68777 L F
.31653 .68796 m .31655 .68795 L .31696 .68777 L F
.525 .44 .702 r
.31639 .68786 m .31658 .68793 L .31919 .68552 L F
.31658 .68793 m .31673 .68799 L .31696 .68777 L F
.334 .802 .706 r
.31696 .68777 m .3172 .68767 L .31919 .68552 L F
.321 0 0 r
.31985 .68871 m .31752 .68852 L .31826 .6872 L F
.31943 .68668 m .31826 .6872 L .31919 .68552 L F
.31985 .68871 m .31826 .6872 L .31943 .68668 L F
.525 .44 .702 r
.31673 .68799 m .3182 .68855 L .31919 .68552 L F
.334 .802 .706 r
.31647 .68797 m .31696 .68777 L .31919 .68552 L F
.525 .44 .702 r
.31577 .68839 m .31732 .68849 L .31639 .68786 L F
.31732 .68849 m .3182 .68855 L .31639 .68786 L F
.509 .632 .907 r
.31603 .68762 m .31653 .68796 L .31647 .68797 L F
.31359 .6856 m .31653 .68796 L .31603 .68762 L F
.914 .586 .409 r
.31518 .58019 m .31201 .57866 L .31277 .57768 L F
.31518 .58019 m .31286 .58128 L .31201 .57866 L F
.679 .602 .763 r
.3149 .57709 m .31518 .58019 L .31277 .57768 L F
.57 .052 0 r
.31518 .58019 m .31712 .58174 L .31286 .58128 L F
.549 .503 .757 r
.31767 .57913 m .31518 .58019 L .3149 .57709 L F
.383 .14 .417 r
.31767 .57913 m .31712 .58174 L .31518 .58019 L F
0 0 0 r
.33401 .67836 m .33331 .67842 L .33554 .67664 L F
.33206 .67983 m .33262 .67925 L .3338 .67905 L F
.3324 .67935 m .33331 .67842 L .33401 .67836 L F
.32989 .68089 m .33401 .67836 L .33206 .67983 L F
.839 .994 .848 r
.33206 .67983 m .33401 .67836 L .33498 .67683 L F
0 0 0 r
.33262 .67925 m .33498 .67683 L .33404 .67861 L F
.33262 .67925 m .33404 .67861 L .3338 .67905 L F
.32989 .68089 m .33139 .6798 L .3324 .67935 L F
.33139 .6798 m .33331 .67842 L .3324 .67935 L F
.218 0 .302 r
.64114 .3754 m .63848 .37914 L .63891 .37673 L F
.64114 .3754 m .63848 .37914 L .63891 .37673 L F
.292 .789 .847 r
.52558 .41676 m .52907 .41615 L .52869 .41601 L F
.799 .709 .766 r
.52907 .41615 m .52845 .41203 L .52869 .41601 L F
.547 .443 .687 r
.27713 .54871 m .27745 .55297 L .27446 .55343 L F
.605 .475 .677 r
.27745 .55297 m .27487 .55609 L .27446 .55343 L F
.808 .651 .687 r
.39324 .5261 m .39307 .52978 L .39502 .52934 L F
.698 .351 .386 r
.39307 .52978 m .39289 .53181 L .39502 .52934 L F
.785 .471 .457 r
.39289 .53181 m .39833 .53223 L .39502 .52934 L F
.566 .178 .266 r
.36817 .51223 m .37197 .51216 L .37256 .51031 L F
.492 .145 .306 r
.37197 .51216 m .37499 .51014 L .37256 .51031 L F
.877 .606 .523 r
.66829 .33852 m .6719 .34232 L .6718 .33966 L F
.393 .282 .607 r
.5352 .40818 m .53774 .41168 L .53645 .40796 L F
.794 .69 .75 r
.33101 .57883 m .33481 .57955 L .33557 .57665 L F
.798 .679 .733 r
.33101 .57883 m .33259 .58268 L .33481 .57955 L F
.883 .695 .644 r
.54772 .45876 m .54986 .46006 L .54805 .45594 L F
.225 .303 .735 r
.62268 .38777 m .62536 .38754 L .62387 .3864 L F
.968 .875 .691 r
.62215 .38508 m .62276 .38708 L .62268 .38777 L F
.225 .303 .735 r
.62268 .38777 m .62387 .3864 L .62215 .38508 L F
0 0 0 r
.6221 .38843 m .62268 .38777 L .62276 .38708 L F
.62114 .3904 m .62268 .38777 L .6221 .38843 L F
.62114 .3904 m .62263 .39081 L .62268 .38777 L F
.191 .075 .483 r
.2679 .56276 m .26659 .56904 L .26684 .5663 L F
.574 .537 .776 r
.51887 .39037 m .51699 .39548 L .5169 .393 L F
.674 .97 .917 r
.63557 .38207 m .63351 .38369 L .63136 .38352 L F
.759 .4 .374 r
.34907 .51652 m .34509 .51802 L .34518 .51548 L F
.34907 .51652 m .34945 .51871 L .34509 .51802 L F
.545 .928 .833 r
.44083 .44228 m .44223 .44085 L .44433 .44049 L F
.44083 .44228 m .44003 .44224 L .44223 .44085 L F
.049 0 .058 r
.48396 .49572 m .48606 .49541 L .48616 .49496 L F
.48396 .49572 m .48326 .49816 L .48606 .49541 L F
.87 .732 .707 r
.31249 .64097 m .31747 .64053 L .31645 .63703 L F
.74 .537 .618 r
.31415 .64257 m .31747 .64053 L .31249 .64097 L F
.31415 .64257 m .31777 .6434 L .31747 .64053 L F
.54 .541 .804 r
.31645 .63703 m .31747 .64053 L .32003 .63869 L F
.627 .549 .747 r
.31777 .6434 m .32003 .63869 L .31747 .64053 L F
.85 .842 .837 r
.31415 .64257 m .31747 .64053 L .31249 .64097 L F
.83 .994 .854 r
.56745 .39122 m .56698 .39324 L .5687 .39112 L F
.95 .8 .659 r
.5644 .39409 m .56698 .39324 L .56745 .39122 L F
.5644 .39409 m .56632 .39607 L .56698 .39324 L F
.301 0 0 r
.32012 .68487 m .32217 .68562 L .31951 .68669 L F
.792 .382 .272 r
.31214 .55015 m .30969 .55166 L .30745 .5488 L F
.239 0 0 r
.31348 .55062 m .31214 .55015 L .31413 .5489 L F
.31348 .55062 m .30969 .55166 L .31214 .55015 L F
0 .101 .648 r
.33799 .54896 m .33915 .55115 L .33878 .5513 L F
.866 .713 .69 r
.3359 .55531 m .33804 .55649 L .33878 .5513 L F
.3359 .55531 m .33878 .5513 L .33915 .55115 L F
.309 .102 .428 r
.27912 .52633 m .28117 .52549 L .28146 .52285 L F
.312 .12 .452 r
.27912 .52633 m .28089 .52822 L .28117 .52549 L F
.27912 .52633 m .27885 .5291 L .28089 .52822 L F
.484 .899 .825 r
.44674 .43921 m .44433 .44049 L .44223 .44085 L F
.855 .993 .741 r
.58978 .37364 m .59059 .37076 L .59189 .37221 L F
.58978 .37364 m .58802 .37384 L .59059 .37076 L F
.887 .898 .831 r
.30483 .54959 m .30563 .54562 L .30745 .5488 L F
0 .219 .733 r
.30791 .55195 m .30845 .5542 L .30708 .55173 L F
.30853 .55262 m .30879 .55567 L .30791 .55195 L F
.204 0 0 r
.30969 .55166 m .30961 .55173 L .30812 .55173 L F
.30969 .55166 m .30812 .55173 L .30809 .55171 L F
.30961 .55173 m .30791 .55195 L .30708 .55173 L F
.712 .369 .395 r
.30825 .55191 m .3086 .55262 L .30839 .55247 L F
.204 0 0 r
.30969 .55166 m .30961 .55173 L .30708 .55173 L F
.30961 .55173 m .30861 .55186 L .30708 .55173 L F
.30936 .55192 m .30843 .55203 L .30831 .552 L F
.712 .369 .395 r
.30745 .5488 m .30825 .55191 L .3056 .54941 L F
.30825 .55191 m .30839 .55247 L .30791 .55195 L F
.204 0 0 r
.30861 .55186 m .30802 .55194 L .30708 .55173 L F
.30809 .55171 m .30812 .55173 L .30708 .55173 L F
.712 .369 .395 r
.30825 .55191 m .30791 .55195 L .3056 .54941 L F
0 0 .39 r
.30858 .55202 m .3086 .55262 L .30838 .55189 L F
.204 0 0 r
.3089 .55188 m .30831 .552 L .30802 .55194 L F
.3089 .55188 m .30802 .55194 L .30861 .55186 L F
.30936 .55192 m .30831 .552 L .3089 .55188 L F
.712 .369 .395 r
.30791 .55195 m .3077 .55198 L .30455 .54975 L F
.3056 .54941 m .30791 .55195 L .30455 .54975 L F
.887 .898 .831 r
.30483 .54959 m .30299 .54864 L .30571 .54508 L F
.30483 .54959 m .30522 .5476 L .30526 .54746 L F
.712 .369 .395 r
.30745 .5488 m .30299 .54864 L .30483 .54959 L F
.30488 .54871 m .30455 .54975 L .30299 .54864 L F
.30745 .5488 m .30455 .54975 L .30488 .54871 L F
.682 .902 .554 r
.30571 .54508 m .30299 .54864 L .30397 .54684 L F
.2 .428 .857 r
.30299 .54864 m .3077 .55198 L .30397 .54684 L F
0 .219 .733 r
.30845 .5542 m .30847 .55493 L .30708 .55173 L F
.955 .749 .586 r
.30879 .55567 m .30675 .55485 L .30708 .55173 L F
.989 .789 .546 r
.30708 .55173 m .30675 .55485 L .30548 .55292 L F
.2 0 0 r
.30708 .55173 m .30587 .5528 L .30791 .55195 L F
.804 .723 .774 r
.30548 .55292 m .30694 .55246 L .30849 .55254 L F
.2 0 0 r
.30587 .5528 m .30613 .55271 L .30791 .55195 L F
.804 .723 .774 r
.30537 .55238 m .30787 .55209 L .30794 .55215 L F
.30694 .55246 m .30794 .55215 L .30849 .55254 L F
.30537 .55238 m .30794 .55215 L .30694 .55246 L F
.30853 .55262 m .30849 .55254 L .3086 .55262 L F
.30548 .55292 m .30849 .55254 L .30853 .55262 L F
.2 .428 .857 r
.30839 .55247 m .3086 .55262 L .30839 .55236 L F
.869 .642 .591 r
.30839 .55236 m .3086 .55262 L .30849 .55254 L F
.712 .369 .395 r
.30791 .55195 m .30784 .55198 L .30782 .55196 L F
.30784 .55198 m .30775 .55202 L .30782 .55196 L F
.30782 .55196 m .30775 .55202 L .3077 .55198 L F
.2 .428 .857 r
.3077 .55198 m .30772 .55198 L .30768 .55195 L F
.30772 .55198 m .30804 .55203 L .30768 .55195 L F
.30768 .55195 m .30804 .55203 L .30397 .54684 L F
.712 .369 .395 r
.30791 .55195 m .30839 .55247 L .30775 .55202 L F
.30838 .55189 m .3086 .55262 L .30825 .55191 L F
0 .219 .733 r
.30897 .55222 m .30893 .55306 L .30791 .55195 L F
.2 0 0 r
.30791 .55195 m .30775 .55202 L .30838 .55207 L F
.2 .428 .857 r
.3077 .55198 m .30775 .55202 L .30804 .55203 L F
.30775 .55202 m .30839 .55247 L .30806 .55204 L F
.30775 .55202 m .30806 .55204 L .30804 .55203 L F
.869 .642 .591 r
.30839 .55236 m .30849 .55254 L .30794 .55215 L F
.30654 .55108 m .30651 .55111 L .30486 .54992 L F
.204 0 0 r
.3085 .55204 m .30838 .55207 L .30708 .55173 L F
.30905 .55216 m .30838 .55207 L .3085 .55204 L F
.30838 .55207 m .30838 .55207 L .3085 .55204 L F
.712 .369 .395 r
.30745 .5488 m .30838 .55189 L .30825 .55191 L F
0 0 .39 r
.30854 .54998 m .30858 .55202 L .30807 .55055 L F
.30854 .54998 m .30807 .55055 L .30745 .5488 L F
.341 .783 .962 r
.31045 .54955 m .30898 .54943 L .30854 .54998 L F
0 0 .39 r
.30858 .55202 m .30838 .55189 L .30745 .5488 L F
.30854 .54998 m .30745 .5488 L .30895 .55071 L F
.30854 .54998 m .30895 .55071 L .30969 .55166 L F
.341 .783 .962 r
.30898 .54943 m .30819 .54936 L .30854 .54998 L F
.30819 .54936 m .30612 .54919 L .30854 .54998 L F
.944 .851 .721 r
.30612 .54919 m .30823 .55211 L .30854 .54998 L F
.869 .642 .591 r
.30839 .55236 m .30794 .55215 L .30803 .55211 L F
.204 0 0 r
.30961 .55173 m .30905 .55216 L .30791 .55195 L F
.30905 .55216 m .30897 .55222 L .30838 .55207 L F
.944 .851 .721 r
.30838 .55207 m .3086 .55262 L .30858 .55202 L F
.204 0 0 r
.30905 .55216 m .30838 .55207 L .30791 .55195 L F
.2 .428 .857 r
.30815 .55217 m .30822 .55215 L .30813 .55204 L F
.30804 .55203 m .30813 .55204 L .30397 .54684 L F
.30815 .55217 m .30813 .55204 L .30804 .55203 L F
.30839 .55247 m .30822 .55215 L .30815 .55217 L F
.30839 .55247 m .30839 .55236 L .30822 .55215 L F
.919 .975 .767 r
.30825 .55214 m .30548 .55292 L .3086 .55262 L F
.2 0 0 r
.30838 .55207 m .30764 .5523 L .30771 .55229 L F
.30825 .55214 m .30771 .55229 L .308 .55228 L F
.869 .642 .591 r
.30813 .55204 m .30839 .55236 L .30797 .55207 L F
.2 0 0 r
.30838 .55207 m .30771 .55229 L .30825 .55214 L F
.30838 .55207 m .308 .55228 L .30897 .55222 L F
.30838 .55207 m .308 .55228 L .30838 .55207 L F
.944 .851 .721 r
.30823 .55211 m .30825 .55214 L .30838 .55207 L F
.30825 .55214 m .3086 .55262 L .30838 .55207 L F
.30823 .55211 m .30858 .55202 L .30854 .54998 L F
.869 .642 .591 r
.30397 .54684 m .30617 .54958 L .30486 .54992 L F
.30617 .54958 m .30813 .55204 L .30486 .54992 L F
.685 .544 .688 r
.30144 .55085 m .30178 .55073 L .30486 .54992 L F
.887 .898 .831 r
.30526 .54746 m .30571 .54508 L .30563 .54562 L F
.30522 .5476 m .30571 .54508 L .30526 .54746 L F
.096 .11 .584 r
.30486 .54992 m .3059 .54589 L .30397 .54684 L F
.30486 .54992 m .30612 .54919 L .3059 .54589 L F
.685 .544 .688 r
.30178 .55073 m .30612 .54919 L .30486 .54992 L F
.869 .642 .591 r
.30813 .55204 m .30797 .55207 L .30486 .54992 L F
.804 .723 .774 r
.30537 .55238 m .30486 .54992 L .30787 .55209 L F
.30548 .55292 m .30119 .55314 L .30486 .54992 L F
.919 .975 .767 r
.30612 .54919 m .30388 .55263 L .30457 .55275 L F
.30566 .55182 m .30457 .55275 L .30548 .55292 L F
.30612 .54919 m .30457 .55275 L .30566 .55182 L F
.869 .642 .591 r
.30803 .55211 m .30794 .55215 L .30651 .55111 L F
.30803 .55211 m .30651 .55111 L .30654 .55108 L F
.2 0 0 r
.30764 .5523 m .30581 .55285 L .30696 .55262 L F
.30764 .5523 m .30696 .55262 L .30897 .55222 L F
.30775 .55202 m .30581 .55285 L .30838 .55207 L F
.30587 .5528 m .30548 .55292 L .30581 .55285 L F
.30708 .55173 m .30548 .55292 L .30587 .5528 L F
.30587 .5528 m .30585 .55281 L .30613 .55271 L F
.30585 .55281 m .30599 .55278 L .30613 .55271 L F
.804 .723 .774 r
.30548 .55292 m .30537 .55238 L .30694 .55246 L F
.919 .975 .767 r
.30612 .54919 m .30548 .55292 L .30825 .55214 L F
.2 0 0 r
.30585 .55281 m .30581 .55285 L .30599 .55278 L F
.204 0 0 r
.30961 .55173 m .30936 .55192 L .30861 .55186 L F
.30936 .55192 m .30905 .55216 L .30843 .55203 L F
.30905 .55216 m .30897 .55222 L .30838 .55207 L F
0 .219 .733 r
.30855 .55265 m .30856 .55269 L .30853 .55262 L F
.30856 .55269 m .30879 .55567 L .30853 .55262 L F
.30893 .55306 m .30891 .55329 L .30855 .55265 L F
.30891 .55329 m .30879 .55567 L .30855 .55265 L F
.30845 .5542 m .30879 .55567 L .30847 .55493 L F
.212 0 .218 r
.38281 .57632 m .3802 .57934 L .38052 .57821 L F
0 0 0 r
.4102 .45978 m .4061 .46212 L .40859 .46145 L F
.182 0 0 r
.41128 .46095 m .4102 .45978 L .40859 .46145 L F
.41128 .46095 m .41281 .45913 L .4102 .45978 L F
.395 .842 .924 r
.57928 .34682 m .58212 .3461 L .58337 .3464 L F
.328 0 0 r
.58212 .3461 m .58612 .34541 L .58337 .3464 L F
.777 .967 .923 r
.67229 .37264 m .6759 .37018 L .67361 .36974 L F
.791 .962 .647 r
.67077 .3736 m .67229 .37264 L .67361 .36974 L F
.87 .905 .854 r
.3004 .61231 m .30233 .6132 L .30446 .61065 L F
.475 .281 .537 r
.30153 .61598 m .30233 .6132 L .3004 .61231 L F
.30153 .61598 m .30402 .61541 L .30233 .6132 L F
.81 .592 .607 r
.68283 .35964 m .6791 .35606 L .67904 .35889 L F
.805 .63 .664 r
.67904 .35889 m .68137 .36294 L .68283 .35964 L F
.965 .931 .617 r
.5581 .43034 m .55816 .43361 L .5597 .42947 L F
.772 .885 .927 r
.5597 .42947 m .56172 .42555 L .55929 .42865 L F
.908 .969 .663 r
.5581 .43034 m .5597 .42947 L .55929 .42865 L F
.447 .852 .969 r
.63203 .39437 m .63047 .39359 L .62766 .39432 L F
.345 .813 .917 r
.63449 .39348 m .63047 .39359 L .63203 .39437 L F
.411 .832 .661 r
.5587 .39774 m .55667 .39909 L .55526 .39987 L F
.5587 .39774 m .55526 .39987 L .5564 .39961 L F
0 0 0 r
.5564 .39961 m .5587 .39707 L .5587 .39774 L F
.5587 .39707 m .5599 .39574 L .5587 .39774 L F
.449 .869 .942 r
.55918 .39829 m .5587 .39844 L .5587 .39774 L F
.5587 .39844 m .55667 .39909 L .5587 .39774 L F
.607 .614 .832 r
.40852 .53268 m .40562 .53408 L .40266 .52974 L F
.648 .813 .962 r
.40425 .53237 m .40562 .53408 L .40852 .53268 L F
0 0 0 r
.52415 .41727 m .52558 .41676 L .52869 .41601 L F
.42921 .56291 m .43094 .56194 L .43223 .55981 L F
.346 0 .17 r
.42768 .56468 m .43094 .56194 L .42921 .56291 L F
.359 .654 .968 r
.55553 .40344 m .55489 .40552 L .55689 .40403 L F
0 0 .048 r
.55464 .40869 m .55553 .40344 L .55591 .40637 L F
.665 .844 .434 r
.55478 .40827 m .55464 .40869 L .55591 .40637 L F
.617 .92 .658 r
.55141 .4117 m .55448 .40917 L .55464 .40869 L F
0 0 0 r
.55141 .4117 m .55464 .40869 L .55351 .4104 L F
.665 .844 .434 r
.55351 .4104 m .55464 .40869 L .55478 .40827 L F
.617 .92 .658 r
.55448 .40917 m .55465 .40903 L .55464 .40869 L F
.987 .896 .591 r
.55465 .40903 m .55489 .40552 L .55464 .40869 L F
.554 .78 .983 r
.52886 .43833 m .5317 .43993 L .52726 .43956 L F
.595 .235 .328 r
.541 .4097 m .53774 .41168 L .53797 .41007 L F
.212 0 0 r
.2908 .66485 m .28704 .66561 L .28962 .66199 L F
.758 .754 .848 r
.28962 .66199 m .2943 .66205 L .2908 .66485 L F
.495 .288 .528 r
.54948 .36627 m .54949 .3689 L .55238 .36562 L F
.54948 .36627 m .54949 .3689 L .55238 .36562 L F
.557 .745 .965 r
.51724 .42612 m .51278 .42458 L .51704 .42444 L F
0 0 0 r
.51393 .42815 m .51724 .42612 L .51663 .42779 L F
.433 .465 .793 r
.51914 .42492 m .51724 .42612 L .51704 .42444 L F
.021 0 .106 r
.51663 .42779 m .51724 .42612 L .51914 .42492 L F
.086 .024 .483 r
.56252 .38229 m .56492 .38078 L .56462 .37797 L F
0 0 0 r
.56252 .38229 m .56205 .38407 L .56492 .38078 L F
.163 0 0 r
.2811 .6362 m .27882 .63701 L .27758 .63904 L F
.508 .243 .447 r
.38387 .53231 m .38431 .5352 L .38103 .53566 L F
.341 .133 .445 r
.38477 .53247 m .38431 .5352 L .38387 .53231 L F
.508 .243 .447 r
.38387 .53231 m .38103 .53566 L .38477 .53247 L F
.871 .958 .858 r
.46077 .54431 m .46104 .54676 L .46215 .54529 L F
.932 .967 .75 r
.46077 .54431 m .4587 .54778 L .46104 .54676 L F
.663 .88 .979 r
.4219 .59332 m .42595 .59317 L .42361 .59192 L F
.528 .296 .506 r
.25718 .556 m .2603 .55603 L .26032 .55288 L F
.354 .094 .375 r
.26032 .55288 m .26275 .5523 L .26322 .54989 L F
.276 .102 .456 r
.26032 .55288 m .26224 .55484 L .26275 .5523 L F
.26032 .55288 m .2603 .55603 L .26224 .55484 L F
.286 .307 .708 r
.2615 .58187 m .25969 .57927 L .26111 .57862 L F
.975 .715 .473 r
.56291 .38992 m .56126 .3912 L .56065 .38886 L F
.56291 .38992 m .56302 .39264 L .56126 .3912 L F
.744 .808 .903 r
.31118 .62946 m .30794 .63225 L .30702 .62948 L F
.856 .71 .699 r
.28139 .65246 m .28371 .65688 L .28112 .65495 L F
.786 .69 .758 r
.28599 .65313 m .28371 .65688 L .28139 .65246 L F
.771 .845 .907 r
.5076 .42567 m .50565 .42144 L .50602 .42449 L F
0 0 .343 r
.25004 .58292 m .2511 .58199 L .25135 .57915 L F
.01 0 .335 r
.25004 .58292 m .25087 .58463 L .2511 .58199 L F
.25004 .58292 m .2497 .58566 L .25087 .58463 L F
0 0 0 r
.63126 .35966 m .62716 .36083 L .6272 .35898 L F
.679 .202 .111 r
.62967 .36016 m .63008 .36036 L .63126 .35966 L F
.521 .577 .852 r
.63031 .36001 m .63126 .35966 L .63008 .36036 L F
0 0 0 r
.6291 .36027 m .62867 .36048 L .62716 .36083 L F
.63126 .35966 m .62967 .36016 L .6291 .36027 L F
.62967 .36016 m .62867 .36048 L .6291 .36027 L F
.679 .202 .111 r
.6272 .35898 m .62967 .36016 L .63126 .35966 L F
.349 .551 .909 r
.62853 .35672 m .62997 .3601 L .6272 .35898 L F
.62997 .3601 m .63008 .36036 L .62967 .36016 L F
.62997 .3601 m .62967 .36016 L .6272 .35898 L F
.521 .577 .852 r
.63301 .35592 m .63126 .35966 L .63031 .36001 L F
.822 .827 .852 r
.63301 .35592 m .63031 .36001 L .62853 .35672 L F
.63031 .36001 m .63008 .36036 L .62997 .3601 L F
.63031 .36001 m .62997 .3601 L .62853 .35672 L F
0 0 0 r
.63031 .36001 m .62982 .36021 L .62966 .36025 L F
.63126 .35966 m .63045 .35997 L .63031 .36001 L F
.63045 .35997 m .62982 .36021 L .63031 .36001 L F
.63126 .35966 m .62966 .36025 L .62867 .36048 L F
.521 .577 .852 r
.63387 .35807 m .63481 .35959 L .63142 .35931 L F
.934 .684 .535 r
.63387 .35807 m .63481 .35959 L .63456 .35758 L F
.521 .577 .852 r
.63403 .358 m .63481 .35959 L .63387 .35807 L F
.934 .684 .535 r
.63227 .35921 m .63481 .35959 L .63387 .35807 L F
.977 .713 .463 r
.63456 .35758 m .63481 .35959 L .63403 .358 L F
.63456 .35758 m .63403 .358 L .63301 .35592 L F
.934 .684 .535 r
.63227 .35921 m .63387 .35807 L .63399 .35802 L F
.63291 .35886 m .63399 .35802 L .63598 .35715 L F
.63227 .35921 m .63399 .35802 L .63291 .35886 L F
.63387 .35807 m .63456 .35758 L .63526 .35737 L F
.63387 .35807 m .63526 .35737 L .63598 .35715 L F
.521 .577 .852 r
.63142 .35931 m .63481 .35959 L .63126 .35966 L F
.63301 .35592 m .63403 .358 L .63142 .35931 L F
.143 .677 .855 r
.63126 .35966 m .63227 .35921 L .62982 .36021 L F
.63126 .35966 m .63481 .35959 L .63227 .35921 L F
.4 0 0 r
.29834 .6844 m .30104 .68556 L .30199 .68616 L F
.581 .932 .942 r
.39954 .57803 m .39704 .57934 L .39803 .5799 L F
0 0 0 r
.43223 .55981 m .43356 .55835 L .43456 .5569 L F
.153 .17 .624 r
.39328 .56458 m .39389 .56817 L .39197 .5696 L F
0 0 0 r
.39389 .56817 m .39222 .57245 L .39197 .5696 L F
.691 .981 .84 r
.52726 .43956 m .52343 .44172 L .5257 .44098 L F
0 0 0 r
.52886 .43833 m .52726 .43956 L .52908 .43823 L F
.52908 .43823 m .52726 .43956 L .5257 .44098 L F
.737 .842 .929 r
.33302 .62108 m .33449 .62256 L .33021 .62248 L F
.691 .829 .949 r
.33701 .62143 m .33449 .62256 L .33302 .62108 L F
.866 .993 .817 r
.29341 .65996 m .29716 .65636 L .2955 .65679 L F
.427 .212 .483 r
.52364 .37869 m .52096 .38208 L .52133 .37961 L F
.901 .854 .787 r
.27236 .65119 m .27461 .65269 L .27192 .65606 L F
0 .224 .746 r
.27536 .65136 m .27461 .65269 L .27236 .65119 L F
.27536 .65136 m .27721 .65478 L .27461 .65269 L F
.926 .653 .503 r
.65529 .35147 m .65332 .35152 L .65317 .34895 L F
.747 .299 0 r
.65529 .35147 m .65603 .35354 L .65332 .35152 L F
.65529 .35147 m .65733 .35497 L .65603 .35354 L F
.798 .641 .688 r
.33645 .56929 m .33369 .57274 L .33817 .57325 L F
.787 .694 .762 r
.33369 .57274 m .33557 .57665 L .33817 .57325 L F
.223 0 0 r
.51805 .44857 m .52194 .44669 L .52063 .44526 L F
.628 .85 .984 r
.52194 .44669 m .52457 .44564 L .52063 .44526 L F
.966 .689 .265 r
.39399 .56218 m .39389 .55952 L .3927 .5585 L F
.838 .559 .516 r
.32675 .51825 m .32933 .51618 L .32498 .51546 L F
.32675 .51825 m .32946 .519 L .32933 .51618 L F
.44 .66 .954 r
.31433 .58786 m .3134 .5898 L .31206 .58794 L F
.482 .282 .532 r
.31433 .58786 m .31206 .58794 L .3134 .5898 L F
.068 0 0 r
.3134 .5898 m .31424 .59081 L .3178 .58826 L F
.3134 .5898 m .31189 .59192 L .31424 .59081 L F
.779 .709 .785 r
.28356 .64927 m .28599 .65313 L .28139 .65246 L F
.707 .685 .827 r
.28979 .6503 m .28599 .65313 L .28356 .64927 L F
0 0 .371 r
.38833 .47029 m .38941 .47136 L .39142 .46882 L F
.916 .844 .758 r
.54889 .45101 m .55038 .45235 L .55102 .44947 L F
.921 .869 .771 r
.54645 .45466 m .55038 .45235 L .54889 .45101 L F
.54645 .45466 m .54805 .45594 L .55038 .45235 L F
.375 .801 .97 r
.63774 .34655 m .63391 .34641 L .63537 .34716 L F
.58 .288 .436 r
.39399 .56218 m .39328 .56458 L .39477 .56505 L F
.685 .844 .959 r
.289 .68351 m .28988 .68078 L .28764 .68143 L F
.289 .68351 m .29153 .68232 L .28988 .68078 L F
0 0 .562 r
.3154 .54451 m .3167 .54835 L .31532 .54653 L F
.43 .137 .364 r
.31532 .54653 m .3167 .54835 L .31413 .5489 L F
.559 0 0 r
.3137 .68583 m .31359 .6856 L .31647 .68797 L F
.3137 .68583 m .31647 .68797 L .31453 .68644 L F
.3137 .68583 m .31453 .68644 L .31295 .6852 L F
.061 .619 .803 r
.30893 .68522 m .31338 .68559 L .3137 .68583 L F
.31338 .68559 m .31359 .6856 L .3137 .68583 L F
.935 .592 .161 r
.56611 .41433 m .56688 .41273 L .56645 .41065 L F
.56611 .41433 m .56757 .4159 L .56688 .41273 L F
.912 .728 .64 r
.37105 .56309 m .37056 .56599 L .36893 .56208 L F
.992 .801 .424 r
.31277 .57768 m .31226 .57659 L .3149 .57709 L F
.31277 .57768 m .31201 .57866 L .31226 .57659 L F
.785 .693 .763 r
.33104 .57597 m .33557 .57665 L .33369 .57274 L F
.794 .69 .75 r
.33101 .57883 m .33557 .57665 L .33104 .57597 L F
.302 .308 .7 r
.25099 .57225 m .25362 .5749 L .25248 .57231 L F
.815 .664 .695 r
.39167 .52236 m .39324 .5261 L .3938 .5233 L F
0 0 0 r
.4829 .41242 m .48446 .4111 L .48596 .40966 L F
.478 .862 .656 r
.4829 .41242 m .48104 .41347 L .48446 .4111 L F
0 0 0 r
.544 .40852 m .54277 .41124 L .54308 .4106 L F
.347 0 0 r
.541 .4097 m .544 .40852 L .54308 .4106 L F
.479 .897 .884 r
.544 .40852 m .54791 .40703 L .54576 .40705 L F
0 0 0 r
.54308 .4106 m .544 .40852 L .54576 .40705 L F
.854 .994 .751 r
.54336 .40836 m .54308 .4106 L .54576 .40705 L F
.474 0 0 r
.54346 .40981 m .54308 .4106 L .54336 .40836 L F
.618 .164 .153 r
.54583 .41253 m .54744 .41058 L .54308 .4106 L F
.474 0 0 r
.54358 .41137 m .54583 .41253 L .54308 .4106 L F
.54358 .41137 m .54308 .4106 L .54346 .40981 L F
0 0 0 r
.54277 .41124 m .54225 .41239 L .54308 .4106 L F
.877 .483 .284 r
.30813 .64496 m .31176 .6469 L .30944 .64502 L F
.893 .934 .836 r
.30864 .65216 m .30983 .64892 L .30733 .65157 L F
.895 .564 .413 r
.31109 .6485 m .31176 .6469 L .30813 .64496 L F
.31131 .64878 m .31105 .64846 L .31047 .64715 L F
.3114 .6484 m .31176 .6469 L .31109 .6485 L F
.31131 .64878 m .3114 .6484 L .31109 .6485 L F
.692 .866 .964 r
.31047 .64715 m .31131 .64878 L .31296 .64768 L F
.637 .077 0 r
.31047 .64715 m .31201 .64824 L .3117 .64822 L F
.895 .564 .413 r
.31105 .64846 m .30862 .64554 L .31047 .64715 L F
.893 .934 .836 r
.30983 .64892 m .31047 .64715 L .30902 .64919 L F
.30864 .65216 m .31131 .64878 L .31047 .64715 L F
.769 .658 .739 r
.30733 .65157 m .31047 .64715 L .3056 .64547 L F
.637 .077 0 r
.31047 .64715 m .3117 .64822 L .30906 .64808 L F
.895 .564 .413 r
.30862 .64554 m .30813 .64496 L .31047 .64715 L F
.716 .219 .057 r
.3056 .64547 m .31047 .64715 L .30813 .64496 L F
.927 .941 .591 r
.30985 .64574 m .31047 .64715 L .3088 .64708 L F
.31089 .6444 m .31047 .64715 L .30985 .64574 L F
.893 .934 .836 r
.30983 .64892 m .30902 .64919 L .30733 .65157 L F
.488 .79 .998 r
.64274 .39598 m .64419 .3941 L .64155 .39408 L F
.64274 .39598 m .64553 .39548 L .64419 .3941 L F
0 0 0 r
.48596 .40966 m .48666 .40957 L .48864 .40888 L F
.48596 .40966 m .48446 .4111 L .48666 .40957 L F
.639 .81 .965 r
.34309 .66579 m .34115 .66707 L .33874 .66519 L F
.673 .886 .522 r
.24646 .59576 m .24597 .59662 L .24846 .59323 L F
.372 0 .188 r
.24727 .59825 m .24597 .59662 L .24646 .59576 L F
.082 .157 .643 r
.3814 .52473 m .3825 .52831 L .38044 .52611 L F
.204 .437 .863 r
.35187 .63232 m .35159 .63479 L .34869 .63343 L F
.35187 .63232 m .35375 .63556 L .35159 .63479 L F
0 0 0 r
.5879 .35748 m .58592 .35969 L .58925 .35538 L F
.384 .368 .718 r
.5879 .35748 m .58901 .36147 L .58592 .35969 L F
.75 .398 .387 r
.3617 .50868 m .36388 .51146 L .36594 .50913 L F
.392 .183 .474 r
.26322 .54989 m .26551 .54919 L .26564 .54629 L F
.271 .025 .345 r
.26322 .54989 m .26484 .55143 L .26551 .54919 L F
.26322 .54989 m .26278 .55213 L .26484 .55143 L F
.33 .034 .302 r
.26551 .54919 m .26484 .55143 L .2672 .55071 L F
.497 0 0 r
.26364 .55114 m .26684 .55076 L .26484 .55143 L F
.26684 .55076 m .2672 .55071 L .26484 .55143 L F
.271 .025 .345 r
.26278 .55213 m .26275 .5523 L .26484 .55143 L F
0 0 0 r
.44887 .449 m .45209 .44591 L .45046 .44738 L F
.586 .873 .558 r
.45377 .44458 m .45384 .44469 L .45537 .44296 L F
.427 .847 .688 r
.45391 .44481 m .45384 .44469 L .45209 .44591 L F
0 0 0 r
.45046 .44738 m .45384 .44469 L .45218 .44619 L F
.586 .873 .558 r
.45218 .44619 m .45384 .44469 L .45377 .44458 L F
.427 .847 .688 r
.45395 .44478 m .45384 .44469 L .45391 .44481 L F
0 0 0 r
.45209 .44591 m .45384 .44469 L .45046 .44738 L F
.41827 .466 m .42131 .46315 L .42058 .4644 L F
.105 0 0 r
.42131 .46315 m .42243 .46442 L .42058 .4644 L F
.42131 .46315 m .42368 .46218 L .42243 .46442 L F
.291 .105 .447 r
.26564 .54629 m .26756 .54806 L .26792 .54541 L F
.26564 .54629 m .26551 .54919 L .26756 .54806 L F
.742 .984 .765 r
.48755 .42183 m .48833 .42185 L .49115 .41912 L F
.718 .563 .678 r
.386 .51989 m .38931 .52162 L .38938 .51954 L F
.731 .549 .645 r
.38931 .52162 m .39172 .51944 L .38938 .51954 L F
.83 .936 .898 r
.50614 .49752 m .5109 .49569 L .51007 .49476 L F
.862 .985 .847 r
.51007 .49476 m .5109 .49569 L .51398 .49243 L F
.476 .463 .764 r
.24807 .58929 m .24846 .59323 L .24993 .59098 L F
.953 .948 .723 r
.56339 .42673 m .56548 .42301 L .56351 .42342 L F
.955 .941 .622 r
.56477 .42213 m .56548 .42301 L .56711 .41851 L F
.881 .992 .793 r
.56351 .42342 m .56548 .42301 L .56477 .42213 L F
.87 .905 .854 r
.3004 .61231 m .30446 .61065 L .30138 .6116 L F
.668 .918 .975 r
.30446 .61065 m .3052 .60866 L .30138 .6116 L F
.30446 .61065 m .30687 .60941 L .3052 .60866 L F
.512 .322 .559 r
.28146 .52285 m .28389 .52251 L .28407 .51943 L F
.354 .139 .442 r
.28146 .52285 m .2834 .52469 L .28389 .52251 L F
.28146 .52285 m .28117 .52549 L .2834 .52469 L F
.875 .707 .671 r
.33475 .56517 m .33645 .56929 L .33664 .56639 L F
.388 0 0 r
.65018 .33741 m .65419 .33557 L .65054 .33681 L F
.65018 .33741 m .65297 .33731 L .65419 .33557 L F
.461 0 .019 r
.65297 .33731 m .65696 .33572 L .65419 .33557 L F
.832 .965 .892 r
.67361 .36974 m .6759 .37018 L .67767 .368 L F
.79 .646 .703 r
.37056 .56599 m .37247 .57006 L .3681 .56915 L F
.841 .773 .786 r
.37247 .57006 m .36785 .57208 L .3681 .56915 L F
.979 .753 .526 r
.32946 .519 m .32921 .52189 L .3308 .52253 L F
.902 .613 .487 r
.32855 .52465 m .3308 .52253 L .32921 .52189 L F
.32855 .52465 m .33089 .52553 L .3308 .52253 L F
.928 .698 .571 r
.32478 .58865 m .32716 .58938 L .32565 .58594 L F
.906 .808 .74 r
.32285 .59205 m .32716 .58938 L .32478 .58865 L F
.32285 .59205 m .32497 .59329 L .32716 .58938 L F
.744 .64 .745 r
.32565 .58594 m .32716 .58938 L .32975 .586 L F
.407 .041 .228 r
.51805 .44857 m .51902 .44671 L .51508 .4491 L F
.887 .893 .471 r
.51902 .44671 m .51805 .44857 L .51508 .4491 L F
0 0 0 r
.52063 .44526 m .51902 .44671 L .51805 .44857 L F
.503 .498 .784 r
.54782 .40919 m .55004 .40614 L .54791 .40703 L F
.54782 .40919 m .55101 .40885 L .55004 .40614 L F
.687 .978 .896 r
.55101 .40885 m .54795 .41044 L .54851 .41002 L F
.565 .935 .821 r
.54746 .41052 m .54851 .41002 L .54782 .40919 L F
.54851 .41002 m .55101 .40885 L .54919 .40905 L F
.54851 .41002 m .54919 .40905 L .54782 .40919 L F
.331 .39 .772 r
.55004 .40614 m .55101 .40885 L .55266 .40695 L F
.687 .978 .896 r
.55101 .40885 m .54851 .41002 L .55266 .40695 L F
0 0 0 r
.55266 .40695 m .54851 .41002 L .55143 .40872 L F
.565 .935 .821 r
.54847 .41008 m .54795 .41044 L .55101 .40885 L F
0 0 0 r
.54851 .41002 m .54795 .41044 L .54847 .41008 L F
.565 .935 .821 r
.54744 .41058 m .54795 .41044 L .54847 .41008 L F
0 0 0 r
.54847 .41008 m .54795 .41044 L .54837 .41023 L F
.565 .935 .821 r
.54744 .41058 m .55101 .40885 L .54746 .41052 L F
0 0 0 r
.54851 .41002 m .54837 .41023 L .55143 .40872 L F
.98 .689 .374 r
.39476 .5805 m .39403 .58192 L .39222 .57808 L F
.468 .751 .991 r
.39704 .57934 m .39476 .5805 L .39222 .57808 L F
.889 .99 .776 r
.30727 .54444 m .30563 .54562 L .30571 .54508 L F
.363 .815 .695 r
.30727 .54444 m .30844 .54373 L .31067 .5436 L F
.30727 .54444 m .30571 .54508 L .30844 .54373 L F
.612 .073 0 r
.34634 .50551 m .34884 .50743 L .35091 .50644 L F
.707 .364 .394 r
.34884 .50743 m .35307 .50531 L .35091 .50644 L F
.713 .9 .963 r
.31816 .59654 m .32182 .5962 L .3199 .59474 L F
.791 .821 .876 r
.3199 .59474 m .32182 .5962 L .32497 .59329 L F
0 .231 .75 r
.30308 .64213 m .30512 .64556 L .30565 .64408 L F
.987 .85 .616 r
.30512 .64556 m .30253 .64743 L .30565 .64408 L F
.30512 .64556 m .30367 .65061 L .30253 .64743 L F
.473 .839 .59 r
.41076 .4754 m .4111 .47505 L .41408 .47278 L F
.75 .366 .325 r
.41076 .4754 m .41291 .47846 L .4086 .47774 L F
.41076 .4754 m .4086 .47774 L .4111 .47505 L F
.862 .985 .847 r
.51007 .49476 m .51398 .49243 L .51254 .49124 L F
.82 .937 .906 r
.51398 .49243 m .51584 .48846 L .51254 .49124 L F
.51398 .49243 m .51724 .4895 L .51584 .48846 L F
.134 .452 .883 r
.49396 .43762 m .49147 .43674 L .4945 .43788 L F
.504 0 0 r
.49147 .43674 m .4957 .43965 L .4945 .43788 L F
.155 .087 .522 r
.25718 .556 m .25903 .55767 L .2603 .55603 L F
.25718 .556 m .25777 .55935 L .25903 .55767 L F
.934 .738 .614 r
.3359 .55531 m .33738 .55909 L .33804 .55649 L F
.823 .689 .716 r
.33101 .57883 m .32803 .58263 L .33259 .58268 L F
.814 .747 .79 r
.32803 .58263 m .32975 .586 L .33259 .58268 L F
.972 .727 .506 r
.58782 .35446 m .58925 .35538 L .58854 .35343 L F
0 0 0 r
.5879 .35748 m .58925 .35538 L .58782 .35446 L F
.654 .292 .345 r
.58925 .35538 m .5879 .35748 L .58782 .35446 L F
.58925 .35538 m .59176 .35809 L .5879 .35748 L F
.786 .945 .927 r
.44021 .56613 m .44049 .56397 L .43877 .56527 L F
.44021 .56613 m .44117 .56512 L .44049 .56397 L F
.703 .939 .637 r
.50535 .48531 m .50771 .48208 L .50823 .48228 L F
.50535 .48531 m .50492 .4853 L .50771 .48208 L F
.999 .788 .474 r
.32432 .5495 m .32295 .54881 L .32344 .54541 L F
.986 .709 .361 r
.32432 .5495 m .32452 .55254 L .32295 .54881 L F
.837 .466 .35 r
.50299 .45642 m .49987 .45657 L .50004 .45525 L F
.117 0 0 r
.50459 .45697 m .50299 .45642 L .5053 .45597 L F
.50459 .45697 m .50122 .45829 L .50299 .45642 L F
.979 .683 .337 r
.30019 .64804 m .3019 .65025 L .30166 .6515 L F
.327 .516 .889 r
.30253 .64743 m .30367 .65061 L .3019 .65025 L F
.511 .898 .74 r
.33748 .67515 m .34187 .67274 L .34021 .67155 L F
.731 .983 .771 r
.34187 .67274 m .34258 .67098 L .34021 .67155 L F
.34187 .67274 m .34491 .66993 L .34258 .67098 L F
.714 .91 .963 r
.50199 .40819 m .50735 .40714 L .50503 .40588 L F
.729 .894 .954 r
.50503 .40588 m .50735 .40714 L .50731 .4044 L F
.082 0 0 r
.42058 .4644 m .41644 .46736 L .41827 .466 L F
.738 .513 .588 r
.28407 .51943 m .28792 .52252 L .28675 .51885 L F
.28407 .51943 m .28389 .52251 L .28792 .52252 L F
.847 .898 .873 r
.49358 .50757 m .49744 .50701 L .49916 .50485 L F
.789 .806 .866 r
.24682 .60777 m .24824 .60946 L .24444 .60905 L F
.784 .534 .559 r
.24824 .60946 m .24803 .61227 L .24369 .61179 L F
.396 .645 .957 r
.24682 .60777 m .24912 .60768 L .24824 .60946 L F
.157 0 0 r
.24884 .61017 m .2513 .61026 L .24907 .61146 L F
.283 .27 .668 r
.24852 .61019 m .24803 .61227 L .24823 .60951 L F
.24912 .60768 m .24884 .61017 L .24803 .61227 L F
.656 .885 .531 r
.24762 .61225 m .24803 .61227 L .24884 .61017 L F
.157 0 0 r
.24865 .61049 m .24907 .61146 L .24762 .61225 L F
.24884 .61017 m .24907 .61146 L .24865 .61049 L F
.283 .27 .668 r
.24912 .60768 m .24852 .61019 L .24824 .60946 L F
.24852 .61019 m .24823 .60951 L .24824 .60946 L F
.963 .939 .648 r
.24678 .6028 m .24488 .60447 L .24615 .60239 L F
.656 .958 .938 r
.24678 .6028 m .24615 .60239 L .24748 .60112 L F
.505 .347 .601 r
.24748 .60112 m .24488 .60447 L .24678 .6028 L F
0 .244 .743 r
.39603 .47209 m .39742 .47346 L .39842 .47359 L F
.237 .738 .669 r
.62745 .3435 m .62947 .34279 L .63108 .34222 L F
.423 .863 .91 r
.62947 .34279 m .63389 .34218 L .63108 .34222 L F
.387 .786 .986 r
.56006 .34881 m .56158 .34831 L .56323 .34916 L F
.136 .495 .905 r
.56347 .34747 m .56323 .34916 L .56158 .34831 L F
.485 .316 .576 r
.56139 .35058 m .56328 .34775 L .56158 .34831 L F
.56328 .34775 m .56347 .34747 L .56158 .34831 L F
.387 .786 .986 r
.55899 .34868 m .56158 .34831 L .56006 .34881 L F
.136 .495 .905 r
.56347 .34747 m .56483 .34932 L .56323 .34916 L F
.881 .557 .432 r
.31816 .52439 m .3151 .52211 L .31725 .52257 L F
.745 .629 .731 r
.32527 .5837 m .32975 .586 L .32803 .58263 L F
.32527 .5837 m .32565 .58594 L .32975 .586 L F
.331 .373 .754 r
.32507 .55484 m .3241 .55922 L .32314 .55849 L F
.862 .746 .734 r
.44791 .54201 m .45007 .54333 L .44832 .5444 L F
.955 .941 .622 r
.56477 .42213 m .56711 .41851 L .56626 .41802 L F
.702 .69 .152 r
.43189 .58544 m .43151 .58732 L .43202 .58476 L F
.753 .925 .946 r
.43202 .58476 m .43151 .58732 L .43356 .58573 L F
.377 .282 .619 r
.29806 .61242 m .29961 .61398 L .3004 .61231 L F
.785 .523 0 r
.29806 .61242 m .30153 .61598 L .29961 .61398 L F
.963 .646 .37 r
.37747 .58326 m .37511 .58201 L .37471 .58363 L F
.417 .728 .99 r
.36935 .57663 m .37037 .57468 L .36759 .57492 L F
.36935 .57663 m .3724 .57627 L .37037 .57468 L F
.553 0 0 r
.5291 .44798 m .53304 .44934 L .53034 .44928 L F
.831 .601 .59 r
.53304 .44934 m .52897 .4518 L .53034 .44928 L F
.53304 .44934 m .53276 .45221 L .52897 .4518 L F
.742 .984 .765 r
.48755 .42183 m .49115 .41912 L .48947 .41997 L F
.555 .908 .702 r
.49249 .41725 m .4944 .41628 L .49622 .41476 L F
.49249 .41725 m .49622 .41476 L .49598 .41497 L F
.699 .983 .876 r
.49598 .41497 m .49348 .41514 L .49249 .41725 L F
0 0 0 r
.49351 .41553 m .49249 .41725 L .49348 .41514 L F
.651 .949 .719 r
.49161 .41872 m .4944 .41628 L .49249 .41725 L F
0 0 0 r
.4937 .41797 m .49249 .41725 L .49351 .41553 L F
.651 .949 .719 r
.49115 .41912 m .49161 .41872 L .49249 .41725 L F
.649 .943 .702 r
.49249 .41725 m .48947 .41997 L .49115 .41912 L F
.804 .399 .283 r
.64883 .34625 m .64695 .34748 L .64493 .3462 L F
.64883 .34625 m .64929 .34836 L .64695 .34748 L F
.759 .366 .309 r
.65317 .34895 m .64883 .34625 L .65292 .34621 L F
.65317 .34895 m .64929 .34836 L .64883 .34625 L F
.897 .692 .616 r
.41328 .55532 m .41638 .55917 L .41533 .5563 L F
.752 .923 .562 r
.34491 .66993 m .34744 .66614 L .34678 .6686 L F
.863 .974 .858 r
.34744 .66614 m .34735 .66364 L .34557 .66508 L F
.34744 .66614 m .35046 .66299 L .34817 .66347 L F
.937 .942 .768 r
.3489 .66209 m .35046 .66299 L .35241 .65914 L F
.884 .963 .842 r
.34735 .66364 m .35046 .66299 L .3489 .66209 L F
.937 .942 .768 r
.3489 .66209 m .35241 .65914 L .35133 .65873 L F
0 0 0 r
.3489 .66214 m .35018 .66044 L .34912 .66368 L F
.3489 .66209 m .34902 .66193 L .3489 .66214 L F
.34902 .66193 m .35018 .66044 L .3489 .66214 L F
.863 .974 .858 r
.34739 .66488 m .34817 .66347 L .34735 .66364 L F
.34744 .66614 m .34817 .66347 L .34739 .66488 L F
.98 .751 .521 r
.34678 .6686 m .34744 .66614 L .34557 .66508 L F
.8 .993 .876 r
.33874 .66519 m .34318 .66277 L .3413 .66463 L F
.6 .942 .937 r
.31836 .54141 m .31697 .54275 L .31593 .54307 L F
.466 .275 .536 r
.34309 .66579 m .34557 .66508 L .34318 .66277 L F
.681 .228 .168 r
.34318 .66277 m .34557 .66508 L .3413 .66463 L F
.503 .892 .726 r
.34599 .66905 m .3459 .66922 L .34678 .6686 L F
.34258 .67098 m .34491 .66993 L .3459 .66922 L F
.34258 .67098 m .3459 .66922 L .34599 .66905 L F
.34258 .67098 m .34678 .6686 L .34506 .66985 L F
.98 .751 .521 r
.34678 .6686 m .34557 .66508 L .34617 .66905 L F
0 0 .231 r
.34623 .66642 m .34557 .66508 L .34735 .66364 L F
.759 .939 .598 r
.34645 .66518 m .34623 .66642 L .34677 .66472 L F
0 0 .231 r
.34623 .66642 m .346 .66765 L .34557 .66508 L F
.34618 .66869 m .34613 .66878 L .34557 .66508 L F
.759 .939 .598 r
.34426 .66829 m .34623 .66642 L .34645 .66518 L F
0 0 .231 r
.34623 .66642 m .34618 .66869 L .346 .66765 L F
.34618 .66869 m .34617 .66905 L .34613 .66878 L F
.834 .888 .46 r
.5653 .39727 m .56472 .39976 L .56632 .39607 L F
.71 .263 .188 r
.50084 .45139 m .50372 .45413 L .50741 .45301 L F
.74 .989 .887 r
.50741 .45301 m .50646 .45193 L .50834 .45298 L F
.50741 .45301 m .50372 .45413 L .50646 .45193 L F
.794 .832 .881 r
.31837 .62653 m .31382 .62824 L .31685 .62595 L F
.883 .941 .848 r
.31773 .62436 m .31837 .62653 L .31685 .62595 L F
0 0 0 r
.45629 .43294 m .45238 .43545 L .45434 .43393 L F
.573 .916 .705 r
.4582 .4313 m .45629 .43294 L .45434 .43393 L F
.914 .937 .809 r
.55681 .43523 m .55816 .43361 L .5581 .43034 L F
.925 .695 .572 r
.39127 .52427 m .39324 .5261 L .39167 .52236 L F
.881 .714 .67 r
.38925 .52825 m .39324 .5261 L .39127 .52427 L F
.38925 .52825 m .39307 .52978 L .39324 .5261 L F
.056 0 0 r
.63946 .34077 m .64351 .33911 L .64073 .33973 L F
.562 .812 .992 r
.64265 .37993 m .63848 .37914 L .64134 .37776 L F
.562 .88 .992 r
.64414 .37803 m .64265 .37993 L .64134 .37776 L F
.64414 .37803 m .64533 .37891 L .64265 .37993 L F
.881 .806 .771 r
.65809 .3586 m .65513 .3586 L .65733 .35497 L F
.883 .8 .763 r
.65809 .3586 m .6557 .36258 L .65513 .3586 L F
.848 .789 .793 r
.65733 .35497 m .65912 .35657 L .65809 .3586 L F
.951 .826 .685 r
.42149 .57147 m .42353 .5731 L .42362 .57014 L F
.876 .656 .601 r
.42149 .57147 m .42347 .575 L .42353 .5731 L F
.504 .452 .732 r
.42362 .57014 m .42353 .5731 L .42651 .5719 L F
0 0 0 r
.42347 .575 m .422 .57976 L .42254 .5784 L F
.278 0 .258 r
.42406 .57289 m .42347 .575 L .42651 .5719 L F
.665 .932 .648 r
.42347 .575 m .42451 .57339 L .42651 .5719 L F
0 0 0 r
.42347 .575 m .42254 .5784 L .42451 .57339 L F
.278 0 .258 r
.42353 .5731 m .42347 .575 L .42406 .57289 L F
.889 .944 .841 r
.44022 .58094 m .44365 .57967 L .44131 .57843 L F
.44022 .58094 m .44039 .58325 L .44365 .57967 L F
.836 .799 .816 r
.44131 .57843 m .44365 .57967 L .44624 .57643 L F
.731 .549 .645 r
.38931 .52162 m .39167 .52236 L .39172 .51944 L F
.535 .548 .815 r
.39172 .51944 m .39277 .51485 L .39505 .51606 L F
.39172 .51944 m .39447 .51931 L .39277 .51485 L F
.841 .602 .577 r
.39167 .52236 m .39447 .51931 L .39172 .51944 L F
.852 .708 .703 r
.67597 .35559 m .6791 .35606 L .67758 .35202 L F
.802 .587 .611 r
.67497 .35817 m .6791 .35606 L .67597 .35559 L F
.67497 .35817 m .67904 .35889 L .6791 .35606 L F
.993 .856 .594 r
.53597 .38614 m .53515 .38553 L .53516 .3849 L F
.42 .375 .703 r
.53208 .3882 m .52929 .38647 L .53198 .38527 L F
.83 .896 .888 r
.53702 .38391 m .53597 .38614 L .53516 .3849 L F
.539 .38287 m .53851 .3834 L .53702 .38391 L F
.53851 .3834 m .53597 .38614 L .53702 .38391 L F
.539 .38287 m .53516 .3849 L .53745 .38388 L F
.488 .296 .546 r
.53601 .38459 m .53208 .3882 L .53198 .38527 L F
.094 0 0 r
.53417 .3849 m .53069 .38636 L .53601 .38459 L F
.53198 .38527 m .5312 .38593 L .53417 .3849 L F
.5312 .38593 m .53069 .38636 L .53417 .3849 L F
.739 .704 .818 r
.53933 .38489 m .53597 .38614 L .539 .38287 L F
.624 .184 .184 r
.53933 .38489 m .53515 .38553 L .53597 .38614 L F
.671 .795 .941 r
.30267 .62912 m .30174 .63256 L .30002 .63173 L F
.30267 .62912 m .30408 .63174 L .30174 .63256 L F
.479 .546 .846 r
.60068 .36724 m .59792 .36961 L .59729 .36729 L F
.253 .106 .479 r
.60068 .36724 m .59768 .37161 L .59792 .36961 L F
.736 .92 .954 r
.52966 .4803 m .52831 .47943 L .5246 .48135 L F
.766 .926 .94 r
.53037 .47765 m .52966 .4803 L .53169 .47831 L F
.53037 .47765 m .52831 .47943 L .52966 .4803 L F
.327 .706 .982 r
.64971 .39572 m .6517 .39458 L .64835 .39451 L F
.64971 .39572 m .65282 .3957 L .6517 .39458 L F
.03 .601 .74 r
.6546 .39574 m .65282 .3957 L .64971 .39572 L F
.347 .366 .738 r
.57356 .35254 m .57445 .35675 L .5766 .35429 L F
.195 .222 .662 r
.57564 .35897 m .5766 .35429 L .57445 .35675 L F
.83 .959 .895 r
.46077 .54431 m .46215 .54529 L .46568 .54219 L F
.842 .477 .361 r
.32072 .52966 m .31884 .53123 L .3164 .528 L F
.822 .444 .339 r
.32072 .52966 m .3215 .53205 L .31884 .53123 L F
.67 .825 .958 r
.31593 .5751 m .3149 .57709 L .31226 .57659 L F
.893 .481 .208 r
.67618 .34556 m .67659 .34784 L .67849 .34771 L F
.988 .832 .598 r
.67626 .35074 m .67849 .34771 L .67659 .34784 L F
.67626 .35074 m .67758 .35202 L .67849 .34771 L F
.624 .184 .184 r
.53933 .38489 m .53831 .38709 L .53515 .38553 L F
.361 0 .057 r
.54213 .38529 m .53831 .38709 L .53933 .38489 L F
.664 .346 .425 r
.43051 .45929 m .42642 .46206 L .42832 .45949 L F
.278 .733 .955 r
.41139 .55566 m .41101 .55133 L .40967 .5515 L F
.41139 .55566 m .41205 .55457 L .41101 .55133 L F
.41139 .55566 m .41328 .55532 L .41205 .55457 L F
.403 .253 .561 r
.35348 .50283 m .35565 .50476 L .35566 .50117 L F
.499 .246 .461 r
.35348 .50283 m .35307 .50531 L .35565 .50476 L F
.71 .181 0 r
.39483 .51717 m .39505 .51606 L .39277 .51485 L F
.453 .244 .504 r
.39505 .51606 m .39701 .51845 L .39447 .51931 L F
.71 .181 0 r
.39483 .51717 m .39701 .51845 L .39505 .51606 L F
.813 .754 .797 r
.39242 .5821 m .3887 .58592 L .38701 .58218 L F
.588 .388 .578 r
.39177 .5853 m .3887 .58592 L .39242 .5821 L F
.886 .944 .582 r
.50823 .48228 m .50963 .47808 L .51147 .4794 L F
.50823 .48228 m .50771 .48208 L .50963 .47808 L F
.942 .858 .729 r
.31763 .58606 m .31547 .58552 L .31712 .58174 L F
.7 .312 .308 r
.31763 .58606 m .31433 .58786 L .31547 .58552 L F
.11 0 0 r
.31433 .58786 m .31817 .58833 L .3178 .58826 L F
.7 .312 .308 r
.31763 .58606 m .31817 .58833 L .31433 .58786 L F
.67 .681 .852 r
.32197 .58312 m .31763 .58606 L .31712 .58174 L F
.174 .669 .917 r
.63891 .39433 m .63741 .39348 L .63449 .39348 L F
.244 .72 .938 r
.64155 .39408 m .63741 .39348 L .63891 .39433 L F
.816 .652 .68 r
.32532 .53926 m .3221 .53873 L .32362 .53546 L F
.932 .827 .719 r
.32532 .53926 m .32208 .54151 L .3221 .53873 L F
.32532 .53926 m .32399 .5426 L .32208 .54151 L F
.947 .785 .649 r
.38545 .52911 m .38214 .53106 L .3825 .52831 L F
.38545 .52911 m .38477 .53247 L .38214 .53106 L F
.281 .176 .553 r
.4935 .43158 m .49632 .43403 L .49615 .43126 L F
.4935 .43158 m .49396 .43762 L .49632 .43403 L F
.487 .456 .748 r
.58789 .34981 m .59063 .35166 L .59009 .34959 L F
0 0 0 r
.59009 .34959 m .59222 .34764 L .59365 .3461 L F
.027 0 0 r
.58885 .34998 m .59009 .34959 L .59063 .35166 L F
.58885 .34998 m .59222 .34764 L .59009 .34959 L F
.875 .707 .671 r
.33475 .56517 m .33259 .56896 L .33645 .56929 L F
.83 .695 .714 r
.33194 .57117 m .33645 .56929 L .33259 .56896 L F
.33194 .57117 m .33369 .57274 L .33645 .56929 L F
0 0 0 r
.64206 .34622 m .64093 .34636 L .63774 .34655 L F
.64493 .3462 m .64093 .34636 L .64206 .34622 L F
.843 .677 .675 r
.44021 .57142 m .44552 .5696 L .44071 .57001 L F
.44021 .57142 m .44478 .57333 L .44552 .5696 L F
.605 .935 .955 r
.44478 .57333 m .44717 .57179 L .44552 .5696 L F
.934 .738 .614 r
.3359 .55531 m .3351 .55825 L .33738 .55909 L F
.879 .745 .711 r
.3351 .55825 m .33636 .56221 L .33738 .55909 L F
0 0 .32 r
.25619 .56603 m .25694 .56799 L .25728 .56516 L F
.643 .457 .616 r
.52203 .43513 m .51896 .43837 L .51913 .43565 L F
.054 0 0 r
.5201 .43629 m .51913 .43565 L .51896 .43837 L F
.5201 .43629 m .52203 .43513 L .51913 .43565 L F
.6 .258 .361 r
.34241 .63499 m .34253 .6331 L .34003 .63272 L F
.606 .29 .407 r
.34003 .63272 m .34383 .6321 L .34253 .6331 L F
.593 .259 .374 r
.34133 .63396 m .34257 .63303 L .34003 .63272 L F
.34257 .63303 m .34383 .6321 L .34334 .63218 L F
0 0 0 r
.34241 .63499 m .34253 .6331 L .34253 .63308 L F
.593 .259 .374 r
.34257 .63303 m .34334 .63218 L .34258 .63231 L F
.802 .966 .655 r
.34308 .63008 m .34253 .63308 L .34518 .62907 L F
.34253 .63308 m .34253 .6331 L .34257 .63303 L F
.34253 .63308 m .34257 .63303 L .34518 .62907 L F
.628 .636 .839 r
.34383 .6321 m .34518 .62907 L .34257 .63303 L F
.34383 .6321 m .34257 .63303 L .34253 .6331 L F
.593 .259 .374 r
.34241 .63499 m .34383 .6321 L .34133 .63396 L F
0 0 0 r
.34241 .63499 m .34253 .63308 L .34308 .63008 L F
.593 .259 .374 r
.34254 .63303 m .34258 .63231 L .34003 .63272 L F
.34257 .63303 m .34258 .63231 L .34254 .63303 L F
.128 0 0 r
.5586 .36133 m .56034 .3613 L .56122 .35907 L F
.093 .187 .671 r
.56122 .35907 m .56276 .35699 L .56052 .35512 L F
.9 .673 .586 r
.4111 .47505 m .41418 .47579 L .41408 .47278 L F
.125 0 0 r
.418 .45776 m .42188 .45487 L .41945 .45583 L F
.867 .794 .777 r
.29779 .66852 m .30046 .66991 L .29846 .67229 L F
0 0 .438 r
.38755 .54113 m .38912 .54505 L .38753 .54198 L F
.61 .425 .606 r
.27487 .55609 m .27465 .55892 L .27046 .55955 L F
.063 0 .33 r
.27255 .56032 m .27046 .55955 L .27465 .55892 L F
.27255 .56032 m .27115 .56139 L .27046 .55955 L F
.427 .082 .275 r
.40041 .46555 m .4031 .46507 L .40391 .46313 L F
.157 0 .147 r
.40391 .46313 m .40537 .46394 L .4061 .46212 L F
.40391 .46313 m .4031 .46507 L .40537 .46394 L F
.764 .731 .822 r
.54584 .46247 m .54265 .46546 L .54673 .46601 L F
.633 .838 .979 r
.28618 .63467 m .28527 .63701 L .28362 .63562 L F
.28618 .63467 m .28811 .63597 L .28527 .63701 L F
.699 .983 .877 r
.57318 .39846 m .57098 .4003 L .5702 .39937 L F
.57318 .39846 m .5702 .39937 L .57044 .39899 L F
.57044 .39899 m .5702 .39937 L .56996 .39908 L F
.57318 .39846 m .57315 .39846 L .57229 .40005 L F
.57315 .39846 m .56996 .39908 L .57229 .40005 L F
.344 .553 .911 r
.5732 .3979 m .57229 .40005 L .57098 .3981 L F
.678 .799 .339 r
.57191 .40076 m .57229 .40005 L .5732 .3979 L F
.57122 .40228 m .57229 .40005 L .57191 .40076 L F
.344 .553 .911 r
.57105 .39799 m .57098 .3981 L .5709 .39799 L F
.5732 .3979 m .57098 .3981 L .57105 .39799 L F
.403 .588 .917 r
.64514 .35039 m .64585 .35257 L .64353 .35264 L F
.64514 .35039 m .64585 .35257 L .64353 .35264 L F
.566 .929 .777 r
.46522 .43697 m .46404 .43833 L .46715 .43592 L F
.46522 .43697 m .46317 .43846 L .46404 .43833 L F
0 0 0 r
.5846 .38879 m .58402 .39196 L .58446 .39034 L F
0 0 .318 r
.58402 .39196 m .58488 .39461 L .58446 .39034 L F
.836 .799 .816 r
.44131 .57843 m .44624 .57643 L .44384 .57497 L F
.67 .483 .624 r
.38288 .57842 m .3802 .57934 L .38281 .57632 L F
.825 .606 .607 r
.38281 .57632 m .38436 .57897 L .38288 .57842 L F
.07 0 0 r
.61345 .34464 m .61623 .34474 L .61763 .34467 L F
.27 .776 .825 r
.61623 .34474 m .62025 .34412 L .61763 .34467 L F
.684 .499 .63 r
.65555 .34582 m .65317 .34895 L .65292 .34621 L F
.002 .47 .867 r
.4957 .43965 m .49754 .43944 L .4945 .43788 L F
.4957 .43965 m .49935 .44099 L .49754 .43944 L F
.18 .469 .889 r
.4957 .43965 m .4998 .44291 L .49935 .44099 L F
.29 0 0 r
.41789 .56773 m .42213 .56772 L .42238 .56637 L F
0 0 0 r
.42238 .56637 m .42301 .56585 L .42552 .5675 L F
.42238 .56637 m .42213 .56772 L .42301 .56585 L F
.758 .782 .872 r
.31488 .69271 m .31577 .68839 L .31438 .6901 L F
.693 .822 .945 r
.58257 .37865 m .58375 .38013 L .58642 .37902 L F
.757 .837 .913 r
.34242 .61759 m .34385 .61919 L .33965 .61912 L F
0 .054 .611 r
.34484 .61722 m .34385 .61919 L .34242 .61759 L F
.34484 .61722 m .34577 .61968 L .34385 .61919 L F
.708 .198 0 r
.38436 .57897 m .38396 .58196 L .38288 .57842 L F
.38436 .57897 m .38524 .5808 L .38396 .58196 L F
.38436 .57897 m .38683 .58196 L .38524 .5808 L F
.536 .648 .907 r
.38524 .5808 m .3869 .57715 L .38349 .57953 L F
.38524 .5808 m .38349 .57953 L .38335 .57963 L F
.708 .198 0 r
.38683 .58196 m .38701 .58218 L .38524 .5808 L F
.714 .531 .64 r
.39833 .53223 m .39925 .53588 L .40148 .53266 L F
0 0 0 r
.40148 .53266 m .4024 .53085 L .40266 .52974 L F
.431 .723 .987 r
.40148 .53266 m .40425 .53237 L .4024 .53085 L F
.13 0 .097 r
.40561 .56904 m .40761 .5683 L .40877 .56601 L F
0 0 .473 r
.40877 .56601 m .40915 .56494 L .4074 .56211 L F
.314 .324 .711 r
.40761 .5683 m .40915 .56494 L .40877 .56601 L F
.885 .6 .5 r
.35548 .5285 m .353 .52513 L .35691 .52551 L F
.803 .692 .742 r
.39289 .53181 m .3946 .53548 L .39833 .53223 L F
.715 .532 .64 r
.3946 .53548 m .39925 .53588 L .39833 .53223 L F
.996 .827 .559 r
.39923 .54396 m .40131 .54292 L .40014 .5407 L F
.39923 .54396 m .40054 .54535 L .40131 .54292 L F
.631 .842 .981 r
.49598 .49149 m .49185 .49094 L .49551 .4875 L F
.631 .628 .829 r
.49958 .48955 m .49598 .49149 L .49551 .4875 L F
.781 .428 .389 r
.38873 .53112 m .39307 .52978 L .38925 .52825 L F
.38873 .53112 m .39289 .53181 L .39307 .52978 L F
.467 .892 .841 r
.54326 .42131 m .54065 .42253 L .53996 .42233 L F
.677 .171 .033 r
.54065 .42253 m .53928 .42386 L .53996 .42233 L F
.54065 .42253 m .54328 .42472 L .53928 .42386 L F
.553 .109 .151 r
.65696 .33572 m .65991 .33727 L .6613 .33527 L F
.64 .206 .202 r
.6613 .33527 m .66416 .33746 L .66378 .33619 L F
.6613 .33527 m .65991 .33727 L .66416 .33746 L F
.469 .221 .454 r
.4998 .44291 m .50326 .44215 L .50233 .4434 L F
.3 .53 .907 r
.49935 .44099 m .4998 .44291 L .50233 .4434 L F
0 0 0 r
.4516 .55324 m .45342 .55165 L .45007 .55485 L F
.909 .776 .702 r
.33597 .53864 m .33732 .54245 L .33814 .53977 L F
.928 .954 .627 r
.47856 .50578 m .47676 .50968 L .47685 .50703 L F
.815 .966 .649 r
.4794 .50333 m .47856 .50578 L .47685 .50703 L F
0 0 .467 r
.53817 .39965 m .53901 .40188 L .53797 .39645 L F
.564 .794 .985 r
.29085 .64644 m .29202 .64438 L .28942 .64477 L F
.29085 .64644 m .29351 .64598 L .29202 .64438 L F
.437 .876 .849 r
.50028 .39861 m .5021 .39736 L .50416 .3962 L F
.50028 .39861 m .49946 .39854 L .5021 .39736 L F
.496 .624 .907 r
.53372 .37986 m .53325 .38204 L .53193 .3826 L F
.401 .196 .483 r
.2682 .54267 m .27063 .54194 L .27088 .53915 L F
.388 .173 .461 r
.2682 .54267 m .27027 .54463 L .27063 .54194 L F
.2682 .54267 m .26792 .54541 L .27027 .54463 L F
.96 .824 .665 r
.46569 .52307 m .46332 .52433 L .46381 .52172 L F
.46569 .52307 m .465 .52567 L .46332 .52433 L F
.834 .799 .818 r
.46825 .5197 m .46569 .52307 L .46381 .52172 L F
0 0 .297 r
.35371 .63972 m .35375 .63556 L .35263 .63799 L F
.939 .94 .765 r
.35081 .64175 m .35371 .63972 L .35263 .63799 L F
.35081 .64175 m .35231 .64222 L .35371 .63972 L F
.628 .636 .839 r
.34383 .6321 m .3469 .63316 L .34518 .62907 L F
.673 .18 .07 r
.34413 .63425 m .34383 .6321 L .34241 .63499 L F
.34413 .63425 m .3469 .63316 L .34383 .6321 L F
.652 .894 .555 r
.58547 .40578 m .58279 .40907 L .58412 .407 L F
0 0 0 r
.58412 .407 m .58279 .40907 L .58208 .41175 L F
.881 .557 .432 r
.31816 .52439 m .31535 .52497 L .3151 .52211 L F
.943 .775 .643 r
.3164 .528 m .31535 .52497 L .31816 .52439 L F
.458 .805 .998 r
.30199 .68616 m .30707 .68684 L .30514 .68596 L F
.766 .925 .94 r
.30514 .68596 m .30707 .68684 L .30893 .68522 L F
.828 .862 .871 r
.51465 .47637 m .51147 .4794 L .50963 .47808 L F
.526 .076 .124 r
.50834 .45298 m .51033 .45519 L .51264 .45208 L F
.51033 .45519 m .51037 .45519 L .51264 .45208 L F
.51037 .45519 m .51039 .45519 L .51069 .45477 L F
.51037 .45519 m .51069 .45477 L .51264 .45208 L F
.968 .902 .541 r
.51033 .45272 m .51035 .45521 L .51037 .45519 L F
0 .013 .567 r
.51033 .45272 m .51036 .45523 L .51035 .45521 L F
.51033 .45272 m .51035 .45521 L .50834 .45298 L F
.968 .902 .541 r
.51033 .45272 m .50972 .45603 L .51035 .45521 L F
.51033 .45272 m .50946 .45538 L .50972 .45603 L F
.51037 .45519 m .50972 .45603 L .51041 .45771 L F
.758 .677 .772 r
.51041 .45771 m .5124 .45795 L .51406 .45373 L F
.51041 .45771 m .51406 .45373 L .51385 .45426 L F
.377 0 .038 r
.51264 .45208 m .51036 .45523 L .51385 .45426 L F
.968 .902 .541 r
.51033 .45272 m .51037 .45519 L .51385 .45426 L F
.51037 .45519 m .51041 .45771 L .51328 .45482 L F
.51037 .45519 m .51328 .45482 L .51385 .45426 L F
.526 .076 .124 r
.51033 .45519 m .51036 .45523 L .51039 .45519 L F
.377 0 .038 r
.51264 .45208 m .51385 .45426 L .51406 .45373 L F
.664 .346 .425 r
.43051 .45929 m .43031 .46132 L .42642 .46206 L F
.524 .227 .404 r
.43051 .45929 m .43299 .46119 L .43031 .46132 L F
.554 .212 .342 r
.43051 .45929 m .43414 .45928 L .43299 .46119 L F
.651 .165 .084 r
.31647 .64451 m .31777 .6434 L .31415 .64257 L F
.627 .549 .747 r
.31777 .6434 m .31936 .6434 L .32003 .63869 L F
.253 0 0 r
.31876 .64407 m .31777 .6434 L .31647 .64451 L F
.31876 .64407 m .31936 .6434 L .31777 .6434 L F
.655 .531 .701 r
.52671 .38961 m .52993 .38932 L .52929 .38647 L F
0 0 0 r
.52671 .38961 m .52868 .38832 L .52929 .38647 L F
.629 .407 .562 r
.52497 .39058 m .52868 .38832 L .52671 .38961 L F
.184 .336 .783 r
.52935 .39133 m .52671 .38961 L .52993 .38932 L F
.461 .826 .994 r
.52671 .38961 m .52868 .38832 L .52993 .38932 L F
.598 .029 0 r
.40974 .54022 m .40811 .54061 L .41074 .54116 L F
.067 .631 .747 r
.51521 .42441 m .51704 .42444 L .51278 .42458 L F
.826 .998 .841 r
.51882 .4219 m .51704 .42444 L .51521 .42441 L F
.433 .465 .793 r
.51914 .42492 m .51704 .42444 L .51882 .4219 L F
0 0 .202 r
.28907 .52827 m .28847 .53166 L .2872 .53245 L F
.796 .509 0 r
.28702 .53336 m .28777 .53543 L .2872 .53245 L F
.28723 .53312 m .2872 .53245 L .28847 .53166 L F
.348 .373 .745 r
.29073 .52734 m .28907 .52827 L .28748 .5254 L F
.313 .112 .44 r
.29043 .5309 m .28907 .52827 L .29073 .52734 L F
.29043 .5309 m .28847 .53166 L .28907 .52827 L F
.075 0 0 r
.29043 .5309 m .28702 .53336 L .28847 .53166 L F
.646 .847 .977 r
.29235 .52954 m .29043 .5309 L .29073 .52734 L F
.548 .462 .71 r
.28549 .52492 m .28814 .53226 L .29164 .52895 L F
.28814 .53226 m .28818 .53238 L .29115 .52944 L F
.28814 .53226 m .29115 .52944 L .29164 .52895 L F
.796 .509 0 r
.28702 .53336 m .28703 .5333 L .28723 .53312 L F
.28703 .5333 m .2872 .53245 L .28723 .53312 L F
.97 .722 .505 r
.57378 .37184 m .57367 .37505 L .57548 .376 L F
.824 .346 0 r
.57367 .37505 m .57441 .37657 L .57548 .376 L F
0 0 .544 r
.57685 .37713 m .5776 .37852 L .57548 .376 L F
.373 .177 .482 r
.57548 .376 m .5776 .37852 L .57572 .3794 L F
0 0 .544 r
.57685 .37713 m .57548 .376 L .57441 .37657 L F
0 0 .057 r
.5999 .35776 m .60242 .35559 L .60004 .35712 L F
.699 .803 .929 r
.60347 .35353 m .60242 .35559 L .60375 .35401 L F
.832 .992 .741 r
.60347 .35353 m .60004 .35712 L .60242 .35559 L F
.299 .569 .932 r
.31347 .53847 m .31593 .54307 L .31361 .5404 L F
.859 .87 .846 r
.31786 .53819 m .31593 .54307 L .31347 .53847 L F
.6 .942 .937 r
.31836 .54141 m .31593 .54307 L .31786 .53819 L F
.776 .521 .55 r
.30582 .65843 m .31027 .65599 L .30644 .65625 L F
.30582 .65843 m .30998 .65898 L .31027 .65599 L F
.919 .741 .646 r
.30998 .65898 m .31172 .66266 L .31154 .66088 L F
.343 0 .054 r
.31477 .66022 m .31154 .66088 L .31172 .66266 L F
.679 .658 .823 r
.31477 .66022 m .31172 .66266 L .30998 .65898 L F
.475 .281 .537 r
.30153 .61598 m .3004 .61231 L .29961 .61398 L F
.779 .679 .753 r
.29227 .65818 m .2943 .66205 L .28962 .66199 L F
.676 .649 .815 r
.2955 .65679 m .29341 .65996 L .29227 .65818 L F
.472 .536 .842 r
.29483 .66028 m .29389 .65951 L .29341 .65996 L F
0 0 .088 r
.29576 .65743 m .29341 .65996 L .2955 .65679 L F
.29585 .65767 m .29389 .65951 L .29576 .65743 L F
.29389 .65951 m .29341 .65996 L .29576 .65743 L F
.472 .536 .842 r
.29673 .66182 m .2943 .66205 L .29331 .66016 L F
.29351 .65994 m .29331 .66016 L .29306 .65968 L F
.29673 .66182 m .29331 .66016 L .29351 .65994 L F
.29389 .65951 m .29227 .65818 L .29341 .65996 L F
0 0 .088 r
.29611 .65831 m .29358 .65986 L .29585 .65767 L F
.29358 .65986 m .29341 .65996 L .29389 .65951 L F
.29358 .65986 m .29389 .65951 L .29585 .65767 L F
.472 .536 .842 r
.29389 .65951 m .29306 .65968 L .29227 .65818 L F
.29483 .66028 m .29358 .65986 L .29389 .65951 L F
.29358 .65986 m .29306 .65968 L .29389 .65951 L F
.441 .518 .842 r
.29483 .66028 m .29341 .65996 L .29358 .65986 L F
.29896 .6615 m .29341 .65996 L .29862 .66111 L F
.29896 .6615 m .29673 .66182 L .29341 .65996 L F
.472 .536 .842 r
.29673 .66182 m .29483 .66028 L .29341 .65996 L F
.29673 .66182 m .29306 .65968 L .29483 .66028 L F
.441 .518 .842 r
.29862 .66111 m .29483 .66028 L .29611 .65831 L F
.29483 .66028 m .29358 .65986 L .29611 .65831 L F
.741 .876 .942 r
.29509 .63346 m .29014 .63431 L .29346 .63238 L F
.646 .881 .984 r
.29747 .63233 m .29509 .63346 L .29346 .63238 L F
.942 .798 .673 r
.44601 .54358 m .4482 .54959 L .44513 .54783 L F
.44601 .54358 m .44832 .5444 L .4482 .54959 L F
.705 .781 .911 r
.44513 .54783 m .4482 .54959 L .4463 .54974 L F
.925 .956 .786 r
.43859 .58296 m .44039 .58325 L .44022 .58094 L F
.602 .593 .815 r
.28601 .67244 m .28923 .67544 L .28755 .67343 L F
.018 0 0 r
.28923 .67544 m .28565 .67888 L .28796 .67754 L F
0 .219 .731 r
.28755 .67343 m .28923 .67544 L .28989 .67488 L F
0 0 0 r
.28989 .67488 m .28923 .67544 L .28796 .67754 L F
.171 0 0 r
.41097 .59437 m .40874 .59447 L .406 .59426 L F
.406 .695 .979 r
.406 .59426 m .40874 .59447 L .4086 .59433 L F
.766 .76 .847 r
.40201 .59416 m .40798 .59412 L .406 .59426 L F
.406 .695 .979 r
.406 .59426 m .4086 .59433 L .40699 .59264 L F
.766 .76 .847 r
.40118 .59416 m .40201 .59416 L .406 .59426 L F
.195 .222 .662 r
.57564 .35897 m .57768 .35704 L .5766 .35429 L F
.232 .282 .709 r
.57564 .35897 m .57837 .36103 L .57768 .35704 L F
.203 .238 .676 r
.57154 .36363 m .56966 .36612 L .56925 .36175 L F
.25 .304 .724 r
.57154 .36363 m .57249 .36811 L .56966 .36612 L F
.847 .386 .073 r
.54522 .42567 m .54859 .429 L .54751 .42784 L F
.861 .813 .801 r
.54859 .429 m .5443 .43095 L .54751 .42784 L F
.54859 .429 m .54617 .4325 L .5443 .43095 L F
.867 .773 .756 r
.54617 .4325 m .54259 .43254 L .5443 .43095 L F
.54617 .4325 m .54412 .43622 L .54259 .43254 L F
.682 .314 .343 r
.35217 .64447 m .35472 .64514 L .35231 .64222 L F
.546 .294 .485 r
.30827 .52277 m .30559 .52589 L .30857 .52532 L F
.812 .98 .893 r
.31154 .51929 m .30827 .52277 L .30826 .51996 L F
.753 .535 0 r
.30827 .52277 m .30809 .52247 L .30826 .51996 L F
.30827 .52277 m .30857 .52532 L .30809 .52247 L F
.62 .358 .499 r
.28858 .55388 m .2909 .55534 L .28819 .55487 L F
.28858 .55388 m .2909 .55534 L .28819 .55487 L F
.683 .87 .97 r
.59198 .40463 m .59535 .40325 L .59384 .40158 L F
0 .353 .73 r
.39222 .57245 m .39452 .57323 L .39578 .57417 L F
.063 .51 .895 r
.39758 .57376 m .39578 .57417 L .39452 .57323 L F
.916 .844 .758 r
.54889 .45101 m .55102 .44947 L .54964 .44895 L F
.973 .835 .646 r
.41622 .56126 m .41669 .56356 L .41738 .56235 L F
.914 .938 .808 r
.55416 .43899 m .55681 .43523 L .55553 .43419 L F
.914 .937 .809 r
.55681 .43523 m .5581 .43034 L .55553 .43419 L F
.898 .729 .664 r
.58521 .35038 m .58854 .35343 L .58789 .34981 L F
.939 .569 .228 r
.58521 .35038 m .58782 .35446 L .58854 .35343 L F
.487 .456 .748 r
.58789 .34981 m .58854 .35343 L .59063 .35166 L F
.382 .139 .417 r
.58782 .35446 m .59063 .35166 L .58854 .35343 L F
.298 .791 .874 r
.62296 .34373 m .6257 .34316 L .62745 .3435 L F
.444 .877 .899 r
.62745 .3435 m .62839 .34216 L .62947 .34279 L F
.62745 .3435 m .6257 .34316 L .62839 .34216 L F
.803 .775 .828 r
.3469 .63316 m .34825 .6278 L .34518 .62907 L F
.3469 .63316 m .35001 .63025 L .34825 .6278 L F
.286 0 0 r
.34869 .63343 m .3469 .63316 L .34413 .63425 L F
.872 .705 .671 r
.36919 .55214 m .36574 .55158 L .3665 .54875 L F
.867 .634 .584 r
.36919 .55214 m .36547 .55445 L .36574 .55158 L F
.36919 .55214 m .36845 .55544 L .36547 .55445 L F
.96 .775 .609 r
.54583 .45702 m .54805 .45594 L .54645 .45466 L F
.54583 .45702 m .54772 .45876 L .54805 .45594 L F
.605 .475 .677 r
.27745 .55297 m .27787 .55594 L .27487 .55609 L F
.597 .413 .603 r
.27787 .55594 m .27465 .55892 L .27487 .55609 L F
.27787 .55594 m .27465 .55892 L .27487 .55609 L F
.537 .322 .536 r
.317 .65588 m .31985 .65564 L .31994 .65259 L F
.395 .209 .507 r
.31994 .65259 m .31985 .65564 L .3222 .65195 L F
.243 0 .321 r
.52633 .37529 m .52364 .37869 L .52461 .37649 L F
0 .029 .599 r
.56876 .35646 m .56949 .35717 L .56948 .35927 L F
0 0 .01 r
.56984 .35828 m .56948 .35927 L .56949 .35717 L F
.56984 .35828 m .56925 .36175 L .56948 .35927 L F
.089 .229 .715 r
.56984 .35828 m .57154 .36363 L .56925 .36175 L F
.104 .128 .601 r
.57256 .35884 m .57154 .36363 L .56984 .35828 L F
.559 .014 0 r
.56949 .35717 m .56838 .35833 L .57102 .35865 L F
.521 .235 .421 r
.56949 .35717 m .57256 .35884 L .56984 .35828 L F
.559 .014 0 r
.56949 .35717 m .57102 .35865 L .57256 .35884 L F
0 .029 .599 r
.5685 .35544 m .56949 .35717 L .56876 .35646 L F
.922 .729 .624 r
.33701 .54529 m .33513 .54841 L .33799 .54896 L F
.859 .687 .668 r
.33513 .54841 m .33915 .55115 L .33799 .54896 L F
.854 .828 .821 r
.46356 .54097 m .4621 .54208 L .46568 .54219 L F
.83 .959 .895 r
.46077 .54431 m .46568 .54219 L .4621 .54208 L F
.861 .825 .811 r
.46356 .54097 m .46568 .54219 L .46815 .53828 L F
0 .128 .67 r
.58938 .3949 m .59179 .39709 L .59183 .39835 L F
.666 .214 0 r
.59261 .40002 m .59183 .39835 L .59179 .39709 L F
.59261 .40002 m .59339 .40086 L .59183 .39835 L F
.719 .426 0 r
.59122 .39532 m .59261 .40002 L .59179 .39709 L F
.102 .237 .719 r
.59362 .39745 m .59261 .40002 L .59122 .39532 L F
.756 .972 .925 r
.59174 .39908 m .59261 .40002 L .59362 .39745 L F
.5917 .39912 m .59261 .40002 L .59174 .39908 L F
.666 .214 0 r
.59261 .40002 m .59384 .40158 L .59339 .40086 L F
.706 .892 .965 r
.50372 .42832 m .49958 .42893 L .50164 .43018 L F
.064 0 0 r
.5076 .42567 m .50372 .42832 L .50642 .42657 L F
0 0 0 r
.50642 .42657 m .50372 .42832 L .50164 .43018 L F
.786 .956 .925 r
.50603 .43345 m .50569 .43598 L .50741 .4343 L F
0 0 0 r
.50569 .43598 m .50867 .4332 L .50741 .4343 L F
.49726 .40196 m .49867 .40008 L .49946 .39854 L F
.576 .825 .453 r
.49726 .40196 m .49723 .40196 L .49867 .40008 L F
.693 .461 .567 r
.29005 .65937 m .28962 .66199 L .28816 .66245 L F
.779 .679 .753 r
.29227 .65818 m .28962 .66199 L .29005 .65937 L F
.191 .075 .483 r
.2679 .56276 m .26709 .56889 L .26659 .56904 L F
.318 .107 .428 r
.27115 .56139 m .27072 .56447 L .2679 .56276 L F
0 0 .374 r
.26965 .56672 m .2679 .56276 L .27072 .56447 L F
.26965 .56672 m .26709 .56889 L .2679 .56276 L F
.107 0 .18 r
.55807 .41152 m .55605 .41277 L .55539 .41469 L F
.608 .922 .677 r
.46715 .43592 m .47025 .43321 L .46849 .43425 L F
.612 .931 .704 r
.46522 .43697 m .46715 .43592 L .46849 .43425 L F
.963 .646 .37 r
.37747 .58326 m .37574 .58429 L .37511 .58201 L F
.099 0 0 r
.38046 .58478 m .37574 .58429 L .37747 .58326 L F
.845 .709 .713 r
.36893 .56208 m .37056 .56599 L .36842 .56476 L F
.883 .807 .77 r
.37056 .56599 m .36624 .56826 L .36842 .56476 L F
.37056 .56599 m .3681 .56915 L .36624 .56826 L F
.747 .994 .832 r
.28528 .53786 m .28817 .53924 L .28635 .53807 L F
.487 .332 .596 r
.30128 .59926 m .30178 .60227 L .30373 .59852 L F
.34 .064 .341 r
.3934 .47399 m .39111 .47269 L .39603 .47209 L F
.603 .139 .125 r
.39842 .47359 m .3934 .47399 L .39603 .47209 L F
.771 .845 .907 r
.5076 .42567 m .50722 .42267 L .50565 .42144 L F
.5076 .42567 m .50926 .42431 L .50722 .42267 L F
0 0 0 r
.50769 .42648 m .5076 .42567 L .50642 .42657 L F
.50769 .42648 m .50735 .42831 L .5076 .42567 L F
.983 .862 .641 r
.55205 .44023 m .55416 .43899 L .55324 .43787 L F
.55205 .44023 m .55298 .4429 L .55416 .43899 L F
.914 .938 .808 r
.55416 .43899 m .55553 .43419 L .55324 .43787 L F
0 0 0 r
.43308 .44757 m .4348 .44634 L .43134 .44876 L F
.43698 .44503 m .4348 .44634 L .43308 .44757 L F
.707 .638 .777 r
.29846 .67229 m .29681 .67316 L .29508 .67115 L F
0 0 0 r
.32101 .645 m .31785 .64781 L .31907 .64629 L F
.691 .829 .949 r
.33701 .62143 m .33302 .62108 L .33561 .61854 L F
.715 .791 .911 r
.33965 .61912 m .33701 .62143 L .33561 .61854 L F
.326 0 .109 r
.39364 .46878 m .39629 .46823 L .39791 .46602 L F
.371 0 .009 r
.39886 .46754 m .39791 .46602 L .39629 .46823 L F
.39886 .46754 m .40041 .46555 L .39791 .46602 L F
.901 .854 .787 r
.27236 .65119 m .27192 .65606 L .27199 .65255 L F
.067 .15 .642 r
.27199 .65255 m .27192 .65606 L .27397 .65859 L F
.158 .604 .934 r
.607 .34435 m .60931 .34465 L .61066 .34581 L F
.46 .846 .982 r
.60931 .34465 m .61345 .34464 L .61066 .34581 L F
.917 .975 .771 r
.35133 .65873 m .35241 .65914 L .35445 .65539 L F
.917 .964 .793 r
.47676 .50968 m .47448 .51302 L .47407 .51066 L F
.912 .924 .542 r
.473 .51516 m .47407 .51066 L .47448 .51302 L F
.896 .979 .81 r
.47676 .50968 m .47407 .51066 L .47685 .50703 L F
.097 .654 .766 r
.61424 .35003 m .61473 .34982 L .60916 .35022 L F
.791 .351 .203 r
.61682 .35023 m .61473 .34982 L .61424 .35003 L F
.633 .071 0 r
.61473 .34982 m .61589 .35038 L .61435 .34974 L F
.376 .741 .99 r
.60916 .35022 m .61473 .34982 L .61215 .34883 L F
.633 .071 0 r
.61473 .34982 m .61435 .34974 L .61215 .34883 L F
.791 .351 .203 r
.61762 .35029 m .61473 .34982 L .61682 .35023 L F
.897 .692 .616 r
.41328 .55532 m .41267 .55804 L .41638 .55917 L F
.848 .616 .587 r
.41267 .55804 m .41622 .56126 L .41638 .55917 L F
.876 .993 .759 r
.65836 .38611 m .66074 .38287 L .65882 .38343 L F
.834 .869 .424 r
.65734 .38855 m .65836 .38611 L .65882 .38343 L F
.887 .803 .76 r
.65513 .3586 m .6557 .36258 L .65397 .36144 L F
.852 .638 .612 r
.67915 .36163 m .68137 .36294 L .67904 .35889 L F
.862 .687 .662 r
.67696 .36483 m .68137 .36294 L .67915 .36163 L F
.67696 .36483 m .68045 .36526 L .68137 .36294 L F
.792 .897 .917 r
.56172 .42555 m .56339 .42673 L .56351 .42342 L F
.822 .579 .571 r
.35937 .52924 m .3555 .5311 L .35548 .5285 L F
.35937 .52924 m .35915 .53198 L .3555 .5311 L F
.322 .045 .329 r
.40259 .57248 m .40539 .57179 L .40561 .56904 L F
.248 0 .311 r
.40561 .56904 m .40759 .57072 L .40761 .5683 L F
.40561 .56904 m .40539 .57179 L .40759 .57072 L F
.514 .012 0 r
.27474 .66941 m .27718 .6719 L .27611 .6708 L F
.329 .538 .905 r
.27474 .66941 m .27876 .67218 L .27718 .6719 L F
0 0 .397 r
.27585 .66492 m .27474 .66941 L .27611 .6708 L F
.736 .354 .327 r
.3886 .47221 m .39082 .47495 L .38636 .47398 L F
.685 .358 .415 r
.39111 .47269 m .39082 .47495 L .3886 .47221 L F
.775 .846 .906 r
.52546 .46292 m .52182 .46533 L .52015 .46269 L F
.84 .705 .715 r
.35565 .50476 m .36036 .50211 L .3592 .50075 L F
.35565 .50476 m .35875 .50598 L .36036 .50211 L F
.436 .868 .772 r
.65182 .37562 m .65407 .3742 L .65401 .37448 L F
0 0 0 r
.65067 .37676 m .65407 .3742 L .65182 .37562 L F
.924 .888 .778 r
.31249 .64097 m .31645 .63703 L .31514 .63615 L F
.442 .79 .998 r
.31514 .63615 m .31645 .63703 L .31819 .63622 L F
.54 .541 .804 r
.31645 .63703 m .32003 .63869 L .31819 .63622 L F
.847 .898 .873 r
.49358 .50757 m .49916 .50485 L .49782 .50432 L F
.825 .988 .873 r
.49916 .50485 m .50111 .50131 L .49782 .50432 L F
.49916 .50485 m .50202 .50208 L .50111 .50131 L F
.534 .069 .098 r
.41101 .55133 m .41427 .55126 L .4148 .54985 L F
.553 .088 .105 r
.41427 .55126 m .41783 .55133 L .4148 .54985 L F
.189 0 0 r
.62623 .34871 m .62442 .34996 L .62171 .34989 L F
.408 0 0 r
.62831 .34847 m .62442 .34996 L .62623 .34871 L F
.193 .284 .73 r
.34728 .49942 m .34847 .49885 L .34782 .49673 L F
.431 .723 .987 r
.34567 .49695 m .34715 .49819 L .34482 .49883 L F
.3474 .49812 m .34731 .49884 L .34482 .49883 L F
.352 .737 .986 r
.34482 .49883 m .34731 .49884 L .34728 .49942 L F
0 .18 .706 r
.34679 .50046 m .34482 .49883 L .34728 .49942 L F
.934 .807 .696 r
.34567 .49695 m .34679 .50046 L .34737 .49837 L F
.34567 .49695 m .34737 .49837 L .34782 .49673 L F
.431 .723 .987 r
.34567 .49695 m .3474 .49812 L .34715 .49819 L F
.3474 .49812 m .34847 .49885 L .34731 .49884 L F
.787 .791 .294 r
.34782 .49673 m .34737 .49837 L .34728 .49942 L F
.34737 .49837 m .34733 .49851 L .34731 .49884 L F
.34737 .49837 m .34731 .49884 L .34728 .49942 L F
.34733 .49851 m .34679 .50046 L .34728 .49942 L F
.352 .737 .986 r
.34731 .49884 m .34847 .49885 L .34728 .49942 L F
.78 .994 .873 r
.57051 .38859 m .5687 .39112 L .57169 .3897 L F
.57051 .38859 m .56745 .39122 L .5687 .39112 L F
.095 0 0 r
.62487 .39531 m .62455 .39535 L .61962 .39517 L F
.374 .839 .804 r
.62766 .39432 m .62455 .39535 L .62487 .39531 L F
.709 .909 .965 r
.57256 .38711 m .57169 .3897 L .57435 .38855 L F
.57256 .38711 m .57051 .38859 L .57169 .3897 L F
.658 .73 .902 r
.34825 .6278 m .35001 .63025 L .35216 .6288 L F
.026 0 .35 r
.52421 .38123 m .52172 .38508 L .52096 .38208 L F
.52421 .38123 m .52362 .38397 L .52172 .38508 L F
0 0 0 r
.52362 .38397 m .52051 .3871 L .52172 .38508 L F
.014 0 0 r
.2834 .52469 m .28792 .52252 L .28389 .52251 L F
.2834 .52469 m .28585 .52406 L .28792 .52252 L F
.342 .66 .972 r
.31035 .64082 m .31415 .64257 L .31236 .64155 L F
.979 .757 .532 r
.31415 .64257 m .31442 .64496 L .31236 .64155 L F
.683 .591 .747 r
.28675 .51885 m .28792 .52252 L .29085 .51977 L F
.995 .783 .504 r
.28792 .52252 m .28585 .52406 L .28748 .5254 L F
.979 .726 .481 r
.31236 .64155 m .31415 .64257 L .31249 .64097 L F
.3 .268 .655 r
.31415 .64257 m .31442 .64496 L .31647 .64451 L F
.542 0 0 r
.31647 .64451 m .31415 .64257 L .31236 .64155 L F
.851 .645 .624 r
.36505 .53928 m .36088 .54132 L .36138 .53849 L F
.36505 .53928 m .36447 .5421 L .36088 .54132 L F
.974 .886 .681 r
.35028 .62236 m .35146 .61957 L .35053 .61753 L F
.834 .799 .818 r
.46825 .5197 m .46381 .52172 L .46655 .51806 L F
.665 .739 .906 r
.47089 .51885 m .46825 .5197 L .46655 .51806 L F
.926 .855 .753 r
.30944 .64502 m .31035 .64082 L .30845 .64343 L F
.877 .483 .284 r
.30813 .64496 m .30944 .64502 L .30845 .64343 L F
0 .239 .733 r
.54225 .41239 m .546 .41563 L .54227 .41507 L F
0 0 .199 r
.54308 .4106 m .54225 .41239 L .54227 .41507 L F
.737 .973 .72 r
.50416 .3962 m .50511 .39422 L .50555 .39434 L F
.50416 .3962 m .5021 .39736 L .50511 .39422 L F
.957 .779 .62 r
.32399 .5426 m .32344 .54541 L .32208 .54151 L F
.675 .822 .954 r
.41407 .59629 m .41877 .59614 L .41694 .59428 L F
.373 0 0 r
.4219 .59332 m .41694 .59428 L .41877 .59614 L F
.496 .877 .972 r
.54791 .40703 m .54921 .40518 L .54576 .40705 L F
.54791 .40703 m .55004 .40614 L .54921 .40518 L F
.723 .983 .779 r
.47411 .41987 m .47121 .42253 L .47228 .42051 L F
.717 .952 .665 r
.47228 .42051 m .47121 .42253 L .46937 .42376 L F
.895 .694 .623 r
.35216 .6288 m .35319 .62622 L .35026 .62514 L F
.875 .765 .737 r
.33549 .54173 m .33732 .54245 L .33597 .53864 L F
.971 .718 .494 r
.33549 .54173 m .33701 .54529 L .33732 .54245 L F
.799 .943 .92 r
.44529 .56193 m .44049 .56397 L .44117 .56512 L F
.886 .827 .783 r
.51833 .47142 m .51807 .46792 L .51949 .46916 L F
.968 .651 .279 r
.51949 .46916 m .51807 .46792 L .51778 .46534 L F
.918 .71 .606 r
.32362 .53546 m .32075 .53476 L .3215 .53205 L F
.906 .776 .707 r
.32362 .53546 m .3221 .53873 L .32075 .53476 L F
.203 0 .26 r
.27088 .53915 m .27286 .53833 L .27361 .53594 L F
.249 .073 .435 r
.27088 .53915 m .2725 .54101 L .27286 .53833 L F
.27088 .53915 m .27063 .54194 L .2725 .54101 L F
.993 .877 .565 r
.317 .65588 m .316 .65909 L .31512 .65775 L F
.395 0 .091 r
.31801 .65802 m .317 .65588 L .31512 .65775 L F
.31801 .65802 m .31985 .65564 L .317 .65588 L F
.373 .803 .967 r
.3952 .49196 m .39869 .4915 L .3991 .49211 L F
.932 .868 .442 r
.39869 .4915 m .39787 .4941 L .3991 .49211 L F
.825 .944 .902 r
.51724 .4895 m .51797 .48637 L .51584 .48846 L F
.51724 .4895 m .52027 .48683 L .51797 .48637 L F
.874 .986 .827 r
.45953 .53208 m .46145 .52792 L .46295 .52908 L F
.45953 .53208 m .45867 .53124 L .46145 .52792 L F
.741 .417 .435 r
.3788 .51784 m .38331 .51597 L .37882 .51522 L F
.3788 .51784 m .38332 .51831 L .38331 .51597 L F
.508 .875 .655 r
.46849 .43425 m .47025 .43321 L .47226 .43163 L F
.951 .826 .685 r
.42149 .57147 m .42362 .57014 L .42262 .56915 L F
.585 .423 .628 r
.42362 .57014 m .42651 .5719 L .42599 .56897 L F
.857 .542 .455 r
.5644 .39409 m .56126 .3912 L .56302 .39264 L F
.956 .694 .498 r
.37937 .56813 m .37947 .57159 L .3814 .56919 L F
.583 .84 .993 r
.37937 .56813 m .3814 .56919 L .38315 .56809 L F
.802 .436 .363 r
.3814 .56919 m .37947 .57159 L .3816 .5716 L F
.789 .644 .702 r
.3816 .5716 m .38315 .56809 L .3814 .56919 L F
.763 .992 .785 r
.66074 .38287 m .66354 .38018 L .66195 .38046 L F
.763 .993 .794 r
.65882 .38343 m .66074 .38287 L .66195 .38046 L F
.936 .787 .67 r
.31236 .64155 m .31442 .64496 L .31181 .64449 L F
.941 .731 .591 r
.31181 .64449 m .31442 .64496 L .31296 .64768 L F
.159 0 .155 r
.31296 .64768 m .31442 .64496 L .31647 .64451 L F
.605 .085 0 r
.28145 .6721 m .28601 .67244 L .28403 .67371 L F
.649 .123 0 r
.28601 .67244 m .28648 .6747 L .28403 .67371 L F
.28601 .67244 m .28755 .67343 L .28648 .6747 L F
0 0 0 r
.57626 .34786 m .5778 .34678 L .57928 .34682 L F
.57626 .34786 m .57612 .34817 L .5778 .34678 L F
.711 .909 .964 r
.54259 .43254 m .53954 .4349 L .53809 .43336 L F
.628 .66 .862 r
.54412 .43622 m .53954 .4349 L .54259 .43254 L F
.958 .902 .724 r
.66011 .36574 m .65744 .36687 L .65658 .36441 L F
.66011 .36574 m .65881 .36854 L .65744 .36687 L F
.417 .29 .599 r
.50444 .41559 m .50685 .41502 L .50663 .41179 L F
.173 .054 .466 r
.50444 .41559 m .50638 .41716 L .50685 .41502 L F
.50444 .41559 m .50471 .41823 L .50638 .41716 L F
.816 .497 .45 r
.38931 .52162 m .39127 .52427 L .39167 .52236 L F
.9 .625 .512 r
.37374 .52289 m .37515 .52632 L .37835 .52288 L F
0 0 .557 r
.37422 .5229 m .37572 .52573 L .37374 .52289 L F
.503 .346 .601 r
.37515 .52632 m .37626 .52675 L .3787 .52255 L F
0 0 .557 r
.37572 .52573 m .37626 .52675 L .37564 .5258 L F
.37572 .52573 m .37564 .5258 L .37374 .52289 L F
0 0 0 r
.37835 .52288 m .37554 .5259 L .3787 .52255 L F
.37554 .5259 m .37515 .52632 L .37561 .52583 L F
.37554 .5259 m .37561 .52583 L .3787 .52255 L F
.75 .991 .793 r
.53169 .47831 m .53243 .47674 L .53037 .47765 L F
.53169 .47831 m .53454 .4756 L .53243 .47674 L F
.914 .972 .68 r
.4694 .53414 m .46815 .53828 L .47086 .53507 L F
.829 .955 .897 r
.47255 .53128 m .47086 .53507 L .47377 .53216 L F
.47255 .53128 m .4694 .53414 L .47086 .53507 L F
.791 .821 .876 r
.3199 .59474 m .32497 .59329 L .32285 .59205 L F
.708 .753 .888 r
.3278 .62378 m .32359 .62301 L .32603 .62165 L F
.682 .693 .854 r
.32603 .62165 m .33021 .62248 L .3278 .62378 L F
.362 .694 .982 r
.28988 .68078 m .29153 .68232 L .29376 .68212 L F
.378 .825 .701 r
.48616 .49496 m .48806 .49384 L .49005 .49303 L F
0 0 0 r
.48616 .49496 m .48606 .49541 L .48806 .49384 L F
.5846 .38879 m .58446 .39034 L .58473 .38777 L F
.895 .858 .797 r
.31076 .60172 m .31422 .60265 L .31545 .5995 L F
.904 .847 .777 r
.31145 .605 m .31422 .60265 L .31076 .60172 L F
.885 .749 .707 r
.38332 .51831 m .38473 .52261 L .386 .51989 L F
.718 .563 .678 r
.386 .51989 m .38473 .52261 L .38931 .52162 L F
.053 0 0 r
.62171 .34989 m .62035 .3502 L .61762 .35029 L F
.231 0 .273 r
.27361 .53594 m .27286 .53833 L .27571 .53507 L F
.988 .719 .381 r
.37973 .53554 m .38013 .53789 L .38103 .53566 L F
0 0 .148 r
.38214 .53106 m .38103 .53566 L .38477 .53247 L F
.38214 .53106 m .38194 .53387 L .38103 .53566 L F
.666 .974 .883 r
.38194 .53387 m .37973 .53554 L .38103 .53566 L F
.678 .264 .253 r
.38013 .53789 m .38406 .53825 L .38103 .53566 L F
.988 .719 .381 r
.37973 .53554 m .38013 .53789 L .38103 .53566 L F
.536 .326 .543 r
.38103 .53566 m .38406 .53825 L .38431 .5352 L F
0 0 .293 r
.42645 .57507 m .42533 .57903 L .42776 .57845 L F
.842 .754 .766 r
.42645 .57507 m .42797 .57899 L .43102 .57483 L F
.331 .806 .907 r
.4264 .57821 m .42777 .57794 L .42983 .57795 L F
.42958 .57801 m .42983 .57795 L .43049 .57795 L F
.4264 .57821 m .42983 .57795 L .42958 .57801 L F
0 0 .293 r
.42776 .57845 m .42529 .57915 L .42797 .57899 L F
.42533 .57903 m .42529 .57915 L .42776 .57845 L F
.42645 .57507 m .4264 .57821 L .42529 .57915 L F
.293 .742 .959 r
.42529 .57915 m .4264 .57821 L .42797 .57899 L F
.562 .936 .864 r
.66354 .38018 m .66423 .37881 L .66195 .38046 L F
.66354 .38018 m .66612 .37863 L .66423 .37881 L F
.83 .741 .766 r
.51248 .47431 m .51465 .47637 L .51025 .47585 L F
.828 .862 .871 r
.51465 .47637 m .50963 .47808 L .51025 .47585 L F
.75 .742 .844 r
.51639 .47471 m .51465 .47637 L .51248 .47431 L F
.045 0 0 r
.44532 .45091 m .44097 .45366 L .44279 .45124 L F
0 0 .325 r
.52945 .41337 m .52869 .41601 L .52845 .41203 L F
.52945 .41337 m .52845 .41203 L .5268 .41133 L F
.313 .371 .763 r
.57356 .35254 m .5766 .35429 L .57556 .35016 L F
.154 0 0 r
.44588 .45007 m .44756 .45023 L .44532 .45091 L F
.44588 .45007 m .44887 .449 L .44756 .45023 L F
.554 .17 .269 r
.38473 .52261 m .38731 .52436 L .38931 .52162 L F
.816 .497 .45 r
.38931 .52162 m .38731 .52436 L .39127 .52427 L F
.93 .899 .774 r
.465 .52567 m .46145 .52792 L .46332 .52433 L F
.465 .52567 m .46295 .52908 L .46145 .52792 L F
0 0 .261 r
.32003 .63869 m .31936 .6434 L .32077 .64055 L F
.686 .854 .444 r
.32077 .64055 m .31936 .6434 L .31876 .64407 L F
.694 .151 0 r
.31936 .6434 m .32101 .645 L .31876 .64407 L F
.183 .63 .942 r
.44021 .57142 m .44395 .57221 L .44478 .57333 L F
.96 .939 .632 r
.44478 .57333 m .44395 .57221 L .44384 .57497 L F
.605 .935 .955 r
.44478 .57333 m .44582 .57119 L .44717 .57179 L F
.699 .952 .68 r
.44455 .57244 m .44478 .57333 L .44384 .57497 L F
.54 .877 .99 r
.44395 .57221 m .44582 .57119 L .44478 .57333 L F
.699 .952 .68 r
.44455 .57244 m .44582 .57119 L .44478 .57333 L F
.074 0 .132 r
.44717 .57179 m .44384 .57497 L .44478 .57333 L F
0 0 0 r
.52929 .38647 m .53069 .38636 L .53198 .38527 L F
.42 .375 .703 r
.53208 .3882 m .52993 .38932 L .52929 .38647 L F
0 0 0 r
.52929 .38647 m .52868 .38832 L .53069 .38636 L F
.707 .812 .931 r
.30702 .62948 m .30408 .63174 L .30267 .62912 L F
0 0 .279 r
.5999 .35776 m .59968 .36198 L .59886 .35914 L F
.725 .434 .484 r
.3151 .52211 m .31065 .52436 L .313 .52005 L F
.977 .728 .492 r
.30586 .58413 m .30773 .58542 L .30796 .58246 L F
.461 0 .019 r
.65297 .33731 m .65583 .3374 L .65696 .33572 L F
.556 .075 .069 r
.65696 .33572 m .65583 .3374 L .65991 .33727 L F
.877 .606 .523 r
.66829 .33852 m .6683 .34116 L .6719 .34232 L F
.822 .51 .462 r
.6682 .34381 m .6719 .34232 L .6683 .34116 L F
.6682 .34381 m .67215 .34482 L .6719 .34232 L F
.496 .315 .565 r
.28816 .66245 m .28704 .66561 L .28439 .66593 L F
.781 .291 .051 r
.28704 .66561 m .28816 .66245 L .28439 .66593 L F
.964 .733 .539 r
.38477 .53247 m .38194 .53387 L .38214 .53106 L F
.38477 .53247 m .38431 .5352 L .38194 .53387 L F
.238 0 0 r
.64351 .33911 m .64635 .33882 L .64701 .3381 L F
.137 0 0 r
.64635 .33882 m .65018 .33741 L .64701 .3381 L F
.34 .064 .341 r
.3934 .47399 m .39082 .47495 L .39111 .47269 L F
.861 .825 .811 r
.46356 .54097 m .46815 .53828 L .46717 .5382 L F
.914 .972 .68 r
.4694 .53414 m .46717 .5382 L .46815 .53828 L F
.684 .693 .852 r
.27812 .54912 m .27745 .55297 L .27713 .54871 L F
.595 .235 .328 r
.541 .4097 m .5409 .4115 L .53774 .41168 L F
.347 0 0 r
.541 .4097 m .54308 .4106 L .5409 .4115 L F
.989 .729 .366 r
.54623 .3965 m .54742 .39623 L .54449 .39456 L F
.54623 .3965 m .54748 .39859 L .54742 .39623 L F
.396 0 0 r
.56043 .40236 m .56209 .40374 L .55844 .40407 L F
.56043 .40236 m .56385 .40298 L .56209 .40374 L F
.56385 .40298 m .56367 .40321 L .56209 .40374 L F
.905 .984 .752 r
.56209 .40374 m .56367 .40321 L .56486 .39991 L F
.396 0 0 r
.56385 .40298 m .56418 .40304 L .56367 .40321 L F
.905 .984 .752 r
.56367 .40321 m .56418 .40304 L .56424 .40276 L F
0 0 0 r
.56391 .40302 m .56426 .40275 L .56379 .40305 L F
.905 .984 .752 r
.56367 .40321 m .56424 .40276 L .56486 .39991 L F
0 0 0 r
.56494 .40272 m .56631 .4014 L .56426 .40275 L F
.56494 .40272 m .56426 .40275 L .56391 .40302 L F
.56361 .40328 m .56379 .40305 L .56316 .40347 L F
.56494 .40272 m .56379 .40305 L .56361 .40328 L F
.898 .595 .463 r
.33019 .53373 m .33452 .53335 L .33033 .53104 L F
.33019 .53373 m .33402 .53562 L .33452 .53335 L F
.894 .59 .463 r
.33452 .53335 m .33402 .53562 L .33598 .53569 L F
0 0 0 r
.43218 .44961 m .43134 .44876 L .4301 .4507 L F
.43218 .44961 m .43308 .44757 L .43134 .44876 L F
.037 0 0 r
.42769 .45183 m .4301 .4507 L .43134 .44876 L F
.98 .793 .579 r
.57256 .38711 m .57484 .38582 L .57536 .38339 L F
.57256 .38711 m .57435 .38855 L .57484 .38582 L F
.399 0 .014 r
.39197 .47065 m .39142 .46882 L .38941 .47136 L F
.39197 .47065 m .39364 .46878 L .39142 .46882 L F
.738 .866 .941 r
.30707 .60645 m .30687 .60941 L .30904 .60767 L F
.834 .937 .894 r
.3052 .60866 m .30687 .60941 L .30707 .60645 L F
.072 0 .408 r
.51327 .41981 m .51093 .41913 L .51356 .41727 L F
.142 0 .179 r
.58665 .37023 m .58749 .37065 L .58469 .37187 L F
.492 .379 .653 r
.58749 .37065 m .58486 .37474 L .58469 .37187 L F
.958 .787 .628 r
.36962 .5593 m .36702 .56094 L .36773 .55816 L F
.36962 .5593 m .36893 .56208 L .36702 .56094 L F
0 0 0 r
.31084 .59585 m .30631 .5979 L .30948 .59795 L F
.686 .98 .838 r
.31312 .6842 m .31295 .6852 L .31603 .68248 L F
.593 .514 .735 r
.31295 .6852 m .31919 .68552 L .31603 .68248 L F
.169 0 .168 r
.31409 .6845 m .31312 .6842 L .31509 .6834 L F
.213 .699 .927 r
.30902 .68523 m .3137 .68583 L .31202 .6848 L F
.998 .838 .504 r
.31151 .68449 m .3137 .68583 L .31295 .6852 L F
.593 .514 .735 r
.31295 .6852 m .31647 .68797 L .31919 .68552 L F
.169 0 .168 r
.31216 .68663 m .31294 .68467 L .31409 .6845 L F
.31294 .68467 m .31312 .6842 L .31409 .6845 L F
.213 .699 .927 r
.30893 .68522 m .30902 .68523 L .31151 .68449 L F
.30902 .68523 m .31202 .6848 L .31151 .68449 L F
.88 .869 .822 r
.54884 .44461 m .55168 .44547 L .55111 .4418 L F
.929 .804 .701 r
.54964 .44895 m .55168 .44547 L .54884 .44461 L F
.89 .874 .814 r
.55111 .4418 m .55168 .44547 L .55298 .4429 L F
.691 .804 .935 r
.37632 .51734 m .37579 .51799 L .37661 .51564 L F
0 .176 .664 r
.3749 .51451 m .37632 .51734 L .37661 .51564 L F
.3749 .51451 m .3771 .51639 L .37632 .51734 L F
.3771 .51639 m .3788 .51784 L .37632 .51734 L F
.691 .804 .935 r
.37632 .51734 m .37574 .51813 L .37579 .51799 L F
.938 .874 .746 r
.37673 .51125 m .37661 .51564 L .37906 .51238 L F
.37673 .51125 m .3749 .51451 L .37661 .51564 L F
.901 .81 .748 r
.3459 .5005 m .348 .50247 L .34679 .50046 L F
.3459 .5005 m .34634 .50551 L .348 .50247 L F
0 0 0 r
.539 .38287 m .5398 .38274 L .54104 .38131 L F
.992 .763 .391 r
.54265 .38209 m .54104 .38131 L .5398 .38274 L F
.54265 .38209 m .54384 .38101 L .54104 .38131 L F
.415 .194 .467 r
.62716 .36083 m .62458 .36246 L .6272 .35898 L F
.57 .612 .855 r
.62716 .36083 m .62853 .35672 L .6272 .35898 L F
.785 .542 .57 r
.31637 .51455 m .32086 .51243 L .31616 .51268 L F
.31637 .51455 m .32058 .51512 L .32086 .51243 L F
.151 0 0 r
.27876 .67218 m .28145 .6721 L .27988 .67257 L F
.835 .484 .391 r
.3809 .58654 m .38013 .58638 L .38046 .58478 L F
.38208 .58535 m .38376 .5885 L .37988 .58758 L F
.973 .782 .587 r
.38046 .58478 m .37988 .58758 L .37822 .586 L F
.158 .687 .864 r
.38138 .58657 m .38075 .58589 L .37839 .58599 L F
.37932 .5862 m .37839 .58599 L .37822 .586 L F
.38138 .58657 m .37839 .58599 L .37932 .5862 L F
.835 .484 .391 r
.38208 .58535 m .3809 .58654 L .38046 .58478 L F
.3809 .58654 m .37988 .58758 L .38013 .58638 L F
.869 .434 .162 r
.39655 .59273 m .39464 .59209 L .39284 .589 L F
.829 .359 .073 r
.39655 .59273 m .39465 .59292 L .39464 .59209 L F
.241 .72 .936 r
.39802 .59384 m .39465 .59292 L .39655 .59273 L F
.29 .059 .38 r
.27625 .53257 m .27836 .5317 L .27885 .5291 L F
.277 .034 .353 r
.27625 .53257 m .27571 .53507 L .27836 .5317 L F
.233 .373 .8 r
.59692 .384 m .59514 .38584 L .59504 .38559 L F
.59692 .384 m .59504 .38559 L .59624 .38352 L F
.59692 .384 m .59339 .38152 L .5954 .38151 L F
.59692 .384 m .5954 .38151 L .59572 .38151 L F
.762 .475 .498 r
.59662 .38221 m .59639 .38313 L .59692 .384 L F
.59639 .38313 m .59575 .38566 L .59692 .384 L F
0 0 0 r
.59698 .38363 m .59575 .38566 L .59633 .38335 L F
.85 .536 .458 r
.59662 .38221 m .59692 .384 L .59644 .383 L F
0 0 0 r
.59638 .38328 m .59633 .38335 L .59662 .38221 L F
.85 .536 .458 r
.59662 .38221 m .59644 .383 L .59572 .38151 L F
0 0 0 r
.59674 .38266 m .59638 .38328 L .59662 .38221 L F
.59698 .38363 m .59633 .38335 L .59674 .38266 L F
.233 .373 .8 r
.59624 .38352 m .59504 .38559 L .59339 .38152 L F
.845 .939 .886 r
.58751 .34804 m .58521 .35038 L .58789 .34981 L F
.476 .463 .764 r
.24807 .58929 m .24993 .59098 L .2498 .58837 L F
.405 0 0 r
.55526 .39987 m .55136 .40071 L .55456 .40077 L F
.885 .659 .591 r
.56346 .36666 m .56123 .36691 L .5617 .36461 L F
.56346 .36666 m .56363 .36849 L .56123 .36691 L F
.893 .615 .509 r
.33387 .53743 m .33598 .53569 L .33402 .53562 L F
.33387 .53743 m .33597 .53864 L .33598 .53569 L F
.1 .224 .706 r
.5653 .39727 m .56631 .4014 L .56472 .39976 L F
.144 0 .195 r
.53208 .3882 m .52935 .39133 L .52993 .38932 L F
.268 .005 .317 r
.26659 .56904 m .26581 .57201 L .26373 .57244 L F
.456 .204 .442 r
.26709 .56889 m .26581 .57201 L .26659 .56904 L F
.36 .295 .648 r
.26581 .57201 m .26625 .57463 L .26373 .57244 L F
.456 .294 .572 r
.26625 .57463 m .26388 .57541 L .26373 .57244 L F
.184 0 .213 r
.5369 .40598 m .53645 .40796 L .53919 .40498 L F
.81 .707 .751 r
.329 .57492 m .32682 .57847 L .33101 .57883 L F
.915 .874 .782 r
.32648 .58136 m .33101 .57883 L .32682 .57847 L F
.32648 .58136 m .32803 .58263 L .33101 .57883 L F
.833 .714 .732 r
.329 .57492 m .33101 .57883 L .33104 .57597 L F
.716 .205 .008 r
.54522 .42567 m .5438 .42696 L .54328 .42472 L F
.54522 .42567 m .54751 .42784 L .5438 .42696 L F
0 .287 .776 r
.28716 .64961 m .28648 .64967 L .28479 .64757 L F
.707 .685 .827 r
.28979 .6503 m .28617 .6497 L .28648 .64967 L F
.778 .359 .254 r
.29054 .65193 m .28979 .6503 L .28648 .64967 L F
.29054 .65193 m .28648 .64967 L .28889 .65111 L F
0 .287 .776 r
.28889 .65111 m .28648 .64967 L .28716 .64961 L F
.707 .685 .827 r
.28617 .6497 m .28356 .64927 L .28648 .64967 L F
.478 .36 .64 r
.29779 .66852 m .29508 .67115 L .2954 .66867 L F
.067 .631 .747 r
.51521 .42441 m .51278 .42458 L .51254 .42499 L F
.715 .873 .956 r
.62321 .36099 m .62458 .36246 L .62716 .36083 L F
.62716 .36083 m .62458 .36246 L .62321 .36099 L F
.08 .293 .777 r
.4111 .47505 m .41291 .47846 L .41418 .47579 L F
.375 .095 .356 r
.40197 .575 m .40539 .57179 L .40259 .57248 L F
.817 .61 .623 r
.67507 .36132 m .67904 .35889 L .67497 .35817 L F
.67507 .36132 m .67915 .36163 L .67904 .35889 L F
.24 0 0 r
.4014 .46688 m .40041 .46555 L .39886 .46754 L F
.4014 .46688 m .4031 .46507 L .40041 .46555 L F
.944 .79 .66 r
.44601 .54358 m .44791 .54201 L .44832 .5444 L F
.876 .596 .512 r
.35289 .5224 m .34963 .52415 L .34942 .52138 L F
.35289 .5224 m .353 .52513 L .34963 .52415 L F
.768 .582 .646 r
.65332 .35152 m .64929 .34836 L .65317 .34895 L F
.859 .687 .668 r
.33513 .54841 m .33454 .55146 L .33915 .55115 L F
.854 .789 .787 r
.33454 .55146 m .3359 .55531 L .33915 .55115 L F
0 0 0 r
.2511 .58199 m .25432 .57872 L .25135 .57915 L F
.794 .701 .762 r
.58486 .37474 m .58257 .37865 L .58642 .37902 L F
.157 .155 .605 r
.58642 .37902 m .58853 .377 L .58802 .37384 L F
0 0 .032 r
.58794 .37866 m .58853 .377 L .58642 .37902 L F
.173 .203 .652 r
.58642 .37902 m .58755 .38233 L .58794 .37866 L F
.762 .926 .942 r
.43202 .58476 m .43356 .58573 L .43561 .58329 L F
.702 .963 .942 r
.31195 .62763 m .31382 .62824 L .31118 .62946 L F
.715 .966 .938 r
.31685 .62595 m .31382 .62824 L .31195 .62763 L F
.674 .897 .547 r
.52343 .44172 m .52063 .44526 L .52457 .44564 L F
.435 .457 .784 r
.52343 .44172 m .52457 .44564 L .52666 .44524 L F
.772 .396 .345 r
.52457 .44564 m .5291 .44798 L .52666 .44524 L F
.464 .259 .515 r
.23857 .61574 m .24102 .61517 L .24124 .61236 L F
.71 .979 .779 r
.47411 .41987 m .47533 .41777 L .47633 .41835 L F
.47411 .41987 m .47228 .42051 L .47533 .41777 L F
0 .225 .737 r
.56664 .3505 m .56648 .35289 L .56483 .34932 L F
.718 .199 0 r
.56638 .354 m .56648 .35289 L .56664 .3505 L F
.56638 .354 m .5685 .35544 L .56648 .35289 L F
.92 .798 .71 r
.54388 .46078 m .54772 .45876 L .54583 .45702 L F
.54388 .46078 m .54584 .46247 L .54772 .45876 L F
.665 .844 .434 r
.5548 .40958 m .55591 .40637 L .55549 .40915 L F
.55351 .4104 m .55495 .40799 L .5548 .40958 L F
.55495 .40799 m .55591 .40637 L .5548 .40958 L F
0 0 .048 r
.55464 .40869 m .55489 .40552 L .5553 .40417 L F
.55518 .4055 m .5553 .40417 L .55553 .40344 L F
.55464 .40869 m .5553 .40417 L .55518 .4055 L F
.922 .865 .766 r
.67596 .36719 m .67767 .368 L .67696 .36483 L F
.832 .965 .892 r
.67361 .36974 m .67767 .368 L .67596 .36719 L F
.816 .815 .849 r
.67767 .368 m .68045 .36526 L .67696 .36483 L F
.826 .976 .889 r
.29819 .64662 m .30034 .64496 L .29858 .64456 L F
.845 .974 .875 r
.29858 .64456 m .30034 .64496 L .30308 .64213 L F
.492 .145 .306 r
.37197 .51216 m .37556 .51192 L .37499 .51014 L F
.539 .171 .291 r
.37499 .51014 m .37556 .51192 L .37673 .51125 L F
.412 .726 .989 r
.31803 .57726 m .32004 .57865 L .31767 .57913 L F
.31803 .57726 m .32004 .57865 L .31767 .57913 L F
.336 .099 .399 r
.32004 .57865 m .31712 .58174 L .31767 .57913 L F
.32004 .57865 m .31712 .58174 L .31767 .57913 L F
.799 .901 .914 r
.56188 .39379 m .55918 .39829 L .5587 .39774 L F
.56188 .39379 m .56215 .3962 L .55918 .39829 L F
.543 .141 .228 r
.40208 .54855 m .39996 .551 L .39771 .54929 L F
.964 .67 .425 r
.40054 .54535 m .40075 .54829 L .40208 .54855 L F
.783 .411 .351 r
.40208 .54855 m .4042 .55152 L .40364 .54989 L F
.977 .806 .604 r
.40075 .54829 m .39996 .551 L .40208 .54855 L F
.854 .404 .01 r
.4024 .53085 m .40425 .53237 L .40266 .52974 L F
.607 .614 .832 r
.40852 .53268 m .40266 .52974 L .40425 .53237 L F
.805 .558 .565 r
.35875 .50598 m .35771 .50842 L .3617 .50868 L F
.776 .44 .418 r
.35771 .50842 m .3599 .51123 L .3617 .50868 L F
.745 .399 .396 r
.3617 .50868 m .3599 .51123 L .36388 .51146 L F
.602 .836 .988 r
.62604 .38529 m .62215 .38508 L .62501 .38485 L F
.535 .828 .999 r
.62752 .38323 m .62604 .38529 L .62501 .38485 L F
.734 .839 .929 r
.29554 .68577 m .29601 .68275 L .29376 .68212 L F
.29554 .68577 m .29834 .6844 L .29601 .68275 L F
.971 .718 .494 r
.33549 .54173 m .33605 .54598 L .33701 .54529 L F
.92 .797 .707 r
.33605 .54598 m .33513 .54841 L .33701 .54529 L F
.825 .68 .703 r
.38473 .52261 m .38344 .52587 L .3814 .52473 L F
.885 .749 .707 r
.38332 .51831 m .38178 .52184 L .38473 .52261 L F
.583 .022 0 r
.38348 .52352 m .38473 .52261 L .38178 .52184 L F
.38348 .52352 m .38731 .52436 L .38473 .52261 L F
.684 .693 .852 r
.27812 .54912 m .28019 .55244 L .27745 .55297 L F
.663 .516 .674 r
.28019 .55244 m .27787 .55594 L .27745 .55297 L F
.592 .878 .566 r
.45537 .44296 m .45395 .44478 L .45751 .44202 L F
.45537 .44296 m .45384 .44469 L .45395 .44478 L F
.824 .847 .865 r
.50722 .42267 m .50926 .42431 L .51072 .42196 L F
0 0 0 r
.40722 .47144 m .41154 .4688 L .40972 .47151 L F
.438 .087 .272 r
.41154 .4688 m .41389 .47031 L .40972 .47151 L F
.41154 .4688 m .41415 .46847 L .41389 .47031 L F
.178 0 .339 r
.55958 .35116 m .56158 .34831 L .55899 .34868 L F
.755 .441 .453 r
.3946 .53548 m .39954 .53823 L .39925 .53588 L F
0 0 0 r
.539 .38287 m .53745 .38388 L .5398 .38274 L F
.2 0 0 r
.41399 .46029 m .41281 .45913 L .41128 .46095 L F
.41399 .46029 m .41545 .45854 L .41281 .45913 L F
.568 .656 .896 r
.39802 .59384 m .40082 .59555 L .40118 .59416 L F
.881 .877 .827 r
.52817 .45958 m .52358 .46144 L .52582 .45773 L F
.52817 .45958 m .52546 .46292 L .52358 .46144 L F
.864 .791 .778 r
.53023 .45564 m .52817 .45958 L .52582 .45773 L F
.969 .934 .656 r
.65701 .37106 m .65744 .36687 L .65881 .36854 L F
0 0 0 r
.39378 .56845 m .39328 .57063 L .39222 .57245 L F
.006 .152 .666 r
.39273 .57158 m .39452 .57323 L .39222 .57245 L F
.39328 .57063 m .39435 .57288 L .39273 .57158 L F
.39435 .57288 m .39452 .57323 L .39273 .57158 L F
.568 .011 0 r
.3933 .57295 m .39606 .57453 L .39628 .57442 L F
0 .554 .795 r
.3933 .57295 m .39452 .57323 L .39328 .57063 L F
.3933 .57295 m .39758 .57376 L .39452 .57323 L F
.568 .011 0 r
.3948 .57324 m .39628 .57442 L .39758 .57376 L F
.3933 .57295 m .39628 .57442 L .3948 .57324 L F
.594 .561 .787 r
.38903 .57012 m .39282 .57263 L .39328 .57063 L F
.39282 .57263 m .3933 .57295 L .39328 .57063 L F
0 0 0 r
.39389 .56817 m .39328 .57063 L .39378 .56845 L F
.44617 .43944 m .44475 .43995 L .44333 .44178 L F
.484 .899 .825 r
.44674 .43921 m .4433 .44046 L .44475 .43995 L F
.386 .832 .713 r
.44908 .43799 m .44475 .43995 L .44699 .43877 L F
0 0 0 r
.44699 .43877 m .44475 .43995 L .44617 .43944 L F
.484 .899 .825 r
.4433 .44046 m .44223 .44085 L .44475 .43995 L F
.386 .832 .713 r
.44908 .43799 m .44674 .43921 L .44475 .43995 L F
.988 .874 .629 r
.33946 .50552 m .33846 .50902 L .33711 .50707 L F
.39 .8 .59 r
.33946 .50552 m .33995 .50519 L .34224 .50558 L F
.33946 .50552 m .33711 .50707 L .33995 .50519 L F
.844 .631 .615 r
.36716 .54588 m .3665 .54875 L .36413 .54496 L F
.273 .045 .374 r
.27885 .5291 m .27836 .5317 L .28089 .52822 L F
.708 .898 .965 r
.30897 .55222 m .30675 .55485 L .30879 .55567 L F
.53 .912 .939 r
.5778 .34678 m .58212 .3461 L .57928 .34682 L F
.855 .989 .722 r
.56133 .40611 m .55911 .40922 L .55955 .40686 L F
.328 0 0 r
.58212 .3461 m .58488 .34665 L .58612 .34541 L F
.836 .38 .126 r
.58488 .34665 m .58751 .34804 L .58612 .34541 L F
.865 .634 .587 r
.35565 .50476 m .35771 .50842 L .35875 .50598 L F
.814 .968 .903 r
.31124 .54193 m .31067 .5436 L .30844 .54373 L F
.31191 .54225 m .31067 .5436 L .31124 .54193 L F
.31361 .5404 m .30844 .54373 L .31066 .54123 L F
.97 .652 .306 r
.31251 .54498 m .31105 .54418 L .31072 .54168 L F
.31093 .54178 m .31072 .54168 L .31066 .54123 L F
.31251 .54498 m .31072 .54168 L .31093 .54178 L F
.814 .968 .903 r
.31361 .5404 m .31191 .54225 L .31124 .54193 L F
.951 .683 .493 r
.28145 .6721 m .28393 .6762 L .28174 .67572 L F
.95 .678 .487 r
.28174 .67572 m .28393 .6762 L .28354 .677 L F
.106 .343 .812 r
.28403 .67371 m .28393 .6762 L .28145 .6721 L F
.884 .876 .439 r
.28403 .67371 m .28393 .6762 L .28354 .677 L F
.865 .9 .856 r
.51724 .39917 m .51504 .40326 L .51851 .40222 L F
.403 .436 .781 r
.51851 .40222 m .51967 .39789 L .51724 .39917 L F
.51851 .40222 m .51933 .40229 L .51967 .39789 L F
.903 .925 .822 r
.53454 .4756 m .53576 .47095 L .53356 .47472 L F
.53454 .4756 m .5371 .47208 L .53576 .47095 L F
.914 .975 .782 r
.53243 .47674 m .53454 .4756 L .53356 .47472 L F
.68 .801 .939 r
.2369 .61188 m .24124 .61236 L .2402 .61043 L F
.767 .524 .568 r
.23978 .60569 m .24013 .61044 L .243 .60899 L F
.517 0 0 r
.24369 .61179 m .24132 .61086 L .24124 .61236 L F
.24369 .61179 m .24182 .61147 L .2402 .61043 L F
.14 0 .021 r
.24355 .61001 m .24182 .61147 L .24393 .6107 L F
.243 .60899 m .24228 .61049 L .24355 .61001 L F
.24228 .61049 m .24182 .61147 L .24355 .61001 L F
.517 0 0 r
.24132 .61086 m .2402 .61043 L .24058 .61114 L F
.24132 .61086 m .24058 .61114 L .24124 .61236 L F
.464 .259 .515 r
.24369 .61179 m .24102 .61517 L .24124 .61236 L F
.85 .913 .876 r
.50202 .50208 m .50346 .49784 L .50111 .50131 L F
.50202 .50208 m .50508 .49907 L .50346 .49784 L F
.618 .101 0 r
.5291 .44798 m .52846 .44776 L .52666 .44524 L F
.5291 .44798 m .53034 .44928 L .52846 .44776 L F
.603 .951 .831 r
.43351 .56911 m .43405 .56832 L .43476 .56761 L F
.42 .825 .978 r
.50062 .45448 m .50372 .45413 L .50084 .45139 L F
.673 .896 .977 r
.60659 .34996 m .60395 .35127 L .60725 .35146 L F
.836 .808 .824 r
.60395 .35127 m .60375 .35401 L .60725 .35146 L F
.613 .956 .89 r
.60725 .35146 m .60944 .34907 L .60659 .34996 L F
.60725 .35146 m .60916 .35022 L .60944 .34907 L F
.949 .666 .468 r
.36138 .53849 m .35927 .53466 L .36154 .53577 L F
.984 .72 .34 r
.3412 .64505 m .34131 .64255 L .34005 .64087 L F
.34005 .64087 m .34131 .64255 L .3412 .64505 L F
.542 .782 .987 r
.34238 .64061 m .34131 .64255 L .34005 .64087 L F
.813 .946 .91 r
.51797 .48637 m .52027 .48683 L .52216 .485 L F
.831 .751 .775 r
.53023 .45564 m .52649 .45492 L .52897 .4518 L F
.864 .791 .778 r
.53023 .45564 m .52582 .45773 L .52649 .45492 L F
.816 .744 .784 r
.53276 .45221 m .53023 .45564 L .52897 .4518 L F
.972 .705 .466 r
.39289 .53181 m .39262 .53448 L .3946 .53548 L F
.938 .621 .411 r
.39259 .5371 m .3946 .53548 L .39262 .53448 L F
.39259 .5371 m .39449 .538 L .3946 .53548 L F
.755 .441 .453 r
.3946 .53548 m .39449 .538 L .39954 .53823 L F
.373 0 0 r
.4219 .59332 m .41882 .59451 L .41694 .59428 L F
.92 .919 .797 r
.42138 .59054 m .4219 .59332 L .42361 .59192 L F
.42138 .59054 m .41882 .59451 L .4219 .59332 L F
.485 0 0 r
.39771 .54929 m .3957 .55025 L .39299 .549 L F
.448 0 0 r
.39771 .54929 m .3983 .54985 L .3957 .55025 L F
.39771 .54929 m .39996 .551 L .3983 .54985 L F
.095 .17 .652 r
.26111 .57862 m .26313 .58062 L .2615 .58187 L F
0 0 .18 r
.26313 .58062 m .26144 .58466 L .2615 .58187 L F
.775 .846 .906 r
.52546 .46292 m .52015 .46269 L .52358 .46144 L F
.861 .93 .87 r
.53576 .47095 m .5371 .47208 L .54004 .46897 L F
.7 .189 .013 r
.51504 .40326 m .51417 .40322 L .51195 .40222 L F
.622 .639 .846 r
.51195 .40222 m .51417 .40322 L .51405 .40298 L F
.372 0 0 r
.51195 .40222 m .51422 .40305 L .51504 .40326 L F
.756 .7 .798 r
.51222 .39939 m .51405 .40298 L .51724 .39917 L F
.51405 .40298 m .51417 .40322 L .51429 .40306 L F
.51405 .40298 m .51429 .40306 L .51724 .39917 L F
.372 0 0 r
.51405 .40298 m .51349 .40286 L .51422 .40305 L F
.51195 .40222 m .51272 .40254 L .51405 .40298 L F
.51272 .40254 m .51349 .40286 L .51405 .40298 L F
.622 .639 .846 r
.51195 .40222 m .51405 .40298 L .51222 .39939 L F
.865 .9 .856 r
.51724 .39917 m .51429 .40306 L .51504 .40326 L F
.51429 .40306 m .51417 .40322 L .51504 .40326 L F
.372 0 0 r
.51349 .40286 m .51485 .40342 L .51504 .40326 L F
.563 .007 0 r
.51485 .40342 m .5173 .40506 L .51504 .40326 L F
.163 0 0 r
.2811 .6362 m .27758 .63904 L .2796 .63792 L F
0 0 0 r
.28085 .6365 m .2811 .6362 L .2796 .63792 L F
.28085 .6365 m .28362 .63562 L .2811 .6362 L F
.921 .531 .155 r
.56065 .38886 m .55963 .38985 L .56005 .38605 L F
.56065 .38886 m .56126 .3912 L .55963 .38985 L F
.879 .745 .711 r
.3351 .55825 m .33327 .56143 L .33636 .56221 L F
.861 .782 .772 r
.33327 .56143 m .33475 .56517 L .33636 .56221 L F
.17 0 .258 r
.62268 .38777 m .62265 .39004 L .62536 .38754 L F
.314 .478 .862 r
.62501 .38485 m .62215 .38508 L .62358 .38301 L F
.187 .3 .748 r
.62215 .38508 m .62536 .38754 L .62358 .38301 L F
.732 .634 .75 r
.62752 .38323 m .62501 .38485 L .62358 .38301 L F
.603 .526 .741 r
.62536 .38754 m .62752 .38323 L .62358 .38301 L F
.62536 .38754 m .62859 .38457 L .62752 .38323 L F
.6285 .38465 m .62536 .38754 L .62385 .38853 L F
.62859 .38457 m .62536 .38754 L .6285 .38465 L F
.17 0 .258 r
.62265 .39004 m .62263 .39081 L .62536 .38754 L F
.977 .713 .463 r
.63456 .35758 m .63301 .35592 L .63598 .35715 L F
.796 .975 .686 r
.59785 .37429 m .59616 .37551 L .59786 .37273 L F
.743 .354 .316 r
.67235 .34692 m .67618 .34556 L .67215 .34482 L F
.67235 .34692 m .67659 .34784 L .67618 .34556 L F
.503 .129 .263 r
.25601 .58837 m .25245 .59021 L .2535 .58911 L F
.674 .97 .917 r
.63557 .38207 m .63136 .38352 L .63495 .38187 L F
0 0 0 r
.63743 .38042 m .63848 .37914 L .63557 .38207 L F
.555 .933 .847 r
.63743 .38042 m .63557 .38207 L .63495 .38187 L F
.933 .94 .593 r
.67604 .35332 m .67758 .35202 L .67626 .35074 L F
.67604 .35332 m .67597 .35559 L .67758 .35202 L F
.415 .823 .977 r
.29838 .58831 m .3014 .58806 L .3008 .58532 L F
0 .104 .619 r
.3014 .58806 m .30169 .5888 L .3008 .58532 L F
.454 .718 .981 r
.30148 .588 m .29838 .58831 L .3008 .58532 L F
.415 .823 .977 r
.29838 .58831 m .30114 .58803 L .3014 .58806 L F
.454 .718 .981 r
.29838 .58831 m .30169 .5888 L .3014 .58806 L F
.30169 .5888 m .29838 .58831 L .30148 .588 L F
.415 .823 .977 r
.29838 .58831 m .29646 .58749 L .30114 .58803 L F
.3014 .58806 m .29646 .58749 L .29838 .58831 L F
.644 .966 .834 r
.47353 .4308 m .47895 .42837 L .47812 .4286 L F
.4 .854 .808 r
.47895 .42837 m .48128 .42739 L .4807 .42731 L F
.39 .838 .733 r
.47812 .4286 m .47895 .42837 L .4807 .42731 L F
.744 .808 .903 r
.31118 .62946 m .30702 .62948 L .30946 .62824 L F
.702 .963 .942 r
.31195 .62763 m .31118 .62946 L .30946 .62824 L F
.775 .689 .769 r
.24369 .61179 m .24536 .61565 L .24102 .61517 L F
.461 .811 .998 r
.24102 .61517 m .24536 .61565 L .24311 .61457 L F
0 .21 .725 r
.24621 .61422 m .24536 .61565 L .24369 .61179 L F
.49 .549 .844 r
.24102 .61517 m .24182 .61147 L .24369 .61179 L F
.609 .608 .825 r
.24182 .61147 m .24349 .61447 L .24621 .61422 L F
.445 .804 .996 r
.24416 .61441 m .24536 .61565 L .24621 .61422 L F
.24311 .61457 m .24536 .61565 L .24408 .61432 L F
.609 .608 .825 r
.24349 .61447 m .24425 .61584 L .24621 .61422 L F
.445 .804 .996 r
.24408 .61432 m .24416 .61441 L .24621 .61422 L F
.49 .549 .844 r
.24311 .61457 m .24349 .61447 L .24348 .61446 L F
.24102 .61517 m .24348 .61446 L .24182 .61147 L F
.445 .804 .996 r
.24273 .61438 m .24311 .61457 L .24408 .61432 L F
.49 .549 .844 r
.24102 .61517 m .24425 .61584 L .24349 .61447 L F
.24102 .61517 m .24349 .61447 L .24311 .61457 L F
.461 .811 .998 r
.24102 .61517 m .24311 .61457 L .24273 .61438 L F
.517 .328 .563 r
.24903 .62089 m .24947 .62235 L .24682 .62232 L F
.24903 .62089 m .24947 .62235 L .24682 .62232 L F
0 0 0 r
.33401 .67836 m .33554 .67664 L .33748 .67515 L F
.674 .126 0 r
.29228 .64575 m .29565 .64732 L .29233 .64596 L F
.29202 .64438 m .29405 .64602 L .29228 .64575 L F
.29405 .64602 m .29565 .64732 L .29228 .64575 L F
0 .508 .717 r
.29494 .64616 m .29819 .64662 L .29701 .64642 L F
.29351 .64598 m .29561 .64627 L .29494 .64616 L F
.29561 .64627 m .29819 .64662 L .29494 .64616 L F
.879 .991 .743 r
.29701 .64642 m .29819 .64662 L .29858 .64456 L F
.388 .433 .786 r
.56052 .35512 m .56139 .35058 L .55958 .35116 L F
.56052 .35512 m .56256 .35439 L .56139 .35058 L F
.301 .187 .552 r
.56052 .35512 m .56276 .35699 L .56256 .35439 L F
.973 .835 .646 r
.41622 .56126 m .41501 .5645 L .41669 .56356 L F
.814 .336 0 r
.41501 .5645 m .41789 .56773 L .41669 .56356 L F
.926 .735 .625 r
.3681 .56915 m .36785 .57208 L .36624 .56826 L F
0 0 0 r
.64493 .3462 m .64362 .34626 L .64093 .34636 L F
.517 0 0 r
.64695 .34748 m .64362 .34626 L .64493 .3462 L F
.486 .583 .877 r
.61657 .39381 m .61799 .39733 L .61962 .39517 L F
.938 .8 .683 r
.33264 .56358 m .33475 .56517 L .33327 .56143 L F
.96 .864 .7 r
.33124 .56798 m .33475 .56517 L .33264 .56358 L F
.33124 .56798 m .33259 .56896 L .33475 .56517 L F
.385 .786 .985 r
.28942 .64477 m .29202 .64438 L .28985 .64351 L F
.657 .103 0 r
.28985 .64351 m .29202 .64438 L .29229 .64466 L F
.28985 .64351 m .29229 .64466 L .29244 .64443 L F
.29078 .64306 m .29244 .64443 L .29445 .64126 L F
.28985 .64351 m .29244 .64443 L .29078 .64306 L F
.174 .561 .933 r
.29202 .64438 m .29351 .64598 L .29444 .6461 L F
.29271 .64466 m .29444 .6461 L .29701 .64642 L F
.29202 .64438 m .29444 .6461 L .29271 .64466 L F
.345 .813 .917 r
.63449 .39348 m .63338 .39296 L .63047 .39359 L F
.115 .65 .86 r
.63449 .39348 m .63741 .39348 L .63338 .39296 L F
.926 .865 .76 r
.47773 .52435 m .48162 .52188 L .4803 .52084 L F
.47773 .52435 m .47941 .52564 L .48162 .52188 L F
.873 .94 .859 r
.48452 .51864 m .4803 .52084 L .48162 .52188 L F
.817 .99 .733 r
.56316 .40347 m .56133 .40611 L .55955 .40686 L F
.636 .659 .856 r
.3459 .5005 m .34567 .49695 L .34482 .49883 L F
.652 .858 .978 r
.59384 .40158 m .59535 .40325 L .59804 .40202 L F
.59384 .40158 m .59535 .40325 L .59804 .40202 L F
.367 .736 .989 r
.29896 .6615 m .29972 .66264 L .29673 .66182 L F
.57 .538 .78 r
.30046 .66514 m .29673 .66182 L .29972 .66264 L F
.734 .975 .731 r
.30141 .65974 m .29972 .66264 L .29896 .6615 L F
.808 .733 .781 r
.329 .57492 m .33369 .57274 L .33194 .57117 L F
.329 .57492 m .33104 .57597 L .33369 .57274 L F
.918 .523 .217 r
.32452 .55254 m .32507 .55484 L .32313 .55371 L F
0 0 .423 r
.32452 .55254 m .32418 .5512 L .32295 .54881 L F
.93 .907 .515 r
.32452 .55254 m .32313 .55371 L .32418 .5512 L F
.918 .523 .217 r
.32452 .55254 m .32507 .55484 L .32313 .55371 L F
.846 .615 .589 r
.32649 .52098 m .32946 .519 L .32675 .51825 L F
.32649 .52098 m .32921 .52189 L .32946 .519 L F
0 0 0 r
.27637 .55756 m .27465 .55892 L .27787 .55594 L F
.27487 .5596 m .27465 .55892 L .27637 .55756 L F
.27487 .5596 m .27255 .56032 L .27465 .55892 L F
.992 .884 .576 r
.32499 .64526 m .32307 .64769 L .32101 .645 L F
.559 .37 .58 r
.32759 .64522 m .32404 .64867 L .32499 .64526 L F
.423 .863 .91 r
.62947 .34279 m .63243 .34184 L .63389 .34218 L F
.39 .836 .933 r
.63243 .34184 m .63679 .34169 L .63389 .34218 L F
.75 .742 .844 r
.51639 .47471 m .51248 .47431 L .51561 .47169 L F
.878 .852 .812 r
.51833 .47142 m .51639 .47471 L .51561 .47169 L F
.492 .167 .343 r
.30559 .52589 m .30797 .52759 L .30857 .52532 L F
.30857 .52532 m .30797 .52759 L .30559 .52589 L F
.832 .827 .843 r
.42518 .58559 m .42655 .58906 L .42588 .5855 L F
.42518 .58559 m .42301 .58841 L .42655 .58906 L F
.839 .819 .83 r
.42655 .58906 m .42301 .58841 L .42361 .59192 L F
.872 .63 .571 r
.56363 .36849 m .56022 .37095 L .56123 .36691 L F
.56363 .36849 m .56286 .37199 L .56022 .37095 L F
.818 .998 .778 r
.49005 .49303 m .49092 .49062 L .49185 .49094 L F
.49005 .49303 m .48806 .49384 L .49092 .49062 L F
.477 .689 .96 r
.28565 .67888 m .28764 .68143 L .28988 .68078 L F
.929 .958 .644 r
.42651 .5719 m .42765 .56747 L .42599 .56897 L F
.755 .669 .767 r
.3056 .64142 m .30845 .64343 L .31035 .64082 L F
.856 .591 .536 r
.30813 .64496 m .30845 .64343 L .3056 .64142 L F
.663 .79 .942 r
.60324 .3969 m .60455 .39878 L .60043 .39815 L F
.60324 .3969 m .60455 .39878 L .60043 .39815 L F
.608 .765 .954 r
.6074 .39794 m .60455 .39878 L .60324 .3969 L F
.60324 .3969 m .60455 .39878 L .6074 .39794 L F
0 0 0 r
.3167 .54835 m .31348 .55062 L .31413 .5489 L F
.45 .322 .615 r
.5644 .39409 m .56215 .3962 L .56188 .39379 L F
.5644 .39409 m .5653 .39727 L .56215 .3962 L F
.693 .97 .928 r
.60011 .36507 m .59729 .36729 L .59766 .36676 L F
.479 .546 .846 r
.60068 .36724 m .59729 .36729 L .60011 .36507 L F
.988 .721 .364 r
.34879 .62373 m .35028 .62236 L .34866 .62207 L F
.34879 .62373 m .35026 .62514 L .35028 .62236 L F
.974 .886 .681 r
.35028 .62236 m .35053 .61753 L .34866 .62207 L F
.798 .656 .705 r
.28139 .65246 m .28112 .65495 L .27721 .65478 L F
.854 .557 .486 r
.34509 .51802 m .34135 .51446 L .34518 .51548 L F
.976 .748 .529 r
.31201 .57866 m .31039 .57872 L .31226 .57659 L F
.653 .881 .523 r
.31226 .57659 m .31593 .5751 L .31544 .57667 L F
.31226 .57659 m .31428 .57364 L .31593 .5751 L F
.31226 .57659 m .31039 .57872 L .31428 .57364 L F
.67 .825 .958 r
.31593 .5751 m .31226 .57659 L .31544 .57667 L F
.427 .212 .483 r
.52364 .37869 m .52421 .38123 L .52096 .38208 L F
0 .21 .725 r
.24621 .61422 m .24369 .61179 L .24803 .61227 L F
.656 .885 .531 r
.24762 .61225 m .24621 .61422 L .24803 .61227 L F
.78 .495 .503 r
.3637 .51421 m .36817 .51223 L .36388 .51146 L F
.3637 .51421 m .3681 .51491 L .36817 .51223 L F
.661 .416 .539 r
.3681 .51491 m .37197 .51216 L .36817 .51223 L F
.908 .958 .812 r
.4751 .5277 m .47377 .53216 L .47681 .52901 L F
.4751 .5277 m .47255 .53128 L .47377 .53216 L F
.519 .317 .546 r
.64114 .3754 m .64134 .37776 L .63848 .37914 L F
.64114 .3754 m .64134 .37776 L .63848 .37914 L F
.248 .753 .885 r
.34224 .50558 m .3444 .50527 L .34634 .50551 L F
.428 0 0 r
.3444 .50527 m .34884 .50743 L .34634 .50551 L F
.747 .464 .503 r
.32068 .51763 m .32498 .51546 L .32058 .51512 L F
.32068 .51763 m .32483 .51812 L .32498 .51546 L F
.773 .488 .502 r
.32498 .51546 m .32483 .51812 L .32675 .51825 L F
0 0 0 r
.42404 .4538 m .42769 .45183 L .42532 .45291 L F
.59 .836 .991 r
.64553 .39548 m .64835 .39451 L .64699 .39319 L F
.597 .845 .991 r
.64419 .3941 m .64553 .39548 L .64699 .39319 L F
.766 .925 .94 r
.30514 .68596 m .30893 .68522 L .30719 .68443 L F
.213 .699 .927 r
.30893 .68522 m .31151 .68449 L .30719 .68443 L F
.142 0 0 r
.51393 .42815 m .51663 .42779 L .51614 .42828 L F
.021 0 .106 r
.51663 .42779 m .51914 .42492 L .51872 .42703 L F
0 0 0 r
.51614 .42828 m .51663 .42779 L .51872 .42703 L F
.912 .809 .733 r
.33351 .55421 m .3359 .55531 L .33454 .55146 L F
.914 .742 .654 r
.33351 .55421 m .3351 .55825 L .3359 .55531 L F
.665 .739 .906 r
.47089 .51885 m .46655 .51806 L .46977 .51631 L F
.857 .786 .781 r
.473 .51516 m .47089 .51885 L .46977 .51631 L F
.794 .866 .903 r
.29014 .63431 m .28811 .63597 L .28618 .63467 L F
.791 .71 .775 r
.27721 .65478 m .28112 .65495 L .27923 .65674 L F
.811 .912 .908 r
.50346 .49784 m .50508 .49907 L .50614 .49752 L F
.89 .874 .814 r
.55111 .4418 m .55298 .4429 L .55205 .44023 L F
0 0 0 r
.48864 .40888 m .49 .40754 L .49158 .40589 L F
.49158 .40589 m .49249 .40617 L .4939 .40468 L F
.49158 .40589 m .49 .40754 L .49249 .40617 L F
.82 .962 .634 r
.2788 .55412 m .27787 .55594 L .28019 .55244 L F
.56 .638 .885 r
.28246 .55153 m .28019 .55244 L .27812 .54912 L F
.107 0 0 r
.28246 .55153 m .2788 .55412 L .28019 .55244 L F
.847 .747 .752 r
.32344 .54541 m .31995 .54494 L .32208 .54151 L F
.811 .563 .563 r
.32344 .54541 m .31916 .54765 L .31995 .54494 L F
.32344 .54541 m .32295 .54881 L .31916 .54765 L F
.309 .098 .422 r
.4074 .56211 m .40915 .56494 L .40969 .56098 L F
.857 .786 .781 r
.473 .51516 m .46977 .51631 L .47248 .51471 L F
.912 .924 .542 r
.473 .51516 m .47248 .51471 L .47407 .51066 L F
.408 0 0 r
.62831 .34847 m .62721 .35006 L .62442 .34996 L F
0 0 0 r
.62981 .34843 m .62831 .34847 L .63106 .34777 L F
.62981 .34843 m .62721 .35006 L .62831 .34847 L F
.895 .858 .797 r
.31076 .60172 m .31545 .5995 L .31031 .60074 L F
.86 .879 .851 r
.31545 .5995 m .31816 .59654 L .31365 .59603 L F
.897 .886 .813 r
.31031 .60074 m .31545 .5995 L .31365 .59603 L F
.71 .924 .964 r
.41238 .59544 m .41407 .59629 L .41694 .59428 L F
.833 .92 .527 r
.51988 .37577 m .51828 .3791 L .51865 .37719 L F
.631 .134 0 r
.51828 .3791 m .51798 .3793 L .51865 .37719 L F
.51828 .3791 m .51947 .38069 L .51798 .3793 L F
.537 .914 .762 r
.48864 .40888 m .48666 .40957 L .49 .40754 L F
.956 .676 .235 r
.57249 .36811 m .57378 .37184 L .57387 .37196 L F
.917 .975 .771 r
.35133 .65873 m .35445 .65539 L .35425 .65539 L F
.008 0 0 r
.27824 .5574 m .27787 .55594 L .2788 .55412 L F
.27824 .5574 m .27637 .55756 L .27787 .55594 L F
.313 0 0 r
.52681 .43074 m .52458 .43004 L .52307 .43025 L F
.888 .846 .797 r
.42361 .59192 m .42301 .58841 L .42138 .59054 L F
.639 .81 .965 r
.34309 .66579 m .33874 .66519 L .3413 .66463 L F
.53 .825 .999 r
.3413 .66463 m .34557 .66508 L .34309 .66579 L F
.801 .45 .391 r
.39284 .589 m .39464 .59209 L .39086 .59135 L F
.281 .028 .34 r
.4441 .55551 m .44327 .55869 L .44136 .55885 L F
.33 .294 .667 r
.44136 .55885 m .44427 .56052 L .44327 .55869 L F
.281 .028 .34 r
.4441 .55551 m .44327 .55869 L .44136 .55885 L F
.33 .294 .667 r
.44136 .55885 m .44427 .56052 L .44327 .55869 L F
0 .013 .567 r
.51033 .45272 m .50834 .45298 L .50646 .45193 L F
.868 .712 .189 r
.52351 .37343 m .52364 .37869 L .52633 .37529 L F
.52351 .37343 m .52331 .37763 L .52364 .37869 L F
.916 .534 .272 r
.52215 .37993 m .52364 .37869 L .52331 .37763 L F
.52215 .37993 m .52421 .38123 L .52364 .37869 L F
0 0 0 r
.42642 .46206 m .42243 .46442 L .42368 .46218 L F
.966 .689 .265 r
.39399 .56218 m .3927 .5585 L .39173 .56115 L F
.58 .288 .436 r
.39328 .56458 m .39399 .56218 L .39173 .56115 L F
.39328 .56458 m .39606 .56446 L .39399 .56218 L F
.39399 .56218 m .39606 .56446 L .39328 .56458 L F
.332 .267 .632 r
.29965 .60798 m .30138 .6116 L .30078 .60745 L F
.29965 .60798 m .3004 .61231 L .30138 .6116 L F
.016 .205 .715 r
.27397 .65859 m .27539 .66312 L .27635 .66081 L F
0 0 .353 r
.27635 .66081 m .27539 .66312 L .27585 .66492 L F
.861 .93 .87 r
.53576 .47095 m .54004 .46897 L .53864 .46771 L F
.887 .947 .843 r
.54265 .46546 m .53864 .46771 L .54004 .46897 L F
.705 .291 0 r
.44327 .55869 m .44427 .56052 L .44529 .56193 L F
.799 .943 .92 r
.44529 .56193 m .44427 .56052 L .44049 .56397 L F
.82 .76 .796 r
.44529 .56193 m .44786 .55848 L .44327 .55869 L F
.705 .291 0 r
.44327 .55869 m .44427 .56052 L .44529 .56193 L F
0 0 0 r
.59365 .3461 m .59488 .34604 L .59565 .34384 L F
.59365 .3461 m .59222 .34764 L .59488 .34604 L F
.757 .711 .808 r
.32075 .53476 m .3221 .53873 L .31786 .53819 L F
.674 .415 .521 r
.3221 .53873 m .31836 .54141 L .31786 .53819 L F
.3221 .53873 m .32208 .54151 L .31836 .54141 L F
.363 .157 .461 r
.28117 .52549 m .28089 .52822 L .2834 .52469 L F
.979 .683 .337 r
.30019 .64804 m .30166 .6515 L .29786 .65132 L F
.751 .357 .305 r
.29786 .65132 m .30166 .6515 L .29987 .65408 L F
.785 .587 .632 r
.3044 .65172 m .29987 .65408 L .30166 .6515 L F
.889 .988 .738 r
.3233 .63684 m .3259 .63528 L .32494 .63573 L F
.856 .994 .749 r
.32494 .63573 m .3259 .63528 L .32647 .63358 L F
.976 .815 .619 r
.3233 .63684 m .32494 .63573 L .32283 .63364 L F
.855 .993 .743 r
.32647 .63358 m .3259 .63528 L .32495 .63585 L F
.32647 .63358 m .32495 .63585 L .32503 .63506 L F
.856 .994 .749 r
.32494 .63573 m .32647 .63358 L .32736 .63523 L F
.855 .993 .743 r
.32647 .63358 m .32503 .63506 L .32736 .63523 L F
.489 .757 .99 r
.32422 .635 m .32494 .63573 L .32496 .63573 L F
.3251 .63444 m .32496 .63573 L .32736 .63523 L F
.32283 .63364 m .32496 .63573 L .3251 .63444 L F
.855 .993 .743 r
.32503 .63506 m .32495 .63585 L .3233 .63684 L F
.32503 .63506 m .3233 .63684 L .32736 .63523 L F
.489 .757 .99 r
.32283 .63364 m .32421 .635 L .32422 .635 L F
.32421 .635 m .32494 .63573 L .32422 .635 L F
.437 .244 .52 r
.60011 .36507 m .59766 .36676 L .59968 .36198 L F
0 0 .279 r
.5999 .35776 m .60051 .36073 L .59968 .36198 L F
.668 .225 0 r
.60051 .36073 m .60011 .36507 L .59968 .36198 L F
.463 .871 .716 r
.4597 .44067 m .45537 .44296 L .45751 .44202 L F
.791 .839 .888 r
.50741 .4343 m .50733 .43134 L .50603 .43345 L F
.514 .296 .522 r
.50867 .4332 m .51068 .4318 L .50741 .4343 L F
.791 .839 .888 r
.50741 .4343 m .51068 .4318 L .50733 .43134 L F
.467 .892 .841 r
.54326 .42131 m .53996 .42233 L .5419 .41791 L F
.346 .801 .944 r
.60244 .34431 m .60517 .34386 L .607 .34435 L F
0 .539 .783 r
.60517 .34386 m .60931 .34465 L .607 .34435 L F
0 0 0 r
.43414 .45928 m .43554 .45776 L .43299 .46119 L F
.249 0 0 r
.30408 .66074 m .30582 .65843 L .30332 .65896 L F
.62 .933 .965 r
.4441 .55551 m .447 .55362 L .44505 .5537 L F
.638 .802 .364 r
.4441 .55551 m .44303 .55734 L .44327 .55869 L F
.4441 .55551 m .44505 .5537 L .44303 .55734 L F
.534 .573 .84 r
.44786 .55848 m .4441 .55551 L .44327 .55869 L F
.44786 .55848 m .447 .55362 L .4441 .55551 L F
.62 .933 .965 r
.4441 .55551 m .447 .55362 L .44505 .5537 L F
.83 .899 .889 r
.31365 .59603 m .31816 .59654 L .3199 .59474 L F
.4 0 0 r
.29834 .6844 m .30199 .68616 L .30152 .68468 L F
.114 0 0 r
.29834 .6844 m .30152 .68468 L .30178 .68477 L F
.29834 .6844 m .30178 .68477 L .29601 .68275 L F
.832 .709 .728 r
.40226 .5549 m .40308 .55882 L .39985 .5575 L F
.785 .307 .096 r
.39985 .5575 m .40308 .55882 L .40089 .55956 L F
.071 .175 .668 r
.4046 .55747 m .40308 .55882 L .40226 .5549 L F
.584 .314 .473 r
.4046 .55747 m .40089 .55956 L .40308 .55882 L F
0 0 0 r
.52415 .41727 m .52869 .41601 L .52567 .41589 L F
.758 .946 .941 r
.52567 .41589 m .52869 .41601 L .52945 .41337 L F
.655 .715 .892 r
.32823 .61912 m .33021 .62248 L .32603 .62165 L F
.73 .764 .88 r
.33112 .61804 m .33021 .62248 L .32823 .61912 L F
.33112 .61804 m .33302 .62108 L .33021 .62248 L F
.921 .946 .599 r
.49987 .45657 m .50062 .45448 L .50004 .45525 L F
.49987 .45657 m .499 .45603 L .50062 .45448 L F
.42 .825 .978 r
.50062 .45448 m .50293 .45336 L .50372 .45413 L F
0 0 0 r
.50062 .45448 m .499 .45603 L .5021 .45392 L F
.50062 .45448 m .5021 .45392 L .50293 .45336 L F
.043 .153 .655 r
.50002 .45471 m .50062 .45448 L .49989 .45076 L F
.50004 .45525 m .50062 .45448 L .50002 .45471 L F
.887 .947 .843 r
.54265 .46546 m .54132 .46433 L .53864 .46771 L F
.916 .94 .805 r
.54388 .46078 m .54265 .46546 L .54584 .46247 L F
.54388 .46078 m .54132 .46433 L .54265 .46546 L F
.755 .669 .767 r
.3056 .64142 m .31035 .64082 L .30848 .63827 L F
.452 .303 .587 r
.31035 .64082 m .31276 .63891 L .30848 .63827 L F
.31035 .64082 m .31236 .64155 L .31276 .63891 L F
.735 .84 .929 r
.29875 .64195 m .30308 .64213 L .30133 .64061 L F
.845 .974 .875 r
.29858 .64456 m .30308 .64213 L .29875 .64195 L F
.642 .796 .957 r
.30308 .64213 m .30389 .63952 L .30133 .64061 L F
.30308 .64213 m .3056 .64142 L .30389 .63952 L F
0 .231 .75 r
.30308 .64213 m .30565 .64408 L .3056 .64142 L F
.253 .106 .479 r
.60068 .36724 m .60053 .37023 L .59768 .37161 L F
.238 .062 .428 r
.60053 .37023 m .59786 .37273 L .59768 .37161 L F
.893 .874 .811 r
.38673 .55138 m .39098 .54996 L .38907 .54984 L F
.38673 .55138 m .38899 .55244 L .39098 .54996 L F
.86 .625 .583 r
.38344 .52587 m .3825 .52831 L .3814 .52473 L F
.956 .676 .235 r
.57292 .36935 m .57271 .3704 L .57378 .37184 L F
.8 .563 .579 r
.57007 .37445 m .57378 .37184 L .57271 .3704 L F
.073 0 .062 r
.57425 .37131 m .57227 .37251 L .57271 .3704 L F
.57227 .37251 m .5721 .37261 L .57271 .3704 L F
.956 .676 .235 r
.57249 .36811 m .57271 .3704 L .57292 .36935 L F
.8 .563 .579 r
.57007 .37445 m .57367 .37505 L .57378 .37184 L F
.91 .686 .587 r
.32826 .52748 m .33089 .52553 L .32855 .52465 L F
.32826 .52748 m .33063 .5284 L .33089 .52553 L F
.725 .434 .484 r
.3151 .52211 m .31535 .52497 L .31065 .52436 L F
.646 .881 .984 r
.29747 .63233 m .29346 .63238 L .29555 .6308 L F
.556 .648 .895 r
.29847 .62876 m .29747 .63233 L .29555 .6308 L F
.29847 .62876 m .30002 .63173 L .29747 .63233 L F
.436 .224 .491 r
.40364 .54989 m .4042 .55152 L .40688 .54814 L F
.873 .623 .557 r
.36413 .54496 m .36088 .54132 L .36447 .5421 L F
.295 .759 .946 r
.341 .64819 m .3456 .64858 L .34279 .64879 L F
.341 .64819 m .3456 .64858 L .34279 .64879 L F
.927 .78 .678 r
.67532 .36331 m .67915 .36163 L .67507 .36132 L F
.67532 .36331 m .67696 .36483 L .67915 .36163 L F
.056 0 0 r
.63954 .34073 m .64229 .34011 L .64351 .33911 L F
.016 0 0 r
.64229 .34011 m .64635 .33882 L .64351 .33911 L F
.64252 .34004 m .6451 .33954 L .64635 .33882 L F
.64229 .34011 m .6451 .33954 L .64252 .34004 L F
.027 0 0 r
.6437 .33904 m .64747 .33907 L .6451 .33954 L F
.242 0 0 r
.64911 .33867 m .6451 .33954 L .64807 .33908 L F
.027 0 0 r
.64747 .33907 m .64807 .33908 L .6451 .33954 L F
.277 .775 .882 r
.6405 .33959 m .64485 .33954 L .64229 .34011 L F
.64485 .33954 m .6451 .33954 L .64229 .34011 L F
.056 0 0 r
.63946 .34077 m .64229 .34011 L .63954 .34073 L F
.71 .181 0 r
.39483 .51717 m .39277 .51485 L .39447 .51931 L F
.946 .619 .376 r
.39701 .51845 m .39483 .51717 L .39447 .51931 L F
.718 .748 .876 r
.54157 .40151 m .54561 .40224 L .54484 .39879 L F
.552 .091 .113 r
.54167 .40383 m .54561 .40224 L .54157 .40151 L F
.54394 .40411 m .54768 .40456 L .54268 .40342 L F
.212 .681 .941 r
.54435 .404 m .54768 .40456 L .54167 .40383 L F
.16 .347 .801 r
.54642 .40469 m .54624 .40535 L .54435 .404 L F
.54624 .40535 m .54576 .40705 L .54455 .40443 L F
.54624 .40535 m .54455 .40443 L .54435 .404 L F
.552 .091 .113 r
.54268 .40342 m .54768 .40456 L .54561 .40224 L F
.54167 .40383 m .54394 .40411 L .54268 .40342 L F
.892 .845 .792 r
.54484 .39879 m .54561 .40224 L .54748 .39859 L F
.2 0 0 r
.54561 .40224 m .54892 .4019 L .54853 .40166 L F
.432 .084 .274 r
.54561 .40224 m .54768 .40456 L .54892 .4019 L F
0 0 0 r
.26224 .55484 m .2603 .55603 L .25903 .55767 L F
.859 .83 .818 r
.52187 .37304 m .51988 .37577 L .5208 .3732 L F
0 0 0 r
.51988 .37577 m .52067 .37589 L .5208 .3732 L F
.51988 .37577 m .51865 .37719 L .52067 .37589 L F
.33 .034 .302 r
.26551 .54919 m .2672 .55071 L .26756 .54806 L F
.241 .72 .936 r
.39802 .59384 m .39763 .59295 L .39465 .59292 L F
.469 .883 .935 r
.4004 .59195 m .39802 .59384 L .40133 .59252 L F
.4004 .59195 m .39763 .59295 L .39802 .59384 L F
.568 .656 .896 r
.39802 .59384 m .40118 .59416 L .40133 .59252 L F
.845 .783 .791 r
.44786 .55848 m .45007 .55485 L .447 .55362 L F
.587 .902 .984 r
.6469 .37696 m .64533 .37891 L .64414 .37803 L F
.6469 .37696 m .648 .37778 L .64533 .37891 L F
.965 .714 .277 r
.57229 .40005 m .57326 .40135 L .57318 .39846 L F
.574 .574 .815 r
.35566 .50117 m .3592 .50075 L .35733 .5001 L F
.611 .953 .909 r
.5308 .43652 m .5332 .43641 L .52886 .43833 L F
.724 .983 .903 r
.53522 .43468 m .5332 .43641 L .5308 .43652 L F
0 0 0 r
.63997 .37929 m .63848 .37914 L .63743 .38042 L F
.63997 .37929 m .64134 .37776 L .63848 .37914 L F
.674 .812 .366 r
.65401 .37448 m .6561 .37023 L .65701 .37106 L F
.969 .934 .656 r
.65701 .37106 m .6561 .37023 L .65744 .36687 L F
.686 .853 .963 r
.44328 .54678 m .44513 .54783 L .44266 .54903 L F
.857 .996 .811 r
.44011 .54975 m .44328 .54678 L .44266 .54903 L F
.49 .804 1 r
.56583 .36526 m .56471 .36396 L .5617 .36461 L F
.5617 .36461 m .56471 .36396 L .56583 .36526 L F
.406 .532 .871 r
.53561 .37956 m .53325 .38204 L .53372 .37986 L F
.53372 .37986 m .53325 .38204 L .53561 .37956 L F
.962 .897 .715 r
.56626 .41802 m .56757 .4159 L .56611 .41433 L F
.831 .556 .523 r
.34945 .51871 m .34562 .52049 L .34509 .51802 L F
.34945 .51871 m .34942 .52138 L .34562 .52049 L F
.365 .826 .742 r
.29289 .65762 m .29227 .65818 L .29143 .65489 L F
.29289 .65762 m .2955 .65679 L .29227 .65818 L F
.878 .939 .854 r
.48604 .51435 m .48452 .51864 L .48698 .515 L F
.849 .996 .827 r
.48898 .5111 m .48698 .515 L .48991 .51189 L F
.48898 .5111 m .48604 .51435 L .48698 .515 L F
.886 .827 .783 r
.51833 .47142 m .51561 .47169 L .51807 .46792 L F
.448 .852 .67 r
.45986 .43005 m .46169 .42912 L .4582 .4313 L F
0 0 0 r
.46411 .42795 m .46169 .42912 L .45986 .43005 L F
.679 .658 .823 r
.31477 .66022 m .30998 .65898 L .31244 .66114 L F
.89 .98 .817 r
.31477 .66022 m .31512 .65775 L .316 .65909 L F
.31477 .66022 m .31244 .66114 L .31512 .65775 L F
.511 .318 .555 r
.31477 .66022 m .31663 .66162 L .316 .65909 L F
.849 .678 .669 r
.38682 .52703 m .39127 .52427 L .38731 .52436 L F
.38682 .52703 m .38925 .52825 L .39127 .52427 L F
.732 .566 .667 r
.28816 .66245 m .28962 .66199 L .28704 .66561 L F
0 0 .278 r
.44601 .54358 m .44624 .54076 L .44791 .54201 L F
.769 .977 .916 r
.44829 .53877 m .44791 .54201 L .44624 .54076 L F
.44829 .53877 m .4514 .53955 L .44791 .54201 L F
.277 .036 .357 r
.26275 .5523 m .26224 .55484 L .26484 .55143 L F
0 0 .442 r
.50471 .41823 m .50565 .42144 L .50573 .41952 L F
0 .211 .736 r
.50565 .42144 m .50722 .42267 L .50573 .41952 L F
.702 .69 .152 r
.43189 .58544 m .43202 .58476 L .43249 .58201 L F
0 0 0 r
.50142 .41008 m .49935 .41173 L .50199 .40819 L F
.50142 .41008 m .50199 .40819 L .50062 .40709 L F
.846 .937 .885 r
.50338 .40399 m .50199 .40819 L .50503 .40588 L F
.50338 .40399 m .50062 .40709 L .50199 .40819 L F
.573 .916 .705 r
.4582 .4313 m .45434 .43393 L .4576 .43146 L F
.454 .865 .71 r
.4582 .4313 m .4576 .43146 L .45986 .43005 L F
.045 .357 .83 r
.31819 .63622 m .32003 .63869 L .32051 .63731 L F
0 0 .261 r
.32003 .63869 m .32077 .64055 L .32051 .63731 L F
.572 .815 .435 r
.25777 .55935 m .25633 .56125 L .25903 .55767 L F
.456 .204 .442 r
.26709 .56889 m .26787 .57268 L .26581 .57201 L F
.041 0 .418 r
.26969 .56949 m .26709 .56889 L .26965 .56672 L F
.26969 .56949 m .26787 .57268 L .26709 .56889 L F
.303 0 .1 r
.49958 .42893 m .49615 .43126 L .50012 .43015 L F
.434 .015 .142 r
.50164 .43018 m .49958 .42893 L .50012 .43015 L F
.669 .16 0 r
.58208 .41175 m .58567 .41548 L .5823 .41441 L F
.439 .776 .997 r
.58567 .41548 m .58776 .41547 L .5823 .41441 L F
.99 .828 .45 r
.6569 .39069 m .65734 .38855 L .6565 .38712 L F
.834 .869 .424 r
.65734 .38855 m .65882 .38343 L .6565 .38712 L F
.45 .684 .965 r
.28479 .64757 m .28648 .64967 L .28356 .64927 L F
.671 .744 .905 r
.5527 .34107 m .55724 .34204 L .55586 .3392 L F
0 .452 .7 r
.55724 .34204 m .55674 .34192 L .5527 .34107 L F
.514 .654 .921 r
.5588 .3391 m .55724 .34204 L .55586 .3392 L F
.5588 .3391 m .55995 .34153 L .55724 .34204 L F
0 .345 .754 r
.5601 .34389 m .55724 .34204 L .55995 .34153 L F
.5601 .34389 m .55674 .34192 L .55724 .34204 L F
.149 .683 .853 r
.59565 .34384 m .59836 .34376 L .59989 .34406 L F
0 .561 .771 r
.59989 .34406 m .59836 .34376 L .60244 .34431 L F
.626 .66 .864 r
.25033 .59401 m .24646 .59576 L .24684 .59464 L F
.388 .222 .532 r
.24929 .59705 m .24646 .59576 L .25033 .59401 L F
.24929 .59705 m .24727 .59825 L .24646 .59576 L F
0 0 0 r
.30373 .59852 m .30178 .60227 L .30272 .60059 L F
.859 .83 .818 r
.52187 .37304 m .5208 .3732 L .52098 .37104 L F
0 0 .185 r
.52366 .36979 m .52187 .37304 L .52098 .37104 L F
.52366 .36979 m .52351 .37343 L .52187 .37304 L F
.707 .364 .394 r
.34884 .50743 m .35323 .50778 L .35307 .50531 L F
.476 .191 .4 r
.35307 .50531 m .35323 .50778 L .35565 .50476 L F
.544 .128 .202 r
.2402 .61043 m .243 .60899 L .24013 .61044 L F
.2402 .61043 m .24182 .61147 L .243 .60899 L F
.91 .777 .702 r
.36893 .56208 m .36492 .56442 L .36702 .56094 L F
.36893 .56208 m .36842 .56476 L .36492 .56442 L F
.125 0 0 r
.418 .45776 m .42052 .45689 L .42188 .45487 L F
0 0 0 r
.42052 .45689 m .42404 .4538 L .42188 .45487 L F
.444 .272 .552 r
.53901 .40188 m .54167 .40383 L .54157 .40151 L F
.53901 .40188 m .53919 .40498 L .54167 .40383 L F
.31 0 0 r
.58665 .37023 m .59059 .37076 L .58749 .37065 L F
.856 .987 .848 r
.44315 .5745 m .44131 .57843 L .44384 .57497 L F
0 0 .443 r
.44395 .57221 m .44455 .57244 L .44384 .57497 L F
.699 .952 .68 r
.44455 .57244 m .44384 .57497 L .44717 .57179 L F
.807 .987 .725 r
.44384 .57497 m .44455 .57244 L .44315 .5745 L F
.925 .974 .726 r
.31381 .51555 m .31154 .51929 L .31149 .51685 L F
.723 .432 .486 r
.31149 .51685 m .31637 .51455 L .31381 .51555 L F
.879 .883 .833 r
.47681 .52901 m .47773 .52435 L .4751 .5277 L F
.47681 .52901 m .47941 .52564 L .47773 .52435 L F
.927 .549 .26 r
.33846 .50902 m .33684 .51004 L .33711 .50707 L F
.33846 .50902 m .33899 .51134 L .33684 .51004 L F
.734 .377 .375 r
.39449 .538 m .39726 .54039 L .39954 .53823 L F
.749 .399 .389 r
.39726 .54039 m .40014 .5407 L .39954 .53823 L F
.769 .658 .739 r
.30733 .65157 m .3056 .64547 L .30768 .64962 L F
.832 .998 .775 r
.30691 .65115 m .30733 .65157 L .30768 .64962 L F
.278 .753 .935 r
.3044 .65172 m .30783 .65207 L .30733 .65157 L F
.582 .418 .624 r
.30733 .65157 m .30433 .65472 L .3044 .65172 L F
.832 .998 .775 r
.30613 .65269 m .30733 .65157 L .30691 .65115 L F
.278 .753 .935 r
.30783 .65207 m .30864 .65216 L .30733 .65157 L F
.034 .554 .866 r
.45007 .55485 m .44926 .55422 L .447 .55362 L F
.45007 .55485 m .44926 .55422 L .447 .55362 L F
.828 .994 .858 r
.45342 .55165 m .44926 .55422 L .45007 .55485 L F
.727 .681 .806 r
.38315 .56809 m .38776 .56907 L .38759 .56599 L F
.649 .485 .648 r
.38545 .57202 m .38776 .56907 L .38315 .56809 L F
.38545 .57202 m .3885 .57191 L .38776 .56907 L F
.583 .569 .803 r
.38759 .56599 m .38776 .56907 L .39006 .56762 L F
0 0 .456 r
.38776 .56907 m .38903 .57012 L .39006 .56762 L F
.38776 .56907 m .3885 .57191 L .38903 .57012 L F
0 0 0 r
.5048 .4404 m .50326 .44215 L .50521 .43856 L F
.947 .836 .701 r
.50292 .43555 m .50506 .43728 L .50603 .43345 L F
0 .373 .796 r
.50455 .4363 m .50506 .43728 L .50292 .43555 L F
.737 .7 .162 r
.50533 .4378 m .50603 .43345 L .50506 .43728 L F
0 .373 .796 r
.50594 .43694 m .50506 .43728 L .50455 .4363 L F
.788 .78 .846 r
.49616 .43866 m .5009 .43781 L .49896 .4333 L F
.322 .506 .883 r
.49896 .4333 m .5009 .43781 L .50292 .43555 L F
0 0 0 r
.50292 .43555 m .5009 .43781 L .49935 .44043 L F
.555 .106 .139 r
.49935 .44043 m .5009 .43781 L .49616 .43866 L F
0 0 0 r
.50292 .43555 m .49935 .44043 L .50079 .43777 L F
.697 .31 .311 r
.50079 .43777 m .50499 .43811 L .50292 .43555 L F
0 .373 .796 r
.50633 .43712 m .50596 .43717 L .50594 .43694 L F
.50596 .43717 m .50506 .43728 L .50594 .43694 L F
.737 .7 .162 r
.50521 .43856 m .50533 .4378 L .50506 .43728 L F
0 .373 .796 r
.50633 .43712 m .50292 .43555 L .50499 .43811 L F
.498 0 0 r
.50343 .43929 m .50499 .43811 L .50079 .43777 L F
.947 .836 .701 r
.50292 .43555 m .50603 .43345 L .50493 .43179 L F
.826 .706 .171 r
.5048 .4404 m .50521 .43856 L .50506 .43728 L F
.81 .843 .875 r
.50632 .43814 m .50383 .44278 L .50588 .43815 L F
.648 .192 .156 r
.50588 .43813 m .5059 .43815 L .50632 .43814 L F
0 0 0 r
.50588 .43813 m .50597 .4379 L .50633 .43712 L F
.826 .706 .171 r
.50562 .43864 m .50506 .43728 L .50588 .43718 L F
.50601 .43781 m .50588 .43718 L .50633 .43712 L F
.50562 .43864 m .50588 .43718 L .50601 .43781 L F
.81 .843 .875 r
.50588 .43813 m .50633 .43712 L .50499 .43811 L F
.50632 .43814 m .50633 .43712 L .50588 .43813 L F
0 0 0 r
.50588 .43815 m .50588 .43813 L .50633 .43712 L F
.81 .843 .875 r
.50632 .43814 m .50588 .43815 L .50633 .43712 L F
.628 .786 .34 r
.50293 .44444 m .50383 .44278 L .50632 .43814 L F
.50293 .44444 m .50632 .43814 L .50443 .4429 L F
.396 .121 .374 r
.50443 .4429 m .50632 .43814 L .50791 .44022 L F
.648 .192 .156 r
.5059 .43815 m .50791 .44022 L .50632 .43814 L F
.50499 .43811 m .50571 .43862 L .50588 .43813 L F
.50571 .43862 m .50791 .44022 L .50588 .43813 L F
.433 .832 .98 r
.50946 .43756 m .50925 .43818 L .50589 .43812 L F
.50596 .43799 m .50589 .43812 L .50499 .43811 L F
.50946 .43756 m .50589 .43812 L .50596 .43799 L F
0 0 0 r
.50383 .44278 m .5048 .4404 L .50562 .43864 L F
.50575 .43839 m .50562 .43864 L .50597 .4379 L F
.50383 .44278 m .50562 .43864 L .50575 .43839 L F
.50383 .44278 m .50597 .4379 L .50588 .43815 L F
.648 .192 .156 r
.50625 .43901 m .50925 .43818 L .50791 .44022 L F
.50499 .43811 m .50607 .43813 L .50625 .43901 L F
.50607 .43813 m .50925 .43818 L .50625 .43901 L F
.826 .706 .171 r
.5048 .4404 m .50488 .4395 L .50562 .43864 L F
.50488 .4395 m .50506 .43728 L .50562 .43864 L F
.433 .832 .98 r
.50946 .43756 m .50925 .43818 L .50607 .43813 L F
.50622 .43796 m .50607 .43813 L .50499 .43811 L F
.50946 .43756 m .50607 .43813 L .50622 .43796 L F
.647 .69 .876 r
.50531 .43331 m .50946 .43756 L .50499 .43811 L F
.50531 .43331 m .50499 .43811 L .50622 .43582 L F
.711 .93 .604 r
.50589 .43623 m .50499 .43811 L .50343 .43929 L F
.50622 .43582 m .5059 .43641 L .50589 .43623 L F
.5059 .43641 m .50499 .43811 L .50589 .43623 L F
.468 .289 .554 r
.5053 .45597 m .50836 .45847 L .50928 .45577 L F
.5053 .45597 m .50928 .45577 L .50459 .45697 L F
.458 .294 .57 r
.3952 .49196 m .39787 .4941 L .39869 .4915 L F
.3952 .49196 m .39536 .49495 L .39787 .4941 L F
.894 .76 .707 r
.36842 .56476 m .36408 .56708 L .36492 .56442 L F
.36842 .56476 m .36624 .56826 L .36408 .56708 L F
.733 .515 .597 r
.32422 .57969 m .32012 .58115 L .32004 .57865 L F
0 0 0 r
.34506 .66985 m .34678 .6686 L .34617 .66905 L F
0 0 .404 r
.3576 .64398 m .35809 .6471 L .35685 .64884 L F
0 0 .033 r
.35809 .6471 m .35649 .65167 L .35685 .64884 L F
.869 .723 .697 r
.36785 .57208 m .36538 .57183 L .36624 .56826 L F
.918 .524 .211 r
.36759 .57492 m .36538 .57183 L .36785 .57208 L F
.851 .497 .383 r
.35927 .53466 m .3555 .5311 L .35915 .53198 L F
.862 .592 .529 r
.66689 .34082 m .66829 .33852 L .66416 .33746 L F
.66689 .34082 m .6683 .34116 L .66829 .33852 L F
.697 .182 .002 r
.49799 .41334 m .50087 .41566 L .497 .41461 L F
0 0 0 r
.49799 .41334 m .49598 .41497 L .49622 .41476 L F
.697 .182 .002 r
.49799 .41334 m .497 .41461 L .49646 .41446 L F
0 0 0 r
.49893 .41214 m .49799 .41334 L .49622 .41476 L F
.49935 .41173 m .49799 .41334 L .49893 .41214 L F
.413 .091 .307 r
.50142 .41008 m .49799 .41334 L .49935 .41173 L F
.904 .955 .617 r
.50845 .40794 m .50663 .41179 L .50651 .40946 L F
0 .031 .525 r
.50663 .41179 m .50612 .41124 L .50651 .40946 L F
.50663 .41179 m .50911 .41412 L .50612 .41124 L F
.363 .25 .589 r
.50685 .41502 m .50911 .41412 L .50663 .41179 L F
.346 0 .17 r
.42768 .56468 m .43036 .56427 L .43094 .56194 L F
.604 .838 .46 r
.43094 .56194 m .43175 .56073 L .43356 .55835 L F
0 0 0 r
.43094 .56194 m .43036 .56427 L .43175 .56073 L F
.492 0 0 r
.28648 .6747 m .28755 .67343 L .28989 .67488 L F
.699 .803 .929 r
.60347 .35353 m .60375 .35401 L .60395 .35127 L F
0 0 0 r
.2511 .58199 m .25323 .58082 L .25432 .57872 L F
0 0 .472 r
.25432 .57872 m .25517 .57421 L .25362 .5749 L F
.25432 .57872 m .25574 .57741 L .25517 .57421 L F
.716 .815 .354 r
.25432 .57872 m .25372 .57945 L .25574 .57741 L F
.25432 .57872 m .25323 .58082 L .25372 .57945 L F
0 0 .208 r
.31206 .58794 m .31547 .58552 L .31433 .58786 L F
.31206 .58794 m .31109 .58379 L .31547 .58552 L F
.31206 .58794 m .31199 .58724 L .31109 .58379 L F
.482 .282 .532 r
.31433 .58786 m .31424 .59081 L .31206 .58794 L F
0 0 .514 r
.31206 .58794 m .31424 .59081 L .31199 .58724 L F
.507 .365 .623 r
.51567 .4079 m .51611 .41116 L .51334 .41188 L F
.394 .202 .499 r
.51577 .4136 m .51334 .41188 L .51611 .41116 L F
.51577 .4136 m .51335 .41437 L .51334 .41188 L F
.791 .992 .88 r
.31633 .64768 m .31785 .64781 L .32101 .645 L F
.876 .592 .505 r
.33899 .51134 m .34142 .51193 L .34135 .51446 L F
.958 .785 .626 r
.38673 .55138 m .38856 .55513 L .38899 .55244 L F
.447 .518 .838 r
.24748 .60411 m .24682 .60777 L .24488 .60447 L F
.24748 .60411 m .24912 .60768 L .24682 .60777 L F
.955 .894 .507 r
.58755 .38233 m .58663 .38431 L .58794 .37866 L F
.847 .828 .829 r
.51967 .39789 m .51933 .40229 L .52308 .39784 L F
.813 .946 .91 r
.51797 .48637 m .52216 .485 L .52096 .48409 L F
.911 .957 .808 r
.52096 .48409 m .52216 .485 L .5246 .48135 L F
.873 .94 .859 r
.48452 .51864 m .48314 .51762 L .4803 .52084 L F
.878 .939 .854 r
.48604 .51435 m .48314 .51762 L .48452 .51864 L F
.755 .876 .934 r
.32359 .62301 m .31773 .62436 L .32161 .62137 L F
.774 .805 .878 r
.32161 .62137 m .32603 .62165 L .32359 .62301 L F
.892 .845 .792 r
.54484 .39879 m .54748 .39859 L .54623 .3965 L F
.794 .866 .903 r
.29014 .63431 m .28618 .63467 L .28865 .63405 L F
.665 .955 .948 r
.29052 .63255 m .29014 .63431 L .28865 .63405 L F
.29052 .63255 m .29346 .63238 L .29014 .63431 L F
.674 .812 .366 r
.65401 .37448 m .65407 .3742 L .6561 .37023 L F
.729 .297 .223 r
.28848 .5559 m .28969 .55748 L .2909 .55534 L F
.28848 .5559 m .28969 .55748 L .2909 .55534 L F
.082 0 0 r
.42058 .4644 m .41871 .46661 L .41644 .46736 L F
.08 0 0 r
.42058 .4644 m .42243 .46442 L .41871 .46661 L F
0 .047 .563 r
.5201 .42334 m .51914 .42492 L .51882 .4219 L F
0 0 0 r
.51872 .42703 m .51914 .42492 L .5201 .42334 L F
.796 .707 .766 r
.52252 .43848 m .52343 .44172 L .5194 .44177 L F
.588 .875 .993 r
.5194 .44177 m .52343 .44172 L .52176 .44054 L F
.995 .764 .464 r
.52252 .43848 m .52324 .44103 L .52176 .44054 L F
.796 .707 .766 r
.52252 .43848 m .5194 .44177 L .51896 .43837 L F
.7 .963 .941 r
.51985 .4399 m .52176 .44054 L .52286 .43837 L F
.51934 .44016 m .52176 .44054 L .51985 .4399 L F
.995 .764 .464 r
.52324 .44103 m .52343 .44172 L .52176 .44054 L F
.467 .818 .997 r
.52176 .44054 m .52343 .44172 L .5257 .44098 L F
.435 .457 .784 r
.52343 .44172 m .52666 .44524 L .5257 .44098 L F
.789 .644 .702 r
.3816 .5716 m .38545 .57202 L .38315 .56809 L F
.603 .086 0 r
.3816 .5716 m .38455 .57334 L .38545 .57202 L F
.655 .223 .211 r
.38455 .57334 m .3885 .57191 L .38545 .57202 L F
.897 .973 .817 r
.58776 .41547 m .58296 .41739 L .5823 .41441 L F
.58776 .41547 m .58538 .41599 L .58296 .41739 L F
.58776 .41547 m .58663 .41715 L .58538 .41599 L F
.58538 .41599 m .58663 .41715 L .58776 .41547 L F
.269 0 0 r
.39463 .47041 m .39364 .46878 L .39197 .47065 L F
.39463 .47041 m .39629 .46823 L .39364 .46878 L F
.959 .847 .689 r
.52846 .44776 m .53034 .44928 L .52897 .4518 L F
.936 .809 .695 r
.31721 .57159 m .31593 .5751 L .31428 .57364 L F
.31721 .57159 m .31428 .57364 L .31543 .57321 L F
.31721 .57159 m .31543 .57321 L .31722 .57078 L F
.343 .526 .892 r
.30152 .68468 m .30199 .68616 L .30305 .68418 L F
.502 .726 .973 r
.30199 .68616 m .30514 .68596 L .30305 .68418 L F
.962 .638 .345 r
.51778 .46534 m .51807 .46792 L .51642 .46647 L F
.861 .985 .847 r
.51778 .46534 m .51829 .46276 L .52015 .46269 L F
.51778 .46534 m .51709 .46405 L .51829 .46276 L F
.969 .9 .539 r
.51778 .46534 m .51642 .46647 L .51709 .46405 L F
.962 .638 .345 r
.51778 .46534 m .51807 .46792 L .51642 .46647 L F
.643 .457 .616 r
.52203 .43513 m .52252 .43848 L .51896 .43837 L F
.121 .144 .61 r
.52307 .43025 m .52203 .43513 L .52386 .43369 L F
.481 .859 .64 r
.52386 .43369 m .52203 .43513 L .5201 .43629 L F
.372 .267 .604 r
.52203 .43513 m .52468 .43734 L .52386 .43369 L F
.52203 .43513 m .52252 .43848 L .52468 .43734 L F
.842 .754 .766 r
.42645 .57507 m .43102 .57483 L .42891 .57397 L F
.765 .439 0 r
.24903 .62089 m .24947 .62235 L .2481 .61859 L F
.456 .293 .57 r
.24903 .62089 m .25178 .62128 L .24947 .62235 L F
.24947 .62235 m .25178 .62128 L .24903 .62089 L F
.939 .569 .228 r
.58521 .35038 m .58613 .35381 L .58782 .35446 L F
.382 .139 .417 r
.58782 .35446 m .59028 .35404 L .59063 .35166 L F
.042 .608 .775 r
.58613 .35381 m .59028 .35404 L .58782 .35446 L F
.369 .144 .436 r
.26756 .54806 m .27027 .54463 L .26792 .54541 L F
.904 .955 .617 r
.50845 .40794 m .50651 .40946 L .50787 .40722 L F
.775 .754 .833 r
.51188 .40532 m .50845 .40794 L .50731 .4044 L F
.279 .738 .952 r
.30877 .65826 m .30943 .6589 L .30582 .65843 L F
.267 0 0 r
.30675 .65986 m .30877 .65826 L .30582 .65843 L F
.942 .957 .66 r
.30782 .65733 m .30877 .65826 L .30675 .65986 L F
.30893 .65468 m .30877 .65826 L .30782 .65733 L F
.279 .738 .952 r
.30877 .65826 m .30998 .65898 L .30943 .6589 L F
.436 .294 .589 r
.31266 .65875 m .30998 .65898 L .30877 .65826 L F
.31266 .65875 m .31244 .66114 L .30998 .65898 L F
.35 .134 .439 r
.34825 .6278 m .35026 .62514 L .3503 .62766 L F
.34825 .6278 m .35026 .62514 L .3503 .62766 L F
.941 .944 .759 r
.3485 .62601 m .3503 .62766 L .34857 .62583 L F
.658 .73 .902 r
.34825 .6278 m .3513 .62858 L .3503 .62766 L F
.187 0 0 r
.34518 .62907 m .34825 .6278 L .34627 .63028 L F
.217 0 0 r
.34627 .63028 m .34825 .6278 L .3503 .62766 L F
.34627 .63028 m .3503 .62766 L .34673 .6306 L F
0 .146 .69 r
.34793 .63141 m .34848 .63237 L .34627 .63028 L F
.217 0 0 r
.34627 .63028 m .34673 .6306 L .34672 .63061 L F
.941 .944 .759 r
.34673 .63059 m .3503 .62766 L .3485 .62601 L F
.34672 .63061 m .34673 .6306 L .34673 .63059 L F
.34673 .6306 m .3503 .62766 L .34673 .63059 L F
.875 .844 .811 r
.34672 .63061 m .34687 .62903 L .34649 .62895 L F
.34687 .62903 m .34721 .62561 L .34649 .62895 L F
.467 .284 .548 r
.34649 .62895 m .34451 .62645 L .3434 .62874 L F
.34451 .62645 m .34415 .626 L .3434 .62874 L F
.519 .819 .999 r
.34267 .63025 m .3434 .62874 L .34224 .63077 L F
.34469 .62776 m .34649 .62895 L .3434 .62874 L F
.34469 .62776 m .3434 .62874 L .34267 .63025 L F
.491 0 0 r
.3459 .62881 m .34649 .62895 L .34469 .62776 L F
0 .146 .69 r
.34649 .62895 m .34673 .6306 L .3464 .62951 L F
.3464 .62951 m .34673 .6306 L .34627 .63028 L F
0 .127 .676 r
.34627 .63028 m .34672 .63061 L .34649 .62895 L F
.875 .844 .811 r
.34672 .63058 m .34857 .62583 L .34721 .62561 L F
.34672 .63061 m .34673 .63059 L .34672 .63058 L F
.34673 .63059 m .34857 .62583 L .34672 .63058 L F
0 .146 .69 r
.34649 .62895 m .34793 .63141 L .34673 .6306 L F
.34673 .63059 m .34673 .6306 L .34673 .6306 L F
.34649 .62895 m .34673 .6306 L .34673 .63059 L F
.491 0 0 r
.34716 .6299 m .34649 .62895 L .3459 .62881 L F
.658 .73 .902 r
.3513 .62858 m .35216 .6288 L .3503 .62766 L F
.895 .694 .623 r
.35216 .6288 m .35026 .62514 L .3503 .62766 L F
.324 0 .195 r
.4061 .46212 m .40537 .46394 L .40859 .46145 L F
.242 .462 .873 r
.35508 .63384 m .35375 .63556 L .35187 .63232 L F
0 0 0 r
.35263 .63799 m .35375 .63556 L .35508 .63384 L F
.98 .876 .509 r
.27141 .65134 m .27302 .64875 L .27236 .65119 L F
.27236 .65119 m .27302 .64875 L .27141 .65134 L F
.863 .86 .409 r
.67604 .35332 m .67497 .35817 L .67597 .35559 L F
.781 .795 .864 r
.32424 .61856 m .32603 .62165 L .32161 .62137 L F
.677 .753 .908 r
.32823 .61912 m .32603 .62165 L .32424 .61856 L F
.434 .439 .766 r
.53515 .38553 m .53649 .38457 L .53516 .3849 L F
.53515 .38553 m .53831 .38709 L .53745 .38388 L F
.569 .426 .647 r
.53601 .38459 m .53657 .38708 L .53685 .38609 L F
.876 .507 .344 r
.53749 .38628 m .53706 .38648 L .53685 .38609 L F
.53749 .3862 m .53685 .38609 L .53645 .38507 L F
.434 .439 .766 r
.53649 .38457 m .53745 .38388 L .53636 .38436 L F
.63 .568 .766 r
.53601 .38459 m .53831 .38709 L .53745 .38388 L F
.823 .938 .571 r
.53685 .38609 m .5398 .38274 L .53745 .38388 L F
.53657 .38708 m .537 .3865 L .53685 .38609 L F
.876 .507 .344 r
.53757 .38739 m .53766 .38875 L .53679 .38655 L F
.53698 .38634 m .53679 .38655 L .53601 .38459 L F
.53757 .38739 m .53679 .38655 L .53698 .38634 L F
.53645 .38507 m .53685 .38609 L .53601 .38459 L F
.569 .426 .647 r
.53601 .38459 m .53685 .38609 L .53745 .38388 L F
.742 .775 .88 r
.53681 .3866 m .53657 .38708 L .53601 .38459 L F
.823 .938 .571 r
.53657 .38708 m .53681 .3866 L .537 .3865 L F
.742 .775 .88 r
.53766 .38875 m .53657 .38708 L .53681 .3866 L F
.823 .938 .571 r
.53657 .38708 m .5367 .38665 L .53681 .3866 L F
.5367 .38665 m .53664 .38562 L .53745 .38403 L F
.53657 .38708 m .53659 .38677 L .5367 .38665 L F
.53659 .38677 m .53664 .38562 L .5367 .38665 L F
.537 .3865 m .5398 .38274 L .53685 .38609 L F
.537 .3865 m .53745 .38403 L .5398 .38274 L F
.5367 .38665 m .53745 .38403 L .537 .3865 L F
.876 .507 .344 r
.53749 .3862 m .53749 .38628 L .53685 .38609 L F
.53749 .38628 m .53757 .38739 L .53706 .38648 L F
.53831 .38709 m .5382 .38736 L .53749 .3862 L F
.5382 .38736 m .53766 .38875 L .53749 .3862 L F
.434 .439 .766 r
.53649 .38457 m .53636 .38436 L .53516 .3849 L F
.128 .268 .74 r
.51254 .42499 m .51393 .42815 L .51475 .42607 L F
.265 .432 .841 r
.51475 .42607 m .51393 .42815 L .51614 .42828 L F
.42 .194 .462 r
.30606 .60097 m .30373 .59852 L .30272 .60059 L F
.30606 .60097 m .30631 .5979 L .30373 .59852 L F
.374 .839 .804 r
.62766 .39432 m .62695 .39431 L .62455 .39535 L F
.394 .841 .928 r
.63047 .39359 m .62923 .39324 L .62766 .39432 L F
.416 .863 .808 r
.62766 .39432 m .62923 .39324 L .62695 .39431 L F
.897 .845 .785 r
.54565 .45077 m .54889 .45101 L .54964 .44895 L F
.917 .837 .752 r
.54467 .45338 m .54889 .45101 L .54565 .45077 L F
.54467 .45338 m .54645 .45466 L .54889 .45101 L F
.813 .78 .822 r
.39039 .56359 m .38759 .56599 L .39039 .56522 L F
.583 .569 .803 r
.38759 .56599 m .39006 .56762 L .39039 .56522 L F
.585 .54 .771 r
.39039 .56522 m .39173 .56115 L .39039 .56359 L F
.39039 .56522 m .39328 .56458 L .39173 .56115 L F
.027 0 .008 r
.39006 .56762 m .39328 .56458 L .39039 .56522 L F
.764 .988 .896 r
.45427 .54982 m .45224 .55115 L .45342 .55165 L F
.828 .994 .858 r
.45342 .55165 m .45224 .55115 L .44926 .55422 L F
.158 0 .316 r
.3222 .65195 m .31985 .65564 L .32156 .65458 L F
0 0 0 r
.32156 .65458 m .31985 .65564 L .31801 .65802 L F
.425 .415 .744 r
.55136 .40071 m .54853 .40166 L .54892 .4019 L F
.595 .931 .955 r
.51137 .42106 m .51072 .42196 L .51327 .41981 L F
.661 .416 .539 r
.3681 .51491 m .37284 .51469 L .37197 .51216 L F
.669 .524 .678 r
.37284 .51469 m .37556 .51192 L .37197 .51216 L F
.551 .835 .998 r
.28748 .5254 m .28585 .52406 L .28841 .52343 L F
.939 .694 .542 r
.28841 .52343 m .29073 .52734 L .28748 .5254 L F
.859 .835 .822 r
.31764 .59406 m .3199 .59474 L .31876 .59149 L F
.83 .899 .889 r
.31365 .59603 m .3199 .59474 L .31764 .59406 L F
.76 .79 .877 r
.31876 .59149 m .3199 .59474 L .32285 .59205 L F
.717 .759 .885 r
.33561 .61854 m .33302 .62108 L .33112 .61804 L F
.56 .061 0 r
.51068 .4318 m .50735 .42831 L .50733 .43134 L F
.631 .628 .829 r
.49958 .48955 m .49551 .4875 L .49767 .48781 L F
.778 .803 .873 r
.5014 .48786 m .49958 .48955 L .49767 .48781 L F
.611 .953 .909 r
.5308 .43652 m .52886 .43833 L .52908 .43823 L F
.847 .828 .829 r
.51967 .39789 m .52308 .39784 L .52243 .39686 L F
.941 .926 .563 r
.52433 .39238 m .52243 .39686 L .52308 .39784 L F
.867 .637 .588 r
.36845 .55544 m .36773 .55816 L .36547 .55445 L F
.999 .845 .538 r
.4522 .53683 m .45162 .53631 L .45329 .53525 L F
.584 .924 .961 r
.45329 .53525 m .45441 .53357 L .45544 .534 L F
.646 .931 .665 r
.45329 .53525 m .45162 .53631 L .45441 .53357 L F
0 0 0 r
.58412 .407 m .58208 .41175 L .58374 .41011 L F
.166 .049 .465 r
.58208 .41175 m .58483 .41173 L .58374 .41011 L F
.58208 .41175 m .5823 .41441 L .58483 .41173 L F
.889 .967 .834 r
.4522 .53683 m .4514 .53955 L .44829 .53877 L F
.821 .611 .619 r
.52519 .35981 m .52632 .36129 L .52696 .3585 L F
.884 .876 .439 r
.28403 .67371 m .28354 .677 L .28174 .67572 L F
.635 .36 .485 r
.43452 .57784 m .43729 .57803 L .43716 .57539 L F
.485 .527 .825 r
.43729 .57803 m .43578 .57396 L .43716 .57539 L F
.833 .825 .84 r
.30904 .60767 m .30802 .60484 L .30707 .60645 L F
.661 .661 .839 r
.30892 .60033 m .31066 .60407 L .31076 .60172 L F
.833 .825 .84 r
.31027 .60631 m .31145 .605 L .31051 .60496 L F
.31027 .60631 m .31051 .60496 L .30802 .60484 L F
.865 .66 .623 r
.31145 .605 m .31163 .60614 L .30802 .60484 L F
.661 .661 .839 r
.31066 .60407 m .31163 .60614 L .31092 .60256 L F
.31066 .60407 m .31092 .60256 L .31076 .60172 L F
.833 .825 .84 r
.30904 .60767 m .31027 .60631 L .30802 .60484 L F
.156 0 .209 r
.26388 .57541 m .26297 .57794 L .26111 .57862 L F
.303 .197 .564 r
.26297 .57794 m .26313 .58062 L .26111 .57862 L F
.768 .582 .646 r
.65332 .35152 m .64919 .35165 L .64929 .34836 L F
.623 .179 .175 r
.65332 .35152 m .65176 .35353 L .64919 .35165 L F
.637 .195 .184 r
.65603 .35354 m .65176 .35353 L .65332 .35152 L F
.46 .846 .982 r
.60931 .34465 m .61192 .34402 L .61345 .34464 L F
.225 .705 .935 r
.61192 .34402 m .61623 .34474 L .61345 .34464 L F
.422 .493 .828 r
.24748 .60112 m .24356 .59921 L .24727 .59825 L F
.858 .965 .869 r
.31154 .51929 m .30826 .51996 L .31149 .51685 L F
.508 .875 .655 r
.46849 .43425 m .47226 .43163 L .47064 .43253 L F
0 0 0 r
.47399 .43039 m .47226 .43163 L .47353 .4308 L F
.428 .835 .643 r
.47064 .43253 m .47226 .43163 L .47399 .43039 L F
.885 .6 .5 r
.35548 .5285 m .35288 .52777 L .353 .52513 L F
.91 .604 .453 r
.3555 .5311 m .35288 .52777 L .35548 .5285 L F
.934 .769 .654 r
.24615 .60239 m .24488 .60447 L .24298 .60084 L F
.852 .987 .853 r
.46381 .52172 m .46564 .51794 L .46655 .51806 L F
.626 .955 .923 r
.46655 .51806 m .46762 .51624 L .46977 .51631 L F
.666 .971 .806 r
.46655 .51806 m .46564 .51794 L .46762 .51624 L F
0 0 .126 r
.25087 .58463 m .25323 .58082 L .2511 .58199 L F
0 0 0 r
.5885 .41311 m .58776 .41547 L .58883 .4117 L F
0 0 .3 r
.58918 .41059 m .58883 .4117 L .58873 .40766 L F
0 0 0 r
.5885 .41311 m .58883 .4117 L .58918 .41059 L F
.427 .147 .384 r
.26625 .57463 m .26297 .57794 L .26388 .57541 L F
.178 0 .339 r
.55958 .35116 m .56139 .35058 L .56158 .34831 L F
.715 .873 .956 r
.62321 .36099 m .62716 .36083 L .62597 .36011 L F
.62716 .36083 m .62321 .36099 L .62597 .36011 L F
.57 .612 .855 r
.62716 .36083 m .62982 .36021 L .62853 .35672 L F
.924 .973 .702 r
.49185 .49094 m .49359 .48612 L .49551 .4875 L F
.49185 .49094 m .49092 .49062 L .49359 .48612 L F
.878 .986 .823 r
.49163 .5079 m .48991 .51189 L .49271 .50862 L F
.49163 .5079 m .48898 .5111 L .48991 .51189 L F
.923 .888 .779 r
.65733 .35497 m .65371 .35715 L .65603 .35354 L F
.65733 .35497 m .65513 .3586 L .65371 .35715 L F
.27 .776 .825 r
.61623 .34474 m .61905 .34409 L .62025 .34412 L F
.173 .71 .793 r
.62025 .34412 m .61905 .34409 L .62296 .34373 L F
.375 .799 .972 r
.44131 .57843 m .44005 .57746 L .43729 .57803 L F
.876 .577 .479 r
.43729 .57803 m .44022 .58094 L .44131 .57843 L F
.856 .987 .848 r
.44315 .5745 m .44005 .57746 L .44131 .57843 L F
.722 .261 .155 r
.54284 .39625 m .54449 .39456 L .54313 .39627 L F
.911 .957 .808 r
.52096 .48409 m .5246 .48135 L .52389 .48094 L F
.744 .993 .863 r
.52594 .47887 m .5246 .48135 L .52831 .47943 L F
.52594 .47887 m .52389 .48094 L .5246 .48135 L F
.288 0 0 r
.50227 .44396 m .50383 .44278 L .50293 .44444 L F
.3 .53 .907 r
.49935 .44099 m .50233 .4434 L .50109 .44311 L F
0 0 0 r
.50233 .4434 m .50326 .44215 L .50393 .44139 L F
.50233 .4434 m .50393 .44139 L .50374 .44168 L F
.50233 .4434 m .5048 .4404 L .50383 .44278 L F
.50233 .4434 m .50383 .44278 L .50109 .44311 L F
.288 0 0 r
.50109 .44311 m .50296 .44289 L .50227 .44396 L F
.50296 .44289 m .50383 .44278 L .50227 .44396 L F
0 0 0 r
.50374 .44168 m .50393 .44139 L .5048 .4404 L F
.671 .958 .733 r
.50555 .39434 m .50673 .3925 L .50855 .39134 L F
.50555 .39434 m .50511 .39422 L .50673 .3925 L F
.842 .619 .601 r
.3215 .53205 m .32075 .53476 L .31884 .53123 L F
.863 .639 .598 r
.32545 .56034 m .32197 .56087 L .32314 .55849 L F
.986 .729 .454 r
.32356 .5645 m .32197 .56087 L .32545 .56034 L F
.622 .639 .846 r
.51195 .40222 m .51222 .39939 L .51027 .40092 L F
0 .449 .86 r
.51027 .40092 m .51485 .40342 L .51195 .40222 L F
.927 .755 .648 r
.33387 .53743 m .33549 .54173 L .33597 .53864 L F
.33387 .53743 m .33206 .54073 L .33549 .54173 L F
.909 .677 .576 r
.33136 .54345 m .33549 .54173 L .33206 .54073 L F
.33136 .54345 m .33605 .54598 L .33549 .54173 L F
.164 0 .378 r
.27063 .54194 m .27197 .54357 L .2725 .54101 L F
.27063 .54194 m .27027 .54463 L .27197 .54357 L F
.782 .476 .471 r
.31637 .51455 m .32068 .51763 L .32058 .51512 L F
.792 .684 .745 r
.33846 .61818 m .33965 .61912 L .33561 .61854 L F
.749 .778 .877 r
.34041 .61494 m .33965 .61912 L .33846 .61818 L F
.34041 .61494 m .34242 .61759 L .33965 .61912 L F
.953 .824 .386 r
.46381 .52172 m .46332 .52433 L .46267 .52344 L F
.852 .987 .853 r
.46381 .52172 m .46315 .52053 L .46564 .51794 L F
.96 .815 .381 r
.46381 .52172 m .46267 .52344 L .46315 .52053 L F
.67 .681 .852 r
.32197 .58312 m .31712 .58174 L .32012 .58115 L F
.095 0 0 r
.42642 .46206 m .43031 .46132 L .42912 .46183 L F
.307 .8 .847 r
.43299 .46119 m .42912 .46183 L .43031 .46132 L F
.312 .529 .903 r
.49635 .48571 m .49551 .4875 L .49359 .48612 L F
.49635 .48571 m .49767 .48781 L .49551 .4875 L F
.872 .566 .467 r
.65658 .36441 m .65461 .36479 L .65397 .36144 L F
.627 .125 .038 r
.65511 .36587 m .65461 .36479 L .65658 .36441 L F
.873 .463 .243 r
.65658 .36441 m .65744 .36687 L .65511 .36587 L F
0 0 .073 r
.50733 .43134 m .50735 .42831 L .50769 .42648 L F
0 0 0 r
.55031 .41384 m .55141 .4117 L .55351 .4104 L F
.826 .998 .841 r
.51882 .4219 m .51521 .42441 L .51796 .4234 L F
.603 .107 .047 r
.5201 .42334 m .51882 .4219 L .51796 .4234 L F
.829 .63 .634 r
.36413 .54496 m .3665 .54875 L .3637 .54785 L F
.89 .66 .584 r
.36574 .55158 m .3637 .54785 L .3665 .54875 L F
.968 .684 .438 r
.4024 .53085 m .4026 .53362 L .40425 .53237 L F
0 0 0 r
.43698 .44503 m .43308 .44757 L .43568 .4467 L F
.4385 .444 m .44003 .44224 L .43698 .44503 L F
.4385 .444 m .43698 .44503 L .43568 .4467 L F
.693 .928 .612 r
.59066 .39273 m .58938 .3949 L .59216 .3916 L F
0 .157 .698 r
.59122 .39532 m .58938 .3949 L .59066 .39273 L F
.59122 .39532 m .59179 .39709 L .58938 .3949 L F
.537 .85 .546 r
.44756 .45023 m .44887 .449 L .45046 .44738 L F
0 0 0 r
.38201 .53459 m .38191 .53596 L .3815 .53672 L F
0 0 .264 r
.38194 .53387 m .38013 .53789 L .37973 .53554 L F
.38194 .53387 m .3815 .53672 L .38013 .53789 L F
.034 0 .397 r
.38113 .53798 m .38368 .5391 L .38406 .53825 L F
.38013 .53789 m .38368 .5391 L .38113 .53798 L F
0 0 0 r
.38431 .5352 m .38406 .53825 L .3843 .53583 L F
.361 0 0 r
.3861 .54042 m .38755 .54113 L .38368 .5391 L F
.3861 .54042 m .38755 .54113 L .38368 .5391 L F
0 .106 .652 r
.3843 .53583 m .3861 .54042 L .38406 .53825 L F
.658 .173 .088 r
.38406 .53825 m .3861 .54042 L .38368 .5391 L F
.436 .471 .798 r
.3843 .53583 m .38599 .54012 L .38368 .5391 L F
.38599 .54012 m .3861 .54042 L .38368 .5391 L F
.034 0 .397 r
.38013 .53789 m .38137 .53958 L .38368 .5391 L F
.38137 .53958 m .38013 .53789 L .3815 .53672 L F
0 0 0 r
.38431 .5352 m .3843 .53583 L .38198 .5339 L F
.38197 .53389 m .38198 .5339 L .38194 .53387 L F
.38431 .5352 m .38198 .5339 L .38197 .53389 L F
.063 .267 .758 r
.38194 .53387 m .3843 .53583 L .38261 .53212 L F
0 0 0 r
.38261 .53212 m .3815 .53672 L .38194 .53387 L F
.567 .376 .583 r
.3843 .53583 m .38137 .53958 L .3815 .53672 L F
.534 .5 .765 r
.37823 .53424 m .38181 .53712 L .38191 .53596 L F
.436 .471 .798 r
.3843 .53583 m .38368 .5391 L .38137 .53958 L F
.567 .376 .583 r
.3843 .53583 m .3815 .53672 L .38191 .53596 L F
.534 .5 .765 r
.38181 .53712 m .38284 .53795 L .38191 .53596 L F
0 0 0 r
.38209 .53428 m .38191 .53596 L .38201 .53459 L F
.38261 .53212 m .38216 .53455 L .38209 .53428 L F
.38216 .53455 m .38191 .53596 L .38209 .53428 L F
.66 .761 .925 r
.64919 .35165 m .64585 .35257 L .64514 .35039 L F
.737 .26 .113 r
.64919 .35165 m .64514 .35039 L .64585 .35257 L F
0 0 0 r
.55539 .41469 m .55228 .41765 L .55421 .41542 L F
.55719 .41295 m .55807 .41152 L .55539 .41469 L F
.519 .873 .632 r
.55719 .41295 m .55539 .41469 L .55421 .41542 L F
.929 .958 .644 r
.42651 .5719 m .42589 .57116 L .42765 .56747 L F
.922 .966 .663 r
.42651 .5719 m .42451 .57339 L .42589 .57116 L F
.818 .964 .902 r
.65282 .3957 m .6547 .39401 L .65368 .39295 L F
.771 .92 .937 r
.6517 .39458 m .65282 .3957 L .65368 .39295 L F
.695 .805 .933 r
.50731 .4044 m .51188 .40532 L .51013 .40359 L F
.775 .754 .833 r
.51188 .40532 m .50731 .4044 L .51013 .40359 L F
.516 .011 0 r
.34811 .63494 m .34869 .63343 L .34413 .63425 L F
.001 0 0 r
.35187 .63232 m .34869 .63343 L .35017 .63372 L F
0 0 0 r
.35017 .63372 m .34869 .63343 L .34811 .63494 L F
.943 .775 .643 r
.3164 .528 m .31471 .52761 L .31535 .52497 L F
.799 .491 .468 r
.3164 .528 m .31439 .53052 L .31471 .52761 L F
.3164 .528 m .31884 .53123 L .31439 .53052 L F
.748 .267 .097 r
.32921 .64089 m .33332 .64154 L .33017 .63933 L F
.629 .495 .68 r
.33017 .63933 m .33332 .64154 L .3328 .63837 L F
.748 .267 .097 r
.32921 .64089 m .33017 .63933 L .3328 .63837 L F
.897 .973 .817 r
.58538 .41599 m .58776 .41547 L .5885 .41311 L F
.956 .95 .697 r
.32987 .57 m .329 .57492 L .33194 .57117 L F
.925 .891 .778 r
.32987 .57 m .33194 .57117 L .33259 .56896 L F
.128 .268 .74 r
.51254 .42499 m .51475 .42607 L .51521 .42441 L F
0 0 0 r
.40537 .46394 m .4031 .46507 L .4014 .46688 L F
.419 .826 .977 r
.62752 .38323 m .63136 .38352 L .62885 .38467 L F
.36 .34 .701 r
.27585 .66492 m .27611 .6708 L .27833 .66716 L F
.537 .509 .772 r
.27718 .6719 m .27833 .66716 L .27611 .6708 L F
.729 .988 .809 r
.51184 .38856 m .50855 .39134 L .5096 .38933 L F
.725 .957 .674 r
.50855 .39134 m .50673 .3925 L .5096 .38933 L F
.977 .698 .429 r
.51896 .43837 m .5194 .44177 L .51722 .43993 L F
.698 .92 .587 r
.5201 .43629 m .51896 .43837 L .51722 .43993 L F
.977 .698 .429 r
.51896 .43837 m .5194 .44177 L .51722 .43993 L F
.376 .741 .99 r
.60916 .35022 m .61215 .34883 L .60944 .34907 L F
0 0 0 r
.44223 .44085 m .44003 .44224 L .4385 .444 L F
.616 .294 .402 r
.40455 .47172 m .4041 .4737 L .40002 .47492 L F
.46 .151 .354 r
.40731 .47288 m .40455 .47172 L .40722 .47144 L F
.40731 .47288 m .4041 .4737 L .40455 .47172 L F
.961 .714 .518 r
.34621 .64557 m .34823 .643 L .34597 .64355 L F
.975 .751 .535 r
.34621 .64557 m .34833 .64565 L .34823 .643 L F
.649 .91 .981 r
.34823 .643 m .34896 .641 L .34597 .64355 L F
.34823 .643 m .35081 .64175 L .34896 .641 L F
.669 .507 .657 r
.34823 .643 m .35217 .64447 L .35081 .64175 L F
.34823 .643 m .34833 .64565 L .35217 .64447 L F
.975 .751 .535 r
.34621 .64557 m .34833 .64565 L .34823 .643 L F
.961 .714 .518 r
.34621 .64557 m .34823 .643 L .34597 .64355 L F
.765 .993 .792 r
.66612 .37863 m .66752 .37693 L .66736 .37619 L F
.76 .995 .853 r
.66423 .37881 m .66612 .37863 L .66736 .37619 L F
.187 0 0 r
.34518 .62907 m .34627 .63028 L .34308 .63008 L F
.863 .793 .78 r
.32409 .58467 m .3217 .58794 L .32478 .58865 L F
.88 .761 .726 r
.3217 .58794 m .32285 .59205 L .32478 .58865 L F
.986 .891 .637 r
.30857 .52532 m .30614 .5265 L .30809 .52247 L F
.96 .674 .449 r
.30857 .52532 m .30797 .52759 L .30614 .5265 L F
.659 .325 .396 r
.31037 .5274 m .30857 .52532 L .31065 .52436 L F
.31037 .5274 m .30797 .52759 L .30857 .52532 L F
.233 .098 .483 r
.43249 .58201 m .43425 .58144 L .43452 .57784 L F
.804 .716 .767 r
.31286 .58128 m .31039 .57872 L .31201 .57866 L F
.552 .58 .835 r
.3222 .65195 m .32435 .65088 L .32307 .64769 L F
0 0 .09 r
.32156 .65458 m .32435 .65088 L .3222 .65195 L F
.856 .591 .536 r
.30813 .64496 m .3056 .64142 L .30565 .64408 L F
.716 .219 .057 r
.3056 .64547 m .30813 .64496 L .30565 .64408 L F
.904 .847 .777 r
.31145 .605 m .31076 .60172 L .31163 .60614 L F
.982 .744 .34 r
.67379 .35927 m .67507 .36132 L .67497 .35817 L F
.863 .86 .409 r
.67604 .35332 m .67486 .35688 L .67497 .35817 L F
.871 .904 .491 r
.67486 .35688 m .67379 .35927 L .67497 .35817 L F
.426 .213 .485 r
.28035 .54443 m .28035 .54894 L .27812 .54912 L F
0 0 0 r
.28035 .54443 m .28433 .54221 L .28264 .54342 L F
.08 0 .395 r
.28242 .54635 m .28035 .54443 L .28264 .54342 L F
.28242 .54635 m .28035 .54894 L .28035 .54443 L F
0 .216 .73 r
.56529 .34852 m .56483 .34932 L .56347 .34747 L F
.56529 .34852 m .56664 .3505 L .56483 .34932 L F
.803 .996 .777 r
.3056 .64142 m .30873 .63679 L .30389 .63952 L F
.3056 .64142 m .30848 .63827 L .30873 .63679 L F
.337 .792 .947 r
.61962 .39517 m .62455 .39535 L .62175 .39441 L F
.484 .874 .968 r
.62455 .39535 m .62511 .39345 L .62175 .39441 L F
.62455 .39535 m .62695 .39431 L .62511 .39345 L F
0 0 0 r
.59561 .37846 m .59339 .38152 L .59546 .37819 L F
.796 .975 .686 r
.59785 .37429 m .59565 .37715 L .59546 .37819 L F
0 0 .037 r
.59565 .37715 m .59561 .37846 L .59546 .37819 L F
0 0 .188 r
.59006 .35112 m .59139 .34908 L .58885 .34998 L F
.027 0 0 r
.58885 .34998 m .59139 .34908 L .59222 .34764 L F
.647 .902 .579 r
.59139 .34908 m .59023 .35016 L .59223 .3478 L F
.345 0 0 r
.59222 .34764 m .5944 .34842 L .59488 .34604 L F
.59222 .34764 m .59139 .34908 L .5944 .34842 L F
.647 .902 .579 r
.59139 .34908 m .59223 .3478 L .59293 .34697 L F
0 0 .188 r
.59063 .35166 m .59139 .34908 L .59006 .35112 L F
.59063 .35166 m .59196 .35208 L .59139 .34908 L F
.59063 .35166 m .59028 .35404 L .59196 .35208 L F
.827 .963 .896 r
.49304 .50603 m .49271 .50862 L .49358 .50757 L F
.862 .983 .85 r
.49304 .50603 m .49163 .5079 L .49271 .50862 L F
.772 .995 .796 r
.47938 .41543 m .47633 .41835 L .47727 .41611 L F
.735 .98 .915 r
.47633 .41835 m .47533 .41777 L .47727 .41611 L F
.525 .564 .838 r
.51718 .40412 m .51669 .40466 L .51485 .40342 L F
0 .449 .86 r
.51027 .40092 m .51439 .40255 L .51485 .40342 L F
.656 .284 0 r
.51439 .40255 m .51456 .40292 L .51485 .40342 L F
.83 .369 .114 r
.51456 .40292 m .51647 .40379 L .51485 .40342 L F
.51647 .40379 m .51718 .40412 L .51601 .40377 L F
.51647 .40379 m .51601 .40377 L .51485 .40342 L F
0 0 0 r
.5176 .40365 m .51968 .40277 L .51718 .40412 L F
.51717 .40383 m .51803 .40386 L .51968 .40277 L F
.83 .369 .114 r
.51456 .40292 m .51535 .40459 L .51718 .40412 L F
0 0 0 r
.51535 .40459 m .5176 .40365 L .51718 .40412 L F
.51535 .40459 m .518 .40387 L .51717 .40383 L F
.632 .629 .829 r
.52123 .40685 m .51718 .40412 L .51968 .40277 L F
0 0 0 r
.518 .40387 m .51803 .40386 L .51717 .40383 L F
.525 .564 .838 r
.51718 .40412 m .5173 .40506 L .51669 .40466 L F
.51718 .40412 m .51567 .4079 L .5173 .40506 L F
.862 .967 .864 r
.41205 .55457 m .41589 .55282 L .41427 .55126 L F
.41205 .55457 m .41328 .55532 L .41589 .55282 L F
.667 .709 .879 r
.41427 .55126 m .41589 .55282 L .41783 .55133 L F
.642 .955 .761 r
.39463 .47041 m .39784 .46877 L .39886 .46754 L F
.218 0 0 r
.39463 .47041 m .39687 .47076 L .39784 .46877 L F
0 0 .345 r
.39886 .46754 m .39784 .46877 L .4002 .46904 L F
.418 .017 .169 r
.39687 .47076 m .4002 .46904 L .39784 .46877 L F
.762 .894 .492 r
.59308 .38913 m .59216 .3916 L .59421 .38782 L F
.794 .951 .613 r
.59308 .38913 m .59066 .39273 L .59216 .3916 L F
.532 .432 .686 r
.32783 .66195 m .33073 .66184 L .32897 .65944 L F
0 0 0 r
.32853 .66059 m .32783 .66195 L .32897 .65944 L F
.36 .743 .988 r
.32853 .66059 m .33073 .66184 L .32783 .66195 L F
.325 .422 .807 r
.56286 .37199 m .56421 .37509 L .56588 .37316 L F
.934 .954 .769 r
.56462 .37797 m .56588 .37316 L .56421 .37509 L F
.897 .845 .785 r
.54565 .45077 m .54964 .44895 L .54809 .44735 L F
.929 .804 .701 r
.54964 .44895 m .54884 .44461 L .54809 .44735 L F
.982 .802 .585 r
.40813 .54365 m .41074 .54116 L .40811 .54061 L F
.40813 .54365 m .41021 .54497 L .41074 .54116 L F
.40813 .54365 m .41021 .54497 L .41074 .54116 L F
.779 .5 .515 r
.38897 .53393 m .39289 .53181 L .38873 .53112 L F
.38897 .53393 m .39262 .53448 L .39282 .53184 L F
.991 .733 .392 r
.39123 .53317 m .39245 .53672 L .39262 .53448 L F
.39245 .53672 m .39259 .5371 L .39262 .53448 L F
.779 .5 .515 r
.39282 .53184 m .39262 .53448 L .39289 .53181 L F
.421 .358 .681 r
.4945 .43788 m .49632 .43403 L .49396 .43762 L F
.867 .583 .505 r
.353 .52513 m .34945 .5267 L .34963 .52415 L F
.353 .52513 m .35288 .52777 L .34945 .5267 L F
.949 .666 .468 r
.36138 .53849 m .3593 .53758 L .35927 .53466 L F
.934 .716 .584 r
.36138 .53849 m .35867 .54035 L .3593 .53758 L F
.36138 .53849 m .36088 .54132 L .35867 .54035 L F
.198 0 .213 r
.41389 .47031 m .41415 .46847 L .41644 .46736 L F
.322 .4 .787 r
.25362 .5749 m .25517 .57421 L .25248 .57231 L F
.794 .685 .745 r
.58257 .37865 m .5776 .37852 L .58127 .37442 L F
.551 .859 .997 r
.58069 .37747 m .5776 .37852 L .58257 .37865 L F
0 0 0 r
.58409 .37613 m .58384 .37656 L .58378 .37665 L F
.58359 .37696 m .58378 .37665 L .58257 .37865 L F
.58409 .37613 m .58378 .37665 L .58359 .37696 L F
0 .114 .666 r
.58249 .37469 m .584 .37629 L .58413 .37508 L F
.385 0 0 r
.58667 .37589 m .58403 .37624 L .58486 .37474 L F
.442 .149 .371 r
.58667 .37589 m .5837 .37876 L .58403 .37624 L F
0 .114 .666 r
.584 .37629 m .58492 .37727 L .58436 .37571 L F
.584 .37629 m .58436 .37571 L .58413 .37508 L F
.053 .204 .702 r
.58311 .37677 m .58346 .37645 L .58249 .37469 L F
.58346 .37645 m .58383 .37611 L .58338 .37564 L F
.58346 .37645 m .58338 .37564 L .58249 .37469 L F
.4 .45 .797 r
.58069 .37747 m .58266 .3769 L .58249 .37469 L F
.357 .463 .832 r
.58384 .37656 m .58311 .37677 L .58257 .37865 L F
.58311 .37677 m .58069 .37747 L .58166 .37808 L F
.58311 .37677 m .58166 .37808 L .58257 .37865 L F
.4 .45 .797 r
.58276 .37836 m .58331 .37744 L .58249 .37469 L F
0 0 0 r
.58486 .37474 m .58409 .37613 L .58257 .37865 L F
.58409 .37613 m .58403 .37624 L .58384 .37656 L F
.357 .463 .832 r
.58403 .37624 m .58069 .37747 L .58384 .37656 L F
.4 .45 .797 r
.58069 .37747 m .58276 .37836 L .58266 .3769 L F
.58276 .37836 m .5837 .37876 L .58331 .37744 L F
.357 .463 .832 r
.58346 .37645 m .5837 .37876 L .58069 .37747 L F
.58403 .37624 m .5837 .37876 L .58346 .37645 L F
.053 .204 .702 r
.5837 .37876 m .58492 .37727 L .58383 .37611 L F
.5837 .37876 m .58383 .37611 L .58311 .37677 L F
0 0 .442 r
.50471 .41823 m .50573 .41952 L .50638 .41716 L F
.854 .776 .774 r
.38602 .55376 m .38856 .55513 L .38673 .55138 L F
.812 .573 .577 r
.38381 .55724 m .38856 .55513 L .38602 .55376 L F
.38381 .55724 m .38779 .55788 L .38856 .55513 L F
.431 .192 .448 r
.38779 .55788 m .39041 .55762 L .38856 .55513 L F
.66 .761 .925 r
.64919 .35165 m .64695 .34748 L .64929 .34836 L F
.968 .935 .673 r
.60225 .3513 m .60347 .35353 L .60395 .35127 L F
.911 .973 .679 r
.60225 .3513 m .60004 .35712 L .60347 .35353 L F
.879 .638 .57 r
.32649 .52098 m .32855 .52465 L .32921 .52189 L F
0 0 .05 r
.37658 .51938 m .37632 .51734 L .3788 .51784 L F
.37658 .51938 m .37551 .52067 L .37632 .51734 L F
.668 .547 .708 r
.59176 .35809 m .58901 .36147 L .5879 .35748 L F
.893 .973 .666 r
.51401 .38472 m .51184 .38856 L .51225 .38581 L F
.882 .992 .779 r
.51184 .38856 m .5096 .38933 L .51225 .38581 L F
.93 .865 .754 r
.65513 .3586 m .65397 .36144 L .65261 .35914 L F
.927 .603 .407 r
.65397 .36144 m .65151 .36283 L .65261 .35914 L F
.65397 .36144 m .65461 .36479 L .65151 .36283 L F
.811 .912 .908 r
.50346 .49784 m .50614 .49752 L .50516 .49617 L F
.795 .902 .917 r
.50516 .49617 m .50614 .49752 L .51007 .49476 L F
.832 .735 .757 r
.30802 .60484 m .31163 .60614 L .30892 .60033 L F
.437 .73 .988 r
.40118 .59416 m .40474 .59296 L .40133 .59252 L F
.40118 .59416 m .406 .59426 L .40474 .59296 L F
.856 .942 .876 r
.51248 .47431 m .51025 .47585 L .51091 .47336 L F
.891 .936 .838 r
.51248 .47431 m .51371 .46997 L .51561 .47169 L F
.51248 .47431 m .51091 .47336 L .51371 .46997 L F
0 .03 .541 r
.33729 .63819 m .33792 .63942 L .33831 .63797 L F
.136 .667 .866 r
.33729 .63819 m .33831 .63797 L .33537 .63783 L F
.719 .417 .466 r
.33543 .641 m .33729 .63819 L .33537 .63783 L F
.998 .817 .474 r
.5208 .3732 m .51955 .36865 L .52098 .37104 L F
.5208 .3732 m .51868 .37179 L .51955 .36865 L F
0 0 .572 r
.52067 .37589 m .51868 .37179 L .5208 .3732 L F
.448 .8 .997 r
.57872 .34588 m .58019 .34567 L .58081 .34503 L F
.53 .912 .939 r
.57936 .34653 m .58019 .34567 L .58212 .3461 L F
.58019 .34567 m .58081 .34503 L .58118 .34533 L F
.58019 .34567 m .58118 .34533 L .58212 .3461 L F
.083 .518 .903 r
.58336 .34523 m .58212 .3461 L .58081 .34503 L F
.719 .487 .574 r
.57961 .3479 m .58336 .34523 L .58019 .34567 L F
.57899 .34609 m .58019 .34567 L .57872 .34588 L F
.244 .09 .464 r
.57872 .34588 m .58081 .34503 L .57899 .34609 L F
.57872 .34588 m .57899 .34609 L .5778 .34678 L F
.719 .487 .574 r
.57884 .34614 m .57899 .34609 L .57872 .34588 L F
.53 .912 .939 r
.5778 .34678 m .58081 .34503 L .57936 .34653 L F
.719 .487 .574 r
.57961 .3479 m .58019 .34567 L .57884 .34614 L F
.448 .8 .997 r
.58019 .34567 m .58336 .34523 L .58081 .34503 L F
.083 .518 .903 r
.58336 .34523 m .58488 .34665 L .58212 .3461 L F
.331 .806 .907 r
.4264 .57821 m .43049 .57795 L .42797 .57899 L F
.512 .255 .462 r
.43051 .58076 m .42797 .57899 L .43049 .57795 L F
.791 .997 .793 r
.47938 .41543 m .48019 .41314 L .48104 .41347 L F
.47938 .41543 m .47727 .41611 L .48019 .41314 L F
.97 .655 .35 r
.39996 .551 m .40226 .5549 L .39979 .55328 L F
.927 .903 .781 r
.39985 .5575 m .39979 .55328 L .40226 .5549 L F
0 .174 .685 r
.40191 .55402 m .40226 .5549 L .39996 .551 L F
.40191 .55402 m .4026 .55475 L .40226 .5549 L F
.071 .175 .668 r
.4046 .55747 m .40226 .5549 L .4026 .55475 L F
0 0 .199 r
.54308 .4106 m .54227 .41507 L .54048 .41388 L F
.953 .764 .61 r
.54227 .41507 m .5419 .41791 L .54048 .41388 L F
.815 .867 .424 r
.55955 .40686 m .55807 .41152 L .55756 .40993 L F
.913 .787 .306 r
.55756 .40993 m .55807 .41152 L .55719 .41295 L F
.655 .223 .211 r
.38455 .57334 m .38609 .57389 L .3885 .57191 L F
.589 .139 .152 r
.3885 .57191 m .39028 .57384 L .38903 .57012 L F
.3885 .57191 m .38609 .57389 L .39028 .57384 L F
.875 .749 .24 r
.25694 .56799 m .25669 .5672 L .25728 .56516 L F
0 0 .324 r
.25728 .56516 m .25727 .56431 L .25633 .56125 L F
.793 .744 .222 r
.25728 .56516 m .25669 .5672 L .25727 .56431 L F
.848 .616 .587 r
.41267 .55804 m .41238 .56088 L .41622 .56126 L F
.931 .554 .256 r
.41238 .56088 m .41501 .5645 L .41622 .56126 L F
.93 .865 .754 r
.65513 .3586 m .65261 .35914 L .65371 .35715 L F
.706 .983 .815 r
.48128 .42739 m .48239 .42551 L .4807 .42731 L F
.48128 .42739 m .48454 .42482 L .48239 .42551 L F
.673 .665 .834 r
.38701 .58218 m .38396 .58196 L .38524 .5808 L F
.899 .863 .796 r
.60043 .39815 m .59632 .40029 L .59869 .39652 L F
.60043 .39815 m .59804 .40202 L .59632 .40029 L F
.858 .868 .846 r
.59632 .40029 m .59804 .40202 L .59943 .3991 L F
.5979 .40019 m .59943 .3991 L .59912 .40012 L F
.59632 .40029 m .59943 .3991 L .5979 .40019 L F
.904 .982 .716 r
.59943 .3991 m .59804 .40202 L .60016 .39858 L F
.59943 .3991 m .60016 .39858 L .60043 .39815 L F
.663 .804 .951 r
.60324 .3969 m .60043 .39815 L .59869 .39652 L F
.104 0 0 r
.59943 .3991 m .60043 .39815 L .60324 .3969 L F
.484 0 0 r
.29611 .65831 m .2955 .65679 L .29289 .65762 L F
.442 .475 .798 r
.59561 .37846 m .59572 .38151 L .59339 .38152 L F
.798 .994 .87 r
.51717 .38206 m .51401 .38472 L .515 .38216 L F
.809 .976 .682 r
.51401 .38472 m .51225 .38581 L .515 .38216 L F
0 0 0 r
.30571 .54508 m .307 .54425 L .30844 .54373 L F
.30571 .54508 m .30397 .54684 L .307 .54425 L F
.406 .738 .992 r
.60004 .35712 m .59978 .35589 L .5999 .35776 L F
.911 .973 .679 r
.60225 .3513 m .59978 .35589 L .60004 .35712 L F
0 0 .254 r
.60079 .35813 m .5999 .35776 L .59978 .35589 L F
.60079 .35813 m .60051 .36073 L .5999 .35776 L F
.525 .564 .838 r
.51718 .40412 m .51837 .40736 L .51567 .4079 L F
.457 .259 .523 r
.51837 .40736 m .51828 .40997 L .51567 .4079 L F
.373 .27 .608 r
.51828 .40997 m .51611 .41116 L .51567 .4079 L F
.733 .681 .8 r
.39704 .57934 m .39403 .58192 L .39222 .57808 L F
.841 .865 .861 r
.55727 .42709 m .55929 .42865 L .56172 .42555 L F
.941 .824 .702 r
.5581 .43034 m .55929 .42865 L .55727 .42709 L F
.817 .99 .733 r
.56316 .40347 m .55955 .40686 L .56209 .40374 L F
.28 .772 .713 r
.56494 .40272 m .56316 .40347 L .56209 .40374 L F
.964 .775 .599 r
.41328 .55532 m .41083 .55697 L .41205 .55457 L F
.41328 .55532 m .41267 .55804 L .41083 .55697 L F
.41328 .55532 m .41083 .55697 L .41205 .55457 L F
.41328 .55532 m .41267 .55804 L .41083 .55697 L F
.84 .46 .331 r
.67043 .34654 m .67215 .34482 L .6682 .34381 L F
.67043 .34654 m .67235 .34692 L .67215 .34482 L F
0 .453 .832 r
.54921 .40518 m .55004 .40614 L .55266 .40695 L F
.492 .379 .653 r
.58749 .37065 m .58802 .37384 L .58486 .37474 L F
.385 0 0 r
.58667 .37589 m .58486 .37474 L .58802 .37384 L F
.423 .596 .916 r
.24273 .61438 m .24425 .61584 L .24102 .61517 L F
0 0 .075 r
.37515 .57845 m .37511 .58201 L .37527 .5799 L F
.277 .22 .612 r
.37515 .57845 m .37745 .57794 L .37689 .57433 L F
.225 0 .217 r
.37527 .5799 m .37745 .57794 L .37515 .57845 L F
.137 0 0 r
.64635 .33882 m .64911 .33867 L .65018 .33741 L F
.512 .034 .057 r
.64911 .33867 m .65297 .33731 L .65018 .33741 L F
.539 0 0 r
.34731 .61693 m .35053 .61753 L .34884 .6168 L F
.139 .684 .748 r
.34731 .61693 m .34884 .6168 L .34484 .61722 L F
.652 .858 .978 r
.59384 .40158 m .59804 .40202 L .59632 .40029 L F
.59384 .40158 m .59804 .40202 L .59632 .40029 L F
.847 .995 .834 r
.54351 .42996 m .5443 .43095 L .54259 .43254 L F
.81 .993 .87 r
.54751 .42784 m .5443 .43095 L .54351 .42996 L F
.842 .961 .627 r
.3204 .56773 m .32202 .56391 L .32356 .5645 L F
.713 .946 .647 r
.39424 .54662 m .39299 .549 L .3957 .55025 L F
.604 .073 0 r
.41291 .47846 m .41072 .47942 L .41099 .47814 L F
.08 .293 .777 r
.41134 .4755 m .41273 .47539 L .41291 .47846 L F
.4111 .47505 m .41273 .47539 L .41134 .4755 L F
.031 0 .124 r
.41273 .47539 m .41518 .47488 L .41486 .47524 L F
.951 .955 .699 r
.41273 .47539 m .41072 .47942 L .41291 .47846 L F
.031 0 .124 r
.41273 .47539 m .41286 .4775 L .41242 .47799 L F
.41273 .47539 m .41486 .47524 L .41286 .4775 L F
.452 .263 .533 r
.41242 .47799 m .40982 .48164 L .41072 .47942 L F
.782 .473 .464 r
.40982 .48164 m .41059 .48003 L .41072 .47942 L F
.41059 .48003 m .41117 .47883 L .41072 .47942 L F
.604 .073 0 r
.41099 .47814 m .41072 .47942 L .4086 .47774 L F
.788 .696 .763 r
.39174 .54155 m .38912 .54505 L .38755 .54113 L F
.931 .966 .677 r
.32795 .57395 m .32682 .57847 L .329 .57492 L F
.956 .95 .697 r
.32987 .57 m .32795 .57395 L .329 .57492 L F
.636 .865 .499 r
.33833 .67373 m .33748 .67515 L .33957 .67239 L F
.649 .939 .688 r
.33498 .67683 m .33748 .67515 L .33833 .67373 L F
.636 .865 .499 r
.33833 .67373 m .33957 .67239 L .34021 .67155 L F
.107 0 0 r
.34021 .67155 m .34061 .67281 L .33833 .67373 L F
0 0 0 r
.33691 .67525 m .33833 .67373 L .33937 .67331 L F
.33691 .67525 m .33937 .67331 L .33964 .67345 L F
.493 .826 .532 r
.33498 .67683 m .33833 .67373 L .3359 .67591 L F
0 0 0 r
.3359 .67591 m .33833 .67373 L .33691 .67525 L F
.3359 .67591 m .33964 .67345 L .33921 .67314 L F
.33964 .67345 m .33937 .67331 L .34061 .67281 L F
.33964 .67345 m .34061 .67281 L .33921 .67314 L F
.33921 .67314 m .34206 .6725 L .34151 .67456 L F
0 .197 .622 r
.33872 .67279 m .33921 .67314 L .34014 .67372 L F
.33729 .67186 m .33921 .67314 L .33872 .67279 L F
.34043 .67387 m .34014 .67372 L .34151 .67456 L F
.33729 .67186 m .34014 .67372 L .34043 .67387 L F
.107 0 0 r
.34021 .67155 m .34258 .67098 L .34061 .67281 L F
.729 .954 .661 r
.37522 .47632 m .3772 .4748 L .3745 .47788 L F
.629 .451 .623 r
.3772 .4748 m .37757 .47849 L .3745 .47788 L F
.625 .593 .798 r
.38015 .47372 m .38007 .47564 L .3772 .4748 L F
.619 .444 .623 r
.38067 .47672 m .3772 .4748 L .38007 .47564 L F
.38067 .47672 m .37757 .47849 L .3772 .4748 L F
.815 .622 .641 r
.37522 .47632 m .38015 .47372 L .3772 .4748 L F
.255 .537 .921 r
.34484 .61722 m .34242 .61759 L .34041 .61494 L F
.626 .66 .864 r
.25033 .59401 m .24684 .59464 L .24984 .59334 L F
0 0 0 r
.24684 .59464 m .24626 .59559 L .24984 .59334 L F
.24684 .59464 m .24369 .59635 L .24626 .59559 L F
.796 .552 .57 r
.32483 .51812 m .32649 .52098 L .32675 .51825 L F
.846 .534 .459 r
.37988 .58758 m .38376 .5885 L .38138 .58657 L F
.555 0 0 r
.38697 .58954 m .38138 .58657 L .38376 .5885 L F
.116 0 0 r
.41658 .45953 m .41545 .45854 L .41399 .46029 L F
.41658 .45953 m .418 .45776 L .41545 .45854 L F
.964 .872 .697 r
.56328 .42035 m .56626 .41802 L .56499 .41677 L F
.56328 .42035 m .56477 .42213 L .56626 .41802 L F
.962 .897 .715 r
.56626 .41802 m .56611 .41433 L .56499 .41677 L F
.045 0 0 r
.44532 .45091 m .44349 .45276 L .44097 .45366 L F
0 0 0 r
.44563 .45173 m .44532 .45091 L .44756 .45023 L F
.44563 .45173 m .44349 .45276 L .44532 .45091 L F
.773 .997 .852 r
.30873 .63679 m .30848 .63827 L .31071 .63512 L F
.594 .698 .915 r
.30848 .63827 m .31276 .63891 L .31071 .63512 L F
.642 .926 .651 r
.4858 .42301 m .48454 .42482 L .48755 .42183 L F
.654 .967 .811 r
.48239 .42551 m .48454 .42482 L .4858 .42301 L F
.707 .812 .931 r
.30702 .62948 m .30267 .62912 L .30532 .6278 L F
.698 .818 .939 r
.30532 .6278 m .30946 .62824 L .30702 .62948 L F
.482 .765 .993 r
.38797 .58038 m .38701 .58218 L .38524 .5808 L F
.38797 .58038 m .38701 .58218 L .38524 .5808 L F
.899 .636 .532 r
.32802 .53023 m .33063 .5284 L .32826 .52748 L F
.32802 .53023 m .33033 .53104 L .33063 .5284 L F
.791 .992 .88 r
.31633 .64768 m .32101 .645 L .31876 .64407 L F
.7 .332 .348 r
.32101 .645 m .31853 .64726 L .31876 .64407 L F
.787 .557 .588 r
.32307 .64769 m .3187 .65015 L .31853 .64726 L F
0 0 .09 r
.3242 .65109 m .32428 .65111 L .32435 .65088 L F
.32156 .65458 m .32428 .65111 L .3242 .65109 L F
.32244 .65346 m .32399 .65205 L .32428 .65111 L F
.32346 .6538 m .32363 .65349 L .32435 .65088 L F
0 0 .047 r
.3246 .65145 m .32356 .65376 L .32505 .65247 L F
.32435 .65088 m .32404 .65201 L .3246 .65145 L F
.32404 .65201 m .32356 .65376 L .3246 .65145 L F
.177 0 0 r
.3187 .65015 m .32471 .65124 L .32232 .651 L F
.32471 .65124 m .32484 .65126 L .32476 .65125 L F
.32471 .65124 m .32476 .65125 L .32232 .651 L F
0 0 .047 r
.32435 .65088 m .32447 .65117 L .32485 .65086 L F
.32498 .65054 m .32485 .65086 L .32588 .65004 L F
.32435 .65088 m .32485 .65086 L .32498 .65054 L F
.101 .285 .764 r
.32307 .64769 m .32435 .65088 L .32588 .65004 L F
.787 .557 .588 r
.32307 .64769 m .32478 .65105 L .32124 .65053 L F
.32307 .64769 m .32124 .65053 L .32075 .649 L F
.32478 .65105 m .32473 .65119 L .3187 .65015 L F
.32486 .65121 m .32484 .65126 L .3187 .65015 L F
.7 .332 .348 r
.32101 .645 m .32307 .64769 L .31948 .64735 L F
0 0 .393 r
.31995 .64652 m .32148 .65069 L .32139 .64786 L F
.7 .332 .348 r
.32101 .645 m .31948 .64735 L .31897 .64686 L F
0 0 .393 r
.3198 .64638 m .3204 .64793 L .31995 .64652 L F
.3204 .64793 m .32148 .65069 L .31995 .64652 L F
.787 .557 .588 r
.32075 .649 m .32124 .65053 L .3187 .65015 L F
.32478 .65105 m .32486 .65121 L .32473 .65119 L F
.177 0 0 r
.32484 .65126 m .32486 .65127 L .32232 .651 L F
.251 .311 .73 r
.32588 .65004 m .32489 .65127 L .32478 .65105 L F
0 0 .047 r
.32447 .65117 m .32461 .65121 L .32588 .65004 L F
.251 .311 .73 r
.32588 .65004 m .32478 .65105 L .32307 .64769 L F
.787 .557 .588 r
.32486 .65121 m .32489 .65127 L .32484 .65126 L F
.987 .791 .554 r
.32524 .65081 m .32479 .65126 L .32486 .65127 L F
.32588 .65004 m .32479 .65126 L .32524 .65081 L F
.177 0 0 r
.32484 .65126 m .32489 .65127 L .32486 .65127 L F
.987 .791 .554 r
.32499 .65115 m .32486 .65127 L .32489 .65127 L F
.32588 .65004 m .32486 .65127 L .32499 .65115 L F
0 0 .047 r
.32461 .65121 m .3254 .65145 L .32588 .65004 L F
0 0 .424 r
.32139 .64786 m .32148 .65069 L .32232 .651 L F
.987 .791 .554 r
.3255 .65047 m .32232 .651 L .32479 .65126 L F
.32332 .65073 m .32232 .651 L .3255 .65047 L F
.32588 .65004 m .32332 .65073 L .3255 .65047 L F
.32588 .65004 m .32358 .65173 L .32232 .651 L F
0 0 .424 r
.32139 .64786 m .32232 .651 L .32358 .65173 L F
.32139 .64786 m .32303 .65076 L .32188 .65084 L F
.32303 .65076 m .32358 .65173 L .32198 .65089 L F
.32303 .65076 m .32198 .65089 L .32188 .65084 L F
0 0 .047 r
.32447 .65117 m .32505 .65247 L .3254 .65145 L F
0 0 .09 r
.32156 .65458 m .32346 .6538 L .32399 .65205 L F
.32156 .65458 m .32399 .65205 L .32244 .65346 L F
.32346 .6538 m .32356 .65376 L .32363 .65349 L F
.638 .356 .474 r
.3187 .65015 m .32148 .65069 L .32058 .64838 L F
.31951 .64737 m .32058 .64838 L .3198 .64638 L F
.3187 .65015 m .32058 .64838 L .31951 .64737 L F
.7 .332 .348 r
.31897 .64686 m .31948 .64735 L .31853 .64726 L F
.707 .86 .955 r
.5014 .48786 m .49767 .48781 L .49995 .48666 L F
.802 .877 .901 r
.50492 .4853 m .5014 .48786 L .49995 .48666 L F
.82 .994 .861 r
.51717 .38206 m .51798 .3793 L .51947 .38069 L F
.51717 .38206 m .515 .38216 L .51798 .3793 L F
.876 .656 .601 r
.42149 .57147 m .42051 .57431 L .42347 .575 L F
.875 .613 .54 r
.42051 .57431 m .422 .57976 L .42347 .575 L F
.919 .922 .8 r
.44328 .54678 m .44601 .54358 L .44513 .54783 L F
0 0 0 r
.33401 .67836 m .33748 .67515 L .33498 .67683 L F
.873 .623 .557 r
.36413 .54496 m .36059 .54413 L .36088 .54132 L F
.893 .694 .627 r
.36413 .54496 m .36031 .54692 L .36059 .54413 L F
.36413 .54496 m .3637 .54785 L .36031 .54692 L F
.646 .507 .679 r
.31836 .54141 m .31995 .54494 L .3154 .54451 L F
.52 .46 .729 r
.31916 .54765 m .3154 .54451 L .31995 .54494 L F
.31916 .54765 m .3167 .54835 L .3154 .54451 L F
.927 .91 .518 r
.27236 .65119 m .27199 .65255 L .27182 .65268 L F
.27236 .65119 m .27182 .65268 L .27172 .65204 L F
.27236 .65119 m .2705 .65368 L .27141 .65134 L F
.101 0 0 r
.27536 .65136 m .27236 .65119 L .27141 .65134 L F
.27536 .65136 m .27163 .65134 L .2734 .65025 L F
.27163 .65134 m .27141 .65134 L .27161 .65123 L F
.27163 .65134 m .27161 .65123 L .2734 .65025 L F
.927 .91 .518 r
.27172 .65204 m .27182 .65268 L .2705 .65368 L F
.067 .15 .642 r
.27199 .65255 m .27359 .65745 L .27356 .65674 L F
.27359 .65745 m .27397 .65859 L .27356 .65674 L F
.053 .426 .868 r
.27352 .65588 m .27356 .65674 L .27488 .65687 L F
.91 .505 .185 r
.27199 .65255 m .27356 .65674 L .2705 .65368 L F
.053 .426 .868 r
.2705 .65368 m .27356 .65674 L .27352 .65588 L F
.244 .72 .938 r
.64155 .39408 m .64012 .39342 L .63741 .39348 L F
.197 .688 .922 r
.64155 .39408 m .64419 .3941 L .64012 .39342 L F
.024 0 .3 r
.52051 .3871 m .51887 .39037 L .51928 .38837 L F
.276 0 0 r
.33995 .50519 m .3444 .50527 L .34224 .50558 L F
.642 .235 .257 r
.38315 .56809 m .38113 .57095 L .37937 .56813 L F
0 0 0 r
.38759 .56599 m .38524 .56754 L .38315 .56809 L F
.38524 .56754 m .38113 .57095 L .38315 .56809 L F
.232 0 0 r
.64277 .37857 m .64134 .37776 L .63997 .37929 L F
.64277 .37857 m .64414 .37803 L .64134 .37776 L F
.608 .765 .954 r
.6074 .39794 m .60324 .3969 L .606 .39613 L F
.60324 .3969 m .6074 .39794 L .606 .39613 L F
.534 .725 .961 r
.6074 .39794 m .6089 .39542 L .606 .39613 L F
.6074 .39794 m .61003 .39729 L .6089 .39542 L F
.6074 .39794 m .6089 .39542 L .606 .39613 L F
.6074 .39794 m .61003 .39729 L .6089 .39542 L F
.914 .742 .654 r
.33351 .55421 m .33198 .55759 L .3351 .55825 L F
.895 .772 .718 r
.33127 .56005 m .3351 .55825 L .33198 .55759 L F
.33127 .56005 m .33327 .56143 L .3351 .55825 L F
0 0 0 r
.44908 .43799 m .4506 .43684 L .45238 .43545 L F
.45238 .43545 m .4529 .43552 L .45434 .43393 L F
.45238 .43545 m .4506 .43684 L .4529 .43552 L F
.8 .622 .662 r
.35565 .50476 m .35323 .50778 L .35771 .50842 L F
.757 .376 .332 r
.35323 .50778 m .35541 .51022 L .35771 .50842 L F
.796 .435 .373 r
.35541 .51022 m .3599 .51123 L .35771 .50842 L F
.532 .847 .544 r
.48226 .50051 m .4811 .50171 L .4794 .50333 L F
0 0 0 r
.59421 .38782 m .59692 .384 L .59575 .38566 L F
.603 .844 .475 r
.59575 .38566 m .59308 .38913 L .59421 .38782 L F
.572 .173 .247 r
.31348 .55062 m .31202 .55352 L .30969 .55166 L F
0 0 0 r
.3167 .54835 m .31494 .54976 L .31349 .55062 L F
.631 .906 .606 r
.31754 .54697 m .31494 .54976 L .3167 .54835 L F
.593 .916 .974 r
.3154 .54813 m .31494 .54976 L .31754 .54697 L F
.156 .474 .895 r
.3154 .54813 m .31614 .54905 L .31494 .54976 L F
.31614 .54905 m .31836 .55179 L .31494 .54976 L F
0 0 0 r
.31349 .55062 m .31494 .54976 L .31348 .55062 L F
.756 .67 .767 r
.31494 .54976 m .31202 .55352 L .31348 .55062 L F
.763 .962 .931 r
.52594 .47887 m .52831 .47943 L .53037 .47765 L F
.914 .962 .801 r
.65368 .39295 m .6547 .39401 L .6569 .39069 L F
.859 .87 .846 r
.31786 .53819 m .31347 .53847 L .31564 .53681 L F
.837 .862 .863 r
.32075 .53476 m .31786 .53819 L .31564 .53681 L F
.529 .898 .967 r
.28433 .63428 m .28362 .63562 L .28085 .6365 L F
.28433 .63428 m .28618 .63467 L .28362 .63562 L F
.93 .936 .58 r
.38165 .51988 m .38178 .52184 L .38332 .51831 L F
0 0 0 r
.27824 .5574 m .27487 .5596 L .27637 .55756 L F
.57734 .37865 m .57572 .3794 L .5776 .37852 L F
.57734 .37865 m .57514 .38068 L .57572 .3794 L F
.362 .694 .982 r
.28988 .68078 m .29376 .68212 L .29202 .68129 L F
0 .502 .859 r
.29376 .68212 m .29447 .68169 L .29202 .68129 L F
.29376 .68212 m .29601 .68275 L .29447 .68169 L F
0 0 0 r
.27571 .53507 m .27286 .53833 L .27454 .53728 L F
.034 0 .321 r
.27286 .53833 m .27432 .5396 L .27454 .53728 L F
.27286 .53833 m .2725 .54101 L .27432 .5396 L F
.75 .599 .688 r
.31712 .58174 m .31547 .58552 L .31286 .58128 L F
.703 .617 .758 r
.32012 .58115 m .31712 .58174 L .32004 .57865 L F
0 0 .015 r
.27836 .5317 m .27571 .53507 L .27739 .53379 L F
.222 0 .273 r
.27454 .53728 m .27739 .53379 L .27571 .53507 L F
.455 .307 .591 r
.28403 .67371 m .28174 .67572 L .28145 .6721 L F
.385 .409 .762 r
.27833 .66716 m .28129 .67187 L .28103 .66628 L F
0 .206 .638 r
.28145 .6721 m .2829 .67291 L .28278 .67283 L F
.28145 .6721 m .28283 .67286 L .28245 .67262 L F
.28145 .6721 m .28245 .67262 L .27988 .67257 L F
.385 .409 .762 r
.28129 .67187 m .28168 .6725 L .28164 .6721 L F
.28129 .67187 m .28164 .6721 L .28103 .66628 L F
0 .206 .638 r
.28145 .6721 m .28403 .67371 L .2829 .67291 L F
.28278 .67283 m .2829 .67291 L .28283 .67286 L F
.28248 .67263 m .28283 .67286 L .28275 .6728 L F
.509 .149 .292 r
.28434 .67377 m .28248 .67263 L .28239 .67262 L F
.28198 .67264 m .28239 .67262 L .28168 .6725 L F
.28434 .67377 m .28239 .67262 L .28198 .67264 L F
.28434 .67377 m .28411 .6729 L .28248 .67263 L F
0 .206 .638 r
.28245 .67262 m .28248 .67263 L .28259 .67269 L F
.509 .149 .292 r
.28442 .67409 m .28348 .67336 L .28168 .6725 L F
0 .206 .638 r
.28248 .67263 m .28275 .6728 L .28259 .67269 L F
.509 .149 .292 r
.28442 .67409 m .28193 .67265 L .28259 .67269 L F
0 .206 .638 r
.28245 .67262 m .28259 .67269 L .28194 .67265 L F
.28245 .67262 m .28181 .67266 L .28239 .67262 L F
.28245 .67262 m .2813 .67263 L .27988 .67257 L F
.509 .149 .292 r
.28193 .67265 m .28168 .6725 L .28259 .67269 L F
0 .206 .638 r
.28194 .67265 m .28259 .67269 L .28181 .67266 L F
.28239 .67262 m .28181 .67266 L .2813 .67263 L F
.335 0 0 r
.28275 .6728 m .28442 .67409 L .28259 .67269 L F
.28403 .67371 m .28442 .67409 L .28275 .6728 L F
.28403 .67371 m .28648 .6747 L .28442 .67409 L F
.509 .149 .292 r
.28442 .67409 m .28434 .67377 L .28348 .67336 L F
.489 .456 .747 r
.28168 .6725 m .28239 .67262 L .28239 .67258 L F
.28176 .67217 m .28239 .67258 L .28317 .66611 L F
.28168 .6725 m .28239 .67258 L .28176 .67217 L F
.28239 .67262 m .28411 .6729 L .28407 .67259 L F
.28239 .67262 m .28407 .67259 L .28317 .66611 L F
.651 .95 .95 r
.55586 .3392 m .55437 .33886 L .5527 .34107 L F
.365 .546 .899 r
.5527 .34107 m .55674 .34192 L .55437 .33886 L F
.452 .87 .735 r
.44699 .43877 m .4506 .43684 L .44908 .43799 L F
.796 .652 .703 r
.53645 .40796 m .53774 .41168 L .53572 .41093 L F
.817 .615 .629 r
.53774 .41168 m .53547 .41222 L .53572 .41093 L F
.53774 .41168 m .53753 .41279 L .53547 .41222 L F
.64 .357 .474 r
.53774 .41168 m .54048 .41388 L .53753 .41279 L F
.53774 .41168 m .5409 .4115 L .54048 .41388 L F
.317 .077 .382 r
.5268 .41133 m .524 .41478 L .52665 .41399 L F
.32 .084 .391 r
.52665 .41399 m .524 .41478 L .52415 .41727 L F
.39 .836 .933 r
.63243 .34184 m .63462 .34149 L .63679 .34169 L F
.344 .82 .883 r
.63462 .34149 m .63946 .34077 L .63679 .34169 L F
.937 .952 .631 r
.42262 .56915 m .42092 .57054 L .42149 .57147 L F
.902 .964 .64 r
.42301 .56585 m .42262 .56915 L .42552 .5675 L F
.42301 .56585 m .42092 .57054 L .42262 .56915 L F
.375 .83 .736 r
.63391 .34641 m .6322 .34694 L .63106 .34777 L F
.404 .822 .639 r
.63106 .34777 m .6322 .34694 L .62981 .34843 L F
.238 .062 .428 r
.60053 .37023 m .6004 .3732 L .59786 .37273 L F
.256 0 .183 r
.6004 .3732 m .59785 .37429 L .59786 .37273 L F
.475 .746 .988 r
.37065 .47721 m .3745 .47788 L .37317 .47648 L F
.37065 .47721 m .3745 .47788 L .37317 .47648 L F
.435 .725 .987 r
.3745 .47788 m .37522 .47632 L .37317 .47648 L F
.559 .075 .063 r
.37757 .47849 m .37776 .47985 L .3745 .47788 L F
.09 .302 .782 r
.3745 .47788 m .37776 .47985 L .37522 .47632 L F
.435 .725 .987 r
.37317 .47648 m .37522 .47632 L .3745 .47788 L F
.791 .745 .811 r
.33641 .61377 m .33846 .61818 L .33561 .61854 L F
.648 .678 .865 r
.34041 .61494 m .33846 .61818 L .33641 .61377 L F
.97 .652 .306 r
.31251 .54498 m .31105 .54418 L .31066 .54123 L F
.587 .903 .641 r
.4858 .42301 m .48755 .42183 L .48947 .41997 L F
.314 .324 .711 r
.40761 .5683 m .4097 .56713 L .40915 .56494 L F
.353 .179 .501 r
.40759 .57072 m .4097 .56713 L .40761 .5683 L F
.421 .358 .681 r
.4945 .43788 m .49616 .43866 L .49632 .43403 L F
.536 0 0 r
.49754 .43944 m .49616 .43866 L .4945 .43788 L F
.931 .966 .677 r
.32795 .57395 m .32551 .57923 L .32682 .57847 L F
.49 .868 .659 r
.32551 .57923 m .32427 .58005 L .32682 .57847 L F
.918 .643 .504 r
.32427 .58005 m .32648 .58136 L .32682 .57847 L F
.866 .923 .864 r
.46062 .54073 m .46356 .54097 L .4617 .53936 L F
.46062 .54073 m .4621 .54208 L .46356 .54097 L F
.768 .89 .932 r
.4617 .53936 m .46356 .54097 L .46717 .5382 L F
.715 .966 .938 r
.31685 .62595 m .31195 .62763 L .31438 .62468 L F
.766 .761 .848 r
.31773 .62436 m .31685 .62595 L .31438 .62468 L F
.857 .542 .455 r
.5644 .39409 m .56188 .39379 L .56126 .3912 L F
.321 .305 .686 r
.56611 .38994 m .5644 .39409 L .56745 .39122 L F
.56611 .38994 m .56705 .39255 L .5644 .39409 L F
0 0 .484 r
.56613 .3952 m .5644 .39409 L .56705 .39255 L F
.56613 .3952 m .5653 .39727 L .5644 .39409 L F
.885 .965 .84 r
.34621 .64557 m .3456 .64858 L .34833 .64565 L F
.892 .49 .243 r
.34622 .64658 m .34833 .64565 L .34621 .64557 L F
.139 0 0 r
.35017 .64584 m .34833 .64565 L .34622 .64658 L F
.35017 .64584 m .351 .64548 L .34833 .64565 L F
.333 0 .014 r
.34833 .64565 m .351 .64548 L .35217 .64447 L F
.68 .881 .505 r
.29833 .65026 m .30019 .64804 L .29786 .65132 L F
.342 .817 .891 r
.30253 .64743 m .30019 .64804 L .30099 .64727 L F
0 0 0 r
.30099 .64727 m .30019 .64804 L .29833 .65026 L F
.894 .868 .806 r
.5084 .49345 m .51254 .49124 L .5116 .49042 L F
.5084 .49345 m .51007 .49476 L .51254 .49124 L F
.84 .989 .86 r
.51447 .4874 m .51254 .49124 L .51584 .48846 L F
.51447 .4874 m .5116 .49042 L .51254 .49124 L F
.629 .119 0 r
.49754 .43944 m .49935 .44099 L .50109 .44311 L F
.299 .569 .932 r
.31347 .53847 m .31361 .5404 L .31066 .54123 L F
.631 .906 .606 r
.31754 .54697 m .3167 .54835 L .31916 .54765 L F
.218 0 .271 r
.50638 .41716 m .50911 .41412 L .50685 .41502 L F
.107 0 0 r
.28246 .55153 m .28118 .55371 L .2788 .55412 L F
.195 0 .32 r
.2788 .55412 m .28069 .55647 L .27824 .5574 L F
.2788 .55412 m .28118 .55371 L .28069 .55647 L F
.772 .347 .24 r
.54583 .41253 m .54795 .41044 L .54744 .41058 L F
0 0 .5 r
.54795 .41044 m .54953 .41203 L .55143 .40872 L F
.746 .812 .339 r
.56645 .41065 m .5676 .40794 L .56678 .40951 L F
.595 .885 .581 r
.5676 .40794 m .57063 .40481 L .56913 .40603 L F
0 0 0 r
.56678 .40951 m .5676 .40794 L .56913 .40603 L F
.853 .803 .314 r
.56123 .36691 m .5603 .36847 L .55856 .36618 L F
.56123 .36691 m .56022 .37095 L .5603 .36847 L F
.229 .321 .751 r
.56766 .39888 m .56631 .4014 L .5653 .39727 L F
.601 .837 .989 r
.56996 .39908 m .56631 .4014 L .56486 .39991 L F
.988 .718 .37 r
.56486 .39991 m .56631 .4014 L .56494 .40272 L F
.176 .443 .873 r
.55882 .35914 m .56034 .3613 L .5586 .36133 L F
0 .025 .592 r
.5586 .36133 m .56045 .36394 L .55882 .35914 L F
.863 .926 .867 r
.40322 .57833 m .40168 .5773 L .40457 .57461 L F
.39 .115 .371 r
.49632 .43403 m .50012 .43015 L .49615 .43126 L F
0 0 0 r
.42642 .46206 m .42473 .46325 L .42243 .46442 L F
.42642 .46206 m .42711 .46204 L .42473 .46325 L F
.42642 .46206 m .42912 .46183 L .42711 .46204 L F
.953 .925 .739 r
.50963 .47808 m .50649 .47998 L .50873 .47691 L F
.50963 .47808 m .50771 .48208 L .50649 .47998 L F
.969 .93 .624 r
.51025 .47585 m .50963 .47808 L .50873 .47691 L F
.819 .92 .904 r
.56611 .38994 m .56745 .39122 L .57051 .38859 L F
.89 .66 .584 r
.36574 .55158 m .36276 .55104 L .3637 .54785 L F
.868 .645 .598 r
.36574 .55158 m .36185 .55367 L .36276 .55104 L F
.36574 .55158 m .36547 .55445 L .36185 .55367 L F
.824 .988 .873 r
.31373 .63311 m .31369 .63483 L .31414 .63272 L F
.844 .803 .811 r
.31071 .63512 m .31367 .6358 L .31369 .63483 L F
.31071 .63512 m .31276 .63891 L .31514 .63615 L F
.253 0 0 r
.31071 .63512 m .31369 .63483 L .3111 .63559 L F
.737 .601 .706 r
.30727 .63302 m .31262 .63456 L .31005 .62945 L F
.31262 .63456 m .31278 .63443 L .31005 .62945 L F
.773 .997 .852 r
.30873 .63679 m .31071 .63512 L .30896 .63652 L F
.253 0 0 r
.31071 .63512 m .3111 .63559 L .30896 .63652 L F
.754 .546 .614 r
.3111 .63559 m .31262 .63456 L .30727 .63302 L F
.815 .956 .907 r
.3111 .63559 m .31259 .63414 L .31261 .63416 L F
.824 .988 .873 r
.31152 .63546 m .31371 .63383 L .31262 .63456 L F
.754 .546 .614 r
.3111 .63559 m .3129 .63464 L .31262 .63456 L F
.824 .988 .873 r
.31152 .63546 m .31313 .63499 L .31282 .63449 L F
.737 .601 .706 r
.31262 .63456 m .3129 .63464 L .31278 .63443 L F
.659 .262 0 r
.31005 .62945 m .31235 .63365 L .31213 .63338 L F
.31235 .63365 m .31266 .63421 L .31237 .63376 L F
.31235 .63365 m .31237 .63376 L .31213 .63338 L F
.815 .956 .907 r
.31261 .63416 m .31241 .63396 L .31414 .63272 L F
.684 .882 .972 r
.31369 .63483 m .31607 .63396 L .31414 .63272 L F
.31607 .63396 m .31678 .6337 L .31625 .63351 L F
.31607 .63396 m .31625 .63351 L .31414 .63272 L F
.173 .339 .791 r
.31819 .63622 m .32053 .63702 L .31699 .63547 L F
.704 .832 .944 r
.31369 .63483 m .31682 .63543 L .31678 .6337 L F
.31682 .63543 m .31699 .63547 L .31678 .6337 L F
.846 .867 .857 r
.31414 .63272 m .31678 .6337 L .31677 .63039 L F
.79 .669 .118 r
.31673 .63173 m .31678 .6337 L .31663 .63512 L F
.31677 .63039 m .31678 .6337 L .31673 .63173 L F
0 .336 .709 r
.31699 .63547 m .31663 .63512 L .31678 .6337 L F
.31699 .63547 m .32053 .63702 L .31663 .63512 L F
.442 .79 .998 r
.31514 .63615 m .31819 .63622 L .31699 .63547 L F
.173 .339 .791 r
.31819 .63622 m .32051 .63731 L .32053 .63702 L F
.835 .419 .251 r
.31663 .63512 m .32053 .63702 L .31825 .63726 L F
.79 .669 .118 r
.31698 .63171 m .31663 .63512 L .31763 .63596 L F
.31677 .63039 m .31671 .63236 L .31698 .63171 L F
.31671 .63236 m .31663 .63512 L .31698 .63171 L F
0 0 0 r
.31242 .63401 m .31414 .63272 L .31559 .6322 L F
.815 .956 .907 r
.3111 .63559 m .31259 .63414 L .31213 .63338 L F
.3111 .63559 m .31205 .63422 L .31241 .63396 L F
0 0 0 r
.31205 .63422 m .31241 .63396 L .31242 .63401 L F
.31241 .63396 m .31414 .63272 L .31242 .63401 L F
.659 .262 0 r
.31278 .63443 m .31237 .63377 L .31213 .63338 L F
.824 .988 .873 r
.3111 .63559 m .31152 .63546 L .31373 .63311 L F
.659 .262 0 r
.31266 .63421 m .31278 .63443 L .31262 .63417 L F
.824 .988 .873 r
.31152 .63546 m .31371 .63367 L .31373 .63311 L F
.815 .956 .907 r
.3111 .63559 m .3129 .63464 L .31259 .63414 L F
.3111 .63559 m .31241 .63396 L .31259 .63414 L F
.659 .262 0 r
.31266 .63421 m .31262 .63417 L .31213 .63338 L F
.31278 .63443 m .3129 .63464 L .31237 .63377 L F
.824 .988 .873 r
.31282 .63449 m .31369 .63483 L .31371 .63383 L F
.31313 .63499 m .31369 .63483 L .31282 .63449 L F
.31262 .63456 m .31371 .63383 L .31371 .63367 L F
.844 .803 .811 r
.31367 .6358 m .31514 .63615 L .31369 .63483 L F
.924 .888 .778 r
.31249 .64097 m .31514 .63615 L .31276 .63891 L F
.561 .835 .997 r
.31369 .63483 m .31514 .63615 L .31699 .63547 L F
.067 0 .192 r
.28089 .52822 m .27836 .5317 L .28004 .53054 L F
.2 0 .173 r
.27836 .5317 m .28041 .53226 L .28004 .53054 L F
.27836 .5317 m .27739 .53379 L .28041 .53226 L F
.846 .957 .883 r
.38721 .5635 m .38759 .56599 L .39039 .56359 L F
.931 .891 .769 r
.3895 .56055 m .39039 .56359 L .39173 .56115 L F
.3895 .56055 m .38721 .5635 L .39039 .56359 L F
.557 .266 .429 r
.52665 .41399 m .52945 .41337 L .5268 .41133 L F
.415 .673 .968 r
.64835 .39451 m .64982 .39261 L .64699 .39319 L F
.64835 .39451 m .6517 .39458 L .64982 .39261 L F
.748 .267 .097 r
.32921 .64089 m .3328 .63837 L .33018 .63934 L F
.45 .337 .634 r
.33332 .64154 m .33537 .63783 L .3328 .63837 L F
.116 0 0 r
.33537 .63783 m .33018 .63934 L .3328 .63837 L F
.903 .629 .513 r
.33019 .53373 m .33387 .53743 L .33402 .53562 L F
.189 .184 .621 r
.24912 .60768 m .2513 .61026 L .24884 .61017 L F
.854 .557 .486 r
.34509 .51802 m .34271 .51789 L .34135 .51446 L F
.815 .442 .348 r
.34509 .51802 m .34301 .52002 L .34271 .51789 L F
.843 .484 .375 r
.34562 .52049 m .34301 .52002 L .34509 .51802 L F
.99 .828 .45 r
.6569 .39069 m .6565 .38712 L .65599 .38958 L F
.914 .962 .801 r
.65368 .39295 m .6569 .39069 L .65599 .38958 L F
.711 .909 .964 r
.54259 .43254 m .53809 .43336 L .54092 .43345 L F
.847 .995 .834 r
.54351 .42996 m .54259 .43254 L .54092 .43345 L F
.756 .7 .798 r
.51222 .39939 m .51724 .39917 L .51271 .40011 L F
.819 .951 .905 r
.51816 .39596 m .51724 .39917 L .51967 .39789 L F
.51816 .39596 m .51271 .40011 L .51724 .39917 L F
.85 .993 .744 r
.57122 .40228 m .57063 .40481 L .57326 .40135 L F
.843 .948 .593 r
.56913 .40603 m .57063 .40481 L .57122 .40228 L F
.91 .666 .557 r
.50154 .45979 m .499 .45603 L .49987 .45657 L F
.844 .381 .073 r
.50122 .45829 m .50154 .45979 L .49987 .45657 L F
.812 .524 .501 r
.39842 .47359 m .39393 .47617 L .3934 .47399 L F
.39842 .47359 m .39764 .47693 L .39393 .47617 L F
.555 .269 .436 r
.39842 .47359 m .40002 .47492 L .39764 .47693 L F
.763 .32 .2 r
.5709 .37571 m .57367 .37505 L .57007 .37445 L F
.5709 .37571 m .57441 .37657 L .57367 .37505 L F
0 0 .167 r
.57612 .34817 m .57556 .35016 L .5778 .34678 L F
.158 .687 .864 r
.38138 .58657 m .37822 .586 L .37988 .58758 L F
0 .1 .645 r
.38138 .58657 m .38333 .58529 L .38075 .58589 L F
.555 0 0 r
.38313 .5875 m .38466 .58931 L .38138 .58657 L F
.38697 .58954 m .38466 .58931 L .38313 .5875 L F
.384 0 0 r
.38697 .58954 m .385 .58975 L .38466 .58931 L F
0 0 .478 r
.38466 .58931 m .385 .58975 L .38494 .58964 L F
0 .1 .645 r
.38138 .58657 m .38466 .58931 L .38333 .58529 L F
.789 .476 0 r
.38333 .58529 m .38438 .58846 L .38385 .5876 L F
.38438 .58846 m .38466 .58931 L .38388 .58766 L F
.38438 .58846 m .38388 .58766 L .38385 .5876 L F
.214 .681 .943 r
.39013 .58875 m .38856 .58786 L .38385 .58761 L F
0 0 .478 r
.38466 .58931 m .38381 .58761 L .38385 .5876 L F
.214 .681 .943 r
.38385 .58762 m .38385 .58761 L .38381 .58761 L F
.39013 .58875 m .38385 .58761 L .38385 .58762 L F
0 0 .478 r
.38466 .58931 m .38494 .58964 L .38381 .58761 L F
.905 .735 .66 r
.33094 .54632 m .33605 .54598 L .33136 .54345 L F
.33094 .54632 m .33321 .54757 L .33605 .54598 L F
.92 .797 .707 r
.33605 .54598 m .33321 .54757 L .33513 .54841 L F
.463 .871 .716 r
.4597 .44067 m .45905 .44083 L .45537 .44296 L F
.505 .892 .723 r
.4597 .44067 m .46317 .43846 L .46119 .43932 L F
.504 .889 .714 r
.46119 .43932 m .45905 .44083 L .4597 .44067 L F
.941 .731 .591 r
.31181 .64449 m .31296 .64768 L .31047 .64715 L F
.668 .132 0 r
.31047 .64715 m .31296 .64768 L .31201 .64824 L F
.159 0 .155 r
.31296 .64768 m .31647 .64451 L .31633 .64768 L F
.992 .747 .449 r
.31633 .64768 m .31201 .64824 L .31296 .64768 L F
.795 .902 .917 r
.50516 .49617 m .51007 .49476 L .5084 .49345 L F
.925 .891 .778 r
.32987 .57 m .33259 .56896 L .33124 .56798 L F
.361 0 .057 r
.54213 .38529 m .54122 .38662 L .53831 .38709 L F
0 0 0 r
.54367 .3835 m .54122 .38662 L .54213 .38529 L F
.934 .954 .769 r
.56462 .37797 m .56378 .37662 L .56588 .37316 L F
.991 .865 .516 r
.56462 .37797 m .56311 .37923 L .56378 .37662 L F
.973 .671 .376 r
.56462 .37797 m .56492 .38078 L .56311 .37923 L F
.561 .857 .997 r
.56471 .36396 m .56045 .36394 L .5617 .36461 L F
.791 .872 .908 r
.49358 .50757 m .49613 .503 L .49304 .50603 L F
.49358 .50757 m .49782 .50432 L .49613 .503 L F
.698 .424 .506 r
.38636 .47398 m .38643 .47729 L .38182 .47575 L F
.38636 .47398 m .38233 .47352 L .38497 .47361 L F
.38636 .47398 m .38182 .47575 L .38233 .47352 L F
.191 0 0 r
.38643 .47729 m .38183 .47879 L .38182 .47575 L F
.495 .405 .683 r
.38182 .47575 m .38416 .47766 L .38497 .47361 L F
.469 0 0 r
.383 .47684 m .38416 .47766 L .38182 .47575 L F
.45 0 0 r
.38636 .47398 m .39053 .47488 L .38856 .47512 L F
.38636 .47398 m .3891 .47539 L .38643 .47729 L F
.48 .391 .678 r
.38497 .47361 m .38416 .47766 L .38847 .47447 L F
.512 .073 .141 r
.383 .47684 m .38637 .47538 L .38416 .47766 L F
.38637 .47538 m .38847 .47447 L .38741 .47526 L F
.38637 .47538 m .38741 .47526 L .38416 .47766 L F
.45 0 0 r
.38856 .47512 m .39082 .47495 L .3891 .47539 L F
.39053 .47488 m .39082 .47495 L .38856 .47512 L F
.285 .777 .72 r
.3891 .47539 m .39082 .47495 L .3934 .47399 L F
.967 .796 .62 r
.31051 .64049 m .31236 .64155 L .31276 .63891 L F
.979 .726 .481 r
.31236 .64155 m .31249 .64097 L .31276 .63891 L F
.689 .526 .661 r
.32208 .54151 m .31995 .54494 L .31836 .54141 L F
.802 .877 .901 r
.50492 .4853 m .49995 .48666 L .50313 .48435 L F
.782 .982 .72 r
.50771 .48208 m .50492 .4853 L .50571 .48312 L F
.652 .916 .978 r
.50492 .4853 m .50313 .48435 L .50571 .48312 L F
0 0 0 r
.59565 .34384 m .59628 .3439 L .59836 .34376 L F
.59565 .34384 m .59488 .34604 L .59628 .3439 L F
.976 .681 .302 r
.3503 .62766 m .35026 .62514 L .34879 .62373 L F
0 0 .356 r
.27758 .63904 m .2741 .64141 L .27622 .64061 L F
0 0 0 r
.2796 .63792 m .27758 .63904 L .27622 .64061 L F
.724 .983 .903 r
.53522 .43468 m .5308 .43652 L .53331 .43521 L F
.542 .921 .927 r
.53644 .4333 m .53809 .43336 L .53522 .43468 L F
.57 .928 .763 r
.53644 .4333 m .53522 .43468 L .53331 .43521 L F
.503 .129 .263 r
.25601 .58837 m .25474 .59032 L .25245 .59021 L F
.841 .998 .82 r
.25608 .58615 m .25601 .58837 L .25863 .58559 L F
.479 .865 .976 r
.25672 .58907 m .25601 .58837 L .25608 .58615 L F
.25672 .58907 m .25474 .59032 L .25601 .58837 L F
0 .024 .597 r
.52666 .44524 m .52846 .44776 L .52791 .44566 L F
.484 .106 .247 r
.32647 .63358 m .33117 .63151 L .33158 .63125 L F
.32647 .63358 m .32952 .6332 L .33117 .63151 L F
.32952 .6332 m .33083 .63303 L .33107 .63196 L F
.32952 .6332 m .33107 .63196 L .33117 .63151 L F
.32647 .63358 m .33158 .63125 L .32952 .6332 L F
.32647 .63358 m .32952 .6332 L .32736 .63523 L F
.496 .185 .369 r
.32941 .63641 m .33055 .63426 L .32859 .63394 L F
.32768 .63475 m .32859 .63394 L .32647 .63358 L F
.754 .986 .76 r
.32859 .63394 m .32736 .63523 L .32952 .6332 L F
.32768 .63475 m .32736 .63523 L .32859 .63394 L F
.496 .185 .369 r
.32941 .63641 m .32859 .63394 L .32768 .63475 L F
.754 .986 .76 r
.32779 .63458 m .32768 .63475 L .32859 .63394 L F
.496 .185 .369 r
.32768 .63475 m .32647 .63358 L .32736 .63523 L F
.754 .986 .76 r
.32759 .63474 m .32736 .63523 L .32779 .63458 L F
.496 .185 .369 r
.32941 .63641 m .32768 .63475 L .32736 .63523 L F
.484 .106 .247 r
.32954 .6332 m .33055 .63426 L .33083 .63303 L F
.32647 .63358 m .3286 .63394 L .32954 .6332 L F
.3286 .63394 m .33055 .63426 L .32954 .6332 L F
0 0 0 r
.32516 .63612 m .32736 .63523 L .3233 .63684 L F
.736 .239 .053 r
.32283 .63364 m .32736 .63523 L .32516 .63612 L F
.754 .987 .764 r
.32516 .63612 m .32656 .63556 L .32829 .63327 L F
.32656 .63556 m .32736 .63523 L .32759 .63474 L F
.32656 .63556 m .32759 .63474 L .32829 .63327 L F
0 0 0 r
.33117 .63151 m .33155 .63263 L .33264 .63069 L F
.33123 .6317 m .33055 .63426 L .33155 .63263 L F
.33117 .63151 m .33107 .63196 L .33123 .6317 L F
.33107 .63196 m .33055 .63426 L .33123 .6317 L F
.754 .986 .76 r
.32829 .63327 m .32759 .63474 L .33143 .63138 L F
.357 .829 .803 r
.33158 .63125 m .33117 .63151 L .33264 .63069 L F
.754 .986 .76 r
.33147 .63132 m .33143 .63138 L .33158 .63125 L F
.32829 .63327 m .33143 .63138 L .33147 .63132 L F
.32759 .63474 m .32952 .6332 L .33158 .63125 L F
.93 .721 .599 r
.34567 .49695 m .34847 .49885 L .34782 .49673 L F
.592 .94 .779 r
.43476 .56761 m .43877 .56527 L .43723 .5642 L F
.799 .921 .919 r
.43723 .5642 m .43877 .56527 L .44049 .56397 L F
.939 .892 .756 r
.28484 .53678 m .28777 .53543 L .28702 .53336 L F
.28484 .53678 m .28635 .53807 L .28777 .53543 L F
.582 .477 .7 r
.38721 .5635 m .38524 .56754 L .38759 .56599 L F
.853 .987 .712 r
.52734 .39205 m .52683 .39488 L .52935 .39133 L F
.302 .545 .917 r
.52433 .39238 m .52683 .39488 L .52734 .39205 L F
.421 .416 .748 r
.38233 .47352 m .38007 .47564 L .38015 .47372 L F
.346 .208 .546 r
.38182 .47575 m .38007 .47564 L .38233 .47352 L F
.38182 .47575 m .38067 .47672 L .38007 .47564 L F
.653 .958 .759 r
.49867 .40008 m .5021 .39736 L .49946 .39854 L F
.333 .087 .384 r
.54048 .41388 m .5409 .4115 L .54308 .4106 L F
.993 .88 .589 r
.50771 .48208 m .50571 .48312 L .50649 .47998 L F
.955 .783 .333 r
.32825 .65736 m .32897 .65944 L .32885 .65473 L F
0 0 0 r
.32853 .66059 m .32897 .65944 L .32825 .65736 L F
.322 .302 .681 r
.32885 .65473 m .32894 .65851 L .33151 .65729 L F
.32885 .65473 m .33151 .65729 L .33251 .6534 L F
.287 .007 .301 r
.33251 .6534 m .33151 .65729 L .33395 .65653 L F
.473 .804 1 r
.33327 .65646 m .33151 .65729 L .3295 .65604 L F
.33395 .65653 m .33151 .65729 L .33327 .65646 L F
.322 .302 .681 r
.32894 .65851 m .32897 .65944 L .33151 .65729 L F
.833 .362 .007 r
.32897 .65944 m .33073 .66184 L .32853 .66059 L F
.32897 .65944 m .32853 .66059 L .33151 .65729 L F
.204 .729 .839 r
.25991 .58594 m .25608 .58615 L .25863 .58559 L F
.1 0 0 r
.26144 .58466 m .25991 .58594 L .25863 .58559 L F
.068 0 0 r
.64635 .33882 m .6451 .33954 L .64911 .33867 L F
.857 .602 .553 r
.35957 .51295 m .36388 .51146 L .3599 .51123 L F
.35957 .51295 m .3637 .51421 L .36388 .51146 L F
.585 .49 .713 r
.24488 .60447 m .24457 .61028 L .24767 .60638 L F
.739 .884 .48 r
.24457 .61028 m .24483 .6085 L .24767 .60638 L F
.24457 .61028 m .24393 .6107 L .24483 .6085 L F
.918 .524 .211 r
.36759 .57492 m .36579 .57412 L .36538 .57183 L F
.339 .746 .981 r
.36759 .57492 m .36864 .57369 L .36579 .57412 L F
.36759 .57492 m .37037 .57468 L .36864 .57369 L F
.267 0 0 r
.30675 .65986 m .30582 .65843 L .30408 .66074 L F
.356 .262 .61 r
.52879 .3882 m .52945 .38997 L .53069 .38636 L F
.52938 .39017 m .52942 .39009 L .53069 .38636 L F
.865 .994 .816 r
.53041 .38849 m .52935 .39133 L .53208 .3882 L F
.356 .262 .61 r
.52938 .39017 m .52939 .3902 L .52942 .39009 L F
.868 .901 .484 r
.52959 .38863 m .52939 .3902 L .53069 .38636 L F
.865 .994 .816 r
.52959 .38863 m .52947 .39002 L .53041 .38849 L F
.52947 .39002 m .52935 .39133 L .53041 .38849 L F
.338 0 0 r
.53048 .3922 m .53019 .39198 L .52959 .38863 L F
.53019 .39198 m .52935 .39133 L .52947 .39002 L F
.53019 .39198 m .52947 .39002 L .52959 .38863 L F
.356 .262 .61 r
.52868 .38832 m .52938 .39017 L .52945 .38997 L F
.52868 .38832 m .52945 .38997 L .52879 .3882 L F
.338 0 0 r
.53048 .3922 m .52734 .39205 L .52935 .39133 L F
.986 .729 .454 r
.32356 .5645 m .32202 .56391 L .32197 .56087 L F
.591 .83 .99 r
.65067 .37676 m .648 .37778 L .64943 .3755 L F
.677 .939 .965 r
.64943 .3755 m .648 .37778 L .6469 .37696 L F
.995 .764 .464 r
.52252 .43848 m .52176 .44054 L .52468 .43734 L F
.205 0 0 r
.35349 .64487 m .35217 .64447 L .351 .64548 L F
0 0 0 r
.35124 .64577 m .35349 .64487 L .351 .64548 L F
.567 .929 .774 r
.35299 .64479 m .35349 .64487 L .35124 .64577 L F
.205 0 0 r
.35349 .64487 m .35408 .64497 L .35217 .64447 L F
.567 .929 .774 r
.35593 .64315 m .35349 .64487 L .35299 .64479 L F
.205 0 0 r
.35349 .64487 m .35472 .64514 L .35408 .64497 L F
.315 .101 .421 r
.2834 .52469 m .28089 .52822 L .28308 .52703 L F
.611 .441 .627 r
.28004 .53054 m .28308 .52703 L .28089 .52822 L F
.998 .838 .504 r
.31151 .68449 m .31295 .6852 L .31312 .6842 L F
.56 .638 .885 r
.28246 .55153 m .27812 .54912 L .28234 .55049 L F
0 .23 .749 r
.28234 .55049 m .28272 .55012 L .28246 .55153 L F
.628 .227 .265 r
.28477 .55368 m .28246 .55153 L .28272 .55012 L F
.28477 .55368 m .28118 .55371 L .28246 .55153 L F
.694 .966 .936 r
.44582 .57119 m .44791 .56986 L .44717 .57179 L F
.738 .992 .864 r
.44717 .57179 m .44791 .56986 L .44455 .57244 L F
.696 .189 .029 r
.53547 .41222 m .53753 .41279 L .53714 .41485 L F
.997 .861 .554 r
.54048 .41388 m .53714 .41485 L .53753 .41279 L F
.941 .801 .676 r
.54467 .45338 m .54583 .45702 L .54645 .45466 L F
.907 .939 .818 r
.52897 .4518 m .52658 .45276 L .52779 .45051 L F
.52897 .4518 m .52649 .45492 L .52658 .45276 L F
.959 .847 .689 r
.52846 .44776 m .52897 .4518 L .52779 .45051 L F
.981 .911 .643 r
.57122 .40228 m .57326 .40135 L .57229 .40005 L F
.824 .686 .71 r
.37556 .51192 m .3749 .51451 L .37673 .51125 L F
.468 .751 .991 r
.39704 .57934 m .39222 .57808 L .39514 .57716 L F
.733 .681 .8 r
.39704 .57934 m .39222 .57808 L .39514 .57716 L F
.617 .677 .884 r
.39514 .57716 m .39704 .57934 L .39954 .57803 L F
.39514 .57716 m .39704 .57934 L .39954 .57803 L F
.506 .859 .606 r
.49723 .40196 m .4939 .40468 L .49587 .403 L F
0 0 0 r
.4939 .40468 m .49553 .40356 L .49587 .403 L F
0 0 .185 r
.52366 .36979 m .52388 .3729 L .52351 .37343 L F
.932 .696 .559 r
.52067 .37589 m .52351 .37343 L .52388 .3729 L F
.52067 .37589 m .52331 .37763 L .52351 .37343 L F
.946 .619 .376 r
.39701 .51845 m .39513 .51969 L .39483 .51717 L F
.39483 .51717 m .39513 .51969 L .39701 .51845 L F
.674 .401 .499 r
.53069 .38636 m .53208 .3882 L .53601 .38459 L F
.53069 .38636 m .52959 .38863 L .53208 .3882 L F
.912 .894 .798 r
.56351 .42342 m .56477 .42213 L .56328 .42035 L F
0 0 .126 r
.25087 .58463 m .25252 .58341 L .25323 .58082 L F
.424 .163 .412 r
.24936 .58659 m .25252 .58341 L .25087 .58463 L F
.775 .378 .304 r
.53928 .42386 m .54328 .42472 L .54287 .42726 L F
.685 .289 .291 r
.54287 .42726 m .54328 .42472 L .5438 .42696 L F
0 0 0 r
.34241 .63499 m .34308 .63008 L .34413 .63425 L F
.48 .852 .987 r
.33897 .62778 m .34095 .62831 L .34323 .62756 L F
.34323 .62756 m .34095 .62831 L .33897 .62778 L F
.66 .761 .925 r
.64919 .35165 m .64514 .35039 L .64695 .34748 L F
.871 .654 .606 r
.648 .35496 m .64742 .35391 L .64765 .35282 L F
.737 .26 .113 r
.64797 .35127 m .64765 .35282 L .64514 .35039 L F
0 .037 .547 r
.64514 .35039 m .64568 .35091 L .64565 .3507 L F
.737 .26 .113 r
.64919 .35165 m .64765 .35282 L .64797 .35127 L F
0 0 0 r
.64668 .35174 m .6489 .35184 L .64931 .35005 L F
0 .037 .547 r
.64578 .35101 m .64765 .35282 L .64647 .35157 L F
.462 .146 .344 r
.64598 .3524 m .646 .35239 L .64608 .35213 L F
0 0 0 r
.64608 .35213 m .64631 .35211 L .6464 .35193 L F
.871 .654 .606 r
.64639 .35203 m .64633 .35208 L .64638 .35201 L F
.846 .743 .749 r
.648 .35496 m .64366 .35698 L .64364 .35419 L F
0 .048 .561 r
.64364 .35419 m .64366 .35698 L .64527 .35436 L F
.671 .899 .553 r
.64404 .35637 m .64218 .35835 L .64527 .35436 L F
.64366 .35698 m .64291 .35768 L .64404 .35637 L F
.64291 .35768 m .64218 .35835 L .64404 .35637 L F
.871 .654 .606 r
.64669 .35329 m .64392 .35424 L .64598 .3524 L F
.648 .35496 m .64562 .35454 L .64669 .35329 L F
.64562 .35454 m .64392 .35424 L .64669 .35329 L F
.64641 .35207 m .64598 .3524 L .64639 .35203 L F
.648 .35496 m .64598 .3524 L .64641 .35207 L F
.64392 .35424 m .64364 .35419 L .64639 .35203 L F
0 .048 .561 r
.64364 .35419 m .64527 .35436 L .64598 .3524 L F
.64364 .35419 m .64598 .3524 L .64608 .35213 L F
0 0 0 r
.64631 .35211 m .64636 .3521 L .64638 .35201 L F
.64631 .35211 m .64638 .35201 L .6464 .35193 L F
0 .037 .547 r
.64568 .35091 m .64578 .35101 L .64565 .3507 L F
.952 .791 .646 r
.64565 .3507 m .64608 .35213 L .64597 .35174 L F
0 0 0 r
.64608 .35213 m .64649 .35187 L .64597 .35174 L F
.871 .654 .606 r
.64638 .35201 m .64611 .35222 L .64597 .35174 L F
.64627 .35181 m .64597 .35174 L .64565 .3507 L F
.64638 .35201 m .64597 .35174 L .64627 .35181 L F
0 .037 .547 r
.64578 .35101 m .64647 .35157 L .64565 .3507 L F
.871 .654 .606 r
.64638 .35201 m .64565 .3507 L .64647 .35157 L F
.18 .324 .774 r
.64514 .35039 m .64362 .34626 L .64695 .34748 L F
.64514 .35039 m .64645 .34821 L .64362 .34626 L F
0 .037 .547 r
.64514 .35039 m .64565 .3507 L .64645 .34821 L F
.822 .637 .652 r
.64565 .3507 m .64246 .34742 L .64645 .34821 L F
0 0 0 r
.64597 .35174 m .64931 .35005 L .64536 .34961 L F
.64649 .35187 m .64931 .35005 L .64597 .35174 L F
.952 .791 .646 r
.64565 .3507 m .64597 .35174 L .64564 .35061 L F
.64565 .3507 m .64364 .35419 L .64608 .35213 L F
.871 .654 .606 r
.64611 .35222 m .64364 .35419 L .64565 .3507 L F
.64633 .35208 m .64364 .35419 L .64638 .35201 L F
.462 .146 .344 r
.64527 .35436 m .64536 .3543 L .646 .35239 L F
.64527 .35436 m .646 .35239 L .64598 .3524 L F
.871 .654 .606 r
.64742 .35391 m .64639 .35203 L .64765 .35282 L F
.64639 .35203 m .64639 .35202 L .64765 .35282 L F
.64638 .35201 m .64647 .35157 L .64765 .35282 L F
.462 .146 .344 r
.64536 .3543 m .6489 .35184 L .64636 .3521 L F
.64536 .3543 m .64636 .3521 L .64608 .35213 L F
.871 .654 .606 r
.64639 .35203 m .64638 .35201 L .64639 .35202 L F
0 0 0 r
.6464 .35193 m .64704 .35203 L .64668 .35174 L F
.64636 .3521 m .64704 .35203 L .6464 .35193 L F
.64704 .35203 m .6489 .35184 L .64668 .35174 L F
.952 .791 .646 r
.64565 .3507 m .64564 .35061 L .64536 .34961 L F
.635 .127 .024 r
.64919 .35165 m .65176 .35353 L .64765 .35282 L F
0 0 0 r
.42052 .45689 m .42262 .45541 L .42404 .4538 L F
.42601 .45309 m .42769 .45183 L .42404 .4538 L F
.42262 .45541 m .42601 .45309 L .42404 .4538 L F
.226 .714 .926 r
.59836 .34376 m .60107 .34371 L .60244 .34431 L F
.361 .801 .959 r
.60107 .34371 m .60517 .34386 L .60244 .34431 L F
.397 0 0 r
.37947 .57159 m .38455 .57334 L .3816 .5716 L F
.745 .739 .847 r
.30267 .62912 m .30002 .63173 L .29847 .62876 L F
.783 .834 .892 r
.33165 .65249 m .32885 .65473 L .33251 .6534 L F
.013 .429 .863 r
.33251 .6534 m .3346 .65373 L .33165 .65249 L F
.287 .007 .301 r
.33251 .6534 m .33395 .65653 L .3346 .65373 L F
.805 .723 .775 r
.31876 .59149 m .32285 .59205 L .3217 .58794 L F
.679 .455 .575 r
.3637 .51421 m .36793 .51676 L .3681 .51491 L F
.49 .114 .254 r
.36793 .51676 m .3705 .51645 L .3681 .51491 L F
.522 .075 .13 r
.3681 .51491 m .3705 .51645 L .37284 .51469 L F
.244 .635 .96 r
.41694 .59428 m .41725 .59312 L .41565 .5942 L F
.41694 .59428 m .41882 .59451 L .41725 .59312 L F
.981 .913 .623 r
.46062 .54073 m .46077 .54431 L .4621 .54208 L F
.946 .596 .313 r
.56126 .3912 m .55985 .39247 L .55963 .38985 L F
.56126 .3912 m .56188 .39379 L .55985 .39247 L F
.968 .9 .536 r
.42092 .57054 m .42051 .57431 L .42149 .57147 L F
.731 .599 .709 r
.32217 .68562 m .32507 .68539 L .3226 .68841 L F
.19 0 .24 r
.3226 .68841 m .32507 .68539 L .32467 .6869 L F
.3226 .68841 m .32507 .68539 L .32467 .6869 L F
0 0 0 r
.32507 .68539 m .32778 .68154 L .32805 .68485 L F
.386 .078 .315 r
.32467 .6869 m .32507 .68539 L .32805 .68485 L F
.856 .665 .642 r
.38682 .52703 m .38873 .53112 L .38925 .52825 L F
.645 .103 0 r
.32295 .54881 m .32209 .55003 L .31916 .54765 L F
.878 .441 .085 r
.32418 .5512 m .32209 .55003 L .32295 .54881 L F
.806 .987 .886 r
.46977 .51631 m .47086 .51333 L .47248 .51471 L F
.46977 .51631 m .46762 .51624 L .47086 .51333 L F
.914 .773 .691 r
.36624 .56826 m .36234 .5705 L .36408 .56708 L F
.36624 .56826 m .36538 .57183 L .36234 .5705 L F
.928 .76 .652 r
.54048 .41388 m .5419 .41791 L .53993 .41669 L F
.934 .845 .732 r
.5419 .41791 m .53842 .42025 L .53993 .41669 L F
.975 .819 .625 r
.53842 .42025 m .53996 .42233 L .53928 .42386 L F
.757 .718 .815 r
.53842 .42025 m .53928 .42386 L .53506 .42334 L F
0 0 0 r
.53842 .42025 m .53687 .42367 L .53898 .42055 L F
.53687 .42367 m .53686 .42367 L .53687 .42367 L F
.53687 .42367 m .53687 .42367 L .53898 .42055 L F
.741 .364 .338 r
.5367 .42432 m .53928 .42386 L .5395 .42598 L F
.53506 .42334 m .53689 .42357 L .5367 .42432 L F
.53689 .42357 m .53928 .42386 L .5367 .42432 L F
.614 .845 .469 r
.53898 .42055 m .53728 .42306 L .53694 .42337 L F
.53728 .42306 m .53686 .42367 L .53689 .42357 L F
.53728 .42306 m .53689 .42357 L .53694 .42337 L F
.934 .845 .732 r
.5419 .41791 m .53996 .42233 L .53891 .42091 L F
.54048 .41887 m .53891 .42091 L .53842 .42025 L F
.5419 .41791 m .53891 .42091 L .54048 .41887 L F
.969 .93 .624 r
.51025 .47585 m .50873 .47691 L .51091 .47336 L F
.785 .759 .83 r
.50972 .46131 m .50569 .46086 L .50836 .45847 L F
.486 .172 .359 r
.50972 .46131 m .50618 .46412 L .50569 .46086 L F
.50972 .46131 m .50912 .46375 L .50618 .46412 L F
0 .191 .722 r
.50836 .45847 m .51036 .46003 L .50972 .46131 L F
0 0 .104 r
.51106 .4613 m .50972 .46131 L .51036 .46003 L F
.51106 .4613 m .50912 .46375 L .50972 .46131 L F
.835 .544 .497 r
.34963 .52415 m .34562 .52049 L .34942 .52138 L F
.748 .324 .243 r
.37937 .56813 m .37591 .56999 L .37947 .57159 L F
.37937 .56813 m .3755 .56753 L .37591 .56999 L F
.37937 .56813 m .37794 .57095 L .3755 .56753 L F
.68 .245 .21 r
.38113 .57095 m .37794 .57095 L .37937 .56813 L F
.75 .487 .533 r
.32068 .51763 m .32283 .52062 L .32483 .51812 L F
.796 .552 .57 r
.32483 .51812 m .32283 .52062 L .32649 .52098 L F
.553 .704 .94 r
.31577 .68839 m .31985 .68871 L .3182 .68855 L F
.987 .882 .633 r
.53645 .40796 m .53375 .40879 L .53543 .40692 L F
.53645 .40796 m .53572 .41093 L .53375 .40879 L F
.868 .985 .839 r
.53919 .40498 m .53645 .40796 L .53543 .40692 L F
.95 .63 .388 r
.66689 .34082 m .6682 .34381 L .6683 .34116 L F
.531 .905 .729 r
.46119 .43932 m .46317 .43846 L .46522 .43697 L F
0 0 0 r
.42601 .45309 m .4301 .4507 L .42769 .45183 L F
.872 .811 .786 r
.32507 .55484 m .32314 .55849 L .32052 .55711 L F
.928 .736 .623 r
.32314 .55849 m .32197 .56087 L .32052 .55711 L F
.868 .985 .839 r
.53919 .40498 m .53543 .40692 L .53763 .40457 L F
0 0 0 r
.53763 .40457 m .54167 .40383 L .53919 .40498 L F
.986 .709 .361 r
.39923 .54396 m .39936 .54727 L .40075 .54829 L F
.98 .81 .602 r
.3983 .54985 m .40075 .54829 L .39936 .54727 L F
.3983 .54985 m .39996 .551 L .40075 .54829 L F
.785 .607 .659 r
.31286 .58128 m .31547 .58552 L .31109 .58379 L F
.558 .121 .167 r
.56286 .37199 m .55884 .37361 L .56022 .37095 L F
.56286 .37199 m .5632 .37351 L .55884 .37361 L F
.532 .104 .174 r
.56588 .37316 m .5632 .37351 L .56286 .37199 L F
0 0 0 r
.49587 .403 m .49867 .40008 L .49723 .40196 L F
.30272 .60059 m .30104 .60489 L .30229 .6016 L F
.341 .357 .732 r
.30229 .6016 m .30104 .60489 L .30292 .60468 L F
.675 .661 .829 r
.30078 .60745 m .30292 .60468 L .30104 .60489 L F
.762 .962 .932 r
.29555 .6308 m .29346 .63238 L .29052 .63255 L F
.446 0 .012 r
.44021 .57142 m .44189 .57228 L .44395 .57221 L F
.44021 .57142 m .43832 .57339 L .44189 .57228 L F
.884 .716 .201 r
.58488 .34665 m .58465 .34996 L .58521 .35038 L F
.81 .486 0 r
.58465 .34996 m .58613 .35381 L .58521 .35038 L F
.79 .776 .84 r
.58488 .34665 m .58521 .35038 L .58751 .34804 L F
0 .148 .625 r
.41097 .59437 m .41238 .59544 L .41094 .59407 L F
.664 .344 .422 r
.39319 .54053 m .39449 .538 L .39259 .5371 L F
.39319 .54053 m .39448 .54045 L .39449 .538 L F
.719 .39 .42 r
.39449 .538 m .39448 .54045 L .39726 .54039 L F
.541 .526 .787 r
.26787 .57268 m .26625 .57463 L .26581 .57201 L F
.762 .926 .942 r
.43202 .58476 m .43561 .58329 L .43425 .58144 L F
.615 .752 .943 r
.43561 .58329 m .43687 .5809 L .43425 .58144 L F
.43561 .58329 m .43859 .58296 L .43687 .5809 L F
.323 .369 .755 r
.62853 .35672 m .63089 .35759 L .63092 .35722 L F
.822 .827 .852 r
.63301 .35592 m .62853 .35672 L .63092 .35722 L F
.666 .732 .899 r
.63089 .35759 m .63109 .35723 L .63092 .35722 L F
.822 .827 .852 r
.63113 .35723 m .63092 .35722 L .6311 .35725 L F
.63301 .35592 m .63092 .35722 L .63109 .35723 L F
.63301 .35592 m .63109 .35723 L .63114 .35723 L F
.302 .43 .825 r
.63467 .35332 m .63301 .35592 L .63114 .35723 L F
.846 .782 .789 r
.63467 .35332 m .63105 .3554 L .63295 .35374 L F
.666 .732 .899 r
.63109 .35723 m .63115 .35721 L .63128 .35696 L F
.846 .782 .789 r
.63467 .35332 m .63131 .357 L .63105 .3554 L F
.666 .732 .899 r
.63125 .35692 m .63128 .35696 L .63295 .35374 L F
.63109 .35723 m .63128 .35696 L .63125 .35692 L F
.63109 .35723 m .63125 .35692 L .63092 .35722 L F
.63125 .35692 m .63295 .35374 L .63122 .3567 L F
.63125 .35692 m .63122 .3567 L .63092 .35722 L F
.846 .782 .789 r
.63125 .35692 m .63105 .35729 L .63105 .35664 L F
.666 .732 .899 r
.63115 .35721 m .63331 .35438 L .63295 .35374 L F
.846 .782 .789 r
.63131 .357 m .63127 .35705 L .63125 .35692 L F
.63127 .35705 m .63105 .35729 L .63125 .35692 L F
.666 .732 .899 r
.63092 .35722 m .63122 .3567 L .63105 .3554 L F
.846 .782 .789 r
.63131 .357 m .63125 .35692 L .63105 .3554 L F
.666 .732 .899 r
.63122 .3567 m .63295 .35374 L .63105 .3554 L F
.846 .782 .789 r
.63125 .35692 m .63105 .35664 L .63105 .3554 L F
.666 .732 .899 r
.63089 .35759 m .63214 .35718 L .63109 .35723 L F
.822 .827 .852 r
.63114 .35723 m .63109 .35723 L .63113 .35723 L F
.302 .43 .825 r
.63131 .357 m .63114 .35723 L .63105 .35729 L F
.63467 .35332 m .63114 .35723 L .63131 .357 L F
.6342 .35406 m .63598 .35715 L .63301 .35592 L F
.63467 .35332 m .635 .35431 L .6342 .35406 L F
.635 .35431 m .63598 .35715 L .6342 .35406 L F
.707 .689 .831 r
.63714 .35324 m .63598 .35715 L .63467 .35332 L F
.469 .184 .398 r
.63714 .35324 m .63443 .35641 L .63598 .35715 L F
.63598 .3546 m .63731 .35537 L .63443 .35641 L F
.63714 .35324 m .63728 .355 L .63598 .3546 L F
.63728 .355 m .63731 .35537 L .63598 .3546 L F
.666 .732 .899 r
.63115 .35721 m .63443 .35641 L .63331 .35438 L F
.63214 .35718 m .63443 .35641 L .63109 .35723 L F
.323 .369 .755 r
.62853 .35672 m .63092 .35722 L .63105 .3554 L F
.822 .827 .852 r
.6311 .35725 m .62853 .35672 L .63105 .35729 L F
.861 .501 .368 r
.32921 .64089 m .33281 .64371 L .33332 .64154 L F
.45 .337 .634 r
.33332 .64154 m .33543 .641 L .33537 .63783 L F
.623 .391 .545 r
.33281 .64371 m .33543 .641 L .33332 .64154 L F
.027 0 .008 r
.39006 .56762 m .39242 .56707 L .39328 .56458 L F
.416 .358 .685 r
.39591 .56716 m .39389 .56817 L .39328 .56458 L F
.219 0 .314 r
.39591 .56716 m .39328 .57063 L .39389 .56817 L F
.755 .735 .834 r
.39094 .56834 m .39221 .56712 L .39006 .56762 L F
.39098 .56837 m .39135 .56798 L .39094 .56834 L F
.39135 .56798 m .39221 .56712 L .39094 .56834 L F
.39098 .56837 m .39242 .56707 L .39221 .56712 L F
.802 .734 .788 r
.39049 .56814 m .39135 .56798 L .39242 .56707 L F
.39135 .56798 m .39591 .56716 L .39242 .56707 L F
.39049 .56814 m .39087 .56848 L .39135 .56798 L F
.755 .735 .834 r
.39098 .56837 m .39049 .56814 L .39242 .56707 L F
.38903 .57012 m .39098 .56837 L .39006 .56762 L F
.38903 .57012 m .39049 .56814 L .39098 .56837 L F
.802 .734 .788 r
.39135 .56798 m .39197 .56883 L .39591 .56716 L F
.39197 .56883 m .39328 .57063 L .39395 .56975 L F
.39197 .56883 m .39395 .56975 L .39591 .56716 L F
.39087 .56848 m .39328 .57063 L .39135 .56798 L F
.631 .934 .69 r
.46723 .42519 m .46411 .42795 L .46538 .42623 L F
.429 .835 .643 r
.46937 .42376 m .46723 .42519 L .46538 .42623 L F
.98 .814 .607 r
.40927 .54737 m .41021 .54497 L .40813 .54365 L F
.40927 .54737 m .41021 .54497 L .40813 .54365 L F
.799 .921 .919 r
.43723 .5642 m .44049 .56397 L .43894 .56262 L F
.787 .875 .912 r
.44049 .56397 m .44207 .55988 L .43894 .56262 L F
.44049 .56397 m .44427 .56052 L .44207 .55988 L F
.841 .865 .861 r
.55727 .42709 m .56172 .42555 L .55971 .42347 L F
.787 .752 .821 r
.55971 .42347 m .56172 .42555 L .56351 .42342 L F
0 0 0 r
.46411 .42795 m .45986 .43005 L .46189 .42846 L F
.635 .963 .83 r
.46538 .42623 m .46411 .42795 L .46189 .42846 L F
0 0 .353 r
.27635 .66081 m .27585 .66492 L .27745 .66462 L F
.28 .328 .734 r
.27585 .66492 m .27833 .66716 L .27745 .66462 L F
.69 .323 .347 r
.65991 .33727 m .66241 .33975 L .66416 .33746 L F
.83 .512 .45 r
.66241 .33975 m .66689 .34082 L .66416 .33746 L F
.166 .069 .491 r
.51508 .41608 m .51335 .41437 L .51577 .4136 L F
.51508 .41608 m .51356 .41727 L .51335 .41437 L F
.677 .949 .692 r
.48326 .49816 m .48425 .49643 L .48606 .49541 L F
.988 .886 .555 r
.48326 .49816 m .48145 .49957 L .48425 .49643 L F
.48326 .49816 m .48226 .50051 L .48145 .49957 L F
0 0 0 r
.60659 .34996 m .60225 .3513 L .60395 .35127 L F
.91 .604 .453 r
.3555 .5311 m .35298 .53038 L .35288 .52777 L F
.83 .488 .409 r
.3555 .5311 m .35284 .53314 L .35298 .53038 L F
.3555 .5311 m .35671 .53433 L .35284 .53314 L F
.851 .497 .383 r
.35927 .53466 m .35671 .53433 L .3555 .5311 L F
0 .067 .629 r
.29786 .65132 m .29987 .65408 L .29833 .65026 L F
.716 .797 .915 r
.50338 .40399 m .50503 .40588 L .50731 .4044 L F
.555 .62 .872 r
.2741 .64141 m .27733 .64261 L .27622 .64061 L F
.876 .577 .479 r
.43729 .57803 m .43687 .5809 L .44022 .58094 L F
.89 .813 .766 r
.43687 .5809 m .43859 .58296 L .44022 .58094 L F
.689 .918 .971 r
.50836 .45847 m .5124 .45795 L .51041 .45771 L F
.87 .725 .699 r
.50928 .45577 m .51041 .45771 L .50946 .45538 L F
0 .15 .666 r
.50944 .456 m .50928 .45577 L .50946 .45538 L F
.689 .918 .971 r
.50914 .45837 m .50954 .45842 L .5124 .45795 L F
.87 .725 .699 r
.50928 .45577 m .50836 .45847 L .51041 .45771 L F
0 .15 .666 r
.50934 .45861 m .50931 .45703 L .50944 .456 L F
.50931 .45703 m .50928 .45577 L .50944 .456 L F
.689 .918 .971 r
.50836 .45847 m .50913 .45844 L .50914 .45837 L F
.50913 .45844 m .50954 .45842 L .50914 .45837 L F
.837 .855 .858 r
.45427 .54982 m .45559 .5508 L .4587 .54778 L F
0 .151 .69 r
.57992 .36744 m .5799 .36611 L .57749 .36396 L F
0 0 .179 r
.57992 .36744 m .5802 .3681 L .5799 .36611 L F
.57992 .36744 m .58052 .37037 L .5802 .3681 L F
.592 .807 .982 r
.51722 .43993 m .5194 .44177 L .52176 .44054 L F
.777 .63 .698 r
.32217 .68562 m .3226 .68841 L .31985 .68871 L F
.081 0 0 r
.31985 .68871 m .3226 .68841 L .32074 .6888 L F
.647 .968 .874 r
.32074 .6888 m .3226 .68841 L .32467 .6869 L F
.738 .319 .253 r
.39328 .56458 m .39591 .56716 L .39606 .56446 L F
.39328 .56458 m .39242 .56707 L .39591 .56716 L F
.416 .358 .685 r
.39591 .56716 m .39328 .56458 L .39606 .56446 L F
.392 .165 .446 r
.2834 .52469 m .28549 .52492 L .28585 .52406 L F
.2834 .52469 m .28308 .52703 L .28549 .52492 L F
0 0 0 r
.30178 .68477 m .30152 .68468 L .30305 .68418 L F
.84 .566 .525 r
.35927 .53466 m .3567 .53649 L .35671 .53433 L F
.35927 .53466 m .3593 .53758 L .3567 .53649 L F
.872 .811 .786 r
.32507 .55484 m .32052 .55711 L .32313 .55371 L F
.905 .737 .662 r
.33256 .55006 m .33513 .54841 L .33321 .54757 L F
.33256 .55006 m .33454 .55146 L .33513 .54841 L F
.804 .716 .767 r
.31286 .58128 m .30872 .58114 L .31039 .57872 L F
.924 .846 .748 r
.31286 .58128 m .30942 .58185 L .30872 .58114 L F
.31286 .58128 m .31109 .58379 L .30942 .58185 L F
.927 .903 .781 r
.39985 .5575 m .39785 .55618 L .39979 .55328 L F
0 0 .345 r
.39985 .5575 m .39962 .55672 L .39785 .55618 L F
.39985 .5575 m .40089 .55956 L .39962 .55672 L F
.956 .839 .687 r
.52649 .45492 m .52419 .45646 L .52658 .45276 L F
.52649 .45492 m .52582 .45773 L .52419 .45646 L F
.914 .799 .719 r
.39041 .55762 m .3927 .5585 L .39293 .55664 L F
0 0 .081 r
.27255 .56032 m .27072 .56447 L .27115 .56139 L F
.895 .57 .077 r
.67379 .35927 m .67532 .36331 L .67507 .36132 L F
0 0 0 r
.43634 .45829 m .43444 .45983 L .43554 .45776 L F
.491 .855 .614 r
.43516 .45917 m .43444 .45983 L .43634 .45829 L F
0 0 0 r
.43554 .45776 m .43444 .45983 L .43309 .46106 L F
.43309 .46106 m .43444 .45983 L .43299 .46119 L F
.516 .915 .883 r
.43299 .46119 m .43444 .45983 L .43181 .46112 L F
0 0 0 r
.43181 .46112 m .43444 .45983 L .43254 .46114 L F
.491 .855 .614 r
.43254 .46114 m .43444 .45983 L .43516 .45917 L F
.307 .8 .847 r
.43299 .46119 m .43181 .46112 L .42912 .46183 L F
.57 0 0 r
.39465 .59292 m .39086 .59135 L .39464 .59209 L F
.642 .955 .761 r
.39463 .47041 m .39886 .46754 L .39629 .46823 L F
.723 .432 .486 r
.31149 .51685 m .31668 .51723 L .31637 .51455 L F
.782 .476 .471 r
.31637 .51455 m .31668 .51723 L .32068 .51763 L F
.81 .993 .87 r
.54751 .42784 m .54351 .42996 L .5438 .42696 L F
.184 .222 .668 r
.56862 .39124 m .56611 .38994 L .56875 .38951 L F
.926 .645 .165 r
.56875 .38951 m .56862 .39124 L .5683 .39004 L F
.819 .92 .904 r
.56611 .38994 m .56918 .389 L .56875 .38951 L F
.926 .645 .165 r
.56875 .38951 m .5683 .39004 L .56778 .38809 L F
.819 .92 .904 r
.56918 .389 m .57051 .38859 L .56875 .38951 L F
.431 0 0 r
.5729 .38944 m .57051 .38859 L .57256 .38711 L F
.5729 .38944 m .56875 .38951 L .57051 .38859 L F
.457 .523 .837 r
.28035 .54894 m .28234 .55049 L .27812 .54912 L F
.876 .592 .505 r
.33899 .51134 m .34135 .51446 L .33919 .51375 L F
.866 .562 .471 r
.34135 .51446 m .33897 .51653 L .33919 .51375 L F
.34135 .51446 m .34271 .51789 L .33897 .51653 L F
.328 .187 .531 r
.28473 .53962 m .28264 .54342 L .28433 .54221 L F
.551 .571 .828 r
.40969 .56098 m .41083 .55697 L .41267 .55804 L F
.40969 .56098 m .41238 .56088 L .41083 .55697 L F
.116 0 .35 r
.40969 .56098 m .41074 .56286 L .41238 .56088 L F
.40969 .56098 m .40915 .56494 L .41074 .56286 L F
.918 .895 .79 r
.55177 .43651 m .55553 .43419 L .5541 .43269 L F
.55177 .43651 m .55324 .43787 L .55553 .43419 L F
.892 .877 .813 r
.5541 .43269 m .55553 .43419 L .5581 .43034 L F
.903 .859 .788 r
.45711 .54657 m .46077 .54431 L .45984 .54339 L F
.45711 .54657 m .4587 .54778 L .46077 .54431 L F
.981 .913 .623 r
.46062 .54073 m .45984 .54339 L .46077 .54431 L F
.742 .893 .947 r
.31951 .68669 m .32217 .68562 L .31919 .68552 L F
.777 .63 .698 r
.32217 .68562 m .31985 .68871 L .31919 .68552 L F
.738 .795 .898 r
.30305 .68418 m .30514 .68596 L .30719 .68443 L F
.916 .715 .615 r
.53572 .41093 m .53313 .41216 L .53375 .40879 L F
.53572 .41093 m .53547 .41222 L .53209 .41266 L F
.945 .828 .698 r
.53378 .40797 m .53543 .40692 L .53375 .40879 L F
.332 .227 .582 r
.53375 .40879 m .53435 .41202 L .53383 .40834 L F
.53375 .40879 m .53383 .40834 L .53378 .40797 L F
.916 .715 .615 r
.53313 .41216 m .53209 .41266 L .53375 .40879 L F
.582 .879 .993 r
.35593 .64315 m .35472 .64514 L .35349 .64487 L F
.958 .94 .714 r
.46332 .52433 m .46033 .52717 L .46267 .52344 L F
.46332 .52433 m .46145 .52792 L .46033 .52717 L F
.375 .095 .356 r
.40197 .575 m .40457 .57461 L .40539 .57179 L F
.354 .077 .347 r
.40539 .57179 m .40702 .57377 L .40759 .57072 L F
.40539 .57179 m .40457 .57461 L .40702 .57377 L F
.443 .175 .411 r
.43425 .58144 m .43729 .57803 L .43452 .57784 L F
.713 .876 .475 r
.35649 .65167 m .35489 .65373 L .35425 .65539 L F
0 0 .033 r
.35809 .6471 m .35743 .65022 L .35649 .65167 L F
.606 .833 .448 r
.35743 .65022 m .35489 .65373 L .35649 .65167 L F
.801 .61 .643 r
.32075 .53476 m .31594 .53432 L .31884 .53123 L F
.837 .862 .863 r
.32075 .53476 m .31564 .53681 L .31594 .53432 L F
.96 .815 .656 r
.31236 .64155 m .31181 .64449 L .31051 .64049 L F
.542 0 0 r
.31647 .64451 m .31236 .64155 L .31254 .64202 L F
.548 .779 .984 r
.31754 .64242 m .31647 .64451 L .31254 .64202 L F
.542 0 0 r
.31254 .64202 m .31236 .64155 L .31145 .64133 L F
0 0 .215 r
.31236 .64155 m .3126 .64192 L .31145 .64133 L F
.548 .779 .984 r
.3126 .64192 m .31254 .64202 L .31145 .64133 L F
0 0 .215 r
.31254 .64202 m .31181 .64449 L .31302 .6433 L F
.31236 .64155 m .31216 .64259 L .31254 .64202 L F
.31216 .64259 m .31181 .64449 L .31254 .64202 L F
.31236 .64155 m .31302 .6433 L .3133 .64303 L F
.3126 .64192 m .3133 .64303 L .31145 .64133 L F
.548 .779 .984 r
.31282 .64157 m .3126 .64192 L .31145 .64133 L F
.31754 .64242 m .31254 .64202 L .31282 .64157 L F
.862 .967 .864 r
.41205 .55457 m .41427 .55126 L .41101 .55133 L F
.477 .689 .96 r
.28565 .67888 m .28988 .68078 L .28796 .67754 L F
.34 .458 .834 r
.28796 .67754 m .28988 .68078 L .29202 .68129 L F
.919 .696 .586 r
.3637 .54785 m .36016 .5498 L .36031 .54692 L F
.3637 .54785 m .36276 .55104 L .36016 .5498 L F
.548 .779 .984 r
.31754 .64242 m .31876 .64407 L .31647 .64451 L F
.959 .892 .507 r
.35147 .65737 m .3523 .65689 L .35156 .65535 L F
.701 .938 .636 r
.35359 .65615 m .3523 .65689 L .35133 .65873 L F
0 0 0 r
.35133 .65873 m .3523 .65689 L .35136 .65959 L F
.959 .892 .507 r
.35136 .65959 m .3523 .65689 L .35147 .65737 L F
.701 .938 .636 r
.35425 .65539 m .3523 .65689 L .35359 .65615 L F
.726 .947 .64 r
.35425 .65539 m .35489 .65373 L .3523 .65689 L F
.537 .509 .772 r
.27718 .6719 m .27988 .67257 L .27833 .66716 L F
.81 .625 .652 r
.31884 .53123 m .31594 .53432 L .31439 .53052 L F
.052 .596 .843 r
.60517 .34386 m .60787 .34415 L .60931 .34465 L F
.243 .752 .873 r
.60787 .34415 m .61192 .34402 L .60931 .34465 L F
.756 .789 .88 r
.31754 .62124 m .31773 .62436 L .31438 .62468 L F
.787 .812 .872 r
.31754 .62124 m .32161 .62137 L .31773 .62436 L F
0 0 0 r
.3489 .66209 m .35133 .65873 L .35018 .66044 L F
.35133 .65873 m .35136 .65959 L .35018 .66044 L F
.833 .634 .634 r
.36547 .55445 m .36773 .55816 L .36354 .55744 L F
.831 .634 .637 r
.36773 .55816 m .36314 .56039 L .36354 .55744 L F
.36773 .55816 m .36702 .56094 L .36314 .56039 L F
.648 .781 .32 r
.35153 .6402 m .35081 .64175 L .35226 .63875 L F
.61 .094 0 r
.35077 .64169 m .35153 .6402 L .35422 .64208 L F
.533 .87 .992 r
.34896 .641 m .35081 .64175 L .35153 .6402 L F
.61 .094 0 r
.3488 .64147 m .35153 .6402 L .35077 .64169 L F
.648 .781 .32 r
.35153 .6402 m .35226 .63875 L .35263 .63799 L F
.53 .623 .889 r
.24488 .60447 m .24547 .6005 L .24298 .60084 L F
.505 .347 .601 r
.24748 .60112 m .24748 .60411 L .24488 .60447 L F
.53 .623 .889 r
.24488 .60447 m .24748 .60411 L .24547 .6005 L F
.585 .49 .713 r
.24488 .60447 m .24767 .60638 L .24748 .60411 L F
.859 .956 .871 r
.25903 .55767 m .25784 .55679 L .26033 .55392 L F
.31 .166 .518 r
.25784 .55679 m .25867 .5579 L .25928 .55547 L F
.621 .855 .486 r
.25903 .55767 m .25633 .56125 L .25732 .55974 L F
.859 .956 .871 r
.25903 .55767 m .26027 .55409 L .26224 .55484 L F
.26027 .55409 m .26033 .55392 L .26039 .55395 L F
.26027 .55409 m .26039 .55395 L .26224 .55484 L F
.899 .939 .829 r
.26484 .55143 m .26224 .55484 L .26038 .55394 L F
.26484 .55143 m .26038 .55394 L .26042 .55388 L F
.26484 .55143 m .26034 .55392 L .26036 .5539 L F
.26484 .55143 m .26046 .55385 L .26085 .55351 L F
.26385 .55119 m .26085 .55351 L .26364 .55114 L F
.26484 .55143 m .26085 .55351 L .26385 .55119 L F
.477 .213 .434 r
.25928 .55547 m .26415 .55678 L .26068 .55365 L F
.26034 .55391 m .26068 .55365 L .26054 .55353 L F
.398 .219 .518 r
.26073 .55346 m .26084 .5535 L .261 .55336 L F
.26054 .55353 m .26065 .55356 L .26073 .55346 L F
.899 .939 .829 r
.26046 .55385 m .26059 .55373 L .26364 .55114 L F
.398 .219 .518 r
.26066 .55363 m .26068 .55365 L .2607 .55358 L F
.26068 .55365 m .26415 .55678 L .26073 .5536 L F
.26068 .55365 m .26073 .5536 L .2607 .55358 L F
.899 .939 .829 r
.26059 .55373 m .261 .55336 L .26364 .55114 L F
.26043 .55386 m .26074 .55359 L .26059 .55373 L F
.26074 .55359 m .261 .55336 L .26059 .55373 L F
.359 .105 .386 r
.26364 .55114 m .2609 .55325 L .26128 .55313 L F
.2609 .55325 m .26073 .55346 L .26494 .55195 L F
.899 .939 .829 r
.261 .55336 m .26117 .55322 L .26364 .55114 L F
.359 .105 .386 r
.26364 .55114 m .26128 .55313 L .26494 .55195 L F
.398 .219 .518 r
.26065 .55356 m .26466 .55489 L .26073 .55346 L F
.359 .105 .386 r
.2609 .55325 m .26054 .55353 L .26073 .55346 L F
.398 .219 .518 r
.26054 .55353 m .26066 .55363 L .2607 .55358 L F
.316 .045 .334 r
.26034 .55391 m .26054 .55353 L .26364 .55114 L F
.26033 .55392 m .26054 .55353 L .26034 .55391 L F
0 0 0 r
.26033 .55392 m .25784 .55679 L .25928 .55547 L F
.477 .213 .434 r
.25928 .55547 m .26054 .55353 L .26033 .55392 L F
.26025 .55398 m .26034 .55391 L .26054 .55353 L F
.899 .939 .829 r
.26046 .55385 m .26043 .55386 L .26059 .55373 L F
.26042 .55388 m .26038 .55394 L .26034 .55392 L F
.26036 .5539 m .26034 .55392 L .26033 .55392 L F
.477 .213 .434 r
.25928 .55547 m .26068 .55365 L .26025 .55398 L F
.398 .219 .518 r
.26074 .55359 m .26415 .55678 L .26466 .55489 L F
.2607 .55358 m .26073 .5536 L .26074 .55359 L F
.26073 .5536 m .26415 .55678 L .26074 .55359 L F
.899 .939 .829 r
.26043 .55386 m .26033 .55392 L .26117 .55322 L F
.398 .219 .518 r
.261 .55336 m .26466 .55489 L .26494 .55195 L F
.26084 .5535 m .26466 .55489 L .261 .55336 L F
.31 .166 .518 r
.25867 .5579 m .2595 .559 L .25937 .55695 L F
.25867 .5579 m .25937 .55695 L .25928 .55547 L F
.621 .855 .486 r
.25752 .55947 m .25732 .55974 L .25742 .55959 L F
.25903 .55767 m .25732 .55974 L .25752 .55947 L F
0 0 .495 r
.25633 .56125 m .25776 .56221 L .25742 .55959 L F
.25633 .56125 m .25727 .56431 L .25776 .56221 L F
.879 .638 .57 r
.32649 .52098 m .32611 .52402 L .32855 .52465 L F
.885 .645 .571 r
.32611 .52402 m .32826 .52748 L .32855 .52465 L F
0 0 .047 r
.58473 .38777 m .58446 .39034 L .58516 .38821 L F
.238 0 0 r
.61657 .39381 m .61899 .39322 L .62007 .39243 L F
.486 .583 .877 r
.61657 .39381 m .61962 .39517 L .61899 .39322 L F
.685 .144 0 r
.38178 .52184 m .38101 .52274 L .38348 .52352 L F
.814 .336 0 r
.41501 .5645 m .41654 .56714 L .41789 .56773 L F
.403 .724 .989 r
.41866 .56593 m .41789 .56773 L .41654 .56714 L F
.841 .745 .758 r
.42768 .56468 m .42612 .56656 L .42336 .56427 L F
.762 .491 .523 r
.42591 .56624 m .42463 .5669 L .42301 .56585 L F
.403 .724 .989 r
.41859 .56608 m .42213 .56772 L .41789 .56773 L F
.41909 .56615 m .42213 .56772 L .41859 .56608 L F
.685 .793 .932 r
.42301 .56585 m .42213 .56772 L .41866 .56593 L F
.748 .851 .41 r
.42154 .56851 m .42092 .57054 L .42301 .56585 L F
.762 .491 .523 r
.42463 .5669 m .42154 .56851 L .42258 .56662 L F
.42463 .5669 m .42258 .56662 L .42301 .56585 L F
.403 .724 .989 r
.41866 .56593 m .41909 .56615 L .41859 .56608 L F
0 0 0 r
.29875 .64195 m .29913 .64283 L .29858 .64456 L F
.29875 .64195 m .30133 .64061 L .29913 .64283 L F
.792 .712 .777 r
.30781 .62451 m .30946 .62824 L .30532 .6278 L F
.556 .573 .826 r
.31031 .62374 m .30946 .62824 L .30781 .62451 L F
.31031 .62374 m .31195 .62763 L .30946 .62824 L F
.869 .945 .863 r
.58873 .40766 m .59005 .4033 L .5874 .40583 L F
.58873 .40766 m .59133 .40481 L .59005 .4033 L F
.959 .647 .233 r
.5876 .4091 m .58873 .40766 L .5874 .40583 L F
.5876 .4091 m .58918 .41059 L .58873 .40766 L F
.933 .882 .761 r
.67443 .36582 m .67596 .36719 L .67696 .36483 L F
.885 .929 .845 r
.67228 .3687 m .67596 .36719 L .67443 .36582 L F
.67228 .3687 m .67361 .36974 L .67596 .36719 L F
.668 .225 0 r
.60051 .36073 m .60273 .36388 L .60011 .36507 L F
.071 .141 .631 r
.60138 .36604 m .60068 .36724 L .60011 .36507 L F
.955 .616 .234 r
.60095 .36496 m .60201 .36707 L .60138 .36604 L F
.60201 .36707 m .60307 .36918 L .60138 .36604 L F
.393 .083 .316 r
.60064 .36483 m .60138 .36604 L .60011 .36507 L F
.60273 .36388 m .60138 .36604 L .60064 .36483 L F
0 0 0 r
.43725 .45644 m .43554 .45776 L .43876 .45501 L F
.43951 .45537 m .43876 .45501 L .44097 .45366 L F
.43951 .45537 m .43725 .45644 L .43876 .45501 L F
.936 .892 .761 r
.52582 .45773 m .52201 .46002 L .52419 .45646 L F
.52582 .45773 m .52358 .46144 L .52201 .46002 L F
.974 .742 .524 r
.54768 .40456 m .54737 .40345 L .54892 .4019 L F
.216 0 0 r
.54892 .4019 m .55233 .4018 L .55136 .40071 L F
.54892 .4019 m .54737 .40345 L .55233 .4018 L F
.308 0 .055 r
.43266 .57151 m .43155 .57345 L .42891 .57397 L F
.497 .143 .295 r
.40722 .47144 m .40964 .47297 L .40731 .47288 L F
.529 .105 .18 r
.40972 .47151 m .40964 .47297 L .40722 .47144 L F
.239 .023 .371 r
.51828 .40997 m .51577 .4136 L .51611 .41116 L F
.232 0 .097 r
.40859 .46145 m .40537 .46394 L .40798 .46296 L F
.37 0 .153 r
.40798 .46296 m .41066 .4625 L .40859 .46145 L F
.369 0 .159 r
.40859 .46145 m .41066 .4625 L .41128 .46095 L F
.669 .524 .678 r
.37284 .51469 m .3749 .51451 L .37556 .51192 L F
.18 0 0 r
.3705 .51645 m .3749 .51451 L .37284 .51469 L F
.837 .855 .858 r
.45427 .54982 m .4587 .54778 L .45711 .54657 L F
.091 .649 .743 r
.63338 .39296 m .62923 .39324 L .63047 .39359 L F
.899 .809 .75 r
.55691 .42976 m .5581 .43034 L .55727 .42709 L F
.892 .877 .813 r
.5541 .43269 m .5581 .43034 L .55691 .42976 L F
.846 .837 .837 r
.54084 .39519 m .53606 .39647 L .53861 .39331 L F
0 0 0 r
.54084 .39519 m .53895 .39593 L .53606 .39647 L F
.47 0 0 r
.53895 .39593 m .54084 .39519 L .53861 .39331 L F
0 0 0 r
.35263 .63799 m .35508 .63384 L .35484 .63676 L F
.794 .727 .79 r
.35484 .63676 m .35153 .6402 L .35263 .63799 L F
.636 .659 .856 r
.3459 .5005 m .34679 .50046 L .34567 .49695 L F
.225 .705 .935 r
.61192 .34402 m .61487 .34402 L .61623 .34474 L F
.434 .835 .978 r
.61487 .34402 m .61905 .34409 L .61623 .34474 L F
.165 .242 .698 r
.57398 .36559 m .57249 .36811 L .57154 .36363 L F
.434 .261 .546 r
.57473 .36694 m .57249 .36811 L .57398 .36559 L F
.57473 .36694 m .57271 .3704 L .57249 .36811 L F
.454 .235 .49 r
.42768 .56468 m .42765 .56747 L .43036 .56427 L F
.773 .974 .695 r
.48606 .49541 m .48704 .49304 L .48806 .49384 L F
.48606 .49541 m .48425 .49643 L .48704 .49304 L F
.98 .722 .466 r
.35776 .64098 m .35593 .64315 L .35579 .63995 L F
.35776 .64098 m .3576 .64398 L .35593 .64315 L F
.342 .742 .983 r
.35579 .63995 m .35856 .63981 L .35776 .64098 L F
0 0 .219 r
.35776 .64098 m .35817 .64313 L .3576 .64398 L F
.35776 .64098 m .35856 .63981 L .35817 .64313 L F
.646 .91 .603 r
.4111 .47505 m .4086 .47774 L .40976 .476 L F
.217 0 0 r
.40976 .476 m .41273 .47539 L .4111 .47505 L F
.15 .254 .717 r
.57556 .35016 m .5766 .35429 L .57804 .35205 L F
.068 .141 .632 r
.5766 .35429 m .57867 .35624 L .57804 .35205 L F
.056 .139 .635 r
.57768 .35704 m .57867 .35624 L .5766 .35429 L F
.766 .394 .351 r
.36538 .57183 m .36161 .57329 L .36234 .5705 L F
.36538 .57183 m .36579 .57412 L .36161 .57329 L F
0 0 0 r
.43634 .45829 m .43554 .45776 L .43725 .45644 L F
.885 .878 .823 r
.58127 .37442 m .5776 .37852 L .57685 .37713 L F
.58127 .37442 m .57685 .37713 L .5796 .37557 L F
0 0 .276 r
.58127 .37442 m .5813 .3727 L .58052 .37037 L F
0 0 0 r
.58127 .37442 m .58249 .37469 L .5813 .3727 L F
.58127 .37442 m .5796 .37557 L .58249 .37469 L F
.939 .836 .715 r
.29315 .53797 m .29059 .53759 L .2917 .53627 L F
.349 .643 .964 r
.29383 .53617 m .29315 .53797 L .2917 .53627 L F
.626 .926 .973 r
.29383 .53617 m .29059 .53759 L .29315 .53797 L F
.941 .801 .676 r
.54467 .45338 m .54305 .4571 L .54583 .45702 L F
.91 .794 .72 r
.54215 .45918 m .54583 .45702 L .54305 .4571 L F
.54215 .45918 m .54388 .46078 L .54583 .45702 L F
.369 .144 .436 r
.26756 .54806 m .26989 .54733 L .27027 .54463 L F
.362 .129 .42 r
.26756 .54806 m .2672 .55071 L .26989 .54733 L F
.625 .905 .607 r
.31189 .59192 m .30876 .59519 L .3107 .59283 L F
.338 .368 .746 r
.30876 .59519 m .31134 .59711 L .3107 .59283 L F
.454 .365 .665 r
.30876 .59519 m .30948 .59795 L .31134 .59711 L F
.969 .742 .54 r
.41267 .55804 m .41238 .56088 L .41083 .55697 L F
.947 .881 .736 r
.55205 .44023 m .55324 .43787 L .55177 .43651 L F
.034 .13 .634 r
.57768 .35704 m .57837 .36103 L .5796 .35884 L F
0 0 0 r
.57837 .36103 m .57899 .36151 L .5796 .35884 L F
.57837 .36103 m .57749 .36396 L .57899 .36151 L F
.788 .612 .662 r
.50459 .45697 m .50154 .45979 L .50122 .45829 L F
.89 .554 .405 r
.33899 .51134 m .33684 .51271 L .33684 .51004 L F
.33899 .51134 m .33919 .51375 L .33684 .51271 L F
0 .176 .664 r
.3749 .51451 m .37776 .51662 L .3788 .51784 L F
.982 .91 .637 r
.37776 .51662 m .37658 .51938 L .3788 .51784 L F
.71 .519 .628 r
.31535 .52497 m .31037 .5274 L .31065 .52436 L F
.31535 .52497 m .31471 .52761 L .31037 .5274 L F
.847 .759 .765 r
.51807 .46792 m .51371 .46997 L .51642 .46647 L F
.51807 .46792 m .51561 .47169 L .51371 .46997 L F
.915 .957 .801 r
.67077 .3736 m .66736 .37619 L .66752 .37693 L F
.649 .857 .979 r
.62982 .36021 m .63089 .35759 L .62853 .35672 L F
.62982 .36021 m .63227 .35921 L .63089 .35759 L F
0 .169 .707 r
.5588 .3391 m .56019 .34026 L .55995 .34153 L F
.616 .557 .766 r
.55719 .33794 m .55986 .34005 L .56019 .34026 L F
.581 .928 .952 r
.55995 .34153 m .56019 .34026 L .56133 .34095 L F
.581 .428 .638 r
.56282 .34031 m .5601 .34389 L .55995 .34153 L F
.581 .928 .952 r
.55995 .34153 m .56019 .34026 L .56282 .34031 L F
.616 .557 .766 r
.55986 .34005 m .56136 .34124 L .56019 .34026 L F
.581 .928 .952 r
.56133 .34095 m .56019 .34026 L .56282 .34031 L F
.933 .882 .761 r
.67443 .36582 m .67696 .36483 L .67532 .36331 L F
.096 .313 .79 r
.27356 .65674 m .27397 .65859 L .27488 .65687 L F
.017 .205 .715 r
.27397 .65859 m .27635 .66081 L .27488 .65687 L F
.923 .748 .646 r
.52215 .37993 m .52362 .38397 L .52421 .38123 L F
.814 .919 .908 r
.51584 .48846 m .51797 .48637 L .51636 .48538 L F
.841 .94 .889 r
.51447 .4874 m .51584 .48846 L .51636 .48538 L F
.879 .629 .556 r
.36088 .54132 m .35817 .54333 L .35867 .54035 L F
.36088 .54132 m .36059 .54413 L .35817 .54333 L F
.929 .789 .685 r
.33044 .56282 m .33327 .56143 L .33127 .56005 L F
.33044 .56282 m .33264 .56358 L .33327 .56143 L F
.761 .687 .78 r
.3339 .61489 m .33561 .61854 L .33112 .61804 L F
.791 .745 .811 r
.33641 .61377 m .33561 .61854 L .3339 .61489 L F
.746 .87 .447 r
.52051 .3871 m .51931 .38875 L .51887 .39037 L F
.024 .347 .825 r
.51931 .38875 m .52069 .3909 L .51887 .39037 L F
.708 .922 .965 r
.37136 .57197 m .37037 .57468 L .37511 .57354 L F
.714 .505 .606 r
.3737 .56922 m .37511 .57354 L .37591 .56999 L F
.3737 .56922 m .37136 .57197 L .37511 .57354 L F
.418 .691 .976 r
.30854 .54998 m .30969 .55166 L .31045 .54955 L F
.88 .736 .699 r
.31202 .55352 m .31045 .54955 L .30969 .55166 L F
.719 .605 .728 r
.30138 .6116 m .3052 .60866 L .30078 .60745 L F
.931 .952 .777 r
.67228 .3687 m .67077 .3736 L .67361 .36974 L F
.916 .976 .702 r
.58663 .38431 m .58429 .3859 L .58569 .3835 L F
0 0 0 r
.58794 .37866 m .58663 .38431 L .58724 .38174 L F
.829 .986 .873 r
.58724 .38174 m .58663 .38431 L .58569 .3835 L F
.149 0 0 r
.38497 .47361 m .38941 .47136 L .38636 .47398 L F
.345 .175 .502 r
.25742 .55959 m .25784 .55679 L .25903 .55767 L F
.877 .685 .64 r
.38067 .47672 m .37776 .47985 L .37757 .47849 L F
.765 .8 .881 r
.55971 .42347 m .56351 .42342 L .56328 .42035 L F
.699 .936 .964 r
.24855 .59822 m .24727 .59825 L .24929 .59705 L F
.24855 .59822 m .24748 .60112 L .24727 .59825 L F
.411 .232 .526 r
.60307 .36918 m .60068 .36724 L .60138 .36604 L F
.60307 .36918 m .60053 .37023 L .60068 .36724 L F
.375 .801 .97 r
.63774 .34655 m .63706 .34603 L .63391 .34641 L F
.353 .787 .967 r
.64093 .34636 m .63706 .34603 L .63774 .34655 L F
.627 .962 .849 r
.47353 .4308 m .47812 .4286 L .47605 .4289 L F
.464 .889 .829 r
.47605 .4289 m .47812 .4286 L .4807 .42731 L F
.992 .763 .391 r
.54265 .38209 m .54367 .3835 L .54384 .38101 L F
.579 .589 .827 r
.56256 .35439 m .56439 .35016 L .56139 .35058 L F
.56256 .35439 m .56634 .35351 L .56439 .35016 L F
.408 .19 .468 r
.56276 .35699 m .56634 .35351 L .56256 .35439 L F
.001 .41 .854 r
.25033 .59401 m .25087 .59335 L .24984 .59334 L F
.509 .267 .484 r
.25313 .59521 m .25033 .59401 L .25087 .59335 L F
.25313 .59521 m .24929 .59705 L .25033 .59401 L F
.001 .41 .854 r
.24984 .59334 m .25087 .59335 L .25033 .59401 L F
.675 .661 .829 r
.30078 .60745 m .3052 .60866 L .30292 .60468 L F
.699 .671 .819 r
.30292 .60468 m .3052 .60866 L .30707 .60645 L F
.419 .826 .977 r
.62752 .38323 m .63041 .38281 L .63136 .38352 L F
.445 .876 .793 r
.63397 .38184 m .63136 .38352 L .63041 .38281 L F
.497 .852 .992 r
.63221 .38107 m .63397 .38184 L .63241 .38227 L F
.63116 .38209 m .63241 .38227 L .63041 .38281 L F
.63221 .38107 m .63241 .38227 L .63116 .38209 L F
.486 .827 .998 r
.62927 .38176 m .63041 .38281 L .62752 .38323 L F
.62927 .38176 m .62752 .38323 L .62859 .38457 L F
.497 .852 .992 r
.63221 .38107 m .63041 .38281 L .62927 .38176 L F
.824 .821 .846 r
.62859 .38457 m .625 .3855 L .62236 .38519 L F
.678 .956 .717 r
.62859 .38457 m .62236 .38519 L .625 .3855 L F
.62859 .38457 m .62385 .38853 L .62556 .38635 L F
.733 .954 .659 r
.62536 .38754 m .62263 .39081 L .62385 .38853 L F
.603 .526 .741 r
.62536 .38754 m .62772 .38622 L .62859 .38457 L F
.62859 .38457 m .62772 .38622 L .62536 .38754 L F
.116 0 0 r
.62385 .38853 m .62567 .38901 L .62576 .38661 L F
.824 .821 .846 r
.62859 .38457 m .62559 .38633 L .62594 .38645 L F
.62449 .38498 m .62236 .38519 L .62552 .3863 L F
.337 .5 .872 r
.62236 .38519 m .62578 .38606 L .62594 .38645 L F
.116 0 0 r
.62556 .38635 m .62576 .38661 L .62578 .38606 L F
.62385 .38853 m .62576 .38661 L .62556 .38635 L F
.824 .821 .846 r
.62859 .38457 m .62449 .38498 L .62559 .38633 L F
.62449 .38498 m .62552 .3863 L .62559 .38633 L F
.678 .956 .717 r
.62859 .38457 m .62556 .38635 L .62578 .38606 L F
.62859 .38457 m .62578 .38606 L .62236 .38519 L F
.913 .966 .655 r
.62927 .38176 m .62859 .38457 L .62594 .38645 L F
.62927 .38176 m .62594 .38645 L .62739 .382 L F
.451 .215 .464 r
.63034 .38255 m .63221 .38107 L .62927 .38176 L F
0 .268 .741 r
.63146 .38305 m .63034 .38255 L .62927 .38176 L F
.63146 .38305 m .62941 .38184 L .62739 .382 L F
.62941 .38184 m .62927 .38176 L .62905 .38178 L F
.62941 .38184 m .62905 .38178 L .62739 .382 L F
.641 .111 0 r
.63034 .38255 m .63089 .38291 L .63219 .38223 L F
.445 .876 .793 r
.6333 .38227 m .63495 .38187 L .63136 .38352 L F
.641 .111 0 r
.63089 .38291 m .6323 .38382 L .63221 .38256 L F
.63089 .38291 m .63221 .38256 L .63219 .38223 L F
.445 .876 .793 r
.63397 .38184 m .6348 .38187 L .6333 .38227 L F
.6348 .38187 m .63495 .38187 L .6333 .38227 L F
.104 0 0 r
.59943 .3991 m .60324 .3969 L .602 .39905 L F
.084 0 0 r
.602 .39905 m .59912 .40012 L .59943 .3991 L F
.663 .804 .951 r
.60324 .3969 m .59869 .39652 L .60176 .39557 L F
.555 .797 .989 r
.60455 .39458 m .60324 .3969 L .60176 .39557 L F
.60455 .39458 m .606 .39613 L .60324 .3969 L F
0 0 0 r
.60324 .3969 m .6044 .39683 L .602 .39905 L F
.60324 .3969 m .606 .39613 L .6044 .39683 L F
.625 .753 .939 r
.30548 .55292 m .30675 .55485 L .30897 .55222 L F
.512 .034 .057 r
.64911 .33867 m .6518 .33905 L .65297 .33731 L F
.479 0 .039 r
.65297 .33731 m .65589 .33855 L .65583 .3374 L F
.65297 .33731 m .6518 .33905 L .65589 .33855 L F
.661 .607 .783 r
.58296 .41739 m .58483 .41173 L .5823 .41441 L F
.815 .622 .641 r
.37522 .47632 m .38067 .47672 L .38015 .47372 L F
.452 .374 .679 r
.38015 .47372 m .38182 .47575 L .38233 .47352 L F
.38015 .47372 m .38067 .47672 L .38182 .47575 L F
.973 .782 .587 r
.38046 .58478 m .37822 .586 L .37913 .58469 L F
.099 0 0 r
.38046 .58478 m .3794 .58471 L .37574 .58429 L F
.493 .581 .872 r
.37574 .58429 m .3794 .58471 L .37652 .58057 L F
.973 .782 .587 r
.38046 .58478 m .3794 .58471 L .38008 .5833 L F
.493 .581 .872 r
.3794 .58471 m .37975 .58475 L .37949 .58441 L F
.3794 .58471 m .37949 .58441 L .37652 .58057 L F
.973 .782 .587 r
.3794 .58471 m .37913 .58469 L .37962 .58396 L F
.684 .65 .81 r
.37652 .58057 m .37949 .58441 L .38008 .5833 L F
.973 .782 .587 r
.3794 .58471 m .37949 .58441 L .38008 .5833 L F
.684 .65 .81 r
.37949 .58441 m .37975 .58475 L .38008 .5833 L F
.973 .782 .587 r
.37949 .58441 m .37962 .58396 L .38008 .5833 L F
.099 0 0 r
.38046 .58478 m .37975 .58475 L .3794 .58471 L F
.934 .918 .539 r
.38008 .5833 m .37975 .58475 L .38046 .58478 L F
.931 .554 .256 r
.41238 .56088 m .4133 .56422 L .41501 .5645 L F
.747 .628 .727 r
.4133 .56422 m .41654 .56714 L .41501 .5645 L F
.153 0 .358 r
.27027 .54463 m .26989 .54733 L .27197 .54357 L F
.867 .945 .866 r
.59005 .4033 m .59133 .40481 L .59384 .40158 L F
.597 .074 0 r
.3107 .59283 m .31397 .59348 L .31189 .59192 L F
.435 .202 .46 r
.31189 .59192 m .31397 .59348 L .31424 .59081 L F
0 0 0 r
.3309 .65409 m .32885 .65473 L .33165 .65249 L F
.064 0 .185 r
.32825 .65736 m .32885 .65473 L .3309 .65409 L F
.427 .147 .384 r
.26625 .57463 m .26436 .57835 L .26297 .57794 L F
.541 .526 .787 r
.26787 .57268 m .26872 .57403 L .26625 .57463 L F
0 0 0 r
.267 .57575 m .26625 .57463 L .26872 .57403 L F
.267 .57575 m .26436 .57835 L .26625 .57463 L F
.927 .941 .591 r
.31089 .6444 m .31181 .64449 L .31047 .64715 L F
.506 .909 .824 r
.3133 .64303 m .31181 .64449 L .31089 .6444 L F
.587 .921 .966 r
.62947 .34279 m .63117 .34086 L .63243 .34184 L F
.62947 .34279 m .62839 .34216 L .63117 .34086 L F
.18 0 0 r
.3705 .51645 m .37308 .51605 L .3749 .51451 L F
.488 0 0 r
.37564 .5154 m .3749 .51451 L .37308 .51605 L F
.37564 .5154 m .37776 .51662 L .3749 .51451 L F
0 0 .366 r
.24884 .60665 m .24912 .60768 L .24832 .60593 L F
.776 .483 .491 r
.2473 .60792 m .24915 .60708 L .24884 .60665 L F
.443 .572 .889 r
.25346 .60946 m .2513 .61026 L .24884 .60665 L F
.25346 .60946 m .24884 .60665 L .25196 .60581 L F
.776 .483 .491 r
.24915 .60708 m .25196 .60581 L .24884 .60665 L F
0 0 .366 r
.24884 .60665 m .24832 .60593 L .24748 .60411 L F
0 0 .536 r
.24884 .60665 m .2513 .61026 L .24912 .60768 L F
.842 .984 .867 r
.45544 .534 m .45753 .53044 L .45867 .53124 L F
.879 .975 .839 r
.45867 .53124 m .46033 .52717 L .46145 .52792 L F
.45867 .53124 m .45753 .53044 L .46033 .52717 L F
.813 .572 .575 r
.32267 .52333 m .32649 .52098 L .32283 .52062 L F
.32267 .52333 m .32611 .52402 L .32649 .52098 L F
.767 .811 .888 r
.29825 .53054 m .29425 .53106 L .29672 .52852 L F
.132 0 0 r
.29825 .53054 m .29736 .53095 L .29425 .53106 L F
.105 .454 .885 r
.29672 .52852 m .29874 .5292 L .29825 .53054 L F
.701 .954 .684 r
.29874 .5292 m .29736 .53095 L .29825 .53054 L F
.632 .933 .967 r
.50722 .42267 m .50948 .42057 L .50573 .41952 L F
.50722 .42267 m .51137 .42106 L .50948 .42057 L F
.707 .79 .916 r
.33792 .63942 m .34227 .63782 L .33831 .63797 L F
.785 .587 .632 r
.3044 .65172 m .30433 .65472 L .29987 .65408 L F
.485 .876 .966 r
.62296 .34373 m .61905 .34409 L .62173 .3432 L F
.481 .856 .984 r
.62173 .3432 m .6257 .34316 L .62296 .34373 L F
.763 .962 .931 r
.52594 .47887 m .53037 .47765 L .52942 .47679 L F
.869 .901 .853 r
.53243 .47674 m .52942 .47679 L .53037 .47765 L F
.587 .875 .563 r
.56837 .37291 m .56728 .37413 L .5699 .37135 L F
.668 .567 .732 r
.56728 .37413 m .57007 .37445 L .5699 .37135 L F
.617 .672 .88 r
.56837 .37291 m .57007 .37445 L .56728 .37413 L F
0 0 .032 r
.58794 .37866 m .58808 .3795 L .58853 .377 L F
0 0 0 r
.58794 .37866 m .58724 .38174 L .58808 .3795 L F
.551 .932 .866 r
.51119 .39952 m .51027 .40092 L .51222 .39939 L F
.51119 .39952 m .50899 .40101 L .51027 .40092 L F
.133 .48 .898 r
.51119 .39952 m .51027 .40092 L .50899 .40101 L F
.51119 .39952 m .51439 .40255 L .51027 .40092 L F
.061 .212 .708 r
.40863 .47777 m .41072 .47942 L .41049 .47861 L F
.843 .732 .741 r
.40976 .476 m .41072 .47942 L .41273 .47539 L F
0 0 .071 r
.41273 .47539 m .41072 .47942 L .40976 .476 L F
.41273 .47539 m .41242 .47799 L .41072 .47942 L F
.482 .513 .813 r
.40976 .476 m .41072 .47942 L .41117 .47883 L F
.93 .784 .679 r
.41085 .47877 m .40695 .47819 L .40695 .47807 L F
.41117 .47883 m .41088 .47878 L .41085 .47877 L F
.41088 .47878 m .40695 .47819 L .41085 .47877 L F
.061 .212 .708 r
.4086 .47774 m .40863 .47777 L .40976 .476 L F
.40863 .47777 m .41049 .47861 L .40976 .476 L F
.745 .246 0 r
.42777 .57794 m .43051 .58076 L .43049 .57795 L F
.875 .481 .284 r
.44207 .55988 m .44427 .56052 L .44327 .55869 L F
.964 .909 .55 r
.44327 .55869 m .44303 .55734 L .44207 .55988 L F
.875 .481 .284 r
.44207 .55988 m .44427 .56052 L .44327 .55869 L F
.245 .117 .501 r
.32914 .68275 m .32778 .68154 L .32989 .68089 L F
.213 .118 .524 r
.32914 .68275 m .32805 .68485 L .32778 .68154 L F
0 0 0 r
.3489 .66209 m .34912 .66368 L .34735 .66364 L F
.693 .423 .51 r
.30606 .60097 m .30892 .60033 L .30631 .5979 L F
.66 .431 .562 r
.30631 .5979 m .30892 .60033 L .30948 .59795 L F
.915 .957 .801 r
.67077 .3736 m .66982 .37264 L .66736 .37619 L F
.931 .952 .777 r
.67228 .3687 m .66982 .37264 L .67077 .3736 L F
.967 .899 .704 r
.34731 .61693 m .34577 .61968 L .34484 .61722 L F
.889 .736 .686 r
.34536 .61976 m .34866 .62207 L .34731 .61693 L F
.889 .559 .062 r
.34793 .6227 m .34866 .62207 L .34536 .61976 L F
.34793 .6227 m .34879 .62373 L .34866 .62207 L F
.835 .911 .889 r
.49782 .50432 m .4995 .50003 L .49613 .503 L F
.49782 .50432 m .50111 .50131 L .4995 .50003 L F
.696 .273 0 r
.56837 .35561 m .5685 .35544 L .56638 .354 L F
.56837 .35561 m .56949 .35717 L .5685 .35544 L F
.791 .351 .203 r
.61762 .35029 m .61589 .35038 L .61473 .34982 L F
.633 .101 0 r
.61762 .35029 m .61629 .35144 L .61589 .35038 L F
.434 0 0 r
.62035 .3502 m .61629 .35144 L .61762 .35029 L F
0 0 0 r
.62007 .39243 m .61899 .39322 L .62263 .39081 L F
.898 .985 .785 r
.25694 .56799 m .25415 .57042 L .25669 .5672 L F
.786 .496 .496 r
.31668 .51723 m .31831 .52004 L .32068 .51763 L F
.781 .488 .491 r
.32068 .51763 m .31831 .52004 L .32283 .52062 L F
.675 .181 .069 r
.53209 .41266 m .53547 .41222 L .53714 .41485 L F
.903 .629 .513 r
.33019 .53373 m .33019 .53687 L .33387 .53743 L F
.876 .673 .625 r
.32948 .53963 m .33387 .53743 L .33019 .53687 L F
.32948 .53963 m .33206 .54073 L .33387 .53743 L F
0 0 .278 r
.44601 .54358 m .44632 .54172 L .44624 .54076 L F
.919 .922 .8 r
.44328 .54678 m .44632 .54172 L .44601 .54358 L F
.892 .749 .697 r
.67289 .34928 m .67626 .35074 L .67659 .34784 L F
.941 .603 .357 r
.67289 .34928 m .67604 .35332 L .67626 .35074 L F
.892 .749 .697 r
.67289 .34928 m .67659 .34784 L .67235 .34692 L F
.497 .305 .55 r
.30844 .54373 m .31105 .54418 L .31066 .54123 L F
.454 0 0 r
.307 .54425 m .31105 .54418 L .30844 .54373 L F
.866 .684 .655 r
.36185 .55367 m .36547 .55445 L .36354 .55744 L F
.365 .826 .742 r
.29289 .65762 m .29143 .65489 L .29038 .65755 L F
0 0 0 r
.29038 .65755 m .29143 .65489 L .29198 .6537 L F
.709 .346 .359 r
.3837 .55954 m .38779 .55788 L .38381 .55724 L F
.3837 .55954 m .38609 .56024 L .38779 .55788 L F
.775 .635 .707 r
.38609 .56024 m .39041 .55762 L .38779 .55788 L F
0 0 0 r
.44223 .44085 m .4385 .444 L .44097 .44306 L F
.001 0 0 r
.44223 .44085 m .44333 .44178 L .44475 .43995 L F
.44223 .44085 m .44097 .44306 L .44333 .44178 L F
.869 .901 .853 r
.53243 .47674 m .53214 .47351 L .52942 .47679 L F
.897 .916 .827 r
.53243 .47674 m .53356 .47472 L .53214 .47351 L F
.572 .102 .101 r
.65583 .3374 m .65856 .33901 L .65991 .33727 L F
.732 .291 .205 r
.65856 .33901 m .66241 .33975 L .65991 .33727 L F
.416 .853 .742 r
.51402 .39812 m .51222 .39939 L .51271 .40011 L F
.51402 .39812 m .51119 .39952 L .51222 .39939 L F
.336 0 0 r
.63741 .39348 m .63614 .39361 L .63338 .39296 L F
.371 .821 .94 r
.64012 .39342 m .63614 .39361 L .63741 .39348 L F
.71 .529 .642 r
.59059 .37076 m .58802 .37384 L .58749 .37065 L F
0 0 0 r
.44756 .45023 m .45046 .44738 L .44931 .44928 L F
.44931 .44928 m .44563 .45173 L .44756 .45023 L F
.762 .962 .932 r
.29555 .6308 m .29052 .63255 L .29401 .63057 L F
.678 .975 .901 r
.29847 .62876 m .29555 .6308 L .29599 .62916 L F
.665 .968 .916 r
.29599 .62916 m .29555 .6308 L .29401 .63057 L F
.847 .662 .652 r
.38538 .53022 m .38873 .53112 L .38682 .52703 L F
.889 .514 .322 r
.38538 .53022 m .38897 .53393 L .38873 .53112 L F
.922 .784 .691 r
.33256 .55006 m .33351 .55421 L .33454 .55146 L F
.876 .802 .773 r
.46506 .53623 m .4694 .53414 L .46795 .53312 L F
.46506 .53623 m .46717 .5382 L .4694 .53414 L F
.83 .934 .897 r
.46795 .53312 m .4694 .53414 L .47255 .53128 L F
0 0 0 r
.28989 .67488 m .28796 .67754 L .28985 .67539 L F
.34 .458 .834 r
.28796 .67754 m .29202 .68129 L .28985 .67539 L F
.011 .405 .854 r
.28989 .67488 m .28985 .67539 L .29338 .67678 L F
.037 .132 .635 r
.28985 .67539 m .29316 .67927 L .29338 .67678 L F
.28985 .67539 m .29202 .68129 L .29316 .67927 L F
0 0 0 r
.32156 .65458 m .31801 .65802 L .32088 .65743 L F
0 0 .05 r
.32247 .65597 m .32156 .65458 L .32088 .65743 L F
.32247 .65597 m .32356 .65376 L .32156 .65458 L F
.947 .881 .736 r
.55205 .44023 m .55177 .43651 L .55062 .43901 L F
.914 .871 .782 r
.54833 .44182 m .55205 .44023 L .55062 .43901 L F
.54833 .44182 m .55111 .4418 L .55205 .44023 L F
.862 .681 .15 r
.58488 .39461 m .58483 .39725 L .58452 .39553 L F
0 0 .471 r
.58446 .39034 m .58488 .39461 L .58566 .39222 L F
.683 .746 .246 r
.58488 .39461 m .58452 .39553 L .58566 .39222 L F
.933 .772 .658 r
.32887 .56653 m .33264 .56358 L .33044 .56282 L F
.32887 .56653 m .33124 .56798 L .33264 .56358 L F
.405 .838 .949 r
.28865 .63405 m .28618 .63467 L .28433 .63428 L F
.842 .984 .867 r
.45544 .534 m .45441 .53357 L .45753 .53044 L F
.821 .739 .774 r
.32001 .62034 m .32161 .62137 L .31754 .62124 L F
.761 .755 .847 r
.32424 .61856 m .32161 .62137 L .32001 .62034 L F
.746 .994 .835 r
.5283 .43826 m .52908 .43823 L .5257 .44098 L F
.424 .315 .626 r
.5257 .44098 m .52855 .44294 L .5283 .43826 L F
.443 .175 .411 r
.43425 .58144 m .43687 .5809 L .43729 .57803 L F
.485 .527 .825 r
.43729 .57803 m .43832 .57339 L .43578 .57396 L F
.43729 .57803 m .44005 .57746 L .43832 .57339 L F
.376 .119 .391 r
.43729 .57803 m .43687 .5809 L .44005 .57746 L F
.927 .973 .709 r
.43175 .56073 m .4313 .55948 L .43356 .55835 L F
.903 .982 .718 r
.43582 .55458 m .43356 .55835 L .43357 .55581 L F
.902 .983 .722 r
.43356 .55835 m .4313 .55948 L .43357 .55581 L F
0 0 0 r
.30133 .64061 m .30231 .64103 L .29913 .64283 L F
.30133 .64061 m .30389 .63952 L .30231 .64103 L F
.042 .608 .775 r
.58613 .35381 m .58986 .35374 L .59028 .35404 L F
.222 .453 .871 r
.58687 .35167 m .59003 .35374 L .58613 .35381 L F
.864 .471 0 r
.58966 .3537 m .5901 .35574 L .59167 .35742 L F
.58943 .35328 m .58954 .35367 L .58966 .3537 L F
.58954 .35367 m .5901 .35574 L .58966 .3537 L F
.042 .608 .775 r
.58986 .35374 m .59003 .35374 L .59007 .35379 L F
.58986 .35374 m .59007 .35379 L .59028 .35404 L F
0 .306 .678 r
.59055 .35372 m .59167 .35456 L .59196 .35208 L F
.59028 .35404 m .59167 .35456 L .59055 .35372 L F
.449 .26 .532 r
.59167 .35456 m .59167 .35742 L .59448 .35637 L F
.501 0 0 r
.59448 .35637 m .59232 .35505 L .59167 .35456 L F
0 .306 .678 r
.59028 .35404 m .59003 .35374 L .59167 .35456 L F
.864 .471 0 r
.58943 .35328 m .5914 .35691 L .59167 .35456 L F
.5914 .35691 m .59167 .35742 L .59167 .35456 L F
.501 0 0 r
.59232 .35505 m .58943 .35328 L .59167 .35456 L F
0 .306 .678 r
.59196 .35208 m .59167 .35456 L .59196 .35208 L F
.782 .618 .677 r
.39726 .54039 m .39923 .54396 L .40014 .5407 L F
.711 .986 .843 r
.5308 .43652 m .52908 .43823 L .5283 .43826 L F
.674 .126 0 r
.29202 .64438 m .29233 .64596 L .29229 .64466 L F
.174 .561 .933 r
.29202 .64438 m .29701 .64642 L .29565 .64732 L F
.917 .95 .802 r
.42138 .59054 m .42301 .58841 L .42022 .5895 L F
.866 .901 .856 r
.42189 .58567 m .42301 .58841 L .42518 .58559 L F
.938 .912 .766 r
.42022 .5895 m .42301 .58841 L .42189 .58567 L F
.855 .555 .48 r
.35288 .52777 m .34964 .52959 L .34945 .5267 L F
.35288 .52777 m .35298 .53038 L .34964 .52959 L F
.94 .961 .74 r
.53356 .47472 m .53576 .47095 L .5348 .47006 L F
.864 .982 .849 r
.5348 .47006 m .53576 .47095 L .53864 .46771 L F
.04 0 0 r
.51687 .45318 m .51385 .45426 L .51406 .45373 L F
.425 .135 .368 r
.51385 .45426 m .51687 .45318 L .51406 .45373 L F
.866 .522 .399 r
.66303 .34153 m .66689 .34082 L .66241 .33975 L F
.66303 .34153 m .66654 .34301 L .66689 .34082 L F
.95 .63 .388 r
.66689 .34082 m .66654 .34301 L .6682 .34381 L F
.081 0 0 r
.31985 .68871 m .32074 .6888 L .3182 .68855 L F
.421 .835 .969 r
.25474 .59032 m .25103 .59048 L .25245 .59021 L F
.617 .954 .911 r
.48104 .41347 m .48246 .41169 L .48446 .4111 L F
.48104 .41347 m .48019 .41314 L .48246 .41169 L F
.04 0 0 r
.62414 .34997 m .62329 .35012 L .62035 .3502 L F
0 0 0 r
.62173 .35048 m .62035 .3502 L .62329 .35012 L F
.716 .98 .773 r
.62472 .34768 m .62184 .35037 L .62329 .35012 L F
.62184 .35037 m .62173 .35048 L .62329 .35012 L F
.04 0 0 r
.62442 .34996 m .62329 .35012 L .62414 .34997 L F
.342 .819 .79 r
.626 .34911 m .62442 .34996 L .62721 .35006 L F
.626 .34911 m .62329 .35012 L .62442 .34996 L F
0 .229 .746 r
.37522 .47632 m .37805 .47861 L .38067 .47672 L F
.877 .685 .64 r
.38067 .47672 m .38123 .48089 L .37776 .47985 L F
.147 .158 .614 r
.38183 .47879 m .38067 .47672 L .38182 .47575 L F
0 0 0 r
.38067 .47672 m .38041 .47711 L .38182 .47575 L F
.38067 .47672 m .37805 .47861 L .38041 .47711 L F
.147 .158 .614 r
.38183 .47879 m .38123 .48089 L .38067 .47672 L F
.037 0 0 r
.27891 .64337 m .28147 .64331 L .28335 .64336 L F
.768 .89 .932 r
.4617 .53936 m .46717 .5382 L .46506 .53623 L F
.676 .911 .579 r
.56188 .39379 m .5587 .39774 L .5599 .39574 L F
.745 .739 .847 r
.30267 .62912 m .29847 .62876 L .30087 .6275 L F
.695 .802 .931 r
.30087 .6275 m .30532 .6278 L .30267 .62912 L F
.892 .903 .828 r
.54884 .44461 m .55111 .4418 L .54833 .44182 L F
0 0 0 r
.44931 .44928 m .45046 .44738 L .45218 .44619 L F
.296 0 .033 r
.54122 .38662 m .53766 .38875 L .53831 .38709 L F
.898 .623 .511 r
.32802 .53023 m .33019 .53373 L .33033 .53104 L F
0 .065 .58 r
.37511 .58201 m .37574 .58429 L .37527 .5799 L F
.716 .984 .798 r
.48446 .4111 m .48561 .40901 L .48666 .40957 L F
.48446 .4111 m .48246 .41169 L .48561 .40901 L F
.922 .784 .691 r
.33256 .55006 m .33058 .55347 L .33351 .55421 L F
.94 .782 .658 r
.33007 .55645 m .33351 .55421 L .33058 .55347 L F
.33007 .55645 m .33198 .55759 L .33351 .55421 L F
0 0 0 r
.34623 .66642 m .34735 .66364 L .34912 .66368 L F
.652 .947 .955 r
.50372 .45413 m .50442 .45289 L .50646 .45193 L F
.50372 .45413 m .50293 .45336 L .50498 .45189 L F
.278 0 0 r
.50324 .45346 m .50115 .45482 L .50502 .45404 L F
.50293 .45336 m .50214 .45401 L .50324 .45346 L F
.50214 .45401 m .50115 .45482 L .50324 .45346 L F
.652 .947 .955 r
.50442 .45289 m .50498 .45189 L .50637 .45193 L F
.50442 .45289 m .50637 .45193 L .50646 .45193 L F
.504 .904 .789 r
.63743 .38042 m .63495 .38187 L .63397 .38184 L F
.592 .758 .957 r
.58069 .37747 m .5776 .37852 L .57685 .37713 L F
0 0 0 r
.58069 .37747 m .57734 .37865 L .5776 .37852 L F
.505 .844 .565 r
.57734 .37865 m .57514 .38068 L .5776 .37852 L F
.8 .563 .579 r
.57007 .37445 m .57271 .3704 L .5699 .37135 L F
.713 .8 .329 r
.5721 .37261 m .57007 .37445 L .56837 .37291 L F
.5721 .37261 m .5709 .37571 L .57007 .37445 L F
.276 0 0 r
.33995 .50519 m .34262 .50575 L .3444 .50527 L F
.428 0 0 r
.34659 .50634 m .34671 .5066 L .34884 .50743 L F
.3444 .50527 m .34671 .5066 L .34659 .50634 L F
0 0 .257 r
.34617 .50496 m .34686 .50691 L .34671 .5066 L F
.974 .794 .372 r
.34779 .50955 m .34884 .50743 L .34671 .5066 L F
0 0 .257 r
.34686 .50691 m .34779 .50955 L .34671 .5066 L F
0 .299 .788 r
.34585 .50501 m .3444 .50527 L .34262 .50575 L F
.34585 .50501 m .34671 .5066 L .3444 .50527 L F
.744 .923 .951 r
.52015 .46269 m .52201 .46002 L .52358 .46144 L F
.52015 .46269 m .51829 .46276 L .52201 .46002 L F
.11 0 0 r
.3524 .63361 m .35187 .63232 L .35017 .63372 L F
.242 .462 .873 r
.35508 .63384 m .35187 .63232 L .35433 .63101 L F
.11 0 0 r
.3524 .63361 m .35433 .63101 L .35187 .63232 L F
0 .345 .754 r
.5601 .34389 m .55854 .34267 L .55674 .34192 L F
.523 .351 .59 r
.56282 .34031 m .56306 .34339 L .5601 .34389 L F
.664 .914 .977 r
.56136 .34124 m .5601 .34389 L .56306 .34339 L F
.56136 .34124 m .55854 .34267 L .5601 .34389 L F
.115 0 0 r
.4041 .4737 m .40044 .47721 L .40002 .47492 L F
.4041 .4737 m .40277 .47612 L .40044 .47721 L F
.825 .657 .674 r
.40731 .47288 m .40277 .47612 L .4041 .4737 L F
.739 .65 .761 r
.50618 .46412 m .50291 .46411 L .50569 .46086 L F
.696 .477 .586 r
.50618 .46412 m .50272 .46687 L .50291 .46411 L F
.50618 .46412 m .50662 .46713 L .50272 .46687 L F
.579 .41 .617 r
.50912 .46375 m .50662 .46713 L .50618 .46412 L F
.108 .314 .788 r
.56613 .3952 m .56766 .39888 L .5653 .39727 L F
0 0 0 r
.41658 .45953 m .42052 .45689 L .418 .45776 L F
.87 .712 .683 r
.38433 .52508 m .38731 .52436 L .38348 .52352 L F
.38433 .52508 m .38682 .52703 L .38731 .52436 L F
.637 .662 .858 r
.24621 .61422 m .24425 .61584 L .24273 .61438 L F
0 0 0 r
.40537 .46394 m .4014 .46688 L .4043 .46645 L F
.23 0 .093 r
.40798 .46296 m .40537 .46394 L .4043 .46645 L F
.575 .849 .996 r
.30305 .68418 m .30719 .68443 L .30569 .68358 L F
.448 .597 .907 r
.30719 .68443 m .30764 .68111 L .30569 .68358 L F
.30719 .68443 m .31151 .68449 L .30764 .68111 L F
.699 .936 .964 r
.24855 .59822 m .24547 .6005 L .24748 .60112 L F
.35 .225 .565 r
.24748 .60411 m .24748 .60112 L .24547 .6005 L F
.24748 .60411 m .24961 .60336 L .24748 .60112 L F
.24748 .60112 m .24961 .60336 L .24748 .60411 L F
.909 .824 .751 r
.56005 .38605 m .5604 .38254 L .56205 .38407 L F
.862 .873 .845 r
.56492 .38078 m .56205 .38407 L .5604 .38254 L F
.735 .992 .853 r
.31347 .53847 m .31066 .54123 L .31156 .5392 L F
.966 .647 .345 r
.31066 .54123 m .30915 .54264 L .31156 .5392 L F
.31066 .54123 m .31105 .54418 L .30915 .54264 L F
.629 .407 .562 r
.52497 .39058 m .52939 .3902 L .52868 .38832 L F
.694 .729 .877 r
.49995 .48666 m .49767 .48781 L .49635 .48571 L F
.31 0 .049 r
.41389 .47031 m .40964 .47297 L .40972 .47151 L F
.337 .792 .947 r
.61962 .39517 m .62175 .39441 L .61899 .39322 L F
.596 .272 .391 r
.3486 .51032 m .35323 .50778 L .34884 .50743 L F
.3486 .51032 m .35175 .51049 L .35323 .50778 L F
.701 .392 .45 r
.35323 .50778 m .35175 .51049 L .35541 .51022 L F
.828 .794 .82 r
.31397 .59348 m .31764 .59406 L .31876 .59149 L F
.847 .76 .766 r
.31365 .59603 m .31764 .59406 L .31397 .59348 L F
.736 .334 .29 r
.35527 .5123 m .3599 .51123 L .35541 .51022 L F
.35527 .5123 m .35957 .51295 L .3599 .51123 L F
.934 .575 .311 r
.66654 .34301 m .66693 .3453 L .6682 .34381 L F
.806 .363 .191 r
.66693 .3453 m .67043 .34654 L .6682 .34381 L F
.734 .74 .856 r
.52581 .42799 m .52681 .43074 L .52307 .43025 L F
.769 .672 .756 r
.52386 .43369 m .52681 .43074 L .52307 .43025 L F
.616 .106 .015 r
.52307 .43025 m .52681 .43074 L .52548 .43215 L F
.276 .447 .85 r
.52832 .42885 m .52681 .43074 L .52581 .42799 L F
.571 .843 .497 r
.52548 .43215 m .52681 .43074 L .52832 .42885 L F
.916 .747 .657 r
.54609 .44575 m .54884 .44461 L .54833 .44182 L F
.54609 .44575 m .54809 .44735 L .54884 .44461 L F
.677 .753 .908 r
.32823 .61912 m .32424 .61856 L .3268 .61739 L F
.701 .736 .878 r
.3268 .61739 m .33112 .61804 L .32823 .61912 L F
.523 0 0 r
.447 .55362 m .44926 .55422 L .44505 .5537 L F
.746 .228 0 r
.65151 .36283 m .65461 .36479 L .65511 .36587 L F
.754 .64 .734 r
.31089 .65594 m .31266 .65875 L .30877 .65826 L F
.682 .877 .972 r
.3145 .65633 m .31266 .65875 L .31089 .65594 L F
.3145 .65633 m .31512 .65775 L .31266 .65875 L F
.601 .436 .631 r
.31512 .65775 m .31244 .66114 L .31266 .65875 L F
.344 .82 .883 r
.63462 .34149 m .63777 .34051 L .63946 .34077 L F
.41 .858 .896 r
.63946 .34077 m .6405 .33959 L .64229 .34011 L F
.63946 .34077 m .63777 .34051 L .6405 .33959 L F
.788 .78 .846 r
.49616 .43866 m .49896 .4333 L .49632 .43403 L F
.555 .106 .139 r
.49935 .44043 m .49616 .43866 L .49754 .43944 L F
.284 .562 .931 r
.30892 .60033 m .31134 .59711 L .30948 .59795 L F
.657 .103 0 r
.28985 .64351 m .29445 .64126 L .29266 .6398 L F
.537 .734 .966 r
.29445 .64126 m .29544 .63898 L .29266 .6398 L F
.29445 .64126 m .29695 .64071 L .29544 .63898 L F
0 0 .101 r
.29445 .64126 m .29523 .643 L .29695 .64071 L F
.29445 .64126 m .29229 .64466 L .29523 .643 L F
.736 .989 .801 r
.28848 .5559 m .28641 .55759 L .28707 .55583 L F
.55 .286 .467 r
.28848 .5559 m .28969 .55748 L .28641 .55759 L F
.739 .221 0 r
.28707 .55583 m .28969 .55748 L .28848 .5559 L F
.704 .971 .745 r
.4368 .55278 m .43891 .55171 L .43582 .55458 L F
.703 .967 .73 r
.43357 .55581 m .4368 .55278 L .43582 .55458 L F
.587 .903 .641 r
.4858 .42301 m .48947 .41997 L .4881 .42163 L F
0 0 0 r
.49249 .41725 m .49165 .41904 L .48947 .41997 L F
.48947 .41997 m .49165 .41904 L .4881 .42163 L F
.262 0 .171 r
.43568 .4467 m .43308 .44757 L .43218 .44961 L F
.85 .466 .321 r
.38123 .48089 m .37955 .48283 L .37776 .47985 L F
.432 .138 .363 r
.38183 .47879 m .37955 .48283 L .38123 .48089 L F
.874 .963 .853 r
.50346 .49784 m .4995 .50003 L .50111 .50131 L F
.696 .809 .935 r
.50688 .40282 m .50338 .40399 L .50731 .4044 L F
.076 .338 .813 r
.50731 .4044 m .5081 .40351 L .50688 .40282 L F
0 .012 .528 r
.50731 .4044 m .50883 .40494 L .5081 .40351 L F
.50731 .4044 m .50787 .40722 L .50883 .40494 L F
.951 .871 .722 r
.47407 .51066 m .47086 .51333 L .47361 .51026 L F
.47407 .51066 m .47248 .51471 L .47086 .51333 L F
.833 .989 .723 r
.47685 .50703 m .47407 .51066 L .47501 .50792 L F
.827 .973 .666 r
.47407 .51066 m .47361 .51026 L .47501 .50792 L F
.034 0 .397 r
.38137 .53958 m .38019 .54024 L .38013 .53789 L F
.38013 .53789 m .38019 .54024 L .38137 .53958 L F
0 0 .493 r
.59561 .37846 m .59662 .38221 L .59572 .38151 L F
.59561 .37846 m .59727 .38126 L .59662 .38221 L F
0 0 0 r
.59698 .38363 m .59662 .38221 L .59727 .38126 L F
.772 .478 .488 r
.31109 .58379 m .309 .58425 L .30942 .58185 L F
.31109 .58379 m .30843 .58609 L .309 .58425 L F
.31109 .58379 m .31199 .58724 L .30843 .58609 L F
.837 .773 .79 r
.54284 .39625 m .54484 .39879 L .54623 .3965 L F
0 0 .073 r
.50733 .43134 m .50769 .42648 L .50618 .42807 L F
.912 .845 .765 r
.50493 .43179 m .50733 .43134 L .50618 .42807 L F
.50493 .43179 m .50603 .43345 L .50733 .43134 L F
.068 0 .322 r
.27197 .54357 m .27432 .5396 L .2725 .54101 L F
.743 .792 .892 r
.31315 .62123 m .31438 .62468 L .31031 .62374 L F
.821 .704 .736 r
.31031 .62374 m .31438 .62468 L .31195 .62763 L F
.763 .802 .885 r
.31754 .62124 m .31438 .62468 L .31315 .62123 L F
.602 .923 .97 r
.50948 .42057 m .51137 .42106 L .51327 .41981 L F
.441 .518 .842 r
.29896 .6615 m .29611 .65831 L .29746 .65961 L F
.632 .751 .934 r
.30141 .65974 m .29896 .6615 L .29746 .65961 L F
.896 .74 .68 r
.52215 .37993 m .52157 .3832 L .52362 .38397 L F
.823 1 .821 r
.52105 .38473 m .52362 .38397 L .52157 .3832 L F
.52105 .38473 m .52051 .3871 L .52362 .38397 L F
.805 .881 .452 r
.52105 .38473 m .51931 .38875 L .52051 .3871 L F
.39 .115 .371 r
.49632 .43403 m .49896 .4333 L .50012 .43015 L F
.431 .136 .362 r
.49896 .4333 m .50164 .43018 L .50012 .43015 L F
.757 .485 .522 r
.31439 .53052 m .31037 .5274 L .31471 .52761 L F
.159 .689 .861 r
.52433 .39238 m .52734 .39205 L .52358 .39193 L F
.855 .806 .318 r
.58616 .39774 m .58572 .40016 L .58561 .39964 L F
.58616 .39774 m .58561 .39964 L .58483 .39725 L F
0 .179 .646 r
.58561 .39964 m .58682 .40019 L .5854 .39859 L F
0 0 .343 r
.58483 .39725 m .58561 .39964 L .58452 .39553 L F
.903 .627 .124 r
.58452 .39553 m .58561 .39964 L .58477 .39789 L F
0 .179 .646 r
.58561 .39964 m .5854 .39859 L .58477 .39789 L F
.855 .806 .318 r
.58572 .40016 m .58562 .40074 L .58561 .39964 L F
.291 .116 .463 r
.58562 .40074 m .58666 .40311 L .58561 .39964 L F
.58562 .40074 m .58638 .40349 L .58666 .40311 L F
.903 .876 .799 r
.41725 .59312 m .42138 .59054 L .42022 .5895 L F
.41725 .59312 m .41882 .59451 L .42138 .59054 L F
.862 .873 .845 r
.56492 .38078 m .5604 .38254 L .56311 .37923 L F
.632 .629 .829 r
.52123 .40685 m .51837 .40736 L .51718 .40412 L F
.403 .129 .381 r
.52123 .40685 m .51828 .40997 L .51837 .40736 L F
.356 .236 .576 r
.26503 .57926 m .26297 .57794 L .26436 .57835 L F
.26503 .57926 m .26313 .58062 L .26297 .57794 L F
.481 .859 .64 r
.52386 .43369 m .5201 .43629 L .52322 .43377 L F
0 0 .475 r
.52551 .43491 m .52468 .43734 L .52386 .43369 L F
.52551 .43491 m .52386 .43369 L .52322 .43377 L F
.895 .988 .774 r
.34506 .66985 m .34617 .66905 L .34623 .66642 L F
.754 .986 .76 r
.32829 .63327 m .33158 .63125 L .32821 .63024 L F
.329 .747 .977 r
.32821 .63024 m .33158 .63125 L .33264 .63069 L F
.473 .879 .95 r
.55586 .3392 m .55719 .33794 L .5588 .3391 L F
.55586 .3392 m .55437 .33886 L .55719 .33794 L F
.137 0 .117 r
.29701 .64642 m .29858 .64456 L .29882 .6456 L F
0 0 .168 r
.29882 .6456 m .29858 .64456 L .29913 .64283 L F
.833 .989 .723 r
.47685 .50703 m .47501 .50792 L .47639 .50679 L F
.854 .939 .569 r
.47685 .50703 m .47843 .50279 L .4794 .50333 L F
.47685 .50703 m .47639 .50679 L .47843 .50279 L F
.85 .728 .728 r
.29676 .55743 m .29342 .55736 L .29583 .55432 L F
.29342 .55736 m .29344 .55714 L .29583 .55432 L F
.604 .325 .467 r
.29676 .55743 m .293 .56044 L .29326 .55736 L F
.757 .955 .644 r
.29583 .55432 m .29326 .55736 L .29404 .55597 L F
0 0 .366 r
.29319 .55962 m .29407 .55947 L .29404 .55597 L F
.293 .56044 m .29312 .56033 L .29319 .55962 L F
.29312 .56033 m .29407 .55947 L .29319 .55962 L F
.85 .728 .728 r
.29342 .55736 m .29326 .55736 L .29344 .55714 L F
.604 .325 .467 r
.29676 .55743 m .29618 .56061 L .293 .56044 L F
.465 .499 .809 r
.29924 .55621 m .29676 .55743 L .29583 .55432 L F
.57 .294 .458 r
.29971 .55951 m .29676 .55743 L .29924 .55621 L F
.29971 .55951 m .29618 .56061 L .29676 .55743 L F
.198 0 .213 r
.41389 .47031 m .41644 .46736 L .41606 .4696 L F
.364 .128 .416 r
.41644 .46736 m .4182 .46876 L .41606 .4696 L F
.41644 .46736 m .41871 .46661 L .4182 .46876 L F
.863 .6 .539 r
.35966 .51605 m .3637 .51421 L .35957 .51295 L F
.35966 .51605 m .36387 .51719 L .3637 .51421 L F
.679 .455 .575 r
.3637 .51421 m .36387 .51719 L .36793 .51676 L F
.971 .658 .347 r
.39996 .551 m .39979 .55328 L .3983 .54985 L F
.813 .469 .405 r
.39979 .55328 m .39996 .551 L .3983 .54985 L F
.39979 .55328 m .40191 .55402 L .39996 .551 L F
.691 .489 .609 r
.31037 .5274 m .30781 .5306 L .30797 .52759 L F
.31037 .5274 m .31343 .53086 L .30781 .5306 L F
.757 .485 .522 r
.31439 .53052 m .31343 .53086 L .31037 .5274 L F
.523 .821 .488 r
.30335 .64652 m .30253 .64743 L .30099 .64727 L F
.557 0 0 r
.30119 .64689 m .30265 .64726 L .30335 .64652 L F
.523 .821 .488 r
.30335 .64652 m .30404 .64581 L .30253 .64743 L F
.557 0 0 r
.30265 .64726 m .30581 .64806 L .30335 .64652 L F
.523 .821 .488 r
.30335 .64652 m .30565 .64408 L .30404 .64581 L F
.304 .628 .962 r
.29601 .68275 m .29722 .68113 L .29447 .68169 L F
0 .3 .75 r
.29722 .68113 m .30022 .68377 L .29984 .67966 L F
0 0 0 r
.30178 .68477 m .30305 .68418 L .30022 .68377 L F
.701 .857 .957 r
.29984 .67966 m .30022 .68377 L .30387 .67999 L F
.644 .688 .877 r
.30305 .68418 m .30387 .67999 L .30022 .68377 L F
0 .3 .75 r
.29722 .68113 m .30178 .68477 L .30022 .68377 L F
.304 .628 .962 r
.29601 .68275 m .30178 .68477 L .29722 .68113 L F
0 0 0 r
.45434 .43393 m .45593 .43281 L .4576 .43146 L F
.45434 .43393 m .4529 .43552 L .45593 .43281 L F
.874 .963 .853 r
.50346 .49784 m .50231 .49691 L .4995 .50003 L F
.882 .962 .845 r
.50369 .49509 m .50346 .49784 L .50516 .49617 L F
.50369 .49509 m .50231 .49691 L .50346 .49784 L F
.94 .961 .74 r
.53356 .47472 m .5348 .47006 L .53214 .47351 L F
.826 .686 .708 r
.36314 .56039 m .36702 .56094 L .36492 .56442 L F
.786 .908 .514 r
.34343 .66988 m .34383 .67008 L .34426 .66829 L F
.407 .856 .786 r
.34258 .67098 m .34417 .67026 L .34383 .67008 L F
0 0 0 r
.34061 .67281 m .34258 .67098 L .34383 .67008 L F
.34061 .67281 m .34383 .67008 L .34206 .6725 L F
.786 .908 .514 r
.34206 .6725 m .34383 .67008 L .34343 .66988 L F
.407 .856 .786 r
.34417 .67026 m .34506 .66985 L .34383 .67008 L F
.672 .798 .942 r
.49571 .45017 m .49989 .45076 L .49824 .4493 L F
.49571 .45017 m .49989 .45076 L .49824 .4493 L F
.707 .62 .758 r
.51475 .42607 m .51796 .4234 L .51521 .42441 L F
.632 .217 .238 r
.52787 .39065 m .52939 .3902 L .52786 .39033 L F
.52358 .39193 m .52734 .39205 L .52939 .3902 L F
0 0 0 r
.52734 .39205 m .52959 .38863 L .52939 .3902 L F
.52789 .39122 m .52918 .39039 L .52959 .38863 L F
.52734 .39205 m .5279 .39155 L .52789 .39122 L F
.5279 .39155 m .52918 .39039 L .52789 .39122 L F
.632 .217 .238 r
.52358 .39193 m .52787 .39065 L .52497 .39058 L F
.52787 .39065 m .52786 .39033 L .52497 .39058 L F
.825 .657 .674 r
.40731 .47288 m .40998 .47576 L .40277 .47612 L F
.116 0 0 r
.40277 .47612 m .40998 .47576 L .40516 .47618 L F
.9 .682 .598 r
.40976 .476 m .40516 .47618 L .40998 .47576 L F
.669 .173 0 r
.40976 .476 m .40998 .47576 L .40731 .47288 L F
.431 .727 .988 r
.40474 .59296 m .406 .59426 L .40699 .59264 L F
.835 .975 .882 r
.48145 .49957 m .4794 .50333 L .47843 .50279 L F
.48145 .49957 m .48226 .50051 L .4794 .50333 L F
.668 .225 0 r
.60051 .36073 m .60228 .36347 L .60273 .36388 L F
.952 .948 .649 r
.60273 .36388 m .60095 .36496 L .60138 .36604 L F
.709 .984 .813 r
.60273 .36388 m .60228 .36347 L .6041 .36169 L F
.698 .955 .691 r
.6041 .36169 m .60095 .36496 L .60273 .36388 L F
.436 .667 .959 r
.6089 .39542 m .61003 .39729 L .61142 .39517 L F
.61142 .39517 m .61003 .39729 L .6089 .39542 L F
.318 0 .137 r
.57271 .3704 m .56837 .37291 L .5699 .37135 L F
.489 0 0 r
.31916 .54765 m .31945 .54808 L .31754 .54697 L F
.31916 .54765 m .32209 .55003 L .31945 .54808 L F
.435 .857 .949 r
.59628 .3439 m .60107 .34371 L .59836 .34376 L F
.798 .918 .919 r
.51636 .48538 m .51797 .48637 L .52096 .48409 L F
.755 .697 .797 r
.64012 .39342 m .64419 .3941 L .64246 .39033 L F
.614 .629 .842 r
.64246 .39033 m .64419 .3941 L .64699 .39319 L F
.512 .897 .954 r
.41238 .59544 m .41282 .59362 L .41094 .59407 L F
.41238 .59544 m .41565 .5942 L .41282 .59362 L F
0 0 0 r
.4937 .41797 m .49165 .41904 L .49249 .41725 L F
.884 .992 .781 r
.4368 .55278 m .44011 .54975 L .43891 .55171 L F
.942 .937 .593 r
.65744 .36687 m .65568 .36908 L .65511 .36587 L F
.65744 .36687 m .6561 .37023 L .65568 .36908 L F
.546 .108 .159 r
.33165 .65249 m .3346 .65373 L .3309 .65409 L F
0 0 0 r
.60659 .34996 m .60543 .35052 L .60225 .3513 L F
.591 .155 .18 r
.60944 .34907 m .60543 .35052 L .60659 .34996 L F
.874 .883 .838 r
.32247 .58368 m .3217 .58794 L .32409 .58467 L F
.899 .929 .827 r
.32247 .58368 m .32409 .58467 L .32648 .58136 L F
.864 .982 .849 r
.5348 .47006 m .53864 .46771 L .53709 .46633 L F
.834 .809 .826 r
.53864 .46771 m .5395 .46279 L .53709 .46633 L F
.53864 .46771 m .54132 .46433 L .5395 .46279 L F
.104 .128 .601 r
.57256 .35884 m .5737 .36169 L .57154 .36363 L F
.171 .242 .695 r
.5737 .36169 m .57398 .36559 L .57154 .36363 L F
.023 0 0 r
.53644 .4333 m .54092 .43345 L .53809 .43336 L F
.62 .766 .95 r
.51967 .39789 m .52243 .39686 L .51816 .39596 L F
.034 .13 .634 r
.57768 .35704 m .5796 .35884 L .57867 .35624 L F
.158 0 0 r
.44189 .57228 m .44455 .57244 L .44395 .57221 L F
0 0 0 r
.44455 .57244 m .44582 .57119 L .44395 .57221 L F
.83 .934 .897 r
.46795 .53312 m .47255 .53128 L .47104 .53 L F
.892 .894 .823 r
.47104 .53 m .47255 .53128 L .4751 .5277 L F
.061 0 0 r
.49799 .41334 m .49348 .41514 L .49598 .41497 L F
.149 0 0 r
.38497 .47361 m .38748 .47306 L .38941 .47136 L F
.534 .118 .198 r
.38748 .47306 m .39197 .47065 L .38941 .47136 L F
.962 .643 .363 r
.44624 .54076 m .44396 .54126 L .44434 .53972 L F
.44624 .54076 m .44632 .54172 L .44396 .54126 L F
.579 .377 .572 r
.44434 .53972 m .44821 .53879 L .44624 .54076 L F
.209 0 0 r
.44421 .53983 m .44673 .54023 L .44434 .53972 L F
.123 .155 .622 r
.44396 .54126 m .44521 .54011 L .444 .53978 L F
.209 0 0 r
.44413 .5399 m .44474 .53998 L .44421 .53983 L F
.44474 .53998 m .44558 .54009 L .44421 .53983 L F
.123 .155 .622 r
.44396 .54126 m .44404 .53836 L .44434 .53972 L F
.444 .53978 m .44421 .53983 L .44404 .53836 L F
.209 0 0 r
.44413 .5399 m .44421 .53983 L .44404 .53836 L F
.44421 .53983 m .44434 .53972 L .44404 .53836 L F
.579 .377 .572 r
.44821 .53879 m .44829 .53877 L .44823 .53883 L F
.44434 .53972 m .44673 .54023 L .44829 .53877 L F
.123 .155 .622 r
.44421 .53983 m .44474 .53998 L .44404 .53836 L F
.209 0 0 r
.44558 .54009 m .44673 .54023 L .44574 .54008 L F
.864 .955 .867 r
.44752 .53772 m .44673 .54023 L .44558 .54009 L F
.209 0 0 r
.44558 .54009 m .44574 .54008 L .44421 .53983 L F
.864 .955 .867 r
.44506 .53972 m .44558 .54009 L .44474 .53998 L F
.44752 .53772 m .44558 .54009 L .44506 .53972 L F
0 0 .082 r
.4442 .53422 m .44414 .53892 L .44404 .53836 L F
.44414 .53892 m .44413 .5399 L .44404 .53836 L F
.123 .155 .622 r
.44474 .53998 m .44487 .53959 L .44404 .53836 L F
.847 .635 .616 r
.44487 .53959 m .44413 .53888 L .44404 .53836 L F
.44413 .53888 m .44286 .53766 L .44404 .53836 L F
.864 .955 .867 r
.44493 .53939 m .44474 .53998 L .44413 .5399 L F
.4503 .53594 m .44474 .53951 L .44854 .53462 L F
.44474 .53951 m .44413 .5399 L .44457 .53937 L F
.44474 .53951 m .44457 .53937 L .44854 .53462 L F
.806 .732 .783 r
.44854 .53462 m .44457 .53937 L .4442 .53422 L F
.44457 .53937 m .44413 .5399 L .44414 .53892 L F
.44457 .53937 m .44414 .53892 L .4442 .53422 L F
.847 .635 .616 r
.44521 .54011 m .44441 .53928 L .44464 .53944 L F
.44487 .53967 m .44464 .53944 L .44474 .53951 L F
.123 .155 .622 r
.44474 .53998 m .44521 .54011 L .44487 .53959 L F
.864 .955 .867 r
.44752 .53772 m .44474 .53998 L .44493 .53939 L F
.847 .635 .616 r
.44521 .54011 m .44464 .53944 L .44487 .53967 L F
.44489 .53963 m .44474 .53951 L .44487 .53959 L F
.44521 .54011 m .44474 .53951 L .44489 .53963 L F
.44441 .53928 m .44286 .53766 L .44487 .53959 L F
.123 .155 .622 r
.44396 .54126 m .44564 .54075 L .44521 .54011 L F
.847 .635 .616 r
.44564 .54075 m .44508 .54012 L .44521 .54011 L F
.44508 .54012 m .44286 .53766 L .44521 .54011 L F
.864 .955 .867 r
.4503 .53594 m .44809 .5386 L .44752 .53772 L F
.44809 .5386 m .44673 .54023 L .44752 .53772 L F
.579 .377 .572 r
.44821 .53879 m .44823 .53883 L .44624 .54076 L F
.553 .573 .829 r
.25516 .59378 m .25293 .59481 L .25103 .59048 L F
.562 .313 .496 r
.25516 .59378 m .25313 .59521 L .25293 .59481 L F
.116 0 0 r
.33537 .63783 m .33415 .63877 L .33018 .63934 L F
.316 0 0 r
.33831 .63797 m .33415 .63877 L .33537 .63783 L F
0 0 0 r
.4576 .43146 m .45845 .43168 L .45986 .43005 L F
.4576 .43146 m .45593 .43281 L .45845 .43168 L F
.976 .751 .533 r
.38433 .52508 m .38538 .53022 L .38682 .52703 L F
0 0 0 r
.29523 .643 m .29229 .64466 L .29233 .64596 L F
0 0 .466 r
.24748 .60411 m .24767 .60638 L .24884 .60665 L F
.018 0 0 r
.24884 .60665 m .24767 .60638 L .24483 .6085 L F
.791 .992 .88 r
.31633 .64768 m .31876 .64407 L .31853 .64726 L F
.849 .896 .87 r
.32077 .64055 m .31876 .64407 L .31754 .64242 L F
.499 0 0 r
.33831 .63797 m .34227 .63782 L .33998 .63924 L F
.757 .882 .469 r
.34282 .63581 m .34227 .63782 L .34413 .63425 L F
.761 .981 .732 r
.33998 .63924 m .34227 .63782 L .34282 .63581 L F
.551 .408 .64 r
.34227 .63782 m .34505 .6373 L .34413 .63425 L F
.524 .388 .638 r
.34238 .64061 m .34505 .6373 L .34227 .63782 L F
.532 .355 .587 r
.42891 .57397 m .4264 .57821 L .42645 .57507 L F
.626 .117 .019 r
.29987 .65408 m .30433 .65472 L .30234 .65645 L F
.29987 .65408 m .30234 .65645 L .30185 .65628 L F
.61 .886 .57 r
.30255 .65622 m .30433 .65472 L .30613 .65269 L F
.30234 .65645 m .30433 .65472 L .30255 .65622 L F
.559 .053 0 r
.30008 .65446 m .29987 .65408 L .30185 .65628 L F
.481 .28 .53 r
.30159 .65602 m .30057 .65583 L .30051 .6549 L F
.559 .053 0 r
.29846 .65278 m .30185 .65628 L .29919 .65354 L F
.481 .28 .53 r
.30198 .65633 m .30132 .65609 L .30259 .65621 L F
.30132 .65609 m .30057 .65583 L .30119 .65594 L F
.30132 .65609 m .30119 .65594 L .30259 .65621 L F
.559 .053 0 r
.29846 .65278 m .29919 .65354 L .30012 .65466 L F
.481 .28 .53 r
.30382 .65699 m .30195 .65937 L .30057 .65583 L F
.664 .433 .561 r
.30215 .65662 m .30032 .65471 L .30012 .65466 L F
.481 .28 .53 r
.30051 .6549 m .30057 .65583 L .30012 .65466 L F
.30328 .65543 m .30257 .6562 L .30012 .65466 L F
.559 .053 0 r
.29919 .65354 m .30215 .65662 L .30012 .65466 L F
.29919 .65354 m .30185 .65628 L .30215 .65662 L F
.481 .28 .53 r
.30259 .65621 m .30159 .65602 L .30051 .6549 L F
.30382 .65699 m .30198 .65633 L .30259 .65621 L F
.61 .886 .57 r
.30215 .65662 m .30234 .65645 L .30255 .65622 L F
.481 .28 .53 r
.30476 .65579 m .30382 .65699 L .30257 .6562 L F
.61 .886 .57 r
.30215 .65662 m .30255 .65622 L .30476 .65579 L F
.694 .951 .68 r
.30613 .65269 m .30433 .65472 L .30733 .65157 L F
.61 .886 .57 r
.30255 .65622 m .30613 .65269 L .30476 .65579 L F
.481 .28 .53 r
.30476 .65579 m .30257 .6562 L .30328 .65543 L F
.626 .117 .019 r
.30185 .65628 m .30234 .65645 L .30215 .65662 L F
.664 .433 .561 r
.30215 .65662 m .30476 .65579 L .30032 .65471 L F
.559 .053 0 r
.29846 .65278 m .29861 .65292 L .30008 .65446 L F
.29861 .65292 m .29987 .65408 L .30008 .65446 L F
.889 .967 .834 r
.4522 .53683 m .44829 .53877 L .45162 .53631 L F
.862 .804 .791 r
.5395 .46279 m .54388 .46078 L .54215 .45918 L F
.5395 .46279 m .54132 .46433 L .54388 .46078 L F
0 0 .456 r
.58446 .39034 m .58551 .39085 L .58516 .38821 L F
.58446 .39034 m .58566 .39222 L .58551 .39085 L F
.01 0 0 r
.63706 .34603 m .6345 .3465 L .63391 .34641 L F
.6345 .3465 m .6322 .34694 L .6335 .34654 L F
.6345 .3465 m .6335 .34654 L .63391 .34641 L F
.485 .895 .919 r
.63706 .34603 m .63351 .34642 L .6322 .34694 L F
.042 .61 .763 r
.6392 .34663 m .63351 .34642 L .63706 .34603 L F
.806 .66 .109 r
.63425 .3436 m .6342 .34528 L .63401 .34455 L F
0 .462 .864 r
.63401 .34455 m .63517 .34469 L .63384 .3439 L F
.63401 .34455 m .63384 .3439 L .63192 .34275 L F
.806 .66 .109 r
.6342 .34528 m .63417 .34632 L .63401 .34455 L F
.63417 .34632 m .63416 .34661 L .63414 .3463 L F
.63417 .34632 m .63414 .3463 L .63401 .34455 L F
.042 .61 .763 r
.63517 .34648 m .63778 .34638 L .63433 .34641 L F
.6344 .34645 m .63433 .34641 L .63351 .34642 L F
.63517 .34648 m .63433 .34641 L .6344 .34645 L F
.6392 .34663 m .6378 .34639 L .63517 .34648 L F
.6378 .34639 m .63778 .34638 L .63517 .34648 L F
.675 .143 0 r
.56019 .34026 m .56136 .34124 L .56282 .34031 L F
.42 .275 .577 r
.56544 .34222 m .56306 .34339 L .56282 .34031 L F
.618 .072 0 r
.56136 .34124 m .56544 .34222 L .56282 .34031 L F
.137 .624 .916 r
.40133 .59252 m .4029 .59187 L .4004 .59195 L F
.40133 .59252 m .40474 .59296 L .4029 .59187 L F
0 0 0 r
.35124 .64577 m .351 .64548 L .35017 .64584 L F
.768 .832 .368 r
.37689 .57433 m .37947 .57159 L .37591 .56999 L F
.37689 .57433 m .37794 .57095 L .37947 .57159 L F
.273 .28 .685 r
.38113 .57095 m .37947 .57159 L .37794 .57095 L F
.397 0 0 r
.38279 .57273 m .38264 .57306 L .38455 .57334 L F
.37947 .57159 m .38264 .57306 L .38279 .57273 L F
.689 .969 .754 r
.38308 .56848 m .38113 .57095 L .38524 .56754 L F
.789 .715 .18 r
.38308 .56848 m .38264 .57306 L .38113 .57095 L F
.933 .943 .777 r
.38258 .57131 m .38248 .57339 L .38264 .57306 L F
.38248 .57339 m .38235 .57615 L .38264 .57306 L F
.273 .28 .685 r
.38113 .57095 m .38264 .57306 L .37947 .57159 L F
0 0 0 r
.6469 .37696 m .64414 .37803 L .64277 .37857 L F
.492 0 0 r
.64093 .34636 m .6392 .34663 L .63706 .34603 L F
.332 0 0 r
.64362 .34626 m .6392 .34663 L .64093 .34636 L F
.897 .825 .769 r
.38208 .5537 m .38602 .55376 L .38673 .55138 L F
.901 .809 .748 r
.38271 .55497 m .38381 .55724 L .38357 .55372 L F
.735 .754 .868 r
.38182 .55601 m .38381 .55724 L .38208 .5537 L F
.801 .531 .53 r
.37977 .5591 m .38381 .55724 L .38182 .55601 L F
0 0 0 r
.38122 .55817 m .3817 .55643 L .38337 .55536 L F
.3817 .55643 m .38182 .55601 L .38206 .55591 L F
.3817 .55643 m .38206 .55591 L .38337 .55536 L F
.901 .809 .748 r
.38357 .55372 m .38381 .55724 L .38602 .55376 L F
.38208 .5537 m .38271 .55497 L .38357 .55372 L F
.91 .752 .673 r
.50154 .45979 m .50291 .46411 L .50083 .4629 L F
.888 .715 .662 r
.50272 .46687 m .50083 .4629 L .50291 .46411 L F
.759 .682 .777 r
.50569 .46086 m .50291 .46411 L .50154 .45979 L F
.788 .998 .801 r
.4803 .52084 m .47644 .52345 L .47773 .52435 L F
.4803 .52084 m .4783 .52181 L .47644 .52345 L F
.87 .995 .795 r
.48198 .51684 m .4803 .52084 L .48314 .51762 L F
.48198 .51684 m .47941 .52006 L .4803 .52084 L F
.871 .994 .794 r
.4803 .52084 m .47941 .52006 L .4783 .52181 L F
.852 .647 .625 r
.30797 .52759 m .30416 .5295 L .30614 .5265 L F
.30797 .52759 m .30781 .5306 L .30416 .5295 L F
.524 .877 .639 r
.27622 .64061 m .27841 .6389 L .2796 .63792 L F
.565 .316 .498 r
.27891 .64337 m .27841 .6389 L .27622 .64061 L F
0 0 0 r
.2796 .63792 m .27841 .6389 L .28008 .63907 L F
.593 .611 .839 r
.27891 .64337 m .28008 .63907 L .27841 .6389 L F
.892 .894 .823 r
.47104 .53 m .4751 .5277 L .47319 .52629 L F
.898 .963 .825 r
.4751 .5277 m .47644 .52345 L .47319 .52629 L F
.4751 .5277 m .47773 .52435 L .47644 .52345 L F
.866 .901 .856 r
.42189 .58567 m .42518 .58559 L .4236 .58369 L F
.696 .791 .924 r
.4236 .58369 m .42518 .58559 L .42777 .58436 L F
0 0 0 r
.5564 .39961 m .5589 .39726 L .5599 .39574 L F
.707 .871 .466 r
.5599 .39574 m .5589 .39726 L .55903 .39698 L F
.5599 .39574 m .55903 .39698 L .56012 .39469 L F
.966 .724 .52 r
.56145 .39351 m .5599 .39574 L .55985 .39247 L F
.56188 .39379 m .5599 .39574 L .56145 .39351 L F
.825 .629 .638 r
.39726 .54039 m .39487 .54373 L .39923 .54396 L F
.782 .522 .542 r
.39424 .54662 m .39923 .54396 L .39487 .54373 L F
.39424 .54662 m .39936 .54727 L .39923 .54396 L F
.531 .905 .729 r
.46119 .43932 m .46522 .43697 L .46347 .43797 L F
0 0 0 r
.46849 .43425 m .46685 .43566 L .46522 .43697 L F
.464 .852 .643 r
.46522 .43697 m .46685 .43566 L .46347 .43797 L F
.077 0 0 r
.28969 .55748 m .28797 .55768 L .28641 .55759 L F
.124 .384 .84 r
.28641 .55759 m .28797 .55768 L .28707 .55583 L F
.176 .028 .428 r
.28797 .55768 m .28623 .56036 L .28641 .55759 L F
.28797 .55768 m .28623 .56036 L .28641 .55759 L F
.718 .884 .958 r
.63089 .35759 m .63227 .35921 L .63598 .35715 L F
.701 .369 0 r
.58052 .37037 m .5807 .37126 L .5802 .3681 L F
.917 .539 .12 r
.58054 .37111 m .5807 .37126 L .58325 .37276 L F
.251 0 .313 r
.57633 .37223 m .57425 .37131 L .57787 .36956 L F
.57859 .36998 m .57787 .36956 L .58008 .3685 L F
.57633 .37223 m .57787 .36956 L .57859 .36998 L F
0 0 0 r
.5807 .37126 m .57633 .37223 L .58008 .3685 L F
.917 .539 .12 r
.58039 .37102 m .5807 .37126 L .58054 .37111 L F
.57858 .36992 m .57964 .37058 L .58039 .37102 L F
.57964 .37058 m .5807 .37126 L .58039 .37102 L F
.701 .369 0 r
.58052 .37037 m .58087 .37141 L .5807 .37126 L F
.58087 .37141 m .5813 .3727 L .5807 .37126 L F
.647 .968 .874 r
.32074 .6888 m .32467 .6869 L .32333 .68752 L F
.009 0 0 r
.32467 .6869 m .32805 .68485 L .32633 .68702 L F
.035 0 0 r
.32333 .68752 m .32467 .6869 L .32633 .68702 L F
.574 .085 .058 r
.65589 .33855 m .65856 .33901 L .65583 .3374 L F
.361 .801 .959 r
.60107 .34371 m .6038 .34328 L .60517 .34386 L F
.321 .737 .977 r
.6038 .34328 m .60787 .34415 L .60517 .34386 L F
.892 .74 .686 r
.4026 .53362 m .40158 .53723 L .40386 .53754 L F
.794 .352 .197 r
.40158 .53723 m .40226 .53915 L .40386 .53754 L F
.892 .74 .686 r
.4026 .53362 m .40158 .53723 L .40386 .53754 L F
.794 .352 .197 r
.40386 .53754 m .40226 .53915 L .40158 .53723 L F
.837 .459 .337 r
.34271 .51789 m .33909 .51868 L .33897 .51653 L F
.34271 .51789 m .34301 .52002 L .33909 .51868 L F
0 0 0 r
.42912 .46183 m .4298 .46166 L .42711 .46204 L F
.42912 .46183 m .43181 .46112 L .4298 .46166 L F
.899 .929 .827 r
.32247 .58368 m .32648 .58136 L .32427 .58005 L F
.982 .727 .33 r
.56837 .35561 m .56838 .35833 L .56949 .35717 L F
.937 .627 .172 r
.52067 .37589 m .52215 .37993 L .52331 .37763 L F
0 0 .359 r
.31919 .68552 m .3182 .68855 L .31999 .68561 L F
.495 .535 .827 r
.3182 .68855 m .32074 .6888 L .31999 .68561 L F
.075 0 .247 r
.57556 .35016 m .57743 .34934 L .5778 .34678 L F
.252 .255 .668 r
.57556 .35016 m .57804 .35205 L .57743 .34934 L F
.769 .386 .33 r
.53928 .42386 m .54287 .42726 L .5395 .42598 L F
.867 .945 .866 r
.59005 .4033 m .59384 .40158 L .59261 .40002 L F
.712 .808 .924 r
.59384 .40158 m .59632 .40029 L .59261 .40002 L F
.59384 .40158 m .59632 .40029 L .59261 .40002 L F
.832 .735 .757 r
.30802 .60484 m .30892 .60033 L .30611 .60332 L F
.78 .671 .743 r
.30611 .60332 m .30707 .60645 L .30802 .60484 L F
.684 .977 .813 r
.65226 .37458 m .65067 .37676 L .64943 .3755 L F
.65226 .37458 m .65407 .3742 L .65067 .37676 L F
.885 .645 .571 r
.32611 .52402 m .32479 .52659 L .32826 .52748 L F
.87 .646 .597 r
.32479 .52659 m .32802 .53023 L .32826 .52748 L F
.855 .643 .616 r
.32418 .5512 m .3207 .55251 L .32209 .55003 L F
.32418 .5512 m .32313 .55371 L .3207 .55251 L F
.953 .704 .523 r
.58802 .37384 m .58853 .377 L .58667 .37589 L F
.734 .761 .874 r
.44505 .5537 m .44926 .55422 L .44778 .55234 L F
.815 .84 .868 r
.44926 .55422 m .45041 .54969 L .44778 .55234 L F
.44926 .55422 m .45224 .55115 L .45041 .54969 L F
.413 .091 .307 r
.50142 .41008 m .50079 .41258 L .49799 .41334 L F
.217 .262 .695 r
.50062 .40709 m .50311 .40902 L .50142 .41008 L F
.275 0 .258 r
.50317 .4118 m .50142 .41008 L .50311 .40902 L F
.50317 .4118 m .50079 .41258 L .50142 .41008 L F
.485 .316 .576 r
.56139 .35058 m .56439 .35016 L .56347 .34747 L F
.968 .9 .536 r
.42092 .57054 m .41976 .57379 L .42051 .57431 L F
.904 .578 .093 r
.41976 .57379 m .422 .57976 L .42051 .57431 L F
.849 .715 .715 r
.29701 .64642 m .29717 .64953 L .29168 .65063 L F
.761 .43 .425 r
.29168 .65063 m .29717 .64953 L .29426 .65339 L F
.129 .056 .498 r
.29833 .65026 m .29717 .64953 L .29882 .6456 L F
.053 .085 .576 r
.29833 .65026 m .29717 .64953 L .29701 .64642 L F
.344 0 .137 r
.29426 .65339 m .29717 .64953 L .29833 .65026 L F
.699 .671 .819 r
.30292 .60468 m .30707 .60645 L .30611 .60332 L F
.845 .804 .811 r
.49359 .48612 m .48953 .48612 L .49184 .48326 L F
.935 .902 .767 r
.49359 .48612 m .48947 .48939 L .48953 .48612 L F
.49359 .48612 m .49092 .49062 L .48947 .48939 L F
.594 .662 .886 r
.49462 .48238 m .49359 .48612 L .49184 .48326 L F
.49462 .48238 m .49635 .48571 L .49359 .48612 L F
.493 .581 .872 r
.37574 .58429 m .37652 .58057 L .37527 .5799 L F
.788 .612 .662 r
.50459 .45697 m .50569 .46086 L .50154 .45979 L F
.672 .545 .702 r
.50836 .45847 m .50459 .45697 L .50928 .45577 L F
.50836 .45847 m .50569 .46086 L .50459 .45697 L F
.835 .544 .497 r
.34963 .52415 m .3469 .52371 L .34562 .52049 L F
.832 .529 .478 r
.34963 .52415 m .3468 .52613 L .3469 .52371 L F
.867 .595 .525 r
.34945 .5267 m .3468 .52613 L .34963 .52415 L F
.385 .409 .762 r
.27833 .66716 m .27988 .67257 L .28168 .6725 L F
.36 .134 .429 r
.28168 .6725 m .27988 .67257 L .28259 .67269 L F
.768 .988 .755 r
.50163 .40481 m .50062 .40709 L .50338 .40399 L F
.099 .254 .737 r
.50163 .40481 m .50311 .40902 L .50062 .40709 L F
.845 .711 .715 r
.32052 .55711 m .32197 .56087 L .31983 .55983 L F
.729 .505 .588 r
.32197 .56087 m .31795 .56381 L .31983 .55983 L F
.32197 .56087 m .32202 .56391 L .31795 .56381 L F
0 .15 .666 r
.50934 .45861 m .50836 .45847 L .50928 .45577 L F
.322 .122 .446 r
.57536 .38339 m .57444 .38668 L .57256 .38711 L F
.548 .433 .674 r
.57444 .38668 m .5729 .38944 L .57256 .38711 L F
.318 0 .137 r
.57271 .3704 m .5721 .37261 L .56837 .37291 L F
.073 0 .062 r
.57425 .37131 m .57271 .3704 L .57473 .36694 L F
.064 0 .331 r
.51327 .41981 m .51356 .41727 L .51508 .41608 L F
.627 .373 .513 r
.40002 .47492 m .40044 .47721 L .39764 .47693 L F
.76 .878 .458 r
.6561 .37023 m .65407 .3742 L .655 .37159 L F
.816 .999 .788 r
.655 .37159 m .65407 .3742 L .65226 .37458 L F
.974 .794 .372 r
.34779 .50955 m .3486 .51032 L .34884 .50743 L F
.842 .465 .337 r
.67043 .34654 m .67088 .34864 L .67235 .34692 L F
.848 .475 .343 r
.67088 .34864 m .67289 .34928 L .67235 .34692 L F
.611 .441 .627 r
.28004 .53054 m .28411 .53237 L .28308 .52703 L F
.659 .256 .27 r
.28041 .53226 m .28411 .53237 L .28004 .53054 L F
.871 .748 .724 r
.56276 .35699 m .56034 .3613 L .55882 .35914 L F
.56276 .35699 m .55882 .35914 L .56268 .35978 L F
.408 .19 .468 r
.56276 .35699 m .56552 .35607 L .56634 .35351 L F
.394 .177 .462 r
.56276 .35699 m .5656 .35842 L .56552 .35607 L F
.56276 .35699 m .56268 .35978 L .5656 .35842 L F
.285 .777 .72 r
.3891 .47539 m .3934 .47399 L .39122 .47571 L F
.791 .408 .33 r
.3934 .47399 m .39393 .47617 L .39122 .47571 L F
.789 .471 .452 r
.41074 .56286 m .4133 .56422 L .41238 .56088 L F
.875 .754 .725 r
.65483 .38562 m .65599 .38958 L .6565 .38712 L F
.887 .851 .801 r
.65483 .38562 m .6565 .38712 L .65882 .38343 L F
0 0 0 r
.61899 .39322 m .62053 .39089 L .62263 .39081 L F
.61899 .39322 m .61948 .39276 L .62053 .39089 L F
.044 0 0 r
.62175 .39441 m .61865 .39493 L .61899 .39322 L F
0 0 0 r
.61899 .39322 m .61865 .39493 L .61948 .39276 L F
.458 .887 .866 r
.62695 .39431 m .62796 .393 L .62511 .39345 L F
.62695 .39431 m .62923 .39324 L .62796 .393 L F
.997 .861 .554 r
.54048 .41388 m .53849 .41621 L .53714 .41485 L F
.54048 .41388 m .53993 .41669 L .53849 .41621 L F
.94 .852 .419 r
.65568 .36908 m .6561 .37023 L .655 .37159 L F
.981 .727 .471 r
.30428 .56061 m .3025 .56256 L .3023 .55929 L F
.553 .833 .998 r
.30494 .55842 m .30428 .56061 L .3023 .55929 L F
.30494 .55842 m .30737 .55979 L .30428 .56061 L F
.694 .174 0 r
.30428 .56061 m .30378 .5608 L .3025 .56256 L F
.30428 .56061 m .3063 .56334 L .30378 .5608 L F
.45 .169 .394 r
.30737 .55979 m .3063 .56334 L .30428 .56061 L F
.284 .562 .931 r
.30892 .60033 m .31076 .60172 L .31031 .60074 L F
.032 0 0 r
.42841 .45209 m .43218 .44961 L .4301 .4507 L F
0 0 0 r
.42601 .45309 m .42841 .45209 L .4301 .4507 L F
.579 .42 .63 r
.57821 .38265 m .57514 .38068 L .57734 .37865 L F
.57821 .38265 m .57536 .38339 L .57514 .38068 L F
.027 0 .065 r
.30889 .64746 m .30891 .64744 L .3088 .64708 L F
.637 .077 0 r
.30916 .64801 m .30891 .64744 L .3088 .64708 L F
0 0 .144 r
.30889 .64746 m .3088 .64708 L .3089 .64746 L F
.30889 .64746 m .3089 .64746 L .30906 .64808 L F
0 0 0 r
.31303 .64523 m .30891 .64745 L .3089 .64746 L F
.637 .077 0 r
.30916 .64801 m .30908 .64806 L .30891 .64744 L F
0 0 0 r
.30932 .64732 m .3089 .64746 L .30856 .64775 L F
.31303 .64523 m .3089 .64746 L .30932 .64732 L F
.30891 .64745 m .30889 .64746 L .30888 .64748 L F
.30891 .64745 m .30888 .64748 L .30856 .64775 L F
.637 .077 0 r
.31047 .64715 m .30916 .64801 L .30894 .64743 L F
.3094 .64711 m .30894 .64743 L .3088 .64708 L F
.31047 .64715 m .30894 .64743 L .3094 .64711 L F
.17 0 .166 r
.31303 .64523 m .31089 .6444 L .30891 .64744 L F
.30891 .64745 m .30891 .64744 L .30889 .64746 L F
.31303 .64523 m .30891 .64744 L .30891 .64745 L F
.027 0 .065 r
.30891 .64744 m .31089 .6444 L .3088 .64708 L F
.637 .077 0 r
.30908 .64806 m .30906 .64808 L .3088 .64708 L F
.946 .762 .299 r
.30809 .52247 m .30727 .51913 L .30826 .51996 L F
.30809 .52247 m .30691 .52172 L .30727 .51913 L F
.77 .856 .413 r
.30809 .52247 m .3067 .5243 L .30691 .52172 L F
.30809 .52247 m .30614 .5265 L .3067 .5243 L F
0 0 0 r
.26218 .58352 m .26144 .58466 L .26313 .58062 L F
.423 .864 .907 r
.26101 .585 m .26144 .58466 L .26218 .58352 L F
.26101 .585 m .25991 .58594 L .26144 .58466 L F
.31 0 .049 r
.41389 .47031 m .41225 .47256 L .40964 .47297 L F
.467 .114 .283 r
.41606 .4696 m .41225 .47256 L .41389 .47031 L F
0 0 .297 r
.25517 .57421 m .25606 .57556 L .25394 .5711 L F
.25517 .57421 m .25574 .57741 L .25606 .57556 L F
.728 .704 .828 r
.32957 .61447 m .33112 .61804 L .3268 .61739 L F
.791 .739 .805 r
.33187 .61327 m .33112 .61804 L .32957 .61447 L F
.33187 .61327 m .3339 .61489 L .33112 .61804 L F
0 0 0 r
.55031 .41384 m .55351 .4104 L .55347 .41264 L F
.332 .086 .383 r
.55555 .41106 m .55351 .4104 L .55549 .40915 L F
.55555 .41106 m .55347 .41264 L .55351 .4104 L F
.887 .851 .801 r
.65483 .38562 m .65882 .38343 L .65817 .38262 L F
.814 .998 .844 r
.65882 .38343 m .66111 .37981 L .65817 .38262 L F
.65882 .38343 m .66195 .38046 L .66111 .37981 L F
.742 .775 .88 r
.53766 .38875 m .53664 .38562 L .53657 .38708 L F
.792 .392 .296 r
.5709 .37571 m .57255 .37852 L .57441 .37657 L F
.647 .201 .179 r
.57441 .37657 m .57734 .37865 L .57685 .37713 L F
.57441 .37657 m .57255 .37852 L .57734 .37865 L F
.561 .857 .997 r
.56326 .36395 m .56358 .36271 L .56045 .36394 L F
.56471 .36396 m .56358 .36271 L .56045 .36394 L F
.459 .318 .602 r
.56045 .36394 m .56358 .36271 L .56268 .35978 L F
.13 0 0 r
.56045 .36394 m .56185 .36414 L .56358 .36271 L F
.386 .276 .605 r
.56268 .35978 m .56358 .36271 L .56473 .3613 L F
0 0 0 r
.56185 .36414 m .56368 .36233 L .56358 .36271 L F
.56368 .36233 m .56473 .3613 L .56358 .36271 L F
.561 .857 .997 r
.56471 .36396 m .56358 .36271 L .56326 .36395 L F
0 0 0 r
.53763 .40457 m .54009 .4043 L .54167 .40383 L F
.097 0 0 r
.54289 .4041 m .54167 .40383 L .54009 .4043 L F
.54289 .4041 m .54435 .404 L .54167 .40383 L F
.708 .549 .671 r
.28411 .53237 m .28549 .52492 L .28308 .52703 L F
0 0 0 r
.46908 .43438 m .46849 .43425 L .47064 .43253 L F
.46908 .43438 m .46685 .43566 L .46849 .43425 L F
.972 .909 .689 r
.56022 .37095 m .55793 .37201 L .5603 .36847 L F
.56022 .37095 m .55884 .37361 L .55793 .37201 L F
.974 .723 .492 r
.3737 .56922 m .37591 .56999 L .3755 .56753 L F
.749 .324 .241 r
.3755 .56753 m .37794 .57095 L .3737 .56922 L F
.769 .664 .747 r
.31657 .59008 m .3217 .58794 L .31966 .58704 L F
.31657 .59008 m .31876 .59149 L .3217 .58794 L F
.874 .883 .838 r
.32247 .58368 m .31966 .58704 L .3217 .58794 L F
.949 .857 .716 r
.55502 .42806 m .55691 .42976 L .55727 .42709 L F
.906 .879 .797 r
.5541 .43269 m .55691 .42976 L .55502 .42806 L F
.757 .882 .469 r
.34282 .63581 m .34413 .63425 L .34365 .63463 L F
.163 .38 .828 r
.34556 .63277 m .34413 .63425 L .34308 .63008 L F
.517 .836 .532 r
.34365 .63463 m .34413 .63425 L .34556 .63277 L F
.516 .011 0 r
.34811 .63494 m .34413 .63425 L .34505 .6373 L F
.901 .917 .822 r
.44139 .54562 m .44328 .54678 L .44011 .54975 L F
.925 .943 .792 r
.44396 .54126 m .44328 .54678 L .44139 .54562 L F
.44396 .54126 m .44632 .54172 L .44328 .54678 L F
.819 .791 .826 r
.5062 .41322 m .50638 .41716 L .50523 .41515 L F
.50612 .41124 m .50911 .41412 L .50638 .41716 L F
0 0 .016 r
.50638 .41716 m .50745 .41695 L .50523 .41515 L F
.626 .303 .403 r
.50523 .41515 m .50745 .41695 L .50402 .41752 L F
.50523 .41515 m .50402 .41752 L .50366 .41758 L F
.819 .791 .826 r
.50612 .41124 m .5062 .41322 L .50523 .41515 L F
0 0 .016 r
.50638 .41716 m .50573 .41952 L .50745 .41695 L F
.837 .497 .411 r
.3056 .64547 m .30565 .64408 L .30335 .64652 L F
.885 .953 .845 r
.30893 .65468 m .31089 .65594 L .30877 .65826 L F
0 .554 .779 r
.31154 .65576 m .31089 .65594 L .30893 .65468 L F
.31154 .65576 m .3145 .65633 L .31089 .65594 L F
.76 .535 .592 r
.39448 .54045 m .39487 .54373 L .39726 .54039 L F
0 0 0 r
.50361 .42925 m .50642 .42657 L .50164 .43018 L F
.221 0 0 r
.50769 .42648 m .50642 .42657 L .50361 .42925 L F
0 0 0 r
.59869 .39652 m .59632 .40029 L .59774 .39807 L F
.184 0 0 r
.59774 .39807 m .60176 .39557 L .59869 .39652 L F
.29 .614 .957 r
.31585 .65621 m .31512 .65775 L .3145 .65633 L F
.509 .04 .077 r
.31722 .65875 m .31801 .65802 L .31512 .65775 L F
.092 .365 .831 r
.31722 .65875 m .31512 .65775 L .31585 .65621 L F
.768 .832 .368 r
.37689 .57433 m .3771 .573 L .3777 .57171 L F
.752 .235 0 r
.3811 .57751 m .37689 .57433 L .37745 .57794 L F
.3811 .57751 m .37997 .57766 L .37689 .57433 L F
.3811 .57751 m .37997 .57766 L .37689 .57433 L F
0 0 .5 r
.37689 .57433 m .37825 .5757 L .3771 .573 L F
.727 .377 .386 r
.3771 .573 m .37825 .5757 L .37603 .57527 L F
.3771 .573 m .37603 .57527 L .37344 .57477 L F
.768 .832 .368 r
.3777 .57171 m .3771 .573 L .37794 .57095 L F
0 0 .5 r
.37689 .57433 m .37997 .57766 L .37825 .5757 L F
.548 .512 .767 r
.58638 .40349 m .58412 .407 L .5874 .40583 L F
.42 .19 .457 r
.5874 .40583 m .58412 .407 L .58374 .41011 L F
.653 .958 .759 r
.49867 .40008 m .50008 .39819 L .5021 .39736 L F
.655 .925 .635 r
.5021 .39736 m .50331 .39554 L .50511 .39422 L F
.667 .963 .76 r
.5021 .39736 m .50008 .39819 L .50331 .39554 L F
.524 .388 .638 r
.34238 .64061 m .34579 .64008 L .34505 .6373 L F
0 0 .556 r
.34343 .64034 m .34238 .64061 L .33998 .63924 L F
.989 .839 .603 r
.34404 .64222 m .34579 .64008 L .34238 .64061 L F
0 0 .556 r
.34343 .64034 m .34404 .64222 L .34238 .64061 L F
.32 .084 .391 r
.52665 .41399 m .52415 .41727 L .52567 .41589 L F
.655 .552 .726 r
.52567 .41589 m .52945 .41337 L .52665 .41399 L F
.696 .638 .787 r
.51614 .42828 m .51872 .42703 L .51475 .42607 L F
.222 0 .273 r
.27454 .53728 m .27641 .53662 L .27739 .53379 L F
.239 0 .281 r
.27739 .53379 m .27891 .53563 L .28041 .53226 L F
.27739 .53379 m .27641 .53662 L .27891 .53563 L F
.48 .852 .987 r
.33897 .62778 m .34323 .62756 L .34178 .62491 L F
.34323 .62756 m .33897 .62778 L .34226 .62983 L F
.148 .39 .84 r
.34323 .62756 m .34415 .626 L .34178 .62491 L F
0 0 0 r
.34323 .62756 m .34226 .62983 L .34415 .626 L F
.243 .752 .873 r
.60787 .34415 m .61003 .34362 L .61192 .34402 L F
.391 .816 .966 r
.61003 .34362 m .61487 .34402 L .61192 .34402 L F
.317 0 .134 r
.41066 .4625 m .41399 .46029 L .41128 .46095 L F
.871 .983 .838 r
.48365 .5151 m .48314 .51762 L .48604 .51435 L F
.874 .985 .83 r
.48198 .51684 m .48314 .51762 L .48365 .5151 L F
.63 .829 .977 r
.31424 .59081 m .31377 .58831 L .31199 .58724 L F
.31424 .59081 m .31657 .59008 L .31377 .58831 L F
.828 .794 .82 r
.31397 .59348 m .31657 .59008 L .31424 .59081 L F
.939 .623 .175 r
.34857 .62583 m .3503 .62766 L .34879 .62373 L F
.006 0 .367 r
.24984 .59334 m .25087 .59335 L .25103 .59048 L F
.234 0 0 r
.24626 .59559 m .25087 .59335 L .24984 .59334 L F
0 0 .345 r
.39886 .46754 m .4002 .46904 L .4014 .46688 L F
.694 .729 .877 r
.49995 .48666 m .49635 .48571 L .4988 .48372 L F
.712 .781 .906 r
.50313 .48435 m .49995 .48666 L .4988 .48372 L F
0 0 .094 r
.30129 .56966 m .30034 .57425 L .30152 .5734 L F
.30075 .57227 m .30066 .57344 L .30034 .57425 L F
.30109 .57233 m .30109 .57242 L .30064 .57353 L F
.52 .814 .999 r
.30152 .5734 m .30034 .57425 L .30066 .57344 L F
0 0 .094 r
.30064 .5735 m .30064 .57353 L .30034 .57425 L F
.30109 .57233 m .30064 .57353 L .30064 .5735 L F
.449 0 .077 r
.2979 .5754 m .29886 .57639 L .29579 .57639 L F
.30034 .57425 m .29886 .57639 L .2979 .5754 L F
.577 .009 0 r
.29886 .57639 m .30062 .57802 L .29996 .57753 L F
.52 .814 .999 r
.30066 .57344 m .30034 .57425 L .29596 .57364 L F
.882 .855 .811 r
.30064 .57353 m .30033 .57402 L .30034 .57425 L F
.449 0 .077 r
.30034 .57425 m .29579 .57639 L .29596 .57364 L F
.882 .855 .811 r
.30033 .57402 m .29886 .57639 L .29924 .57583 L F
.30033 .57402 m .29924 .57583 L .30034 .57425 L F
.546 .23 .383 r
.29579 .57639 m .30033 .57402 L .29596 .57364 L F
.30033 .57402 m .30063 .57386 L .30043 .57385 L F
.30033 .57402 m .30043 .57385 L .29596 .57364 L F
.29991 .5747 m .29886 .57639 L .30061 .57441 L F
.29579 .57639 m .29886 .57639 L .29991 .5747 L F
.29579 .57639 m .30061 .57441 L .30063 .57386 L F
.30043 .57385 m .30066 .57344 L .29596 .57364 L F
.882 .855 .811 r
.30066 .57348 m .30033 .57402 L .30064 .57353 L F
.546 .23 .383 r
.30063 .57386 m .30066 .57348 L .30043 .57385 L F
.30066 .57348 m .30066 .57344 L .30043 .57385 L F
0 0 .094 r
.30129 .56966 m .30109 .57233 L .30066 .57344 L F
.30129 .56966 m .30066 .57344 L .30075 .57227 L F
.882 .855 .811 r
.30109 .57242 m .29886 .57639 L .30033 .57402 L F
.30109 .57242 m .30033 .57402 L .30066 .57348 L F
.577 .009 0 r
.29886 .57639 m .29996 .57753 L .29755 .57576 L F
.546 .23 .383 r
.30063 .57386 m .30061 .57441 L .30152 .5734 L F
.30063 .57386 m .30152 .5734 L .30066 .57344 L F
.873 .994 .763 r
.31428 .57364 m .31039 .57872 L .31126 .57561 L F
.665 .953 .721 r
.31428 .57364 m .31474 .57236 L .31543 .57321 L F
.31428 .57364 m .31126 .57561 L .31474 .57236 L F
0 0 0 r
.49587 .403 m .49795 .40217 L .49867 .40008 L F
.49587 .403 m .49553 .40356 L .49795 .40217 L F
.939 .694 .542 r
.28841 .52343 m .28817 .5265 L .29073 .52734 L F
0 0 .559 r
.29072 .52554 m .29073 .52734 L .28817 .5265 L F
.29072 .52554 m .29235 .52954 L .29073 .52734 L F
.742 .804 .901 r
.6517 .39458 m .65368 .39295 L .64982 .39261 L F
.6 .552 .773 r
.54768 .40456 m .54576 .40705 L .54921 .40518 L F
.835 .995 .753 r
.54336 .40836 m .54576 .40705 L .54642 .40469 L F
.888 .562 .425 r
.34562 .52049 m .34338 .52242 L .34301 .52002 L F
.34562 .52049 m .3469 .52371 L .34338 .52242 L F
.839 .63 .621 r
.3593 .53758 m .3551 .53955 L .3567 .53649 L F
.3593 .53758 m .35867 .54035 L .3551 .53955 L F
.363 .041 .279 r
.37745 .57794 m .37997 .57766 L .3811 .57751 L F
.553 .931 .824 r
.38235 .57615 m .37997 .57766 L .3811 .57751 L F
.3811 .57751 m .37997 .57766 L .38235 .57615 L F
.906 .863 .787 r
.65603 .35354 m .65201 .35561 L .65176 .35353 L F
.65603 .35354 m .65371 .35715 L .65201 .35561 L F
.646 .847 .977 r
.29235 .52954 m .29425 .53106 L .29043 .5309 L F
.29043 .5309 m .29425 .53106 L .29235 .52954 L F
.796 .881 .908 r
.29672 .52852 m .29425 .53106 L .29235 .52954 L F
.29672 .52852 m .29425 .53106 L .29235 .52954 L F
.29672 .52852 m .29235 .52954 L .29487 .52883 L F
.459 .72 .981 r
.29425 .53106 m .29487 .52883 L .29235 .52954 L F
.29425 .53106 m .29736 .53095 L .29487 .52883 L F
.706 .964 .94 r
.66328 .3781 m .66195 .38046 L .66423 .37881 L F
.726 .984 .901 r
.66111 .37981 m .66195 .38046 L .66328 .3781 L F
.429 .835 .643 r
.46937 .42376 m .46538 .42623 L .46737 .42467 L F
.635 .899 .581 r
.47061 .42195 m .47228 .42051 L .46937 .42376 L F
.66 .957 .743 r
.47061 .42195 m .46937 .42376 L .46737 .42467 L F
.816 .922 .907 r
.50369 .49509 m .50516 .49617 L .5084 .49345 L F
0 0 0 r
.50511 .39422 m .50571 .39422 L .50673 .3925 L F
.50511 .39422 m .50331 .39554 L .50571 .39422 L F
.761 .755 .847 r
.32424 .61856 m .32001 .62034 L .32247 .61684 L F
.703 .768 .902 r
.32247 .61684 m .3268 .61739 L .32424 .61856 L F
0 0 0 r
.49867 .40008 m .49795 .40217 L .50008 .39819 L F
.828 .794 .82 r
.31397 .59348 m .31876 .59149 L .31657 .59008 L F
.623 .391 .545 r
.33281 .64371 m .33633 .64449 L .33543 .641 L F
.829 .983 .702 r
.31458 .64602 m .31483 .6471 L .31529 .64502 L F
.992 .747 .449 r
.31501 .64785 m .31483 .6471 L .31201 .64824 L F
.444 .876 .908 r
.30906 .64808 m .31201 .64824 L .31483 .6471 L F
.30906 .64808 m .31483 .6471 L .31266 .64869 L F
.829 .983 .702 r
.31266 .64869 m .31483 .6471 L .31458 .64602 L F
.992 .747 .449 r
.31633 .64768 m .31483 .6471 L .31501 .64785 L F
.31633 .64768 m .31621 .65058 L .31483 .6471 L F
.544 .308 .508 r
.3187 .65015 m .31633 .64768 L .31621 .65058 L F
.3187 .65015 m .31853 .64726 L .31633 .64768 L F
.424 .84 .965 r
.31633 .64768 m .31853 .64726 L .31483 .6471 L F
.897 .825 .769 r
.38208 .5537 m .38673 .55138 L .3835 .5507 L F
.548 .124 .189 r
.38907 .54984 m .3835 .5507 L .38673 .55138 L F
.501 .165 .329 r
.58008 .3685 m .57425 .37131 L .57473 .36694 L F
.58008 .3685 m .57839 .36801 L .57666 .36824 L F
0 0 0 r
.57666 .36824 m .57537 .36879 L .57589 .36859 L F
.501 .165 .329 r
.57839 .36801 m .57765 .36779 L .57666 .36824 L F
.837 .544 .493 r
.5802 .3681 m .57666 .36824 L .57983 .36706 L F
0 0 0 r
.57666 .36824 m .57589 .36859 L .57805 .36776 L F
.501 .165 .329 r
.57765 .36779 m .57473 .36694 L .57666 .36824 L F
.965 .648 .361 r
.57442 .36652 m .57522 .36843 L .57666 .36824 L F
.57522 .36843 m .57537 .36879 L .57666 .36824 L F
0 .058 .604 r
.57398 .36559 m .57666 .36824 L .57473 .36694 L F
.856 .784 .78 r
.54565 .45077 m .54809 .44735 L .54609 .44575 L F
.798 .918 .919 r
.51636 .48538 m .52096 .48409 L .51921 .48256 L F
.845 .839 .839 r
.51921 .48256 m .52096 .48409 L .52389 .48094 L F
.534 .865 .591 r
.47533 .41777 m .47228 .42051 L .47387 .419 L F
.509 .84 .55 r
.47387 .419 m .47228 .42051 L .47061 .42195 L F
.883 .968 .841 r
.31853 .64726 m .3198 .64638 L .31854 .64369 L F
.638 .356 .474 r
.3187 .65015 m .3198 .64638 L .31853 .64726 L F
.183 .552 .931 r
.31854 .64369 m .3198 .64638 L .32258 .6453 L F
0 0 .393 r
.3198 .64638 m .32139 .64786 L .32258 .6453 L F
0 .55 .816 r
.31521 .64167 m .31754 .64242 L .31145 .64133 L F
.31521 .64167 m .31145 .64133 L .3133 .64303 L F
1 .822 .509 r
.5885 .41311 m .58918 .41059 L .5876 .4091 L F
.607 .894 .989 r
.51988 .42219 m .5201 .42334 L .51796 .4234 L F
.824 .693 .72 r
.51796 .4234 m .51872 .42703 L .5201 .42334 L F
.376 .457 .816 r
.50809 .44812 m .50646 .45193 L .50498 .45189 L F
.50809 .44812 m .51033 .45272 L .50646 .45193 L F
.276 .199 .586 r
.56347 .34747 m .56439 .35016 L .56529 .34852 L F
.87 .963 .858 r
.48623 .51171 m .48604 .51435 L .48898 .5111 L F
.891 .973 .825 r
.48623 .51171 m .48365 .5151 L .48604 .51435 L F
0 0 .163 r
.25727 .56431 m .25727 .56603 L .25776 .56221 L F
.25727 .56431 m .25669 .5672 L .25727 .56603 L F
.682 .66 .822 r
.52366 .36979 m .52098 .37104 L .51955 .36865 L F
.446 .224 .482 r
.60336 .37217 m .60053 .37023 L .60307 .36918 L F
.60336 .37217 m .6004 .3732 L .60053 .37023 L F
.896 .962 .827 r
.30872 .58114 m .30741 .58004 L .30971 .57948 L F
.717 .651 .095 r
.3082 .58075 m .30971 .57948 L .30741 .58004 L F
.896 .962 .827 r
.30872 .58114 m .30971 .57948 L .31008 .57917 L F
.327 .743 .977 r
.30815 .58103 m .30741 .58004 L .30872 .58114 L F
.30423 .58024 m .30741 .58004 L .30815 .58103 L F
.385 .547 .892 r
.30729 .57792 m .30741 .58004 L .30527 .57719 L F
.617 .533 .737 r
.30729 .57792 m .30695 .57943 L .30741 .58004 L F
.327 .743 .977 r
.30423 .58024 m .30741 .58004 L .30872 .58114 L F
.826 .955 .9 r
.30423 .58024 m .30527 .57719 L .30741 .58004 L F
.705 .289 .255 r
.30636 .58202 m .30423 .58024 L .30741 .58004 L F
.617 .533 .737 r
.30695 .57943 m .30636 .58202 L .30741 .58004 L F
.717 .651 .095 r
.30942 .58185 m .30741 .58004 L .30872 .58114 L F
.30942 .58185 m .30971 .57948 L .3082 .58075 L F
.896 .962 .827 r
.31008 .57917 m .30971 .57948 L .31039 .57872 L F
0 0 0 r
.30971 .57948 m .31126 .57561 L .31039 .57872 L F
.878 .647 .585 r
.36059 .54413 m .36031 .54692 L .35817 .54333 L F
0 .166 .626 r
.39086 .59135 m .39116 .59136 L .391 .59115 L F
.57 0 0 r
.39465 .59292 m .39342 .59313 L .39086 .59135 L F
0 .166 .626 r
.39086 .59135 m .39342 .59313 L .39116 .59136 L F
.47 0 0 r
.32941 .63641 m .32736 .63523 L .32516 .63612 L F
.767 .679 .131 r
.5662 .41197 m .56611 .41433 L .56645 .41065 L F
.844 .709 .713 r
.56249 .41578 m .56611 .41433 L .5662 .41197 L F
.56249 .41578 m .56499 .41677 L .56611 .41433 L F
.68 .895 .975 r
.36864 .57369 m .37037 .57468 L .37136 .57197 L F
.738 .899 .951 r
.30389 .63952 m .30658 .638 L .30441 .63606 L F
.30658 .638 m .30873 .63679 L .30691 .63648 L F
.30658 .638 m .30691 .63648 L .30441 .63606 L F
.283 .758 .934 r
.30702 .63632 m .30873 .63679 L .30896 .63652 L F
.30441 .63606 m .30691 .63648 L .30702 .63632 L F
.30691 .63648 m .30873 .63679 L .30702 .63632 L F
.754 .546 .614 r
.3111 .63559 m .30727 .63302 L .30896 .63652 L F
.593 .596 .824 r
.3111 .63559 m .30896 .63652 L .30727 .63302 L F
0 0 .13 r
.30756 .63349 m .30721 .63602 L .30783 .63391 L F
.738 .299 .209 r
.30441 .63606 m .30896 .63652 L .30676 .63831 L F
0 0 .13 r
.30721 .63602 m .30708 .637 L .30738 .63578 L F
.30721 .63602 m .30738 .63578 L .30783 .63391 L F
.30727 .63302 m .30716 .63534 L .30756 .63349 L F
.30716 .63534 m .30708 .637 L .30756 .63349 L F
.738 .899 .951 r
.30389 .63952 m .30441 .63606 L .30507 .63911 L F
0 0 0 r
.30231 .64103 m .30389 .63952 L .30507 .63911 L F
.278 .033 .351 r
.27432 .5396 m .27641 .53662 L .27454 .53728 L F
.732 .769 .882 r
.30334 .62634 m .30532 .6278 L .30087 .6275 L F
.821 .761 .796 r
.30781 .62451 m .30532 .6278 L .30334 .62634 L F
.424 .191 .455 r
.5429 .38544 m .54122 .38662 L .54367 .3835 L F
.448 .74 .99 r
.54265 .38209 m .54574 .38195 L .54367 .3835 L F
0 0 0 r
.54434 .38342 m .54367 .3835 L .54574 .38195 L F
.54434 .38342 m .5429 .38544 L .54367 .3835 L F
.791 .527 .538 r
.31831 .52004 m .32267 .52333 L .32283 .52062 L F
.911 .88 .792 r
.55727 .42709 m .55971 .42347 L .55816 .42198 L F
.792 .882 .912 r
.55816 .42198 m .55971 .42347 L .56328 .42035 L F
0 0 .466 r
.24748 .60411 m .24884 .60665 L .24961 .60336 L F
0 0 .366 r
.24884 .60665 m .24748 .60411 L .24961 .60336 L F
.845 .839 .839 r
.51921 .48256 m .52389 .48094 L .52225 .47952 L F
.755 .892 .94 r
.52225 .47952 m .52389 .48094 L .52594 .47887 L F
.495 .405 .683 r
.38182 .47575 m .38497 .47361 L .38233 .47352 L F
.469 0 0 r
.383 .47684 m .38182 .47575 L .38041 .47711 L F
.297 0 0 r
.38008 .5833 m .38524 .5808 L .38335 .57963 L F
.38008 .5833 m .38334 .58332 L .38524 .5808 L F
.536 .648 .907 r
.38524 .5808 m .38797 .58038 L .3869 .57715 L F
.058 0 0 r
.38524 .5808 m .38625 .58189 L .38797 .58038 L F
.38524 .5808 m .38334 .58332 L .38625 .58189 L F
.917 .971 .783 r
.48806 .49384 m .48947 .48939 L .49092 .49062 L F
.48806 .49384 m .48704 .49304 L .48947 .48939 L F
.144 .241 .706 r
.57749 .36396 m .5799 .36611 L .57899 .36151 L F
.722 .741 .866 r
.33187 .61327 m .33641 .61377 L .3339 .61489 L F
.661 .607 .783 r
.58296 .41739 m .58538 .41599 L .58483 .41173 L F
.096 0 .187 r
.51865 .37719 m .51798 .3793 L .52067 .37589 L F
.849 .715 .715 r
.29701 .64642 m .29168 .65063 L .29565 .64732 L F
.053 .085 .576 r
.29833 .65026 m .29701 .64642 L .29882 .6456 L F
.767 .679 .131 r
.5662 .41197 m .56645 .41065 L .56678 .40951 L F
0 0 .067 r
.28085 .6365 m .2796 .63792 L .28148 .63648 L F
0 0 0 r
.2796 .63792 m .28008 .63907 L .28148 .63648 L F
.819 .875 .887 r
.31873 .6172 m .32001 .62034 L .31754 .62124 L F
.821 .876 .885 r
.32247 .61684 m .32001 .62034 L .31873 .6172 L F
.941 .603 .357 r
.67289 .34928 m .67445 .35286 L .67604 .35332 L F
.981 .905 .584 r
.67409 .35485 m .67604 .35332 L .67445 .35286 L F
.67409 .35485 m .67486 .35688 L .67604 .35332 L F
.822 .84 .862 r
.45041 .54969 m .45427 .54982 L .45357 .54688 L F
.45041 .54969 m .45224 .55115 L .45427 .54982 L F
.84 .885 .874 r
.45357 .54688 m .45427 .54982 L .45711 .54657 L F
.149 0 .272 r
.5778 .34678 m .57961 .3479 L .57872 .34588 L F
.5778 .34678 m .57743 .34934 L .57961 .3479 L F
0 0 .135 r
.56634 .35351 m .56664 .3505 L .56529 .34852 L F
.56634 .35351 m .56638 .354 L .56664 .3505 L F
.434 0 0 r
.62035 .3502 m .61924 .35162 L .61629 .35144 L F
0 0 0 r
.62173 .35048 m .61924 .35162 L .62035 .3502 L F
0 0 .008 r
.35817 .64313 m .35809 .6471 L .3576 .64398 L F
.732 .986 .897 r
.62263 .39081 m .62053 .39089 L .62385 .38853 L F
.366 .832 .778 r
.39704 .59178 m .39465 .59292 L .39763 .59295 L F
.39704 .59178 m .39342 .59313 L .39465 .59292 L F
.982 .837 .623 r
.52846 .44776 m .52625 .44939 L .52791 .44566 L F
.52846 .44776 m .52779 .45051 L .52625 .44939 L F
.99 .76 .495 r
.58853 .377 m .58649 .37809 L .58667 .37589 L F
.58853 .377 m .58808 .3795 L .58649 .37809 L F
.617 .802 .377 r
.50787 .40722 m .50836 .40632 L .50883 .40494 L F
.50787 .40722 m .50651 .40946 L .50836 .40632 L F
.704 .913 .564 r
.43568 .56572 m .43476 .56761 L .43723 .5642 L F
.696 .716 .194 r
.43465 .56787 m .43476 .56761 L .43568 .56572 L F
.43465 .56787 m .43409 .57009 L .43476 .56761 L F
.555 .124 .176 r
.3843 .53583 m .38723 .5362 L .38897 .53393 L F
.3843 .53583 m .38897 .53393 L .38807 .53514 L F
.889 .514 .322 r
.38538 .53022 m .38807 .53514 L .38897 .53393 L F
.717 .472 .555 r
.38723 .5362 m .39123 .53317 L .38897 .53393 L F
.825 .631 .641 r
.31439 .53052 m .31594 .53432 L .31392 .53341 L F
.938 .571 .188 r
.31564 .53681 m .31392 .53341 L .31594 .53432 L F
.984 .791 .564 r
.52415 .41727 m .52407 .42017 L .52291 .41798 L F
.821 .761 .796 r
.30781 .62451 m .30334 .62634 L .30648 .62439 L F
.574 .853 .996 r
.30848 .62267 m .30781 .62451 L .30648 .62439 L F
.30848 .62267 m .31031 .62374 L .30781 .62451 L F
.6 .842 .472 r
.59785 .37429 m .59669 .37569 L .59565 .37715 L F
0 0 .403 r
.59669 .37569 m .59561 .37846 L .59565 .37715 L F
.89 .746 .696 r
.36408 .56708 m .36083 .56659 L .36263 .56313 L F
.909 .747 .67 r
.36408 .56708 m .36016 .56936 L .36083 .56659 L F
.36408 .56708 m .36234 .5705 L .36016 .56936 L F
.837 .726 .742 r
.36492 .56442 m .36408 .56708 L .36263 .56313 L F
.316 0 0 r
.33831 .63797 m .33608 .63916 L .33415 .63877 L F
.517 0 0 r
.33998 .63924 m .33608 .63916 L .33831 .63797 L F
0 0 0 r
.55266 .40695 m .55143 .40872 L .5525 .4085 L F
0 .453 .832 r
.54921 .40518 m .55266 .40695 L .5525 .4085 L F
.846 .639 .622 r
.31392 .53341 m .31343 .53086 L .31439 .53052 L F
.255 .537 .921 r
.34484 .61722 m .34041 .61494 L .34292 .61665 L F
.831 .742 .766 r
.34292 .61665 m .34731 .61693 L .34484 .61722 L F
.84 .656 .654 r
.34536 .61976 m .34731 .61693 L .34292 .61665 L F
.652 .676 .86 r
.33964 .61264 m .34041 .61494 L .33641 .61377 L F
.275 .425 .831 r
.34147 .61268 m .34041 .61494 L .33964 .61264 L F
.45 0 0 r
.34096 .61554 m .34292 .61665 L .34041 .61494 L F
.34096 .61554 m .34041 .61494 L .34147 .61268 L F
.434 .835 .978 r
.61487 .34402 m .61788 .34334 L .61905 .34409 L F
.533 .887 .98 r
.61905 .34409 m .62076 .34229 L .62173 .3432 L F
.61905 .34409 m .61788 .34334 L .62076 .34229 L F
.876 .574 .473 r
.3524 .63361 m .35508 .63384 L .35433 .63101 L F
.74 .966 .691 r
.52176 .44054 m .52468 .43734 L .52286 .43837 L F
.793 .976 .689 r
.52286 .43837 m .52468 .43734 L .52551 .43491 L F
0 0 0 r
.44151 .45415 m .44097 .45366 L .44349 .45276 L F
.44151 .45415 m .43951 .45537 L .44097 .45366 L F
0 .15 .666 r
.50934 .45861 m .51036 .46003 L .50836 .45847 L F
.765 .483 .507 r
.25313 .59521 m .24855 .59822 L .24929 .59705 L F
.811 .544 .535 r
.32267 .52333 m .32479 .52659 L .32611 .52402 L F
.1 0 .099 r
.52531 .42932 m .52581 .42799 L .52307 .43025 L F
.327 .235 .596 r
.52531 .42932 m .52307 .43025 L .52548 .43215 L F
0 0 .335 r
.28242 .54635 m .28234 .55049 L .28035 .54894 L F
.649 .935 .968 r
.29932 .62694 m .29847 .62876 L .29599 .62916 L F
.29932 .62694 m .30087 .6275 L .29847 .62876 L F
.826 .686 .708 r
.36314 .56039 m .36492 .56442 L .36263 .56313 L F
.431 .136 .362 r
.49896 .4333 m .50195 .43232 L .50164 .43018 L F
.812 .73 .774 r
.50195 .43232 m .50361 .42925 L .50164 .43018 L F
.403 .129 .381 r
.52123 .40685 m .52083 .40909 L .51828 .40997 L F
.639 .631 .826 r
.52413 .40604 m .52123 .40685 L .51968 .40277 L F
.496 .209 .408 r
.52413 .40604 m .52083 .40909 L .52123 .40685 L F
0 0 .081 r
.27255 .56032 m .27173 .56346 L .27072 .56447 L F
0 0 0 r
.27173 .56346 m .26965 .56672 L .27072 .56447 L F
.014 0 .16 r
.26503 .57926 m .26218 .58352 L .26313 .58062 L F
.897 .712 .643 r
.36276 .55104 m .35941 .5527 L .36016 .5498 L F
.36276 .55104 m .36185 .55367 L .35941 .5527 L F
.34 .733 .984 r
.27612 .65039 m .27536 .65136 L .2734 .65025 L F
.769 .908 .52 r
.32633 .68702 m .32805 .68485 L .32914 .68275 L F
.421 .835 .969 r
.25321 .59039 m .25349 .58988 L .25103 .59048 L F
.25474 .59032 m .25349 .58988 L .25103 .59048 L F
.547 .572 .832 r
.25103 .59048 m .25349 .58988 L .25182 .58599 L F
.421 .835 .969 r
.25474 .59032 m .25349 .58988 L .25321 .59039 L F
.553 .573 .829 r
.25516 .59378 m .25103 .59048 L .25349 .58988 L F
.625 .858 .49 r
.25087 .59335 m .25349 .58988 L .25103 .59048 L F
.629 .842 .452 r
.25349 .58988 m .25608 .58615 L .25182 .58599 L F
.634 .862 .493 r
.25349 .58988 m .2518 .59186 L .25412 .58875 L F
.25349 .58988 m .25412 .58875 L .25424 .58858 L F
.479 .865 .976 r
.25672 .58907 m .25349 .58988 L .25474 .59032 L F
0 0 0 r
.51727 .41182 m .51577 .4136 L .51828 .40997 L F
.51543 .41508 m .51577 .4136 L .51727 .41182 L F
.51543 .41508 m .51508 .41608 L .51577 .4136 L F
.686 .98 .838 r
.31312 .6842 m .31603 .68248 L .31509 .6834 L F
.505 .542 .828 r
.31603 .68248 m .31919 .68552 L .3205 .68365 L F
.5 0 0 r
.31603 .68248 m .3205 .68365 L .31509 .6834 L F
.296 0 .033 r
.54122 .38662 m .54015 .38867 L .53766 .38875 L F
0 0 0 r
.5419 .38678 m .54122 .38662 L .5429 .38544 L F
.5419 .38678 m .54015 .38867 L .54122 .38662 L F
.737 .474 .532 r
.31037 .51841 m .31668 .51723 L .31149 .51685 L F
.31037 .51841 m .31688 .51936 L .31668 .51723 L F
.757 .489 .528 r
.31688 .51936 m .31831 .52004 L .31668 .51723 L F
.534 .328 .547 r
.28549 .52492 m .28841 .52343 L .28585 .52406 L F
.888 .715 .662 r
.50272 .46687 m .49938 .46658 L .50083 .4629 L F
.874 .839 .808 r
.50272 .46687 m .49815 .46877 L .49938 .46658 L F
.50272 .46687 m .50008 .47028 L .49815 .46877 L F
.674 .516 .663 r
.50272 .46687 m .50293 .4702 L .50008 .47028 L F
.638 .434 .59 r
.50662 .46713 m .50293 .4702 L .50272 .46687 L F
.745 .246 0 r
.42777 .57794 m .42906 .57986 L .43051 .58076 L F
.863 .838 .82 r
.65261 .35914 m .65201 .35561 L .65371 .35715 L F
.157 0 .081 r
.37551 .52067 m .37201 .52367 L .37374 .52289 L F
.439 .409 .729 r
.37374 .52289 m .37626 .52675 L .37515 .52632 L F
0 0 .557 r
.37422 .5229 m .37374 .52289 L .37201 .52367 L F
.967 .795 .363 r
.33684 .51004 m .33605 .50887 L .33711 .50707 L F
0 0 0 r
.33711 .50707 m .33889 .5064 L .33995 .50519 L F
.33711 .50707 m .33853 .50763 L .33889 .5064 L F
.33711 .50707 m .33605 .50887 L .33853 .50763 L F
.7 .858 .445 r
.3299 .63944 m .32921 .64089 L .33018 .63934 L F
.119 0 0 r
.33415 .63877 m .3299 .63944 L .33018 .63934 L F
.856 .784 .78 r
.54565 .45077 m .54609 .44575 L .54369 .44942 L F
.908 .798 .728 r
.54369 .44942 m .54467 .45338 L .54565 .45077 L F
.606 .552 .768 r
.26985 .5711 m .26872 .57403 L .26787 .57268 L F
.046 0 .086 r
.26985 .5711 m .267 .57575 L .26872 .57403 L F
0 .295 .792 r
.28558 .64657 m .28745 .64944 L .28479 .64757 L F
0 .287 .776 r
.28889 .65111 m .28479 .64757 L .28745 .64944 L F
.439 .829 .985 r
.63117 .34086 m .63462 .34149 L .63243 .34184 L F
.091 .649 .743 r
.63338 .39296 m .63189 .39301 L .62923 .39324 L F
0 .548 .762 r
.63614 .39361 m .63189 .39301 L .63338 .39296 L F
.504 .904 .789 r
.63743 .38042 m .63397 .38184 L .63579 .38194 L F
0 0 0 r
.63997 .37929 m .63743 .38042 L .63579 .38194 L F
.956 .947 .711 r
.42765 .56747 m .42493 .56882 L .42591 .56624 L F
.42765 .56747 m .42589 .57116 L .42493 .56882 L F
.876 .893 .842 r
.43036 .56427 m .42765 .56747 L .42591 .56624 L F
.707 .62 .758 r
.51475 .42607 m .51872 .42703 L .51796 .4234 L F
.762 .659 .748 r
.30611 .60332 m .30892 .60033 L .30606 .60097 L F
.284 .562 .931 r
.30892 .60033 m .31031 .60074 L .31134 .59711 L F
.98 .915 .641 r
.53849 .41621 m .53993 .41669 L .53842 .42025 L F
.863 .838 .82 r
.65261 .35914 m .64941 .35885 L .65201 .35561 L F
.856 .641 .61 r
.65261 .35914 m .64906 .36134 L .64941 .35885 L F
.65261 .35914 m .65151 .36283 L .64906 .36134 L F
.544 .814 .996 r
.60738 .394 m .606 .39613 L .60455 .39458 L F
.60738 .394 m .6089 .39542 L .606 .39613 L F
.294 .791 .836 r
.606 .39613 m .6067 .39542 L .6044 .39683 L F
.606 .39613 m .6089 .39542 L .6067 .39542 L F
.883 .929 .846 r
.48755 .50984 m .48898 .5111 L .49163 .5079 L F
.911 .924 .811 r
.48623 .51171 m .48898 .5111 L .48755 .50984 L F
.353 .179 .501 r
.40759 .57072 m .40968 .56998 L .4097 .56713 L F
0 0 .243 r
.40759 .57072 m .40856 .57148 L .40968 .56998 L F
.532 .829 .5 r
.41028 .56929 m .40798 .57173 L .41029 .56928 L F
.40968 .56998 m .40895 .57073 L .41028 .56929 L F
.40895 .57073 m .40798 .57173 L .41028 .56929 L F
0 0 .243 r
.40839 .57135 m .40702 .57377 L .40856 .57148 L F
.40759 .57072 m .40724 .5726 L .40839 .57135 L F
.40724 .5726 m .40702 .57377 L .40839 .57135 L F
.532 .355 .587 r
.42891 .57397 m .42777 .57794 L .4264 .57821 L F
.067 0 .348 r
.43055 .57581 m .42891 .57397 L .43155 .57345 L F
.43055 .57581 m .42777 .57794 L .42891 .57397 L F
0 0 0 r
.59876 .37374 m .59785 .37429 L .6004 .3732 L F
.59876 .37374 m .59669 .37569 L .59785 .37429 L F
.732 .232 .041 r
.30781 .5306 m .30613 .53162 L .30416 .5295 L F
.913 .525 .255 r
.30781 .5306 m .30765 .53236 L .30613 .53162 L F
.71 .389 .431 r
.31343 .53086 m .30765 .53236 L .30781 .5306 L F
.606 .552 .768 r
.26985 .5711 m .26787 .57268 L .26969 .56949 L F
.481 .856 .984 r
.62173 .3432 m .6246 .34239 L .6257 .34316 L F
.597 .846 .992 r
.62839 .34216 m .6257 .34316 L .62715 .34086 L F
.676 .944 .961 r
.6257 .34316 m .6246 .34239 L .62715 .34086 L F
0 0 0 r
.55456 .40077 m .55691 .39924 L .5564 .39961 L F
.5564 .39961 m .55691 .39924 L .5589 .39726 L F
.745 .769 .873 r
.60712 .36982 m .60307 .36918 L .60825 .36771 L F
.882 .986 .817 r
.60963 .36639 m .60712 .36982 L .60825 .36771 L F
.955 .616 .234 r
.60144 .36594 m .60145 .36774 L .60307 .36918 L F
.60095 .36496 m .60145 .36774 L .60144 .36594 L F
.703 .885 .964 r
.60307 .36918 m .60145 .36774 L .60825 .36771 L F
.66 .414 .537 r
.60598 .36835 m .60336 .37217 L .60307 .36918 L F
.60825 .36771 m .60723 .36864 L .60598 .36835 L F
.60723 .36864 m .60336 .37217 L .60598 .36835 L F
.889 .853 .8 r
.60699 .36818 m .60825 .36771 L .60614 .36772 L F
.60102 .37042 m .60336 .37217 L .60825 .36771 L F
.47 .863 .972 r
.60838 .36674 m .60694 .3662 L .60825 .36771 L F
.60838 .36674 m .60694 .3662 L .60825 .36771 L F
.476 .66 .942 r
.60712 .36982 m .60838 .36674 L .60825 .36771 L F
.467 .304 .576 r
.60963 .36639 m .61 .36946 L .60712 .36982 L F
.882 .986 .817 r
.60963 .36639 m .60825 .36771 L .60838 .36674 L F
.476 .66 .942 r
.60765 .36853 m .60889 .36902 L .60838 .36674 L F
.60889 .36902 m .61 .36946 L .60987 .36925 L F
.60889 .36902 m .60987 .36925 L .60838 .36674 L F
.889 .853 .8 r
.60102 .37042 m .60699 .36818 L .60145 .36774 L F
.60699 .36818 m .60614 .36772 L .60145 .36774 L F
.476 .66 .942 r
.60712 .36982 m .60949 .36953 L .60765 .36853 L F
.60949 .36953 m .61 .36946 L .60765 .36853 L F
.737 .909 .536 r
.60344 .36631 m .60146 .36967 L .60145 .36774 L F
.60146 .36967 m .60102 .37042 L .60145 .36774 L F
.753 .796 .887 r
.42849 .56269 m .43036 .56427 L .42623 .56331 L F
.876 .893 .842 r
.43036 .56427 m .42591 .56624 L .42623 .56331 L F
.877 .786 .756 r
.43175 .56073 m .43036 .56427 L .42849 .56269 L F
.857 .602 .552 r
.3567 .53649 m .35284 .53314 L .35671 .53433 L F
.891 .818 .769 r
.32887 .56653 m .32987 .57 L .33124 .56798 L F
.497 0 0 r
.26364 .55114 m .26494 .55195 L .2672 .55071 L F
.798 .979 .699 r
.26989 .54733 m .2672 .55071 L .26761 .5491 L F
.571 .304 .473 r
.26494 .55195 m .26761 .5491 L .2672 .55071 L F
.109 .318 .791 r
.58465 .34996 m .58687 .35167 L .58613 .35381 L F
.592 .807 .982 r
.51722 .43993 m .52176 .44054 L .51934 .44016 L F
.35 .545 .904 r
.29202 .68129 m .29447 .68169 L .29316 .67927 L F
0 0 .359 r
.31919 .68552 m .31999 .68561 L .3205 .68365 L F
.659 .957 .941 r
.62981 .34843 m .62864 .34796 L .62721 .35006 L F
.609 .897 .988 r
.62864 .34796 m .626 .34911 L .62721 .35006 L F
.638 .434 .59 r
.50662 .46713 m .50706 .47006 L .50293 .4702 L F
.579 .41 .617 r
.50912 .46375 m .50966 .46673 L .50662 .46713 L F
.574 .389 .594 r
.50966 .46673 m .50706 .47006 L .50662 .46713 L F
.695 .294 .283 r
.29583 .55432 m .29924 .55621 L .29896 .55368 L F
.29583 .55432 m .29404 .55597 L .29924 .55621 L F
.465 .499 .809 r
.29924 .55621 m .29583 .55432 L .29896 .55368 L F
0 0 0 r
.29038 .65755 m .29198 .6537 L .29289 .65762 L F
.489 .715 .971 r
.59632 .40029 m .59912 .40012 L .59774 .39807 L F
.464 .889 .829 r
.4775 .4284 m .4807 .42731 L .47856 .42808 L F
.631 .956 .784 r
.47856 .42808 m .4807 .42731 L .48198 .42566 L F
.292 0 .172 r
.48032 .42712 m .47973 .42773 L .47856 .42808 L F
.47973 .42773 m .47736 .43017 L .47856 .42808 L F
.464 .889 .829 r
.47605 .4289 m .4775 .4284 L .47856 .42808 L F
.605 .896 .601 r
.48198 .42566 m .4807 .42731 L .48239 .42551 L F
.877 .786 .756 r
.43175 .56073 m .42849 .56269 L .4313 .55948 L F
.732 .635 .75 r
.30292 .60468 m .30611 .60332 L .30606 .60097 L F
.991 .733 .392 r
.39123 .53317 m .39121 .53618 L .39259 .5371 L F
.903 .693 .609 r
.38901 .53893 m .39259 .5371 L .39121 .53618 L F
.38901 .53893 m .39319 .54053 L .39259 .5371 L F
.755 .735 .834 r
.38903 .57012 m .39328 .57063 L .39049 .56814 L F
.949 .857 .716 r
.55502 .42806 m .55727 .42709 L .55592 .42583 L F
.911 .88 .792 r
.55727 .42709 m .55816 .42198 L .55592 .42583 L F
0 0 0 r
.27197 .54357 m .26989 .54733 L .27127 .54578 L F
.566 .329 .516 r
.26761 .5491 m .27127 .54578 L .26989 .54733 L F
.848 .855 .848 r
.51829 .46276 m .51709 .46405 L .51508 .46286 L F
.933 .798 .689 r
.51709 .46405 m .51642 .46647 L .51508 .46286 L F
.954 .91 .736 r
.55873 .40494 m .55955 .40686 L .55756 .40993 L F
.839 .894 .879 r
.56209 .40374 m .55955 .40686 L .55873 .40494 L F
.439 .829 .985 r
.63117 .34086 m .634 .34026 L .63462 .34149 L F
.321 .779 .948 r
.634 .34026 m .63777 .34051 L .63462 .34149 L F
.308 .335 .726 r
.63105 .3554 m .63105 .35729 L .62853 .35672 L F
.801 .531 .53 r
.37977 .5591 m .3837 .55954 L .38381 .55724 L F
.669 .173 0 r
.40976 .476 m .40731 .47288 L .40964 .47297 L F
.746 .755 .859 r
.4236 .58369 m .42777 .58436 L .42569 .58268 L F
.742 .687 .798 r
.53506 .42334 m .53686 .42367 L .53842 .42025 L F
.005 .565 .808 r
.53694 .42337 m .53686 .42367 L .53506 .42334 L F
.697 .792 .923 r
.56119 .4165 m .56499 .41677 L .56249 .41578 L F
.776 .611 .676 r
.56328 .42035 m .56499 .41677 L .56119 .4165 L F
.72 .743 .869 r
.33438 .61055 m .33641 .61377 L .33187 .61327 L F
.656 .792 .947 r
.33685 .61039 m .33641 .61377 L .33438 .61055 L F
.33685 .61039 m .33964 .61264 L .33641 .61377 L F
.882 .629 .551 r
.33919 .51375 m .33568 .5147 L .33684 .51271 L F
.33919 .51375 m .33897 .51653 L .33568 .5147 L F
.225 0 .217 r
.37527 .5799 m .37652 .58057 L .37745 .57794 L F
.343 .803 .936 r
.43409 .57355 m .43832 .57339 L .43578 .57396 L F
.43578 .57396 m .43832 .57339 L .43409 .57355 L F
.99 .728 .39 r
.52291 .41798 m .52407 .42017 L .52294 .42224 L F
.453 .615 .918 r
.52581 .4181 m .52407 .42017 L .52291 .41798 L F
.778 .662 .736 r
.52581 .4181 m .52294 .42224 L .52407 .42017 L F
.96 .884 .713 r
.41205 .55457 m .41083 .55697 L .40932 .5559 L F
.41205 .55457 m .41083 .55697 L .40932 .5559 L F
.886 .457 .143 r
.40246 .55586 m .4026 .55475 L .40191 .55402 L F
.40246 .55586 m .4046 .55747 L .4026 .55475 L F
.76 .339 .251 r
.39393 .47617 m .39764 .47693 L .39571 .47842 L F
.294 0 0 r
.39764 .47693 m .39834 .47779 L .39571 .47842 L F
.39764 .47693 m .40044 .47721 L .39834 .47779 L F
.802 .635 .675 r
.50008 .47028 m .49568 .472 L .49815 .46877 L F
.50008 .47028 m .49786 .47397 L .49568 .472 L F
.632 .417 .572 r
.50008 .47028 m .49943 .47514 L .49786 .47397 L F
.69 .469 .582 r
.50313 .47384 m .50008 .47028 L .50293 .4702 L F
.50313 .47384 m .49943 .47514 L .50008 .47028 L F
.469 .822 .548 r
.47727 .41611 m .47533 .41777 L .47387 .419 L F
.947 .866 .727 r
.42589 .57116 m .42304 .57196 L .42493 .56882 L F
.42589 .57116 m .42451 .57339 L .42304 .57196 L F
.883 .929 .846 r
.48755 .50984 m .49163 .5079 L .48898 .5083 L F
.859 .932 .872 r
.49153 .50499 m .49163 .5079 L .49304 .50603 L F
.49153 .50499 m .48898 .5083 L .49163 .5079 L F
.308 .11 .44 r
.57764 .38489 m .57536 .38339 L .57821 .38265 L F
.57764 .38489 m .57444 .38668 L .57536 .38339 L F
.443 .692 .971 r
.28941 .64928 m .28889 .65111 L .28745 .64944 L F
.451 .7 .973 r
.29168 .65063 m .28889 .65111 L .28941 .64928 L F
0 0 .485 r
.29198 .6537 m .28889 .65111 L .29168 .65063 L F
.371 .821 .94 r
.64012 .39342 m .63997 .39292 L .63614 .39361 L F
0 0 0 r
.64246 .39033 m .64205 .3913 L .64045 .39298 L F
.614 .629 .842 r
.64541 .39133 m .64699 .39319 L .64593 .39151 L F
.64246 .39033 m .64538 .39217 L .64541 .39133 L F
.64538 .39217 m .64699 .39319 L .64541 .39133 L F
.398 .744 .993 r
.6455 .38881 m .64829 .38987 L .64596 .38841 L F
.532 .047 .049 r
.6429 .3911 m .64185 .39177 L .64593 .39151 L F
.55 .076 .081 r
.64593 .39151 m .64185 .39177 L .64217 .39101 L F
.64393 .39083 m .64217 .39101 L .64246 .39033 L F
.68 .958 .946 r
.64328 .38999 m .6424 .39093 L .64287 .39109 L F
.64291 .39108 m .64287 .39109 L .6429 .3911 L F
.64328 .38999 m .64287 .39109 L .64291 .39108 L F
.55 .076 .081 r
.64541 .39133 m .64296 .39109 L .64393 .39083 L F
.425 .733 .99 r
.64593 .39151 m .64296 .39109 L .6429 .3911 L F
.398 .744 .993 r
.6429 .3911 m .64296 .39109 L .64292 .39109 L F
.55 .076 .081 r
.64593 .39151 m .64217 .39101 L .64541 .39133 L F
.425 .733 .99 r
.64593 .39151 m .64829 .38987 L .64296 .39109 L F
.55 .076 .081 r
.64296 .39109 m .6429 .39108 L .64291 .39108 L F
.64296 .39109 m .64291 .39108 L .64393 .39083 L F
.299 .576 .937 r
.64291 .39108 m .64596 .38841 L .64377 .38858 L F
.6429 .3911 m .64292 .39109 L .64291 .39108 L F
.64292 .39109 m .64596 .38841 L .64291 .39108 L F
.968 .918 .701 r
.6429 .3911 m .64287 .39109 L .64185 .39177 L F
.55 .076 .081 r
.64289 .39108 m .64217 .39101 L .64253 .39097 L F
.64289 .39108 m .64217 .39101 L .64289 .39108 L F
.968 .918 .701 r
.64287 .39109 m .64045 .39025 L .64185 .39177 L F
.55 .076 .081 r
.6429 .39108 m .64289 .39108 L .64289 .39108 L F
.64291 .39108 m .64253 .39097 L .64393 .39083 L F
.6429 .39108 m .64253 .39097 L .64291 .39108 L F
.398 .744 .993 r
.64292 .39109 m .64544 .39052 L .6455 .38881 L F
.64296 .39109 m .64544 .39052 L .64292 .39109 L F
.64544 .39052 m .64829 .38987 L .6455 .38881 L F
.68 .958 .946 r
.64377 .38858 m .64045 .39025 L .6424 .39093 L F
.64377 .38858 m .6424 .39093 L .64328 .38999 L F
0 0 0 r
.64045 .39298 m .64185 .39177 L .64012 .39342 L F
.64205 .3913 m .64185 .39177 L .64045 .39298 L F
.588 .947 .88 r
.64012 .39342 m .64185 .39177 L .63997 .39292 L F
.659 .464 .609 r
.51231 .46585 m .50912 .46375 L .51106 .4613 L F
.51231 .46585 m .50966 .46673 L .50912 .46375 L F
.405 .838 .949 r
.2869 .63414 m .28433 .63428 L .28716 .63348 L F
.167 0 0 r
.28716 .63348 m .28243 .63604 L .2856 .63481 L F
.671 .943 .675 r
.28726 .63322 m .28716 .63348 L .2856 .63481 L F
.28887 .63169 m .28716 .63348 L .28726 .63322 L F
.405 .838 .949 r
.28865 .63405 m .2869 .63414 L .28716 .63348 L F
.748 .966 .933 r
.29052 .63255 m .28865 .63405 L .28716 .63348 L F
.866 .684 .655 r
.36185 .55367 m .36354 .55744 L .36142 .55651 L F
.906 .711 .628 r
.36354 .55744 m .36314 .56039 L .36142 .55651 L F
.827 .534 .493 r
.39319 .54053 m .39487 .54373 L .39448 .54045 L F
.848 .855 .848 r
.51829 .46276 m .51508 .46286 L .51694 .46136 L F
.744 .893 .947 r
.52201 .46002 m .51829 .46276 L .51694 .46136 L F
.732 .635 .75 r
.30292 .60468 m .30272 .60059 L .30229 .6016 L F
.30292 .60468 m .30606 .60097 L .30272 .60059 L F
.816 .922 .907 r
.50369 .49509 m .5084 .49345 L .50676 .49212 L F
.828 .884 .883 r
.50676 .49212 m .5084 .49345 L .5116 .49042 L F
0 0 .027 r
.27305 .56159 m .27255 .56032 L .27487 .5596 L F
.27305 .56159 m .27173 .56346 L .27255 .56032 L F
.912 .8 .723 r
.543 .45231 m .54467 .45338 L .54369 .44942 L F
.913 .757 .674 r
.54105 .45549 m .54467 .45338 L .543 .45231 L F
.54105 .45549 m .54305 .4571 L .54467 .45338 L F
.938 .571 .188 r
.31564 .53681 m .31419 .53586 L .31392 .53341 L F
.897 .968 .822 r
.31347 .53847 m .31419 .53586 L .31564 .53681 L F
.833 .86 .866 r
.52658 .45276 m .52625 .44939 L .52779 .45051 L F
.52658 .45276 m .52317 .45245 L .52625 .44939 L F
.877 .79 .76 r
.52658 .45276 m .52419 .45646 L .52317 .45245 L F
.708 .549 .671 r
.28411 .53237 m .28818 .53238 L .28549 .52492 L F
.534 .328 .547 r
.28549 .52492 m .28817 .5265 L .28841 .52343 L F
.548 .462 .71 r
.28549 .52492 m .29164 .52895 L .28817 .5265 L F
.89 .757 .708 r
.33094 .54632 m .33256 .55006 L .33321 .54757 L F
.926 .899 .495 r
.67532 .36331 m .67408 .36452 L .67443 .36582 L F
.869 .541 .029 r
.6744 .36185 m .67532 .36331 L .67379 .35927 L F
.99 .8 .413 r
.6744 .36185 m .67408 .36452 L .67532 .36331 L F
.704 .968 .935 r
.48666 .40957 m .48775 .40739 L .49 .40754 L F
.703 .979 .908 r
.49 .40754 m .49107 .40524 L .49249 .40617 L F
.49 .40754 m .48775 .40739 L .49107 .40524 L F
.863 .951 .869 r
.46564 .51794 m .46315 .52053 L .46156 .51828 L F
.99 .859 .61 r
.46267 .52344 m .46156 .51828 L .46315 .52053 L F
.609 .608 .825 r
.24182 .61147 m .24621 .61422 L .24393 .6107 L F
.637 .666 .862 r
.24393 .6107 m .24621 .61422 L .24762 .61225 L F
.937 .919 .771 r
.32507 .57506 m .32551 .57923 L .32795 .57395 L F
.927 .923 .787 r
.32507 .57506 m .32427 .58005 L .32551 .57923 L F
.546 .493 .748 r
.27745 .66462 m .27833 .66716 L .28103 .66628 L F
.825 .933 .902 r
.33812 .62624 m .33897 .62778 L .34178 .62491 L F
.556 0 0 r
.3392 .6292 m .33897 .62778 L .33812 .62624 L F
.3392 .6292 m .34226 .62983 L .33897 .62778 L F
.891 .603 .492 r
.38901 .54187 m .39319 .54053 L .38901 .53893 L F
.38901 .54187 m .39266 .54364 L .39319 .54053 L F
.827 .534 .493 r
.39319 .54053 m .39266 .54364 L .39487 .54373 L F
0 0 0 r
.25323 .58082 m .25252 .58341 L .25372 .57945 L F
.228 .301 .731 r
.55674 .34192 m .55719 .33794 L .55437 .33886 L F
.55674 .34192 m .55854 .34267 L .55719 .33794 L F
.88 .932 .85 r
.31978 .56755 m .31722 .57078 L .31645 .56828 L F
.956 .94 .622 r
.31543 .57321 m .31645 .56828 L .31722 .57078 L F
.832 .998 .775 r
.30613 .65269 m .30768 .64962 L .30769 .65219 L F
0 0 0 r
.30476 .65579 m .30613 .65269 L .30769 .65219 L F
.918 .787 .701 r
.55347 .41264 m .55421 .41542 L .55098 .41538 L F
.635 .631 .829 r
.55719 .41295 m .55421 .41542 L .55347 .41264 L F
.8 1 .819 r
.40457 .57461 m .40168 .5773 L .40221 .57513 L F
.451 .88 .802 r
.40457 .57461 m .40442 .57394 L .40702 .57377 L F
.40457 .57461 m .40221 .57513 L .40442 .57394 L F
.979 .706 .436 r
.58328 .34876 m .58488 .34665 L .58336 .34523 L F
.58328 .34876 m .58465 .34996 L .58488 .34665 L F
.934 .82 .709 r
.32924 .55872 m .33127 .56005 L .33007 .55645 L F
.921 .783 .691 r
.32924 .55872 m .33044 .56282 L .33127 .56005 L F
.915 .816 .735 r
.33007 .55645 m .33127 .56005 L .33198 .55759 L F
.644 .688 .877 r
.30305 .68418 m .30569 .68358 L .30387 .67999 L F
.673 .871 .974 r
.50446 .40161 m .50338 .40399 L .50688 .40282 L F
.8 .992 .753 r
.50446 .40161 m .50163 .40481 L .50338 .40399 L F
.789 .668 .729 r
.50933 .46957 m .51091 .47336 L .5068 .47288 L F
.858 .731 .722 r
.51091 .47336 m .50666 .47558 L .5068 .47288 L F
.51091 .47336 m .50873 .47691 L .50666 .47558 L F
.756 .653 .747 r
.51371 .46997 m .51091 .47336 L .50933 .46957 L F
.717 .651 .095 r
.30942 .58185 m .30938 .58198 L .30971 .57948 L F
0 0 0 r
.30971 .57948 m .3102 .57916 L .31126 .57561 L F
.30971 .57948 m .30938 .58198 L .3102 .57916 L F
.754 .659 .756 r
.51231 .46585 m .51371 .46997 L .50933 .46957 L F
.756 .66 .756 r
.51642 .46647 m .51371 .46997 L .51231 .46585 L F
.895 .988 .774 r
.34506 .66985 m .34623 .66642 L .34383 .67008 L F
0 0 0 r
.41871 .46661 m .42243 .46442 L .42075 .46576 L F
.42243 .46442 m .42335 .465 L .42075 .46576 L F
.42243 .46442 m .42473 .46325 L .42335 .465 L F
.412 .536 .872 r
.40874 .59447 m .40981 .59188 L .40699 .59264 L F
.40874 .59447 m .41094 .59407 L .40981 .59188 L F
.501 .75 .984 r
.31526 .56164 m .31511 .56375 L .31332 .56275 L F
.31526 .56164 m .31795 .56381 L .31511 .56375 L F
.758 .569 .641 r
.31736 .56606 m .31332 .56275 L .31511 .56375 L F
.6 .287 .411 r
.31795 .56381 m .31736 .56606 L .31511 .56375 L F
.534 .118 .198 r
.38748 .47306 m .39242 .47423 L .39197 .47065 L F
.998 .833 .552 r
.39242 .47423 m .39463 .47041 L .39197 .47065 L F
0 0 .203 r
.39242 .47423 m .39302 .47194 L .39197 .47065 L F
0 0 .335 r
.28242 .54635 m .28272 .55012 L .28234 .55049 L F
.71 .389 .431 r
.31343 .53086 m .31004 .53306 L .30765 .53236 L F
.846 .639 .622 r
.31392 .53341 m .31004 .53306 L .31343 .53086 L F
.729 .743 .863 r
.32548 .61441 m .3268 .61739 L .32247 .61684 L F
.756 .755 .852 r
.32957 .61447 m .3268 .61739 L .32548 .61441 L F
.41 .449 .79 r
.27635 .66081 m .27745 .66462 L .27959 .66277 L F
.546 .493 .748 r
.27745 .66462 m .28103 .66628 L .27959 .66277 L F
.903 .861 .789 r
.29233 .64596 m .29565 .64732 L .29168 .65063 L F
.663 .68 .856 r
.55522 .37355 m .55647 .37686 L .55343 .37434 L F
0 0 .247 r
.55793 .37201 m .55647 .37686 L .55522 .37355 L F
.55793 .37201 m .55766 .375 L .55647 .37686 L F
.674 .281 .293 r
.55766 .375 m .55479 .37609 L .55511 .37602 L F
.433 .242 .52 r
.55345 .3766 m .55343 .37434 L .55511 .37602 L F
.674 .281 .293 r
.55479 .37609 m .55345 .3766 L .55511 .37602 L F
.61 .075 0 r
.55539 .37596 m .55511 .37602 L .55343 .37434 L F
.55647 .37686 m .55511 .37602 L .55539 .37596 L F
.618 .908 .983 r
.55766 .375 m .55511 .37602 L .55647 .37686 L F
0 0 .135 r
.56634 .35351 m .56529 .34852 L .56439 .35016 L F
.418 .444 .78 r
.56552 .35607 m .56638 .354 L .56634 .35351 L F
.711 .986 .843 r
.5308 .43652 m .5283 .43826 L .52989 .43838 L F
0 0 0 r
.53331 .43521 m .5308 .43652 L .53312 .43554 L F
.53312 .43554 m .5308 .43652 L .52989 .43838 L F
.875 .754 .725 r
.65483 .38562 m .65273 .38961 L .65599 .38958 L F
.864 .805 .79 r
.65273 .38961 m .65368 .39295 L .65599 .38958 L F
0 0 0 r
.51895 .40984 m .51828 .40997 L .52083 .40909 L F
.51895 .40984 m .51727 .41182 L .51828 .40997 L F
.48 .255 .494 r
.3957 .55025 m .39936 .54727 L .39424 .54662 L F
.3957 .55025 m .3983 .54985 L .39936 .54727 L F
.756 .67 .767 r
.31494 .54976 m .3167 .55447 L .31202 .55352 L F
.681 .202 .107 r
.3167 .55447 m .31424 .55571 L .31202 .55352 L F
.561 .563 .813 r
.31884 .55318 m .3167 .55447 L .31494 .54976 L F
.643 .15 .067 r
.3167 .55447 m .31838 .55614 L .31424 .55571 L F
.945 .732 .584 r
.31884 .55318 m .31838 .55614 L .3167 .55447 L F
.842 .626 .61 r
.32775 .53311 m .33019 .53373 L .32802 .53023 L F
.837 .526 .463 r
.32775 .53311 m .32776 .53561 L .33019 .53373 L F
.883 .611 .522 r
.32776 .53561 m .33019 .53687 L .33019 .53373 L F
.117 0 .313 r
.30119 .55314 m .29924 .55621 L .29896 .55368 L F
.30119 .55314 m .29924 .55621 L .29896 .55368 L F
.499 .794 .998 r
.64699 .39319 m .64867 .39125 L .64593 .39151 L F
.64699 .39319 m .64982 .39261 L .64867 .39125 L F
.704 .968 .935 r
.48666 .40957 m .48561 .40901 L .48775 .40739 L F
.775 .456 .447 r
.3593 .51895 m .36387 .51719 L .35966 .51605 L F
.3593 .51895 m .36353 .51951 L .36387 .51719 L F
.598 .291 .42 r
.36387 .51719 m .36642 .51891 L .36793 .51676 L F
.36387 .51719 m .36353 .51951 L .36642 .51891 L F
.839 .894 .879 r
.56209 .40374 m .55873 .40494 L .55844 .40407 L F
.763 .852 .918 r
.31377 .58831 m .31657 .59008 L .31966 .58704 L F
.912 .667 .554 r
.293 .56044 m .29303 .56352 L .29016 .56179 L F
.916 .617 .461 r
.29303 .56352 m .29265 .56619 L .29016 .56179 L F
.919 .526 .153 r
.29016 .56179 m .29265 .56619 L .29083 .56476 L F
.308 0 0 r
.29016 .56179 m .29031 .56216 L .293 .56044 L F
0 0 .366 r
.293 .56044 m .29404 .55597 L .29326 .55736 L F
.466 .304 .576 r
.29575 .56269 m .293 .56044 L .29618 .56061 L F
.276 0 0 r
.293 .56044 m .29575 .56269 L .29407 .55947 L F
.466 .304 .576 r
.29575 .56269 m .29303 .56352 L .293 .56044 L F
.276 0 0 r
.293 .56044 m .29332 .56173 L .29575 .56269 L F
.293 .56044 m .29031 .56216 L .29332 .56173 L F
.949 .764 .619 r
.33094 .54632 m .33025 .54893 L .33256 .55006 L F
.919 .779 .69 r
.32848 .55246 m .33256 .55006 L .33025 .54893 L F
.32848 .55246 m .33058 .55347 L .33256 .55006 L F
.988 .736 .36 r
.37591 .53759 m .37599 .53814 L .37756 .53977 L F
.811 .556 .553 r
.37466 .5423 m .37858 .54084 L .37756 .53977 L F
0 0 0 r
.37756 .53977 m .37638 .54111 L .37466 .5423 L F
.988 .736 .36 r
.37599 .53814 m .37638 .54111 L .37756 .53977 L F
.811 .556 .553 r
.37858 .54084 m .38019 .54024 L .37756 .53977 L F
.37466 .5423 m .37916 .54303 L .38019 .54024 L F
.409 .839 .952 r
.37756 .53977 m .38019 .54024 L .38137 .53958 L F
.546 .407 .643 r
.37916 .54303 m .38137 .53958 L .38019 .54024 L F
.523 .55 .825 r
.24298 .60084 m .24547 .6005 L .24369 .59635 L F
.98 .824 .422 r
.52107 .37863 m .52157 .3832 L .52215 .37993 L F
.937 .627 .172 r
.52067 .37589 m .52107 .37863 L .52215 .37993 L F
0 0 .251 r
.5248 .36612 m .52366 .36979 L .52223 .36702 L F
.66 .632 .811 r
.5248 .36612 m .52223 .36702 L .52185 .36551 L F
.682 .66 .822 r
.52366 .36979 m .52185 .36551 L .52223 .36702 L F
.52366 .36979 m .51955 .36865 L .52185 .36551 L F
0 0 .251 r
.5248 .36612 m .52524 .36794 L .52366 .36979 L F
0 0 .475 r
.52431 .37022 m .52366 .36979 L .52524 .36794 L F
.52431 .37022 m .52518 .37173 L .52366 .36979 L F
.017 0 .452 r
.52366 .36979 m .52518 .37173 L .52388 .3729 L F
.606 .13 .098 r
.28648 .6747 m .28989 .67488 L .28857 .67648 L F
.465 0 0 r
.28989 .67488 m .29114 .67606 L .28857 .67648 L F
.28989 .67488 m .29338 .67678 L .29114 .67606 L F
.917 .827 .743 r
.32797 .56871 m .32987 .57 L .32887 .56653 L F
.979 .875 .66 r
.32797 .56871 m .32795 .57395 L .32987 .57 L F
.601 .796 .974 r
.56136 .34124 m .56306 .34339 L .56544 .34222 L F
.363 .041 .279 r
.37745 .57794 m .37652 .58057 L .37997 .57766 L F
.774 .716 .798 r
.49329 .47322 m .49445 .47666 L .49137 .47592 L F
.807 .489 .452 r
.49445 .47666 m .49245 .47868 L .49137 .47592 L F
.514 .322 .558 r
.49786 .47397 m .49445 .47666 L .49329 .47322 L F
.49786 .47397 m .49731 .47641 L .49445 .47666 L F
.757 .599 .682 r
.49731 .47641 m .49245 .47868 L .49445 .47666 L F
.839 .579 .546 r
.35298 .53038 m .34915 .53239 L .34964 .52959 L F
.35298 .53038 m .35284 .53314 L .34915 .53239 L F
.567 .183 .273 r
.35109 .51218 m .35175 .51049 L .3486 .51032 L F
0 .139 .608 r
.35109 .51218 m .3486 .51032 L .34779 .50955 L F
.659 .96 .934 r
.46564 .51794 m .4668 .51599 L .46762 .51624 L F
.46564 .51794 m .46156 .51828 L .4668 .51599 L F
.764 .305 .16 r
.61629 .35144 m .61215 .34883 L .61589 .35038 L F
.715 .644 .778 r
.3107 .59283 m .31134 .59711 L .31397 .59348 L F
.701 .625 .769 r
.31134 .59711 m .31365 .59603 L .31397 .59348 L F
.651 .496 .66 r
.31031 .60074 m .31365 .59603 L .31134 .59711 L F
.23 0 .093 r
.40798 .46296 m .4043 .46645 L .40661 .46526 L F
.206 0 0 r
.40893 .46413 m .40798 .46296 L .40661 .46526 L F
.40893 .46413 m .41066 .4625 L .40798 .46296 L F
.413 .049 .234 r
.36793 .51676 m .36867 .5182 L .3705 .51645 L F
.36793 .51676 m .36642 .51891 L .36867 .5182 L F
.976 .751 .533 r
.38433 .52508 m .38341 .52941 L .38538 .53022 L F
.837 .517 .448 r
.38261 .53212 m .38538 .53022 L .38341 .52941 L F
.38261 .53212 m .38807 .53514 L .38538 .53022 L F
.861 .501 .368 r
.32921 .64089 m .33066 .64395 L .33281 .64371 L F
.566 .022 0 r
.33374 .64554 m .33281 .64371 L .33066 .64395 L F
.33374 .64554 m .33561 .64581 L .33281 .64371 L F
.551 .059 .04 r
.33561 .64581 m .33633 .64449 L .33281 .64371 L F
.727 .716 .84 r
.51508 .46286 m .51642 .46647 L .51231 .46585 L F
.722 .195 0 r
.39758 .57376 m .4003 .57688 L .40168 .5773 L F
.745 .978 .918 r
.40168 .5773 m .4003 .57688 L .40221 .57513 L F
.184 .222 .668 r
.56862 .39124 m .56705 .39255 L .56611 .38994 L F
.469 .701 .969 r
.29544 .63898 m .29695 .64071 L .29811 .63872 L F
.65 .851 .457 r
.29811 .63872 m .29695 .64071 L .29523 .643 L F
.98 .686 .332 r
.29833 .65026 m .29987 .65408 L .29846 .65278 L F
.853 .738 .736 r
.31483 .6471 m .31853 .64726 L .31754 .64242 L F
.833 .533 .481 r
.3187 .65015 m .31853 .64726 L .31483 .6471 L F
.883 .968 .841 r
.31853 .64726 m .31854 .64369 L .31754 .64242 L F
.58 .521 .754 r
.4097 .56713 m .41074 .56286 L .40915 .56494 L F
.4097 .56713 m .41236 .56708 L .41074 .56286 L F
.239 .092 .47 r
.4097 .56713 m .41182 .56864 L .41236 .56708 L F
.4097 .56713 m .40968 .56998 L .41182 .56864 L F
.261 0 0 r
.56056 .37431 m .55884 .37361 L .56126 .37375 L F
.56056 .37431 m .55766 .375 L .55884 .37361 L F
.153 0 0 r
.5632 .37351 m .56126 .37375 L .55884 .37361 L F
.584 .314 .473 r
.4046 .55747 m .40391 .55984 L .40089 .55956 L F
.932 .696 .559 r
.40246 .55586 m .40391 .55984 L .4046 .55747 L F
.384 0 0 r
.33995 .50519 m .33889 .5064 L .34262 .50575 L F
.683 .479 .605 r
.5068 .47288 m .50293 .4702 L .50706 .47006 L F
.5068 .47288 m .50313 .47384 L .50293 .4702 L F
.18 0 0 r
.32088 .65743 m .31801 .65802 L .31722 .65875 L F
.872 .615 .547 r
.38101 .52274 m .38433 .52508 L .38348 .52352 L F
0 0 0 r
.41658 .45953 m .41892 .45843 L .42052 .45689 L F
.41892 .45843 m .42262 .45541 L .42052 .45689 L F
.432 .138 .363 r
.38183 .47879 m .38223 .48235 L .37955 .48283 L F
.191 0 0 r
.38643 .47729 m .3854 .47856 L .38183 .47879 L F
.534 .31 .521 r
.3854 .47856 m .38223 .48235 L .38183 .47879 L F
.966 .824 .653 r
.56005 .38605 m .55963 .38985 L .55801 .38856 L F
.949 .671 .218 r
.55963 .38985 m .55904 .39068 L .55832 .3892 L F
.55841 .38888 m .55832 .3892 L .55801 .38856 L F
.55963 .38985 m .55832 .3892 L .55841 .38888 L F
.55904 .39068 m .55846 .38973 L .55801 .38856 L F
0 .202 .718 r
.55891 .39086 m .55784 .38964 L .55801 .38856 L F
.137 .024 .45 r
.55826 .38939 m .56175 .38847 L .56332 .38644 L F
.55784 .38964 m .55823 .38953 L .55826 .38939 L F
.55823 .38953 m .56175 .38847 L .55826 .38939 L F
.909 .824 .751 r
.56005 .38605 m .55848 .38592 L .5604 .38254 L F
.966 .824 .653 r
.56005 .38605 m .55801 .38856 L .55848 .38592 L F
.787 .909 .515 r
.5604 .38254 m .55848 .38592 L .5591 .38389 L F
.539 .514 .776 r
.5591 .38389 m .55799 .38894 L .56332 .38644 L F
.55799 .38894 m .55784 .38964 L .55826 .38939 L F
.55799 .38894 m .55826 .38939 L .56332 .38644 L F
.949 .671 .218 r
.55904 .39068 m .55891 .39086 L .55846 .38973 L F
.55963 .38985 m .55985 .39247 L .55891 .39086 L F
.778 .762 .839 r
.64982 .39261 m .65368 .39295 L .65273 .38961 L F
.637 .123 0 r
.39817 .57503 m .39758 .57376 L .39606 .57453 L F
.39817 .57503 m .4003 .57688 L .39758 .57376 L F
.619 .675 .881 r
.4988 .48372 m .49635 .48571 L .49462 .48238 L F
.815 .936 .569 r
.30612 .54919 m .30832 .54528 L .3059 .54589 L F
.926 .945 .6 r
.30832 .54528 m .30632 .54766 L .30693 .54628 L F
.454 0 0 r
.307 .54425 m .30832 .54528 L .30979 .5442 L F
.38 0 .045 r
.307 .54425 m .3059 .54589 L .30832 .54528 L F
.926 .945 .6 r
.30832 .54528 m .30693 .54628 L .30856 .54264 L F
.454 0 0 r
.30979 .5442 m .30832 .54528 L .31105 .54418 L F
.971 .782 .591 r
.31105 .54418 m .30832 .54528 L .30915 .54264 L F
.018 .198 .708 r
.55985 .33748 m .5588 .3391 L .55719 .33794 L F
.55985 .33748 m .56019 .34026 L .5588 .3391 L F
.721 .945 .954 r
.30826 .51996 m .31037 .51841 L .31066 .51765 L F
.30826 .51996 m .30727 .51913 L .31037 .51841 L F
.633 .214 .231 r
.30727 .51913 m .30935 .52109 L .31037 .51841 L F
.30935 .52109 m .30952 .52125 L .31037 .51841 L F
.721 .945 .954 r
.31066 .51765 m .31037 .51841 L .31149 .51685 L F
.584 .816 .427 r
.54434 .38342 m .5419 .38678 L .5429 .38544 L F
.704 .638 .779 r
.58483 .41173 m .58538 .41599 L .5885 .41311 L F
.785 .683 .752 r
.43832 .57339 m .44315 .5745 L .44189 .57228 L F
.43832 .57339 m .44005 .57746 L .44315 .5745 L F
.564 .52 .765 r
.44315 .5745 m .44455 .57244 L .44189 .57228 L F
.629 .119 0 r
.49754 .43944 m .50109 .44311 L .49935 .44043 L F
0 0 .519 r
.49935 .44043 m .49944 .44057 L .50044 .44183 L F
.49944 .44057 m .50073 .44255 L .50044 .44183 L F
.288 0 0 r
.50109 .44311 m .50293 .44444 L .50044 .44183 L F
.748 .313 .217 r
.50044 .44183 m .50293 .44444 L .50241 .44434 L F
0 0 .519 r
.50073 .44255 m .50109 .44311 L .50044 .44183 L F
.748 .313 .217 r
.50044 .44183 m .50241 .44434 L .49806 .44342 L F
0 .084 .644 r
.49935 .44043 m .50044 .44183 L .50046 .43983 L F
.748 .313 .217 r
.50044 .44183 m .49806 .44342 L .49994 .44061 L F
.50044 .44183 m .49994 .44061 L .50046 .43983 L F
.718 .884 .958 r
.63089 .35759 m .63598 .35715 L .63443 .35641 L F
.989 .839 .603 r
.34404 .64222 m .34597 .64355 L .34579 .64008 L F
.766 .492 .52 r
.34184 .64632 m .34597 .64355 L .34404 .64222 L F
.34184 .64632 m .34622 .64658 L .34597 .64355 L F
.892 .49 .243 r
.34622 .64658 m .34621 .64557 L .34597 .64355 L F
.716 .646 .778 r
.34579 .64008 m .34597 .64355 L .34896 .641 L F
.34579 .64008 m .34896 .641 L .34895 .64099 L F
.349 .279 .635 r
.34579 .64008 m .34824 .64134 L .34821 .64131 L F
.716 .646 .778 r
.34579 .64008 m .34895 .64099 L .34778 .6411 L F
.34895 .64099 m .34896 .641 L .34896 .641 L F
.34895 .64099 m .34896 .641 L .34893 .641 L F
.34895 .64099 m .34893 .641 L .34778 .6411 L F
.349 .279 .635 r
.34579 .64008 m .34778 .6411 L .34505 .6373 L F
.34778 .6411 m .34821 .64131 L .34809 .64115 L F
.34778 .6411 m .34809 .64115 L .34505 .6373 L F
.763 .251 0 r
.34821 .64131 m .34824 .64134 L .34821 .64132 L F
.716 .646 .778 r
.34579 .64008 m .34673 .64118 L .34824 .64134 L F
0 0 0 r
.34778 .6411 m .34797 .64116 L .34673 .64118 L F
.716 .646 .778 r
.34579 .64008 m .34778 .6411 L .34673 .64118 L F
.858 .439 .228 r
.3457 .63917 m .34803 .64116 L .34673 .64118 L F
.34803 .64116 m .34824 .64134 L .34673 .64118 L F
0 0 0 r
.34797 .64116 m .3488 .64147 L .34673 .64118 L F
.34896 .641 m .34886 .6413 L .34778 .6411 L F
.34886 .6413 m .3488 .64147 L .34778 .6411 L F
.575 .938 .914 r
.34125 .63759 m .34081 .63816 L .34282 .63581 L F
.34081 .63816 m .33998 .63924 L .34165 .63722 L F
.34081 .63816 m .34165 .63722 L .34282 .63581 L F
.161 .695 .841 r
.33998 .63924 m .33868 .63897 L .33608 .63916 L F
.223 0 0 r
.34014 .63891 m .33667 .64043 L .33868 .63897 L F
0 0 0 r
.33998 .63924 m .34125 .63759 L .34343 .64034 L F
.33998 .63924 m .34083 .63889 L .34125 .63759 L F
.223 0 0 r
.34083 .63889 m .33983 .63926 L .34014 .63891 L F
.33983 .63926 m .33667 .64043 L .34014 .63891 L F
.865 .727 .708 r
.34254 .63702 m .3457 .63917 L .34125 .63759 L F
.763 .251 0 r
.34528 .63798 m .34546 .63818 L .3457 .63917 L F
.34546 .63818 m .34726 .64023 L .3457 .63917 L F
.34726 .64023 m .34821 .64131 L .3457 .63917 L F
.34821 .64131 m .34821 .64132 L .3457 .63917 L F
.34614 .63868 m .34824 .64134 L .34528 .63798 L F
.541 .492 .751 r
.34673 .64118 m .34871 .63746 L .3457 .63917 L F
.409 .163 .427 r
.34871 .63746 m .34602 .64056 L .3457 .63917 L F
.34602 .64056 m .34505 .64168 L .3457 .63917 L F
.763 .251 0 r
.34505 .6373 m .34614 .63868 L .34528 .63798 L F
.706 .985 .834 r
.3456 .63568 m .34811 .63494 L .34505 .6373 L F
.763 .251 0 r
.34505 .6373 m .3457 .63917 L .3456 .63568 L F
.865 .727 .708 r
.3456 .63568 m .3457 .63917 L .34254 .63702 L F
.582 .279 .419 r
.3891 .47539 m .3854 .47856 L .38643 .47729 L F
.403 0 0 r
.38455 .57334 m .38264 .57306 L .38609 .57389 L F
.741 .364 .338 r
.53506 .42334 m .5395 .42598 L .53793 .42633 L F
.005 .565 .808 r
.53694 .42337 m .53506 .42334 L .53793 .42633 L F
.873 .682 .641 r
.32948 .53963 m .33136 .54345 L .33206 .54073 L F
.989 .894 .597 r
.4026 .53362 m .40158 .53723 L .40054 .53519 L F
.40054 .53519 m .40158 .53723 L .4026 .53362 L F
.40054 .53519 m .40158 .53723 L .4026 .53362 L F
.56 .351 .553 r
.56486 .39991 m .56494 .40272 L .56209 .40374 L F
.601 .837 .989 r
.56996 .39908 m .56486 .39991 L .56766 .39888 L F
.361 .794 .618 r
.45537 .44296 m .45905 .44083 L .45719 .44189 L F
.459 .852 .651 r
.45719 .44189 m .45905 .44083 L .46119 .43932 L F
.775 .635 .707 r
.38609 .56024 m .3895 .56055 L .39041 .55762 L F
.668 .749 .911 r
.51816 .39596 m .52243 .39686 L .52024 .39441 L F
0 0 0 r
.32516 .63612 m .3233 .63684 L .32283 .63364 L F
.783 .96 .924 r
.43894 .56262 m .43649 .56254 L .43723 .5642 L F
.985 .89 .552 r
.43649 .56254 m .43568 .56572 L .43723 .5642 L F
0 0 .313 r
.267 .57575 m .26503 .57926 L .26436 .57835 L F
.826 .775 .804 r
.45548 .54513 m .45711 .54657 L .45579 .54305 L F
.84 .885 .874 r
.45357 .54688 m .45711 .54657 L .45548 .54513 L F
.792 .76 .823 r
.45579 .54305 m .45711 .54657 L .45984 .54339 L F
.933 .941 .777 r
.56588 .37316 m .56126 .37375 L .5632 .37351 L F
.56588 .37316 m .5635 .37503 L .56126 .37375 L F
.56588 .37316 m .56378 .37662 L .5635 .37503 L F
.068 0 .322 r
.27197 .54357 m .27382 .54259 L .27432 .5396 L F
.344 .126 .432 r
.27127 .54578 m .27382 .54259 L .27197 .54357 L F
.586 .873 .558 r
.45218 .44619 m .45537 .44296 L .45401 .44439 L F
0 0 0 r
.45401 .44439 m .45537 .44296 L .45719 .44189 L F
.945 .732 .584 r
.31884 .55318 m .32052 .55711 L .31838 .55614 L F
.964 .68 .255 r
.31983 .55983 m .31838 .55614 L .32052 .55711 L F
.776 .685 .762 r
.32313 .55371 m .32052 .55711 L .31884 .55318 L F
0 0 0 r
.55456 .40077 m .55391 .40219 L .55691 .39924 L F
.451 0 0 r
.38609 .57389 m .39049 .57681 L .39028 .57384 L F
.594 .561 .787 r
.38903 .57012 m .39028 .57384 L .3933 .57295 L F
.864 .994 .817 r
.39049 .57681 m .3933 .57295 L .39028 .57384 L F
.374 .124 .401 r
.30388 .55263 m .30119 .55314 L .30548 .55292 L F
.709 .468 .558 r
.39979 .55328 m .40246 .55586 L .40191 .55402 L F
.459 .318 .602 r
.56045 .36394 m .56268 .35978 L .55882 .35914 L F
.945 .956 .734 r
.29059 .53759 m .2894 .53605 L .2917 .53627 L F
.082 .641 .781 r
.2917 .53627 m .2894 .53605 L .29383 .53617 L F
.861 .794 .783 r
.32202 .56391 m .31736 .56606 L .31795 .56381 L F
.32202 .56391 m .31978 .56755 L .31736 .56606 L F
.427 .775 .997 r
.36161 .57329 m .36579 .57412 L .3642 .57292 L F
.49 .701 .963 r
.36579 .57412 m .3669 .57181 L .3642 .57292 L F
.36579 .57412 m .36864 .57369 L .3669 .57181 L F
0 0 .1 r
.32051 .63731 m .32075 .63982 L .32053 .63702 L F
.32051 .63731 m .32077 .64055 L .32075 .63982 L F
0 0 0 r
.4385 .444 m .43568 .4467 L .43772 .44556 L F
.181 0 .055 r
.44097 .44306 m .4385 .444 L .43772 .44556 L F
.592 .758 .957 r
.58069 .37747 m .57685 .37713 L .5796 .37557 L F
.4 .45 .797 r
.58069 .37747 m .58249 .37469 L .5796 .37557 L F
.508 .396 .662 r
.55873 .40494 m .55591 .40637 L .55553 .40344 L F
.55873 .40494 m .55591 .40637 L .55553 .40344 L F
.76 .401 .374 r
.65176 .35353 m .648 .35496 L .64765 .35282 L F
.65176 .35353 m .65201 .35561 L .648 .35496 L F
.87 .646 .597 r
.32479 .52659 m .32428 .52953 L .32802 .53023 L F
.842 .664 .66 r
.32428 .52953 m .32775 .53311 L .32802 .53023 L F
.459 .831 .992 r
.60564 .38291 m .60985 .38317 L .60879 .38218 L F
.60564 .38291 m .60985 .38317 L .60879 .38218 L F
.75 .245 .015 r
.31419 .53586 m .31004 .53306 L .31392 .53341 L F
.75 .739 .842 r
.3207 .55251 m .32313 .55371 L .31884 .55318 L F
.858 .955 .609 r
.44303 .55734 m .44505 .5537 L .4433 .55525 L F
.798 .999 .816 r
.44778 .55234 m .4433 .55525 L .44505 .5537 L F
.824 .999 .833 r
.44303 .55734 m .44032 .55844 L .44207 .55988 L F
.44303 .55734 m .4433 .55525 L .44032 .55844 L F
.927 .891 .774 r
.55177 .43651 m .5541 .43269 L .55267 .43132 L F
.906 .879 .797 r
.5541 .43269 m .55502 .42806 L .55267 .43132 L F
.885 .701 .648 r
.35867 .54035 m .35489 .54231 L .3551 .53955 L F
.35867 .54035 m .35817 .54333 L .35489 .54231 L F
.061 0 0 r
.49799 .41334 m .49646 .41446 L .49348 .41514 L F
.53 .354 .587 r
.50079 .41258 m .50087 .41566 L .49799 .41334 L F
.547 .572 .832 r
.25103 .59048 m .25182 .58599 L .24936 .58659 L F
.887 .818 .775 r
.28707 .55583 m .28797 .55768 L .28969 .55748 L F
0 0 .403 r
.59669 .37569 m .59717 .37677 L .59561 .37846 L F
.01 .027 .528 r
.59717 .37677 m .59727 .38126 L .59561 .37846 L F
.918 .937 .803 r
.54877 .37863 m .54633 .37916 L .54845 .37618 L F
.655 .147 .025 r
.54877 .37863 m .54776 .38038 L .54633 .37916 L F
.01 0 .425 r
.5507 .37472 m .54877 .37863 L .54845 .37618 L F
.5507 .37472 m .55095 .37766 L .54877 .37863 L F
0 0 0 r
.55095 .37766 m .54776 .38038 L .54877 .37863 L F
.548 .124 .189 r
.38907 .54984 m .38711 .5522 L .3835 .5507 L F
.342 0 0 r
.39147 .54995 m .38711 .5522 L .38907 .54984 L F
0 0 .127 r
.5283 .43826 m .52865 .44003 L .52989 .43838 L F
.5283 .43826 m .52855 .44294 L .52865 .44003 L F
.88 .932 .85 r
.31978 .56755 m .31645 .56828 L .31736 .56606 L F
0 0 0 r
.45986 .43005 m .46016 .42988 L .46189 .42846 L F
.45986 .43005 m .45845 .43168 L .46016 .42988 L F
.729 .401 .425 r
.35109 .51218 m .35541 .51022 L .35175 .51049 L F
.35109 .51218 m .35527 .5123 L .35541 .51022 L F
.994 .833 .576 r
.5438 .42696 m .54215 .42866 L .54287 .42726 L F
.5438 .42696 m .54351 .42996 L .54215 .42866 L F
.857 .602 .552 r
.3567 .53649 m .35267 .53592 L .35284 .53314 L F
.918 .739 .644 r
.3567 .53649 m .35269 .53863 L .35267 .53592 L F
.3567 .53649 m .3551 .53955 L .35269 .53863 L F
.97 .925 .61 r
.67292 .35639 m .67486 .35688 L .67409 .35485 L F
.67292 .35639 m .67379 .35927 L .67486 .35688 L F
.763 .802 .885 r
.31754 .62124 m .31315 .62123 L .31552 .61981 L F
.819 .875 .887 r
.31873 .6172 m .31754 .62124 L .31552 .61981 L F
.904 .976 .801 r
.63975 .35082 m .63883 .35005 L .63978 .34817 L F
.332 0 0 r
.64362 .34626 m .64286 .34701 L .6392 .34663 L F
.64286 .34701 m .64205 .34732 L .6392 .34663 L F
.904 .976 .801 r
.63975 .35082 m .63978 .34817 L .64039 .34794 L F
.417 .789 .994 r
.64205 .34732 m .63911 .34668 L .6392 .34663 L F
.64246 .34742 m .64162 .34723 L .64205 .34732 L F
.64162 .34723 m .63778 .34638 L .64205 .34732 L F
.63911 .34668 m .63778 .34638 L .63824 .34646 L F
.63911 .34668 m .63824 .34646 L .6392 .34663 L F
.64246 .34742 m .64078 .34618 L .63778 .34638 L F
.904 .976 .801 r
.63975 .35082 m .64078 .34618 L .64246 .34742 L F
.312 .218 .585 r
.64081 .34709 m .63883 .35005 L .64086 .34872 L F
.904 .976 .801 r
.64059 .34703 m .64038 .34698 L .64078 .34618 L F
.312 .218 .585 r
.64078 .34618 m .64038 .34698 L .64081 .34709 L F
.904 .976 .801 r
.64039 .34794 m .63978 .34817 L .64038 .34698 L F
.64039 .34794 m .64038 .34698 L .64059 .34703 L F
.312 .218 .585 r
.64038 .34698 m .63883 .35005 L .64081 .34709 L F
.332 0 0 r
.64286 .34701 m .64246 .34742 L .64205 .34732 L F
.62 .078 0 r
.64645 .34821 m .64246 .34742 L .64362 .34626 L F
.692 .396 .468 r
.28069 .55647 m .28477 .55368 L .28291 .55546 L F
.28069 .55647 m .28118 .55371 L .28477 .55368 L F
.178 .403 .843 r
.28583 .55229 m .28477 .55368 L .28272 .55012 L F
.589 .869 .545 r
.28291 .55546 m .28477 .55368 L .28583 .55229 L F
.858 .682 .663 r
.41936 .58033 m .41903 .58326 L .42016 .58341 L F
.68 .433 .541 r
.41658 .58651 m .42016 .58341 L .41903 .58326 L F
.41658 .58651 m .41936 .58628 L .42016 .58341 L F
.6 .628 .851 r
.42016 .58341 m .4217 .58037 L .41936 .58033 L F
.42016 .58341 m .4236 .58369 L .4217 .58037 L F
.613 .366 .519 r
.42016 .58341 m .42189 .58567 L .4236 .58369 L F
.42016 .58341 m .41936 .58628 L .42189 .58567 L F
.435 .857 .949 r
.59628 .3439 m .60097 .34232 L .60107 .34371 L F
0 .505 .779 r
.60097 .34232 m .6038 .34328 L .60107 .34371 L F
.918 .787 .701 r
.55347 .41264 m .55098 .41538 L .55031 .41384 L F
.964 .68 .255 r
.31983 .55983 m .31852 .55874 L .31838 .55614 L F
.898 .81 .752 r
.31983 .55983 m .31526 .56164 L .31852 .55874 L F
.31983 .55983 m .31795 .56381 L .31526 .56164 L F
.788 .683 .748 r
.42451 .57339 m .422 .57976 L .41976 .57379 L F
.989 .884 .62 r
.56311 .37923 m .5635 .37503 L .56378 .37662 L F
.173 0 .234 r
.2734 .65025 m .27141 .65134 L .2705 .65368 L F
.783 .96 .924 r
.43894 .56262 m .43713 .56173 L .43649 .56254 L F
.794 .864 .901 r
.43894 .56262 m .44032 .55844 L .43713 .56173 L F
.43894 .56262 m .44207 .55988 L .44032 .55844 L F
.997 .821 .469 r
.51868 .37179 m .5177 .37043 L .51955 .36865 L F
.589 .823 .439 r
.51955 .36865 m .52056 .36717 L .52185 .36551 L F
.598 .868 .535 r
.51955 .36865 m .5177 .37043 L .52056 .36717 L F
.667 .284 .31 r
.34853 .64908 m .35017 .64584 L .34622 .64658 L F
0 0 0 r
.35124 .64577 m .35017 .64584 L .34853 .64908 L F
.91 .666 .557 r
.50154 .45979 m .49892 .45887 L .499 .45603 L F
.96 .736 .556 r
.50083 .4629 m .49892 .45887 L .50154 .45979 L F
.901 .917 .822 r
.44139 .54562 m .44011 .54975 L .43935 .54929 L F
.828 .884 .883 r
.50676 .49212 m .5116 .49042 L .50962 .48884 L F
.814 .822 .856 r
.50962 .48884 m .5116 .49042 L .51447 .4874 L F
0 0 0 r
.6469 .37696 m .64277 .37857 L .645 .37688 L F
.611 .953 .91 r
.64943 .3755 m .6469 .37696 L .645 .37688 L F
.284 .784 .79 r
.60963 .36639 m .61171 .36562 L .6125 .36561 L F
.6125 .36561 m .61171 .36562 L .60963 .36639 L F
.581 .385 .581 r
.6125 .36561 m .61 .36946 L .60963 .36639 L F
0 0 .389 r
.61113 .36683 m .61 .36946 L .60963 .36639 L F
.61113 .36683 m .60963 .36639 L .60838 .36674 L F
.855 .916 .872 r
.44829 .53877 m .4503 .53594 L .45162 .53631 L F
.907 .978 .79 r
.45162 .53631 m .45284 .53234 L .45441 .53357 L F
.45162 .53631 m .4503 .53594 L .45284 .53234 L F
.627 .189 .188 r
.5729 .38944 m .57165 .3915 L .56875 .38951 L F
.548 .433 .674 r
.57444 .38668 m .57578 .38913 L .5729 .38944 L F
.622 .273 .359 r
.57578 .38913 m .57165 .3915 L .5729 .38944 L F
.614 .138 .101 r
.38169 .55106 m .38024 .5514 L .38157 .55016 L F
0 0 .156 r
.38308 .54891 m .38169 .55106 L .38157 .55016 L F
.835 .66 .666 r
.37666 .54913 m .38093 .55077 L .37952 .54505 L F
.38093 .55077 m .38169 .55106 L .38143 .55033 L F
0 0 0 r
.38199 .54981 m .38093 .55077 L .38217 .54966 L F
.38157 .55016 m .38093 .55077 L .38199 .54981 L F
.485 .472 .768 r
.37952 .54505 m .38143 .55033 L .38308 .54891 L F
.38143 .55033 m .38169 .55106 L .38308 .54891 L F
0 0 0 r
.38111 .5506 m .38046 .55119 L .38093 .55077 L F
.38157 .55016 m .38094 .55074 L .38111 .5506 L F
.38094 .55074 m .38046 .55119 L .38111 .5506 L F
.792 .659 .717 r
.38093 .55077 m .38024 .5514 L .38169 .55106 L F
.37666 .54913 m .38024 .5514 L .38093 .55077 L F
.835 .66 .666 r
.38093 .55077 m .38143 .55033 L .37952 .54505 L F
0 0 0 r
.38217 .54966 m .38024 .5514 L .38308 .54891 L F
.38046 .55119 m .38024 .5514 L .38217 .54966 L F
.777 .599 .658 r
.38609 .56024 m .38721 .5635 L .3895 .56055 L F
.787 .65 .711 r
.53451 .39229 m .53606 .39647 L .5319 .39585 L F
.412 .26 .563 r
.53441 .39756 m .5319 .39585 L .53606 .39647 L F
.715 .614 .743 r
.53861 .39331 m .53606 .39647 L .53451 .39229 L F
.484 .853 .616 r
.53534 .39682 m .53606 .39647 L .53895 .39593 L F
.53534 .39682 m .53441 .39756 L .53606 .39647 L F
.98 .824 .422 r
.52107 .37863 m .52035 .38171 L .52157 .3832 L F
0 0 .228 r
.52035 .38171 m .52105 .38473 L .52157 .3832 L F
.761 .479 .506 r
.25488 .59986 m .25074 .59953 L .25313 .59521 L F
.25488 .59986 m .25313 .59521 L .25346 .5973 L F
.562 .313 .496 r
.25516 .59378 m .25346 .5973 L .25313 .59521 L F
.44 .509 .834 r
.2569 .59243 m .25516 .59378 L .25349 .58988 L F
0 0 0 r
.25564 .59495 m .25516 .59378 L .2569 .59243 L F
.25564 .59495 m .25346 .5973 L .25516 .59378 L F
.612 .759 .949 r
.42623 .56331 m .42336 .56427 L .42456 .56243 L F
.807 .985 .717 r
.25669 .5672 m .25415 .57042 L .25448 .56984 L F
.374 .159 .454 r
.25394 .5711 m .25448 .56984 L .25415 .57042 L F
0 0 0 r
.4341 .44847 m .43568 .4467 L .43218 .44961 L F
.43772 .44556 m .43568 .4467 L .4341 .44847 L F
.184 0 .249 r
.42075 .46576 m .4182 .46876 L .41871 .46661 L F
0 .015 .581 r
.42931 .57761 m .42777 .57794 L .43055 .57581 L F
.42931 .57761 m .42906 .57986 L .42777 .57794 L F
.576 .529 .766 r
.40089 .55956 m .40246 .55586 L .39962 .55672 L F
.40089 .55956 m .40391 .55984 L .40246 .55586 L F
.46 .828 .993 r
.53962 .43253 m .54092 .43345 L .53644 .4333 L F
.9 .929 .826 r
.54351 .42996 m .54092 .43345 L .54087 .43008 L F
.927 .942 .788 r
.54087 .43008 m .54092 .43345 L .53962 .43253 L F
.979 .875 .66 r
.32797 .56871 m .32645 .57297 L .32795 .57395 L F
.936 .921 .773 r
.32645 .57297 m .32507 .57506 L .32795 .57395 L F
.841 .755 .768 r
.45842 .53949 m .4617 .53936 L .46033 .53695 L F
.45842 .53949 m .46062 .54073 L .4617 .53936 L F
.823 .85 .869 r
.46033 .53695 m .4617 .53936 L .46506 .53623 L F
.383 0 0 r
.29672 .52852 m .29487 .52883 L .29874 .5292 L F
.582 .595 .831 r
.31999 .68561 m .32074 .6888 L .32333 .68752 L F
.903 .645 .538 r
.35817 .54333 m .36031 .54692 L .35792 .54596 L F
.86 .601 .545 r
.36031 .54692 m .35768 .5488 L .35792 .54596 L F
.36031 .54692 m .36016 .5498 L .35768 .5488 L F
.865 .425 .027 r
.30581 .64806 m .3056 .64547 L .30335 .64652 L F
.30581 .64806 m .30768 .64962 L .3056 .64547 L F
.743 .717 .827 r
.52317 .45245 m .52419 .45646 L .52039 .45605 L F
.773 .595 .658 r
.52419 .45646 m .52201 .46002 L .52039 .45605 L F
.1 .23 .712 r
.60079 .35813 m .60228 .36347 L .60051 .36073 L F
.574 .931 .938 r
.41725 .59312 m .41282 .59362 L .41565 .5942 L F
.508 .137 .272 r
.52832 .42885 m .52581 .42799 L .52531 .42932 L F
.875 .49 .305 r
.66753 .34711 m .67043 .34654 L .66693 .3453 L F
.66753 .34711 m .67088 .34864 L .67043 .34654 L F
.863 .559 .472 r
.3469 .52371 m .34315 .52518 L .34338 .52242 L F
.3469 .52371 m .3468 .52613 L .34315 .52518 L F
.187 0 .314 r
.2859 .53601 m .28484 .53678 L .28702 .53336 L F
0 0 0 r
.28889 .53203 m .28702 .53336 L .29043 .5309 L F
.346 .124 .427 r
.28773 .53285 m .2859 .53601 L .28702 .53336 L F
.28668 .53498 m .2859 .53601 L .28773 .53285 L F
.755 .571 .648 r
.28287 .53297 m .28662 .53476 L .2873 .53371 L F
.28795 .5324 m .2873 .53371 L .28818 .53238 L F
.28287 .53297 m .2873 .53371 L .28795 .5324 L F
.346 .124 .427 r
.28889 .53203 m .28668 .53498 L .28773 .53285 L F
.639 .631 .826 r
.52413 .40604 m .51968 .40277 L .52241 .40195 L F
.748 .983 .752 r
.52212 .40679 m .52083 .40909 L .52413 .40604 L F
.61 .639 .854 r
.52614 .40318 m .52413 .40604 L .52241 .40195 L F
.475 .452 .753 r
.52614 .40318 m .52683 .40611 L .52413 .40604 L F
.596 .936 .75 r
.52526 .40437 m .52413 .40604 L .52683 .40611 L F
.52526 .40437 m .52212 .40679 L .52413 .40604 L F
.842 .558 .508 r
.34945 .5267 m .34673 .52885 L .3468 .52613 L F
.34945 .5267 m .34964 .52959 L .34673 .52885 L F
.157 0 .081 r
.37551 .52067 m .37422 .5229 L .37201 .52367 L F
.498 .903 .798 r
.35017 .63372 m .34811 .63494 L .3456 .63568 L F
.854 .922 .875 r
.49304 .50603 m .49458 .50179 L .49153 .50499 L F
.49304 .50603 m .49613 .503 L .49458 .50179 L F
.728 .782 .896 r
.51385 .45426 m .51036 .45523 L .51033 .45272 L F
.487 .871 .973 r
.25372 .57945 m .25606 .57556 L .25574 .57741 L F
.692 .875 .967 r
.5076 .40045 m .50688 .40282 L .50899 .40101 L F
.5076 .40045 m .50446 .40161 L .50688 .40282 L F
.468 .241 .486 r
.50899 .40101 m .5081 .40351 L .50688 .40282 L F
0 0 0 r
.29235 .52954 m .28889 .53203 L .29043 .5309 L F
.293 0 0 r
.54642 .40469 m .54435 .404 L .54289 .4041 L F
.765 .483 .507 r
.25313 .59521 m .25074 .59953 L .24855 .59822 L F
.794 .727 .79 r
.35484 .63676 m .35579 .63995 L .35153 .6402 L F
.772 .509 .538 r
.35153 .6402 m .35579 .63995 L .35593 .64315 L F
.2 .712 .891 r
.35619 .6394 m .35579 .63995 L .35521 .63801 L F
.577 .032 0 r
.35668 .64008 m .35619 .6394 L .35453 .63945 L F
.2 .712 .891 r
.35619 .6394 m .35856 .63981 L .35579 .63995 L F
.577 .032 0 r
.35678 .64011 m .35619 .6394 L .35668 .64008 L F
.2 .712 .891 r
.35619 .6394 m .35521 .63801 L .35484 .63676 L F
0 0 .134 r
.52959 .38863 m .53328 .38866 L .53069 .38636 L F
.674 .401 .499 r
.53069 .38636 m .53328 .38866 L .52959 .38863 L F
.424 0 0 r
.5184 .45518 m .51674 .4554 L .51385 .45426 L F
.425 .135 .368 r
.51385 .45426 m .51674 .4554 L .51687 .45318 L F
.51385 .45426 m .51674 .4554 L .51687 .45318 L F
.849 .896 .87 r
.32077 .64055 m .31754 .64242 L .32075 .63982 L F
.9 .929 .826 r
.54351 .42996 m .54087 .43008 L .54215 .42866 L F
.81 .977 .897 r
.66423 .37881 m .66653 .37519 L .66328 .3781 L F
.66423 .37881 m .66736 .37619 L .66653 .37519 L F
.609 .691 .901 r
.5709 .39799 m .57229 .40005 L .56996 .39908 L F
.627 .962 .849 r
.47353 .4308 m .47605 .4289 L .47399 .43039 L F
.897 .968 .822 r
.31347 .53847 m .31156 .5392 L .31419 .53586 L F
.106 .589 .909 r
.30494 .55842 m .30715 .55871 L .30737 .55979 L F
.513 .552 .833 r
.3072 .55897 m .30643 .56291 L .30737 .55979 L F
.30715 .55871 m .30662 .56177 L .3072 .55897 L F
.30662 .56177 m .30643 .56291 L .3072 .55897 L F
.568 .514 .754 r
.30378 .5608 m .30662 .56177 L .3063 .56334 L F
.30662 .56177 m .30916 .56264 L .3063 .56334 L F
.513 .552 .833 r
.30715 .55871 m .30916 .56264 L .30662 .56177 L F
.30715 .55871 m .30662 .56177 L .30378 .5608 L F
.30715 .55871 m .3063 .56334 L .30643 .56291 L F
.271 0 0 r
.40277 .47612 m .39834 .47779 L .40044 .47721 L F
.792 .882 .912 r
.55816 .42198 m .56328 .42035 L .56114 .41844 L F
.776 .611 .676 r
.56328 .42035 m .56119 .4165 L .56114 .41844 L F
.321 .737 .977 r
.6038 .34328 m .60768 .34297 L .60787 .34415 L F
.199 .67 .938 r
.60768 .34297 m .61003 .34362 L .60787 .34415 L F
.872 .615 .547 r
.38101 .52274 m .38116 .52554 L .38433 .52508 L F
.874 .622 .554 r
.38116 .52554 m .38341 .52941 L .38433 .52508 L F
.903 .686 .599 r
.36185 .55367 m .36142 .55651 L .35941 .5527 L F
0 0 0 r
.47064 .43253 m .47399 .43039 L .47342 .43089 L F
.47064 .43253 m .47127 .43306 L .46908 .43438 L F
.47064 .43253 m .47342 .43089 L .47127 .43306 L F
.326 .175 .518 r
.2859 .53601 m .28473 .53962 L .28484 .53678 L F
.847 .696 .695 r
.36142 .55651 m .36314 .56039 L .36083 .55931 L F
.885 .72 .672 r
.36314 .56039 m .35919 .56275 L .36083 .55931 L F
.36314 .56039 m .36263 .56313 L .35919 .56275 L F
.708 .925 .964 r
.30144 .62528 m .30334 .62634 L .30087 .6275 L F
.75 .959 .938 r
.30144 .62528 m .30087 .6275 L .29932 .62694 L F
0 0 .102 r
.41989 .58113 m .41936 .58033 L .4217 .58037 L F
.41989 .58113 m .41903 .58326 L .41936 .58033 L F
.747 .628 .727 r
.4133 .56422 m .41236 .56708 L .41654 .56714 L F
.521 .034 .041 r
.41182 .56864 m .41654 .56714 L .41236 .56708 L F
.41182 .56864 m .41498 .56893 L .41654 .56714 L F
0 0 0 r
.41654 .56714 m .41711 .56705 L .41866 .56593 L F
.41654 .56714 m .41498 .56893 L .41711 .56705 L F
.707 .196 .014 r
.65856 .33901 m .66303 .34153 L .66241 .33975 L F
.6 .552 .773 r
.54768 .40456 m .54921 .40518 L .54737 .40345 L F
0 0 .058 r
.32053 .63702 m .32064 .63831 L .31825 .63726 L F
.32053 .63702 m .32075 .63982 L .32064 .63831 L F
0 0 0 r
.47342 .43089 m .47399 .43039 L .47605 .4289 L F
.221 0 0 r
.50769 .42648 m .50361 .42925 L .50618 .42807 L F
.822 .387 .208 r
.34721 .62561 m .34879 .62373 L .34793 .6227 L F
.34721 .62561 m .34857 .62583 L .34879 .62373 L F
.33 0 0 r
.38308 .56848 m .38524 .56754 L .38733 .56818 L F
.582 .477 .7 r
.38721 .5635 m .38801 .56698 L .38524 .56754 L F
.358 0 .102 r
.38524 .56754 m .38801 .56698 L .38733 .56818 L F
.779 .904 .928 r
.31315 .62123 m .31031 .62374 L .30848 .62267 L F
.833 .533 .481 r
.3187 .65015 m .31483 .6471 L .31621 .65058 L F
0 0 0 r
.43181 .46112 m .43254 .46114 L .4298 .46166 L F
.587 .015 0 r
.28442 .67409 m .28648 .6747 L .28857 .67648 L F
.961 .721 .529 r
.33684 .51004 m .33413 .51107 L .33605 .50887 L F
.33684 .51004 m .33684 .51271 L .33413 .51107 L F
.162 .249 .707 r
.67378 .36206 m .67377 .36287 L .67408 .36452 L F
0 0 .073 r
.67408 .36452 m .67228 .3687 L .67435 .36593 L F
.67408 .36452 m .67372 .36658 L .67228 .3687 L F
.162 .249 .707 r
.67377 .36287 m .67372 .36658 L .67408 .36452 L F
0 0 .073 r
.67408 .36452 m .67435 .36593 L .67443 .36582 L F
.634 .082 0 r
.38264 .57306 m .38383 .57405 L .38609 .57389 L F
.38383 .57405 m .38478 .57482 L .38591 .57402 L F
.38383 .57405 m .38591 .57402 L .38609 .57389 L F
.933 .943 .777 r
.38258 .57131 m .38073 .57555 L .38235 .57615 L F
.862 .969 .863 r
.38235 .57615 m .38073 .57555 L .38191 .57407 L F
.789 .715 .18 r
.38302 .5691 m .38258 .57131 L .38264 .57306 L F
.38308 .56848 m .38258 .57131 L .38302 .5691 L F
.483 .583 .878 r
.38253 .57238 m .38246 .57381 L .38376 .57175 L F
.38246 .57381 m .38235 .57615 L .38302 .57406 L F
.38246 .57381 m .38302 .57406 L .38376 .57175 L F
.38258 .57131 m .3834 .57253 L .38235 .57615 L F
.862 .969 .863 r
.38302 .57406 m .38296 .57406 L .38339 .57282 L F
.38338 .57293 m .38339 .57282 L .38375 .57179 L F
.38338 .57293 m .38375 .57179 L .38375 .57179 L F
.38302 .57406 m .38339 .57282 L .38338 .57293 L F
.634 .082 0 r
.38478 .57482 m .38526 .57503 L .38609 .57389 L F
.261 .463 .868 r
.38545 .5733 m .38517 .57515 L .3834 .57253 L F
.862 .969 .863 r
.38296 .57406 m .38356 .572 L .38376 .57175 L F
.261 .463 .868 r
.38545 .5733 m .38358 .5726 L .38344 .57191 L F
.38358 .5726 m .3834 .57253 L .38342 .57217 L F
.862 .969 .863 r
.38296 .57406 m .38191 .57407 L .38356 .572 L F
.261 .463 .868 r
.38358 .5726 m .38342 .57217 L .38344 .57191 L F
.38344 .57191 m .3834 .57253 L .38298 .57191 L F
.38342 .5719 m .38298 .57191 L .38258 .57131 L F
.38344 .57191 m .38298 .57191 L .38342 .5719 L F
.679 .604 .765 r
.37875 .57083 m .38073 .57555 L .38258 .57131 L F
.962 .694 .479 r
.37875 .57083 m .38073 .57555 L .37858 .57355 L F
.799 .804 .855 r
.38332 .5719 m .38073 .57555 L .37858 .57355 L F
.38342 .57217 m .38073 .57555 L .38332 .5719 L F
.741 .348 .308 r
.38335 .57194 m .38117 .57308 L .38344 .57191 L F
.113 0 0 r
.37858 .57355 m .38117 .57308 L .38335 .57194 L F
.741 .348 .308 r
.38154 .57261 m .38117 .57308 L .38335 .57194 L F
.113 0 0 r
.38335 .57194 m .38117 .57308 L .38347 .5719 L F
.799 .804 .855 r
.38376 .57175 m .38342 .57217 L .38332 .5719 L F
.807 .412 .305 r
.37915 .56559 m .38308 .56848 L .38169 .56423 L F
.38041 .56652 m .37969 .56809 L .38308 .56848 L F
.37915 .56559 m .37969 .56809 L .38041 .56652 L F
0 0 .311 r
.38017 .56605 m .37964 .56784 L .37915 .56559 L F
.727 .574 .682 r
.38017 .56605 m .37933 .56889 L .37969 .56809 L F
.37933 .56889 m .37875 .57083 L .37969 .56809 L F
.675 .342 .402 r
.37875 .57083 m .38308 .56848 L .37969 .56809 L F
.37875 .57083 m .38258 .57131 L .38308 .56848 L F
.844 .911 .506 r
.38017 .56605 m .37969 .56809 L .38169 .56423 L F
.38017 .56605 m .37969 .56809 L .38169 .56423 L F
.727 .574 .682 r
.38017 .56605 m .3776 .56932 L .37875 .57083 L F
.38017 .56605 m .38313 .56998 L .3776 .56932 L F
.668 .202 0 r
.38137 .56778 m .38285 .56968 L .3814 .56771 L F
.38285 .56968 m .38313 .56998 L .38017 .56605 L F
.518 .404 .664 r
.38308 .56848 m .38511 .56657 L .38169 .56423 L F
.741 .348 .308 r
.38258 .57131 m .38339 .57025 L .3841 .571 L F
.3841 .571 m .38366 .5699 L .38564 .57069 L F
.38339 .57025 m .38366 .5699 L .3841 .571 L F
.38366 .5699 m .38435 .5698 L .38564 .57069 L F
.113 0 0 r
.38332 .5719 m .38342 .5719 L .38376 .57175 L F
.261 .463 .868 r
.3856 .57124 m .38258 .57131 L .38564 .57069 L F
.38545 .5733 m .38342 .5719 L .3856 .57124 L F
.113 0 0 r
.38342 .5719 m .38353 .57186 L .38376 .57175 L F
.862 .969 .863 r
.38375 .57179 m .38375 .57179 L .38376 .57175 L F
.261 .463 .868 r
.38342 .5719 m .38258 .57131 L .3856 .57124 L F
.113 0 0 r
.38342 .5719 m .38348 .57189 L .38353 .57186 L F
.741 .348 .308 r
.38258 .57131 m .38342 .5719 L .38395 .56952 L F
.38366 .5699 m .38395 .56952 L .38435 .5698 L F
.38342 .5719 m .38484 .57178 L .38395 .56952 L F
.727 .574 .682 r
.38313 .56998 m .38459 .57192 L .38042 .57038 L F
.741 .348 .308 r
.38342 .5719 m .38545 .5733 L .38484 .57178 L F
.992 .746 .449 r
.38545 .5733 m .38473 .57293 L .38443 .57075 L F
.727 .574 .682 r
.38459 .57192 m .38463 .57196 L .3846 .57195 L F
.38459 .57192 m .3846 .57195 L .38042 .57038 L F
.38313 .56998 m .38042 .57038 L .3776 .56932 L F
.842 .654 .648 r
.38043 .57005 m .38459 .57195 L .38137 .56778 L F
.38459 .57195 m .38463 .57196 L .38458 .5719 L F
.38459 .57195 m .38458 .5719 L .38137 .56778 L F
.668 .202 0 r
.38285 .56968 m .38458 .5719 L .38313 .56998 L F
.38458 .5719 m .38463 .57196 L .38459 .57192 L F
.38458 .5719 m .38459 .57192 L .38313 .56998 L F
.74 .647 .756 r
.38137 .56778 m .38458 .5719 L .38395 .56952 L F
.634 .082 0 r
.38478 .57482 m .38517 .57515 L .38526 .57503 L F
.483 .583 .878 r
.3834 .57253 m .38517 .57515 L .38235 .57615 L F
.741 .348 .308 r
.38344 .57191 m .38117 .57308 L .38545 .5733 L F
.048 .539 .886 r
.3776 .56932 m .3846 .57195 L .38043 .57005 L F
.992 .746 .449 r
.38473 .57293 m .38378 .57244 L .38411 .5716 L F
.3846 .57195 m .38411 .5716 L .38443 .57075 L F
.38473 .57293 m .38411 .5716 L .3846 .57195 L F
.048 .539 .886 r
.3846 .57195 m .38463 .57196 L .38459 .57195 L F
.3846 .57195 m .38459 .57195 L .38043 .57005 L F
.74 .647 .756 r
.38458 .5719 m .38463 .57196 L .38395 .56952 L F
.992 .746 .449 r
.38442 .57071 m .38433 .57096 L .38395 .56952 L F
.38433 .57096 m .38416 .57142 L .38395 .56952 L F
.38416 .57142 m .38378 .57244 L .38386 .57109 L F
.38416 .57142 m .38386 .57109 L .38395 .56952 L F
.38443 .57075 m .38443 .57077 L .38442 .57071 L F
.38443 .57077 m .38378 .57244 L .38442 .57071 L F
.776 .567 .616 r
.38327 .5667 m .38123 .56813 L .38137 .56778 L F
.932 .778 .668 r
.37777 .56853 m .38043 .57005 L .38137 .56778 L F
.776 .567 .616 r
.38123 .56813 m .38102 .56828 L .38137 .56778 L F
.668 .202 0 r
.38137 .56778 m .3814 .56771 L .38017 .56605 L F
.113 0 0 r
.38342 .5719 m .38347 .5719 L .38348 .57189 L F
.37858 .57355 m .38335 .57194 L .38332 .5719 L F
.741 .348 .308 r
.38258 .57131 m .38154 .57261 L .38335 .57194 L F
.38342 .5719 m .38335 .57194 L .38344 .57191 L F
.113 0 0 r
.38335 .57194 m .38342 .5719 L .38332 .5719 L F
.741 .348 .308 r
.38258 .57131 m .38335 .57194 L .38342 .5719 L F
.113 0 0 r
.38335 .57194 m .38347 .5719 L .38342 .5719 L F
.721 .323 .294 r
.38376 .57175 m .38235 .57247 L .38258 .57131 L F
.38235 .57247 m .38117 .57308 L .38258 .57131 L F
.862 .969 .863 r
.38235 .57615 m .38191 .57407 L .38302 .57406 L F
.602 .045 0 r
.38517 .57515 m .3894 .57624 L .38609 .57389 L F
.451 0 0 r
.38609 .57389 m .3894 .57624 L .39049 .57681 L F
.59 .819 .987 r
.39704 .59178 m .39763 .59295 L .4004 .59195 L F
.788 .683 .748 r
.42451 .57339 m .41976 .57379 L .42304 .57196 L F
.862 .738 .725 r
.45842 .53949 m .45984 .54339 L .46062 .54073 L F
.054 .449 .878 r
.29581 .6577 m .29746 .65961 L .29611 .65831 L F
.495 .727 .975 r
.29957 .65882 m .29746 .65961 L .29581 .6577 L F
.632 .751 .934 r
.30141 .65974 m .29746 .65961 L .29957 .65882 L F
0 .179 .646 r
.58561 .39964 m .58844 .40159 L .58682 .40019 L F
.3 .278 .666 r
.58561 .39964 m .58666 .40311 L .58844 .40159 L F
.602 .923 .97 r
.50948 .42057 m .51327 .41981 L .51192 .41929 L F
.029 0 .304 r
.51508 .41836 m .51327 .41981 L .51508 .41608 L F
.583 .941 .916 r
.51192 .41929 m .51327 .41981 L .51508 .41836 L F
.401 .824 .651 r
.5398 .38274 m .54169 .3815 L .54265 .38209 L F
.5398 .38274 m .53745 .38403 L .54169 .3815 L F
.713 .8 .329 r
.5721 .37261 m .57133 .37428 L .5709 .37571 L F
.766 .304 0 r
.57071 .37672 m .5709 .37571 L .57133 .37428 L F
.57071 .37672 m .57255 .37852 L .5709 .37571 L F
.754 .359 .304 r
.30843 .58609 m .31199 .58724 L .31127 .58814 L F
.484 .041 .12 r
.31127 .58814 m .31199 .58724 L .31377 .58831 L F
.769 .908 .52 r
.32633 .68702 m .32914 .68275 L .32852 .68586 L F
.197 0 .332 r
.32989 .68089 m .33138 .6826 L .32914 .68275 L F
.07 0 .126 r
.32852 .68586 m .32914 .68275 L .33138 .6826 L F
.798 .999 .816 r
.44778 .55234 m .44637 .55219 L .4433 .55525 L F
.749 .783 .88 r
.44778 .55234 m .44675 .54891 L .44637 .55219 L F
.44778 .55234 m .45041 .54969 L .44675 .54891 L F
.328 .187 .531 r
.28473 .53962 m .28463 .54267 L .28264 .54342 L F
.286 .102 .447 r
.28463 .54267 m .28242 .54635 L .28264 .54342 L F
.302 0 0 r
.40264 .46833 m .4014 .46688 L .4002 .46904 L F
.40264 .46833 m .4043 .46645 L .4014 .46688 L F
.659 .696 .873 r
.30387 .67999 m .30569 .68358 L .30764 .68111 L F
0 0 .045 r
.56862 .39124 m .56613 .3952 L .56705 .39255 L F
.806 .887 .903 r
.49613 .503 m .49781 .49878 L .49458 .50179 L F
.49613 .503 m .4995 .50003 L .49781 .49878 L F
0 .229 .746 r
.37522 .47632 m .37776 .47985 L .37805 .47861 L F
0 0 0 r
.34896 .641 m .35153 .6402 L .3488 .64147 L F
.046 0 .086 r
.26985 .5711 m .26923 .57467 L .267 .57575 L F
.192 .151 .579 r
.27196 .5689 m .26985 .5711 L .26969 .56949 L F
.27196 .5689 m .27251 .57189 L .26985 .5711 L F
.677 .432 .543 r
.27251 .57189 m .26923 .57467 L .26985 .5711 L F
.981 .898 .56 r
.41886 .57181 m .41976 .57379 L .42092 .57054 L F
.057 .278 .769 r
.42154 .56851 m .42304 .57196 L .42092 .57054 L F
.866 .733 .714 r
.42304 .57196 m .41886 .57181 L .42092 .57054 L F
.575 .233 .353 r
.28119 .64554 m .28162 .64348 L .27891 .64337 L F
.28119 .64554 m .28162 .64348 L .27891 .64337 L F
.755 .758 .855 r
.28119 .64554 m .28085 .64364 L .28162 .64348 L F
.037 0 0 r
.27891 .64337 m .28222 .64337 L .28162 .64348 L F
.593 .611 .839 r
.27891 .64337 m .28162 .64348 L .28008 .63907 L F
.755 .758 .855 r
.28085 .64364 m .28026 .64035 L .28162 .64348 L F
.037 0 0 r
.28222 .64337 m .28335 .64336 L .28162 .64348 L F
.75 .268 .096 r
.28162 .64348 m .28335 .64336 L .28558 .64657 L F
.879 .53 .383 r
.66339 .34378 m .66654 .34301 L .66303 .34153 L F
.66339 .34378 m .66693 .3453 L .66654 .34301 L F
0 .486 .853 r
.30195 .65937 m .30141 .65974 L .29957 .65882 L F
.30195 .65937 m .30408 .66074 L .30141 .65974 L F
.984 .752 .506 r
.35253 .63551 m .35508 .63384 L .3524 .63361 L F
.35253 .63551 m .35484 .63676 L .35508 .63384 L F
.799 .99 .744 r
.53763 .40457 m .53543 .40692 L .53658 .40492 L F
0 0 0 r
.53763 .40457 m .53658 .40492 L .54009 .4043 L F
.418 .444 .78 r
.56552 .35607 m .56837 .35561 L .56638 .354 L F
.317 0 .134 r
.41066 .4625 m .4132 .46184 L .41399 .46029 L F
.254 0 .103 r
.4132 .46184 m .41658 .45953 L .41399 .46029 L F
.632 .894 .986 r
.55663 .40411 m .55591 .40637 L .55873 .40494 L F
.55663 .40411 m .55591 .40637 L .55873 .40494 L F
.954 .91 .736 r
.55873 .40494 m .55549 .40915 L .55591 .40637 L F
.967 .884 .698 r
.55062 .43901 m .55177 .43651 L .55041 .43526 L F
.927 .891 .774 r
.55177 .43651 m .55267 .43132 L .55041 .43526 L F
.322 .506 .883 r
.49896 .4333 m .50292 .43555 L .50195 .43232 L F
.723 .598 .716 r
.53766 .38875 m .53861 .39331 L .53451 .39229 L F
0 .029 .568 r
.53915 .39089 m .53861 .39331 L .53766 .38875 L F
.912 .628 .134 r
.5382 .39496 m .53861 .39331 L .53915 .39089 L F
.5382 .39496 m .53895 .39593 L .53861 .39331 L F
.933 .572 .309 r
.56114 .41844 m .56119 .4165 L .55926 .41742 L F
.698 .903 .969 r
.56119 .4165 m .56249 .41578 L .56173 .41381 L F
.862 .985 .707 r
.55926 .41742 m .56119 .4165 L .56173 .41381 L F
.933 .572 .309 r
.56114 .41844 m .56119 .4165 L .55926 .41742 L F
.809 .716 .762 r
.45842 .53949 m .45579 .54305 L .45984 .54339 L F
.561 .877 .993 r
.54061 .41656 m .53931 .41769 L .54195 .41658 L F
.98 .915 .641 r
.53849 .41621 m .53845 .41844 L .53931 .41769 L F
.893 .483 .073 r
.53849 .41621 m .53931 .41769 L .53751 .41652 L F
.561 .877 .993 r
.53751 .41652 m .53931 .41769 L .54061 .41656 L F
.98 .915 .641 r
.53845 .41844 m .53842 .42025 L .53931 .41769 L F
0 0 0 r
.53842 .42025 m .53898 .42055 L .53931 .41769 L F
.44 .265 .547 r
.25448 .56984 m .25727 .56603 L .25669 .5672 L F
.722 .393 .421 r
.31037 .51841 m .31379 .52214 L .31688 .51936 L F
.804 .518 .505 r
.31688 .51936 m .31805 .52273 L .31831 .52004 L F
.31688 .51936 m .31379 .52214 L .31805 .52273 L F
.712 .781 .906 r
.50313 .48435 m .4988 .48372 L .50158 .48266 L F
.682 .814 .946 r
.50571 .48312 m .50313 .48435 L .50158 .48266 L F
.748 .966 .933 r
.29052 .63255 m .28716 .63348 L .28887 .63169 L F
.733 .905 .955 r
.29203 .62956 m .29052 .63255 L .28887 .63169 L F
.29203 .62956 m .29401 .63057 L .29052 .63255 L F
.705 .877 .48 r
.67098 .37021 m .66982 .37264 L .67228 .3687 L F
.609 .845 .472 r
.67228 .3687 m .67372 .36658 L .67098 .37021 L F
.894 .752 .698 r
.3202 .58208 m .32427 .58005 L .32268 .57876 L F
.3202 .58208 m .32247 .58368 L .32427 .58005 L F
.927 .923 .787 r
.32507 .57506 m .32268 .57876 L .32427 .58005 L F
.755 .571 .648 r
.28287 .53297 m .28724 .53248 L .28411 .53237 L F
.28724 .53248 m .28728 .53237 L .28411 .53237 L F
.477 .897 .855 r
.28673 .53368 m .28614 .53387 L .28701 .53115 L F
.28662 .53476 m .28643 .53441 L .28673 .53368 L F
.28643 .53441 m .28614 .53387 L .28673 .53368 L F
.755 .571 .648 r
.28724 .53248 m .28818 .53238 L .28728 .53237 L F
.909 .974 .683 r
.28818 .53238 m .28701 .53115 L .29164 .52895 L F
.28818 .53238 m .28662 .53476 L .28701 .53115 L F
.791 .527 .538 r
.31831 .52004 m .31805 .52273 L .32267 .52333 L F
.746 .228 0 r
.65151 .36283 m .65511 .36587 L .65093 .36551 L F
.812 .552 .545 r
.65511 .36587 m .6509 .3678 L .65093 .36551 L F
.65511 .36587 m .65568 .36908 L .6509 .3678 L F
.712 .979 .913 r
.54669 .41593 m .54749 .41661 L .54813 .41521 L F
.659 .256 .27 r
.28041 .53226 m .28287 .53297 L .28411 .53237 L F
.458 .632 .929 r
.50573 .41952 m .50948 .42057 L .50745 .41695 L F
.756 .814 .899 r
.33077 .61073 m .33187 .61327 L .32768 .61288 L F
.79 .776 .839 r
.32768 .61288 m .33187 .61327 L .32957 .61447 L F
.758 .815 .898 r
.33438 .61055 m .33187 .61327 L .33077 .61073 L F
.782 .317 .139 r
.54921 .40518 m .55233 .4018 L .54737 .40345 L F
.724 .598 .715 r
.50966 .46673 m .50933 .46957 L .50706 .47006 L F
.789 .668 .729 r
.50933 .46957 m .5068 .47288 L .50706 .47006 L F
.754 .659 .756 r
.51231 .46585 m .50933 .46957 L .50966 .46673 L F
.809 .562 .566 r
.31803 .52541 m .32267 .52333 L .31805 .52273 L F
.31803 .52541 m .32252 .52618 L .32267 .52333 L F
.786 .542 .567 r
.32252 .52618 m .32479 .52659 L .32267 .52333 L F
0 .566 .724 r
.30005 .58004 m .30225 .58012 L .30423 .58024 L F
.30005 .58004 m .30225 .58012 L .30423 .58024 L F
.826 .955 .9 r
.30423 .58024 m .30225 .58012 L .30527 .57719 L F
.705 .289 .255 r
.30588 .58162 m .30225 .58012 L .30423 .58024 L F
.30496 .58138 m .30225 .58012 L .30588 .58162 L F
.373 .659 .968 r
.30062 .57802 m .30225 .58012 L .30005 .58004 L F
.56 .196 .307 r
.30225 .58012 m .29908 .58151 L .30005 .58004 L F
.30225 .58012 m .30271 .58196 L .29908 .58151 L F
.828 .693 .714 r
.30062 .57802 m .30527 .57719 L .30225 .58012 L F
.705 .289 .255 r
.30636 .58202 m .30271 .58196 L .30225 .58012 L F
.828 .693 .714 r
.30062 .57802 m .30192 .58058 L .30527 .57719 L F
.30192 .58058 m .30213 .58099 L .30237 .5807 L F
.30192 .58058 m .30237 .5807 L .30527 .57719 L F
.705 .289 .255 r
.30636 .58202 m .30496 .58138 L .30588 .58162 L F
.062 0 0 r
.64807 .33908 m .6518 .33905 L .64911 .33867 L F
.853 .773 .773 r
.50873 .47691 m .50421 .47895 L .50666 .47558 L F
.50873 .47691 m .50649 .47998 L .50421 .47895 L F
.198 .43 .859 r
.57734 .37865 m .58107 .38226 L .57821 .38265 L F
.216 0 .02 r
.58107 .38226 m .57764 .38489 L .57821 .38265 L F
.422 .835 .652 r
.48417 .42425 m .48239 .42551 L .4858 .42301 L F
.48417 .42425 m .48198 .42566 L .48239 .42551 L F
.017 .114 .623 r
.3299 .63944 m .33066 .64395 L .32921 .64089 L F
.921 .783 .691 r
.32924 .55872 m .32755 .56253 L .33044 .56282 L F
.933 .772 .658 r
.32686 .56537 m .33044 .56282 L .32755 .56253 L F
.32686 .56537 m .32887 .56653 L .33044 .56282 L F
.841 .8 .811 r
.41225 .47256 m .41273 .47539 L .40976 .476 L F
.095 0 .422 r
.41505 .47235 m .41273 .47539 L .41225 .47256 L F
.41505 .47235 m .41518 .47488 L .41273 .47539 L F
.729 .375 0 r
.40054 .53519 m .40226 .53915 L .40158 .53723 L F
.40158 .53723 m .40226 .53915 L .40054 .53519 L F
.658 .429 .56 r
.36867 .5182 m .37308 .51605 L .3705 .51645 L F
.576 .856 .524 r
.50673 .3925 m .50819 .39069 L .5096 .38933 L F
.869 .991 .734 r
.5096 .38933 m .51164 .38502 L .51225 .38581 L F
.5096 .38933 m .5092 .38849 L .51164 .38502 L F
.922 .913 .522 r
.5096 .38933 m .50819 .39069 L .5092 .38849 L F
.823 .85 .869 r
.46033 .53695 m .46506 .53623 L .46365 .53532 L F
.845 .948 .885 r
.4667 .53233 m .46506 .53623 L .46795 .53312 L F
.4667 .53233 m .46365 .53532 L .46506 .53623 L F
.778 .52 .545 r
.51119 .39952 m .50843 .39887 L .50899 .40101 L F
.949 .941 .742 r
.50843 .39887 m .5076 .40045 L .50899 .40101 L F
.778 .52 .545 r
.51119 .39952 m .50988 .39991 L .50843 .39887 L F
.827 .884 .884 r
.51302 .39482 m .51119 .39952 L .51402 .39812 L F
.51302 .39482 m .50988 .39991 L .51119 .39952 L F
.647 .624 .813 r
.51302 .39482 m .51341 .39808 L .50988 .39991 L F
0 0 .079 r
.50899 .40101 m .51022 .39995 L .51028 .39993 L F
.50995 .40036 m .51028 .39993 L .51119 .39952 L F
.50899 .40101 m .51028 .39993 L .50995 .40036 L F
.647 .624 .813 r
.51341 .39808 m .51029 .39991 L .50988 .39991 L F
.207 .712 .903 r
.51029 .39991 m .51033 .39986 L .50988 .39991 L F
0 0 .079 r
.51022 .39995 m .51049 .3998 L .51119 .39952 L F
.754 .994 .867 r
.51402 .39812 m .51271 .40011 L .51816 .39596 L F
.647 .624 .813 r
.51341 .39808 m .51364 .39997 L .51207 .39994 L F
.682 .262 0 r
.51259 .40037 m .51439 .40255 L .51199 .40028 L F
.51204 .40004 m .51199 .40028 L .51119 .39952 L F
.51259 .40037 m .51199 .40028 L .51204 .40004 L F
0 .353 .818 r
.51308 .40067 m .51439 .40255 L .51183 .40013 L F
.51198 .4 m .51183 .40013 L .51119 .39952 L F
.51308 .40067 m .51183 .40013 L .51198 .4 L F
.647 .624 .813 r
.51032 .39989 m .51089 .39991 L .51029 .39991 L F
.667 .214 .166 r
.51033 .39986 m .51308 .40067 L .51259 .40037 L F
.647 .624 .813 r
.51089 .39991 m .51095 .39992 L .51029 .39991 L F
0 0 .079 r
.51022 .39995 m .51033 .39986 L .51049 .3998 L F
.207 .712 .903 r
.51095 .39992 m .51033 .39986 L .51029 .39991 L F
.667 .214 .166 r
.51095 .39992 m .51204 .40004 L .51119 .39952 L F
.647 .624 .813 r
.51089 .39991 m .51207 .39994 L .51095 .39992 L F
.667 .214 .166 r
.51049 .3998 m .51095 .39992 L .51119 .39952 L F
.647 .624 .813 r
.5113 .39932 m .51205 .39993 L .51032 .39989 L F
.51205 .39993 m .51207 .39994 L .51032 .39989 L F
.207 .712 .903 r
.51207 .39994 m .51033 .39986 L .51095 .39992 L F
.667 .214 .166 r
.51095 .39992 m .51259 .40037 L .51204 .40004 L F
.51033 .39986 m .51259 .40037 L .51049 .3998 L F
.207 .712 .903 r
.51207 .39992 m .5125 .39941 L .51033 .39986 L F
.51364 .39997 m .5126 .39946 L .51207 .39992 L F
.5126 .39946 m .5125 .39941 L .51207 .39992 L F
.51364 .39997 m .51207 .39992 L .51207 .39994 L F
.51207 .39992 m .51033 .39986 L .51207 .39994 L F
.647 .624 .813 r
.51341 .39808 m .51207 .39994 L .5113 .39932 L F
.682 .262 0 r
.51308 .40067 m .51325 .40091 L .51259 .40037 L F
.51325 .40091 m .51439 .40255 L .51259 .40037 L F
0 0 .079 r
.50899 .40101 m .5081 .40351 L .51033 .39986 L F
.847 .907 .877 r
.45753 .53044 m .45441 .53357 L .45284 .53234 L F
.805 .73 .782 r
.3787 .52255 m .37626 .52675 L .37422 .5229 L F
.006 .564 .812 r
.51328 .43914 m .51722 .43993 L .51589 .43947 L F
.51589 .43947 m .51722 .43993 L .51328 .43914 L F
.896 .95 .832 r
.51814 .43567 m .51722 .43993 L .51589 .43947 L F
.51814 .43567 m .5201 .43629 L .51722 .43993 L F
0 .539 .796 r
.51589 .43947 m .51722 .43993 L .51934 .44016 L F
.006 .564 .812 r
.51589 .43947 m .51722 .43993 L .51328 .43914 L F
.064 0 .185 r
.32825 .65736 m .3309 .65409 L .3295 .65604 L F
.887 .889 .827 r
.3295 .65604 m .32853 .66059 L .32825 .65736 L F
.345 .175 .502 r
.25742 .55959 m .2595 .559 L .25784 .55679 L F
.697 .805 .932 r
.29874 .5292 m .29736 .53095 L .29487 .52883 L F
.961 .802 .64 r
.38221 .55145 m .38208 .5537 L .3835 .5507 L F
.542 .059 .06 r
.3835 .5507 m .38711 .5522 L .38221 .55145 L F
.931 .964 .762 r
.3835 .5507 m .38221 .55145 L .38308 .54891 L F
.467 .114 .283 r
.41606 .4696 m .41505 .47235 L .41225 .47256 L F
.135 0 .057 r
.4182 .46876 m .41505 .47235 L .41606 .4696 L F
0 0 0 r
.62923 .39324 m .63064 .39333 L .62796 .393 L F
.028 .574 .838 r
.63189 .39301 m .63353 .39277 L .63064 .39333 L F
0 0 0 r
.63292 .39205 m .63064 .39333 L .63353 .39277 L F
.63292 .39205 m .63114 .39345 L .63064 .39333 L F
.63114 .39345 m .62945 .39478 L .63064 .39333 L F
.62923 .39324 m .63004 .39317 L .63064 .39333 L F
.63004 .39317 m .63189 .39301 L .63064 .39333 L F
.887 .889 .827 r
.3295 .65604 m .33151 .65729 L .32853 .66059 L F
.954 .91 .736 r
.55873 .40494 m .55756 .40993 L .55549 .40915 L F
.817 .614 .628 r
.55756 .40993 m .55555 .41106 L .55549 .40915 L F
.55756 .40993 m .55719 .41295 L .55555 .41106 L F
.591 .155 .18 r
.60944 .34907 m .60827 .35106 L .60543 .35052 L F
.271 0 .02 r
.61071 .35038 m .60944 .34907 L .61215 .34883 L F
.61071 .35038 m .60827 .35106 L .60944 .34907 L F
.489 .456 .747 r
.28168 .6725 m .28317 .66611 L .28103 .66628 L F
.758 .886 .936 r
.31151 .68449 m .31312 .6842 L .31123 .68241 L F
.994 .777 .501 r
.31123 .68241 m .31312 .6842 L .31216 .68663 L F
.193 .579 .94 r
.34147 .61268 m .33964 .61264 L .33685 .61039 L F
.889 .989 .746 r
.66736 .37619 m .66982 .37264 L .66786 .37307 L F
.758 .993 .799 r
.66786 .37307 m .66982 .37264 L .67098 .37021 L F
0 0 0 r
.59246 .39103 m .59066 .39273 L .59308 .38913 L F
.68 .903 .558 r
.59397 .38743 m .59308 .38913 L .59575 .38566 L F
0 0 0 r
.59397 .38743 m .59246 .39103 L .59308 .38913 L F
.032 0 0 r
.42841 .45209 m .43088 .45119 L .43218 .44961 L F
0 0 0 r
.43218 .44961 m .43088 .45119 L .4341 .44847 L F
.149 0 .075 r
.44455 .57244 m .44791 .56986 L .44582 .57119 L F
.825 .933 .902 r
.33812 .62624 m .34178 .62491 L .33914 .62509 L F
0 .311 .701 r
.34178 .62491 m .34245 .62501 L .33914 .62509 L F
.34178 .62491 m .34415 .626 L .34245 .62501 L F
.96 .736 .556 r
.50083 .4629 m .49832 .46162 L .49892 .45887 L F
.975 .853 .656 r
.50083 .4629 m .4981 .46513 L .49832 .46162 L F
.50083 .4629 m .49938 .46658 L .4981 .46513 L F
.916 .974 .692 r
.51225 .38581 m .51375 .38124 L .515 .38216 L F
.51225 .38581 m .51164 .38502 L .51375 .38124 L F
.519 .694 .948 r
.58483 .41173 m .5885 .41311 L .58653 .41133 L F
1 .822 .509 r
.5885 .41311 m .5876 .4091 L .58653 .41133 L F
.955 .825 .675 r
.54035 .45779 m .54215 .45918 L .54105 .45549 L F
.909 .918 .812 r
.53807 .46152 m .54215 .45918 L .54035 .45779 L F
.53807 .46152 m .5395 .46279 L .54215 .45918 L F
.853 .79 .79 r
.54105 .45549 m .54215 .45918 L .54305 .4571 L F
.812 .73 .774 r
.50195 .43232 m .50493 .43179 L .50361 .42925 L F
.795 .605 .645 r
.50292 .43555 m .50493 .43179 L .50195 .43232 L F
.799 .725 .783 r
.50361 .42925 m .50493 .43179 L .50618 .42807 L F
.889 .989 .746 r
.66736 .37619 m .66786 .37307 L .66653 .37519 L F
.432 .862 .749 r
.32989 .68089 m .33206 .67983 L .3319 .67973 L F
0 0 0 r
.33206 .67983 m .3338 .67905 L .3319 .67973 L F
.50673 .3925 m .50571 .39422 L .50819 .39069 L F
.386 .276 .605 r
.56268 .35978 m .56473 .3613 L .5656 .35842 L F
.919 .951 .798 r
.515 .38216 m .51703 .37698 L .51798 .3793 L F
.515 .38216 m .51375 .38124 L .51703 .37698 L F
0 .548 .762 r
.63614 .39361 m .63464 .39325 L .63189 .39301 L F
.383 .824 .949 r
.63614 .39361 m .63677 .39221 L .63464 .39325 L F
.63614 .39361 m .63997 .39292 L .63677 .39221 L F
.152 .649 .912 r
.3107 .59283 m .31397 .59348 L .31229 .59265 L F
.3107 .59283 m .31397 .59348 L .31229 .59265 L F
0 .113 .66 r
.55856 .36618 m .5603 .36847 L .55908 .36524 L F
0 0 .497 r
.59278 .39333 m .59066 .39273 L .59246 .39103 L F
.59278 .39333 m .59122 .39532 L .59066 .39273 L F
.609 .691 .901 r
.5709 .39799 m .56996 .39908 L .56766 .39888 L F
.84 .656 .654 r
.34536 .61976 m .34292 .61665 L .34301 .61909 L F
.769 .275 .046 r
.34501 .62175 m .34536 .61976 L .34301 .61909 L F
.34501 .62175 m .34793 .6227 L .34536 .61976 L F
.374 .159 .454 r
.25394 .5711 m .25545 .57266 L .25448 .56984 L F
.44 .265 .547 r
.25448 .56984 m .2572 .57067 L .25727 .56603 L F
.409 .178 .449 r
.25448 .56984 m .25781 .57172 L .2572 .57067 L F
.25448 .56984 m .25545 .57266 L .25781 .57172 L F
.814 .822 .856 r
.50962 .48884 m .51447 .4874 L .5126 .48567 L F
.807 .832 .87 r
.51447 .4874 m .51636 .48538 L .5126 .48567 L F
.529 .317 .537 r
.39785 .55618 m .39962 .55672 L .39979 .55328 L F
.709 .468 .558 r
.39979 .55328 m .39962 .55672 L .40246 .55586 L F
.523 .592 .865 r
.3186 .63037 m .31989 .62624 L .31702 .62957 L F
.3186 .63037 m .32139 .63029 L .31989 .62624 L F
.358 0 0 r
.31966 .63197 m .3186 .63037 L .31702 .62957 L F
.31966 .63197 m .32139 .63029 L .3186 .63037 L F
.741 .646 .755 r
.49568 .472 m .49786 .47397 L .49329 .47322 L F
.318 .43 .818 r
.49943 .47514 m .50003 .47545 L .49786 .47397 L F
.596 .4 .586 r
.49786 .47397 m .50003 .47545 L .49731 .47641 L F
.757 .336 .252 r
.5395 .42598 m .54287 .42726 L .54215 .42866 L F
.742 .775 .88 r
.53766 .38875 m .53328 .38866 L .53664 .38562 L F
.776 .684 .762 r
.53766 .38875 m .53451 .39229 L .53328 .38866 L F
0 .029 .568 r
.53915 .39089 m .53766 .38875 L .54015 .38867 L F
.391 .816 .966 r
.61003 .34362 m .61309 .34303 L .61487 .34402 L F
.424 .835 .971 r
.61309 .34303 m .61788 .34334 L .61487 .34402 L F
.711 .926 .963 r
.30648 .62439 m .30334 .62634 L .30144 .62528 L F
.418 .444 .78 r
.56552 .35607 m .56712 .35247 L .56837 .35561 L F
.56552 .35607 m .56817 .35734 L .56712 .35247 L F
0 0 .288 r
.56552 .35607 m .56646 .35696 L .56817 .35734 L F
.56552 .35607 m .5656 .35842 L .56646 .35696 L F
.581 .917 .696 r
.52008 .43573 m .52322 .43377 L .5201 .43629 L F
.111 .644 .865 r
.52008 .43573 m .5201 .43629 L .51814 .43567 L F
.893 .841 .787 r
.58844 .40159 m .59261 .40002 L .5917 .39912 L F
.58844 .40159 m .59005 .4033 L .59261 .40002 L F
.328 .778 .956 r
.54831 .40271 m .54959 .40282 L .54982 .40336 L F
.782 .317 .139 r
.55016 .40415 m .54982 .40336 L .55233 .4018 L F
.462 0 0 r
.55231 .40305 m .55233 .4018 L .54982 .40336 L F
.328 .778 .956 r
.54959 .40282 m .55231 .40305 L .54982 .40336 L F
.782 .317 .139 r
.54921 .40518 m .54982 .40336 L .55016 .40415 L F
.54921 .40518 m .54642 .40469 L .54982 .40336 L F
.54921 .40518 m .5525 .4085 L .54642 .40469 L F
.053 .601 .837 r
.40699 .59264 m .4029 .59187 L .40474 .59296 L F
.668 .616 .787 r
.51508 .46286 m .51231 .46585 L .51106 .4613 L F
.896 .628 .523 r
.35792 .54596 m .35489 .54231 L .35817 .54333 L F
.795 .435 .375 r
.39266 .54364 m .39389 .54639 L .39487 .54373 L F
0 0 0 r
.39487 .54373 m .39511 .54491 L .39424 .54662 L F
.39487 .54373 m .39389 .54639 L .39511 .54491 L F
.755 .892 .94 r
.52225 .47952 m .52594 .47887 L .52468 .47805 L F
.78 .866 .912 r
.52468 .47805 m .52594 .47887 L .52942 .47679 L F
.73 .32 .272 r
.35527 .5123 m .35773 .51518 L .35957 .51295 L F
.954 .671 .463 r
.35957 .51295 m .35773 .51518 L .35966 .51605 L F
.635 .644 .842 r
.56879 .3946 m .56766 .39888 L .56613 .3952 L F
.56879 .3946 m .5709 .39799 L .56766 .39888 L F
.734 .934 .599 r
.28985 .64351 m .29266 .6398 L .29058 .64173 L F
.55 .862 .996 r
.29266 .6398 m .29544 .63898 L .29336 .63801 L F
.742 .936 .601 r
.29058 .64173 m .29266 .6398 L .29336 .63801 L F
.437 .092 .281 r
.29971 .55951 m .29575 .56269 L .29618 .56061 L F
.456 .503 .819 r
.27488 .65687 m .27635 .66081 L .27841 .66047 L F
.41 .449 .79 r
.27635 .66081 m .27959 .66277 L .27841 .66047 L F
.606 .105 .035 r
.3869 .57715 m .38235 .57615 L .38335 .57963 L F
0 0 0 r
.38443 .57797 m .38709 .57705 L .38721 .57763 L F
.38709 .57705 m .3894 .57624 L .38721 .57763 L F
0 0 .467 r
.3869 .57715 m .38749 .57894 L .38721 .57763 L F
.38749 .57894 m .38797 .58038 L .38721 .57763 L F
.989 .874 .528 r
.38797 .58038 m .38625 .58189 L .38721 .57763 L F
.775 .987 .745 r
.52185 .36551 m .52281 .36304 L .52459 .36238 L F
.732 .87 .455 r
.52185 .36551 m .52056 .36717 L .52281 .36304 L F
.66 .632 .811 r
.5248 .36612 m .52185 .36551 L .52459 .36238 L F
.423 .864 .907 r
.26101 .585 m .25863 .58583 L .25991 .58594 L F
.48 .055 .156 r
.26101 .585 m .25969 .58557 L .25863 .58583 L F
.204 .729 .839 r
.25991 .58594 m .25863 .58583 L .25763 .58607 L F
.48 .055 .156 r
.25969 .58557 m .25677 .58681 L .25863 .58583 L F
.204 .729 .839 r
.25763 .58607 m .25863 .58583 L .25608 .58615 L F
0 0 .008 r
.35817 .64313 m .35817 .64566 L .35809 .6471 L F
.818 .98 .691 r
.35809 .6471 m .35668 .64717 L .35743 .65022 L F
.35809 .6471 m .35817 .64566 L .35668 .64717 L F
.858 .463 .293 r
.37776 .47985 m .37638 .48142 L .37805 .47861 L F
.37776 .47985 m .37955 .48283 L .37638 .48142 L F
.32 .516 .891 r
.52164 .38904 m .52069 .3909 L .51931 .38875 L F
.716 .98 .773 r
.62472 .34768 m .62329 .35012 L .626 .34911 L F
.888 .743 .695 r
.36263 .56313 m .35838 .56545 L .35919 .56275 L F
.36263 .56313 m .36083 .56659 L .35838 .56545 L F
.905 .754 .683 r
.36234 .5705 m .36161 .57329 L .36016 .56936 L F
.12 .41 .858 r
.28119 .64554 m .28059 .64702 L .27902 .64466 L F
.25 .293 .711 r
.57776 .38723 m .57444 .38668 L .57764 .38489 L F
.57776 .38723 m .57578 .38913 L .57444 .38668 L F
.762 .622 .704 r
.53451 .39229 m .52959 .38863 L .53328 .38866 L F
.53451 .39229 m .53048 .3922 L .52959 .38863 L F
.762 .613 .693 r
.53451 .39229 m .5319 .39585 L .53048 .3922 L F
.197 0 .332 r
.32989 .68089 m .3319 .67973 L .33138 .6826 L F
0 0 0 r
.37977 .5591 m .38182 .55601 L .38122 .55817 L F
0 0 .485 r
.38337 .55536 m .38182 .55601 L .38208 .5537 L F
.756 .755 .852 r
.32957 .61447 m .32548 .61441 L .32768 .61288 L F
.493 .309 .559 r
.41225 .47256 m .40976 .476 L .40964 .47297 L F
.366 .761 .986 r
.39 .57284 m .39098 .57304 L .39144 .57379 L F
.864 .994 .817 r
.39201 .57473 m .39144 .57379 L .3933 .57295 L F
.455 0 0 r
.39361 .5736 m .3933 .57295 L .39144 .57379 L F
.366 .761 .986 r
.39098 .57304 m .39361 .5736 L .39144 .57379 L F
.864 .994 .817 r
.39049 .57681 m .39144 .57379 L .39201 .57473 L F
.39049 .57681 m .3894 .57624 L .39144 .57379 L F
.469 .822 .548 r
.47727 .41611 m .47387 .419 L .47595 .41763 L F
.622 .907 .617 r
.47727 .41611 m .47859 .41432 L .48019 .41314 L F
.586 .839 .476 r
.47727 .41611 m .47595 .41763 L .47859 .41432 L F
0 0 0 r
.30397 .54684 m .3059 .54589 L .307 .54425 L F
.572 .813 .431 r
.41903 .58326 m .4177 .585 L .41658 .58651 L F
.71 .86 .444 r
.41989 .58113 m .4177 .585 L .41903 .58326 L F
.057 0 0 r
.44563 .45173 m .44151 .45415 L .44349 .45276 L F
.881 .684 .632 r
.32898 .54254 m .33136 .54345 L .32948 .53963 L F
.923 .681 .556 r
.32898 .54254 m .33094 .54632 L .33136 .54345 L F
.822 .466 .383 r
.34301 .52002 m .34083 .52181 L .33909 .51868 L F
.34301 .52002 m .34338 .52242 L .34083 .52181 L F
.988 .719 .39 r
.54531 .34435 m .5449 .34259 L .54614 .34035 L F
.54531 .34435 m .54344 .34377 L .5449 .34259 L F
0 0 .306 r
.54614 .34035 m .54645 .34315 L .54531 .34435 L F
.354 .814 .931 r
.54531 .34435 m .54645 .34315 L .54344 .34377 L F
.184 0 0 r
.59774 .39807 m .60048 .39753 L .60176 .39557 L F
.533 .892 .975 r
.60455 .39458 m .60176 .39557 L .60319 .39392 L F
.13 0 0 r
.60176 .39557 m .6044 .39683 L .60319 .39392 L F
.60176 .39557 m .60323 .39658 L .6044 .39683 L F
.60176 .39557 m .60048 .39753 L .60323 .39658 L F
.821 .876 .885 r
.32247 .61684 m .31873 .6172 L .32057 .61558 L F
.765 .841 .909 r
.32548 .61441 m .32247 .61684 L .32057 .61558 L F
.627 .922 .976 r
.62173 .3432 m .62322 .34096 L .6246 .34239 L F
.62173 .3432 m .62076 .34229 L .62322 .34096 L F
0 0 0 r
.33155 .63263 m .33055 .63426 L .32941 .63641 L F
.50612 .41124 m .50613 .41127 L .50651 .40946 L F
.50651 .40946 m .50613 .41127 L .50836 .40632 L F
.798 .391 .28 r
.38171 .56166 m .38662 .56365 L .3837 .55954 L F
.751 .482 .524 r
.38169 .56423 m .38662 .56365 L .38171 .56166 L F
.515 .664 .929 r
.38208 .56065 m .38184 .56285 L .38171 .56166 L F
.38184 .56285 m .38169 .56423 L .38171 .56166 L F
.718 .282 .215 r
.38171 .56166 m .3837 .55954 L .38145 .55928 L F
.38171 .56166 m .38145 .55928 L .37977 .5591 L F
.785 .294 0 r
.3837 .55954 m .38721 .5635 L .38609 .56024 L F
.3837 .55954 m .38662 .56365 L .38721 .5635 L F
.277 .775 .882 r
.6405 .33959 m .6437 .33904 L .6451 .33954 L F
.88 .736 .699 r
.31202 .55352 m .3096 .55316 L .31045 .54955 L F
.396 0 0 r
.31202 .55352 m .30754 .55553 L .3096 .55316 L F
.31202 .55352 m .30982 .55548 L .30754 .55553 L F
.657 .22 .2 r
.31202 .55352 m .31424 .55571 L .30982 .55548 L F
0 0 .168 r
.29882 .6456 m .29913 .64283 L .29879 .6462 L F
.856 .87 .85 r
.29879 .6462 m .29833 .65026 L .29882 .6456 L F
0 0 0 r
.6322 .34694 m .62864 .34796 L .62981 .34843 L F
.41 .703 .982 r
.61016 .39355 m .6089 .39542 L .60738 .394 L F
.61016 .39355 m .61142 .39517 L .6089 .39542 L F
.6089 .39542 m .61016 .39355 L .6067 .39542 L F
.6089 .39542 m .61142 .39517 L .61016 .39355 L F
.42 .19 .457 r
.5874 .40583 m .58374 .41011 L .58518 .40779 L F
.421 .511 .846 r
.58374 .41011 m .58653 .41133 L .58518 .40779 L F
.519 .694 .948 r
.58483 .41173 m .58653 .41133 L .58374 .41011 L F
.558 .827 .996 r
.62839 .34216 m .62986 .34001 L .63117 .34086 L F
.62839 .34216 m .62715 .34086 L .62986 .34001 L F
.903 .867 .794 r
.53541 .46501 m .5395 .46279 L .53807 .46152 L F
.53541 .46501 m .53709 .46633 L .5395 .46279 L F
.876 .602 .521 r
.67096 .35137 m .67289 .34928 L .67088 .34864 L F
.67096 .35137 m .67445 .35286 L .67289 .34928 L F
.99 .725 .394 r
.5449 .34259 m .54344 .34377 L .54348 .34089 L F
.512 .753 .983 r
.54348 .34089 m .54614 .34035 L .5449 .34259 L F
.956 .94 .622 r
.31543 .57321 m .31474 .57236 L .31645 .56828 L F
.509 .84 .55 r
.47387 .419 m .47061 .42195 L .47253 .42047 L F
0 0 0 r
.47253 .42047 m .47595 .41763 L .47387 .419 L F
.509 .276 .497 r
.29575 .56269 m .29265 .56619 L .29303 .56352 L F
0 0 .531 r
.29368 .6556 m .29289 .65762 L .29198 .6537 L F
.358 .652 .967 r
.29368 .6556 m .29581 .6577 L .29289 .65762 L F
.054 .449 .878 r
.29581 .6577 m .29611 .65831 L .29289 .65762 L F
0 0 0 r
.28558 .64657 m .28985 .64351 L .2885 .6456 L F
.702 .848 .422 r
.2885 .6456 m .28985 .64351 L .29058 .64173 L F
.965 .938 .681 r
.58569 .3835 m .58107 .38226 L .58422 .38084 L F
.58569 .3835 m .58352 .38452 L .58107 .38226 L F
.58569 .3835 m .58429 .3859 L .58352 .38452 L F
.806 .866 .893 r
.58724 .38174 m .58569 .3835 L .58422 .38084 L F
.008 .053 .56 r
.52459 .36238 m .52644 .3641 L .5248 .36612 L F
0 0 .251 r
.52644 .3641 m .52524 .36794 L .5248 .36612 L F
.879 .51 .343 r
.33897 .51653 m .33698 .51817 L .33568 .5147 L F
.889 .529 .356 r
.33909 .51868 m .33698 .51817 L .33897 .51653 L F
.754 .994 .867 r
.51402 .39812 m .51816 .39596 L .5168 .39523 L F
.611 .954 .827 r
.52024 .39441 m .51944 .39433 L .51816 .39596 L F
.534 .882 .985 r
.51944 .39433 m .5168 .39523 L .51816 .39596 L F
.65 .911 .98 r
.29383 .53617 m .2894 .53605 L .29059 .53759 L F
.635 .631 .829 r
.55719 .41295 m .55347 .41264 L .55555 .41106 L F
.055 0 0 r
.27824 .5574 m .27719 .55874 L .27487 .5596 L F
.298 0 .11 r
.28069 .55647 m .27719 .55874 L .27824 .5574 L F
0 0 0 r
.28243 .63604 m .28085 .6365 L .28148 .63648 L F
.28243 .63604 m .28433 .63428 L .28085 .6365 L F
.669 .899 .555 r
.59698 .38363 m .59397 .38743 L .59575 .38566 L F
.964 .939 .686 r
.30843 .58609 m .30713 .5853 L .309 .58425 L F
.513 .264 .475 r
.30843 .58609 m .30816 .58959 L .30557 .58963 L F
0 0 0 r
.30843 .58609 m .30591 .58921 L .30684 .5884 L F
.30591 .58921 m .30557 .58963 L .30684 .5884 L F
0 .11 .66 r
.30742 .5879 m .30684 .5884 L .30799 .58941 L F
0 0 0 r
.30843 .58609 m .30684 .5884 L .30713 .5853 L F
0 .11 .66 r
.30681 .58625 m .30684 .5884 L .30742 .5879 L F
.754 .359 .304 r
.30843 .58609 m .31127 .58814 L .30816 .58959 L F
.811 .999 .796 r
.53658 .40492 m .53543 .40692 L .53378 .40797 L F
.605 .778 .963 r
.59774 .39807 m .59912 .40012 L .602 .39905 L F
.682 .262 0 r
.51308 .40067 m .51456 .40292 L .51439 .40255 L F
.826 .971 .892 r
.46862 .53051 m .46795 .53312 L .47104 .53 L F
.46862 .53051 m .4667 .53233 L .46795 .53312 L F
.548 .512 .767 r
.58638 .40349 m .5874 .40583 L .58666 .40311 L F
.693 .593 .739 r
.58666 .40311 m .5874 .40583 L .59005 .4033 L F
.852 .549 .475 r
.58518 .40779 m .5876 .4091 L .5874 .40583 L F
.686 .36 .418 r
.32821 .63024 m .33155 .63263 L .32829 .63327 L F
.32821 .63024 m .33264 .63069 L .33155 .63263 L F
.887 .727 .678 r
.50649 .47998 m .50571 .48312 L .50421 .47895 L F
.924 .745 .259 r
.30152 .5734 m .30109 .57242 L .30129 .56966 L F
.882 .855 .811 r
.29886 .57639 m .30109 .57242 L .30152 .5734 L F
.787 .909 .515 r
.5604 .38254 m .5591 .38389 L .55908 .38122 L F
.884 .926 .845 r
.56311 .37923 m .5604 .38254 L .55908 .38122 L F
.729 .683 .806 r
.4217 .58037 m .4236 .58369 L .42569 .58268 L F
.856 .804 .315 r
.52865 .44003 m .52855 .44294 L .52791 .44566 L F
.85 .985 .705 r
.60102 .37042 m .6004 .3732 L .60336 .37217 L F
.60102 .37042 m .59876 .37374 L .6004 .3732 L F
.822 .998 .841 r
.59628 .3439 m .59488 .34604 L .59552 .34342 L F
.995 .77 .481 r
.59488 .34604 m .59293 .34697 L .59552 .34342 L F
.59488 .34604 m .5944 .34842 L .59293 .34697 L F
.806 .973 .675 r
.49329 .47322 m .49137 .47592 L .49152 .47448 L F
.89 .488 .056 r
.49137 .47592 m .49072 .47711 L .49152 .47448 L F
.49137 .47592 m .49245 .47868 L .49072 .47711 L F
.842 .664 .66 r
.32428 .52953 m .32379 .53237 L .32775 .53311 L F
.83 .528 .477 r
.32379 .53237 m .32776 .53561 L .32775 .53311 L F
.67 .797 .943 r
.51934 .40464 m .52049 .40271 L .52043 .40266 L F
.704 .982 .891 r
.52043 .40266 m .52169 .40071 L .52415 .40036 L F
.67 .797 .943 r
.52049 .40271 m .52169 .40071 L .52043 .40266 L F
0 0 0 r
.52033 .40258 m .52043 .40266 L .52241 .40195 L F
.51968 .40277 m .52043 .40266 L .52033 .40258 L F
.51968 .40277 m .51803 .40386 L .52043 .40266 L F
.695 .975 .779 r
.61377 .36343 m .6125 .36561 L .61577 .36461 L F
.61377 .36343 m .61171 .36562 L .6125 .36561 L F
.61377 .36343 m .6125 .36561 L .61577 .36461 L F
.61377 .36343 m .61171 .36562 L .6125 .36561 L F
.938 .795 .677 r
.37564 .5154 m .37658 .51938 L .37776 .51662 L F
.716 .593 .718 r
.41074 .56286 m .41236 .56708 L .4133 .56422 L F
.75 .521 .585 r
.29407 .55947 m .29924 .55621 L .29404 .55597 L F
.614 .618 .831 r
.3 .55853 m .30014 .5586 L .29971 .55951 L F
.30014 .5586 m .30163 .55935 L .30023 .55947 L F
.30014 .5586 m .30023 .55947 L .29971 .55951 L F
.30083 .55563 m .30163 .55935 L .3 .55853 L F
.30083 .55563 m .30009 .55818 L .29924 .55621 L F
.75 .521 .585 r
.3 .55853 m .30014 .5586 L .29924 .55621 L F
.614 .618 .831 r
.30009 .55818 m .3 .55853 L .29924 .55621 L F
0 .043 .585 r
.30004 .55717 m .30066 .55948 L .30096 .55783 L F
.718 .429 .487 r
.3025 .56256 m .29971 .55951 L .3023 .55929 L F
0 .043 .585 r
.30066 .55948 m .30109 .56049 L .30096 .55783 L F
.289 0 0 r
.29575 .56269 m .29981 .5616 L .29827 .56144 L F
.437 .092 .281 r
.29971 .55951 m .29827 .56144 L .29575 .56269 L F
.289 0 0 r
.29575 .56269 m .29827 .56144 L .29491 .56109 L F
.718 .429 .487 r
.3025 .56256 m .29742 .56257 L .29944 .56175 L F
.30181 .56181 m .29827 .56144 L .29971 .55951 L F
.289 0 0 r
.29727 .56228 m .29742 .56257 L .29981 .5616 L F
.29575 .56269 m .29742 .56257 L .29727 .56228 L F
.818 .554 .54 r
.3025 .56256 m .29779 .56458 L .29742 .56257 L F
.026 .084 .587 r
.29779 .56458 m .29793 .56353 L .29742 .56257 L F
.718 .429 .487 r
.3025 .56256 m .29944 .56175 L .30181 .56181 L F
.29944 .56175 m .29827 .56144 L .29981 .5616 L F
.29944 .56175 m .29981 .5616 L .30181 .56181 L F
.289 0 0 r
.29981 .5616 m .29742 .56257 L .30113 .56124 L F
.718 .429 .487 r
.29944 .56175 m .29742 .56257 L .29827 .56144 L F
.437 .092 .281 r
.29827 .56144 m .29742 .56257 L .29575 .56269 L F
.289 0 0 r
.29491 .56109 m .30113 .56124 L .29407 .55947 L F
.29981 .5616 m .30113 .56124 L .29491 .56109 L F
.614 .618 .831 r
.3 .55853 m .29971 .55951 L .29924 .55621 L F
.75 .521 .585 r
.29407 .55947 m .30086 .56117 L .29924 .55621 L F
.67 .958 .944 r
.30113 .56124 m .29742 .56257 L .29836 .56014 L F
.026 .084 .587 r
.29793 .56353 m .29836 .56014 L .29742 .56257 L F
0 .043 .585 r
.30014 .5586 m .30113 .56124 L .29996 .55689 L F
.614 .618 .831 r
.30083 .55563 m .3023 .55929 L .30163 .55935 L F
.565 .59 .837 r
.30494 .55842 m .3023 .55929 L .30083 .55563 L F
0 .043 .585 r
.30066 .55948 m .30113 .56124 L .30109 .56049 L F
.75 .521 .585 r
.30086 .56117 m .30113 .56124 L .30014 .5586 L F
.30086 .56117 m .30014 .5586 L .3 .55853 L F
.67 .958 .944 r
.30113 .56124 m .29836 .56014 L .30096 .55783 L F
0 0 0 r
.30096 .55783 m .30032 .55851 L .3023 .55878 L F
.30096 .55783 m .3023 .55878 L .30336 .55893 L F
0 .043 .585 r
.29996 .55689 m .30004 .55717 L .30096 .55783 L F
.29924 .55621 m .30014 .5586 L .29996 .55689 L F
.117 0 .313 r
.30119 .55314 m .30083 .55563 L .29924 .55621 L F
0 .043 .585 r
.29924 .55621 m .30096 .55783 L .30083 .55563 L F
.117 0 .313 r
.30119 .55314 m .30083 .55563 L .29924 .55621 L F
0 0 0 r
.48019 .41314 m .48065 .41287 L .48246 .41169 L F
.48019 .41314 m .47859 .41432 L .48065 .41287 L F
.805 .73 .782 r
.3787 .52255 m .37422 .5229 L .37615 .52334 L F
.596 .4 .587 r
.3787 .52255 m .38101 .52274 L .38165 .51988 L F
.877 .619 .544 r
.37746 .52447 m .3787 .52255 L .37615 .52334 L F
.37746 .52447 m .38101 .52274 L .3787 .52255 L F
.493 .826 .532 r
.33498 .67683 m .3359 .67591 L .33482 .67642 L F
.821 .847 .386 r
.3338 .67905 m .33498 .67683 L .33482 .67642 L F
.931 .943 .78 r
.46267 .52344 m .45985 .52418 L .46125 .52229 L F
.46267 .52344 m .46033 .52717 L .45985 .52418 L F
.796 .998 .85 r
.46125 .52229 m .45872 .52315 L .45948 .52243 L F
.99 .859 .61 r
.4624 .5222 m .46125 .52229 L .46156 .51828 L F
0 0 .173 r
.46156 .51828 m .46125 .52229 L .46187 .52021 L F
.796 .998 .85 r
.46125 .52229 m .45948 .52243 L .46187 .52021 L F
.99 .859 .61 r
.46267 .52344 m .46125 .52229 L .4624 .5222 L F
.847 .907 .877 r
.45753 .53044 m .45284 .53234 L .45552 .52894 L F
.852 .848 .838 r
.46033 .52717 m .45753 .53044 L .45552 .52894 L F
.78 .866 .912 r
.52468 .47805 m .52942 .47679 L .52734 .47485 L F
.836 .822 .835 r
.52942 .47679 m .53014 .47186 L .52734 .47485 L F
.52942 .47679 m .53214 .47351 L .53014 .47186 L F
.94 .958 .746 r
.4706 .52743 m .47319 .52629 L .47102 .52541 L F
.4706 .52743 m .47104 .53 L .47319 .52629 L F
.789 .858 .902 r
.47319 .52629 m .47473 .522 L .47102 .52541 L F
.47319 .52629 m .47644 .52345 L .47473 .522 L F
.8 .991 .881 r
.46762 .51624 m .46798 .51401 L .47086 .51333 L F
.85 .993 .742 r
.46762 .51624 m .4668 .51599 L .46798 .51401 L F
.935 .923 .774 r
.54369 .44942 m .54609 .44575 L .54465 .44455 L F
.923 .928 .794 r
.54465 .44455 m .54609 .44575 L .54833 .44182 L F
0 0 .257 r
.34617 .50496 m .34671 .5066 L .34585 .50501 L F
.743 .466 .511 r
.39571 .47842 m .39122 .47571 L .39393 .47617 L F
.653 .848 .45 r
.30528 .52781 m .30416 .5295 L .305 .52798 L F
.038 .196 .7 r
.30416 .5295 m .30613 .53162 L .305 .52798 L F
.809 .435 0 r
.305 .52798 m .30474 .52902 L .30465 .5282 L F
.305 .52798 m .30465 .5282 L .30455 .52725 L F
.653 .848 .45 r
.30614 .5265 m .30528 .52781 L .305 .52798 L F
.783 .886 .467 r
.30614 .5265 m .305 .52798 L .3067 .5243 L F
.167 0 0 r
.28716 .63348 m .28446 .63424 L .28547 .6344 L F
.671 .943 .675 r
.28887 .63169 m .28595 .63447 L .28794 .63477 L F
.28595 .63447 m .2856 .63481 L .28791 .63477 L F
.28595 .63447 m .28791 .63477 L .28794 .63477 L F
.167 0 0 r
.28547 .6344 m .28433 .63428 L .28243 .63604 L F
.28446 .63424 m .28433 .63428 L .28547 .6344 L F
0 0 0 r
.48631 .42287 m .4858 .42301 L .4881 .42163 L F
.48631 .42287 m .48417 .42425 L .4858 .42301 L F
.784 .948 .928 r
.55343 .37434 m .55229 .3735 L .55522 .37355 L F
.55343 .37434 m .5507 .37472 L .55229 .3735 L F
.433 .242 .52 r
.55345 .3766 m .5507 .37472 L .55343 .37434 L F
.822 .956 .902 r
.56173 .41381 m .56249 .41578 L .5662 .41197 L F
.619 .208 .242 r
.56875 .38951 m .57165 .3915 L .56862 .39124 L F
.926 .645 .165 r
.56875 .38951 m .56862 .39124 L .56778 .38809 L F
.696 .48 .59 r
.5068 .47288 m .50433 .47652 L .50313 .47384 L F
.5068 .47288 m .50666 .47558 L .50433 .47652 L F
.539 .375 .608 r
.39607 .55591 m .39613 .55973 L .39293 .55664 L F
.39607 .55591 m .39613 .55973 L .39293 .55664 L F
.342 0 0 r
.39147 .54995 m .39015 .55193 L .38711 .5522 L F
.136 .136 .594 r
.25394 .5711 m .25606 .57556 L .25545 .57266 L F
0 0 0 r
.44904 .4382 m .4506 .43684 L .44699 .43877 L F
.4529 .43552 m .4506 .43684 L .44904 .4382 L F
.911 .951 .81 r
.5658 .40818 m .56678 .40951 L .56913 .40603 L F
.996 .828 .472 r
.5662 .41197 m .56678 .40951 L .5658 .40818 L F
0 0 .203 r
.67401 .35969 m .67379 .35927 L .67292 .35639 L F
.67401 .35969 m .6744 .36185 L .67379 .35927 L F
.373 0 .136 r
.27891 .53563 m .28287 .53297 L .28041 .53226 L F
.534 .015 0 r
.32547 .62809 m .3281 .62689 L .32417 .62679 L F
.02 0 0 r
.32417 .62679 m .3281 .62689 L .32683 .62686 L F
.597 .949 .897 r
.32683 .62686 m .32763 .62688 L .32901 .62542 L F
.32763 .62688 m .3281 .62689 L .32901 .62542 L F
.635 .956 .778 r
.32901 .62542 m .3281 .62689 L .32547 .62809 L F
0 0 0 r
.33009 .62428 m .32901 .62542 L .32734 .62756 L F
.33016 .6242 m .32901 .62542 L .33009 .62428 L F
.855 .643 .615 r
.65151 .36283 m .65093 .36551 L .64906 .36134 L F
.014 0 .16 r
.26503 .57926 m .26416 .58256 L .26218 .58352 L F
0 0 .313 r
.267 .57575 m .2667 .57844 L .26503 .57926 L F
.425 .107 .32 r
.26781 .58122 m .26503 .57926 L .2667 .57844 L F
.26781 .58122 m .26416 .58256 L .26503 .57926 L F
0 0 .107 r
.51508 .41836 m .51508 .41608 L .51543 .41508 L F
.847 .815 .818 r
.52067 .37589 m .51798 .3793 L .51703 .37698 L F
.099 0 .019 r
.33595 .64599 m .33633 .64449 L .33561 .64581 L F
.33595 .64599 m .33802 .64381 L .33633 .64449 L F
.762 .499 .536 r
.3346 .65373 m .3295 .65604 L .3309 .65409 L F
.3346 .65373 m .33395 .65653 L .3295 .65604 L F
.863 .897 .857 r
.30486 .54992 m .30119 .55314 L .30144 .55085 L F
.278 .033 .351 r
.27432 .5396 m .27626 .53885 L .27641 .53662 L F
.415 .202 .48 r
.27626 .53885 m .27891 .53563 L .27641 .53662 L F
0 0 0 r
.63997 .37929 m .63579 .38194 L .63902 .38091 L F
.64045 .37958 m .63997 .37929 L .63902 .38091 L F
.64045 .37958 m .64277 .37857 L .63997 .37929 L F
.278 0 0 r
.53793 .42633 m .5395 .42598 L .53863 .427 L F
.757 .336 .252 r
.5395 .42598 m .54215 .42866 L .53863 .427 L F
.895 .901 .824 r
.5184 .45518 m .51901 .45204 L .52039 .45605 L F
.806 .628 .661 r
.52201 .46002 m .5184 .45518 L .52039 .45605 L F
.775 .77 .848 r
.52317 .45245 m .52039 .45605 L .51901 .45204 L F
.729 .683 .806 r
.4217 .58037 m .42569 .58268 L .42425 .57963 L F
.749 .785 .882 r
.42425 .57963 m .42569 .58268 L .42906 .57986 L F
.87 .991 .737 r
.309 .58425 m .30938 .58198 L .30942 .58185 L F
.775 .365 .274 r
.30952 .52125 m .31379 .52214 L .31037 .51841 L F
.702 .461 .556 r
.50313 .47384 m .50003 .47545 L .49943 .47514 L F
.50313 .47384 m .50433 .47652 L .50003 .47545 L F
.752 .991 .794 r
.52212 .40679 m .51895 .40984 L .52083 .40909 L F
.102 0 0 r
.27719 .55874 m .27305 .56159 L .27487 .5596 L F
0 0 0 r
.26313 .58377 m .26218 .58352 L .26416 .58256 L F
.26313 .58377 m .26101 .585 L .26218 .58352 L F
.884 .926 .845 r
.56311 .37923 m .55908 .38122 L .56183 .37792 L F
.989 .884 .62 r
.56311 .37923 m .56183 .37792 L .5635 .37503 L F
0 0 0 r
.24762 .61225 m .2513 .61026 L .24897 .61181 L F
.542 .034 0 r
.24897 .61181 m .2513 .61026 L .2506 .61141 L F
.725 .622 .742 r
.25346 .60946 m .25783 .61275 L .25347 .61273 L F
.73 .552 .652 r
.25346 .60946 m .25347 .61273 L .2506 .61141 L F
.503 .612 .893 r
.25347 .61273 m .25595 .6122 L .25252 .61055 L F
0 0 0 r
.25084 .61124 m .2513 .61026 L .25346 .60946 L F
.503 .612 .893 r
.25205 .61075 m .25252 .61055 L .25159 .6101 L F
.25347 .61273 m .25252 .61055 L .25205 .61075 L F
0 0 0 r
.2506 .61141 m .25065 .61132 L .25084 .61124 L F
.25065 .61132 m .2513 .61026 L .25084 .61124 L F
.717 .472 .555 r
.38723 .5362 m .39121 .53618 L .39123 .53317 L F
.192 .06 .461 r
.3934 .53431 m .39123 .53317 L .3939 .53229 L F
.3934 .53431 m .39121 .53618 L .39123 .53317 L F
.3934 .53431 m .39123 .53317 L .3939 .53229 L F
.3934 .53431 m .39121 .53618 L .39123 .53317 L F
.074 .061 .536 r
.35856 .63981 m .3592 .64312 L .35817 .64313 L F
.066 0 .202 r
.3592 .64312 m .35817 .64566 L .35817 .64313 L F
.932 .696 .559 r
.52067 .37589 m .52388 .3729 L .52349 .37309 L F
.5 .855 .603 r
.52518 .37173 m .52349 .37309 L .52388 .3729 L F
.967 .884 .698 r
.55062 .43901 m .55041 .43526 L .54824 .43883 L F
.892 .901 .827 r
.54833 .44182 m .55062 .43901 L .54824 .43883 L F
.253 .744 .915 r
.31479 .54975 m .31304 .54928 L .31045 .54955 L F
.31494 .54976 m .31304 .54928 L .31045 .54955 L F
.419 .732 .991 r
.31045 .54955 m .31304 .54928 L .31161 .5477 L F
.691 .697 .165 r
.31045 .54955 m .31027 .55028 L .31304 .54928 L F
.96 .881 .712 r
.31304 .54928 m .31027 .55028 L .31107 .54875 L F
.31304 .54928 m .31107 .54875 L .31161 .5477 L F
.253 .744 .915 r
.31494 .54976 m .31304 .54928 L .31479 .54975 L F
.593 .916 .974 r
.3154 .54813 m .31304 .54928 L .31494 .54976 L F
.156 .474 .895 r
.3154 .54813 m .31494 .54976 L .31304 .54928 L F
.561 .563 .813 r
.31884 .55318 m .31494 .54976 L .31836 .55179 L F
.637 .666 .862 r
.24393 .6107 m .24762 .61225 L .24625 .61076 L F
0 0 0 r
.24762 .61225 m .24897 .61181 L .24625 .61076 L F
.574 .931 .938 r
.41725 .59312 m .41683 .59237 L .41282 .59362 L F
.863 .977 .675 r
.41926 .58863 m .41725 .59312 L .42022 .5895 L F
.41926 .58863 m .41683 .59237 L .41725 .59312 L F
0 0 0 r
.44699 .43877 m .44333 .44178 L .44555 .44052 L F
.44555 .44052 m .44904 .4382 L .44699 .43877 L F
0 .066 .589 r
.57804 .35205 m .57867 .35624 L .57989 .35372 L F
0 0 .545 r
.57867 .35624 m .58014 .35638 L .57989 .35372 L F
.57867 .35624 m .5796 .35884 L .58014 .35638 L F
.852 .848 .838 r
.46033 .52717 m .45552 .52894 L .45852 .52594 L F
.83 .904 .891 r
.45985 .52418 m .46033 .52717 L .45852 .52594 L F
.344 0 .137 r
.29426 .65339 m .29833 .65026 L .29846 .65278 L F
.856 .87 .85 r
.29879 .6462 m .30099 .64727 L .29833 .65026 L F
.598 .943 .783 r
.53455 .4339 m .53644 .4333 L .53331 .43521 L F
.516 .782 .993 r
.53791 .43102 m .53644 .4333 L .53455 .4339 L F
.53791 .43102 m .53962 .43253 L .53644 .4333 L F
.922 .909 .791 r
.53323 .46888 m .53709 .46633 L .53541 .46501 L F
.53323 .46888 m .5348 .47006 L .53709 .46633 L F
.761 .43 .425 r
.29168 .65063 m .29426 .65339 L .29198 .6537 L F
0 0 .531 r
.29368 .6556 m .29198 .6537 L .29426 .65339 L F
.55 .826 .997 r
.30675 .65986 m .30408 .66074 L .30195 .65937 L F
0 0 0 r
.41137 .46295 m .41066 .4625 L .40893 .46413 L F
.41137 .46295 m .4132 .46184 L .41066 .4625 L F
0 0 .572 r
.52067 .37589 m .5206 .37474 L .51868 .37179 L F
.847 .815 .818 r
.52067 .37589 m .51703 .37698 L .5206 .37474 L F
.707 .886 .963 r
.52151 .37329 m .52067 .37589 L .52349 .37309 L F
.965 .636 .285 r
.51945 .37715 m .52067 .37589 L .52151 .37329 L F
.51945 .37715 m .52107 .37863 L .52067 .37589 L F
.844 .59 .554 r
.35284 .53314 m .34903 .53499 L .34915 .53239 L F
.35284 .53314 m .35267 .53592 L .34903 .53499 L F
.984 .754 .508 r
.36161 .57329 m .35988 .57245 L .36016 .56936 L F
.478 .814 .999 r
.3642 .57292 m .35988 .57245 L .36161 .57329 L F
.693 .593 .739 r
.58666 .40311 m .59005 .4033 L .58844 .40159 L F
.679 .768 .918 r
.39646 .5311 m .398 .53298 L .3939 .53229 L F
.779 .408 .353 r
.39645 .53343 m .39628 .5355 L .3934 .53431 L F
.398 .53298 m .39628 .5355 L .39645 .53343 L F
.781 .423 .378 r
.39628 .5355 m .39618 .53742 L .3934 .53431 L F
.97 .666 .276 r
.39609 .53528 m .39616 .53693 L .39628 .5355 L F
.39616 .53693 m .39618 .53742 L .39628 .5355 L F
.779 .408 .353 r
.39658 .53274 m .3934 .53431 L .3939 .53229 L F
.39645 .53343 m .3934 .53431 L .39658 .53274 L F
.97 .666 .276 r
.39461 .53348 m .39584 .53657 L .39609 .53528 L F
.39584 .53657 m .39618 .53742 L .39609 .53528 L F
.779 .408 .353 r
.398 .53298 m .39645 .53343 L .39658 .53274 L F
.908 .518 .102 r
.39646 .5311 m .39717 .53428 L .398 .53298 L F
0 0 0 r
.39717 .53428 m .39628 .5355 L .398 .53298 L F
.9 .918 .525 r
.38662 .56365 m .38511 .56657 L .38721 .5635 L F
.722 .87 .459 r
.38721 .5635 m .38701 .56323 L .38897 .56354 L F
.38721 .5635 m .38511 .56657 L .38701 .56323 L F
.686 .692 .85 r
.38897 .56354 m .38801 .56698 L .38721 .5635 L F
.404 .494 .838 r
.27959 .66277 m .28103 .66628 L .28317 .66611 L F
.902 .957 .822 r
.4706 .52743 m .46862 .53051 L .47104 .53 L F
.758 .886 .936 r
.31151 .68449 m .31123 .68241 L .30764 .68111 L F
.798 .846 .887 r
.5126 .48567 m .51636 .48538 L .51584 .48277 L F
.847 .872 .86 r
.51584 .48277 m .51636 .48538 L .51921 .48256 L F
.291 0 0 r
.6518 .33905 m .65479 .33959 L .65589 .33855 L F
.575 .049 0 r
.65479 .33959 m .65856 .33901 L .65589 .33855 L F
.751 .748 .85 r
.3207 .55251 m .31836 .55179 L .31945 .54808 L F
.3207 .55251 m .31884 .55318 L .31836 .55179 L F
.728 .676 .8 r
.32209 .55003 m .3207 .55251 L .31945 .54808 L F
.911 .951 .81 r
.5658 .40818 m .56913 .40603 L .56813 .40504 L F
.937 .943 .769 r
.56813 .40504 m .56913 .40603 L .57122 .40228 L F
.974 .68 .293 r
.33568 .5147 m .33413 .51107 L .33684 .51271 L F
.571 .853 .997 r
.55719 .33794 m .5557 .33681 L .55437 .33886 L F
.55437 .33886 m .5557 .33681 L .55719 .33794 L F
.335 .192 .533 r
.28464 .54221 m .28664 .5418 L .28463 .54267 L F
.28473 .53962 m .28522 .54018 L .28464 .54221 L F
.28522 .54018 m .28664 .5418 L .28464 .54221 L F
.37 .197 .512 r
.28527 .54098 m .28664 .5418 L .28522 .54018 L F
.28527 .54098 m .28522 .54018 L .28473 .53962 L F
.252 .112 .489 r
.28997 .53676 m .28527 .54098 L .2855 .53917 L F
.28637 .5361 m .2855 .53917 L .2859 .53601 L F
.28997 .53676 m .2855 .53917 L .28637 .5361 L F
.326 .175 .518 r
.2859 .53601 m .28527 .54098 L .28473 .53962 L F
.346 .124 .427 r
.28889 .53203 m .2894 .53605 L .2859 .53601 L F
.252 .112 .489 r
.28997 .53676 m .2859 .53601 L .2894 .53605 L F
.998 .833 .552 r
.39242 .47423 m .39302 .47194 L .39463 .47041 L F
.238 0 0 r
.39463 .47041 m .39302 .47194 L .39687 .47076 L F
.611 .953 .91 r
.64943 .3755 m .645 .37688 L .64853 .37545 L F
.333 .816 .82 r
.65226 .37458 m .64943 .3755 L .64853 .37545 L F
0 0 .172 r
.34912 .66368 m .35018 .66044 L .35136 .65959 L F
.228 .745 .744 r
.60388 .35082 m .60225 .3513 L .60543 .35052 L F
.589 .315 .468 r
.60513 .3533 m .60218 .35192 L .60388 .35082 L F
.64 .885 .986 r
.60165 .35293 m .59978 .35589 L .60225 .3513 L F
.60077 .35463 m .59978 .35589 L .60165 .35293 L F
.60126 .354 m .60225 .3513 L .60127 .3515 L F
.228 .745 .744 r
.60388 .35082 m .60127 .3515 L .60225 .3513 L F
.589 .315 .468 r
.60218 .35192 m .60127 .3515 L .60258 .35116 L F
.60218 .35192 m .60258 .35116 L .60388 .35082 L F
.64 .885 .986 r
.60126 .354 m .60077 .35463 L .60165 .35293 L F
.60126 .354 m .59876 .3546 L .59978 .35589 L F
0 0 .423 r
.60126 .354 m .59978 .35589 L .59876 .3546 L F
.60126 .354 m .60079 .35813 L .59978 .35589 L F
.933 .849 .737 r
.65129 .38793 m .65483 .38562 L .65333 .38411 L F
.65129 .38793 m .65273 .38961 L .65483 .38562 L F
.817 .911 .904 r
.65483 .38562 m .65677 .38133 L .65333 .38411 L F
.65483 .38562 m .65817 .38262 L .65677 .38133 L F
.466 .853 .645 r
.52548 .43215 m .52322 .43377 L .52008 .43573 L F
0 0 .475 r
.52551 .43491 m .52322 .43377 L .52548 .43215 L F
.159 .699 .754 r
.28151 .53538 m .28662 .53476 L .28287 .53297 L F
.28269 .53524 m .28402 .53496 L .28662 .53476 L F
0 0 0 r
.28402 .53496 m .2826 .53681 L .2851 .53474 L F
.477 .897 .855 r
.28662 .53476 m .28402 .53496 L .28614 .53387 L F
0 0 0 r
.28402 .53496 m .2851 .53474 L .28614 .53387 L F
.159 .699 .754 r
.28151 .53538 m .28402 .53496 L .28269 .53524 L F
.807 .582 .597 r
.32032 .52875 m .32479 .52659 L .32252 .52618 L F
.32032 .52875 m .32428 .52953 L .32479 .52659 L F
.424 .163 .412 r
.24936 .58659 m .25182 .58599 L .25252 .58341 L F
.124 .217 .689 r
.25252 .58341 m .25277 .5789 L .25372 .57945 L F
.25252 .58341 m .25373 .58341 L .25277 .5789 L F
.111 .374 .835 r
.25252 .58341 m .25497 .58454 L .25373 .58341 L F
.461 .197 .427 r
.25252 .58341 m .25182 .58599 L .25497 .58454 L F
.964 .936 .696 r
.49892 .45887 m .49956 .45561 L .499 .45603 L F
.393 .839 .731 r
.499 .45603 m .50115 .45482 L .50293 .45336 L F
.499 .45603 m .49956 .45561 L .50115 .45482 L F
.898 .918 .826 r
.53214 .47351 m .5348 .47006 L .53323 .46888 L F
.87 .991 .737 r
.309 .58425 m .30713 .5853 L .30938 .58198 L F
.278 0 0 r
.50293 .45336 m .50502 .45404 L .50498 .45189 L F
.425 .683 .97 r
.38845 .47446 m .39242 .47423 L .38748 .47306 L F
.3891 .47539 m .3899 .47511 L .38845 .47446 L F
.3899 .47511 m .39242 .47423 L .38845 .47446 L F
.3891 .47539 m .39122 .47571 L .39242 .47423 L F
.31 .686 .978 r
.38847 .47447 m .39122 .47571 L .3891 .47539 L F
.295 0 0 r
.38999 .47516 m .39096 .47559 L .38847 .47447 L F
.39096 .47559 m .39122 .47571 L .39036 .47532 L F
.39096 .47559 m .39036 .47532 L .38847 .47447 L F
0 0 .412 r
.38847 .47447 m .3891 .47539 L .38748 .47306 L F
.48 .391 .678 r
.38497 .47361 m .38847 .47447 L .38748 .47306 L F
.016 0 0 r
.42451 .45511 m .42601 .45309 L .42262 .45541 L F
.108 0 0 r
.42451 .45511 m .42841 .45209 L .42601 .45309 L F
.937 .943 .769 r
.56813 .40504 m .57122 .40228 L .56966 .40303 L F
0 0 0 r
.57232 .3999 m .57443 .3984 L .57221 .40024 L F
.678 .799 .339 r
.57122 .40228 m .57241 .39965 L .57232 .3999 L F
.755 .97 .695 r
.56966 .40303 m .57122 .40228 L .57232 .3999 L F
0 0 0 r
.57232 .3999 m .57221 .40024 L .57119 .40108 L F
.678 .799 .339 r
.57241 .39965 m .5732 .3979 L .57232 .3999 L F
.923 .928 .794 r
.54465 .44455 m .54833 .44182 L .54704 .44069 L F
.892 .901 .827 r
.54833 .44182 m .54824 .43883 L .54704 .44069 L F
.859 .877 .85 r
.4995 .50003 m .50074 .4955 L .49781 .49878 L F
.4995 .50003 m .50231 .49691 L .50074 .4955 L F
.813 .933 .562 r
.40856 .57148 m .40798 .57173 L .40968 .56998 L F
.797 .628 .672 r
.40651 .56864 m .40847 .57097 L .41029 .56928 L F
.40613 .56858 m .40689 .56935 L .40651 .56864 L F
.40689 .56935 m .40847 .57097 L .40651 .56864 L F
.519 .589 .865 r
.40613 .56858 m .40847 .57097 L .40361 .56819 L F
.40847 .57097 m .40845 .57101 L .40361 .56819 L F
.40613 .56858 m .40847 .57097 L .40361 .56819 L F
.861 .996 .806 r
.40847 .57097 m .40827 .57142 L .41029 .56928 L F
.519 .589 .865 r
.40847 .57097 m .40856 .57107 L .40845 .57101 L F
.40847 .57097 m .40845 .57101 L .40361 .56819 L F
.861 .996 .806 r
.40799 .57142 m .40798 .57173 L .40827 .57142 L F
.40799 .57142 m .40827 .57142 L .40847 .57097 L F
.40805 .56949 m .40856 .57107 L .40768 .57017 L F
.40805 .56949 m .40768 .57017 L .40613 .56858 L F
.797 .628 .672 r
.40613 .56858 m .41029 .56928 L .409 .56414 L F
.139 .166 .627 r
.40613 .56858 m .40805 .56949 L .40846 .56599 L F
.238 .338 .764 r
.41188 .56623 m .41029 .56928 L .409 .56414 L F
0 0 .353 r
.40805 .56949 m .40947 .56504 L .40846 .56599 L F
.40805 .56949 m .40947 .56768 L .40947 .56504 L F
.598 .894 .603 r
.40805 .56949 m .40632 .57084 L .4085 .56865 L F
.40805 .56949 m .4085 .56865 L .40947 .56768 L F
.861 .996 .806 r
.40805 .56949 m .40799 .57142 L .40847 .57097 L F
.40916 .56938 m .40847 .57097 L .41029 .56928 L F
.40805 .56949 m .40847 .57097 L .40916 .56938 L F
.519 .589 .865 r
.40847 .57097 m .40856 .57107 L .40845 .57101 L F
0 .138 .681 r
.40799 .57142 m .40842 .5705 L .40805 .56949 L F
.40798 .57173 m .40805 .57153 L .40799 .57142 L F
.40805 .57153 m .40842 .5705 L .40799 .57142 L F
.797 .628 .672 r
.40847 .57097 m .40856 .57107 L .41029 .56928 L F
.717 .986 .881 r
.40753 .57301 m .40798 .57173 L .40856 .57148 L F
.532 .829 .5 r
.40968 .56998 m .41029 .56928 L .41182 .56864 L F
.324 .8 .913 r
.41029 .56928 m .41498 .56893 L .41182 .56864 L F
.41029 .56928 m .41335 .56856 L .41498 .56893 L F
.588 .323 .482 r
.40798 .57173 m .41074 .57399 L .41301 .569 L F
0 .138 .681 r
.40798 .57173 m .40931 .57296 L .40842 .5705 L F
.717 .986 .881 r
.40702 .57377 m .40798 .57173 L .40753 .57301 L F
.40702 .57377 m .40442 .57394 L .40798 .57173 L F
.806 .628 .661 r
.52201 .46002 m .51828 .45961 L .5184 .45518 L F
.744 .893 .947 r
.52201 .46002 m .51694 .46136 L .51828 .45961 L F
.776 .764 .841 r
.31486 .65736 m .31722 .65875 L .31585 .65621 L F
.885 .495 .287 r
.31589 .65996 m .31722 .65875 L .31486 .65736 L F
.079 0 0 r
.31862 .65915 m .31722 .65875 L .31589 .65996 L F
.31862 .65915 m .31977 .65826 L .31722 .65875 L F
.18 0 0 r
.32088 .65743 m .31722 .65875 L .31977 .65826 L F
.989 .889 .573 r
.52921 .39925 m .52945 .39434 L .5319 .39585 L F
.52921 .39925 m .52827 .39802 L .52945 .39434 L F
.537 .352 .578 r
.5319 .39585 m .53213 .39887 L .52921 .39925 L F
.602 .047 0 r
.53213 .39887 m .52827 .39802 L .52921 .39925 L F
.784 .843 .896 r
.49568 .472 m .49163 .47171 L .49356 .47019 L F
.49568 .472 m .49329 .47322 L .49163 .47171 L F
.76 .965 .931 r
.49356 .47019 m .49815 .46877 L .49568 .472 L F
.924 .74 .636 r
.32788 .55527 m .33058 .55347 L .32848 .55246 L F
.32788 .55527 m .33007 .55645 L .33058 .55347 L F
.399 .2 .491 r
.27382 .54259 m .27626 .53885 L .27432 .5396 L F
.847 .702 .702 r
.32776 .53561 m .32948 .53963 L .33019 .53687 L F
.811 .995 .864 r
.49553 .40356 m .49249 .40617 L .49324 .40359 L F
.672 .973 .898 r
.49553 .40356 m .49668 .40143 L .49795 .40217 L F
.49553 .40356 m .49324 .40359 L .49668 .40143 L F
.347 .087 .37 r
.64668 .36501 m .64369 .36836 L .6439 .36578 L F
0 0 .243 r
.6439 .36578 m .64535 .36617 L .64668 .36501 L F
.6439 .36578 m .64369 .36836 L .64535 .36617 L F
.576 .39 .592 r
.50336 .4151 m .50079 .41258 L .50317 .4118 L F
.50336 .4151 m .50087 .41566 L .50079 .41258 L F
0 0 0 r
.47342 .43089 m .47605 .4289 L .47478 .43111 L F
.47342 .43089 m .47478 .43111 L .47127 .43306 L F
.898 .918 .826 r
.53214 .47351 m .53323 .46888 L .53014 .47186 L F
0 0 .306 r
.55985 .39247 m .56094 .39307 L .55891 .39086 L F
.55985 .39247 m .5599 .39574 L .56094 .39307 L F
.895 .893 .819 r
.38008 .5833 m .37822 .586 L .3764 .58498 L F
.471 .534 .841 r
.37822 .586 m .37881 .58416 L .3764 .58498 L F
.37822 .586 m .38075 .58589 L .37881 .58416 L F
.821 .933 .559 r
.31483 .6471 m .31754 .64242 L .31529 .64502 L F
.781 .797 .866 r
.31911 .63763 m .31754 .64242 L .31521 .64167 L F
.31911 .63763 m .32075 .63982 L .31754 .64242 L F
.41 0 .033 r
.31529 .64502 m .31754 .64242 L .31854 .64369 L F
.358 .791 .967 r
.55143 .40872 m .55549 .40915 L .55462 .40829 L F
.55143 .40872 m .55549 .40915 L .55462 .40829 L F
.786 .993 .879 r
.55462 .40829 m .55549 .40915 L .55573 .4069 L F
.55462 .40829 m .55549 .40915 L .55573 .4069 L F
.219 .135 .542 r
.25727 .56603 m .25981 .56183 L .25776 .56221 L F
.25727 .56603 m .26003 .56477 L .25981 .56183 L F
.22 .093 .486 r
.25727 .56603 m .26011 .5676 L .26003 .56477 L F
.25727 .56603 m .2572 .57067 L .26011 .5676 L F
.455 0 0 r
.39361 .5736 m .39606 .57453 L .3933 .57295 L F
.757 .754 .85 r
.42724 .55905 m .42849 .56269 L .42623 .56331 L F
.4313 .55948 m .42849 .56269 L .42724 .55905 L F
.847 .872 .86 r
.51584 .48277 m .51921 .48256 L .51756 .48124 L F
.809 .844 .876 r
.51756 .48124 m .51921 .48256 L .52225 .47952 L F
.306 .08 .398 r
.58406 .38019 m .58107 .38226 L .5837 .37876 L F
.58422 .38084 m .58303 .38137 L .58406 .38019 L F
.58303 .38137 m .58107 .38226 L .58406 .38019 L F
.442 .149 .371 r
.58665 .37591 m .58649 .37809 L .5837 .37876 L F
.63 .391 .537 r
.58422 .38084 m .58649 .37809 L .5837 .37876 L F
.708 .447 .529 r
.58236 .38058 m .58519 .37887 L .58492 .37727 L F
.58519 .37887 m .58649 .37809 L .58606 .37787 L F
.58539 .37865 m .58606 .37787 L .58492 .37727 L F
.63 .391 .537 r
.58422 .38084 m .58681 .38101 L .58649 .37809 L F
.708 .447 .529 r
.58542 .37874 m .58681 .38101 L .58649 .37809 L F
.58236 .38058 m .58653 .38098 L .58542 .37874 L F
.58653 .38098 m .58681 .38101 L .58542 .37874 L F
0 0 .335 r
.58635 .38009 m .58492 .37727 L .58649 .37809 L F
0 0 .532 r
.58618 .3797 m .58432 .37551 L .58492 .37727 L F
.58432 .37551 m .58413 .37508 L .58492 .37727 L F
.708 .447 .529 r
.58519 .37887 m .58539 .37865 L .58492 .37727 L F
0 0 .335 r
.58681 .38101 m .58635 .38009 L .58649 .37809 L F
.442 .149 .371 r
.58667 .37589 m .58649 .37809 L .58665 .37591 L F
.487 0 0 r
.31509 .6834 m .3205 .68365 L .31722 .68457 L F
.375 .837 .777 r
.31722 .68457 m .3205 .68365 L .32107 .68325 L F
.549 .598 .855 r
.31999 .68561 m .32107 .68325 L .3205 .68365 L F
.793 .749 .813 r
.30797 .56533 m .30386 .56586 L .3063 .56334 L F
.601 .16 .174 r
.30797 .56533 m .30675 .56653 L .30386 .56586 L F
.482 .568 .866 r
.30916 .56264 m .30797 .56533 L .3063 .56334 L F
.30916 .56264 m .31052 .56543 L .30797 .56533 L F
0 0 0 r
.30882 .56553 m .30797 .56533 L .31052 .56543 L F
.30882 .56553 m .30675 .56653 L .30797 .56533 L F
.033 0 0 r
.58649 .37809 m .58946 .37741 L .58767 .37735 L F
.58649 .37809 m .58946 .37741 L .58767 .37735 L F
.332 .227 .582 r
.53375 .40879 m .53209 .41266 L .53435 .41202 L F
.675 .181 .069 r
.53209 .41266 m .53714 .41485 L .53809 .41579 L F
.413 .55 .884 r
.53209 .41266 m .53809 .41579 L .53435 .41202 L F
.587 .586 .819 r
.24369 .59635 m .24547 .6005 L .24855 .59822 L F
.504 .638 .914 r
.29316 .67927 m .29447 .68169 L .29722 .68113 L F
.538 .834 .999 r
.30335 .64652 m .30099 .64727 L .29879 .6462 L F
.892 .977 .82 r
.49184 .48326 m .48953 .48612 L .48906 .48452 L F
.944 .89 .746 r
.49184 .48326 m .49075 .48189 L .49462 .48238 L F
.49184 .48326 m .48906 .48452 L .49075 .48189 L F
.706 .901 .966 r
.29599 .62916 m .29401 .63057 L .29203 .62956 L F
.383 .163 .451 r
.50498 .45189 m .50809 .44812 L .50544 .44951 L F
.376 .457 .816 r
.50809 .44812 m .50498 .45189 L .50544 .44951 L F
.889 .685 .621 r
.35941 .5527 m .36142 .55651 L .35909 .55525 L F
.907 .761 .688 r
.36142 .55651 m .35766 .55878 L .35909 .55525 L F
.36142 .55651 m .36083 .55931 L .35766 .55878 L F
.621 .498 .691 r
.27173 .56346 m .2724 .56628 L .26965 .56672 L F
.608 .44 .629 r
.2724 .56628 m .26969 .56949 L .26965 .56672 L F
.621 .498 .691 r
.27173 .56346 m .2724 .56628 L .26965 .56672 L F
.556 .837 .997 r
.40326 .54777 m .40426 .54937 L .40453 .54849 L F
0 0 .075 r
.40511 .54988 m .40426 .54937 L .404 .54895 L F
.40335 .54787 m .404 .54895 L .40326 .54777 L F
.404 .54895 m .404 .54895 L .40392 .54882 L F
.548 .247 .409 r
.40426 .54937 m .40205 .5498 L .40392 .54882 L F
.40426 .54937 m .40392 .54882 L .40453 .54849 L F
0 0 .075 r
.40511 .54988 m .404 .54895 L .40335 .54787 L F
.787 .649 .093 r
.40392 .54882 m .40348 .54809 L .40453 .54849 L F
0 0 .075 r
.404 .54895 m .40392 .54882 L .40335 .54787 L F
.787 .649 .093 r
.40205 .5498 m .4018 .54744 L .40348 .54809 L F
.40205 .5498 m .40348 .54809 L .40392 .54882 L F
.40205 .5498 m .4017 .55022 L .4018 .54744 L F
.767 .421 0 r
.40205 .5498 m .40327 .55372 L .4017 .55022 L F
.548 .247 .409 r
.40426 .54937 m .40371 .55232 L .40205 .5498 L F
.567 .252 .395 r
.40371 .55232 m .40327 .55372 L .40205 .5498 L F
.743 .946 .947 r
.49249 .40617 m .49107 .40524 L .49324 .40359 L F
.027 0 0 r
.6437 .33904 m .64649 .3391 L .64807 .33908 L F
.05 0 0 r
.64807 .33908 m .64649 .3391 L .65068 .33924 L F
.062 0 0 r
.64807 .33908 m .65068 .33924 L .6518 .33905 L F
.994 .771 .492 r
.48953 .48612 m .48833 .48594 L .48906 .48452 L F
.48953 .48612 m .48947 .48939 L .48833 .48594 L F
.841 .929 .888 r
.64867 .39125 m .64982 .39261 L .65273 .38961 L F
.091 0 0 r
.42473 .46325 m .4257 .46449 L .42335 .465 L F
.42473 .46325 m .42711 .46204 L .4257 .46449 L F
.806 .973 .675 r
.49329 .47322 m .49152 .47448 L .49163 .47171 L F
.917 .977 .716 r
.54522 .41995 m .54669 .41593 L .54389 .41915 L F
.807 .386 .246 r
.54338 .42131 m .54522 .41995 L .54389 .41915 L F
.54338 .42131 m .54714 .4222 L .54522 .41995 L F
.859 .78 .772 r
.52291 .41798 m .51988 .42219 L .51808 .41941 L F
.52291 .41798 m .51808 .41941 L .52108 .42017 L F
.99 .728 .39 r
.52291 .41798 m .52294 .42224 L .51988 .42219 L F
.498 .528 .818 r
.52291 .41798 m .52581 .4181 L .52613 .41637 L F
.815 .554 .544 r
.52108 .42017 m .52581 .4181 L .52291 .41798 L F
.453 .615 .918 r
.52581 .4181 m .52291 .41798 L .52613 .41637 L F
.757 .599 .682 r
.49731 .47641 m .49732 .47918 L .49245 .47868 L F
.666 .542 .704 r
.50003 .47545 m .49732 .47918 L .49731 .47641 L F
.135 0 .057 r
.4182 .46876 m .4175 .47113 L .41505 .47235 L F
.184 0 .249 r
.42075 .46576 m .42082 .46842 L .4182 .46876 L F
.093 0 0 r
.4182 .46876 m .41957 .4696 L .4175 .47113 L F
.4182 .46876 m .42082 .46842 L .41957 .4696 L F
.152 0 .128 r
.43634 .45829 m .43725 .45644 L .43951 .45537 L F
.812 .747 .791 r
.52518 .37173 m .52752 .37577 L .52349 .37309 L F
0 .224 .653 r
.52752 .37577 m .52642 .37495 L .52349 .37309 L F
.634 .951 .753 r
.52459 .36238 m .52281 .36304 L .52646 .36025 L F
.067 .053 .53 r
.52646 .36025 m .52644 .3641 L .52459 .36238 L F
.549 .712 .948 r
.5284 .37335 m .52752 .37577 L .52518 .37173 L F
.5284 .37335 m .53034 .37518 L .52752 .37577 L F
.8 .974 .906 r
.5284 .37335 m .52752 .37577 L .53034 .37518 L F
.5284 .37335 m .52642 .37495 L .52752 .37577 L F
.902 .667 .573 r
.53048 .3922 m .5319 .39585 L .52945 .39434 L F
.412 .26 .563 r
.53441 .39756 m .53213 .39887 L .5319 .39585 L F
.684 .65 .81 r
.37652 .58057 m .38008 .5833 L .37865 .58189 L F
.895 .893 .819 r
.38008 .5833 m .3764 .58498 L .37865 .58189 L F
0 0 0 r
.38175 .58147 m .38008 .5833 L .38335 .57963 L F
.348 .606 .945 r
.38175 .58147 m .38334 .58332 L .38008 .5833 L F
.462 0 0 r
.55231 .40305 m .55391 .40219 L .55233 .4018 L F
0 0 0 r
.29235 .52954 m .29076 .53116 L .28889 .53203 L F
0 0 .318 r
.29029 .5338 m .28889 .53203 L .29076 .53116 L F
.29029 .5338 m .2894 .53605 L .28889 .53203 L F
.901 .558 .385 r
.67163 .35356 m .67445 .35286 L .67096 .35137 L F
.67163 .35356 m .67409 .35485 L .67445 .35286 L F
.95 .652 .209 r
.41936 .58628 m .41926 .58863 L .42022 .5895 L F
.679 .57 .726 r
.41936 .58628 m .42022 .5895 L .42189 .58567 L F
.95 .652 .209 r
.41936 .58628 m .41926 .58863 L .42022 .5895 L F
.532 .768 .984 r
.60722 .3806 m .60564 .38291 L .60436 .38127 L F
.60722 .3806 m .60879 .38218 L .60564 .38291 L F
.60722 .3806 m .60564 .38291 L .60436 .38127 L F
.60722 .3806 m .60879 .38218 L .60564 .38291 L F
.856 .877 .854 r
.50074 .4955 m .50231 .49691 L .50369 .49509 L F
.592 .571 .799 r
.6041 .36169 m .60228 .36347 L .60079 .35813 L F
.459 .852 .651 r
.45719 .44189 m .46119 .43932 L .45964 .4408 L F
0 0 0 r
.45964 .4408 m .46119 .43932 L .46347 .43797 L F
.914 .839 .757 r
.45409 .54156 m .45548 .54513 L .45579 .54305 L F
.45409 .54156 m .45176 .54559 L .45548 .54513 L F
.912 .851 .77 r
.45176 .54559 m .45357 .54688 L .45548 .54513 L F
.652 .968 .892 r
.39242 .56707 m .39049 .56814 L .38961 .56775 L F
.38961 .56775 m .39049 .56814 L .39242 .56707 L F
.453 .646 .941 r
.60838 .36674 m .61 .36946 L .61113 .36683 L F
.506 .909 .824 r
.3133 .64303 m .31089 .6444 L .31303 .64523 L F
.234 0 0 r
.24626 .59559 m .24841 .5955 L .25087 .59335 L F
.625 .858 .49 r
.25087 .59335 m .2518 .59186 L .25349 .58988 L F
.641 .908 .601 r
.25087 .59335 m .24841 .5955 L .2518 .59186 L F
.971 .873 .682 r
.54117 .45053 m .543 .45231 L .54369 .44942 L F
.965 .901 .708 r
.53978 .4544 m .543 .45231 L .54117 .45053 L F
.53978 .4544 m .54105 .45549 L .543 .45231 L F
.686 .692 .85 r
.38897 .56354 m .39242 .56707 L .38801 .56698 L F
.652 .968 .892 r
.39242 .56707 m .38733 .56818 L .38801 .56698 L F
.39242 .56707 m .38961 .56775 L .38733 .56818 L F
.783 .301 0 r
.39062 .56566 m .39242 .56707 L .38897 .56354 L F
.652 .968 .892 r
.38961 .56775 m .39242 .56707 L .39062 .56566 L F
.873 .722 .692 r
.50421 .47895 m .50571 .48312 L .5039 .48098 L F
.682 .814 .946 r
.50571 .48312 m .50158 .48266 L .5039 .48098 L F
.855 .88 .856 r
.4783 .52181 m .47473 .522 L .47644 .52345 L F
.4783 .52181 m .47761 .51875 L .47473 .522 L F
.831 .869 .873 r
.4783 .52181 m .47941 .52006 L .47761 .51875 L F
.668 .801 .946 r
.61748 .39413 m .61552 .3958 L .61865 .39493 L F
.61748 .39413 m .61552 .3958 L .61865 .39493 L F
.87 .813 .791 r
.33647 .62003 m .34028 .62001 L .33865 .61673 L F
.769 .344 .241 r
.33747 .62235 m .34028 .62001 L .33647 .62003 L F
.96 .656 .408 r
.34301 .61909 m .33865 .61673 L .34028 .62001 L F
.017 0 0 r
.34301 .61909 m .34028 .62001 L .33747 .62235 L F
.407 .611 .933 r
.24393 .6107 m .24625 .61076 L .24483 .6085 L F
0 0 0 r
.55801 .38856 m .5591 .38389 L .55848 .38592 L F
.942 .963 .711 r
.47843 .50279 m .47632 .50397 L .47718 .50162 L F
.47843 .50279 m .47639 .50679 L .47632 .50397 L F
.857 .905 .866 r
.47987 .49829 m .47843 .50279 L .47718 .50162 L F
.47987 .49829 m .48145 .49957 L .47843 .50279 L F
.931 .955 .774 r
.47086 .51333 m .47086 .51032 L .47361 .51026 L F
.852 .953 .878 r
.47361 .51026 m .47388 .50731 L .47501 .50792 L F
.47361 .51026 m .47086 .51032 L .47388 .50731 L F
.634 .13 .034 r
.31945 .54808 m .3154 .54813 L .31754 .54697 L F
.693 .82 .943 r
.25497 .58454 m .25182 .58599 L .25461 .5861 L F
.25497 .58454 m .25461 .5861 L .25608 .58615 L F
.784 .41 .348 r
.25863 .58583 m .25497 .58454 L .25608 .58615 L F
.629 .842 .452 r
.25473 .5881 m .25524 .58726 L .25608 .58615 L F
.25349 .58988 m .25424 .58858 L .25524 .58726 L F
.25349 .58988 m .25524 .58726 L .25473 .5881 L F
.937 .63 .434 r
.25608 .58615 m .25424 .58858 L .25672 .58907 L F
.791 .936 .925 r
.25672 .58907 m .25424 .58858 L .2562 .58722 L F
.25672 .58907 m .2562 .58722 L .25677 .58714 L F
.784 .41 .348 r
.2569 .58732 m .25631 .58783 L .25611 .58735 L F
.25648 .58677 m .25611 .58735 L .25519 .58509 L F
.2569 .58732 m .25611 .58735 L .25648 .58677 L F
.791 .936 .925 r
.25677 .58714 m .2562 .58722 L .25677 .58681 L F
.784 .41 .348 r
.25717 .58709 m .25678 .58714 L .25497 .58454 L F
.2569 .58732 m .25519 .58509 L .25497 .58454 L F
0 .174 .7 r
.25677 .58714 m .25695 .58752 L .25672 .58907 L F
.25695 .58752 m .25795 .58953 L .25741 .58933 L F
.25695 .58752 m .25741 .58933 L .25672 .58907 L F
.984 .859 .636 r
.25677 .58681 m .25631 .58783 L .2569 .58732 L F
.784 .41 .348 r
.25863 .58583 m .25717 .58709 L .25497 .58454 L F
.25717 .58709 m .2569 .58732 L .25678 .58714 L F
.984 .859 .636 r
.25677 .58681 m .2569 .58732 L .25863 .58583 L F
0 .174 .7 r
.25711 .58759 m .25795 .58953 L .25677 .58714 L F
.48 .055 .156 r
.26101 .585 m .2599 .58691 L .25789 .58685 L F
.25725 .58661 m .25789 .58685 L .25677 .58681 L F
.26101 .585 m .25789 .58685 L .25725 .58661 L F
.518 .504 .781 r
.25789 .58685 m .25795 .58953 L .25677 .58681 L F
.2599 .58691 m .25819 .58921 L .25789 .58685 L F
.25819 .58921 m .25795 .58953 L .25789 .58685 L F
.52 .257 .456 r
.25906 .58739 m .25677 .58681 L .2599 .58691 L F
.588 .501 .724 r
.25898 .58725 m .25906 .58739 L .25902 .58727 L F
0 .174 .7 r
.25677 .58681 m .25711 .58759 L .25677 .58714 L F
.52 .257 .456 r
.25906 .58739 m .25631 .58783 L .25677 .58681 L F
.588 .501 .724 r
.25898 .58725 m .25631 .58783 L .25906 .58739 L F
0 0 0 r
.25653 .58724 m .25884 .58725 L .25677 .58681 L F
.25902 .58726 m .2599 .58691 L .25789 .58685 L F
.386 .421 .775 r
.25721 .58041 m .25902 .58726 L .26018 .58232 L F
.25902 .58726 m .25906 .58739 L .25908 .58728 L F
.25902 .58726 m .25908 .58728 L .26018 .58232 L F
0 0 0 r
.25907 .58728 m .25908 .58728 L .25902 .58726 L F
.25908 .58728 m .2599 .58691 L .25902 .58726 L F
.392 .486 .836 r
.2599 .58691 m .25908 .58728 L .25906 .58739 L F
0 0 0 r
.25916 .58732 m .2599 .58691 L .25907 .58728 L F
.392 .486 .836 r
.2599 .58691 m .26018 .58232 L .25908 .58728 L F
0 0 0 r
.25884 .58725 m .25789 .58685 L .25677 .58681 L F
.25916 .58732 m .25898 .58725 L .25884 .58725 L F
.25898 .58725 m .25789 .58685 L .25884 .58725 L F
0 0 .175 r
.2562 .58722 m .25608 .5875 L .25677 .58681 L F
.588 .501 .724 r
.25544 .58082 m .25624 .58724 L .25838 .58616 L F
0 0 .175 r
.25608 .5875 m .25653 .58724 L .25677 .58681 L F
.588 .501 .724 r
.25624 .58724 m .25626 .5874 L .25653 .58724 L F
.25624 .58724 m .25653 .58724 L .25838 .58616 L F
.25838 .58616 m .25704 .58724 L .25898 .58725 L F
.25704 .58724 m .25631 .58783 L .25898 .58725 L F
0 0 0 r
.25527 .58943 m .25916 .58732 L .25884 .58725 L F
.588 .501 .724 r
.25626 .5874 m .25631 .58783 L .25838 .58616 L F
0 0 0 r
.25527 .58943 m .25884 .58725 L .25653 .58724 L F
.588 .501 .724 r
.25707 .58044 m .25898 .58725 L .25721 .58041 L F
.25544 .58082 m .25763 .5848 L .25707 .58044 L F
.25763 .5848 m .25898 .58725 L .25707 .58044 L F
.25898 .58725 m .25902 .58727 L .25721 .58041 L F
0 0 .175 r
.25608 .5875 m .25527 .58943 L .25653 .58724 L F
.25424 .58858 m .25496 .58918 L .2562 .58722 L F
.25496 .58918 m .25527 .58943 L .2562 .58722 L F
0 0 .507 r
.25497 .58454 m .25574 .58644 L .25551 .58216 L F
.25497 .58454 m .25551 .58216 L .25544 .58082 L F
.25574 .58644 m .25631 .58783 L .25607 .5859 L F
.25574 .58644 m .25607 .5859 L .25544 .58082 L F
.44 .509 .834 r
.2569 .59243 m .25349 .58988 L .25672 .58907 L F
.9 .682 .598 r
.40976 .476 m .41117 .47883 L .40695 .47807 L F
.93 .784 .679 r
.41117 .47883 m .40759 .48149 L .40695 .47819 L F
.782 .473 .464 r
.40982 .48164 m .40759 .48149 L .41117 .47883 L F
.451 .628 .929 r
.50745 .41695 m .50948 .42057 L .51192 .41929 L F
.354 .257 .604 r
.25776 .56221 m .2595 .559 L .25742 .55959 L F
.902 .667 .573 r
.53048 .3922 m .52945 .39434 L .52734 .39205 L F
.905 .968 .81 r
.47501 .50792 m .47388 .50731 L .47639 .50679 L F
.91 .965 .805 r
.47639 .50679 m .47388 .50731 L .47632 .50397 L F
.971 .873 .682 r
.54117 .45053 m .54369 .44942 L .54273 .44836 L F
.935 .923 .774 r
.54369 .44942 m .54465 .44455 L .54273 .44836 L F
.509 .383 .644 r
.5081 .40351 m .5115 .40385 L .51033 .39986 L F
.5081 .40351 m .50883 .40494 L .5115 .40385 L F
.763 .852 .918 r
.31377 .58831 m .31966 .58704 L .31748 .58534 L F
.812 .751 .796 r
.31748 .58534 m .31966 .58704 L .32247 .58368 L F
0 0 .051 r
.42335 .465 m .42082 .46842 L .42075 .46576 L F
.66 .486 .639 r
.42623 .56331 m .4228 .56404 L .42456 .56243 L F
.42623 .56331 m .42301 .56585 L .4228 .56404 L F
.42623 .56331 m .42591 .56624 L .42301 .56585 L F
.757 .754 .85 r
.42724 .55905 m .42623 .56331 L .42456 .56243 L F
.96 .656 .408 r
.34301 .61909 m .34292 .61665 L .34096 .61554 L F
.165 .684 .884 r
.31585 .65621 m .3145 .65633 L .31154 .65576 L F
.787 .585 .627 r
.37466 .5423 m .37952 .54505 L .37916 .54303 L F
.546 .407 .643 r
.37916 .54303 m .38207 .54265 L .38137 .53958 L F
.284 .191 .57 r
.37916 .54303 m .38138 .54497 L .38207 .54265 L F
.37916 .54303 m .37952 .54505 L .38138 .54497 L F
.639 .964 .826 r
.51687 .45318 m .51813 .4513 L .51901 .45204 L F
.51687 .45318 m .51456 .45381 L .51813 .4513 L F
.168 0 .309 r
.51687 .45318 m .51674 .4554 L .51901 .45204 L F
.52 .063 .108 r
.57292 .38048 m .57734 .37865 L .57255 .37852 L F
.57292 .38048 m .57577 .38081 L .57734 .37865 L F
.198 .43 .859 r
.57734 .37865 m .58154 .38109 L .58107 .38226 L F
.503 .832 .999 r
.57577 .38081 m .58154 .38109 L .57734 .37865 L F
0 .505 .779 r
.60097 .34232 m .60253 .34265 L .6038 .34328 L F
.704 .245 .158 r
.60253 .34265 m .60768 .34297 L .6038 .34328 L F
.376 0 0 r
.65068 .33924 m .65479 .33959 L .6518 .33905 L F
.377 .527 .88 r
.5703 .35348 m .56837 .35561 L .56712 .35247 L F
.536 .517 .782 r
.5703 .35348 m .56838 .35833 L .56837 .35561 L F
.87 .709 .68 r
.32611 .53917 m .32948 .53963 L .32776 .53561 L F
.854 .679 .664 r
.32611 .53917 m .32898 .54254 L .32948 .53963 L F
.609 .242 .322 r
.41658 .58651 m .41926 .58863 L .41936 .58628 L F
.373 0 .136 r
.27891 .53563 m .28151 .53538 L .28287 .53297 L F
.622 .273 .359 r
.57578 .38913 m .5752 .39173 L .57165 .3915 L F
0 0 .151 r
.57753 .38973 m .57578 .38913 L .57776 .38723 L F
.57753 .38973 m .5752 .39173 L .57578 .38913 L F
.374 .124 .401 r
.30119 .55314 m .30388 .55263 L .30144 .55085 L F
.30119 .55314 m .30083 .55563 L .30388 .55263 L F
.30388 .55263 m .30083 .55563 L .30119 .55314 L F
.582 .279 .419 r
.3891 .47539 m .38892 .47771 L .38771 .47658 L F
.722 .45 .514 r
.39047 .4756 m .38897 .4783 L .3891 .47539 L F
.38897 .4783 m .38887 .47829 L .3891 .47539 L F
.38984 .47734 m .38904 .47828 L .39047 .4756 L F
.38904 .47828 m .38885 .4785 L .38898 .47827 L F
.38904 .47828 m .38898 .47827 L .39047 .4756 L F
.39122 .47571 m .38984 .47734 L .39047 .4756 L F
.39122 .47571 m .39146 .47865 L .38885 .4785 L F
0 0 .352 r
.39242 .47423 m .39122 .47571 L .39284 .47416 L F
.499 .892 .95 r
.39284 .47416 m .39122 .47571 L .38999 .47516 L F
.743 .466 .511 r
.39571 .47842 m .39146 .47865 L .39122 .47571 L F
.648 .899 .571 r
.38951 .47832 m .39284 .47416 L .38999 .47516 L F
.3895 .47836 m .38953 .47833 L .38951 .47832 L F
.38953 .47833 m .39284 .47416 L .38951 .47832 L F
.582 .279 .419 r
.38598 .47806 m .38885 .4785 L .3854 .47856 L F
.38771 .47658 m .38872 .47828 L .38598 .47806 L F
.38872 .47828 m .38885 .4785 L .38598 .47806 L F
.38892 .47771 m .38887 .47829 L .38771 .47658 L F
.38887 .47829 m .38885 .4785 L .38872 .47828 L F
.38887 .47829 m .38872 .47828 L .38771 .47658 L F
.925 .667 .529 r
.38847 .47447 m .38562 .47715 L .38947 .47835 L F
.182 .676 .919 r
.38943 .47834 m .38949 .47835 L .38947 .47835 L F
.38562 .47715 m .38945 .47834 L .38943 .47834 L F
.38945 .47834 m .38949 .47835 L .38943 .47834 L F
.38643 .4774 m .3879 .47714 L .38947 .47833 L F
.38562 .47715 m .38947 .47833 L .38948 .47834 L F
.38562 .47715 m .38948 .47834 L .38945 .47834 L F
.925 .667 .529 r
.38847 .47447 m .38947 .47835 L .38949 .4783 L F
.38847 .47447 m .38947 .47823 L .38999 .47516 L F
.38949 .4783 m .38947 .47835 L .3895 .47836 L F
.38947 .47823 m .3895 .47836 L .38952 .47827 L F
.38947 .47823 m .38952 .47827 L .38999 .47516 L F
.588 .928 .956 r
.3879 .47714 m .3911 .47577 L .3895 .47836 L F
.012 0 0 r
.38674 .47833 m .3895 .47685 L .3879 .47714 L F
.3895 .47685 m .39041 .47636 L .3879 .47714 L F
.182 .676 .919 r
.38562 .47715 m .3879 .47714 L .38643 .4774 L F
.38945 .47834 m .38948 .47834 L .38949 .47835 L F
.38947 .47835 m .38949 .47835 L .3895 .47836 L F
.722 .45 .514 r
.38897 .4783 m .38885 .4785 L .38887 .47829 L F
.071 .277 .765 r
.4177 .585 m .41926 .58863 L .41658 .58651 L F
.163 .38 .828 r
.34556 .63277 m .34308 .63008 L .34627 .63028 L F
.531 .243 .422 r
.34627 .63028 m .34848 .63237 L .34556 .63277 L F
.923 .681 .556 r
.32898 .54254 m .32861 .54543 L .33094 .54632 L F
.878 .718 .679 r
.32861 .54543 m .33025 .54893 L .33094 .54632 L F
.232 .707 .939 r
.58422 .38084 m .58681 .38101 L .58724 .38174 L F
.833 .59 .041 r
.58724 .38174 m .58681 .38101 L .58649 .37809 L F
.549 .598 .855 r
.31999 .68561 m .32333 .68752 L .32107 .68325 L F
.498 .903 .798 r
.35017 .63372 m .34633 .63536 L .34709 .63567 L F
.466 .093 .247 r
.35253 .63551 m .35017 .63372 L .34709 .63567 L F
.582 .401 .601 r
.34556 .63277 m .34848 .63237 L .3456 .63568 L F
.65 .904 .584 r
.3456 .63568 m .34848 .63237 L .34662 .63403 L F
.839 .702 .712 r
.34871 .63746 m .35253 .63551 L .34709 .63567 L F
.951 .599 .25 r
.34662 .63403 m .34779 .63595 L .34709 .63567 L F
.34779 .63595 m .34871 .63746 L .34709 .63567 L F
.498 .903 .798 r
.34633 .63536 m .3456 .63568 L .34709 .63567 L F
.466 .093 .247 r
.35253 .63551 m .3524 .63361 L .35017 .63372 L F
0 0 0 r
.32505 .65247 m .32356 .65376 L .32247 .65597 L F
.931 .955 .774 r
.47086 .51333 m .4698 .51236 L .47086 .51032 L F
.883 .967 .841 r
.47086 .51333 m .46798 .51401 L .4698 .51236 L F
.812 .751 .796 r
.31748 .58534 m .32247 .58368 L .3202 .58208 L F
.395 0 0 r
.34184 .64632 m .34469 .64697 L .34622 .64658 L F
0 .124 .674 r
.34688 .64551 m .34622 .64658 L .34469 .64697 L F
.34688 .64551 m .34853 .64908 L .34622 .64658 L F
.907 .763 .692 r
.61948 .39276 m .62022 .39306 L .62053 .39089 L F
.61948 .39276 m .61865 .39493 L .61748 .39413 L F
.61948 .39276 m .61748 .39413 L .62022 .39306 L F
.884 .681 .623 r
.35941 .5527 m .35768 .5488 L .36016 .5498 L F
.206 0 0 r
.55229 .3735 m .55793 .37201 L .55522 .37355 L F
.999 .803 .497 r
.30005 .58004 m .29908 .58151 L .29868 .5797 L F
.728 .981 .91 r
.30005 .58004 m .29868 .5797 L .30062 .57802 L F
.755 .619 .708 r
.49732 .47918 m .49462 .48238 L .49245 .47868 L F
.726 .575 .685 r
.49732 .47918 m .4988 .48372 L .49462 .48238 L F
.666 .542 .704 r
.50003 .47545 m .50157 .47939 L .49732 .47918 L F
.604 .506 .717 r
.50158 .48266 m .49732 .47918 L .50157 .47939 L F
.50158 .48266 m .4988 .48372 L .49732 .47918 L F
.16 .191 .645 r
.57743 .34934 m .57986 .34978 L .57961 .3479 L F
.57743 .34934 m .57804 .35205 L .57986 .34978 L F
.894 .472 .137 r
.54527 .415 m .54583 .41253 L .54358 .41137 L F
0 .079 .633 r
.54797 .41387 m .54813 .41521 L .54675 .4136 L F
.54797 .41387 m .54675 .4136 L .54583 .41253 L F
0 0 .29 r
.54797 .41387 m .55038 .41501 L .55003 .41224 L F
0 0 0 r
.5482 .41392 m .54797 .41387 L .55003 .41224 L F
.685 .976 .901 r
.54669 .41593 m .54797 .41387 L .54429 .41557 L F
0 0 0 r
.54673 .41526 m .54797 .41387 L .5482 .41392 L F
0 .079 .633 r
.54797 .41387 m .54583 .41253 L .54527 .415 L F
.575 .049 0 r
.65479 .33959 m .65729 .34031 L .65856 .33901 L F
.71 .211 .053 r
.65856 .33901 m .65729 .34031 L .66119 .34121 L F
.707 .196 .014 r
.65856 .33901 m .66119 .34121 L .66303 .34153 L F
.914 .737 .648 r
.36083 .55931 m .35692 .56155 L .35766 .55878 L F
.36083 .55931 m .35919 .56275 L .35692 .56155 L F
0 0 0 r
.46351 .42791 m .46376 .42754 L .46229 .42918 L F
.46376 .42754 m .46538 .42623 L .46409 .42705 L F
.46737 .42467 m .46538 .42623 L .46376 .42754 L F
.46737 .42467 m .46376 .42754 L .46558 .42577 L F
.46558 .42577 m .46376 .42754 L .46351 .42791 L F
.46376 .42754 m .46409 .42705 L .46189 .42846 L F
.685 .793 .932 r
.42301 .56585 m .41866 .56593 L .4228 .56404 L F
0 0 0 r
.46376 .42754 m .46189 .42846 L .46016 .42988 L F
.779 .904 .928 r
.31315 .62123 m .30848 .62267 L .31182 .62032 L F
.761 .845 .914 r
.31354 .61847 m .31315 .62123 L .31182 .62032 L F
.31354 .61847 m .31552 .61981 L .31315 .62123 L F
0 0 0 r
.41892 .45843 m .42111 .4572 L .42262 .45541 L F
.012 0 0 r
.4235 .45636 m .42262 .45541 L .42111 .4572 L F
.4235 .45636 m .42451 .45511 L .42262 .45541 L F
.555 .895 .655 r
.32247 .65597 m .32088 .65743 L .31977 .65826 L F
.044 0 0 r
.62175 .39441 m .62124 .39474 L .61865 .39493 L F
0 0 0 r
.62378 .39329 m .622 .39434 L .62511 .39345 L F
.422 0 0 r
.62796 .393 m .62378 .39329 L .62511 .39345 L F
.62796 .393 m .6267 .39355 L .62378 .39329 L F
.519 .001 0 r
.63064 .39333 m .62665 .39426 L .6267 .39355 L F
.62665 .39426 m .62628 .39434 L .62634 .39422 L F
.62665 .39426 m .62634 .39422 L .6267 .39355 L F
.288 .669 .972 r
.62588 .39408 m .62692 .39429 L .62846 .39347 L F
.519 .001 0 r
.63064 .39333 m .62945 .39478 L .62628 .39434 L F
.288 .669 .972 r
.62692 .39429 m .62707 .39432 L .62709 .39431 L F
.62692 .39429 m .62709 .39431 L .62846 .39347 L F
.62707 .39432 m .62945 .39478 L .62933 .39462 L F
.62707 .39432 m .62933 .39462 L .62846 .39347 L F
.397 0 0 r
.62575 .39412 m .6267 .39355 L .62634 .39422 L F
.62581 .39415 m .62634 .39422 L .62628 .39434 L F
.62575 .39412 m .62634 .39422 L .62581 .39415 L F
.62378 .39329 m .62643 .39353 L .62575 .39412 L F
.62643 .39353 m .6267 .39355 L .62575 .39412 L F
.06 .29 .778 r
.62378 .39329 m .62628 .39434 L .62588 .39408 L F
.606 .25 .34 r
.62588 .39408 m .62571 .39719 L .62262 .3967 L F
.62588 .39408 m .62571 .39719 L .62262 .3967 L F
.62588 .39408 m .62554 .39431 L .6246 .39549 L F
.455 0 0 r
.62262 .3967 m .62151 .39698 L .61851 .39611 L F
.62262 .3967 m .62151 .39698 L .61851 .39611 L F
.606 .25 .34 r
.62588 .39408 m .62262 .3967 L .62151 .39698 L F
.62554 .39431 m .62151 .39698 L .62373 .39591 L F
.62554 .39431 m .62373 .39591 L .6246 .39549 L F
.06 .29 .778 r
.62378 .39329 m .62588 .39408 L .6253 .39238 L F
.62378 .39329 m .6253 .39238 L .62485 .39106 L F
0 0 0 r
.62378 .39329 m .62175 .39441 L .622 .39434 L F
.62378 .39329 m .62124 .39474 L .62175 .39441 L F
.178 0 0 r
.32232 .651 m .32148 .65069 L .3187 .65015 L F
.993 .839 .48 r
.5737 .36169 m .57309 .36416 L .57398 .36559 L F
.56 .027 0 r
.57442 .36652 m .57398 .36559 L .57309 .36416 L F
.57442 .36652 m .57666 .36824 L .57398 .36559 L F
.758 .338 .252 r
.35216 .63817 m .35484 .63676 L .35253 .63551 L F
.35216 .63817 m .35619 .6394 L .35484 .63676 L F
.772 .509 .538 r
.35153 .6402 m .35593 .64315 L .35422 .64208 L F
.728 .696 .82 r
.4487 .54879 m .45041 .54969 L .45357 .54688 L F
.831 .602 .591 r
.44675 .54891 m .45041 .54969 L .4487 .54879 L F
0 0 0 r
.43965 .44445 m .44097 .44306 L .43772 .44556 L F
.44333 .44178 m .44097 .44306 L .43965 .44445 L F
.737 .666 .78 r
.38261 .53212 m .3843 .53583 L .38807 .53514 L F
.412 .795 .991 r
.56838 .35833 m .57089 .35794 L .57256 .35884 L F
0 0 .512 r
.57411 .35947 m .57256 .35884 L .57089 .35794 L F
.57411 .35947 m .5737 .36169 L .57256 .35884 L F
0 0 .134 r
.52959 .38863 m .53127 .38635 L .53328 .38866 L F
.52959 .38863 m .53013 .38821 L .53127 .38635 L F
0 0 0 r
.52959 .38863 m .52918 .39039 L .53013 .38821 L F
.30676 .63831 m .30896 .63652 L .3111 .63559 L F
.496 .532 .823 r
.2885 .6456 m .28745 .64944 L .28558 .64657 L F
.2885 .6456 m .28941 .64928 L .28745 .64944 L F
.551 .584 .84 r
.54425 .37741 m .54574 .38195 L .54265 .38209 L F
.54425 .37741 m .54265 .38209 L .54355 .38002 L F
.662 .963 .93 r
.54265 .38209 m .54169 .3815 L .54355 .38002 L F
.752 .32 .225 r
.61215 .34883 m .61455 .3515 L .61071 .35038 L F
.764 .305 .16 r
.61629 .35144 m .61455 .3515 L .61215 .34883 L F
.707 .689 .831 r
.63714 .35324 m .63467 .35332 L .63695 .35152 L F
.363 .219 .548 r
.63975 .35082 m .63714 .35324 L .63695 .35152 L F
.63975 .35082 m .64026 .3543 L .63714 .35324 L F
.403 .138 .394 r
.64026 .3543 m .63731 .35537 L .63714 .35324 L F
0 .084 .644 r
.49935 .44043 m .50046 .43983 L .50079 .43777 L F
.399 .496 .842 r
.25564 .59495 m .25781 .59926 L .25346 .5973 L F
.547 .43 .671 r
.25346 .5973 m .25781 .59926 L .25488 .59986 L F
.798 .537 .543 r
.3593 .51895 m .36344 .5223 L .36353 .51951 L F
.692 .481 .596 r
.36344 .5223 m .36642 .51891 L .36353 .51951 L F
.903 .675 .585 r
.35489 .54231 m .35269 .53863 L .3551 .53955 L F
.69 .752 .253 r
.58566 .39222 m .58452 .39553 L .58517 .39349 L F
0 0 .222 r
.58452 .39553 m .58525 .39621 L .58517 .39349 L F
.58452 .39553 m .58477 .39789 L .58525 .39621 L F
.706 .912 .561 r
.39511 .54491 m .39261 .54831 L .39424 .54662 L F
0 0 .469 r
.29164 .52895 m .29072 .52554 L .28817 .5265 L F
.349 .733 .986 r
.30557 .58963 m .30816 .58959 L .30684 .5884 L F
.575 .233 .353 r
.28119 .64554 m .27891 .64337 L .27902 .64466 L F
.28119 .64554 m .27891 .64337 L .27902 .64466 L F
.965 .797 .362 r
.41886 .57181 m .41877 .57471 L .41976 .57379 L F
0 0 0 r
.41976 .57379 m .42118 .57287 L .42304 .57196 L F
.41976 .57379 m .41877 .57471 L .42118 .57287 L F
.847 .615 .588 r
.34964 .52959 m .34644 .53169 L .34673 .52885 L F
.34964 .52959 m .34915 .53239 L .34644 .53169 L F
0 .275 .78 r
.5861 .34973 m .58465 .34996 L .58328 .34876 L F
.5861 .34973 m .58687 .35167 L .58465 .34996 L F
.173 0 .234 r
.2734 .65025 m .2705 .65368 L .27242 .65196 L F
.324 .329 .711 r
.2705 .65368 m .27313 .65549 L .27242 .65196 L F
.053 .426 .868 r
.2705 .65368 m .27488 .65687 L .27313 .65549 L F
.856 .877 .854 r
.50074 .4955 m .50369 .49509 L .50338 .49237 L F
.839 .885 .875 r
.50512 .49074 m .50369 .49509 L .50676 .49212 L F
.50512 .49074 m .50338 .49237 L .50369 .49509 L F
.736 .682 .799 r
.57308 .39504 m .5709 .39799 L .56879 .3946 L F
.344 .553 .911 r
.5732 .3979 m .5709 .39799 L .57308 .39504 L F
.877 .619 .544 r
.37746 .52447 m .38116 .52554 L .38101 .52274 L F
.216 0 .02 r
.58107 .38226 m .58049 .38421 L .57764 .38489 L F
.602 .886 .991 r
.58107 .38226 m .58236 .38058 L .58355 .37896 L F
.58107 .38226 m .58154 .38109 L .58236 .38058 L F
.503 .832 .999 r
.57697 .38087 m .57826 .38011 L .58154 .38109 L F
.57577 .38081 m .57826 .38011 L .57697 .38087 L F
.314 .331 .719 r
.5804 .37724 m .58072 .37867 L .57826 .38011 L F
.602 .859 .992 r
.58154 .38109 m .57826 .38011 L .58236 .38058 L F
.5 0 0 r
.57826 .38011 m .5817 .38149 L .58236 .38058 L F
.58261 .38185 m .58145 .38197 L .58291 .38197 L F
.57826 .38011 m .58145 .38197 L .58261 .38185 L F
.314 .331 .719 r
.58072 .37867 m .58145 .38197 L .57826 .38011 L F
.5 0 0 r
.5817 .38149 m .58291 .38197 L .58236 .38058 L F
.602 .886 .991 r
.58355 .37896 m .58236 .38058 L .5837 .37876 L F
.708 .447 .529 r
.58236 .38058 m .58492 .37727 L .5837 .37876 L F
.047 0 0 r
.58291 .38197 m .58681 .38101 L .58236 .38058 L F
.564 .504 .747 r
.58375 .3806 m .58145 .38197 L .5804 .37724 L F
.924 .96 .644 r
.58178 .37877 m .58021 .38209 L .58145 .38197 L F
.58021 .38209 m .57998 .38258 L .58145 .38197 L F
.658 .195 .142 r
.5813 .38247 m .58352 .38452 L .58049 .38421 L F
.727 .745 .866 r
.58049 .38421 m .58352 .38452 L .58291 .38197 L F
0 0 0 r
.58291 .38197 m .58011 .38503 L .58049 .38421 L F
.58011 .38503 m .57934 .38587 L .58049 .38421 L F
.658 .195 .142 r
.58107 .38226 m .5813 .38247 L .58049 .38421 L F
.634 .469 .642 r
.52548 .43215 m .52832 .42885 L .52531 .42932 L F
.669 .974 .826 r
.63467 .35332 m .63614 .35142 L .63695 .35152 L F
.63467 .35332 m .63295 .35374 L .63614 .35142 L F
.873 .904 .849 r
.48425 .49643 m .48145 .49957 L .47987 .49829 L F
.859 .946 .873 r
.37997 .57766 m .37624 .57918 L .37825 .5757 L F
.37997 .57766 m .37652 .58057 L .37624 .57918 L F
.691 .861 .963 r
.38235 .57615 m .37997 .57766 L .37825 .5757 L F
.38235 .57615 m .37997 .57766 L .37825 .5757 L F
.572 .724 .945 r
.32333 .68752 m .32423 .68371 L .32107 .68325 L F
.32333 .68752 m .32633 .68702 L .32423 .68371 L F
.903 .861 .789 r
.29233 .64596 m .29168 .65063 L .28941 .64928 L F
.811 .578 .585 r
.6509 .3678 m .65568 .36908 L .655 .37159 L F
.544 .448 .697 r
.27492 .56571 m .27173 .56346 L .27305 .56159 L F
.27492 .56571 m .2724 .56628 L .27173 .56346 L F
.465 .281 .546 r
.25928 .55547 m .26195 .55831 L .26415 .55678 L F
.25928 .55547 m .2595 .559 L .26195 .55831 L F
.072 .065 .542 r
.57804 .35205 m .57989 .35372 L .57986 .34978 L F
.429 .53 .858 r
.51462 .43479 m .51328 .43914 L .51171 .43818 L F
.51461 .43482 m .51589 .43947 L .51328 .43914 L F
.51463 .43483 m .51589 .43947 L .51461 .43482 L F
.83 .785 .81 r
.51814 .43567 m .51589 .43947 L .51462 .43479 L F
.52 .42 .682 r
.51754 .43553 m .51451 .43813 L .51726 .43721 L F
.83 .785 .81 r
.51814 .43567 m .51462 .43479 L .51784 .43354 L F
.52 .42 .682 r
.51782 .43388 m .51669 .43533 L .51754 .43553 L F
.51669 .43533 m .51451 .43813 L .51754 .43553 L F
.429 .53 .858 r
.51462 .43479 m .51463 .43483 L .51461 .43482 L F
.223 .63 .955 r
.51451 .43813 m .51328 .43914 L .51171 .43818 L F
.51451 .43813 m .51589 .43947 L .51328 .43914 L F
.616 .557 .766 r
.55719 .33794 m .56019 .34026 L .55985 .33748 L F
.271 0 0 r
.40277 .47612 m .40104 .47762 L .39834 .47779 L F
.524 0 0 r
.40695 .47819 m .40503 .47735 L .40695 .47807 L F
.40503 .47735 m .40353 .47669 L .40491 .47725 L F
.40503 .47735 m .40491 .47725 L .40695 .47807 L F
.267 .76 .691 r
.40355 .47614 m .40104 .47762 L .40277 .47612 L F
.40516 .47618 m .40406 .47656 L .40355 .47614 L F
.40406 .47656 m .40104 .47762 L .40355 .47614 L F
.809 .57 .576 r
.31803 .52541 m .32032 .52875 L .32252 .52618 L F
.689 .869 .966 r
.31989 .62624 m .32417 .62679 L .32243 .62443 L F
.31989 .62624 m .32243 .62443 L .32214 .62445 L F
.476 .524 .827 r
.32302 .62523 m .32471 .62197 L .32243 .62443 L F
.32417 .62679 m .32437 .62495 L .32302 .62523 L F
.32437 .62495 m .32471 .62197 L .32302 .62523 L F
.838 .764 .78 r
.32139 .63029 m .32417 .62679 L .31989 .62624 L F
.153 0 .209 r
.32346 .62902 m .32417 .62679 L .32139 .63029 L F
.476 .524 .827 r
.32417 .62679 m .32683 .62686 L .32471 .62197 L F
.534 .015 0 r
.32547 .62809 m .32417 .62679 L .32346 .62902 L F
.731 .266 .146 r
.32114 .62563 m .32633 .62714 L .32439 .62763 L F
.32077 .6254 m .32136 .62559 L .32114 .62563 L F
.32136 .62559 m .32633 .62714 L .32114 .62563 L F
.783 .603 .657 r
.32471 .62197 m .32488 .62253 L .32184 .62447 L F
.32488 .62253 m .32541 .62423 L .32214 .62445 L F
.32488 .62253 m .32214 .62445 L .32184 .62447 L F
.521 .886 .674 r
.32077 .6254 m .31989 .62624 L .32214 .62445 L F
.783 .603 .657 r
.32184 .62447 m .3222 .62468 L .32077 .6254 L F
.32541 .62423 m .32633 .62714 L .32184 .62447 L F
.521 .886 .674 r
.32077 .6254 m .32214 .62445 L .32233 .62429 L F
.476 .524 .827 r
.32243 .62443 m .32471 .62197 L .32233 .62429 L F
.783 .603 .657 r
.3222 .62468 m .32633 .62714 L .32136 .62559 L F
.3222 .62468 m .32136 .62559 L .32077 .6254 L F
.689 .869 .966 r
.32214 .62445 m .32243 .62443 L .32233 .62429 L F
.636 .437 .597 r
.5076 .40045 m .50337 .40612 L .50446 .40161 L F
.194 .321 .766 r
.50338 .40614 m .50311 .40902 L .50163 .40481 L F
.636 .437 .597 r
.5076 .40045 m .50416 .4053 L .50337 .40612 L F
.50416 .4053 m .50348 .40626 L .50338 .40614 L F
.50416 .4053 m .50338 .40614 L .50337 .40612 L F
.194 .321 .766 r
.50338 .40614 m .50338 .40614 L .50338 .40614 L F
.50338 .40614 m .50311 .40902 L .50338 .40614 L F
.636 .437 .597 r
.50337 .40612 m .50348 .40626 L .50327 .40625 L F
.194 .321 .766 r
.50445 .40695 m .50434 .40712 L .50338 .40614 L F
.538 .303 .506 r
.50327 .40625 m .50445 .40695 L .50338 .40614 L F
.50327 .40625 m .50338 .40614 L .50163 .40481 L F
.636 .437 .597 r
.5076 .40045 m .50772 .40638 L .50348 .40626 L F
.50337 .40612 m .50327 .40625 L .50332 .40607 L F
.50337 .40612 m .50332 .40607 L .50446 .40161 L F
.39 .763 .992 r
.50354 .40622 m .50772 .40638 L .50704 .40585 L F
.194 .321 .766 r
.50349 .40625 m .50337 .40633 L .50338 .40614 L F
.39 .763 .992 r
.50327 .40625 m .50348 .40626 L .50354 .40622 L F
.50348 .40626 m .50772 .40638 L .50354 .40622 L F
.194 .321 .766 r
.50434 .40712 m .50311 .40902 L .50337 .40633 L F
.50434 .40712 m .50337 .40633 L .50349 .40625 L F
.575 .565 .805 r
.50445 .40695 m .50317 .4118 L .50311 .40902 L F
.783 .886 .92 r
.53664 .38562 m .53328 .38866 L .53127 .38635 L F
0 0 .075 r
.40511 .54988 m .40371 .55232 L .40426 .54937 L F
.739 .722 .194 r
.5796 .35884 m .57953 .35857 L .58014 .35638 L F
.5796 .35884 m .57899 .36151 L .57953 .35857 L F
.912 .973 .682 r
.55592 .42583 m .55816 .42198 L .55731 .42159 L F
.861 .985 .847 r
.5589 .41887 m .55816 .42198 L .56114 .41844 L F
.886 .986 .721 r
.55731 .42159 m .55816 .42198 L .5589 .41887 L F
.902 .712 .637 r
.36083 .56659 m .36016 .56936 L .35838 .56545 L F
.873 .904 .849 r
.48425 .49643 m .47987 .49829 L .48232 .4948 L F
.851 .851 .842 r
.48704 .49304 m .48425 .49643 L .48232 .4948 L F
.765 .841 .909 r
.32548 .61441 m .32057 .61558 L .32376 .61307 L F
.754 .803 .892 r
.32596 .61116 m .32548 .61441 L .32376 .61307 L F
.32596 .61116 m .32768 .61288 L .32548 .61441 L F
.663 .772 .931 r
.3669 .57181 m .36864 .57369 L .37136 .57197 L F
.782 .975 .914 r
.53534 .39682 m .53895 .39593 L .5382 .39496 L F
.606 .105 .035 r
.3869 .57715 m .38443 .57797 L .38235 .57615 L F
.829 .847 .385 r
.38545 .5733 m .38438 .57714 L .38517 .57515 L F
.38438 .57714 m .38412 .57808 L .38433 .57751 L F
.38438 .57714 m .38433 .57751 L .38517 .57515 L F
0 .163 .682 r
.38235 .57615 m .38428 .57783 L .38335 .57963 L F
.38428 .57783 m .38443 .57797 L .3842 .57834 L F
.38428 .57783 m .3842 .57834 L .38335 .57963 L F
.618 .856 .49 r
.38443 .57797 m .38175 .58147 L .38335 .57963 L F
.533 .105 .174 r
.27582 .6523 m .2734 .65025 L .27242 .65196 L F
.34 .733 .984 r
.27612 .65039 m .2734 .65025 L .27582 .6523 L F
0 .327 .809 r
.32064 .63831 m .32075 .63982 L .31911 .63763 L F
.873 .99 .819 r
.3523 .65689 m .35489 .65373 L .35156 .65535 L F
0 0 0 r
.40567 .46626 m .4043 .46645 L .40264 .46833 L F
.40567 .46626 m .40661 .46526 L .4043 .46645 L F
.692 .481 .596 r
.36344 .5223 m .36782 .52256 L .36642 .51891 L F
.682 .476 .601 r
.36642 .51891 m .37027 .5222 L .36867 .5182 L F
.36642 .51891 m .36782 .52256 L .37027 .5222 L F
.811 .562 .563 r
.37308 .51605 m .37658 .51938 L .37564 .5154 L F
.37308 .51605 m .37291 .51886 L .37658 .51938 L F
.807 .67 .713 r
.37291 .51886 m .37422 .5229 L .37658 .51938 L F
.567 .929 .774 r
.35593 .64315 m .35124 .64577 L .35376 .64513 L F
.985 .774 .539 r
.35422 .64208 m .35593 .64315 L .35376 .64513 L F
.616 .557 .766 r
.55719 .33794 m .55854 .34267 L .56136 .34124 L F
.119 0 0 r
.33415 .63877 m .33188 .63941 L .3299 .63944 L F
.303 0 0 r
.33608 .63916 m .33188 .63941 L .33415 .63877 L F
.684 .386 .463 r
.3509 .51511 m .35527 .5123 L .35109 .51218 L F
.3509 .51511 m .35506 .51528 L .35527 .5123 L F
.62 .331 .457 r
.35506 .51528 m .35773 .51518 L .35527 .5123 L F
.746 .266 .103 r
.5635 .37503 m .56056 .37431 L .56126 .37375 L F
.514 .11 .213 r
.30816 .58959 m .31127 .58814 L .30969 .59008 L F
.484 .041 .12 r
.31127 .58814 m .31377 .58831 L .31288 .5878 L F
.882 .592 .493 r
.31127 .58814 m .31229 .59265 L .30969 .59008 L F
0 0 0 r
.30969 .59008 m .31127 .58814 L .31288 .5878 L F
.557 .659 .905 r
.51284 .46069 m .51508 .46286 L .51106 .4613 L F
.725 .697 .823 r
.51694 .46136 m .51508 .46286 L .51284 .46069 L F
.557 .659 .905 r
.51284 .46069 m .51106 .4613 L .51036 .46003 L F
.692 .313 .325 r
.5115 .40385 m .51456 .40292 L .51308 .40067 L F
.5115 .40385 m .51535 .40459 L .51456 .40292 L F
.217 .334 .769 r
.41094 .59407 m .41221 .59166 L .40981 .59188 L F
.41094 .59407 m .41282 .59362 L .41221 .59166 L F
.86 .599 .542 r
.3468 .52613 m .34299 .52786 L .34315 .52518 L F
.3468 .52613 m .34673 .52885 L .34299 .52786 L F
.984 .904 .601 r
.49815 .46877 m .4981 .46513 L .49938 .46658 L F
.909 .782 .708 r
.51808 .41941 m .51988 .42219 L .51733 .42209 L F
.548 0 0 r
.51733 .42209 m .51988 .42219 L .51797 .42279 L F
.433 .707 .98 r
.51988 .42219 m .52108 .42017 L .51797 .42279 L F
.51988 .42219 m .52294 .42224 L .52108 .42017 L F
.771 .304 .137 r
.31004 .53306 m .30613 .53162 L .30765 .53236 L F
.883 .457 .17 r
.39086 .5443 m .39266 .54364 L .38901 .54187 L F
.39086 .5443 m .39389 .54639 L .39266 .54364 L F
.969 .649 .332 r
.35678 .64011 m .35856 .63981 L .35619 .6394 L F
.35678 .64011 m .3592 .64312 L .35856 .63981 L F
.59 .819 .987 r
.39704 .59178 m .4004 .59195 L .39745 .59091 L F
0 .56 .807 r
.4029 .59187 m .39745 .59091 L .4004 .59195 L F
0 0 0 r
.28452 .54559 m .28272 .55012 L .28242 .54635 L F
.28452 .54559 m .28341 .54867 L .28272 .55012 L F
.091 .38 .842 r
.28341 .54867 m .28583 .55229 L .28272 .55012 L F
.963 .709 .503 r
.29114 .67606 m .29338 .67678 L .29316 .67927 L F
.653 .536 .708 r
.50421 .47895 m .50003 .47545 L .50433 .47652 L F
.50421 .47895 m .50157 .47939 L .50003 .47545 L F
.554 .866 .996 r
.27488 .65687 m .27744 .65616 L .27557 .65519 L F
.434 .742 .992 r
.27313 .65549 m .27488 .65687 L .27557 .65519 L F
.456 .503 .819 r
.27488 .65687 m .27841 .66047 L .27744 .65616 L F
.425 .743 .993 r
.29544 .63898 m .29615 .63717 L .29336 .63801 L F
.29544 .63898 m .29811 .63872 L .29615 .63717 L F
.711 .926 .963 r
.30648 .62439 m .30144 .62528 L .30438 .62263 L F
.746 .866 .935 r
.30848 .62267 m .30648 .62439 L .30438 .62263 L F
.562 .574 .824 r
.29487 .52883 m .29235 .52954 L .29072 .52554 L F
.29487 .52883 m .29235 .52954 L .29072 .52554 L F
.966 .912 .56 r
.29184 .5282 m .29235 .52954 L .29487 .52883 L F
.637 .224 .243 r
.29164 .52895 m .28701 .53115 L .29076 .53116 L F
.29164 .52895 m .29076 .53116 L .29184 .5282 L F
.966 .912 .56 r
.29184 .5282 m .29076 .53116 L .29235 .52954 L F
.567 .376 .583 r
.3843 .53583 m .38191 .53596 L .38284 .53795 L F
.669 .191 .108 r
.38284 .53795 m .3868 .5382 L .3843 .53583 L F
.591 .232 .328 r
.3843 .53583 m .3868 .5382 L .38723 .5362 L F
.876 .836 .802 r
.45409 .54156 m .45842 .53949 L .45737 .53864 L F
.45409 .54156 m .45579 .54305 L .45842 .53949 L F
.933 .962 .76 r
.45948 .53509 m .45842 .53949 L .46033 .53695 L F
.45948 .53509 m .45737 .53864 L .45842 .53949 L F
.286 .102 .447 r
.28463 .54267 m .28452 .54559 L .28242 .54635 L F
.394 .373 .717 r
.59139 .34908 m .59196 .35208 L .5935 .35108 L F
.181 0 .374 r
.59196 .35208 m .59167 .35456 L .5935 .35108 L F
.809 .969 .659 r
.35743 .65022 m .35535 .65191 L .35489 .65373 L F
.978 .918 .628 r
.35668 .64717 m .35535 .65191 L .35743 .65022 L F
.825 .505 .447 r
.31379 .52214 m .31803 .52541 L .31805 .52273 L F
.936 .823 .708 r
.32743 .5568 m .33007 .55645 L .32788 .55527 L F
.32743 .5568 m .32924 .55872 L .33007 .55645 L F
.843 .964 .883 r
.65817 .38262 m .65895 .3795 L .65677 .38133 L F
.65817 .38262 m .66111 .37981 L .65895 .3795 L F
.773 .676 .757 r
.65201 .35561 m .64941 .35885 L .648 .35496 L F
.658 .429 .56 r
.36867 .5182 m .37291 .51886 L .37308 .51605 L F
.732 .567 .668 r
.50666 .47558 m .50421 .47895 L .50433 .47652 L F
.064 .404 .858 r
.33266 .60828 m .33298 .60867 L .33255 .61007 L F
.758 .815 .898 r
.33438 .61055 m .33238 .61065 L .33255 .61007 L F
.214 0 0 r
.33523 .61144 m .33438 .61055 L .33255 .61007 L F
.33523 .61144 m .33685 .61039 L .33438 .61055 L F
.064 .404 .858 r
.33298 .60867 m .33523 .61144 L .33255 .61007 L F
.758 .815 .898 r
.33238 .61065 m .33077 .61073 L .33255 .61007 L F
.919 .81 .723 r
.52791 .44566 m .52431 .44779 L .52738 .44436 L F
.52791 .44566 m .52625 .44939 L .52431 .44779 L F
.856 .804 .315 r
.52865 .44003 m .52791 .44566 L .52738 .44436 L F
.487 .871 .973 r
.25372 .57945 m .25513 .57808 L .25606 .57556 L F
.25372 .57945 m .25277 .5789 L .25513 .57808 L F
.76 .965 .931 r
.49356 .47019 m .49713 .46775 L .49815 .46877 L F
.984 .904 .601 r
.49815 .46877 m .49713 .46775 L .4981 .46513 L F
.817 .697 .733 r
.64941 .35885 m .6458 .35831 L .648 .35496 L F
.785 .814 .875 r
.64906 .36134 m .6458 .35831 L .64941 .35885 L F
.162 .247 .705 r
.59278 .39333 m .59362 .39745 L .59122 .39532 L F
.895 .901 .824 r
.5184 .45518 m .51674 .4554 L .51901 .45204 L F
.851 .667 .652 r
.5184 .45518 m .51579 .45803 L .51674 .4554 L F
.5184 .45518 m .51828 .45961 L .51579 .45803 L F
.758 .608 .691 r
.64906 .36134 m .65093 .36551 L .64668 .36501 L F
.753 .478 .515 r
.65093 .36551 m .64552 .36922 L .64668 .36501 L F
.65093 .36551 m .6509 .3678 L .64552 .36922 L F
.363 .123 .41 r
.2724 .56628 m .27196 .5689 L .26969 .56949 L F
.2724 .56628 m .27196 .5689 L .26969 .56949 L F
.768 .845 .91 r
.31873 .6172 m .31552 .61981 L .31354 .61847 L F
.821 .635 .652 r
.49245 .47868 m .49462 .48238 L .49075 .48189 L F
.841 .929 .888 r
.64867 .39125 m .65273 .38961 L .65129 .38793 L F
.896 .628 .523 r
.35792 .54596 m .35469 .54514 L .35489 .54231 L F
.915 .673 .557 r
.35768 .5488 m .35469 .54514 L .35792 .54596 L F
.028 .574 .838 r
.63189 .39301 m .63464 .39325 L .63353 .39277 L F
.899 .898 .817 r
.48601 .50857 m .48898 .5083 L .48849 .50571 L F
.48601 .50857 m .48755 .50984 L .48898 .5083 L F
.855 .922 .873 r
.48849 .50571 m .48898 .5083 L .49153 .50499 L F
.69 .752 .253 r
.58566 .39222 m .58517 .39349 L .58551 .39085 L F
.957 .673 .456 r
.66902 .35007 m .67088 .34864 L .66753 .34711 L F
.66902 .35007 m .67096 .35137 L .67088 .34864 L F
.987 .791 .554 r
.32588 .65004 m .32505 .65247 L .32358 .65173 L F
.789 .539 0 r
.5802 .3681 m .57983 .36706 L .5799 .36611 L F
.185 .272 .721 r
.57899 .36151 m .5799 .36611 L .58036 .36372 L F
0 0 0 r
.5799 .36611 m .57983 .36706 L .58036 .36372 L F
.857 .605 .557 r
.5635 .37503 m .56183 .37792 L .56056 .37431 L F
.9 .682 .598 r
.40976 .476 m .40695 .47807 L .40516 .47618 L F
.713 .675 .811 r
.57693 .41637 m .578 .41903 L .57464 .41851 L F
.292 0 0 r
.57464 .41851 m .578 .41903 L .57664 .41916 L F
.718 .381 0 r
.57748 .41809 m .578 .41903 L .57693 .41637 L F
.785 .998 .811 r
.57664 .41916 m .578 .41903 L .57748 .41809 L F
.809 .844 .876 r
.51756 .48124 m .52225 .47952 L .52049 .47792 L F
.776 .832 .896 r
.52049 .47792 m .52225 .47952 L .52468 .47805 L F
.155 0 0 r
.47856 .42808 m .47478 .43111 L .47605 .4289 L F
.899 .808 .749 r
.32686 .56537 m .32797 .56871 L .32887 .56653 L F
.957 .931 .726 r
.55346 .42657 m .55502 .42806 L .55592 .42583 L F
.931 .947 .78 r
.55267 .43132 m .55502 .42806 L .55346 .42657 L F
0 .001 .565 r
.31718 .63585 m .31825 .63726 L .31763 .63596 L F
.988 .897 .606 r
.31763 .63596 m .31825 .63726 L .31633 .63784 L F
0 0 0 r
.31795 .63604 m .31763 .63596 L .31633 .63784 L F
.31918 .63468 m .31763 .63596 L .31795 .63604 L F
0 .001 .565 r
.31663 .63512 m .31718 .63585 L .31763 .63596 L F
.599 .898 .614 r
.55691 .39924 m .55468 .40143 L .55548 .40028 L F
.69 .931 .624 r
.55691 .39924 m .55548 .40028 L .55684 .39839 L F
0 0 0 r
.55548 .40028 m .5565 .40065 L .55642 .39891 L F
.774 .997 .841 r
.55684 .39839 m .55548 .40028 L .55638 .39793 L F
0 0 0 r
.55548 .40028 m .55642 .39891 L .55638 .39793 L F
.599 .898 .614 r
.55468 .40143 m .55391 .40219 L .55548 .40028 L F
.617 .928 .687 r
.55548 .40028 m .55391 .40219 L .55231 .40305 L F
.409 .839 .952 r
.37756 .53977 m .38137 .53958 L .37974 .53916 L F
.109 .299 .774 r
.38137 .53958 m .38284 .53795 L .37974 .53916 L F
.38137 .53958 m .38405 .54164 L .38284 .53795 L F
.403 .315 .641 r
.38137 .53958 m .38207 .54265 L .38405 .54164 L F
.465 .21 .442 r
.27459 .56833 m .2724 .56628 L .27492 .56571 L F
.27459 .56833 m .27196 .5689 L .2724 .56628 L F
.414 .538 .873 r
.61865 .39493 m .62022 .39306 L .61748 .39413 L F
.61865 .39493 m .62124 .39474 L .62022 .39306 L F
0 0 .451 r
.53694 .42337 m .53793 .42633 L .53863 .427 L F
.354 .257 .604 r
.25776 .56221 m .25981 .56183 L .2595 .559 L F
.366 .822 .714 r
.41866 .56593 m .42043 .56494 L .4228 .56404 L F
.98 .877 .656 r
.4228 .56404 m .42148 .56218 L .42456 .56243 L F
.4228 .56404 m .42043 .56494 L .42148 .56218 L F
.87 .878 .84 r
.48198 .51384 m .48028 .51547 L .48365 .5151 L F
.875 .868 .828 r
.48028 .51547 m .48198 .51684 L .48365 .5151 L F
.87 .878 .84 r
.48198 .51384 m .48365 .5151 L .48623 .51171 L F
.641 .846 .979 r
.5944 .34842 m .59139 .34908 L .59293 .34697 L F
.747 .32 .237 r
.59139 .34908 m .5935 .35108 L .59023 .35016 L F
.62 .383 .537 r
.59139 .34908 m .5935 .35108 L .5944 .34842 L F
.4 .823 .967 r
.60319 .39392 m .60738 .394 L .60455 .39458 L F
.771 .304 .137 r
.31004 .53306 m .3081 .53429 L .30613 .53162 L F
.742 .264 .108 r
.31004 .53306 m .31181 .53517 L .3081 .53429 L F
.75 .245 .015 r
.31419 .53586 m .31181 .53517 L .31004 .53306 L F
.787 .999 .825 r
.35489 .65373 m .35535 .65191 L .35156 .65535 L F
.458 .59 .897 r
.51205 .45741 m .51036 .46003 L .50934 .45861 L F
.51205 .45741 m .51284 .46069 L .51036 .46003 L F
.785 .814 .875 r
.64906 .36134 m .64713 .36249 L .64529 .36095 L F
.868 .79 .295 r
.64713 .36249 m .64648 .36298 L .64529 .36095 L F
.64713 .36249 m .64668 .36501 L .64648 .36298 L F
.758 .608 .691 r
.64906 .36134 m .64668 .36501 L .64713 .36249 L F
.033 0 0 r
.4881 .42163 m .49165 .41904 L .49049 .4205 L F
.051 0 0 r
.4937 .41797 m .49049 .4205 L .49165 .41904 L F
.582 .524 .756 r
.52981 .4052 m .52683 .40611 L .52614 .40318 L F
.52981 .4052 m .52614 .40318 L .52798 .40227 L F
.154 .27 .732 r
.52683 .40611 m .52755 .40323 L .52526 .40437 L F
.405 .093 .32 r
.52981 .4052 m .52919 .40725 L .52683 .40611 L F
.154 .27 .732 r
.52683 .40611 m .52919 .40725 L .52755 .40323 L F
.863 .47 .294 r
.66339 .34378 m .66568 .34723 L .66693 .3453 L F
.753 .32 .222 r
.66693 .3453 m .66568 .34723 L .66753 .34711 L F
.198 .253 .695 r
.3325 .64213 m .33066 .64395 L .3299 .63944 L F
.295 .409 .809 r
.3325 .64213 m .33374 .64554 L .33066 .64395 L F
.769 .934 .938 r
.64185 .39177 m .63677 .39221 L .63997 .39292 L F
.762 .491 .523 r
.42591 .56624 m .42493 .56882 L .42154 .56851 L F
0 0 0 r
.32346 .62902 m .32139 .63029 L .31966 .63197 L F
.43772 .44556 m .4341 .44847 L .43609 .44699 L F
.43965 .44445 m .43772 .44556 L .43609 .44699 L F
.228 .259 .686 r
.28317 .66611 m .28411 .6729 L .2856 .66847 L F
0 0 .316 r
.2856 .66847 m .28411 .6729 L .28442 .67409 L F
0 0 0 r
.41559 .46057 m .41658 .45953 L .4132 .46184 L F
.035 0 0 r
.41801 .45966 m .41658 .45953 L .41559 .46057 L F
.41801 .45966 m .41892 .45843 L .41658 .45953 L F
.785 .814 .875 r
.64906 .36134 m .64529 .36095 L .6458 .35831 L F
.864 .88 .847 r
.50512 .49074 m .50676 .49212 L .50962 .48884 L F
.851 .851 .842 r
.48704 .49304 m .48232 .4948 L .48544 .49176 L F
.907 .904 .809 r
.48947 .48939 m .48704 .49304 L .48544 .49176 L F
.853 .782 .781 r
.31945 .54808 m .31836 .55179 L .3154 .54813 L F
.056 0 0 r
.3939 .53229 m .3957 .53256 L .39646 .5311 L F
0 0 0 r
.3934 .53431 m .3957 .53256 L .3939 .53229 L F
.827 .712 .738 r
.29404 .55597 m .28957 .55521 L .29228 .55211 L F
0 0 0 r
.29259 .55487 m .29282 .5554 L .29231 .5531 L F
.29269 .55553 m .29282 .5554 L .29259 .55487 L F
.104 .639 .861 r
.29299 .55579 m .29282 .5554 L .28957 .55521 L F
.29404 .55597 m .29282 .5554 L .29299 .55579 L F
.763 .398 0 r
.29231 .5531 m .29404 .55597 L .29228 .55211 L F
.989 .873 .526 r
.29231 .5531 m .29282 .5554 L .29404 .55597 L F
.746 .468 .51 r
.50836 .40632 m .5115 .40385 L .50883 .40494 L F
.668 .499 .647 r
.5039 .48098 m .50157 .47939 L .50421 .47895 L F
.5039 .48098 m .50158 .48266 L .50157 .47939 L F
0 0 0 r
.41866 .56593 m .41711 .56705 L .42043 .56494 L F
.899 .808 .749 r
.32686 .56537 m .32469 .56868 L .32797 .56871 L F
.911 .764 .687 r
.32401 .57156 m .32797 .56871 L .32469 .56868 L F
.32401 .57156 m .32645 .57297 L .32797 .56871 L F
.739 .699 .812 r
.58518 .40779 m .58653 .41133 L .5876 .4091 L F
.877 .652 .592 r
.4337 .50576 m .42941 .50818 L .43159 .50446 L F
.4337 .50576 m .43312 .50893 L .42941 .50818 L F
.475 .809 .999 r
.43159 .50446 m .43582 .50501 L .4337 .50576 L F
.397 .221 .523 r
.43582 .50501 m .43312 .50893 L .4337 .50576 L F
.862 .758 .746 r
.48833 .48594 m .48947 .48939 L .48723 .48798 L F
.907 .904 .809 r
.48947 .48939 m .48544 .49176 L .48723 .48798 L F
.73 .747 .866 r
.39116 .59136 m .39342 .59313 L .39704 .59178 L F
.278 0 .144 r
.57399 .37341 m .5721 .37261 L .57425 .37131 L F
.57399 .37341 m .57133 .37428 L .5721 .37261 L F
.866 .864 .835 r
.47761 .51875 m .47941 .52006 L .48198 .51684 L F
.954 .755 .596 r
.35773 .51518 m .3593 .51895 L .35966 .51605 L F
.478 .851 .987 r
.63695 .35152 m .63883 .35005 L .63975 .35082 L F
.497 .905 .828 r
.63695 .35152 m .63614 .35142 L .63883 .35005 L F
.957 .931 .726 r
.55346 .42657 m .55592 .42583 L .55487 .42476 L F
.912 .973 .682 r
.55592 .42583 m .55731 .42159 L .55487 .42476 L F
.855 .916 .872 r
.44829 .53877 m .44673 .54023 L .4503 .53594 L F
.884 .681 .623 r
.35941 .5527 m .35622 .55195 L .35768 .5488 L F
.894 .676 .6 r
.35909 .55525 m .35622 .55195 L .35941 .5527 L F
0 0 .485 r
.38337 .55536 m .38208 .5537 L .38221 .55145 L F
.598 .943 .783 r
.53455 .4339 m .53331 .43521 L .53312 .43554 L F
.719 .487 .574 r
.57961 .3479 m .58328 .34876 L .58336 .34523 L F
.762 .621 .704 r
.50523 .41515 m .50613 .41127 L .50612 .41124 L F
.466 .826 .995 r
.31045 .54955 m .30875 .54856 L .30612 .54919 L F
.419 .732 .991 r
.31045 .54955 m .31161 .5477 L .30875 .54856 L F
.691 .697 .165 r
.31045 .54955 m .3096 .55316 L .31027 .55028 L F
.089 .146 .628 r
.38122 .55817 m .38171 .56166 L .37977 .5591 L F
.09 0 .402 r
.59876 .37374 m .59717 .37677 L .59669 .37569 L F
.703 .592 .729 r
.3063 .56334 m .3025 .56256 L .30378 .5608 L F
.513 .552 .833 r
.30715 .55871 m .30378 .5608 L .3063 .56334 L F
.849 .438 .256 r
.37955 .48283 m .37823 .48448 L .37638 .48142 L F
0 0 0 r
.38027 .48331 m .37955 .48283 L .38223 .48235 L F
.38027 .48331 m .37823 .48448 L .37955 .48283 L F
.707 .871 .466 r
.5599 .39574 m .56012 .39469 L .56094 .39307 L F
.83 .999 .828 r
.44866 .54566 m .4487 .54879 L .45176 .54559 L F
.44866 .54566 m .44755 .54779 L .4487 .54879 L F
.728 .696 .82 r
.4487 .54879 m .45357 .54688 L .45176 .54559 L F
.49 .881 .962 r
.4487 .54879 m .44755 .54779 L .44675 .54891 L F
.883 .967 .841 r
.43742 .54792 m .44139 .54562 L .43935 .54929 L F
.43742 .54792 m .44024 .54452 L .44139 .54562 L F
0 0 0 r
.44024 .54452 m .44396 .54126 L .44139 .54562 L F
.659 .696 .873 r
.30387 .67999 m .30764 .68111 L .30663 .67918 L F
.176 .538 .925 r
.30764 .68111 m .30975 .68086 L .30663 .67918 L F
.30764 .68111 m .31123 .68241 L .30975 .68086 L F
.394 .188 .478 r
.38554 .5542 m .38221 .55145 L .38711 .5522 L F
.38554 .5542 m .38337 .55536 L .38221 .55145 L F
.749 .785 .882 r
.42425 .57963 m .42906 .57986 L .42407 .57804 L F
.593 .827 .988 r
.42407 .57804 m .42906 .57986 L .42931 .57761 L F
.785 .754 .824 r
.52317 .45245 m .51901 .45204 L .52106 .45078 L F
.787 .753 .822 r
.52625 .44939 m .52317 .45245 L .52106 .45078 L F
.057 0 0 r
.44563 .45173 m .44418 .4533 L .44151 .45415 L F
0 0 0 r
.44931 .44928 m .44752 .4506 L .44563 .45173 L F
.44563 .45173 m .44752 .4506 L .44418 .4533 L F
.769 .573 .632 r
.37794 .57095 m .37405 .57271 L .3737 .56922 L F
.37794 .57095 m .3771 .573 L .37405 .57271 L F
.975 .891 .677 r
.52945 .39434 m .52918 .39039 L .52734 .39205 L F
.528 .908 .75 r
.52241 .40195 m .52415 .40036 L .52524 .40133 L F
.52241 .40195 m .52043 .40266 L .52415 .40036 L F
.61 .639 .854 r
.52614 .40318 m .52241 .40195 L .52524 .40133 L F
.534 .843 .999 r
.62986 .34001 m .634 .34026 L .63117 .34086 L F
.964 .938 .644 r
.37652 .58057 m .37489 .58154 L .37624 .57918 L F
.624 .11 .004 r
.37865 .58189 m .37489 .58154 L .37652 .58057 L F
.776 .832 .896 r
.52049 .47792 m .52468 .47805 L .52372 .47515 L F
.85 .881 .861 r
.52372 .47515 m .52468 .47805 L .52734 .47485 L F
.758 .569 .641 r
.31736 .56606 m .31339 .56584 L .31332 .56275 L F
.779 .519 .542 r
.31645 .56828 m .31339 .56584 L .31736 .56606 L F
.518 0 0 r
.61629 .35144 m .61538 .35234 L .61455 .3515 L F
.343 0 0 r
.61924 .35162 m .61538 .35234 L .61629 .35144 L F
0 0 0 r
.44931 .44928 m .45218 .44619 L .45098 .44753 L F
.44947 .44921 m .44931 .44928 L .45098 .44753 L F
.44947 .44921 m .44752 .4506 L .44931 .44928 L F
.691 .981 .859 r
.66111 .37981 m .66281 .37756 L .65895 .3795 L F
.66111 .37981 m .66328 .3781 L .66281 .37756 L F
.864 .88 .847 r
.50512 .49074 m .50962 .48884 L .50802 .48753 L F
.844 .931 .885 r
.50962 .48884 m .51113 .48464 L .50802 .48753 L F
.50962 .48884 m .5126 .48567 L .51113 .48464 L F
.964 .936 .696 r
.49892 .45887 m .49807 .45753 L .49956 .45561 L F
.848 .679 .143 r
.49832 .46162 m .49807 .45753 L .49892 .45887 L F
.99 .848 .605 r
.32743 .5568 m .32755 .56253 L .32924 .55872 L F
0 0 .387 r
.60224 .36036 m .60095 .36496 L .6041 .36169 L F
.60224 .36036 m .60253 .36291 L .60095 .36496 L F
.133 .142 .602 r
.60253 .36291 m .60145 .36774 L .60095 .36496 L F
.424 .835 .971 r
.61309 .34303 m .61549 .34246 L .61788 .34334 L F
.248 .757 .866 r
.61549 .34246 m .62076 .34229 L .61788 .34334 L F
0 .217 .74 r
.53714 .41485 m .53849 .41621 L .53729 .41379 L F
.53714 .41485 m .53729 .41379 L .53809 .41579 L F
.832 .532 .482 r
.31838 .55614 m .31488 .55839 L .31424 .55571 L F
.31838 .55614 m .31852 .55874 L .31488 .55839 L F
0 .211 .726 r
.51052 .45065 m .51033 .45272 L .50809 .44812 L F
.957 .813 .66 r
.5078 .4541 m .51033 .45272 L .51052 .45065 L F
.5078 .4541 m .50946 .45538 L .51033 .45272 L F
.773 .991 .77 r
.42292 .57801 m .4217 .58037 L .42425 .57963 L F
.42292 .57801 m .41989 .58113 L .4217 .58037 L F
0 0 0 r
.45098 .44753 m .45218 .44619 L .45401 .44439 L F
.752 .991 .884 r
.63034 .38255 m .63219 .38223 L .63221 .38107 L F
.072 .423 .868 r
.63221 .38107 m .63219 .38223 L .63352 .3815 L F
.538 .348 .57 r
.63034 .38255 m .6323 .38382 L .63221 .38107 L F
0 0 .019 r
.63219 .38223 m .63228 .38355 L .63355 .38148 L F
.63228 .38355 m .6323 .38382 L .63346 .38164 L F
.63228 .38355 m .63346 .38164 L .63355 .38148 L F
.342 .198 .536 r
.63221 .38107 m .6323 .38382 L .6335 .38157 L F
.182 .657 .933 r
.63428 .38102 m .63397 .38184 L .63221 .38107 L F
.411 .076 .284 r
.63359 .38152 m .63221 .38107 L .63351 .38158 L F
.63428 .38102 m .63221 .38107 L .63359 .38152 L F
.072 .423 .868 r
.63221 .38107 m .63352 .3815 L .63355 .38148 L F
.342 .198 .536 r
.63221 .38107 m .6335 .38157 L .63355 .38148 L F
.411 .076 .284 r
.63351 .38158 m .63221 .38107 L .63146 .38305 L F
.6339 .38093 m .63146 .38305 L .63247 .3806 L F
.63428 .38102 m .6335 .38159 L .6339 .38093 L F
.6335 .38159 m .63146 .38305 L .6339 .38093 L F
.866 .864 .835 r
.47761 .51875 m .48198 .51684 L .48028 .51547 L F
.698 .886 .967 r
.6246 .34239 m .62586 .33953 L .62715 .34086 L F
.6246 .34239 m .62322 .34096 L .62586 .33953 L F
0 0 0 r
.33998 .63924 m .33802 .64381 L .33895 .64198 L F
.575 .938 .914 r
.34125 .63759 m .33868 .63897 L .33998 .63924 L F
0 0 0 r
.33998 .63924 m .33895 .64198 L .34083 .63889 L F
.725 .697 .823 r
.51694 .46136 m .51284 .46069 L .51579 .45803 L F
.775 .716 .797 r
.51828 .45961 m .51694 .46136 L .51579 .45803 L F
.47 0 0 r
.32941 .63641 m .32516 .63612 L .32766 .63544 L F
.727 .628 .747 r
.33155 .63263 m .32941 .63641 L .32829 .63327 L F
.979 .708 .443 r
.32829 .63327 m .32921 .63587 L .32766 .63544 L F
.754 .987 .764 r
.32516 .63612 m .32829 .63327 L .32766 .63544 L F
.297 .773 .928 r
.32616 .63503 m .32766 .63544 L .32849 .63501 L F
.32548 .63504 m .32766 .63544 L .32616 .63503 L F
.979 .708 .443 r
.32921 .63587 m .32941 .63641 L .32766 .63544 L F
.816 .73 .77 r
.31332 .56275 m .30916 .56264 L .31155 .5614 L F
.31332 .56275 m .31052 .56543 L .30916 .56264 L F
.697 .52 .644 r
.31332 .56275 m .31339 .56584 L .31052 .56543 L F
.668 .849 .969 r
.31526 .56164 m .31332 .56275 L .31155 .5614 L F
.844 .999 .794 r
.40599 .58986 m .40437 .59159 L .4055 .59214 L F
.053 .601 .837 r
.40624 .5925 m .4055 .59214 L .4029 .59187 L F
.055 .602 .839 r
.4029 .59187 m .4055 .59214 L .40094 .59135 L F
0 .56 .807 r
.40021 .5914 m .40094 .59135 L .39745 .59091 L F
.4029 .59187 m .40094 .59135 L .40021 .5914 L F
.713 .282 .224 r
.4055 .59214 m .4022 .59391 L .40211 .59155 L F
0 0 .48 r
.40094 .59135 m .4022 .59391 L .4021 .59128 L F
.40094 .59135 m .4021 .59128 L .40203 .58943 L F
.844 .999 .794 r
.40437 .59159 m .4022 .59391 L .4055 .59214 L F
.053 .601 .837 r
.40699 .59264 m .4055 .59214 L .40624 .5925 L F
.553 .888 .986 r
.40981 .59188 m .40788 .59099 L .40699 .59264 L F
.591 .924 .964 r
.40788 .59099 m .4055 .59214 L .40699 .59264 L F
0 0 0 r
.33921 .67314 m .34061 .67281 L .34206 .6725 L F
.854 .679 .664 r
.32611 .53917 m .3252 .54169 L .32898 .54254 L F
.897 .574 .429 r
.3252 .54169 m .32861 .54543 L .32898 .54254 L F
0 0 0 r
.45593 .43281 m .4529 .43552 L .45429 .43428 L F
.45593 .43281 m .45692 .43318 L .45845 .43168 L F
.45593 .43281 m .45429 .43428 L .45692 .43318 L F
.716 .367 .384 r
.50087 .41566 m .49639 .41735 L .49646 .41446 L F
.50087 .41566 m .50054 .41767 L .49639 .41735 L F
.631 .359 .488 r
.50336 .4151 m .50054 .41767 L .50087 .41566 L F
0 0 0 r
.48246 .41169 m .48415 .41047 L .48561 .40901 L F
.422 .82 .605 r
.48246 .41169 m .48065 .41287 L .48415 .41047 L F
.72 .903 .96 r
.62727 .34624 m .626 .34911 L .62864 .34796 L F
.62727 .34624 m .62472 .34768 L .626 .34911 L F
.69 .931 .624 r
.55691 .39924 m .55684 .39839 L .5589 .39726 L F
.298 0 .11 r
.28069 .55647 m .28045 .55834 L .27719 .55874 L F
0 0 0 r
.2807 .55673 m .28069 .55647 L .28291 .55546 L F
.2807 .55673 m .28045 .55834 L .28069 .55647 L F
.758 .822 .903 r
.3287 .60875 m .32768 .61288 L .32596 .61116 L F
.3287 .60875 m .33077 .61073 L .32768 .61288 L F
.321 .779 .948 r
.634 .34026 m .63676 .33991 L .63777 .34051 L F
.299 .791 .878 r
.63676 .33991 m .6405 .33959 L .63777 .34051 L F
0 0 0 r
.55801 .38856 m .55784 .38964 L .5591 .38389 L F
.778 .662 .736 r
.52581 .4181 m .52674 .42212 L .52294 .42224 L F
.223 .739 .864 r
.52421 .4222 m .52674 .42212 L .52559 .4219 L F
.614 .559 .769 r
.52967 .41996 m .52674 .42212 L .52581 .4181 L F
.282 0 0 r
.52559 .4219 m .52674 .42212 L .5295 .42311 L F
.394 .187 .476 r
.5295 .42311 m .52674 .42212 L .52967 .41996 L F
.282 0 0 r
.52559 .4219 m .5295 .42311 L .52776 .42348 L F
.255 .258 .67 r
.52689 .42161 m .52559 .4219 L .52776 .42348 L F
.52616 .42003 m .52559 .4219 L .52689 .42161 L F
.223 .739 .864 r
.52294 .42224 m .52421 .4222 L .52559 .4219 L F
.99 .753 .376 r
.56712 .35247 m .56817 .35734 L .56572 .35135 L F
.817 .769 .808 r
.56646 .35696 m .56572 .35135 L .56817 .35734 L F
.85 .61 .574 r
.32032 .52875 m .32379 .53237 L .32428 .52953 L F
.903 .897 .812 r
.48623 .51171 m .48755 .50984 L .48601 .50857 L F
.466 .853 .645 r
.52548 .43215 m .52008 .43573 L .52551 .43491 L F
.349 .227 .569 r
.39607 .55591 m .39613 .55973 L .39815 .55809 L F
.39607 .55591 m .39613 .55973 L .39815 .55809 L F
.787 .585 .627 r
.37466 .5423 m .377 .54608 L .37952 .54505 L F
.839 .667 .669 r
.37421 .54848 m .37952 .54505 L .377 .54608 L F
.37421 .54848 m .37666 .54913 L .37952 .54505 L F
.485 .472 .768 r
.37952 .54505 m .38308 .54891 L .38138 .54497 L F
.824 .439 .323 r
.51868 .37179 m .51614 .37322 L .5177 .37043 L F
.51868 .37179 m .52026 .37421 L .51614 .37322 L F
.52026 .37421 m .51954 .37438 L .51614 .37322 L F
.663 .669 .845 r
.51562 .37738 m .51614 .37322 L .51799 .37385 L F
.51802 .37611 m .51799 .37385 L .5206 .37474 L F
.51562 .37738 m .51799 .37385 L .51802 .37611 L F
.814 .674 .71 r
.51836 .37436 m .52151 .37329 L .5208 .37271 L F
.51773 .37479 m .51826 .37458 L .51836 .37436 L F
.67 .454 .584 r
.51614 .37322 m .51808 .37454 L .5177 .37043 L F
.814 .674 .71 r
.51826 .37458 m .51855 .3743 L .51835 .3744 L F
.51732 .37507 m .51826 .37467 L .51773 .37479 L F
.524 .42 .678 r
.5184 .37476 m .51732 .37507 L .51819 .37448 L F
.814 .674 .71 r
.51826 .37458 m .52151 .37329 L .51855 .3743 L F
.67 .454 .584 r
.51819 .37448 m .5184 .37476 L .51835 .3744 L F
.814 .674 .71 r
.51835 .3744 m .51855 .3743 L .51836 .37436 L F
.51826 .37467 m .52151 .37329 L .51826 .37458 L F
.51821 .37468 m .51826 .37458 L .51773 .37479 L F
.51826 .37467 m .51826 .37458 L .51821 .37468 L F
0 0 .361 r
.51797 .37211 m .51835 .3744 L .51795 .37053 L F
.51835 .3744 m .5184 .37476 L .51836 .37437 L F
.51835 .3744 m .51836 .37437 L .51795 .37053 L F
.824 .439 .323 r
.52026 .37421 m .5206 .37474 L .51954 .37438 L F
.663 .669 .845 r
.51562 .37738 m .5206 .37474 L .51703 .37698 L F
.814 .674 .71 r
.51732 .37507 m .51945 .37715 L .52151 .37329 L F
.524 .42 .678 r
.5184 .37476 m .51836 .37436 L .5208 .37271 L F
0 0 .361 r
.51836 .37436 m .5184 .37476 L .51848 .37412 L F
.51836 .37437 m .5184 .37476 L .51836 .37436 L F
.524 .42 .678 r
.5184 .37476 m .51819 .37448 L .51836 .37436 L F
.67 .454 .584 r
.51808 .37454 m .5184 .37476 L .51819 .37448 L F
.51808 .37454 m .51835 .3744 L .5177 .37043 L F
0 0 .361 r
.51795 .37053 m .51836 .37437 L .51887 .37089 L F
.51836 .37437 m .51848 .37412 L .51887 .37089 L F
.5177 .37043 m .51797 .37211 L .51795 .37053 L F
.932 .555 .251 r
.63857 .37524 m .63732 .37649 L .63736 .37497 L F
.914 .951 .806 r
.63857 .37524 m .64004 .37045 L .64062 .37408 L F
.63857 .37524 m .63736 .37497 L .64004 .37045 L F
0 0 0 r
.64047 .37439 m .63857 .37524 L .64062 .37408 L F
.64047 .37439 m .63732 .37649 L .63857 .37524 L F
.822 .956 .902 r
.56173 .41381 m .5662 .41197 L .56499 .41071 L F
.996 .828 .472 r
.5662 .41197 m .5658 .40818 L .56499 .41071 L F
.425 .733 .99 r
.64593 .39151 m .64867 .39125 L .64829 .38987 L F
.861 .522 .409 r
.66119 .34121 m .66145 .34362 L .66303 .34153 L F
.808 .444 .368 r
.66303 .34153 m .66145 .34362 L .66339 .34378 L F
.973 .911 .685 r
.49245 .47868 m .48947 .48087 L .49072 .47711 L F
.49245 .47868 m .49075 .48189 L .48947 .48087 L F
0 0 .468 r
.5813 .3727 m .58249 .37469 L .5807 .37126 L F
.428 .507 .838 r
.25795 .58953 m .2569 .59243 L .25672 .58907 L F
.25795 .58953 m .25911 .59235 L .2569 .59243 L F
.554 .24 .391 r
.25911 .59235 m .25564 .59495 L .2569 .59243 L F
.295 .109 .449 r
.28664 .5418 m .28452 .54559 L .28463 .54267 L F
0 0 0 r
.6322 .34694 m .63144 .34728 L .62864 .34796 L F
.63144 .34728 m .63351 .34642 L .6322 .34694 L F
.495 .727 .975 r
.29957 .65882 m .29581 .6577 L .29793 .65634 L F
.468 .404 .703 r
.30012 .65466 m .29957 .65882 L .29793 .65634 L F
.30012 .65466 m .30195 .65937 L .29957 .65882 L F
.422 .413 .744 r
.27744 .65616 m .27841 .66047 L .28095 .65846 L F
.385 .349 .695 r
.27841 .66047 m .28119 .66249 L .28095 .65846 L F
.273 .349 .76 r
.27841 .66047 m .27959 .66277 L .28119 .66249 L F
.685 .726 .212 r
.5656 .35842 m .56554 .35857 L .56646 .35696 L F
.5656 .35842 m .56473 .3613 L .56554 .35857 L F
.64 .866 .496 r
.57331 .41998 m .57464 .41851 L .572 .42204 L F
.525 .328 .556 r
.57464 .41851 m .57497 .42165 L .572 .42204 L F
.038 0 .07 r
.57693 .41637 m .57464 .41851 L .57641 .41814 L F
.292 0 0 r
.57464 .41851 m .57664 .41916 L .57497 .42165 L F
.813 .872 .89 r
.57331 .41998 m .57641 .41814 L .57464 .41851 L F
.542 .446 .695 r
.36867 .5182 m .37327 .52145 L .37291 .51886 L F
.36867 .5182 m .37027 .5222 L .37327 .52145 L F
.605 .778 .963 r
.59774 .39807 m .602 .39905 L .60048 .39753 L F
.784 .899 .924 r
.60048 .39753 m .602 .39905 L .6044 .39683 L F
.742 .982 .912 r
.43193 .55464 m .4368 .55278 L .43357 .55581 L F
.43193 .55464 m .43568 .552 L .4368 .55278 L F
.869 .858 .828 r
.43742 .54792 m .4368 .55278 L .43568 .552 L F
.43742 .54792 m .43935 .54929 L .4368 .55278 L F
.87 .878 .84 r
.48198 .51384 m .48623 .51171 L .48478 .51039 L F
.903 .897 .812 r
.48623 .51171 m .48601 .50857 L .48478 .51039 L F
0 0 .469 r
.29164 .52895 m .29184 .5282 L .29072 .52554 L F
.751 .99 .885 r
.3215 .65556 m .31977 .65826 L .31965 .65732 L F
.3215 .65556 m .32247 .65597 L .31977 .65826 L F
.797 .938 .578 r
.31965 .65732 m .31977 .65826 L .31862 .65915 L F
.73 .747 .866 r
.39116 .59136 m .39704 .59178 L .39385 .58942 L F
.296 .679 .975 r
.39745 .59091 m .39385 .58942 L .39704 .59178 L F
.774 .725 .807 r
.43104 .5574 m .4313 .55948 L .42724 .55905 L F
.838 .768 .785 r
.43357 .55581 m .4313 .55948 L .43104 .5574 L F
.661 .424 .549 r
.52524 .40133 m .52798 .40227 L .52614 .40318 L F
.882 .837 .797 r
.42456 .56243 m .42148 .56218 L .42294 .55923 L F
.788 .809 .869 r
.42724 .55905 m .42456 .56243 L .42294 .55923 L F
.897 .511 .288 r
.27902 .64466 m .27993 .64861 L .28119 .64554 L F
.89 .936 .84 r
.30713 .5415 m .30726 .541 L .30654 .54078 L F
.892 .867 .807 r
.31156 .5392 m .30977 .54176 L .30726 .541 L F
.30832 .54022 m .30726 .541 L .30654 .54078 L F
.31156 .5392 m .30726 .541 L .30832 .54022 L F
.847 .948 .884 r
.31156 .5392 m .30832 .54022 L .31139 .53705 L F
.30832 .54022 m .30654 .54078 L .30758 .53998 L F
.30832 .54022 m .30758 .53998 L .31139 .53705 L F
.851 .9 .87 r
.31139 .53705 m .30654 .54078 L .30824 .53711 L F
.89 .936 .84 r
.30726 .541 m .30683 .54014 L .30654 .54078 L F
.30726 .541 m .30824 .53711 L .30683 .54014 L F
.892 .867 .807 r
.30977 .54176 m .30915 .54264 L .30654 .54078 L F
.89 .936 .84 r
.30652 .54153 m .30533 .5416 L .30684 .54113 L F
.30693 .54124 m .30684 .54113 L .30726 .541 L F
.30652 .54153 m .30684 .54113 L .30693 .54124 L F
.608 .081 0 r
.30666 .54089 m .30713 .5415 L .30654 .54078 L F
.30856 .54264 m .30713 .5415 L .30666 .54089 L F
.865 .839 .372 r
.30915 .54264 m .30856 .54264 L .30666 .54089 L F
.30705 .54114 m .30666 .54089 L .30654 .54078 L F
.30915 .54264 m .30666 .54089 L .30705 .54114 L F
.89 .936 .84 r
.30726 .541 m .30696 .54109 L .30659 .53965 L F
.688 .178 .019 r
.30713 .5415 m .30569 .54296 L .30367 .54127 L F
.594 .041 0 r
.30367 .54127 m .30533 .5416 L .30713 .5415 L F
.89 .936 .84 r
.30696 .54109 m .30533 .5416 L .30605 .54049 L F
.30696 .54109 m .30605 .54049 L .30659 .53965 L F
.30752 .53996 m .30659 .53965 L .30824 .53711 L F
.30726 .541 m .30659 .53965 L .30752 .53996 L F
.30713 .5415 m .30652 .54153 L .30726 .541 L F
.897 .967 .823 r
.31419 .53586 m .31156 .5392 L .31139 .53705 L F
0 0 0 r
.41398 .46234 m .4132 .46184 L .41137 .46295 L F
.41398 .46234 m .41559 .46057 L .4132 .46184 L F
.714 .505 .606 r
.3737 .56922 m .37405 .57271 L .37136 .57197 L F
.986 .83 .606 r
.5944 .34842 m .5935 .35108 L .59293 .34697 L F
.5944 .34842 m .5935 .35108 L .59293 .34697 L F
.853 .57 .509 r
.35267 .53592 m .34932 .53792 L .34903 .53499 L F
.35267 .53592 m .35269 .53863 L .34932 .53792 L F
.707 .355 .377 r
.33853 .50763 m .34262 .50575 L .33889 .5064 L F
.33853 .50763 m .34127 .50804 L .34262 .50575 L F
.188 0 .081 r
.34262 .50575 m .34408 .50699 L .34585 .50501 L F
.34262 .50575 m .34127 .50804 L .34408 .50699 L F
.589 .315 .468 r
.60513 .3533 m .60126 .354 L .60127 .3515 L F
.71 .825 .374 r
.52002 .38714 m .51931 .38875 L .52005 .38704 L F
.52111 .38467 m .52002 .38714 L .52105 .38473 L F
.52002 .38714 m .52005 .38704 L .52105 .38473 L F
.52111 .38467 m .51973 .38736 L .51931 .38875 L F
.669 .168 0 r
.51973 .38736 m .52164 .38904 L .51931 .38875 L F
.51991 .38752 m .52052 .3884 L .52164 .38904 L F
.51973 .38736 m .51989 .38757 L .51991 .38752 L F
.51989 .38757 m .52052 .3884 L .51991 .38752 L F
.169 0 .168 r
.31216 .68663 m .31509 .6834 L .31461 .68481 L F
.487 0 0 r
.31509 .6834 m .31722 .68457 L .31461 .68481 L F
.862 .743 .228 r
.67378 .36206 m .6744 .36185 L .67401 .35969 L F
.67378 .36206 m .67408 .36452 L .6744 .36185 L F
.613 .952 .804 r
.645 .37688 m .64277 .37857 L .64441 .3766 L F
.613 .95 .791 r
.64441 .3766 m .64277 .37857 L .64045 .37958 L F
.906 .923 .817 r
.30727 .63302 m .31005 .62945 L .30819 .62838 L F
.429 .565 .889 r
.31005 .62945 m .31132 .62592 L .30819 .62838 L F
.659 .262 0 r
.31005 .62945 m .31213 .63338 L .3144 .63055 L F
.634 .289 .369 r
.31005 .62945 m .3144 .63055 L .31326 .63055 L F
.429 .565 .889 r
.31005 .62945 m .31326 .63055 L .31132 .62592 L F
.017 0 0 r
.34301 .61909 m .33747 .62235 L .34108 .61935 L F
0 0 0 r
.33826 .62187 m .34108 .61935 L .3379 .62199 L F
.33996 .62083 m .34097 .6195 L .33826 .62187 L F
.34097 .6195 m .34108 .61935 L .33826 .62187 L F
.33802 .62202 m .3379 .62199 L .33747 .62235 L F
.33826 .62187 m .3379 .62199 L .33802 .62202 L F
.33996 .62083 m .33747 .62235 L .33747 .62114 L F
.193 .601 .945 r
.33706 .62472 m .33812 .62624 L .33914 .62509 L F
.33599 .62453 m .33632 .62479 L .33706 .62472 L F
.33599 .62453 m .33914 .62509 L .33814 .62541 L F
.644 .557 .742 r
.33814 .62541 m .33996 .62083 L .33747 .62114 L F
.156 .016 .426 r
.3389 .62219 m .33747 .62114 L .3374 .61911 L F
.644 .557 .742 r
.33814 .62541 m .3405 .62454 L .33996 .62083 L F
.156 .016 .426 r
.33937 .62314 m .33836 .62208 L .3389 .62219 L F
.33836 .62208 m .33747 .62114 L .3389 .62219 L F
.938 .77 .648 r
.33391 .62174 m .33682 .62288 L .33647 .62003 L F
0 0 .451 r
.33647 .62003 m .33682 .62288 L .33747 .62235 L F
0 0 0 r
.33747 .62235 m .33682 .62288 L .33599 .62453 L F
.656 .368 .471 r
.33747 .62114 m .33759 .62245 L .33391 .62174 L F
.33759 .62245 m .33783 .62517 L .33611 .62375 L F
.33783 .62517 m .33774 .62524 L .33611 .62375 L F
.201 .169 .596 r
.33796 .62462 m .33814 .62541 L .33801 .62462 L F
.193 .601 .945 r
.33632 .62479 m .33812 .62624 L .33706 .62472 L F
.863 .421 .025 r
.3392 .6292 m .33812 .62624 L .33599 .62453 L F
.34 .757 .978 r
.33331 .62293 m .33682 .62288 L .33391 .62174 L F
.534 .188 .328 r
.33599 .62453 m .33682 .62288 L .33331 .62293 L F
0 .194 .719 r
.33774 .62524 m .33599 .62453 L .33391 .62174 L F
.863 .421 .025 r
.3392 .6292 m .33599 .62453 L .33814 .62541 L F
.659 .875 .98 r
.3377 .62528 m .33814 .62541 L .33656 .62628 L F
.33867 .62443 m .33814 .62541 L .3377 .62528 L F
.285 0 0 r
.33814 .62541 m .33599 .62453 L .33774 .62529 L F
.33814 .62541 m .33774 .62529 L .33784 .62533 L F
0 .194 .719 r
.33784 .62533 m .33774 .62529 L .33774 .62524 L F
.33774 .62529 m .33599 .62453 L .33774 .62524 L F
.659 .875 .98 r
.33937 .62314 m .33867 .62443 L .33789 .62509 L F
.156 .016 .426 r
.33937 .62314 m .33784 .62533 L .33783 .62517 L F
.201 .169 .596 r
.33747 .62235 m .33796 .62462 L .33747 .62114 L F
.33796 .62462 m .33801 .62462 L .33747 .62114 L F
.156 .016 .426 r
.33937 .62314 m .33783 .62517 L .33747 .62114 L F
.659 .875 .98 r
.33937 .62314 m .33789 .62509 L .33774 .62521 L F
.33774 .62489 m .33774 .62521 L .33632 .62641 L F
.33937 .62314 m .33774 .62521 L .33774 .62489 L F
.33867 .62443 m .33656 .62628 L .33632 .62641 L F
.656 .368 .471 r
.33783 .62517 m .33784 .62533 L .33774 .62524 L F
.33759 .62245 m .33611 .62375 L .33391 .62174 L F
.739 .672 .784 r
.57165 .3915 m .57308 .39504 L .56879 .3946 L F
.529 .472 .737 r
.5752 .39173 m .57308 .39504 L .57165 .3915 L F
.5752 .39173 m .5759 .39436 L .57308 .39504 L F
.462 .257 .514 r
.5759 .39436 m .5732 .3979 L .57308 .39504 L F
.961 .636 .346 r
.60102 .37042 m .60163 .37313 L .60336 .37217 L F
0 0 0 r
.4529 .43552 m .44904 .4382 L .45122 .43687 L F
.478 .831 .561 r
.45429 .43428 m .4529 .43552 L .45122 .43687 L F
.897 .967 .823 r
.31419 .53586 m .31139 .53705 L .31181 .53517 L F
.878 .718 .679 r
.32861 .54543 m .32686 .5488 L .33025 .54893 L F
.877 .738 .705 r
.32686 .5488 m .32848 .55246 L .33025 .54893 L F
.53 .241 .421 r
.30727 .51913 m .30691 .52172 L .30952 .52125 L F
.88 .827 .791 r
.3868 .5382 m .39121 .53618 L .38723 .5362 L F
.3868 .5382 m .38901 .53893 L .39121 .53618 L F
.838 .768 .785 r
.43357 .55581 m .43104 .5574 L .43193 .55464 L F
.206 0 0 r
.55229 .3735 m .5562 .37334 L .55793 .37201 L F
.072 0 .213 r
.5603 .36847 m .55793 .37201 L .55931 .37079 L F
0 0 0 r
.55793 .37201 m .55895 .37249 L .55931 .37079 L F
.55793 .37201 m .5562 .37334 L .55895 .37249 L F
.566 .329 .516 r
.26761 .5491 m .27108 .54887 L .27127 .54578 L F
.344 .126 .432 r
.27127 .54578 m .27361 .54513 L .27382 .54259 L F
.331 .139 .462 r
.27127 .54578 m .2732 .54786 L .27361 .54513 L F
.27127 .54578 m .27108 .54887 L .2732 .54786 L F
.706 .901 .966 r
.29599 .62916 m .29333 .62943 L .29456 .62865 L F
0 0 0 r
.29577 .62788 m .29456 .62865 L .29244 .63013 L F
.707 .981 .902 r
.29629 .62752 m .29599 .62916 L .29456 .62865 L F
0 0 0 r
.29629 .62752 m .29456 .62865 L .29577 .62788 L F
.706 .901 .966 r
.29333 .62943 m .29203 .62956 L .29456 .62865 L F
.707 .981 .902 r
.29629 .62752 m .29932 .62694 L .29599 .62916 L F
0 0 0 r
.5603 .36847 m .56185 .36414 L .55908 .36524 L F
.5603 .36847 m .56211 .36443 L .56185 .36414 L F
.5603 .36847 m .56159 .36634 L .56211 .36443 L F
.102 .059 .519 r
.55931 .37079 m .56159 .36634 L .5603 .36847 L F
.501 .763 .989 r
.572 .42204 m .57497 .42165 L .57331 .41998 L F
.861 .985 .847 r
.5589 .41887 m .56114 .41844 L .55926 .41742 L F
.937 .641 .179 r
.28008 .63907 m .28162 .64348 L .28026 .64035 L F
.75 .268 .096 r
.28162 .64348 m .28301 .64523 L .28119 .64554 L F
.28162 .64348 m .28313 .64467 L .28301 .64523 L F
.28313 .64467 m .28438 .64563 L .28301 .64523 L F
0 0 0 r
.28238 .64797 m .28301 .64523 L .28238 .64798 L F
.75 .268 .096 r
.28438 .64563 m .28558 .64657 L .28301 .64523 L F
.699 .593 .734 r
.28558 .64657 m .2885 .6456 L .28301 .64523 L F
.28558 .64657 m .2885 .6456 L .28301 .64523 L F
0 0 0 r
.28377 .64354 m .28301 .64523 L .28238 .64797 L F
.755 .758 .855 r
.28119 .6447 m .28301 .64523 L .28122 .64062 L F
.28119 .64554 m .28301 .64523 L .28119 .6447 L F
.797 .523 .523 r
.29083 .56476 m .29575 .56269 L .29332 .56173 L F
.509 .276 .497 r
.29575 .56269 m .29556 .5657 L .29265 .56619 L F
.797 .523 .523 r
.29083 .56476 m .29556 .5657 L .29575 .56269 L F
.326 .13 .453 r
.29575 .56269 m .29779 .56458 L .29742 .56257 L F
.29575 .56269 m .29556 .5657 L .29779 .56458 L F
.29575 .56269 m .29779 .56458 L .29742 .56257 L F
.29575 .56269 m .29556 .5657 L .29779 .56458 L F
.941 .631 .181 r
.37327 .52145 m .37422 .5229 L .37291 .51886 L F
.565 .006 0 r
.37323 .52352 m .37422 .5229 L .37327 .52145 L F
.37323 .52352 m .37615 .52334 L .37422 .5229 L F
0 .556 .75 r
.61951 .38495 m .625 .3855 L .62236 .38519 L F
.61951 .38495 m .625 .3855 L .62236 .38519 L F
.542 .261 .439 r
.30754 .55553 m .30982 .55548 L .3096 .55316 L F
.75 .544 0 r
.3096 .55316 m .30958 .55428 L .31027 .55028 L F
.3096 .55316 m .30982 .55548 L .30958 .55428 L F
.45 .795 .998 r
.5557 .33681 m .55985 .33748 L .55719 .33794 L F
.5557 .33681 m .55985 .33748 L .55719 .33794 L F
.865 .839 .372 r
.30915 .54264 m .30832 .54528 L .30856 .54264 L F
.404 .494 .838 r
.27959 .66277 m .28317 .66611 L .28119 .66249 L F
.545 .84 .513 r
.48561 .40901 m .48594 .40852 L .48775 .40739 L F
.48561 .40901 m .48415 .41047 L .48594 .40852 L F
.921 .674 .547 r
.30386 .56586 m .30178 .56547 L .3025 .56256 L F
.703 .592 .729 r
.3063 .56334 m .30386 .56586 L .3025 .56256 L F
.693 .223 .13 r
.30675 .56653 m .30178 .56547 L .30386 .56586 L F
.716 .476 .561 r
.29426 .65339 m .29846 .65278 L .29793 .65634 L F
.728 .487 .562 r
.29846 .65278 m .30012 .65466 L .29793 .65634 L F
.65 .851 .457 r
.29811 .63872 m .29523 .643 L .29913 .64283 L F
.992 .77 .501 r
.29752 .64248 m .29913 .64283 L .29523 .643 L F
.29752 .64248 m .29879 .6462 L .29913 .64283 L F
.66 .969 .906 r
.29913 .64283 m .30231 .64103 L .30121 .641 L F
.29862 .64078 m .30155 .6407 L .29811 .63872 L F
.29913 .64283 m .30121 .641 L .29862 .64078 L F
.30121 .641 m .30155 .6407 L .29862 .64078 L F
.29913 .64283 m .3017 .64079 L .30155 .6407 L F
.29913 .64283 m .30121 .641 L .3 .64097 L F
0 0 0 r
.30121 .641 m .30139 .64102 L .3 .64097 L F
.66 .969 .906 r
.30141 .64102 m .3 .64097 L .3017 .64079 L F
.29913 .64283 m .3 .64097 L .30141 .64102 L F
0 0 0 r
.30139 .64102 m .30302 .64117 L .3 .64097 L F
.30231 .64103 m .30291 .64115 L .30121 .641 L F
.30291 .64115 m .30302 .64117 L .30121 .641 L F
0 0 .157 r
.28997 .53676 m .28664 .5418 L .28527 .54098 L F
.182 .657 .933 r
.63428 .38102 m .63579 .38194 L .63397 .38184 L F
.34 .757 .978 r
.33331 .62293 m .33391 .62174 L .33149 .62201 L F
.397 0 0 r
.33599 .62453 m .33331 .62293 L .33149 .62201 L F
.644 .548 .732 r
.56862 .39124 m .56879 .3946 L .56613 .3952 L F
.587 .586 .819 r
.24369 .59635 m .24855 .59822 L .24626 .59559 L F
0 0 0 r
.48859 .42167 m .4881 .42163 L .49049 .4205 L F
.48859 .42167 m .48631 .42287 L .4881 .42163 L F
.795 .948 .606 r
.34426 .66829 m .34383 .67008 L .34623 .66642 L F
.811 .999 .796 r
.53658 .40492 m .53378 .40797 L .53688 .40741 L F
.469 .338 .619 r
.53435 .41202 m .53688 .40741 L .53378 .40797 L F
0 0 0 r
.25488 .59986 m .25019 .6017 L .25074 .59953 L F
.25488 .59986 m .25266 .60112 L .25019 .6017 L F
.617 .612 .823 r
.25123 .59553 m .25368 .59986 L .25522 .59792 L F
.572 .828 .464 r
.25368 .59986 m .25266 .60112 L .25522 .59792 L F
0 0 .286 r
.25488 .59986 m .25522 .59792 L .25266 .60112 L F
.423 .096 .305 r
.25781 .59926 m .25577 .60275 L .25488 .59986 L F
0 0 .286 r
.25488 .59986 m .25577 .60275 L .25522 .59792 L F
.787 .753 .822 r
.52625 .44939 m .52106 .45078 L .52431 .44779 L F
.77 .676 .759 r
.52827 .39802 m .52798 .40227 L .52524 .40133 L F
.764 .913 .939 r
.52524 .40133 m .5282 .39921 L .52827 .39802 L F
.815 .822 .343 r
.52945 .39434 m .52903 .39565 L .52862 .39555 L F
.52903 .39565 m .52827 .39802 L .52862 .39555 L F
.478 .874 .7 r
.52862 .39555 m .52698 .39629 L .52827 .39548 L F
.815 .822 .343 r
.52945 .39434 m .52862 .39555 L .52778 .39362 L F
.975 .891 .677 r
.52945 .39434 m .52778 .39362 L .52918 .39039 L F
.848 .685 .68 r
.52918 .39039 m .52478 .38979 L .52835 .3899 L F
.52918 .39039 m .52751 .39145 L .52719 .39012 L F
.52918 .39039 m .52778 .39362 L .52493 .3931 L F
0 0 .518 r
.52788 .39294 m .52862 .39555 L .52835 .3899 L F
.52778 .39362 m .5284 .39504 L .52788 .39294 L F
.5284 .39504 m .52862 .39555 L .52788 .39294 L F
.848 .685 .68 r
.52719 .39012 m .52493 .3931 L .52478 .38979 L F
.52751 .39145 m .52493 .3931 L .52719 .39012 L F
0 0 .436 r
.52862 .39555 m .53018 .39098 L .52835 .3899 L F
.52862 .39555 m .5304 .39414 L .53018 .39098 L F
.478 .874 .7 r
.52862 .39555 m .52827 .39548 L .5304 .39414 L F
0 0 0 r
.52827 .39802 m .5282 .39921 L .52862 .39555 L F
.748 .95 .944 r
.52828 .3985 m .52698 .39629 L .52862 .39555 L F
.5282 .39921 m .52796 .39863 L .52828 .3985 L F
.52796 .39863 m .52698 .39629 L .52828 .3985 L F
.602 .047 0 r
.53213 .39887 m .53 .39943 L .52867 .39834 L F
.52905 .39819 m .52867 .39834 L .52827 .39802 L F
.53213 .39887 m .52867 .39834 L .52905 .39819 L F
.464 .885 .786 r
.53238 .39805 m .53213 .39887 L .53441 .39756 L F
.53238 .39805 m .53 .39943 L .53213 .39887 L F
0 0 .225 r
.33457 .64924 m .33478 .64921 L .33534 .64681 L F
.3354 .64652 m .33534 .64681 L .33546 .64633 L F
.33457 .64924 m .33534 .64681 L .3354 .64652 L F
.693 .549 .687 r
.33595 .64599 m .33633 .64874 L .33491 .6491 L F
.934 .823 .712 r
.33374 .64554 m .33457 .64924 L .33546 .64633 L F
.33374 .64554 m .33339 .64947 L .33457 .64924 L F
.693 .549 .687 r
.33534 .64681 m .33491 .6491 L .33339 .64947 L F
.33595 .64599 m .33491 .6491 L .33534 .64681 L F
.33563 .64641 m .33339 .64947 L .33374 .64554 L F
.84 .473 .359 r
.33339 .64947 m .33483 .6523 L .33457 .64924 L F
0 0 .266 r
.33457 .64924 m .33483 .6523 L .3349 .64919 L F
.647 .412 .549 r
.33633 .64874 m .33466 .65197 L .33491 .6491 L F
0 0 .266 r
.3349 .64919 m .33483 .6523 L .33523 .64914 L F
.647 .412 .549 r
.33485 .65161 m .33483 .6523 L .33466 .65197 L F
.33633 .64874 m .33483 .6523 L .33485 .65161 L F
.33491 .6491 m .33466 .65197 L .33339 .64947 L F
0 0 .225 r
.33497 .64838 m .33523 .64914 L .33546 .64633 L F
.33478 .64921 m .3349 .64919 L .33497 .64838 L F
.3349 .64919 m .33523 .64914 L .33497 .64838 L F
.33546 .64633 m .33523 .64914 L .33561 .64581 L F
.693 .549 .687 r
.33595 .64599 m .33563 .64641 L .33546 .64633 L F
.33555 .64591 m .33546 .64633 L .33374 .64554 L F
.33595 .64599 m .33546 .64633 L .33555 .64591 L F
.934 .823 .712 r
.33374 .64554 m .33546 .64633 L .33561 .64581 L F
.806 .751 .801 r
.29228 .55211 m .29082 .54862 L .29275 .5492 L F
.473 .756 .992 r
.29364 .54729 m .29275 .5492 L .29082 .54862 L F
.29364 .54729 m .29532 .54879 L .29275 .5492 L F
.776 .717 .184 r
.29236 .55044 m .29228 .55211 L .29274 .54927 L F
.29236 .55044 m .29274 .54927 L .29275 .5492 L F
.292 .114 .46 r
.29221 .55092 m .29236 .55044 L .29141 .5498 L F
.29415 .55363 m .29231 .5531 L .29236 .55044 L F
.29415 .55363 m .29236 .55044 L .29221 .55092 L F
.776 .717 .184 r
.29236 .55044 m .29275 .5492 L .29532 .54879 L F
.713 .945 .646 r
.33895 .64198 m .33802 .64381 L .33595 .64599 L F
0 0 .228 r
.52035 .38171 m .52111 .38467 L .52105 .38473 L F
.981 .864 .647 r
.33993 .63034 m .34226 .62983 L .3392 .6292 L F
.33993 .63034 m .3411 .63201 L .34226 .62983 L F
0 0 0 r
.34226 .62983 m .3434 .62874 L .34415 .626 L F
.34224 .63077 m .34226 .62983 L .3411 .63201 L F
.34224 .63077 m .3434 .62874 L .34226 .62983 L F
.84 .457 .326 r
.56908 .37904 m .57255 .37852 L .57071 .37672 L F
.56908 .37904 m .57292 .38048 L .57255 .37852 L F
.83 .528 .477 r
.32379 .53237 m .32376 .53509 L .32776 .53561 L F
.838 .667 .67 r
.32332 .53807 m .32776 .53561 L .32376 .53509 L F
.32332 .53807 m .32611 .53917 L .32776 .53561 L F
.542 .914 .948 r
.59628 .3439 m .59902 .34181 L .60097 .34232 L F
.59628 .3439 m .59552 .34342 L .59902 .34181 L F
.857 .702 .689 r
.36016 .56936 m .35655 .569 L .35838 .56545 L F
.804 .567 .58 r
.36016 .56936 m .35571 .57143 L .35655 .569 L F
.36016 .56936 m .35988 .57245 L .35571 .57143 L F
.703 .187 0 r
.54596 .42351 m .54714 .4222 L .54338 .42131 L F
.88 .884 .453 r
.54732 .41952 m .54714 .4222 L .54596 .42351 L F
.948 .93 .75 r
.55041 .43526 m .55267 .43132 L .55131 .4303 L F
.931 .947 .78 r
.55267 .43132 m .55346 .42657 L .55131 .4303 L F
.592 .571 .799 r
.6041 .36169 m .60079 .35813 L .60224 .36036 L F
.642 .798 .355 r
.34263 .64476 m .34184 .64632 L .34404 .64222 L F
.292 .607 .954 r
.34263 .64476 m .34469 .64697 L .34184 .64632 L F
.567 .354 .551 r
.34469 .64697 m .34176 .64922 L .34184 .64632 L F
.34469 .64697 m .34176 .64922 L .34184 .64632 L F
.743 .989 .791 r
.34623 .66642 m .34912 .66368 L .34677 .66472 L F
0 0 0 r
.62053 .39089 m .62266 .38994 L .62385 .38853 L F
.624 .577 .781 r
.62022 .39306 m .62266 .38994 L .62053 .39089 L F
.725 .622 .742 r
.25346 .60946 m .25711 .60945 L .25783 .61275 L F
.36 .806 .951 r
.25783 .61275 m .25595 .6122 L .25347 .61273 L F
0 0 0 r
.25711 .60945 m .25754 .61002 L .25776 .61243 L F
.725 .625 .747 r
.25632 .6067 m .25711 .60945 L .25346 .60946 L F
.758 .852 .92 r
.25758 .61044 m .25455 .60891 L .25595 .6122 L F
.266 .153 .533 r
.25889 .60543 m .25711 .60945 L .25632 .6067 L F
.25889 .60543 m .25915 .60875 L .25711 .60945 L F
.758 .852 .92 r
.25915 .60875 m .25749 .60995 L .25758 .61044 L F
0 0 0 r
.25749 .60995 m .25915 .60875 L .25754 .61002 L F
.25711 .60945 m .25915 .60875 L .25749 .60995 L F
.758 .852 .92 r
.25915 .60875 m .25728 .60882 L .25749 .60995 L F
.25728 .60882 m .25455 .60891 L .25758 .61044 L F
0 0 0 r
.25776 .61243 m .25758 .61044 L .25783 .61275 L F
.758 .852 .92 r
.25915 .60875 m .25758 .61044 L .25754 .61002 L F
0 0 0 r
.25758 .61044 m .25754 .61002 L .25759 .61052 L F
.25758 .61044 m .25759 .61052 L .25783 .61275 L F
.758 .852 .92 r
.25758 .61044 m .25595 .6122 L .25754 .61002 L F
.874 .949 .857 r
.25754 .61002 m .25595 .6122 L .25783 .61275 L F
.974 .68 .293 r
.33568 .5147 m .33445 .51443 L .33413 .51107 L F
.914 .519 .225 r
.33568 .5147 m .33488 .51688 L .33445 .51443 L F
.33568 .5147 m .33698 .51817 L .33488 .51688 L F
.97 .893 .524 r
.27954 .65175 m .27612 .65039 L .27582 .6523 L F
.212 0 .338 r
.33138 .6826 m .3319 .67973 L .3338 .67905 L F
.998 .787 .49 r
.51929 .38023 m .52107 .37863 L .51945 .37715 L F
.51929 .38023 m .52035 .38171 L .52107 .37863 L F
.752 .834 .914 r
.29984 .67966 m .30387 .67999 L .30288 .67891 L F
.588 .83 .99 r
.30387 .67999 m .30488 .67792 L .30288 .67891 L F
.30387 .67999 m .30663 .67918 L .30488 .67792 L F
.799 .612 .649 r
.38076 .52833 m .38341 .52941 L .38116 .52554 L F
.866 .653 .612 r
.38076 .52833 m .38261 .53212 L .38341 .52941 L F
.347 .087 .37 r
.64668 .36501 m .64552 .36922 L .64369 .36836 L F
.913 .92 .534 r
.64668 .36501 m .64535 .36617 L .64648 .36298 L F
.538 .834 .999 r
.30335 .64652 m .29879 .6462 L .30119 .64689 L F
.478 .814 .999 r
.3642 .57292 m .36264 .57183 L .35988 .57245 L F
.568 .857 .997 r
.36673 .57079 m .3642 .57292 L .3669 .57181 L F
.36673 .57079 m .36264 .57183 L .3642 .57292 L F
.565 .006 0 r
.37323 .52352 m .37746 .52447 L .37615 .52334 L F
0 .139 .608 r
.35109 .51218 m .34779 .50955 L .34665 .51188 L F
.757 .513 .564 r
.34654 .51466 m .35109 .51218 L .34665 .51188 L F
.34654 .51466 m .3509 .51511 L .35109 .51218 L F
.515 .769 .989 r
.30856 .64775 m .30768 .64962 L .30581 .64806 L F
0 0 .391 r
.30936 .65091 m .30768 .64962 L .30856 .64775 L F
.30936 .65091 m .30769 .65219 L .30768 .64962 L F
.845 .59 .553 r
.34338 .52242 m .34061 .52459 L .34083 .52181 L F
.34338 .52242 m .34315 .52518 L .34061 .52459 L F
.55 .826 .997 r
.30675 .65986 m .30195 .65937 L .30437 .66155 L F
.938 .897 .761 r
.30893 .65468 m .30675 .65986 L .30499 .65877 L F
.987 .813 .583 r
.30499 .65877 m .30675 .65986 L .30437 .66155 L F
.715 .816 .928 r
.40221 .57513 m .4003 .57688 L .39817 .57503 L F
.849 .511 .413 r
.33909 .51868 m .33695 .52081 L .33698 .51817 L F
.33909 .51868 m .34083 .52181 L .33695 .52081 L F
.753 .564 .64 r
.30441 .63606 m .30727 .63302 L .30475 .6321 L F
.30441 .63606 m .30708 .637 L .30727 .63302 L F
.906 .923 .817 r
.30727 .63302 m .30819 .62838 L .30475 .6321 L F
.583 .928 .734 r
.31055 .63649 m .31205 .63422 L .31064 .63646 L F
0 0 0 r
.30676 .63831 m .3111 .63559 L .31012 .63581 L F
.631 .953 .768 r
.30676 .63831 m .31012 .63581 L .30808 .63717 L F
.583 .928 .734 r
.30808 .63717 m .30998 .63576 L .31055 .63649 L F
.593 .596 .824 r
.3111 .63559 m .31104 .63555 L .31012 .63581 L F
.31104 .63555 m .30727 .63302 L .31012 .63581 L F
0 0 .13 r
.30727 .63302 m .30783 .63391 L .30985 .63558 L F
.30971 .63541 m .30985 .63558 L .31012 .63581 L F
.30727 .63302 m .30985 .63558 L .30971 .63541 L F
.815 .956 .907 r
.3111 .63559 m .31213 .63338 L .31205 .63422 L F
.698 .812 .936 r
.31205 .63422 m .31012 .63581 L .30783 .63391 L F
.583 .928 .734 r
.30979 .63589 m .31012 .63581 L .31205 .63422 L F
.30808 .63717 m .31012 .63581 L .30979 .63589 L F
.6 .939 .757 r
.31012 .63581 m .3111 .63559 L .31205 .63422 L F
.31012 .63581 m .3111 .63559 L .31205 .63422 L F
.583 .928 .734 r
.30998 .63576 m .31205 .63422 L .31055 .63649 L F
0 .202 .718 r
.55891 .39086 m .55976 .39033 L .55784 .38964 L F
.137 .024 .45 r
.55784 .38964 m .55976 .39033 L .56175 .38847 L F
.762 .621 .704 r
.50523 .41515 m .50317 .4118 L .50613 .41127 L F
.50523 .41515 m .50336 .4151 L .50317 .4118 L F
.626 .303 .403 r
.50523 .41515 m .50366 .41758 L .50336 .4151 L F
.818 .554 .54 r
.3025 .56256 m .30178 .56547 L .29779 .56458 L F
.8 .541 .547 r
.64369 .36836 m .64004 .37045 L .64354 .36825 L F
.64369 .36836 m .6441 .37112 L .64004 .37045 L F
.624 .895 .581 r
.64369 .36836 m .64354 .36825 L .64535 .36617 L F
.183 .114 .539 r
.64558 .36981 m .64369 .36836 L .64552 .36922 L F
.64558 .36981 m .6441 .37112 L .64369 .36836 L F
.817 .425 0 r
.31476 .65805 m .31589 .65996 L .31486 .65736 L F
0 0 0 r
.31535 .65705 m .31486 .65736 L .31585 .65621 L F
.31476 .65805 m .31535 .65705 L .31574 .65681 L F
.31535 .65705 m .31585 .65621 L .31576 .65667 L F
.31535 .65705 m .31576 .65667 L .31574 .65681 L F
.165 .684 .884 r
.31585 .65621 m .31154 .65576 L .31576 .65667 L F
.315 .539 .909 r
.31094 .65395 m .30893 .65468 L .30769 .65219 L F
.31094 .65395 m .31154 .65576 L .30893 .65468 L F
.264 .426 .836 r
.30936 .65091 m .31094 .65395 L .30769 .65219 L F
.494 .682 .949 r
.31021 .65275 m .31154 .65576 L .31094 .65395 L F
.782 .397 0 r
.31021 .65275 m .31094 .65395 L .30936 .65091 L F
.494 .682 .949 r
.31021 .65275 m .31579 .65665 L .31154 .65576 L F
.165 .684 .884 r
.31585 .65621 m .31576 .65667 L .31586 .65669 L F
.494 .682 .949 r
.31579 .65665 m .3158 .65665 L .31579 .65665 L F
.31579 .65665 m .31579 .65665 L .31154 .65576 L F
.3158 .65665 m .31586 .65669 L .31577 .65667 L F
0 0 0 r
.31675 .65553 m .31585 .65621 L .31586 .65669 L F
.735 .713 .831 r
.31675 .65553 m .31586 .65669 L .31579 .65665 L F
0 0 0 r
.31576 .65668 m .31585 .65621 L .31675 .65553 L F
.735 .713 .831 r
.31675 .65553 m .31579 .65665 L .31021 .65275 L F
0 0 0 r
.31574 .65681 m .31576 .65668 L .31675 .65553 L F
.494 .682 .949 r
.3158 .65665 m .31577 .65667 L .31154 .65576 L F
0 0 0 r
.31476 .65805 m .31484 .65752 L .31535 .65705 L F
.31484 .65752 m .31486 .65736 L .31535 .65705 L F
.46347 .43797 m .46685 .43566 L .46555 .4375 L F
.46555 .4375 m .46685 .43566 L .46908 .43438 L F
.56185 .36414 m .56382 .36265 L .56473 .3613 L F
.56211 .36443 m .56159 .36634 L .56207 .36515 L F
.56211 .36443 m .56207 .36515 L .56274 .36352 L F
.56213 .36393 m .56211 .36443 L .56382 .36265 L F
.56185 .36414 m .56211 .36443 L .56213 .36393 L F
.882 .855 .811 r
.29886 .57639 m .29755 .57576 L .30109 .57242 L F
.30109 .57242 m .29755 .57576 L .29886 .57639 L F
.954 .823 .676 r
.53875 .45665 m .54105 .45549 L .53978 .4544 L F
.53875 .45665 m .54035 .45779 L .54105 .45549 L F
.915 .673 .557 r
.35768 .5488 m .35439 .54809 L .35469 .54514 L F
.913 .723 .632 r
.35768 .5488 m .3538 .55091 L .35439 .54809 L F
.35768 .5488 m .35622 .55195 L .3538 .55091 L F
.804 .313 0 r
.31052 .56543 m .31046 .56699 L .30882 .56553 L F
.31052 .56543 m .31323 .56867 L .31046 .56699 L F
.697 .447 .541 r
.31339 .56584 m .31323 .56867 L .31052 .56543 L F
.52 .326 .558 r
.42711 .46204 m .42735 .46206 L .4257 .46449 L F
.42711 .46204 m .4298 .46166 L .42735 .46206 L F
.582 .908 .979 r
.63443 .35641 m .63499 .35488 L .63295 .35374 L F
.63443 .35641 m .63731 .35537 L .63499 .35488 L F
.757 .549 .616 r
.54642 .40469 m .5525 .4085 L .55143 .40872 L F
.333 .816 .82 r
.65226 .37458 m .64853 .37545 L .65109 .37368 L F
.959 .931 .721 r
.65226 .37458 m .65315 .36996 L .655 .37159 L F
.65226 .37458 m .65109 .37368 L .65315 .36996 L F
.85 .881 .861 r
.52372 .47515 m .52734 .47485 L .52562 .47338 L F
.829 .874 .878 r
.52734 .47485 m .52859 .47036 L .52562 .47338 L F
.52734 .47485 m .53014 .47186 L .52859 .47036 L F
.923 .65 .506 r
.37746 .52447 m .38076 .52833 L .38116 .52554 L F
.018 0 0 r
.24884 .60665 m .24483 .6085 L .2473 .60792 L F
.857 .792 .786 r
.54845 .37618 m .54425 .37741 L .54709 .37535 L F
.54845 .37618 m .54633 .37916 L .54425 .37741 L F
0 0 0 r
.54709 .37535 m .5507 .37472 L .54845 .37618 L F
0 0 .423 r
.60126 .354 m .60174 .35708 L .60079 .35813 L F
0 0 .409 r
.60135 .35883 m .60079 .35813 L .60174 .35708 L F
.60135 .35883 m .60224 .36036 L .60079 .35813 L F
.851 .979 .866 r
.31907 .61487 m .32057 .61558 L .31873 .6172 L F
.741 .969 .932 r
.32376 .61307 m .32057 .61558 L .31907 .61487 L F
0 0 0 r
.42718 .45414 m .43088 .45119 L .42841 .45209 L F
.108 0 0 r
.42451 .45511 m .42718 .45414 L .42841 .45209 L F
.86 .923 .869 r
.27557 .65519 m .27744 .65616 L .27988 .65313 L F
.613 .499 .7 r
.27744 .65616 m .28086 .6559 L .27988 .65313 L F
.422 .413 .744 r
.27744 .65616 m .28095 .65846 L .28086 .6559 L F
.968 .932 .632 r
.54015 .38867 m .53834 .38944 L .53915 .39089 L F
.549 .911 .725 r
.54137 .38713 m .54015 .38867 L .5419 .38678 L F
.54137 .38713 m .53834 .38944 L .54015 .38867 L F
.536 .517 .782 r
.5703 .35348 m .57089 .35794 L .56838 .35833 L F
.193 .579 .94 r
.34147 .61268 m .33685 .61039 L .33952 .61172 L F
.968 .76 .568 r
.34096 .61554 m .34147 .61268 L .33952 .61172 L F
0 0 .041 r
.51375 .38124 m .51562 .37738 L .51703 .37698 L F
.46 0 0 r
.39571 .47842 m .39402 .47987 L .39146 .47865 L F
.531 .099 .164 r
.39834 .47779 m .39402 .47987 L .39571 .47842 L F
0 0 0 r
.30231 .64103 m .30507 .63911 L .30302 .64117 L F
.683 .874 .97 r
.31521 .64167 m .3133 .64303 L .31324 .64061 L F
0 .107 .658 r
.31324 .64061 m .3133 .64303 L .31529 .64502 L F
.894 .676 .6 r
.35909 .55525 m .35573 .55474 L .35622 .55195 L F
.933 .762 .646 r
.35909 .55525 m .35543 .5577 L .35573 .55474 L F
.35909 .55525 m .35766 .55878 L .35543 .5577 L F
.779 .856 .41 r
.56473 .3613 m .56382 .36265 L .56554 .35857 L F
.665 .788 .94 r
.29793 .65634 m .29581 .6577 L .29368 .6556 L F
.399 .2 .491 r
.27382 .54259 m .27623 .54195 L .27626 .53885 L F
.207 .018 .39 r
.27382 .54259 m .27541 .54419 L .27623 .54195 L F
.27382 .54259 m .27361 .54513 L .27541 .54419 L F
.803 .727 .78 r
.37601 .58165 m .3764 .58498 L .37489 .58154 L F
.37865 .58189 m .37764 .58327 L .37601 .58165 L F
.37764 .58327 m .3764 .58498 L .37601 .58165 L F
.717 .363 0 r
.37489 .58154 m .3764 .58498 L .37606 .58463 L F
.926 .549 .27 r
.37881 .58416 m .37606 .58463 L .3764 .58498 L F
.37857 .5842 m .37711 .58711 L .37606 .58463 L F
.37881 .58416 m .37871 .58434 L .37857 .5842 L F
.37871 .58434 m .37711 .58711 L .37857 .5842 L F
.611 .128 .083 r
.37881 .58416 m .38143 .58732 L .37711 .58711 L F
.584 .127 .133 r
.38333 .58529 m .37881 .58416 L .38075 .58589 L F
.38333 .58529 m .38143 .58732 L .37881 .58416 L F
.504 .794 .998 r
.29265 .56619 m .29556 .5657 L .29083 .56476 L F
.85 .61 .574 r
.32032 .52875 m .32021 .53161 L .32379 .53237 L F
.842 .538 .475 r
.322 .53422 m .32379 .53237 L .32021 .53161 L F
.322 .53422 m .32376 .53509 L .32379 .53237 L F
.881 .989 .808 r
.54383 .40618 m .54642 .40469 L .54289 .4041 L F
.54383 .40618 m .54336 .40836 L .54642 .40469 L F
.569 .902 .98 r
.54831 .40271 m .54982 .40336 L .54642 .40469 L F
.54642 .40469 m .54982 .40336 L .54831 .40271 L F
.757 .549 .616 r
.54642 .40469 m .55143 .40872 L .54982 .40336 L F
.192 0 .256 r
.38405 .54164 m .38207 .54265 L .38138 .54497 L F
.727 .377 .386 r
.3771 .573 m .37344 .57477 L .37405 .57271 L F
.886 .737 .691 r
.34414 .51041 m .34779 .50955 L .34617 .50496 L F
.34414 .51041 m .34665 .51188 L .34779 .50955 L F
.866 .733 .714 r
.42304 .57196 m .42118 .57287 L .41886 .57181 L F
.749 .707 .812 r
.42493 .56882 m .42304 .57196 L .42154 .56851 L F
.792 .659 .717 r
.37666 .54913 m .37611 .55213 L .38024 .5514 L F
0 0 .221 r
.37611 .55213 m .37771 .5521 L .37928 .55157 L F
.83 .697 .717 r
.37421 .54848 m .37611 .55213 L .37666 .54913 L F
0 0 .221 r
.37785 .5521 m .37611 .55213 L .37635 .55066 L F
.757 .245 0 r
.37583 .55156 m .37723 .55227 L .37635 .55066 L F
.37723 .55227 m .37811 .55271 L .37761 .55214 L F
.37723 .55227 m .37761 .55214 L .37635 .55066 L F
0 0 .221 r
.37928 .55157 m .37785 .5521 L .38024 .5514 L F
.37771 .5521 m .37785 .5521 L .37928 .55157 L F
.513 .854 .584 r
.38308 .54891 m .38024 .5514 L .38106 .5505 L F
.48 .883 .735 r
.38106 .5505 m .38024 .5514 L .37785 .5521 L F
.267 .105 .467 r
.53658 .40492 m .5389 .40645 L .54009 .4043 L F
.53658 .40492 m .53688 .40741 L .5389 .40645 L F
.539 .874 .61 r
.49886 .39977 m .49721 .40095 L .49842 .3999 L F
.49886 .39977 m .49842 .3999 L .50035 .39824 L F
.745 .878 .464 r
.50008 .39819 m .4993 .39964 L .49886 .39977 L F
.4993 .39964 m .49795 .40217 L .49886 .39977 L F
.738 .968 .933 r
.49795 .40217 m .49668 .40143 L .49886 .39977 L F
.9 .538 .347 r
.34903 .53499 m .34644 .53169 L .34915 .53239 L F
.504 .517 .804 r
.34415 .626 m .34501 .62175 L .34245 .62501 L F
.34415 .626 m .34721 .62561 L .34501 .62175 L F
.467 .284 .548 r
.34649 .62895 m .34721 .62561 L .34415 .626 L F
.927 .663 .519 r
.3868 .5382 m .38901 .54187 L .38901 .53893 L F
.823 .871 .881 r
.31377 .58831 m .31528 .58413 L .31288 .5878 L F
.31377 .58831 m .31748 .58534 L .31528 .58413 L F
.811 .578 .585 r
.6509 .3678 m .655 .37159 L .65315 .36996 L F
.798 .537 .543 r
.3593 .51895 m .35916 .5217 L .36344 .5223 L F
.702 .247 .167 r
.35916 .5217 m .36246 .52495 L .36344 .5223 L F
.638 .214 .222 r
.36344 .5223 m .36366 .52412 L .36802 .52349 L F
0 0 0 r
.36344 .5223 m .36415 .52322 L .36366 .52412 L F
.36344 .5223 m .36246 .52495 L .36415 .52322 L F
.638 .214 .222 r
.36344 .5223 m .36802 .52349 L .36782 .52256 L F
.92 .753 .659 r
.35724 .51759 m .3593 .51895 L .35773 .51518 L F
.811 .549 .542 r
.35487 .52076 m .3593 .51895 L .35724 .51759 L F
.35487 .52076 m .35916 .5217 L .3593 .51895 L F
.182 0 0 r
.4298 .46166 m .43254 .46139 L .42735 .46206 L F
.159 0 0 r
.43254 .46139 m .42777 .46521 L .42735 .46206 L F
.33 0 .077 r
.42735 .46206 m .42519 .46571 L .4257 .46449 L F
.42735 .46206 m .42777 .46521 L .42519 .46571 L F
0 0 .522 r
.31123 .68241 m .31216 .68663 L .31289 .68528 L F
.623 .957 .812 r
.31289 .68528 m .31216 .68663 L .31461 .68481 L F
.779 .519 .542 r
.31645 .56828 m .31323 .56867 L .31339 .56584 L F
.82 .656 .68 r
.31126 .57561 m .30729 .57792 L .30915 .57451 L F
.31126 .57561 m .3102 .57916 L .30729 .57792 L F
.873 .877 .836 r
.31126 .57561 m .31238 .57074 L .31474 .57236 L F
.31126 .57561 m .30915 .57451 L .31238 .57074 L F
.198 .253 .695 r
.3325 .64213 m .3299 .63944 L .33188 .63941 L F
.571 .304 .473 r
.26494 .55195 m .26752 .55171 L .26761 .5491 L F
.575 .321 .494 r
.26752 .55171 m .27108 .54887 L .26761 .5491 L F
.74 .692 .805 r
.29233 .64596 m .28941 .64928 L .2885 .6456 L F
.96 .656 .408 r
.34301 .61909 m .34096 .61554 L .33865 .61673 L F
.765 .257 0 r
.343 .62071 m .34301 .61909 L .34108 .61935 L F
.343 .62071 m .34501 .62175 L .34301 .61909 L F
.809 .955 .911 r
.41122 .58843 m .40981 .59188 L .41232 .58872 L F
.41122 .58843 m .40788 .59099 L .40981 .59188 L F
.31 .116 .447 r
.40981 .59188 m .41221 .59166 L .41232 .58872 L F
.383 .163 .451 r
.50498 .45189 m .50786 .45116 L .50809 .44812 L F
.673 .535 .688 r
.50502 .45404 m .50786 .45116 L .50498 .45189 L F
.743 .972 .928 r
.51584 .48277 m .51113 .48464 L .5126 .48567 L F
.743 .804 .901 r
.45948 .53509 m .46033 .53695 L .46365 .53532 L F
.415 .202 .48 r
.27626 .53885 m .27885 .53836 L .27891 .53563 L F
.323 .142 .473 r
.27626 .53885 m .27826 .541 L .27885 .53836 L F
.27626 .53885 m .27623 .54195 L .27826 .541 L F
.085 .398 .854 r
.53569 .41337 m .53809 .41579 L .53729 .41379 L F
.893 .483 .073 r
.53849 .41621 m .53751 .41652 L .53729 .41379 L F
.551 .476 .723 r
.53751 .41652 m .53876 .41417 L .53729 .41379 L F
.53876 .41417 m .53929 .41319 L .53729 .41379 L F
.085 .398 .854 r
.53435 .41202 m .53569 .41337 L .53729 .41379 L F
.744 .983 .754 r
.43713 .56173 m .43681 .56126 L .43649 .56254 L F
.951 .881 .478 r
.43538 .56308 m .43649 .56254 L .43681 .56126 L F
.43538 .56308 m .43568 .56572 L .43649 .56254 L F
.919 .526 .153 r
.29016 .56179 m .29083 .56476 L .29031 .56216 L F
.51 .306 .539 r
.50446 .40161 m .50327 .40625 L .50163 .40481 L F
.102 0 0 r
.27719 .55874 m .27534 .56103 L .27305 .56159 L F
.318 0 0 r
.27824 .56039 m .27719 .55874 L .28045 .55834 L F
.27824 .56039 m .27534 .56103 L .27719 .55874 L F
.855 .922 .873 r
.48849 .50571 m .49153 .50499 L .49045 .50396 L F
.835 .997 .835 r
.49153 .50499 m .49375 .50114 L .49045 .50396 L F
.49153 .50499 m .49458 .50179 L .49375 .50114 L F
.903 .675 .585 r
.35489 .54231 m .35231 .54147 L .35269 .53863 L F
.872 .604 .53 r
.35489 .54231 m .35208 .54429 L .35231 .54147 L F
.35489 .54231 m .35469 .54514 L .35208 .54429 L F
0 0 .232 r
.54383 .40618 m .54358 .41137 L .54336 .40836 L F
.609 .743 .94 r
.32464 .68392 m .32633 .68702 L .32852 .68586 L F
.32423 .68371 m .32852 .68586 L .32673 .68193 L F
.023 0 0 r
.326 .68279 m .32667 .68257 L .32486 .68413 L F
.32673 .68193 m .32671 .6822 L .326 .68279 L F
.32671 .6822 m .32667 .68257 L .326 .68279 L F
.609 .743 .94 r
.32423 .68371 m .32446 .68407 L .32464 .68392 L F
.32446 .68407 m .32633 .68702 L .32464 .68392 L F
.355 .155 .465 r
.32822 .68867 m .32633 .68702 L .32852 .68586 L F
.32822 .68867 m .32633 .68702 L .32852 .68586 L F
.773 .657 .734 r
.30153 .59164 m .30293 .59637 L .2984 .59556 L F
.669 .183 .087 r
.2984 .59556 m .30293 .59637 L .30075 .59778 L F
.533 .513 .779 r
.30519 .59533 m .30293 .59637 L .30153 .59164 L F
0 0 0 r
.30075 .59778 m .30293 .59637 L .30519 .59533 L F
.983 .702 .401 r
.5078 .4541 m .50934 .45861 L .50946 .45538 L F
.267 .76 .691 r
.40516 .47618 m .40353 .47669 L .40104 .47762 L F
.735 .213 0 r
.40516 .47618 m .40695 .47807 L .40353 .47669 L F
.851 .744 .744 r
.53863 .427 m .54215 .42866 L .54087 .43008 L F
0 0 .172 r
.34912 .66368 m .35136 .65959 L .35112 .6618 L F
.999 .803 .508 r
.35112 .6618 m .35136 .65959 L .34965 .66143 L F
.959 .892 .507 r
.35136 .65959 m .35156 .65535 L .35167 .65727 L F
.879 .942 .576 r
.34965 .66143 m .35136 .65959 L .35167 .65727 L F
.903 .771 .706 r
.54633 .37916 m .54574 .38195 L .54425 .37741 L F
.382 .258 .585 r
.54776 .38038 m .54574 .38195 L .54633 .37916 L F
.404 .13 .381 r
.28008 .63907 m .28243 .63604 L .28148 .63648 L F
.746 .866 .935 r
.30848 .62267 m .30438 .62263 L .30669 .62115 L F
.684 .979 .881 r
.30821 .62141 m .30848 .62267 L .30669 .62115 L F
.30821 .62141 m .31182 .62032 L .30848 .62267 L F
0 0 0 r
.63144 .34728 m .63416 .34661 L .63351 .34642 L F
.065 0 0 r
.63351 .34642 m .63778 .34638 L .63416 .34661 L F
.846 .743 .749 r
.648 .35496 m .6458 .35831 L .64366 .35698 L F
.781 .807 .873 r
.51579 .45803 m .51284 .46069 L .51205 .45741 L F
.815 .554 .544 r
.52108 .42017 m .52559 .4219 L .52581 .4181 L F
.614 .559 .769 r
.52967 .41996 m .52581 .4181 L .52795 .41737 L F
.462 .528 .84 r
.528 .41641 m .52967 .41996 L .52795 .41737 L F
.52818 .4168 m .53222 .4206 L .52967 .41996 L F
.528 .41641 m .52852 .41693 L .52818 .4168 L F
.52852 .41693 m .53222 .4206 L .52818 .4168 L F
.432 .463 .792 r
.52795 .41737 m .52588 .41768 L .52744 .41709 L F
.52795 .41737 m .52581 .4181 L .52613 .41637 L F
.629 .357 .487 r
.52649 .41613 m .52837 .41493 L .52806 .41675 L F
.52649 .41613 m .52806 .41675 L .52795 .41737 L F
.432 .463 .792 r
.52795 .41737 m .52581 .4181 L .52588 .41768 L F
0 0 .213 r
.52581 .4181 m .52616 .42003 L .52795 .41737 L F
.629 .357 .487 r
.52613 .41637 m .5267 .416 L .52795 .41737 L F
.5267 .416 m .52837 .41493 L .52809 .41659 L F
.5267 .416 m .52809 .41659 L .52795 .41737 L F
.531 .547 .816 r
.53442 .41932 m .528 .41641 L .53367 .41813 L F
.53481 .41994 m .52961 .41725 L .53442 .41932 L F
.52961 .41725 m .528 .41641 L .53442 .41932 L F
.776 .582 .637 r
.528 .41641 m .52795 .41737 L .52616 .42003 L F
.52771 .41699 m .5271 .41817 L .52825 .41679 L F
.5271 .41817 m .52616 .42003 L .52686 .41894 L F
.5271 .41817 m .52686 .41894 L .52825 .41679 L F
.629 .357 .487 r
.52613 .41637 m .52649 .41613 L .52748 .41697 L F
.52744 .41709 m .52748 .41697 L .52795 .41737 L F
.52613 .41637 m .52748 .41697 L .52744 .41709 L F
.776 .582 .637 r
.52825 .41679 m .52616 .42003 L .52964 .41883 L F
.528 .41641 m .52771 .41699 L .52825 .41679 L F
.432 .463 .792 r
.52744 .41709 m .52588 .41768 L .52613 .41637 L F
0 0 .213 r
.52581 .4181 m .52559 .4219 L .52616 .42003 L F
.906 .498 .194 r
.3957 .53256 m .39717 .53428 L .39646 .5311 L F
.691 .861 .963 r
.38235 .57615 m .37825 .5757 L .38073 .57555 L F
.38235 .57615 m .37825 .5757 L .38073 .57555 L F
.891 .871 .811 r
.54087 .43008 m .53962 .43253 L .53791 .43102 L F
.768 .845 .91 r
.31873 .6172 m .31354 .61847 L .31701 .62021 L F
.851 .979 .866 r
.31907 .61487 m .31873 .6172 L .31701 .62021 L F
0 0 0 r
.50008 .39819 m .50196 .3968 L .50331 .39554 L F
.50008 .39819 m .49886 .39977 L .50196 .3968 L F
.114 0 0 r
.54169 .42574 m .54438 .42445 L .54386 .42497 L F
.779 .603 .661 r
.53893 .42345 m .54347 .42485 L .54338 .42131 L F
.369 .813 .67 r
.54347 .42485 m .54438 .42445 L .54232 .42544 L F
.54382 .42467 m .54386 .42466 L .54347 .42485 L F
.54386 .42466 m .54438 .42445 L .54347 .42485 L F
.54382 .42467 m .54232 .42544 L .54169 .42574 L F
.792 .514 .517 r
.54169 .42574 m .54386 .42497 L .54347 .42485 L F
.54169 .42574 m .54347 .42485 L .53893 .42345 L F
.779 .603 .661 r
.54347 .42485 m .54386 .42497 L .54382 .42467 L F
.54347 .42485 m .54382 .42467 L .54338 .42131 L F
.369 .813 .67 r
.54343 .42483 m .54382 .42467 L .54169 .42574 L F
.968 .714 .284 r
.54382 .42467 m .54438 .42445 L .54338 .42131 L F
.703 .187 0 r
.54596 .42351 m .54338 .42131 L .54438 .42445 L F
.369 .813 .67 r
.54596 .42351 m .54438 .42445 L .54343 .42483 L F
.968 .714 .284 r
.54386 .42497 m .54438 .42445 L .54382 .42467 L F
.851 .864 .851 r
.31528 .58413 m .31748 .58534 L .3202 .58208 L F
.847 .873 .86 r
.31414 .63272 m .31677 .63039 L .31702 .62957 L F
.358 0 0 r
.31966 .63197 m .31702 .62957 L .31677 .63039 L F
.224 .149 .557 r
.31677 .63039 m .31918 .63468 L .31966 .63197 L F
.31788 .63237 m .3174 .63449 L .31812 .63278 L F
.31677 .63039 m .31715 .63282 L .31788 .63237 L F
.31715 .63282 m .3174 .63449 L .31788 .63237 L F
.796 .797 .852 r
.31896 .63077 m .31843 .63204 L .31559 .6322 L F
.517 .882 .978 r
.31559 .6322 m .31843 .63204 L .31755 .63123 L F
.796 .797 .852 r
.31896 .63077 m .31966 .63197 L .31843 .63204 L F
.517 .882 .978 r
.31843 .63204 m .31966 .63197 L .31895 .63172 L F
.31843 .63204 m .31895 .63172 L .31755 .63123 L F
.776 .747 .826 r
.31572 .62674 m .31702 .62957 L .31989 .62624 L F
.796 .797 .852 r
.3176 .62845 m .31896 .63077 L .31559 .6322 L F
.224 .149 .557 r
.31812 .63278 m .31763 .63596 L .31918 .63468 L F
.3174 .63449 m .31763 .63596 L .31812 .63278 L F
.937 .939 .77 r
.55143 .40872 m .54814 .41059 L .54992 .40831 L F
.55143 .40872 m .54953 .41203 L .54814 .41059 L F
.544 .542 .802 r
.55143 .40872 m .55231 .40305 L .54982 .40336 L F
.55143 .40872 m .55462 .40829 L .55231 .40305 L F
.536 .537 .803 r
.55231 .40305 m .55462 .40829 L .55573 .4069 L F
.394 .793 .985 r
.55535 .40751 m .55143 .40872 L .54992 .40831 L F
0 0 0 r
.55573 .4069 m .55462 .40829 L .55535 .40751 L F
.394 .793 .985 r
.55535 .40751 m .55462 .40829 L .55143 .40872 L F
0 0 0 r
.54709 .37535 m .54959 .37505 L .5507 .37472 L F
.165 0 0 r
.54959 .37505 m .55229 .3735 L .5507 .37472 L F
.433 .242 .52 r
.55345 .3766 m .55095 .37766 L .5507 .37472 L F
.343 0 0 r
.61924 .35162 m .61784 .35266 L .61538 .35234 L F
.883 .93 .548 r
.61866 .34968 m .61924 .35162 L .62173 .35048 L F
.61866 .34968 m .61784 .35266 L .61924 .35162 L F
0 0 0 r
.45964 .4408 m .46347 .43797 L .462 .43955 L F
.46347 .43797 m .46449 .43884 L .462 .43955 L F
.46347 .43797 m .46555 .4375 L .46449 .43884 L F
0 .39 .706 r
.30816 .58959 m .30799 .58941 L .30684 .5884 L F
.30816 .58959 m .30969 .59008 L .30799 .58941 L F
.837 .544 .493 r
.5802 .3681 m .58008 .3685 L .57666 .36824 L F
.5802 .3681 m .5807 .37126 L .58008 .3685 L F
0 0 0 r
.50331 .39554 m .50394 .39522 L .50571 .39422 L F
.50331 .39554 m .50196 .3968 L .50394 .39522 L F
.583 .941 .916 r
.51192 .41929 m .51508 .41836 L .51427 .41988 L F
0 0 .107 r
.51508 .41836 m .51543 .41508 L .51537 .41784 L F
0 0 0 r
.51427 .41988 m .51508 .41836 L .51537 .41784 L F
.326 .439 .823 r
.24625 .61076 m .2473 .60792 L .24483 .6085 L F
.24625 .61076 m .24897 .61181 L .2473 .60792 L F
.866 .653 .612 r
.38076 .52833 m .37919 .53146 L .38261 .53212 L F
.805 .594 .616 r
.37823 .53424 m .38261 .53212 L .37919 .53146 L F
.37823 .53424 m .38191 .53596 L .38261 .53212 L F
.769 .934 .938 r
.64185 .39177 m .64045 .39025 L .63677 .39221 L F
.468 .078 .216 r
.57748 .41809 m .57693 .41637 L .57641 .41814 L F
.718 .983 .901 r
.30144 .62528 m .29932 .62694 L .29629 .62752 L F
.528 .828 .5 r
.54574 .38195 m .54405 .38366 L .54434 .38342 L F
0 0 0 r
.54654 .38189 m .54574 .38195 L .54776 .38038 L F
.54654 .38189 m .54405 .38366 L .54574 .38195 L F
.565 .762 .971 r
.33255 .61007 m .33077 .61073 L .3287 .60875 L F
.491 .855 .614 r
.43254 .46114 m .43634 .45829 L .43513 .46022 L F
0 0 0 r
.43634 .45829 m .43951 .45537 L .43848 .45745 L F
.43722 .4591 m .43634 .45829 L .43848 .45745 L F
.43722 .4591 m .43513 .46022 L .43634 .45829 L F
.879 .95 .852 r
.31633 .63784 m .31911 .63763 L .31521 .64167 L F
.285 .181 .556 r
.32064 .63831 m .32088 .64139 L .31911 .63763 L F
.404 0 0 r
.32064 .63831 m .31911 .63763 L .31633 .63784 L F
.425 0 0 r
.31633 .63784 m .31825 .63726 L .32064 .63831 L F
.881 .795 .76 r
.32401 .57156 m .32507 .57506 L .32645 .57297 L F
.614 .225 .282 r
.60543 .35052 m .60827 .35106 L .60388 .35082 L F
.631 .359 .488 r
.50336 .4151 m .50366 .41758 L .50054 .41767 L F
.726 .985 .79 r
.34677 .66472 m .34912 .66368 L .35112 .6618 L F
.716 .476 .561 r
.29426 .65339 m .29793 .65634 L .29368 .6556 L F
.014 0 0 r
.54009 .4043 m .54075 .40519 L .54289 .4041 L F
.54009 .4043 m .5389 .40645 L .54075 .40519 L F
.907 .672 .572 r
.34673 .52885 m .34331 .53045 L .34299 .52786 L F
.34673 .52885 m .34644 .53169 L .34331 .53045 L F
.454 .347 .644 r
.25781 .57172 m .26011 .5676 L .2572 .57067 L F
0 0 0 r
.30476 .65579 m .30769 .65219 L .30893 .65468 L F
.938 .897 .761 r
.30893 .65468 m .30499 .65877 L .30476 .65579 L F
.567 .631 .874 r
.53931 .41769 m .54389 .41915 L .54195 .41658 L F
.702 .446 .535 r
.54338 .42131 m .53931 .41769 L .53898 .42055 L F
.54338 .42131 m .54389 .41915 L .53931 .41769 L F
.213 .411 .84 r
.28119 .66249 m .28317 .66611 L .28422 .66433 L F
.077 .227 .717 r
.28317 .66611 m .2856 .66847 L .28422 .66433 L F
.501 .234 .442 r
.36782 .52256 m .37233 .52154 L .37027 .5222 L F
.36782 .52256 m .36802 .52349 L .37233 .52154 L F
.791 .997 .859 r
.66328 .3781 m .66653 .37519 L .66436 .37552 L F
.802 .994 .763 r
.66281 .37756 m .66328 .3781 L .66436 .37552 L F
.553 .889 .639 r
.47061 .42195 m .46737 .42467 L .46886 .42309 L F
.485 .855 .623 r
.47061 .42195 m .4721 .42064 L .47253 .42047 L F
.47061 .42195 m .46886 .42309 L .4721 .42064 L F
.556 .895 .656 r
.46886 .42309 m .46737 .42467 L .46558 .42577 L F
.739 .672 .784 r
.57165 .3915 m .56879 .3946 L .56862 .39124 L F
0 0 0 r
.29203 .62956 m .28887 .63169 L .29008 .63099 L F
.29008 .63099 m .28887 .63169 L .28794 .63477 L F
.575 .565 .805 r
.50445 .40695 m .50613 .41127 L .50317 .4118 L F
.852 .911 .506 r
.54953 .41203 m .54797 .41387 L .54814 .41059 L F
.104 .332 .803 r
.58249 .37469 m .58325 .37276 L .5807 .37126 L F
0 .114 .666 r
.58249 .37469 m .58413 .37508 L .58325 .37276 L F
.963 .709 .503 r
.29114 .67606 m .29316 .67927 L .29533 .67941 L F
.504 .638 .914 r
.29316 .67927 m .29722 .68113 L .29533 .67941 L F
0 .118 .664 r
.58477 .39789 m .58682 .40019 L .58525 .39621 L F
.715 .427 .487 r
.37233 .52154 m .37327 .52145 L .37027 .5222 L F
.986 .763 .366 r
.37308 .541 m .37419 .5457 L .37466 .5423 L F
.738 .573 .67 r
.37419 .5457 m .377 .54608 L .37466 .5423 L F
.633 .784 .334 r
.3745 .53954 m .37591 .53759 L .37455 .53941 L F
.36 .723 .987 r
.37466 .5423 m .37517 .54194 L .37308 .541 L F
.37517 .54194 m .37492 .54106 L .37308 .541 L F
.37466 .5423 m .37638 .54111 L .37412 .54103 L F
.37382 .54161 m .37412 .54103 L .37308 .541 L F
.37466 .5423 m .37412 .54103 L .37382 .54161 L F
.986 .763 .366 r
.37308 .541 m .37243 .54424 L .37288 .54461 L F
.37337 .5422 m .37288 .54461 L .37419 .5457 L F
.37308 .541 m .37288 .54461 L .37337 .5422 L F
.983 .703 .34 r
.37249 .54647 m .37419 .5457 L .37243 .54424 L F
.496 .096 .211 r
.37365 .54102 m .37286 .54342 L .37308 .541 L F
.36 .723 .987 r
.37517 .54194 m .37638 .54111 L .37492 .54106 L F
.496 .096 .211 r
.37638 .54111 m .37325 .54316 L .37365 .54102 L F
.37325 .54316 m .37286 .54342 L .37365 .54102 L F
.841 .652 .646 r
.37591 .53759 m .37343 .54232 L .37638 .54111 L F
.37343 .54232 m .37286 .54342 L .37325 .54316 L F
.37343 .54232 m .37325 .54316 L .37638 .54111 L F
0 0 0 r
.37288 .54483 m .37254 .5463 L .37259 .54605 L F
.789 .999 .835 r
.37354 .5421 m .37286 .54342 L .37638 .54111 L F
0 0 0 r
.37354 .5421 m .37281 .54516 L .37288 .54483 L F
.37281 .54516 m .37254 .5463 L .37288 .54483 L F
.37354 .5421 m .37285 .54525 L .37285 .54526 L F
.3731 .54395 m .37285 .54526 L .37254 .5463 L F
.37354 .5421 m .37285 .54526 L .3731 .54395 L F
.37259 .54605 m .37254 .5463 L .37249 .54647 L F
.633 .784 .334 r
.37354 .5421 m .37286 .54342 L .37444 .5404 L F
.37463 .54002 m .37444 .5404 L .37591 .53759 L F
.37354 .5421 m .37444 .5404 L .37463 .54002 L F
.37354 .5421 m .37463 .54002 L .3745 .53954 L F
.37463 .54002 m .37591 .53759 L .3745 .53954 L F
.707 .713 .186 r
.57362 .36171 m .5737 .36169 L .57411 .35947 L F
.57362 .36171 m .57309 .36416 L .5737 .36169 L F
.81 .665 .702 r
.31645 .56828 m .31474 .57236 L .31323 .56867 L F
.892 .883 .818 r
.45284 .53234 m .4503 .53594 L .44854 .53462 L F
.33 0 0 r
.38308 .56848 m .38733 .56818 L .38566 .56787 L F
.745 .974 .925 r
.38753 .56672 m .38733 .56818 L .38961 .56775 L F
.38753 .56672 m .38566 .56787 L .38733 .56818 L F
.988 .841 .605 r
.35665 .64466 m .3592 .64312 L .35678 .64011 L F
.35665 .64466 m .35817 .64566 L .3592 .64312 L F
.116 0 0 r
.62385 .38853 m .62266 .38994 L .62567 .38901 L F
.783 .886 .92 r
.53664 .38562 m .53127 .38635 L .53542 .38458 L F
.885 .892 .831 r
.53745 .38403 m .53664 .38562 L .53542 .38458 L F
.933 .889 .765 r
.54824 .43883 m .55041 .43526 L .54899 .43391 L F
.948 .93 .75 r
.55041 .43526 m .55131 .4303 L .54899 .43391 L F
.708 .918 .576 r
.51025 .4363 m .50925 .43818 L .50946 .43756 L F
.451 .683 .965 r
.50925 .43818 m .51171 .43818 L .51025 .4363 L F
.655 .829 .409 r
.50791 .44022 m .50925 .43818 L .51025 .4363 L F
.562 .574 .824 r
.29487 .52883 m .29072 .52554 L .29184 .5282 L F
0 0 0 r
.31559 .6322 m .31414 .63272 L .31702 .62957 L F
0 .158 .696 r
.58516 .38821 m .58601 .38666 L .58352 .38452 L F
0 0 .441 r
.58516 .38821 m .58709 .38818 L .58601 .38666 L F
.58516 .38821 m .58551 .39085 L .58709 .38818 L F
.933 .903 .771 r
.53667 .46026 m .54035 .45779 L .53875 .45665 L F
.53667 .46026 m .53807 .46152 L .54035 .45779 L F
0 0 0 r
.43848 .45745 m .43951 .45537 L .44151 .45415 L F
.626 .367 .506 r
.34365 .63463 m .3456 .63568 L .34282 .63581 L F
.588 .406 .602 r
.34556 .63277 m .3456 .63568 L .34365 .63463 L F
.897 .648 .554 r
.34501 .62175 m .34721 .62561 L .34793 .6227 L F
.905 .755 .684 r
.35919 .56275 m .35838 .56545 L .35692 .56155 L F
.583 .826 .449 r
.44675 .54891 m .44494 .55119 L .44637 .55219 L F
.44675 .54891 m .44755 .54779 L .44494 .55119 L F
.671 .812 .951 r
.29533 .67941 m .29722 .68113 L .29984 .67966 L F
.534 .31 .521 r
.3854 .47856 m .38503 .48183 L .38223 .48235 L F
.688 .446 .551 r
.38818 .48112 m .3854 .47856 L .38885 .4785 L F
.38818 .48112 m .38503 .48183 L .3854 .47856 L F
.988 .736 .36 r
.37591 .53759 m .37756 .53977 L .37974 .53916 L F
.892 .883 .818 r
.45284 .53234 m .44854 .53462 L .45111 .53104 L F
.874 .879 .836 r
.45552 .52894 m .45284 .53234 L .45111 .53104 L F
.961 .859 .694 r
.47025 .52406 m .4706 .52743 L .47102 .52541 L F
.812 .97 .902 r
.47025 .52406 m .47102 .52541 L .47473 .522 L F
.203 .041 .426 r
.27891 .53563 m .28061 .53731 L .28151 .53538 L F
.27891 .53563 m .27885 .53836 L .28061 .53731 L F
.587 .015 0 r
.28442 .67409 m .28857 .67648 L .28735 .67458 L F
.498 .707 .964 r
.28735 .67458 m .28857 .67648 L .29114 .67606 L F
0 0 0 r
.44024 .54452 m .44275 .5428 L .44396 .54126 L F
.44396 .54126 m .44275 .5428 L .44564 .54075 L F
.795 .535 .544 r
.53805 .34797 m .53388 .34994 L .53683 .34818 L F
.53805 .34797 m .53831 .35092 L .53388 .34994 L F
.529 .337 .565 r
.54094 .34748 m .53831 .35092 L .53805 .34797 L F
0 0 .405 r
.53935 .34815 m .53831 .35092 L .53805 .34797 L F
.53935 .34815 m .53805 .34797 L .53683 .34818 L F
.685 .976 .901 r
.54669 .41593 m .54813 .41521 L .54797 .41387 L F
.107 0 .385 r
.57934 .38587 m .57764 .38489 L .5798 .38438 L F
0 0 .341 r
.57962 .38425 m .5789 .38731 L .57934 .38587 L F
0 0 0 r
.5788 .38777 m .57753 .38973 L .57934 .38587 L F
0 0 .341 r
.5789 .38731 m .5788 .38777 L .57934 .38587 L F
.107 0 .385 r
.57934 .38587 m .5798 .38438 L .58049 .38421 L F
.57934 .38587 m .57776 .38723 L .57764 .38489 L F
.565 .59 .837 r
.30494 .55842 m .30083 .55563 L .30096 .55783 L F
.578 .425 .638 r
.49646 .41446 m .4937 .41797 L .49348 .41514 L F
.95 .799 .659 r
.38517 .57515 m .3869 .57715 L .3894 .57624 L F
.38517 .57515 m .38443 .57797 L .3869 .57715 L F
.889 .934 .84 r
.49781 .49878 m .49375 .50114 L .49458 .50179 L F
.468 .725 .981 r
.52294 .42224 m .52559 .4219 L .52108 .42017 L F
.588 .332 .496 r
.50809 .44812 m .50786 .45116 L .51052 .45065 L F
.78 .878 .919 r
.43104 .5574 m .42538 .55786 L .4279 .55687 L F
.43104 .5574 m .42724 .55905 L .42538 .55786 L F
.755 .955 .939 r
.43104 .5574 m .43147 .55471 L .43193 .55464 L F
.43104 .5574 m .4279 .55687 L .43147 .55471 L F
.251 .086 .453 r
.26923 .57467 m .2667 .57844 L .267 .57575 L F
.879 .943 .853 r
.51571 .47991 m .51584 .48277 L .51756 .48124 L F
.831 .945 .897 r
.51925 .47697 m .51756 .48124 L .52049 .47792 L F
.51925 .47697 m .51571 .47991 L .51756 .48124 L F
.426 0 0 r
.64552 .36922 m .6509 .3678 L .64971 .36944 L F
.766 .31 .164 r
.6509 .3678 m .65315 .36996 L .64971 .36944 L F
0 0 0 r
.47856 .42808 m .48198 .42566 L .48032 .42712 L F
.48032 .42712 m .48198 .42566 L .48417 .42425 L F
.199 .67 .938 r
.60768 .34297 m .60947 .343 L .61003 .34362 L F
.138 0 0 r
.60947 .343 m .61309 .34303 L .61003 .34362 L F
.487 .572 .867 r
.27534 .56103 m .27492 .56571 L .27305 .56159 L F
.27534 .56103 m .27739 .56513 L .27492 .56571 L F
.371 .134 .419 r
.27739 .56513 m .27459 .56833 L .27492 .56571 L F
0 .539 .796 r
.51589 .43947 m .51934 .44016 L .51893 .43865 L F
.753 .924 .947 r
.51934 .44016 m .52147 .43725 L .51893 .43865 L F
.51934 .44016 m .52286 .43837 L .52147 .43725 L F
.685 .544 .688 r
.30144 .55085 m .30388 .55263 L .30612 .54919 L F
.858 .961 .624 r
.51565 .41298 m .51543 .41508 L .51727 .41182 L F
.937 .67 .507 r
.51248 .41601 m .51543 .41508 L .51565 .41298 L F
.51248 .41601 m .51537 .41784 L .51543 .41508 L F
.492 .294 .539 r
.54344 .34377 m .54614 .34035 L .54348 .34089 L F
.847 .45 .29 r
.66937 .35286 m .67096 .35137 L .66902 .35007 L F
.66937 .35286 m .67163 .35356 L .67096 .35137 L F
.825 .505 .447 r
.31379 .52214 m .31373 .52457 L .31803 .52541 L F
.838 .617 .603 r
.31373 .52457 m .31776 .52831 L .31803 .52541 L F
.786 .568 .605 r
.31776 .52831 m .32032 .52875 L .31803 .52541 L F
.798 .317 0 r
.38917 .56493 m .38897 .56354 L .38701 .56323 L F
.38917 .56493 m .39062 .56566 L .38897 .56354 L F
.443 .572 .889 r
.25346 .60946 m .25196 .60581 L .25165 .60841 L F
.833 .851 .86 r
.25632 .6067 m .25346 .60946 L .25165 .60841 L F
.733 .455 .508 r
.37419 .5457 m .37421 .54848 L .377 .54608 L F
.885 .991 .786 r
.32505 .65247 m .32247 .65597 L .3215 .65556 L F
.153 0 .094 r
.40792 .46678 m .40661 .46526 L .40567 .46626 L F
.40792 .46678 m .40893 .46413 L .40661 .46526 L F
.88 .925 .849 r
.43713 .56173 m .44032 .55844 L .43874 .55734 L F
.817 .966 .902 r
.4433 .55525 m .43874 .55734 L .44032 .55844 L F
.99 .848 .605 r
.32743 .5568 m .32616 .56173 L .32755 .56253 L F
.954 .781 .63 r
.32493 .5641 m .32755 .56253 L .32616 .56173 L F
.32493 .5641 m .32686 .56537 L .32755 .56253 L F
.859 .733 .723 r
.32686 .5488 m .3264 .55224 L .32848 .55246 L F
.961 .797 .632 r
.32595 .55404 m .32848 .55246 L .3264 .55224 L F
.32595 .55404 m .32788 .55527 L .32848 .55246 L F
.684 .841 .959 r
.46197 .5339 m .45948 .53509 L .46365 .53532 L F
.829 .865 .872 r
.46197 .5339 m .46365 .53532 L .4667 .53233 L F
.693 .223 .13 r
.30675 .56653 m .30435 .56775 L .30178 .56547 L F
0 0 0 r
.30681 .567 m .30675 .56653 L .30882 .56553 L F
.30681 .567 m .30435 .56775 L .30675 .56653 L F
.874 .879 .836 r
.45552 .52894 m .45111 .53104 L .45415 .52791 L F
.894 .936 .835 r
.45552 .52894 m .45674 .52453 L .45852 .52594 L F
.45552 .52894 m .45415 .52791 L .45674 .52453 L F
.474 .591 .89 r
.24855 .59822 m .24841 .5955 L .24626 .59559 L F
.24855 .59822 m .25074 .59953 L .24841 .5955 L F
.773 .46 .457 r
.24855 .59822 m .25019 .6017 L .25074 .59953 L F
.25074 .59953 m .25019 .6017 L .24855 .59822 L F
0 0 .267 r
.58036 .36372 m .57953 .35857 L .57899 .36151 L F
.557 .006 0 r
.30096 .55783 m .30336 .55893 L .30494 .55842 L F
.326 .8 .916 r
.30336 .55893 m .30715 .55871 L .30494 .55842 L F
.77 .974 .698 r
.5589 .39726 m .55684 .39839 L .56012 .39469 L F
.674 .281 .293 r
.55766 .375 m .55782 .37691 L .55345 .3766 L F
.821 .589 .588 r
.56056 .37431 m .55782 .37691 L .55766 .375 L F
.806 .989 .882 r
.52918 .39039 m .53127 .38635 L .53013 .38821 L F
.668 .849 .969 r
.31526 .56164 m .31155 .5614 L .31348 .56065 L F
.826 .904 .894 r
.31852 .55874 m .31526 .56164 L .31348 .56065 L F
.253 0 0 r
.37136 .57197 m .36897 .57209 L .3669 .57181 L F
.37136 .57197 m .36897 .57209 L .3669 .57181 L F
.759 .297 .152 r
.37344 .57477 m .36897 .57209 L .37136 .57197 L F
.714 .371 .395 r
.37405 .57271 m .37344 .57477 L .37136 .57197 L F
0 0 0 r
.44333 .44178 m .43965 .44445 L .44197 .44343 L F
.44555 .44052 m .44333 .44178 L .44197 .44343 L F
.297 .345 .743 r
.25277 .5789 m .25373 .58341 L .25544 .58082 L F
0 0 .507 r
.25497 .58454 m .25544 .58082 L .25373 .58341 L F
.502 .505 .792 r
.53195 .40375 m .52981 .4052 L .52798 .40227 L F
.104 0 .192 r
.53195 .40375 m .52919 .40725 L .52981 .4052 L F
.923 .65 .506 r
.37746 .52447 m .37754 .52778 L .38076 .52833 L F
.864 .65 .611 r
.37666 .53015 m .38076 .52833 L .37754 .52778 L F
.37666 .53015 m .37919 .53146 L .38076 .52833 L F
.503 .867 .637 r
.39459 .56078 m .39613 .55973 L .39815 .55809 L F
.39459 .56078 m .39613 .55973 L .39815 .55809 L F
.451 .245 .508 r
.2595 .559 m .26169 .56114 L .26195 .55831 L F
.33 .239 .599 r
.25981 .56183 m .26169 .56114 L .2595 .559 L F
.515 0 0 r
.59167 .35456 m .59003 .35374 L .58687 .35167 L F
.58975 .3534 m .58687 .35167 L .58943 .35328 L F
0 .067 .589 r
.5861 .34973 m .58943 .35328 L .58687 .35167 L F
.816 .458 0 r
.58851 .352 m .58898 .3531 L .58943 .35328 L F
.58898 .3531 m .5901 .35574 L .58943 .35328 L F
.515 0 0 r
.59167 .35456 m .58975 .3534 L .58943 .35328 L F
.875 .816 .788 r
.5935 .35108 m .59167 .35456 L .58943 .35328 L F
.647 .265 .306 r
.43312 .50893 m .42901 .51047 L .42941 .50818 L F
.43312 .50893 m .43248 .51068 L .42901 .51047 L F
.397 .221 .523 r
.43582 .50501 m .43587 .50783 L .43312 .50893 L F
.197 0 .126 r
.43312 .50893 m .43587 .50783 L .43248 .51068 L F
0 0 0 r
.51164 .38502 m .5092 .38849 L .51036 .38692 L F
.03 0 .232 r
.50819 .39069 m .51036 .38692 L .5092 .38849 L F
.165 0 0 r
.54959 .37505 m .55138 .37486 L .55229 .3735 L F
0 0 0 r
.55229 .3735 m .55524 .37278 L .5562 .37334 L F
.55229 .3735 m .55138 .37486 L .55524 .37278 L F
.826 .818 .842 r
.51302 .39482 m .51402 .39812 L .5168 .39523 L F
.851 .744 .744 r
.53863 .427 m .54087 .43008 L .53791 .43102 L F
.488 .534 .831 r
.38138 .54497 m .38308 .54891 L .38563 .54706 L F
.077 0 0 r
.38308 .54891 m .38347 .55005 L .38563 .54706 L F
.38308 .54891 m .38106 .5505 L .38347 .55005 L F
.56 .252 .403 r
.60827 .35106 m .60513 .3533 L .60388 .35082 L F
.886 .934 .845 r
.52147 .43725 m .52286 .43837 L .52551 .43491 L F
0 0 .284 r
.25606 .57556 m .25781 .57172 L .25545 .57266 L F
.587 .083 .022 r
.33523 .61144 m .33952 .61172 L .33685 .61039 L F
.133 0 0 r
.50988 .39991 m .5076 .40045 L .50843 .39887 L F
.865 .788 .773 r
.32401 .57156 m .3214 .57519 L .32507 .57506 L F
.864 .789 .775 r
.3214 .57519 m .32268 .57876 L .32507 .57506 L F
.155 0 0 r
.47856 .42808 m .47736 .43017 L .47478 .43111 L F
.558 .827 .996 r
.62715 .34086 m .62586 .33953 L .62986 .34001 L F
.784 .899 .924 r
.60048 .39753 m .6044 .39683 L .60323 .39658 L F
.071 0 .059 r
.6044 .39683 m .60738 .394 L .60319 .39392 L F
.6044 .39683 m .6067 .39542 L .60738 .394 L F
.851 .864 .851 r
.31528 .58413 m .3202 .58208 L .31825 .58072 L F
.868 .864 .833 r
.31825 .58072 m .3202 .58208 L .32268 .57876 L F
.783 .774 .845 r
.53014 .47186 m .53126 .46714 L .52859 .47036 L F
.53014 .47186 m .53323 .46888 L .53126 .46714 L F
.921 .589 .394 r
.67163 .35356 m .67292 .35639 L .67409 .35485 L F
.954 .86 .445 r
.53782 .39218 m .53915 .39089 L .53834 .38944 L F
.53782 .39218 m .5382 .39496 L .53915 .39089 L F
.756 .297 .16 r
.52524 .40133 m .52755 .40323 L .52798 .40227 L F
.661 .424 .549 r
.52524 .40133 m .52755 .40323 L .52798 .40227 L F
.217 .192 .615 r
.53 .39943 m .52798 .40227 L .52827 .39802 L F
.604 .127 .095 r
.52755 .40323 m .53195 .40375 L .52798 .40227 L F
0 0 0 r
.53 .39943 m .52755 .40323 L .52798 .40227 L F
.389 .193 .489 r
.41505 .47235 m .4175 .47113 L .41518 .47488 L F
.555 .569 .823 r
.32471 .62197 m .32683 .62686 L .32901 .62542 L F
.739 .48 .537 r
.39015 .55193 m .38554 .5542 L .38711 .5522 L F
.891 .861 .804 r
.43538 .56308 m .43465 .56787 L .43568 .56572 L F
.883 .708 .659 r
.6458 .35831 m .64529 .36095 L .64366 .35698 L F
.715 .981 .907 r
.49356 .47019 m .49163 .47171 L .49267 .4696 L F
0 0 .05 r
.49163 .47171 m .49195 .47157 L .49267 .4696 L F
.49163 .47171 m .49152 .47448 L .49195 .47157 L F
.133 0 0 r
.50988 .39991 m .51033 .39986 L .5076 .40045 L F
.555 .434 .669 r
.64246 .34742 m .64271 .35117 L .63975 .35082 L F
.339 .203 .545 r
.64164 .35247 m .63975 .35082 L .64271 .35117 L F
.64164 .35247 m .64026 .3543 L .63975 .35082 L F
.375 .837 .777 r
.31722 .68457 m .32107 .68325 L .31988 .68543 L F
.328 0 0 r
.32107 .68325 m .3222 .68465 L .31988 .68543 L F
.32107 .68325 m .32423 .68371 L .3222 .68465 L F
.047 .416 .864 r
.29811 .63872 m .29851 .63757 L .29615 .63717 L F
.29811 .63872 m .3017 .64079 L .29851 .63757 L F
.76 .446 .454 r
.30946 .52414 m .31379 .52214 L .30952 .52125 L F
.30946 .52414 m .31373 .52457 L .31379 .52214 L F
.534 .796 .993 r
.32766 .63544 m .32516 .63612 L .32374 .63472 L F
.32766 .63544 m .32516 .63612 L .32374 .63472 L F
.517 .808 .998 r
.51451 .43813 m .51589 .43947 L .51893 .43865 L F
.367 .484 .846 r
.25074 .59953 m .25123 .59553 L .24841 .5955 L F
.25074 .59953 m .25368 .59986 L .25123 .59553 L F
.365 .034 .264 r
.25019 .6017 m .25368 .59986 L .25074 .59953 L F
.806 .751 .801 r
.29228 .55211 m .28856 .55222 L .29082 .54862 L F
.908 .902 .807 r
.29228 .55211 m .28772 .55437 L .28856 .55222 L F
.29228 .55211 m .28957 .55521 L .28772 .55437 L F
.763 .398 0 r
.29231 .5531 m .29228 .55211 L .29236 .55044 L F
.829 .995 .759 r
.66786 .37307 m .66749 .37252 L .66653 .37519 L F
.817 .997 .851 r
.66653 .37519 m .66749 .37252 L .66436 .37552 L F
0 0 0 r
.51375 .38124 m .51164 .38502 L .51311 .38301 L F
0 0 .041 r
.51375 .38124 m .51509 .37996 L .51562 .37738 L F
0 0 0 r
.51375 .38124 m .51311 .38301 L .51509 .37996 L F
.772 .745 .828 r
.3144 .63055 m .31702 .62957 L .31572 .62674 L F
.472 .076 .207 r
.31559 .6322 m .31702 .62957 L .3144 .63055 L F
.695 .613 .761 r
.25515 .60572 m .25632 .6067 L .25196 .60581 L F
.833 .851 .86 r
.25632 .6067 m .25165 .60841 L .25196 .60581 L F
.632 .735 .922 r
.25577 .60275 m .25889 .60543 L .25515 .60572 L F
.7 .748 .89 r
.25577 .60275 m .25632 .6067 L .25515 .60572 L F
.25577 .60275 m .25889 .60543 L .25632 .6067 L F
0 0 .298 r
.5088 .40224 m .5076 .40045 L .51033 .39986 L F
.414 .694 .978 r
.5102 .40532 m .50836 .40632 L .50787 .40615 L F
0 0 .298 r
.5088 .40224 m .50773 .40635 L .5076 .40045 L F
.50773 .40635 m .50772 .40636 L .5076 .40045 L F
.50773 .40635 m .50772 .40638 L .50772 .40636 L F
.848 .928 .882 r
.50704 .40585 m .50772 .40638 L .5088 .40224 L F
.414 .694 .978 r
.50822 .40565 m .50787 .40615 L .50704 .40585 L F
.746 .468 .51 r
.50836 .40632 m .51119 .4072 L .5115 .40385 L F
.414 .694 .978 r
.5102 .40532 m .50787 .40615 L .50822 .40565 L F
.404 .13 .381 r
.28008 .63907 m .28251 .63843 L .28243 .63604 L F
.187 0 .348 r
.28243 .63604 m .28437 .63737 L .2856 .63481 L F
.28243 .63604 m .28251 .63843 L .28437 .63737 L F
0 .225 .744 r
.34505 .64168 m .34404 .64222 L .34343 .64034 L F
.732 .655 .773 r
.34505 .64168 m .34263 .64476 L .34404 .64222 L F
.76 .98 .727 r
.5183 .40948 m .51727 .41182 L .51895 .40984 L F
.751 .95 .634 r
.51565 .41298 m .51727 .41182 L .5183 .40948 L F
.512 .875 .649 r
.59014 .40006 m .58844 .40159 L .5917 .39912 L F
.467 .751 .991 r
.58682 .40019 m .58844 .40159 L .59014 .40006 L F
.58682 .40019 m .58844 .40159 L .59014 .40006 L F
.86 .923 .869 r
.27557 .65519 m .27988 .65313 L .27954 .65175 L F
.97 .893 .524 r
.28088 .6482 m .27988 .65313 L .27954 .65175 L F
.596 .024 0 r
.27988 .65313 m .28026 .65433 L .27954 .65175 L F
.295 .311 .707 r
.27988 .65313 m .28086 .6559 L .2824 .6551 L F
.596 .024 0 r
.27988 .65313 m .2824 .6551 L .28026 .65433 L F
.024 .038 .535 r
.59899 .37924 m .59727 .38126 L .59717 .37677 L F
0 0 .198 r
.59886 .38122 m .59727 .38126 L .59899 .37924 L F
.59886 .38122 m .59698 .38363 L .59727 .38126 L F
.776 .483 .491 r
.2473 .60792 m .25165 .60841 L .25196 .60581 L F
.481 .821 .999 r
.25355 .60432 m .25515 .60572 L .25196 .60581 L F
0 0 .2 r
.25196 .60581 m .253 .60659 L .25355 .60432 L F
.25196 .60581 m .25165 .60841 L .253 .60659 L F
.952 .931 .739 r
.49075 .48189 m .48906 .48452 L .48947 .48087 L F
.884 .766 .726 r
.51674 .4554 m .51579 .45803 L .51456 .45381 L F
.867 .763 .746 r
.53126 .46714 m .53541 .46501 L .5336 .46392 L F
.53126 .46714 m .53323 .46888 L .53541 .46501 L F
.863 .84 .821 r
.5336 .46392 m .53541 .46501 L .53807 .46152 L F
.05 0 .029 r
.33605 .50887 m .33413 .51107 L .33695 .5093 L F
.388 .021 .215 r
.33695 .5093 m .33853 .50763 L .33605 .50887 L F
.837 .613 .6 r
.3102 .57916 m .30938 .58198 L .30729 .57792 L F
.815 .936 .569 r
.30663 .54828 m .30632 .54766 L .30832 .54528 L F
.30612 .54919 m .30632 .54766 L .30663 .54828 L F
.483 .817 .999 r
.30875 .54856 m .30632 .54766 L .30612 .54919 L F
.706 .172 0 r
.30875 .54856 m .30723 .54923 L .30632 .54766 L F
.951 .636 .397 r
.30723 .54923 m .30611 .54723 L .30632 .54766 L F
.963 .911 .714 r
.30856 .54264 m .30632 .54766 L .30531 .54582 L F
.951 .636 .397 r
.30611 .54723 m .30531 .54582 L .30632 .54766 L F
.822 .637 .652 r
.64565 .3507 m .64271 .35117 L .64246 .34742 L F
.952 .791 .646 r
.64565 .3507 m .64536 .34961 L .64271 .35117 L F
.854 .883 .859 r
.40453 .54849 m .4018 .54744 L .40326 .54777 L F
.515 0 0 r
.31424 .55571 m .31248 .55698 L .30982 .55548 L F
.898 .505 .267 r
.31424 .55571 m .31488 .55839 L .31248 .55698 L F
.253 .735 .931 r
.33257 .6757 m .33482 .67642 L .3359 .67591 L F
.777 .769 .846 r
.32995 .67906 m .32968 .68121 L .32673 .68193 L F
.754 .719 .82 r
.32673 .68193 m .32836 .68216 L .32955 .68127 L F
.581 .925 .726 r
.32955 .68127 m .32968 .68121 L .3297 .68116 L F
.023 0 0 r
.32673 .68193 m .32968 .68121 L .32955 .68127 L F
.028 0 0 r
.32995 .67906 m .3297 .68116 L .32968 .68121 L F
.754 .719 .82 r
.32673 .68193 m .32969 .68124 L .32995 .67906 L F
.32969 .68124 m .33073 .68099 L .32995 .67906 L F
.028 0 0 r
.32995 .67906 m .33003 .68009 L .3297 .68116 L F
.77 .687 .772 r
.32852 .68586 m .33138 .6826 L .32673 .68193 L F
.023 0 0 r
.32673 .68193 m .32955 .68127 L .32667 .68257 L F
.581 .925 .726 r
.32667 .68257 m .32955 .68127 L .33003 .68009 L F
.32955 .68127 m .3297 .68116 L .33003 .68009 L F
.754 .719 .82 r
.32955 .68127 m .33138 .6826 L .33073 .68099 L F
.32836 .68216 m .33138 .6826 L .32955 .68127 L F
.813 .746 .79 r
.32995 .67906 m .33138 .6826 L .3338 .67905 L F
.842 .833 .838 r
.33257 .6757 m .33244 .67782 L .32995 .67906 L F
.028 0 0 r
.32995 .67906 m .33244 .67782 L .3323 .67795 L F
.807 .768 .817 r
.32995 .67906 m .33131 .67906 L .3316 .67828 L F
0 0 .179 r
.33248 .67775 m .33244 .67782 L .33257 .6757 L F
.807 .768 .817 r
.33131 .67906 m .33248 .67775 L .33257 .6757 L F
.33248 .67775 m .33308 .67708 L .33257 .6757 L F
0 0 .179 r
.33308 .67672 m .33248 .67775 L .33257 .6757 L F
.028 0 0 r
.32995 .67906 m .3323 .67795 L .33003 .68009 L F
.807 .768 .817 r
.32995 .67906 m .3316 .67828 L .33257 .6757 L F
.597 .871 .544 r
.3323 .67795 m .33244 .67782 L .33248 .67775 L F
.807 .768 .817 r
.33131 .67906 m .3338 .67905 L .33308 .67708 L F
.597 .871 .544 r
.33133 .67887 m .3323 .67795 L .33256 .67761 L F
.3323 .67795 m .33248 .67775 L .33256 .67761 L F
.33003 .68009 m .33133 .67887 L .33308 .67672 L F
.33133 .67887 m .33256 .67761 L .33308 .67672 L F
.973 .812 .623 r
.3338 .67905 m .33482 .67642 L .33398 .67615 L F
.33308 .67708 m .33398 .67615 L .33257 .6757 L F
.3338 .67905 m .33398 .67615 L .33308 .67708 L F
.669 .569 .733 r
.51033 .39986 m .5115 .40385 L .51308 .40067 L F
.733 .456 .509 r
.5115 .40385 m .51528 .40719 L .51535 .40459 L F
.5115 .40385 m .51119 .4072 L .51528 .40719 L F
.875 .816 .788 r
.5935 .35108 m .58943 .35328 L .59023 .35016 L F
.269 .041 .372 r
.57961 .3479 m .58202 .34773 L .58328 .34876 L F
.57961 .3479 m .57986 .34978 L .58202 .34773 L F
.751 .797 .89 r
.34221 .51056 m .34665 .51188 L .34414 .51041 L F
.866 .6 .533 r
.34221 .51056 m .34654 .51466 L .34665 .51188 L F
0 0 0 r
.51036 .38692 m .51311 .38301 L .51164 .38502 L F
.89 .944 .84 r
.54389 .41915 m .54669 .41593 L .54429 .41557 L F
.699 .401 0 r
.30613 .53162 m .30607 .53167 L .305 .52798 L F
.781 .283 .011 r
.30613 .53162 m .30516 .53272 L .30607 .53167 L F
.30613 .53162 m .3081 .53429 L .30516 .53272 L F
.366 .127 .413 r
.51528 .40719 m .51803 .40386 L .51535 .40459 L F
.372 .008 .211 r
.60738 .394 m .6067 .39542 L .61016 .39355 L F
.969 .903 .699 r
.52847 .43692 m .52989 .43838 L .52865 .44003 L F
.821 .933 .905 r
.53173 .4363 m .52989 .43838 L .52847 .43692 L F
0 0 0 r
.53312 .43554 m .52989 .43838 L .53173 .4363 L F
.821 .589 .588 r
.56056 .37431 m .56183 .37792 L .55782 .37691 L F
.554 .772 .979 r
.62864 .34796 m .63144 .34728 L .62727 .34624 L F
.091 .573 .904 r
.30574 .63594 m .30708 .637 L .30441 .63606 L F
.743 .937 .95 r
.30783 .63391 m .30708 .637 L .30574 .63594 L F
.983 .703 .34 r
.37249 .54647 m .37421 .54848 L .37419 .5457 L F
.885 .892 .831 r
.53745 .38403 m .53542 .38458 L .53611 .38264 L F
.497 .838 .997 r
.53745 .38403 m .53974 .38208 L .54169 .3815 L F
.53745 .38403 m .53611 .38264 L .53974 .38208 L F
0 0 0 r
.30302 .64117 m .30507 .63911 L .30676 .63831 L F
.738 .299 .209 r
.30441 .63606 m .30676 .63831 L .30507 .63911 L F
.885 .991 .786 r
.32505 .65247 m .3215 .65556 L .32358 .65173 L F
.745 .978 .732 r
.2929 .6443 m .29523 .643 L .29233 .64596 L F
0 0 0 r
.29752 .64248 m .29523 .643 L .2929 .6443 L F
.102 .059 .519 r
.55931 .37079 m .56162 .36903 L .56159 .36634 L F
0 0 0 r
.55931 .37079 m .55895 .37249 L .56162 .36903 L F
.897 .574 .429 r
.3252 .54169 m .32518 .54441 L .32861 .54543 L F
.93 .8 .695 r
.32491 .54754 m .32861 .54543 L .32518 .54441 L F
.32491 .54754 m .32686 .5488 L .32861 .54543 L F
.512 .073 .141 r
.383 .47684 m .38562 .47715 L .38847 .47447 L F
.764 .996 .858 r
.53455 .4339 m .53312 .43554 L .53173 .4363 L F
.99 .753 .376 r
.56712 .35247 m .56572 .35135 L .56618 .35117 L F
.857 .988 .846 r
.56712 .35247 m .56834 .34925 L .56677 .35148 L F
.377 .527 .88 r
.567 .35161 m .56712 .35247 L .56677 .35148 L F
.857 .988 .846 r
.5673 .352 m .56697 .35143 L .56834 .34925 L F
0 .399 .818 r
.56824 .35177 m .5703 .35348 L .567 .35161 L F
.56692 .35151 m .567 .35161 L .56677 .35148 L F
.56824 .35177 m .567 .35161 L .56692 .35151 L F
.857 .988 .846 r
.56712 .35247 m .567 .35161 L .5673 .352 L F
.567 .35161 m .56697 .35143 L .5673 .352 L F
0 .399 .818 r
.56692 .35151 m .56677 .35148 L .56834 .34925 L F
.857 .988 .846 r
.56697 .35143 m .56685 .35058 L .56834 .34925 L F
0 .399 .818 r
.56824 .35177 m .56692 .35151 L .56834 .34925 L F
.377 .527 .88 r
.5703 .35348 m .56712 .35247 L .567 .35161 L F
.857 .988 .846 r
.56712 .35247 m .56618 .35117 L .56685 .35058 L F
.67 .857 .971 r
.64976 .38371 m .65333 .38411 L .65124 .38303 L F
.831 .699 .718 r
.65129 .38793 m .65333 .38411 L .64976 .38371 L F
.791 .922 .924 r
.65333 .38411 m .65543 .38016 L .65124 .38303 L F
.65333 .38411 m .65677 .38133 L .65543 .38016 L F
.81 .764 .811 r
.48723 .48798 m .48627 .48408 L .48833 .48594 L F
.796 .818 .869 r
.48906 .48452 m .48833 .48594 L .48627 .48408 L F
.848 .679 .143 r
.49832 .46162 m .49799 .4603 L .49807 .45753 L F
0 0 .017 r
.49832 .46162 m .49838 .46307 L .49799 .4603 L F
.49832 .46162 m .4981 .46513 L .49838 .46307 L F
.242 .445 .859 r
.58466 .34674 m .58328 .34876 L .58202 .34773 L F
.58466 .34674 m .5861 .34973 L .58328 .34876 L F
.863 .84 .821 r
.5336 .46392 m .53807 .46152 L .53667 .46026 L F
.826 .818 .842 r
.51302 .39482 m .5168 .39523 L .51536 .39285 L F
.609 .71 .917 r
.51536 .39285 m .5168 .39523 L .51944 .39433 L F
.71 .874 .958 r
.64679 .37357 m .645 .37688 L .64441 .3766 L F
.64679 .37357 m .64853 .37545 L .645 .37688 L F
.789 .556 .583 r
.31781 .53116 m .32032 .52875 L .31776 .52831 L F
.31781 .53116 m .32021 .53161 L .32032 .52875 L F
.88 .925 .849 r
.43713 .56173 m .43874 .55734 L .43681 .56126 L F
.739 .419 0 r
.391 .59115 m .39116 .59136 L .39013 .58875 L F
.676 .806 .945 r
.39013 .58875 m .39116 .59136 L .39385 .58942 L F
.452 .15 .362 r
.49807 .45753 m .50115 .45482 L .49956 .45561 L F
.751 .482 .524 r
.38169 .56423 m .38511 .56657 L .38662 .56365 L F
.566 .904 .978 r
.37638 .48142 m .37614 .4797 L .37805 .47861 L F
0 0 0 r
.37805 .47861 m .37861 .47889 L .38041 .47711 L F
.37805 .47861 m .37614 .4797 L .37861 .47889 L F
.589 .869 .545 r
.28342 .55491 m .28583 .55229 L .28502 .55456 L F
.487 .148 .316 r
.28583 .55229 m .28772 .55437 L .28502 .55456 L F
.404 .732 .991 r
.28502 .55315 m .28713 .55411 L .28502 .55456 L F
.28713 .55411 m .28772 .55437 L .28502 .55456 L F
.589 .869 .545 r
.28291 .55546 m .28342 .55491 L .28502 .55456 L F
.204 .712 .9 r
.28649 .55153 m .28583 .55229 L .28341 .54867 L F
.28649 .55153 m .28744 .55184 L .28583 .55229 L F
.487 .148 .316 r
.28583 .55229 m .28856 .55222 L .28772 .55437 L F
.912 .957 .807 r
.29082 .54862 m .28934 .55097 L .28649 .55153 L F
.28934 .55097 m .28856 .55222 L .28744 .55184 L F
.28934 .55097 m .28744 .55184 L .28649 .55153 L F
.3 .297 .689 r
.28546 .54587 m .28649 .55153 L .28341 .54867 L F
.912 .957 .807 r
.29082 .54862 m .28649 .55153 L .28915 .55009 L F
.564 .484 .723 r
.28915 .55009 m .28649 .55153 L .28546 .54587 L F
.619 .954 .804 r
.28727 .55148 m .28658 .55113 L .28527 .55283 L F
.28574 .55262 m .28527 .55283 L .28502 .55315 L F
.28727 .55148 m .28527 .55283 L .28574 .55262 L F
.28915 .55009 m .28703 .55094 L .28727 .55148 L F
.28703 .55094 m .28658 .55113 L .28727 .55148 L F
.204 .712 .9 r
.28744 .55184 m .28856 .55222 L .28762 .55224 L F
.28744 .55184 m .28762 .55224 L .28583 .55229 L F
.726 .985 .79 r
.34677 .66472 m .35112 .6618 L .34965 .66143 L F
.527 .887 .978 r
.63499 .35488 m .63731 .35537 L .64026 .3543 L F
.866 .95 .866 r
.25577 .60275 m .25515 .60572 L .25355 .60432 L F
.788 .809 .869 r
.42724 .55905 m .42294 .55923 L .42538 .55786 L F
.891 .548 .389 r
.65792 .34198 m .66119 .34121 L .65729 .34031 L F
.65792 .34198 m .66145 .34362 L .66119 .34121 L F
.247 0 0 r
.38498 .48274 m .38027 .48331 L .38223 .48235 L F
.315 0 .002 r
.38503 .48183 m .38498 .48274 L .38223 .48235 L F
.594 .364 .538 r
.53222 .4206 m .5295 .42311 L .52967 .41996 L F
.418 .017 .169 r
.39687 .47076 m .39946 .47063 L .4002 .46904 L F
.356 0 .19 r
.39946 .47063 m .40264 .46833 L .4002 .46904 L F
.52 .805 .998 r
.33575 .64459 m .33595 .64599 L .33374 .64554 L F
.935 .713 .577 r
.33561 .64581 m .33633 .64874 L .33595 .64599 L F
.713 .945 .646 r
.33895 .64198 m .33595 .64599 L .33575 .64459 L F
.564 .901 .662 r
.59014 .40006 m .5917 .39912 L .59362 .39745 L F
.743 .972 .928 r
.51584 .48277 m .51335 .4829 L .51113 .48464 L F
.879 .943 .853 r
.51571 .47991 m .51335 .4829 L .51584 .48277 L F
0 0 .316 r
.2856 .66847 m .28442 .67409 L .28667 .67362 L F
.465 .492 .802 r
.28442 .67409 m .28735 .67458 L .28667 .67362 L F
.84 .662 .661 r
.32332 .53807 m .3252 .54169 L .32611 .53917 L F
.867 .926 .863 r
.56183 .37792 m .55908 .38122 L .55802 .37968 L F
.326 .395 .781 r
.5591 .38389 m .55802 .37968 L .55908 .38122 L F
.469 .338 .619 r
.53435 .41202 m .53687 .41102 L .53688 .40741 L F
.085 .398 .854 r
.53435 .41202 m .53729 .41379 L .53687 .41102 L F
.909 .756 .679 r
.35692 .56155 m .35838 .56545 L .35633 .56415 L F
.888 .747 .7 r
.35838 .56545 m .35418 .56767 L .35633 .56415 L F
.35838 .56545 m .35655 .569 L .35418 .56767 L F
.89 .944 .84 r
.54389 .41915 m .54429 .41557 L .54195 .41658 L F
.806 .899 .908 r
.52106 .45078 m .51947 .44934 L .52028 .44724 L F
.52106 .45078 m .51901 .45204 L .51947 .44934 L F
.768 .812 .888 r
.52431 .44779 m .52106 .45078 L .52028 .44724 L F
.154 0 .071 r
.41801 .45966 m .42111 .4572 L .41892 .45843 L F
.595 .776 .966 r
.42292 .57801 m .42425 .57963 L .42407 .57804 L F
.74 .692 .805 r
.29233 .64596 m .2885 .6456 L .29053 .64514 L F
.745 .978 .732 r
.2929 .6443 m .29233 .64596 L .29053 .64514 L F
0 0 0 r
.45098 .44753 m .45401 .44439 L .45299 .4468 L F
.45401 .44439 m .45719 .44189 L .45607 .44398 L F
.45517 .44545 m .45401 .44439 L .45607 .44398 L F
.45517 .44545 m .45299 .4468 L .45401 .44439 L F
0 .168 .691 r
.55891 .39086 m .56094 .39307 L .55976 .39033 L F
.525 .377 .622 r
.27459 .56833 m .27251 .57189 L .27196 .5689 L F
.27459 .56833 m .27251 .57189 L .27196 .5689 L F
.534 .843 .999 r
.62986 .34001 m .63274 .33921 L .634 .34026 L F
.327 .75 .975 r
.63274 .33921 m .63676 .33991 L .634 .34026 L F
.933 .889 .765 r
.54824 .43883 m .54899 .43391 L .54771 .43661 L F
.938 .942 .768 r
.54704 .44069 m .54824 .43883 L .54771 .43661 L F
.889 .934 .84 r
.49781 .49878 m .49636 .49776 L .49375 .50114 L F
.878 .968 .846 r
.49781 .49878 m .49825 .49588 L .49636 .49776 L F
.49781 .49878 m .50074 .4955 L .49825 .49588 L F
.201 .276 .718 r
.54405 .38366 m .5419 .38678 L .54434 .38342 L F
.54405 .38366 m .54439 .38599 L .5419 .38678 L F
.588 .228 .326 r
.54439 .38599 m .54137 .38713 L .5419 .38678 L F
.894 .988 .775 r
.5658 .40818 m .56813 .40504 L .56595 .40562 L F
.678 .919 .6 r
.56937 .40297 m .56813 .40504 L .56966 .40303 L F
.698 .982 .824 r
.56595 .40562 m .56813 .40504 L .56937 .40297 L F
.913 .908 .803 r
.43097 .57048 m .43108 .57479 L .43465 .56787 L F
.178 .31 .762 r
.43097 .57048 m .43258 .57476 L .43108 .57479 L F
.865 .727 .708 r
.3456 .63568 m .34125 .63759 L .34282 .63581 L F
.869 .791 .771 r
.32055 .57764 m .32268 .57876 L .3214 .57519 L F
.868 .864 .833 r
.31825 .58072 m .32268 .57876 L .32055 .57764 L F
0 0 0 r
.32346 .62902 m .31966 .63197 L .32131 .6321 L F
.237 0 .14 r
.32547 .62809 m .32346 .62902 L .32131 .6321 L F
.76 .755 .848 r
.31132 .62592 m .31326 .63055 L .31572 .62674 L F
.772 .745 .828 r
.3144 .63055 m .31572 .62674 L .31326 .63055 L F
.911 .698 .601 r
.31323 .56867 m .31474 .57236 L .31238 .57074 L F
.707 .536 .655 r
.52518 .37173 m .52642 .37495 L .52349 .37309 L F
.795 .77 .83 r
.52431 .37022 m .52349 .37309 L .52518 .37173 L F
.644 .504 .678 r
.52518 .37173 m .52642 .37495 L .5284 .37335 L F
.207 .56 .935 r
.39542 .57219 m .39606 .57453 L .39361 .5736 L F
.39542 .57219 m .39817 .57503 L .39606 .57453 L F
.251 0 .313 r
.57633 .37223 m .57399 .37341 L .57425 .37131 L F
.614 .845 .469 r
.53898 .42055 m .53694 .42337 L .53893 .42345 L F
0 .04 .593 r
.53694 .42337 m .53917 .42669 L .53893 .42345 L F
.53694 .42337 m .53863 .427 L .53917 .42669 L F
.539 .914 .755 r
.49107 .40524 m .48775 .40739 L .48923 .40593 L F
.527 .881 .647 r
.48775 .40739 m .48594 .40852 L .48923 .40593 L F
.83 .741 .766 r
.51579 .45803 m .51205 .45741 L .51456 .45381 L F
.1 0 0 r
.34585 .50501 m .34408 .50699 L .34617 .50496 L F
.603 .856 .501 r
.30527 .57719 m .30554 .57659 L .30729 .57792 L F
.30527 .57719 m .30213 .58099 L .30554 .57659 L F
.093 0 0 r
.45607 .44398 m .45719 .44189 L .45964 .4408 L F
.829 .865 .872 r
.46197 .5339 m .4667 .53233 L .46582 .53117 L F
.829 .961 .895 r
.46582 .53117 m .4667 .53233 L .46862 .53051 L F
.647 .968 .842 r
.61646 .34206 m .61529 .34161 L .61788 .34126 L F
.359 .516 .877 r
.61788 .34126 m .61798 .34189 L .61549 .34246 L F
0 0 0 r
.61549 .34246 m .61538 .34267 L .61788 .34126 L F
.647 .968 .842 r
.61538 .34267 m .6153 .34179 L .61646 .34206 L F
.6153 .34179 m .61529 .34161 L .61646 .34206 L F
.248 .757 .866 r
.61785 .34239 m .61798 .34189 L .62076 .34229 L F
.61549 .34246 m .61684 .34215 L .61785 .34239 L F
.61684 .34215 m .61798 .34189 L .61785 .34239 L F
.744 .986 .901 r
.62076 .34229 m .62212 .33972 L .62322 .34096 L F
.62076 .34229 m .61798 .34189 L .62212 .33972 L F
.09 0 .402 r
.59876 .37374 m .59863 .37643 L .59717 .37677 L F
.024 .038 .535 r
.59899 .37924 m .59717 .37677 L .59863 .37643 L F
.924 .962 .781 r
.5018 .491 m .50074 .4955 L .50338 .49237 L F
.5018 .491 m .49965 .49457 L .50074 .4955 L F
.865 .974 .856 r
.50074 .4955 m .49965 .49457 L .49825 .49588 L F
.281 0 .073 r
.5125 .39941 m .5088 .40224 L .51033 .39986 L F
.652 .86 .979 r
.29925 .59033 m .30153 .59164 L .29669 .59149 L F
.8 .7 .755 r
.29669 .59149 m .30153 .59164 L .2984 .59556 L F
.252 .679 .963 r
.30351 .59147 m .30153 .59164 L .29925 .59033 L F
.533 .513 .779 r
.30519 .59533 m .30153 .59164 L .30351 .59147 L F
.902 .971 .812 r
.51901 .45204 m .51813 .4513 L .51947 .44934 L F
.472 .076 .207 r
.31559 .6322 m .3144 .63055 L .31213 .63338 L F
0 0 .356 r
.3669 .57181 m .36713 .5717 L .36673 .57079 L F
.807 .322 .041 r
.36897 .57209 m .36713 .5717 L .36717 .57185 L F
.36897 .57209 m .36758 .57303 L .36713 .5717 L F
.72 .738 .865 r
.36758 .57303 m .3671 .57158 L .36713 .5717 L F
.3671 .57158 m .36569 .56738 L .36713 .5717 L F
.807 .322 .041 r
.36717 .57185 m .36713 .5717 L .3669 .57181 L F
.97 .893 .524 r
.28088 .6482 m .27954 .65175 L .27993 .64861 L F
.587 .811 .985 r
.63763 .37939 m .63579 .38194 L .63428 .38102 L F
.63763 .37939 m .63902 .38091 L .63579 .38194 L F
.749 .705 .81 r
.29908 .58151 m .29543 .58202 L .29868 .5797 L F
.452 0 0 r
.29908 .58151 m .29815 .58284 L .29543 .58202 L F
.468 0 0 r
.30271 .58196 m .29815 .58284 L .29908 .58151 L F
.687 .782 .923 r
.39511 .54491 m .39389 .54639 L .39086 .5443 L F
.4 .744 .993 r
.30488 .67792 m .30663 .67918 L .30747 .67775 L F
.158 .437 .872 r
.30663 .67918 m .30975 .68086 L .30747 .67775 L F
.552 .848 .998 r
.41302 .58684 m .41232 .58872 L .41487 .58808 L F
.717 .985 .892 r
.41302 .58684 m .41122 .58843 L .41232 .58872 L F
.988 .729 .363 r
.41122 .58843 m .41221 .59166 L .41232 .58872 L F
.784 .636 .697 r
.41221 .59166 m .41487 .58808 L .41232 .58872 L F
.886 .934 .845 r
.52147 .43725 m .52551 .43491 L .52008 .43573 L F
.875 .702 .663 r
.3457 .63917 m .34343 .64034 L .34125 .63759 L F
.618 .218 .263 r
.3457 .63917 m .34505 .64168 L .34343 .64034 L F
.152 0 .013 r
.28794 .63477 m .2856 .63481 L .28437 .63737 L F
0 0 .283 r
.28086 .6559 m .28154 .6581 L .2824 .6551 L F
.28086 .6559 m .28095 .65846 L .28154 .6581 L F
.304 0 0 r
.30295 .6362 m .30441 .63606 L .30032 .63574 L F
.30295 .6362 m .30441 .63606 L .30032 .63574 L F
.753 .564 .64 r
.30441 .63606 m .30475 .6321 L .30295 .6362 L F
.091 .573 .904 r
.30574 .63594 m .30441 .63606 L .30295 .6362 L F
.133 .142 .602 r
.60253 .36291 m .60344 .36631 L .60145 .36774 L F
.81 .764 .811 r
.48723 .48798 m .483 .48763 L .48627 .48408 L F
.932 .809 .702 r
.48723 .48798 m .48355 .49022 L .483 .48763 L F
.48723 .48798 m .48544 .49176 L .48355 .49022 L F
.348 .247 .597 r
.33443 .64109 m .33188 .63941 L .33608 .63916 L F
.234 0 0 r
.33868 .63897 m .33443 .64109 L .33608 .63916 L F
.826 .904 .894 r
.31852 .55874 m .31348 .56065 L .31488 .55839 L F
.859 .839 .371 r
.56499 .41071 m .5658 .40818 L .56595 .40562 L F
0 0 0 r
.34224 .63077 m .3411 .63201 L .33993 .63034 L F
.56 .252 .403 r
.60827 .35106 m .60812 .35315 L .60513 .3533 L F
.543 .28 .466 r
.61071 .35038 m .60812 .35315 L .60827 .35106 L F
.528 .365 .604 r
.39176 .4797 m .38885 .4785 L .39146 .47865 L F
.455 .006 .093 r
.39146 .47865 m .39402 .47987 L .39176 .4797 L F
.918 .676 .556 r
.29851 .63757 m .3017 .64079 L .3 .64097 L F
.082 .242 .73 r
.29851 .63757 m .29965 .64016 L .30023 .63815 L F
.29965 .64016 m .3 .64097 L .30023 .63815 L F
.84 .989 .725 r
.29876 .63888 m .30032 .63782 L .30023 .63815 L F
.082 .242 .73 r
.29851 .63757 m .30023 .63815 L .30152 .637 L F
.84 .989 .725 r
.30032 .63782 m .30152 .637 L .30023 .63815 L F
.959 .699 .499 r
.3 .64097 m .29898 .64218 L .30023 .63815 L F
.04 .231 .732 r
.29892 .64356 m .29879 .6462 L .29752 .64248 L F
.29994 .64434 m .29881 .64617 L .29892 .64356 L F
.29881 .64617 m .29879 .6462 L .29892 .64356 L F
0 0 0 r
.29752 .64248 m .2929 .6443 L .29579 .64267 L F
.591 .018 0 r
.29994 .64434 m .29752 .64248 L .29579 .64267 L F
.959 .699 .499 r
.29898 .64218 m .29802 .64331 L .29903 .64095 L F
.29898 .64218 m .29903 .64095 L .30023 .63815 L F
.098 .314 .79 r
.30119 .64689 m .29879 .6462 L .29994 .64434 L F
.299 .791 .878 r
.63676 .33991 m .63957 .33934 L .6405 .33959 L F
.083 .643 .732 r
.63957 .33934 m .6437 .33904 L .6405 .33959 L F
.632 .842 .981 r
.3154 .54813 m .31304 .54928 L .31161 .5477 L F
.96 .881 .712 r
.31304 .54928 m .31161 .5477 L .3154 .54813 L F
.972 .904 .69 r
.38961 .56775 m .39062 .56566 L .38917 .56493 L F
.244 .695 .955 r
.35988 .57245 m .3592 .57072 L .35571 .57143 L F
.051 .595 .844 r
.36264 .57183 m .3592 .57072 L .35988 .57245 L F
.935 .713 .577 r
.33561 .64581 m .33523 .64914 L .33633 .64874 L F
.951 .794 .652 r
.33523 .64914 m .33483 .6523 L .33633 .64874 L F
0 0 0 r
.45299 .4468 m .44947 .44921 L .45098 .44753 L F
.28329 .55541 m .28291 .55546 L .28502 .55456 L F
.28329 .55541 m .2807 .55673 L .28291 .55546 L F
.941 .929 .763 r
.52391 .36646 m .52524 .36794 L .52644 .3641 L F
.963 .787 .616 r
.52253 .36887 m .52524 .36794 L .52391 .36646 L F
.52253 .36887 m .52431 .37022 L .52524 .36794 L F
.854 .63 .599 r
.35231 .54147 m .34932 .53792 L .35269 .53863 L F
.556 .417 .646 r
.64337 .37255 m .64004 .37045 L .6441 .37112 L F
.407 .485 .827 r
.64558 .36981 m .64693 .37002 L .6441 .37112 L F
0 0 0 r
.64693 .37002 m .64337 .37255 L .6441 .37112 L F
.813 .872 .89 r
.57331 .41998 m .57497 .42165 L .57664 .41916 L F
.051 0 0 r
.4937 .41797 m .49246 .42017 L .49049 .4205 L F
.236 0 0 r
.49639 .41735 m .49246 .42017 L .4937 .41797 L F
.556 .396 .619 r
.49646 .41446 m .49639 .41735 L .4937 .41797 L F
.947 .915 .751 r
.45985 .52418 m .45872 .52315 L .46125 .52229 L F
.811 .866 .888 r
.45985 .52418 m .45852 .52594 L .45674 .52453 L F
.564 .639 .884 r
.2506 .61141 m .25347 .61273 L .25159 .6101 L F
.767 .974 .92 r
.2506 .61141 m .25159 .6101 L .24897 .61181 L F
.782 .996 .867 r
.46156 .51828 m .46493 .51452 L .4668 .51599 L F
.833 .896 .884 r
.46798 .51401 m .4668 .51599 L .46493 .51452 L F
.409 .185 .459 r
.61391 .35214 m .61455 .3515 L .61538 .35234 L F
.543 .28 .466 r
.61071 .35038 m .61097 .35321 L .60812 .35315 L F
.409 .185 .459 r
.61391 .35214 m .61097 .35321 L .61071 .35038 L F
0 0 .048 r
.60944 .35375 m .60812 .35315 L .61097 .35321 L F
.744 .978 .732 r
.61188 .3516 m .60944 .35375 L .61097 .35321 L F
.409 .185 .459 r
.61263 .35144 m .61071 .35038 L .61362 .35123 L F
.744 .978 .732 r
.61247 .35055 m .61137 .35171 L .61188 .3516 L F
.61137 .35171 m .60944 .35375 L .61188 .3516 L F
.409 .185 .459 r
.61391 .35214 m .61263 .35144 L .61455 .3515 L F
.61263 .35144 m .61362 .35123 L .61455 .3515 L F
.857 .72 .711 r
.51808 .41941 m .51427 .41988 L .51702 .41903 L F
.51808 .41941 m .51733 .42209 L .51427 .41988 L F
0 .44 .724 r
.51702 .41903 m .52108 .42017 L .51808 .41941 L F
.817 .966 .902 r
.4433 .55525 m .44197 .55448 L .43874 .55734 L F
.853 .949 .879 r
.4433 .55525 m .44494 .55119 L .44197 .55448 L F
.4433 .55525 m .44637 .55219 L .44494 .55119 L F
.296 .679 .975 r
.39745 .59091 m .39824 .58997 L .39385 .58942 L F
.219 .63 .954 r
.39745 .59091 m .39939 .59 L .39824 .58997 L F
.39745 .59091 m .40094 .59135 L .39939 .59 L F
.639 .215 .223 r
.36366 .52412 m .36495 .52587 L .36802 .52349 L F
.602 .265 .372 r
.36495 .52587 m .37233 .52154 L .36802 .52349 L F
.287 .607 .954 r
.30975 .68086 m .31123 .68241 L .31236 .68115 L F
0 0 .54 r
.31236 .68115 m .31123 .68241 L .31289 .68528 L F
.893 .562 .414 r
.34061 .52459 m .33695 .52081 L .34083 .52181 L F
.847 .992 .846 r
.31215 .61809 m .31182 .62032 L .30821 .62141 L F
.31215 .61809 m .31354 .61847 L .31182 .62032 L F
.178 .359 .807 r
.25764 .59689 m .25781 .59926 L .25564 .59495 L F
.972 .923 .611 r
.25764 .59689 m .25577 .60275 L .25781 .59926 L F
.88 .709 .666 r
.42118 .57287 m .41877 .57471 L .41886 .57181 L F
.78 .59 .643 r
.30636 .58202 m .30213 .58472 L .30271 .58196 L F
.30636 .58202 m .30713 .5853 L .30213 .58472 L F
.617 .533 .737 r
.30729 .57792 m .30938 .58198 L .30636 .58202 L F
.617 .489 .683 r
.30938 .58198 m .30713 .5853 L .30636 .58202 L F
0 0 0 r
.38443 .57797 m .38412 .57808 L .3894 .57624 L F
.879 .945 .852 r
.39144 .57379 m .3894 .57624 L .39 .57284 L F
.963 .818 .651 r
.38517 .57515 m .38412 .57808 L .38443 .57797 L F
.834 .908 .889 r
.3894 .57624 m .38412 .57808 L .39 .57284 L F
.533 .309 .521 r
.26494 .55195 m .26719 .5543 L .26752 .55171 L F
.26494 .55195 m .26466 .55489 L .26719 .5543 L F
.533 .615 .88 r
.31461 .68481 m .3156 .68161 L .31289 .68528 L F
.31461 .68481 m .31722 .68457 L .3156 .68161 L F
.956 .94 .722 r
.54208 .44553 m .54465 .44455 L .54356 .44359 L F
.54208 .44553 m .54273 .44836 L .54465 .44455 L F
.928 .957 .778 r
.54356 .44359 m .54465 .44455 L .54704 .44069 L F
.795 .77 .83 r
.52431 .37022 m .52151 .37329 L .52349 .37309 L F
.532 .836 .516 r
.46016 .42988 m .45845 .43168 L .45692 .43318 L F
.928 .957 .778 r
.54356 .44359 m .54704 .44069 L .54651 .44033 L F
.938 .942 .768 r
.54704 .44069 m .54771 .43661 L .54651 .44033 L F
.968 .773 .589 r
.32595 .55404 m .32743 .5568 L .32788 .55527 L F
.753 .684 .785 r
.33865 .61673 m .34096 .61554 L .33787 .61526 L F
.965 .737 .297 r
.33865 .61316 m .33945 .61451 L .33952 .61172 L F
0 0 .35 r
.33885 .61348 m .33945 .61451 L .33865 .61316 L F
.44 .804 .995 r
.34001 .61545 m .34096 .61554 L .33945 .61451 L F
0 0 .35 r
.34062 .61628 m .33945 .61451 L .33885 .61348 L F
.44 .804 .995 r
.33787 .61526 m .34001 .61545 L .33945 .61451 L F
.99 .729 .413 r
.33945 .61451 m .34096 .61554 L .33952 .61172 L F
.89 .716 .66 r
.38721 .57763 m .38625 .58189 L .38443 .57797 L F
.94 .718 .574 r
.64366 .35698 m .64529 .36095 L .64334 .36039 L F
.657 .101 0 r
.64529 .36095 m .64439 .36162 L .64334 .36039 L F
.773 .266 0 r
.64529 .36095 m .64648 .36298 L .64439 .36162 L F
.868 .771 .753 r
.2999 .62179 m .30144 .62528 L .2976 .62557 L F
.718 .983 .901 r
.30144 .62528 m .29629 .62752 L .2976 .62557 L F
.726 .714 .839 r
.30438 .62263 m .30144 .62528 L .3006 .62338 L F
.30438 .62263 m .3006 .62338 L .30175 .62214 L F
.744 .689 .798 r
.30235 .62148 m .30438 .62263 L .2999 .62179 L F
.791 .899 .919 r
.3054 .61969 m .30438 .62263 L .30235 .62148 L F
.526 .92 .847 r
.3054 .61969 m .30235 .62148 L .30397 .62002 L F
0 0 0 r
.30397 .62002 m .30241 .62143 L .30084 .62358 L F
.30241 .62143 m .30235 .62148 L .30232 .62153 L F
.30241 .62143 m .30232 .62153 L .30084 .62358 L F
.726 .714 .839 r
.30175 .62214 m .3006 .62338 L .2999 .62179 L F
.165 0 0 r
.41398 .46234 m .41801 .45966 L .41559 .46057 L F
.843 .544 .484 r
.40982 .48164 m .40683 .48159 L .40759 .48149 L F
.40982 .48164 m .40961 .48437 L .40683 .48159 L F
.452 .263 .533 r
.41242 .47799 m .41234 .48115 L .40982 .48164 L F
.083 0 .338 r
.41123 .48277 m .40982 .48164 L .41234 .48115 L F
.41123 .48277 m .40961 .48437 L .40982 .48164 L F
.664 .453 .588 r
.3509 .51511 m .35455 .51722 L .35506 .51528 L F
.75 .575 .659 r
.35455 .51722 m .35773 .51518 L .35506 .51528 L F
.481 .28 .53 r
.30476 .65579 m .30499 .65877 L .30195 .65937 L F
.481 .279 .528 r
.30499 .65877 m .30437 .66155 L .30195 .65937 L F
.566 .904 .978 r
.37638 .48142 m .37379 .48145 L .37614 .4797 L F
.858 .432 .207 r
.37638 .48142 m .37394 .48188 L .37379 .48145 L F
.37638 .48142 m .37823 .48448 L .37394 .48188 L F
.862 .614 .562 r
.34315 .52518 m .33831 .52594 L .34061 .52459 L F
.34315 .52518 m .34299 .52786 L .33831 .52594 L F
0 0 0 r
.57444 .39645 m .5732 .3979 L .5759 .39436 L F
.57232 .3999 m .5732 .3979 L .57444 .39645 L F
.297 .617 .958 r
.30032 .63574 m .30295 .6362 L .30101 .63414 L F
.30032 .63574 m .30295 .6362 L .30101 .63414 L F
.596 .919 .972 r
.60998 .36489 m .60838 .36674 L .61113 .36683 L F
.60998 .36489 m .60694 .3662 L .60838 .36674 L F
.60998 .36489 m .60838 .36674 L .61113 .36683 L F
.60998 .36489 m .60694 .3662 L .60838 .36674 L F
.759 .536 .595 r
.34654 .51466 m .3507 .518 L .3509 .51511 L F
.664 .453 .588 r
.3509 .51511 m .3507 .518 L .35455 .51722 L F
.682 .19 0 r
.28197 .54213 m .28333 .54359 L .28392 .54395 L F
.915 .978 .712 r
.28505 .54464 m .28392 .54395 L .28452 .54559 L F
0 0 .005 r
.28546 .54587 m .28452 .54559 L .28392 .54395 L F
.682 .19 0 r
.28356 .54373 m .28546 .54587 L .28392 .54395 L F
.28363 .54391 m .28546 .54587 L .28356 .54373 L F
.915 .978 .712 r
.28664 .5418 m .28392 .54395 L .28505 .54464 L F
.682 .19 0 r
.28217 .54232 m .28546 .54587 L .28392 .54395 L F
.485 .231 .454 r
.27732 .54334 m .28247 .54273 L .28047 .5401 L F
.682 .19 0 r
.28197 .54213 m .28225 .54243 L .28217 .54232 L F
.398 .229 .532 r
.28247 .54273 m .2825 .54278 L .28256 .54272 L F
.682 .19 0 r
.28225 .54243 m .28228 .54246 L .28217 .54232 L F
.28228 .54246 m .28546 .54587 L .28221 .54236 L F
.28228 .54246 m .28221 .54236 L .28217 .54232 L F
.485 .231 .454 r
.28247 .54273 m .28256 .54272 L .28219 .54226 L F
.28217 .54232 m .28219 .54226 L .28164 .54158 L F
.28247 .54273 m .28219 .54226 L .28217 .54232 L F
.976 .794 .594 r
.28286 .54028 m .28392 .54395 L .28314 .53969 L F
.28197 .54213 m .28217 .54232 L .28286 .54028 L F
.28217 .54232 m .28392 .54395 L .28286 .54028 L F
.485 .231 .454 r
.28247 .54273 m .28164 .54158 L .28047 .5401 L F
.699 .174 0 r
.28047 .5401 m .28256 .54272 L .28197 .54213 L F
.398 .229 .532 r
.27732 .54334 m .27886 .54421 L .2825 .54278 L F
.27886 .54421 m .28176 .54342 L .2825 .54278 L F
.27732 .54334 m .2825 .54278 L .28247 .54273 L F
.591 .352 .522 r
.28256 .54272 m .28007 .54489 L .28281 .54437 L F
.28256 .54272 m .28281 .54437 L .28197 .54213 L F
.544 .357 .578 r
.28197 .54213 m .28239 .54325 L .2852 .54163 L F
.28239 .54325 m .28281 .54437 L .28423 .54275 L F
.28239 .54325 m .28423 .54275 L .2852 .54163 L F
.398 .229 .532 r
.27886 .54421 m .28007 .54489 L .28176 .54342 L F
.593 .438 .641 r
.28814 .54458 m .28546 .54587 L .28392 .54395 L F
.479 0 0 r
.28384 .54441 m .28572 .54528 L .28814 .54458 L F
.28281 .54437 m .28398 .54473 L .28384 .54441 L F
.28398 .54473 m .28572 .54528 L .28384 .54441 L F
.682 .19 0 r
.28333 .54359 m .28363 .54391 L .28356 .54373 L F
0 0 .005 r
.28546 .54587 m .28341 .54867 L .28452 .54559 L F
.885 .984 .816 r
.64829 .38987 m .64867 .39125 L .65129 .38793 L F
.111 .644 .865 r
.52008 .43573 m .51814 .43567 L .52147 .43725 L F
0 .355 .767 r
.51996 .4361 m .51814 .43567 L .51784 .43354 L F
.51996 .4361 m .52147 .43725 L .51814 .43567 L F
.715 .816 .928 r
.40221 .57513 m .39817 .57503 L .40082 .57439 L F
.625 .902 .985 r
.40221 .57513 m .40402 .57288 L .40442 .57394 L F
.40221 .57513 m .40082 .57439 L .40402 .57288 L F
0 .475 .78 r
.52052 .3884 m .52478 .38979 L .52164 .38904 L F
.8 .7 .755 r
.33647 .62003 m .33865 .61673 L .33787 .61526 L F
0 0 0 r
.39046 .47634 m .3911 .47577 L .39041 .47636 L F
.648 .899 .571 r
.3895 .47836 m .3911 .47577 L .3927 .47434 L F
0 0 0 r
.39358 .47493 m .3911 .47577 L .39046 .47634 L F
.648 .899 .571 r
.3927 .47434 m .3911 .47577 L .39284 .47416 L F
0 0 0 r
.29244 .63013 m .29203 .62956 L .29008 .63099 L F
.29244 .63013 m .29456 .62865 L .29203 .62956 L F
.341 0 .064 r
.26659 .58242 m .26416 .58256 L .26781 .58122 L F
.26659 .58242 m .26313 .58377 L .26416 .58256 L F
.597 .764 .959 r
.34263 .64476 m .34688 .64551 L .34469 .64697 L F
.667 .629 .802 r
.31155 .5614 m .30916 .56264 L .30715 .55871 L F
.582 .576 .811 r
.51522 .39327 m .51364 .39997 L .51302 .39482 L F
.898 .986 .779 r
.51376 .3973 m .51364 .39997 L .51509 .39383 L F
.51376 .3973 m .5125 .39941 L .51364 .39997 L F
.166 0 .022 r
.51425 .40051 m .51287 .39964 L .51376 .3973 L F
.51287 .39964 m .5125 .39941 L .51376 .3973 L F
.898 .986 .779 r
.51376 .3973 m .51509 .39383 L .51522 .39327 L F
.87 .599 .525 r
.43373 .50718 m .43582 .50501 L .43159 .50446 L F
.43373 .50718 m .43587 .50783 L .43582 .50501 L F
.182 0 0 r
.4298 .46166 m .43254 .46114 L .43254 .46139 L F
0 0 .414 r
.37555 .5508 m .37558 .55111 L .37421 .54848 L F
.37555 .5508 m .37611 .55213 L .37421 .54848 L F
.859 .416 .15 r
.37373 .55024 m .37555 .5508 L .37421 .54848 L F
.094 .624 .87 r
.37552 .55052 m .37555 .5508 L .37373 .55024 L F
.37635 .55066 m .37555 .5508 L .37552 .55052 L F
0 0 .414 r
.37555 .5508 m .37611 .55213 L .37558 .55111 L F
.036 .424 .866 r
.37635 .55066 m .37611 .55213 L .37555 .5508 L F
0 0 .221 r
.37785 .5521 m .37589 .55455 L .37611 .55213 L F
.37611 .55213 m .37589 .55455 L .37785 .5521 L F
.149 .216 .678 r
.57782 .39285 m .5759 .39436 L .5752 .39173 L F
0 0 0 r
.57444 .39645 m .5759 .39436 L .57782 .39285 L F
.214 .681 .943 r
.39013 .58875 m .38381 .58761 L .385 .58975 L F
.739 .419 0 r
.391 .59115 m .39013 .58875 L .385 .58975 L F
.956 .625 .348 r
.5258 .35755 m .52646 .36025 L .52419 .3587 L F
.386 .444 .799 r
.52747 .356 m .5258 .35755 L .52419 .3587 L F
.52747 .356 m .52646 .36025 L .5258 .35755 L F
.761 .799 .884 r
.29984 .67966 m .30288 .67891 L .29877 .67614 L F
.512 .749 .981 r
.29877 .67614 m .30288 .67891 L .30488 .67792 L F
.7 .87 .962 r
.65109 .37368 m .64853 .37545 L .64679 .37357 L F
.528 .365 .604 r
.39176 .4797 m .38818 .48112 L .38885 .4785 L F
.978 .917 .614 r
.56658 .38832 m .56601 .389 L .56778 .38809 L F
.766 .992 .785 r
.569 .38588 m .56658 .38832 L .56778 .38809 L F
.639 .434 .589 r
.56601 .389 m .569 .38588 L .56778 .38809 L F
.617 .954 .812 r
.53534 .39682 m .53595 .39575 L .53441 .39756 L F
.616 .952 .797 r
.53595 .39575 m .53238 .39805 L .53441 .39756 L F
.82 .708 .742 r
.29669 .59149 m .2984 .59556 L .29453 .59515 L F
.793 .443 .394 r
.29453 .59515 m .2984 .59556 L .29849 .59717 L F
.531 .239 .415 r
.29849 .59717 m .2984 .59556 L .30075 .59778 L F
.764 .631 .713 r
.29364 .54729 m .29753 .548 L .29562 .54662 L F
.525 .808 .998 r
.29546 .54776 m .29532 .54879 L .29364 .54729 L F
.29546 .54776 m .29753 .548 L .29532 .54879 L F
.764 .631 .713 r
.29364 .54729 m .29712 .54819 L .29753 .548 L F
.525 .808 .998 r
.29562 .54662 m .29753 .548 L .29546 .54776 L F
0 0 0 r
.29753 .548 m .29236 .55044 L .29532 .54879 L F
.764 .631 .713 r
.29546 .54776 m .29236 .55044 L .29712 .54819 L F
.29364 .54729 m .29354 .54754 L .29546 .54776 L F
.29354 .54754 m .29236 .55044 L .29546 .54776 L F
.525 .808 .998 r
.29562 .54662 m .29546 .54776 L .29364 .54729 L F
.704 .766 .901 r
.38625 .58189 m .38334 .58332 L .38175 .58147 L F
0 0 0 r
.49049 .4205 m .49127 .42112 L .48859 .42167 L F
.49049 .4205 m .49246 .42017 L .49127 .42112 L F
.566 .018 0 r
.51427 .41988 m .51733 .42209 L .51797 .42279 L F
0 0 .284 r
.25606 .57556 m .25746 .57456 L .25781 .57172 L F
.356 .07 .334 r
.25606 .57556 m .2575 .57731 L .25746 .57456 L F
.25606 .57556 m .25513 .57808 L .2575 .57731 L F
.334 .226 .579 r
.26003 .56477 m .26169 .56114 L .25981 .56183 L F
.575 .321 .494 r
.26752 .55171 m .27052 .55153 L .27108 .54887 L F
.373 .139 .425 r
.27108 .54887 m .27299 .55071 L .2732 .54786 L F
.27108 .54887 m .27052 .55153 L .27299 .55071 L F
.248 .012 .345 r
.57495 .3742 m .57133 .37428 L .57399 .37341 L F
.57495 .3742 m .57071 .37672 L .57133 .37428 L F
.9 .538 .347 r
.34903 .53499 m .34668 .53419 L .34644 .53169 L F
.871 .57 .476 r
.34903 .53499 m .34645 .53702 L .34668 .53419 L F
.34903 .53499 m .34932 .53792 L .34645 .53702 L F
.73 .64 .759 r
.38405 .54164 m .38901 .54187 L .3868 .5382 L F
.707 .459 .547 r
.38386 .54439 m .38901 .54187 L .38405 .54164 L F
.38386 .54439 m .38809 .54465 L .38901 .54187 L F
.587 .335 .502 r
.38809 .54465 m .39086 .5443 L .38901 .54187 L F
.554 .24 .391 r
.25911 .59235 m .25857 .59483 L .25564 .59495 L F
.452 .522 .839 r
.25795 .58953 m .26167 .5913 L .25911 .59235 L F
.23 0 .283 r
.26066 .5939 m .25911 .59235 L .26167 .5913 L F
.26066 .5939 m .25857 .59483 L .25911 .59235 L F
0 0 0 r
.40511 .54988 m .40327 .55372 L .40371 .55232 L F
.764 .98 .724 r
.52091 .40652 m .51895 .40984 L .52212 .40679 L F
.52091 .40652 m .5183 .40948 L .51895 .40984 L F
.925 .845 .745 r
.32493 .5641 m .32469 .56868 L .32686 .56537 L F
.364 0 0 r
.31701 .62021 m .31354 .61847 L .31215 .61809 L F
.149 .216 .678 r
.57782 .39285 m .5752 .39173 L .57753 .38973 L F
.829 .961 .895 r
.46582 .53117 m .46862 .53051 L .46726 .5292 L F
.893 .925 .834 r
.46726 .5292 m .46862 .53051 L .4706 .52743 L F
.8 .7 .755 r
.33647 .62003 m .33787 .61526 L .33503 .61892 L F
.938 .77 .648 r
.33391 .62174 m .33647 .62003 L .33503 .61892 L F
0 0 .1 r
.58036 .36372 m .58124 .36422 L .5804 .36205 L F
.685 .346 0 r
.5804 .36205 m .58124 .36422 L .5807 .36287 L F
0 0 .267 r
.58036 .36372 m .5804 .36205 L .57984 .3605 L F
.685 .346 0 r
.5804 .36205 m .5807 .36287 L .57919 .35909 L F
0 0 .267 r
.57984 .3605 m .5804 .36205 L .57953 .35857 L F
0 0 .1 r
.58036 .36372 m .57983 .36706 L .58124 .36422 L F
.876 .965 .851 r
.52191 .47368 m .52049 .47792 L .52372 .47515 L F
.52191 .47368 m .51925 .47697 L .52049 .47792 L F
.289 .575 .938 r
.3456 .63568 m .34662 .63403 L .34709 .63567 L F
.807 .745 .795 r
.35124 .64577 m .34853 .64908 L .34688 .64551 L F
.654 .965 .794 r
.41498 .56893 m .41596 .56731 L .41711 .56705 L F
.591 .935 .945 r
.41498 .56893 m .41335 .56856 L .41596 .56731 L F
.978 .876 .663 r
.34408 .50699 m .34414 .51041 L .34617 .50496 L F
.488 .372 .647 r
.27313 .65549 m .27582 .6523 L .27242 .65196 L F
.27313 .65549 m .27557 .65519 L .27582 .6523 L F
.367 .206 .527 r
.29556 .5657 m .29768 .56796 L .29779 .56458 L F
.29779 .56458 m .29768 .56796 L .29556 .5657 L F
.879 .95 .852 r
.31633 .63784 m .31521 .64167 L .31324 .64061 L F
.497 .311 .558 r
.6047 .35619 m .60126 .354 L .60513 .3533 L F
.6047 .35619 m .60174 .35708 L .60126 .354 L F
.005 0 0 r
.43258 .57476 m .42931 .57761 L .43055 .57581 L F
0 0 .082 r
.4442 .53422 m .44404 .53836 L .44286 .53766 L F
.812 .97 .902 r
.47025 .52406 m .47473 .522 L .4731 .52079 L F
.865 .912 .861 r
.47473 .522 m .47602 .51761 L .4731 .52079 L F
.47473 .522 m .47761 .51875 L .47602 .51761 L F
.724 .681 .808 r
.41487 .58808 m .41926 .58863 L .4177 .585 L F
.744 .62 .721 r
.41487 .58808 m .41683 .59237 L .41926 .58863 L F
.655 .856 .977 r
.50415 .42842 m .50349 .43108 L .5028 .43032 L F
.50415 .42842 m .50644 .43031 L .50349 .43108 L F
.562 .085 0 r
.5028 .43032 m .50349 .43108 L .50531 .43331 L F
.5 .144 .294 r
.50349 .43108 m .50644 .43031 L .50531 .43331 L F
.86 .577 .508 r
.34668 .53419 m .34331 .53045 L .34644 .53169 L F
.776 .747 .826 r
.31572 .62674 m .31989 .62624 L .31637 .6256 L F
.465 .825 .995 r
.31637 .6256 m .31989 .62624 L .32077 .6254 L F
.912 .926 .81 r
.45298 .54103 m .45176 .54559 L .45409 .54156 L F
.922 .975 .753 r
.45535 .53719 m .45409 .54156 L .45737 .53864 L F
.45535 .53719 m .45298 .54103 L .45409 .54156 L F
.867 .926 .863 r
.56183 .37792 m .55802 .37968 L .55782 .37691 L F
.593 .474 .686 r
.38171 .56166 m .37915 .56559 L .38169 .56423 L F
0 0 .311 r
.38017 .56605 m .37915 .56559 L .38169 .56423 L F
.593 .474 .686 r
.38169 .56423 m .37915 .56559 L .38171 .56166 L F
.699 .768 .278 r
.4981 .46513 m .49792 .46532 L .49838 .46307 L F
.4981 .46513 m .49713 .46775 L .49792 .46532 L F
.235 .567 .939 r
.25929 .60384 m .25889 .60543 L .25577 .60275 L F
.861 .835 .819 r
.25929 .60384 m .25915 .60875 L .25889 .60543 L F
0 0 .5 r
.5703 .35348 m .57159 .35567 L .57089 .35794 L F
.191 .415 .849 r
.57159 .35567 m .57411 .35947 L .57089 .35794 L F
.8 .769 .825 r
.37825 .5757 m .37624 .57918 L .37326 .57757 L F
.884 .695 .642 r
.37624 .57918 m .37489 .58154 L .37326 .57757 L F
.041 .305 .794 r
.34649 .62895 m .34909 .63068 L .34848 .63237 L F
.744 .938 .604 r
.34848 .63237 m .34909 .63068 L .34662 .63403 L F
.704 .245 .158 r
.60253 .34265 m .60532 .3433 L .60768 .34297 L F
.115 0 0 r
.60768 .34297 m .60532 .3433 L .60947 .343 L F
.885 .984 .816 r
.64829 .38987 m .65129 .38793 L .64902 .38824 L F
.831 .699 .718 r
.65129 .38793 m .64976 .38371 L .65093 .38483 L F
.935 .941 .773 r
.65093 .38483 m .64902 .38824 L .65129 .38793 L F
0 0 .157 r
.28997 .53676 m .28842 .54043 L .28664 .5418 L F
.303 0 0 r
.28726 .5433 m .28664 .5418 L .28842 .54043 L F
.28726 .5433 m .28392 .54395 L .28664 .5418 L F
.594 .944 .795 r
.29282 .5554 m .28772 .55437 L .28957 .55521 L F
.65 .967 .814 r
.29868 .5797 m .29543 .58202 L .29722 .5802 L F
.355 .377 .746 r
.29543 .58202 m .29815 .58284 L .29722 .5802 L F
.86 .868 .843 r
.32456 .60851 m .32596 .61116 L .32199 .61193 L F
.844 .897 .875 r
.32199 .61193 m .32596 .61116 L .32376 .61307 L F
.746 .828 .915 r
.3287 .60875 m .32596 .61116 L .32456 .60851 L F
.701 .963 .942 r
.30799 .58941 m .30969 .59008 L .31288 .5878 L F
0 0 0 r
.43088 .45119 m .43254 .45017 L .4341 .44847 L F
.4341 .44847 m .43503 .44916 L .43609 .44699 L F
.4341 .44847 m .43254 .45017 L .43503 .44916 L F
.489 .022 .071 r
.28238 .64798 m .28301 .64523 L .28119 .64554 L F
0 .104 .658 r
.28122 .64062 m .28301 .64523 L .28377 .64354 L F
.678 .753 .907 r
.33238 .60795 m .33255 .61007 L .3287 .60875 L F
0 0 .244 r
.33266 .60828 m .33255 .61007 L .33238 .60795 L F
.764 .913 .939 r
.52524 .40133 m .52415 .40036 L .5282 .39921 L F
.661 .424 .549 r
.52524 .40133 m .52526 .40437 L .52755 .40323 L F
.9 .514 .284 r
.66604 .34832 m .66753 .34711 L .66568 .34723 L F
.66604 .34832 m .66902 .35007 L .66753 .34711 L F
.633 .403 .552 r
.29031 .56216 m .29083 .56476 L .29332 .56173 L F
.603 .633 .854 r
.62022 .39306 m .62124 .39474 L .62378 .39329 L F
.805 .715 .765 r
.3488 .64147 m .35124 .64577 L .34893 .644 L F
.807 .745 .795 r
.35124 .64577 m .34688 .64551 L .34893 .644 L F
.554 .611 .864 r
.35376 .64513 m .35124 .64577 L .3488 .64147 L F
0 0 0 r
.59023 .35016 m .59192 .34864 L .59293 .34697 L F
.853 .974 .868 r
.58943 .35328 m .59192 .34864 L .59023 .35016 L F
.741 .969 .932 r
.32376 .61307 m .31907 .61487 L .32199 .61193 L F
.838 .617 .603 r
.31373 .52457 m .31346 .5275 L .31776 .52831 L F
.846 .583 .54 r
.31346 .5275 m .31781 .53116 L .31776 .52831 L F
.547 .831 .489 r
.41242 .47799 m .41518 .47488 L .41369 .47649 L F
0 0 0 r
.41246 .47823 m .41242 .47799 L .41369 .47649 L F
.41246 .47823 m .41234 .48115 L .41242 .47799 L F
.864 .477 .307 r
.35487 .52076 m .35917 .52463 L .35916 .5217 L F
.464 .295 .567 r
.35917 .52463 m .36246 .52495 L .35916 .5217 L F
.35917 .52463 m .36246 .52495 L .35916 .5217 L F
.93 .771 .663 r
.48078 .49141 m .48232 .4948 L .48055 .49341 L F
.909 .909 .809 r
.48232 .4948 m .47834 .49701 L .48055 .49341 L F
.48232 .4948 m .47987 .49829 L .47834 .49701 L F
.756 .719 .818 r
.48544 .49176 m .48232 .4948 L .48078 .49141 L F
.871 .552 .444 r
.31139 .53705 m .3081 .53429 L .31181 .53517 L F
.282 0 0 r
.49639 .41735 m .49952 .41759 L .49927 .41773 L F
0 0 0 r
.49927 .41773 m .49534 .4195 L .49639 .41735 L F
.57 .887 .613 r
.49979 .41673 m .49815 .41833 L .49927 .41773 L F
0 0 0 r
.49927 .41773 m .49797 .41851 L .49534 .4195 L F
.57 .887 .613 r
.49815 .41833 m .49797 .41851 L .49927 .41773 L F
.282 0 0 r
.49952 .41759 m .50054 .41767 L .49927 .41773 L F
.168 .7 .849 r
.50054 .41767 m .50163 .41714 L .49927 .41773 L F
.50054 .41767 m .50366 .41758 L .50163 .41714 L F
.804 .811 .857 r
.48906 .48452 m .48627 .48408 L .48947 .48087 L F
.828 .484 .404 r
.66165 .3458 m .66339 .34378 L .66145 .34362 L F
.66165 .3458 m .66568 .34723 L .66339 .34378 L F
.941 .928 .764 r
.54273 .44836 m .54006 .44909 L .54117 .45053 L F
.931 .942 .781 r
.54208 .44553 m .54006 .44909 L .54273 .44836 L F
.722 .25 .127 r
.35453 .63945 m .35619 .6394 L .35216 .63817 L F
.784 .636 .697 r
.41221 .59166 m .41683 .59237 L .41487 .58808 L F
.769 .688 .774 r
.41282 .59362 m .41683 .59237 L .41221 .59166 L F
.746 .353 0 r
.54302 .40533 m .54289 .4041 L .54075 .40519 L F
.54302 .40533 m .54383 .40618 L .54289 .4041 L F
.935 .757 .637 r
.35766 .55878 m .35692 .56155 L .35543 .5577 L F
0 0 0 r
.42718 .45414 m .42931 .45282 L .43088 .45119 L F
.43088 .45119 m .43178 .45184 L .43254 .45017 L F
.43088 .45119 m .42931 .45282 L .43178 .45184 L F
0 0 .352 r
.39242 .47423 m .39284 .47416 L .39302 .47194 L F
.327 .033 .304 r
.39302 .47194 m .39534 .47324 L .39687 .47076 L F
.39302 .47194 m .39284 .47416 L .39534 .47324 L F
.937 .641 .179 r
.28008 .63907 m .28122 .64062 L .28251 .63843 L F
.28008 .63907 m .28026 .64035 L .28122 .64062 L F
.716 .98 .776 r
.49107 .40524 m .49215 .40334 L .49324 .40359 L F
.49107 .40524 m .48923 .40593 L .49215 .40334 L F
.911 .711 .619 r
.31238 .57074 m .31046 .56699 L .31323 .56867 L F
0 0 0 r
.46555 .4375 m .46908 .43438 L .46782 .43623 L F
.46782 .43623 m .46908 .43438 L .47127 .43306 L F
.297 .345 .743 r
.25277 .5789 m .25544 .58082 L .25513 .57808 L F
.328 .778 .956 r
.54831 .40271 m .55231 .40305 L .54982 .40336 L F
.758 .504 .549 r
.30713 .5853 m .30188 .5876 L .30213 .58472 L F
.30713 .5853 m .30684 .5884 L .30188 .5876 L F
.383 .223 .537 r
.33413 .51107 m .33445 .51443 L .33695 .5093 L F
.193 0 .086 r
.26313 .58377 m .2599 .58691 L .26101 .585 L F
.702 .848 .422 r
.2885 .6456 m .29058 .64173 L .29053 .64514 L F
0 0 .173 r
.46156 .51828 m .46187 .52021 L .46072 .51788 L F
.782 .996 .867 r
.46156 .51828 m .46072 .51788 L .46493 .51452 L F
.889 .734 .683 r
.47718 .50162 m .47326 .50408 L .47494 .50022 L F
.47718 .50162 m .47632 .50397 L .47326 .50408 L F
.841 .8 .812 r
.47987 .49829 m .47718 .50162 L .47494 .50022 L F
.824 .767 .799 r
.47086 .51032 m .4698 .51236 L .46722 .51049 L F
.847 .759 .766 r
.4698 .51236 m .46798 .51401 L .46722 .51049 L F
.869 .649 .602 r
.35622 .55195 m .3531 .55376 L .3538 .55091 L F
.35622 .55195 m .35573 .55474 L .3531 .55376 L F
.563 .594 .842 r
.31531 .65725 m .31589 .65996 L .31476 .65805 L F
0 0 0 r
.31476 .65805 m .31675 .65553 L .31531 .65725 L F
.563 .594 .842 r
.31531 .65725 m .31862 .65915 L .31589 .65996 L F
.809 .371 .202 r
.56908 .37904 m .571 .38214 L .57292 .38048 L F
.197 0 0 r
.57292 .38048 m .57413 .38148 L .57577 .38081 L F
.57292 .38048 m .571 .38214 L .57413 .38148 L F
.895 .671 .591 r
.32332 .53807 m .323 .54106 L .3252 .54169 L F
.816 .499 .452 r
.3232 .54372 m .3252 .54169 L .323 .54106 L F
.3232 .54372 m .32518 .54441 L .3252 .54169 L F
.841 .8 .812 r
.47987 .49829 m .47494 .50022 L .47834 .49701 L F
.452 .15 .362 r
.49807 .45753 m .50101 .45693 L .50115 .45482 L F
.66 .392 .504 r
.50101 .45693 m .50502 .45404 L .50115 .45482 L F
0 .245 .681 r
.30982 .55548 m .31085 .55575 L .30958 .55428 L F
.30982 .55548 m .31248 .55698 L .31085 .55575 L F
.492 .399 .678 r
.51171 .43818 m .51451 .43813 L .51462 .43479 L F
.75 .575 .659 r
.35455 .51722 m .35724 .51759 L .35773 .51518 L F
.972 .904 .69 r
.38961 .56775 m .38917 .56493 L .38753 .56672 L F
.872 .629 .568 r
.35469 .54514 m .35439 .54809 L .35208 .54429 L F
.839 .889 .876 r
.5018 .491 m .50338 .49237 L .50512 .49074 L F
.319 .114 .437 r
.27361 .54513 m .27531 .54705 L .27541 .54419 L F
.27361 .54513 m .2732 .54786 L .27531 .54705 L F
0 0 .097 r
.58551 .39085 m .58633 .39113 L .58709 .38818 L F
.58551 .39085 m .58517 .39349 L .58633 .39113 L F
.375 .048 .277 r
.63455 .37725 m .63732 .37649 L .63736 .37497 L F
.63736 .37497 m .63732 .37649 L .63455 .37725 L F
0 0 0 r
.64004 .37045 m .63736 .37497 L .63935 .37176 L F
.187 0 .248 r
.63736 .37497 m .64047 .37439 L .63935 .37176 L F
.63736 .37497 m .63732 .37649 L .64047 .37439 L F
.289 0 0 r
.39775 .47222 m .39687 .47076 L .39534 .47324 L F
.39775 .47222 m .39946 .47063 L .39687 .47076 L F
.531 .099 .164 r
.39834 .47779 m .39669 .47993 L .39402 .47987 L F
.418 0 .093 r
.39987 .47947 m .39834 .47779 L .40104 .47762 L F
.39987 .47947 m .39669 .47993 L .39834 .47779 L F
.791 .39 .293 r
.38385 .5876 m .38143 .58732 L .38333 .58529 L F
.852 .992 .839 r
.4808 .513 m .48028 .51547 L .48198 .51384 L F
.93 .971 .737 r
.48304 .50929 m .48198 .51384 L .48478 .51039 L F
.48304 .50929 m .4808 .513 L .48198 .51384 L F
0 0 .425 r
.574 .3646 m .57309 .36416 L .57362 .36171 L F
.574 .3646 m .57442 .36652 L .57309 .36416 L F
.722 .983 .904 r
.49356 .47019 m .49614 .46725 L .49713 .46775 L F
.49356 .47019 m .49267 .4696 L .49614 .46725 L F
.574 .371 .568 r
.3067 .5243 m .30952 .52125 L .30691 .52172 L F
.702 .634 .778 r
.50836 .40632 m .50613 .41127 L .50445 .40695 L F
.45 0 .053 r
.38818 .48112 m .38498 .48274 L .38503 .48183 L F
.38818 .48112 m .38703 .48298 L .38498 .48274 L F
.413 .026 .192 r
.39176 .4797 m .38703 .48298 L .38818 .48112 L F
.451 .513 .831 r
.33575 .64459 m .33374 .64554 L .3325 .64213 L F
.75 .955 .649 r
.30178 .56547 m .29933 .56852 L .29779 .56458 L F
.30178 .56547 m .29977 .5671 L .29933 .56852 L F
.689 .232 .162 r
.30178 .56547 m .30435 .56775 L .29977 .5671 L F
.985 .742 .482 r
.29779 .56458 m .29768 .56796 L .29933 .56852 L F
.575 .907 .977 r
.29977 .5671 m .29768 .56796 L .29933 .56852 L F
0 0 0 r
.30075 .59778 m .30519 .59533 L .30271 .59561 L F
0 .224 .735 r
.30595 .59368 m .30519 .59533 L .30351 .59147 L F
.661 .971 .897 r
.30271 .59561 m .30519 .59533 L .30595 .59368 L F
0 0 0 r
.50819 .39069 m .50571 .39422 L .50697 .39286 L F
.355 .792 .619 r
.50571 .39422 m .50615 .39395 L .50697 .39286 L F
.50571 .39422 m .50394 .39522 L .50615 .39395 L F
.817 .769 .808 r
.56646 .35696 m .56276 .35632 L .56572 .35135 L F
.87 .905 .494 r
.56382 .36265 m .56386 .36128 L .56408 .36067 L F
0 .302 .781 r
.56543 .35848 m .56276 .35632 L .56638 .35695 L F
.5629 .35643 m .56522 .35756 L .56276 .35632 L F
.56554 .35857 m .56522 .35756 L .5629 .35643 L F
.56554 .35857 m .56543 .35848 L .56646 .35696 L F
.482 .235 .463 r
.56494 .3597 m .56651 .35818 L .56522 .35756 L F
0 .302 .781 r
.56543 .35848 m .56638 .35695 L .56646 .35696 L F
.482 .235 .463 r
.56651 .35818 m .56808 .35666 L .56522 .35756 L F
.87 .905 .494 r
.56459 .35985 m .56408 .36067 L .56522 .35756 L F
.833 .683 .696 r
.56142 .36266 m .56343 .36097 L .56386 .36128 L F
.87 .905 .494 r
.56414 .36149 m .56408 .36067 L .56459 .35985 L F
.56382 .36265 m .56522 .35756 L .56554 .35857 L F
0 0 .126 r
.56522 .35756 m .56386 .36128 L .56494 .3597 L F
.833 .683 .696 r
.56343 .36097 m .56494 .3597 L .56386 .36128 L F
.87 .905 .494 r
.56382 .36265 m .56399 .36138 L .56414 .36149 L F
.56399 .36138 m .56408 .36067 L .56414 .36149 L F
.451 .628 .929 r
.50745 .41695 m .51192 .41929 L .51028 .41757 L F
.411 .486 .827 r
.51192 .41929 m .51248 .41601 L .51028 .41757 L F
.51192 .41929 m .51427 .41988 L .51248 .41601 L F
.88 .909 .845 r
.47602 .51761 m .47761 .51875 L .48028 .51547 L F
.41 0 .033 r
.31529 .64502 m .31854 .64369 L .31863 .6455 L F
0 .425 .795 r
.31854 .64369 m .32258 .6453 L .32033 .644 L F
.31854 .64369 m .32033 .644 L .31863 .6455 L F
.554 .611 .864 r
.35376 .64513 m .3488 .64147 L .35422 .64208 L F
.821 .933 .905 r
.53173 .4363 m .52847 .43692 L .53093 .43414 L F
.806 .98 .897 r
.53368 .43294 m .53173 .4363 L .53093 .43414 L F
.53368 .43294 m .53455 .4339 L .53173 .4363 L F
0 0 .23 r
.59376 .38983 m .59246 .39103 L .59397 .38743 L F
0 0 .422 r
.59429 .39161 m .59246 .39103 L .59376 .38983 L F
.59429 .39161 m .59278 .39333 L .59246 .39103 L F
0 0 0 r
.30096 .55783 m .29836 .56014 L .30032 .55851 L F
.956 .898 .727 r
.35668 .64717 m .35817 .64566 L .35665 .64466 L F
.755 .758 .855 r
.28119 .64554 m .28122 .64062 L .28026 .64035 L F
.489 .022 .071 r
.28238 .64798 m .28119 .64554 L .27993 .64861 L F
.671 .812 .951 r
.29533 .67941 m .29984 .67966 L .29766 .67844 L F
.761 .799 .884 r
.29984 .67966 m .29877 .67614 L .29766 .67844 L F
.247 0 0 r
.53831 .35092 m .53424 .35309 L .53388 .34994 L F
.53831 .35092 m .53719 .35252 L .53424 .35309 L F
.39 .186 .478 r
.53935 .34815 m .53719 .35252 L .53831 .35092 L F
.098 0 .098 r
.40264 .46833 m .40437 .46872 L .40567 .46626 L F
.144 0 0 r
.40567 .46626 m .40685 .46783 L .40792 .46678 L F
.40567 .46626 m .40437 .46872 L .40685 .46783 L F
.752 .986 .902 r
.65809 .37886 m .65677 .38133 L .65895 .3795 L F
.664 .886 .979 r
.65543 .38016 m .65677 .38133 L .65809 .37886 L F
.518 .404 .664 r
.38308 .56848 m .38566 .56787 L .38511 .56657 L F
.39 .763 .992 r
.50327 .40625 m .50704 .40585 L .50445 .40695 L F
.201 0 0 r
.29722 .5802 m .30062 .57802 L .29868 .5797 L F
.983 .702 .401 r
.5078 .4541 m .50804 .45767 L .50934 .45861 L F
.622 .866 .989 r
.50934 .45861 m .5107 .45634 L .51205 .45741 L F
.50934 .45861 m .50804 .45767 L .5107 .45634 L F
.572 .713 .938 r
.50737 .42611 m .50644 .43031 L .50415 .42842 L F
.50737 .42611 m .50954 .42942 L .50644 .43031 L F
.374 .067 .31 r
.50644 .43031 m .50801 .43179 L .50531 .43331 L F
.50644 .43031 m .50954 .42942 L .50801 .43179 L F
0 0 0 r
.43848 .45745 m .44151 .45415 L .44033 .45595 L F
.011 0 0 r
.44275 .45486 m .44151 .45415 L .44418 .4533 L F
.44275 .45486 m .44033 .45595 L .44151 .45415 L F
.832 .897 .886 r
.50357 .48942 m .5018 .491 L .50512 .49074 L F
.854 .897 .865 r
.50357 .48942 m .50512 .49074 L .50802 .48753 L F
0 0 .051 r
.42335 .465 m .42267 .46687 L .42082 .46842 L F
.08 0 0 r
.4257 .46449 m .42267 .46687 L .42335 .465 L F
.9 .965 .645 r
.305 .52798 m .30455 .52725 L .3067 .5243 L F
.809 .435 0 r
.305 .52798 m .30607 .53167 L .30526 .53008 L F
.973 .891 .685 r
.30516 .53272 m .30484 .5299 L .30607 .53167 L F
.30484 .5299 m .30474 .52902 L .30526 .53008 L F
.30484 .5299 m .30526 .53008 L .30607 .53167 L F
.677 .482 .614 r
.30568 .53112 m .3088 .53242 L .30873 .5315 L F
.30653 .53059 m .30873 .5315 L .30857 .52933 L F
.30568 .53112 m .30873 .5315 L .30653 .53059 L F
.973 .891 .685 r
.30516 .53272 m .30378 .53229 L .30474 .52902 L F
.677 .482 .614 r
.30378 .53229 m .30618 .53235 L .30568 .53112 L F
.30618 .53235 m .3088 .53242 L .30568 .53112 L F
.809 .435 0 r
.30478 .52886 m .30526 .53008 L .30474 .52902 L F
.305 .52798 m .30526 .53008 L .30478 .52886 L F
.192 0 .256 r
.38405 .54164 m .38138 .54497 L .38386 .54439 L F
.802 .758 .812 r
.38284 .53795 m .38405 .54164 L .3868 .5382 L F
.215 .135 .545 r
.53688 .40741 m .53897 .40895 L .5389 .40645 L F
.53688 .40741 m .53687 .41102 L .53897 .40895 L F
.928 .715 .595 r
.51427 .41988 m .51537 .41784 L .51248 .41601 L F
.376 .056 .29 r
.51702 .41903 m .51537 .41784 L .51427 .41988 L F
.826 .521 .475 r
.30475 .6321 m .30101 .63414 L .30295 .6362 L F
.30475 .6321 m .30574 .63594 L .30101 .63414 L F
0 0 0 r
.3072 .63048 m .30475 .6321 L .30819 .62838 L F
.349 .232 .576 r
.30783 .63391 m .30475 .6321 L .3072 .63048 L F
.30783 .63391 m .30574 .63594 L .30475 .6321 L F
.251 .086 .453 r
.26923 .57467 m .26868 .5782 L .2667 .57844 L F
.277 .222 .614 r
.26868 .5782 m .26886 .58091 L .2667 .57844 L F
.087 .176 .662 r
.2667 .57844 m .26886 .58091 L .26781 .58122 L F
.944 .69 .524 r
.33531 .61366 m .33787 .61526 L .33523 .61144 L F
.909 .778 .705 r
.33503 .61892 m .33787 .61526 L .33531 .61366 L F
.434 .743 .992 r
.33531 .61366 m .33787 .61526 L .33945 .61451 L F
.902 .775 .711 r
.32312 .55067 m .3264 .55224 L .32686 .5488 L F
.875 .65 .595 r
.32312 .55067 m .32595 .55404 L .3264 .55224 L F
.348 .247 .597 r
.33443 .64109 m .3325 .64213 L .33188 .63941 L F
0 0 0 r
.47436 .41912 m .47595 .41763 L .47253 .42047 L F
.47859 .41432 m .47595 .41763 L .4776 .416 L F
.503 .826 .521 r
.4776 .416 m .47595 .41763 L .47436 .41912 L F
0 0 0 r
.50366 .41758 m .50745 .41695 L .50613 .41724 L F
0 .454 .713 r
.50745 .41695 m .50813 .41702 L .50613 .41724 L F
.50745 .41695 m .51028 .41757 L .50813 .41702 L F
.926 .942 .593 r
.52253 .36887 m .52151 .37329 L .52431 .37022 L F
.52253 .36887 m .5208 .37271 L .52151 .37329 L F
0 0 0 r
.5807 .37126 m .57907 .37168 L .57633 .37223 L F
.917 .539 .12 r
.57858 .36992 m .57907 .37168 L .5807 .37126 L F
.195 0 .228 r
.27623 .54195 m .27541 .54419 L .27826 .541 L F
.677 .432 .543 r
.27251 .57189 m .27194 .57471 L .26923 .57467 L F
0 0 0 r
.2744 .56897 m .27251 .57189 L .27459 .56833 L F
.119 0 .339 r
.27346 .57343 m .27251 .57189 L .2744 .56897 L F
.27346 .57343 m .27194 .57471 L .27251 .57189 L F
.984 .833 .442 r
.5589 .41887 m .55926 .41742 L .55844 .41636 L F
.911 .976 .786 r
.55844 .41636 m .55926 .41742 L .56173 .41381 L F
.03 0 .232 r
.50819 .39069 m .5108 .38891 L .51036 .38692 L F
0 0 0 r
.50697 .39286 m .5108 .38891 L .50819 .39069 L F
.53782 .39218 m .53534 .39682 L .5382 .39496 L F
.412 .46 .8 r
.52196 .37882 m .52035 .38171 L .51929 .38023 L F
.52196 .37882 m .52344 .38327 L .52035 .38171 L F
.502 .43 .707 r
.52344 .38327 m .52111 .38467 L .52035 .38171 L F
.715 .427 .487 r
.37233 .52154 m .37323 .52352 L .37327 .52145 L F
.903 .685 .597 r
.322 .53422 m .32332 .53807 L .32376 .53509 L F
.902 .683 .597 r
.33695 .52081 m .33488 .51688 L .33698 .51817 L F
.644 .946 .72 r
.55095 .37766 m .54923 .3784 L .54776 .38038 L F
0 0 0 r
.54904 .38076 m .54776 .38038 L .54923 .3784 L F
.54904 .38076 m .54654 .38189 L .54776 .38038 L F
.811 .866 .888 r
.45985 .52418 m .45674 .52453 L .45872 .52315 L F
.823 .969 .896 r
.62229 .34749 m .62173 .35048 L .62472 .34768 L F
.82 .967 .899 r
.62229 .34749 m .61866 .34968 L .62173 .35048 L F
.188 .093 .509 r
.55138 .37486 m .55192 .37726 L .55446 .37534 L F
.081 0 0 r
.55126 .37753 m .55203 .37778 L .54923 .3784 L F
.55345 .3766 m .55203 .37778 L .55126 .37753 L F
.828 .489 .415 r
.55409 .37821 m .55135 .38023 L .55203 .37778 L F
.032 0 .251 r
.55135 .38023 m .55276 .37801 L .55203 .37778 L F
.864 .632 .585 r
.55782 .37691 m .55409 .37821 L .55345 .3766 L F
.765 .28 .081 r
.55409 .37821 m .55203 .37778 L .55345 .3766 L F
.032 0 .251 r
.55276 .37801 m .55446 .37534 L .55203 .37778 L F
.188 .093 .509 r
.55192 .37726 m .55203 .37778 L .55302 .37679 L F
.55192 .37726 m .55302 .37679 L .55446 .37534 L F
.081 0 0 r
.55345 .3766 m .55065 .37779 L .55095 .37766 L F
.55065 .37779 m .54923 .3784 L .55 .37807 L F
.55065 .37779 m .55 .37807 L .55095 .37766 L F
.679 .844 .962 r
.39461 .53348 m .39628 .5355 L .39717 .53428 L F
.824 .767 .799 r
.47086 .51032 m .46722 .51049 L .46887 .50924 L F
.843 .885 .871 r
.47388 .50731 m .47086 .51032 L .46887 .50924 L F
.488 .534 .831 r
.38138 .54497 m .38563 .54706 L .38386 .54439 L F
.465 .16 .364 r
.26719 .5543 m .27052 .55153 L .26752 .55171 L F
.558 .911 .706 r
.52526 .40437 m .52352 .40527 L .52212 .40679 L F
.546 .929 .888 r
.52352 .40527 m .52091 .40652 L .52212 .40679 L F
.882 .95 .848 r
.30729 .57792 m .30825 .57336 L .30915 .57451 L F
.30729 .57792 m .30554 .57659 L .30825 .57336 L F
0 .17 .69 r
.58352 .38452 m .58468 .38193 L .58291 .38197 L F
.58352 .38452 m .58557 .38456 L .58468 .38193 L F
.58352 .38452 m .58601 .38666 L .58557 .38456 L F
.88 .909 .845 r
.47602 .51761 m .48028 .51547 L .47686 .51594 L F
.806 .965 .909 r
.47686 .51594 m .48028 .51547 L .4808 .513 L F
.237 0 .14 r
.32547 .62809 m .32131 .6321 L .32476 .631 L F
0 0 0 r
.32734 .62756 m .32901 .62542 L .32547 .62809 L F
.013 0 .109 r
.32734 .62756 m .32547 .62809 L .32476 .631 L F
0 0 .457 r
.59378 .39548 m .59362 .39745 L .59278 .39333 L F
.893 .969 .655 r
.59189 .39843 m .59362 .39745 L .59378 .39548 L F
0 0 0 r
.59317 .39695 m .59189 .39843 L .59351 .39654 L F
.564 .901 .662 r
.59112 .39932 m .59362 .39745 L .59189 .39843 L F
0 0 0 r
.59072 .39986 m .59189 .39843 L .59317 .39695 L F
.564 .901 .662 r
.59014 .40006 m .59112 .39932 L .59189 .39843 L F
.911 .976 .786 r
.55844 .41636 m .56173 .41381 L .56108 .41299 L F
.844 .921 .884 r
.56173 .41381 m .56368 .40938 L .56108 .41299 L F
.56173 .41381 m .56499 .41071 L .56368 .40938 L F
.606 .057 0 r
.53974 .38208 m .54405 .38366 L .54169 .3815 L F
.275 .128 .493 r
.54169 .3815 m .54405 .38366 L .54355 .38002 L F
.439 .843 .65 r
.47253 .42047 m .4721 .42064 L .47436 .41912 L F
.215 .711 .916 r
.5901 .35574 m .59448 .35637 L .59167 .35742 L F
.133 0 0 r
.28061 .53731 m .28402 .53496 L .28151 .53538 L F
.783 .492 .494 r
.31781 .53116 m .3175 .53382 L .32021 .53161 L F
.812 .541 .528 r
.32021 .53161 m .3175 .53382 L .322 .53422 L F
.81 .66 .697 r
.37608 .53751 m .37974 .53916 L .37823 .53424 L F
.988 .736 .36 r
.37591 .53759 m .37974 .53916 L .37608 .53751 L F
.534 .5 .765 r
.37823 .53424 m .37974 .53916 L .38284 .53795 L F
0 .034 .544 r
.28095 .65846 m .28119 .66249 L .28258 .66081 L F
.242 .413 .833 r
.28119 .66249 m .28422 .66433 L .28258 .66081 L F
.968 .773 .589 r
.32595 .55404 m .32576 .5563 L .32743 .5568 L F
.888 .708 .652 r
.3234 .56027 m .32743 .5568 L .32576 .5563 L F
.3234 .56027 m .32616 .56173 L .32743 .5568 L F
.976 .751 .533 r
.35571 .57143 m .35418 .56767 L .35655 .569 L F
.969 .903 .699 r
.52847 .43692 m .52865 .44003 L .52761 .43873 L F
.873 .746 .719 r
.52865 .44003 m .52516 .44283 L .52761 .43873 L F
.52865 .44003 m .52738 .44436 L .52516 .44283 L F
.961 .859 .694 r
.47025 .52406 m .46936 .52673 L .4706 .52743 L F
.893 .925 .834 r
.46726 .5292 m .4706 .52743 L .46936 .52673 L F
.667 .629 .802 r
.31155 .5614 m .30715 .55871 L .30975 .55834 L F
.593 .699 .916 r
.31348 .56065 m .31155 .5614 L .30975 .55834 L F
0 0 0 r
.59636 .38535 m .59397 .38743 L .59698 .38363 L F
.59886 .38122 m .59636 .38535 L .59698 .38363 L F
.869 .741 .719 r
.65315 .36996 m .65109 .37368 L .64971 .36944 L F
.454 .347 .644 r
.25781 .57172 m .26048 .57112 L .26011 .5676 L F
.442 .197 .445 r
.25781 .57172 m .25975 .57386 L .26048 .57112 L F
.25781 .57172 m .25746 .57456 L .25975 .57386 L F
.311 .77 .949 r
.50366 .41758 m .50422 .41628 L .50163 .41714 L F
.50366 .41758 m .50613 .41724 L .50422 .41628 L F
0 0 0 r
.47859 .41432 m .4796 .41481 L .48065 .41287 L F
.47859 .41432 m .4776 .416 L .4796 .41481 L F
.913 .908 .803 r
.43097 .57048 m .43465 .56787 L .43311 .56672 L F
.891 .861 .804 r
.43538 .56308 m .43311 .56672 L .43465 .56787 L F
.492 .294 .539 r
.54344 .34377 m .54645 .34315 L .54614 .34035 L F
0 0 0 r
.44752 .43966 m .44904 .4382 L .44555 .44052 L F
.45122 .43687 m .44904 .4382 L .44752 .43966 L F
.993 .875 .593 r
.49072 .47711 m .48964 .47575 L .49152 .47448 L F
.903 .974 .677 r
.49152 .47448 m .48964 .47575 L .49195 .47157 L F
.079 0 0 r
.4235 .45636 m .42718 .45414 L .42451 .45511 L F
.866 .6 .533 r
.34221 .51056 m .34253 .5138 L .34654 .51466 L F
.842 .605 .581 r
.3422 .51662 m .34654 .51466 L .34253 .5138 L F
.3422 .51662 m .34656 .51778 L .34654 .51466 L F
.759 .536 .595 r
.34654 .51466 m .34656 .51778 L .3507 .518 L F
.835 .919 .891 r
.41302 .58684 m .41487 .58808 L .4177 .585 L F
.892 .842 .789 r
.45535 .53719 m .45948 .53509 L .45822 .53429 L F
.45535 .53719 m .45737 .53864 L .45948 .53509 L F
.618 .935 .961 r
.46197 .5339 m .46074 .53322 L .45948 .53509 L F
.588 .901 .985 r
.46074 .53322 m .45822 .53429 L .45948 .53509 L F
.205 .183 .611 r
.54593 .40759 m .54358 .41137 L .54383 .40618 L F
.648 .585 .77 r
.54593 .40759 m .54527 .415 L .54358 .41137 L F
0 0 0 r
.53782 .39218 m .53595 .39575 L .53534 .39682 L F
.902 .775 .711 r
.32312 .55067 m .32686 .5488 L .32491 .54754 L F
.828 .673 .691 r
.40683 .48159 m .40695 .47819 L .40759 .48149 L F
0 0 .048 r
.59636 .38535 m .59376 .38983 L .59397 .38743 L F
.294 0 .149 r
.60812 .35315 m .6047 .35619 L .60513 .3533 L F
.114 .624 .896 r
.30906 .64808 m .31266 .64869 L .30856 .64775 L F
.498 .707 .964 r
.28735 .67458 m .29114 .67606 L .28923 .67432 L F
.497 .734 .978 r
.28923 .67432 m .29114 .67606 L .29363 .67554 L F
.963 .709 .503 r
.29114 .67606 m .29533 .67941 L .29363 .67554 L F
.316 .078 .386 r
.27885 .53836 m .28047 .5401 L .28061 .53731 L F
.27885 .53836 m .27826 .541 L .28047 .5401 L F
.663 .669 .845 r
.51562 .37738 m .51732 .37507 L .51614 .37322 L F
.51562 .37738 m .51945 .37715 L .51732 .37507 L F
.717 .367 .385 r
.51562 .37738 m .51929 .38023 L .51945 .37715 L F
.51562 .37738 m .51509 .37996 L .51929 .38023 L F
0 0 0 r
.51036 .38692 m .51214 .38518 L .51311 .38301 L F
0 0 .22 r
.51036 .38692 m .51127 .38741 L .51214 .38518 L F
.51036 .38692 m .5108 .38891 L .51127 .38741 L F
0 .268 .741 r
.63146 .38305 m .6323 .38382 L .63034 .38255 L F
.602 .265 .372 r
.36495 .52587 m .36838 .5262 L .37233 .52154 L F
.625 .26 .331 r
.36838 .5262 m .37323 .52352 L .37233 .52154 L F
.122 .065 .514 r
.29029 .5338 m .28997 .53676 L .2894 .53605 L F
.528 .332 .558 r
.29336 .63801 m .29128 .64368 L .29058 .64173 L F
0 0 .183 r
.29416 .64025 m .29336 .63801 L .29615 .63717 L F
.29344 .63823 m .29128 .64368 L .29336 .63801 L F
.29167 .64293 m .29128 .64368 L .29344 .63823 L F
.395 .26 .577 r
.29167 .64293 m .29128 .64368 L .2929 .6443 L F
0 0 .183 r
.29147 .64347 m .29128 .64368 L .29167 .64293 L F
.395 .26 .577 r
.29058 .64173 m .29128 .64368 L .29167 .64293 L F
.29058 .64173 m .29167 .64293 L .29053 .64514 L F
.332 .322 .698 r
.2929 .6443 m .29128 .64368 L .29147 .64347 L F
.395 .26 .577 r
.29167 .64293 m .2929 .6443 L .29147 .64347 L F
.332 .322 .698 r
.2929 .6443 m .29147 .64347 L .29416 .64025 L F
.395 .26 .577 r
.29147 .64347 m .2929 .6443 L .29088 .64502 L F
.29167 .64293 m .29088 .64502 L .29053 .64514 L F
0 0 .183 r
.29416 .64025 m .29147 .64347 L .29344 .63823 L F
.047 0 0 r
.58291 .38197 m .58468 .38193 L .58681 .38101 L F
0 0 .335 r
.58681 .38101 m .58618 .3797 L .58597 .37934 L F
.954 .951 .673 r
.58681 .38101 m .58468 .38193 L .58618 .3797 L F
0 0 0 r
.58618 .3797 m .58468 .38193 L .5865 .38027 L F
.58618 .3797 m .5865 .38027 L .5869 .37991 L F
0 0 .335 r
.58597 .37934 m .58618 .3797 L .58492 .37727 L F
.465 .289 .556 r
.26415 .55678 m .26195 .55831 L .26438 .55759 L F
.336 .108 .413 r
.26169 .56114 m .26438 .55759 L .26195 .55831 L F
.561 .877 .993 r
.53751 .41652 m .54195 .41658 L .54028 .41574 L F
.494 .864 .984 r
.54028 .41574 m .54195 .41658 L .54429 .41557 L F
.779 .603 .661 r
.53893 .42345 m .54338 .42131 L .53898 .42055 L F
.405 0 0 r
.63064 .39333 m .6267 .39355 L .62796 .393 L F
.805 .771 .822 r
.52354 .44311 m .52431 .44779 L .52028 .44724 L F
.815 .773 .813 r
.52516 .44283 m .52431 .44779 L .52354 .44311 L F
.52516 .44283 m .52738 .44436 L .52431 .44779 L F
.912 .926 .81 r
.45298 .54103 m .45045 .54428 L .45176 .54559 L F
.918 .925 .802 r
.45045 .54428 m .44866 .54566 L .45176 .54559 L F
.531 .547 .816 r
.53481 .41994 m .53222 .4206 L .528 .41641 L F
.509 .06 .119 r
.52964 .41883 m .53367 .41813 L .528 .41641 L F
.75 .571 .653 r
.35455 .51722 m .35487 .52076 L .35724 .51759 L F
.739 .48 .537 r
.39015 .55193 m .38957 .55435 L .38554 .5542 L F
.913 .965 .8 r
.38978 .54929 m .39015 .55193 L .39261 .54831 L F
.97 .837 .426 r
.38894 .55362 m .39015 .55193 L .38978 .54929 L F
.38894 .55362 m .38957 .55435 L .39015 .55193 L F
.848 .891 .466 r
.52015 .38556 m .51973 .38736 L .52111 .38467 L F
.776 .897 .493 r
.52067 .38422 m .52111 .38467 L .52344 .38327 L F
.52067 .38422 m .52015 .38556 L .52111 .38467 L F
.739 .992 .855 r
.66885 .37124 m .66786 .37307 L .67098 .37021 L F
.66885 .37124 m .66749 .37252 L .66786 .37307 L F
.879 .818 .785 r
.64086 .34872 m .64164 .35247 L .64271 .35117 L F
.221 0 0 r
.64811 .34828 m .64791 .34834 L .64791 .34837 L F
.693 .829 .948 r
.64811 .34828 m .64536 .34961 L .64931 .35005 L F
.965 .868 .693 r
.64811 .34828 m .64931 .35005 L .64794 .34835 L F
.64811 .34828 m .64794 .34835 L .64782 .3482 L F
.221 0 0 r
.64811 .34828 m .64698 .34945 L .6455 .34947 L F
.64791 .34837 m .64729 .34854 L .64536 .34961 L F
.64791 .34834 m .64729 .34854 L .64791 .34837 L F
.64729 .34854 m .64441 .34948 L .64536 .34961 L F
.608 .793 .97 r
.64286 .34912 m .64266 .35111 L .64536 .34961 L F
.64086 .34872 m .64131 .34932 L .64286 .34912 L F
.64131 .34932 m .64266 .35111 L .64286 .34912 L F
.221 0 0 r
.64729 .34854 m .6455 .34947 L .64441 .34948 L F
.64811 .34828 m .64762 .3485 L .64729 .34854 L F
.64762 .3485 m .6455 .34947 L .64729 .34854 L F
0 0 0 r
.64931 .35005 m .65008 .34976 L .648 .34838 L F
.64931 .35005 m .64792 .34827 L .64791 .34832 L F
.558 .007 0 r
.65008 .34976 m .64698 .34945 L .64801 .34838 L F
.65008 .34976 m .64801 .34838 L .64811 .34828 L F
0 0 0 r
.648 .34838 m .65008 .34976 L .64792 .34827 L F
.64791 .34832 m .64792 .34827 L .64782 .3482 L F
.608 .793 .97 r
.64266 .35111 m .64271 .35117 L .64536 .34961 L F
0 0 0 r
.48032 .42712 m .48417 .42425 L .48228 .42551 L F
.403 .811 .603 r
.48631 .42287 m .48228 .42551 L .48417 .42425 L F
.759 .672 .766 r
.38443 .57797 m .38625 .58189 L .38175 .58147 L F
.67 .202 .133 r
.31046 .56699 m .30681 .567 L .30882 .56553 L F
.756 .719 .818 r
.48544 .49176 m .48078 .49141 L .48355 .49022 L F
.376 0 0 r
.65068 .33924 m .65339 .33982 L .65479 .33959 L F
.498 0 0 r
.65339 .33982 m .65729 .34031 L .65479 .33959 L F
.609 .71 .917 r
.51536 .39285 m .51944 .39433 L .51792 .38991 L F
.581 .595 .831 r
.51944 .39433 m .52052 .3884 L .51792 .38991 L F
.51944 .39433 m .52229 .39371 L .52052 .3884 L F
.485 .538 .836 r
.30169 .5736 m .30213 .58099 L .30062 .57802 L F
.598 .63 .854 r
.30554 .57659 m .30213 .58099 L .30169 .5736 L F
.035 0 0 r
.63295 .35374 m .63521 .35303 L .63614 .35142 L F
.332 .382 .763 r
.63295 .35374 m .63499 .35488 L .63521 .35303 L F
.929 .609 .415 r
.51221 .40836 m .51528 .40719 L .51119 .4072 L F
.51221 .40836 m .51413 .40961 L .51528 .40719 L F
.366 .127 .413 r
.51528 .40719 m .51766 .40647 L .51803 .40386 L F
.705 .468 .564 r
.51413 .40961 m .51766 .40647 L .51528 .40719 L F
0 0 0 r
.67372 .36658 m .67275 .36812 L .67098 .37021 L F
.64 .955 .765 r
.67098 .37021 m .67275 .36812 L .66885 .37124 L F
.812 .535 .519 r
.49806 .44342 m .50293 .44444 L .50257 .44698 L F
.066 0 .316 r
.50257 .44698 m .50293 .44444 L .50443 .4429 L F
.235 0 .254 r
.41056 .46613 m .40893 .46413 L .40792 .46678 L F
.41056 .46613 m .41137 .46295 L .40893 .46413 L F
.927 .648 .494 r
.63087 .33993 m .63274 .33921 L .62986 .34001 L F
.006 .575 .778 r
.62586 .33953 m .63087 .33993 L .62986 .34001 L F
.871 .773 .751 r
.46798 .51401 m .46493 .51452 L .46722 .51049 L F
.925 .845 .745 r
.32493 .5641 m .32289 .56791 L .32469 .56868 L F
.91 .756 .678 r
.3219 .57013 m .32469 .56868 L .32289 .56791 L F
.3219 .57013 m .32401 .57156 L .32469 .56868 L F
.996 .802 .441 r
.64366 .35698 m .64334 .36039 L .64218 .35835 L F
.783 .603 .657 r
.32471 .62197 m .32077 .6254 L .32233 .62429 L F
.608 .081 0 r
.30856 .54264 m .30569 .54296 L .30713 .5415 L F
.5 .814 1 r
.32471 .62197 m .32792 .62176 L .32622 .62002 L F
.719 .414 0 r
.32471 .62241 m .32633 .62714 L .32471 .62197 L F
.555 .569 .823 r
.32471 .62197 m .32901 .62542 L .32792 .62176 L F
.719 .414 0 r
.32471 .62241 m .32471 .62197 L .32622 .62002 L F
.578 .591 .83 r
.33496 .66891 m .33784 .66869 L .33592 .66443 L F
.33496 .66891 m .33592 .66443 L .33573 .6674 L F
.427 .782 .996 r
.33573 .6674 m .33784 .66869 L .33496 .66891 L F
.586 .782 .973 r
.313 .62998 m .31559 .6322 L .31213 .63338 L F
.848 .998 .804 r
.313 .62998 m .31213 .63338 L .31017 .63335 L F
.767 .938 .592 r
.55346 .42657 m .55487 .42476 L .55332 .42615 L F
.86 .994 .754 r
.55487 .42476 m .55731 .42159 L .55542 .42228 L F
.853 .95 .595 r
.55332 .42615 m .55487 .42476 L .55542 .42228 L F
.871 .837 .809 r
.47632 .50397 m .47388 .50731 L .47326 .50408 L F
0 0 0 r
.42082 .46842 m .42267 .46687 L .41957 .4696 L F
0 0 .199 r
.51803 .40386 m .51934 .40464 L .52043 .40266 L F
.51803 .40386 m .51766 .40647 L .51934 .40464 L F
.753 .473 .509 r
.33853 .50763 m .34221 .51056 L .34127 .50804 L F
.75 .498 .55 r
.34127 .50804 m .34414 .51041 L .34408 .50699 L F
.34127 .50804 m .34221 .51056 L .34414 .51041 L F
.894 .987 .739 r
.55542 .42228 m .55731 .42159 L .5589 .41887 L F
.968 .933 .678 r
.41674 .48683 m .41545 .48939 L .41766 .48785 L F
.946 .676 .493 r
.41545 .48939 m .41763 .49063 L .41766 .48785 L F
.968 .933 .678 r
.41766 .48785 m .41545 .48939 L .41674 .48683 L F
.946 .676 .493 r
.41766 .48785 m .41763 .49063 L .41545 .48939 L F
.968 .933 .678 r
.41674 .48683 m .41545 .48939 L .41766 .48785 L F
.946 .676 .493 r
.41545 .48939 m .41763 .49063 L .41766 .48785 L F
.853 .869 .851 r
.48413 .50712 m .48601 .50857 L .48849 .50571 L F
.894 .86 .8 r
.48478 .51039 m .48601 .50857 L .48413 .50712 L F
.854 .63 .599 r
.35231 .54147 m .34875 .54069 L .34932 .53792 L F
.873 .611 .539 r
.35208 .54429 m .34875 .54069 L .35231 .54147 L F
.955 .852 .701 r
.53818 .45305 m .54117 .45053 L .54006 .44909 L F
.53818 .45305 m .53978 .4544 L .54117 .45053 L F
.569 .768 .973 r
.63464 .39325 m .63567 .39114 L .63353 .39277 L F
.63464 .39325 m .63677 .39221 L .63567 .39114 L F
.798 .983 .896 r
.53693 .43029 m .53455 .4339 L .53368 .43294 L F
.53693 .43029 m .53791 .43102 L .53455 .4339 L F
.861 .996 .806 r
.40805 .56949 m .41029 .56928 L .40856 .57107 L F
.486 .65 .931 r
.41188 .56623 m .41335 .56856 L .41029 .56928 L F
.297 .773 .928 r
.32849 .63501 m .32766 .63544 L .32548 .63504 L F
.32548 .63504 m .32849 .63501 L .3285 .63186 L F
.534 .796 .993 r
.32766 .63544 m .3245 .63486 L .32548 .63504 L F
.32766 .63544 m .32374 .63472 L .32548 .63504 L F
.297 .773 .928 r
.32849 .63501 m .32548 .63504 L .32787 .63596 L F
.172 .557 .931 r
.32411 .63338 m .32548 .63504 L .32476 .631 L F
.685 .605 .76 r
.32476 .631 m .32548 .63504 L .3285 .63186 L F
0 .418 .854 r
.32691 .6353 m .32548 .63504 L .32411 .63338 L F
.32787 .63596 m .32548 .63504 L .32691 .6353 L F
.534 .796 .993 r
.3245 .63486 m .32374 .63472 L .32548 .63504 L F
.236 0 0 r
.49639 .41735 m .49534 .4195 L .49246 .42017 L F
.66 .392 .504 r
.50101 .45693 m .50527 .45693 L .50502 .45404 L F
.673 .535 .688 r
.50502 .45404 m .5078 .4541 L .50786 .45116 L F
.732 .497 .571 r
.50527 .45693 m .5078 .4541 L .50502 .45404 L F
0 0 .298 r
.38208 .56065 m .38171 .56166 L .38122 .55817 L F
.791 .899 .919 r
.3054 .61969 m .30669 .62115 L .30438 .62263 L F
.836 .677 .685 r
.42901 .51047 m .43039 .51468 L .42651 .51393 L F
.771 .486 .503 r
.43039 .51468 m .426 .51681 L .42651 .51393 L F
.43039 .51468 m .43025 .51725 L .426 .51681 L F
.702 .607 .747 r
.43248 .51068 m .43039 .51468 L .42901 .51047 L F
.569 .446 .672 r
.43248 .51068 m .43378 .51416 L .43039 .51468 L F
.532 .29 .493 r
.43378 .51416 m .43025 .51725 L .43039 .51468 L F
.854 .897 .865 r
.50357 .48942 m .50802 .48753 L .50657 .48617 L F
.825 .917 .899 r
.50802 .48753 m .50956 .48351 L .50657 .48617 L F
.50802 .48753 m .51113 .48464 L .50956 .48351 L F
.895 .849 .79 r
.47326 .50408 m .47388 .50731 L .47229 .50607 L F
.843 .885 .871 r
.47388 .50731 m .46887 .50924 L .47229 .50607 L F
.138 0 0 r
.60947 .343 m .61222 .34316 L .61309 .34303 L F
.202 .728 .741 r
.61309 .34303 m .61222 .34316 L .61549 .34246 L F
.903 .685 .597 r
.322 .53422 m .32015 .5373 L .32332 .53807 L F
.893 .684 .613 r
.32015 .5373 m .323 .54106 L .32332 .53807 L F
.756 .985 .904 r
.54709 .37535 m .54425 .37741 L .54515 .37524 L F
.407 .16 .424 r
.54425 .37741 m .54638 .37908 L .54515 .37524 L F
.54425 .37741 m .54355 .38002 L .54638 .37908 L F
0 0 0 r
.3934 .53431 m .39461 .53348 L .3957 .53256 L F
.148 .312 .774 r
.3934 .53431 m .39618 .53742 L .39461 .53348 L F
.594 .364 .538 r
.53222 .4206 m .53217 .42358 L .5295 .42311 L F
.509 .325 .567 r
.53481 .41994 m .53217 .42358 L .53222 .4206 L F
.356 0 .19 r
.39946 .47063 m .40212 .47004 L .40264 .46833 L F
.098 0 .098 r
.40264 .46833 m .40212 .47004 L .40437 .46872 L F
.624 .577 .781 r
.62022 .39306 m .62378 .39329 L .62266 .38994 L F
0 0 0 r
.41518 .47488 m .4175 .47113 L .41644 .47306 L F
.666 .885 .523 r
.41369 .47649 m .41518 .47488 L .41644 .47306 L F
.903 .895 .81 r
.3359 .67591 m .33921 .67314 L .33729 .67186 L F
.07 0 .332 r
.57934 .38587 m .57753 .38973 L .57776 .38723 L F
.866 .995 .764 r
.53112 .35363 m .52849 .35677 L .52917 .35412 L F
.574 .354 .544 r
.53112 .35363 m .53132 .35651 L .52849 .35677 L F
.575 .443 .665 r
.53112 .35363 m .53424 .35309 L .53388 .34994 L F
.53112 .35363 m .53424 .35309 L .53388 .34994 L F
.47 .888 .785 r
.53112 .35363 m .53276 .35232 L .53424 .35309 L F
.53112 .35363 m .52917 .35412 L .53276 .35232 L F
.474 .28 .537 r
.53418 .35559 m .53112 .35363 L .53424 .35309 L F
.53418 .35559 m .53132 .35651 L .53112 .35363 L F
0 0 0 r
.44555 .44052 m .44197 .44343 L .44455 .44254 L F
.44555 .44052 m .44647 .44131 L .44752 .43966 L F
.44555 .44052 m .44455 .44254 L .44647 .44131 L F
.27739 .56513 m .27578 .56738 L .27459 .56833 L F
.438 .438 .761 r
.27578 .56738 m .2744 .56897 L .27459 .56833 L F
.724 .719 .845 r
.62727 .34624 m .63144 .34728 L .63008 .34518 L F
.579 .728 .944 r
.63144 .34728 m .63401 .34455 L .63008 .34518 L F
.63144 .34728 m .63416 .34661 L .63401 .34455 L F
.228 0 .282 r
.41301 .569 m .41074 .57399 L .41287 .57307 L F
.41287 .57307 m .41074 .57399 L .41301 .569 L F
.913 .965 .8 r
.38978 .54929 m .39261 .54831 L .39069 .54701 L F
.684 .896 .537 r
.39511 .54491 m .39325 .54696 L .39261 .54831 L F
.383 .742 .991 r
.39261 .54831 m .39325 .54696 L .39069 .54701 L F
.684 .896 .537 r
.39511 .54491 m .39325 .54696 L .39261 .54831 L F
.859 .839 .371 r
.56499 .41071 m .56595 .40562 L .56368 .40938 L F
.948 .879 .733 r
.48413 .50712 m .48304 .50929 L .48478 .51039 L F
.162 .249 .707 r
.67378 .36206 m .67528 .36452 L .67372 .36658 L F
0 0 0 r
.67372 .36658 m .67528 .36452 L .67275 .36812 L F
.769 .951 .626 r
.59293 .34697 m .59389 .34454 L .59552 .34342 L F
0 0 0 r
.59293 .34697 m .59422 .3472 L .59389 .34454 L F
.59293 .34697 m .59192 .34864 L .59422 .3472 L F
.932 .927 .779 r
.42294 .55923 m .42148 .56218 L .42032 .55999 L F
.989 .888 .565 r
.42043 .56494 m .42032 .55999 L .42148 .56218 L F
0 0 0 r
.41957 .4696 m .41644 .47306 L .4175 .47113 L F
.7 .351 .381 r
.34625 .52003 m .3507 .518 L .34656 .51778 L F
.34625 .52003 m .35063 .52032 L .3507 .518 L F
.772 .415 .378 r
.3507 .518 m .35487 .52076 L .35455 .51722 L F
.3507 .518 m .35063 .52032 L .35487 .52076 L F
.515 .664 .929 r
.38208 .56065 m .38565 .56434 L .38169 .56423 L F
.377 .84 .796 r
.38565 .56434 m .38017 .56605 L .38169 .56423 L F
0 0 0 r
.5177 .37043 m .51883 .36936 L .52056 .36717 L F
0 0 .361 r
.5177 .37043 m .51887 .37089 L .51883 .36936 L F
.79 .994 .873 r
.49792 .46532 m .49713 .46775 L .49614 .46725 L F
.015 .064 .568 r
.43568 .552 m .43606 .54698 L .43742 .54792 L F
.519 .1 .185 r
.43606 .54698 m .44024 .54452 L .43742 .54792 L F
.974 .708 .466 r
.67206 .35624 m .67401 .35969 L .67292 .35639 L F
.67206 .35624 m .67205 .35898 L .67401 .35969 L F
.787 .405 .333 r
.67164 .36171 m .67401 .35969 L .67205 .35898 L F
.67164 .36171 m .67378 .36206 L .67297 .36058 L F
.792 .338 0 r
.67289 .36151 m .67378 .36206 L .67164 .36171 L F
.67289 .36151 m .67477 .36388 L .67378 .36206 L F
.67477 .36388 m .67528 .36452 L .67378 .36206 L F
.787 .405 .333 r
.67297 .36058 m .67378 .36206 L .67401 .35969 L F
.477 .256 .499 r
.39102 .54433 m .39383 .54404 L .39511 .54491 L F
.754 .954 .94 r
.39511 .54491 m .39383 .54404 L .39583 .54254 L F
0 0 0 r
.39325 .54696 m .39502 .54392 L .39383 .54404 L F
.39502 .54392 m .39583 .54254 L .39383 .54404 L F
.477 .256 .499 r
.39086 .5443 m .39383 .54404 L .39102 .54433 L F
.754 .954 .94 r
.39511 .54491 m .39583 .54254 L .39773 .54429 L F
.145 0 0 r
.39734 .54481 m .39511 .54491 L .39773 .54429 L F
.39734 .54481 m .39325 .54696 L .39511 .54491 L F
.334 .226 .579 r
.26003 .56477 m .26196 .564 L .26169 .56114 L F
.346 .209 .548 r
.26003 .56477 m .26215 .56667 L .26196 .564 L F
.26003 .56477 m .26011 .5676 L .26215 .56667 L F
.795 .305 .029 r
.36897 .57209 m .37018 .57423 L .36758 .57303 L F
.759 .297 .152 r
.37344 .57477 m .37018 .57423 L .36897 .57209 L F
.506 .285 .512 r
.49807 .45753 m .49799 .4603 L .50101 .45693 L F
.42 .107 .327 r
.50343 .43929 m .50079 .43777 L .50046 .43983 L F
.644 .511 .686 r
.50786 .45116 m .5078 .4541 L .51052 .45065 L F
0 .034 .544 r
.28095 .65846 m .28258 .66081 L .28154 .6581 L F
.567 .429 .652 r
.33695 .5093 m .33445 .51443 L .33804 .51359 L F
.33695 .5093 m .33804 .51359 L .337 .50999 L F
.388 .021 .215 r
.33695 .5093 m .337 .50999 L .33853 .50763 L F
.776 .466 .462 r
.337 .50999 m .34175 .51112 L .33853 .50763 L F
.753 .473 .509 r
.33853 .50763 m .34175 .51112 L .34221 .51056 L F
.976 .751 .533 r
.35571 .57143 m .35392 .57093 L .35418 .56767 L F
.262 .6 .952 r
.35571 .57143 m .35639 .56999 L .35392 .57093 L F
.35571 .57143 m .3592 .57072 L .35639 .56999 L F
.829 .703 .725 r
.37666 .53015 m .37823 .53424 L .37919 .53146 L F
.732 .614 .726 r
.32792 .62176 m .32901 .62542 L .33149 .62201 L F
0 0 .243 r
.33016 .6242 m .3316 .62623 L .33078 .62394 L F
0 0 0 r
.33149 .62201 m .32978 .62436 L .33016 .6242 L F
.397 0 0 r
.33599 .62453 m .33149 .62201 L .33391 .62174 L F
.334 0 .151 r
.33391 .62174 m .33149 .62201 L .33016 .6242 L F
.33391 .62174 m .33016 .6242 L .33042 .62294 L F
0 0 .243 r
.33016 .6242 m .33078 .62394 L .33042 .62294 L F
0 0 0 r
.32978 .62436 m .32901 .62542 L .33016 .6242 L F
.8 .769 .825 r
.37825 .5757 m .37326 .57757 L .37344 .57477 L F
.51 .724 .969 r
.37858 .57355 m .38073 .57555 L .37825 .5757 L F
.37858 .57355 m .38073 .57555 L .37825 .5757 L F
.442 .21 .465 r
.31161 .5477 m .31027 .55028 L .30875 .54856 L F
.706 .172 0 r
.30875 .54856 m .31027 .55028 L .30723 .54923 L F
.813 .872 .89 r
.57331 .41998 m .57664 .41916 L .57641 .41814 L F
.571 .56 .803 r
.57641 .41814 m .57664 .41916 L .57748 .41809 L F
.539 .514 .776 r
.5591 .38389 m .56332 .38644 L .56139 .38257 L F
.326 .395 .781 r
.5591 .38389 m .56142 .38283 L .55802 .37968 L F
0 .438 .862 r
.30821 .62141 m .30669 .62115 L .3054 .61969 L F
.74 .331 .275 r
.37323 .52352 m .37524 .52644 L .37746 .52447 L F
.94 .666 .493 r
.37524 .52644 m .37754 .52778 L .37746 .52447 L F
.919 .635 .147 r
.60135 .35883 m .60253 .36291 L .60224 .36036 L F
.527 .369 .61 r
.60102 .37042 m .60163 .37313 L .59876 .37374 L F
0 0 .037 r
.60016 .37162 m .59876 .37374 L .60163 .37313 L F
.60016 .37162 m .59863 .37643 L .59876 .37374 L F
.57 .799 .986 r
.32792 .62176 m .33149 .62201 L .32991 .62054 L F
.41 .72 .988 r
.32991 .62054 m .33149 .62201 L .33391 .62174 L F
.928 .973 .737 r
.52281 .36304 m .52419 .3587 L .52646 .36025 L F
.386 .444 .799 r
.52747 .356 m .52818 .35924 L .52646 .36025 L F
.153 0 .382 r
.52818 .35924 m .52703 .36253 L .52646 .36025 L F
0 0 .323 r
.5268 .36162 m .52652 .36328 L .52646 .36025 L F
.52652 .36328 m .52644 .3634 L .52646 .36025 L F
.52675 .363 m .52644 .36376 L .5268 .36162 L F
.28 .783 .816 r
.52703 .36253 m .52347 .36303 L .52683 .36282 L F
.52703 .36253 m .52683 .36282 L .5273 .36279 L F
0 0 .323 r
.52652 .36328 m .52644 .36376 L .52644 .3634 L F
.527 .36241 m .52675 .363 L .5268 .36162 L F
.52703 .36253 m .52644 .3641 L .52644 .36376 L F
.811 .697 .739 r
.52246 .36467 m .52391 .36646 L .52674 .3634 L F
.797 .999 .804 r
.5273 .36279 m .52644 .3641 L .52675 .36328 L F
.811 .697 .739 r
.52675 .363 m .52675 .36328 L .5273 .36279 L F
.52675 .363 m .5273 .36279 L .52683 .36282 L F
.797 .999 .804 r
.5273 .36279 m .52675 .36328 L .52703 .36253 L F
.811 .697 .739 r
.52675 .36328 m .52674 .3634 L .5273 .36279 L F
.52246 .36467 m .52674 .3634 L .52675 .363 L F
.52246 .36467 m .52675 .363 L .52347 .36303 L F
.52675 .363 m .52683 .36282 L .52347 .36303 L F
0 0 .323 r
.52703 .36253 m .52644 .36376 L .527 .36241 L F
.488 0 0 r
.3042 .6481 m .30581 .64806 L .30119 .64689 L F
.584 .62 .854 r
.30665 .64446 m .30581 .64806 L .30557 .64583 L F
.30665 .64446 m .30856 .64775 L .30581 .64806 L F
.925 .97 .765 r
.30557 .64583 m .30581 .64806 L .3042 .6481 L F
.941 .929 .763 r
.52391 .36646 m .52644 .3641 L .5273 .36279 L F
.375 .833 .75 r
.59552 .34342 m .59725 .34245 L .59902 .34181 L F
.17 0 0 r
.59389 .34454 m .59725 .34245 L .59552 .34342 L F
.705 .943 .959 r
.5282 .39921 m .52415 .40036 L .52491 .39805 L F
.748 .95 .944 r
.5282 .39921 m .52491 .39805 L .52698 .39629 L F
0 0 0 r
.53127 .38635 m .534 .3854 L .53542 .38458 L F
.5 .299 .539 r
.534 .3854 m .53611 .38264 L .53542 .38458 L F
.864 .582 .508 r
.34299 .52786 m .34056 .53013 L .33831 .52594 L F
.835 .532 .476 r
.34331 .53045 m .34056 .53013 L .34299 .52786 L F
.382 .801 .606 r
.64004 .37045 m .64228 .36903 L .64354 .36825 L F
.815 .844 .871 r
.63931 .37087 m .63673 .37103 L .63917 .36803 L F
.63935 .37176 m .63833 .37148 L .63931 .37087 L F
.63833 .37148 m .63673 .37103 L .63931 .37087 L F
.916 .796 .321 r
.64082 .36995 m .63951 .37074 L .64228 .36903 L F
.815 .844 .871 r
.63951 .37074 m .63917 .36803 L .64013 .36684 L F
.916 .796 .321 r
.64004 .37045 m .63935 .37176 L .63931 .37087 L F
.815 .844 .871 r
.63935 .37176 m .63931 .37087 L .63951 .37074 L F
.63931 .37087 m .63917 .36803 L .63951 .37074 L F
.916 .796 .321 r
.64004 .37045 m .63931 .37087 L .64082 .36995 L F
.63931 .37087 m .63918 .37094 L .63951 .37074 L F
.63931 .37087 m .63951 .37074 L .64082 .36995 L F
.63951 .37074 m .63918 .37094 L .64159 .36946 L F
.63951 .37074 m .64159 .36946 L .64228 .36903 L F
.63931 .37087 m .63935 .37176 L .63918 .37094 L F
.815 .844 .871 r
.63935 .37176 m .63951 .37074 L .63918 .37094 L F
.63951 .37074 m .64013 .36684 L .63918 .37094 L F
.556 .417 .646 r
.64337 .37255 m .64062 .37408 L .64004 .37045 L F
.844 .999 .794 r
.40599 .58986 m .4055 .59214 L .40788 .59099 L F
.716 .596 .721 r
.52755 .40323 m .52919 .40725 L .53195 .40375 L F
.775 .689 .769 r
.2473 .60792 m .24897 .61181 L .25165 .60841 L F
.705 .583 .716 r
.24897 .61181 m .25159 .6101 L .25165 .60841 L F
.743 .916 .951 r
.62322 .34096 m .62459 .338 L .62586 .33953 L F
.62322 .34096 m .62212 .33972 L .62459 .338 L F
.833 .726 .747 r
.35543 .5577 m .35692 .56155 L .35331 .5606 L F
.92 .652 .514 r
.35633 .56415 m .35331 .5606 L .35692 .56155 L F
.573 .757 .965 r
.40082 .57439 m .39817 .57503 L .39542 .57219 L F
.327 .75 .975 r
.63274 .33921 m .63543 .33904 L .63676 .33991 L F
.269 .75 .93 r
.63543 .33904 m .63957 .33934 L .63676 .33991 L F
0 0 0 r
.26886 .58091 m .26659 .58242 L .26781 .58122 L F
.527 .887 .978 r
.63499 .35488 m .64026 .3543 L .63853 .35227 L F
.815 .892 .898 r
.63853 .35227 m .64026 .3543 L .64164 .35247 L F
.773 .519 .551 r
.4018 .54744 m .40511 .54988 L .40326 .54777 L F
0 0 0 r
.57119 .40108 m .57443 .3984 L .57303 .3997 L F
.429 .817 .585 r
.5709 .40125 m .57119 .40108 L .57303 .3997 L F
.725 .986 .801 r
.56736 .40355 m .56937 .40297 L .57119 .40108 L F
.56736 .40355 m .57119 .40108 L .56946 .40229 L F
.429 .817 .585 r
.56946 .40229 m .57119 .40108 L .5709 .40125 L F
.621 .916 .644 r
.57119 .40108 m .56966 .40303 L .57144 .40093 L F
.57119 .40108 m .57144 .40093 L .57232 .3999 L F
.57119 .40108 m .56937 .40297 L .56966 .40303 L F
.545 .11 .165 r
.37861 .47889 m .383 .47684 L .38041 .47711 L F
.518 .504 .781 r
.2599 .58691 m .26167 .5913 L .25795 .58953 L F
.865 .546 .447 r
.66958 .35548 m .67163 .35356 L .66937 .35286 L F
.66958 .35548 m .67206 .35624 L .67163 .35356 L F
.921 .589 .394 r
.67163 .35356 m .67206 .35624 L .67292 .35639 L F
.326 .8 .916 r
.30336 .55893 m .3062 .55834 L .30715 .55871 L F
.759 .992 .88 r
.30715 .55871 m .30809 .55655 L .30975 .55834 L F
.30715 .55871 m .3062 .55834 L .30809 .55655 L F
.001 .257 .762 r
.27781 .56321 m .27739 .56513 L .27534 .56103 L F
.604 .532 .747 r
.27781 .56321 m .27578 .56738 L .27739 .56513 L F
.839 .702 .712 r
.34871 .63746 m .35216 .63817 L .35253 .63551 L F
.353 0 0 r
.34871 .63746 m .35138 .63838 L .35216 .63817 L F
0 .397 .818 r
.35312 .63809 m .35216 .63817 L .35138 .63838 L F
.35312 .63809 m .35453 .63945 L .35216 .63817 L F
.805 .684 .731 r
.34893 .644 m .3488 .64147 L .34673 .64118 L F
.805 .715 .765 r
.3488 .64147 m .34893 .644 L .34673 .64118 L F
.536 .505 .769 r
.34893 .644 m .3488 .64147 L .34673 .64118 L F
.805 .684 .731 r
.34893 .644 m .34888 .64383 L .3488 .64147 L F
.541 .492 .751 r
.34673 .64118 m .3488 .64147 L .34868 .63753 L F
.805 .684 .731 r
.34888 .64383 m .3479 .64098 L .3488 .64147 L F
.541 .492 .751 r
.34868 .63753 m .3488 .64147 L .34871 .63746 L F
0 0 0 r
.52281 .36304 m .52056 .36717 L .52246 .36467 L F
.288 .265 .659 r
.52056 .36717 m .52253 .36887 L .52246 .36467 L F
.597 .231 .319 r
.52056 .36717 m .51883 .36936 L .52253 .36887 L F
.853 .869 .851 r
.48413 .50712 m .48849 .50571 L .48692 .5046 L F
.783 .92 .929 r
.48909 .50295 m .48849 .50571 L .49045 .50396 L F
.48909 .50295 m .48692 .5046 L .48849 .50571 L F
.76 .755 .848 r
.31132 .62592 m .31572 .62674 L .3135 .62451 L F
.607 .687 .9 r
.3135 .62451 m .31572 .62674 L .31637 .6256 L F
.574 .371 .568 r
.3067 .5243 m .30946 .52414 L .30952 .52125 L F
.113 .408 .858 r
.3204 .63007 m .31966 .63197 L .3176 .62845 L F
.566 .903 .978 r
.31755 .63123 m .31966 .63197 L .3204 .63007 L F
.183 0 0 r
.32347 .6333 m .32177 .63295 L .32411 .63338 L F
.413 0 .021 r
.32177 .63295 m .31957 .6325 L .31918 .63468 L F
0 0 .239 r
.31918 .63468 m .31976 .63284 L .32177 .63295 L F
.183 0 0 r
.31976 .63284 m .32177 .63295 L .32347 .6333 L F
.413 0 .021 r
.32177 .63295 m .31966 .63197 L .31957 .6325 L F
.32177 .63295 m .32131 .6321 L .31966 .63197 L F
.324 .658 .972 r
.3204 .63007 m .32131 .6321 L .31966 .63197 L F
.819 .56 .548 r
.31737 .53638 m .322 .53422 L .3175 .53382 L F
.31737 .53638 m .32015 .5373 L .322 .53422 L F
.859 .416 .15 r
.37373 .55024 m .37421 .54848 L .37249 .54647 L F
.925 .605 .417 r
.30049 .58341 m .29833 .58533 L .29832 .58522 L F
.468 0 0 r
.3021 .58208 m .30049 .58341 L .29815 .58284 L F
.399 .477 .824 r
.29815 .58284 m .2989 .58111 L .29722 .5802 L F
.2989 .58111 m .2993 .58021 L .29845 .5802 L F
.2989 .58111 m .29845 .5802 L .29722 .5802 L F
.29815 .58284 m .30049 .58341 L .2993 .58021 L F
.925 .605 .417 r
.29993 .58318 m .29832 .58522 L .29812 .58243 L F
.30049 .58341 m .30018 .58368 L .29993 .58318 L F
.30018 .58368 m .29832 .58522 L .29993 .58318 L F
.468 0 0 r
.30271 .58196 m .30049 .58341 L .3021 .58208 L F
.978 .842 .638 r
.30271 .58196 m .30213 .58472 L .30049 .58341 L F
.948 .878 .732 r
.32439 .62763 m .32633 .62714 L .32471 .62241 L F
.534 .609 .874 r
.25159 .6101 m .25455 .60891 L .25165 .60841 L F
.25159 .6101 m .25595 .6122 L .25455 .60891 L F
.8 .934 .569 r
.43193 .55464 m .43147 .55471 L .43312 .55171 L F
.683 .526 .666 r
.43339 .55133 m .43327 .55152 L .43324 .5514 L F
.43603 .54698 m .43338 .55129 L .43182 .54625 L F
.43339 .55133 m .43324 .5514 L .43182 .54625 L F
.815 .637 .662 r
.43182 .54625 m .43327 .55148 L .42986 .54975 L F
.8 .934 .569 r
.43193 .55464 m .43312 .55171 L .43335 .55135 L F
.815 .637 .662 r
.43327 .55148 m .43327 .55152 L .43325 .55151 L F
.43327 .55148 m .43325 .55151 L .42986 .54975 L F
.8 .934 .569 r
.43321 .55157 m .43312 .55171 L .43318 .55161 L F
.849 .876 .86 r
.43327 .55152 m .42911 .55283 L .42986 .54975 L F
.43323 .55153 m .43343 .55117 L .42911 .55283 L F
.8 .934 .569 r
.43323 .55154 m .43318 .55161 L .43343 .55117 L F
.43321 .55157 m .43318 .55161 L .43323 .55154 L F
.43335 .55135 m .43321 .55157 L .43343 .55117 L F
.849 .876 .86 r
.43327 .55152 m .43343 .55117 L .43323 .55153 L F
.683 .526 .666 r
.43606 .54698 m .43343 .55126 L .4334 .55127 L F
.015 .064 .568 r
.43568 .552 m .4367 .55032 L .43606 .54698 L F
.539 .169 .287 r
.43359 .55123 m .43654 .55058 L .43568 .552 L F
.683 .526 .666 r
.43606 .54698 m .43654 .54952 L .43343 .55126 L F
.43654 .54952 m .4367 .55032 L .43357 .55122 L F
.43654 .54952 m .43357 .55122 L .43343 .55126 L F
.4334 .55127 m .43339 .55133 L .43338 .55129 L F
.43343 .55126 m .43339 .55133 L .4334 .55127 L F
.784 .916 .928 r
.43343 .55117 m .43357 .55122 L .43335 .55135 L F
.43357 .55122 m .43359 .55123 L .43339 .55133 L F
.539 .169 .287 r
.43357 .55122 m .43654 .55058 L .43359 .55123 L F
.43343 .55117 m .43442 .55098 L .43357 .55122 L F
.43442 .55098 m .43654 .55058 L .43357 .55122 L F
.784 .916 .928 r
.43359 .55123 m .43568 .552 L .43335 .55135 L F
.43339 .55133 m .43335 .55135 L .43335 .55135 L F
.43359 .55123 m .43335 .55135 L .43339 .55133 L F
.683 .526 .666 r
.43339 .55133 m .4367 .55032 L .43327 .55152 L F
.43343 .55126 m .43357 .55122 L .43339 .55133 L F
.43357 .55122 m .4367 .55032 L .43339 .55133 L F
.784 .916 .928 r
.43357 .55122 m .43339 .55133 L .43335 .55135 L F
.539 .169 .287 r
.43442 .55098 m .4367 .55032 L .43654 .55058 L F
.43343 .55117 m .4367 .55032 L .43442 .55098 L F
.683 .526 .666 r
.43606 .54698 m .43338 .55129 L .43603 .54698 L F
.784 .916 .928 r
.43335 .55135 m .43568 .552 L .43193 .55464 L F
.836 .53 .471 r
.37431 .53085 m .37823 .53424 L .37666 .53015 L F
.37431 .53085 m .37407 .53357 L .37823 .53424 L F
.963 .706 .5 r
.37407 .53357 m .37608 .53751 L .37823 .53424 L F
.893 .562 .414 r
.34061 .52459 m .33691 .52362 L .33695 .52081 L F
.878 .704 .661 r
.33831 .52594 m .33691 .52362 L .34061 .52459 L F
.732 .497 .571 r
.50527 .45693 m .50804 .45767 L .5078 .4541 L F
.573 .669 .903 r
.51025 .4363 m .50946 .43756 L .50531 .43331 L F
.32 .276 .652 r
.53687 .41102 m .53929 .41319 L .53897 .40895 L F
.53687 .41102 m .53729 .41379 L .53929 .41319 L F
.853 .951 .599 r
.42941 .50818 m .42988 .50598 L .43159 .50446 L F
.831 .407 .233 r
.42988 .50598 m .43373 .50718 L .43159 .50446 L F
.375 0 .092 r
.63614 .35142 m .63853 .35227 L .63883 .35005 L F
.63614 .35142 m .63521 .35303 L .63853 .35227 L F
.79 .786 .849 r
.4017 .55022 m .40327 .55372 L .40511 .54988 L F
.093 0 0 r
.45607 .44398 m .45964 .4408 L .4584 .44298 L F
0 0 0 r
.4584 .44298 m .45964 .4408 L .462 .43955 L F
.386 .498 .85 r
.25165 .60841 m .25455 .60891 L .253 .60659 L F
.365 .034 .264 r
.25019 .6017 m .25266 .60112 L .25368 .59986 L F
0 .134 .681 r
.3156 .68161 m .31722 .68457 L .31797 .68396 L F
.026 .495 .879 r
.31722 .68457 m .31988 .68543 L .31797 .68396 L F
.674 .825 .956 r
.64976 .38371 m .65061 .38097 L .64819 .38295 L F
.64976 .38371 m .65124 .38303 L .65061 .38097 L F
.813 .482 .428 r
.64819 .38295 m .65093 .38483 L .64976 .38371 L F
.885 .882 .826 r
.34245 .62501 m .34501 .62175 L .343 .62071 L F
0 0 0 r
.53863 .427 m .53856 .42829 L .53917 .42669 L F
.53863 .427 m .53797 .43065 L .53856 .42829 L F
.697 .916 .969 r
.53885 .42713 m .53856 .42829 L .5375 .42728 L F
.083 0 0 r
.5405 .42694 m .53917 .42669 L .53856 .42829 L F
.697 .916 .969 r
.5405 .42694 m .53856 .42829 L .53885 .42713 L F
0 0 0 r
.53797 .43065 m .53791 .43102 L .53856 .42829 L F
.844 .964 .882 r
.62572 .34459 m .62472 .34768 L .62727 .34624 L F
.62572 .34459 m .62229 .34749 L .62472 .34768 L F
.832 .51 .444 r
.30946 .52414 m .31346 .5275 L .31373 .52457 L F
.519 .1 .185 r
.43606 .54698 m .43853 .54684 L .44024 .54452 L F
.6 .289 .413 r
.43862 .54909 m .43606 .54698 L .4367 .55032 L F
.43862 .54909 m .43916 .5468 L .43606 .54698 L F
0 0 .182 r
.43606 .54698 m .43651 .54684 L .4367 .55032 L F
.539 .169 .287 r
.4367 .55032 m .43343 .55117 L .43327 .55152 L F
.4367 .55032 m .43598 .55199 L .43343 .55117 L F
.43343 .55117 m .43598 .55199 L .4367 .55032 L F
.94 .916 .764 r
.43357 .55153 m .4367 .55032 L .43659 .54825 L F
.43482 .54953 m .43659 .54825 L .43651 .54684 L F
.43357 .55153 m .43659 .54825 L .43482 .54953 L F
.519 .1 .185 r
.43853 .54684 m .43916 .5468 L .43946 .54616 L F
.43853 .54684 m .43946 .54616 L .44024 .54452 L F
0 0 .167 r
.44024 .54452 m .44178 .54015 L .44275 .5428 L F
.44024 .54452 m .44137 .54434 L .44178 .54015 L F
0 0 .449 r
.44164 .54602 m .44024 .54452 L .43916 .5468 L F
.44164 .54602 m .44137 .54434 L .44024 .54452 L F
.517 .808 .998 r
.51451 .43813 m .51893 .43865 L .51726 .43721 L F
.701 .898 .967 r
.51893 .43865 m .51996 .4361 L .51726 .43721 L F
.51893 .43865 m .52147 .43725 L .51996 .4361 L F
.802 .962 .913 r
.40798 .57173 m .40442 .57394 L .40402 .57288 L F
.40798 .57173 m .40402 .57288 L .40931 .57296 L F
.536 .916 .77 r
.49324 .40359 m .49475 .40213 L .49668 .40143 L F
.526 .916 .917 r
.49324 .40359 m .49215 .40334 L .49475 .40213 L F
.864 .477 .307 r
.35487 .52076 m .3576 .52496 L .35917 .52463 L F
.862 .472 .303 r
.3576 .52496 m .35714 .52604 L .35917 .52463 L F
.458 .364 .661 r
.35917 .52463 m .36188 .52715 L .36246 .52495 L F
.737 .28 .165 r
.35714 .52604 m .36188 .52715 L .35917 .52463 L F
.846 .583 .54 r
.31346 .5275 m .31335 .53026 L .31781 .53116 L F
.759 .469 .493 r
.31555 .53344 m .31781 .53116 L .31335 .53026 L F
.31555 .53344 m .3175 .53382 L .31781 .53116 L F
.735 .713 .831 r
.31675 .65553 m .31021 .65275 L .31477 .65156 L F
.694 .758 .901 r
.31968 .65238 m .31675 .65553 L .31477 .65156 L F
.634 .654 .852 r
.31968 .65238 m .3215 .65556 L .31675 .65553 L F
.646 .433 .581 r
.31675 .65553 m .31965 .65732 L .31531 .65725 L F
.31675 .65553 m .3215 .65556 L .31965 .65732 L F
.848 .992 .74 r
.28502 .55315 m .28329 .55541 L .28502 .55456 L F
.168 .705 .815 r
.54709 .37535 m .54515 .37524 L .54959 .37505 L F
0 0 0 r
.56211 .36443 m .56274 .36352 L .56343 .36306 L F
.471 .352 .636 r
.56159 .36634 m .56381 .36599 L .56274 .36352 L F
0 .272 .769 r
.56536 .36578 m .56274 .36352 L .56381 .36599 L F
.56536 .36578 m .56591 .36543 L .56274 .36352 L F
.505 0 0 r
.56274 .36352 m .56591 .36543 L .56208 .36396 L F
.56274 .36352 m .56208 .36396 L .56189 .36388 L F
0 0 0 r
.56343 .36306 m .56274 .36352 L .56382 .36265 L F
.178 .359 .807 r
.25764 .59689 m .25564 .59495 L .25857 .59483 L F
.806 .982 .704 r
.57577 .38081 m .5768 .37801 L .57826 .38011 L F
.57577 .38081 m .57413 .38148 L .5768 .37801 L F
.824 .718 .749 r
.3192 .57381 m .32401 .57156 L .3219 .57013 L F
.3192 .57381 m .3214 .57519 L .32401 .57156 L F
.55 .931 .84 r
.42538 .55786 m .42294 .55923 L .42032 .55999 L F
.871 .552 .444 r
.31139 .53705 m .30824 .53711 L .3081 .53429 L F
.521 .889 .972 r
.33914 .62509 m .34245 .62501 L .3405 .62454 L F
.885 .882 .826 r
.34245 .62501 m .343 .62071 L .3405 .62454 L F
.465 .289 .556 r
.26415 .55678 m .26438 .55759 L .26466 .55489 L F
.372 .128 .41 r
.26438 .55759 m .26719 .5543 L .26466 .55489 L F
0 0 0 r
.38122 .55817 m .38337 .55536 L .38252 .55567 L F
0 0 .298 r
.38208 .56065 m .38122 .55817 L .38252 .55567 L F
.426 0 0 r
.64552 .36922 m .64971 .36944 L .64558 .36981 L F
.52 .196 .359 r
.3067 .5243 m .30882 .5265 L .30946 .52414 L F
.3067 .5243 m .30455 .52725 L .30882 .5265 L F
.845 .892 .872 r
.64045 .37958 m .63902 .38091 L .63763 .37939 L F
.93 .875 .761 r
.53818 .45305 m .53875 .45665 L .53978 .4544 L F
.53818 .45305 m .53629 .45638 L .53875 .45665 L F
.989 .874 .621 r
.53629 .45638 m .53667 .46026 L .53875 .45665 L F
.811 .775 .82 r
.43248 .51068 m .43587 .50783 L .43373 .50718 L F
.812 .95 .911 r
.53032 .38732 m .52812 .38967 L .52868 .38689 L F
.178 0 0 r
.52868 .38689 m .53014 .38727 L .53032 .38732 L F
.53014 .38727 m .53289 .38798 L .53032 .38732 L F
.806 .989 .882 r
.53072 .38742 m .53032 .38732 L .53127 .38635 L F
.52918 .39039 m .53032 .38732 L .53072 .38742 L F
.52918 .39039 m .52812 .38967 L .53032 .38732 L F
.507 0 0 r
.52918 .39039 m .52835 .3899 L .52812 .38967 L F
.426 0 0 r
.5295 .42311 m .53065 .42471 L .52776 .42348 L F
.5295 .42311 m .53217 .42358 L .53065 .42471 L F
.871 .63 .572 r
.35573 .55474 m .35543 .5577 L .3531 .55376 L F
.771 .915 .936 r
.52191 .47368 m .52562 .47338 L .52439 .47219 L F
.841 .851 .852 r
.52191 .47368 m .52372 .47515 L .52562 .47338 L F
.847 .927 .882 r
.52439 .47219 m .52562 .47338 L .52859 .47036 L F
.888 .507 .309 r
.65792 .34198 m .66165 .3458 L .66145 .34362 L F
.636 .944 .723 r
.52675 .4026 m .52526 .40437 L .52755 .40323 L F
.624 .825 .419 r
.53 .39943 m .52886 .40102 L .52755 .40323 L F
.644 .964 .906 r
.52886 .40102 m .52675 .4026 L .52755 .40323 L F
0 0 0 r
.52281 .36304 m .52246 .36467 L .52197 .36238 L F
.928 .973 .737 r
.52281 .36304 m .52197 .36238 L .52419 .3587 L F
0 0 .447 r
.57114 .3538 m .5703 .35348 L .56824 .35177 L F
.57114 .3538 m .57159 .35567 L .5703 .35348 L F
.697 .19 .028 r
.29082 .54862 m .28915 .55009 L .29141 .5498 L F
.86 .748 .739 r
.29141 .5498 m .29364 .54729 L .29082 .54862 L F
.965 .737 .297 r
.33865 .61316 m .33952 .61172 L .33523 .61144 L F
0 0 .479 r
.57986 .34978 m .57989 .35372 L .58128 .35101 L F
0 0 .371 r
.57989 .35372 m .58105 .35413 L .58128 .35101 L F
.57989 .35372 m .58014 .35638 L .58105 .35413 L F
.678 .953 .953 r
.65895 .3795 m .66034 .37728 L .65809 .37886 L F
.65895 .3795 m .66281 .37756 L .66034 .37728 L F
.051 .595 .844 r
.36264 .57183 m .36019 .57092 L .3592 .57072 L F
.456 .867 .954 r
.36605 .57096 m .36361 .57014 L .36264 .57183 L F
.431 .845 .965 r
.36264 .57183 m .36361 .57014 L .36019 .57092 L F
.589 .698 .918 r
.36019 .57092 m .36361 .57014 L .35909 .56943 L F
.538 .722 .958 r
.35909 .56943 m .36288 .57003 L .36354 .56919 L F
.36288 .57003 m .36361 .57014 L .36354 .56919 L F
.802 .915 .915 r
.36354 .56919 m .36398 .56882 L .36412 .56808 L F
.456 .867 .954 r
.36474 .57038 m .36361 .57014 L .36605 .57096 L F
0 0 .333 r
.36673 .57079 m .36569 .56738 L .36361 .57014 L F
.802 .915 .915 r
.36355 .5693 m .36361 .57014 L .36412 .56946 L F
.364 .56889 m .36412 .56946 L .36569 .56738 L F
.36355 .5693 m .36412 .56946 L .364 .56889 L F
.953 .951 .715 r
.36383 .56997 m .36376 .56994 L .36398 .56882 L F
.364 .56889 m .36398 .56882 L .36412 .56808 L F
.36383 .56997 m .36398 .56882 L .364 .56889 L F
.36337 .57293 m .364 .56889 L .36569 .56738 L F
.364 .56889 m .36412 .56808 L .36569 .56738 L F
.802 .915 .915 r
.36354 .56919 m .36355 .5693 L .36569 .56738 L F
.36398 .56882 m .36569 .56738 L .36412 .56808 L F
.953 .951 .715 r
.36376 .56994 m .36339 .56977 L .36412 .56808 L F
0 0 .089 r
.36412 .56808 m .36378 .56889 L .36354 .56919 L F
.36378 .56889 m .36253 .57179 L .36354 .56919 L F
.953 .951 .715 r
.36337 .57293 m .36253 .57179 L .36339 .56977 L F
.36337 .57293 m .36339 .56977 L .36383 .56997 L F
.456 .867 .954 r
.36673 .57079 m .36474 .57038 L .36605 .57096 L F
.845 .892 .872 r
.64045 .37958 m .63763 .37939 L .64047 .37439 L F
.693 .705 .857 r
.64441 .3766 m .64045 .37958 L .64047 .37439 L F
.898 .93 .83 r
.51205 .45741 m .51339 .45278 L .51456 .45381 L F
.935 .951 .767 r
.51456 .45381 m .51575 .44918 L .51813 .4513 L F
.51456 .45381 m .51339 .45278 L .51575 .44918 L F
.78 .961 .65 r
.64354 .36825 m .64412 .36481 L .64535 .36617 L F
.64354 .36825 m .64341 .36708 L .64412 .36481 L F
.64354 .36825 m .64228 .36903 L .64341 .36708 L F
.234 0 0 r
.33868 .63897 m .33667 .64043 L .33443 .64109 L F
.668 .861 .973 r
.33984 .63629 m .33868 .63897 L .34125 .63759 L F
.33984 .63629 m .33868 .63897 L .34125 .63759 L F
.579 .855 .996 r
.32622 .62002 m .32792 .62176 L .32991 .62054 L F
.676 .806 .945 r
.39013 .58875 m .39385 .58942 L .39256 .5875 L F
.303 .68 .976 r
.39385 .58942 m .39594 .58796 L .39256 .5875 L F
.39385 .58942 m .39824 .58997 L .39594 .58796 L F
.507 .274 .495 r
.24841 .5955 m .25123 .59553 L .2518 .59186 L F
.475 .28 .536 r
.2518 .59186 m .25298 .59198 L .25424 .58858 L F
.513 .279 .497 r
.2518 .59186 m .25395 .59486 L .25298 .59198 L F
.2518 .59186 m .25123 .59553 L .25395 .59486 L F
.562 .083 .075 r
.343 .62071 m .34108 .61935 L .33996 .62083 L F
0 0 0 r
.57666 .36824 m .57805 .36776 L .57983 .36706 L F
.941 .705 .554 r
.37489 .58154 m .3731 .58193 L .37326 .57757 L F
.562 .021 0 r
.37303 .58249 m .3731 .58193 L .37489 .58154 L F
0 0 .375 r
.37489 .58154 m .37606 .58463 L .37576 .58221 L F
.37489 .58154 m .37576 .58221 L .37303 .58249 L F
.975 .669 .323 r
.66757 .35117 m .66902 .35007 L .66604 .34832 L F
.66757 .35117 m .66937 .35286 L .66902 .35007 L F
0 0 0 r
.4382 .44549 m .43965 .44445 L .43609 .44699 L F
.44197 .44343 m .43965 .44445 L .4382 .44549 L F
.266 .288 .698 r
.2856 .66847 m .28667 .67362 L .28806 .67056 L F
.447 .484 .805 r
.28667 .67362 m .28923 .67432 L .28806 .67056 L F
.28667 .67362 m .28735 .67458 L .28923 .67432 L F
.914 .952 .806 r
.37524 .52644 m .37431 .53085 L .37666 .53015 L F
.37524 .52644 m .37275 .53007 L .37431 .53085 L F
.988 .718 .388 r
.37275 .53007 m .37407 .53357 L .37431 .53085 L F
.913 .975 .692 r
.29669 .59149 m .29453 .59515 L .29436 .59312 L F
.416 .834 .661 r
.29436 .59312 m .29925 .59033 L .29669 .59149 L F
.075 0 0 r
.43254 .46139 m .43254 .46114 L .43513 .46022 L F
.539 0 0 r
.65339 .33982 m .65599 .34123 L .65729 .34031 L F
.805 .323 .059 r
.65729 .34031 m .65599 .34123 L .65792 .34198 L F
.672 .962 .747 r
.57986 .34978 m .58157 .34747 L .58202 .34773 L F
0 0 .467 r
.57986 .34978 m .58128 .35101 L .58157 .34747 L F
.448 .679 .963 r
.61113 .36683 m .61246 .36465 L .60998 .36489 L F
.61113 .36683 m .61246 .36465 L .60998 .36489 L F
.737 .909 .536 r
.60344 .36631 m .60132 .36962 L .60102 .37042 L F
.96 .63 .249 r
.60016 .37162 m .60102 .37042 L .60132 .36962 L F
.60016 .37162 m .60163 .37313 L .60102 .37042 L F
.534 .745 .972 r
.30101 .63414 m .30574 .63594 L .30295 .6362 L F
.165 0 0 r
.41398 .46234 m .41654 .46161 L .41801 .45966 L F
.154 0 .071 r
.41801 .45966 m .42018 .45971 L .42111 .4572 L F
.131 0 0 r
.41654 .46161 m .42018 .45971 L .41801 .45966 L F
.881 .988 .725 r
.2807 .55673 m .27824 .56039 L .28045 .55834 L F
.793 .443 .394 r
.29453 .59515 m .29849 .59717 L .29437 .5985 L F
.027 0 0 r
.29437 .5985 m .29849 .59717 L .29656 .59814 L F
.139 .544 .923 r
.29849 .59717 m .30075 .59778 L .29883 .59616 L F
.656 .961 .767 r
.29656 .59814 m .29849 .59717 L .29883 .59616 L F
.139 .544 .923 r
.29849 .59717 m .30075 .59778 L .29883 .59616 L F
0 0 0 r
.46229 .42918 m .46376 .42754 L .46016 .42988 L F
.48 .098 .237 r
.53132 .35651 m .53092 .35803 L .52849 .35677 L F
.629 .615 .818 r
.53092 .35803 m .52917 .35412 L .52849 .35677 L F
.624 .851 .986 r
.50704 .40585 m .50836 .40632 L .50445 .40695 L F
.966 .937 .657 r
.53182 .46227 m .53126 .46714 L .5336 .46392 L F
.852 .904 .871 r
.53182 .46227 m .5336 .46392 L .53667 .46026 L F
.911 .711 .619 r
.31238 .57074 m .30954 .57093 L .31046 .56699 L F
.96 .946 .683 r
.30915 .57451 m .30954 .57093 L .31238 .57074 L F
0 0 0 r
.42018 .45971 m .4235 .45636 L .42111 .4572 L F
.64931 .35005 m .6489 .35184 L .65008 .34976 L F
.684 .21 .121 r
.30856 .64775 m .31266 .64869 L .31016 .65042 L F
0 0 .147 r
.3144 .64752 m .31266 .64869 L .31529 .64502 L F
0 0 0 r
.31016 .65042 m .31266 .64869 L .3144 .64752 L F
.377 0 .191 r
.36495 .52587 m .36415 .52322 L .36366 .52412 L F
.579 .336 .512 r
.38563 .54706 m .38809 .54465 L .38386 .54439 L F
.38563 .54706 m .38795 .54708 L .38809 .54465 L F
.597 .355 .52 r
.38795 .54708 m .39086 .5443 L .38809 .54465 L F
0 0 .519 r
.42901 .51047 m .42727 .50705 L .42941 .50818 L F
.42901 .51047 m .42849 .50886 L .42727 .50705 L F
.947 .923 .751 r
.42901 .51047 m .42563 .51248 L .42849 .50886 L F
.42901 .51047 m .42651 .51393 L .42563 .51248 L F
.863 .657 .623 r
.37344 .57477 m .36941 .57689 L .37018 .57423 L F
.37344 .57477 m .37326 .57757 L .36941 .57689 L F
.92 .652 .514 r
.35633 .56415 m .35324 .56411 L .35331 .5606 L F
.909 .797 .725 r
.35633 .56415 m .35217 .56661 L .35324 .56411 L F
.35633 .56415 m .35418 .56767 L .35217 .56661 L F
.984 .833 .442 r
.5589 .41887 m .55844 .41636 L .55825 .41901 L F
.894 .987 .739 r
.55542 .42228 m .5589 .41887 L .55825 .41901 L F
.292 0 .172 r
.48032 .42712 m .47996 .42935 L .47736 .43017 L F
.311 0 .177 r
.48275 .42823 m .48032 .42712 L .48228 .42551 L F
.48275 .42823 m .47996 .42935 L .48032 .42712 L F
.805 .684 .731 r
.34893 .644 m .34505 .64168 L .3479 .64098 L F
.34893 .644 m .34688 .64551 L .34505 .64168 L F
.488 .563 .858 r
.34128 .627 m .3392 .6292 L .33814 .62541 L F
.431 .415 .74 r
.34128 .627 m .33993 .63034 L .3392 .6292 L F
.811 .775 .82 r
.43248 .51068 m .43373 .50718 L .43301 .5106 L F
.034 .281 .776 r
.43301 .5106 m .43378 .51416 L .43248 .51068 L F
.682 .841 .418 r
.38701 .56323 m .38511 .56657 L .38665 .56356 L F
.13 .366 .825 r
.38925 .56271 m .38917 .56493 L .38701 .56323 L F
.38925 .56271 m .38701 .56323 L .38665 .56356 L F
.895 .757 .701 r
.3192 .57381 m .32055 .57764 L .3214 .57519 L F
.3192 .57381 m .3173 .57736 L .32055 .57764 L F
.895 .852 .793 r
.31633 .57949 m .32055 .57764 L .3173 .57736 L F
.31633 .57949 m .31825 .58072 L .32055 .57764 L F
0 0 0 r
.57232 .3999 m .57444 .39645 L .57443 .3984 L F
.083 .643 .732 r
.63957 .33934 m .64242 .3391 L .6437 .33904 L F
.053 0 0 r
.6437 .33904 m .64242 .3391 L .64649 .3391 L F
.732 .449 .499 r
.28701 .53115 m .29029 .5338 L .29076 .53116 L F
.758 .852 .92 r
.25915 .60875 m .25662 .6073 L .25455 .60891 L F
.861 .835 .819 r
.25929 .60384 m .25662 .6073 L .25915 .60875 L F
0 .171 .633 r
.54593 .40759 m .54383 .40618 L .54302 .40533 L F
.955 .815 .665 r
.49072 .47711 m .48769 .47955 L .48964 .47575 L F
.49072 .47711 m .48947 .48087 L .48769 .47955 L F
.698 .675 .824 r
.29533 .67941 m .29613 .67462 L .29363 .67554 L F
.29533 .67941 m .29766 .67844 L .29613 .67462 L F
.96 .946 .683 r
.30915 .57451 m .30825 .57336 L .30954 .57093 L F
.684 .389 .469 r
.38554 .5542 m .38252 .55567 L .38337 .55536 L F
.646 .469 .629 r
.38511 .56657 m .38753 .56672 L .38665 .56356 L F
.38511 .56657 m .38566 .56787 L .38753 .56672 L F
0 0 .26 r
.30188 .5876 m .30049 .58341 L .30213 .58472 L F
.697 .555 .689 r
.27557 .65519 m .27954 .65175 L .27582 .6523 L F
.925 .761 .66 r
.64971 .36944 m .65109 .37368 L .64951 .37198 L F
.7 .87 .962 r
.65109 .37368 m .64679 .37357 L .64951 .37198 L F
.991 .848 .602 r
.27993 .64861 m .27772 .64984 L .27981 .64855 L F
.27993 .64861 m .27954 .65175 L .27772 .64984 L F
0 0 0 r
.27926 .65025 m .27993 .64861 L .2794 .64973 L F
.865 .464 0 r
.27772 .64984 m .27954 .65175 L .28026 .65433 L F
.27772 .64984 m .28026 .65433 L .27713 .65289 L F
.71 .176 0 r
.27843 .65411 m .28026 .65433 L .27917 .65486 L F
.27819 .65338 m .28026 .65433 L .27859 .65413 L F
.27834 .65392 m .27859 .65413 L .27839 .65411 L F
.27819 .65338 m .27859 .65413 L .27834 .65392 L F
.737 .566 .661 r
.28076 .6494 m .28448 .64633 L .28238 .64798 L F
.55 .407 .639 r
.27917 .6507 m .27833 .65391 L .27925 .65063 L F
.27833 .65391 m .27834 .65392 L .27937 .65019 L F
0 0 0 r
.2793 .65015 m .28238 .64798 L .27993 .64861 L F
.27936 .65018 m .28238 .64798 L .2793 .65015 L F
.55 .407 .639 r
.27929 .65024 m .27917 .6507 L .27937 .65019 L F
.27917 .6507 m .27925 .65063 L .27937 .65019 L F
.153 0 0 r
.28173 .65107 m .28369 .64899 L .27971 .65066 L F
0 0 .159 r
.27937 .65026 m .27821 .65437 L .27941 .65188 L F
.27936 .65024 m .27821 .65437 L .27937 .65026 L F
.27977 .65039 m .27941 .65188 L .28005 .65053 L F
.27937 .65019 m .27941 .65188 L .27977 .65039 L F
.55 .407 .639 r
.27713 .65289 m .27815 .65429 L .27827 .65386 L F
.71 .176 0 r
.27713 .65289 m .27819 .65338 L .27834 .65392 L F
.588 .936 .764 r
.27994 .64814 m .27981 .64855 L .27772 .64984 L F
.55 .407 .639 r
.27713 .65289 m .27827 .65386 L .27975 .64846 L F
0 0 0 r
.28076 .6494 m .28238 .64798 L .27926 .65025 L F
.55 .407 .639 r
.27815 .65429 m .27821 .65437 L .27975 .64846 L F
.71 .176 0 r
.27713 .65289 m .27834 .65392 L .27839 .65411 L F
.153 0 0 r
.28 .65101 m .27971 .65066 L .27896 .65097 L F
.953 .737 .574 r
.28026 .65433 m .2824 .6551 L .28154 .6581 L F
.28026 .65433 m .28154 .6581 L .28089 .65607 L F
.208 .163 .584 r
.28026 .65433 m .28232 .65656 L .2823 .65506 L F
.28026 .65433 m .28089 .65607 L .28232 .65656 L F
.28026 .65433 m .2823 .65506 L .27917 .65486 L F
.539 .552 .816 r
.27917 .65486 m .2823 .65506 L .28013 .65096 L F
.153 0 0 r
.28065 .65085 m .27971 .65066 L .27995 .65095 L F
.539 .552 .816 r
.27917 .65486 m .28003 .65098 L .27838 .65406 L F
.153 0 0 r
.28013 .65096 m .27995 .65095 L .27998 .65098 L F
.539 .552 .816 r
.28003 .65098 m .28006 .65082 L .27998 .65098 L F
.28003 .65098 m .27998 .65098 L .27838 .65406 L F
.153 0 0 r
.28003 .65098 m .27998 .65098 L .27999 .65099 L F
.28013 .65096 m .27998 .65098 L .28003 .65098 L F
.28065 .65085 m .27995 .65095 L .28013 .65096 L F
.28173 .65107 m .28065 .65085 L .28018 .65096 L F
.109 .304 .778 r
.28018 .65096 m .28347 .65495 L .28173 .65107 L F
.153 0 0 r
.28096 .65104 m .28018 .65096 L .28 .65101 L F
.28173 .65107 m .28018 .65096 L .28096 .65104 L F
.109 .304 .778 r
.28018 .65096 m .2823 .65506 L .28347 .65495 L F
.28006 .65082 m .28013 .65096 L .28018 .65096 L F
.28013 .65096 m .2823 .65506 L .28018 .65096 L F
.153 0 0 r
.28065 .65085 m .27999 .65099 L .28 .65101 L F
.109 .304 .778 r
.28006 .65082 m .28018 .65096 L .28173 .65107 L F
.539 .552 .816 r
.28003 .65098 m .28013 .65096 L .28006 .65082 L F
.27917 .65486 m .28013 .65096 L .28003 .65098 L F
0 0 .159 r
.27937 .65019 m .27936 .65024 L .27937 .65026 L F
.737 .566 .661 r
.27981 .65026 m .28369 .64899 L .28448 .64633 L F
.27896 .65097 m .27971 .65066 L .27981 .65026 L F
.27971 .65066 m .28369 .64899 L .27981 .65026 L F
0 0 0 r
.27896 .65097 m .28076 .6494 L .27926 .65025 L F
.2794 .64973 m .27993 .64861 L .27981 .64855 L F
0 0 .159 r
.27994 .64814 m .27937 .65019 L .27968 .65035 L F
.28003 .65011 m .27968 .65035 L .28005 .65053 L F
.27994 .64814 m .27968 .65035 L .28003 .65011 L F
.737 .566 .661 r
.27968 .65035 m .28288 .64767 L .28076 .6494 L F
.27896 .65097 m .27981 .65026 L .27968 .65035 L F
.27981 .65026 m .28288 .64767 L .27968 .65035 L F
.28288 .64767 m .28448 .64633 L .28076 .6494 L F
.55 .407 .639 r
.27833 .65391 m .27821 .65437 L .27834 .65392 L F
.539 .552 .816 r
.27917 .65486 m .27838 .65406 L .27821 .65437 L F
.71 .176 0 r
.27839 .65411 m .27843 .65411 L .27917 .65486 L F
0 0 .159 r
.28005 .65053 m .27837 .65404 L .28006 .65082 L F
.27837 .65404 m .27821 .65437 L .27838 .65406 L F
.27837 .65404 m .27838 .65406 L .28006 .65082 L F
0 0 0 r
.27926 .65025 m .27936 .65018 L .2793 .65015 L F
.681 .741 .238 r
.27896 .65097 m .2794 .64973 L .27994 .64814 L F
.2794 .64973 m .27981 .64855 L .27994 .64814 L F
.55 .407 .639 r
.27975 .64846 m .27948 .6495 L .27994 .64814 L F
.27948 .6495 m .27929 .65024 L .27994 .64814 L F
.27929 .65024 m .27937 .65019 L .27994 .64814 L F
0 0 0 r
.27896 .65097 m .27926 .65025 L .2794 .64973 L F
0 0 .175 r
.25424 .58858 m .25298 .59198 L .25527 .58943 L F
0 0 0 r
.57071 .37672 m .56951 .37886 L .56908 .37904 L F
.564 .141 .197 r
.57389 .37866 m .57071 .37672 L .57495 .3742 L F
.57389 .37866 m .56951 .37886 L .57071 .37672 L F
.746 .828 .915 r
.3287 .60875 m .32456 .60851 L .32654 .60757 L F
.563 .879 .992 r
.32985 .60692 m .3287 .60875 L .32654 .60757 L F
.32985 .60692 m .33238 .60795 L .3287 .60875 L F
.826 .986 .877 r
.53856 .42829 m .53791 .43102 L .53693 .43029 L F
.943 .667 .485 r
.41721 .57597 m .41989 .58113 L .41885 .57832 L F
.41721 .57597 m .41796 .58059 L .41989 .58113 L F
.949 .892 .738 r
.41796 .58059 m .4177 .585 L .41989 .58113 L F
.716 .609 .736 r
.41885 .57832 m .41989 .58113 L .42292 .57801 L F
.414 .694 .978 r
.5102 .40532 m .51119 .4072 L .50836 .40632 L F
0 0 .464 r
.51185 .40744 m .51119 .4072 L .5102 .40532 L F
.51185 .40744 m .51221 .40836 L .51119 .4072 L F
.582 .576 .811 r
.51522 .39327 m .51302 .39482 L .51536 .39285 L F
.632 .521 .71 r
.51822 .39184 m .51536 .39285 L .51792 .38991 L F
.727 .467 .534 r
.51822 .39184 m .51522 .39327 L .51536 .39285 L F
.465 .16 .364 r
.26719 .5543 m .26986 .55383 L .27052 .55153 L F
.344 .061 .331 r
.26986 .55383 m .27299 .55071 L .27052 .55153 L F
.979 .743 .509 r
.37112 .55932 m .37303 .56082 L .37317 .55795 L F
.449 .834 .986 r
.37317 .55795 m .37397 .5566 L .37112 .55932 L F
.37317 .55795 m .37577 .55733 L .37397 .5566 L F
.613 .475 .67 r
.37303 .56082 m .37577 .55733 L .37317 .55795 L F
.878 .856 .817 r
.31347 .58278 m .31238 .58396 L .31528 .58413 L F
.881 .816 .78 r
.31079 .58648 m .31528 .58413 L .31238 .58396 L F
.31079 .58648 m .31288 .5878 L .31528 .58413 L F
.848 .862 .853 r
.31347 .58278 m .31528 .58413 L .31825 .58072 L F
.532 .836 .516 r
.46016 .42988 m .45692 .43318 L .4589 .43161 L F
0 0 0 r
.4589 .43161 m .46229 .42918 L .46016 .42988 L F
.57633 .37223 m .57495 .3742 L .57399 .37341 L F
.51782 .43388 m .51784 .43354 L .51462 .43479 L F
.649 .129 0 r
.51996 .4361 m .51784 .43354 L .51782 .43388 L F
.738 .976 .922 r
.51335 .4829 m .51216 .48236 L .51113 .48464 L F
.639 .877 .985 r
.51113 .48464 m .51216 .48236 L .50956 .48351 L F
0 .067 .589 r
.5861 .34973 m .58851 .352 L .58943 .35328 L F
.853 .974 .868 r
.58943 .35328 m .58851 .352 L .59192 .34864 L F
.569 .242 .374 r
.58943 .35328 m .5901 .35574 L .58851 .352 L F
.58943 .35328 m .59302 .3558 L .5901 .35574 L F
.501 0 0 r
.59448 .35637 m .59302 .3558 L .58943 .35328 L F
.91 .982 .742 r
.54836 .43294 m .55131 .4303 L .55034 .42935 L F
.54836 .43294 m .54899 .43391 L .55131 .4303 L F
.927 .966 .77 r
.55034 .42935 m .55131 .4303 L .55346 .42657 L F
.57 .887 .613 r
.49979 .41673 m .49927 .41773 L .50163 .41714 L F
.294 0 0 r
.60507 .34475 m .60947 .343 L .60532 .3433 L F
.60507 .34475 m .60805 .34448 L .60947 .343 L F
0 0 0 r
.60947 .343 m .61076 .34346 L .61222 .34316 L F
.60947 .343 m .60805 .34448 L .61076 .34346 L F
.433 0 0 r
.30084 .62358 m .30235 .62148 L .2999 .62179 L F
.94 .963 .69 r
.41246 .47823 m .41123 .48277 L .41234 .48115 L F
.646 .283 .34 r
.53032 .38732 m .534 .3854 L .53127 .38635 L F
.888 .818 .342 r
.42032 .55999 m .4195 .56502 L .41943 .56171 L F
.4195 .56502 m .41945 .56534 L .41945 .56496 L F
.4195 .56502 m .41945 .56496 L .41943 .56171 L F
.623 .955 .794 r
.41711 .56705 m .41812 .56559 L .41964 .56516 L F
.4198 .56533 m .41964 .56516 L .42043 .56494 L F
.41711 .56705 m .41964 .56516 L .4198 .56533 L F
.41711 .56705 m .41596 .56731 L .41812 .56559 L F
.835 .919 .891 r
.41302 .58684 m .4177 .585 L .41605 .58398 L F
.949 .892 .738 r
.41796 .58059 m .41605 .58398 L .4177 .585 L F
.294 0 .149 r
.60812 .35315 m .60771 .3554 L .6047 .35619 L F
0 0 .048 r
.60944 .35375 m .60771 .3554 L .60812 .35315 L F
.852 .986 .855 r
.46373 .52992 m .46197 .5339 L .46582 .53117 L F
.46373 .52992 m .46074 .53322 L .46197 .5339 L F
.684 .979 .846 r
.30891 .62677 m .30819 .62838 L .31132 .62592 L F
.652 .774 .306 r
.3072 .63048 m .30819 .62838 L .30891 .62677 L F
.642 .578 .768 r
.31965 .65732 m .31862 .65915 L .31531 .65725 L F
.026 .48 .878 r
.3549 .63829 m .35453 .63945 L .35312 .63809 L F
.3549 .63829 m .3575 .63999 L .35453 .63945 L F
.577 .032 0 r
.35678 .64011 m .35453 .63945 L .3575 .63999 L F
0 0 .381 r
.59354 .39394 m .59278 .39333 L .59429 .39161 L F
.59354 .39394 m .59378 .39548 L .59278 .39333 L F
.825 .625 .632 r
.35208 .54429 m .35439 .54809 L .35196 .54712 L F
.821 .627 .641 r
.35439 .54809 m .3499 .55015 L .35196 .54712 L F
.35439 .54809 m .3538 .55091 L .3499 .55015 L F
.796 .966 .914 r
.41748 .57456 m .41721 .57597 L .41877 .57471 L F
.831 .661 .672 r
.41721 .57597 m .41885 .57832 L .41877 .57471 L F
.541 .925 .902 r
.41958 .57346 m .41877 .57471 L .42134 .57425 L F
.41958 .57346 m .41748 .57456 L .41877 .57471 L F
.713 .567 .688 r
.41877 .57471 m .42292 .57801 L .42134 .57425 L F
.41877 .57471 m .41885 .57832 L .42292 .57801 L F
.898 .93 .83 r
.51205 .45741 m .5107 .45634 L .51339 .45278 L F
.864 .632 .585 r
.55782 .37691 m .55802 .37968 L .55409 .37821 L F
.492 .358 .626 r
.37394 .48188 m .37614 .4797 L .37379 .48145 L F
.141 0 0 r
.26659 .58242 m .2647 .58413 L .26313 .58377 L F
0 0 0 r
.2674 .58305 m .26659 .58242 L .26886 .58091 L F
.2674 .58305 m .2647 .58413 L .26659 .58242 L F
.855 .799 .795 r
.45111 .53104 m .44665 .53303 L .45001 .53017 L F
.45111 .53104 m .44854 .53462 L .44665 .53303 L F
.845 .975 .874 r
.45111 .53104 m .4529 .52723 L .45415 .52791 L F
.45111 .53104 m .45001 .53017 L .4529 .52723 L F
.745 .277 .137 r
.66165 .3458 m .66604 .34832 L .66568 .34723 L F
.193 0 .086 r
.26313 .58377 m .26202 .58649 L .2599 .58691 L F
.155 0 .1 r
.2647 .58413 m .26202 .58649 L .26313 .58377 L F
.976 .92 .66 r
.54771 .43661 m .54899 .43391 L .54687 .43514 L F
.925 .973 .708 r
.54687 .43514 m .54899 .43391 L .54836 .43294 L F
.451 .513 .831 r
.33575 .64459 m .3325 .64213 L .33443 .64109 L F
.511 .214 .399 r
.6047 .35619 m .60135 .35883 L .60174 .35708 L F
0 0 0 r
.30302 .64117 m .30676 .63831 L .30641 .64275 L F
.306 .117 .452 r
.30641 .64275 m .30676 .63831 L .30808 .63717 L F
.906 .688 .597 r
.34932 .53792 m .34628 .53977 L .34645 .53702 L F
.34932 .53792 m .34875 .54069 L .34628 .53977 L F
.97 .728 .516 r
.32088 .64139 m .32258 .6453 L .32033 .644 L F
.528 .824 .999 r
.32464 .64447 m .32258 .6453 L .32033 .644 L F
.208 0 .201 r
.32464 .64447 m .32258 .6453 L .32139 .64786 L F
.636 .944 .723 r
.52675 .4026 m .52352 .40527 L .52526 .40437 L F
.963 .941 .669 r
.53126 .46714 m .52924 .46844 L .52859 .47036 L F
.53126 .46714 m .53027 .46589 L .52924 .46844 L F
.966 .937 .657 r
.53182 .46227 m .53027 .46589 L .53126 .46714 L F
.852 .947 .879 r
.35156 .65535 m .35535 .65191 L .35378 .65104 L F
.968 .886 .695 r
.35378 .65104 m .35535 .65191 L .35668 .64717 L F
0 0 0 r
.53424 .35309 m .53683 .34818 L .53388 .34994 L F
.491 0 0 r
.34716 .6299 m .34909 .63068 L .34649 .62895 L F
0 0 0 r
.57444 .39644 m .57782 .39285 L .57642 .39458 L F
0 0 .42 r
.57862 .39001 m .57782 .39285 L .57753 .38973 L F
.936 .963 .671 r
.57862 .39001 m .57642 .39458 L .57782 .39285 L F
0 0 .09 r
.57839 .39272 m .57642 .39458 L .57862 .39001 L F
.57839 .39279 m .57642 .39458 L .57839 .39272 L F
0 0 0 r
.57444 .39645 m .57444 .39644 L .57642 .39458 L F
0 0 .066 r
.57642 .39458 m .57443 .3984 L .57444 .39645 L F
.2 0 .004 r
.40208 .47859 m .40104 .47762 L .40353 .47669 L F
.40208 .47859 m .39987 .47947 L .40104 .47762 L F
.721 .474 .552 r
.35063 .52032 m .35348 .52328 L .35487 .52076 L F
.813 .489 .441 r
.35348 .52328 m .3576 .52496 L .35487 .52076 L F
.757 .577 .004 r
.35167 .65727 m .35156 .65535 L .35142 .65446 L F
.852 .947 .879 r
.35156 .65535 m .35378 .65104 L .35142 .65446 L F
0 0 .012 r
.37354 .5421 m .37308 .541 L .37286 .54342 L F
.37354 .5421 m .37243 .54424 L .37308 .541 L F
.822 .925 .903 r
.49045 .50396 m .49226 .49989 L .48909 .50295 L F
.49045 .50396 m .49375 .50114 L .49226 .49989 L F
.215 0 .192 r
.55548 .40028 m .55231 .40305 L .55401 .403 L F
.262 .317 .731 r
.55231 .40305 m .55554 .40546 L .55401 .403 L F
.536 .537 .803 r
.55231 .40305 m .55551 .40665 L .55554 .40546 L F
0 .172 .694 r
.55401 .403 m .55554 .40546 L .55602 .40319 L F
.845 .959 .622 r
.55557 .40426 m .55554 .40546 L .55426 .40734 L F
.55602 .40319 m .55554 .40546 L .55557 .40426 L F
.536 .537 .803 r
.55551 .40665 m .55573 .4069 L .55554 .40546 L F
.366 .761 .986 r
.39 .57284 m .39241 .57254 L .39361 .5736 L F
.383 0 0 r
.39241 .57254 m .39542 .57219 L .39361 .5736 L F
.015 0 .043 r
.28437 .63737 m .28251 .63843 L .28122 .64062 L F
.149 .278 .741 r
.28422 .66433 m .2856 .66847 L .2869 .66684 L F
.146 .273 .737 r
.2856 .66847 m .28806 .67056 L .2869 .66684 L F
.338 .58 .931 r
.30975 .68086 m .30956 .67799 L .30747 .67775 L F
.30975 .68086 m .31236 .68115 L .30956 .67799 L F
0 .044 .612 r
.58525 .39621 m .58682 .40019 L .58749 .39953 L F
.38 0 0 r
.58682 .40019 m .59014 .40006 L .58854 .40098 L F
.633 .953 .768 r
.58854 .40098 m .59014 .40006 L .59189 .39843 L F
.612 .941 .747 r
.5892 .4004 m .59189 .39843 L .59072 .39986 L F
0 .276 .779 r
.58799 .40021 m .58682 .40019 L .58854 .40098 L F
.58749 .39953 m .58854 .40098 L .5881 .40079 L F
.612 .941 .747 r
.5881 .40079 m .58854 .40098 L .59189 .39843 L F
.5881 .40079 m .58882 .40034 L .5892 .4004 L F
.58882 .40034 m .59189 .39843 L .5892 .4004 L F
0 .276 .779 r
.58749 .39953 m .58696 .40005 L .58799 .40021 L F
.58696 .40005 m .58682 .40019 L .58799 .40021 L F
0 0 0 r
.46782 .43623 m .47127 .43306 L .47018 .43513 L F
.47127 .43306 m .47478 .43111 L .47358 .4326 L F
.005 0 0 r
.47127 .43306 m .47249 .43387 L .47018 .43513 L F
.47127 .43306 m .47358 .4326 L .47249 .43387 L F
.395 .785 .989 r
.29793 .54651 m .29753 .548 L .29562 .54662 L F
.29793 .54651 m .30019 .5476 L .29753 .548 L F
.29793 .54651 m .29753 .548 L .29562 .54662 L F
.29793 .54651 m .30019 .5476 L .29753 .548 L F
.201 0 0 r
.29722 .5802 m .2993 .58021 L .30062 .57802 L F
.485 .538 .836 r
.30169 .5736 m .30062 .57802 L .29993 .57688 L F
.884 .881 .448 r
.30062 .57802 m .29978 .57825 L .29993 .57688 L F
.30062 .57802 m .2993 .58021 L .29978 .57825 L F
.853 .777 .776 r
.31488 .55839 m .31348 .56065 L .31248 .55698 L F
.868 .554 .035 r
.483 .48763 m .48355 .49022 L .48219 .48628 L F
.873 .956 .857 r
.48627 .48408 m .483 .48763 L .48219 .48628 L F
.25 0 0 r
.41812 .56559 m .41945 .56534 L .42043 .56494 L F
.989 .888 .565 r
.42043 .56494 m .41945 .56534 L .42032 .55999 L F
.774 .689 .77 r
.28772 .55437 m .28953 .55751 L .28521 .55718 L F
.604 .1 .028 r
.28953 .55751 m .28755 .55888 L .28521 .55718 L F
.594 .944 .795 r
.29282 .5554 m .28953 .55751 L .28772 .55437 L F
.29282 .5554 m .29024 .55641 L .28953 .55751 L F
.616 .917 .65 r
.29024 .55641 m .28755 .55888 L .28953 .55751 L F
.631 .743 .928 r
.42292 .57801 m .42443 .57529 L .42134 .57425 L F
.42292 .57801 m .42618 .57785 L .42443 .57529 L F
.595 .776 .966 r
.42292 .57801 m .42407 .57804 L .42618 .57785 L F
.806 .732 .783 r
.44854 .53462 m .4442 .53422 L .44665 .53303 L F
.104 0 0 r
.64649 .3391 m .64918 .33929 L .65068 .33924 L F
.155 0 0 r
.64918 .33929 m .65339 .33982 L .65068 .33924 L F
.416 .834 .661 r
.29659 .59185 m .29808 .59091 L .29925 .59033 L F
.29436 .59312 m .29808 .59091 L .29659 .59185 L F
.252 .679 .963 r
.30351 .59147 m .29925 .59033 L .30188 .5876 L F
.113 0 .244 r
.29808 .59091 m .29779 .59297 L .29953 .58998 L F
.572 .911 .686 r
.29808 .59091 m .29994 .58928 L .29925 .59033 L F
.113 0 .244 r
.29808 .59091 m .29953 .58998 L .29994 .58928 L F
.753 .96 .937 r
.29518 .59167 m .29808 .59091 L .29436 .59312 L F
.712 .596 .725 r
.29433 .59365 m .29518 .59167 L .29436 .59312 L F
.84 .998 .78 r
.29325 .5959 m .29453 .59515 L .2931 .59621 L F
.912 .731 .645 r
.29453 .59515 m .29437 .5985 L .29117 .59765 L F
.891 .989 .775 r
.29436 .59312 m .29453 .59515 L .2916 .59687 L F
.712 .596 .725 r
.29408 .59756 m .29513 .59197 L .29433 .59365 L F
.29513 .59197 m .29518 .59167 L .29433 .59365 L F
.84 .998 .78 r
.2916 .59687 m .29325 .5959 L .29117 .59765 L F
.29325 .5959 m .2931 .59621 L .29117 .59765 L F
.524 0 0 r
.40695 .47819 m .40576 .47819 L .40353 .47669 L F
.952 .945 .731 r
.4048 .48324 m .40576 .47819 L .40695 .47819 L F
.828 .673 .691 r
.40683 .48159 m .4048 .48324 L .40695 .47819 L F
.113 .244 .721 r
.62266 .38994 m .62378 .39329 L .62485 .39106 L F
.651 .094 0 r
.37823 .48448 m .37551 .48355 L .37394 .48188 L F
.37823 .48448 m .37743 .48509 L .37551 .48355 L F
.905 .648 .54 r
.38027 .48331 m .37743 .48509 L .37823 .48448 L F
0 0 0 r
.47478 .43111 m .47581 .43143 L .47358 .4326 L F
.47478 .43111 m .47736 .43017 L .47581 .43143 L F
.006 0 0 r
.40028 .47111 m .39946 .47063 L .39775 .47222 L F
.40028 .47111 m .40212 .47004 L .39946 .47063 L F
0 0 .281 r
.58517 .39349 m .58639 .39415 L .58633 .39113 L F
.58517 .39349 m .58525 .39621 L .58639 .39415 L F
.216 .048 .426 r
.2732 .54786 m .27477 .54964 L .27531 .54705 L F
.2732 .54786 m .27299 .55071 L .27477 .54964 L F
0 0 0 r
.29269 .55553 m .29024 .55641 L .29282 .5554 L F
.131 .68 .777 r
.42618 .57785 m .42407 .57804 L .42931 .57761 L F
.84 .423 .246 r
.3422 .51662 m .34625 .52003 L .34656 .51778 L F
.664 .161 .042 r
.40961 .48437 m .4048 .48324 L .40683 .48159 L F
.40961 .48437 m .40763 .48564 L .40537 .48337 L F
.76 .968 .684 r
.41054 .48215 m .40763 .48564 L .40961 .48437 L F
.817 .993 .75 r
.41054 .48215 m .40799 .48372 L .40763 .48564 L F
.92 .606 .132 r
.40799 .48372 m .40938 .48739 L .40763 .48564 L F
.40938 .48739 m .40941 .48747 L .40763 .48564 L F
.664 .161 .042 r
.40537 .48337 m .40763 .48564 L .4048 .48324 L F
.76 .968 .684 r
.41054 .48215 m .40961 .48437 L .41123 .48277 L F
.646 .853 .979 r
.42727 .50705 m .42988 .50598 L .42941 .50818 L F
0 0 0 r
.32423 .68371 m .32673 .68193 L .32486 .68413 L F
.814 .689 .727 r
.2976 .62557 m .29968 .62336 L .2999 .62179 L F
0 0 0 r
.29769 .62634 m .29968 .62336 L .2976 .62557 L F
.433 0 0 r
.30084 .62358 m .2999 .62179 L .29968 .62336 L F
0 0 0 r
.30084 .62358 m .29968 .62336 L .29769 .62634 L F
.55573 .4069 m .55535 .40751 L .55554 .40546 L F
.722 .97 .933 r
.65124 .38303 m .65322 .37984 L .65061 .38097 L F
.65124 .38303 m .65543 .38016 L .65322 .37984 L F
.216 .039 .413 r
.25544 .58082 m .2575 .57731 L .25513 .57808 L F
.593 .699 .916 r
.31348 .56065 m .30975 .55834 L .31248 .55698 L F
.786 .908 .514 r
.34206 .6725 m .34426 .66829 L .34348 .67053 L F
0 0 .028 r
.34151 .67456 m .34206 .6725 L .34348 .67053 L F
.847 .927 .882 r
.52439 .47219 m .52859 .47036 L .52732 .46973 L F
.759 .986 .9 r
.52859 .47036 m .52924 .46844 L .52732 .46973 L F
.956 .898 .727 r
.35668 .64717 m .35665 .64466 L .35557 .64713 L F
.968 .886 .695 r
.35378 .65104 m .35668 .64717 L .35557 .64713 L F
.612 .403 .575 r
.27145 .57729 m .26923 .57467 L .27194 .57471 L F
.27145 .57729 m .26868 .5782 L .26923 .57467 L F
0 0 0 r
.50697 .39286 m .50946 .39127 L .5108 .38891 L F
.50697 .39286 m .50615 .39395 L .50946 .39127 L F
.745 .641 .745 r
.30188 .5876 m .30684 .5884 L .30351 .59147 L F
.572 .363 .559 r
.30684 .5884 m .30649 .59104 L .30351 .59147 L F
0 .11 .66 r
.30799 .58941 m .30684 .5884 L .30681 .58625 L F
.287 .118 .468 r
.30799 .58941 m .30649 .59104 L .30684 .5884 L F
.30799 .58941 m .30649 .59104 L .30684 .5884 L F
.566 .018 0 r
.51427 .41988 m .51797 .42279 L .51702 .41903 L F
.761 .708 .801 r
.51797 .42279 m .52108 .42017 L .51702 .41903 L F
0 .107 .658 r
.31324 .64061 m .31529 .64502 L .31282 .64411 L F
.493 .193 .386 r
.3144 .64752 m .31529 .64502 L .318 .647 L F
.568 .141 .192 r
.31529 .64502 m .31863 .6455 L .318 .647 L F
.873 .956 .857 r
.48627 .48408 m .48219 .48628 L .48481 .48287 L F
.84 .92 .887 r
.48947 .48087 m .48627 .48408 L .48481 .48287 L F
.76 .63 .067 r
.35656 .64275 m .35665 .64466 L .35678 .64011 L F
.35656 .64275 m .35678 .64011 L .3575 .63999 L F
.701 .963 .942 r
.30799 .58941 m .31288 .5878 L .31079 .58648 L F
.503 .289 .521 r
.57805 .36776 m .58124 .36422 L .57983 .36706 L F
.026 .084 .587 r
.29779 .56458 m .2993 .56321 L .29836 .56014 L F
0 0 .057 r
.29779 .56458 m .29803 .56574 L .2993 .56321 L F
.29779 .56458 m .29768 .56796 L .29803 .56574 L F
0 .224 .735 r
.30595 .59368 m .30351 .59147 L .30649 .59104 L F
.274 0 .069 r
.34175 .51112 m .33804 .51359 L .3403 .51265 L F
.34175 .51112 m .3403 .51265 L .34221 .51056 L F
.836 .577 .547 r
.3403 .51265 m .34253 .5138 L .34221 .51056 L F
.071 0 0 r
.43609 .44699 m .43733 .44808 L .4382 .44549 L F
.43609 .44699 m .43503 .44916 L .43733 .44808 L F
.927 .966 .77 r
.55034 .42935 m .55346 .42657 L .55332 .42615 L F
.873 .611 .539 r
.35208 .54429 m .34847 .54346 L .34875 .54069 L F
.888 .659 .586 r
.35196 .54712 m .34847 .54346 L .35208 .54429 L F
.954 .727 .556 r
.54814 .41059 m .54797 .41387 L .54593 .40759 L F
.478 .309 .573 r
.55003 .41224 m .54797 .41387 L .54814 .41059 L F
.648 .585 .77 r
.54593 .40759 m .54797 .41387 L .54527 .415 L F
.341 0 .17 r
.54429 .41557 m .54797 .41387 L .54673 .41526 L F
0 0 0 r
.54673 .41526 m .54857 .41358 L .5472 .412 L F
.54857 .41358 m .55003 .41224 L .54869 .41213 L F
.54857 .41358 m .54869 .41213 L .5472 .412 L F
0 0 .29 r
.54852 .41413 m .54878 .41686 L .55038 .41501 L F
.54797 .41387 m .54841 .41549 L .54852 .41413 L F
.54841 .41549 m .54878 .41686 L .54852 .41413 L F
.595 .619 .845 r
.29613 .67462 m .29766 .67844 L .29877 .67614 L F
.413 .026 .192 r
.39176 .4797 m .38971 .48269 L .38703 .48298 L F
.364 0 .101 r
.39402 .47987 m .38971 .48269 L .39176 .4797 L F
.545 .494 .749 r
.51614 .37322 m .51732 .37507 L .5184 .37476 L F
.848 .862 .853 r
.31347 .58278 m .31825 .58072 L .31633 .57949 L F
.819 .639 .658 r
.64337 .37255 m .64047 .37439 L .64062 .37408 L F
.391 .264 .586 r
.33445 .51443 m .3381 .51556 L .33804 .51359 L F
.33445 .51443 m .33488 .51688 L .3381 .51556 L F
.732 .449 .499 r
.28701 .53115 m .28614 .53387 L .29029 .5338 L F
.172 .557 .931 r
.32411 .63338 m .32374 .63472 L .32548 .63504 L F
.32548 .63504 m .32374 .63472 L .32411 .63338 L F
.363 .82 .716 r
.49668 .40143 m .49721 .40095 L .49886 .39977 L F
.49668 .40143 m .49475 .40213 L .49721 .40095 L F
.893 .684 .613 r
.32015 .5373 m .31932 .54008 L .323 .54106 L F
.84 .67 .671 r
.31932 .54008 m .3232 .54372 L .323 .54106 L F
.695 .965 .938 r
.50813 .41702 m .51028 .41757 L .51248 .41601 L F
.427 0 .061 r
.64971 .36944 m .64693 .37002 L .64558 .36981 L F
.825 .725 .754 r
.32358 .65173 m .31968 .65238 L .32188 .65084 L F
.32358 .65173 m .3215 .65556 L .31968 .65238 L F
.401 .266 .581 r
.32064 .63831 m .32088 .64139 L .32302 .6406 L F
.32064 .63831 m .32088 .64139 L .32302 .6406 L F
.625 .26 .331 r
.36838 .5262 m .37099 .52639 L .37323 .52352 L F
.677 .324 .369 r
.37099 .52639 m .37524 .52644 L .37323 .52352 L F
.728 .859 .434 r
.27346 .57343 m .27145 .57729 L .27194 .57471 L F
0 0 0 r
.55548 .40028 m .55401 .403 L .5565 .40065 L F
.31303 .64523 m .30856 .64775 L .31149 .64551 L F
.836 .934 .893 r
.31282 .64411 m .31303 .64523 L .31149 .64551 L F
.867 .739 .719 r
.3234 .56027 m .32493 .5641 L .32616 .56173 L F
.857 .789 .784 r
.48055 .49341 m .47932 .48966 L .48078 .49141 L F
.652 .803 .955 r
.48355 .49022 m .48078 .49141 L .47932 .48966 L F
.679 .789 .933 r
.42728 .57636 m .42618 .57785 L .42931 .57761 L F
.805 .783 .832 r
.42728 .57636 m .42931 .57761 L .43258 .57476 L F
.735 .756 .247 r
.57953 .35857 m .5796 .35784 L .58014 .35638 L F
.828 .501 0 r
.57953 .35857 m .57919 .35909 L .5796 .35784 L F
.57953 .35857 m .5804 .36205 L .57919 .35909 L F
0 0 .523 r
.64334 .36039 m .64365 .36011 L .64218 .35835 L F
.64334 .36039 m .64439 .36162 L .64365 .36011 L F
.842 .957 .886 r
.66034 .37728 m .66281 .37756 L .66436 .37552 L F
.777 .819 .886 r
.38665 .56356 m .38753 .56672 L .38917 .56493 L F
.725 .842 .937 r
.62572 .34459 m .62727 .34624 L .63008 .34518 L F
.55 .931 .84 r
.42538 .55786 m .42032 .55999 L .42423 .55755 L F
.587 .864 .995 r
.42617 .55591 m .4279 .55687 L .42538 .55786 L F
.73 .987 .89 r
.42617 .55591 m .42538 .55786 L .42423 .55755 L F
.172 0 0 r
.38347 .55005 m .38795 .54708 L .38563 .54706 L F
.51 .553 .836 r
.34004 .66784 m .33784 .66869 L .33592 .66443 L F
.528 .829 .999 r
.33573 .6674 m .33784 .66869 L .34004 .66784 L F
.778 .638 .706 r
.56521 .37881 m .56533 .38044 L .56714 .37995 L F
.72 .923 .961 r
.56714 .37995 m .56721 .37974 L .56908 .37904 L F
.506 .061 .127 r
.566 .38051 m .56691 .38158 L .56908 .37904 L F
.583 .561 .795 r
.56332 .38644 m .56418 .38122 L .56139 .38257 L F
.56332 .38644 m .56658 .38832 L .5643 .38122 L F
.388 .823 .673 r
.56533 .38044 m .56139 .38257 L .56422 .38097 L F
.583 .561 .795 r
.56412 .38122 m .56422 .38097 L .56382 .38119 L F
.383 0 0 r
.56666 .3814 m .56427 .38123 L .56616 .38104 L F
.56427 .38123 m .56412 .38122 L .56616 .38104 L F
0 0 0 r
.56533 .38044 m .56412 .38122 L .56139 .38257 L F
.72 .641 .769 r
.56446 .38121 m .56658 .38832 L .569 .38588 L F
.5643 .38122 m .56658 .38832 L .56446 .38121 L F
.383 0 0 r
.56691 .38158 m .56412 .38122 L .56666 .3814 L F
.72 .641 .769 r
.56422 .38097 m .56446 .38121 L .56691 .38158 L F
.56599 .38279 m .569 .38588 L .56783 .38348 L F
.77 .762 .846 r
.56691 .38158 m .569 .38588 L .571 .38214 L F
.113 0 .405 r
.571 .38214 m .569 .38588 L .57086 .38413 L F
.889 .926 .84 r
.5706 .3831 m .569 .38588 L .57086 .38413 L F
.762 .37 .311 r
.56908 .37904 m .5675 .38089 L .57087 .38209 L F
.57096 .38206 m .57087 .38209 L .571 .38214 L F
.56908 .37904 m .57087 .38209 L .57096 .38206 L F
.889 .926 .84 r
.56967 .38244 m .56726 .3846 L .569 .38588 L F
.762 .37 .311 r
.5675 .38089 m .56884 .38185 L .571 .38214 L F
.889 .926 .84 r
.57 .38076 m .56857 .38276 L .56967 .38244 L F
.56857 .38276 m .56726 .3846 L .56967 .38244 L F
.57 .38076 m .56967 .38244 L .5706 .3831 L F
.56967 .38244 m .569 .38588 L .5706 .3831 L F
.762 .37 .311 r
.5675 .38089 m .56691 .38158 L .56884 .38185 L F
.624 .215 .248 r
.57086 .38413 m .56726 .3846 L .569 .38588 L F
.715 .664 .799 r
.56881 .38872 m .57086 .38413 L .569 .38588 L F
.56881 .38872 m .57287 .38896 L .57086 .38413 L F
.624 .215 .248 r
.56987 .38426 m .56988 .38643 L .56726 .3846 L F
.57086 .38413 m .57068 .38456 L .56987 .38426 L F
.57068 .38456 m .56988 .38643 L .56987 .38426 L F
.72 .641 .769 r
.56446 .38121 m .56599 .38279 L .56691 .38158 L F
.56599 .38279 m .56783 .38348 L .56691 .38158 L F
.383 0 0 r
.56616 .38104 m .56436 .3812 L .56533 .38044 L F
.56436 .3812 m .56412 .38122 L .56419 .38117 L F
.56436 .3812 m .56419 .38117 L .56533 .38044 L F
.72 .641 .769 r
.56422 .38097 m .5643 .38122 L .56446 .38121 L F
.583 .561 .795 r
.56418 .38122 m .56418 .38118 L .56412 .38122 L F
.56418 .38118 m .56422 .38097 L .56412 .38122 L F
.56418 .38122 m .56382 .38119 L .56139 .38257 L F
0 0 0 r
.56412 .38122 m .56411 .38122 L .56139 .38257 L F
.56411 .38122 m .56321 .38179 L .56167 .38245 L F
.56411 .38122 m .56167 .38245 L .56139 .38257 L F
.583 .561 .795 r
.56418 .38122 m .5643 .38122 L .56427 .38114 L F
.56418 .38118 m .56427 .38114 L .56422 .38097 L F
.56418 .38122 m .56427 .38114 L .56418 .38118 L F
.56332 .38644 m .5643 .38122 L .56418 .38122 L F
.383 0 0 r
.56691 .38158 m .56321 .38179 L .56411 .38122 L F
.56414 .38122 m .56411 .38122 L .56412 .38122 L F
.56691 .38158 m .56411 .38122 L .56414 .38122 L F
.506 .061 .127 r
.56479 .3811 m .56691 .38158 L .566 .38051 L F
.72 .923 .961 r
.56714 .37995 m .56533 .38044 L .56721 .37974 L F
.506 .061 .127 r
.56422 .38097 m .56584 .38032 L .56533 .38044 L F
.464 .661 .947 r
.56721 .37974 m .56951 .37886 L .5675 .37884 L F
0 0 0 r
.56908 .37904 m .56795 .37958 L .56714 .37995 L F
.383 0 0 r
.56691 .38158 m .56533 .38044 L .56584 .38032 L F
.506 .061 .127 r
.56422 .38097 m .56479 .3811 L .56795 .37958 L F
.56776 .37956 m .56795 .37958 L .56908 .37904 L F
.464 .661 .947 r
.56714 .37995 m .56795 .37958 L .56721 .37974 L F
.56795 .37958 m .56776 .37956 L .56721 .37974 L F
.56714 .37995 m .5675 .37884 L .56521 .37881 L F
.506 .061 .127 r
.56422 .38097 m .56795 .37958 L .56776 .37956 L F
.464 .661 .947 r
.56795 .37958 m .56853 .37931 L .56776 .37956 L F
.506 .061 .127 r
.56776 .37956 m .56908 .37904 L .56721 .37974 L F
0 0 0 r
.56908 .37904 m .56951 .37886 L .56795 .37958 L F
.464 .661 .947 r
.56853 .37931 m .56951 .37886 L .56721 .37974 L F
.506 .061 .127 r
.56584 .38032 m .56776 .37956 L .56533 .38044 L F
.56776 .37956 m .56721 .37974 L .56533 .38044 L F
.383 0 0 r
.56584 .38032 m .56533 .38044 L .56528 .37965 L F
.56691 .38158 m .56528 .37965 L .56521 .37881 L F
.842 .958 .886 r
.30336 .55893 m .30384 .55591 L .3062 .55834 L F
.30336 .55893 m .30032 .55851 L .30384 .55591 L F
.963 .706 .5 r
.37407 .53357 m .37405 .53647 L .37608 .53751 L F
.928 .589 .372 r
.37405 .53647 m .37591 .53759 L .37608 .53751 L F
.131 .191 .659 r
.52616 .42003 m .5294 .42063 L .52964 .41883 L F
.52616 .42003 m .52776 .42348 L .5294 .42063 L F
.478 .831 .561 r
.45429 .43428 m .45122 .43687 L .45342 .43554 L F
.085 0 0 r
.45692 .43318 m .45429 .43428 L .45342 .43554 L F
.496 .313 .561 r
.51427 .41988 m .51425 .42303 L .51702 .41903 L F
.08 0 0 r
.4257 .46449 m .42519 .46571 L .42267 .46687 L F
0 0 0 r
.58014 .35638 m .5796 .35784 L .58105 .35413 L F
.44418 .4533 m .44752 .4506 L .44623 .45267 L F
.44275 .45486 m .44418 .4533 L .44623 .45267 L F
.679 .844 .962 r
.39461 .53348 m .39717 .53428 L .3957 .53256 L F
.19 .62 .945 r
.60131 .34186 m .60097 .34232 L .59902 .34181 L F
.60131 .34186 m .60253 .34265 L .60097 .34232 L F
.879 .818 .785 r
.64086 .34872 m .63853 .35227 L .64164 .35247 L F
.423 0 0 r
.33266 .60828 m .33238 .60795 L .32985 .60692 L F
.478 .365 .647 r
.26011 .5676 m .26276 .56934 L .26215 .56667 L F
.26011 .5676 m .26048 .57112 L .26276 .56934 L F
.896 .961 .828 r
.45674 .52453 m .45415 .52791 L .45389 .52502 L F
.916 .965 .793 r
.45415 .52791 m .4529 .52723 L .45389 .52502 L F
0 0 0 r
.55638 .39793 m .56012 .39469 L .55684 .39839 L F
.55638 .39793 m .55908 .39614 L .56012 .39469 L F
.938 .908 .521 r
.56012 .39469 m .55908 .39614 L .56094 .39307 L F
.291 .374 .776 r
.55976 .39033 m .56094 .39307 L .5627 .39176 L F
.328 0 .127 r
.56094 .39307 m .56336 .39426 L .5627 .39176 L F
.56094 .39307 m .55908 .39614 L .56336 .39426 L F
.273 0 0 r
.54775 .40737 m .54846 .40817 L .54708 .40692 L F
.895 .988 .755 r
.54846 .40817 m .54992 .40831 L .5493 .40911 L F
.224 .745 .825 r
.54846 .40817 m .55404 .40764 L .54992 .40831 L F
.55404 .40764 m .55535 .40751 L .5541 .4077 L F
.55404 .40764 m .5541 .4077 L .54992 .40831 L F
.754 .988 .895 r
.55426 .40734 m .55387 .40748 L .55403 .40706 L F
.268 0 0 r
.55125 .40847 m .55535 .40751 L .55311 .40773 L F
.55125 .40847 m .55311 .40773 L .54846 .40817 L F
.273 0 0 r
.55009 .40894 m .55125 .40847 L .54846 .40817 L F
.377 .824 .699 r
.55014 .40892 m .55125 .40847 L .55009 .40894 L F
.55403 .40706 m .55125 .40847 L .55014 .40892 L F
.754 .988 .895 r
.55387 .40748 m .55125 .40847 L .55363 .40726 L F
.55387 .40748 m .55363 .40726 L .55403 .40706 L F
.273 0 0 r
.55009 .40894 m .54846 .40817 L .54775 .40737 L F
.895 .988 .755 r
.54846 .40817 m .5493 .40911 L .54814 .41059 L F
.732 .655 .773 r
.34505 .64168 m .34688 .64551 L .34263 .64476 L F
.529 .627 .892 r
.58834 .34839 m .5861 .34973 L .58466 .34674 L F
0 .091 .624 r
.5874 .35033 m .5861 .34973 L .58834 .34839 L F
.5874 .35033 m .58851 .352 L .5861 .34973 L F
.832 .695 .712 r
.43029 .57334 m .43258 .57476 L .43097 .57048 L F
.805 .783 .832 r
.42728 .57636 m .43258 .57476 L .43029 .57334 L F
.902 .683 .597 r
.33695 .52081 m .33456 .52016 L .33488 .51688 L F
.895 .593 .467 r
.33695 .52081 m .33473 .52263 L .33456 .52016 L F
.861 .531 .425 r
.33695 .52081 m .33691 .52362 L .33473 .52263 L F
.913 .795 .717 r
.28988 .59813 m .29119 .60119 L .28888 .59821 L F
.954 .607 .242 r
.28896 .59843 m .29119 .60119 L .28994 .60096 L F
.28888 .59821 m .28901 .59839 L .28896 .59843 L F
.28901 .59839 m .29119 .60119 L .28896 .59843 L F
.583 .629 .863 r
.29291 .59967 m .29119 .60119 L .29117 .59765 L F
.515 .608 .884 r
.29159 .59798 m .29119 .60119 L .28988 .59813 L F
.956 .638 .382 r
.28888 .59821 m .28994 .60096 L .2876 .59906 L F
.112 0 0 r
.28988 .59813 m .28863 .59865 L .29159 .59798 L F
.28863 .59865 m .2876 .59906 L .28826 .59888 L F
.912 .634 .503 r
.29177 .59835 m .29437 .5985 L .29291 .59967 L F
.29117 .59765 m .29231 .59796 L .29177 .59835 L F
.29231 .59796 m .29437 .5985 L .29177 .59835 L F
.587 .63 .861 r
.29117 .59765 m .29291 .59967 L .2916 .59687 L F
.112 0 0 r
.28863 .59865 m .28826 .59888 L .29159 .59798 L F
.94 .963 .726 r
.28994 .60096 m .29119 .60119 L .29152 .59852 L F
.29114 .59879 m .29152 .59852 L .29159 .59798 L F
.28994 .60096 m .29152 .59852 L .29114 .59879 L F
.027 0 0 r
.29437 .5985 m .29656 .59814 L .29291 .59967 L F
.336 .108 .413 r
.26169 .56114 m .26414 .56072 L .26438 .55759 L F
.394 .316 .65 r
.26169 .56114 m .26429 .56337 L .26414 .56072 L F
.458 .316 .6 r
.26196 .564 m .26429 .56337 L .26169 .56114 L F
.623 .094 0 r
.62459 .338 m .63087 .33993 L .62586 .33953 L F
.081 0 .208 r
.63883 .35005 m .63853 .35227 L .64086 .34872 L F
.857 .789 .784 r
.48055 .49341 m .47684 .49301 L .47932 .48966 L F
.882 .755 .717 r
.48055 .49341 m .47631 .49573 L .47684 .49301 L F
.48055 .49341 m .47834 .49701 L .47631 .49573 L F
0 0 0 r
.44623 .45267 m .44752 .4506 L .44947 .44921 L F
.094 0 0 r
.61784 .35266 m .61391 .35214 L .61538 .35234 L F
.994 .872 .591 r
.31698 .61655 m .31907 .61487 L .31701 .62021 L F
.833 .975 .884 r
.32199 .61193 m .31907 .61487 L .31798 .61394 L F
.987 .897 .608 r
.31798 .61394 m .31907 .61487 L .31698 .61655 L F
.718 .276 .201 r
.60253 .34265 m .60507 .34475 L .60532 .3433 L F
.499 .039 .092 r
.29615 .63717 m .29702 .6398 L .29416 .64025 L F
.29615 .63717 m .29851 .63757 L .29702 .6398 L F
.909 .587 .423 r
.3081 .53429 m .30531 .53591 L .30516 .53272 L F
.3081 .53429 m .30824 .53711 L .30531 .53591 L F
.656 .754 .922 r
.42443 .57529 m .42618 .57785 L .42728 .57636 L F
.944 .863 .73 r
.43874 .55734 m .4378 .55428 L .43665 .55584 L F
.933 .872 .754 r
.43681 .56126 m .43874 .55734 L .43665 .55584 L F
.794 .817 .871 r
.43874 .55734 m .43994 .55277 L .4378 .55428 L F
.43874 .55734 m .44197 .55448 L .43994 .55277 L F
.99 .828 .451 r
.34871 .63746 m .3488 .64147 L .3479 .64098 L F
.597 .355 .52 r
.38795 .54708 m .39069 .54701 L .39086 .5443 L F
.477 .256 .499 r
.39086 .5443 m .39069 .54701 L .39383 .54404 L F
.908 .674 .573 r
.37326 .57757 m .36943 .57927 L .36941 .57689 L F
.37326 .57757 m .3731 .58193 L .36943 .57927 L F
.522 .806 .998 r
.39939 .59 m .40094 .59135 L .40203 .58943 L F
.69 .667 .823 r
.31149 .64551 m .30856 .64775 L .30665 .64446 L F
.684 .21 .121 r
.30856 .64775 m .31016 .65042 L .30936 .65091 L F
.479 .308 .571 r
.52229 .39371 m .52478 .38979 L .52052 .3884 L F
.52229 .39371 m .52493 .3931 L .52478 .38979 L F
.52478 .38979 m .52493 .3931 L .52229 .39371 L F
.55 .042 0 r
.38554 .5542 m .38957 .55435 L .38762 .55585 L F
.952 .944 .629 r
.38762 .55585 m .38957 .55435 L .38894 .55362 L F
.892 .952 .836 r
.49375 .50114 m .49436 .49761 L .49226 .49989 L F
.49375 .50114 m .49636 .49776 L .49436 .49761 L F
.803 .752 .805 r
.51947 .44934 m .51813 .4513 L .51575 .44918 L F
0 0 0 r
.53424 .35309 m .53576 .35124 L .53683 .34818 L F
.522 .881 .982 r
.53424 .35309 m .53276 .35232 L .53576 .35124 L F
.317 .025 .3 r
.53719 .35252 m .53418 .35559 L .53424 .35309 L F
.637 .877 .986 r
.51996 .4361 m .52147 .43725 L .52301 .43458 L F
.51996 .4361 m .52147 .43725 L .52301 .43458 L F
0 0 0 r
.51782 .43388 m .51462 .43479 L .51451 .43813 L F
.133 0 0 r
.28061 .53731 m .2826 .53681 L .28402 .53496 L F
0 0 0 r
.409 .56414 m .40613 .56858 L .40846 .56599 L F
.172 .557 .931 r
.32411 .63338 m .32131 .6321 L .32177 .63295 L F
.32411 .63338 m .32476 .631 L .32131 .6321 L F
.512 .749 .981 r
.29877 .67614 m .30488 .67792 L .30398 .67681 L F
.22 .726 .899 r
.30488 .67792 m .30536 .67729 L .30398 .67681 L F
.30488 .67792 m .30747 .67775 L .30536 .67729 L F
0 0 .518 r
.52778 .39362 m .52835 .3899 L .52493 .3931 L F
.666 .885 .523 r
.41369 .47649 m .41644 .47306 L .41535 .47505 L F
0 0 0 r
.41957 .4696 m .41826 .47173 L .41644 .47306 L F
.41644 .47306 m .41826 .47173 L .41535 .47505 L F
.767 .825 .897 r
.33867 .66114 m .34266 .66124 L .34214 .65898 L F
.724 .309 .261 r
.34129 .66378 m .34266 .66124 L .33867 .66114 L F
0 0 .549 r
.34214 .65898 m .34266 .66124 L .34336 .66 L F
.172 0 .027 r
.34362 .66297 m .34129 .66378 L .34028 .66537 L F
0 0 0 r
.34336 .66 m .34129 .66378 L .34362 .66297 L F
.172 0 .027 r
.34362 .66297 m .34028 .66537 L .34162 .66479 L F
.991 .77 .506 r
.34187 .66274 m .34362 .66297 L .34162 .66479 L F
.34203 .66143 m .34239 .66178 L .34187 .66274 L F
.34239 .66178 m .34362 .66297 L .34187 .66274 L F
0 0 0 r
.34326 .66018 m .34266 .66124 L .34129 .66378 L F
.34336 .66 m .34333 .66005 L .34326 .66018 L F
.34333 .66005 m .34266 .66124 L .34326 .66018 L F
.178 .359 .807 r
.25764 .59689 m .25857 .59483 L .25809 .59709 L F
.352 .121 .417 r
.26066 .5939 m .25809 .59709 L .25857 .59483 L F
.792 .514 .517 r
.54169 .42574 m .53893 .42345 L .53917 .42669 L F
.372 .128 .41 r
.26438 .55759 m .26679 .55696 L .26719 .5543 L F
.494 .235 .45 r
.26438 .55759 m .26647 .55975 L .26679 .55696 L F
.26438 .55759 m .26414 .56072 L .26647 .55975 L F
.553 .513 .765 r
.51946 .38999 m .52052 .3884 L .51875 .38943 L F
.51822 .39184 m .52097 .39156 L .52052 .3884 L F
.082 .345 .818 r
.5191 .38777 m .52097 .39156 L .52052 .3884 L F
.5191 .38777 m .52195 .3896 L .52111 .39128 L F
.52065 .39092 m .52111 .39128 L .52097 .39156 L F
.5191 .38777 m .52111 .39128 L .52065 .39092 L F
.553 .513 .765 r
.51822 .39184 m .51946 .38999 L .51792 .38991 L F
.51946 .38999 m .51875 .38943 L .51792 .38991 L F
.832 .51 .444 r
.30946 .52414 m .30882 .5265 L .31346 .5275 L F
.837 .575 .542 r
.30857 .52933 m .31346 .5275 L .30882 .5265 L F
.30857 .52933 m .31335 .53026 L .31346 .5275 L F
0 0 0 r
.48065 .41287 m .48245 .41165 L .48415 .41047 L F
.48065 .41287 m .4796 .41481 L .48245 .41165 L F
.86 .577 .508 r
.34668 .53419 m .3432 .53338 L .34331 .53045 L F
.858 .615 .569 r
.34668 .53419 m .34301 .53616 L .3432 .53338 L F
.34668 .53419 m .34645 .53702 L .34301 .53616 L F
.725 .842 .937 r
.62572 .34459 m .63008 .34518 L .63087 .33993 L F
.465 .763 .995 r
.63008 .34518 m .63132 .34353 L .63109 .34168 L F
.63058 .34184 m .63109 .34168 L .63087 .33993 L F
.63008 .34518 m .63109 .34168 L .63058 .34184 L F
0 0 0 r
.63274 .33921 m .63434 .33858 L .63543 .33904 L F
.63268 .33929 m .63109 .34168 L .63174 .34106 L F
.63109 .34168 m .63147 .34156 L .63434 .33858 L F
.927 .648 .494 r
.63087 .33993 m .63048 .3426 L .63109 .34168 L F
.63087 .33993 m .63109 .34168 L .63268 .33929 L F
.63087 .33993 m .63268 .33929 L .63274 .33921 L F
.465 .763 .995 r
.63132 .34353 m .63192 .34275 L .63148 .34156 L F
.63125 .34295 m .63148 .34156 L .63087 .33993 L F
.63132 .34353 m .63148 .34156 L .63125 .34295 L F
.682 .962 .734 r
.62841 .34134 m .62572 .34459 L .63087 .33993 L F
.62806 .34154 m .62781 .34186 L .6282 .34152 L F
.62781 .34186 m .62572 .34459 L .62841 .34134 L F
.703 .975 .918 r
.62806 .34154 m .62485 .34389 L .62572 .34459 L F
.787 .998 .847 r
.6262 .3411 m .62485 .34389 L .62806 .34154 L F
.648 .094 0 r
.63014 .34265 m .62751 .34161 L .62806 .34154 L F
.62751 .34161 m .6262 .3411 L .62806 .34154 L F
.682 .962 .734 r
.62806 .34154 m .6282 .34152 L .62841 .34134 L F
.62806 .34154 m .63087 .33993 L .62773 .34 L F
.984 .727 .46 r
.6296 .34123 m .63048 .3426 L .63087 .33993 L F
.577 .005 0 r
.62907 .34186 m .62806 .34154 L .6296 .34123 L F
.984 .727 .46 r
.62945 .34138 m .62946 .34139 L .6296 .34123 L F
.62946 .34139 m .62981 .3418 L .6296 .34123 L F
.62981 .3418 m .63048 .3426 L .62996 .34179 L F
.62981 .3418 m .62996 .34179 L .6296 .34123 L F
.839 .827 .836 r
.6309 .34151 m .63048 .3426 L .62946 .34139 L F
.577 .005 0 r
.62989 .34142 m .62946 .34139 L .6296 .34123 L F
.839 .827 .836 r
.62989 .34142 m .62946 .34139 L .62945 .34138 L F
.6309 .34151 m .62946 .34139 L .62989 .34142 L F
.577 .005 0 r
.63148 .34156 m .62991 .34091 L .63087 .33993 L F
0 0 0 r
.63109 .34168 m .63048 .3426 L .63147 .34156 L F
.839 .827 .836 r
.63147 .34156 m .63048 .3426 L .6309 .34151 L F
.577 .005 0 r
.62989 .34142 m .62773 .34 L .63147 .34156 L F
.839 .827 .836 r
.63148 .34156 m .6309 .34151 L .63191 .3389 L F
.63147 .34156 m .6309 .34151 L .63148 .34156 L F
.577 .005 0 r
.63112 .34223 m .62989 .34142 L .63148 .34156 L F
.62989 .34142 m .63147 .34156 L .63148 .34156 L F
.63192 .34275 m .62907 .34186 L .62946 .34139 L F
.63192 .34275 m .62946 .34139 L .62989 .34142 L F
.63192 .34275 m .62871 .34189 L .62907 .34186 L F
0 0 0 r
.63167 .34224 m .62904 .34329 L .63014 .34265 L F
.62904 .34329 m .62898 .34331 L .63014 .34265 L F
.577 .005 0 r
.63058 .34239 m .63014 .34265 L .62871 .34189 L F
.63192 .34275 m .63014 .34265 L .63058 .34239 L F
.62907 .34186 m .62871 .34189 L .62806 .34154 L F
.6296 .34123 m .62806 .34154 L .62773 .34 L F
.62991 .34091 m .62907 .34056 L .63087 .33993 L F
.62907 .34056 m .62773 .34 L .63087 .33993 L F
.623 .094 0 r
.6272 .3388 m .62773 .34 L .63087 .33993 L F
.62459 .338 m .62773 .34 L .6272 .3388 L F
.903 .914 .819 r
.62806 .34154 m .62815 .34096 L .62773 .34 L F
.984 .727 .46 r
.62818 .33951 m .63087 .33993 L .62773 .34 L F
.839 .827 .836 r
.63434 .33858 m .62826 .33939 L .63168 .33804 L F
.903 .914 .819 r
.62814 .33999 m .62816 .33896 L .62806 .34034 L F
.839 .827 .836 r
.62826 .33939 m .62784 .33945 L .62829 .33929 L F
.62826 .33939 m .62829 .33929 L .63168 .33804 L F
.903 .914 .819 r
.62806 .34034 m .62816 .33896 L .62773 .34 L F
.62813 .34041 m .62814 .33999 L .62806 .34034 L F
.62823 .34051 m .6282 .33988 L .62813 .34041 L F
.794 .909 .92 r
.63168 .33804 m .62829 .33929 L .62868 .3377 L F
.903 .914 .819 r
.62818 .33951 m .62868 .3377 L .62816 .33896 L F
.716 .856 .432 r
.62868 .3377 m .62784 .33945 L .62773 .34 L F
.794 .909 .92 r
.62829 .33929 m .62784 .33945 L .62868 .3377 L F
.903 .914 .819 r
.6282 .33988 m .62819 .33968 L .62813 .34041 L F
.62819 .33968 m .62816 .33896 L .62814 .33989 L F
.62819 .33968 m .62814 .33989 L .62813 .34041 L F
.984 .727 .46 r
.62818 .33951 m .62922 .34103 L .63087 .33993 L F
.62922 .34103 m .62945 .34138 L .62959 .34123 L F
.62922 .34103 m .62959 .34123 L .63087 .33993 L F
.641 .08 0 r
.62355 .3389 m .62806 .34154 L .62773 .34 L F
.62355 .3389 m .6262 .3411 L .62806 .34154 L F
.903 .914 .819 r
.62806 .34154 m .6262 .3411 L .62708 .3399 L F
.839 .827 .836 r
.63106 .33902 m .62938 .34049 L .62822 .33971 L F
.984 .727 .46 r
.62784 .33945 m .62818 .33951 L .62773 .34 L F
.62784 .33945 m .6282 .33988 L .62818 .33951 L F
.839 .827 .836 r
.62826 .33939 m .62822 .33971 L .62784 .33945 L F
.63106 .33902 m .62822 .33971 L .62826 .33939 L F
.984 .727 .46 r
.6282 .33988 m .62945 .34138 L .62818 .33951 L F
.903 .914 .819 r
.62823 .34051 m .62843 .33924 L .62826 .33942 L F
.6282 .33988 m .62826 .33942 L .62818 .33951 L F
.62823 .34051 m .62826 .33942 L .6282 .33988 L F
.839 .827 .836 r
.6309 .34151 m .62945 .34138 L .6282 .33988 L F
.62822 .33971 m .6282 .33988 L .62784 .33945 L F
.6309 .34151 m .6282 .33988 L .62822 .33971 L F
.903 .914 .819 r
.62843 .33924 m .62868 .3377 L .62818 .33951 L F
.599 .038 0 r
.62355 .3389 m .62773 .34 L .62459 .338 L F
.903 .914 .819 r
.62823 .34051 m .62708 .3399 L .62868 .3377 L F
.62815 .34096 m .62823 .34051 L .62773 .34 L F
.62806 .34154 m .62708 .3399 L .62823 .34051 L F
.839 .827 .836 r
.63191 .3389 m .6309 .34151 L .62938 .34049 L F
.63191 .3389 m .62938 .34049 L .63106 .33902 L F
0 0 0 r
.63274 .33921 m .63268 .33929 L .63434 .33858 L F
.63268 .33929 m .63174 .34106 L .63434 .33858 L F
.839 .827 .836 r
.63434 .33858 m .63147 .34156 L .63191 .3389 L F
.577 .005 0 r
.63192 .34275 m .63112 .34223 L .63148 .34156 L F
.465 .763 .995 r
.63008 .34518 m .63401 .34455 L .63192 .34275 L F
.481 .221 .443 r
.26679 .55696 m .26938 .55635 L .26719 .5543 L F
.49 .22 .432 r
.26719 .5543 m .26938 .55635 L .26986 .55383 L F
.817 .81 .844 r
.5115 .42639 m .50954 .42942 L .50737 .42611 L F
.053 0 .27 r
.51083 .42869 m .50954 .42942 L .5115 .42639 L F
0 0 0 r
.50801 .43179 m .50954 .42942 L .51083 .42869 L F
.896 .961 .828 r
.45674 .52453 m .45389 .52502 L .45495 .52308 L F
.735 .846 .932 r
.45872 .52315 m .45674 .52453 L .45495 .52308 L F
.529 .316 .535 r
.31637 .6256 m .32009 .62714 L .3176 .62845 L F
.465 .825 .995 r
.31637 .6256 m .32077 .6254 L .32009 .62714 L F
.851 .457 .297 r
.31637 .6256 m .3176 .62845 L .31685 .6278 L F
.078 0 .419 r
.31958 .62263 m .31637 .6256 L .31685 .6278 L F
0 0 0 r
.3172 .62493 m .31637 .6256 L .31958 .62263 L F
.253 .638 .962 r
.3135 .62451 m .31637 .6256 L .31714 .62498 L F
.3135 .62451 m .31714 .62498 L .31701 .62491 L F
.818 .931 .907 r
.31132 .62592 m .3135 .62451 L .3116 .62336 L F
.365 .606 .941 r
.3135 .62451 m .31505 .62304 L .3116 .62336 L F
.3135 .62451 m .3172 .62493 L .31505 .62304 L F
.828 .727 .753 r
.31449 .62353 m .31685 .6278 L .31143 .6262 L F
.31505 .62304 m .31543 .62405 L .31449 .62353 L F
.31543 .62405 m .31685 .6278 L .31449 .62353 L F
.253 .638 .962 r
.31701 .62491 m .31714 .62498 L .3172 .62493 L F
.727 .467 .534 r
.51822 .39184 m .52098 .3972 L .51522 .39327 L F
0 0 .461 r
.51977 .3937 m .51822 .39184 L .52097 .39156 L F
.51977 .3937 m .52098 .3972 L .51822 .39184 L F
.572 .342 .528 r
.25809 .59709 m .25577 .60275 L .25764 .59689 L F
.415 .237 .529 r
.25298 .59198 m .25625 .59382 L .25527 .58943 L F
.25298 .59198 m .25395 .59486 L .25625 .59382 L F
.852 .904 .871 r
.53182 .46227 m .53667 .46026 L .53539 .45914 L F
.989 .874 .621 r
.53629 .45638 m .53539 .45914 L .53667 .46026 L F
.08 .289 .773 r
.63416 .34661 m .63517 .34469 L .63401 .34455 L F
.465 .773 .997 r
.63708 .3462 m .63517 .34469 L .63416 .34661 L F
.316 .783 .935 r
.63778 .34638 m .63708 .3462 L .63416 .34661 L F
.013 0 0 r
.61222 .34316 m .61538 .34267 L .61549 .34246 L F
.215 .711 .916 r
.5901 .35574 m .59302 .3558 L .59448 .35637 L F
.565 .906 .974 r
.59628 .35454 m .59302 .3558 L .59448 .35637 L F
.59448 .35637 m .59302 .3558 L .59628 .35454 L F
.59628 .35454 m .59302 .3558 L .59448 .35637 L F
.936 .821 .706 r
.47494 .50022 m .47143 .50274 L .4735 .49904 L F
.47494 .50022 m .47326 .50408 L .47143 .50274 L F
.821 .925 .903 r
.47834 .49701 m .47494 .50022 L .4735 .49904 L F
.947 .953 .732 r
.46722 .51049 m .46503 .5114 L .46634 .51009 L F
.46722 .51049 m .46493 .51452 L .46503 .5114 L F
.709 .973 .926 r
.46722 .51049 m .46767 .50871 L .46887 .50924 L F
.751 .993 .868 r
.46722 .51049 m .46634 .51009 L .46767 .50871 L F
.022 0 0 r
.42267 .46687 m .42155 .46933 L .41957 .4696 L F
.013 0 0 r
.41957 .4696 m .42063 .47075 L .41826 .47173 L F
.41957 .4696 m .42155 .46933 L .42063 .47075 L F
.438 .438 .761 r
.27578 .56738 m .27682 .57047 L .2744 .56897 L F
.147 0 .106 r
.27682 .57047 m .27346 .57343 L .2744 .56897 L F
.431 .415 .74 r
.34128 .627 m .34224 .63077 L .33993 .63034 L F
0 0 0 r
.48415 .41047 m .48458 .41019 L .48594 .40852 L F
.48415 .41047 m .48245 .41165 L .48458 .41019 L F
.32423 .68371 m .32486 .68413 L .3222 .68465 L F
0 0 .484 r
.33464 .61063 m .33523 .61144 L .33266 .60828 L F
.942 .917 .544 r
.33344 .61353 m .33523 .61144 L .33464 .61063 L F
.552 .022 0 r
.33533 .61325 m .33523 .61144 L .33344 .61353 L F
.33533 .61325 m .33865 .61316 L .33523 .61144 L F
.532 .29 .493 r
.43378 .51416 m .43345 .5168 L .43025 .51725 L F
.034 .281 .776 r
.43301 .5106 m .43433 .51219 L .43378 .51416 L F
.791 .96 .641 r
.43378 .51416 m .43245 .51439 L .43345 .5168 L F
.43378 .51416 m .43433 .51219 L .43245 .51439 L F
.813 .885 .897 r
.40599 .58986 m .40788 .59099 L .41122 .58843 L F
.652 .957 .938 r
.5562 .37334 m .55774 .37118 L .55895 .37249 L F
.5562 .37334 m .55524 .37278 L .55774 .37118 L F
.159 0 0 r
.43254 .46139 m .43034 .46441 L .42777 .46521 L F
.075 0 0 r
.43254 .46139 m .43513 .46022 L .43484 .46129 L F
.236 0 0 r
.43484 .46129 m .43034 .46441 L .43254 .46139 L F
.846 .652 .64 r
.32311 .54575 m .32518 .54441 L .3232 .54372 L F
.32311 .54575 m .32491 .54754 L .32518 .54441 L F
.772 .612 .681 r
.337 .50999 m .33804 .51359 L .34175 .51112 L F
.108 0 .145 r
.27541 .54419 m .27732 .54334 L .27826 .541 L F
.485 .231 .454 r
.27732 .54334 m .28047 .5401 L .27826 .541 L F
0 0 0 r
.45122 .43687 m .44752 .43966 L .4497 .43846 L F
.45342 .43554 m .45122 .43687 L .4497 .43846 L F
.802 .96 .635 r
.58145 .38197 m .57934 .38587 L .58291 .38197 L F
.559 .935 .861 r
.58375 .3806 m .58145 .38197 L .58291 .38197 L F
.157 .522 .918 r
.58291 .38197 m .58468 .38193 L .58375 .3806 L F
.559 .935 .861 r
.58375 .3806 m .58145 .38197 L .58291 .38197 L F
.157 .522 .918 r
.58291 .38197 m .58468 .38193 L .58375 .3806 L F
.796 .794 .85 r
.44275 .5428 m .44178 .54015 L .44564 .54075 L F
.912 .843 .763 r
.46868 .52287 m .46936 .52673 L .47025 .52406 L F
.867 .908 .858 r
.46868 .52287 m .47025 .52406 L .4731 .52079 L F
.564 .362 .565 r
.49799 .4603 m .50107 .45994 L .50101 .45693 L F
.291 0 .127 r
.50107 .45994 m .50527 .45693 L .50101 .45693 L F
.881 .8 .765 r
.37524 .52644 m .37666 .53015 L .37754 .52778 L F
.291 .374 .776 r
.55976 .39033 m .5627 .39176 L .56175 .38847 L F
.773 .992 .882 r
.52415 .40036 m .52169 .40071 L .52491 .39805 L F
.277 .134 .499 r
.27541 .54419 m .27727 .54597 L .27732 .54334 L F
.289 .134 .49 r
.27541 .54419 m .27531 .54705 L .27727 .54597 L F
0 0 .037 r
.59945 .37385 m .59963 .37456 L .59863 .37643 L F
.715 .365 0 r
.59882 .37286 m .59971 .37491 L .59963 .37456 L F
.5 .649 .924 r
.60074 .37725 m .59863 .37643 L .59963 .37456 L F
.715 .365 0 r
.59971 .37491 m .60074 .37725 L .59963 .37456 L F
0 0 .037 r
.60016 .37162 m .59963 .37456 L .59945 .37385 L F
.5 .649 .924 r
.60074 .37725 m .59899 .37924 L .59863 .37643 L F
.852 .489 .363 r
.55802 .37968 m .55604 .3815 L .55409 .37821 L F
0 0 0 r
.56321 .38179 m .56071 .38447 L .56139 .38257 L F
.56139 .38257 m .56071 .38447 L .56142 .38283 L F
.764 .355 .277 r
.55802 .37968 m .56142 .38283 L .55604 .3815 L F
.443 .48 .802 r
.52484 .38142 m .52344 .38327 L .52196 .37882 L F
.648 .966 .82 r
.52486 .38133 m .52344 .38327 L .52484 .38142 L F
.443 .48 .802 r
.52484 .38142 m .52196 .37882 L .52452 .37826 L F
.648 .966 .82 r
.52486 .38133 m .52067 .38422 L .52344 .38327 L F
.847 .635 .616 r
.44564 .54075 m .44178 .54015 L .44286 .53766 L F
.561 .323 .511 r
.54355 .38002 m .54654 .38189 L .54638 .37908 L F
.54355 .38002 m .54405 .38366 L .54654 .38189 L F
0 0 0 r
.46449 .43884 m .46555 .4375 L .46782 .43623 L F
.413 .863 .837 r
.39625 .58222 m .40103 .58089 L .39875 .57878 L F
.425 0 0 r
.39793 .58135 m .39944 .58091 L .40103 .58089 L F
.963 .63 .289 r
.40048 .57941 m .40103 .58089 L .40205 .58088 L F
.39926 .57827 m .40025 .57973 L .40048 .57941 L F
.40025 .57973 m .40103 .58089 L .40048 .57941 L F
.413 .863 .837 r
.39625 .58222 m .3977 .58147 L .40103 .58089 L F
.3977 .58147 m .39793 .58135 L .39832 .58129 L F
.3977 .58147 m .39832 .58129 L .40103 .58089 L F
.963 .63 .289 r
.40205 .58088 m .40103 .58089 L .40228 .5811 L F
0 .049 .588 r
.40228 .5811 m .40253 .57636 L .39926 .57827 L F
.40238 .5792 m .40343 .57974 L .40253 .57636 L F
.40228 .5811 m .40343 .57974 L .40238 .5792 L F
.53 .918 .918 r
.40228 .5811 m .40103 .58089 L .40343 .57974 L F
.298 0 0 r
.40343 .57974 m .40266 .58006 L .40356 .57981 L F
.40343 .57974 m .40356 .57981 L .4036 .5798 L F
.972 .707 .469 r
.39875 .57878 m .40103 .58089 L .39926 .57827 L F
.741 .669 .781 r
.39472 .58439 m .39674 .58352 L .39571 .58383 L F
.39306 .58533 m .39595 .58391 L .39472 .58439 L F
.39595 .58391 m .39674 .58352 L .39472 .58439 L F
0 .017 .555 r
.39673 .58361 m .39792 .5815 L .39625 .58222 L F
.3976 .58613 m .3978 .58319 L .39673 .58361 L F
.3978 .58319 m .39792 .5815 L .39673 .58361 L F
.39792 .5815 m .39793 .58135 L .3977 .58147 L F
.39792 .5815 m .3977 .58147 L .39625 .58222 L F
.298 0 0 r
.4036 .5798 m .3991 .58163 L .40561 .58046 L F
0 .017 .555 r
.3976 .58613 m .39874 .5845 L .39797 .58153 L F
.39792 .5815 m .39797 .58153 L .39793 .58135 L F
.3976 .58613 m .39797 .58153 L .39792 .5815 L F
.425 0 0 r
.39944 .58091 m .40343 .57974 L .40103 .58089 L F
.034 .347 .824 r
.39571 .58383 m .39674 .58352 L .39625 .58222 L F
.72 .975 .745 r
.39625 .58222 m .39306 .58533 L .39571 .58383 L F
.741 .669 .781 r
.39306 .58533 m .39625 .58222 L .39674 .58352 L F
.39306 .58533 m .3976 .58613 L .39625 .58222 L F
.905 .978 .792 r
.39461 .58097 m .39306 .58533 L .39625 .58222 L F
.731 .436 .48 r
.39875 .57878 m .39461 .58097 L .39625 .58222 L F
.666 .238 .222 r
.39793 .58135 m .39725 .58293 L .39461 .58097 L F
.39725 .58293 m .39706 .58338 L .39663 .58296 L F
.39725 .58293 m .39663 .58296 L .39461 .58097 L F
.656 .503 .664 r
.39825 .5815 m .39874 .5845 L .40162 .58297 L F
.39793 .58135 m .39797 .58153 L .39825 .5815 L F
.39797 .58153 m .39874 .5845 L .39825 .5815 L F
.298 0 0 r
.40266 .58006 m .39969 .58133 L .4036 .5798 L F
.39969 .58133 m .39852 .58183 L .3998 .58132 L F
.39969 .58133 m .3998 .58132 L .4036 .5798 L F
.656 .503 .664 r
.39793 .58135 m .39926 .58194 L .39751 .58235 L F
.598 .346 .506 r
.39996 .58278 m .40561 .58046 L .39751 .58235 L F
.39745 .58249 m .39751 .58235 L .39709 .58244 L F
.39996 .58278 m .39751 .58235 L .39745 .58249 L F
0 0 0 r
.39853 .58005 m .39825 .58069 L .39793 .58135 L F
.298 0 0 r
.3991 .58163 m .39755 .58226 L .40011 .58174 L F
.656 .503 .664 r
.39793 .58135 m .39751 .58235 L .39709 .58244 L F
.298 0 0 r
.39755 .58226 m .39709 .58244 L .39751 .58235 L F
.39755 .58226 m .39751 .58235 L .40011 .58174 L F
0 0 0 r
.39751 .58235 m .39734 .58274 L .39745 .58249 L F
.3975 .58237 m .39745 .58249 L .39793 .58135 L F
.425 0 0 r
.39793 .58135 m .39709 .58244 L .39755 .58225 L F
.39793 .58135 m .39755 .58225 L .39891 .58167 L F
0 0 0 r
.39825 .58069 m .3975 .58237 L .39793 .58135 L F
.39825 .58069 m .39744 .58251 L .39751 .58235 L F
.39744 .58251 m .39734 .58274 L .39751 .58235 L F
.39734 .58274 m .39706 .58338 L .39793 .58135 L F
.656 .503 .664 r
.40059 .58252 m .40162 .58297 L .39996 .58278 L F
.598 .346 .506 r
.40162 .58297 m .40211 .58266 L .39996 .58278 L F
.40211 .58266 m .40561 .58046 L .39996 .58278 L F
.298 0 0 r
.39852 .58183 m .39709 .58244 L .39856 .58185 L F
.39852 .58183 m .39856 .58185 L .4036 .5798 L F
.3991 .58163 m .40011 .58174 L .40561 .58046 L F
.425 0 0 r
.39944 .58091 m .39891 .58167 L .40343 .57974 L F
.39793 .58135 m .39891 .58167 L .39944 .58091 L F
.734 .8 .904 r
.39935 .56768 m .39565 .56809 L .3952 .56577 L F
.375 0 0 r
.39935 .56768 m .39455 .56968 L .39565 .56809 L F
.383 0 0 r
.39241 .57254 m .39494 .57281 L .39542 .57219 L F
0 0 .238 r
.39547 .57022 m .39588 .57112 L .39494 .57281 L F
.375 0 0 r
.39935 .56768 m .39715 .56954 L .39519 .56965 L F
.39935 .56768 m .39519 .56965 L .39509 .56946 L F
.39509 .56946 m .39519 .56965 L .39455 .56968 L F
.117 .592 .915 r
.3952 .56577 m .39854 .56682 L .39935 .56768 L F
.939 .606 .375 r
.39565 .56809 m .39455 .56968 L .39459 .56625 L F
.969 .68 .272 r
.39459 .56625 m .39455 .56968 L .3939 .56694 L F
.924 .536 .172 r
.3939 .56694 m .39565 .56809 L .39459 .56625 L F
.919 .898 .791 r
.3952 .56577 m .39565 .56809 L .3939 .56694 L F
0 .516 .836 r
.39628 .56591 m .39854 .56682 L .3952 .56577 L F
.625 .537 .735 r
.39513 .56841 m .39715 .56954 L .39628 .56591 L F
.39455 .56968 m .39628 .56959 L .39513 .56841 L F
.39628 .56959 m .39715 .56954 L .39513 .56841 L F
.39455 .56968 m .39628 .56591 L .3939 .56694 L F
.371 .351 .707 r
.39455 .56968 m .39568 .56988 L .3939 .56694 L F
.833 .498 .42 r
.39507 .56943 m .39568 .56988 L .39525 .5698 L F
.39433 .56784 m .39472 .56844 L .39507 .56943 L F
.39472 .56844 m .39568 .56988 L .39507 .56943 L F
0 0 .238 r
.39505 .57003 m .39494 .57281 L .39455 .56968 L F
.505 .409 .679 r
.39455 .56968 m .39511 .57008 L .39568 .56988 L F
0 0 .238 r
.39542 .57043 m .39494 .57281 L .39504 .57019 L F
.3952 .56979 m .39504 .57019 L .39507 .56943 L F
.39542 .57043 m .39504 .57019 L .3952 .56979 L F
.505 .409 .679 r
.39455 .56968 m .39241 .57254 L .39059 .57164 L F
.39455 .56968 m .39494 .57281 L .39241 .57254 L F
.39455 .56968 m .39059 .57164 L .39511 .57008 L F
.754 .804 .893 r
.3952 .56979 m .39142 .57027 L .39141 .56915 L F
.39568 .56988 m .39515 .56993 L .3952 .56979 L F
.39515 .56993 m .39142 .57027 L .3952 .56979 L F
0 0 .238 r
.39507 .56943 m .39505 .57003 L .39455 .56968 L F
.754 .804 .893 r
.39515 .56993 m .39059 .57164 L .39142 .57027 L F
.39568 .56988 m .39511 .57008 L .39515 .56993 L F
.39511 .57008 m .39059 .57164 L .39515 .56993 L F
0 0 .238 r
.39569 .56912 m .39542 .57043 L .39519 .56977 L F
.39531 .56931 m .39519 .56977 L .39507 .56943 L F
.39569 .56912 m .39519 .56977 L .39531 .56931 L F
.833 .498 .42 r
.39425 .56751 m .39568 .56988 L .39379 .56704 L F
.082 .15 .635 r
.3939 .56694 m .39569 .56912 L .39507 .56943 L F
.3939 .56694 m .39507 .56943 L .39455 .56968 L F
.833 .498 .42 r
.39379 .56704 m .39433 .56784 L .39141 .56915 L F
.39433 .56784 m .39525 .5698 L .39141 .56915 L F
.3939 .56694 m .39425 .56751 L .39379 .56704 L F
0 0 .238 r
.39569 .56912 m .39587 .57104 L .39547 .57022 L F
.39587 .57104 m .39588 .57112 L .39547 .57022 L F
.573 .757 .965 r
.40082 .57439 m .39542 .57219 L .39853 .57155 L F
.975 .922 .617 r
.39854 .56682 m .39715 .56954 L .39935 .56768 L F
.631 .117 .005 r
.39853 .57155 m .40402 .57288 L .40082 .57439 L F
.989 .775 .521 r
.39715 .56954 m .39853 .57155 L .39935 .56768 L F
.745 .371 .343 r
.56175 .38847 m .56658 .38832 L .56332 .38644 L F
.898 .616 .5 r
.3531 .55376 m .3499 .55015 L .3538 .55091 L F
0 0 0 r
.29769 .62634 m .2976 .62557 L .29629 .62752 L F
.479 .78 .997 r
.39872 .54235 m .39773 .54429 L .39583 .54254 L F
.39872 .54235 m .40036 .54377 L .39773 .54429 L F
0 0 0 r
.39872 .54235 m .39773 .54429 L .40036 .54377 L F
.591 .17 .212 r
.39583 .54254 m .39479 .54516 L .39717 .54476 L F
.39739 .54444 m .39717 .54476 L .39759 .54469 L F
.39583 .54254 m .39717 .54476 L .39739 .54444 L F
0 0 0 r
.39841 .54297 m .39734 .54481 L .39773 .54429 L F
.39872 .54235 m .39823 .54322 L .39841 .54297 L F
.39823 .54322 m .39734 .54481 L .39841 .54297 L F
.497 .734 .978 r
.28923 .67432 m .29363 .67554 L .2919 .67368 L F
.621 .732 .926 r
.29363 .67554 m .29533 .67389 L .2919 .67368 L F
.29363 .67554 m .29613 .67462 L .29533 .67389 L F
.113 .244 .721 r
.62266 .38994 m .62485 .39106 L .62567 .38901 L F
.455 .145 .35 r
.53418 .35559 m .53092 .35803 L .53132 .35651 L F
.892 .837 .784 r
.43477 .55985 m .43538 .56308 L .43681 .56126 L F
.933 .872 .754 r
.43681 .56126 m .43665 .55584 L .43477 .55985 L F
.812 .535 .519 r
.49806 .44342 m .50257 .44698 L .50008 .4453 L F
.428 .18 .434 r
.50257 .44698 m .50215 .44946 L .49952 .45018 L F
.50257 .44698 m .50215 .44946 L .49952 .45018 L F
.798 .731 .79 r
.50257 .44698 m .49952 .45018 L .50008 .4453 L F
.898 .627 .518 r
.50008 .4453 m .50215 .44946 L .50257 .44698 L F
.819 .723 .759 r
.50008 .4453 m .50257 .44698 L .50443 .4429 L F
.898 .627 .518 r
.50257 .44698 m .50215 .44946 L .50008 .4453 L F
.083 0 0 r
.5405 .42694 m .54169 .42574 L .53917 .42669 L F
.516 .913 .815 r
.54382 .42398 m .54596 .42351 L .54169 .42574 L F
0 0 0 r
.54382 .42398 m .54169 .42574 L .5405 .42694 L F
.702 .934 .622 r
.50372 .42902 m .5028 .43032 L .50386 .42829 L F
.562 .085 0 r
.5028 .43032 m .50531 .43331 L .50165 .4326 L F
0 0 0 r
.50386 .42829 m .50165 .4326 L .50301 .43138 L F
.712 .727 .207 r
.50399 .42754 m .50386 .42829 L .50301 .43138 L F
.50435 .42613 m .50386 .42829 L .50399 .42754 L F
.702 .934 .622 r
.50415 .42842 m .50372 .42902 L .50386 .42829 L F
0 0 0 r
.50386 .42829 m .5028 .43032 L .50165 .4326 L F
.53683 .34818 m .53767 .34947 L .53935 .34815 L F
.53683 .34818 m .53576 .35124 L .53767 .34947 L F
.024 0 0 r
.53217 .42358 m .53332 .42398 L .53065 .42471 L F
.53217 .42358 m .53494 .42302 L .53332 .42398 L F
.509 .325 .567 r
.53481 .41994 m .53494 .42302 L .53217 .42358 L F
.791 .743 .809 r
.33667 .64043 m .33895 .64198 L .33575 .64459 L F
.77 .747 .832 r
.34083 .63889 m .33895 .64198 L .33667 .64043 L F
.816 .701 .739 r
.51947 .44934 m .51633 .44655 L .52028 .44724 L F
.51947 .44934 m .51575 .44918 L .51633 .44655 L F
0 0 0 r
.56572 .35135 m .56276 .35632 L .56418 .35414 L F
.22 .239 .668 r
.56276 .35632 m .56522 .35756 L .56418 .35414 L F
.502 .111 .231 r
.62739 .382 m .62578 .38606 L .62594 .38645 L F
.121 .638 .889 r
.50422 .41628 m .50613 .41724 L .50813 .41702 L F
.876 .935 .559 r
.56382 .36265 m .56274 .36352 L .56386 .36128 L F
.712 .966 .717 r
.58202 .34773 m .58366 .34511 L .58466 .34674 L F
.58202 .34773 m .58157 .34747 L .58366 .34511 L F
.829 .979 .883 r
.49636 .49776 m .49825 .49588 L .49698 .49511 L F
.821 .973 .894 r
.49436 .49761 m .49636 .49776 L .49698 .49511 L F
.778 .743 .821 r
.39 .57284 m .38412 .57808 L .38545 .5733 L F
.444 .282 .565 r
.52478 .38979 m .52493 .3931 L .52835 .3899 L F
.757 .577 .004 r
.35167 .65727 m .35142 .65446 L .35013 .65719 L F
.954 .929 .735 r
.34965 .66143 m .35167 .65727 L .35013 .65719 L F
.796 .966 .914 r
.41748 .57456 m .4142 .57719 L .41721 .57597 L F
.875 .623 .553 r
.41444 .57964 m .41721 .57597 L .4142 .57719 L F
.41444 .57964 m .41796 .58059 L .41721 .57597 L F
.843 .73 .739 r
.3234 .56027 m .32113 .56374 L .32493 .5641 L F
.849 .723 .725 r
.32048 .56634 m .32493 .5641 L .32113 .56374 L F
.32048 .56634 m .32289 .56791 L .32493 .5641 L F
.996 .843 .5 r
.49952 .45018 m .49908 .45358 L .49792 .45157 L F
.49792 .45157 m .49908 .45358 L .49952 .45018 L F
.731 .266 .146 r
.32077 .6254 m .32439 .62763 L .32009 .62714 L F
.791 .743 .809 r
.33667 .64043 m .33575 .64459 L .33443 .64109 L F
.842 .613 .591 r
.33554 .61801 m .33747 .62114 L .33702 .62106 L F
.909 .778 .705 r
.33503 .61892 m .33512 .61715 L .33554 .61801 L F
.842 .613 .591 r
.33554 .61801 m .33391 .62174 L .33503 .61892 L F
.33554 .61801 m .33231 .62026 L .33391 .62174 L F
.33554 .61801 m .33702 .62106 L .33231 .62026 L F
.909 .778 .705 r
.33512 .61715 m .33531 .61366 L .33554 .61801 L F
.84 .92 .887 r
.48947 .48087 m .48481 .48287 L .48769 .47955 L F
.875 .65 .595 r
.32312 .55067 m .32243 .55334 L .32595 .55404 L F
.892 .664 .586 r
.32243 .55334 m .32576 .5563 L .32595 .55404 L F
.866 .95 .866 r
.25577 .60275 m .25355 .60432 L .25493 .60335 L F
.572 .342 .528 r
.25809 .59709 m .25522 .59792 L .25577 .60275 L F
.47 0 0 r
.25493 .60335 m .25929 .60384 L .25577 .60275 L F
.568 .375 .58 r
.49799 .4603 m .49838 .46307 L .50107 .45994 L F
.49799 .4603 m .49838 .46307 L .50107 .45994 L F
.858 .887 .857 r
.46373 .52992 m .46582 .53117 L .46726 .5292 L F
.392 .211 .513 r
.2575 .57731 m .25975 .57386 L .25746 .57456 L F
.253 .735 .931 r
.33257 .6757 m .3359 .67591 L .33385 .67411 L F
.903 .895 .81 r
.3359 .67591 m .33729 .67186 L .33385 .67411 L F
.306 .117 .452 r
.30641 .64275 m .30808 .63717 L .30763 .63927 L F
.797 .65 .7 r
.31064 .63646 m .30763 .63927 L .30808 .63717 L F
.825 .987 .875 r
.51552 .47936 m .51335 .4829 L .51571 .47991 L F
.51552 .47936 m .51216 .48236 L .51335 .4829 L F
.827 .558 .532 r
.42921 .51954 m .42632 .52231 L .42646 .51927 L F
.43048 .51967 m .42632 .52231 L .42921 .51954 L F
.81 .977 .685 r
.42448 .52413 m .42464 .52392 L .42632 .52231 L F
0 0 .346 r
.42632 .52231 m .42637 .52194 L .42646 .51927 L F
.738 .379 .371 r
.43025 .51725 m .42646 .51927 L .42654 .51686 L F
.43025 .51725 m .43048 .51967 L .42646 .51927 L F
0 0 .346 r
.42637 .52194 m .42699 .51774 L .42646 .51927 L F
.42632 .52231 m .42694 .52098 L .42699 .51774 L F
.81 .977 .685 r
.42464 .52392 m .42694 .52098 L .42632 .52231 L F
.738 .379 .371 r
.42654 .51686 m .42646 .51927 L .426 .51681 L F
.621 .29 .389 r
.43025 .51725 m .43273 .51957 L .43048 .51967 L F
.536 .304 .51 r
.43025 .51725 m .43345 .5168 L .43273 .51957 L F
.993 .861 .517 r
.34348 .67053 m .34426 .66829 L .34255 .67038 L F
.734 .923 .571 r
.34426 .66829 m .34677 .66472 L .34484 .66668 L F
.728 .894 .506 r
.34255 .67038 m .34426 .66829 L .34484 .66668 L F
.487 .165 .345 r
.57 .38076 m .56521 .37881 L .56951 .37886 L F
.57 .38076 m .56691 .38158 L .56521 .37881 L F
0 0 0 r
.42549 .45558 m .42931 .45282 L .42718 .45414 L F
.42549 .45558 m .42718 .45414 L .4235 .45636 L F
.86 .748 .739 r
.29141 .5498 m .29236 .55044 L .29364 .54729 L F
0 .153 .675 r
.60297 .35983 m .60253 .36291 L .60135 .35883 L F
.169 .354 .805 r
.60297 .35983 m .60557 .36477 L .60253 .36291 L F
.419 .324 .642 r
.60557 .36477 m .60344 .36631 L .60253 .36291 L F
.545 .11 .165 r
.37861 .47889 m .38119 .47916 L .383 .47684 L F
.184 0 0 r
.38119 .47916 m .38562 .47715 L .383 .47684 L F
.652 .68 .864 r
.63521 .35303 m .63499 .35488 L .63853 .35227 L F
.976 .858 .659 r
.54512 .43887 m .54771 .43661 L .54687 .43514 L F
.54512 .43887 m .54651 .44033 L .54771 .43661 L F
.888 .659 .586 r
.35196 .54712 m .34816 .54646 L .34847 .54346 L F
.85 .721 .72 r
.3499 .55015 m .34816 .54646 L .35196 .54712 L F
.825 .847 .386 r
.54732 .41952 m .54652 .42048 L .5475 .41883 L F
.54732 .41952 m .54596 .42351 L .54652 .42048 L F
.819 .723 .759 r
.50008 .4453 m .50443 .4429 L .50335 .44203 L F
.785 .804 .868 r
.50443 .4429 m .50559 .43902 L .50335 .44203 L F
.50443 .4429 m .50791 .44022 L .50559 .43902 L F
0 0 0 r
.29629 .62752 m .29244 .63013 L .29482 .62945 L F
.29769 .62634 m .29629 .62752 L .29482 .62945 L F
.895 .988 .755 r
.54846 .40817 m .54814 .41059 L .54593 .40759 L F
.667 .69 .862 r
.54194 .34541 m .54171 .34918 L .53935 .34815 L F
.218 0 .039 r
.54171 .34918 m .53967 .35176 L .53935 .34815 L F
.54171 .34918 m .54235 .35096 L .53967 .35176 L F
.362 .417 .784 r
.54194 .34541 m .54496 .34685 L .54171 .34918 L F
.165 0 .056 r
.545 .34976 m .54171 .34918 L .54496 .34685 L F
.545 .34976 m .54235 .35096 L .54171 .34918 L F
.347 .792 .957 r
.29925 .59033 m .30251 .58947 L .30188 .5876 L F
.29925 .59033 m .29994 .58928 L .30258 .58945 L F
.821 .69 .719 r
.29779 .59297 m .29967 .59316 L .29994 .58928 L F
.29967 .59316 m .30167 .59337 L .3009 .59156 L F
.29967 .59316 m .3009 .59156 L .29994 .58928 L F
.347 .792 .957 r
.30251 .58947 m .30258 .58945 L .30256 .5894 L F
.30251 .58947 m .30256 .5894 L .30188 .5876 L F
.573 .669 .903 r
.51025 .4363 m .50531 .43331 L .50622 .43582 L F
.862 .766 .755 r
.50559 .43902 m .51025 .4363 L .50622 .43582 L F
.50559 .43902 m .50791 .44022 L .51025 .4363 L F
.713 .591 .718 r
.33945 .61451 m .33994 .61986 L .33554 .61801 L F
.362 0 0 r
.33554 .61801 m .33994 .61986 L .3374 .61911 L F
0 0 .35 r
.34062 .61628 m .33994 .61986 L .33945 .61451 L F
.829 .988 .87 r
.3374 .61911 m .33994 .61986 L .34062 .61628 L F
.96 .9 .721 r
.64648 .36298 m .64535 .36617 L .64412 .36481 L F
.47 .295 .561 r
.53775 .42199 m .53494 .42302 L .53481 .41994 L F
.475 0 0 r
.5367 .42156 m .53775 .42199 L .53641 .42105 L F
.5367 .42156 m .53641 .42105 L .53481 .41994 L F
.763 .992 .881 r
.5367 .42156 m .53775 .42199 L .53863 .41969 L F
.5367 .42156 m .53775 .42199 L .53863 .41969 L F
0 0 0 r
.53678 .42169 m .5367 .42156 L .53863 .41969 L F
.53332 .42398 m .53494 .42302 L .53775 .42199 L F
.53332 .42398 m .53775 .42199 L .5367 .42156 L F
.53428 .4244 m .5367 .42156 L .53678 .42169 L F
.475 0 0 r
.5367 .42156 m .53481 .41994 L .53367 .41813 L F
.97 .655 .286 r
.35392 .57093 m .35217 .56661 L .35418 .56767 L F
.156 0 .077 r
.42267 .46687 m .42404 .46837 L .42155 .46933 L F
.42267 .46687 m .42519 .46571 L .42404 .46837 L F
1 .813 .508 r
.31324 .64061 m .31282 .64411 L .31186 .63997 L F
0 0 0 r
.31437 .63966 m .31324 .64061 L .31186 .63997 L F
.31437 .63966 m .31633 .63784 L .31324 .64061 L F
1 .813 .508 r
.31324 .64061 m .31282 .64411 L .31186 .63997 L F
.786 .873 .912 r
.63677 .39221 m .64045 .39025 L .63908 .38883 L F
.749 .865 .933 r
.63908 .38883 m .64045 .39025 L .64377 .38858 L F
0 0 .294 r
.5788 .38777 m .57862 .39001 L .57753 .38973 L F
.705 .468 .564 r
.51413 .40961 m .5183 .40948 L .51766 .40647 L F
.533 .358 .59 r
.51766 .40647 m .52091 .40652 L .51934 .40464 L F
.51766 .40647 m .5183 .40948 L .52091 .40652 L F
.307 .567 .93 r
.38665 .56356 m .38565 .56434 L .38208 .56065 L F
.38665 .56356 m .38208 .56065 L .38501 .5609 L F
.57 .632 .873 r
.38106 .56561 m .38656 .56352 L .38342 .56111 L F
0 .015 .554 r
.38177 .56428 m .38166 .56518 L .38106 .56561 L F
.377 .84 .796 r
.38565 .56434 m .38106 .56561 L .38063 .5659 L F
.27 .761 .687 r
.38665 .56356 m .38106 .56561 L .38565 .56434 L F
.38665 .56356 m .38656 .56352 L .38224 .56516 L F
.38222 .56518 m .38224 .56516 L .38106 .56561 L F
.38665 .56356 m .38224 .56516 L .38222 .56518 L F
.57 .632 .873 r
.38106 .56561 m .38174 .56431 L .38177 .56428 L F
.38174 .56431 m .38342 .56111 L .38177 .56428 L F
.327 0 .21 r
.37682 .56098 m .37805 .56221 L .38183 .56115 L F
.37627 .56097 m .37805 .56221 L .37682 .56098 L F
.071 0 .021 r
.37725 .56489 m .37891 .56307 L .37805 .56221 L F
.37891 .56307 m .38039 .56147 L .37805 .56221 L F
.698 .706 .854 r
.37627 .56097 m .38183 .56115 L .3786 .55749 L F
.004 .365 .835 r
.3786 .55749 m .38183 .56115 L .38208 .56065 L F
.3786 .55749 m .38136 .56 L .38252 .55567 L F
.889 .951 .84 r
.38132 .56003 m .37805 .56221 L .3808 .55888 L F
.38183 .56115 m .37877 .56201 L .38132 .56003 L F
.37877 .56201 m .37805 .56221 L .38132 .56003 L F
.004 .365 .835 r
.38136 .56 m .38208 .56065 L .38219 .55935 L F
.38136 .56 m .38219 .55935 L .38252 .55567 L F
.88 .577 .471 r
.38039 .56147 m .38177 .56428 L .38342 .56111 L F
0 0 .394 r
.38153 .56369 m .38183 .5642 L .38177 .56428 L F
.38183 .5642 m .38231 .56503 L .38177 .56428 L F
.38231 .56503 m .38327 .5667 L .38227 .5651 L F
.38231 .56503 m .38227 .5651 L .38177 .56428 L F
0 .015 .554 r
.38166 .56518 m .38137 .56778 L .38106 .56561 L F
.377 .84 .796 r
.38063 .5659 m .38106 .56561 L .38017 .56605 L F
.269 .75 .93 r
.63543 .33904 m .63822 .33882 L .63957 .33934 L F
.318 .776 .949 r
.63822 .33882 m .64242 .3391 L .63957 .33934 L F
.813 .885 .897 r
.40599 .58986 m .41122 .58843 L .40968 .58764 L F
.816 .965 .903 r
.41146 .58578 m .41122 .58843 L .41302 .58684 L F
.41146 .58578 m .40968 .58764 L .41122 .58843 L F
.86 .577 .508 r
.34331 .53045 m .34049 .53263 L .34056 .53013 L F
.34331 .53045 m .3432 .53338 L .34049 .53263 L F
.841 .628 .614 r
.3531 .55376 m .35543 .5577 L .35339 .55677 L F
.907 .768 .696 r
.35331 .5606 m .35339 .55677 L .35543 .5577 L F
.849 .835 .832 r
.37112 .55932 m .37039 .56414 L .37303 .56082 L F
.654 .487 .645 r
.37039 .56414 m .37319 .56417 L .37303 .56082 L F
.613 .475 .67 r
.37303 .56082 m .37627 .56097 L .37577 .55733 L F
.334 .24 .597 r
.37303 .56082 m .37553 .56291 L .37627 .56097 L F
.37303 .56082 m .37319 .56417 L .37553 .56291 L F
.681 .84 .959 r
.63615 .37783 m .63428 .38102 L .63247 .3806 L F
.63615 .37783 m .63763 .37939 L .63428 .38102 L F
.019 0 0 r
.39284 .47416 m .39358 .47493 L .39534 .47324 L F
.39284 .47416 m .3911 .47577 L .39358 .47493 L F
.816 .463 .388 r
.42982 .50871 m .43373 .50718 L .42988 .50598 L F
.42982 .50871 m .43301 .5106 L .43373 .50718 L F
.391 .208 .509 r
.50046 .43983 m .49806 .44342 L .50053 .4425 L F
.473 .408 .704 r
.49806 .44342 m .50008 .4453 L .50053 .4425 L F
.735 .494 .564 r
.30302 .64117 m .29994 .64434 L .3 .64097 L F
.30302 .64117 m .30516 .64485 L .29994 .64434 L F
.795 .706 .767 r
.30641 .64275 m .30516 .64485 L .30302 .64117 L F
0 0 0 r
.53238 .39805 m .53247 .39842 L .53 .39943 L F
.5312 .39989 m .53 .39943 L .53247 .39842 L F
.5312 .39989 m .52886 .40102 L .53 .39943 L F
.773 .519 .551 r
.4018 .54744 m .4017 .55022 L .40511 .54988 L F
.129 .263 .734 r
.26269 .59056 m .26167 .5913 L .2599 .58691 L F
.611 .531 .74 r
.26269 .59056 m .26066 .5939 L .26167 .5913 L F
0 0 .26 r
.30188 .5876 m .30258 .58945 L .30049 .58341 L F
.216 .039 .413 r
.25544 .58082 m .25721 .58041 L .2575 .57731 L F
.481 .818 .999 r
.51509 .37996 m .51776 .37919 L .51929 .38023 L F
.572 .86 .996 r
.51929 .38023 m .5205 .37828 L .52196 .37882 L F
.51929 .38023 m .51776 .37919 L .5205 .37828 L F
.821 .83 .856 r
.52442 .43944 m .52516 .44283 L .5217 .44255 L F
.819 .833 .86 r
.5217 .44255 m .52516 .44283 L .52354 .44311 L F
.898 .868 .8 r
.52761 .43873 m .52516 .44283 L .52442 .43944 L F
.656 .368 .471 r
.33747 .62114 m .33391 .62174 L .33231 .62026 L F
.362 0 0 r
.33579 .61841 m .3374 .61911 L .33747 .62114 L F
.283 .752 .943 r
.33561 .61848 m .3374 .61911 L .33309 .61871 L F
.33309 .61871 m .3374 .61911 L .33561 .61848 L F
.276 0 0 r
.33836 .61953 m .3374 .61911 L .33561 .61848 L F
.765 .641 .725 r
.33996 .62083 m .3405 .62454 L .343 .62071 L F
.813 .997 .772 r
.34035 .62029 m .33937 .62314 L .3374 .61911 L F
.276 0 0 r
.34035 .62029 m .3374 .61911 L .33836 .61953 L F
.362 0 0 r
.33554 .61801 m .3374 .61911 L .33579 .61841 L F
0 0 0 r
.34677 .66472 m .34965 .66143 L .34844 .6639 L F
.34484 .66668 m .34677 .66472 L .34844 .6639 L F
.664 .86 .974 r
.60557 .36477 m .60344 .36631 L .60694 .3662 L F
.60557 .36477 m .60344 .36631 L .60694 .3662 L F
.654 .856 .977 r
.60557 .36477 m .60694 .3662 L .60998 .36489 L F
.60557 .36477 m .60694 .3662 L .60998 .36489 L F
.96 .9 .721 r
.64648 .36298 m .64412 .36481 L .64439 .36162 L F
.912 .843 .763 r
.46868 .52287 m .46649 .52654 L .46936 .52673 L F
.889 .88 .819 r
.46649 .52654 m .46726 .5292 L .46936 .52673 L F
.28 0 .202 r
.41056 .46613 m .41398 .46234 L .41137 .46295 L F
.924 .84 .391 r
.31046 .56699 m .30922 .56886 L .30681 .567 L F
.31046 .56699 m .30954 .57093 L .30922 .56886 L F
.043 0 0 r
.50527 .45693 m .50628 .4577 L .50804 .45767 L F
.305 0 0 r
.50628 .4577 m .5107 .45634 L .50804 .45767 L F
.636 .964 .836 r
.5389 .40645 m .5402 .40465 L .54075 .40519 L F
.976 .71 .302 r
.5389 .40645 m .53791 .40625 L .5402 .40465 L F
.5389 .40645 m .53897 .40895 L .53791 .40625 L F
.786 .873 .912 r
.63677 .39221 m .63908 .38883 L .63567 .39114 L F
.867 .908 .858 r
.46868 .52287 m .4731 .52079 L .47172 .5198 L F
.865 .933 .866 r
.47602 .51761 m .47172 .5198 L .4731 .52079 L F
.286 .086 .424 r
.26048 .57112 m .26244 .57239 L .26276 .56934 L F
.26048 .57112 m .25975 .57386 L .26244 .57239 L F
0 .148 .613 r
.60131 .34186 m .60507 .34475 L .60253 .34265 L F
.551 .476 .723 r
.53751 .41652 m .54028 .41574 L .53929 .41319 L F
.972 .671 .288 r
.66801 .35374 m .66937 .35286 L .66757 .35117 L F
.66801 .35374 m .66958 .35548 L .66937 .35286 L F
0 0 .333 r
.36673 .57079 m .36713 .5717 L .36569 .56738 L F
.502 .111 .231 r
.62739 .382 m .62712 .38584 L .62578 .38606 L F
.046 .33 .811 r
.62651 .38506 m .62726 .38631 L .62765 .38584 L F
.62726 .38631 m .62826 .38798 L .62775 .3862 L F
.505 .528 .814 r
.62567 .38901 m .62826 .38798 L .62712 .38584 L F
.82 .421 0 r
.62712 .38584 m .62826 .38798 L .62741 .38655 L F
.62712 .38584 m .62741 .38655 L .62651 .38506 L F
.502 .111 .231 r
.62739 .382 m .62597 .38302 L .62712 .38584 L F
.62597 .38302 m .62381 .38458 L .62712 .38584 L F
.046 .33 .811 r
.62726 .38631 m .62775 .3862 L .62765 .38584 L F
.505 .528 .814 r
.62576 .38666 m .62712 .38584 L .62578 .38606 L F
.62567 .38901 m .62686 .3864 L .62576 .38666 L F
.62686 .3864 m .62712 .38584 L .62576 .38666 L F
.897 .983 .714 r
.5018 .491 m .49993 .49209 L .49965 .49457 L F
.85 .982 .862 r
.49965 .49457 m .49698 .49511 L .49825 .49588 L F
.49965 .49457 m .49993 .49209 L .49698 .49511 L F
.954 .929 .735 r
.34965 .66143 m .35013 .65719 L .34997 .65947 L F
.787 .829 .359 r
.34844 .6639 m .34965 .66143 L .34997 .65947 L F
0 0 0 r
.409 .56414 m .40947 .56504 L .41188 .56623 L F
.409 .56414 m .40846 .56599 L .40947 .56504 L F
.797 .97 .668 r
.44866 .54566 m .44822 .54561 L .44755 .54779 L F
.552 .822 .996 r
.44755 .54779 m .44822 .54561 L .44551 .54637 L F
.898 .872 .803 r
.44494 .55119 m .44755 .54779 L .44551 .54637 L F
.291 0 .127 r
.50107 .45994 m .50377 .45931 L .50527 .45693 L F
.043 0 0 r
.50527 .45693 m .50377 .45931 L .50628 .4577 L F
.403 .811 .603 r
.48631 .42287 m .48582 .42317 L .48228 .42551 L F
.401 .843 .731 r
.48859 .42167 m .48813 .42175 L .48631 .42287 L F
0 0 0 r
.48813 .42175 m .48582 .42317 L .48631 .42287 L F
.713 .591 .718 r
.33945 .61451 m .33554 .61801 L .33531 .61366 L F
.922 .656 .517 r
.66982 .35779 m .67206 .35624 L .66958 .35548 L F
.66982 .35779 m .67205 .35898 L .67206 .35624 L F
.524 .42 .678 r
.5184 .37476 m .5208 .37271 L .51887 .37089 L F
0 .235 .747 r
.28258 .66081 m .28422 .66433 L .28541 .66454 L F
.149 .278 .741 r
.28422 .66433 m .2869 .66684 L .28541 .66454 L F
.55 .819 .996 r
.64078 .34618 m .63708 .3462 L .63778 .34638 L F
.86 .912 .866 r
.44197 .55448 m .44311 .55008 L .43994 .55277 L F
.44197 .55448 m .44494 .55119 L .44311 .55008 L F
.685 .917 .972 r
.39111 .58665 m .39013 .58875 L .39256 .5875 L F
.39111 .58665 m .38856 .58786 L .39013 .58875 L F
.904 .842 .772 r
.52847 .43692 m .52761 .43873 L .52442 .43944 L F
.67 .689 .859 r
.3156 .68161 m .31817 .68198 L .31782 .6807 L F
0 .134 .681 r
.3156 .68161 m .31797 .68396 L .31817 .68198 L F
.5 .577 .865 r
.31782 .6807 m .31817 .68198 L .32109 .68041 L F
.763 .662 .751 r
.31797 .68396 m .32109 .68041 L .31817 .68198 L F
.796 .676 .733 r
.51778 .44528 m .52028 .44724 L .51633 .44655 L F
.834 .824 .839 r
.5217 .44255 m .52028 .44724 L .51778 .44528 L F
.5217 .44255 m .52354 .44311 L .52028 .44724 L F
.777 .819 .886 r
.38665 .56356 m .38917 .56493 L .38925 .56271 L F
.904 .842 .772 r
.52847 .43692 m .52442 .43944 L .52629 .43551 L F
.875 .914 .851 r
.5296 .43274 m .52847 .43692 L .52629 .43551 L F
.5296 .43274 m .53093 .43414 L .52847 .43692 L F
.848 .928 .882 r
.50704 .40585 m .5088 .40224 L .5102 .40532 L F
.562 .438 .668 r
.28047 .5401 m .2826 .53681 L .28061 .53731 L F
.836 .856 .86 r
.64596 .38841 m .64829 .38987 L .64902 .38824 L F
.963 .911 .714 r
.30856 .54264 m .30531 .54582 L .30569 .54296 L F
0 0 0 r
.44033 .45595 m .43722 .4591 L .43848 .45745 L F
.31205 .63422 m .31559 .6322 L .3138 .63308 L F
.821 .832 .857 r
.3176 .62845 m .31559 .6322 L .313 .62998 L F
.517 .882 .978 r
.31559 .6322 m .31755 .63123 L .3138 .63308 L F
.63 .428 .59 r
.38402 .48513 m .38027 .48331 L .38498 .48274 L F
0 0 0 r
.38703 .48298 m .38402 .48513 L .38498 .48274 L F
.684 .389 .469 r
.38554 .5542 m .38521 .55674 L .38252 .55567 L F
.55 .042 0 r
.38554 .5542 m .38762 .55585 L .38521 .55674 L F
0 0 .048 r
.59636 .38535 m .59429 .38956 L .59376 .38983 L F
0 0 .274 r
.59429 .38956 m .59429 .39161 L .59376 .38983 L F
0 0 .517 r
.426 .51681 m .42563 .51248 L .42651 .51393 L F
.818 .931 .907 r
.31132 .62592 m .31143 .6262 L .30891 .62677 L F
.31132 .62592 m .3116 .62336 L .31143 .6262 L F
.998 .841 .507 r
.4048 .48324 m .40308 .48545 L .40363 .48218 L F
.952 .945 .731 r
.4048 .48324 m .40363 .48218 L .40576 .47819 L F
.645 .199 .176 r
.40763 .48564 m .40308 .48545 L .4048 .48324 L F
.998 .841 .507 r
.4048 .48324 m .40308 .48545 L .40363 .48218 L F
.873 .611 .539 r
.34875 .54069 m .34597 .54259 L .34628 .53977 L F
.34875 .54069 m .34847 .54346 L .34597 .54259 L F
.82 .575 .02 r
.53701 .38818 m .53782 .39218 L .53834 .38944 L F
.891 .922 .836 r
.5397 .3853 m .53834 .38944 L .54137 .38713 L F
.5397 .3853 m .53701 .38818 L .53834 .38944 L F
0 0 .179 r
.33308 .67672 m .33257 .6757 L .33385 .67411 L F
0 0 0 r
.44197 .44343 m .4382 .44549 L .44046 .44514 L F
.032 0 0 r
.44455 .44254 m .44197 .44343 L .44046 .44514 L F
.522 .843 .543 r
.49886 .39977 m .50035 .39824 L .50196 .3968 L F
0 0 0 r
.50196 .3968 m .50276 .39693 L .50394 .39522 L F
.50196 .3968 m .50035 .39824 L .50276 .39693 L F
.836 .93 .892 r
.46493 .51452 m .46072 .51631 L .4632 .51323 L F
.46493 .51452 m .46072 .51788 L .46072 .51631 L F
.826 .886 .887 r
.46503 .5114 m .46493 .51452 L .4632 .51323 L F
.833 .975 .884 r
.32199 .61193 m .31798 .61394 L .32015 .61075 L F
.873 .896 .847 r
.32456 .60851 m .32199 .61193 L .32015 .61075 L F
.893 .562 .412 r
.36796 .56351 m .3683 .566 L .37039 .56414 L F
.849 .835 .832 r
.37112 .55932 m .36796 .56351 L .37039 .56414 L F
.705 .275 .225 r
.3683 .566 m .37291 .5666 L .37039 .56414 L F
.62 .312 .426 r
.37039 .56414 m .37291 .5666 L .37319 .56417 L F
.939 .941 .765 r
.43188 .56598 m .43097 .57048 L .43311 .56672 L F
.991 .879 .607 r
.4326 .56331 m .43311 .56672 L .43538 .56308 L F
.4326 .56331 m .43188 .56598 L .43311 .56672 L F
.314 .331 .719 r
.5804 .37724 m .57826 .38011 L .5768 .37801 L F
.921 .974 .698 r
.54208 .44553 m .54356 .44359 L .5416 .4446 L F
.848 .993 .842 r
.54293 .4426 m .54356 .44359 L .54651 .44033 L F
.934 .967 .69 r
.5416 .4446 m .54356 .44359 L .54293 .4426 L F
.303 .767 .944 r
.38381 .58761 m .38143 .58732 L .38385 .5876 L F
.41 .72 .988 r
.32991 .62054 m .33391 .62174 L .33231 .62026 L F
.334 0 .151 r
.33391 .62174 m .33042 .62294 L .33231 .62026 L F
.331 .071 .361 r
.29174 .5241 m .29122 .52646 L .29408 .52321 L F
.29174 .5241 m .29122 .52646 L .29408 .52321 L F
.928 .589 .372 r
.37405 .53647 m .37455 .53941 L .37591 .53759 L F
.89 .99 .756 r
.31289 .68528 m .3156 .68161 L .31406 .68208 L F
.637 .909 .982 r
.3156 .68161 m .31782 .6807 L .31562 .6796 L F
.843 .998 .778 r
.31406 .68208 m .3156 .68161 L .31562 .6796 L F
.252 .752 .895 r
.64242 .3391 m .64504 .33879 L .64649 .3391 L F
.218 .671 .949 r
.64785 .33833 m .64649 .3391 L .64504 .33879 L F
.64785 .33833 m .64918 .33929 L .64649 .3391 L F
.172 0 0 r
.38347 .55005 m .38643 .54911 L .38795 .54708 L F
.864 .663 .629 r
.38643 .54911 m .39069 .54701 L .38795 .54708 L F
.668 .783 .935 r
.53213 .43083 m .53093 .43414 L .5296 .43274 L F
.53213 .43083 m .53368 .43294 L .53093 .43414 L F
.677 .411 .512 r
.56409 .35176 m .56834 .34925 L .56618 .35117 L F
.396 .853 .83 r
.56572 .35135 m .56409 .35176 L .56618 .35117 L F
0 0 0 r
.56572 .35135 m .56418 .35414 L .56409 .35176 L F
.677 .411 .512 r
.56409 .35176 m .56824 .35177 L .56834 .34925 L F
.898 .616 .5 r
.3531 .55376 m .35001 .55301 L .3499 .55015 L F
.909 .668 .561 r
.35339 .55677 m .35001 .55301 L .3531 .55376 L F
.146 0 .314 r
.30595 .59368 m .30649 .59104 L .30799 .58941 L F
.817 .698 .732 r
.32033 .644 m .318 .647 L .31863 .6455 L F
.727 .695 .819 r
.43169 .52764 m .4327 .53045 L .42877 .5299 L F
.711 .458 .54 r
.43255 .53277 m .42877 .5299 L .4327 .53045 L F
.22 .372 .804 r
.43169 .52764 m .43421 .52891 L .4327 .53045 L F
0 0 .345 r
.43421 .52891 m .43255 .53277 L .4327 .53045 L F
.303 .767 .944 r
.38381 .58761 m .38359 .58684 L .38143 .58732 L F
.173 .665 .92 r
.38856 .58786 m .38359 .58684 L .38381 .58761 L F
.203 .73 .759 r
.61076 .34346 m .61538 .34267 L .61222 .34316 L F
0 .208 .734 r
.57325 .35732 m .57411 .35947 L .57159 .35567 L F
.082 .142 .627 r
.57325 .35732 m .57362 .36171 L .57411 .35947 L F
.744 .978 .732 r
.61247 .35055 m .61097 .35321 L .61391 .35214 L F
.924 .777 .679 r
.3776 .56932 m .37858 .57355 L .37875 .57083 L F
.669 .922 .614 r
.28772 .55437 m .28521 .55718 L .28616 .55568 L F
.117 .262 .738 r
.28521 .55718 m .28755 .55888 L .28616 .55568 L F
.905 .501 .108 r
.46072 .51788 m .46028 .51901 L .46072 .51631 L F
.46072 .51788 m .46187 .52021 L .46028 .51901 L F
0 0 0 r
.42018 .45971 m .42228 .45834 L .4235 .45636 L F
.42458 .45709 m .4235 .45636 L .42228 .45834 L F
.42458 .45709 m .42549 .45558 L .4235 .45636 L F
.892 .837 .784 r
.43477 .55985 m .4326 .56331 L .43538 .56308 L F
.825 .98 .885 r
.50239 .48853 m .5018 .491 L .50357 .48942 L F
.87 .988 .721 r
.50239 .48853 m .49993 .49209 L .5018 .491 L F
.439 .867 .754 r
.32517 .60788 m .32654 .60757 L .32456 .60851 L F
0 0 0 r
.32985 .60692 m .32654 .60757 L .32517 .60788 L F
.82 .489 .43 r
.30435 .56775 m .3002 .56935 L .29977 .5671 L F
.30435 .56775 m .30367 .57045 L .3002 .56935 L F
0 0 .148 r
.30523 .56891 m .30435 .56775 L .30681 .567 L F
.30523 .56891 m .30367 .57045 L .30435 .56775 L F
.745 .371 .343 r
.56175 .38847 m .56601 .389 L .56658 .38832 L F
.513 .82 1 r
.58857 .43218 m .59001 .43342 L .59295 .43269 L F
.58857 .43218 m .59001 .43342 L .59295 .43269 L F
.155 0 0 r
.64918 .33929 m .65295 .33992 L .65339 .33982 L F
.403 0 0 r
.65295 .33992 m .65599 .34123 L .65339 .33982 L F
.892 .664 .586 r
.32243 .55334 m .32201 .55651 L .32576 .5563 L F
.898 .789 .732 r
.32201 .55651 m .3234 .56027 L .32576 .5563 L F
.749 .865 .933 r
.63908 .38883 m .64377 .38858 L .64168 .38723 L F
.413 .743 .993 r
.64596 .38841 m .64168 .38723 L .64377 .38858 L F
.409 .163 .427 r
.34871 .63746 m .3479 .64098 L .34505 .64168 L F
.951 .599 .25 r
.34662 .63403 m .34714 .63658 L .34871 .63746 L F
0 .366 .683 r
.34851 .63734 m .34871 .63746 L .34714 .63658 L F
.34851 .63734 m .35138 .63838 L .34871 .63746 L F
.993 .783 .515 r
.34714 .63658 m .3479 .64098 L .34871 .63746 L F
.998 .794 .504 r
.33488 .51688 m .33456 .52016 L .3329 .51853 L F
.015 0 0 r
.33488 .51688 m .33599 .5176 L .3381 .51556 L F
.33488 .51688 m .3329 .51853 L .33599 .5176 L F
.619 .788 .962 r
.28502 .55315 m .28772 .55437 L .2891 .55239 L F
.748 .608 .703 r
.28616 .55568 m .2891 .55239 L .28772 .55437 L F
.858 .887 .857 r
.46373 .52992 m .46726 .5292 L .46649 .52654 L F
.84 .67 .671 r
.31932 .54008 m .31878 .54297 L .3232 .54372 L F
.848 .6 .563 r
.31878 .54297 m .32311 .54575 L .3232 .54372 L F
.072 0 .035 r
.43484 .46129 m .43513 .46022 L .43722 .4591 L F
.842 .957 .886 r
.66034 .37728 m .66436 .37552 L .66364 .37465 L F
.821 .995 .856 r
.66436 .37552 m .66666 .37184 L .66364 .37465 L F
.66436 .37552 m .66749 .37252 L .66666 .37184 L F
.913 .539 .3 r
.33113 .61435 m .33215 .61362 L .32912 .61161 L F
.33113 .61435 m .33215 .61362 L .32912 .61161 L F
0 0 0 r
.33344 .61353 m .33215 .61362 L .33113 .61435 L F
.33113 .61435 m .33215 .61362 L .33344 .61353 L F
.819 .639 .658 r
.64337 .37255 m .64239 .37501 L .64047 .37439 L F
0 0 0 r
.64693 .37002 m .64559 .37153 L .64337 .37255 L F
.741 .665 .776 r
.64679 .37357 m .64337 .37255 L .64559 .37153 L F
.64679 .37357 m .64239 .37501 L .64337 .37255 L F
.767 .821 .896 r
.29883 .59616 m .30075 .59778 L .30271 .59561 L F
.813 .459 .387 r
.64951 .37198 m .64693 .37002 L .64971 .36944 L F
.64951 .37198 m .64559 .37153 L .64693 .37002 L F
.631 .718 .91 r
.28923 .67432 m .29004 .67051 L .28806 .67056 L F
.28923 .67432 m .2919 .67368 L .29004 .67051 L F
.888 .99 .778 r
.54652 .42048 m .54596 .42351 L .54382 .42398 L F
.853 .73 .727 r
.32032 .54963 m .32491 .54754 L .32311 .54575 L F
.32032 .54963 m .32312 .55067 L .32491 .54754 L F
.689 .191 .056 r
.30533 .5416 m .30569 .54296 L .30367 .54127 L F
.893 .946 .836 r
.30824 .53711 m .30533 .5416 L .30467 .53953 L F
.423 .321 .634 r
.30464 .54208 m .30299 .544 L .30367 .54127 L F
.30569 .54296 m .30434 .54348 L .30464 .54208 L F
.30434 .54348 m .30299 .544 L .30464 .54208 L F
.30569 .54296 m .30299 .544 L .30367 .54127 L F
.785 .285 0 r
.30497 .54048 m .30348 .54205 L .30467 .53953 L F
.30533 .5416 m .30471 .54175 L .30497 .54048 L F
.30471 .54175 m .30348 .54205 L .30497 .54048 L F
.30533 .5416 m .30569 .54296 L .30348 .54205 L F
.798 .974 .68 r
.51816 .47578 m .51571 .47991 L .51925 .47697 L F
.51816 .47578 m .51552 .47936 L .51571 .47991 L F
.122 .065 .514 r
.29029 .5338 m .2905 .53692 L .28997 .53676 L F
0 0 .225 r
.28982 .53936 m .28997 .53676 L .2905 .53692 L F
.28982 .53936 m .28842 .54043 L .28997 .53676 L F
.959 .699 .499 r
.3 .64097 m .29994 .64434 L .29802 .64331 L F
.26 0 0 r
.54028 .41574 m .54404 .41558 L .5426 .41625 L F
.161 .387 .834 r
.54074 .41345 m .54028 .41574 L .5426 .41625 L F
.54074 .41345 m .5426 .41625 L .54159 .41703 L F
.656 .705 .883 r
.5426 .41625 m .54425 .41265 L .54185 .4166 L F
.5426 .41625 m .54185 .4166 L .54159 .41703 L F
.26 0 0 r
.54404 .41558 m .54429 .41557 L .5426 .41625 L F
0 0 0 r
.54429 .41557 m .54551 .41559 L .5426 .41625 L F
.54429 .41557 m .54673 .41526 L .54551 .41559 L F
.46558 .42577 m .46229 .42918 L .46456 .4279 L F
.46774 .425 m .46886 .42309 L .46558 .42577 L F
.46774 .425 m .46558 .42577 L .46456 .4279 L F
.698 .812 .936 r
.31205 .63422 m .30783 .63391 L .31017 .63335 L F
.032 0 0 r
.31064 .63646 m .31205 .63422 L .3138 .63308 L F
.313 .075 .383 r
.32302 .6406 m .32088 .64139 L .32033 .644 L F
.32033 .644 m .32088 .64139 L .32302 .6406 L F
.608 .793 .97 r
.64086 .34872 m .64536 .34961 L .64441 .34948 L F
.625 .565 .767 r
.54515 .37524 m .54923 .3784 L .54959 .37505 L F
.512 .295 .522 r
.54923 .3784 m .55138 .37486 L .54959 .37505 L F
.762 .535 .59 r
.39 .57284 m .38564 .57069 L .38832 .57152 L F
.39 .57284 m .38545 .5733 L .38564 .57069 L F
.2 .672 .938 r
.38832 .57152 m .39241 .57254 L .39 .57284 L F
.36 .191 .512 r
.26215 .56667 m .26429 .56337 L .26196 .564 L F
.352 .71 .985 r
.62935 .38093 m .63146 .38305 L .62739 .382 L F
.821 .914 .902 r
.63247 .3806 m .63146 .38305 L .62935 .38093 L F
.906 .827 .758 r
.31693 .57226 m .3192 .57381 L .31804 .56999 L F
.895 .757 .701 r
.31494 .57606 m .3192 .57381 L .31693 .57226 L F
.31494 .57606 m .3173 .57736 L .3192 .57381 L F
.84 .8 .813 r
.31804 .56999 m .3192 .57381 L .3219 .57013 L F
.534 .796 .993 r
.31797 .68396 m .31988 .68543 L .3222 .68465 L F
.869 .837 .813 r
.47229 .50607 m .47143 .50274 L .47326 .50408 L F
.47229 .50607 m .46886 .50598 L .47143 .50274 L F
.973 .927 .666 r
.46887 .50924 m .46886 .50598 L .47229 .50607 L F
.033 .118 .622 r
.52015 .38556 m .52052 .3884 L .51973 .38736 L F
.693 .705 .857 r
.64441 .3766 m .64047 .37439 L .64239 .37501 L F
.741 .665 .776 r
.64679 .37357 m .64441 .3766 L .64239 .37501 L F
.394 .824 .96 r
.45495 .52308 m .45772 .52249 L .45872 .52315 L F
.45495 .52308 m .45772 .52249 L .45872 .52315 L F
.896 .986 .787 r
.45872 .52315 m .46028 .51901 L .46187 .52021 L F
.45872 .52315 m .45772 .52249 L .46028 .51901 L F
.86 .534 .015 r
.49908 .45358 m .49943 .45567 L .49792 .45157 L F
.49792 .45157 m .49943 .45567 L .49908 .45358 L F
.49908 .45358 m .49943 .45567 L .49792 .45157 L F
.802 .96 .635 r
.58145 .38197 m .57962 .38425 L .57934 .38587 L F
.108 .626 .886 r
.37397 .5566 m .37577 .55733 L .3786 .55749 L F
.698 .706 .854 r
.37627 .56097 m .3786 .55749 L .37577 .55733 L F
.39 .186 .478 r
.53935 .34815 m .53967 .35176 L .53719 .35252 L F
0 0 0 r
.53935 .34815 m .54096 .34687 L .54194 .34541 L F
.441 .813 .557 r
.53935 .34815 m .53767 .34947 L .54096 .34687 L F
.466 0 0 r
.28614 .53387 m .28699 .53458 L .29029 .5338 L F
0 0 0 r
.29008 .53471 m .29029 .5338 L .28699 .53458 L F
0 0 .227 r
.29094 .53473 m .29089 .53498 L .29093 .53439 L F
.29089 .53498 m .2905 .53692 L .29085 .53487 L F
.29089 .53498 m .29085 .53487 L .29093 .53439 L F
.738 .746 .23 r
.29089 .53498 m .28982 .53936 L .2905 .53692 L F
0 0 .227 r
.29089 .53435 m .2905 .53692 L .29029 .5338 L F
.586 .051 0 r
.29008 .53471 m .29079 .53525 L .29094 .53467 L F
.738 .746 .23 r
.29094 .53471 m .29082 .53516 L .29089 .53498 L F
.29087 .53498 m .29082 .53516 L .29094 .53471 L F
.448 .441 .759 r
.29087 .53498 m .29093 .53522 L .29082 .53516 L F
.29112 .53499 m .2912 .53534 L .29087 .53498 L F
.2912 .53534 m .29211 .53936 L .29093 .53522 L F
.2912 .53534 m .29093 .53522 L .29087 .53498 L F
.738 .746 .23 r
.29082 .53516 m .28982 .53936 L .29089 .53498 L F
.448 .441 .759 r
.29082 .53516 m .29211 .53936 L .28982 .53936 L F
.29093 .53522 m .29211 .53936 L .29082 .53516 L F
0 0 .227 r
.29091 .53451 m .2905 .53692 L .29089 .53435 L F
.586 .051 0 r
.29043 .53498 m .29155 .53684 L .29106 .53546 L F
.29008 .53471 m .29018 .53486 L .29043 .53498 L F
.29018 .53486 m .29155 .53684 L .29043 .53498 L F
.29079 .53525 m .29106 .53546 L .29094 .53471 L F
.29079 .53525 m .29094 .53471 L .29094 .53467 L F
.738 .746 .23 r
.291 .53444 m .29087 .53498 L .29094 .53471 L F
.586 .051 0 r
.29018 .53486 m .28902 .53658 L .29027 .53671 L F
.29068 .53558 m .29027 .53671 L .29155 .53684 L F
.29018 .53486 m .29027 .53671 L .29068 .53558 L F
.29008 .53471 m .29003 .53479 L .29018 .53486 L F
.29003 .53479 m .28902 .53658 L .29018 .53486 L F
.2914 .53465 m .29123 .53499 L .29184 .5349 L F
.2914 .53465 m .29184 .5349 L .29168 .53463 L F
.004 .12 .634 r
.29377 .53602 m .29162 .53452 L .29456 .53489 L F
.29308 .53701 m .29168 .53463 L .29377 .53602 L F
.29168 .53463 m .29162 .53452 L .29377 .53602 L F
.708 .721 .86 r
.29324 .53182 m .29385 .53324 L .29174 .53413 L F
.472 .407 .703 r
.29168 .53421 m .29177 .53407 L .29093 .53394 L F
.708 .721 .86 r
.29385 .53324 m .29456 .53489 L .29162 .53452 L F
.29385 .53324 m .29162 .53452 L .29149 .53451 L F
.472 .407 .703 r
.29168 .53463 m .29445 .5345 L .29168 .53421 L F
.29149 .53451 m .29168 .53421 L .29093 .53413 L F
.29168 .53463 m .29168 .53421 L .29149 .53451 L F
.708 .721 .86 r
.29174 .53413 m .29149 .53451 L .291 .53444 L F
.29385 .53324 m .29149 .53451 L .29174 .53413 L F
0 0 .322 r
.29324 .53182 m .29445 .5345 L .29456 .53489 L F
.472 .407 .703 r
.29093 .53394 m .29445 .5345 L .29324 .53182 L F
.708 .721 .86 r
.29324 .53182 m .29174 .53413 L .291 .53444 L F
.472 .407 .703 r
.29093 .53413 m .29168 .53421 L .29093 .53394 L F
.29168 .53421 m .29445 .5345 L .29177 .53407 L F
.29094 .53467 m .29168 .53463 L .29093 .53413 L F
.586 .051 0 r
.29123 .53499 m .29308 .53701 L .29416 .53503 L F
.29123 .53499 m .29416 .53503 L .29445 .5345 L F
.004 .12 .634 r
.29308 .53701 m .291 .53444 L .29162 .53452 L F
.586 .051 0 r
.29168 .53463 m .29184 .5349 L .29445 .5345 L F
.29094 .53467 m .29108 .53483 L .2914 .53465 L F
.29108 .53483 m .29123 .53499 L .2914 .53465 L F
.004 .12 .634 r
.29308 .53701 m .29211 .53936 L .29112 .53499 L F
.586 .051 0 r
.29096 .53482 m .29308 .53701 L .29094 .53467 L F
.004 .12 .634 r
.29308 .53701 m .29112 .53499 L .291 .53444 L F
.586 .051 0 r
.29106 .53546 m .29308 .53701 L .29096 .53482 L F
.29106 .53546 m .29155 .53684 L .29308 .53701 L F
.448 .441 .759 r
.291 .53444 m .29112 .53499 L .29087 .53498 L F
0 0 .227 r
.29093 .53439 m .29091 .53451 L .29089 .53435 L F
.291 .53444 m .29094 .53473 L .29093 .53439 L F
.472 .407 .703 r
.29008 .53471 m .29094 .53467 L .29093 .53439 L F
0 0 0 r
.29008 .53471 m .291 .53444 L .29093 .53439 L F
.29008 .53471 m .29093 .53439 L .29029 .5338 L F
.472 .407 .703 r
.29008 .53471 m .29093 .53439 L .29093 .53394 L F
0 0 0 r
.4721 .42064 m .46886 .42309 L .47068 .42174 L F
.47068 .42174 m .46886 .42309 L .46774 .425 L F
.578 .404 .61 r
.50053 .4425 m .50343 .43929 L .50046 .43983 L F
.907 .768 .696 r
.35331 .5606 m .35102 .55982 L .35339 .55677 L F
.897 .629 .525 r
.35331 .5606 m .35065 .56266 L .35102 .55982 L F
.35331 .5606 m .35324 .56411 L .35065 .56266 L F
.782 .507 .519 r
.31555 .53344 m .31737 .53638 L .3175 .53382 L F
.571 .327 .507 r
.27824 .56039 m .27781 .56321 L .27534 .56103 L F
.821 .698 .728 r
.52246 .36467 m .52253 .36887 L .52391 .36646 L F
.813 .978 .894 r
.50578 .48565 m .50357 .48942 L .50657 .48617 L F
.50578 .48565 m .50239 .48853 L .50357 .48942 L F
.405 .32 .647 r
.27068 .57906 m .26868 .5782 L .27145 .57729 L F
.27068 .57906 m .26886 .58091 L .26868 .5782 L F
0 .02 .593 r
.51037 .42249 m .51065 .42501 L .50901 .42124 L F
.864 .735 .218 r
.51036 .4227 m .51065 .42501 L .51037 .42249 L F
.817 .81 .844 r
.51081 .42634 m .50737 .42611 L .51065 .42501 L F
.717 .661 .793 r
.50606 .42489 m .51065 .42501 L .50737 .42611 L F
.724 .621 .743 r
.50901 .42124 m .51065 .42501 L .50606 .42489 L F
.864 .735 .218 r
.51026 .42804 m .51065 .42501 L .51036 .4227 L F
.817 .81 .844 r
.5115 .42639 m .51081 .42634 L .51065 .42501 L F
.997 .857 .538 r
.51083 .42869 m .5115 .42639 L .51065 .42501 L F
.348 0 0 r
.42443 .57529 m .41958 .57346 L .42134 .57425 L F
.841 .729 .739 r
.32048 .56634 m .3219 .57013 L .32289 .56791 L F
0 0 0 r
.4584 .44298 m .462 .43955 L .4607 .44176 L F
.102 0 0 r
.4632 .44065 m .462 .43955 L .46449 .43884 L F
.4632 .44065 m .4607 .44176 L .462 .43955 L F
.364 0 .101 r
.39402 .47987 m .39215 .48236 L .38971 .48269 L F
.691 .308 .317 r
.39645 .48228 m .39215 .48236 L .39402 .47987 L F
.615 .328 .459 r
.39669 .47993 m .39645 .48228 L .39402 .47987 L F
.898 .872 .803 r
.44494 .55119 m .44551 .54637 L .44531 .54824 L F
.903 .899 .812 r
.44494 .55119 m .44531 .54824 L .44311 .55008 L F
.895 .867 .804 r
.42953 .56966 m .43029 .57334 L .43097 .57048 L F
.939 .941 .765 r
.43188 .56598 m .42953 .56966 L .43097 .57048 L F
.865 .933 .866 r
.47602 .51761 m .47467 .51654 L .47172 .5198 L F
.903 .927 .823 r
.47709 .51281 m .47602 .51761 L .47686 .51594 L F
.47709 .51281 m .47467 .51654 L .47602 .51761 L F
.041 .582 .847 r
.5402 .40465 m .54302 .40533 L .54075 .40519 L F
.808 .799 .843 r
.64951 .37198 m .64679 .37357 L .64559 .37153 L F
.955 .933 .732 r
.52024 .4719 m .51925 .47697 L .52191 .47368 L F
.52024 .4719 m .51816 .47578 L .51925 .47697 L F
.695 .965 .938 r
.50813 .41702 m .51248 .41601 L .51053 .41666 L F
0 0 0 r
.51248 .41601 m .51565 .41298 L .51427 .41442 L F
.758 .726 .822 r
.50709 .41417 m .5128 .41535 L .50973 .41086 L F
.216 0 0 r
.50813 .41702 m .5128 .41535 L .50709 .41417 L F
0 0 .129 r
.51121 .4121 m .51165 .41121 L .51069 .41104 L F
.5128 .41535 m .51069 .41104 L .50994 .41117 L F
.76 .529 .582 r
.50973 .41086 m .51552 .41192 L .51221 .40836 L F
.858 .991 .837 r
.50594 .41347 m .50709 .41417 L .50973 .41086 L F
.076 0 0 r
.51172 .41086 m .51122 .41165 L .50818 .41201 L F
.51185 .41082 m .51183 .41084 L .51172 .41086 L F
.51183 .41084 m .51122 .41165 L .51172 .41086 L F
.813 .327 0 r
.51221 .40836 m .51552 .41192 L .51413 .40961 L F
.76 .529 .582 r
.50973 .41086 m .51221 .40836 L .51185 .40744 L F
.74 .614 .718 r
.51185 .41082 m .50973 .41086 L .51185 .40744 L F
0 0 .129 r
.50994 .41117 m .51069 .41104 L .50973 .41086 L F
.076 0 0 r
.51185 .41082 m .50818 .41201 L .50973 .41086 L F
0 0 .342 r
.51316 .40783 m .51185 .41082 L .51185 .41044 L F
.51316 .40783 m .51185 .41044 L .51185 .40744 L F
.639 .836 .433 r
.51557 .40401 m .51316 .40783 L .51422 .40566 L F
.714 .969 .724 r
.5145 .40554 m .51411 .40594 L .51316 .40783 L F
0 0 .342 r
.51316 .40783 m .51185 .40744 L .51422 .40566 L F
.714 .969 .724 r
.51411 .40594 m .51154 .40857 L .51316 .40783 L F
.68 .816 .371 r
.51316 .40783 m .51122 .41165 L .51183 .41084 L F
.5119 .41071 m .51183 .41084 L .51185 .41082 L F
.51316 .40783 m .51183 .41084 L .5119 .41071 L F
0 0 .129 r
.5128 .41535 m .51552 .41192 L .51165 .41121 L F
.5128 .41535 m .51165 .41121 L .51121 .4121 L F
.216 0 0 r
.50813 .41702 m .51053 .41666 L .5128 .41535 L F
.394 .816 .636 r
.5128 .41535 m .51053 .41666 L .51427 .41442 L F
.535 .914 .767 r
.51053 .41666 m .51248 .41601 L .51427 .41442 L F
.511 .214 .399 r
.6047 .35619 m .60443 .35846 L .60135 .35883 L F
.253 .005 .331 r
.6061 .35685 m .6047 .35619 L .60749 .35577 L F
.6067 .35714 m .60443 .35846 L .6047 .35619 L F
0 .153 .675 r
.60297 .35983 m .60135 .35883 L .60313 .35862 L F
.60297 .35983 m .60313 .35862 L .60443 .35846 L F
.918 .631 .144 r
.60234 .35895 m .60271 .36184 L .60297 .35983 L F
.60271 .36184 m .60275 .36213 L .60297 .35983 L F
.75 .994 .822 r
.60559 .35601 m .60234 .35895 L .60386 .35859 L F
.60466 .35797 m .60386 .35859 L .60443 .35846 L F
.60559 .35601 m .60386 .35859 L .60466 .35797 L F
.253 .005 .331 r
.60749 .35577 m .6047 .35619 L .60771 .3554 L F
.6067 .35714 m .6061 .35685 L .60749 .35577 L F
.007 .148 .663 r
.58525 .39621 m .58776 .39689 L .58639 .39415 L F
.58525 .39621 m .58749 .39953 L .58776 .39689 L F
.427 .428 .757 r
.3285 .63186 m .32849 .63501 L .33151 .63452 L F
.129 0 0 r
.33151 .63452 m .32849 .63501 L .32787 .63596 L F
0 0 0 r
.25527 .58943 m .25735 .58861 L .2599 .58691 L F
.392 .486 .836 r
.2599 .58691 m .26202 .58649 L .26018 .58232 L F
.129 .263 .734 r
.26269 .59056 m .2599 .58691 L .26202 .58649 L F
.726 .514 .604 r
.25735 .58861 m .26202 .58649 L .2599 .58691 L F
.89 .99 .756 r
.31283 .68485 m .31358 .68181 L .31236 .68115 L F
.425 .151 .392 r
.3133 .68189 m .31236 .68115 L .31406 .68208 L F
.57 .6 .844 r
.31204 .6771 m .3133 .68189 L .31365 .68155 L F
.31435 .67871 m .31365 .68155 L .31562 .6796 L F
.31204 .6771 m .31365 .68155 L .31435 .67871 L F
.89 .99 .756 r
.31289 .68528 m .31406 .68208 L .31358 .68181 L F
.31289 .68528 m .31358 .68181 L .31283 .68485 L F
.359 .792 .613 r
.40437 .46872 m .40212 .47004 L .40028 .47111 L F
.973 .927 .666 r
.46887 .50924 m .46767 .50871 L .46886 .50598 L F
0 0 0 r
.47436 .41912 m .4721 .42064 L .47068 .42174 L F
.326 .162 .5 r
.3976 .58613 m .39779 .58855 L .39974 .58633 L F
.39779 .58855 m .39783 .58916 L .39821 .5886 L F
.39779 .58855 m .39821 .5886 L .39974 .58633 L F
.423 0 0 r
.39939 .59 m .39677 .58845 L .39824 .58997 L F
.39677 .58845 m .39594 .58796 L .39646 .58841 L F
.39677 .58845 m .39646 .58841 L .39824 .58997 L F
0 0 0 r
.47736 .43017 m .47823 .43033 L .47581 .43143 L F
.47736 .43017 m .47996 .42935 L .47823 .43033 L F
.817 .625 .643 r
.3403 .51265 m .3422 .51662 L .34253 .5138 L F
.821 .925 .903 r
.47834 .49701 m .4735 .49904 L .47631 .49573 L F
.77 .69 .775 r
.48219 .48628 m .48355 .49022 L .47932 .48966 L F
.596 .935 .949 r
.65322 .37984 m .65543 .38016 L .65809 .37886 L F
.661 .509 .667 r
.31633 .63784 m .31923 .63672 L .31918 .63468 L F
.037 0 0 r
.31666 .63878 m .31633 .63784 L .31437 .63966 L F
.31666 .63878 m .31923 .63672 L .31633 .63784 L F
.69 .667 .823 r
.31149 .64551 m .30665 .64446 L .30981 .64353 L F
.793 .81 .865 r
.31282 .64411 m .31149 .64551 L .30981 .64353 L F
.35 0 0 r
.59902 .34181 m .59725 .34245 L .60131 .34186 L F
.427 .687 .972 r
.57858 .36992 m .58325 .37276 L .58298 .37112 L F
0 0 .551 r
.58413 .37508 m .58298 .37112 L .58325 .37276 L F
.727 .769 .886 r
.31248 .55698 m .30975 .55834 L .30809 .55655 L F
.625 .861 .987 r
.29803 .56574 m .29768 .56796 L .29977 .5671 L F
.888 .507 .309 r
.65792 .34198 m .6597 .34524 L .66165 .3458 L F
.87 .462 .252 r
.6597 .34524 m .6603 .34729 L .66165 .3458 L F
.744 .279 .145 r
.6603 .34729 m .66467 .34871 L .66165 .3458 L F
.745 .277 .137 r
.66165 .3458 m .66467 .34871 L .66604 .34832 L F
.563 .182 .276 r
.40576 .47819 m .40208 .47859 L .40353 .47669 L F
.013 0 0 r
.49246 .42017 m .49375 .42041 L .49127 .42112 L F
.49246 .42017 m .49534 .4195 L .49375 .42041 L F
.84 .761 .775 r
.4442 .53422 m .44286 .53766 L .43989 .5362 L F
.899 .706 .632 r
.44286 .53766 m .43954 .53885 L .43989 .5362 L F
.44286 .53766 m .44178 .54015 L .43954 .53885 L F
0 0 .239 r
.31918 .63468 m .32 .6357 L .31976 .63284 L F
.31918 .63468 m .31923 .63672 L .32 .6357 L F
.481 0 0 r
.38395 .56952 m .38832 .57152 L .38564 .57069 L F
.988 .76 .501 r
.38564 .57069 m .38545 .5733 L .38395 .56952 L F
.725 .941 .625 r
.40402 .57288 m .40396 .57228 L .40931 .57296 L F
.631 .117 .005 r
.39853 .57155 m .40181 .57405 L .40402 .57288 L F
.871 .84 .812 r
.39996 .57286 m .40076 .57415 L .40139 .57378 L F
.475 0 0 r
.39996 .57286 m .40185 .57408 L .39853 .57155 L F
.631 .117 .005 r
.40181 .57405 m .40185 .57408 L .40249 .57403 L F
.40185 .57408 m .40248 .57404 L .40249 .57403 L F
.40181 .57405 m .40249 .57403 L .40402 .57288 L F
.871 .84 .812 r
.40076 .57415 m .40264 .57403 L .40396 .57228 L F
.475 0 0 r
.39996 .57286 m .40214 .5743 L .40185 .57408 L F
.871 .84 .812 r
.39996 .57286 m .40139 .57378 L .40396 .57228 L F
.40076 .57415 m .40157 .57545 L .40264 .57403 L F
.631 .117 .005 r
.40185 .57408 m .40214 .5743 L .40248 .57404 L F
.725 .941 .625 r
.40402 .57288 m .40214 .5743 L .40396 .57228 L F
.767 .457 .461 r
.40264 .57403 m .40931 .57296 L .40396 .57228 L F
.40157 .57545 m .40624 .57395 L .40264 .57403 L F
.40624 .57395 m .40931 .57296 L .40264 .57403 L F
.40157 .57545 m .40517 .57631 L .40931 .57296 L F
.998 .783 .48 r
.40931 .57296 m .40632 .57084 L .40805 .56949 L F
.903 .984 .773 r
.40931 .57296 m .40486 .57496 L .40632 .57084 L F
.40931 .57296 m .4057 .57589 L .40486 .57496 L F
.943 .836 .709 r
.40632 .57084 m .40486 .57496 L .4031 .57359 L F
.454 .244 .504 r
.40486 .57496 m .40677 .5755 L .40409 .5741 L F
.40486 .57496 m .40409 .5741 L .4031 .57359 L F
.903 .984 .773 r
.4057 .57589 m .40517 .57631 L .40486 .57496 L F
.617 .612 .823 r
.25123 .59553 m .25522 .59792 L .25395 .59486 L F
.665 .645 .82 r
.25395 .59486 m .25522 .59792 L .25809 .59709 L F
.572 .342 .528 r
.25522 .59792 m .25791 .60021 L .25809 .59709 L F
.25809 .59709 m .25791 .60021 L .25522 .59792 L F
.631 .829 .423 r
.51311 .38301 m .51422 .38113 L .51509 .37996 L F
.684 .788 .317 r
.51311 .38301 m .51311 .38271 L .51422 .38113 L F
.51311 .38301 m .51214 .38518 L .51311 .38271 L F
.858 .735 .726 r
.32048 .56634 m .31804 .56999 L .3219 .57013 L F
.905 .648 .54 r
.38027 .48331 m .38039 .48625 L .37743 .48509 L F
.38039 .48625 m .38041 .48691 L .37993 .48661 L F
.38039 .48625 m .37993 .48661 L .37743 .48509 L F
.63 .428 .59 r
.38402 .48513 m .38041 .48691 L .38027 .48331 L F
.264 0 0 r
.38402 .48513 m .37993 .48661 L .38041 .48691 L F
.905 .648 .54 r
.37743 .48509 m .38041 .48691 L .37743 .48509 L F
.756 .771 .865 r
.37993 .48661 m .37865 .48708 L .37743 .48509 L F
.264 0 0 r
.37993 .48661 m .37865 .48708 L .38041 .48691 L F
.756 .771 .865 r
.38041 .48691 m .37865 .48708 L .37993 .48661 L F
.264 0 0 r
.38398 .48514 m .3828 .48618 L .3796 .48687 L F
.38402 .48513 m .38402 .48513 L .38398 .48514 L F
.38402 .48513 m .3828 .48618 L .38398 .48514 L F
.37993 .48661 m .3796 .48687 L .37865 .48708 L F
.38402 .48513 m .3796 .48687 L .37993 .48661 L F
.759 .991 .887 r
.66866 .37003 m .66749 .37252 L .66885 .37124 L F
.752 .985 .904 r
.66666 .37184 m .66749 .37252 L .66866 .37003 L F
.904 .981 .787 r
.45056 .54196 m .45045 .54428 L .45298 .54103 L F
.753 .909 .529 r
.45535 .53719 m .45376 .53894 L .45298 .54103 L F
.761 .995 .82 r
.45376 .53894 m .45056 .54196 L .45298 .54103 L F
.098 0 0 r
.45607 .44398 m .4584 .44298 L .45517 .44545 L F
.895 .867 .804 r
.42953 .56966 m .4272 .57331 L .43029 .57334 L F
.873 .896 .846 r
.4272 .57331 m .42728 .57636 L .43029 .57334 L F
.889 .951 .84 r
.38183 .56115 m .3808 .55888 L .38208 .56065 L F
0 0 0 r
.45683 .53586 m .45535 .53719 L .45822 .53429 L F
.45629 .53644 m .45535 .53719 L .45683 .53586 L F
.45629 .53644 m .45376 .53894 L .45535 .53719 L F
.838 .557 .512 r
.37811 .55271 m .38106 .5505 L .37785 .5521 L F
.37811 .55271 m .38101 .55326 L .38106 .5505 L F
.635 .518 .703 r
.38101 .55326 m .38347 .55005 L .38106 .5505 L F
.629 .615 .818 r
.53092 .35803 m .52818 .35924 L .52747 .356 L F
0 0 .053 r
.53092 .35803 m .52703 .36253 L .52818 .35924 L F
.18 0 .316 r
.37319 .56417 m .37291 .5666 L .37553 .56291 L F
.873 .896 .847 r
.32456 .60851 m .32015 .61075 L .32348 .60738 L F
.439 .867 .754 r
.32517 .60788 m .32456 .60851 L .32348 .60738 L F
.658 .629 .809 r
.253 .60659 m .25493 .60335 L .25355 .60432 L F
.521 .889 .972 r
.33914 .62509 m .3405 .62454 L .33814 .62541 L F
.344 .061 .331 r
.26986 .55383 m .27222 .55311 L .27299 .55071 L F
.095 0 .214 r
.27299 .55071 m .27222 .55311 L .27477 .54964 L F
.741 .912 .541 r
.60223 .36781 m .60132 .36962 L .60344 .36631 L F
0 0 0 r
.6016 .36949 m .60132 .36962 L .60223 .36781 L F
.6016 .36949 m .60016 .37162 L .60132 .36962 L F
.951 .946 .73 r
.55554 .40546 m .55535 .40751 L .55426 .40734 L F
.754 .988 .895 r
.55426 .40734 m .55535 .40751 L .55125 .40847 L F
.878 .628 .556 r
.34837 .52216 m .35063 .52032 L .34625 .52003 L F
.34837 .52216 m .35022 .52325 L .35063 .52032 L F
.721 .474 .552 r
.35063 .52032 m .35022 .52325 L .35348 .52328 L F
.392 .211 .513 r
.2575 .57731 m .25974 .57665 L .25975 .57386 L F
.441 .221 .483 r
.2575 .57731 m .25927 .57983 L .25974 .57665 L F
.2575 .57731 m .25721 .58041 L .25927 .57983 L F
0 .509 .791 r
.41188 .56623 m .41596 .56731 L .41335 .56856 L F
.838 .839 .846 r
.31008 .61656 m .31215 .61809 L .30821 .62141 L F
.699 .831 .945 r
.31428 .61606 m .31215 .61809 L .31008 .61656 L F
.364 0 0 r
.31701 .62021 m .31215 .61809 L .31428 .61606 L F
.848 .993 .842 r
.54293 .4426 m .54651 .44033 L .54512 .43887 L F
.281 0 .073 r
.5125 .39941 m .51139 .40166 L .5088 .40224 L F
.166 0 .022 r
.51425 .40051 m .51139 .40166 L .5125 .39941 L F
.899 .913 .514 r
.35557 .64713 m .35665 .64466 L .35656 .64275 L F
.471 .352 .636 r
.56159 .36634 m .56162 .36903 L .56381 .36599 L F
.782 .397 0 r
.31021 .65275 m .30936 .65091 L .31016 .65042 L F
.639 .434 .589 r
.56601 .389 m .56881 .38872 L .569 .38588 L F
.811 .572 .577 r
.28757 .6542 m .28802 .65121 L .28334 .65057 L F
.28757 .6542 m .28334 .65057 L .28492 .65266 L F
.678 .193 .092 r
.28334 .65057 m .28802 .65121 L .28724 .65204 L F
.28334 .65057 m .28673 .65184 L .28584 .6518 L F
.28673 .65184 m .28724 .65204 L .28644 .6519 L F
.28673 .65184 m .28644 .6519 L .28584 .6518 L F
0 .081 .63 r
.28858 .65083 m .28644 .6519 L .28874 .65003 L F
.28644 .6519 m .28492 .65266 L .28585 .65202 L F
.291 .538 .915 r
.2836 .6494 m .28628 .65175 L .28369 .64899 L F
.408 .205 .49 r
.2899 .65346 m .28802 .65121 L .28757 .6542 L F
0 .081 .63 r
.28817 .6522 m .28757 .6542 L .28644 .6519 L F
.678 .193 .092 r
.28584 .6518 m .28724 .65204 L .28696 .65234 L F
.2869 .65232 m .28696 .65234 L .28695 .65235 L F
.28584 .6518 m .28696 .65234 L .2869 .65232 L F
.291 .538 .915 r
.28628 .65175 m .28631 .6517 L .28369 .64899 L F
.658 .682 .862 r
.28874 .65003 m .28631 .6517 L .28369 .64899 L F
.291 .538 .915 r
.28631 .6517 m .28632 .65169 L .28369 .64899 L F
.28334 .65057 m .28584 .6518 L .2836 .6494 L F
0 .081 .63 r
.28644 .6519 m .28616 .65196 L .28874 .65003 L F
.28616 .65196 m .28631 .6517 L .28874 .65003 L F
.291 .538 .915 r
.28584 .6518 m .28695 .65235 L .2836 .6494 L F
.658 .682 .862 r
.28631 .6517 m .28585 .65202 L .28369 .64899 L F
.28585 .65202 m .28492 .65266 L .28458 .65166 L F
.28585 .65202 m .28458 .65166 L .28369 .64899 L F
.291 .538 .915 r
.28628 .65175 m .28695 .65235 L .28632 .65169 L F
0 .081 .63 r
.28616 .65196 m .28585 .65202 L .28631 .6517 L F
.28858 .65083 m .28817 .6522 L .28724 .65204 L F
0 0 0 r
.28724 .65204 m .28802 .65121 L .28858 .65083 L F
0 .081 .63 r
.28858 .65083 m .28724 .65204 L .28644 .6519 L F
0 0 0 r
.28695 .65235 m .28724 .65204 L .28858 .65083 L F
0 .081 .63 r
.2861 .65207 m .28757 .6542 L .28492 .65266 L F
.28644 .6519 m .287 .65303 L .2861 .65207 L F
.287 .65303 m .28757 .6542 L .2861 .65207 L F
.28858 .65083 m .28802 .65121 L .2899 .65346 L F
.152 0 .013 r
.28794 .63477 m .28437 .63737 L .28615 .63641 L F
0 0 0 r
.29008 .63099 m .28794 .63477 L .28917 .63318 L F
.668 .929 .637 r
.28917 .63318 m .28794 .63477 L .28615 .63641 L F
.956 .81 .658 r
.31027 .55028 m .30764 .55124 L .30723 .54923 L F
.31027 .55028 m .30958 .55428 L .30764 .55124 L F
.763 .951 .937 r
.63474 .38997 m .63353 .39277 L .63567 .39114 L F
.805 .944 .916 r
.62846 .39347 m .62945 .39478 L .63292 .39205 L F
.63062 .39285 m .63292 .39205 L .63359 .39201 L F
.62846 .39347 m .63292 .39205 L .63062 .39285 L F
.817 1 .823 r
.634 .39167 m .63292 .39205 L .63353 .39277 L F
.63474 .38997 m .63292 .39205 L .634 .39167 L F
.537 .397 .638 r
.30101 .63414 m .30152 .637 L .29851 .63757 L F
0 0 0 r
.29919 .63726 m .29851 .63757 L .30101 .63414 L F
.29702 .6398 m .29851 .63757 L .29919 .63726 L F
.51509 .37996 m .51591 .37934 L .5158 .37976 L F
.51509 .37996 m .51422 .38113 L .51591 .37934 L F
.615 .847 .472 r
.51591 .37934 m .5146 .3809 L .51601 .37901 L F
.51591 .37934 m .51601 .37901 L .51731 .37727 L F
0 0 0 r
.5158 .37976 m .51591 .37934 L .51776 .37919 L F
.838 .631 .623 r
.3381 .51556 m .3403 .51265 L .33804 .51359 L F
.502 .111 .231 r
.62739 .382 m .62651 .38506 L .62381 .38458 L F
0 0 .015 r
.62739 .382 m .62651 .38506 L .62935 .38093 L F
.801 .611 .644 r
.31335 .53026 m .31288 .53338 L .31555 .53344 L F
.785 .511 .522 r
.31288 .53338 m .31295 .536 L .31555 .53344 L F
.782 .507 .519 r
.31555 .53344 m .31295 .536 L .31737 .53638 L F
.153 0 0 r
.2697 .58224 m .26886 .58091 L .27068 .57906 L F
.2697 .58224 m .2674 .58305 L .26886 .58091 L F
.765 .467 .481 r
.35348 .52328 m .35714 .52604 L .3576 .52496 L F
0 0 0 r
.57633 .37223 m .57539 .37399 L .57495 .3742 L F
.342 .584 .933 r
.57633 .37223 m .57907 .37168 L .57831 .37116 L F
0 0 0 r
.57831 .37116 m .57539 .37399 L .57633 .37223 L F
.639 .485 .658 r
.30516 .64485 m .30119 .64689 L .29994 .64434 L F
.30516 .64485 m .3042 .6481 L .30119 .64689 L F
.087 0 0 r
.33385 .67411 m .33729 .67186 L .33601 .67399 L F
.047 0 0 r
.33385 .67411 m .3357 .67486 L .33308 .67672 L F
.33385 .67411 m .33601 .67399 L .3357 .67486 L F
.775 .908 .932 r
.43147 .55471 m .4279 .55687 L .42617 .55591 L F
.754 .686 .786 r
.36976 .53322 m .37407 .53357 L .37275 .53007 L F
.848 .6 .565 r
.36992 .53545 m .37407 .53357 L .36976 .53322 L F
.36992 .53545 m .37405 .53647 L .37407 .53357 L F
.74 .452 .493 r
.51522 .39327 m .5177 .39752 L .51376 .3973 L F
.51522 .39327 m .52098 .3972 L .5177 .39752 L F
.921 .817 .727 r
.51887 .37089 m .52253 .36887 L .51883 .36936 L F
.51887 .37089 m .5208 .37271 L .52253 .36887 L F
.656 .339 .423 r
.2891 .55239 m .29141 .5498 L .28915 .55009 L F
0 0 0 r
.29269 .55553 m .29231 .5531 L .29415 .55363 L F
.656 .339 .423 r
.2891 .55239 m .29415 .55363 L .29141 .5498 L F
.23 .319 .749 r
.5294 .42063 m .52776 .42348 L .53065 .42471 L F
.78 .677 .75 r
.32139 .64786 m .32464 .64447 L .32033 .644 L F
.74 .906 .951 r
.29998 .54581 m .30019 .5476 L .29793 .54651 L F
.627 .323 .435 r
.29998 .54581 m .29793 .54651 L .30019 .5476 L F
.5 .299 .539 r
.534 .3854 m .53677 .38533 L .53611 .38264 L F
.699 .514 .634 r
.53677 .38533 m .53974 .38208 L .53611 .38264 L F
0 0 .018 r
.28334 .63952 m .28437 .63737 L .28122 .64062 L F
.3 .252 .635 r
.28122 .64062 m .28377 .64354 L .28334 .63952 L F
.739 .493 .558 r
.30474 .52902 m .30882 .5265 L .30455 .52725 L F
.868 .591 .517 r
.34628 .53977 m .34301 .53616 L .34645 .53702 L F
.668 .573 .739 r
.35714 .52604 m .36143 .52952 L .36188 .52715 L F
.648 .554 .735 r
.36246 .52495 m .36188 .52715 L .36415 .52322 L F
.377 0 .191 r
.36495 .52587 m .36188 .52715 L .36415 .52322 L F
.36495 .52587 m .3646 .52649 L .36188 .52715 L F
.534 .27 .461 r
.36143 .52952 m .3646 .52649 L .36188 .52715 L F
.839 .847 .384 r
.49195 .47157 m .49152 .47173 L .49267 .4696 L F
.46 .853 .653 r
.49267 .4696 m .49442 .46823 L .49614 .46725 L F
0 0 0 r
.49267 .4696 m .49152 .47173 L .49442 .46823 L F
.664 .619 .794 r
.25455 .60891 m .25662 .6073 L .253 .60659 L F
.646 .283 .34 r
.53032 .38732 m .53289 .38798 L .534 .3854 L F
.715 .357 .37 r
.534 .3854 m .53701 .38818 L .53677 .38533 L F
.534 .3854 m .53289 .38798 L .53701 .38818 L F
.371 .117 .394 r
.26986 .55383 m .26938 .55635 L .27222 .55311 L F
.909 .668 .561 r
.35339 .55677 m .34956 .55593 L .35001 .55301 L F
.912 .779 .701 r
.35339 .55677 m .34883 .55877 L .34956 .55593 L F
.35339 .55677 m .35102 .55982 L .34883 .55877 L F
.765 .733 .823 r
.61598 .35049 m .61391 .35214 L .61784 .35266 L F
.651 .704 .886 r
.61598 .35049 m .61784 .35266 L .61866 .34968 L F
.258 .482 .883 r
.39256 .5875 m .39306 .58533 L .39111 .58665 L F
.39256 .5875 m .39594 .58796 L .39306 .58533 L F
.878 .704 .661 r
.33831 .52594 m .33661 .52639 L .33691 .52362 L F
.882 .582 .476 r
.33831 .52594 m .33677 .52871 L .33661 .52639 L F
.33831 .52594 m .34056 .53013 L .33677 .52871 L F
.727 .951 .654 r
.33652 .66292 m .33592 .66443 L .33867 .66114 L F
.587 .437 .645 r
.33592 .66443 m .33861 .66518 L .33867 .66114 L F
.51 .553 .836 r
.34004 .66784 m .33592 .66443 L .33861 .66518 L F
.607 .363 .522 r
.33573 .6674 m .33861 .66518 L .33592 .66443 L F
.33573 .6674 m .33861 .66518 L .33592 .66443 L F
0 0 .107 r
.33642 .6659 m .33592 .66443 L .33652 .66292 L F
.33642 .6659 m .33573 .6673 L .33592 .66443 L F
.989 .728 .371 r
.3354 .66417 m .33642 .6659 L .33652 .66292 L F
.33514 .66447 m .33556 .66493 L .3354 .66417 L F
.33556 .66493 m .33642 .6659 L .3354 .66417 L F
.82 .976 .677 r
.33652 .66292 m .33867 .66114 L .33777 .66116 L F
.915 .878 .784 r
.33434 .66244 m .33652 .66292 L .33726 .6601 L F
.989 .728 .371 r
.33514 .66447 m .33652 .66292 L .33434 .66244 L F
.837 .793 .809 r
.33726 .6601 m .33652 .66292 L .33777 .66116 L F
.915 .878 .784 r
.33434 .66244 m .33726 .6601 L .33468 .65936 L F
.433 .714 .983 r
.33468 .65936 m .33726 .6601 L .33741 .65892 L F
.44 .238 .508 r
.33737 .66444 m .33516 .66298 L .33637 .65956 L F
.33516 .66298 m .33434 .66244 L .33489 .66166 L F
.33516 .66298 m .33489 .66166 L .33637 .65956 L F
0 .208 .725 r
.33713 .66445 m .33642 .6659 L .33514 .66447 L F
.33737 .66444 m .33642 .6659 L .33713 .66445 L F
0 0 .107 r
.33642 .6659 m .33573 .6674 L .33573 .6673 L F
.552 .873 .593 r
.32 .6357 m .31923 .63672 L .31666 .63878 L F
.734 .272 .153 r
.32622 .62002 m .32991 .62054 L .3278 .6222 L F
.38 .062 .296 r
.32991 .62054 m .33002 .62245 L .3278 .6222 L F
.32991 .62054 m .33042 .62294 L .33002 .62245 L F
.32991 .62054 m .33231 .62026 L .33042 .62294 L F
.815 .593 .601 r
.31737 .53638 m .31932 .54008 L .32015 .5373 L F
.878 .767 .736 r
.48208 .50571 m .48304 .50929 L .48413 .50712 L F
.793 .802 .859 r
.48208 .50571 m .48413 .50712 L .48692 .5046 L F
.728 .859 .434 r
.27346 .57343 m .27197 .57566 L .27145 .57729 L F
.366 .048 .287 r
.27343 .57801 m .27145 .57729 L .27197 .57566 L F
.27343 .57801 m .27068 .57906 L .27145 .57729 L F
.766 .959 .651 r
.51661 .41075 m .51565 .41298 L .5183 .40948 L F
.744 .914 .545 r
.51427 .41442 m .51565 .41298 L .51661 .41075 L F
.426 .726 .988 r
.31782 .6807 m .31976 .67891 L .31562 .6796 L F
.31782 .6807 m .32109 .68041 L .31976 .67891 L F
.146 0 0 r
.32009 .62714 m .32336 .62752 L .32308 .62757 L F
.948 .878 .732 r
.32439 .62763 m .32471 .62241 L .32524 .62609 L F
.456 .854 .664 r
.32281 .62762 m .32308 .62757 L .32524 .62609 L F
.563 .368 .575 r
.32009 .62714 m .32308 .62757 L .3204 .63007 L F
.32009 .62714 m .32308 .62757 L .3204 .63007 L F
.456 .854 .664 r
.32147 .62845 m .32308 .62757 L .32281 .62762 L F
.146 0 0 r
.32336 .62752 m .32439 .62763 L .32308 .62757 L F
.627 .961 .892 r
.32308 .62757 m .32439 .62763 L .32524 .62609 L F
.829 .749 .775 r
.36577 .54922 m .36981 .55034 L .37088 .54727 L F
.951 .799 .35 r
.36877 .55202 m .36981 .55034 L .36577 .54922 L F
.36912 .55145 m .36937 .55362 L .36981 .55034 L F
.776 .544 .585 r
.36981 .55034 m .36937 .55362 L .37254 .55346 L F
.859 .416 .15 r
.37373 .55024 m .37088 .54727 L .36981 .55034 L F
.702 .777 .291 r
.37254 .55346 m .37373 .55024 L .36981 .55034 L F
.859 .416 .15 r
.37373 .55024 m .37249 .54647 L .37088 .54727 L F
.785 .592 .64 r
.37249 .54647 m .37373 .55024 L .36922 .55041 L F
.36936 .54885 m .36922 .55041 L .36721 .55049 L F
.37249 .54647 m .36922 .55041 L .36936 .54885 L F
.951 .799 .35 r
.36877 .55202 m .36901 .55266 L .36912 .55145 L F
.36901 .55266 m .36937 .55362 L .36912 .55145 L F
.662 .969 .805 r
.42877 .5299 m .42992 .52804 L .43169 .52764 L F
0 0 .149 r
.42877 .5299 m .42969 .53003 L .42992 .52804 L F
.711 .458 .54 r
.43255 .53277 m .42857 .53309 L .42877 .5299 L F
0 0 .149 r
.42877 .5299 m .42857 .53309 L .42969 .53003 L F
.051 0 .05 r
.4382 .44549 m .43949 .44674 L .44046 .44514 L F
.4382 .44549 m .43733 .44808 L .43949 .44674 L F
.974 .814 .621 r
.37018 .57423 m .36781 .57562 L .36758 .57303 L F
.37018 .57423 m .36941 .57689 L .36781 .57562 L F
0 0 0 r
.45215 .44787 m .44947 .44921 L .45299 .4468 L F
.103 0 0 r
.45517 .44545 m .45215 .44787 L .45299 .4468 L F
.836 .856 .86 r
.64596 .38841 m .64902 .38824 L .6479 .38666 L F
.913 .881 .79 r
.6479 .38666 m .64902 .38824 L .65093 .38483 L F
.795 .706 .767 r
.30641 .64275 m .30665 .64446 L .30516 .64485 L F
.741 .504 .571 r
.30516 .64485 m .30665 .64446 L .30557 .64583 L F
.552 .533 .788 r
.30981 .64353 m .30665 .64446 L .30641 .64275 L F
.5 .649 .924 r
.60074 .37725 m .60189 .37836 L .59899 .37924 L F
.416 .3 .612 r
.60189 .37836 m .60168 .38124 L .59899 .37924 L F
.599 .228 .309 r
.59899 .37924 m .60168 .38124 L .59886 .38122 L F
.595 .619 .845 r
.29613 .67462 m .29877 .67614 L .29886 .67402 L F
.546 .6 .859 r
.29877 .67614 m .30127 .67355 L .29886 .67402 L F
.29877 .67614 m .30398 .67681 L .30127 .67355 L F
.641 .849 .46 r
.45931 .53209 m .45822 .53429 L .46074 .53322 L F
.45931 .53209 m .45683 .53586 L .45822 .53429 L F
.374 .817 .951 r
.5205 .37828 m .52452 .37826 L .52196 .37882 L F
.913 .791 .712 r
.44312 .52973 m .44179 .52622 L .4406 .52879 L F
.338 .755 .978 r
.4406 .52879 m .44532 .52936 L .44312 .52973 L F
.276 .147 .518 r
.44532 .52936 m .44377 .53158 L .44312 .52973 L F
.912 .606 .453 r
.44377 .53158 m .4406 .52879 L .44312 .52973 L F
.582 .867 .995 r
.31346 .65043 m .31477 .65156 L .31182 .65233 L F
.31126 .652 m .31182 .65233 L .31021 .65275 L F
.31346 .65043 m .31182 .65233 L .31126 .652 L F
.31346 .65043 m .3104 .65262 L .31046 .6532 L F
.782 .397 0 r
.31021 .65275 m .31016 .65042 L .31046 .6532 L F
.98 .704 .43 r
.3088 .65281 m .31046 .6532 L .31027 .65143 L F
.30975 .65114 m .31027 .65143 L .31016 .65042 L F
.3088 .65281 m .31027 .65143 L .30975 .65114 L F
.732 .669 .788 r
.44665 .53303 m .4442 .53422 L .44377 .53158 L F
.84 .761 .775 r
.4442 .53422 m .43989 .5362 L .44377 .53158 L F
0 0 .512 r
.28154 .6581 m .28232 .65656 L .28089 .65607 L F
.28154 .6581 m .28298 .6592 L .28232 .65656 L F
.28154 .6581 m .28258 .66081 L .28298 .6592 L F
.656 .754 .922 r
.42443 .57529 m .42728 .57636 L .4272 .57331 L F
.902 .981 .707 r
.50632 .48392 m .50657 .48617 L .50956 .48351 L F
.50632 .48392 m .50578 .48565 L .50657 .48617 L F
.877 .993 .786 r
.55844 .41636 m .56108 .41299 L .55911 .41339 L F
0 0 .069 r
.55825 .41901 m .55844 .41636 L .55911 .41339 L F
.769 .545 .595 r
.2917 .5436 m .28842 .54043 L .28982 .53936 L F
.2917 .5436 m .28726 .5433 L .28842 .54043 L F
.881 .657 .595 r
.32004 .55251 m .32312 .55067 L .32032 .54963 L F
.32004 .55251 m .32243 .55334 L .32312 .55067 L F
.327 0 .21 r
.37627 .56097 m .37553 .56291 L .37805 .56221 L F
.353 0 0 r
.31212 .6446 m .31282 .64411 L .30981 .64353 L F
.046 .212 .712 r
.31186 .63997 m .31282 .64411 L .31435 .64264 L F
.498 .837 .556 r
.31435 .64264 m .31282 .64411 L .31212 .6446 L F
.913 .979 .715 r
.56319 .40834 m .56595 .40562 L .56531 .40529 L F
.56319 .40834 m .56368 .40938 L .56595 .40562 L F
.674 .973 .802 r
.56595 .40562 m .56937 .40297 L .56736 .40355 L F
.672 .976 .844 r
.56531 .40529 m .56595 .40562 L .56736 .40355 L F
.868 .628 .573 r
.30857 .52933 m .31288 .53338 L .31335 .53026 L F
0 0 0 r
.33016 .6242 m .32734 .62756 L .32988 .62751 L F
0 0 .243 r
.33016 .6242 m .32988 .62751 L .3316 .62623 L F
.285 0 0 r
.33814 .62541 m .33784 .62533 L .33632 .62641 L F
.659 .875 .98 r
.33937 .62314 m .3405 .62454 L .33814 .62541 L F
.488 .563 .858 r
.34128 .627 m .33814 .62541 L .3405 .62454 L F
0 0 0 r
.60557 .36477 m .60223 .36781 L .60344 .36631 L F
.801 .308 0 r
.36943 .57927 m .3731 .58193 L .37303 .58249 L F
.593 .725 .935 r
.29613 .67462 m .29621 .67112 L .29533 .67389 L F
.29613 .67462 m .29886 .67402 L .29621 .67112 L F
.813 .482 .428 r
.64819 .38295 m .64839 .38614 L .65093 .38483 L F
.913 .881 .79 r
.6479 .38666 m .65093 .38483 L .64839 .38614 L F
.785 .924 .929 r
.50531 .43331 m .50801 .43179 L .50669 .43023 L F
.855 .937 .876 r
.50669 .43023 m .50801 .43179 L .51083 .42869 L F
.694 .758 .901 r
.31968 .65238 m .31477 .65156 L .31791 .65076 L F
.717 .861 .95 r
.32188 .65084 m .31968 .65238 L .31791 .65076 L F
0 0 .517 r
.426 .51681 m .42714 .51481 L .42563 .51248 L F
0 0 .293 r
.426 .51681 m .42699 .51774 L .42714 .51481 L F
.426 .51681 m .42646 .51927 L .42699 .51774 L F
.826 .979 .686 r
.56184 .41052 m .56108 .41299 L .56368 .40938 L F
.819 1 .813 r
.55911 .41339 m .56108 .41299 L .56184 .41052 L F
.864 .663 .629 r
.38643 .54911 m .38978 .54929 L .39069 .54701 L F
.545 .352 .57 r
.39069 .54701 m .39325 .54696 L .39383 .54404 L F
.087 0 0 r
.5227 .39258 m .52097 .39156 L .52195 .3896 L F
.5227 .39258 m .51977 .3937 L .52097 .39156 L F
.371 .128 .411 r
.41074 .57399 m .41163 .57505 L .41287 .57307 L F
.785 .71 .78 r
.41026 .57663 m .41061 .57668 L .41163 .57505 L F
.41061 .57668 m .4142 .57719 L .41287 .57307 L F
.371 .128 .411 r
.41163 .57505 m .41026 .57663 L .41224 .57576 L F
.41074 .57399 m .41026 .57663 L .41163 .57505 L F
.785 .71 .78 r
.41026 .57663 m .41163 .57505 L .41287 .57307 L F
.371 .128 .411 r
.41163 .57505 m .41224 .57576 L .41287 .57307 L F
.785 .71 .78 r
.41026 .57663 m .41287 .57307 L .41074 .57399 L F
.206 0 .341 r
.27531 .54705 m .27477 .54964 L .27727 .54597 L F
.784 .705 .777 r
.28401 .57061 m .27941 .57034 L .28146 .56657 L F
.986 .719 .427 r
.28401 .57061 m .28217 .57012 L .27941 .57034 L F
.28401 .57061 m .28359 .57271 L .28217 .57012 L F
.368 .659 .969 r
.28315 .56848 m .28401 .57061 L .28146 .56657 L F
.28315 .56848 m .28557 .5699 L .28401 .57061 L F
.031 0 .213 r
.28557 .5699 m .28359 .57271 L .28401 .57061 L F
0 .438 .862 r
.30821 .62141 m .3054 .61969 L .3068 .61915 L F
.838 .839 .846 r
.31008 .61656 m .30821 .62141 L .3068 .61915 L F
.553 .828 .478 r
.49838 .46307 m .49989 .46125 L .50045 .46066 L F
0 0 0 r
.49792 .46532 m .49912 .46363 L .49989 .46125 L F
.823 .815 .331 r
.49989 .46125 m .49912 .46363 L .49936 .4618 L F
.49989 .46125 m .49936 .4618 L .49959 .46008 L F
.553 .828 .478 r
.50045 .46066 m .49989 .46125 L .50107 .45994 L F
.669 .871 .49 r
.50107 .45994 m .50118 .45921 L .50377 .45931 L F
.50107 .45994 m .49989 .46125 L .50118 .45921 L F
.147 0 .106 r
.27682 .57047 m .27576 .57321 L .27346 .57343 L F
.376 .001 .194 r
.27576 .57321 m .27197 .57566 L .27346 .57343 L F
.184 0 0 r
.38119 .47916 m .38388 .4787 L .38562 .47715 L F
.251 0 0 r
.38562 .47715 m .38388 .4787 L .3879 .47714 L F
.779 .642 .709 r
.43989 .5362 m .43988 .53324 L .44377 .53158 L F
.704 .969 .933 r
.43988 .53324 m .4407 .5318 L .44377 .53158 L F
.624 .122 .038 r
.4407 .5318 m .44389 .53394 L .44556 .53257 L F
.645 .909 .599 r
.44556 .53257 m .445 .53257 L .44512 .53249 L F
.366 0 0 r
.44377 .53158 m .44556 .53257 L .44584 .53262 L F
.276 .147 .518 r
.44532 .52936 m .44556 .53257 L .44377 .53158 L F
.912 .606 .453 r
.44377 .53158 m .4407 .5318 L .4406 .52879 L F
.761 .507 .549 r
.44532 .52936 m .44556 .53257 L .4407 .5318 L F
.645 .909 .599 r
.44556 .53257 m .44512 .53249 L .4475 .53083 L F
.366 0 0 r
.44584 .53262 m .44556 .53257 L .44665 .53303 L F
.723 .987 .886 r
.44665 .53303 m .4475 .53083 L .45001 .53017 L F
.44665 .53303 m .44556 .53257 L .4475 .53083 L F
.324 .033 .307 r
.29244 .63013 m .29008 .63099 L .28917 .63318 L F
0 .527 .759 r
.30536 .67729 m .30747 .67775 L .30956 .67799 L F
.834 .962 .631 r
.45056 .54196 m .44866 .54566 L .45045 .54428 L F
.94 .963 .69 r
.41246 .47823 m .41054 .48215 L .41123 .48277 L F
.187 0 .097 r
.43503 .44916 m .43254 .45017 L .43178 .45184 L F
.317 .025 .3 r
.53719 .35252 m .53679 .35471 L .53418 .35559 L F
.038 0 .205 r
.5388 .3525 m .53719 .35252 L .53967 .35176 L F
.5388 .3525 m .53679 .35471 L .53719 .35252 L F
.902 .613 .489 r
.43871 .5269 m .43845 .52946 L .4367 .52798 L F
.504 .249 .462 r
.4406 .52879 m .43871 .5269 L .44179 .52622 L F
.4406 .52879 m .43845 .52946 L .43871 .5269 L F
.644 .694 .882 r
.4367 .52798 m .4406 .52879 L .44 .52658 L F
.059 0 0 r
.43674 .52635 m .43908 .52451 L .43871 .5269 L F
.114 .653 .851 r
.43551 .52639 m .43617 .52632 L .43871 .5269 L F
.647 .73 .909 r
.43616 .52608 m .43687 .52459 L .43529 .52431 L F
.43674 .52635 m .43687 .52459 L .43606 .5263 L F
.18 .433 .865 r
.43529 .52431 m .43652 .52629 L .43627 .52631 L F
.43529 .52431 m .43627 .52631 L .43551 .52639 L F
.647 .73 .909 r
.43606 .5263 m .43616 .52608 L .43529 .52431 L F
.114 .653 .851 r
.43617 .52632 m .43627 .52631 L .4368 .52637 L F
.43627 .52631 m .43674 .52635 L .4368 .52637 L F
.902 .613 .489 r
.43871 .5269 m .4367 .52798 L .43551 .52639 L F
.647 .73 .909 r
.43663 .52779 m .43674 .52635 L .43606 .5263 L F
.114 .653 .851 r
.43627 .52631 m .43652 .52629 L .43674 .52635 L F
.059 0 0 r
.43652 .52629 m .43676 .52613 L .43674 .52635 L F
.43676 .52613 m .43908 .52451 L .43674 .52635 L F
.114 .653 .851 r
.43617 .52632 m .4368 .52637 L .43871 .5269 L F
.546 .603 .862 r
.43908 .52451 m .44179 .52622 L .43871 .5269 L F
.059 0 0 r
.43676 .52613 m .43959 .52509 L .43908 .52451 L F
.647 .73 .909 r
.4367 .52798 m .43959 .52509 L .43679 .52611 L F
.4367 .52798 m .43687 .52459 L .43663 .52779 L F
.059 0 0 r
.43652 .52629 m .43959 .52509 L .43676 .52613 L F
.647 .73 .909 r
.43679 .52611 m .43959 .52509 L .43687 .52459 L F
.644 .694 .882 r
.43822 .52646 m .44 .52658 L .43959 .52509 L F
.4367 .52798 m .44 .52658 L .43822 .52646 L F
.848 .6 .563 r
.31878 .54297 m .31863 .54571 L .32311 .54575 L F
.858 .701 .686 r
.31863 .54571 m .32032 .54963 L .32311 .54575 L F
.118 0 .114 r
.28615 .63641 m .28437 .63737 L .28614 .63751 L F
.118 0 .082 r
.28614 .63751 m .28437 .63737 L .28334 .63952 L F
.928 .905 .781 r
.32114 .60624 m .32348 .60738 L .32015 .61075 L F
0 .386 .734 r
.32517 .60788 m .32348 .60738 L .32114 .60624 L F
.727 .769 .886 r
.31248 .55698 m .30809 .55655 L .31085 .55575 L F
.772 .837 .902 r
.52191 .47368 m .52326 .46925 L .52024 .4719 L F
.52191 .47368 m .52439 .47219 L .52326 .46925 L F
.897 .734 .672 r
.30958 .55428 m .30613 .55472 L .30764 .55124 L F
.30958 .55428 m .30809 .55655 L .30613 .55472 L F
0 0 0 r
.49792 .46532 m .49989 .46125 L .49838 .46307 L F
.431 .765 .996 r
.50165 .4326 m .50531 .43331 L .50495 .4323 L F
.785 .924 .929 r
.50531 .43331 m .50669 .43023 L .50495 .4323 L F
0 0 .243 r
.50495 .4323 m .50622 .43582 L .50531 .43331 L F
.744 .566 .653 r
.39987 .47947 m .39645 .48228 L .39669 .47993 L F
.909 .528 .098 r
.64738 .38376 m .64819 .38295 L .64637 .38105 L F
.774 .88 .924 r
.64637 .38105 m .64819 .38295 L .65061 .38097 L F
.94 .647 .188 r
.64738 .38376 m .64839 .38614 L .64819 .38295 L F
0 .137 .654 r
.30956 .67799 m .31236 .68115 L .3133 .68189 L F
.97 .655 .286 r
.35392 .57093 m .35258 .57015 L .35217 .56661 L F
.755 .959 .937 r
.35499 .56832 m .35392 .57093 L .35639 .56999 L F
.35499 .56832 m .35258 .57015 L .35392 .57093 L F
.36 .187 .506 r
.25975 .57386 m .26182 .57508 L .26244 .57239 L F
.25975 .57386 m .25974 .57665 L .26182 .57508 L F
.523 .878 .643 r
.48594 .40852 m .48745 .40704 L .48923 .40593 L F
0 0 0 r
.48594 .40852 m .48458 .41019 L .48745 .40704 L F
.915 .791 .709 r
.41436 .48535 m .41545 .48939 L .41674 .48683 L F
.41436 .48535 m .41545 .48939 L .41674 .48683 L F
.229 0 .207 r
.62485 .39106 m .62826 .38798 L .62567 .38901 L F
.931 .961 .656 r
.56184 .41052 m .56368 .40938 L .56319 .40834 L F
.306 .796 .766 r
.3068 .61915 m .3054 .61969 L .30397 .62002 L F
.032 0 0 r
.31064 .63646 m .3138 .63308 L .31382 .63606 L F
0 0 0 r
.3138 .63308 m .31755 .63123 L .31569 .63272 L F
.004 0 .224 r
.31382 .63606 m .3138 .63308 L .31569 .63272 L F
.817 .698 .732 r
.32033 .644 m .32139 .64786 L .318 .647 L F
.812 .565 .565 r
.32139 .64786 m .31791 .65076 L .318 .647 L F
.32139 .64786 m .32188 .65084 L .31791 .65076 L F
.541 .446 .696 r
.27945 .5676 m .27682 .57047 L .27578 .56738 L F
.27945 .5676 m .27941 .57034 L .27682 .57047 L F
.168 0 .115 r
.27812 .57216 m .27682 .57047 L .27941 .57034 L F
.27812 .57216 m .27576 .57321 L .27682 .57047 L F
.28 .783 .816 r
.52703 .36253 m .52655 .36223 L .52347 .36303 L F
0 0 .053 r
.53092 .35803 m .53034 .36046 L .52703 .36253 L F
.463 .884 .786 r
.53034 .36046 m .52655 .36223 L .52703 .36253 L F
0 0 0 r
.31016 .65042 m .3144 .64752 L .31346 .65043 L F
.382 0 .108 r
.3144 .64752 m .31538 .64887 L .31346 .65043 L F
.3144 .64752 m .318 .647 L .31538 .64887 L F
.843 .938 .887 r
.55895 .37249 m .56051 .36879 L .56162 .36903 L F
.539 0 0 r
.56162 .36903 m .56576 .37223 L .5648 .3688 L F
.56521 .3718 m .5643 .37134 L .56576 .37223 L F
0 0 0 r
.56301 .37247 m .56471 .37191 L .5643 .37134 L F
.576 .523 .758 r
.5648 .3688 m .56576 .37223 L .56715 .36989 L F
.539 0 0 r
.56393 .37081 m .5643 .37134 L .56521 .3718 L F
.311 0 0 r
.5643 .37134 m .56715 .36989 L .56576 .37223 L F
0 0 0 r
.56471 .37191 m .56762 .37095 L .5643 .37134 L F
.539 0 0 r
.56162 .36903 m .5643 .37134 L .56393 .37081 L F
0 .167 .697 r
.56336 .36953 m .56325 .37044 L .56162 .36903 L F
.993 .812 .441 r
.56336 .36953 m .56321 .37079 L .5643 .37134 L F
.56321 .37079 m .56301 .37247 L .5643 .37134 L F
0 .167 .697 r
.56336 .36953 m .56162 .36903 L .56051 .36879 L F
.654 .597 .778 r
.56162 .36903 m .5648 .3688 L .56381 .36599 L F
.332 .322 .698 r
.2929 .6443 m .29416 .64025 L .29579 .64267 L F
.775 .908 .932 r
.43147 .55471 m .42617 .55591 L .42911 .55283 L F
.853 .85 .839 r
.43343 .55117 m .43147 .55471 L .42911 .55283 L F
.935 .856 .74 r
.41442 .58256 m .41796 .58059 L .41444 .57964 L F
.41442 .58256 m .41605 .58398 L .41796 .58059 L F
.843 .938 .887 r
.55895 .37249 m .55774 .37118 L .56051 .36879 L F
.63 .872 .987 r
.51726 .43721 m .51798 .43511 L .51782 .43388 L F
.51726 .43721 m .51996 .4361 L .51798 .43511 L F
.51 .553 .836 r
.34004 .66784 m .33861 .66518 L .33573 .6674 L F
.831 .749 .773 r
.33977 .67139 m .34292 .67066 L .34255 .67038 L F
.34292 .67066 m .34348 .67053 L .34255 .67038 L F
.073 0 .243 r
.3438 .669 m .34255 .67038 L .34484 .66668 L F
.729 .981 .762 r
.34219 .67012 m .34255 .67038 L .3438 .669 L F
0 0 0 r
.33977 .67139 m .34255 .67038 L .34211 .67061 L F
0 .197 .622 r
.33765 .67209 m .34151 .67456 L .33977 .67139 L F
.831 .749 .773 r
.33977 .67139 m .34151 .67456 L .34348 .67053 L F
0 0 0 r
.33977 .67139 m .34211 .67061 L .33969 .67187 L F
.729 .981 .762 r
.33969 .67187 m .34255 .67038 L .34219 .67012 L F
0 .197 .622 r
.33729 .67186 m .33765 .67209 L .33977 .67139 L F
.55 .819 .996 r
.64078 .34618 m .63984 .34539 L .63708 .3462 L F
.908 .555 .36 r
.30516 .53272 m .30354 .53489 L .30378 .53229 L F
.30516 .53272 m .30531 .53591 L .30354 .53489 L F
0 0 0 r
.45543 .43492 m .45692 .43318 L .45342 .43554 L F
.4589 .43161 m .45692 .43318 L .45543 .43492 L F
.93 .937 .783 r
.53932 .44825 m .53818 .45305 L .54006 .44909 L F
.917 .978 .753 r
.5416 .4446 m .54006 .44909 L .54208 .44553 L F
.5416 .4446 m .53932 .44825 L .54006 .44909 L F
0 0 .532 r
.58618 .3797 m .58585 .37756 L .58413 .37508 L F
0 0 0 r
.58618 .3797 m .5869 .37991 L .58585 .37756 L F
.84 .423 .246 r
.3422 .51662 m .34484 .51961 L .34625 .52003 L F
.883 .555 .425 r
.34484 .51961 m .34472 .52174 L .34625 .52003 L F
.714 .31 .281 r
.34472 .52174 m .34837 .52216 L .34625 .52003 L F
0 0 0 r
.27892 .55539 m .27824 .56039 L .2807 .55673 L F
.27892 .55539 m .27854 .55874 L .27824 .56039 L F
0 .185 .718 r
.27854 .55874 m .28051 .56247 L .27824 .56039 L F
.504 .268 .489 r
.28051 .56247 m .27781 .56321 L .27824 .56039 L F
.375 0 0 r
.66467 .34871 m .66547 .34928 L .66604 .34832 L F
0 .221 .694 r
.66547 .34928 m .66757 .35117 L .66604 .34832 L F
.877 .928 .853 r
.5166 .44384 m .51778 .44528 L .51633 .44655 L F
.755 .955 .939 r
.52086 .4415 m .51778 .44528 L .5166 .44384 L F
.52086 .4415 m .5217 .44255 L .51778 .44528 L F
.888 .507 .31 r
.65641 .34345 m .65792 .34198 L .65599 .34123 L F
.65641 .34345 m .6597 .34524 L .65792 .34198 L F
.98 .845 .453 r
.43345 .5168 m .43183 .51729 L .43273 .51957 L F
.43345 .5168 m .43245 .51439 L .43183 .51729 L F
.838 .631 .623 r
.3381 .51556 m .3422 .51662 L .3403 .51265 L F
.799 .484 .457 r
.3381 .51556 m .34244 .5188 L .3422 .51662 L F
.829 .449 .334 r
.34244 .5188 m .34484 .51961 L .3422 .51662 L F
0 0 0 r
.44623 .45267 m .44947 .44921 L .44839 .45131 L F
.051 0 0 r
.45071 .45018 m .44947 .44921 L .45215 .44787 L F
.45071 .45018 m .44839 .45131 L .44947 .44921 L F
.402 .069 .283 r
.2826 .53681 m .28542 .5365 L .28614 .53387 L F
.276 0 .237 r
.28614 .53387 m .28542 .5365 L .28699 .53458 L F
.826 .925 .9 r
.41146 .58578 m .41302 .58684 L .41605 .58398 L F
.848 .87 .857 r
.62212 .33972 m .61788 .34126 L .62032 .33939 L F
.62212 .33972 m .61798 .34189 L .61788 .34126 L F
.859 .987 .845 r
.62212 .33972 m .62332 .33635 L .62459 .338 L F
.62212 .33972 m .62032 .33939 L .62332 .33635 L F
.099 .648 .821 r
.63434 .33858 m .63822 .33882 L .63543 .33904 L F
.601 .714 .924 r
.2919 .67368 m .29262 .66987 L .29004 .67051 L F
.2919 .67368 m .29533 .67389 L .29262 .66987 L F
.78 .491 .499 r
.2917 .5436 m .28814 .54458 L .28726 .5433 L F
.2917 .5436 m .29167 .54674 L .28814 .54458 L F
.695 .675 .827 r
.29365 .54108 m .2917 .5436 L .28982 .53936 L F
.571 .496 .731 r
.29365 .54108 m .29483 .5436 L .2917 .5436 L F
.34 .141 .457 r
.29368 .54519 m .2917 .5436 L .29483 .5436 L F
.29368 .54519 m .29167 .54674 L .2917 .5436 L F
0 .11 .66 r
.30799 .58941 m .30681 .58625 L .30431 .58976 L F
.853 .723 .718 r
.30431 .58976 m .30595 .59368 L .30799 .58941 L F
.782 .725 .8 r
.30799 .58941 m .31079 .58648 L .30681 .58625 L F
.901 .971 .664 r
.59189 .39843 m .59378 .39548 L .59354 .39394 L F
.996 .78 .426 r
.33514 .63674 m .33667 .64043 L .33506 .63972 L F
.33514 .63674 m .33667 .64043 L .33506 .63972 L F
.547 .876 .607 r
.48923 .40593 m .49064 .40442 L .49215 .40334 L F
.555 .893 .65 r
.48923 .40593 m .48745 .40704 L .49064 .40442 L F
.715 .865 .953 r
.27892 .55539 m .2807 .55673 L .28329 .55541 L F
.878 .767 .736 r
.48208 .50571 m .47979 .5094 L .48304 .50929 L F
.873 .798 .773 r
.47979 .5094 m .4808 .513 L .48304 .50929 L F
.654 .856 .977 r
.60557 .36477 m .60998 .36489 L .6082 .36315 L F
.60557 .36477 m .60998 .36489 L .6082 .36315 L F
.457 .662 .95 r
.60998 .36489 m .61108 .36228 L .6082 .36315 L F
.60998 .36489 m .61246 .36465 L .61108 .36228 L F
.60998 .36489 m .61108 .36228 L .6082 .36315 L F
.60998 .36489 m .61246 .36465 L .61108 .36228 L F
.707 .733 .871 r
.30809 .55655 m .3062 .55834 L .30384 .55591 L F
.128 .654 .876 r
.63984 .34539 m .63517 .34469 L .63708 .3462 L F
.588 .218 .307 r
.36495 .52587 m .3646 .52649 L .36838 .5262 L F
.665 .645 .82 r
.25395 .59486 m .25809 .59709 L .25625 .59382 L F
.473 .53 .835 r
.25809 .59709 m .25863 .59262 L .25625 .59382 L F
.352 .121 .417 r
.26066 .5939 m .2603 .59653 L .25809 .59709 L F
.473 .53 .835 r
.25809 .59709 m .2603 .59653 L .25863 .59262 L F
.376 .182 .486 r
.25809 .59709 m .25791 .60021 L .2603 .59653 L F
.25809 .59709 m .25791 .60021 L .2603 .59653 L F
.606 .533 .746 r
.50053 .4425 m .50008 .4453 L .50335 .44203 L F
.11 0 .268 r
.51622 .39897 m .51376 .3973 L .5177 .39752 L F
.51622 .39897 m .51425 .40051 L .51376 .3973 L F
.743 .993 .857 r
.53479 .43071 m .53368 .43294 L .53213 .43083 L F
.53479 .43071 m .53693 .43029 L .53368 .43294 L F
.329 .292 .665 r
.53897 .40895 m .53929 .41319 L .54167 .41116 L F
0 .056 .609 r
.53929 .41319 m .54074 .41345 L .54167 .41116 L F
.53929 .41319 m .54028 .41574 L .54074 .41345 L F
.895 .876 .809 r
.64047 .37439 m .63763 .37939 L .63615 .37783 L F
.501 .184 .361 r
.5627 .39176 m .56601 .389 L .56175 .38847 L F
.5627 .39176 m .56584 .39166 L .56601 .389 L F
.503 .185 .361 r
.56601 .389 m .56584 .39166 L .56877 .39066 L F
.534 .149 .258 r
.56601 .389 m .56877 .39066 L .56881 .38872 L F
.766 .959 .651 r
.51661 .41075 m .5183 .40948 L .51413 .40961 L F
.811 .697 .739 r
.52246 .36467 m .52347 .36303 L .52197 .36238 L F
.549 .923 .78 r
.33867 .66114 m .34214 .65898 L .33777 .66116 L F
.724 .309 .261 r
.34129 .66378 m .33867 .66114 L .33861 .66518 L F
.588 .228 .326 r
.54439 .38599 m .54388 .38786 L .54137 .38713 L F
.555 .547 .801 r
.54682 .38486 m .54439 .38599 L .54405 .38366 L F
.587 .36 .538 r
.54682 .38486 m .54388 .38786 L .54439 .38599 L F
.732 .639 .756 r
.56381 .36599 m .56867 .36897 L .56536 .36578 L F
.56381 .36599 m .5648 .3688 L .56867 .36897 L F
.576 .523 .758 r
.5648 .3688 m .56715 .36989 L .56867 .36897 L F
.282 .569 .936 r
.56536 .36578 m .56867 .36897 L .56809 .36705 L F
.174 .167 .61 r
.56715 .36989 m .56809 .36705 L .56867 .36897 L F
.708 .341 .352 r
.36937 .55362 m .36977 .55566 L .37254 .55346 L F
.702 .777 .291 r
.37254 .55346 m .37285 .55243 L .37373 .55024 L F
.722 .965 .704 r
.37254 .55346 m .36977 .55566 L .37285 .55243 L F
.863 .819 .804 r
.30994 .58282 m .31347 .58278 L .31239 .57962 L F
.30994 .58282 m .31238 .58396 L .31347 .58278 L F
.823 .814 .841 r
.31239 .57962 m .31347 .58278 L .31633 .57949 L F
.764 .911 .528 r
.52419 .3587 m .52197 .36238 L .52288 .36002 L F
.651 .924 .975 r
.52419 .3587 m .52508 .35617 L .52747 .356 L F
.52419 .3587 m .52377 .35754 L .52508 .35617 L F
.941 .892 .492 r
.52419 .3587 m .52288 .36002 L .52377 .35754 L F
.938 .688 .533 r
.38101 .55326 m .38092 .55609 L .38252 .55567 L F
.004 .365 .835 r
.3786 .55749 m .38252 .55567 L .38092 .55609 L F
0 .487 .862 r
.38252 .55567 m .3835 .55546 L .38101 .55326 L F
.38252 .55567 m .38521 .55674 L .3835 .55546 L F
.36 .191 .512 r
.26215 .56667 m .26417 .56617 L .26429 .56337 L F
.272 .212 .604 r
.26276 .56934 m .26417 .56617 L .26215 .56667 L F
.28 0 .202 r
.41056 .46613 m .4131 .46525 L .41398 .46234 L F
.152 0 .061 r
.4131 .46525 m .41654 .46161 L .41398 .46234 L F
.829 .749 .775 r
.36577 .54922 m .37088 .54727 L .36843 .54615 L F
.785 .592 .64 r
.37249 .54647 m .36843 .54615 L .37088 .54727 L F
.558 .007 0 r
.65008 .34976 m .64811 .34828 L .64782 .3482 L F
.669 .949 .7 r
.49614 .46725 m .49598 .46644 L .49792 .46532 L F
.49614 .46725 m .49442 .46823 L .49598 .46644 L F
.741 .504 .571 r
.30516 .64485 m .30557 .64583 L .3042 .6481 L F
.937 .74 .611 r
.66956 .36057 m .67205 .35898 L .66982 .35779 L F
.66956 .36057 m .67164 .36171 L .67205 .35898 L F
.85 .548 .476 r
.3499 .55015 m .34724 .55209 L .34716 .54963 L F
.85 .721 .72 r
.3499 .55015 m .34716 .54963 L .34816 .54646 L F
.876 .597 .511 r
.3499 .55015 m .35001 .55301 L .34724 .55209 L F
.455 .145 .35 r
.53418 .35559 m .53351 .35748 L .53092 .35803 L F
.309 .01 .284 r
.53679 .35471 m .53351 .35748 L .53418 .35559 L F
.862 .777 .766 r
.32183 .55894 m .3234 .56027 L .32201 .55651 L F
.859 .756 .748 r
.31881 .56255 m .3234 .56027 L .32183 .55894 L F
.31881 .56255 m .32113 .56374 L .3234 .56027 L F
.724 .779 .896 r
.52439 .47219 m .52565 .4679 L .52326 .46925 L F
.52439 .47219 m .52732 .46973 L .52565 .4679 L F
.793 .802 .859 r
.48208 .50571 m .48692 .5046 L .48441 .50411 L F
.782 .898 .924 r
.48441 .50411 m .48692 .5046 L .48909 .50295 L F
.807 .834 .872 r
.4808 .513 m .47709 .51281 L .47686 .51594 L F
.013 0 .109 r
.32734 .62756 m .32476 .631 L .32745 .63055 L F
.429 .127 .349 r
.32757 .63014 m .32734 .62756 L .32745 .63055 L F
.32757 .63014 m .32988 .62751 L .32734 .62756 L F
.852 .499 .385 r
.41256 .57871 m .4142 .57719 L .41026 .57663 L F
.41256 .57871 m .41444 .57964 L .4142 .57719 L F
.727 .678 .803 r
.41287 .57307 m .4142 .57719 L .41748 .57456 L F
.927 .911 .784 r
.53689 .45206 m .53629 .45638 L .53818 .45305 L F
.93 .937 .783 r
.53932 .44825 m .53689 .45206 L .53818 .45305 L F
0 0 0 r
.39325 .54696 m .39479 .54516 L .39583 .54254 L F
0 0 .206 r
.39325 .54696 m .39479 .54516 L .39383 .54404 L F
.318 .776 .949 r
.63822 .33882 m .64124 .33847 L .64242 .3391 L F
.514 .845 .998 r
.64124 .33847 m .64504 .33879 L .64242 .3391 L F
0 0 0 r
.38703 .48298 m .38523 .48453 L .38402 .48513 L F
.389 0 0 r
.38971 .48269 m .38523 .48453 L .38703 .48298 L F
.842 .495 .398 r
.51575 .44918 m .51176 .44586 L .51442 .44496 L F
.51575 .44918 m .51226 .44841 L .51176 .44586 L F
.829 .553 .005 r
.51339 .45278 m .51226 .44841 L .51575 .44918 L F
.839 .726 .739 r
.51633 .44655 m .51575 .44918 L .51442 .44496 L F
.604 .532 .747 r
.27781 .56321 m .27945 .5676 L .27578 .56738 L F
.974 .669 .366 r
.33456 .52016 m .33272 .52117 L .3329 .51853 L F
.33456 .52016 m .33473 .52263 L .33272 .52117 L F
.98 .811 .602 r
.53791 .40625 m .53897 .40895 L .53761 .40932 L F
.793 .338 .161 r
.53761 .40932 m .53897 .40895 L .53719 .4103 L F
0 .144 .654 r
.53897 .40895 m .54167 .41116 L .53975 .40907 L F
.53897 .40895 m .53975 .40907 L .53719 .4103 L F
.314 0 .055 r
.39734 .54481 m .39579 .5477 L .39325 .54696 L F
0 0 0 r
.39872 .54235 m .39759 .54469 L .39734 .54481 L F
.39759 .54469 m .39579 .5477 L .39734 .54481 L F
.45342 .43554 m .4497 .43846 L .45206 .43735 L F
.4542 .43577 m .45342 .43554 L .45206 .43735 L F
.4542 .43577 m .45543 .43492 L .45342 .43554 L F
.265 0 .019 r
.33729 .67186 m .33862 .67317 L .33601 .67399 L F
.33729 .67186 m .33977 .67139 L .33862 .67317 L F
.658 .629 .809 r
.253 .60659 m .25662 .6073 L .25493 .60335 L F
.75 .755 .857 r
.60045 .34461 m .60259 .34869 L .60191 .34546 L F
.76 .27 .064 r
.59987 .343 m .60496 .34466 L .60131 .34186 L F
0 .148 .613 r
.60131 .34186 m .60502 .34469 L .60507 .34475 L F
.76 .27 .064 r
.60496 .34466 m .60502 .34469 L .605 .34467 L F
.60496 .34466 m .605 .34467 L .60131 .34186 L F
.503 .892 .725 r
.60045 .34461 m .59933 .34528 L .59914 .34524 L F
.59933 .34528 m .59722 .34655 L .59914 .34524 L F
.60045 .34461 m .59722 .34655 L .59914 .34524 L F
.545 .495 .751 r
.59697 .34383 m .59722 .34655 L .59914 .34524 L F
0 0 0 r
.59654 .34867 m .59914 .34524 L .59722 .34655 L F
.59655 .34866 m .59867 .34723 L .59914 .34524 L F
.59654 .34867 m .59867 .34723 L .59655 .34866 L F
0 0 .463 r
.6004 .34721 m .59981 .34646 L .59867 .34723 L F
.87 .692 .167 r
.59914 .34524 m .59867 .34723 L .59871 .34515 L F
.545 .495 .751 r
.59697 .34383 m .59914 .34524 L .59987 .343 L F
.928 .726 .24 r
.59872 .34426 m .59867 .34723 L .59805 .34419 L F
0 0 .463 r
.59981 .34646 m .59805 .34419 L .59867 .34723 L F
.87 .692 .167 r
.59914 .34524 m .59871 .34515 L .59872 .34426 L F
.949 .701 .527 r
.59914 .34524 m .6016 .34818 L .60045 .34461 L F
.683 .663 .824 r
.60208 .34435 m .59989 .34483 L .60191 .34546 L F
.6022 .34359 m .60502 .34469 L .60175 .34362 L F
.60118 .34333 m .60175 .34362 L .59987 .343 L F
.6022 .34359 m .60175 .34362 L .60118 .34333 L F
.795 .999 .843 r
.59914 .34524 m .6022 .34359 L .59987 .343 L F
.59914 .34524 m .59872 .34426 L .60021 .34285 L F
.60037 .34293 m .60021 .34285 L .60062 .34247 L F
.59914 .34524 m .60021 .34285 L .60037 .34293 L F
.683 .663 .824 r
.6022 .34359 m .60101 .34423 L .60208 .34435 L F
.60101 .34423 m .59989 .34483 L .60208 .34435 L F
.957 .642 .227 r
.60045 .34461 m .60075 .34553 L .60107 .3458 L F
.893 .56 .411 r
.60191 .34546 m .59914 .34524 L .60045 .34461 L F
.683 .663 .824 r
.59989 .34483 m .59914 .34524 L .60052 .34535 L F
.59989 .34483 m .60052 .34535 L .60191 .34546 L F
.957 .642 .227 r
.60107 .3458 m .6016 .34818 L .60259 .34869 L F
.60075 .34553 m .6016 .34818 L .60107 .3458 L F
0 0 0 r
.60259 .34869 m .60502 .34469 L .60191 .34546 L F
.60259 .34869 m .60507 .34475 L .60502 .34469 L F
.60259 .34869 m .60408 .34649 L .60507 .34475 L F
.65 .955 .942 r
.60259 .34869 m .6016 .34818 L .60408 .34649 L F
.614 .132 .088 r
.41352 .489 m .41192 .49067 L .41127 .48947 L F
.41352 .489 m .41192 .49067 L .41127 .48947 L F
.765 .989 .892 r
.66885 .37124 m .67216 .36731 L .66866 .37003 L F
.66885 .37124 m .67275 .36812 L .67216 .36731 L F
0 0 0 r
.49215 .40334 m .49307 .40318 L .49475 .40213 L F
.49215 .40334 m .49064 .40442 L .49307 .40318 L F
.26 .637 .963 r
.58366 .34511 m .5881 .34701 L .58466 .34674 L F
.529 .627 .892 r
.58834 .34839 m .58466 .34674 L .5881 .34701 L F
.649 .129 0 r
.51996 .4361 m .51782 .43388 L .51798 .43511 L F
.374 .136 .42 r
.26647 .55975 m .26938 .55635 L .26679 .55696 L F
0 .172 .694 r
.55401 .403 m .55602 .40319 L .5565 .40065 L F
.552 .533 .788 r
.30981 .64353 m .30641 .64275 L .30763 .63927 L F
.611 .531 .74 r
.26269 .59056 m .26369 .59345 L .26066 .5939 L F
.601 .362 .527 r
.26369 .59345 m .2603 .59653 L .26066 .5939 L F
.753 .706 .808 r
.28557 .5699 m .2881 .57418 L .28359 .57271 L F
.139 .619 .92 r
.2881 .57418 m .2867 .57315 L .28359 .57271 L F
.814 .546 .532 r
.28557 .5699 m .29031 .57308 L .2881 .57418 L F
.599 .897 .988 r
.2881 .57418 m .2867 .57315 L .29031 .57308 L F
.625 .565 .767 r
.54515 .37524 m .54638 .37908 L .54923 .3784 L F
.414 .298 .611 r
.54638 .37908 m .54904 .38076 L .54923 .3784 L F
.54638 .37908 m .54654 .38189 L .54904 .38076 L F
.975 .873 .671 r
.30531 .53591 m .30346 .53845 L .30354 .53489 L F
.711 .532 .645 r
.30354 .53489 m .30375 .53503 L .30531 .53591 L F
.893 .946 .836 r
.30788 .53735 m .30467 .53953 L .30531 .53591 L F
.975 .873 .671 r
.30531 .53591 m .30467 .53953 L .30346 .53845 L F
.711 .532 .645 r
.30375 .53503 m .30859 .53839 L .30531 .53591 L F
.893 .946 .836 r
.30824 .53711 m .30788 .53735 L .30531 .53591 L F
.589 .829 .99 r
.30879 .53569 m .30824 .53711 L .30531 .53591 L F
.097 0 0 r
.46651 .43784 m .46449 .43884 L .46782 .43623 L F
0 0 0 r
.46874 .43672 m .46782 .43623 L .47018 .43513 L F
.46874 .43672 m .46651 .43784 L .46782 .43623 L F
0 0 .388 r
.53708 .39014 m .53595 .39575 L .53782 .39218 L F
.53599 .39556 m .53711 .39395 L .53595 .39575 L F
.53708 .39014 m .53711 .39395 L .53599 .39556 L F
0 0 0 r
.53865 .3921 m .53711 .39395 L .53902 .39151 L F
.82 .575 .02 r
.53713 .38877 m .53708 .39014 L .53782 .39218 L F
.515 .429 .697 r
.53902 .39151 m .53711 .39395 L .53708 .39014 L F
.626 .932 .688 r
.53865 .3921 m .53804 .39263 L .53711 .39395 L F
.932 .566 .291 r
.53711 .39395 m .53333 .39336 L .53354 .39481 L F
.53609 .39478 m .53354 .39481 L .53381 .39663 L F
.53711 .39395 m .53354 .39481 L .53609 .39478 L F
.139 .236 .704 r
.53333 .39336 m .53555 .3948 L .53381 .39663 L F
.582 .121 .124 r
.53191 .39482 m .52881 .39604 L .53398 .39576 L F
.5304 .39414 m .52981 .39484 L .53191 .39482 L F
.52981 .39484 m .52881 .39604 L .53191 .39482 L F
.932 .566 .291 r
.53711 .39395 m .53496 .39267 L .53333 .39336 L F
.53711 .39395 m .53555 .3948 L .53496 .39267 L F
.626 .932 .688 r
.53804 .39263 m .53555 .3948 L .53711 .39395 L F
.567 .318 .498 r
.53496 .39267 m .53704 .39099 L .53708 .39014 L F
.466 .162 .365 r
.53708 .39014 m .53778 .39055 L .5394 .38717 L F
.53778 .39055 m .53874 .3911 L .53884 .39049 L F
.53778 .39055 m .53884 .39049 L .5394 .38717 L F
.53 .218 .382 r
.54348 .38842 m .5394 .38717 L .54388 .38786 L F
.54215 .39028 m .54188 .38997 L .54348 .38842 L F
.54188 .38997 m .5394 .38717 L .54348 .38842 L F
0 0 0 r
.54155 .39029 m .53865 .3921 L .53902 .39151 L F
.53 .218 .382 r
.54215 .39028 m .54065 .39064 L .5394 .38717 L F
.524 .53 .804 r
.54065 .39064 m .53902 .39151 L .54079 .39065 L F
.53895 .3905 m .53901 .39134 L .54065 .39064 L F
.53901 .39134 m .53902 .39151 L .54065 .39064 L F
.53 .218 .382 r
.54065 .39064 m .53884 .39049 L .5394 .38717 L F
.524 .53 .804 r
.53895 .3905 m .54079 .39065 L .54144 .39034 L F
.587 .854 .994 r
.54205 .39004 m .53874 .3911 L .54065 .39064 L F
.54205 .39004 m .54065 .39064 L .54215 .39028 L F
.53 .218 .382 r
.54065 .39064 m .53874 .3911 L .53884 .39049 L F
.524 .53 .804 r
.53895 .39048 m .53895 .3905 L .54144 .39034 L F
0 0 0 r
.54205 .39004 m .54138 .39045 L .54155 .39029 L F
.54138 .39045 m .53865 .3921 L .54155 .39029 L F
.524 .53 .804 r
.53888 .38951 m .53895 .39048 L .54205 .39004 L F
.53895 .39048 m .54144 .39034 L .54205 .39004 L F
.515 .429 .697 r
.53902 .39151 m .53708 .39014 L .53874 .3911 L F
.567 .318 .498 r
.53704 .39099 m .53888 .38951 L .53708 .39014 L F
.82 .575 .02 r
.53701 .38818 m .53708 .39014 L .53713 .38877 L F
.93 .827 .722 r
.30954 .57093 m .30718 .5701 L .30922 .56886 L F
.30954 .57093 m .30825 .57336 L .30718 .5701 L F
.419 0 0 r
.56877 .39066 m .57287 .38896 L .56881 .38872 L F
.56877 .39066 m .57171 .39068 L .57287 .38896 L F
.194 .35 .793 r
.57086 .38413 m .57287 .38896 L .57424 .38672 L F
0 0 0 r
.57287 .38896 m .57422 .38951 L .57424 .38672 L F
.57287 .38896 m .57171 .39068 L .57422 .38951 L F
.562 .438 .668 r
.28047 .5401 m .28314 .53969 L .2826 .53681 L F
.474 .165 .361 r
.28047 .5401 m .28197 .54213 L .28314 .53969 L F
.936 .85 .733 r
.30023 .63815 m .29615 .64222 L .29702 .6398 L F
.30023 .63815 m .29802 .64331 L .29615 .64222 L F
.539 .246 .418 r
.30123 .64115 m .30154 .63826 L .29876 .63888 L F
.51 0 0 r
.29957 .63732 m .30152 .637 L .30091 .63752 L F
.30041 .63757 m .30091 .63752 L .30075 .63766 L F
.29919 .63726 m .2994 .63724 L .29957 .63732 L F
.2994 .63724 m .30152 .637 L .29957 .63732 L F
.29919 .63726 m .30091 .63752 L .30041 .63757 L F
.722 .335 .316 r
.29919 .63726 m .30101 .63414 L .30075 .63766 L F
.956 .661 .228 r
.30101 .63414 m .30152 .637 L .30091 .63752 L F
.30077 .63739 m .30091 .63752 L .30075 .63766 L F
.30101 .63414 m .30091 .63752 L .30077 .63739 L F
.882 .978 .832 r
.30028 .63698 m .30177 .63613 L .30154 .63539 L F
.29974 .63765 m .30045 .63712 L .30028 .63698 L F
.30045 .63712 m .30177 .63613 L .30028 .63698 L F
.539 .246 .418 r
.30154 .63826 m .30177 .63613 L .30016 .6376 L F
.30154 .63826 m .30016 .6376 L .29876 .63888 L F
.743 .498 .56 r
.29919 .63726 m .30075 .63766 L .29876 .63888 L F
.882 .978 .832 r
.29876 .63888 m .30016 .6376 L .29974 .63765 L F
.30016 .6376 m .30177 .63613 L .29974 .63765 L F
.766 .761 .848 r
.30681 .58625 m .31079 .58648 L .30994 .58282 L F
.867 .816 .798 r
.30994 .58282 m .31079 .58648 L .31238 .58396 L F
.767 .821 .896 r
.29883 .59616 m .30271 .59561 L .30167 .59337 L F
.754 .79 .882 r
.30271 .59561 m .30595 .59368 L .30167 .59337 L F
.272 .212 .604 r
.26276 .56934 m .26486 .56936 L .26417 .56617 L F
.297 .098 .432 r
.26244 .57239 m .26486 .56936 L .26276 .56934 L F
.772 .704 .788 r
.43291 .53905 m .43611 .54328 L .43245 .54382 L F
.508 .887 .967 r
.43245 .54382 m .43611 .54328 L .43277 .54389 L F
.729 .613 .728 r
.43291 .53905 m .437 .54357 L .43611 .54328 L F
.311 0 0 r
.43611 .54328 m .437 .54357 L .43277 .54389 L F
.492 .358 .626 r
.37394 .48188 m .37551 .48355 L .37614 .4797 L F
.641 .966 .844 r
.63567 .39114 m .638 .38859 L .63474 .38997 L F
.63567 .39114 m .63908 .38883 L .638 .38859 L F
.304 0 0 r
.59725 .34245 m .59987 .343 L .60131 .34186 L F
.766 .959 .651 r
.51661 .41075 m .51413 .40961 L .51552 .41192 L F
.896 .59 .461 r
.34056 .53013 m .33682 .53091 L .33677 .52871 L F
.34056 .53013 m .34049 .53263 L .33682 .53091 L F
.702 .59 .727 r
.34469 .62776 m .34224 .63077 L .34128 .627 L F
.838 .781 .797 r
.47979 .5094 m .47709 .51281 L .4808 .513 L F
.593 .438 .641 r
.28814 .54458 m .28392 .54395 L .28726 .5433 L F
.402 .854 .888 r
.41812 .56559 m .41943 .56171 L .41945 .56534 L F
.877 .928 .853 r
.5166 .44384 m .51633 .44655 L .51442 .44496 L F
.882 .771 .735 r
.31494 .57606 m .31633 .57949 L .3173 .57736 L F
0 0 0 r
.53555 .3948 m .53548 .39493 L .53381 .39663 L F
.53381 .39663 m .53246 .398 L .53595 .39575 L F
.653 .961 .771 r
.53711 .39395 m .53381 .39663 L .53595 .39575 L F
0 0 0 r
.53548 .39493 m .53337 .39865 L .53381 .39663 L F
.53381 .39663 m .53238 .39805 L .53246 .398 L F
.083 .224 .712 r
.52197 .36238 m .52347 .36303 L .52288 .36002 L F
.718 .925 .961 r
.29291 .59967 m .29408 .59756 L .2916 .59687 L F
.29291 .59967 m .29656 .59814 L .29408 .59756 L F
.586 .856 .995 r
.51283 .4437 m .51442 .44496 L .51176 .44586 L F
.936 .578 .17 r
.51176 .44586 m .51081 .44698 L .51283 .4437 L F
.51176 .44586 m .51226 .44841 L .51081 .44698 L F
.816 .897 .482 r
.5108 .38891 m .50946 .39127 L .51127 .38741 L F
.734 .592 .698 r
.43277 .54389 m .43606 .54698 L .43182 .54625 L F
.783 .806 .32 r
.437 .54357 m .43606 .54698 L .43277 .54389 L F
.437 .54357 m .4366 .54448 L .43606 .54698 L F
0 0 .182 r
.43606 .54698 m .4366 .54448 L .43651 .54684 L F
.901 .485 .143 r
.29977 .5671 m .2985 .56811 L .29803 .56574 L F
.29977 .5671 m .3002 .56935 L .2985 .56811 L F
.781 .926 .931 r
.29656 .59814 m .29883 .59616 L .29408 .59756 L F
.503 0 0 r
.42992 .52804 m .43421 .52891 L .43169 .52764 L F
.685 .605 .76 r
.32476 .631 m .3285 .63186 L .32745 .63055 L F
.402 .736 .992 r
.34192 .62429 m .3405 .62454 L .33937 .62314 L F
.674 .639 .807 r
.34192 .62429 m .34128 .627 L .3405 .62454 L F
.267 0 0 r
.39358 .47493 m .39775 .47222 L .39534 .47324 L F
.855 .937 .876 r
.50669 .43023 m .51083 .42869 L .51026 .42804 L F
.997 .857 .538 r
.51083 .42869 m .51065 .42501 L .51026 .42804 L F
.726 .428 .474 r
.42727 .50705 m .42294 .50885 L .42644 .50522 L F
.42727 .50705 m .42849 .50886 L .42294 .50885 L F
.655 .793 .948 r
.42644 .50522 m .42988 .50598 L .42727 .50705 L F
0 0 0 r
.42549 .45558 m .42778 .45447 L .42931 .45282 L F
.05 0 0 r
.42778 .45447 m .43178 .45184 L .42931 .45282 L F
.545 .911 .733 r
.50737 .42611 m .50415 .42842 L .50386 .42829 L F
0 0 0 r
.35557 .64713 m .35175 .64982 L .35378 .65104 L F
.35557 .64713 m .35336 .64873 L .35175 .64982 L F
.899 .913 .514 r
.35557 .64713 m .35656 .64275 L .3553 .64674 L F
.743 .96 .668 r
.35557 .64713 m .3553 .64674 L .35336 .64873 L F
.538 .853 .554 r
.47436 .41912 m .47579 .41758 L .4776 .416 L F
0 0 0 r
.4776 .416 m .47799 .41616 L .4796 .41481 L F
.4776 .416 m .47579 .41758 L .47799 .41616 L F
.452 .837 .986 r
.38117 .57308 m .38378 .57244 L .38545 .5733 L F
.776 .685 .763 r
.25493 .60335 m .25662 .6073 L .25929 .60384 L F
.964 .635 .274 r
.66813 .35609 m .66958 .35548 L .66801 .35374 L F
.66813 .35609 m .66982 .35779 L .66958 .35548 L F
.134 0 0 r
.37711 .58711 m .38143 .58732 L .37844 .58736 L F
.382 .629 .951 r
.38143 .58732 m .38231 .58521 L .37844 .58736 L F
.38143 .58732 m .38359 .58684 L .38231 .58521 L F
.975 .805 .609 r
.52015 .38556 m .5191 .38777 L .52052 .3884 L F
.871 .643 .589 r
.34847 .54346 m .34816 .54646 L .34597 .54259 L F
.543 .224 .377 r
.56418 .35414 m .56824 .35177 L .56409 .35176 L F
.763 .843 .912 r
.52485 .43389 m .52629 .43551 L .52301 .43458 L F
.881 .728 .687 r
.52301 .43458 m .52629 .43551 L .52442 .43944 L F
.76 .842 .914 r
.5296 .43274 m .52629 .43551 L .52485 .43389 L F
.948 .827 .386 r
.5881 .34701 m .5874 .35033 L .58834 .34839 L F
.57 .7 .929 r
.29262 .66987 m .29533 .67389 L .29621 .67112 L F
.42 .704 .981 r
.64439 .36162 m .64552 .35996 L .64365 .36011 L F
.983 .799 .395 r
.64439 .36162 m .64365 .36011 L .64552 .35996 L F
.64439 .36162 m .64412 .36481 L .64365 .36011 L F
.427 .428 .757 r
.3285 .63186 m .33151 .63452 L .33072 .6311 L F
0 0 0 r
.3275 .63247 m .3285 .63186 L .33072 .6311 L F
.512 .295 .522 r
.54923 .3784 m .55203 .37778 L .55138 .37486 L F
.671 .954 .95 r
.55524 .37278 m .55138 .37486 L .55313 .37242 L F
.188 .093 .509 r
.55138 .37486 m .55446 .37534 L .55313 .37242 L F
.272 0 0 r
.40685 .46783 m .41056 .46613 L .40792 .46678 L F
.881 .643 .575 r
.3432 .53338 m .34032 .53532 L .34049 .53263 L F
.3432 .53338 m .34301 .53616 L .34032 .53532 L F
.572 .588 .831 r
.30938 .6301 m .30783 .63391 L .3072 .63048 L F
.30939 .63029 m .30783 .63391 L .30938 .6301 L F
.30948 .63008 m .31017 .63335 L .30783 .63391 L F
.878 .645 .582 r
.3063 .63606 m .3096 .63374 L .30854 .63199 L F
.3096 .63374 m .31017 .63335 L .30955 .63283 L F
.3096 .63374 m .30955 .63283 L .30854 .63199 L F
.572 .588 .831 r
.30948 .63008 m .30939 .63029 L .30938 .6301 L F
.576 .921 .961 r
.50956 .48351 m .51096 .4818 L .50632 .48392 L F
.50956 .48351 m .51216 .48236 L .51096 .4818 L F
0 0 .526 r
.34716 .6299 m .34662 .63403 L .34909 .63068 L F
.34716 .6299 m .34793 .63292 L .34662 .63403 L F
.78 .503 0 r
.34652 .63491 m .34714 .63658 L .34662 .63403 L F
.34652 .63491 m .34662 .63403 L .34793 .63292 L F
.926 .538 .205 r
.37606 .58463 m .37471 .58497 L .37576 .58221 L F
.37606 .58463 m .37711 .58711 L .37471 .58497 L F
.287 .411 .814 r
.58601 .38666 m .58709 .38818 L .58557 .38456 L F
.821 .832 .857 r
.3176 .62845 m .313 .62998 L .31685 .6278 L F
.113 .408 .858 r
.3204 .63007 m .3176 .62845 L .32009 .62714 L F
.05 0 0 r
.42777 .46521 m .42404 .46837 L .42519 .46571 L F
.476 .801 1 r
.56532 .34115 m .56864 .3406 L .56947 .34181 L F
.56532 .34115 m .56864 .3406 L .56947 .34181 L F
.342 .41 .787 r
.2869 .66684 m .28806 .67056 L .29004 .67051 L F
.835 .643 .643 r
.57147 .36721 m .57537 .36879 L .57442 .36652 L F
0 .473 .811 r
.57147 .36721 m .5741 .36802 L .57537 .36879 L F
.459 .862 .965 r
.5741 .36802 m .57805 .36776 L .57537 .36879 L F
.596 .935 .949 r
.65322 .37984 m .65809 .37886 L .65736 .37827 L F
.705 .964 .941 r
.65809 .37886 m .66034 .37728 L .65945 .3765 L F
.728 .986 .892 r
.65736 .37827 m .65809 .37886 L .65945 .3765 L F
.428 .477 .809 r
.63984 .34539 m .64086 .34872 L .64359 .34684 L F
.439 .499 .824 r
.64086 .34872 m .64441 .34948 L .64359 .34684 L F
.731 .75 .867 r
.36545 .53259 m .36976 .53322 L .36791 .53138 L F
.725 .309 .259 r
.36545 .53259 m .36791 .53523 L .36976 .53322 L F
.792 .756 .82 r
.36791 .53138 m .36976 .53322 L .37275 .53007 L F
.813 .431 .332 r
.36976 .53322 m .36791 .53523 L .36992 .53545 L F
.704 .779 .91 r
.51934 .40464 m .52091 .40652 L .52352 .40527 L F
0 .156 .691 r
.58557 .38456 m .58709 .38818 L .58778 .38844 L F
.118 0 .289 r
.58709 .38818 m .58633 .39113 L .58778 .38844 L F
.873 .715 .682 r
.39804 .48625 m .39512 .48569 L .39645 .48228 L F
.744 .259 .089 r
.39804 .48625 m .39602 .48716 L .39512 .48569 L F
.744 .566 .653 r
.39987 .47947 m .40237 .48311 L .39645 .48228 L F
.40237 .48311 m .40305 .48411 L .40152 .48368 L F
.40237 .48311 m .40152 .48368 L .39645 .48228 L F
.621 .598 .805 r
.40161 .48345 m .39645 .48228 L .40305 .48411 L F
.40161 .48345 m .39804 .48625 L .39645 .48228 L F
.197 0 0 r
.40161 .48345 m .39602 .48716 L .39713 .48666 L F
.39997 .48473 m .39713 .48666 L .39804 .48625 L F
.40161 .48345 m .39713 .48666 L .39997 .48473 L F
.793 .41 .331 r
.56071 .38447 m .55604 .3815 L .56142 .38283 L F
.868 .628 .573 r
.30857 .52933 m .3088 .53242 L .31288 .53338 L F
.76 .64 .728 r
.3088 .53242 m .31295 .536 L .31288 .53338 L F
.203 .73 .759 r
.61076 .34346 m .61353 .34286 L .61538 .34267 L F
.647 .968 .842 r
.61538 .34267 m .61353 .34286 L .61529 .34161 L F
.834 .717 .735 r
.31143 .6262 m .31685 .6278 L .313 .62998 L F
.624 .697 .897 r
.31505 .62304 m .3172 .62493 L .31958 .62263 L F
.637 .631 .827 r
.31958 .62263 m .31685 .6278 L .31505 .62304 L F
.841 .669 .668 r
.33691 .52362 m .33661 .52639 L .33473 .52263 L F
0 0 0 r
.4632 .44065 m .46449 .43884 L .46651 .43784 L F
.979 .78 .568 r
.3204 .63007 m .32177 .63295 L .31976 .63284 L F
.183 0 0 r
.32411 .63338 m .32177 .63295 L .31976 .63284 L F
.843 .773 .784 r
.47932 .48966 m .47586 .4894 L .47738 .48809 L F
.852 .78 .781 r
.47932 .48966 m .47471 .49171 L .47586 .4894 L F
.47932 .48966 m .47684 .49301 L .47471 .49171 L F
.819 .778 .814 r
.48219 .48628 m .47932 .48966 L .47738 .48809 L F
.727 .916 .56 r
.35206 .65285 m .35142 .65446 L .35378 .65104 L F
.68 .798 .337 r
.35013 .65719 m .35142 .65446 L .35206 .65285 L F
.674 .639 .807 r
.34192 .62429 m .34469 .62776 L .34128 .627 L F
0 .509 .791 r
.41188 .56623 m .41428 .56667 L .41596 .56731 L F
.702 .981 .898 r
.41596 .56731 m .41649 .56547 L .41812 .56559 L F
.613 .922 .974 r
.41596 .56731 m .41428 .56667 L .41649 .56547 L F
0 .167 .706 r
.3436 .62427 m .34377 .62625 L .34192 .62429 L F
.819 .705 .168 r
.34357 .62549 m .34377 .62625 L .3436 .62427 L F
0 .063 .604 r
.34377 .62625 m .34392 .6268 L .34192 .62429 L F
.819 .705 .168 r
.34349 .62878 m .34377 .62625 L .34357 .62549 L F
0 .063 .604 r
.34377 .62625 m .34469 .62776 L .34392 .6268 L F
.674 .14 0 r
.34349 .62878 m .34469 .62776 L .34377 .62625 L F
.34349 .62878 m .34716 .6299 L .34469 .62776 L F
.305 0 0 r
.50628 .4577 m .50909 .45767 L .5107 .45634 L F
.615 .85 .479 r
.5107 .45634 m .51208 .45431 L .51339 .45278 L F
.653 .91 .597 r
.5107 .45634 m .50909 .45767 L .51208 .45431 L F
.543 .224 .377 r
.56418 .35414 m .56804 .35413 L .56824 .35177 L F
.588 .262 .383 r
.56824 .35177 m .56804 .35413 L .57114 .3538 L F
.699 .514 .634 r
.53677 .38533 m .5397 .3853 L .53974 .38208 L F
.455 .315 .601 r
.53974 .38208 m .54259 .38419 L .54405 .38366 L F
.53974 .38208 m .5397 .3853 L .54259 .38419 L F
.734 .592 .698 r
.43277 .54389 m .43182 .54625 L .43245 .54382 L F
.372 .775 .984 r
.50165 .4326 m .50495 .4323 L .50301 .43138 L F
.84 .757 .771 r
.31494 .57606 m .31239 .57962 L .31633 .57949 L F
.924 .777 .679 r
.3776 .56932 m .37634 .57333 L .37858 .57355 L F
.585 .019 0 r
.37634 .57333 m .37667 .57401 L .37858 .57355 L F
.089 0 0 r
.37667 .57401 m .38117 .57308 L .37858 .57355 L F
0 .235 .747 r
.28258 .66081 m .28541 .66454 L .28423 .66323 L F
0 0 .558 r
.28298 .6592 m .28258 .66081 L .28423 .66323 L F
.907 .813 .743 r
.48964 .47575 m .48576 .47806 L .48828 .47442 L F
.48964 .47575 m .48769 .47955 L .48576 .47806 L F
.925 .909 .787 r
.49195 .47157 m .48964 .47575 L .48828 .47442 L F
.925 .605 .417 r
.30049 .58341 m .30258 .58945 L .29833 .58533 L F
.911 .749 .667 r
.2993 .58021 m .30049 .58341 L .29812 .58243 L F
.629 .615 .818 r
.53092 .35803 m .52747 .356 L .52917 .35412 L F
.072 0 .085 r
.53245 .35919 m .53092 .35803 L .53351 .35748 L F
.53245 .35919 m .53034 .36046 L .53092 .35803 L F
.837 .984 .871 r
.33777 .66116 m .34214 .65898 L .34393 .65705 L F
0 0 .549 r
.34214 .65898 m .34336 .66 L .34393 .65705 L F
.827 .616 .617 r
.31267 .53863 m .31737 .53638 L .31295 .536 L F
.31267 .53863 m .31503 .53936 L .31737 .53638 L F
.812 .592 .604 r
.31503 .53936 m .31932 .54008 L .31737 .53638 L F
.835 .643 .643 r
.57147 .36721 m .57442 .36652 L .574 .3646 L F
.927 .911 .784 r
.53689 .45206 m .53483 .45523 L .53629 .45638 L F
.961 .816 .655 r
.53372 .45769 m .53629 .45638 L .53483 .45523 L F
.53372 .45769 m .53539 .45914 L .53629 .45638 L F
.311 .129 .465 r
.26429 .56337 m .26647 .55975 L .26414 .56072 L F
.638 .386 .522 r
.44178 .54015 m .437 .54357 L .43954 .53885 L F
.44178 .54015 m .44137 .54434 L .437 .54357 L F
.093 .578 .904 r
.64785 .33833 m .65295 .33992 L .64918 .33929 L F
.814 .999 .842 r
.53856 .42829 m .53693 .43029 L .53479 .43071 L F
0 0 .462 r
.55003 .41224 m .55163 .41188 L .5472 .412 L F
.55003 .41224 m .55147 .41402 L .55163 .41188 L F
.55003 .41224 m .55038 .41501 L .55147 .41402 L F
0 0 .094 r
.52452 .37826 m .52486 .38133 L .52484 .38142 L F
.958 .694 .492 r
.57114 .3538 m .57325 .35732 L .57159 .35567 L F
.895 .876 .809 r
.64047 .37439 m .63615 .37783 L .63915 .37485 L F
.678 .327 0 r
.64047 .37439 m .63996 .37331 L .63935 .37176 L F
.93 .972 .726 r
.64047 .37439 m .63915 .37485 L .63996 .37331 L F
.496 .234 .446 r
.35028 .52637 m .35348 .52328 L .35022 .52325 L F
.35028 .52637 m .35326 .52582 L .35348 .52328 L F
.765 .467 .481 r
.35348 .52328 m .35326 .52582 L .35714 .52604 L F
0 0 0 r
.49127 .42112 m .48813 .42175 L .48859 .42167 L F
.736 .588 .014 r
.36941 .57689 m .36935 .57869 L .36781 .57562 L F
.36941 .57689 m .36943 .57927 L .36935 .57869 L F
.591 .018 0 r
.29965 .64423 m .29579 .64267 L .29802 .64331 L F
.445 0 0 r
.29368 .64296 m .29802 .64331 L .29579 .64267 L F
.531 .831 .999 r
.29611 .64223 m .29802 .64331 L .29368 .64296 L F
.29615 .64222 m .29802 .64331 L .29611 .64223 L F
.591 .018 0 r
.29994 .64434 m .29965 .64423 L .29802 .64331 L F
0 0 0 r
.50394 .39522 m .50593 .3942 L .50615 .39395 L F
.50394 .39522 m .50417 .39502 L .50593 .3942 L F
.50394 .39522 m .50276 .39693 L .50417 .39502 L F
.558 .157 .239 r
.30681 .567 m .30922 .56886 L .30523 .56891 L F
.829 .553 .005 r
.51339 .45278 m .51279 .45136 L .51226 .44841 L F
.973 .867 .479 r
.51339 .45278 m .51208 .45431 L .51279 .45136 L F
.578 .404 .61 r
.50053 .4425 m .50335 .44203 L .50343 .43929 L F
.85 .938 .881 r
.6215 .34611 m .62572 .34459 L .62485 .34389 L F
.6215 .34611 m .62229 .34749 L .62572 .34459 L F
.598 .63 .854 r
.30554 .57659 m .30169 .5736 L .30483 .57317 L F
.707 .597 .73 r
.30825 .57336 m .30554 .57659 L .30483 .57317 L F
.474 .478 .782 r
.40363 .48218 m .39987 .47947 L .40208 .47859 L F
.40363 .48218 m .40305 .48411 L .39987 .47947 L F
.666 .162 .04 r
.28888 .59821 m .2876 .59906 L .28988 .59813 L F
.398 .229 .532 r
.27732 .54334 m .27727 .54597 L .28007 .54489 L F
.925 .907 .512 r
.63673 .37103 m .63625 .36979 L .63648 .36897 L F
.854 .986 .853 r
.64013 .36684 m .63673 .37103 L .63648 .36897 L F
.425 .804 .992 r
.63935 .37176 m .63625 .36979 L .63673 .37103 L F
.633 .178 .153 r
.63935 .37176 m .63478 .37297 L .63625 .36979 L F
.63935 .37176 m .63728 .3735 L .63478 .37297 L F
.627 .169 .147 r
.63935 .37176 m .63996 .37331 L .63728 .3735 L F
.032 0 0 r
.44455 .44254 m .44046 .44514 L .44274 .44405 L F
0 0 0 r
.44647 .44131 m .44455 .44254 L .44274 .44405 L F
.5957 .38697 m .59429 .38956 L .59636 .38535 L F
0 0 .277 r
.59527 .38984 m .59429 .38956 L .5957 .38697 L F
.59527 .38984 m .59429 .39161 L .59429 .38956 L F
.888 .818 .342 r
.42032 .55999 m .41943 .56171 L .41986 .55902 L F
.721 .976 .922 r
.42089 .55762 m .42032 .55999 L .41986 .55902 L F
.42089 .55762 m .42423 .55755 L .42032 .55999 L F
.016 0 0 r
.4497 .43846 m .44752 .43966 L .44647 .44131 L F
.828 .489 .415 r
.55409 .37821 m .55604 .3815 L .55135 .38023 L F
.483 .9 .862 r
.52747 .356 m .52787 .35493 L .52917 .35412 L F
.52747 .356 m .52508 .35617 L .52787 .35493 L F
.785 .592 .64 r
.37249 .54647 m .36721 .55049 L .36843 .54615 L F
0 0 0 r
.37354 .5421 m .37249 .54647 L .37243 .54424 L F
0 0 .387 r
.37349 .54766 m .37249 .54647 L .37285 .54525 L F
.37349 .54766 m .37373 .55024 L .37249 .54647 L F
.191 .342 .787 r
.52812 .38967 m .53018 .39098 L .52868 .38689 L F
.504 0 0 r
.52835 .3899 m .53018 .39098 L .52812 .38967 L F
.819 .778 .814 r
.48219 .48628 m .47738 .48809 L .48071 .48529 L F
.911 .927 .811 r
.48219 .48628 m .48327 .48161 L .48481 .48287 L F
.48219 .48628 m .48071 .48529 L .48327 .48161 L F
.826 .925 .9 r
.41146 .58578 m .41605 .58398 L .41442 .58256 L F
0 0 0 r
.60507 .34475 m .60672 .34345 L .60805 .34448 L F
.60507 .34475 m .60408 .34649 L .60672 .34345 L F
.782 .898 .924 r
.48441 .50411 m .48909 .50295 L .48768 .50185 L F
.837 .939 .893 r
.48909 .50295 m .49075 .49894 L .48768 .50185 L F
.48909 .50295 m .49226 .49989 L .49075 .49894 L F
.925 .909 .787 r
.49195 .47157 m .48828 .47442 L .49152 .47173 L F
.082 .142 .627 r
.57325 .35732 m .57519 .35976 L .57362 .36171 L F
.312 .321 .709 r
.57519 .35976 m .574 .3646 L .57362 .36171 L F
.889 .782 .737 r
.43036 .5425 m .43182 .54625 L .42977 .54481 L F
.832 .661 .67 r
.43182 .54625 m .42719 .54884 L .42977 .54481 L F
.43182 .54625 m .42986 .54975 L .42719 .54884 L F
.862 .773 .762 r
.43245 .54382 m .43182 .54625 L .43036 .5425 L F
.739 .493 .558 r
.30474 .52902 m .30857 .52933 L .30882 .5265 L F
0 0 .551 r
.58413 .37508 m .5845 .37324 L .58298 .37112 L F
0 0 .56 r
.58413 .37508 m .58585 .37756 L .5845 .37324 L F
.639 .846 .453 r
.39542 .57219 m .39715 .56954 L .39853 .57155 L F
.475 0 0 r
.39996 .57286 m .39853 .57155 L .39715 .56954 L F
.513 .82 1 r
.58857 .43218 m .59295 .43269 L .59144 .43118 L F
.58857 .43218 m .59295 .43269 L .59144 .43118 L F
0 0 .129 r
.5128 .41535 m .51427 .41442 L .51552 .41192 L F
.938 .965 .726 r
.54807 .43032 m .54836 .43294 L .55034 .42935 L F
.831 1 .803 r
.55034 .42935 m .55332 .42615 L .55111 .42682 L F
.835 .998 .774 r
.54807 .43032 m .55034 .42935 L .55111 .42682 L F
.798 .701 .759 r
.30167 .59337 m .30595 .59368 L .30431 .58976 L F
.872 .743 .717 r
.31881 .56255 m .32048 .56634 L .32113 .56374 L F
.837 .513 .44 r
.36992 .53545 m .37247 .53859 L .37405 .53647 L F
.849 .53 .448 r
.37247 .53859 m .37455 .53941 L .37405 .53647 L F
.715 .865 .953 r
.27892 .55539 m .28329 .55541 L .28149 .55446 L F
.041 0 0 r
.28502 .55315 m .28149 .55446 L .28329 .55541 L F
.534 .27 .461 r
.36143 .52952 m .36421 .52908 L .3646 .52649 L F
.445 .078 .247 r
.36421 .52908 m .36838 .5262 L .3646 .52649 L F
.968 .675 .419 r
.50826 .40422 m .5102 .40532 L .5088 .40224 L F
0 .042 .608 r
.51074 .40371 m .5102 .40532 L .50826 .40422 L F
.51074 .40371 m .51185 .40744 L .5102 .40532 L F
.727 .678 .803 r
.41287 .57307 m .41424 .57352 L .41418 .57301 L F
.863 .989 .723 r
.41453 .57158 m .41287 .57307 L .41544 .57295 L F
.41453 .57158 m .41224 .57576 L .41287 .57307 L F
.41409 .57237 m .41152 .57527 L .41224 .57576 L F
.41453 .57158 m .41407 .57215 L .41409 .57237 L F
.41407 .57215 m .41152 .57527 L .41409 .57237 L F
.727 .678 .803 r
.41418 .57301 m .41748 .57456 L .41544 .57295 L F
.41424 .57352 m .41748 .57456 L .41418 .57301 L F
.643 .843 .977 r
.41544 .57295 m .41748 .57456 L .41958 .57346 L F
.057 0 .057 r
.44033 .45595 m .43995 .458 L .43722 .4591 L F
.068 0 .06 r
.44175 .45703 m .44033 .45595 L .44275 .45486 L F
.44175 .45703 m .43995 .458 L .44033 .45595 L F
.041 0 0 r
.28502 .55315 m .28384 .55411 L .28149 .55446 L F
.591 .871 .548 r
.28658 .55113 m .28384 .55411 L .28502 .55315 L F
.619 .788 .962 r
.28502 .55315 m .2891 .55239 L .28915 .55009 L F
.774 .88 .924 r
.64637 .38105 m .65061 .38097 L .64993 .38015 L F
.498 .884 .964 r
.64993 .38015 m .65061 .38097 L .65322 .37984 L F
0 0 0 r
.41535 .47505 m .41246 .47823 L .41369 .47649 L F
.988 .868 .624 r
.45389 .52502 m .45276 .52456 L .45495 .52308 L F
.745 .971 .703 r
.45495 .52308 m .45276 .52456 L .45582 .52115 L F
.51 .786 .995 r
.45582 .52115 m .45772 .52249 L .45495 .52308 L F
.719 .971 .728 r
.4529 .52723 m .45001 .53017 L .45099 .5283 L F
.709 .986 .852 r
.45001 .53017 m .4475 .53083 L .45099 .5283 L F
.859 .962 .627 r
.29993 .57688 m .29987 .57532 L .30169 .5736 L F
.955 .94 .725 r
.29978 .57825 m .29987 .57532 L .29993 .57688 L F
.688 .543 .684 r
.50343 .43929 m .50559 .43902 L .50622 .43582 L F
.959 .667 .438 r
.35206 .65285 m .35378 .65104 L .35175 .64982 L F
.714 .857 .435 r
.55426 .4239 m .55332 .42615 L .55542 .42228 L F
.872 .912 .854 r
.55542 .42228 m .5569 .41756 L .55563 .41958 L F
.55542 .42228 m .55825 .41901 L .5569 .41756 L F
.866 .878 .441 r
.55426 .4239 m .55542 .42228 L .55563 .41958 L F
.77 .996 .815 r
.55111 .42682 m .55332 .42615 L .55426 .4239 L F
.92 .781 .691 r
.38626 .55201 m .38978 .54929 L .38643 .54911 L F
.38626 .55201 m .38894 .55362 L .38978 .54929 L F
.311 .129 .465 r
.26429 .56337 m .26636 .56271 L .26647 .55975 L F
.349 .225 .567 r
.26429 .56337 m .26645 .56551 L .26636 .56271 L F
.406 .228 .525 r
.26417 .56617 m .26645 .56551 L .26429 .56337 L F
.687 .974 .784 r
.33642 .6659 m .33861 .66518 L .33573 .6674 L F
.079 0 0 r
.34028 .66537 m .33861 .66518 L .33642 .6659 L F
.34028 .66537 m .34129 .66378 L .33861 .66518 L F
.887 .498 .289 r
.42176 .57565 m .42059 .57641 L .42173 .57445 L F
.42059 .57641 m .42026 .57663 L .4206 .57613 L F
.42059 .57641 m .4206 .57613 L .42173 .57445 L F
.801 .6 .039 r
.42173 .57445 m .42176 .57565 L .42156 .57455 L F
.348 0 0 r
.42192 .57434 m .42173 .57445 L .41958 .57346 L F
.801 .6 .039 r
.42173 .57445 m .42145 .57393 L .4212 .57428 L F
.42173 .57445 m .42156 .57455 L .42145 .57393 L F
.5 0 0 r
.42173 .57445 m .41808 .57185 L .41958 .57346 L F
.348 0 0 r
.42443 .57529 m .42173 .57445 L .42192 .57434 L F
.678 .305 .332 r
.4272 .57331 m .42173 .57445 L .42443 .57529 L F
.4272 .57331 m .42176 .57565 L .42173 .57445 L F
.839 .964 .886 r
.42599 .57234 m .42176 .57565 L .4272 .57331 L F
.5 0 0 r
.42099 .57393 m .4212 .57428 L .41808 .57185 L F
.42173 .57445 m .4212 .57428 L .42099 .57393 L F
.87 .706 .677 r
.42145 .57393 m .42125 .57437 L .4212 .57428 L F
.907 .883 .458 r
.42173 .57445 m .42026 .57663 L .4212 .57428 L F
.42173 .57445 m .42026 .57663 L .4212 .57428 L F
.87 .706 .677 r
.42125 .57437 m .42026 .57663 L .4212 .57428 L F
.848 .93 .882 r
.42145 .57393 m .42176 .57565 L .42599 .57234 L F
0 0 .173 r
.42233 .57532 m .42058 .57698 L .42145 .57393 L F
.42058 .57698 m .42052 .57704 L .42058 .57682 L F
.42058 .57698 m .42058 .57682 L .42145 .57393 L F
.652 .774 .306 r
.3072 .63048 m .30891 .62677 L .30948 .63008 L F
.639 .846 .453 r
.39542 .57219 m .39494 .57281 L .39715 .56954 L F
.866 .908 .858 r
.48769 .47955 m .48481 .48287 L .48327 .48161 L F
0 0 0 r
.47393 .41951 m .47266 .42037 L .47162 .42236 L F
.551 .878 .607 r
.47266 .42037 m .47579 .41758 L .47436 .41912 L F
0 0 0 r
.47454 .41876 m .47266 .42037 L .47393 .41951 L F
.47436 .41912 m .47121 .42136 L .47266 .42037 L F
.47121 .42136 m .47068 .42174 L .47266 .42037 L F
.53381 .39663 m .53247 .39842 L .53238 .39805 L F
.831 .682 .697 r
.47684 .49301 m .47232 .49521 L .47471 .49171 L F
.47684 .49301 m .47631 .49573 L .47232 .49521 L F
.981 .698 .401 r
.3835 .55546 m .38521 .55674 L .38369 .55828 L F
0 0 0 r
.38369 .55828 m .38521 .55674 L .38762 .55585 L F
.149 .238 .701 r
.43598 .55199 m .4378 .55428 L .43994 .55277 L F
.43598 .55199 m .43665 .55584 L .4378 .55428 L F
.911 .752 .671 r
.31808 .56512 m .32048 .56634 L .31881 .56255 L F
.887 .785 .742 r
.31591 .56873 m .32048 .56634 L .31808 .56512 L F
.31591 .56873 m .31804 .56999 L .32048 .56634 L F
.962 .666 .246 r
.35217 .56661 m .35096 .56569 L .35065 .56266 L F
.957 .636 .374 r
.35217 .56661 m .35089 .56743 L .35096 .56569 L F
.35217 .56661 m .35258 .57015 L .35089 .56743 L F
.834 .739 .76 r
.35324 .56411 m .35217 .56661 L .35065 .56266 L F
0 .171 .633 r
.54593 .40759 m .54302 .40533 L .54407 .40784 L F
.16 .596 .935 r
.54708 .40692 m .54593 .40759 L .54407 .40784 L F
.54708 .40692 m .54846 .40817 L .54593 .40759 L F
.766 .539 .589 r
.27021 .59021 m .26618 .59244 L .26876 .59015 L F
.27021 .59021 m .26988 .59336 L .26618 .59244 L F
.707 .984 .886 r
.27021 .59021 m .26876 .59015 L .27074 .58851 L F
0 .037 .599 r
.27074 .58851 m .27182 .59134 L .27021 .59021 L F
.065 0 .39 r
.27182 .59134 m .26988 .59336 L .27021 .59021 L F
0 0 .034 r
.43598 .55199 m .43862 .54909 L .4367 .55032 L F
.072 0 .035 r
.43484 .46129 m .43722 .4591 L .43699 .46079 L F
.106 0 .221 r
.43995 .458 m .43699 .46079 L .43722 .4591 L F
.431 .164 .407 r
.43862 .54909 m .44164 .54602 L .43916 .5468 L F
.792 .756 .82 r
.36791 .53138 m .37275 .53007 L .37075 .52865 L F
.878 .85 .812 r
.37075 .52865 m .37275 .53007 L .37524 .52644 L F
.763 .662 .751 r
.31797 .68396 m .3222 .68465 L .32109 .68041 L F
.534 .54 .807 r
.3222 .68465 m .32319 .68003 L .32109 .68041 L F
.3222 .68465 m .32486 .68413 L .32319 .68003 L F
0 .081 .63 r
.28858 .65083 m .2899 .65346 L .28757 .6542 L F
.555 .547 .801 r
.54682 .38486 m .54405 .38366 L .54654 .38189 L F
.331 .801 .706 r
.54405 .38366 m .54507 .38308 L .54654 .38189 L F
.538 .443 .695 r
.54904 .38076 m .54682 .38486 L .54654 .38189 L F
0 0 0 r
.54507 .38308 m .54904 .38076 L .54654 .38189 L F
.908 .68 .581 r
.33661 .52639 m .33425 .52594 L .33473 .52263 L F
.853 .458 .293 r
.33661 .52639 m .33466 .528 L .33425 .52594 L F
.915 .567 .367 r
.33677 .52871 m .33466 .528 L .33661 .52639 L F
.677 .486 .621 r
.50335 .44203 m .50559 .43902 L .50343 .43929 L F
0 .479 .771 r
.66956 .36057 m .67289 .36151 L .67164 .36171 L F
0 0 0 r
.47823 .43033 m .47996 .42935 L .48275 .42823 L F
.696 .883 .967 r
.6215 .34611 m .61912 .34766 L .62229 .34749 L F
.811 .703 .746 r
.61912 .34766 m .61866 .34968 L .62229 .34749 L F
.833 .629 .627 r
.31503 .53936 m .31878 .54297 L .31932 .54008 L F
.74 .484 .542 r
.32929 .60956 m .33266 .60828 L .32985 .60692 L F
.32929 .60956 m .33464 .61063 L .33266 .60828 L F
.331 .801 .706 r
.54405 .38366 m .54259 .38419 L .54507 .38308 L F
.927 .826 .726 r
.52843 .4646 m .53182 .46227 L .53068 .46094 L F
.52843 .4646 m .53027 .46589 L .53182 .46227 L F
.827 .93 .9 r
.53068 .46094 m .53182 .46227 L .53539 .45914 L F
.938 .965 .725 r
.54687 .43514 m .54836 .43294 L .54807 .43032 L F
.812 .877 .893 r
.61247 .35055 m .61391 .35214 L .61598 .35049 L F
.672 .706 .873 r
.30718 .5701 m .30825 .57336 L .30483 .57317 L F
.591 .17 .212 r
.39583 .54254 m .39759 .54469 L .39872 .54235 L F
.178 0 0 r
.34851 .63734 m .35312 .63809 L .35138 .63838 L F
.34851 .63734 m .35133 .63795 L .35312 .63809 L F
.261 .755 .908 r
.35133 .63795 m .3549 .63829 L .35312 .63809 L F
.2 .672 .938 r
.38832 .57152 m .39059 .57164 L .39241 .57254 L F
.236 0 0 r
.43484 .46129 m .43302 .46378 L .43034 .46441 L F
.325 0 .076 r
.43699 .46079 m .43302 .46378 L .43484 .46129 L F
0 0 0 r
.54673 .41526 m .5472 .412 L .54646 .41416 L F
.86 .988 .719 r
.54551 .41559 m .54673 .41526 L .54646 .41416 L F
.482 .512 .812 r
.54137 .38713 m .54259 .38419 L .5397 .3853 L F
.54137 .38713 m .54388 .38786 L .54259 .38419 L F
.17 0 0 r
.59389 .34454 m .59697 .34383 L .59725 .34245 L F
.304 0 0 r
.59725 .34245 m .59697 .34383 L .59987 .343 L F
.829 .977 .885 r
.64228 .36903 m .63918 .37094 L .64341 .36708 L F
.559 .476 .718 r
.28314 .53969 m .28542 .5365 L .2826 .53681 L F
.752 .667 .767 r
.30483 .57317 m .30169 .5736 L .30367 .57045 L F
.672 .706 .873 r
.30718 .5701 m .30483 .57317 L .30367 .57045 L F
0 0 .211 r
.51977 .3937 m .5177 .39752 L .52098 .3972 L F
.502 .686 .95 r
.29621 .67112 m .29886 .67402 L .30127 .67355 L F
.878 .85 .812 r
.37075 .52865 m .37524 .52644 L .37099 .52639 L F
.857 .683 .665 r
.34618 .52517 m .35022 .52325 L .34837 .52216 L F
.34618 .52517 m .35028 .52637 L .35022 .52325 L F
.835 .808 .319 r
.2993 .56321 m .30032 .55851 L .29836 .56014 L F
.901 .971 .664 r
.59189 .39843 m .59354 .39394 L .59351 .39654 L F
0 0 0 r
.38523 .48453 m .3828 .48618 L .38402 .48513 L F
.834 .549 .507 r
.35326 .52582 m .35832 .52845 L .35714 .52604 L F
.35757 .52806 m .35794 .52844 L .35832 .52845 L F
.852 .723 .72 r
.35273 .52831 m .35435 .53226 L .35794 .52882 L F
.35794 .52844 m .35794 .52882 L .35832 .52845 L F
.35273 .52831 m .35794 .52882 L .35794 .52844 L F
.769 .558 .613 r
.35435 .53226 m .35844 .52978 L .35832 .52845 L F
.668 .573 .739 r
.35795 .52669 m .35799 .52849 L .36143 .52952 L F
.35714 .52604 m .35794 .52834 L .35795 .52669 L F
.866 .671 .636 r
.35832 .52845 m .35844 .52978 L .35714 .52604 L F
.668 .573 .739 r
.35794 .52834 m .35799 .52849 L .35795 .52669 L F
.35799 .52849 m .35844 .52978 L .35917 .52972 L F
.35799 .52849 m .35917 .52972 L .36143 .52952 L F
.834 .549 .507 r
.35326 .52582 m .35273 .52831 L .35794 .52844 L F
.35326 .52582 m .35794 .52844 L .35757 .52806 L F
.681 .367 .437 r
.43255 .53277 m .43149 .53476 L .42857 .53309 L F
0 0 .345 r
.43421 .52891 m .43401 .53182 L .43255 .53277 L F
.69 .683 .838 r
.43401 .53182 m .43149 .53476 L .43255 .53277 L F
.586 .125 .125 r
.31569 .63272 m .31755 .63123 L .31976 .63284 L F
.566 .903 .978 r
.31755 .63123 m .3204 .63007 L .31976 .63284 L F
.868 .591 .517 r
.34628 .53977 m .34298 .53901 L .34301 .53616 L F
.897 .635 .533 r
.34597 .54259 m .34298 .53901 L .34628 .53977 L F
.571 .636 .877 r
.31538 .64887 m .31477 .65156 L .31346 .65043 L F
.31538 .64887 m .31791 .65076 L .31477 .65156 L F
.599 .038 0 r
.62355 .3389 m .62459 .338 L .62332 .33635 L F
.445 .078 .247 r
.36421 .52908 m .36669 .5291 L .36838 .5262 L F
.659 .311 .371 r
.36838 .5262 m .36669 .5291 L .37075 .52865 L F
.641 .314 .403 r
.36838 .5262 m .37075 .52865 L .37099 .52639 L F
.644 .544 .727 r
.57413 .38148 m .56951 .37886 L .57389 .37866 L F
.57413 .38148 m .571 .38214 L .56951 .37886 L F
.994 .872 .591 r
.31698 .61655 m .31701 .62021 L .31428 .61606 L F
.833 .991 .735 r
.67528 .36452 m .67216 .36731 L .67275 .36812 L F
.844 .865 .417 r
.51127 .38741 m .51111 .38664 L .51214 .38518 L F
.725 .852 .42 r
.51214 .38518 m .51111 .38664 L .51311 .38271 L F
.881 .652 .588 r
.32004 .55251 m .32201 .55651 L .32243 .55334 L F
.856 .93 .875 r
.45931 .53209 m .46074 .53322 L .46373 .52992 L F
.832 .685 .7 r
.46028 .51901 m .4588 .515 L .46072 .51631 L F
.834 .839 .85 r
.4632 .51323 m .46072 .51631 L .4588 .515 L F
0 0 .069 r
.55825 .41901 m .55911 .41339 L .5569 .41756 L F
.847 .515 .424 r
.34244 .5188 m .34472 .52174 L .34484 .51961 L F
0 .024 .563 r
.67289 .36151 m .67484 .36368 L .67528 .36452 L F
.67484 .36368 m .67493 .36377 L .67497 .36385 L F
.67484 .36368 m .67497 .36385 L .67528 .36452 L F
0 .13 .676 r
.67388 .36154 m .67493 .36377 L .67289 .36151 L F
.873 .872 .833 r
.67216 .36731 m .67372 .36209 L .67065 .36573 L F
.67372 .36209 m .67388 .36154 L .6736 .36192 L F
.67372 .36209 m .6736 .36192 L .67065 .36573 L F
.833 .991 .735 r
.67528 .36452 m .67493 .36377 L .67216 .36731 L F
.583 .837 .993 r
.40481 .58826 m .40203 .58943 L .40599 .58986 L F
.794 .692 .752 r
.40203 .58943 m .4022 .59391 L .40599 .58986 L F
.117 .667 .723 r
.40968 .58764 m .40481 .58826 L .40599 .58986 L F
.154 .257 .718 r
.39325 .54696 m .39579 .5477 L .39479 .54516 L F
.854 .609 .568 r
.37836 .55379 m .38101 .55326 L .37811 .55271 L F
.37836 .55379 m .38092 .55609 L .38101 .55326 L F
.635 .518 .703 r
.38101 .55326 m .38456 .55329 L .38347 .55005 L F
.595 .276 .4 r
.38101 .55326 m .3835 .55546 L .38456 .55329 L F
.853 .911 .873 r
.52442 .43944 m .5217 .44255 L .52096 .43923 L F
.982 .908 .602 r
.52096 .43923 m .5217 .44255 L .52086 .4415 L F
.772 .704 .788 r
.43291 .53905 m .43245 .54382 L .43036 .5425 L F
.5 .23 .437 r
.57086 .38413 m .57413 .38148 L .571 .38214 L F
.57086 .38413 m .57413 .38148 L .571 .38214 L F
.262 .099 .462 r
.59851 .38383 m .59636 .38535 L .59886 .38122 L F
0 0 .003 r
.59851 .38383 m .5957 .38697 L .59636 .38535 L F
.686 .491 .617 r
.40363 .48218 m .40161 .48345 L .40305 .48411 L F
.977 .873 .666 r
.38617 .55491 m .38894 .55362 L .38626 .55201 L F
.38617 .55491 m .38762 .55585 L .38894 .55362 L F
.834 .962 .631 r
.45056 .54196 m .44822 .54561 L .44866 .54566 L F
.817 .738 .777 r
.47631 .49573 m .4735 .49904 L .47232 .49521 L F
.593 .462 .671 r
.5768 .37801 m .57495 .3742 L .57539 .37399 L F
.5768 .37801 m .57389 .37866 L .57495 .3742 L F
.404 .144 .403 r
.36729 .55623 m .36977 .55566 L .36937 .55362 L F
.777 .491 0 r
.36877 .55202 m .36977 .55566 L .36937 .55362 L F
.691 .747 .895 r
.30613 .55472 m .30809 .55655 L .30384 .55591 L F
.967 .817 .643 r
.36732 .55941 m .36538 .56291 L .36796 .56351 L F
.979 .841 .445 r
.36598 .56642 m .36796 .56351 L .3683 .566 L F
.36598 .56642 m .36538 .56291 L .36796 .56351 L F
.776 .708 .788 r
.36732 .55941 m .36796 .56351 L .37112 .55932 L F
0 0 0 r
.54194 .34541 m .54321 .3455 L .54496 .34685 L F
.54194 .34541 m .54096 .34687 L .54321 .3455 L F
.827 .558 .532 r
.43048 .51967 m .43005 .52208 L .42632 .52231 L F
.486 .161 .341 r
.43273 .51957 m .43005 .52208 L .43048 .51967 L F
.769 .558 .613 r
.35435 .53226 m .3586 .53268 L .35844 .52978 L F
.654 .469 .622 r
.35844 .52978 m .3586 .53268 L .36143 .52952 L F
0 0 0 r
.37373 .55024 m .37508 .54887 L .37635 .55066 L F
.757 .245 0 r
.37583 .55156 m .37635 .55066 L .37508 .54887 L F
.838 .557 .512 r
.37811 .55271 m .37785 .5521 L .37635 .55066 L F
.423 0 0 r
.39939 .59 m .39783 .58916 L .39594 .58796 L F
.884 .958 .844 r
.39974 .58633 m .39939 .59 L .40203 .58943 L F
.39974 .58633 m .39783 .58916 L .39939 .59 L F
.833 .995 .848 r
.52079 .38281 m .52015 .38556 L .52067 .38422 L F
.31 .284 .668 r
.52079 .38281 m .5191 .38777 L .52015 .38556 L F
0 0 0 r
.59143 .34912 m .58851 .352 L .59146 .35012 L F
.512 .043 .079 r
.5874 .35033 m .59146 .35012 L .58851 .352 L F
.327 0 0 r
.59007 .35059 m .59147 .35036 L .59146 .35012 L F
.59147 .35036 m .59418 .34992 L .59146 .35012 L F
0 0 0 r
.59192 .34864 m .59143 .34912 L .59146 .35012 L F
.743 .406 .413 r
.37373 .55024 m .36877 .55202 L .36721 .55049 L F
.37373 .55024 m .37285 .55243 L .36877 .55202 L F
0 0 0 r
.37508 .54887 m .37373 .55024 L .37349 .54766 L F
.37508 .54887 m .37285 .55243 L .37373 .55024 L F
.37373 .55024 m .37285 .55243 L .37508 .54887 L F
.359 .792 .613 r
.40437 .46872 m .40028 .47111 L .40322 .47127 L F
.356 .001 .217 r
.40322 .47127 m .40685 .46783 L .40437 .46872 L F
.585 .434 .642 r
.5768 .37801 m .57413 .38148 L .57389 .37866 L F
.557 .934 .86 r
.638 .38859 m .63908 .38883 L .64168 .38723 L F
.405 .117 .359 r
.54904 .38076 m .55203 .37778 L .54923 .3784 L F
.54904 .38076 m .55203 .37778 L .54923 .3784 L F
0 0 .294 r
.5788 .38777 m .57927 .39052 L .57862 .39001 L F
0 0 .341 r
.57962 .38425 m .58011 .38632 L .5788 .38777 L F
0 0 .281 r
.58011 .38632 m .57927 .39052 L .5788 .38777 L F
.638 .875 .986 r
.52301 .43458 m .51996 .4361 L .51798 .43511 L F
.51798 .43511 m .51996 .4361 L .52301 .43458 L F
0 0 0 r
.49534 .4195 m .49797 .41851 L .49375 .42041 L F
.837 .984 .871 r
.33777 .66116 m .34393 .65705 L .34336 .66 L F
.505 .22 .415 r
.34619 .65952 m .34393 .65705 L .34336 .66 L F
.34619 .65952 m .3472 .65693 L .34393 .65705 L F
.34393 .65705 m .34619 .65952 L .34336 .66 L F
.34393 .65705 m .3472 .65693 L .34619 .65952 L F
.85 .503 .397 r
.34618 .52517 m .34826 .52824 L .35028 .52637 L F
.598 .155 .169 r
.35028 .52637 m .34826 .52824 L .35273 .52831 L F
.489 .215 .425 r
.35028 .52637 m .35273 .52831 L .35326 .52582 L F
.812 .877 .893 r
.61247 .35055 m .61598 .35049 L .6148 .34895 L F
.801 .9 .912 r
.6148 .34895 m .61598 .35049 L .61912 .34766 L F
.651 .704 .886 r
.61598 .35049 m .61866 .34968 L .61912 .34766 L F
.56 .923 .753 r
.48228 .42551 m .48582 .42317 L .48452 .42366 L F
.465 .875 .733 r
.48452 .42366 m .48582 .42317 L .48813 .42175 L F
.829 .841 .857 r
.52199 .40339 m .52675 .4026 L .52485 .40261 L F
.52199 .40339 m .52352 .40527 L .52675 .4026 L F
.431 0 0 r
.52886 .40102 m .52485 .40261 L .52675 .4026 L F
.714 .229 .091 r
.38501 .5609 m .38925 .56271 L .38665 .56356 L F
.316 .784 .67 r
.38743 .56315 m .38665 .56356 L .38925 .56271 L F
.38743 .56315 m .38656 .56352 L .38665 .56356 L F
.866 .908 .858 r
.48769 .47955 m .48327 .48161 L .48576 .47806 L F
.019 .592 .733 r
.3828 .48618 m .3782 .4861 L .37865 .48708 L F
0 0 0 r
.3793 .4863 m .37866 .48651 L .3782 .4861 L F
0 0 .453 r
.37787 .48581 m .37865 .48708 L .3782 .4861 L F
0 0 0 r
.37866 .48651 m .37682 .48713 L .3782 .4861 L F
0 0 .453 r
.37743 .48509 m .37787 .48581 L .3782 .4861 L F
.793 .724 .787 r
.43994 .55277 m .43862 .54909 L .43598 .55199 L F
.766 .819 .894 r
.43994 .55277 m .44127 .54849 L .43862 .54909 L F
.43994 .55277 m .44311 .55008 L .44127 .54849 L F
.436 .321 .623 r
.48515 .42745 m .48228 .42551 L .48452 .42366 L F
.48515 .42745 m .48275 .42823 L .48228 .42551 L F
.327 0 .246 r
.27343 .57801 m .2697 .58224 L .27068 .57906 L F
.749 .979 .916 r
.42617 .55591 m .42423 .55755 L .42089 .55762 L F
.737 .688 .805 r
.44531 .54824 m .44164 .54602 L .44127 .54849 L F
.44531 .54824 m .44551 .54637 L .44164 .54602 L F
.885 .81 .77 r
.44311 .55008 m .44531 .54824 L .44127 .54849 L F
0 0 .536 r
.62485 .39106 m .62588 .39408 L .62662 .39232 L F
.677 .858 .457 r
.62662 .39232 m .62588 .39408 L .6246 .39549 L F
.579 .117 .119 r
.62628 .39434 m .62945 .39478 L .62588 .39408 L F
.288 .669 .972 r
.62588 .39408 m .62846 .39347 L .62571 .39719 L F
.791 .981 .708 r
.29308 .53701 m .29248 .53775 L .29211 .53936 L F
.695 .675 .827 r
.2919 .5403 m .29056 .5397 L .29211 .53936 L F
.29056 .5397 m .28982 .53936 L .29211 .53936 L F
.29365 .54108 m .2919 .5403 L .29211 .53936 L F
.329 .48 .858 r
.29516 .53841 m .29365 .54108 L .29211 .53936 L F
.814 .701 .74 r
.2902 .5406 m .29388 .53897 L .29211 .53936 L F
.29388 .53897 m .29516 .53841 L .29211 .53936 L F
.791 .981 .708 r
.29248 .53775 m .2902 .5406 L .29211 .53936 L F
.329 .48 .858 r
.29516 .53841 m .29625 .54236 L .29365 .54108 L F
.479 .449 .746 r
.297 .54273 m .29483 .5436 L .29365 .54108 L F
.814 .701 .74 r
.2902 .5406 m .29342 .54333 L .29516 .53841 L F
0 0 0 r
.29516 .53841 m .29505 .5389 L .29474 .5369 L F
.29516 .53841 m .29474 .5369 L .29458 .53578 L F
.329 .48 .858 r
.29516 .53841 m .297 .54273 L .29625 .54236 L F
.509 .402 .669 r
.25721 .58041 m .26018 .58232 L .25927 .57983 L F
.879 .91 .846 r
.43353 .55925 m .4326 .56331 L .43477 .55985 L F
0 0 0 r
.43533 .55727 m .43353 .55925 L .4354 .55849 L F
.43533 .55727 m .43653 .55613 L .43353 .55925 L F
.43665 .55584 m .43533 .55727 L .4354 .55849 L F
.43665 .55584 m .43653 .55613 L .43533 .55727 L F
.149 .238 .701 r
.43598 .55199 m .43847 .55467 L .43665 .55584 L F
0 0 0 r
.43665 .55584 m .43847 .55467 L .43653 .55613 L F
.649 .774 .94 r
.43653 .55613 m .43847 .55467 L .43806 .55466 L F
.43653 .55613 m .43806 .55466 L .43518 .55459 L F
.43522 .55532 m .43518 .55459 L .43401 .55456 L F
.43653 .55613 m .43518 .55459 L .43522 .55532 L F
0 0 0 r
.4354 .55849 m .43353 .55925 L .43477 .55985 L F
.60944 .35375 m .6067 .35714 L .60771 .3554 L F
.601 .362 .527 r
.26369 .59345 m .26316 .59661 L .2603 .59653 L F
.548 .495 .748 r
.26269 .59056 m .26618 .59244 L .26369 .59345 L F
.545 .311 .512 r
.26637 .59565 m .26369 .59345 L .26618 .59244 L F
.26637 .59565 m .26316 .59661 L .26369 .59345 L F
.746 .632 .733 r
.37551 .48355 m .37846 .48366 L .37861 .47889 L F
.37551 .48355 m .37861 .47889 L .37614 .4797 L F
.585 .893 .614 r
.37551 .48355 m .37562 .48304 L .37846 .48366 L F
0 0 .388 r
.37857 .48004 m .37846 .48366 L .37995 .48081 L F
.701 .965 .939 r
.37846 .48366 m .37562 .48304 L .37995 .48081 L F
.102 0 0 r
.37995 .48081 m .37747 .48289 L .38087 .48133 L F
.37995 .48081 m .38087 .48133 L .3818 .4809 L F
0 0 .388 r
.37861 .47889 m .37857 .48004 L .37995 .48081 L F
.311 0 0 r
.5643 .37134 m .56762 .37095 L .56715 .36989 L F
.174 .167 .61 r
.56715 .36989 m .56985 .36931 L .56809 .36705 L F
.046 0 .06 r
.56715 .36989 m .56762 .37095 L .56985 .36931 L F
.67 .797 .943 r
.51934 .40464 m .52352 .40527 L .52199 .40339 L F
0 0 0 r
.41887 .46064 m .42018 .45971 L .41654 .46161 L F
.022 0 0 r
.41887 .46064 m .42228 .45834 L .42018 .45971 L F
.647 .42 .56 r
.59146 .35012 m .59422 .3472 L .59192 .34864 L F
.821 .914 .902 r
.63247 .3806 m .62935 .38093 L .63221 .38014 L F
.603 .943 .774 r
.63615 .37783 m .63247 .3806 L .63221 .38014 L F
.564 .484 .723 r
.28915 .55009 m .28546 .54587 L .28814 .54458 L F
.567 .938 .869 r
.53276 .35232 m .52917 .35412 L .53215 .35256 L F
.06 0 0 r
.52787 .35493 m .53215 .35256 L .52917 .35412 L F
.953 .953 .686 r
.4529 .52723 m .45276 .52456 L .45389 .52502 L F
.4529 .52723 m .45099 .5283 L .45276 .52456 L F
.901 .822 .76 r
.46461 .52535 m .46868 .52287 L .46747 .52188 L F
.46461 .52535 m .46649 .52654 L .46868 .52287 L F
.85 .952 .88 r
.46747 .52188 m .46868 .52287 L .47172 .5198 L F
.486 .161 .341 r
.43273 .51957 m .4323 .52172 L .43005 .52208 L F
.962 .806 .371 r
.43273 .51957 m .4316 .52138 L .4323 .52172 L F
.43273 .51957 m .43183 .51729 L .4316 .52138 L F
.374 .136 .42 r
.26647 .55975 m .26899 .5594 L .26938 .55635 L F
.455 .242 .5 r
.26647 .55975 m .26857 .56179 L .26899 .5594 L F
.26647 .55975 m .26636 .56271 L .26857 .56179 L F
.21 .054 .439 r
.25974 .57665 m .26184 .57789 L .26182 .57508 L F
.25974 .57665 m .25927 .57983 L .26184 .57789 L F
.656 .54 .711 r
.28146 .56657 m .27941 .57034 L .27945 .5676 L F
0 0 0 r
.27956 .57106 m .27941 .57034 L .28217 .57012 L F
.27956 .57106 m .27812 .57216 L .27941 .57034 L F
.474 .246 .488 r
.26938 .55635 m .27192 .55577 L .27222 .55311 L F
.299 .074 .394 r
.27477 .54964 m .27222 .55311 L .2744 .5523 L F
.4 .184 .467 r
.27222 .55311 m .27437 .55435 L .2744 .5523 L F
.27222 .55311 m .27192 .55577 L .27437 .55435 L F
.955 .949 .711 r
.60443 .35846 m .60234 .35895 L .60297 .35983 L F
.75 .994 .822 r
.60559 .35601 m .60443 .35846 L .6067 .35714 L F
.699 .575 .712 r
.56336 .39426 m .56584 .39166 L .5627 .39176 L F
.634 .933 .685 r
.49792 .46532 m .49598 .46644 L .49912 .46363 L F
.483 .019 .074 r
.53137 .42066 m .53367 .41813 L .52964 .41883 L F
0 .162 .693 r
.53488 .41702 m .5367 .42156 L .53367 .41813 L F
.53488 .41702 m .53367 .41813 L .53137 .42066 L F
.021 .236 .741 r
.28369 .64899 m .28492 .65266 L .28334 .65057 L F
.701 .535 .66 r
.53677 .38533 m .53701 .38818 L .5397 .3853 L F
.867 .761 .744 r
.4735 .49904 m .47003 .49864 L .47232 .49521 L F
.879 .782 .751 r
.4735 .49904 m .46939 .50127 L .47003 .49864 L F
.4735 .49904 m .47143 .50274 L .46939 .50127 L F
.891 .477 .207 r
.65834 .34652 m .6597 .34524 L .65641 .34345 L F
.65834 .34652 m .6603 .34729 L .6597 .34524 L F
.861 .962 .867 r
.49226 .49989 m .49436 .49761 L .49271 .4969 L F
.829 .939 .898 r
.49075 .49894 m .49226 .49989 L .49271 .4969 L F
0 .137 .654 r
.30956 .67799 m .3133 .68189 L .31204 .6771 L F
.38 .302 .641 r
.31562 .6796 m .3133 .68189 L .31406 .68208 L F
.249 .266 .682 r
.2645 .58867 m .26269 .59056 L .26202 .58649 L F
.41 .517 .856 r
.2645 .58867 m .26618 .59244 L .26269 .59056 L F
.992 .816 .441 r
.59882 .37286 m .59963 .37456 L .60016 .37162 L F
.638 .886 .546 r
.6016 .36949 m .59882 .37286 L .60016 .37162 L F
.462 .146 .344 r
.64527 .35436 m .64816 .35389 L .6489 .35184 L F
0 0 0 r
.6489 .35184 m .64816 .35389 L .65008 .34976 L F
.643 .806 .962 r
.5944 .35265 m .59302 .3558 L .59628 .35454 L F
.5944 .35265 m .59302 .3558 L .59628 .35454 L F
.641 .849 .46 r
.45931 .53209 m .45629 .53644 L .45683 .53586 L F
.667 .566 .732 r
.28146 .56657 m .27945 .5676 L .27781 .56321 L F
.258 0 .245 r
.5397 .3853 m .53701 .38818 L .5394 .38717 L F
.886 .936 .844 r
.64527 .35436 m .64218 .35835 L .64133 .35665 L F
0 .002 .563 r
.64218 .35835 m .64365 .36011 L .64133 .35665 L F
0 0 .339 r
.58557 .38456 m .5869 .37991 L .58468 .38193 L F
0 0 0 r
.28807 .6358 m .28615 .63641 L .28614 .63751 L F
.28807 .6358 m .28917 .63318 L .28615 .63641 L F
.45517 .44545 m .4584 .44298 L .45771 .44401 L F
.194 0 .187 r
.4584 .44298 m .46013 .44319 L .45771 .44401 L F
.4584 .44298 m .4607 .44176 L .46013 .44319 L F
.642 .131 .017 r
.35909 .56943 m .35499 .56832 L .35639 .56999 L F
.748 .757 .86 r
.3592 .57072 m .35909 .56943 L .35639 .56999 L F
.831 .822 .841 r
.29408 .59756 m .29883 .59616 L .29638 .59522 L F
.792 .838 .887 r
.29638 .59522 m .29883 .59616 L .30167 .59337 L F
0 0 .442 r
.58157 .34747 m .58128 .35101 L .58259 .34906 L F
0 0 .165 r
.58105 .35413 m .58259 .34906 L .58128 .35101 L F
.287 0 .181 r
.51139 .40166 m .50826 .40422 L .5088 .40224 L F
.816 .773 .812 r
.32015 .61075 m .31798 .61394 L .31545 .61239 L F
.893 .714 .653 r
.31545 .61239 m .31798 .61394 L .31698 .61655 L F
.936 .701 .558 r
.35102 .55982 m .35065 .56266 L .34883 .55877 L F
.833 .629 .627 r
.31503 .53936 m .31477 .5422 L .31878 .54297 L F
.835 .585 .561 r
.31477 .5422 m .31863 .54571 L .31878 .54297 L F
.885 .876 .822 r
.30367 .57045 m .30169 .5736 L .30031 .57173 L F
.994 .809 .547 r
.30169 .5736 m .29987 .57532 L .30031 .57173 L F
.699 .831 .945 r
.31428 .61606 m .31008 .61656 L .31237 .61565 L F
.568 .553 .798 r
.31545 .61239 m .31428 .61606 L .31237 .61565 L F
.31545 .61239 m .31698 .61655 L .31428 .61606 L F
.103 0 0 r
.45517 .44545 m .45414 .44777 L .45215 .44787 L F
.003 0 0 r
.45637 .44641 m .45517 .44545 L .45771 .44401 L F
.45637 .44641 m .45414 .44777 L .45517 .44545 L F
.712 .576 .7 r
.297 .54273 m .29368 .54519 L .29483 .5436 L F
.505 .658 .929 r
.38369 .55828 m .38208 .56065 L .3808 .55888 L F
.38369 .55828 m .38501 .5609 L .38208 .56065 L F
.378 .139 .421 r
.26938 .55635 m .27009 .55856 L .27192 .55577 L F
.26938 .55635 m .26899 .5594 L .27009 .55856 L F
.466 .303 .575 r
.56522 .35756 m .56804 .35413 L .56418 .35414 L F
.324 .033 .307 r
.29244 .63013 m .28917 .63318 L .29121 .63265 L F
0 0 0 r
.29121 .63265 m .28917 .63318 L .28807 .6358 L F
.823 .708 .738 r
.33514 .63674 m .33984 .63629 L .33836 .6332 L F
.628 .171 .148 r
.33606 .63787 m .33984 .63629 L .33514 .63674 L F
.938 .594 .168 r
.33866 .63563 m .33984 .63629 L .33836 .6332 L F
.841 .991 .855 r
.33866 .63563 m .33984 .63629 L .33606 .63787 L F
.827 .93 .9 r
.53068 .46094 m .53539 .45914 L .53372 .45769 L F
.683 .663 .824 r
.6022 .34359 m .60191 .34546 L .60502 .34469 L F
.68 .798 .337 r
.35013 .65719 m .35206 .65285 L .35086 .65533 L F
0 0 .067 r
.34997 .65947 m .35013 .65719 L .35086 .65533 L F
.919 .898 .791 r
.3952 .56577 m .3939 .56694 L .39628 .56591 L F
.814 .958 .625 r
.42857 .53309 m .42711 .53433 L .42969 .53003 L F
.691 .218 .123 r
.43149 .53476 m .42711 .53433 L .42857 .53309 L F
.778 .768 .844 r
.46503 .5114 m .46464 .50922 L .46634 .51009 L F
.745 .938 .949 r
.46634 .51009 m .46687 .50753 L .46767 .50871 L F
.46634 .51009 m .46464 .50922 L .46687 .50753 L F
.918 .833 .745 r
.52924 .46844 m .53027 .46589 L .52843 .4646 L F
.893 .697 .63 r
.39628 .56591 m .39715 .56954 L .39854 .56682 L F
.955 .623 .347 r
.37471 .58497 m .37711 .58711 L .37534 .58837 L F
.13 0 0 r
.37534 .58837 m .37711 .58711 L .37844 .58736 L F
.262 0 .083 r
.29482 .62945 m .29244 .63013 L .29121 .63265 L F
.817 .593 .599 r
.318 .647 m .31791 .65076 L .31538 .64887 L F
.559 .476 .718 r
.28314 .53969 m .28611 .5392 L .28542 .5365 L F
.484 .186 .384 r
.28197 .54213 m .28611 .5392 L .28314 .53969 L F
.862 .591 .527 r
.42667 .50816 m .42988 .50598 L .42644 .50522 L F
.42667 .50816 m .42982 .50871 L .42988 .50598 L F
.833 .683 .696 r
.56142 .36266 m .56386 .36128 L .56274 .36352 L F
.516 .645 .914 r
.37044 .58179 m .37138 .58172 L .36919 .58317 L F
.801 .308 0 r
.36943 .57927 m .37212 .58167 L .37138 .58172 L F
0 0 .524 r
.36943 .57927 m .37138 .58172 L .36935 .57869 L F
.511 .665 .932 r
.37075 .58079 m .37179 .5786 L .36935 .57869 L F
.37138 .58172 m .37158 .58021 L .37075 .58079 L F
.37158 .58021 m .37179 .5786 L .37075 .58079 L F
.37138 .58172 m .3725 .5795 L .37179 .5786 L F
.516 .645 .914 r
.37248 .57953 m .37138 .58172 L .37044 .58179 L F
.444 .661 .953 r
.37515 .57914 m .37394 .58136 L .37264 .57936 L F
.24 0 .033 r
.37515 .57914 m .37264 .57936 L .37257 .57947 L F
.54 .779 .986 r
.37394 .58136 m .37515 .57914 L .37308 .5794 L F
.3725 .57951 m .3728 .57876 L .3725 .5795 L F
.37394 .58136 m .37299 .57919 L .3725 .57951 L F
.516 .645 .914 r
.37264 .57936 m .37226 .58007 L .37249 .57953 L F
0 0 0 r
.37257 .57947 m .37264 .57936 L .37249 .57953 L F
.54 .779 .986 r
.37299 .57919 m .3728 .57876 L .3725 .57951 L F
.516 .645 .914 r
.37226 .58007 m .37138 .58172 L .37249 .57953 L F
.37264 .57936 m .37394 .58136 L .37138 .58172 L F
.511 .665 .932 r
.37138 .58172 m .37394 .58136 L .3725 .57951 L F
0 0 0 r
.3725 .57951 m .37249 .57953 L .37248 .57953 L F
.511 .665 .932 r
.37248 .57953 m .3725 .57951 L .3725 .5795 L F
.516 .645 .914 r
.37249 .57953 m .37138 .58172 L .37248 .57953 L F
.511 .665 .932 r
.37138 .58172 m .3725 .57951 L .37248 .57953 L F
0 0 0 r
.37257 .57947 m .3725 .57951 L .37238 .57964 L F
.3725 .57951 m .37248 .57953 L .37238 .57964 L F
.37254 .57953 m .37257 .57947 L .37238 .57964 L F
.801 .308 0 r
.37212 .58167 m .37303 .58249 L .37138 .58172 L F
.367 .787 .976 r
.37576 .58221 m .37138 .58172 L .37303 .58249 L F
.37576 .58221 m .37394 .58136 L .37138 .58172 L F
.804 .582 .601 r
.37471 .58497 m .37138 .58172 L .37394 .58136 L F
.37471 .58497 m .37138 .58547 L .37138 .58172 L F
.961 .72 .526 r
.37138 .58172 m .37138 .58547 L .36919 .58317 L F
.54 .779 .986 r
.37394 .58136 m .37651 .5807 L .37515 .57914 L F
.431 .844 .966 r
.37871 .5813 m .37394 .58136 L .37576 .58221 L F
.622 .674 .879 r
.37576 .58221 m .37868 .58291 L .37871 .5813 L F
.431 .844 .966 r
.37871 .5813 m .37651 .5807 L .37394 .58136 L F
.159 0 0 r
.38091 .58128 m .37651 .5807 L .37871 .5813 L F
.38091 .58128 m .3782 .58098 L .37739 .58084 L F
.37749 .58083 m .37739 .58084 L .37651 .5807 L F
.38091 .58128 m .37739 .58084 L .37749 .58083 L F
.207 0 0 r
.37651 .5807 m .37633 .58074 L .37515 .57914 L F
.444 .661 .953 r
.37443 .58047 m .37704 .58169 L .37394 .58136 L F
.37515 .57914 m .37633 .58074 L .37443 .58047 L F
.37633 .58074 m .37704 .58169 L .37443 .58047 L F
.207 0 0 r
.37651 .5807 m .3782 .58098 L .37787 .58096 L F
.37651 .5807 m .37787 .58096 L .37633 .58074 L F
.444 .661 .953 r
.37621 .58057 m .37857 .58185 L .37704 .58169 L F
.37515 .57914 m .37726 .58082 L .37621 .58057 L F
.37726 .58082 m .37857 .58185 L .37621 .58057 L F
.6 .063 0 r
.37749 .58144 m .37731 .58086 L .37728 .58086 L F
.883 .479 .039 r
.37731 .58094 m .37749 .58144 L .37577 .58088 L F
.6 .063 0 r
.37749 .58144 m .37728 .58086 L .37695 .58092 L F
.37749 .58144 m .37857 .58185 L .37731 .58086 L F
.883 .479 .039 r
.37787 .58096 m .37749 .58144 L .37731 .58094 L F
.3782 .58098 m .37813 .58102 L .37787 .58096 L F
.37813 .58102 m .37749 .58144 L .37787 .58096 L F
.207 0 0 r
.37633 .58074 m .37787 .58096 L .37577 .58088 L F
.37633 .58074 m .37577 .58088 L .37515 .57914 L F
.6 .063 0 r
.37695 .58092 m .37731 .58086 L .37515 .57914 L F
.24 0 .033 r
.37515 .57914 m .37084 .58242 L .37342 .58148 L F
.769 .415 0 r
.37515 .57914 m .37577 .58088 L .37558 .58054 L F
.451 .053 .192 r
.37471 .58497 m .37868 .58291 L .37576 .58221 L F
.539 .587 .851 r
.37857 .58185 m .37471 .58497 L .37394 .58136 L F
.677 .296 .318 r
.37342 .58148 m .37587 .58146 L .37515 .57914 L F
.769 .415 0 r
.37515 .57914 m .37558 .58054 L .37477 .57906 L F
.677 .296 .318 r
.37558 .58054 m .37749 .58144 L .37515 .57914 L F
0 .434 .79 r
.37558 .58054 m .37576 .58059 L .37534 .5801 L F
.37577 .58088 m .37577 .58079 L .37558 .58054 L F
.677 .296 .318 r
.37577 .58079 m .37749 .58144 L .37558 .58054 L F
0 .434 .79 r
.37577 .58088 m .37749 .58144 L .37577 .58079 L F
.677 .296 .318 r
.37625 .58145 m .37749 .58144 L .37577 .58079 L F
0 .434 .79 r
.37577 .58079 m .37749 .58144 L .37576 .58041 L F
.37577 .58079 m .37576 .58059 L .37558 .58054 L F
.677 .296 .318 r
.37587 .58146 m .37625 .58145 L .37558 .58054 L F
0 .434 .79 r
.37534 .5801 m .37576 .58041 L .37477 .57906 L F
.37576 .58059 m .37576 .58041 L .37534 .5801 L F
.24 0 .033 r
.37477 .57943 m .37257 .57947 L .37084 .58242 L F
.37515 .57914 m .37458 .57922 L .37477 .57943 L F
.37458 .57922 m .37257 .57947 L .37477 .57943 L F
.54 .779 .986 r
.37308 .5794 m .37515 .57914 L .3728 .57876 L F
.3725 .5795 m .3728 .57876 L .37179 .5786 L F
0 0 0 r
.37084 .58242 m .37254 .57953 L .36919 .58317 L F
.37254 .57953 m .37238 .57964 L .36919 .58317 L F
.879 .91 .846 r
.43353 .55925 m .43081 .56239 L .4326 .56331 L F
.967 .83 .656 r
.43081 .56239 m .43188 .56598 L .4326 .56331 L F
.374 .817 .951 r
.5205 .37828 m .52244 .3779 L .52452 .37826 L F
.973 .67 .291 r
.5234 .37978 m .52452 .37826 L .52244 .3779 L F
.5234 .37978 m .52486 .38133 L .52452 .37826 L F
.901 .642 .537 r
.42563 .51248 m .42294 .50885 L .42849 .50886 L F
.773 .971 .922 r
.55524 .37278 m .55649 .36997 L .55774 .37118 L F
.55524 .37278 m .55313 .37242 L .55649 .36997 L F
.155 0 .1 r
.2647 .58413 m .26401 .5858 L .26202 .58649 L F
.595 .342 .504 r
.2674 .58305 m .26401 .5858 L .2647 .58413 L F
.918 .801 .715 r
.64365 .36011 m .64412 .36481 L .64224 .3635 L F
.828 .707 .731 r
.64341 .36708 m .64224 .3635 L .64412 .36481 L F
.487 .312 .57 r
.27477 .54964 m .27755 .55105 L .27727 .54597 L F
.318 0 .107 r
.2744 .5523 m .27755 .55105 L .27477 .54964 L F
.954 .783 .632 r
.43826 .5313 m .43989 .5362 L .43564 .53562 L F
.43826 .5313 m .43988 .53324 L .43989 .5362 L F
.762 .555 .616 r
.43564 .53562 m .43989 .5362 L .43954 .53885 L F
.389 0 0 r
.38971 .48269 m .38775 .48454 L .38523 .48453 L F
.504 .022 .045 r
.3932 .48413 m .38971 .48269 L .39215 .48236 L F
.3932 .48413 m .38775 .48454 L .38971 .48269 L F
0 0 0 r
.46085 .43078 m .46229 .42918 L .4589 .43161 L F
.46456 .4279 m .46229 .42918 L .46085 .43078 L F
.708 .549 .671 r
.36143 .52952 m .3586 .53268 L .36336 .53143 L F
.661 .605 .782 r
.36336 .53143 m .36421 .52908 L .36143 .52952 L F
.811 .778 .822 r
.52924 .46844 m .52843 .4646 L .52565 .4679 L F
.799 .793 .847 r
.52732 .46973 m .52924 .46844 L .52565 .4679 L F
.042 0 0 r
.36842 .5686 m .37291 .5666 L .3683 .566 L F
.36842 .5686 m .371 .56798 L .37291 .5666 L F
.272 .059 .396 r
.37291 .5666 m .37508 .56601 L .37553 .56291 L F
.843 .418 .221 r
.371 .56798 m .37318 .5688 L .37291 .5666 L F
.505 .848 .996 r
.41226 .56455 m .41188 .56623 L .40947 .56504 L F
.204 .548 .93 r
.41226 .56455 m .41428 .56667 L .41188 .56623 L F
0 .329 .814 r
.28541 .66454 m .2874 .66476 L .28423 .66323 L F
.28541 .66454 m .28835 .66651 L .2874 .66476 L F
.229 .37 .799 r
.28541 .66454 m .2869 .66684 L .28835 .66651 L F
.099 .648 .821 r
.63434 .33858 m .63814 .33827 L .63822 .33882 L F
.711 .532 0 r
.63822 .33882 m .638 .33653 L .64124 .33847 L F
.63822 .33882 m .63814 .33827 L .638 .33653 L F
.667 .566 .732 r
.28146 .56657 m .27781 .56321 L .28051 .56247 L F
.342 .41 .787 r
.2869 .66684 m .29004 .67051 L .28835 .66651 L F
.901 .642 .537 r
.42563 .51248 m .42291 .51191 L .42294 .50885 L F
0 0 .487 r
.42563 .51248 m .42575 .51105 L .42291 .51191 L F
.42563 .51248 m .42714 .51481 L .42575 .51105 L F
.741 .348 .308 r
.41026 .57663 m .40843 .57865 L .41256 .57871 L F
0 0 0 r
.41152 .57527 m .41026 .57663 L .41224 .57576 L F
.41152 .57527 m .40843 .57865 L .41026 .57663 L F
.152 0 .061 r
.4131 .46525 m .41547 .4642 L .41654 .46161 L F
.098 0 0 r
.41547 .4642 m .41887 .46064 L .41654 .46161 L F
.921 .946 .797 r
.48105 .5051 m .47979 .5094 L .48208 .50571 L F
.783 .993 .879 r
.48285 .50324 m .48208 .50571 L .48441 .50411 L F
.48285 .50324 m .48105 .5051 L .48208 .50571 L F
.772 .556 .606 r
.36729 .55623 m .37112 .55932 L .36977 .55566 L F
.36729 .55623 m .36732 .55941 L .37112 .55932 L F
.752 .704 .807 r
.36977 .55566 m .37112 .55932 L .37397 .5566 L F
.855 .997 .809 r
.51776 .37919 m .51897 .37609 L .5205 .37828 L F
.51776 .37919 m .51591 .37934 L .51897 .37609 L F
.829 .557 .526 r
.34301 .53616 m .34004 .53843 L .34032 .53532 L F
.34301 .53616 m .34298 .53901 L .34004 .53843 L F
.254 .251 .663 r
.38106 .56561 m .38137 .56778 L .38017 .56605 L F
0 0 0 r
.60557 .36477 m .60449 .36624 L .60223 .36781 L F
.629 .613 .815 r
.6082 .36315 m .60557 .36477 L .60297 .35983 L F
.659 .842 .433 r
.60691 .36233 m .60557 .36477 L .6082 .36315 L F
.60691 .36233 m .60449 .36624 L .60557 .36477 L F
.781 .7 .775 r
.31186 .63997 m .30981 .64353 L .30763 .63927 L F
.728 .88 .478 r
.31016 .64225 m .30981 .64353 L .31186 .63997 L F
0 .248 .761 r
.31212 .6446 m .30981 .64353 L .31016 .64225 L F
.77 .615 .687 r
.36532 .55237 m .36715 .55587 L .36593 .55203 L F
.36715 .55587 m .3672 .55579 L .36593 .55203 L F
.766 .921 .55 r
.36756 .55535 m .36706 .55607 L .36729 .55623 L F
.36706 .55607 m .36606 .55753 L .36667 .55688 L F
.36706 .55607 m .36667 .55688 L .36729 .55623 L F
.277 .322 .729 r
.36593 .55203 m .3672 .55579 L .36782 .55448 L F
.766 .921 .55 r
.36757 .55532 m .36742 .55554 L .36756 .55535 L F
.36762 .55514 m .36695 .55616 L .36757 .55532 L F
.277 .322 .729 r
.3672 .55579 m .36736 .55627 L .36782 .55448 L F
.772 .493 .513 r
.3668 .55637 m .36554 .55808 L .36736 .55627 L F
.36104 .55743 m .36554 .55808 L .3668 .55637 L F
.766 .921 .55 r
.36742 .55554 m .36606 .55753 L .36756 .55535 L F
.36695 .55616 m .36606 .55753 L .36757 .55532 L F
.772 .493 .513 r
.36104 .55743 m .3668 .55637 L .36115 .55462 L F
.3668 .55637 m .36736 .55627 L .36695 .55616 L F
.3668 .55637 m .36695 .55616 L .36115 .55462 L F
.77 .615 .687 r
.36582 .55586 m .36736 .55627 L .36532 .55237 L F
.766 .921 .55 r
.36782 .55448 m .36554 .55808 L .36606 .55753 L F
.36782 .55448 m .36606 .55753 L .36762 .55514 L F
.77 .615 .687 r
.36715 .55587 m .36736 .55627 L .3672 .55579 L F
.36115 .55462 m .36582 .55586 L .36532 .55237 L F
.993 .752 .452 r
.36606 .55753 m .36732 .55941 L .36729 .55623 L F
.36554 .55808 m .36621 .55858 L .36606 .55753 L F
.36621 .55858 m .36732 .55941 L .36606 .55753 L F
.636 .57 .764 r
.32912 .61161 m .33113 .61435 L .32929 .60956 L F
.52 .203 .37 r
.32611 .61514 m .32912 .61161 L .32606 .61348 L F
.32613 .61575 m .32668 .61498 L .32611 .61514 L F
.32668 .61498 m .32912 .61161 L .32611 .61514 L F
.797 .426 .354 r
.32613 .61575 m .32606 .61348 L .32227 .61257 L F
.893 .583 .453 r
.32556 .61463 m .32912 .61161 L .32613 .61575 L F
.32556 .61463 m .33113 .61435 L .32912 .61161 L F
.74 .526 .604 r
.33344 .61353 m .32929 .60956 L .33113 .61435 L F
.443 .874 .915 r
.33344 .61353 m .33113 .61435 L .32845 .61449 L F
.33032 .61396 m .32845 .61449 L .32556 .61463 L F
.33344 .61353 m .32845 .61449 L .33032 .61396 L F
.858 .701 .686 r
.31851 .54872 m .32032 .54963 L .31863 .54571 L F
.837 .639 .635 r
.31851 .54872 m .32004 .55251 L .32032 .54963 L F
.837 .638 .634 r
.34597 .54259 m .34816 .54646 L .34572 .54541 L F
.88 .756 .722 r
.34816 .54646 m .34407 .54846 L .34572 .54541 L F
.34816 .54646 m .34716 .54963 L .34407 .54846 L F
.967 .643 .311 r
.43845 .52946 m .43988 .53324 L .43826 .5313 L F
.109 .222 .7 r
.43845 .52946 m .4407 .5318 L .43988 .53324 L F
.644 .694 .882 r
.4367 .52798 m .43845 .52946 L .4406 .52879 L F
.645 .282 .341 r
.43826 .5313 m .4407 .5318 L .43845 .52946 L F
.523 .29 .503 r
.43845 .52946 m .4407 .5318 L .4406 .52879 L F
.596 .524 .744 r
.53215 .35256 m .53576 .35124 L .53276 .35232 L F
.73 .867 .945 r
.30265 .58599 m .30681 .58625 L .30499 .5847 L F
.84 .735 .748 r
.30265 .58599 m .30431 .58976 L .30681 .58625 L F
.822 .881 .888 r
.30499 .5847 m .30681 .58625 L .30994 .58282 L F
.877 .633 .566 r
.35001 .55301 m .34956 .55593 L .34724 .55209 L F
.128 .654 .876 r
.63984 .34539 m .6382 .34465 L .63517 .34469 L F
.013 .586 .746 r
.64194 .34487 m .6382 .34465 L .63984 .34539 L F
.428 .477 .809 r
.63984 .34539 m .64359 .34684 L .64194 .34487 L F
.834 .839 .85 r
.4632 .51323 m .4588 .515 L .46199 .51265 L F
.778 .768 .844 r
.46503 .5114 m .4632 .51323 L .46199 .51265 L F
.416 .82 .613 r
.49475 .40213 m .49539 .40161 L .49721 .40095 L F
.49475 .40213 m .49307 .40318 L .49539 .40161 L F
.64 .878 .985 r
.5166 .44384 m .51442 .44496 L .51283 .4437 L F
.989 .779 .529 r
.33473 .52263 m .33237 .52438 L .33272 .52117 L F
.33473 .52263 m .33425 .52594 L .33237 .52438 L F
.966 .923 .59 r
.36519 .56576 m .36412 .56808 L .36598 .56642 L F
.979 .841 .445 r
.36598 .56642 m .36519 .56576 L .36538 .56291 L F
.966 .923 .59 r
.36519 .56576 m .36412 .56808 L .36598 .56642 L F
.391 .82 .963 r
.3683 .566 m .3654 .56577 L .36598 .56642 L F
.856 .726 .718 r
.3683 .566 m .36519 .56576 L .36538 .56291 L F
0 .215 .717 r
.36753 .56467 m .3683 .566 L .36538 .56291 L F
.824 .549 .523 r
.36753 .56467 m .36842 .5686 L .3683 .566 L F
.36767 .56532 m .371 .56798 L .36842 .5686 L F
.36753 .56467 m .36812 .56523 L .36767 .56532 L F
.36812 .56523 m .371 .56798 L .36767 .56532 L F
.391 .82 .963 r
.3654 .56577 m .36519 .56576 L .36525 .5658 L F
.3654 .56577 m .36525 .5658 L .36598 .56642 L F
.726 .514 .604 r
.25735 .58861 m .26267 .5904 L .26202 .58649 L F
.459 .548 .86 r
.26202 .58649 m .26215 .58216 L .26018 .58232 L F
.26202 .58649 m .26401 .5858 L .26215 .58216 L F
.375 .274 .611 r
.26202 .58649 m .2645 .58867 L .26401 .5858 L F
.26202 .58649 m .26267 .5904 L .2645 .58867 L F
.249 .266 .682 r
.2645 .58867 m .26202 .58649 L .26401 .5858 L F
.55 .407 .639 r
.27713 .65289 m .27994 .64814 L .27772 .64984 L F
.891 .748 .697 r
.31993 .55522 m .32183 .55894 L .32201 .55651 L F
.31993 .55522 m .31768 .55899 L .32183 .55894 L F
.881 .812 .777 r
.31768 .55899 m .31881 .56255 L .32183 .55894 L F
.28 .443 .845 r
.30398 .67681 m .30326 .67311 L .30127 .67355 L F
.30398 .67681 m .30536 .67729 L .30326 .67311 L F
.856 .93 .875 r
.45931 .53209 m .46373 .52992 L .46273 .52836 L F
.879 .909 .845 r
.46273 .52836 m .46373 .52992 L .46649 .52654 L F
.9 .939 .574 r
.54512 .43887 m .54687 .43514 L .54647 .43436 L F
.938 .965 .725 r
.54687 .43514 m .54807 .43032 L .54751 .43211 L F
.881 .969 .649 r
.54647 .43436 m .54687 .43514 L .54751 .43211 L F
.682 .523 .664 r
.40576 .47819 m .40363 .48218 L .40208 .47859 L F
.38 .366 .718 r
.38347 .55005 m .38626 .55201 L .38643 .54911 L F
.38347 .55005 m .38456 .55329 L .38626 .55201 L F
.823 .968 .896 r
.49436 .49761 m .49567 .49435 L .49271 .4969 L F
.49436 .49761 m .49698 .49511 L .49567 .49435 L F
.81 .768 .814 r
.3418 .6204 m .34192 .62429 L .33937 .62314 L F
.031 .119 .624 r
.34334 .62184 m .34192 .62429 L .3418 .6204 L F
0 .167 .706 r
.3436 .62427 m .34192 .62429 L .34334 .62184 L F
.803 .962 .912 r
.66034 .37728 m .6627 .37352 L .65945 .3765 L F
.66034 .37728 m .66364 .37465 L .6627 .37352 L F
0 0 0 r
.57839 .39279 m .5757 .39623 L .57642 .39458 L F
.661 .899 .56 r
.5768 .39439 m .5757 .39623 L .57704 .3941 L F
0 0 0 r
.5757 .39623 m .57461 .39805 L .57642 .39458 L F
.661 .899 .56 r
.57428 .39752 m .5757 .39623 L .5768 .39439 L F
0 0 0 r
.5757 .39623 m .57443 .3984 L .57461 .39805 L F
.677 .901 .553 r
.57303 .3997 m .57443 .3984 L .5757 .39623 L F
.607 .946 .929 r
.50377 .45931 m .50491 .45765 L .50628 .4577 L F
.50377 .45931 m .50118 .45921 L .50491 .45765 L F
.799 .368 .225 r
.336 .61521 m .33865 .61316 L .33533 .61325 L F
.336 .61521 m .34062 .61628 L .33865 .61316 L F
.938 .805 .687 r
.39645 .48228 m .3932 .48413 L .39215 .48236 L F
.39645 .48228 m .39512 .48569 L .3932 .48413 L F
.573 .814 .99 r
.50163 .41714 m .50313 .41516 L .49979 .41673 L F
.50163 .41714 m .50422 .41628 L .50313 .41516 L F
.187 0 .097 r
.43503 .44916 m .43178 .45184 L .43392 .45057 L F
.022 0 0 r
.43733 .44808 m .43503 .44916 L .43392 .45057 L F
.672 .156 .001 r
.37551 .48355 m .3776 .48539 L .3743 .48442 L F
.585 .893 .614 r
.37551 .48355 m .3743 .48442 L .37562 .48304 L F
.589 .029 0 r
.37743 .48509 m .3776 .48539 L .37551 .48355 L F
.514 .845 .998 r
.64124 .33847 m .64384 .33768 L .64504 .33879 L F
0 .524 .747 r
.64384 .33768 m .64785 .33833 L .64504 .33879 L F
.545 .911 .733 r
.50737 .42611 m .50386 .42829 L .50606 .42489 L F
0 0 0 r
.51327 .47775 m .51216 .48236 L .51552 .47936 L F
.51327 .47775 m .51286 .47972 L .51216 .48236 L F
.828 .987 .874 r
.51216 .48236 m .51286 .47972 L .51096 .4818 L F
0 0 .388 r
.37861 .47889 m .37995 .48081 L .38119 .47916 L F
.881 .728 .687 r
.52301 .43458 m .52442 .43944 L .52298 .43774 L F
.891 .875 .814 r
.52298 .43774 m .52442 .43944 L .52096 .43923 L F
0 0 0 r
.47249 .43387 m .47358 .4326 L .47581 .43143 L F
.1 .394 .85 r
.32541 .61835 m .32622 .62002 L .32373 .61687 L F
.911 .863 .78 r
.3254 .61842 m .32622 .62002 L .32541 .61835 L F
0 .337 .818 r
.32373 .61687 m .32541 .61835 L .32659 .61879 L F
.035 .353 .828 r
.32537 .61837 m .3262 .62 L .32659 .61879 L F
.3262 .62 m .32622 .62002 L .32659 .61879 L F
.73 .96 .68 r
.32708 .61729 m .32659 .61879 L .32715 .61722 L F
.035 .353 .828 r
.32373 .61687 m .32622 .62002 L .3254 .61842 L F
.32492 .61767 m .3254 .61842 L .32506 .61776 L F
.767 .667 .752 r
.32108 .62277 m .32168 .62142 L .32058 .61828 L F
.32168 .62142 m .32306 .61834 L .32086 .61829 L F
.32168 .62142 m .32086 .61829 L .32058 .61828 L F
.32538 .61839 m .32534 .61835 L .32058 .61828 L F
.746 .625 .725 r
.31951 .61597 m .32373 .61687 L .32227 .61257 L F
.767 .667 .752 r
.32113 .62322 m .32538 .61839 L .32306 .61834 L F
.32113 .62322 m .32306 .61834 L .32108 .62277 L F
.32538 .61839 m .32541 .61835 L .32534 .61835 L F
.608 .137 .11 r
.32058 .61828 m .32541 .61835 L .32243 .62103 L F
.74 .371 .354 r
.32253 .61942 m .32373 .61687 L .31951 .61597 L F
.198 .287 .731 r
.32157 .61568 m .32253 .61942 L .32057 .61718 L F
.32023 .61587 m .32057 .61718 L .31951 .61597 L F
.32157 .61568 m .32057 .61718 L .32023 .61587 L F
.797 .426 .354 r
.32613 .61575 m .32227 .61257 L .32373 .61687 L F
.672 .785 .316 r
.32459 .61482 m .32395 .61634 L .32253 .61942 L F
.32395 .61634 m .32373 .61687 L .32342 .61754 L F
.32395 .61634 m .32342 .61754 L .32253 .61942 L F
.035 .353 .828 r
.32373 .61687 m .3254 .61842 L .32538 .61839 L F
.32457 .61743 m .32538 .61839 L .32492 .61767 L F
.32373 .61687 m .32538 .61839 L .32457 .61743 L F
.911 .863 .78 r
.32471 .62241 m .3254 .61842 L .32113 .62322 L F
.3254 .61842 m .32541 .61835 L .32538 .61839 L F
.3254 .61842 m .32538 .61839 L .32113 .62322 L F
.32471 .62241 m .32622 .62002 L .3254 .61842 L F
.371 0 0 r
.32243 .62103 m .32539 .61837 L .32659 .61879 L F
.32539 .61837 m .32541 .61835 L .32659 .61879 L F
.035 .353 .828 r
.32506 .61776 m .32537 .61837 L .32659 .61879 L F
0 .337 .818 r
.32373 .61687 m .32659 .61879 L .32613 .61575 L F
.035 .353 .828 r
.32373 .61687 m .32659 .61879 L .32613 .61575 L F
.371 0 0 r
.32243 .62103 m .32486 .61973 L .32443 .62026 L F
.32486 .61973 m .32659 .61879 L .32443 .62026 L F
.914 .618 .13 r
.32424 .6237 m .32471 .62241 L .32113 .62322 L F
.32424 .6237 m .32524 .62609 L .32471 .62241 L F
.926 .824 .726 r
.32443 .62026 m .32656 .62134 L .32455 .62434 L F
.789 .448 .409 r
.32656 .62134 m .32976 .625 L .32455 .62434 L F
.926 .824 .726 r
.32443 .62026 m .32455 .62434 L .32666 .62277 L F
.684 .149 0 r
.32443 .62026 m .32553 .62246 L .32375 .6211 L F
.814 .7 .739 r
.31713 .62189 m .32113 .62322 L .32058 .61828 L F
.622 .465 .648 r
.31682 .61938 m .32058 .61828 L .31951 .61597 L F
.814 .7 .739 r
.31713 .62189 m .32058 .61828 L .31682 .61938 L F
.629 .87 .514 r
.31682 .61938 m .31951 .61597 L .31773 .61793 L F
.909 .561 .369 r
.31773 .61793 m .32058 .61828 L .31951 .61597 L F
.649 .169 0 r
.32019 .61816 m .32058 .61828 L .32243 .62103 L F
.763 .667 .756 r
.32394 .615 m .32253 .61942 L .32157 .61568 L F
.32459 .61482 m .32426 .61556 L .32394 .615 L F
.32426 .61556 m .32253 .61942 L .32394 .615 L F
.805 .679 .726 r
.32227 .61257 m .32606 .61348 L .32479 .60899 L F
.912 .981 .746 r
.32227 .61257 m .32479 .60899 L .32349 .60872 L F
.32227 .61257 m .32349 .60872 L .32179 .61095 L F
.105 0 .168 r
.31951 .61597 m .32227 .61257 L .32157 .61568 L F
.933 .768 .294 r
.32157 .61568 m .32227 .61257 L .32179 .61095 L F
.816 .773 .812 r
.32015 .61075 m .31545 .61239 L .31849 .60983 L F
.347 0 0 r
.31913 .61178 m .32179 .61095 L .31797 .61085 L F
.74 .333 0 r
.32134 .61094 m .32179 .61095 L .31913 .61178 L F
.933 .768 .294 r
.32227 .61548 m .32375 .61519 L .32459 .61482 L F
.32157 .61568 m .32375 .61519 L .32227 .61548 L F
.32157 .61568 m .32162 .61464 L .32375 .61519 L F
.32162 .61464 m .32179 .61095 L .32375 .61519 L F
.74 .333 0 r
.32134 .61094 m .32375 .61519 L .32245 .61239 L F
.32134 .61094 m .32245 .61239 L .32163 .61095 L F
.124 .332 .799 r
.32519 .6149 m .32375 .61519 L .32134 .61094 L F
.797 .426 .354 r
.32613 .61575 m .32373 .61687 L .32459 .61482 L F
0 .155 .605 r
.32585 .61557 m .32459 .61482 L .32375 .61519 L F
.124 .332 .799 r
.32585 .61557 m .32375 .61519 L .32519 .6149 L F
.74 .333 0 r
.32163 .61095 m .32245 .61239 L .32179 .61095 L F
.656 .496 .655 r
.32243 .62103 m .32301 .61595 L .32019 .61816 L F
.537 .036 .012 r
.32046 .6184 m .32297 .61891 L .32248 .62013 L F
.32019 .61816 m .32177 .61858 L .32046 .6184 L F
.32177 .61858 m .32297 .61891 L .32046 .6184 L F
.656 .496 .655 r
.32259 .61961 m .32443 .62026 L .32398 .61891 L F
.32269 .61872 m .32398 .61891 L .32301 .61595 L F
.32259 .61961 m .32398 .61891 L .32269 .61872 L F
.32243 .62103 m .32343 .62065 L .32259 .61961 L F
.32343 .62065 m .32443 .62026 L .32259 .61961 L F
.564 .899 .659 r
.32375 .61519 m .32459 .61482 L .32301 .61595 L F
.152 .205 .664 r
.32375 .61519 m .32301 .61595 L .32519 .61601 L F
.056 .548 .888 r
.32301 .61595 m .32715 .61722 L .32602 .61652 L F
.32394 .61598 m .32602 .61652 L .32519 .61601 L F
.32301 .61595 m .32602 .61652 L .32394 .61598 L F
.235 .175 .582 r
.32519 .61601 m .32297 .61891 L .32349 .61642 L F
.155 0 .29 r
.32394 .61598 m .32381 .61634 L .32519 .61601 L F
.544 .471 .723 r
.32241 .61748 m .32297 .61891 L .32177 .61858 L F
.32327 .61664 m .32297 .61891 L .32241 .61748 L F
.3236 .61589 m .32297 .61891 L .32337 .61583 L F
.155 0 .29 r
.32287 .61703 m .32248 .62013 L .32394 .61598 L F
.235 .175 .582 r
.32519 .61601 m .32349 .61642 L .32375 .61519 L F
.155 0 .29 r
.32381 .61634 m .32325 .61794 L .32519 .61601 L F
.772 .991 .885 r
.32448 .6153 m .32347 .61773 L .32519 .61601 L F
.32347 .61773 m .32297 .61891 L .32519 .61601 L F
0 0 0 r
.32248 .62013 m .32297 .61891 L .32519 .61601 L F
.155 0 .29 r
.32325 .61794 m .32248 .62013 L .32519 .61601 L F
.32301 .61595 m .32287 .61703 L .32394 .61598 L F
.544 .471 .723 r
.32337 .61583 m .32327 .61664 L .32241 .61748 L F
.32375 .61519 m .3236 .61589 L .32337 .61583 L F
.32093 .61754 m .32177 .61858 L .32019 .61816 L F
.577 .918 .707 r
.32375 .61519 m .32019 .61816 L .32301 .61595 L F
.544 .471 .723 r
.32375 .61519 m .32177 .61858 L .32093 .61754 L F
.684 .149 0 r
.32443 .62026 m .32375 .6211 L .32248 .62013 L F
.73 .96 .68 r
.32443 .62026 m .32659 .61879 L .32708 .61729 L F
0 .019 .59 r
.32659 .61879 m .32622 .62002 L .3278 .6222 L F
.748 .608 .703 r
.28616 .55568 m .29024 .55641 L .2891 .55239 L F
.745 .62 .72 r
.28616 .55568 m .28755 .55888 L .29024 .55641 L F
0 .029 .581 r
.2891 .55239 m .29024 .55641 L .29079 .55394 L F
.574 .789 .98 r
.29079 .55394 m .29024 .55641 L .29269 .55553 L F
.878 .645 .582 r
.3063 .63606 m .31064 .63646 L .31017 .63335 L F
.909 .768 .28 r
.31287 .63229 m .3123 .63233 L .31288 .63239 L F
0 0 0 r
.313 .62998 m .31092 .63245 L .3123 .63233 L F
0 0 .458 r
.31143 .6262 m .313 .62998 L .31256 .62814 L F
.909 .768 .28 r
.31256 .62814 m .313 .62998 L .3123 .63233 L F
.31256 .62814 m .3123 .63233 L .31287 .63229 L F
0 0 0 r
.31092 .63245 m .31017 .63335 L .3123 .63233 L F
0 0 .294 r
.31017 .63335 m .31109 .63514 L .3123 .63233 L F
.31017 .63335 m .31064 .63646 L .31109 .63514 L F
.923 .803 .71 r
.30854 .63199 m .31017 .63335 L .30948 .63008 L F
.884 .809 .77 r
.2876 .59906 m .28994 .60096 L .29159 .59798 L F
.622 .891 .988 r
.43959 .52509 m .44179 .52622 L .43908 .52451 L F
.636 .57 .764 r
.32912 .61161 m .32929 .60956 L .32606 .61348 L F
.587 .36 .538 r
.54682 .38486 m .54703 .38749 L .54388 .38786 L F
.538 .443 .695 r
.54904 .38076 m .54972 .38429 L .54682 .38486 L F
.253 .118 .496 r
.5491 .38611 m .54682 .38486 L .54972 .38429 L F
.5491 .38611 m .54703 .38749 L .54682 .38486 L F
.661 .605 .782 r
.36336 .53143 m .36545 .53259 L .36421 .52908 L F
.714 .457 .536 r
.36336 .53143 m .36647 .53439 L .36545 .53259 L F
.695 .624 .773 r
.36421 .52908 m .36545 .53259 L .36791 .53138 L F
.544 .333 .545 r
.36647 .53439 m .36791 .53523 L .36545 .53259 L F
.78 .747 .823 r
.28217 .57012 m .28359 .57271 L .28557 .5699 L F
.684 .892 .529 r
.28557 .5699 m .28359 .57271 L .2843 .57149 L F
.411 .592 .918 r
.28359 .57271 m .2867 .57315 L .2843 .57149 L F
.85 .952 .88 r
.46747 .52188 m .47172 .5198 L .47022 .51867 L F
.846 .865 .856 r
.47172 .5198 m .47293 .51504 L .47022 .51867 L F
.47172 .5198 m .47467 .51654 L .47293 .51504 L F
0 .128 .645 r
.28255 .56449 m .28146 .56657 L .28051 .56247 L F
.936 .859 .739 r
.28255 .56449 m .28315 .56848 L .28146 .56657 L F
0 0 0 r
.55038 .41501 m .5475 .41883 L .54945 .41747 L F
.55147 .41402 m .55038 .41501 L .54945 .41747 L F
.622 .891 .988 r
.43959 .52509 m .44217 .5242 L .44179 .52622 L F
.44179 .52622 m .43959 .52509 L .4406 .52879 L F
.44179 .52622 m .44217 .5242 L .43959 .52509 L F
0 0 .012 r
.54945 .41747 m .5475 .41883 L .54652 .42048 L F
.814 .999 .842 r
.53856 .42829 m .53479 .43071 L .5375 .42728 L F
.108 .626 .886 r
.37397 .5566 m .3786 .55749 L .37685 .55616 L F
.699 .648 .796 r
.3786 .55749 m .37836 .55379 L .37685 .55616 L F
.3786 .55749 m .38092 .55609 L .37836 .55379 L F
0 0 0 r
.4589 .43161 m .45543 .43492 L .45774 .43362 L F
.4589 .43161 m .4598 .43218 L .46085 .43078 L F
.4589 .43161 m .45774 .43362 L .4598 .43218 L F
.53679 .35471 m .5358 .35619 L .53351 .35748 L F
.084 0 0 r
.53509 .35828 m .53351 .35748 L .5358 .35619 L F
.53509 .35828 m .53245 .35919 L .53351 .35748 L F
.799 .999 .831 r
.36575 .54363 m .36445 .54563 L .36427 .54284 L F
.651 .752 .924 r
.36445 .54563 m .36575 .54363 L .36427 .54284 L F
.612 .336 .474 r
.35833 .53531 m .36336 .53143 L .3586 .53268 L F
.35833 .53531 m .36112 .53531 L .36336 .53143 L F
.714 .457 .536 r
.36336 .53143 m .36112 .53531 L .36647 .53439 L F
.043 0 0 r
.54235 .35096 m .5388 .3525 L .53967 .35176 L F
.822 .949 .599 r
.645 .38724 m .64574 .38471 L .64522 .38556 L F
.413 .743 .993 r
.64489 .38812 m .645 .38724 L .64168 .38723 L F
.569 .327 .51 r
.64168 .38723 m .645 .38724 L .64464 .38978 L F
.822 .949 .599 r
.645 .38724 m .64522 .38556 L .64347 .38845 L F
.413 .743 .993 r
.64596 .38841 m .645 .38724 L .64489 .38812 L F
.997 .79 .437 r
.64596 .38841 m .645 .38724 L .64464 .38978 L F
.91 .934 .814 r
.64738 .38376 m .64596 .38841 L .6479 .38666 L F
.64738 .38376 m .645 .38724 L .64596 .38841 L F
.997 .79 .437 r
.64596 .38841 m .645 .38724 L .64464 .38978 L F
.936 .876 .751 r
.51644 .47455 m .52024 .4719 L .51895 .47103 L F
.51644 .47455 m .51816 .47578 L .52024 .4719 L F
.763 .936 .941 r
.52024 .4719 m .52124 .46888 L .51895 .47103 L F
.52024 .4719 m .52326 .46925 L .52124 .46888 L F
0 0 0 r
.29436 .59312 m .2916 .59687 L .2936 .59427 L F
.712 .596 .725 r
.29408 .59756 m .29436 .59312 L .2936 .59427 L F
0 0 0 r
.28695 .65235 m .28858 .65083 L .28874 .65003 L F
.519 .767 .987 r
.56691 .33882 m .56532 .34115 L .56388 .33968 L F
.56691 .33882 m .56864 .3406 L .56532 .34115 L F
.608 .076 0 r
.56864 .3406 m .56388 .33968 L .56532 .34115 L F
.5 .23 .437 r
.57086 .38413 m .57431 .38388 L .57413 .38148 L F
.57086 .38413 m .57431 .38388 L .57413 .38148 L F
.814 .546 .532 r
.28557 .5699 m .2867 .57315 L .29031 .57308 L F
.253 0 .022 r
.43034 .46441 m .42635 .46739 L .42777 .46521 L F
.05 0 0 r
.42777 .46521 m .42635 .46739 L .42404 .46837 L F
.914 .915 .805 r
.29987 .57532 m .29999 .57453 L .30031 .57173 L F
.885 .876 .822 r
.30367 .57045 m .30031 .57173 L .30057 .56947 L F
.914 .915 .805 r
.29999 .57453 m .30056 .57084 L .30031 .57173 L F
.885 .876 .822 r
.30057 .56947 m .30031 .57173 L .3002 .56935 L F
.589 .614 .845 r
.30523 .56891 m .30718 .5701 L .30367 .57045 L F
.561 .398 .618 r
.53289 .38798 m .53708 .39014 L .53701 .38818 L F
.137 0 .108 r
.53708 .39014 m .5394 .38717 L .53701 .38818 L F
.466 .162 .365 r
.53708 .39014 m .5394 .38717 L .53701 .38818 L F
.955 .941 .624 r
.2993 .58021 m .29812 .58243 L .29978 .57825 L F
.173 .665 .92 r
.38856 .58786 m .3864 .58688 L .38359 .58684 L F
.528 0 0 r
.39111 .58665 m .3864 .58688 L .38856 .58786 L F
0 0 .339 r
.58557 .38456 m .58707 .38262 L .5869 .37991 L F
.15 .308 .769 r
.58557 .38456 m .58843 .3864 L .58707 .38262 L F
0 .156 .691 r
.58557 .38456 m .58778 .38844 L .58843 .3864 L F
.049 0 0 r
.30629 .61975 m .3068 .61915 L .30397 .62002 L F
0 0 0 r
.308 .61823 m .31008 .61656 L .3068 .61915 L F
.308 .61823 m .3068 .61915 L .30629 .61975 L F
.402 .854 .888 r
.41812 .56559 m .41919 .5646 L .41943 .56171 L F
.41812 .56559 m .41649 .56547 L .41919 .5646 L F
.891 .607 .499 r
.34724 .55209 m .34407 .54846 L .34716 .54963 L F
.958 .694 .492 r
.57114 .3538 m .57101 .35645 L .57325 .35732 L F
.522 0 0 r
.57101 .35645 m .57519 .35976 L .57325 .35732 L F
.196 0 0 r
.38388 .4787 m .38674 .47833 L .3879 .47714 L F
0 0 0 r
.39041 .47636 m .3911 .47577 L .3879 .47714 L F
.60449 .36624 m .6016 .36949 L .60223 .36781 L F
.871 .493 .325 r
.65295 .33992 m .65641 .34345 L .65599 .34123 L F
.849 .69 .685 r
.64708 .35756 m .64659 .35648 L .64441 .35599 L F
.886 .936 .844 r
.64527 .35436 m .643 .35568 L .64441 .35599 L F
.069 0 0 r
.64441 .35599 m .64816 .35389 L .64527 .35436 L F
.64441 .35599 m .64562 .35578 L .64816 .35389 L F
.909 .981 .721 r
.64816 .35389 m .64562 .35578 L .64763 .3525 L F
.375 .598 .933 r
.64528 .35363 m .64562 .35578 L .64441 .35599 L F
.93 .956 .775 r
.64763 .3525 m .64562 .35578 L .64528 .35363 L F
.849 .69 .685 r
.64659 .35648 m .64528 .35363 L .64441 .35599 L F
.886 .936 .844 r
.643 .35568 m .64133 .35665 L .64441 .35599 L F
.74 .526 .604 r
.33344 .61353 m .33464 .61063 L .32929 .60956 L F
.594 .373 .549 r
.574 .3646 m .5741 .36802 L .57147 .36721 L F
.312 .321 .709 r
.57519 .35976 m .57597 .36344 L .574 .3646 L F
.542 .447 .697 r
.57597 .36344 m .5741 .36802 L .574 .3646 L F
.475 .455 .756 r
.2916 .59687 m .29408 .59756 L .2936 .59427 L F
.729 .613 .728 r
.43291 .53905 m .4371 .53952 L .437 .54357 L F
.68 .572 .727 r
.4371 .53952 m .43954 .53885 L .437 .54357 L F
.057 .61 .822 r
.437 .54357 m .43991 .54363 L .43797 .54316 L F
.599 .568 .79 r
.437 .54357 m .44137 .54434 L .44164 .54602 L F
.437 .54357 m .44164 .54602 L .43991 .54363 L F
.057 .61 .822 r
.437 .54357 m .43797 .54316 L .4366 .54448 L F
.075 .008 .469 r
.27727 .54597 m .279 .54806 L .28007 .54489 L F
.27727 .54597 m .27755 .55105 L .279 .54806 L F
.556 .862 .996 r
.60805 .34448 m .60939 .34257 L .61076 .34346 L F
.60805 .34448 m .60672 .34345 L .60939 .34257 L F
.506 .691 .951 r
.61108 .36228 m .61246 .36465 L .61444 .36192 L F
.61108 .36228 m .61246 .36465 L .61444 .36192 L F
0 .029 .581 r
.2891 .55239 m .29269 .55553 L .29415 .55363 L F
.2891 .55239 m .29079 .55394 L .29269 .55553 L F
.862 .823 .809 r
.47143 .50274 m .4668 .50484 L .46939 .50127 L F
.47143 .50274 m .46886 .50598 L .4668 .50484 L F
.72 .738 .865 r
.36758 .57303 m .36337 .57293 L .36569 .56738 L F
.794 .516 .517 r
.36758 .57303 m .36296 .57489 L .36337 .57293 L F
.36758 .57303 m .36781 .57562 L .36296 .57489 L F
.581 .378 .571 r
.59389 .34454 m .59722 .34655 L .59697 .34383 L F
.59389 .34454 m .59422 .3472 L .59722 .34655 L F
0 0 0 r
.33977 .67139 m .33969 .67187 L .33862 .67317 L F
.845 .959 .622 r
.55602 .40319 m .55426 .40734 L .55403 .40706 L F
.76 .842 .914 r
.5296 .43274 m .52485 .43389 L .52799 .43132 L F
.775 .944 .934 r
.53062 .42997 m .5296 .43274 L .52799 .43132 L F
.53062 .42997 m .53213 .43083 L .5296 .43274 L F
0 0 0 r
.4632 .44065 m .46651 .43784 L .46564 .43949 L F
.46564 .43949 m .46651 .43784 L .46874 .43672 L F
.93 .738 .622 r
.30569 .54296 m .30531 .54582 L .30348 .54205 L F
.438 .732 .989 r
.31976 .67891 m .32109 .68041 L .32319 .68003 L F
0 0 .387 r
.58776 .39689 m .58749 .39953 L .5881 .40079 L F
.125 .615 .912 r
.29816 .54284 m .30146 .54411 L .297 .54273 L F
.431 .411 .737 r
.29816 .54284 m .297 .54273 L .30146 .54411 L F
.674 .821 .954 r
.30348 .54205 m .30146 .54411 L .29816 .54284 L F
0 0 0 r
.30348 .54205 m .29998 .54581 L .30146 .54411 L F
.928 .905 .781 r
.32114 .60624 m .32015 .61075 L .31849 .60983 L F
.761 .507 .549 r
.44532 .52936 m .4407 .5318 L .4406 .52879 L F
.846 .833 .833 r
.51327 .47775 m .51552 .47936 L .51816 .47578 L F
.827 .765 .794 r
.31591 .56873 m .31693 .57226 L .31804 .56999 L F
.879 .909 .845 r
.46273 .52836 m .46649 .52654 L .46461 .52535 L F
.483 .019 .074 r
.53137 .42066 m .52964 .41883 L .5294 .42063 L F
.768 .996 .82 r
.62597 .38873 m .62826 .38798 L .62639 .38967 L F
.427 .84 .968 r
.62597 .38873 m .62613 .38908 L .62252 .38864 L F
.768 .996 .82 r
.62576 .38917 m .62639 .38967 L .62485 .39106 L F
.62613 .38908 m .62639 .38967 L .62576 .38917 L F
.62597 .38873 m .62613 .38908 L .62576 .38917 L F
.427 .84 .968 r
.62597 .38873 m .62666 .38914 L .62613 .38908 L F
.768 .996 .82 r
.62597 .38873 m .62576 .38917 L .62666 .38914 L F
.62576 .38917 m .62485 .39106 L .62666 .38914 L F
.946 .622 .193 r
.62613 .38908 m .62576 .38917 L .62252 .38864 L F
.62576 .38917 m .62384 .38965 L .62331 .38925 L F
.62576 .38917 m .62331 .38925 L .62252 .38864 L F
0 0 .536 r
.62485 .39106 m .62662 .39232 L .62666 .38914 L F
.946 .622 .193 r
.62666 .38914 m .62552 .39095 L .62384 .38965 L F
.62666 .38914 m .62384 .38965 L .62613 .38908 L F
.842 .495 .397 r
.57831 .37116 m .57907 .37168 L .57858 .36992 L F
0 .527 .831 r
.58298 .37112 m .581 .3703 L .57858 .36992 L F
.842 .495 .397 r
.57831 .37116 m .57858 .36992 L .581 .3703 L F
.345 .204 .542 r
.57858 .36992 m .581 .3703 L .58111 .3672 L F
.56 .515 .761 r
.57805 .36776 m .57858 .36992 L .58111 .3672 L F
0 0 0 r
.50615 .39395 m .50813 .39274 L .50946 .39127 L F
.50615 .39395 m .50593 .3942 L .50813 .39274 L F
.651 .752 .924 r
.36445 .54563 m .36843 .54615 L .36575 .54363 L F
.741 .611 .713 r
.36445 .54563 m .36577 .54922 L .36843 .54615 L F
.335 .621 .955 r
.36843 .54615 m .36928 .54435 L .36575 .54363 L F
.05 0 .318 r
.36843 .54615 m .37016 .54723 L .36928 .54435 L F
.36843 .54615 m .36721 .55049 L .37016 .54723 L F
.06 0 0 r
.52787 .35493 m .53101 .35413 L .53215 .35256 L F
.596 .524 .744 r
.53215 .35256 m .53664 .35463 L .53576 .35124 L F
0 .529 .709 r
.53101 .35413 m .53664 .35463 L .53215 .35256 L F
0 0 .09 r
.57839 .39279 m .57862 .39001 L .57927 .39052 L F
.576 .581 .821 r
.44551 .54637 m .44665 .54163 L .44381 .54415 L F
.44551 .54637 m .44822 .54561 L .44665 .54163 L F
.711 .735 .87 r
.44164 .54602 m .44551 .54637 L .44381 .54415 L F
.098 0 0 r
.45215 .44787 m .45414 .44777 L .45071 .45018 L F
.272 0 0 r
.40685 .46783 m .40952 .46736 L .41056 .46613 L F
0 0 0 r
.40952 .46736 m .4131 .46525 L .41056 .46613 L F
.951 .636 .397 r
.30723 .54923 m .30543 .54853 L .30531 .54582 L F
.91 .695 .6 r
.30764 .55124 m .30543 .54853 L .30723 .54923 L F
.58 .862 .537 r
.58157 .34747 m .58319 .34549 L .58366 .34511 L F
0 0 .438 r
.58157 .34747 m .58259 .34906 L .58319 .34549 L F
0 0 .211 r
.51977 .3937 m .5194 .39637 L .5177 .39752 L F
0 0 0 r
.51887 .39772 m .5177 .39752 L .5194 .39637 L F
.51887 .39772 m .51622 .39897 L .5177 .39752 L F
0 0 .029 r
.38456 .55329 m .3835 .55546 L .38626 .55201 L F
.995 .764 .415 r
.50314 .40594 m .50326 .40627 L .5044 .40633 L F
.654 .971 .862 r
.5044 .40633 m .50288 .4083 L .50562 .40639 L F
.536 .375 .609 r
.50607 .40608 m .50616 .40791 L .50288 .4083 L F
.492 .756 .989 r
.5044 .40633 m .50616 .40791 L .50288 .4083 L F
.995 .764 .415 r
.50326 .40627 m .5042 .40894 L .5044 .40633 L F
.654 .971 .862 r
.5044 .40633 m .50562 .40639 L .50607 .40608 L F
.695 .176 0 r
.41127 .48947 m .40768 .48951 L .40941 .48747 L F
.41015 .48948 m .40975 .49008 L .40768 .48951 L F
.659 .195 .141 r
.40941 .48747 m .40631 .48731 L .40763 .48564 L F
.839 .512 .435 r
.41192 .49067 m .40971 .49124 L .40768 .48951 L F
.777 .528 .559 r
.40941 .48747 m .40594 .48918 L .40631 .48731 L F
.40941 .48747 m .40768 .48951 L .40594 .48918 L F
.997 .767 .449 r
.40837 .48618 m .4095 .49045 L .40941 .48747 L F
.4095 .49045 m .40971 .49124 L .40963 .49026 L F
.4095 .49045 m .40963 .49026 L .40941 .48747 L F
.695 .176 0 r
.41127 .48947 m .41192 .49067 L .40975 .49008 L F
.41127 .48947 m .40975 .49008 L .41015 .48948 L F
.883 .625 .543 r
.40941 .48747 m .41192 .49067 L .41127 .48947 L F
.831 .999 .824 r
.33632 .62641 m .33784 .62533 L .33937 .62314 L F
.784 .302 .082 r
.35435 .53226 m .35833 .53531 L .3586 .53268 L F
.406 0 0 r
.66056 .34884 m .66467 .34871 L .6603 .34729 L F
.66056 .34884 m .66547 .34928 L .66467 .34871 L F
.984 .705 .4 r
.4917 .41586 m .49368 .41432 L .49165 .41302 L F
.861 .927 .869 r
.49165 .41302 m .49368 .41432 L .49631 .41137 L F
.049 0 0 r
.49435 .41471 m .49368 .41432 L .4917 .41586 L F
.49435 .41471 m .49648 .41416 L .49368 .41432 L F
.521 .342 .579 r
.49368 .41432 m .49648 .41416 L .49631 .41137 L F
.832 .474 .377 r
.33599 .5176 m .34115 .51957 L .3381 .51556 L F
.799 .484 .457 r
.3381 .51556 m .34115 .51957 L .34244 .5188 L F
.797 .65 .7 r
.31064 .63646 m .31186 .63997 L .30763 .63927 L F
.514 .458 .731 r
.31382 .63606 m .31186 .63997 L .31064 .63646 L F
.31382 .63606 m .31437 .63966 L .31186 .63997 L F
.182 .715 .822 r
.31186 .63997 m .31437 .63966 L .31299 .63953 L F
.046 .212 .712 r
.31186 .63997 m .31435 .64264 L .31437 .63966 L F
.182 .715 .822 r
.31186 .63997 m .31299 .63953 L .31016 .64225 L F
0 0 .382 r
.30032 .55851 m .30195 .55487 L .30384 .55591 L F
.865 .925 .865 r
.30384 .55591 m .3048 .55162 L .30613 .55472 L F
.30384 .55591 m .30195 .55487 L .3048 .55162 L F
0 0 0 r
.30397 .62002 m .30084 .62358 L .30341 .62292 L F
.049 0 0 r
.30629 .61975 m .30397 .62002 L .30341 .62292 L F
.909 .787 .714 r
.46886 .50598 m .46767 .50871 L .4668 .50484 L F
.426 .501 .833 r
.25863 .59262 m .2603 .59653 L .26151 .59411 L F
.574 .25 .382 r
.26316 .59661 m .26259 .59876 L .2603 .59653 L F
.205 .233 .669 r
.2603 .59653 m .26259 .59876 L .26151 .59411 L F
.399 .852 .797 r
.31121 .61571 m .31237 .61565 L .31008 .61656 L F
0 0 0 r
.31121 .61571 m .31008 .61656 L .308 .61823 L F
.505 0 0 r
.56274 .36352 m .56189 .36388 L .56142 .36266 L F
0 0 0 r
.28377 .64354 m .28238 .64798 L .28448 .64633 L F
.827 .765 .794 r
.31591 .56873 m .31336 .57217 L .31693 .57226 L F
.837 .718 .733 r
.31336 .57217 m .31494 .57606 L .31693 .57226 L F
.765 .615 .693 r
.32479 .60899 m .32985 .60692 L .32517 .60788 L F
.32479 .60899 m .32929 .60956 L .32985 .60692 L F
.897 .635 .533 r
.34597 .54259 m .3426 .54156 L .34298 .53901 L F
.92 .678 .556 r
.34572 .54541 m .3426 .54156 L .34597 .54259 L F
.776 .557 .603 r
.34472 .52174 m .34618 .52517 L .34837 .52216 L F
0 0 .074 r
.37508 .56601 m .37805 .56221 L .37553 .56291 L F
.839 .636 .628 r
.42986 .54975 m .42911 .55283 L .42719 .54884 L F
.76 .64 .728 r
.3088 .53242 m .30879 .53569 L .31295 .536 L F
.773 .473 .479 r
.30879 .53569 m .31267 .53863 L .31295 .536 L F
.915 .82 .738 r
.43081 .56239 m .42876 .56613 L .43188 .56598 L F
.989 .861 .618 r
.42876 .56613 m .42953 .56966 L .43188 .56598 L F
.814 .771 .813 r
.2852 .54163 m .28281 .54437 L .28814 .54458 L F
.719 .562 .676 r
.29167 .54674 m .28915 .55009 L .28814 .54458 L F
.735 .223 0 r
.29167 .54674 m .28952 .54633 L .28814 .54458 L F
.29167 .54674 m .28952 .54633 L .28814 .54458 L F
0 0 .452 r
.28814 .54458 m .28952 .54633 L .28761 .54375 L F
0 .078 .58 r
.28814 .54458 m .28761 .54375 L .28539 .54183 L F
.623 .958 .823 r
.28761 .54375 m .28572 .54528 L .28814 .54458 L F
0 0 .452 r
.28814 .54458 m .28952 .54633 L .28761 .54375 L F
.82 .855 .874 r
.28761 .54375 m .28952 .54633 L .29175 .54293 L F
.28761 .54375 m .29175 .54293 L .29065 .54311 L F
.217 .36 .794 r
.29065 .54311 m .28952 .54633 L .28761 .54375 L F
.542 .295 .49 r
.28678 .54566 m .2885 .54453 L .28761 .54375 L F
.2885 .54453 m .29065 .54311 L .28761 .54375 L F
0 .078 .58 r
.28539 .54183 m .28761 .54375 L .2852 .54163 L F
.466 .303 .575 r
.56522 .35756 m .56808 .35666 L .56804 .35413 L F
.743 .396 .393 r
.29518 .59167 m .29779 .59297 L .29808 .59091 L F
.113 0 .244 r
.29808 .59091 m .29779 .59297 L .29994 .58928 L F
.05 0 0 r
.42778 .45447 m .43028 .4536 L .43178 .45184 L F
.023 0 0 r
.43178 .45184 m .43275 .45266 L .43392 .45057 L F
.43178 .45184 m .43028 .4536 L .43275 .45266 L F
.267 0 0 r
.39358 .47493 m .39627 .47437 L .39775 .47222 L F
.302 0 .114 r
.39627 .47437 m .40028 .47111 L .39775 .47222 L F
0 0 0 r
.47116 .43574 m .47018 .43513 L .47249 .43387 L F
.47116 .43574 m .46874 .43672 L .47018 .43513 L F
.966 .923 .705 r
.62765 .38584 m .62826 .38798 L .62597 .38873 L F
0 0 .135 r
.50946 .39127 m .51111 .38664 L .51127 .38741 L F
.499 .354 .615 r
.31143 .6262 m .30948 .63008 L .30891 .62677 L F
.117 .667 .723 r
.40968 .58764 m .40646 .58802 L .40481 .58826 L F
.77 .976 .917 r
.41036 .58527 m .40968 .58764 L .41146 .58578 L F
.41036 .58527 m .40646 .58802 L .40968 .58764 L F
.835 .808 .319 r
.2993 .56321 m .29932 .56125 L .30032 .55851 L F
.974 .84 .648 r
.2993 .56321 m .29638 .56451 L .29932 .56125 L F
.2993 .56321 m .29803 .56574 L .29638 .56451 L F
0 0 0 r
.48055 .42906 m .48275 .42823 L .48515 .42745 L F
.48055 .42906 m .48478 .42758 L .48399 .42791 L F
.48478 .42758 m .48515 .42745 L .48399 .42791 L F
.478 0 0 r
.48399 .42791 m .48602 .42883 L .48372 .42803 L F
.468 .869 .962 r
.48368 .42802 m .48237 .42756 L .48055 .42906 L F
.478 0 0 r
.48399 .42791 m .48372 .42803 L .48237 .42756 L F
.496 .364 .631 r
.48237 .42756 m .48202 .42804 L .48055 .42906 L F
0 0 0 r
.47969 .42966 m .48275 .42823 L .48055 .42906 L F
.496 .364 .631 r
.48202 .42804 m .4796 .43138 L .48055 .42906 L F
0 0 0 r
.47823 .43033 m .47969 .42966 L .48055 .42906 L F
.836 .724 .741 r
.37508 .56601 m .37318 .5688 L .3776 .56932 L F
.857 .694 .679 r
.37277 .5715 m .3776 .56932 L .37318 .5688 L F
.37277 .5715 m .37634 .57333 L .3776 .56932 L F
0 .128 .663 r
.3776 .56932 m .37777 .56853 L .37508 .56601 L F
.045 .537 .883 r
.3776 .56932 m .38043 .57005 L .37777 .56853 L F
.676 .271 .27 r
.57424 .38672 m .57086 .38413 L .57431 .38388 L F
.57424 .38672 m .56988 .38643 L .57086 .38413 L F
.194 .35 .793 r
.57086 .38413 m .57424 .38672 L .57431 .38388 L F
.677 .732 .892 r
.64738 .38376 m .6479 .38666 L .64839 .38614 L F
0 0 0 r
.53829 .35371 m .53679 .35471 L .5388 .3525 L F
.54009 .35352 m .5378 .35485 L .53829 .35371 L F
.53936 .35294 m .53829 .35371 L .5388 .3525 L F
.54009 .35352 m .53829 .35371 L .53908 .35314 L F
.032 0 .019 r
.54009 .35352 m .5384 .35339 L .53908 .35314 L F
.54009 .35352 m .53908 .35314 L .54109 .35242 L F
0 0 0 r
.54009 .35352 m .53908 .35314 L .53936 .35294 L F
.095 0 0 r
.54235 .35096 m .54109 .35242 L .5388 .3525 L F
0 0 0 r
.54009 .35352 m .53936 .35294 L .54109 .35242 L F
.53936 .35294 m .5388 .3525 L .54109 .35242 L F
.522 .406 .663 r
.53918 .353 m .53863 .3533 L .53908 .35314 L F
.54012 .35158 m .5388 .35311 L .53918 .353 L F
.5388 .35311 m .53863 .3533 L .53918 .353 L F
.54065 .35204 m .53908 .35314 L .54109 .35242 L F
.54012 .35158 m .53908 .35314 L .54065 .35204 L F
.53767 .34947 m .5384 .35339 L .53863 .3533 L F
.53767 .34947 m .53863 .3533 L .54012 .35158 L F
0 0 0 r
.5378 .35485 m .53735 .35479 L .53829 .35371 L F
.53735 .35479 m .53679 .35471 L .53829 .35371 L F
.5378 .35485 m .5358 .35619 L .53679 .35471 L F
.3316 .62623 m .32988 .62751 L .32757 .63014 L F
.778 .768 .844 r
.46503 .5114 m .46199 .51265 L .46464 .50922 L F
.359 .581 .926 r
.62501 .38247 m .62651 .38506 L .62381 .38458 L F
.939 .826 .705 r
.62651 .38506 m .62501 .38247 L .62381 .38458 L F
.82 .421 0 r
.62712 .38584 m .62651 .38506 L .62381 .38458 L F
.94 .68 .516 r
.34049 .53263 m .33797 .53391 L .33682 .53091 L F
.34049 .53263 m .34032 .53532 L .33797 .53391 L F
.137 .122 .576 r
.26417 .56617 m .26603 .56831 L .26645 .56551 L F
.26417 .56617 m .26486 .56936 L .26603 .56831 L F
.936 .705 .564 r
.66673 .3596 m .66982 .35779 L .66813 .35609 L F
.66673 .3596 m .66956 .36057 L .66982 .35779 L F
.987 .82 .589 r
.53791 .40625 m .53761 .40932 L .53571 .40622 L F
.667 .97 .912 r
.5402 .40465 m .53791 .40625 L .53571 .40622 L F
.752 .704 .807 r
.36977 .55566 m .37397 .5566 L .37243 .5559 L F
.608 .916 .977 r
.37505 .5546 m .37397 .5566 L .37685 .55616 L F
.37505 .5546 m .37243 .5559 L .37397 .5566 L F
0 .221 .694 r
.66547 .34928 m .66628 .34983 L .66757 .35117 L F
.695 .339 0 r
.66628 .34983 m .66801 .35374 L .66757 .35117 L F
.84 .891 .876 r
.29175 .54293 m .28952 .54633 L .29167 .54674 L F
.217 .36 .794 r
.29075 .54341 m .29081 .54361 L .2906 .54326 L F
.29081 .54361 m .29154 .54589 L .29069 .54351 L F
.29081 .54361 m .29069 .54351 L .2906 .54326 L F
.84 .891 .876 r
.29175 .54293 m .29167 .54674 L .29368 .54519 L F
.396 .752 .993 r
.29368 .54519 m .29448 .54365 L .29175 .54293 L F
.773 .721 .805 r
.29448 .54365 m .2921 .54765 L .29065 .54311 L F
.29448 .54365 m .29225 .5449 L .29166 .54431 L F
.712 .576 .7 r
.297 .54273 m .29803 .54581 L .29368 .54519 L F
.396 .752 .993 r
.29368 .54519 m .29803 .54581 L .29448 .54365 L F
.692 .612 .762 r
.29448 .54365 m .29646 .54822 L .2921 .54765 L F
0 .113 .66 r
.2963 .54592 m .29646 .54822 L .29448 .54365 L F
.704 .317 .313 r
.29166 .54431 m .29211 .54447 L .29448 .54365 L F
.217 .36 .794 r
.2906 .54326 m .29154 .54589 L .28952 .54633 L F
.731 .927 .585 r
.29054 .54786 m .28996 .54901 L .29167 .54674 L F
.217 .36 .794 r
.29154 .54589 m .2921 .54765 L .29094 .54706 L F
.29154 .54589 m .29094 .54706 L .28952 .54633 L F
.684 .632 .792 r
.29646 .54822 m .29296 .55097 L .2921 .54765 L F
.802 .587 .611 r
.29101 .5456 m .29414 .54911 L .29082 .54451 L F
.773 .721 .805 r
.29166 .54431 m .29142 .54478 L .29082 .54451 L F
.713 .537 .649 r
.29082 .54451 m .29414 .54911 L .29533 .54736 L F
.29082 .54451 m .29533 .54736 L .29201 .54504 L F
.773 .721 .805 r
.29142 .54478 m .29101 .5456 L .29082 .54451 L F
.29225 .5449 m .29101 .5456 L .29166 .54431 L F
.29201 .54504 m .29091 .54488 L .29101 .5456 L F
.29448 .54365 m .29149 .54468 L .29201 .54504 L F
.29149 .54468 m .29091 .54488 L .29201 .54504 L F
.713 .537 .649 r
.29201 .54504 m .29533 .54736 L .29576 .54672 L F
.773 .721 .805 r
.29448 .54365 m .29065 .54311 L .29081 .5442 L F
.713 .537 .649 r
.29082 .54451 m .29201 .54504 L .29149 .54468 L F
.773 .721 .805 r
.29149 .54468 m .29081 .5442 L .29091 .54488 L F
.704 .317 .313 r
.29082 .54451 m .29149 .54468 L .29166 .54431 L F
.29149 .54468 m .29238 .54491 L .29192 .54453 L F
.29149 .54468 m .29192 .54453 L .29166 .54431 L F
.29238 .54491 m .2963 .54592 L .29166 .54431 L F
.773 .721 .805 r
.29448 .54365 m .29081 .5442 L .29149 .54468 L F
.713 .537 .649 r
.29149 .54468 m .29576 .54672 L .2963 .54592 L F
.29201 .54504 m .29576 .54672 L .29149 .54468 L F
.704 .317 .313 r
.29211 .54447 m .2963 .54592 L .29448 .54365 L F
.217 .36 .794 r
.29065 .54311 m .29075 .54341 L .2906 .54326 L F
.731 .927 .585 r
.28993 .54846 m .28915 .55009 L .28996 .54901 L F
.28993 .54846 m .28996 .54901 L .29054 .54786 L F
.874 .862 .825 r
.47293 .51504 m .47467 .51654 L .47709 .51281 L F
.086 0 .407 r
.28611 .5392 m .28699 .53458 L .28542 .5365 L F
.28611 .5392 m .28818 .53804 L .28699 .53458 L F
0 0 .39 r
.28699 .53458 m .28902 .53658 L .29008 .53471 L F
.28699 .53458 m .28818 .53804 L .28902 .53658 L F
.92 .914 .796 r
.54263 .43932 m .54293 .4426 L .54512 .43887 L F
.959 .926 .724 r
.5416 .4446 m .54293 .4426 L .54263 .43932 L F
.566 .48 .718 r
.25527 .58943 m .25863 .59262 L .25735 .58861 L F
.25527 .58943 m .25625 .59382 L .25863 .59262 L F
.695 .624 .773 r
.36421 .52908 m .36791 .53138 L .36669 .5291 L F
.738 .773 .882 r
.36669 .5291 m .36791 .53138 L .37075 .52865 L F
0 .35 .823 r
.34652 .63491 m .34851 .63734 L .34714 .63658 L F
.913 .709 .614 r
.35459 .6422 m .3575 .63999 L .3549 .63829 L F
.35459 .6422 m .35656 .64275 L .3575 .63999 L F
.731 .601 .711 r
.43564 .53562 m .4371 .53952 L .43291 .53905 L F
.762 .555 .616 r
.43564 .53562 m .43954 .53885 L .4371 .53952 L F
0 0 0 r
.58778 .38844 m .58793 .38921 L .58843 .3864 L F
.58778 .38844 m .58633 .39113 L .58793 .38921 L F
.643 .843 .977 r
.41544 .57295 m .41958 .57346 L .41808 .57185 L F
.129 0 0 r
.33151 .63452 m .32787 .63596 L .33079 .63501 L F
.492 .42 .704 r
.33151 .63452 m .33347 .62986 L .33072 .6311 L F
.33151 .63452 m .33398 .63368 L .33347 .62986 L F
.027 0 0 r
.33079 .63501 m .33398 .63368 L .33151 .63452 L F
.871 .669 .627 r
.36383 .54839 m .36577 .54922 L .36445 .54563 L F
.748 .425 .437 r
.36151 .55162 m .36577 .54922 L .36383 .54839 L F
.36151 .55162 m .36593 .55203 L .36577 .54922 L F
.679 .37 .445 r
.36593 .55203 m .36877 .55202 L .36577 .54922 L F
.58 .941 .905 r
.61788 .34126 m .61943 .33954 L .62032 .33939 L F
.61788 .34126 m .61529 .34161 L .61943 .33954 L F
0 .418 .854 r
.32787 .63596 m .32411 .63338 L .3275 .63247 L F
.686 .679 .837 r
.32996 .63171 m .32787 .63596 L .3275 .63247 L F
.32996 .63171 m .33079 .63501 L .32787 .63596 L F
0 0 0 r
.26988 .59336 m .26637 .59565 L .26618 .59244 L F
.26988 .59336 m .26777 .59475 L .26637 .59565 L F
.334 0 .193 r
.27182 .59134 m .26777 .59475 L .26988 .59336 L F
.677 .482 .614 r
.30378 .53229 m .30857 .52933 L .30474 .52902 L F
.089 0 0 r
.37667 .57401 m .37908 .57386 L .38117 .57308 L F
0 0 0 r
.38117 .57308 m .38146 .57299 L .38378 .57244 L F
.38117 .57308 m .37908 .57386 L .38146 .57299 L F
.828 .727 .753 r
.31505 .62304 m .31143 .6262 L .3116 .62336 L F
0 0 .054 r
.58105 .35413 m .5796 .35784 L .58124 .35556 L F
.268 .257 .661 r
.57919 .35909 m .58124 .35556 L .5796 .35784 L F
.995 .842 .579 r
.506 .42186 m .50606 .42489 L .50427 .4231 L F
.827 .947 .593 r
.50606 .42489 m .50435 .42613 L .50427 .4231 L F
.50606 .42489 m .50386 .42829 L .50435 .42613 L F
.724 .621 .743 r
.50901 .42124 m .50606 .42489 L .506 .42186 L F
.839 .92 .888 r
.66364 .37465 m .66539 .37027 L .6627 .37352 L F
.66364 .37465 m .66666 .37184 L .66539 .37027 L F
.459 .862 .965 r
.5741 .36802 m .57684 .36723 L .57805 .36776 L F
.503 .289 .521 r
.57805 .36776 m .58111 .3672 L .58124 .36422 L F
.582 .921 .965 r
.57805 .36776 m .57943 .366 L .58111 .3672 L F
.57805 .36776 m .57684 .36723 L .57943 .366 L F
.088 .204 .691 r
.58124 .36422 m .58119 .35983 L .57919 .35909 L F
.58124 .36422 m .58266 .36237 L .58119 .35983 L F
0 0 .205 r
.58124 .36422 m .58221 .36498 L .58266 .36237 L F
.58124 .36422 m .58111 .3672 L .58221 .36498 L F
.686 .631 .788 r
.57877 .37538 m .5768 .37801 L .57539 .37399 L F
.681 .624 .784 r
.5804 .37724 m .5768 .37801 L .57877 .37538 L F
0 0 0 r
.55638 .39793 m .55942 .39668 L .55908 .39614 L F
.635 .266 .326 r
.55942 .39668 m .56336 .39426 L .55908 .39614 L F
0 0 .035 r
.59536 .39201 m .59429 .39161 L .59527 .38984 L F
.59536 .39201 m .59354 .39394 L .59429 .39161 L F
.801 .9 .912 r
.6148 .34895 m .61912 .34766 L .61817 .34714 L F
.637 .96 .914 r
.6215 .34611 m .62065 .34567 L .61912 .34766 L F
.629 .951 .937 r
.62065 .34567 m .61817 .34714 L .61912 .34766 L F
.438 .249 .525 r
.60145 .38277 m .59886 .38122 L .60168 .38124 L F
.60145 .38277 m .59851 .38383 L .59886 .38122 L F
0 0 .455 r
.58298 .37112 m .58269 .37039 L .581 .3703 L F
.58298 .37112 m .5845 .37324 L .58269 .37039 L F
.798 .789 .844 r
.64341 .36708 m .63918 .37094 L .64013 .36684 L F
0 0 0 r
.44275 .45486 m .44623 .45267 L .44523 .45359 L F
.44523 .45359 m .44623 .45267 L .44839 .45131 L F
.744 .992 .815 r
.38378 .57244 m .38212 .57284 L .38223 .57164 L F
.38212 .57284 m .38146 .57299 L .38183 .57234 L F
.38212 .57284 m .38183 .57234 L .38223 .57164 L F
0 .287 .738 r
.38111 .57119 m .38123 .57129 L .38114 .57179 L F
.515 .726 .969 r
.38223 .57164 m .38146 .57299 L .38114 .57179 L F
0 .287 .738 r
.38123 .57129 m .38286 .57271 L .38169 .57208 L F
.515 .726 .969 r
.38223 .57164 m .38114 .57179 L .38203 .57025 L F
0 .287 .738 r
.38123 .57129 m .38169 .57208 L .38114 .57179 L F
.904 .498 .105 r
.38159 .57069 m .38286 .57271 L .38111 .57119 L F
.38203 .57025 m .38231 .57108 L .38159 .57069 L F
.63 .963 .868 r
.38378 .57244 m .38366 .57238 L .38633 .57087 L F
.38366 .57238 m .38223 .57164 L .38433 .57125 L F
.38366 .57238 m .38433 .57125 L .38633 .57087 L F
.957 .92 .729 r
.38633 .57087 m .38306 .57149 L .38343 .57026 L F
.481 0 0 r
.38395 .56952 m .38633 .57087 L .38739 .5711 L F
.957 .92 .729 r
.38633 .57087 m .38343 .57026 L .38449 .56902 L F
0 0 .242 r
.38452 .5734 m .38543 .5719 L .38524 .56969 L F
.957 .92 .729 r
.38633 .57087 m .38449 .56902 L .39142 .57027 L F
0 0 .242 r
.38509 .56995 m .38524 .56969 L .38521 .56926 L F
.38452 .5734 m .38524 .56969 L .38509 .56995 L F
.858 .652 .623 r
.38449 .56902 m .38223 .57164 L .38327 .5667 L F
.38449 .56902 m .38223 .57164 L .38327 .5667 L F
.776 .567 .616 r
.38327 .5667 m .38223 .57164 L .38203 .57025 L F
.38327 .5667 m .38223 .57164 L .38203 .57025 L F
.904 .498 .105 r
.38231 .57108 m .38286 .57271 L .38159 .57069 L F
.957 .92 .729 r
.38306 .57149 m .38223 .57164 L .38259 .57123 L F
.38306 .57149 m .38259 .57123 L .38343 .57026 L F
.481 0 0 r
.38739 .5711 m .38633 .57087 L .38832 .57152 L F
.5 .466 .751 r
.39142 .57027 m .38832 .57152 L .38633 .57087 L F
.39142 .57027 m .39059 .57164 L .38832 .57152 L F
.807 .706 .753 r
.30258 .58945 m .29994 .58928 L .29833 .58533 L F
.768 .707 .794 r
.29994 .58928 m .30431 .58976 L .30265 .58599 L F
.779 .673 .746 r
.30167 .59337 m .30431 .58976 L .29994 .58928 L F
.665 .254 .257 r
.39141 .56915 m .39569 .56912 L .3939 .56694 L F
.757 .653 .746 r
.32606 .61348 m .32929 .60956 L .32479 .60899 L F
0 0 0 r
.49127 .42112 m .49039 .4213 L .48813 .42175 L F
.49385 .42073 m .49127 .42112 L .49375 .42041 L F
.49385 .42073 m .49039 .4213 L .49127 .42112 L F
.711 .705 .843 r
.6047 .37741 m .60189 .37836 L .60074 .37725 L F
.595 .419 .614 r
.6047 .37741 m .60168 .38124 L .60189 .37836 L F
.961 .821 .659 r
.42484 .55208 m .42617 .55591 L .42439 .55478 L F
.749 .979 .916 r
.42617 .55591 m .42089 .55762 L .42439 .55478 L F
.766 .752 .84 r
.42484 .55208 m .42911 .55283 L .42617 .55591 L F
.711 .356 .373 r
.55604 .3815 m .5521 .38327 L .55135 .38023 L F
.55604 .3815 m .55654 .38364 L .5521 .38327 L F
.793 .41 .331 r
.56071 .38447 m .55654 .38364 L .55604 .3815 L F
.905 .498 .196 r
.54208 .40609 m .54302 .40533 L .5402 .40465 L F
.54208 .40609 m .54407 .40784 L .54302 .40533 L F
.864 .979 .682 r
.57998 .38258 m .57962 .38425 L .58145 .38197 L F
.924 .96 .644 r
.58178 .37877 m .58145 .38197 L .58375 .3806 L F
.67 .797 .943 r
.51934 .40464 m .52199 .40339 L .52169 .40071 L F
.483 .84 .58 r
.52223 .40026 m .52342 .39917 L .52491 .39805 L F
0 0 .082 r
.5242 .40058 m .52435 .39831 L .52342 .39917 L F
.389 .637 .954 r
.52342 .39917 m .52453 .39432 L .5254 .39746 L F
0 0 .082 r
.52435 .39831 m .52444 .39697 L .52342 .39917 L F
.483 .84 .58 r
.52169 .40071 m .52342 .39917 L .52223 .40026 L F
.537 .565 .831 r
.52199 .40339 m .52342 .39917 L .52169 .40071 L F
.646 .243 .266 r
.34115 .51957 m .34023 .52141 L .34244 .5188 L F
.847 .515 .424 r
.34244 .5188 m .34023 .52141 L .34472 .52174 L F
.619 .149 .116 r
.40763 .48564 m .40631 .48731 L .40308 .48545 L F
.92 .914 .796 r
.54263 .43932 m .54512 .43887 L .54385 .43769 L F
.9 .939 .574 r
.54512 .43887 m .54647 .43436 L .54385 .43769 L F
.743 .983 .759 r
.31545 .61239 m .31237 .61565 L .31121 .61571 L F
.86 .621 .575 r
.41312 .58161 m .41444 .57964 L .41256 .57871 L F
.41312 .58161 m .41442 .58256 L .41444 .57964 L F
.875 .88 .836 r
.47738 .48809 m .47408 .48826 L .47562 .48647 L F
.47738 .48809 m .47586 .4894 L .47408 .48826 L F
.771 .882 .926 r
.48071 .48529 m .47738 .48809 L .47562 .48647 L F
.773 .679 .76 r
.54259 .38419 m .54388 .38786 L .5394 .38717 L F
.251 0 0 r
.54703 .38749 m .54215 .39028 L .54388 .38786 L F
.26 .637 .963 r
.58366 .34511 m .58666 .34543 L .5881 .34701 L F
.964 .831 .409 r
.58725 .34712 m .5881 .34701 L .58666 .34543 L F
.58725 .34712 m .5874 .35033 L .5881 .34701 L F
.967 .642 .305 r
.51226 .44841 m .51071 .44924 L .51081 .44698 L F
.51226 .44841 m .51279 .45136 L .51071 .44924 L F
.686 .491 .617 r
.40363 .48218 m .40308 .48545 L .40161 .48345 L F
0 0 0 r
.44383 .45589 m .44275 .45486 L .44523 .45359 L F
.44383 .45589 m .44175 .45703 L .44275 .45486 L F
.69 .683 .838 r
.43401 .53182 m .43564 .53562 L .43149 .53476 L F
.734 .605 .714 r
.43564 .53562 m .43291 .53905 L .43149 .53476 L F
.679 .859 .457 r
.43641 .53397 m .43564 .53562 L .43401 .53182 L F
.43641 .53397 m .43826 .5313 L .43564 .53562 L F
0 0 .135 r
.50946 .39127 m .51075 .3892 L .51111 .38664 L F
.644 .868 .5 r
.50946 .39127 m .50813 .39274 L .51075 .3892 L F
.297 .098 .432 r
.26244 .57239 m .26429 .57195 L .26486 .56936 L F
.269 .104 .464 r
.26182 .57508 m .26429 .57195 L .26244 .57239 L F
.878 .652 .591 r
.31993 .55522 m .32201 .55651 L .32004 .55251 L F
.198 .283 .726 r
.27917 .65486 m .27821 .65437 L .27713 .65289 L F
.846 .833 .833 r
.51327 .47775 m .51816 .47578 L .51644 .47455 L F
.813 1 .819 r
.49698 .49511 m .49777 .49259 L .49567 .49435 L F
.49698 .49511 m .49993 .49209 L .49777 .49259 L F
0 0 .279 r
.58633 .39113 m .58751 .39197 L .58793 .38921 L F
.58633 .39113 m .58639 .39415 L .58751 .39197 L F
.698 .943 .651 r
.50625 .4302 m .50495 .4323 L .50669 .43023 L F
.628 .884 .988 r
.50301 .43138 m .50495 .4323 L .50625 .4302 L F
0 .527 .759 r
.30536 .67729 m .30956 .67799 L .30771 .67717 L F
.548 .881 .989 r
.30956 .67799 m .31037 .6765 L .30771 .67717 L F
.30956 .67799 m .31204 .6771 L .31037 .6765 L F
.712 .221 .076 r
.30808 .63774 m .31064 .63646 L .3063 .63606 L F
.674 .96 .737 r
.31109 .63514 m .31064 .63646 L .30808 .63774 L F
.118 0 .082 r
.28614 .63751 m .28334 .63952 L .28612 .63958 L F
.076 .083 .562 r
.28334 .63952 m .28544 .64235 L .28612 .63958 L F
.28334 .63952 m .28377 .64354 L .28544 .64235 L F
.183 0 .197 r
.56321 .38179 m .56346 .38329 L .56071 .38447 L F
.855 .663 .643 r
.56691 .38158 m .56346 .38329 L .56321 .38179 L F
.792 .838 .887 r
.29638 .59522 m .30167 .59337 L .29779 .59297 L F
.994 .857 .514 r
.36445 .54563 m .36253 .54753 L .36383 .54839 L F
.799 .999 .831 r
.36575 .54363 m .36435 .54384 L .36445 .54563 L F
.749 .645 .746 r
.35818 .5441 m .36389 .54538 L .36086 .54045 L F
.868 .94 .57 r
.36439 .54457 m .36317 .5469 L .36445 .54563 L F
.36438 .54435 m .36389 .54538 L .36439 .54457 L F
.36388 .54539 m .36317 .5469 L .36386 .54559 L F
.36394 .54531 m .36386 .54559 L .36435 .54466 L F
.36388 .54539 m .36386 .54559 L .36394 .54531 L F
.419 .51 .845 r
.36086 .54045 m .36395 .54524 L .36435 .54384 L F
.868 .94 .57 r
.36389 .54538 m .36388 .54539 L .36439 .54457 L F
.766 .503 .537 r
.35827 .54693 m .36253 .54753 L .36382 .54549 L F
.35827 .54693 m .36382 .54549 L .35818 .5441 L F
.36382 .54549 m .36389 .54538 L .35818 .5441 L F
.749 .645 .746 r
.36389 .54538 m .36395 .54524 L .36086 .54045 L F
.868 .94 .57 r
.36435 .54384 m .36317 .5469 L .36438 .54435 L F
.419 .51 .845 r
.36395 .54524 m .36407 .54542 L .36435 .54384 L F
.766 .503 .537 r
.36382 .54549 m .36253 .54753 L .36407 .54542 L F
.868 .94 .57 r
.36388 .54539 m .36435 .54466 L .36439 .54457 L F
.766 .503 .537 r
.36382 .54549 m .36407 .54542 L .36389 .54538 L F
.749 .645 .746 r
.36389 .54538 m .36407 .54542 L .36395 .54524 L F
.868 .94 .57 r
.36435 .54384 m .36253 .54753 L .36317 .5469 L F
.748 .757 .86 r
.3592 .57072 m .36019 .57092 L .35909 .56943 L F
.796 .424 .353 r
.36337 .57293 m .36296 .57489 L .36019 .57092 L F
.36337 .57293 m .36296 .57489 L .36019 .57092 L F
.463 .16 .366 r
.29416 .64025 m .29615 .64222 L .29368 .64296 L F
.29416 .64025 m .29702 .6398 L .29615 .64222 L F
.156 0 .01 r
.42155 .46933 m .42404 .46837 L .42063 .47075 L F
.837 .812 .826 r
.46034 .50798 m .46199 .51265 L .45954 .50996 L F
.861 .869 .843 r
.46199 .51265 m .45669 .51382 L .45954 .50996 L F
.46199 .51265 m .4588 .515 L .45669 .51382 L F
.716 .752 .881 r
.46464 .50922 m .46199 .51265 L .46034 .50798 L F
.861 .927 .869 r
.49165 .41302 m .49631 .41137 L .49488 .41047 L F
.548 .795 .99 r
.49631 .41137 m .49901 .41083 L .49705 .40877 L F
.731 .961 .942 r
.49705 .40877 m .49488 .41047 L .49631 .41137 L F
.504 .31 .551 r
.49648 .41416 m .49901 .41083 L .49631 .41137 L F
.715 .243 .127 r
.53761 .40932 m .53358 .40967 L .53571 .40622 L F
.53761 .40932 m .53719 .4103 L .53358 .40967 L F
.121 .638 .889 r
.50422 .41628 m .50813 .41702 L .50709 .41417 L F
.734 .828 .372 r
.50813 .41702 m .506 .42186 L .50673 .41968 L F
.738 .596 .698 r
.50901 .42124 m .506 .42186 L .50813 .41702 L F
.423 .33 .646 r
.51053 .41666 m .50901 .42124 L .50813 .41702 L F
.51053 .41666 m .51192 .42077 L .50901 .42124 L F
.374 0 .105 r
.50995 .41931 m .50813 .41702 L .50673 .41968 L F
.50995 .41931 m .51053 .41666 L .50813 .41702 L F
0 0 .165 r
.58105 .35413 m .5817 .35325 L .58259 .34906 L F
0 0 .061 r
.58105 .35413 m .58124 .35556 L .5817 .35325 L F
.874 .851 .817 r
.46028 .51901 m .45772 .52249 L .45582 .52115 L F
.315 0 0 r
.31016 .65042 m .31123 .6517 L .3088 .65281 L F
.31016 .65042 m .31346 .65043 L .31123 .6517 L F
.542 .829 .998 r
.63025 .35347 m .62637 .35295 L .62748 .35426 L F
.63025 .35347 m .62637 .35295 L .62748 .35426 L F
0 .02 .593 r
.51037 .42249 m .50901 .42124 L .51192 .42077 L F
.78 .747 .823 r
.28217 .57012 m .28557 .5699 L .28315 .56848 L F
.809 .543 .537 r
.2843 .57149 m .2867 .57315 L .28557 .5699 L F
.808 .868 .426 r
.30467 .53953 m .30385 .54023 L .30346 .53845 L F
.30467 .53953 m .30348 .54205 L .30385 .54023 L F
.832 .716 .737 r
.31336 .57217 m .31082 .57588 L .31494 .57606 L F
.828 .736 .763 r
.31082 .57588 m .31239 .57962 L .31494 .57606 L F
.832 .685 .7 r
.46028 .51901 m .45658 .51851 L .4588 .515 L F
.874 .851 .817 r
.46028 .51901 m .45582 .52115 L .45658 .51851 L F
.887 .933 .843 r
.47866 .5085 m .47709 .51281 L .47979 .5094 L F
.921 .946 .797 r
.48105 .5051 m .47866 .5085 L .47979 .5094 L F
0 0 0 r
.48245 .41165 m .4796 .41481 L .48154 .41294 L F
.508 .842 .556 r
.48154 .41294 m .4796 .41481 L .47799 .41616 L F
.405 .117 .359 r
.54904 .38076 m .55135 .38023 L .55203 .37778 L F
.54904 .38076 m .55135 .38023 L .55203 .37778 L F
.528 0 0 r
.39111 .58665 m .38902 .58767 L .3864 .58688 L F
.685 .959 .945 r
.39196 .58464 m .39111 .58665 L .39306 .58533 L F
.563 .774 .978 r
.38632 .58668 m .38961 .58648 L .38681 .58312 L F
.38961 .58648 m .39053 .58642 L .38972 .5857 L F
.38961 .58648 m .38972 .5857 L .38681 .58312 L F
.811 .731 .777 r
.3899 .58283 m .39461 .58097 L .39293 .57965 L F
.3899 .58283 m .39196 .58464 L .39461 .58097 L F
.818 .49 .435 r
.3866 .58305 m .3899 .58283 L .38751 .58318 L F
.38654 .58295 m .3899 .58283 L .3866 .58305 L F
.066 .63 .738 r
.38661 .58294 m .3899 .58283 L .38588 .58297 L F
.75 .831 .914 r
.38661 .58294 m .38741 .58319 L .3899 .58283 L F
.38741 .58319 m .39196 .58464 L .3899 .58283 L F
.818 .49 .435 r
.38751 .58318 m .3899 .58283 L .38993 .58351 L F
.701 .963 .717 r
.39038 .58121 m .3899 .58283 L .39293 .57965 L F
0 0 .123 r
.38996 .58409 m .38993 .58351 L .39037 .58125 L F
.38993 .58351 m .3899 .58283 L .39004 .58236 L F
.38993 .58351 m .39004 .58236 L .39037 .58125 L F
.75 .831 .914 r
.38989 .58398 m .39054 .5864 L .39196 .58464 L F
.38974 .58559 m .39054 .58642 L .38989 .58398 L F
.38681 .58312 m .39054 .58642 L .38741 .58319 L F
.818 .49 .435 r
.3866 .58305 m .38993 .58351 L .38681 .58312 L F
.563 .774 .978 r
.39037 .58628 m .39038 .58627 L .38661 .58294 L F
.39053 .58642 m .39038 .58627 L .39037 .58628 L F
.39053 .58642 m .39054 .58641 L .39038 .58627 L F
.616 .287 .391 r
.3864 .58688 m .39053 .58642 L .38632 .58668 L F
.754 .984 .75 r
.39092 .58571 m .39015 .58712 L .39111 .58665 L F
.616 .287 .391 r
.39053 .58642 m .39054 .58642 L .39053 .58642 L F
.39053 .58642 m .39053 .58642 L .38632 .58668 L F
.754 .984 .75 r
.39037 .58651 m .38902 .58767 L .38985 .58726 L F
.39092 .58571 m .38987 .58679 L .39037 .58651 L F
.616 .287 .391 r
.39053 .58642 m .38902 .58767 L .39054 .58642 L F
.3864 .58688 m .38902 .58767 L .39053 .58642 L F
.754 .984 .75 r
.39092 .58571 m .3903 .58661 L .39054 .58641 L F
.3903 .58661 m .38985 .58726 L .39053 .58642 L F
.3903 .58661 m .39053 .58642 L .39054 .58641 L F
.38987 .58679 m .38902 .58767 L .39037 .58651 L F
.39054 .58641 m .38985 .58726 L .39015 .58712 L F
.39196 .58464 m .39092 .58571 L .39111 .58665 L F
.75 .831 .914 r
.39054 .5864 m .39054 .58642 L .39196 .58464 L F
.38741 .58319 m .38974 .58559 L .38989 .58398 L F
.38661 .58294 m .38681 .58312 L .38741 .58319 L F
.818 .49 .435 r
.38681 .58312 m .38993 .58351 L .38996 .58409 L F
.563 .774 .978 r
.3866 .58305 m .38652 .58292 L .38467 .58261 L F
.818 .49 .435 r
.38629 .58296 m .38654 .58295 L .3866 .58305 L F
.563 .774 .978 r
.38632 .58668 m .3866 .58305 L .38467 .58261 L F
.3866 .58305 m .38661 .58294 L .38652 .58292 L F
0 0 .123 r
.39006 .5863 m .38996 .58409 L .39038 .58121 L F
.38996 .58409 m .39037 .58125 L .39038 .58121 L F
.563 .774 .978 r
.38632 .58668 m .38681 .58312 L .3866 .58305 L F
.818 .49 .435 r
.38588 .58297 m .38629 .58296 L .39006 .5863 L F
.38629 .58296 m .38996 .58409 L .39006 .5863 L F
.563 .774 .978 r
.3866 .58305 m .38681 .58312 L .38661 .58294 L F
.39053 .58642 m .39054 .58642 L .39054 .58641 L F
.584 .709 .929 r
.39974 .58633 m .40203 .58943 L .40481 .58826 L F
.982 .694 .347 r
.36337 .57293 m .3618 .57408 L .36253 .57179 L F
.36337 .57293 m .36296 .57489 L .3618 .57408 L F
.798 .524 .524 r
.56071 .38447 m .55627 .38639 L .55654 .38364 L F
.56071 .38447 m .56112 .38713 L .55627 .38639 L F
.267 .115 .481 r
.56346 .38329 m .56112 .38713 L .56071 .38447 L F
0 0 0 r
.3275 .63247 m .33072 .6311 L .32996 .63171 L F
.006 0 0 r
.33072 .6311 m .3317 .63162 L .32996 .63171 L F
.33072 .6311 m .33347 .62986 L .3317 .63162 L F
.327 0 .246 r
.27343 .57801 m .27227 .58149 L .2697 .58224 L F
.566 .7 .932 r
.27448 .57535 m .27343 .57801 L .27197 .57566 L F
.27448 .57535 m .27592 .57741 L .27343 .57801 L F
.189 0 .108 r
.27592 .57741 m .27227 .58149 L .27343 .57801 L F
.714 .229 .091 r
.38501 .5609 m .38743 .56315 L .38925 .56271 L F
.727 .602 .716 r
.43149 .53476 m .43291 .53905 L .42885 .53911 L F
.727 .578 .688 r
.42885 .53911 m .43291 .53905 L .43036 .5425 L F
0 0 0 r
.38369 .55828 m .38762 .55585 L .38617 .55491 L F
.682 .959 .722 r
.3204 .63007 m .32308 .62757 L .32147 .62845 L F
0 0 .07 r
.31976 .63284 m .3204 .63007 L .32147 .62845 L F
0 0 0 r
.48245 .41165 m .48266 .41141 L .48458 .41019 L F
.48245 .41165 m .48154 .41294 L .48266 .41141 L F
.885 .934 .845 r
.41162 .47827 m .41054 .48215 L .41246 .47823 L F
0 0 0 r
.41535 .47505 m .41408 .47701 L .41246 .47823 L F
.463 .886 .804 r
.41246 .47823 m .41408 .47701 L .41162 .47827 L F
.762 .902 .939 r
.66539 .37027 m .66666 .37184 L .66866 .37003 L F
.385 .338 .682 r
.26018 .58232 m .26184 .57789 L .25927 .57983 L F
.325 0 .076 r
.43699 .46079 m .43563 .46322 L .43302 .46378 L F
.106 0 .221 r
.43995 .458 m .43905 .46063 L .43699 .46079 L F
.068 0 0 r
.43905 .46063 m .43563 .46322 L .43699 .46079 L F
.885 .934 .845 r
.41162 .47827 m .40912 .48093 L .41054 .48215 L F
.978 .881 .665 r
.40912 .48093 m .40799 .48372 L .41054 .48215 L F
.16 0 0 r
.37995 .48081 m .38388 .4787 L .38119 .47916 L F
.054 .314 .799 r
.4367 .52798 m .43529 .52431 L .43551 .52639 L F
.899 .564 .079 r
.42291 .51191 m .42115 .50748 L .42294 .50885 L F
.852 .879 .859 r
.42644 .50522 m .42294 .50885 L .42115 .50748 L F
.711 .705 .843 r
.6047 .37741 m .60074 .37725 L .60331 .37578 L F
.595 .419 .614 r
.6047 .37741 m .60509 .38114 L .60168 .38124 L F
.349 .651 .968 r
.60551 .37552 m .6047 .37741 L .60331 .37578 L F
0 0 .39 r
.60474 .37365 m .6049 .37404 L .60551 .37552 L F
.349 .651 .968 r
.60551 .37552 m .60676 .37727 L .60623 .37731 L F
.451 .315 .604 r
.60777 .37991 m .6047 .37741 L .60676 .37727 L F
.805 .438 0 r
.60667 .37815 m .60676 .37727 L .60551 .37552 L F
0 0 .39 r
.6049 .37404 m .60667 .37815 L .60551 .37552 L F
.349 .651 .968 r
.60551 .37552 m .60623 .37731 L .6047 .37741 L F
.451 .315 .604 r
.60777 .37991 m .60509 .38114 L .6047 .37741 L F
.942 .697 .226 r
.46767 .50871 m .46687 .50753 L .4668 .50484 L F
.46767 .50871 m .46687 .50753 L .4668 .50484 L F
0 0 .322 r
.55638 .39793 m .55773 .3985 L .55942 .39668 L F
.55638 .39793 m .5565 .40065 L .55773 .3985 L F
.935 .947 .772 r
.42812 .56874 m .4272 .57331 L .42953 .56966 L F
.42812 .56874 m .42599 .57234 L .4272 .57331 L F
.697 .666 .816 r
.30348 .54205 m .30531 .54582 L .29998 .54581 L F
.712 .429 .494 r
.30531 .54582 m .30058 .54823 L .29998 .54581 L F
.30531 .54582 m .30543 .54853 L .30058 .54823 L F
.826 .622 .628 r
.31267 .53863 m .31477 .5422 L .31503 .53936 L F
.009 .357 .831 r
.29793 .54651 m .2988 .54575 L .29998 .54581 L F
.627 .323 .435 r
.29998 .54581 m .30058 .54823 L .29793 .54651 L F
0 0 .479 r
.29983 .54556 m .29927 .54428 L .29816 .54284 L F
.431 .411 .737 r
.29816 .54284 m .29803 .54581 L .297 .54273 L F
.924 .831 .735 r
.29448 .54365 m .29803 .54581 L .29816 .54284 L F
.661 .128 0 r
.29816 .54284 m .29927 .54428 L .29745 .54313 L F
.2974 .54307 m .29745 .54313 L .29738 .54308 L F
.29816 .54284 m .29745 .54313 L .2974 .54307 L F
.674 .871 .973 r
.29738 .54308 m .29927 .54428 L .29967 .54276 L F
.727 .541 .639 r
.2963 .54592 m .29892 .54347 L .29927 .54428 L F
.29892 .54347 m .29967 .54276 L .29927 .54428 L F
0 0 .479 r
.29998 .54581 m .29927 .54428 L .29983 .54556 L F
.954 .915 .552 r
.29998 .54581 m .2988 .54575 L .29927 .54428 L F
.727 .541 .639 r
.2963 .54592 m .29927 .54428 L .2988 .54575 L F
.29838 .54397 m .30145 .54631 L .29967 .54276 L F
.009 .357 .831 r
.29793 .54651 m .30058 .54823 L .2988 .54575 L F
.84 .769 .784 r
.30058 .54823 m .29646 .54822 L .2988 .54575 L F
.727 .541 .639 r
.2963 .54592 m .30093 .54627 L .29838 .54397 L F
.30093 .54627 m .30145 .54631 L .29838 .54397 L F
.659 .681 .86 r
.28369 .64899 m .28695 .65235 L .28874 .65003 L F
.572 .561 .804 r
.32319 .68003 m .32486 .68413 L .32667 .68257 L F
.814 .507 .471 r
.42981 .51146 m .43301 .5106 L .42982 .50871 L F
.42981 .51146 m .43433 .51219 L .43301 .5106 L F
.683 .136 0 r
.38342 .56111 m .38501 .5609 L .38369 .55828 L F
.38342 .56111 m .38743 .56315 L .38501 .5609 L F
0 0 0 r
.44864 .44016 m .4497 .43846 L .44647 .44131 L F
.013 0 0 r
.45206 .43735 m .4497 .43846 L .44864 .44016 L F
.431 .164 .407 r
.43862 .54909 m .44127 .54849 L .44164 .54602 L F
.378 .788 .981 r
.44381 .54415 m .43991 .54363 L .44164 .54602 L F
.874 .862 .825 r
.47293 .51504 m .47709 .51281 L .4758 .51202 L F
.887 .933 .843 r
.47866 .5085 m .4758 .51202 L .47709 .51281 L F
.197 0 0 r
.40161 .48345 m .39918 .48626 L .39602 .48716 L F
.585 .082 .024 r
.40308 .48545 m .39918 .48626 L .40161 .48345 L F
.144 0 .028 r
.28993 .54846 m .28658 .55113 L .28915 .55009 L F
.861 .804 .793 r
.31768 .55899 m .31483 .56253 L .31881 .56255 L F
.863 .716 .699 r
.31483 .56253 m .31808 .56512 L .31881 .56255 L F
.449 .037 .165 r
.60168 .38124 m .60424 .38244 L .60145 .38277 L F
.456 .013 .107 r
.60509 .38114 m .60424 .38244 L .60168 .38124 L F
.955 .94 .725 r
.29978 .57825 m .29858 .57813 L .29987 .57532 L F
.967 .919 .703 r
.29812 .58243 m .29858 .57813 L .29978 .57825 L F
.989 .861 .618 r
.42876 .56613 m .42812 .56874 L .42953 .56966 L F
.889 .482 .231 r
.39602 .48716 m .3932 .48413 L .39512 .48569 L F
.936 .757 .635 r
.37583 .55156 m .37836 .55379 L .37811 .55271 L F
.841 .966 .883 r
.48593 .50039 m .48441 .50411 L .48768 .50185 L F
.48593 .50039 m .48285 .50324 L .48441 .50411 L F
.412 .793 .992 r
.32241 .63242 m .32411 .63338 L .31976 .63284 L F
.839 .925 .889 r
.32498 .63006 m .32411 .63338 L .32241 .63242 L F
.32498 .63006 m .32745 .63055 L .32411 .63338 L F
.685 .544 .688 r
.32745 .63055 m .3275 .63247 L .32411 .63338 L F
.287 .732 .962 r
.53062 .42997 m .53479 .43071 L .53213 .43083 L F
0 .249 .722 r
.39416 .57071 m .39536 .57169 L .39588 .57112 L F
.651 .856 .467 r
.39494 .57281 m .39588 .57112 L .39667 .57025 L F
0 .249 .722 r
.39536 .57169 m .39696 .57301 L .39588 .57112 L F
.651 .856 .467 r
.39667 .57025 m .39588 .57112 L .39715 .56954 L F
0 0 .382 r
.30032 .55851 m .30196 .55776 L .30195 .55487 L F
0 0 0 r
.30032 .55851 m .29932 .56125 L .30196 .55776 L F
.788 .714 .783 r
.33398 .63368 m .33836 .6332 L .33711 .62932 L F
.786 .643 .704 r
.33514 .63674 m .33836 .6332 L .33398 .63368 L F
.994 .746 .412 r
.33711 .62932 m .33836 .6332 L .33677 .63243 L F
.945 .588 .206 r
.33677 .63243 m .33836 .6332 L .33866 .63563 L F
.078 0 0 r
.42458 .45709 m .42778 .45447 L .42549 .45558 L F
.845 .614 .589 r
.36273 .56131 m .36732 .55941 L .36554 .55808 L F
.36273 .56131 m .36538 .56291 L .36732 .55941 L F
.792 .453 .415 r
.42632 .52231 m .43005 .52208 L .42874 .52461 L F
.835 .999 .808 r
.4323 .52172 m .42874 .52461 L .43005 .52208 L F
.788 .953 .621 r
.50239 .48853 m .50068 .48988 L .49993 .49209 L F
.78 .998 .827 r
.49993 .49209 m .50068 .48988 L .49777 .49259 L F
.835 .655 .66 r
.37247 .53859 m .37354 .5421 L .37455 .53941 L F
.837 .639 .635 r
.31851 .54872 m .31596 .55175 L .32004 .55251 L F
.849 .606 .571 r
.31596 .55175 m .31993 .55522 L .32004 .55251 L F
.835 .585 .561 r
.31477 .5422 m .31448 .54505 L .31863 .54571 L F
.873 .657 .607 r
.31448 .54505 m .31851 .54872 L .31863 .54571 L F
.808 .784 .831 r
.30354 .53489 m .3088 .53242 L .30378 .53229 L F
.795 .712 .773 r
.52868 .38689 m .53018 .39098 L .53289 .38798 L F
.619 .438 .615 r
.53018 .39098 m .53338 .39097 L .53289 .38798 L F
.561 .398 .618 r
.53289 .38798 m .53338 .39097 L .53708 .39014 L F
.346 .509 .877 r
.58155 .37623 m .5804 .37724 L .57877 .37538 L F
.564 .504 .747 r
.58375 .3806 m .5804 .37724 L .58155 .37623 L F
.801 .933 .919 r
.32757 .63014 m .32745 .63055 L .32498 .63006 L F
.808 .983 .891 r
.50578 .48565 m .50311 .48582 L .50239 .48853 L F
.844 .958 .618 r
.50311 .48582 m .50068 .48988 L .50239 .48853 L F
0 .479 .771 r
.66956 .36057 m .67388 .36154 L .67289 .36151 L F
0 .458 .855 r
.56536 .36578 m .56809 .36705 L .56591 .36543 L F
.375 .194 .503 r
.51661 .41075 m .51427 .41442 L .51552 .41192 L F
.31 .284 .668 r
.52079 .38281 m .52051 .38697 L .5191 .38777 L F
.343 .355 .728 r
.52051 .38697 m .52195 .3896 L .5191 .38777 L F
.806 .991 .879 r
.50422 .41628 m .50709 .41417 L .50594 .41347 L F
.502 .686 .95 r
.29621 .67112 m .30127 .67355 L .30143 .67238 L F
.403 .645 .955 r
.30143 .67238 m .30127 .67355 L .30326 .67311 L F
.828 .707 .731 r
.64341 .36708 m .64013 .36684 L .64224 .3635 L F
.92 .678 .556 r
.34572 .54541 m .34243 .5448 L .3426 .54156 L F
.905 .748 .677 r
.34407 .54846 m .34243 .5448 L .34572 .54541 L F
0 0 0 r
.35287 .563 m .35104 .56348 L .35065 .56266 L F
0 0 .302 r
.35065 .56266 m .35104 .56348 L .35096 .56332 L F
.35104 .56348 m .35113 .56367 L .35104 .56348 L F
.35104 .56348 m .35104 .56348 L .35096 .56332 L F
0 0 0 r
.35287 .563 m .35133 .5634 L .35104 .56348 L F
.949 .637 .41 r
.35017 .56303 m .35096 .56569 L .34886 .56405 L F
.35065 .56266 m .35071 .56325 L .35017 .56303 L F
.35071 .56325 m .35096 .56569 L .35017 .56303 L F
.35065 .56266 m .35096 .56569 L .34886 .56405 L F
.486 0 0 r
.35065 .56266 m .35017 .56303 L .35113 .56367 L F
.35017 .56303 m .34886 .56405 L .35113 .56367 L F
0 0 0 r
.35096 .56332 m .35066 .56342 L .35065 .56266 L F
.35066 .56342 m .34886 .56405 L .35017 .56303 L F
.35066 .56342 m .35017 .56303 L .35065 .56266 L F
.35038 .56363 m .34886 .56405 L .35066 .56342 L F
.3507 .56346 m .35066 .56342 L .35096 .56332 L F
.35038 .56363 m .35066 .56342 L .3507 .56346 L F
.741 .923 .952 r
.3507 .56346 m .34634 .56141 L .34732 .56182 L F
.35113 .56367 m .35072 .56347 L .3507 .56346 L F
.35072 .56347 m .34634 .56141 L .3507 .56346 L F
.35078 .56353 m .34886 .56405 L .34842 .56256 L F
.35113 .56367 m .34886 .56405 L .35078 .56353 L F
0 0 0 r
.35033 .56366 m .34886 .56405 L .35038 .56363 L F
.741 .923 .952 r
.35084 .56353 m .35074 .56349 L .35072 .56347 L F
.35074 .56349 m .34842 .56256 L .35072 .56347 L F
.868 .546 .438 r
.35096 .56332 m .35113 .56367 L .3507 .56346 L F
0 0 0 r
.35104 .56348 m .35033 .56366 L .35096 .56332 L F
.35104 .56348 m .35104 .56348 L .3506 .56359 L F
.3508 .56354 m .3506 .56359 L .34886 .56405 L F
.35104 .56348 m .3506 .56359 L .3508 .56354 L F
.741 .923 .952 r
.35081 .56354 m .34842 .56256 L .35084 .56353 L F
.712 .225 .085 r
.35133 .5634 m .34842 .56256 L .34886 .56405 L F
.35133 .5634 m .3493 .56359 L .34842 .56256 L F
0 .03 .599 r
.34842 .56256 m .3493 .56359 L .34909 .56307 L F
.741 .923 .952 r
.35072 .56347 m .34842 .56256 L .34781 .5621 L F
0 0 .302 r
.35065 .56266 m .35096 .56332 L .34883 .55877 L F
.868 .546 .438 r
.34883 .55877 m .35096 .56332 L .34551 .56094 L F
.35096 .56332 m .3507 .56346 L .34551 .56094 L F
.34883 .55877 m .34551 .56094 L .3459 .55829 L F
.838 .727 .201 r
.3459 .55829 m .34551 .56094 L .3454 .55929 L F
0 .03 .599 r
.34842 .56256 m .34973 .55978 L .3454 .55929 L F
.34842 .56256 m .34828 .5611 L .34973 .55978 L F
.34842 .56256 m .34909 .56307 L .34828 .5611 L F
.741 .923 .952 r
.34781 .5621 m .34842 .56256 L .34634 .56141 L F
.35113 .56367 m .35081 .56354 L .35084 .56353 L F
.34732 .56182 m .34634 .56141 L .34551 .56094 L F
0 0 0 r
.35287 .563 m .35104 .56348 L .35104 .56348 L F
.917 .862 .771 r
.47586 .4894 m .47471 .49171 L .47408 .48826 L F
.49 .619 .906 r
.2809 .55859 m .28051 .56247 L .27854 .55874 L F
.2809 .55859 m .28272 .56186 L .28051 .56247 L F
0 .128 .645 r
.28255 .56449 m .28051 .56247 L .28272 .56186 L F
.631 .385 .527 r
.39594 .58796 m .3976 .58613 L .39306 .58533 L F
.39594 .58796 m .39783 .58916 L .3976 .58613 L F
.326 .162 .5 r
.3976 .58613 m .39974 .58633 L .39874 .5845 L F
.666 .82 .958 r
.3317 .63162 m .33079 .63501 L .32996 .63171 L F
.3317 .63162 m .33398 .63368 L .33079 .63501 L F
.603 .943 .774 r
.63615 .37783 m .63221 .38014 L .6348 .37899 L F
.841 .965 .884 r
.63915 .37485 m .63615 .37783 L .63653 .37494 L F
.894 .932 .554 r
.63653 .37494 m .63615 .37783 L .6348 .37899 L F
.855 .663 .643 r
.56691 .38158 m .56726 .3846 L .56346 .38329 L F
.624 .498 .689 r
.57 .38076 m .56726 .3846 L .56691 .38158 L F
.873 .841 .81 r
.47471 .49171 m .47156 .49141 L .47408 .48826 L F
.902 .863 .792 r
.47471 .49171 m .47053 .49392 L .47156 .49141 L F
.47471 .49171 m .47232 .49521 L .47053 .49392 L F
.351 .123 .421 r
.28149 .55446 m .27854 .55874 L .27892 .55539 L F
0 0 .005 r
.41826 .47173 m .41737 .47419 L .41535 .47505 L F
.018 0 0 r
.41642 .47595 m .41535 .47505 L .41737 .47419 L F
.41642 .47595 m .41408 .47701 L .41535 .47505 L F
.873 .657 .607 r
.31448 .54505 m .31418 .54794 L .31851 .54872 L F
.87 .697 .664 r
.31418 .54794 m .31596 .55175 L .31851 .54872 L F
.822 .881 .888 r
.30499 .5847 m .30994 .58282 L .30824 .5818 L F
.89 .9 .83 r
.30824 .5818 m .30994 .58282 L .31239 .57962 L F
.818 .717 .753 r
.43149 .53476 m .42894 .53606 L .42711 .53433 L F
.727 .602 .716 r
.43149 .53476 m .42885 .53911 L .42894 .53606 L F
.681 .671 .834 r
.26876 .59015 m .26618 .59244 L .2645 .58867 L F
.269 .104 .464 r
.26182 .57508 m .26413 .57458 L .26429 .57195 L F
.598 .449 .65 r
.26184 .57789 m .26413 .57458 L .26182 .57508 L F
.852 .879 .859 r
.42644 .50522 m .42115 .50748 L .42427 .50405 L F
.928 .59 .375 r
.42429 .50718 m .42644 .50522 L .42427 .50405 L F
.42429 .50718 m .42667 .50816 L .42644 .50522 L F
.635 .266 .326 r
.55942 .39668 m .56204 .39689 L .56336 .39426 L F
.699 .575 .712 r
.56336 .39426 m .56612 .39465 L .56584 .39166 L F
.183 0 .098 r
.56336 .39426 m .56457 .39537 L .56612 .39465 L F
.56336 .39426 m .56204 .39689 L .56457 .39537 L F
0 0 0 r
.63359 .39201 m .63292 .39205 L .63474 .38997 L F
.268 .257 .661 r
.57919 .35909 m .58119 .35983 L .58124 .35556 L F
.577 .675 .906 r
.29004 .67051 m .29047 .66653 L .28835 .66651 L F
.29004 .67051 m .29262 .66987 L .29047 .66653 L F
.465 .875 .733 r
.48452 .42366 m .48813 .42175 L .4868 .42281 L F
.409 .067 .271 r
.48813 .42175 m .49063 .42326 L .4868 .42281 L F
.48813 .42175 m .49039 .4213 L .49063 .42326 L F
.911 .846 .767 r
.30764 .55124 m .30613 .55472 L .3048 .55162 L F
.442 .173 .408 r
.5304 .39414 m .53338 .39097 L .53018 .39098 L F
.805 .727 .778 r
.31082 .57588 m .30907 .57906 L .31239 .57962 L F
.89 .9 .83 r
.30824 .5818 m .31239 .57962 L .30907 .57906 L F
.753 .678 .777 r
.42894 .53606 m .42885 .53911 L .42744 .53869 L F
.842 .387 0 r
.43036 .5425 m .42744 .53869 L .42885 .53911 L F
.356 .001 .217 r
.40322 .47127 m .40585 .47064 L .40685 .46783 L F
.309 0 .033 r
.4082 .46958 m .40685 .46783 L .40585 .47064 L F
.4082 .46958 m .40952 .46736 L .40685 .46783 L F
0 0 .194 r
.28377 .64354 m .28405 .64436 L .28544 .64235 L F
.28377 .64354 m .28448 .64633 L .28405 .64436 L F
.244 0 .012 r
.25863 .59262 m .26267 .5904 L .25735 .58861 L F
.974 .914 .583 r
.42977 .54481 m .4286 .54412 L .43036 .5425 L F
.932 .92 .779 r
.42977 .54481 m .42572 .54748 L .4286 .54412 L F
.42977 .54481 m .42719 .54884 L .42572 .54748 L F
.068 0 0 r
.42063 .47075 m .41737 .47419 L .41826 .47173 L F
.043 0 0 r
.38523 .48453 m .38063 .4861 L .3828 .48618 L F
.38523 .48453 m .3834 .48557 L .38063 .4861 L F
.499 .019 .048 r
.3834 .48557 m .38064 .48606 L .38063 .4861 L F
.019 .592 .733 r
.3806 .48614 m .38063 .4861 L .3782 .4861 L F
0 0 0 r
.3793 .4863 m .3782 .4861 L .38063 .4861 L F
.499 .019 .048 r
.38064 .48606 m .3793 .4863 L .38063 .4861 L F
.019 .592 .733 r
.3828 .48618 m .38063 .4861 L .3806 .48614 L F
.638 .875 .986 r
.52301 .43458 m .51798 .43511 L .52143 .43089 L F
.9 .904 .818 r
.51952 .4296 m .52143 .43089 L .51798 .43511 L F
.766 .78 .865 r
.52082 .43076 m .52301 .43458 L .52143 .43089 L F
.51976 .43053 m .52048 .43142 L .52082 .43076 L F
.52048 .43142 m .52301 .43458 L .52082 .43076 L F
.51976 .43053 m .52485 .43389 L .52301 .43458 L F
.973 .664 .349 r
.51976 .43053 m .52143 .43089 L .51952 .4296 L F
.714 .781 .905 r
.52799 .43132 m .52485 .43389 L .51976 .43053 L F
.574 .108 .11 r
.52213 .43412 m .52389 .43202 L .52001 .43232 L F
.51988 .43259 m .52001 .43232 L .51954 .43236 L F
.52213 .43412 m .52001 .43232 L .51988 .43259 L F
.815 .978 .686 r
.50673 .41968 m .506 .42186 L .50427 .4231 L F
.531 .45 .708 r
.56584 .39166 m .56612 .39465 L .56856 .39344 L F
.324 .783 .649 r
.56612 .39465 m .56668 .39433 L .56856 .39344 L F
.56612 .39465 m .56457 .39537 L .56668 .39433 L F
.808 .784 .831 r
.30354 .53489 m .30531 .53591 L .3088 .53242 L F
.706 .596 .73 r
.30531 .53591 m .30879 .53569 L .3088 .53242 L F
.662 .374 .474 r
.30531 .53591 m .30859 .53839 L .30879 .53569 L F
.198 0 .228 r
.27192 .55577 m .27369 .55675 L .27437 .55435 L F
.27192 .55577 m .27009 .55856 L .27369 .55675 L F
.909 .982 .765 r
.56319 .40834 m .56531 .40529 L .56325 .4057 L F
.667 .974 .837 r
.56325 .4057 m .56531 .40529 L .56736 .40355 L F
.492 .844 .583 r
.52491 .39805 m .5254 .39746 L .52698 .39629 L F
0 0 .082 r
.5242 .40058 m .52447 .39972 L .52445 .39815 L F
.52435 .39828 m .52445 .39815 L .52444 .39697 L F
.5242 .40058 m .52445 .39815 L .52435 .39828 L F
.492 .844 .583 r
.52491 .39805 m .52405 .39869 L .5254 .39746 L F
.52405 .39869 m .52342 .39917 L .52419 .3985 L F
.52405 .39869 m .52419 .3985 L .5254 .39746 L F
0 0 0 r
.44647 .44131 m .44274 .44405 L .44495 .44277 L F
.44864 .44016 m .44647 .44131 L .44495 .44277 L F
.921 .544 .279 r
.33682 .53091 m .33466 .528 L .33677 .52871 L F
.773 .473 .479 r
.30879 .53569 m .30859 .53839 L .31267 .53863 L F
.749 .447 .472 r
.29812 .58243 m .29398 .58471 L .2967 .58144 L F
.29812 .58243 m .29833 .58533 L .29398 .58471 L F
.967 .919 .703 r
.29812 .58243 m .2967 .58144 L .29858 .57813 L F
.779 .972 .918 r
.52079 .38281 m .52067 .38422 L .52486 .38133 L F
.531 .45 .708 r
.56584 .39166 m .56856 .39344 L .56877 .39066 L F
0 0 .159 r
.27994 .64814 m .28006 .65082 L .27896 .65097 L F
.882 .602 .508 r
.43401 .55456 m .43598 .55199 L .43357 .55153 L F
.665 .3 .344 r
.43401 .55456 m .43847 .55467 L .43598 .55199 L F
.782 .516 .535 r
.3472 .65693 m .34997 .65947 L .34619 .65952 L F
.919 .553 .318 r
.64698 .34945 m .64359 .34684 L .64441 .34948 L F
.824 .703 .73 r
.34023 .52141 m .34194 .52447 L .34472 .52174 L F
.8 .567 .585 r
.34194 .52447 m .34618 .52517 L .34472 .52174 L F
.632 .885 .548 r
.40157 .57545 m .39926 .57827 L .40253 .57636 L F
.55 .756 .973 r
.40253 .57636 m .40517 .57631 L .40157 .57545 L F
.529 .404 .654 r
.40343 .57974 m .40517 .57631 L .40253 .57636 L F
.298 0 0 r
.40343 .57974 m .40561 .58046 L .40597 .57928 L F
.529 .404 .654 r
.40343 .57974 m .40597 .57928 L .40517 .57631 L F
.328 .473 .853 r
.30326 .67311 m .30536 .67729 L .30647 .67484 L F
.409 .571 .902 r
.30647 .67484 m .30536 .67729 L .30771 .67717 L F
.966 .741 .548 r
.35273 .52831 m .35273 .53237 L .35435 .53226 L F
.881 .484 .275 r
.35273 .53237 m .35253 .53372 L .35435 .53226 L F
.774 .317 .163 r
.35253 .53372 m .35673 .53533 L .35435 .53226 L F
.784 .302 .082 r
.35435 .53226 m .35673 .53533 L .35833 .53531 L F
.91 .695 .6 r
.30764 .55124 m .3048 .55162 L .30543 .54853 L F
.842 .387 0 r
.43036 .5425 m .42909 .54177 L .42744 .53869 L F
.995 .777 .495 r
.43036 .5425 m .4286 .54412 L .42909 .54177 L F
.249 0 0 r
.52739 .36171 m .52863 .36197 L .52576 .3624 L F
.53034 .36046 m .52921 .36146 L .52739 .36171 L F
.74 .244 .055 r
.52655 .36223 m .52601 .3619 L .52347 .36303 L F
.52601 .3619 m .52288 .36002 L .52332 .36226 L F
.52601 .3619 m .52332 .36226 L .52347 .36303 L F
.52655 .36223 m .52576 .3624 L .52288 .36002 L F
.249 0 0 r
.53034 .36046 m .52576 .3624 L .52655 .36223 L F
.52921 .36146 m .52863 .36197 L .52739 .36171 L F
0 0 .13 r
.26408 .59657 m .26316 .59661 L .26637 .59565 L F
.26408 .59657 m .26259 .59876 L .26316 .59661 L F
.993 .754 .458 r
.43251 .5305 m .43421 .52891 L .42992 .52804 L F
.43251 .5305 m .43401 .53182 L .43421 .52891 L F
.629 .613 .815 r
.6082 .36315 m .60297 .35983 L .60691 .36233 L F
.438 .843 .973 r
.60691 .36233 m .61108 .36228 L .6082 .36315 L F
.61108 .36228 m .60691 .36233 L .6082 .36315 L F
.944 .961 .71 r
.41312 .58161 m .41146 .58578 L .41442 .58256 L F
.41312 .58161 m .41036 .58527 L .41146 .58578 L F
.534 .613 .878 r
.60331 .37578 m .60074 .37725 L .59882 .37286 L F
.244 0 .012 r
.25863 .59262 m .26094 .59216 L .26267 .5904 L F
.504 .25 .462 r
.26094 .59216 m .2645 .58867 L .26267 .5904 L F
0 0 .453 r
.37743 .48509 m .3782 .4861 L .3776 .48539 L F
.207 .455 .875 r
.63615 .33653 m .63434 .33858 L .63168 .33804 L F
.63615 .33653 m .63814 .33827 L .63434 .33858 L F
.262 0 .083 r
.29482 .62945 m .29121 .63265 L .29293 .63153 L F
0 0 0 r
.29611 .62895 m .29769 .62634 L .29482 .62945 L F
.29611 .62895 m .29482 .62945 L .29293 .63153 L F
.595 .342 .504 r
.2674 .58305 m .2671 .58587 L .26401 .5858 L F
.322 .114 .435 r
.26936 .58492 m .2674 .58305 L .2697 .58224 L F
.26936 .58492 m .2671 .58587 L .2674 .58305 L F
.746 .908 .531 r
.5379 .44973 m .53689 .45206 L .53932 .44825 L F
.862 .975 .666 r
.53972 .44591 m .53932 .44825 L .5416 .4446 L F
.848 .923 .532 r
.53972 .44591 m .5379 .44973 L .53932 .44825 L F
.84 .513 .433 r
.36791 .53523 m .37247 .53859 L .36992 .53545 L F
.64 .878 .985 r
.5166 .44384 m .51283 .4437 L .51543 .44245 L F
.729 .818 .92 r
.51832 .43977 m .5166 .44384 L .51543 .44245 L F
.51832 .43977 m .52086 .4415 L .5166 .44384 L F
.77 .465 .471 r
.42575 .51105 m .42982 .50871 L .42667 .50816 L F
.42575 .51105 m .42981 .51146 L .42982 .50871 L F
.638 .875 .986 r
.51798 .43511 m .52301 .43458 L .52298 .43774 L F
.674 .124 0 r
.37277 .5715 m .37667 .57401 L .37634 .57333 L F
.593 .363 .537 r
.56808 .35666 m .57114 .3538 L .56804 .35413 L F
.552 .681 .924 r
.52121 .37568 m .5205 .37828 L .51897 .37609 L F
.52121 .37568 m .52244 .3779 L .5205 .37828 L F
.451 .053 .192 r
.37818 .58317 m .37816 .58489 L .37868 .58291 L F
.773 .7 .783 r
.37816 .58489 m .38091 .58128 L .37868 .58291 L F
.759 .734 .83 r
.37844 .58736 m .38231 .58521 L .37816 .58489 L F
.773 .7 .783 r
.37816 .58489 m .38231 .58521 L .38091 .58128 L F
0 0 .023 r
.37815 .58601 m .37816 .58489 L .37857 .58185 L F
.13 0 0 r
.37534 .58837 m .37844 .58736 L .37816 .58489 L F
0 0 .023 r
.37799 .5876 m .37816 .58489 L .37815 .58601 L F
.451 .053 .192 r
.37471 .58497 m .37816 .58489 L .37818 .58317 L F
.388 .471 .824 r
.37871 .5813 m .37868 .58291 L .38091 .58128 L F
.932 .778 .668 r
.37777 .56853 m .38137 .56778 L .38102 .56828 L F
0 .015 .554 r
.38177 .56428 m .38327 .5667 L .38137 .56778 L F
.484 .186 .384 r
.28197 .54213 m .2852 .54163 L .28611 .5392 L F
0 0 .118 r
.28611 .5392 m .2852 .54163 L .28818 .53804 L F
.431 0 0 r
.52886 .40102 m .52763 .40289 L .52485 .40261 L F
0 0 0 r
.52995 .40142 m .52886 .40102 L .5312 .39989 L F
.52995 .40142 m .52763 .40289 L .52886 .40102 L F
.557 .934 .86 r
.638 .38859 m .64168 .38723 L .64048 .3888 L F
.569 .327 .51 r
.64168 .38723 m .64464 .38978 L .64048 .3888 L F
.826 .615 .617 r
.43245 .51439 m .43433 .51219 L .42981 .51146 L F
.262 0 0 r
.38359 .58684 m .38632 .58668 L .38231 .58521 L F
.38359 .58684 m .3864 .58688 L .38632 .58668 L F
.67 .637 .807 r
.35089 .56743 m .35258 .57015 L .35499 .56832 L F
.747 .505 .564 r
.56595 .38605 m .56346 .38329 L .56726 .3846 L F
.636 .186 .166 r
.56726 .3846 m .56988 .38643 L .56595 .38605 L F
.098 0 0 r
.41547 .4642 m .4178 .46312 L .41887 .46064 L F
.022 0 0 r
.41887 .46064 m .42101 .46031 L .42228 .45834 L F
.043 0 0 r
.42009 .46184 m .41887 .46064 L .4178 .46312 L F
.42009 .46184 m .42101 .46031 L .41887 .46064 L F
.443 .874 .915 r
.33344 .61353 m .32556 .61463 L .33158 .61214 L F
.444 .029 .156 r
.336 .61521 m .33533 .61325 L .33344 .61353 L F
0 .171 .616 r
.336 .61521 m .33158 .61214 L .33338 .61184 L F
0 0 0 r
.3333 .61186 m .33191 .61229 L .33284 .61205 L F
0 .171 .616 r
.336 .61521 m .33344 .61353 L .33179 .61229 L F
.336 .61521 m .33179 .61229 L .33181 .61229 L F
0 0 0 r
.33191 .61229 m .32834 .61339 L .33204 .61229 L F
.33191 .61229 m .33204 .61229 L .33284 .61205 L F
0 .171 .616 r
.33181 .61229 m .33179 .61229 L .33158 .61214 L F
0 0 0 r
.33338 .61184 m .33158 .61214 L .32834 .61339 L F
.643 .926 .974 r
.33062 .61176 m .33284 .61205 L .32834 .61339 L F
.236 0 0 r
.33062 .61176 m .33267 .61212 L .33284 .61205 L F
.726 .251 0 r
.33507 .61436 m .336 .61521 L .33544 .61448 L F
.33507 .61436 m .33544 .61448 L .33338 .61184 L F
0 0 .568 r
.33478 .61249 m .3346 .61365 L .33338 .61184 L F
.924 .901 .498 r
.33451 .61416 m .33507 .61436 L .33478 .61249 L F
.33404 .61708 m .33507 .61436 L .33451 .61416 L F
.236 0 0 r
.33267 .61212 m .33478 .61249 L .33284 .61205 L F
0 0 0 r
.33338 .61184 m .3333 .61186 L .33284 .61205 L F
.862 .975 .666 r
.53972 .44591 m .5416 .4446 L .54086 .44354 L F
.959 .926 .724 r
.5416 .4446 m .54263 .43932 L .54086 .44354 L F
.042 0 0 r
.42101 .46031 m .42458 .45709 L .42228 .45834 L F
.379 .249 .574 r
.26636 .56271 m .2679 .56463 L .26857 .56179 L F
.26636 .56271 m .26645 .56551 L .2679 .56463 L F
.289 .783 .743 r
.55649 .36997 m .56051 .36879 L .55774 .37118 L F
.925 .961 .649 r
.56184 .41052 m .56319 .40834 L .56325 .4057 L F
.916 .913 .801 r
.33347 .62986 m .33632 .62641 L .33448 .62578 L F
.654 .447 .591 r
.33347 .62986 m .33711 .62932 L .33632 .62641 L F
0 0 .298 r
.33632 .62641 m .33711 .62932 L .33703 .62736 L F
.33632 .62641 m .33703 .62736 L .33448 .62578 L F
.936 .757 .635 r
.37583 .55156 m .37505 .5546 L .37836 .55379 L F
.939 .845 .723 r
.37505 .5546 m .37685 .55616 L .37836 .55379 L F
0 0 0 r
.54507 .38308 m .54763 .3821 L .54904 .38076 L F
.487 .408 .693 r
.5521 .38327 m .54904 .38076 L .55135 .38023 L F
0 0 0 r
.54904 .38076 m .55013 .38119 L .55135 .38023 L F
.487 .408 .693 r
.5521 .38327 m .54972 .38429 L .54904 .38076 L F
0 0 0 r
.54904 .38076 m .54763 .3821 L .55013 .38119 L F
.59 .095 0 r
.39801 .57085 m .39715 .56954 L .39588 .57112 L F
.39801 .57085 m .39996 .57286 L .39715 .56954 L F
0 0 0 r
.29934 .62513 m .30084 .62358 L .29769 .62634 L F
.207 0 0 r
.30341 .62292 m .30084 .62358 L .29934 .62513 L F
.697 .916 .969 r
.5405 .42694 m .5375 .42728 L .54035 .42672 L F
.677 .962 .742 r
.54299 .42404 m .5405 .42694 L .54035 .42672 L F
.54299 .42404 m .54382 .42398 L .5405 .42694 L F
.289 .783 .743 r
.55649 .36997 m .55839 .36925 L .56051 .36879 L F
.348 .384 .757 r
.55649 .36997 m .55877 .3711 L .55848 .36922 L F
.776 .995 .789 r
.56051 .36879 m .55839 .36925 L .56164 .36624 L F
.348 .384 .757 r
.55839 .36925 m .55846 .36913 L .5581 .36684 L F
.776 .995 .789 r
.55839 .36925 m .55822 .36929 L .55856 .36898 L F
.55839 .36925 m .55846 .36913 L .56164 .36624 L F
.55846 .36913 m .55865 .3689 L .56164 .36624 L F
.56051 .36879 m .56164 .36624 L .56336 .36953 L F
.808 .696 .741 r
.56164 .36624 m .55865 .3689 L .5581 .36684 L F
.55865 .3689 m .55822 .36929 L .5581 .36684 L F
.579 .557 .793 r
.55962 .3677 m .55899 .37021 L .562 .36906 L F
.55899 .37021 m .55877 .3711 L .55916 .37085 L F
.55899 .37021 m .55916 .37085 L .562 .36906 L F
.5581 .36684 m .55846 .36913 L .55962 .3677 L F
.55846 .36913 m .55877 .3711 L .55962 .3677 L F
.776 .995 .789 r
.55846 .36913 m .55856 .36898 L .55865 .3689 L F
.348 .384 .757 r
.55649 .36997 m .55839 .36925 L .5581 .36684 L F
.55839 .36925 m .55848 .36922 L .55846 .36913 L F
.289 .783 .743 r
.55649 .36997 m .55822 .36929 L .55839 .36925 L F
.287 0 .181 r
.51139 .40166 m .51074 .40371 L .50826 .40422 L F
0 0 0 r
.51425 .40051 m .51074 .40371 L .51139 .40166 L F
.266 0 .222 r
.46013 .44319 m .4607 .44176 L .4632 .44065 L F
.92 .527 .162 r
.33425 .52594 m .33292 .52678 L .33237 .52438 L F
.33425 .52594 m .33466 .528 L .33292 .52678 L F
.949 .948 .734 r
.50634 .40296 m .50607 .40608 L .50826 .40422 L F
.50634 .40296 m .5044 .40633 L .50607 .40608 L F
.553 .387 .611 r
.50607 .40608 m .50616 .40791 L .50826 .40422 L F
0 0 0 r
.49797 .41851 m .49385 .42073 L .49375 .42041 L F
.49797 .41851 m .49672 .41973 L .49385 .42073 L F
.49819 .4183 m .49797 .41851 L .49979 .41673 L F
.49819 .4183 m .49672 .41973 L .49797 .41851 L F
.863 .944 .869 r
.5053 .48346 m .50578 .48565 L .50632 .48392 L F
.899 .954 .827 r
.5053 .48346 m .50311 .48582 L .50578 .48565 L F
.84 .717 .729 r
.47232 .49521 m .46783 .49723 L .47053 .49392 L F
.47232 .49521 m .47003 .49864 L .46783 .49723 L F
0 0 0 r
.47068 .42174 m .46774 .425 L .46971 .42355 L F
.47266 .42037 m .47068 .42174 L .46971 .42355 L F
.848 .632 .61 r
.34724 .55209 m .34956 .55593 L .34724 .55514 L F
.905 .686 .595 r
.34883 .55877 m .34724 .55514 L .34956 .55593 L F
.518 .861 .993 r
.50491 .45765 m .50909 .45767 L .50628 .4577 L F
.686 .631 .788 r
.57877 .37538 m .57539 .37399 L .5779 .37372 L F
.057 .449 .879 r
.5779 .37372 m .58155 .37623 L .57877 .37538 L F
.839 .507 .425 r
.40843 .57865 m .41312 .58161 L .41256 .57871 L F
.993 .875 .593 r
.6068 .35457 m .60559 .35601 L .6067 .35714 L F
.787 .711 .78 r
.6068 .35457 m .6067 .35714 L .60944 .35375 L F
.627 .703 .9 r
.60408 .34649 m .6016 .34818 L .59914 .34524 L F
.814 .628 .651 r
.42719 .54884 m .42911 .55283 L .42484 .55208 L F
0 .351 .765 r
.63517 .34469 m .63386 .34368 L .63192 .34275 L F
.251 .667 .964 r
.6382 .34465 m .63386 .34368 L .63517 .34469 L F
.774 .997 .828 r
.50035 .39824 m .49721 .40095 L .49812 .39869 L F
.737 .992 .834 r
.50035 .39824 m .50127 .39602 L .50276 .39693 L F
.50035 .39824 m .49812 .39869 L .50127 .39602 L F
0 0 0 r
.29934 .62513 m .29769 .62634 L .29611 .62895 L F
0 .017 .59 r
.30031 .57173 m .2985 .56811 L .3002 .56935 L F
.647 .42 .56 r
.59146 .35012 m .59418 .34992 L .59422 .3472 L F
.365 .195 .514 r
.59422 .3472 m .59654 .34867 L .59722 .34655 L F
.59422 .3472 m .59418 .34992 L .59654 .34867 L F
.779 .972 .918 r
.52079 .38281 m .52486 .38133 L .5234 .37978 L F
0 0 0 r
.34484 .66668 m .34844 .6639 L .34637 .66551 L F
0 0 .015 r
.3438 .669 m .34484 .66668 L .34637 .66551 L F
.39 0 .004 r
.60539 .35055 m .6013 .35253 L .6068 .35457 L F
.60539 .35055 m .60484 .35271 L .6013 .35253 L F
0 0 0 r
.60682 .35095 m .60539 .35055 L .6082 .3524 L F
.322 .316 .697 r
.60539 .35055 m .6068 .35457 L .6082 .3524 L F
0 0 0 r
.60682 .35095 m .60484 .35271 L .60539 .35055 L F
.967 .887 .697 r
.64224 .3635 m .64099 .36194 L .64365 .36011 L F
.809 .52 0 r
.64552 .35996 m .64133 .35665 L .64365 .36011 L F
.6447 .35931 m .64441 .35599 L .64133 .35665 L F
.64552 .35996 m .64521 .35887 L .6447 .35931 L F
.64521 .35887 m .64441 .35599 L .6447 .35931 L F
0 0 0 r
.64384 .3601 m .64517 .35912 L .64552 .35996 L F
.64365 .36011 m .64517 .35912 L .64384 .3601 L F
.809 .52 0 r
.64522 .35889 m .64517 .35912 L .64441 .35599 L F
.64552 .35996 m .64517 .35912 L .64522 .35889 L F
0 0 0 r
.64517 .35912 m .64397 .36068 L .64505 .3596 L F
.719 .548 .658 r
.64441 .35599 m .64517 .35912 L .64836 .35914 L F
.64441 .35599 m .64836 .35914 L .64708 .35756 L F
0 0 0 r
.64517 .35912 m .64708 .35756 L .64836 .35914 L F
.64517 .35912 m .64505 .3596 L .64653 .35812 L F
.64517 .35912 m .64653 .35812 L .64708 .35756 L F
.64411 .35981 m .64397 .36068 L .64517 .35912 L F
.64365 .36011 m .64368 .36017 L .64411 .35981 L F
.64368 .36017 m .64397 .36068 L .64411 .35981 L F
.64365 .36011 m .64099 .36194 L .64397 .36068 L F
.608 .655 .871 r
.53065 .42471 m .53137 .42066 L .5294 .42063 L F
.53065 .42471 m .53332 .42398 L .53137 .42066 L F
.804 .699 .749 r
.44665 .54163 m .45056 .54196 L .44929 .541 L F
.44665 .54163 m .44822 .54561 L .45056 .54196 L F
.913 .95 .808 r
.45198 .53744 m .45056 .54196 L .45376 .53894 L F
.45198 .53744 m .44929 .541 L .45056 .54196 L F
.498 .884 .964 r
.64993 .38015 m .65322 .37984 L .65288 .37962 L F
.585 .931 .949 r
.65322 .37984 m .65496 .37806 L .65288 .37962 L F
.65322 .37984 m .65736 .37827 L .65496 .37806 L F
.742 .383 0 r
.33042 .62294 m .3316 .62623 L .33002 .62245 L F
.475 .152 .338 r
.36112 .53531 m .36349 .5371 L .36647 .53439 L F
.77 .447 .441 r
.36349 .5371 m .36791 .53523 L .36647 .53439 L F
.801 .933 .919 r
.32757 .63014 m .32498 .63006 L .32782 .62955 L F
.558 .913 .714 r
.33008 .62773 m .32757 .63014 L .32782 .62955 L F
.566 .571 .817 r
.32757 .63014 m .33168 .62886 L .3316 .62623 L F
.542 .845 .999 r
.33008 .62773 m .33168 .62886 L .32757 .63014 L F
.665 .216 .175 r
.60297 .35983 m .60275 .36213 L .60691 .36233 L F
0 0 0 r
.46774 .425 m .46456 .4279 L .46638 .42636 L F
.46971 .42355 m .46774 .425 L .46638 .42636 L F
.863 .716 .699 r
.31483 .56253 m .31443 .56483 L .31808 .56512 L F
.859 .739 .73 r
.31443 .56483 m .31591 .56873 L .31808 .56512 L F
.807 .776 .824 r
.53975 .40907 m .54167 .41116 L .54407 .40784 L F
.452 .183 .414 r
.54425 .41265 m .54167 .41116 L .54074 .41345 L F
.599 .472 .679 r
.54167 .41116 m .54466 .41098 L .54407 .40784 L F
.502 .13 .266 r
.54425 .41265 m .54466 .41098 L .54167 .41116 L F
.955 .951 .679 r
.32349 .60872 m .32479 .60899 L .32517 .60788 L F
.926 .818 .719 r
.42744 .53869 m .42711 .53433 L .42894 .53606 L F
.42744 .53869 m .42507 .5382 L .42711 .53433 L F
.719 .405 .445 r
.42744 .53869 m .42438 .54139 L .42507 .5382 L F
.42744 .53869 m .42909 .54177 L .42438 .54139 L F
.833 .567 .538 r
.34298 .53901 m .33999 .54097 L .34004 .53843 L F
.34298 .53901 m .3426 .54156 L .33999 .54097 L F
.475 .45 .751 r
.36877 .55202 m .37016 .54723 L .36721 .55049 L F
.971 .789 .6 r
.29588 .53071 m .29663 .53572 L .29821 .53171 L F
.347 .772 .974 r
.29821 .53171 m .30023 .53125 L .29588 .53071 L F
.267 .002 .313 r
.29821 .53171 m .29663 .53572 L .30023 .53125 L F
.971 .928 .674 r
.34755 .66124 m .34844 .6639 L .34997 .65947 L F
.98 .914 .622 r
.34637 .66551 m .34844 .6639 L .34755 .66124 L F
0 .362 .672 r
.66673 .3596 m .66931 .36048 L .66956 .36057 L F
0 .46 .734 r
.67084 .36074 m .66956 .36057 L .66931 .36048 L F
.67084 .36074 m .67388 .36154 L .66956 .36057 L F
.762 .485 0 r
.64816 .35389 m .64698 .34945 L .65008 .34976 L F
.64816 .35389 m .64763 .3525 L .64698 .34945 L F
.705 .918 .577 r
.54616 .42044 m .54652 .42048 L .54382 .42398 L F
0 0 .012 r
.54945 .41747 m .54652 .42048 L .54805 .41879 L F
.567 .905 .674 r
.54805 .41879 m .54652 .42048 L .54616 .42044 L F
.933 .954 .769 r
.53478 .45232 m .53483 .45523 L .53689 .45206 L F
.773 .995 .869 r
.5379 .44973 m .53478 .45232 L .53689 .45206 L F
0 .529 .709 r
.53101 .35413 m .53361 .35435 L .53664 .35463 L F
.257 .224 .628 r
.53664 .35463 m .53767 .34947 L .53576 .35124 L F
.53664 .35463 m .5384 .35339 L .53767 .34947 L F
.115 0 0 r
.53664 .35463 m .5378 .35485 L .5384 .35339 L F
.53664 .35463 m .53361 .35435 L .5378 .35485 L F
0 0 .003 r
.59851 .38383 m .59782 .38602 L .5957 .38697 L F
0 0 .223 r
.59606 .38933 m .5957 .38697 L .59782 .38602 L F
.59606 .38933 m .59527 .38984 L .5957 .38697 L F
.351 .238 .582 r
.26429 .57195 m .26603 .56831 L .26486 .56936 L F
.653 .605 .789 r
.30922 .56886 m .30718 .5701 L .30523 .56891 L F
.755 .905 .943 r
.6082 .3524 m .6068 .35457 L .60944 .35375 L F
.571 .925 .949 r
.61066 .34844 m .61056 .34805 L .60815 .34976 L F
.327 .321 .7 r
.61056 .34805 m .61062 .34847 L .60815 .34976 L F
.025 0 0 r
.61247 .35055 m .60928 .35193 L .60944 .35375 L F
.62 .783 .96 r
.60815 .34976 m .61247 .35055 L .61066 .34844 L F
.025 0 0 r
.60928 .35193 m .60883 .35309 L .60944 .35375 L F
.61247 .35055 m .61102 .35167 L .6082 .3524 L F
.615 .09 0 r
.60815 .34976 m .61102 .35167 L .61247 .35055 L F
.327 .321 .7 r
.61062 .34847 m .61102 .35167 L .60972 .3508 L F
.61062 .34847 m .60972 .3508 L .60815 .34976 L F
.025 0 0 r
.60928 .35193 m .6082 .3524 L .60883 .35309 L F
.964 .886 .705 r
.30854 .63199 m .30948 .63008 L .3088 .62941 L F
.925 .908 .786 r
.3088 .62941 m .30948 .63008 L .31143 .6262 L F
.846 .844 .842 r
.29572 .55261 m .29079 .55394 L .29296 .55097 L F
.29572 .55261 m .29269 .55553 L .29079 .55394 L F
.515 .836 .533 r
.29424 .554 m .29269 .55553 L .29523 .55308 L F
.663 .234 .219 r
.29424 .554 m .29338 .55663 L .29245 .55566 L F
.29424 .554 m .29079 .55394 L .29269 .55553 L F
.29424 .554 m .29245 .55566 L .29079 .55394 L F
.515 .836 .533 r
.29424 .554 m .29523 .55308 L .29572 .55261 L F
.572 .8 .985 r
.29778 .55156 m .29572 .55261 L .29296 .55097 L F
0 0 0 r
.29424 .554 m .29572 .55261 L .29778 .55156 L F
.806 .991 .879 r
.50422 .41628 m .50594 .41347 L .50313 .41516 L F
.251 0 0 r
.54703 .38749 m .54498 .38987 L .54215 .39028 L F
.427 .033 .186 r
.5491 .38611 m .54498 .38987 L .54703 .38749 L F
.43 .415 .741 r
.2984 .53729 m .297 .54273 L .29516 .53841 L F
.2984 .53729 m .29816 .54284 L .297 .54273 L F
.154 0 .069 r
.60037 .38483 m .59851 .38383 L .60145 .38277 L F
.60037 .38483 m .59782 .38602 L .59851 .38383 L F
.782 .989 .752 r
.49721 .40095 m .49539 .40161 L .49812 .39869 L F
.457 0 0 r
.64194 .34487 m .64217 .34529 L .64136 .34475 L F
.574 .096 0 r
.64359 .34684 m .64217 .34529 L .64194 .34487 L F
.919 .553 .318 r
.64698 .34945 m .64217 .34529 L .64359 .34684 L F
.64698 .34945 m .64549 .34931 L .64217 .34529 L F
.914 .59 .418 r
.64217 .34529 m .64549 .34931 L .64202 .3468 L F
.64217 .34529 m .64202 .3468 L .64136 .34475 L F
0 0 .078 r
.64202 .3468 m .64243 .34472 L .64136 .34475 L F
.64243 .34472 m .64284 .34257 L .64136 .34475 L F
.013 .586 .746 r
.64029 .34477 m .64136 .34475 L .6382 .34465 L F
.64194 .34487 m .64136 .34475 L .64029 .34477 L F
.385 .338 .682 r
.26018 .58232 m .26215 .58216 L .26184 .57789 L F
.707 .965 .718 r
.57671 .37181 m .57539 .37399 L .57831 .37116 L F
.654 .246 .258 r
.581 .3703 m .57671 .37181 L .57831 .37116 L F
.585 .082 .024 r
.40308 .48545 m .40173 .48712 L .39918 .48626 L F
.616 .117 .042 r
.40631 .48731 m .40173 .48712 L .40308 .48545 L F
.76 .857 .922 r
.50669 .43023 m .50863 .42647 L .50625 .4302 L F
.50669 .43023 m .51026 .42804 L .50863 .42647 L F
.632 .885 .548 r
.40157 .57545 m .39875 .57878 L .39926 .57827 L F
.08 0 0 r
.44046 .44514 m .43949 .44674 L .44274 .44405 L F
.265 .116 .484 r
.52288 .36002 m .52508 .35617 L .52377 .35754 L F
0 .021 .595 r
.56809 .36705 m .5682 .36518 L .56591 .36543 L F
.56809 .36705 m .56985 .36931 L .5682 .36518 L F
.841 .965 .884 r
.63915 .37485 m .63478 .37297 L .63728 .3735 L F
.63915 .37485 m .63653 .37494 L .63478 .37297 L F
.808 .729 .777 r
.63996 .37331 m .63915 .37485 L .63728 .3735 L F
.936 .853 .735 r
.42719 .54884 m .42338 .55142 L .42572 .54748 L F
.42719 .54884 m .42484 .55208 L .42338 .55142 L F
.432 .832 .979 r
.58319 .34549 m .58666 .34543 L .58366 .34511 L F
.783 .314 .125 r
.65899 .34832 m .6603 .34729 L .65834 .34652 L F
.65899 .34832 m .66056 .34884 L .6603 .34729 L F
.193 .719 .849 r
.34619 .65952 m .34997 .65947 L .34925 .65923 L F
.971 .928 .674 r
.34755 .66124 m .34997 .65947 L .34619 .65952 L F
0 0 .067 r
.34997 .65947 m .35086 .65533 L .34925 .65923 L F
0 0 0 r
.46456 .4279 m .46085 .43078 L .46315 .42956 L F
.46638 .42636 m .46456 .4279 L .46315 .42956 L F
.676 .194 .1 r
.36781 .57562 m .3662 .57769 L .36296 .57489 L F
.798 .339 0 r
.36781 .57562 m .36789 .57733 L .3662 .57769 L F
.36781 .57562 m .36897 .57794 L .36789 .57733 L F
.203 .649 .948 r
.36789 .57733 m .36843 .57626 L .36671 .57666 L F
.36789 .57733 m .36671 .57666 L .36603 .57681 L F
.798 .339 0 r
.36897 .57794 m .36935 .57869 L .36789 .57733 L F
0 .554 .788 r
.638 .33653 m .64384 .33768 L .64124 .33847 L F
.909 .811 .738 r
.4588 .515 m .45452 .51734 L .45669 .51382 L F
.4588 .515 m .45658 .51851 L .45452 .51734 L F
.588 .317 .474 r
.37096 .55292 m .36877 .55202 L .37285 .55243 L F
.475 .45 .751 r
.36877 .55202 m .37096 .55292 L .37016 .54723 L F
.588 .317 .474 r
.36877 .55202 m .36858 .55251 L .37096 .55292 L F
.36858 .55251 m .36782 .55448 L .37052 .55314 L F
.36858 .55251 m .37052 .55314 L .37096 .55292 L F
.37096 .55292 m .36782 .55448 L .36877 .55202 L F
.86 .982 .853 r
.37285 .55243 m .36977 .55566 L .37042 .55393 L F
.37117 .55264 m .37042 .55393 L .37088 .55267 L F
.37285 .55243 m .37042 .55393 L .37117 .55264 L F
.492 .463 .753 r
.37016 .54723 m .37096 .55292 L .37106 .55283 L F
.37286 .54975 m .37106 .55283 L .37372 .55056 L F
.37016 .54723 m .37106 .55283 L .37286 .54975 L F
.441 .518 .841 r
.36977 .55566 m .37243 .5559 L .37121 .55336 L F
.37069 .55319 m .37121 .55336 L .37088 .55267 L F
.36977 .55566 m .37121 .55336 L .37069 .55319 L F
.442 .674 .962 r
.57671 .37181 m .5779 .37372 L .57539 .37399 L F
.832 .623 .621 r
.3123 .54142 m .31477 .5422 L .31267 .53863 L F
.798 .55 .563 r
.30992 .54444 m .31477 .5422 L .3123 .54142 L F
.30992 .54444 m .31448 .54505 L .31477 .5422 L F
0 0 0 r
.56856 .39344 m .57171 .39068 L .56877 .39066 L F
.674 .96 .735 r
.31346 .65043 m .31046 .6532 L .31123 .6517 L F
.566 .918 .96 r
.31123 .6517 m .31046 .6532 L .3088 .65281 L F
.214 0 .158 r
.5521 .38327 m .5491 .38611 L .54972 .38429 L F
.588 .421 .623 r
.64637 .38105 m .64993 .38015 L .64738 .38376 L F
.948 .823 .688 r
.35992 .55062 m .36383 .54839 L .36253 .54753 L F
.35992 .55062 m .36151 .55162 L .36383 .54839 L F
.318 0 .107 r
.2744 .5523 m .27688 .55175 L .27755 .55105 L F
.55 .386 .611 r
.27437 .55435 m .27688 .55175 L .2744 .5523 L F
.87 .58 .494 r
.34393 .63181 m .34716 .6299 L .34349 .62878 L F
.34393 .63181 m .34793 .63292 L .34716 .6299 L F
.593 .363 .537 r
.56808 .35666 m .57101 .35645 L .57114 .3538 L F
.619 .942 .951 r
.35175 .64982 m .35336 .64873 L .35175 .64869 L F
.8 .58 .018 r
.35157 .65063 m .35175 .64982 L .35175 .64869 L F
.35157 .65063 m .35206 .65285 L .35175 .64982 L F
.375 .194 .503 r
.51661 .41075 m .5166 .41343 L .51427 .41442 L F
.744 .914 .545 r
.51427 .41442 m .51661 .41075 L .5166 .41343 L F
.667 .97 .912 r
.5402 .40465 m .53571 .40622 L .538 .40562 L F
.653 .124 0 r
.538 .40562 m .54208 .40609 L .5402 .40465 L F
.743 .983 .759 r
.31545 .61239 m .31121 .61571 L .31355 .61465 L F
.069 0 .102 r
.31849 .60983 m .31545 .61239 L .31797 .61085 L F
0 0 0 r
.31797 .61085 m .31545 .61239 L .31355 .61465 L F
.813 .997 .772 r
.34035 .62029 m .3418 .6204 L .33937 .62314 L F
.032 0 0 r
.5394 .38717 m .54168 .38646 L .54259 .38419 L F
.124 0 .029 r
.54259 .38419 m .54416 .38531 L .54507 .38308 L F
.54259 .38419 m .54168 .38646 L .54416 .38531 L F
.376 .001 .194 r
.27576 .57321 m .27448 .57535 L .27197 .57566 L F
.359 .042 .285 r
.27812 .57216 m .27448 .57535 L .27576 .57321 L F
.705 .918 .577 r
.54616 .42044 m .54382 .42398 L .54475 .42186 L F
.783 .976 .695 r
.54475 .42186 m .54382 .42398 L .54299 .42404 L F
.426 .501 .833 r
.25863 .59262 m .26151 .59411 L .26094 .59216 L F
.324 0 0 r
.34955 .63842 m .35133 .63795 L .34851 .63734 L F
.34955 .63842 m .34851 .63734 L .34652 .63491 L F
0 .386 .734 r
.32517 .60788 m .32114 .60624 L .32282 .60513 L F
.955 .951 .679 r
.32349 .60872 m .32517 .60788 L .32282 .60513 L F
.645 .909 .599 r
.44556 .53257 m .44389 .53394 L .445 .53257 L F
.072 0 0 r
.45867 .44533 m .45771 .44401 L .46013 .44319 L F
.45867 .44533 m .45637 .44641 L .45771 .44401 L F
.388 .803 .976 r
.60939 .34257 m .61353 .34286 L .61076 .34346 L F
.891 .607 .499 r
.34724 .55209 m .34407 .55131 L .34407 .54846 L F
.907 .665 .562 r
.34724 .55514 m .34407 .55131 L .34724 .55209 L F
.925 .712 .595 r
.34004 .53843 m .33797 .53391 L .34032 .53532 L F
.712 .596 .725 r
.29408 .59756 m .29638 .59522 L .29518 .59167 L F
0 0 .094 r
.42089 .55762 m .41986 .55902 L .4212 .55748 L F
0 0 .154 r
.41943 .56171 m .4212 .55748 L .41986 .55902 L F
.307 .144 .491 r
.28614 .63751 m .28818 .63867 L .28807 .6358 L F
.28614 .63751 m .28612 .63958 L .28818 .63867 L F
.405 .107 .344 r
.33601 .67399 m .33785 .67572 L .3357 .67486 L F
.33601 .67399 m .33862 .67317 L .33785 .67572 L F
.695 .197 .056 r
.35806 .53719 m .35833 .53531 L .35673 .53533 L F
.35806 .53719 m .36072 .53771 L .35833 .53531 L F
.586 .248 .364 r
.35833 .53531 m .36072 .53771 L .36112 .53531 L F
.796 .635 .683 r
.37247 .53859 m .3694 .54157 L .37354 .5421 L F
.838 .636 .63 r
.36928 .54435 m .37354 .5421 L .3694 .54157 L F
.36928 .54435 m .37285 .54525 L .37354 .5421 L F
0 0 0 r
.63359 .39201 m .63474 .38997 L .63384 .38956 L F
.513 .907 .929 r
.63384 .38956 m .63474 .38997 L .638 .38859 L F
.933 .857 .423 r
.40517 .57631 m .40409 .57792 L .40486 .57496 L F
.127 0 0 r
.40664 .57718 m .40517 .57631 L .40843 .57865 L F
.61 .454 .645 r
.40517 .57631 m .40597 .57928 L .40843 .57865 L F
.127 0 0 r
.40664 .57718 m .40409 .57792 L .40517 .57631 L F
.928 .97 .753 r
.48576 .47806 m .48705 .47348 L .48828 .47442 L F
.792 .965 .917 r
.48828 .47442 m .48884 .47136 L .49152 .47173 L F
.48828 .47442 m .48705 .47348 L .48884 .47136 L F
0 0 0 r
.47249 .43387 m .47581 .43143 L .47506 .43264 L F
.221 0 .056 r
.47823 .43033 m .47506 .43264 L .47581 .43143 L F
.608 .076 0 r
.56864 .3406 m .56663 .34153 L .56388 .33968 L F
.99 .765 .504 r
.56691 .33882 m .56663 .34153 L .56864 .3406 L F
.974 .87 .67 r
.28067 .56835 m .28217 .57012 L .28315 .56848 L F
.28067 .56835 m .27956 .57106 L .28217 .57012 L F
.955 .86 .707 r
.35324 .64564 m .35656 .64275 L .35459 .6422 L F
.35324 .64564 m .3553 .64674 L .35656 .64275 L F
.935 .565 .183 r
.2985 .56811 m .29638 .56451 L .29803 .56574 L F
.289 .389 .792 r
.51276 .40279 m .51185 .40744 L .51074 .40371 L F
.51276 .40279 m .51422 .40566 L .51185 .40744 L F
.52 .822 1 r
.54496 .34685 m .54321 .3455 L .5474 .346 L F
.384 .187 .486 r
.5474 .346 m .545 .34976 L .54496 .34685 L F
.835 .999 .808 r
.4323 .52172 m .4316 .52138 L .42874 .52461 L F
.944 .58 .227 r
.50995 .41931 m .51192 .42077 L .51053 .41666 L F
0 0 0 r
.436 .45009 m .43733 .44808 L .43392 .45057 L F
.43949 .44674 m .43733 .44808 L .436 .45009 L F
.769 .384 .326 r
.33592 .52062 m .34115 .51957 L .33599 .5176 L F
.33592 .52062 m .34023 .52141 L .34115 .51957 L F
.753 .682 .782 r
.29833 .58533 m .29994 .58928 L .30265 .58599 L F
.656 .705 .883 r
.5426 .41625 m .54551 .41559 L .54425 .41265 L F
.773 .936 .936 r
.52124 .46888 m .52326 .46925 L .52565 .4679 L F
.904 .505 .238 r
.37372 .55056 m .37508 .54887 L .37349 .54766 L F
.37372 .55056 m .37583 .55156 L .37508 .54887 L F
.85 .512 .414 r
.30859 .53839 m .3123 .54142 L .31267 .53863 L F
.948 .861 .72 r
.53217 .45629 m .53483 .45523 L .53478 .45232 L F
.53217 .45629 m .53372 .45769 L .53483 .45523 L F
.708 .721 .86 r
.29324 .53182 m .291 .53444 L .29008 .53471 L F
.253 0 .022 r
.43034 .46441 m .42895 .46674 L .42635 .46739 L F
.411 .018 .179 r
.43302 .46378 m .42895 .46674 L .43034 .46441 L F
0 0 0 r
.55147 .41402 m .54945 .41747 L .55065 .41484 L F
.741 .916 .55 r
.55065 .41484 m .54945 .41747 L .54805 .41879 L F
.356 .171 .488 r
.26857 .56179 m .27009 .55856 L .26899 .5594 L F
.644 .558 .744 r
.29518 .59167 m .29638 .59522 L .29779 .59297 L F
.261 0 0 r
.49752 .41513 m .49648 .41416 L .49435 .41471 L F
.707 .741 .878 r
.49979 .41673 m .5015 .41268 L .49953 .41346 L F
.637 .909 .606 r
.49819 .4183 m .49961 .4163 L .49964 .41561 L F
.477 .24 .476 r
.49648 .41416 m .49979 .41468 L .49953 .41346 L F
.707 .741 .878 r
.49979 .41673 m .50313 .41516 L .5015 .41268 L F
.081 .202 .692 r
.49979 .41468 m .49979 .41673 L .50127 .415 L F
.192 0 0 r
.50127 .415 m .49979 .41468 L .49752 .41513 L F
.261 0 0 r
.49752 .41513 m .49863 .41491 L .49648 .41416 L F
.49863 .41491 m .49979 .41468 L .49785 .41437 L F
.49863 .41491 m .49785 .41437 L .49648 .41416 L F
.148 .039 .462 r
.49953 .41346 m .49979 .41468 L .50127 .415 L F
.192 0 0 r
.50127 .415 m .49752 .41513 L .49974 .41361 L F
.637 .909 .606 r
.49918 .41529 m .49964 .41561 L .49974 .41361 L F
.49819 .4183 m .49964 .41561 L .49918 .41529 L F
.504 .31 .551 r
.49648 .41416 m .49953 .41346 L .49901 .41083 L F
.849 .606 .571 r
.31596 .55175 m .31572 .5547 L .31993 .55522 L F
.85 .685 .677 r
.31572 .5547 m .31768 .55899 L .31993 .55522 L F
.89 .86 .805 r
.48576 .47806 m .48152 .48019 L .48474 .4773 L F
.48576 .47806 m .48327 .48161 L .48152 .48019 L F
.928 .97 .753 r
.48576 .47806 m .48474 .4773 L .48705 .47348 L F
.958 .85 .692 r
.42632 .52231 m .42642 .52575 L .42448 .52413 L F
.872 .89 .844 r
.42642 .52575 m .4249 .52618 L .42448 .52413 L F
.792 .453 .415 r
.42632 .52231 m .42874 .52461 L .42642 .52575 L F
.442 .878 .836 r
.42642 .52575 m .42874 .52461 L .4249 .52618 L F
.936 .859 .739 r
.28255 .56449 m .28067 .56835 L .28315 .56848 L F
.773 .936 .936 r
.52124 .46888 m .52565 .4679 L .52397 .46635 L F
.841 .837 .842 r
.52565 .4679 m .52676 .46299 L .52397 .46635 L F
.52565 .4679 m .52843 .4646 L .52676 .46299 L F
.786 .643 .704 r
.33514 .63674 m .33398 .63368 L .33561 .63423 L F
.098 .09 .559 r
.33561 .63423 m .33606 .63787 L .33514 .63674 L F
.223 .115 .514 r
.33606 .63787 m .33506 .63972 L .33514 .63674 L F
0 0 .316 r
.58042 .38522 m .57962 .38425 L .57998 .38258 L F
.58042 .38522 m .58011 .38632 L .57962 .38425 L F
0 0 .074 r
.37508 .56601 m .37725 .56489 L .37805 .56221 L F
.335 .093 .391 r
.37805 .56221 m .38039 .56147 L .3808 .55888 L F
.905 .978 .792 r
.39461 .58097 m .39196 .58464 L .39306 .58533 L F
.542 .447 .697 r
.57597 .36344 m .57684 .36723 L .5741 .36802 L F
.589 .019 0 r
.34334 .62184 m .3418 .6204 L .34035 .62029 L F
.564 .504 .747 r
.58375 .3806 m .58155 .37623 L .58178 .37877 L F
.925 .908 .786 r
.3088 .62941 m .31143 .6262 L .30953 .62756 L F
.782 .331 .178 r
.30953 .62756 m .31143 .6262 L .31256 .62814 L F
.438 .732 .989 r
.31976 .67891 m .32319 .68003 L .32137 .67884 L F
.435 .772 .997 r
.32137 .67884 m .32319 .68003 L .32576 .67952 L F
.572 .561 .804 r
.32319 .68003 m .32667 .68257 L .32576 .67952 L F
.528 .468 .732 r
.31666 .63878 m .31437 .63966 L .31382 .63606 L F
.437 .874 .892 r
.31299 .63953 m .31437 .63966 L .31666 .63878 L F
.486 .32 .581 r
.31435 .64264 m .31666 .63878 L .31437 .63966 L F
.679 .975 .902 r
.62315 .34374 m .6215 .34611 L .62485 .34389 L F
.62315 .34374 m .62065 .34567 L .6215 .34611 L F
.137 0 .108 r
.53708 .39014 m .53888 .38951 L .5394 .38717 L F
.078 0 .091 r
.5394 .38717 m .54118 .38807 L .54168 .38646 L F
.5394 .38717 m .53888 .38951 L .54118 .38807 L F
0 .524 .747 r
.64384 .33768 m .64818 .33821 L .64785 .33833 L F
.272 .564 .934 r
.65073 .33693 m .65179 .33895 L .64785 .33833 L F
.653 .806 .957 r
.65026 .33661 m .65054 .33703 L .65073 .33693 L F
.65054 .33703 m .65179 .33895 L .65073 .33693 L F
.963 .913 .558 r
.65047 .33735 m .65179 .33895 L .65054 .33703 L F
.364 .804 .959 r
.6471 .33482 m .6442 .33549 L .64675 .33467 L F
.64857 .33548 m .64598 .33548 L .6471 .33482 L F
.64598 .33548 m .6442 .33549 L .6471 .33482 L F
.64857 .33548 m .64612 .3352 L .6442 .33549 L F
.217 .554 .933 r
.64612 .3352 m .64573 .33563 L .642 .33698 L F
.64573 .33563 m .64384 .33768 L .64287 .33731 L F
.64573 .33563 m .64287 .33731 L .642 .33698 L F
.272 .564 .934 r
.65054 .33703 m .64785 .33833 L .64812 .33823 L F
.65055 .33702 m .64785 .33833 L .65054 .33703 L F
.65073 .33693 m .64812 .33823 L .64818 .33821 L F
.749 .856 .929 r
.65053 .33703 m .64818 .33821 L .65038 .3368 L F
.65025 .33661 m .64612 .3352 L .64857 .33548 L F
.65038 .3368 m .64612 .3352 L .65026 .33662 L F
.65038 .3368 m .65007 .337 L .64958 .3365 L F
0 .022 .525 r
.64857 .33548 m .65047 .33735 L .65027 .33662 L F
.64857 .33548 m .65027 .33662 L .65026 .33661 L F
.749 .856 .929 r
.65026 .33662 m .65025 .33661 L .64857 .33548 L F
.963 .913 .558 r
.65027 .33662 m .65054 .33703 L .65026 .33661 L F
.65033 .33673 m .65054 .33703 L .65027 .33662 L F
.749 .856 .929 r
.65073 .33693 m .65038 .3368 L .65026 .33662 L F
.963 .913 .558 r
.65027 .33663 m .65033 .33673 L .65027 .33662 L F
0 .022 .525 r
.64868 .33558 m .65119 .33803 L .65047 .33735 L F
.64857 .33548 m .64865 .33556 L .64868 .33558 L F
.64865 .33556 m .65119 .33803 L .64868 .33558 L F
.749 .856 .929 r
.64958 .3365 m .64818 .33821 L .64612 .3352 L F
.65007 .337 m .64818 .33821 L .64958 .3365 L F
.963 .913 .558 r
.65053 .33703 m .65054 .33703 L .65027 .33663 L F
.272 .564 .934 r
.65073 .33693 m .65055 .33702 L .65054 .33703 L F
.749 .856 .929 r
.65073 .33693 m .65053 .33703 L .65038 .3368 L F
.963 .913 .558 r
.65041 .33711 m .65053 .33703 L .65027 .33663 L F
.65047 .33735 m .65054 .33703 L .65041 .33711 L F
.65047 .33735 m .65048 .33738 L .65179 .33895 L F
.093 .578 .904 r
.64785 .33833 m .65179 .33895 L .65249 .33977 L F
.963 .913 .558 r
.65048 .33738 m .65088 .34148 L .65179 .33895 L F
.093 .578 .904 r
.65249 .33977 m .65179 .33895 L .65295 .33992 L F
.138 0 0 r
.545 .34976 m .54109 .35242 L .54235 .35096 L F
.858 .991 .837 r
.50594 .41347 m .50973 .41086 L .50818 .41201 L F
.676 .904 .563 r
.53381 .39663 m .5312 .39989 L .53247 .39842 L F
.779 .836 .896 r
.61066 .34844 m .61247 .35055 L .6148 .34895 L F
.646 .814 .383 r
.50826 .40422 m .50616 .40791 L .50725 .40586 L F
.479 .585 .883 r
.50826 .40422 m .5089 .401 L .50634 .40296 L F
.50826 .40422 m .51074 .40371 L .5089 .401 L F
0 0 0 r
.50826 .40422 m .50863 .404 L .51074 .40371 L F
.50826 .40422 m .50725 .40586 L .50863 .404 L F
.84 .513 .433 r
.36791 .53523 m .36782 .53764 L .37247 .53859 L F
.842 .723 .733 r
.36782 .53764 m .3694 .54157 L .37247 .53859 L F
.74 .872 .941 r
.49705 .40877 m .49901 .41083 L .50219 .40842 L F
.742 .941 .949 r
.50219 .40842 m .49901 .41083 L .50147 .40939 L F
.315 .188 .544 r
.49901 .41083 m .5015 .41268 L .50147 .40939 L F
.49901 .41083 m .49953 .41346 L .5015 .41268 L F
.795 .518 .518 r
.34194 .52447 m .34446 .52808 L .34618 .52517 L F
.788 .509 .514 r
.34618 .52517 m .34446 .52808 L .34826 .52824 L F
.419 .862 .793 r
.44665 .54163 m .44227 .54323 L .44381 .54415 L F
.378 .788 .981 r
.44381 .54415 m .44227 .54323 L .43991 .54363 L F
0 0 0 r
.4366 .54448 m .43581 .54717 L .43651 .54684 L F
.4366 .54448 m .43797 .54316 L .43581 .54717 L F
.753 .971 .928 r
.65496 .37806 m .65736 .37827 L .65945 .3765 L F
.359 .042 .285 r
.27812 .57216 m .27718 .57465 L .27448 .57535 L F
.582 .808 .985 r
.26857 .57298 m .27593 .57395 L .27103 .57232 L F
.342 0 .148 r
.27508 .57452 m .27593 .57395 L .26897 .57303 L F
.947 .663 .468 r
.27464 .57477 m .27718 .57465 L .27448 .57535 L F
.27505 .57461 m .27718 .57465 L .27464 .57477 L F
.27655 .57421 m .27718 .57465 L .27469 .5746 L F
.532 .768 .984 r
.27448 .57535 m .27615 .57492 L .27604 .57475 L F
.342 0 .148 r
.27508 .57452 m .27547 .57444 L .27593 .57395 L F
.951 .65 .213 r
.27593 .57395 m .27356 .56934 L .27103 .57232 L F
.532 .768 .984 r
.27473 .57443 m .27604 .57475 L .27508 .5732 L F
.27448 .57535 m .27604 .57475 L .27473 .57443 L F
.823 .795 .825 r
.27699 .5756 m .27448 .57535 L .27615 .57492 L F
.27813 .57571 m .27592 .57741 L .27448 .57535 L F
.065 0 0 r
.27577 .57431 m .27266 .57743 L .275 .5761 L F
.27593 .57395 m .27547 .57444 L .27577 .57431 L F
.27547 .57444 m .27266 .57743 L .27577 .57431 L F
.947 .663 .468 r
.27469 .5746 m .27505 .57461 L .27464 .57477 L F
.065 0 0 r
.27593 .57395 m .27577 .57431 L .27508 .5732 L F
.947 .663 .468 r
.27508 .5732 m .27655 .57421 L .2758 .57437 L F
.27508 .5732 m .2758 .57437 L .27469 .5746 L F
.342 0 .148 r
.26982 .57805 m .27266 .57743 L .27547 .57444 L F
.26982 .57805 m .27547 .57444 L .27508 .57452 L F
.26982 .57805 m .27508 .57452 L .26857 .57298 L F
.27508 .57452 m .26897 .57303 L .26857 .57298 L F
.532 .768 .984 r
.27615 .57492 m .27718 .57465 L .27508 .5732 L F
.065 0 0 r
.27577 .57431 m .27568 .57454 L .27508 .5732 L F
.27568 .57454 m .275 .5761 L .27505 .57403 L F
.27568 .57454 m .27505 .57403 L .27508 .5732 L F
.823 .795 .825 r
.27813 .57571 m .27699 .5756 L .27718 .57465 L F
.27699 .5756 m .27615 .57492 L .27718 .57465 L F
.229 0 .127 r
.27673 .58001 m .27592 .57741 L .27813 .57571 L F
0 0 .356 r
.27898 .57175 m .27813 .57571 L .27718 .57465 L F
.27898 .57175 m .27972 .57678 L .27813 .57571 L F
.413 .158 .415 r
.27972 .57678 m .27673 .58001 L .27813 .57571 L F
.642 .131 .017 r
.35909 .56943 m .35824 .57076 L .35499 .56832 L F
.816 .682 .717 r
.36354 .56919 m .35824 .57076 L .35909 .56943 L F
0 0 0 r
.40952 .46736 m .41197 .46634 L .4131 .46525 L F
.41197 .46634 m .41547 .4642 L .4131 .46525 L F
.62 .895 .585 r
.33272 .52117 m .33599 .5176 L .3329 .51853 L F
.582 .63 .864 r
.26401 .5858 m .26497 .58144 L .26215 .58216 L F
.26401 .5858 m .2671 .58587 L .26497 .58144 L F
.681 .671 .834 r
.26876 .59015 m .2645 .58867 L .26547 .58932 L F
.587 .308 .46 r
.26401 .5858 m .26547 .58932 L .2671 .58587 L F
.025 .033 .528 r
.2645 .58867 m .26547 .58932 L .26401 .5858 L F
.587 .308 .46 r
.26401 .5858 m .26547 .58932 L .2671 .58587 L F
.025 .033 .528 r
.2645 .58867 m .26547 .58932 L .26401 .5858 L F
.57 .6 .844 r
.31204 .6771 m .31562 .6796 L .31489 .67617 L F
.655 .7 .88 r
.31562 .6796 m .31696 .67578 L .31489 .67617 L F
.31562 .6796 m .31976 .67891 L .31696 .67578 L F
.261 .755 .908 r
.35133 .63795 m .35353 .63778 L .3549 .63829 L F
.933 .803 .693 r
.35353 .63778 m .35459 .6422 L .3549 .63829 L F
.473 .206 .427 r
.38039 .56147 m .38369 .55828 L .3808 .55888 L F
.789 .345 .194 r
.31907 .62467 m .32113 .62322 L .31713 .62189 L F
.364 0 0 r
.32424 .6237 m .32113 .62322 L .31907 .62467 L F
.93 .886 .768 r
.35336 .64873 m .3553 .64674 L .35324 .64564 L F
.905 .686 .595 r
.34883 .55877 m .3459 .55829 L .34724 .55514 L F
.874 .825 .796 r
.62935 .38093 m .62501 .38247 L .62711 .38064 L F
.62935 .38093 m .62651 .38506 L .62501 .38247 L F
.545 .826 .998 r
.631 .37858 m .62935 .38093 L .62711 .38064 L F
.631 .37858 m .63221 .38014 L .62935 .38093 L F
.442 .173 .408 r
.5304 .39414 m .53333 .39336 L .53338 .39097 L F
.006 0 0 r
.53333 .39336 m .53708 .39014 L .53338 .39097 L F
.239 0 0 r
.66435 .34976 m .66637 .35037 L .66351 .34941 L F
.695 .339 0 r
.66628 .34983 m .66649 .35034 L .66651 .35034 L F
.66649 .35034 m .66722 .35212 L .66651 .35034 L F
0 0 .396 r
.66705 .35058 m .66722 .35212 L .66628 .34983 L F
.239 0 0 r
.66637 .35037 m .66705 .35058 L .6664 .35037 L F
.66637 .35037 m .6664 .35037 L .66351 .34941 L F
.861 .685 .155 r
.66705 .35058 m .66717 .35215 L .66722 .35212 L F
.66717 .35215 m .66735 .35442 L .66722 .35212 L F
.695 .339 0 r
.66728 .35207 m .66722 .35212 L .66801 .35374 L F
.66651 .35034 m .66722 .35212 L .66728 .35207 L F
.923 .675 .186 r
.66722 .35212 m .66813 .35609 L .66801 .35374 L F
.898 .887 .813 r
.48327 .48161 m .47902 .48397 L .48152 .48019 L F
.48327 .48161 m .48071 .48529 L .47902 .48397 L F
.829 .904 .891 r
.48768 .50185 m .48896 .49743 L .48593 .50039 L F
.48768 .50185 m .49075 .49894 L .48896 .49743 L F
.871 .493 .325 r
.65295 .33992 m .65465 .34315 L .65641 .34345 L F
.86 .465 .29 r
.65465 .34315 m .65511 .34526 L .65641 .34345 L F
.833 .426 .271 r
.65511 .34526 m .65834 .34652 L .65641 .34345 L F
.537 .565 .831 r
.52199 .40339 m .52485 .40261 L .52342 .39917 L F
0 0 0 r
.51422 .38113 m .51311 .38271 L .51591 .37934 L F
.824 .825 .849 r
.6671 .36856 m .66866 .37003 L .66761 .36684 L F
.762 .902 .939 r
.66539 .37027 m .66866 .37003 L .6671 .36856 L F
.811 .887 .899 r
.66866 .37003 m .67065 .36573 L .66761 .36684 L F
.66866 .37003 m .67216 .36731 L .67065 .36573 L F
.771 .882 .926 r
.48071 .48529 m .47562 .48647 L .47902 .48397 L F
.187 .374 .817 r
.51071 .44924 m .50938 .4465 L .51081 .44698 L F
.51071 .44924 m .51147 .4501 L .50938 .4465 L F
.715 .644 .777 r
.50938 .4465 m .50983 .44729 L .50595 .44945 L F
.50983 .44729 m .51147 .4501 L .51072 .45001 L F
.50983 .44729 m .51072 .45001 L .50595 .44945 L F
.996 .848 .572 r
.51279 .45136 m .51142 .45217 L .51071 .44924 L F
.622 .405 .566 r
.51072 .45001 m .50706 .45283 L .50595 .44945 L F
.51147 .4501 m .51083 .45049 L .51072 .45001 L F
.51083 .45049 m .50706 .45283 L .51072 .45001 L F
.51083 .45049 m .51071 .4526 L .50706 .45283 L F
.996 .848 .572 r
.51142 .45217 m .51122 .45229 L .51083 .45049 L F
.51142 .45217 m .51083 .45049 L .51083 .45036 L F
.51122 .45229 m .51071 .4526 L .51072 .45001 L F
.51142 .45217 m .51071 .44998 L .51071 .44924 L F
.622 .405 .566 r
.51147 .4501 m .51071 .4526 L .51083 .45049 L F
.996 .848 .572 r
.51083 .45036 m .51083 .45049 L .51072 .45001 L F
.51072 .45001 m .51071 .4526 L .51071 .44998 L F
.51279 .45136 m .51208 .45431 L .51071 .4526 L F
.674 .781 .93 r
.31204 .6771 m .31265 .67414 L .31037 .6765 L F
.31204 .6771 m .31489 .67617 L .31265 .67414 L F
.964 .886 .705 r
.30854 .63199 m .3088 .62941 L .30599 .63123 L F
.938 .803 .686 r
.3063 .63606 m .30854 .63199 L .30599 .63123 L F
.96 .928 .719 r
.64013 .36684 m .64099 .36194 L .64224 .3635 L F
.597 .871 .544 r
.33003 .68009 m .33308 .67672 L .33151 .67839 L F
.585 .839 .993 r
.3307 .67528 m .33308 .67672 L .3357 .67486 L F
.933 .832 .721 r
.33151 .67839 m .33308 .67672 L .3307 .67528 L F
.703 .382 .431 r
.43641 .53397 m .4407 .5318 L .43826 .5313 L F
.598 .851 .992 r
.58111 .3672 m .57943 .366 L .58221 .36498 L F
.132 0 0 r
.60777 .37991 m .60424 .38244 L .60509 .38114 L F
.302 0 .114 r
.39627 .47437 m .39891 .47374 L .40028 .47111 L F
.496 .095 .21 r
.40028 .47111 m .39891 .47374 L .40251 .47242 L F
.513 .067 .128 r
.40028 .47111 m .40251 .47242 L .40322 .47127 L F
.944 .923 .758 r
.55575 .41623 m .55911 .41339 L .55777 .41248 L F
.55575 .41623 m .5569 .41756 L .55911 .41339 L F
.858 .909 .867 r
.55911 .41339 m .56052 .40921 L .55777 .41248 L F
.55911 .41339 m .56184 .41052 L .56052 .40921 L F
.533 .411 .66 r
.62032 .33939 m .62334 .336 L .62332 .33635 L F
0 0 .097 r
.62332 .33635 m .62355 .3389 L .62334 .336 L F
0 .039 .601 r
.58639 .39415 m .58811 .39458 L .58751 .39197 L F
.58639 .39415 m .58776 .39689 L .58811 .39458 L F
.031 0 0 r
.43392 .45057 m .4351 .45157 L .436 .45009 L F
.43392 .45057 m .43275 .45266 L .4351 .45157 L F
.63 .767 .945 r
.41649 .56547 m .41428 .56667 L .41226 .56455 L F
.864 .493 .343 r
.65088 .34148 m .65295 .33992 L .65179 .33895 L F
.65088 .34148 m .65465 .34315 L .65295 .33992 L F
.807 .776 .824 r
.53975 .40907 m .54407 .40784 L .54208 .40609 L F
.604 .588 .807 r
.54545 .40278 m .54708 .40692 L .54407 .40784 L F
.57 .86 .996 r
.54407 .40784 m .54708 .40692 L .54553 .40642 L F
.604 .588 .807 r
.54545 .40278 m .54407 .40784 L .54553 .40642 L F
.821 .87 .882 r
.54553 .40642 m .54708 .40692 L .54634 .40534 L F
.546 .40512 m .54634 .40534 L .54611 .40483 L F
.54553 .40642 m .54634 .40534 L .546 .40512 L F
.604 .588 .807 r
.546 .40512 m .54553 .40642 L .54616 .40581 L F
.54545 .40278 m .54553 .40642 L .546 .40512 L F
.946 .596 .313 r
.54545 .40278 m .54596 .40496 L .54413 .40394 L F
.54596 .40496 m .546 .40512 L .54532 .40469 L F
.54596 .40496 m .54532 .40469 L .54413 .40394 L F
.855 .922 .874 r
.54393 .40411 m .54455 .40611 L .54532 .40469 L F
.54393 .40411 m .54532 .40469 L .5457 .40397 L F
.821 .87 .882 r
.54455 .40611 m .54553 .40642 L .5457 .40397 L F
.54553 .40642 m .54611 .40483 L .5457 .40397 L F
.604 .588 .807 r
.54616 .40581 m .54407 .40784 L .54628 .4063 L F
.946 .596 .313 r
.54413 .40394 m .54628 .4063 L .54393 .40411 L F
.546 .40512 m .54628 .4063 L .54413 .40394 L F
.57 .86 .996 r
.54407 .40784 m .54553 .40642 L .54455 .40611 L F
.54407 .40784 m .54455 .40611 L .54628 .4063 L F
.695 .614 .761 r
.54466 .41098 m .54708 .40692 L .54407 .40784 L F
.57 .7 .929 r
.29262 .66987 m .29621 .67112 L .29529 .66916 L F
.43 .674 .965 r
.29621 .67112 m .29729 .66927 L .29529 .66916 L F
.29621 .67112 m .30143 .67238 L .29729 .66927 L F
.477 .281 .534 r
.3835 .55546 m .38617 .55491 L .38626 .55201 L F
.487 .31 .566 r
.3835 .55546 m .38369 .55828 L .38617 .55491 L F
.181 0 .075 r
.44523 .45359 m .44839 .45131 L .4475 .45293 L F
.117 0 0 r
.4463 .455 m .44523 .45359 L .4475 .45293 L F
.4463 .455 m .44383 .45589 L .44523 .45359 L F
.892 .762 .711 r
.40396 .57228 m .40214 .5743 L .39996 .57286 L F
.131 .255 .725 r
.28298 .6592 m .28423 .66323 L .28533 .66145 L F
.28 .456 .856 r
.28423 .66323 m .2874 .66476 L .28533 .66145 L F
0 0 .203 r
.59449 .39426 m .59354 .39394 L .59536 .39201 L F
.59449 .39426 m .59351 .39654 L .59354 .39394 L F
.734 .495 .567 r
.31976 .63284 m .31582 .63552 L .31569 .63272 L F
.31976 .63284 m .32 .6357 L .31582 .63552 L F
0 0 .308 r
.31713 .62189 m .31682 .61938 L .31773 .61793 L F
0 0 .07 r
.31976 .63284 m .32147 .62845 L .32241 .63242 L F
.485 .31 .568 r
.32241 .63242 m .32 .6357 L .31976 .63284 L F
.412 .793 .992 r
.32241 .63242 m .31976 .63284 L .32 .6357 L F
.842 .716 .725 r
.47003 .49864 m .46939 .50127 L .46783 .49723 L F
.994 .841 .579 r
.60484 .35271 m .60664 .35441 L .6013 .35253 L F
.60664 .35441 m .6068 .35457 L .60657 .35448 L F
.60664 .35441 m .60657 .35448 L .6013 .35253 L F
.60484 .35271 m .60559 .35601 L .6068 .35457 L F
0 0 0 r
.60709 .35394 m .60721 .35411 L .60559 .35601 L F
.6082 .3524 m .60766 .35334 L .60709 .35394 L F
.60766 .35334 m .60721 .35411 L .60709 .35394 L F
.482 0 0 r
.56112 .38713 m .5589 .38767 L .55627 .38639 L F
.267 .115 .481 r
.56346 .38329 m .56337 .386 L .56112 .38713 L F
.177 0 0 r
.56337 .386 m .5589 .38767 L .56112 .38713 L F
.885 .832 .79 r
.52676 .46299 m .53068 .46094 L .52957 .45999 L F
.52676 .46299 m .52843 .4646 L .53068 .46094 L F
.846 .849 .846 r
.52957 .45999 m .53068 .46094 L .53372 .45769 L F
.004 0 .224 r
.31382 .63606 m .31569 .63272 L .31582 .63552 L F
.528 .468 .732 r
.31666 .63878 m .31382 .63606 L .31582 .63552 L F
.405 0 0 r
.62262 .3967 m .62405 .39807 L .62151 .39698 L F
.62262 .3967 m .62571 .39719 L .62405 .39807 L F
0 0 0 r
.29702 .6398 m .29919 .63726 L .29876 .63888 L F
.802 .699 .752 r
.46939 .50127 m .46528 .50077 L .46783 .49723 L F
.803 .697 .748 r
.46939 .50127 m .4668 .50484 L .46528 .50077 L F
.962 .818 .388 r
.5565 .40065 m .55602 .40319 L .55538 .40223 L F
.638 .828 .416 r
.5565 .40065 m .55538 .40223 L .55773 .3985 L F
0 0 0 r
.47249 .43387 m .47362 .43469 L .47116 .43574 L F
.47249 .43387 m .47506 .43264 L .47362 .43469 L F
.9 .904 .818 r
.51952 .4296 m .51798 .43511 L .51954 .43236 L F
.638 .875 .986 r
.51798 .43511 m .52119 .43679 L .51917 .43689 L F
.52119 .43679 m .52298 .43774 L .51917 .43689 L F
.895 .809 .756 r
.51917 .43689 m .51718 .43761 L .51788 .43694 L F
0 0 .488 r
.51954 .43236 m .51798 .43511 L .51917 .43689 L F
.51954 .43236 m .51933 .43496 L .51968 .43526 L F
.51933 .43496 m .51917 .43689 L .51968 .43526 L F
.895 .809 .756 r
.51917 .43689 m .51788 .43694 L .51968 .43526 L F
.51917 .43689 m .51832 .43977 L .51718 .43761 L F
.001 0 0 r
.52024 .43573 m .51968 .43526 L .51788 .43775 L F
.52213 .43412 m .51968 .43526 L .52024 .43573 L F
.774 .709 .791 r
.53767 .34947 m .53975 .35123 L .54096 .34687 L F
.522 .406 .663 r
.53767 .34947 m .54109 .35242 L .53975 .35123 L F
0 0 .339 r
.54096 .34687 m .53975 .35123 L .54246 .3476 L F
0 0 .531 r
.53975 .35123 m .54217 .34958 L .54246 .3476 L F
.53975 .35123 m .54109 .35242 L .54217 .34958 L F
.939 .826 .705 r
.62651 .38506 m .62395 .38498 L .62501 .38247 L F
.634 .085 0 r
.62651 .38506 m .62765 .38584 L .62395 .38498 L F
.688 .61 .763 r
.35089 .56743 m .35419 .5655 L .35096 .56569 L F
.35089 .56743 m .35499 .56832 L .35419 .5655 L F
.43 .865 .766 r
.26777 .59475 m .26408 .59657 L .26637 .59565 L F
.837 .793 .809 r
.33726 .6601 m .33777 .66116 L .33741 .65892 L F
.223 .656 .955 r
.33777 .66116 m .34061 .66028 L .33741 .65892 L F
.377 0 .021 r
.33777 .66116 m .34309 .66005 L .34203 .66143 L F
.34309 .66005 m .34336 .66 L .34203 .66143 L F
.997 .783 .487 r
.34203 .66143 m .34162 .66479 L .34113 .6626 L F
.223 .656 .955 r
.33777 .66116 m .34203 .66143 L .34061 .66028 L F
.997 .783 .487 r
.34203 .66143 m .34113 .6626 L .34061 .66028 L F
.916 .913 .801 r
.33347 .62986 m .33448 .62578 L .33168 .62886 L F
.93 .641 .471 r
.3317 .63162 m .33347 .62986 L .33168 .62886 L F
.788 .714 .783 r
.33398 .63368 m .33711 .62932 L .33347 .62986 L F
.626 .894 .577 r
.43651 .54684 m .43296 .55033 L .43357 .55153 L F
.43651 .54684 m .43581 .54717 L .43296 .55033 L F
.729 .981 .762 r
.33969 .67187 m .3438 .669 L .34197 .67052 L F
0 0 .015 r
.3438 .669 m .34637 .66551 L .34417 .66714 L F
.801 .955 .622 r
.34197 .67052 m .3438 .669 L .34417 .66714 L F
.482 .235 .463 r
.56494 .3597 m .56796 .35914 L .56808 .35666 L F
.446 .206 .456 r
.56808 .35666 m .57093 .35816 L .57101 .35645 L F
.56808 .35666 m .56796 .35914 L .57093 .35816 L F
.802 .82 .865 r
.45198 .53744 m .45376 .53894 L .45629 .53644 L F
.981 .902 .574 r
.28448 .64633 m .28253 .64818 L .28405 .64436 L F
.28448 .64633 m .28369 .64899 L .28253 .64818 L F
.533 .411 .66 r
.62032 .33939 m .62355 .3389 L .62334 .336 L F
.554 .901 .976 r
.61943 .33954 m .62355 .3389 L .62032 .33939 L F
.308 .107 .436 r
.26603 .56831 m .2679 .56463 L .26645 .56551 L F
.189 0 .108 r
.27592 .57741 m .27444 .58074 L .27227 .58149 L F
.229 0 .127 r
.27673 .58001 m .27444 .58074 L .27592 .57741 L F
.85 .746 .748 r
.30889 .57424 m .31336 .57217 L .31122 .57097 L F
.30889 .57424 m .31082 .57588 L .31336 .57217 L F
.862 .829 .813 r
.31122 .57097 m .31336 .57217 L .31591 .56873 L F
.899 .564 .079 r
.42291 .51191 m .42183 .51063 L .42115 .50748 L F
.994 .87 .546 r
.42291 .51191 m .42112 .51314 L .42183 .51063 L F
.42183 .51063 m .42291 .51191 L .42575 .51105 L F
.42183 .51063 m .42112 .51314 L .42291 .51191 L F
.166 0 .204 r
.32048 .60871 m .32114 .60624 L .31849 .60983 L F
.675 .485 .62 r
.32048 .60871 m .32282 .60513 L .32114 .60624 L F
.772 .97 .683 r
.49442 .46823 m .49152 .47173 L .49246 .46947 L F
.663 .944 .688 r
.49442 .46823 m .49553 .46646 L .49598 .46644 L F
.662 .939 .673 r
.49442 .46823 m .49246 .46947 L .49553 .46646 L F
.839 .507 .425 r
.40843 .57865 m .40834 .58109 L .41312 .58161 L F
.868 .683 .651 r
.40834 .58109 m .41036 .58527 L .41312 .58161 L F
.322 .573 .931 r
.3344 .63106 m .33398 .63368 L .3317 .63162 L F
.3344 .63106 m .33561 .63423 L .33398 .63368 L F
.145 0 .066 r
.45071 .45018 m .4475 .45293 L .44839 .45131 L F
.599 .854 .5 r
.35499 .56832 m .35739 .56538 L .35419 .5655 L F
.3552 .56806 m .35586 .56708 L .3569 .56598 L F
.35499 .56832 m .35586 .56708 L .3552 .56806 L F
.3569 .56598 m .35586 .56708 L .35739 .56538 L F
0 .386 .78 r
.35739 .56538 m .35287 .563 L .35419 .5655 L F
.35712 .56524 m .35724 .56506 L .35287 .563 L F
.35739 .56538 m .35724 .56506 L .35712 .56524 L F
.716 .965 .708 r
.35822 .56362 m .35724 .56506 L .35739 .56538 L F
.426 .273 .569 r
.35822 .56362 m .35733 .56492 L .35724 .56506 L F
.35733 .56492 m .35586 .56708 L .35724 .56506 L F
.35586 .56708 m .35822 .56362 L .35739 .56538 L F
.35822 .56362 m .35848 .56669 L .35586 .56708 L F
.35586 .56708 m .35848 .56669 L .35822 .56362 L F
.352 .764 .98 r
.35586 .56708 m .35848 .56669 L .35627 .56646 L F
.701 .659 .806 r
.35287 .563 m .35096 .56569 L .35419 .5655 L F
.831 .368 .104 r
.35586 .56708 m .35133 .5634 L .35724 .56506 L F
.35586 .56708 m .35329 .56614 L .35133 .5634 L F
.352 .764 .98 r
.35586 .56708 m .35627 .56646 L .35329 .56614 L F
.05 .279 .771 r
.35499 .56832 m .35824 .57076 L .35586 .56708 L F
0 0 .121 r
.35824 .57076 m .35848 .56669 L .35586 .56708 L F
.365 0 0 r
.35848 .56669 m .35473 .56827 L .35586 .56708 L F
.35473 .56827 m .35331 .56887 L .35586 .56708 L F
.667 .729 .895 r
.41453 .57158 m .41544 .57295 L .41808 .57185 L F
.02 0 0 r
.31773 .61793 m .31951 .61597 L .32157 .61568 L F
.569 .177 .258 r
.49039 .4213 m .49349 .42301 L .49063 .42326 L F
.542 .229 .387 r
.49385 .42073 m .49349 .42301 L .49039 .4213 L F
.356 .171 .488 r
.26857 .56179 m .27144 .56331 L .27009 .55856 L F
.703 .373 .414 r
.27009 .55856 m .27583 .56148 L .27369 .55675 L F
.27009 .55856 m .27144 .56331 L .27583 .56148 L F
.884 .748 .706 r
.31359 .56774 m .31591 .56873 L .31443 .56483 L F
.862 .829 .813 r
.31122 .57097 m .31591 .56873 L .31359 .56774 L F
.749 .691 .796 r
.29833 .58533 m .30265 .58599 L .30107 .58386 L F
.716 .75 .879 r
.30265 .58599 m .30384 .58137 L .30107 .58386 L F
.30265 .58599 m .30499 .5847 L .30384 .58137 L F
.981 .888 .657 r
.55563 .41958 m .5569 .41756 L .55465 .41879 L F
.98 .893 .661 r
.55465 .41879 m .5569 .41756 L .55575 .41623 L F
.16 0 0 r
.37995 .48081 m .38241 .48032 L .38388 .4787 L F
.03 0 0 r
.38388 .4787 m .38477 .47947 L .38674 .47833 L F
.38388 .4787 m .38241 .48032 L .38477 .47947 L F
.864 .735 .218 r
.51026 .42804 m .51037 .42249 L .50863 .42647 L F
.779 .836 .896 r
.61079 .34841 m .6148 .34895 L .61375 .34763 L F
.61074 .34845 m .6148 .34895 L .61079 .34841 L F
.572 .857 .996 r
.61079 .34841 m .61056 .34805 L .61066 .34844 L F
.61375 .34763 m .61135 .34794 L .61079 .34841 L F
.61135 .34794 m .61056 .34805 L .61079 .34841 L F
.61375 .34763 m .61231 .34673 L .61056 .34805 L F
0 0 .443 r
.61217 .34726 m .61263 .35007 L .61102 .35167 L F
.61225 .34698 m .61227 .34718 L .61217 .34726 L F
.61227 .34718 m .61263 .35007 L .61217 .34726 L F
.61231 .34673 m .61233 .3469 L .61225 .34698 L F
.61233 .3469 m .61263 .35007 L .61225 .34698 L F
.779 .836 .896 r
.61066 .34844 m .61074 .34845 L .61079 .34841 L F
.142 0 0 r
.61817 .34714 m .61375 .34763 L .6148 .34895 L F
.776 .734 .813 r
.32667 .68257 m .33003 .68009 L .32576 .67952 L F
.926 .942 .79 r
.45631 .53326 m .45629 .53644 L .45931 .53209 L F
.856 .992 .838 r
.45956 .52969 m .45931 .53209 L .46273 .52836 L F
.855 .991 .839 r
.45956 .52969 m .45631 .53326 L .45931 .53209 L F
.846 .849 .846 r
.52957 .45999 m .53372 .45769 L .53217 .45629 L F
.908 .928 .815 r
.63907 .39386 m .64048 .3888 L .64186 .3931 L F
.63907 .39386 m .63773 .39275 L .64048 .3888 L F
.545 .838 .999 r
.64186 .3931 m .63773 .39275 L .63907 .39386 L F
0 0 0 r
.27755 .55105 m .27906 .55021 L .279 .54806 L F
.27755 .55105 m .27688 .55175 L .27906 .55021 L F
0 .064 .576 r
.37508 .56601 m .37616 .56675 L .37725 .56489 L F
.37508 .56601 m .37777 .56853 L .37616 .56675 L F
.45 .401 .712 r
.48736 .42628 m .48515 .42745 L .48452 .42366 L F
.357 .805 .667 r
.48399 .42791 m .48515 .42745 L .48736 .42628 L F
.946 .622 .193 r
.62665 .38981 m .62662 .39232 L .62552 .39095 L F
.537 .802 .994 r
.62662 .39232 m .62851 .3904 L .62552 .39095 L F
0 0 0 r
.62695 .39062 m .62457 .39191 L .62552 .39095 L F
.571 .861 .542 r
.62552 .39095 m .62264 .394 L .62135 .38985 L F
.62552 .39095 m .62425 .39208 L .62264 .394 L F
0 0 0 r
.62457 .39191 m .62425 .39208 L .62552 .39095 L F
.946 .622 .193 r
.62666 .38914 m .62665 .38981 L .62552 .39095 L F
.925 .961 .649 r
.56184 .41052 m .56325 .4057 L .56052 .40921 L F
.512 .043 .079 r
.5874 .35033 m .59007 .35059 L .59146 .35012 L F
.587 .118 0 r
.58725 .34712 m .59007 .35059 L .5874 .35033 L F
.553 .091 .111 r
.26547 .58932 m .27074 .58851 L .26876 .59015 L F
.167 .295 .751 r
.5845 .37324 m .58585 .37756 L .58715 .37498 L F
0 .086 .619 r
.58585 .37756 m .58784 .37766 L .58715 .37498 L F
.58585 .37756 m .5869 .37991 L .58784 .37766 L F
.314 .311 .696 r
.50147 .40939 m .5042 .40894 L .50219 .40842 L F
.612 .461 .653 r
.5015 .41268 m .5042 .40894 L .50147 .40939 L F
.833 .683 .696 r
.56142 .36266 m .56189 .36388 L .56494 .3597 L F
.622 .388 .541 r
.56494 .3597 m .56826 .36236 L .56796 .35914 L F
.56494 .3597 m .56189 .36388 L .56826 .36236 L F
.745 .774 .876 r
.32576 .67952 m .33003 .68009 L .32878 .67873 L F
.734 .771 .882 r
.32878 .67873 m .33003 .68009 L .33151 .67839 L F
.719 .966 .937 r
.49152 .47173 m .48884 .47136 L .49246 .46947 L F
0 0 .527 r
.52435 .37744 m .52244 .3779 L .52121 .37568 L F
.52435 .37744 m .5234 .37978 L .52244 .3779 L F
.109 .306 .781 r
.2823 .65506 m .28232 .65656 L .28347 .65495 L F
.105 .3 .776 r
.28232 .65656 m .28512 .65872 L .28347 .65495 L F
.398 .32 .651 r
.28232 .65656 m .28298 .6592 L .28512 .65872 L F
0 0 0 r
.45774 .43362 m .45543 .43492 L .4542 .43577 L F
.45 .401 .712 r
.48736 .42628 m .48452 .42366 L .4868 .42281 L F
.29 .548 .921 r
.2874 .66476 m .28835 .66651 L .28924 .66479 L F
.269 .521 .908 r
.28924 .66479 m .28835 .66651 L .29047 .66653 L F
.293 0 .194 r
.279 .54806 m .28281 .54437 L .28007 .54489 L F
.834 .813 .829 r
.52096 .43923 m .52086 .4415 L .51832 .43977 L F
.787 .998 .847 r
.6262 .3411 m .62315 .34374 L .62485 .34389 L F
.456 .854 .664 r
.32147 .62845 m .32524 .62609 L .3232 .62782 L F
0 0 .299 r
.32455 .62434 m .32467 .62473 L .32424 .6237 L F
.443 0 0 r
.32455 .62434 m .32424 .6237 L .3217 .62454 L F
.517 .352 .595 r
.32455 .62434 m .32408 .62412 L .32442 .62394 L F
.32455 .62434 m .32442 .62394 L .32666 .62277 L F
0 0 .299 r
.32455 .62434 m .32524 .62609 L .32467 .62473 L F
.949 .946 .631 r
.3232 .62782 m .32524 .62609 L .32455 .62434 L F
.824 .763 .795 r
.43353 .55925 m .43653 .55613 L .43401 .55456 L F
.873 .872 .833 r
.67216 .36731 m .67493 .36377 L .67388 .36154 L F
.695 .614 .761 r
.54466 .41098 m .5472 .412 L .54708 .40692 L F
.733 .569 .669 r
.54646 .41416 m .5472 .412 L .54466 .41098 L F
.273 0 0 r
.55009 .40894 m .54708 .40692 L .5472 .412 L F
.556 .541 .793 r
.5472 .412 m .55163 .41188 L .55009 .40894 L F
.927 .925 .788 r
.46219 .52554 m .46461 .52535 L .46346 .52467 L F
.46219 .52554 m .46273 .52836 L .46461 .52535 L F
.871 .994 .803 r
.46503 .52277 m .46461 .52535 L .46747 .52188 L F
.844 .984 .864 r
.46503 .52277 m .46346 .52467 L .46461 .52535 L F
.475 .152 .338 r
.36112 .53531 m .36072 .53771 L .36349 .5371 L F
.785 .891 .476 r
.29445 .5345 m .29308 .53701 L .29456 .53489 L F
.941 .608 .372 r
.39696 .57301 m .39723 .57344 L .39926 .57493 L F
0 0 .252 r
.39926 .57493 m .39875 .57878 L .40096 .57618 L F
.39926 .57493 m .39952 .57719 L .39875 .57878 L F
.941 .608 .372 r
.39723 .57344 m .39952 .57719 L .39926 .57493 L F
0 0 .252 r
.39926 .57493 m .40096 .57618 L .40157 .57545 L F
.871 .84 .812 r
.39996 .57286 m .39926 .57493 L .40157 .57545 L F
0 0 0 r
.52698 .39629 m .52881 .39604 L .5304 .39414 L F
.52698 .39629 m .52894 .3964 L .52881 .39604 L F
.52698 .39629 m .5254 .39746 L .52894 .3964 L F
.42063 .47075 m .42404 .46837 L .42268 .46981 L F
.216 0 .055 r
.42635 .46739 m .42268 .46981 L .42404 .46837 L F
0 0 .512 r
.58776 .39689 m .5881 .40079 L .58919 .39869 L F
.604 .887 .99 r
.5881 .40079 m .59072 .39986 L .58919 .39869 L F
.262 0 .268 r
.2679 .56463 m .27144 .56331 L .26857 .56179 L F
.794 .988 .735 r
.50118 .45921 m .49989 .46125 L .50057 .4591 L F
.823 .815 .331 r
.49989 .46125 m .49959 .46008 L .50057 .4591 L F
.674 .821 .954 r
.30348 .54205 m .29816 .54284 L .30183 .53946 L F
.261 .49 .889 r
.30385 .54023 m .30348 .54205 L .30183 .53946 L F
.598 .698 .913 r
.29262 .66987 m .29314 .666 L .29047 .66653 L F
.29262 .66987 m .29529 .66916 L .29314 .666 L F
0 .017 .59 r
.30031 .57173 m .30056 .57084 L .29903 .56918 L F
.914 .915 .805 r
.29987 .57532 m .29806 .57443 L .30056 .57084 L F
0 0 .136 r
.29806 .57443 m .29857 .57005 L .30056 .57084 L F
.821 .513 .469 r
.29857 .57005 m .30186 .57225 L .30056 .57084 L F
.30186 .57225 m .30267 .5728 L .30056 .57084 L F
0 .017 .59 r
.29903 .56918 m .30056 .57084 L .2985 .56811 L F
.824 .706 .735 r
.4668 .50484 m .46294 .50436 L .46528 .50077 L F
.639 .606 .8 r
.46687 .50753 m .46294 .50436 L .4668 .50484 L F
.55 .386 .611 r
.27437 .55435 m .2771 .55437 L .27688 .55175 L F
.165 0 .169 r
.27437 .55435 m .27532 .55602 L .2771 .55437 L F
.27437 .55435 m .27369 .55675 L .27532 .55602 L F
.836 .998 .784 r
.47022 .51867 m .46795 .51957 L .46747 .52188 L F
.827 1 .816 r
.46795 .51957 m .46503 .52277 L .46747 .52188 L F
.927 .604 .408 r
.37471 .58497 m .37318 .58799 L .37138 .58547 L F
.37471 .58497 m .37534 .58837 L .37318 .58799 L F
.539 .587 .851 r
.37857 .58185 m .37816 .58489 L .37471 .58497 L F
.924 .831 .735 r
.29448 .54365 m .29816 .54284 L .29738 .54308 L F
.646 .602 .79 r
.30183 .53946 m .29816 .54284 L .2984 .53729 L F
.159 0 .018 r
.41079 .46878 m .40952 .46736 L .4082 .46958 L F
.41079 .46878 m .41197 .46634 L .40952 .46736 L F
.747 .425 .438 r
.3782 .4861 m .3743 .48442 L .3776 .48539 L F
.586 .848 .994 r
.63319 .37182 m .63478 .37297 L .63046 .37283 L F
.808 .905 .908 r
.63625 .36979 m .63478 .37297 L .63319 .37182 L F
.586 .848 .994 r
.63319 .37182 m .63478 .37297 L .63243 .3729 L F
0 0 .48 r
.63478 .37297 m .6354 .37363 L .63319 .37182 L F
.808 .905 .908 r
.63625 .36979 m .63319 .37182 L .63648 .36897 L F
.773 .997 .836 r
.63648 .36897 m .63319 .37182 L .6343 .36966 L F
.989 .74 .366 r
.6354 .37363 m .63442 .3701 L .63319 .37182 L F
.63442 .3701 m .6343 .36966 L .63319 .37182 L F
.586 .848 .994 r
.63319 .37182 m .63243 .3729 L .63046 .37283 L F
0 0 .48 r
.63478 .37297 m .63653 .37494 L .6354 .37363 L F
.883 .625 .543 r
.40941 .48747 m .40971 .49124 L .41192 .49067 L F
.733 .569 .669 r
.54646 .41416 m .54466 .41098 L .54425 .41265 L F
.933 .926 .778 r
.46219 .52554 m .45956 .52969 L .46273 .52836 L F
.822 .784 .817 r
.54425 .41265 m .54551 .41559 L .54646 .41416 L F
.785 .684 .138 r
.33703 .62736 m .33711 .62932 L .33677 .63243 L F
.582 .121 .124 r
.5304 .39414 m .53398 .39576 L .53333 .39336 L F
.711 .532 .645 r
.30354 .53489 m .30346 .53845 L .30859 .53839 L F
.907 .665 .562 r
.34724 .55514 m .34354 .55418 L .34407 .55131 L F
.89 .665 .59 r
.34724 .55514 m .343 .55695 L .34354 .55418 L F
.34724 .55514 m .3459 .55829 L .343 .55695 L F
0 .365 .785 r
.63192 .34275 m .63282 .34252 L .63014 .34265 L F
.63192 .34275 m .63386 .34368 L .63282 .34252 L F
.77 .447 .441 r
.36349 .5371 m .36782 .53764 L .36791 .53523 L F
.828 .928 .899 r
.49075 .49894 m .49129 .49603 L .48896 .49743 L F
.49075 .49894 m .49271 .4969 L .49129 .49603 L F
.013 0 0 r
.45206 .43735 m .44864 .44016 L .45093 .4391 L F
0 0 0 r
.4542 .43577 m .45206 .43735 L .45357 .43647 L F
.45357 .43647 m .45206 .43735 L .45093 .4391 L F
.908 .814 .743 r
.30889 .57424 m .30907 .57906 L .31082 .57588 L F
.30889 .57424 m .3065 .57814 L .30907 .57906 L F
.934 .743 .62 r
.3065 .57814 m .30824 .5818 L .30907 .57906 L F
0 0 0 r
.56856 .39344 m .57046 .39224 L .57171 .39068 L F
.381 .819 .669 r
.56668 .39433 m .57046 .39224 L .56856 .39344 L F
.986 .83 .605 r
.43251 .5305 m .4321 .5335 L .43401 .53182 L F
.678 .254 .233 r
.4321 .5335 m .43641 .53397 L .43401 .53182 L F
.832 .974 .67 r
.64738 .38376 m .64574 .38471 L .645 .38724 L F
.822 .949 .599 r
.645 .38724 m .64347 .38845 L .64464 .38978 L F
.547 .262 .435 r
.4407 .5318 m .44081 .53419 L .44389 .53394 L F
.703 .382 .431 r
.43641 .53397 m .44081 .53419 L .4407 .5318 L F
.626 .146 .094 r
.40561 .58046 m .40834 .58109 L .40597 .57928 L F
.523 .236 .42 r
.40597 .57928 m .40834 .58109 L .40843 .57865 L F
.351 .123 .421 r
.28149 .55446 m .2809 .55859 L .27854 .55874 L F
.358 .767 .982 r
.28384 .55411 m .28197 .55326 L .28149 .55446 L F
.265 .052 .392 r
.28284 .5564 m .28149 .55446 L .28273 .55593 L F
.28284 .5564 m .28273 .55593 L .28281 .55622 L F
.2826 .55635 m .28149 .55446 L .28284 .5564 L F
.28277 .55597 m .28149 .55446 L .28197 .55326 L F
.28316 .5573 m .2815 .55825 L .28149 .55446 L F
.2815 .55825 m .2809 .55859 L .28101 .55778 L F
.2815 .55825 m .28101 .55778 L .28149 .55446 L F
.28316 .5573 m .28294 .55693 L .28286 .55647 L F
.61 .632 .848 r
.28281 .55622 m .28284 .5564 L .28302 .55629 L F
.265 .052 .392 r
.28297 .55668 m .28286 .55647 L .28277 .55597 L F
.28316 .5573 m .28286 .55647 L .28297 .55668 L F
.627 .529 .724 r
.28633 .5597 m .28316 .5573 L .28302 .55629 L F
.28633 .5597 m .28351 .56014 L .28333 .5587 L F
.2832 .55733 m .28333 .5587 L .28316 .5573 L F
.28633 .5597 m .28333 .5587 L .2832 .55733 L F
.28633 .5597 m .28302 .55629 L .28429 .55677 L F
.204 .053 .442 r
.2831 .55632 m .2849 .55951 L .28429 .55677 L F
.28302 .55629 m .28311 .55645 L .2831 .55632 L F
.28311 .55645 m .2849 .55951 L .2831 .55632 L F
.28302 .55629 m .28296 .55665 L .2849 .55951 L F
.452 .4 .709 r
.28316 .5573 m .28351 .56014 L .28108 .5587 L F
.2815 .55825 m .28108 .5587 L .2809 .55859 L F
.28316 .5573 m .28108 .5587 L .2815 .55825 L F
.204 .053 .442 r
.28296 .55666 m .28253 .55923 L .28453 .55947 L F
.28296 .55665 m .28295 .55667 L .28296 .55666 L F
.28295 .55667 m .28253 .55923 L .28296 .55666 L F
.28296 .55665 m .28453 .55947 L .2849 .55951 L F
.155 .407 .851 r
.2809 .55859 m .28351 .56014 L .28272 .56186 L F
.582 .598 .834 r
.28351 .56014 m .28255 .56449 L .28272 .56186 L F
.28351 .56014 m .28532 .56453 L .28255 .56449 L F
.578 .596 .834 r
.2881 .56373 m .28532 .56453 L .28351 .56014 L F
.204 .053 .442 r
.28253 .55923 m .28212 .56168 L .28258 .56132 L F
.28329 .55996 m .28258 .56132 L .28375 .56041 L F
.28253 .55923 m .28258 .56132 L .28329 .55996 L F
.578 .596 .834 r
.2881 .56373 m .28351 .56014 L .28633 .5597 L F
.83 .796 .819 r
.28258 .56132 m .28347 .56223 L .28632 .5601 L F
.265 .052 .392 r
.28294 .55693 m .2826 .55635 L .28284 .5564 L F
.744 .538 .615 r
.27816 .56049 m .28123 .56221 L .28302 .55629 L F
.18 .458 .883 r
.28191 .56226 m .28322 .56267 L .28347 .56223 L F
.28042 .56229 m .28199 .5625 L .28191 .56226 L F
.28199 .5625 m .28322 .56267 L .28191 .56226 L F
.695 .846 .955 r
.28283 .56204 m .28205 .56212 L .28347 .56223 L F
.28205 .56212 m .28123 .56221 L .28191 .56226 L F
.28123 .56221 m .28119 .56227 L .28191 .56226 L F
.744 .538 .615 r
.28123 .56221 m .28169 .56246 L .28205 .56212 L F
.28169 .56246 m .28197 .56262 L .28199 .5625 L F
.28123 .56221 m .28205 .56212 L .28302 .55629 L F
.695 .846 .955 r
.28153 .56166 m .28042 .56229 L .28205 .56212 L F
.28229 .56188 m .28205 .56212 L .28283 .56204 L F
.28153 .56166 m .28205 .56212 L .28229 .56188 L F
.83 .796 .819 r
.28229 .56188 m .28347 .56223 L .28258 .56132 L F
.28258 .56132 m .28632 .5601 L .2849 .55951 L F
.204 .053 .442 r
.28199 .5625 m .28201 .56257 L .28361 .56059 L F
.28357 .56063 m .28361 .56059 L .28375 .56041 L F
.28199 .5625 m .28361 .56059 L .28357 .56063 L F
.514 .615 .89 r
.28153 .56166 m .28197 .56262 L .28123 .56221 L F
.28153 .56166 m .28123 .56221 L .27816 .56049 L F
.695 .846 .955 r
.28123 .56221 m .28042 .56229 L .28119 .56227 L F
.28205 .56212 m .28191 .56226 L .28347 .56223 L F
.204 .053 .442 r
.28212 .56168 m .28205 .56212 L .28375 .56041 L F
.28205 .56212 m .28199 .5625 L .28357 .56063 L F
.28205 .56212 m .28357 .56063 L .28375 .56041 L F
.28199 .5625 m .28197 .56262 L .28201 .56257 L F
.28375 .56041 m .28201 .56257 L .28391 .56056 L F
.28201 .56257 m .28197 .56262 L .28201 .56257 L F
.28201 .56257 m .28201 .56257 L .28391 .56056 L F
.18 .458 .883 r
.27895 .56232 m .28227 .56434 L .28246 .56401 L F
.28201 .56257 m .28246 .56401 L .28322 .56267 L F
.27895 .56232 m .28246 .56401 L .28201 .56257 L F
.744 .538 .615 r
.28169 .56246 m .28199 .5625 L .28205 .56212 L F
.83 .796 .819 r
.28153 .56166 m .28229 .56188 L .28258 .56132 L F
.204 .053 .442 r
.28253 .55923 m .28391 .56056 L .2849 .55951 L F
.83 .796 .819 r
.28153 .56166 m .28258 .56132 L .2849 .55951 L F
.624 .678 .88 r
.2849 .55951 m .28201 .56257 L .28153 .56166 L F
.28201 .56257 m .28197 .56262 L .28194 .56256 L F
.28201 .56257 m .28194 .56256 L .28153 .56166 L F
.18 .458 .883 r
.27895 .56232 m .28199 .56257 L .28042 .56229 L F
.28199 .56257 m .28322 .56267 L .28134 .56241 L F
.28199 .56257 m .28134 .56241 L .28042 .56229 L F
.695 .846 .955 r
.28153 .56166 m .27895 .56232 L .28042 .56229 L F
.61 .632 .848 r
.2782 .55468 m .28281 .55622 L .28197 .55326 L F
.28281 .55622 m .28302 .55629 L .28197 .55326 L F
.265 .052 .392 r
.28281 .55622 m .28273 .55593 L .28277 .55597 L F
.744 .538 .615 r
.27816 .56049 m .28288 .55641 L .28068 .55783 L F
.28288 .55641 m .28302 .55629 L .28284 .5564 L F
.28288 .55641 m .28284 .5564 L .28068 .55783 L F
.61 .632 .848 r
.2782 .55468 m .28068 .55783 L .28284 .5564 L F
.2782 .55468 m .28284 .5564 L .28281 .55622 L F
.667 .974 .837 r
.56325 .4057 m .56736 .40355 L .56568 .40306 L F
.379 .808 .634 r
.56946 .40229 m .56944 .40227 L .56736 .40355 L F
.438 .875 .889 r
.56736 .40355 m .56944 .40227 L .56568 .40306 L F
0 0 0 r
.48745 .40704 m .48927 .40605 L .49064 .40442 L F
.49064 .40442 m .49195 .40482 L .49307 .40318 L F
.49064 .40442 m .48927 .40605 L .49195 .40482 L F
.854 .986 .853 r
.64013 .36684 m .63648 .36897 L .63911 .36561 L F
.96 .928 .719 r
.64013 .36684 m .63911 .36561 L .64099 .36194 L F
.227 0 .03 r
.53245 .35919 m .52863 .36197 L .53034 .36046 L F
.933 .779 .668 r
.45658 .51851 m .45582 .52115 L .45452 .51734 L F
.068 0 0 r
.42063 .47075 m .41953 .47312 L .41737 .47419 L F
.344 0 .219 r
.42268 .46981 m .41953 .47312 L .42063 .47075 L F
.406 0 0 r
.66056 .34884 m .66351 .34941 L .66547 .34928 L F
.628 .095 0 r
.66547 .34928 m .66351 .34941 L .66628 .34983 L F
.482 .795 .999 r
.53337 .42943 m .53479 .43071 L .53062 .42997 L F
.302 0 .245 r
.53332 .42398 m .5367 .42156 L .53428 .4244 L F
.53332 .42398 m .53428 .4244 L .53137 .42066 L F
.888 .917 .837 r
.5375 .42728 m .53479 .43071 L .53337 .42943 L F
0 0 0 r
.39358 .47493 m .39041 .47636 L .39289 .4757 L F
.187 0 0 r
.39545 .47523 m .39358 .47493 L .39289 .4757 L F
.39545 .47523 m .39627 .47437 L .39358 .47493 L F
.946 .881 .739 r
.42782 .56362 m .43081 .56239 L .42931 .56126 L F
.42782 .56362 m .42876 .56613 L .43081 .56239 L F
.882 .923 .847 r
.42931 .56126 m .43081 .56239 L .43353 .55925 L F
0 0 0 r
.48458 .41019 m .48641 .40898 L .48745 .40704 L F
.48745 .40704 m .48802 .40689 L .48927 .40605 L F
.48745 .40704 m .48641 .40898 L .48802 .40689 L F
.905 .748 .677 r
.34407 .54846 m .34159 .54759 L .34243 .5448 L F
.916 .63 .486 r
.34407 .54846 m .34157 .55033 L .34159 .54759 L F
.34407 .54846 m .34407 .55131 L .34157 .55033 L F
.448 .265 .538 r
.28952 .54633 m .2921 .54765 L .28993 .54846 L F
.745 .553 .635 r
.34997 .53116 m .35273 .52831 L .34826 .52824 L F
.34997 .53116 m .35273 .53237 L .35273 .52831 L F
.351 .238 .582 r
.26429 .57195 m .26639 .57118 L .26603 .56831 L F
.351 .17 .489 r
.26429 .57195 m .26618 .57367 L .26639 .57118 L F
.26429 .57195 m .26413 .57458 L .26618 .57367 L F
.11 .6 .907 r
.3278 .6222 m .32656 .62134 L .32659 .61879 L F
.3278 .6222 m .33002 .62245 L .32656 .62134 L F
0 0 0 r
.57171 .39068 m .5727 .38851 L .57422 .38951 L F
.57171 .39068 m .5728 .39076 L .5727 .38851 L F
.57171 .39068 m .57046 .39224 L .5728 .39076 L F
.701 .589 .726 r
.34336 .66 m .34362 .66297 L .34619 .65952 L F
.877 .882 .835 r
.34619 .65952 m .34362 .66297 L .34203 .66143 L F
.857 .744 .737 r
.51917 .43689 m .52298 .43774 L .52096 .43923 L F
.815 .582 .587 r
.55654 .38364 m .55214 .38551 L .5521 .38327 L F
.55654 .38364 m .55627 .38639 L .55214 .38551 L F
.882 .923 .847 r
.42931 .56126 m .43353 .55925 L .43194 .55822 L F
.824 .763 .795 r
.43353 .55925 m .43401 .55456 L .43278 .55541 L F
.978 .865 .656 r
.43194 .55822 m .43353 .55925 L .43278 .55541 L F
.731 .436 .48 r
.39875 .57878 m .39793 .58135 L .39461 .58097 L F
0 0 0 r
.39853 .58005 m .39875 .57878 L .39952 .57719 L F
.39853 .58005 m .39793 .58135 L .39875 .57878 L F
.277 .322 .729 r
.36593 .55203 m .36782 .55448 L .36877 .55202 L F
.988 .867 .513 r
.28253 .64818 m .28369 .64899 L .28173 .65107 L F
.713 .489 .585 r
.30543 .54853 m .30045 .55131 L .30058 .54823 L F
.30543 .54853 m .3048 .55162 L .30045 .55131 L F
.394 .806 .603 r
.48458 .41019 m .48266 .41141 L .48641 .40898 L F
.265 0 0 r
.38775 .48454 m .3834 .48557 L .38523 .48453 L F
0 0 0 r
.42458 .45709 m .4265 .45633 L .42778 .45447 L F
.014 0 0 r
.42778 .45447 m .42881 .45531 L .43028 .4536 L F
.42778 .45447 m .4265 .45633 L .42881 .45531 L F
.883 .991 .79 r
.47022 .51867 m .47293 .51504 L .47043 .51615 L F
.889 .99 .766 r
.47022 .51867 m .47043 .51615 L .46795 .51957 L F
.327 0 0 r
.59007 .35059 m .59301 .3512 L .59418 .34992 L F
0 0 0 r
.59418 .34992 m .59541 .34992 L .59654 .34867 L F
.59418 .34992 m .59301 .3512 L .59541 .34992 L F
.921 .976 .744 r
.36736 .55627 m .36554 .55808 L .36782 .55448 L F
.85 .512 .414 r
.30859 .53839 m .30839 .54067 L .3123 .54142 L F
.869 .69 .659 r
.30839 .54067 m .30992 .54444 L .3123 .54142 L F
.599 .576 .799 r
.39974 .58633 m .40498 .58723 L .40162 .58297 L F
.42 .721 .987 r
.40481 .58826 m .40565 .58729 L .40498 .58723 L F
.599 .576 .799 r
.40498 .58723 m .40585 .58738 L .40578 .5873 L F
.794 .858 .898 r
.40625 .58639 m .40646 .58802 L .41036 .58527 L F
.599 .576 .799 r
.40498 .58723 m .40565 .58729 L .40162 .58297 L F
.40565 .58729 m .4057 .58722 L .40162 .58297 L F
.74 .235 0 r
.40162 .58297 m .4057 .58722 L .40503 .58672 L F
.794 .858 .898 r
.40503 .58672 m .40565 .58729 L .4057 .58722 L F
.74 .235 0 r
.4057 .58722 m .40585 .58738 L .40503 .58672 L F
.794 .858 .898 r
.40503 .58672 m .4057 .58722 L .40625 .58639 L F
.40565 .58729 m .40646 .58802 L .40625 .58639 L F
.599 .576 .799 r
.40565 .58729 m .40578 .5873 L .4057 .58722 L F
.42 .721 .987 r
.40481 .58826 m .40646 .58802 L .40565 .58729 L F
.40498 .58723 m .40565 .58729 L .40506 .58675 L F
.584 .709 .929 r
.39974 .58633 m .40481 .58826 L .40498 .58723 L F
.42 .721 .987 r
.40481 .58826 m .40506 .58675 L .40503 .58672 L F
.584 .709 .929 r
.40498 .58723 m .40481 .58826 L .40585 .58738 L F
.42 .721 .987 r
.40481 .58826 m .40503 .58672 L .40585 .58738 L F
.265 .116 .484 r
.52288 .36002 m .52462 .35907 L .52508 .35617 L F
.896 .565 .075 r
.52576 .3624 m .52462 .35907 L .52288 .36002 L F
.772 .61 .679 r
.39479 .54516 m .39579 .5477 L .39759 .54469 L F
.706 .903 .541 r
.64738 .38376 m .64993 .38015 L .64864 .38137 L F
.74 .963 .68 r
.64864 .38137 m .64574 .38471 L .64738 .38376 L F
.266 0 .222 r
.46013 .44319 m .4632 .44065 L .4626 .4423 L F
.026 0 0 r
.4626 .4423 m .45867 .44533 L .46013 .44319 L F
.186 0 .262 r
.44112 .45931 m .43995 .458 L .44175 .45703 L F
.44112 .45931 m .43905 .46063 L .43995 .458 L F
.816 .786 .825 r
.3374 .61911 m .34062 .61628 L .336 .61521 L F
.802 .82 .865 r
.45198 .53744 m .45629 .53644 L .45357 .53584 L F
.868 .91 .858 r
.45357 .53584 m .45629 .53644 L .45631 .53326 L F
0 0 0 r
.53381 .39663 m .53337 .39865 L .5312 .39989 L F
.885 .665 .6 r
.52334 .38526 m .52506 .38638 L .52868 .38689 L F
.52318 .38521 m .52339 .38534 L .52334 .38526 L F
.52339 .38534 m .52506 .38638 L .52334 .38526 L F
.794 .713 .775 r
.52625 .38576 m .52397 .38544 L .52305 .38465 L F
.578 .831 .993 r
.52474 .38506 m .52351 .38518 L .52455 .38552 L F
.52625 .38576 m .52455 .38552 L .52868 .38689 L F
.52474 .38506 m .52455 .38552 L .52625 .38576 L F
.794 .713 .775 r
.52806 .38482 m .52625 .38576 L .52305 .38465 L F
.578 .831 .993 r
.52655 .38619 m .52334 .38526 L .52868 .38689 L F
.52351 .38518 m .52335 .38526 L .52655 .38619 L F
.52335 .38526 m .52334 .38526 L .52655 .38619 L F
.876 .682 .637 r
.52305 .38465 m .52397 .38544 L .52318 .38521 L F
.52397 .38544 m .52506 .38638 L .52318 .38521 L F
.794 .713 .775 r
.52625 .38576 m .52506 .38638 L .52397 .38544 L F
.818 .848 .871 r
.52868 .38689 m .52506 .38638 L .52625 .38576 L F
.52868 .38689 m .52625 .38576 L .52806 .38482 L F
0 0 .474 r
.52806 .38482 m .52868 .38689 L .5283 .38471 L F
.578 .831 .993 r
.5283 .38471 m .52474 .38506 L .52868 .38689 L F
.52351 .38518 m .52318 .38521 L .52334 .38526 L F
.508 .524 .808 r
.52287 .3855 m .52448 .38893 L .52195 .3896 L F
.52304 .3847 m .52325 .38531 L .52287 .3855 L F
.52325 .38531 m .52448 .38893 L .52287 .3855 L F
.52305 .38465 m .52312 .38484 L .52304 .3847 L F
.52312 .38484 m .52448 .38893 L .52304 .3847 L F
.888 .917 .837 r
.5375 .42728 m .53337 .42943 L .536 .42625 L F
.476 .8 1 r
.5389 .42551 m .5375 .42728 L .536 .42625 L F
.5389 .42551 m .54035 .42672 L .5375 .42728 L F
.032 0 .251 r
.55135 .38023 m .5534 .3793 L .55446 .37534 L F
0 0 0 r
.55135 .38023 m .55013 .38119 L .5534 .3793 L F
.573 .35 .539 r
.36575 .54363 m .36552 .5411 L .36435 .54384 L F
.36575 .54363 m .3694 .54157 L .36552 .5411 L F
.36575 .54363 m .36928 .54435 L .3694 .54157 L F
.597 .309 .45 r
.42969 .53003 m .43251 .5305 L .42992 .52804 L F
.934 .755 .637 r
.31265 .67414 m .31489 .67617 L .31349 .67254 L F
.41 .49 .832 r
.31349 .67254 m .31489 .67617 L .31696 .67578 L F
.826 .615 .617 r
.43245 .51439 m .42981 .51146 L .42964 .51468 L F
.727 .501 .584 r
.43183 .51729 m .43245 .51439 L .42964 .51468 L F
.173 .709 .754 r
.64993 .38015 m .65024 .37992 L .64864 .38137 L F
.64993 .38015 m .65288 .37962 L .65024 .37992 L F
.93 .701 .572 r
.371 .56798 m .37277 .5715 L .37318 .5688 L F
.77 .615 .687 r
.36115 .55462 m .36593 .55203 L .36151 .55162 L F
.677 .708 .871 r
.43652 .52629 m .43959 .52509 L .43529 .52431 L F
.868 .816 .795 r
.51327 .47775 m .51197 .474 L .5099 .47715 L F
.798 .545 .554 r
.50908 .4798 m .51327 .47775 L .5099 .47715 L F
.50908 .4798 m .51286 .47972 L .51327 .47775 L F
.792 .782 .844 r
.51448 .47276 m .51327 .47775 L .51644 .47455 L F
.51448 .47276 m .51197 .474 L .51327 .47775 L F
.34 .568 .923 r
.31696 .67578 m .31976 .67891 L .32137 .67884 L F
.899 .842 .779 r
.54074 .41345 m .53874 .41713 L .53756 .41505 L F
.54074 .41345 m .53756 .41505 L .54001 .41468 L F
.161 .387 .834 r
.54074 .41345 m .54159 .41703 L .53874 .41713 L F
.877 .869 .826 r
.54001 .41468 m .54425 .41265 L .54074 .41345 L F
.925 .536 .181 r
.37178 .54654 m .37285 .54525 L .36928 .54435 L F
.37178 .54654 m .37349 .54766 L .37285 .54525 L F
.805 .438 0 r
.60667 .37815 m .60777 .37991 L .60676 .37727 L F
.223 0 .318 r
.28818 .63867 m .28612 .63958 L .28544 .64235 L F
.085 0 .296 r
.2713 .58298 m .2697 .58224 L .27227 .58149 L F
.2713 .58298 m .26936 .58492 L .2697 .58224 L F
.634 .576 .772 r
.30177 .63613 m .3063 .63606 L .30154 .63539 L F
.30177 .63613 m .30665 .638 L .3063 .63606 L F
.622 .084 0 r
.3042 .63849 m .30177 .63613 L .30123 .64115 L F
.3042 .63849 m .30665 .638 L .30177 .63613 L F
.728 .313 .26 r
.61155 .39626 m .61044 .39874 L .61087 .39674 L F
.692 .948 .674 r
.61584 .39446 m .61438 .39601 L .61443 .3967 L F
.097 .603 .894 r
.61439 .3962 m .61443 .3967 L .61446 .3962 L F
.61155 .39626 m .61443 .3967 L .61439 .3962 L F
.11 0 .001 r
.61397 .39696 m .61155 .39626 L .61443 .3967 L F
.61296 .3975 m .61204 .39669 L .61397 .39696 L F
.61204 .39669 m .61155 .39626 L .61397 .39696 L F
.715 .776 .9 r
.61584 .39446 m .61446 .3962 L .61441 .39616 L F
.61584 .39446 m .61441 .39616 L .61184 .39416 L F
.692 .948 .674 r
.61438 .39601 m .61296 .3975 L .61354 .39719 L F
.61421 .39639 m .61354 .39719 L .61397 .39696 L F
.61438 .39601 m .61354 .39719 L .61421 .39639 L F
.61439 .39619 m .61397 .39696 L .61443 .3967 L F
.61438 .39601 m .61397 .39696 L .61439 .39619 L F
.11 0 .001 r
.61296 .3975 m .61044 .39874 L .61155 .39626 L F
.097 .603 .894 r
.61155 .39626 m .61446 .3962 L .61087 .39674 L F
.372 .664 .971 r
.61179 .39467 m .61441 .39616 L .61159 .39663 L F
.61258 .39474 m .61441 .39616 L .61179 .39467 L F
.61441 .39616 m .61446 .3962 L .61438 .39621 L F
.61441 .39616 m .61438 .39621 L .61159 .39663 L F
.61184 .39416 m .61258 .39474 L .61179 .39467 L F
.762 .698 .791 r
.61184 .39416 m .61296 .3975 L .61584 .39446 L F
.709 .669 .809 r
.61616 .39401 m .61296 .3975 L .61194 .39445 L F
.61533 .39404 m .61194 .39445 L .61184 .39416 L F
.61616 .39401 m .61194 .39445 L .61533 .39404 L F
.606 .85 .99 r
.61952 .39337 m .61865 .39363 L .61467 .39314 L F
.61865 .39363 m .61584 .39446 L .61545 .39402 L F
.61865 .39363 m .61545 .39402 L .61467 .39314 L F
.751 .985 .756 r
.61135 .3979 m .61296 .3975 L .61616 .39401 L F
.61135 .3979 m .61499 .39496 L .6146 .39661 L F
.61499 .39496 m .61616 .39401 L .61556 .39501 L F
.692 .948 .674 r
.61584 .39446 m .61443 .3967 L .61709 .39575 L F
.419 .865 .886 r
.61709 .39575 m .61446 .3962 L .61584 .39446 L F
.751 .985 .756 r
.61499 .39496 m .61556 .39501 L .6146 .39661 L F
.372 .664 .971 r
.61094 .39654 m .61159 .39663 L .61087 .39674 L F
.61184 .39416 m .61159 .39663 L .61094 .39654 L F
0 0 .143 r
.59606 .38933 m .59536 .39201 L .59527 .38984 L F
.714 .781 .905 r
.52799 .43132 m .52389 .43202 L .5268 .43273 L F
.52799 .43132 m .51976 .43053 L .52389 .43202 L F
0 0 0 r
.52885 .43139 m .52799 .43132 L .5268 .43273 L F
.52885 .43139 m .53062 .42997 L .52799 .43132 L F
.555 .847 .522 r
.49819 .4183 m .49979 .41673 L .50127 .415 L F
.925 .712 .595 r
.34004 .53843 m .33662 .53739 L .33797 .53391 L F
.916 .66 .535 r
.33999 .54097 m .33662 .53739 L .34004 .53843 L F
.438 .843 .973 r
.60691 .36233 m .60969 .36166 L .61108 .36228 L F
.61108 .36228 m .60969 .36166 L .60691 .36233 L F
.527 .887 .978 r
.61108 .36228 m .61266 .36062 L .61444 .36192 L F
.61108 .36228 m .60969 .36166 L .61266 .36062 L F
.61108 .36228 m .61266 .36062 L .61444 .36192 L F
.61108 .36228 m .60969 .36166 L .61266 .36062 L F
.816 .786 .825 r
.3374 .61911 m .336 .61521 L .33561 .61848 L F
.869 .678 .641 r
.34652 .63491 m .34793 .63292 L .34393 .63181 L F
.442 .714 .981 r
.50612 .4568 m .50491 .45765 L .50318 .45579 L F
.749 .569 .652 r
.50706 .45283 m .5079 .45663 L .50318 .45579 L F
.578 .883 .992 r
.50909 .45767 m .50701 .45698 L .5079 .45663 L F
.749 .569 .652 r
.5079 .45663 m .50792 .4567 L .50766 .45665 L F
.5079 .45663 m .50766 .45665 L .50318 .45579 L F
.578 .883 .992 r
.50989 .45641 m .5079 .45663 L .51038 .45565 L F
.50909 .45767 m .5079 .45663 L .50989 .45641 L F
.533 .43 .683 r
.51038 .45565 m .50962 .45595 L .50706 .45283 L F
.50977 .45614 m .50792 .4567 L .50706 .45283 L F
.749 .569 .652 r
.50766 .45665 m .50612 .4568 L .50318 .45579 L F
.578 .883 .992 r
.50701 .45698 m .50642 .45678 L .5079 .45663 L F
.749 .569 .652 r
.50792 .4567 m .50642 .45678 L .50766 .45665 L F
.50642 .45678 m .50612 .4568 L .50766 .45665 L F
.578 .883 .992 r
.5079 .45663 m .50606 .45666 L .51038 .45565 L F
.50642 .45678 m .50606 .45666 L .5079 .45663 L F
.533 .43 .683 r
.51038 .45565 m .50977 .45614 L .50962 .45595 L F
.50977 .45614 m .50809 .45748 L .50792 .4567 L F
.518 .861 .993 r
.50491 .45765 m .50498 .4576 L .50909 .45767 L F
.50498 .4576 m .50612 .4568 L .50687 .45702 L F
.50498 .4576 m .50687 .45702 L .50909 .45767 L F
.50612 .4568 m .50623 .45672 L .50642 .45678 L F
.50612 .4568 m .50642 .45678 L .50909 .45767 L F
.749 .569 .652 r
.50792 .4567 m .50809 .45748 L .50612 .4568 L F
.442 .714 .981 r
.50809 .45748 m .50491 .45765 L .50612 .4568 L F
.518 .861 .993 r
.50491 .45765 m .50606 .45666 L .50623 .45672 L F
.662 .917 .607 r
.50909 .45767 m .51038 .45565 L .51208 .45431 L F
0 0 0 r
.56301 .37247 m .56612 .37178 L .56762 .37095 L F
.695 .948 .669 r
.56762 .37095 m .56884 .36885 L .56985 .36931 L F
.56762 .37095 m .56612 .37178 L .56884 .36885 L F
.502 .294 .53 r
.5227 .39258 m .5194 .39637 L .51977 .3937 L F
.012 0 0 r
.38674 .47833 m .38855 .47816 L .39041 .47636 L F
.148 0 0 r
.38855 .47816 m .39289 .4757 L .39041 .47636 L F
.877 .882 .835 r
.34619 .65952 m .34203 .66143 L .34336 .66 L F
.277 .256 .654 r
.52305 .38465 m .52051 .38697 L .52079 .38281 L F
.508 .524 .808 r
.52274 .38494 m .52195 .3896 L .52051 .38697 L F
.52288 .38543 m .52195 .3896 L .52274 .38494 L F
.777 .888 .473 r
.52448 .38893 m .5227 .39258 L .52195 .3896 L F
.508 .524 .808 r
.52305 .38465 m .52288 .38543 L .52274 .38494 L F
.811 .697 .739 r
.52088 .38821 m .52448 .38893 L .52305 .38465 L F
.778 .92 .543 r
.52155 .38617 m .52088 .38821 L .52305 .38465 L F
.924 .696 .574 r
.5211 .38749 m .52448 .38893 L .52088 .38821 L F
.5211 .38749 m .52287 .39158 L .52408 .38958 L F
.52381 .38864 m .52408 .38958 L .52448 .38893 L F
.5211 .38749 m .52408 .38958 L .52381 .38864 L F
.826 .71 .736 r
.53874 .41713 m .53488 .41702 L .53756 .41505 L F
.53874 .41713 m .5367 .42156 L .53488 .41702 L F
.164 0 0 r
.53874 .41713 m .54004 .41779 L .53863 .41969 L F
.53874 .41713 m .54159 .41703 L .54004 .41779 L F
.32 .136 .467 r
.53863 .41969 m .5367 .42156 L .53874 .41713 L F
.766 .777 .862 r
.30384 .58137 m .30499 .5847 L .30824 .5818 L F
.863 .944 .869 r
.5053 .48346 m .50632 .48392 L .50663 .48111 L F
.754 .804 .893 r
.50632 .48392 m .50908 .4798 L .50663 .48111 L F
.50632 .48392 m .51096 .4818 L .50908 .4798 L F
.504 .25 .462 r
.26094 .59216 m .2633 .59258 L .2645 .58867 L F
.385 .137 .41 r
.2645 .58867 m .26604 .59125 L .26547 .58932 L F
.2645 .58867 m .2633 .59258 L .26604 .59125 L F
.094 0 0 r
.38449 .56902 m .39141 .56915 L .39142 .57027 L F
.695 .615 .762 r
.38231 .58521 m .38632 .58668 L .38467 .58261 L F
.677 .174 .041 r
.53358 .40967 m .53719 .4103 L .53565 .4116 L F
.701 .919 .967 r
.53772 .40798 m .53719 .4103 L .53975 .40907 L F
.838 .947 .589 r
.53565 .4116 m .53719 .4103 L .53772 .40798 L F
.788 .686 .751 r
.46294 .50436 m .46464 .50922 L .46034 .50798 L F
.639 .606 .8 r
.46687 .50753 m .46464 .50922 L .46294 .50436 L F
.211 0 .18 r
.4626 .4423 m .4632 .44065 L .46564 .43949 L F
.844 .817 .334 r
.57941 .38789 m .57927 .39052 L .58011 .38632 L F
0 0 0 r
.57936 .39034 m .57927 .39052 L .57941 .38789 L F
.57936 .39034 m .57839 .39279 L .57927 .39052 L F
.468 .272 .53 r
.56388 .33968 m .56663 .34153 L .56691 .33882 L F
.889 .482 .231 r
.39602 .48716 m .39429 .48705 L .3932 .48413 L F
0 0 0 r
.39918 .48626 m .39724 .48682 L .39602 .48716 L F
.527 .143 .255 r
.39724 .48682 m .39429 .48705 L .39602 .48716 L F
.727 .84 .934 r
.33677 .63243 m .33561 .63423 L .3344 .63106 L F
.945 .588 .206 r
.33677 .63243 m .33866 .63563 L .33561 .63423 L F
.708 .531 .647 r
.33561 .63423 m .33866 .63563 L .33606 .63787 L F
.804 .623 .656 r
.34446 .52808 m .34572 .53089 L .34826 .52824 L F
.742 .522 .596 r
.34572 .53089 m .34997 .53116 L .34826 .52824 L F
0 0 .453 r
.57609 .36246 m .57597 .36344 L .57519 .35976 L F
.021 .091 .597 r
.57831 .36482 m .57597 .36344 L .57609 .36246 L F
.57831 .36482 m .57684 .36723 L .57597 .36344 L F
.705 .979 .789 r
.30599 .63123 m .3088 .62941 L .30575 .63018 L F
.8 .995 .77 r
.30575 .63018 m .3088 .62941 L .30953 .62756 L F
.971 .815 .63 r
.4518 .52066 m .45276 .52456 L .45104 .52334 L F
.947 .896 .744 r
.45276 .52456 m .44922 .52679 L .45104 .52334 L F
.45276 .52456 m .45099 .5283 L .44922 .52679 L F
.79 .735 .802 r
.45582 .52115 m .45276 .52456 L .4518 .52066 L F
.66 .907 .98 r
.4249 .52618 m .42728 .52351 L .42448 .52413 L F
.4249 .52618 m .42874 .52461 L .42852 .52444 L F
.42616 .52477 m .42852 .52444 L .42728 .52351 L F
.745 .463 .504 r
.42448 .52413 m .42478 .52496 L .42125 .52546 L F
.66 .907 .98 r
.4249 .52618 m .42527 .526 L .4252 .52585 L F
0 0 .364 r
.4249 .52618 m .42525 .52624 L .42448 .52413 L F
.4249 .52618 m .42525 .52624 L .42448 .52413 L F
.745 .463 .504 r
.42478 .52496 m .42525 .52624 L .42125 .52546 L F
.42448 .52413 m .41979 .52606 L .42302 .522 L F
.715 .376 0 r
.4243 .52405 m .42525 .52624 L .42478 .52496 L F
.42436 .52408 m .42478 .52496 L .42448 .52413 L F
.4243 .52405 m .42478 .52496 L .42436 .52408 L F
.66 .907 .98 r
.4252 .52585 m .42852 .52444 L .42616 .52477 L F
.42527 .526 m .42852 .52444 L .4252 .52585 L F
.961 .648 .242 r
.4249 .52618 m .42557 .53073 L .42429 .52921 L F
.4249 .52618 m .42557 .53073 L .42429 .52921 L F
.4249 .52618 m .42429 .52921 L .42525 .52624 L F
.4249 .52618 m .42429 .52921 L .42525 .52624 L F
.745 .463 .504 r
.42125 .52546 m .42525 .52624 L .41979 .52606 L F
.516 .594 .87 r
.26497 .58144 m .2671 .58587 L .26936 .58492 L F
.236 0 .263 r
.2671 .58587 m .26547 .58932 L .26936 .58492 L F
.2671 .58587 m .26547 .58932 L .26936 .58492 L F
0 .551 .743 r
.31773 .61793 m .32058 .61828 L .32019 .61816 L F
.838 .601 .581 r
.3426 .54156 m .33975 .54406 L .33999 .54097 L F
.3426 .54156 m .34243 .5448 L .33975 .54406 L F
.293 0 .194 r
.279 .54806 m .28137 .54744 L .28281 .54437 L F
.344 0 .029 r
.28137 .54744 m .28572 .54528 L .28281 .54437 L F
.777 .633 .701 r
.33244 .53239 m .33377 .53111 L .33521 .53082 L F
.921 .544 .279 r
.33655 .53054 m .33521 .53082 L .33466 .528 L F
0 0 .343 r
.33466 .528 m .33521 .53082 L .33572 .52925 L F
.777 .633 .701 r
.33377 .53111 m .33572 .52925 L .33521 .53082 L F
.921 .544 .279 r
.33682 .53091 m .33521 .53082 L .33655 .53054 L F
.821 .703 .734 r
.33797 .53391 m .33521 .53082 L .33682 .53091 L F
.49 .813 1 r
.32556 .61463 m .32613 .61575 L .32459 .61482 L F
.783 .668 .737 r
.31418 .54794 m .31071 .55234 L .31596 .55175 L F
.776 .539 .576 r
.31134 .55412 m .31596 .55175 L .31071 .55234 L F
.31134 .55412 m .31572 .5547 L .31596 .55175 L F
.419 .862 .793 r
.44665 .54163 m .44432 .5423 L .44227 .54323 L F
.629 .962 .86 r
.44776 .53997 m .44665 .54163 L .44929 .541 L F
.44776 .53997 m .44432 .5423 L .44665 .54163 L F
.258 0 .012 r
.40518 .47177 m .40322 .47127 L .40251 .47242 L F
.40518 .47177 m .40585 .47064 L .40322 .47127 L F
.3 0 .241 r
.42332 .45923 m .4265 .45633 L .42458 .45709 L F
.042 0 0 r
.42101 .46031 m .42332 .45923 L .42458 .45709 L F
.207 0 0 r
.30341 .62292 m .29934 .62513 L .3017 .62504 L F
0 0 0 r
.3048 .62129 m .30341 .62292 L .3017 .62504 L F
.049 0 0 r
.30629 .61975 m .30341 .62292 L .3048 .62129 L F
0 0 0 r
.53337 .39865 m .52995 .40142 L .5312 .39989 L F
1 .802 .477 r
.51208 .45431 m .51038 .45565 L .51071 .4526 L F
.006 0 .356 r
.2771 .55437 m .27906 .55021 L .27688 .55175 L F
.856 .974 .865 r
.47303 .5124 m .47293 .51504 L .4758 .51202 L F
.899 .985 .783 r
.47043 .51615 m .47293 .51504 L .47303 .5124 L F
0 0 .288 r
.55163 .41188 m .55147 .41402 L .5524 .41383 L F
0 0 0 r
.5524 .41383 m .55147 .41402 L .55065 .41484 L F
.798 .542 .551 r
.43207 .55418 m .43357 .55153 L .43296 .55033 L F
.43207 .55418 m .43401 .55456 L .43357 .55153 L F
.575 .845 .996 r
.29277 .56703 m .29124 .56859 L .28934 .56741 L F
.675 .402 .5 r
.29277 .56703 m .28934 .56741 L .29124 .56859 L F
.493 .891 .742 r
.50593 .3942 m .50417 .39502 L .50813 .39274 L F
.975 .919 .608 r
.35086 .65533 m .35206 .65285 L .35157 .65063 L F
.81 .582 .593 r
.30992 .54444 m .31418 .54794 L .31448 .54505 L F
.632 .243 .289 r
.33892 .66821 m .34028 .66537 L .33642 .6659 L F
0 0 0 r
.34162 .66479 m .34028 .66537 L .33892 .66821 L F
.84 .769 .784 r
.30058 .54823 m .29778 .55156 L .29646 .54822 L F
.617 .424 .598 r
.30058 .54823 m .30045 .55131 L .29778 .55156 L F
.022 .04 .538 r
.57093 .35816 m .57069 .35448 L .57101 .35645 L F
.522 0 0 r
.57329 .35826 m .57329 .35844 L .57519 .35976 L F
.57101 .35645 m .57329 .35844 L .57329 .35826 L F
0 .048 .612 r
.57265 .3564 m .57329 .35844 L .57148 .35593 L F
0 .209 .726 r
.57148 .35593 m .57329 .35844 L .57101 .35645 L F
.448 .729 .986 r
.57093 .35816 m .57329 .35844 L .57265 .3564 L F
.888 .609 .095 r
.57265 .3564 m .57329 .35862 L .57329 .35844 L F
.402 .239 .543 r
.57133 .36178 m .57398 .36101 L .57329 .35844 L F
.888 .609 .095 r
.57329 .35862 m .57398 .36101 L .57329 .35844 L F
.736 .681 .798 r
.38091 .58128 m .38231 .58521 L .38467 .58261 L F
.916 .739 .647 r
.36246 .56426 m .36412 .56808 L .36519 .56576 L F
.521 .433 .697 r
.36538 .56291 m .36519 .56576 L .36753 .56467 L F
.901 .765 .702 r
.36246 .56426 m .36519 .56576 L .36538 .56291 L F
.886 .604 .504 r
.36481 .5669 m .36519 .56576 L .36412 .56808 L F
.36481 .5669 m .36753 .56467 L .36519 .56576 L F
.93 .948 .78 r
.51081 .44698 m .51165 .44296 L .51283 .4437 L F
.672 .864 .972 r
.51324 .44115 m .51283 .4437 L .51165 .44296 L F
.51324 .44115 m .51543 .44245 L .51283 .4437 L F
.753 .99 .887 r
.45099 .5283 m .4475 .53083 L .4482 .52901 L F
.784 .982 .718 r
.4475 .53083 m .445 .53257 L .4482 .52901 L F
.131 .255 .725 r
.28298 .6592 m .28533 .66145 L .28512 .65872 L F
.504 .548 .834 r
.26151 .59411 m .2633 .59258 L .26094 .59216 L F
.26151 .59411 m .26401 .59382 L .2633 .59258 L F
.609 .506 .711 r
.26151 .59411 m .26408 .59657 L .26401 .59382 L F
.26151 .59411 m .26259 .59876 L .26408 .59657 L F
.753 .971 .928 r
.65496 .37806 m .65945 .3765 L .65846 .37539 L F
.833 .93 .895 r
.65945 .3765 m .66149 .37209 L .65846 .37539 L F
.65945 .3765 m .6627 .37352 L .66149 .37209 L F
.498 .837 .556 r
.31435 .64264 m .31212 .6446 L .31355 .64495 L F
.486 .32 .581 r
.31435 .64264 m .31708 .64206 L .31666 .63878 L F
.244 0 0 r
.31495 .64335 m .31435 .64264 L .31355 .64495 L F
.31495 .64335 m .31708 .64206 L .31435 .64264 L F
.222 .576 .942 r
.29729 .66927 m .30143 .67238 L .30208 .67183 L F
.403 .645 .955 r
.30143 .67238 m .30326 .67311 L .30208 .67183 L F
.825 .679 .701 r
.42484 .55208 m .42075 .55426 L .42338 .55142 L F
.42484 .55208 m .42439 .55478 L .42075 .55426 L F
.308 .033 .323 r
.49599 .42199 m .49385 .42073 L .49672 .41973 L F
.49599 .42199 m .49349 .42301 L .49385 .42073 L F
.654 .246 .258 r
.581 .3703 m .58035 .37245 L .57671 .37181 L F
0 0 0 r
.5824 .37042 m .581 .3703 L .58269 .37039 L F
.5824 .37042 m .58035 .37245 L .581 .3703 L F
.845 .772 .78 r
.42711 .53433 m .42315 .53418 L .42557 .53073 L F
.856 .708 .697 r
.42711 .53433 m .42507 .5382 L .42315 .53418 L F
.779 .745 .822 r
.42969 .53003 m .42711 .53433 L .42557 .53073 L F
0 0 0 r
.308 .61823 m .30629 .61975 L .3048 .62129 L F
.33785 .67572 m .33862 .67317 L .33969 .67187 L F
.851 .407 .158 r
.64698 .34945 m .64583 .35091 L .64549 .34931 L F
.941 .573 .25 r
.64698 .34945 m .64763 .3525 L .64583 .35091 L F
.764 .995 .806 r
.50417 .39502 m .50276 .39693 L .50375 .39464 L F
.666 .926 .973 r
.50276 .39693 m .50127 .39602 L .50375 .39464 L F
.782 .809 .874 r
.51096 .4818 m .51286 .47972 L .50908 .4798 L F
.786 .695 .764 r
.60672 .34345 m .6022 .34359 L .60524 .34294 L F
.60672 .34345 m .60408 .34649 L .6022 .34359 L F
.384 .836 .921 r
.60524 .34294 m .60939 .34257 L .60672 .34345 L F
.892 .945 .838 r
.6246 .39549 m .62571 .39719 L .62846 .39347 L F
.996 .853 .521 r
.62405 .39807 m .62571 .39719 L .6246 .39549 L F
.967 .705 .486 r
.57424 .38672 m .5727 .38851 L .56988 .38643 L F
.57424 .38672 m .57422 .38951 L .5727 .38851 L F
.351 .196 .527 r
.2852 .54163 m .28754 .54078 L .28818 .53804 L F
.376 .255 .586 r
.2852 .54163 m .28761 .54375 L .28754 .54078 L F
.866 .994 .809 r
.54807 .43032 m .55111 .42682 L .54818 .42803 L F
.845 .939 .886 r
.55111 .42682 m .5529 .42256 L .55141 .42408 L F
.55111 .42682 m .55426 .4239 L .5529 .42256 L F
.865 .995 .809 r
.54818 .42803 m .55111 .42682 L .55141 .42408 L F
.812 .711 .753 r
.36782 .53764 m .36552 .5411 L .3694 .54157 L F
0 0 .526 r
.58811 .39458 m .58776 .39689 L .58919 .39869 L F
.64 .547 .733 r
.31797 .61085 m .32048 .60871 L .31849 .60983 L F
.935 .558 .234 r
.57329 .35844 m .57609 .36246 L .57519 .35976 L F
.848 .683 .676 r
.62395 .38498 m .62765 .38584 L .62597 .38873 L F
.71 .379 .414 r
.30385 .54023 m .30859 .53839 L .30346 .53845 L F
.30385 .54023 m .30839 .54067 L .30859 .53839 L F
.158 .455 .883 r
.30326 .67311 m .30452 .67194 L .30208 .67183 L F
.30326 .67311 m .30647 .67484 L .30452 .67194 L F
.587 .118 0 r
.58725 .34712 m .58936 .34988 L .59007 .35059 L F
0 .488 .811 r
.58936 .34988 m .59301 .3512 L .59007 .35059 L F
.783 .651 .717 r
.42964 .51468 m .42575 .51105 L .42714 .51481 L F
.42964 .51468 m .42981 .51146 L .42575 .51105 L F
.749 .6 .692 r
.42714 .51481 m .42699 .51774 L .42964 .51468 L F
.604 .392 .566 r
.42699 .51774 m .42984 .51735 L .42964 .51468 L F
.727 .501 .584 r
.43183 .51729 m .42964 .51468 L .42984 .51735 L F
0 0 .244 r
.5869 .37991 m .58787 .38033 L .58784 .37766 L F
.5869 .37991 m .58707 .38262 L .58787 .38033 L F
.371 .775 .984 r
.41808 .57185 m .4168 .5709 L .41453 .57158 L F
.591 .276 .404 r
.41808 .57185 m .4212 .57428 L .4178 .57402 L F
.987 .721 .359 r
.41808 .57185 m .4178 .57402 L .4168 .5709 L F
0 0 .272 r
.33637 .65956 m .33468 .65936 L .33741 .65892 L F
.33637 .65956 m .33434 .66244 L .33468 .65936 L F
0 0 0 r
.51425 .40051 m .51276 .40279 L .51161 .40291 L F
.51622 .39897 m .51276 .40279 L .51425 .40051 L F
.91 .886 .796 r
.51224 .40146 m .51276 .40279 L .51622 .39897 L F
.157 .31 .769 r
.51382 .40267 m .51276 .40279 L .51224 .40146 L F
.51557 .40401 m .51276 .40279 L .51382 .40267 L F
0 0 0 r
.51161 .40291 m .51276 .40279 L .51074 .40371 L F
.762 .254 0 r
.3662 .57769 m .3618 .57408 L .36296 .57489 L F
.92 .606 .132 r
.40799 .48372 m .40837 .48618 L .40941 .48747 L F
.995 .796 .428 r
.33272 .52117 m .33237 .52438 L .3313 .5228 L F
.62 .895 .585 r
.33272 .52117 m .334 .51938 L .33599 .5176 L F
.801 .732 .788 r
.3313 .5228 m .334 .51938 L .33272 .52117 L F
.388 .803 .976 r
.60939 .34257 m .61247 .34208 L .61353 .34286 L F
.7 .981 .896 r
.61353 .34286 m .61495 .3406 L .61529 .34161 L F
.665 .943 .962 r
.61353 .34286 m .61247 .34208 L .61495 .3406 L F
0 0 .243 r
.58259 .34906 m .5817 .35325 L .5831 .35107 L F
0 0 .13 r
.5817 .35325 m .58279 .35351 L .5831 .35107 L F
.5817 .35325 m .58124 .35556 L .58279 .35351 L F
.93 .886 .768 r
.35336 .64873 m .35324 .64564 L .35175 .64869 L F
0 .01 .519 r
.4212 .55748 m .42439 .55478 L .42089 .55762 L F
.4212 .55748 m .42075 .55426 L .42439 .55478 L F
.683 .663 .824 r
.6022 .34359 m .60408 .34649 L .59914 .34524 L F
.753 .99 .887 r
.45099 .5283 m .4482 .52901 L .44922 .52679 L F
.939 .866 .442 r
.54751 .43211 m .54807 .43032 L .54768 .4293 L F
.866 .994 .809 r
.54807 .43032 m .54818 .42803 L .54768 .4293 L F
0 .554 .788 r
.638 .33653 m .642 .33698 L .64384 .33768 L F
.217 .554 .933 r
.64612 .3352 m .64818 .33821 L .64384 .33768 L F
.794 .725 .787 r
.45582 .52115 m .4518 .52066 L .45452 .51734 L F
.895 .985 .797 r
.54385 .43769 m .54647 .43436 L .5439 .43522 L F
.916 .973 .782 r
.5439 .43522 m .54647 .43436 L .54751 .43211 L F
.46 .225 .471 r
.2971 .58482 m .29398 .58471 L .29833 .58533 L F
.891 .981 .814 r
.30055 .57966 m .29833 .58533 L .30107 .58386 L F
.781 .898 .493 r
.29858 .57813 m .2967 .58144 L .29725 .57955 L F
.577 .842 .995 r
.29725 .57955 m .2967 .58144 L .30055 .57966 L F
.393 .234 .544 r
.2967 .58144 m .297 .58391 L .30055 .57966 L F
.751 .727 .831 r
.30055 .57966 m .30042 .57989 L .30038 .57988 L F
.891 .981 .814 r
.30055 .57966 m .30048 .57977 L .30047 .5798 L F
.30055 .57966 m .30047 .5798 L .29833 .58533 L F
.684 .78 .924 r
.30055 .57966 m .30107 .58386 L .30384 .58137 L F
.751 .727 .831 r
.30055 .57966 m .30161 .58002 L .30042 .57989 L F
.30055 .57966 m .30038 .57988 L .29725 .57955 L F
.742 .741 .85 r
.3004 .57989 m .30042 .57989 L .30042 .57987 L F
.3004 .57989 m .30042 .57987 L .30041 .57985 L F
.30038 .57988 m .3004 .57989 L .30041 .57985 L F
.393 .234 .544 r
.30038 .57988 m .2971 .58482 L .30048 .57977 L F
.297 .58391 m .29704 .5843 L .30038 .57988 L F
.29704 .5843 m .2971 .58482 L .30038 .57988 L F
.297 .58391 m .30048 .57977 L .30055 .57966 L F
.742 .741 .85 r
.29725 .57955 m .30038 .57988 L .30022 .57648 L F
.30038 .57988 m .30041 .57985 L .30022 .57648 L F
.30042 .57989 m .30161 .58002 L .30108 .57868 L F
.30042 .57989 m .30108 .57868 L .30022 .57648 L F
.891 .981 .814 r
.30048 .57977 m .2971 .58482 L .2976 .58502 L F
.30048 .57977 m .2976 .58502 L .29833 .58533 L F
.533 .287 .488 r
.29778 .55156 m .29856 .55468 L .29424 .554 L F
.4 .336 .669 r
.29743 .55714 m .29424 .554 L .29856 .55468 L F
.29743 .55714 m .29544 .55818 L .29424 .554 L F
0 0 .154 r
.41943 .56171 m .42079 .56005 L .4212 .55748 L F
.583 .558 .792 r
.41919 .5646 m .41994 .56247 L .41939 .56223 L F
.605 .722 .928 r
.41919 .5646 m .41455 .56342 L .41828 .56201 L F
.583 .558 .792 r
.41919 .5646 m .42184 .56388 L .42079 .56005 L F
.436 .565 .886 r
.41828 .56201 m .42132 .56295 L .41919 .5646 L F
.391 .85 .822 r
.41733 .56186 m .41828 .56201 L .41455 .56342 L F
.393 0 0 r
.41733 .56186 m .42057 .56274 L .41828 .56201 L F
.42057 .56274 m .42132 .56295 L .42035 .56265 L F
.42057 .56274 m .42035 .56265 L .41828 .56201 L F
.583 .558 .792 r
.41939 .56223 m .42079 .56005 L .41943 .56171 L F
.41994 .56247 m .42079 .56005 L .41939 .56223 L F
.497 .829 .999 r
.40946 .57657 m .40843 .57865 L .41152 .57527 L F
.40946 .57657 m .40664 .57718 L .40843 .57865 L F
.901 .765 .702 r
.36246 .56426 m .36538 .56291 L .36273 .56131 L F
.923 .675 .186 r
.66722 .35212 m .66735 .35442 L .66813 .35609 L F
.868 .692 .66 r
.66482 .358 m .66813 .35609 L .66735 .35442 L F
.66482 .358 m .66673 .3596 L .66813 .35609 L F
.426 0 0 r
.39141 .56915 m .39588 .57112 L .39569 .56912 L F
.269 .605 .954 r
.61998 .39497 m .61851 .39611 L .61709 .39575 L F
.61998 .39497 m .62151 .39698 L .61851 .39611 L F
.61998 .39497 m .61851 .39611 L .61709 .39575 L F
.61998 .39497 m .62151 .39698 L .61851 .39611 L F
.572 .786 .98 r
.30771 .67717 m .30856 .67484 L .30647 .67484 L F
.30771 .67717 m .31037 .6765 L .30856 .67484 L F
0 0 .339 r
.54096 .34687 m .54246 .3476 L .54321 .3455 L F
.938 .757 .631 r
.42429 .50718 m .42575 .51105 L .42667 .50816 L F
0 0 0 r
.46638 .42636 m .46855 .42539 L .46971 .42355 L F
.47162 .42236 m .47266 .42037 L .46971 .42355 L F
.46971 .42355 m .47064 .42398 L .47162 .42236 L F
.46971 .42355 m .46855 .42539 L .47064 .42398 L F
.844 .766 .776 r
.51448 .47276 m .51895 .47103 L .5174 .46973 L F
.51448 .47276 m .51644 .47455 L .51895 .47103 L F
.768 .831 .901 r
.51895 .47103 m .52023 .46661 L .5174 .46973 L F
.51895 .47103 m .52124 .46888 L .52023 .46661 L F
.821 .962 .901 r
.49271 .4969 m .49418 .49332 L .49129 .49603 L F
.49271 .4969 m .49567 .49435 L .49418 .49332 L F
0 0 0 r
.47454 .41876 m .47579 .41758 L .47266 .42037 L F
.47799 .41616 m .47579 .41758 L .47454 .41876 L F
.917 .972 .78 r
.47865 .5058 m .47866 .5085 L .48105 .5051 L F
.769 .996 .854 r
.48188 .50291 m .48105 .5051 L .48285 .50324 L F
.774 .998 .837 r
.48188 .50291 m .47865 .5058 L .48105 .5051 L F
.797 .667 .72 r
.31523 .55764 m .31768 .55899 L .31572 .5547 L F
.814 .719 .759 r
.31269 .56089 m .31768 .55899 L .31523 .55764 L F
.31269 .56089 m .31483 .56253 L .31768 .55899 L F
.854 .446 .263 r
.38342 .56111 m .38656 .56352 L .38743 .56315 L F
.734 .771 .882 r
.32878 .67873 m .33151 .67839 L .3307 .67528 L F
.824 .703 .73 r
.34023 .52141 m .34006 .52459 L .34194 .52447 L F
.816 .518 .485 r
.33983 .52694 m .34194 .52447 L .34006 .52459 L F
.33983 .52694 m .34446 .52808 L .34194 .52447 L F
.952 .746 .589 r
.37393 .48667 m .3726 .48242 L .3743 .48442 L F
.279 .732 .956 r
.3726 .48242 m .37562 .48304 L .3743 .48442 L F
.747 .425 .438 r
.3782 .4861 m .37393 .48667 L .3743 .48442 L F
.682 .623 .782 r
.58319 .34549 m .58259 .34906 L .58725 .34712 L F
0 0 0 r
.5831 .35107 m .58725 .34712 L .58259 .34906 L F
.437 .874 .892 r
.31299 .63953 m .31666 .63878 L .31524 .63794 L F
.738 .637 .747 r
.31582 .63552 m .32 .6357 L .31666 .63878 L F
.918 .63 .481 r
.31666 .63878 m .31708 .64206 L .31465 .64072 L F
.989 .846 .606 r
.31524 .63794 m .31666 .63878 L .31465 .64072 L F
.554 .074 .07 r
.55205 .37092 m .55649 .36997 L .55313 .37242 L F
0 0 .324 r
.55313 .37242 m .55447 .37148 L .55205 .37092 L F
.55313 .37242 m .5541 .37363 L .55447 .37148 L F
.438 .71 .981 r
.55446 .37534 m .5541 .37363 L .55313 .37242 L F
.473 .206 .427 r
.38039 .56147 m .38342 .56111 L .38369 .55828 L F
0 0 .434 r
.58199 .37292 m .58185 .37444 L .58116 .37509 L F
.757 .53 0 r
.58116 .37509 m .58178 .37877 L .58155 .37623 L F
.58116 .37509 m .58154 .37782 L .58178 .37877 L F
0 0 .434 r
.58185 .37444 m .58154 .37782 L .58116 .37509 L F
.057 .449 .879 r
.58062 .37559 m .58116 .37509 L .58155 .37623 L F
.5779 .37372 m .58116 .37509 L .58062 .37559 L F
.918 .883 .784 r
.51037 .42249 m .51192 .42077 L .50995 .41931 L F
.98 .757 .53 r
.58707 .38262 m .58843 .3864 L .58656 .38517 L F
0 0 .255 r
.58843 .3864 m .58991 .38751 L .58939 .38441 L F
.58843 .3864 m .58793 .38921 L .58991 .38751 L F
.624 .887 .988 r
.57943 .366 m .57684 .36723 L .57831 .36482 L F
.886 .978 .827 r
.47601 .50929 m .4758 .51202 L .47866 .5085 L F
.867 .969 .858 r
.47303 .5124 m .4758 .51202 L .47601 .50929 L F
.475 .201 .418 r
.5521 .38327 m .55214 .38551 L .5491 .38611 L F
.819 .705 .168 r
.34349 .62878 m .3436 .62427 L .34174 .62795 L F
.934 .591 .353 r
.34183 .63045 m .34349 .62878 L .34174 .62795 L F
.34183 .63045 m .34393 .63181 L .34349 .62878 L F
.674 .124 0 r
.37277 .5715 m .37503 .57363 L .37667 .57401 L F
.39 .8 .98 r
.37503 .57363 m .37908 .57386 L .37667 .57401 L F
.722 .923 .96 r
.41189 .57271 m .41152 .57527 L .41453 .57158 L F
.102 0 0 r
.4168 .5709 m .41189 .57271 L .41453 .57158 L F
0 0 0 r
.46638 .42636 m .46315 .42956 L .46518 .42794 L F
.46518 .42794 m .46855 .42539 L .46638 .42636 L F
.59072 .39986 m .59154 .39889 L .59163 .39924 L F
.59163 .39924 m .59351 .39654 L .59241 .39871 L F
.59154 .39889 m .59351 .39654 L .59163 .39924 L F
.392 .779 .99 r
.58919 .39869 m .59072 .39986 L .59241 .39871 L F
.431 0 0 r
.58919 .39869 m .59178 .39985 L .5893 .39932 L F
.59178 .39985 m .59206 .39997 L .5918 .39991 L F
.59178 .39985 m .5918 .39991 L .5893 .39932 L F
.812 .83 .864 r
.29858 .57813 m .29806 .57443 L .29987 .57532 L F
.576 .662 .896 r
.29396 .56916 m .29731 .57372 L .29364 .57376 L F
.29415 .56925 m .29731 .57372 L .29396 .56916 L F
0 0 .136 r
.29806 .57443 m .29806 .57479 L .29857 .57005 L F
.683 .594 .75 r
.29806 .57443 m .29491 .57778 L .29364 .57376 L F
.692 .393 .465 r
.29364 .57376 m .29806 .57479 L .29806 .57443 L F
.729 .721 .843 r
.29857 .57005 m .29806 .57479 L .29397 .56899 L F
.29865 .57122 m .29432 .572 L .29876 .57276 L F
.29857 .57005 m .2973 .57063 L .29865 .57122 L F
.2973 .57063 m .29432 .572 L .29865 .57122 L F
.576 .662 .896 r
.29397 .56899 m .29415 .56925 L .29396 .56916 L F
.29731 .57372 m .29806 .57479 L .29743 .57464 L F
.29731 .57372 m .29743 .57464 L .29364 .57376 L F
.812 .83 .864 r
.29858 .57813 m .29785 .57806 L .29806 .57443 L F
.29785 .57806 m .29491 .57778 L .29748 .57505 L F
.29785 .57806 m .29748 .57505 L .29806 .57443 L F
.781 .898 .493 r
.29858 .57813 m .29725 .57955 L .29491 .57778 L F
.965 .908 .709 r
.5529 .42256 m .55426 .4239 L .55563 .41958 L F
.334 0 .193 r
.27182 .59134 m .27027 .59416 L .26777 .59475 L F
.653 .636 .821 r
.27316 .58792 m .27182 .59134 L .27074 .58851 L F
.27316 .58792 m .27516 .59212 L .27182 .59134 L F
.017 0 .016 r
.2731 .59158 m .27182 .59134 L .27516 .59212 L F
.2731 .59158 m .27027 .59416 L .27182 .59134 L F
.747 .505 .564 r
.56595 .38605 m .56337 .386 L .56346 .38329 L F
0 0 .396 r
.66705 .35058 m .66628 .34983 L .66351 .34941 L F
.476 0 0 r
.3932 .48413 m .3904 .48582 L .38775 .48454 L F
.819 .45 .357 r
.3932 .48413 m .39429 .48705 L .3904 .48582 L F
.572 .8 .985 r
.29778 .55156 m .29296 .55097 L .29646 .54822 L F
.702 .39 .446 r
.29932 .5541 m .29856 .55468 L .29778 .55156 L F
.877 .681 .635 r
.30045 .55131 m .29932 .5541 L .29778 .55156 L F
.771 .429 0 r
.5457 .40397 m .54708 .40692 L .54545 .40278 L F
.902 .659 .561 r
.39579 .5477 m .39382 .54757 L .39479 .54516 L F
.443 .856 .959 r
.39668 .54674 m .39382 .54757 L .39579 .5477 L F
.39579 .5477 m .39382 .54757 L .39668 .54674 L F
.93 .701 .572 r
.371 .56798 m .37068 .57117 L .37277 .5715 L F
.639 .085 0 r
.37264 .57225 m .37277 .5715 L .37068 .57117 L F
.37264 .57225 m .37503 .57363 L .37277 .5715 L F
.93 .948 .78 r
.51081 .44698 m .50938 .4465 L .51165 .44296 L F
.513 .815 1 r
.33292 .52678 m .33466 .528 L .33571 .52642 L F
0 0 .343 r
.33466 .528 m .33572 .52925 L .33571 .52642 L F
.821 .977 .682 r
.54263 .43932 m .54385 .43769 L .542 .43902 L F
.921 .968 .671 r
.542 .43902 m .54385 .43769 L .5439 .43522 L F
.308 .107 .436 r
.26603 .56831 m .26767 .56802 L .2679 .56463 L F
.262 0 .268 r
.2679 .56463 m .26986 .56426 L .27144 .56331 L F
.557 .39 .611 r
.26767 .56802 m .26986 .56426 L .2679 .56463 L F
.888 .924 .84 r
.53772 .40798 m .53975 .40907 L .54208 .40609 L F
.555 .169 .264 r
.60424 .38244 m .60037 .38483 L .60145 .38277 L F
.98 .862 .649 r
.42782 .56362 m .42812 .56874 L .42876 .56613 L F
0 0 0 r
.43949 .44674 m .44144 .44599 L .44274 .44405 L F
.024 0 0 r
.44274 .44405 m .44385 .44494 L .44495 .44277 L F
.44274 .44405 m .44144 .44599 L .44385 .44494 L F
.234 0 .096 r
.54416 .38531 m .54763 .3821 L .54507 .38308 L F
.673 .866 .972 r
.44227 .54323 m .43797 .54316 L .43991 .54363 L F
0 0 0 r
.29934 .62513 m .29611 .62895 L .29869 .62813 L F
.246 0 .238 r
.3017 .62504 m .29934 .62513 L .29869 .62813 L F
.657 .92 .619 r
.51591 .37934 m .51731 .37727 L .51897 .37609 L F
0 0 .22 r
.51897 .37609 m .52002 .37132 L .52121 .37568 L F
.51897 .37609 m .52003 .37403 L .52002 .37132 L F
.704 .934 .621 r
.51897 .37609 m .51731 .37727 L .52003 .37403 L F
.712 .727 .207 r
.50435 .42613 m .50301 .43138 L .5054 .42854 L F
0 0 0 r
.50301 .43138 m .50625 .4302 L .50477 .43146 L F
.50301 .43138 m .50477 .43146 L .5054 .42854 L F
.411 .018 .179 r
.43302 .46378 m .43164 .46647 L .42895 .46674 L F
.408 .025 .198 r
.43563 .46322 m .43164 .46647 L .43302 .46378 L F
.74 .872 .941 r
.49705 .40877 m .50219 .40842 L .4997 .40745 L F
.227 .403 .829 r
.50219 .40842 m .50314 .40594 L .4997 .40745 L F
.50219 .40842 m .5042 .40894 L .50314 .40594 L F
.221 0 .056 r
.47823 .43033 m .47729 .43266 L .47506 .43264 L F
.079 0 .002 r
.4796 .43138 m .47823 .43033 L .48055 .42906 L F
.4796 .43138 m .47729 .43266 L .47823 .43033 L F
.006 0 0 r
.53333 .39336 m .53496 .39267 L .53708 .39014 L F
.233 .286 .712 r
.3063 .63606 m .30665 .638 L .30808 .63774 L F
0 0 0 r
.30808 .63774 m .30665 .638 L .3042 .63849 L F
.955 .912 .733 r
.46528 .50077 m .46586 .49597 L .46783 .49723 L F
.853 .87 .852 r
.47053 .49392 m .46783 .49723 L .46586 .49597 L F
.949 .92 .746 r
.55602 .40319 m .55316 .40512 L .55538 .40223 L F
.55602 .40319 m .55403 .40706 L .55316 .40512 L F
.553 .091 .111 r
.26547 .58932 m .26852 .59089 L .27074 .58851 L F
.134 0 0 r
.26852 .59089 m .27316 .58792 L .27074 .58851 L F
0 0 0 r
.29121 .63265 m .28807 .6358 L .29015 .63488 L F
0 0 .07 r
.29293 .63153 m .29121 .63265 L .29015 .63488 L F
.609 .86 .991 r
.6348 .37899 m .63221 .38014 L .631 .37858 L F
.153 0 0 r
.28173 .65107 m .27896 .65097 L .28006 .65082 L F
.672 .795 .335 r
.59241 .39871 m .59351 .39654 L .59449 .39426 L F
.603 .598 .82 r
.37088 .55267 m .37372 .55056 L .37096 .55292 L F
.593 .602 .83 r
.37088 .55267 m .37243 .5559 L .37505 .5546 L F
.877 .681 .635 r
.30045 .55131 m .30195 .55487 L .29932 .5541 L F
.784 .528 .549 r
.30195 .55487 m .29743 .55714 L .29932 .5541 L F
.30195 .55487 m .30196 .55776 L .29743 .55714 L F
.71 .613 .747 r
.3048 .55162 m .30195 .55487 L .30045 .55131 L F
.513 .907 .929 r
.63384 .38956 m .638 .38859 L .63634 .38831 L F
0 .555 .757 r
.638 .38859 m .64048 .3888 L .63634 .38831 L F
.409 .408 .747 r
.58035 .37245 m .5779 .37372 L .57671 .37181 L F
.58035 .37245 m .58116 .37509 L .5779 .37372 L F
.901 .969 .816 r
.47865 .5058 m .47601 .50929 L .47866 .5085 L F
0 .139 .683 r
.27549 .59035 m .27516 .59212 L .27316 .58792 L F
.634 .934 .967 r
.27549 .59035 m .2731 .59158 L .27516 .59212 L F
.935 .565 .183 r
.2985 .56811 m .29634 .56725 L .29638 .56451 L F
.852 .393 .068 r
.30056 .57084 m .29634 .56725 L .2985 .56811 L F
.973 .926 .661 r
.53986 .44257 m .54263 .43932 L .542 .43902 L F
.53986 .44257 m .54086 .44354 L .54263 .43932 L F
.477 0 0 r
.3782 .4861 m .37682 .48713 L .37393 .48667 L F
.97 .723 .295 r
.42115 .50748 m .42015 .50676 L .42019 .50353 L F
.912 .571 .103 r
.42115 .50748 m .42183 .51063 L .42015 .50676 L F
.754 .694 .794 r
.42427 .50405 m .42115 .50748 L .42019 .50353 L F
.52 .442 .708 r
.26184 .57789 m .26215 .58216 L .26497 .58144 L F
.17 .348 .799 r
.27956 .57106 m .28121 .57235 L .27898 .57175 L F
.28121 .57235 m .28248 .57334 L .28111 .57272 L F
.28121 .57235 m .28111 .57272 L .27898 .57175 L F
.761 .61 .691 r
.28255 .56449 m .2837 .56912 L .28067 .56835 L F
.577 .221 .328 r
.2837 .56912 m .27956 .57106 L .28067 .56835 L F
.2837 .56912 m .28146 .57197 L .27956 .57106 L F
.839 .997 .774 r
.28294 .56856 m .28188 .56995 L .28146 .57197 L F
.349 .155 .47 r
.28191 .57593 m .27898 .57175 L .28248 .57334 L F
.446 .376 .685 r
.28146 .57197 m .28248 .57334 L .27956 .57106 L F
.839 .997 .774 r
.28188 .56995 m .27987 .57258 L .2813 .57203 L F
.28188 .56995 m .2813 .57203 L .28146 .57197 L F
.349 .155 .47 r
.28111 .5748 m .27972 .57678 L .27898 .57175 L F
.28191 .57593 m .27986 .57673 L .28111 .5748 L F
.27986 .57673 m .27972 .57678 L .28111 .5748 L F
.776 .498 .515 r
.27773 .57483 m .28195 .57351 L .27987 .57258 L F
.28195 .57351 m .28248 .57334 L .28212 .57324 L F
.28195 .57351 m .28212 .57324 L .27987 .57258 L F
0 0 0 r
.27898 .57175 m .27718 .57465 L .27956 .57106 L F
0 0 .056 r
.27956 .57106 m .27718 .57465 L .27812 .57216 L F
.83 .81 .832 r
.6627 .37352 m .66362 .36825 L .66149 .37209 L F
.6627 .37352 m .66539 .37027 L .66362 .36825 L F
.142 0 0 r
.61789 .34717 m .61657 .34761 L .61375 .34763 L F
.366 .756 .987 r
.61375 .34763 m .61657 .34761 L .61231 .34673 L F
.476 .787 .999 r
.61657 .34761 m .61498 .34633 L .61231 .34673 L F
.965 .637 .294 r
.61498 .34633 m .61523 .34807 L .61657 .34761 L F
.61523 .34807 m .61534 .3489 L .61657 .34761 L F
.142 0 0 r
.61817 .34714 m .61657 .34761 L .61789 .34717 L F
.447 .87 .751 r
.61904 .34621 m .61817 .34714 L .62065 .34567 L F
.61904 .34621 m .61657 .34761 L .61817 .34714 L F
.681 .746 .901 r
.41455 .56342 m .41649 .56547 L .41226 .56455 L F
.605 .722 .928 r
.41919 .5646 m .41649 .56547 L .41455 .56342 L F
.933 .803 .693 r
.35353 .63778 m .35183 .64147 L .35459 .6422 L F
.953 .778 .629 r
.35125 .64454 m .35459 .6422 L .35183 .64147 L F
.35125 .64454 m .35324 .64564 L .35459 .6422 L F
.138 0 0 r
.545 .34976 m .54407 .35148 L .54109 .35242 L F
0 0 0 r
.54637 .34796 m .545 .34976 L .5474 .346 L F
.54601 .34915 m .545 .34976 L .54637 .34796 L F
.54637 .34796 m .5474 .346 L .54321 .3455 L F
.54637 .34796 m .54321 .3455 L .54633 .34558 L F
.529 .342 .571 r
.55011 .34257 m .55026 .34556 L .5474 .346 L F
0 0 0 r
.5474 .346 m .54936 .34407 L .55011 .34257 L F
.503 .783 .995 r
.55026 .34556 m .54936 .34407 L .5474 .346 L F
.041 0 .292 r
.54936 .34407 m .54637 .34796 L .54633 .34558 L F
.54936 .34407 m .54881 .3466 L .54637 .34796 L F
0 0 0 r
.54881 .3466 m .54583 .34976 L .54699 .34822 L F
.54881 .3466 m .54583 .34976 L .54601 .34915 L F
.728 .397 .42 r
.54679 .34819 m .54583 .34976 L .54699 .34822 L F
0 0 0 r
.54723 .34748 m .54601 .34915 L .54637 .34796 L F
.54679 .34819 m .54601 .34915 L .54723 .34748 L F
.54583 .34976 m .54566 .34976 L .54601 .34915 L F
.54566 .34976 m .545 .34976 L .54601 .34915 L F
.728 .397 .42 r
.54246 .3476 m .54583 .34976 L .54679 .34819 L F
0 0 0 r
.54749 .34734 m .54694 .34801 L .54723 .34748 L F
.54694 .34801 m .54687 .34806 L .54723 .34748 L F
.384 .321 .663 r
.54633 .34558 m .54694 .34801 L .54881 .3466 L F
.54694 .34801 m .54699 .34822 L .54881 .3466 L F
0 0 0 r
.54694 .34801 m .54679 .34819 L .54687 .34806 L F
.757 .555 .623 r
.54679 .34819 m .54699 .34822 L .54694 .34801 L F
0 0 0 r
.54881 .3466 m .54601 .34915 L .54749 .34734 L F
.757 .555 .623 r
.54657 .34816 m .54679 .34819 L .54685 .34766 L F
.54679 .34819 m .54694 .34801 L .54685 .34766 L F
.54246 .3476 m .54657 .34816 L .54633 .34558 L F
.54657 .34816 m .54685 .34766 L .54633 .34558 L F
0 0 0 r
.54583 .34976 m .54407 .35148 L .545 .34976 L F
.43949 .44674 m .436 .45009 L .43827 .44872 L F
.43949 .44674 m .44026 .44739 L .44144 .44599 L F
.43949 .44674 m .43827 .44872 L .44026 .44739 L F
.892 .945 .838 r
.6246 .39549 m .62846 .39347 L .62662 .39232 L F
.543 .853 .998 r
.63023 .39296 m .63359 .39201 L .62956 .39179 L F
.162 .009 .411 r
.63359 .39201 m .63384 .38956 L .63446 .39157 L F
.63359 .39201 m .63446 .39157 L .62956 .39179 L F
.537 .071 .095 r
.62956 .39179 m .63446 .39157 L .63293 .39354 L F
0 .327 .794 r
.62895 .39072 m .62956 .39179 L .63293 .39354 L F
.62851 .3904 m .62956 .39179 L .62895 .39072 L F
.543 .853 .998 r
.62846 .39347 m .63023 .39296 L .62956 .39179 L F
.514 .817 1 r
.62662 .39232 m .62846 .39347 L .62956 .39179 L F
.865 .863 .835 r
.47156 .49141 m .47238 .48703 L .47408 .48826 L F
.87 .893 .848 r
.47562 .48647 m .47408 .48826 L .47238 .48703 L F
.795 .999 .843 r
.59914 .34524 m .60062 .34247 L .6022 .34359 L F
0 0 0 r
.51311 .38271 m .51111 .38664 L .51244 .38456 L F
0 0 .019 r
.51111 .38664 m .5116 .3868 L .51244 .38456 L F
.51111 .38664 m .51075 .3892 L .5116 .3868 L F
.684 .389 .468 r
.34997 .53116 m .35253 .53372 L .35273 .53237 L F
.359 .206 .532 r
.28807 .6358 m .28818 .63867 L .29015 .63488 L F
.816 .682 .717 r
.36354 .56919 m .36253 .57179 L .35824 .57076 L F
.724 .787 .902 r
.50313 .41516 m .50412 .41191 L .5015 .41268 L F
.50313 .41516 m .50594 .41347 L .50412 .41191 L F
.888 .924 .84 r
.53772 .40798 m .54208 .40609 L .538 .40562 L F
.78 .674 .747 r
.29588 .53071 m .29663 .53572 L .30023 .53125 L F
.599 .576 .799 r
.39974 .58633 m .40162 .58297 L .39874 .5845 L F
.534 .613 .878 r
.60331 .37578 m .59882 .37286 L .60445 .37463 L F
.49 .564 .858 r
.60113 .37055 m .60445 .37463 L .59882 .37286 L F
.554 .848 .998 r
.60239 .37191 m .60445 .37463 L .60113 .37055 L F
.603 .37256 m .60426 .37435 L .60239 .37191 L F
.60426 .37435 m .60445 .37463 L .60239 .37191 L F
.416 .667 .964 r
.60474 .37365 m .60551 .37552 L .60519 .37556 L F
.554 .848 .998 r
.603 .37256 m .60474 .37365 L .60445 .37463 L F
.416 .667 .964 r
.60474 .37365 m .60331 .37578 L .60445 .37463 L F
.60426 .37436 m .60519 .37556 L .60331 .37578 L F
.60474 .37365 m .60519 .37556 L .60426 .37436 L F
.857 .744 .737 r
.51917 .43689 m .52096 .43923 L .51832 .43977 L F
.736 .681 .798 r
.38091 .58128 m .38467 .58261 L .38337 .58272 L F
.113 0 0 r
.38337 .58272 m .38467 .58261 L .38661 .58294 L F
.774 .913 .934 r
.52783 .45807 m .52571 .45949 L .52957 .45999 L F
.885 .842 .797 r
.52571 .45949 m .52676 .46299 L .52957 .45999 L F
.727 .985 .899 r
.53217 .45629 m .52783 .45807 L .52957 .45999 L F
.088 0 0 r
.41197 .46634 m .41443 .46582 L .41547 .4642 L F
.004 0 0 r
.41443 .46582 m .4178 .46312 L .41547 .4642 L F
.728 .843 .935 r
.32576 .67952 m .32878 .67873 L .32696 .67649 L F
.835 .869 .869 r
.32696 .67649 m .32878 .67873 L .3307 .67528 L F
0 0 .104 r
.32715 .61722 m .32659 .61879 L .32656 .62134 L F
.87 .893 .848 r
.47562 .48647 m .47238 .48703 L .47424 .48511 L F
.766 .908 .937 r
.47902 .48397 m .47562 .48647 L .47424 .48511 L F
.745 .942 .948 r
.49656 .49193 m .49567 .49435 L .49777 .49259 L F
.756 .952 .94 r
.49418 .49332 m .49567 .49435 L .49656 .49193 L F
.133 .337 .8 r
.5845 .37324 m .5856 .37146 L .58269 .37039 L F
.102 .294 .771 r
.5845 .37324 m .58715 .37498 L .5856 .37146 L F
0 0 0 r
.41114 .47892 m .40912 .48093 L .41162 .47827 L F
.325 0 .171 r
.41408 .47701 m .41114 .47892 L .41162 .47827 L F
.598 .449 .65 r
.26184 .57789 m .26575 .58046 L .26413 .57458 L F
.52 .442 .708 r
.26184 .57789 m .26497 .58144 L .26575 .58046 L F
.432 .832 .979 r
.58319 .34549 m .58378 .34536 L .58666 .34543 L F
.791 .55 .572 r
.58378 .34536 m .58725 .34712 L .58666 .34543 L F
.85 .703 .7 r
.31269 .56089 m .31443 .56483 L .31483 .56253 L F
.626 .078 0 r
.35287 .563 m .35724 .56506 L .35133 .5634 L F
.84 .572 .533 r
.42909 .54177 m .42433 .54359 L .42438 .54139 L F
.42909 .54177 m .42582 .54374 L .42433 .54359 L F
.42909 .54177 m .4286 .54412 L .42582 .54374 L F
.798 .419 .338 r
.65096 .34412 m .65465 .34315 L .65088 .34148 L F
.65096 .34412 m .65511 .34526 L .65465 .34315 L F
.736 .598 .703 r
.42694 .52098 m .42984 .51735 L .42699 .51774 L F
0 0 0 r
.45071 .45018 m .45414 .44777 L .45325 .44882 L F
.45325 .44882 m .45414 .44777 L .45637 .44641 L F
.148 .154 .609 r
.58124 .35556 m .58119 .35983 L .58325 .35743 L F
0 0 .484 r
.58266 .36237 m .58325 .35743 L .58119 .35983 L F
.252 .506 .902 r
.29314 .666 m .29529 .66916 L .29616 .66742 L F
.28 .541 .919 r
.29616 .66742 m .29529 .66916 L .29729 .66927 L F
.73 .448 .5 r
.34572 .53089 m .34802 .53393 L .34997 .53116 L F
.684 .389 .468 r
.34997 .53116 m .34802 .53393 L .35253 .53372 L F
.595 .933 .951 r
.61529 .34161 m .61708 .33924 L .61943 .33954 L F
.61529 .34161 m .61495 .3406 L .61708 .33924 L F
.968 .787 .606 r
.60164 .35797 m .60275 .36213 L .60234 .35895 L F
.795 .988 .89 r
.60455 .3556 m .60234 .35895 L .60559 .35601 L F
.60455 .3556 m .60164 .35797 L .60234 .35895 L F
.965 .908 .709 r
.5529 .42256 m .55563 .41958 L .55465 .41879 L F
.548 .817 .458 r
.51311 .38271 m .5146 .3809 L .51591 .37934 L F
0 0 0 r
.51311 .38271 m .51244 .38456 L .5146 .3809 L F
.903 .84 .773 r
.46528 .50077 m .46109 .50306 L .46384 .49963 L F
.46528 .50077 m .46294 .50436 L .46109 .50306 L F
.955 .912 .733 r
.46528 .50077 m .46384 .49963 L .46586 .49597 L F
.278 .163 .538 r
.26639 .57118 m .26767 .56802 L .26603 .56831 L F
.794 .909 .92 r
.63168 .33804 m .62868 .3377 L .63335 .33654 L F
.47 .89 .803 r
.63168 .33804 m .63545 .33541 L .63615 .33653 L F
.63168 .33804 m .63335 .33654 L .63545 .33541 L F
.799 .712 .769 r
.3065 .57814 m .30384 .58137 L .30824 .5818 L F
.811 .816 .855 r
.3232 .62782 m .32241 .63242 L .32147 .62845 L F
.3232 .62782 m .32498 .63006 L .32241 .63242 L F
.734 .28 .174 r
.55606 .38635 m .55488 .38813 L .55214 .38551 L F
.655 .337 .423 r
.55214 .38551 m .55488 .38813 L .54945 .38861 L F
.464 .045 .158 r
.55488 .38813 m .55074 .3905 L .54945 .38861 L F
.55229 .38962 m .5536 .39017 L .55074 .3905 L F
.55488 .38813 m .5536 .39017 L .55229 .38962 L F
.675 .835 .41 r
.5549 .38757 m .55379 .3898 L .55488 .38813 L F
.55379 .3898 m .5536 .39017 L .55488 .38813 L F
.52 .032 .038 r
.5589 .38767 m .55488 .38813 L .55627 .38639 L F
.246 .76 .835 r
.5589 .38767 m .55769 .38759 L .55488 .38813 L F
.734 .28 .174 r
.55627 .38639 m .55488 .38813 L .55606 .38635 L F
.675 .835 .41 r
.5549 .38757 m .55488 .38813 L .55769 .38759 L F
.881 .493 .294 r
.55531 .39088 m .5536 .39017 L .5549 .38757 L F
.55557 .39293 m .5536 .39017 L .55531 .39088 L F
.323 0 0 r
.56988 .38643 m .56625 .38712 L .56595 .38605 L F
.56988 .38643 m .56861 .38745 L .56625 .38712 L F
.654 .113 0 r
.56988 .38643 m .5727 .38851 L .56861 .38745 L F
.665 .623 .798 r
.26401 .59382 m .26408 .59657 L .26777 .59475 L F
.92 .787 .698 r
.45954 .50996 m .45784 .50608 L .46034 .50798 L F
.45954 .50996 m .45625 .50995 L .45784 .50608 L F
.916 .911 .801 r
.45954 .50996 m .45516 .51238 L .45625 .50995 L F
.45954 .50996 m .45669 .51382 L .45516 .51238 L F
.071 0 .021 r
.37725 .56489 m .37876 .56433 L .38039 .56147 L F
.88 .577 .471 r
.38039 .56147 m .37876 .56433 L .38177 .56428 L F
.545 .838 .999 r
.64186 .3931 m .64074 .39187 L .63773 .39275 L F
.968 .684 .268 r
.64048 .3888 m .64074 .39187 L .64186 .3931 L F
.969 .812 .632 r
.35931 .5534 m .36151 .55162 L .35992 .55062 L F
.35931 .5534 m .36115 .55462 L .36151 .55162 L F
.345 .121 .424 r
.56591 .36543 m .56826 .36236 L .56189 .36388 L F
.761 .987 .757 r
.39054 .58642 m .38902 .58767 L .39196 .58464 L F
.865 .863 .835 r
.47156 .49141 m .46963 .4904 L .47238 .48703 L F
.918 .827 .74 r
.47156 .49141 m .47053 .49392 L .46963 .4904 L F
.377 .824 .699 r
.55403 .40706 m .55009 .40894 L .55287 .40825 L F
.992 .823 .451 r
.55316 .40512 m .55403 .40706 L .55287 .40825 L F
.498 .282 .517 r
.40947 .56768 m .41226 .56455 L .40947 .56504 L F
.006 0 .356 r
.2771 .55437 m .2782 .55468 L .27906 .55021 L F
.745 .669 .776 r
.27532 .55602 m .2782 .55468 L .2771 .55437 L F
.984 .704 .389 r
.3317 .63162 m .33168 .62886 L .33008 .62773 L F
.736 .97 .707 r
.33168 .62886 m .33261 .62699 L .33008 .62773 L F
.33168 .62886 m .33448 .62578 L .33261 .62699 L F
.76 .347 .266 r
.61087 .39674 m .60609 .39767 L .60908 .39508 L F
.61087 .39674 m .61044 .39874 L .60609 .39767 L F
.372 .664 .971 r
.61184 .39416 m .61087 .39674 L .60908 .39508 L F
0 0 0 r
.55011 .34257 m .55148 .34248 L .55302 .34431 L F
.492 .314 .567 r
.55302 .34431 m .55026 .34556 L .55011 .34257 L F
0 0 0 r
.55011 .34257 m .54936 .34407 L .55148 .34248 L F
.438 .71 .981 r
.55446 .37534 m .55747 .37625 L .5541 .37363 L F
.22 0 0 r
.5534 .3793 m .55747 .37625 L .55446 .37534 L F
.5534 .3793 m .55637 .37855 L .55747 .37625 L F
.613 .776 .959 r
.5541 .37363 m .55747 .37625 L .55981 .37506 L F
.18 0 0 r
.55747 .37625 m .55937 .37738 L .55981 .37506 L F
.55747 .37625 m .55637 .37855 L .55937 .37738 L F
.054 0 .153 r
.52462 .35907 m .52787 .35493 L .52508 .35617 L F
.873 .71 .677 r
.31201 .56386 m .31443 .56483 L .31269 .56089 L F
.828 .684 .703 r
.30991 .56707 m .31443 .56483 L .31201 .56386 L F
.30991 .56707 m .31359 .56774 L .31443 .56483 L F
.763 .979 .719 r
.52194 .38054 m .52079 .38281 L .5234 .37978 L F
.139 .248 .716 r
.52194 .38054 m .52305 .38465 L .52079 .38281 L F
0 0 .308 r
.31713 .62189 m .31773 .61793 L .31712 .62045 L F
.772 .274 0 r
.31721 .62355 m .31907 .62467 L .31713 .62189 L F
.31721 .62355 m .31713 .62189 L .31712 .62045 L F
.839 .531 .467 r
.3618 .57408 m .35824 .57076 L .36253 .57179 L F
0 .208 .725 r
.33737 .66444 m .33892 .66821 L .33642 .6659 L F
0 0 0 r
.38674 .47833 m .38477 .47947 L .38855 .47816 L F
.265 0 0 r
.38775 .48454 m .38587 .48562 L .3834 .48557 L F
.469 0 0 r
.3904 .48582 m .38587 .48562 L .38775 .48454 L F
0 0 0 r
.46085 .43078 m .4598 .43218 L .46315 .42956 L F
.427 .033 .186 r
.5491 .38611 m .54774 .38941 L .54498 .38987 L F
.477 .079 .207 r
.54945 .38861 m .5491 .38611 L .55214 .38551 L F
.54945 .38861 m .54774 .38941 L .5491 .38611 L F
.145 0 .066 r
.45071 .45018 m .44988 .4526 L .4475 .45293 L F
.045 0 .03 r
.452 .45132 m .45071 .45018 L .45325 .44882 L F
.452 .45132 m .44988 .4526 L .45071 .45018 L F
.436 .815 .991 r
.53219 .42849 m .53062 .42997 L .52885 .43139 L F
.53219 .42849 m .53337 .42943 L .53062 .42997 L F
.435 .772 .997 r
.32137 .67884 m .32576 .67952 L .32376 .67865 L F
.728 .843 .935 r
.32576 .67952 m .32696 .67649 L .32376 .67865 L F
0 0 0 r
.60113 .37055 m .59882 .37286 L .6016 .36949 L F
.699 .685 .834 r
.30154 .63539 m .3063 .63606 L .30431 .63421 L F
.938 .803 .686 r
.3063 .63606 m .30599 .63123 L .30431 .63421 L F
.783 .73 .803 r
.31109 .63514 m .31582 .63552 L .31288 .63239 L F
.656 .476 .629 r
.30808 .63774 m .31326 .63634 L .31109 .63514 L F
.527 0 0 r
.31109 .63514 m .31317 .63629 L .31274 .63633 L F
.31317 .63629 m .31326 .63634 L .31274 .63633 L F
.07 0 0 r
.30847 .63867 m .31326 .63634 L .30808 .63774 L F
.709 .983 .804 r
.31274 .63633 m .31326 .63634 L .30903 .6384 L F
.30914 .63831 m .30903 .6384 L .30847 .63867 L F
.31274 .63633 m .30903 .6384 L .30914 .63831 L F
.574 .043 0 r
.31274 .63633 m .31582 .63552 L .31109 .63514 L F
.783 .73 .803 r
.31109 .63514 m .31288 .63239 L .3123 .63233 L F
.688 .617 .771 r
.31013 .63232 m .312 .63581 L .3091 .63252 L F
.084 .432 .873 r
.31288 .63239 m .31582 .63552 L .316 .63362 L F
.979 .686 .379 r
.31256 .62814 m .31288 .63239 L .31115 .63089 L F
0 .335 .674 r
.3123 .63211 m .31288 .63239 L .316 .63362 L F
.3123 .63211 m .316 .63362 L .31423 .63279 L F
0 .354 .672 r
.3123 .63211 m .31423 .63279 L .31166 .63187 L F
.709 .983 .804 r
.31274 .63633 m .30847 .63867 L .31027 .63815 L F
.712 .422 .484 r
.30686 .6357 m .31159 .63658 L .31027 .63815 L F
.84 .971 .656 r
.31147 .63647 m .31171 .63644 L .31027 .63815 L F
.31171 .63644 m .31274 .63633 L .31096 .63764 L F
.688 .617 .771 r
.312 .63581 m .31202 .63585 L .3112 .6365 L F
.84 .971 .656 r
.31179 .63624 m .31274 .63633 L .31167 .63644 L F
.688 .617 .771 r
.31202 .63585 m .3125 .63674 L .31159 .63658 L F
.31202 .63585 m .31159 .63658 L .3112 .6365 L F
.84 .971 .656 r
.31164 .63622 m .31179 .63624 L .31147 .63647 L F
.31179 .63624 m .31167 .63644 L .31147 .63647 L F
.927 .673 .534 r
.31244 .63543 m .31202 .63585 L .30974 .63161 L F
.84 .971 .656 r
.31256 .63495 m .3126 .63528 L .31164 .63622 L F
.3126 .63528 m .31274 .63633 L .31164 .63622 L F
.927 .673 .534 r
.3123 .63211 m .31244 .63543 L .30974 .63161 L F
.31244 .63543 m .3125 .63674 L .31202 .63585 L F
.69 .617 .77 r
.31256 .63495 m .3125 .63674 L .31202 .63585 L F
.31256 .63495 m .31202 .63585 L .30974 .63161 L F
.84 .971 .656 r
.31159 .63658 m .31096 .63764 L .31027 .63815 L F
.31171 .63644 m .31096 .63764 L .31159 .63658 L F
.712 .422 .484 r
.31159 .63658 m .3125 .63674 L .31027 .63815 L F
.69 .617 .77 r
.31256 .63495 m .31166 .63187 L .31423 .63279 L F
.31256 .63495 m .30974 .63161 L .31166 .63187 L F
.206 0 0 r
.31413 .63252 m .312 .63196 L .31055 .63359 L F
.691 .206 .091 r
.3075 .63006 m .3123 .63211 L .30974 .63161 L F
.782 .331 .178 r
.30953 .62756 m .31256 .62814 L .31199 .62743 L F
.979 .686 .379 r
.31256 .62814 m .31115 .63089 L .31199 .62743 L F
.567 .052 0 r
.31115 .63089 m .31288 .63239 L .3123 .63211 L F
.493 .286 .526 r
.30953 .62756 m .31115 .63089 L .3075 .63006 L F
.30953 .62756 m .31199 .62743 L .31115 .63089 L F
.691 .206 .091 r
.3075 .63006 m .31115 .63089 L .3123 .63211 L F
0 .354 .672 r
.3123 .63211 m .31256 .62867 L .30974 .63161 L F
.206 0 0 r
.312 .63196 m .31166 .63187 L .31155 .63205 L F
.312 .63196 m .31155 .63205 L .31055 .63359 L F
.688 .617 .771 r
.3091 .63252 m .312 .63581 L .30686 .6357 L F
.30974 .63161 m .31013 .63232 L .3091 .63252 L F
.312 .63581 m .3112 .6365 L .30686 .6357 L F
.734 .99 .876 r
.316 .63362 m .31582 .63552 L .31274 .63633 L F
.909 .603 .453 r
.31524 .63794 m .31582 .63552 L .31274 .63633 L F
.394 .639 .954 r
.52485 .40261 m .5242 .40058 L .52342 .39917 L F
.52485 .40261 m .52763 .40289 L .5242 .40058 L F
.554 .074 .07 r
.55205 .37092 m .55447 .37148 L .55649 .36997 L F
.218 .226 .655 r
.5581 .36684 m .55822 .36929 L .55649 .36997 L F
.573 .097 .087 r
.55649 .36997 m .55447 .37148 L .55877 .3711 L F
.605 .457 .654 r
.56796 .35914 m .57133 .36178 L .57093 .35816 L F
.56796 .35914 m .56826 .36236 L .57133 .36178 L F
.729 .64 .76 r
.42874 .52461 m .42694 .52098 L .42728 .52351 L F
.42874 .52461 m .4316 .52138 L .42694 .52098 L F
.811 .701 .743 r
.29663 .53572 m .29516 .53841 L .29458 .53578 L F
.646 .602 .79 r
.30073 .53883 m .2984 .53729 L .29812 .53733 L F
.30183 .53946 m .2984 .53729 L .30073 .53883 L F
.67 .518 .67 r
.2984 .53729 m .29516 .53841 L .29647 .53602 L F
.2984 .53729 m .29647 .53602 L .29663 .53572 L F
.665 .221 .188 r
.29458 .53578 m .29812 .53733 L .29663 .53572 L F
.64 .101 0 r
.2984 .53729 m .29812 .53733 L .29663 .53572 L F
.926 .912 .786 r
.42507 .5699 m .42599 .57234 L .42812 .56874 L F
.98 .862 .649 r
.42782 .56362 m .42658 .56797 L .42812 .56874 L F
.917 .933 .804 r
.42658 .56797 m .42507 .5699 L .42812 .56874 L F
.132 0 0 r
.60777 .37991 m .60587 .38219 L .60424 .38244 L F
.905 .965 .645 r
.60646 .38031 m .60777 .37991 L .60667 .37815 L F
.60646 .38031 m .60587 .38219 L .60777 .37991 L F
.736 .879 .471 r
.50523 .40415 m .50566 .40415 L .50634 .40296 L F
.133 0 0 r
.50906 .40342 m .50523 .40415 L .50538 .404 L F
.50822 .40328 m .50538 .404 L .50634 .40296 L F
.50906 .40342 m .50538 .404 L .50822 .40328 L F
.447 .642 .94 r
.51074 .40371 m .51224 .40146 L .5089 .401 L F
.742 .666 .777 r
.51224 .40146 m .51046 .40271 L .50848 .40175 L F
.51046 .40271 m .50863 .404 L .50857 .40319 L F
.51046 .40271 m .50857 .40319 L .50848 .40175 L F
.236 .747 .72 r
.50639 .4037 m .50484 .40415 L .50523 .40415 L F
.50484 .40415 m .50328 .40461 L .50523 .40415 L F
.736 .879 .471 r
.50523 .40415 m .5044 .40633 L .50566 .40415 L F
0 0 0 r
.5089 .401 m .50848 .40175 L .50634 .40296 L F
.133 0 0 r
.50906 .40342 m .50634 .40296 L .50848 .40175 L F
.827 .81 .835 r
.66362 .36825 m .66539 .37027 L .6671 .36856 L F
.579 .875 .994 r
.34107 .49408 m .34186 .49217 L .34408 .4932 L F
.34107 .49408 m .34186 .49217 L .34408 .4932 L F
0 0 0 r
.41114 .47892 m .40799 .48372 L .40912 .48093 L F
.877 .869 .826 r
.54001 .41468 m .54159 .41703 L .54425 .41265 L F
.988 .725 .364 r
.54004 .41779 m .54159 .41703 L .54001 .41468 L F
.321 .644 .967 r
.63386 .34368 m .63583 .34215 L .63282 .34252 L F
.63386 .34368 m .63721 .34377 L .63583 .34215 L F
.251 .667 .964 r
.6382 .34465 m .63721 .34377 L .63386 .34368 L F
0 0 0 r
.30123 .63637 m .29876 .63888 L .30154 .63539 L F
.283 .25 .643 r
.30123 .63637 m .30123 .64115 L .29876 .63888 L F
.554 .901 .976 r
.61943 .33954 m .62181 .33853 L .62355 .3389 L F
.108 .286 .763 r
.62527 .33759 m .62355 .3389 L .62181 .33853 L F
.62527 .33759 m .6262 .3411 L .62355 .3389 L F
.591 .444 .651 r
.26413 .57458 m .26754 .57917 L .26618 .57367 L F
.26413 .57458 m .26575 .58046 L .26754 .57917 L F
.447 .642 .94 r
.51074 .40371 m .51276 .40279 L .51224 .40146 L F
.709 .986 .863 r
.51074 .40371 m .51224 .40146 L .51276 .40279 L F
.51074 .40371 m .50863 .404 L .51224 .40146 L F
.377 .842 .817 r
.51074 .40371 m .50863 .404 L .51276 .40279 L F
.81 .582 .593 r
.30992 .54444 m .30979 .54738 L .31418 .54794 L F
.861 .803 .792 r
.30963 .55019 m .31418 .54794 L .30979 .54738 L F
.30963 .55019 m .31071 .55234 L .31418 .54794 L F
.144 0 .028 r
.28993 .54846 m .2888 .55042 L .28658 .55113 L F
.412 .013 .17 r
.2916 .54987 m .28993 .54846 L .2921 .54765 L F
.2916 .54987 m .2888 .55042 L .28993 .54846 L F
0 0 0 r
.55942 .39668 m .56073 .39548 L .56204 .39689 L F
.55942 .39668 m .55773 .3985 L .56073 .39548 L F
.622 .509 .705 r
.40037 .562 m .40192 .56478 L .3986 .56479 L F
0 0 0 r
.40037 .562 m .3986 .56479 L .3997 .56309 L F
.574 .251 .383 r
.40192 .56478 m .4011 .56698 L .3986 .56479 L F
.031 .232 .735 r
.3986 .56479 m .4011 .56698 L .3997 .56309 L F
.816 .824 .856 r
.6666 .36555 m .6671 .36856 L .66761 .36684 L F
.6666 .36555 m .66362 .36825 L .6671 .36856 L F
.934 .634 .447 r
.334 .51938 m .33592 .52062 L .33599 .5176 L F
.825 .784 .814 r
.47053 .49392 m .46705 .49337 L .46963 .4904 L F
.853 .87 .852 r
.47053 .49392 m .46586 .49597 L .46705 .49337 L F
.765 .611 .687 r
.4316 .52138 m .43183 .51729 L .42984 .51735 L F
.467 .286 .551 r
.29398 .58471 m .2971 .58482 L .2967 .58144 L F
.46 .225 .471 r
.29398 .58471 m .29375 .58763 L .2971 .58482 L F
.2971 .58482 m .29375 .58763 L .29398 .58471 L F
.848 .93 .882 r
.42145 .57393 m .42599 .57234 L .42507 .5699 L F
.639 .167 0 r
.37138 .58547 m .37162 .58628 L .36919 .58317 L F
.37138 .58547 m .37318 .58799 L .37162 .58628 L F
.675 .485 .62 r
.32048 .60871 m .32349 .60872 L .32282 .60513 L F
0 0 0 r
.60449 .36624 m .60384 .36773 L .6016 .36949 L F
.60384 .36773 m .60113 .37055 L .6016 .36949 L F
.476 .841 .594 r
.49336 .41155 m .49165 .41302 L .49488 .41047 L F
.436 .243 .518 r
.49435 .41471 m .49165 .41302 L .49336 .41155 L F
.49435 .41471 m .4917 .41586 L .49165 .41302 L F
.718 .988 .859 r
.64347 .38845 m .64478 .38625 L .64399 .38685 L F
.444 .768 .997 r
.64315 .38943 m .64347 .38845 L .64048 .3888 L F
.718 .988 .859 r
.64347 .38845 m .64399 .38685 L .64111 .38901 L F
.444 .768 .997 r
.64464 .38978 m .64347 .38845 L .64315 .38943 L F
0 0 .056 r
.60643 .36429 m .60449 .36624 L .60691 .36233 L F
.728 .355 .343 r
.60275 .36213 m .60561 .36495 L .60691 .36233 L F
.60561 .36495 m .60597 .3653 L .60624 .36444 L F
.60561 .36495 m .60624 .36444 L .60691 .36233 L F
0 .046 .562 r
.60401 .36304 m .6056 .36488 L .60275 .36213 L F
.725 .352 .342 r
.60691 .36233 m .60597 .3653 L .60643 .36429 L F
0 0 0 r
.60643 .36429 m .60912 .36198 L .60902 .36332 L F
.60643 .36429 m .60597 .3653 L .60702 .36419 L F
.60643 .36429 m .60702 .36419 L .60912 .36198 L F
.832 .892 .884 r
.60912 .36198 m .60702 .36419 L .60401 .36304 L F
.60702 .36419 m .60597 .3653 L .60561 .36489 L F
0 0 0 r
.60773 .3642 m .60586 .36502 L .60617 .36461 L F
.60687 .36426 m .60617 .36461 L .60643 .36429 L F
.832 .892 .884 r
.60702 .36419 m .60561 .36489 L .60687 .36426 L F
0 0 0 r
.60773 .3642 m .60617 .36461 L .60687 .36426 L F
.653 .762 .283 r
.6056 .36489 m .60561 .36495 L .60643 .36429 L F
.60489 .36554 m .60449 .36624 L .60643 .36429 L F
.60473 .36567 m .60472 .36569 L .60489 .36554 L F
.60472 .36569 m .60449 .36624 L .60489 .36554 L F
.60473 .36567 m .60643 .36429 L .60643 .36429 L F
0 0 0 r
.60617 .36461 m .6056 .36489 L .60643 .36429 L F
.60586 .36502 m .60561 .36489 L .60617 .36461 L F
.60561 .36489 m .6056 .36489 L .60617 .36461 L F
.832 .892 .884 r
.60687 .36426 m .60561 .36489 L .6056 .36488 L F
.60571 .36478 m .6056 .36488 L .60557 .36485 L F
.60687 .36426 m .6056 .36488 L .60571 .36478 L F
.60702 .36419 m .60557 .36485 L .60401 .36304 L F
0 0 0 r
.60797 .36404 m .60702 .36419 L .60902 .36332 L F
.60702 .36419 m .60643 .36429 L .60861 .36348 L F
.60702 .36419 m .60861 .36348 L .60902 .36332 L F
.60773 .3642 m .60643 .36429 L .60797 .36404 L F
0 .046 .562 r
.6056 .36489 m .60597 .3653 L .60561 .36495 L F
.60561 .36489 m .60597 .3653 L .6056 .36489 L F
.653 .762 .283 r
.60481 .36547 m .60473 .36567 L .60561 .36495 L F
.60481 .36547 m .60561 .36495 L .6056 .36489 L F
0 0 0 r
.60586 .36502 m .60481 .36547 L .6056 .36489 L F
0 .046 .562 r
.6056 .36488 m .60561 .36489 L .6056 .36489 L F
.6056 .36488 m .60561 .36495 L .60275 .36213 L F
.653 .762 .283 r
.60481 .36547 m .60384 .36773 L .60449 .36624 L F
0 0 0 r
.31797 .61085 m .31355 .61465 L .31543 .61328 L F
.64 .547 .733 r
.31797 .61085 m .32179 .61095 L .32048 .60871 L F
.347 0 0 r
.31913 .61178 m .31797 .61085 L .31543 .61328 L F
.762 .951 .629 r
.49598 .46644 m .4968 .46452 L .49912 .46363 L F
.896 .987 .78 r
.49959 .46008 m .49912 .46363 L .4968 .46452 L F
.914 .524 .248 r
.65715 .34706 m .65834 .34652 L .65511 .34526 L F
.65715 .34706 m .65899 .34832 L .65834 .34652 L F
.222 0 0 r
.29175 .54293 m .29342 .54333 L .2902 .5406 L F
.29175 .54293 m .29448 .54365 L .29342 .54333 L F
0 0 0 r
.29516 .53841 m .29342 .54333 L .29505 .5389 L F
.522 .401 .656 r
.29448 .54365 m .29505 .5389 L .29342 .54333 L F
.983 .702 .403 r
.52864 .411 m .53037 .4132 L .5288 .41513 L F
.539 .717 .955 r
.53289 .41231 m .53037 .4132 L .52864 .411 L F
.752 .488 .534 r
.53289 .41231 m .5288 .41513 L .53037 .4132 L F
.485 .097 .228 r
.26986 .56426 m .27583 .56148 L .27144 .56331 L F
.26986 .56426 m .27621 .56417 L .27583 .56148 L F
0 0 .496 r
.27583 .56148 m .27532 .55602 L .27369 .55675 L F
.27583 .56148 m .27692 .56122 L .27532 .55602 L F
0 0 .167 r
.27583 .56148 m .27633 .56314 L .27692 .56122 L F
.27583 .56148 m .27621 .56417 L .27633 .56314 L F
.05 0 0 r
.45639 .43553 m .45774 .43362 L .4542 .43577 L F
0 0 0 r
.4598 .43218 m .45774 .43362 L .45639 .43553 L F
.982 .706 .419 r
.35931 .5534 m .36104 .55743 L .36115 .55462 L F
.137 0 .008 r
.4132 .46778 m .41197 .46634 L .41079 .46878 L F
.4132 .46778 m .41443 .46582 L .41197 .46634 L F
.569 .791 .983 r
.32563 .62756 m .32498 .63006 L .3232 .62782 L F
.32563 .62756 m .32782 .62955 L .32498 .63006 L F
.918 .883 .784 r
.51037 .42249 m .50995 .41931 L .50692 .42241 L F
.839 .693 .701 r
.50692 .42241 m .50863 .42647 L .51037 .42249 L F
.288 .207 .587 r
.53398 .39576 m .53555 .3948 L .53333 .39336 L F
.308 .201 .566 r
.53333 .39336 m .53555 .3948 L .53496 .39267 L F
.931 .964 .666 r
.36407 .54542 m .36253 .54753 L .36435 .54384 L F
.821 .703 .734 r
.33797 .53391 m .33434 .53382 L .33521 .53082 L F
.857 .621 .579 r
.33797 .53391 m .33417 .53638 L .33434 .53382 L F
.33797 .53391 m .33662 .53739 L .33417 .53638 L F
.942 .764 .633 r
.37372 .55056 m .37505 .5546 L .37583 .55156 L F
.032 0 .019 r
.54009 .35352 m .5378 .35485 L .5384 .35339 L F
.768 .494 .519 r
.42015 .50676 m .42427 .50405 L .42019 .50353 L F
.42015 .50676 m .42429 .50718 L .42427 .50405 L F
.869 .678 .641 r
.34652 .63491 m .34393 .63181 L .34503 .63483 L F
.56 .041 0 r
.3451 .63474 m .34364 .63317 L .34223 .63201 L F
.34597 .63555 m .34519 .63475 L .3451 .63474 L F
.871 .482 .011 r
.34364 .63317 m .34503 .63483 L .34393 .63181 L F
.128 .521 .915 r
.34678 .63481 m .34503 .63483 L .34364 .63317 L F
.56 .041 0 r
.34519 .63475 m .34364 .63317 L .3451 .63474 L F
0 0 .521 r
.34678 .63481 m .34652 .63491 L .34571 .63486 L F
.34552 .63482 m .34571 .63486 L .34503 .63483 L F
.34678 .63481 m .34571 .63486 L .34552 .63482 L F
.34678 .63481 m .34955 .63842 L .34652 .63491 L F
.793 .367 .234 r
.35253 .53372 m .35477 .53635 L .35673 .53533 L F
.75 .3 .182 r
.35477 .53635 m .35806 .53719 L .35673 .53533 L F
.409 .741 .993 r
.33309 .61871 m .33404 .61708 L .33123 .61749 L F
.33309 .61871 m .33561 .61848 L .33404 .61708 L F
.345 0 .091 r
.33428 .62058 m .33309 .61871 L .33123 .61749 L F
.33428 .62058 m .33561 .61848 L .33309 .61871 L F
.413 .627 .942 r
.6013 .35253 m .60484 .35271 L .60268 .35029 L F
.6013 .35253 m .60484 .35271 L .60268 .35029 L F
.981 .745 .507 r
.29079 .55394 m .2887 .55375 L .2888 .55042 L F
.82 .764 .8 r
.29296 .55097 m .29079 .55394 L .2888 .55042 L F
.714 .303 .265 r
.28637 .55723 m .29208 .55588 L .28916 .55655 L F
.802 .413 .317 r
.29215 .55587 m .29186 .55569 L .29258 .55579 L F
.29186 .55569 m .2887 .55375 L .29103 .55498 L F
.29186 .55569 m .29103 .55498 L .29258 .55579 L F
.985 .754 .505 r
.29544 .55818 m .2946 .56058 L .29338 .55663 L F
.965 .758 .575 r
.29338 .55663 m .2946 .56058 L .29283 .55933 L F
.29338 .55663 m .2946 .56058 L .29283 .55933 L F
.802 .413 .317 r
.29338 .55663 m .28916 .55655 L .2887 .55375 L F
.853 .832 .826 r
.29295 .55662 m .28896 .5593 L .28913 .55691 L F
.685 .77 .916 r
.28749 .55662 m .28633 .5597 L .28429 .55677 L F
.28892 .55682 m .28633 .5597 L .28749 .55662 L F
.853 .832 .826 r
.29295 .55662 m .28913 .55691 L .29131 .55659 L F
.29283 .55696 m .28896 .5593 L .29295 .55662 L F
.712 .713 .849 r
.28979 .55702 m .29131 .55659 L .2929 .55662 L F
.853 .832 .826 r
.29338 .55663 m .29283 .55696 L .29295 .55662 L F
.712 .713 .849 r
.29288 .55668 m .2929 .55662 L .29338 .55663 L F
.28979 .55702 m .2929 .55662 L .29288 .55668 L F
.29283 .55933 m .29236 .55897 L .29338 .55663 L F
.29236 .55897 m .29294 .55668 L .29338 .55663 L F
.802 .413 .317 r
.29292 .55615 m .29215 .55587 L .29258 .55579 L F
.29338 .55663 m .29294 .55636 L .29292 .55615 L F
.29294 .55636 m .29215 .55587 L .29292 .55615 L F
0 0 .013 r
.29315 .55582 m .29299 .55677 L .29328 .55752 L F
.29299 .55677 m .29258 .55915 L .29312 .55789 L F
.29299 .55677 m .29312 .55789 L .29328 .55752 L F
.29314 .55563 m .29307 .55609 L .29315 .55582 L F
.29307 .55609 m .29258 .55915 L .29315 .55582 L F
.714 .303 .265 r
.28862 .55669 m .29298 .55666 L .29208 .55588 L F
.579 .596 .834 r
.28892 .55682 m .28896 .5593 L .28633 .5597 L F
.28913 .55691 m .28896 .5593 L .28892 .55682 L F
.712 .713 .849 r
.29283 .55933 m .28896 .5593 L .28913 .55691 L F
.714 .303 .265 r
.28929 .55697 m .29298 .55666 L .28862 .55669 L F
.853 .832 .826 r
.29131 .55659 m .28913 .55691 L .28916 .55655 L F
.712 .713 .849 r
.28979 .55702 m .28913 .55691 L .28916 .55655 L F
.29283 .55933 m .28913 .55691 L .28979 .55702 L F
.714 .303 .265 r
.28637 .55723 m .28929 .55697 L .28913 .55691 L F
.28832 .55677 m .28913 .55691 L .28862 .55669 L F
.28637 .55723 m .28913 .55691 L .28832 .55677 L F
.579 .596 .834 r
.28916 .55655 m .28913 .55691 L .28892 .55682 L F
.685 .77 .916 r
.28916 .55655 m .28892 .55682 L .28749 .55662 L F
.714 .303 .265 r
.28783 .5571 m .28766 .55763 L .28999 .55696 L F
.28976 .55693 m .28999 .55696 L .29024 .55689 L F
.28783 .5571 m .28999 .55696 L .28976 .55693 L F
.28637 .55723 m .28656 .55729 L .28783 .5571 L F
.28656 .55729 m .28766 .55763 L .28783 .5571 L F
0 0 .013 r
.29337 .55549 m .29328 .55752 L .29411 .55503 L F
.29321 .55558 m .29322 .55589 L .29337 .55549 L F
.29322 .55589 m .29328 .55752 L .29337 .55549 L F
.29314 .55563 m .29315 .55582 L .29321 .55558 L F
.29315 .55582 m .29328 .55752 L .29321 .55558 L F
.712 .713 .849 r
.29236 .55897 m .28979 .55702 L .29294 .55668 L F
.28979 .55702 m .28916 .55655 L .29131 .55659 L F
.714 .303 .265 r
.29024 .55689 m .29258 .55915 L .29298 .55666 L F
.28766 .55763 m .29258 .55915 L .29024 .55689 L F
.29208 .55588 m .29298 .55666 L .29314 .55563 L F
.29208 .55588 m .29314 .55563 L .29197 .5559 L F
.29208 .55588 m .29197 .5559 L .28916 .55655 L F
.802 .413 .317 r
.29258 .55579 m .2887 .55375 L .29079 .55394 L F
.121 0 0 r
.39545 .47523 m .39891 .47374 L .39627 .47437 L F
.807 .879 .898 r
.51832 .43977 m .51543 .44245 L .51324 .44115 L F
.268 0 0 r
.58269 .37039 m .5856 .37146 L .5824 .37042 L F
.818 .717 .754 r
.30991 .56707 m .31122 .57097 L .31359 .56774 L F
.762 .951 .629 r
.49598 .46644 m .49553 .46646 L .4968 .46452 L F
.943 .836 .709 r
.40632 .57084 m .4031 .57359 L .40549 .57048 L F
.571 .207 .312 r
.40549 .57048 m .40947 .56768 L .40632 .57084 L F
.792 .675 .735 r
.33558 .52363 m .34006 .52459 L .34023 .52141 L F
.757 .44 .448 r
.33571 .52642 m .34006 .52459 L .33558 .52363 L F
.33571 .52642 m .33983 .52694 L .34006 .52459 L F
.916 .66 .535 r
.33999 .54097 m .33655 .53983 L .33662 .53739 L F
.952 .712 .537 r
.33999 .54097 m .33616 .54158 L .33655 .53983 L F
.33999 .54097 m .33975 .54406 L .33616 .54158 L F
.793 .766 .829 r
.35698 .54077 m .35818 .5441 L .35824 .54113 L F
.54 .852 .998 r
.35907 .53932 m .35824 .54113 L .36086 .54045 L F
.672 .969 .917 r
.35907 .53932 m .35698 .54077 L .35824 .54113 L F
.749 .645 .746 r
.35818 .5441 m .36086 .54045 L .35824 .54113 L F
.886 .604 .504 r
.36481 .5669 m .36412 .56808 L .36246 .56426 L F
.775 .994 .873 r
.56946 .40229 m .57303 .3997 L .57062 .39986 L F
.686 .907 .562 r
.57428 .39752 m .57303 .3997 L .5757 .39623 L F
.708 .984 .886 r
.57062 .39986 m .57303 .3997 L .57428 .39752 L F
.415 .102 .324 r
.53793 .35754 m .5358 .35619 L .5378 .35485 L F
.53793 .35754 m .53509 .35828 L .5358 .35619 L F
.805 .692 .74 r
.42315 .53418 m .42507 .5382 L .42237 .53702 L F
.809 .673 .714 r
.42507 .5382 m .42011 .54018 L .42237 .53702 L F
.42507 .5382 m .42438 .54139 L .42011 .54018 L F
.717 .753 .88 r
.30859 .67239 m .31349 .67254 L .31057 .66979 L F
.744 .491 .548 r
.31265 .67414 m .31349 .67254 L .30859 .67239 L F
.41 .49 .832 r
.31349 .67254 m .31696 .67578 L .31616 .67346 L F
.31479 .67256 m .31616 .67346 L .31585 .67258 L F
.31349 .67254 m .31616 .67346 L .31479 .67256 L F
.513 .635 .908 r
.31585 .67258 m .31696 .67578 L .31654 .67364 L F
.31585 .67258 m .31696 .67578 L .31654 .67364 L F
.938 .757 .631 r
.31585 .67258 m .31654 .67364 L .31536 .67358 L F
.236 0 .265 r
.31537 .67356 m .31349 .67254 L .31397 .67255 L F
.31536 .67359 m .31349 .67254 L .31537 .67356 L F
.3156 .67373 m .31409 .67255 L .31585 .67258 L F
0 .206 .692 r
.31057 .66979 m .31193 .67107 L .3152 .67344 L F
.938 .757 .631 r
.31585 .67258 m .31535 .67358 L .31507 .67332 L F
0 .296 .785 r
.31057 .66979 m .31507 .67332 L .31479 .67299 L F
.236 .753 .779 r
.31261 .66973 m .31216 .66996 L .31453 .66937 L F
0 .296 .785 r
.31137 .66987 m .31171 .67018 L .31216 .66996 L F
.31057 .66979 m .31479 .67299 L .31137 .66987 L F
0 .206 .692 r
.31057 .66979 m .3152 .67344 L .31507 .67332 L F
.776 .851 .908 r
.30649 .67052 m .30859 .67239 L .31057 .66979 L F
.30649 .67052 m .31057 .66979 L .30962 .66756 L F
0 .296 .785 r
.31057 .66979 m .31216 .66996 L .30962 .66756 L F
.671 .268 .274 r
.30962 .66756 m .31216 .66996 L .30765 .67022 L F
.236 .753 .779 r
.31028 .67018 m .31216 .66996 L .31261 .66973 L F
0 .296 .785 r
.31171 .67018 m .31479 .67299 L .31216 .66996 L F
.938 .757 .631 r
.31585 .67258 m .31507 .67332 L .31481 .67301 L F
.31585 .67258 m .31536 .67358 L .31535 .67358 L F
.236 0 .265 r
.3156 .67373 m .31585 .67258 L .31481 .67301 L F
.938 .757 .631 r
.31481 .67301 m .31507 .67332 L .31478 .67303 L F
0 .206 .692 r
.31507 .67332 m .3152 .67344 L .3156 .67373 L F
.938 .757 .631 r
.31478 .67303 m .31535 .67358 L .31365 .6735 L F
.67 .137 0 r
.31537 .6736 m .31642 .67363 L .31685 .67469 L F
.236 0 .265 r
.3156 .67373 m .31537 .6736 L .31537 .67356 L F
.31537 .6736 m .31536 .67359 L .31536 .67358 L F
.31537 .6736 m .31536 .67358 L .31537 .67356 L F
.67 .137 0 r
.31535 .67358 m .31536 .67358 L .31537 .6736 L F
.31536 .67358 m .31642 .67363 L .31537 .6736 L F
0 .206 .692 r
.31193 .67107 m .31349 .67254 L .31537 .6736 L F
.31193 .67107 m .31537 .6736 L .3156 .67373 L F
.236 0 .265 r
.3156 .67373 m .31481 .67301 L .31365 .6735 L F
0 .296 .785 r
.31507 .67332 m .3156 .67373 L .31306 .67094 L F
.31507 .67332 m .31306 .67094 L .31216 .66996 L F
.074 .495 .896 r
.31696 .67578 m .31779 .67504 L .31654 .67364 L F
.67 .137 0 r
.31685 .67469 m .31642 .67363 L .31779 .67504 L F
.31365 .6735 m .31535 .67358 L .31685 .67469 L F
.31642 .67363 m .31654 .67364 L .31671 .67382 L F
.31642 .67363 m .31671 .67382 L .31779 .67504 L F
.547 .04 .002 r
.56595 .38605 m .56625 .38712 L .56337 .386 L F
.782 .431 .392 r
.65762 .35028 m .66056 .34884 L .65899 .34832 L F
.65762 .35028 m .66013 .35139 L .66056 .34884 L F
.153 0 .238 r
.66056 .34884 m .66228 .35007 L .66351 .34941 L F
.66056 .34884 m .66013 .35139 L .66228 .35007 L F
.369 .038 .267 r
.42635 .46739 m .42976 .46846 L .42637 .46874 L F
.42635 .46739 m .42895 .46674 L .42976 .46846 L F
.216 0 .055 r
.42635 .46739 m .42637 .46874 L .42268 .46981 L F
.939 .866 .442 r
.54751 .43211 m .54768 .4293 L .54685 .43163 L F
.916 .973 .782 r
.5439 .43522 m .54751 .43211 L .54685 .43163 L F
.682 .623 .782 r
.58319 .34549 m .58725 .34712 L .58378 .34536 L F
0 0 0 r
.5831 .35107 m .58474 .34993 L .58725 .34712 L F
.069 0 0 r
.58725 .34712 m .58814 .34849 L .58936 .34988 L F
.58725 .34712 m .58474 .34993 L .58814 .34849 L F
.793 .618 .663 r
.3105 .64566 m .31212 .6446 L .31016 .64225 L F
.504 .142 .286 r
.3105 .64566 m .31355 .64495 L .31212 .6446 L F
.143 0 0 r
.44879 .45414 m .4475 .45293 L .44988 .4526 L F
.44879 .45414 m .4463 .455 L .4475 .45293 L F
.694 .481 .595 r
.56044 .37239 m .56336 .36953 L .562 .36906 L F
.56044 .37239 m .56301 .37247 L .56336 .36953 L F
.196 .401 .837 r
.56396 .36728 m .56336 .36953 L .56164 .36624 L F
.804 .996 .864 r
.56396 .36728 m .562 .36906 L .56336 .36953 L F
.165 0 0 r
.47506 .43264 m .47629 .4336 L .47362 .43469 L F
.47506 .43264 m .47729 .43266 L .47629 .4336 L F
0 0 0 r
.49307 .40318 m .49364 .40304 L .49539 .40161 L F
.49307 .40318 m .49195 .40482 L .49364 .40304 L F
.606 .942 .76 r
.45198 .53744 m .44776 .53997 L .44929 .541 L F
.45198 .53744 m .45005 .53821 L .44776 .53997 L F
.707 .977 .916 r
.45198 .53744 m .45357 .53584 L .45262 .53549 L F
.766 .99 .768 r
.45262 .53549 m .45005 .53821 L .45198 .53744 L F
.722 .893 .958 r
.56457 .39537 m .56204 .39689 L .56073 .39548 L F
.772 .819 .889 r
.40642 .48482 m .40436 .48618 L .40837 .48618 L F
.157 0 0 r
.40614 .48552 m .40436 .48618 L .40642 .48482 L F
.995 .802 .534 r
.40631 .48731 m .40436 .48618 L .40183 .48712 L F
.40631 .48731 m .40594 .48918 L .40436 .48618 L F
.227 .036 .4 r
.40594 .48918 m .40837 .48618 L .40436 .48618 L F
.157 0 0 r
.40542 .48729 m .40436 .48618 L .40614 .48552 L F
.995 .802 .534 r
.40183 .48712 m .40436 .48618 L .40173 .48712 L F
.864 .594 .528 r
.31134 .55412 m .31523 .55764 L .31572 .5547 L F
.31134 .55412 m .31121 .55699 L .31523 .55764 L F
.854 .754 .751 r
.31121 .55699 m .31269 .56089 L .31523 .55764 L F
.13 0 0 r
.37534 .58837 m .37816 .58489 L .37799 .5876 L F
.427 .84 .968 r
.62597 .38873 m .62252 .38864 L .62395 .38498 L F
.576 .075 .027 r
.33261 .62699 m .33448 .62578 L .33703 .62736 L F
.865 .62 .566 r
.34407 .55131 m .34105 .55349 L .34157 .55033 L F
.34407 .55131 m .34354 .55418 L .34105 .55349 L F
.829 .659 .671 r
.34243 .5448 m .34159 .54759 L .33975 .54406 L F
.094 0 0 r
.38449 .56902 m .38674 .56914 L .39003 .56912 L F
.776 .567 .616 r
.38327 .5667 m .38203 .57025 L .38102 .56828 L F
.156 0 0 r
.38449 .56902 m .38521 .56926 L .38978 .5693 L F
.777 .326 .177 r
.38126 .56829 m .38475 .56915 L .38327 .5667 L F
.858 .652 .623 r
.38449 .56902 m .38327 .5667 L .38521 .56926 L F
.777 .326 .177 r
.38475 .56915 m .38521 .56926 L .38512 .56914 L F
.38475 .56915 m .38512 .56914 L .38327 .5667 L F
.094 0 0 r
.39003 .56912 m .38978 .5693 L .39141 .56915 L F
0 0 0 r
.38978 .5693 m .38807 .57123 L .38965 .56947 L F
.094 0 0 r
.3899 .56912 m .38978 .5693 L .39003 .56912 L F
0 0 0 r
.38978 .5693 m .39112 .56784 L .39295 .56892 L F
.38978 .5693 m .38965 .56947 L .39112 .56784 L F
.094 0 0 r
.38674 .56914 m .38978 .5693 L .3899 .56912 L F
0 .265 .769 r
.39295 .56892 m .39141 .56915 L .38978 .5693 L F
.426 0 0 r
.39518 .57081 m .39416 .57071 L .39588 .57112 L F
.39141 .56915 m .39416 .57071 L .39518 .57081 L F
0 .265 .769 r
.39295 .56892 m .39416 .57071 L .39141 .56915 L F
.439 0 0 r
.39263 .57056 m .39416 .57071 L .39295 .56892 L F
.39261 .57069 m .39416 .57071 L .39263 .57056 L F
.794 .697 .758 r
.29743 .55714 m .2946 .56058 L .29544 .55818 L F
.357 .805 .667 r
.48399 .42791 m .48736 .42628 L .48602 .42883 L F
.617 .491 .686 r
.49063 .42326 m .48736 .42628 L .4868 .42281 L F
.49063 .42326 m .49061 .42605 L .48736 .42628 L F
.471 .05 .158 r
.48736 .42628 m .48977 .42757 L .48602 .42883 L F
.48736 .42628 m .49061 .42605 L .48977 .42757 L F
.844 .817 .334 r
.57941 .38789 m .58011 .38632 L .58042 .38522 L F
.825 .985 .71 r
.50118 .45921 m .50318 .45579 L .50491 .45765 L F
.50118 .45921 m .50057 .4591 L .50318 .45579 L F
.664 .351 .432 r
.42438 .54139 m .42112 .5431 L .42011 .54018 L F
.42438 .54139 m .42433 .54359 L .42112 .5431 L F
.297 .775 .676 r
.32834 .61339 m .33091 .61241 L .32556 .61463 L F
.49 .813 1 r
.32556 .61463 m .32459 .61482 L .32803 .61726 L F
.297 .775 .676 r
.32834 .61339 m .32556 .61463 L .32803 .61726 L F
.92 .921 .797 r
.32834 .61339 m .32585 .61557 L .32732 .61378 L F
.32834 .61339 m .32732 .61378 L .32821 .6127 L F
.297 .775 .676 r
.32834 .61339 m .33158 .61214 L .33091 .61241 L F
.447 .854 .966 r
.37318 .58799 m .37534 .58837 L .37799 .5876 L F
.646 .602 .79 r
.30183 .53946 m .29812 .53733 L .29955 .5396 L F
.459 0 0 r
.30183 .53946 m .29955 .5396 L .30385 .54023 L F
.706 .965 .939 r
.65422 .37721 m .65288 .37962 L .65496 .37806 L F
.725 .983 .902 r
.65024 .37992 m .65288 .37962 L .65422 .37721 L F
.934 .726 .597 r
.36047 .56034 m .36273 .56131 L .36104 .55743 L F
.79 .55 .573 r
.35822 .56362 m .36273 .56131 L .36047 .56034 L F
.35822 .56362 m .36246 .56426 L .36273 .56131 L F
.762 .674 .765 r
.36104 .55743 m .36273 .56131 L .36554 .55808 L F
.736 .598 .703 r
.42694 .52098 m .4316 .52138 L .42984 .51735 L F
.84 .635 .626 r
.34446 .52808 m .34181 .53066 L .34572 .53089 L F
.706 .427 .5 r
.34128 .53349 m .34572 .53089 L .34181 .53066 L F
.34128 .53349 m .34562 .53356 L .34572 .53089 L F
.729 .448 .501 r
.34562 .53356 m .34802 .53393 L .34572 .53089 L F
.797 .523 .523 r
.43278 .55541 m .43401 .55456 L .43207 .55418 L F
.412 .013 .17 r
.2916 .54987 m .2921 .54765 L .29296 .55097 L F
.82 .764 .8 r
.29296 .55097 m .2888 .55042 L .2916 .54987 L F
.84 .86 .859 r
.52023 .46661 m .52124 .46888 L .52397 .46635 L F
.779 .745 .822 r
.42969 .53003 m .42557 .53073 L .42786 .53069 L F
.821 .385 .203 r
.42786 .53069 m .43251 .5305 L .42969 .53003 L F
.555 .169 .264 r
.60424 .38244 m .60314 .38498 L .60037 .38483 L F
.299 .316 .71 r
.60424 .38244 m .60587 .38219 L .60646 .38031 L F
.727 .62 .738 r
.60646 .38031 m .60314 .38498 L .60424 .38244 L F
0 0 0 r
.53428 .4244 m .53863 .41969 L .53828 .42241 L F
0 0 .216 r
.54004 .41779 m .53828 .42241 L .53863 .41969 L F
.442 .714 .981 r
.50809 .45748 m .50606 .45666 L .50491 .45765 L F
0 0 .343 r
.56985 .36931 m .57107 .36441 L .5682 .36518 L F
.56985 .36931 m .5712 .36727 L .57107 .36441 L F
.664 .966 .921 r
.56985 .36931 m .56884 .36885 L .5712 .36727 L F
.321 .479 .861 r
.28533 .66145 m .2874 .66476 L .28924 .66479 L F
.818 .734 .771 r
.46294 .50436 m .45784 .50608 L .46109 .50306 L F
.46294 .50436 m .46034 .50798 L .45784 .50608 L F
.931 .881 .764 r
.45669 .51382 m .45289 .51606 L .45516 .51238 L F
.45669 .51382 m .45452 .51734 L .45289 .51606 L F
.653 .886 .534 r
.57704 .3941 m .5757 .39623 L .57839 .39279 L F
0 0 0 r
.44864 .44016 m .44495 .44277 L .44694 .44155 L F
.45093 .4391 m .44864 .44016 L .44694 .44155 L F
.703 .878 .963 r
.30154 .63539 m .30431 .63421 L .30259 .63251 L F
.30154 .63539 m .30259 .63251 L .30161 .63555 L F
0 0 0 r
.30123 .63637 m .30154 .63539 L .30161 .63555 L F
.549 .551 .809 r
.52329 .371 m .52121 .37568 L .52002 .37132 L F
.52329 .371 m .52461 .3756 L .52121 .37568 L F
0 0 .527 r
.52435 .37744 m .52121 .37568 L .52461 .3756 L F
.738 .976 .728 r
.53329 .41782 m .53488 .41702 L .53199 .42002 L F
.53329 .41782 m .53199 .42002 L .53137 .42066 L F
.792 .841 .888 r
.53334 .41497 m .53488 .41702 L .53329 .41782 L F
.53334 .41497 m .53756 .41505 L .53488 .41702 L F
.422 .588 .91 r
.53448 .41579 m .53329 .41782 L .53599 .41746 L F
.53436 .41565 m .53329 .41782 L .53448 .41579 L F
.419 .494 .83 r
.53137 .42066 m .53428 .4244 L .53329 .41782 L F
.718 .797 .913 r
.53428 .4244 m .53599 .41746 L .53329 .41782 L F
.53428 .4244 m .53828 .42241 L .53599 .41746 L F
.964 .836 .668 r
.54086 .44354 m .53832 .44489 L .53972 .44591 L F
.928 .963 .77 r
.53986 .44257 m .53832 .44489 L .54086 .44354 L F
.035 .588 .825 r
.53226 .40644 m .53382 .40674 L .53384 .40699 L F
.872 .804 .781 r
.53571 .40622 m .53358 .40967 L .53133 .40823 L F
.53571 .40622 m .53385 .40707 L .53384 .40699 L F
0 0 0 r
.538 .40562 m .53571 .40622 L .53384 .40699 L F
.538 .40562 m .53762 .40575 L .53643 .40724 L F
.53762 .40575 m .53384 .40699 L .53643 .40724 L F
.035 .588 .825 r
.53382 .40674 m .53643 .40724 L .53384 .40699 L F
.872 .804 .781 r
.53385 .40707 m .53133 .40823 L .53384 .40699 L F
.714 .974 .925 r
.53226 .40644 m .53384 .40699 L .53133 .40823 L F
.834 .554 .515 r
.53445 .40971 m .53643 .40724 L .53226 .40644 L F
.53464 .40999 m .53643 .40724 L .53445 .40971 L F
.854 .833 .826 r
.52284 .46285 m .52023 .46661 L .52397 .46635 L F
.86 .856 .836 r
.52397 .46635 m .52489 .4615 L .52284 .46285 L F
.52397 .46635 m .52676 .46299 L .52489 .4615 L F
.345 .121 .424 r
.56591 .36543 m .5682 .36518 L .56826 .36236 L F
.843 .641 .629 r
.3396 .52937 m .34446 .52808 L .33983 .52694 L F
.3396 .52937 m .34181 .53066 L .34446 .52808 L F
.246 0 .189 r
.46564 .43949 m .46874 .43672 L .46762 .44044 L F
.234 0 .184 r
.46762 .44044 m .46874 .43672 L .47116 .43574 L F
.962 .943 .666 r
.34925 .65923 m .35086 .65533 L .34988 .65462 L F
.975 .919 .608 r
.35086 .65533 m .35157 .65063 L .34988 .65462 L F
.851 .801 .801 r
.6082 .3524 m .60484 .35271 L .60682 .35095 L F
.6082 .3524 m .60559 .35601 L .60484 .35271 L F
0 0 0 r
.60865 .35164 m .6082 .3524 L .61102 .35167 L F
.60865 .35164 m .60721 .35411 L .6082 .3524 L F
.148 0 0 r
.38855 .47816 m .39109 .47765 L .39289 .4757 L F
.217 0 0 r
.39109 .47765 m .39545 .47523 L .39289 .4757 L F
.613 .947 .935 r
.60721 .35411 m .60455 .3556 L .60559 .35601 L F
.419 .865 .886 r
.61709 .39575 m .61443 .3967 L .61446 .3962 L F
.05 0 0 r
.45639 .43553 m .4542 .43577 L .45357 .43647 L F
.795 .999 .84 r
.48188 .50291 m .48285 .50324 L .48593 .50039 L F
.129 0 0 r
.42881 .45531 m .43275 .45266 L .43028 .4536 L F
.94 .807 .685 r
.30657 .57306 m .30889 .57424 L .30741 .57051 L F
.879 .764 .731 r
.30436 .57658 m .30889 .57424 L .30657 .57306 L F
.30436 .57658 m .3065 .57814 L .30889 .57424 L F
.834 .778 .799 r
.30741 .57051 m .30889 .57424 L .31122 .57097 L F
.799 .984 .717 r
.52435 .37744 m .52194 .38054 L .5234 .37978 L F
.603 .902 .622 r
.49524 .40956 m .49488 .41047 L .49705 .40877 L F
.49524 .40956 m .49336 .41155 L .49488 .41047 L F
.176 0 .258 r
.44383 .45589 m .44112 .45931 L .44175 .45703 L F
.344 0 .219 r
.42268 .46981 m .42212 .47247 L .41953 .47312 L F
.316 .006 .271 r
.42268 .46981 m .4247 .47175 L .42212 .47247 L F
.42268 .46981 m .42637 .46874 L .4247 .47175 L F
.824 .549 .523 r
.36753 .56467 m .36753 .56768 L .371 .56798 L F
.808 .582 .596 r
.36661 .57039 m .371 .56798 L .36753 .56768 L F
.36661 .57039 m .37068 .57117 L .371 .56798 L F
0 0 .394 r
.38153 .56369 m .38177 .56428 L .37876 .56433 L F
.809 .448 0 r
.30963 .55019 m .31134 .55412 L .31071 .55234 L F
.062 .144 .638 r
.28462 .56639 m .2837 .56912 L .28255 .56449 L F
.792 .937 .578 r
.28294 .56856 m .2837 .56912 L .28462 .56639 L F
.28294 .56856 m .28146 .57197 L .2837 .56912 L F
.062 .144 .638 r
.28462 .56639 m .28255 .56449 L .28532 .56453 L F
.612 .807 .975 r
.6246 .39549 m .62151 .39698 L .61998 .39497 L F
0 .376 .833 r
.61998 .39497 m .62151 .39698 L .62405 .39807 L F
.763 .916 .541 r
.57936 .39034 m .57704 .3941 L .57839 .39279 L F
.841 .9 .879 r
.28464 .55064 m .28384 .55411 L .28658 .55113 L F
.451 .336 .631 r
.28678 .54566 m .28747 .55009 L .29023 .54911 L F
.25 0 0 r
.2888 .55042 m .28566 .55059 L .28658 .55113 L F
.28566 .55059 m .28464 .55064 L .28507 .55075 L F
.2888 .55042 m .28758 .5508 L .28464 .55064 L F
.451 .336 .631 r
.28747 .55009 m .28758 .5508 L .28964 .54949 L F
.28747 .55009 m .28964 .54949 L .29023 .54911 L F
.25 0 0 r
.28566 .55059 m .28507 .55075 L .28658 .55113 L F
.836 .922 .891 r
.54299 .42404 m .54035 .42672 L .5389 .42551 L F
.227 0 .03 r
.53245 .35919 m .5315 .36135 L .52863 .36197 L F
.143 0 0 r
.53399 .36027 m .53245 .35919 L .53509 .35828 L F
.53399 .36027 m .5315 .36135 L .53245 .35919 L F
0 0 0 r
.5234 .36194 m .524 .3613 L .52449 .36088 L F
.896 .565 .075 r
.52506 .36037 m .52449 .36088 L .52462 .35907 L F
0 0 0 r
.52449 .36088 m .52617 .35901 L .52605 .35898 L F
.524 .3613 m .52617 .35901 L .52449 .36088 L F
.896 .565 .075 r
.52576 .3624 m .52449 .36088 L .52506 .36037 L F
.872 .993 .809 r
.52576 .3624 m .52275 .36381 L .52449 .36088 L F
.52576 .3624 m .52277 .36547 L .52275 .36381 L F
.612 .376 .535 r
.52576 .3624 m .52606 .36544 L .52277 .36547 L F
.51 .303 .534 r
.52904 .3639 m .52576 .3624 L .52863 .36197 L F
.52904 .3639 m .52606 .36544 L .52576 .3624 L F
.774 .699 .78 r
.42183 .51063 m .42575 .51105 L .42429 .50718 L F
.407 .209 .496 r
.279 .54806 m .28153 .54878 L .28137 .54744 L F
.279 .54806 m .27906 .55021 L .28153 .54878 L F
0 0 0 r
.3048 .62129 m .3017 .62504 L .30408 .62399 L F
.308 .61823 m .3048 .62129 L .30668 .62085 L F
0 0 .031 r
.30668 .62085 m .3048 .62129 L .30408 .62399 L F
.841 .9 .879 r
.28464 .55064 m .28197 .55326 L .28384 .55411 L F
.044 0 0 r
.40518 .47177 m .4082 .46958 L .40585 .47064 L F
.423 .809 .989 r
.50394 .42212 m .50427 .4231 L .50026 .42287 L F
.527 0 0 r
.50026 .42287 m .50427 .4231 L .50238 .42424 L F
.51 .339 .585 r
.50427 .4231 m .50692 .42241 L .50673 .41968 L F
.482 .85 .989 r
.50394 .42212 m .50692 .42241 L .50427 .4231 L F
.50427 .4231 m .50394 .42212 L .50238 .42424 L F
.50427 .4231 m .50692 .42241 L .50394 .42212 L F
.759 .66 .753 r
.50435 .42613 m .50692 .42241 L .50427 .4231 L F
0 0 0 r
.58178 .37877 m .58155 .38056 L .57998 .38258 L F
.818 .643 .091 r
.58154 .37782 m .58155 .38056 L .58178 .37877 L F
.485 .814 1 r
.60062 .34247 m .60524 .34294 L .6022 .34359 L F
.577 .844 .995 r
.32137 .67884 m .32376 .67865 L .32203 .6766 L F
.662 .884 .98 r
.32203 .6766 m .32376 .67865 L .32696 .67649 L F
.872 .684 .646 r
.40827 .58395 m .41036 .58527 L .40834 .58109 L F
.794 .858 .898 r
.40503 .58672 m .41036 .58527 L .40827 .58395 L F
.671 .725 .889 r
.26766 .58025 m .27227 .58149 L .26982 .57805 L F
.497 .484 .773 r
.26766 .58025 m .2713 .58298 L .27227 .58149 L F
.506 .623 .901 r
.27227 .58149 m .27266 .57743 L .26982 .57805 L F
.27227 .58149 m .27444 .58074 L .27266 .57743 L F
.583 .319 .483 r
.27444 .58074 m .2713 .58298 L .27227 .58149 L F
.27444 .58074 m .2713 .58298 L .27227 .58149 L F
.886 .604 .504 r
.36481 .5669 m .36753 .56768 L .36753 .56467 L F
.897 .847 .785 r
.52489 .4615 m .52676 .46299 L .52571 .45949 L F
.643 .769 .94 r
.50412 .41191 m .50594 .41347 L .50818 .41201 L F
.919 .595 .126 r
.66482 .358 m .66632 .36224 L .66673 .3596 L F
.384 .813 .644 r
.66632 .36224 m .66931 .36048 L .66673 .3596 L F
.501 .695 .956 r
.6382 .34465 m .64015 .34288 L .63721 .34377 L F
.6382 .34465 m .64136 .34475 L .64015 .34288 L F
.995 .764 .415 r
.50314 .40594 m .5044 .40633 L .50523 .40415 L F
.454 .132 .33 r
.5044 .40633 m .5062 .4082 L .50725 .40586 L F
0 0 .072 r
.58155 .38056 m .58042 .38522 L .57998 .38258 L F
.501 .249 .464 r
.53358 .40967 m .53289 .41231 L .53133 .40823 L F
.53358 .40967 m .53565 .4116 L .53289 .41231 L F
.851 .732 .732 r
.30991 .56707 m .30741 .57051 L .31122 .57097 L F
.792 .675 .735 r
.33558 .52363 m .34023 .52141 L .33592 .52062 L F
.43 .424 .751 r
.40397 .56362 m .40192 .56478 L .40037 .562 L F
.543 0 0 r
.3997 .56309 m .40397 .56362 L .40037 .562 L F
.34 .568 .923 r
.31696 .67578 m .32137 .67884 L .3204 .67713 L F
.577 .844 .995 r
.32137 .67884 m .32203 .6766 L .3204 .67713 L F
.364 0 0 r
.32424 .6237 m .31907 .62467 L .3217 .62454 L F
.916 .956 .802 r
.5054 .42854 m .50625 .4302 L .50863 .42647 L F
.988 .863 .502 r
.50477 .43146 m .50625 .4302 L .5054 .42854 L F
.384 .836 .921 r
.60524 .34294 m .60804 .34214 L .60939 .34257 L F
.469 .859 .976 r
.60804 .34214 m .61247 .34208 L .60939 .34257 L F
.555 .284 .46 r
.56826 .36236 m .5682 .36518 L .57107 .36441 L F
.549 .287 .47 r
.56826 .36236 m .57107 .36441 L .57133 .36178 L F
.709 .316 0 r
.55009 .40894 m .55163 .41188 L .5524 .41383 L F
.927 .971 .752 r
.34755 .66124 m .34925 .65923 L .34667 .66059 L F
.962 .943 .666 r
.34925 .65923 m .34988 .65462 L .34878 .65724 L F
.941 .959 .742 r
.34667 .66059 m .34925 .65923 L .34878 .65724 L F
.85 .774 .777 r
.31481 .64214 m .31708 .64206 L .31495 .64335 L F
.601 .45 .649 r
.31299 .63953 m .3151 .64124 L .31016 .64225 L F
.3151 .64124 m .31524 .64136 L .31505 .64139 L F
.3151 .64124 m .31505 .64139 L .31016 .64225 L F
.31524 .64136 m .31504 .64173 L .31016 .64225 L F
.29 .243 .631 r
.31267 .64487 m .31016 .64225 L .31494 .64174 L F
.823 1 .805 r
.31481 .64214 m .31267 .64487 L .31479 .64195 L F
.31495 .64335 m .31429 .64379 L .31481 .64214 L F
.31429 .64379 m .31267 .64487 L .31481 .64214 L F
.85 .774 .777 r
.31504 .64173 m .31708 .64206 L .31481 .64214 L F
.31538 .64112 m .3156 .64124 L .31504 .64173 L F
.3156 .64124 m .31708 .64206 L .31504 .64173 L F
.29 .243 .631 r
.31267 .64487 m .31479 .64195 L .31562 .64167 L F
.31479 .64195 m .31494 .64174 L .31504 .64173 L F
.31479 .64195 m .31504 .64173 L .31562 .64167 L F
0 .224 .723 r
.31465 .64072 m .31562 .64167 L .31299 .63953 L F
.823 1 .805 r
.31479 .64195 m .31267 .64487 L .31465 .64072 L F
.85 .774 .777 r
.31465 .64072 m .31538 .64112 L .31481 .64214 L F
.601 .45 .649 r
.31524 .64136 m .31562 .64167 L .31504 .64173 L F
.29 .243 .631 r
.31267 .64487 m .3105 .64566 L .31016 .64225 L F
.258 .263 .674 r
.37016 .54723 m .37178 .54654 L .36928 .54435 L F
.344 0 .029 r
.28137 .54744 m .28432 .54693 L .28572 .54528 L F
.151 0 0 r
.28572 .54528 m .28678 .54566 L .28761 .54375 L F
.28572 .54528 m .28432 .54693 L .28678 .54566 L F
.838 .727 .201 r
.3459 .55829 m .3454 .55929 L .343 .55695 L F
.918 .905 .795 r
.48152 .48019 m .47743 .48273 L .47994 .47894 L F
.48152 .48019 m .47902 .48397 L .47743 .48273 L F
.826 .906 .895 r
.48474 .4773 m .48152 .48019 L .47994 .47894 L F
.722 .923 .96 r
.41189 .57271 m .40876 .57414 L .41152 .57527 L F
.972 .704 .464 r
.40876 .57414 m .40946 .57657 L .41152 .57527 L F
.815 .851 .876 r
.30856 .67484 m .31037 .6765 L .31265 .67414 L F
.798 .664 .715 r
.30775 .54381 m .30992 .54444 L .30839 .54067 L F
.798 .572 .594 r
.30581 .54669 m .30992 .54444 L .30775 .54381 L F
.30581 .54669 m .30979 .54738 L .30992 .54444 L F
.571 .207 .312 r
.40549 .57048 m .40764 .57131 L .40947 .56768 L F
.498 .282 .517 r
.40947 .56768 m .41177 .56728 L .41226 .56455 L F
0 0 0 r
.40947 .56768 m .41119 .56694 L .41177 .56728 L F
.40947 .56768 m .40764 .57131 L .41119 .56694 L F
.641 .936 .966 r
.41455 .56342 m .41226 .56455 L .4131 .56275 L F
.703 .676 .132 r
.41226 .56455 m .41227 .56437 L .4131 .56275 L F
.41226 .56455 m .41177 .56728 L .41227 .56437 L F
.101 .151 .628 r
.58124 .35556 m .58325 .35743 L .58279 .35351 L F
0 0 0 r
.59654 .34867 m .59541 .34992 L .59867 .34723 L F
0 0 .437 r
.40711 .49138 m .40768 .48951 L .40971 .49124 L F
.40711 .49138 m .40971 .49124 L .40794 .48953 L F
.997 .767 .449 r
.40837 .48618 m .40794 .48953 L .40971 .49124 L F
.658 .15 .027 r
.54393 .40411 m .5457 .40397 L .54545 .40278 L F
0 0 .023 r
.37799 .5876 m .37857 .58185 L .37318 .58799 L F
.887 .902 .833 r
.37162 .58628 m .37648 .58318 L .37534 .58339 L F
.37648 .58318 m .37857 .58185 L .37679 .5827 L F
.37648 .58318 m .37679 .5827 L .37534 .58339 L F
.37162 .58628 m .37318 .58799 L .37857 .58185 L F
.851 .468 .324 r
.38091 .58128 m .37904 .58339 L .3782 .58098 L F
.73 .989 .821 r
.37534 .58339 m .37857 .58185 L .37749 .58144 L F
.821 .392 0 r
.37857 .58185 m .37904 .58339 L .37749 .58144 L F
.883 .479 .039 r
.3782 .58098 m .37865 .58226 L .37749 .58144 L F
.37865 .58226 m .37904 .58339 L .37749 .58144 L F
.324 .754 .972 r
.37611 .58047 m .37749 .58144 L .37985 .5811 L F
.37576 .58041 m .37749 .58144 L .37611 .58047 L F
.548 .782 .985 r
.37904 .58339 m .37985 .5811 L .37762 .58142 L F
.37755 .58152 m .37762 .58142 L .37749 .58144 L F
.37904 .58339 m .37762 .58142 L .37755 .58152 L F
.337 .817 .871 r
.38337 .58272 m .37904 .58339 L .38091 .58128 L F
.219 0 .16 r
.41953 .47312 m .41642 .47595 L .41737 .47419 L F
.88 .541 .042 r
.33237 .52438 m .33292 .52678 L .3313 .5228 L F
.781 .665 .735 r
.36349 .5371 m .36552 .5411 L .36782 .53764 L F
.795 .999 .84 r
.48188 .50291 m .48593 .50039 L .48472 .49945 L F
.811 .962 .908 r
.48472 .49945 m .48593 .50039 L .48896 .49743 L F
0 0 .528 r
.57119 .34457 m .57218 .348 L .57143 .34882 L F
.941 .602 .356 r
.57064 .34381 m .56961 .34615 L .56988 .34277 L F
.57119 .34457 m .5708 .34496 L .57064 .34381 L F
.5708 .34496 m .56961 .34615 L .57064 .34381 L F
.592 .056 0 r
.57143 .34882 m .56945 .34925 L .57123 .34843 L F
.795 .575 .01 r
.57115 .34737 m .57142 .34922 L .57143 .34882 L F
.592 .056 0 r
.57143 .34882 m .57123 .34843 L .57218 .348 L F
.57143 .34882 m .57138 .35032 L .56945 .34925 L F
.795 .575 .01 r
.57131 .34858 m .57138 .35032 L .57142 .34922 L F
.941 .602 .356 r
.57119 .34457 m .57099 .34715 L .5708 .34496 L F
.923 .747 .262 r
.57058 .34444 m .5709 .34608 L .57119 .34457 L F
.5709 .34608 m .57143 .34882 L .57119 .34457 L F
.941 .602 .356 r
.5708 .34496 m .5709 .34608 L .56961 .34615 L F
.5709 .34608 m .57099 .34715 L .57073 .34696 L F
.5709 .34608 m .57073 .34696 L .56961 .34615 L F
.795 .575 .01 r
.57058 .34444 m .57142 .34922 L .57115 .34737 L F
.941 .602 .356 r
.57119 .34457 m .57218 .348 L .57099 .34715 L F
.952 .902 .521 r
.56945 .34925 m .56961 .34615 L .57099 .34715 L F
.795 .575 .01 r
.57093 .34644 m .571 .34716 L .57131 .34858 L F
.571 .34716 m .57123 .34843 L .57131 .34858 L F
.952 .902 .521 r
.57123 .34843 m .57099 .34715 L .57218 .348 L F
.56945 .34925 m .57099 .34715 L .57123 .34843 L F
.795 .575 .01 r
.571 .34716 m .57108 .34816 L .57123 .34843 L F
.57058 .34444 m .57107 .34809 L .57093 .34644 L F
.57107 .34809 m .57108 .34816 L .57093 .34644 L F
.57108 .34816 m .57138 .35032 L .57131 .34858 L F
.164 0 .058 r
.43792 .46224 m .43563 .46322 L .43905 .46063 L F
.215 0 .091 r
.44053 .46113 m .43905 .46063 L .44112 .45931 L F
.44053 .46113 m .43792 .46224 L .43905 .46063 L F
.587 .854 .994 r
.54205 .39004 m .53902 .39151 L .53874 .3911 L F
.935 .558 .234 r
.57329 .35844 m .57398 .36101 L .57609 .36246 L F
.285 .207 .59 r
.5764 .36456 m .57609 .36246 L .57398 .36101 L F
.5764 .36456 m .57831 .36482 L .57609 .36246 L F
.785 .684 .138 r
.33703 .62736 m .33677 .63243 L .3344 .63106 L F
.879 .809 .777 r
.39696 .57301 m .39926 .57493 L .39801 .57085 L F
.824 .784 .815 r
.39801 .57085 m .39926 .57493 L .39996 .57286 L F
.211 0 .18 r
.4626 .4423 m .46564 .43949 L .4646 .44201 L F
.222 0 .253 r
.46564 .43949 m .46712 .44147 L .4646 .44201 L F
.46564 .43949 m .46762 .44044 L .46712 .44147 L F
.454 .244 .504 r
.40486 .57496 m .40664 .57718 L .40677 .5755 L F
.40486 .57496 m .40409 .57792 L .40664 .57718 L F
.054 0 .153 r
.52462 .35907 m .52743 .3575 L .52787 .35493 L F
0 0 .004 r
.52462 .35907 m .52605 .35898 L .52743 .3575 L F
.52462 .35907 m .52449 .36088 L .52605 .35898 L F
0 0 0 r
.30953 .61707 m .31121 .61571 L .308 .61823 L F
.30953 .61707 m .308 .61823 L .30668 .62085 L F
.789 .448 .409 r
.32656 .62134 m .33002 .62245 L .32976 .625 L F
.334 .352 .731 r
.33002 .62245 m .3316 .62623 L .33155 .62541 L F
.904 .569 .399 r
.33002 .62245 m .33155 .62541 L .32976 .625 L F
.589 .019 0 r
.34334 .62184 m .34035 .62029 L .34186 .62113 L F
.973 .672 .382 r
.34186 .62113 m .3436 .62427 L .34334 .62184 L F
0 0 0 r
.44081 .53419 m .44144 .53482 L .44389 .53394 L F
.44081 .53419 m .43951 .5362 L .44144 .53482 L F
.182 0 0 r
.43681 .53711 m .44081 .53419 L .43641 .53397 L F
.43681 .53711 m .43951 .5362 L .44081 .53419 L F
.177 0 0 r
.56337 .386 m .56174 .38728 L .5589 .38767 L F
.55 .04 0 r
.56625 .38712 m .56174 .38728 L .56337 .386 L F
.775 .994 .873 r
.56946 .40229 m .57062 .39986 L .56944 .40227 L F
0 0 0 r
.31355 .61465 m .31121 .61571 L .30953 .61707 L F
.969 .654 .345 r
.37178 .54654 m .37372 .55056 L .37349 .54766 L F
.603 .598 .82 r
.37088 .55267 m .37505 .5546 L .37372 .55056 L F
0 0 0 r
.48022 .41396 m .47966 .41453 L .4784 .41622 L F
.667 .915 .599 r
.48266 .41141 m .47966 .41453 L .48111 .41286 L F
0 0 0 r
.48111 .41286 m .47966 .41453 L .48022 .41396 L F
.511 .844 .559 r
.47966 .41453 m .48154 .41294 L .47846 .41573 L F
.47966 .41453 m .47846 .41573 L .47799 .41616 L F
.667 .915 .599 r
.48266 .41141 m .48154 .41294 L .47966 .41453 L F
0 0 .437 r
.40711 .49138 m .40594 .48918 L .40768 .48951 L F
.584 .078 .016 r
.39793 .58135 m .39709 .58244 L .39461 .58097 L F
.912 .783 .706 r
.62501 .38247 m .62127 .38471 L .62433 .38184 L F
.62501 .38247 m .62395 .38498 L .62127 .38471 L F
.708 .949 .955 r
.62711 .38064 m .62501 .38247 L .6263 .37998 L F
.751 .991 .881 r
.62501 .38247 m .62433 .38184 L .6263 .37998 L F
.77 .705 .791 r
.2946 .56058 m .29638 .56451 L .29203 .56398 L F
.355 0 .151 r
.29638 .56451 m .29277 .56703 L .29203 .56398 L F
.29638 .56451 m .29455 .56719 L .29277 .56703 L F
.788 .712 .781 r
.29932 .56125 m .29638 .56451 L .2946 .56058 L F
.51 .126 .248 r
.29638 .56451 m .29634 .56725 L .29455 .56719 L F
.502 .294 .53 r
.5227 .39258 m .52241 .3957 L .5194 .39637 L F
.374 0 .12 r
.52197 .39696 m .5194 .39637 L .52241 .3957 L F
.52197 .39696 m .51887 .39772 L .5194 .39637 L F
.408 .025 .198 r
.43563 .46322 m .4345 .46602 L .43164 .46647 L F
.354 .014 .243 r
.43792 .46224 m .4345 .46602 L .43563 .46322 L F
.57 .814 .99 r
.39008 .5638 m .38783 .56483 L .38618 .56318 L F
.22 0 0 r
.39008 .5638 m .38618 .56318 L .38783 .56483 L F
.794 .697 .758 r
.29743 .55714 m .29932 .56125 L .2946 .56058 L F
.77 .687 .772 r
.30196 .55776 m .29932 .56125 L .29743 .55714 L F
.847 .787 .793 r
.5053 .48346 m .50492 .47914 L .50215 .48268 L F
.5053 .48346 m .50663 .48111 L .50492 .47914 L F
.84 .756 .77 r
.50215 .48268 m .50311 .48582 L .5053 .48346 L F
.026 0 0 r
.4626 .4423 m .4612 .44435 L .45867 .44533 L F
0 0 0 r
.46357 .44293 m .4626 .4423 L .4646 .44201 L F
.46357 .44293 m .4612 .44435 L .4626 .4423 L F
.619 .397 .558 r
.29505 .5389 m .29812 .53733 L .29458 .53578 L F
.638 .65 .845 r
.26401 .59382 m .26604 .59125 L .2633 .59258 L F
.26401 .59382 m .26777 .59475 L .26604 .59125 L F
.938 .595 .348 r
.40642 .48482 m .40837 .48618 L .40799 .48372 L F
0 0 0 r
.41114 .47892 m .40956 .4818 L .40799 .48372 L F
.604 .907 .635 r
.40956 .4818 m .40642 .48482 L .40799 .48372 L F
.912 .951 .809 r
.42435 .52201 m .42694 .52098 L .42448 .52413 L F
.816 .452 .367 r
.42435 .52201 m .42728 .52351 L .42694 .52098 L F
.624 .933 .966 r
.31585 .67258 m .31967 .67227 L .3186 .67161 L F
.3186 .67161 m .31967 .67227 L .31585 .67258 L F
.881 .765 .73 r
.31654 .67364 m .31967 .67227 L .31585 .67258 L F
.777 .888 .473 r
.52448 .38893 m .52287 .39158 L .5227 .39258 L F
.285 .114 .466 r
.52453 .39432 m .5227 .39258 L .52287 .39158 L F
.52453 .39432 m .52241 .3957 L .5227 .39258 L F
.924 .967 .669 r
.55578 .41373 m .55575 .41623 L .55777 .41248 L F
.706 .937 .628 r
.55777 .41248 m .56052 .40921 L .55897 .41029 L F
.715 .959 .689 r
.55578 .41373 m .55777 .41248 L .55897 .41029 L F
.223 0 .318 r
.28818 .63867 m .28544 .64235 L .28748 .64131 L F
.059 0 .012 r
.28748 .64131 m .28544 .64235 L .28405 .64436 L F
.239 0 0 r
.66435 .34976 m .66351 .34941 L .66228 .35007 L F
.083 .266 .752 r
.58707 .38262 m .58939 .38441 L .58787 .38033 L F
.679 .561 .715 r
.32179 .61095 m .32349 .60872 L .32048 .60871 L F
.242 0 0 r
.50375 .39464 m .50813 .39274 L .50417 .39502 L F
.50375 .39464 m .50657 .39429 L .50813 .39274 L F
0 0 0 r
.51075 .3892 m .50813 .39274 L .5099 .39085 L F
.426 .158 .403 r
.50657 .39429 m .5099 .39085 L .50813 .39274 L F
.278 .163 .538 r
.26639 .57118 m .26823 .57075 L .26767 .56802 L F
.313 .288 .671 r
.26639 .57118 m .26857 .57298 L .26823 .57075 L F
.458 .282 .555 r
.26618 .57367 m .26857 .57298 L .26639 .57118 L F
.514 .342 .586 r
.50673 .41968 m .50692 .42241 L .50995 .41931 L F
.766 .908 .937 r
.47902 .48397 m .47424 .48511 L .47743 .48273 L F
.341 .102 .398 r
.63446 .39157 m .63384 .38956 L .63634 .38831 L F
0 0 .484 r
.58266 .36237 m .58381 .36032 L .58325 .35743 L F
.998 .789 .491 r
.58266 .36237 m .58331 .36243 L .58381 .36032 L F
.58266 .36237 m .58221 .36498 L .58108 .36313 L F
.58266 .36237 m .58108 .36313 L .58331 .36243 L F
0 0 .221 r
.58793 .38921 m .58943 .38978 L .58991 .38751 L F
.58793 .38921 m .58751 .39197 L .58943 .38978 L F
.746 .934 .949 r
.57943 .366 m .58108 .36313 L .58221 .36498 L F
.57943 .366 m .57831 .36482 L .58108 .36313 L F
.759 .66 .753 r
.50435 .42613 m .50863 .42647 L .50692 .42241 L F
.916 .956 .802 r
.5054 .42854 m .50863 .42647 L .50435 .42613 L F
.765 .677 .765 r
.45104 .52334 m .45015 .51948 L .4518 .52066 L F
.878 .897 .841 r
.45452 .51734 m .4518 .52066 L .45015 .51948 L F
.864 .995 .81 r
.54453 .42021 m .54616 .42044 L .54475 .42186 L F
.708 .984 .885 r
.54805 .41879 m .54616 .42044 L .54453 .42021 L F
.723 .642 .768 r
.36086 .54045 m .36552 .5411 L .36349 .5371 L F
.419 .51 .845 r
.36086 .54045 m .36435 .54384 L .36552 .5411 L F
0 0 .121 r
.52787 .35493 m .52926 .3558 L .53101 .35413 L F
.52787 .35493 m .52743 .3575 L .52926 .3558 L F
.36 .694 .982 r
.36789 .57733 m .36935 .57869 L .37179 .5786 L F
.913 .903 .801 r
.30259 .63251 m .30431 .63421 L .30599 .63123 L F
.44 .238 .508 r
.33737 .66444 m .33514 .66447 L .33434 .66244 L F
.328 .813 .851 r
.31267 .64487 m .31355 .64495 L .3105 .64566 L F
.093 0 .13 r
.30971 .64797 m .3105 .64566 L .31267 .64487 L F
.328 .813 .851 r
.31267 .64487 m .3105 .64566 L .30971 .64797 L F
.716 .804 .919 r
.6666 .36555 m .66761 .36684 L .67065 .36573 L F
.82 .473 .399 r
.34928 .64053 m .35133 .63795 L .34955 .63842 L F
.88 .723 .683 r
.34928 .64053 m .35353 .63778 L .35133 .63795 L F
.794 .713 .775 r
.52806 .38482 m .52305 .38465 L .52569 .3841 L F
0 .547 .806 r
.52806 .38482 m .52569 .3841 L .5283 .38471 L F
.951 .753 .599 r
.42433 .54359 m .42572 .54748 L .42365 .54654 L F
.939 .946 .763 r
.42572 .54748 m .42308 .54848 L .42365 .54654 L F
.42572 .54748 m .42338 .55142 L .42308 .54848 L F
.668 .208 .152 r
.42433 .54359 m .4286 .54412 L .42572 .54748 L F
.923 .669 .536 r
.33975 .54406 m .34159 .54759 L .33927 .54666 L F
.904 .616 .488 r
.34159 .54759 m .3392 .54947 L .33927 .54666 L F
.34159 .54759 m .34157 .55033 L .3392 .54947 L F
.55 .62 .874 r
.26777 .59475 m .26852 .59089 L .26604 .59125 L F
.26777 .59475 m .27027 .59416 L .26852 .59089 L F
.722 .768 .889 r
.50663 .48111 m .50908 .4798 L .50492 .47914 L F
.074 .495 .896 r
.31696 .67578 m .3204 .67713 L .31779 .67504 L F
.652 .657 .842 r
.28754 .54078 m .28902 .53658 L .28818 .53804 L F
.919 .595 .126 r
.66482 .358 m .66573 .36236 L .66632 .36224 L F
.865 .456 0 r
.66573 .36236 m .66667 .36458 L .66632 .36224 L F
.384 .813 .644 r
.66632 .36224 m .66777 .36134 L .66931 .36048 L F
0 0 .192 r
.66632 .36224 m .6681 .36294 L .66777 .36134 L F
.66632 .36224 m .66667 .36458 L .6681 .36294 L F
.841 .998 .826 r
.42075 .55426 m .42097 .55202 L .42338 .55142 L F
0 0 .4 r
.42075 .55426 m .42163 .55528 L .42097 .55202 L F
0 .01 .519 r
.4212 .55748 m .42204 .55666 L .42075 .55426 L F
.983 .698 .361 r
.42163 .55528 m .42034 .55742 L .42181 .55497 L F
.946 .946 .746 r
.42338 .55142 m .42097 .55202 L .42308 .54848 L F
0 0 .11 r
.42163 .55528 m .42255 .55373 L .42285 .55086 L F
.983 .698 .361 r
.42163 .55528 m .42181 .55497 L .42255 .55373 L F
0 0 .4 r
.42075 .55426 m .42145 .55557 L .42163 .55528 L F
.42145 .55557 m .42204 .55666 L .42163 .55528 L F
.77 .69 .774 r
.42875 .55277 m .43207 .55418 L .43068 .5522 L F
.835 .523 .462 r
.42988 .55641 m .43207 .55418 L .42875 .55277 L F
.798 .542 .551 r
.43207 .55418 m .43296 .55033 L .43068 .5522 L F
.797 .523 .523 r
.43278 .55541 m .43207 .55418 L .42988 .55641 L F
.279 .732 .956 r
.3726 .48242 m .3749 .48227 L .37562 .48304 L F
.758 .433 .434 r
.3749 .48227 m .37995 .48081 L .37562 .48304 L F
0 0 0 r
.47454 .41876 m .47162 .42236 L .47385 .42107 L F
.47799 .41616 m .47454 .41876 L .4767 .41779 L F
.4767 .41779 m .47454 .41876 L .47385 .42107 L F
.54 .852 .998 r
.35907 .53932 m .36072 .53771 L .35806 .53719 L F
.35907 .53932 m .36086 .54045 L .36072 .53771 L F
.592 .456 .664 r
.36072 .53771 m .36086 .54045 L .36349 .5371 L F
.787 .815 .874 r
.64129 .35844 m .64099 .36194 L .63751 .3608 L F
.921 .965 .784 r
.63911 .36561 m .63697 .36589 L .63919 .3622 L F
0 0 0 r
.63866 .36338 m .63898 .3632 L .63919 .3622 L F
.946 .957 .671 r
.64099 .36194 m .63911 .36561 L .63919 .3622 L F
.782 .278 0 r
.64129 .35844 m .64397 .36068 L .64099 .36194 L F
0 0 0 r
.63898 .3632 m .6421 .36144 L .63919 .3622 L F
.946 .957 .671 r
.63936 .36141 m .63919 .3622 L .63751 .3608 L F
.64099 .36194 m .63919 .3622 L .63936 .36141 L F
.098 0 .165 r
.40397 .56362 m .4011 .56698 L .40192 .56478 L F
.516 .594 .87 r
.26497 .58144 m .26936 .58492 L .26766 .58025 L F
.497 .484 .773 r
.26766 .58025 m .26936 .58492 L .2713 .58298 L F
0 0 .16 r
.29015 .63488 m .28818 .63867 L .28921 .63777 L F
0 0 .158 r
.28921 .63777 m .28818 .63867 L .28748 .64131 L F
.976 .751 .532 r
.34186 .49217 m .34276 .49351 L .34408 .4932 L F
.34408 .4932 m .34276 .49351 L .34186 .49217 L F
.451 .868 .731 r
.62137 .34482 m .62065 .34567 L .62315 .34374 L F
.62137 .34482 m .61904 .34621 L .62065 .34567 L F
.709 .316 0 r
.55009 .40894 m .5524 .41383 L .55287 .40825 L F
.541 .357 .581 r
.32655 .65535 m .32681 .65884 L .32386 .65876 L F
.32386 .65876 m .32681 .65884 L .32655 .65535 L F
.613 .161 .155 r
.39918 .48626 m .40173 .48712 L .39724 .48682 L F
.558 .732 .957 r
.29047 .66653 m .29168 .66442 L .28924 .66479 L F
.29047 .66653 m .29314 .666 L .29168 .66442 L F
.848 .8 .804 r
.51718 .43761 m .51832 .43977 L .51433 .43946 L F
.807 .879 .898 r
.51832 .43977 m .51324 .44115 L .51433 .43946 L F
0 0 0 r
.51075 .3892 m .51178 .38967 L .5116 .3868 L F
.51075 .3892 m .5099 .39085 L .51178 .38967 L F
.727 .985 .899 r
.53217 .45629 m .53151 .45554 L .52783 .45807 L F
.935 .951 .626 r
.53343 .45129 m .53217 .45629 L .53478 .45232 L F
.53343 .45129 m .53151 .45554 L .53217 .45629 L F
.745 .479 .528 r
.51954 .43236 m .51976 .43053 L .51952 .4296 L F
.878 .897 .841 r
.45452 .51734 m .45015 .51948 L .45289 .51606 L F
.848 .995 .758 r
.56111 .40626 m .56052 .40921 L .56325 .4057 L F
.85 .956 .613 r
.55897 .41029 m .56052 .40921 L .56111 .40626 L F
.831 .55 .512 r
.61708 .33924 m .62181 .33853 L .61943 .33954 L F
.841 .734 .745 r
.63653 .37494 m .63228 .37714 L .6354 .37363 L F
.63653 .37494 m .6348 .37899 L .63228 .37714 L F
.859 .854 .836 r
.30647 .67484 m .30649 .67052 L .30452 .67194 L F
.30647 .67484 m .30859 .67239 L .30649 .67052 L F
.362 .117 .402 r
.30856 .67484 m .30859 .67239 L .30647 .67484 L F
.861 .756 .746 r
.31121 .55699 m .30893 .56065 L .31269 .56089 L F
.827 .66 .676 r
.30834 .56315 m .31269 .56089 L .30893 .56065 L F
.30834 .56315 m .31201 .56386 L .31269 .56089 L F
.838 .902 .883 r
.49777 .49259 m .49935 .48881 L .49656 .49193 L F
.49777 .49259 m .50068 .48988 L .49935 .48881 L F
0 0 0 r
.59722 .38741 m .59606 .38933 L .59782 .38602 L F
.59913 .38564 m .59782 .38602 L .60037 .38483 L F
.59913 .38564 m .59722 .38741 L .59782 .38602 L F
.325 0 .171 r
.41408 .47701 m .41319 .47849 L .41114 .47892 L F
.2 0 .124 r
.41642 .47595 m .41319 .47849 L .41408 .47701 L F
.858 .788 .781 r
.48705 .47348 m .48253 .47536 L .48526 .4717 L F
.48705 .47348 m .48474 .4773 L .48253 .47536 L F
.739 .838 .925 r
.48884 .47136 m .48705 .47348 L .48526 .4717 L F
.757 .555 .623 r
.54246 .3476 m .54633 .34558 L .54321 .3455 L F
.254 0 0 r
.39891 .47374 m .40075 .47435 L .40251 .47242 L F
.271 0 0 r
.40075 .47435 m .40518 .47177 L .40251 .47242 L F
.699 .634 .78 r
.57076 .35231 m .57148 .35593 L .57069 .35448 L F
.204 .28 .72 r
.57281 .35371 m .57148 .35593 L .57076 .35231 L F
0 .048 .612 r
.57265 .3564 m .57148 .35593 L .57281 .35371 L F
0 0 0 r
.47966 .41453 m .47799 .41616 L .4767 .41779 L F
.462 .298 .572 r
.31524 .63794 m .31465 .64072 L .31299 .63953 L F
.39 .8 .98 r
.37503 .57363 m .37755 .57325 L .37908 .57386 L F
.631 .902 .985 r
.37908 .57386 m .38114 .57179 L .38146 .57299 L F
.37908 .57386 m .37755 .57325 L .38114 .57179 L F
.648 .094 0 r
.63014 .34265 m .62898 .34331 L .6262 .3411 L F
.843 .846 .382 r
.63174 .34029 m .63129 .34191 L .63167 .34224 L F
0 0 0 r
.63167 .34224 m .63014 .34265 L .63202 .34256 L F
.578 .281 .428 r
.6262 .3411 m .62898 .34331 L .62609 .34255 L F
.108 0 0 r
.62898 .34331 m .62494 .34347 L .62609 .34255 L F
.368 0 0 r
.63167 .34224 m .62768 .34368 L .62898 .34331 L F
.63153 .34229 m .63084 .3435 L .62768 .34368 L F
.63167 .34224 m .63084 .3435 L .63153 .34229 L F
.782 .512 .527 r
.62935 .34358 m .62636 .34594 L .62768 .34368 L F
.63084 .3435 m .62981 .34407 L .62935 .34358 L F
.62981 .34407 m .62636 .34594 L .62935 .34358 L F
.63084 .3435 m .63118 .34655 L .62636 .34594 L F
0 .038 .606 r
.6294 .34162 m .63038 .34432 L .63084 .3435 L F
.63038 .34432 m .63118 .34655 L .63084 .3435 L F
.63022 .34335 m .63144 .34454 L .6313 .34565 L F
.6294 .34162 m .6313 .34565 L .63059 .34489 L F
.214 .528 .92 r
.63144 .34454 m .63233 .34629 L .63118 .34655 L F
.082 .565 .901 r
.634 .34601 m .63233 .34629 L .63144 .34454 L F
.588 .023 0 r
.63144 .34454 m .63048 .34517 L .63261 .34568 L F
.63144 .34454 m .63261 .34568 L .634 .34601 L F
0 .038 .606 r
.6294 .34162 m .63144 .34454 L .63022 .34335 L F
.63059 .34489 m .6313 .34565 L .63118 .34655 L F
.843 .846 .382 r
.63129 .34191 m .63084 .3435 L .63167 .34224 L F
0 0 0 r
.63167 .34224 m .63202 .34256 L .63282 .34252 L F
.744 .491 .548 r
.31265 .67414 m .30859 .67239 L .30856 .67484 L F
.758 .433 .434 r
.3749 .48227 m .37747 .48289 L .37995 .48081 L F
.102 0 0 r
.37995 .48081 m .3818 .4809 L .38241 .48032 L F
.492 .463 .753 r
.37016 .54723 m .37372 .55056 L .37178 .54654 L F
.837 .753 .77 r
.53565 .4116 m .53756 .41505 L .53334 .41497 L F
.459 .583 .89 r
.54001 .41468 m .53756 .41505 L .53565 .4116 L F
.959 .827 .67 r
.33155 .62541 m .3316 .62623 L .33008 .62773 L F
.421 .268 .567 r
.32894 .65767 m .32681 .65884 L .32655 .65535 L F
.32655 .65535 m .32681 .65884 L .32894 .65767 L F
.52 .801 .997 r
.39293 .57965 m .39461 .58097 L .39562 .5791 L F
.054 .208 .706 r
.39461 .58097 m .39706 .58338 L .39562 .5791 L F
.693 .553 .691 r
.49349 .42301 m .49061 .42605 L .49063 .42326 L F
.904 .938 .571 r
.40594 .48918 m .40374 .4927 L .40388 .49111 L F
.782 .495 .501 r
.40681 .49237 m .40374 .4927 L .40594 .48918 L F
.227 .036 .4 r
.40594 .48918 m .40794 .48953 L .40837 .48618 L F
.689 .204 .093 r
.40594 .48918 m .40711 .49138 L .40794 .48953 L F
0 0 .437 r
.40711 .49138 m .40681 .49237 L .40594 .48918 L F
.689 .204 .093 r
.40594 .48918 m .40388 .49111 L .40711 .49138 L F
.229 0 0 r
.40594 .48918 m .40388 .49111 L .40794 .48953 L F
.754 .566 .642 r
.43392 .5367 m .43641 .53397 L .4321 .5335 L F
.624 .377 .524 r
.43392 .5367 m .43681 .53711 L .43641 .53397 L F
.836 .922 .891 r
.54299 .42404 m .5389 .42551 L .5415 .42293 L F
.886 .934 .844 r
.54475 .42186 m .54299 .42404 L .5415 .42293 L F
.826 .906 .895 r
.48474 .4773 m .47994 .47894 L .48253 .47536 L F
.09 0 0 r
.42009 .46184 m .42332 .45923 L .42101 .46031 L F
.819 .743 .78 r
.63228 .37714 m .6348 .37899 L .631 .37858 L F
.695 .836 .951 r
.33008 .62773 m .32782 .62955 L .32563 .62756 L F
.986 .743 .48 r
.65715 .34706 m .65762 .35028 L .65899 .34832 L F
.739 .371 .355 r
.3027 .63143 m .30556 .63006 L .29976 .62953 L F
.913 .903 .801 r
.30537 .63047 m .30599 .63123 L .30575 .63019 L F
.30259 .63251 m .30575 .63132 L .30537 .63047 L F
.30575 .63132 m .30599 .63123 L .30537 .63047 L F
.784 .629 .689 r
.29976 .62953 m .30556 .63006 L .3027 .62662 L F
0 .292 .79 r
.3027 .62662 m .30556 .63006 L .30565 .62888 L F
.836 .938 .569 r
.30565 .62888 m .30556 .63006 L .30533 .63036 L F
.913 .903 .801 r
.30259 .63251 m .30575 .63019 L .30572 .6302 L F
.30572 .6302 m .30575 .63019 L .30575 .63018 L F
.278 .044 .368 r
.30423 .63308 m .30259 .63251 L .30575 .63018 L F
.739 .371 .355 r
.30388 .63219 m .30533 .63036 L .3027 .63143 L F
.30533 .63036 m .30556 .63006 L .3027 .63143 L F
.836 .938 .569 r
.30511 .62988 m .30533 .63036 L .30388 .63219 L F
.30565 .62888 m .30533 .63036 L .30511 .62988 L F
.451 .799 .998 r
.37777 .56853 m .37818 .56707 L .37616 .56675 L F
.37777 .56853 m .38102 .56828 L .37818 .56707 L F
.438 0 0 r
.55302 .34431 m .54936 .34407 L .55026 .34556 L F
.863 .935 .868 r
.53622 .44828 m .53478 .45232 L .5379 .44973 L F
.53622 .44828 m .53343 .45129 L .53478 .45232 L F
.389 .637 .954 r
.52342 .39917 m .52241 .3957 L .52453 .39432 L F
.52342 .39917 m .52197 .39696 L .52256 .3962 L F
.52342 .39917 m .52444 .39697 L .52197 .39696 L F
.786 .517 .53 r
.52444 .39697 m .52047 .3989 L .52197 .39696 L F
.52047 .3989 m .52022 .39902 L .52197 .39696 L F
.389 .637 .954 r
.52256 .3962 m .52197 .39696 L .52241 .3957 L F
0 0 .094 r
.49819 .4183 m .49599 .42199 L .49672 .41973 L F
.465 .264 .523 r
.26604 .59125 m .26852 .59089 L .26547 .58932 L F
.134 0 0 r
.26852 .59089 m .27119 .59012 L .27316 .58792 L F
.49 .815 1 r
.27375 .58636 m .27592 .58744 L .27316 .58792 L F
.27411 .58639 m .27592 .58744 L .27375 .58636 L F
0 .139 .683 r
.27549 .59035 m .27316 .58792 L .27592 .58744 L F
.495 .817 1 r
.2738 .58621 m .27817 .58672 L .27592 .58744 L F
.481 .284 .536 r
.27817 .58672 m .27549 .59035 L .27592 .58744 L F
.27817 .58672 m .27807 .58972 L .27549 .59035 L F
.761 .516 .563 r
.27358 .58744 m .27807 .58972 L .27817 .58673 L F
.27811 .58673 m .27817 .58673 L .27817 .58672 L F
.27358 .58744 m .27817 .58673 L .27811 .58673 L F
.49 .815 1 r
.2738 .58621 m .27411 .58639 L .27375 .58636 L F
.734 .91 .54 r
.27316 .58792 m .27119 .59012 L .2738 .58621 L F
.616 .758 .947 r
.42302 .522 m .42435 .52201 L .42448 .52413 L F
.514 .675 .938 r
.42435 .52201 m .42728 .52351 L .42448 .52413 L F
.715 .376 0 r
.4243 .52405 m .42448 .52413 L .42302 .522 L F
.745 .479 .528 r
.51954 .43236 m .52389 .43202 L .51976 .43053 L F
.476 0 0 r
.52521 .43378 m .52389 .43202 L .52213 .43412 L F
.475 .122 .286 r
.52383 .4358 m .52521 .43378 L .52213 .43412 L F
.807 .923 .539 r
.52444 .43447 m .52521 .43378 L .52383 .4358 L F
.476 0 0 r
.52521 .43378 m .52649 .43266 L .52389 .43202 L F
.807 .923 .539 r
.52585 .43136 m .52521 .43378 L .52444 .43447 L F
.476 0 0 r
.52521 .43378 m .5268 .43273 L .52649 .43266 L F
.584 .585 .819 r
.28512 .65872 m .28618 .65428 L .28347 .65495 L F
.28512 .65872 m .2878 .65818 L .28618 .65428 L F
.625 .517 .711 r
.28533 .66145 m .2878 .65818 L .28512 .65872 L F
.598 .346 .506 r
.40162 .58297 m .40456 .5826 L .40561 .58046 L F
.75 .581 .666 r
.40456 .5826 m .40834 .58109 L .40561 .58046 L F
.722 .893 .958 r
.56457 .39537 m .56073 .39548 L .56319 .39407 L F
.634 .865 .985 r
.56668 .39433 m .56457 .39537 L .56319 .39407 L F
.854 .723 .718 r
.63634 .38831 m .63773 .39275 L .63446 .39157 L F
.719 .195 0 r
.63446 .39157 m .63773 .39275 L .63615 .39326 L F
.779 .686 .761 r
.64048 .3888 m .63773 .39275 L .63634 .38831 L F
.501 .862 .988 r
.63773 .39275 m .63992 .39098 L .63615 .39326 L F
.63773 .39275 m .64074 .39187 L .63992 .39098 L F
.812 .71 .753 r
.4168 .5709 m .4178 .57402 L .41439 .57245 L F
.82 .377 .186 r
.4178 .57402 m .41706 .57619 L .41439 .57245 L F
.85 .605 .568 r
.4212 .57428 m .41706 .57619 L .4178 .57402 L F
.166 .683 .89 r
.44432 .5423 m .44106 .54177 L .44227 .54323 L F
.673 .866 .972 r
.44227 .54323 m .44106 .54177 L .43797 .54316 L F
.918 .922 .539 r
.55465 .41879 m .55575 .41623 L .55578 .41373 L F
.738 .526 .606 r
.51071 .44924 m .51071 .4526 L .51147 .4501 L F
.91 .886 .796 r
.51224 .40146 m .51622 .39897 L .51615 .40074 L F
0 0 0 r
.51887 .39772 m .51615 .40074 L .51622 .39897 L F
.803 .722 .775 r
.67065 .36573 m .67388 .36154 L .67084 .36074 L F
.793 .766 .829 r
.35698 .54077 m .35379 .54345 L .35818 .5441 L F
.739 .494 .558 r
.35551 .54679 m .35818 .5441 L .35379 .54345 L F
.35551 .54679 m .35827 .54693 L .35818 .5441 L F
.613 .776 .959 r
.5541 .37363 m .56044 .37239 L .55877 .3711 L F
.5541 .37363 m .55981 .37506 L .56044 .37239 L F
.694 .481 .595 r
.56044 .37239 m .562 .36906 L .55877 .3711 L F
.53 .877 .632 r
.55981 .37506 m .56301 .37247 L .56044 .37239 L F
.023 0 .043 r
.49271 .4248 m .49061 .42605 L .49349 .42301 L F
.204 0 .128 r
.49271 .4248 m .49349 .42301 L .49599 .42199 L F
.886 .934 .844 r
.54475 .42186 m .5415 .42293 L .54453 .42021 L F
.668 .208 .152 r
.42433 .54359 m .42687 .54592 L .4286 .54412 L F
0 0 0 r
.4286 .54412 m .42945 .53945 L .42582 .54374 L F
.4286 .54412 m .43127 .54066 L .42945 .53945 L F
.4286 .54412 m .43072 .54255 L .43127 .54066 L F
.563 .316 .5 r
.42687 .54592 m .43072 .54255 L .4286 .54412 L F
.866 .768 .751 r
.50215 .48268 m .49978 .486 L .50311 .48582 L F
.916 .889 .79 r
.49935 .48881 m .50311 .48582 L .49978 .486 L F
.49935 .48881 m .50068 .48988 L .50311 .48582 L F
0 0 0 r
.48977 .42757 m .49061 .42605 L .49271 .4248 L F
.913 .78 .701 r
.62127 .38471 m .62395 .38498 L .62252 .38864 L F
0 .444 .8 r
.3357 .67486 m .33785 .67572 L .33597 .67467 L F
0 0 0 r
.33785 .67572 m .33969 .67187 L .34039 .67495 L F
.52 .84 .999 r
.33597 .67467 m .33785 .67572 L .34039 .67495 L F
.716 .804 .919 r
.6666 .36555 m .67065 .36573 L .66927 .36419 L F
.803 .722 .775 r
.67065 .36573 m .67084 .36074 L .66927 .36419 L F
.407 .133 .382 r
.50238 .42424 m .50026 .42287 L .50003 .42518 L F
.50238 .42424 m .50394 .42212 L .50026 .42287 L F
.527 0 0 r
.50026 .42287 m .50238 .42424 L .50003 .42518 L F
.311 0 0 r
.51224 .40146 m .50848 .40175 L .5089 .401 L F
0 0 0 r
.5966 .38982 m .59606 .38933 L .59722 .38741 L F
.5966 .38982 m .59536 .39201 L .59606 .38933 L F
.548 .03 0 r
.52894 .3964 m .53398 .39576 L .52881 .39604 L F
.52894 .3964 m .5312 .39697 L .53398 .39576 L F
.863 .815 .8 r
.5312 .39697 m .53555 .3948 L .53398 .39576 L F
.719 .972 .93 r
.56478 .40359 m .56325 .4057 L .56568 .40306 L F
.716 .983 .791 r
.56111 .40626 m .56325 .4057 L .56478 .40359 L F
.005 0 0 r
.44495 .44277 m .44611 .4437 L .44694 .44155 L F
.44495 .44277 m .44385 .44494 L .44611 .4437 L F
.835 .869 .869 r
.32696 .67649 m .3307 .67528 L .32939 .67574 L F
.585 .839 .993 r
.3307 .67528 m .33315 .67507 L .33341 .67453 L F
.33315 .67507 m .3357 .67486 L .33341 .67453 L F
.667 .862 .471 r
.33341 .67453 m .33405 .67328 L .33391 .67349 L F
0 0 0 r
.32939 .67574 m .3307 .67528 L .33341 .67453 L F
.32939 .67574 m .33341 .67453 L .33159 .67695 L F
.667 .862 .471 r
.33341 .67453 m .33391 .67349 L .33159 .67695 L F
.936 .86 .741 r
.35175 .64869 m .35125 .64454 L .34994 .64784 L F
.973 .733 .516 r
.35157 .65063 m .35175 .64869 L .34994 .64784 L F
.905 .845 .774 r
.35175 .64869 m .35324 .64564 L .35125 .64454 L F
.93 .956 .775 r
.64763 .3525 m .64528 .35363 L .64583 .35091 L F
.53 .877 .632 r
.55981 .37506 m .56157 .37335 L .56301 .37247 L F
.647 .923 .638 r
.56301 .37247 m .56443 .37042 L .56612 .37178 L F
.56301 .37247 m .56157 .37335 L .56443 .37042 L F
.823 1 .805 r
.31495 .64335 m .31355 .64495 L .31267 .64487 L F
.886 .983 .817 r
.63911 .36561 m .63648 .36897 L .63697 .36589 L F
.892 .985 .802 r
.63648 .36897 m .6343 .36966 L .63697 .36589 L F
.801 .666 .715 r
.30391 .54323 m .30839 .54067 L .30385 .54023 L F
.30391 .54323 m .30775 .54381 L .30839 .54067 L F
0 .155 .605 r
.32585 .61557 m .32803 .61726 L .32459 .61482 L F
.79 .74 .807 r
.57398 .36101 m .57107 .36441 L .5764 .36456 L F
.774 .997 .847 r
.5712 .36727 m .56952 .36732 L .5712 .36579 L F
.367 .207 .528 r
.57107 .36441 m .5712 .36727 L .57346 .36543 L F
.774 .997 .847 r
.57196 .36558 m .5712 .36579 L .57233 .36477 L F
.5712 .36727 m .5712 .36579 L .57196 .36558 L F
.439 0 0 r
.57581 .36454 m .57346 .36543 L .5764 .36456 L F
.57107 .36441 m .5731 .36528 L .57581 .36454 L F
.5731 .36528 m .57346 .36543 L .57581 .36454 L F
.359 .824 .749 r
.5764 .36456 m .57621 .36423 L .57831 .36482 L F
.5764 .36456 m .57346 .36543 L .57621 .36423 L F
.234 0 .096 r
.54416 .38531 m .54689 .38439 L .54763 .3821 L F
0 0 .007 r
.54763 .3821 m .54904 .38281 L .55013 .38119 L F
.54763 .3821 m .54689 .38439 L .54904 .38281 L F
.923 .752 .651 r
.32976 .625 m .33155 .62541 L .33008 .62773 L F
.886 .465 .068 r
.64549 .34931 m .6442 .34954 L .64202 .3468 L F
.64549 .34931 m .64583 .35091 L .6442 .34954 L F
.916 .775 .689 r
.42988 .55641 m .43194 .55822 L .43278 .55541 L F
.194 0 .026 r
.41319 .47849 m .40956 .4818 L .41114 .47892 L F
.724 .656 .782 r
.26575 .58046 m .26497 .58144 L .26766 .58025 L F
.756 .755 .851 r
.36072 .57762 m .36288 .58098 L .35846 .58054 L F
.724 .314 .27 r
.36288 .58098 m .36104 .58342 L .35846 .58054 L F
.205 .466 .884 r
.3639 .58066 m .36288 .58098 L .36072 .57762 L F
.758 .503 .546 r
.3639 .58066 m .36104 .58342 L .36288 .58098 L F
.797 .544 .554 r
.43314 .53916 m .42945 .53945 L .43127 .54066 L F
0 0 0 r
.43072 .54255 m .43314 .53916 L .43127 .54066 L F
.839 .761 .777 r
.42557 .53073 m .42112 .53043 L .42429 .52921 L F
.42557 .53073 m .42102 .53268 L .42112 .53043 L F
.42557 .53073 m .42315 .53418 L .42102 .53268 L F
.772 .359 .268 r
.4243 .53166 m .42557 .53073 L .42429 .52921 L F
.4243 .53166 m .42786 .53069 L .42557 .53073 L F
.869 .427 .121 r
.52568 .36718 m .52277 .36547 L .52276 .36793 L F
.49 .252 .48 r
.52568 .36718 m .52277 .36547 L .52606 .36544 L F
.869 .427 .121 r
.52568 .36718 m .52275 .36381 L .52277 .36547 L F
.49 .252 .48 r
.52568 .36718 m .52276 .36793 L .52277 .36547 L F
.824 .881 .885 r
.5126 .47142 m .51093 .4729 L .51448 .47276 L F
.788 .908 .924 r
.51093 .4729 m .51197 .474 L .51448 .47276 L F
.821 .881 .888 r
.5126 .47142 m .51448 .47276 L .5174 .46973 L F
.769 .82 .893 r
.53599 .41746 m .53828 .42241 L .54004 .41779 L F
.002 0 .08 r
.54168 .38646 m .54323 .3863 L .54416 .38531 L F
.54168 .38646 m .54118 .38807 L .54323 .3863 L F
.918 .824 .737 r
.29932 .5541 m .29743 .55714 L .29856 .55468 L F
.952 .746 .589 r
.37393 .48667 m .37222 .48697 L .3726 .48242 L F
.395 0 0 r
.37393 .48667 m .37354 .48743 L .37222 .48697 L F
.003 0 0 r
.37682 .48713 m .37354 .48743 L .37393 .48667 L F
.858 .686 .667 r
.30963 .55019 m .30881 .55355 L .31134 .55412 L F
.808 .593 .611 r
.30881 .55355 m .31121 .55699 L .31134 .55412 L F
0 .444 .8 r
.3357 .67486 m .33597 .67467 L .33341 .67453 L F
.222 .576 .942 r
.29729 .66927 m .30208 .67183 L .30136 .67056 L F
.293 .602 .951 r
.30136 .67056 m .30208 .67183 L .30452 .67194 L F
.808 .598 .618 r
.30391 .54323 m .30581 .54669 L .30775 .54381 L F
.652 .657 .842 r
.28754 .54078 m .2902 .5406 L .28902 .53658 L F
.549 .391 .619 r
.28754 .54078 m .29065 .54311 L .2902 .5406 L F
.28754 .54078 m .28761 .54375 L .29065 .54311 L F
.071 0 .021 r
.37725 .56489 m .37616 .56675 L .37876 .56433 L F
.831 .77 .794 r
.30161 .58002 m .3065 .57814 L .30436 .57658 L F
.30161 .58002 m .30384 .58137 L .3065 .57814 L F
0 0 0 r
.45325 .44882 m .45637 .44641 L .45581 .4481 L F
.178 0 .154 r
.45581 .4481 m .45637 .44641 L .45867 .44533 L F
.75 .581 .666 r
.40456 .5826 m .40827 .58395 L .40834 .58109 L F
.938 .78 .66 r
.42237 .53702 m .42102 .53268 L .42315 .53418 L F
.42237 .53702 m .41874 .53788 L .42102 .53268 L F
.907 .855 .779 r
.42237 .53702 m .4183 .5386 L .41874 .53788 L F
.42237 .53702 m .42011 .54018 L .4183 .5386 L F
.924 .866 .763 r
.53622 .44828 m .53972 .44591 L .53832 .44489 L F
.53622 .44828 m .5379 .44973 L .53972 .44591 L F
0 0 .336 r
.57069 .35448 m .57117 .35335 L .57076 .35231 L F
0 .035 .583 r
.57069 .35448 m .57265 .3564 L .57117 .35335 L F
.022 .04 .538 r
.57093 .35816 m .57265 .3564 L .57069 .35448 L F
.004 0 0 r
.41443 .46582 m .41647 .46503 L .4178 .46312 L F
.2 0 .046 r
.41647 .46503 m .42009 .46184 L .4178 .46312 L F
.535 .566 .832 r
.3344 .63106 m .3317 .63162 L .33008 .62773 L F
0 0 0 r
.29572 .63023 m .29611 .62895 L .29293 .63153 L F
.217 0 0 r
.29884 .62912 m .29611 .62895 L .29572 .63023 L F
.29884 .62912 m .29869 .62813 L .29611 .62895 L F
.552 .163 .257 r
.28532 .56453 m .28728 .56693 L .28462 .56639 L F
.424 .146 .385 r
.2881 .56373 m .28728 .56693 L .28532 .56453 L F
.821 .385 .203 r
.42786 .53069 m .4321 .5335 L .43251 .5305 L F
.196 .424 .855 r
.33741 .65892 m .33838 .65704 L .33637 .65956 L F
.33741 .65892 m .34061 .66028 L .33838 .65704 L F
.724 .656 .782 r
.26575 .58046 m .26766 .58025 L .26754 .57917 L F
.614 .625 .838 r
.26754 .57917 m .26766 .58025 L .26982 .57805 L F
.947 .663 .468 r
.27508 .5732 m .275 .5761 L .27718 .57465 L F
.27508 .5732 m .275 .5761 L .27718 .57465 L F
.501 .276 .504 r
.27508 .5732 m .275 .5761 L .27534 .57594 L F
.27508 .5732 m .27534 .57594 L .27773 .57483 L F
.951 .65 .213 r
.27497 .57208 m .27508 .5732 L .27356 .56934 L F
.27593 .57395 m .27508 .5732 L .27497 .57208 L F
.871 .482 .011 r
.34364 .63317 m .34393 .63181 L .34183 .63045 L F
.605 .921 .973 r
.4131 .56275 m .41189 .56196 L .41501 .56125 L F
.532 .385 .627 r
.41191 .56206 m .41501 .56125 L .41189 .56196 L F
.391 .85 .822 r
.41612 .56211 m .41455 .56342 L .4131 .56275 L F
.998 .847 .525 r
.4131 .56275 m .41227 .56437 L .41189 .56196 L F
.605 .921 .973 r
.4131 .56275 m .41501 .56125 L .41733 .56186 L F
.532 .385 .627 r
.41227 .56437 m .41427 .56209 L .41191 .56206 L F
.41427 .56209 m .41501 .56125 L .41191 .56206 L F
.391 .85 .822 r
.41733 .56186 m .41686 .56212 L .41612 .56211 L F
.41686 .56212 m .41455 .56342 L .41612 .56211 L F
.841 .718 .728 r
.52506 .38638 m .52448 .38893 L .52318 .38521 L F
.65 .538 .714 r
.57093 .35816 m .57133 .36178 L .57329 .35844 L F
.356 .128 .424 r
.57133 .36178 m .57107 .36441 L .57398 .36101 L F
.567 .318 .498 r
.53496 .39267 m .53865 .3921 L .53888 .38951 L F
.524 .53 .804 r
.53888 .38951 m .54205 .39004 L .54118 .38807 L F
0 0 .104 r
.32715 .61722 m .32656 .62134 L .32443 .62026 L F
.753 .736 .836 r
.50492 .47914 m .50908 .4798 L .50812 .47611 L F
.902 .813 .75 r
.50812 .47611 m .50908 .4798 L .5099 .47715 L F
.027 0 .101 r
.29293 .63153 m .29015 .63488 L .29209 .63334 L F
.204 0 .342 r
.29209 .63334 m .29015 .63488 L .28921 .63777 L F
.081 .136 .62 r
.57093 .35816 m .57265 .3564 L .5711 .35472 L F
0 0 .481 r
.57533 .35868 m .57329 .35844 L .57265 .3564 L F
.888 .609 .095 r
.57265 .3564 m .57344 .36111 L .57398 .36101 L F
.884 .614 .524 r
.57265 .3564 m .57344 .36111 L .5688 .35752 L F
.57265 .3564 m .5688 .35752 L .57046 .35715 L F
.672 .122 0 r
.57035 .35624 m .57265 .3564 L .57046 .35715 L F
.635 .958 .923 r
.57046 .35715 m .57098 .35634 L .57035 .35624 L F
.081 .136 .62 r
.5711 .35472 m .57265 .3564 L .57117 .35335 L F
.622 .392 .548 r
.57117 .35335 m .57265 .3564 L .57281 .35371 L F
.624 .958 .905 r
.57581 .3536 m .57035 .35624 L .57182 .35505 L F
.635 .958 .923 r
.57132 .35582 m .57182 .35505 L .57035 .35624 L F
.57132 .35582 m .56943 .35653 L .57182 .35505 L F
.57098 .35634 m .57132 .35582 L .57035 .35624 L F
.672 .122 0 r
.57098 .35634 m .57426 .35815 L .57287 .35664 L F
.57035 .35624 m .57037 .35625 L .57098 .35634 L F
.57037 .35625 m .57426 .35815 L .57098 .35634 L F
.635 .958 .923 r
.57046 .35715 m .56956 .35661 L .57037 .35625 L F
.57098 .35634 m .57037 .35625 L .57132 .35582 L F
.57046 .35715 m .57037 .35625 L .57098 .35634 L F
.56956 .35661 m .56943 .35653 L .57132 .35582 L F
.222 .289 .721 r
.57581 .3536 m .57579 .3538 L .57035 .35624 L F
.57579 .3538 m .57578 .35389 L .57132 .35582 L F
.57579 .3538 m .57132 .35582 L .57035 .35624 L F
.672 .122 0 r
.57035 .35624 m .57287 .35664 L .57265 .3564 L F
.57426 .35815 m .57533 .35868 L .57265 .3564 L F
.222 .289 .721 r
.57578 .35389 m .57533 .35868 L .57035 .35624 L F
.777 .634 .702 r
.50595 .44945 m .50706 .45283 L .5035 .45272 L F
.749 .569 .652 r
.50706 .45283 m .50318 .45579 L .5035 .45272 L F
.533 .43 .683 r
.51038 .45565 m .50706 .45283 L .51071 .4526 L F
.968 .787 .606 r
.60164 .35797 m .60099 .36153 L .60275 .36213 L F
.993 .824 .572 r
.59949 .35867 m .60099 .36153 L .60164 .35797 L F
.181 .683 .91 r
.60275 .36213 m .60099 .36153 L .60062 .36098 L F
0 .046 .562 r
.60401 .36304 m .60275 .36213 L .60062 .36098 L F
.954 .706 .525 r
.33927 .54666 m .33616 .54158 L .33975 .54406 L F
0 .306 .742 r
.52763 .40289 m .52622 .40165 L .5242 .40058 L F
.78 .93 .932 r
.52862 .39978 m .52763 .40289 L .52995 .40142 L F
.52862 .39978 m .52622 .40165 L .52763 .40289 L F
.684 .78 .924 r
.30055 .57966 m .30384 .58137 L .30161 .58002 L F
.942 .579 .271 r
.35716 .55291 m .35749 .55533 L .35932 .55625 L F
.859 .474 .315 r
.35749 .55533 m .35771 .55534 L .35932 .55625 L F
.982 .706 .419 r
.35931 .5534 m .35932 .55625 L .36093 .55716 L F
.942 .579 .271 r
.35716 .55291 m .35932 .55625 L .35931 .5534 L F
.859 .474 .315 r
.35771 .55534 m .36204 .55569 L .35932 .55625 L F
.982 .706 .419 r
.36093 .55716 m .35932 .55625 L .36104 .55743 L F
.984 .792 .566 r
.35932 .55625 m .36047 .56034 L .36104 .55743 L F
0 0 0 r
.55981 .37506 m .56096 .37563 L .56157 .37335 L F
.55981 .37506 m .55937 .37738 L .56096 .37563 L F
.888 .963 .837 r
.536 .42625 m .53337 .42943 L .53219 .42849 L F
.816 .702 .74 r
.30834 .56315 m .30991 .56707 L .31201 .56386 L F
.745 .669 .776 r
.27532 .55602 m .28068 .55783 L .2782 .55468 L F
.56 .411 .635 r
.27532 .55602 m .27816 .56049 L .28068 .55783 L F
.332 .016 .27 r
.29293 .63153 m .29263 .6346 L .29572 .63023 L F
.29293 .63153 m .29209 .63334 L .29263 .6346 L F
.792 .878 .909 r
.65496 .37806 m .65703 .37384 L .65422 .37721 L F
.65496 .37806 m .65846 .37539 L .65703 .37384 L F
0 0 0 r
.436 .45009 m .4351 .45157 L .43827 .44872 L F
.74 .235 0 r
.40162 .58297 m .40503 .58672 L .40456 .5826 L F
.882 .95 .849 r
.46181 .52355 m .46219 .52554 L .46346 .52467 L F
.83 .934 .897 r
.46352 .52187 m .46346 .52467 L .46503 .52277 L F
.46352 .52187 m .46181 .52355 L .46346 .52467 L F
.945 .916 .754 r
.42782 .56362 m .42931 .56126 L .42654 .56248 L F
.865 .89 .852 r
.42882 .55828 m .42931 .56126 L .43194 .55822 L F
.944 .919 .757 r
.42654 .56248 m .42931 .56126 L .42882 .55828 L F
.557 .39 .611 r
.26767 .56802 m .27254 .56834 L .26986 .56426 L F
.495 .37 .639 r
.26986 .56426 m .27503 .56676 L .27621 .56417 L F
.26986 .56426 m .27254 .56834 L .27503 .56676 L F
.43 .134 .36 r
.26823 .57075 m .27254 .56834 L .26767 .56802 L F
.329 0 .155 r
.45581 .4481 m .452 .45132 L .45325 .44882 L F
.869 .744 .722 r
.34417 .66714 m .34637 .66551 L .34302 .66401 L F
.865 .75 .734 r
.34302 .66401 m .34637 .66551 L .34755 .66124 L F
0 0 .568 r
.33478 .61249 m .33338 .61184 L .33284 .61205 L F
.672 .358 .434 r
.34802 .53393 m .35274 .53606 L .35253 .53372 L F
.728 .397 .42 r
.35274 .53606 m .35477 .53635 L .35253 .53372 L F
.914 .913 .804 r
.5099 .47715 m .51197 .474 L .51093 .4729 L F
.625 .517 .711 r
.28533 .66145 m .28871 .66233 L .2878 .65818 L F
.321 .479 .861 r
.28533 .66145 m .28924 .66479 L .28871 .66233 L F
0 0 0 r
.54247 .35224 m .54109 .35242 L .54407 .35148 L F
.54109 .35242 m .54247 .35224 L .54217 .34958 L F
.54109 .35242 m .54009 .35352 L .54247 .35224 L F
.54247 .35224 m .54009 .35352 L .54109 .35242 L F
.612 .461 .653 r
.5015 .41268 m .50412 .41191 L .5042 .40894 L F
.211 .363 .799 r
.36163 .56124 m .36254 .56329 L .36033 .56363 L F
.176 .682 .905 r
.35929 .56379 m .36033 .56363 L .36246 .56426 L F
0 0 .473 r
.36346 .56537 m .36246 .56426 L .36033 .56363 L F
.211 .363 .799 r
.36254 .56329 m .36346 .56537 L .36033 .56363 L F
.176 .682 .905 r
.35822 .56362 m .36033 .56363 L .35929 .56379 L F
.986 .871 .511 r
.36267 .56412 m .3626 .56439 L .36346 .56537 L F
0 0 .473 r
.36346 .56537 m .36444 .56648 L .36246 .56426 L F
.986 .871 .511 r
.3626 .56439 m .3619 .56683 L .36346 .56537 L F
0 0 .473 r
.36346 .56537 m .36481 .5669 L .36444 .56648 L F
.18 .065 .477 r
.42079 .56005 m .42204 .55666 L .4212 .55748 L F
.88 .723 .683 r
.34928 .64053 m .35183 .64147 L .35353 .63778 L F
.865 .75 .734 r
.34302 .66401 m .34755 .66124 L .34667 .66059 L F
.764 .683 .773 r
.42015 .50676 m .42183 .51063 L .42429 .50718 L F
.468 .89 .809 r
.4997 .40745 m .49864 .40751 L .49705 .40877 L F
.461 .866 .698 r
.49864 .40751 m .49524 .40956 L .49705 .40877 L F
.97 .826 .645 r
.36484 .56914 m .36661 .57039 L .36753 .56768 L F
.654 .122 0 r
.36484 .56914 m .36893 .57042 L .36661 .57039 L F
.36484 .56914 m .3676 .57064 L .36893 .57042 L F
.93 .946 .781 r
.36893 .57042 m .3676 .57064 L .3679 .56994 L F
.36893 .57042 m .3679 .56994 L .3695 .56625 L F
.153 .662 .902 r
.37046 .57113 m .36893 .57042 L .37068 .57117 L F
.36699 .57046 m .36893 .57042 L .37046 .57113 L F
.749 .926 .57 r
.3697 .57159 m .37055 .57038 L .36893 .57042 L F
.088 .329 .804 r
.37147 .56908 m .37068 .57117 L .36893 .57042 L F
.749 .926 .57 r
.37055 .57038 m .37147 .56908 L .36893 .57042 L F
.153 .662 .902 r
.36661 .57039 m .36893 .57042 L .36699 .57046 L F
.088 .329 .804 r
.37147 .56908 m .37264 .57225 L .37068 .57117 L F
.979 .829 .623 r
.33404 .61708 m .336 .61521 L .33507 .61436 L F
.33404 .61708 m .33561 .61848 L .336 .61521 L F
.854 .664 .645 r
.30572 .54954 m .30979 .54738 L .30581 .54669 L F
.30572 .54954 m .30963 .55019 L .30979 .54738 L F
.914 .913 .804 r
.5099 .47715 m .51093 .4729 L .50812 .47611 L F
.839 .531 .467 r
.3618 .57408 m .36034 .57527 L .35824 .57076 L F
.856 .446 0 r
.35824 .57076 m .36018 .57492 L .35782 .57205 L F
.36018 .57492 m .36034 .57527 L .36014 .57502 L F
.36018 .57492 m .36014 .57502 L .35782 .57205 L F
.485 .216 .431 r
.3618 .57408 m .36424 .5776 L .36072 .57762 L F
.705 .205 0 r
.3618 .57408 m .36193 .57525 L .35997 .57554 L F
.618 .07 0 r
.36014 .57502 m .35623 .57508 L .35782 .57205 L F
.36034 .57527 m .35967 .57524 L .36014 .57502 L F
.35967 .57524 m .35623 .57508 L .36014 .57502 L F
.36034 .57527 m .35943 .57562 L .35623 .57508 L F
.847 .99 .727 r
.36008 .5752 m .35943 .57562 L .36002 .5754 L F
.36008 .5752 m .36002 .5754 L .36034 .57527 L F
.3618 .57408 m .36008 .5752 L .36034 .57527 L F
.705 .205 0 r
.36091 .57466 m .35997 .57554 L .36008 .5752 L F
.3618 .57408 m .36131 .57447 L .36091 .57466 L F
.36131 .57447 m .35997 .57554 L .36091 .57466 L F
.36008 .5752 m .35997 .57554 L .35943 .57562 L F
.3618 .57408 m .36424 .5776 L .36193 .57525 L F
.923 .95 .791 r
.36424 .5776 m .3639 .58066 L .3662 .57769 L F
0 .221 .743 r
.36593 .58102 m .3639 .58066 L .36451 .57792 L F
.762 .254 0 r
.3662 .57769 m .36429 .5776 L .36195 .57421 L F
.62 .952 .926 r
.36603 .57681 m .36424 .5776 L .3662 .57769 L F
.762 .254 0 r
.36195 .57421 m .36424 .5776 L .3618 .57408 L F
.36429 .5776 m .36424 .5776 L .36195 .57421 L F
.36429 .5776 m .36424 .5776 L .36429 .5776 L F
.205 .466 .884 r
.3639 .58066 m .36072 .57762 L .36424 .5776 L F
.046 .21 .711 r
.36072 .57762 m .36254 .57831 L .36424 .5776 L F
.762 .987 .898 r
.36424 .5776 m .36254 .57831 L .36337 .57758 L F
.741 .684 .797 r
.36555 .57663 m .36424 .5776 L .36603 .57681 L F
.36401 .57604 m .36424 .5776 L .36555 .57663 L F
.36193 .57525 m .36603 .57681 L .36413 .57476 L F
.713 .939 .959 r
.36488 .57626 m .36424 .5776 L .36603 .57681 L F
.089 .19 .676 r
.36488 .57626 m .36437 .57852 L .36424 .5776 L F
.36437 .57852 m .3639 .58066 L .36424 .5776 L F
.741 .684 .797 r
.36193 .57525 m .36424 .5776 L .36401 .57604 L F
.762 .987 .898 r
.36424 .5776 m .36337 .57758 L .36488 .57626 L F
0 .221 .743 r
.3656 .5795 m .36451 .57792 L .36488 .57626 L F
.36593 .58102 m .36451 .57792 L .3656 .5795 L F
.852 .788 .789 r
.35773 .54953 m .36253 .54753 L .35827 .54693 L F
.35773 .54953 m .35992 .55062 L .36253 .54753 L F
.841 .848 .85 r
.66375 .35567 m .6613 .35739 L .66482 .358 L F
.788 .513 .521 r
.66085 .36008 m .66482 .358 L .6613 .35739 L F
.66085 .36008 m .66573 .36236 L .66482 .358 L F
.62 .957 .904 r
.66735 .35442 m .66375 .35567 L .66482 .358 L F
.888 .963 .837 r
.536 .42625 m .53219 .42849 L .53488 .426 L F
.029 0 0 r
.53731 .42668 m .536 .42625 L .53488 .426 L F
.53731 .42668 m .5389 .42551 L .536 .42625 L F
.748 .269 .106 r
.39429 .48705 m .39281 .48841 L .3904 .48582 L F
.545 .021 0 r
.39708 .48858 m .39281 .48841 L .39429 .48705 L F
.527 .143 .255 r
.39724 .48682 m .39708 .48858 L .39429 .48705 L F
.765 .677 .765 r
.45104 .52334 m .4475 .52054 L .45015 .51948 L F
.45104 .52334 m .44715 .52342 L .4475 .52054 L F
.763 .576 .644 r
.45104 .52334 m .44922 .52679 L .44715 .52342 L F
.555 .468 .712 r
.26618 .57367 m .26982 .57805 L .26857 .57298 L F
.26618 .57367 m .26754 .57917 L .26982 .57805 L F
.498 .693 .956 r
.64015 .34288 m .64136 .34475 L .64284 .34257 L F
.445 .071 .233 r
.42976 .46846 m .42895 .46674 L .43136 .4679 L F
.44 .081 .258 r
.42895 .46674 m .43164 .46647 L .43136 .4679 L F
0 0 0 r
.4598 .43218 m .46198 .43156 L .46315 .42956 L F
.18 0 .12 r
.46198 .43156 m .46518 .42794 L .46315 .42956 L F
.121 0 0 r
.39545 .47523 m .39818 .47468 L .39891 .47374 L F
.257 0 0 r
.39818 .47468 m .40075 .47435 L .39891 .47374 L F
.955 .865 .71 r
.33521 .53082 m .33434 .53382 L .33244 .53239 L F
.984 .71 .412 r
.33434 .53382 m .33417 .53638 L .33244 .53239 L F
.758 .539 .6 r
.29967 .54276 m .30385 .54023 L .29955 .5396 L F
.29967 .54276 m .30391 .54323 L .30385 .54023 L F
.801 .732 .788 r
.3313 .5228 m .33558 .52363 L .334 .51938 L F
.813 .706 .747 r
.3313 .5228 m .33292 .52678 L .33558 .52363 L F
.513 .815 1 r
.33292 .52678 m .33571 .52642 L .33558 .52363 L F
.888 .767 .723 r
.334 .51938 m .33558 .52363 L .33592 .52062 L F
.741 .618 .721 r
.42112 .5431 m .41734 .54387 L .42011 .54018 L F
.628 .293 .385 r
.42112 .5431 m .41987 .54609 L .41734 .54387 L F
.798 .577 .603 r
.42433 .54359 m .41987 .54609 L .42112 .5431 L F
.842 .426 .247 r
.5054 .42854 m .50435 .42613 L .50242 .42677 L F
.50242 .42677 m .50435 .42613 L .5054 .42854 L F
0 0 .121 r
.35824 .57076 m .35878 .56835 L .35848 .56669 L F
.856 .446 0 r
.35824 .57076 m .35782 .57205 L .35878 .56835 L F
.862 .665 .634 r
.34354 .55418 m .343 .55695 L .34105 .55349 L F
.919 .702 .594 r
.29491 .57778 m .29212 .5725 L .29364 .57376 L F
.29491 .57778 m .29164 .57668 L .29212 .5725 L F
.918 .707 .601 r
.29491 .57778 m .29201 .5777 L .29164 .57668 L F
.015 .26 .762 r
.29491 .57778 m .29587 .57605 L .29201 .5777 L F
.29491 .57778 m .29725 .57955 L .29587 .57605 L F
.821 .385 .203 r
.42786 .53069 m .42871 .53284 L .4321 .5335 L F
.861 .636 .596 r
.42804 .53547 m .4321 .5335 L .42871 .53284 L F
.42804 .53547 m .43174 .53649 L .4321 .5335 L F
.801 .578 .599 r
.43174 .53649 m .43392 .5367 L .4321 .5335 L F
.706 .962 .708 r
.445 .53257 m .44389 .53394 L .44471 .53211 L F
.691 .978 .805 r
.44471 .53211 m .44389 .53394 L .44144 .53482 L F
.066 .237 .73 r
.30748 .63685 m .30636 .63767 L .30686 .6357 L F
0 0 0 r
.30808 .63774 m .30563 .63821 L .30636 .63767 L F
.07 0 0 r
.30847 .63867 m .30808 .63774 L .30636 .63767 L F
.066 .237 .73 r
.30847 .63867 m .30636 .63767 L .30748 .63685 L F
0 0 0 r
.30563 .63821 m .3042 .63849 L .30636 .63767 L F
.653 .475 .631 r
.27906 .55021 m .28197 .55326 L .28153 .54878 L F
.27906 .55021 m .2782 .55468 L .28197 .55326 L F
.947 .944 .746 r
.5035 .45272 m .50456 .44818 L .50595 .44945 L F
.982 .697 .333 r
.50445 .44542 m .50595 .44945 L .50456 .44818 L F
.727 .667 .791 r
.50938 .4465 m .50595 .44945 L .50445 .44542 L F
.66 .462 .606 r
.56988 .34277 m .57058 .34444 L .57119 .34457 L F
.739 .601 .703 r
.40456 .5826 m .40503 .58672 L .40827 .58395 L F
.641 .168 .114 r
.65118 .34614 m .65511 .34526 L .65096 .34412 L F
.65118 .34614 m .65545 .3468 L .65511 .34526 L F
.76 .268 .061 r
.65511 .34526 m .65545 .3468 L .65715 .34706 L F
.865 .89 .852 r
.42882 .55828 m .43194 .55822 L .42988 .55641 L F
.278 .776 .745 r
.42875 .55277 m .43068 .5522 L .4286 .5527 L F
0 0 0 r
.43068 .5522 m .43138 .55206 L .4286 .5527 L F
.43068 .5522 m .43296 .55033 L .43138 .55206 L F
.276 0 0 r
.34035 .62029 m .33561 .61848 L .33712 .61863 L F
.643 .352 .462 r
.33428 .62058 m .33712 .61863 L .33561 .61848 L F
.882 .95 .849 r
.46181 .52355 m .45937 .52619 L .46219 .52554 L F
.902 .846 .78 r
.45811 .52822 m .46219 .52554 L .45937 .52619 L F
.45811 .52822 m .45956 .52969 L .46219 .52554 L F
.872 .961 .624 r
.41177 .56728 m .41119 .56694 L .41227 .56437 L F
0 0 0 r
.49539 .40161 m .49708 .4005 L .49812 .39869 L F
.49539 .40161 m .49364 .40304 L .49708 .4005 L F
.568 .901 .659 r
.49812 .39869 m .49966 .39702 L .50127 .39602 L F
0 0 0 r
.49812 .39869 m .49708 .4005 L .49966 .39702 L F
.789 .737 .804 r
.28902 .53658 m .2902 .5406 L .29308 .53701 L F
.384 0 0 r
.33703 .62736 m .33914 .62762 L .3394 .62795 L F
.33914 .62762 m .34174 .62795 L .3394 .62795 L F
.33703 .62736 m .34174 .62795 L .3394 .62795 L F
.861 .888 .855 r
.33791 .62591 m .3394 .62795 L .34256 .62391 L F
0 0 .437 r
.33997 .62867 m .3394 .62795 L .33791 .62591 L F
.887 .584 .468 r
.34183 .63045 m .3394 .62795 L .34087 .62988 L F
0 0 .437 r
.34087 .62988 m .3394 .62795 L .33997 .62867 L F
.902 .828 .763 r
.3394 .62795 m .3436 .62427 L .34256 .62391 L F
.3394 .62795 m .34174 .62795 L .3436 .62427 L F
.929 .566 .147 r
.34256 .62391 m .3436 .62427 L .34186 .62113 L F
.759 .774 .865 r
.48709 .4957 m .49129 .49603 L .48991 .49269 L F
.774 .75 .831 r
.48896 .49743 m .49129 .49603 L .48709 .4957 L F
.722 .744 .869 r
.49129 .49603 m .49261 .4914 L .48991 .49269 L F
.49129 .49603 m .49418 .49332 L .49261 .4914 L F
.811 .962 .908 r
.48472 .49945 m .48896 .49743 L .48709 .4957 L F
.704 .675 .82 r
.50412 .41191 m .5062 .4082 L .5042 .40894 L F
0 0 0 r
.50725 .40586 m .5062 .4082 L .50863 .404 L F
0 0 .072 r
.58155 .38056 m .58126 .38321 L .58042 .38522 L F
0 0 0 r
.58079 .38568 m .58042 .38522 L .58126 .38321 L F
.58079 .38568 m .57941 .38789 L .58042 .38522 L F
.923 .918 .793 r
.29203 .56398 m .29058 .56281 L .29283 .55933 L F
.732 .599 .708 r
.29283 .55933 m .29058 .56281 L .28896 .5593 L F
.432 .226 .498 r
.29058 .56281 m .29152 .56384 L .29078 .56093 L F
.575 .845 .996 r
.29277 .56703 m .28934 .56741 L .29203 .56398 L F
.518 .83 1 r
.29203 .56398 m .29048 .56389 L .29058 .56281 L F
.29048 .56389 m .2881 .56373 L .29058 .56281 L F
.948 .927 .749 r
.29078 .56093 m .29073 .56129 L .29058 .56281 L F
.499 .525 .815 r
.29058 .56281 m .2881 .56373 L .28633 .5597 L F
.297 .034 .335 r
.29058 .56281 m .28728 .56693 L .2881 .56373 L F
.499 .525 .815 r
.29058 .56281 m .28633 .5597 L .28896 .5593 L F
.522 .307 .529 r
.29003 .56573 m .28728 .56693 L .29058 .56281 L F
.948 .927 .749 r
.29073 .56129 m .29003 .56573 L .29058 .56281 L F
.997 .808 .532 r
.29203 .56398 m .29003 .56573 L .29058 .56281 L F
.432 .226 .498 r
.29152 .56384 m .29257 .56499 L .29176 .56316 L F
.29152 .56384 m .29176 .56316 L .29078 .56093 L F
.724 .937 .614 r
.28934 .56741 m .29003 .56573 L .2912 .56472 L F
.29097 .56533 m .2912 .56472 L .29203 .56398 L F
.28934 .56741 m .2912 .56472 L .29097 .56533 L F
.675 .402 .5 r
.29277 .56703 m .29014 .56948 L .28934 .56741 L F
.886 .866 .814 r
.29014 .56948 m .29003 .56573 L .28934 .56741 L F
0 0 0 r
.5315 .36135 m .52904 .3639 L .52863 .36197 L F
.345 .605 .945 r
.29729 .66927 m .2982 .66737 L .29616 .66742 L F
.29729 .66927 m .30136 .67056 L .2982 .66737 L F
.895 .84 .783 r
.4559 .52963 m .45379 .53298 L .45631 .53326 L F
.842 .994 .846 r
.45262 .53549 m .45631 .53326 L .45379 .53298 L F
.45262 .53549 m .45357 .53584 L .45631 .53326 L F
.816 .79 .828 r
.4559 .52963 m .45631 .53326 L .45956 .52969 L F
.673 .403 .504 r
.34562 .53356 m .34802 .53628 L .34802 .53393 L F
.672 .358 .434 r
.34802 .53393 m .34802 .53628 L .35274 .53606 L F
0 0 0 r
.60865 .35164 m .61102 .35167 L .60881 .35062 L F
0 0 .443 r
.61231 .34673 m .61102 .35167 L .61056 .34805 L F
.513 .867 .988 r
.61263 .35007 m .60881 .35062 L .61102 .35167 L F
0 0 0 r
.4598 .43218 m .45639 .43553 L .45866 .43424 L F
.028 0 0 r
.46112 .43321 m .4598 .43218 L .45866 .43424 L F
.46112 .43321 m .46198 .43156 L .4598 .43218 L F
.552 .764 .976 r
.61952 .39337 m .61709 .39575 L .61584 .39446 L F
.61863 .39425 m .61998 .39497 L .61709 .39575 L F
.61976 .39422 m .61998 .39497 L .61863 .39425 L F
.61952 .39337 m .61998 .39497 L .61709 .39575 L F
.612 .807 .975 r
.6246 .39549 m .61998 .39497 L .62264 .394 L F
0 .376 .833 r
.61998 .39497 m .62405 .39807 L .62264 .394 L F
.627 .814 .972 r
.62264 .394 m .61998 .39497 L .61952 .39337 L F
.378 0 0 r
.62199 .39418 m .62144 .39541 L .61854 .39511 L F
.62264 .394 m .6225 .39417 L .62199 .39418 L F
.6225 .39417 m .62144 .39541 L .62199 .39418 L F
.552 .764 .976 r
.61952 .39337 m .61976 .39422 L .61863 .39425 L F
.61952 .39337 m .61709 .39575 L .61584 .39446 L F
.808 .696 .741 r
.56164 .36624 m .5581 .36684 L .56017 .36683 L F
.465 0 0 r
.56164 .36624 m .56017 .36683 L .56396 .36728 L F
.797 .674 .729 r
.55447 .37148 m .5541 .37363 L .55877 .3711 L F
.844 .69 .691 r
.27633 .56314 m .28169 .56664 L .27895 .56232 L F
.27633 .56314 m .27632 .56588 L .28169 .56664 L F
.532 .378 .617 r
.27632 .56588 m .27868 .5676 L .28169 .56664 L F
.18 .458 .883 r
.27895 .56232 m .28169 .56664 L .28227 .56434 L F
.655 .529 .699 r
.27868 .5676 m .28227 .56434 L .28169 .56664 L F
.835 .71 .726 r
.30834 .56315 m .30572 .56662 L .30991 .56707 L F
.835 .706 .722 r
.30572 .56662 m .30741 .57051 L .30991 .56707 L F
0 0 .481 r
.57533 .35868 m .57398 .36101 L .57329 .35844 L F
.531 .695 .944 r
.37572 .57056 m .37503 .57363 L .37264 .57225 L F
.37572 .57056 m .37755 .57325 L .37503 .57363 L F
.493 .889 .733 r
.44457 .54039 m .44345 .54107 L .44317 .54169 L F
.166 .683 .89 r
.44299 .54209 m .44317 .54169 L .44106 .54177 L F
.183 .688 .906 r
.44106 .54177 m .44317 .54169 L .43942 .54106 L F
.613 .929 .966 r
.43797 .54316 m .44106 .54177 L .43942 .54106 L F
.663 .149 .009 r
.44317 .54169 m .44082 .54267 L .43942 .54106 L F
.493 .889 .733 r
.44345 .54107 m .44082 .54267 L .44317 .54169 L F
.166 .683 .89 r
.44432 .5423 m .44317 .54169 L .44299 .54209 L F
.428 .867 .791 r
.44776 .53997 m .44317 .54169 L .44432 .5423 L F
.872 .661 .133 r
.65043 .34066 m .65088 .34148 L .65047 .33735 L F
.65043 .34066 m .65096 .34412 L .65088 .34148 L F
.587 .781 .972 r
.53679 .38997 m .53865 .3921 L .53496 .39267 L F
.583 .365 .551 r
.53496 .39267 m .53865 .3921 L .53679 .38997 L F
.53496 .39267 m .53555 .3948 L .53865 .3921 L F
.467 .692 .965 r
.54628 .4063 m .54455 .40611 L .54393 .40411 L F
0 0 0 r
.30953 .61707 m .30668 .62085 L .30886 .6198 L F
.31355 .61465 m .30953 .61707 L .312 .61686 L F
.107 0 .068 r
.312 .61686 m .30953 .61707 L .30886 .6198 L F
.923 .918 .793 r
.29203 .56398 m .29283 .55933 L .2946 .56058 L F
.93 .632 .455 r
.35586 .56708 m .35331 .56887 L .35329 .56614 L F
.53 .062 .088 r
.40173 .48712 m .39708 .48858 L .39724 .48682 L F
.40173 .48712 m .40061 .48884 L .39708 .48858 L F
.197 0 0 r
.40436 .48618 m .40061 .48884 L .40173 .48712 L F
.58 .13 .148 r
.57117 .35335 m .57281 .35371 L .57076 .35231 L F
0 0 .337 r
.57138 .35032 m .57117 .35335 L .57076 .35231 L F
.57138 .35032 m .57117 .35335 L .57076 .35231 L F
.79 .566 .597 r
.33597 .67467 m .33969 .67187 L .33892 .67126 L F
.33597 .67467 m .34039 .67495 L .33969 .67187 L F
.745 .792 .891 r
.33969 .67187 m .34258 .66841 L .33892 .67126 L F
.33969 .67187 m .34197 .67052 L .34258 .66841 L F
.833 .867 .87 r
.42011 .54018 m .41612 .5401 L .4183 .5386 L F
.864 .819 .803 r
.42011 .54018 m .41734 .54387 L .41612 .5401 L F
.529 .529 .799 r
.52587 .37007 m .52461 .3756 L .52329 .371 L F
.52587 .37007 m .52748 .37465 L .52461 .3756 L F
0 0 .149 r
.52615 .37602 m .52461 .3756 L .52748 .37465 L F
.52615 .37602 m .52435 .37744 L .52461 .3756 L F
.858 .987 .847 r
.54786 .42654 m .54768 .4293 L .54818 .42803 L F
.865 .858 .404 r
.54685 .43163 m .54768 .4293 L .54786 .42654 L F
.8 .731 .787 r
.62127 .38471 m .62252 .38864 L .61934 .38631 L F
.863 .419 .133 r
.62252 .38864 m .62135 .38985 L .61934 .38631 L F
.673 .149 0 r
.62252 .38864 m .62552 .39095 L .62135 .38985 L F
0 0 0 r
.55431 .42058 m .5529 .42256 L .55303 .42229 L F
.55431 .42058 m .55303 .42229 L .55465 .41879 L F
.55431 .42058 m .55465 .41879 L .55399 .41728 L F
.918 .922 .539 r
.55465 .41879 m .55578 .41373 L .55399 .41728 L F
0 0 .437 r
.55567 .41881 m .55431 .42058 L .55399 .41728 L F
.591 .855 .51 r
.55533 .41921 m .55431 .42058 L .55567 .41881 L F
.55289 .42208 m .55431 .42058 L .55533 .41921 L F
.539 .717 .955 r
.53289 .41231 m .52864 .411 L .53133 .40823 L F
.752 .488 .534 r
.53289 .41231 m .53334 .41497 L .5288 .41513 L F
.54 .344 .565 r
.53565 .4116 m .53334 .41497 L .53289 .41231 L F
.887 .584 .468 r
.34183 .63045 m .34174 .62795 L .3394 .62795 L F
.522 .401 .656 r
.29448 .54365 m .29738 .54308 L .29505 .5389 L F
.619 .397 .558 r
.29505 .5389 m .29955 .5396 L .29812 .53733 L F
.617 .439 .619 r
.29505 .5389 m .29738 .54308 L .29955 .5396 L F
.675 .402 .5 r
.29277 .56703 m .2928 .57011 L .29014 .56948 L F
0 0 0 r
.29397 .56899 m .2928 .57011 L .29453 .56721 L F
.29397 .56899 m .29453 .56721 L .29455 .56719 L F
0 0 .347 r
.29397 .56899 m .2928 .57011 L .29277 .56703 L F
.576 .662 .896 r
.29397 .56899 m .29364 .57376 L .2928 .57011 L F
.969 .652 .344 r
.29235 .56784 m .29354 .57035 L .29397 .56899 L F
.29354 .57035 m .29432 .572 L .29397 .56899 L F
0 0 .347 r
.29397 .56899 m .29277 .56703 L .29455 .56719 L F
.605 .267 .37 r
.53793 .35754 m .53399 .36027 L .53509 .35828 L F
.906 .718 .638 r
.35773 .54953 m .35931 .5534 L .35992 .55062 L F
.129 0 0 r
.42881 .45531 m .43136 .45453 L .43275 .45266 L F
.12 0 0 r
.43275 .45266 m .43391 .45372 L .4351 .45157 L F
.43275 .45266 m .43136 .45453 L .43391 .45372 L F
.723 .447 .508 r
.34112 .53614 m .34562 .53356 L .34128 .53349 L F
.34112 .53614 m .34536 .53646 L .34562 .53356 L F
.673 .403 .504 r
.34562 .53356 m .34536 .53646 L .34802 .53628 L F
.8 .995 .77 r
.30575 .63018 m .30953 .62756 L .3075 .63006 L F
0 0 0 r
.5824 .37042 m .58116 .37509 L .58035 .37245 L F
.5824 .37042 m .58199 .37292 L .58116 .37509 L F
.797 .544 .554 r
.43314 .53916 m .43392 .5367 L .43174 .53649 L F
0 0 0 r
.43314 .53916 m .43681 .53711 L .43392 .5367 L F
.217 0 0 r
.39109 .47765 m .39393 .47713 L .39545 .47523 L F
.577 .205 .299 r
.39393 .47713 m .39818 .47468 L .39545 .47523 L F
.743 .425 0 r
.4286 .5527 m .42988 .55641 L .42875 .55277 L F
.976 .854 .655 r
.42481 .56691 m .42782 .56362 L .42654 .56248 L F
.42481 .56691 m .42658 .56797 L .42782 .56362 L F
.851 .84 .833 r
.46963 .4904 m .46705 .49337 L .46499 .4922 L F
.895 .816 .763 r
.46705 .49337 m .46586 .49597 L .46499 .4922 L F
0 0 .356 r
.38102 .56828 m .38126 .56829 L .37818 .56707 L F
.38102 .56828 m .38203 .57025 L .38126 .56829 L F
.234 0 .184 r
.46762 .44044 m .47116 .43574 L .46954 .43859 L F
.168 0 .078 r
.46954 .43859 m .47116 .43574 L .47362 .43469 L F
.704 .675 .82 r
.50412 .41191 m .50818 .41201 L .5062 .4082 L F
.193 .388 .827 r
.5062 .4082 m .50818 .41201 L .50936 .41009 L F
.478 .762 .993 r
.50818 .41201 m .51122 .41165 L .50936 .41009 L F
.76 .534 .59 r
.33571 .52642 m .3396 .52937 L .33983 .52694 L F
.933 .807 .697 r
.45784 .50608 m .45434 .50859 L .45647 .50511 L F
.45784 .50608 m .45625 .50995 L .45434 .50859 L F
.936 .93 .774 r
.45784 .50608 m .45892 .50153 L .46109 .50306 L F
.45784 .50608 m .45647 .50511 L .45892 .50153 L F
.876 .546 .422 r
.36481 .5669 m .36484 .56914 L .36753 .56768 L F
.899 .668 .581 r
.30572 .54954 m .30881 .55355 L .30963 .55019 L F
.841 .789 .801 r
.46586 .49597 m .46229 .49561 L .46499 .4922 L F
.86 .733 .721 r
.46586 .49597 m .46384 .49963 L .46229 .49561 L F
.941 .843 .717 r
.41734 .54387 m .41532 .54328 L .41612 .5401 L F
.674 .124 0 r
.41734 .54387 m .4172 .54519 L .41532 .54328 L F
.41734 .54387 m .41987 .54609 L .4172 .54519 L F
.973 .733 .516 r
.35157 .65063 m .34994 .64784 L .34976 .64988 L F
.965 .843 .672 r
.34988 .65462 m .35157 .65063 L .34976 .64988 L F
.698 .312 .313 r
.35601 .53832 m .35806 .53719 L .35477 .53635 L F
.35601 .53832 m .35907 .53932 L .35806 .53719 L F
.485 .814 1 r
.60062 .34247 m .60388 .34163 L .60524 .34294 L F
.495 .819 1 r
.60683 .34095 m .60524 .34294 L .60388 .34163 L F
.60683 .34095 m .60804 .34214 L .60524 .34294 L F
.685 .716 .873 r
.51038 .45565 m .50606 .45666 L .50809 .45748 L F
.884 .663 .142 r
.53733 .35514 m .5378 .35485 L .53361 .35435 L F
.53733 .35514 m .53793 .35754 L .5378 .35485 L F
.836 .748 .767 r
.51165 .44296 m .50619 .44357 L .50751 .4439 L F
.51165 .44296 m .50751 .4439 L .50814 .4434 L F
.122 .672 .786 r
.50309 .444 m .50751 .4439 L .50445 .44542 L F
.741 .913 .952 r
.50619 .44357 m .50585 .44393 L .50751 .4439 L F
.50585 .44393 m .50445 .44542 L .50751 .4439 L F
.727 .667 .791 r
.50938 .4465 m .50445 .44542 L .50585 .44393 L F
.50654 .44389 m .50585 .44393 L .50619 .44357 L F
.122 .672 .786 r
.50557 .44394 m .50585 .44393 L .50751 .4439 L F
.727 .667 .791 r
.50938 .4465 m .50585 .44393 L .50654 .44389 L F
.122 .672 .786 r
.50309 .444 m .50348 .44397 L .50585 .44393 L F
.50309 .444 m .50585 .44393 L .50557 .44394 L F
.569 .939 .887 r
.50814 .4434 m .50823 .44231 L .51016 .4418 L F
.50751 .4439 m .50759 .44371 L .50814 .4434 L F
.836 .748 .767 r
.5088 .44328 m .50626 .44363 L .50619 .44357 L F
.51165 .44296 m .50864 .44334 L .5088 .44328 L F
.50864 .44334 m .50626 .44363 L .5088 .44328 L F
.50814 .4434 m .50767 .44367 L .50626 .44363 L F
.569 .939 .887 r
.50759 .44371 m .50582 .44378 L .50823 .44231 L F
.50751 .4439 m .50715 .44387 L .50759 .44371 L F
.836 .748 .767 r
.51114 .44376 m .50654 .44389 L .50626 .44363 L F
.569 .939 .887 r
.50715 .44387 m .50582 .44378 L .50759 .44371 L F
.50759 .44371 m .50823 .44231 L .50814 .4434 L F
.836 .748 .767 r
.51165 .44296 m .51114 .44376 L .50767 .44367 L F
.51165 .44296 m .50767 .44367 L .50814 .4434 L F
.51114 .44376 m .50938 .4465 L .50654 .44389 L F
.122 .672 .786 r
.50348 .44397 m .50354 .44397 L .50751 .4439 L F
0 0 0 r
.50582 .44378 m .50676 .44408 L .50725 .44349 L F
.50582 .44378 m .50725 .44349 L .50823 .44231 L F
.122 .672 .786 r
.50514 .44393 m .50582 .44378 L .50715 .44387 L F
.50354 .44397 m .50582 .44378 L .50514 .44393 L F
.50354 .44397 m .50715 .44387 L .50751 .4439 L F
.836 .748 .767 r
.51165 .44296 m .50814 .4434 L .51016 .4418 L F
.818 .922 .906 r
.51324 .44115 m .51165 .44296 L .51218 .4401 L F
.847 .945 .884 r
.51218 .4401 m .51165 .44296 L .51016 .4418 L F
.278 0 .193 r
.52904 .3639 m .52568 .36718 L .52606 .36544 L F
.821 .881 .888 r
.5126 .47142 m .5174 .46973 L .51574 .46825 L F
.832 .871 .873 r
.51574 .46825 m .5174 .46973 L .52023 .46661 L F
.798 .577 .603 r
.42433 .54359 m .42365 .54654 L .41987 .54609 L F
.368 .708 .986 r
.42433 .54359 m .42582 .54374 L .42493 .54194 L F
.504 0 0 r
.42521 .54453 m .42433 .54359 L .42493 .54194 L F
.348 0 0 r
.42518 .54475 m .42538 .54482 L .42521 .54453 L F
.504 0 0 r
.42521 .54453 m .42687 .54592 L .42501 .54421 L F
.077 .631 .815 r
.42732 .54555 m .42687 .54592 L .42521 .54453 L F
.348 0 0 r
.42538 .54482 m .42732 .54555 L .42521 .54453 L F
.504 0 0 r
.42521 .54453 m .42501 .54421 L .42433 .54359 L F
.751 .989 .783 r
.66362 .36825 m .65998 .37074 L .66149 .37209 L F
.66362 .36825 m .66178 .36891 L .65998 .37074 L F
.577 .895 .629 r
.6666 .36555 m .66537 .3663 L .66362 .36825 L F
.609 .946 .777 r
.66362 .36825 m .66537 .3663 L .66178 .36891 L F
.851 .84 .833 r
.46963 .4904 m .46499 .4922 L .46798 .48915 L F
.878 .897 .841 r
.47238 .48703 m .46963 .4904 L .46798 .48915 L F
.692 .562 .703 r
.28153 .54878 m .28432 .54693 L .28137 .54744 L F
0 0 .153 r
.33655 .53983 m .33703 .53595 L .33662 .53739 L F
.157 .31 .769 r
.51557 .40401 m .51422 .40566 L .51276 .40279 L F
.492 .298 .545 r
.29448 .54365 m .2963 .54592 L .29738 .54308 L F
.29448 .54365 m .2963 .54592 L .29738 .54308 L F
.102 0 0 r
.4168 .5709 m .41466 .57221 L .41189 .57271 L F
.657 .832 .413 r
.41557 .57059 m .41455 .57223 L .41466 .57221 L F
.411 .82 .62 r
.41439 .57245 m .41466 .57221 L .4148 .57219 L F
0 0 .535 r
.41439 .57245 m .41706 .57619 L .41466 .57221 L F
.357 0 0 r
.41466 .57221 m .4133 .57425 L .4103 .57448 L F
.657 .832 .413 r
.41455 .57223 m .4133 .57425 L .41466 .57221 L F
.411 .82 .62 r
.4148 .57219 m .41466 .57221 L .4168 .5709 L F
0 .079 .601 r
.4168 .5709 m .41759 .57111 L .4166 .57037 L F
.776 .845 .904 r
.45811 .52822 m .4559 .52963 L .45956 .52969 L F
.853 .898 .867 r
.65846 .37539 m .65998 .37074 L .65703 .37384 L F
.65846 .37539 m .66149 .37209 L .65998 .37074 L F
.708 .984 .885 r
.54805 .41879 m .54453 .42021 L .54682 .42052 L F
0 0 .143 r
.55065 .41484 m .54805 .41879 L .55007 .41728 L F
.775 .607 .671 r
.54682 .42052 m .55007 .41728 L .54805 .41879 L F
0 0 .439 r
.42132 .56295 m .42202 .56379 L .42184 .56388 L F
0 0 .518 r
.42184 .56388 m .42234 .5594 L .42079 .56005 L F
.42184 .56388 m .42327 .56228 L .42234 .5594 L F
.892 .714 .654 r
.42202 .56379 m .42237 .56337 L .42184 .56388 L F
.393 0 0 r
.41733 .56186 m .42173 .56355 L .42132 .56295 L F
.773 .821 .89 r
.42173 .56355 m .42202 .56379 L .42132 .56295 L F
.589 .047 0 r
.41501 .56125 m .42173 .56355 L .41733 .56186 L F
.611 .431 .614 r
.41501 .56125 m .41845 .5644 L .42173 .56355 L F
.773 .821 .89 r
.42173 .56355 m .41845 .5644 L .42202 .56379 L F
.762 .645 .733 r
.41395 .56794 m .42202 .56379 L .41845 .5644 L F
.41395 .56794 m .41489 .56875 L .42202 .56379 L F
.41489 .56875 m .41759 .57111 L .42063 .56608 L F
.41489 .56875 m .42063 .56608 L .42202 .56379 L F
.826 .723 .751 r
.42202 .56379 m .42049 .56949 L .42379 .56873 L F
.788 .682 .747 r
.42202 .56379 m .41759 .57111 L .42049 .56949 L F
.979 .769 .55 r
.42257 .56524 m .42128 .5647 L .42209 .56371 L F
.887 .736 .688 r
.42257 .56524 m .42654 .56248 L .42327 .56228 L F
.826 .723 .751 r
.42202 .56379 m .42259 .56539 L .42257 .56524 L F
.42259 .56539 m .42379 .56873 L .42257 .56524 L F
.535 .056 .066 r
.42256 .56514 m .42077 .56449 L .4225 .56521 L F
.892 .714 .654 r
.42202 .56379 m .42257 .56524 L .42327 .56228 L F
.42237 .56337 m .42327 .56228 L .42311 .56247 L F
.42237 .56337 m .42311 .56247 L .42184 .56388 L F
.937 .766 .646 r
.42327 .56228 m .42257 .56524 L .42123 .56098 L F
.535 .056 .066 r
.42394 .56374 m .42243 .5641 L .42256 .56514 L F
.42243 .5641 m .42077 .56449 L .42256 .56514 L F
.42267 .56513 m .4225 .56521 L .42257 .56524 L F
.42394 .56374 m .4225 .56521 L .42267 .56513 L F
.979 .769 .55 r
.42209 .56371 m .42077 .56449 L .42123 .56098 L F
.42128 .5647 m .42077 .56449 L .42209 .56371 L F
.574 .108 .11 r
.52213 .43412 m .51954 .43236 L .51968 .43526 L F
.337 .797 .939 r
.54215 .39028 m .54486 .38978 L .54205 .39004 L F
.54215 .39028 m .54498 .38987 L .54486 .38978 L F
.62 .957 .904 r
.66735 .35442 m .66698 .35374 L .66375 .35567 L F
.861 .685 .155 r
.66705 .35058 m .66698 .35374 L .66735 .35442 L F
.85 .605 .568 r
.4212 .57428 m .42026 .57663 L .41706 .57619 L F
.469 .859 .976 r
.60804 .34214 m .61086 .34126 L .61247 .34208 L F
.458 .853 .975 r
.61247 .34208 m .61343 .3405 L .61495 .3406 L F
.61247 .34208 m .61086 .34126 L .61343 .3405 L F
.849 .942 .882 r
.46667 .51871 m .46503 .52277 L .46795 .51957 L F
.46667 .51871 m .46352 .52187 L .46503 .52277 L F
.926 .579 .355 r
.29212 .5725 m .2928 .57011 L .29364 .57376 L F
.354 .014 .243 r
.43792 .46224 m .43718 .46519 L .4345 .46602 L F
.176 0 .182 r
.43962 .46392 m .43792 .46224 L .44053 .46113 L F
.43962 .46392 m .43718 .46519 L .43792 .46224 L F
.301 .06 .371 r
.44346 .45817 m .44112 .45931 L .44383 .45589 L F
.274 0 .295 r
.44297 .4601 m .44112 .45931 L .44346 .45817 L F
.44297 .4601 m .44053 .46113 L .44112 .45931 L F
.537 .802 .994 r
.62662 .39232 m .62956 .39179 L .62851 .3904 L F
.364 .508 .868 r
.29314 .666 m .29421 .66385 L .29168 .66442 L F
.29314 .666 m .29616 .66742 L .29421 .66385 L F
.108 .604 .904 r
.42429 .52921 m .41979 .52606 L .42525 .52624 L F
.955 .823 .675 r
.4243 .52405 m .42429 .52921 L .42525 .52624 L F
0 0 0 r
.31543 .61328 m .31355 .61465 L .312 .61686 L F
.852 .393 .068 r
.30056 .57084 m .29857 .57005 L .29634 .56725 L F
.693 .919 .97 r
.30092 .56883 m .29857 .57005 L .30056 .57084 L F
0 .209 .724 r
.30056 .57084 m .30267 .5728 L .30092 .56883 L F
.823 .665 .687 r
.31267 .64487 m .31562 .64167 L .31465 .64072 L F
.793 .434 .376 r
.5727 .38851 m .56888 .3902 L .56861 .38745 L F
.5727 .38851 m .5728 .39076 L .56888 .3902 L F
0 0 0 r
.45357 .43647 m .45093 .4391 L .45268 .43761 L F
.102 0 0 r
.45268 .43761 m .45639 .43553 L .45357 .43647 L F
.19 0 0 r
.49966 .39702 m .50375 .39464 L .50127 .39602 L F
.878 .897 .841 r
.47238 .48703 m .46798 .48915 L .47088 .48576 L F
.837 .916 .889 r
.47238 .48703 m .47259 .48409 L .47424 .48511 L F
.47238 .48703 m .47088 .48576 L .47259 .48409 L F
.583 .319 .483 r
.27444 .58074 m .274 .58339 L .2713 .58298 L F
.27444 .58074 m .274 .58339 L .2713 .58298 L F
.526 .634 .9 r
.27266 .57743 m .27444 .58074 L .27673 .58001 L F
.361 .126 .417 r
.27673 .58001 m .274 .58339 L .27444 .58074 L F
.27444 .58074 m .274 .58339 L .27673 .58001 L F
.219 0 .16 r
.41953 .47312 m .41888 .47488 L .41642 .47595 L F
.337 0 .208 r
.42212 .47247 m .41888 .47488 L .41953 .47312 L F
.81 .678 .718 r
.3396 .52937 m .34128 .53349 L .34181 .53066 L F
.776 .812 .881 r
.55205 .37092 m .54832 .37046 L .54928 .36866 L F
.361 0 .037 r
.55205 .37092 m .54766 .37354 L .54832 .37046 L F
.55205 .37092 m .55081 .37327 L .54766 .37354 L F
.255 .627 .96 r
.55224 .36966 m .55205 .37092 L .54928 .36866 L F
.55224 .36966 m .55447 .37148 L .55205 .37092 L F
.777 .837 .375 r
.55224 .36966 m .55205 .37092 L .55447 .37148 L F
.55224 .36966 m .55081 .37327 L .55205 .37092 L F
0 0 0 r
.55013 .38119 m .55211 .38026 L .5534 .3793 L F
.009 0 0 r
.55211 .38026 m .55637 .37855 L .5534 .3793 L F
.532 .555 .824 r
.28618 .65428 m .2878 .65818 L .29034 .65758 L F
.513 .444 .716 r
.28871 .66233 m .29034 .65758 L .2878 .65818 L F
.494 .448 .735 r
.28871 .66233 m .28924 .66479 L .29168 .66442 L F
.795 .671 .728 r
.33698 .53287 m .34128 .53349 L .3396 .52937 L F
.697 .404 .475 r
.33703 .53595 m .34128 .53349 L .33698 .53287 L F
.33703 .53595 m .34112 .53614 L .34128 .53349 L F
.356 .75 .986 r
.3197 .62333 m .31907 .62467 L .31721 .62355 L F
.3197 .62333 m .3217 .62454 L .31907 .62467 L F
0 0 0 r
.59449 .39426 m .59536 .39201 L .5966 .38982 L F
.435 .587 .905 r
.55329 .4135 m .5524 .41383 L .55065 .41484 L F
.667 .573 .741 r
.55007 .41728 m .55329 .4135 L .55065 .41484 L F
0 0 0 r
.40518 .47177 m .40665 .47125 L .4082 .46958 L F
.128 0 0 r
.40665 .47125 m .41079 .46878 L .4082 .46958 L F
.992 .793 .535 r
.3726 .48242 m .37222 .48697 L .37072 .48454 L F
.203 0 0 r
.37072 .48454 m .3749 .48227 L .3726 .48242 L F
.831 .55 .512 r
.61708 .33924 m .61836 .34009 L .62181 .33853 L F
.586 .943 .813 r
.62181 .33853 m .6238 .33649 L .62527 .33759 L F
.62181 .33853 m .61836 .34009 L .6238 .33649 L F
0 0 0 r
.48927 .40605 m .49052 .40611 L .49195 .40482 L F
.48927 .40605 m .48802 .40689 L .49052 .40611 L F
.981 .821 .609 r
.5035 .45272 m .50318 .45579 L .50147 .4543 L F
.947 .944 .746 r
.5035 .45272 m .50256 .4518 L .50456 .44818 L F
.975 .917 .67 r
.5035 .45272 m .50147 .4543 L .50256 .4518 L F
.032 .128 .633 r
.37084 .58242 m .36919 .58317 L .37162 .58628 L F
.343 .095 .386 r
.44587 .45726 m .44383 .45589 L .4463 .455 L F
.44587 .45726 m .44346 .45817 L .44383 .45589 L F
.3 0 .241 r
.42332 .45923 m .42581 .45837 L .4265 .45633 L F
.299 0 .241 r
.4265 .45633 m .42831 .4575 L .42881 .45531 L F
.4265 .45633 m .42581 .45837 L .42831 .4575 L F
.749 .713 .818 r
.26852 .59089 m .27027 .59416 L .2731 .59158 L F
0 0 0 r
.52885 .43139 m .5268 .43273 L .52521 .43378 L F
.634 .865 .985 r
.56668 .39433 m .56319 .39407 L .56591 .39357 L F
.841 .998 .827 r
.56668 .39433 m .56888 .3902 L .57046 .39224 L F
.56668 .39433 m .56591 .39357 L .56888 .3902 L F
.271 0 0 r
.40075 .47435 m .40347 .47389 L .40518 .47177 L F
.306 0 .21 r
.40347 .47389 m .40665 .47125 L .40518 .47177 L F
.637 .251 .296 r
.31773 .61793 m .32019 .61816 L .32001 .6202 L F
.629 .253 .313 r
.31773 .61793 m .32001 .6202 L .31712 .62045 L F
.716 .938 .624 r
.6681 .36294 m .6666 .36555 L .66927 .36419 L F
.6681 .36294 m .66537 .3663 L .6666 .36555 L F
0 0 0 r
.44908 .44063 m .45093 .4391 L .44694 .44155 L F
.464 .821 .55 r
.45268 .43761 m .45093 .4391 L .44908 .44063 L F
.738 .751 .863 r
.60268 .35029 m .60484 .35271 L .60682 .35095 L F
.60268 .35029 m .60484 .35271 L .60682 .35095 L F
.772 .359 .268 r
.4243 .53166 m .42871 .53284 L .42786 .53069 L F
.911 .965 .803 r
.34258 .66841 m .34197 .67052 L .34417 .66714 L F
.438 0 0 r
.55302 .34431 m .55115 .34509 L .54936 .34407 L F
.506 .778 .993 r
.55416 .3421 m .55302 .34431 L .55148 .34248 L F
.55416 .3421 m .55557 .34363 L .55302 .34431 L F
.727 .972 .723 r
.55416 .3421 m .55302 .34431 L .55557 .34363 L F
.55416 .3421 m .55115 .34509 L .55302 .34431 L F
.796 .581 .611 r
.41399 .49633 m .4094 .49872 L .41067 .4977 L F
.41399 .49633 m .4139 .49937 L .4094 .49872 L F
0 .413 .803 r
.41067 .4977 m .4139 .49937 L .41399 .49633 L F
.57 .362 .559 r
.42057 .51607 m .42037 .51634 L .41841 .51657 L F
.42037 .51634 m .41828 .51914 L .41838 .51717 L F
.42037 .51634 m .41838 .51717 L .41841 .51657 L F
.521 .324 .554 r
.42154 .51585 m .42162 .51858 L .42037 .51634 L F
.52 .354 .597 r
.42154 .51585 m .41841 .51657 L .41999 .51566 L F
.521 .324 .554 r
.42154 .51585 m .42037 .51634 L .41999 .51566 L F
.563 .34 .535 r
.41999 .51566 m .42037 .51634 L .41828 .51914 L F
.42037 .51634 m .42162 .51858 L .41828 .51914 L F
.57 .362 .559 r
.42154 .51585 m .41828 .51914 L .42057 .51607 L F
.563 .34 .535 r
.41999 .51566 m .41828 .51914 L .41841 .51657 L F
.003 0 0 r
.37682 .48713 m .37474 .4874 L .37354 .48743 L F
.435 0 0 r
.3793 .4863 m .37474 .4874 L .37682 .48713 L F
.965 .786 .612 r
.34157 .55033 m .33885 .55248 L .3392 .54947 L F
.34157 .55033 m .34105 .55349 L .33885 .55248 L F
.513 .444 .716 r
.28871 .66233 m .29121 .66028 L .29034 .65758 L F
.494 .448 .735 r
.28871 .66233 m .29168 .66442 L .29121 .66028 L F
.918 .878 .78 r
.52864 .411 m .52466 .41378 L .52732 .41018 L F
.52864 .411 m .52617 .41527 L .52466 .41378 L F
.983 .702 .403 r
.52864 .411 m .5288 .41513 L .52617 .41527 L F
.856 .964 .872 r
.53133 .40823 m .52864 .411 L .52732 .41018 L F
0 0 .444 r
.58751 .39197 m .58896 .39247 L .58943 .38978 L F
.58751 .39197 m .58811 .39458 L .58896 .39247 L F
.161 0 0 r
.3818 .4809 m .38458 .48054 L .38241 .48032 L F
.194 0 .002 r
.38241 .48032 m .38458 .48054 L .38477 .47947 L F
.803 .851 .886 r
.51276 .40279 m .50863 .404 L .51224 .40146 L F
.753 .913 .537 r
.55773 .3985 m .55673 .40009 L .55643 .39977 L F
.274 0 0 r
.55643 .39977 m .55758 .40037 L .55612 .39944 L F
.988 .759 .501 r
.5567 .39708 m .55643 .39977 L .55476 .39857 L F
.274 0 0 r
.55643 .39977 m .55612 .39944 L .55476 .39857 L F
.753 .913 .537 r
.55673 .40009 m .55538 .40223 L .55643 .39977 L F
.841 .939 .889 r
.56073 .39548 m .55773 .3985 L .5567 .39708 L F
.993 .791 .416 r
.55773 .3985 m .55643 .39977 L .5567 .39708 L F
.904 .761 .692 r
.44715 .52342 m .44568 .51885 L .4475 .52054 L F
.44715 .52342 m .44401 .52271 L .44568 .51885 L F
.824 .562 .543 r
.44715 .52342 m .44296 .52503 L .44401 .52271 L F
.44715 .52342 m .44707 .52613 L .44296 .52503 L F
.854 .589 .537 r
.44715 .52342 m .44922 .52679 L .44707 .52613 L F
.73 .489 .562 r
.35551 .54679 m .35773 .54953 L .35827 .54693 L F
.964 .65 .373 r
.34928 .64053 m .34955 .63842 L .34739 .6394 L F
.328 .59 .939 r
.35013 .63586 m .34955 .63842 L .34678 .63481 L F
.827 .989 .724 r
.34739 .6394 m .34955 .63842 L .35013 .63586 L F
.57 .814 .99 r
.39008 .5638 m .38618 .56318 L .38781 .56093 L F
.22 0 0 r
.39008 .5638 m .38847 .56369 L .38618 .56318 L F
0 .009 .526 r
.39114 .55922 m .39008 .5638 L .38781 .56093 L F
.39114 .55922 m .39156 .56281 L .39008 .5638 L F
.4 .852 .899 r
.39156 .56281 m .38847 .56369 L .39008 .5638 L F
0 0 0 r
.538 .40562 m .53643 .40724 L .53772 .40798 L F
.246 0 .238 r
.3017 .62504 m .29869 .62813 L .30068 .62695 L F
.133 0 .077 r
.30408 .62399 m .3017 .62504 L .30068 .62695 L F
.69 .54 .678 r
.55316 .40512 m .55323 .40568 L .55538 .40223 L F
0 0 .109 r
.55538 .40223 m .55682 .40298 L .55643 .39977 L F
.55538 .40223 m .55323 .40568 L .55682 .40298 L F
.09 0 0 r
.53101 .35413 m .53229 .35482 L .53361 .35435 L F
.53101 .35413 m .52926 .3558 L .53229 .35482 L F
.954 .617 .33 r
.343 .55695 m .34132 .55637 L .34105 .55349 L F
0 .205 .719 r
.343 .55695 m .34379 .5553 L .34132 .55637 L F
.343 .55695 m .3454 .55929 L .34379 .5553 L F
.468 .324 .602 r
.32563 .62756 m .3232 .62782 L .32455 .62434 L F
.945 .757 .616 r
.62264 .394 m .62405 .39807 L .6246 .39549 L F
.558 0 0 r
.33903 .62014 m .34035 .62029 L .33712 .61863 L F
.33903 .62014 m .34186 .62113 L .34035 .62029 L F
.921 .757 .662 r
.62734 .33364 m .62868 .3377 L .62706 .33584 L F
.849 .796 .799 r
.62868 .3377 m .62527 .33759 L .62706 .33584 L F
.62868 .3377 m .6262 .3411 L .62527 .33759 L F
.53 .679 .934 r
.62878 .33433 m .62868 .3377 L .62734 .33364 L F
.62878 .33433 m .63335 .33654 L .62868 .3377 L F
.954 .769 .615 r
.4482 .52901 m .44707 .52613 L .44922 .52679 L F
.4482 .52901 m .44699 .52926 L .44707 .52613 L F
.784 .94 .59 r
.445 .53257 m .44699 .52926 L .4482 .52901 L F
.431 .161 .401 r
.62609 .34255 m .62315 .34374 L .6262 .3411 L F
0 0 0 r
.62494 .34347 m .62315 .34374 L .62609 .34255 L F
.62494 .34347 m .62137 .34482 L .62315 .34374 L F
.731 .942 .953 r
.48884 .47136 m .49118 .4686 L .49246 .46947 L F
.85 .982 .862 r
.49553 .46646 m .49246 .46947 L .49309 .46709 L F
.837 .973 .882 r
.49246 .46947 m .49118 .4686 L .49309 .46709 L F
.704 .324 .325 r
.66931 .36048 m .66777 .36134 L .67084 .36074 L F
.845 .446 0 r
.66777 .36134 m .66927 .36419 L .67084 .36074 L F
.232 .497 .9 r
.34551 .56094 m .34842 .56256 L .3454 .55929 L F
.617 .955 .815 r
.48641 .40898 m .48266 .41141 L .48247 .41096 L F
.796 .932 .564 r
.48247 .41096 m .48266 .41141 L .48111 .41286 L F
.537 .036 .012 r
.32019 .61816 m .32248 .62013 L .32001 .6202 L F
0 0 .078 r
.28405 .64436 m .28253 .64818 L .28363 .64704 L F
0 0 .109 r
.28363 .64704 m .28253 .64818 L .28173 .65107 L F
.572 .84 .995 r
.28347 .65495 m .28464 .65291 L .28173 .65107 L F
.28347 .65495 m .28618 .65428 L .28464 .65291 L F
.951 .937 .605 r
.50057 .4591 m .50147 .4543 L .50318 .45579 L F
.753 .772 .868 r
.62916 .37684 m .62711 .38064 L .6263 .37998 L F
.62916 .37684 m .631 .37858 L .62711 .38064 L F
.804 .983 .708 r
.55141 .42408 m .5529 .42256 L .55108 .42364 L F
.658 .944 .696 r
.55108 .42364 m .5529 .42256 L .55431 .42058 L F
.859 .923 .87 r
.47424 .48511 m .47554 .48106 L .47743 .48273 L F
.47424 .48511 m .47259 .48409 L .47554 .48106 L F
.081 0 .036 r
.28629 .6438 m .28748 .64131 L .28405 .64436 L F
0 0 .158 r
.28921 .63777 m .28748 .64131 L .28896 .63908 L F
0 0 0 r
.28896 .63908 m .28748 .64131 L .28629 .6438 L F
.483 .276 .522 r
.36047 .56034 m .36033 .56363 L .35822 .56362 L F
.897 .963 .637 r
.36204 .55569 m .36047 .56034 L .35932 .55625 L F
.859 .474 .315 r
.35749 .55533 m .35969 .55874 L .35986 .55859 L F
.897 .963 .637 r
.36154 .55715 m .35986 .55859 L .36047 .56034 L F
0 0 .23 r
.36163 .56124 m .36047 .56034 L .35986 .55859 L F
.859 .474 .315 r
.35969 .55874 m .36104 .56083 L .35986 .55859 L F
.897 .963 .637 r
.36204 .55569 m .35986 .55859 L .36154 .55715 L F
0 0 .23 r
.36163 .56124 m .36033 .56363 L .36047 .56034 L F
.194 0 .026 r
.41319 .47849 m .41204 .48097 L .40956 .4818 L F
.2 0 .124 r
.41642 .47595 m .41538 .47849 L .41319 .47849 L F
.431 .091 .287 r
.41538 .47849 m .41204 .48097 L .41319 .47849 L F
.667 .86 .466 r
.50211 .40402 m .50126 .40532 L .50095 .40614 L F
.506 .908 .811 r
.50095 .40614 m .49864 .40751 L .4997 .40745 L F
0 0 0 r
.49979 .40756 m .49864 .40751 L .50095 .40614 L F
.667 .86 .466 r
.50126 .40532 m .49979 .40756 L .50095 .40614 L F
.506 .908 .811 r
.50095 .40614 m .4997 .40745 L .50061 .40705 L F
.50095 .40614 m .50061 .40705 L .50314 .40594 L F
.14 0 .223 r
.28629 .6438 m .28405 .64436 L .28363 .64704 L F
.876 .682 .637 r
.52305 .38465 m .52318 .38521 L .52569 .3841 L F
.598 .822 .985 r
.52569 .3841 m .52318 .38521 L .5283 .38471 L F
.52569 .3841 m .52318 .38521 L .5283 .38471 L F
0 0 0 r
.55013 .38119 m .55141 .38154 L .55211 .38026 L F
.55013 .38119 m .54904 .38281 L .55141 .38154 L F
.531 .586 .855 r
.52394 .3801 m .52305 .38465 L .52194 .38054 L F
.52394 .3801 m .52569 .3841 L .52305 .38465 L F
.16 .348 .803 r
.52394 .3801 m .52683 .38189 L .52569 .3841 L F
.589 .857 .517 r
.52523 .38194 m .52305 .38465 L .52569 .3841 L F
.52523 .38194 m .52155 .38617 L .52305 .38465 L F
.941 .608 .372 r
.39696 .57301 m .39755 .57635 L .39952 .57719 L F
.825 .608 .609 r
.39562 .5791 m .39952 .57719 L .39755 .57635 L F
.39562 .5791 m .39853 .58005 L .39952 .57719 L F
.52 .806 .998 r
.64015 .34288 m .63583 .34215 L .63721 .34377 L F
.468 .324 .602 r
.32563 .62756 m .32455 .62434 L .3217 .62454 L F
.517 .352 .595 r
.32455 .62434 m .32563 .62756 L .32408 .62412 L F
.32455 .62434 m .3283 .62668 L .32563 .62756 L F
.98 .784 .57 r
.32976 .625 m .3283 .62668 L .32455 .62434 L F
.838 .93 .891 r
.4968 .46452 m .49553 .46646 L .49415 .4647 L F
.92 .931 .799 r
.49553 .46646 m .49309 .46709 L .49415 .4647 L F
.739 .838 .925 r
.48884 .47136 m .48526 .4717 L .48772 .47086 L F
.731 .942 .953 r
.48884 .47136 m .48772 .47086 L .49118 .4686 L F
.632 .488 .669 r
.52276 .36793 m .52329 .371 L .52002 .37132 L F
0 0 0 r
.52002 .37132 m .52172 .36942 L .52276 .36793 L F
0 0 .232 r
.52002 .37132 m .52112 .37174 L .52172 .36942 L F
.52002 .37132 m .52003 .37403 L .52112 .37174 L F
.645 .092 0 r
.58936 .34988 m .59118 .35199 L .59301 .3512 L F
.093 .648 .792 r
.59418 .35034 m .59299 .35027 L .59421 .35028 L F
.384 .821 .673 r
.59398 .35069 m .59418 .35034 L .59541 .34992 L F
.332 .037 .305 r
.59867 .34723 m .59541 .34992 L .6004 .34721 L F
.528 .109 .189 r
.59418 .35034 m .6004 .34721 L .59541 .34992 L F
.59418 .35034 m .59698 .3503 L .6004 .34721 L F
.093 .648 .792 r
.59418 .35034 m .59421 .35028 L .59698 .3503 L F
.384 .821 .673 r
.59301 .3512 m .59418 .35034 L .59398 .35069 L F
.59301 .3512 m .59118 .35199 L .59418 .35034 L F
.36 .694 .982 r
.36789 .57733 m .37179 .5786 L .37029 .57752 L F
.258 .638 .963 r
.37179 .5786 m .37383 .57774 L .37029 .57752 L F
.37179 .5786 m .37515 .57914 L .37383 .57774 L F
.523 .019 .001 r
.56174 .38728 m .55769 .38759 L .5589 .38767 L F
.887 .873 .818 r
.46795 .51957 m .47043 .51615 L .46911 .51479 L F
.882 .874 .824 r
.46911 .51479 m .47043 .51615 L .47303 .5124 L F
.887 .873 .818 r
.46795 .51957 m .46911 .51479 L .46667 .51871 L F
.872 .97 .852 r
.42493 .54194 m .42582 .54374 L .42945 .53945 L F
.55 .04 0 r
.56625 .38712 m .56449 .38773 L .56174 .38728 L F
.356 0 0 r
.56861 .38745 m .56449 .38773 L .56625 .38712 L F
.809 .674 .714 r
.49755 .48528 m .50215 .48268 L .50045 .48126 L F
.49755 .48528 m .49978 .486 L .50215 .48268 L F
.873 .863 .827 r
.50045 .48126 m .50215 .48268 L .50492 .47914 L F
.817 .984 .886 r
.51518 .43723 m .51718 .43761 L .51433 .43946 L F
.799 .984 .895 r
.51968 .43526 m .51718 .43761 L .51518 .43723 L F
0 0 0 r
.55682 .40298 m .55323 .40568 L .55439 .40622 L F
0 0 .294 r
.55316 .40512 m .55439 .40622 L .55323 .40568 L F
.55316 .40512 m .55287 .40825 L .55439 .40622 L F
.398 .711 .986 r
.52617 .41527 m .52466 .41661 L .52466 .41378 L F
.52617 .41527 m .52777 .41354 L .52466 .41661 L F
.52617 .41527 m .5288 .41513 L .52777 .41354 L F
.617 .955 .815 r
.48641 .40898 m .48247 .41096 L .48491 .40828 L F
.668 .95 .955 r
.48641 .40898 m .48712 .40707 L .48802 .40689 L F
.48641 .40898 m .48491 .40828 L .48712 .40707 L F
.205 0 .135 r
.41642 .47595 m .41768 .47743 L .41538 .47849 L F
.41642 .47595 m .41888 .47488 L .41768 .47743 L F
.717 .693 .826 r
.36072 .57762 m .35846 .58054 L .36109 .57912 L F
.551 .327 .529 r
.35846 .58054 m .36104 .58342 L .36109 .57912 L F
.838 .758 .775 r
.4599 .49927 m .46109 .50306 L .45892 .50153 L F
.802 .74 .796 r
.46384 .49963 m .46109 .50306 L .4599 .49927 L F
.758 .552 .618 r
.29967 .54276 m .30145 .54631 L .30391 .54323 L F
.785 .592 .639 r
.30391 .54323 m .30145 .54631 L .30581 .54669 L F
.62 .952 .926 r
.36603 .57681 m .3662 .57769 L .36789 .57733 L F
.82 .85 .87 r
.56568 .40306 m .56944 .40227 L .56739 .40032 L F
.777 .845 .903 r
.56739 .40032 m .56944 .40227 L .57062 .39986 L F
.449 0 0 r
.60037 .38483 m .6033 .38611 L .59913 .38564 L F
.485 .011 .054 r
.60037 .38483 m .60314 .38498 L .6033 .38611 L F
0 .362 .774 r
.59063 .37427 m .5856 .37146 L .58715 .37498 L F
.714 .831 .385 r
.58784 .37766 m .59063 .37427 L .58715 .37498 L F
.773 .47 .474 r
.40681 .49237 m .4053 .49496 L .40374 .4927 L F
.773 .879 .457 r
.40711 .49138 m .4053 .49496 L .40681 .49237 L F
.373 .665 .971 r
.31779 .67504 m .3204 .67713 L .32203 .6766 L F
.873 .863 .827 r
.50045 .48126 m .50492 .47914 L .50343 .47745 L F
.805 .856 .888 r
.50343 .47745 m .50492 .47914 L .50812 .47611 L F
.886 .984 .815 r
.64074 .39187 m .64347 .38845 L .64111 .38901 L F
.891 .986 .802 r
.63992 .39098 m .64074 .39187 L .64111 .38901 L F
.02 0 .023 r
.30068 .62695 m .29869 .62813 L .29884 .62912 L F
.89 .686 .62 r
.35125 .64454 m .35183 .64147 L .34928 .64053 L F
.856 .964 .872 r
.53133 .40823 m .52732 .41018 L .53011 .40704 L F
.714 .974 .925 r
.53226 .40644 m .53133 .40823 L .53011 .40704 L F
.204 0 .342 r
.29209 .63334 m .28921 .63777 L .29138 .63664 L F
.265 .025 .351 r
.28921 .63777 m .29155 .63949 L .29138 .63664 L F
.28921 .63777 m .28896 .63908 L .29155 .63949 L F
.56 .411 .635 r
.27532 .55602 m .27692 .56122 L .27816 .56049 L F
.98 .784 .57 r
.32976 .625 m .33008 .62773 L .3283 .62668 L F
.695 .836 .951 r
.33008 .62773 m .32563 .62756 L .3283 .62668 L F
.535 .566 .832 r
.3344 .63106 m .33008 .62773 L .33261 .62699 L F
.789 .712 .779 r
.33737 .66444 m .34162 .66479 L .33892 .66821 L F
.125 0 0 r
.4224 .46086 m .42581 .45837 L .42332 .45923 L F
.134 0 .029 r
.4224 .46086 m .42332 .45923 L .42009 .46184 L F
.824 .702 .73 r
.30572 .56662 m .3038 .57039 L .30741 .57051 L F
.808 .668 .709 r
.3038 .57039 m .30657 .57306 L .30741 .57051 L F
0 0 0 r
.43581 .54717 m .43476 .54888 L .43296 .55033 L F
.43296 .55033 m .43367 .55129 L .43138 .55206 L F
.43296 .55033 m .43476 .54888 L .43367 .55129 L F
.295 0 0 r
.35133 .5634 m .35096 .56422 L .3493 .56359 L F
0 .48 .851 r
.35329 .56614 m .35178 .56502 L .35133 .5634 L F
.35178 .56502 m .3509 .56437 L .3511 .56391 L F
.35178 .56502 m .3511 .56391 L .35133 .5634 L F
.35178 .56502 m .35201 .56509 L .3509 .56437 L F
.35329 .56614 m .35201 .56509 L .35178 .56502 L F
.982 .708 .329 r
.35331 .56887 m .35201 .56509 L .35329 .56614 L F
.46 .185 .408 r
.35199 .56537 m .35251 .56524 L .35201 .56509 L F
.35251 .56524 m .35538 .56451 L .35201 .56509 L F
.982 .708 .329 r
.35331 .56887 m .35188 .56758 L .35201 .56509 L F
.46 .185 .408 r
.35188 .56758 m .35284 .56674 L .35199 .56537 L F
.35284 .56674 m .35538 .56451 L .35199 .56537 L F
.713 .18 0 r
.35538 .56451 m .35003 .56149 L .35157 .56429 L F
.35476 .56461 m .35157 .56429 L .35201 .56509 L F
.35538 .56451 m .35157 .56429 L .35476 .56461 L F
.295 0 0 r
.35096 .56422 m .3509 .56437 L .35051 .56418 L F
.35096 .56422 m .35051 .56418 L .3493 .56359 L F
.869 .744 .722 r
.34417 .66714 m .34162 .66479 L .34258 .66841 L F
.34417 .66714 m .34302 .66401 L .34162 .66479 L F
0 .061 .606 r
.58811 .39458 m .58919 .39869 L .58955 .39753 L F
.431 0 0 r
.58919 .39869 m .5893 .39932 L .58955 .39753 L F
.392 .779 .99 r
.58919 .39869 m .59241 .39871 L .59206 .39997 L F
.283 .771 .909 r
.33123 .61749 m .33282 .61667 L .32901 .61847 L F
.33123 .61749 m .33404 .61708 L .33282 .61667 L F
.345 0 .091 r
.33428 .62058 m .33123 .61749 L .33121 .62023 L F
.861 .556 .471 r
.33121 .62023 m .33123 .61749 L .32901 .61847 L F
.611 .799 .374 r
.64574 .38471 m .64478 .38625 L .64347 .38845 L F
.911 .982 .756 r
.64864 .38137 m .64537 .38469 L .64574 .38471 L F
.871 .843 .379 r
.64537 .38469 m .64478 .38625 L .64574 .38471 L F
.735 .733 .849 r
.3186 .67161 m .31654 .67364 L .31585 .67258 L F
0 .354 .816 r
.5242 .40058 m .52622 .40165 L .52447 .39972 L F
.835 .774 .794 r
.63228 .37714 m .62916 .37684 L .63097 .3755 L F
.63228 .37714 m .631 .37858 L .62916 .37684 L F
.86 .894 .858 r
.6354 .37363 m .63228 .37714 L .63097 .3755 L F
.798 .937 .921 r
.49959 .46008 m .4989 .45934 L .50057 .4591 L F
.951 .937 .605 r
.50057 .4591 m .4997 .45813 L .50147 .4543 L F
.881 .993 .772 r
.50057 .4591 m .4989 .45934 L .4997 .45813 L F
.488 .318 .576 r
.36033 .56363 m .35848 .56669 L .35822 .56362 L F
.332 0 .234 r
.43531 .54464 m .43496 .54555 L .43479 .5438 L F
.968 .757 .565 r
.43504 .54499 m .43535 .5447 L .43479 .5438 L F
.43535 .5447 m .43711 .54309 L .43479 .5438 L F
.332 0 .234 r
.43565 .54379 m .43531 .54464 L .43479 .5438 L F
.847 .974 .664 r
.43797 .54316 m .43575 .54455 L .43581 .54717 L F
.43575 .54455 m .43529 .54484 L .43535 .5451 L F
.43575 .54455 m .43535 .5451 L .43581 .54717 L F
.43529 .54484 m .43514 .54527 L .43516 .54532 L F
.43533 .54503 m .43516 .54532 L .43581 .54717 L F
.43529 .54484 m .43516 .54532 L .43533 .54503 L F
.832 1 .809 r
.43581 .54717 m .43496 .54555 L .43476 .54888 L F
.43581 .54717 m .43514 .54527 L .43496 .54555 L F
.43514 .54527 m .43504 .54499 L .43496 .54555 L F
.332 0 .234 r
.43853 .54375 m .43507 .54549 L .43514 .54527 L F
.43614 .54378 m .43514 .54527 L .43565 .54379 L F
.847 .974 .664 r
.43797 .54316 m .43711 .54309 L .43504 .54499 L F
.332 0 .234 r
.43853 .54375 m .43514 .54527 L .43614 .54378 L F
.318 .069 .371 r
.43496 .54566 m .4379 .54632 L .43492 .54966 L F
.43496 .54555 m .43502 .54556 L .43496 .54566 L F
.43502 .54556 m .4379 .54632 L .43496 .54566 L F
.332 0 .234 r
.43853 .54375 m .4379 .54632 L .43502 .54556 L F
.43507 .54549 m .43502 .54556 L .43496 .54555 L F
.43853 .54375 m .43502 .54556 L .43507 .54549 L F
.43507 .54549 m .43496 .54555 L .43565 .54379 L F
.847 .974 .664 r
.43529 .54484 m .43504 .54499 L .43514 .54527 L F
.665 .965 .776 r
.43797 .54316 m .43942 .54106 L .43711 .54309 L F
.51 0 0 r
.60609 .39767 m .61044 .39874 L .60865 .39914 L F
.412 .856 .772 r
.60865 .39914 m .61044 .39874 L .61296 .3975 L F
.951 .929 .743 r
.42481 .56691 m .42507 .5699 L .42658 .56797 L F
0 0 0 r
.44694 .44155 m .44611 .4437 L .44908 .44063 L F
.935 .723 .591 r
.35773 .54953 m .35716 .55291 L .35931 .5534 L F
0 0 0 r
.51887 .39772 m .51752 .39977 L .51615 .40074 L F
.14 0 0 r
.52197 .39696 m .51752 .39977 L .51887 .39772 L F
.833 .735 .756 r
.42945 .53945 m .43174 .53649 L .42804 .53547 L F
.797 .544 .554 r
.43314 .53916 m .43174 .53649 L .42945 .53945 L F
.899 .668 .581 r
.30572 .54954 m .3053 .5525 L .30881 .55355 L F
.892 .721 .662 r
.3053 .5525 m .30695 .55644 L .30881 .55355 L F
.808 .593 .611 r
.30881 .55355 m .30695 .55644 L .31121 .55699 L F
.78 .493 .501 r
.65762 .35028 m .65967 .35362 L .66013 .35139 L F
.425 .161 .407 r
.66013 .35139 m .66256 .35252 L .66228 .35007 L F
.66013 .35139 m .65967 .35362 L .66256 .35252 L F
.834 .867 .869 r
.52862 .39978 m .53337 .39865 L .5312 .39697 L F
.52862 .39978 m .52995 .40142 L .53337 .39865 L F
.863 .815 .8 r
.5312 .39697 m .53337 .39865 L .53555 .3948 L F
.804 .669 .715 r
.30654 .55903 m .31121 .55699 L .30695 .55644 L F
.30654 .55903 m .30893 .56065 L .31121 .55699 L F
.832 .871 .873 r
.51574 .46825 m .52023 .46661 L .51874 .46494 L F
.875 .874 .832 r
.51874 .46494 m .52023 .46661 L .52284 .46285 L F
.735 .48 .543 r
.30096 .5492 m .30581 .54669 L .30145 .54631 L F
.30096 .5492 m .30572 .54954 L .30581 .54669 L F
.791 .725 .791 r
.3997 .56309 m .4011 .56698 L .40397 .56362 L F
.87 .706 .677 r
.42145 .57393 m .42052 .57704 L .42026 .57663 L F
.89 .624 .53 r
.41995 .5745 m .42021 .57459 L .42255 .57233 L F
.64 .904 .591 r
.42255 .57233 m .42145 .57393 L .42499 .56998 L F
0 0 .173 r
.42233 .57532 m .42145 .57393 L .42255 .57233 L F
.89 .624 .53 r
.42021 .57459 m .42233 .57532 L .42255 .57233 L F
.64 .904 .591 r
.42255 .57233 m .42499 .56998 L .42507 .5699 L F
.71 .724 .203 r
.65684 .3479 m .65715 .34706 L .65545 .3468 L F
.65684 .3479 m .65624 .35039 L .65715 .34706 L F
.986 .743 .48 r
.65715 .34706 m .65624 .35039 L .65762 .35028 L F
.727 .609 .725 r
.35418 .54664 m .35551 .54679 L .35379 .54345 L F
.785 .54 .566 r
.35082 .54919 m .35551 .54679 L .35418 .54664 L F
.35082 .54919 m .35515 .54967 L .35551 .54679 L F
.73 .489 .562 r
.35551 .54679 m .35515 .54967 L .35773 .54953 L F
.384 .321 .663 r
.54633 .34558 m .54881 .3466 L .54936 .34407 L F
.811 .713 .757 r
.46384 .49963 m .4599 .49927 L .46229 .49561 L F
.792 .702 .766 r
.34061 .66028 m .34162 .66479 L .33737 .66444 L F
0 0 .311 r
.34251 .6663 m .34162 .66479 L .34302 .66401 L F
.34251 .6663 m .34258 .66841 L .34162 .66479 L F
.505 .401 .67 r
.52587 .37007 m .52276 .36793 L .52568 .36718 L F
.036 0 0 r
.52276 .36793 m .52511 .36742 L .52568 .36718 L F
.505 .401 .67 r
.52587 .37007 m .52329 .371 L .52276 .36793 L F
.036 0 0 r
.52276 .36793 m .52172 .36942 L .52511 .36742 L F
.941 .952 .755 r
.53464 .40999 m .53772 .40798 L .53643 .40724 L F
.53464 .40999 m .53565 .4116 L .53772 .40798 L F
0 0 .39 r
.60474 .37365 m .60617 .37641 L .60667 .37815 L F
0 0 .128 r
.60743 .37846 m .60667 .37815 L .60617 .37641 L F
.60743 .37846 m .60646 .38031 L .60667 .37815 L F
.882 .874 .824 r
.46911 .51479 m .47303 .5124 L .47208 .5118 L F
.855 .99 .844 r
.47208 .5118 m .47303 .5124 L .47601 .50929 L F
0 0 0 r
.43314 .53916 m .43524 .53847 L .43681 .53711 L F
.712 .987 .852 r
.43524 .53847 m .43951 .5362 L .43681 .53711 L F
.911 .982 .756 r
.64864 .38137 m .64663 .38199 L .64537 .38469 L F
.744 .982 .911 r
.6498 .37896 m .64864 .38137 L .65024 .37992 L F
.77 .996 .807 r
.6498 .37896 m .64663 .38199 L .64864 .38137 L F
.499 .019 .048 r
.3834 .48557 m .38159 .48752 L .3793 .4863 L F
.483 .022 .083 r
.38587 .48562 m .38159 .48752 L .3834 .48557 L F
.749 .713 .818 r
.26852 .59089 m .2731 .59158 L .27119 .59012 L F
.676 .847 .965 r
.27119 .59012 m .2731 .59158 L .27549 .59035 L F
0 0 0 r
.54486 .38978 m .54112 .39099 L .54205 .39004 L F
.54112 .39099 m .53865 .3921 L .54205 .39004 L F
.52155 .38617 m .5211 .38749 L .52088 .38821 L F
.786 .401 .325 r
.2887 .55375 m .29314 .55563 L .29033 .55107 L F
.2887 .55375 m .28916 .55655 L .29314 .55563 L F
0 0 .173 r
.29314 .55563 m .29433 .55168 L .29033 .55107 L F
.29314 .55563 m .29411 .55503 L .29433 .55168 L F
0 0 0 r
.49736 .42022 m .49599 .42199 L .49819 .4183 L F
.603 .897 .607 r
.49437 .4232 m .49599 .42199 L .49736 .42022 L F
.51 .825 .51 r
.49609 .42145 m .49437 .4232 L .49736 .42022 L F
.707 .757 .256 r
.49609 .42145 m .49605 .42159 L .49437 .4232 L F
.204 0 .128 r
.49275 .42476 m .49599 .42199 L .49437 .4232 L F
.707 .757 .256 r
.49605 .42159 m .49472 .42582 L .49437 .4232 L F
.204 0 .128 r
.49271 .4248 m .49275 .42476 L .49437 .4232 L F
.681 .567 .72 r
.28153 .54878 m .28197 .55326 L .28464 .55064 L F
.896 .662 .577 r
.28302 .55629 m .28316 .5573 L .28197 .55326 L F
.104 0 .041 r
.41562 .46681 m .41443 .46582 L .4132 .46778 L F
.41562 .46681 m .41647 .46503 L .41443 .46582 L F
.662 .884 .98 r
.32203 .6766 m .32696 .67649 L .32462 .67638 L F
0 0 0 r
.32696 .67649 m .32775 .67689 L .32462 .67638 L F
.32696 .67649 m .32939 .67574 L .32775 .67689 L F
.292 0 .283 r
.29263 .6346 m .29209 .63334 L .29138 .63664 L F
.838 .926 .89 r
.60062 .34247 m .59872 .34426 L .59783 .34255 L F
.928 .726 .24 r
.59872 .34426 m .59805 .34419 L .59783 .34255 L F
.869 .925 .861 r
.51433 .43946 m .51324 .44115 L .51218 .4401 L F
.887 .611 .513 r
.34941 .54247 m .35418 .54664 L .35379 .54345 L F
.34941 .54247 m .3494 .54554 L .35418 .54664 L F
.878 .706 .665 r
.34918 .54836 m .35418 .54664 L .3494 .54554 L F
.34918 .54836 m .35082 .54919 L .35418 .54664 L F
.802 .983 .895 r
.60241 .35526 m .60164 .35797 L .60455 .3556 L F
.841 .998 .785 r
.60241 .35526 m .59949 .35867 L .60164 .35797 L F
.784 .94 .59 r
.445 .53257 m .44471 .53211 L .44699 .52926 L F
.884 .86 .812 r
.53679 .38997 m .53865 .3921 L .54118 .38807 L F
.411 .227 .518 r
.54118 .38807 m .53865 .3921 L .54112 .39099 L F
.601 .788 .97 r
.53679 .38997 m .53865 .3921 L .54112 .39099 L F
.118 0 .358 r
.5831 .35107 m .58279 .35351 L .58474 .34993 L F
.936 .966 .737 r
.53986 .44257 m .542 .43902 L .53983 .43972 L F
.796 .901 .494 r
.54268 .43667 m .542 .43902 L .5439 .43522 L F
.821 .999 .798 r
.53983 .43972 m .542 .43902 L .54268 .43667 L F
.707 .451 .534 r
.52453 .39432 m .52894 .3964 L .5254 .39746 L F
.954 .706 .525 r
.33927 .54666 m .33681 .54567 L .33616 .54158 L F
.867 .692 .165 r
.33927 .54666 m .33863 .54756 L .33681 .54567 L F
.33927 .54666 m .3392 .54947 L .33863 .54756 L F
.799 .775 .831 r
.3023 .63642 m .30123 .64115 L .30123 .63637 L F
.3023 .63642 m .3042 .63849 L .30123 .64115 L F
.387 .706 .985 r
.33341 .67453 m .33597 .67467 L .33405 .67328 L F
.33341 .67453 m .33597 .67467 L .33405 .67328 L F
.855 .99 .844 r
.47208 .5118 m .47601 .50929 L .47463 .50828 L F
.884 .934 .847 r
.47745 .50489 m .47601 .50929 L .47865 .5058 L F
.47745 .50489 m .47463 .50828 L .47601 .50929 L F
.806 .791 .838 r
.52432 .45817 m .52489 .4615 L .52571 .45949 L F
.52432 .45817 m .52106 .46123 L .52489 .4615 L F
.812 .781 .824 r
.52106 .46123 m .52284 .46285 L .52489 .4615 L F
0 0 0 r
.60384 .36773 m .60261 .36966 L .60113 .37055 L F
.554 .848 .998 r
.603 .37256 m .60113 .37055 L .60261 .36966 L F
.836 .998 .829 r
.56884 .36885 m .56612 .37178 L .56686 .36901 L F
.668 .866 .974 r
.56686 .36901 m .56593 .37163 L .56443 .37042 L F
0 0 0 r
.5636 .37185 m .56686 .36901 L .56443 .37042 L F
.802 .937 .574 r
.56686 .36901 m .56532 .37042 L .56776 .36646 L F
.56686 .36901 m .56776 .36646 L .56795 .36616 L F
.668 .866 .974 r
.56686 .36901 m .56612 .37178 L .56593 .37163 L F
0 0 0 r
.47385 .42107 m .47162 .42236 L .47064 .42398 L F
.459 .583 .89 r
.54001 .41468 m .53565 .4116 L .53871 .4134 L F
.988 .726 .361 r
.53871 .4134 m .54004 .41779 L .54001 .41468 L F
.425 .06 .239 r
.43164 .46647 m .43397 .46756 L .43136 .4679 L F
.43164 .46647 m .4345 .46602 L .43397 .46756 L F
.706 .719 .859 r
.45015 .51948 m .4475 .52054 L .44568 .51885 L F
.76 .534 .59 r
.33571 .52642 m .33572 .52925 L .3396 .52937 L F
.96 .892 .716 r
.45625 .50995 m .45374 .51119 L .45434 .50859 L F
.45625 .50995 m .45516 .51238 L .45374 .51119 L F
.801 .496 .472 r
.65481 .35286 m .65762 .35028 L .65624 .35039 L F
.65481 .35286 m .65967 .35362 L .65762 .35028 L F
.102 0 0 r
.54416 .38531 m .54323 .3863 L .54689 .38439 L F
.738 .622 .73 r
.33703 .62736 m .3344 .63106 L .33261 .62699 L F
.968 .774 .589 r
.49275 .41358 m .49435 .41471 L .49336 .41155 L F
.276 .674 .97 r
.49275 .41358 m .49752 .41513 L .49435 .41471 L F
.283 .609 .955 r
.33791 .62591 m .3394 .62795 L .33703 .62736 L F
.33791 .62591 m .3394 .62795 L .33703 .62736 L F
.891 .957 .836 r
.48019 .50149 m .47865 .5058 L .48188 .50291 L F
.48019 .50149 m .47745 .50489 L .47865 .5058 L F
0 .219 .634 r
.53702 .41232 m .53565 .4116 L .53464 .40999 L F
.53702 .41232 m .53871 .4134 L .53565 .4116 L F
.882 .861 .815 r
.4031 .57359 m .40111 .57184 L .40549 .57048 L F
.238 .491 .894 r
.40621 .56855 m .40764 .57131 L .40549 .57048 L F
.706 .975 .92 r
.40549 .57048 m .40111 .57184 L .40621 .56855 L F
.499 .197 .385 r
.42976 .46846 m .4247 .47175 L .42637 .46874 L F
.637 .909 .606 r
.49819 .4183 m .49974 .41361 L .49752 .41513 L F
.117 .241 .717 r
.49961 .4163 m .49819 .4183 L .49752 .41513 L F
.637 .909 .606 r
.49819 .4183 m .50127 .415 L .49961 .4163 L F
0 0 0 r
.49961 .4163 m .49736 .42022 L .49819 .4183 L F
.948 .65 .439 r
.50445 .44542 m .50256 .44657 L .50309 .444 L F
.50445 .44542 m .50456 .44818 L .50256 .44657 L F
.841 .939 .889 r
.56073 .39548 m .5567 .39708 L .55912 .39384 L F
.717 .834 .937 r
.56319 .39407 m .56073 .39548 L .55912 .39384 L F
.454 .18 .407 r
.37616 .56675 m .37818 .56707 L .37876 .56433 L F
.597 .84 .99 r
.37935 .56169 m .37876 .56433 L .37731 .56268 L F
.37935 .56169 m .37876 .56433 L .37731 .56268 L F
0 0 0 r
.37876 .56433 m .37935 .56169 L .38153 .56369 L F
.37876 .56433 m .37909 .56477 L .37935 .56169 L F
.37876 .56433 m .37818 .56707 L .37909 .56477 L F
.43 .134 .36 r
.26823 .57075 m .27097 .57029 L .27254 .56834 L F
.573 .476 .706 r
.26823 .57075 m .27103 .57232 L .27097 .57029 L F
.26823 .57075 m .26857 .57298 L .27103 .57232 L F
.692 .562 .703 r
.28153 .54878 m .28464 .55064 L .28432 .54693 L F
.488 .803 1 r
.60682 .35095 m .60529 .34966 L .60268 .35029 L F
.60682 .35095 m .60529 .34966 L .60268 .35029 L F
.278 0 .193 r
.52904 .3639 m .52741 .36703 L .52568 .36718 L F
0 0 0 r
.5306 .36237 m .52766 .36675 L .52904 .3639 L F
.372 .418 .78 r
.52801 .36698 m .52847 .3685 L .52778 .36817 L F
.52768 .36701 m .52778 .36817 L .52568 .36718 L F
.52801 .36698 m .52778 .36817 L .52768 .36701 L F
0 0 0 r
.52766 .36675 m .52722 .36741 L .52741 .36703 L F
.52766 .36675 m .52741 .36703 L .52904 .3639 L F
.372 .418 .78 r
.52755 .36547 m .52787 .36651 L .52568 .36718 L F
.52787 .36651 m .52741 .36703 L .52568 .36718 L F
.608 .405 .581 r
.52766 .36675 m .52755 .36547 L .52722 .36741 L F
.5306 .36237 m .52755 .36547 L .52766 .36675 L F
.372 .418 .78 r
.52787 .36651 m .52801 .36698 L .52741 .36703 L F
.278 0 .193 r
.52741 .36703 m .52722 .36741 L .52568 .36718 L F
0 0 0 r
.5315 .36135 m .5306 .36237 L .52904 .3639 L F
.809 .355 .156 r
.34049 .62266 m .34186 .62113 L .33903 .62014 L F
.936 .57 .282 r
.34049 .62266 m .34256 .62391 L .34186 .62113 L F
.64 .904 .591 r
.42255 .57233 m .42507 .5699 L .42379 .56873 L F
.951 .929 .743 r
.42481 .56691 m .42379 .56873 L .42507 .5699 L F
.046 .21 .711 r
.36072 .57762 m .36109 .57912 L .36254 .57831 L F
0 0 .127 r
.36109 .57912 m .36167 .58182 L .36254 .57831 L F
.36109 .57912 m .36104 .58342 L .36167 .58182 L F
.18 .065 .477 r
.42079 .56005 m .42234 .5594 L .42204 .55666 L F
.579 .557 .793 r
.5581 .36684 m .562 .36906 L .56017 .36683 L F
.836 .703 .717 r
.30654 .55903 m .30404 .56264 L .30834 .56315 L F
.835 .71 .726 r
.30404 .56264 m .30572 .56662 L .30834 .56315 L F
.779 .681 .756 r
.30654 .55903 m .30834 .56315 L .30893 .56065 L F
.989 .74 .366 r
.6354 .37363 m .6342 .37225 L .6343 .36966 L F
.86 .894 .858 r
.6354 .37363 m .63097 .3755 L .6342 .37225 L F
.802 .792 .843 r
.40241 .57583 m .39755 .57635 L .40098 .57262 L F
.597 .13 .117 r
.40241 .57583 m .40079 .57834 L .39755 .57635 L F
.569 .438 .663 r
.4031 .57359 m .40241 .57583 L .40098 .57262 L F
.4031 .57359 m .40677 .5755 L .40241 .57583 L F
.123 0 0 r
.40677 .5755 m .40079 .57834 L .40241 .57583 L F
.886 .906 .836 r
.5439 .43522 m .54685 .43163 L .54524 .43022 L F
.865 .858 .404 r
.54685 .43163 m .54786 .42654 L .54524 .43022 L F
.178 0 .154 r
.45581 .4481 m .45867 .44533 L .45838 .44752 L F
.382 .12 .387 r
.46111 .44653 m .45867 .44533 L .4612 .44435 L F
.46111 .44653 m .45838 .44752 L .45867 .44533 L F
.973 .915 .684 r
.42102 .53268 m .41962 .53165 L .42112 .53043 L F
.954 .809 .66 r
.42102 .53268 m .41733 .53449 L .41962 .53165 L F
.255 .758 .715 r
.4183 .5386 m .41863 .53759 L .41733 .53449 L F
.954 .809 .66 r
.42102 .53268 m .41874 .53787 L .41863 .53759 L F
.41786 .53423 m .41863 .53759 L .41733 .53449 L F
.42102 .53268 m .41863 .53759 L .41786 .53423 L F
.255 .758 .715 r
.41863 .53759 m .42146 .53751 L .41963 .53446 L F
.4183 .5386 m .41882 .53842 L .41863 .53759 L F
.41882 .53842 m .42146 .53751 L .41863 .53759 L F
.41863 .53759 m .41963 .53446 L .41733 .53449 L F
.954 .809 .66 r
.41874 .53787 m .41874 .53788 L .41733 .53449 L F
.886 .906 .836 r
.5439 .43522 m .54524 .43022 L .54357 .43407 L F
.931 .889 .48 r
.54268 .43667 m .5439 .43522 L .54357 .43407 L F
.72 .559 .67 r
.638 .33653 m .63615 .33653 L .63828 .33616 L F
.638 .33653 m .63814 .33827 L .63615 .33653 L F
.419 .456 .792 r
.64131 .33549 m .638 .33653 L .63828 .33616 L F
.64131 .33549 m .642 .33698 L .638 .33653 L F
.782 .278 0 r
.64129 .35844 m .6426 .36035 L .64397 .36068 L F
.957 .902 .727 r
.64397 .36068 m .64412 .35743 L .64708 .35756 L F
.64397 .36068 m .6426 .36035 L .64412 .35743 L F
.88 .792 .758 r
.64726 .34358 m .64565 .34717 L .64824 .34756 L F
.429 0 0 r
.64565 .34717 m .6469 .3479 L .64824 .34756 L F
.584 .614 .848 r
.64726 .34358 m .64824 .34756 L .65118 .34614 L F
.474 .008 .066 r
.6469 .3479 m .65118 .34614 L .64824 .34756 L F
.557 .707 .941 r
.30636 .63767 m .3042 .63849 L .3023 .63642 L F
.203 .649 .948 r
.36789 .57733 m .37029 .57752 L .36843 .57626 L F
.2 0 .046 r
.41647 .46503 m .41892 .46419 L .42009 .46184 L F
.372 .022 .236 r
.41892 .46419 m .4224 .46086 L .42009 .46184 L F
.762 .754 .846 r
.49418 .49332 m .49656 .49193 L .49261 .4914 L F
.952 .64 .211 r
.34105 .55349 m .34017 .55452 L .33885 .55248 L F
.34105 .55349 m .34132 .55637 L .34017 .55452 L F
0 0 .264 r
.55447 .37148 m .55464 .37368 L .5541 .37363 L F
0 .249 .722 r
.39416 .57071 m .39592 .57172 L .39696 .57301 L F
.888 .744 .696 r
.39592 .57172 m .39755 .57635 L .39696 .57301 L F
.832 .781 .804 r
.30022 .57648 m .30161 .58002 L .30436 .57658 L F
.882 .861 .815 r
.4031 .57359 m .40098 .57262 L .40111 .57184 L F
.734 .958 .671 r
.57107 .36441 m .57207 .36207 L .57398 .36101 L F
.565 .162 .237 r
.38458 .48054 m .38855 .47816 L .38477 .47947 L F
.38458 .48054 m .3871 .48103 L .38855 .47816 L F
.365 0 .178 r
.3871 .48103 m .39109 .47765 L .38855 .47816 L F
.703 .262 .202 r
.63446 .39157 m .63615 .39326 L .63293 .39354 L F
.014 0 0 r
.44385 .44494 m .44144 .44599 L .44026 .44739 L F
.781 .734 .809 r
.34941 .54247 m .35379 .54345 L .35257 .53997 L F
.778 .732 .81 r
.35257 .53997 m .35379 .54345 L .35698 .54077 L F
.033 0 0 r
.46753 .42685 m .46855 .42539 L .46518 .42794 L F
.089 0 .041 r
.46753 .42685 m .47064 .42398 L .46855 .42539 L F
0 0 0 r
.47629 .4336 m .47729 .43266 L .4796 .43138 L F
.601 .835 .988 r
.49974 .41361 m .50127 .415 L .5026 .41263 L F
.716 .936 .617 r
.49961 .4163 m .50127 .415 L .5026 .41263 L F
.845 .726 .733 r
.30267 .5728 m .30022 .57648 L .30436 .57658 L F
.801 .71 .765 r
.30267 .5728 m .30436 .57658 L .30657 .57306 L F
0 .117 .641 r
.40664 .57718 m .40781 .57571 L .40677 .5755 L F
.473 .836 .993 r
.40946 .57657 m .40781 .57571 L .40664 .57718 L F
0 0 .153 r
.33655 .53983 m .33686 .5393 L .33703 .53595 L F
0 0 0 r
.33686 .5393 m .33616 .54158 L .33655 .53983 L F
.573 .201 .297 r
.33616 .54158 m .33365 .54231 L .33655 .53983 L F
.706 .971 .93 r
.60587 .35301 m .60455 .3556 L .60721 .35411 L F
.60587 .35301 m .60241 .35526 L .60455 .3556 L F
.563 .414 .637 r
.28464 .55064 m .28678 .54566 L .28432 .54693 L F
.836 .999 .792 r
.61142 .3608 m .61043 .36246 L .61266 .36062 L F
.848 .784 .789 r
.48348 .49532 m .48709 .4957 L .4857 .49225 L F
.879 .808 .774 r
.4826 .49798 m .48709 .4957 L .48348 .49532 L F
.4826 .49798 m .48472 .49945 L .48709 .4957 L F
.739 .736 .849 r
.4857 .49225 m .48709 .4957 L .48991 .49269 L F
.838 .926 .89 r
.60062 .34247 m .59783 .34255 L .59982 .34108 L F
.464 .81 .998 r
.59982 .34108 m .60388 .34163 L .60062 .34247 L F
.722 .201 0 r
.63566 .33574 m .63828 .33616 L .63615 .33653 L F
.63545 .33541 m .6366 .33572 L .63575 .33574 L F
.63545 .33541 m .63575 .33574 L .63566 .33574 L F
0 .477 .857 r
.63392 .33436 m .63518 .33511 L .63545 .33541 L F
.722 .201 0 r
.6366 .33572 m .63828 .33616 L .63566 .33574 L F
.63588 .33552 m .6369 .33613 L .63828 .33616 L F
0 .477 .857 r
.63518 .33511 m .6369 .33613 L .63545 .33541 L F
.286 .785 .862 r
.63828 .33616 m .6369 .33613 L .64131 .33549 L F
.568 .181 .269 r
.6369 .33613 m .64091 .33772 L .6413 .33558 L F
.64056 .3356 m .6413 .33558 L .64131 .33549 L F
.6369 .33613 m .6413 .33558 L .64056 .3356 L F
.952 .902 .521 r
.56945 .34925 m .56902 .34788 L .56961 .34615 L F
0 .368 .835 r
.56945 .34925 m .57138 .35032 L .56902 .34788 L F
.798 .969 .911 r
.56902 .34788 m .56674 .34962 L .56945 .34925 L F
.874 .988 .823 r
.54786 .42654 m .54818 .42803 L .55141 .42408 L F
.878 .85 .812 r
.48253 .47536 m .47822 .47741 L .48098 .47404 L F
.48253 .47536 m .47994 .47894 L .47822 .47741 L F
.881 .9 .84 r
.48526 .4717 m .48253 .47536 L .48098 .47404 L F
.684 .203 .104 r
.39102 .4874 m .38587 .48562 L .3904 .48582 L F
.523 .323 .55 r
.3904 .48582 m .39281 .48841 L .39102 .4874 L F
.884 .86 .812 r
.53679 .38997 m .54118 .38807 L .54112 .39099 L F
.737 .952 .946 r
.54323 .3863 m .54118 .38807 L .54234 .38571 L F
.548 .516 .772 r
.54112 .39099 m .54234 .38571 L .54118 .38807 L F
.849 .69 .685 r
.64708 .35756 m .64412 .35743 L .64528 .35363 L F
.765 .627 .707 r
.33572 .52925 m .33698 .53287 L .3396 .52937 L F
.399 .632 .948 r
.2982 .66737 m .30136 .67056 L .30323 .67012 L F
.293 .602 .951 r
.30136 .67056 m .30452 .67194 L .30323 .67012 L F
.67 .762 .919 r
.38114 .57179 m .37755 .57325 L .37572 .57056 L F
.808 .668 .709 r
.3038 .57039 m .30267 .5728 L .30657 .57306 L F
0 0 0 r
.5415 .42293 m .5389 .42551 L .54075 .42403 L F
.45 .825 .578 r
.54075 .42403 m .5389 .42551 L .53731 .42668 L F
.727 .62 .738 r
.60646 .38031 m .60717 .38471 L .60314 .38498 L F
.531 .068 .099 r
.60314 .38498 m .60717 .38471 L .60615 .38661 L F
.635 .697 .89 r
.60813 .38069 m .60717 .38471 L .60646 .38031 L F
.60813 .38069 m .61013 .38401 L .60717 .38471 L F
.23 0 0 r
.60717 .38471 m .60872 .38578 L .60615 .38661 L F
.60717 .38471 m .61013 .38401 L .60872 .38578 L F
.885 .756 .714 r
.42804 .53547 m .42591 .53899 L .42945 .53945 L F
.872 .97 .852 r
.42493 .54194 m .42945 .53945 L .42591 .53899 L F
.813 .765 .808 r
.65043 .34066 m .64726 .34358 L .65096 .34412 L F
.584 .614 .848 r
.64726 .34358 m .65118 .34614 L .65096 .34412 L F
.875 .874 .832 r
.51874 .46494 m .52284 .46285 L .52106 .46123 L F
0 0 0 r
.48977 .42757 m .49271 .4248 L .49273 .42808 L F
.062 0 .336 r
.49472 .42582 m .49271 .4248 L .49437 .4232 L F
.49472 .42582 m .49273 .42808 L .49271 .4248 L F
.869 .788 .769 r
.47994 .47894 m .47554 .48106 L .47822 .47741 L F
.47994 .47894 m .47743 .48273 L .47554 .48106 L F
0 0 .169 r
.58027 .3879 m .57941 .38789 L .58079 .38568 L F
.58027 .3879 m .57936 .39034 L .57941 .38789 L F
.769 .84 .905 r
.52432 .45817 m .52571 .45949 L .52783 .45807 L F
0 0 .434 r
.58199 .37292 m .58253 .37566 L .58154 .37782 L F
0 0 .193 r
.58237 .37829 m .58154 .37782 L .58253 .37566 L F
.58237 .37829 m .58155 .38056 L .58154 .37782 L F
0 0 .195 r
.55287 .40825 m .55352 .40861 L .55439 .40622 L F
.55295 .40895 m .55313 .41078 L .55352 .40861 L F
.019 0 .411 r
.55287 .40825 m .5524 .41383 L .55313 .41078 L F
.865 .799 .308 r
.55352 .40861 m .55281 .41256 L .55272 .4103 L F
0 0 0 r
.55396 .40835 m .55352 .40861 L .55272 .4103 L F
.55504 .40665 m .55352 .40861 L .55396 .40835 L F
0 0 .195 r
.55287 .40825 m .55295 .40895 L .55352 .40861 L F
.563 .414 .637 r
.28464 .55064 m .28758 .5508 L .28678 .54566 L F
.542 .295 .49 r
.28678 .54566 m .29101 .5456 L .29065 .54311 L F
.451 .336 .631 r
.28678 .54566 m .29023 .54911 L .29101 .5456 L F
.549 .012 0 r
.53229 .35482 m .53733 .35514 L .53361 .35435 L F
.764 .751 .84 r
.49261 .4914 m .49656 .49193 L .49539 .48835 L F
.81 .774 .819 r
.49539 .48835 m .49656 .49193 L .49935 .48881 L F
.578 .1 .083 r
.5288 .41513 m .53334 .41497 L .53167 .41644 L F
0 0 .326 r
.53334 .41497 m .53414 .41298 L .53167 .41644 L F
.53334 .41497 m .53436 .41565 L .53414 .41298 L F
.53334 .41497 m .53329 .41782 L .53436 .41565 L F
.8 .521 .516 r
.42308 .54848 m .41987 .54609 L .42365 .54654 L F
.926 .579 .355 r
.29212 .5725 m .29014 .56948 L .2928 .57011 L F
.29212 .5725 m .29033 .57367 L .29014 .56948 L F
.866 .751 .24 r
.29212 .5725 m .2914 .57535 L .29033 .57367 L F
.29212 .5725 m .29164 .57668 L .2914 .57535 L F
.758 .503 .546 r
.3639 .58066 m .36544 .5825 L .36104 .58342 L F
0 .221 .743 r
.36593 .58102 m .36544 .5825 L .3639 .58066 L F
.329 0 .155 r
.45581 .4481 m .45465 .45069 L .452 .45132 L F
.452 .103 .281 r
.45838 .44752 m .45465 .45069 L .45581 .4481 L F
.655 .971 .859 r
.63751 .3608 m .63882 .35908 L .64129 .35844 L F
.131 .236 .707 r
.63751 .3608 m .63919 .3622 L .63882 .35908 L F
.77 .462 .465 r
.4139 .49937 m .40949 .50139 L .4094 .49872 L F
.4139 .49937 m .41387 .50187 L .40949 .50139 L F
0 .413 .803 r
.41067 .4977 m .41289 .4984 L .4139 .49937 L F
.953 .7 .245 r
.41289 .4984 m .41387 .50187 L .4139 .49937 L F
.781 .506 .52 r
.35008 .53767 m .35477 .53635 L .35274 .53606 L F
.35008 .53767 m .35601 .53832 L .35477 .53635 L F
.621 .959 .871 r
.56884 .36885 m .56952 .36732 L .5712 .36727 L F
.56884 .36885 m .56686 .36901 L .56952 .36732 L F
.778 .732 .81 r
.35257 .53997 m .35698 .54077 L .35601 .53832 L F
.622 .597 .804 r
.35601 .53832 m .35698 .54077 L .35907 .53932 L F
.87 .885 .844 r
.48019 .50149 m .48188 .50291 L .48472 .49945 L F
.428 .867 .791 r
.44776 .53997 m .44488 .54078 L .44317 .54169 L F
.534 .893 .679 r
.44776 .53997 m .45005 .53821 L .44915 .53856 L F
.538 .924 .827 r
.44915 .53856 m .44488 .54078 L .44776 .53997 L F
.887 .795 .754 r
.41837 .52223 m .41979 .52606 L .41747 .52469 L F
.908 .504 .201 r
.42008 .52794 m .41747 .52469 L .41979 .52606 L F
.821 .77 .805 r
.42302 .522 m .41979 .52606 L .41837 .52223 L F
.108 .604 .904 r
.42429 .52921 m .42008 .52794 L .41979 .52606 L F
.605 .267 .37 r
.53793 .35754 m .53786 .36025 L .53399 .36027 L F
0 .038 .608 r
.53733 .35514 m .53857 .35698 L .53793 .35754 L F
.551 .223 .366 r
.54056 .35936 m .53786 .36025 L .53793 .35754 L F
0 .261 .768 r
.53857 .35698 m .54056 .35936 L .53793 .35754 L F
0 .233 .752 r
.38153 .56369 m .38336 .56517 L .38327 .5667 L F
.777 .326 .177 r
.38126 .56829 m .38327 .5667 L .38336 .56517 L F
.894 .937 .565 r
.53983 .43972 m .53832 .44489 L .53986 .44257 L F
.831 .531 .483 r
.49576 .48531 m .49978 .486 L .49755 .48528 L F
.838 .684 .691 r
.49576 .48531 m .49935 .48881 L .49978 .486 L F
.994 .759 .466 r
.33392 .53916 m .33232 .53791 L .33417 .53638 L F
.763 .692 .783 r
.33244 .53239 m .33417 .53638 L .33698 .53287 L F
.994 .759 .466 r
.33392 .53916 m .33232 .53791 L .33417 .53638 L F
.585 .432 .64 r
.33417 .53638 m .33703 .53595 L .33698 .53287 L F
.678 .976 .823 r
.54583 .34976 m .54247 .35224 L .54407 .35148 L F
0 0 0 r
.59443 .39588 m .59241 .39871 L .59449 .39426 L F
.59206 .39997 m .59241 .39871 L .59443 .39588 L F
.642 .859 .982 r
.61904 .34621 m .61498 .34633 L .61657 .34761 L F
0 0 0 r
.30123 .63637 m .30161 .63555 L .3023 .63642 L F
.972 .793 .602 r
.64583 .35091 m .64528 .35363 L .6442 .34954 L F
.879 .807 .774 r
.45516 .51238 m .45179 .51295 L .45374 .51119 L F
.45516 .51238 m .45289 .51606 L .45179 .51295 L F
.069 .257 .747 r
.58939 .38441 m .59037 .3823 L .58787 .38033 L F
0 0 .375 r
.58939 .38441 m .5907 .38492 L .59037 .3823 L F
.58939 .38441 m .58991 .38751 L .5907 .38492 L F
.752 .614 .706 r
.29955 .5396 m .29738 .54308 L .29967 .54276 L F
.764 .303 .152 r
.63882 .35908 m .6426 .36035 L .64129 .35844 L F
.773 .681 .762 r
.37063 .54258 m .37178 .54654 L .36743 .54597 L F
.179 .687 .901 r
.37178 .54654 m .36998 .54596 L .36743 .54597 L F
.102 .236 .717 r
.37063 .54258 m .37324 .54511 L .37178 .54654 L F
.032 0 0 r
.37324 .54511 m .36998 .54596 L .37178 .54654 L F
.19 0 0 r
.49966 .39702 m .50251 .39632 L .50375 .39464 L F
.059 0 0 r
.50375 .39464 m .50508 .39539 L .50657 .39429 L F
.50375 .39464 m .50251 .39632 L .50508 .39539 L F
.211 0 0 r
.54774 .38941 m .54486 .38978 L .54498 .38987 L F
.907 .808 .738 r
.34878 .65724 m .34988 .65462 L .34782 .65345 L F
.965 .843 .672 r
.34988 .65462 m .34976 .64988 L .34782 .65345 L F
0 0 0 r
.43827 .44872 m .4351 .45157 L .43732 .45013 L F
.114 0 .097 r
.43732 .45013 m .44026 .44739 L .43827 .44872 L F
.47 .88 .743 r
.61495 .3406 m .61672 .33921 L .61708 .33924 L F
.476 .896 .866 r
.61495 .3406 m .61343 .3405 L .61672 .33921 L F
.097 .421 .867 r
.37222 .48697 m .37354 .48743 L .37072 .48454 L F
.616 .749 .94 r
.37072 .48454 m .37222 .48697 L .36806 .48522 L F
.743 .653 .76 r
.44857 .51537 m .45015 .51948 L .44568 .51885 L F
.747 .655 .758 r
.45289 .51606 m .45015 .51948 L .44857 .51537 L F
.754 .947 .623 r
.51731 .37727 m .5146 .3809 L .51702 .3778 L F
0 0 0 r
.5146 .3809 m .5153 .3807 L .51702 .3778 L F
.51702 .3778 m .52021 .37703 L .51731 .37727 L F
.51702 .3778 m .51815 .37764 L .52021 .37703 L F
.51702 .3778 m .5153 .3807 L .51815 .37764 L F
.43072 .54255 m .43219 .54164 L .43314 .53916 L F
.004 0 .021 r
.43219 .54164 m .43524 .53847 L .43314 .53916 L F
.497 .119 .254 r
.48977 .42757 m .48883 .43023 L .48602 .42883 L F
.553 .233 .38 r
.49273 .42808 m .48883 .43023 L .48977 .42757 L F
.886 .866 .814 r
.29014 .56948 m .28745 .56918 L .29003 .56573 L F
.683 .366 .431 r
.29014 .56948 m .28832 .57293 L .28745 .56918 L F
.29014 .56948 m .29033 .57367 L .28832 .57293 L F
.702 .228 0 r
.34087 .62988 m .34364 .63317 L .34183 .63045 L F
.337 .817 .871 r
.38337 .58272 m .38169 .58268 L .37904 .58339 L F
.114 0 0 r
.38337 .58272 m .38588 .58297 L .38169 .58268 L F
.763 .697 .789 r
.38406 .58468 m .38493 .58367 L .38588 .58297 L F
.113 0 0 r
.38337 .58272 m .38598 .5829 L .38588 .58297 L F
.7 .817 .938 r
.38169 .58268 m .38588 .58297 L .38458 .58117 L F
.197 .53 .922 r
.38458 .58117 m .38588 .58297 L .38676 .58156 L F
.763 .697 .789 r
.38493 .58367 m .38676 .58156 L .38588 .58297 L F
.113 0 0 r
.38598 .5829 m .38661 .58294 L .38588 .58297 L F
0 0 0 r
.452 .45132 m .44879 .45414 L .44988 .4526 L F
0 0 .361 r
.42052 .57704 m .42116 .57907 L .42026 .57663 L F
.42052 .57704 m .42141 .57794 L .42116 .57907 L F
0 0 .06 r
.42233 .57532 m .42141 .57794 L .42052 .57704 L F
0 0 .505 r
.58811 .39458 m .58932 .3951 L .58896 .39247 L F
.58811 .39458 m .58931 .39703 L .58932 .3951 L F
0 0 0 r
.58932 .3951 m .58902 .39679 L .58932 .394 L F
0 0 .159 r
.58896 .39247 m .58932 .3951 L .58932 .394 L F
0 0 0 r
.58932 .3951 m .58932 .394 L .58932 .394 L F
0 0 .505 r
.58931 .39703 m .58955 .39753 L .58932 .3951 L F
.531 .068 .099 r
.60314 .38498 m .60615 .38661 L .6033 .38611 L F
.799 .984 .895 r
.51968 .43526 m .51518 .43723 L .51788 .43775 L F
.805 .536 .532 r
.42302 .522 m .41828 .51914 L .42162 .51858 L F
.42302 .522 m .41837 .52223 L .41828 .51914 L F
.878 .549 .044 r
.42162 .51858 m .42214 .52099 L .42302 .522 L F
.967 .667 .405 r
.42214 .52099 m .4243 .52405 L .42302 .522 L F
.44 .773 .997 r
.28618 .65428 m .28955 .65414 L .28464 .65291 L F
.532 .555 .824 r
.28618 .65428 m .29034 .65758 L .28955 .65414 L F
.18 0 .12 r
.46198 .43156 m .46444 .43043 L .46518 .42794 L F
.125 0 .101 r
.46518 .42794 m .46669 .4293 L .46753 .42685 L F
.46518 .42794 m .46444 .43043 L .46669 .4293 L F
.176 .482 .898 r
.30323 .67012 m .30452 .67194 L .30497 .67054 L F
.703 .984 .874 r
.30452 .67194 m .30649 .67052 L .30497 .67054 L F
.30452 .67194 m .30649 .67052 L .30497 .67054 L F
.219 0 .346 r
.52435 .37744 m .52394 .3801 L .52194 .38054 L F
.549 .895 .662 r
.57398 .36101 m .57207 .36207 L .57344 .36111 L F
.07 0 0 r
.57491 .36154 m .57398 .36101 L .57533 .35868 L F
.57491 .36154 m .57207 .36207 L .57398 .36101 L F
.838 .684 .691 r
.49576 .48531 m .49539 .48835 L .49935 .48881 L F
0 0 .078 r
.64202 .3468 m .64248 .34611 L .64284 .34257 L F
.727 .361 .357 r
.64202 .3468 m .63998 .34671 L .64248 .34611 L F
.64202 .3468 m .64182 .34852 L .63998 .34671 L F
.64202 .3468 m .6442 .34954 L .64182 .34852 L F
.805 .856 .888 r
.50343 .47745 m .50812 .47611 L .50632 .47479 L F
.869 .905 .855 r
.50812 .47611 m .50949 .4715 L .50632 .47479 L F
.50812 .47611 m .51093 .4729 L .50949 .4715 L F
.613 .216 .267 r
.34802 .53628 m .35008 .53767 L .35274 .53606 L F
.869 .925 .861 r
.51433 .43946 m .51218 .4401 L .51518 .43723 L F
.932 .893 .768 r
.53474 .44696 m .53832 .44489 L .53791 .44385 L F
.53474 .44696 m .53622 .44828 L .53832 .44489 L F
.894 .937 .565 r
.53983 .43972 m .53791 .44385 L .53832 .44489 L F
.702 .605 .745 r
.31543 .61328 m .31928 .61407 L .31913 .61178 L F
.395 0 0 r
.31625 .61444 m .31928 .61407 L .31543 .61328 L F
0 0 .307 r
.31913 .61178 m .31928 .61407 L .32001 .6126 L F
.576 .942 .856 r
.32001 .6126 m .31928 .61407 L .31625 .61444 L F
.87 .885 .844 r
.48019 .50149 m .48472 .49945 L .4826 .49798 L F
.183 .656 .934 r
.3749 .48227 m .37761 .48262 L .37747 .48289 L F
.094 0 0 r
.37761 .48262 m .3818 .4809 L .37747 .48289 L F
.881 .9 .84 r
.48526 .4717 m .48098 .47404 L .48401 .4711 L F
.711 .961 .945 r
.48526 .4717 m .48635 .46952 L .48772 .47086 L F
.48526 .4717 m .48401 .4711 L .48635 .46952 L F
0 0 0 r
.51244 .38456 m .51404 .38265 L .5146 .3809 L F
.129 .007 .432 r
.5116 .3868 m .51404 .38265 L .51244 .38456 L F
.965 .742 .551 r
.38588 .58297 m .38746 .5869 L .38551 .58641 L F
0 0 .242 r
.38452 .5734 m .38521 .56926 L .38286 .57271 L F
.505 .868 .985 r
.38286 .57271 m .38543 .5719 L .38452 .5734 L F
.818 .49 .435 r
.38588 .58297 m .39006 .5863 L .38746 .5869 L F
.476 .825 .997 r
.38746 .5869 m .38841 .58532 L .38551 .58641 L F
.38746 .5869 m .39006 .5863 L .38841 .58532 L F
.733 .671 .79 r
.28758 .5508 m .2887 .55375 L .29033 .55107 L F
.173 0 .101 r
.44203 .46283 m .44053 .46113 L .44297 .4601 L F
.44203 .46283 m .43962 .46392 L .44053 .46113 L F
.907 .855 .78 r
.50936 .41009 m .51122 .41165 L .51316 .40783 L F
.874 .988 .823 r
.54786 .42654 m .55141 .42408 L .55108 .42364 L F
0 0 0 r
.31543 .61328 m .312 .61686 L .31409 .61575 L F
.395 0 0 r
.31625 .61444 m .31543 .61328 L .31409 .61575 L F
.86 .927 .87 r
.62433 .38184 m .62091 .38227 L .62256 .38024 L F
.62433 .38184 m .62127 .38471 L .62091 .38227 L F
.763 .888 .934 r
.6263 .37998 m .62433 .38184 L .62256 .38024 L F
.188 0 0 r
.48602 .42883 m .48219 .43071 L .48237 .42756 L F
.48602 .42883 m .48491 .43026 L .48219 .43071 L F
.513 0 0 r
.48883 .43023 m .48491 .43026 L .48602 .42883 L F
.701 .963 .717 r
.39038 .58121 m .39293 .57965 L .39136 .57942 L F
.872 .985 .833 r
.39419 .57576 m .39293 .57965 L .39562 .5791 L F
.39419 .57576 m .39136 .57942 L .39293 .57965 L F
0 .362 .774 r
.59052 .3742 m .58972 .37339 L .5856 .37146 L F
.59063 .37427 m .58972 .37339 L .59052 .3742 L F
.876 .913 .51 r
.58972 .37339 m .58904 .37125 L .58904 .37098 L F
.219 .455 .873 r
.58904 .37125 m .58898 .37103 L .58499 .36933 L F
.58904 .37125 m .58903 .37121 L .58904 .37125 L F
.58903 .37121 m .58898 .37103 L .58904 .37125 L F
.5856 .37146 m .58904 .37125 L .58499 .36933 L F
.5856 .37146 m .58972 .37339 L .58904 .37125 L F
.295 .411 .81 r
.58499 .36933 m .589 .37104 L .58716 .36743 L F
0 .133 .67 r
.589 .37104 m .58899 .37093 L .58904 .37098 L F
.885 .665 .145 r
.58904 .37098 m .58812 .36624 L .58716 .36743 L F
.58904 .37098 m .58716 .36743 L .58887 .37027 L F
.58904 .37098 m .58887 .37027 L .58944 .37123 L F
.295 .411 .81 r
.589 .37104 m .58899 .37093 L .58716 .36743 L F
.885 .665 .145 r
.58904 .37098 m .58899 .37093 L .58887 .37027 L F
.295 .411 .81 r
.58899 .37093 m .58892 .37037 L .58887 .37027 L F
.58899 .37093 m .58887 .37027 L .58716 .36743 L F
.885 .665 .145 r
.58887 .37027 m .5884 .37036 L .58821 .36762 L F
.58899 .37093 m .5884 .37036 L .58887 .37027 L F
.58904 .37098 m .58821 .36762 L .58812 .36624 L F
.295 .411 .81 r
.589 .37104 m .58944 .37123 L .58892 .37037 L F
0 .133 .67 r
.58903 .37121 m .589 .37104 L .58904 .37098 L F
.589 .37104 m .58898 .37093 L .58899 .37093 L F
.58893 .37384 m .5884 .37036 L .58898 .37093 L F
.58893 .37384 m .58898 .37093 L .58903 .37121 L F
.876 .913 .51 r
.58904 .37125 m .58903 .37122 L .58903 .37121 L F
.58904 .37125 m .58903 .37121 L .58904 .37098 L F
.58972 .37339 m .58904 .37098 L .59156 .37197 L F
.219 .455 .873 r
.58904 .37125 m .58944 .37123 L .58898 .37103 L F
.58904 .37125 m .58972 .37339 L .58944 .37123 L F
.876 .913 .51 r
.58972 .37339 m .58898 .37263 L .58903 .37122 L F
.58972 .37339 m .58893 .37384 L .58898 .37263 L F
.714 .831 .385 r
.58784 .37766 m .58972 .37339 L .59063 .37427 L F
.58784 .37766 m .58852 .37572 L .58972 .37339 L F
0 0 .348 r
.58784 .37766 m .58963 .37798 L .58852 .37572 L F
.58784 .37766 m .58787 .38033 L .58963 .37798 L F
.643 .352 .462 r
.33428 .62058 m .33903 .62014 L .33712 .61863 L F
.92 .921 .797 r
.32834 .61339 m .32803 .61726 L .32585 .61557 L F
.769 .84 .905 r
.52432 .45817 m .52783 .45807 L .52527 .45675 L F
.774 .805 .878 r
.52783 .45807 m .52914 .45368 L .52527 .45675 L F
.52783 .45807 m .53151 .45554 L .52914 .45368 L F
0 0 0 r
.28896 .63908 m .28629 .6438 L .28862 .643 L F
.267 .008 .323 r
.29155 .63949 m .28896 .63908 L .28862 .643 L F
.611 .955 .885 r
.50328 .40461 m .50314 .40594 L .50523 .40415 L F
.50328 .40461 m .50095 .40614 L .50314 .40594 L F
.907 .808 .738 r
.34878 .65724 m .34782 .65345 L .3475 .6559 L F
.944 .936 .757 r
.34523 .65991 m .34878 .65724 L .3475 .6559 L F
.34523 .65991 m .34667 .66059 L .34878 .65724 L F
.859 .514 .398 r
.42116 .57907 m .41706 .57619 L .42026 .57663 L F
.907 .855 .78 r
.50936 .41009 m .51316 .40783 L .51154 .40857 L F
.639 .836 .433 r
.51557 .40401 m .5145 .40554 L .51452 .40568 L F
0 0 0 r
.5176 .40268 m .5145 .40554 L .51557 .40401 L F
.52 .847 .558 r
.51454 .40551 m .51598 .40406 L .5145 .40554 L F
.5176 .40268 m .51598 .40406 L .51454 .40551 L F
.324 0 0 r
.51997 .40338 m .51792 .40373 L .5176 .40268 L F
.51792 .40373 m .51598 .40406 L .51659 .40354 L F
.51792 .40373 m .51659 .40354 L .5176 .40268 L F
.239 .033 .386 r
.5176 .40268 m .51615 .40074 L .51752 .39977 L F
.529 .36 .596 r
.52022 .39902 m .5176 .40268 L .51752 .39977 L F
.52022 .39902 m .52053 .40203 L .5176 .40268 L F
.327 0 .098 r
.52053 .40203 m .51997 .40338 L .5176 .40268 L F
.352 .232 .574 r
.5226 .40091 m .52053 .40203 L .52022 .39902 L F
.014 0 0 r
.5226 .40091 m .51997 .40338 L .52053 .40203 L F
.615 .417 .59 r
.5226 .40091 m .52292 .40384 L .51997 .40338 L F
.5226 .40091 m .52292 .40384 L .51997 .40338 L F
.49 .032 .09 r
.51997 .40338 m .51847 .40551 L .51598 .40406 L F
0 0 0 r
.52153 .40232 m .51997 .40338 L .52292 .40384 L F
.388 .346 .691 r
.5197 .40394 m .51974 .40399 L .52153 .40232 L F
.51974 .40399 m .51974 .404 L .51975 .40399 L F
.51974 .40399 m .51975 .40399 L .52153 .40232 L F
.157 .31 .769 r
.51557 .40401 m .51224 .40146 L .51615 .40074 L F
.239 .033 .386 r
.5176 .40268 m .51557 .40401 L .51615 .40074 L F
.802 .463 .414 r
.51445 .4024 m .51967 .40398 L .51722 .40013 L F
.51967 .40398 m .51974 .404 L .5197 .40394 L F
.51967 .40398 m .5197 .40394 L .51722 .40013 L F
.472 .063 .181 r
.51965 .404 m .51847 .40551 L .51974 .404 L F
0 0 0 r
.51967 .40397 m .51847 .40551 L .51937 .40424 L F
.472 .063 .181 r
.51598 .40406 m .51847 .40551 L .51965 .404 L F
0 0 0 r
.5197 .40394 m .51847 .40551 L .51967 .40397 L F
.52153 .40232 m .51847 .40551 L .51974 .404 L F
.52153 .40232 m .51853 .40545 L .5197 .40394 L F
.51853 .40545 m .51847 .40551 L .5197 .40394 L F
.52153 .40232 m .51937 .40424 L .51997 .40338 L F
.388 .346 .691 r
.51722 .40013 m .5197 .40394 L .52153 .40232 L F
.472 .063 .181 r
.51598 .40406 m .51974 .404 L .51689 .40313 L F
.51598 .40406 m .51689 .40313 L .51445 .4024 L F
.715 .701 .166 r
.51454 .4048 m .5145 .40554 L .51598 .40406 L F
0 0 0 r
.51847 .40551 m .51525 .40886 L .51445 .40521 L F
.639 .836 .433 r
.51452 .40568 m .5145 .40554 L .51316 .40783 L F
0 0 .003 r
.5145 .40554 m .51408 .40737 L .51154 .40857 L F
0 0 .007 r
.51296 .40968 m .51154 .40857 L .51408 .40737 L F
.805 .858 .409 r
.51444 .40534 m .51296 .40968 L .51408 .40737 L F
.51454 .4048 m .51391 .40675 L .51444 .40534 L F
.51391 .40675 m .51296 .40968 L .51444 .40534 L F
0 0 .007 r
.51296 .40968 m .51085 .41111 L .51154 .40857 L F
.104 0 .171 r
.51116 .40839 m .51296 .40968 L .51281 .40645 L F
.714 .928 .962 r
.51116 .40839 m .50936 .41009 L .51154 .40857 L F
.368 .382 .743 r
.5062 .4082 m .50936 .41009 L .50861 .40618 L F
.476 .459 .76 r
.50861 .40618 m .50936 .41009 L .51116 .40839 L F
.366 0 .111 r
.51154 .40857 m .50826 .41098 L .51116 .40839 L F
.51154 .40857 m .51085 .41111 L .50826 .41098 L F
.104 0 .171 r
.51116 .40839 m .51085 .41111 L .51296 .40968 L F
.636 .238 .273 r
.50721 .41109 m .51116 .40839 L .50826 .41098 L F
.597 .95 .838 r
.50387 .41282 m .50721 .41109 L .50826 .41098 L F
.282 0 0 r
.50826 .41098 m .51085 .41111 L .50387 .41282 L F
.636 .238 .273 r
.50721 .41109 m .51085 .41111 L .51116 .40839 L F
.838 .713 .725 r
.51296 .40968 m .51029 .40998 L .51281 .40645 L F
.715 .481 .57 r
.50387 .41282 m .51085 .41111 L .50721 .41109 L F
.292 0 .025 r
.51296 .40968 m .50933 .41204 L .51029 .40998 L F
.51296 .40968 m .51216 .41175 L .50933 .41204 L F
.382 .237 .557 r
.51281 .40645 m .51234 .41039 L .51258 .41026 L F
.715 .701 .166 r
.51447 .40522 m .51408 .40737 L .5145 .40554 L F
.205 .19 .619 r
.51443 .4051 m .51525 .40886 L .51296 .40968 L F
.382 .237 .557 r
.51369 .40732 m .51258 .41026 L .51525 .40886 L F
.336 .317 .689 r
.51281 .40645 m .51296 .40968 L .51454 .4048 L F
.205 .19 .619 r
.51443 .4051 m .51296 .40968 L .51281 .40645 L F
.382 .237 .557 r
.51281 .40645 m .51258 .41026 L .51369 .40732 L F
0 0 0 r
.51448 .40511 m .51445 .40521 L .51443 .4051 L F
.715 .701 .166 r
.51454 .4048 m .51447 .40522 L .5145 .40554 L F
0 0 0 r
.51847 .40551 m .51445 .40521 L .51448 .40511 L F
.715 .701 .166 r
.51454 .4048 m .51454 .40482 L .51454 .4048 L F
.51454 .40482 m .51447 .40522 L .51454 .4048 L F
.14 0 0 r
.52197 .39696 m .52022 .39902 L .51752 .39977 L F
.705 .724 .865 r
.45179 .51295 m .45289 .51606 L .44857 .51537 L F
.838 .93 .891 r
.4968 .46452 m .49415 .4647 L .49646 .46135 L F
.834 .816 .833 r
.4968 .46452 m .49646 .46135 L .49959 .46008 L F
.766 .983 .736 r
.38618 .56318 m .38659 .56153 L .38781 .56093 L F
.235 .567 .938 r
.38618 .56318 m .38847 .56369 L .38659 .56153 L F
.907 .498 .159 r
.66382 .36203 m .66573 .36236 L .66085 .36008 L F
.981 .912 .618 r
.66441 .36528 m .66537 .3663 L .66529 .36438 L F
.907 .498 .159 r
.66382 .36203 m .66638 .36432 L .66573 .36236 L F
.66638 .36432 m .66667 .36458 L .66655 .36432 L F
.66638 .36432 m .66655 .36432 L .66573 .36236 L F
.652 .766 .933 r
.6681 .36294 m .66667 .36458 L .66382 .36203 L F
.981 .912 .618 r
.66464 .36441 m .66529 .36438 L .66521 .36232 L F
.66441 .36528 m .66529 .36438 L .66464 .36441 L F
.827 .631 .638 r
.50242 .42677 m .50477 .43146 L .5054 .42854 L F
.5054 .42854 m .50477 .43146 L .50242 .42677 L F
.334 .49 .865 r
.29421 .66385 m .29616 .66742 L .2982 .66737 L F
.855 .748 .745 r
.34994 .64784 m .35125 .64454 L .34895 .643 L F
.89 .686 .62 r
.35125 .64454 m .34928 .64053 L .34895 .643 L F
.853 .913 .873 r
.62002 .3834 m .62127 .38471 L .61934 .38631 L F
.829 .911 .894 r
.62091 .38227 m .62127 .38471 L .62002 .3834 L F
.499 0 0 r
.32775 .67689 m .32939 .67574 L .33159 .67695 L F
.52 .806 .998 r
.64015 .34288 m .63851 .34149 L .63583 .34215 L F
.509 .668 .934 r
.64015 .34288 m .64124 .33924 L .63851 .34149 L F
.64015 .34288 m .64284 .34257 L .64124 .33924 L F
.603 .642 .862 r
.61043 .36246 m .60902 .36332 L .60912 .36198 L F
.042 0 0 r
.6119 .36302 m .60902 .36332 L .61043 .36246 L F
.6119 .36302 m .60773 .3642 L .60902 .36332 L F
.396 .772 .992 r
.32408 .62412 m .3217 .62454 L .3197 .62333 L F
.468 .324 .602 r
.32563 .62756 m .3217 .62454 L .32408 .62412 L F
0 0 .166 r
.50863 .404 m .5062 .4082 L .50861 .40618 L F
.383 .015 .21 r
.28227 .56434 m .28632 .5601 L .28347 .56223 L F
.28227 .56434 m .28468 .56391 L .28632 .5601 L F
0 0 .448 r
.28632 .5601 m .28637 .55723 L .2849 .55951 L F
.28632 .5601 m .28746 .5616 L .28637 .55723 L F
.661 .442 .577 r
.28468 .56391 m .28746 .5616 L .28632 .5601 L F
.811 .576 .017 r
.42204 .55666 m .42234 .5594 L .42163 .55528 L F
.454 .746 .991 r
.42204 .55666 m .42547 .55617 L .42163 .55528 L F
.777 .633 .701 r
.33244 .53239 m .33698 .53287 L .33572 .52925 L F
.486 .89 .939 r
.50906 .40342 m .51058 .40258 L .50863 .404 L F
.031 0 .286 r
.50861 .40618 m .51058 .40258 L .50863 .404 L F
0 0 .109 r
.28363 .64704 m .28173 .65107 L .28341 .64966 L F
.225 .344 .776 r
.28173 .65107 m .28464 .65291 L .28341 .64966 L F
0 .078 .639 r
.52293 .39081 m .52287 .39158 L .52243 .39056 L F
.52293 .39081 m .52453 .39432 L .52287 .39158 L F
.557 .607 .859 r
.52563 .39291 m .52453 .39432 L .52293 .39081 L F
.52563 .39291 m .52293 .39081 L .52543 .39035 L F
.34 0 .036 r
.52179 .39207 m .52368 .39118 L .52293 .39081 L F
.52368 .39118 m .52543 .39035 L .52293 .39081 L F
0 .078 .639 r
.52293 .39081 m .52243 .39056 L .5211 .38749 L F
.829 .904 .892 r
.50949 .4715 m .51093 .4729 L .5126 .47142 L F
.604 .693 .906 r
.37572 .57056 m .37264 .57225 L .37147 .56908 L F
.814 .518 .489 r
.29634 .56725 m .29514 .56813 L .29455 .56719 L F
.29634 .56725 m .2952 .56791 L .29397 .56899 L F
.29634 .56725 m .29857 .57005 L .2952 .56791 L F
.664 .629 .804 r
.29592 .56803 m .29857 .57005 L .30092 .56883 L F
.2952 .56791 m .29547 .56809 L .29592 .56803 L F
.29547 .56809 m .29857 .57005 L .29592 .56803 L F
.814 .518 .489 r
.29514 .56813 m .29397 .56899 L .29421 .56825 L F
.29514 .56813 m .29421 .56825 L .29455 .56719 L F
.089 .317 .794 r
.60743 .37846 m .60813 .38069 L .60646 .38031 L F
.158 0 0 r
.4351 .45157 m .43643 .45281 L .43732 .45013 L F
.4351 .45157 m .43391 .45372 L .43643 .45281 L F
.74 .969 .932 r
.59063 .37427 m .58972 .37339 L .59156 .37197 L F
.59156 .37197 m .58972 .37339 L .59063 .37427 L F
0 0 0 r
.57621 .36423 m .58108 .36313 L .57831 .36482 L F
.845 .446 0 r
.66777 .36134 m .6681 .36294 L .66927 .36419 L F
.855 .748 .745 r
.34994 .64784 m .34895 .643 L .34644 .64683 L F
.848 .582 .536 r
.34621 .64974 m .34994 .64784 L .34644 .64683 L F
.34621 .64974 m .34976 .64988 L .34994 .64784 L F
.337 0 .208 r
.42212 .47247 m .42161 .4742 L .41888 .47488 L F
.465 .142 .334 r
.4247 .47175 m .42161 .4742 L .42212 .47247 L F
.886 .784 .743 r
.52914 .45368 m .53343 .45129 L .5319 .45012 L F
.52914 .45368 m .53151 .45554 L .53343 .45129 L F
.859 .91 .867 r
.5319 .45012 m .53343 .45129 L .53622 .44828 L F
.729 .99 .87 r
.316 .63362 m .31274 .63633 L .31256 .63495 L F
.873 .626 .563 r
.44699 .52926 m .44296 .52503 L .44707 .52613 L F
.599 .177 .214 r
.2875 .56797 m .28462 .56639 L .28728 .56693 L F
.2875 .56797 m .28294 .56856 L .28462 .56639 L F
.584 .29 .434 r
.34453 .53926 m .34802 .53628 L .34536 .53646 L F
.34453 .53926 m .3478 .53922 L .34802 .53628 L F
.562 .271 .431 r
.34802 .53628 m .3478 .53922 L .35008 .53767 L F
0 0 .512 r
.58279 .35351 m .58325 .35743 L .58424 .35522 L F
0 0 .454 r
.58325 .35743 m .58484 .35784 L .58424 .35522 L F
.58325 .35743 m .58381 .36032 L .58484 .35784 L F
.779 .527 .555 r
.35515 .54967 m .35716 .55291 L .35773 .54953 L F
.168 0 .078 r
.46954 .43859 m .47362 .43469 L .47313 .4373 L F
.202 0 .184 r
.47629 .4336 m .47313 .4373 L .47362 .43469 L F
.599 .349 .51 r
.3415 .53953 m .34536 .53646 L .34112 .53614 L F
.3415 .53953 m .34453 .53926 L .34536 .53646 L F
.128 0 0 r
.40665 .47125 m .40923 .47057 L .41079 .46878 L F
.089 0 0 r
.40923 .47057 m .4132 .46778 L .41079 .46878 L F
.807 .814 .856 r
.56017 .36683 m .562 .36906 L .56396 .36728 L F
.976 .707 .455 r
.66507 .35182 m .66705 .35058 L .66435 .34976 L F
.66507 .35182 m .66698 .35374 L .66705 .35058 L F
.46 .884 .91 r
.36104 .58342 m .36544 .5825 L .36172 .58272 L F
.595 .939 .938 r
.36172 .58272 m .36544 .5825 L .36593 .58102 L F
.799 .68 .734 r
.39562 .5791 m .39706 .58338 L .39853 .58005 L F
.41 .11 .343 r
.27254 .56834 m .27356 .56934 L .27503 .56676 L F
.27254 .56834 m .27097 .57029 L .27356 .56934 L F
.413 .158 .415 r
.27972 .57678 m .2792 .57936 L .27673 .58001 L F
.305 .066 .377 r
.28191 .57593 m .2792 .57936 L .27972 .57678 L F
0 0 .307 r
.31913 .61178 m .32001 .6126 L .32134 .61094 L F
.644 .597 .787 r
.52985 .37032 m .52748 .37465 L .52587 .37007 L F
.489 .406 .69 r
.53 .37364 m .52748 .37465 L .52985 .37032 L F
0 0 0 r
.53 .37364 m .52615 .37602 L .52748 .37465 L F
.452 .39 .697 r
.27508 .5732 m .27691 .5687 L .27356 .56934 L F
.27508 .5732 m .27851 .5732 L .27691 .5687 L F
.45 .302 .588 r
.27508 .5732 m .27773 .57483 L .27851 .5732 L F
.633 .874 .987 r
.42822 .55526 m .42988 .55641 L .42547 .55617 L F
0 0 0 r
.42988 .55641 m .42872 .5585 L .42882 .55828 L F
.633 .874 .987 r
.42822 .55526 m .42988 .55641 L .42547 .55617 L F
0 0 0 r
.5146 .3809 m .51404 .38265 L .5153 .3807 L F
.694 .294 .284 r
.54945 .38861 m .54822 .38957 L .54774 .38941 L F
.54945 .38861 m .55074 .3905 L .54822 .38957 L F
0 0 0 r
.54486 .38978 m .54384 .3903 L .54112 .39099 L F
.729 .252 .115 r
.55074 .3905 m .54682 .39072 L .54648 .39034 L F
.242 .758 .806 r
.54739 .38971 m .54384 .3903 L .54752 .38961 L F
.729 .252 .115 r
.547 .38998 m .54648 .39034 L .54603 .38984 L F
.55074 .3905 m .54648 .39034 L .547 .38998 L F
.242 .758 .806 r
.54752 .38961 m .54384 .3903 L .54486 .38978 L F
.54822 .38957 m .54739 .38971 L .54752 .38961 L F
.211 0 0 r
.54774 .38941 m .54822 .38957 L .54486 .38978 L F
.75 .694 .797 r
.61934 .38631 m .61425 .38737 L .61682 .38422 L F
.755 .759 .856 r
.61329 .39123 m .61467 .39314 L .61311 .39146 L F
.544 .136 .218 r
.61797 .38894 m .61425 .38737 L .61934 .38631 L F
.61739 .38923 m .61425 .38737 L .61797 .38894 L F
.861 .911 .865 r
.61682 .38422 m .61425 .38737 L .61288 .38597 L F
0 .263 .73 r
.61288 .38597 m .61425 .38737 L .61773 .38942 L F
.61288 .38597 m .61773 .38942 L .61585 .38796 L F
.755 .759 .856 r
.61585 .38796 m .61533 .39023 L .61329 .39123 L F
.61533 .39023 m .61467 .39314 L .61329 .39123 L F
.544 .136 .218 r
.61773 .38942 m .61739 .38923 L .61797 .38894 L F
.853 .913 .873 r
.62002 .3834 m .61934 .38631 L .61682 .38422 L F
.805 .432 .35 r
.61934 .38631 m .62135 .38985 L .61773 .38942 L F
.977 .846 .449 r
.62706 .33584 m .62613 .33442 L .62734 .33364 L F
.092 0 0 r
.62613 .33442 m .62878 .33433 L .62734 .33364 L F
0 0 .315 r
.59949 .35867 m .60062 .36098 L .60099 .36153 L F
.776 .707 .787 r
.3454 .55929 m .34973 .55978 L .34808 .55578 L F
0 0 0 r
.34973 .55978 m .35176 .55586 L .34808 .55578 L F
.34973 .55978 m .35072 .55813 L .35176 .55586 L F
.648 .895 .56 r
.34973 .55978 m .34828 .5611 L .35072 .55813 L F
0 0 .501 r
.28955 .65414 m .29034 .65758 L .2909 .65609 L F
.664 .23 .208 r
.29034 .65758 m .28833 .65948 L .2909 .65609 L F
.199 .247 .688 r
.29034 .65758 m .29121 .66028 L .29275 .65988 L F
.664 .23 .208 r
.29034 .65758 m .29275 .65988 L .28833 .65948 L F
.108 .604 .904 r
.42429 .52921 m .42234 .52822 L .42008 .52794 L F
.732 .622 .736 r
.41962 .53165 m .42429 .52921 L .42112 .53043 L F
.41962 .53165 m .42234 .52822 L .42429 .52921 L F
.955 .823 .675 r
.4243 .52405 m .42234 .52822 L .42429 .52921 L F
.951 .612 .336 r
.42234 .52822 m .4243 .53166 L .42429 .52921 L F
.42234 .52822 m .4243 .53166 L .42429 .52921 L F
.602 .058 0 r
.65026 .33661 m .65073 .33693 L .64857 .33548 L F
.794 .994 .875 r
.33892 .67126 m .34258 .66841 L .33938 .66914 L F
.806 .993 .872 r
.33938 .66914 m .34258 .66841 L .34251 .6663 L F
0 0 0 r
.59449 .39426 m .5966 .38982 L .59551 .39191 L F
.59551 .39191 m .59443 .39588 L .59449 .39426 L F
.746 .813 .905 r
.56132 .39259 m .56319 .39407 L .55912 .39384 L F
.534 .538 .806 r
.56435 .38937 m .56319 .39407 L .56132 .39259 L F
.56435 .38937 m .56591 .39357 L .56319 .39407 L F
0 0 0 r
.30649 .67052 m .30962 .66756 L .30765 .67022 L F
.139 .685 .769 r
.30497 .67054 m .30649 .67052 L .30765 .67022 L F
.646 .734 .913 r
.5824 .37042 m .5856 .37146 L .58499 .36933 L F
.5824 .37042 m .5856 .37146 L .58499 .36933 L F
.78 .994 .875 r
.63459 .3392 m .63282 .34252 L .63583 .34215 L F
.63459 .3392 m .63167 .34224 L .63282 .34252 L F
.785 .918 .927 r
.65024 .37992 m .65298 .37588 L .6498 .37896 L F
.65024 .37992 m .65422 .37721 L .65298 .37588 L F
.829 .904 .892 r
.50949 .4715 m .5126 .47142 L .51021 .47099 L F
.831 .86 .867 r
.51402 .46666 m .5126 .47142 L .51574 .46825 L F
.51402 .46666 m .51021 .47099 L .5126 .47142 L F
.284 .049 .371 r
.54936 .34407 m .55115 .34509 L .55148 .34248 L F
.269 .058 .397 r
.54936 .34407 m .54881 .3466 L .55115 .34509 L F
.203 0 0 r
.37072 .48454 m .37316 .48416 L .3749 .48227 L F
.772 .462 .462 r
.37316 .48416 m .37761 .48262 L .3749 .48227 L F
.547 .564 .823 r
.29168 .66442 m .29275 .65988 L .29121 .66028 L F
.29168 .66442 m .29421 .66385 L .29275 .65988 L F
.776 .498 .515 r
.27773 .57483 m .28191 .57593 L .28248 .57334 L F
.634 .482 .659 r
.28461 .57251 m .28191 .57593 L .28248 .57334 L F
0 0 .001 r
.28248 .57334 m .28303 .57338 L .28461 .57251 L F
.28248 .57334 m .28191 .57593 L .28303 .57338 L F
.57 .362 .559 r
.42154 .51585 m .42162 .51858 L .41828 .51914 L F
.202 0 .214 r
.44587 .45726 m .44297 .4601 L .44346 .45817 L F
.84 .712 .722 r
.30404 .56264 m .3019 .56629 L .30572 .56662 L F
.825 .704 .731 r
.30092 .56883 m .30572 .56662 L .3019 .56629 L F
.30092 .56883 m .3038 .57039 L .30572 .56662 L F
.905 .98 .709 r
.45384 .53098 m .45379 .53298 L .4559 .52963 L F
.762 .954 .937 r
.45661 .52732 m .4559 .52963 L .45811 .52822 L F
.839 .988 .718 r
.45661 .52732 m .45384 .53098 L .4559 .52963 L F
0 0 0 r
.52885 .43139 m .52521 .43378 L .52681 .43249 L F
.812 .981 .892 r
.52997 .42835 m .53219 .42849 L .52885 .43139 L F
.841 .995 .752 r
.52997 .42835 m .52885 .43139 L .52681 .43249 L F
.676 .847 .965 r
.27119 .59012 m .27549 .59035 L .27358 .58744 L F
.564 .632 .878 r
.27549 .59035 m .27807 .58972 L .27358 .58744 L F
.842 .969 .881 r
.34302 .66401 m .34523 .65991 L .34312 .66329 L F
.34302 .66401 m .34667 .66059 L .34523 .65991 L F
.716 .695 .157 r
.34251 .6663 m .34302 .66401 L .34312 .66329 L F
.197 0 0 r
.40436 .48618 m .40289 .4882 L .40061 .48884 L F
.157 0 0 r
.40542 .48729 m .40289 .4882 L .40436 .48618 L F
.786 .644 .704 r
.35008 .53767 m .35257 .53997 L .35601 .53832 L F
.073 .633 .778 r
.32147 .62022 m .32443 .62026 L .32248 .62013 L F
.32001 .6202 m .32443 .62026 L .32248 .62013 L F
.1 .288 .767 r
.32248 .62013 m .32553 .62246 L .3243 .61997 L F
.32248 .62013 m .3243 .61997 L .32323 .6178 L F
.073 .633 .778 r
.32001 .6202 m .32147 .62022 L .32248 .62013 L F
.684 .149 0 r
.32443 .62026 m .32666 .62277 L .32553 .62246 L F
.299 .019 .31 r
.44879 .45414 m .44587 .45726 L .4463 .455 L F
.969 .676 .27 r
.36346 .56537 m .36484 .56914 L .36481 .5669 L F
0 0 0 r
.45495 .43674 m .45639 .43553 L .45268 .43761 L F
.45866 .43424 m .45639 .43553 L .45495 .43674 L F
.526 .634 .9 r
.27266 .57743 m .27673 .58001 L .275 .5761 L F
.533 .52 .787 r
.27673 .58001 m .27773 .57483 L .275 .5761 L F
.27673 .58001 m .2792 .57936 L .27773 .57483 L F
.365 0 0 r
.35848 .56669 m .35878 .56835 L .35331 .56887 L F
.807 .732 .781 r
.65936 .35632 m .66375 .35567 L .66256 .35252 L F
.65936 .35632 m .6613 .35739 L .66375 .35567 L F
.7 .804 .93 r
.66375 .35567 m .66507 .35182 L .66256 .35252 L F
.66375 .35567 m .66698 .35374 L .66507 .35182 L F
.672 .938 .661 r
.44915 .53856 m .45005 .53821 L .45262 .53549 L F
0 0 .563 r
.59068 .35008 m .58936 .34988 L .58814 .34849 L F
.59068 .35008 m .59118 .35199 L .58936 .34988 L F
.709 .512 .62 r
.2961 .54914 m .30145 .54631 L .2963 .54592 L F
.2961 .54914 m .30096 .5492 L .30145 .54631 L F
0 0 0 r
.54303 .42304 m .5415 .42293 L .54075 .42403 L F
.54303 .42304 m .54453 .42021 L .5415 .42293 L F
.873 .626 .563 r
.44699 .52926 m .44294 .52821 L .44296 .52503 L F
.873 .642 .586 r
.44699 .52926 m .44471 .53211 L .44294 .52821 L F
.229 0 .274 r
.42881 .45531 m .43058 .45638 L .43136 .45453 L F
.42881 .45531 m .42831 .4575 L .43058 .45638 L F
.435 0 0 r
.3793 .4863 m .37734 .48772 L .37474 .4874 L F
.502 0 0 r
.38159 .48752 m .37734 .48772 L .3793 .4863 L F
.864 .539 .021 r
.4053 .49496 m .40388 .49111 L .40374 .4927 L F
.414 .809 .986 r
.60683 .34095 m .61086 .34126 L .60804 .34214 L F
.761 .516 .563 r
.27358 .58744 m .27817 .58672 L .2738 .58621 L F
0 0 0 r
.52743 .3575 m .52605 .35898 L .52926 .3558 L F
.559 .867 .568 r
.49195 .40482 m .49052 .40611 L .49364 .40304 L F
.707 .451 .534 r
.52453 .39432 m .52725 .39689 L .52894 .3964 L F
.52453 .39432 m .52444 .39697 L .52725 .39689 L F
0 0 .304 r
.52563 .39291 m .52444 .39697 L .52453 .39432 L F
.473 .105 .258 r
.53399 .36027 m .5306 .36237 L .5315 .36135 L F
.067 0 0 r
.46661 .44218 m .4646 .44201 L .46712 .44147 L F
.46661 .44218 m .46357 .44293 L .4646 .44201 L F
.672 .35 .421 r
.32793 .62016 m .32901 .61847 L .32715 .61722 L F
.832 .964 .637 r
.6045 .36518 m .60384 .36773 L .60481 .36547 L F
.886 .985 .713 r
.6045 .36518 m .60261 .36966 L .60384 .36773 L F
.859 .91 .867 r
.5319 .45012 m .53622 .44828 L .53474 .44696 L F
.982 .712 .326 r
.41828 .51914 m .41733 .52104 L .41733 .51799 L F
.41828 .51914 m .41837 .52223 L .41733 .52104 L F
.539 .312 .518 r
.42162 .51858 m .41837 .52223 L .41828 .51914 L F
.982 .712 .326 r
.41828 .51914 m .41733 .52104 L .41733 .51799 L F
.41828 .51914 m .41837 .52223 L .41733 .52104 L F
.763 .792 .877 r
.5728 .39076 m .57046 .39224 L .56888 .3902 L F
.884 .951 .846 r
.33597 .67467 m .33724 .67068 L .33405 .67328 L F
.33597 .67467 m .33892 .67126 L .33724 .67068 L F
.826 .982 .882 r
.60699 .39464 m .60609 .39767 L .60503 .39667 L F
.60699 .39464 m .60908 .39508 L .60609 .39767 L F
.478 .174 .372 r
.60581 .39947 m .60609 .39767 L .60865 .39914 L F
.728 .397 .42 r
.54246 .3476 m .54217 .34958 L .54583 .34976 L F
.786 .897 .921 r
.62527 .33759 m .62613 .33442 L .62706 .33584 L F
.439 0 0 r
.39337 .5707 m .39592 .57172 L .39416 .57071 L F
.39409 .57115 m .39592 .57172 L .39337 .5707 L F
.888 .744 .696 r
.39592 .57172 m .39419 .57576 L .39755 .57635 L F
0 0 0 r
.39506 .57393 m .39419 .57576 L .39592 .57172 L F
.711 .222 0 r
.3942 .57253 m .39506 .57393 L .39261 .57069 L F
0 0 0 r
.39506 .57393 m .39508 .57387 L .39261 .57069 L F
.39435 .57185 m .39592 .57172 L .39409 .57115 L F
.439 0 0 r
.39261 .57069 m .39409 .57115 L .39337 .5707 L F
.777 .615 .679 r
.39511 .56832 m .39435 .57185 L .39261 .57069 L F
.39435 .57185 m .3942 .57253 L .39261 .57069 L F
.196 .054 .449 r
.39453 .57234 m .39506 .57393 L .3942 .57253 L F
0 0 0 r
.39508 .57387 m .39555 .57266 L .39437 .57186 L F
.39508 .57387 m .39437 .57186 L .39453 .57234 L F
.39555 .57266 m .39592 .57172 L .39435 .57185 L F
.567 .022 0 r
.39592 .57172 m .39946 .57312 L .40098 .57262 L F
.39592 .57172 m .39946 .57312 L .40098 .57262 L F
.455 .521 .837 r
.39666 .56784 m .39946 .57312 L .39592 .57172 L F
0 .41 .781 r
.39592 .57172 m .39946 .57312 L .39616 .57137 L F
.196 .054 .449 r
.39616 .57137 m .39506 .57393 L .39453 .57234 L F
0 0 0 r
.39453 .57234 m .39437 .57186 L .39435 .57185 L F
.209 .077 .472 r
.39453 .57234 m .3942 .57253 L .39435 .57185 L F
0 0 0 r
.39508 .57387 m .39409 .57115 L .39261 .57069 L F
.209 .077 .472 r
.39528 .57189 m .39453 .57234 L .39445 .57137 L F
.39453 .57234 m .39435 .57185 L .39445 .57137 L F
.455 .521 .837 r
.39666 .56784 m .39592 .57172 L .39616 .57137 L F
.209 .077 .472 r
.39616 .57137 m .39528 .57189 L .39511 .56832 L F
.39528 .57189 m .39445 .57137 L .39511 .56832 L F
.531 .331 .554 r
.51731 .37727 m .52021 .37703 L .52003 .37403 L F
.51731 .37727 m .52021 .37703 L .52003 .37403 L F
0 0 .25 r
.52003 .37403 m .52081 .37332 L .52112 .37174 L F
.52003 .37403 m .52021 .37703 L .52081 .37332 L F
.262 0 0 r
.40796 .49729 m .41067 .4977 L .4094 .49872 L F
.40796 .49729 m .41289 .4984 L .41067 .4977 L F
.483 .022 .083 r
.38587 .48562 m .38426 .48748 L .38159 .48752 L F
.662 .227 .206 r
.38587 .48562 m .38829 .48789 L .38426 .48748 L F
.684 .203 .104 r
.39102 .4874 m .38829 .48789 L .38587 .48562 L F
.179 0 0 r
.55211 .38026 m .55455 .38017 L .55524 .37946 L F
.532 .828 .497 r
.55524 .37946 m .55455 .38017 L .55487 .37983 L F
.009 0 0 r
.55211 .38026 m .55524 .37946 L .55598 .3787 L F
.532 .828 .497 r
.55524 .37946 m .55487 .37983 L .55733 .37717 L F
.009 0 0 r
.55598 .3787 m .55524 .37946 L .55637 .37855 L F
.575 .874 .571 r
.55637 .37855 m .55733 .37717 L .55937 .37738 L F
.55637 .37855 m .55524 .37946 L .55733 .37717 L F
.577 .205 .299 r
.39393 .47713 m .39673 .47739 L .39818 .47468 L F
.472 .107 .264 r
.39673 .47739 m .40075 .47435 L .39818 .47468 L F
.449 .302 .588 r
.52615 .37602 m .52394 .3801 L .52435 .37744 L F
.75 .532 .601 r
.27621 .56417 m .27632 .56588 L .27633 .56314 L F
.27621 .56417 m .27503 .56676 L .27632 .56588 L F
.45 .628 .93 r
.61159 .38133 m .61013 .38401 L .60813 .38069 L F
.61159 .38133 m .6129 .38372 L .61013 .38401 L F
.612 .127 .077 r
.61013 .38401 m .61288 .38597 L .60872 .38578 L F
.439 .264 .546 r
.6129 .38372 m .61288 .38597 L .61013 .38401 L F
.967 .93 .621 r
.44568 .51885 m .44363 .52011 L .4435 .51788 L F
.44568 .51885 m .44401 .52271 L .44363 .52011 L F
.829 .9 .89 r
.44568 .51885 m .44707 .51449 L .44857 .51537 L F
.44568 .51885 m .4435 .51788 L .44707 .51449 L F
.539 .868 .994 r
.61067 .39309 m .60908 .39508 L .60699 .39464 L F
.61067 .39309 m .61184 .39416 L .60908 .39508 L F
0 0 .541 r
.603 .37256 m .60617 .37641 L .60474 .37365 L F
.729 .954 .947 r
.33724 .67068 m .33892 .67126 L .33938 .66914 L F
0 0 .141 r
.54928 .36866 m .54832 .37046 L .54949 .36891 L F
.551 .471 .718 r
.54766 .37354 m .54949 .36891 L .54832 .37046 L F
.936 .785 .669 r
.64528 .35363 m .64354 .35275 L .6442 .34954 L F
.988 .896 .612 r
.64528 .35363 m .64323 .35506 L .64354 .35275 L F
.64528 .35363 m .64412 .35743 L .64323 .35506 L F
.462 .314 .594 r
.49524 .40956 m .49275 .41358 L .49336 .41155 L F
.523 .019 .001 r
.56174 .38728 m .56026 .38885 L .55769 .38759 L F
.68 .202 .108 r
.56435 .38937 m .56026 .38885 L .56174 .38728 L F
.646 .264 .306 r
.56449 .38773 m .56435 .38937 L .56174 .38728 L F
.656 .382 .493 r
.35076 .55237 m .35515 .54967 L .35082 .54919 L F
.35076 .55237 m .35366 .55274 L .35515 .54967 L F
.779 .527 .555 r
.35515 .54967 m .35366 .55274 L .35716 .55291 L F
.501 .349 .606 r
.30259 .63251 m .3023 .63642 L .30161 .63555 L F
.23 .122 .517 r
.30423 .63308 m .3023 .63642 L .30259 .63251 L F
.869 .427 .121 r
.52568 .36718 m .52511 .36742 L .52275 .36381 L F
.247 .214 .623 r
.52568 .36718 m .52722 .36741 L .52755 .36547 L F
.629 .639 .841 r
.52847 .3685 m .52587 .37007 L .52568 .36718 L F
.751 .549 .623 r
.33703 .53595 m .3415 .53953 L .34112 .53614 L F
.591 .948 .875 r
.43951 .5362 m .44072 .53457 L .44144 .53482 L F
.43951 .5362 m .43792 .53599 L .44072 .53457 L F
.712 .987 .852 r
.43524 .53847 m .43792 .53599 L .43951 .5362 L F
.6 .545 .764 r
.27097 .57029 m .27103 .57232 L .27356 .56934 L F
.726 .6 .716 r
.34061 .66028 m .33737 .66444 L .33637 .65956 L F
.34061 .66028 m .33637 .65956 L .33855 .66029 L F
.953 .652 .426 r
.33838 .65704 m .34061 .66028 L .33855 .66029 L F
.733 .671 .79 r
.28758 .5508 m .29033 .55107 L .29023 .54911 L F
.517 .274 .485 r
.29033 .55107 m .29414 .54911 L .29023 .54911 L F
.29033 .55107 m .29433 .55168 L .29414 .54911 L F
.86 .688 .667 r
.49373 .48428 m .49755 .48528 L .49702 .48109 L F
.49373 .48428 m .49576 .48531 L .49755 .48528 L F
.846 .851 .848 r
.49702 .48109 m .49755 .48528 L .50045 .48126 L F
.21 .413 .842 r
.52569 .3841 m .52683 .38189 L .52523 .38194 L F
.776 .921 .545 r
.52449 .36088 m .52275 .36381 L .5234 .36194 L F
.031 .199 .705 r
.52275 .36381 m .52511 .36742 L .5234 .36194 L F
.961 .913 .721 r
.45129 .5345 m .45379 .53298 L .45384 .53098 L F
.45129 .5345 m .45262 .53549 L .45379 .53298 L F
.856 .818 .811 r
.46499 .4922 m .4605 .49407 L .46328 .49055 L F
.46499 .4922 m .46229 .49561 L .4605 .49407 L F
.815 .834 .864 r
.46798 .48915 m .46499 .4922 L .46328 .49055 L F
.893 .955 .834 r
.45936 .5238 m .45811 .52822 L .45937 .52619 L F
.45936 .5238 m .45661 .52732 L .45811 .52822 L F
.551 .006 0 r
.39281 .48841 m .38829 .48789 L .39102 .4874 L F
.202 0 .237 r
.40956 .4818 m .40913 .4837 L .40642 .48482 L F
.285 0 .058 r
.40795 .48659 m .40642 .48482 L .40913 .4837 L F
.40795 .48659 m .40542 .48729 L .40642 .48482 L F
.275 0 .091 r
.4345 .46602 m .43649 .4666 L .43397 .46756 L F
.4345 .46602 m .43718 .46519 L .43649 .4666 L F
.986 .719 .421 r
.65912 .35847 m .66085 .36008 L .65936 .35632 L F
.864 .533 .424 r
.6576 .36136 m .66085 .36008 L .65912 .35847 L F
.6576 .36136 m .66098 .36266 L .66085 .36008 L F
.832 .715 .736 r
.65936 .35632 m .66085 .36008 L .6613 .35739 L F
.907 .498 .159 r
.66382 .36203 m .66085 .36008 L .66098 .36266 L F
.733 .504 .582 r
.30077 .55205 m .30572 .54954 L .30096 .5492 L F
.30077 .55205 m .3053 .5525 L .30572 .54954 L F
.745 .745 .852 r
.29587 .57605 m .29725 .57955 L .30022 .57648 L F
.74 .445 .481 r
.56861 .38745 m .56435 .38937 L .56449 .38773 L F
.56861 .38745 m .56888 .3902 L .56435 .38937 L F
.466 .176 .388 r
.29726 .63285 m .29572 .63023 L .29263 .6346 L F
.29726 .63285 m .29884 .62912 L .29572 .63023 L F
.525 .226 .401 r
.42161 .4742 m .41768 .47743 L .41888 .47488 L F
.9 .624 .51 r
.3392 .54947 m .33565 .55088 L .33863 .54756 L F
.3392 .54947 m .33885 .55248 L .33565 .55088 L F
.887 .879 .821 r
.5622 .40309 m .56478 .40359 L .56391 .4002 L F
.89 .876 .816 r
.56111 .40626 m .56478 .40359 L .5622 .40309 L F
.805 .841 .877 r
.56391 .4002 m .56478 .40359 L .56739 .40032 L F
.82 .85 .87 r
.56568 .40306 m .56739 .40032 L .56478 .40359 L F
.462 .314 .594 r
.49524 .40956 m .49559 .41415 L .49275 .41358 L F
0 0 .296 r
.49611 .41023 m .49559 .41415 L .49533 .41065 L F
.49611 .41023 m .49533 .41065 L .49524 .40956 L F
0 0 0 r
.49611 .41023 m .49749 .40874 L .49979 .40756 L F
.53 .896 .696 r
.49768 .40864 m .49611 .41023 L .49979 .40756 L F
0 0 0 r
.49704 .40974 m .49611 .41023 L .49768 .40864 L F
.948 .956 .718 r
.49449 .41342 m .49559 .41415 L .49611 .41023 L F
0 0 0 r
.49543 .41249 m .49611 .41023 L .49704 .40974 L F
0 .531 .846 r
.49559 .41415 m .49662 .41484 L .49491 .41429 L F
.49559 .41415 m .49491 .41429 L .49275 .41358 L F
.779 .541 .575 r
.49389 .4146 m .49619 .41404 L .49559 .41415 L F
.04 .256 .754 r
.49856 .41346 m .49752 .41513 L .49559 .41415 L F
.779 .541 .575 r
.49619 .41404 m .49856 .41346 L .49559 .41415 L F
.948 .956 .718 r
.49389 .4146 m .49559 .41415 L .49449 .41342 L F
0 .531 .846 r
.49559 .41415 m .49752 .41513 L .49662 .41484 L F
.04 .256 .754 r
.49856 .41346 m .49961 .4163 L .49752 .41513 L F
.859 .791 .783 r
.45892 .50153 m .45785 .49771 L .4599 .49927 L F
.45892 .50153 m .45534 .50124 L .45785 .49771 L F
.866 .768 .752 r
.45892 .50153 m .45647 .50511 L .45534 .50124 L F
0 0 .011 r
.58474 .34993 m .58279 .35351 L .58508 .35085 L F
.029 0 .456 r
.58279 .35351 m .58424 .35522 L .58508 .35085 L F
.862 .794 .783 r
.46229 .49561 m .45785 .49771 L .4605 .49407 L F
.46229 .49561 m .4599 .49927 L .45785 .49771 L F
.715 .539 .651 r
.29414 .54911 m .2961 .54914 L .2963 .54592 L F
.839 .524 .455 r
.65481 .35286 m .65936 .35632 L .65967 .35362 L F
.807 .732 .781 r
.65936 .35632 m .66256 .35252 L .65967 .35362 L F
.801 .689 .741 r
.3053 .5525 m .30295 .55617 L .30695 .55644 L F
.762 .679 .771 r
.30295 .55617 m .30654 .55903 L .30695 .55644 L F
0 0 0 r
.57621 .36423 m .57992 .36367 L .57972 .36344 L F
.641 .102 0 r
.57521 .36218 m .57992 .36367 L .57621 .36423 L F
.57491 .36154 m .57864 .36313 L .57521 .36218 L F
.57864 .36313 m .57992 .36367 L .57521 .36218 L F
.914 .646 .151 r
.58082 .36509 m .58141 .3639 L .57879 .36374 L F
.58141 .3639 m .58086 .36375 L .57761 .36367 L F
.128 0 0 r
.57992 .36367 m .57996 .36373 L .58148 .36376 L F
0 0 0 r
.57972 .36344 m .57992 .36367 L .58108 .36313 L F
.603 .15 .151 r
.57992 .36367 m .58331 .36243 L .58108 .36313 L F
.57992 .36367 m .58148 .36376 L .58331 .36243 L F
.923 .65 .164 r
.58148 .36376 m .58268 .36886 L .58382 .36551 L F
.58148 .36376 m .58171 .3672 L .58268 .36886 L F
.914 .646 .151 r
.58082 .36509 m .58171 .3672 L .5817 .3671 L F
.58082 .36509 m .5817 .3671 L .58148 .36376 L F
0 .077 .617 r
.57987 .36309 m .58004 .36328 L .58082 .36509 L F
.58004 .36328 m .58262 .36628 L .58082 .36509 L F
.58262 .36628 m .58325 .36701 L .58082 .36509 L F
.914 .646 .151 r
.58082 .36509 m .57879 .36374 L .57761 .36367 L F
.58141 .3639 m .58148 .36376 L .58086 .36375 L F
.128 0 0 r
.57992 .36367 m .57761 .36367 L .57996 .36373 L F
.751 .549 .623 r
.33703 .53595 m .33686 .5393 L .3415 .53953 L F
.762 .679 .771 r
.30295 .55617 m .30217 .5592 L .30654 .55903 L F
.761 .592 .668 r
.30217 .5592 m .30404 .56264 L .30654 .55903 L F
.412 .856 .772 r
.60865 .39914 m .61296 .3975 L .61135 .3979 L F
.859 .514 .398 r
.42116 .57907 m .41737 .57904 L .41706 .57619 L F
.41706 .57619 m .4173 .57844 L .41435 .5775 L F
.4173 .57844 m .41737 .57904 L .41565 .57817 L F
.4173 .57844 m .41565 .57817 L .41435 .5775 L F
.363 .796 .966 r
.42116 .57907 m .42141 .57794 L .41672 .57776 L F
.792 .926 .924 r
.41672 .57776 m .41737 .57904 L .42116 .57907 L F
.831 .699 .718 r
.30092 .56883 m .30267 .5728 L .3038 .57039 L F
.769 .415 0 r
.37515 .57914 m .37477 .57906 L .37383 .57774 L F
.125 0 0 r
.4224 .46086 m .42495 .45979 L .42581 .45837 L F
.231 0 .028 r
.42581 .45837 m .42753 .45896 L .42831 .4575 L F
.42581 .45837 m .42495 .45979 L .42753 .45896 L F
.418 .401 .733 r
.5288 .41513 m .53117 .41381 L .52777 .41354 L F
.5288 .41513 m .53167 .41644 L .53117 .41381 L F
.426 .158 .403 r
.50657 .39429 m .50937 .39354 L .5099 .39085 L F
.195 0 .318 r
.5099 .39085 m .5113 .39172 L .51178 .38967 L F
.5099 .39085 m .50937 .39354 L .5113 .39172 L F
.732 .746 .863 r
.4857 .49225 m .48991 .49269 L .48831 .49081 L F
.742 .764 .87 r
.48991 .49269 m .49128 .48807 L .48831 .49081 L F
.48991 .49269 m .49261 .4914 L .49128 .48807 L F
.798 .797 .851 r
.56739 .40032 m .57062 .39986 L .56984 .39732 L F
.781 .962 .924 r
.57062 .39986 m .57299 .39667 L .56984 .39732 L F
.57062 .39986 m .57428 .39752 L .57299 .39667 L F
.657 .895 .555 r
.57562 .3954 m .57428 .39752 L .57704 .3941 L F
.628 .918 .978 r
.57299 .39667 m .57428 .39752 L .57562 .3954 L F
.79 .612 .659 r
.28774 .5832 m .2833 .57981 L .28608 .57926 L F
.28774 .5832 m .28558 .58338 L .2833 .57981 L F
.709 .94 .635 r
.2861 .58236 m .28558 .58338 L .28774 .5832 L F
.984 .71 .415 r
.28608 .57926 m .2861 .58236 L .28774 .5832 L F
.612 .188 .215 r
.52725 .39689 m .5312 .39697 L .52894 .3964 L F
.753 .918 .946 r
.53488 .426 m .53219 .42849 L .53375 .42501 L F
.809 .981 .893 r
.53375 .42501 m .53219 .42849 L .52997 .42835 L F
.67 .762 .919 r
.38114 .57179 m .37572 .57056 L .379 .57036 L F
0 .287 .738 r
.38111 .57119 m .38114 .57179 L .379 .57036 L F
.924 .901 .498 r
.33404 .61708 m .33478 .61249 L .33346 .61441 L F
.963 .94 .689 r
.33282 .61667 m .33404 .61708 L .33346 .61441 L F
.917 .946 .803 r
.44857 .51537 m .44963 .51086 L .45179 .51295 L F
.44857 .51537 m .44707 .51449 L .44963 .51086 L F
0 0 0 r
.30668 .62085 m .30408 .62399 L .30493 .62315 L F
.069 0 0 r
.30886 .6198 m .30668 .62085 L .30493 .62315 L F
.8 .521 .516 r
.42308 .54848 m .42142 .54874 L .42121 .54708 L F
.019 0 .461 r
.42097 .55202 m .42258 .54794 L .42308 .54848 L F
.42163 .55035 m .42285 .55086 L .42258 .54794 L F
.42097 .55202 m .42178 .55152 L .42163 .55035 L F
.42178 .55152 m .42285 .55086 L .42163 .55035 L F
.8 .521 .516 r
.42121 .54708 m .41987 .54899 L .41987 .54609 L F
.42142 .54874 m .41987 .54899 L .42121 .54708 L F
.133 0 .077 r
.30408 .62399 m .30068 .62695 L .3027 .62662 L F
0 0 0 r
.30493 .62315 m .30408 .62399 L .3027 .62662 L F
.585 .421 .625 r
.27692 .56122 m .27895 .56232 L .27816 .56049 L F
.27692 .56122 m .27633 .56314 L .27895 .56232 L F
0 0 .384 r
.29164 .57668 m .29201 .5777 L .2914 .57535 L F
.621 .791 .963 r
.2914 .57535 m .29201 .5777 L .29587 .57605 L F
.464 .821 .55 r
.45268 .43761 m .44908 .44063 L .45154 .43963 L F
0 0 0 r
.45268 .43761 m .45358 .43806 L .45495 .43674 L F
.45268 .43761 m .45154 .43963 L .45358 .43806 L F
.52155 .38617 m .52086 .38856 L .5211 .38749 L F
.357 0 0 r
.51874 .39226 m .52293 .39081 L .5211 .38749 L F
.51874 .39226 m .5211 .38749 L .52086 .38856 L F
.767 .493 .52 r
.41987 .54609 m .41561 .54852 L .4172 .54519 L F
.41987 .54609 m .41987 .54899 L .41561 .54852 L F
.876 .985 .828 r
.65422 .37721 m .65622 .37288 L .65298 .37588 L F
.65422 .37721 m .65703 .37384 L .65622 .37288 L F
.868 .808 .788 r
.65266 .35023 m .65448 .35168 L .65608 .34912 L F
.627 .14 .078 r
.65118 .34614 m .65577 .34915 L .65545 .3468 L F
.65577 .34915 m .65578 .34915 L .65545 .3468 L F
.71 .724 .203 r
.65684 .3479 m .65545 .3468 L .65578 .34915 L F
.868 .808 .788 r
.65578 .34915 m .65608 .34912 L .65684 .3479 L F
.71 .724 .203 r
.65684 .3479 m .65578 .34915 L .65579 .34917 L F
.589 .019 0 r
.65276 .34792 m .65575 .34915 L .65118 .34614 L F
.868 .808 .788 r
.65266 .35023 m .65608 .34912 L .65426 .34934 L F
.589 .019 0 r
.65575 .34915 m .65579 .34917 L .65577 .34915 L F
.65575 .34915 m .65577 .34915 L .65118 .34614 L F
.868 .808 .788 r
.65575 .34915 m .65578 .34915 L .65684 .3479 L F
.627 .14 .078 r
.65577 .34915 m .65579 .34917 L .65578 .34915 L F
.726 .56 .666 r
.65684 .3479 m .65579 .34917 L .65575 .34915 L F
.65684 .3479 m .65575 .34915 L .65276 .34792 L F
.868 .808 .788 r
.6549 .34898 m .65575 .34915 L .65684 .3479 L F
.65426 .34934 m .65577 .34915 L .6549 .34898 L F
.65577 .34915 m .65578 .34915 L .6549 .34898 L F
.722 .957 .947 r
.57346 .36543 m .5712 .36727 L .57233 .36477 L F
.563 .316 .5 r
.42687 .54592 m .43015 .54602 L .43072 .54255 L F
.391 .241 .555 r
.43015 .54602 m .43219 .54164 L .43072 .54255 L F
.877 .884 .835 r
.6343 .36966 m .6317 .36922 L .63385 .36663 L F
.887 .608 .509 r
.6343 .36966 m .63108 .37214 L .6317 .36922 L F
.6343 .36966 m .6342 .37225 L .63108 .37214 L F
.872 .882 .839 r
.63697 .36589 m .6343 .36966 L .63385 .36663 L F
.527 .348 .582 r
.43116 .55478 m .42872 .5585 L .42849 .557 L F
.42954 .55504 m .42849 .557 L .42822 .55526 L F
.43116 .55478 m .42849 .557 L .42954 .55504 L F
0 0 0 r
.42882 .55828 m .42605 .56155 L .42654 .56248 L F
.42605 .56155 m .42593 .56168 L .42596 .56171 L F
.42605 .56155 m .42596 .56171 L .42654 .56248 L F
.42882 .55828 m .42872 .5585 L .42593 .56168 L F
.851 .729 .728 r
.53802 .41573 m .54004 .41779 L .53871 .4134 L F
.769 .82 .893 r
.53599 .41746 m .54004 .41779 L .53802 .41573 L F
0 0 0 r
.57844 .392 m .57704 .3941 L .57936 .39034 L F
.644 .891 .554 r
.57844 .392 m .57562 .3954 L .57704 .3941 L F
.718 .96 .688 r
.37063 .54258 m .36743 .54597 L .36829 .54417 L F
.793 .545 .562 r
.36829 .54417 m .37324 .54511 L .37063 .54258 L F
.325 .16 .497 r
.33855 .66029 m .33637 .65956 L .33838 .65704 L F
.73 .95 .95 r
.60833 .35144 m .60721 .35411 L .60865 .35164 L F
.60833 .35144 m .60587 .35301 L .60721 .35411 L F
.844 .828 .832 r
.41119 .56694 m .40764 .57131 L .40621 .56855 L F
.763 .823 .9 r
.52447 .39972 m .52622 .40165 L .52862 .39978 L F
.672 .938 .661 r
.44915 .53856 m .45262 .53549 L .45129 .5345 L F
.878 .657 .6 r
.34567 .64336 m .34928 .64053 L .34739 .6394 L F
.34567 .64336 m .34895 .643 L .34928 .64053 L F
.982 .692 .367 r
.40779 .5725 m .40946 .57657 L .40876 .57414 L F
.742 .747 .856 r
.40779 .5725 m .40876 .57414 L .41189 .57271 L F
.052 .243 .74 r
.4103 .57448 m .40946 .57657 L .40779 .5725 L F
.624 .901 .986 r
.4103 .57448 m .40781 .57571 L .40946 .57657 L F
.741 .901 .95 r
.49118 .4686 m .48772 .47086 L .48635 .46952 L F
.719 .382 .408 r
.33686 .5393 m .34082 .54172 L .3415 .53953 L F
.789 .62 .672 r
.34082 .54172 m .34453 .53926 L .3415 .53953 L F
.094 0 0 r
.37761 .48262 m .3798 .48257 L .3818 .4809 L F
.174 0 0 r
.3798 .48257 m .38458 .48054 L .3818 .4809 L F
.069 .243 .735 r
.40388 .49111 m .4053 .49496 L .40711 .49138 L F
0 0 0 r
.62695 .39062 m .62552 .39095 L .62851 .3904 L F
.02 0 .023 r
.30068 .62695 m .29884 .62912 L .29976 .62953 L F
.784 .629 .689 r
.29976 .62953 m .3027 .62662 L .30068 .62695 L F
.881 .977 .835 r
.62916 .37684 m .62531 .37908 L .62836 .37569 L F
.62916 .37684 m .6263 .37998 L .62531 .37908 L F
.729 .96 .943 r
.63097 .3755 m .62916 .37684 L .62836 .37569 L F
.876 .728 .694 r
.31216 .66996 m .3156 .67373 L .31365 .6735 L F
.546 .908 .715 r
.41612 .5401 m .41759 .53874 L .4183 .5386 L F
.255 .758 .715 r
.4183 .5386 m .41733 .53449 L .41874 .53788 L F
.4183 .5386 m .41759 .53874 L .42146 .53751 L F
.849 .581 .534 r
.32793 .62016 m .33121 .62023 L .32901 .61847 L F
.603 .075 0 r
.33009 .62136 m .33121 .62023 L .32793 .62016 L F
.746 .228 0 r
.33152 .62209 m .33121 .62023 L .33009 .62136 L F
.33152 .62209 m .33353 .62302 L .33121 .62023 L F
.671 .338 .401 r
.33353 .62302 m .33428 .62058 L .33121 .62023 L F
.705 .812 .352 r
.58027 .3879 m .57844 .392 L .57936 .39034 L F
.548 .516 .772 r
.54112 .39099 m .54384 .3903 L .54234 .38571 L F
.881 .958 .848 r
.45936 .5238 m .45937 .52619 L .46181 .52355 L F
.838 .975 .88 r
.46236 .52087 m .46181 .52355 L .46352 .52187 L F
.46236 .52087 m .45936 .5238 L .46181 .52355 L F
.93 .886 .768 r
.50456 .44818 m .50095 .45055 L .50256 .44657 L F
.50456 .44818 m .50256 .4518 L .50095 .45055 L F
.735 .395 .405 r
.39674 .4908 m .39281 .48841 L .39708 .48858 L F
.601 .268 .378 r
.39708 .48858 m .39978 .49088 L .39674 .4908 L F
.611 .263 .355 r
.40061 .48884 m .39978 .49088 L .39708 .48858 L F
.389 .686 .978 r
.36743 .54597 m .36998 .54596 L .36829 .54417 L F
.982 .767 .539 r
.56988 .34277 m .56961 .34615 L .56807 .34171 L F
.56807 .34171 m .56961 .34615 L .56988 .34277 L F
.66 .462 .606 r
.56988 .34277 m .56961 .34615 L .57058 .34444 L F
.819 .842 .866 r
.51402 .46666 m .51574 .46825 L .51874 .46494 L F
.832 .892 .884 r
.60912 .36198 m .60401 .36304 L .60696 .36264 L F
0 0 0 r
.60696 .36264 m .61142 .3608 L .60912 .36198 L F
.603 .642 .862 r
.61043 .36246 m .60912 .36198 L .61142 .3608 L F
.499 .197 .385 r
.42976 .46846 m .42753 .47151 L .4247 .47175 L F
.506 .206 .391 r
.43117 .46972 m .42976 .46846 L .43136 .4679 L F
.43117 .46972 m .42753 .47151 L .42976 .46846 L F
.639 .25 0 r
.54891 .36601 m .54664 .36178 L .54928 .36404 L F
.429 .759 .996 r
.54664 .36178 m .55199 .36298 L .54928 .36404 L F
.264 0 .278 r
.55199 .36298 m .54891 .36601 L .54928 .36404 L F
0 0 0 r
.47629 .4336 m .4796 .43138 L .47878 .43284 L F
.496 .364 .631 r
.48237 .42756 m .48219 .43071 L .4796 .43138 L F
.269 0 .076 r
.4796 .43138 m .48219 .43071 L .47878 .43284 L F
.696 .192 0 r
.4243 .53166 m .42804 .53547 L .42871 .53284 L F
0 0 0 r
.58991 .38751 m .59062 .38756 L .5907 .38492 L F
.58991 .38751 m .58943 .38978 L .59062 .38756 L F
.781 .782 .854 r
.49128 .48807 m .49261 .4914 L .49539 .48835 L F
.73 .657 .777 r
.30108 .64331 m .30541 .64764 L .30355 .64341 L F
.757 .259 0 r
.30242 .64497 m .30269 .64492 L .30251 .64475 L F
.30232 .64485 m .30251 .64475 L .30108 .64331 L F
.30242 .64497 m .30251 .64475 L .30232 .64485 L F
.8 .309 0 r
.3016 .64532 m .30406 .647 L .30108 .64331 L F
.812 .944 .589 r
.30355 .64341 m .3016 .64532 L .30108 .64331 L F
.30355 .64341 m .30341 .64299 L .30178 .6451 L F
.30355 .64341 m .30178 .6451 L .30185 .64508 L F
.644 .967 .843 r
.30428 .64196 m .30341 .64299 L .30355 .64341 L F
.657 .19 .133 r
.30355 .64341 m .30185 .64508 L .30428 .64196 L F
.812 .944 .589 r
.30185 .64508 m .30178 .6451 L .3016 .64532 L F
.657 .19 .133 r
.30185 .64508 m .3016 .64532 L .30176 .64513 L F
.30185 .64508 m .30176 .64513 L .30428 .64196 L F
.757 .259 0 r
.30406 .647 m .30541 .64764 L .30269 .64492 L F
.30406 .647 m .30269 .64492 L .30242 .64497 L F
.195 .347 .79 r
.30355 .64341 m .30541 .64764 L .30588 .64507 L F
.861 .978 .856 r
.30588 .64507 m .30541 .64764 L .30406 .647 L F
0 0 0 r
.54234 .38571 m .54689 .38439 L .54323 .3863 L F
.295 .246 .632 r
.61142 .3608 m .61374 .36102 L .61043 .36246 L F
.203 .039 .424 r
.61374 .36102 m .6119 .36302 L .61043 .36246 L F
.798 .937 .921 r
.49959 .46008 m .49646 .46135 L .4989 .45934 L F
.314 .217 .583 r
.55313 .41078 m .5524 .41383 L .55329 .4135 L F
.629 .462 .638 r
.46954 .43859 m .46712 .44147 L .46762 .44044 L F
.904 .498 .105 r
.38203 .57025 m .38111 .57119 L .38126 .56829 L F
0 0 .094 r
.58225 .38094 m .58155 .38056 L .58237 .37829 L F
.58225 .38094 m .58126 .38321 L .58155 .38056 L F
.786 .897 .921 r
.62527 .33759 m .6238 .33649 L .62613 .33442 L F
.978 .688 .31 r
.4094 .49872 m .40949 .50139 L .40796 .49729 L F
.794 .714 .776 r
.62135 .38985 m .62264 .394 L .61952 .39337 L F
.378 0 0 r
.62264 .394 m .61854 .39511 L .61952 .39337 L F
.472 .312 .583 r
.61534 .3489 m .61231 .34673 L .61498 .34633 L F
.61534 .3489 m .61263 .35007 L .61231 .34673 L F
.545 .817 .461 r
.62425 .39208 m .62144 .39541 L .62264 .394 L F
.703 .921 .585 r
.2909 .65609 m .28874 .65818 L .28673 .65539 L F
0 .005 .581 r
.28673 .65539 m .28874 .65818 L .28859 .65782 L F
.721 .241 .107 r
.28487 .65297 m .28955 .65414 L .28673 .65539 L F
.407 .839 .696 r
.28673 .65539 m .28955 .65414 L .29108 .65321 L F
0 0 .501 r
.28955 .65414 m .2909 .65609 L .29108 .65321 L F
.407 .839 .696 r
.28673 .65539 m .29108 .65321 L .2909 .65609 L F
0 .005 .581 r
.28673 .65539 m .28859 .65782 L .28711 .65426 L F
.721 .241 .107 r
.28464 .65291 m .28487 .65297 L .28673 .65539 L F
.821 .513 .469 r
.29857 .57005 m .29876 .57276 L .30267 .5728 L F
.849 .733 .735 r
.29876 .57276 m .30022 .57648 L .30267 .5728 L F
.994 .782 .506 r
.33392 .53916 m .33365 .54231 L .33232 .53791 L F
.449 .277 .555 r
.33365 .54231 m .33392 .53916 L .33232 .53791 L F
.869 .653 .608 r
.33616 .54158 m .3338 .54467 L .33365 .54231 L F
.33616 .54158 m .33681 .54567 L .33439 .54487 L F
.33451 .54374 m .33439 .54487 L .3338 .54467 L F
.33616 .54158 m .33439 .54487 L .33451 .54374 L F
.449 .277 .555 r
.33365 .54231 m .33468 .54207 L .33392 .53916 L F
.33468 .54207 m .33633 .54169 L .33488 .54016 L F
.33468 .54207 m .33488 .54016 L .33392 .53916 L F
.33365 .54231 m .33633 .54169 L .33392 .53916 L F
.672 .663 .833 r
.30423 .63308 m .30636 .63767 L .3023 .63642 L F
.184 .371 .815 r
.30686 .6357 m .30636 .63767 L .30423 .63308 L F
.442 0 0 r
.54531 .42227 m .54453 .42021 L .54303 .42304 L F
.54531 .42227 m .54682 .42052 L .54453 .42021 L F
.347 .127 .431 r
.66256 .35252 m .66435 .34976 L .66228 .35007 L F
.823 .686 .712 r
.27503 .56676 m .27356 .56934 L .27632 .56588 L F
.683 .476 .6 r
.27632 .56588 m .27356 .56934 L .27691 .5687 L F
.532 .378 .617 r
.27632 .56588 m .27691 .5687 L .27868 .5676 L F
.853 .971 .871 r
.65703 .37384 m .65747 .371 L .65622 .37288 L F
.65703 .37384 m .65998 .37074 L .65747 .371 L F
.768 .814 .337 r
.58382 .36551 m .5824 .37042 L .58499 .36933 L F
.68 .292 0 r
.58171 .3672 m .58253 .36876 L .58268 .36886 L F
.768 .814 .337 r
.58282 .36896 m .58268 .36886 L .5824 .37042 L F
0 0 .132 r
.58357 .37073 m .5824 .37042 L .58268 .36886 L F
.68 .292 0 r
.58253 .36876 m .58357 .37073 L .58268 .36886 L F
.768 .814 .337 r
.58382 .36551 m .58268 .36886 L .58282 .36896 L F
0 0 .132 r
.58357 .37073 m .58199 .37292 L .5824 .37042 L F
.968 .911 .561 r
.41612 .5401 m .41532 .54328 L .41505 .5412 L F
.71 .179 0 r
.41532 .54328 m .41456 .54459 L .41505 .5412 L F
.41532 .54328 m .4172 .54519 L .41456 .54459 L F
0 0 0 r
.54234 .38571 m .54547 .38493 L .54689 .38439 L F
.635 .753 .934 r
.54904 .38281 m .54689 .38439 L .54513 .382 L F
.369 .031 .256 r
.43397 .46756 m .43117 .46972 L .43136 .4679 L F
0 0 0 r
.50657 .39429 m .50749 .39428 L .50937 .39354 L F
.50657 .39429 m .50508 .39539 L .50749 .39428 L F
.548 .782 .985 r
.37904 .58339 m .38169 .58268 L .37985 .5811 L F
.208 .168 .591 r
.58331 .36243 m .58484 .35784 L .58381 .36032 L F
.607 .261 .357 r
.33619 .62325 m .33428 .62058 L .33353 .62302 L F
.33619 .62325 m .33903 .62014 L .33428 .62058 L F
.857 .699 .686 r
.56902 .34788 m .57138 .35032 L .57058 .34444 L F
.861 .888 .855 r
.33791 .62591 m .34256 .62391 L .34049 .62266 L F
.775 .607 .671 r
.54682 .42052 m .55092 .42088 L .55007 .41728 L F
.667 .573 .741 r
.55007 .41728 m .55399 .41728 L .55329 .4135 L F
.252 .264 .678 r
.55007 .41728 m .55381 .4206 L .55399 .41728 L F
.55007 .41728 m .55092 .42088 L .55381 .4206 L F
.763 .888 .934 r
.6263 .37998 m .62256 .38024 L .62531 .37908 L F
.432 .226 .498 r
.29058 .56281 m .29003 .56573 L .29257 .56499 L F
.236 .747 .72 r
.50639 .4037 m .50523 .40415 L .50906 .40342 L F
.481 .211 .427 r
.43138 .55206 m .42822 .55526 L .4286 .5527 L F
.093 0 .04 r
.47281 .42288 m .47385 .42107 L .47064 .42398 L F
0 0 0 r
.47558 .41944 m .4767 .41779 L .47385 .42107 L F
.179 0 .27 r
.47281 .42288 m .47558 .41944 L .47385 .42107 L F
.052 .243 .74 r
.4103 .57448 m .40779 .5725 L .41189 .57271 L F
.357 0 0 r
.41466 .57221 m .4103 .57448 L .41189 .57271 L F
.452 .103 .281 r
.45838 .44752 m .45748 .45024 L .45465 .45069 L F
.449 .146 .359 r
.46111 .44653 m .45748 .45024 L .45838 .44752 L F
.938 .908 .765 r
.46667 .51871 m .46911 .51479 L .46738 .5137 L F
.831 .936 .897 r
.46738 .5137 m .46911 .51479 L .47208 .5118 L F
0 0 0 r
.42685 .55995 m .42641 .56053 L .42593 .56168 L F
.476 .86 .979 r
.42593 .56168 m .42327 .56228 L .42563 .56243 L F
0 0 0 r
.42641 .56053 m .42394 .56374 L .42593 .56168 L F
.476 .86 .979 r
.42593 .56168 m .42563 .56243 L .42654 .56248 L F
.887 .736 .688 r
.42257 .56524 m .42481 .56691 L .42654 .56248 L F
0 .543 .711 r
.37029 .57752 m .37131 .57757 L .36843 .57626 L F
.37029 .57752 m .37383 .57774 L .37131 .57757 L F
.815 .834 .864 r
.46798 .48915 m .46328 .49055 L .46618 .48766 L F
.855 .86 .844 r
.47088 .48576 m .46798 .48915 L .46618 .48766 L F
.365 .05 .292 r
.42162 .46351 m .42495 .45979 L .4224 .46086 L F
.372 .022 .236 r
.41892 .46419 m .42162 .46351 L .4224 .46086 L F
.759 .537 .595 r
.29626 .55165 m .30096 .5492 L .2961 .54914 L F
.29626 .55165 m .30077 .55205 L .30096 .5492 L F
.795 .658 .711 r
.55329 .4135 m .55399 .41728 L .55578 .41373 L F
.598 .879 .564 r
.55578 .41373 m .55897 .41029 L .55744 .41161 L F
.642 .956 .768 r
.55563 .41327 m .55578 .41373 L .55744 .41161 L F
.93 .946 .781 r
.36893 .57042 m .3695 .56625 L .37147 .56908 L F
.148 0 0 r
.37147 .56908 m .3676 .57064 L .36893 .57042 L F
.7 .187 .009 r
.3676 .57064 m .3697 .57159 L .36893 .57042 L F
0 0 0 r
.41612 .5401 m .41505 .5412 L .41759 .53874 L F
.669 .81 .365 r
.64412 .35743 m .64353 .35841 L .64323 .35506 L F
.64412 .35743 m .6426 .36035 L .64353 .35841 L F
.858 .725 .715 r
.34782 .65345 m .34976 .64988 L .34621 .64974 L F
.844 .828 .832 r
.41119 .56694 m .40621 .56855 L .40883 .56794 L F
.469 .127 .303 r
.40883 .56794 m .41227 .56437 L .41119 .56694 L F
.696 .192 0 r
.4243 .53166 m .42644 .53434 L .42804 .53547 L F
.847 .696 .695 r
.4238 .53802 m .42804 .53547 L .42644 .53434 L F
.4238 .53802 m .42591 .53899 L .42804 .53547 L F
0 0 0 r
.4784 .41622 m .4767 .41779 L .47558 .41944 L F
.47966 .41453 m .4767 .41779 L .4784 .41622 L F
.935 .82 .706 r
.50256 .4518 m .49968 .45286 L .50095 .45055 L F
.50256 .4518 m .50147 .4543 L .49968 .45286 L F
.774 .748 .83 r
.39565 .55898 m .39114 .55922 L .3934 .55691 L F
.458 .375 .675 r
.3937 .56144 m .39346 .55909 L .39565 .55898 L F
0 .17 .657 r
.3934 .55691 m .39481 .55795 L .39565 .55898 L F
.971 .926 .616 r
.39481 .55795 m .3937 .56144 L .39565 .55898 L F
.496 .48 .769 r
.39463 .55942 m .39392 .56352 L .3937 .56144 L F
.39392 .56352 m .39373 .5646 L .3937 .56144 L F
.458 .375 .675 r
.3937 .56144 m .39114 .55922 L .39346 .55909 L F
.873 .785 .761 r
.5169 .46335 m .52106 .46123 L .51984 .46054 L F
.5169 .46335 m .51874 .46494 L .52106 .46123 L F
.742 .987 .78 r
.52432 .45817 m .52209 .45916 L .52106 .46123 L F
.672 .944 .961 r
.52106 .46123 m .52209 .45916 L .51984 .46054 L F
.219 .382 .813 r
.37354 .48743 m .37316 .48416 L .37072 .48454 L F
.37354 .48743 m .37474 .4874 L .37316 .48416 L F
.07 0 0 r
.48712 .40707 m .49052 .40611 L .48802 .40689 L F
.031 0 .224 r
.59913 .38564 m .5966 .38982 L .59722 .38741 L F
.514 .615 .89 r
.28153 .56166 m .27816 .56049 L .27895 .56232 L F
.373 .665 .971 r
.31779 .67504 m .32203 .6766 L .32048 .67481 L F
.469 .653 .94 r
.32203 .6766 m .32451 .67547 L .32048 .67481 L F
.32203 .6766 m .32462 .67638 L .32451 .67547 L F
0 .128 .676 r
.3493 .56359 m .3509 .56437 L .34828 .5611 L F
.204 0 0 r
.42008 .52794 m .41801 .53049 L .41531 .53112 L F
.42008 .52794 m .41531 .53112 L .41926 .52895 L F
.42008 .52794 m .41926 .52895 L .41947 .52884 L F
.908 .504 .201 r
.42008 .52794 m .41947 .52884 L .41942 .52875 L F
.42008 .52794 m .41942 .52875 L .41747 .52469 L F
.8 .388 0 r
.41747 .52469 m .41942 .52875 L .41642 .52371 L F
.41942 .52875 m .41947 .52884 L .41942 .52876 L F
.41942 .52875 m .41942 .52876 L .41642 .52371 L F
.965 .939 .658 r
.41747 .52469 m .41642 .52371 L .41837 .52223 L F
.479 .551 .852 r
.41642 .52371 m .41942 .52876 L .42073 .52713 L F
.549 .812 .446 r
.42073 .52713 m .41957 .52857 L .42008 .52794 L F
.41925 .52896 m .41942 .52875 L .42008 .52794 L F
.479 .551 .852 r
.41942 .52876 m .41947 .52884 L .42073 .52713 L F
.549 .812 .446 r
.42073 .52713 m .41925 .52896 L .41957 .52857 L F
.41865 .52971 m .41801 .53049 L .42008 .52794 L F
.971 .828 .643 r
.41934 .52885 m .41801 .53049 L .41947 .52884 L F
.41631 .52926 m .41947 .52884 L .41531 .53112 L F
.41631 .52926 m .41801 .53049 L .41934 .52885 L F
.549 .812 .446 r
.41925 .52896 m .4189 .52939 L .41938 .52881 L F
.41941 .52876 m .41938 .52881 L .41942 .52875 L F
.41925 .52896 m .41938 .52881 L .41941 .52876 L F
.4189 .52939 m .41865 .52971 L .42008 .52794 L F
.42073 .52713 m .42008 .52794 L .42234 .52822 L F
.728 .675 .799 r
.3478 .53922 m .34514 .54229 L .34941 .54247 L F
.662 .419 .542 r
.34537 .54556 m .34941 .54247 L .34514 .54229 L F
.34537 .54556 m .3494 .54554 L .34941 .54247 L F
.761 .689 .782 r
.3478 .53922 m .34941 .54247 L .35257 .53997 L F
.365 0 .178 r
.3871 .48103 m .38975 .48047 L .39109 .47765 L F
.496 .15 .31 r
.38975 .48047 m .39393 .47713 L .39109 .47765 L F
.939 .75 .278 r
.58955 .39753 m .58857 .39837 L .58932 .3951 L F
.58955 .39753 m .5893 .39932 L .58857 .39837 L F
.751 .697 .8 r
.54217 .34958 m .54247 .35224 L .54583 .34976 L F
.629 .639 .841 r
.52847 .3685 m .52985 .37032 L .52587 .37007 L F
.467 .2 .426 r
.41204 .48097 m .40913 .4837 L .40956 .4818 L F
.687 .4 .482 r
.29414 .54911 m .29626 .55165 L .2961 .54914 L F
0 0 0 r
.44225 .44666 m .44385 .44494 L .44026 .44739 L F
.44611 .4437 m .44385 .44494 L .44225 .44666 L F
.858 .814 .805 r
.39419 .57576 m .39562 .5791 L .39755 .57635 L F
.967 .667 .405 r
.42214 .52099 m .42196 .52382 L .4243 .52405 L F
.971 .859 .671 r
.42073 .52713 m .4243 .52405 L .42196 .52382 L F
.42073 .52713 m .42234 .52822 L .4243 .52405 L F
.406 0 .048 r
.40781 .57571 m .40626 .57777 L .40334 .57781 L F
.398 .732 .991 r
.40334 .57781 m .40626 .57777 L .40584 .57742 L F
.123 0 0 r
.40677 .5755 m .40334 .57781 L .40123 .57814 L F
.406 0 .048 r
.40781 .57571 m .40334 .57781 L .40677 .5755 L F
.398 .732 .991 r
.40334 .57781 m .40584 .57742 L .40424 .57608 L F
.123 0 0 r
.40123 .57814 m .40334 .57781 L .40079 .57834 L F
.474 .008 .066 r
.6469 .3479 m .64984 .34807 L .65101 .34622 L F
.443 0 0 r
.64248 .34611 m .6469 .3479 L .64565 .34717 L F
.64248 .34611 m .64546 .34766 L .6469 .3479 L F
.039 .602 .792 r
.6469 .3479 m .64546 .34766 L .64984 .34807 L F
.669 .198 .125 r
.64546 .34766 m .64914 .34917 L .64984 .34807 L F
.64914 .34917 m .65036 .34968 L .64984 .34807 L F
.474 .008 .066 r
.65101 .34622 m .64984 .34807 L .65118 .34614 L F
.589 .019 0 r
.65276 .34792 m .65118 .34614 L .64984 .34807 L F
.761 .689 .782 r
.3478 .53922 m .35257 .53997 L .35008 .53767 L F
.258 0 .158 r
.41817 .46608 m .41647 .46503 L .41562 .46681 L F
.41817 .46608 m .41892 .46419 L .41647 .46503 L F
.997 .789 .496 r
.38588 .58297 m .38551 .58641 L .38406 .58468 L F
.518 0 0 r
.54961 .4218 m .55092 .42088 L .54682 .42052 L F
.029 0 0 r
.55381 .4206 m .55092 .42088 L .54961 .4218 L F
.548 .377 .602 r
.63048 .39578 m .63279 .39635 L .62963 .39656 L F
.63293 .39354 m .63289 .39438 L .63048 .39578 L F
.63289 .39438 m .63279 .39635 L .63048 .39578 L F
.773 .654 .098 r
.63282 .39392 m .63279 .39635 L .63293 .39354 L F
.275 0 0 r
.63293 .39354 m .63615 .39326 L .63282 .39392 L F
.61 .955 .884 r
.63282 .39392 m .6341 .39367 L .63775 .3914 L F
.6341 .39367 m .63615 .39326 L .63752 .39166 L F
.6341 .39367 m .63752 .39166 L .63775 .3914 L F
.612 .956 .858 r
.63615 .39326 m .63992 .39098 L .63775 .3914 L F
.653 .319 .395 r
.34049 .62266 m .33903 .62014 L .33619 .62325 L F
.808 .755 .803 r
.64539 .34174 m .65043 .34066 L .64868 .3395 L F
.64539 .34174 m .64726 .34358 L .65043 .34066 L F
.734 .92 .955 r
.65119 .33803 m .65043 .34066 L .65047 .33735 L F
.65119 .33803 m .64868 .3395 L .65043 .34066 L F
.624 .495 .684 r
.39755 .57635 m .4006 .5764 L .40098 .57262 L F
.566 .206 .318 r
.39755 .57635 m .40079 .57834 L .4006 .5764 L F
.712 .203 .016 r
.55313 .41078 m .55281 .41256 L .55352 .40861 L F
.314 .217 .583 r
.55313 .41078 m .55329 .4135 L .55563 .41327 L F
.712 .203 .016 r
.55313 .41078 m .55563 .41327 L .55281 .41256 L F
.188 .27 .717 r
.58787 .38033 m .59037 .3823 L .58963 .37798 L F
.729 .99 .87 r
.316 .63362 m .31256 .63495 L .31423 .63279 L F
.802 .587 .611 r
.29101 .5456 m .29023 .54911 L .29414 .54911 L F
.687 .4 .482 r
.29414 .54911 m .29433 .55168 L .29626 .55165 L F
.867 .769 .751 r
.45647 .50511 m .45317 .50489 L .45534 .50124 L F
.863 .774 .762 r
.45647 .50511 m .45209 .50723 L .45317 .50489 L F
.45647 .50511 m .45434 .50859 L .45209 .50723 L F
.772 .462 .462 r
.37316 .48416 m .38049 .48602 L .37761 .48262 L F
.192 .332 .777 r
.37761 .48262 m .38049 .48602 L .3798 .48257 L F
0 0 .11 r
.42163 .55528 m .42285 .55086 L .42097 .55202 L F
.846 .97 .877 r
.46236 .52087 m .46352 .52187 L .46667 .51871 L F
.67 .137 0 r
.31365 .6735 m .31779 .67504 L .31616 .67342 L F
.486 .646 .928 r
.31779 .67504 m .31871 .6725 L .31616 .67342 L F
.31779 .67504 m .32048 .67481 L .31871 .6725 L F
.655 .855 .976 r
.61895 .34471 m .61498 .34633 L .61904 .34621 L F
.212 .724 .885 r
.62137 .34482 m .61895 .34471 L .61904 .34621 L F
.872 .882 .839 r
.63697 .36589 m .63385 .36663 L .63605 .36422 L F
.911 .918 .81 r
.63919 .3622 m .63697 .36589 L .63605 .36422 L F
.223 .424 .848 r
.37818 .56707 m .38126 .56829 L .37909 .56477 L F
.561 .687 .924 r
.63583 .34215 m .63748 .33824 L .63459 .3392 L F
.63583 .34215 m .63851 .34149 L .63748 .33824 L F
.727 .775 .891 r
.61553 .38223 m .61682 .38422 L .6129 .38372 L F
.861 .911 .865 r
.61682 .38422 m .61288 .38597 L .6129 .38372 L F
.611 .588 .803 r
.61833 .37908 m .61682 .38422 L .61553 .38223 L F
.61833 .37908 m .62002 .3834 L .61682 .38422 L F
.944 .597 .189 r
.35604 .55355 m .35716 .55291 L .35366 .55274 L F
.35604 .55355 m .35749 .55533 L .35716 .55291 L F
.089 0 .041 r
.46753 .42685 m .46985 .42631 L .47064 .42398 L F
0 0 .009 r
.47064 .42398 m .47194 .42496 L .47281 .42288 L F
.47064 .42398 m .46985 .42631 L .47194 .42496 L F
.077 .631 .815 r
.42732 .54555 m .43015 .54602 L .42687 .54592 L F
.618 .861 .502 r
.40497 .49516 m .40367 .49672 L .40481 .49528 L F
.864 .539 .021 r
.40528 .49492 m .40497 .49516 L .40388 .49111 L F
.069 .243 .735 r
.40388 .49111 m .40638 .49328 L .4053 .49496 L F
.354 .277 .63 r
.40388 .49111 m .40497 .49516 L .40638 .49328 L F
.618 .861 .502 r
.40497 .49516 m .40481 .49528 L .40638 .49328 L F
.864 .539 .021 r
.4053 .49496 m .40497 .49516 L .40528 .49492 L F
.642 .876 .519 r
.4053 .49496 m .40367 .49672 L .40497 .49516 L F
.63 .871 .515 r
.40638 .49328 m .40367 .49672 L .4053 .49496 L F
.855 .86 .844 r
.47088 .48576 m .46618 .48766 L .46936 .48493 L F
.838 .926 .89 r
.47259 .48409 m .47088 .48576 L .47082 .48283 L F
.876 .947 .856 r
.47082 .48283 m .47088 .48576 L .46936 .48493 L F
.316 0 .15 r
.42753 .47151 m .42428 .47385 L .4247 .47175 L F
.465 .142 .334 r
.4247 .47175 m .42428 .47385 L .42161 .4742 L F
.551 .471 .718 r
.54766 .37354 m .55081 .37327 L .54949 .36891 L F
.846 .851 .848 r
.49702 .48109 m .50045 .48126 L .49867 .47984 L F
.877 .871 .828 r
.49867 .47984 m .50045 .48126 L .50343 .47745 L F
0 0 .123 r
.39006 .5863 m .39038 .58121 L .38841 .58532 L F
.446 .881 .856 r
.58474 .34993 m .58613 .34905 L .58814 .34849 L F
0 0 .005 r
.58508 .35085 m .58613 .34905 L .58474 .34993 L F
.292 0 .283 r
.29263 .6346 m .29138 .63664 L .29419 .63628 L F
.405 .162 .429 r
.2968 .63519 m .29263 .6346 L .29419 .63628 L F
.2968 .63519 m .29726 .63285 L .29263 .6346 L F
.78 .65 .719 r
.2833 .57981 m .28097 .58289 L .2815 .58245 L F
.575 .352 .54 r
.2815 .58245 m .28161 .58237 L .2833 .57981 L F
.749 .603 .695 r
.28153 .58249 m .28558 .58338 L .28135 .58293 L F
.28393 .5808 m .28558 .58338 L .28153 .58249 L F
.739 .451 .493 r
.28558 .58338 m .28331 .58567 L .28097 .58289 L F
.586 .422 .625 r
.28154 .58245 m .28331 .58567 L .2861 .58236 L F
.2815 .58245 m .28152 .5825 L .28154 .58245 L F
.28152 .5825 m .28331 .58567 L .28154 .58245 L F
.749 .603 .695 r
.28152 .58252 m .28135 .58293 L .28125 .58292 L F
.28153 .58249 m .28135 .58293 L .28152 .58252 L F
.2833 .57981 m .28393 .5808 L .28153 .58249 L F
.666 .451 .583 r
.28097 .58289 m .28331 .58567 L .28152 .5825 L F
.28097 .58289 m .28152 .5825 L .2815 .58245 L F
.575 .352 .54 r
.28161 .58237 m .28608 .57926 L .2833 .57981 L F
.28161 .58237 m .2861 .58236 L .28608 .57926 L F
.2815 .58245 m .28154 .58245 L .28161 .58237 L F
.28154 .58245 m .2861 .58236 L .28161 .58237 L F
.749 .603 .695 r
.2833 .57981 m .28161 .58237 L .28097 .58289 L F
.28161 .58237 m .28125 .58292 L .28114 .58291 L F
.28161 .58237 m .28114 .58291 L .28097 .58289 L F
.709 .94 .635 r
.2861 .58236 m .28331 .58567 L .28558 .58338 L F
0 0 .392 r
.31765 .62107 m .32001 .6202 L .31752 .62268 L F
.31765 .62107 m .31712 .62045 L .32001 .6202 L F
.405 .673 .97 r
.32001 .6202 m .3206 .61817 L .31752 .62268 L F
.32001 .6202 m .32248 .62013 L .3206 .61817 L F
.877 .871 .828 r
.49867 .47984 m .50343 .47745 L .50174 .47607 L F
.803 .892 .908 r
.50174 .47607 m .50343 .47745 L .50632 .47479 L F
.937 .94 .595 r
.32793 .62016 m .32901 .61847 L .32781 .61826 L F
.96 .931 .718 r
.3312 .61662 m .33346 .61441 L .33328 .61455 L F
.461 .889 .85 r
.32781 .61826 m .32901 .61847 L .32981 .61809 L F
.33044 .61742 m .32981 .61809 L .33282 .61667 L F
.32781 .61826 m .32981 .61809 L .33044 .61742 L F
.32781 .61826 m .33282 .61667 L .32948 .61834 L F
.96 .931 .718 r
.32948 .61834 m .33096 .61688 L .3312 .61662 L F
.33096 .61688 m .33346 .61441 L .3312 .61662 L F
.424 .416 .746 r
.4635 .44211 m .4612 .44435 L .46357 .44293 L F
.382 .171 .464 r
.46343 .44545 m .4612 .44435 L .4635 .44211 L F
.46343 .44545 m .46111 .44653 L .4612 .44435 L F
.815 .705 .744 r
.64248 .34611 m .64726 .34358 L .64539 .34174 L F
.64248 .34611 m .64565 .34717 L .64726 .34358 L F
.756 .729 .827 r
.40949 .50139 m .41387 .50187 L .41289 .4984 L F
0 0 .366 r
.28867 .56473 m .28728 .56693 L .29003 .56573 L F
.28867 .56473 m .2875 .56797 L .28728 .56693 L F
.717 .583 .704 r
.52725 .39689 m .52862 .39978 L .5312 .39697 L F
.729 .721 .843 r
.29857 .57005 m .29397 .56899 L .29432 .572 L F
.793 .997 .856 r
.52498 .4559 m .52432 .45817 L .52527 .45675 L F
.813 .997 .778 r
.52498 .4559 m .52209 .45916 L .52432 .45817 L F
0 0 .392 r
.31765 .62107 m .31721 .62355 L .31712 .62045 L F
.282 .747 .947 r
.31752 .62268 m .31721 .62355 L .31765 .62107 L F
.31752 .62268 m .3197 .62333 L .31721 .62355 L F
.29 0 .218 r
.452 .45132 m .45143 .45328 L .44879 .45414 L F
.298 0 .171 r
.45465 .45069 m .45143 .45328 L .452 .45132 L F
.437 .174 .416 r
.55148 .34248 m .55115 .34509 L .55416 .3421 L F
.111 0 .002 r
.46331 .43217 m .46198 .43156 L .46112 .43321 L F
.46331 .43217 m .46444 .43043 L .46198 .43156 L F
.426 .86 .751 r
.61708 .33924 m .61932 .33784 L .61836 .34009 L F
.717 .963 .942 r
.6238 .33649 m .61836 .34009 L .61932 .33784 L F
.379 .631 .953 r
.34017 .55452 m .34132 .55637 L .3422 .55425 L F
.607 .88 .991 r
.3422 .55425 m .34132 .55637 L .34379 .5553 L F
.825 .981 .883 r
.65998 .37074 m .66178 .36891 L .66094 .36791 L F
.822 .979 .888 r
.65747 .371 m .65998 .37074 L .66094 .36791 L F
.539 .312 .518 r
.42162 .51858 m .42214 .52099 L .41837 .52223 L F
.437 0 0 r
.54949 .36891 m .55224 .36966 L .54928 .36866 L F
.874 .774 .748 r
.51238 .43792 m .51218 .4401 L .50889 .43935 L F
.994 .81 .548 r
.51016 .4418 m .50889 .43935 L .51218 .4401 L F
.635 .561 .754 r
.51518 .43723 m .51218 .4401 L .51238 .43792 L F
.91 .864 .424 r
.5598 .40823 m .56059 .40587 L .56038 .40445 L F
0 0 0 r
.55991 .40763 m .5598 .40823 L .55998 .40721 L F
.718 .86 .44 r
.5598 .40823 m .55965 .409 L .56111 .40626 L F
0 0 0 r
.55951 .41014 m .5598 .40823 L .55991 .40763 L F
.718 .86 .44 r
.5598 .40823 m .55897 .41029 L .55965 .409 L F
.753 .932 .583 r
.55744 .41161 m .55897 .41029 L .5598 .40823 L F
.435 .185 .435 r
.38521 .56926 m .38807 .57123 L .38978 .5693 L F
.921 .924 .796 r
.44296 .52503 m .44363 .52011 L .44401 .52271 L F
.757 .678 .774 r
.34379 .5553 m .3454 .55929 L .34808 .55578 L F
.926 .743 .635 r
.29929 .55541 m .30217 .5592 L .30295 .55617 L F
.29929 .55541 m .30073 .55908 L .30217 .5592 L F
.828 .592 .581 r
.30073 .55908 m .30404 .56264 L .30217 .5592 L F
.108 0 0 r
.62898 .34331 m .62768 .34368 L .62494 .34347 L F
.857 .699 .686 r
.56902 .34788 m .57058 .34444 L .56961 .34615 L F
0 .103 .586 r
.4166 .57037 m .41759 .57111 L .41395 .56794 L F
.792 .989 .743 r
.41557 .57059 m .4166 .57037 L .41395 .56794 L F
.41557 .57059 m .41466 .57221 L .4166 .57037 L F
.258 0 0 r
.4166 .57037 m .41705 .57151 L .41759 .57111 L F
.133 0 .018 r
.41466 .57221 m .41705 .57151 L .4166 .57037 L F
.988 .723 .361 r
.52466 .41378 m .52466 .41661 L .52335 .41508 L F
0 0 0 r
.52732 .41018 m .52466 .41378 L .52499 .41335 L F
.548 .84 .511 r
.52499 .41335 m .52466 .41378 L .52335 .41508 L F
.629 .462 .638 r
.46954 .43859 m .46971 .43972 L .46712 .44147 L F
.456 .181 .406 r
.46954 .43859 m .4727 .43985 L .46971 .43972 L F
.46954 .43859 m .47313 .4373 L .4727 .43985 L F
.789 .62 .672 r
.34082 .54172 m .34514 .54229 L .34453 .53926 L F
.621 .511 .707 r
.34453 .53926 m .34514 .54229 L .3478 .53922 L F
.115 0 .2 r
.29976 .62953 m .29884 .62912 L .29726 .63285 L F
.814 .62 .64 r
.52447 .39972 m .52862 .39978 L .52725 .39689 L F
.472 .107 .264 r
.39673 .47739 m .39975 .47711 L .40075 .47435 L F
.245 0 .171 r
.40075 .47435 m .40221 .47615 L .40347 .47389 L F
.40075 .47435 m .39975 .47711 L .40221 .47615 L F
.418 .072 .268 r
.52617 .35901 m .52926 .3558 L .52605 .35898 L F
.399 .632 .948 r
.2982 .66737 m .30323 .67012 L .30061 .66695 L F
.184 .479 .895 r
.30061 .66695 m .30323 .67012 L .30497 .67054 L F
0 0 0 r
.33686 .5393 m .33633 .54169 L .33616 .54158 L F
.719 .382 .408 r
.33686 .5393 m .33633 .54169 L .34082 .54172 L F
.814 .62 .64 r
.52447 .39972 m .52725 .39689 L .52444 .39697 L F
.718 .375 .395 r
.46971 .43972 m .46661 .44218 L .46712 .44147 L F
.828 .592 .581 r
.30073 .55908 m .29991 .56196 L .30404 .56264 L F
.871 .759 .736 r
.2995 .56504 m .30404 .56264 L .29991 .56196 L F
.2995 .56504 m .3019 .56629 L .30404 .56264 L F
.001 0 0 r
.52213 .43412 m .51788 .43775 L .51998 .4377 L F
.475 .122 .286 r
.52383 .4358 m .52213 .43412 L .51998 .4377 L F
.591 .716 .93 r
.64124 .33924 m .64284 .34257 L .64539 .34174 L F
.815 .705 .744 r
.64248 .34611 m .64539 .34174 L .64284 .34257 L F
.114 0 .097 r
.43732 .45013 m .43959 .44975 L .44026 .44739 L F
.229 0 .128 r
.43732 .45013 m .43892 .45191 L .43959 .44975 L F
.43732 .45013 m .43643 .45281 L .43892 .45191 L F
.129 .007 .432 r
.5116 .3868 m .51389 .38563 L .51404 .38265 L F
0 0 0 r
.51178 .38967 m .51389 .38563 L .5116 .3868 L F
0 0 .437 r
.55567 .41881 m .55399 .41728 L .55381 .4206 L F
.994 .81 .548 r
.51016 .4418 m .50823 .44231 L .50889 .43935 L F
.665 .506 .659 r
.2738 .58621 m .27119 .59012 L .27358 .58744 L F
.237 0 .185 r
.40246 .4892 m .40061 .48884 L .40289 .4882 L F
.40246 .4892 m .39978 .49088 L .40061 .48884 L F
0 .43 .702 r
.39156 .56281 m .38659 .56153 L .38847 .56369 L F
.853 .698 .689 r
.49373 .48428 m .49539 .48835 L .49576 .48531 L F
0 0 .017 r
.46753 .42685 m .46865 .42782 L .46985 .42631 L F
.46753 .42685 m .46669 .4293 L .46865 .42782 L F
.235 .601 .951 r
.36167 .58182 m .36104 .58342 L .36172 .58272 L F
.789 .677 .74 r
.45374 .51119 m .45209 .50723 L .45434 .50859 L F
.464 .81 .998 r
.59982 .34108 m .60252 .3405 L .60388 .34163 L F
.528 .83 .999 r
.60252 .3405 m .60683 .34095 L .60388 .34163 L F
0 0 0 r
.52732 .41018 m .52499 .41335 L .52628 .41137 L F
.451 .237 .496 r
.52732 .41018 m .53098 .40905 L .53011 .40704 L F
.866 .834 .814 r
.52628 .41137 m .53098 .40905 L .52732 .41018 L F
.447 0 0 r
.56026 .38885 m .5549 .38757 L .55769 .38759 L F
.694 .188 .033 r
.5893 .39932 m .59206 .39997 L .59109 .40142 L F
0 0 0 r
.59206 .39997 m .59443 .39588 L .59443 .39914 L F
.002 0 0 r
.59206 .39997 m .5934 .40087 L .59109 .40142 L F
.59206 .39997 m .59443 .39914 L .5934 .40087 L F
.883 .884 .828 r
.55912 .39384 m .5567 .39708 L .555 .3957 L F
.988 .759 .501 r
.5567 .39708 m .55476 .39857 L .555 .3957 L F
.882 .645 .122 r
.42163 .55528 m .42234 .5594 L .42187 .55838 L F
.927 .553 .276 r
.42234 .5594 m .42123 .56098 L .42187 .55838 L F
.42234 .5594 m .42327 .56228 L .42123 .56098 L F
.897 .769 .713 r
.44294 .52821 m .44139 .52378 L .44296 .52503 L F
.921 .924 .796 r
.44296 .52503 m .44139 .52378 L .44363 .52011 L F
.917 .911 .798 r
.47259 .48409 m .4721 .48069 L .47554 .48106 L F
.47259 .48409 m .47082 .48283 L .4721 .48069 L F
.819 .842 .866 r
.51402 .46666 m .51874 .46494 L .5169 .46335 L F
.847 .531 .453 r
.34082 .54172 m .34537 .54556 L .34514 .54229 L F
.846 .935 .884 r
.48491 .40828 m .48247 .41096 L .48423 .4085 L F
.58 .81 .417 r
.48423 .4085 m .48247 .41096 L .48111 .41286 L F
.911 .918 .81 r
.63919 .3622 m .63605 .36422 L .63866 .36338 L F
0 0 0 r
.63919 .3622 m .6426 .36035 L .63882 .35908 L F
.63919 .3622 m .64179 .36152 L .6426 .36035 L F
.787 .957 .924 r
.63874 .36326 m .63759 .36254 L .6409 .35989 L F
.63866 .36338 m .6386 .36334 L .63874 .36326 L F
.6386 .36334 m .63759 .36254 L .63874 .36326 L F
0 0 0 r
.64179 .36152 m .6421 .36144 L .64216 .36131 L F
.64179 .36152 m .64216 .36131 L .6426 .36035 L F
0 .143 .645 r
.38222 .56375 m .38153 .56369 L .37935 .56169 L F
.38222 .56375 m .38336 .56517 L .38153 .56369 L F
.862 .81 .797 r
.48141 .49405 m .4857 .49225 L .48413 .4908 L F
.48141 .49405 m .48348 .49532 L .4857 .49225 L F
.749 .856 .929 r
.48413 .4908 m .4857 .49225 L .48831 .49081 L F
.877 .707 .667 r
.34918 .54836 m .35076 .55237 L .35082 .54919 L F
.886 .985 .713 r
.6045 .36518 m .60234 .36851 L .60261 .36966 L F
.949 .646 .206 r
.60185 .37102 m .60261 .36966 L .60234 .36851 L F
.60185 .37102 m .603 .37256 L .60261 .36966 L F
.736 .647 .76 r
.64182 .34852 m .63725 .34912 L .63998 .34671 L F
.659 .346 .432 r
.64182 .34852 m .6401 .35179 L .63725 .34912 L F
.853 .695 .685 r
.6442 .34954 m .6401 .35179 L .64182 .34852 L F
.883 .82 .781 r
.34644 .64683 m .34895 .643 L .34567 .64336 L F
.11 0 .096 r
.44026 .44739 m .44176 .44863 L .44225 .44666 L F
.44026 .44739 m .43959 .44975 L .44176 .44863 L F
0 .171 .695 r
.29275 .65988 m .29421 .66385 L .29496 .66217 L F
.234 .512 .909 r
.29496 .66217 m .29421 .66385 L .29651 .66431 L F
.334 .49 .865 r
.29421 .66385 m .2982 .66737 L .29651 .66431 L F
.729 .96 .943 r
.63097 .3755 m .62836 .37569 L .63108 .37214 L F
.838 .891 .878 r
.6342 .37225 m .63097 .3755 L .63108 .37214 L F
.889 .925 .839 r
.64537 .38469 m .64652 .37934 L .6439 .38297 L F
.64537 .38469 m .64663 .38199 L .64652 .37934 L F
1 .81 .493 r
.64354 .3849 m .64537 .38469 L .6439 .38297 L F
.64354 .3849 m .64478 .38625 L .64537 .38469 L F
.426 .86 .751 r
.61708 .33924 m .61672 .33921 L .61932 .33784 L F
0 .17 .707 r
.41706 .57619 m .41714 .57447 L .41466 .57221 L F
.859 .514 .398 r
.41706 .57619 m .41435 .5775 L .41714 .57447 L F
0 0 .304 r
.52563 .39291 m .52642 .39543 L .52444 .39697 L F
.327 .486 .865 r
.52543 .39035 m .52842 .39232 L .52563 .39291 L F
.737 .301 .214 r
.52543 .39035 m .52475 .3917 L .52726 .39212 L F
.52712 .39146 m .52726 .39212 L .52842 .39232 L F
.52543 .39035 m .52726 .39212 L .52712 .39146 L F
0 0 .305 r
.52851 .39156 m .52727 .39215 L .52842 .39232 L F
.52727 .39215 m .52563 .39291 L .52842 .39232 L F
.15 0 0 r
.52727 .39215 m .52842 .39232 L .52726 .39212 L F
0 0 .305 r
.52727 .39215 m .52733 .39242 L .52727 .39215 L F
.52733 .39242 m .52733 .39242 L .52727 .39215 L F
.52759 .39328 m .52753 .39338 L .52727 .39215 L F
.52727 .39215 m .52642 .39543 L .52563 .39291 L F
.52753 .39338 m .52642 .39543 L .52727 .39215 L F
.15 0 0 r
.52424 .39265 m .52842 .39232 L .52472 .39176 L F
.52734 .39241 m .52851 .39156 L .52842 .39232 L F
.52472 .39176 m .52727 .39215 L .52475 .3917 L F
.52727 .39215 m .52726 .39212 L .52475 .3917 L F
.52424 .39265 m .52851 .39156 L .52734 .39241 L F
0 0 .305 r
.52733 .39242 m .52753 .39338 L .52733 .39242 L F
.52851 .39156 m .52759 .39328 L .52727 .39215 L F
0 0 0 r
.6426 .36035 m .6421 .36144 L .64353 .35841 L F
.202 0 .214 r
.44587 .45726 m .44516 .46011 L .44297 .4601 L F
.2 0 .113 r
.44449 .46179 m .44297 .4601 L .44516 .46011 L F
.44449 .46179 m .44203 .46283 L .44297 .4601 L F
.733 .365 .355 r
.55733 .37717 m .56096 .37563 L .55937 .37738 L F
.768 .698 .785 r
.29876 .57276 m .29587 .57605 L .30022 .57648 L F
.811 .326 .022 r
.56163 .38052 m .56338 .38158 L .563 .38011 L F
.733 .493 .565 r
.56338 .38158 m .56574 .37941 L .563 .38011 L F
.282 .78 .753 r
.56574 .37941 m .56163 .38052 L .563 .38011 L F
.917 .776 .691 r
.50147 .4543 m .49775 .45648 L .49968 .45286 L F
.50147 .4543 m .4997 .45813 L .49775 .45648 L F
.786 .357 .231 r
.35943 .57562 m .35762 .57752 L .35623 .57508 L F
.849 .666 .654 r
.36193 .57525 m .35762 .57752 L .35943 .57562 L F
.897 .85 .789 r
.49309 .46709 m .48983 .46711 L .49214 .46345 L F
.852 .908 .872 r
.49309 .46709 m .49118 .4686 L .48983 .46711 L F
.854 .832 .824 r
.49415 .4647 m .49309 .46709 L .49214 .46345 L F
.785 .773 .843 r
.55731 .39205 m .55912 .39384 L .55557 .39293 L F
.883 .884 .828 r
.55912 .39384 m .555 .3957 L .55557 .39293 L F
.737 .767 .877 r
.56132 .39259 m .55912 .39384 L .55731 .39205 L F
.089 0 0 r
.40923 .47057 m .41168 .46973 L .4132 .46778 L F
.138 0 .015 r
.41435 .46917 m .4132 .46778 L .41168 .46973 L F
.41435 .46917 m .41562 .46681 L .4132 .46778 L F
.846 .97 .877 r
.46236 .52087 m .46667 .51871 L .46488 .51722 L F
.938 .908 .765 r
.46667 .51871 m .46738 .5137 L .46488 .51722 L F
.242 .758 .806 r
.54628 .38989 m .54603 .38984 L .54384 .3903 L F
.917 .874 .445 r
.54603 .38984 m .54495 .39053 L .54524 .38967 L F
.575 .533 .771 r
.54384 .3903 m .54603 .38984 L .54547 .38493 L F
.917 .874 .445 r
.54603 .38984 m .54524 .38967 L .54582 .388 L F
.242 .758 .806 r
.54822 .38957 m .54603 .38984 L .54628 .38989 L F
.665 .19 .115 r
.54822 .38957 m .55074 .3905 L .54603 .38984 L F
.786 .517 .53 r
.52444 .39697 m .52447 .39972 L .52022 .39902 L F
0 0 .131 r
.52497 .39695 m .52444 .39697 L .52642 .39543 L F
.52497 .39695 m .52447 .39972 L .52444 .39697 L F
.202 0 .184 r
.47629 .4336 m .47568 .43606 L .47313 .4373 L F
.625 .897 .587 r
.47803 .43237 m .48127 .42889 L .47879 .43129 L F
0 0 0 r
.47859 .43166 m .47803 .43237 L .47879 .43129 L F
.461 .871 .952 r
.47731 .43329 m .47878 .43284 L .47803 .43237 L F
0 0 0 r
.47697 .43461 m .47803 .43237 L .47859 .43166 L F
.461 .871 .952 r
.47629 .4336 m .47731 .43329 L .47803 .43237 L F
0 0 0 r
.47697 .43461 m .47629 .4336 L .47803 .43237 L F
.47697 .43461 m .47568 .43606 L .47629 .4336 L F
.732 .592 .7 r
.30077 .55205 m .30295 .55617 L .3053 .5525 L F
.807 .989 .733 r
.38781 .56093 m .38944 .55808 L .39114 .55922 L F
.38781 .56093 m .38659 .56153 L .38944 .55808 L F
.14 0 .223 r
.28629 .6438 m .28363 .64704 L .28556 .6463 L F
.036 0 .313 r
.28363 .64704 m .2848 .6488 L .28556 .6463 L F
.28363 .64704 m .28341 .64966 L .2848 .6488 L F
.473 .105 .258 r
.53399 .36027 m .53399 .3622 L .5306 .36237 L F
.807 .387 .249 r
.53792 .36308 m .53399 .36027 L .53786 .36025 L F
.53792 .36308 m .53399 .3622 L .53399 .36027 L F
.815 .684 .719 r
.49128 .48807 m .49539 .48835 L .49373 .48428 L F
.924 .874 .769 r
.29235 .56784 m .2952 .56791 L .29492 .56393 L F
.29235 .56784 m .29397 .56899 L .2952 .56791 L F
.638 .655 .85 r
.29492 .56393 m .2952 .56791 L .2995 .56504 L F
.664 .629 .804 r
.2952 .56791 m .30092 .56883 L .2995 .56504 L F
.838 .788 .804 r
.56391 .4002 m .56739 .40032 L .56602 .39663 L F
.721 .643 .771 r
.56888 .3902 m .56591 .39357 L .56435 .38937 L F
.778 .761 .838 r
.56602 .39663 m .56739 .40032 L .56984 .39732 L F
.903 .782 .718 r
.48141 .49405 m .4826 .49798 L .48348 .49532 L F
.718 .375 .395 r
.46971 .43972 m .46992 .44302 L .46661 .44218 L F
.061 0 .341 r
.47173 .44125 m .46971 .43972 L .4727 .43985 L F
.47173 .44125 m .46992 .44302 L .46971 .43972 L F
.347 .127 .431 r
.66256 .35252 m .66507 .35182 L .66435 .34976 L F
.488 0 0 r
.29309 .65463 m .29544 .65368 L .29108 .65321 L F
.332 0 0 r
.29108 .65321 m .29544 .65368 L .2943 .6538 L F
.746 .645 .748 r
.27773 .57483 m .2792 .57936 L .28191 .57593 L F
.499 .908 .863 r
.2943 .6538 m .29544 .65368 L .29696 .65237 L F
.494 .888 .725 r
.29696 .65237 m .29544 .65368 L .29309 .65463 L F
.938 .966 .722 r
.52021 .37703 m .51815 .37764 L .52081 .37332 L F
.798 .728 .786 r
.50686 .43319 m .50834 .43727 L .50414 .43663 L F
.77 .376 .306 r
.50414 .43663 m .50834 .43727 L .50889 .43935 L F
.705 .68 .824 r
.51075 .43409 m .50834 .43727 L .50686 .43319 L F
.676 .638 .804 r
.51075 .43409 m .51238 .43792 L .50834 .43727 L F
.874 .774 .748 r
.51238 .43792 m .50889 .43935 L .50834 .43727 L F
.396 .772 .992 r
.32206 .62376 m .3197 .62333 L .32216 .62319 L F
.179 0 0 r
.32035 .62428 m .32216 .62319 L .3197 .62333 L F
.546 .812 .995 r
.32231 .62221 m .32216 .62319 L .32035 .62428 L F
.32345 .62101 m .32216 .62319 L .32231 .62221 L F
.396 .772 .992 r
.32408 .62412 m .32206 .62376 L .32216 .62319 L F
.657 .901 .981 r
.32666 .62277 m .32408 .62412 L .32216 .62319 L F
.839 .524 .455 r
.65481 .35286 m .65546 .35535 L .65936 .35632 L F
.859 .478 .325 r
.65546 .35535 m .65912 .35847 L .65936 .35632 L F
.709 .669 .809 r
.61616 .39401 m .61184 .39416 L .61467 .39314 L F
.588 .285 .422 r
.61952 .39337 m .61616 .39401 L .61467 .39314 L F
.61952 .39337 m .61854 .39511 L .61616 .39401 L F
.58 .054 0 r
.61616 .39401 m .61694 .39638 L .6146 .39661 L F
.61616 .39401 m .61854 .39511 L .61694 .39638 L F
.764 .661 .748 r
.3465 .55185 m .35076 .55237 L .34918 .54836 L F
.764 .662 .75 r
.3465 .55185 m .34808 .55578 L .35076 .55237 L F
.653 .5 .664 r
.34808 .55578 m .35176 .55586 L .35076 .55237 L F
.58 .13 .146 r
.35076 .55237 m .35303 .554 L .35366 .55274 L F
.262 .257 .664 r
.35076 .55237 m .35143 .55469 L .35303 .554 L F
.944 .597 .189 r
.35604 .55355 m .35366 .55274 L .35303 .554 L F
.401 .82 .971 r
.35303 .554 m .3515 .55341 L .35422 .55349 L F
.35303 .554 m .35422 .55349 L .35604 .55355 L F
.262 .257 .664 r
.35143 .55469 m .35176 .55586 L .35303 .554 L F
.299 .019 .31 r
.44879 .45414 m .4483 .45663 L .44587 .45726 L F
.379 .086 .336 r
.45124 .45551 m .44879 .45414 L .45143 .45328 L F
.45124 .45551 m .4483 .45663 L .44879 .45414 L F
.762 .661 .751 r
.34379 .5553 m .34808 .55578 L .3465 .55185 L F
.909 .669 .563 r
.47554 .48106 m .4721 .48069 L .47338 .48066 L F
.834 .867 .869 r
.47554 .48106 m .47677 .4763 L .47822 .47741 L F
.47554 .48106 m .47338 .48066 L .47677 .4763 L F
.922 .967 .666 r
.65448 .35168 m .65624 .35039 L .65684 .3479 L F
.65448 .35168 m .65481 .35286 L .65624 .35039 L F
0 0 0 r
.52873 .37451 m .5287 .37445 L .53 .37364 L F
.995 .818 .456 r
.52875 .37102 m .52873 .37451 L .53 .37364 L F
.004 .003 .502 r
.52948 .37307 m .52873 .37451 L .52875 .37102 L F
0 0 .259 r
.52829 .3732 m .52873 .37451 L .52948 .37307 L F
0 0 .471 r
.53075 .37138 m .53 .37364 L .52994 .37231 L F
.53045 .37104 m .52994 .37231 L .52985 .37032 L F
.53075 .37138 m .52994 .37231 L .53045 .37104 L F
.691 .659 .814 r
.53241 .36969 m .52847 .3685 L .53187 .36725 L F
.167 .361 .812 r
.53309 .36709 m .53241 .36969 L .53187 .36725 L F
.825 1 .824 r
.53309 .36709 m .53118 .36924 L .53241 .36969 L F
.691 .659 .814 r
.53241 .36969 m .52985 .37032 L .52847 .3685 L F
.412 0 .116 r
.53241 .36969 m .53075 .37138 L .52985 .37032 L F
.825 1 .824 r
.53118 .36924 m .5297 .37092 L .53068 .37047 L F
.53118 .36924 m .53068 .37047 L .53241 .36969 L F
.995 .818 .456 r
.52875 .37102 m .53 .37364 L .53075 .37138 L F
.612 .856 .99 r
.5297 .37092 m .52875 .37102 L .53075 .37138 L F
.428 .859 .936 r
.5297 .37092 m .52638 .37112 L .52875 .37102 L F
.5297 .37092 m .52986 .37003 L .52638 .37112 L F
.004 .003 .502 r
.52948 .37307 m .52875 .37102 L .52638 .37112 L F
.52948 .37307 m .52638 .37112 L .52986 .37003 L F
.579 .553 .789 r
.53187 .36725 m .52847 .3685 L .52755 .36547 L F
.608 .405 .581 r
.5306 .36237 m .53161 .36629 L .52755 .36547 L F
.579 .553 .789 r
.53187 .36725 m .52755 .36547 L .53161 .36629 L F
.531 .488 .753 r
.52638 .37112 m .52986 .37003 L .52807 .36519 L F
.087 0 0 r
.52638 .37112 m .52885 .37146 L .52986 .37003 L F
.559 .493 .737 r
.52532 .37252 m .52813 .37353 L .52885 .37146 L F
.522 .463 .731 r
.52813 .37353 m .52935 .36986 L .52885 .37146 L F
.52819 .37336 m .52994 .37073 L .52935 .36986 L F
0 0 .259 r
.52824 .37321 m .52826 .37326 L .52829 .3732 L F
.52826 .37326 m .52873 .37451 L .52829 .3732 L F
.52836 .37323 m .52948 .37307 L .52979 .37349 L F
.522 .463 .731 r
.52813 .37353 m .52842 .37308 L .52819 .37336 L F
.52842 .37308 m .52994 .37073 L .52845 .37296 L F
.52842 .37308 m .52845 .37296 L .52819 .37336 L F
0 0 0 r
.52873 .37451 m .52615 .37602 L .5287 .37445 L F
.449 .302 .588 r
.52615 .37602 m .52708 .37934 L .52394 .3801 L F
.478 .319 .587 r
.52996 .37837 m .52615 .37602 L .52873 .37451 L F
.52996 .37837 m .52708 .37934 L .52615 .37602 L F
.522 .463 .731 r
.52813 .37353 m .52836 .37323 L .52833 .37322 L F
.834 .976 .882 r
.52836 .37323 m .52813 .37353 L .52824 .37321 L F
.52979 .37349 m .52813 .37353 L .52836 .37323 L F
.311 .801 .856 r
.52839 .37348 m .52813 .37353 L .53005 .37341 L F
.522 .463 .731 r
.52813 .37353 m .52849 .37329 L .52836 .37323 L F
0 0 .259 r
.52824 .37321 m .52829 .3732 L .52836 .37323 L F
.669 .81 .951 r
.52868 .37316 m .52813 .37353 L .52824 .37321 L F
0 0 .259 r
.52829 .3732 m .52948 .37307 L .52836 .37323 L F
0 0 0 r
.53213 .37257 m .52979 .37349 L .52948 .37307 L F
.669 .81 .951 r
.53183 .37281 m .52813 .37353 L .52868 .37316 L F
.522 .463 .731 r
.52813 .37353 m .52898 .3735 L .52849 .37329 L F
.311 .801 .856 r
.53005 .37341 m .52813 .37353 L .52979 .37349 L F
0 0 0 r
.53213 .37257 m .53183 .37281 L .52979 .37349 L F
.311 .801 .856 r
.53183 .37281 m .52839 .37348 L .53005 .37341 L F
.775 .495 .512 r
.52481 .37278 m .52677 .37453 L .52813 .37353 L F
.748 .328 .25 r
.52662 .37833 m .5271 .37818 L .52811 .37378 L F
.52662 .37833 m .52811 .37378 L .52808 .37379 L F
.775 .495 .512 r
.52783 .37376 m .52818 .37374 L .52813 .37353 L F
.52677 .37453 m .52805 .37381 L .52783 .37376 L F
.52805 .37381 m .52818 .37374 L .52783 .37376 L F
.748 .328 .25 r
.52662 .37833 m .528 .37403 L .52796 .37411 L F
.528 .37403 m .52818 .37349 L .52796 .37411 L F
0 0 .259 r
.52827 .37328 m .52878 .37461 L .52873 .37451 L F
.52824 .37321 m .52834 .37347 L .52827 .37328 L F
0 0 .062 r
.52836 .3736 m .52822 .37412 L .52813 .37353 L F
.765 .698 .788 r
.52822 .37412 m .52823 .37365 L .52813 .37353 L F
.298 .032 .331 r
.52818 .37374 m .52823 .37365 L .52813 .37353 L F
0 0 .062 r
.52835 .37349 m .52836 .3736 L .52813 .37353 L F
.298 .032 .331 r
.52823 .37365 m .52831 .37353 L .52813 .37353 L F
.765 .698 .788 r
.52823 .37365 m .52824 .37321 L .52813 .37353 L F
.748 .328 .25 r
.52823 .37384 m .52823 .37384 L .52833 .37344 L F
0 0 .259 r
.52831 .3734 m .52878 .37461 L .52827 .37328 L F
.52837 .37355 m .52878 .37461 L .52831 .3734 L F
.52878 .37461 m .52943 .37628 L .52873 .37451 L F
.52943 .37628 m .52982 .37732 L .52909 .37543 L F
.52943 .37628 m .52909 .37543 L .52873 .37451 L F
0 0 .062 r
.53183 .37281 m .52985 .37735 L .52966 .37688 L F
.53183 .37281 m .52966 .37688 L .52835 .37349 L F
.612 .856 .99 r
.5297 .37092 m .53075 .37138 L .53241 .36969 L F
.529 .921 .886 r
.53211 .36914 m .5297 .37092 L .53309 .36709 L F
.759 .625 .712 r
.53785 .36578 m .53352 .36561 L .53399 .3622 L F
.285 0 .152 r
.53652 .36553 m .53352 .36561 L .53785 .36578 L F
.411 .053 .244 r
.53652 .36553 m .53211 .36914 L .53309 .36709 L F
.189 .053 .453 r
.53211 .36914 m .53213 .37257 L .52948 .37307 L F
.411 .053 .244 r
.53652 .36553 m .53536 .36845 L .53211 .36914 L F
.718 .463 .539 r
.53621 .37217 m .53211 .36914 L .53536 .36845 L F
.53621 .37217 m .53213 .37257 L .53211 .36914 L F
0 0 0 r
.53621 .37217 m .53183 .37281 L .53213 .37257 L F
.53621 .37217 m .53465 .37245 L .53183 .37281 L F
.166 .705 .791 r
.53465 .37245 m .53432 .37229 L .53183 .37281 L F
.129 0 .235 r
.53432 .37229 m .5314 .37574 L .53183 .37281 L F
.418 .47 .807 r
.53173 .37337 m .53221 .37317 L .53223 .36789 L F
.53221 .37317 m .53432 .37229 L .53376 .37111 L F
.53221 .37317 m .53376 .37111 L .53223 .36789 L F
0 0 .062 r
.53093 .37486 m .5314 .37574 L .52985 .37735 L F
.53183 .37281 m .53167 .37389 L .53093 .37486 L F
.53167 .37389 m .5314 .37574 L .53093 .37486 L F
0 0 .337 r
.52884 .37486 m .52982 .37732 L .52996 .37837 L F
.52873 .37451 m .52982 .37732 L .52884 .37486 L F
.568 .41 .627 r
.52967 .38121 m .52708 .37934 L .52996 .37837 L F
.699 .31 .307 r
.52982 .37732 m .52967 .38121 L .52996 .37837 L F
.52982 .37732 m .53147 .37846 L .52967 .38121 L F
.748 .328 .25 r
.52759 .37802 m .53018 .37897 L .52982 .37732 L F
.53018 .37897 m .53054 .3791 L .53023 .37834 L F
.53018 .37897 m .53023 .37834 L .52982 .37732 L F
.5292 .37883 m .53054 .3791 L .52759 .37802 L F
.53054 .3791 m .53078 .37914 L .52982 .37732 L F
.699 .31 .307 r
.52982 .37732 m .53078 .37914 L .53147 .37846 L F
0 0 .006 r
.53011 .37947 m .53009 .37953 L .52977 .37923 L F
.452 .309 .596 r
.52708 .37934 m .52683 .38189 L .52394 .3801 L F
.568 .41 .627 r
.52967 .38121 m .52683 .38189 L .52708 .37934 L F
.863 .843 .823 r
.52977 .37923 m .5292 .37883 L .52662 .37833 L F
.748 .328 .25 r
.52662 .37833 m .5292 .37883 L .52759 .37802 L F
.814 .587 .595 r
.52977 .37923 m .52662 .37833 L .52886 .37839 L F
.53009 .37953 m .52662 .37833 L .52977 .37923 L F
.863 .843 .823 r
.53004 .37942 m .52977 .37923 L .52662 .37833 L F
.814 .587 .595 r
.53009 .37953 m .5263 .38086 L .52662 .37833 L F
.863 .843 .823 r
.5263 .38086 m .53004 .37942 L .52662 .37833 L F
.53004 .37942 m .53078 .37914 L .5292 .37883 L F
0 0 .006 r
.53016 .37932 m .53011 .37947 L .5295 .37899 L F
.53011 .37947 m .52977 .37923 L .5295 .37899 L F
0 0 0 r
.52811 .38243 m .52683 .38189 L .52967 .38121 L F
.863 .843 .823 r
.52898 .38037 m .52811 .38243 L .52992 .38019 L F
.52725 .38168 m .52811 .38243 L .52898 .38037 L F
0 0 0 r
.53009 .37953 m .53008 .37953 L .53009 .37953 L F
0 0 .006 r
.53009 .37952 m .53009 .37953 L .53009 .37953 L F
.863 .843 .823 r
.5263 .38086 m .52992 .38019 L .53009 .37953 L F
0 0 .001 r
.53008 .37953 m .5263 .38086 L .53009 .37953 L F
.863 .843 .823 r
.5263 .38086 m .53009 .37953 L .53012 .37939 L F
.5263 .38086 m .52725 .38168 L .52898 .38037 L F
0 0 .001 r
.52794 .38163 m .5263 .38086 L .53008 .37953 L F
0 0 0 r
.53007 .38022 m .52794 .38163 L .53008 .37953 L F
.863 .843 .823 r
.53018 .37937 m .52992 .38019 L .53078 .37914 L F
.53012 .37939 m .53009 .37953 L .53018 .37937 L F
.53009 .37953 m .52992 .38019 L .53018 .37937 L F
0 0 0 r
.53007 .38022 m .53009 .37953 L .53098 .37857 L F
.53009 .37953 m .53009 .37953 L .53009 .37953 L F
.53009 .37953 m .53009 .37953 L .53098 .37857 L F
.53007 .38022 m .53008 .37953 L .53009 .37953 L F
0 0 .006 r
.53016 .37932 m .53015 .37946 L .53009 .37953 L F
.53016 .37932 m .53009 .37953 L .53009 .37952 L F
.5314 .37574 m .53098 .37857 L .53015 .37946 L F
.5314 .37574 m .53015 .37946 L .53016 .37932 L F
.5314 .37574 m .53016 .37932 L .52886 .37839 L F
.53016 .37932 m .5295 .37899 L .52886 .37839 L F
0 0 .062 r
.52966 .37688 m .52985 .37735 L .52886 .37839 L F
.748 .328 .25 r
.52712 .37817 m .52982 .37732 L .52837 .37355 L F
0 0 .259 r
.52834 .37347 m .52837 .37355 L .52831 .3734 L F
.748 .328 .25 r
.52712 .37817 m .52837 .37355 L .52833 .37344 L F
0 0 .062 r
.52836 .3736 m .52886 .37839 L .52822 .37412 L F
.748 .328 .25 r
.5271 .37818 m .52833 .37344 L .52824 .37321 L F
.765 .698 .788 r
.52886 .37839 m .52824 .37321 L .52822 .37412 L F
.748 .328 .25 r
.5271 .37818 m .52712 .37817 L .52823 .37384 L F
.5271 .37818 m .52823 .37384 L .52823 .37384 L F
0 0 .062 r
.52966 .37688 m .52886 .37839 L .52835 .37349 L F
.298 .032 .331 r
.52882 .37636 m .52928 .37588 L .52831 .37353 L F
.52928 .37588 m .53173 .37337 L .52836 .37352 L F
.52928 .37588 m .52836 .37352 L .52831 .37353 L F
.765 .698 .788 r
.52886 .37839 m .52662 .37833 L .52805 .37381 L F
.748 .328 .25 r
.52796 .37411 m .52818 .37349 L .52815 .37349 L F
.52808 .37379 m .52811 .37378 L .52818 .37349 L F
.52815 .37349 m .52818 .37349 L .52824 .37321 L F
.765 .698 .788 r
.52832 .37387 m .52805 .37381 L .52824 .37321 L F
.52886 .37839 m .52805 .37381 L .52832 .37387 L F
.298 .032 .331 r
.52882 .37636 m .52831 .37353 L .52818 .37374 L F
.775 .495 .512 r
.52677 .37453 m .52882 .37636 L .52818 .37374 L F
.529 .921 .886 r
.53211 .36914 m .52986 .37003 L .5297 .37092 L F
.189 .053 .453 r
.53211 .36914 m .52948 .37307 L .52986 .37003 L F
.522 .463 .731 r
.52833 .37322 m .53173 .37337 L .52994 .37073 L F
.52898 .3735 m .53173 .37337 L .52833 .37322 L F
.789 .552 .578 r
.53098 .40905 m .53226 .40644 L .53011 .40704 L F
.064 0 0 r
.43649 .4666 m .43718 .46519 L .43962 .46392 L F
.878 .946 .854 r
.47822 .47741 m .4796 .47304 L .48098 .47404 L F
.47822 .47741 m .47677 .4763 L .4796 .47304 L F
0 0 0 r
.45866 .43424 m .45495 .43674 L .45727 .43576 L F
.46112 .43321 m .45866 .43424 L .45727 .43576 L F
.618 .677 .884 r
.63545 .33541 m .63335 .33654 L .62878 .33433 L F
.64 .772 .943 r
.51176 .43445 m .51238 .43792 L .51075 .43409 L F
.51176 .43445 m .51518 .43723 L .51238 .43792 L F
.938 .8 .681 r
.34394 .65607 m .3475 .6559 L .34782 .65345 L F
.925 .792 .695 r
.34321 .65859 m .3475 .6559 L .34394 .65607 L F
.34321 .65859 m .34523 .65991 L .3475 .6559 L F
.919 .857 .764 r
.38111 .57119 m .38521 .56926 L .38126 .56829 L F
.38111 .57119 m .38286 .57271 L .38521 .56926 L F
.435 .185 .435 r
.38521 .56926 m .38543 .5719 L .38807 .57123 L F
.526 .801 .996 r
.5573 .37265 m .56157 .37335 L .56012 .37195 L F
.5573 .37265 m .56157 .37335 L .56012 .37195 L F
.995 .767 .472 r
.56157 .37335 m .56096 .37563 L .56012 .37195 L F
0 0 0 r
.56443 .37042 m .56157 .37335 L .5636 .37185 L F
.623 .846 .985 r
.5636 .37185 m .56157 .37335 L .56012 .37195 L F
.388 .188 .483 r
.56096 .37563 m .5636 .37185 L .56157 .37335 L F
.634 .482 .659 r
.28461 .57251 m .2846 .57652 L .28191 .57593 L F
.452 0 0 r
.28191 .57593 m .28481 .57679 L .2846 .57652 L F
.352 .255 .603 r
.28696 .57475 m .2846 .57652 L .28461 .57251 L F
.025 0 .128 r
.28696 .57475 m .28481 .57679 L .2846 .57652 L F
.438 .511 .836 r
.28191 .57593 m .28481 .57679 L .28303 .57338 L F
.992 .862 .606 r
.41837 .52223 m .41642 .52371 L .41733 .52104 L F
.41733 .52104 m .41642 .52371 L .41837 .52223 L F
.499 .002 .007 r
.41837 .52223 m .42188 .52353 L .42214 .52099 L F
.41837 .52223 m .41642 .52371 L .42188 .52353 L F
.926 .743 .635 r
.29929 .55541 m .29825 .55837 L .30073 .55908 L F
.929 .713 .59 r
.29825 .55837 m .29991 .56196 L .30073 .55908 L F
.987 .833 .604 r
.40098 .57262 m .4006 .5764 L .39946 .57312 L F
0 0 0 r
.39946 .57312 m .40111 .57184 L .40098 .57262 L F
.831 .936 .897 r
.46738 .5137 m .47208 .5118 L .4702 .51035 L F
.865 .83 .811 r
.4702 .51035 m .47208 .5118 L .47463 .50828 L F
.537 .867 .994 r
.61467 .39314 m .61184 .39416 L .61067 .39309 L F
.969 .735 .53 r
.34582 .65245 m .34782 .65345 L .34621 .64974 L F
.938 .8 .681 r
.34394 .65607 m .34782 .65345 L .34582 .65245 L F
.865 .83 .811 r
.4702 .51035 m .47463 .50828 L .47284 .50695 L F
.863 .867 .84 r
.47284 .50695 m .47463 .50828 L .47745 .50489 L F
.413 .127 .366 r
.4483 .45663 m .44516 .46011 L .44587 .45726 L F
.278 0 .167 r
.43136 .45453 m .43058 .45638 L .43391 .45372 L F
.489 .821 .999 r
.40214 .55106 m .40581 .55167 L .40342 .55222 L F
.551 .006 0 r
.39281 .48841 m .39098 .48949 L .38829 .48789 L F
.828 .378 .159 r
.39281 .48841 m .39475 .49124 L .39256 .48856 L F
.39475 .49124 m .39583 .49283 L .39487 .49157 L F
.39475 .49124 m .39487 .49157 L .39256 .48856 L F
.735 .395 .405 r
.39674 .4908 m .39583 .49283 L .39281 .48841 L F
.682 .292 .302 r
.39674 .4908 m .39487 .49157 L .39583 .49283 L F
.39487 .49157 m .39293 .49238 L .39583 .49283 L F
.39487 .49157 m .39516 .49237 L .39293 .49238 L F
.89 .639 .552 r
.39293 .49238 m .39516 .49237 L .39583 .49283 L F
.682 .292 .302 r
.39516 .49237 m .3955 .49332 L .39293 .49238 L F
.89 .639 .552 r
.39293 .49238 m .39098 .48949 L .39516 .49237 L F
.828 .378 .159 r
.39256 .48856 m .39583 .49283 L .39098 .48949 L F
.769 .633 .711 r
.39098 .48949 m .39516 .49237 L .39293 .49238 L F
.39516 .49237 m .39583 .49283 L .39293 .49238 L F
.682 .292 .302 r
.39597 .49236 m .39553 .49333 L .3955 .49332 L F
.39674 .4908 m .39599 .49236 L .39597 .49236 L F
.39599 .49236 m .39553 .49333 L .39597 .49236 L F
.39674 .4908 m .3955 .49332 L .39487 .49157 L F
.438 .185 .432 r
.28556 .6463 m .28862 .643 L .28629 .6438 L F
.757 .556 .626 r
.27691 .5687 m .27987 .57258 L .27868 .5676 L F
.27691 .5687 m .27851 .5732 L .27987 .57258 L F
.474 .895 .866 r
.44488 .54078 m .44457 .54039 L .44317 .54169 L F
.778 .733 .811 r
.60503 .39667 m .60581 .39947 L .60195 .40024 L F
.197 0 0 r
.60195 .40024 m .60581 .39947 L .60417 .40047 L F
.002 0 0 r
.60581 .39947 m .60788 .39941 L .60417 .40047 L F
.60581 .39947 m .60865 .39914 L .60788 .39941 L F
.891 .984 .806 r
.63775 .3914 m .63992 .39098 L .64111 .38901 L F
0 0 0 r
.49966 .39702 m .49708 .4005 L .49895 .39852 L F
.588 .939 .932 r
.49895 .39852 m .50084 .39729 L .49966 .39702 L F
.001 0 0 r
.49966 .39702 m .50084 .39729 L .50251 .39632 L F
.741 .901 .95 r
.49118 .4686 m .48635 .46952 L .48983 .46711 L F
.431 .091 .287 r
.41538 .47849 m .41472 .48039 L .41204 .48097 L F
.589 .356 .531 r
.41768 .47743 m .41472 .48039 L .41538 .47849 L F
.441 .208 .463 r
.3338 .54467 m .33633 .54169 L .33365 .54231 L F
.859 .474 .315 r
.35749 .55533 m .35986 .55859 L .36204 .55569 L F
.759 .625 .712 r
.53785 .36578 m .53399 .3622 L .53792 .36308 L F
.718 .618 .745 r
.54056 .35936 m .53792 .36308 L .53786 .36025 L F
.583 .435 .646 r
.54056 .35936 m .54109 .36247 L .53792 .36308 L F
.58 .355 .539 r
.54109 .36247 m .53785 .36578 L .53792 .36308 L F
.357 0 0 r
.51874 .39226 m .52179 .39207 L .52293 .39081 L F
.86 .793 .298 r
.60881 .35062 m .60833 .35144 L .60865 .35164 L F
.761 .752 .844 r
.45374 .51119 m .45179 .51295 L .44963 .51086 L F
.853 .695 .685 r
.6442 .34954 m .64354 .35275 L .6401 .35179 L F
.765 .694 .783 r
.36346 .56537 m .3609 .56915 L .36484 .56914 L F
.035 .606 .736 r
.3609 .56915 m .36415 .56908 L .36484 .56914 L F
.181 .486 .9 r
.36456 .56721 m .3676 .57064 L .36484 .56914 L F
.919 .85 .405 r
.36484 .56914 m .36415 .56908 L .36456 .56721 L F
.72 .434 .492 r
.30575 .63018 m .3075 .63006 L .30731 .63266 L F
.691 .206 .091 r
.3075 .63006 m .30974 .63161 L .30731 .63266 L F
.774 .965 .925 r
.66178 .36891 m .66441 .36528 L .66094 .36791 L F
.66178 .36891 m .66537 .3663 L .66441 .36528 L F
.921 .674 .547 r
.34394 .64872 m .34644 .64683 L .34396 .64599 L F
.34394 .64872 m .34621 .64974 L .34644 .64683 L F
.883 .82 .781 r
.34644 .64683 m .34567 .64336 L .34396 .64599 L F
.88 .773 .739 r
.48141 .49405 m .47931 .4978 L .4826 .49798 L F
.856 .783 .779 r
.47831 .49986 m .4826 .49798 L .47931 .4978 L F
.47831 .49986 m .48019 .50149 L .4826 .49798 L F
.649 .518 .69 r
.28745 .56918 m .28832 .57293 L .28461 .57251 L F
.352 .255 .603 r
.28696 .57475 m .28461 .57251 L .28832 .57293 L F
.718 .365 .377 r
.28303 .57338 m .28832 .57293 L .28461 .57251 L F
.649 .518 .69 r
.28745 .56918 m .28832 .57293 L .28461 .57251 L F
.881 .82 .783 r
.49646 .46135 m .49214 .46345 L .4947 .45984 L F
.49646 .46135 m .49415 .4647 L .49214 .46345 L F
.787 .852 .9 r
.4989 .45934 m .49646 .46135 L .4947 .45984 L F
.797 .614 .653 r
.29929 .55541 m .30295 .55617 L .30077 .55205 L F
.389 .814 .635 r
.52172 .36942 m .52248 .36893 L .52511 .36742 L F
.061 .222 .718 r
.5234 .36194 m .52511 .36742 L .52583 .36366 L F
.586 .931 .742 r
.52511 .36742 m .52574 .36609 L .52583 .36366 L F
.52511 .36742 m .52248 .36893 L .52574 .36609 L F
.256 .442 .852 r
.39946 .57312 m .4006 .5764 L .40227 .5738 L F
0 0 .185 r
.4006 .5764 m .40162 .5765 L .40227 .5738 L F
.4006 .5764 m .40079 .57834 L .40162 .5765 L F
.978 .766 .349 r
.51058 .40258 m .50639 .4037 L .50906 .40342 L F
.324 0 0 r
.63711 .34752 m .63868 .34742 L .63873 .34753 L F
.167 0 0 r
.63873 .34753 m .64143 .34724 L .64248 .34611 L F
.324 0 0 r
.63868 .34742 m .64143 .34724 L .63873 .34753 L F
.555 .883 .62 r
.63882 .34774 m .63873 .34753 L .63998 .34671 L F
.63725 .34912 m .63873 .34753 L .63882 .34774 L F
.699 .329 .343 r
.63725 .34912 m .63616 .34864 L .63873 .34753 L F
.63725 .34912 m .63734 .35121 L .63616 .34864 L F
.63725 .34912 m .6401 .35179 L .63734 .35121 L F
0 0 0 r
.50256 .44657 m .50582 .44378 L .50309 .444 L F
.49864 .40751 m .49749 .40874 L .49524 .40956 L F
.49979 .40756 m .49749 .40874 L .49864 .40751 L F
.414 .809 .986 r
.60683 .34095 m .60956 .34041 L .61086 .34126 L F
.139 .68 .83 r
.60956 .34041 m .61343 .3405 L .61086 .34126 L F
.912 .96 .634 r
.44144 .53482 m .44289 .53078 L .44471 .53211 L F
.44144 .53482 m .44072 .53457 L .44289 .53078 L F
.452 .835 .606 r
.59783 .34255 m .59932 .34138 L .59982 .34108 L F
0 0 0 r
.59805 .34419 m .59932 .34138 L .59783 .34255 L F
.72 .595 .715 r
.60529 .34966 m .60881 .35062 L .60776 .3487 L F
.914 .956 .805 r
.60621 .3511 m .60382 .35302 L .60587 .35301 L F
.58 .029 0 r
.60529 .34966 m .60742 .3509 L .60881 .35062 L F
.60742 .3509 m .60833 .35144 L .60877 .35068 L F
.60742 .3509 m .60877 .35068 L .60881 .35062 L F
.582 .939 .925 r
.60776 .3487 m .60707 .34803 L .60529 .34966 L F
.268 .362 .775 r
.60707 .34803 m .60833 .35144 L .60529 .34966 L F
.914 .956 .805 r
.60645 .34979 m .60525 .35126 L .60621 .3511 L F
.60525 .35126 m .60382 .35302 L .60621 .3511 L F
.394 .444 .794 r
.60776 .3487 m .60881 .35062 L .61078 .34841 L F
.639 .836 .976 r
.61078 .34841 m .60881 .35062 L .61263 .35007 L F
.124 .332 .799 r
.32585 .61557 m .32134 .61094 L .32346 .61244 L F
.536 .073 .102 r
.32346 .61244 m .32134 .61094 L .32001 .6126 L F
.266 .361 .775 r
.58499 .36933 m .58567 .36473 L .58382 .36551 L F
.58499 .36933 m .58716 .36743 L .58567 .36473 L F
.549 .012 0 r
.53229 .35482 m .53477 .3556 L .53733 .35514 L F
.8 .399 .291 r
.53477 .3556 m .53857 .35698 L .53733 .35514 L F
.859 .77 .763 r
.2995 .56504 m .30092 .56883 L .3019 .56629 L F
.749 .856 .929 r
.48413 .4908 m .48831 .49081 L .48658 .48923 L F
.776 .871 .918 r
.48658 .48923 m .48831 .49081 L .49128 .48807 L F
0 0 0 r
.49364 .40304 m .49532 .40196 L .49708 .4005 L F
.449 .148 .361 r
.49532 .40196 m .49895 .39852 L .49708 .4005 L F
0 .038 .594 r
.33681 .54567 m .33657 .5446 L .3338 .54467 L F
.33681 .54567 m .33863 .54756 L .33657 .5446 L F
.857 .78 .775 r
.47547 .50329 m .47365 .5044 L .47745 .50489 L F
.863 .867 .84 r
.47284 .50695 m .47745 .50489 L .47365 .5044 L F
.829 .787 .812 r
.47547 .50329 m .47745 .50489 L .48019 .50149 L F
.761 .57 .639 r
.29626 .55165 m .29929 .55541 L .30077 .55205 L F
.737 .767 .877 r
.56132 .39259 m .55731 .39205 L .56026 .38885 L F
.774 .75 .831 r
.56435 .38937 m .56132 .39259 L .56026 .38885 L F
.604 .693 .906 r
.37572 .57056 m .37147 .56908 L .37368 .56905 L F
.197 0 0 r
.37368 .56905 m .379 .57036 L .37572 .57056 L F
.657 .19 .133 r
.30355 .64341 m .30588 .64507 L .3016 .64532 L F
.484 .27 .512 r
.49974 .41361 m .49961 .4163 L .5026 .41263 L F
.525 .226 .401 r
.42161 .4742 m .42218 .47745 L .41768 .47743 L F
.492 .21 .414 r
.42161 .4742 m .42375 .47622 L .42218 .47745 L F
.42161 .4742 m .42428 .47385 L .42375 .47622 L F
.782 .319 0 r
.34223 .63201 m .34364 .63317 L .34087 .62988 L F
.128 .521 .915 r
.34678 .63481 m .34364 .63317 L .34597 .63555 L F
.863 .752 .739 r
.42257 .56524 m .42379 .56873 L .42481 .56691 L F
.506 .602 .883 r
.29651 .66431 m .2982 .66737 L .30061 .66695 L F
.758 .767 .86 r
.61672 .39175 m .61952 .39337 L .61467 .39314 L F
.819 .748 .785 r
.62135 .38985 m .61952 .39337 L .61672 .39175 L F
.807 .679 .723 r
.53436 .41565 m .53871 .4134 L .53702 .41232 L F
.53436 .41565 m .53802 .41573 L .53871 .4134 L F
.602 .893 .989 r
.48098 .47404 m .48208 .47194 L .48401 .4711 L F
.48098 .47404 m .4796 .47304 L .48208 .47194 L F
.477 .656 .939 r
.36603 .57681 m .36843 .57626 L .36413 .57476 L F
.934 .744 .266 r
.60719 .34509 m .60707 .34803 L .60776 .3487 L F
.22 .712 .921 r
.60776 .3487 m .61078 .34841 L .60707 .34803 L F
.759 .592 .67 r
.54949 .36891 m .55081 .37327 L .55224 .36966 L F
0 0 .296 r
.49611 .41023 m .49524 .40956 L .49749 .40874 L F
.539 .043 .026 r
.54531 .42227 m .54961 .4218 L .54682 .42052 L F
.49 0 0 r
.59913 .38564 m .6033 .38611 L .60166 .38638 L F
.215 0 0 r
.6033 .38611 m .60486 .38673 L .60166 .38638 L F
.6033 .38611 m .60615 .38661 L .60486 .38673 L F
.782 .74 .814 r
.37162 .58628 m .37342 .58148 L .37084 .58242 L F
.37162 .58628 m .37534 .58339 L .37342 .58148 L F
0 .116 .664 r
.31216 .66996 m .31365 .6735 L .31441 .67234 L F
.306 .719 .976 r
.31365 .6735 m .31616 .67342 L .31441 .67234 L F
.84 .905 .494 r
.54396 .43176 m .54357 .43407 L .54524 .43022 L F
.796 .819 .34 r
.54268 .43667 m .54357 .43407 L .54396 .43176 L F
0 0 0 r
.60696 .36264 m .60999 .36148 L .61142 .3608 L F
.313 .774 .638 r
.61142 .3608 m .6126 .36021 L .61374 .36102 L F
.61142 .3608 m .60999 .36148 L .6126 .36021 L F
.911 .812 .737 r
.50748 .47006 m .51021 .47099 L .51018 .46654 L F
.50748 .47006 m .50949 .4715 L .51021 .47099 L F
.811 .816 .854 r
.51018 .46654 m .51021 .47099 L .51402 .46666 L F
.167 0 0 r
.63873 .34753 m .64248 .34611 L .63998 .34671 L F
.729 .252 .115 r
.55074 .3905 m .55064 .39161 L .54682 .39072 L F
.571 .18 .262 r
.5536 .39017 m .55064 .39161 L .55074 .3905 L F
.805 .694 .743 r
.53599 .41746 m .53802 .41573 L .53436 .41565 L F
.27 .743 .94 r
.61534 .3489 m .61078 .34841 L .61263 .35007 L F
.849 .694 .69 r
.4238 .53802 m .42493 .54194 L .42591 .53899 L F
.789 .552 .578 r
.53098 .40905 m .53464 .40999 L .53226 .40644 L F
.331 .024 .285 r
.42753 .45896 m .43058 .45638 L .42831 .4575 L F
.174 0 0 r
.3798 .48257 m .38236 .48221 L .38458 .48054 L F
.02 0 0 r
.38236 .48221 m .3871 .48103 L .38458 .48054 L F
.739 .736 .848 r
.37534 .58339 m .37749 .58144 L .37342 .58148 L F
.553 .233 .38 r
.49273 .42808 m .49163 .43031 L .48883 .43023 L F
.523 .202 .364 r
.49512 .42926 m .49273 .42808 L .49472 .42582 L F
.49512 .42926 m .49163 .43031 L .49273 .42808 L F
0 0 .463 r
.6004 .34721 m .59982 .34532 L .59805 .34419 L F
.6004 .34721 m .60129 .34884 L .59982 .34532 L F
.17 0 0 r
.59698 .3503 m .60129 .34884 L .6004 .34721 L F
0 0 0 r
.58162 .38323 m .58126 .38321 L .58225 .38094 L F
.58162 .38323 m .58079 .38568 L .58126 .38321 L F
.803 .892 .908 r
.50174 .47607 m .50632 .47479 L .50434 .47328 L F
.816 .815 .849 r
.50434 .47328 m .50632 .47479 L .50949 .4715 L F
.718 .86 .44 r
.5598 .40823 m .56111 .40626 L .56059 .40587 L F
.89 .876 .816 r
.56111 .40626 m .5622 .40309 L .56059 .40587 L F
.845 .987 .715 r
.29003 .56573 m .28745 .56918 L .28813 .56737 L F
.948 .927 .749 r
.29078 .56093 m .28867 .56473 L .29003 .56573 L F
.674 .447 .569 r
.28813 .56737 m .29257 .56499 L .29003 .56573 L F
.107 0 .068 r
.312 .61686 m .30886 .6198 L .31086 .61849 L F
0 0 0 r
.31409 .61575 m .312 .61686 L .31086 .61849 L F
.179 0 0 r
.55211 .38026 m .55141 .38154 L .55455 .38017 L F
.481 .211 .427 r
.43138 .55206 m .43116 .55478 L .42822 .55526 L F
.282 .053 .378 r
.43138 .55206 m .43367 .55129 L .43116 .55478 L F
.829 .787 .812 r
.47547 .50329 m .48019 .50149 L .47831 .49986 L F
.4 0 .003 r
.63079 .3888 m .62695 .39062 L .62851 .3904 L F
0 .327 .794 r
.62851 .3904 m .63293 .39354 L .63079 .3888 L F
.884 .969 .839 r
.57346 .36543 m .57491 .36154 L .57621 .36423 L F
.57346 .36543 m .57233 .36477 L .57491 .36154 L F
.725 .95 .652 r
.61895 .34471 m .61534 .3489 L .61498 .34633 L F
.418 .072 .268 r
.52617 .35901 m .52869 .35852 L .52926 .3558 L F
.296 0 .232 r
.52926 .3558 m .53046 .35658 L .53229 .35482 L F
.52926 .3558 m .52869 .35852 L .53046 .35658 L F
0 0 0 r
.40111 .57184 m .40415 .56913 L .40621 .56855 L F
.40111 .57184 m .40167 .57233 L .40415 .56913 L F
.773 .723 .806 r
.40415 .56913 m .40167 .57233 L .40014 .56971 L F
.40415 .56913 m .40014 .56971 L .40276 .5691 L F
0 .135 .682 r
.40014 .56971 m .40276 .57225 L .40276 .5691 L F
.664 .39 .495 r
.40276 .5691 m .40114 .5703 L .40098 .56787 L F
0 0 0 r
.40029 .57248 m .40167 .57233 L .40111 .57184 L F
.39946 .57312 m .40129 .57246 L .40029 .57248 L F
.40129 .57246 m .40167 .57233 L .40029 .57248 L F
.375 .531 .884 r
.40014 .56971 m .40167 .57233 L .39946 .57312 L F
0 .135 .682 r
.40014 .56971 m .40157 .57246 L .40181 .57242 L F
.40014 .56971 m .40181 .57242 L .40132 .57086 L F
.375 .531 .884 r
.40014 .56971 m .39946 .57312 L .39666 .56784 L F
.275 .427 .833 r
.39946 .57312 m .40014 .56971 L .39616 .57137 L F
.39946 .57312 m .40227 .5738 L .40014 .56971 L F
.523 .313 .537 r
.40014 .56971 m .39616 .57137 L .39666 .56784 L F
.366 0 0 r
.3972 .56825 m .40014 .56971 L .39666 .56784 L F
.224 .182 .598 r
.3972 .56825 m .39616 .57137 L .40014 .56971 L F
.664 .39 .495 r
.40114 .5703 m .39846 .5723 L .40059 .56855 L F
.40114 .5703 m .40059 .56855 L .40098 .56787 L F
0 .135 .682 r
.40132 .57086 m .40181 .57242 L .40276 .57225 L F
.40157 .57246 m .40227 .5738 L .4027 .57244 L F
.40157 .57246 m .4027 .57244 L .40276 .57225 L F
0 0 0 r
.54524 .43022 m .54786 .42654 L .54684 .42835 L F
.54396 .43176 m .54524 .43022 L .54684 .42835 L F
.994 .844 .585 r
.51396 .41913 m .51517 .42047 L .51348 .42061 L F
.691 .876 .968 r
.51684 .4181 m .51517 .42047 L .51396 .41913 L F
.554 .676 .92 r
.51684 .4181 m .51821 .42017 L .51517 .42047 L F
.078 0 0 r
.51517 .42047 m .51665 .42062 L .51348 .42061 L F
.51517 .42047 m .51821 .42017 L .51665 .42062 L F
.528 0 0 r
.34597 .63555 m .35013 .63586 L .34678 .63481 L F
.147 0 0 r
.48423 .4085 m .48712 .40707 L .48491 .40828 L F
.886 .943 .844 r
.39295 .56892 m .39373 .5646 L .39511 .56832 L F
.39295 .56892 m .39112 .56784 L .39373 .5646 L F
.439 0 0 r
.39261 .57069 m .39295 .56892 L .39511 .56832 L F
.72 .434 .492 r
.30575 .63018 m .30388 .63219 L .30423 .63308 L F
.30575 .63018 m .30565 .62888 L .30388 .63219 L F
.30575 .63018 m .30731 .63266 L .30565 .62888 L F
.306 0 .21 r
.40347 .47389 m .40593 .47311 L .40665 .47125 L F
.324 0 .218 r
.40665 .47125 m .40593 .47311 L .40923 .47057 L F
.732 .622 .736 r
.41962 .53165 m .4243 .53166 L .42234 .52822 L F
.745 .502 .563 r
.41963 .53446 m .4243 .53166 L .41962 .53165 L F
.41963 .53446 m .42396 .53513 L .4243 .53166 L F
.594 .369 .544 r
.42396 .53513 m .42644 .53434 L .4243 .53166 L F
.847 .531 .453 r
.34082 .54172 m .34111 .54457 L .34537 .54556 L F
.664 .313 .369 r
.34049 .5479 m .34537 .54556 L .34111 .54457 L F
.34049 .5479 m .34473 .54781 L .34537 .54556 L F
.795 .452 .406 r
.34537 .54556 m .34918 .54836 L .3494 .54554 L F
.34537 .54556 m .34473 .54781 L .34918 .54836 L F
.07 0 0 r
.48712 .40707 m .49066 .4064 L .49052 .40611 L F
0 0 0 r
.49052 .40611 m .49217 .40455 L .49364 .40304 L F
.49052 .40611 m .49066 .4064 L .49217 .40455 L F
.356 .204 .533 r
.29138 .63664 m .29341 .6389 L .29419 .63628 L F
.29138 .63664 m .29155 .63949 L .29341 .6389 L F
.369 .031 .256 r
.43397 .46756 m .43297 .4695 L .43117 .46972 L F
.155 0 .071 r
.43649 .4666 m .43297 .4695 L .43397 .46756 L F
.575 .533 .771 r
.54384 .3903 m .54547 .38493 L .54234 .38571 L F
0 .477 .775 r
.53857 .35698 m .5434 .35833 L .54056 .35936 L F
.491 .351 .618 r
.5434 .35833 m .54109 .36247 L .54056 .35936 L F
.828 .791 .816 r
.33018 .67317 m .33405 .67328 L .33275 .66989 L F
.843 .744 .754 r
.33159 .67695 m .33405 .67328 L .33018 .67317 L F
.75 .778 .876 r
.33405 .67328 m .33522 .66883 L .33275 .66989 L F
.33405 .67328 m .33724 .67068 L .33522 .66883 L F
.823 .857 .873 r
.3934 .55691 m .39221 .55813 L .39097 .55762 L F
.3934 .55691 m .38944 .55808 L .38988 .5573 L F
.329 .742 .979 r
.38988 .5573 m .39481 .55795 L .3934 .55691 L F
.39034 .55736 m .39377 .55694 L .39481 .55795 L F
.38988 .5573 m .39013 .55728 L .39034 .55736 L F
.39013 .55728 m .39377 .55694 L .39034 .55736 L F
.823 .857 .873 r
.39097 .55762 m .39114 .55922 L .38944 .55808 L F
.39221 .55813 m .39114 .55922 L .39097 .55762 L F
.458 .375 .675 r
.3937 .56144 m .39156 .56281 L .39114 .55922 L F
.679 .229 0 r
.33885 .55248 m .33781 .55137 L .33565 .55088 L F
.33885 .55248 m .34017 .55452 L .33781 .55137 L F
.818 .738 .776 r
.27851 .5732 m .27773 .57483 L .27987 .57258 L F
.646 .551 .733 r
.27868 .5676 m .27987 .57258 L .28294 .56856 L F
.248 .251 .666 r
.28745 .56918 m .28989 .57146 L .28813 .56737 L F
.28745 .56918 m .28832 .57293 L .28989 .57146 L F
.795 .788 .847 r
.4184 .54864 m .42258 .54794 L .4212 .54456 L F
.051 .609 .81 r
.41781 .54857 m .41987 .54899 L .41785 .54857 L F
.41561 .54852 m .41955 .54895 L .41781 .54857 L F
.41955 .54895 m .41987 .54899 L .41781 .54857 L F
.41706 .54847 m .41785 .54857 L .41732 .54846 L F
.985 .855 .631 r
.41732 .54846 m .41796 .5493 L .4176 .54852 L F
.41732 .54846 m .4176 .54852 L .41661 .54641 L F
.378 .842 .823 r
.41766 .54853 m .41796 .5493 L .41732 .54846 L F
.41987 .54899 m .41796 .5493 L .41766 .54853 L F
.051 .609 .81 r
.41561 .54852 m .41785 .54857 L .41706 .54847 L F
.832 .851 .861 r
.41681 .54633 m .41796 .5493 L .4212 .54456 L F
.41661 .54641 m .41796 .5493 L .41681 .54633 L F
.795 .788 .847 r
.41796 .5493 m .41965 .5488 L .4184 .54864 L F
.41965 .5488 m .42258 .54794 L .4184 .54864 L F
.378 .842 .823 r
.41987 .54899 m .42258 .54794 L .41796 .5493 L F
.867 .446 .215 r
.64323 .35506 m .6401 .35179 L .64354 .35275 L F
.695 .419 0 r
.65448 .35168 m .65546 .35535 L .65481 .35286 L F
.65448 .35168 m .65546 .35535 L .65481 .35286 L F
.764 .604 .68 r
.28227 .56434 m .2875 .56797 L .28468 .56391 L F
.28227 .56434 m .28294 .56856 L .2875 .56797 L F
.567 .635 .878 r
.28468 .56391 m .2875 .56797 L .28867 .56473 L F
.912 .814 .737 r
.41992 .57116 m .42379 .56873 L .42049 .56949 L F
.41992 .57116 m .42255 .57233 L .42379 .56873 L F
.915 .863 .774 r
.35331 .56887 m .3489 .57144 L .35188 .56758 L F
.35331 .56887 m .35118 .57294 L .3489 .57144 L F
.699 .561 .695 r
.35623 .57217 m .35118 .57294 L .35331 .56887 L F
.617 .574 .783 r
.35878 .56835 m .35623 .57217 L .35331 .56887 L F
.789 .677 .74 r
.45374 .51119 m .44963 .51086 L .45209 .50723 L F
0 0 0 r
.54786 .42654 m .55108 .42364 L .54981 .42531 L F
.54684 .42835 m .54786 .42654 L .54981 .42531 L F
.408 0 0 r
.55071 .42351 m .54961 .4218 L .5485 .42235 L F
.55128 .4238 m .55095 .42342 L .55071 .42351 L F
.55095 .42342 m .54961 .4218 L .55071 .42351 L F
0 0 0 r
.54981 .42531 m .55289 .42208 L .55187 .42381 L F
.408 0 0 r
.55139 .42387 m .55131 .42377 L .55128 .4238 L F
.55131 .42377 m .54961 .4218 L .55128 .4238 L F
0 0 0 r
.54981 .42531 m .55108 .42364 L .55289 .42208 L F
0 .348 .825 r
.55016 .42199 m .55139 .42387 L .5485 .42235 L F
0 0 0 r
.55108 .42364 m .55274 .42206 L .55231 .42258 L F
.408 0 0 r
.55139 .42387 m .55289 .42208 L .54961 .4218 L F
.814 .818 .853 r
.54832 .4266 m .55016 .42199 L .54688 .42273 L F
.53 .215 .378 r
.55289 .42208 m .55381 .4206 L .54961 .4218 L F
.057 0 .029 r
.55187 .42381 m .55289 .42208 L .55509 .42082 L F
.55187 .42381 m .55289 .42208 L .55509 .42082 L F
.484 .881 .715 r
.55139 .42387 m .55187 .42381 L .55375 .42231 L F
.55139 .42387 m .55187 .42381 L .55375 .42231 L F
.814 .818 .853 r
.54832 .4266 m .55139 .42387 L .55016 .42199 L F
0 0 0 r
.55231 .42258 m .55431 .42058 L .55289 .42208 L F
.55274 .42206 m .55431 .42058 L .55231 .42258 L F
.675 .77 .922 r
.55375 .42231 m .55139 .42387 L .55016 .42199 L F
.55016 .42199 m .55139 .42387 L .55375 .42231 L F
.964 .937 .636 r
.55372 .41667 m .55381 .4206 L .55289 .42208 L F
.591 .855 .51 r
.55289 .42208 m .55567 .41881 L .55509 .42082 L F
.764 .847 .914 r
.55567 .41881 m .55381 .4206 L .55372 .41667 L F
.964 .937 .636 r
.55372 .41667 m .55289 .42208 L .55509 .42082 L F
.675 .77 .922 r
.55375 .42231 m .55016 .42199 L .55217 .42083 L F
.55016 .42199 m .55375 .42231 L .55227 .42367 L F
.55016 .42199 m .55227 .42367 L .55217 .42083 L F
.772 .524 .559 r
.55217 .42083 m .55227 .42367 L .54925 .42378 L F
.54907 .42346 m .54925 .42378 L .54867 .4238 L F
.55217 .42083 m .54925 .42378 L .54907 .42346 L F
.814 .818 .853 r
.54851 .4255 m .54688 .42273 L .54855 .42256 L F
.5489 .42316 m .54855 .42256 L .549 .42252 L F
.54851 .4255 m .54855 .42256 L .5489 .42316 L F
.54832 .4266 m .54825 .42642 L .54851 .4255 L F
.54825 .42642 m .54688 .42273 L .54851 .4255 L F
.772 .524 .559 r
.54942 .42219 m .54867 .4238 L .54938 .42221 L F
.55217 .42083 m .54907 .42346 L .54942 .42219 L F
.54907 .42346 m .54867 .4238 L .54942 .42219 L F
.852 .987 .714 r
.54652 .42729 m .54832 .4266 L .54871 .42426 L F
.54795 .42454 m .54885 .42342 L .54834 .42379 L F
.54652 .42729 m .54871 .42426 L .54795 .42454 L F
.565 .566 .814 r
.54906 .42598 m .54652 .42729 L .54834 .42379 L F
.517 .028 .035 r
.54836 .4238 m .54867 .4238 L .54838 .42376 L F
.852 .987 .714 r
.54795 .42454 m .54871 .42426 L .54885 .42342 L F
.517 .028 .035 r
.54865 .42384 m .54867 .4238 L .54836 .4238 L F
0 0 0 r
.549 .42252 m .54516 .42335 L .54838 .42376 L F
.852 .987 .714 r
.54834 .42379 m .54838 .42376 L .549 .42252 L F
.54838 .42376 m .54885 .42342 L .549 .42252 L F
0 0 0 r
.549 .42252 m .54838 .42376 L .54867 .4238 L F
.79 .663 .723 r
.54867 .4238 m .55227 .42367 L .55038 .4245 L F
.54867 .4238 m .55038 .4245 L .54906 .42598 L F
.565 .566 .814 r
.54906 .42598 m .549 .42252 L .54867 .4238 L F
.21 0 0 r
.5485 .42235 m .54961 .4218 L .54531 .42227 L F
0 .348 .825 r
.55016 .42199 m .5485 .42235 L .54688 .42273 L F
.675 .897 .976 r
.54938 .42221 m .54873 .42366 L .54947 .42097 L F
.54873 .42366 m .54867 .4238 L .54871 .42368 L F
.565 .566 .814 r
.54901 .42291 m .54834 .42379 L .549 .42252 L F
.54902 .42347 m .54874 .4236 L .54901 .42291 L F
.54874 .4236 m .54834 .42379 L .54901 .42291 L F
.54851 .42382 m .54834 .42379 L .54902 .42347 L F
.54906 .42598 m .54834 .42379 L .54902 .4239 L F
.517 .028 .035 r
.54705 .42618 m .54865 .42384 L .54836 .4238 L F
.54639 .42519 m .54838 .42376 L .54833 .42375 L F
.5457 .42416 m .54833 .42375 L .54516 .42335 L F
.54639 .42519 m .54833 .42375 L .5457 .42416 L F
.046 0 0 r
.54531 .42227 m .54303 .42304 L .54171 .4247 L F
.54531 .42227 m .54171 .4247 L .54427 .42373 L F
.136 0 0 r
.54688 .42273 m .54531 .42227 L .54427 .42373 L F
0 0 0 r
.54427 .42373 m .54171 .4247 L .5403 .42551 L F
.364 .821 .717 r
.54245 .42433 m .54427 .42373 L .5403 .42551 L F
.261 .754 .674 r
.54516 .42335 m .54427 .42373 L .54245 .42433 L F
0 0 0 r
.54516 .42335 m .54245 .42433 L .54222 .42456 L F
.54388 .42409 m .54222 .42456 L .54099 .42577 L F
.54516 .42335 m .54222 .42456 L .54388 .42409 L F
.261 .754 .674 r
.54516 .42335 m .54688 .42273 L .54427 .42373 L F
0 0 0 r
.549 .42252 m .54688 .42273 L .54516 .42335 L F
.517 .028 .035 r
.54705 .42618 m .54838 .42376 L .54639 .42519 L F
.54705 .42618 m .54516 .42335 L .546 .4237 L F
0 0 0 r
.54516 .42335 m .54099 .42577 L .546 .4237 L F
.76 .314 0 r
.54419 .42235 m .5458 .42355 L .543 .42343 L F
.5458 .42355 m .546 .4237 L .54544 .42365 L F
.5458 .42355 m .54544 .42365 L .543 .42343 L F
.771 .853 .912 r
.543 .42343 m .546 .4237 L .54442 .42435 L F
.54187 .42475 m .54442 .42435 L .54099 .42577 L F
.543 .42343 m .54442 .42435 L .54187 .42475 L F
.782 .872 .44 r
.54947 .42097 m .54871 .42368 L .54705 .42618 L F
.54871 .42368 m .54867 .4238 L .54865 .42384 L F
.54871 .42368 m .54865 .42384 L .54705 .42618 L F
.675 .897 .976 r
.54873 .42366 m .54871 .42368 L .54947 .42097 L F
.565 .566 .814 r
.54902 .4239 m .54851 .42382 L .54902 .42347 L F
.826 .904 .894 r
.47878 .43284 m .48219 .43071 L .48127 .42889 L F
.433 .804 .994 r
.48219 .43071 m .48248 .42909 L .48127 .42889 L F
.48219 .43071 m .48491 .43026 L .48248 .42909 L F
.515 0 0 r
.6576 .36136 m .65863 .36257 L .66098 .36266 L F
.202 .73 .799 r
.66098 .36266 m .6638 .36197 L .66382 .36203 L F
.66098 .36266 m .65863 .36257 L .66329 .36203 L F
.66098 .36266 m .66329 .36203 L .66355 .36203 L F
.173 .708 .813 r
.65829 .36224 m .6638 .36197 L .65863 .36257 L F
.65829 .36224 m .66166 .36184 L .6638 .36197 L F
.855 .875 .854 r
.66032 .36718 m .66162 .362 L .6606 .36383 L F
.66162 .362 m .66166 .36184 L .66157 .362 L F
.66162 .362 m .66157 .362 L .6606 .36383 L F
.202 .73 .799 r
.66355 .36203 m .66329 .36203 L .6638 .36197 L F
.069 0 0 r
.30886 .6198 m .30493 .62315 L .30704 .62155 L F
0 0 0 r
.31086 .61849 m .30886 .6198 L .30704 .62155 L F
.355 .244 .588 r
.41466 .57221 m .41714 .57447 L .41705 .57151 L F
0 0 0 r
.35176 .55586 m .35072 .55813 L .35303 .554 L F
0 .087 .636 r
.36998 .54596 m .37031 .54504 L .36829 .54417 L F
.032 0 0 r
.37324 .54511 m .3721 .54624 L .36998 .54596 L F
.648 .101 0 r
.37324 .54511 m .37537 .54704 L .3721 .54624 L F
.514 .807 .999 r
.37201 .54602 m .37537 .54704 L .37334 .5457 L F
.37075 .54633 m .37188 .5465 L .37201 .54602 L F
.37188 .5465 m .37537 .54704 L .37201 .54602 L F
0 .087 .636 r
.36998 .54596 m .37196 .54622 L .37031 .54504 L F
.37196 .54622 m .3721 .54624 L .37197 .54616 L F
.37196 .54622 m .37197 .54616 L .37031 .54504 L F
.593 .808 .982 r
.38406 .58468 m .38551 .58641 L .38841 .58532 L F
.89 .624 .53 r
.41995 .5745 m .42255 .57233 L .41992 .57116 L F
.731 .981 .762 r
.60696 .36264 m .60481 .36547 L .60773 .3642 L F
.60696 .36264 m .6045 .36518 L .60481 .36547 L F
0 0 0 r
.49364 .40304 m .49217 .40455 L .49532 .40196 L F
.455 .631 .93 r
.6142 .38132 m .6129 .38372 L .61159 .38133 L F
.712 .945 .956 r
.61553 .38223 m .6129 .38372 L .6142 .38132 L F
.819 .748 .785 r
.62135 .38985 m .61672 .39175 L .61773 .38942 L F
.469 .127 .303 r
.40883 .56794 m .41147 .56764 L .41123 .56545 L F
.808 .481 .435 r
.41147 .56764 m .40759 .56736 L .40717 .56433 L F
.91 .54 .096 r
.41032 .56689 m .41171 .56967 L .41147 .56764 L F
.41171 .56967 m .41198 .57023 L .41147 .56764 L F
.469 .127 .303 r
.41123 .56545 m .41147 .56764 L .41227 .56437 L F
.532 .385 .627 r
.41227 .56437 m .41638 .56577 L .41501 .56125 L F
.772 .646 .724 r
.41147 .56764 m .41638 .56577 L .41227 .56437 L F
.658 .614 .794 r
.62091 .38227 m .62002 .3834 L .61833 .37908 L F
.701 .834 .947 r
.37985 .5811 m .38169 .58268 L .38458 .58117 L F
.812 .463 0 r
.63388 .39185 m .63282 .39392 L .63427 .39183 L F
.779 .414 0 r
.63079 .3888 m .63293 .39354 L .63188 .39193 L F
.694 .971 .76 r
.63028 .39564 m .63293 .39354 L .62963 .39656 L F
.63203 .39379 m .63293 .39354 L .63028 .39564 L F
.985 .893 .564 r
.63188 .39193 m .63293 .39354 L .63147 .39395 L F
.812 .463 0 r
.63188 .39193 m .63293 .39354 L .63282 .39392 L F
.63188 .39193 m .63252 .39328 L .63388 .39185 L F
.63252 .39328 m .63282 .39392 L .63388 .39185 L F
.694 .971 .76 r
.63147 .39395 m .63203 .39379 L .63028 .39564 L F
.504 .713 .965 r
.62963 .39656 m .63279 .39635 L .63147 .39395 L F
0 .404 .688 r
.5353 .4261 m .53488 .426 L .53375 .42501 L F
.5353 .4261 m .53731 .42668 L .53488 .426 L F
.436 0 .034 r
.35623 .57217 m .35371 .57424 L .35118 .57294 L F
.608 .038 0 r
.35371 .57424 m .3489 .57144 L .35118 .57294 L F
.613 .561 .772 r
.645 .33568 m .642 .33698 L .64188 .33672 L F
.64399 .33563 m .64188 .33672 L .64131 .33549 L F
.645 .33568 m .64188 .33672 L .64399 .33563 L F
0 0 0 r
.64399 .33563 m .64411 .33557 L .6442 .33549 L F
.64399 .33563 m .6442 .33549 L .64131 .33549 L F
.613 .561 .772 r
.64612 .3352 m .64491 .33528 L .6442 .33549 L F
.64491 .33528 m .64131 .33549 L .6442 .33549 L F
.64612 .3352 m .645 .33568 L .64394 .33563 L F
.134 0 0 r
.64411 .33557 m .64491 .33528 L .6442 .33549 L F
.613 .561 .772 r
.64491 .33528 m .64394 .33563 L .64131 .33549 L F
.64612 .3352 m .64394 .33563 L .64491 .33528 L F
.134 0 0 r
.64223 .33727 m .6465 .33481 L .64491 .33528 L F
.64223 .33727 m .64491 .33528 L .64411 .33557 L F
.6465 .33481 m .64675 .33467 L .6442 .33549 L F
0 0 0 r
.64091 .33772 m .64223 .33727 L .64411 .33557 L F
.64091 .33772 m .64411 .33557 L .64399 .33563 L F
.64091 .33772 m .64399 .33563 L .64131 .33549 L F
.479 .881 .725 r
.50937 .39354 m .51001 .39268 L .5113 .39172 L F
.50937 .39354 m .50749 .39428 L .51001 .39268 L F
0 .354 .672 r
.3123 .63211 m .31166 .63187 L .31256 .62867 L F
.148 0 0 r
.37147 .56908 m .36994 .57059 L .3676 .57064 L F
.749 .926 .57 r
.36981 .57144 m .36994 .57059 L .37147 .56908 L F
.137 0 0 r
.37368 .56905 m .36994 .57059 L .37147 .56908 L F
.36994 .57059 m .37368 .56905 L .37147 .56908 L F
.37368 .56905 m .37251 .5702 L .36994 .57059 L F
.36994 .57059 m .37251 .5702 L .37368 .56905 L F
.94 .929 .765 r
.37251 .5702 m .37004 .56997 L .36994 .57059 L F
.37004 .56997 m .36812 .56979 L .36994 .57059 L F
.749 .926 .57 r
.3697 .57159 m .36994 .57059 L .36981 .57144 L F
.132 .488 .902 r
.3695 .56625 m .37368 .56905 L .37147 .56908 L F
0 .136 .593 r
.64675 .33467 m .65119 .33803 L .64857 .33548 L F
0 0 0 r
.52412 .3844 m .52155 .38617 L .52523 .38194 L F
.02 0 0 r
.52683 .38189 m .52412 .3844 L .52523 .38194 L F
.676 .923 .973 r
.37731 .56268 m .37855 .56026 L .37935 .56169 L F
.37731 .56268 m .37533 .56186 L .37855 .56026 L F
.685 .19 .065 r
.37731 .56268 m .37531 .56385 L .37533 .56186 L F
.37731 .56268 m .37909 .56477 L .37531 .56385 L F
.778 .761 .838 r
.56602 .39663 m .56984 .39732 L .56909 .39514 L F
.562 .824 .995 r
.56984 .39732 m .57125 .39539 L .56909 .39514 L F
.56984 .39732 m .57299 .39667 L .57125 .39539 L F
0 0 0 r
.58943 .38978 m .58957 .39016 L .59062 .38756 L F
.58943 .38978 m .58896 .39247 L .58957 .39016 L F
.316 0 .15 r
.42753 .47151 m .42693 .47317 L .42428 .47385 L F
.299 0 .114 r
.43117 .46972 m .42693 .47317 L .42753 .47151 L F
.969 .652 .344 r
.29235 .56784 m .29432 .572 L .29397 .56899 L F
.725 .666 .791 r
.40796 .49729 m .40949 .50139 L .41289 .4984 L F
.862 .812 .799 r
.4605 .49407 m .45607 .49633 L .45881 .4925 L F
.4605 .49407 m .45785 .49771 L .45607 .49633 L F
.869 .86 .83 r
.46328 .49055 m .4605 .49407 L .45881 .4925 L F
0 0 0 r
.34327 .49896 m .34152 .50064 L .34443 .49723 L F
.097 0 .301 r
.34327 .49896 m .34193 .49799 L .34443 .49723 L F
.34327 .49896 m .34152 .50064 L .34193 .49799 L F
.34193 .49799 m .34327 .49896 L .34443 .49723 L F
.34193 .49799 m .34152 .50064 L .34327 .49896 L F
0 0 .342 r
.58295 .37339 m .58199 .37292 L .58357 .37073 L F
.58295 .37339 m .58253 .37566 L .58199 .37292 L F
.787 .852 .9 r
.4989 .45934 m .4947 .45984 L .49775 .45648 L F
.824 .808 .836 r
.4997 .45813 m .4989 .45934 L .49775 .45648 L F
.72 .598 .719 r
.43747 .54036 m .43711 .54309 L .43942 .54106 L F
.43747 .54036 m .43479 .5438 L .43711 .54309 L F
.655 .529 .699 r
.27868 .5676 m .28294 .56856 L .28227 .56434 L F
0 .424 .849 r
.51553 .43665 m .51518 .43723 L .51176 .43445 L F
.308 0 0 r
.51805 .43801 m .51788 .43775 L .51518 .43723 L F
.005 .469 .868 r
.51805 .43801 m .51518 .43723 L .51553 .43665 L F
.862 .865 .841 r
.66521 .36232 m .66537 .3663 L .6681 .36294 L F
.891 .984 .806 r
.63775 .3914 m .64111 .38901 L .6405 .38799 L F
.803 .925 .917 r
.64111 .38901 m .64354 .3849 L .6405 .38799 L F
.64111 .38901 m .64478 .38625 L .64354 .3849 L F
.617 .574 .783 r
.35878 .56835 m .35782 .57205 L .35623 .57217 L F
.913 .82 .742 r
.35782 .57205 m .35371 .57424 L .35623 .57217 L F
.496 .15 .31 r
.38975 .48047 m .39263 .48035 L .39393 .47713 L F
.517 .171 .32 r
.39393 .47713 m .3963 .47872 L .39673 .47739 L F
.39393 .47713 m .39263 .48035 L .3963 .47872 L F
.092 0 0 r
.62613 .33442 m .62884 .33449 L .62878 .33433 L F
.618 .677 .884 r
.63545 .33541 m .62878 .33433 L .63392 .33436 L F
.081 0 0 r
.62878 .33433 m .62884 .33449 L .63392 .33436 L F
.548 .913 .733 r
.48401 .4711 m .48546 .46961 L .48635 .46952 L F
.48401 .4711 m .48208 .47194 L .48546 .46961 L F
0 .43 .702 r
.39156 .56281 m .38875 .56206 L .38812 .56192 L F
.832 .546 .506 r
.3937 .56144 m .38875 .56206 L .39156 .56281 L F
.3937 .56144 m .39002 .56382 L .38875 .56206 L F
0 .027 .598 r
.38875 .56206 m .39002 .56382 L .38988 .56231 L F
.38885 .56208 m .38988 .56231 L .38982 .56161 L F
.873 .722 .691 r
.39002 .56382 m .38676 .56507 L .38982 .56161 L F
0 0 0 r
.38982 .56161 m .38822 .56356 L .3907 .56118 L F
.38982 .56161 m .3907 .56118 L .39146 .56046 L F
0 .027 .598 r
.38875 .56206 m .38885 .56208 L .38982 .56161 L F
0 .43 .702 r
.38812 .56192 m .38875 .56206 L .38659 .56153 L F
.391 .241 .555 r
.43015 .54602 m .43235 .54496 L .43219 .54164 L F
.691 .919 .97 r
.42732 .54555 m .43235 .54496 L .43015 .54602 L F
.937 .94 .769 r
.53036 .44869 m .52914 .45368 L .5319 .45012 L F
.854 .891 .863 r
.53036 .44869 m .5319 .45012 L .53474 .44696 L F
.208 0 0 r
.3739 .4846 m .37731 .48357 L .37582 .48414 L F
.793 .768 .831 r
.3798 .48257 m .38049 .48602 L .37582 .48414 L F
.3798 .48257 m .37582 .48414 L .37844 .48323 L F
.208 0 0 r
.37731 .48357 m .37844 .48323 L .37582 .48414 L F
.359 .725 .988 r
.37582 .48414 m .38049 .48602 L .37474 .48456 L F
.37582 .48414 m .37474 .48456 L .37316 .48416 L F
.983 .698 .361 r
.42163 .55528 m .42187 .55838 L .42034 .55742 L F
.449 .146 .359 r
.46111 .44653 m .4604 .44963 L .45748 .45024 L F
.38 .087 .336 r
.46293 .44876 m .46111 .44653 L .46343 .44545 L F
.46293 .44876 m .4604 .44963 L .46111 .44653 L F
.622 .538 .738 r
.28637 .55723 m .29078 .56093 L .29258 .55915 L F
.879 .804 .771 r
.29258 .55915 m .29078 .56093 L .29328 .55752 L F
.26 0 0 r
.29078 .56093 m .29594 .56171 L .29328 .55752 L F
.29078 .56093 m .29514 .56164 L .29594 .56171 L F
.665 .645 .82 r
.29328 .55752 m .29594 .56171 L .29825 .55837 L F
.84 .925 .888 r
.29594 .56171 m .29514 .56164 L .29825 .55837 L F
.869 .86 .83 r
.46328 .49055 m .45881 .4925 L .4617 .48933 L F
.813 .924 .91 r
.46328 .49055 m .46485 .4866 L .46618 .48766 L F
.46328 .49055 m .4617 .48933 L .46485 .4866 L F
.643 .926 .974 r
.33062 .61176 m .32834 .61339 L .32821 .6127 L F
.834 .999 .803 r
.52793 .45262 m .52527 .45675 L .52914 .45368 L F
.937 .94 .769 r
.53036 .44869 m .52793 .45262 L .52914 .45368 L F
.365 .05 .292 r
.42162 .46351 m .42426 .46277 L .42495 .45979 L F
.319 0 .251 r
.42426 .46277 m .42753 .45896 L .42495 .45979 L F
.573 .806 .987 r
.38111 .57119 m .38543 .5719 L .38286 .57271 L F
.816 .815 .849 r
.50434 .47328 m .50949 .4715 L .50748 .47006 L F
.169 0 0 r
.62494 .34347 m .62063 .34449 L .62137 .34482 L F
.62494 .34347 m .62342 .34428 L .62063 .34449 L F
.62768 .34368 m .62342 .34428 L .62494 .34347 L F
.193 .614 .946 r
.61032 .38005 m .60813 .38069 L .60743 .37846 L F
.61032 .38005 m .61159 .38133 L .60813 .38069 L F
.685 .77 .916 r
.28916 .55655 m .28429 .55677 L .28637 .55723 L F
.718 .365 .377 r
.28303 .57338 m .28696 .57475 L .28832 .57293 L F
.768 .489 .512 r
.29033 .57367 m .28696 .57475 L .28832 .57293 L F
0 0 0 r
.28832 .57293 m .28696 .57475 L .28989 .57146 L F
.526 .77 .986 r
.54807 .38119 m .54904 .38281 L .54513 .382 L F
.603 .814 .981 r
.55141 .38154 m .54904 .38281 L .54807 .38119 L F
.598 .349 .512 r
.41733 .53449 m .41963 .53446 L .41962 .53165 L F
.982 .695 .386 r
.41801 .53049 m .41963 .53446 L .41962 .53165 L F
.849 .773 .777 r
.45785 .49771 m .4532 .49999 L .45607 .49633 L F
.45785 .49771 m .45534 .50124 L .4532 .49999 L F
.97 .738 .531 r
.4238 .53802 m .42376 .54232 L .42493 .54194 L F
.916 .601 .434 r
.42318 .54375 m .42493 .54194 L .42376 .54232 L F
.42318 .54375 m .42521 .54453 L .42493 .54194 L F
.941 .807 .684 r
.50256 .44657 m .49881 .44934 L .50128 .44722 L F
.50256 .44657 m .50095 .45055 L .49881 .44934 L F
0 0 0 r
.50256 .44657 m .50438 .44509 L .50582 .44378 L F
.398 .044 .244 r
.50128 .44722 m .50438 .44509 L .50256 .44657 L F
0 0 .501 r
.28341 .64966 m .28464 .65291 L .28486 .65174 L F
0 .044 .613 r
.28486 .65174 m .28464 .65291 L .28673 .65539 L F
.738 .965 .937 r
.52681 .43249 m .52521 .43378 L .52585 .43136 L F
.851 .739 .739 r
.48935 .48647 m .49373 .48428 L .492 .48281 L F
.48935 .48647 m .49128 .48807 L .49373 .48428 L F
.792 .849 .893 r
.492 .48281 m .49373 .48428 L .49702 .48109 L F
0 0 .47 r
.58857 .39837 m .5893 .39932 L .59109 .40142 L F
.58 .81 .417 r
.48423 .4085 m .48111 .41286 L .48369 .41182 L F
.147 0 0 r
.48423 .4085 m .48637 .40866 L .48712 .40707 L F
.251 0 .269 r
.48423 .4085 m .48612 .41086 L .48637 .40866 L F
.48423 .4085 m .48369 .41182 L .48612 .41086 L F
.928 .909 .781 r
.34448 .55057 m .34379 .5553 L .3465 .55185 L F
.34448 .55057 m .3422 .55425 L .34379 .5553 L F
.299 0 .114 r
.43117 .46972 m .42957 .4725 L .42693 .47317 L F
.268 0 .076 r
.43297 .4695 m .42957 .4725 L .43117 .46972 L F
.899 .647 .547 r
.44294 .52821 m .44471 .53211 L .44289 .53078 L F
.361 .241 .578 r
.55643 .39977 m .55682 .40298 L .56017 .40107 L F
0 0 0 r
.55682 .40298 m .55758 .40037 L .56017 .40107 L F
.55682 .40298 m .55614 .40408 L .55925 .40089 L F
.55921 .40085 m .55925 .40089 L .55983 .4003 L F
.55682 .40298 m .55925 .40089 L .55921 .40085 L F
.274 0 0 r
.55741 .40011 m .55905 .40068 L .55758 .40037 L F
.55905 .40068 m .56017 .40107 L .55916 .40079 L F
.55905 .40068 m .55916 .40079 L .55758 .40037 L F
0 0 0 r
.55682 .40298 m .55983 .4003 L .55758 .40037 L F
.057 0 0 r
.55758 .40037 m .55983 .4003 L .55768 .40051 L F
.55758 .40037 m .55768 .40051 L .5549 .40078 L F
.274 0 0 r
.55643 .39977 m .55741 .40011 L .55758 .40037 L F
.807 .73 .779 r
.34473 .54781 m .3465 .55185 L .34918 .54836 L F
.212 .724 .885 r
.62137 .34482 m .62063 .34449 L .61895 .34471 L F
.467 .2 .426 r
.41204 .48097 m .41207 .48356 L .40913 .4837 L F
.655 .347 .438 r
.41204 .48097 m .4151 .48359 L .41207 .48356 L F
.547 .374 .598 r
.41472 .48039 m .4151 .48359 L .41204 .48097 L F
0 0 0 r
.51178 .38967 m .51293 .38751 L .51389 .38563 L F
0 0 .439 r
.5113 .39172 m .51293 .38751 L .51178 .38967 L F
.63 .549 .745 r
.53117 .41381 m .53167 .41644 L .53414 .41298 L F
0 0 0 r
.44908 .44063 m .44611 .4437 L .44814 .4421 L F
.15 0 .006 r
.44814 .4421 m .45154 .43963 L .44908 .44063 L F
0 0 0 r
.30493 .62315 m .3027 .62662 L .30549 .62818 L F
.184 .111 .534 r
.30493 .62315 m .30698 .62404 L .30704 .62155 L F
.30493 .62315 m .30549 .62818 L .30698 .62404 L F
.864 .425 .155 r
.63392 .33436 m .6355 .33657 L .6369 .33613 L F
.478 0 0 r
.6355 .33657 m .64091 .33772 L .6369 .33613 L F
.962 .761 .587 r
.34448 .55057 m .3465 .55185 L .34473 .54781 L F
.98 .847 .456 r
.60116 .39888 m .60195 .40024 L .60054 .40151 L F
.867 .974 .855 r
.60503 .39667 m .60195 .40024 L .60116 .39888 L F
.209 0 0 r
.60054 .40151 m .60195 .40024 L .60417 .40047 L F
.639 .25 0 r
.54891 .36601 m .54814 .36463 L .54664 .36178 L F
.988 .843 .467 r
.54891 .36601 m .54751 .36754 L .54814 .36463 L F
.429 .759 .996 r
.55163 .3629 m .55081 .3615 L .55199 .36298 L F
.54664 .36178 m .55081 .3615 L .55163 .3629 L F
.977 .921 .626 r
.54998 .35948 m .54985 .35985 L .55081 .3615 L F
0 .37 .8 r
.54509 .358 m .55081 .3615 L .54664 .36178 L F
.711 .234 .115 r
.55081 .3615 m .54826 .36194 L .54814 .36463 L F
0 .37 .8 r
.54757 .35952 m .5499 .36042 L .55081 .3615 L F
.711 .234 .115 r
.55081 .3615 m .54876 .36287 L .54826 .36194 L F
.072 .437 .875 r
.548 .35787 m .5498 .36019 L .54509 .358 L F
.5498 .36019 m .5499 .36042 L .54509 .358 L F
.22 .043 .416 r
.54952 .36014 m .54876 .36287 L .54826 .36194 L F
0 .37 .8 r
.54904 .35999 m .5499 .36042 L .54757 .35952 L F
.22 .043 .416 r
.54972 .36021 m .54876 .36287 L .54952 .36014 L F
.708 .262 0 r
.54723 .36091 m .54876 .36287 L .54826 .36194 L F
.54826 .36194 m .54876 .36287 L .54723 .36091 L F
.935 .819 .705 r
.54723 .36091 m .54876 .36287 L .54976 .3601 L F
.977 .921 .626 r
.54987 .35989 m .54977 .36028 L .55081 .3615 L F
.931 .846 .738 r
.54998 .35948 m .55002 .36048 L .5498 .36019 L F
.54998 .35948 m .5498 .36019 L .54973 .36009 L F
.977 .921 .626 r
.54985 .35985 m .54972 .36021 L .54977 .36028 L F
.54985 .35985 m .54977 .36028 L .54987 .35989 L F
.22 .043 .416 r
.54998 .35948 m .54972 .36021 L .54968 .3602 L F
.54998 .35948 m .54968 .3602 L .54952 .36014 L F
.931 .846 .738 r
.54998 .35948 m .54973 .36009 L .54809 .35787 L F
.935 .819 .705 r
.54948 .35974 m .54976 .3601 L .54998 .35948 L F
.54723 .36091 m .54976 .3601 L .54948 .35974 L F
.072 .437 .875 r
.54809 .35787 m .54932 .35954 L .548 .35787 L F
.54932 .35954 m .5498 .36019 L .548 .35787 L F
.5498 .36019 m .55002 .36048 L .5499 .36042 L F
.977 .921 .626 r
.54972 .36021 m .54876 .36287 L .55046 .36173 L F
.5499 .36042 m .55046 .36173 L .55081 .3615 L F
.54972 .36021 m .55046 .36173 L .5499 .36042 L F
0 .37 .8 r
.54509 .358 m .54904 .35999 L .54757 .35952 L F
.5499 .36042 m .55002 .36048 L .55081 .3615 L F
.863 .955 .868 r
.55081 .3615 m .54891 .36601 L .55199 .36298 L F
.55081 .3615 m .54814 .36463 L .54891 .36601 L F
.003 0 0 r
.55053 .36634 m .54891 .36601 L .54814 .36463 L F
.55053 .36634 m .54751 .36754 L .54891 .36601 L F
.674 .759 .915 r
.63748 .33824 m .63851 .34149 L .64124 .33924 L F
.57 .365 .563 r
.53117 .41381 m .53464 .40999 L .53098 .40905 L F
.53117 .41381 m .53414 .41298 L .53464 .40999 L F
.562 .357 .561 r
.53414 .41298 m .53702 .41232 L .53464 .40999 L F
.302 0 .091 r
.4207 .4652 m .41892 .46419 L .41817 .46608 L F
.4207 .4652 m .42162 .46351 L .41892 .46419 L F
.22 0 .029 r
.40221 .47615 m .40593 .47311 L .40347 .47389 L F
.897 .769 .713 r
.44294 .52821 m .43964 .52742 L .44139 .52378 L F
.859 .689 .67 r
.44289 .53078 m .43964 .52742 L .44294 .52821 L F
.767 .919 .545 r
.59753 .38735 m .5966 .38982 L .59913 .38564 L F
.718 .834 .387 r
.59551 .39191 m .5966 .38982 L .59753 .38735 L F
.314 .073 .379 r
.47313 .4373 m .47513 .43877 L .4727 .43985 L F
.47313 .4373 m .47568 .43606 L .47513 .43877 L F
.839 .896 .88 r
.64652 .37934 m .64663 .38199 L .6498 .37896 L F
.499 0 0 r
.32775 .67689 m .33159 .67695 L .33018 .67317 L F
.298 0 .171 r
.45465 .45069 m .45439 .45248 L .45143 .45328 L F
.48 .081 .207 r
.45465 .45069 m .45699 .45219 L .45439 .45248 L F
.453 .105 .284 r
.45748 .45024 m .45699 .45219 L .45465 .45069 L F
.834 .999 .803 r
.52793 .45262 m .52498 .4559 L .52527 .45675 L F
0 .292 .79 r
.3027 .62662 m .30565 .62888 L .30549 .62818 L F
.683 .292 .3 r
.33633 .54169 m .33868 .54341 L .34082 .54172 L F
.831 .518 .46 r
.33868 .54341 m .34111 .54457 L .34082 .54172 L F
.513 .598 .876 r
.32462 .67638 m .32545 .67285 L .32451 .67547 L F
.32462 .67638 m .32775 .67689 L .32545 .67285 L F
.571 .18 .262 r
.5536 .39017 m .55332 .39217 L .55064 .39161 L F
.881 .493 .294 r
.55557 .39293 m .55332 .39217 L .5536 .39017 L F
0 0 0 r
.59805 .34419 m .59843 .34338 L .59932 .34138 L F
0 .256 .756 r
.59805 .34419 m .59982 .34532 L .59843 .34338 L F
.143 .402 .85 r
.32781 .61826 m .33009 .62136 L .32793 .62016 L F
.972 .734 .519 r
.51627 .39569 m .51613 .40046 L .51752 .39977 L F
.502 0 0 r
.51613 .40046 m .51599 .40108 L .51752 .39977 L F
.551 .509 .763 r
.51752 .39977 m .51943 .39499 L .51627 .39569 L F
.51752 .39977 m .52022 .39902 L .51943 .39499 L F
0 0 0 r
.51752 .39977 m .51722 .40013 L .52022 .39902 L F
.51752 .39977 m .51599 .40108 L .51722 .40013 L F
.502 0 0 r
.51613 .40046 m .51599 .40108 L .51752 .39977 L F
.756 .681 .778 r
.2914 .57535 m .29587 .57605 L .29432 .572 L F
.759 .682 .777 r
.29432 .572 m .29587 .57605 L .29876 .57276 L F
0 0 .145 r
.36069 .56783 m .3619 .56683 L .36009 .56805 L F
.739 .923 .568 r
.3619 .56683 m .3609 .56915 L .36321 .56575 L F
.359 .608 .944 r
.36143 .56791 m .36415 .56908 L .3609 .56915 L F
.3619 .56683 m .36306 .56799 L .36143 .56791 L F
.36306 .56799 m .36415 .56908 L .36143 .56791 L F
0 0 0 r
.36415 .56908 m .36193 .57525 L .36413 .57476 L F
.36415 .56908 m .3624 .57467 L .36193 .57525 L F
.888 .732 .682 r
.36719 .57147 m .36498 .5718 L .3676 .57064 L F
.623 .592 .798 r
.36667 .57106 m .36498 .5718 L .36719 .57147 L F
.773 .451 .442 r
.36667 .57105 m .36498 .5718 L .36667 .57106 L F
.623 .592 .798 r
.36415 .56908 m .36498 .5718 L .36667 .57106 L F
.773 .451 .442 r
.36667 .57106 m .36498 .5718 L .36719 .5717 L F
.623 .592 .798 r
.36415 .56908 m .36667 .57106 L .36567 .5712 L F
.36667 .57106 m .36719 .57147 L .36697 .57143 L F
.36667 .57106 m .36697 .57143 L .36567 .5712 L F
.773 .451 .442 r
.3676 .57064 m .36753 .57121 L .36912 .57148 L F
.36954 .57151 m .36912 .57148 L .3697 .57159 L F
.3676 .57064 m .36912 .57148 L .36954 .57151 L F
.251 .007 .335 r
.3676 .57064 m .36994 .57059 L .36751 .57137 L F
.3676 .57064 m .36751 .57137 L .36719 .57147 L F
.556 .932 .899 r
.36726 .57135 m .36719 .57147 L .36751 .57137 L F
.773 .451 .442 r
.36768 .57123 m .36719 .5717 L .3697 .57159 L F
.36667 .57105 m .36697 .57143 L .36768 .57123 L F
.556 .932 .899 r
.36726 .57135 m .36697 .57143 L .36719 .57147 L F
.773 .451 .442 r
.36697 .57143 m .36719 .5717 L .36768 .57123 L F
.3676 .57064 m .36667 .57105 L .36753 .57121 L F
.784 .74 .812 r
.3695 .56625 m .3676 .57064 L .36456 .56721 L F
.556 .932 .899 r
.36812 .56979 m .36567 .5712 L .36697 .57143 L F
.36812 .56979 m .36697 .57143 L .36726 .57135 L F
.36812 .56979 m .36726 .57135 L .36994 .57059 L F
.36726 .57135 m .36751 .57137 L .36994 .57059 L F
.623 .592 .798 r
.36415 .56908 m .36413 .57476 L .36498 .5718 L F
.82 .638 .656 r
.35852 .57312 m .3624 .57467 L .36415 .56908 L F
.35852 .57312 m .36415 .56908 L .36117 .57321 L F
.013 0 0 r
.36348 .57192 m .36415 .56908 L .36567 .5712 L F
.36348 .57192 m .36117 .57321 L .36415 .56908 L F
.703 .515 .631 r
.36413 .57476 m .3697 .57159 L .36498 .5718 L F
.796 .992 .754 r
.36567 .5712 m .36348 .57192 L .36467 .5707 L F
.337 0 0 r
.3653 .5681 m .36486 .56851 L .36618 .56915 L F
.36486 .56851 m .36275 .57045 L .3656 .56937 L F
.36486 .56851 m .3656 .56937 L .36618 .56915 L F
.36275 .57045 m .36273 .57067 L .36563 .5694 L F
.3656 .56937 m .36563 .5694 L .36618 .56915 L F
.36275 .57045 m .36563 .5694 L .3656 .56937 L F
.36275 .57045 m .36231 .57085 L .36273 .57067 L F
.89 .732 .68 r
.36456 .56721 m .36415 .56908 L .3619 .56683 L F
.337 0 0 r
.36405 .56804 m .36231 .57085 L .3653 .5681 L F
.778 .322 .163 r
.3645 .5672 m .36231 .57085 L .36456 .56721 L F
.3619 .56683 m .36198 .56767 L .3645 .5672 L F
.36198 .56767 m .36231 .57085 L .3645 .5672 L F
0 0 .145 r
.36258 .56716 m .36231 .57085 L .3619 .56683 L F
.36258 .56716 m .3619 .56683 L .36069 .56783 L F
.548 .837 .504 r
.36026 .56799 m .36048 .56751 L .36258 .56716 L F
.764 .468 .485 r
.35522 .56826 m .35637 .57089 L .35986 .56826 L F
.539 .017 0 r
.36073 .56766 m .35986 .56826 L .35902 .56826 L F
.35742 .56802 m .35726 .56888 L .35522 .56826 L F
.36045 .56769 m .35726 .56888 L .35742 .56802 L F
.36073 .56766 m .36034 .56779 L .36045 .56769 L F
.36034 .56779 m .35726 .56888 L .36045 .56769 L F
.764 .468 .485 r
.35522 .56826 m .35989 .56826 L .36009 .56805 L F
.548 .837 .504 r
.36009 .56805 m .35997 .56817 L .35999 .56815 L F
.507 0 0 r
.35762 .56694 m .35799 .56711 L .36113 .56698 L F
.301 .682 .976 r
.36059 .56755 m .36073 .56766 L .35708 .56696 L F
.539 .017 0 r
.36052 .56762 m .35522 .56826 L .35708 .56696 L F
.36073 .56766 m .36045 .56769 L .36052 .56762 L F
.36045 .56769 m .35522 .56826 L .36052 .56762 L F
.764 .468 .485 r
.35637 .57089 m .35671 .57165 L .35986 .56826 L F
.548 .837 .504 r
.35989 .56826 m .35854 .56964 L .35857 .5696 L F
.507 0 0 r
.35799 .56711 m .36009 .56805 L .36058 .56754 L F
.51 .865 .621 r
.36048 .56751 m .35986 .56826 L .35997 .56817 L F
.501 0 0 r
.35708 .56696 m .35522 .56826 L .36009 .56805 L F
.548 .837 .504 r
.35989 .56825 m .35857 .5696 L .36048 .56751 L F
.764 .468 .485 r
.35986 .56826 m .35671 .57165 L .35989 .56826 L F
.548 .837 .504 r
.35989 .56826 m .35857 .5696 L .35989 .56825 L F
.507 0 0 r
.35799 .56711 m .36058 .56754 L .3611 .56701 L F
.35799 .56711 m .3611 .56701 L .36112 .56698 L F
.35762 .56694 m .36167 .56698 L .36189 .56683 L F
.77 .611 .681 r
.35741 .56358 m .3619 .56683 L .36267 .56412 L F
.35741 .56358 m .35708 .56696 L .3619 .56683 L F
.515 .798 .997 r
.36154 .56544 m .36073 .56766 L .35879 .56607 L F
.51 .865 .621 r
.36048 .56751 m .36071 .56765 L .36154 .56544 L F
.36071 .56765 m .36073 .56766 L .36077 .56755 L F
.36071 .56765 m .36077 .56755 L .36154 .56544 L F
.507 0 0 r
.36112 .56698 m .3611 .56701 L .36113 .56698 L F
.35708 .56696 m .35758 .56714 L .35762 .56694 L F
.301 .682 .976 r
.35879 .56607 m .36059 .56755 L .35708 .56696 L F
.548 .837 .504 r
.36009 .56805 m .35999 .56815 L .36048 .56751 L F
.507 0 0 r
.36113 .56698 m .36009 .56805 L .36167 .56698 L F
.36189 .56683 m .36167 .56698 L .3619 .56683 L F
.548 .837 .504 r
.36009 .56805 m .36011 .56801 L .36018 .568 L F
.51 .865 .621 r
.36069 .56763 m .35986 .56826 L .36073 .56766 L F
.548 .837 .504 r
.36017 .56802 m .36018 .568 L .36026 .56799 L F
.36009 .56805 m .36018 .568 L .36017 .56802 L F
.51 .865 .621 r
.36048 .56751 m .36017 .56801 L .36069 .56763 L F
.548 .837 .504 r
.36018 .568 m .36048 .56751 L .36026 .56799 L F
.36011 .56801 m .36048 .56751 L .36018 .568 L F
.51 .865 .621 r
.35999 .56815 m .36015 .56804 L .36016 .56803 L F
.36017 .56801 m .36016 .56803 L .36069 .56763 L F
.35999 .56815 m .36016 .56803 L .36017 .56801 L F
.36048 .56751 m .35999 .56815 L .36017 .56801 L F
.35999 .56815 m .35997 .56817 L .36015 .56804 L F
.548 .837 .504 r
.35997 .56817 m .35989 .56826 L .36048 .56751 L F
.35989 .56826 m .35671 .57165 L .35854 .56964 L F
.539 .017 0 r
.35986 .56826 m .35843 .56924 L .35902 .56826 L F
.507 0 0 r
.35758 .56714 m .36009 .56805 L .35762 .56694 L F
.51 .865 .621 r
.36048 .56751 m .35843 .56924 L .35986 .56826 L F
.539 .017 0 r
.35902 .56826 m .35843 .56924 L .35726 .56888 L F
.815 .602 .614 r
.36618 .56915 m .36231 .57085 L .36258 .56716 L F
0 0 .474 r
.36587 .56968 m .36549 .56854 L .36564 .56923 L F
.796 .992 .754 r
.36593 .57015 m .36586 .57018 L .36618 .56915 L F
.36567 .5712 m .36618 .56915 L .36812 .56979 L F
.36586 .57018 m .36467 .5707 L .36573 .56961 L F
.36586 .57018 m .36573 .56961 L .36618 .56915 L F
.36567 .5712 m .36467 .5707 L .36593 .57015 L F
.745 .586 .678 r
.36667 .57127 m .36348 .57192 L .36618 .56915 L F
0 0 .474 r
.36667 .57127 m .3661 .56994 L .36587 .56968 L F
.3661 .56994 m .36549 .56854 L .36587 .56968 L F
.3661 .56994 m .36672 .5704 L .36549 .56854 L F
.36667 .57127 m .36671 .57065 L .3661 .56994 L F
.36671 .57065 m .36672 .5704 L .3661 .56994 L F
.337 0 0 r
.36456 .56721 m .36405 .56804 L .3653 .5681 L F
.197 0 0 r
.37368 .56905 m .37685 .56988 L .379 .57036 L F
.37 .5 .859 r
.3753 .56669 m .37685 .56988 L .37368 .56905 L F
.033 .036 .528 r
.37368 .56905 m .37434 .5689 L .3753 .56669 L F
.132 .488 .902 r
.3695 .56625 m .37434 .5689 L .37368 .56905 L F
0 .313 .729 r
.3716 .56704 m .37434 .5689 L .37073 .56692 L F
.3716 .56704 m .37073 .56692 L .3695 .56625 L F
.732 .855 .939 r
.3753 .56669 m .3716 .56704 L .37347 .56552 L F
0 0 0 r
.37347 .56552 m .37185 .56707 L .3716 .56704 L F
.732 .855 .939 r
.3753 .56669 m .37434 .5689 L .3716 .56704 L F
.874 .753 .726 r
.3716 .56704 m .37251 .5702 L .37012 .56873 L F
0 0 0 r
.37185 .56707 m .37012 .56873 L .3716 .56704 L F
0 .313 .729 r
.3716 .56704 m .3695 .56625 L .36944 .56685 L F
.654 .594 .776 r
.3685 .56704 m .37012 .56873 L .37035 .56666 L F
0 .313 .729 r
.3716 .56704 m .36944 .56685 L .36944 .56692 L F
.654 .594 .776 r
.37035 .56666 m .37032 .56693 L .3716 .56704 L F
.37032 .56693 m .37012 .56873 L .3716 .56704 L F
.784 .74 .812 r
.36946 .56665 m .36456 .56721 L .36896 .56695 L F
.36946 .56665 m .36896 .56695 L .36944 .56685 L F
.3695 .56625 m .36755 .56663 L .36946 .56665 L F
.36755 .56663 m .36456 .56721 L .36946 .56665 L F
.654 .594 .776 r
.36724 .56573 m .36896 .56695 L .37035 .56666 L F
.784 .74 .812 r
.36944 .56685 m .36896 .56695 L .36944 .56692 L F
.364 .585 .928 r
.36724 .56573 m .36944 .56692 L .36896 .56695 L F
.36724 .56573 m .36896 .56695 L .36456 .56721 L F
.654 .594 .776 r
.36724 .56573 m .3685 .56704 L .36896 .56695 L F
.069 .582 .883 r
.3692 .56601 m .37073 .56667 L .36724 .56573 L F
.37073 .56667 m .3716 .56704 L .37035 .56666 L F
.37073 .56667 m .37035 .56666 L .36724 .56573 L F
.337 0 0 r
.36456 .56721 m .36812 .56979 L .36724 .56573 L F
.36456 .56721 m .36618 .56915 L .36812 .56979 L F
.815 .602 .614 r
.36618 .56915 m .36258 .56716 L .36398 .56547 L F
.36517 .56573 m .36398 .56547 L .3648 .56448 L F
.36618 .56915 m .36398 .56547 L .36517 .56573 L F
.654 .594 .776 r
.36724 .56573 m .36812 .56979 L .37012 .56873 L F
.815 .602 .614 r
.36618 .56915 m .3648 .56448 L .36467 .5673 L F
.751 .392 .374 r
.36805 .56634 m .36939 .56807 L .36467 .5673 L F
.762 .351 .27 r
.36962 .56644 m .36944 .56692 L .36724 .56573 L F
.3716 .56704 m .36964 .56693 L .36962 .56644 L F
.36964 .56693 m .36944 .56692 L .36962 .56644 L F
.883 .596 .081 r
.36966 .56736 m .36939 .56807 L .3692 .56601 L F
.37012 .56873 m .3697 .56835 L .36966 .56736 L F
.3697 .56835 m .36939 .56807 L .36966 .56736 L F
.751 .392 .374 r
.3692 .56601 m .36926 .5666 L .36805 .56634 L F
.36926 .5666 m .36939 .56807 L .36805 .56634 L F
0 0 .474 r
.36564 .56923 m .36549 .56854 L .36467 .5673 L F
.703 .515 .631 r
.36413 .57476 m .36843 .57626 L .3697 .57159 L F
.711 .583 .71 r
.36667 .57127 m .36456 .57457 L .36348 .57192 L F
.722 .859 .946 r
.36667 .57127 m .36348 .57192 L .36195 .57075 L F
.633 .106 0 r
.36403 .57098 m .36452 .57278 L .36667 .57127 L F
.36272 .57084 m .3632 .57135 L .36403 .57098 L F
.3632 .57135 m .36452 .57278 L .36403 .57098 L F
.36195 .57075 m .36267 .57132 L .36272 .57084 L F
.36267 .57132 m .36452 .57278 L .36272 .57084 L F
.739 .923 .568 r
.3619 .56683 m .36321 .56575 L .36346 .56537 L F
.652 .766 .933 r
.6681 .36294 m .66382 .36203 L .66677 .36137 L F
.862 .865 .841 r
.66521 .36232 m .6681 .36294 L .66677 .36137 L F
.694 .457 .56 r
.53352 .36561 m .5306 .36237 L .53399 .3622 L F
.53352 .36561 m .53161 .36629 L .5306 .36237 L F
0 0 0 r
.44611 .4437 m .44225 .44666 L .445 .4457 L F
.139 0 0 r
.44611 .4437 m .44755 .44476 L .44814 .4421 L F
.44611 .4437 m .445 .4457 L .44755 .44476 L F
.591 .716 .93 r
.64124 .33924 m .64539 .34174 L .64386 .33865 L F
.683 .72 .878 r
.64386 .33865 m .64539 .34174 L .64868 .3395 L F
.26 0 0 r
.58609 .35033 m .58814 .34849 L .58613 .34905 L F
.58609 .35033 m .59068 .35008 L .58814 .34849 L F
.794 .691 .751 r
.37474 .4874 m .37065 .4868 L .37316 .48416 L F
.704 .243 .155 r
.37474 .4874 m .37285 .48913 L .37065 .4868 L F
.426 0 0 r
.37749 .48827 m .37474 .4874 L .37734 .48772 L F
.37749 .48827 m .37285 .48913 L .37474 .4874 L F
.522 0 0 r
.64143 .34724 m .64546 .34766 L .64248 .34611 L F
.826 .904 .894 r
.47878 .43284 m .48127 .42889 L .47803 .43237 L F
.461 .684 .962 r
.32048 .67481 m .32357 .67467 L .31871 .6725 L F
.32048 .67481 m .32451 .67547 L .32357 .67467 L F
.677 .883 .974 r
.6194 .37634 m .62209 .37852 L .61833 .37908 L F
.759 .606 .688 r
.62209 .37852 m .62256 .38024 L .61833 .37908 L F
.726 .897 .956 r
.62442 .37566 m .62209 .37852 L .6194 .37634 L F
.602 .511 .724 r
.62531 .37908 m .62209 .37852 L .62442 .37566 L F
.62531 .37908 m .62256 .38024 L .62209 .37852 L F
.775 .535 .571 r
.29433 .55168 m .29929 .55541 L .29626 .55165 L F
.517 .861 .6 r
.59982 .34108 m .60118 .33971 L .60252 .3405 L F
.59982 .34108 m .59932 .34138 L .60118 .33971 L F
.658 .614 .794 r
.62091 .38227 m .61833 .37908 L .62256 .38024 L F
.282 .78 .753 r
.56313 .38012 m .56402 .37971 L .56163 .38052 L F
.56572 .37942 m .56402 .37971 L .56313 .38012 L F
.55 .528 .784 r
.56645 .37747 m .56402 .37971 L .56574 .37941 L F
.704 .935 .623 r
.56779 .37658 m .56645 .37747 L .56574 .37941 L F
.685 .758 .907 r
.56779 .37658 m .56574 .37941 L .56958 .37753 L F
.633 .412 .565 r
.56574 .37941 m .56954 .38138 L .56958 .37753 L F
.55 .528 .784 r
.56645 .37747 m .56745 .3789 L .56402 .37971 L F
.56645 .37747 m .56745 .3789 L .56402 .37971 L F
.613 .443 .629 r
.56594 .37795 m .5651 .37921 L .56402 .37971 L F
.282 .78 .753 r
.56574 .37941 m .56402 .37971 L .56572 .37942 L F
.733 .493 .565 r
.56338 .38158 m .56576 .38216 L .56574 .37941 L F
.734 .466 .524 r
.56338 .38158 m .56571 .38496 L .56576 .38216 L F
.842 .461 .328 r
.56174 .38343 m .56571 .38496 L .56338 .38158 L F
.613 .443 .629 r
.5651 .37921 m .56296 .38245 L .56402 .37971 L F
.907 .568 .389 r
.56163 .38052 m .56174 .38343 L .56338 .38158 L F
.483 .479 .777 r
.56163 .38052 m .56402 .37971 L .56382 .37794 L F
.996 .764 .42 r
.56402 .37971 m .56296 .38245 L .56306 .37987 L F
.483 .479 .777 r
.56163 .38052 m .56382 .37794 L .56033 .37778 L F
.996 .764 .42 r
.56402 .37971 m .56306 .37987 L .56311 .37855 L F
.633 .412 .565 r
.56574 .37941 m .56576 .38216 L .56954 .38138 L F
.345 0 0 r
.28833 .65948 m .29275 .65988 L .29075 .66011 L F
.535 .03 0 r
.29275 .65988 m .29303 .66029 L .29075 .66011 L F
.29275 .65988 m .29496 .66217 L .29303 .66029 L F
.854 .907 .87 r
.52335 .41508 m .52466 .41661 L .52214 .41822 L F
.738 .534 .617 r
.52466 .41661 m .52481 .42016 L .52214 .41822 L F
.808 .905 .908 r
.52628 .41137 m .52499 .41335 L .52483 .40999 L F
.52483 .40999 m .52499 .41335 L .52628 .41137 L F
.809 .824 .862 r
.52466 .41661 m .52628 .41137 L .52335 .41508 L F
.52466 .41661 m .52777 .41354 L .52628 .41137 L F
.227 .639 .957 r
.52531 .41543 m .52466 .41661 L .52335 .41508 L F
.439 .224 .488 r
.52777 .41354 m .52698 .41676 L .52466 .41661 L F
.227 .639 .957 r
.52531 .41543 m .52698 .41676 L .52466 .41661 L F
.63 .45 .62 r
.52815 .41891 m .52466 .41661 L .52698 .41676 L F
.52815 .41891 m .52481 .42016 L .52466 .41661 L F
0 0 .283 r
.3697 .57159 m .37069 .57386 L .36994 .57059 L F
.3697 .57159 m .36843 .57626 L .37069 .57386 L F
.45 .825 .578 r
.54075 .42403 m .53731 .42668 L .53979 .42552 L F
.095 0 0 r
.54303 .42304 m .54075 .42403 L .53979 .42552 L F
.652 .846 .975 r
.48733 .42869 m .48491 .43026 L .48883 .43023 L F
.48733 .42869 m .48491 .43026 L .48883 .43023 L F
.296 0 0 r
.48883 .43023 m .48988 .4313 L .48733 .42869 L F
.48883 .43023 m .49163 .43031 L .48988 .4313 L F
.85 .997 .776 r
.63398 .33775 m .63167 .34224 L .63459 .3392 L F
.63398 .33775 m .63174 .34029 L .63167 .34224 L F
.553 .393 .618 r
.28429 .55677 m .2849 .55951 L .28637 .55723 L F
0 0 0 r
.39711 .49176 m .39674 .4908 L .39978 .49088 L F
.39711 .49176 m .39553 .49333 L .39674 .4908 L F
.791 .681 .743 r
.2968 .63519 m .30391 .63372 L .29899 .63238 L F
.30391 .63372 m .3041 .63368 L .30394 .63364 L F
.30391 .63372 m .30394 .63364 L .29899 .63238 L F
.641 .265 .315 r
.30075 .63762 m .3034 .63451 L .2968 .63519 L F
.3034 .63451 m .3041 .63368 L .30273 .63396 L F
.3034 .63451 m .30273 .63396 L .2968 .63519 L F
.846 .957 .614 r
.30269 .63506 m .3041 .63368 L .30075 .63762 L F
.682 .18 .042 r
.30533 .6375 m .30604 .63666 L .30269 .63506 L F
.30604 .63666 m .30686 .6357 L .3044 .63532 L F
.30604 .63666 m .3044 .63532 L .30269 .63506 L F
.771 .356 .263 r
.29899 .63238 m .3041 .63368 L .30269 .63506 L F
.957 .921 .568 r
.30269 .63506 m .30402 .63335 L .30388 .63219 L F
.30402 .63335 m .30423 .63308 L .30415 .63289 L F
.30402 .63335 m .30415 .63289 L .30388 .63219 L F
.8 .423 .342 r
.30269 .63506 m .30686 .6357 L .30423 .63308 L F
.011 0 0 r
.48637 .40866 m .48924 .4074 L .48712 .40707 L F
.244 0 0 r
.48712 .40707 m .48924 .4074 L .49066 .4064 L F
.775 .535 .571 r
.29433 .55168 m .29411 .55503 L .29929 .55541 L F
.896 .817 .762 r
.45534 .50124 m .45116 .50356 L .4532 .49999 L F
.45534 .50124 m .45317 .50489 L .45116 .50356 L F
.179 0 .27 r
.47281 .42288 m .47534 .42228 L .47558 .41944 L F
.002 0 0 r
.47281 .42288 m .47409 .42374 L .47534 .42228 L F
.47281 .42288 m .47194 .42496 L .47409 .42374 L F
.467 .705 .972 r
.3206 .61817 m .32248 .62013 L .32323 .6178 L F
.397 .692 .979 r
.29108 .65321 m .2943 .6538 L .29227 .65202 L F
.038 .106 .606 r
.29309 .65463 m .29108 .65321 L .29227 .65202 L F
.864 .549 .453 r
.42188 .52353 m .42196 .52382 L .42214 .52099 L F
.747 .641 .743 r
.52777 .41354 m .53117 .41381 L .53098 .40905 L F
.278 .019 .33 r
.52172 .36942 m .52414 .37029 L .52248 .36893 L F
.52172 .36942 m .52112 .37174 L .52414 .37029 L F
.982 .91 .627 r
.39038 .58121 m .39136 .57942 L .38938 .58064 L F
.806 .79 .837 r
.39345 .57772 m .39136 .57942 L .39419 .57576 L F
.565 .903 .668 r
.38938 .58064 m .39136 .57942 L .39345 .57772 L F
.179 0 0 r
.32035 .62428 m .3197 .62333 L .31752 .62268 L F
.565 .903 .668 r
.38938 .58064 m .39345 .57772 L .39205 .58013 L F
0 0 0 r
.39414 .5764 m .39345 .57772 L .39419 .57576 L F
.63 .797 .36 r
.39414 .5764 m .39205 .58013 L .39345 .57772 L F
.75 .877 .937 r
.58944 .37123 m .58972 .37339 L .59156 .37197 L F
.876 .913 .51 r
.58972 .37339 m .58852 .37572 L .58893 .37384 L F
.589 .251 .363 r
.41167 .48575 m .40913 .4837 L .41207 .48356 L F
.41167 .48575 m .40795 .48659 L .40913 .4837 L F
.07 0 .14 r
.4784 .41622 m .48074 .4153 L .48111 .41286 L F
.276 0 .192 r
.48111 .41286 m .48329 .41453 L .48369 .41182 L F
.48111 .41286 m .48074 .4153 L .48329 .41453 L F
.854 .891 .863 r
.53036 .44869 m .53474 .44696 L .53313 .44557 L F
.83 .887 .883 r
.53313 .44557 m .53474 .44696 L .53791 .44385 L F
.636 .881 .536 r
.52412 .3844 m .52086 .38856 L .52155 .38617 L F
.657 .901 .981 r
.32666 .62277 m .32216 .62319 L .32553 .62246 L F
.922 .976 .74 r
.3278 .61793 m .32666 .62277 L .32553 .62246 L F
.3278 .61793 m .32666 .62277 L .32553 .62246 L F
.956 .934 .604 r
.32448 .6153 m .32519 .61601 L .32323 .6178 L F
.32448 .6153 m .32519 .61601 L .32323 .6178 L F
.929 .898 .775 r
.53869 .43876 m .53791 .44385 L .53983 .43972 L F
.857 .878 .853 r
.53983 .43972 m .54115 .43509 L .53869 .43876 L F
.53983 .43972 m .54268 .43667 L .54115 .43509 L F
.869 .987 .834 r
.4323 .54145 m .43524 .53847 L .43219 .54164 L F
.647 .177 .123 r
.43219 .54164 m .43085 .54381 L .4323 .54145 L F
.578 .638 .875 r
.43442 .54543 m .43486 .54446 L .43496 .54555 L F
.43235 .54496 m .43463 .54451 L .43442 .54543 L F
.43463 .54451 m .43486 .54446 L .43442 .54543 L F
.968 .757 .565 r
.43463 .54451 m .43479 .5438 L .43219 .54164 L F
.43463 .54451 m .43219 .54164 L .43235 .54496 L F
.578 .638 .875 r
.43235 .54496 m .43479 .5438 L .43486 .54446 L F
.968 .757 .565 r
.43504 .54499 m .43479 .5438 L .43463 .54451 L F
.43504 .54499 m .43463 .54451 L .43235 .54496 L F
.647 .177 .123 r
.43219 .54164 m .43479 .5438 L .43085 .54381 L F
.869 .987 .834 r
.4323 .54145 m .43393 .5378 L .43524 .53847 L F
.757 .945 .942 r
.4354 .53578 m .43792 .53599 L .43524 .53847 L F
.841 .989 .859 r
.43393 .5378 m .4354 .53578 L .43524 .53847 L F
.58 .355 .539 r
.54109 .36247 m .54147 .36561 L .53785 .36578 L F
.491 .351 .618 r
.5434 .35833 m .54359 .36196 L .54109 .36247 L F
.275 .142 .512 r
.54329 .36395 m .54109 .36247 L .54359 .36196 L F
.54329 .36395 m .54147 .36561 L .54109 .36247 L F
.913 .82 .742 r
.35782 .57205 m .35623 .57508 L .35371 .57424 L F
.705 .68 .824 r
.51075 .43409 m .50713 .43534 L .50972 .43536 L F
.51075 .43409 m .50686 .43319 L .50713 .43534 L F
.148 0 0 r
.51176 .43445 m .51075 .43409 L .50972 .43536 L F
.208 .168 .591 r
.58331 .36243 m .58559 .36061 L .58484 .35784 L F
.662 .566 .735 r
.58148 .36376 m .58559 .36061 L .58331 .36243 L F
.048 0 0 r
.46669 .4293 m .46444 .43043 L .46331 .43217 L F
.041 0 0 r
.60615 .38661 m .60731 .38715 L .60486 .38673 L F
.60615 .38661 m .60872 .38578 L .60731 .38715 L F
.268 0 .137 r
.40542 .48729 m .40246 .4892 L .40289 .4882 L F
.791 .84 .889 r
.51388 .46356 m .51018 .46654 L .51402 .46666 L F
.86 .887 .854 r
.51388 .46356 m .51402 .46666 L .5169 .46335 L F
.665 .645 .82 r
.29328 .55752 m .29929 .55541 L .29411 .55503 L F
.29328 .55752 m .29825 .55837 L .29929 .55541 L F
.862 .966 .864 r
.61833 .37908 m .61553 .38223 L .6142 .38132 L F
.913 .834 .755 r
.4172 .54519 m .41561 .54852 L .41456 .54459 L F
.006 0 0 r
.60073 .38612 m .59913 .38564 L .60166 .38638 L F
.60073 .38612 m .59753 .38735 L .59913 .38564 L F
.562 .081 .072 r
.38159 .48752 m .37969 .4893 L .37734 .48772 L F
.68 .225 .165 r
.3841 .48979 m .37969 .4893 L .38159 .48752 L F
.593 .276 .402 r
.38426 .48748 m .3841 .48979 L .38159 .48752 L F
0 0 .315 r
.59949 .35867 m .60054 .36081 L .60062 .36098 L F
.707 .94 .635 r
.60094 .35616 m .59949 .35867 L .60241 .35526 L F
.011 .485 .871 r
.60124 .36019 m .59949 .35867 L .60094 .35616 L F
.60124 .36019 m .60054 .36081 L .59949 .35867 L F
.839 .896 .88 r
.64652 .37934 m .6498 .37896 L .64878 .37774 L F
.842 .972 .879 r
.6498 .37896 m .65202 .37484 L .64878 .37774 L F
.6498 .37896 m .65298 .37588 L .65202 .37484 L F
0 .047 .605 r
.60435 .37317 m .603 .37256 L .60185 .37102 L F
.60435 .37317 m .60537 .37517 L .603 .37256 L F
0 0 .541 r
.603 .37256 m .60537 .37517 L .60617 .37641 L F
.031 0 .286 r
.50861 .40618 m .51028 .40492 L .51058 .40258 L F
.476 .459 .76 r
.50861 .40618 m .51116 .40839 L .51028 .40492 L F
.352 .232 .574 r
.5226 .40091 m .52022 .39902 L .52361 .39958 L F
.5226 .40091 m .52361 .39958 L .52447 .39972 L F
.884 .972 .661 r
.52497 .39695 m .5226 .40091 L .52447 .39972 L F
0 0 0 r
.52497 .39695 m .52412 .39882 L .5226 .40091 L F
.821 .715 .749 r
.52153 .39703 m .5226 .40091 L .52497 .39695 L F
.177 .291 .743 r
.52153 .39703 m .52412 .39882 L .5226 .40091 L F
.377 .716 .988 r
.52155 .40229 m .5226 .40091 L .52412 .39882 L F
.52153 .40232 m .5226 .40091 L .52155 .40229 L F
.796 .819 .34 r
.54268 .43667 m .54396 .43176 L .54115 .43509 L F
0 0 0 r
.4784 .41622 m .47558 .41944 L .47822 .41862 L F
.034 0 .18 r
.4784 .41622 m .48004 .4173 L .48074 .4153 L F
.4784 .41622 m .47822 .41862 L .48004 .4173 L F
.376 0 0 r
.38829 .48789 m .3841 .48979 L .38426 .48748 L F
.38829 .48789 m .38664 .48971 L .3841 .48979 L F
.553 .08 .085 r
.39098 .48949 m .38664 .48971 L .38829 .48789 L F
.94 .841 .718 r
.44363 .52011 m .44317 .51676 L .4435 .51788 L F
.905 .94 .576 r
.4435 .51788 m .44497 .51295 L .44707 .51449 L F
.4435 .51788 m .44317 .51676 L .44497 .51295 L F
.528 .83 .999 r
.60252 .3405 m .60532 .33972 L .60683 .34095 L F
.492 .8 .999 r
.60532 .33972 m .60956 .34041 L .60683 .34095 L F
.047 .443 .875 r
.60274 .36148 m .60062 .36098 L .60054 .36081 L F
.60274 .36148 m .60401 .36304 L .60062 .36098 L F
.768 .489 .512 r
.29033 .57367 m .2914 .57535 L .28696 .57475 L F
.387 0 0 r
.63282 .39392 m .63293 .39354 L .63147 .39395 L F
.921 .677 .553 r
.34582 .65245 m .34621 .64974 L .34394 .64872 L F
.422 .69 .975 r
.35841 .55331 m .35749 .55533 L .35604 .55355 L F
0 0 .462 r
.35838 .55616 m .35749 .55533 L .35841 .55331 L F
.859 .474 .315 r
.35749 .55533 m .36104 .56083 L .35986 .55859 L F
0 0 .462 r
.35838 .55616 m .36104 .56083 L .35749 .55533 L F
.747 .804 .898 r
.40468 .54964 m .40581 .55167 L .40214 .55106 L F
.823 .527 .489 r
.40214 .55106 m .40581 .55167 L .40536 .55428 L F
.517 .687 .944 r
.40752 .5494 m .40581 .55167 L .40468 .54964 L F
0 0 .146 r
.40536 .55428 m .40581 .55167 L .40752 .5494 L F
.849 .666 .654 r
.36193 .57525 m .36254 .57831 L .35762 .57752 L F
.826 .565 .014 r
.36199 .57627 m .36193 .57525 L .3624 .57467 L F
.36199 .57627 m .36254 .57831 L .36193 .57525 L F
0 .385 .781 r
.37939 .57001 m .379 .57036 L .37685 .56988 L F
.37939 .57001 m .38111 .57119 L .379 .57036 L F
.706 .168 0 r
.53487 .42676 m .53731 .42668 L .5353 .4261 L F
.454 .885 .851 r
.53979 .42552 m .53731 .42668 L .53487 .42676 L F
.717 .963 .942 r
.6238 .33649 m .61932 .33784 L .62183 .33644 L F
0 0 0 r
.62183 .33644 m .62613 .33442 L .6238 .33649 L F
.744 .414 .423 r
.36254 .57831 m .35741 .58102 L .35762 .57752 L F
.36254 .57831 m .36167 .58182 L .35741 .58102 L F
.982 .699 .331 r
.36494 .57986 m .36488 .57626 L .36254 .57831 L F
.031 .252 .752 r
.36199 .57627 m .36494 .57986 L .36254 .57831 L F
.618 .2 0 r
.60537 .37517 m .60743 .37846 L .60617 .37641 L F
.589 .356 .531 r
.41768 .47743 m .41764 .48035 L .41472 .48039 L F
.55 .336 .543 r
.41768 .47743 m .42062 .47897 L .41764 .48035 L F
.41768 .47743 m .42218 .47745 L .42062 .47897 L F
.689 .974 .915 r
.60587 .35301 m .60382 .35302 L .60241 .35526 L F
.684 .934 .636 r
.60382 .35302 m .60094 .35616 L .60241 .35526 L F
.762 .27 .06 r
.37131 .57757 m .37383 .57774 L .37477 .57906 L F
.184 .479 .895 r
.30061 .66695 m .30497 .67054 L .30318 .66731 L F
.534 .663 .92 r
.30497 .67054 m .30652 .66773 L .30318 .66731 L F
.30497 .67054 m .30765 .67022 L .30652 .66773 L F
.17 0 0 r
.59698 .3503 m .59989 .34993 L .60129 .34884 L F
.361 .483 .847 r
.60129 .34884 m .60381 .34723 L .59982 .34532 L F
.395 .061 .277 r
.59989 .34993 m .60381 .34723 L .60129 .34884 L F
.326 .793 .687 r
.60788 .39941 m .60865 .39914 L .61135 .3979 L F
0 .356 .823 r
.33446 .62242 m .33353 .62302 L .33152 .62209 L F
.564 .171 .256 r
.33681 .62476 m .33619 .62325 L .33353 .62302 L F
0 .356 .823 r
.33446 .62242 m .33681 .62476 L .33353 .62302 L F
.611 .431 .614 r
.41501 .56125 m .41638 .56577 L .41845 .5644 L F
.02 0 0 r
.38236 .48221 m .38511 .48182 L .3871 .48103 L F
.35 0 0 r
.38511 .48182 m .38975 .48047 L .3871 .48103 L F
.188 0 .272 r
.47558 .41944 m .47754 .42097 L .47822 .41862 L F
.47558 .41944 m .47534 .42228 L .47754 .42097 L F
.867 .974 .855 r
.60503 .39667 m .60116 .39888 L .60275 .39729 L F
.673 .95 .7 r
.60699 .39464 m .60503 .39667 L .60603 .3949 L F
.656 .971 .839 r
.60603 .3949 m .60503 .39667 L .60275 .39729 L F
.859 .478 .325 r
.65546 .35535 m .65566 .35757 L .65912 .35847 L F
.97 .654 .302 r
.65566 .35757 m .6576 .36136 L .65912 .35847 L F
.711 .645 .781 r
.29514 .56164 m .29991 .56196 L .29825 .55837 L F
.712 .522 .63 r
.29492 .56393 m .29991 .56196 L .29514 .56164 L F
.29492 .56393 m .2995 .56504 L .29991 .56196 L F
.71 .772 .9 r
.33522 .66883 m .33724 .67068 L .33938 .66914 L F
0 0 0 r
.50251 .39632 m .50084 .39729 L .50508 .39539 L F
0 0 .081 r
.54547 .38493 m .54603 .38984 L .54582 .388 L F
.534 0 0 r
.54682 .39072 m .54495 .39053 L .54603 .38984 L F
.766 .763 .849 r
.41456 .54459 m .41561 .54852 L .41135 .54751 L F
.753 .437 .449 r
.41561 .54852 m .41132 .55066 L .41135 .54751 L F
.41561 .54852 m .4155 .55087 L .41132 .55066 L F
.051 .609 .81 r
.41561 .54852 m .41732 .54846 L .4155 .55087 L F
.78 .42 0 r
.36267 .56412 m .36346 .56537 L .36163 .56124 L F
.352 .059 .32 r
.42693 .47317 m .42375 .47622 L .42428 .47385 L F
.767 .675 .762 r
.42146 .53751 m .4238 .53802 L .42396 .53513 L F
.85 .631 .605 r
.41936 .54025 m .4238 .53802 L .42146 .53751 L F
.41936 .54025 m .42376 .54232 L .4238 .53802 L F
.674 .595 .759 r
.4238 .53802 m .42644 .53434 L .42396 .53513 L F
.891 .887 .821 r
.56043 .40094 m .5622 .40309 L .56391 .4002 L F
.919 .961 .644 r
.56038 .40445 m .5622 .40309 L .56043 .40094 L F
.56038 .40445 m .56059 .40587 L .5622 .40309 L F
.126 0 0 r
.61854 .39511 m .62014 .39549 L .61694 .39638 L F
0 0 0 r
.62292 .39375 m .62144 .39541 L .62425 .39208 L F
.126 0 0 r
.61964 .39522 m .62144 .39541 L .62014 .39549 L F
.608 .949 .792 r
.62014 .39549 m .62144 .39541 L .62292 .39375 L F
.308 0 .104 r
.62014 .39549 m .62288 .39472 L .62033 .39559 L F
.62014 .39549 m .62033 .39559 L .6189 .39608 L F
.126 0 0 r
.61854 .39511 m .61964 .39522 L .62014 .39549 L F
.057 0 0 r
.53483 .35596 m .53339 .3565 L .53415 .35635 L F
.329 .755 .974 r
.53483 .35596 m .53857 .35698 L .53519 .35575 L F
.53483 .35596 m .53765 .35571 L .53857 .35698 L F
.057 0 0 r
.53483 .35596 m .53415 .35635 L .53765 .35571 L F
.329 .755 .974 r
.53483 .35596 m .53519 .35575 L .53477 .3556 L F
.168 .558 .931 r
.54033 .35563 m .53857 .35698 L .53765 .35571 L F
.54033 .35563 m .54173 .35773 L .53857 .35698 L F
.72 .319 0 r
.54033 .35563 m .54134 .35741 L .54173 .35773 L F
0 .477 .775 r
.53857 .35698 m .54173 .35773 L .54198 .35793 L F
.72 .319 0 r
.54134 .35741 m .54275 .35989 L .54173 .35773 L F
0 .477 .775 r
.54198 .35793 m .54173 .35773 L .5434 .35833 L F
.472 .886 .771 r
.40621 .56855 m .40759 .56736 L .40883 .56794 L F
.40621 .56855 m .40415 .56913 L .40759 .56736 L F
.881 .493 .294 r
.55557 .39293 m .5549 .38757 L .55731 .39205 L F
.776 .773 .85 r
.56026 .38885 m .55731 .39205 L .5549 .38757 L F
0 0 0 r
.5636 .37185 m .56532 .37042 L .56686 .36901 L F
.729 .903 .956 r
.56952 .36732 m .56686 .36901 L .56795 .36616 L F
0 .288 .69 r
.56958 .37753 m .57308 .37948 L .57083 .37813 L F
0 0 0 r
.56954 .38138 m .57308 .37948 L .56958 .37753 L F
.56954 .38138 m .57189 .38024 L .57308 .37948 L F
.868 .423 .096 r
.57308 .37948 m .57189 .38024 L .57083 .37813 L F
.05 0 0 r
.30765 .67022 m .31216 .66996 L .31028 .67018 L F
0 .116 .664 r
.31216 .66996 m .31441 .67234 L .31453 .66937 L F
.803 .568 .583 r
.33799 .66577 m .34312 .66329 L .34042 .66217 L F
.33799 .66577 m .34251 .6663 L .34312 .66329 L F
.874 .83 .801 r
.34312 .66329 m .34321 .65859 L .34042 .66217 L F
.34312 .66329 m .34523 .65991 L .34321 .65859 L F
.891 .953 .838 r
.33681 .62476 m .33791 .62591 L .34049 .62266 L F
.902 .488 .148 r
.33671 .62708 m .33791 .62591 L .33681 .62476 L F
.33671 .62708 m .33883 .62819 L .33791 .62591 L F
0 0 .437 r
.34087 .62988 m .33791 .62591 L .33883 .62819 L F
.86 .887 .854 r
.51388 .46356 m .5169 .46335 L .51533 .46187 L F
.826 .892 .889 r
.51533 .46187 m .5169 .46335 L .51984 .46054 L F
.527 0 0 r
.60872 .38578 m .61288 .38597 L .61156 .38725 L F
.609 .085 0 r
.61427 .3869 m .61326 .38753 L .61156 .38725 L F
.762 .674 .764 r
.61156 .38725 m .61585 .38796 L .61311 .39146 L F
.61156 .38725 m .61311 .39146 L .61303 .38712 L F
.996 .863 .556 r
.61272 .38787 m .61311 .39146 L .61182 .39004 L F
.61303 .38712 m .61304 .38767 L .61272 .38787 L F
.61304 .38767 m .61311 .39146 L .61272 .38787 L F
.609 .085 0 r
.61288 .38597 m .61427 .3869 L .61156 .38725 L F
.61427 .3869 m .61585 .38796 L .61326 .38753 L F
.73 .29 .205 r
.33328 .61455 m .33478 .61249 L .33062 .61176 L F
.62 .83 .432 r
.33346 .61441 m .33478 .61249 L .33328 .61455 L F
.633 .861 .985 r
.6119 .36302 m .60696 .36264 L .60773 .3642 L F
.791 .728 .793 r
.54513 .382 m .54074 .38161 L .54347 .37824 L F
.463 .261 .52 r
.54348 .3836 m .54513 .382 L .54547 .38493 L F
.54348 .3836 m .54074 .38161 L .54513 .382 L F
.525 .772 .987 r
.54687 .3795 m .54513 .382 L .54347 .37824 L F
.54687 .3795 m .54807 .38119 L .54513 .382 L F
.896 .62 .512 r
.57207 .36207 m .5688 .35752 L .57344 .36111 L F
.776 .871 .918 r
.48658 .48923 m .49128 .48807 L .48935 .48647 L F
.953 .767 .614 r
.34549 .63785 m .34739 .6394 L .34597 .63555 L F
.939 .84 .72 r
.34374 .64208 m .34739 .6394 L .34549 .63785 L F
.34374 .64208 m .34567 .64336 L .34739 .6394 L F
.785 .711 .782 r
.34597 .63555 m .34739 .6394 L .35013 .63586 L F
.799 .773 .83 r
.45209 .50723 m .44817 .50685 L .45116 .50356 L F
.82 .724 .759 r
.45209 .50723 m .44963 .51086 L .44817 .50685 L F
.892 .82 .77 r
.45317 .50489 m .45209 .50723 L .45116 .50356 L F
.984 .898 .646 r
.43476 .54888 m .43496 .54555 L .43367 .55129 L F
.425 .019 .163 r
.3963 .47872 m .39889 .4786 L .39673 .47739 L F
.428 .014 .149 r
.39673 .47739 m .39889 .4786 L .39975 .47711 L F
.311 0 .196 r
.41712 .46872 m .41562 .46681 L .41435 .46917 L F
.41712 .46872 m .41817 .46608 L .41562 .46681 L F
0 0 0 r
.49867 .41822 m .49736 .42022 L .49961 .4163 L F
.595 .863 .527 r
.4988 .41833 m .49736 .42022 L .49867 .41822 L F
.4988 .41833 m .49609 .42145 L .49736 .42022 L F
0 0 0 r
.46112 .43321 m .45727 .43576 L .45954 .43471 L F
.46331 .43217 m .46112 .43321 L .45954 .43471 L F
.677 .745 .902 r
.42934 .53571 m .4323 .54145 L .4298 .53696 L F
.42934 .53571 m .43393 .5378 L .4323 .54145 L F
.987 .841 .611 r
.42875 .54197 m .4323 .54145 L .43085 .54381 L F
.42875 .54197 m .4298 .53696 L .4323 .54145 L F
.401 .18 .46 r
.50686 .43319 m .50414 .43663 L .50713 .43534 L F
.77 .376 .306 r
.50414 .43663 m .50889 .43935 L .50713 .43534 L F
0 0 0 r
.50582 .44378 m .50438 .44509 L .50676 .44408 L F
.633 .861 .985 r
.6119 .36302 m .60999 .36148 L .60696 .36264 L F
.679 .877 .972 r
.6126 .36021 m .6119 .36302 L .61374 .36102 L F
.6126 .36021 m .60999 .36148 L .6119 .36302 L F
.838 .996 .761 r
.63385 .36663 m .6317 .36922 L .63214 .36725 L F
.995 .807 .542 r
.6317 .36922 m .62979 .37097 L .63214 .36725 L F
.6317 .36922 m .63108 .37214 L .62979 .37097 L F
.827 .705 .731 r
.37909 .56477 m .38336 .56517 L .38222 .56375 L F
.37909 .56477 m .38126 .56829 L .38336 .56517 L F
.888 .989 .74 r
.63385 .36663 m .63479 .36339 L .63605 .36422 L F
.63385 .36663 m .63214 .36725 L .63479 .36339 L F
.802 .759 .244 r
.55557 .39293 m .55516 .39321 L .55332 .39217 L F
.55557 .39293 m .555 .3957 L .55516 .39321 L F
.228 .395 .822 r
.50116 .41465 m .49961 .4163 L .49856 .41346 L F
0 0 0 r
.49867 .41822 m .49961 .4163 L .50116 .41465 L F
.701 .834 .947 r
.37985 .5811 m .38458 .58117 L .38279 .57973 L F
.172 .538 .925 r
.38458 .58117 m .38513 .57981 L .38279 .57973 L F
.38458 .58117 m .38676 .58156 L .38513 .57981 L F
.171 0 .055 r
.43391 .45372 m .43058 .45638 L .43295 .4555 L F
.269 0 .104 r
.43391 .45372 m .4357 .45455 L .43643 .45281 L F
.43391 .45372 m .43295 .4555 L .4357 .45455 L F
.937 .924 .771 r
.46618 .48766 m .46718 .48278 L .46936 .48493 L F
.46618 .48766 m .46485 .4866 L .46718 .48278 L F
.832 .975 .885 r
.65298 .37588 m .65372 .37302 L .65202 .37484 L F
.65298 .37588 m .65622 .37288 L .65372 .37302 L F
.866 .834 .814 r
.52628 .41137 m .52777 .41354 L .53098 .40905 L F
.626 .608 .812 r
.28303 .57338 m .28481 .57679 L .28696 .57475 L F
.782 .665 .735 r
.29078 .56093 m .29257 .56499 L .29514 .56164 L F
.663 .493 .644 r
.29514 .56164 m .29257 .56499 L .29492 .56393 L F
.807 .679 .723 r
.53436 .41565 m .53702 .41232 L .53414 .41298 L F
.45 .625 .927 r
.54131 .40395 m .54244 .40583 L .53974 .40618 L F
.54131 .40395 m .54244 .40583 L .53974 .40618 L F
.556 .427 .66 r
.51874 .39226 m .51943 .39499 L .51627 .39569 L F
0 0 .093 r
.51674 .39613 m .51627 .39569 L .51756 .39541 L F
.85 .392 .021 r
.51421 .39994 m .51599 .40108 L .51613 .40046 L F
.802 .463 .414 r
.51445 .4024 m .51639 .40081 L .51421 .39994 L F
0 0 .093 r
.51637 .39677 m .51613 .40046 L .51623 .39701 L F
.51638 .39871 m .51613 .40046 L .51637 .39677 L F
.51674 .39613 m .51638 .39871 L .51637 .39677 L F
.908 .973 .798 r
.51674 .39613 m .51421 .39994 L .51613 .40046 L F
.739 .876 .944 r
.51722 .40013 m .51599 .40108 L .51421 .39994 L F
.802 .463 .414 r
.51639 .40081 m .51722 .40013 L .51638 .40008 L F
.51639 .40081 m .51638 .40008 L .51421 .39994 L F
0 0 .093 r
.51674 .39613 m .51623 .39701 L .51627 .39569 L F
.556 .427 .66 r
.51874 .39226 m .51943 .39499 L .51627 .39569 L F
.592 .851 .5 r
.51837 .39396 m .51713 .39545 L .51674 .39613 L F
.51713 .39545 m .51611 .39669 L .51674 .39613 L F
.51611 .39669 m .51557 .39734 L .51674 .39613 L F
0 0 .093 r
.51674 .39613 m .51756 .39541 L .51943 .39499 L F
0 0 .501 r
.28341 .64966 m .28486 .65174 L .2848 .6488 L F
.438 .185 .432 r
.28556 .6463 m .28815 .64583 L .28862 .643 L F
.267 .008 .323 r
.29155 .63949 m .28862 .643 L .29122 .64252 L F
.315 .081 .391 r
.28862 .643 m .29037 .64493 L .29122 .64252 L F
.28862 .643 m .28815 .64583 L .29037 .64493 L F
.604 .905 .629 r
.41505 .5412 m .41578 .54031 L .41759 .53874 L F
0 0 0 r
.41505 .5412 m .41498 .54228 L .41578 .54031 L F
.41505 .5412 m .41456 .54459 L .41498 .54228 L F
.051 .4 .856 r
.53785 .36578 m .53934 .36497 L .53652 .36553 L F
.359 0 0 r
.54147 .36561 m .5405 .36658 L .53785 .36578 L F
.763 .476 .499 r
.54664 .36178 m .54329 .36395 L .54359 .36196 L F
.54664 .36178 m .54814 .36463 L .54329 .36395 L F
.739 .542 .627 r
.54664 .36178 m .5434 .35833 L .54509 .358 L F
.54664 .36178 m .54359 .36196 L .5434 .35833 L F
0 0 .252 r
.54329 .36395 m .54449 .35903 L .54275 .35989 L F
.54408 .36073 m .54449 .3617 L .54449 .35903 L F
.54329 .36395 m .54449 .3617 L .54408 .36073 L F
.021 .113 .621 r
.54541 .36414 m .54716 .36394 L .54449 .3617 L F
.555 .02 0 r
.54449 .3617 m .54716 .36394 L .54527 .36348 L F
.038 0 0 r
.54381 .36297 m .54541 .36414 L .54449 .3617 L F
.54329 .36395 m .5442 .36404 L .54381 .36297 L F
.5442 .36404 m .54541 .36414 L .54381 .36297 L F
0 0 .437 r
.54278 .36012 m .54381 .36366 L .54329 .36395 L F
.54283 .36019 m .54381 .36366 L .54278 .36012 L F
.95 .597 .279 r
.54239 .36245 m .54381 .36366 L .54326 .36169 L F
0 0 .36 r
.54239 .36245 m .53934 .36497 L .54381 .36366 L F
.54074 .36105 m .53995 .36326 L .54239 .36245 L F
.53995 .36326 m .53934 .36497 L .54239 .36245 L F
.029 0 0 r
.54419 .36186 m .54302 .36293 L .54148 .36326 L F
.54449 .3617 m .54438 .36179 L .54419 .36186 L F
.54438 .36179 m .54302 .36293 L .54419 .36186 L F
.54195 .36284 m .54148 .36326 L .54062 .36344 L F
.54449 .3617 m .54148 .36326 L .54195 .36284 L F
.95 .597 .279 r
.54074 .36105 m .54239 .36245 L .54293 .36051 L F
.54239 .36245 m .54326 .36169 L .54293 .36051 L F
0 0 .437 r
.54275 .35989 m .54283 .36019 L .54278 .36012 L F
.95 .597 .279 r
.54271 .35992 m .54293 .36051 L .54275 .35989 L F
.54074 .36105 m .54293 .36051 L .54271 .35992 L F
.555 .02 0 r
.54449 .3617 m .54527 .36348 L .54514 .36345 L F
.54412 .36201 m .54514 .36345 L .54302 .36293 L F
.54449 .3617 m .54514 .36345 L .54412 .36201 L F
.486 .435 .726 r
.54062 .36344 m .54039 .36422 L .53934 .36497 L F
.051 .4 .856 r
.5381 .36586 m .5405 .36658 L .53934 .36497 L F
.678 .482 .613 r
.54329 .36395 m .5405 .36658 L .54147 .36561 L F
.762 .543 .601 r
.54751 .36754 m .54329 .36395 L .54814 .36463 L F
.678 .482 .613 r
.54329 .36395 m .54365 .36755 L .5405 .36658 L F
0 0 0 r
.5405 .36658 m .54205 .36562 L .54329 .36395 L F
.762 .543 .601 r
.54751 .36754 m .54365 .36755 L .5435 .366 L F
.54586 .36614 m .5435 .366 L .54329 .36395 L F
.54751 .36754 m .5435 .366 L .54586 .36614 L F
0 0 0 r
.53994 .3658 m .54381 .36366 L .53934 .36497 L F
.54016 .36611 m .54057 .36584 L .53994 .3658 L F
.54057 .36584 m .54381 .36366 L .53994 .3658 L F
.5405 .36658 m .54223 .36505 L .54016 .36611 L F
.5405 .36658 m .542 .36517 L .54223 .36505 L F
.5431 .36414 m .54329 .36395 L .54381 .36366 L F
.54223 .36505 m .54381 .36366 L .54016 .36611 L F
.038 0 0 r
.54422 .36404 m .54205 .36562 L .54541 .36414 L F
.54329 .36395 m .54262 .36485 L .54422 .36404 L F
.54262 .36485 m .54205 .36562 L .54422 .36404 L F
.382 .617 .944 r
.5405 .36658 m .54205 .36562 L .53934 .36497 L F
.486 .435 .726 r
.54039 .36422 m .53898 .36908 L .53934 .36497 L F
.051 .4 .856 r
.53785 .36578 m .5381 .36586 L .53934 .36497 L F
.756 .966 .678 r
.4473 .53708 m .44488 .54078 L .44915 .53856 L F
.4473 .53708 m .44457 .54039 L .44488 .54078 L F
.505 .275 .499 r
.45439 .45248 m .45124 .45551 L .45143 .45328 L F
.618 .956 .825 r
.48635 .46952 m .48749 .46784 L .48983 .46711 L F
.627 .95 .761 r
.48635 .46952 m .48546 .46961 L .48749 .46784 L F
.882 .985 .819 r
.52997 .42835 m .52681 .43249 L .52585 .43136 L F
.121 0 0 r
.52062 .41956 m .52214 .41822 L .51821 .42017 L F
.51821 .42017 m .52214 .41822 L .52062 .41956 L F
.52062 .41956 m .51821 .42017 L .51684 .4181 L F
.51821 .42017 m .52062 .41956 L .51665 .42062 L F
.891 .953 .838 r
.33681 .62476 m .34049 .62266 L .33619 .62325 L F
.782 .586 .635 r
.35762 .57752 m .35371 .57424 L .35623 .57508 L F
.701 .958 .948 r
.40051 .4887 m .39978 .49088 L .40246 .4892 L F
.771 .997 .838 r
.40051 .4887 m .39711 .49176 L .39978 .49088 L F
.212 0 .016 r
.4103 .57448 m .40626 .57777 L .40781 .57571 L F
.659 .859 .976 r
.57125 .39539 m .57299 .39667 L .57562 .3954 L F
.667 .951 .954 r
.50211 .40402 m .50095 .40614 L .50328 .40461 L F
.621 .869 .519 r
.41947 .52884 m .41801 .53049 L .42073 .52713 L F
.83 .887 .883 r
.53313 .44557 m .53791 .44385 L .5364 .4426 L F
.929 .898 .775 r
.53869 .43876 m .5364 .4426 L .53791 .44385 L F
.537 .867 .994 r
.61467 .39314 m .61067 .39309 L .61311 .39146 L F
.755 .759 .856 r
.61585 .38796 m .61672 .39175 L .61467 .39314 L F
.399 .486 .832 r
.34017 .55452 m .34039 .54986 L .33781 .55137 L F
.34017 .55452 m .3422 .55425 L .34039 .54986 L F
.226 .043 .41 r
.29155 .63949 m .29305 .64155 L .29341 .6389 L F
.29155 .63949 m .29122 .64252 L .29305 .64155 L F
.455 .147 .353 r
.43942 .54106 m .43853 .54375 L .43747 .54036 L F
.43942 .54106 m .44082 .54267 L .43853 .54375 L F
.849 .433 .245 r
.56958 .34422 m .56646 .34316 L .56807 .34171 L F
.449 .762 .996 r
.56646 .34316 m .57141 .34413 L .56807 .34171 L F
.862 .966 .864 r
.61833 .37908 m .6142 .38132 L .61628 .37989 L F
.813 .998 .788 r
.61833 .37908 m .61628 .37989 L .6194 .37634 L F
.222 .289 .721 r
.57581 .3536 m .57734 .35725 L .57533 .35868 L F
0 0 .209 r
.57675 .35919 m .57533 .35868 L .57734 .35725 L F
.57675 .35919 m .57491 .36154 L .57533 .35868 L F
.216 .643 .953 r
.57035 .35624 m .57533 .35868 L .57046 .35715 L F
.793 .545 .562 r
.36829 .54417 m .37031 .54504 L .37324 .54511 L F
.546 0 0 r
.37334 .5457 m .37324 .54511 L .37031 .54504 L F
.37334 .5457 m .37537 .54704 L .37324 .54511 L F
0 0 .439 r
.5113 .39172 m .51316 .39048 L .51293 .38751 L F
0 0 0 r
.5113 .39172 m .51001 .39268 L .51316 .39048 L F
.703 .921 .585 r
.2909 .65609 m .28833 .65948 L .28874 .65818 L F
.118 .528 .915 r
.28833 .65948 m .29075 .66011 L .28874 .65818 L F
.037 0 0 r
.53046 .35658 m .53483 .35596 L .53229 .35482 L F
.488 0 0 r
.53229 .35482 m .53483 .35596 L .53477 .3556 L F
.902 .885 .806 r
.44989 .5334 m .4501 .53631 L .45129 .5345 L F
.672 .938 .661 r
.44915 .53856 m .45129 .5345 L .4501 .53631 L F
.881 .95 .85 r
.45271 .53004 m .45129 .5345 L .45384 .53098 L F
.45271 .53004 m .44989 .5334 L .45129 .5345 L F
.808 .719 .766 r
.44963 .51086 m .4455 .51025 L .44817 .50685 L F
.809 .716 .763 r
.44963 .51086 m .44707 .51449 L .4455 .51025 L F
.725 .95 .652 r
.61895 .34471 m .61602 .34718 L .61534 .3489 L F
.289 0 0 r
.62028 .34556 m .61895 .34471 L .62063 .34449 L F
.62028 .34556 m .61602 .34718 L .61895 .34471 L F
.903 .846 .778 r
.47338 .48066 m .47061 .47967 L .47285 .47607 L F
.47338 .48066 m .4721 .48069 L .47061 .47967 L F
.796 .794 .851 r
.47677 .4763 m .47338 .48066 L .47285 .47607 L F
.96 .931 .718 r
.32948 .61834 m .33282 .61667 L .33346 .61441 L F
.954 .949 .713 r
.45501 .52598 m .45384 .53098 L .45661 .52732 L F
.874 .881 .837 r
.45501 .52598 m .45661 .52732 L .45936 .5238 L F
.139 .68 .83 r
.61137 .34045 m .61228 .34027 L .61343 .3405 L F
.214 0 0 r
.61088 .34062 m .61329 .34007 L .61228 .34027 L F
0 0 0 r
.61228 .34027 m .61672 .33921 L .61343 .3405 L F
.214 0 0 r
.61329 .34007 m .61516 .33965 L .61228 .34027 L F
.139 .68 .83 r
.60956 .34041 m .61228 .34027 L .61137 .34045 L F
.29 .696 .973 r
.57215 .34523 m .57141 .34413 L .56958 .34422 L F
.57215 .34523 m .57141 .34413 L .56958 .34422 L F
.153 0 .088 r
.43649 .4666 m .43962 .46392 L .4386 .46547 L F
.396 .111 .358 r
.44203 .46283 m .4386 .46547 L .43962 .46392 L F
.584 .603 .837 r
.30565 .62888 m .30731 .63266 L .30974 .63161 L F
.856 .409 .135 r
.54173 .35773 m .54275 .35989 L .5434 .35833 L F
0 0 0 r
.54275 .35989 m .54509 .358 L .5434 .35833 L F
.457 .722 .982 r
.29227 .65202 m .2943 .6538 L .29387 .65135 L F
.499 .908 .863 r
.2943 .6538 m .29696 .65237 L .29464 .65161 L F
.2943 .6538 m .29464 .65161 L .29396 .65184 L F
.494 .888 .725 r
.29696 .65237 m .29309 .65463 L .29642 .65508 L F
.686 .497 .625 r
.29309 .65463 m .29607 .65756 L .29642 .65508 L F
.001 .082 .595 r
.29498 .65535 m .29252 .65232 L .29476 .65215 L F
.29252 .65232 m .29227 .65202 L .29326 .65207 L F
.29252 .65232 m .29326 .65207 L .29476 .65215 L F
.499 .908 .863 r
.29396 .65184 m .29464 .65161 L .29387 .65135 L F
.784 .602 .655 r
.41531 .53112 m .41733 .53449 L .41298 .53424 L F
.783 .586 .634 r
.41733 .53449 m .41481 .53541 L .41298 .53424 L F
.831 .801 .823 r
.41801 .53049 m .41733 .53449 L .41531 .53112 L F
.41801 .53049 m .41485 .53524 L .41733 .53449 L F
.831 .8 .822 r
.41733 .53449 m .41485 .53524 L .41481 .53541 L F
.43 0 0 r
.41963 .53446 m .41485 .53524 L .41733 .53449 L F
.854 .907 .87 r
.52335 .41508 m .52214 .41822 L .52062 .41956 L F
.442 0 0 r
.52214 .41822 m .52271 .41871 L .52062 .41956 L F
.52214 .41822 m .52481 .42016 L .52271 .41871 L F
.847 .75 .756 r
.65358 .35377 m .65546 .35535 L .65448 .35168 L F
.639 .3 .382 r
.6513 .3574 m .65546 .35535 L .65358 .35377 L F
.6513 .3574 m .65566 .35757 L .65546 .35535 L F
.733 .365 .355 r
.55733 .37717 m .56033 .37778 L .56096 .37563 L F
.388 .188 .483 r
.56096 .37563 m .56387 .37477 L .5636 .37185 L F
.549 .308 .502 r
.56033 .37778 m .56387 .37477 L .56096 .37563 L F
.894 .905 .826 r
.4473 .53708 m .44915 .53856 L .4501 .53631 L F
.939 .597 .171 r
.51275 .44892 m .51401 .45004 L .51225 .44618 L F
.51225 .44618 m .51401 .45004 L .51275 .44892 L F
.27 .743 .94 r
.61534 .3489 m .61415 .34812 L .61078 .34841 L F
.604 .933 .958 r
.61602 .34718 m .61415 .34812 L .61534 .3489 L F
0 0 .057 r
.58291 .376 m .58253 .37566 L .58295 .37339 L F
.58291 .376 m .58237 .37829 L .58253 .37566 L F
.954 .949 .713 r
.45501 .52598 m .45271 .53004 L .45384 .53098 L F
0 0 0 r
.45727 .43576 m .45495 .43674 L .45358 .43806 L F
.58027 .3879 m .58079 .38568 L .58162 .38323 L F
.115 0 .2 r
.29976 .62953 m .29726 .63285 L .29899 .63238 L F
.739 .371 .355 r
.30388 .63219 m .29976 .62953 L .29899 .63238 L F
.506 .602 .883 r
.29651 .66431 m .30061 .66695 L .29956 .66511 L F
.193 .47 .889 r
.29956 .66511 m .30061 .66695 L .30143 .66548 L F
.325 .639 .965 r
.30061 .66695 m .30318 .66731 L .30143 .66548 L F
.923 .848 .752 r
.41338 .52986 m .41531 .53112 L .41298 .53424 L F
.971 .828 .643 r
.41631 .52926 m .41531 .53112 L .41338 .52986 L F
.441 .208 .463 r
.3338 .54467 m .33657 .5446 L .33633 .54169 L F
.632 .346 .467 r
.33633 .54169 m .33657 .5446 L .33868 .54341 L F
.49 .078 .185 r
.41759 .57111 m .41992 .57116 L .42049 .56949 L F
.927 .854 .75 r
.47751 .49646 m .48141 .49405 L .47949 .49242 L F
.47751 .49646 m .47931 .4978 L .48141 .49405 L F
.846 .831 .832 r
.47949 .49242 m .48141 .49405 L .48413 .4908 L F
.891 .887 .821 r
.56043 .40094 m .56391 .4002 L .5622 .39836 L F
.875 .848 .814 r
.5622 .39836 m .56391 .4002 L .56602 .39663 L F
0 0 0 r
.39414 .5764 m .39419 .57576 L .39506 .57393 L F
.621 .568 .773 r
.4635 .44211 m .46357 .44293 L .46661 .44218 L F
.442 .519 .842 r
.29651 .66431 m .29777 .66161 L .29496 .66217 L F
.29651 .66431 m .29956 .66511 L .29777 .66161 L F
.744 .724 .833 r
.51225 .44618 m .5168 .44667 L .51491 .44319 L F
.939 .597 .171 r
.51225 .44618 m .51442 .4475 L .5168 .44667 L F
.428 .565 .889 r
.51491 .44319 m .5168 .44667 L .51623 .44285 L F
.959 .91 .724 r
.5168 .44667 m .51442 .4475 L .51623 .44285 L F
.953 .81 .665 r
.3509 .56437 m .35201 .56509 L .35003 .56149 L F
.247 .099 .474 r
.51404 .38265 m .51578 .38409 L .5153 .3807 L F
.51404 .38265 m .51389 .38563 L .51578 .38409 L F
.155 0 .071 r
.43649 .4666 m .43554 .46913 L .43297 .4695 L F
.129 0 .061 r
.43776 .468 m .43649 .4666 L .4386 .46547 L F
.43776 .468 m .43554 .46913 L .43649 .4666 L F
.661 .442 .577 r
.28468 .56391 m .28867 .56473 L .28746 .5616 L F
.622 .538 .738 r
.28637 .55723 m .28746 .5616 L .29078 .56093 L F
.589 .406 .601 r
.28746 .5616 m .28867 .56473 L .29078 .56093 L F
.406 .106 .34 r
.2848 .6488 m .28815 .64583 L .28556 .6463 L F
.915 .756 .67 r
.4455 .51025 m .44707 .51449 L .44497 .51295 L F
.524 .86 .994 r
.63479 .36339 m .63866 .36338 L .63605 .36422 L F
.859 .689 .67 r
.44289 .53078 m .43872 .53009 L .43964 .52742 L F
.921 .815 .724 r
.44289 .53078 m .43863 .53294 L .43872 .53009 L F
.44289 .53078 m .44072 .53457 L .43863 .53294 L F
.75 .877 .937 r
.58944 .37123 m .59156 .37197 L .58904 .37098 L F
.909 .843 .767 r
.50095 .45055 m .49968 .45286 L .49881 .44934 L F
0 0 .211 r
.59595 .39331 m .59443 .39588 L .59551 .39191 L F
.083 .121 .603 r
.59624 .39759 m .59443 .39588 L .59595 .39331 L F
.251 .129 .512 r
.59624 .39759 m .59443 .39914 L .59443 .39588 L F
.481 .728 .98 r
.60274 .36148 m .60696 .36264 L .60401 .36304 L F
.674 .447 .569 r
.28813 .56737 m .29235 .56784 L .29257 .56499 L F
.924 .874 .769 r
.29235 .56784 m .29492 .56393 L .29257 .56499 L F
.64 .865 .984 r
.31616 .67342 m .31666 .67139 L .31441 .67234 L F
.31616 .67342 m .31871 .6725 L .31666 .67139 L F
.792 .849 .893 r
.492 .48281 m .49702 .48109 L .4946 .47966 L F
.776 .726 .806 r
.4946 .47966 m .49702 .48109 L .49867 .47984 L F
0 0 0 r
.5234 .36194 m .52518 .36084 L .52617 .35901 L F
.061 .222 .718 r
.5234 .36194 m .52583 .36366 L .52518 .36084 L F
.99 .727 .396 r
.34394 .64872 m .34396 .64599 L .3423 .64478 L F
.908 .932 .816 r
.3423 .64478 m .34396 .64599 L .34567 .64336 L F
.28 .019 .328 r
.41764 .48035 m .4151 .48359 L .41472 .48039 L F
.754 .684 .784 r
.28696 .57475 m .2914 .57535 L .28989 .57146 L F
.76 .687 .782 r
.28989 .57146 m .2914 .57535 L .29432 .572 L F
.367 .68 .978 r
.41435 .5775 m .41737 .57904 L .41672 .57776 L F
.776 .728 .809 r
.49763 .47609 m .4946 .47966 L .49867 .47984 L F
.803 .743 .797 r
.49763 .47609 m .49867 .47984 L .50174 .47607 L F
.525 .789 .993 r
.4116 .56051 m .41189 .56196 L .40779 .56161 L F
.48 .072 .188 r
.41189 .56196 m .40717 .56433 L .40779 .56161 L F
.41189 .56196 m .41026 .56408 L .40717 .56433 L F
.216 .534 .923 r
.4116 .56051 m .41301 .56047 L .41189 .56196 L F
.497 .415 .693 r
.41301 .56047 m .41026 .56408 L .41189 .56196 L F
0 0 0 r
.42685 .55995 m .42557 .56188 L .42394 .56374 L F
.561 .855 .535 r
.42394 .56374 m .4234 .56436 L .42593 .56168 L F
0 0 0 r
.42513 .56238 m .42442 .56363 L .42394 .56374 L F
.561 .855 .535 r
.42394 .56374 m .42257 .56524 L .4234 .56436 L F
.535 .056 .066 r
.42394 .56374 m .42348 .56594 L .42077 .56449 L F
0 0 0 r
.42442 .56363 m .42348 .56594 L .42394 .56374 L F
.921 .715 .607 r
.42154 .56247 m .42329 .56559 L .42442 .56363 L F
.42329 .56559 m .42348 .56594 L .42442 .56363 L F
0 0 0 r
.42557 .56188 m .42442 .56363 L .42513 .56238 L F
.656 .89 .982 r
.48248 .42909 m .48491 .43026 L .48733 .42869 L F
.53 .323 .544 r
.29341 .6389 m .2968 .63519 L .29419 .63628 L F
.869 .847 .819 r
.47193 .5035 m .47547 .50329 L .47472 .49979 L F
.47193 .5035 m .47365 .5044 L .47547 .50329 L F
.865 .865 .836 r
.47472 .49979 m .47547 .50329 L .47831 .49986 L F
.479 .818 .999 r
.66382 .36203 m .66574 .36027 L .66677 .36137 L F
.725 .934 .957 r
.66677 .36137 m .66478 .36112 L .66521 .36232 L F
.66478 .36112 m .66429 .36106 L .66451 .36135 L F
.491 .837 .564 r
.6646 .36127 m .66507 .36088 L .66382 .36203 L F
.976 .888 .675 r
.66309 .36371 m .66521 .36232 L .66451 .36135 L F
.66449 .36136 m .66451 .36135 L .66429 .36106 L F
.725 .934 .957 r
.66478 .36112 m .66574 .36027 L .66429 .36106 L F
.74 .901 .951 r
.66429 .36106 m .66574 .36027 L .66449 .36136 L F
.66429 .36106 m .66449 .36136 L .6638 .36197 L F
.976 .888 .675 r
.66395 .36182 m .66449 .36136 L .66429 .36106 L F
.491 .837 .564 r
.66441 .36144 m .6646 .36127 L .66382 .36203 L F
.6638 .36197 m .66444 .36141 L .66382 .36203 L F
.976 .888 .675 r
.66309 .36371 m .66451 .36135 L .66395 .36182 L F
.491 .837 .564 r
.6646 .36127 m .66551 .36048 L .66507 .36088 L F
.66444 .36141 m .66478 .36112 L .66441 .36144 L F
.66478 .36112 m .66551 .36048 L .66441 .36144 L F
.66444 .36141 m .66574 .36027 L .66551 .36048 L F
.725 .934 .957 r
.66677 .36137 m .66574 .36027 L .66478 .36112 L F
.66478 .36112 m .66451 .36135 L .66521 .36232 L F
.767 .675 .762 r
.42146 .53751 m .42396 .53513 L .41963 .53446 L F
0 0 .005 r
.58508 .35085 m .58609 .35033 L .58613 .34905 L F
.874 .881 .837 r
.45501 .52598 m .45936 .5238 L .45782 .52294 L F
.842 .928 .887 r
.45782 .52294 m .45936 .5238 L .46236 .52087 L F
0 0 0 r
.40923 .47057 m .40593 .47311 L .40824 .47176 L F
.193 0 0 r
.40824 .47176 m .41168 .46973 L .40923 .47057 L F
.824 .997 .77 r
.35072 .55813 m .34828 .5611 L .3485 .55958 L F
.063 .343 .819 r
.34828 .5611 m .35003 .56149 L .3485 .55958 L F
.953 .81 .665 r
.3509 .56437 m .35003 .56149 L .34828 .5611 L F
.853 .995 .754 r
.65622 .37288 m .65747 .371 L .65707 .37009 L F
.812 .978 .895 r
.65372 .37302 m .65622 .37288 L .65707 .37009 L F
0 0 0 r
.55682 .40298 m .55439 .40622 L .55614 .40408 L F
.895 .508 .288 r
.33977 .63148 m .34087 .62988 L .33883 .62819 L F
.86 .453 .26 r
.33977 .63148 m .34223 .63201 L .34087 .62988 L F
.212 .365 .801 r
.50713 .43534 m .50889 .43935 L .51019 .43795 L F
.12 .22 .694 r
.50889 .43935 m .51108 .44199 L .51019 .43795 L F
.557 .33 .527 r
.50823 .44231 m .51108 .44199 L .50889 .43935 L F
.85 .813 .813 r
.61773 .38942 m .61672 .39175 L .61585 .38796 L F
.809 .768 .815 r
.62836 .37569 m .62531 .37908 L .62442 .37566 L F
.688 .754 .902 r
.32357 .67467 m .32451 .67547 L .32545 .67285 L F
.184 0 0 r
.5267 .42048 m .52481 .42016 L .52815 .41891 L F
0 .459 .832 r
.52271 .41871 m .52481 .42016 L .5267 .42048 L F
0 0 0 r
.63424 .35017 m .63325 .35078 L .6332 .3508 L F
.63292 .35081 m .6332 .3508 L .63234 .35109 L F
.63424 .35017 m .6332 .3508 L .63292 .35081 L F
.63424 .35017 m .63302 .35076 L .63616 .34864 L F
.63302 .35076 m .63306 .35063 L .63616 .34864 L F
.693 .191 0 r
.63424 .35017 m .63338 .35039 L .63325 .35078 L F
.63424 .35017 m .63545 .35188 L .63338 .35039 L F
.684 .24 .19 r
.63734 .35121 m .63545 .35188 L .63424 .35017 L F
.345 0 0 r
.6401 .35179 m .63545 .35188 L .63734 .35121 L F
.6401 .35179 m .63892 .35261 L .63545 .35188 L F
.047 .546 .882 r
.63545 .35188 m .63892 .35261 L .63429 .35076 L F
.63391 .35077 m .63429 .35076 L .63338 .35039 L F
.63545 .35188 m .63429 .35076 L .63391 .35077 L F
.552 .903 .686 r
.63616 .34864 m .63306 .35063 L .63711 .34752 L F
.63306 .35063 m .63234 .35109 L .63306 .35062 L F
0 0 0 r
.63302 .35076 m .63234 .35109 L .63306 .35063 L F
.93 .768 .66 r
.63234 .35109 m .63325 .35078 L .63306 .35062 L F
.63234 .35109 m .63306 .35062 L .63091 .3488 L F
.552 .903 .686 r
.63306 .35062 m .63234 .35109 L .6331 .35053 L F
.63306 .35063 m .6331 .35053 L .63711 .34752 L F
0 .34 .787 r
.63319 .35027 m .63325 .35078 L .63338 .35039 L F
.783 .714 .787 r
.63711 .34752 m .6331 .35053 L .63233 .34629 L F
0 .34 .787 r
.63175 .34951 m .63306 .35062 L .63308 .35055 L F
.63234 .34995 m .63308 .35055 L .63309 .35052 L F
.63175 .34951 m .63308 .35055 L .63234 .34995 L F
.93 .768 .66 r
.63234 .34995 m .63091 .3488 L .63233 .34629 L F
.63234 .35109 m .63091 .3488 L .63234 .34995 L F
.783 .714 .787 r
.6331 .35053 m .63234 .35109 L .63234 .34995 L F
.6331 .35053 m .63234 .34995 L .63233 .34629 L F
0 .34 .787 r
.63091 .3488 m .63175 .34951 L .63317 .35025 L F
.63175 .34951 m .63309 .35052 L .63317 .35025 L F
.63317 .35025 m .63318 .35031 L .63319 .35027 L F
.63318 .35031 m .63325 .35078 L .63319 .35027 L F
.63306 .35062 m .63325 .35078 L .63317 .35025 L F
.661 .566 .737 r
.63616 .34864 m .63734 .35121 L .63424 .35017 L F
.791 .681 .743 r
.2968 .63519 m .29899 .63238 L .29726 .63285 L F
.485 .167 .352 r
.4604 .44963 m .45699 .45219 L .45748 .45024 L F
.923 .885 .778 r
.63147 .39395 m .63279 .39635 L .63282 .39392 L F
.978 .766 .349 r
.51058 .40258 m .50991 .40327 L .50639 .4037 L F
.277 .763 .918 r
.51255 .40159 m .50875 .40149 L .50991 .40327 L F
.50875 .40149 m .50739 .40145 L .50991 .40327 L F
.978 .766 .349 r
.51058 .40258 m .5104 .40402 L .50991 .40327 L F
.5104 .40402 m .51028 .40492 L .50991 .40327 L F
.826 .892 .889 r
.51533 .46187 m .51984 .46054 L .51839 .45924 L F
.693 .893 .97 r
.51984 .46054 m .52209 .45916 L .51839 .45924 L F
.529 .17 .303 r
.41759 .53874 m .41936 .54025 L .42146 .53751 L F
.846 .831 .832 r
.47949 .49242 m .48413 .4908 L .4825 .48931 L F
.737 .862 .939 r
.4825 .48931 m .48413 .4908 L .48658 .48923 L F
.828 .815 .838 r
.3016 .64532 m .30588 .64507 L .30406 .647 L F
.909 .929 .814 r
.46354 .44108 m .4635 .44211 L .46421 .44096 L F
.46368 .43791 m .4611 .44149 L .4635 .44211 L F
.422 .401 .731 r
.46524 .44257 m .46343 .44545 L .4635 .44211 L F
.46566 .44268 m .46525 .44319 L .46524 .44257 L F
.46485 .44369 m .46343 .44545 L .46476 .44334 L F
.46566 .44268 m .46581 .44526 L .46343 .44545 L F
.448 .176 .407 r
.46523 .44663 m .46343 .44545 L .46581 .44526 L F
.46523 .44663 m .46293 .44876 L .46343 .44545 L F
.208 0 0 r
.46129 .44767 m .46534 .44551 L .46123 .44483 L F
.46534 .44551 m .46581 .44526 L .46526 .44521 L F
.46534 .44551 m .46526 .44521 L .46123 .44483 L F
.422 .401 .731 r
.46525 .44319 m .46485 .44369 L .46524 .44257 L F
.46485 .44369 m .46476 .44334 L .46524 .44257 L F
.809 .639 .671 r
.4611 .44149 m .46123 .44483 L .46526 .44521 L F
.46526 .44482 m .46526 .44521 L .46581 .44526 L F
.4611 .44149 m .46526 .44521 L .46526 .44482 L F
.46291 .44196 m .46566 .44268 L .4635 .44211 L F
.4611 .44149 m .46296 .44198 L .46291 .44196 L F
.46296 .44198 m .46566 .44268 L .46291 .44196 L F
0 0 0 r
.4642 .44128 m .46308 .44202 L .4641 .44116 L F
.809 .639 .671 r
.4611 .44149 m .46581 .44526 L .46566 .44268 L F
0 0 0 r
.46308 .44202 m .46252 .44239 L .46302 .442 L F
.46308 .44202 m .46302 .442 L .4641 .44116 L F
0 0 .395 r
.46252 .44239 m .46112 .44151 L .4641 .44116 L F
.46112 .44151 m .4611 .44149 L .46143 .44146 L F
.46112 .44151 m .46143 .44146 L .4641 .44116 L F
.909 .929 .814 r
.46368 .43791 m .46354 .44108 L .46549 .4389 L F
.46354 .44108 m .46421 .44096 L .46549 .4389 L F
.621 .568 .773 r
.4635 .44211 m .46661 .44218 L .46549 .4389 L F
0 0 0 r
.36741 .48536 m .37316 .48416 L .37065 .4868 L F
.36741 .48536 m .37113 .48481 L .37316 .48416 L F
.038 0 0 r
.37113 .48481 m .37582 .48414 L .37316 .48416 L F
.303 0 .229 r
.31366 .61917 m .31409 .61575 L .31086 .61849 L F
.157 0 .195 r
.31625 .61444 m .31409 .61575 L .31366 .61917 L F
.886 .679 .617 r
.41995 .5745 m .42141 .57794 L .42233 .57532 L F
0 0 .06 r
.55614 .40408 m .55439 .40622 L .55352 .40861 L F
.997 .809 .532 r
.42034 .55742 m .42187 .55838 L .42123 .56098 L F
.558 .502 .749 r
.56387 .37477 m .56532 .37042 L .5636 .37185 L F
0 0 .159 r
.58896 .39247 m .58932 .394 L .58957 .39016 L F
.132 .367 .826 r
.4212 .54456 m .42258 .54794 L .42392 .54657 L F
.94 .672 .204 r
.42258 .54794 m .42132 .54874 L .42392 .54657 L F
.42258 .54794 m .42285 .55086 L .42132 .54874 L F
.48 0 0 r
.49163 .43031 m .49434 .43158 L .48988 .4313 L F
.471 .108 .266 r
.49512 .42926 m .49434 .43158 L .49163 .43031 L F
.662 .967 .916 r
.5688 .35752 m .56943 .35653 L .57046 .35715 L F
.867 .862 .833 r
.47751 .49646 m .47472 .49979 L .47831 .49986 L F
.89 .872 .813 r
.47751 .49646 m .47831 .49986 L .47931 .4978 L F
.413 .127 .366 r
.4483 .45663 m .44793 .45953 L .44516 .46011 L F
.318 .05 .34 r
.45014 .45853 m .4483 .45663 L .45124 .45551 L F
.45014 .45853 m .44793 .45953 L .4483 .45663 L F
.268 0 .076 r
.43297 .4695 m .43219 .47179 L .42957 .4725 L F
.273 0 .171 r
.43554 .46913 m .43219 .47179 L .43297 .4695 L F
0 0 0 r
.30974 .63161 m .30686 .6357 L .30821 .63454 L F
.712 .422 .484 r
.30686 .6357 m .31027 .63815 L .30847 .63867 L F
0 0 0 r
.30821 .63454 m .30686 .6357 L .30533 .6375 L F
.54 0 0 r
.37978 .56263 m .37935 .56169 L .37855 .56026 L F
.37978 .56263 m .38222 .56375 L .37935 .56169 L F
.691 .935 .634 r
.42872 .5585 m .42685 .55995 L .42593 .56168 L F
.319 0 .251 r
.42426 .46277 m .42676 .46201 L .42753 .45896 L F
.331 .024 .285 r
.42753 .45896 m .42989 .45914 L .43058 .45638 L F
.408 .105 .335 r
.42676 .46201 m .42989 .45914 L .42753 .45896 L F
.865 .824 .806 r
.49881 .44934 m .49968 .45286 L .49643 .45258 L F
.887 .762 .718 r
.49968 .45286 m .49775 .45648 L .49643 .45258 L F
0 0 .43 r
.58963 .37798 m .59037 .3823 L .59045 .38032 L F
0 0 .198 r
.59037 .3823 m .59088 .38266 L .59045 .38032 L F
.59037 .3823 m .5907 .38492 L .59088 .38266 L F
.402 .123 .372 r
.42989 .45914 m .43295 .4555 L .43058 .45638 L F
.854 .775 .774 r
.45999 .51929 m .46488 .51722 L .46315 .51564 L F
.45999 .51929 m .46236 .52087 L .46488 .51722 L F
.855 .82 .813 r
.46488 .51722 m .46412 .51374 L .46315 .51564 L F
.46488 .51722 m .46738 .5137 L .46412 .51374 L F
.788 .719 .788 r
.32545 .67285 m .32775 .67689 L .33018 .67317 L F
.845 .505 .41 r
.55281 .41256 m .55563 .41327 L .55408 .41536 L F
0 0 0 r
.55408 .41536 m .55563 .41327 L .55744 .41161 L F
.882 .785 .75 r
.46898 .50657 m .46666 .5103 L .4702 .51035 L F
.863 .837 .819 r
.4702 .51035 m .46666 .5103 L .46738 .5137 L F
.804 .75 .803 r
.46898 .50657 m .4702 .51035 L .47284 .50695 L F
.539 .167 .284 r
.41578 .54031 m .41936 .54025 L .41759 .53874 L F
0 0 0 r
.61228 .34027 m .61516 .33965 L .61672 .33921 L F
.35 .816 .733 r
.61672 .33921 m .61782 .33846 L .61932 .33784 L F
.61672 .33921 m .61516 .33965 L .61782 .33846 L F
0 0 0 r
.38126 .56829 m .38202 .56844 L .38351 .56883 L F
.38126 .56829 m .37939 .57001 L .38202 .56844 L F
.763 .708 .8 r
.38351 .56883 m .38543 .5719 L .38111 .57119 L F
.56 .626 .874 r
.38807 .57123 m .38543 .5719 L .38351 .56883 L F
.561 0 0 r
.37734 .48772 m .37969 .4893 L .37749 .48827 L F
.734 .848 .934 r
.50017 .47451 m .49763 .47609 L .50174 .47607 L F
.849 .865 .853 r
.50017 .47451 m .50174 .47607 L .50434 .47328 L F
.896 .982 .803 r
.40568 .56002 m .40301 .56365 L .40494 .56125 L F
.813 .546 .534 r
.40779 .56161 m .40531 .56266 L .40592 .5602 L F
.40531 .56266 m .40301 .56365 L .40494 .56137 L F
.216 0 0 r
.40494 .56125 m .40502 .56125 L .40568 .56002 L F
.813 .546 .534 r
.40531 .56266 m .40494 .56139 L .40507 .56123 L F
.40572 .561 m .40507 .56123 L .40592 .5602 L F
.40531 .56266 m .40507 .56123 L .40572 .561 L F
.512 .813 .999 r
.40568 .56002 m .4116 .56051 L .40779 .56161 L F
.216 0 0 r
.40583 .56126 m .40647 .56219 L .40844 .5613 L F
.813 .546 .534 r
.40494 .56139 m .40498 .56132 L .40592 .5602 L F
.216 0 0 r
.40502 .56125 m .40844 .5613 L .40568 .56002 L F
.813 .546 .534 r
.40779 .56161 m .40717 .56433 L .40301 .56365 L F
.185 0 0 r
.40844 .5613 m .40647 .56219 L .41085 .56127 L F
.838 .572 .537 r
.40705 .564 m .41085 .56127 L .40647 .56219 L F
0 0 .264 r
.40705 .56097 m .40705 .56303 L .40647 .56219 L F
.40705 .56303 m .40705 .564 L .40647 .56219 L F
.216 0 0 r
.40502 .56125 m .40647 .56219 L .40583 .56126 L F
.40494 .56125 m .40497 .56127 L .40502 .56125 L F
.40497 .56127 m .40647 .56219 L .40502 .56125 L F
.813 .546 .534 r
.40494 .56139 m .40494 .56137 L .40498 .56132 L F
.845 .508 .417 r
.40717 .56433 m .40485 .56643 L .40301 .56365 L F
.859 .875 .849 r
.40485 .56643 m .40494 .56137 L .40301 .56365 L F
.40494 .56137 m .40494 .56125 L .40301 .56365 L F
.40494 .56137 m .40492 .5613 L .40494 .56125 L F
.813 .546 .534 r
.40592 .5602 m .40508 .5612 L .40568 .56002 L F
.40508 .5612 m .40301 .56365 L .4046 .56148 L F
.148 0 0 r
.40492 .5613 m .40497 .56127 L .40494 .56125 L F
.813 .546 .534 r
.40508 .5612 m .4046 .56148 L .40568 .56002 L F
.859 .875 .849 r
.40485 .56643 m .40399 .56319 L .40492 .5613 L F
.40485 .56643 m .40492 .5613 L .40494 .56137 L F
.148 0 0 r
.40399 .56319 m .40647 .56219 L .40497 .56127 L F
.40399 .56319 m .40497 .56127 L .40492 .5613 L F
.874 .771 .745 r
.31027 .63815 m .3125 .63674 L .31256 .63495 L F
.908 .932 .816 r
.3423 .64478 m .34567 .64336 L .34374 .64208 L F
.377 .425 .784 r
.36843 .57626 m .37131 .57757 L .37069 .57386 L F
.763 .697 .789 r
.38406 .58468 m .38841 .58532 L .38676 .58156 L F
.817 .72 .757 r
.38676 .58156 m .38841 .58532 L .39038 .58121 L F
.259 0 .07 r
.4207 .4652 m .42426 .46277 L .42162 .46351 L F
.532 .251 .434 r
.56571 .38496 m .56954 .38138 L .56576 .38216 L F
.882 .985 .819 r
.52997 .42835 m .52585 .43136 L .52915 .42862 L F
.554 .895 .655 r
.52759 .42955 m .52915 .42862 L .52747 .42964 L F
.756 .995 .838 r
.53188 .42564 m .53024 .42797 L .52915 .42862 L F
.53188 .42564 m .53375 .42501 L .52997 .42835 L F
.53188 .42564 m .53142 .42614 L .53162 .42644 L F
.53142 .42614 m .52915 .42862 L .53162 .42644 L F
.554 .895 .655 r
.53162 .42644 m .52747 .42964 L .53014 .42741 L F
.142 0 0 r
.53194 .42692 m .53162 .42644 L .53014 .42741 L F
.53282 .42669 m .53162 .42644 L .53194 .42692 L F
.554 .895 .655 r
.53162 .42644 m .53013 .42775 L .53022 .42752 L F
.313 .802 .86 r
.53121 .42649 m .53282 .42669 L .53027 .42737 L F
.53032 .42725 m .53027 .42737 L .53014 .42741 L F
.53121 .42649 m .53027 .42737 L .53032 .42725 L F
.554 .895 .655 r
.53022 .42752 m .52915 .42862 L .52759 .42955 L F
.53013 .42775 m .52915 .42862 L .53022 .42752 L F
.756 .995 .838 r
.53024 .42797 m .52997 .42835 L .52915 .42862 L F
.809 .768 .815 r
.62836 .37569 m .62442 .37566 L .62632 .37414 L F
.828 .818 .84 r
.63108 .37214 m .62836 .37569 L .62632 .37414 L F
0 0 0 r
.62183 .33644 m .62456 .33558 L .62613 .33442 L F
.62456 .33558 m .62884 .33449 L .62613 .33442 L F
0 .528 .743 r
.60073 .38612 m .60166 .38638 L .60486 .38673 L F
0 0 0 r
.52082 .38997 m .51874 .39226 L .52086 .38856 L F
.636 .881 .536 r
.52412 .3844 m .52237 .38631 L .52086 .38856 L F
0 0 0 r
.52237 .38631 m .52082 .38997 L .52086 .38856 L F
.817 .72 .757 r
.38676 .58156 m .39038 .58121 L .38938 .58064 L F
.656 .629 .81 r
.32821 .6127 m .32585 .61557 L .32346 .61244 L F
.728 .868 .947 r
.36172 .58272 m .36494 .57986 L .36167 .58182 L F
.36172 .58272 m .36593 .58102 L .36494 .57986 L F
.875 .848 .814 r
.5622 .39836 m .56602 .39663 L .56469 .39592 L F
.225 .745 .775 r
.56909 .39514 m .56469 .39592 L .56602 .39663 L F
.774 .752 .834 r
.47082 .48283 m .46936 .48493 L .46718 .48278 L F
.132 .367 .826 r
.4212 .54456 m .42521 .54453 L .42318 .54375 L F
.4212 .54456 m .42392 .54657 L .42521 .54453 L F
.348 0 0 r
.42518 .54475 m .42521 .54453 L .42392 .54657 L F
.34 0 .036 r
.52179 .39207 m .52475 .3917 L .52543 .39035 L F
0 0 0 r
.38944 .55808 m .38659 .56153 L .38881 .55916 L F
.449 .325 .618 r
.38659 .56153 m .38875 .56206 L .38881 .55916 L F
.77 .654 .733 r
.28989 .57146 m .29432 .572 L .29235 .56784 L F
.85 .83 .827 r
.46738 .5137 m .46666 .5103 L .46412 .51374 L F
.857 .948 .875 r
.46368 .43791 m .46549 .4389 L .46801 .43587 L F
.551 .419 .654 r
.46549 .4389 m .46855 .43952 L .46801 .43587 L F
.182 .225 .672 r
.46549 .4389 m .46825 .44086 L .46855 .43952 L F
.46549 .4389 m .46661 .44218 L .46825 .44086 L F
.779 .724 .802 r
.53352 .36561 m .53187 .36725 L .53161 .36629 L F
.065 0 .077 r
.53352 .36561 m .53309 .36709 L .53187 .36725 L F
.366 0 .188 r
.52518 .36084 m .52869 .35852 L .52617 .35901 L F
.933 .763 .288 r
.555 .3957 m .55426 .39705 L .55516 .39321 L F
.555 .3957 m .55476 .39857 L .55426 .39705 L F
0 0 0 r
.3016 .64532 m .30341 .64299 L .30428 .64196 L F
.982 .699 .331 r
.36492 .57873 m .36576 .58022 L .36488 .57626 L F
.406 .4 .74 r
.36713 .57955 m .3644 .57781 L .36357 .57608 L F
.3644 .57781 m .36199 .57627 L .36343 .57609 L F
.3644 .57781 m .36343 .57609 L .36357 .57608 L F
.982 .699 .331 r
.36494 .57986 m .36593 .58102 L .36576 .58022 L F
.36494 .57986 m .36576 .58022 L .36548 .57972 L F
.371 .691 .981 r
.36494 .57986 m .36593 .58102 L .36713 .57955 L F
.36713 .57955 m .36593 .58102 L .36494 .57986 L F
0 0 0 r
.36361 .58019 m .36494 .57986 L .36713 .57955 L F
.588 .944 .813 r
.36167 .58182 m .36494 .57986 L .36292 .58031 L F
0 0 0 r
.36292 .58031 m .36494 .57986 L .36361 .58019 L F
.982 .699 .331 r
.36494 .57986 m .36548 .57972 L .36492 .57873 L F
.028 0 .455 r
.58508 .35085 m .58424 .35522 L .58624 .353 L F
0 .004 .515 r
.58424 .35522 m .58642 .3556 L .58624 .353 L F
.58424 .35522 m .58484 .35784 L .58642 .3556 L F
.011 .485 .871 r
.60124 .36019 m .60274 .36148 L .60054 .36081 L F
0 0 .384 r
.51116 .40839 m .51227 .40521 L .51028 .40492 L F
.51116 .40839 m .51281 .40645 L .51227 .40521 L F
.849 .865 .853 r
.50017 .47451 m .50434 .47328 L .50278 .47186 L F
.834 .906 .888 r
.50278 .47186 m .50434 .47328 L .50748 .47006 L F
0 0 0 r
.39463 .55942 m .3937 .56144 L .3942 .55988 L F
.39463 .55942 m .3942 .55988 L .39481 .55795 L F
.39463 .55942 m .39481 .55795 L .39377 .55694 L F
.125 0 .166 r
.38988 .5573 m .39463 .55942 L .39377 .55694 L F
0 .422 .722 r
.39276 .55844 m .39493 .5591 L .39463 .55942 L F
.39493 .5591 m .39651 .55959 L .39463 .55942 L F
.654 .736 .91 r
.59418 .35034 m .59118 .35199 L .59068 .35008 L F
.22 0 .029 r
.40221 .47615 m .40472 .47542 L .40593 .47311 L F
.263 0 .151 r
.40472 .47542 m .40824 .47176 L .40593 .47311 L F
.914 .956 .805 r
.60645 .34979 m .60587 .35301 L .60833 .35144 L F
.135 0 .032 r
.34669 .49632 m .34327 .49896 L .34443 .49723 L F
.953 .93 .587 r
.34443 .49723 m .3425 .49878 L .34327 .49896 L F
.135 0 .032 r
.34669 .49632 m .34327 .49896 L .34443 .49723 L F
0 .281 .668 r
.56958 .37753 m .57083 .37813 L .56779 .37658 L F
.832 .546 .506 r
.3937 .56144 m .39373 .5646 L .39002 .56382 L F
.457 0 .025 r
.52072 .43858 m .51788 .43775 L .51805 .43801 L F
.52072 .43858 m .51998 .4377 L .51788 .43775 L F
.743 .729 .839 r
.33522 .66883 m .33938 .66914 L .33799 .66577 L F
.772 .743 .826 r
.33938 .66914 m .34251 .6663 L .33799 .66577 L F
.785 .941 .592 r
.43116 .55478 m .42938 .55644 L .42872 .5585 L F
.79 .962 .647 r
.42872 .5585 m .42938 .55644 L .42685 .55995 L F
.97 .654 .302 r
.65566 .35757 m .65598 .36017 L .6576 .36136 L F
.544 .044 0 r
.65829 .36224 m .6576 .36136 L .65598 .36017 L F
.65829 .36224 m .65863 .36257 L .6576 .36136 L F
0 0 0 r
.31086 .61849 m .30704 .62155 L .31003 .62089 L F
.305 0 .199 r
.31366 .61917 m .31086 .61849 L .31003 .62089 L F
.658 .13 0 r
.55064 .39161 m .5494 .39204 L .54682 .39072 L F
.497 .845 .995 r
.55332 .39217 m .5494 .39204 L .55064 .39161 L F
.554 .229 .373 r
.51874 .39226 m .52143 .39419 L .52179 .39207 L F
.247 .299 .72 r
.52082 .38997 m .52143 .39419 L .51874 .39226 L F
.348 .293 .654 r
.51874 .39226 m .52143 .39419 L .51943 .39499 L F
.51874 .39226 m .52143 .39419 L .51943 .39499 L F
0 0 .322 r
.52022 .39902 m .52143 .39419 L .51943 .39499 L F
.52022 .39902 m .52153 .39703 L .52123 .39498 L F
.675 .977 .853 r
.52022 .39902 m .51722 .40013 L .52153 .39703 L F
.506 .229 .427 r
.51963 .39871 m .52179 .39877 L .52153 .39703 L F
.52179 .39877 m .52412 .39882 L .52153 .39703 L F
0 0 .322 r
.52123 .39498 m .52153 .39703 L .52143 .39419 L F
0 0 0 r
.43367 .55129 m .43238 .55337 L .43116 .55478 L F
.552 .853 .54 r
.43116 .55478 m .43238 .55337 L .42938 .55644 L F
.897 .478 .12 r
.6401 .35179 m .64112 .35559 L .63892 .35261 L F
.867 .446 .215 r
.64323 .35506 m .64112 .35559 L .6401 .35179 L F
.547 .841 .998 r
.37065 .4868 m .36618 .48674 L .36741 .48536 L F
.67 .285 .307 r
.37065 .4868 m .36582 .48874 L .36618 .48674 L F
.37065 .4868 m .36943 .489 L .36582 .48874 L F
.653 .265 .298 r
.37065 .4868 m .37285 .48913 L .36943 .489 L F
.874 .479 .282 r
.41147 .56764 m .41557 .57059 L .41395 .56794 L F
.41147 .56764 m .41198 .57023 L .41557 .57059 L F
.936 .786 .67 r
.41111 .573 m .41557 .57059 L .41198 .57023 L F
.41111 .573 m .4133 .57425 L .41557 .57059 L F
0 0 0 r
.60907 .39377 m .61067 .39309 L .60699 .39464 L F
.60907 .39377 m .60699 .39464 L .60603 .3949 L F
.483 .797 .999 r
.40079 .57834 m .40334 .57781 L .40162 .5765 L F
.788 .914 .925 r
.56952 .36732 m .57117 .3637 L .57233 .36477 L F
.56952 .36732 m .56795 .36616 L .57117 .3637 L F
.4 0 .003 r
.63079 .3888 m .62946 .39054 L .62695 .39062 L F
.779 .414 0 r
.63079 .3888 m .63188 .39193 L .63366 .38829 L F
.82 .635 .651 r
.63366 .38829 m .62946 .39054 L .63079 .3888 L F
.424 .485 .819 r
.39581 .56407 m .39511 .56832 L .39373 .5646 L F
.39581 .56407 m .39666 .56784 L .39511 .56832 L F
.307 .128 .466 r
.39666 .56784 m .39616 .57137 L .39511 .56832 L F
.791 .774 .837 r
.46898 .50657 m .47284 .50695 L .47193 .5035 L F
.901 .827 .764 r
.47193 .5035 m .47284 .50695 L .47365 .5044 L F
.285 0 .152 r
.53652 .36553 m .53309 .36709 L .53352 .36561 L F
.857 .799 .792 r
.4947 .45984 m .49022 .46175 L .49292 .4584 L F
.4947 .45984 m .49214 .46345 L .49022 .46175 L F
.835 .857 .862 r
.49775 .45648 m .4947 .45984 L .49292 .4584 L F
.598 .853 .992 r
.36104 .56083 m .36163 .56124 L .35986 .55859 L F
.988 .722 .413 r
.64353 .35841 m .64142 .35594 L .64323 .35506 L F
.64142 .35594 m .64139 .35659 L .64112 .35559 L F
.64353 .35841 m .64139 .35659 L .64142 .35594 L F
.988 .888 .621 r
.64353 .35841 m .6409 .35989 L .64139 .35659 L F
0 0 .319 r
.64139 .35659 m .64093 .3597 L .64124 .35933 L F
.904 .556 .371 r
.64343 .35725 m .64423 .35974 L .64375 .35715 L F
0 0 .319 r
.64139 .35659 m .64124 .35933 L .64341 .35676 L F
.64093 .3597 m .6409 .35989 L .64351 .35663 L F
.988 .888 .621 r
.64353 .35841 m .6421 .36144 L .6409 .35989 L F
0 0 .319 r
.64093 .3597 m .6409 .35989 L .6409 .35989 L F
.688 .966 .745 r
.6409 .35989 m .6391 .36074 L .64351 .35663 L F
0 0 .319 r
.6434 .35663 m .64341 .35676 L .64351 .35663 L F
.799 .83 .875 r
.64351 .35663 m .6391 .36074 L .6377 .35871 L F
.904 .556 .371 r
.64102 .35799 m .64351 .35935 L .64343 .35725 L F
.64351 .35935 m .64423 .35974 L .64343 .35725 L F
0 0 .319 r
.64139 .35659 m .64341 .35676 L .6434 .35663 L F
.988 .722 .413 r
.64142 .35594 m .64112 .35559 L .64148 .3555 L F
.64142 .35594 m .64148 .3555 L .64323 .35506 L F
.225 .745 .775 r
.56909 .39514 m .56674 .39548 L .56469 .39592 L F
.139 0 0 r
.56909 .39514 m .5698 .39551 L .56674 .39548 L F
.56909 .39514 m .57125 .39539 L .5698 .39551 L F
.691 .919 .97 r
.42732 .54555 m .43085 .54381 L .43235 .54496 L F
.593 .881 .992 r
.43085 .54381 m .43479 .5438 L .43235 .54496 L F
.578 .638 .875 r
.43235 .54496 m .43496 .54555 L .43504 .54499 L F
.842 .928 .887 r
.45782 .52294 m .46236 .52087 L .45999 .51929 L F
.49 .078 .185 r
.41759 .57111 m .41705 .57151 L .41992 .57116 L F
.048 .267 .762 r
.52831 .41704 m .52815 .41891 L .52698 .41676 L F
.896 .946 .588 r
.5267 .42048 m .52815 .41891 L .52831 .41704 L F
.552 .903 .686 r
.63616 .34864 m .63711 .34752 L .63873 .34753 L F
.13 0 .165 r
.38881 .55916 m .38988 .5573 L .38944 .55808 L F
.683 .72 .878 r
.64386 .33865 m .64868 .3395 L .64693 .33788 L F
.53 .863 .994 r
.65119 .33803 m .64693 .33788 L .64868 .3395 L F
.15 0 .006 r
.44814 .4421 m .45074 .44168 L .45154 .43963 L F
0 0 0 r
.45154 .43963 m .45259 .44036 L .45358 .43806 L F
.45154 .43963 m .45074 .44168 L .45259 .44036 L F
.424 .792 .995 r
.54776 .38431 m .54348 .3836 L .54547 .38493 L F
0 0 .081 r
.54547 .38493 m .54582 .388 L .54776 .38431 L F
.13 0 .165 r
.38881 .55916 m .39055 .55962 L .38988 .5573 L F
.125 0 .166 r
.38988 .5573 m .39276 .55844 L .39463 .55942 L F
.38988 .5573 m .39055 .55962 L .39276 .55844 L F
0 0 0 r
.35303 .554 m .35072 .55813 L .35218 .55618 L F
.653 .469 .622 r
.3485 .55958 m .35218 .55618 L .35072 .55813 L F
0 0 .195 r
.43496 .54555 m .43492 .54966 L .43367 .55129 L F
.562 .811 .434 r
.43367 .55129 m .43363 .55133 L .43238 .55337 L F
.43367 .55129 m .43492 .54966 L .43363 .55133 L F
.684 .979 .838 r
.34327 .49896 m .3425 .49878 L .34152 .50064 L F
.552 0 0 r
.31055 .63359 m .31166 .63187 L .30974 .63161 L F
.618 .665 .873 r
.31166 .63187 m .31434 .62872 L .31256 .62867 L F
.31166 .63187 m .31674 .63201 L .31434 .62872 L F
.205 0 0 r
.31413 .63252 m .31674 .63201 L .31166 .63187 L F
.788 .719 .788 r
.32545 .67285 m .33018 .67317 L .32827 .67218 L F
.875 .889 .84 r
.32827 .67218 m .33018 .67317 L .33275 .66989 L F
0 0 .481 r
.49472 .42582 m .49642 .4284 L .49512 .42926 L F
.296 0 .198 r
.49695 .43077 m .49512 .42926 L .49642 .4284 L F
.49695 .43077 m .49434 .43158 L .49512 .42926 L F
.533 .024 0 r
.60872 .38578 m .61156 .38725 L .60731 .38715 L F
.71 .968 .728 r
.49066 .4064 m .48924 .4074 L .49217 .40455 L F
.928 .927 .786 r
.49214 .46345 m .48882 .46456 L .49022 .46175 L F
.49214 .46345 m .48983 .46711 L .48882 .46456 L F
0 .332 .801 r
.33019 .62043 m .33009 .62136 L .32781 .61826 L F
.33019 .62043 m .33152 .62209 L .33009 .62136 L F
0 0 0 r
.61135 .3979 m .6146 .39661 L .61321 .39742 L F
.02 0 0 r
.61321 .39742 m .6146 .39661 L .61694 .39638 L F
.993 .752 .457 r
.60541 .34313 m .60707 .34803 L .60719 .34509 L F
.607 .809 .978 r
.60957 .3438 m .60719 .34509 L .60541 .34313 L F
.363 .198 .518 r
.60957 .3438 m .60707 .34803 L .60719 .34509 L F
.718 .834 .387 r
.59551 .39191 m .59753 .38735 L .5972 .38981 L F
0 0 .206 r
.5972 .38981 m .59595 .39331 L .59551 .39191 L F
0 0 .541 r
.58963 .37798 m .58893 .37384 L .58852 .37572 L F
.984 .705 .401 r
.4938 .42406 m .49468 .42549 L .49527 .42383 L F
0 0 .41 r
.49535 .42657 m .49472 .42582 L .49527 .42383 L F
.984 .705 .401 r
.49468 .42549 m .49535 .42657 L .49527 .42383 L F
.707 .757 .256 r
.49585 .42222 m .49527 .42383 L .49472 .42582 L F
.49609 .42145 m .49527 .42383 L .49585 .42222 L F
0 0 .41 r
.49535 .42657 m .49642 .4284 L .49472 .42582 L F
.176 0 0 r
.52302 .43745 m .52383 .4358 L .51998 .4377 L F
.807 .923 .539 r
.52585 .43136 m .52383 .4358 L .52502 .43405 L F
0 0 0 r
.52502 .43405 m .52383 .4358 L .52302 .43745 L F
.362 .52 .879 r
.60887 .37691 m .60743 .37846 L .60537 .37517 L F
.244 .335 .759 r
.60887 .37691 m .61032 .38005 L .60743 .37846 L F
.531 .355 .588 r
.33565 .55088 m .33781 .55137 L .33863 .54756 L F
.87 .559 .457 r
.41956 .54303 m .42376 .54232 L .41936 .54025 L F
.41956 .54303 m .42318 .54375 L .42376 .54232 L F
.555 .888 .987 r
.60252 .3405 m .604 .33866 L .60532 .33972 L F
.60252 .3405 m .60118 .33971 L .604 .33866 L F
0 0 0 r
.35303 .554 m .35218 .55618 L .3515 .55341 L F
.921 .677 .553 r
.34582 .65245 m .34394 .64872 L .34263 .65222 L F
.892 .743 .69 r
.34394 .65607 m .34582 .65245 L .34263 .65222 L F
.268 0 .137 r
.40542 .48729 m .40472 .48896 L .40246 .4892 L F
.2 .712 .89 r
.40472 .48896 m .40051 .4887 L .40246 .4892 L F
.674 .52 .668 r
.28813 .56737 m .28989 .57146 L .29235 .56784 L F
.902 .885 .806 r
.44989 .5334 m .4473 .53708 L .4501 .53631 L F
.351 0 .129 r
.54776 .38431 m .55141 .38154 L .54807 .38119 L F
.54776 .38431 m .55049 .38377 L .55141 .38154 L F
.424 .118 .341 r
.55141 .38154 m .55413 .3822 L .55455 .38017 L F
.737 .58 .68 r
.55049 .38377 m .55413 .3822 L .55141 .38154 L F
.532 .251 .434 r
.56571 .38496 m .56921 .38459 L .56954 .38138 L F
.175 0 .338 r
.56954 .38138 m .57123 .38311 L .57189 .38024 L F
.56954 .38138 m .56921 .38459 L .57123 .38311 L F
.783 .998 .852 r
.65747 .371 m .66032 .36718 L .65707 .37009 L F
.65747 .371 m .66094 .36791 L .66032 .36718 L F
.35 0 0 r
.38511 .48182 m .38793 .48184 L .38975 .48047 L F
.361 0 0 r
.38793 .48184 m .39199 .48104 L .38975 .48047 L F
.257 0 0 r
.38975 .48047 m .39199 .48104 L .39263 .48035 L F
.863 .876 .846 r
.45607 .49633 m .45256 .49635 L .45536 .49309 L F
.876 .858 .82 r
.45607 .49633 m .4532 .49999 L .45256 .49635 L F
.875 .882 .836 r
.45881 .4925 m .45607 .49633 L .45536 .49309 L F
0 0 .139 r
.47513 .43877 m .47568 .43606 L .47697 .43461 L F
.444 .155 .379 r
.44176 .44863 m .445 .4457 L .44225 .44666 L F
.62 .549 .753 r
.52414 .37029 m .52574 .36609 L .52248 .36893 L F
.334 .71 .983 r
.61032 .38005 m .6142 .38132 L .61159 .38133 L F
.597 .317 .462 r
.41217 .53501 m .41298 .53424 L .41481 .53541 L F
.949 .928 .748 r
.41481 .53541 m .41304 .53442 L .41217 .53501 L F
.41481 .53541 m .41485 .53524 L .41304 .53442 L F
.523 .204 .368 r
.40795 .48659 m .40472 .48896 L .40542 .48729 L F
.556 .477 .722 r
.30565 .62888 m .30698 .62404 L .30549 .62818 L F
0 0 0 r
.52081 .37332 m .52414 .37029 L .52112 .37174 L F
.836 .638 .635 r
.34039 .54986 m .34473 .54781 L .34049 .5479 L F
.34039 .54986 m .34448 .55057 L .34473 .54781 L F
.305 0 .171 r
.39889 .4786 m .40221 .47615 L .39975 .47711 L F
.793 .638 .69 r
.33868 .54341 m .34049 .5479 L .34111 .54457 L F
.766 .888 .932 r
.31666 .67139 m .31871 .6725 L .32054 .67072 L F
.637 .622 .819 r
.31871 .6725 m .32357 .67467 L .32054 .67072 L F
.923 .961 .785 r
.6017 .36605 m .6045 .36518 L .60359 .36436 L F
.6017 .36605 m .60234 .36851 L .6045 .36518 L F
.762 .994 .804 r
.60567 .36277 m .6045 .36518 L .60696 .36264 L F
.73 .976 .922 r
.60567 .36277 m .60359 .36436 L .6045 .36518 L F
.938 .815 .362 r
.60145 .36915 m .60234 .36851 L .6017 .36605 L F
.60145 .36915 m .60185 .37102 L .60234 .36851 L F
.305 .514 .894 r
.30652 .66773 m .30765 .67022 L .30851 .66775 L F
.434 .66 .956 r
.30765 .67022 m .31028 .67018 L .30851 .66775 L F
.843 .84 .842 r
.4532 .49999 m .44989 .49946 L .45256 .49635 L F
.899 .777 .717 r
.4532 .49999 m .44899 .50218 L .44989 .49946 L F
.4532 .49999 m .45116 .50356 L .44899 .50218 L F
.611 .614 .829 r
.32054 .67072 m .32357 .67467 L .32545 .67285 L F
0 0 0 r
.54171 .4247 m .54303 .42304 L .53979 .42552 L F
.546 0 0 r
.37334 .5457 m .37031 .54504 L .37075 .54633 L F
.546 .812 .995 r
.32345 .62101 m .32553 .62246 L .32216 .62319 L F
.598 .853 .992 r
.36104 .56083 m .3576 .5613 L .36163 .56124 L F
.75 .359 .311 r
.3576 .5613 m .36267 .56412 L .36163 .56124 L F
.266 0 .145 r
.52869 .35852 m .53067 .35934 L .53046 .35658 L F
.037 0 0 r
.53046 .35658 m .53339 .3565 L .53483 .35596 L F
.185 0 .193 r
.53046 .35658 m .53067 .35934 L .53339 .3565 L F
.348 0 0 r
.37844 .48323 m .38236 .48221 L .3798 .48257 L F
.176 0 0 r
.52302 .43745 m .51998 .4377 L .52072 .43858 L F
.674 .759 .915 r
.63748 .33824 m .64124 .33924 L .64091 .33772 L F
.684 .698 .858 r
.64091 .33772 m .64124 .33924 L .64386 .33865 L F
.959 .922 .725 r
.48983 .46711 m .48749 .46784 L .48882 .46456 L F
.875 .889 .84 r
.32827 .67218 m .33275 .66989 L .3274 .66969 L F
.665 .923 .975 r
.33275 .66989 m .33522 .66883 L .33344 .66793 L F
.666 .924 .974 r
.32867 .66932 m .33275 .66989 L .33344 .66793 L F
.3283 .66972 m .33275 .66989 L .32867 .66932 L F
.738 .866 .94 r
.3274 .66969 m .33344 .66793 L .32929 .66801 L F
.338 .384 .763 r
.32908 .66887 m .32853 .67229 L .32827 .67218 L F
.32929 .66801 m .32915 .66879 L .32908 .66887 L F
.32915 .66879 m .32853 .67229 L .32908 .66887 L F
.666 .924 .974 r
.3274 .66969 m .3283 .66972 L .32867 .66932 L F
.902 .955 .823 r
.41304 .53442 m .41485 .53524 L .41801 .53049 L F
.038 0 0 r
.47513 .43877 m .47173 .44125 L .4727 .43985 L F
.634 .801 .963 r
.63398 .33775 m .63459 .3392 L .63748 .33824 L F
.864 .722 .704 r
.44139 .52378 m .43705 .52618 L .43975 .52256 L F
.44139 .52378 m .43964 .52742 L .43705 .52618 L F
.909 .891 .801 r
.44363 .52011 m .44139 .52378 L .43975 .52256 L F
.611 .144 0 r
.37477 .57906 m .37436 .57871 L .37131 .57757 L F
.37477 .57906 m .37576 .58041 L .37436 .57871 L F
.134 0 0 r
.64223 .33727 m .64569 .33638 L .64675 .33467 L F
0 .199 .705 r
.64871 .33532 m .64986 .33694 L .64675 .33467 L F
0 .136 .593 r
.64675 .33467 m .64982 .33691 L .65119 .33803 L F
.64982 .33691 m .64986 .33694 L .64996 .33703 L F
.64982 .33691 m .64996 .33703 L .65119 .33803 L F
.574 .814 .989 r
.64693 .33788 m .64838 .33578 L .64569 .33638 L F
.64838 .33578 m .64871 .33532 L .64808 .33554 L F
.64838 .33578 m .64808 .33554 L .64569 .33638 L F
0 .199 .705 r
.64871 .33532 m .64675 .33467 L .64569 .33638 L F
.828 .818 .84 r
.63108 .37214 m .62632 .37414 L .62979 .37097 L F
.702 .305 .291 r
.46661 .44218 m .46566 .44268 L .46825 .44086 L F
.46661 .44218 m .46581 .44526 L .46566 .44268 L F
.46661 .44218 m .46865 .44451 L .46581 .44526 L F
.46661 .44218 m .46992 .44302 L .46865 .44451 L F
.737 .862 .939 r
.4825 .48931 m .48658 .48923 L .48558 .48619 L F
.827 .808 .832 r
.48558 .48619 m .48658 .48923 L .48935 .48647 L F
0 0 0 r
.46985 .42631 m .46865 .42782 L .47194 .42496 L F
.28 .019 .328 r
.41764 .48035 m .41738 .48258 L .4151 .48359 L F
.359 .041 .283 r
.42062 .47897 m .41738 .48258 L .41764 .48035 L F
.219 0 .201 r
.44814 .4421 m .4499 .44382 L .45074 .44168 L F
.44814 .4421 m .44755 .44476 L .4499 .44382 L F
.352 .059 .32 r
.42693 .47317 m .42642 .47549 L .42375 .47622 L F
.399 .099 .336 r
.42906 .47471 m .42693 .47317 L .42957 .4725 L F
.42906 .47471 m .42642 .47549 L .42693 .47317 L F
.737 .81 .909 r
.47082 .48283 m .46718 .48278 L .46918 .4823 L F
.828 .753 .781 r
.4721 .48069 m .47082 .48283 L .46918 .4823 L F
0 0 0 r
.46865 .44451 m .46992 .44302 L .47173 .44125 L F
.896 .62 .512 r
.57207 .36207 m .57084 .36182 L .5688 .35752 L F
.839 .43 .266 r
.57207 .36207 m .57117 .3637 L .57084 .36182 L F
.525 0 0 r
.57117 .3637 m .56998 .3633 L .56688 .36097 L F
.645 .958 .931 r
.57117 .3637 m .56998 .3633 L .57008 .36325 L F
.993 .764 .395 r
.57225 .36392 m .57117 .3637 L .57207 .36207 L F
.57227 .36416 m .57117 .3637 L .57225 .36392 L F
.652 .969 .885 r
.57117 .3637 m .56915 .36366 L .56965 .36339 L F
.66 .536 .702 r
.57491 .36154 m .57233 .36477 L .57207 .36207 L F
.525 0 0 r
.57117 .3637 m .56866 .35975 L .57084 .36182 L F
.57117 .3637 m .56688 .36097 L .56866 .35975 L F
.645 .958 .931 r
.57117 .3637 m .57008 .36325 L .57286 .36164 L F
.469 .265 .52 r
.56688 .36097 m .56998 .3633 L .56992 .36094 L F
.588 .506 .73 r
.5688 .35752 m .57084 .36182 L .56866 .35975 L F
.479 .273 .521 r
.56992 .36094 m .56998 .3633 L .57286 .36164 L F
.652 .969 .885 r
.57117 .3637 m .56965 .36339 L .57286 .36164 L F
.993 .764 .395 r
.57233 .36477 m .57117 .3637 L .57227 .36416 L F
.78 .601 .657 r
.3262 .61147 m .33062 .61176 L .32821 .6127 L F
.656 .629 .81 r
.32821 .6127 m .32346 .61244 L .3262 .61147 L F
.623 .138 .081 r
.32916 .61371 m .33062 .61176 L .3262 .61147 L F
.739 .278 .154 r
.32916 .61371 m .33328 .61455 L .33062 .61176 L F
.642 .468 .632 r
.41705 .57151 m .41714 .57447 L .41992 .57116 L F
.822 .816 .843 r
.48848 .48315 m .48558 .48619 L .48935 .48647 L F
.863 .835 .818 r
.48848 .48315 m .48935 .48647 L .492 .48281 L F
.684 .231 .172 r
.65036 .34968 m .65266 .35023 L .64984 .34807 L F
.605 .321 .46 r
.64984 .34807 m .65266 .35023 L .65276 .34792 L F
.659 .859 .976 r
.57125 .39539 m .57562 .3954 L .57457 .39494 L F
.589 .849 .497 r
.57713 .39341 m .57562 .3954 L .57844 .392 L F
.635 .956 .93 r
.57713 .39341 m .57457 .39494 L .57562 .3954 L F
0 .425 .829 r
.52831 .41704 m .52698 .41676 L .52531 .41543 L F
.326 .793 .687 r
.60788 .39941 m .61135 .3979 L .61072 .39844 L F
0 0 0 r
.61321 .39742 m .61072 .39844 L .61135 .3979 L F
.691 .876 .968 r
.51684 .4181 m .51396 .41913 L .51622 .41808 L F
.111 0 0 r
.51348 .42061 m .51622 .41808 L .51396 .41913 L F
.702 .218 .095 r
.53188 .42564 m .5353 .4261 L .53375 .42501 L F
.94 .841 .718 r
.44363 .52011 m .44203 .51918 L .44317 .51676 L F
.909 .891 .801 r
.44363 .52011 m .43975 .52256 L .44203 .51918 L F
.055 .207 .705 r
.3624 .57467 m .36357 .57608 L .36199 .57627 L F
.406 .4 .74 r
.36713 .57955 m .36494 .57986 L .36199 .57627 L F
0 0 0 r
.49867 .41822 m .50116 .41465 L .50083 .41695 L F
.4988 .41833 m .49867 .41822 L .50083 .41695 L F
.736 .945 .95 r
.44072 .53457 m .43792 .53599 L .4354 .53578 L F
.498 .169 .34 r
.4151 .48359 m .41167 .48575 L .41207 .48356 L F
0 0 .124 r
.51815 .37764 m .52083 .37594 L .52081 .37332 L F
0 0 0 r
.52081 .37332 m .52252 .37307 L .52414 .37029 L F
0 0 .081 r
.52081 .37332 m .52177 .37431 L .52252 .37307 L F
.52081 .37332 m .52083 .37594 L .52177 .37431 L F
.92 .525 .195 r
.33977 .63148 m .33883 .62819 L .33671 .62708 L F
.493 .857 .988 r
.50822 .44815 m .51225 .44813 L .51157 .44694 L F
.931 .594 .15 r
.51164 .44736 m .51238 .44839 L .51174 .44716 L F
.51153 .44756 m .51186 .44793 L .51164 .44736 L F
.51153 .44756 m .51174 .44716 L .51252 .44813 L F
.51174 .44716 m .51235 .44822 L .51225 .44618 L F
.51235 .44822 m .51275 .44892 L .51267 .44847 L F
.51235 .44822 m .51267 .44847 L .51225 .44618 L F
.493 .857 .988 r
.51225 .44813 m .51153 .44756 L .51252 .44813 L F
.50822 .44815 m .51153 .44756 L .51225 .44813 L F
.931 .594 .15 r
.51174 .44716 m .51225 .44618 L .51252 .44813 L F
.493 .857 .988 r
.50954 .44439 m .51157 .44694 L .50977 .44375 L F
.50822 .44815 m .51157 .44694 L .50954 .44439 L F
.51225 .44813 m .51252 .44813 L .511 .44572 L F
.51225 .44813 m .511 .44572 L .50977 .44375 L F
.931 .594 .15 r
.51238 .44839 m .51275 .44892 L .51174 .44716 L F
.51186 .44793 m .51275 .44892 L .51164 .44736 L F
.976 .672 .354 r
.51008 .44333 m .51252 .44813 L .51108 .44199 L F
.50977 .44375 m .511 .44572 L .51008 .44333 L F
.511 .44572 m .51252 .44813 L .51008 .44333 L F
.811 .524 0 r
.51108 .44199 m .51252 .44813 L .51225 .44618 L F
.702 .653 .798 r
.51108 .44199 m .51225 .44618 L .51491 .44319 L F
.939 .597 .171 r
.51225 .44618 m .51275 .44892 L .51442 .4475 L F
.9 .761 .698 r
.41722 .56178 m .41301 .56047 L .41557 .55917 L F
.41722 .56178 m .41284 .56373 L .41301 .56047 L F
.402 0 0 r
.41722 .56178 m .41203 .56514 L .41284 .56373 L F
.41722 .56178 m .41504 .56493 L .41203 .56514 L F
0 0 0 r
.41951 .55982 m .41722 .56178 L .41557 .55917 L F
.41951 .55982 m .4183 .56181 L .41722 .56178 L F
.4183 .56181 m .41504 .56493 L .41722 .56178 L F
.828 .753 .781 r
.4721 .48069 m .46918 .4823 L .47061 .47967 L F
.185 0 .226 r
.43959 .44975 m .43892 .45191 L .44176 .44863 L F
.923 .848 .752 r
.41338 .52986 m .41298 .53424 L .4108 .53365 L F
.597 .317 .462 r
.41217 .53501 m .4108 .53365 L .41298 .53424 L F
.744 .915 .95 r
.40468 .54964 m .40214 .55106 L .40148 .54924 L F
.995 .794 .521 r
.40214 .55106 m .40017 .5526 L .40148 .54924 L F
.40214 .55106 m .40165 .55384 L .40017 .5526 L F
.823 .527 .489 r
.40214 .55106 m .40536 .55428 L .40165 .55384 L F
.846 .745 .752 r
.49643 .45258 m .49775 .45648 L .49544 .45514 L F
.835 .857 .862 r
.49775 .45648 m .49292 .4584 L .49544 .45514 L F
.263 0 .152 r
.44708 .46086 m .44516 .46011 L .44793 .45953 L F
.44708 .46086 m .44449 .46179 L .44516 .46011 L F
.492 .8 .999 r
.60532 .33972 m .60826 .33916 L .60956 .34041 L F
.347 0 0 r
.60826 .33916 m .61228 .34027 L .60956 .34041 L F
0 .386 .804 r
.59982 .34532 m .60107 .34518 L .59843 .34338 L F
.59982 .34532 m .60381 .34723 L .60107 .34518 L F
.454 .885 .851 r
.53979 .42552 m .53487 .42676 L .53823 .42668 L F
0 0 0 r
.5403 .42551 m .53979 .42552 L .53823 .42668 L F
.5403 .42551 m .54171 .4247 L .53979 .42552 L F
.872 .874 .835 r
.3372 .66177 m .34042 .66217 L .33955 .65898 L F
.912 .803 .726 r
.33799 .66577 m .34042 .66217 L .3372 .66177 L F
.841 .861 .858 r
.33955 .65898 m .34042 .66217 L .34321 .65859 L F
.096 .631 .861 r
.37576 .58041 m .37985 .5811 L .3786 .58058 L F
.583 .929 .951 r
.3786 .58058 m .37985 .5811 L .38279 .57973 L F
0 0 0 r
.46331 .43217 m .46504 .43074 L .46669 .4293 L F
.085 0 0 r
.46504 .43074 m .46865 .42782 L .46669 .4293 L F
0 0 0 r
.57965 .38978 m .57844 .392 L .58027 .3879 L F
.682 .884 .51 r
.57965 .38978 m .57713 .39341 L .57844 .392 L F
.736 .945 .95 r
.44072 .53457 m .4354 .53578 L .43863 .53294 L F
.495 .89 .734 r
.52053 .39381 m .51943 .39499 L .52143 .39419 L F
.52053 .39381 m .51674 .39613 L .51943 .39499 L F
.804 .781 .831 r
.47677 .4763 m .47285 .47607 L .4758 .47294 L F
.822 .79 .822 r
.4796 .47304 m .47677 .4763 L .4758 .47294 L F
.02 0 0 r
.52683 .38189 m .52584 .38397 L .5244 .38413 L F
0 0 0 r
.52811 .38243 m .52584 .38397 L .52683 .38189 L F
.87 .746 .724 r
.5263 .38086 m .52584 .38397 L .52811 .38243 L F
.5263 .38086 m .52727 .38381 L .52584 .38397 L F
.52727 .38381 m .52775 .38527 L .52584 .38397 L F
.02 0 0 r
.5244 .38413 m .52584 .38397 L .52412 .3844 L F
.028 0 .455 r
.58508 .35085 m .58624 .353 L .58609 .35033 L F
.708 .599 .732 r
.33863 .54756 m .34049 .5479 L .33868 .54341 L F
.454 .284 .559 r
.33863 .54756 m .34039 .54986 L .34049 .5479 L F
.793 .911 .921 r
.66094 .36791 m .66309 .36371 L .66032 .36718 L F
.66094 .36791 m .66441 .36528 L .66309 .36371 L F
.449 .148 .361 r
.49532 .40196 m .49806 .40166 L .49895 .39852 L F
0 0 .109 r
.49895 .39852 m .49806 .40166 L .49966 .39978 L F
.49806 .40166 m .49836 .40146 L .49998 .39941 L F
.847 .998 .809 r
.49881 .40101 m .49835 .39988 L .49916 .39907 L F
.767 .89 .932 r
.49998 .39941 m .49836 .40146 L .49868 .40169 L F
0 0 0 r
.49806 .40166 m .49836 .40146 L .49857 .40161 L F
.49532 .40196 m .49867 .4016 L .49868 .40169 L F
.767 .89 .932 r
.49836 .40146 m .49798 .40195 L .49868 .40169 L F
0 0 0 r
.49857 .40161 m .49861 .40129 L .49867 .4016 L F
.49836 .40146 m .49861 .40129 L .49857 .40161 L F
.847 .998 .809 r
.49868 .40169 m .49861 .40129 L .49881 .40101 L F
.49861 .40129 m .49835 .39988 L .49881 .40101 L F
0 0 .109 r
.49994 .39938 m .49966 .39978 L .49998 .39941 L F
.49895 .39852 m .49966 .39978 L .49994 .39938 L F
.49806 .40166 m .49798 .40195 L .49836 .40146 L F
0 0 0 r
.49532 .40196 m .49792 .40017 L .49861 .40129 L F
.49792 .40017 m .49836 .39997 L .49861 .40129 L F
.49532 .40196 m .49861 .40129 L .49806 .40166 L F
.352 0 .012 r
.49868 .40169 m .49798 .40195 L .49532 .40196 L F
.449 .148 .361 r
.49532 .40196 m .49798 .40195 L .49806 .40166 L F
0 0 0 r
.4949 .40411 m .49766 .40279 L .49904 .39966 L F
.49859 .39987 m .49904 .39966 L .49931 .39904 L F
.4949 .40411 m .49904 .39966 L .49859 .39987 L F
.49792 .40017 m .49835 .39988 L .49836 .39997 L F
.588 .939 .932 r
.49895 .39852 m .50021 .39725 L .50084 .39729 L F
0 0 .109 r
.49895 .39852 m .49998 .39941 L .50021 .39725 L F
.772 .646 .724 r
.41147 .56764 m .41395 .56794 L .41638 .56577 L F
.375 .061 .299 r
.41638 .56577 m .41395 .56794 L .41845 .5644 L F
.953 .723 .553 r
.60645 .34979 m .60833 .35144 L .60707 .34803 L F
.919 .647 .51 r
.34196 .63506 m .34223 .63201 L .33977 .63148 L F
.56 .041 0 r
.34597 .63555 m .34223 .63201 L .34196 .63506 L F
.863 .835 .818 r
.48848 .48315 m .492 .48281 L .49024 .48127 L F
.874 .888 .841 r
.49024 .48127 m .492 .48281 L .4946 .47966 L F
.813 .611 .629 r
.34148 .63802 m .34597 .63555 L .34196 .63506 L F
.34148 .63802 m .34549 .63785 L .34597 .63555 L F
.212 0 .016 r
.4103 .57448 m .40897 .57692 L .40626 .57777 L F
.427 .766 .996 r
.4103 .57448 m .4133 .57425 L .41111 .573 L F
0 0 0 r
.40995 .57587 m .4103 .57448 L .41111 .573 L F
.40995 .57587 m .40897 .57692 L .4103 .57448 L F
.834 .906 .888 r
.50278 .47186 m .50748 .47006 L .50597 .46875 L F
.891 .916 .835 r
.50597 .46875 m .50748 .47006 L .51018 .46654 L F
.479 .551 .852 r
.41642 .52371 m .42073 .52713 L .42188 .52353 L F
.537 .359 .588 r
.42188 .52353 m .42073 .52713 L .42196 .52382 L F
.53 .863 .994 r
.65119 .33803 m .64986 .33694 L .64693 .33788 L F
.611 .901 .986 r
.65119 .33803 m .65276 .33569 L .65387 .33694 L F
.65119 .33803 m .64986 .33694 L .65276 .33569 L F
.65119 .33803 m .65276 .33569 L .65387 .33694 L F
.65119 .33803 m .64986 .33694 L .65276 .33569 L F
.269 .758 .674 r
.50021 .39725 m .50508 .39539 L .50084 .39729 L F
.50037 .39718 m .50172 .39664 L .50508 .39539 L F
.132 0 .079 r
.50172 .39664 m .50442 .39695 L .50425 .39563 L F
.565 .932 .797 r
.50508 .39539 m .50172 .39664 L .50389 .39506 L F
.132 0 .079 r
.50172 .39664 m .50425 .39563 L .50417 .39498 L F
.269 .758 .674 r
.50021 .39725 m .50172 .39664 L .50037 .39718 L F
.565 .932 .797 r
.50508 .39539 m .50389 .39506 L .50749 .39428 L F
.708 .599 .732 r
.33863 .54756 m .33868 .54341 L .33657 .5446 L F
.454 .284 .559 r
.33863 .54756 m .33781 .55137 L .34039 .54986 L F
.452 .137 .34 r
.41712 .46872 m .4207 .4652 L .41817 .46608 L F
.562 .391 .607 r
.54347 .37824 m .54074 .38161 L .54378 .37937 L F
.463 .261 .52 r
.54348 .3836 m .54079 .38458 L .54074 .38161 L F
0 0 .244 r
.54074 .38161 m .54079 .38458 L .54166 .38172 L F
.949 .603 .312 r
.54348 .3836 m .54166 .38172 L .54079 .38458 L F
.914 .592 .115 r
.54198 .38496 m .54115 .38265 L .54166 .38172 L F
0 0 .244 r
.54074 .38161 m .54166 .38172 L .54238 .38041 L F
.914 .592 .115 r
.54115 .38265 m .54029 .38025 L .54166 .38172 L F
0 0 .244 r
.54238 .38041 m .54166 .38172 L .54378 .37937 L F
.613 .931 .965 r
.50447 .40272 m .50328 .40461 L .50639 .4037 L F
.50447 .40272 m .50211 .40402 L .50328 .40461 L F
0 0 0 r
.5934 .40087 m .59443 .39914 L .59624 .39759 L F
.636 .799 .961 r
.53412 .3869 m .5356 .38885 L .5311 .38805 L F
.594 .3 .439 r
.5356 .38885 m .53257 .39101 L .5311 .38805 L F
.5356 .38885 m .53484 .39218 L .53257 .39101 L F
0 0 .049 r
.53655 .38905 m .5356 .38885 L .53412 .3869 L F
.53655 .38905 m .53484 .39218 L .5356 .38885 L F
.473 0 0 r
.62884 .33449 m .63245 .33584 L .63392 .33436 L F
.864 .446 .23 r
.63392 .33436 m .63245 .33584 L .6355 .33657 L F
.875 .882 .836 r
.45881 .4925 m .45536 .49309 L .45718 .49098 L F
.836 .872 .87 r
.4617 .48933 m .45881 .4925 L .45718 .49098 L F
.498 .169 .34 r
.4151 .48359 m .41444 .48572 L .41167 .48575 L F
.299 .012 .298 r
.41738 .48258 m .41444 .48572 L .4151 .48359 L F
.779 .541 .575 r
.49389 .4146 m .49998 .41598 L .49856 .41346 L F
.338 .361 .738 r
.49856 .41346 m .49998 .41598 L .50116 .41465 L F
.396 .111 .358 r
.44203 .46283 m .44338 .46584 L .4386 .46547 L F
.512 .203 .38 r
.44338 .46584 m .43776 .468 L .4386 .46547 L F
.771 .356 .263 r
.29899 .63238 m .30269 .63506 L .30388 .63219 L F
.857 .948 .875 r
.46368 .43791 m .46801 .43587 L .46621 .43663 L F
.581 .44 .654 r
.46801 .43587 m .47106 .43836 L .47026 .43559 L F
.46801 .43587 m .46855 .43952 L .47106 .43836 L F
0 0 0 r
.46621 .43663 m .46801 .43587 L .46977 .43566 L F
.46958 .43577 m .46977 .43566 L .47026 .43559 L F
.46621 .43663 m .46977 .43566 L .46958 .43577 L F
.46621 .43663 m .47026 .43559 L .46948 .4345 L F
.91 .898 .486 r
.46848 .43602 m .46787 .44106 L .4664 .43715 L F
.46848 .43602 m .4664 .43715 L .46621 .43663 L F
0 0 0 r
.47019 .43455 m .46946 .43548 L .46848 .43602 L F
.91 .898 .486 r
.46843 .43646 m .46747 .43805 L .46787 .44106 L F
.46848 .43602 m .46819 .43661 L .46843 .43646 L F
.46819 .43661 m .46747 .43805 L .46843 .43646 L F
0 0 0 r
.46946 .43548 m .46747 .43805 L .46848 .43602 L F
.892 .582 .455 r
.32122 .61427 m .32346 .61244 L .32001 .6126 L F
.32122 .61427 m .32448 .6153 L .32346 .61244 L F
.439 .351 .66 r
.32346 .61244 m .3263 .61336 L .3262 .61147 L F
.32346 .61244 m .32448 .6153 L .3263 .61336 L F
.684 .698 .858 r
.64091 .33772 m .64386 .33865 L .64223 .33727 L F
.533 .798 .994 r
.64386 .33865 m .64569 .33638 L .64223 .33727 L F
.64386 .33865 m .64693 .33788 L .64569 .33638 L F
.236 .753 .779 r
.31028 .67018 m .31453 .66937 L .31441 .67234 L F
.517 .252 .452 r
.42642 .47549 m .42292 .47912 L .42375 .47622 L F
.421 .101 .314 r
.42218 .47745 m .42375 .47622 L .42292 .47912 L F
.59 .65 .878 r
.58148 .36376 m .58382 .36551 L .58567 .36473 L F
0 0 0 r
.51389 .38563 m .51293 .38751 L .51578 .38409 L F
.62292 .39375 m .62425 .39208 L .62695 .39062 L F
.506 .804 .999 r
.61078 .34841 m .60938 .3471 L .60707 .34803 L F
.409 .72 .988 r
.61078 .34841 m .61324 .34581 L .60938 .3471 L F
.61078 .34841 m .61415 .34812 L .61324 .34581 L F
.874 .888 .841 r
.49024 .48127 m .4946 .47966 L .49299 .47813 L F
.857 .896 .863 r
.49299 .47813 m .4946 .47966 L .49763 .47609 L F
.584 .603 .837 r
.30565 .62888 m .30974 .63161 L .30821 .62817 L F
.766 .694 .783 r
.30974 .63161 m .31256 .62867 L .30821 .62817 L F
.552 0 0 r
.31055 .63359 m .30974 .63161 L .30821 .63454 L F
.709 .65 .789 r
.36461 .48647 m .36582 .48874 L .36168 .48858 L F
.295 0 .042 r
.36461 .48647 m .36289 .48845 L .36552 .48736 L F
.36634 .48649 m .36552 .48736 L .36757 .48651 L F
.36461 .48647 m .36552 .48736 L .36634 .48649 L F
.423 .86 .924 r
.36618 .48674 m .36698 .48581 L .36741 .48536 L F
.36698 .48581 m .36698 .48581 L .36703 .48576 L F
.36698 .48581 m .36703 .48576 L .36741 .48536 L F
.36618 .48674 m .36461 .48647 L .36698 .48581 L F
.767 .859 .918 r
.51839 .45924 m .52209 .45916 L .52038 .45791 L F
.848 .858 .85 r
.52038 .45791 m .52209 .45916 L .52498 .4559 L F
.483 .877 .702 r
.61311 .39146 m .61067 .39309 L .60907 .39377 L F
.271 0 .166 r
.43643 .45281 m .43815 .45368 L .43892 .45191 L F
.43643 .45281 m .4357 .45455 L .43815 .45368 L F
.868 .808 .788 r
.65266 .35023 m .65684 .3479 L .65276 .34792 L F
.683 .229 .168 r
.40536 .55428 m .40407 .55619 L .40165 .55384 L F
0 0 .146 r
.40536 .55428 m .40752 .5494 L .40706 .55263 L F
.581 .258 .387 r
.40706 .55263 m .40407 .55619 L .40536 .55428 L F
.556 .477 .722 r
.30565 .62888 m .30821 .62817 L .30698 .62404 L F
.204 0 0 r
.47879 .43129 m .48127 .42889 L .48248 .42909 L F
0 0 .027 r
.58258 .37874 m .58237 .37829 L .58291 .376 L F
.58258 .37874 m .58225 .38094 L .58237 .37829 L F
.891 .916 .835 r
.50597 .46875 m .51018 .46654 L .50858 .46519 L F
.801 .885 .906 r
.50858 .46519 m .51018 .46654 L .51388 .46356 L F
.301 .017 .304 r
.52179 .39207 m .52143 .39419 L .52424 .39265 L F
.52179 .39207 m .52363 .39251 L .52475 .3917 L F
.52363 .39251 m .52458 .39202 L .52475 .3917 L F
.665 .118 0 r
.52082 .38997 m .52424 .39265 L .52143 .39419 L F
.023 0 .421 r
.52085 .39394 m .52264 .39203 L .52053 .39381 L F
.52143 .39419 m .52186 .39342 L .52085 .39394 L F
.52186 .39342 m .52264 .39203 L .52085 .39394 L F
.301 .017 .304 r
.52363 .39251 m .52424 .39265 L .52458 .39202 L F
.816 .803 .839 r
.4796 .47304 m .4758 .47294 L .47878 .47166 L F
.622 .725 .92 r
.48208 .47194 m .4796 .47304 L .47878 .47166 L F
.576 .942 .856 r
.32001 .6126 m .31625 .61444 L .3176 .61543 L F
.892 .582 .455 r
.32006 .61464 m .32001 .6126 L .3176 .61543 L F
.205 0 .304 r
.3176 .61543 m .31625 .61444 L .31887 .61375 L F
.892 .582 .455 r
.32122 .61427 m .32104 .61401 L .32006 .61464 L F
.32104 .61401 m .32001 .6126 L .32006 .61464 L F
.741 .641 .749 r
.31887 .61375 m .32122 .61427 L .3176 .61543 L F
.72 .597 .718 r
.31545 .61762 m .32186 .61761 L .31985 .61502 L F
.31687 .61602 m .31985 .61502 L .31887 .61375 L F
.31545 .61762 m .31985 .61502 L .31687 .61602 L F
.817 .605 .615 r
.31852 .61563 m .32186 .61761 L .31828 .61694 L F
.31972 .61486 m .32186 .61761 L .31852 .61563 L F
.892 .711 .651 r
.32323 .6178 m .32448 .6153 L .32122 .61427 L F
0 0 .096 r
.3263 .61336 m .32448 .6153 L .32323 .6178 L F
.3263 .61336 m .32323 .6178 L .32122 .61427 L F
.599 .304 .44 r
.31828 .61694 m .32406 .61699 L .32144 .61448 L F
.32072 .61472 m .32144 .61448 L .32122 .61427 L F
.31828 .61694 m .32144 .61448 L .32072 .61472 L F
.817 .605 .615 r
.31887 .61375 m .31972 .61486 L .31852 .61563 L F
.532 .349 .578 r
.41435 .5775 m .41708 .57739 L .41714 .57447 L F
.367 .68 .978 r
.41435 .5775 m .41672 .57776 L .41708 .57739 L F
.988 .768 .379 r
.65266 .35023 m .65358 .35377 L .65448 .35168 L F
.65266 .35023 m .65221 .35252 L .65358 .35377 L F
.937 .96 .752 r
.65221 .35252 m .6513 .3574 L .65358 .35377 L F
.449 .255 .525 r
.5693 .34495 m .56958 .34422 L .57141 .34413 L F
.5693 .34495 m .56646 .34316 L .56958 .34422 L F
.763 .539 .593 r
.41135 .54751 m .40752 .5494 L .41046 .54659 L F
.41135 .54751 m .41132 .55066 L .40752 .5494 L F
.791 .822 .876 r
.41456 .54459 m .41135 .54751 L .41046 .54659 L F
.306 .667 .974 r
.30318 .66731 m .30404 .66581 L .30143 .66548 L F
.30318 .66731 m .30652 .66773 L .30404 .66581 L F
.487 .834 .997 r
.41132 .55066 m .4155 .55087 L .41421 .54985 L F
.836 .954 .892 r
.41421 .54985 m .4155 .55087 L .41732 .54846 L F
.795 .648 .699 r
.41708 .57739 m .42141 .57794 L .41995 .5745 L F
.681 .807 .942 r
.41672 .57776 m .42141 .57794 L .41708 .57739 L F
.99 .727 .396 r
.34394 .64872 m .3423 .64478 L .34187 .64768 L F
.976 .804 .607 r
.34263 .65222 m .34394 .64872 L .34187 .64768 L F
.836 .949 .893 r
.33344 .66793 m .33522 .66883 L .33799 .66577 L F
0 0 0 r
.46331 .43217 m .45954 .43471 L .46187 .43355 L F
.46187 .43355 m .46504 .43074 L .46331 .43217 L F
.343 .631 .959 r
.51903 .4173 m .51684 .4181 L .51622 .41808 L F
.51903 .4173 m .52062 .41956 L .51684 .4181 L F
.955 .78 .626 r
.56866 .35975 m .56688 .36097 L .5674 .35832 L F
.588 .506 .73 r
.5688 .35752 m .56866 .35975 L .5674 .35832 L F
.976 .672 .354 r
.50977 .44375 m .50823 .44231 L .50676 .44408 L F
.50977 .44375 m .51108 .44199 L .50823 .44231 L F
.831 .758 .783 r
.44817 .50685 m .44339 .50902 L .44637 .50548 L F
.44817 .50685 m .4455 .51025 L .44339 .50902 L F
.842 .868 .862 r
.45116 .50356 m .44817 .50685 L .44637 .50548 L F
.662 .128 0 r
.57083 .37813 m .56645 .37747 L .56779 .37658 L F
.641 .102 0 r
.57491 .36154 m .57761 .36367 L .57992 .36367 L F
.219 .279 .712 r
.57675 .35919 m .57761 .36367 L .57491 .36154 L F
0 .437 .844 r
.5447 .3779 m .54687 .3795 L .54347 .37824 L F
.5447 .3779 m .54347 .37824 L .54378 .37937 L F
0 0 0 r
.58027 .3879 m .58162 .38323 L .58126 .38528 L F
.58126 .38528 m .57965 .38978 L .58027 .3879 L F
.884 .858 .811 r
.4641 .44116 m .4611 .44149 L .46368 .43791 L F
.45 .462 .78 r
.46621 .43663 m .4641 .44116 L .46368 .43791 L F
.46621 .43663 m .46787 .44106 L .4641 .44116 L F
0 0 0 r
.4642 .44128 m .4641 .44116 L .46787 .44106 L F
.864 .779 .765 r
.52604 .45113 m .53036 .44869 L .52911 .44792 L F
.52604 .45113 m .52793 .45262 L .53036 .44869 L F
.74 .968 .933 r
.53104 .44631 m .53036 .44869 L .53313 .44557 L F
.53104 .44631 m .52911 .44792 L .53036 .44869 L F
0 0 0 r
.58932 .3951 m .58857 .39837 L .58902 .39679 L F
.952 .688 .499 r
.42285 .55086 m .42151 .55245 L .42132 .54874 L F
.42285 .55086 m .42255 .55373 L .42151 .55245 L F
.847 .982 .695 r
.5311 .38805 m .52842 .39232 L .52894 .38941 L F
.495 .573 .864 r
.52851 .39156 m .52894 .38941 L .52842 .39232 L F
.67 .593 .76 r
.53257 .39101 m .52842 .39232 L .5311 .38805 L F
.829 .522 .471 r
.53257 .39101 m .52882 .39152 L .52842 .39232 L F
.52882 .39152 m .52851 .39156 L .5285 .39171 L F
.53257 .39101 m .53107 .39369 L .52851 .39156 L F
.772 .449 .439 r
.53527 .39382 m .53107 .39369 L .53257 .39101 L F
.371 .5 .859 r
.53076 .39038 m .53107 .39369 L .5331 .39163 L F
.52894 .38941 m .52972 .39099 L .53076 .39038 L F
.52972 .39099 m .53107 .39369 L .53076 .39038 L F
.829 .522 .471 r
.52882 .39152 m .5285 .39171 L .52842 .39232 L F
.212 .365 .801 r
.50713 .43534 m .51019 .43795 L .50972 .43536 L F
.114 0 .2 r
.29305 .64155 m .29122 .64252 L .29037 .64493 L F
.821 .715 .748 r
.34039 .54986 m .3422 .55425 L .34448 .55057 L F
.745 .735 .842 r
.30821 .62817 m .31256 .62867 L .31097 .62628 L F
.13 .409 .857 r
.31097 .62628 m .31256 .62867 L .31329 .62704 L F
.263 .575 .941 r
.31329 .62704 m .31256 .62867 L .31434 .62872 L F
.4 0 .066 r
.62342 .34428 m .62028 .34556 L .62063 .34449 L F
.843 .903 .879 r
.38351 .56883 m .38111 .57119 L .37939 .57001 L F
.695 .544 .677 r
.41714 .57447 m .41995 .5745 L .41992 .57116 L F
.744 .915 .95 r
.40468 .54964 m .40148 .54924 L .40304 .54668 L F
.55 .558 .816 r
.4072 .54744 m .40468 .54964 L .40304 .54668 L F
.4072 .54744 m .40752 .5494 L .40468 .54964 L F
.485 .167 .352 r
.4604 .44963 m .45981 .45181 L .45699 .45219 L F
.524 .264 .463 r
.46293 .44876 m .45981 .45181 L .4604 .44963 L F
.421 .101 .314 r
.42218 .47745 m .42292 .47912 L .42062 .47897 L F
.302 .07 .386 r
.44477 .46407 m .44203 .46283 L .44449 .46179 L F
.44477 .46407 m .44338 .46584 L .44203 .46283 L F
.962 .792 .353 r
.54711 .38252 m .54807 .38119 L .54687 .3795 L F
.54711 .38252 m .54776 .38431 L .54807 .38119 L F
.359 .041 .283 r
.42062 .47897 m .42001 .48191 L .41738 .48258 L F
.25 0 .188 r
.42292 .47912 m .42001 .48191 L .42062 .47897 L F
.53 .323 .544 r
.29341 .6389 m .29612 .63856 L .2968 .63519 L F
.491 .204 .405 r
.29567 .64115 m .29341 .6389 L .29305 .64155 L F
.29567 .64115 m .29612 .63856 L .29341 .6389 L F
0 0 0 r
.31752 .62268 m .3206 .61817 L .31926 .62019 L F
.268 0 0 r
.31926 .62019 m .3206 .61817 L .32323 .6178 L F
.641 .265 .315 r
.30075 .63762 m .2968 .63519 L .29612 .63856 L F
0 0 .06 r
.55614 .40408 m .55352 .40861 L .55504 .40665 L F
.983 .775 .544 r
.42123 .56098 m .42077 .56449 L .41951 .55982 L F
.997 .809 .532 r
.42034 .55742 m .42123 .56098 L .41951 .55982 L F
.983 .775 .544 r
.42123 .56098 m .42077 .56449 L .41951 .55982 L F
0 0 .541 r
.58963 .37798 m .59044 .37597 L .58893 .37384 L F
0 0 .207 r
.59045 .38032 m .59044 .37597 L .58963 .37798 L F
.46 .185 .408 r
.35213 .56737 m .35453 .56714 L .35538 .56451 L F
.35188 .56758 m .35453 .56714 L .35213 .56737 L F
.514 .383 .64 r
.35453 .56714 m .35741 .56358 L .35538 .56451 L F
.35453 .56714 m .35708 .56696 L .35741 .56358 L F
.518 .56 .838 r
.35456 .56498 m .35703 .56691 L .35453 .56714 L F
.35703 .56691 m .35708 .56696 L .35453 .56714 L F
.713 .18 0 r
.35538 .56451 m .35402 .5646 L .35003 .56149 L F
.35372 .56439 m .35294 .56467 L .3509 .56244 L F
.35353 .56449 m .35294 .56467 L .35372 .56439 L F
.35402 .5646 m .3509 .56244 L .35003 .56149 L F
.67 .932 .642 r
.35353 .56449 m .35459 .5633 L .35294 .56467 L F
.749 .467 .505 r
.35299 .56069 m .35294 .56467 L .35459 .5633 L F
.67 .932 .642 r
.35353 .56449 m .35359 .56364 L .35459 .5633 L F
.35291 .56518 m .35353 .56449 L .35294 .56467 L F
.35291 .56518 m .35312 .5647 L .35353 .56449 L F
.35312 .5647 m .35359 .56364 L .35353 .56449 L F
.713 .18 0 r
.35376 .56442 m .35353 .56449 L .35372 .56439 L F
.35402 .5646 m .35294 .56467 L .35376 .56442 L F
.874 .994 .79 r
.35459 .5633 m .35294 .56467 L .35538 .56451 L F
.518 .56 .838 r
.35459 .5633 m .35678 .56652 L .35456 .56498 L F
.35678 .56652 m .35708 .56696 L .35456 .56498 L F
.874 .994 .79 r
.35459 .5633 m .35538 .56451 L .3576 .5613 L F
.066 0 .201 r
.35538 .56451 m .35741 .56358 L .3576 .5613 L F
0 0 .527 r
.58484 .35784 m .58686 .35815 L .58642 .3556 L F
.58484 .35784 m .58559 .36061 L .58686 .35815 L F
.366 0 .188 r
.52518 .36084 m .52799 .36023 L .52869 .35852 L F
.266 0 .145 r
.52869 .35852 m .52799 .36023 L .53067 .35934 L F
.038 0 0 r
.37113 .48481 m .3739 .4846 L .37582 .48414 L F
.064 0 0 r
.28663 .64828 m .28815 .64583 L .2848 .6488 L F
.13 0 .029 r
.29037 .64493 m .28815 .64583 L .28663 .64828 L F
.848 .858 .85 r
.52038 .45791 m .52498 .4559 L .52304 .45468 L F
.834 .819 .835 r
.52304 .45468 m .52498 .4559 L .52793 .45262 L F
.816 .663 .114 r
.5907 .38492 m .5904 .38665 L .59088 .38266 L F
.5907 .38492 m .59062 .38756 L .5904 .38665 L F
.347 0 0 r
.61782 .33846 m .62183 .33644 L .61932 .33784 L F
0 .259 .768 r
.31434 .62872 m .31674 .63201 L .31707 .63075 L F
.631 .963 .865 r
.31707 .63075 m .31674 .63201 L .31413 .63252 L F
.773 .876 .922 r
.63282 .39392 m .63639 .38992 L .63427 .39183 L F
.63282 .39392 m .63775 .3914 L .63639 .38992 L F
.805 .689 .737 r
.44497 .51295 m .44339 .50902 L .4455 .51025 L F
0 .382 .833 r
.55733 .37717 m .56163 .38052 L .56033 .37778 L F
.55733 .37717 m .55959 .37841 L .56163 .38052 L F
.5603 .37907 m .56184 .37964 L .56167 .38033 L F
.55959 .37841 m .56088 .37911 L .5603 .37907 L F
.56088 .37911 m .56184 .37964 L .5603 .37907 L F
.55 .528 .784 r
.56645 .37747 m .56402 .37971 L .56382 .37794 L F
.542 .791 .99 r
.56311 .37855 m .56594 .37795 L .56402 .37971 L F
0 .382 .833 r
.55959 .37841 m .56167 .38033 L .56163 .38052 L F
.402 .441 .787 r
.55935 .37976 m .56184 .37964 L .55733 .37717 L F
.508 .241 .445 r
.55851 .38417 m .56163 .38052 L .56184 .37964 L F
.55851 .38417 m .56184 .37964 L .55935 .37976 L F
.996 .763 .426 r
.56266 .37887 m .56296 .38245 L .56138 .37975 L F
.56311 .37855 m .56304 .38045 L .56266 .37887 L F
.56304 .38045 m .56296 .38245 L .56266 .37887 L F
.02 0 0 r
.56215 .37922 m .56594 .37795 L .56311 .37855 L F
.56138 .37975 m .56263 .37926 L .56215 .37922 L F
.56263 .37926 m .56594 .37795 L .56215 .37922 L F
.402 .441 .787 r
.55935 .37976 m .55733 .37717 L .55865 .37587 L F
.55935 .37976 m .55901 .37787 L .55561 .37906 L F
.55901 .37787 m .55865 .37587 L .5578 .37676 L F
.55901 .37787 m .5578 .37676 L .55561 .37906 L F
.508 .241 .445 r
.55851 .38417 m .56174 .38343 L .56163 .38052 L F
.525 .207 .371 r
.55455 .38017 m .55665 .37777 L .55733 .37717 L F
.55455 .38017 m .55561 .37906 L .55665 .37777 L F
.55455 .38017 m .55935 .37976 L .55561 .37906 L F
.55455 .38017 m .55413 .3822 L .55935 .37976 L F
.505 .275 .499 r
.45439 .45248 m .45386 .45512 L .45124 .45551 L F
.537 .248 .424 r
.45386 .45512 m .45014 .45853 L .45124 .45551 L F
.874 .994 .79 r
.35459 .5633 m .3576 .5613 L .35625 .55979 L F
.602 .851 .991 r
.35625 .55979 m .3576 .5613 L .36104 .56083 L F
.75 .359 .311 r
.3576 .5613 m .35741 .56358 L .36267 .56412 L F
.96 .656 .237 r
.35625 .55979 m .35741 .56358 L .3576 .5613 L F
.466 .239 .485 r
.45652 .45438 m .45439 .45248 L .45699 .45219 L F
.45652 .45438 m .45386 .45512 L .45439 .45248 L F
.491 .055 .139 r
.39199 .48104 m .3963 .47872 L .39263 .48035 L F
.39199 .48104 m .39462 .48118 L .3963 .47872 L F
.323 0 .008 r
.39462 .48118 m .39889 .4786 L .3963 .47872 L F
.902 .955 .823 r
.41304 .53442 m .41801 .53049 L .41631 .52926 L F
.994 .76 .462 r
.63639 .38992 m .63775 .3914 L .63653 .38752 L F
.786 .71 .779 r
.63775 .3914 m .6405 .38799 L .63653 .38752 L F
0 .24 .712 r
.55476 .39857 m .55516 .39814 L .55426 .39705 L F
.55476 .39857 m .55758 .40037 L .55516 .39814 L F
0 .027 .598 r
.38875 .56206 m .39055 .55962 L .38881 .55916 L F
.147 .643 .912 r
.37909 .56477 m .37829 .56402 L .37531 .56385 L F
.811 .998 .849 r
.37978 .56263 m .37909 .56477 L .38222 .56375 L F
.37978 .56263 m .37829 .56402 L .37909 .56477 L F
.913 .946 .809 r
.64652 .37934 m .64438 .37953 L .6439 .38297 L F
.767 .986 .901 r
.64792 .37682 m .64652 .37934 L .64878 .37774 L F
.64792 .37682 m .64438 .37953 L .64652 .37934 L F
.497 .845 .995 r
.55332 .39217 m .55266 .39105 L .5494 .39204 L F
.194 .164 .595 r
.55332 .39217 m .55513 .39024 L .55266 .39105 L F
.55332 .39217 m .55516 .39321 L .55513 .39024 L F
.588 .506 .73 r
.5688 .35752 m .5674 .35832 L .56943 .35653 L F
.193 0 0 r
.40824 .47176 m .4103 .47181 L .41168 .46973 L F
.363 0 .1 r
.4103 .47181 m .41435 .46917 L .41168 .46973 L F
.074 0 0 r
.41498 .54228 m .41936 .54025 L .41578 .54031 L F
0 .271 .774 r
.54876 .36287 m .54814 .36463 L .54826 .36194 L F
.54876 .36287 m .55053 .36634 L .54814 .36463 L F
0 0 0 r
.55408 .41536 m .55744 .41161 L .55713 .41368 L F
.55951 .41014 m .55744 .41161 L .5598 .40823 L F
0 0 .002 r
.55713 .41368 m .55744 .41161 L .55951 .41014 L F
.875 .537 .033 r
.65024 .35606 m .65157 .35946 L .6513 .3574 L F
.937 .96 .752 r
.65221 .35252 m .65024 .35606 L .6513 .3574 L F
.764 .488 .516 r
.65157 .35946 m .65566 .35757 L .6513 .3574 L F
.261 .412 .825 r
.29777 .66161 m .29956 .66511 L .30143 .66548 L F
.91 .864 .424 r
.5598 .40823 m .56038 .40445 L .55998 .40721 L F
.795 .648 .699 r
.41708 .57739 m .41995 .5745 L .41714 .57447 L F
.111 0 0 r
.51348 .42061 m .51665 .42062 L .5162 .42079 L F
.51348 .42061 m .5162 .42079 L .51622 .41808 L F
0 0 .004 r
.59932 .34138 m .59843 .34338 L .60118 .33971 L F
.56 .626 .874 r
.38807 .57123 m .38351 .56883 L .38626 .56894 L F
.801 .755 .811 r
.39112 .56784 m .38807 .57123 L .38626 .56894 L F
.72 .832 .934 r
.51665 .42062 m .52062 .41956 L .51903 .4173 L F
.899 .872 .802 r
.52335 .41508 m .51903 .4173 L .5198 .41465 L F
.366 0 0 r
.5198 .41465 m .5231 .41549 L .52335 .41508 L F
.169 .607 .938 r
.52201 .41419 m .5231 .41549 L .52099 .41495 L F
.52248 .41464 m .5231 .41549 L .52201 .41419 L F
.899 .872 .802 r
.52335 .41508 m .52268 .41618 L .52207 .41574 L F
.52268 .41618 m .52062 .41956 L .52207 .41574 L F
.465 .251 .503 r
.52271 .41871 m .52531 .41543 L .52335 .41508 L F
.52271 .41871 m .52335 .41508 L .52426 .41298 L F
.52271 .41871 m .52354 .41564 L .52204 .41428 L F
.665 .788 .325 r
.52426 .41298 m .5231 .41549 L .52335 .41508 L F
.914 .977 .775 r
.52426 .41298 m .5231 .41549 L .52248 .41464 L F
.465 .251 .503 r
.52248 .41464 m .52426 .41298 L .52208 .41426 L F
.914 .977 .775 r
.52426 .41298 m .52248 .41464 L .52211 .41413 L F
.465 .251 .503 r
.52354 .41564 m .52426 .41298 L .52248 .41464 L F
.52354 .41564 m .52208 .41426 L .52204 .41428 L F
.169 .607 .938 r
.52211 .41413 m .52248 .41464 L .52201 .41419 L F
.52039 .41452 m .52099 .41495 L .5198 .41465 L F
.52211 .41413 m .52099 .41495 L .52039 .41452 L F
.899 .872 .802 r
.52207 .41574 m .52062 .41956 L .51903 .4173 L F
.512 .732 .973 r
.51903 .4173 m .52062 .41956 L .52271 .41871 L F
.29 .342 .743 r
.31926 .62019 m .32035 .62428 L .31752 .62268 L F
0 0 0 r
.62456 .33558 m .62758 .33493 L .62884 .33449 L F
.609 .071 0 r
.62758 .33493 m .63245 .33584 L .62884 .33449 L F
.148 0 0 r
.38202 .56844 m .38626 .56894 L .38351 .56883 L F
.725 .587 .7 r
.64091 .33772 m .63748 .33824 L .6355 .33657 L F
.602 .851 .991 r
.35625 .55979 m .36104 .56083 L .35838 .55616 L F
.708 .804 .925 r
.63653 .38752 m .6405 .38799 L .63875 .38637 L F
.848 .908 .876 r
.6405 .38799 m .64219 .38346 L .63875 .38637 L F
.6405 .38799 m .64354 .3849 L .64219 .38346 L F
.941 .961 .733 r
.6439 .38297 m .64219 .38346 L .64354 .3849 L F
.6439 .38297 m .64438 .37953 L .64219 .38346 L F
.214 .593 .947 r
.28874 .65818 m .29075 .66011 L .29303 .66029 L F
.873 .706 .672 r
.43964 .52742 m .43872 .53009 L .43705 .52618 L F
.859 .99 .839 r
.60406 .36252 m .6014 .36465 L .60359 .36436 L F
.762 .994 .804 r
.60512 .36253 m .60657 .36254 L .60274 .36148 L F
0 .415 .836 r
.60124 .36019 m .60567 .36277 L .60274 .36148 L F
.60124 .36019 m .60362 .36114 L .60567 .36277 L F
.60362 .36114 m .60434 .36142 L .6053 .36239 L F
.60362 .36114 m .6053 .36239 L .60567 .36277 L F
.891 .665 .149 r
.6006 .35762 m .60124 .36019 L .60116 .35904 L F
.6006 .35762 m .60116 .35904 L .60094 .35616 L F
0 0 0 r
.60382 .35302 m .60332 .35409 L .60094 .35616 L F
.60332 .35409 m .60296 .35486 L .60238 .35524 L F
.60332 .35409 m .60238 .35524 L .60094 .35616 L F
.935 .964 .751 r
.60222 .35225 m .59996 .35598 L .60054 .35748 L F
.6007 .35728 m .60054 .35748 L .6006 .35762 L F
0 0 0 r
.60296 .35486 m .6006 .35762 L .60094 .35616 L F
.935 .964 .751 r
.60222 .35225 m .60054 .35748 L .6007 .35728 L F
.59996 .35598 m .59974 .35634 L .6006 .35762 L F
.856 .46 .289 r
.6006 .35762 m .60434 .36142 L .60124 .36019 L F
.879 .444 .135 r
.59899 .35853 m .60251 .36129 L .60168 .35969 L F
.59964 .35817 m .60168 .35969 L .6006 .35762 L F
.59899 .35853 m .60168 .35969 L .59964 .35817 L F
.859 .99 .839 r
.60434 .36142 m .60334 .36252 L .60406 .36252 L F
.60334 .36252 m .6014 .36465 L .60406 .36252 L F
.762 .994 .804 r
.60567 .36277 m .60696 .36264 L .60657 .36254 L F
.60567 .36277 m .60657 .36254 L .60512 .36253 L F
.291 .278 .672 r
.51028 .40492 m .51255 .40159 L .50991 .40327 L F
.51028 .40492 m .51227 .40521 L .51255 .40159 L F
.789 .995 .87 r
.5364 .4426 m .53392 .44307 L .53313 .44557 L F
.813 .998 .781 r
.53392 .44307 m .53104 .44631 L .53313 .44557 L F
.776 .478 .484 r
.4988 .41833 m .49998 .41598 L .49389 .4146 L F
0 0 0 r
.50116 .41465 m .49998 .41598 L .4988 .41833 L F
.157 0 .195 r
.31625 .61444 m .31366 .61917 L .31545 .61762 L F
.72 .597 .718 r
.31545 .61762 m .31887 .61375 L .31625 .61444 L F
.834 .819 .835 r
.52304 .45468 m .52793 .45262 L .52604 .45113 L F
.616 .78 .96 r
.38513 .57981 m .38676 .58156 L .38938 .58064 L F
.92 .951 .613 r
.55272 .4103 m .55281 .41256 L .55196 .41297 L F
.845 .505 .41 r
.55281 .41256 m .55408 .41536 L .55196 .41297 L F
.976 .888 .675 r
.66309 .36371 m .66441 .36528 L .66521 .36232 L F
.836 .872 .87 r
.4617 .48933 m .45718 .49098 L .46008 .48826 L F
.813 .923 .91 r
.46485 .4866 m .4617 .48933 L .46008 .48826 L F
.72 .832 .934 r
.51665 .42062 m .51903 .4173 L .5162 .42079 L F
.61 .591 .807 r
.29496 .66217 m .29607 .65756 L .29303 .66029 L F
.29496 .66217 m .29777 .66161 L .29607 .65756 L F
.253 0 .047 r
.35218 .55618 m .35604 .55355 L .3515 .55341 L F
.35218 .55618 m .35501 .55547 L .35604 .55355 L F
.703 .459 .552 r
.35501 .55547 m .35841 .55331 L .35604 .55355 L F
.204 0 .01 r
.4207 .4652 m .42332 .46434 L .42426 .46277 L F
.231 0 .042 r
.42332 .46434 m .42676 .46201 L .42426 .46277 L F
.857 .896 .863 r
.49299 .47813 m .49763 .47609 L .49588 .4746 L F
.735 .857 .938 r
.49588 .4746 m .49763 .47609 L .50017 .47451 L F
0 .08 .64 r
.28486 .65174 m .28673 .65539 L .28711 .65426 L F
.669 .738 .902 r
.54244 .40583 m .54522 .40473 L .54131 .40395 L F
.54244 .40583 m .54522 .40473 L .54131 .40395 L F
0 0 0 r
.45358 .43806 m .4554 .43717 L .45727 .43576 L F
.099 0 0 r
.4554 .43717 m .45954 .43471 L .45727 .43576 L F
.662 .566 .735 r
.58148 .36376 m .58567 .36473 L .58559 .36061 L F
.641 .576 .766 r
.37855 .56026 m .37533 .56186 L .37392 .55732 L F
.37855 .56026 m .37392 .55732 L .37682 .55664 L F
.745 .662 .768 r
.37682 .55996 m .37855 .56026 L .37653 .55945 L F
.507 .251 .46 r
.37392 .55732 m .3764 .55958 L .37644 .55929 L F
.745 .662 .768 r
.37682 .55996 m .37653 .55945 L .37567 .5591 L F
.507 .251 .46 r
.37516 .55703 m .37644 .55929 L .37682 .55664 L F
.37392 .55732 m .37644 .55929 L .37516 .55703 L F
.3764 .55958 m .37682 .55996 L .37682 .55916 L F
.3764 .55958 m .37682 .55916 L .37682 .55664 L F
.728 .639 .759 r
.38137 .55747 m .37855 .56026 L .37682 .55664 L F
.725 .646 .77 r
.37936 .55301 m .38137 .55747 L .37682 .55664 L F
.112 .228 .706 r
.37493 .55824 m .37638 .56053 L .3764 .55958 L F
.37392 .55732 m .3746 .55821 L .37493 .55824 L F
.3746 .55821 m .37638 .56053 L .37493 .55824 L F
.901 .582 .433 r
.37682 .55664 m .37682 .55916 L .37567 .5591 L F
.37682 .55664 m .37602 .55835 L .37912 .55586 L F
.37602 .55835 m .37567 .5591 L .37643 .55839 L F
.37602 .55835 m .37643 .55839 L .37912 .55586 L F
.883 .894 .835 r
.37641 .55914 m .37567 .5591 L .3764 .5594 L F
.37643 .55839 m .3764 .5594 L .37855 .56026 L F
.901 .582 .433 r
.37682 .55916 m .37682 .55996 L .37567 .5591 L F
.883 .894 .835 r
.37643 .55839 m .37567 .5591 L .37641 .55914 L F
.37912 .55586 m .37643 .55839 L .37704 .55893 L F
.37898 .55698 m .37704 .55893 L .37855 .56026 L F
.37912 .55586 m .37704 .55893 L .37898 .55698 L F
.112 .228 .706 r
.37392 .55732 m .37533 .56186 L .37638 .56053 L F
.3764 .55958 m .37638 .56053 L .37682 .55996 L F
.436 .482 .809 r
.37531 .56385 m .37682 .55996 L .37533 .56186 L F
.07 0 0 r
.60054 .40151 m .60417 .40047 L .60365 .40107 L F
.239 .749 .725 r
.60417 .40047 m .60788 .39941 L .60623 .39976 L F
0 0 0 r
.60365 .40107 m .60417 .40047 L .60623 .39976 L F
.818 .647 .671 r
.34374 .64208 m .34549 .63785 L .34148 .63802 L F
.191 0 .3 r
.40982 .48739 m .40795 .48659 L .41167 .48575 L F
.689 .974 .915 r
.41444 .48572 m .40982 .48739 L .41167 .48575 L F
.854 .96 .875 r
.3489 .57144 m .3509 .56736 L .35188 .56758 L F
.542 .685 .932 r
.35291 .56518 m .35453 .56714 L .35188 .56758 L F
.828 .999 .792 r
.35188 .56758 m .3509 .56736 L .35291 .56518 L F
.542 .685 .932 r
.35291 .56518 m .35453 .56714 L .35188 .56758 L F
.905 .858 .413 r
.60638 .34775 m .60645 .34979 L .60707 .34803 L F
.771 .703 .787 r
.60957 .3438 m .60707 .34803 L .60541 .34313 L F
0 .498 .745 r
.60848 .3482 m .60707 .34803 L .60938 .3471 L F
.60848 .3482 m .60638 .34775 L .60707 .34803 L F
0 0 .47 r
.58857 .39837 m .59109 .40142 L .58934 .40071 L F
.464 .826 .994 r
.58934 .40071 m .59109 .40142 L .5934 .40087 L F
.82 .635 .651 r
.63366 .38829 m .63188 .39193 L .62946 .39054 L F
.341 .066 .342 r
.5153 .3807 m .51783 .38081 L .51815 .37764 L F
.488 .184 .376 r
.51815 .37764 m .5208 .37978 L .52083 .37594 L F
.51815 .37764 m .51783 .38081 L .5208 .37978 L F
.854 .96 .875 r
.3489 .57144 m .34728 .57094 L .3509 .56736 L F
0 .178 .688 r
.3489 .57144 m .35008 .57168 L .34728 .57094 L F
.608 .038 0 r
.35371 .57424 m .35145 .57344 L .3489 .57144 L F
0 .178 .688 r
.3489 .57144 m .35145 .57344 L .35008 .57168 L F
.624 .87 .518 r
.54378 .37937 m .54166 .38172 L .5447 .3779 L F
.842 .868 .862 r
.45116 .50356 m .44637 .50548 L .44899 .50218 L F
.658 .889 .981 r
.48248 .42909 m .48733 .42869 L .48776 .4274 L F
.061 .223 .719 r
.48776 .4274 m .48733 .42869 L .48841 .42668 L F
.752 .256 .047 r
.48733 .42869 m .48988 .4313 L .48655 .43051 L F
.48733 .42869 m .48655 .43051 L .48841 .42668 L F
.89 .639 .552 r
.39293 .49238 m .39076 .49241 L .39098 .48949 L F
.36 0 0 r
.39553 .49333 m .39076 .49241 L .39293 .49238 L F
.853 .447 .268 r
.29387 .65135 m .29696 .65237 L .29476 .65215 L F
.928 .69 .558 r
.29476 .65215 m .29696 .65237 L .29642 .65508 L F
.867 .759 .741 r
.33955 .65898 m .34321 .65859 L .34173 .65493 L F
.869 .759 .739 r
.34173 .65493 m .34321 .65859 L .34394 .65607 L F
.525 0 0 r
.56234 .38569 m .56571 .38496 L .56174 .38343 L F
.56234 .38569 m .56444 .38683 L .56571 .38496 L F
.303 0 0 r
.56571 .38496 m .56757 .38579 L .56921 .38459 L F
0 0 0 r
.56571 .38496 m .56745 .38505 L .56757 .38579 L F
.56571 .38496 m .56444 .38683 L .56745 .38505 L F
.826 .963 .636 r
.53869 .43876 m .54115 .43509 L .53934 .43641 L F
.769 .978 .71 r
.54225 .43261 m .54115 .43509 L .54396 .43176 L F
.76 .953 .638 r
.53934 .43641 m .54115 .43509 L .54225 .43261 L F
.845 .508 .417 r
.40717 .56433 m .40759 .56736 L .40485 .56643 L F
.808 .481 .435 r
.41147 .56764 m .40717 .56433 L .41026 .56408 L F
.602 .902 .985 r
.50739 .40145 m .50639 .4037 L .50991 .40327 L F
.50739 .40145 m .50447 .40272 L .50639 .4037 L F
.402 .123 .372 r
.42989 .45914 m .43249 .45858 L .43295 .4555 L F
.286 .029 .337 r
.43295 .4555 m .43501 .45742 L .4357 .45455 L F
.43295 .4555 m .43249 .45858 L .43501 .45742 L F
.892 .743 .69 r
.34394 .65607 m .34263 .65222 L .34173 .65493 L F
.766 .888 .932 r
.31666 .67139 m .32054 .67072 L .31773 .67091 L F
.421 .639 .946 r
.32054 .67072 m .32234 .66851 L .31773 .67091 L F
.32054 .67072 m .32498 .67264 L .32234 .66851 L F
.611 .614 .829 r
.32054 .67072 m .32545 .67285 L .32498 .67264 L F
.155 .267 .729 r
.32948 .61834 m .32781 .61826 L .32912 .61594 L F
.819 .7 .733 r
.32948 .61834 m .33328 .61455 L .32916 .61371 L F
.32948 .61834 m .32916 .61371 L .32912 .61594 L F
.122 .224 .698 r
.32912 .61594 m .33019 .62043 L .32781 .61826 L F
.508 0 0 r
.53487 .42676 m .5353 .4261 L .53188 .42564 L F
.773 .568 .622 r
.46825 .44086 m .47106 .43836 L .46855 .43952 L F
.7 .874 .963 r
.46918 .4823 m .46547 .48145 L .46862 .47822 L F
.46918 .4823 m .46718 .48278 L .46547 .48145 L F
.836 .851 .857 r
.47061 .47967 m .46918 .4823 L .46862 .47822 L F
.821 .98 .691 r
.52851 .39156 m .52497 .39695 L .52642 .39543 L F
.523 .204 .368 r
.40795 .48659 m .4078 .48881 L .40472 .48896 L F
.191 0 .3 r
.40982 .48739 m .4078 .48881 L .40795 .48659 L F
.554 .111 .152 r
.37749 .48827 m .37559 .48921 L .37285 .48913 L F
.383 0 0 r
.37969 .4893 m .37559 .48921 L .37749 .48827 L F
.005 .469 .868 r
.51805 .43801 m .51553 .43665 L .51654 .43854 L F
.475 0 0 r
.51654 .43854 m .52072 .43858 L .51805 .43801 L F
.438 0 0 r
.3841 .48979 m .3822 .49044 L .37969 .4893 L F
.05 0 0 r
.38664 .48971 m .3822 .49044 L .3841 .48979 L F
.524 .86 .994 r
.63479 .36339 m .63759 .36254 L .63688 .36338 L F
0 0 0 r
.63479 .36339 m .63593 .36324 L .63759 .36254 L F
.602 .932 .722 r
.63759 .36254 m .63593 .36324 L .63909 .36075 L F
.63759 .36254 m .63909 .36075 L .6391 .36074 L F
.524 .86 .994 r
.63688 .36338 m .63759 .36254 L .63866 .36338 L F
.787 .957 .924 r
.63866 .36338 m .6409 .35989 L .6421 .36144 L F
.148 0 0 r
.51176 .43445 m .50972 .43536 L .51224 .43502 L F
.542 0 0 r
.51224 .43502 m .51553 .43665 L .51176 .43445 L F
.634 .801 .963 r
.63398 .33775 m .63748 .33824 L .6355 .33657 L F
.805 .689 .737 r
.44497 .51295 m .44099 .51257 L .44339 .50902 L F
.81 .658 .695 r
.44497 .51295 m .44317 .51676 L .44099 .51257 L F
.654 .736 .91 r
.59418 .35034 m .59068 .35008 L .59299 .35027 L F
.801 .755 .811 r
.39112 .56784 m .38626 .56894 L .38902 .56647 L F
.856 .853 .838 r
.39373 .5646 m .39112 .56784 L .38902 .56647 L F
.276 .772 .728 r
.60788 .39941 m .609 .39884 L .60623 .39976 L F
.60788 .39941 m .61072 .39844 L .609 .39884 L F
0 0 .11 r
.44049 .54281 m .43853 .54375 L .44082 .54267 L F
.44049 .54281 m .4379 .54632 L .43853 .54375 L F
.72 .598 .719 r
.43747 .54036 m .43853 .54375 L .43479 .5438 L F
.702 .653 .798 r
.51108 .44199 m .51491 .44319 L .51441 .44119 L F
.568 .045 0 r
.51623 .44285 m .51441 .44119 L .51491 .44319 L F
.801 .885 .906 r
.50858 .46519 m .51388 .46356 L .51167 .4623 L F
.849 .876 .86 r
.51167 .4623 m .51388 .46356 L .51533 .46187 L F
.336 .196 .538 r
.2848 .6488 m .28674 .65139 L .28663 .64828 L F
.2848 .6488 m .28486 .65174 L .28674 .65139 L F
.646 .544 .725 r
.30698 .62404 m .31003 .62089 L .30704 .62155 L F
.398 .732 .991 r
.40334 .57781 m .40424 .57608 L .40162 .5765 L F
.263 0 .151 r
.40472 .47542 m .40725 .47456 L .40824 .47176 L F
.333 .005 .25 r
.40725 .47456 m .4103 .47181 L .40824 .47176 L F
.808 .905 .908 r
.52483 .40999 m .52628 .41137 L .52426 .41298 L F
.995 .804 .537 r
.52483 .40999 m .52426 .41298 L .52628 .41137 L F
.726 .897 .956 r
.62442 .37566 m .6194 .37634 L .62314 .37461 L F
.8 .924 .919 r
.62632 .37414 m .62442 .37566 L .62314 .37461 L F
.856 .412 .004 r
.56642 .37796 m .56745 .3789 L .56645 .37747 L F
.56642 .37796 m .56645 .37747 L .57083 .37813 L F
.841 .432 .264 r
.57083 .37813 m .57189 .38024 L .56642 .37796 L F
.538 .382 .618 r
.5153 .3807 m .51862 .38324 L .51783 .38081 L F
.5153 .3807 m .51578 .38409 L .51862 .38324 L F
.695 .64 .79 r
.30805 .65193 m .31056 .65309 L .30996 .64975 L F
.735 .611 .72 r
.30855 .65603 m .31056 .65309 L .30805 .65193 L F
.712 .609 .741 r
.31056 .65309 m .31266 .64851 L .30996 .64975 L F
.31056 .65309 m .31325 .65089 L .31266 .64851 L F
.148 0 .09 r
.31299 .6522 m .31056 .65309 L .30855 .65603 L F
.31299 .6522 m .31325 .65089 L .31056 .65309 L F
.96 .822 .663 r
.63245 .33584 m .63398 .33775 L .6355 .33657 L F
.782 .586 .635 r
.35762 .57752 m .35322 .57717 L .35371 .57424 L F
.872 .642 .587 r
.35762 .57752 m .35426 .57887 L .35322 .57717 L F
.35762 .57752 m .35741 .58102 L .35426 .57887 L F
.764 .488 .516 r
.65157 .35946 m .65598 .36017 L .65566 .35757 L F
.573 .676 .909 r
.32498 .67264 m .32474 .66717 L .32234 .66851 L F
.517 .218 .397 r
.32827 .67218 m .32498 .67264 L .32545 .67285 L F
.32827 .67218 m .32853 .67229 L .32498 .67264 L F
.338 .384 .763 r
.32929 .66801 m .32827 .67218 L .3274 .66969 L F
.573 .676 .909 r
.32498 .67264 m .32853 .67229 L .32474 .66717 L F
.147 .276 .741 r
.39813 .5654 m .39666 .56784 L .39581 .56407 L F
.366 0 0 r
.3972 .56825 m .39666 .56784 L .39813 .5654 L F
0 .457 .772 r
.5494 .39204 m .54495 .39053 L .54682 .39072 L F
.26 0 0 r
.58609 .35033 m .58841 .35044 L .59068 .35008 L F
.28 0 0 r
.59068 .35008 m .58841 .35044 L .59299 .35027 L F
.95 .735 .577 r
.59828 .40074 m .60116 .39888 L .60054 .40151 L F
.756 .994 .862 r
.60275 .39729 m .60116 .39888 L .60226 .39656 L F
.561 .308 .489 r
.59624 .39759 m .59987 .3983 L .59972 .39853 L F
.59752 .39957 m .59972 .39853 L .59828 .40074 L F
.59624 .39759 m .59972 .39853 L .59752 .39957 L F
.59624 .39759 m .59752 .39957 L .59787 .39948 L F
.59752 .39957 m .59828 .40074 L .59787 .39948 L F
.279 0 .065 r
.5939 .40127 m .59787 .39948 L .59528 .4024 L F
.5934 .40087 m .59738 .39963 L .5939 .40127 L F
.59738 .39963 m .59787 .39948 L .5939 .40127 L F
.18 .114 .541 r
.59787 .39948 m .59844 .40051 L .59528 .4024 L F
.766 .986 .749 r
.59867 .40032 m .60116 .39888 L .59828 .40074 L F
.685 .139 0 r
.59828 .40074 m .60054 .40151 L .59909 .4017 L F
.214 0 .24 r
.59987 .3983 m .60226 .39656 L .59828 .40074 L F
.18 .114 .541 r
.59787 .39948 m .59828 .40074 L .59909 .4017 L F
.59844 .40051 m .59909 .4017 L .59624 .40222 L F
.59844 .40051 m .59624 .40222 L .59528 .4024 L F
.766 .986 .749 r
.60226 .39656 m .60153 .3981 L .59867 .40032 L F
.60153 .3981 m .60116 .39888 L .59867 .40032 L F
.925 .889 .777 r
.46718 .48278 m .46329 .48527 L .46547 .48145 L F
.46718 .48278 m .46485 .4866 L .46329 .48527 L F
.549 .308 .502 r
.56033 .37778 m .56382 .37794 L .56387 .37477 L F
.558 .502 .749 r
.56387 .37477 m .56675 .37393 L .56532 .37042 L F
.489 .27 .507 r
.56382 .37794 m .56675 .37393 L .56387 .37477 L F
.791 .822 .876 r
.41456 .54459 m .41046 .54659 L .41231 .54561 L F
.872 .993 .754 r
.41498 .54228 m .41456 .54459 L .41231 .54561 L F
0 0 .346 r
.30866 .65182 m .30855 .65603 L .30805 .65193 L F
.738 .815 .912 r
.31299 .6522 m .30855 .65603 L .30866 .65182 L F
0 .165 .699 r
.6034 .37126 m .60185 .37102 L .60145 .36915 L F
.6034 .37126 m .60435 .37317 L .60185 .37102 L F
.497 .24 .455 r
.32916 .61371 m .3262 .61147 L .3263 .61336 L F
.814 .985 .886 r
.64976 .37483 m .64878 .37774 L .65202 .37484 L F
.64976 .37483 m .64792 .37682 L .64878 .37774 L F
0 .027 .598 r
.38875 .56206 m .38982 .56161 L .39055 .55962 L F
0 .029 .594 r
.41203 .56514 m .41147 .56764 L .41026 .56408 L F
.698 .961 .944 r
.41203 .56514 m .41032 .56689 L .41147 .56764 L F
.503 .854 .597 r
.49217 .40455 m .49391 .40294 L .49532 .40196 L F
0 0 0 r
.49532 .40196 m .49391 .40294 L .49835 .39988 L F
.772 .449 .439 r
.53527 .39382 m .53257 .39101 L .53484 .39218 L F
.824 .822 .847 r
.4212 .54456 m .42318 .54375 L .41956 .54303 L F
.897 .974 .674 r
.53683 .43989 m .5364 .4426 L .53869 .43876 L F
.83 .98 .689 r
.53934 .43641 m .53683 .43989 L .53869 .43876 L F
0 0 0 r
.52811 .38243 m .52967 .38121 L .52898 .38241 L F
.615 .746 .939 r
.53263 .38051 m .52967 .38121 L .53147 .37846 L F
.82 .56 .546 r
.53263 .38051 m .52898 .38241 L .52967 .38121 L F
.404 0 0 r
.64143 .34724 m .6445 .34837 L .64546 .34766 L F
.735 .209 0 r
.64546 .34766 m .6445 .34837 L .64658 .34933 L F
.669 .198 .125 r
.64546 .34766 m .64658 .34933 L .65036 .34968 L F
.757 .344 .268 r
.51188 .43767 m .51553 .43665 L .51224 .43502 L F
.51188 .43767 m .51654 .43854 L .51553 .43665 L F
.837 .799 .815 r
.40955 .52957 m .4108 .53365 L .40723 .53262 L F
.839 .5 .413 r
.4108 .53365 m .40695 .53441 L .40723 .53262 L F
.4108 .53365 m .41107 .53628 L .40695 .53441 L F
.842 .802 .812 r
.4119 .52975 m .4108 .53365 L .40955 .52957 L F
.853 .776 .776 r
.4122 .52594 m .41338 .52986 L .40955 .52957 L F
.881 .83 .792 r
.4122 .52594 m .4078 .5283 L .41044 .52472 L F
.4122 .52594 m .40955 .52957 L .4078 .5283 L F
.981 .885 .657 r
.4101 .52556 m .41107 .53007 L .41179 .52742 L F
.41172 .52585 m .41179 .52742 L .4122 .52594 L F
.4101 .52556 m .41179 .52742 L .41172 .52585 L F
.842 .802 .812 r
.41338 .52986 m .412 .53189 L .4119 .52975 L F
.412 .53189 m .4108 .53365 L .4119 .52975 L F
.597 .317 .462 r
.41217 .53501 m .41107 .53628 L .4108 .53365 L F
.88 .782 .749 r
.46465 .50876 m .46898 .50657 L .46722 .5051 L F
.46465 .50876 m .46666 .5103 L .46898 .50657 L F
.828 .857 .868 r
.46722 .5051 m .46898 .50657 L .47193 .5035 L F
0 .545 .761 r
.33344 .62208 m .33152 .62209 L .33019 .62043 L F
.33344 .62208 m .33446 .62242 L .33152 .62209 L F
.817 .663 .692 r
.51066 .42281 m .51143 .42596 L .50864 .4241 L F
.837 .644 .641 r
.50864 .4241 m .51143 .42596 L .50881 .42601 L F
.366 .241 .574 r
.51344 .42182 m .51143 .42596 L .51066 .42281 L F
.51344 .42182 m .51381 .42474 L .51143 .42596 L F
.555 .891 .985 r
.51143 .42596 m .51381 .42474 L .50881 .42601 L F
.901 .774 .713 r
.47548 .49496 m .47949 .49242 L .47791 .49116 L F
.47548 .49496 m .47751 .49646 L .47949 .49242 L F
.847 .907 .877 r
.47791 .49116 m .47949 .49242 L .4825 .48931 L F
0 0 0 r
.52584 .38397 m .52237 .38631 L .52412 .3844 L F
.856 .853 .838 r
.39373 .5646 m .38902 .56647 L .39002 .56382 L F
.496 .48 .769 r
.39463 .55942 m .39581 .56407 L .39373 .5646 L F
.28 .745 .947 r
.604 .33866 m .60826 .33916 L .60532 .33972 L F
.62 .188 .2 r
.31474 .65026 m .31266 .64851 L .31325 .65089 L F
0 0 .035 r
.31474 .65026 m .31325 .65089 L .31299 .6522 L F
.701 .627 .771 r
.32323 .6178 m .32553 .62246 L .3278 .61793 L F
.967 .662 .388 r
.32323 .6178 m .32553 .62246 L .32345 .62101 L F
.879 .867 .822 r
.3278 .61793 m .32553 .62246 L .32345 .62101 L F
.011 0 0 r
.48637 .40866 m .48874 .40807 L .48924 .4074 L F
0 0 0 r
.48924 .4074 m .49133 .40659 L .49217 .40455 L F
.48924 .4074 m .48874 .40807 L .49133 .40659 L F
.124 .483 .9 r
.60584 .37317 m .60537 .37517 L .60435 .37317 L F
.60584 .37317 m .60887 .37691 L .60537 .37517 L F
.849 .876 .86 r
.51167 .4623 m .51533 .46187 L .51377 .46078 L F
.861 .93 .869 r
.5167 .4576 m .51533 .46187 L .51839 .45924 L F
.5167 .4576 m .51377 .46078 L .51533 .46187 L F
.846 .957 .614 r
.30269 .63506 m .30075 .63762 L .30246 .63723 L F
.599 .246 .342 r
.30246 .63723 m .30533 .6375 L .30269 .63506 L F
.457 .722 .982 r
.29227 .65202 m .29387 .65135 L .29476 .65215 L F
.001 .082 .595 r
.29498 .65535 m .29309 .65463 L .29227 .65202 L F
.481 .326 .593 r
.36994 .57059 m .37069 .57386 L .37251 .5702 L F
.252 .016 .348 r
.48369 .41182 m .48552 .41322 L .48612 .41086 L F
.48369 .41182 m .48329 .41453 L .48552 .41322 L F
0 0 0 r
.45981 .45181 m .45652 .45438 L .45699 .45219 L F
.552 .023 0 r
.40165 .55384 m .40241 .55489 L .40017 .5526 L F
.40165 .55384 m .40397 .55609 L .40241 .55489 L F
.587 .056 0 r
.40017 .5526 m .40241 .55489 L .40087 .55379 L F
.567 .432 .656 r
.40241 .55489 m .40094 .5508 L .4009 .55235 L F
.40094 .5508 m .40093 .55077 L .40093 .55081 L F
.40094 .5508 m .40093 .55081 L .4009 .55235 L F
.949 .944 .739 r
.40017 .5526 m .3987 .55292 L .40093 .5481 L F
.881 .577 .064 r
.397 .54705 m .39843 .55201 L .3976 .55091 L F
.39843 .55201 m .3987 .55292 L .39818 .55197 L F
.39843 .55201 m .39818 .55197 L .3976 .55091 L F
.868 .814 .794 r
.39818 .55197 m .3989 .55283 L .3987 .55292 L F
.729 .619 .735 r
.40093 .5481 m .3987 .55292 L .397 .54705 L F
.949 .944 .739 r
.40017 .5526 m .40093 .5481 L .40148 .54924 L F
.159 0 .388 r
.40093 .5481 m .3987 .55292 L .40093 .55077 L F
.514 .344 .588 r
.39974 .55109 m .40093 .55077 L .39973 .55082 L F
.598 .329 .481 r
.39974 .55112 m .39948 .55118 L .39958 .55115 L F
.514 .344 .588 r
.40087 .55082 m .40093 .55077 L .39804 .55156 L F
.726 .316 .27 r
.40084 .54626 m .40093 .5481 L .397 .54705 L F
.847 .772 .779 r
.39982 .5475 m .39958 .55115 L .3976 .55091 L F
.813 .72 .762 r
.39982 .5475 m .399 .54877 L .40093 .55077 L F
.374 .463 .823 r
.39969 .54995 m .39974 .55112 L .39958 .55115 L F
.813 .72 .762 r
.399 .54877 m .39973 .55082 L .40093 .55077 L F
.726 .316 .27 r
.40084 .54626 m .397 .54705 L .3996 .54387 L F
.902 .983 .718 r
.40304 .54668 m .40093 .5481 L .40084 .54626 L F
.795 .754 .815 r
.40573 .54358 m .40304 .54668 L .40084 .54626 L F
.40573 .54358 m .40084 .54626 L .40377 .54175 L F
.899 .968 .819 r
.40377 .54175 m .40084 .54626 L .3999 .54446 L F
.40074 .54329 m .3999 .54446 L .3996 .54387 L F
.40377 .54175 m .3999 .54446 L .40074 .54329 L F
.72 .756 .881 r
.40932 .54241 m .40573 .54358 L .40377 .54175 L F
.507 0 0 r
.40377 .54175 m .40624 .54293 L .40826 .54259 L F
.40875 .54234 m .40826 .54259 L .40932 .54241 L F
.40377 .54175 m .40826 .54259 L .40875 .54234 L F
.603 .951 .896 r
.40624 .54293 m .40924 .54133 L .40932 .54241 L F
.587 .88 .993 r
.40772 .54221 m .4067 .54338 L .40924 .54133 L F
.818 .731 .769 r
.40919 .54371 m .40573 .54358 L .40932 .54241 L F
.587 .88 .993 r
.4067 .54338 m .40616 .54401 L .40713 .54316 L F
.4067 .54338 m .40713 .54316 L .40924 .54133 L F
.267 .362 .775 r
.40537 .53844 m .40377 .54175 L .40219 .54074 L F
.40537 .53844 m .40624 .54293 L .40377 .54175 L F
.517 .254 .454 r
.40295 .54019 m .4046 .54283 L .40537 .53844 L F
.40219 .54074 m .40242 .54093 L .40295 .54019 L F
.899 .968 .819 r
.40377 .54175 m .3996 .54387 L .40219 .54074 L F
.517 .254 .454 r
.40242 .54093 m .4046 .54283 L .40295 .54019 L F
.935 .967 .737 r
.40179 .54365 m .39982 .5475 L .40093 .5481 L F
.973 .693 .289 r
.39982 .5475 m .40093 .55077 L .40093 .5481 L F
.39 .306 .639 r
.397 .54705 m .39982 .5475 L .3996 .54387 L F
0 0 0 r
.397 .54705 m .39847 .54714 L .39982 .5475 L F
.585 .455 .67 r
.3996 .54387 m .39982 .5475 L .40179 .54365 L F
.374 .463 .823 r
.40015 .54508 m .39964 .55055 L .39847 .54714 L F
.39964 .55055 m .39958 .55115 L .39939 .55046 L F
.813 .72 .762 r
.399 .54877 m .39818 .55002 L .39964 .55055 L F
.374 .463 .823 r
.39964 .55055 m .39939 .55046 L .39847 .54714 L F
.813 .72 .762 r
.39964 .55055 m .3976 .55091 L .39973 .55082 L F
.39818 .55002 m .3976 .55091 L .39964 .55055 L F
.374 .463 .823 r
.39978 .54898 m .40045 .55098 L .39983 .5511 L F
.39975 .55087 m .39983 .5511 L .39974 .55112 L F
.39978 .54898 m .39983 .5511 L .39975 .55087 L F
.39978 .54898 m .39974 .55112 L .39969 .54995 L F
.485 .891 .766 r
.39958 .55115 m .39884 .55151 L .3976 .55091 L F
.514 .344 .588 r
.39804 .55156 m .39861 .5514 L .3976 .55091 L F
.3989 .55283 m .40087 .55082 L .39944 .5512 L F
.39823 .55184 m .39944 .5512 L .39804 .55156 L F
.3989 .55283 m .39944 .5512 L .39823 .55184 L F
.868 .814 .794 r
.39795 .55156 m .39823 .55184 L .39818 .55197 L F
.3976 .55091 m .39804 .55156 L .39795 .55156 L F
.39804 .55156 m .39823 .55184 L .39795 .55156 L F
.39823 .55184 m .3989 .55283 L .39818 .55197 L F
.3976 .55091 m .39601 .55291 L .3989 .55283 L F
.514 .344 .588 r
.3989 .55283 m .3976 .55091 L .39601 .55291 L F
.485 .891 .766 r
.39884 .55151 m .39601 .55291 L .3976 .55091 L F
.39944 .5512 m .39832 .55157 L .39832 .55158 L F
.39958 .55115 m .39944 .5512 L .39944 .5512 L F
.39944 .5512 m .39832 .55157 L .39944 .5512 L F
.514 .344 .588 r
.39861 .5514 m .39974 .55109 L .3976 .55091 L F
.39974 .55109 m .39973 .55082 L .3976 .55091 L F
.598 .329 .481 r
.40045 .55098 m .39842 .55158 L .39948 .55118 L F
.40045 .55098 m .39948 .55118 L .39974 .55112 L F
.485 .891 .766 r
.39832 .55158 m .39746 .55186 L .39745 .55187 L F
.39832 .55157 m .39746 .55186 L .39832 .55158 L F
.39958 .55115 m .39745 .55187 L .39797 .55194 L F
.598 .329 .481 r
.39842 .55158 m .39746 .55186 L .39832 .55157 L F
.39842 .55158 m .39832 .55157 L .39958 .55115 L F
.485 .891 .766 r
.39797 .55194 m .39745 .55187 L .39601 .55291 L F
.567 .432 .656 r
.40241 .55489 m .40546 .55139 L .40093 .55077 L F
.775 .623 .692 r
.40093 .55077 m .40546 .55139 L .40358 .54732 L F
.199 .723 .717 r
.40017 .5526 m .3989 .55283 L .3987 .55292 L F
.587 .056 0 r
.40017 .5526 m .40087 .55379 L .3989 .55283 L F
.514 .344 .588 r
.3989 .55283 m .40087 .55379 L .40093 .55077 L F
.598 .329 .481 r
.40364 .55036 m .39904 .55148 L .40045 .55098 L F
.39904 .55148 m .39746 .55186 L .40045 .55098 L F
.902 .983 .718 r
.40304 .54668 m .40148 .54924 L .40093 .5481 L F
.745 .668 .775 r
.40573 .54358 m .4072 .54744 L .40304 .54668 L F
.935 .967 .737 r
.40179 .54365 m .40093 .5481 L .40358 .54732 L F
.775 .623 .692 r
.40093 .55077 m .40358 .54732 L .40093 .5481 L F
.374 .463 .823 r
.40015 .54508 m .40364 .55036 L .40045 .55098 L F
.40015 .54508 m .40045 .55098 L .39978 .54898 L F
.567 .432 .656 r
.40151 .5542 m .4009 .55235 L .40088 .55371 L F
.40241 .55489 m .4009 .55235 L .40151 .5542 L F
.40241 .55489 m .40088 .55371 L .40087 .55379 L F
.552 .023 0 r
.40397 .55609 m .40407 .55619 L .40241 .55489 L F
.528 .37 .611 r
.52518 .36084 m .52583 .36366 L .52799 .36023 L F
.52518 .36084 m .52583 .36366 L .52799 .36023 L F
.246 .168 .566 r
.50972 .43536 m .51188 .43767 L .51224 .43502 L F
.50972 .43536 m .51019 .43795 L .51188 .43767 L F
.977 .839 .439 r
.55081 .3615 m .55002 .36048 L .54998 .35948 L F
.875 .855 .819 r
.45409 .52272 m .4516 .5263 L .45501 .52598 L F
.854 .723 .717 r
.45076 .52842 m .45501 .52598 L .4516 .5263 L F
.45076 .52842 m .45271 .53004 L .45501 .52598 L F
.836 .838 .848 r
.45409 .52272 m .45501 .52598 L .45782 .52294 L F
.138 .139 .596 r
.58559 .36061 m .58567 .36473 L .58749 .36241 L F
.294 .36 .76 r
.58567 .36473 m .58812 .36624 L .58749 .36241 L F
.266 .362 .775 r
.58567 .36473 m .58716 .36743 L .58812 .36624 L F
.771 .77 .852 r
.30826 .64897 m .30805 .65193 L .30996 .64975 L F
.30826 .64897 m .30996 .64975 L .3083 .64951 L F
.30826 .64897 m .3083 .64951 L .3074 .64938 L F
.154 0 0 r
.30996 .64975 m .3104 .65034 L .30845 .64972 L F
0 0 .346 r
.30866 .65182 m .30847 .65185 L .3083 .64951 L F
.30866 .65182 m .3083 .64951 L .30834 .64957 L F
.30847 .65185 m .30805 .65193 L .30823 .64933 L F
.30829 .64943 m .30823 .64933 L .30826 .64897 L F
.30847 .65185 m .30823 .64933 L .30829 .64943 L F
.943 .595 .324 r
.30834 .64957 m .30804 .64958 L .30642 .65003 L F
.509 0 0 r
.3074 .64938 m .30804 .64958 L .30642 .65003 L F
.943 .595 .324 r
.30804 .64958 m .30711 .64963 L .30642 .65003 L F
.30866 .65182 m .30834 .64957 L .30642 .65003 L F
.509 0 0 r
.30804 .64958 m .30845 .64972 L .30642 .65003 L F
.30845 .64972 m .3104 .65034 L .30874 .65021 L F
.30845 .64972 m .30874 .65021 L .30642 .65003 L F
.154 0 0 r
.3083 .64951 m .30834 .64957 L .3074 .64938 L F
.30834 .64957 m .30804 .64958 L .3074 .64938 L F
0 0 .346 r
.30834 .64957 m .3083 .64951 L .30826 .64897 L F
.943 .595 .324 r
.30834 .64957 m .30826 .64897 L .30711 .64963 L F
.154 0 0 r
.30834 .64957 m .30845 .64972 L .30804 .64958 L F
.30996 .64975 m .30845 .64972 L .3083 .64951 L F
.7 .96 .708 r
.56325 .39662 m .5622 .39836 L .56469 .39592 L F
0 0 0 r
.56674 .39548 m .56325 .39662 L .56469 .39592 L F
.537 .118 .193 r
.62768 .34368 m .62636 .34594 L .62342 .34428 L F
.818 .994 .754 r
.54396 .43176 m .54684 .42835 L .54467 .42933 L F
.819 .983 .703 r
.54225 .43261 m .54396 .43176 L .54467 .42933 L F
.225 .743 .852 r
.57125 .39539 m .57253 .39469 L .5698 .39551 L F
.57125 .39539 m .57457 .39494 L .57253 .39469 L F
.994 .758 .462 r
.39098 .48949 m .38923 .49091 L .38664 .48971 L F
.39098 .48949 m .39076 .49241 L .38923 .49091 L F
.583 .929 .951 r
.3786 .58058 m .38279 .57973 L .3809 .57899 L F
.165 .662 .914 r
.38279 .57973 m .38336 .579 L .3809 .57899 L F
.38279 .57973 m .38513 .57981 L .38336 .579 L F
.396 .816 .634 r
.44049 .54281 m .44082 .54267 L .44457 .54039 L F
.995 .821 .557 r
.37069 .57386 m .37131 .57757 L .36983 .57642 L F
0 .423 .804 r
.37131 .57757 m .37202 .57727 L .36983 .57642 L F
.37131 .57757 m .37436 .57871 L .37202 .57727 L F
.444 .155 .379 r
.44176 .44863 m .44451 .44806 L .445 .4457 L F
.381 .101 .358 r
.445 .4457 m .44715 .44726 L .44755 .44476 L F
.445 .4457 m .44451 .44806 L .44715 .44726 L F
.42 .213 .49 r
.61149 .38412 m .61227 .38321 L .61251 .38207 L F
.652 .11 0 r
.61277 .38085 m .61251 .38207 L .6142 .38132 L F
.729 .925 .957 r
.61508 .37872 m .61628 .37989 L .6142 .38132 L F
.829 .981 .692 r
.6142 .38132 m .61251 .38207 L .61508 .37872 L F
.42 .213 .49 r
.61227 .38321 m .6148 .38027 L .61251 .38207 L F
.652 .11 0 r
.61032 .38005 m .61251 .38207 L .61277 .38085 L F
.511 .531 .814 r
.55798 .4175 m .55567 .41881 L .55408 .41536 L F
.16 0 .215 r
.55509 .42082 m .55567 .41881 L .55798 .4175 L F
.961 .627 .259 r
.55408 .41536 m .55567 .41881 L .55372 .41667 L F
.208 0 0 r
.46129 .44767 m .46386 .44728 L .46581 .44526 L F
.528 .45 .712 r
.46581 .44526 m .46825 .44086 L .46566 .44268 L F
.388 .087 .329 r
.46865 .44451 m .46523 .44663 L .46581 .44526 L F
.46865 .44451 m .46835 .44729 L .46523 .44663 L F
0 0 0 r
.46865 .44451 m .47173 .44125 L .46825 .44086 L F
.46865 .44451 m .46825 .44086 L .47107 .44378 L F
.348 .056 .319 r
.47078 .44656 m .46865 .44451 L .47107 .44378 L F
.47078 .44656 m .46835 .44729 L .46865 .44451 L F
.528 .45 .712 r
.46581 .44526 m .46909 .44491 L .46825 .44086 L F
.385 .153 .435 r
.46529 .45047 m .46293 .44876 L .46523 .44663 L F
.385 .114 .375 r
.46792 .44962 m .46782 .44951 L .46835 .44729 L F
.46782 .44951 m .46523 .44663 L .46835 .44729 L F
.749 .456 .487 r
.4689 .44499 m .46835 .44729 L .46909 .44491 L F
.385 .114 .375 r
.46782 .44951 m .46529 .45047 L .46525 .44811 L F
.46627 .44784 m .46525 .44811 L .46523 .44672 L F
.46782 .44951 m .46525 .44811 L .46627 .44784 L F
.46782 .44951 m .46523 .44672 L .46533 .44674 L F
.286 0 .027 r
.46386 .44728 m .46609 .44784 L .46835 .44729 L F
.46834 .44729 m .46835 .44729 L .46835 .44729 L F
.191 .715 .699 r
.46835 .44729 m .46609 .44784 L .46859 .44719 L F
.46835 .44729 m .46835 .44729 L .46835 .44729 L F
.46835 .44729 m .46609 .44784 L .46835 .44729 L F
.286 0 .027 r
.46386 .44728 m .46835 .44729 L .46834 .44729 L F
.385 .114 .375 r
.46533 .44674 m .46523 .44672 L .46523 .44663 L F
.46792 .44962 m .46779 .44966 L .46782 .44951 L F
.46779 .44966 m .46529 .45047 L .46782 .44951 L F
.749 .456 .487 r
.46888 .445 m .46835 .44729 L .4689 .44499 L F
.46386 .44728 m .46834 .44729 L .46888 .445 L F
.46834 .44729 m .46835 .44729 L .46888 .445 L F
.46386 .44728 m .46909 .44491 L .46581 .44526 L F
.802 .697 .749 r
.46566 .44268 m .46123 .44483 L .46581 .44526 L F
.305 0 .171 r
.39889 .4786 m .4015 .47781 L .40221 .47615 L F
.285 0 .162 r
.40221 .47615 m .4015 .47781 L .40472 .47542 L F
.646 .544 .725 r
.30698 .62404 m .31097 .62628 L .31003 .62089 L F
.657 .538 .708 r
.30821 .62817 m .31097 .62628 L .30698 .62404 L F
0 0 0 r
.45358 .43806 m .45259 .44036 L .4554 .43717 L F
.584 .554 .787 r
.51019 .43795 m .51108 .44199 L .51441 .44119 L F
0 0 0 r
.49217 .40455 m .49133 .40659 L .49391 .40294 L F
0 0 .339 r
.58857 .39837 m .58921 .39902 L .58902 .39679 L F
.58857 .39837 m .58934 .40071 L .58921 .39902 L F
.136 0 0 r
.54688 .42273 m .5485 .42235 L .54531 .42227 L F
.836 .949 .893 r
.33344 .66793 m .33799 .66577 L .33601 .66758 L F
.912 .803 .726 r
.33799 .66577 m .3372 .66177 L .33674 .66478 L F
.996 .842 .573 r
.33601 .66758 m .33799 .66577 L .33674 .66478 L F
.62 .188 .2 r
.31474 .65026 m .31551 .64866 L .31266 .64851 L F
.017 0 0 r
.3153 .64923 m .31551 .64866 L .31474 .65026 L F
.611 .195 .228 r
.31266 .64851 m .3153 .64923 L .31474 .65026 L F
.3153 .64923 m .31611 .64946 L .31474 .65026 L F
.017 0 0 r
.31498 .65007 m .3153 .64923 L .31474 .65026 L F
.593 .133 .131 r
.3153 .64923 m .31551 .64866 L .31611 .64946 L F
.222 .057 .435 r
.31611 .64946 m .31551 .64866 L .31815 .64767 L F
.017 0 0 r
.31815 .64767 m .31551 .64866 L .31498 .65007 L F
.593 .133 .131 r
.31266 .64851 m .31551 .64866 L .3153 .64923 L F
.019 .402 .854 r
.33598 .62279 m .33681 .62476 L .33446 .62242 L F
.913 .698 .198 r
.33671 .62708 m .33681 .62476 L .33598 .62279 L F
.407 .114 .351 r
.43219 .47179 m .42906 .47471 L .42957 .4725 L F
.483 .877 .702 r
.61311 .39146 m .61072 .39216 L .61182 .39004 L F
.61311 .39146 m .60907 .39377 L .61072 .39216 L F
.348 0 0 r
.37844 .48323 m .3808 .48388 L .38236 .48221 L F
.522 .096 .173 r
.3808 .48388 m .38511 .48182 L .38236 .48221 L F
.581 .258 .387 r
.40706 .55263 m .40747 .55626 L .40407 .55619 L F
.702 .22 .102 r
.40752 .5494 m .41024 .55223 L .40706 .55263 L F
.305 .071 .384 r
.40967 .55512 m .40706 .55263 L .41024 .55223 L F
.40967 .55512 m .40747 .55626 L .40706 .55263 L F
.908 .982 .726 r
.55992 .39979 m .56043 .40094 L .5622 .39836 L F
.701 .963 .718 r
.56325 .39662 m .55992 .39979 L .5622 .39836 L F
.466 .68 .958 r
.35322 .57717 m .35145 .57344 L .35371 .57424 L F
.8 .924 .919 r
.62632 .37414 m .62314 .37461 L .62545 .37283 L F
.809 .963 .908 r
.62632 .37414 m .62885 .37009 L .62979 .37097 L F
.62632 .37414 m .62545 .37283 L .62885 .37009 L F
.885 .849 .803 r
.4623 .51239 m .45966 .51596 L .46315 .51564 L F
.872 .876 .836 r
.45966 .51596 m .45999 .51929 L .46315 .51564 L F
.899 .855 .79 r
.4623 .51239 m .46315 .51564 L .46412 .51374 L F
.042 0 .193 r
.47822 .41862 m .47754 .42097 L .48004 .4173 L F
0 0 0 r
.47534 .42228 m .47409 .42374 L .47754 .42097 L F
.54275 .35989 m .54449 .35903 L .54509 .358 L F
.072 .437 .875 r
.54809 .35787 m .54509 .358 L .54449 .35903 L F
.719 .645 .774 r
.43705 .52618 m .43872 .53009 L .43439 .52996 L F
.712 .482 .574 r
.43872 .53009 m .4345 .53236 L .43439 .52996 L F
.43872 .53009 m .43863 .53294 L .4345 .53236 L F
.702 .22 .102 r
.40752 .5494 m .41132 .55066 L .41024 .55223 L F
.52 .802 .997 r
.41132 .55066 m .41154 .55268 L .41024 .55223 L F
.41132 .55066 m .41421 .54985 L .41221 .54853 L F
.41132 .55066 m .41221 .54853 L .41154 .55268 L F
.426 .763 .996 r
.31028 .67018 m .31106 .66835 L .30851 .66775 L F
.31028 .67018 m .31255 .66992 L .31106 .66835 L F
.236 .753 .779 r
.31028 .67018 m .31441 .67234 L .31255 .66992 L F
.818 .731 .769 r
.40919 .54371 m .41046 .54659 L .4072 .54744 L F
.819 .744 .781 r
.41046 .54659 m .40752 .5494 L .4072 .54744 L F
.236 .402 .825 r
.41231 .54561 m .41046 .54659 L .40919 .54371 L F
.4 0 .066 r
.62342 .34428 m .62349 .34541 L .62028 .34556 L F
.55 .065 .058 r
.62342 .34428 m .62636 .34594 L .62349 .34541 L F
.429 .586 .906 r
.37754 .56673 m .37685 .56988 L .3753 .56669 L F
.37754 .56673 m .37939 .57001 L .37685 .56988 L F
.815 .627 .649 r
.50864 .4241 m .50679 .42735 L .50713 .42453 L F
.444 .333 .634 r
.50679 .42735 m .50794 .4241 L .50713 .42453 L F
.50794 .4241 m .50852 .42248 L .50713 .42453 L F
.734 .991 .843 r
.51044 .42276 m .5095 .42326 L .50977 .42271 L F
.51066 .42281 m .50792 .42415 L .51044 .42276 L F
.50792 .42415 m .50713 .42453 L .50804 .42405 L F
.50792 .42415 m .50804 .42405 L .51044 .42276 L F
.5095 .42326 m .50794 .4241 L .50969 .42272 L F
.51066 .42281 m .50864 .4241 L .50713 .42453 L F
.631 .863 .986 r
.50881 .42601 m .51381 .42474 L .51178 .4233 L F
.50881 .42601 m .51178 .4233 L .51158 .42491 L F
.03 0 .25 r
.51158 .42491 m .50981 .42703 L .50881 .42601 L F
.395 .304 .633 r
.50925 .42306 m .50981 .42703 L .51158 .42491 L F
.50852 .42248 m .50879 .42343 L .50925 .42306 L F
.50879 .42343 m .50981 .42703 L .50925 .42306 L F
.50968 .42277 m .51158 .42491 L .51178 .4233 L F
.50852 .42248 m .50925 .42306 L .50968 .42277 L F
.734 .991 .843 r
.5095 .42326 m .50969 .42272 L .50981 .42264 L F
.395 .304 .633 r
.50925 .42306 m .51158 .42491 L .50968 .42277 L F
.734 .991 .843 r
.50986 .42265 m .50977 .42271 L .50981 .42264 L F
.51044 .42276 m .50977 .42271 L .50986 .42265 L F
.122 .551 .919 r
.50852 .42248 m .50968 .42277 L .50973 .42262 L F
.50968 .42277 m .51178 .4233 L .50973 .42262 L F
.815 .627 .649 r
.50864 .4241 m .50881 .42601 L .50679 .42735 L F
.415 .205 .483 r
.50981 .42703 m .50679 .42735 L .50881 .42601 L F
.444 .333 .634 r
.50679 .42735 m .50981 .42703 L .50879 .42343 L F
.50794 .4241 m .50879 .42343 L .50852 .42248 L F
.50679 .42735 m .50879 .42343 L .50794 .4241 L F
.734 .991 .843 r
.50981 .42264 m .50713 .42453 L .50973 .42262 L F
.50794 .4241 m .50713 .42453 L .50981 .42264 L F
.388 .849 .827 r
.51344 .42182 m .51066 .42281 L .50973 .42262 L F
.38 .65 .963 r
.37576 .58041 m .37651 .57859 L .37436 .57871 L F
.37576 .58041 m .3786 .58058 L .37651 .57859 L F
.36 0 0 r
.39553 .49333 m .39263 .49323 L .39236 .49272 L F
.555 .924 .935 r
.39669 .4918 m .39263 .49323 L .39528 .49332 L F
.39669 .4918 m .39528 .49332 L .39553 .49333 L F
.33 .008 .259 r
.39872 .49017 m .39717 .4913 L .39669 .4918 L F
.39717 .4913 m .3956 .49244 L .39669 .4918 L F
.05 0 0 r
.3956 .49244 m .39279 .49351 L .39263 .49323 L F
.39279 .49351 m .39176 .49391 L .39263 .49323 L F
.36 0 0 r
.39236 .49272 m .39263 .49323 L .39076 .49241 L F
.555 .924 .935 r
.39669 .4918 m .39553 .49333 L .39711 .49176 L F
.813 .923 .91 r
.46485 .4866 m .46008 .48826 L .46329 .48527 L F
.846 .99 .852 r
.50977 .45217 m .50873 .45157 L .50993 .44992 L F
.50977 .45217 m .50873 .45157 L .50993 .44992 L F
.896 .889 .816 r
.45848 .5178 m .45999 .51929 L .45966 .51596 L F
.904 .861 .788 r
.45707 .51971 m .45999 .51929 L .45848 .5178 L F
.45707 .51971 m .45782 .52294 L .45999 .51929 L F
0 .133 .67 r
.58893 .37384 m .58963 .37186 L .5884 .37036 L F
0 0 .54 r
.58893 .37384 m .59044 .37597 L .58963 .37186 L F
.867 .985 .84 r
.53683 .43989 m .53392 .44307 L .5364 .4426 L F
0 0 .092 r
.48074 .4153 m .48206 .41564 L .48329 .41453 L F
.48074 .4153 m .48004 .4173 L .48206 .41564 L F
.687 .697 .854 r
.47106 .43836 m .47513 .43877 L .47317 .43385 L F
.727 .54 .638 r
.47106 .43836 m .47173 .44125 L .47513 .43877 L F
0 0 .139 r
.47513 .43877 m .47697 .43461 L .47763 .43786 L F
.548 .617 .874 r
.47317 .43385 m .47513 .43877 L .47763 .43786 L F
.225 .746 .803 r
.41107 .53007 m .41338 .52986 L .4122 .52594 L F
.41107 .53007 m .41631 .52926 L .41338 .52986 L F
.567 .865 .557 r
.54684 .42835 m .54981 .42531 L .54832 .4266 L F
.601 .936 .743 r
.54467 .42933 m .54684 .42835 L .54832 .4266 L F
.564 .401 .62 r
.37655 .55364 m .37392 .55732 L .37682 .55664 L F
.37655 .55364 m .37392 .55732 L .37682 .55664 L F
.154 0 0 r
.30996 .64975 m .31266 .64851 L .3104 .65034 L F
.611 .195 .228 r
.31266 .64851 m .31474 .65026 L .3104 .65034 L F
.633 .197 .197 r
.59299 .35027 m .59577 .35227 L .59698 .3503 L F
.332 0 .04 r
.59698 .3503 m .59848 .3502 L .59989 .34993 L F
.59698 .3503 m .59649 .3511 L .59848 .3502 L F
.59649 .3511 m .59723 .35116 L .59848 .3502 L F
.529 .128 .224 r
.59848 .3502 m .59577 .35227 L .60009 .35146 L F
0 .564 .781 r
.59441 .35057 m .59733 .3508 L .59959 .35134 L F
.59905 .3513 m .59959 .35134 L .60009 .35146 L F
.59441 .35057 m .59959 .35134 L .59905 .3513 L F
.332 0 .04 r
.59649 .3511 m .59577 .35227 L .59723 .35116 L F
.901 .797 .736 r
.52898 .38241 m .5311 .38805 L .52921 .38668 L F
.847 .982 .695 r
.5311 .38805 m .52894 .38941 L .52921 .38668 L F
.628 .667 .869 r
.53412 .3869 m .5311 .38805 L .52898 .38241 L F
.833 .798 .818 r
.46412 .51374 m .46465 .50876 L .4623 .51239 L F
.46412 .51374 m .46666 .5103 L .46465 .50876 L F
.817 .826 .857 r
.47878 .47166 m .47385 .47132 L .47747 .4687 L F
.47878 .47166 m .4758 .47294 L .47385 .47132 L F
.639 .819 .97 r
.48098 .47018 m .47878 .47166 L .47747 .4687 L F
.622 .725 .92 r
.48208 .47194 m .47878 .47166 L .48098 .47018 L F
0 0 0 r
.54832 .4266 m .54981 .42531 L .55187 .42381 L F
.55983 .4003 m .55614 .40408 L .55504 .40665 L F
.84 .832 .839 r
.45707 .51971 m .45409 .52272 L .45782 .52294 L F
.836 .954 .892 r
.41421 .54985 m .41732 .54846 L .41661 .54641 L F
.709 .777 .289 r
.41732 .54846 m .4154 .55367 L .41598 .55178 L F
.606 .462 .659 r
.41732 .54846 m .41818 .55336 L .4154 .55367 L F
0 .255 .764 r
.41973 .5492 m .42151 .55245 L .42011 .55111 L F
.41973 .5492 m .42011 .55111 L .41732 .54846 L F
.703 .717 .86 r
.42151 .55245 m .41818 .55336 L .41732 .54846 L F
0 .255 .764 r
.41973 .5492 m .41732 .54846 L .41598 .55178 L F
.832 .851 .861 r
.41661 .54641 m .4212 .54456 L .41956 .54303 L F
.88 .859 .816 r
.41221 .54853 m .41421 .54985 L .41661 .54641 L F
.805 .692 .739 r
.41231 .54561 m .41661 .54641 L .41498 .54228 L F
.88 .859 .816 r
.41221 .54853 m .41661 .54641 L .41231 .54561 L F
.748 .665 .77 r
.41498 .54228 m .41661 .54641 L .41956 .54303 L F
.779 .616 .678 r
.41582 .54327 m .41772 .54866 L .41548 .54673 L F
.404 .403 .745 r
.41789 .54652 m .41787 .54851 L .41582 .54327 L F
.73 .93 .593 r
.41952 .54817 m .41711 .54924 L .41767 .54871 L F
.404 .403 .745 r
.41787 .54851 m .41787 .5491 L .41772 .54866 L F
.41787 .54851 m .41772 .54866 L .41582 .54327 L F
.73 .93 .593 r
.41952 .54817 m .41973 .5492 L .41711 .54924 L F
.41767 .54871 m .41711 .54924 L .41582 .54925 L F
.761 .619 .701 r
.41548 .54673 m .41749 .54873 L .41437 .54971 L F
.73 .93 .593 r
.41749 .54873 m .41582 .54925 L .4157 .54926 L F
.41749 .54873 m .4157 .54926 L .41626 .54906 L F
.41952 .54817 m .41582 .54925 L .41749 .54873 L F
.761 .619 .701 r
.41749 .54873 m .41787 .5491 L .41437 .54971 L F
.779 .616 .678 r
.41772 .54866 m .41787 .5491 L .41749 .54873 L F
.41772 .54866 m .41749 .54873 L .41548 .54673 L F
.741 .653 .763 r
.41787 .54851 m .41437 .54971 L .41787 .5491 L F
.41789 .54652 m .41437 .54971 L .41787 .54851 L F
.73 .93 .593 r
.41626 .54906 m .4157 .54926 L .41556 .54926 L F
.41556 .54926 m .41973 .5492 L .41437 .54971 L F
.41944 .54778 m .41952 .54817 L .41556 .54926 L F
.42066 .54732 m .41973 .5492 L .41944 .54778 L F
.157 0 .329 r
.48637 .40866 m .4881 .40953 L .48874 .40807 L F
.48637 .40866 m .48612 .41086 L .4881 .40953 L F
.735 .857 .938 r
.49588 .4746 m .50017 .47451 L .49921 .47192 L F
.816 .859 .88 r
.49921 .47192 m .50017 .47451 L .50278 .47186 L F
.347 0 0 r
.60826 .33916 m .61033 .33988 L .61228 .34027 L F
.665 .115 0 r
.61033 .33988 m .61088 .34062 L .61228 .34027 L F
.911 .699 .603 r
.49022 .46175 m .48652 .4638 L .4885 .46035 L F
.49022 .46175 m .48882 .46456 L .48652 .4638 L F
.873 .89 .843 r
.49292 .4584 m .49022 .46175 L .4885 .46035 L F
.807 .683 .727 r
.4317 .53313 m .43393 .5378 L .42934 .53571 L F
.512 .447 .72 r
.4345 .53236 m .43393 .5378 L .4317 .53313 L F
.4345 .53236 m .4354 .53578 L .43393 .5378 L F
.807 .997 .857 r
.65202 .37484 m .65372 .37302 L .65307 .37215 L F
.791 .985 .897 r
.64976 .37483 m .65202 .37484 L .65307 .37215 L F
.907 .975 .798 r
.49881 .44934 m .49643 .45258 L .49666 .44947 L F
.724 .987 .884 r
.50128 .44722 m .49881 .44934 L .49666 .44947 L F
.958 .944 .65 r
.49643 .45258 m .49544 .45514 L .49459 .45393 L F
.905 .921 .818 r
.49544 .45514 m .49149 .45702 L .49459 .45393 L F
.49544 .45514 m .49292 .4584 L .49149 .45702 L F
.847 .907 .877 r
.47791 .49116 m .4825 .48931 L .48097 .48811 L F
.859 .918 .869 r
.48393 .48486 m .4825 .48931 L .48558 .48619 L F
.48393 .48486 m .48097 .48811 L .4825 .48931 L F
.963 .632 .303 r
.54582 .388 m .54348 .3836 L .54776 .38431 L F
.465 .184 .402 r
.54776 .38431 m .55039 .38613 L .55049 .38377 L F
0 .163 .621 r
.54879 .38484 m .54776 .38431 L .54711 .38252 L F
.54856 .38472 m .55039 .38613 L .54776 .38431 L F
.808 .638 .671 r
.55039 .38613 m .55142 .38983 L .55513 .39024 L F
.917 .691 .582 r
.55039 .38613 m .54828 .38873 L .55142 .38983 L F
0 .163 .621 r
.54938 .38531 m .55039 .38613 L .54856 .38472 L F
.812 .477 .422 r
.55049 .38377 m .55039 .38613 L .55164 .38463 L F
.723 .86 .947 r
.55133 .38462 m .55039 .38613 L .54879 .38484 L F
.639 .421 .57 r
.55133 .38462 m .54882 .388 L .55039 .38613 L F
.54882 .388 m .54828 .38873 L .55039 .38613 L F
.812 .477 .422 r
.55164 .38463 m .55039 .38613 L .55461 .38687 L F
.639 .421 .57 r
.55031 .38599 m .55289 .38834 L .54828 .38873 L F
.808 .638 .671 r
.55039 .38613 m .55513 .39024 L .55461 .38687 L F
.639 .421 .57 r
.55133 .38462 m .55261 .38765 L .55031 .38599 L F
.55261 .38765 m .55289 .38834 L .55031 .38599 L F
0 .163 .621 r
.54879 .38484 m .54938 .38531 L .54856 .38472 L F
.198 0 0 r
.35856 .57988 m .36015 .58093 L .35858 .57987 L F
.28 .715 .966 r
.35741 .58102 m .36141 .58177 L .36015 .58093 L F
.873 .465 .248 r
.35426 .57887 m .35741 .58102 L .35553 .58222 L F
.198 0 0 r
.35553 .58222 m .35741 .58102 L .36015 .58093 L F
.35553 .58222 m .36015 .58093 L .35856 .57988 L F
.28 .715 .966 r
.36141 .58177 m .36167 .58182 L .36015 .58093 L F
.588 .944 .813 r
.36167 .58182 m .36292 .58031 L .36015 .58093 L F
.436 .482 .809 r
.37531 .56385 m .37829 .56402 L .37682 .55996 L F
0 0 0 r
.31441 .67234 m .31666 .67139 L .3161 .67173 L F
.31441 .67234 m .3161 .67173 L .31255 .66992 L F
.781 .804 .871 r
.48546 .46961 m .48208 .47194 L .48098 .47018 L F
.329 .023 .286 r
.42009 .46823 m .42332 .46434 L .4207 .4652 L F
.452 .137 .34 r
.41712 .46872 m .42009 .46823 L .4207 .4652 L F
.074 0 0 r
.41498 .54228 m .41765 .54168 L .41936 .54025 L F
.956 .624 .34 r
.41765 .54168 m .41956 .54303 L .41936 .54025 L F
.931 .963 .664 r
.49666 .44947 m .49643 .45258 L .49459 .45393 L F
.846 .668 .661 r
.44099 .51257 m .44317 .51676 L .43899 .51562 L F
.88 .683 .632 r
.44203 .51918 m .43899 .51562 L .44317 .51676 L F
0 0 0 r
.58258 .37874 m .58162 .38323 L .58225 .38094 L F
.766 .666 .752 r
.55935 .37976 m .55476 .384 L .55851 .38417 L F
.525 .188 .339 r
.55461 .38687 m .55851 .38417 L .55476 .384 L F
.55461 .38687 m .55857 .38641 L .55851 .38417 L F
0 0 0 r
.55857 .38641 m .56174 .38343 L .55851 .38417 L F
.097 0 0 r
.45014 .45853 m .44708 .46086 L .44793 .45953 L F
.706 .169 0 r
.4154 .55367 m .41767 .55601 L .41544 .55512 L F
.568 .316 .494 r
.41818 .55336 m .41767 .55601 L .4154 .55367 L F
.706 .169 0 r
.4154 .55367 m .41544 .55512 L .41598 .55178 L F
.766 .713 .803 r
.43705 .52618 m .43439 .52996 L .43284 .52554 L F
.788 .725 .793 r
.43284 .52554 m .43439 .52996 L .43002 .52902 L F
.816 .657 .686 r
.43439 .52996 m .4317 .53313 L .43002 .52902 L F
.697 .477 .585 r
.4345 .53236 m .4317 .53313 L .43439 .52996 L F
.34 .761 .976 r
.3721 .54624 m .37537 .54704 L .37075 .54633 L F
.514 .807 .999 r
.37594 .54506 m .37537 .54704 L .37334 .5457 L F
.37594 .54506 m .37537 .54704 L .37334 .5457 L F
.041 .13 .631 r
.58559 .36061 m .58749 .36241 L .58686 .35815 L F
.828 .857 .868 r
.46722 .5051 m .47193 .5035 L .47018 .50206 L F
.862 .864 .839 r
.47018 .50206 m .47193 .5035 L .47472 .49979 L F
.473 .166 .364 r
.29567 .64115 m .30075 .63762 L .29612 .63856 L F
.773 .568 .622 r
.46825 .44086 m .47173 .44125 L .47106 .43836 L F
.687 .697 .854 r
.47106 .43836 m .47317 .43385 L .47026 .43559 L F
.517 0 0 r
.40568 .56002 m .40844 .5613 L .4116 .56051 L F
.126 0 0 r
.40844 .5613 m .41301 .56047 L .4116 .56051 L F
.51 .836 .54 r
.55733 .37717 m .55665 .37777 L .55865 .37587 L F
.746 .742 .848 r
.54006 .37075 m .54199 .37414 L .53779 .37349 L F
.212 .702 .925 r
.54199 .37414 m .54124 .37358 L .53779 .37349 L F
.248 0 .074 r
.54552 .3708 m .54452 .37119 L .54266 .37116 L F
.255 .475 .879 r
.54266 .37116 m .54199 .37414 L .54026 .37111 L F
.82 .997 .847 r
.54266 .37116 m .54124 .37358 L .54199 .37414 L F
.283 0 0 r
.53959 .37311 m .54124 .37358 L .54266 .37116 L F
.248 0 .074 r
.54452 .37119 m .53959 .37311 L .54266 .37116 L F
.255 .475 .879 r
.54266 .37116 m .54026 .37111 L .54006 .37075 L F
0 .097 .637 r
.42077 .56449 m .42154 .56247 L .41951 .55982 L F
.111 .336 .805 r
.42077 .56449 m .42348 .56594 L .42154 .56247 L F
.497 .415 .693 r
.41301 .56047 m .41284 .56373 L .41026 .56408 L F
0 .029 .594 r
.41203 .56514 m .41026 .56408 L .41284 .56373 L F
.013 0 0 r
.46865 .42782 m .47103 .42708 L .47194 .42496 L F
0 0 0 r
.47194 .42496 m .47317 .42585 L .47409 .42374 L F
.47194 .42496 m .47103 .42708 L .47317 .42585 L F
.314 .121 .451 r
.37682 .55664 m .37936 .55301 L .37655 .55364 L F
.725 .646 .77 r
.37936 .55301 m .37682 .55664 L .37655 .55364 L F
.396 .816 .634 r
.44049 .54281 m .44457 .54039 L .44238 .53897 L F
.816 .781 .82 r
.44238 .53897 m .44457 .54039 L .4473 .53708 L F
.966 .901 .706 r
.6294 .34162 m .63084 .3435 L .63174 .34029 L F
.524 .264 .463 r
.46293 .44876 m .46278 .45152 L .45981 .45181 L F
.385 .153 .435 r
.46529 .45047 m .46278 .45152 L .46293 .44876 L F
.71 .783 .909 r
.42875 .54197 m .42732 .54555 L .42518 .54475 L F
.42875 .54197 m .43085 .54381 L .42732 .54555 L F
.136 .346 .808 r
.58358 .36809 m .58357 .37073 L .58171 .3672 L F
.74 .678 .13 r
.58358 .36809 m .58295 .37339 L .58357 .37073 L F
.555 .561 .814 r
.29607 .65756 m .29777 .66161 L .30016 .65886 L F
.44 .392 .707 r
.30016 .65886 m .29777 .66161 L .30202 .66119 L F
.261 .412 .825 r
.29777 .66161 m .30143 .66548 L .30202 .66119 L F
.939 .922 .767 r
.51275 .44892 m .50993 .44992 L .51153 .44756 L F
.802 .925 .917 r
.51442 .4475 m .51275 .44892 L .51153 .44756 L F
.939 .922 .767 r
.51275 .44892 m .50993 .44992 L .51153 .44756 L F
0 .457 .772 r
.5494 .39204 m .54739 .39109 L .54495 .39053 L F
.69 .956 .95 r
.55142 .38983 m .5494 .39204 L .55266 .39105 L F
.55142 .38983 m .54739 .39109 L .5494 .39204 L F
.085 0 0 r
.46504 .43074 m .46756 .42975 L .46865 .42782 L F
.119 0 0 r
.46865 .42782 m .47007 .42883 L .47103 .42708 L F
.46865 .42782 m .46756 .42975 L .47007 .42883 L F
.408 .105 .335 r
.42676 .46201 m .42951 .46132 L .42989 .45914 L F
.289 .007 .299 r
.42989 .45914 m .4319 .4604 L .43249 .45858 L F
.42989 .45914 m .42951 .46132 L .4319 .4604 L F
.883 .894 .835 r
.37912 .55586 m .37855 .56026 L .38137 .55747 L F
.745 .662 .768 r
.37682 .55996 m .37978 .56263 L .37855 .56026 L F
.895 .654 .566 r
.33958 .63444 m .34196 .63506 L .33977 .63148 L F
.877 .539 .406 r
.33976 .63693 m .34196 .63506 L .33958 .63444 L F
.987 .817 .586 r
.33976 .63693 m .34148 .63802 L .34196 .63506 L F
.33976 .63693 m .34148 .63802 L .34196 .63506 L F
.963 .632 .303 r
.54582 .388 m .54391 .38679 L .54348 .3836 L F
.984 .816 .597 r
.54582 .388 m .54495 .39053 L .54391 .38679 L F
.474 .877 .719 r
.50749 .39428 m .50923 .3929 L .51001 .39268 L F
.486 .901 .844 r
.50749 .39428 m .50389 .39506 L .50923 .3929 L F
.873 .89 .843 r
.49292 .4584 m .4885 .46035 L .49149 .45702 L F
.893 .972 .824 r
.63153 .33844 m .63174 .34029 L .63398 .33775 L F
.96 .822 .663 r
.63245 .33584 m .63153 .33844 L .63398 .33775 L F
.334 .074 .364 r
.44176 .44863 m .43892 .45191 L .44134 .45092 L F
.314 .058 .357 r
.44176 .44863 m .44374 .44989 L .44451 .44806 L F
.44176 .44863 m .44134 .45092 L .44374 .44989 L F
0 0 .159 r
.56085 .40283 m .56043 .40094 L .55992 .39979 L F
0 0 0 r
.56103 .4028 m .56085 .40283 L .56243 .40068 L F
0 0 .159 r
.56085 .40283 m .56038 .40445 L .5604 .40291 L F
.859 .757 .246 r
.55974 .40476 m .56038 .40445 L .56085 .40283 L F
0 0 0 r
.55974 .40476 m .56085 .40283 L .56103 .4028 L F
0 0 .159 r
.56085 .40283 m .5604 .40291 L .56043 .40094 L F
.537 .248 .424 r
.45386 .45512 m .4533 .45834 L .45014 .45853 L F
.39 .121 .381 r
.45602 .45761 m .45386 .45512 L .45652 .45438 L F
.45602 .45761 m .4533 .45834 L .45386 .45512 L F
0 0 0 r
.49543 .41249 m .49389 .4146 L .49611 .41023 L F
.945 .916 .544 r
.59062 .38756 m .58957 .39016 L .5891 .38891 L F
.875 .939 .57 r
.59062 .38756 m .5891 .38891 L .5904 .38665 L F
.574 .814 .989 r
.64693 .33788 m .64986 .33694 L .64871 .33532 L F
.449 .762 .996 r
.56646 .34316 m .57039 .34258 L .57141 .34413 L F
.974 .919 .673 r
.57039 .34258 m .5693 .34495 L .57141 .34413 L F
.385 0 0 r
.40472 .48896 m .40329 .48955 L .40051 .4887 L F
.388 0 0 r
.4078 .48881 m .40329 .48955 L .40472 .48896 L F
.323 0 .008 r
.39462 .48118 m .39742 .48075 L .39889 .4786 L F
0 0 0 r
.39889 .4786 m .39965 .4796 L .4015 .47781 L F
.39889 .4786 m .39742 .48075 L .39965 .4796 L F
.818 .647 .671 r
.34374 .64208 m .34148 .63802 L .34121 .64071 L F
.843 .718 .726 r
.3423 .64478 m .34374 .64208 L .34121 .64071 L F
.885 .839 .795 r
.47285 .47607 m .46862 .47822 L .47111 .47469 L F
.47285 .47607 m .47061 .47967 L .46862 .47822 L F
.839 .861 .861 r
.4758 .47294 m .47285 .47607 L .47111 .47469 L F
.221 .617 .953 r
.30404 .66581 m .30652 .66773 L .30851 .66775 L F
.786 .754 .823 r
.44762 .53231 m .44989 .5334 L .44818 .53058 L F
.845 .772 .781 r
.44533 .53543 m .44989 .5334 L .44762 .53231 L F
.44533 .53543 m .4473 .53708 L .44989 .5334 L F
.805 .759 .81 r
.44818 .53058 m .44989 .5334 L .45271 .53004 L F
.363 0 .1 r
.4103 .47181 m .41379 .47058 L .41435 .46917 L F
.441 .013 .129 r
.41379 .47058 m .41658 .47045 L .41435 .46917 L F
.417 .042 .216 r
.41435 .46917 m .41658 .47045 L .41712 .46872 L F
.202 0 0 r
.54735 .36795 m .54365 .36755 L .54751 .36754 L F
.29 0 0 r
.54866 .36817 m .54751 .36754 L .55053 .36634 L F
.808 .585 .601 r
.54866 .36817 m .54624 .37085 L .54735 .36795 L F
.72 .977 .92 r
.54624 .37085 m .54725 .36895 L .54756 .3682 L F
.54754 .36808 m .54756 .3682 L .54818 .36671 L F
.54624 .37085 m .54756 .3682 L .54754 .36808 L F
.29 0 0 r
.54866 .36817 m .54752 .36798 L .54751 .36754 L F
.54752 .36798 m .54735 .36795 L .54746 .36768 L F
.54752 .36798 m .54746 .36768 L .54751 .36754 L F
.484 .253 .488 r
.35003 .56149 m .35299 .56069 L .3485 .55958 L F
.35003 .56149 m .35294 .56467 L .35299 .56069 L F
.475 .306 .572 r
.56688 .36097 m .56943 .35653 L .5674 .35832 L F
.249 0 .193 r
.43815 .45368 m .44134 .45092 L .43892 .45191 L F
.582 .362 .547 r
.58609 .35033 m .58624 .353 L .58841 .35044 L F
.299 .012 .298 r
.41738 .48258 m .41683 .48465 L .41444 .48572 L F
.379 .082 .329 r
.41738 .48258 m .42001 .48191 L .41683 .48465 L F
.442 .246 .517 r
.51622 .41808 m .5162 .42079 L .51903 .4173 L F
.547 .641 .895 r
.51835 .41467 m .51622 .41808 L .51903 .4173 L F
0 .116 .637 r
.29489 .65599 m .29309 .65463 L .29498 .65535 L F
.29489 .65599 m .29607 .65756 L .29309 .65463 L F
.653 .469 .622 r
.3485 .55958 m .35299 .56069 L .35218 .55618 L F
.638 .458 .624 r
.35218 .55618 m .35625 .55979 L .35501 .55547 L F
.35218 .55618 m .35299 .56069 L .35625 .55979 L F
.781 .804 .871 r
.48546 .46961 m .48098 .47018 L .48363 .46855 L F
.675 .912 .975 r
.48546 .46961 m .48632 .46713 L .48749 .46784 L F
.48546 .46961 m .48363 .46855 L .48632 .46713 L F
0 0 0 r
.56674 .39548 m .56589 .39597 L .56325 .39662 L F
.089 0 0 r
.5698 .39551 m .56589 .39597 L .56674 .39548 L F
0 0 0 r
.51799 .44152 m .52163 .43886 L .51937 .43864 L F
.029 0 0 r
.51654 .43854 m .5187 .43863 L .52072 .43858 L F
0 0 0 r
.5187 .43863 m .51937 .43864 L .51762 .43847 L F
0 .542 .761 r
.51762 .43847 m .51871 .43863 L .5187 .43863 L F
.51762 .43847 m .5187 .43863 L .51654 .43854 L F
0 0 0 r
.51764 .43862 m .5187 .43863 L .51762 .43847 L F
.51799 .44152 m .51937 .43864 L .51764 .43862 L F
.029 0 0 r
.5187 .43863 m .51871 .43863 L .51871 .43863 L F
.5187 .43863 m .51871 .43863 L .52072 .43858 L F
0 0 0 r
.51799 .44152 m .52053 .44069 L .52163 .43886 L F
.978 .799 .385 r
.52163 .43886 m .52053 .44069 L .5206 .43999 L F
.12 0 0 r
.52072 .43858 m .52163 .43886 L .52283 .43754 L F
.52072 .43858 m .51871 .43863 L .52163 .43886 L F
.788 .673 .738 r
.52163 .43886 m .51871 .43863 L .51762 .43847 L F
.978 .799 .385 r
.52163 .43886 m .5206 .43999 L .52086 .43756 L F
.12 0 0 r
.52283 .43754 m .52163 .43886 L .52302 .43745 L F
0 0 0 r
.62292 .39375 m .62695 .39062 L .62546 .39327 L F
.692 .413 .496 r
.62946 .39054 m .62546 .39327 L .62695 .39062 L F
.616 .78 .96 r
.38513 .57981 m .38938 .58064 L .38772 .57926 L F
.44 .756 .995 r
.38772 .57926 m .38938 .58064 L .39028 .57891 L F
.475 .796 .999 r
.38938 .58064 m .39205 .58013 L .39028 .57891 L F
.517 .252 .452 r
.42642 .47549 m .42577 .47745 L .42292 .47912 L F
.399 .123 .375 r
.42906 .47471 m .42577 .47745 L .42642 .47549 L F
.751 .784 .88 r
.51839 .45924 m .51972 .4544 L .5167 .4576 L F
.51839 .45924 m .52038 .45791 L .51972 .4544 L F
0 0 .207 r
.59045 .38032 m .59075 .37865 L .59044 .37597 L F
0 0 .418 r
.59088 .38266 m .59075 .37865 L .59045 .38032 L F
0 0 .51 r
.31003 .62089 m .31097 .62628 L .31149 .62349 L F
.219 .37 .802 r
.31156 .62309 m .31097 .62628 L .31329 .62704 L F
.622 .351 .486 r
.31182 .62561 m .30868 .62907 L .31124 .62505 L F
.31329 .62704 m .31211 .62756 L .31182 .62561 L F
.31211 .62756 m .30868 .62907 L .31182 .62561 L F
0 0 .51 r
.31003 .62089 m .31149 .62349 L .31139 .62284 L F
.31003 .62089 m .31156 .62309 L .31206 .62046 L F
.492 .305 .554 r
.3099 .6255 m .31242 .62162 L .31156 .62309 L F
.374 .129 .409 r
.31443 .61999 m .31206 .62046 L .312 .62082 L F
.31443 .61999 m .312 .62082 L .31156 .62309 L F
.668 .928 .635 r
.31443 .61999 m .31156 .62309 L .31244 .62158 L F
.512 .115 .226 r
.31244 .62158 m .31672 .61921 L .31443 .61999 L F
.31672 .61921 m .31691 .6191 L .31443 .61999 L F
.492 .305 .554 r
.31242 .62162 m .31244 .62158 L .31156 .62309 L F
0 0 .51 r
.31139 .62284 m .31146 .62327 L .31156 .62309 L F
.31146 .62327 m .31149 .62349 L .31156 .62309 L F
.05 0 0 r
.38664 .48971 m .38485 .49026 L .3822 .49044 L F
.423 0 0 r
.38664 .48971 m .38923 .49091 L .38485 .49026 L F
.631 .443 .61 r
.49389 .4146 m .49405 .41743 L .4912 .41788 L F
.49389 .4146 m .49405 .41743 L .4912 .41788 L F
0 0 .175 r
.49447 .41475 m .49389 .4146 L .49543 .41249 L F
.776 .478 .484 r
.4988 .41833 m .49389 .4146 L .49405 .41743 L F
0 0 .175 r
.49447 .41475 m .49405 .41743 L .49389 .4146 L F
.703 .717 .86 r
.42151 .55245 m .42255 .55373 L .41818 .55336 L F
.841 .752 .765 r
.42255 .55373 m .41767 .55601 L .41818 .55336 L F
.42255 .55373 m .42034 .55742 L .41767 .55601 L F
.62 .549 .753 r
.52414 .37029 m .52638 .37112 L .52574 .36609 L F
.165 0 0 r
.52252 .37307 m .52638 .37112 L .52414 .37029 L F
.88 .854 .813 r
.44339 .50902 m .44017 .5089 L .44138 .50768 L F
.891 .833 .783 r
.44339 .50902 m .44099 .51257 L .44017 .5089 L F
.836 .865 .866 r
.44637 .50548 m .44339 .50902 L .44138 .50768 L F
.216 .124 .53 r
.60638 .34775 m .60382 .35302 L .60645 .34979 L F
.896 .98 .698 r
.63214 .36725 m .62979 .37097 L .63021 .36808 L F
.749 .927 .573 r
.63479 .36339 m .63214 .36725 L .63336 .36462 L F
.781 .985 .733 r
.63214 .36725 m .63021 .36808 L .63336 .36462 L F
.995 .762 .457 r
.63639 .38992 m .63653 .38752 L .63498 .38842 L F
.7 .907 .969 r
.63761 .38504 m .63653 .38752 L .63875 .38637 L F
.794 .974 .683 r
.63498 .38842 m .63653 .38752 L .63761 .38504 L F
0 0 0 r
.63479 .36339 m .63336 .36462 L .63593 .36324 L F
.422 .113 .335 r
.44647 .46352 m .44449 .46179 L .44708 .46086 L F
.44647 .46352 m .44477 .46407 L .44449 .46179 L F
.293 .032 .336 r
.51293 .38751 m .5154 .38662 L .51578 .38409 L F
.311 0 .262 r
.5154 .38662 m .51862 .38324 L .51578 .38409 L F
.347 0 0 r
.61782 .33846 m .62071 .33822 L .62183 .33644 L F
.43 .029 .176 r
.62071 .33822 m .62456 .33558 L .62183 .33644 L F
.77 .898 .932 r
.60476 .39316 m .60275 .39729 L .60226 .39656 L F
.60476 .39316 m .60603 .3949 L .60275 .39729 L F
.346 .234 .581 r
.28486 .65174 m .28711 .65426 L .28674 .65139 L F
.816 .781 .82 r
.44238 .53897 m .4473 .53708 L .44533 .53543 L F
.504 .287 .517 r
.59624 .39759 m .59787 .39948 L .5934 .40087 L F
.482 .536 .836 r
.59755 .39352 m .59624 .39759 L .59595 .39331 L F
.59755 .39352 m .59987 .3983 L .59624 .39759 L F
.965 .702 .486 r
.37912 .55586 m .38137 .55747 L .37936 .55301 L F
.559 .075 .062 r
.37285 .48913 m .37103 .4909 L .36943 .489 L F
.346 0 0 r
.37559 .48921 m .37103 .4909 L .37285 .48913 L F
.966 .901 .706 r
.6294 .34162 m .63174 .34029 L .63153 .33844 L F
.956 .625 .348 r
.62946 .39054 m .63077 .39276 L .62972 .39302 L F
.555 .824 .996 r
.63188 .39193 m .63304 .39037 L .62946 .39054 L F
.692 .413 .496 r
.62946 .39054 m .62972 .39302 L .62546 .39327 L F
0 0 .363 r
.63123 .39091 m .62972 .39302 L .62946 .39054 L F
.149 0 0 r
.62546 .39327 m .62972 .39302 L .62786 .39353 L F
.672 .973 .81 r
.62794 .39347 m .62972 .39302 L .63123 .39091 L F
.62786 .39353 m .62972 .39302 L .62794 .39347 L F
.956 .625 .348 r
.63077 .39276 m .63147 .39395 L .62972 .39302 L F
.555 .824 .996 r
.63188 .39193 m .63427 .39183 L .63304 .39037 L F
.153 .01 .419 r
.39615 .57343 m .39506 .57393 L .39616 .57137 L F
.546 .37 .595 r
.39615 .57343 m .39414 .5764 L .39506 .57393 L F
.383 0 0 r
.37969 .4893 m .37796 .49032 L .37559 .48921 L F
.452 0 0 r
.3822 .49044 m .37796 .49032 L .37969 .4893 L F
.862 .864 .839 r
.47018 .50206 m .47472 .49979 L .47263 .49849 L F
.818 .761 .799 r
.47263 .49849 m .47472 .49979 L .47751 .49646 L F
0 0 0 r
.56921 .38459 m .56757 .38579 L .57123 .38311 L F
.689 .974 .915 r
.41444 .48572 m .41233 .48606 L .40982 .48739 L F
.26 0 0 r
.41683 .48465 m .41233 .48606 L .41444 .48572 L F
.388 .849 .827 r
.51344 .42182 m .50973 .42262 L .51178 .4233 L F
.427 .284 .583 r
.51634 .42241 m .51381 .42474 L .51344 .42182 L F
.166 .701 .719 r
.51178 .4233 m .51634 .42241 L .51344 .42182 L F
.444 .178 .414 r
.5162 .42079 m .51634 .42241 L .51344 .42182 L F
.624 .958 .905 r
.57581 .3536 m .57182 .35505 L .57498 .35241 L F
0 .295 .769 r
.57567 .35268 m .57581 .3536 L .57498 .35241 L F
.57567 .35268 m .57908 .35567 L .57581 .3536 L F
.399 .393 .737 r
.57908 .35567 m .57734 .35725 L .57581 .3536 L F
.919 .532 .247 r
.55196 .41297 m .55408 .41536 L .55372 .41667 L F
.511 .531 .814 r
.55798 .4175 m .55408 .41536 L .55713 .41368 L F
.392 .247 .562 r
.51293 .38751 m .51556 .38911 L .5154 .38662 L F
.391 .248 .564 r
.51293 .38751 m .51316 .39048 L .51556 .38911 L F
.818 .761 .799 r
.47263 .49849 m .47751 .49646 L .47548 .49496 L F
.976 .804 .607 r
.34263 .65222 m .34187 .64768 L .34016 .65119 L F
.834 .68 .691 r
.34016 .65119 m .34173 .65493 L .34263 .65222 L F
.605 .11 .05 r
.52497 .39695 m .52412 .39882 L .52153 .39703 L F
.132 .212 .68 r
.52565 .3927 m .52497 .39695 L .52851 .39156 L F
.52565 .3927 m .52696 .39547 L .52497 .39695 L F
0 0 0 r
.52696 .39547 m .52412 .39882 L .52497 .39695 L F
.88 .683 .632 r
.44203 .51918 m .43857 .51883 L .43899 .51562 L F
.865 .783 .769 r
.44203 .51918 m .43975 .52256 L .43857 .51883 L F
.466 .68 .958 r
.35322 .57717 m .35438 .57494 L .35145 .57344 L F
.35322 .57717 m .3553 .5778 L .35438 .57494 L F
0 0 .481 r
.35322 .57717 m .35404 .57741 L .3553 .5778 L F
.35322 .57717 m .35426 .57887 L .35404 .57741 L F
.79 .92 .925 r
.63304 .39037 m .63427 .39183 L .63639 .38992 L F
.888 .692 .631 r
.41767 .55601 m .42034 .55742 L .41951 .55982 L F
.805 .759 .81 r
.44818 .53058 m .45271 .53004 L .45076 .52842 L F
.208 0 0 r
.3739 .4846 m .37655 .48441 L .37844 .48323 L F
.332 0 0 r
.37844 .48323 m .37655 .48441 L .3808 .48388 L F
.305 0 .199 r
.31366 .61917 m .31003 .62089 L .31206 .62046 L F
.82 .56 .546 r
.53263 .38051 m .53299 .38368 L .52898 .38241 L F
.481 .329 .597 r
.53506 .37694 m .53263 .38051 L .53147 .37846 L F
.53506 .37694 m .53542 .3797 L .53263 .38051 L F
.336 .212 .559 r
.53524 .38246 m .53263 .38051 L .53542 .3797 L F
.53524 .38246 m .53299 .38368 L .53263 .38051 L F
.267 0 0 r
.58841 .35044 m .59158 .35104 L .59299 .35027 L F
0 .215 .711 r
.59441 .35057 m .59577 .35227 L .59397 .35098 L F
.59441 .35057 m .59397 .35098 L .59299 .35027 L F
.59441 .35057 m .59299 .35027 L .59158 .35104 L F
.371 .819 .691 r
.59441 .35057 m .59293 .35114 L .59486 .35016 L F
.59441 .35057 m .59486 .35016 L .59621 .34947 L F
.464 .826 .994 r
.58934 .40071 m .5934 .40087 L .59208 .40314 L F
.279 0 .065 r
.5934 .40087 m .59528 .4024 L .59208 .40314 L F
.851 .892 .867 r
.48393 .48486 m .48558 .48619 L .48848 .48315 L F
0 .274 .771 r
.35294 .56467 m .35453 .56714 L .35291 .56518 L F
.518 .56 .838 r
.35459 .5633 m .35453 .56714 L .35294 .56467 L F
.646 .175 .121 r
.54365 .36755 m .54188 .3696 L .5405 .36658 L F
.044 0 .364 r
.5405 .36658 m .54188 .3696 L .54205 .36562 L F
.896 .837 .779 r
.56795 .36616 m .56348 .36929 L .56704 .36412 L F
.56795 .36616 m .56532 .37042 L .56348 .36929 L F
.215 .739 .811 r
.56704 .36412 m .57117 .3637 L .56795 .36616 L F
.344 .73 .985 r
.52292 .40384 m .52634 .40358 L .52784 .40511 L F
.976 .917 .668 r
.52784 .40511 m .52561 .40561 L .52292 .40384 L F
.52784 .40511 m .52671 .40685 L .52561 .40561 L F
.763 .937 .941 r
.52784 .40511 m .52834 .40216 L .52984 .40354 L F
.52784 .40511 m .52634 .40358 L .52834 .40216 L F
0 0 0 r
.52984 .40354 m .52671 .40685 L .52784 .40511 L F
.283 0 .238 r
.4357 .45455 m .43744 .45651 L .43815 .45368 L F
.4357 .45455 m .43501 .45742 L .43744 .45651 L F
.825 .504 .446 r
.64874 .35155 m .65266 .35023 L .65036 .34968 L F
.64874 .35155 m .65221 .35252 L .65266 .35023 L F
.829 .842 .857 r
.50113 .4703 m .49921 .47192 L .50278 .47186 L F
.804 .841 .879 r
.50113 .4703 m .50278 .47186 L .50597 .46875 L F
.802 .925 .917 r
.51442 .4475 m .51153 .44756 L .51371 .44452 L F
.785 .712 .783 r
.51188 .43767 m .51441 .44119 L .51654 .43854 L F
.616 .863 .509 r
.51654 .43854 m .51441 .44119 L .51601 .43902 L F
.185 .172 .61 r
.51598 .43906 m .51642 .4433 L .51601 .43902 L F
.51441 .44119 m .5154 .44223 L .51598 .43906 L F
.965 .927 .705 r
.51623 .44285 m .51443 .4475 L .51515 .44357 L F
.51515 .44357 m .51442 .4475 L .51371 .44452 L F
.51443 .4475 m .51442 .4475 L .51515 .44357 L F
.51623 .44285 m .51371 .44452 L .51642 .4433 L F
.568 .045 0 r
.51623 .44285 m .51642 .4433 L .51441 .44119 L F
.185 .172 .61 r
.5154 .44223 m .51642 .4433 L .51598 .43906 L F
.709 .566 .691 r
.55413 .3822 m .55476 .384 L .55935 .37976 L F
.928 .69 .558 r
.29476 .65215 m .29642 .65508 L .29665 .65343 L F
.563 0 0 r
.29642 .65508 m .29489 .65599 L .29665 .65343 L F
.29642 .65508 m .29607 .65756 L .29489 .65599 L F
.555 .561 .815 r
.29607 .65756 m .29851 .65659 L .29642 .65508 L F
.563 0 0 r
.29642 .65508 m .297 .65639 L .29607 .65756 L F
.29642 .65508 m .29851 .65659 L .297 .65639 L F
.437 0 0 r
.48988 .4313 m .49131 .43139 L .4908 .43171 L F
.48988 .4313 m .49195 .43222 L .48969 .43329 L F
.704 .763 .898 r
.48956 .43248 m .49146 .42889 L .48955 .4324 L F
.48969 .43329 m .49017 .4321 L .48956 .43248 L F
.49017 .4321 m .49146 .42889 L .48956 .43248 L F
.437 0 0 r
.4908 .43171 m .49434 .43158 L .49195 .43222 L F
.49131 .43139 m .49434 .43158 L .4908 .43171 L F
.239 .748 .713 r
.49195 .43222 m .49434 .43158 L .49695 .43077 L F
.982 .89 .543 r
.52585 .43136 m .52502 .43405 L .52432 .43255 L F
.563 .898 .656 r
.52747 .42964 m .52915 .42862 L .52585 .43136 L F
.546 .869 .589 r
.52747 .42964 m .52585 .43136 L .52432 .43255 L F
.268 0 0 r
.31926 .62019 m .32323 .6178 L .32345 .62101 L F
.701 .627 .771 r
.32323 .6178 m .3278 .61793 L .32345 .62101 L F
.863 .95 .869 r
.6194 .37634 m .61628 .37989 L .61508 .37872 L F
.81 .995 .865 r
.6638 .36197 m .66166 .36184 L .66429 .36106 L F
.859 .757 .246 r
.55974 .40476 m .55998 .40721 L .56038 .40445 L F
.574 .86 .996 r
.60073 .38612 m .59905 .38532 L .59753 .38735 L F
.359 .326 .686 r
.59905 .38532 m .5972 .38981 L .59753 .38735 L F
.839 .861 .861 r
.4758 .47294 m .47111 .47469 L .47385 .47132 L F
.023 0 .421 r
.52143 .39419 m .52307 .3938 L .52264 .39203 L F
.52143 .39419 m .52153 .39703 L .52307 .3938 L F
.162 .443 .875 r
.35438 .57494 m .3553 .5778 L .35622 .57495 L F
.758 .987 .763 r
.35622 .57495 m .3553 .5778 L .35404 .57741 L F
.395 .061 .277 r
.59989 .34993 m .60272 .34924 L .60381 .34723 L F
.442 .734 .989 r
.60381 .34723 m .60422 .34682 L .60107 .34518 L F
0 0 0 r
.60381 .34723 m .60272 .34924 L .60422 .34682 L F
.13 0 .029 r
.29037 .64493 m .28663 .64828 L .28907 .64707 L F
0 0 0 r
.29156 .64371 m .29305 .64155 L .29037 .64493 L F
.349 .131 .435 r
.28907 .64707 m .29156 .64371 L .29037 .64493 L F
.544 .024 0 r
.36943 .489 m .36396 .48996 L .36582 .48874 L F
.36943 .489 m .36665 .49063 L .36396 .48996 L F
.589 .079 .006 r
.37103 .4909 m .36665 .49063 L .36943 .489 L F
.782 .996 .866 r
.65372 .37302 m .65643 .36929 L .65307 .37215 L F
.65372 .37302 m .65707 .37009 L .65643 .36929 L F
.474 .242 .481 r
.53527 .39382 m .53418 .39646 L .53107 .39369 L F
.31 .729 .975 r
.53912 .39684 m .53418 .39646 L .53529 .39664 L F
.5394 .39685 m .53914 .39683 L .53912 .39684 L F
.53914 .39683 m .53418 .39646 L .53912 .39684 L F
.997 .779 .477 r
.5397 .39665 m .5395 .39997 L .54006 .3978 L F
.5393 .39541 m .53936 .39676 L .5397 .39665 L F
.53936 .39676 m .5395 .39997 L .5397 .39665 L F
.665 .385 .486 r
.53875 .39485 m .53565 .39645 L .53527 .39382 L F
.31 .729 .975 r
.5389 .39681 m .53565 .39645 L .53418 .39646 L F
.53565 .39645 m .53529 .39641 L .53528 .39641 L F
.53565 .39645 m .53528 .39641 L .53418 .39646 L F
0 0 .126 r
.5394 .39685 m .5395 .39997 L .53937 .397 L F
.5394 .39685 m .53937 .397 L .5393 .39541 L F
.959 .689 .248 r
.5393 .39541 m .53993 .39741 L .5394 .39685 L F
.53993 .39741 m .54006 .3978 L .5394 .39685 L F
0 0 0 r
.54173 .39311 m .5394 .39685 L .53875 .39485 L F
.31 .729 .975 r
.53987 .39623 m .5399 .39619 L .5388 .39624 L F
.665 .385 .486 r
.53875 .39485 m .5394 .39685 L .53565 .39645 L F
.53565 .39645 m .53529 .39641 L .53527 .39382 L F
.31 .729 .975 r
.53883 .39627 m .5388 .39624 L .53418 .39646 L F
.53987 .39623 m .5388 .39624 L .53883 .39627 L F
.5394 .39685 m .53987 .39623 L .53951 .39624 L F
.5394 .39685 m .53951 .39624 L .53529 .39641 L F
.5394 .39685 m .53529 .39641 L .5389 .39681 L F
.665 .385 .486 r
.53565 .39645 m .5394 .39685 L .53529 .39664 L F
.53565 .39645 m .53529 .39664 L .53529 .39641 L F
.474 .242 .481 r
.53527 .39382 m .53529 .39641 L .53418 .39646 L F
.53529 .39641 m .53529 .39664 L .53418 .39646 L F
.645 .589 .777 r
.5385 .39271 m .53527 .39382 L .53484 .39218 L F
.629 .534 .727 r
.5385 .39271 m .53875 .39485 L .53527 .39382 L F
.631 .076 0 r
.31434 .62872 m .31347 .62959 L .31329 .62704 L F
.31434 .62872 m .31707 .63075 L .31347 .62959 L F
.908 .749 .672 r
.33947 .64428 m .3423 .64478 L .34121 .64071 L F
.88 .652 .59 r
.3387 .64714 m .3423 .64478 L .33947 .64428 L F
.3387 .64714 m .34187 .64768 L .3423 .64478 L F
0 0 0 r
.60054 .40151 m .602 .40144 L .59909 .4017 L F
.292 .773 .679 r
.60132 .40166 m .602 .40144 L .60445 .40041 L F
.066 0 0 r
.59909 .4017 m .602 .40144 L .60011 .40214 L F
.292 .773 .679 r
.60011 .40214 m .602 .40144 L .60132 .40166 L F
0 0 0 r
.60054 .40151 m .60276 .40119 L .602 .40144 L F
.60276 .40119 m .60365 .40107 L .602 .40144 L F
.451 .021 .129 r
.62028 .34556 m .61941 .34759 L .61602 .34718 L F
.23 0 0 r
.62349 .34541 m .61941 .34759 L .62028 .34556 L F
.266 .665 .968 r
.36117 .57321 m .3624 .57467 L .35852 .57312 L F
.062 .209 .705 r
.36456 .57457 m .3624 .57467 L .36117 .57321 L F
.36456 .57457 m .36357 .57608 L .3624 .57467 L F
.112 0 .284 r
.52583 .36366 m .52725 .36328 L .52799 .36023 L F
.236 .297 .723 r
.52583 .36366 m .52807 .36519 L .52725 .36328 L F
.432 .265 .553 r
.52583 .36366 m .52574 .36609 L .52807 .36519 L F
.204 0 0 r
.47879 .43129 m .48248 .42909 L .48215 .42942 L F
.512 .186 .353 r
.48248 .42909 m .48655 .43051 L .48215 .42942 L F
.48248 .42909 m .48776 .4274 L .48655 .43051 L F
.83 .969 .891 r
.63021 .36808 m .62979 .37097 L .62885 .37009 L F
.737 .807 .907 r
.50827 .43608 m .51019 .43795 L .50507 .43644 L F
.8 .36 .203 r
.51019 .43795 m .50789 .44079 L .50507 .43644 L F
.281 .609 .955 r
.51188 .43767 m .51019 .43795 L .50827 .43608 L F
.584 .554 .787 r
.51019 .43795 m .51121 .43874 L .51188 .43767 L F
.51121 .43874 m .51441 .44119 L .51188 .43767 L F
.281 .609 .955 r
.51188 .43767 m .511 .43481 L .51224 .43502 L F
.992 .77 .396 r
.51188 .43767 m .51224 .43502 L .511 .43481 L F
.51188 .43767 m .511 .43481 L .5138 .43502 L F
.666 .913 .592 r
.5138 .43502 m .51291 .43603 L .51188 .43767 L F
0 0 0 r
.51067 .43858 m .51019 .43795 L .51188 .43767 L F
.281 .609 .955 r
.51188 .43767 m .50827 .43608 L .511 .43481 L F
.666 .913 .592 r
.51291 .43603 m .51067 .43858 L .51188 .43767 L F
0 0 0 r
.51067 .43858 m .50789 .44079 L .51019 .43795 L F
.334 .809 .745 r
.609 .39884 m .61072 .39844 L .61321 .39742 L F
.398 .044 .244 r
.50128 .44722 m .50403 .44703 L .50438 .44509 L F
.218 0 .196 r
.50438 .44509 m .50403 .44703 L .50676 .44408 L F
.722 .306 .258 r
.64658 .34933 m .64874 .35155 L .65036 .34968 L F
.336 0 .074 r
.29418 .64339 m .29305 .64155 L .29156 .64371 L F
.29418 .64339 m .29567 .64115 L .29305 .64155 L F
.849 .854 .846 r
.45256 .49635 m .44989 .49946 L .44786 .49823 L F
.933 .798 .688 r
.44989 .49946 m .44899 .50218 L .44786 .49823 L F
.791 .64 .695 r
.49118 .42052 m .49609 .42145 L .49405 .41743 L F
.964 .744 .557 r
.49357 .42291 m .49609 .42145 L .49118 .42052 L F
.49357 .42291 m .49527 .42383 L .49609 .42145 L F
.709 .61 .743 r
.49405 .41743 m .49609 .42145 L .4988 .41833 L F
.148 0 0 r
.38202 .56844 m .38463 .56885 L .38626 .56894 L F
.999 .837 .533 r
.38626 .56894 m .38511 .56575 L .38902 .56647 L F
.38626 .56894 m .38463 .56885 L .38511 .56575 L F
.582 .832 .464 r
.49838 .43469 m .49568 .43812 L .497 .43633 L F
.516 .331 .568 r
.49568 .43812 m .49848 .43761 L .49838 .43469 L F
.49838 .43469 m .49848 .43761 L .49568 .43812 L F
.484 .808 1 r
.497 .43633 m .49848 .43761 L .49568 .43812 L F
.791 .64 .695 r
.49118 .42052 m .49405 .41743 L .4912 .41788 L F
.107 0 0 r
.4912 .41788 m .49242 .4185 L .49118 .42052 L F
.4912 .41788 m .49405 .41743 L .49242 .4185 L F
.569 .768 .972 r
.40626 .57777 m .40692 .57507 L .40424 .57608 L F
.40626 .57777 m .40897 .57692 L .40692 .57507 L F
.513 .576 .856 r
.40162 .5765 m .40276 .57225 L .40227 .5738 L F
.681 .719 .878 r
.32474 .66717 m .32853 .67229 L .32929 .66801 L F
0 0 0 r
.3161 .67173 m .31666 .67139 L .31773 .67091 L F
.231 0 .042 r
.42332 .46434 m .42599 .46356 L .42676 .46201 L F
.346 0 .137 r
.42599 .46356 m .42951 .46132 L .42676 .46201 L F
0 0 0 r
.45981 .45181 m .45914 .45321 L .45652 .45438 L F
.022 0 .278 r
.46111 .44972 m .45981 .45181 L .46278 .45152 L F
.46111 .44972 m .45914 .45321 L .45981 .45181 L F
.737 .58 .68 r
.55049 .38377 m .55476 .384 L .55413 .3822 L F
.346 0 0 r
.37559 .48921 m .37382 .49087 L .37103 .4909 L F
.379 0 0 r
.37796 .49032 m .37382 .49087 L .37559 .48921 L F
0 .425 .829 r
.52831 .41704 m .52531 .41543 L .52997 .41765 L F
.923 .861 .761 r
.52593 .41912 m .5267 .42048 L .52831 .41704 L F
.52593 .41912 m .52831 .41704 L .52969 .41755 L F
.52593 .41912 m .52969 .41755 L .52915 .41795 L F
0 .459 .832 r
.52271 .41871 m .5267 .42048 L .52593 .41912 L F
.923 .861 .761 r
.52915 .41795 m .52969 .41755 L .52997 .41765 L F
.269 .215 .611 r
.52653 .41775 m .52593 .41912 L .52997 .41765 L F
.578 .627 .864 r
.52718 .41814 m .5267 .41976 L .52434 .42129 L F
.5267 .41976 m .52584 .42265 L .52446 .42141 L F
.5267 .41976 m .52446 .42141 L .52434 .42129 L F
.865 .851 .827 r
.51972 .4544 m .52038 .45791 L .52304 .45468 L F
.836 .88 .875 r
.52135 .45295 m .51972 .4544 L .52304 .45468 L F
.872 .881 .838 r
.52135 .45295 m .52304 .45468 L .52604 .45113 L F
.864 .82 .804 r
.44017 .5089 m .44099 .51257 L .43895 .51119 L F
.914 .78 .7 r
.44099 .51257 m .43704 .51473 L .43895 .51119 L F
.44099 .51257 m .43899 .51562 L .43704 .51473 L F
.762 .72 .813 r
.43705 .52618 m .43284 .52554 L .43581 .52242 L F
.81 .745 .791 r
.43975 .52256 m .43705 .52618 L .43581 .52242 L F
.92 .525 .195 r
.33977 .63148 m .33671 .62708 L .3367 .62998 L F
.926 .684 .553 r
.3374 .63367 m .33977 .63148 L .3367 .62998 L F
.3374 .63367 m .33958 .63444 L .33977 .63148 L F
.707 .285 .244 r
.65157 .35946 m .65435 .36194 L .65598 .36017 L F
.693 .268 .233 r
.65598 .36017 m .65435 .36194 L .65829 .36224 L F
.377 .716 .988 r
.52153 .40232 m .52292 .40384 L .5226 .40091 L F
.872 .881 .838 r
.52135 .45295 m .52604 .45113 L .52474 .4498 L F
.751 .986 .902 r
.52911 .44792 m .52474 .4498 L .52604 .45113 L F
0 0 .102 r
.57908 .35567 m .57675 .35919 L .57734 .35725 L F
.324 0 0 r
.63711 .34752 m .6402 .34813 L .64074 .34729 L F
0 .487 .764 r
.63642 .34711 m .6402 .34813 L .63711 .34752 L F
.716 .58 .701 r
.63642 .34711 m .63995 .34852 L .6402 .34813 L F
.63995 .34852 m .64146 .34912 L .6402 .34813 L F
.324 0 0 r
.64074 .34729 m .6402 .34813 L .64143 .34724 L F
.433 0 0 r
.64143 .34724 m .6402 .34813 L .6445 .34837 L F
.958 .737 .561 r
.33936 .63893 m .34148 .63802 L .33976 .63693 L F
.33936 .63893 m .34121 .64071 L .34148 .63802 L F
.656 .883 .981 r
.61324 .34581 m .61415 .34812 L .61602 .34718 L F
.224 .182 .598 r
.3972 .56825 m .39615 .57343 L .39616 .57137 L F
.165 0 0 r
.52252 .37307 m .52532 .37252 L .52638 .37112 L F
.531 .488 .753 r
.52638 .37112 m .52807 .36519 L .52574 .36609 L F
.087 0 0 r
.52638 .37112 m .52532 .37252 L .52885 .37146 L F
.273 0 .171 r
.43554 .46913 m .43469 .47099 L .43219 .47179 L F
.475 .204 .423 r
.43776 .468 m .43469 .47099 L .43554 .46913 L F
.812 .477 .422 r
.55049 .38377 m .55461 .38687 L .55476 .384 L F
.29 0 0 r
.59848 .3502 m .60272 .34924 L .59989 .34993 L F
.59848 .3502 m .60152 .35048 L .60272 .34924 L F
.178 0 .194 r
.60009 .35146 m .60222 .35055 L .59848 .3502 L F
0 .322 .739 r
.5984 .34976 m .5998 .35117 L .59733 .3508 L F
.5998 .35117 m .60009 .35146 L .59946 .35131 L F
.5998 .35117 m .59946 .35131 L .59733 .3508 L F
.29 0 0 r
.60152 .35048 m .60222 .35055 L .60238 .35014 L F
.60152 .35048 m .60238 .35014 L .60272 .34924 L F
.944 .937 .757 r
.41192 .53151 m .41107 .53628 L .41217 .53501 L F
.531 .655 .914 r
.41192 .53151 m .41217 .53501 L .41304 .53442 L F
.851 .892 .867 r
.48393 .48486 m .48848 .48315 L .48695 .48204 L F
.841 .927 .888 r
.48695 .48204 m .48848 .48315 L .49024 .48127 L F
0 0 .096 r
.3263 .61336 m .32406 .61699 L .32579 .61722 L F
.3263 .61336 m .32122 .61427 L .32406 .61699 L F
.577 .426 .64 r
.32579 .61722 m .32916 .61371 L .3263 .61336 L F
.703 .459 .552 r
.35501 .55547 m .35838 .55616 L .35841 .55331 L F
.467 0 0 r
.36582 .48874 m .36396 .48996 L .36168 .48858 L F
.475 .306 .572 r
.56688 .36097 m .56992 .36094 L .56943 .35653 L F
.489 .27 .507 r
.56382 .37794 m .56645 .37747 L .56675 .37393 L F
.096 .224 .708 r
.56675 .37393 m .56777 .37326 L .56532 .37042 L F
.281 .1 .448 r
.56675 .37393 m .56915 .37553 L .56777 .37326 L F
.56675 .37393 m .56645 .37747 L .56915 .37553 L F
.511 .847 .565 r
.40051 .4887 m .39872 .49017 L .39711 .49176 L F
.529 .888 .669 r
.39872 .49017 m .39669 .4918 L .39711 .49176 L F
.313 .076 .386 r
.60118 .33971 m .59843 .34338 L .60083 .3423 L F
.267 0 .279 r
.60083 .3423 m .604 .33866 L .60118 .33971 L F
.904 .585 .433 r
.56702 .37929 m .56594 .37795 L .56745 .3789 L F
.856 .635 .602 r
.56642 .37796 m .56702 .37929 L .56745 .3789 L F
.869 .628 .572 r
.57189 .38024 m .57123 .38311 L .56642 .37796 L F
.807 .756 .806 r
.43975 .52256 m .43581 .52242 L .43857 .51883 L F
.953 .637 .391 r
.56532 .37042 m .56386 .37194 L .56348 .36929 L F
.758 .314 .198 r
.56532 .37042 m .56777 .37326 L .56386 .37194 L F
0 0 0 r
.61694 .39638 m .61611 .39686 L .61321 .39742 L F
.61694 .39638 m .62014 .39549 L .6189 .39608 L F
.61694 .39638 m .6189 .39608 L .61611 .39686 L F
.50116 .41465 m .4988 .41833 L .50083 .41695 L F
.417 .282 .588 r
.59843 .34338 m .60107 .34518 L .60083 .3423 L F
.29 .378 .78 r
.50065 .43213 m .50122 .43662 L .49838 .43469 L F
.50085 .43191 m .5009 .43251 L .50065 .43213 L F
.5009 .43251 m .50122 .43662 L .50065 .43213 L F
.676 .579 .739 r
.50388 .4333 m .50507 .43644 L .50122 .43662 L F
.775 .551 .595 r
.50507 .43644 m .50096 .43927 L .50122 .43662 L F
.50507 .43644 m .50483 .4403 L .50096 .43927 L F
.8 .56 .574 r
.50313 .4359 m .50479 .43829 L .50482 .43555 L F
.532 .343 .57 r
.49838 .43469 m .50122 .43662 L .49848 .43761 L F
.803 .782 .833 r
.50388 .4333 m .50122 .43662 L .50085 .43191 L F
.8 .56 .574 r
.50067 .43641 m .50467 .43824 L .50313 .4359 L F
.50467 .43824 m .50479 .43829 L .50313 .4359 L F
.29 .378 .78 r
.50085 .43191 m .49838 .43469 L .497 .43633 L F
.996 .81 .447 r
.54006 .3978 m .5395 .39997 L .5394 .39685 L F
.707 .568 .696 r
.43863 .53294 m .4354 .53578 L .4345 .53236 L F
.704 .382 .429 r
.60731 .38715 m .61156 .38725 L .61182 .39004 L F
.596 .302 .44 r
.61156 .38725 m .61303 .38712 L .61182 .39004 L F
0 0 0 r
.50173 .40565 m .50156 .40548 L .50344 .40464 L F
.50156 .40548 m .49979 .40756 L .5013 .40525 L F
.643 .945 .718 r
.49768 .40864 m .49979 .40756 L .50156 .40548 L F
0 0 0 r
.50015 .40658 m .50156 .40548 L .50173 .40565 L F
.50156 .40548 m .5013 .40525 L .50211 .40402 L F
.922 .703 .589 r
.33944 .65384 m .34173 .65493 L .34016 .65119 L F
.884 .784 .746 r
.33955 .65898 m .34173 .65493 L .33944 .65384 L F
.314 .121 .451 r
.37682 .55664 m .37912 .55586 L .37936 .55301 L F
.497 .29 .529 r
.56646 .34316 m .56214 .34289 L .56509 .34162 L F
.56646 .34316 m .56381 .34654 L .56214 .34289 L F
.56646 .34316 m .56669 .34605 L .56381 .34654 L F
.453 .758 .995 r
.56509 .34162 m .57039 .34258 L .56646 .34316 L F
.449 .255 .525 r
.5693 .34495 m .56669 .34605 L .56646 .34316 L F
.818 .731 .769 r
.40919 .54371 m .4072 .54744 L .40573 .54358 L F
.465 .251 .503 r
.52271 .41871 m .52653 .41775 L .52531 .41543 L F
.267 .169 .554 r
.52653 .41775 m .52997 .41765 L .52531 .41543 L F
.548 .617 .874 r
.47317 .43385 m .47697 .43461 L .47608 .4335 L F
.47317 .43385 m .47763 .43786 L .47697 .43461 L F
0 0 0 r
.47747 .43395 m .47879 .43129 L .4777 .43364 L F
.47697 .43461 m .47773 .43322 L .47747 .43395 L F
.47773 .43322 m .47879 .43129 L .47747 .43395 L F
.742 .289 .175 r
.47608 .4335 m .47719 .43469 L .4743 .43512 L F
.47719 .43469 m .47812 .43569 L .4769 .43551 L F
.47719 .43469 m .4769 .43551 L .4743 .43512 L F
0 0 0 r
.47697 .43461 m .4777 .43364 L .47608 .4335 L F
0 0 .109 r
.61233 .37623 m .61032 .38005 L .60887 .37691 L F
.61233 .37623 m .61177 .37855 L .61076 .37922 L F
.61177 .37855 m .61176 .37861 L .6117 .37865 L F
.61177 .37855 m .6117 .37865 L .61076 .37922 L F
.779 .512 .532 r
.61508 .37872 m .61194 .37885 L .61233 .37623 L F
.245 .292 .713 r
.61251 .38207 m .61188 .37874 L .6117 .37886 L F
.779 .512 .532 r
.61188 .37874 m .6117 .37886 L .61177 .37855 L F
.245 .292 .713 r
.61188 .37874 m .61178 .37819 L .6117 .37886 L F
.779 .512 .532 r
.61194 .37885 m .61177 .37855 L .61233 .37623 L F
.245 .292 .713 r
.61185 .37858 m .61187 .37842 L .61183 .37847 L F
.61251 .38207 m .61189 .37856 L .61185 .37858 L F
.61189 .37856 m .61187 .37842 L .61185 .37858 L F
.803 .687 .737 r
.61508 .37872 m .61251 .38207 L .61194 .37885 L F
.245 .292 .713 r
.61251 .38207 m .61209 .37812 L .61187 .37842 L F
.355 .828 .801 r
.61202 .37845 m .6072 .3798 L .61049 .37922 L F
.61133 .37882 m .61049 .37922 L .61064 .37919 L F
.61202 .37845 m .61049 .37922 L .61133 .37882 L F
.803 .687 .737 r
.61194 .37885 m .61251 .38207 L .6117 .37886 L F
.245 .292 .713 r
.61223 .37936 m .6148 .38027 L .61209 .37812 L F
.355 .828 .801 r
.61224 .37834 m .61173 .37861 L .61232 .37843 L F
.245 .292 .713 r
.61178 .37819 m .6117 .37781 L .6117 .37886 L F
.355 .828 .801 r
.61209 .37841 m .61199 .37846 L .61202 .37845 L F
.58 .008 0 r
.61236 .37834 m .61227 .37834 L .61192 .37799 L F
.6137 .37979 m .61232 .37843 L .61206 .37814 L F
.245 .292 .713 r
.61183 .37847 m .61209 .37812 L .6117 .37781 L F
.58 .008 0 r
.61207 .37814 m .61206 .37814 L .61192 .37799 L F
.6137 .37979 m .61206 .37814 L .61207 .37814 L F
.355 .828 .801 r
.61163 .37834 m .6072 .3798 L .61162 .37851 L F
.58 .008 0 r
.61192 .37799 m .61197 .37808 L .6117 .37781 L F
.02 0 .007 r
.6117 .37781 m .61223 .37834 L .6117 .37862 L F
.58 .008 0 r
.61197 .37808 m .6121 .37834 L .6117 .37781 L F
.02 0 .007 r
.6117 .37781 m .61322 .37781 L .61223 .37834 L F
.355 .828 .801 r
.6117 .37847 m .61162 .37851 L .6117 .37849 L F
.6117 .37847 m .6117 .37849 L .61221 .37834 L F
.61202 .37834 m .6117 .37847 L .61221 .37834 L F
.61163 .37834 m .61162 .37851 L .61202 .37834 L F
.58 .008 0 r
.6121 .37834 m .61202 .37834 L .6117 .37781 L F
.02 0 .007 r
.6117 .37781 m .61202 .37834 L .61322 .37781 L F
.355 .828 .801 r
.61322 .37781 m .6129 .37792 L .61221 .37834 L F
.61224 .37834 m .61221 .37834 L .61202 .37845 L F
.61322 .37781 m .61221 .37834 L .61224 .37834 L F
.58 .008 0 r
.6148 .38027 m .6137 .37979 L .61227 .37834 L F
.6148 .38027 m .61227 .37834 L .61236 .37834 L F
.355 .828 .801 r
.61322 .37781 m .61224 .37834 L .61232 .37843 L F
.02 0 .007 r
.61223 .37834 m .61322 .37781 L .61232 .37843 L F
.355 .828 .801 r
.61221 .37834 m .61199 .37846 L .61209 .37841 L F
.58 .008 0 r
.6121 .37834 m .61262 .37933 L .61202 .37834 L F
.61348 .3797 m .61262 .37933 L .61192 .37799 L F
.02 0 .007 r
.61202 .37834 m .61262 .37933 L .61322 .37781 L F
0 0 0 r
.60801 .37962 m .6072 .3798 L .61163 .37834 L F
.355 .828 .801 r
.6129 .37792 m .61163 .37834 L .61221 .37834 L F
0 0 0 r
.61136 .37846 m .61163 .37834 L .61322 .37781 L F
.60801 .37962 m .61163 .37834 L .61136 .37846 L F
.58 .008 0 r
.6137 .37979 m .61348 .3797 L .61232 .37843 L F
.355 .828 .801 r
.61232 .37843 m .61173 .37861 L .6117 .37886 L F
.02 0 .007 r
.6117 .37862 m .61223 .37834 L .6117 .37886 L F
.61223 .37834 m .61232 .37843 L .6117 .37886 L F
.355 .828 .801 r
.61221 .37834 m .6072 .3798 L .61199 .37846 L F
0 0 .109 r
.61176 .37861 m .6117 .37886 L .61076 .37922 L F
.355 .828 .801 r
.61173 .37861 m .61064 .37919 L .6117 .37886 L F
.779 .512 .532 r
.61194 .37885 m .6117 .37886 L .61188 .37874 L F
.245 .292 .713 r
.61251 .38207 m .61337 .38139 L .61223 .37936 L F
.61337 .38139 m .6148 .38027 L .61223 .37936 L F
0 0 .109 r
.61076 .37922 m .6117 .37886 L .61032 .38005 L F
.064 .186 .681 r
.61032 .38005 m .61251 .38207 L .6117 .37886 L F
.58 .183 .255 r
.60989 .38111 m .61251 .38207 L .61032 .38005 L F
.216 .124 .53 r
.60638 .34775 m .60645 .35111 L .60382 .35302 L F
0 0 0 r
.60411 .35258 m .60382 .35302 L .60645 .35111 L F
.60411 .35258 m .60296 .35486 L .60382 .35302 L F
.508 0 0 r
.53487 .42676 m .53188 .42564 L .53162 .42644 L F
.099 0 0 r
.4554 .43717 m .45808 .43643 L .45954 .43471 L F
0 0 0 r
.45954 .43471 m .46035 .43509 L .46187 .43355 L F
.45954 .43471 m .45808 .43643 L .46035 .43509 L F
0 0 .224 r
.52799 .36023 m .52969 .36085 L .53067 .35934 L F
.52799 .36023 m .52725 .36328 L .52969 .36085 L F
.791 .341 .175 r
.39263 .49323 m .38923 .49091 L .39076 .49241 L F
.645 .589 .777 r
.5385 .39271 m .53484 .39218 L .53655 .38905 L F
.611 .736 .934 r
.52026 .41607 m .52261 .41805 L .52204 .41428 L F
.719 .975 .924 r
.52426 .41298 m .52359 .41213 L .52197 .41305 L F
.744 .669 .777 r
.52359 .41213 m .5213 .41343 L .51863 .41115 L F
.32 .565 .926 r
.51863 .41115 m .52079 .413 L .51824 .41323 L F
.52079 .413 m .5213 .41343 L .51923 .4133 L F
.52079 .413 m .51923 .4133 L .51824 .41323 L F
.5213 .41343 m .52112 .4139 L .51824 .41323 L F
.169 .607 .938 r
.52112 .4139 m .5198 .41465 L .51824 .41323 L F
.52121 .41422 m .5198 .41465 L .52112 .4139 L F
.52193 .41417 m .5198 .41465 L .52178 .41405 L F
.525 .275 .479 r
.52204 .41428 m .51824 .41323 L .5198 .41465 L F
.52204 .41428 m .51835 .41467 L .51826 .41352 L F
.51878 .41338 m .51826 .41352 L .51824 .41323 L F
.52204 .41428 m .51826 .41352 L .51878 .41338 L F
.614 .794 .968 r
.51869 .41385 m .51893 .41378 L .52151 .41286 L F
.52146 .41287 m .52151 .41286 L .52359 .41213 L F
.51869 .41385 m .52151 .41286 L .52146 .41287 L F
.719 .975 .924 r
.5213 .41342 m .52091 .41308 L .52101 .41347 L F
.52426 .41298 m .52144 .41306 L .5213 .41342 L F
.52144 .41306 m .52091 .41308 L .5213 .41342 L F
.9 .86 .793 r
.52132 .41342 m .52206 .41426 L .52426 .41298 L F
.744 .669 .777 r
.52359 .41213 m .52211 .41413 L .52133 .41346 L F
.52132 .41342 m .52133 .41346 L .5213 .41343 L F
.52359 .41213 m .52133 .41346 L .52132 .41342 L F
.9 .86 .793 r
.5213 .41342 m .52133 .41345 L .52132 .41342 L F
.52133 .41345 m .52206 .41426 L .52132 .41342 L F
.32 .565 .926 r
.5213 .41343 m .52133 .41346 L .52112 .4139 L F
.52133 .41346 m .52178 .41405 L .52112 .4139 L F
.9 .86 .793 r
.52101 .41347 m .52178 .41405 L .5213 .41342 L F
.52178 .41405 m .52206 .41426 L .5213 .41342 L F
.32 .565 .926 r
.52133 .41346 m .52211 .41413 L .52178 .41405 L F
.719 .975 .924 r
.52197 .41305 m .52359 .41213 L .52091 .41308 L F
.52101 .41347 m .52091 .41308 L .51893 .41378 L F
.169 .607 .938 r
.52178 .41405 m .52121 .41422 L .52112 .4139 L F
.52211 .41413 m .52193 .41417 L .52178 .41405 L F
.9 .86 .793 r
.51893 .41378 m .52204 .41428 L .52206 .41426 L F
.51893 .41378 m .52206 .41426 L .52101 .41347 L F
.525 .275 .479 r
.52204 .41428 m .52073 .41583 L .51835 .41467 L F
0 .374 .82 r
.51842 .41452 m .52073 .41583 L .51869 .41385 L F
.51835 .41467 m .51894 .41496 L .51842 .41452 L F
.51894 .41496 m .52073 .41583 L .51842 .41452 L F
.611 .736 .934 r
.51903 .4173 m .52271 .41871 L .52261 .41805 L F
.51903 .4173 m .52261 .41805 L .52026 .41607 L F
.55 .533 .789 r
.52271 .41871 m .52593 .41912 L .52653 .41775 L F
.051 0 0 r
.52153 .39703 m .51722 .40013 L .51963 .39871 L F
.388 .346 .691 r
.51722 .40013 m .52153 .40232 L .51963 .39871 L F
.372 .381 .74 r
.54369 .35492 m .54275 .35989 L .54033 .35563 L F
.54369 .35492 m .54449 .35903 L .54275 .35989 L F
.621 .075 0 r
.54449 .3617 m .54275 .35989 L .54449 .35903 L F
.54449 .3617 m .54074 .36105 L .54275 .35989 L F
.879 .852 .813 r
.45718 .49098 m .45352 .49162 L .45607 .48796 L F
.877 .859 .82 r
.45718 .49098 m .45536 .49309 L .45352 .49162 L F
.778 .81 .879 r
.46008 .48826 m .45718 .49098 L .45607 .48796 L F
.698 .436 .524 r
.53934 .36497 m .53536 .36845 L .53652 .36553 L F
.849 .854 .846 r
.45256 .49635 m .44786 .49823 L .45067 .49487 L F
.852 .849 .839 r
.45536 .49309 m .45256 .49635 L .45067 .49487 L F
.713 .73 .864 r
.56214 .34289 m .56381 .34654 L .55991 .34514 L F
0 .478 .802 r
.56381 .34654 m .56226 .34555 L .55991 .34514 L F
.765 .293 .124 r
.56669 .34605 m .56226 .34555 L .56381 .34654 L F
.445 .445 .765 r
.39857 .56266 m .39581 .56407 L .39463 .55942 L F
.34 .217 .563 r
.39857 .56266 m .39813 .5654 L .39581 .56407 L F
0 0 0 r
.36168 .48858 m .36289 .48845 L .36461 .48647 L F
0 .198 .716 r
.36168 .48858 m .36396 .48996 L .36289 .48845 L F
.378 .687 .979 r
.60584 .37317 m .61233 .37623 L .60887 .37691 L F
.94 .929 .765 r
.37251 .5702 m .37069 .57386 L .369 .57263 L F
.97 .765 .571 r
.37069 .57386 m .3679 .57524 L .369 .57263 L F
.37069 .57386 m .36983 .57642 L .3679 .57524 L F
0 0 .269 r
.30202 .66119 m .30143 .66548 L .3023 .66369 L F
.281 .573 .938 r
.3023 .66369 m .30143 .66548 L .30404 .66581 L F
.795 .936 .923 r
.63761 .38504 m .63875 .38637 L .64219 .38346 L F
.683 .875 .971 r
.46948 .4345 m .47026 .43559 L .47317 .43385 L F
.236 .402 .825 r
.41231 .54561 m .40919 .54371 L .40932 .54241 L F
.28 .745 .947 r
.604 .33866 m .6065 .33854 L .60826 .33916 L F
0 .359 .673 r
.6065 .33854 m .61033 .33988 L .60826 .33916 L F
.389 .601 .932 r
.31255 .66992 m .31346 .66707 L .31106 .66835 L F
.31255 .66992 m .3161 .67173 L .31346 .66707 L F
.202 0 0 r
.54735 .36795 m .54188 .3696 L .54365 .36755 L F
.172 .078 .5 r
.59755 .39352 m .59595 .39331 L .5972 .38981 L F
.627 .957 .915 r
.57182 .35505 m .56943 .35653 L .57178 .35436 L F
.278 .167 .543 r
.56943 .35653 m .57143 .35972 L .57178 .35436 L F
.56943 .35653 m .56992 .36094 L .57143 .35972 L F
.604 .94 .753 r
.31474 .65026 m .31611 .64946 L .31815 .64767 L F
.847 .998 .809 r
.49868 .40169 m .49916 .39907 L .49998 .39941 L F
0 0 .016 r
.58841 .35044 m .58624 .353 L .58863 .35132 L F
.337 0 0 r
.58863 .35132 m .59158 .35104 L .58841 .35044 L F
.849 .781 .785 r
.50379 .46704 m .50858 .46519 L .50712 .46402 L F
.50379 .46704 m .50597 .46875 L .50858 .46519 L F
.811 .92 .91 r
.50712 .46402 m .50858 .46519 L .51167 .4623 L F
0 0 .395 r
.46252 .44239 m .46123 .44483 L .4611 .44149 L F
.628 .667 .869 r
.53412 .3869 m .53125 .3844 L .53299 .38368 L F
0 0 .189 r
.52977 .38616 m .53023 .38599 L .53158 .38448 L F
.52921 .38668 m .52949 .38649 L .52977 .38616 L F
.52949 .38649 m .53023 .38599 L .52977 .38616 L F
.628 .667 .869 r
.53125 .3844 m .52898 .38241 L .53209 .3834 L F
.53125 .3844 m .53209 .3834 L .53299 .38368 L F
.877 .905 .846 r
.53524 .38246 m .53412 .3869 L .53299 .38368 L F
.53524 .38246 m .53249 .38562 L .53412 .3869 L F
.815 .34 .076 r
.53249 .38562 m .53655 .38905 L .53412 .3869 L F
.836 .865 .866 r
.44637 .50548 m .44138 .50768 L .44469 .50415 L F
.881 .891 .835 r
.44899 .50218 m .44637 .50548 L .44469 .50415 L F
.668 .407 .517 r
.48215 .42942 m .4777 .43364 L .47879 .43129 L F
.48215 .42942 m .48281 .43364 L .4777 .43364 L F
.726 .644 .767 r
.48655 .43051 m .48281 .43364 L .48215 .42942 L F
.575 .663 .897 r
.64541 .33462 m .64569 .33638 L .64223 .33727 L F
.64223 .33727 m .64569 .33638 L .64541 .33462 L F
.823 .978 .888 r
.65707 .37009 m .65776 .36723 L .65643 .36929 L F
.65707 .37009 m .66032 .36718 L .65776 .36723 L F
.852 .849 .839 r
.45536 .49309 m .45067 .49487 L .45352 .49162 L F
0 0 0 r
.55857 .38641 m .56022 .38565 L .56174 .38343 L F
.954 .918 .737 r
.56022 .38565 m .56138 .37975 L .56199 .3808 L F
.56223 .3833 m .56199 .3808 L .56296 .38245 L F
0 0 0 r
.56174 .38343 m .56225 .38357 L .56234 .38569 L F
.954 .918 .737 r
.56022 .38565 m .56199 .3808 L .56223 .3833 L F
0 0 0 r
.56225 .38357 m .56257 .38365 L .5624 .38512 L F
.56225 .38357 m .5624 .38512 L .56234 .38569 L F
.56174 .38343 m .56022 .38565 L .56257 .38365 L F
.751 .65 .092 r
.58957 .39016 m .58935 .39158 L .5891 .38891 L F
.58957 .39016 m .58932 .394 L .58935 .39158 L F
.707 .637 .078 r
.58932 .394 m .58928 .39429 L .58935 .39158 L F
.58932 .394 m .58902 .39679 L .58928 .39429 L F
.909 .887 .798 r
.42132 .54874 m .42151 .55245 L .41973 .5492 L F
.759 .392 .36 r
.53147 .37846 m .53542 .3797 L .53506 .37694 L F
.863 .95 .869 r
.6194 .37634 m .61508 .37872 L .61852 .37576 L F
.662 .961 .934 r
.6194 .37634 m .62089 .37422 L .62314 .37461 L F
.6194 .37634 m .61852 .37576 L .62089 .37422 L F
.522 .096 .173 r
.3808 .48388 m .3835 .48427 L .38511 .48182 L F
.462 .034 .139 r
.38511 .48182 m .38759 .483 L .38793 .48184 L F
.38511 .48182 m .3835 .48427 L .38759 .483 L F
0 0 0 r
.29303 .66029 m .29607 .65756 L .29383 .65999 L F
.556 .835 .493 r
.29383 .65999 m .29607 .65756 L .297 .65639 L F
.555 .561 .815 r
.29607 .65756 m .30016 .65886 L .29851 .65659 L F
.94 .929 .765 r
.37251 .5702 m .369 .57263 L .36812 .56979 L F
.407 .114 .351 r
.43219 .47179 m .43206 .47417 L .42906 .47471 L F
.456 .152 .359 r
.43475 .47358 m .43219 .47179 L .43469 .47099 L F
.43475 .47358 m .43206 .47417 L .43219 .47179 L F
.737 .622 .731 r
.43002 .52902 m .4317 .53313 L .42727 .53274 L F
.742 .574 .667 r
.42727 .53274 m .4317 .53313 L .42934 .53571 L F
.86 .769 .761 r
.44899 .50218 m .44547 .50168 L .44786 .49823 L F
.881 .891 .835 r
.44899 .50218 m .44469 .50415 L .44547 .50168 L F
.847 .945 .585 r
.49242 .4185 m .49405 .41743 L .49447 .41475 L F
.873 .722 .691 r
.39002 .56382 m .38902 .56647 L .38676 .56507 L F
.453 .12 .311 r
.42577 .47745 m .42245 .48096 L .42292 .47912 L F
.25 0 .188 r
.42292 .47912 m .42245 .48096 L .42001 .48191 L F
.23 .597 .95 r
.37614 .56533 m .3753 .56669 L .37347 .56552 L F
.37614 .56533 m .37754 .56673 L .3753 .56669 L F
.625 .955 .919 r
.57253 .39469 m .57457 .39494 L .57713 .39341 L F
.983 .717 .332 r
.49998 .39941 m .49916 .39907 L .50021 .39725 L F
.269 0 .059 r
.49916 .39907 m .50172 .39664 L .50021 .39725 L F
.214 .593 .947 r
.28874 .65818 m .29303 .66029 L .29139 .65842 L F
0 0 0 r
.29303 .66029 m .29383 .65999 L .29139 .65842 L F
.643 .89 .985 r
.50292 .40236 m .50211 .40402 L .50447 .40272 L F
0 0 0 r
.50344 .40464 m .50211 .40402 L .50292 .40236 L F
.50344 .40464 m .50156 .40548 L .50211 .40402 L F
.724 .987 .884 r
.50091 .4474 m .49666 .44947 L .50043 .44779 L F
0 0 0 r
.49666 .44947 m .49819 .4482 L .50043 .44779 L F
.503 0 0 r
.49819 .4482 m .49963 .44844 L .50043 .44779 L F
.49963 .44844 m .50188 .44882 L .50043 .44779 L F
.724 .987 .884 r
.50128 .44722 m .50091 .4474 L .50043 .44779 L F
.409 .709 .984 r
.50278 .44577 m .50403 .44703 L .50128 .44722 L F
.519 .866 .612 r
.50128 .44722 m .50043 .44779 L .50278 .44577 L F
.474 .236 .472 r
.53339 .3565 m .53067 .35934 L .53441 .35659 L F
.321 0 0 r
.53438 .35631 m .53661 .35679 L .53765 .35571 L F
.53339 .3565 m .53441 .35659 L .53438 .35631 L F
.467 .073 .208 r
.53521 .35672 m .53164 .35994 L .5378 .35826 L F
.321 0 0 r
.53441 .35659 m .53644 .35678 L .53438 .35631 L F
.467 .073 .208 r
.53467 .3564 m .53443 .35669 L .53521 .35672 L F
.53443 .35669 m .53164 .35994 L .53521 .35672 L F
.321 0 0 r
.53644 .35678 m .53661 .35679 L .53656 .35678 L F
.53644 .35678 m .53656 .35678 L .53438 .35631 L F
0 0 0 r
.53067 .35934 m .53164 .35994 L .53443 .35669 L F
.53441 .35659 m .53443 .35669 L .53467 .3564 L F
.53067 .35934 m .53443 .35669 L .53441 .35659 L F
.474 .236 .472 r
.53339 .3565 m .53441 .35659 L .53467 .3564 L F
.321 0 0 r
.53492 .35664 m .53635 .35706 L .53661 .35679 L F
.467 .073 .208 r
.53467 .3564 m .53521 .35672 L .53635 .35706 L F
.53521 .35672 m .5378 .35826 L .53635 .35706 L F
.321 0 0 r
.53339 .3565 m .53635 .35706 L .53492 .35664 L F
.57 .125 .155 r
.53635 .35706 m .54033 .35563 L .53765 .35571 L F
.675 .2 .117 r
.60486 .38673 m .60347 .38841 L .60073 .38612 L F
.841 .512 .431 r
.60731 .38715 m .60347 .38841 L .60486 .38673 L F
0 0 .363 r
.63123 .39091 m .62946 .39054 L .63236 .39041 L F
.661 .935 .661 r
.63008 .39143 m .63123 .39091 L .63271 .38878 L F
.62963 .39188 m .63123 .39091 L .63008 .39143 L F
0 0 .363 r
.63123 .39091 m .63236 .39041 L .63304 .39037 L F
.936 .945 .77 r
.40415 .56913 m .40485 .56643 L .40759 .56736 L F
.40415 .56913 m .40276 .5691 L .40485 .56643 L F
.841 .927 .888 r
.48695 .48204 m .49024 .48127 L .48887 .4802 L F
.914 .935 .809 r
.49123 .47699 m .49024 .48127 L .49299 .47813 L F
.49123 .47699 m .48887 .4802 L .49024 .48127 L F
.215 .739 .811 r
.56704 .36412 m .56915 .36366 L .57117 .3637 L F
.856 .903 .867 r
.53779 .37349 m .53898 .36908 L .54006 .37075 L F
.53779 .37349 m .53621 .37217 L .53898 .36908 L F
.259 0 0 r
.54124 .37358 m .53621 .37217 L .53779 .37349 L F
.214 0 0 r
.61088 .34062 m .61441 .34067 L .61516 .33965 L F
.611 .048 0 r
.61516 .33965 m .61689 .34129 L .61782 .33846 L F
.61516 .33965 m .61441 .34067 L .61689 .34129 L F
.419 .818 .983 r
.38513 .57981 m .38772 .57926 L .38336 .579 L F
0 0 0 r
.40472 .47542 m .4015 .47781 L .40384 .47665 L F
.245 0 .03 r
.40384 .47665 m .40725 .47456 L .40472 .47542 L F
.622 .852 .986 r
.61324 .34581 m .60848 .3482 L .60938 .3471 L F
.63 .759 .94 r
.6074 .39195 m .60603 .3949 L .60476 .39316 L F
.6074 .39195 m .60907 .39377 L .60603 .3949 L F
.672 .76 .917 r
.31346 .66707 m .3161 .67173 L .31788 .66776 L F
0 0 0 r
.3161 .67173 m .31773 .67091 L .31788 .66776 L F
0 .429 .705 r
.33598 .62279 m .33446 .62242 L .33344 .62208 L F
0 0 0 r
.30642 .65003 m .30826 .64897 L .3074 .64938 L F
.48655 .43051 m .48776 .4274 L .48841 .42668 L F
0 .542 .761 r
.51762 .43847 m .51654 .43854 L .51601 .43902 L F
.858 .539 .015 r
.5735 .34562 m .57416 .34851 L .57495 .34974 L F
.986 .853 .478 r
.57495 .34974 m .57354 .35095 L .57416 .34851 L F
.858 .539 .015 r
.57495 .34974 m .57416 .34851 L .5735 .34562 L F
.986 .853 .478 r
.57495 .34974 m .57354 .35095 L .57416 .34851 L F
.804 .841 .879 r
.50113 .4703 m .50597 .46875 L .50379 .46704 L F
.304 .062 .372 r
.44755 .44476 m .44715 .44726 L .4499 .44382 L F
.978 .903 .566 r
.40643 .51581 m .40465 .51738 L .40564 .51504 L F
.447 0 0 r
.40329 .48955 m .39872 .49017 L .40051 .4887 L F
.978 .903 .566 r
.40643 .51581 m .40465 .51738 L .40564 .51504 L F
.42 .21 .487 r
.55513 .39024 m .55857 .38641 L .55461 .38687 L F
.867 .988 .834 r
.60359 .36436 m .6014 .36465 L .6017 .36605 L F
.859 .99 .839 r
.60434 .36142 m .60359 .36436 L .60567 .36277 L F
.081 0 .363 r
.51227 .40521 m .51598 .40406 L .51445 .4024 L F
.51227 .40521 m .51454 .4048 L .51598 .40406 L F
.6 .045 0 r
.58934 .40071 m .59208 .40314 L .58968 .40165 L F
.58934 .40071 m .58968 .40165 L .58921 .39902 L F
.865 .895 .854 r
.49435 .47331 m .49299 .47813 L .49588 .4746 L F
.49435 .47331 m .49123 .47699 L .49299 .47813 L F
.982 .747 .344 r
.58295 .37339 m .58187 .37481 L .58291 .376 L F
.74 .678 .13 r
.58358 .36809 m .58292 .37317 L .58295 .37339 L F
.7 .857 .442 r
.58292 .37317 m .58187 .37481 L .58295 .37339 L F
.79 .92 .925 r
.63304 .39037 m .63639 .38992 L .63498 .38842 L F
.98 .713 .318 r
.46123 .44483 m .45996 .44656 L .46129 .44767 L F
0 0 0 r
.4619 .44482 m .46123 .44483 L .46252 .44239 L F
.4619 .44482 m .45996 .44656 L .46123 .44483 L F
.438 .389 .706 r
.46825 .44086 m .46909 .44491 L .47107 .44378 L F
.382 .377 .73 r
.46825 .44086 m .47107 .44378 L .47206 .44173 L F
.003 0 .106 r
.45074 .44168 m .4499 .44382 L .45259 .44036 L F
.48 .423 .716 r
.54173 .39311 m .53875 .39485 L .5385 .39271 L F
.388 0 0 r
.4078 .48881 m .40565 .49005 L .40329 .48955 L F
.497 .088 .194 r
.40982 .48739 m .40565 .49005 L .4078 .48881 L F
.803 .753 .806 r
.54495 .39053 m .541 .38983 L .54391 .38679 L F
.461 0 0 r
.54495 .39053 m .54341 .39099 L .541 .38983 L F
.159 .692 .846 r
.54739 .39109 m .54341 .39099 L .54495 .39053 L F
.383 .003 .189 r
.41658 .47045 m .42009 .46823 L .41712 .46872 L F
.949 .603 .312 r
.54348 .3836 m .54198 .38496 L .54166 .38172 L F
0 0 .334 r
.54447 .38412 m .54391 .38679 L .54475 .38427 L F
.54348 .3836 m .54377 .38572 L .54447 .38412 L F
.54377 .38572 m .54391 .38679 L .54447 .38412 L F
.54348 .3836 m .54475 .38427 L .54198 .38496 L F
.914 .592 .115 r
.54198 .38496 m .54103 .38391 L .54029 .38025 L F
.648 .916 .979 r
.54481 .38334 m .54103 .38391 L .54198 .38496 L F
.54594 .3827 m .54499 .38293 L .54481 .38334 L F
.54499 .38293 m .54103 .38391 L .54481 .38334 L F
.313 0 .188 r
.45014 .45853 m .44985 .4601 L .44708 .46086 L F
.416 .039 .213 r
.45014 .45853 m .45248 .45974 L .44985 .4601 L F
.436 .005 .121 r
.4533 .45834 m .45248 .45974 L .45014 .45853 L F
.841 .512 .431 r
.60731 .38715 m .6074 .38951 L .60347 .38841 L F
.704 .382 .429 r
.60731 .38715 m .61182 .39004 L .6074 .38951 L F
.723 .686 .144 r
.58162 .38323 m .58125 .38504 L .58126 .38528 L F
0 0 0 r
.58258 .37874 m .58195 .38247 L .58162 .38323 L F
.58195 .38247 m .58125 .38504 L .58162 .38323 L F
.928 .69 .558 r
.29476 .65215 m .29665 .65343 L .29498 .65535 L F
.669 .713 .881 r
.38202 .56844 m .37939 .57001 L .37754 .56673 L F
.872 .516 .371 r
.48655 .43051 m .48988 .4313 L .48969 .43329 L F
.828 .617 .617 r
.36757 .48651 m .36741 .48536 L .36698 .48581 L F
.36757 .48651 m .37113 .48481 L .36741 .48536 L F
.6 .832 .988 r
.62364 .35392 m .62225 .35638 L .62501 .35551 L F
.62364 .35392 m .62225 .35638 L .62501 .35551 L F
.453 .12 .311 r
.42577 .47745 m .42519 .48052 L .42245 .48096 L F
.399 .123 .375 r
.42906 .47471 m .42854 .47764 L .42577 .47745 L F
.724 .367 .373 r
.42935 .48079 m .42577 .47745 L .42854 .47764 L F
.42935 .48079 m .42519 .48052 L .42577 .47745 L F
.928 .973 .728 r
.52502 .43405 m .52267 .43467 L .52432 .43255 L F
.52502 .43405 m .52302 .43745 L .52267 .43467 L F
.92 .951 .613 r
.55272 .4103 m .55196 .41297 L .55086 .41339 L F
.683 .306 0 r
.55196 .41297 m .55277 .41492 L .55086 .41339 L F
.55196 .41297 m .55372 .41667 L .55277 .41492 L F
.983 .9 .646 r
.40855 .53443 m .40847 .5346 L .4097 .5354 L F
0 .427 .788 r
.41096 .53623 m .4097 .5354 L .40695 .53441 L F
.318 0 .159 r
.40705 .53777 m .40695 .53441 L .4097 .5354 L F
.983 .9 .646 r
.40847 .5346 m .40705 .53777 L .4097 .5354 L F
0 .427 .788 r
.41107 .53628 m .4097 .5354 L .41096 .53623 L F
.944 .937 .757 r
.41192 .53151 m .4097 .5354 L .41107 .53628 L F
0 .176 .697 r
.58082 .36509 m .58358 .36809 L .58171 .3672 L F
.329 .023 .286 r
.42009 .46823 m .42259 .46733 L .42332 .46434 L F
.392 .09 .329 r
.42259 .46733 m .42599 .46356 L .42332 .46434 L F
.861 .847 .829 r
.3372 .66177 m .33747 .65761 L .33495 .66124 L F
.3372 .66177 m .33955 .65898 L .33747 .65761 L F
.941 .74 .603 r
.33495 .66124 m .33674 .66478 L .3372 .66177 L F
.732 .641 .758 r
.41767 .55601 m .41951 .55982 L .41557 .55917 L F
.736 .284 .179 r
.41951 .55982 m .42154 .56247 L .4183 .56181 L F
.884 .784 .746 r
.33955 .65898 m .33944 .65384 L .33747 .65761 L F
.773 .266 0 r
.50911 .41553 m .512 .41746 L .51077 .41717 L F
.51077 .41717 m .512 .41746 L .50911 .41553 L F
.44 .866 .935 r
.5136 .41642 m .512 .41746 L .51077 .41717 L F
.51077 .41717 m .512 .41746 L .5136 .41642 L F
.67 .789 .938 r
.31788 .66776 m .31773 .67091 L .32234 .66851 L F
.702 .775 .909 r
.37651 .57859 m .3786 .58058 L .3809 .57899 L F
.69 .711 .864 r
.541 .38983 m .5385 .39271 L .53655 .38905 L F
.48 .423 .716 r
.54173 .39311 m .5385 .39271 L .541 .38983 L F
.345 .326 .695 r
.51255 .40159 m .51227 .40521 L .51445 .4024 L F
.081 0 .363 r
.51227 .40521 m .51281 .40645 L .51454 .4048 L F
0 0 0 r
.54832 .4266 m .55187 .42381 L .55139 .42387 L F
.82 .85 .871 r
.4469 .52897 m .44762 .53231 L .44818 .53058 L F
.4469 .52897 m .44401 .53175 L .44762 .53231 L F
.87 .784 .763 r
.44401 .53175 m .44533 .53543 L .44762 .53231 L F
.563 .916 .718 r
.51001 .39268 m .51135 .3912 L .51316 .39048 L F
.51001 .39268 m .50923 .3929 L .51135 .3912 L F
.913 .698 .198 r
.33671 .62708 m .33598 .62279 L .33535 .62618 L F
.966 .679 .435 r
.33416 .62924 m .33671 .62708 L .33535 .62618 L F
.33416 .62924 m .3367 .62998 L .33671 .62708 L F
.356 .072 .338 r
.46909 .44491 m .47078 .44656 L .47107 .44378 L F
.46909 .44491 m .46835 .44729 L .47078 .44656 L F
.504 .571 .857 r
.63338 .35039 m .63214 .3529 L .63091 .3488 L F
0 0 .258 r
.63091 .3488 m .63214 .3529 L .63154 .35069 L F
.749 .559 .639 r
.63142 .35363 m .63154 .35069 L .63214 .3529 L F
0 0 0 r
.63435 .3523 m .63214 .3529 L .63338 .35039 L F
.63435 .3523 m .63142 .35363 L .63214 .3529 L F
.879 .927 .85 r
.55509 .42082 m .55664 .41607 L .55372 .41667 L F
.55509 .42082 m .55798 .4175 L .55664 .41607 L F
.515 .761 .985 r
.5447 .3779 m .54792 .37769 L .54687 .3795 L F
.739 .705 .169 r
.54792 .37769 m .54711 .38252 L .54687 .3795 L F
.988 .723 .419 r
.64112 .35559 m .64139 .35659 L .63966 .35466 L F
.6402 .35435 m .63966 .35466 L .63892 .35261 L F
.64112 .35559 m .63966 .35466 L .6402 .35435 L F
0 0 .319 r
.64139 .35659 m .64351 .35663 L .63966 .35466 L F
.702 .345 .369 r
.64351 .35663 m .63922 .35492 L .63966 .35466 L F
.63922 .35492 m .63747 .35422 L .63966 .35466 L F
.855 .875 .854 r
.66032 .36718 m .66309 .36371 L .66166 .36184 L F
.899 .95 .828 r
.66032 .36718 m .6606 .36383 L .65776 .36723 L F
.442 .574 .891 r
.55205 .36426 m .55053 .36634 L .54876 .36287 L F
.653 .484 .643 r
.55205 .36426 m .54866 .36817 L .55053 .36634 L F
.105 0 .246 r
.4881 .40953 m .48612 .41086 L .48552 .41322 L F
.234 0 .157 r
.44451 .44806 m .44615 .44892 L .44715 .44726 L F
.44451 .44806 m .44374 .44989 L .44615 .44892 L F
.473 .166 .364 r
.29567 .64115 m .29862 .64075 L .30075 .63762 L F
.35 0 .032 r
.3001 .63942 m .30075 .63762 L .29862 .64075 L F
.3001 .63942 m .30246 .63723 L .30075 .63762 L F
.295 0 .042 r
.36461 .48647 m .36757 .48651 L .36698 .48581 L F
.376 .093 .35 r
.45856 .45668 m .45652 .45438 L .45914 .45321 L F
.45856 .45668 m .45602 .45761 L .45652 .45438 L F
0 0 .285 r
.58624 .353 m .58744 .35329 L .58863 .35132 L F
.58624 .353 m .58642 .3556 L .58744 .35329 L F
0 0 .307 r
.55426 .39705 m .55575 .39562 L .55516 .39321 L F
0 0 .356 r
.55426 .39705 m .55516 .39814 L .55575 .39562 L F
.413 .568 .899 r
.53107 .39369 m .53418 .39646 L .5331 .39163 L F
.467 .605 .905 r
.53418 .39646 m .53501 .39038 L .5331 .39163 L F
0 0 0 r
.54011 .39571 m .54085 .39545 L .5394 .39685 L F
.54173 .39311 m .54085 .39545 L .54011 .39571 L F
.452 .367 .669 r
.54367 .39729 m .54145 .39873 L .54085 .39545 L F
.54085 .39545 m .54145 .39873 L .54367 .39729 L F
0 0 .48 r
.54085 .39545 m .54145 .39873 L .54093 .39542 L F
.337 .301 .67 r
.54341 .39099 m .54173 .39311 L .541 .38983 L F
0 0 0 r
.54341 .39099 m .54085 .39545 L .54173 .39311 L F
.757 .647 .74 r
.54072 .39407 m .54085 .39545 L .54341 .39099 L F
0 0 .48 r
.54085 .39545 m .54093 .39542 L .54072 .39407 L F
0 0 0 r
.54072 .39407 m .5394 .39685 L .54085 .39545 L F
.54072 .39407 m .5399 .39619 L .5394 .39685 L F
.467 .605 .905 r
.53418 .39646 m .5399 .39619 L .53501 .39038 L F
0 0 0 r
.47409 .42374 m .47632 .42281 L .47754 .42097 L F
.48004 .4173 m .47754 .42097 L .47897 .41917 L F
.47754 .42097 m .47863 .42173 L .47897 .41917 L F
.47754 .42097 m .47632 .42281 L .47863 .42173 L F
.888 .839 .792 r
.41192 .53151 m .41631 .52926 L .41107 .53007 L F
.41192 .53151 m .41304 .53442 L .41631 .52926 L F
0 0 0 r
.48329 .41453 m .48206 .41564 L .48552 .41322 L F
.938 .897 .498 r
.52302 .43745 m .52163 .43886 L .52267 .43467 L F
.852 .995 .827 r
.46787 .44106 m .46747 .43805 L .4642 .44128 L F
.84 .702 .711 r
.64795 .35792 m .65157 .35946 L .65024 .35606 L F
.837 .421 .248 r
.64795 .35792 m .65023 .36109 L .65157 .35946 L F
.719 .26 .16 r
.65023 .36109 m .65435 .36194 L .65157 .35946 L F
.738 .815 .912 r
.31299 .6522 m .30866 .65182 L .3104 .65034 L F
.736 .72 .836 r
.31474 .65026 m .31299 .6522 L .3104 .65034 L F
.749 .467 .505 r
.35299 .56069 m .35459 .5633 L .35625 .55979 L F
.764 .897 .936 r
.51178 .4233 m .51381 .42474 L .51634 .42241 L F
.624 .157 .125 r
.5189 .42277 m .51472 .4227 L .5162 .42079 L F
.095 0 0 r
.51472 .4227 m .5189 .42277 L .5162 .42079 L F
.859 .724 .712 r
.60422 .34682 m .60272 .34924 L .60107 .34518 L F
.764 .423 .407 r
.63118 .34655 m .6296 .34905 L .62636 .34594 L F
.63118 .34655 m .63091 .3488 L .6296 .34905 L F
.951 .864 .717 r
.66166 .36184 m .66309 .36371 L .66429 .36106 L F
.778 .904 .929 r
.49435 .47331 m .49588 .4746 L .49921 .47192 L F
.468 .874 .719 r
.51316 .39048 m .51419 .38948 L .51556 .38911 L F
.51316 .39048 m .51135 .3912 L .51419 .38948 L F
.999 .797 .456 r
.48749 .46784 m .48652 .4638 L .48882 .46456 L F
.48749 .46784 m .48632 .46713 L .48652 .4638 L F
.311 0 .262 r
.5154 .38662 m .51776 .3862 L .51862 .38324 L F
.498 .788 .997 r
.51862 .38324 m .5208 .37978 L .51783 .38081 L F
.51862 .38324 m .51966 .38114 L .5208 .37978 L F
.51862 .38324 m .52117 .38255 L .51966 .38114 L F
0 0 0 r
.51862 .38324 m .51966 .38114 L .52117 .38255 L F
.51862 .38324 m .51881 .38364 L .51966 .38114 L F
.51862 .38324 m .51776 .3862 L .51881 .38364 L F
.996 .764 .42 r
.55664 .41607 m .55798 .4175 L .55726 .41427 L F
0 0 0 r
.55614 .41754 m .55664 .41607 L .55836 .41414 L F
.55547 .41856 m .55664 .41607 L .55614 .41754 L F
.996 .764 .42 r
.55664 .41607 m .55726 .41427 L .55713 .41368 L F
.492 .236 .454 r
.43206 .47417 m .42854 .47764 L .42906 .47471 L F
.391 0 .142 r
.39965 .4796 m .40384 .47665 L .4015 .47781 L F
.639 .819 .97 r
.48098 .47018 m .47747 .4687 L .47887 .46728 L F
.655 .88 .981 r
.48174 .46747 m .48098 .47018 L .47887 .46728 L F
.48174 .46747 m .48363 .46855 L .48098 .47018 L F
.934 .803 .691 r
.33774 .64999 m .34016 .65119 L .3387 .64714 L F
.954 .745 .584 r
.33944 .65384 m .34016 .65119 L .33774 .64999 L F
.857 .78 .775 r
.3387 .64714 m .34016 .65119 L .34187 .64768 L F
0 0 .198 r
.57721 .36127 m .57761 .36367 L .57675 .35919 L F
.14 .446 .879 r
.57987 .36309 m .57761 .36367 L .57721 .36127 L F
.57987 .36309 m .58082 .36509 L .57761 .36367 L F
.818 .654 .679 r
.35459 .5633 m .35708 .56696 L .35741 .56358 L F
.818 .662 .689 r
.35625 .55979 m .35459 .5633 L .35741 .56358 L F
.818 .654 .679 r
.35459 .5633 m .35708 .56696 L .35741 .56358 L F
.689 .877 .491 r
.42536 .56198 m .42442 .56363 L .42685 .55995 L F
.638 .858 .48 r
.42685 .55995 m .42938 .55644 L .42788 .55823 L F
.654 .865 .486 r
.42788 .55823 m .42536 .56198 L .42685 .55995 L F
.855 .96 .874 r
.52561 .40561 m .52671 .40685 L .52984 .40354 L F
.656 .883 .981 r
.61324 .34581 m .61602 .34718 L .61519 .34487 L F
.328 .618 .955 r
.61602 .34718 m .6175 .34561 L .61519 .34487 L F
.61602 .34718 m .61941 .34759 L .6175 .34561 L F
.821 .48 .41 r
.42727 .53274 m .42761 .53518 L .42474 .5347 L F
.918 .939 .802 r
.42626 .53142 m .43002 .52902 L .42727 .53274 L F
.959 .939 .712 r
.42474 .5347 m .42626 .53142 L .42727 .53274 L F
.821 .48 .41 r
.42727 .53274 m .42761 .53518 L .42474 .5347 L F
.742 .574 .667 r
.42727 .53274 m .42934 .53571 L .42761 .53518 L F
.671 .612 .781 r
.28674 .65139 m .28907 .64707 L .28663 .64828 L F
.927 .779 .677 r
.33947 .64428 m .34121 .64071 L .33936 .63893 L F
.794 .855 .896 r
.55665 .37777 m .55561 .37906 L .55444 .37622 L F
.828 .668 .684 r
.55441 .37247 m .55665 .37777 L .55232 .37461 L F
.794 .855 .896 r
.55389 .37575 m .55444 .37622 L .55232 .37461 L F
.55665 .37777 m .55444 .37622 L .55389 .37575 L F
.619 .571 .778 r
.55865 .37587 m .55665 .37777 L .55441 .37247 L F
.413 0 0 r
.55865 .37587 m .55444 .37622 L .55561 .37906 L F
.421 0 0 r
.55718 .37701 m .55538 .37702 L .55444 .37622 L F
.55538 .37702 m .55322 .37703 L .55444 .37622 L F
.921 .715 .607 r
.42154 .56247 m .42442 .56363 L .42536 .56198 L F
.918 .939 .802 r
.42626 .53142 m .42859 .5279 L .43002 .52902 L F
.848 .837 .834 r
.43097 .52399 m .43002 .52902 L .42859 .5279 L F
.43097 .52399 m .43284 .52554 L .43002 .52902 L F
.407 .571 .903 r
.37436 .57871 m .37458 .57529 L .37202 .57727 L F
.37436 .57871 m .37651 .57859 L .37458 .57529 L F
.071 0 0 r
.52237 .38631 m .51843 .3887 L .52082 .38997 L F
0 .049 .615 r
.52103 .38795 m .52082 .38997 L .51843 .3887 L F
.665 .118 0 r
.52285 .39157 m .52264 .39203 L .52424 .39265 L F
.52082 .38997 m .52264 .39203 L .52285 .39157 L F
.15 0 0 r
.52424 .39265 m .52565 .3927 L .52851 .39156 L F
.052 .59 .852 r
.52264 .39203 m .52565 .3927 L .52424 .39265 L F
.68 .491 .623 r
.52307 .3938 m .52565 .3927 L .52264 .39203 L F
0 0 0 r
.52334 .39162 m .52228 .3928 L .52264 .39203 L F
.52228 .3928 m .52137 .39382 L .52264 .39203 L F
0 .049 .615 r
.52103 .38795 m .52264 .39203 L .52082 .38997 L F
.361 0 0 r
.38793 .48184 m .39059 .48177 L .39199 .48104 L F
.437 0 0 r
.39199 .48104 m .39059 .48177 L .39462 .48118 L F
.445 .445 .765 r
.39857 .56266 m .39463 .55942 L .39651 .55959 L F
.7 .611 .755 r
.32345 .62101 m .32035 .62428 L .31926 .62019 L F
.641 .847 .979 r
.65276 .33569 m .64986 .33694 L .64871 .33532 L F
.64871 .33532 m .64986 .33694 L .65276 .33569 L F
.772 .709 .172 r
.55965 .40756 m .55998 .40721 L .55989 .40633 L F
0 0 0 r
.56078 .40527 m .55945 .4086 L .55965 .40756 L F
0 0 .002 r
.55713 .41368 m .55951 .41014 L .55825 .41228 L F
.881 .924 .535 r
.55825 .41228 m .55951 .41014 L .55965 .40756 L F
.55825 .41228 m .55965 .40756 L .55929 .41039 L F
.785 .704 .165 r
.5593 .40898 m .55929 .41039 L .55965 .40756 L F
0 0 0 r
.55945 .4086 m .5593 .40898 L .55965 .40756 L F
.772 .709 .172 r
.55965 .40756 m .55989 .40633 L .55974 .40476 L F
.55965 .40756 m .55951 .41014 L .55998 .40721 L F
.132 0 .126 r
.43249 .45858 m .4342 .45921 L .43501 .45742 L F
.43249 .45858 m .4319 .4604 L .4342 .45921 L F
.057 0 0 r
.55758 .40037 m .5549 .40078 L .55516 .39814 L F
.134 0 .143 r
.31443 .61999 m .31366 .61917 L .31206 .62046 L F
.31443 .61999 m .31545 .61762 L .31366 .61917 L F
.783 .593 .026 r
.58812 .36624 m .5884 .37036 L .58803 .36749 L F
0 .028 .579 r
.58812 .36624 m .58877 .36543 L .58749 .36241 L F
0 0 0 r
.58812 .36624 m .58803 .36749 L .58877 .36543 L F
.086 .392 .85 r
.35145 .57344 m .35214 .57175 L .35008 .57168 L F
.35145 .57344 m .35438 .57494 L .35214 .57175 L F
.803 .764 .817 r
.38902 .56647 m .38511 .56575 L .38676 .56507 L F
.285 0 .249 r
.47317 .42585 m .47632 .42281 L .47409 .42374 L F
.879 .835 .799 r
.44962 .52497 m .4469 .52897 L .45076 .52842 L F
.856 .888 .86 r
.4469 .52897 m .44818 .53058 L .45076 .52842 L F
.875 .834 .802 r
.44962 .52497 m .45076 .52842 L .4516 .5263 L F
0 0 0 r
.48004 .4173 m .48201 .41595 L .48206 .41564 L F
0 0 .104 r
.47897 .41917 m .48201 .41595 L .48004 .4173 L F
.868 .969 .857 r
.42938 .55644 m .43238 .55337 L .4285 .55436 L F
.794 .992 .88 r
.43363 .55133 m .4285 .55436 L .43238 .55337 L F
.796 .783 .841 r
.44149 .5353 m .43848 .53854 L .44238 .53897 L F
.924 .83 .733 r
.43845 .54137 m .44238 .53897 L .43848 .53854 L F
.43845 .54137 m .44049 .54281 L .44238 .53897 L F
.827 .8 .826 r
.44149 .5353 m .44238 .53897 L .44533 .53543 L F
.406 .4 .74 r
.36713 .57955 m .36357 .57608 L .36545 .57819 L F
0 .094 .615 r
.36456 .57457 m .36545 .57819 L .36357 .57608 L F
.638 .943 .957 r
.62314 .37461 m .62376 .37274 L .62545 .37283 L F
.62314 .37461 m .62089 .37422 L .62376 .37274 L F
.704 .573 .705 r
.52906 .38126 m .53082 .38291 L .53078 .37914 L F
.52811 .38243 m .52964 .3827 L .52906 .38126 L F
.52964 .3827 m .53082 .38291 L .52906 .38126 L F
.39 .401 .751 r
.52898 .38241 m .52921 .38668 L .53069 .38531 L F
.52978 .38306 m .53069 .38531 L .53158 .38448 L F
.52898 .38241 m .53069 .38531 L .52978 .38306 L F
0 0 .189 r
.52921 .38668 m .52894 .38941 L .53023 .38599 L F
.603 .935 .733 r
.63759 .36254 m .6391 .36074 L .6409 .35989 L F
.89 .602 .492 r
.42934 .53571 m .4274 .53817 L .42761 .53518 L F
.42934 .53571 m .4298 .53696 L .4274 .53817 L F
.909 .881 .795 r
.39028 .57891 m .39205 .58013 L .39414 .5764 L F
.014 0 .248 r
.55516 .39321 m .55779 .38953 L .55513 .39024 L F
.55516 .39321 m .55757 .39168 L .55779 .38953 L F
.056 0 .317 r
.55516 .39321 m .5574 .39413 L .55757 .39168 L F
.55516 .39321 m .55575 .39562 L .5574 .39413 L F
.93 .942 .782 r
.42128 .54709 m .42392 .54657 L .42132 .54874 L F
.876 .992 .806 r
.42401 .54418 m .42518 .54475 L .42392 .54657 L F
.855 .988 .849 r
.42401 .54418 m .42392 .54657 L .42128 .54709 L F
.941 .925 .763 r
.46554 .50388 m .46465 .50876 L .46722 .5051 L F
.838 .906 .885 r
.46554 .50388 m .46722 .5051 L .47018 .50206 L F
.243 0 .184 r
.41683 .48465 m .42001 .48191 L .41936 .48369 L F
.421 .132 .366 r
.42245 .48096 m .41936 .48369 L .42001 .48191 L F
.975 .877 .5 r
.42938 .55644 m .4285 .55436 L .42788 .55823 L F
.889 .919 .837 r
.50679 .42735 m .50376 .43071 L .50235 .42908 L F
.49 .252 .48 r
.50679 .42735 m .50734 .43014 L .50376 .43071 L F
.889 .919 .837 r
.50679 .42735 m .50235 .42908 L .50532 .42949 L F
.415 .205 .483 r
.50981 .42703 m .50734 .43014 L .50679 .42735 L F
.835 .805 .822 r
.50532 .42949 m .50981 .42703 L .50679 .42735 L F
.981 .885 .657 r
.4101 .52556 m .4122 .52594 L .41044 .52472 L F
.783 .714 .787 r
.63455 .34686 m .63233 .34629 L .63423 .34667 L F
.082 .565 .901 r
.634 .34601 m .63642 .34711 L .63233 .34629 L F
0 .34 .787 r
.63091 .3488 m .63274 .34998 L .63267 .34993 L F
.504 .571 .857 r
.63338 .35039 m .63091 .3488 L .63154 .35069 L F
.66 .411 .533 r
.63091 .3488 m .63154 .35069 L .63267 .34993 L F
.85 .935 .56 r
.63193 .34942 m .63189 .34948 L .63267 .34993 L F
.345 0 0 r
.63189 .34948 m .63205 .3495 L .63267 .34993 L F
.85 .935 .56 r
.63385 .34645 m .63193 .34942 L .63267 .34993 L F
.783 .714 .787 r
.63711 .34752 m .63455 .34686 L .63642 .34711 L F
.369 .265 .603 r
.63642 .34711 m .63338 .35039 L .63267 .34993 L F
.63642 .34711 m .63602 .3501 L .63338 .35039 L F
.783 .714 .787 r
.63455 .34686 m .63423 .34667 L .63642 .34711 L F
.85 .935 .56 r
.634 .34601 m .63267 .34993 L .63642 .34711 L F
.502 .384 .651 r
.63267 .34993 m .63602 .3501 L .63642 .34711 L F
.345 0 0 r
.63205 .3495 m .63602 .3501 L .63267 .34993 L F
0 .34 .787 r
.63274 .34998 m .63276 .34999 L .63267 .34993 L F
.63276 .34999 m .63338 .35039 L .63267 .34993 L F
.85 .935 .56 r
.634 .34601 m .63376 .3464 L .63385 .34645 L F
.63376 .3464 m .63189 .34948 L .63385 .34645 L F
.774 .755 .836 r
.55142 .38983 m .55266 .39105 L .55513 .39024 L F
.42 .21 .487 r
.55513 .39024 m .55779 .38953 L .55857 .38641 L F
.839 .677 .682 r
.40781 .56888 m .41198 .57023 L .41032 .56689 L F
.853 .68 .667 r
.40781 .56888 m .41111 .573 L .41198 .57023 L F
.249 0 .193 r
.43815 .45368 m .44065 .45344 L .44134 .45092 L F
.283 0 .205 r
.44134 .45092 m .44318 .45257 L .44374 .44989 L F
.44134 .45092 m .44065 .45344 L .44318 .45257 L F
.817 .605 .615 r
.31887 .61375 m .31828 .61694 L .32122 .61427 L F
.822 .721 .754 r
.32929 .66801 m .33344 .66793 L .3318 .66422 L F
.767 .552 .607 r
.33601 .66758 m .3318 .66422 L .33344 .66793 L F
.792 .793 .853 r
.46008 .48826 m .45607 .48796 L .45898 .48504 L F
.789 .792 .855 r
.46329 .48527 m .46008 .48826 L .45898 .48504 L F
.915 .972 .679 r
.64219 .38346 m .64438 .37953 L .64377 .37873 L F
.833 .971 .887 r
.64792 .37682 m .64377 .37873 L .64438 .37953 L F
.751 .986 .902 r
.52911 .44792 m .52678 .44758 L .52474 .4498 L F
.73 .978 .918 r
.53104 .44631 m .53015 .44563 L .52911 .44792 L F
.737 .983 .906 r
.53015 .44563 m .52678 .44758 L .52911 .44792 L F
.377 .716 .988 r
.52153 .40232 m .52634 .40358 L .52292 .40384 L F
.449 .254 .523 r
.52292 .40384 m .52634 .40358 L .52153 .40232 L F
.52292 .40384 m .52561 .40561 L .52634 .40358 L F
.406 .141 .396 r
.44985 .4601 m .44647 .46352 L .44708 .46086 L F
.321 .722 .98 r
.30332 .63631 m .30533 .6375 L .30246 .63723 L F
.524 .843 .543 r
.30332 .63631 m .30246 .63723 L .3001 .63942 L F
.321 .722 .98 r
.30332 .63631 m .30533 .6375 L .30246 .63723 L F
.829 .837 .853 r
.3509 .56736 m .34728 .57094 L .34564 .56874 L F
.304 .463 .854 r
.34728 .57094 m .34822 .56812 L .34564 .56874 L F
.34728 .57094 m .35008 .57168 L .34822 .56812 L F
.909 .568 .385 r
.33976 .63693 m .33958 .63444 L .3374 .63367 L F
.892 .826 .775 r
.46835 .5005 m .47263 .49849 L .47067 .49712 L F
.46835 .5005 m .47018 .50206 L .47263 .49849 L F
.843 .845 .846 r
.47067 .49712 m .47263 .49849 L .47548 .49496 L F
.977 .92 .638 r
.43363 .55133 m .43492 .54966 L .43277 .55094 L F
.766 .981 .725 r
.4379 .54632 m .43564 .54764 L .43492 .54966 L F
.767 .977 .71 r
.43492 .54966 m .43564 .54764 L .43277 .55094 L F
0 0 0 r
.36292 .58031 m .36713 .57955 L .36545 .57819 L F
.748 .266 .098 r
.64507 .35051 m .64658 .34933 L .6445 .34837 L F
.64507 .35051 m .64874 .35155 L .64658 .34933 L F
.724 .958 .945 r
.41557 .55917 m .41301 .56047 L .41432 .55831 L F
.907 .969 .806 r
.41767 .55601 m .41557 .55917 L .41432 .55831 L F
.317 .283 .662 r
.52153 .39703 m .52412 .39882 L .52307 .3938 L F
.491 0 0 r
.31691 .6191 m .32186 .61761 L .31545 .61762 L F
.798 .459 .414 r
.31828 .61694 m .32186 .61761 L .31691 .6191 L F
.126 0 0 r
.40844 .5613 m .41085 .56127 L .41301 .56047 L F
.601 .362 .527 r
.41085 .56127 m .41432 .55831 L .41301 .56047 L F
.854 .923 .875 r
.42084 .53869 m .41765 .54168 L .41586 .54137 L F
.676 .918 .598 r
.41853 .54023 m .41765 .54168 L .41883 .53989 L F
.748 .665 .77 r
.41498 .54228 m .41709 .54263 L .41765 .54168 L F
.389 .825 .953 r
.41586 .54137 m .41765 .54168 L .41498 .54228 L F
.113 0 0 r
.41498 .54228 m .41765 .54168 L .41582 .54327 L F
.389 .825 .953 r
.41586 .54137 m .41765 .54168 L .41498 .54228 L F
.676 .918 .598 r
.41582 .54327 m .41765 .54168 L .41853 .54023 L F
.748 .665 .77 r
.41709 .54263 m .41956 .54303 L .41765 .54168 L F
.909 .881 .795 r
.39028 .57891 m .39414 .5764 L .3923 .57719 L F
.546 .37 .595 r
.39615 .57343 m .39732 .57598 L .39414 .5764 L F
.154 0 0 r
.39414 .5764 m .39539 .57714 L .3923 .57719 L F
.39414 .5764 m .39732 .57598 L .39539 .57714 L F
.26 0 0 r
.41683 .48465 m .4153 .48631 L .41233 .48606 L F
.199 0 .1 r
.41683 .48465 m .41793 .48652 L .4153 .48631 L F
.41683 .48465 m .41936 .48369 L .41793 .48652 L F
.372 .469 .83 r
.28711 .65426 m .28874 .65818 L .29034 .65595 L F
.331 .411 .794 r
.29034 .65595 m .28874 .65818 L .29139 .65842 L F
.225 0 .138 r
.46529 .45047 m .46484 .45239 L .46278 .45152 L F
.717 .424 .48 r
.46484 .45239 m .46111 .44972 L .46278 .45152 L F
.357 .015 .241 r
.43815 .45368 m .44014 .45579 L .44065 .45344 L F
.43815 .45368 m .43744 .45651 L .44014 .45579 L F
.82 .839 .864 r
.43581 .52242 m .43284 .52554 L .43097 .52399 L F
.687 .562 .708 r
.35501 .55547 m .35625 .55979 L .35838 .55616 L F
.905 .781 .295 r
.6014 .36465 m .60145 .36915 L .6017 .36605 L F
.301 .682 .976 r
.35879 .56607 m .35708 .56696 L .35459 .5633 L F
.159 0 .115 r
.49133 .40659 m .48874 .40807 L .4881 .40953 L F
.224 .182 .598 r
.3972 .56825 m .39846 .5723 L .39615 .57343 L F
0 .027 .578 r
.39788 .57343 m .39615 .57343 L .39846 .5723 L F
.39788 .57343 m .39732 .57598 L .39615 .57343 L F
.238 .412 .833 r
.51835 .41467 m .51903 .4173 L .52073 .41583 L F
.963 .831 .406 r
.52483 .40999 m .52359 .41213 L .52426 .41298 L F
.838 .802 .816 r
.40955 .52957 m .40723 .53262 L .40494 .53161 L F
.913 .666 .552 r
.40723 .53262 m .40695 .53441 L .40494 .53161 L F
.359 .326 .686 r
.59905 .38532 m .59924 .38875 L .5972 .38981 L F
.271 .149 .524 r
.59993 .39102 m .5972 .38981 L .59924 .38875 L F
.59993 .39102 m .59755 .39352 L .5972 .38981 L F
.771 .391 .336 r
.6065 .33854 m .61088 .34062 L .61033 .33988 L F
.389 0 .103 r
.29651 .64258 m .29567 .64115 L .29418 .64339 L F
.376 0 .112 r
.29651 .64258 m .29862 .64075 L .29567 .64115 L F
.577 .426 .64 r
.32579 .61722 m .32912 .61594 L .32916 .61371 L F
.431 .873 .856 r
.32624 .61649 m .32579 .61722 L .32406 .61699 L F
.32624 .61649 m .32912 .61594 L .32579 .61722 L F
.883 .946 .847 r
.46465 .50876 m .46047 .51108 L .4623 .51239 L F
.46465 .50876 m .46326 .50779 L .46047 .51108 L F
.941 .925 .763 r
.46554 .50388 m .46326 .50779 L .46465 .50876 L F
.854 .752 .75 r
.46547 .48145 m .46113 .48335 L .46354 .48008 L F
.46547 .48145 m .46329 .48527 L .46113 .48335 L F
.814 .828 .861 r
.46862 .47822 m .46547 .48145 L .46354 .48008 L F
.071 0 0 r
.52237 .38631 m .52103 .38795 L .51843 .3887 L F
.487 .209 .416 r
.52584 .38397 m .52775 .38527 L .52237 .38631 L F
.036 0 0 r
.52323 .38715 m .52237 .38631 L .52775 .38527 L F
.52323 .38715 m .52103 .38795 L .52237 .38631 L F
.53 .034 .023 r
.49848 .43761 m .50096 .43927 L .49815 .43872 L F
.428 .13 .356 r
.50122 .43662 m .50096 .43927 L .49848 .43761 L F
.891 .468 .092 r
.35426 .57887 m .35382 .58114 L .35404 .57741 L F
.35426 .57887 m .35553 .58222 L .35382 .58114 L F
.265 .665 .968 r
.35933 .5718 m .36117 .57321 L .35852 .57312 L F
.35933 .5718 m .36117 .57321 L .35852 .57312 L F
.811 .92 .91 r
.50712 .46402 m .51167 .4623 L .51052 .46158 L F
.791 .896 .918 r
.51052 .46158 m .51167 .4623 L .51377 .46078 L F
.465 .011 .087 r
.38759 .483 m .39031 .48318 L .38793 .48184 L F
.455 .029 .14 r
.38793 .48184 m .39031 .48318 L .39059 .48177 L F
.795 .936 .923 r
.63761 .38504 m .64219 .38346 L .64095 .38206 L F
.915 .972 .679 r
.64219 .38346 m .64377 .37873 L .64095 .38206 L F
.952 .792 .647 r
.4274 .53817 m .4298 .53696 L .42875 .54197 L F
.698 .436 .524 r
.53934 .36497 m .53898 .36908 L .53536 .36845 L F
0 0 .36 r
.54074 .36105 m .54062 .36344 L .53934 .36497 L F
.734 .24 0 r
.41043 .53044 m .41107 .53007 L .4101 .52556 L F
.41043 .53044 m .41192 .53151 L .41107 .53007 L F
.839 .772 .787 r
.44149 .5353 m .44533 .53543 L .44401 .53175 L F
.907 .711 .626 r
.43899 .51562 m .43637 .51741 L .43704 .51473 L F
.43899 .51562 m .43857 .51883 L .43637 .51741 L F
.23 0 0 r
.62349 .34541 m .62229 .34704 L .61941 .34759 L F
.031 0 0 r
.62636 .34594 m .62229 .34704 L .62349 .34541 L F
.775 .997 .852 r
.3509 .56736 m .35147 .56534 L .35291 .56518 L F
.628 .958 .803 r
.35259 .56522 m .35147 .56534 L .35359 .56364 L F
.03 0 0 r
.35017 .5661 m .35359 .56364 L .35147 .56534 L F
.829 .837 .853 r
.3509 .56736 m .34698 .56839 L .34822 .56812 L F
.34698 .56839 m .34564 .56874 L .34822 .56812 L F
.187 .202 .644 r
.34822 .56812 m .35053 .57109 L .35028 .56768 L F
.775 .997 .852 r
.3509 .56736 m .34822 .56812 L .35147 .56534 L F
.577 .904 .658 r
.35147 .56534 m .34972 .56684 L .35017 .5661 L F
.34972 .56684 m .34822 .56812 L .35017 .5661 L F
0 0 .376 r
.35014 .56238 m .35077 .56511 L .35017 .5661 L F
.03 0 0 r
.35088 .56559 m .35117 .56688 L .35359 .56364 L F
0 0 .376 r
.35077 .56511 m .35117 .56688 L .35017 .5661 L F
.187 .202 .644 r
.34822 .56812 m .35028 .56768 L .35017 .5661 L F
.611 .828 .434 r
.35359 .56364 m .35117 .56688 L .35443 .56231 L F
.35359 .56364 m .35443 .56231 L .35454 .56215 L F
.628 .958 .803 r
.35291 .56518 m .35259 .56522 L .35359 .56364 L F
.513 .576 .856 r
.40162 .5765 m .40424 .57608 L .40276 .57225 L F
.334 .809 .745 r
.609 .39884 m .61321 .39742 L .61165 .39769 L F
.218 .741 .798 r
.61321 .39742 m .61436 .39686 L .61165 .39769 L F
.61321 .39742 m .61611 .39686 L .61436 .39686 L F
.272 0 .039 r
.56444 .38683 m .56257 .38365 L .56234 .38569 L F
.43 .029 .176 r
.62071 .33822 m .62378 .33799 L .62456 .33558 L F
.666 .254 .255 r
.62456 .33558 m .62773 .33779 L .62758 .33493 L F
.62456 .33558 m .62378 .33799 L .62773 .33779 L F
.736 .246 .074 r
.49 .42217 m .49118 .42052 L .49242 .4185 L F
.49 .42217 m .49357 .42291 L .49118 .42052 L F
.103 .21 .691 r
.32912 .61594 m .33158 .61876 L .33019 .62043 L F
.137 .262 .73 r
.33158 .61876 m .33344 .62208 L .33019 .62043 L F
.454 .885 .834 r
.61064 .37919 m .60472 .38096 L .60701 .38078 L F
.61064 .37919 m .6072 .3798 L .60472 .38096 L F
.885 .767 .726 r
.60701 .38078 m .60989 .38111 L .61064 .37919 L F
.447 .461 .78 r
.60989 .38111 m .6117 .37886 L .61064 .37919 L F
0 0 0 r
.46621 .43663 m .46948 .4345 L .46848 .43602 L F
.308 0 .104 r
.62014 .39549 m .62292 .39375 L .62288 .39472 L F
.443 .007 .114 r
.62288 .39472 m .62292 .39375 L .6255 .39483 L F
.428 .065 .245 r
.62292 .39375 m .62546 .39327 L .6255 .39483 L F
.79 .353 .209 r
.63892 .35261 m .63747 .35422 L .63338 .35039 L F
.816 .39 .23 r
.63966 .35466 m .63747 .35422 L .63892 .35261 L F
.346 0 .137 r
.42599 .46356 m .42855 .46309 L .42951 .46132 L F
.206 0 .066 r
.42951 .46132 m .43105 .46221 L .4319 .4604 L F
.42951 .46132 m .42855 .46309 L .43105 .46221 L F
.495 .573 .864 r
.52851 .39156 m .53107 .39369 L .52894 .38941 L F
.895 .586 .455 r
.50376 .43071 m .50085 .43191 L .50235 .42908 L F
.50376 .43071 m .50388 .4333 L .50085 .43191 L F
.329 .147 .476 r
.5053 .43184 m .50376 .43071 L .50714 .43034 L F
.50554 .43201 m .50388 .4333 L .50376 .43071 L F
.84 .476 .363 r
.5017 .43441 m .50287 .43382 L .50494 .43117 L F
.50287 .43382 m .50388 .4333 L .50414 .43279 L F
.50287 .43382 m .50414 .43279 L .50494 .43117 L F
.329 .147 .476 r
.50714 .43034 m .50376 .43071 L .50734 .43014 L F
.50554 .43201 m .5053 .43184 L .50714 .43034 L F
.759 .392 .36 r
.53147 .37846 m .53078 .37914 L .53542 .3797 L F
.689 .561 .705 r
.53078 .37914 m .53524 .38246 L .53542 .3797 L F
.965 .75 .564 r
.49535 .42657 m .49695 .43077 L .49642 .4284 L F
.926 .748 .642 r
.4948 .42909 m .49695 .43077 L .49535 .42657 L F
.239 .748 .713 r
.49195 .43222 m .49695 .43077 L .4948 .42909 L F
.855 .96 .874 r
.52561 .40561 m .52984 .40354 L .52834 .40216 L F
.745 .662 .768 r
.37682 .55996 m .37829 .56402 L .37978 .56263 L F
.881 .823 .786 r
.47359 .49349 m .47791 .49116 L .47649 .48978 L F
.47359 .49349 m .47548 .49496 L .47791 .49116 L F
.71 .974 .924 r
.48097 .48811 m .47649 .48978 L .47791 .49116 L F
.958 .929 .725 r
.43845 .54137 m .4379 .54632 L .44049 .54281 L F
.43845 .54137 m .43665 .54495 L .4379 .54632 L F
.986 .895 .633 r
.43665 .54495 m .43564 .54764 L .4379 .54632 L F
.333 .005 .25 r
.40725 .47456 m .40981 .4738 L .4103 .47181 L F
.377 0 .19 r
.40981 .4738 m .41379 .47058 L .4103 .47181 L F
.838 .802 .816 r
.40955 .52957 m .40494 .53161 L .4078 .5283 L F
.491 0 0 r
.31691 .6191 m .31545 .61762 L .31443 .61999 L F
.905 .781 .295 r
.6014 .36465 m .60078 .36864 L .60145 .36915 L F
.762 .275 0 r
.60078 .36864 m .6034 .37126 L .60145 .36915 L F
.866 .837 .816 r
.44962 .52497 m .4516 .5263 L .45409 .52272 L F
.496 0 0 r
.6034 .37126 m .60584 .37317 L .60435 .37317 L F
.82 .932 .559 r
.57182 .35505 m .57354 .35095 L .57498 .35241 L F
.57182 .35505 m .57178 .35436 L .57354 .35095 L F
.508 0 0 r
.53487 .42676 m .53162 .42644 L .53421 .42694 L F
.181 0 0 r
.53421 .42694 m .53823 .42668 L .53487 .42676 L F
.575 .881 .591 r
.55991 .34514 m .56106 .34369 L .56214 .34289 L F
.084 .332 .807 r
.55991 .34514 m .56226 .34555 L .56106 .34369 L F
.887 .952 .842 r
.60594 .34491 m .60638 .34775 L .60848 .3482 L F
.622 .852 .986 r
.61324 .34581 m .60852 .3456 L .60848 .3482 L F
.756 .778 .871 r
.61381 .3434 m .60852 .3456 L .61324 .34581 L F
.61 .947 .93 r
.60944 .34466 m .60852 .3456 L .61381 .3434 L F
.498 .75 .985 r
.60848 .3482 m .60852 .3456 L .60944 .34466 L F
.60848 .3482 m .60944 .34466 L .60594 .34491 L F
.875 .537 .033 r
.60107 .34518 m .60272 .34924 L .60158 .3472 L F
.095 0 0 r
.60272 .34924 m .60439 .34701 L .60158 .3472 L F
.60272 .34924 m .60369 .34995 L .60439 .34701 L F
.60272 .34924 m .60222 .35055 L .60369 .34995 L F
.662 .8 .949 r
.40692 .57507 m .40897 .57692 L .40995 .57587 L F
.872 .822 .796 r
.4577 .51454 m .4623 .51239 L .46047 .51108 L F
.4577 .51454 m .45966 .51596 L .4623 .51239 L F
.735 .93 .954 r
.60116 .39596 m .59987 .3983 L .59755 .39352 L F
.60116 .39596 m .60226 .39656 L .59987 .3983 L F
.984 .705 .401 r
.4938 .42406 m .49527 .42383 L .49357 .42291 L F
.267 0 .279 r
.60083 .3423 m .6038 .34113 L .604 .33866 L F
.518 .176 .327 r
.604 .33866 m .60677 .34059 L .6065 .33854 L F
.604 .33866 m .6038 .34113 L .60677 .34059 L F
.475 .204 .423 r
.43776 .468 m .4375 .47044 L .43469 .47099 L F
.512 .203 .38 r
.44338 .46584 m .4409 .46779 L .43776 .468 L F
.41 .151 .407 r
.44013 .4697 m .43776 .468 L .4409 .46779 L F
.44013 .4697 m .4375 .47044 L .43776 .468 L F
.524 .332 .562 r
.51963 .39871 m .52153 .40232 L .52412 .39882 L F
.762 .616 .697 r
.50403 .44703 m .50822 .44815 L .50676 .44408 L F
.764 .592 .664 r
.50413 .45082 m .50822 .44815 L .50403 .44703 L F
.50413 .45082 m .50873 .45157 L .50822 .44815 L F
.493 .857 .988 r
.50822 .44815 m .50977 .44375 L .50676 .44408 L F
.641 .506 .683 r
.50822 .44815 m .50873 .45157 L .51153 .44756 L F
.573 .514 .751 r
.50676 .44408 m .50822 .44815 L .50977 .44375 L F
.907 .969 .806 r
.41767 .55601 m .41432 .55831 L .41544 .55512 L F
.853 .68 .667 r
.40781 .56888 m .40738 .57241 L .41111 .573 L F
.831 .633 .635 r
.40692 .57507 m .41111 .573 L .40738 .57241 L F
.40692 .57507 m .40995 .57587 L .41111 .573 L F
.709 .206 .038 r
.60701 .38078 m .61005 .38369 L .60989 .38111 L F
.447 .461 .78 r
.60989 .38111 m .61251 .38207 L .6117 .37886 L F
.761 .34 .251 r
.61005 .38369 m .61251 .38207 L .60989 .38111 L F
.785 .837 .892 r
.42649 .5409 m .42518 .54475 L .42401 .54418 L F
.42649 .5409 m .42875 .54197 L .42518 .54475 L F
.278 .45 .852 r
.5409 .36859 m .54006 .37075 L .53898 .36908 L F
.5409 .36859 m .54266 .37116 L .54006 .37075 L F
.856 .635 .602 r
.56642 .37796 m .57123 .38311 L .56702 .37929 L F
.744 .561 0 r
.56757 .38579 m .56702 .37929 L .57101 .38327 L F
.56757 .38579 m .56745 .38505 L .56718 .38139 L F
.56716 .38099 m .56718 .38139 L .56702 .37929 L F
.56757 .38579 m .56718 .38139 L .56716 .38099 L F
.288 0 0 r
.56699 .382 m .56257 .38365 L .56296 .38245 L F
.56698 .38206 m .56257 .38365 L .56699 .382 L F
.56697 .38209 m .56648 .38307 L .56257 .38365 L F
.968 .725 .291 r
.56699 .382 m .56716 .38445 L .5666 .38332 L F
.56718 .38139 m .56716 .38445 L .56699 .382 L F
.288 0 0 r
.5672 .38201 m .56697 .38209 L .5672 .38198 L F
.56697 .38209 m .56257 .38365 L .56698 .38206 L F
.56697 .38209 m .56698 .38206 L .5672 .38198 L F
.968 .725 .291 r
.56718 .38139 m .5666 .38332 L .56648 .38307 L F
.288 0 0 r
.56733 .38196 m .56648 .38307 L .56697 .38209 L F
.968 .725 .291 r
.56718 .38167 m .56745 .38505 L .56716 .38445 L F
.56718 .38139 m .5672 .38163 L .56718 .38167 L F
.5672 .38163 m .56745 .38505 L .56718 .38167 L F
.613 .443 .629 r
.56691 .38076 m .56699 .382 L .56296 .38245 L F
.968 .725 .291 r
.56702 .37929 m .56718 .38139 L .56679 .38231 L F
.56702 .37929 m .56679 .38231 L .56648 .38307 L F
.904 .585 .433 r
.56702 .37929 m .56733 .38196 L .56691 .38076 L F
.56702 .37929 m .56691 .38076 L .56608 .37836 L F
.613 .443 .629 r
.56691 .38076 m .56733 .38196 L .56699 .382 L F
.288 0 0 r
.5672 .38198 m .56698 .38206 L .56699 .382 L F
.56733 .38196 m .5672 .38201 L .5672 .38198 L F
.744 .561 0 r
.57101 .38327 m .56702 .37929 L .57123 .38311 L F
0 0 0 r
.5688 .38059 m .56648 .38307 L .56733 .38196 L F
.968 .725 .291 r
.56749 .37964 m .56648 .38307 L .5688 .38059 L F
.56702 .37929 m .56688 .38028 L .56749 .37964 L F
.56688 .38028 m .56648 .38307 L .56749 .37964 L F
.613 .443 .629 r
.56594 .37795 m .56678 .38038 L .56296 .38245 L F
.56678 .38038 m .56691 .38076 L .56608 .38111 L F
.56678 .38038 m .56608 .38111 L .56296 .38245 L F
.904 .585 .433 r
.56702 .37929 m .56608 .37836 L .56594 .37795 L F
0 .052 .575 r
.40407 .55619 m .40529 .55442 L .40241 .55489 L F
.313 0 0 r
.40747 .55626 m .40595 .55711 L .40407 .55619 L F
0 .052 .575 r
.40407 .55619 m .40595 .55711 L .40529 .55442 L F
.895 .61 .498 r
.40616 .54401 m .40932 .54241 L .40924 .54133 L F
.40616 .54401 m .40881 .54541 L .40932 .54241 L F
.236 .402 .825 r
.41231 .54561 m .40932 .54241 L .40881 .54541 L F
.671 .612 .781 r
.28674 .65139 m .28955 .6512 L .28907 .64707 L F
.634 .371 .502 r
.28922 .65482 m .28674 .65139 L .28711 .65426 L F
.28922 .65482 m .28955 .6512 L .28674 .65139 L F
.221 .617 .953 r
.30404 .66581 m .30851 .66775 L .30652 .66538 L F
.239 .524 .916 r
.30652 .66538 m .30851 .66775 L .31106 .66835 L F
.745 .695 .803 r
.3318 .66422 m .33674 .66478 L .33495 .66124 L F
.767 .552 .607 r
.33601 .66758 m .33674 .66478 L .3318 .66422 L F
.828 .617 .617 r
.36757 .48651 m .37113 .48787 L .37113 .48481 L F
0 0 0 r
.37113 .48787 m .3739 .4846 L .37113 .48481 L F
.531 .048 0 r
.30016 .65886 m .30074 .65953 L .29851 .65659 L F
0 .189 .717 r
.30016 .65886 m .30202 .66119 L .30169 .66056 L F
.531 .048 0 r
.30016 .65886 m .30169 .66056 L .30074 .65953 L F
.843 .845 .846 r
.47067 .49712 m .47548 .49496 L .47359 .49349 L F
.824 .805 .833 r
.4577 .51454 m .45848 .5178 L .45966 .51596 L F
.4577 .51454 m .45483 .51786 L .45848 .5178 L F
.835 .774 .794 r
.45483 .51786 m .45707 .51971 L .45848 .5178 L F
0 0 0 r
.46381 .43251 m .46504 .43074 L .46187 .43355 L F
.46035 .43509 m .46381 .43251 L .46187 .43355 L F
.731 .543 0 r
.58902 .39679 m .58893 .39693 L .58928 .39429 L F
.58902 .39679 m .58921 .39902 L .58893 .39693 L F
.866 .837 .816 r
.44962 .52497 m .45409 .52272 L .45226 .52145 L F
.844 .843 .843 r
.45226 .52145 m .45409 .52272 L .45707 .51971 L F
.45226 .52145 m .45707 .51971 L .45483 .51786 L F
.791 .896 .918 r
.51052 .46158 m .51377 .46078 L .51256 .4598 L F
.82 .963 .901 r
.51573 .457 m .51377 .46078 L .5167 .4576 L F
.51573 .457 m .51256 .4598 L .51377 .46078 L F
.585 .278 .415 r
.60073 .38612 m .59924 .38875 L .59905 .38532 L F
.60073 .38612 m .60347 .38841 L .59924 .38875 L F
.833 .971 .887 r
.64792 .37682 m .64572 .3766 L .64377 .37873 L F
.817 .976 .894 r
.64881 .3739 m .64792 .37682 L .64976 .37483 L F
.814 .974 .899 r
.64881 .3739 m .64572 .3766 L .64792 .37682 L F
.53 .754 .978 r
.36015 .58093 m .36085 .57844 L .35858 .57987 L F
.36015 .58093 m .36292 .58031 L .36085 .57844 L F
0 0 0 r
.46608 .43143 m .46504 .43074 L .46381 .43251 L F
.46608 .43143 m .46756 .42975 L .46504 .43074 L F
.799 .773 .83 r
.49482 .43934 m .49138 .44039 L .49424 .43739 L F
.437 0 .057 r
.49482 .43934 m .49422 .44151 L .49138 .44039 L F
.514 .529 .81 r
.497 .43633 m .49482 .43934 L .49424 .43739 L F
.497 .43633 m .49815 .43872 L .49482 .43934 L F
.671 .367 .45 r
.49815 .43872 m .49422 .44151 L .49482 .43934 L F
.838 .906 .885 r
.46554 .50388 m .47018 .50206 L .46835 .5005 L F
.55 .461 .707 r
.55779 .38953 m .56022 .38565 L .55857 .38641 L F
.376 0 .134 r
.53467 .3564 m .53635 .35706 L .53339 .3565 L F
.789 .792 .855 r
.46329 .48527 m .45898 .48504 L .46113 .48335 L F
.385 .83 .71 r
.60365 .40107 m .60445 .40041 L .602 .40144 L F
.60365 .40107 m .60623 .39976 L .60445 .40041 L F
.838 .467 .35 r
.36812 .56979 m .369 .57263 L .36667 .57127 L F
.528 .872 .99 r
.36812 .56979 m .36939 .56807 L .37012 .56873 L F
.36812 .56979 m .36618 .56915 L .36939 .56807 L F
.625 .955 .919 r
.57253 .39469 m .57713 .39341 L .57475 .39398 L F
0 0 0 r
.57875 .39138 m .57713 .39341 L .57965 .38978 L F
.644 .966 .824 r
.57875 .39138 m .57475 .39398 L .57713 .39341 L F
.377 0 .19 r
.40981 .4738 m .41257 .47324 L .41379 .47058 L F
.214 0 0 r
.41257 .47324 m .41658 .47045 L .41379 .47058 L F
.805 .989 .884 r
.50676 .44408 m .50789 .44079 L .50977 .44375 L F
.50676 .44408 m .50534 .44384 L .50789 .44079 L F
.467 .855 .979 r
.50977 .44375 m .50534 .44384 L .50676 .44408 L F
.839 .811 .822 r
.30595 .63262 m .30821 .63454 L .30533 .6375 L F
.567 .761 .969 r
.31055 .63359 m .30821 .63454 L .30595 .63262 L F
.765 .293 .124 r
.56669 .34605 m .56559 .3476 L .56226 .34555 L F
0 0 0 r
.56788 .34615 m .56669 .34605 L .5693 .34495 L F
.56788 .34615 m .56559 .3476 L .56669 .34605 L F
.875 .847 .813 r
.64858 .35451 m .64795 .35792 L .65024 .35606 L F
.905 .864 .788 r
.64858 .35451 m .65024 .35606 L .65221 .35252 L F
.609 .071 0 r
.62795 .335 m .62883 .33569 L .63245 .33584 L F
.62804 .33521 m .62883 .33569 L .62795 .335 L F
.885 .716 .668 r
.62883 .33569 m .62984 .33672 L .63245 .33584 L F
.62984 .33672 m .63153 .33844 L .6318 .33768 L F
.62984 .33672 m .6318 .33768 L .63245 .33584 L F
.531 .67 .926 r
.62933 .3357 m .63153 .33844 L .62984 .33672 L F
.62933 .3357 m .62984 .33672 L .62883 .33569 L F
0 0 .264 r
.6289 .33626 m .62894 .33491 L .62933 .3357 L F
.62894 .33491 m .629 .33288 L .62933 .3357 L F
.448 .343 .643 r
.62758 .33493 m .62773 .33779 L .62883 .33569 L F
.585 .506 .732 r
.62883 .33569 m .62773 .33779 L .62933 .3357 L F
0 0 .264 r
.62773 .33779 m .62821 .33592 L .6289 .33626 L F
.62821 .33592 m .629 .33288 L .6289 .33626 L F
.62826 .33573 m .62899 .3357 L .629 .33288 L F
.62773 .33779 m .62856 .33642 L .62826 .33573 L F
.62856 .33642 m .62899 .3357 L .62826 .33573 L F
.609 .071 0 r
.62758 .33493 m .62804 .33521 L .62795 .335 L F
.572 .478 .71 r
.51556 .38911 m .51776 .3862 L .5154 .38662 L F
0 0 .313 r
.58187 .37481 m .58258 .37874 L .58291 .376 L F
.831 .823 .841 r
.61182 .39004 m .61072 .39216 L .6074 .39195 L F
.841 .807 .818 r
.6074 .39195 m .61072 .39216 L .60907 .39377 L F
.905 .864 .788 r
.64858 .35451 m .65221 .35252 L .64874 .35155 L F
.556 .755 .97 r
.52835 .36525 m .53209 .36606 L .53096 .3642 L F
0 .069 .619 r
.52807 .36519 m .53096 .3642 L .53209 .36606 L F
.556 .755 .97 r
.52807 .36519 m .52835 .36525 L .53096 .3642 L F
0 .069 .619 r
.53071 .36428 m .52994 .36741 L .53096 .3642 L F
.52807 .36519 m .52994 .36741 L .53071 .36428 L F
.52807 .36519 m .52962 .36937 L .52994 .36741 L F
.52962 .36937 m .52986 .37003 L .52994 .36741 L F
.52807 .36519 m .52986 .37003 L .52994 .36741 L F
0 0 0 r
.52994 .36741 m .5294 .36964 L .53011 .36639 L F
.52994 .36741 m .53011 .36639 L .53023 .36587 L F
.904 .871 .435 r
.52986 .37003 m .52885 .37146 L .52994 .36741 L F
0 0 0 r
.52994 .36741 m .52885 .37146 L .52935 .36986 L F
.52994 .36741 m .52935 .36986 L .5294 .36964 L F
.804 .812 .328 r
.53096 .3642 m .52994 .36741 L .53023 .36587 L F
0 0 0 r
.53023 .36587 m .53267 .36351 L .53096 .3642 L F
.53267 .36351 m .53268 .36351 L .53096 .3642 L F
.859 .803 .794 r
.47111 .47469 m .46657 .47669 L .46977 .47362 L F
.47111 .47469 m .46862 .47822 L .46657 .47669 L F
.945 .924 .757 r
.47111 .47469 m .47201 .46977 L .47385 .47132 L F
.47111 .47469 m .46977 .47362 L .47201 .46977 L F
.277 .763 .918 r
.51255 .40159 m .51007 .40116 L .50739 .40145 L F
.581 .907 .979 r
.51309 .40021 m .51255 .40159 L .51421 .39994 L F
.51309 .40021 m .51007 .40116 L .51255 .40159 L F
.345 .326 .695 r
.51255 .40159 m .51445 .4024 L .51421 .39994 L F
0 0 0 r
.53067 .35934 m .52969 .36085 L .53164 .35994 L F
.57904 .35572 m .57856 .35768 L .57675 .35919 L F
0 0 .033 r
.57856 .35768 m .57721 .36127 L .57675 .35919 L F
.825 .732 .205 r
.57814 .35692 m .57819 .3592 L .57856 .35768 L F
0 0 .033 r
.57856 .35768 m .5782 .35984 L .57721 .36127 L F
.825 .732 .205 r
.57819 .3592 m .5782 .35984 L .57856 .35768 L F
0 0 0 r
.57908 .35567 m .57856 .35768 L .57904 .35572 L F
0 .409 .822 r
.36983 .57642 m .37006 .57565 L .3679 .57524 L F
.36983 .57642 m .37202 .57727 L .37006 .57565 L F
.702 .775 .909 r
.37651 .57859 m .3809 .57899 L .37925 .57765 L F
.364 .668 .973 r
.3809 .57899 m .38188 .57732 L .37925 .57765 L F
.3809 .57899 m .38336 .579 L .38188 .57732 L F
.82 .839 .864 r
.43581 .52242 m .43097 .52399 L .43379 .52071 L F
.83 .796 .82 r
.43857 .51883 m .43581 .52242 L .43379 .52071 L F
.759 .894 .938 r
.62861 .35299 m .62501 .35551 L .62364 .35392 L F
.518 .339 .577 r
.62861 .35299 m .62808 .35564 L .62501 .35551 L F
0 .469 .807 r
.62808 .35564 m .62364 .35392 L .62501 .35551 L F
.829 .867 .421 r
.58004 .38725 m .57965 .38978 L .58126 .38528 L F
.809 .831 .359 r
.58004 .38725 m .57875 .39138 L .57965 .38978 L F
.832 .999 .818 r
.41032 .56689 m .40805 .56743 L .40781 .56888 L F
.458 .055 .187 r
.41203 .56514 m .40805 .56743 L .41032 .56689 L F
.343 .102 .397 r
.50973 .42262 m .50713 .42453 L .50852 .42248 L F
.382 .02 .221 r
.50672 .41347 m .50356 .4135 L .50402 .4162 L F
.50672 .41347 m .50356 .4135 L .50402 .4162 L F
.683 .875 .971 r
.46948 .4345 m .47317 .43385 L .47208 .4325 L F
.619 .817 .976 r
.47317 .43385 m .47459 .43191 L .47208 .4325 L F
.47317 .43385 m .47608 .4335 L .47459 .43191 L F
.125 .675 .774 r
.53686 .42666 m .53823 .42668 L .53421 .42694 L F
.534 .924 .855 r
.53975 .42525 m .5403 .42551 L .53823 .42668 L F
.531 .921 .893 r
.53975 .42525 m .53823 .42668 L .53686 .42666 L F
.669 .713 .881 r
.38202 .56844 m .37754 .56673 L .38057 .56595 L F
.492 .324 .581 r
.38511 .56575 m .38202 .56844 L .38057 .56595 L F
.38511 .56575 m .38463 .56885 L .38202 .56844 L F
.075 0 0 r
.45513 .45844 m .4533 .45834 L .45602 .45761 L F
.45513 .45844 m .45248 .45974 L .4533 .45834 L F
.839 .811 .822 r
.30595 .63262 m .30533 .6375 L .30332 .63631 L F
.544 .792 .99 r
.61538 .3594 m .61826 .3587 L .61668 .35702 L F
.61538 .3594 m .61826 .3587 L .61668 .35702 L F
.814 .828 .861 r
.46862 .47822 m .46354 .48008 L .46657 .47669 L F
.195 0 .161 r
.56594 .37795 m .56915 .37553 L .56645 .37747 L F
.782 .995 .784 r
.50718 .44935 m .50702 .45014 L .50504 .45086 L F
.50912 .44798 m .50702 .45014 L .50718 .44935 L F
.463 .781 .998 r
.50702 .45014 m .50873 .45157 L .50679 .45126 L F
.50702 .45014 m .50679 .45126 L .50413 .45082 L F
.822 .905 .897 r
.50993 .44992 m .50873 .45157 L .50702 .45014 L F
.96 .941 .706 r
.48733 .45942 m .4885 .46035 L .48652 .4638 L F
.861 .978 .857 r
.49149 .45702 m .4885 .46035 L .48733 .45942 L F
.859 .875 .849 r
.40485 .56643 m .40201 .56536 L .40399 .56319 L F
.923 .866 .766 r
.40485 .56643 m .40098 .56787 L .40201 .56536 L F
.40485 .56643 m .40276 .5691 L .40098 .56787 L F
.996 .764 .42 r
.55664 .41607 m .55713 .41368 L .55825 .41228 L F
.127 0 .169 r
.39055 .55962 m .38982 .56161 L .39276 .55844 L F
0 0 .366 r
.5208 .37978 m .52177 .37431 L .52083 .37594 L F
.275 .027 .345 r
.52273 .37776 m .52407 .37833 L .52407 .37588 L F
0 0 .366 r
.5208 .37978 m .52287 .3783 L .52271 .37771 L F
.275 .027 .345 r
.5218 .37906 m .52305 .37866 L .52273 .37776 L F
.52305 .37866 m .52407 .37833 L .52273 .37776 L F
0 0 .366 r
.52168 .37481 m .52271 .37771 L .52177 .37431 L F
.5208 .37978 m .52271 .37771 L .52168 .37481 L F
.275 .027 .345 r
.52273 .37776 m .52407 .37588 L .52243 .37665 L F
0 0 .366 r
.52287 .3783 m .52289 .37829 L .52243 .37665 L F
.52287 .3783 m .52243 .37665 L .52177 .37431 L F
.275 .027 .345 r
.5218 .37906 m .52273 .37776 L .52132 .37717 L F
.52273 .37776 m .52243 .37665 L .52132 .37717 L F
.334 .09 .388 r
.52177 .37431 m .52132 .37717 L .52243 .37665 L F
.52177 .37431 m .52243 .37665 L .52407 .37588 L F
0 0 .366 r
.52289 .37829 m .52293 .37826 L .52177 .37431 L F
0 0 .136 r
.51881 .38364 m .51972 .38396 L .52162 .37947 L F
0 0 0 r
.5208 .37978 m .51973 .38105 L .52228 .37882 L F
.52266 .37845 m .52228 .37882 L .52293 .37826 L F
.5208 .37978 m .52228 .37882 L .52266 .37845 L F
.87 .746 .724 r
.5263 .38086 m .52493 .38493 L .52775 .38527 L F
0 0 0 r
.52581 .38301 m .52493 .38493 L .52606 .38159 L F
.52581 .38301 m .52606 .38159 L .5263 .38086 L F
.876 .704 .666 r
.52493 .38493 m .52323 .38715 L .52775 .38527 L F
0 0 .076 r
.52581 .38301 m .52323 .38715 L .52493 .38493 L F
.52581 .38301 m .5253 .38515 L .52323 .38715 L F
.728 .309 .252 r
.52072 .38438 m .52532 .38517 L .52581 .38301 L F
.52532 .38517 m .52543 .38519 L .52548 .38492 L F
.106 0 .212 r
.52794 .38163 m .5253 .38515 L .52581 .38301 L F
.728 .309 .252 r
.52532 .38517 m .52548 .38492 L .52581 .38301 L F
0 0 0 r
.5253 .38515 m .52276 .3904 L .52305 .38842 L F
.5253 .38515 m .52305 .38842 L .52323 .38715 L F
.649 .874 .508 r
.52706 .38259 m .5253 .38515 L .52794 .38163 L F
.464 .258 .514 r
.52561 .38471 m .52558 .38475 L .5253 .38515 L F
0 0 0 r
.5253 .38515 m .52396 .38795 L .52276 .3904 L F
.798 .871 .434 r
.52434 .3867 m .52396 .38795 L .5253 .38515 L F
.464 .258 .514 r
.52558 .38475 m .52434 .3867 L .5253 .38515 L F
.735 .522 .605 r
.52532 .38517 m .52434 .3867 L .52543 .38519 L F
.52072 .38438 m .52434 .3867 L .52532 .38517 L F
.464 .258 .514 r
.52572 .38454 m .52535 .38513 L .52561 .38471 L F
.52706 .38259 m .52532 .38517 L .52572 .38454 L F
.698 .668 .121 r
.52581 .38301 m .52543 .38519 L .52558 .38432 L F
0 .163 .69 r
.52407 .37833 m .52581 .38301 L .52631 .3801 L F
.698 .668 .121 r
.52581 .38301 m .52558 .38432 L .52631 .3801 L F
0 0 .001 r
.52794 .38163 m .52581 .38301 L .5263 .38086 L F
.597 .558 .781 r
.52631 .3801 m .52548 .38494 L .52706 .38259 L F
.52548 .38494 m .52543 .38519 L .52706 .38259 L F
.464 .258 .514 r
.52535 .38513 m .52532 .38517 L .52534 .38514 L F
.52535 .38513 m .52534 .38514 L .52561 .38471 L F
.52706 .38259 m .52477 .38605 L .52532 .38517 L F
.52477 .38605 m .52434 .3867 L .52561 .38471 L F
.723 .53 .629 r
.52192 .37918 m .51972 .38396 L .52581 .38301 L F
0 0 0 r
.51973 .38105 m .51966 .38114 L .52022 .38064 L F
.51973 .38105 m .52022 .38064 L .52293 .37826 L F
.669 .967 .922 r
.52293 .37826 m .51966 .38114 L .5218 .37906 L F
.723 .53 .629 r
.5218 .37906 m .52162 .37947 L .52192 .37918 L F
.52162 .37947 m .51972 .38396 L .52192 .37918 L F
0 0 .136 r
.52142 .37965 m .52162 .37947 L .5218 .37906 L F
.51881 .38364 m .52162 .37947 L .52142 .37965 L F
.949 .596 .281 r
.57213 .34685 m .57416 .34851 L .5735 .34562 L F
.57213 .34685 m .57416 .34851 L .5735 .34562 L F
0 .389 .838 r
.57354 .35095 m .57567 .35268 L .57498 .35241 L F
.398 .851 .895 r
.297 .65639 m .29851 .65659 L .29929 .6556 L F
0 .017 .589 r
.29929 .6556 m .29851 .65659 L .30074 .65953 L F
0 0 0 r
.50739 .40145 m .50292 .40236 L .50447 .40272 L F
.15 .21 .671 r
.28907 .64707 m .28955 .6512 L .29118 .64904 L F
.661 .596 .771 r
.28922 .65482 m .29118 .64904 L .28955 .6512 L F
0 0 .411 r
.60083 .3423 m .60251 .34281 L .6038 .34113 L F
.60083 .3423 m .60107 .34518 L .60251 .34281 L F
.71 .974 .924 r
.48097 .48811 m .48003 .48749 L .47649 .48978 L F
.844 .995 .836 r
.48134 .48552 m .48097 .48811 L .48393 .48486 L F
.841 .994 .844 r
.48134 .48552 m .48003 .48749 L .48097 .48811 L F
.142 0 0 r
.53282 .42669 m .53421 .42694 L .53162 .42644 L F
.834 .862 .866 r
.49751 .47039 m .50113 .4703 L .49939 .46919 L F
.49751 .47039 m .49921 .47192 L .50113 .4703 L F
.846 .864 .856 r
.49939 .46919 m .50113 .4703 L .50379 .46704 L F
.693 .884 .504 r
.51557 .39734 m .51421 .39994 L .51671 .39617 L F
.744 .979 .738 r
.51557 .39734 m .51309 .40021 L .51421 .39994 L F
.152 0 0 r
.51761 .39619 m .51459 .39835 L .51557 .39734 L F
.476 .884 .941 r
.51408 .39871 m .51309 .40021 L .51557 .39734 L F
.152 0 0 r
.51459 .39835 m .51408 .39871 L .51557 .39734 L F
.693 .884 .504 r
.51557 .39734 m .51671 .39617 L .51674 .39613 L F
.259 0 0 r
.54124 .37358 m .54168 .3739 L .53621 .37217 L F
.283 0 0 r
.53959 .37311 m .54168 .3739 L .54124 .37358 L F
.498 .75 .985 r
.55277 .41492 m .55372 .41667 L .55664 .41607 L F
.778 .904 .929 r
.49435 .47331 m .49921 .47192 L .49751 .47039 L F
.434 .274 .563 r
.5501 .37461 m .5503 .37741 L .54792 .37769 L F
.186 0 0 r
.55444 .37622 m .5503 .37741 L .5501 .37461 L F
.852 .81 .808 r
.5478 .37769 m .5503 .37741 L .55048 .37635 L F
.54573 .37873 m .54775 .37814 L .5478 .37769 L F
.739 .705 .169 r
.54763 .37939 m .54735 .38055 L .54711 .38252 L F
.54792 .37769 m .54769 .37886 L .54763 .37939 L F
.54769 .37886 m .54735 .38055 L .54763 .37939 L F
.389 .115 .373 r
.5503 .37741 m .54735 .38055 L .54792 .37769 L F
.852 .81 .808 r
.54775 .37814 m .5503 .37741 L .5478 .37769 L F
.919 .947 .799 r
.54166 .38172 m .54273 .37678 L .5447 .3779 L F
.54166 .38172 m .54029 .38025 L .54273 .37678 L F
.691 .444 .545 r
.54029 .38025 m .5457 .38259 L .54358 .38003 L F
.5457 .38259 m .54594 .3827 L .54574 .38247 L F
.5457 .38259 m .54574 .38247 L .54358 .38003 L F
.54029 .38025 m .54103 .38391 L .54552 .3828 L F
.5457 .38259 m .54552 .3828 L .54594 .3827 L F
.54029 .38025 m .54552 .3828 L .5457 .38259 L F
.382 .787 .983 r
.5455 .3832 m .54711 .38252 L .54734 .38063 L F
.54705 .38097 m .54734 .38063 L .54735 .38055 L F
.5455 .3832 m .54734 .38063 L .54705 .38097 L F
.54475 .38427 m .54528 .38388 L .5455 .3832 L F
.54528 .38388 m .54711 .38252 L .5455 .3832 L F
.54475 .38427 m .54879 .38484 L .54711 .38252 L F
.614 .213 .26 r
.39031 .48318 m .39462 .48118 L .39059 .48177 L F
.39031 .48318 m .39328 .48382 L .39462 .48118 L F
.299 0 .107 r
.39462 .48118 m .39599 .48313 L .39742 .48075 L F
.39462 .48118 m .39328 .48382 L .39599 .48313 L F
.736 .825 .919 r
.47747 .4687 m .47385 .47132 L .47201 .46977 L F
.831 .994 .855 r
.51972 .4544 m .51728 .45512 L .5167 .4576 L F
.84 .997 .831 r
.5167 .4576 m .51728 .45512 L .51573 .457 L F
.396 .066 .285 r
.41931 .46998 m .42259 .46733 L .42009 .46823 L F
.383 .003 .189 r
.41658 .47045 m .41931 .46998 L .42009 .46823 L F
.09 0 0 r
.40982 .48739 m .41233 .48606 L .41272 .48639 L F
.218 0 0 r
.41233 .48606 m .4153 .48631 L .41272 .48639 L F
.859 .814 .804 r
.5549 .40078 m .55983 .4003 L .55504 .40665 L F
0 .291 .77 r
.35622 .56325 m .35789 .56508 L .35459 .5633 L F
.35789 .56508 m .35879 .56607 L .35626 .5644 L F
.35789 .56508 m .35626 .5644 L .35459 .5633 L F
.797 .77 .828 r
.3648 .56448 m .36258 .56716 L .36154 .56544 L F
.974 .762 .555 r
.36154 .56544 m .36048 .56751 L .36258 .56716 L F
.546 .741 .966 r
.35622 .56325 m .36154 .56544 L .35879 .56607 L F
.687 .852 .962 r
.35831 .56602 m .36048 .56751 L .36154 .56544 L F
.184 0 .14 r
.36154 .56544 m .36048 .56751 L .36293 .56616 L F
.36154 .56544 m .36293 .56616 L .3603 .56608 L F
.3596 .56579 m .3603 .56608 L .35831 .56602 L F
.36154 .56544 m .3603 .56608 L .3596 .56579 L F
0 .291 .77 r
.35622 .56325 m .35459 .5633 L .35359 .56364 L F
.829 .867 .421 r
.58004 .38725 m .58126 .38528 L .58125 .38504 L F
.557 .328 .524 r
.4375 .47044 m .43475 .47358 L .43469 .47099 L F
.113 0 0 r
.41498 .54228 m .41582 .54327 L .41586 .54137 L F
.428 .722 .987 r
.47459 .43191 m .47608 .4335 L .47713 .43163 L F
.742 .289 .175 r
.47608 .4335 m .4743 .43512 L .47713 .43163 L F
.609 .33 .469 r
.4777 .43364 m .47812 .43569 L .47608 .4335 L F
.301 .569 .933 r
.57914 .35352 m .57908 .35567 L .57567 .35268 L F
.798 .735 .208 r
.57914 .35352 m .57856 .35768 L .57908 .35567 L F
.245 0 .03 r
.40384 .47665 m .40642 .47607 L .40725 .47456 L F
.386 .014 .204 r
.40642 .47607 m .40981 .4738 L .40725 .47456 L F
.743 .7 .81 r
.45996 .44656 m .457 .44992 L .46111 .44972 L F
.757 .461 .484 r
.45645 .45182 m .46111 .44972 L .457 .44992 L F
.583 .342 .517 r
.46029 .44858 m .45645 .45182 L .457 .44992 L F
.743 .7 .81 r
.46055 .44704 m .46111 .44972 L .46129 .44767 L F
.46042 .44781 m .46111 .44972 L .46055 .44704 L F
.583 .342 .517 r
.46176 .44799 m .46021 .44911 L .46029 .44858 L F
.46021 .44911 m .45645 .45182 L .46029 .44858 L F
.743 .7 .81 r
.45996 .44656 m .46042 .44781 L .46055 .44704 L F
0 0 .191 r
.46129 .44767 m .46178 .44886 L .46386 .44728 L F
.46129 .44767 m .46111 .44972 L .46178 .44886 L F
.529 .537 .808 r
.52807 .36519 m .52969 .36085 L .52725 .36328 L F
.565 .905 .677 r
.62885 .37009 m .62545 .37283 L .6275 .37096 L F
.074 0 0 r
.62376 .37274 m .6275 .37096 L .62545 .37283 L F
.284 0 0 r
.65435 .36194 m .65763 .36268 L .65829 .36224 L F
.898 .93 .83 r
.65776 .36723 m .65899 .36347 L .65734 .36651 L F
.504 .321 .567 r
.65943 .36338 m .65829 .36224 L .65763 .36268 L F
.6606 .36383 m .65982 .3633 L .65943 .36338 L F
.65982 .3633 m .65829 .36224 L .65943 .36338 L F
.6606 .36383 m .65763 .36268 L .65928 .3626 L F
.898 .93 .83 r
.65899 .36347 m .65928 .3626 L .65883 .36351 L F
.65899 .36347 m .65883 .36351 L .65734 .36651 L F
.504 .321 .567 r
.6606 .36383 m .66166 .36184 L .65829 .36224 L F
.873 .835 .805 r
.44138 .50768 m .43815 .5074 L .44061 .5042 L F
.44138 .50768 m .44017 .5089 L .43815 .5074 L F
.801 .822 .867 r
.44469 .50415 m .44138 .50768 L .44061 .5042 L F
.877 .837 .803 r
.43895 .51119 m .43815 .5074 L .44017 .5089 L F
.43895 .51119 m .43558 .51086 L .43815 .5074 L F
.902 .766 .701 r
.43895 .51119 m .43704 .51473 L .43558 .51086 L F
.347 .79 .959 r
.38336 .579 m .38772 .57926 L .38604 .5786 L F
.327 .778 .954 r
.38772 .57926 m .39028 .57891 L .38604 .5786 L F
.38772 .57926 m .39028 .57891 L .38604 .5786 L F
.83 .796 .82 r
.43857 .51883 m .43379 .52071 L .43637 .51741 L F
.206 0 0 r
.31413 .63252 m .31055 .63359 L .31347 .62959 L F
.749 .743 .847 r
.31347 .62959 m .31707 .63075 L .31413 .63252 L F
0 .134 .671 r
.5884 .37036 m .58963 .37186 L .58803 .36749 L F
.198 0 .048 r
.44339 .46685 m .44338 .46584 L .44477 .46407 L F
.44339 .46685 m .4409 .46779 L .44338 .46584 L F
.684 .349 .403 r
.50827 .43608 m .50789 .44079 L .50507 .43644 L F
.469 .169 .374 r
.51067 .43858 m .50827 .43608 L .511 .43481 L F
.51067 .43858 m .50789 .44079 L .50827 .43608 L F
.849 .806 .808 r
.30642 .65003 m .3104 .65034 L .30866 .65182 L F
.219 .37 .802 r
.31156 .62309 m .31329 .62704 L .31124 .62505 L F
.622 .351 .486 r
.31329 .62704 m .30889 .63017 L .30868 .62907 L F
.31329 .62704 m .31347 .62959 L .30889 .63017 L F
.807 .933 .564 r
.55129 .41148 m .55272 .4103 L .55086 .41339 L F
.914 .981 .752 r
.55504 .40665 m .55272 .4103 L .55286 .40751 L F
.913 .918 .529 r
.55286 .40751 m .55272 .4103 L .55129 .41148 L F
.767 .67 .755 r
.40695 .53441 m .40227 .53506 L .40494 .53161 L F
.648 .28 .332 r
.40695 .53441 m .40463 .5388 L .40227 .53506 L F
.318 0 .159 r
.40705 .53777 m .40463 .5388 L .40695 .53441 L F
.031 0 0 r
.62636 .34594 m .62482 .34673 L .62229 .34704 L F
.779 .281 .016 r
.62636 .34594 m .6296 .34905 L .62482 .34673 L F
.954 .745 .584 r
.33944 .65384 m .33774 .64999 L .33565 .65354 L F
.857 .711 .7 r
.33747 .65761 m .33944 .65384 L .33565 .65354 L F
.479 .273 .521 r
.56992 .36094 m .57286 .36164 L .57143 .35972 L F
.59 .674 .898 r
.64871 .33532 m .64569 .33638 L .64541 .33462 L F
.64541 .33462 m .64569 .33638 L .64871 .33532 L F
.833 .883 .878 r
.51371 .44452 m .51153 .44756 L .51079 .44463 L F
.94 .935 .764 r
.51153 .44756 m .51016 .44668 L .51079 .44463 L F
.51153 .44756 m .50993 .44992 L .51016 .44668 L F
.859 .814 .804 r
.5549 .40078 m .55504 .40665 L .55441 .40446 L F
.947 .957 .723 r
.55441 .40446 m .55504 .40665 L .55286 .40751 L F
.497 .088 .194 r
.40982 .48739 m .40834 .49001 L .40565 .49005 L F
.573 .264 .407 r
.41272 .48639 m .40834 .49001 L .40982 .48739 L F
.868 .992 .817 r
.53299 .44228 m .53104 .44631 L .53392 .44307 L F
.53299 .44228 m .53015 .44563 L .53104 .44631 L F
.656 .489 .646 r
.54301 .35224 m .54033 .35563 L .54369 .35492 L F
.54301 .35224 m .54033 .35563 L .54369 .35492 L F
.353 .297 .655 r
.54369 .35492 m .54575 .35412 L .54301 .35224 L F
.54301 .35224 m .54575 .35412 L .54369 .35492 L F
.477 .483 .786 r
.54575 .35412 m .54449 .35903 L .54369 .35492 L F
.54536 .35562 m .54809 .35787 L .54449 .35903 L F
.54698 .35609 m .54809 .35787 L .54536 .35562 L F
.547 .08 .098 r
.54754 .35671 m .54769 .35688 L .5479 .35687 L F
0 0 .56 r
.54575 .35412 m .54762 .35672 L .54698 .35609 L F
.54698 .35609 m .54754 .35671 L .54784 .35735 L F
.54784 .35748 m .54784 .35735 L .54809 .35787 L F
.54698 .35609 m .54784 .35735 L .54784 .35748 L F
.829 .763 .789 r
.54773 .35692 m .54783 .35711 L .5479 .35687 L F
.153 .128 .575 r
.54783 .35711 m .54781 .35672 L .5479 .35687 L F
0 0 .56 r
.54754 .35671 m .54795 .35731 L .54809 .35787 L F
.935 .819 .705 r
.54723 .36091 m .54998 .35948 L .54809 .35787 L F
.677 .782 .929 r
.55142 .36157 m .54876 .36287 L .54723 .36091 L F
.935 .819 .705 r
.54723 .36091 m .55049 .35857 L .55142 .36157 L F
.54723 .36091 m .54809 .35787 L .55049 .35857 L F
.442 .574 .891 r
.55205 .36426 m .54876 .36287 L .55142 .36157 L F
.81 .802 .844 r
.5488 .3605 m .54879 .36051 L .54998 .36278 L F
.153 .128 .575 r
.54625 .36272 m .54882 .36035 L .54873 .35925 L F
.54882 .36035 m .54884 .36034 L .54883 .36029 L F
.54882 .36035 m .54883 .36029 L .54873 .35925 L F
.829 .763 .789 r
.54159 .35876 m .54625 .36272 L .54783 .35711 L F
.153 .128 .575 r
.54625 .36272 m .54756 .35769 L .54783 .35711 L F
.54625 .36272 m .54873 .35925 L .54756 .35769 L F
.663 .143 0 r
.54159 .35876 m .54364 .3611 L .54625 .36272 L F
.785 .736 .807 r
.54364 .3611 m .54905 .36014 L .54625 .36272 L F
.54364 .3611 m .54645 .36235 L .54879 .36051 L F
.54879 .36051 m .54879 .36051 L .5488 .3605 L F
.54364 .3611 m .54879 .36051 L .54879 .36051 L F
.81 .802 .844 r
.54879 .36051 m .54645 .36235 L .54824 .36257 L F
.54879 .36051 m .54824 .36257 L .54998 .36278 L F
.153 .128 .575 r
.54884 .36034 m .54905 .36014 L .54896 .35988 L F
.54884 .36034 m .54896 .35988 L .54873 .35925 L F
0 0 .56 r
.54754 .35671 m .54791 .35711 L .54795 .35731 L F
.153 .128 .575 r
.54756 .35769 m .54781 .35672 L .54783 .35704 L F
.54756 .35769 m .54783 .35704 L .54783 .35711 L F
.54756 .35769 m .54873 .35925 L .54781 .35672 L F
.829 .763 .789 r
.54159 .35876 m .54713 .3571 L .54166 .35697 L F
.54713 .3571 m .5479 .35687 L .54697 .35689 L F
.54713 .3571 m .54697 .35689 L .54166 .35697 L F
0 0 .56 r
.54762 .35672 m .54791 .35711 L .54772 .35691 L F
.54762 .35672 m .54772 .35691 L .54698 .35609 L F
.829 .763 .789 r
.54159 .35876 m .54783 .35711 L .54773 .35692 L F
.477 .483 .786 r
.54575 .35412 m .54698 .35609 L .54536 .35562 L F
.547 .08 .098 r
.54369 .35492 m .54754 .35671 L .54575 .35412 L F
.54754 .35671 m .5479 .35687 L .54575 .35412 L F
0 0 .464 r
.5479 .35687 m .54781 .35672 L .54575 .35412 L F
0 0 .56 r
.54575 .35412 m .54781 .35672 L .54791 .35711 L F
.547 .08 .098 r
.54492 .35549 m .54166 .35697 L .54769 .35688 L F
.54492 .35549 m .54769 .35688 L .54754 .35671 L F
.54369 .35492 m .54352 .35509 L .54492 .35549 L F
.54352 .35509 m .54166 .35697 L .54492 .35549 L F
0 0 .418 r
.59088 .38266 m .5914 .3814 L .59075 .37865 L F
0 0 .122 r
.59088 .38266 m .59122 .38425 L .5914 .3814 L F
.59088 .38266 m .5904 .38665 L .59122 .38425 L F
0 .062 .575 r
.58686 .35815 m .58744 .35329 L .58642 .3556 L F
0 0 0 r
.61689 .34129 m .62071 .33822 L .61782 .33846 L F
.655 .472 .624 r
.51525 .40886 m .51216 .41175 L .51296 .40968 L F
.892 .778 .73 r
.42649 .5409 m .4274 .53817 L .42875 .54197 L F
.361 .039 .277 r
.44647 .46352 m .44339 .46685 L .44477 .46407 L F
.166 .701 .719 r
.51178 .4233 m .51472 .4227 L .51634 .42241 L F
.764 .897 .936 r
.51178 .4233 m .51634 .42241 L .51472 .4227 L F
.808 .761 .809 r
.44786 .49823 m .44377 .49768 L .44653 .49452 L F
.822 .708 .739 r
.44786 .49823 m .44311 .50035 L .44377 .49768 L F
.44786 .49823 m .44547 .50168 L .44311 .50035 L F
.804 .759 .811 r
.45067 .49487 m .44786 .49823 L .44653 .49452 L F
.998 .836 .554 r
.56348 .36929 m .56166 .3681 L .56251 .36484 L F
.684 .284 0 r
.56386 .37194 m .56166 .3681 L .56348 .36929 L F
.846 .794 .8 r
.56704 .36412 m .56348 .36929 L .56251 .36484 L F
.935 .693 .215 r
.58963 .37186 m .59044 .37597 L .58966 .37438 L F
0 0 .441 r
.59075 .37865 m .58966 .37438 L .59044 .37597 L F
.758 .754 .849 r
.37347 .56552 m .37012 .56873 L .3692 .56601 L F
.529 .537 .808 r
.52807 .36519 m .53096 .3642 L .52969 .36085 L F
0 0 .375 r
.61233 .37623 m .61263 .37386 L .61422 .37482 L F
.61263 .37386 m .61268 .3735 L .61314 .3739 L F
.61263 .37386 m .61314 .3739 L .61422 .37482 L F
.61233 .37623 m .61281 .37394 L .61268 .3735 L F
.378 .687 .979 r
.60719 .3738 m .61281 .37394 L .61233 .37623 L F
.60584 .37317 m .61026 .37366 L .60719 .3738 L F
.61026 .37366 m .61281 .37394 L .60719 .3738 L F
.502 0 0 r
.60589 .37332 m .60861 .37383 L .61281 .37394 L F
.163 0 0 r
.60998 .37369 m .61281 .37394 L .61135 .37378 L F
.60998 .37369 m .61135 .37378 L .60584 .37317 L F
.007 0 0 r
.60861 .37383 m .61268 .3735 L .61281 .37394 L F
.60861 .37383 m .61135 .37374 L .61238 .37355 L F
.61151 .3736 m .61238 .37355 L .61268 .3735 L F
.60861 .37383 m .61238 .37355 L .61151 .3736 L F
.163 0 0 r
.60589 .37332 m .60998 .37369 L .60584 .37317 L F
.779 .512 .532 r
.61508 .37872 m .61233 .37623 L .61422 .37482 L F
.392 .09 .329 r
.42259 .46733 m .42523 .46665 L .42599 .46356 L F
.403 .091 .318 r
.42523 .46665 m .42855 .46309 L .42599 .46356 L F
.965 .757 .573 r
.50188 .44882 m .50413 .45082 L .50403 .44703 L F
.977 .806 .604 r
.50278 .44577 m .50188 .44882 L .50403 .44703 L F
.641 .847 .979 r
.65276 .33569 m .64871 .33532 L .65124 .33398 L F
.64871 .33532 m .65276 .33569 L .65124 .33398 L F
0 0 0 r
.46948 .4345 m .47019 .43455 L .46848 .43602 L F
.46948 .4345 m .47208 .4325 L .47019 .43455 L F
0 0 .104 r
.47897 .41917 m .4813 .41811 L .48201 .41595 L F
0 0 .086 r
.47897 .41917 m .47863 .42173 L .4813 .41811 L F
.269 0 .059 r
.49916 .39907 m .50203 .39824 L .50172 .39664 L F
0 0 0 r
.50389 .39506 m .50172 .39664 L .50417 .39498 L F
.132 0 .079 r
.50172 .39664 m .50203 .39824 L .50442 .39695 L F
.652 .969 .881 r
.51837 .39396 m .51674 .39613 L .52053 .39381 L F
0 .564 .781 r
.59441 .35057 m .60009 .35146 L .59577 .35227 L F
.178 0 .194 r
.60009 .35146 m .60222 .35225 L .60222 .35055 L F
0 .322 .739 r
.5984 .34976 m .60222 .35225 L .60009 .35146 L F
.682 .953 .699 r
.56177 .39729 m .55992 .39979 L .56325 .39662 L F
.35 0 0 r
.56589 .39597 m .56177 .39729 L .56325 .39662 L F
.927 .779 .677 r
.33947 .64428 m .33936 .63893 L .33702 .64329 L F
.911 .732 .647 r
.33702 .64329 m .3387 .64714 L .33947 .64428 L F
.519 .785 .993 r
.55138 .35509 m .5537 .35379 L .55426 .35533 L F
.55426 .35533 m .5537 .35379 L .55138 .35509 L F
.535 .77 .984 r
.5558 .35284 m .55426 .35533 L .5537 .35379 L F
.5558 .35284 m .55698 .3546 L .55426 .35533 L F
.662 .139 0 r
.55698 .3546 m .5537 .35379 L .55426 .35533 L F
.519 .785 .993 r
.55138 .35509 m .5537 .35379 L .55426 .35533 L F
.55138 .35509 m .5537 .35379 L .55426 .35533 L F
.861 .978 .857 r
.49149 .45702 m .48733 .45942 L .49051 .45684 L F
.573 .876 .578 r
.49149 .45702 m .49285 .45538 L .49459 .45393 L F
.582 .945 .878 r
.49149 .45702 m .49051 .45684 L .49285 .45538 L F
0 0 .028 r
.4499 .44382 m .44715 .44726 L .44896 .44582 L F
.248 0 .269 r
.44615 .44892 m .44896 .44582 L .44715 .44726 L F
0 .498 .828 r
.36757 .48651 m .37071 .48756 L .37074 .48772 L F
.195 .722 .737 r
.36492 .48868 m .37071 .48756 L .36757 .48651 L F
.261 0 0 r
.36753 .48808 m .37064 .48713 L .37071 .48756 L F
0 0 0 r
.37307 .48557 m .37251 .48655 L .3739 .4846 L F
.37113 .48787 m .37251 .48655 L .37307 .48557 L F
0 .498 .828 r
.37074 .48772 m .37071 .48756 L .37113 .48787 L F
.502 .888 .961 r
.37113 .48787 m .37071 .48756 L .37251 .48655 L F
.238 0 0 r
.37251 .48655 m .37022 .488 L .37189 .48763 L F
.37251 .48655 m .37189 .48763 L .37463 .48702 L F
.261 0 0 r
.37064 .48713 m .37251 .48655 L .37071 .48756 L F
.752 .272 .101 r
.32861 .61828 m .32912 .61594 L .32624 .61649 L F
.32861 .61828 m .33158 .61876 L .32912 .61594 L F
.83 .97 .89 r
.48416 .48223 m .48393 .48486 L .48695 .48204 L F
.874 .989 .822 r
.48416 .48223 m .48134 .48552 L .48393 .48486 L F
.947 .676 .49 r
.3344 .63261 m .3367 .62998 L .33416 .62924 L F
.3344 .63261 m .3374 .63367 L .3367 .62998 L F
0 .007 .554 r
.58749 .36241 m .58848 .35998 L .58686 .35815 L F
0 0 .47 r
.58749 .36241 m .58856 .36272 L .58848 .35998 L F
.58749 .36241 m .58877 .36543 L .58856 .36272 L F
.288 0 0 r
.37251 .48655 m .37655 .48441 L .3739 .4846 L F
.818 .382 0 r
.53158 .38448 m .53082 .38291 L .52898 .38241 L F
.149 0 0 r
.62546 .39327 m .62786 .39353 L .6255 .39483 L F
.52 .792 .995 r
.55011 .35444 m .5537 .35379 L .55138 .35509 L F
.55011 .35444 m .5537 .35379 L .55138 .35509 L F
.765 .816 .893 r
.55441 .37247 m .55059 .37176 L .55353 .37078 L F
.864 .701 .678 r
.55232 .37461 m .55059 .37176 L .55441 .37247 L F
.621 .747 .937 r
.55765 .37164 m .55441 .37247 L .55353 .37078 L F
.619 .571 .778 r
.55865 .37587 m .55441 .37247 L .55765 .37164 L F
.827 .539 .502 r
.6074 .38951 m .60381 .39187 L .60347 .38841 L F
.6074 .38951 m .6074 .39195 L .60381 .39187 L F
.831 .823 .841 r
.61182 .39004 m .6074 .39195 L .6074 .38951 L F
.776 .692 .77 r
.52163 .41931 m .52312 .42338 L .5189 .42277 L F
.286 .741 .956 r
.52312 .42338 m .52177 .42262 L .5189 .42277 L F
.538 .814 .997 r
.52434 .42129 m .52312 .42338 L .52163 .41931 L F
.52434 .42129 m .52584 .42265 L .52312 .42338 L F
0 .234 .627 r
.52432 .42402 m .52312 .42338 L .52584 .42265 L F
.52432 .42402 m .52177 .42262 L .52312 .42338 L F
.077 0 0 r
.52252 .37307 m .52481 .37278 L .52532 .37252 L F
.52252 .37307 m .52177 .37431 L .52481 .37278 L F
.846 .794 .8 r
.56704 .36412 m .56251 .36484 L .56536 .364 L F
.125 .675 .757 r
.56536 .364 m .56915 .36366 L .56704 .36412 L F
.585 .667 .896 r
.30404 .66581 m .30519 .66284 L .3023 .66369 L F
.30404 .66581 m .30652 .66538 L .30519 .66284 L F
.537 .925 .876 r
.54943 .38944 m .55142 .38983 L .54828 .38873 L F
.54943 .38944 m .54739 .39109 L .55142 .38983 L F
.565 .321 .505 r
.54205 .36562 m .54735 .36795 L .54541 .36414 L F
.54205 .36562 m .54188 .3696 L .54735 .36795 L F
.57 .125 .155 r
.53635 .35706 m .53894 .35772 L .54033 .35563 L F
.292 0 .004 r
.54033 .35563 m .54166 .35697 L .54369 .35492 L F
.54033 .35563 m .53894 .35772 L .54166 .35697 L F
.05 0 .149 r
.45259 .44036 m .4499 .44382 L .45179 .44239 L F
.226 0 .278 r
.44896 .44582 m .45179 .44239 L .4499 .44382 L F
.787 .899 .493 r
.5904 .38665 m .58979 .38651 L .59122 .38425 L F
.5904 .38665 m .5891 .38891 L .58979 .38651 L F
.69 .711 .864 r
.541 .38983 m .53655 .38905 L .53899 .38821 L F
.81 .767 .813 r
.54391 .38679 m .541 .38983 L .53899 .38821 L F
.749 .749 .852 r
.62773 .33779 m .63153 .33844 L .62933 .3357 L F
.792 .673 .733 r
.62773 .33779 m .6294 .34162 L .63153 .33844 L F
.179 0 .213 r
.4554 .43717 m .45259 .44036 L .45476 .43914 L F
.188 0 .218 r
.4554 .43717 m .45665 .43745 L .45808 .43643 L F
.4554 .43717 m .45476 .43914 L .45665 .43745 L F
.914 .977 .775 r
.52426 .41298 m .52211 .41413 L .52359 .41213 L F
.595 .631 .857 r
.47206 .44173 m .47107 .44378 L .47317 .44307 L F
.487 .251 .481 r
.47303 .44588 m .47107 .44378 L .47317 .44307 L F
.47303 .44588 m .47078 .44656 L .47107 .44378 L F
.595 .631 .857 r
.47206 .44173 m .47107 .44378 L .47317 .44307 L F
.487 .251 .481 r
.47303 .44588 m .47107 .44378 L .47317 .44307 L F
.47303 .44588 m .47078 .44656 L .47107 .44378 L F
.846 .864 .856 r
.49939 .46919 m .50379 .46704 L .50253 .4658 L F
.829 .938 .899 r
.50253 .4658 m .50379 .46704 L .50712 .46402 L F
.191 .715 .699 r
.46835 .44729 m .46859 .44719 L .47078 .44656 L F
.172 0 .18 r
.47078 .44656 m .46792 .44962 L .46835 .44729 L F
0 0 0 r
.6275 .37096 m .63021 .36808 L .62885 .37009 L F
.689 .382 .451 r
.40967 .55512 m .40595 .55711 L .40747 .55626 L F
.798 .459 .414 r
.31828 .61694 m .31691 .6191 L .31942 .61884 L F
.168 0 0 r
.32322 .61706 m .31828 .61694 L .31942 .61884 L F
.32322 .61706 m .32406 .61699 L .31828 .61694 L F
.923 .558 .313 r
.49138 .44039 m .4899 .44183 L .49001 .44028 L F
.891 .954 .837 r
.49138 .44039 m .49211 .43697 L .49424 .43739 L F
.49138 .44039 m .49001 .44028 L .49211 .43697 L F
.433 0 0 r
.49138 .44039 m .49422 .44151 L .4899 .44183 L F
.712 .469 .557 r
.48281 .43364 m .47812 .43569 L .4777 .43364 L F
.81 .767 .813 r
.54391 .38679 m .53899 .38821 L .54198 .38496 L F
.563 .754 .967 r
.54475 .38427 m .54391 .38679 L .54198 .38496 L F
0 0 0 r
.48206 .41564 m .48414 .41484 L .48552 .41322 L F
.311 .099 .422 r
.4881 .40953 m .48552 .41322 L .48786 .41182 L F
0 0 0 r
.48552 .41322 m .48656 .41374 L .48786 .41182 L F
.48552 .41322 m .48414 .41484 L .48656 .41374 L F
.768 .563 .621 r
.40772 .54794 m .41231 .54561 L .40881 .54541 L F
.40772 .54794 m .41221 .54853 L .41231 .54561 L F
0 .233 .746 r
.55129 .41148 m .55086 .41339 L .55277 .41492 L F
.868 .983 .842 r
.53299 .44228 m .53392 .44307 L .53683 .43989 L F
.272 .34 .75 r
.56243 .40068 m .55992 .39979 L .56177 .39729 L F
.345 .275 .634 r
.56243 .40068 m .56085 .40283 L .55992 .39979 L F
.805 .785 .834 r
.38676 .56507 m .38321 .56459 L .38569 .56334 L F
.38676 .56507 m .38511 .56575 L .38321 .56459 L F
.417 0 0 r
.38569 .56334 m .38982 .56161 L .38676 .56507 L F
.783 .989 .89 r
.64976 .37483 m .65228 .37135 L .64881 .3739 L F
.64976 .37483 m .65307 .37215 L .65228 .37135 L F
.798 .739 .798 r
.45179 .44239 m .45476 .43914 L .45259 .44036 L F
.811 .742 .787 r
.45067 .49487 m .44653 .49452 L .44888 .49096 L F
.785 .732 .803 r
.45352 .49162 m .45067 .49487 L .44888 .49096 L F
.968 .726 .518 r
.36724 .56573 m .36529 .56163 L .3688 .56215 L F
.36724 .56573 m .3648 .56448 L .36529 .56163 L F
.457 .353 .648 r
.3688 .56215 m .3692 .56601 L .36724 .56573 L F
.751 .392 .374 r
.3692 .56601 m .3648 .56448 L .36724 .56573 L F
.826 .664 .681 r
.5659 .34411 m .57039 .34258 L .56509 .34162 L F
.5659 .34411 m .5693 .34495 L .57039 .34258 L F
.818 .744 .782 r
.32946 .66313 m .3318 .66422 L .33042 .66052 L F
.83 .734 .758 r
.32929 .66801 m .3318 .66422 L .32946 .66313 L F
.755 .714 .814 r
.3318 .66422 m .33495 .66124 L .33042 .66052 L F
.774 .311 0 r
.56777 .37326 m .56457 .37479 L .56386 .37194 L F
.56777 .37326 m .56687 .37308 L .56457 .37479 L F
.56777 .37326 m .56915 .37553 L .56687 .37308 L F
.863 .984 .702 r
.39539 .57714 m .39732 .57598 L .39788 .57343 L F
.413 0 0 r
.55865 .37587 m .55718 .37701 L .55444 .37622 L F
.325 .371 .756 r
.56039 .37321 m .55865 .37587 L .55765 .37164 L F
.803 .334 .112 r
.56233 .37884 m .55865 .37587 L .56039 .37321 L F
.56233 .37884 m .55718 .37701 L .55865 .37587 L F
.403 .465 .81 r
.28711 .65426 m .29034 .65595 L .28922 .65482 L F
.868 .983 .842 r
.53299 .44228 m .53683 .43989 L .53629 .43943 L F
.845 .984 .702 r
.539 .4356 m .53683 .43989 L .53934 .43641 L F
.539 .4356 m .53629 .43943 L .53683 .43989 L F
.749 .559 .639 r
.63142 .35363 m .62861 .35299 L .63154 .35069 L F
.63142 .35363 m .62808 .35564 L .62861 .35299 L F
.292 0 .052 r
.63142 .35363 m .63088 .355 L .62808 .35564 L F
.348 0 .142 r
.63435 .3523 m .63088 .355 L .63142 .35363 L F
.867 .935 .865 r
.60476 .39316 m .60226 .39656 L .60116 .39596 L F
.493 .835 .554 r
.3001 .63942 m .29862 .64075 L .29651 .64258 L F
.771 .96 .65 r
.53934 .43641 m .5419 .4323 L .539 .4356 L F
.53934 .43641 m .54225 .43261 L .5419 .4323 L F
.887 .952 .842 r
.60594 .34491 m .60439 .34701 L .60638 .34775 L F
.621 .243 .305 r
.60369 .34995 m .60638 .34775 L .60439 .34701 L F
.284 .176 .551 r
.60638 .34775 m .60833 .35032 L .60645 .35111 L F
.621 .243 .305 r
.60369 .34995 m .60833 .35032 L .60638 .34775 L F
0 0 0 r
.49666 .44947 m .49459 .45393 L .49559 .45195 L F
.715 .932 .607 r
.49459 .45393 m .49285 .45538 L .49559 .45195 L F
.498 0 0 r
.56214 .34289 m .5659 .34411 L .56509 .34162 L F
.56214 .34289 m .56106 .34369 L .5659 .34411 L F
.572 .478 .71 r
.51556 .38911 m .51843 .3887 L .51776 .3862 L F
.48 .89 .772 r
.51556 .38911 m .51728 .38773 L .51843 .3887 L F
.51556 .38911 m .51419 .38948 L .51728 .38773 L F
.398 .853 .882 r
.60623 .39976 m .60788 .39869 L .60445 .40041 L F
.60623 .39976 m .609 .39884 L .60788 .39869 L F
.759 .992 .794 r
.63123 .39091 m .63304 .39037 L .63498 .38842 L F
.872 .516 .371 r
.48655 .43051 m .48969 .43329 L .48594 .4325 L F
.757 .674 .77 r
.48818 .43311 m .49001 .44028 L .48545 .43875 L F
.7 .64 .785 r
.49211 .43697 m .49001 .44028 L .48818 .43311 L F
.757 .674 .77 r
.48818 .43311 m .48545 .43875 L .48642 .4357 L F
.7 .64 .785 r
.49211 .43697 m .49079 .43567 L .49035 .43507 L F
.49079 .43567 m .48818 .43311 L .49035 .43507 L F
.206 0 0 r
.48791 .43292 m .48969 .43329 L .48818 .43311 L F
.745 .993 .855 r
.48818 .43311 m .48969 .43329 L .48955 .4324 L F
.01 .267 .769 r
.48953 .43252 m .49035 .43507 L .48818 .43311 L F
.488 0 0 r
.48967 .43416 m .49035 .43507 L .48953 .43252 L F
.48979 .43549 m .49035 .43507 L .48967 .43416 L F
.01 .267 .769 r
.48845 .43331 m .48818 .43311 L .48713 .43428 L F
.48953 .43252 m .48818 .43311 L .48845 .43331 L F
.206 0 0 r
.48594 .4325 m .48791 .43292 L .48818 .43311 L F
.704 .763 .898 r
.48969 .43329 m .49195 .43222 L .49146 .42889 L F
.097 0 0 r
.47019 .43455 m .47208 .4325 L .47459 .43191 L F
.771 .391 .336 r
.6065 .33854 m .60677 .34059 L .61088 .34062 L F
.237 0 0 r
.60866 .3406 m .6098 .34094 L .61088 .34062 L F
.153 .523 .918 r
.60838 .33981 m .61123 .34136 L .6098 .34094 L F
.963 .786 .615 r
.61179 .34165 m .61088 .34062 L .6098 .34094 L F
.153 .523 .918 r
.61123 .34136 m .61179 .34165 L .6098 .34094 L F
.237 0 0 r
.60677 .34059 m .6098 .34094 L .60866 .3406 L F
.963 .786 .615 r
.61179 .34165 m .61441 .34067 L .61088 .34062 L F
.495 .199 .392 r
.42519 .48052 m .42223 .48362 L .42245 .48096 L F
.421 .132 .366 r
.42245 .48096 m .42223 .48362 L .41936 .48369 L F
.685 .888 .972 r
.48632 .46713 m .48363 .46855 L .48174 .46747 L F
.749 .71 .815 r
.61852 .37576 m .61508 .37872 L .61422 .37482 L F
.717 .534 .641 r
.51029 .40998 m .51234 .41039 L .51281 .40645 L F
.382 .237 .557 r
.51281 .40645 m .51525 .40886 L .51443 .4051 L F
.195 .719 .857 r
.53686 .42666 m .53421 .42694 L .53282 .42669 L F
.159 0 .115 r
.49133 .40659 m .4881 .40953 L .4909 .40896 L F
0 0 .069 r
.49391 .40294 m .49133 .40659 L .49311 .40491 L F
.345 .11 .407 r
.49133 .40659 m .49335 .40766 L .49311 .40491 L F
.49133 .40659 m .4909 .40896 L .49335 .40766 L F
.956 .614 .304 r
.50265 .45214 m .50413 .45082 L .50188 .44882 L F
0 0 0 r
.50504 .45086 m .50413 .45082 L .50265 .45214 L F
.798 .52 .518 r
.49819 .45109 m .50265 .45214 L .50188 .44882 L F
.616 .074 0 r
.49819 .45109 m .50082 .453 L .50265 .45214 L F
0 0 0 r
.50082 .453 m .50504 .45086 L .50265 .45214 L F
.50082 .453 m .50318 .45204 L .50504 .45086 L F
.552 .892 .65 r
.50504 .45086 m .50318 .45204 L .50404 .45133 L F
0 0 0 r
.50504 .45086 m .50612 .45035 L .50413 .45082 L F
.782 .995 .784 r
.50912 .44798 m .50504 .45086 L .50754 .44672 L F
0 0 0 r
.50754 .44672 m .50504 .45086 L .50658 .44923 L F
.552 .892 .65 r
.50504 .45086 m .50404 .45133 L .50658 .44923 L F
0 0 0 r
.50504 .45086 m .50702 .45014 L .50612 .45035 L F
.824 .987 .876 r
.52042 .45191 m .51972 .4544 L .52135 .45295 L F
.835 .993 .853 r
.52042 .45191 m .51728 .45512 L .51972 .4544 L F
.391 0 .142 r
.39965 .4796 m .40256 .4792 L .40384 .47665 L F
.52 .181 .334 r
.40256 .4792 m .40642 .47607 L .40384 .47665 L F
.87 .887 .845 r
.51016 .44668 m .50993 .44992 L .50912 .44798 L F
.822 .905 .897 r
.50993 .44992 m .50702 .45014 L .50912 .44798 L F
.492 .236 .454 r
.43206 .47417 m .43211 .47708 L .42854 .47764 L F
.51 .25 .456 r
.43457 .47584 m .43206 .47417 L .43475 .47358 L F
.43457 .47584 m .43211 .47708 L .43206 .47417 L F
.692 .461 .568 r
.46792 .44962 m .46484 .45239 L .46529 .45047 L F
0 0 .334 r
.50482 .43555 m .50507 .43644 L .50388 .4333 L F
.827 .694 .156 r
.50507 .43644 m .50479 .43829 L .50482 .43555 L F
.778 .601 .66 r
.50483 .4403 m .50091 .44232 L .50096 .43927 L F
.68 .713 .874 r
.50479 .43829 m .50483 .4403 L .50096 .43927 L F
.732 .277 .169 r
.50479 .43829 m .50226 .44014 L .50446 .44015 L F
.827 .694 .156 r
.50505 .43684 m .50483 .4403 L .50479 .43829 L F
.453 .371 .674 r
.50789 .44079 m .50483 .4403 L .50479 .43829 L F
.732 .277 .169 r
.50479 .43829 m .50446 .44015 L .50605 .44017 L F
.827 .694 .156 r
.50507 .43644 m .50505 .43684 L .50479 .43829 L F
.875 .847 .813 r
.64858 .35451 m .64604 .35789 L .64795 .35792 L F
.806 .437 .358 r
.64641 .36008 m .64795 .35792 L .64604 .35789 L F
.64641 .36008 m .65023 .36109 L .64795 .35792 L F
.559 .039 0 r
.3822 .49044 m .38064 .49211 L .37796 .49032 L F
.647 .232 .241 r
.38485 .49026 m .38064 .49211 L .3822 .49044 L F
0 0 0 r
.39813 .5654 m .39747 .56802 L .3972 .56825 L F
0 0 .343 r
.39747 .56802 m .39846 .5723 L .3972 .56825 L F
.645 .87 .503 r
.54225 .43261 m .5446 .42921 L .5419 .4323 L F
.54225 .43261 m .54467 .42933 L .5446 .42921 L F
.936 .712 .574 r
.62773 .33779 m .62724 .34067 L .6294 .34162 L F
.933 .636 .453 r
.62724 .34067 m .62759 .3436 L .6294 .34162 L F
.751 .346 .285 r
.62759 .3436 m .63144 .34454 L .6294 .34162 L F
.588 .67 .896 r
.37458 .57529 m .37651 .57859 L .37925 .57765 L F
.836 .695 .707 r
.40546 .55139 m .41024 .55223 L .40772 .54794 L F
.736 .27 .143 r
.40546 .55139 m .40767 .55363 L .41024 .55223 L F
0 .105 .659 r
.40772 .54794 m .41024 .55223 L .41154 .55268 L F
0 0 0 r
.41024 .55223 m .41203 .55434 L .41154 .55268 L F
.438 .22 .483 r
.41203 .55434 m .40967 .55512 L .41024 .55223 L F
0 0 0 r
.41024 .55223 m .41029 .5524 L .41203 .55434 L F
.41024 .55223 m .40767 .55363 L .41029 .5524 L F
.438 .22 .483 r
.41203 .55434 m .41024 .55223 L .41154 .55268 L F
.344 .774 .971 r
.42474 .5347 m .42761 .53518 L .42306 .53475 L F
.641 .167 .113 r
.42306 .53475 m .42761 .53518 L .42522 .53621 L F
.921 .667 .536 r
.42522 .53621 m .42761 .53518 L .4274 .53817 L F
.406 .141 .396 r
.44985 .4601 m .45011 .46303 L .44647 .46352 L F
.463 .181 .399 r
.45201 .46201 m .44985 .4601 L .45248 .45974 L F
.45201 .46201 m .45011 .46303 L .44985 .4601 L F
.836 .696 .708 r
.44547 .50168 m .44469 .50415 L .44311 .50035 L F
0 .176 .697 r
.58082 .36509 m .58325 .36701 L .58358 .36809 L F
.852 .765 .257 r
.5829 .36968 m .58358 .36809 L .58325 .36701 L F
.5829 .36968 m .58292 .37317 L .58358 .36809 L F
0 0 .269 r
.30202 .66119 m .3023 .66369 L .30169 .66056 L F
.918 .817 .731 r
.50402 .4162 m .50681 .41631 L .50672 .41347 L F
.485 .478 .775 r
.50672 .41347 m .50681 .41631 L .50725 .41608 L F
.50672 .41347 m .50725 .41608 L .50737 .41576 L F
.402 .036 .224 r
.50662 .41642 m .50381 .41892 L .50398 .41678 L F
.50592 .41636 m .50398 .41678 L .50402 .4162 L F
.50662 .41642 m .50398 .41678 L .50592 .41636 L F
.634 .092 0 r
.50411 .41648 m .50592 .41636 L .50402 .4162 L F
.50592 .41636 m .50681 .41631 L .50402 .4162 L F
.519 .914 .912 r
.50725 .41608 m .50681 .41631 L .50592 .41636 L F
.402 .036 .224 r
.50737 .41576 m .50662 .41642 L .50402 .4162 L F
.50692 .41693 m .50381 .41892 L .50737 .41576 L F
.50911 .41553 m .50692 .41693 L .50737 .41576 L F
.485 .478 .775 r
.50737 .41576 m .50725 .41608 L .50743 .41598 L F
.871 .707 .676 r
.50672 .41347 m .50911 .41553 L .50737 .41576 L F
.522 .504 .777 r
.50933 .41204 m .50911 .41553 L .50672 .41347 L F
.50933 .41204 m .51077 .41717 L .50911 .41553 L F
.581 .542 .776 r
.51253 .41373 m .51149 .41576 L .50933 .41204 L F
.51149 .41576 m .51077 .41717 L .51036 .41572 L F
.51149 .41576 m .51036 .41572 L .50933 .41204 L F
.544 .197 .33 r
.51153 .41781 m .50636 .41894 L .50899 .41567 L F
.50927 .41568 m .50899 .41567 L .50911 .41553 L F
.44 .866 .935 r
.5136 .41642 m .51077 .41717 L .51149 .41576 L F
.51327 .41559 m .51149 .41576 L .51253 .41373 L F
.5136 .41642 m .51149 .41576 L .51327 .41559 L F
.544 .197 .33 r
.50954 .41594 m .50899 .41567 L .50927 .41568 L F
.50954 .41594 m .50911 .41553 L .50952 .41594 L F
.34 0 0 r
.51077 .41717 m .51313 .41796 L .51153 .41781 L F
.544 .197 .33 r
.51153 .41781 m .5107 .41711 L .51077 .41717 L F
.51153 .41781 m .50933 .41596 L .50954 .41594 L F
.50933 .41596 m .50899 .41567 L .50954 .41594 L F
.485 .478 .775 r
.50672 .41347 m .50743 .41598 L .51093 .41411 L F
.871 .707 .676 r
.50672 .41347 m .50737 .41576 L .50402 .4162 L F
.519 .914 .912 r
.51093 .41411 m .50725 .41608 L .50411 .41648 L F
.50725 .41608 m .50592 .41636 L .50411 .41648 L F
.402 .036 .224 r
.50911 .41553 m .50636 .41894 L .50381 .41892 L F
.309 .002 .272 r
.44318 .45257 m .44615 .44892 L .44374 .44989 L F
.822 .98 .887 r
.52474 .4498 m .52042 .45191 L .52135 .45295 L F
.035 0 .017 r
.47103 .42708 m .47007 .42883 L .47317 .42585 L F
.59 .21 .29 r
.36231 .56239 m .36154 .56544 L .3648 .56448 L F
0 0 0 r
.36231 .56239 m .3648 .56448 L .36529 .56163 L F
.485 .244 .474 r
.36529 .56163 m .3648 .56448 L .36231 .56239 L F
0 0 0 r
.36231 .56239 m .36318 .56067 L .3648 .56448 L F
.36231 .56239 m .36154 .56544 L .36318 .56067 L F
.454 .157 .37 r
.44339 .46685 m .44013 .4697 L .4409 .46779 L F
.377 0 0 r
.37655 .48441 m .37888 .48531 L .3808 .48388 L F
.369 0 0 r
.37888 .48531 m .3835 .48427 L .3808 .48388 L F
.717 .636 .765 r
.40128 .56231 m .39651 .55959 L .39965 .55946 L F
.40128 .56231 m .39857 .56266 L .39651 .55959 L F
.128 0 .102 r
.40128 .56231 m .39813 .5654 L .39857 .56266 L F
.40128 .56231 m .39882 .56514 L .39813 .5654 L F
.664 .39 .495 r
.40276 .5691 m .40276 .57225 L .39846 .5723 L F
0 .304 .798 r
.39965 .55946 m .40191 .56095 L .40128 .56231 L F
.586 .406 .604 r
.40399 .56319 m .40128 .56231 L .40191 .56095 L F
.40399 .56319 m .39882 .56514 L .40128 .56231 L F
.214 0 0 r
.41257 .47324 m .41522 .47255 L .41658 .47045 L F
.016 0 0 r
.41522 .47255 m .41931 .46998 L .41658 .47045 L F
.921 .715 .607 r
.42154 .56247 m .42536 .56198 L .42377 .56363 L F
.654 .865 .486 r
.42788 .55823 m .42637 .56026 L .42536 .56198 L F
.67 .895 .545 r
.42637 .56026 m .42377 .56363 L .42536 .56198 L F
.983 .725 .457 r
.51824 .41323 m .51869 .41385 L .51863 .41115 L F
.51824 .41323 m .51835 .41467 L .51671 .41327 L F
.51824 .41323 m .51671 .41327 L .51869 .41385 L F
.891 .708 .648 r
.49146 .42889 m .49535 .42657 L .4938 .42406 L F
.49146 .42889 m .4948 .42909 L .49535 .42657 L F
.67 .789 .938 r
.31788 .66776 m .32234 .66851 L .32043 .6666 L F
.709 .744 .88 r
.32234 .66851 m .32474 .66717 L .32043 .6666 L F
.45 .15 .364 r
.49009 .41012 m .4881 .40953 L .48786 .41182 L F
.49009 .41012 m .4909 .40896 L .4881 .40953 L F
.037 0 0 r
.5698 .39551 m .56878 .39577 L .56589 .39597 L F
0 0 0 r
.57087 .39549 m .5698 .39551 L .57253 .39469 L F
.57087 .39549 m .56878 .39577 L .5698 .39551 L F
.817 .973 .897 r
.48416 .48223 m .48695 .48204 L .48887 .4802 L F
0 .429 .705 r
.33598 .62279 m .33344 .62208 L .33496 .62227 L F
.951 .798 .657 r
.33303 .62552 m .33598 .62279 L .33496 .62227 L F
.33303 .62552 m .33535 .62618 L .33598 .62279 L F
.221 0 .118 r
.43501 .45742 m .4342 .45921 L .43744 .45651 L F
.712 .469 .557 r
.48281 .43364 m .48279 .43617 L .47812 .43569 L F
.726 .644 .767 r
.48655 .43051 m .48594 .4325 L .48281 .43364 L F
.595 .349 .515 r
.48594 .4325 m .48279 .43617 L .48281 .43364 L F
.45 .5 .819 r
.60158 .3472 m .60251 .34281 L .60107 .34518 L F
.95 .949 .73 r
.43958 .53368 m .43848 .53854 L .44149 .5353 L F
.43958 .53368 m .43741 .53758 L .43848 .53854 L F
.981 .735 .331 r
.43741 .53758 m .43845 .54137 L .43848 .53854 L F
.018 0 0 r
.58863 .35132 m .59008 .35188 L .59158 .35104 L F
.58863 .35132 m .58814 .35213 L .59008 .35188 L F
.58814 .35213 m .5884 .35277 L .59008 .35188 L F
.58814 .35213 m .58744 .35329 L .5884 .35277 L F
.644 .922 .976 r
.59008 .35188 m .58744 .35329 L .58888 .35104 L F
0 0 .148 r
.58863 .35332 m .58905 .35373 L .58888 .35104 L F
.58834 .35601 m .58894 .35408 L .58863 .35332 L F
.58894 .35408 m .58905 .35373 L .58863 .35332 L F
.595 .349 .515 r
.48594 .4325 m .48642 .4357 L .48279 .43617 L F
.206 0 0 r
.48594 .4325 m .48818 .43311 L .48642 .4357 L F
.55 .461 .707 r
.55779 .38953 m .56075 .38889 L .56022 .38565 L F
.368 .052 .292 r
.55757 .39168 m .56075 .38889 L .55779 .38953 L F
.689 .561 .705 r
.53078 .37914 m .53082 .38291 L .53524 .38246 L F
.96 .941 .706 r
.48733 .45942 m .48652 .4638 L .48621 .46118 L F
.993 .877 .596 r
.48632 .46713 m .48621 .46118 L .48652 .4638 L F
.785 .732 .803 r
.45352 .49162 m .44888 .49096 L .45157 .48994 L F
.834 .771 .792 r
.45607 .48796 m .45352 .49162 L .45157 .48994 L F
0 0 0 r
.49666 .44947 m .49559 .45195 L .49649 .4497 L F
.49666 .44947 m .49649 .4497 L .49819 .4482 L F
.716 .68 .814 r
.32474 .66717 m .32929 .66801 L .32786 .66443 L F
.83 .734 .758 r
.32929 .66801 m .32946 .66313 L .32786 .66443 L F
.346 0 0 r
.52264 .39203 m .51837 .39396 L .52053 .39381 L F
0 0 0 r
.48206 .41564 m .48201 .41595 L .48414 .41484 L F
.586 .146 .172 r
.49211 .43697 m .497 .43633 L .49424 .43739 L F
.818 .382 0 r
.53158 .38448 m .53249 .38562 L .53082 .38291 L F
.688 .552 .695 r
.53082 .38291 m .53249 .38562 L .53524 .38246 L F
.355 .828 .877 r
.61611 .39686 m .61701 .39584 L .61436 .39686 L F
.61611 .39686 m .6189 .39608 L .61701 .39584 L F
.759 .894 .938 r
.62861 .35299 m .62364 .35392 L .62653 .35247 L F
.833 .954 .894 r
.62861 .35299 m .62923 .34994 L .63154 .35069 L F
.62861 .35299 m .62653 .35247 L .62923 .34994 L F
.171 0 .169 r
.49311 .40491 m .49835 .39988 L .49391 .40294 L F
.614 .803 .972 r
.38057 .56595 m .37754 .56673 L .37614 .56533 L F
.921 .595 .129 r
.30169 .66056 m .3023 .66369 L .30074 .65953 L F
.492 .324 .581 r
.38511 .56575 m .38057 .56595 L .38321 .56459 L F
.738 .335 .288 r
.38923 .49091 m .38728 .49291 L .38485 .49026 L F
.761 .368 .308 r
.38923 .49091 m .39176 .49391 L .38728 .49291 L F
.791 .341 .175 r
.39263 .49323 m .39176 .49391 L .38923 .49091 L F
.775 .272 0 r
.63154 .35069 m .6296 .34905 L .63091 .3488 L F
.054 .292 .781 r
.5782 .35984 m .57987 .36309 L .57721 .36127 L F
0 0 .313 r
.58187 .37481 m .58257 .37731 L .58258 .37874 L F
.728 .69 .149 r
.58228 .38004 m .58258 .37874 L .58257 .37731 L F
.58228 .38004 m .58195 .38247 L .58258 .37874 L F
.834 .771 .792 r
.45607 .48796 m .45157 .48994 L .45434 .48675 L F
.827 .883 .884 r
.45898 .48504 m .45607 .48796 L .45434 .48675 L F
.361 .039 .277 r
.44647 .46352 m .44587 .4662 L .44339 .46685 L F
.495 .22 .426 r
.45011 .46303 m .44587 .4662 L .44647 .46352 L F
.803 .972 .906 r
.50778 .46137 m .50712 .46402 L .51052 .46158 L F
.758 .972 .925 r
.51147 .45875 m .51052 .46158 L .51256 .4598 L F
.51147 .45875 m .50778 .46137 L .51052 .46158 L F
.349 .131 .435 r
.28907 .64707 m .29129 .6464 L .29156 .64371 L F
.15 .21 .671 r
.28907 .64707 m .29118 .64904 L .29129 .6464 L F
.872 .748 .723 r
.33523 .63931 m .33936 .63893 L .33976 .63693 L F
.872 .714 .684 r
.33702 .64329 m .33936 .63893 L .33523 .63931 L F
.693 .972 .923 r
.50494 .43117 m .50388 .4333 L .50554 .43201 L F
.84 .476 .363 r
.5017 .43441 m .50482 .43555 L .50388 .4333 L F
.453 .292 .572 r
.41936 .48369 m .42222 .48638 L .41793 .48652 L F
.41936 .48369 m .42223 .48362 L .42222 .48638 L F
.02 0 0 r
.56138 .37975 m .56413 .37918 L .56594 .37795 L F
.74 .92 .952 r
.56237 .37955 m .5634 .37699 L .56413 .37918 L F
.56138 .37975 m .56175 .37924 L .56237 .37955 L F
.517 0 0 r
.56233 .37884 m .5608 .37877 L .55747 .37711 L F
.949 .596 .226 r
.56138 .37975 m .55992 .37872 L .56233 .37884 L F
.175 .345 .796 r
.56379 .37549 m .56233 .37884 L .56039 .37321 L F
.517 0 0 r
.5608 .37877 m .55992 .37872 L .55747 .37711 L F
.562 .936 .865 r
.5634 .37699 m .56233 .37884 L .56379 .37549 L F
.5634 .37699 m .55992 .37872 L .56233 .37884 L F
.74 .92 .952 r
.56175 .37924 m .5634 .37699 L .56237 .37955 L F
.517 0 0 r
.55747 .37711 m .55992 .37872 L .55718 .37701 L F
.364 .821 .717 r
.54245 .42433 m .5403 .42551 L .53975 .42525 L F
.836 .908 .886 r
.29665 .65343 m .29489 .65599 L .29498 .65535 L F
.661 .217 .187 r
.42935 .48079 m .42787 .48266 L .42519 .48052 L F
0 0 .067 r
.43211 .47708 m .42935 .48079 L .42854 .47764 L F
.43211 .47708 m .43093 .47965 L .42935 .48079 L F
.483 .217 .435 r
.43093 .47965 m .42787 .48266 L .42935 .48079 L F
.496 .477 .766 r
.59993 .39102 m .60116 .39596 L .59755 .39352 L F
.965 .922 .586 r
.58163 .37271 m .58292 .37317 L .5829 .36968 L F
.58163 .37271 m .58187 .37481 L .58292 .37317 L F
.965 .898 .527 r
.31156 .62309 m .31124 .62505 L .3099 .6255 L F
.873 .989 .822 r
.30868 .62907 m .3099 .6255 L .31124 .62505 L F
.794 .992 .88 r
.43363 .55133 m .43277 .55094 L .4285 .55436 L F
.802 .982 .896 r
.65307 .37215 m .65643 .36929 L .65396 .36941 L F
.82 .994 .861 r
.65228 .37135 m .65307 .37215 L .65396 .36941 L F
.909 .568 .385 r
.33976 .63693 m .3374 .63367 L .33794 .63595 L F
.872 .748 .723 r
.33523 .63931 m .33976 .63693 L .33794 .63595 L F
.467 .855 .979 r
.50977 .44375 m .50865 .44287 L .50534 .44384 L F
.247 .58 .944 r
.50954 .4421 m .50977 .44375 L .50789 .44079 L F
.50954 .4421 m .51122 .44328 L .50977 .44375 L F
.50954 .4421 m .50977 .44375 L .50865 .44287 L F
.50954 .4421 m .51122 .44328 L .50977 .44375 L F
.589 .649 .877 r
.54598 .37385 m .5447 .3779 L .54273 .37678 L F
.54598 .37385 m .54792 .37769 L .5447 .3779 L F
.648 .656 .844 r
.40276 .57225 m .40424 .57608 L .40692 .57507 L F
.835 .695 .709 r
.44469 .50415 m .44061 .5042 L .44311 .50035 L F
.815 .34 .076 r
.53249 .38562 m .53442 .38844 L .53655 .38905 L F
.575 .247 .376 r
.53442 .38844 m .53899 .38821 L .53655 .38905 L F
.829 .938 .899 r
.50253 .4658 m .50712 .46402 L .50607 .46327 L F
.825 .986 .876 r
.50778 .46137 m .50607 .46327 L .50712 .46402 L F
.649 .201 .174 r
.6402 .34813 m .64294 .35031 L .6445 .34837 L F
.836 .445 .31 r
.6445 .34837 m .64294 .35031 L .64507 .35051 L F
.695 .913 .572 r
.40227 .53506 m .40321 .53322 L .40494 .53161 L F
0 .022 .571 r
.40227 .53506 m .40463 .5388 L .40321 .53322 L F
.537 .05 .047 r
.40329 .48955 m .40109 .49177 L .39872 .49017 L F
.482 .001 .036 r
.40565 .49005 m .40109 .49177 L .40329 .48955 L F
.909 .887 .798 r
.42132 .54874 m .41973 .5492 L .42128 .54709 L F
.026 .019 .51 r
.56702 .37929 m .5688 .38059 L .5682 .37738 L F
.563 .838 .492 r
.4078 .5283 m .40494 .53161 L .4063 .52995 L F
.751 .581 .665 r
.40321 .53322 m .4063 .52995 L .40494 .53161 L F
.599 .935 .741 r
.54467 .42933 m .54652 .42729 L .5446 .42921 L F
.54467 .42933 m .54832 .4266 L .54652 .42729 L F
.33 .008 .259 r
.39872 .49017 m .39836 .49186 L .3956 .49244 L F
.39836 .49186 m .39831 .49211 L .3956 .49244 L F
.05 0 0 r
.3956 .49244 m .39263 .49323 L .39382 .49282 L F
.3956 .49244 m .39382 .49282 L .39669 .4918 L F
.738 .458 .505 r
.53023 .38599 m .53249 .38562 L .53158 .38448 L F
.53023 .38599 m .53231 .38862 L .53249 .38562 L F
.605 .343 .495 r
.53231 .38862 m .53442 .38844 L .53249 .38562 L F
.639 .114 0 r
.65023 .36109 m .65311 .36317 L .65435 .36194 L F
.161 0 0 r
.65611 .36235 m .65435 .36194 L .65311 .36317 L F
.65611 .36235 m .65763 .36268 L .65435 .36194 L F
.902 .728 .656 r
.40563 .56908 m .40781 .56888 L .40805 .56743 L F
.40563 .56908 m .40645 .57064 L .40781 .56888 L F
.81 .76 .807 r
.40563 .56908 m .40523 .57144 L .40276 .57225 L F
.298 .787 .739 r
.40276 .57225 m .40523 .57144 L .40511 .57147 L F
.775 .696 .777 r
.40276 .57225 m .40407 .57182 L .40563 .56908 L F
0 0 .195 r
.4053 .57135 m .40523 .57144 L .40563 .56908 L F
.775 .696 .777 r
.4038 .57229 m .4053 .57135 L .40563 .56908 L F
.4053 .57135 m .40645 .57064 L .40563 .56908 L F
0 0 .195 r
.40638 .56978 m .4053 .57135 L .40563 .56908 L F
.298 .787 .739 r
.40276 .57225 m .40511 .57147 L .40308 .57193 L F
.775 .696 .777 r
.40276 .57225 m .4038 .57229 L .40407 .57182 L F
.581 .937 .787 r
.40511 .57147 m .40523 .57144 L .4053 .57135 L F
.775 .696 .777 r
.4038 .57229 m .40738 .57241 L .40645 .57064 L F
.581 .937 .787 r
.4045 .57161 m .40511 .57147 L .40545 .57114 L F
.40511 .57147 m .4053 .57135 L .40545 .57114 L F
.40308 .57193 m .4045 .57161 L .40638 .56978 L F
.4045 .57161 m .40545 .57114 L .40638 .56978 L F
.902 .728 .656 r
.40645 .57064 m .40738 .57241 L .40767 .57003 L F
.40645 .57064 m .40767 .57003 L .40781 .56888 L F
.741 .666 .777 r
.33289 .6569 m .33747 .65761 L .33565 .65354 L F
.751 .639 .737 r
.33289 .6569 m .33495 .66124 L .33747 .65761 L F
.525 .749 .977 r
.61941 .34759 m .61986 .34624 L .6175 .34561 L F
.61941 .34759 m .62229 .34704 L .61986 .34624 L F
.663 .321 .385 r
.40098 .56787 m .39813 .5654 L .39882 .56514 L F
.40098 .56787 m .39747 .56802 L .39813 .5654 L F
.781 .651 .719 r
.33042 .66052 m .33495 .66124 L .33289 .6569 L F
.422 .16 .41 r
.29129 .6464 m .29418 .64339 L .29156 .64371 L F
.354 .059 .319 r
.43105 .46221 m .4342 .45921 L .4319 .4604 L F
0 0 0 r
.56788 .34615 m .5693 .34495 L .5659 .34411 L F
.44 .866 .935 r
.51077 .41717 m .5136 .41642 L .51313 .41796 L F
.875 .594 .51 r
.33361 .63542 m .3374 .63367 L .3344 .63261 L F
.33361 .63542 m .33794 .63595 L .3374 .63367 L F
.842 .714 .722 r
.33615 .64642 m .3387 .64714 L .33702 .64329 L F
.799 .636 .68 r
.33404 .6496 m .3387 .64714 L .33615 .64642 L F
.33404 .6496 m .33774 .64999 L .3387 .64714 L F
.873 .601 .523 r
.64507 .35051 m .64858 .35451 L .64874 .35155 L F
.894 .49 .234 r
.58968 .40165 m .59208 .40314 L .59065 .40433 L F
.125 0 0 r
.59208 .40314 m .59409 .40376 L .59065 .40433 L F
.59208 .40314 m .59528 .4024 L .59409 .40376 L F
.761 .34 .251 r
.61005 .38369 m .61149 .38412 L .61251 .38207 L F
.01 0 0 r
.6216 .39548 m .6189 .39608 L .62288 .39472 L F
.038 0 0 r
.62288 .39472 m .6246 .39482 L .6216 .39548 L F
.62288 .39472 m .6255 .39483 L .6246 .39482 L F
.91 .832 .371 r
.58099 .38276 m .58195 .38247 L .58228 .38004 L F
.58099 .38276 m .58125 .38504 L .58195 .38247 L F
0 0 0 r
.63435 .3523 m .63338 .35039 L .63154 .35069 L F
.421 .436 .77 r
.63338 .35039 m .63267 .34993 L .63602 .3501 L F
.63338 .35039 m .63435 .3523 L .63267 .34993 L F
.63338 .35039 m .63747 .35422 L .63435 .3523 L F
.341 .668 .975 r
.63338 .35039 m .63602 .3501 L .63267 .34993 L F
.91 .971 .798 r
.4903 .47579 m .48887 .4802 L .49123 .47699 L F
.879 .978 .836 r
.49312 .47246 m .49123 .47699 L .49435 .47331 L F
.49312 .47246 m .4903 .47579 L .49123 .47699 L F
.826 .537 0 r
.58921 .39902 m .58877 .39975 L .58893 .39693 L F
.58921 .39902 m .58968 .40165 L .58877 .39975 L F
.835 .805 .822 r
.50532 .42949 m .50734 .43014 L .50981 .42703 L F
.874 .758 .731 r
.50554 .43201 m .50734 .43014 L .50532 .42949 L F
.759 .992 .794 r
.63123 .39091 m .63498 .38842 L .63451 .38798 L F
.793 .974 .682 r
.63451 .38798 m .63498 .38842 L .63761 .38504 L F
.022 0 .278 r
.46111 .44972 m .46073 .45252 L .45914 .45321 L F
.541 .445 .695 r
.46073 .45252 m .45856 .45668 L .45914 .45321 L F
.778 .871 .916 r
.51671 .41327 m .51835 .41467 L .5136 .41642 L F
.303 0 0 r
.5136 .41642 m .51835 .41467 L .51583 .41718 L F
0 .374 .82 r
.51835 .41467 m .51869 .41385 L .51583 .41718 L F
.684 .575 .727 r
.53898 .36908 m .53621 .37217 L .53536 .36845 L F
.153 .523 .918 r
.53621 .37217 m .53767 .37116 L .53465 .37245 L F
0 .399 .831 r
.53767 .37116 m .53959 .37311 L .54252 .37117 L F
.403 .515 .858 r
.5409 .36859 m .54552 .3708 L .54266 .37116 L F
.486 .435 .726 r
.54062 .36344 m .5409 .36859 L .53898 .36908 L F
.614 .713 .916 r
.53844 .36888 m .54252 .37117 L .53888 .36761 L F
.53767 .37116 m .54111 .37116 L .53844 .36888 L F
.54111 .37116 m .54252 .37117 L .53844 .36888 L F
.222 .563 .937 r
.54252 .37117 m .54125 .36931 L .53888 .36761 L F
.54125 .36931 m .54058 .36832 L .5401 .36812 L F
.54125 .36931 m .5401 .36812 L .53888 .36761 L F
.248 0 .074 r
.54552 .3708 m .54451 .37242 L .53959 .37311 L F
.405 .64 .952 r
.54253 .37064 m .54451 .37242 L .54281 .37041 L F
.54185 .37161 m .54281 .37041 L .54252 .37117 L F
.222 .563 .937 r
.54252 .37117 m .54281 .37041 L .54058 .36832 L F
.405 .64 .952 r
.5415 .3715 m .54416 .37231 L .54253 .37064 L F
.54416 .37231 m .54451 .37242 L .54253 .37064 L F
.53959 .37311 m .54281 .37041 L .54185 .37161 L F
.53959 .37311 m .54285 .37265 L .5415 .3715 L F
.54285 .37265 m .54451 .37242 L .5415 .3715 L F
0 .399 .831 r
.53767 .37116 m .54168 .3739 L .53959 .37311 L F
.153 .523 .918 r
.53621 .37217 m .54168 .3739 L .53767 .37116 L F
.363 .308 .661 r
.51601 .43902 m .51799 .44152 L .51762 .43847 L F
.51601 .43902 m .51642 .4433 L .51799 .44152 L F
.68 .491 .623 r
.52307 .3938 m .52696 .39547 L .52565 .3927 L F
.18 0 0 r
.39742 .48075 m .39862 .48213 L .39965 .4796 L F
.39742 .48075 m .39599 .48313 L .39862 .48213 L F
0 0 0 r
.63435 .3523 m .63154 .35069 L .63267 .34993 L F
.348 0 .142 r
.63435 .3523 m .63353 .35566 L .63088 .355 L F
.755 .382 .348 r
.63747 .35422 m .63353 .35566 L .63435 .3523 L F
.816 .614 .63 r
.41598 .55178 m .41203 .55434 L .41488 .55143 L F
.41598 .55178 m .41544 .55512 L .41203 .55434 L F
.745 .935 .949 r
.41437 .54971 m .41973 .5492 L .41598 .55178 L F
.994 .871 .546 r
.41437 .54971 m .41598 .55178 L .41488 .55143 L F
.793 .974 .682 r
.63451 .38798 m .63761 .38504 L .63671 .38398 L F
.802 .98 .898 r
.63671 .38398 m .63761 .38504 L .64095 .38206 L F
.755 .571 .648 r
.37347 .56552 m .3692 .56601 L .3688 .56215 L F
.37347 .56552 m .3688 .56215 L .37103 .56396 L F
.486 .576 .871 r
.37466 .56229 m .37347 .56552 L .37103 .56396 L F
.37466 .56229 m .37614 .56533 L .37347 .56552 L F
.741 .842 .927 r
.36545 .57819 m .36085 .57844 L .36292 .58031 L F
.842 .745 .756 r
.43558 .51086 m .43704 .51473 L .4349 .51342 L F
.84 .693 .7 r
.43637 .51741 m .4349 .51342 L .43704 .51473 L F
.954 .693 .502 r
.33416 .62924 m .33535 .62618 L .33303 .62552 L F
.025 0 0 r
.47007 .42883 m .46756 .42975 L .46608 .43143 L F
.847 .855 .848 r
.49195 .43222 m .4948 .42909 L .49146 .42889 L F
.749 .71 .815 r
.61852 .37576 m .61422 .37482 L .61717 .37442 L F
.703 .888 .965 r
.62089 .37422 m .61852 .37576 L .61984 .37282 L F
.714 .9 .963 r
.61852 .37576 m .61717 .37442 L .61984 .37282 L F
.968 .645 .292 r
.56706 .3789 m .56594 .37795 L .56413 .37918 L F
.56706 .3789 m .5682 .37738 L .56594 .37795 L F
.195 0 .161 r
.56594 .37795 m .5682 .37738 L .56915 .37553 L F
.542 .428 .674 r
.52894 .38941 m .53231 .38862 L .53023 .38599 L F
.371 .5 .859 r
.52894 .38941 m .5331 .39163 L .53231 .38862 L F
.756 .778 .871 r
.61381 .3434 m .61324 .34581 L .61519 .34487 L F
.364 .417 .783 r
.61519 .34487 m .61695 .34454 L .61381 .3434 L F
.61519 .34487 m .6175 .34561 L .61695 .34454 L F
.901 .906 .818 r
.46354 .48008 m .45926 .4822 L .46179 .47878 L F
.46354 .48008 m .46113 .48335 L .45926 .4822 L F
.932 .9 .772 r
.46354 .48008 m .46294 .47649 L .46657 .47669 L F
.46354 .48008 m .46179 .47878 L .46294 .47649 L F
.635 .849 .982 r
.36348 .57192 m .36117 .57321 L .35933 .5718 L F
.858 .577 .511 r
.35981 .57285 m .36117 .57321 L .35933 .5718 L F
.36049 .57303 m .36348 .57192 L .36117 .57321 L F
.36144 .57244 m .36348 .57192 L .36049 .57303 L F
.062 .209 .705 r
.36456 .57457 m .36117 .57321 L .36348 .57192 L F
.635 .849 .982 r
.36348 .57192 m .35933 .5718 L .36195 .57075 L F
.858 .577 .511 r
.35981 .57285 m .36144 .57244 L .36049 .57303 L F
.35981 .57285 m .36175 .5737 L .36348 .57192 L F
.344 .259 .614 r
.36291 .57151 m .36175 .5737 L .36452 .57278 L F
.36195 .57075 m .36185 .57218 L .36291 .57151 L F
.36185 .57218 m .36175 .5737 L .36291 .57151 L F
0 0 0 r
.50739 .40145 m .5061 .40175 L .50292 .40236 L F
.326 .811 .865 r
.51007 .40116 m .5061 .40175 L .50739 .40145 L F
0 .062 .575 r
.58686 .35815 m .58834 .35601 L .58744 .35329 L F
0 .016 .535 r
.58686 .35815 m .58848 .35998 L .58834 .35601 L F
.662 .515 .674 r
.52307 .3938 m .52412 .39882 L .52696 .39547 L F
.35 .093 .377 r
.5061 .40175 m .50344 .40464 L .50292 .40236 L F
.27 .761 .91 r
.62068 .35714 m .61668 .35702 L .61826 .3587 L F
.61668 .35702 m .62068 .35714 L .61826 .3587 L F
.62068 .35714 m .6199 .35652 L .61668 .35702 L F
.61668 .35702 m .6199 .35652 L .62068 .35714 L F
.422 .727 .989 r
.61826 .3587 m .6199 .35652 L .61668 .35702 L F
0 .105 .659 r
.40772 .54794 m .41154 .55268 L .41221 .54853 L F
.557 .328 .524 r
.4375 .47044 m .43738 .4731 L .43475 .47358 L F
.425 .221 .497 r
.43999 .47211 m .4375 .47044 L .44013 .4697 L F
.43999 .47211 m .43738 .4731 L .4375 .47044 L F
.833 .883 .878 r
.51371 .44452 m .51079 .44463 L .51122 .44328 L F
.535 0 0 r
.51122 .44328 m .51642 .4433 L .51371 .44452 L F
.756 .594 .676 r
.30889 .63017 m .30595 .63262 L .30868 .62907 L F
.30889 .63017 m .31055 .63359 L .30595 .63262 L F
.674 .56 .719 r
.31347 .62959 m .31055 .63359 L .30889 .63017 L F
.103 0 0 r
.36235 .48939 m .36757 .48651 L .36289 .48845 L F
.854 .798 .795 r
.43958 .53368 m .44401 .53175 L .44269 .53059 L F
.43958 .53368 m .44149 .5353 L .44401 .53175 L F
.84 .932 .89 r
.44269 .53059 m .44401 .53175 L .4469 .52897 L F
.817 .973 .897 r
.48416 .48223 m .48887 .4802 L .48773 .4794 L F
.91 .971 .798 r
.4903 .47579 m .48773 .4794 L .48887 .4802 L F
.885 .814 .773 r
.46676 .49867 m .47067 .49712 L .46911 .4953 L F
.46676 .49867 m .46835 .5005 L .47067 .49712 L F
.868 .891 .849 r
.46911 .4953 m .47067 .49712 L .47359 .49349 L F
.805 .889 .905 r
.45898 .48504 m .45926 .4822 L .46113 .48335 L F
.864 .701 .678 r
.55232 .37461 m .5501 .37461 L .55059 .37176 L F
.186 0 0 r
.55444 .37622 m .5501 .37461 L .55232 .37461 L F
.927 .874 .765 r
.42082 .57225 m .41884 .57183 L .42012 .56885 L F
.053 .25 .746 r
.42012 .56885 m .42146 .57008 L .42082 .57225 L F
.693 .936 .965 r
.42146 .57008 m .41884 .57183 L .42082 .57225 L F
0 0 0 r
.41044 .52472 m .4078 .5283 L .40915 .5266 L F
.959 .93 .72 r
.41043 .53044 m .4097 .5354 L .41192 .53151 L F
.103 0 0 r
.41044 .52472 m .40915 .5266 L .4101 .52556 L F
0 0 0 r
.61802 .34038 m .61964 .33935 L .62071 .33822 L F
.61705 .34116 m .61964 .33935 L .61802 .34038 L F
.372 .835 .776 r
.61964 .33935 m .62378 .33799 L .62071 .33822 L F
.498 .737 .979 r
.62203 .33768 m .62249 .33801 L .61964 .33935 L F
.372 .835 .776 r
.61964 .33935 m .62249 .33801 L .62378 .33799 L F
.455 .197 .434 r
.61964 .33935 m .62221 .34099 L .62133 .33828 L F
.498 .737 .979 r
.62086 .33684 m .62203 .33768 L .61964 .33935 L F
.455 .197 .434 r
.61964 .33935 m .62133 .33828 L .62086 .33684 L F
0 0 0 r
.61689 .34129 m .61964 .33935 L .61705 .34116 L F
.736 .825 .919 r
.47747 .4687 m .47201 .46977 L .47501 .46658 L F
.755 .727 .826 r
.47887 .46728 m .47747 .4687 L .47501 .46658 L F
.535 0 0 r
.51122 .44328 m .51482 .44452 L .51642 .4433 L F
.417 .036 .205 r
.51482 .44452 m .51799 .44152 L .51642 .4433 L F
.691 .754 .9 r
.36802 .56059 m .3688 .56215 L .36529 .56163 L F
.504 .651 .924 r
.37108 .56034 m .3688 .56215 L .36802 .56059 L F
.38 .417 .774 r
.37108 .56034 m .37103 .56396 L .3688 .56215 L F
.714 .57 .691 r
.4063 .52995 m .40915 .5266 L .4078 .5283 L F
.836 .823 .836 r
.43379 .52071 m .43097 .52399 L .43017 .52051 L F
.849 .83 .828 r
.43097 .52399 m .42716 .52403 L .43017 .52051 L F
.869 .769 .75 r
.43097 .52399 m .42859 .5279 L .42716 .52403 L F
.511 .627 .902 r
.30519 .66284 m .30652 .66538 L .3089 .66486 L F
.239 .524 .916 r
.30652 .66538 m .31106 .66835 L .3089 .66486 L F
.966 .762 .577 r
.57416 .34851 m .57354 .35095 L .57213 .34685 L F
.57213 .34685 m .57354 .35095 L .57416 .34851 L F
.57416 .34851 m .57354 .35095 L .57213 .34685 L F
.335 .65 .969 r
.38188 .57732 m .38336 .579 L .38425 .57735 L F
.443 .777 .998 r
.38336 .579 m .38604 .5786 L .38425 .57735 L F
.287 0 0 r
.3835 .48427 m .38587 .48474 L .38759 .483 L F
.418 0 0 r
.38587 .48474 m .39031 .48318 L .38759 .483 L F
.483 .84 .581 r
.49768 .40864 m .50156 .40548 L .50015 .40658 L F
.679 .768 .918 r
.32043 .6666 m .32474 .66717 L .32271 .66627 L F
.751 .753 .854 r
.32271 .66627 m .32474 .66717 L .32786 .66443 L F
.544 .809 .995 r
.4183 .56181 m .42154 .56247 L .42049 .56065 L F
.4183 .56181 m .42154 .56247 L .42049 .56065 L F
.534 .013 0 r
.42377 .56363 m .42049 .56065 L .42154 .56247 L F
.075 0 0 r
.50417 .39498 m .50923 .3929 L .50389 .39506 L F
.50417 .39498 m .50763 .39417 L .50923 .3929 L F
0 0 0 r
.50923 .3929 m .51017 .39308 L .51135 .3912 L F
.50923 .3929 m .50763 .39417 L .51017 .39308 L F
.396 .066 .285 r
.41931 .46998 m .422 .46938 L .42259 .46733 L F
.331 .01 .261 r
.42259 .46733 m .42458 .46859 L .42523 .46665 L F
.42259 .46733 m .422 .46938 L .42458 .46859 L F
0 0 .145 r
.5891 .38891 m .58944 .38915 L .58979 .38651 L F
.5891 .38891 m .58935 .39158 L .58944 .38915 L F
.621 .747 .937 r
.55765 .37164 m .55353 .37078 L .55628 .36972 L F
.217 .576 .942 r
.55628 .36972 m .55944 .371 L .55765 .37164 L F
.325 .371 .756 r
.56039 .37321 m .55765 .37164 L .55944 .371 L F
0 .009 .581 r
.35008 .57168 m .35053 .57109 L .34822 .56812 L F
.104 .621 .887 r
.35214 .57175 m .35053 .57109 L .35008 .57168 L F
.599 .562 .784 r
.47637 .43961 m .47317 .44307 L .47206 .44173 L F
.257 .48 .882 r
.47206 .44173 m .47317 .44307 L .47442 .44057 L F
.599 .562 .784 r
.47637 .43961 m .47719 .44322 L .47317 .44307 L F
.668 .416 .531 r
.47716 .44545 m .47317 .44307 L .47719 .44322 L F
0 0 .254 r
.47317 .44307 m .47469 .4438 L .47442 .44057 L F
.668 .416 .531 r
.47582 .44466 m .47304 .44567 L .47317 .44307 L F
0 0 .254 r
.47317 .44307 m .47303 .44588 L .47469 .4438 L F
.336 .811 .748 r
.47129 .44631 m .46859 .44719 L .4734 .44527 L F
.47078 .44656 m .46994 .4468 L .47129 .44631 L F
.46994 .4468 m .46859 .44719 L .47129 .44631 L F
.668 .416 .531 r
.47645 .44503 m .47303 .44588 L .47304 .44567 L F
.47645 .44503 m .47304 .44567 L .47582 .44466 L F
.47716 .44545 m .47303 .44588 L .47645 .44503 L F
.336 .811 .748 r
.47078 .44656 m .47129 .44631 L .47303 .44588 L F
.47129 .44631 m .4734 .44527 L .47303 .44588 L F
.18 .36 .807 r
.35438 .57494 m .35501 .57209 L .35214 .57175 L F
.35438 .57494 m .35622 .57495 L .35501 .57209 L F
.682 .459 .577 r
.60347 .38841 m .59993 .39102 L .59924 .38875 L F
.845 .991 .73 r
.65776 .36723 m .65734 .36651 L .65643 .36929 L F
.81 .981 .893 r
.65643 .36929 m .65734 .36651 L .65396 .36941 L F
0 .47 .712 r
.51015 .40989 m .51234 .41039 L .51029 .40998 L F
.655 .472 .624 r
.51216 .41175 m .51234 .41039 L .51015 .40989 L F
.51216 .41175 m .51525 .40886 L .51234 .41039 L F
0 .47 .712 r
.51015 .40989 m .51029 .40998 L .50933 .41204 L F
0 .469 .807 r
.62808 .35564 m .62654 .35458 L .62364 .35392 L F
.603 .05 0 r
.63088 .355 m .62654 .35458 L .62808 .35564 L F
.835 .975 .882 r
.49604 .46962 m .49435 .47331 L .49751 .47039 L F
.49604 .46962 m .49312 .47246 L .49435 .47331 L F
.506 .312 .551 r
.52634 .40358 m .52561 .40561 L .52834 .40216 L F
.04 .219 .721 r
.58963 .37186 m .5905 .36965 L .58803 .36749 L F
.743 .717 .186 r
.58966 .37438 m .5905 .36965 L .58963 .37186 L F
.684 .284 0 r
.56386 .37194 m .56283 .3703 L .56166 .3681 L F
.763 .434 .43 r
.56386 .37194 m .55944 .371 L .56283 .3703 L F
.56386 .37194 m .56039 .37321 L .55944 .371 L F
.56386 .37194 m .56457 .37479 L .56039 .37321 L F
.873 .826 .798 r
.45039 .51991 m .45483 .51786 L .45322 .51665 L F
.45039 .51991 m .45226 .52145 L .45483 .51786 L F
.866 .909 .859 r
.45322 .51665 m .45483 .51786 L .4577 .51454 L F
.195 0 0 r
.45856 .45668 m .45513 .45844 L .45602 .45761 L F
.568 .045 0 r
.37103 .4909 m .36913 .49223 L .36665 .49063 L F
.429 0 0 r
.37329 .49205 m .36913 .49223 L .37103 .4909 L F
.417 0 .006 r
.37382 .49087 m .37329 .49205 L .37103 .4909 L F
.827 .883 .884 r
.45898 .48504 m .45434 .48675 L .45598 .48406 L F
.797 .498 .483 r
.4557 .48276 m .45736 .48355 L .45334 .48284 L F
.805 .889 .905 r
.45898 .48504 m .4567 .48365 L .45915 .48329 L F
.797 .498 .483 r
.45736 .48355 m .45747 .48361 L .45726 .48357 L F
.45736 .48355 m .45726 .48357 L .45334 .48284 L F
.805 .889 .905 r
.45898 .48504 m .45598 .48406 L .4567 .48365 L F
.745 .76 .865 r
.45598 .48406 m .45334 .48284 L .45726 .48357 L F
.45598 .48406 m .45726 .48357 L .45747 .48361 L F
.805 .889 .905 r
.4592 .48283 m .45768 .48333 L .45926 .4822 L F
.45726 .48357 m .4567 .48365 L .4592 .48283 L F
.72 .628 .755 r
.45926 .4822 m .45747 .48361 L .45736 .48355 L F
.45926 .4822 m .45736 .48355 L .4557 .48276 L F
.805 .889 .905 r
.45768 .48333 m .4567 .48365 L .45926 .4822 L F
.45915 .48329 m .45726 .48357 L .4592 .48283 L F
.029 0 0 r
.54449 .3617 m .54062 .36344 L .54074 .36105 L F
.59 .674 .898 r
.64871 .33532 m .64541 .33462 L .64698 .33336 L F
.64541 .33462 m .64871 .33532 L .64698 .33336 L F
0 .422 .722 r
.39276 .55844 m .39571 .55929 L .39596 .55942 L F
.179 .71 .841 r
.39433 .55899 m .39518 .559 L .39571 .55929 L F
.39518 .559 m .39829 .55901 L .39571 .55929 L F
0 .422 .722 r
.39596 .55942 m .39571 .55929 L .39651 .55959 L F
.194 .71 .883 r
.39829 .55901 m .39651 .55959 L .39571 .55929 L F
.39829 .55901 m .39965 .55946 L .39651 .55959 L F
.867 .935 .865 r
.60476 .39316 m .60116 .39596 L .60381 .39187 L F
.738 .88 .946 r
.60381 .39187 m .6074 .39195 L .60476 .39316 L F
.386 .014 .204 r
.40642 .47607 m .4092 .47559 L .40981 .4738 L F
.425 .048 .219 r
.4092 .47559 m .41188 .4752 L .40981 .4738 L F
.407 .059 .26 r
.40981 .4738 m .41188 .4752 L .41257 .47324 L F
.734 .988 .799 r
.52857 .42746 m .53014 .42741 L .52747 .42964 L F
.313 .802 .86 r
.53121 .42649 m .53014 .42741 L .52857 .42746 L F
.715 .974 .746 r
.41883 .53989 m .41765 .54168 L .42084 .53869 L F
.286 0 .027 r
.46386 .44728 m .46178 .44886 L .46609 .44784 L F
0 0 .441 r
.59075 .37865 m .59099 .37691 L .58966 .37438 L F
0 0 .222 r
.59075 .37865 m .59112 .37905 L .59099 .37691 L F
.59075 .37865 m .5914 .3814 L .59112 .37905 L F
.966 .792 .615 r
.52276 .43098 m .52432 .43255 L .52158 .43304 L F
.965 .845 .673 r
.52158 .43304 m .52432 .43255 L .52267 .43467 L F
.826 .845 .862 r
.52747 .42964 m .52432 .43255 L .52276 .43098 L F
.822 .98 .887 r
.52474 .4498 m .52364 .44908 L .52042 .45191 L F
.761 .971 .925 r
.52563 .44734 m .52474 .4498 L .52678 .44758 L F
.52563 .44734 m .52364 .44908 L .52474 .4498 L F
0 0 0 r
.60833 .35032 m .60411 .35258 L .60645 .35111 L F
.648 .656 .844 r
.40276 .57225 m .40692 .57507 L .40738 .57241 L F
.798 .739 .798 r
.45179 .44239 m .45404 .44151 L .45476 .43914 L F
.165 0 .074 r
.45158 .4452 m .45404 .44151 L .45179 .44239 L F
.45158 .4452 m .4541 .44418 L .45404 .44151 L F
.007 0 .403 r
.45476 .43914 m .45404 .44151 L .45664 .4406 L F
.037 0 .071 r
.45404 .44151 m .45611 .44299 L .45664 .4406 L F
.45404 .44151 m .4541 .44418 L .45611 .44299 L F
.806 .538 .534 r
.61381 .3434 m .61689 .34129 L .61441 .34067 L F
.61381 .3434 m .61695 .34454 L .61689 .34129 L F
.048 0 .417 r
.61689 .34129 m .61938 .34199 L .61964 .33935 L F
.61689 .34129 m .61695 .34454 L .61938 .34199 L F
.861 .712 .695 r
.40616 .54401 m .40772 .54794 L .40881 .54541 L F
.288 0 0 r
.37251 .48655 m .37497 .48606 L .37655 .48441 L F
.377 0 0 r
.37655 .48441 m .37497 .48606 L .37888 .48531 L F
.526 0 0 r
.5189 .42277 m .51736 .42413 L .51472 .4227 L F
.095 0 0 r
.51472 .4227 m .51742 .42283 L .5189 .42277 L F
.867 .982 .845 r
.5189 .42277 m .52046 .41911 L .52163 .41931 L F
.5189 .42277 m .51742 .42283 L .52046 .41911 L F
.134 0 0 r
.5189 .42277 m .52009 .4234 L .51736 .42413 L F
.5189 .42277 m .52177 .42262 L .52081 .42307 L F
0 .268 .773 r
.52213 .4188 m .52434 .42129 L .52163 .41931 L F
.52265 .41825 m .52326 .41935 L .52213 .4188 L F
.52326 .41935 m .52434 .42129 L .52213 .4188 L F
.763 .73 .822 r
.52718 .41814 m .52434 .42129 L .52265 .41825 L F
.576 .554 .792 r
.52125 .42303 m .52428 .42026 L .5207 .42285 L F
.52428 .42026 m .52553 .41912 L .52412 .42021 L F
.52428 .42026 m .52412 .42021 L .5207 .42285 L F
.527 0 0 r
.52009 .4234 m .52177 .42262 L .52432 .42402 L F
.576 .554 .792 r
.52464 .42272 m .52553 .41912 L .52125 .42303 L F
.315 .09 .405 r
.52392 .42106 m .5207 .42285 L .52447 .41994 L F
.788 .76 .827 r
.52046 .41911 m .51742 .42283 L .51611 .41983 L F
.52046 .41911 m .51611 .41983 L .51917 .41917 L F
.692 .439 .536 r
.51917 .41917 m .52392 .42106 L .52346 .42004 L F
0 .268 .773 r
.52265 .41825 m .52163 .41931 L .52046 .41911 L F
.692 .439 .536 r
.51917 .41917 m .52265 .41825 L .52046 .41911 L F
.51964 .41905 m .52346 .42004 L .52265 .41825 L F
.51917 .41917 m .52346 .42004 L .51964 .41905 L F
.315 .09 .405 r
.52474 .42007 m .52447 .41994 L .52553 .41912 L F
.52392 .42106 m .52447 .41994 L .52474 .42007 L F
.576 .554 .792 r
.52432 .42402 m .52464 .42272 L .52125 .42303 L F
.134 0 0 r
.51966 .42317 m .52081 .42307 L .52009 .4234 L F
.5189 .42277 m .52081 .42307 L .51966 .42317 L F
.654 .325 .404 r
.48971 .42501 m .49357 .42291 L .49 .42217 L F
.48971 .42501 m .4938 .42406 L .49357 .42291 L F
0 0 .104 r
.58803 .36749 m .58856 .36272 L .58877 .36543 L F
.849 .757 .762 r
.41796 .53686 m .42084 .53869 L .41671 .53797 L F
.854 .923 .875 r
.42084 .53869 m .41586 .54137 L .41671 .53797 L F
.639 .775 .946 r
.42093 .53633 m .42084 .53869 L .41796 .53686 L F
.545 .367 .591 r
.42093 .53633 m .41883 .53989 L .42084 .53869 L F
.403 .091 .318 r
.42523 .46665 m .4279 .46605 L .42855 .46309 L F
.383 .074 .312 r
.42855 .46309 m .43057 .46526 L .43105 .46221 L F
.42855 .46309 m .4279 .46605 L .43057 .46526 L F
0 .318 .78 r
.62923 .34994 m .62776 .34887 L .6296 .34905 L F
.62776 .34887 m .62776 .34816 L .6296 .34905 L F
.62776 .34887 m .62482 .34673 L .62776 .34816 L F
.62923 .34994 m .6283 .34863 L .62482 .34673 L F
.668 .955 .722 r
.62653 .35247 m .62766 .35001 L .62923 .34994 L F
.62766 .35001 m .6283 .34863 L .62902 .34965 L F
.62766 .35001 m .62902 .34965 L .62923 .34994 L F
.62653 .35247 m .62736 .35117 L .62777 .35005 L F
.62653 .35247 m .62777 .35005 L .62777 .34978 L F
.754 .673 .772 r
.62528 .35249 m .62101 .35412 L .62376 .35048 L F
.444 .874 .786 r
.62364 .35392 m .62491 .3528 L .62653 .35247 L F
.62491 .3528 m .62524 .35251 L .62568 .35249 L F
.62491 .3528 m .62568 .35249 L .62653 .35247 L F
.095 .445 .88 r
.62364 .35392 m .62654 .35458 L .62583 .3531 L F
.603 .05 0 r
.63088 .355 m .62934 .35576 L .62654 .35458 L F
.444 .874 .786 r
.62524 .35251 m .62525 .3525 L .62653 .35247 L F
.62524 .3525 m .62566 .35235 L .62653 .35247 L F
.668 .955 .722 r
.62653 .35247 m .62566 .35235 L .62736 .35117 L F
.38 0 0 r
.62638 .35185 m .62736 .35117 L .62668 .35197 L F
.62412 .35096 m .62736 .35117 L .62638 .35185 L F
.62412 .35096 m .6267 .35198 L .62528 .35249 L F
.668 .955 .722 r
.62566 .35235 m .62544 .35232 L .62736 .35117 L F
.38 0 0 r
.62528 .35249 m .6267 .35198 L .62583 .35308 L F
.095 .445 .88 r
.62572 .35301 m .62583 .3531 L .6258 .35304 L F
.62572 .35301 m .6258 .35304 L .62575 .353 L F
.62364 .35392 m .62577 .35299 L .62524 .35251 L F
.38 0 0 r
.6254 .35265 m .62583 .35308 L .62577 .35315 L F
.62528 .35249 m .62583 .35308 L .6254 .35265 L F
.095 .445 .88 r
.62575 .353 m .6258 .35304 L .62577 .35299 L F
.226 .57 .94 r
.6258 .35304 m .62736 .35117 L .62544 .35232 L F
.62654 .35458 m .62736 .35117 L .6258 .35304 L F
.38 0 0 r
.62668 .35197 m .62736 .35117 L .6267 .35198 L F
.226 .57 .94 r
.62654 .35458 m .62577 .35315 L .62736 .35117 L F
.62654 .35458 m .62934 .35576 L .62577 .35315 L F
.88 .468 .231 r
.62641 .35362 m .62764 .35721 L .62577 .35315 L F
.62934 .35576 m .6291 .35597 L .62641 .35362 L F
.6291 .35597 m .62764 .35721 L .62641 .35362 L F
.095 .445 .88 r
.62364 .35392 m .62583 .3531 L .62572 .35301 L F
.754 .673 .772 r
.6254 .35265 m .62524 .35251 L .62528 .35249 L F
.62217 .35388 m .62101 .35412 L .62528 .35249 L F
.444 .874 .786 r
.62524 .35251 m .62524 .3525 L .62525 .3525 L F
.62524 .3525 m .62544 .35232 L .62566 .35235 L F
.095 .445 .88 r
.62524 .35251 m .62577 .35299 L .62544 .35232 L F
.754 .673 .772 r
.62577 .35315 m .62217 .35388 L .62524 .35251 L F
.62577 .35315 m .62524 .35251 L .6254 .35265 L F
.372 .166 .466 r
.62391 .3553 m .62129 .35423 L .62577 .35315 L F
.62129 .35423 m .62101 .35412 L .62217 .35388 L F
.62129 .35423 m .62217 .35388 L .62577 .35315 L F
.38 0 0 r
.62376 .35048 m .62502 .35072 L .62412 .35096 L F
.62502 .35072 m .62736 .35117 L .62412 .35096 L F
.668 .955 .722 r
.62777 .34978 m .62777 .35005 L .6283 .34863 L F
.775 .272 0 r
.63154 .35069 m .62923 .34994 L .6296 .34905 L F
.798 .65 .698 r
.33565 .65354 m .33774 .64999 L .33404 .6496 L F
.874 .949 .858 r
.30595 .63262 m .30715 .62855 L .30868 .62907 L F
.873 .989 .822 r
.30868 .62907 m .30715 .62855 L .3099 .6255 L F
.615 .635 .847 r
.3089 .66486 m .31106 .66835 L .31346 .66707 L F
.414 .858 .776 r
.62378 .33799 m .62391 .33746 L .62507 .33821 L F
.961 .908 .718 r
.62391 .33746 m .62381 .33861 L .62507 .33821 L F
.62381 .33861 m .62347 .34248 L .62507 .33821 L F
.928 .702 .576 r
.62507 .33821 m .62773 .33779 L .62614 .33787 L F
.62507 .33821 m .62614 .33787 L .62378 .33799 L F
.62507 .33821 m .62724 .34067 L .62773 .33779 L F
.666 .901 .562 r
.62933 .3357 m .62899 .3357 L .62773 .33779 L F
.103 0 0 r
.36235 .48939 m .36492 .48868 L .36757 .48651 L F
.632 .956 .783 r
.63154 .35069 m .63189 .34948 L .63267 .34993 L F
.63154 .35069 m .63189 .34948 L .63267 .34993 L F
.854 .789 .787 r
.44498 .52697 m .44962 .52497 L .4475 .52329 L F
.44498 .52697 m .4469 .52897 L .44962 .52497 L F
.82 .754 .79 r
.4475 .52329 m .44962 .52497 L .45226 .52145 L F
.959 .93 .72 r
.41043 .53044 m .40855 .53443 L .4097 .5354 L F
.692 .822 .945 r
.38604 .5786 m .39028 .57891 L .3886 .57728 L F
.743 .836 .921 r
.3886 .57728 m .39028 .57891 L .3923 .57719 L F
.978 .915 .661 r
.51843 .3887 m .51881 .38364 L .51776 .3862 L F
.417 0 0 r
.38569 .56334 m .38822 .56356 L .38982 .56161 L F
0 0 0 r
.38982 .56161 m .39146 .56046 L .39276 .55844 L F
.82 .754 .79 r
.4475 .52329 m .45226 .52145 L .45039 .51991 L F
.856 .78 .776 r
.43379 .52071 m .43017 .52051 L .43249 .51703 L F
.821 .765 .8 r
.43637 .51741 m .43379 .52071 L .43249 .51703 L F
.639 .775 .946 r
.42093 .53633 m .42116 .53366 L .42306 .53475 L F
.845 .736 .744 r
.42359 .53022 m .42306 .53475 L .42116 .53366 L F
.42359 .53022 m .42474 .5347 L .42306 .53475 L F
.631 .208 .222 r
.42306 .53475 m .42522 .53621 L .42093 .53633 L F
.272 0 .039 r
.56444 .38683 m .56022 .38565 L .56257 .38365 L F
.56444 .38683 m .56075 .38889 L .56022 .38565 L F
.56444 .38683 m .56376 .38814 L .56075 .38889 L F
.611 .179 .196 r
.56376 .38814 m .56738 .38821 L .56444 .38683 L F
.554 .353 .562 r
.56444 .38683 m .56738 .38821 L .56745 .38505 L F
0 .389 .838 r
.57354 .35095 m .57613 .352 L .57567 .35268 L F
.091 .557 .907 r
.57613 .352 m .57914 .35352 L .57567 .35268 L F
.712 .284 .231 r
.60472 .38096 m .61005 .38369 L .60701 .38078 L F
.779 .685 .76 r
.47765 .46312 m .47887 .46728 L .47501 .46658 L F
.222 .324 .758 r
.48051 .46518 m .47887 .46728 L .47765 .46312 L F
.432 .63 .937 r
.48051 .46518 m .48174 .46747 L .47887 .46728 L F
.722 .956 .673 r
.63021 .36808 m .63148 .36585 L .63336 .36462 L F
.548 .93 .89 r
.63336 .36462 m .6351 .36296 L .63593 .36324 L F
.518 .873 .633 r
.63336 .36462 m .63148 .36585 L .6351 .36296 L F
.685 .888 .972 r
.48632 .46713 m .48174 .46747 L .48514 .46602 L F
.993 .877 .596 r
.48632 .46713 m .48514 .46602 L .48621 .46118 L F
0 0 .197 r
.57163 .35674 m .57143 .35972 L .57173 .35842 L F
.57178 .35436 m .57163 .35674 L .57225 .3561 L F
.57163 .35674 m .57173 .35842 L .57225 .3561 L F
0 .131 .679 r
.57143 .35972 m .5702 .35593 L .57225 .3561 L F
.57143 .35972 m .57286 .36164 L .5702 .35593 L F
.955 .645 .22 r
.57178 .35932 m .57157 .36055 L .5702 .35593 L F
.57286 .36164 m .57187 .36081 L .57178 .35932 L F
.57187 .36081 m .57157 .36055 L .57178 .35932 L F
.918 .866 .772 r
.4615 .50638 m .46554 .50388 L .46429 .50292 L F
.4615 .50638 m .46326 .50779 L .46554 .50388 L F
.963 .928 .71 r
.46516 .49992 m .46554 .50388 L .46835 .5005 L F
.46516 .49992 m .46429 .50292 L .46554 .50388 L F
.868 .891 .849 r
.46911 .4953 m .47359 .49349 L .47242 .49257 L F
.832 .982 .878 r
.47573 .48961 m .47359 .49349 L .47649 .48978 L F
.47573 .48961 m .47242 .49257 L .47359 .49349 L F
.498 .75 .985 r
.55277 .41492 m .55664 .41607 L .55547 .41856 L F
0 0 .087 r
.55836 .41414 m .55664 .41607 L .55825 .41228 L F
.748 .877 .938 r
.37006 .57565 m .37202 .57727 L .37458 .57529 L F
.195 .722 .737 r
.36492 .48868 m .36753 .48808 L .37071 .48756 L F
.84 .932 .89 r
.44269 .53059 m .4469 .52897 L .44498 .52697 L F
.671 .367 .45 r
.49815 .43872 m .4966 .44187 L .49422 .44151 L F
.768 .581 .645 r
.50096 .43927 m .4966 .44187 L .49815 .43872 L F
.641 .789 .953 r
.49932 .41798 m .50381 .41892 L .5027 .41642 L F
.49932 .41798 m .50381 .41892 L .5027 .41642 L F
.634 .092 0 r
.50411 .41648 m .50402 .4162 L .50381 .41892 L F
.50411 .41648 m .50381 .41892 L .5027 .41642 L F
.42 .582 .907 r
.50381 .41892 m .50411 .41648 L .5027 .41642 L F
.50381 .41892 m .50636 .41894 L .50411 .41648 L F
.586 .406 .604 r
.40399 .56319 m .40201 .56536 L .39882 .56514 L F
.586 .408 .607 r
.40201 .56536 m .40098 .56787 L .39882 .56514 L F
.826 .845 .862 r
.52747 .42964 m .52276 .43098 L .52612 .42752 L F
.384 .623 .947 r
.52857 .42746 m .52747 .42964 L .52647 .42807 L F
0 0 0 r
.53027 .42697 m .52857 .42746 L .52695 .42863 L F
.53121 .42649 m .52857 .42746 L .53027 .42697 L F
.384 .623 .947 r
.52857 .42746 m .52647 .42807 L .52612 .42752 L F
.789 .625 .678 r
.369 .57263 m .3679 .57524 L .36667 .57127 L F
.573 .264 .407 r
.41272 .48639 m .4135 .49032 L .40834 .49001 L F
.524 .249 .439 r
.4153 .48631 m .4135 .49032 L .41272 .48639 L F
.84 .693 .7 r
.43637 .51741 m .43249 .51703 L .4349 .51342 L F
.381 .781 .985 r
.64698 .33336 m .65124 .33398 L .64871 .33532 L F
.65124 .33398 m .64698 .33336 L .64871 .33532 L F
.653 .484 .643 r
.55205 .36426 m .55215 .36882 L .54866 .36817 L F
.669 .562 .725 r
.55576 .36374 m .55205 .36426 L .55142 .36157 L F
.225 .147 .554 r
.55438 .36626 m .55205 .36426 L .55576 .36374 L F
.55438 .36626 m .55215 .36882 L .55205 .36426 L F
.526 .382 .628 r
.54689 .3906 m .54695 .39091 L .54716 .38832 L F
.159 .692 .846 r
.54698 .39108 m .54695 .39091 L .54341 .39099 L F
.639 .466 .633 r
.54695 .39091 m .54359 .39447 L .54341 .39099 L F
.535 .319 .534 r
.54695 .39091 m .54651 .39388 L .54359 .39447 L F
.526 .382 .628 r
.54651 .39388 m .54695 .39091 L .54689 .3906 L F
.159 .692 .846 r
.54739 .39109 m .54695 .39091 L .54698 .39108 L F
.537 .925 .876 r
.54943 .38944 m .54695 .39091 L .54739 .39109 L F
0 0 0 r
.5549 .40078 m .55494 .40044 L .55516 .39814 L F
.06 0 .413 r
.55516 .39814 m .5574 .39413 L .55575 .39562 L F
.55516 .39814 m .55741 .39683 L .5574 .39413 L F
0 0 .055 r
.55516 .39814 m .55494 .40044 L .55741 .39683 L F
.495 .199 .392 r
.42519 .48052 m .42497 .48298 L .42223 .48362 L F
.59 .278 .409 r
.42519 .48052 m .42787 .48266 L .42497 .48298 L F
.935 .964 .751 r
.60222 .35225 m .6006 .35762 L .60296 .35486 L F
.879 .444 .135 r
.59899 .35853 m .6006 .35762 L .59974 .35634 L F
.856 .46 .289 r
.6006 .35762 m .60251 .36129 L .60434 .36142 L F
.459 .221 .465 r
.43662 .47506 m .43475 .47358 L .43738 .4731 L F
.43662 .47506 m .43457 .47584 L .43475 .47358 L F
0 0 0 r
.6275 .37096 m .62967 .36981 L .63021 .36808 L F
.63021 .36808 m .62967 .36981 L .63148 .36585 L F
.978 .915 .661 r
.51843 .3887 m .51728 .38773 L .51881 .38364 L F
.475 .838 .993 r
.51843 .3887 m .51728 .38773 L .52103 .38795 L F
.578 .627 .864 r
.52718 .41814 m .52912 .4223 L .52584 .42265 L F
.522 .252 .446 r
.52584 .42265 m .52912 .4223 L .52856 .42463 L F
0 .164 .642 r
.52584 .42265 m .52856 .42463 L .52767 .42371 L F
.52584 .42265 m .52767 .42371 L .52432 .42402 L F
.35 0 0 r
.56589 .39597 m .56513 .39726 L .56177 .39729 L F
.053 0 0 r
.56589 .39597 m .56732 .39626 L .56513 .39726 L F
.56589 .39597 m .56878 .39577 L .56732 .39626 L F
.745 .759 .864 r
.35553 .58222 m .35648 .57767 L .35382 .58114 L F
.35553 .58222 m .35858 .57987 L .35648 .57767 L F
.938 .797 .677 r
.46676 .49867 m .46516 .49992 L .46835 .5005 L F
.614 .803 .972 r
.38057 .56595 m .37614 .56533 L .37867 .56361 L F
.722 .737 .862 r
.38321 .56459 m .38057 .56595 L .37867 .56361 L F
.848 .835 .833 r
.46657 .47669 m .46294 .47649 L .46538 .47491 L F
.798 .824 .872 r
.46977 .47362 m .46657 .47669 L .46538 .47491 L F
.866 .909 .859 r
.45322 .51665 m .4577 .51454 L .45613 .5134 L F
.887 .913 .838 r
.45613 .5134 m .4577 .51454 L .46047 .51108 L F
0 0 0 r
.59008 .35188 m .59441 .35057 L .59158 .35104 L F
.824 .671 .693 r
.33189 .65609 m .33289 .6569 L .33279 .65421 L F
.801 .68 .731 r
.33042 .66052 m .33289 .6569 L .33189 .65609 L F
.659 .542 .71 r
.33279 .65421 m .33289 .6569 L .33565 .65354 L F
.458 0 0 r
.52481 .37278 m .52813 .37353 L .52532 .37252 L F
0 .11 .583 r
.64146 .34912 m .64294 .35031 L .6402 .34813 L F
.881 .732 .692 r
.33523 .63931 m .33794 .63595 L .33361 .63542 L F
0 0 .135 r
.57178 .35436 m .57314 .35333 L .57354 .35095 L F
.852 .847 .384 r
.57225 .3561 m .57254 .35518 L .57213 .35567 L F
.57254 .35518 m .57314 .35333 L .57213 .35567 L F
.57225 .3561 m .57225 .35497 L .57314 .35333 L F
.57213 .35567 m .57314 .35333 L .57178 .35436 L F
.655 .949 .715 r
.57225 .35497 m .57613 .352 L .57314 .35333 L F
.442 .131 .34 r
.57354 .35095 m .57314 .35333 L .57613 .352 L F
.828 .397 0 r
.57349 .35309 m .57315 .35372 L .57348 .35258 L F
.655 .949 .715 r
.57268 .35457 m .57315 .35372 L .57442 .35299 L F
.57225 .35497 m .57442 .35299 L .57362 .35392 L F
.57362 .35392 m .57442 .35299 L .57613 .352 L F
.732 .27 .151 r
.57613 .352 m .57315 .35372 L .57818 .35459 L F
.842 .56 .511 r
.57315 .35372 m .57814 .35692 L .57818 .35459 L F
.57315 .35372 m .57505 .35704 L .57814 .35692 L F
.828 .397 0 r
.57354 .35542 m .57505 .35704 L .57315 .35372 L F
.57354 .35542 m .57315 .35372 L .57349 .35309 L F
.655 .949 .715 r
.57225 .35497 m .57315 .35372 L .57268 .35457 L F
0 0 0 r
.59528 .4024 m .59909 .4017 L .59793 .40204 L F
.566 .74 .958 r
.59753 .40261 m .59822 .40228 L .59714 .40297 L F
.066 0 0 r
.59909 .4017 m .60011 .40214 L .59808 .40204 L F
.119 0 0 r
.59753 .40261 m .59793 .40204 L .59808 .40204 L F
.59753 .40261 m .59808 .40204 L .60011 .40214 L F
.636 .629 .826 r
.60011 .40214 m .60226 .39827 L .5993 .39892 L F
.60011 .40214 m .60243 .4009 L .60226 .39827 L F
.259 .338 .755 r
.60229 .40077 m .60011 .40214 L .5993 .39892 L F
.566 .74 .958 r
.59753 .40261 m .60011 .40214 L .60037 .40126 L F
.59822 .40228 m .59827 .40237 L .59797 .40253 L F
.59822 .40228 m .59797 .40253 L .59724 .40291 L F
.59726 .40289 m .59724 .40291 L .59714 .40297 L F
.59822 .40228 m .59724 .40291 L .59726 .40289 L F
.59822 .40228 m .60037 .40126 L .59827 .40237 L F
.066 0 0 r
.59805 .402 m .59808 .40204 L .59793 .40204 L F
.59909 .4017 m .59808 .40204 L .59805 .402 L F
.824 .671 .693 r
.33189 .65609 m .33279 .65421 L .33164 .65304 L F
.669 .589 .756 r
.33279 .65421 m .33404 .6496 L .33164 .65304 L F
.33279 .65421 m .33565 .65354 L .33404 .6496 L F
.41 .137 .386 r
.3275 .6183 m .32406 .61699 L .32322 .61706 L F
.3275 .6183 m .32624 .61649 L .32406 .61699 L F
0 0 0 r
.39276 .55844 m .39433 .55899 L .39571 .55929 L F
.39276 .55844 m .39146 .56046 L .39433 .55899 L F
.309 .637 .965 r
.36396 .48996 m .36492 .48868 L .36235 .48939 L F
.36396 .48996 m .36665 .49063 L .36492 .48868 L F
.672 .701 .868 r
.5543 .3611 m .55142 .36157 L .55049 .35857 L F
.669 .562 .725 r
.55576 .36374 m .55142 .36157 L .5543 .3611 L F
.338 .436 .815 r
.29139 .65842 m .29208 .65577 L .29034 .65595 L F
.29139 .65842 m .29383 .65999 L .29208 .65577 L F
.864 .801 .786 r
.32571 .66287 m .32946 .66313 L .33042 .66052 L F
.858 .815 .806 r
.32786 .66443 m .32946 .66313 L .32571 .66287 L F
.778 .871 .916 r
.51671 .41327 m .5136 .41642 L .51253 .41373 L F
.303 0 0 r
.5136 .41642 m .51583 .41718 L .51313 .41796 L F
.723 .86 .947 r
.55133 .38462 m .54879 .38484 L .5515 .38262 L F
.582 .662 .893 r
.55479 .38147 m .55133 .38462 L .5515 .38262 L F
.55479 .38147 m .55609 .38424 L .55133 .38462 L F
.547 .376 .601 r
.5561 .38709 m .55133 .38462 L .55609 .38424 L F
.5561 .38709 m .55289 .38834 L .55133 .38462 L F
.668 .803 .947 r
.5176 .40376 m .51847 .40551 L .51443 .4051 L F
0 0 0 r
.51847 .40551 m .51754 .40744 L .51525 .40886 L F
.402 .642 .954 r
.51986 .4036 m .51847 .40551 L .5176 .40376 L F
0 0 0 r
.51986 .4036 m .51754 .40744 L .51847 .40551 L F
.541 .305 .508 r
.511 .43481 m .51067 .43858 L .5138 .43502 L F
.45 .5 .819 r
.60158 .3472 m .60439 .34701 L .60251 .34281 L F
.206 0 .231 r
.45513 .45844 m .45201 .46201 L .45248 .45974 L F
.836 .787 .805 r
.44311 .50035 m .43895 .50002 L .44198 .49654 L F
.855 .726 .72 r
.44311 .50035 m .44061 .5042 L .43895 .50002 L F
.915 .82 .738 r
.44377 .49768 m .44311 .50035 L .44198 .49654 L F
.662 .139 0 r
.55698 .3546 m .55579 .35532 L .5537 .35379 L F
.37 .284 .627 r
.5558 .35284 m .55579 .35532 L .55698 .3546 L F
.346 0 0 r
.52264 .39203 m .52137 .39382 L .51837 .39396 L F
0 .062 .625 r
.52103 .38795 m .52276 .3904 L .52264 .39203 L F
0 0 0 r
.52334 .39162 m .52264 .39203 L .52276 .3904 L F
.613 .807 .974 r
.51314 .42079 m .51472 .4227 L .51178 .4233 L F
.51314 .42079 m .51472 .4227 L .51178 .4233 L F
.887 .913 .838 r
.45613 .5134 m .46047 .51108 L .45897 .50992 L F
.867 .881 .844 r
.46047 .51108 m .4615 .50638 L .45897 .50992 L F
.46047 .51108 m .46326 .50779 L .4615 .50638 L F
0 0 .075 r
.55929 .41039 m .55836 .41414 L .55825 .41228 L F
.401 .136 .392 r
.44014 .45579 m .44318 .45257 L .44065 .45344 L F
.648 .237 .251 r
.37796 .49032 m .37329 .49205 L .37382 .49087 L F
.37796 .49032 m .37627 .49268 L .37329 .49205 L F
.53 .104 .177 r
.38064 .49211 m .37627 .49268 L .37796 .49032 L F
.458 .055 .187 r
.41203 .56514 m .41063 .5676 L .40805 .56743 L F
0 0 .353 r
.41277 .56323 m .41203 .56514 L .41463 .56496 L F
.838 .572 .537 r
.4127 .56515 m .41278 .56517 L .41271 .56503 L F
0 0 .353 r
.41361 .56109 m .41277 .56323 L .41504 .56493 L F
.41277 .56323 m .41463 .56496 L .41504 .56493 L F
.41277 .56323 m .41271 .56503 L .41203 .56514 L F
.41361 .56109 m .4127 .56517 L .41277 .56323 L F
0 0 .319 r
.41271 .56503 m .41361 .56109 L .41085 .56127 L F
.41278 .56517 m .41361 .56109 L .41271 .56503 L F
0 0 .353 r
.41271 .56503 m .4127 .56517 L .41268 .56516 L F
.41271 .56503 m .41268 .56516 L .41203 .56514 L F
0 0 .319 r
.41278 .56517 m .41334 .56519 L .41361 .56109 L F
0 0 .353 r
.41361 .56109 m .41334 .56519 L .4127 .56517 L F
.838 .572 .537 r
.40705 .564 m .4127 .56515 L .411 .56157 L F
.4127 .56515 m .41271 .56503 L .411 .56157 L F
.41075 .56134 m .411 .56157 L .41085 .56127 L F
.40705 .564 m .411 .56157 L .41075 .56134 L F
.426 .023 .169 r
.41433 .56607 m .41063 .5676 L .41203 .56514 L F
.49 .162 .337 r
.40805 .56743 m .41272 .56519 L .40705 .564 L F
.41272 .56519 m .41278 .56517 L .41268 .56515 L F
.41272 .56519 m .41268 .56515 L .40705 .564 L F
.426 .023 .169 r
.41433 .56607 m .41308 .56557 L .41334 .56519 L F
.41308 .56557 m .41203 .56514 L .41266 .56516 L F
.49 .162 .337 r
.40805 .56743 m .41063 .5676 L .41275 .5652 L F
.41272 .56519 m .41275 .5652 L .41278 .56517 L F
.40805 .56743 m .41275 .5652 L .41272 .56519 L F
.426 .023 .169 r
.41272 .56519 m .41266 .56516 L .4127 .56517 L F
.707 .926 .598 r
.41278 .56517 m .41275 .56518 L .41334 .56519 L F
.426 .023 .169 r
.41308 .56557 m .41268 .56518 L .41272 .56519 L F
.707 .926 .598 r
.41175 .56634 m .41092 .56728 L .41132 .56597 L F
.293 0 0 r
.41433 .56607 m .41356 .5672 L .41063 .5676 L F
.707 .926 .598 r
.41092 .56728 m .41063 .5676 L .41132 .56597 L F
.427 .782 .996 r
.41063 .5676 m .41356 .5672 L .41132 .56597 L F
.411 0 0 r
.41132 .56597 m .4122 .56721 L .41102 .56571 L F
.41132 .56597 m .41102 .56571 L .40992 .56431 L F
.707 .926 .598 r
.41278 .56517 m .41175 .56634 L .41132 .56597 L F
.318 .734 .976 r
.41091 .56521 m .4115 .56539 L .41132 .56597 L F
.707 .926 .598 r
.41275 .56518 m .41132 .56597 L .41334 .56519 L F
.426 .023 .169 r
.41308 .56557 m .4127 .56517 L .41334 .56519 L F
.419 0 0 r
.41442 .56624 m .41334 .56519 L .41132 .56597 L F
.339 0 0 r
.41132 .56597 m .41442 .56624 L .41334 .56519 L F
.318 .734 .976 r
.4115 .56539 m .41442 .56624 L .41132 .56597 L F
.426 .023 .169 r
.41268 .56518 m .41266 .56516 L .4127 .56518 L F
.41268 .56518 m .4127 .56518 L .41272 .56519 L F
.685 .449 .56 r
.48279 .43617 m .47865 .43844 L .47812 .43569 L F
.48279 .43617 m .48288 .43892 L .47865 .43844 L F
.635 .431 .589 r
.48642 .4357 m .48288 .43892 L .48279 .43617 L F
.98 .808 .401 r
.60021 .36606 m .60078 .36864 L .6014 .36465 L F
.744 .25 .058 r
.60251 .36129 m .60295 .36259 L .60434 .36142 L F
.168 0 .027 r
.60404 .36101 m .60295 .36259 L .60393 .36065 L F
.612 .886 .569 r
.60434 .36142 m .60295 .36259 L .60192 .36408 L F
.168 0 .027 r
.60485 .36361 m .60295 .36259 L .60404 .36101 L F
.612 .886 .569 r
.60192 .36408 m .60295 .36259 L .6014 .36465 L F
.579 .831 .464 r
.60295 .36259 m .60021 .36606 L .6014 .36465 L F
.257 .48 .882 r
.47206 .44173 m .47442 .44057 L .47637 .43961 L F
.575 .247 .376 r
.53442 .38844 m .53808 .38985 L .53899 .38821 L F
0 0 0 r
.53899 .38821 m .54077 .3863 L .54198 .38496 L F
.715 .624 .754 r
.53808 .38985 m .54077 .3863 L .53899 .38821 L F
.851 .729 .729 r
.42435 .52743 m .42626 .53142 L .42359 .53022 L F
.845 .736 .744 r
.42359 .53022 m .42626 .53142 L .42474 .5347 L F
.802 .713 .767 r
.42435 .52743 m .42859 .5279 L .42626 .53142 L F
.485 .478 .775 r
.50672 .41347 m .51093 .41411 L .50933 .41204 L F
.581 .542 .776 r
.51253 .41373 m .50933 .41204 L .51216 .41175 L F
.614 .394 .559 r
.51093 .41411 m .51015 .40989 L .50933 .41204 L F
.793 .737 .801 r
.42716 .52403 m .42859 .5279 L .42435 .52743 L F
.742 .424 .444 r
.39535 .55047 m .39552 .54934 L .3976 .55091 L F
.881 .577 .064 r
.397 .54705 m .3976 .55091 L .394 .5482 L F
.848 .499 .393 r
.39601 .55291 m .39448 .55168 L .3976 .55091 L F
.39448 .55168 m .39219 .54984 L .39535 .55047 L F
.39448 .55168 m .39535 .55047 L .3976 .55091 L F
0 0 0 r
.39778 .5471 m .39535 .5505 L .39847 .54714 L F
.397 .54705 m .39538 .55043 L .39778 .5471 L F
.39538 .55043 m .39535 .5505 L .39778 .5471 L F
.848 .499 .393 r
.39601 .55291 m .39225 .55225 L .39219 .54984 L F
0 0 0 r
.39535 .5505 m .39442 .55244 L .39522 .5514 L F
.39535 .5505 m .39522 .5514 L .39847 .54714 L F
.742 .424 .444 r
.39219 .54984 m .394 .5482 L .39552 .54934 L F
.39219 .54984 m .39552 .54934 L .39535 .55047 L F
.39219 .54984 m .397 .54705 L .394 .5482 L F
.787 .987 .739 r
.47722 .48749 m .47649 .48978 L .48003 .48749 L F
.47722 .48749 m .47573 .48961 L .47649 .48978 L F
.751 .392 .374 r
.3692 .56601 m .36467 .5673 L .3648 .56448 L F
.808 .585 .601 r
.54866 .36817 m .55059 .37176 L .54624 .37085 L F
.723 .559 .667 r
.55353 .37078 m .54866 .36817 L .55215 .36882 L F
.55353 .37078 m .55059 .37176 L .54866 .36817 L F
.369 0 0 r
.37888 .48531 m .38158 .48546 L .3835 .48427 L F
.264 0 0 r
.3835 .48427 m .38158 .48546 L .38587 .48474 L F
.898 .93 .83 r
.65776 .36723 m .6606 .36383 L .65928 .3626 L F
.172 0 .18 r
.47078 .44656 m .47033 .44864 L .46792 .44962 L F
.573 .199 .295 r
.47322 .44808 m .47078 .44656 L .47303 .44588 L F
.47322 .44808 m .47033 .44864 L .47078 .44656 L F
.693 .972 .923 r
.50494 .43117 m .50554 .43201 L .50532 .42949 L F
.625 .758 .942 r
.56687 .37308 m .56915 .37553 L .5702 .37414 L F
0 0 0 r
.56915 .37553 m .5682 .37738 L .5702 .37414 L F
.689 .382 .451 r
.40967 .55512 m .40924 .5575 L .40595 .55711 L F
.79 .669 .73 r
.41203 .55434 m .40924 .5575 L .40967 .55512 L F
.974 .922 .612 r
.47812 .43569 m .47557 .43756 L .4743 .43512 L F
.47812 .43569 m .47637 .43961 L .47557 .43756 L F
.738 .523 .601 r
.47865 .43844 m .47637 .43961 L .47812 .43569 L F
.776 .736 .816 r
.5501 .37461 m .54792 .37769 L .54598 .37385 L F
.475 .894 .891 r
.60788 .39869 m .609 .39884 L .61165 .39769 L F
.771 .986 .899 r
.49837 .46807 m .49751 .47039 L .49939 .46919 L F
.667 .954 .95 r
.50033 .46661 m .49939 .46919 L .50253 .4658 L F
.50033 .46661 m .49837 .46807 L .49939 .46919 L F
.887 .834 .789 r
.30595 .63262 m .30178 .63334 L .30418 .63177 L F
.30595 .63262 m .30332 .63631 L .30178 .63334 L F
.874 .949 .858 r
.30595 .63262 m .30418 .63177 L .30715 .62855 L F
.802 .98 .898 r
.63671 .38398 m .64095 .38206 L .64019 .38127 L F
.872 .991 .817 r
.64095 .38206 m .64377 .37873 L .64166 .37912 L F
.877 .992 .799 r
.64019 .38127 m .64095 .38206 L .64166 .37912 L F
.661 .596 .771 r
.28922 .65482 m .29331 .65432 L .29118 .64904 L F
.292 .429 .828 r
.28922 .65482 m .29208 .65577 L .29331 .65432 L F
.28922 .65482 m .29034 .65595 L .29208 .65577 L F
.672 .76 .917 r
.31346 .66707 m .31788 .66776 L .31624 .66606 L F
.731 .741 .859 r
.31788 .66776 m .32043 .6666 L .31624 .66606 L F
.778 .601 .66 r
.50483 .4403 m .50534 .44384 L .50091 .44232 L F
.453 .371 .674 r
.50789 .44079 m .50534 .44384 L .50483 .4403 L F
.757 .461 .484 r
.45645 .45182 m .46073 .45252 L .46111 .44972 L F
.717 .424 .48 r
.46484 .45239 m .46073 .45252 L .46111 .44972 L F
.46484 .45239 m .46073 .45252 L .46111 .44972 L F
0 0 .164 r
.46182 .45034 m .46156 .44877 L .46166 .4484 L F
.46177 .44825 m .46166 .4484 L .46176 .44799 L F
.752 .995 .847 r
.46178 .44886 m .46153 .44857 L .46184 .44816 L F
0 0 .164 r
.46182 .45034 m .46166 .4484 L .46177 .44825 L F
.752 .995 .847 r
.46178 .44886 m .46111 .44972 L .46153 .44857 L F
.46184 .44816 m .46153 .44857 L .46188 .44759 L F
.56 .001 0 r
.4619 .44482 m .46609 .44784 L .46178 .44886 L F
0 0 .164 r
.46182 .45034 m .46176 .44799 L .46188 .44759 L F
0 0 .072 r
.46153 .44857 m .46182 .45034 L .46188 .44759 L F
.583 .342 .517 r
.46157 .44813 m .46069 .45205 L .45645 .45182 L F
.46069 .45205 m .46047 .4523 L .45645 .45182 L F
0 0 .072 r
.46111 .44972 m .46154 .45009 L .46153 .44857 L F
.583 .342 .517 r
.46156 .44877 m .46063 .45232 L .46157 .44813 L F
0 0 .072 r
.46111 .44972 m .46073 .45252 L .46182 .45034 L F
.745 .954 .648 r
.46134 .4513 m .46082 .45186 L .46182 .45034 L F
0 0 .164 r
.46182 .45034 m .46063 .45232 L .46071 .45204 L F
0 0 .072 r
.46154 .45009 m .46182 .45034 L .46156 .44877 L F
.46154 .45009 m .46156 .44877 L .46153 .44857 L F
0 0 .164 r
.46182 .45034 m .46071 .45204 L .46156 .44877 L F
.625 .12 .032 r
.45645 .45182 m .45906 .45376 L .46073 .45252 L F
.562 .211 .332 r
.46047 .4523 m .45906 .45376 L .45645 .45182 L F
.745 .954 .648 r
.46073 .45252 m .45949 .45344 L .46047 .4523 L F
.45949 .45344 m .45906 .45376 L .46134 .4513 L F
.562 .211 .332 r
.46063 .45232 m .45906 .45376 L .46047 .4523 L F
.745 .954 .648 r
.46123 .45153 m .46047 .4523 L .46134 .4513 L F
.46073 .45252 m .46047 .4523 L .46123 .45153 L F
.46082 .45186 m .45906 .45376 L .46182 .45034 L F
.583 .342 .517 r
.46069 .45205 m .46063 .45232 L .46047 .4523 L F
.46176 .44799 m .46156 .44877 L .46157 .44813 L F
.226 0 .278 r
.44896 .44582 m .45158 .4452 L .45179 .44239 L F
.46 .522 .834 r
.55438 .36626 m .55353 .37078 L .55215 .36882 L F
.55438 .36626 m .55628 .36972 L .55353 .37078 L F
.85 .728 .728 r
.42522 .53621 m .4274 .53817 L .42649 .5409 L F
.595 .923 .968 r
.36529 .56163 m .36576 .55997 L .36802 .56059 L F
.976 .738 .512 r
.36529 .56163 m .36318 .56067 L .36576 .55997 L F
.36529 .56163 m .3648 .56448 L .36318 .56067 L F
0 0 0 r
.49009 .41012 m .49335 .40766 L .4909 .40896 L F
.685 .78 .923 r
.60222 .35225 m .60296 .35486 L .60411 .35258 L F
.857 .823 .814 r
.47201 .46977 m .46877 .46936 L .47109 .4662 L F
.914 .848 .764 r
.47201 .46977 m .46795 .47207 L .46877 .46936 L F
.47201 .46977 m .46977 .47362 L .46795 .47207 L F
.788 .787 .851 r
.47501 .46658 m .47201 .46977 L .47109 .4662 L F
.647 .232 .241 r
.38485 .49026 m .38269 .49241 L .38064 .49211 L F
.73 .339 .311 r
.38728 .49291 m .38269 .49241 L .38485 .49026 L F
.343 0 0 r
.41767 .47168 m .422 .46938 L .41931 .46998 L F
.016 0 0 r
.41522 .47255 m .41767 .47168 L .41931 .46998 L F
.804 .673 .719 r
.41544 .55512 m .41432 .55831 L .41203 .55434 L F
.096 0 0 r
.45665 .43745 m .46035 .43509 L .45808 .43643 L F
.833 .97 .888 r
.64377 .37873 m .64572 .3766 L .6446 .37568 L F
.866 .992 .821 r
.64166 .37912 m .64377 .37873 L .6446 .37568 L F
0 0 .167 r
.49702 .41088 m .49543 .41249 L .49768 .40864 L F
.711 .614 .747 r
.49702 .41088 m .49447 .41475 L .49543 .41249 L F
.248 0 .269 r
.44615 .44892 m .4487 .44859 L .44896 .44582 L F
.278 0 .276 r
.44896 .44582 m .45114 .44756 L .45158 .4452 L F
.44896 .44582 m .4487 .44859 L .45114 .44756 L F
.781 .679 .751 r
.40358 .54732 m .40772 .54794 L .40616 .54401 L F
.792 .63 .68 r
.40358 .54732 m .40546 .55139 L .40772 .54794 L F
.852 .852 .841 r
.44653 .49452 m .44377 .49768 L .44198 .49654 L F
.576 .015 0 r
.55718 .37701 m .55544 .37678 L .55322 .37703 L F
.186 0 0 r
.55444 .37622 m .55322 .37703 L .5506 .37732 L F
.576 .015 0 r
.55544 .37678 m .55236 .37637 L .55322 .37703 L F
.186 0 0 r
.5506 .37732 m .55322 .37703 L .5503 .37741 L F
.007 0 .403 r
.45476 .43914 m .45664 .4406 L .45665 .43745 L F
.89 .834 .784 r
.49297 .42038 m .49 .42217 L .49242 .4185 L F
0 0 .082 r
.49046 .42224 m .49 .42217 L .49297 .42038 L F
0 0 0 r
.49559 .41692 m .49297 .42038 L .49242 .4185 L F
.49559 .41692 m .49373 .41948 L .49297 .42038 L F
.506 .852 .586 r
.49373 .41948 m .49046 .42224 L .49297 .42038 L F
.066 0 0 r
.48786 .41182 m .48907 .4128 L .49009 .41012 L F
.48786 .41182 m .48656 .41374 L .48907 .4128 L F
.105 0 0 r
.60251 .34281 m .60677 .34059 L .6038 .34113 L F
.508 .512 .795 r
.53096 .3642 m .53164 .35994 L .52969 .36085 L F
.53096 .3642 m .53268 .36351 L .53164 .35994 L F
.969 .664 .386 r
.50091 .44232 m .50278 .44577 L .50095 .44489 L F
.977 .806 .604 r
.50095 .44489 m .50188 .44882 L .50278 .44577 L F
.735 .667 .784 r
.50534 .44384 m .50278 .44577 L .50091 .44232 L F
.809 .928 .913 r
.50095 .44489 m .50278 .44577 L .50534 .44384 L F
.977 .806 .604 r
.50095 .44489 m .50188 .44882 L .50278 .44577 L F
.919 .709 .602 r
.36456 .57457 m .36327 .5772 L .36545 .57819 L F
.741 .842 .927 r
.36545 .57819 m .36327 .5772 L .36085 .57844 L F
.203 0 .142 r
.29651 .64258 m .29936 .64193 L .3001 .63942 L F
.152 .308 .769 r
.3001 .63942 m .29894 .63584 L .30332 .63631 L F
.3001 .63942 m .30163 .63837 L .29894 .63584 L F
.466 .299 .571 r
.29936 .64193 m .30163 .63837 L .3001 .63942 L F
.753 .282 .128 r
.56022 .38565 m .55864 .38681 L .55609 .38424 L F
.601 .27 .381 r
.56257 .38365 m .56208 .38701 L .56027 .3869 L F
.55935 .38624 m .56027 .3869 L .55864 .38681 L F
.632 .078 0 r
.55704 .38457 m .55891 .38571 L .56022 .38565 L F
.954 .918 .737 r
.56022 .38565 m .55891 .38571 L .56138 .37975 L F
.601 .27 .381 r
.56257 .38365 m .55864 .38681 L .56022 .38565 L F
.56257 .38365 m .56027 .3869 L .55935 .38624 L F
.632 .078 0 r
.55609 .38424 m .55787 .38517 L .55704 .38457 L F
.55787 .38517 m .55891 .38571 L .55704 .38457 L F
.316 .076 .382 r
.52177 .37431 m .52293 .37826 L .52132 .37717 L F
.334 .09 .388 r
.52177 .37431 m .52407 .37588 L .52481 .37278 L F
.873 .601 .523 r
.64507 .35051 m .64517 .35403 L .64858 .35451 L F
.852 .801 .8 r
.64517 .35403 m .64604 .35789 L .64858 .35451 L F
.762 .275 0 r
.60078 .36864 m .60181 .37009 L .6034 .37126 L F
.645 .09 0 r
.60207 .37187 m .6034 .37126 L .60181 .37009 L F
.60207 .37187 m .60589 .37332 L .6034 .37126 L F
.496 0 0 r
.6034 .37126 m .60589 .37332 L .60584 .37317 L F
.85 .728 .728 r
.42522 .53621 m .42649 .5409 L .42358 .54047 L F
.905 .858 .785 r
.42358 .54047 m .42649 .5409 L .42401 .54418 L F
.868 .789 .771 r
.32719 .65252 m .33164 .65304 L .32893 .65238 L F
.872 .693 .657 r
.32676 .65543 m .33164 .65304 L .32719 .65252 L F
.32676 .65543 m .33189 .65609 L .33164 .65304 L F
.838 .825 .835 r
.32893 .65238 m .33164 .65304 L .33404 .6496 L F
.588 .67 .896 r
.37458 .57529 m .37925 .57765 L .37666 .57512 L F
.431 .757 .995 r
.37925 .57765 m .37978 .57595 L .37666 .57512 L F
.37925 .57765 m .38188 .57732 L .37978 .57595 L F
.793 .541 .556 r
.60222 .35225 m .60369 .34995 L .60222 .35055 L F
.454 .157 .37 r
.44339 .46685 m .44291 .46913 L .44013 .4697 L F
.341 .039 .299 r
.44587 .4662 m .44291 .46913 L .44339 .46685 L F
.692 .461 .568 r
.46792 .44962 m .46792 .4524 L .46484 .45239 L F
.526 .414 .669 r
.47033 .44864 m .46792 .4524 L .46792 .44962 L F
.291 .788 .861 r
.61701 .39584 m .6189 .39608 L .6216 .39548 L F
.85 .756 .76 r
.43629 .54004 m .43845 .54137 L .43741 .53758 L F
.846 .727 .732 r
.43383 .5438 m .43845 .54137 L .43629 .54004 L F
.43383 .5438 m .43665 .54495 L .43845 .54137 L F
.586 .794 .979 r
.36939 .56807 m .36618 .56915 L .36467 .5673 L F
.567 .432 .656 r
.40241 .55489 m .40529 .55442 L .40546 .55139 L F
.202 .24 .679 r
.54541 .36414 m .54818 .36671 L .54716 .36394 L F
.54541 .36414 m .54735 .36795 L .54818 .36671 L F
.586 .146 .172 r
.49211 .43697 m .49556 .43843 L .497 .43633 L F
.8 .56 .574 r
.50138 .43502 m .50482 .43555 L .5017 .43441 L F
.50067 .43641 m .50101 .43634 L .50138 .43502 L F
.50101 .43634 m .50482 .43555 L .50138 .43502 L F
.557 .398 .622 r
.497 .43633 m .5013 .43532 L .50085 .43191 L F
.5013 .43532 m .50141 .4353 L .50137 .43507 L F
.5013 .43532 m .50137 .43507 L .50085 .43191 L F
.42 0 .078 r
.497 .43633 m .50067 .43641 L .50141 .4353 L F
.497 .43633 m .49556 .43843 L .50067 .43641 L F
.285 0 .249 r
.47317 .42585 m .4757 .42488 L .47632 .42281 L F
.2 0 .214 r
.47632 .42281 m .4757 .42488 L .47863 .42173 L F
.879 .537 .398 r
.64375 .35715 m .64641 .36008 L .64604 .35789 L F
.852 .801 .8 r
.64517 .35403 m .64375 .35715 L .64604 .35789 L F
.368 .052 .292 r
.55757 .39168 m .56031 .39096 L .56075 .38889 L F
.358 .027 .26 r
.56031 .39096 m .56376 .38814 L .56075 .38889 L F
.309 .002 .272 r
.44318 .45257 m .44574 .45174 L .44615 .44892 L F
.224 0 .248 r
.44615 .44892 m .44802 .45069 L .4487 .44859 L F
.44615 .44892 m .44574 .45174 L .44802 .45069 L F
.671 .565 .726 r
.55793 .36186 m .55576 .36374 L .5543 .3611 L F
.401 .002 .163 r
.55628 .36568 m .55576 .36374 L .55861 .365 L F
.55628 .36568 m .55438 .36626 L .55576 .36374 L F
.643 .516 .693 r
.55793 .36186 m .55861 .365 L .55576 .36374 L F
.871 .705 .673 r
.32845 .6594 m .33189 .65609 L .32676 .65543 L F
.801 .68 .731 r
.33042 .66052 m .33189 .65609 L .32845 .6594 L F
.672 .701 .868 r
.5543 .3611 m .55049 .35857 L .55264 .35682 L F
.675 .705 .87 r
.55675 .35842 m .5543 .3611 L .55264 .35682 L F
.631 .631 .832 r
.55675 .35842 m .55793 .36186 L .5543 .3611 L F
.79 .669 .73 r
.41203 .55434 m .41432 .55831 L .40924 .5575 L F
0 .533 .755 r
.41238 .558 m .41186 .55784 L .41076 .55774 L F
.41432 .55831 m .41186 .55784 L .41238 .558 L F
.722 .983 .782 r
.41294 .55565 m .41086 .55753 L .41186 .55784 L F
0 .533 .755 r
.41076 .55774 m .41186 .55784 L .40924 .5575 L F
.781 .471 .463 r
.41186 .55784 m .40641 .5591 L .40924 .5575 L F
.41186 .55784 m .40724 .56083 L .40641 .5591 L F
.722 .983 .782 r
.41086 .55753 m .40724 .56083 L .41186 .55784 L F
.601 .362 .527 r
.41085 .56127 m .41361 .56109 L .41432 .55831 L F
.732 .704 .824 r
.41361 .56109 m .41518 .55874 L .41432 .55831 L F
.463 0 0 r
.41518 .55874 m .41186 .55784 L .41432 .55831 L F
.41518 .55874 m .41443 .55918 L .41186 .55784 L F
.722 .983 .782 r
.41394 .55802 m .41186 .55784 L .41443 .55918 L F
.41294 .55565 m .41186 .55784 L .41394 .55802 L F
.622 .288 .384 r
.5665 .38562 m .56208 .38701 L .56257 .38365 L F
0 0 .354 r
.56738 .38821 m .56672 .38444 L .56745 .38505 L F
.56672 .38444 m .56648 .38307 L .56683 .3838 L F
.622 .288 .384 r
.56751 .38612 m .56727 .386 L .56648 .38307 L F
0 0 .354 r
.56672 .38444 m .56683 .3838 L .56745 .38505 L F
.56672 .38444 m .56711 .3854 L .56648 .38307 L F
.56738 .38821 m .5675 .38665 L .56732 .38615 L F
.5671 .3866 m .56732 .38615 L .56729 .38606 L F
.56738 .38821 m .56732 .38615 L .5671 .3866 L F
.5671 .3866 m .56729 .38606 L .56689 .38543 L F
.622 .288 .384 r
.56638 .38631 m .56208 .38701 L .5665 .38562 L F
.004 0 0 r
.56434 .38624 m .56208 .38701 L .56732 .38615 L F
.622 .288 .384 r
.56732 .38615 m .56638 .38631 L .56727 .386 L F
.004 0 0 r
.56434 .38624 m .56732 .38615 L .56733 .38613 L F
.622 .288 .384 r
.56727 .386 m .56638 .38631 L .5665 .38562 L F
0 0 .417 r
.56751 .38642 m .56434 .38624 L .56733 .38613 L F
.622 .288 .384 r
.56751 .38612 m .56732 .38615 L .56727 .386 L F
.004 0 0 r
.56733 .38613 m .56732 .38615 L .56751 .38612 L F
0 0 .417 r
.56751 .38642 m .56733 .38613 L .56751 .38612 L F
0 0 .354 r
.56689 .38543 m .56729 .38606 L .56672 .38444 L F
.622 .288 .384 r
.56727 .386 m .56257 .38365 L .56648 .38307 L F
0 0 .354 r
.56711 .3854 m .56751 .38642 L .56648 .38307 L F
.5675 .38665 m .56751 .38642 L .56672 .38444 L F
.864 .801 .786 r
.32571 .66287 m .33042 .66052 L .32845 .6594 L F
.682 .459 .577 r
.60347 .38841 m .60381 .39187 L .59993 .39102 L F
.711 .583 .71 r
.36667 .57127 m .3679 .57524 L .36456 .57457 L F
.708 .819 .364 r
.36442 .57451 m .36456 .57457 L .3679 .57524 L F
.175 .465 .888 r
.3679 .57524 m .36879 .57354 L .36442 .57451 L F
.3679 .57524 m .37006 .57565 L .36879 .57354 L F
.714 .939 .959 r
.49837 .46807 m .49604 .46962 L .49751 .47039 L F
.611 .236 .307 r
.3219 .62102 m .32322 .61706 L .31942 .61884 L F
.481 .239 .47 r
.32647 .62096 m .32322 .61706 L .3219 .62102 L F
.32647 .62096 m .3275 .6183 L .32322 .61706 L F
.676 .765 .917 r
.38085 .56153 m .38321 .56459 L .37867 .56361 L F
.557 .714 .945 r
.38569 .56334 m .38321 .56459 L .38085 .56153 L F
.751 .753 .854 r
.32271 .66627 m .32786 .66443 L .32571 .66287 L F
.852 .852 .841 r
.44653 .49452 m .44198 .49654 L .44461 .49293 L F
.847 .799 .804 r
.44888 .49096 m .44653 .49452 L .44461 .49293 L F
.65 .797 .953 r
.31624 .66606 m .32043 .6666 L .31841 .66535 L F
.662 .8 .948 r
.32043 .6666 m .32152 .66295 L .31841 .66535 L F
.32043 .6666 m .32271 .66627 L .32152 .66295 L F
.813 .635 .662 r
.5501 .37461 m .54624 .37085 L .55059 .37176 L F
.708 .819 .364 r
.36442 .57451 m .36327 .5772 L .36456 .57457 L F
.825 .774 .804 r
.36195 .57075 m .36667 .57127 L .36467 .5673 L F
.66 .924 .628 r
.36667 .57127 m .36452 .57278 L .36672 .5704 L F
.52 .181 .334 r
.40256 .4792 m .40544 .47907 L .40642 .47607 L F
.438 .11 .311 r
.40544 .47907 m .4092 .47559 L .40642 .47607 L F
.229 .692 .946 r
.61268 .3735 m .61717 .37442 L .61422 .37482 L F
.615 .478 .672 r
.53858 .39742 m .54145 .39873 L .54085 .39545 L F
.684 .33 .369 r
.53858 .39742 m .54075 .40053 L .54145 .39873 L F
.615 .478 .672 r
.54085 .39545 m .54145 .39873 L .53858 .39742 L F
.684 .33 .369 r
.54145 .39873 m .54075 .40053 L .53858 .39742 L F
.254 0 .311 r
.49702 .41088 m .49768 .40864 L .50015 .40658 L F
.647 .109 0 r
.64641 .36008 m .64902 .36211 L .65023 .36109 L F
.633 .091 0 r
.64902 .36211 m .65311 .36317 L .65023 .36109 L F
.074 0 0 r
.62376 .37274 m .62732 .37142 L .6275 .37096 L F
0 0 0 r
.6275 .37096 m .62732 .37142 L .62967 .36981 L F
.878 .716 .677 r
.33464 .6422 m .33702 .64329 L .33523 .63931 L F
.9 .78 .72 r
.33272 .64575 m .33702 .64329 L .33464 .6422 L F
.33272 .64575 m .33615 .64642 L .33702 .64329 L F
.228 0 .126 r
.43744 .45651 m .4342 .45921 L .4368 .45827 L F
.4 .018 .194 r
.4368 .45827 m .43947 .45786 L .43744 .45651 L F
.368 .036 .265 r
.43744 .45651 m .43947 .45786 L .44014 .45579 L F
.702 .956 .69 r
.56915 .36366 m .57157 .36055 L .57286 .36164 L F
.363 0 .09 r
.3956 .49244 m .3914 .49552 L .39176 .49391 L F
.3956 .49244 m .39417 .49513 L .3914 .49552 L F
.54 .198 .337 r
.39831 .49211 m .39417 .49513 L .3956 .49244 L F
.664 .478 .624 r
.50085 .43191 m .50426 .43102 L .50235 .42908 L F
0 .2 .725 r
.50235 .42908 m .50426 .43102 L .50494 .43117 L F
.693 .972 .923 r
.50494 .43117 m .50532 .42949 L .50235 .42908 L F
.144 0 .191 r
.48201 .41595 m .4813 .41811 L .48414 .41484 L F
.171 0 .169 r
.49311 .40491 m .4949 .40411 L .49835 .39988 L F
.534 .405 .651 r
.49335 .40766 m .4949 .40411 L .49311 .40491 L F
.195 .719 .857 r
.53686 .42666 m .53282 .42669 L .53522 .42581 L F
.619 .928 .97 r
.53975 .42525 m .53686 .42666 L .53522 .42581 L F
.59 .309 .459 r
.49682 .42392 m .49971 .42438 L .50023 .41896 L F
.49682 .42392 m .49971 .42438 L .50023 .41896 L F
.271 .049 .382 r
.50023 .41896 m .49971 .42438 L .50191 .42301 L F
.50191 .42301 m .49971 .42438 L .50023 .41896 L F
0 0 0 r
.50196 .44215 m .50337 .44326 L .50226 .44014 L F
.809 .928 .913 r
.50095 .44489 m .5044 .44406 L .50337 .44326 L F
0 0 0 r
.50158 .44516 m .50095 .44489 L .50337 .44326 L F
.50155 .4452 m .50153 .44519 L .50158 .44516 L F
.581 .748 .956 r
.50177 .44506 m .50206 .44553 L .50126 .44537 L F
0 0 0 r
.50149 .44525 m .50147 .44524 L .50155 .4452 L F
.50151 .44513 m .50337 .44326 L .50196 .44215 L F
.50147 .44524 m .50095 .44489 L .50155 .4452 L F
.50155 .4452 m .50337 .44326 L .50151 .44513 L F
.50153 .44519 m .50095 .44489 L .50158 .44516 L F
.489 0 0 r
.49675 .44491 m .50095 .44489 L .50036 .44621 L F
0 0 0 r
.50036 .44621 m .50095 .44489 L .50144 .44522 L F
.50134 .44536 m .50144 .44522 L .50147 .44524 L F
.50036 .44621 m .50144 .44522 L .50134 .44536 L F
.798 .52 .518 r
.49819 .45109 m .50188 .44882 L .49819 .4482 L F
.599 .422 .613 r
.5019 .44911 m .50007 .44709 L .50206 .44553 L F
0 0 0 r
.50036 .44621 m .50147 .44524 L .50115 .44554 L F
.751 .461 .492 r
.50091 .44232 m .50095 .44489 L .49675 .44491 L F
0 .433 .824 r
.49675 .44491 m .49754 .44519 L .4979 .44469 L F
.49754 .44519 m .50036 .44621 L .4979 .44469 L F
.49675 .44491 m .4979 .44469 L .49591 .4465 L F
.751 .461 .492 r
.50091 .44232 m .49675 .44491 L .4966 .44187 L F
.727 .449 .506 r
.4966 .44187 m .49675 .44491 L .49288 .44388 L F
0 .161 .699 r
.49591 .4465 m .49684 .44925 L .49473 .4464 L F
.49591 .4465 m .49473 .4464 L .49288 .44388 L F
.519 0 0 r
.49684 .44925 m .4938 .45131 L .48811 .44836 L F
.49684 .44925 m .48811 .44836 L .49112 .4492 L F
.789 .637 .692 r
.49288 .44388 m .49684 .44925 L .49112 .4492 L F
.889 .973 .667 r
.49524 .44817 m .49684 .44925 L .49615 .44719 L F
.49524 .44817 m .49615 .44719 L .49591 .4465 L F
.999 .808 .515 r
.49524 .44817 m .49367 .45023 L .49446 .44901 L F
0 0 .431 r
.49378 .44503 m .49524 .44817 L .49591 .4465 L F
.341 .202 .543 r
.48811 .44836 m .48863 .44895 L .4865 .45442 L F
.48863 .44895 m .49176 .45252 L .48707 .45422 L F
.48863 .44895 m .48707 .45422 L .4865 .45442 L F
.218 0 .181 r
.4938 .45131 m .49176 .45252 L .48811 .44836 L F
.421 0 0 r
.48811 .44847 m .49112 .4492 L .48816 .44837 L F
.48811 .44847 m .48816 .44837 L .48811 .44836 L F
.341 .202 .543 r
.48811 .44836 m .48808 .44846 L .48808 .44846 L F
.48808 .44846 m .4865 .45442 L .48808 .44846 L F
.48808 .44846 m .4865 .45442 L .48704 .45249 L F
.48811 .44836 m .48704 .45249 L .48772 .44994 L F
.421 0 0 r
.48697 .4482 m .48808 .44846 L .48748 .45089 L F
.48697 .4482 m .48811 .44847 L .48811 .44836 L F
.584 .445 .657 r
.48985 .44439 m .48991 .44462 L .48811 .44847 L F
.48991 .44462 m .49112 .4492 L .48872 .44862 L F
.48991 .44462 m .48872 .44862 L .48811 .44847 L F
.48884 .44573 m .48811 .44847 L .48697 .4482 L F
.48985 .44439 m .48811 .44847 L .48884 .44573 L F
.341 .202 .543 r
.48772 .44994 m .48704 .45249 L .48748 .45089 L F
.789 .637 .692 r
.49288 .44388 m .49112 .4492 L .48985 .44439 L F
0 0 .431 r
.49378 .44503 m .4953 .44788 L .49524 .44817 L F
.999 .808 .515 r
.49524 .44817 m .49455 .44892 L .49562 .44744 L F
0 0 .431 r
.4953 .44788 m .49531 .4479 L .49524 .44817 L F
0 0 0 r
.49648 .44655 m .49591 .4465 L .49524 .44817 L F
.69 .453 .558 r
.4979 .44469 m .49524 .44817 L .49591 .4465 L F
.999 .808 .515 r
.49562 .44744 m .4953 .44787 L .49618 .44637 L F
.569 .264 .411 r
.49528 .44791 m .49367 .45023 L .49531 .4479 L F
.49262 .44906 m .49367 .45023 L .49528 .44791 L F
.999 .808 .515 r
.49455 .44892 m .49446 .44901 L .49539 .44775 L F
.49531 .44787 m .49539 .44775 L .49562 .44744 L F
.49455 .44892 m .49539 .44775 L .49531 .44787 L F
.4953 .44787 m .49446 .44901 L .49535 .44764 L F
.4953 .44787 m .49535 .44764 L .49618 .44637 L F
.698 .346 .376 r
.48908 .44653 m .49529 .44789 L .49378 .44503 L F
.49529 .44789 m .49531 .4479 L .4953 .44788 L F
.49529 .44789 m .4953 .44788 L .49378 .44503 L F
0 0 0 r
.4979 .44469 m .49591 .4465 L .49648 .44655 L F
0 .161 .699 r
.49591 .4465 m .49288 .44388 L .49675 .44491 L F
.727 .82 .922 r
.49378 .44503 m .49591 .4465 L .4979 .44469 L F
.49378 .44503 m .4979 .44469 L .49774 .44285 L F
.542 .841 .519 r
.49832 .44412 m .4979 .44469 L .49618 .44637 L F
.768 .581 .645 r
.50096 .43927 m .50091 .44232 L .4966 .44187 L F
.695 .435 .526 r
.49774 .44285 m .50126 .4451 L .50226 .44014 L F
.581 .748 .956 r
.50157 .44513 m .50126 .44537 L .5012 .44536 L F
.344 .501 .87 r
.49774 .44285 m .50036 .44621 L .50115 .44554 L F
.49774 .44285 m .49915 .44396 L .50126 .4451 L F
.49915 .44396 m .50115 .44554 L .5012 .44536 L F
.49915 .44396 m .5012 .44536 L .50126 .4451 L F
.599 .422 .613 r
.50007 .44709 m .4979 .44469 L .5012 .44536 L F
.50129 .44542 m .5012 .44536 L .50132 .44538 L F
.50007 .44709 m .5012 .44536 L .50129 .44542 L F
.581 .748 .956 r
.50126 .4451 m .5012 .44536 L .49871 .44486 L F
.50157 .44513 m .5012 .44536 L .50126 .4451 L F
0 0 0 r
.50115 .44554 m .50147 .44524 L .50149 .44525 L F
.344 .501 .87 r
.50126 .4451 m .50115 .44554 L .50149 .44525 L F
.581 .748 .956 r
.50147 .44524 m .50126 .44537 L .50167 .44506 L F
.695 .435 .526 r
.50126 .4451 m .50149 .44525 L .50151 .44513 L F
.50126 .4451 m .50151 .44513 L .50226 .44014 L F
.581 .748 .956 r
.50167 .44506 m .50157 .44513 L .4979 .44469 L F
.50157 .44513 m .49871 .44486 L .4979 .44469 L F
.542 .841 .519 r
.49921 .44319 m .4979 .44469 L .49832 .44412 L F
.599 .422 .613 r
.50007 .44709 m .50132 .44538 L .50206 .44553 L F
.581 .748 .956 r
.50177 .44506 m .50147 .44524 L .50167 .44506 L F
0 0 0 r
.50149 .44525 m .50155 .4452 L .50151 .44513 L F
.581 .748 .956 r
.50099 .44383 m .50177 .44506 L .50147 .44504 L F
.50089 .44386 m .50147 .44504 L .4979 .44469 L F
.50099 .44383 m .50147 .44504 L .50089 .44386 L F
.497 .829 .999 r
.50402 .44376 m .50365 .44409 L .50099 .44383 L F
.50365 .44409 m .50206 .44553 L .50177 .44506 L F
.50365 .44409 m .50177 .44506 L .50099 .44383 L F
.809 .928 .913 r
.5044 .44406 m .50534 .44384 L .50337 .44326 L F
.56 .639 .886 r
.50534 .44384 m .50605 .44017 L .50337 .44326 L F
.50534 .44384 m .50865 .44287 L .50605 .44017 L F
.351 .812 .929 r
.61984 .37282 m .62376 .37274 L .62089 .37422 L F
.73 .93 .593 r
.42066 .54732 m .42128 .54709 L .41973 .5492 L F
.649 .577 .761 r
.60381 .39187 m .60116 .39596 L .59993 .39102 L F
.721 .778 .898 r
.30178 .63334 m .30332 .63631 L .29894 .63584 L F
.766 .857 .917 r
.32152 .66295 m .32271 .66627 L .32571 .66287 L F
.519 .214 .389 r
.29384 .64571 m .29651 .64258 L .29418 .64339 L F
.29384 .64571 m .29642 .64524 L .29651 .64258 L F
.496 .31 .558 r
.29642 .64524 m .29936 .64193 L .29651 .64258 L F
.845 .664 .124 r
.629 .33288 m .62899 .3357 L .62933 .3357 L F
.422 .16 .41 r
.29129 .6464 m .29384 .64571 L .29418 .64339 L F
.287 .77 .681 r
.57475 .39398 m .57087 .39549 L .57253 .39469 L F
.766 .73 .819 r
.45004 .48613 m .45157 .48994 L .44715 .48935 L F
.752 .75 .85 r
.45157 .48994 m .44888 .49096 L .44715 .48935 L F
.758 .726 .823 r
.45434 .48675 m .45157 .48994 L .45004 .48613 L F
.502 .907 .82 r
.6246 .39482 m .6255 .39483 L .62786 .39353 L F
.758 .7 .796 r
.53501 .39038 m .5399 .39619 L .54072 .39407 L F
.883 .818 .78 r
.33404 .6496 m .33615 .64642 L .33272 .64575 L F
.695 .32 .334 r
.49001 .44028 m .48535 .44148 L .48545 .43875 L F
.49001 .44028 m .4899 .44183 L .48535 .44148 L F
.514 .25 .453 r
.49916 .39907 m .49835 .39988 L .49931 .39904 L F
.264 0 .049 r
.50113 .39856 m .49916 .39907 L .49931 .39904 L F
.50113 .39856 m .50203 .39824 L .49916 .39907 L F
.847 .799 .804 r
.44888 .49096 m .44461 .49293 L .44715 .48935 L F
.381 .781 .985 r
.64698 .33336 m .65051 .33308 L .65124 .33398 L F
.65124 .33398 m .65051 .33308 L .64698 .33336 L F
.66 .94 .964 r
.65124 .33398 m .65051 .33308 L .65274 .33168 L F
.65124 .33398 m .65051 .33308 L .65274 .33168 L F
.097 0 0 r
.47019 .43455 m .47459 .43191 L .4743 .43512 L F
.456 .257 .52 r
.47713 .43163 m .4743 .43512 L .47459 .43191 L F
0 0 0 r
.4949 .40411 m .49931 .39904 L .49835 .39988 L F
.082 0 .023 r
.49931 .39904 m .50007 .40155 L .50113 .39856 L F
.49931 .39904 m .49766 .40279 L .50007 .40155 L F
.729 .651 .772 r
.40098 .56787 m .39846 .5723 L .39747 .56802 L F
.183 0 0 r
.39846 .5723 m .40074 .57269 L .39788 .57343 L F
.40049 .57228 m .40276 .57225 L .40074 .57269 L F
.298 .787 .739 r
.40276 .57225 m .40308 .57193 L .40074 .57269 L F
0 0 0 r
.40093 .573 m .40074 .57269 L .40308 .57193 L F
.399 .57398 m .40074 .57269 L .40093 .573 L F
.183 0 0 r
.39846 .5723 m .40049 .57228 L .40074 .57269 L F
.681 .727 .885 r
.3023 .66369 m .30339 .65951 L .30074 .65953 L F
.3023 .66369 m .30519 .66284 L .30339 .65951 L F
.263 0 .248 r
.47007 .42883 m .46993 .42977 L .47317 .42585 L F
0 0 0 r
.47317 .42585 m .47404 .42624 L .4757 .42488 L F
.47317 .42585 m .46993 .42977 L .47404 .42624 L F
.565 .592 .839 r
.56106 .34369 m .56383 .34496 L .5659 .34411 L F
.652 .223 .216 r
.56383 .34496 m .56788 .34615 L .5659 .34411 L F
.696 .983 .852 r
.62241 .35464 m .6199 .35652 L .62068 .35714 L F
.62241 .35464 m .6199 .35652 L .62068 .35714 L F
.833 .964 .891 r
.51331 .45667 m .51256 .4598 L .51573 .457 L F
.51331 .45667 m .51147 .45875 L .51256 .4598 L F
.753 .663 .762 r
.41361 .56109 m .41504 .56493 L .4183 .56181 L F
.798 .824 .872 r
.46977 .47362 m .46538 .47491 L .46795 .47207 L F
.466 .123 .299 r
.39872 .49017 m .40109 .49177 L .39831 .49211 L F
.025 0 0 r
.47007 .42883 m .46608 .43143 L .46844 .42998 L F
0 0 0 r
.47007 .42883 m .47208 .42803 L .46993 .42977 L F
.47007 .42883 m .46844 .42998 L .47208 .42803 L F
.81 .48 0 r
.58146 .37505 m .58187 .37481 L .58163 .37271 L F
.58146 .37505 m .58257 .37731 L .58187 .37481 L F
.811 .897 .483 r
.58125 .38504 m .58011 .38632 L .58004 .38725 L F
.927 .875 .45 r
.58099 .38276 m .58011 .38632 L .58125 .38504 L F
.326 .811 .865 r
.51007 .40116 m .50894 .40099 L .5061 .40175 L F
.534 .924 .888 r
.51142 .39969 m .51007 .40116 L .51309 .40021 L F
.51142 .39969 m .50894 .40099 L .51007 .40116 L F
.568 .432 .656 r
.46176 .44799 m .457 .44992 L .45996 .44656 L F
.742 .424 .444 r
.39219 .54984 m .39442 .55244 L .397 .54705 L F
.469 .484 .791 r
.62229 .34704 m .62347 .34248 L .61986 .34624 L F
.62229 .34704 m .62482 .34673 L .62347 .34248 L F
.404 .403 .745 r
.41789 .54652 m .41582 .54327 L .41821 .54322 L F
.41927 .54513 m .41821 .54322 L .42121 .54317 L F
.41789 .54652 m .41821 .54322 L .41927 .54513 L F
.849 .42 0 r
.42 .54644 m .42128 .54709 L .42066 .54732 L F
.41909 .54524 m .41954 .54562 L .42 .54644 L F
.41954 .54562 m .42128 .54709 L .42 .54644 L F
.678 .388 .474 r
.42121 .54317 m .41909 .54524 L .41789 .54652 L F
.861 .912 .865 r
.4223 .54317 m .42128 .54709 L .41909 .54524 L F
.4223 .54317 m .42401 .54418 L .42128 .54709 L F
.747 .561 .643 r
.49146 .42889 m .4938 .42406 L .48971 .42501 L F
.608 .613 .831 r
.37466 .56229 m .37103 .56396 L .37108 .56034 L F
.418 0 0 r
.38587 .48474 m .38848 .48491 L .39031 .48318 L F
.44 0 0 r
.38848 .48491 m .39328 .48382 L .39031 .48318 L F
.888 .791 .747 r
.4349 .51342 m .43349 .50945 L .43558 .51086 L F
.4349 .51342 m .43128 .51306 L .43349 .50945 L F
.89 .774 .728 r
.4349 .51342 m .43042 .51556 L .43128 .51306 L F
.4349 .51342 m .43249 .51703 L .43042 .51556 L F
.551 .557 .814 r
.56031 .3574 m .55793 .36186 L .55675 .35842 L F
.56031 .3574 m .56068 .36144 L .55793 .36186 L F
.718 .564 .679 r
.56251 .36484 m .55793 .36186 L .56068 .36144 L F
.56251 .36484 m .55861 .365 L .55793 .36186 L F
.743 .836 .921 r
.3886 .57728 m .3923 .57719 L .39114 .57616 L F
.282 .73 .96 r
.3923 .57719 m .39372 .57626 L .39114 .57616 L F
.3923 .57719 m .39539 .57714 L .39372 .57626 L F
.864 .693 .668 r
.43383 .5438 m .43564 .54764 L .43665 .54495 L F
.684 .745 .898 r
.35858 .57987 m .36085 .57844 L .35648 .57767 L F
.411 .142 .392 r
.43999 .47211 m .43662 .47506 L .43738 .4731 L F
.732 .704 .824 r
.41361 .56109 m .4183 .56181 L .41518 .55874 L F
.507 .646 .919 r
.41518 .55874 m .4183 .56181 L .42049 .56065 L F
.509 .611 .889 r
.51472 .4227 m .51611 .41983 L .51314 .42079 L F
.51472 .4227 m .51742 .42283 L .51611 .41983 L F
.249 .296 .716 r
.51472 .4227 m .51611 .41983 L .51314 .42079 L F
.51472 .4227 m .51736 .42413 L .51611 .41983 L F
.096 0 0 r
.45665 .43745 m .45941 .43724 L .46035 .43509 L F
.181 0 .207 r
.45665 .43745 m .45885 .43952 L .45941 .43724 L F
.45665 .43745 m .45664 .4406 L .45885 .43952 L F
.125 .675 .757 r
.56536 .364 m .56871 .36362 L .56915 .36366 L F
.702 .956 .69 r
.56915 .36366 m .56871 .36362 L .57157 .36055 L F
.861 .749 .738 r
.43671 .50341 m .43815 .5074 L .43591 .50591 L F
.858 .8 .792 r
.43815 .5074 m .43349 .50945 L .43591 .50591 L F
.43815 .5074 m .43558 .51086 L .43349 .50945 L F
.785 .716 .787 r
.44061 .5042 m .43815 .5074 L .43671 .50341 L F
.382 .787 .983 r
.54475 .38427 m .54796 .38396 L .54879 .38484 L F
.788 .98 .905 r
.54879 .38484 m .54904 .38222 L .5515 .38262 L F
.54879 .38484 m .54796 .38396 L .54904 .38222 L F
.267 .756 .914 r
.54791 .41478 m .55277 .41492 L .55042 .41445 L F
.54791 .41478 m .55277 .41492 L .55042 .41445 L F
.964 .779 .605 r
.55129 .41148 m .55277 .41492 L .55042 .41445 L F
.59 .041 0 r
.55277 .41492 m .55313 .41589 L .55042 .41445 L F
0 0 0 r
.55547 .41856 m .55836 .41414 L .55774 .41666 L F
.498 .75 .985 r
.55277 .41492 m .55547 .41856 L .55617 .41789 L F
.59 .041 0 r
.55277 .41492 m .55617 .41789 L .55313 .41589 L F
.532 .371 .607 r
.29118 .64904 m .29384 .64571 L .29129 .6464 L F
0 0 0 r
.49009 .41012 m .49237 .40981 L .49335 .40766 L F
.49009 .41012 m .48907 .4128 L .49237 .40981 L F
.242 .739 .91 r
.36802 .56059 m .37108 .56034 L .37025 .55758 L F
.504 .651 .924 r
.37108 .56034 m .36802 .56059 L .37025 .55758 L F
.242 .739 .91 r
.36802 .56059 m .36576 .55997 L .37108 .56034 L F
0 0 0 r
.54594 .3827 m .54475 .38427 L .54735 .38055 L F
.648 .916 .979 r
.54594 .3827 m .54198 .38496 L .54475 .38427 L F
.047 0 0 r
.54198 .38496 m .54346 .38541 L .54475 .38427 L F
.54198 .38496 m .54077 .3863 L .54346 .38541 L F
.557 .515 .764 r
.54198 .38496 m .54475 .38427 L .54594 .3827 L F
.813 .635 .662 r
.5501 .37461 m .54598 .37385 L .54624 .37085 L F
.9 .86 .793 r
.51893 .41378 m .52073 .41583 L .52204 .41428 L F
.341 0 0 r
.51462 .41448 m .51253 .41373 L .51178 .41481 L F
.51462 .41448 m .51671 .41327 L .51253 .41373 L F
.59 .462 .674 r
.47865 .43844 m .47719 .44322 L .47637 .43961 L F
.47865 .43844 m .4801 .44233 L .47719 .44322 L F
.474 .287 .547 r
.4801 .44233 m .47716 .44545 L .47719 .44322 L F
.373 .43 .791 r
.29118 .64904 m .29331 .65432 L .29569 .65432 L F
.727 .769 .887 r
.29208 .65577 m .297 .65639 L .29482 .65465 L F
.293 0 .05 r
.29563 .65432 m .29331 .65432 L .29263 .65512 L F
.29482 .65465 m .29263 .65512 L .29208 .65577 L F
.29563 .65432 m .29263 .65512 L .29482 .65465 L F
.551 .73 .958 r
.29502 .65461 m .297 .65639 L .29929 .6556 L F
.293 0 .05 r
.29569 .65432 m .29492 .65463 L .29466 .65452 L F
.551 .73 .958 r
.29466 .65452 m .29482 .65465 L .29492 .65463 L F
.727 .769 .887 r
.29208 .65577 m .29482 .65465 L .29466 .65452 L F
.293 0 .05 r
.29569 .65432 m .29563 .65432 L .29476 .65467 L F
.29489 .65464 m .29476 .65467 L .29208 .65577 L F
.29569 .65432 m .29476 .65467 L .29489 .65464 L F
.373 .43 .791 r
.29118 .64904 m .29569 .65432 L .29383 .64814 L F
.355 .351 .717 r
.29383 .64814 m .29569 .65432 L .29692 .65334 L F
.61 .881 .991 r
.29569 .65432 m .29466 .65452 L .29692 .65334 L F
.551 .73 .958 r
.29466 .65452 m .29502 .65461 L .29692 .65334 L F
.29502 .65461 m .29929 .6556 L .29756 .65395 L F
.29502 .65461 m .29756 .65395 L .29692 .65334 L F
.293 0 .05 r
.29492 .65463 m .29208 .65577 L .29466 .65452 L F
.551 .73 .958 r
.29466 .65452 m .29492 .65463 L .29502 .65461 L F
.29482 .65465 m .297 .65639 L .29502 .65461 L F
.506 .787 .996 r
.55571 .42038 m .55375 .42231 L .55217 .42083 L F
.505 .83 .529 r
.55227 .42367 m .55375 .42231 L .55571 .42038 L F
.929 .607 .408 r
.36492 .48868 m .36494 .49125 L .36298 .49027 L F
.548 0 0 r
.36534 .48915 m .36493 .48935 L .36492 .48868 L F
.317 .779 .646 r
.36298 .49027 m .36753 .48808 L .36492 .48868 L F
.36395 .4898 m .36587 .48885 L .36753 .48808 L F
.36298 .49027 m .36357 .48998 L .36395 .4898 L F
.36357 .48998 m .36587 .48885 L .36395 .4898 L F
.548 0 0 r
.36665 .49063 m .36494 .49125 L .36493 .48935 L F
.36665 .49063 m .36493 .48935 L .36534 .48915 L F
.36665 .49063 m .36913 .49223 L .36494 .49125 L F
.679 .679 .843 r
.50479 .43829 m .50096 .43927 L .50067 .43641 L F
.957 .76 .595 r
.56251 .36484 m .56015 .36628 L .55861 .365 L F
.56251 .36484 m .56166 .3681 L .56015 .36628 L F
.647 .643 .832 r
.56536 .364 m .56251 .36484 L .56068 .36144 L F
.428 .18 .434 r
.55757 .39168 m .5574 .39413 L .56031 .39096 L F
.414 .858 .776 r
.62378 .33799 m .62249 .33801 L .62391 .33746 L F
.143 0 0 r
.59528 .4024 m .59753 .40261 L .59409 .40376 L F
.59528 .4024 m .59793 .40204 L .59753 .40261 L F
0 0 .104 r
.58803 .36749 m .58854 .36565 L .58856 .36272 L F
0 .144 .68 r
.58803 .36749 m .58979 .36821 L .58854 .36565 L F
.58803 .36749 m .5905 .36965 L .58979 .36821 L F
.723 .697 .824 r
.3389 .5111 m .34023 .51378 L .33758 .51328 L F
.739 .363 .339 r
.34023 .51378 m .33792 .51535 L .33758 .51328 L F
.242 .424 .842 r
.3389 .5111 m .34154 .51246 L .34023 .51378 L F
.549 .896 .667 r
.34154 .51246 m .33792 .51535 L .34023 .51378 L F
0 0 0 r
.60677 .34059 m .60838 .33981 L .6098 .34094 L F
.60677 .34059 m .6047 .34237 L .60838 .33981 L F
.477 .51 .813 r
.6047 .34237 m .60793 .34455 L .6058 .34215 L F
0 0 0 r
.6047 .34237 m .60451 .34253 L .60497 .34221 L F
.6047 .34237 m .60497 .34221 L .60838 .33981 L F
.477 .51 .813 r
.60251 .34281 m .60346 .34311 L .6047 .34237 L F
.60346 .34311 m .60793 .34455 L .6047 .34237 L F
.105 0 0 r
.60251 .34281 m .6047 .34237 L .60677 .34059 L F
.804 .712 .763 r
.60838 .33981 m .60497 .34221 L .60455 .34074 L F
.477 .51 .813 r
.60251 .34281 m .605 .34231 L .60455 .34074 L F
.804 .712 .763 r
.60497 .34221 m .60451 .34253 L .60455 .34074 L F
.477 .51 .813 r
.605 .34231 m .6058 .34215 L .60455 .34074 L F
.105 0 0 r
.60251 .34281 m .60451 .34253 L .6047 .34237 L F
.635 .431 .589 r
.48642 .4357 m .48545 .43875 L .48288 .43892 L F
.653 .868 .492 r
.48713 .43428 m .48642 .4357 L .48818 .43311 L F
.48818 .43311 m .48642 .4357 L .48713 .43428 L F
.846 .679 .143 r
.58935 .39158 m .58897 .39266 L .58944 .38915 L F
.58935 .39158 m .58928 .39429 L .58897 .39266 L F
.4 .117 .364 r
.43457 .47584 m .43093 .47965 L .43211 .47708 L F
.839 .971 .883 r
.47722 .48749 m .48003 .48749 L .48134 .48552 L F
.701 .347 .373 r
.5378 .35826 m .53894 .35772 L .53635 .35706 L F
.507 .646 .919 r
.41518 .55874 m .42049 .56065 L .42049 .55804 L F
.41518 .55874 m .42049 .55804 L .41883 .55975 L F
.952 .622 .361 r
.42049 .55804 m .42049 .56065 L .41883 .55975 L F
.838 .825 .835 r
.32893 .65238 m .33404 .6496 L .33179 .64814 L F
.883 .818 .78 r
.33404 .6496 m .33272 .64575 L .33179 .64814 L F
0 0 .091 r
.55774 .41666 m .55571 .42038 L .55547 .41856 L F
.506 .787 .996 r
.55571 .42038 m .55617 .41789 L .55547 .41856 L F
.462 .216 .454 r
.44291 .46913 m .43999 .47211 L .44013 .4697 L F
.482 .001 .036 r
.40565 .49005 m .40384 .49185 L .40109 .49177 L F
.582 .114 .107 r
.40565 .49005 m .40829 .49202 L .40384 .49185 L F
.529 .164 .291 r
.40834 .49001 m .40829 .49202 L .40565 .49005 L F
.809 .542 .534 r
.62347 .34248 m .62724 .34067 L .62507 .33821 L F
.62347 .34248 m .62759 .3436 L .62724 .34067 L F
.452 .367 .669 r
.54367 .39729 m .54085 .39545 L .54359 .39447 L F
.572 .415 .629 r
.54359 .39447 m .54085 .39545 L .54341 .39099 L F
.452 .367 .669 r
.54085 .39545 m .54367 .39729 L .54359 .39447 L F
.344 .002 .234 r
.41188 .4752 m .41522 .47255 L .41257 .47324 L F
.404 .824 .648 r
.51135 .3912 m .51311 .39003 L .51419 .38948 L F
0 0 0 r
.51135 .3912 m .51017 .39308 L .51311 .39003 L F
.905 .858 .785 r
.42358 .54047 m .42401 .54418 L .4223 .54317 L F
.815 .736 .778 r
.47501 .46658 m .47109 .4662 L .47386 .4627 L F
.809 .734 .781 r
.47765 .46312 m .47501 .46658 L .47386 .4627 L F
.56 .446 .68 r
.48278 .4414 m .47865 .43844 L .48288 .43892 L F
.48278 .4414 m .4801 .44233 L .47865 .43844 L F
.195 0 0 r
.45856 .45668 m .45773 .45784 L .45513 .45844 L F
.541 .445 .695 r
.46073 .45252 m .46102 .45613 L .45856 .45668 L F
.429 .021 .162 r
.46102 .45613 m .45773 .45784 L .45856 .45668 L F
.803 .747 .801 r
.47686 .45889 m .47765 .46312 L .47386 .4627 L F
.591 .463 .675 r
.48174 .45908 m .47765 .46312 L .47686 .45889 L F
.48174 .45908 m .48059 .46199 L .47765 .46312 L F
.222 .324 .758 r
.48051 .46518 m .47765 .46312 L .48059 .46199 L F
0 0 .195 r
.40638 .56978 m .40563 .56908 L .40805 .56743 L F
0 0 .044 r
.49819 .4482 m .49649 .4497 L .49559 .45195 L F
.816 .969 .901 r
.6446 .37568 m .64572 .3766 L .64881 .3739 L F
.293 0 0 r
.63353 .35566 m .62934 .35576 L .63088 .355 L F
.748 .877 .938 r
.37006 .57565 m .37458 .57529 L .3731 .57391 L F
.368 .547 .899 r
.37458 .57529 m .37574 .57315 L .3731 .57391 L F
.37458 .57529 m .37666 .57512 L .37574 .57315 L F
.954 .674 .467 r
.64328 .35231 m .64507 .35051 L .64294 .35031 L F
.64328 .35231 m .64517 .35403 L .64507 .35051 L F
0 0 .01 r
.5914 .3814 m .5916 .3817 L .59112 .37905 L F
.5914 .3814 m .59122 .38425 L .5916 .3817 L F
.615 .635 .847 r
.3089 .66486 m .31346 .66707 L .31185 .66544 L F
.704 .739 .879 r
.31346 .66707 m .31429 .66261 L .31185 .66544 L F
.31346 .66707 m .31624 .66606 L .31429 .66261 L F
.531 0 0 r
.55861 .365 m .56015 .36628 L .55628 .36568 L F
.57 .244 .378 r
.53231 .38862 m .53501 .39038 L .53442 .38844 L F
.35 .333 .7 r
.53231 .38862 m .5331 .39163 L .53501 .39038 L F
.57 .244 .378 r
.53231 .38862 m .53501 .39038 L .53442 .38844 L F
.757 .647 .74 r
.54072 .39407 m .54341 .39099 L .54272 .39159 L F
.229 .23 .653 r
.54313 .36553 m .5409 .36859 L .54062 .36344 L F
.433 .511 .839 r
.54313 .36553 m .54552 .3708 L .5409 .36859 L F
.714 .695 .831 r
.37867 .56361 m .37614 .56533 L .37466 .56229 L F
.793 .701 .763 r
.43895 .50002 m .44061 .5042 L .43671 .50341 L F
.313 0 .148 r
.39965 .4796 m .40112 .48143 L .40256 .4792 L F
.39965 .4796 m .39862 .48213 L .40112 .48143 L F
.354 .059 .319 r
.43105 .46221 m .43385 .46139 L .4342 .45921 L F
.448 .19 .43 r
.43385 .46139 m .4368 .45827 L .4342 .45921 L F
.303 0 .165 r
.42458 .46859 m .4279 .46605 L .42523 .46665 L F
.66 .467 .613 r
.50085 .43191 m .5017 .43441 L .50426 .43102 L F
.652 .463 .616 r
.50141 .4353 m .5017 .43441 L .50085 .43191 L F
.312 .15 .495 r
.51525 .40886 m .5176 .40376 L .51443 .4051 L F
0 .226 .702 r
.40063 .55961 m .39965 .55946 L .39829 .55901 L F
.40063 .55961 m .40191 .56095 L .39965 .55946 L F
.878 .911 .847 r
.50754 .44672 m .51016 .44668 L .50912 .44798 L F
.888 .654 .578 r
.40915 .5266 m .41043 .53044 L .4101 .52556 L F
.119 0 .204 r
.4734 .44527 m .47469 .4438 L .47303 .44588 L F
.523 .183 .333 r
.47716 .44545 m .47322 .44808 L .47303 .44588 L F
.98 .914 .618 r
.52267 .43467 m .52163 .43886 L .52086 .43756 L F
.635 .853 .473 r
.42788 .55823 m .42643 .55999 L .42637 .56026 L F
.956 .834 .683 r
.42788 .55823 m .42649 .55374 L .42646 .55496 L F
.42788 .55823 m .4285 .55436 L .42649 .55374 L F
.995 .814 .448 r
.42646 .55496 m .42643 .55999 L .42788 .55823 L F
.65 .937 .966 r
.38687 .57665 m .38604 .5786 L .3886 .57728 L F
.529 .818 .999 r
.38425 .57735 m .38604 .5786 L .38687 .57665 L F
.752 .995 .847 r
.46178 .44886 m .46188 .44759 L .4619 .44482 L F
.1 .618 .885 r
.48524 .45866 m .48733 .45942 L .48336 .45852 L F
.942 .786 .659 r
.48524 .45866 m .48733 .45942 L .48621 .46118 L F
.499 .803 .999 r
.4896 .45539 m .49026 .45583 L .48866 .45788 L F
.628 .944 .732 r
.49051 .45684 m .48767 .45914 L .48866 .45788 L F
.408 .826 .646 r
.49285 .45538 m .49051 .45684 L .48866 .45788 L F
.49285 .45538 m .48866 .45788 L .49219 .45709 L F
.499 .803 .999 r
.49026 .45583 m .49219 .45709 L .48866 .45788 L F
.628 .944 .732 r
.48767 .45914 m .48733 .45942 L .48866 .45788 L F
.594 .874 .993 r
.48866 .45788 m .48733 .45942 L .48524 .45866 L F
.758 .7 .796 r
.53501 .39038 m .54072 .39407 L .53808 .38985 L F
.617 .679 .886 r
.53808 .38985 m .54072 .39407 L .54272 .39159 L F
.755 .382 .348 r
.63747 .35422 m .63793 .35648 L .63353 .35566 L F
.702 .345 .369 r
.64351 .35663 m .63793 .35648 L .63747 .35422 L F
.722 .445 .506 r
.3914 .49552 m .38728 .49291 L .39176 .49391 L F
.743 .717 .186 r
.58966 .37438 m .58991 .37221 L .5905 .36965 L F
0 0 .372 r
.58966 .37438 m .59026 .37501 L .58991 .37221 L F
.58966 .37438 m .59099 .37691 L .59026 .37501 L F
.512 .115 .226 r
.31244 .62158 m .31527 .62137 L .31691 .6191 L F
.481 .173 .366 r
.31925 .62084 m .31691 .6191 L .31527 .62137 L F
.31925 .62084 m .31942 .61884 L .31691 .6191 L F
.654 .5 .662 r
.42497 .48298 m .42222 .48638 L .42223 .48362 L F
.523 .183 .333 r
.47716 .44545 m .47684 .44774 L .47322 .44808 L F
.474 .287 .547 r
.4801 .44233 m .47982 .44456 L .47716 .44545 L F
.36 .05 .298 r
.47982 .44456 m .47684 .44774 L .47716 .44545 L F
.511 .627 .902 r
.30519 .66284 m .3089 .66486 L .30768 .66224 L F
.534 .631 .893 r
.3089 .66486 m .31012 .6618 L .30768 .66224 L F
.3089 .66486 m .31185 .66544 L .31012 .6618 L F
.878 .58 .479 r
.32884 .62059 m .33158 .61876 L .32861 .61828 L F
.771 .394 .34 r
.32884 .62059 m .33223 .62012 L .33158 .61876 L F
.714 .634 .766 r
.33223 .62012 m .33344 .62208 L .33158 .61876 L F
.756 .399 0 r
.58968 .40165 m .58961 .4024 L .58877 .39975 L F
.58968 .40165 m .59065 .40433 L .58961 .4024 L F
.641 .095 0 r
.40191 .56095 m .40647 .56219 L .40399 .56319 L F
.225 .609 .952 r
.54781 .35672 m .55049 .35857 L .54809 .35787 L F
.906 .977 .695 r
.63593 .36324 m .6377 .35871 L .6391 .36074 L F
.63593 .36324 m .6351 .36296 L .6377 .35871 L F
.417 .036 .205 r
.51482 .44452 m .51778 .44414 L .51799 .44152 L F
.055 0 .143 r
.51799 .44152 m .51778 .44414 L .52053 .44069 L F
.916 .853 .766 r
.51079 .44463 m .51016 .44668 L .50754 .44672 L F
.405 0 0 r
.55232 .38957 m .54828 .38873 L .55289 .38834 L F
.55232 .38957 m .54943 .38944 L .54828 .38873 L F
.962 .783 .614 r
.5549 .40078 m .55237 .40379 L .55494 .40044 L F
.5549 .40078 m .55441 .40446 L .55237 .40379 L F
.44 .323 .624 r
.40529 .55442 m .40767 .55363 L .40546 .55139 L F
.614 .794 .968 r
.51869 .41385 m .52073 .41583 L .51893 .41378 L F
.446 .346 .648 r
.5537 .35379 m .55579 .35532 L .5558 .35284 L F
.782 .968 .92 r
.52563 .44734 m .53015 .44563 L .52857 .44428 L F
.52563 .44734 m .52678 .44758 L .53015 .44563 L F
.875 .907 .849 r
.52857 .44428 m .53015 .44563 L .53299 .44228 L F
.843 .956 .886 r
.51728 .45512 m .51331 .45667 L .51573 .457 L F
.538 .555 .82 r
.30519 .66284 m .30603 .66061 L .30339 .65951 L F
.30519 .66284 m .30768 .66224 L .30603 .66061 L F
.586 .389 .582 r
.35843 .56924 m .35671 .57165 L .35522 .56826 L F
0 0 .037 r
.50426 .43102 m .5017 .43441 L .50494 .43117 L F
.558 .616 .866 r
.53129 .42118 m .52912 .4223 L .52718 .41814 L F
.28 .035 .353 r
.52856 .42463 m .52912 .4223 L .53129 .42118 L F
.476 .884 .941 r
.51408 .39871 m .51142 .39969 L .51309 .40021 L F
.336 .06 .338 r
.50417 .39498 m .50686 .39597 L .50763 .39417 L F
.50417 .39498 m .50442 .39695 L .50686 .39597 L F
.793 .541 .556 r
.60222 .35225 m .60411 .35258 L .60369 .34995 L F
.67 .456 .587 r
.60369 .34995 m .60411 .35258 L .60833 .35032 L F
.556 .835 .493 r
.29383 .65999 m .297 .65639 L .29631 .65936 L F
.788 .527 .544 r
.29631 .65936 m .297 .65639 L .29208 .65577 L F
.822 .849 .869 r
.4285 .55436 m .43095 .54959 L .42649 .55374 L F
.4285 .55436 m .43277 .55094 L .43095 .54959 L F
.564 .677 .915 r
.6175 .34561 m .61938 .34199 L .61695 .34454 L F
.6175 .34561 m .61986 .34624 L .61938 .34199 L F
.963 .786 .615 r
.61179 .34165 m .61381 .3434 L .61441 .34067 L F
0 0 0 r
.56732 .39626 m .56878 .39577 L .57087 .39549 L F
.641 .095 0 r
.40191 .56095 m .40495 .56336 L .40647 .56219 L F
0 0 .264 r
.40705 .56097 m .40647 .56219 L .40495 .56336 L F
.67 .198 .122 r
.3275 .6183 m .32861 .61828 L .32624 .61649 L F
0 0 0 r
.55974 .40476 m .56243 .40068 L .56171 .40293 L F
0 0 .193 r
.56078 .40527 m .55974 .40476 L .56171 .40293 L F
0 0 .018 r
.56078 .40527 m .56171 .40293 L .5638 .40122 L F
.599 .814 .413 r
.56078 .40527 m .56243 .4028 L .56174 .4038 L F
0 0 .193 r
.56078 .40527 m .55967 .40698 L .55974 .40476 L F
.599 .814 .413 r
.56078 .40527 m .56174 .4038 L .55954 .40703 L F
0 0 .193 r
.56078 .40527 m .55965 .40756 L .55967 .40698 L F
.529 .922 .861 r
.36258 .56716 m .36048 .56751 L .36293 .56616 L F
.36258 .56716 m .36048 .56751 L .36293 .56616 L F
.437 .171 .412 r
.43057 .46526 m .43385 .46139 L .43105 .46221 L F
.917 .922 .802 r
.44586 .52225 m .44498 .52697 L .4475 .52329 L F
.918 .941 .803 r
.44861 .51845 m .4475 .52329 L .45039 .51991 L F
.44861 .51845 m .44586 .52225 L .4475 .52329 L F
.847 .841 .839 r
.43277 .55094 m .43368 .54618 L .43095 .54959 L F
.43277 .55094 m .43564 .54764 L .43368 .54618 L F
.4 .117 .364 r
.43457 .47584 m .4336 .47895 L .43093 .47965 L F
.343 .065 .339 r
.43591 .47797 m .43457 .47584 L .43662 .47506 L F
.43591 .47797 m .4336 .47895 L .43457 .47584 L F
.704 .472 .571 r
.48545 .43875 m .48278 .4414 L .48288 .43892 L F
.641 .505 .681 r
.40408 .54508 m .40358 .54732 L .40546 .5449 L F
.4046 .54283 m .40179 .54365 L .40358 .54732 L F
.72 .602 .724 r
.40438 .5484 m .40073 .54553 L .40327 .54563 L F
.40073 .54553 m .40015 .54508 L .40186 .54538 L F
.40073 .54553 m .40186 .54538 L .40327 .54563 L F
.641 .505 .681 r
.4046 .54283 m .40408 .54508 L .40616 .54401 L F
.40408 .54508 m .40546 .5449 L .40616 .54401 L F
.705 .695 .838 r
.40705 .53777 m .40624 .54293 L .40537 .53844 L F
.40705 .53777 m .40924 .54133 L .40624 .54293 L F
.587 .88 .993 r
.40772 .54221 m .4046 .54283 L .40616 .54401 L F
.613 .93 .699 r
.40616 .54401 m .40924 .54133 L .40772 .54221 L F
0 0 .212 r
.56513 .39726 m .56243 .40068 L .56177 .39729 L F
.56513 .39726 m .56466 .39967 L .56243 .40068 L F
0 0 0 r
.56243 .40068 m .56466 .39967 L .56171 .40293 L F
.524 .249 .439 r
.4153 .48631 m .41511 .48888 L .4135 .49032 L F
.536 .258 .441 r
.4153 .48631 m .41788 .48852 L .41511 .48888 L F
.572 .248 .381 r
.41793 .48652 m .41788 .48852 L .4153 .48631 L F
.889 .932 .841 r
.33758 .51328 m .33758 .51 L .3389 .5111 L F
.33758 .51328 m .33598 .5123 L .33758 .51 L F
.835 .53 0 r
.33758 .51328 m .33721 .51396 L .33598 .5123 L F
.33758 .51328 m .33792 .51535 L .33721 .51396 L F
0 0 0 r
.59008 .35188 m .59293 .35114 L .59441 .35057 L F
.371 .819 .691 r
.59441 .35057 m .59621 .34947 L .59733 .3508 L F
.539 0 0 r
.62759 .3436 m .63048 .34517 L .63144 .34454 L F
.875 .907 .849 r
.52857 .44428 m .53299 .44228 L .53127 .44071 L F
.764 .946 .939 r
.53629 .43943 m .53127 .44071 L .53299 .44228 L F
.733 .757 .872 r
.45281 .48467 m .45434 .48675 L .45004 .48613 L F
.745 .76 .865 r
.45598 .48406 m .45434 .48675 L .45281 .48467 L F
0 0 .406 r
.52086 .43756 m .52152 .43434 L .52178 .43401 L F
.965 .845 .673 r
.52158 .43304 m .52202 .4337 L .52178 .43401 L F
0 0 .402 r
.52158 .43304 m .52178 .43401 L .52191 .43248 L F
0 0 .406 r
.52152 .43434 m .52191 .43248 L .52178 .43401 L F
.965 .845 .673 r
.52202 .4337 m .52267 .43467 L .52178 .43401 L F
.98 .914 .618 r
.52267 .43467 m .52086 .43756 L .52178 .43401 L F
.748 .813 .903 r
.61938 .34199 m .61986 .34624 L .62347 .34248 L F
0 0 .136 r
.51881 .38364 m .5218 .37906 L .51966 .38114 L F
.933 .967 .688 r
.43729 .53494 m .43741 .53758 L .43958 .53368 L F
.789 .999 .832 r
.44269 .53059 m .44006 .53165 L .43958 .53368 L F
.813 .987 .724 r
.44006 .53165 m .43729 .53494 L .43958 .53368 L F
.788 .527 .544 r
.29631 .65936 m .29208 .65577 L .29383 .65999 L F
.706 .984 .881 r
.50607 .46327 m .50352 .46373 L .50253 .4658 L F
.728 .983 .774 r
.50352 .46373 m .50033 .46661 L .50253 .4658 L F
.529 .907 .74 r
.48174 .46747 m .48221 .46661 L .48514 .46602 L F
.856 .963 .631 r
.47829 .4686 m .478 .46965 L .47811 .46946 L F
.47829 .4686 m .47811 .46946 L .48051 .46518 L F
.902 .975 .681 r
.47858 .46645 m .47829 .4686 L .48051 .46518 L F
0 0 .52 r
.47858 .46645 m .47864 .46691 L .47829 .4686 L F
.47864 .46691 m .47887 .4687 L .47829 .4686 L F
.529 .907 .74 r
.48174 .46747 m .47812 .46958 L .48221 .46661 L F
.47812 .46958 m .47815 .46954 L .48221 .46661 L F
.47812 .46958 m .478 .46965 L .47815 .46954 L F
.095 0 .15 r
.478 .46965 m .47906 .47016 L .48221 .46661 L F
0 0 .52 r
.47887 .4687 m .47906 .47016 L .47853 .4691 L F
.47887 .4687 m .47853 .4691 L .47829 .4686 L F
0 0 0 r
.46285 .43346 m .46381 .43251 L .46035 .43509 L F
.133 0 0 r
.46285 .43346 m .46608 .43143 L .46381 .43251 L F
.453 .21 .454 r
.54075 .40053 m .54367 .39729 L .54145 .39873 L F
.54367 .39729 m .54075 .40053 L .54145 .39873 L F
.575 .247 .376 r
.53442 .38844 m .53501 .39038 L .53808 .38985 L F
.711 .614 .747 r
.49702 .41088 m .49809 .415 L .49447 .41475 L F
.085 0 0 r
.49809 .415 m .49559 .41692 L .49447 .41475 L F
.49809 .415 m .49682 .41673 L .49559 .41692 L F
.533 .527 .794 r
.49966 .40985 m .49809 .415 L .49702 .41088 L F
.49966 .40985 m .50248 .41544 L .49809 .415 L F
.587 .066 0 r
.50205 .41666 m .49809 .415 L .50248 .41544 L F
.50205 .41666 m .49682 .41673 L .49809 .415 L F
.55 .445 .687 r
.35404 .57741 m .35648 .57767 L .35622 .57495 L F
.556 .367 .581 r
.35382 .58114 m .35648 .57767 L .35404 .57741 L F
.55 .445 .687 r
.35404 .57741 m .35648 .57767 L .35622 .57495 L F
.651 .68 .864 r
.31624 .66606 m .31706 .66172 L .31429 .66261 L F
.31624 .66606 m .31841 .66535 L .31706 .66172 L F
.565 .592 .839 r
.56106 .34369 m .56226 .34555 L .56383 .34496 L F
.564 .588 .837 r
.56226 .34555 m .56559 .3476 L .56383 .34496 L F
.818 .871 .886 r
.41488 .55143 m .41203 .55434 L .41029 .5524 L F
.914 .83 .371 r
.57818 .35459 m .57856 .35768 L .57914 .35352 L F
.825 .732 .205 r
.57814 .35692 m .57856 .35768 L .57818 .35459 L F
.691 .559 .7 r
.465 .45532 m .46073 .45252 L .46484 .45239 L F
.697 .492 .605 r
.46792 .4524 m .465 .45532 L .46484 .45239 L F
.786 .353 .223 r
.50067 .43641 m .50226 .44014 L .50479 .43829 L F
.453 .371 .674 r
.50789 .44079 m .50479 .43829 L .50605 .44017 L F
.807 .841 .377 r
.51122 .44328 m .51044 .44474 L .51079 .44463 L F
.571 .939 .9 r
.50754 .44672 m .50902 .44487 L .51044 .44474 L F
0 .446 .765 r
.50997 .44485 m .51044 .44474 L .50902 .44487 L F
.284 0 0 r
.51274 .4453 m .51482 .44452 L .51044 .44474 L F
0 .446 .765 r
.51181 .44481 m .51274 .4453 L .51044 .44474 L F
.51181 .44481 m .51044 .44474 L .50997 .44485 L F
.916 .853 .766 r
.51079 .44463 m .51074 .44467 L .51044 .44474 L F
.51074 .44467 m .50754 .44672 L .51044 .44474 L F
0 .51 .709 r
.40595 .55711 m .40767 .55363 L .40529 .55442 L F
.254 0 .311 r
.49702 .41088 m .50015 .40658 L .49966 .40985 L F
0 0 0 r
.50015 .40658 m .50344 .40464 L .50239 .40637 L F
.343 .073 .352 r
.50248 .40913 m .50015 .40658 L .50239 .40637 L F
.50248 .40913 m .49966 .40985 L .50015 .40658 L F
.387 .219 .529 r
.4642 .44128 m .4619 .44482 L .46252 .44239 L F
.816 .969 .901 r
.6446 .37568 m .64881 .3739 L .64789 .37304 L F
.785 .955 .925 r
.64881 .3739 m .64989 .37087 L .64789 .37304 L F
.64881 .3739 m .65228 .37135 L .64989 .37087 L F
.674 .456 .582 r
.46792 .4524 m .46777 .4552 L .465 .45532 L F
.526 .414 .669 r
.47033 .44864 m .47029 .45158 L .46792 .4524 L F
.611 .46 .653 r
.47029 .45158 m .46777 .4552 L .46792 .4524 L F
.965 .69 .464 r
.43368 .54618 m .43564 .54764 L .43383 .5438 L F
0 .384 .777 r
.49419 .43733 m .49211 .43697 L .49035 .43507 L F
.49419 .43733 m .49556 .43843 L .49211 .43697 L F
.887 .737 .69 r
.48543 .4266 m .48971 .42501 L .48741 .42518 L F
.48543 .4266 m .48719 .42794 L .48971 .42501 L F
.795 .58 .609 r
.48719 .42794 m .49146 .42889 L .48971 .42501 L F
0 0 .082 r
.49046 .42224 m .48971 .42501 L .49 .42217 L F
.784 .997 .806 r
.49046 .42224 m .48741 .42518 L .48971 .42501 L F
.21 .006 .369 r
.49559 .41692 m .49242 .4185 L .49447 .41475 L F
.35 .825 .869 r
.53522 .42581 m .53282 .42669 L .53121 .42649 L F
0 .256 .756 r
.45996 .44656 m .46188 .44759 L .46176 .44799 L F
.28 .122 .481 r
.4619 .44482 m .46188 .44759 L .45996 .44656 L F
0 0 0 r
.53023 .36587 m .53199 .36511 L .53268 .36351 L F
.53268 .36351 m .5378 .35826 L .53164 .35994 L F
.53268 .36351 m .53487 .36239 L .5378 .35826 L F
.18 0 .137 r
.53199 .36511 m .53487 .36239 L .53268 .36351 L F
.728 .247 .104 r
.60311 .38239 m .60739 .38347 L .60472 .38096 L F
.712 .284 .231 r
.60472 .38096 m .60739 .38347 L .61005 .38369 L F
.728 .247 .104 r
.60311 .38239 m .60472 .38096 L .6072 .3798 L F
.351 .812 .929 r
.61984 .37282 m .62262 .3722 L .62376 .37274 L F
.034 0 0 r
.62262 .3722 m .62732 .37142 L .62376 .37274 L F
.495 .22 .426 r
.45011 .46303 m .44893 .46568 L .44587 .4662 L F
.339 .064 .341 r
.45139 .46466 m .45011 .46303 L .45201 .46201 L F
.45139 .46466 m .44893 .46568 L .45011 .46303 L F
.614 .794 .968 r
.51869 .41385 m .52359 .41213 L .51863 .41115 L F
.759 .752 .847 r
.53679 .41434 m .53828 .4183 L .53403 .41772 L F
0 .505 .712 r
.53403 .41772 m .53828 .4183 L .53695 .4181 L F
.615 .608 .821 r
.53976 .41375 m .53828 .4183 L .53679 .41434 L F
.53976 .41375 m .54131 .41738 L .53828 .4183 L F
.436 .868 .923 r
.53828 .4183 m .53988 .41695 L .53695 .4181 L F
.53828 .4183 m .54131 .41738 L .53988 .41695 L F
.849 .803 .805 r
.48677 .43079 m .48955 .4324 L .49146 .42889 L F
.896 .769 .714 r
.48818 .43311 m .48955 .4324 L .48677 .43079 L F
.44 0 0 r
.38848 .48491 m .39107 .48523 L .39328 .48382 L F
.12 0 0 r
.39328 .48382 m .39107 .48523 L .39531 .48395 L F
.135 0 0 r
.39328 .48382 m .39531 .48395 L .39599 .48313 L F
.343 0 0 r
.41767 .47168 m .42047 .47135 L .422 .46938 L F
.411 .007 .16 r
.42047 .47135 m .42458 .46859 L .422 .46938 L F
.437 .493 .819 r
.29929 .6556 m .30074 .65953 L .30339 .65951 L F
.498 .331 .585 r
.52323 .38715 m .52276 .3904 L .52103 .38795 L F
.716 .58 .701 r
.63642 .34711 m .63602 .3501 L .64146 .34912 L F
.401 0 0 r
.63602 .3501 m .63941 .3511 L .64146 .34912 L F
.805 .446 .376 r
.63941 .3511 m .64294 .35031 L .64146 .34912 L F
.714 .695 .831 r
.37867 .56361 m .37466 .56229 L .37725 .56122 L F
.673 .758 .915 r
.38085 .56153 m .37867 .56361 L .37725 .56122 L F
.947 .955 .727 r
.47557 .43756 m .47637 .43961 L .47442 .44057 L F
.475 .894 .891 r
.60788 .39869 m .61165 .39769 L .61074 .39778 L F
.277 .778 .767 r
.61074 .39778 m .61165 .39769 L .61436 .39686 L F
.206 0 .231 r
.45513 .45844 m .45432 .46134 L .45201 .46201 L F
.354 .041 .29 r
.45601 .46054 m .45513 .45844 L .45773 .45784 L F
.45601 .46054 m .45432 .46134 L .45513 .45844 L F
.764 .946 .939 r
.53629 .43943 m .53499 .43836 L .53127 .44071 L F
.905 .979 .791 r
.5365 .43646 m .53629 .43943 L .539 .4356 L F
.853 .957 .877 r
.5365 .43646 m .53499 .43836 L .53629 .43943 L F
.746 .527 .597 r
.42093 .53633 m .42522 .53621 L .42358 .54047 L F
.401 .136 .392 r
.44014 .45579 m .4428 .45505 L .44318 .45257 L F
.286 .041 .356 r
.44318 .45257 m .44512 .45397 L .44574 .45174 L F
.44318 .45257 m .4428 .45505 L .44512 .45397 L F
.386 0 0 r
.51869 .41385 m .51671 .41327 L .51462 .41448 L F
.647 .643 .832 r
.56536 .364 m .56068 .36144 L .56387 .36211 L F
.562 .58 .829 r
.56671 .35904 m .56536 .364 L .56387 .36211 L F
.56671 .35904 m .56871 .36362 L .56536 .364 L F
.229 .23 .653 r
.54313 .36553 m .54062 .36344 L .54302 .36293 L F
.618 .692 .896 r
.50113 .39856 m .50442 .39695 L .50203 .39824 L F
.50113 .39856 m .50405 .39874 L .50442 .39695 L F
.326 0 0 r
.50007 .40155 m .50405 .39874 L .50113 .39856 L F
.175 .345 .796 r
.56379 .37549 m .56039 .37321 L .56457 .37479 L F
.711 .775 .902 r
.56354 .3715 m .56457 .37479 L .56687 .37308 L F
.074 .071 .549 r
.56354 .3715 m .56379 .37549 L .56457 .37479 L F
.576 .594 .833 r
.56383 .34496 m .56559 .3476 L .56788 .34615 L F
.534 .405 .651 r
.49335 .40766 m .49626 .40742 L .4949 .40411 L F
0 0 0 r
.49335 .40766 m .49427 .40829 L .49626 .40742 L F
.49335 .40766 m .49237 .40981 L .49427 .40829 L F
.615 .273 .367 r
.56376 .38814 m .56659 .38904 L .56738 .38821 L F
.098 .115 .588 r
.56659 .38904 m .56751 .38642 L .56738 .38821 L F
.535 .557 .824 r
.55715 .38012 m .55609 .38424 L .55479 .38147 L F
.55715 .38012 m .55891 .38571 L .55609 .38424 L F
.577 .36 .549 r
.55609 .38424 m .55864 .38681 L .5561 .38709 L F
0 .526 .706 r
.3591 .55418 m .35722 .55401 L .35477 .5538 L F
.35477 .5538 m .35722 .55401 L .3591 .55418 L F
.702 .963 .942 r
.35976 .55228 m .35722 .55401 L .3591 .55418 L F
.35976 .55228 m .35722 .55401 L .3591 .55418 L F
.863 .726 .711 r
.33285 .63839 m .33523 .63931 L .33361 .63542 L F
.84 .676 .679 r
.33068 .64174 m .33523 .63931 L .33285 .63839 L F
.33068 .64174 m .33464 .6422 L .33523 .63931 L F
.714 .634 .766 r
.33223 .62012 m .33496 .62227 L .33344 .62208 L F
.875 .783 .756 r
.33042 .62464 m .33496 .62227 L .33223 .62012 L F
.33042 .62464 m .33303 .62552 L .33496 .62227 L F
.441 .458 .781 r
.54029 .38025 m .54177 .37589 L .54273 .37678 L F
.755 .619 .709 r
.54311 .37685 m .54358 .38003 L .54573 .37873 L F
.54177 .37589 m .54246 .37747 L .54311 .37685 L F
.54246 .37747 m .54358 .38003 L .54311 .37685 L F
.526 .881 .983 r
.54273 .37678 m .54448 .37556 L .54598 .37385 L F
.54448 .37556 m .5447 .3754 L .54491 .37515 L F
.54448 .37556 m .54491 .37515 L .54598 .37385 L F
.54273 .37678 m .54177 .37589 L .5447 .3754 L F
.502 .907 .82 r
.6246 .39482 m .62786 .39353 L .62756 .39361 L F
.51 .872 .64 r
.62786 .39353 m .63123 .39091 L .62963 .39188 L F
.505 .861 .615 r
.62756 .39361 m .62786 .39353 L .62963 .39188 L F
.968 .645 .292 r
.56706 .3789 m .5688 .38059 L .5682 .37738 L F
0 0 0 r
.5682 .37738 m .56964 .37539 L .5702 .37414 L F
.968 .645 .292 r
.5682 .37738 m .56706 .3789 L .56964 .37539 L F
.5682 .37738 m .5688 .38059 L .56706 .3789 L F
.852 .73 .729 r
.42234 .52578 m .42435 .52743 L .42359 .53022 L F
.825 .795 .824 r
.42518 .52251 m .42435 .52743 L .42234 .52578 L F
.42518 .52251 m .42716 .52403 L .42435 .52743 L F
.625 .758 .942 r
.56687 .37308 m .5702 .37414 L .57031 .37278 L F
.788 .768 .258 r
.5702 .37414 m .56964 .37539 L .57031 .37278 L F
.622 .852 .987 r
.54716 .38832 m .54695 .39091 L .54943 .38944 L F
.526 .382 .628 r
.54651 .39388 m .54943 .38944 L .54695 .39091 L F
.54651 .39388 m .54943 .38944 L .54695 .39091 L F
.17 .322 .776 r
.50636 .41894 m .50721 .41555 L .50411 .41648 L F
.375 0 .014 r
.51153 .41781 m .5092 .41985 L .50636 .41894 L F
.17 .322 .776 r
.50636 .41894 m .5092 .41985 L .50721 .41555 L F
.532 .371 .607 r
.29118 .64904 m .29383 .64814 L .29384 .64571 L F
.849 .998 .797 r
.539 .4356 m .5419 .4323 L .53958 .4331 L F
.843 .998 .819 r
.53958 .4331 m .5365 .43646 L .539 .4356 L F
.785 .984 .726 r
.5419 .4323 m .5446 .42921 L .54264 .43005 L F
.773 .996 .811 r
.53958 .4331 m .5419 .4323 L .54264 .43005 L F
.341 .789 .635 r
.51419 .38948 m .51553 .38873 L .51728 .38773 L F
.51419 .38948 m .51311 .39003 L .51553 .38873 L F
.852 .73 .729 r
.42234 .52578 m .42359 .53022 L .4198 .52955 L F
.836 .73 .747 r
.4198 .52955 m .42359 .53022 L .42116 .53366 L F
.092 0 0 r
.46035 .43509 m .46177 .43617 L .46285 .43346 L F
.46035 .43509 m .45941 .43724 L .46177 .43617 L F
0 0 0 r
.47404 .42624 m .46993 .42977 L .47208 .42803 L F
.341 .039 .299 r
.44587 .4662 m .44547 .46833 L .44291 .46913 L F
.496 .188 .373 r
.44893 .46568 m .44547 .46833 L .44587 .4662 L F
.583 .118 .117 r
.51044 .44474 m .51482 .44452 L .51122 .44328 L F
.383 .812 .965 r
.55322 .37703 m .55236 .37637 L .5503 .37741 L F
.928 .926 .786 r
.5515 .38262 m .55236 .37637 L .55479 .38147 L F
.5515 .38262 m .54904 .38222 L .55236 .37637 L F
.906 .81 .741 r
.40495 .56336 m .406 .56698 L .40705 .564 L F
0 0 .195 r
.40618 .56827 m .40805 .56743 L .406 .56698 L F
.40638 .56978 m .40696 .56897 L .40618 .56827 L F
.40696 .56897 m .40805 .56743 L .40618 .56827 L F
.446 .283 .565 r
.406 .56698 m .40886 .56892 L .40638 .56978 L F
.406 .56698 m .40886 .56892 L .40638 .56978 L F
0 0 .307 r
.40495 .56336 m .40629 .56777 L .406 .56698 L F
.811 .54 .527 r
.40508 .57003 m .40638 .56978 L .406 .56698 L F
.406 .56698 m .40638 .56978 L .40508 .57003 L F
.40508 .57003 m .406 .56698 L .40629 .56777 L F
.895 .754 .698 r
.40221 .5647 m .40629 .56777 L .40495 .56336 L F
.40082 .56538 m .40499 .56721 L .40221 .5647 L F
.40499 .56721 m .40629 .56777 L .40221 .5647 L F
.49 .162 .337 r
.40805 .56743 m .40705 .564 L .406 .56698 L F
.182 .625 .942 r
.35214 .57175 m .35361 .5711 L .35053 .57109 L F
.35214 .57175 m .35501 .57209 L .35361 .5711 L F
.736 .674 .79 r
.41258 .53893 m .41586 .54137 L .4125 .54045 L F
.729 .385 .396 r
.41586 .54137 m .41142 .54287 L .4125 .54045 L F
.41586 .54137 m .41582 .54327 L .41142 .54287 L F
.763 .668 .758 r
.41671 .53797 m .41586 .54137 L .41258 .53893 L F
.736 .69 .807 r
.35648 .57767 m .36085 .57844 L .35981 .57285 L F
.695 .634 .784 r
.36085 .57844 m .36175 .5737 L .35981 .57285 L F
.36085 .57844 m .36327 .5772 L .36175 .5737 L F
.704 .472 .571 r
.48545 .43875 m .48535 .44148 L .48278 .4414 L F
.646 .95 .732 r
.54264 .43005 m .5446 .42921 L .54652 .42729 L F
.9 .928 .547 r
.52276 .43098 m .52158 .43304 L .52215 .43052 L F
.854 .97 .87 r
.52435 .42699 m .52276 .43098 L .52215 .43052 L F
.52435 .42699 m .52612 .42752 L .52276 .43098 L F
.619 .928 .97 r
.53975 .42525 m .53522 .42581 L .53823 .42449 L F
.531 .876 .988 r
.54245 .42433 m .53975 .42525 L .53823 .42449 L F
.345 .149 .465 r
.30178 .63334 m .29894 .63584 L .30125 .63432 L F
.473 .369 .656 r
.29894 .63584 m .30163 .63837 L .30125 .63432 L F
.843 .956 .886 r
.51728 .45512 m .51612 .454 L .51331 .45667 L F
.815 .953 .908 r
.51953 .45114 m .51728 .45512 L .52042 .45191 L F
.51953 .45114 m .51612 .454 L .51728 .45512 L F
.89 .523 .051 r
.57809 .36036 m .57987 .36309 L .5782 .35984 L F
0 .047 .59 r
.57809 .36036 m .58252 .36565 L .57987 .36309 L F
0 .077 .617 r
.57987 .36309 m .58252 .36565 L .58325 .36701 L F
.379 .145 .428 r
.48278 .4414 m .47982 .44456 L .4801 .44233 L F
.69 .456 .563 r
.4135 .49032 m .40829 .49202 L .40834 .49001 L F
.892 .926 .835 r
.41796 .53686 m .41671 .53797 L .41654 .53555 L F
.846 .928 .883 r
.42116 .53366 m .41796 .53686 L .41654 .53555 L F
.639 .775 .946 r
.42093 .53633 m .41796 .53686 L .42116 .53366 L F
.345 0 0 r
.63189 .34948 m .63501 .35049 L .63602 .3501 L F
.287 0 0 r
.63602 .3501 m .63501 .35049 L .63941 .3511 L F
.959 .941 .712 r
.44348 .52584 m .44269 .53059 L .44498 .52697 L F
.917 .922 .802 r
.44586 .52225 m .44348 .52584 L .44498 .52697 L F
.791 .658 .716 r
.46538 .47491 m .46101 .47511 L .46407 .47109 L F
.46538 .47491 m .46294 .47649 L .46101 .47511 L F
.677 .657 .822 r
.46795 .47207 m .46538 .47491 L .46407 .47109 L F
.602 .643 .863 r
.54359 .39447 m .54483 .38985 L .54272 .39159 L F
.54359 .39447 m .54651 .39388 L .54483 .38985 L F
.439 .207 .464 r
.54651 .39388 m .54367 .39729 L .54359 .39447 L F
.54651 .39388 m .54367 .39729 L .54359 .39447 L F
.883 .829 .788 r
.43249 .51703 m .42812 .51923 L .43042 .51556 L F
.43249 .51703 m .43017 .52051 L .42812 .51923 L F
.627 .475 .656 r
.5561 .38709 m .55232 .38957 L .55289 .38834 L F
.932 .893 .768 r
.55441 .40446 m .55121 .4064 L .55237 .40379 L F
.55441 .40446 m .55286 .40751 L .55121 .4064 L F
.438 .11 .311 r
.40544 .47907 m .40828 .47856 L .4092 .47559 L F
.321 0 .186 r
.40828 .47856 m .41188 .4752 L .4092 .47559 L F
.707 .792 .917 r
.55264 .35682 m .55049 .35857 L .54781 .35672 L F
0 .51 .709 r
.40595 .55711 m .40504 .55699 L .40767 .55363 L F
.40595 .55711 m .40924 .5575 L .40504 .55699 L F
.655 .472 .624 r
.51216 .41175 m .51791 .413 L .51525 .40886 L F
.51525 .40886 m .51791 .413 L .51216 .41175 L F
.312 .15 .495 r
.51525 .40886 m .51754 .40744 L .5176 .40376 L F
.446 .398 .711 r
.51754 .40744 m .51791 .413 L .51525 .40886 L F
.51754 .40744 m .51791 .413 L .51525 .40886 L F
.72 .977 .92 r
.54624 .37085 m .54818 .36671 L .54735 .36795 L F
.54624 .37085 m .54552 .3708 L .54725 .36895 L F
.983 .8 .579 r
.54624 .37085 m .54598 .37385 L .54552 .3708 L F
.54 .273 .46 r
.3996 .54387 m .40179 .54365 L .40219 .54074 L F
.517 .254 .454 r
.40219 .54074 m .40179 .54365 L .4046 .54283 L F
.668 .48 .622 r
.50141 .4353 m .50067 .43641 L .5017 .43441 L F
.291 .788 .861 r
.61701 .39584 m .6216 .39548 L .61991 .39478 L F
.392 .826 .955 r
.6216 .39548 m .62283 .39404 L .61991 .39478 L F
.6216 .39548 m .6246 .39482 L .62283 .39404 L F
.914 .83 .371 r
.57818 .35459 m .57914 .35352 L .57613 .352 L F
.949 .956 .687 r
.43741 .53758 m .43519 .53903 L .43629 .54004 L F
.919 .877 .779 r
.43195 .54255 m .43629 .54004 L .43519 .53903 L F
.43195 .54255 m .43383 .5438 L .43629 .54004 L F
.358 .027 .26 r
.56031 .39096 m .56299 .39026 L .56376 .38814 L F
.615 .273 .367 r
.56376 .38814 m .56299 .39026 L .56659 .38904 L F
.35 .035 .283 r
.45386 .46381 m .45201 .46201 L .45432 .46134 L F
.45386 .46381 m .45139 .46466 L .45201 .46201 L F
.561 .923 .755 r
.57657 .39225 m .57475 .39398 L .57875 .39138 L F
.698 .742 .234 r
.57948 .38885 m .57875 .39138 L .58004 .38725 L F
.825 .996 .766 r
.57948 .38885 m .57657 .39225 L .57875 .39138 L F
.384 .604 .935 r
.38188 .57732 m .38288 .57532 L .37978 .57595 L F
.38188 .57732 m .38425 .57735 L .38288 .57532 L F
.931 .969 .697 r
.43729 .53494 m .43519 .53903 L .43741 .53758 L F
.749 .953 .642 r
.47713 .43163 m .47968 .42854 L .47819 .42937 L F
.474 .232 .466 r
.47988 .43098 m .47968 .42854 L .47713 .43163 L F
.549 .298 .487 r
.47988 .43098 m .48306 .42783 L .47968 .42854 L F
.155 .692 .706 r
.47968 .42854 m .48087 .42825 L .47819 .42937 L F
.47968 .42854 m .48306 .42783 L .48087 .42825 L F
.657 .698 .876 r
.31012 .6618 m .31185 .66544 L .31429 .66261 L F
.441 .458 .781 r
.54029 .38025 m .54358 .38003 L .54177 .37589 L F
.97 .882 .689 r
.55286 .40751 m .55004 .40981 L .55121 .4064 L F
.55286 .40751 m .55129 .41148 L .55004 .40981 L F
.91 .981 .771 r
.46533 .49817 m .46516 .49992 L .46676 .49867 L F
.866 .993 .819 r
.46818 .49485 m .46676 .49867 L .46911 .4953 L F
.46818 .49485 m .46533 .49817 L .46676 .49867 L F
.747 .639 .74 r
.48336 .45852 m .48059 .46199 L .48174 .45908 L F
.195 0 .267 r
.48326 .46058 m .48059 .46199 L .48336 .45852 L F
.308 .128 .467 r
.48326 .46058 m .48051 .46518 L .48059 .46199 L F
.341 .012 .253 r
.44014 .45579 m .43947 .45786 L .4428 .45505 L F
0 0 0 r
.50531 .40305 m .50344 .40464 L .5061 .40175 L F
.50239 .40637 m .50344 .40464 L .50531 .40305 L F
.611 .478 .675 r
.42012 .56885 m .41884 .57183 L .42021 .56777 L F
.661 .522 .683 r
.42214 .56768 m .42012 .56885 L .42021 .56777 L F
.547 .309 .506 r
.42214 .56768 m .42146 .57008 L .42012 .56885 L F
.42214 .56768 m .42146 .57008 L .42012 .56885 L F
.42 .312 .626 r
.42021 .56777 m .42146 .57008 L .42012 .56885 L F
.474 .335 .612 r
.42021 .56777 m .41884 .57183 L .42146 .57008 L F
.743 .622 .725 r
.48303 .45627 m .48336 .45852 L .48174 .45908 L F
.435 .28 .57 r
.48576 .45525 m .48336 .45852 L .48303 .45627 L F
.48576 .45525 m .48524 .45866 L .48336 .45852 L F
.416 .093 .307 r
.48336 .45852 m .48524 .45866 L .48326 .46058 L F
.852 .81 .808 r
.54573 .37873 m .54735 .38055 L .5503 .37741 L F
.294 .527 .906 r
.5503 .37741 m .55149 .375 L .55048 .37635 L F
.5503 .37741 m .55236 .37637 L .55149 .375 L F
.849 .864 .852 r
.44861 .51845 m .45039 .51991 L .45322 .51665 L F
.855 .776 .774 r
.44715 .48935 m .44337 .48947 L .44544 .4877 L F
.44715 .48935 m .44461 .49293 L .44337 .48947 L F
.831 .863 .869 r
.45004 .48613 m .44715 .48935 L .44544 .4877 L F
.879 .537 .398 r
.64375 .35715 m .64423 .35974 L .64641 .36008 L F
.854 .467 .313 r
.64423 .35974 m .64479 .36195 L .64641 .36008 L F
.643 .186 .151 r
.64641 .36008 m .64479 .36195 L .64902 .36211 L F
.483 .217 .435 r
.43093 .47965 m .4307 .48224 L .42787 .48266 L F
.413 .161 .42 r
.43335 .48126 m .43093 .47965 L .4336 .47895 L F
.43335 .48126 m .4307 .48224 L .43093 .47965 L F
.213 .717 .903 r
.65611 .36235 m .65928 .3626 L .65763 .36268 L F
.666 .191 .113 r
.40924 .5575 m .40641 .5591 L .40504 .55699 L F
.264 .261 .668 r
.37106 .56027 m .37273 .55977 L .37025 .55758 L F
.37106 .56027 m .37273 .55977 L .37025 .55758 L F
.37108 .56034 m .37273 .55977 L .37106 .56027 L F
.337 .737 .982 r
.37102 .55866 m .37421 .55933 L .37273 .55977 L F
.37421 .55933 m .37533 .55956 L .37273 .55977 L F
.37102 .55866 m .37421 .55933 L .37273 .55977 L F
.37421 .55933 m .37533 .55956 L .37273 .55977 L F
.264 .261 .668 r
.37108 .56034 m .37273 .55977 L .37106 .56027 L F
.812 .729 .774 r
.41173 .53711 m .40924 .54133 L .40705 .53777 L F
.613 .102 .011 r
.40924 .54133 m .41142 .54287 L .40772 .54221 L F
.66 .526 .69 r
.41173 .53711 m .4125 .54045 L .40924 .54133 L F
.536 .221 .379 r
.4125 .54045 m .41142 .54287 L .40924 .54133 L F
.17 0 .043 r
.50836 .40117 m .5061 .40175 L .50894 .40099 L F
.50836 .40117 m .50531 .40305 L .5061 .40175 L F
.667 .346 .419 r
.4899 .44183 m .49422 .44151 L .49288 .44388 L F
.727 .449 .506 r
.4966 .44187 m .49288 .44388 L .49422 .44151 L F
.832 .794 .815 r
.43017 .52051 m .42716 .52403 L .42518 .52251 L F
.326 0 0 r
.50007 .40155 m .50296 .40131 L .50405 .39874 L F
0 0 .093 r
.50405 .39874 m .50686 .39597 L .50442 .39695 L F
.50405 .39874 m .50628 .39853 L .50686 .39597 L F
.505 .211 .401 r
.50296 .40131 m .50628 .39853 L .50405 .39874 L F
.07 .147 .638 r
.4949 .40411 m .49793 .40625 L .49766 .40279 L F
.4949 .40411 m .49626 .40742 L .49793 .40625 L F
.775 .495 .512 r
.52481 .37278 m .52407 .37588 L .52882 .37636 L F
.616 .896 .987 r
.3886 .57728 m .38924 .57524 L .38687 .57665 L F
.3886 .57728 m .39114 .57616 L .38924 .57524 L F
.274 .739 .948 r
.47019 .43455 m .4743 .43512 L .47334 .43429 L F
0 0 .446 r
.4743 .43512 m .47553 .43303 L .47334 .43429 L F
.4743 .43512 m .47519 .43551 L .47553 .43303 L F
.4743 .43512 m .47557 .43756 L .47519 .43551 L F
.654 .5 .662 r
.42497 .48298 m .4252 .48576 L .42222 .48638 L F
.656 .502 .662 r
.42787 .48266 m .4252 .48576 L .42497 .48298 L F
.849 .803 .805 r
.48677 .43079 m .49146 .42889 L .48719 .42794 L F
.701 .347 .373 r
.5378 .35826 m .53774 .35981 L .53894 .35772 L F
.442 .065 .226 r
.53894 .35772 m .53774 .35981 L .54159 .35876 L F
.437 .085 .269 r
.53894 .35772 m .54159 .35876 L .54166 .35697 L F
0 .124 .668 r
.60021 .36606 m .60181 .37009 L .60078 .36864 L F
.537 .229 .392 r
.4252 .48576 m .42211 .48903 L .42222 .48638 L F
.692 .373 .431 r
.42222 .48638 m .41788 .48852 L .41793 .48652 L F
.42222 .48638 m .42211 .48903 L .41788 .48852 L F
.825 .775 .805 r
.50605 .44017 m .50789 .44079 L .51067 .43858 L F
.698 .742 .234 r
.57948 .38885 m .58004 .38725 L .58011 .38632 L F
.812 .898 .903 r
.65228 .37135 m .65262 .36798 L .64989 .37087 L F
.65228 .37135 m .65396 .36941 L .65262 .36798 L F
.61 .947 .93 r
.60944 .34466 m .61381 .3434 L .61179 .34165 L F
.997 .804 .447 r
.58146 .37505 m .58228 .38004 L .58257 .37731 L F
.832 .794 .815 r
.43017 .52051 m .42518 .52251 L .42812 .51923 L F
.751 .643 .741 r
.4794 .45585 m .48174 .45908 L .47686 .45889 L F
.743 .622 .725 r
.48303 .45627 m .48174 .45908 L .4794 .45585 L F
.779 .994 .872 r
.507 .46088 m .50607 .46327 L .50778 .46137 L F
.507 .46088 m .50352 .46373 L .50607 .46327 L F
.65 .16 .075 r
.35933 .5718 m .35752 .57285 L .35981 .57285 L F
0 0 0 r
.36195 .57075 m .35752 .57285 L .35933 .5718 L F
.261 0 0 r
.36753 .48808 m .37022 .488 L .37251 .48655 L F
.246 0 0 r
.37251 .48655 m .37463 .48702 L .37497 .48606 L F
.695 .369 0 r
.60209 .36038 m .60251 .36129 L .60103 .36013 L F
.60209 .36038 m .60295 .36259 L .60251 .36129 L F
.203 .448 .871 r
.60209 .36038 m .60393 .36065 L .60295 .36259 L F
.134 0 0 r
.59976 .36035 m .60295 .36058 L .60209 .36038 L F
.60295 .36058 m .60393 .36065 L .60209 .36038 L F
.695 .369 0 r
.60209 .36038 m .60103 .36013 L .59899 .35853 L F
.842 .656 .651 r
.33272 .64575 m .33464 .6422 L .33068 .64174 L F
.714 .57 .691 r
.4063 .52995 m .41043 .53044 L .40915 .5266 L F
.691 .559 .7 r
.465 .45532 m .46102 .45613 L .46073 .45252 L F
.597 .648 .871 r
.31706 .66172 m .31841 .66535 L .32152 .66295 L F
.799 .83 .875 r
.64351 .35663 m .6377 .35871 L .63793 .35648 L F
.939 .846 .724 r
.64328 .35231 m .64167 .3558 L .64375 .35715 L F
.904 .556 .371 r
.64102 .35799 m .64375 .35715 L .64167 .3558 L F
.84 .785 .799 r
.64328 .35231 m .64375 .35715 L .64517 .35403 L F
.753 .677 .777 r
.48204 .45275 m .48303 .45627 L .4794 .45585 L F
.663 .623 .8 r
.48576 .45525 m .48303 .45627 L .48204 .45275 L F
.959 .941 .712 r
.44348 .52584 m .44164 .52967 L .44269 .53059 L F
.92 .964 .787 r
.44164 .52967 m .44006 .53165 L .44269 .53059 L F
.954 .693 .502 r
.33416 .62924 m .33303 .62552 L .33253 .62842 L F
.866 .664 .627 r
.33189 .6314 m .33416 .62924 L .33253 .62842 L F
.33189 .6314 m .3344 .63261 L .33416 .62924 L F
.908 .676 .576 r
.33042 .62464 m .33253 .62842 L .33303 .62552 L F
.614 .394 .559 r
.51093 .41411 m .51216 .41175 L .51015 .40989 L F
.51093 .41411 m .51178 .41481 L .51216 .41175 L F
.536 .776 .986 r
.51015 .40989 m .51216 .41175 L .51291 .40924 L F
.468 .667 .95 r
.5499 .41251 m .54791 .41478 L .55042 .41445 L F
.55042 .41445 m .54791 .41478 L .5499 .41251 L F
.812 .729 .774 r
.41173 .53711 m .40705 .53777 L .41006 .53752 L F
0 .078 .615 r
.41311 .53586 m .41173 .53711 L .41006 .53752 L F
.41311 .53586 m .41258 .53893 L .41173 .53711 L F
.736 .674 .79 r
.41258 .53893 m .4125 .54045 L .41173 .53711 L F
.982 .804 .399 r
.58325 .36701 m .58204 .36831 L .5829 .36968 L F
.975 .825 .414 r
.58252 .36565 m .58204 .36831 L .58325 .36701 L F
.147 .673 .874 r
.52857 .42746 m .52612 .42752 L .52435 .42699 L F
.839 .574 .537 r
.51313 .41796 m .5092 .41985 L .51153 .41781 L F
.034 0 0 r
.62262 .3722 m .62567 .37193 L .62732 .37142 L F
.806 .988 .728 r
.62732 .37142 m .62848 .36845 L .62967 .36981 L F
.62732 .37142 m .62567 .37193 L .62848 .36845 L F
.51 .535 .818 r
.36175 .5737 m .36327 .5772 L .36442 .57451 L F
.675 .705 .87 r
.55675 .35842 m .55264 .35682 L .55579 .35532 L F
.599 .677 .896 r
.55817 .35496 m .55675 .35842 L .55579 .35532 L F
.55817 .35496 m .56031 .3574 L .55675 .35842 L F
.287 .77 .681 r
.57475 .39398 m .57475 .39394 L .57087 .39549 L F
.498 .832 .542 r
.57657 .39225 m .57475 .39394 L .57475 .39398 L F
.469 .493 .8 r
.56288 .35873 m .56068 .36144 L .56031 .3574 L F
.476 .503 .807 r
.56288 .35873 m .56387 .36211 L .56068 .36144 L F
.839 .971 .883 r
.47722 .48749 m .48134 .48552 L .48022 .48438 L F
.877 .903 .845 r
.48022 .48438 m .48134 .48552 L .48416 .48223 L F
.271 .422 .831 r
.33966 .50863 m .3389 .5111 L .33758 .51 L F
.33966 .50863 m .34154 .51246 L .3389 .5111 L F
.421 .235 .522 r
.5176 .40376 m .51754 .40744 L .51986 .4036 L F
.229 .692 .946 r
.61268 .3735 m .61564 .37356 L .61717 .37442 L F
.269 .775 .809 r
.61564 .37356 m .61984 .37282 L .61717 .37442 L F
.465 .606 .907 r
.61927 .3554 m .6199 .35652 L .61668 .35702 L F
.61927 .3554 m .6199 .35652 L .61668 .35702 L F
.841 .671 .672 r
.48535 .44148 m .48725 .44513 L .48227 .44434 L F
.862 .651 .617 r
.48725 .44513 m .48281 .44748 L .48227 .44434 L F
.48725 .44513 m .48697 .4482 L .48281 .44748 L F
.741 .639 .747 r
.4899 .44183 m .48725 .44513 L .48535 .44148 L F
.465 .26 .516 r
.4899 .44183 m .48985 .44439 L .48725 .44513 L F
.584 .445 .657 r
.48985 .44439 m .48697 .4482 L .48725 .44513 L F
.462 .216 .454 r
.44291 .46913 m .44266 .47161 L .43999 .47211 L F
.472 .255 .502 r
.44547 .46833 m .44266 .47161 L .44291 .46913 L F
.725 .645 .769 r
.60251 .34281 m .60439 .34701 L .60594 .34491 L F
.891 .757 .256 r
.58897 .39266 m .58928 .39429 L .58893 .39693 L F
.411 .142 .392 r
.43999 .47211 m .44014 .47537 L .43662 .47506 L F
.623 .454 .633 r
.44014 .47537 m .43591 .47797 L .43662 .47506 L F
.888 .988 .797 r
.52022 .44993 m .52042 .45191 L .52364 .44908 L F
.52022 .44993 m .51953 .45114 L .52042 .45191 L F
0 0 0 r
.4757 .42488 m .4774 .42331 L .47863 .42173 L F
.58 .816 .43 r
.4813 .41811 m .47863 .42173 L .47986 .42003 L F
0 0 0 r
.47863 .42173 m .47957 .42215 L .47986 .42003 L F
.47863 .42173 m .4774 .42331 L .47957 .42215 L F
.818 .871 .886 r
.41488 .55143 m .41029 .5524 L .41297 .54955 L F
.731 .827 .924 r
.41437 .54971 m .41488 .55143 L .41297 .54955 L F
.429 .021 .162 r
.46102 .45613 m .46073 .45763 L .45773 .45784 L F
.755 .495 .539 r
.465 .45532 m .46073 .45763 L .46102 .45613 L F
.311 0 0 r
.54346 .38541 m .54796 .38396 L .54475 .38427 L F
.763 .668 .758 r
.41671 .53797 m .41258 .53893 L .41654 .53555 L F
.942 .786 .659 r
.48524 .45866 m .48621 .46118 L .48504 .45963 L F
.993 .876 .598 r
.48621 .46118 m .48397 .46475 L .48504 .45963 L F
.48621 .46118 m .48514 .46602 L .48397 .46475 L F
.575 .393 .598 r
.29383 .64814 m .29642 .64524 L .29384 .64571 L F
.917 .524 .228 r
.56166 .3681 m .56051 .36817 L .56015 .36628 L F
.56166 .3681 m .56283 .3703 L .56051 .36817 L F
.669 .967 .922 r
.52293 .37826 m .5218 .37906 L .52132 .37717 L F
.877 .903 .845 r
.48022 .48438 m .48416 .48223 L .48318 .48136 L F
.867 .973 .855 r
.48615 .47806 m .48416 .48223 L .48773 .4794 L F
.48615 .47806 m .48318 .48136 L .48416 .48223 L F
.195 0 .206 r
.62482 .34673 m .62759 .3436 L .62347 .34248 L F
.62482 .34673 m .62797 .34545 L .62759 .3436 L F
.58 .128 .145 r
.62759 .3436 m .62797 .34545 L .63048 .34517 L F
.869 .667 .628 r
.33042 .62464 m .33223 .62012 L .32884 .62059 L F
.534 .013 0 r
.42377 .56363 m .42355 .56357 L .42049 .56065 L F
.636 .897 .576 r
.42476 .56208 m .42377 .56363 L .42637 .56026 L F
.42476 .56208 m .42355 .56357 L .42377 .56363 L F
.853 .737 .735 r
.42116 .53366 m .41754 .53299 L .4198 .52955 L F
.846 .928 .883 r
.42116 .53366 m .41654 .53555 L .41754 .53299 L F
.575 .25 .381 r
.31925 .62084 m .3219 .62102 L .31942 .61884 L F
.714 .567 .687 r
.4063 .52995 m .40855 .53443 L .41043 .53044 L F
.804 .833 .873 r
.45926 .4822 m .45598 .48406 L .45747 .48361 L F
.525 .099 .174 r
.49589 .43894 m .50067 .43641 L .49556 .43843 L F
.49589 .43894 m .49781 .43959 L .50067 .43641 L F
.701 .312 .308 r
.49781 .43959 m .50226 .44014 L .50067 .43641 L F
.636 .897 .576 r
.42476 .56208 m .42637 .56026 L .42643 .55999 L F
0 0 0 r
.54594 .3827 m .54735 .38055 L .54573 .37873 L F
.839 .574 .537 r
.51313 .41796 m .51314 .42079 L .5092 .41985 L F
.567 .585 .831 r
.51178 .41481 m .51313 .41796 L .51583 .41718 L F
.51583 .41718 m .51313 .41796 L .51178 .41481 L F
0 0 .183 r
.51384 .41777 m .51313 .41796 L .51583 .41718 L F
.51384 .41777 m .51314 .42079 L .51313 .41796 L F
.188 .128 .553 r
.52935 .36986 m .53199 .36511 L .53023 .36587 L F
.52935 .36986 m .53223 .36789 L .53199 .36511 L F
.418 .47 .807 r
.53173 .37337 m .53223 .36789 L .52935 .36986 L F
.675 .961 .739 r
.63123 .39091 m .63451 .38798 L .63271 .38878 L F
.849 .864 .852 r
.44861 .51845 m .45322 .51665 L .45161 .51542 L F
.861 .909 .864 r
.45161 .51542 m .45322 .51665 L .45613 .5134 L F
.763 .734 .826 r
.44337 .48947 m .44461 .49293 L .44037 .49237 L F
.784 .688 .759 r
.44461 .49293 m .44198 .49654 L .44037 .49237 L F
.401 0 .111 r
.40256 .4792 m .40469 .48053 L .40544 .47907 L F
.40256 .4792 m .40112 .48143 L .40469 .48053 L F
.637 .851 .982 r
.54451 .37242 m .54598 .37385 L .54728 .37202 L F
.693 .571 .713 r
.5447 .3754 m .54728 .37202 L .54598 .37385 L F
.503 .208 .398 r
.44296 .47448 m .43999 .47211 L .44266 .47161 L F
.44296 .47448 m .44014 .47537 L .43999 .47211 L F
.491 .836 .559 r
.4757 .42488 m .47404 .42624 L .4774 .42331 L F
.82 .723 .757 r
.56138 .37975 m .55891 .38571 L .55715 .38012 L F
.909 .923 .813 r
.39372 .57626 m .39539 .57714 L .39788 .57343 L F
.791 .692 .755 r
.44198 .49654 m .43759 .49612 L .44037 .49237 L F
.789 .7 .766 r
.44198 .49654 m .43895 .50002 L .43759 .49612 L F
.667 .346 .419 r
.4899 .44183 m .49288 .44388 L .48985 .44439 L F
.205 0 0 r
.47846 .43251 m .47988 .43098 L .47713 .43163 L F
.47846 .43251 m .47713 .43163 L .47819 .42937 L F
.803 .516 .502 r
.38728 .49291 m .38282 .4949 L .38269 .49241 L F
.38728 .49291 m .38718 .49579 L .38282 .4949 L F
.722 .445 .506 r
.3914 .49552 m .38718 .49579 L .38728 .49291 L F
.836 .999 .786 r
.47101 .49151 m .46911 .4953 L .47242 .49257 L F
.47101 .49151 m .46818 .49485 L .46911 .4953 L F
.751 .581 .665 r
.40321 .53322 m .40855 .53443 L .4063 .52995 L F
.848 .85 .844 r
.32719 .65252 m .32893 .65238 L .32781 .64833 L F
.829 .841 .857 r
.32781 .64833 m .32893 .65238 L .33179 .64814 L F
.545 .367 .591 r
.42093 .53633 m .42147 .53978 L .41883 .53989 L F
.746 .527 .597 r
.42093 .53633 m .42358 .54047 L .42147 .53978 L F
.748 .888 .484 r
.58979 .38651 m .59004 .38561 L .59122 .38425 L F
.845 .898 .479 r
.59122 .38425 m .59004 .38561 L .5916 .3817 L F
0 0 0 r
.51881 .38364 m .51728 .38773 L .51854 .38545 L F
.51854 .38545 m .51972 .38396 L .51881 .38364 L F
.755 .495 .539 r
.465 .45532 m .46505 .45808 L .46073 .45763 L F
.7 .471 .574 r
.46777 .4552 m .46505 .45808 L .465 .45532 L F
0 0 0 r
.56031 .39096 m .5574 .39413 L .55937 .39256 L F
.212 0 .051 r
.56031 .39096 m .56265 .39141 L .56299 .39026 L F
.56031 .39096 m .55937 .39256 L .56265 .39141 L F
.966 .692 .462 r
.43174 .54512 m .43383 .5438 L .43195 .54255 L F
.43174 .54512 m .43368 .54618 L .43383 .5438 L F
.006 0 .06 r
.48414 .41484 m .4813 .41811 L .48346 .41667 L F
.394 .101 .344 r
.48346 .41667 m .48656 .41374 L .48414 .41484 L F
.778 .655 .726 r
.43482 .49926 m .43671 .50341 L .43236 .50266 L F
.794 .673 .73 r
.43671 .50341 m .43185 .50534 L .43236 .50266 L F
.43671 .50341 m .43591 .50591 L .43185 .50534 L F
.755 .645 .74 r
.43895 .50002 m .43671 .50341 L .43482 .49926 L F
.72 .628 .755 r
.45926 .4822 m .4557 .48276 L .45814 .47838 L F
.812 .738 .782 r
.46179 .47878 m .45926 .4822 L .45814 .47838 L F
.415 .516 .853 r
.35501 .57209 m .35622 .57495 L .35752 .57285 L F
.566 .457 .689 r
.35622 .57495 m .35981 .57285 L .35752 .57285 L F
.35622 .57495 m .35648 .57767 L .35981 .57285 L F
.796 .668 .723 r
.43591 .50591 m .43349 .50945 L .43185 .50534 L F
.705 .562 .69 r
.47336 .45026 m .47033 .44864 L .47322 .44808 L F
.578 .422 .633 r
.47684 .44774 m .47336 .45026 L .47322 .44808 L F
.415 .179 .446 r
.42787 .48266 m .42774 .48522 L .4252 .48576 L F
.323 .027 .298 r
.4307 .48224 m .42774 .48522 L .42787 .48266 L F
.824 .696 .723 r
.46179 .47878 m .46101 .47511 L .46294 .47649 L F
.46179 .47878 m .45814 .47838 L .46101 .47511 L F
.765 .395 .354 r
.55232 .38957 m .55065 .39286 L .54943 .38944 L F
.627 .475 .656 r
.5561 .38709 m .55574 .38942 L .55232 .38957 L F
.015 0 0 r
.55458 .38922 m .55232 .38957 L .55574 .38942 L F
.55458 .38922 m .55065 .39286 L .55232 .38957 L F
.537 .229 .392 r
.4252 .48576 m .42456 .48838 L .42211 .48903 L F
.431 .154 .391 r
.42774 .48522 m .42456 .48838 L .4252 .48576 L F
.032 0 0 r
.39788 .57343 m .399 .57398 L .39609 .57497 L F
.488 .86 .984 r
.39609 .57497 m .399 .57398 L .39866 .57383 L F
.909 .923 .813 r
.39475 .57556 m .39788 .57343 L .39609 .57497 L F
.488 .86 .984 r
.39609 .57497 m .39866 .57383 L .3972 .57319 L F
.909 .923 .813 r
.39372 .57626 m .39475 .57556 L .39609 .57497 L F
.032 0 0 r
.39788 .57343 m .40074 .57269 L .399 .57398 L F
.324 0 .221 r
.47986 .42003 m .48346 .41667 L .4813 .41811 L F
.741 .676 .787 r
.43759 .49612 m .43895 .50002 L .43482 .49926 L F
.183 0 .063 r
.41437 .47429 m .41522 .47255 L .41188 .4752 L F
.365 .021 .242 r
.41437 .47429 m .41767 .47168 L .41522 .47255 L F
.759 .681 .776 r
.50605 .44017 m .50865 .44287 L .50954 .4421 L F
.758 .976 .92 r
.52454 .44657 m .52364 .44908 L .52563 .44734 L F
.769 .984 .905 r
.52022 .44993 m .52364 .44908 L .52454 .44657 L F
.9 .902 .818 r
.48615 .47806 m .48773 .4794 L .4903 .47579 L F
.827 .397 .216 r
.50605 .44017 m .50954 .4421 L .50789 .44079 L F
.9 .902 .818 r
.48615 .47806 m .4903 .47579 L .48837 .47436 L F
.851 .843 .837 r
.48837 .47436 m .4903 .47579 L .49312 .47246 L F
.303 0 .165 r
.42458 .46859 m .42722 .46784 L .4279 .46605 L F
.469 .147 .338 r
.42722 .46784 m .43057 .46526 L .4279 .46605 L F
.39 .471 .823 r
.41518 .55874 m .41727 .55575 L .41443 .55918 L F
.41518 .55874 m .41883 .55975 L .41727 .55575 L F
0 .545 .714 r
.36576 .55997 m .36889 .56017 L .37108 .56034 L F
.658 .962 .929 r
.37108 .56034 m .37102 .55866 L .37273 .55977 L F
.37108 .56034 m .36889 .56017 L .37102 .55866 L F
.608 .613 .831 r
.37466 .56229 m .37108 .56034 L .37273 .55977 L F
.676 .918 .598 r
.41582 .54327 m .41883 .53989 L .42121 .54317 L F
.706 .589 .722 r
.42147 .53978 m .42121 .54317 L .41883 .53989 L F
.83 .722 .745 r
.4557 .48276 m .45107 .48119 L .45399 .47793 L F
.4557 .48276 m .45334 .48284 L .45107 .48119 L F
.783 .77 .841 r
.45814 .47838 m .4557 .48276 L .45399 .47793 L F
.621 .732 .926 r
.37725 .56122 m .37466 .56229 L .37273 .55977 L F
0 0 .148 r
.58834 .35601 m .58888 .35104 L .58744 .35329 L F
.557 .714 .945 r
.38569 .56334 m .38085 .56153 L .38402 .56076 L F
.499 .535 .825 r
.38659 .55955 m .38569 .56334 L .38402 .56076 L F
.38659 .55955 m .38822 .56356 L .38569 .56334 L F
.915 .972 .68 r
.63451 .38798 m .63671 .38398 L .6348 .38511 L F
.757 .99 .887 r
.63671 .38398 m .64019 .38127 L .63787 .38152 L F
.769 .976 .705 r
.6348 .38511 m .63671 .38398 L .63787 .38152 L F
.725 .645 .769 r
.60251 .34281 m .60594 .34491 L .60793 .34455 L F
.306 .793 .891 r
.60944 .34466 m .60793 .34455 L .60594 .34491 L F
.407 .194 .474 r
.51761 .39619 m .51557 .39734 L .51837 .39396 L F
0 0 .281 r
.5574 .39413 m .55872 .39471 L .55937 .39256 L F
.5574 .39413 m .55741 .39683 L .55872 .39471 L F
.687 .852 .962 r
.35831 .56602 m .36154 .56544 L .35622 .56325 L F
.863 .891 .465 r
.36318 .56067 m .36154 .56544 L .36185 .56252 L F
.184 0 .14 r
.36154 .56544 m .35831 .56602 L .36185 .56252 L F
.653 .868 .492 r
.48713 .43428 m .48818 .43311 L .48677 .43079 L F
.971 .656 .308 r
.48677 .43079 m .48713 .43428 L .48818 .43311 L F
.36 .05 .298 r
.47982 .44456 m .47977 .44736 L .47684 .44774 L F
.379 .145 .428 r
.48278 .4414 m .48227 .44434 L .47982 .44456 L F
0 0 .168 r
.48062 .44622 m .47982 .44456 L .48227 .44434 L F
.48062 .44622 m .47977 .44736 L .47982 .44456 L F
.82 .723 .757 r
.56138 .37975 m .55715 .38012 L .55992 .37872 L F
.74 .92 .952 r
.56138 .37975 m .55992 .37872 L .5634 .37699 L F
.7 .471 .574 r
.46777 .4552 m .46781 .45804 L .46505 .45808 L F
.611 .46 .653 r
.47029 .45158 m .4709 .45465 L .46777 .4552 L F
.689 .527 .662 r
.4709 .45465 m .46781 .45804 L .46777 .4552 L F
.705 .562 .69 r
.47336 .45026 m .47029 .45158 L .47033 .44864 L F
.828 .759 .787 r
.47386 .4627 m .46898 .4645 L .47146 .46112 L F
.47386 .4627 m .47109 .4662 L .46898 .4645 L F
.786 .718 .789 r
.47686 .45889 m .47386 .4627 L .47146 .46112 L F
.851 .693 .686 r
.33189 .6314 m .33361 .63542 L .3344 .63261 L F
.63 .533 .726 r
.40321 .53322 m .40705 .53777 L .40855 .53443 L F
.831 .863 .869 r
.45004 .48613 m .44544 .4877 L .44823 .48457 L F
.744 .835 .921 r
.45281 .48467 m .45004 .48613 L .44823 .48457 L F
0 .311 .769 r
.62482 .34673 m .62651 .34701 L .62797 .34545 L F
.62482 .34673 m .6283 .34863 L .62651 .34701 L F
.808 .737 .785 r
.47109 .4662 m .46877 .46936 L .46619 .46813 L F
.854 .687 .675 r
.46877 .46936 m .46795 .47207 L .46619 .46813 L F
.995 .841 .575 r
.55004 .40981 m .55129 .41148 L .55042 .41445 L F
.766 .857 .917 r
.32152 .66295 m .32571 .66287 L .32356 .66157 L F
.837 .793 .809 r
.32571 .66287 m .32623 .65797 L .32356 .66157 L F
.32571 .66287 m .32845 .6594 L .32623 .65797 L F
.8 .885 .462 r
.53597 .36851 m .53465 .37245 L .53767 .37116 L F
.53597 .36851 m .53432 .37229 L .53465 .37245 L F
.798 .548 .561 r
.60739 .38347 m .61149 .38412 L .61005 .38369 L F
.677 .196 .099 r
.60739 .38347 m .61006 .38565 L .61149 .38412 L F
0 0 0 r
.61149 .38412 m .61327 .38443 L .61454 .38299 L F
.61149 .38412 m .61006 .38565 L .61327 .38443 L F
.42 .213 .49 r
.61149 .38412 m .61454 .38299 L .6148 .38027 L F
.861 .909 .864 r
.45161 .51542 m .45613 .5134 L .45453 .51212 L F
.879 .903 .842 r
.45453 .51212 m .45613 .5134 L .45897 .50992 L F
.915 .975 .693 r
.63271 .38878 m .63451 .38798 L .6348 .38511 L F
.851 .843 .837 r
.48837 .47436 m .49312 .47246 L .49197 .47183 L F
.821 .992 .866 r
.49385 .46974 m .49312 .47246 L .49604 .46962 L F
.813 .987 .882 r
.49385 .46974 m .49197 .47183 L .49312 .47246 L F
.908 .737 .659 r
.39106 .55728 m .38884 .55665 L .38958 .55329 L F
.664 .47 .613 r
.38878 .55884 m .38884 .55665 L .39106 .55728 L F
0 0 .162 r
.39225 .55225 m .39106 .55728 L .38958 .55329 L F
.39225 .55225 m .39198 .55564 L .39106 .55728 L F
.58 .715 .935 r
.39433 .55899 m .39106 .55728 L .39198 .55564 L F
.39433 .55899 m .38878 .55884 L .39106 .55728 L F
.642 .457 .618 r
.47336 .45026 m .4709 .45465 L .47029 .45158 L F
.47336 .45026 m .47506 .45545 L .4709 .45465 L F
.578 .422 .633 r
.47684 .44774 m .47735 .45204 L .47336 .45026 L F
.635 .453 .62 r
.47705 .45399 m .47336 .45026 L .47735 .45204 L F
.47705 .45399 m .47506 .45545 L .47336 .45026 L F
.007 0 .093 r
.49559 .45195 m .49285 .45538 L .49513 .45346 L F
.331 0 .218 r
.49559 .45195 m .49845 .45213 L .49819 .45109 L F
.49559 .45195 m .49513 .45346 L .49845 .45213 L F
0 0 .044 r
.49819 .4482 m .49559 .45195 L .49819 .45109 L F
.517 .55 .829 r
.30603 .66061 m .30768 .66224 L .31012 .6618 L F
.76 .707 .802 r
.30339 .65951 m .30603 .66061 L .30611 .65832 L F
.573 .548 .789 r
.30611 .65832 m .30603 .66061 L .30882 .65791 L F
.517 .55 .829 r
.30603 .66061 m .31012 .6618 L .30882 .65791 L F
.921 .716 .608 r
.32623 .65797 m .32845 .6594 L .32676 .65543 L F
.805 .446 .376 r
.63941 .3511 m .64328 .35231 L .64294 .35031 L F
.808 .737 .785 r
.47109 .4662 m .46619 .46813 L .46898 .4645 L F
0 0 0 r
.49513 .45346 m .49285 .45538 L .49219 .45709 L F
.44 .757 .995 r
.35454 .56215 m .35622 .56325 L .35359 .56364 L F
.576 .015 0 r
.55718 .37701 m .55591 .37775 L .55236 .37637 L F
.156 .651 .915 r
.55992 .37872 m .55591 .37775 L .55718 .37701 L F
.711 .775 .902 r
.56354 .3715 m .56687 .37308 L .56539 .36936 L F
.397 .756 .993 r
.56687 .37308 m .56833 .37185 L .56539 .36936 L F
.56687 .37308 m .57031 .37278 L .56833 .37185 L F
.687 .852 .962 r
.35831 .56602 m .35843 .56924 L .36048 .56751 L F
0 0 .099 r
.36048 .56751 m .35843 .56924 L .35831 .56602 L F
.36048 .56751 m .35671 .57165 L .35843 .56924 L F
.745 .76 .865 r
.45598 .48406 m .45281 .48467 L .45334 .48284 L F
.28 .035 .353 r
.52856 .42463 m .52978 .42254 L .52767 .42371 L F
.52856 .42463 m .53129 .42118 L .52978 .42254 L F
.37 .284 .627 r
.55579 .35532 m .55817 .35496 L .5558 .35284 L F
.5558 .35284 m .55817 .35496 L .55579 .35532 L F
.451 .437 .751 r
.55628 .36568 m .55628 .36972 L .55438 .36626 L F
.55628 .36568 m .5589 .37022 L .55628 .36972 L F
.237 .582 .945 r
.5589 .37022 m .55944 .371 L .55628 .36972 L F
.448 .19 .43 r
.43385 .46139 m .43633 .46075 L .4368 .45827 L F
.338 .029 .285 r
.43633 .46075 m .43947 .45786 L .4368 .45827 L F
.471 .526 .832 r
.54372 .41686 m .54131 .41738 L .53976 .41375 L F
.3 .786 .9 r
.53988 .41695 m .54131 .41738 L .54372 .41686 L F
.897 .948 .831 r
.48514 .46602 m .48221 .46661 L .48397 .46475 L F
.292 .773 .679 r
.60011 .40214 m .60445 .40041 L .60243 .4009 L F
.389 .831 .704 r
.60445 .40041 m .60788 .39869 L .60648 .39919 L F
.404 .852 .775 r
.60243 .4009 m .60445 .40041 L .60648 .39919 L F
.425 .082 .279 r
.53487 .36239 m .53774 .35981 L .5378 .35826 L F
.726 .866 .947 r
.56283 .3703 m .5589 .37022 L .56051 .36817 L F
.56283 .3703 m .55944 .371 L .5589 .37022 L F
.359 .091 .364 r
.56539 .36936 m .56354 .3715 L .56283 .3703 L F
.54 .198 .337 r
.39831 .49211 m .39682 .49506 L .39417 .49513 L F
.63 .352 .479 r
.40109 .49177 m .39682 .49506 L .39831 .49211 L F
.663 .623 .8 r
.48576 .45525 m .48204 .45275 L .48425 .45124 L F
.574 .54 .779 r
.4865 .45442 m .48576 .45525 L .48425 .45124 L F
0 0 .344 r
.48736 .45703 m .48576 .45525 L .4865 .45442 L F
.48736 .45703 m .48524 .45866 L .48576 .45525 L F
.978 .826 .624 r
.5984 .34976 m .59974 .35634 L .60222 .35225 L F
.327 .795 .691 r
.52407 .37833 m .52882 .37636 L .52407 .37588 L F
.52407 .37833 m .52626 .37731 L .52882 .37636 L F
.298 .032 .331 r
.52882 .37636 m .5314 .37574 L .53173 .37337 L F
.466 .876 .729 r
.52882 .37636 m .5286 .3759 L .5314 .37574 L F
.52882 .37636 m .52626 .37731 L .5286 .3759 L F
.133 0 0 r
.46285 .43346 m .46526 .43345 L .46608 .43143 L F
.306 0 .212 r
.46177 .43617 m .46526 .43345 L .46285 .43346 L F
.886 .867 .815 r
.45715 .50855 m .4615 .50638 L .45961 .50495 L F
.45715 .50855 m .45897 .50992 L .4615 .50638 L F
.832 .944 .897 r
.46429 .50292 m .45961 .50495 L .4615 .50638 L F
.519 .914 .912 r
.51093 .41411 m .50411 .41648 L .50721 .41555 L F
.879 .903 .842 r
.45453 .51212 m .45897 .50992 L .45715 .50855 L F
.26 .566 .936 r
.29692 .65334 m .29929 .6556 L .3013 .65566 L F
.437 .493 .819 r
.29929 .6556 m .30339 .65951 L .3013 .65566 L F
.503 .046 .099 r
.37463 .48702 m .37888 .48531 L .37497 .48606 L F
.728 .247 .104 r
.60311 .38239 m .6072 .3798 L .60543 .38037 L F
0 0 0 r
.60543 .38037 m .6072 .3798 L .60801 .37962 L F
.832 .944 .897 r
.46429 .50292 m .46278 .50194 L .45961 .50495 L F
.918 .928 .801 r
.46533 .49817 m .46429 .50292 L .46516 .49992 L F
.46533 .49817 m .46278 .50194 L .46429 .50292 L F
.778 .687 .763 r
.4794 .45585 m .47423 .45753 L .47705 .45399 L F
.4794 .45585 m .47686 .45889 L .47423 .45753 L F
.795 .75 .811 r
.48204 .45275 m .4794 .45585 L .47705 .45399 L F
.675 .504 .646 r
.52718 .41814 m .53042 .41683 L .52981 .41437 L F
.52718 .41814 m .53042 .41683 L .52981 .41437 L F
.558 .616 .866 r
.53129 .42118 m .52718 .41814 L .53042 .41683 L F
.345 .294 .656 r
.52981 .41437 m .53042 .41683 L .53253 .41635 L F
.53253 .41635 m .53042 .41683 L .52981 .41437 L F
.076 .076 .553 r
.53253 .41635 m .53129 .42118 L .53042 .41683 L F
.53253 .41635 m .53317 .41931 L .5319 .41879 L F
.913 .599 .117 r
.53214 .41766 m .53317 .41931 L .5328 .41762 L F
.099 0 0 r
.53253 .41635 m .52925 .41886 L .53214 .41766 L F
.345 .294 .656 r
.52981 .41437 m .53042 .41683 L .53253 .41635 L F
.099 0 0 r
.53253 .41635 m .53042 .41683 L .52925 .41886 L F
.778 .897 .927 r
.53307 .4142 m .53102 .4179 L .53214 .41766 L F
.199 .725 .73 r
.53214 .41766 m .53102 .4179 L .53172 .4177 L F
.913 .599 .117 r
.53214 .41766 m .5328 .41759 L .53253 .41635 L F
.253 0 0 r
.52925 .41886 m .53042 .41683 L .52718 .41814 L F
.778 .897 .927 r
.53235 .41688 m .53214 .41766 L .5314 .41761 L F
.4 0 0 r
.5314 .41761 m .53214 .41766 L .53144 .41776 L F
0 0 0 r
.53679 .41434 m .5347 .41689 L .53585 .41558 L F
.5347 .41689 m .53403 .41772 L .53585 .41558 L F
.214 .473 .886 r
.53585 .41558 m .53785 .41602 L .53684 .41446 L F
.875 .777 .751 r
.5395 .4108 m .53679 .41434 L .53511 .41301 L F
.708 .516 .627 r
.5395 .4108 m .53976 .41375 L .53679 .41434 L F
.875 .777 .751 r
.5395 .4108 m .53511 .41301 L .53949 .41392 L F
.934 .574 .31 r
.53679 .41434 m .53585 .41558 L .53511 .41301 L F
.43 .695 .975 r
.53663 .41137 m .53949 .41392 L .53511 .41301 L F
.214 .473 .886 r
.53585 .41558 m .53684 .41446 L .53578 .41283 L F
.294 0 0 r
.53352 .41718 m .535 .41758 L .53372 .41739 L F
0 0 0 r
.53352 .41718 m .53144 .41776 L .53312 .41676 L F
.53144 .41776 m .53142 .41768 L .53537 .41543 L F
.53103 .4179 m .53105 .41789 L .53537 .41543 L F
.778 .897 .927 r
.53307 .4142 m .53235 .41688 L .5312 .4176 L F
.387 .394 .745 r
.53106 .41787 m .53104 .41787 L .53119 .41759 L F
0 0 0 r
.53144 .41776 m .53111 .41785 L .53142 .41768 L F
.387 .394 .745 r
.53105 .41789 m .53119 .41759 L .5312 .4176 L F
.4 0 0 r
.5314 .41761 m .53144 .41776 L .53001 .41797 L F
.199 .725 .73 r
.5316 .41774 m .53116 .41771 L .53001 .41797 L F
.53214 .41766 m .53187 .41767 L .5316 .41774 L F
.53187 .41767 m .53116 .41771 L .5316 .41774 L F
.387 .394 .745 r
.53105 .41789 m .53102 .4179 L .53104 .41787 L F
.53105 .41789 m .53104 .41787 L .53106 .41787 L F
.5312 .4176 m .53119 .41759 L .53307 .4142 L F
.4 0 0 r
.52898 .41746 m .5312 .4176 L .53001 .41797 L F
.5312 .4176 m .5314 .41761 L .53131 .41764 L F
.5312 .4176 m .53131 .41764 L .53001 .41797 L F
.778 .897 .927 r
.53307 .4142 m .5312 .4176 L .52898 .41746 L F
.53235 .41688 m .5314 .41761 L .5312 .4176 L F
.387 .394 .745 r
.53537 .41543 m .53105 .41789 L .53307 .4142 L F
.538 .58 .845 r
.53001 .41797 m .53352 .41718 L .53146 .41567 L F
.294 0 0 r
.53352 .41718 m .53372 .41739 L .53074 .41695 L F
0 0 0 r
.53352 .41718 m .53312 .41676 L .53537 .41543 L F
.199 .725 .73 r
.53173 .41768 m .53352 .41718 L .53116 .41771 L F
.53214 .41766 m .53352 .41718 L .53173 .41768 L F
0 0 0 r
.53352 .41718 m .53103 .4179 L .53111 .41785 L F
.53103 .4179 m .53102 .4179 L .53105 .41789 L F
.199 .725 .73 r
.53214 .41766 m .53172 .4177 L .53352 .41718 L F
.913 .599 .117 r
.53214 .41766 m .5328 .41762 L .5328 .41759 L F
.599 .574 .797 r
.53214 .41766 m .53452 .41986 L .53317 .41931 L F
.53452 .41986 m .53533 .42061 L .53317 .41931 L F
.076 .076 .553 r
.5319 .41879 m .53317 .41931 L .53129 .42118 L F
.521 .285 .498 r
.53317 .41931 m .52978 .42254 L .53129 .42118 L F
.651 .095 0 r
.51021 .41482 m .51093 .41411 L .50721 .41555 L F
.51021 .41482 m .51178 .41481 L .51093 .41411 L F
0 0 0 r
.52137 .39382 m .51761 .39619 L .51837 .39396 L F
.793 .999 .818 r
.51045 .4574 m .50778 .46137 L .51147 .45875 L F
.51045 .4574 m .507 .46088 L .50778 .46137 L F
.575 .393 .598 r
.29383 .64814 m .29773 .64892 L .29642 .64524 L F
.355 .351 .717 r
.29383 .64814 m .29692 .65334 L .29773 .64892 L F
.786 .718 .789 r
.47686 .45889 m .47222 .45836 L .47423 .45753 L F
.47686 .45889 m .47146 .46112 L .47222 .45836 L F
.352 .649 .967 r
.35477 .5538 m .35722 .55401 L .3556 .552 L F
.35477 .5538 m .35722 .55401 L .3556 .552 L F
.754 .798 .888 r
.36879 .57354 m .37006 .57565 L .3731 .57391 L F
.77 .921 .937 r
.41654 .53555 m .41258 .53893 L .41311 .53586 L F
.291 .788 .772 r
.60788 .39869 m .60908 .398 L .60648 .39919 L F
.60788 .39869 m .61074 .39778 L .60908 .398 L F
.782 .643 .708 r
.65734 .36651 m .65928 .3626 L .65611 .36235 L F
.974 .862 .665 r
.65262 .36798 m .65396 .36941 L .65328 .36577 L F
.782 .77 .842 r
.65396 .36941 m .65734 .36651 L .65328 .36577 L F
.733 .966 .698 r
.51728 .38773 m .51553 .38873 L .51854 .38545 L F
0 .308 .781 r
.41334 .56519 m .41683 .56693 L .41433 .56607 L F
.235 0 0 r
.41683 .56693 m .41356 .5672 L .41433 .56607 L F
.841 .671 .672 r
.48535 .44148 m .48227 .44434 L .48278 .4414 L F
0 0 .43 r
.58848 .35998 m .58899 .35893 L .58834 .35601 L F
.705 .641 .083 r
.58856 .36272 m .58899 .35893 L .58848 .35998 L F
.78 .855 .906 r
.55579 .35532 m .55264 .35682 L .55124 .35521 L F
.629 .12 .019 r
.55124 .35521 m .55401 .35716 L .55579 .35532 L F
.14 0 0 r
.55579 .35532 m .5567 .35636 L .55817 .35496 L F
.55579 .35532 m .55401 .35716 L .5567 .35636 L F
.969 .662 .272 r
.60021 .36606 m .60047 .3687 L .60181 .37009 L F
.967 .716 .502 r
.60047 .3687 m .60207 .37187 L .60181 .37009 L F
.782 .662 .73 r
.43185 .50534 m .43349 .50945 L .42922 .50891 L F
.786 .637 .695 r
.43349 .50945 m .43128 .51306 L .42922 .50891 L F
.412 .598 .922 r
.53403 .41772 m .53695 .4181 L .53585 .41558 L F
.439 .207 .464 r
.54651 .39388 m .5464 .39667 L .54367 .39729 L F
.54651 .39388 m .5464 .39667 L .54367 .39729 L F
.526 .382 .628 r
.54651 .39388 m .54716 .38832 L .54483 .38985 L F
.54651 .39388 m .55002 .39317 L .54943 .38944 L F
.382 .112 .375 r
.55002 .39317 m .5464 .39667 L .54651 .39388 L F
0 0 .168 r
.54651 .39388 m .54755 .39407 L .55002 .39317 L F
.54651 .39388 m .5464 .39667 L .54755 .39407 L F
.526 .382 .628 r
.54651 .39388 m .55002 .39317 L .54943 .38944 L F
.496 .31 .558 r
.29642 .64524 m .29917 .6446 L .29936 .64193 L F
.725 .584 .697 r
.29773 .64892 m .29917 .6446 L .29642 .64524 L F
.834 .828 .841 r
.55313 .41589 m .55617 .41789 L .55217 .42083 L F
.506 .787 .996 r
.55571 .42038 m .55217 .42083 L .55617 .41789 L F
0 0 0 r
.36195 .57075 m .36003 .57205 L .35752 .57285 L F
.704 .924 .593 r
.3628 .56899 m .36195 .57075 L .36467 .5673 L F
.71 .952 .671 r
.3628 .56899 m .36003 .57205 L .36195 .57075 L F
.321 0 .186 r
.40828 .47856 m .41082 .47786 L .41188 .4752 L F
.304 .017 .301 r
.41356 .4773 m .41188 .4752 L .41082 .47786 L F
.41356 .4773 m .41437 .47429 L .41188 .4752 L F
.604 .375 .542 r
.42049 .56065 m .42091 .5634 L .41883 .55975 L F
.42049 .56065 m .42355 .56357 L .42091 .5634 L F
0 0 0 r
.55864 .38681 m .55574 .38942 L .5561 .38709 L F
.404 .01 .174 r
.39531 .48395 m .39862 .48213 L .39599 .48313 L F
.5 .55 .839 r
.54725 .36895 m .54552 .3708 L .54313 .36553 L F
.576 0 0 r
.60207 .37187 m .60437 .37319 L .60589 .37332 L F
.061 .612 .83 r
.60437 .37319 m .60861 .37383 L .60589 .37332 L F
.549 .298 .487 r
.47988 .43098 m .48272 .4305 L .48306 .42783 L F
.452 .881 .802 r
.48087 .42825 m .48306 .42783 L .48543 .4266 L F
.619 .754 .943 r
.48306 .42783 m .48719 .42794 L .48543 .4266 L F
.747 .542 .618 r
.48272 .4305 m .48719 .42794 L .48306 .42783 L F
.56 .001 0 r
.4619 .44482 m .46588 .44811 L .46609 .44784 L F
.644 .799 .357 r
.46609 .44784 m .46705 .44594 L .46859 .44719 L F
.46609 .44784 m .46588 .44811 L .46705 .44594 L F
.835 .767 .787 r
.48697 .4482 m .48425 .45124 L .48281 .44748 L F
.643 .457 .617 r
.48697 .4482 m .48748 .45089 L .48425 .45124 L F
.496 .188 .373 r
.44893 .46568 m .44832 .46783 L .44547 .46833 L F
.473 .166 .365 r
.4511 .46697 m .44893 .46568 L .45139 .46466 L F
.4511 .46697 m .44832 .46783 L .44893 .46568 L F
.939 .711 .567 r
.33143 .63422 m .33361 .63542 L .33189 .6314 L F
.875 .741 .71 r
.32911 .63782 m .33361 .63542 L .33143 .63422 L F
.32911 .63782 m .33285 .63839 L .33361 .63542 L F
.498 .538 .829 r
.37666 .57512 m .37865 .5724 L .37574 .57315 L F
.37666 .57512 m .37978 .57595 L .37865 .5724 L F
.744 .835 .921 r
.45281 .48467 m .44823 .48457 L .45107 .48119 L F
.783 .736 .81 r
.45334 .48284 m .45281 .48467 L .45107 .48119 L F
.804 .454 0 r
.56648 .38307 m .56751 .38642 L .56751 .38612 L F
.517 .546 .825 r
.45985 .48077 m .46504 .48105 L .46352 .47702 L F
.231 .117 .51 r
.46352 .47702 m .4638 .48043 L .45985 .48077 L F
.155 .664 .901 r
.46504 .48105 m .4638 .48043 L .45985 .48077 L F
.175 0 .168 r
.4638 .48043 m .46088 .48314 L .45985 .48077 L F
.4638 .48043 m .46088 .48314 L .45985 .48077 L F
0 0 0 r
.59065 .40433 m .59409 .40376 L .59246 .40444 L F
.59065 .40433 m .59246 .40444 L .58961 .4024 L F
.978 .826 .624 r
.5984 .34976 m .59788 .35547 L .59974 .35634 L F
.985 .771 .532 r
.59788 .35547 m .59899 .35853 L .59974 .35634 L F
.51 .535 .818 r
.36175 .5737 m .36442 .57451 L .36452 .57278 L F
.864 .995 .771 r
.64019 .38127 m .64099 .37836 L .63787 .38152 L F
.64019 .38127 m .64166 .37912 L .64099 .37836 L F
.889 .973 .667 r
.49524 .44817 m .4938 .45131 L .49684 .44925 L F
.503 .046 .099 r
.37463 .48702 m .37709 .48745 L .37888 .48531 L F
.554 .102 .133 r
.37888 .48531 m .38197 .48688 L .38158 .48546 L F
.37888 .48531 m .37709 .48745 L .38197 .48688 L F
.437 .171 .412 r
.43057 .46526 m .43331 .46463 L .43385 .46139 L F
.386 .11 .368 r
.43331 .46463 m .43633 .46075 L .43385 .46139 L F
0 0 .539 r
.47829 .4686 m .47906 .47016 L .478 .46965 L F
.894 .815 .762 r
.42105 .52211 m .42234 .52578 L .41976 .52445 L F
.901 .823 .76 r
.4198 .52955 m .41976 .52445 L .42234 .52578 L F
.786 .769 .838 r
.42105 .52211 m .42518 .52251 L .42234 .52578 L F
.845 .64 .625 r
.63048 .34517 m .63189 .34948 L .634 .34601 L F
.707 .792 .917 r
.55264 .35682 m .54781 .35672 L .55124 .35521 L F
.385 .833 .932 r
.61135 .37374 m .61564 .37356 L .61268 .3735 L F
.129 0 .235 r
.53432 .37229 m .5314 .37574 L .53173 .37337 L F
.453 .21 .454 r
.54075 .40053 m .54355 .39982 L .54367 .39729 L F
.54367 .39729 m .54355 .39982 L .54075 .40053 L F
.434 .194 .45 r
.5464 .39667 m .54355 .39982 L .54367 .39729 L F
.5464 .39667 m .54355 .39982 L .54367 .39729 L F
.765 .321 .198 r
.36467 .5673 m .36672 .5704 L .3628 .56899 L F
.277 .778 .767 r
.61074 .39778 m .61436 .39686 L .61348 .39678 L F
.408 .86 .865 r
.61624 .3957 m .61436 .39686 L .61701 .39584 L F
.408 .86 .846 r
.61348 .39678 m .61436 .39686 L .61624 .3957 L F
.517 .019 .011 r
.37329 .49205 m .37161 .49364 L .36913 .49223 L F
.648 .171 .107 r
.37329 .49205 m .37621 .49419 L .37161 .49364 L F
.637 .206 .207 r
.37627 .49268 m .37621 .49419 L .37329 .49205 L F
.387 .219 .529 r
.4642 .44128 m .46449 .44452 L .4619 .44482 L F
.41 .341 .669 r
.46449 .44452 m .46588 .44811 L .4619 .44482 L F
.199 0 .149 r
.50763 .39417 m .50686 .39597 L .51017 .39308 L F
.836 .605 .59 r
.46101 .47511 m .45666 .47154 L .46125 .4724 L F
.46101 .47511 m .45648 .47433 L .45666 .47154 L F
.826 .699 .725 r
.46101 .47511 m .45814 .47838 L .45648 .47433 L F
.775 .694 .774 r
.46407 .47109 m .46101 .47511 L .46125 .4724 L F
.79 .708 .773 r
.54358 .38003 m .54594 .3827 L .54573 .37873 L F
.893 .904 .827 r
.57814 .35692 m .57809 .36036 L .5782 .35984 L F
.664 .971 .9 r
.49742 .46764 m .49604 .46962 L .49837 .46807 L F
.49742 .46764 m .49385 .46974 L .49604 .46962 L F
.327 0 0 r
.56299 .39026 m .56621 .39004 L .56659 .38904 L F
.098 .115 .588 r
.56659 .38904 m .56859 .38833 L .56751 .38642 L F
0 0 0 r
.56659 .38904 m .56621 .39004 L .56859 .38833 L F
.316 .055 .35 r
.45158 .4452 m .45358 .44662 L .4541 .44418 L F
.45158 .4452 m .45114 .44756 L .45358 .44662 L F
.953 .772 .317 r
.6148 .38027 m .61383 .38144 L .61262 .37933 L F
.6148 .38027 m .61454 .38299 L .61383 .38144 L F
.775 .94 .934 r
.47288 .48991 m .47242 .49257 L .47573 .48961 L F
.47288 .48991 m .47101 .49151 L .47242 .49257 L F
.411 .007 .16 r
.42047 .47135 m .4234 .47094 L .42458 .46859 L F
.297 0 .106 r
.42458 .46859 m .4261 .47016 L .42722 .46784 L F
.42458 .46859 m .4234 .47094 L .4261 .47016 L F
.427 .848 .693 r
.49793 .40625 m .49626 .40742 L .49427 .40829 L F
.63 .533 .726 r
.40321 .53322 m .40463 .5388 L .40705 .53777 L F
.795 .75 .811 r
.48204 .45275 m .47705 .45399 L .48012 .45089 L F
.783 .806 .871 r
.48425 .45124 m .48204 .45275 L .48012 .45089 L F
0 0 0 r
.36318 .56067 m .36456 .55989 L .36576 .55997 L F
.36318 .56067 m .36185 .56252 L .36456 .55989 L F
.531 .876 .988 r
.54245 .42433 m .53823 .42449 L .54099 .42577 L F
.891 .907 .831 r
.40504 .55699 m .40598 .55246 L .40767 .55363 L F
.40504 .55699 m .40332 .55592 L .40598 .55246 L F
.551 .158 .25 r
.40504 .55699 m .40335 .55932 L .40332 .55592 L F
.40504 .55699 m .40641 .5591 L .40335 .55932 L F
.269 .775 .809 r
.61564 .37356 m .61887 .37279 L .61984 .37282 L F
.34 .82 .823 r
.61984 .37282 m .62179 .37184 L .62262 .3722 L F
.61984 .37282 m .61887 .37279 L .62179 .37184 L F
.702 .626 .769 r
.46619 .46813 m .46795 .47207 L .46407 .47109 L F
.747 .542 .618 r
.48272 .4305 m .48677 .43079 L .48719 .42794 L F
.489 .32 .578 r
.54242 .41011 m .53976 .41375 L .5395 .4108 L F
.334 .015 .266 r
.53949 .41392 m .54242 .41011 L .5395 .4108 L F
.671 .472 .607 r
.46073 .45763 m .45601 .46054 L .45773 .45784 L F
.806 .479 .437 r
.64938 .36486 m .65311 .36317 L .64902 .36211 L F
.64938 .36486 m .65328 .36577 L .65311 .36317 L F
.829 .668 .683 r
.65328 .36577 m .65611 .36235 L .65311 .36317 L F
.725 .664 .789 r
.57157 .36055 m .56871 .36362 L .56671 .35904 L F
.38 .587 .925 r
.39114 .57616 m .39201 .57319 L .38924 .57524 L F
.39114 .57616 m .39372 .57626 L .39201 .57319 L F
.872 .754 .73 r
.33068 .64174 m .33285 .63839 L .32911 .63782 L F
.877 .821 .789 r
.43482 .49926 m .43032 .50146 L .43259 .49785 L F
.43482 .49926 m .43236 .50266 L .43032 .50146 L F
.809 .797 .841 r
.43759 .49612 m .43482 .49926 L .43259 .49785 L F
.233 .283 .71 r
.40335 .55932 m .40191 .56095 L .40063 .55961 L F
.40335 .55932 m .40495 .56336 L .40191 .56095 L F
.375 .351 .704 r
.60455 .34074 m .60451 .34253 L .60251 .34281 L F
.88 .963 .846 r
.47602 .48642 m .47573 .48961 L .47722 .48749 L F
.47602 .48642 m .47288 .48991 L .47573 .48961 L F
.561 .253 .404 r
.41533 .4911 m .4135 .49032 L .41511 .48888 L F
.582 .331 .502 r
.41788 .48852 m .41533 .4911 L .41511 .48888 L F
.492 .305 .554 r
.3099 .6255 m .31243 .62465 L .31244 .62158 L F
.512 .265 .477 r
.31243 .62465 m .31527 .62137 L .31244 .62158 L F
.522 .291 .505 r
.30125 .63432 m .30418 .63177 L .30178 .63334 L F
.927 .568 .142 r
.40093 .52935 m .40199 .53233 L .40321 .53322 L F
.40321 .53322 m .40199 .53233 L .40093 .52935 L F
.655 .879 .981 r
.41029 .5524 m .40767 .55363 L .40598 .55246 L F
0 0 .028 r
.3099 .6255 m .30715 .62855 L .30931 .6272 L F
.56 .159 .238 r
.30931 .6272 m .3121 .62733 L .3099 .6255 L F
.443 .196 .443 r
.3099 .6255 m .3121 .62733 L .31243 .62465 L F
0 0 0 r
.55864 .38681 m .55727 .38839 L .55574 .38942 L F
.367 .836 .869 r
.55574 .38942 m .55727 .38839 L .55458 .38922 L F
.667 .844 .968 r
.36879 .57354 m .3731 .57391 L .37126 .57252 L F
.571 .812 .99 r
.37126 .57252 m .3731 .57391 L .37574 .57315 L F
.377 .097 .357 r
.44802 .45069 m .45114 .44756 L .4487 .44859 L F
.268 0 .23 r
.46747 .43805 m .46743 .44198 L .4642 .44128 L F
.38 .155 .442 r
.47 .43697 m .46747 .43805 L .47019 .43455 L F
.498 .118 .251 r
.46974 .43843 m .46747 .43805 L .47 .43697 L F
.46974 .43843 m .46743 .44198 L .46747 .43805 L F
.522 .291 .505 r
.30125 .63432 m .30418 .63536 L .30418 .63177 L F
.475 .371 .657 r
.30125 .63432 m .30163 .63837 L .30418 .63536 L F
0 0 0 r
.40537 .53844 m .40615 .5388 L .40705 .53777 L F
.708 .677 .133 r
.40537 .53844 m .40506 .54007 L .40615 .5388 L F
.40537 .53844 m .4046 .54283 L .40506 .54007 L F
.721 .317 .282 r
.61322 .37781 m .61262 .37933 L .60801 .37962 L F
.849 .475 .342 r
.6377 .35871 m .63353 .35566 L .63793 .35648 L F
.588 .187 .249 r
.38158 .48546 m .384 .48755 L .38587 .48474 L F
.399 0 .088 r
.384 .48755 m .38848 .48491 L .38587 .48474 L F
.964 .94 .681 r
.58204 .36831 m .58163 .37271 L .5829 .36968 L F
.593 .892 .989 r
.46859 .44719 m .46705 .44594 L .4734 .44527 L F
.763 .73 .822 r
.52718 .41814 m .52265 .41825 L .52553 .41912 L F
.253 0 0 r
.52925 .41886 m .52718 .41814 L .52553 .41912 L F
.728 .465 .53 r
.32647 .62096 m .32861 .61828 L .3275 .6183 L F
.32647 .62096 m .32884 .62059 L .32861 .61828 L F
.964 .94 .681 r
.58204 .36831 m .58052 .37213 L .58163 .37271 L F
.978 .759 .539 r
.58052 .37213 m .58146 .37505 L .58163 .37271 L F
.574 .54 .779 r
.4865 .45442 m .48425 .45124 L .48748 .45089 L F
.169 0 .24 r
.4896 .45539 m .4865 .45442 L .49176 .45252 L F
.4896 .45539 m .48736 .45703 L .4865 .45442 L F
.829 .668 .683 r
.65328 .36577 m .65734 .36651 L .65611 .36235 L F
.005 0 0 r
.46608 .43143 m .46725 .43231 L .46844 .42998 L F
.46608 .43143 m .46526 .43345 L .46725 .43231 L F
.344 .086 .371 r
.30418 .63177 m .3067 .63141 L .30715 .62855 L F
.573 .415 .629 r
.30418 .63536 m .3067 .63141 L .30418 .63177 L F
.715 .624 .754 r
.53808 .38985 m .54272 .39159 L .54077 .3863 L F
.527 .518 .789 r
.54077 .3863 m .54272 .39159 L .54483 .38985 L F
.762 .623 .706 r
.42358 .54047 m .4223 .54317 L .42147 .53978 L F
0 0 .402 r
.52158 .43304 m .52191 .43248 L .52215 .43052 L F
.37 0 .032 r
.40469 .48053 m .40742 .48018 L .40544 .47907 L F
.35 0 .104 r
.40544 .47907 m .40742 .48018 L .40828 .47856 L F
.813 .758 .801 r
.48281 .44748 m .48425 .45124 L .48012 .45089 L F
.428 .194 .455 r
.47258 .43578 m .47019 .43455 L .47334 .43429 L F
.47258 .43578 m .47 .43697 L .47019 .43455 L F
.748 .612 .707 r
.46407 .47109 m .45935 .46813 L .46397 .46919 L F
.46407 .47109 m .46125 .4724 L .45935 .46813 L F
.741 .682 .795 r
.46619 .46813 m .46407 .47109 L .46397 .46919 L F
.062 0 0 r
.3914 .49552 m .38965 .49575 L .38718 .49579 L F
.444 0 0 r
.39417 .49513 m .38965 .49575 L .3914 .49552 L F
.567 .585 .831 r
.51178 .41481 m .51583 .41718 L .51462 .41448 L F
.51583 .41718 m .51178 .41481 L .51458 .41567 L F
.278 0 0 r
.51458 .41567 m .51178 .41481 L .51021 .41482 L F
.851 .673 .661 r
.3299 .62758 m .33253 .62842 L .33042 .62464 L F
.864 .692 .667 r
.32792 .63103 m .33253 .62842 L .3299 .62758 L F
.32792 .63103 m .33189 .6314 L .33253 .62842 L F
.233 0 .265 r
.44574 .45174 m .44512 .45397 L .44802 .45069 L F
.673 .758 .915 r
.38085 .56153 m .37725 .56122 L .37977 .56023 L F
.602 .755 .951 r
.38229 .55904 m .38085 .56153 L .37977 .56023 L F
.38229 .55904 m .38402 .56076 L .38085 .56153 L F
.689 .527 .662 r
.4709 .45465 m .47222 .45836 L .46781 .45804 L F
.766 .719 .808 r
.47506 .45545 m .47222 .45836 L .4709 .45465 L F
.419 0 0 r
.41442 .56624 m .41683 .56693 L .41334 .56519 L F
.571 .404 .617 r
.3067 .63141 m .30931 .6272 L .30715 .62855 L F
.455 .197 .434 r
.61964 .33935 m .61938 .34199 L .62221 .34099 L F
.466 .299 .571 r
.29936 .64193 m .30131 .6413 L .30163 .63837 L F
.594 .393 .578 r
.29936 .64193 m .30182 .64389 L .30131 .6413 L F
.29936 .64193 m .29917 .6446 L .30182 .64389 L F
.346 .817 .753 r
.34154 .51246 m .33721 .51396 L .33792 .51535 L F
0 0 .307 r
.52396 .38795 m .52334 .39162 L .52276 .3904 L F
.966 .933 .624 r
.58045 .38122 m .58228 .38004 L .58116 .37865 L F
.58045 .38122 m .58099 .38276 L .58228 .38004 L F
.997 .804 .447 r
.58146 .37505 m .58116 .37865 L .58228 .38004 L F
.789 .94 .926 r
.43095 .54959 m .42718 .54998 L .42649 .55374 L F
.43095 .54959 m .42931 .54849 L .42718 .54998 L F
.866 .88 .845 r
.43095 .54959 m .43174 .54512 L .42931 .54849 L F
.43095 .54959 m .43368 .54618 L .43174 .54512 L F
.699 .372 .419 r
.38064 .49211 m .37621 .49419 L .37627 .49268 L F
.38064 .49211 m .38163 .49366 L .37621 .49419 L F
.702 .387 .44 r
.38269 .49241 m .38163 .49366 L .38064 .49211 L F
.677 .94 .662 r
.48326 .46058 m .48524 .45866 L .4843 .459 L F
.485 .878 .963 r
.48524 .45866 m .48866 .45788 L .48736 .45703 L F
.248 0 .102 r
.49882 .41746 m .49682 .41673 L .50205 .41666 L F
.573 .932 .933 r
.50611 .41477 m .50205 .41666 L .50248 .41544 L F
.594 .594 .821 r
.50248 .40913 m .50248 .41516 L .49966 .40985 L F
.50248 .41516 m .50248 .41544 L .50235 .41518 L F
.50248 .41516 m .50235 .41518 L .49966 .40985 L F
.50248 .40913 m .50611 .41477 L .50248 .41544 L F
.835 .568 .021 r
.50459 .40863 m .50611 .41477 L .50248 .40913 L F
.50459 .40863 m .5058 .41474 L .50611 .41477 L F
.806 .673 .126 r
.50611 .41477 m .50603 .41475 L .50543 .41482 L F
.835 .568 .021 r
.5058 .41474 m .5059 .41523 L .50611 .41477 L F
.806 .673 .126 r
.50543 .41482 m .50576 .41473 L .50212 .41507 L F
.50576 .41473 m .50585 .41471 L .50569 .41472 L F
.50576 .41473 m .50569 .41472 L .50212 .41507 L F
.50603 .41475 m .50585 .41471 L .50543 .41482 L F
.066 .117 .606 r
.50699 .4099 m .50624 .41357 L .50459 .40863 L F
.50591 .41391 m .5059 .41523 L .50568 .41414 L F
.806 .673 .126 r
.5059 .41472 m .5059 .41523 L .50585 .41471 L F
.50611 .41477 m .5059 .41523 L .5059 .41472 L F
.066 .117 .606 r
.50624 .41357 m .5059 .41523 L .50591 .41391 L F
.50624 .41357 m .50568 .41414 L .50459 .40863 L F
.573 .932 .933 r
.50418 .41567 m .50212 .41507 L .50205 .41666 L F
.50611 .41477 m .50498 .41486 L .50418 .41567 L F
.50498 .41486 m .50212 .41507 L .50418 .41567 L F
.439 .09 .275 r
.50212 .41507 m .49882 .41746 L .50205 .41666 L F
.775 .796 .87 r
.30339 .65951 m .30611 .65832 L .30427 .65504 L F
.748 .786 .883 r
.30427 .65504 m .30611 .65832 L .30855 .65528 L F
.573 .548 .789 r
.30611 .65832 m .30882 .65791 L .30855 .65528 L F
.848 .85 .844 r
.32719 .65252 m .32781 .64833 L .32512 .65152 L F
.91 .757 .679 r
.32512 .65152 m .32676 .65543 L .32719 .65252 L F
.494 .22 .427 r
.43555 .48034 m .4336 .47895 L .43591 .47797 L F
.43555 .48034 m .43335 .48126 L .4336 .47895 L F
.677 .976 .818 r
.52857 .44428 m .52454 .44657 L .52563 .44734 L F
.748 .813 .903 r
.61938 .34199 m .62347 .34248 L .62221 .34099 L F
.961 .908 .718 r
.62391 .33746 m .62221 .34099 L .62347 .34248 L F
.074 0 0 r
.4428 .45505 m .43947 .45786 L .44181 .45671 L F
.203 0 .111 r
.44181 .45671 m .44512 .45397 L .4428 .45505 L F
.517 .906 .938 r
.6246 .39482 m .62482 .39353 L .62283 .39404 L F
.6246 .39482 m .62756 .39361 L .62482 .39353 L F
.799 .634 .678 r
.41582 .54327 m .41303 .54703 L .41142 .54287 L F
.41582 .54327 m .41548 .54673 L .41303 .54703 L F
.432 .316 .621 r
.47951 .44775 m .47684 .44774 L .47977 .44736 L F
.47951 .44775 m .47735 .45204 L .47684 .44774 L F
.646 .95 .732 r
.54264 .43005 m .54652 .42729 L .54491 .42825 L F
0 0 0 r
.54491 .42825 m .54652 .42729 L .54906 .42598 L F
.676 .663 .829 r
.55715 .38012 m .55479 .38147 L .55236 .37637 L F
.834 .828 .841 r
.55313 .41589 m .55217 .42083 L .55181 .42009 L F
.824 .995 .757 r
.55181 .42009 m .55217 .42083 L .54938 .42221 L F
.842 .656 .651 r
.33272 .64575 m .33068 .64174 L .33046 .64487 L F
.848 .736 .74 r
.33046 .64487 m .33179 .64814 L .33272 .64575 L F
.702 .387 .44 r
.38269 .49241 m .38282 .4949 L .38163 .49366 L F
.706 .589 .722 r
.42147 .53978 m .4223 .54317 L .42121 .54317 L F
.678 .388 .474 r
.42121 .54317 m .4223 .54317 L .41909 .54524 L F
.152 0 0 r
.51761 .39619 m .51676 .39798 L .51408 .39871 L F
0 0 0 r
.52137 .39382 m .52 .39499 L .51761 .39619 L F
.52 .39499 m .51676 .39798 L .51761 .39619 L F
.50239 .40637 m .50531 .40305 L .50474 .40568 L F
.438 .122 .33 r
.50836 .40117 m .50474 .40568 L .50531 .40305 L F
.922 .779 .685 r
.43236 .50266 m .43185 .50534 L .43032 .50146 L F
.69 .456 .563 r
.4135 .49032 m .41079 .49223 L .40829 .49202 L F
.561 .253 .404 r
.41533 .4911 m .41079 .49223 L .4135 .49032 L F
.527 0 0 r
.52009 .4234 m .52432 .42402 L .5207 .42285 L F
0 0 0 r
.52009 .4234 m .5207 .42285 L .52392 .42106 L F
.83 .94 .898 r
.51186 .45572 m .51147 .45875 L .51331 .45667 L F
.854 .956 .876 r
.51045 .4574 m .51147 .45875 L .51186 .45572 L F
.241 0 .315 r
.56732 .39626 m .56466 .39967 L .56513 .39726 L F
.771 .726 .811 r
.43868 .48876 m .44037 .49237 L .43603 .49189 L F
.787 .685 .752 r
.44037 .49237 m .43759 .49612 L .43603 .49189 L F
.795 .803 .858 r
.44137 .48763 m .44037 .49237 L .43868 .48876 L F
.44137 .48763 m .44337 .48947 L .44037 .49237 L F
.891 .757 .256 r
.58897 .39266 m .58893 .39693 L .58984 .39484 L F
0 0 .258 r
.58893 .39693 m .59053 .39742 L .58984 .39484 L F
.58893 .39693 m .58877 .39975 L .59053 .39742 L F
.106 .659 .721 r
.51319 .44463 m .51482 .44452 L .51274 .4453 L F
.51319 .44463 m .51778 .44414 L .51482 .44452 L F
0 0 .259 r
.58834 .35601 m .58891 .35641 L .58905 .35373 L F
.58834 .35601 m .58899 .35893 L .58891 .35641 L F
0 0 0 r
.54998 .36278 m .54818 .36671 L .54979 .36324 L F
.167 .206 .658 r
.54818 .36671 m .54982 .36578 L .54979 .36324 L F
0 0 .074 r
.54818 .36671 m .54725 .36895 L .54982 .36578 L F
.782 .677 .749 r
.54716 .36394 m .54818 .36671 L .54998 .36278 L F
0 0 .074 r
.54818 .36671 m .54725 .36895 L .54982 .36578 L F
.75 .285 .147 r
.5092 .41985 m .51314 .42079 L .51043 .42116 L F
.581 .574 .81 r
.5092 .41985 m .51178 .42025 L .51021 .41482 L F
.841 .968 .882 r
.51127 .42105 m .51314 .42079 L .51272 .41961 L F
.698 .633 .78 r
.51021 .41482 m .5123 .41944 L .51384 .41777 L F
.841 .968 .882 r
.51253 .41908 m .51314 .42079 L .51384 .41777 L F
.698 .633 .78 r
.5123 .41944 m .51274 .42039 L .51384 .41777 L F
.841 .968 .882 r
.51178 .42025 m .51272 .41961 L .51256 .41916 L F
.5123 .41944 m .51256 .41916 L .51253 .41908 L F
.51178 .42025 m .51256 .41916 L .5123 .41944 L F
.51127 .42105 m .51272 .41961 L .51178 .42025 L F
.619 .337 .467 r
.51043 .42116 m .51274 .42039 L .51178 .42025 L F
.51043 .42116 m .51178 .42025 L .5092 .41985 L F
.581 .574 .81 r
.51178 .42025 m .51274 .42039 L .5123 .41944 L F
.51178 .42025 m .5123 .41944 L .51021 .41482 L F
.841 .968 .882 r
.51043 .42116 m .51127 .42105 L .51253 .41908 L F
.7 .843 .951 r
.51384 .41777 m .51314 .42079 L .51611 .41983 L F
.906 .754 .682 r
.32911 .64629 m .33179 .64814 L .33046 .64487 L F
.829 .841 .857 r
.32781 .64833 m .33179 .64814 L .32911 .64629 L F
.311 0 0 r
.54346 .38541 m .54711 .38504 L .54796 .38396 L F
0 0 0 r
.54796 .38396 m .54861 .38222 L .54904 .38222 L F
.54861 .38222 m .54888 .3815 L .54899 .38201 L F
.54861 .38222 m .54899 .38201 L .54904 .38222 L F
.54796 .38396 m .54932 .38341 L .54888 .3815 L F
.54796 .38396 m .54711 .38504 L .54932 .38341 L F
.756 .292 .148 r
.54932 .38341 m .54728 .38514 L .54609 .38366 L F
.54724 .383 m .54609 .38366 L .54525 .38261 L F
.54932 .38341 m .54609 .38366 L .54724 .383 L F
.887 .877 .82 r
.47872 .46374 m .48051 .46518 L .48326 .46058 L F
.602 .095 .021 r
.48221 .46661 m .47858 .46645 L .48051 .46518 L F
.006 .179 .693 r
.48155 .46318 m .48051 .46518 L .47872 .46374 L F
.48155 .46318 m .48221 .46661 L .48051 .46518 L F
.775 .633 .703 r
.42922 .50891 m .43128 .51306 L .42683 .51222 L F
.84 .72 .731 r
.43128 .51306 m .42655 .51518 L .42683 .51222 L F
.43128 .51306 m .43042 .51556 L .42655 .51518 L F
0 0 .248 r
.5592 .41261 m .55836 .41414 L .55929 .41039 L F
0 0 .044 r
.55774 .41666 m .55836 .41414 L .5592 .41261 L F
.855 .83 .822 r
.50226 .44014 m .50337 .44326 L .50605 .44017 L F
.775 .796 .87 r
.30339 .65951 m .30427 .65504 L .3013 .65566 L F
.818 .995 .761 r
.64166 .37912 m .64399 .37517 L .64099 .37836 L F
.64166 .37912 m .6446 .37568 L .64399 .37517 L F
.849 .475 .342 r
.6377 .35871 m .63399 .35833 L .63353 .35566 L F
.927 .899 .779 r
.6377 .35871 m .63372 .36139 L .63399 .35833 L F
.6377 .35871 m .6351 .36296 L .63372 .36139 L F
.38 .217 .531 r
.54582 .36366 m .54302 .36293 L .54716 .36394 L F
.54582 .36366 m .54313 .36553 L .54302 .36293 L F
.375 .67 .973 r
.37618 .54081 m .37682 .54324 L .37468 .53974 L F
.62 .818 .977 r
.37468 .53974 m .37504 .54033 L .37449 .54 L F
.038 .527 .882 r
.374 .53977 m .37445 .53998 L .37468 .53974 L F
.37445 .53998 m .37618 .54081 L .37468 .53974 L F
.633 .838 .979 r
.37468 .53974 m .3743 .53989 L .374 .53977 L F
.038 .527 .882 r
.374 .53977 m .37413 .5398 L .37443 .53997 L F
.633 .838 .979 r
.3743 .53989 m .37069 .54135 L .374 .53977 L F
.038 .527 .882 r
.37413 .5398 m .37416 .53981 L .3743 .53989 L F
.37426 .53988 m .3743 .53989 L .37443 .53997 L F
.37413 .5398 m .3743 .53989 L .37426 .53988 L F
.633 .838 .979 r
.37468 .53974 m .37449 .54 L .37445 .53998 L F
.038 .527 .882 r
.37416 .53981 m .37597 .54023 L .37444 .53997 L F
.37416 .53981 m .37444 .53997 L .37443 .53997 L F
.633 .838 .979 r
.37445 .53998 m .37248 .5427 L .37208 .54239 L F
.37449 .54 m .37248 .5427 L .37445 .53998 L F
.37468 .53974 m .37208 .54239 L .37185 .54222 L F
.37383 .5401 m .37185 .54222 L .37078 .54142 L F
.37468 .53974 m .37185 .54222 L .37383 .5401 L F
.37468 .53974 m .37078 .54142 L .37221 .54074 L F
.62 .818 .977 r
.37449 .54 m .37682 .54324 L .37248 .5427 L F
.448 .263 .536 r
.37497 .54488 m .37248 .5427 L .37682 .54324 L F
.62 .818 .977 r
.37504 .54033 m .37682 .54324 L .37449 .54 L F
.96 .927 .589 r
.37618 .54081 m .37497 .54488 L .37682 .54324 L F
0 0 .077 r
.37616 .54322 m .37497 .54488 L .37618 .54081 L F
0 0 0 r
.37569 .54593 m .37497 .54488 L .37616 .54322 L F
.237 .207 .621 r
.37406 .53986 m .37516 .54495 L .37616 .54322 L F
.374 .53977 m .37403 .53989 L .37406 .53986 L F
.37403 .53989 m .37516 .54495 L .37406 .53986 L F
.038 .527 .882 r
.37443 .53997 m .37597 .54023 L .37618 .54081 L F
.237 .207 .621 r
.37416 .53981 m .37616 .54322 L .37597 .54023 L F
.374 .53977 m .37406 .53986 L .37416 .53981 L F
.37406 .53986 m .37616 .54322 L .37416 .53981 L F
.633 .838 .979 r
.37221 .54074 m .37078 .54142 L .37069 .54135 L F
.301 .789 .739 r
.51172 .39993 m .50894 .40099 L .51142 .39969 L F
.51172 .39993 m .50836 .40117 L .50894 .40099 L F
.671 .232 .198 r
.47846 .43251 m .48241 .43311 L .47988 .43098 L F
.55 .3 .49 r
.47988 .43098 m .48241 .43311 L .48272 .4305 L F
.351 .507 .873 r
.54943 .38944 m .54901 .38535 L .54716 .38832 L F
.54943 .38944 m .55193 .39063 L .54901 .38535 L F
.643 .33 .427 r
.54943 .38944 m .55065 .39286 L .55193 .39063 L F
0 0 .476 r
.54996 .3928 m .55065 .39286 L .54943 .38944 L F
.55002 .39317 m .55065 .39286 L .54943 .38944 L F
.164 0 .139 r
.55193 .39063 m .55065 .39286 L .55458 .38922 L F
.349 .654 .969 r
.54973 .39225 m .55157 .39294 L .55065 .39286 L F
.55157 .39294 m .55454 .39406 L .55065 .39286 L F
0 0 .476 r
.55002 .39317 m .55065 .39286 L .54996 .3928 L F
.777 .711 .79 r
.32236 .6549 m .32676 .65543 L .32512 .65152 L F
.797 .58 .609 r
.32623 .65797 m .32676 .65543 L .32236 .6549 L F
.333 .351 .73 r
.5702 .35593 m .56987 .35532 L .57225 .3561 L F
.885 .752 .71 r
.46209 .46443 m .45875 .46466 L .46035 .46069 L F
.855 .787 .783 r
.46209 .46443 m .45719 .46673 L .45875 .46466 L F
.46209 .46443 m .45935 .46813 L .45719 .46673 L F
.715 .567 .686 r
.46209 .46443 m .46397 .46919 L .45935 .46813 L F
.744 .702 .812 r
.46486 .46121 m .46209 .46443 L .46035 .46069 L F
.683 .603 .761 r
.46486 .46121 m .46634 .46525 L .46209 .46443 L F
.696 .557 .693 r
.46619 .46813 m .46209 .46443 L .46634 .46525 L F
.46619 .46813 m .46397 .46919 L .46209 .46443 L F
.84 .723 .735 r
.43042 .51556 m .42812 .51923 L .42655 .51518 L F
.706 .518 .631 r
.46781 .45804 m .46486 .46121 L .46505 .45808 L F
.46781 .45804 m .46758 .46092 L .46486 .46121 L F
.751 .642 .74 r
.47222 .45836 m .46758 .46092 L .46781 .45804 L F
.568 .698 .929 r
.38425 .57735 m .38548 .57462 L .38288 .57532 L F
.38425 .57735 m .38687 .57665 L .38548 .57462 L F
.312 .549 .917 r
.35501 .57209 m .35588 .57036 L .35361 .5711 L F
.35501 .57209 m .35752 .57285 L .35588 .57036 L F
.532 .442 .699 r
.51736 .42413 m .51917 .41917 L .51611 .41983 L F
.51736 .42413 m .52009 .4234 L .51917 .41917 L F
.722 .521 .618 r
.39463 .55423 m .39225 .55225 L .39601 .55291 L F
.674 .47 .602 r
.39746 .55186 m .39463 .55423 L .39601 .55291 L F
.846 .801 .807 r
.41633 .52899 m .41864 .52605 L .4198 .52955 L F
.909 .837 .762 r
.4198 .52955 m .41563 .53187 L .41633 .52899 L F
.4198 .52955 m .41754 .53299 L .41563 .53187 L F
.901 .823 .76 r
.4198 .52955 m .41864 .52605 L .41976 .52445 L F
.718 .31 .275 r
.36913 .49223 m .36475 .49375 L .36494 .49125 L F
.36913 .49223 m .3676 .49442 L .36475 .49375 L F
.504 .067 .142 r
.37161 .49364 m .3676 .49442 L .36913 .49223 L F
0 0 .183 r
.51384 .41777 m .51583 .41718 L .51458 .41567 L F
.72 .612 .736 r
.51462 .41448 m .51583 .41718 L .51869 .41385 L F
.737 .607 .713 r
.45935 .46813 m .46125 .4724 L .45666 .47154 L F
.797 .69 .746 r
.43603 .49189 m .43759 .49612 L .43371 .49536 L F
.809 .797 .841 r
.43759 .49612 m .43259 .49785 L .43371 .49536 L F
.922 .779 .686 r
.43032 .50146 m .43185 .50534 L .42959 .50375 L F
.885 .839 .795 r
.43185 .50534 m .42724 .50742 L .42959 .50375 L F
.43185 .50534 m .42922 .50891 L .42724 .50742 L F
.953 .923 .739 r
.63148 .36585 m .62848 .36845 L .63047 .36454 L F
.63148 .36585 m .62967 .36981 L .62848 .36845 L F
.822 .922 .902 r
.6351 .36296 m .63148 .36585 L .63047 .36454 L F
.987 .827 .596 r
.54645 .36235 m .54716 .36394 L .54998 .36278 L F
.631 .723 .914 r
.5488 .3605 m .54998 .36278 L .55322 .36169 L F
.484 .244 .475 r
.54998 .36278 m .55273 .3647 L .55322 .36169 L F
.081 .286 .77 r
.55174 .36155 m .55273 .3647 L .54998 .36278 L F
.55174 .36155 m .54998 .36278 L .54979 .36324 L F
.39 .222 .529 r
.46525 .44391 m .4642 .44128 L .46743 .44198 L F
.46525 .44391 m .46449 .44452 L .4642 .44128 L F
.77 .575 .634 r
.46505 .45808 m .46035 .46069 L .46073 .45763 L F
.46505 .45808 m .46486 .46121 L .46035 .46069 L F
.472 .255 .502 r
.44547 .46833 m .44538 .47108 L .44266 .47161 L F
.642 .346 .455 r
.4455 .47387 m .44266 .47161 L .44538 .47108 L F
.4455 .47387 m .44296 .47448 L .44266 .47161 L F
.849 .454 .294 r
.40327 .54563 m .40015 .54508 L .40179 .54365 L F
0 0 0 r
.40179 .54365 m .40363 .54249 L .4046 .54283 L F
.641 .505 .681 r
.4046 .54283 m .40327 .54563 L .40179 .54365 L F
0 0 0 r
.40179 .54365 m .40015 .54508 L .40363 .54249 L F
.858 .47 .308 r
.64121 .3604 m .64423 .35974 L .64102 .35799 L F
.64121 .3604 m .64479 .36195 L .64423 .35974 L F
.625 .124 0 r
.49589 .43894 m .49556 .43843 L .49419 .43733 L F
.568 .332 .518 r
.4481 .47056 m .44547 .46833 L .44832 .46783 L F
.4481 .47056 m .44538 .47108 L .44547 .46833 L F
.751 .642 .74 r
.47222 .45836 m .47146 .46112 L .46758 .46092 L F
.754 .607 .695 r
.47146 .46112 m .46898 .4645 L .46758 .46092 L F
.761 .72 .814 r
.56238 .35592 m .56031 .3574 L .55817 .35496 L F
.469 .493 .8 r
.56288 .35873 m .56031 .3574 L .56238 .35592 L F
0 0 0 r
.50754 .44672 m .50658 .44923 L .50741 .44615 L F
.571 .939 .9 r
.50754 .44672 m .50741 .44615 L .50902 .44487 L F
.552 .035 0 r
.56084 .38817 m .55727 .38839 L .55864 .38681 L F
.535 .094 .148 r
.56208 .38701 m .56084 .38817 L .55864 .38681 L F
.798 .747 .806 r
.42378 .51871 m .42518 .52251 L .42105 .52211 L F
.778 .738 .815 r
.42812 .51923 m .42518 .52251 L .42378 .51871 L F
0 0 0 r
.5905 .36965 m .58991 .37221 L .59022 .37096 L F
0 0 .412 r
.59022 .37096 m .58979 .36821 L .5905 .36965 L F
.323 .027 .298 r
.4307 .48224 m .43019 .48444 L .42774 .48522 L F
.652 .448 .595 r
.43335 .48126 m .43019 .48444 L .4307 .48224 L F
.741 .653 .763 r
.41789 .54652 m .42066 .54732 L .41437 .54971 L F
.692 .701 .854 r
.41909 .54524 m .42066 .54732 L .41789 .54652 L F
.693 .674 .828 r
.5646 .35274 m .5668 .3562 L .56238 .35592 L F
.727 .518 .609 r
.5668 .3562 m .56288 .35873 L .56238 .35592 L F
.5668 .3562 m .56671 .35904 L .56288 .35873 L F
.725 .686 .812 r
.56987 .35532 m .5668 .3562 L .5646 .35274 L F
.668 .469 .606 r
.56987 .35532 m .56671 .35904 L .5668 .3562 L F
0 0 .406 r
.52086 .43756 m .52241 .43605 L .52191 .43248 L F
0 0 .148 r
.52086 .43756 m .52165 .4385 L .52241 .43605 L F
.52086 .43756 m .52053 .44069 L .52165 .4385 L F
.766 .719 .808 r
.47506 .45545 m .47423 .45753 L .47222 .45836 L F
.771 .724 .809 r
.47705 .45399 m .47423 .45753 L .47506 .45545 L F
0 0 0 r
.40705 .53777 m .40807 .5372 L .41006 .53752 L F
.40705 .53777 m .40615 .5388 L .40807 .5372 L F
.621 .581 .788 r
.30418 .63536 m .30163 .63837 L .30428 .63763 L F
.603 .419 .606 r
.30163 .63837 m .30308 .63956 L .30428 .63763 L F
.30163 .63837 m .30131 .6413 L .30308 .63956 L F
.889 .853 .399 r
.58944 .38915 m .59004 .38561 L .58979 .38651 L F
.922 .959 .788 r
.55494 .40044 m .55117 .40313 L .55267 .40093 L F
.55494 .40044 m .55237 .40379 L .55117 .40313 L F
.871 .987 .718 r
.55741 .39683 m .55494 .40044 L .55546 .39782 L F
.843 .993 .845 r
.55494 .40044 m .55267 .40093 L .55546 .39782 L F
0 0 .248 r
.5592 .41261 m .55929 .41039 L .5593 .40898 L F
.621 .732 .926 r
.37725 .56122 m .37273 .55977 L .37533 .55956 L F
.588 .811 .985 r
.37977 .56023 m .37725 .56122 L .37533 .55956 L F
.512 .265 .477 r
.31243 .62465 m .31518 .62413 L .31527 .62137 L F
.594 .305 .448 r
.31518 .62413 m .31925 .62084 L .31527 .62137 L F
.484 .848 .99 r
.59008 .35188 m .58888 .35104 L .59293 .35114 L F
.669 .596 .765 r
.46898 .4645 m .46634 .46525 L .46486 .46121 L F
.647 .512 .685 r
.46898 .4645 m .46619 .46813 L .46634 .46525 L F
.469 .147 .338 r
.42722 .46784 m .43002 .46743 L .43057 .46526 L F
.348 .02 .261 r
.43002 .46743 m .43331 .46463 L .43057 .46526 L F
.899 .815 .755 r
.38884 .55665 m .38779 .5527 L .38958 .55329 L F
.291 .064 .387 r
.39219 .54984 m .38958 .55329 L .39225 .55225 L F
.973 .759 .555 r
.39065 .55165 m .38958 .55329 L .38779 .5527 L F
.291 .064 .387 r
.39219 .54984 m .38958 .55329 L .39225 .55225 L F
.973 .759 .555 r
.39065 .55165 m .39225 .55225 L .38958 .55329 L F
.995 .841 .575 r
.55026 .41256 m .55042 .41445 L .5499 .41251 L F
0 .267 .675 r
.55042 .41445 m .55135 .41477 L .5499 .41251 L F
.733 .244 0 r
.5493 .41243 m .5499 .41251 L .55135 .41477 L F
.54815 .41112 m .5499 .41251 L .5493 .41243 L F
.995 .841 .575 r
.55004 .40981 m .55026 .41256 L .5499 .41251 L F
0 .267 .675 r
.55042 .41445 m .55313 .41589 L .55135 .41477 L F
.852 .979 .864 r
.64789 .37304 m .64399 .37517 L .6446 .37568 L F
.725 .686 .812 r
.56987 .35532 m .56467 .35277 L .56812 .35389 L F
.762 .607 .686 r
.56987 .35532 m .57157 .36055 L .56671 .35904 L F
.34 .732 .984 r
.56812 .35389 m .57225 .35497 L .56987 .35532 L F
.333 .351 .73 r
.5702 .35593 m .57157 .36055 L .56987 .35532 L F
.466 .195 .418 r
.56784 .35725 m .57092 .35479 L .56812 .35389 L F
0 .52 .798 r
.56812 .35389 m .57128 .35451 L .57225 .35497 L F
.466 .195 .418 r
.57092 .35479 m .57128 .35451 L .56812 .35389 L F
.725 .686 .812 r
.56467 .35277 m .5646 .35274 L .56812 .35389 L F
.801 .653 .698 r
.41548 .54673 m .41297 .54955 L .41303 .54703 L F
.761 .619 .701 r
.41548 .54673 m .41437 .54971 L .41297 .54955 L F
.061 .612 .83 r
.60437 .37319 m .60741 .37331 L .60861 .37383 L F
.322 .768 .961 r
.60741 .37331 m .61135 .37374 L .60861 .37383 L F
.696 .965 .73 r
.55741 .39683 m .55546 .39782 L .55872 .39471 L F
.76 .447 .456 r
.60311 .38239 m .60749 .38526 L .60739 .38347 L F
.656 .242 .247 r
.60749 .38526 m .61006 .38565 L .60739 .38347 L F
.757 .675 .771 r
.39146 .56046 m .38822 .56356 L .38659 .55955 L F
.683 .532 .676 r
.56051 .36817 m .55628 .36568 L .56015 .36628 L F
.56051 .36817 m .5589 .37022 L .55628 .36568 L F
.604 .055 0 r
.55817 .35496 m .56245 .35704 L .56238 .35592 L F
0 0 0 r
.56238 .35592 m .56384 .35387 L .5646 .35274 L F
.56238 .35592 m .56245 .35704 L .56384 .35387 L F
.489 .32 .578 r
.54242 .41011 m .5427 .41319 L .53976 .41375 L F
.471 .526 .832 r
.54372 .41686 m .53976 .41375 L .5427 .41319 L F
.306 .793 .891 r
.60944 .34466 m .60788 .34427 L .60793 .34455 L F
.136 0 .281 r
.61179 .34165 m .61175 .34363 L .60944 .34466 L F
.436 0 0 r
.61175 .34363 m .60788 .34427 L .60944 .34466 L F
.336 0 0 r
.56265 .39141 m .56621 .39004 L .56299 .39026 L F
.63 .352 .479 r
.40109 .49177 m .40079 .49516 L .39682 .49506 L F
.63 .353 .479 r
.4037 .49441 m .40109 .49177 L .40384 .49185 L F
.4037 .49441 m .40079 .49516 L .40109 .49177 L F
.714 .652 .787 r
.56671 .35904 m .56387 .36211 L .56288 .35873 L F
.861 .626 .581 r
.33143 .63422 m .33189 .6314 L .32792 .63103 L F
.499 .803 .999 r
.4896 .45539 m .48866 .45788 L .48736 .45703 L F
.589 .186 .246 r
.38197 .48688 m .384 .48755 L .38158 .48546 L F
.677 .976 .818 r
.52857 .44428 m .52798 .44396 L .52454 .44657 L F
.762 .955 .64 r
.53127 .44071 m .52973 .44175 L .52857 .44428 L F
.777 .989 .751 r
.52857 .44428 m .52973 .44175 L .52798 .44396 L F
.576 .554 .792 r
.52432 .42402 m .52767 .42371 L .52553 .41912 L F
.54 .31 .515 r
.52573 .42678 m .52767 .42371 L .52432 .42402 L F
.52432 .42402 m .52767 .42371 L .52573 .42678 L F
.666 .696 .868 r
.42649 .55374 m .42718 .54998 L .42419 .55281 L F
.733 .479 .544 r
.42419 .55281 m .42646 .55496 L .42649 .55374 L F
.98 .728 .477 r
.34181 .52951 m .3416 .5323 L .33994 .5284 L F
.509 .829 1 r
.34181 .52951 m .33994 .5284 L .34281 .52773 L F
.98 .728 .477 r
.33994 .5284 m .34181 .52951 L .34281 .52773 L F
.33994 .5284 m .3416 .5323 L .34181 .52951 L F
.338 .029 .285 r
.43633 .46075 m .43863 .46008 L .43947 .45786 L F
.23 0 .237 r
.43863 .46008 m .44181 .45671 L .43947 .45786 L F
.658 .697 .875 r
.31012 .6618 m .31429 .66261 L .31258 .66091 L F
.717 .709 .842 r
.31429 .66261 m .31526 .65794 L .31258 .66091 L F
.31429 .66261 m .31706 .66172 L .31526 .65794 L F
.822 .922 .902 r
.6351 .36296 m .63047 .36454 L .63372 .36139 L F
0 0 .038 r
.58873 .36366 m .58876 .36091 L .5887 .36146 L F
.759 .674 .123 r
.58899 .35893 m .5887 .36146 L .58877 .3591 L F
0 0 .038 r
.58876 .36091 m .58877 .3591 L .5887 .36146 L F
.705 .641 .083 r
.58865 .3619 m .5887 .36146 L .58899 .35893 L F
.58856 .36272 m .5887 .36146 L .58865 .3619 L F
0 0 .068 r
.58856 .36272 m .58873 .36366 L .5887 .36146 L F
.58856 .36272 m .58854 .36565 L .58873 .36366 L F
.757 .675 .771 r
.39146 .56046 m .38659 .55955 L .38878 .55884 L F
.58 .715 .935 r
.39433 .55899 m .39146 .56046 L .38878 .55884 L F
.816 .8 .836 r
.45935 .46813 m .45535 .46788 L .45719 .46673 L F
.833 .763 .785 r
.45935 .46813 m .45666 .47154 L .45535 .46788 L F
.73 .454 .51 r
.48241 .43311 m .48677 .43079 L .48272 .4305 L F
.48241 .43311 m .48713 .43428 L .48677 .43079 L F
.608 .095 .003 r
.48516 .43217 m .48953 .43252 L .48677 .43079 L F
0 .252 .722 r
.48813 .43105 m .48953 .43252 L .48677 .43079 L F
.48813 .43105 m .48677 .43079 L .48516 .43217 L F
.419 .068 .26 r
.41712 .47368 m .41993 .47316 L .41767 .47168 L F
.438 .054 .213 r
.41767 .47168 m .41993 .47316 L .42047 .47135 L F
.365 .021 .242 r
.41437 .47429 m .41712 .47368 L .41767 .47168 L F
.814 .694 .733 r
.45814 .47838 m .45399 .47793 L .45648 .47433 L F
.889 .76 .712 r
.32867 .64034 m .33068 .64174 L .32911 .63782 L F
.831 .619 .616 r
.32618 .64413 m .33068 .64174 L .32867 .64034 L F
.32618 .64413 m .33046 .64487 L .33068 .64174 L F
.429 .28 .576 r
.54781 .35672 m .55132 .35813 L .55124 .35521 L F
.54781 .35672 m .54905 .36014 L .55132 .35813 L F
0 0 .466 r
.35017 .5661 m .35053 .57109 L .35148 .5686 L F
.44 .654 .95 r
.35053 .57109 m .35361 .5711 L .35148 .5686 L F
.565 .026 0 r
.52695 .42863 m .52857 .42746 L .52435 .42699 L F
.743 .311 .224 r
.38718 .49579 m .3852 .4976 L .38282 .4949 L F
.322 0 0 r
.38965 .49575 m .3852 .4976 L .38718 .49579 L F
.614 .713 .916 r
.53767 .37116 m .53888 .36761 L .53597 .36851 L F
.895 .835 .779 r
.42724 .50742 m .42922 .50891 L .42683 .51222 L F
.394 .101 .344 r
.48346 .41667 m .4861 .41591 L .48656 .41374 L F
.348 .073 .346 r
.4861 .41591 m .48907 .4128 L .48656 .41374 L F
.346 .817 .753 r
.34154 .51246 m .33794 .51352 L .33721 .51396 L F
0 0 0 r
.34156 .50965 m .34148 .50987 L .34103 .50999 L F
0 .02 .593 r
.34103 .50999 m .34154 .51246 L .34041 .51015 L F
.89 .986 .801 r
.33598 .5123 m .33526 .5107 L .33758 .51 L F
.834 .999 .825 r
.33758 .51 m .33526 .5107 L .33826 .50749 L F
.727 .967 .706 r
.33826 .50749 m .33526 .5107 L .3362 .50875 L F
.929 .717 .595 r
.33845 .5125 m .3362 .50875 L .33526 .5107 L F
.887 .979 .824 r
.34103 .50999 m .33846 .51293 L .34154 .51246 L F
.33846 .51293 m .33846 .51298 L .34154 .51246 L F
.33841 .51299 m .33838 .51339 L .34154 .51246 L F
0 0 .032 r
.34103 .50999 m .34071 .51211 L .34007 .51243 L F
.929 .717 .595 r
.33948 .51308 m .3392 .5127 L .33895 .51278 L F
.887 .979 .824 r
.33846 .51293 m .33841 .51299 L .33846 .51298 L F
.318 .807 .845 r
.33798 .51315 m .33845 .5125 L .33526 .5107 L F
.33838 .51351 m .33841 .51299 L .33798 .51315 L F
.33841 .51299 m .33845 .5125 L .33798 .51315 L F
.33721 .51396 m .33838 .51351 L .33526 .5107 L F
.887 .979 .824 r
.33839 .51329 m .33794 .51352 L .33838 .51339 L F
0 0 .032 r
.33846 .51293 m .33895 .51278 L .33841 .51299 L F
.318 .807 .845 r
.33838 .51351 m .33948 .51308 L .33845 .5125 L F
0 0 .032 r
.34103 .50999 m .34007 .51243 L .33919 .5127 L F
.34022 .51092 m .33919 .5127 L .33846 .51293 L F
.34103 .50999 m .33919 .5127 L .34022 .51092 L F
.33841 .51299 m .33918 .51273 L .33794 .51352 L F
0 0 .488 r
.33598 .5123 m .33721 .51396 L .33526 .5107 L F
.924 .693 .57 r
.33907 .51291 m .33505 .51432 L .33553 .51147 L F
.318 .807 .845 r
.33721 .51396 m .33794 .51352 L .33948 .51308 L F
.676 .451 .572 r
.33724 .51595 m .33948 .51308 L .33794 .51352 L F
.33724 .51595 m .33909 .516 L .33948 .51308 L F
.924 .693 .57 r
.33948 .51308 m .33909 .516 L .33833 .51568 L F
.416 .252 .549 r
.34071 .51211 m .34087 .51494 L .33833 .51565 L F
.33834 .51473 m .33833 .51565 L .33724 .51595 L F
.33904 .51296 m .33724 .51595 L .33794 .51352 L F
.33903 .51298 m .33724 .51595 L .33904 .51296 L F
.33833 .51474 m .33724 .51595 L .33905 .51296 L F
.651 .337 .428 r
.33724 .51595 m .3381 .51827 L .33909 .516 L F
.947 .621 .378 r
.3381 .51827 m .33505 .51432 L .33833 .51568 L F
.33829 .51783 m .33833 .51568 L .33909 .516 L F
.3381 .51827 m .33833 .51568 L .33829 .51783 L F
.416 .252 .549 r
.33839 .51468 m .33833 .51565 L .33833 .51565 L F
.33839 .51468 m .33833 .51565 L .33834 .51473 L F
.924 .693 .57 r
.33948 .51308 m .33833 .51568 L .33837 .51502 L F
.416 .252 .549 r
.34071 .51211 m .33833 .51565 L .33839 .51468 L F
.924 .693 .57 r
.33837 .51502 m .33833 .51568 L .33805 .51557 L F
.33894 .51323 m .33805 .51557 L .33505 .51432 L F
.33948 .51308 m .33805 .51557 L .33894 .51323 L F
.416 .252 .549 r
.33905 .51296 m .33903 .51298 L .33904 .51296 L F
.924 .693 .57 r
.33948 .51308 m .33894 .51323 L .33907 .51291 L F
.33894 .51323 m .33905 .51296 L .33907 .51291 L F
.929 .717 .595 r
.33948 .51308 m .33907 .51291 L .3392 .5127 L F
.416 .252 .549 r
.34071 .51211 m .33833 .51474 L .33905 .51296 L F
.924 .693 .57 r
.33894 .51323 m .33888 .51325 L .33905 .51296 L F
0 0 .032 r
.33918 .51273 m .33905 .51296 L .33794 .51352 L F
.924 .693 .57 r
.33888 .51325 m .33505 .51432 L .33907 .51291 L F
.929 .717 .595 r
.33895 .51278 m .33841 .51167 L .33845 .5125 L F
.3392 .5127 m .33841 .51167 L .33895 .51278 L F
.33841 .51167 m .3362 .50875 L .33845 .5125 L F
.3392 .5127 m .33553 .51147 L .3362 .50875 L F
0 0 .032 r
.33895 .51278 m .34007 .51243 L .33841 .51299 L F
.929 .717 .595 r
.33907 .51291 m .33553 .51147 L .3392 .5127 L F
0 0 .032 r
.33918 .51273 m .34007 .51243 L .33905 .51296 L F
0 0 0 r
.34148 .50987 m .34071 .51211 L .34103 .50999 L F
0 .02 .593 r
.34103 .50999 m .34041 .51015 L .33966 .50863 L F
.438 .122 .33 r
.50836 .40117 m .5077 .40494 L .50474 .40568 L F
.192 0 .256 r
.50893 .40314 m .50836 .40117 L .51172 .39993 L F
.50893 .40314 m .5077 .40494 L .50836 .40117 L F
.11 .278 .756 r
.39379 .54854 m .39442 .55244 L .39219 .54984 L F
.864 .921 .865 r
.39225 .55225 m .39379 .54854 L .39219 .54984 L F
.431 .154 .391 r
.42774 .48522 m .42735 .48794 L .42456 .48838 L F
.509 .279 .501 r
.43019 .48444 m .42735 .48794 L .42774 .48522 L F
.661 .777 .935 r
.36452 .57278 m .36442 .57451 L .36879 .57354 L F
.35 .825 .869 r
.53522 .42581 m .53121 .42649 L .53368 .42511 L F
.721 .865 .949 r
.53681 .42279 m .53522 .42581 L .53368 .42511 L F
.53681 .42279 m .53823 .42449 L .53522 .42581 L F
.594 .305 .448 r
.31518 .62413 m .32017 .62423 L .31925 .62084 L F
.59 .317 .471 r
.32171 .62367 m .31925 .62084 L .32017 .62423 L F
.32171 .62367 m .3219 .62102 L .31925 .62084 L F
.674 .941 .964 r
.49924 .46594 m .49837 .46807 L .50033 .46661 L F
.74 .99 .88 r
.49924 .46594 m .49742 .46764 L .49837 .46807 L F
0 0 0 r
.52334 .39162 m .52 .39499 L .52137 .39382 L F
.60295 .36259 m .60221 .36462 L .60021 .36606 L F
.60221 .36462 m .60047 .3687 L .60021 .36606 L F
.229 .238 .662 r
.5986 .34741 m .59733 .3508 L .59621 .34947 L F
.5986 .34741 m .5984 .34976 L .59733 .3508 L F
.582 .331 .502 r
.41788 .48852 m .41799 .49135 L .41533 .4911 L F
.709 .513 .621 r
.41788 .48852 m .42184 .49227 L .41799 .49135 L F
.41788 .48852 m .42211 .48903 L .42184 .49227 L F
.796 .803 .858 r
.44544 .4877 m .44337 .48947 L .44137 .48763 L F
.669 .974 .882 r
.53127 .44071 m .53499 .43836 L .53252 .43878 L F
.665 .928 .638 r
.53252 .43878 m .52973 .44175 L .53127 .44071 L F
.764 .719 .81 r
.47703 .43997 m .48306 .4411 L .47965 .43643 L F
.346 .206 .543 r
.47703 .43997 m .47945 .44156 L .48306 .4411 L F
.372 .555 .903 r
.47965 .43643 m .48306 .4411 L .48396 .43972 L F
.701 .98 .899 r
.48396 .43972 m .48306 .4411 L .47945 .44156 L F
.762 .729 .822 r
.31526 .65794 m .31706 .66172 L .31964 .6584 L F
.667 .584 .753 r
.31706 .66172 m .32152 .66295 L .31964 .6584 L F
.538 .328 .543 r
.42456 .48838 m .42184 .49227 L .42211 .48903 L F
.831 .653 .661 r
.32623 .62412 m .33042 .62464 L .32884 .62059 L F
.838 .659 .661 r
.32593 .62707 m .33042 .62464 L .32623 .62412 L F
.32593 .62707 m .3299 .62758 L .33042 .62464 L F
.755 .619 .709 r
.54177 .37589 m .54573 .37873 L .5447 .3754 L F
.681 .606 .765 r
.5447 .3754 m .54573 .37873 L .55048 .37635 L F
.799 .748 .805 r
.45666 .47154 m .45276 .47085 L .45535 .46788 L F
.821 .608 .615 r
.45648 .47433 m .45276 .47085 L .45666 .47154 L F
.887 .877 .82 r
.47872 .46374 m .48326 .46058 L .48146 .46 L F
.677 .94 .662 r
.48326 .46058 m .4843 .459 L .48146 .46 L F
.872 .847 .816 r
.56505 .36027 m .56724 .36224 L .56543 .36001 L F
.681 .205 .116 r
.56323 .36354 m .56724 .36224 L .56505 .36027 L F
.56323 .36354 m .56985 .36542 L .56724 .36224 L F
.328 .449 .832 r
.56724 .36224 m .56784 .35725 L .56543 .36001 L F
.56724 .36224 m .57074 .36153 L .56784 .35725 L F
0 .094 .611 r
.56724 .36224 m .5695 .36369 L .57074 .36153 L F
.56724 .36224 m .56985 .36542 L .5695 .36369 L F
.646 .633 .823 r
.31012 .6618 m .31266 .65896 L .30882 .65791 L F
.31012 .6618 m .31258 .66091 L .31266 .65896 L F
.761 .53 .583 r
.40829 .49202 m .4037 .49441 L .40384 .49185 L F
.40829 .49202 m .40796 .49473 L .4037 .49441 L F
.523 .316 .541 r
.40829 .49202 m .41071 .49425 L .40796 .49473 L F
.652 .289 .342 r
.41079 .49223 m .41071 .49425 L .40829 .49202 L F
.527 .518 .789 r
.54077 .3863 m .54483 .38985 L .54346 .38541 L F
.885 .911 .84 r
.47602 .48642 m .48022 .48438 L .47891 .4836 L F
.47602 .48642 m .47722 .48749 L .48022 .48438 L F
.867 .98 .848 r
.48182 .48035 m .48022 .48438 L .48318 .48136 L F
.48182 .48035 m .47891 .4836 L .48022 .48438 L F
.586 .186 .25 r
.49845 .45213 m .50082 .453 L .49819 .45109 L F
.488 0 0 r
.48979 .43549 m .49419 .43733 L .49035 .43507 L F
.932 .747 .629 r
.48504 .45963 m .48155 .46318 L .4843 .459 L F
.48504 .45963 m .48397 .46475 L .48155 .46318 L F
.723 .53 .629 r
.5218 .37906 m .52581 .38301 L .52407 .37833 L F
.168 0 .027 r
.60485 .36361 m .60221 .36462 L .60295 .36259 L F
.676 .663 .829 r
.55715 .38012 m .55236 .37637 L .55591 .37775 L F
.69 .767 .91 r
.55591 .37775 m .55715 .38012 L .55992 .37872 L F
.404 .01 .174 r
.39531 .48395 m .39793 .48379 L .39862 .48213 L F
.492 .162 .335 r
.39793 .48379 m .40112 .48143 L .39862 .48213 L F
.985 .803 .576 r
.5634 .37699 m .56413 .37918 L .56379 .37549 L F
0 .328 .728 r
.5634 .37699 m .56706 .3789 L .56413 .37918 L F
.455 .88 .919 r
.61074 .39778 m .61146 .39645 L .60908 .398 L F
.61074 .39778 m .61348 .39678 L .61146 .39645 L F
.669 .596 .765 r
.46898 .4645 m .46486 .46121 L .46758 .46092 L F
.719 .833 .935 r
.35976 .55228 m .35722 .55401 L .3556 .552 L F
.35976 .55228 m .35722 .55401 L .3556 .552 L F
.699 .504 .621 r
.45601 .46054 m .45386 .46381 L .45432 .46134 L F
.764 .554 .613 r
.41118 .54552 m .40772 .54221 L .41142 .54287 L F
.797 .596 .629 r
.41142 .54287 m .41303 .54703 L .41118 .54552 L F
.425 .082 .279 r
.53487 .36239 m .53751 .36199 L .53774 .35981 L F
.636 .259 .312 r
.53774 .35981 m .54321 .36148 L .54159 .35876 L F
.53774 .35981 m .53751 .36199 L .54321 .36148 L F
.793 .703 .765 r
.42655 .51518 m .42812 .51923 L .42378 .51871 L F
.179 .71 .841 r
.39433 .55899 m .39619 .55885 L .39829 .55901 L F
.4 .47 .817 r
.39935 .55558 m .39829 .55901 L .39619 .55885 L F
.39935 .55558 m .40063 .55961 L .39829 .55901 L F
.386 .11 .368 r
.43331 .46463 m .43593 .46389 L .43633 .46075 L F
.37 .096 .362 r
.43593 .46389 m .43863 .46008 L .43633 .46075 L F
.987 .827 .596 r
.54645 .36235 m .54582 .36366 L .54716 .36394 L F
.528 .302 .517 r
.56539 .36936 m .56758 .37201 L .56354 .3715 L F
.704 .311 .3 r
.56833 .37185 m .56758 .37201 L .56539 .36936 L F
.716 .248 .136 r
.4203 .5663 m .41374 .56482 L .42091 .5634 L F
.4203 .5663 m .41683 .56693 L .41374 .56482 L F
.468 0 0 r
.4203 .5663 m .41817 .56735 L .41683 .56693 L F
0 0 0 r
.42355 .56357 m .4203 .5663 L .42091 .5634 L F
.42355 .56357 m .42189 .56523 L .4203 .5663 L F
.42189 .56523 m .41817 .56735 L .4203 .5663 L F
.886 .95 .844 r
.44746 .51775 m .44586 .52225 L .44861 .51845 L F
.867 .99 .827 r
.45027 .51446 m .44861 .51845 L .45161 .51542 L F
.45027 .51446 m .44746 .51775 L .44861 .51845 L F
.562 .084 .078 r
.63353 .35566 m .63204 .35728 L .62934 .35576 L F
.873 .495 .322 r
.63353 .35566 m .63399 .35833 L .63204 .35728 L F
.531 .366 .603 r
.52265 .41825 m .52392 .42106 L .52553 .41912 L F
.233 .149 .55 r
.47829 .4686 m .47785 .47124 L .47906 .47016 L F
.47829 .4686 m .47785 .47124 L .47906 .47016 L F
.655 .879 .981 r
.41029 .5524 m .40598 .55246 L .40859 .54895 L F
.741 .668 .779 r
.41297 .54955 m .41029 .5524 L .40859 .54895 L F
.967 .727 .292 r
.59112 .37905 m .59026 .37501 L .59099 .37691 L F
.514 .168 .318 r
.41533 .4911 m .41071 .49425 L .41079 .49223 L F
.922 .816 .725 r
.63965 .35422 m .64328 .35231 L .63941 .3511 L F
.63965 .35422 m .64167 .3558 L .64328 .35231 L F
.735 .983 .908 r
.51612 .454 m .51186 .45572 L .51331 .45667 L F
0 .025 .533 r
.35807 .55867 m .35622 .56325 L .35454 .56215 L F
.35807 .55867 m .35746 .56201 L .35622 .56325 L F
.07 .153 .645 r
.35746 .56201 m .35831 .56602 L .35622 .56325 L F
.665 .95 .954 r
.57087 .39549 m .57475 .39394 L .57212 .39338 L F
.73 .964 .939 r
.57212 .39338 m .57475 .39394 L .57657 .39225 L F
.725 .584 .697 r
.29773 .64892 m .30007 .64841 L .29917 .6446 L F
.248 .267 .685 r
.29917 .6446 m .30215 .64987 L .30182 .64389 L F
.29917 .6446 m .30007 .64841 L .30215 .64987 L F
0 0 0 r
.49513 .45346 m .49219 .45709 L .49392 .45605 L F
.49392 .45605 m .49845 .45213 L .49513 .45346 L F
.609 .675 .888 r
.37978 .57595 m .38098 .57205 L .37865 .5724 L F
.37978 .57595 m .38288 .57532 L .38098 .57205 L F
.906 .81 .741 r
.40495 .56336 m .40705 .564 L .40705 .56097 L F
.967 .716 .502 r
.60047 .3687 m .60029 .37143 L .60207 .37187 L F
.572 0 0 r
.60029 .37143 m .60437 .37319 L .60207 .37187 L F
.607 .823 .983 r
.41993 .55198 m .42419 .55281 L .42252 .55098 L F
.812 .698 .739 r
.41993 .55198 m .4215 .55669 L .42419 .55281 L F
.554 .35 .558 r
.4215 .55669 m .4246 .55648 L .42419 .55281 L F
.761 .923 .942 r
.42419 .55281 m .4233 .55058 L .42252 .55098 L F
.42419 .55281 m .42718 .54998 L .4233 .55058 L F
.733 .479 .544 r
.42419 .55281 m .4246 .55648 L .42646 .55496 L F
.334 .015 .266 r
.54445 .4113 m .54447 .41129 L .54242 .41011 L F
0 0 .043 r
.54514 .41168 m .54683 .41007 L .54455 .41136 L F
.538 .561 .826 r
.54516 .41131 m .54683 .41007 L .54514 .41168 L F
0 0 0 r
.54455 .41136 m .54614 .41047 L .54515 .41132 L F
.54614 .41047 m .54655 .41023 L .54494 .41151 L F
.54614 .41047 m .54494 .41151 L .54491 .41153 L F
.54655 .41023 m .54683 .41007 L .54491 .41153 L F
.538 .561 .826 r
.54546 .40611 m .54683 .41007 L .54516 .41131 L F
0 0 0 r
.54489 .41152 m .54515 .41132 L .54491 .41153 L F
.54455 .41136 m .54515 .41132 L .54489 .41152 L F
.538 .561 .826 r
.54546 .40611 m .54516 .41131 L .54179 .40901 L F
.54516 .41131 m .54514 .41168 L .54494 .41151 L F
.54516 .41131 m .54494 .41151 L .54179 .40901 L F
0 0 0 r
.54455 .41136 m .54465 .41141 L .54365 .41292 L F
.354 0 0 r
.54456 .41137 m .54514 .41168 L .54457 .41137 L F
.286 0 0 r
.54514 .41168 m .54463 .41138 L .54465 .41141 L F
.354 0 0 r
.54465 .41141 m .54514 .41168 L .54456 .41137 L F
.286 0 0 r
.54514 .41168 m .54465 .41141 L .54479 .41163 L F
.354 0 0 r
.54478 .41147 m .54514 .41168 L .54465 .41141 L F
.286 0 0 r
.54514 .41168 m .54479 .41163 L .54494 .41151 L F
0 0 0 r
.54479 .41163 m .54511 .41162 L .5449 .4118 L F
.54465 .41141 m .54491 .41153 L .54479 .41163 L F
.54491 .41153 m .54511 .41162 L .54479 .41163 L F
.54465 .41141 m .5449 .4118 L .54365 .41292 L F
.354 0 0 r
.54242 .41011 m .54457 .41137 L .54455 .41136 L F
.191 .104 .521 r
.54455 .41136 m .5427 .41319 L .54242 .41011 L F
.334 .015 .266 r
.53949 .41392 m .54445 .4113 L .54242 .41011 L F
.471 .526 .832 r
.54372 .41686 m .5427 .41319 L .54196 .41496 L F
0 0 .027 r
.54196 .41496 m .5427 .41319 L .54455 .41136 L F
.693 .914 .97 r
.54021 .41095 m .54447 .41129 L .53949 .41392 L F
0 0 0 r
.54407 .4122 m .54196 .41496 L .54455 .41136 L F
.54365 .41292 m .54246 .41436 L .54407 .4122 L F
.54246 .41436 m .54196 .41496 L .54407 .4122 L F
.354 0 0 r
.54242 .41011 m .54478 .41147 L .54456 .41137 L F
.54242 .41011 m .54447 .41129 L .54514 .41168 L F
.286 0 0 r
.54471 .41133 m .54021 .41095 L .54179 .40901 L F
.54494 .41151 m .54461 .41147 L .54471 .41133 L F
.54479 .41163 m .54447 .41129 L .54021 .41095 L F
.54463 .41138 m .54447 .41129 L .54479 .41163 L F
.54461 .41147 m .54021 .41095 L .54471 .41133 L F
.54479 .41163 m .54021 .41095 L .54494 .41151 L F
0 0 0 r
.54491 .41153 m .54683 .41007 L .54511 .41162 L F
.812 .771 .815 r
.44419 .4841 m .44544 .4877 L .44137 .48763 L F
.797 .764 .823 r
.44823 .48457 m .44544 .4877 L .44419 .4841 L F
.66 .845 .971 r
.36293 .56616 m .36048 .56751 L .35831 .56602 L F
.967 .891 .514 r
.58045 .38122 m .58011 .38632 L .58099 .38276 L F
.925 .823 .725 r
.41754 .53299 m .41654 .53555 L .41563 .53187 L F
.785 .645 .707 r
.42091 .5634 m .41374 .56482 L .41883 .55975 L F
.852 .979 .864 r
.64789 .37304 m .64579 .37268 L .64399 .37517 L F
.753 .773 .869 r
.64789 .37304 m .64932 .3679 L .64827 .36995 L F
.64789 .37304 m .64989 .37087 L .64932 .3679 L F
.89 .969 .831 r
.64827 .36995 m .64579 .37268 L .64789 .37304 L F
.804 .712 .763 r
.60838 .33981 m .60455 .34074 L .60692 .3403 L F
.153 .523 .918 r
.60838 .33981 m .61104 .34002 L .61179 .34165 L F
.135 0 0 r
.60838 .33981 m .60692 .3403 L .61104 .34002 L F
.634 .527 .714 r
.48012 .45089 m .47705 .45399 L .47735 .45204 L F
.576 .401 .607 r
.29692 .65334 m .30007 .64841 L .29773 .64892 L F
.29692 .65334 m .30069 .65365 L .30007 .64841 L F
.30069 .65365 m .30114 .65343 L .30007 .64841 L F
.285 .21 .594 r
.30007 .64841 m .30114 .65343 L .30248 .65093 L F
.568 .583 .828 r
.30196 .65302 m .30248 .65093 L .30028 .65365 L F
.30069 .65365 m .30028 .65365 L .29999 .654 L F
.30196 .65302 m .30028 .65365 L .30069 .65365 L F
.268 0 0 r
.29971 .65365 m .30069 .65365 L .29692 .65334 L F
.568 .583 .828 r
.29999 .654 m .30248 .65093 L .29971 .65365 L F
.268 0 0 r
.29971 .65365 m .30119 .65369 L .30069 .65365 L F
.285 .21 .594 r
.30114 .65343 m .30119 .65369 L .30248 .65093 L F
.568 .583 .828 r
.3013 .65566 m .30196 .65302 L .30114 .65343 L F
.30049 .65463 m .30114 .65343 L .29999 .654 L F
.3013 .65566 m .30114 .65343 L .30049 .65463 L F
.576 .401 .607 r
.30069 .65365 m .30119 .65369 L .30114 .65343 L F
.285 .21 .594 r
.30007 .64841 m .30248 .65093 L .30215 .64987 L F
.055 0 0 r
.61454 .38299 m .61597 .38364 L .61383 .38144 L F
.61454 .38299 m .61327 .38443 L .61597 .38364 L F
.611 .392 .559 r
.3121 .62733 m .31518 .62413 L .31243 .62465 L F
.668 .536 .694 r
.45386 .46381 m .4511 .46697 L .45139 .46466 L F
.893 .935 .561 r
.55237 .40379 m .55111 .40496 L .55117 .40313 L F
.55237 .40379 m .55121 .4064 L .55111 .40496 L F
.008 0 0 r
.55937 .39256 m .56101 .39313 L .56265 .39141 L F
.55937 .39256 m .55872 .39471 L .56101 .39313 L F
.749 .532 .601 r
.32623 .62412 m .32884 .62059 L .32647 .62096 L F
.834 .994 .749 r
.46182 .45034 m .45906 .45376 L .46063 .45232 L F
.399 0 .088 r
.384 .48755 m .38667 .48731 L .38848 .48491 L F
.539 .11 .175 r
.38848 .48491 m .38667 .48731 L .39104 .48658 L F
.536 .115 .189 r
.38848 .48491 m .39104 .48658 L .39107 .48523 L F
.671 .472 .607 r
.46073 .45763 m .46035 .46069 L .45601 .46054 L F
.324 0 .221 r
.47986 .42003 m .48256 .41939 L .48346 .41667 L F
.354 .013 .24 r
.48256 .41939 m .4861 .41591 L .48346 .41667 L F
.641 .505 .681 r
.4046 .54283 m .40482 .54652 L .40327 .54563 L F
.731 .387 .397 r
.40482 .54652 m .40438 .5484 L .40327 .54563 L F
.356 .688 .981 r
.36674 .55829 m .36576 .55997 L .36456 .55989 L F
.36674 .55829 m .36889 .56017 L .36576 .55997 L F
.571 .812 .99 r
.37126 .57252 m .37574 .57315 L .37409 .57142 L F
.594 .777 .968 r
.37409 .57142 m .37574 .57315 L .37865 .5724 L F
.899 .815 .755 r
.38884 .55665 m .38544 .55662 L .38779 .5527 L F
.853 .758 .757 r
.38884 .55665 m .38472 .55789 L .38544 .55662 L F
.38884 .55665 m .38659 .55955 L .38472 .55789 L F
.664 .47 .613 r
.38878 .55884 m .38659 .55955 L .38884 .55665 L F
.452 .881 .802 r
.48087 .42825 m .48543 .4266 L .48368 .42716 L F
.492 .89 .738 r
.48368 .42716 m .48543 .4266 L .48741 .42518 L F
.751 .673 .775 r
.32152 .66295 m .32356 .66157 L .32408 .65951 L F
.808 .732 .781 r
.32408 .65951 m .32356 .66157 L .32623 .65797 L F
.751 .673 .775 r
.32152 .66295 m .32408 .65951 L .31964 .6584 L F
.522 .229 .41 r
.56758 .37201 m .56528 .37441 L .56354 .3715 L F
.074 .071 .549 r
.56354 .3715 m .56528 .37441 L .56379 .37549 L F
.251 .368 .788 r
.53955 .42164 m .53823 .42449 L .53681 .42279 L F
.53955 .42164 m .54099 .42577 L .53823 .42449 L F
.797 .58 .609 r
.32623 .65797 m .32236 .6549 L .32408 .65951 L F
.085 0 0 r
.59409 .40376 m .59753 .40261 L .59714 .40297 L F
.538 .328 .543 r
.42456 .48838 m .42471 .49117 L .42184 .49227 L F
.625 .394 .547 r
.42733 .49061 m .42456 .48838 L .42735 .48794 L F
.42733 .49061 m .42471 .49117 L .42456 .48838 L F
.634 .527 .714 r
.48012 .45089 m .47735 .45204 L .47951 .44775 L F
0 0 0 r
.47208 .42803 m .46844 .42998 L .4702 .42952 L F
.467 .198 .422 r
.46725 .43231 m .4702 .42952 L .46844 .42998 L F
.907 .982 .728 r
.4046 .54283 m .40363 .54249 L .40506 .54007 L F
.658 .504 .664 r
.40772 .54221 m .40482 .54652 L .4046 .54283 L F
.868 .53 .411 r
.64708 .36435 m .64902 .36211 L .64479 .36195 L F
.64708 .36435 m .64938 .36486 L .64902 .36211 L F
.004 0 0 r
.56434 .38624 m .56084 .38817 L .56208 .38701 L F
0 0 0 r
.56732 .39626 m .57087 .39549 L .56979 .39501 L F
.665 .95 .954 r
.57087 .39549 m .57212 .39338 L .56979 .39501 L F
.947 .955 .727 r
.47557 .43756 m .47442 .44057 L .47703 .43997 L F
.451 .28 .557 r
.47469 .4438 m .47703 .43997 L .47442 .44057 L F
.546 .392 .623 r
.30182 .64389 m .30308 .63956 L .30131 .6413 L F
.924 .944 .792 r
.44459 .52117 m .44348 .52584 L .44586 .52225 L F
.886 .95 .844 r
.44746 .51775 m .44459 .52117 L .44586 .52225 L F
.72 .791 .908 r
.38659 .55955 m .38402 .56076 L .38229 .55904 L F
.834 .999 .825 r
.33758 .51 m .33826 .50749 L .33966 .50863 L F
.585 .708 .928 r
.53585 .41558 m .53695 .4181 L .53988 .41695 L F
.271 .776 .791 r
.59409 .40376 m .59501 .40313 L .59246 .40444 L F
.59409 .40376 m .59714 .40297 L .59501 .40313 L F
.893 .904 .827 r
.57814 .35692 m .57598 .36064 L .57809 .36036 L F
.693 .16 0 r
.5793 .36275 m .57809 .36036 L .57598 .36064 L F
0 .047 .59 r
.57809 .36036 m .58175 .36429 L .58252 .36565 L F
.693 .16 0 r
.5793 .36275 m .58175 .36429 L .57809 .36036 L F
.752 .748 .849 r
.62241 .35464 m .6199 .35652 L .61927 .3554 L F
.61927 .3554 m .6199 .35652 L .62241 .35464 L F
.546 .392 .623 r
.30182 .64389 m .30455 .64377 L .30308 .63956 L F
.581 .387 .584 r
.30308 .63956 m .30644 .6377 L .30428 .63763 L F
.30308 .63956 m .3076 .64021 L .30644 .6377 L F
.481 .278 .527 r
.30455 .64377 m .3076 .64021 L .30308 .63956 L F
.444 0 0 r
.39417 .49513 m .39234 .49676 L .38965 .49575 L F
.589 .094 .047 r
.39699 .49696 m .39234 .49676 L .39417 .49513 L F
.538 .193 .331 r
.39682 .49506 m .39699 .49696 L .39417 .49513 L F
0 0 0 r
.55121 .4064 m .55004 .40981 L .55102 .40831 L F
.765 .633 .071 r
.55111 .40496 m .55121 .4064 L .55102 .40831 L F
.327 0 .134 r
.40742 .48018 m .41082 .47786 L .40828 .47856 L F
.648 .474 .635 r
.48227 .44434 m .48448 .4443 L .48421 .44304 L F
.48227 .44434 m .48281 .44748 L .48448 .4443 L F
.48227 .44434 m .48421 .44304 L .48062 .44622 L F
.26 .566 .936 r
.29692 .65334 m .3013 .65566 L .29971 .65365 L F
.366 0 .162 r
.42722 .46784 m .42945 .46895 L .43002 .46743 L F
.42722 .46784 m .4261 .47016 L .42945 .46895 L F
.3 .786 .9 r
.53988 .41695 m .54372 .41686 L .54196 .41496 L F
.85 .99 .848 r
.53252 .43878 m .53499 .43836 L .5365 .43646 L F
.926 .713 .595 r
.57031 .37278 m .56964 .37539 L .56833 .37185 L F
.83 .742 .767 r
.59788 .35547 m .59563 .358 L .59899 .35853 L F
.713 .228 .092 r
.59563 .358 m .59803 .35987 L .59899 .35853 L F
.664 .168 .062 r
.59899 .35853 m .59803 .35987 L .60209 .36038 L F
.624 .211 .239 r
.38163 .49366 m .37859 .49618 L .37621 .49419 L F
.564 .089 .087 r
.38282 .4949 m .37859 .49618 L .38163 .49366 L F
.895 .835 .779 r
.42724 .50742 m .42683 .51222 L .42458 .51132 L F
.857 .628 .591 r
.42458 .51132 m .42683 .51222 L .42655 .51518 L F
.624 .458 .638 r
.30882 .65791 m .31202 .65459 L .30855 .65528 L F
.30882 .65791 m .31266 .65896 L .31202 .65459 L F
.735 .983 .908 r
.51612 .454 m .51526 .4533 L .51186 .45572 L F
.867 .995 .804 r
.51809 .44976 m .51612 .454 L .51953 .45114 L F
.51809 .44976 m .51526 .4533 L .51612 .454 L F
.967 .891 .514 r
.58045 .38122 m .57936 .38491 L .58011 .38632 L F
.989 .893 .599 r
.57936 .38491 m .57948 .38885 L .58011 .38632 L F
.891 .809 .761 r
.41563 .53187 m .41654 .53555 L .41463 .53414 L F
.77 .921 .937 r
.41654 .53555 m .41311 .53586 L .41463 .53414 L F
.032 0 .206 r
.61436 .3408 m .61179 .34165 L .61104 .34002 L F
.61436 .3408 m .61175 .34363 L .61179 .34165 L F
.937 .873 .749 r
.43976 .5284 m .44348 .52584 L .44204 .52508 L F
.43976 .5284 m .44164 .52967 L .44348 .52584 L F
.924 .944 .792 r
.44459 .52117 m .44204 .52508 L .44348 .52584 L F
.812 .773 .817 r
.5077 .40494 m .51028 .40909 L .50459 .40863 L F
.066 .117 .606 r
.50699 .4099 m .50459 .40863 L .51028 .40909 L F
.547 .578 .838 r
.50893 .40314 m .51028 .40909 L .5077 .40494 L F
.50893 .40314 m .51448 .40821 L .51028 .40909 L F
.164 .7 .717 r
.51028 .40909 m .50966 .40909 L .50699 .4099 L F
.51028 .40909 m .51448 .40821 L .50966 .40909 L F
.756 .615 .703 r
.41303 .54703 m .40859 .54895 L .41118 .54552 L F
.41303 .54703 m .41297 .54955 L .40859 .54895 L F
.166 0 0 r
.46721 .44038 m .46697 .44062 L .46805 .44036 L F
.46431 .44045 m .46697 .44062 L .46721 .44038 L F
.566 .926 .757 r
.46537 .44167 m .46671 .44089 L .46697 .44062 L F
.44 .868 .757 r
.46805 .44036 m .46697 .44062 L .46775 .44021 L F
.815 .718 .758 r
.4668 .43727 m .46431 .44045 L .46805 .44036 L F
.534 .659 .917 r
.46805 .44036 m .46838 .44052 L .46974 .43843 L F
0 0 0 r
.47185 .43889 m .46805 .44036 L .46974 .43843 L F
.4692 .43991 m .47066 .43962 L .46805 .44036 L F
.47185 .43889 m .47066 .43962 L .4692 .43991 L F
.42 .012 .157 r
.47421 .4378 m .47362 .43943 L .47066 .43962 L F
.229 .732 .9 r
.47362 .43943 m .47192 .43937 L .47066 .43962 L F
.56 0 0 r
.47066 .43962 m .4668 .43727 L .46785 .43985 L F
.47066 .43962 m .46785 .43985 L .46805 .44036 L F
.42 .012 .157 r
.47421 .4378 m .47066 .43962 L .47185 .43889 L F
.56 0 0 r
.47009 .43927 m .46948 .43929 L .4668 .43727 L F
.47066 .43962 m .46948 .43929 L .47009 .43927 L F
.654 .961 .768 r
.46948 .43929 m .46687 .44027 L .46816 .43933 L F
.051 0 .123 r
.47258 .43578 m .47185 .43889 L .46974 .43843 L F
.402 .284 .602 r
.4668 .43727 m .46948 .43929 L .4691 .43677 L F
.051 0 .123 r
.47258 .43578 m .46974 .43843 L .47 .43697 L F
.233 0 .182 r
.47421 .4378 m .47258 .43578 L .47519 .43551 L F
.47421 .4378 m .47185 .43889 L .47258 .43578 L F
.643 .967 .878 r
.46948 .43929 m .47415 .43691 L .4691 .43677 L F
.654 .961 .768 r
.46948 .43929 m .46816 .43933 L .47074 .43746 L F
.229 .732 .9 r
.47192 .43937 m .46948 .43929 L .47066 .43962 L F
.566 .926 .757 r
.46671 .44089 m .46948 .43929 L .46697 .44062 L F
.44 .868 .757 r
.46805 .44036 m .46775 .44021 L .46948 .43929 L F
.534 .659 .917 r
.46805 .44036 m .46743 .44198 L .46838 .44052 L F
.51 .239 .439 r
.41356 .4773 m .41712 .47368 L .41437 .47429 L F
0 0 .376 r
.35014 .56238 m .35017 .5661 L .34755 .56468 L F
.669 .255 0 r
.35017 .5661 m .35019 .56653 L .34755 .56468 L F
.35017 .5661 m .35148 .5686 L .35019 .56653 L F
.632 .575 .772 r
.30428 .63763 m .30661 .6341 L .30418 .63536 L F
.30428 .63763 m .30644 .6377 L .30661 .6341 L F
.382 .112 .375 r
.54685 .39623 m .54901 .39582 L .5464 .39667 L F
.55002 .39317 m .54901 .39582 L .54685 .39623 L F
.545 .407 .644 r
.55065 .39286 m .55219 .39562 L .54901 .39582 L F
.289 0 0 r
.55219 .39562 m .55143 .39536 L .54901 .39582 L F
.545 .407 .644 r
.55065 .39286 m .54901 .39582 L .55002 .39317 L F
.289 0 0 r
.55143 .39536 m .54755 .39407 L .54901 .39582 L F
.563 .792 .985 r
.5464 .39667 m .54901 .39582 L .54755 .39407 L F
.699 .979 .794 r
.55002 .39317 m .54973 .39225 L .55065 .39286 L F
.55002 .39317 m .54755 .39407 L .54973 .39225 L F
.888 .954 .841 r
.48755 .47417 m .48615 .47806 L .48837 .47436 L F
.719 .981 .909 r
.48941 .4719 m .48837 .47436 L .49197 .47183 L F
.757 .991 .786 r
.48941 .4719 m .48755 .47417 L .48837 .47436 L F
.504 .885 .968 r
.61701 .39584 m .61878 .39435 L .61624 .3957 L F
.61701 .39584 m .61991 .39478 L .61878 .39435 L F
.838 .642 .638 r
.32792 .63103 m .3299 .62758 L .32593 .62707 L F
0 0 0 r
.55038 .4245 m .55227 .42367 L .55496 .42284 L F
.505 .83 .529 r
.55227 .42367 m .55571 .42038 L .55496 .42284 L F
.889 .853 .399 r
.58944 .38915 m .58924 .38799 L .59004 .38561 L F
.806 .714 .179 r
.58897 .39266 m .58924 .38799 L .58944 .38915 L F
.658 .504 .664 r
.40772 .54221 m .40953 .54664 L .40482 .54652 L F
.764 .554 .613 r
.41118 .54552 m .40953 .54664 L .40772 .54221 L F
.713 .557 .675 r
.4511 .46697 m .4481 .47056 L .44832 .46783 L F
.912 .809 .733 r
.62651 .34701 m .63048 .34517 L .62797 .34545 L F
.62651 .34701 m .6283 .34863 L .63048 .34517 L F
.784 .61 .664 r
.6283 .34863 m .63189 .34948 L .63048 .34517 L F
.693 .571 .713 r
.5447 .3754 m .55048 .37635 L .54728 .37202 L F
.623 .454 .633 r
.44014 .47537 m .43998 .47821 L .43591 .47797 L F
.667 .504 .655 r
.43998 .47821 m .43555 .48034 L .43591 .47797 L F
.707 .843 .948 r
.30855 .65528 m .31202 .65459 L .31111 .65413 L F
.592 .591 .819 r
.31202 .65459 m .31424 .6516 L .31111 .65413 L F
.31202 .65459 m .3152 .65491 L .31424 .6516 L F
.63 .467 .643 r
.31266 .65896 m .3152 .65491 L .31202 .65459 L F
0 0 .21 r
.56528 .37441 m .5634 .37699 L .56379 .37549 L F
.812 .732 .776 r
.44823 .48457 m .44419 .4841 L .44684 .48069 L F
.792 .723 .787 r
.45107 .48119 m .44823 .48457 L .44684 .48069 L F
0 0 .399 r
.54465 .36228 m .54313 .36553 L .54582 .36366 L F
.54355 .36186 m .54313 .36553 L .54465 .36228 L F
.54364 .3611 m .54428 .36337 L .54313 .36553 L F
.669 .184 .09 r
.54339 .36179 m .54004 .36272 L .54428 .36337 L F
.54321 .36148 m .5429 .3616 L .54339 .36179 L F
.5429 .3616 m .54004 .36272 L .54339 .36179 L F
0 0 .399 r
.54364 .3611 m .54355 .36186 L .54465 .36228 L F
.5 .55 .839 r
.54725 .36895 m .54313 .36553 L .54513 .36784 L F
.954 .898 .733 r
.54428 .36337 m .54513 .36784 L .54313 .36553 L F
0 0 0 r
.52009 .4234 m .52392 .42106 L .51917 .41917 L F
.789 .991 .884 r
.41006 .53752 m .41132 .53442 L .41311 .53586 L F
.41006 .53752 m .40807 .5372 L .41132 .53442 L F
.443 .561 .879 r
.54901 .38535 m .55193 .39063 L .55321 .38693 L F
.164 0 .139 r
.55193 .39063 m .55458 .38922 L .55321 .38693 L F
.514 .168 .318 r
.41533 .4911 m .41296 .49387 L .41071 .49425 L F
.586 .395 .589 r
.41533 .4911 m .41767 .49417 L .41296 .49387 L F
.41533 .4911 m .41799 .49135 L .41767 .49417 L F
.869 .95 .862 r
.48182 .48035 m .48318 .48136 L .48615 .47806 L F
.759 .687 .782 r
.36452 .57278 m .36879 .57354 L .36672 .5704 L F
.672 .78 .931 r
.36879 .57354 m .36977 .57072 L .36672 .5704 L F
.36879 .57354 m .37126 .57252 L .36977 .57072 L F
0 0 0 r
.55673 .41885 m .55571 .42038 L .55774 .41666 L F
0 0 .028 r
.55496 .42284 m .55571 .42038 L .55673 .41885 L F
.795 .69 .749 r
.41727 .55575 m .4215 .55669 L .41993 .55198 L F
0 0 0 r
.41883 .55975 m .42052 .55854 L .4215 .55669 L F
.791 .698 .762 r
.41727 .55575 m .41883 .55975 L .4215 .55669 L F
.597 .946 .807 r
.42052 .55854 m .4246 .55648 L .4215 .55669 L F
.385 .833 .932 r
.61135 .37374 m .61439 .37299 L .61564 .37356 L F
.073 .635 .737 r
.61439 .37299 m .61887 .37279 L .61564 .37356 L F
.722 .967 .937 r
.62482 .39353 m .62756 .39361 L .62963 .39188 L F
.884 .623 .539 r
.37248 .5427 m .37042 .54564 L .37069 .54135 L F
.37248 .5427 m .37245 .54574 L .37042 .54564 L F
.448 .263 .536 r
.37497 .54488 m .37245 .54574 L .37248 .5427 L F
.405 0 0 r
.41683 .56693 m .41132 .56597 L .41356 .5672 L F
0 0 0 r
.47208 .42803 m .47318 .42833 L .47404 .42624 L F
.47208 .42803 m .4702 .42952 L .47318 .42833 L F
.867 .801 .784 r
.43603 .49189 m .43155 .49395 L .43412 .49021 L F
.43603 .49189 m .43371 .49536 L .43155 .49395 L F
.81 .797 .84 r
.43868 .48876 m .43603 .49189 L .43412 .49021 L F
0 0 0 r
.51311 .39003 m .51017 .39308 L .51221 .39144 L F
.129 0 0 r
.51311 .39003 m .51488 .39022 L .51553 .38873 L F
.51311 .39003 m .51221 .39144 L .51488 .39022 L F
.784 .689 .76 r
.40953 .54664 m .40438 .5484 L .40482 .54652 L F
.377 .097 .357 r
.44802 .45069 m .45063 .4499 L .45114 .44756 L F
.307 .038 .332 r
.45114 .44756 m .45063 .4499 L .45358 .44662 L F
.873 .994 .791 r
.52053 .44069 m .51778 .44414 L .51828 .44133 L F
.834 .98 .879 r
.51828 .44133 m .51778 .44414 L .51319 .44463 L F
.672 .619 .787 r
.6283 .34863 m .63202 .3507 L .63189 .34948 L F
.519 .31 .536 r
.63202 .3507 m .63501 .35049 L .63189 .34948 L F
.831 .61 .603 r
.32911 .64629 m .33046 .64487 L .32618 .64413 L F
0 0 0 r
.51017 .39308 m .50686 .39597 L .50891 .39454 L F
.244 0 .272 r
.50891 .39454 m .51221 .39144 L .51017 .39308 L F
.699 .504 .621 r
.45601 .46054 m .45875 .46466 L .45386 .46381 L F
.673 .497 .64 r
.46035 .46069 m .45875 .46466 L .45601 .46054 L F
.686 .978 .895 r
.62262 .3722 m .62179 .37184 L .62398 .37016 L F
.495 .74 .982 r
.62398 .37016 m .62567 .37193 L .62262 .3722 L F
.16 0 .095 r
.49616 .41835 m .49559 .41692 L .49682 .41673 L F
.49616 .41835 m .49373 .41948 L .49559 .41692 L F
.802 .69 .741 r
.45107 .48119 m .44684 .48069 L .44956 .47718 L F
.711 .645 .782 r
.45399 .47793 m .45107 .48119 L .44956 .47718 L F
.498 .327 .58 r
.50474 .40568 m .50248 .40913 L .50239 .40637 L F
.568 .583 .828 r
.3013 .65566 m .30427 .65504 L .30248 .65093 L F
.712 .583 .709 r
.31964 .6584 m .32408 .65951 L .32236 .6549 L F
.728 .309 .252 r
.52072 .38438 m .52581 .38301 L .51972 .38396 L F
.637 .851 .982 r
.54451 .37242 m .54728 .37202 L .54725 .36895 L F
.581 .445 .66 r
.54728 .37202 m .55053 .36801 L .54725 .36895 L F
.54728 .37202 m .55208 .37308 L .55053 .36801 L F
.405 .471 .815 r
.54728 .37202 m .55149 .375 L .55208 .37308 L F
.54728 .37202 m .55048 .37635 L .55149 .375 L F
.806 .714 .179 r
.58897 .39266 m .58883 .39104 L .58924 .38799 L F
0 .087 .63 r
.58984 .39484 m .58883 .39104 L .58897 .39266 L F
.861 .785 .775 r
.41118 .54552 m .40859 .54895 L .40953 .54664 L F
.338 .05 .319 r
.50628 .39853 m .50891 .39454 L .50686 .39597 L F
.881 .66 .598 r
.40044 .5686 m .40629 .56777 L .40082 .56538 L F
.40044 .5686 m .40508 .57003 L .40629 .56777 L F
.201 0 .314 r
.4541 .44418 m .45582 .44543 L .45611 .44299 L F
.4541 .44418 m .45358 .44662 L .45582 .44543 L F
.937 .937 .77 r
.4526 .51063 m .45161 .51542 L .45453 .51212 L F
.4526 .51063 m .45027 .51446 L .45161 .51542 L F
.971 .756 .556 r
.63965 .35422 m .64102 .35799 L .64167 .3558 L F
.452 .305 .59 r
.30182 .64389 m .3051 .64766 L .30455 .64377 L F
.30182 .64389 m .30215 .64987 L .3051 .64766 L F
.559 .032 0 r
.63204 .35728 m .62764 .35721 L .62934 .35576 L F
.526 .126 .225 r
.39104 .48658 m .39531 .48395 L .39107 .48523 L F
.39104 .48658 m .39377 .48679 L .39531 .48395 L F
.242 0 .081 r
.39531 .48395 m .39636 .48594 L .39793 .48379 L F
.39531 .48395 m .39377 .48679 L .39636 .48594 L F
.838 .799 .813 r
.54281 .37041 m .54451 .37242 L .54725 .36895 L F
.903 .854 .784 r
.43853 .53021 m .44164 .52967 L .43976 .5284 L F
.43853 .53021 m .44006 .53165 L .44164 .52967 L F
.726 .989 .823 r
.52053 .44069 m .51828 .44133 L .52165 .4385 L F
.851 .826 .823 r
.62651 .34701 m .62736 .35117 L .6283 .34863 L F
.38 0 0 r
.62376 .35048 m .62726 .35193 L .62736 .35117 L F
.851 .826 .823 r
.62651 .34701 m .62736 .35117 L .6283 .34863 L F
.576 .043 0 r
.62726 .35193 m .63055 .35206 L .62736 .35117 L F
.672 .619 .787 r
.6283 .34863 m .62736 .35117 L .63202 .3507 L F
.303 0 0 r
.62736 .35117 m .63055 .35206 L .63202 .3507 L F
.699 .678 .826 r
.31266 .65896 m .31258 .66091 L .31526 .65794 L F
.756 .539 .601 r
.32171 .62367 m .32647 .62096 L .3219 .62102 L F
.32171 .62367 m .32623 .62412 L .32647 .62096 L F
.768 .654 .736 r
.31808 .65453 m .32236 .6549 L .32093 .6513 L F
.766 .664 .75 r
.31964 .6584 m .32236 .6549 L .31808 .65453 L F
.73 .636 .753 r
.32093 .6513 m .32236 .6549 L .32512 .65152 L F
.732 .627 .742 r
.48281 .44748 m .48012 .45089 L .47951 .44775 L F
.48281 .44748 m .47977 .44736 L .48042 .44649 L F
.48102 .44645 m .48042 .44649 L .48062 .44622 L F
.48281 .44748 m .48042 .44649 L .48102 .44645 L F
.48281 .44748 m .47951 .44775 L .47977 .44736 L F
.48281 .44748 m .48102 .44645 L .48093 .44823 L F
.48102 .44645 m .48062 .44622 L .48093 .44823 L F
.571 .183 .268 r
.48093 .44823 m .48448 .4443 L .48281 .44748 L F
.48093 .44823 m .48411 .44836 L .48431 .44623 L F
.48264 .44634 m .48431 .44623 L .48448 .4443 L F
.48093 .44823 m .48431 .44623 L .48264 .44634 L F
.171 .132 .569 r
.48448 .4443 m .48678 .44164 L .48421 .44304 L F
.48448 .4443 m .48747 .44517 L .48678 .44164 L F
.443 .171 .404 r
.48411 .44836 m .48747 .44517 L .48448 .4443 L F
.165 .248 .705 r
.54321 .36148 m .54364 .3611 L .54159 .35876 L F
.631 .723 .914 r
.5488 .3605 m .55322 .36169 L .55132 .35813 L F
.112 .369 .831 r
.55322 .36169 m .55401 .35978 L .55132 .35813 L F
.998 .79 .449 r
.55322 .36169 m .55174 .36155 L .55401 .35978 L F
.55322 .36169 m .55273 .3647 L .55174 .36155 L F
.782 .672 .742 r
.31526 .65794 m .31964 .6584 L .31808 .65453 L F
.768 .756 .842 r
.30427 .65504 m .30855 .65528 L .30697 .65336 L F
.694 .702 .853 r
.30855 .65528 m .30936 .65065 L .30697 .65336 L F
.30855 .65528 m .31111 .65413 L .30936 .65065 L F
.831 .775 .799 r
.43259 .49785 m .42887 .49743 L .43155 .49395 L F
.846 .733 .739 r
.43259 .49785 m .43032 .50146 L .42887 .49743 L F
.875 .797 .769 r
.43371 .49536 m .43259 .49785 L .43155 .49395 L F
.913 .942 .81 r
.45837 .50393 m .45715 .50855 L .45961 .50495 L F
.831 .929 .897 r
.45961 .50495 m .46129 .50071 L .45837 .50393 L F
.45961 .50495 m .46278 .50194 L .46129 .50071 L F
0 0 0 r
.41883 .55975 m .41374 .56482 L .41737 .56197 L F
.41883 .55975 m .41913 .56044 L .42052 .55854 L F
.41883 .55975 m .41737 .56197 L .41913 .56044 L F
.605 .55 .767 r
.54346 .38541 m .54483 .38985 L .54716 .38832 L F
.328 .169 .507 r
.42471 .49117 m .42243 .49503 L .42184 .49227 L F
.726 .582 .694 r
.42184 .49227 m .41767 .49417 L .41799 .49135 L F
.42184 .49227 m .4193 .49448 L .41767 .49417 L F
.42184 .49227 m .42243 .49503 L .4193 .49448 L F
.328 0 .199 r
.51408 .39871 m .51172 .39993 L .51142 .39969 L F
.759 .674 .123 r
.58899 .35893 m .58877 .3591 L .58891 .35641 L F
.996 .856 .53 r
.58175 .36429 m .58204 .36831 L .58252 .36565 L F
0 0 .044 r
.55774 .41666 m .5592 .41261 L .55914 .41455 L F
0 0 0 r
.55673 .41885 m .55774 .41666 L .55914 .41455 L F
.61 .915 .979 r
.62241 .35464 m .61927 .3554 L .62101 .35412 L F
.129 0 .235 r
.53432 .37229 m .53339 .37468 L .5314 .37574 L F
.53432 .37229 m .53339 .37468 L .5314 .37574 L F
.736 .986 .898 r
.5314 .37574 m .53189 .37345 L .53339 .37468 L F
.5314 .37574 m .5286 .3759 L .53189 .37345 L F
.339 .111 .414 r
.5335 .3774 m .5314 .37574 L .53339 .37468 L F
.5335 .3774 m .53098 .37857 L .5314 .37574 L F
.838 .799 .813 r
.54281 .37041 m .54725 .36895 L .54513 .36784 L F
.674 .651 .819 r
.54982 .36578 m .54725 .36895 L .55053 .36801 L F
.749 .764 .865 r
.38659 .55955 m .38229 .55904 L .38472 .55789 L F
.86 .628 .586 r
.64938 .36486 m .65262 .36798 L .65328 .36577 L F
0 0 0 r
.54491 .42825 m .54906 .42598 L .54838 .4267 L F
0 0 .003 r
.54906 .42598 m .55096 .42544 L .54838 .4267 L F
.54906 .42598 m .55038 .4245 L .55096 .42544 L F
.332 0 0 r
.36587 .48885 m .37022 .488 L .36753 .48808 L F
.652 .671 .855 r
.38687 .57665 m .38788 .57204 L .38548 .57462 L F
.38687 .57665 m .38924 .57524 L .38788 .57204 L F
.545 .687 .932 r
.35752 .57285 m .35823 .56946 L .35588 .57036 L F
.35752 .57285 m .36003 .57205 L .35823 .56946 L F
.861 .626 .581 r
.33143 .63422 m .32792 .63103 L .32747 .63384 L F
.797 .658 .709 r
.32747 .63384 m .32911 .63782 L .33143 .63422 L F
.328 .169 .507 r
.42471 .49117 m .42466 .49407 L .42243 .49503 L F
.703 .599 .737 r
.42466 .49407 m .4219 .49757 L .42243 .49503 L F
.73 .447 .5 r
.42243 .49503 m .4219 .49757 L .4193 .49448 L F
0 .213 .733 r
.4246 .55648 m .42643 .55999 L .42646 .55496 L F
.709 .753 .886 r
.39372 .57626 m .39484 .57196 L .39201 .57319 L F
.39372 .57626 m .39609 .57497 L .39484 .57196 L F
.159 0 .195 r
.44802 .45069 m .44512 .45397 L .44745 .45283 L F
.433 .137 .361 r
.44745 .45283 m .45063 .4499 L .44802 .45069 L F
.531 .185 .327 r
.41993 .47316 m .4234 .47094 L .42047 .47135 L F
.463 .257 .513 r
.45611 .44299 m .45885 .43952 L .45664 .4406 L F
0 .213 .733 r
.4246 .55648 m .42674 .55785 L .42643 .55999 L F
.814 .942 .583 r
.42674 .55785 m .42476 .56208 L .42643 .55999 L F
.501 .414 .689 r
.30644 .6377 m .30931 .6334 L .30661 .6341 L F
.30644 .6377 m .31037 .63782 L .30931 .6334 L F
.471 .305 .573 r
.3076 .64021 m .31037 .63782 L .30644 .6377 L F
.652 .448 .595 r
.43335 .48126 m .43307 .48421 L .43019 .48444 L F
.706 .547 .67 r
.43555 .48034 m .43307 .48421 L .43335 .48126 L F
.821 .608 .615 r
.45648 .47433 m .45236 .47378 L .45276 .47085 L F
.813 .693 .733 r
.45648 .47433 m .45399 .47793 L .45236 .47378 L F
.869 .924 .861 r
.51809 .44976 m .51953 .45114 L .52022 .44993 L F
.492 0 0 r
.34305 .56184 m .34776 .56253 L .34482 .563 L F
.545 0 0 r
.34776 .56253 m .34305 .56184 L .34482 .563 L F
.84 .929 .889 r
.43377 .53812 m .43195 .54255 L .43519 .53903 L F
.43377 .53812 m .43049 .54127 L .43195 .54255 L F
.998 .781 .472 r
.43195 .54255 m .43021 .54371 L .43174 .54512 L F
.43195 .54255 m .43049 .54127 L .43021 .54371 L F
.869 .95 .862 r
.48182 .48035 m .48615 .47806 L .48487 .47703 L F
.888 .954 .841 r
.48755 .47417 m .48487 .47703 L .48615 .47806 L F
.156 .651 .915 r
.55992 .37872 m .55791 .378 L .55591 .37775 L F
.69 .767 .91 r
.55591 .37775 m .55992 .37872 L .55791 .378 L F
.755 .878 .935 r
.5634 .37699 m .55791 .378 L .55992 .37872 L F
.5634 .37699 m .55791 .378 L .55992 .37872 L F
.534 .326 .544 r
.45885 .43952 m .46177 .43617 L .45941 .43724 L F
0 0 0 r
.55038 .4245 m .55496 .42284 L .55334 .42407 L F
.034 0 0 r
.55096 .42544 m .55038 .4245 L .55334 .42407 L F
.72 .665 .795 r
.56086 .35693 m .56543 .36001 L .5652 .35913 L F
.694 .712 .862 r
.5595 .35283 m .56245 .35704 L .56384 .35387 L F
.72 .665 .795 r
.56204 .35572 m .5652 .35913 L .56384 .35387 L F
.288 .513 .898 r
.55945 .35292 m .56245 .35704 L .55817 .35496 L F
.55994 .35344 m .56245 .35704 L .55945 .35292 L F
.72 .665 .795 r
.56086 .35693 m .5652 .35913 L .56204 .35572 L F
.288 .513 .898 r
.5595 .35283 m .55994 .35344 L .55945 .35292 L F
.696 .66 .811 r
.5567 .35636 m .5595 .35283 L .55817 .35496 L F
0 0 0 r
.42446 .56165 m .42355 .56357 L .42476 .56208 L F
.42446 .56165 m .42189 .56523 L .42355 .56357 L F
.609 .802 .383 r
.52435 .42699 m .52215 .43052 L .52287 .42934 L F
.134 .269 .738 r
.52215 .43052 m .52443 .43217 L .52287 .42934 L F
.357 .257 .603 r
.52191 .43248 m .52443 .43217 L .52215 .43052 L F
.203 0 .111 r
.44181 .45671 m .44419 .45626 L .44512 .45397 L F
.324 0 .163 r
.44512 .45397 m .44731 .45509 L .44745 .45283 L F
.44512 .45397 m .44419 .45626 L .44731 .45509 L F
.603 .452 .65 r
.44808 .473 m .44538 .47108 L .4481 .47056 L F
.44808 .473 m .4455 .47387 L .44538 .47108 L F
.621 .134 .076 r
.58888 .35104 m .59167 .35299 L .59293 .35114 L F
.053 0 0 r
.59293 .35114 m .596 .34992 L .59621 .34947 L F
.775 .571 .623 r
.59167 .35299 m .596 .34992 L .59293 .35114 L F
.594 .429 .628 r
.44265 .47736 m .44014 .47537 L .44296 .47448 L F
.44265 .47736 m .43998 .47821 L .44014 .47537 L F
.993 .767 .484 r
.55004 .40981 m .54815 .41112 L .55102 .40831 L F
.55004 .40981 m .5499 .41251 L .54815 .41112 L F
.129 .028 .461 r
.52191 .43248 m .52379 .43438 L .52443 .43217 L F
.52191 .43248 m .52241 .43605 L .52379 .43438 L F
.87 .838 .812 r
.4526 .51063 m .45715 .50855 L .45575 .50761 L F
.4526 .51063 m .45453 .51212 L .45715 .50855 L F
.913 .942 .81 r
.45837 .50393 m .45575 .50761 L .45715 .50855 L F
.85 .99 .848 r
.53252 .43878 m .5365 .43646 L .53535 .43538 L F
.912 .957 .808 r
.53807 .43168 m .5365 .43646 L .53958 .4331 L F
.53807 .43168 m .53535 .43538 L .5365 .43646 L F
.689 .509 .639 r
.40754 .49718 m .4037 .49441 L .40796 .49473 L F
.499 .238 .45 r
.41071 .49425 m .40754 .49718 L .40796 .49473 L F
.743 .446 .479 r
.4193 .49448 m .4173 .49721 L .41767 .49417 L F
.4193 .49448 m .4219 .49757 L .4173 .49721 L F
.348 .02 .261 r
.43002 .46743 m .43268 .46668 L .43331 .46463 L F
.229 0 .213 r
.43331 .46463 m .43507 .46566 L .43593 .46389 L F
.43331 .46463 m .43268 .46668 L .43507 .46566 L F
0 0 0 r
.56171 .40293 m .56466 .39967 L .5638 .40122 L F
.727 .654 .777 r
.32093 .6513 m .32512 .65152 L .32349 .64759 L F
.725 .653 .778 r
.32349 .64759 m .32512 .65152 L .32781 .64833 L F
.161 .269 .728 r
.47557 .43756 m .47703 .43997 L .47519 .43551 L F
.517 .165 .31 r
.52695 .42863 m .52435 .42699 L .52287 .42934 L F
.954 .898 .733 r
.54428 .36337 m .54222 .36703 L .54513 .36784 L F
.901 .764 .7 r
.54058 .36832 m .54513 .36784 L .54222 .36703 L F
.54058 .36832 m .54281 .37041 L .54513 .36784 L F
.531 .53 .799 r
.52553 .41912 m .52767 .42371 L .52978 .42254 L F
.237 0 .296 r
.52978 .42254 m .52767 .42371 L .52573 .42678 L F
.52978 .42254 m .52767 .42371 L .52573 .42678 L F
0 0 0 r
.5646 .35274 m .56649 .3527 L .56812 .35389 L F
.5646 .35274 m .56384 .35387 L .56649 .3527 L F
.588 .811 .985 r
.37977 .56023 m .37533 .55956 L .37796 .55861 L F
.658 .823 .963 r
.38229 .55904 m .37977 .56023 L .37796 .55861 L F
.52 .267 .472 r
.55124 .35521 m .55132 .35813 L .55401 .35716 L F
.837 .823 .835 r
.64932 .3679 m .64989 .37087 L .65262 .36798 L F
0 0 .417 r
.56751 .38642 m .56773 .38624 L .56434 .38624 L F
.56751 .38642 m .56859 .38833 L .56773 .38624 L F
0 0 .377 r
.5593 .40898 m .55987 .41192 L .5592 .41261 L F
0 0 .005 r
.55987 .41192 m .55914 .41455 L .5592 .41261 L F
0 0 .507 r
.58877 .39975 m .59024 .40013 L .59053 .39742 L F
.58877 .39975 m .58961 .4024 L .59024 .40013 L F
.004 .472 .868 r
.49551 .43796 m .49589 .43894 L .49419 .43733 L F
.49551 .43796 m .49781 .43959 L .49589 .43894 L F
0 0 0 r
.52334 .39162 m .52234 .39406 L .52 .39499 L F
0 0 .307 r
.52396 .38795 m .5242 .39083 L .52334 .39162 L F
0 0 0 r
.5242 .39083 m .52234 .39406 L .52334 .39162 L F
.978 .759 .539 r
.58052 .37213 m .57968 .37437 L .58146 .37505 L F
.994 .787 .515 r
.57967 .37712 m .58146 .37505 L .57968 .37437 L F
.57967 .37712 m .58116 .37865 L .58146 .37505 L F
.573 .415 .629 r
.30418 .63536 m .30661 .6341 L .3067 .63141 L F
.514 .398 .659 r
.46705 .44594 m .46449 .44452 L .46525 .44391 L F
.46705 .44594 m .46588 .44811 L .46449 .44452 L F
.581 .574 .81 r
.5092 .41985 m .51021 .41482 L .50721 .41555 L F
.813 .328 0 r
.61262 .37933 m .61129 .38012 L .60976 .37969 L F
.285 .37 .775 r
.60976 .37969 m .61129 .38012 L .61121 .37981 L F
.813 .328 0 r
.61262 .37933 m .60976 .37969 L .6085 .37959 L F
.285 .37 .775 r
.60976 .37969 m .61121 .37981 L .61016 .37605 L F
.813 .328 0 r
.6085 .37959 m .60976 .37969 L .60801 .37962 L F
.61262 .37933 m .61383 .38144 L .61129 .38012 L F
.86 .628 .586 r
.64938 .36486 m .64932 .3679 L .65262 .36798 L F
.967 .727 .292 r
.59112 .37905 m .59021 .37794 L .59026 .37501 L F
.919 .613 .134 r
.59112 .37905 m .5916 .3817 L .59021 .37794 L F
.784 .689 .76 r
.40953 .54664 m .40859 .54895 L .40438 .5484 L F
.791 .666 .726 r
.40859 .54895 m .40598 .55246 L .40438 .5484 L F
.795 .76 .821 r
.31424 .6516 m .31805 .65151 L .31677 .64875 L F
.666 .501 .652 r
.3152 .65491 m .31805 .65151 L .31424 .6516 L F
.3152 .65491 m .31808 .65453 L .31805 .65151 L F
.67 .695 .864 r
.31805 .65151 m .31907 .64727 L .31677 .64875 L F
.31805 .65151 m .32093 .6513 L .31907 .64727 L F
.768 .654 .736 r
.31808 .65453 m .32093 .6513 L .31805 .65151 L F
.81 .797 .84 r
.43868 .48876 m .43412 .49021 L .43697 .48688 L F
.682 .758 .909 r
.43697 .48688 m .44137 .48763 L .43868 .48876 L F
.599 .836 .459 r
.56528 .37441 m .56399 .37601 L .5634 .37699 L F
0 .334 .804 r
.56399 .37601 m .56567 .37794 L .5634 .37699 L F
0 .328 .728 r
.5634 .37699 m .56567 .37794 L .56706 .3789 L F
.68 .298 .317 r
.40135 .49682 m .39682 .49506 L .40079 .49516 L F
.40135 .49682 m .39699 .49696 L .39682 .49506 L F
.795 .476 .45 r
.36494 .49125 m .36354 .49275 L .36298 .49027 L F
.36494 .49125 m .36475 .49375 L .36354 .49275 L F
0 0 0 r
.56652 .39799 m .56466 .39967 L .56732 .39626 L F
.5638 .40122 m .56466 .39967 L .56652 .39799 L F
.859 .861 .84 r
.43691 .53177 m .44006 .53165 L .43853 .53021 L F
.885 .876 .822 r
.43549 .53416 m .44006 .53165 L .43691 .53177 L F
.43549 .53416 m .43729 .53494 L .44006 .53165 L F
0 0 0 r
.56652 .39799 m .56732 .39626 L .56979 .39501 L F
.9 .871 .8 r
.41976 .52445 m .41947 .52093 L .42105 .52211 L F
.875 .909 .85 r
.42378 .51871 m .42105 .52211 L .41947 .52093 L F
0 0 0 r
.399 .57398 m .40308 .57193 L .40347 .57198 L F
.762 .872 .928 r
.399 .57398 m .40192 .57267 L .3975 .57017 L F
.40192 .57267 m .40347 .57198 L .40284 .57179 L F
.40192 .57267 m .40284 .57179 L .3975 .57017 L F
.789 .926 .926 r
.40308 .57193 m .40508 .57003 L .40373 .57094 L F
.40297 .57167 m .40373 .57094 L .4029 .5715 L F
.40308 .57193 m .40373 .57094 L .40297 .57167 L F
.40308 .57193 m .40638 .56978 L .40508 .57003 L F
0 .317 .718 r
.40347 .57198 m .40308 .57193 L .4029 .5715 L F
.719 .458 .53 r
.46705 .44594 m .47259 .44701 L .4734 .44527 L F
.055 0 .021 r
.47259 .44701 m .47415 .44587 L .4734 .44527 L F
.119 0 .204 r
.4734 .44527 m .47415 .44587 L .47469 .4438 L F
.827 .899 .891 r
.53807 .43168 m .53958 .4331 L .54264 .43005 L F
0 0 0 r
.53121 .42649 m .52695 .42863 L .52977 .42801 L F
.66 .667 .846 r
.53262 .42198 m .53368 .42511 L .53121 .42649 L F
.53199 .42399 m .53121 .42649 L .53222 .42417 L F
0 0 0 r
.53222 .42417 m .531 .42591 L .53258 .42446 L F
.746 .783 .883 r
.53533 .42061 m .53368 .42511 L .53262 .42198 L F
.996 .765 .442 r
.53262 .42198 m .53368 .42511 L .53222 .42417 L F
0 0 0 r
.53222 .42417 m .53258 .42446 L .53422 .42295 L F
.66 .667 .846 r
.53262 .42198 m .53199 .42399 L .53222 .42417 L F
.737 .905 .527 r
.53222 .42417 m .53121 .42649 L .52977 .42801 L F
.564 .089 .087 r
.38282 .4949 m .38086 .49676 L .37859 .49618 L F
.742 .312 .229 r
.38282 .4949 m .3852 .4976 L .38086 .49676 L F
.336 0 0 r
.56265 .39141 m .56522 .39107 L .56621 .39004 L F
0 0 0 r
.56522 .39107 m .56859 .38833 L .56621 .39004 L F
.537 .918 .929 r
.54934 .38169 m .55155 .38046 L .55236 .37637 L F
.264 0 0 r
.55155 .38046 m .55591 .37775 L .55236 .37637 L F
.55155 .38046 m .55437 .3799 L .55591 .37775 L F
.437 .831 .982 r
.5541 .37995 m .55283 .37976 L .55437 .3799 L F
.55155 .38046 m .55276 .3798 L .5541 .37995 L F
.55276 .3798 m .55283 .37976 L .5541 .37995 L F
.554 .579 .834 r
.55236 .37637 m .55466 .37418 L .55149 .375 L F
.55236 .37637 m .55591 .37775 L .55466 .37418 L F
.841 .781 .794 r
.55302 .37545 m .55269 .37979 L .55066 .37955 L F
.437 .831 .982 r
.55155 .38046 m .55076 .37966 L .55276 .37979 L F
.55076 .37966 m .55066 .37955 L .55276 .37979 L F
.841 .781 .794 r
.55269 .37979 m .55256 .38154 L .55066 .37955 L F
.809 .753 .801 r
.55437 .3799 m .55256 .38154 L .55269 .37979 L F
.55437 .3799 m .55269 .37979 L .55302 .37545 L F
.437 .831 .982 r
.55276 .37979 m .55066 .37955 L .55283 .37976 L F
.537 .918 .929 r
.54904 .38222 m .55155 .38046 L .54934 .38169 L F
.54904 .38222 m .54888 .3815 L .55155 .38046 L F
.572 0 0 r
.60029 .37143 m .60318 .37346 L .60437 .37319 L F
.296 .783 .721 r
.60437 .37319 m .60592 .37243 L .60741 .37331 L F
.60437 .37319 m .60318 .37346 L .60592 .37243 L F
.409 0 0 r
.37022 .488 m .37255 .48908 L .37463 .48702 L F
.481 0 .014 r
.37255 .48908 m .37709 .48745 L .37463 .48702 L F
.069 .035 .508 r
.34151 .5065 m .33966 .50863 L .33826 .50749 L F
.34151 .5065 m .34103 .50999 L .33966 .50863 L F
.944 .62 .388 r
.40093 .52935 m .40199 .53233 L .39974 .53076 L F
.40093 .52935 m .40199 .53233 L .39974 .53076 L F
.019 0 0 r
.40093 .52935 m .39974 .53076 L .40133 .52952 L F
0 0 .151 r
.40093 .52935 m .40133 .52952 L .40269 .52763 L F
.959 .678 .46 r
.39833 .524 m .40115 .52919 L .3983 .52695 L F
.40115 .52919 m .40133 .52952 L .40106 .5293 L F
.40115 .52919 m .40106 .5293 L .3983 .52695 L F
.527 .563 .835 r
.40269 .52763 m .40133 .52952 L .40115 .52919 L F
.40269 .52763 m .40115 .52919 L .39833 .524 L F
0 0 0 r
.40146 .52883 m .40101 .52934 L .40093 .52935 L F
.40101 .52934 m .39974 .53076 L .40052 .52983 L F
.40101 .52934 m .40052 .52983 L .40093 .52935 L F
.917 .779 .692 r
.40106 .5293 m .39974 .53076 L .3983 .52695 L F
.40133 .52952 m .39974 .53076 L .40106 .5293 L F
0 0 0 r
.40269 .52763 m .4005 .52995 L .40106 .5293 L F
.40165 .52864 m .40106 .5293 L .40146 .52883 L F
.40269 .52763 m .40106 .5293 L .40165 .52864 L F
.4005 .52995 m .39974 .53076 L .40146 .52883 L F
.579 .685 .913 r
.38288 .57532 m .38355 .57153 L .38098 .57205 L F
.38288 .57532 m .38548 .57462 L .38355 .57153 L F
.492 .162 .335 r
.39793 .48379 m .40069 .48356 L .40112 .48143 L F
.469 .117 .285 r
.40069 .48356 m .40469 .48053 L .40112 .48143 L F
.571 .404 .617 r
.3067 .63141 m .30929 .63068 L .30931 .6272 L F
.633 .455 .624 r
.30931 .6272 m .30929 .63068 L .3121 .62733 L F
.575 .417 .629 r
.3067 .63141 m .30661 .6341 L .30929 .63068 L F
.676 .458 .583 r
.47519 .43551 m .47334 .43429 L .47553 .43303 L F
.47519 .43551 m .47258 .43578 L .47334 .43429 L F
.18 0 .137 r
.53199 .36511 m .53417 .36464 L .53487 .36239 L F
.269 0 .17 r
.53487 .36239 m .53775 .36283 L .53751 .36199 L F
.53487 .36239 m .53417 .36464 L .53775 .36283 L F
.863 .845 .824 r
.39847 .54714 m .39442 .55244 L .39379 .54854 L F
.916 .92 .803 r
.46129 .50071 m .46533 .49817 L .46352 .49669 L F
.46129 .50071 m .46278 .50194 L .46533 .49817 L F
.858 .858 .84 r
.46352 .49669 m .46533 .49817 L .46818 .49485 L F
.713 .557 .675 r
.4511 .46697 m .45276 .47085 L .4481 .47056 L F
.668 .536 .694 r
.45386 .46381 m .45535 .46788 L .4511 .46697 L F
.45535 .46788 m .45276 .47085 L .4511 .46697 L F
.208 0 .16 r
.49237 .40981 m .48907 .4128 L .49143 .41175 L F
.209 0 .281 r
.49143 .41175 m .49427 .40829 L .49237 .40981 L F
.752 .426 .432 r
.63055 .35206 m .63501 .35049 L .63202 .3507 L F
.549 .903 .693 r
.60499 .38057 m .60311 .38239 L .60543 .38037 L F
.914 .518 .132 r
.60248 .38414 m .60408 .38531 L .60311 .38239 L F
.76 .447 .456 r
.60311 .38239 m .60408 .38531 L .60749 .38526 L F
.914 .518 .132 r
.60248 .38414 m .60311 .38239 L .60499 .38057 L F
0 0 .263 r
.58979 .36821 m .58873 .36366 L .58854 .36565 L F
.611 .392 .559 r
.3121 .62733 m .31495 .62706 L .31518 .62413 L F
.628 .423 .586 r
.31495 .62706 m .32017 .62423 L .31518 .62413 L F
0 0 0 r
.51854 .38545 m .52072 .38438 L .51972 .38396 L F
0 0 .178 r
.60793 .34455 m .60692 .3403 L .60455 .34074 L F
.871 .566 .469 r
.63733 .35349 m .63941 .3511 L .63501 .35049 L F
.63733 .35349 m .63965 .35422 L .63941 .3511 L F
.23 0 .237 r
.43863 .46008 m .44125 .45939 L .44181 .45671 L F
.396 .127 .384 r
.44125 .45939 m .44419 .45626 L .44181 .45671 L F
.119 0 0 r
.60433 .36541 m .60213 .36669 L .60174 .36665 L F
0 0 0 r
.60137 .3666 m .60174 .36665 L .60047 .3687 L F
.838 .698 .164 r
.60009 .36971 m .60047 .3687 L .60174 .36665 L F
.847 .943 .58 r
.60174 .36665 m .60028 .36777 L .60009 .36971 L F
.119 0 0 r
.60213 .36669 m .60028 .36777 L .60174 .36665 L F
0 0 0 r
.60221 .36462 m .60174 .36665 L .60137 .3666 L F
.838 .698 .164 r
.60009 .36971 m .60029 .37143 L .60047 .3687 L F
.387 .171 .459 r
.39913 .53553 m .39625 .53932 L .39868 .53829 L F
.39913 .53553 m .39625 .53932 L .39868 .53829 L F
.824 .38 .178 r
.64121 .3604 m .6436 .36348 L .64479 .36195 L F
.728 .249 .108 r
.6436 .36348 m .64708 .36435 L .64479 .36195 L F
.941 .575 .256 r
.53511 .41301 m .53578 .41283 L .53663 .41137 L F
.53511 .41301 m .53585 .41558 L .53377 .41423 L F
.53511 .41301 m .53377 .41423 L .53578 .41283 L F
.322 0 0 r
.38965 .49575 m .3881 .49729 L .3852 .4976 L F
.448 0 0 r
.39234 .49676 m .3881 .49729 L .38965 .49575 L F
.875 .976 .844 r
.4925 .46871 m .49197 .47183 L .49385 .46974 L F
.4925 .46871 m .48941 .4719 L .49197 .47183 L F
.705 .707 .849 r
.30936 .65065 m .31111 .65413 L .31424 .6516 L F
.469 .792 .999 r
.46807 .47786 m .46666 .47637 L .46352 .47702 L F
.096 .267 .749 r
.46352 .47702 m .46567 .47851 L .46807 .47786 L F
.974 .899 .683 r
.46807 .47786 m .46567 .47851 L .46666 .47637 L F
.764 .695 .786 r
.42887 .49743 m .43032 .50146 L .42604 .50109 L F
.847 .526 .446 r
.42959 .50375 m .42604 .50109 L .43032 .50146 L F
.785 .736 .807 r
.54364 .3611 m .5488 .3605 L .54905 .36014 L F
.753 .98 .914 r
.54905 .36014 m .5488 .3605 L .55132 .35813 L F
.97 .904 .695 r
.43549 .53416 m .43519 .53903 L .43729 .53494 L F
.43549 .53416 m .43377 .53812 L .43519 .53903 L F
.605 .55 .767 r
.54346 .38541 m .54716 .38832 L .54711 .38504 L F
.096 .267 .749 r
.46352 .47702 m .46504 .48105 L .46567 .47851 L F
.802 .98 .899 r
.46504 .48105 m .4638 .48043 L .46567 .47851 L F
.63 .467 .643 r
.31266 .65896 m .31526 .65794 L .3152 .65491 L F
.664 .494 .645 r
.31526 .65794 m .31808 .65453 L .3152 .65491 L F
.326 .48 .86 r
.60037 .40126 m .60011 .40214 L .60229 .40077 L F
.186 0 .25 r
.47986 .42003 m .48181 .42084 L .48256 .41939 L F
.47986 .42003 m .47957 .42215 L .48181 .42084 L F
.864 .612 .557 r
.54364 .3611 m .54582 .36366 L .54645 .36235 L F
.864 .812 .797 r
.48397 .46475 m .48221 .46661 L .48155 .46318 L F
.9 .871 .8 r
.41976 .52445 m .4169 .52463 L .41947 .52093 L F
.911 .843 .764 r
.41976 .52445 m .41864 .52605 L .4169 .52463 L F
.706 .547 .67 r
.43555 .48034 m .43714 .48429 L .43307 .48421 L F
.667 .504 .655 r
.43998 .47821 m .43988 .48079 L .43555 .48034 L F
.666 .527 .685 r
.43988 .48079 m .43714 .48429 L .43555 .48034 L F
.516 .915 .838 r
.59714 .40297 m .59742 .40179 L .59501 .40313 L F
.59714 .40297 m .60037 .40126 L .59742 .40179 L F
.651 .772 .938 r
.36977 .57072 m .37126 .57252 L .37409 .57142 L F
.858 .858 .84 r
.46352 .49669 m .46818 .49485 L .46656 .49361 L F
.871 .917 .857 r
.46656 .49361 m .46818 .49485 L .47101 .49151 L F
.869 .924 .861 r
.51809 .44976 m .52022 .44993 L .5205 .44692 L F
.792 .869 .905 r
.5205 .44692 m .52022 .44993 L .52454 .44657 L F
.843 .973 .878 r
.5025 .46282 m .50033 .46661 L .50352 .46373 L F
.5025 .46282 m .49924 .46594 L .50033 .46661 L F
0 0 0 r
.49605 .45421 m .4969 .45354 L .49845 .45213 L F
.545 .727 .959 r
.49849 .45229 m .4969 .45354 L .4953 .4514 L F
.252 0 0 r
.49975 .45264 m .49845 .45213 L .4969 .45354 L F
.545 .727 .959 r
.49975 .45264 m .4969 .45354 L .49849 .45229 L F
0 0 0 r
.49392 .45605 m .4969 .45354 L .49605 .45421 L F
.252 0 0 r
.49975 .45264 m .50082 .453 L .49845 .45213 L F
.838 .955 .89 r
.507 .46088 m .5025 .46282 L .50352 .46373 L F
.791 .75 .816 r
.31907 .64727 m .32093 .6513 L .32349 .64759 L F
.594 .777 .968 r
.37409 .57142 m .37865 .5724 L .37589 .57004 L F
.418 .707 .983 r
.37865 .5724 m .3793 .57039 L .37589 .57004 L F
.37865 .5724 m .38098 .57205 L .3793 .57039 L F
.857 .628 .591 r
.42458 .51132 m .42655 .51518 L .42236 .51473 L F
.802 .718 .772 r
.42655 .51518 m .42378 .51871 L .42236 .51473 L F
.711 .645 .782 r
.45236 .47378 m .45399 .47793 L .44956 .47718 L F
.375 .225 .546 r
.55053 .36801 m .55273 .3647 L .54982 .36578 L F
.039 .039 .528 r
.55312 .36723 m .55276 .37198 L .55393 .37058 L F
.953 .602 .272 r
.55312 .36723 m .55393 .37058 L .55375 .37026 L F
.375 .225 .546 r
.55053 .36801 m .55312 .36723 L .55263 .36487 L F
.6 .456 .657 r
.55053 .36801 m .55276 .37198 L .55312 .36723 L F
.953 .602 .272 r
.55312 .36723 m .55375 .37026 L .55127 .36595 L F
.375 .225 .546 r
.55263 .36487 m .55312 .36723 L .55273 .3647 L F
.6 .456 .657 r
.55053 .36801 m .55208 .37308 L .55276 .37198 L F
.451 .28 .557 r
.47469 .4438 m .47735 .44289 L .47703 .43997 L F
.347 .039 .292 r
.47469 .4438 m .47674 .44506 L .47735 .44289 L F
.47469 .4438 m .47415 .44587 L .47674 .44506 L F
.71 .524 .635 r
.4455 .47387 m .44265 .47736 L .44296 .47448 L F
.729 .552 .651 r
.4455 .47387 m .44733 .47802 L .44265 .47736 L F
.726 .55 .653 r
.44956 .47718 m .4455 .47387 L .44808 .473 L F
.44956 .47718 m .44733 .47802 L .4455 .47387 L F
.863 .845 .824 r
.39847 .54714 m .39379 .54854 L .39548 .54666 L F
.795 .926 .923 r
.40015 .54508 m .39847 .54714 L .39548 .54666 L F
.81 .68 .72 r
.32649 .64122 m .32867 .64034 L .32911 .63782 L F
.797 .636 .682 r
.32618 .64413 m .32867 .64034 L .32649 .64122 L F
.842 .833 .837 r
.42362 .50755 m .42724 .50742 L .42458 .51132 L F
.836 .83 .841 r
.4208 .51073 m .42362 .50755 L .42458 .51132 L F
.884 .723 .677 r
.4208 .51073 m .42458 .51132 L .42236 .51473 L F
.453 .316 .604 r
.49793 .40625 m .50007 .40155 L .49766 .40279 L F
.348 .073 .346 r
.4861 .41591 m .48859 .41488 L .48907 .4128 L F
.225 0 .257 r
.48859 .41488 m .49143 .41175 L .48907 .4128 L F
.37 .096 .362 r
.43593 .46389 m .43852 .46306 L .43863 .46008 L F
.359 .088 .36 r
.43863 .46008 m .4411 .4621 L .44125 .45939 L F
.43863 .46008 m .43852 .46306 L .4411 .4621 L F
.645 .166 .099 r
.37621 .49419 m .37438 .49585 L .37161 .49364 L F
.653 .176 .106 r
.37859 .49618 m .37438 .49585 L .37621 .49419 L F
.81 .663 .7 r
.3248 .63749 m .32911 .63782 L .32747 .63384 L F
.81 .68 .72 r
.32649 .64122 m .32911 .63782 L .3248 .63749 L F
.509 .279 .501 r
.43019 .48444 m .43015 .48717 L .42735 .48794 L F
.767 .579 .643 r
.43307 .48421 m .43015 .48717 L .43019 .48444 L F
.538 .824 .998 r
.4629 .4483 m .46182 .45034 L .46438 .44977 L F
.528 .321 .543 r
.46182 .45034 m .46451 .45267 L .46438 .44977 L F
.976 .764 .552 r
.4629 .4483 m .46451 .45267 L .46182 .45034 L F
.729 .567 .672 r
.45719 .46673 m .45386 .46381 L .45875 .46466 L F
.45719 .46673 m .45535 .46788 L .45386 .46381 L F
.563 .89 .987 r
.61348 .39678 m .61364 .39455 L .61146 .39645 L F
.61348 .39678 m .61624 .3957 L .61364 .39455 L F
.543 .828 .998 r
.36095 .54815 m .3629 .54969 L .36558 .54882 L F
.36095 .54815 m .3629 .54969 L .36558 .54882 L F
.782 .708 .782 r
.42236 .51473 m .42378 .51871 L .42199 .51702 L F
.875 .909 .85 r
.42378 .51871 m .41947 .52093 L .42199 .51702 L F
.981 .697 .398 r
.56833 .37185 m .56964 .37539 L .56793 .37383 L F
.792 .964 .652 r
.56964 .37539 m .56802 .37635 L .56793 .37383 L F
.56964 .37539 m .56706 .3789 L .56802 .37635 L F
.488 .86 .984 r
.39609 .57497 m .3972 .57319 L .39484 .57196 L F
.534 .659 .917 r
.46805 .44036 m .46525 .44391 L .46743 .44198 L F
.075 .11 .594 r
.46805 .44036 m .46705 .44594 L .46525 .44391 L F
.706 .619 .757 r
.53223 .36789 m .53432 .37229 L .53597 .36851 L F
.374 .1 .365 r
.53604 .3738 m .53339 .37468 L .53432 .37229 L F
.53604 .3738 m .53339 .37468 L .53432 .37229 L F
.689 .924 .97 r
.56706 .3789 m .56567 .37794 L .56802 .37635 L F
.281 0 .095 r
.42945 .46895 m .43268 .46668 L .43002 .46743 L F
.791 .731 .797 r
.48221 .46661 m .47906 .47016 L .47858 .46645 L F
.345 .359 .732 r
.53199 .36511 m .53525 .36665 L .53417 .36464 L F
.564 .745 .962 r
.53223 .36789 m .53525 .36665 L .53199 .36511 L F
.572 .732 .95 r
.35361 .5711 m .35407 .56802 L .35148 .5686 L F
.35361 .5711 m .35588 .57036 L .35407 .56802 L F
0 0 .178 r
.60793 .34455 m .60788 .34427 L .60692 .3403 L F
.807 .704 .752 r
.40332 .55592 m .39935 .55558 L .40169 .55194 L F
.804 .716 .768 r
.40332 .55592 m .40063 .55961 L .39935 .55558 L F
.705 .568 .698 r
.40335 .55932 m .40063 .55961 L .40332 .55592 L F
.781 .693 .767 r
.40598 .55246 m .40332 .55592 L .40169 .55194 L F
.601 .448 .647 r
.44265 .47736 m .43988 .48079 L .43998 .47821 L F
.845 .784 .793 r
.62391 .33746 m .62249 .33801 L .62086 .33684 L F
.865 .741 .724 r
.62086 .33684 m .62221 .34099 L .62391 .33746 L F
.515 .81 .999 r
.49392 .45605 m .49219 .45709 L .4896 .45539 L F
.73 .964 .939 r
.57212 .39338 m .57657 .39225 L .57547 .39102 L F
.873 .946 .859 r
.57848 .38755 m .57657 .39225 L .57948 .38885 L F
.57848 .38755 m .57547 .39102 L .57657 .39225 L F
.731 .64 .757 r
.32349 .64759 m .32781 .64833 L .32618 .64413 L F
.831 .61 .603 r
.32911 .64629 m .32618 .64413 L .32781 .64833 L F
.467 0 0 r
.37709 .48745 m .37985 .4878 L .38197 .48688 L F
.413 0 0 r
.37985 .4878 m .384 .48755 L .38197 .48688 L F
.689 .484 .604 r
.45276 .47085 m .44808 .473 L .4481 .47056 L F
.45276 .47085 m .45236 .47378 L .44808 .473 L F
.354 .013 .24 r
.48256 .41939 m .48545 .41872 L .4861 .41591 L F
.255 0 .209 r
.4861 .41591 m .48801 .41755 L .48859 .41488 L F
.4861 .41591 m .48545 .41872 L .48801 .41755 L F
.598 .329 .481 r
.40364 .55036 m .40169 .55194 L .39746 .55186 L F
.72 .602 .724 r
.40438 .5484 m .40364 .55036 L .40015 .54508 L F
.824 .723 .753 r
.40438 .5484 m .40169 .55194 L .40364 .55036 L F
.788 .665 .727 r
.40438 .5484 m .40598 .55246 L .40169 .55194 L F
0 0 .352 r
.59912 .35335 m .59788 .35547 L .5984 .34976 L F
.408 .243 .543 r
.60096 .34717 m .5984 .34976 L .5986 .34741 L F
.60096 .34717 m .60219 .35015 L .5984 .34976 L F
.307 .093 .416 r
.60145 .35207 m .5984 .34976 L .60219 .35015 L F
.60145 .35207 m .59912 .35335 L .5984 .34976 L F
.728 .543 .641 r
.42733 .49061 m .42466 .49407 L .42471 .49117 L F
.519 .733 .971 r
.54802 .40364 m .54803 .40559 L .54624 .40445 L F
.54802 .40364 m .55111 .40496 L .54803 .40559 L F
.85 .615 .583 r
.55111 .40496 m .54624 .40445 L .54803 .40559 L F
.838 .955 .89 r
.507 .46088 m .50327 .46112 L .5025 .46282 L F
.844 .965 .882 r
.50737 .45795 m .507 .46088 L .51045 .4574 L F
.831 .957 .895 r
.50737 .45795 m .50327 .46112 L .507 .46088 L F
.557 .47 .712 r
.40705 .56097 m .40335 .55932 L .40641 .5591 L F
.40705 .56097 m .40495 .56336 L .40335 .55932 L F
.871 .828 .802 r
.59449 .355 m .59788 .35547 L .59611 .35466 L F
.59449 .355 m .59563 .358 L .59788 .35547 L F
.224 0 .006 r
.59912 .35335 m .59611 .35466 L .59788 .35547 L F
.756 .784 .876 r
.48953 .43252 m .48713 .43428 L .48516 .43217 L F
.469 .117 .285 r
.40069 .48356 m .40355 .48323 L .40469 .48053 L F
.358 0 .166 r
.40355 .48323 m .40742 .48018 L .40469 .48053 L F
.655 .557 .732 r
.47519 .43551 m .47703 .43997 L .47965 .43643 L F
.346 .206 .543 r
.47703 .43997 m .47735 .44289 L .47945 .44156 L F
.742 .597 .695 r
.44956 .47718 m .44684 .48069 L .44733 .47802 L F
.668 .58 .747 r
.45236 .47378 m .44956 .47718 L .44808 .473 L F
.327 0 .134 r
.40742 .48018 m .41018 .47959 L .41082 .47786 L F
.55 .216 .355 r
.41018 .47959 m .41356 .4773 L .41082 .47786 L F
.674 .47 .602 r
.39746 .55186 m .39935 .55558 L .39463 .55423 L F
.617 .447 .63 r
.40169 .55194 m .39935 .55558 L .39746 .55186 L F
.962 .915 .563 r
.55313 .41589 m .55149 .41702 L .55135 .41477 L F
.55313 .41589 m .55181 .42009 L .55149 .41702 L F
.871 .917 .857 r
.46656 .49361 m .47101 .49151 L .46844 .49187 L F
.771 .962 .929 r
.47162 .48905 m .47101 .49151 L .47288 .48991 L F
.802 .983 .895 r
.47162 .48905 m .46844 .49187 L .47101 .49151 L F
.872 .856 .823 r
.4169 .52463 m .41864 .52605 L .41633 .52899 L F
.744 .579 .671 r
.48136 .43295 m .47965 .43643 L .48241 .43311 L F
.47907 .43449 m .47965 .43643 L .48136 .43295 L F
.663 .533 .696 r
.47519 .43551 m .47965 .43643 L .47846 .43251 L F
.336 0 .145 r
.48259 .43285 m .47687 .43676 L .47807 .43516 L F
.4782 .43507 m .47807 .43516 L .4781 .43513 L F
.48259 .43285 m .47807 .43516 L .4782 .43507 L F
.744 .579 .671 r
.47846 .43251 m .47907 .43449 L .48136 .43295 L F
.585 .358 .538 r
.48241 .43311 m .47965 .43643 L .48322 .43571 L F
.418 .263 .562 r
.48241 .43311 m .48322 .43571 L .48516 .43217 L F
.989 .893 .599 r
.57936 .38491 m .57848 .38755 L .57948 .38885 L F
.752 .741 .842 r
.35776 .49467 m .35336 .49423 L .35558 .49241 L F
.549 .373 .595 r
.35336 .49423 m .35591 .49469 L .35587 .49438 L F
.35336 .49423 m .35587 .49438 L .35558 .49241 L F
.77 .743 .828 r
.36053 .49146 m .35776 .49467 L .35558 .49241 L F
.404 0 0 r
.35776 .49467 m .3604 .49615 L .35663 .49454 L F
.027 .593 .786 r
.35547 .49444 m .35587 .49438 L .35336 .49423 L F
.35577 .49437 m .35574 .49416 L .35336 .49423 L F
.034 .566 .856 r
.35336 .49423 m .35574 .49416 L .35591 .49469 L F
.699 .784 .304 r
.35574 .49416 m .35542 .49491 L .35574 .49412 L F
.77 .743 .828 r
.36053 .49146 m .35558 .49241 L .36125 .49098 L F
0 0 .367 r
.35574 .49237 m .35668 .49176 L .36125 .49098 L F
.35558 .49241 m .35668 .49176 L .35574 .49237 L F
.791 .531 .545 r
.35556 .48995 m .35731 .49136 L .35668 .49176 L F
.255 0 0 r
.36125 .49098 m .35668 .49176 L .36116 .49121 L F
.603 .481 .686 r
.36053 .49146 m .36088 .49463 L .35776 .49467 L F
.673 .532 .684 r
.36354 .49275 m .36053 .49146 L .36298 .49027 L F
.36354 .49275 m .36088 .49463 L .36053 .49146 L F
.393 0 0 r
.35668 .49176 m .35897 .49271 L .36116 .49121 L F
.791 .531 .545 r
.35731 .49136 m .35897 .49271 L .35668 .49176 L F
0 0 .367 r
.3558 .4939 m .35598 .49403 L .35668 .49176 L F
.699 .784 .304 r
.35574 .49416 m .35574 .49412 L .35668 .49176 L F
.027 .593 .786 r
.35604 .49439 m .35574 .49416 L .35577 .49437 L F
.35684 .49444 m .35574 .49416 L .35604 .49439 L F
0 0 .367 r
.3558 .4939 m .35587 .49438 L .35598 .49403 L F
.35587 .49438 m .356 .49436 L .35646 .49262 L F
.35645 .49252 m .35646 .49262 L .35668 .49176 L F
.35587 .49438 m .35646 .49262 L .35645 .49252 L F
.027 .593 .786 r
.35776 .49467 m .35587 .49438 L .35547 .49444 L F
0 0 .367 r
.35587 .49438 m .35591 .49469 L .356 .49436 L F
.699 .784 .304 r
.35574 .49416 m .356 .49436 L .35591 .49469 L F
.815 .512 .476 r
.35663 .49454 m .35618 .49837 L .35574 .49416 L F
.3604 .49615 m .35694 .49797 L .35663 .49454 L F
.35694 .49797 m .35618 .49837 L .35663 .49454 L F
.699 .784 .304 r
.35574 .49416 m .35668 .49176 L .356 .49436 L F
.404 0 0 r
.35633 .49431 m .35663 .49454 L .35574 .49416 L F
.027 .593 .786 r
.35776 .49467 m .35684 .49444 L .35587 .49438 L F
.404 0 0 r
.35776 .49467 m .35663 .49454 L .35633 .49431 L F
0 0 .367 r
.35558 .49241 m .3558 .4939 L .35668 .49176 L F
.498 .089 .194 r
.36088 .49463 m .3604 .49615 L .35776 .49467 L F
.778 .593 .65 r
.32156 .62666 m .32623 .62412 L .32171 .62367 L F
.32156 .62666 m .32593 .62707 L .32623 .62412 L F
.847 .526 .446 r
.42959 .50375 m .42611 .5037 L .42604 .50109 L F
.872 .791 .767 r
.42959 .50375 m .42724 .50742 L .42611 .5037 L F
.17 .316 .77 r
.57348 .35258 m .57315 .35372 L .57225 .35497 L F
.736 .988 .887 r
.57225 .35497 m .57128 .35451 L .57348 .35258 L F
.872 .856 .823 r
.4169 .52463 m .41633 .52899 L .41387 .52781 L F
.888 .716 .663 r
.41633 .52899 m .41563 .53187 L .41387 .52781 L F
0 .462 .812 r
.61248 .35685 m .61419 .3574 L .61546 .35822 L F
.61546 .35822 m .61419 .3574 L .61248 .35685 L F
.472 .885 .932 r
.61819 .3567 m .61419 .3574 L .61546 .35822 L F
.61819 .3567 m .61419 .3574 L .61546 .35822 L F
.568 .407 .623 r
.30661 .6341 m .30931 .6334 L .30929 .63068 L F
.531 .53 .799 r
.52553 .41912 m .52978 .42254 L .52925 .41886 L F
.328 0 .199 r
.51408 .39871 m .51366 .39966 L .51172 .39993 L F
.456 .18 .405 r
.51366 .39966 m .50893 .40314 L .51172 .39993 L F
.679 .832 .957 r
.37102 .55866 m .36889 .56017 L .36674 .55829 L F
.971 .756 .556 r
.63965 .35422 m .63934 .35707 L .64102 .35799 L F
.956 .63 .358 r
.63934 .35707 m .64121 .3604 L .64102 .35799 L F
.664 .534 .695 r
.47846 .43251 m .47553 .43303 L .47819 .42937 L F
.638 .492 .668 r
.47846 .43251 m .47519 .43551 L .47553 .43303 L F
.205 0 0 r
.47846 .43251 m .47819 .42937 L .47553 .43303 L F
.663 .533 .696 r
.47519 .43551 m .47846 .43251 L .47553 .43303 L F
.682 .484 .612 r
.4037 .49441 m .40135 .49682 L .40079 .49516 L F
.711 .528 .64 r
.4037 .49441 m .40356 .49783 L .40135 .49682 L F
.689 .509 .639 r
.40754 .49718 m .40356 .49783 L .4037 .49441 L F
.073 .635 .737 r
.61439 .37299 m .6171 .37281 L .61726 .37286 L F
.763 .505 .544 r
.61325 .37493 m .61718 .3758 L .6171 .37281 L F
.61325 .37493 m .61498 .37398 L .61673 .37454 L F
.61498 .37398 m .6171 .37281 L .61689 .37376 L F
.61498 .37398 m .61689 .37376 L .61673 .37454 L F
.542 .538 .8 r
.61718 .3758 m .61973 .37476 L .61866 .37356 L F
.787 .613 .05 r
.6171 .37281 m .61696 .37277 L .61688 .37157 L F
.073 .635 .737 r
.61726 .37286 m .6171 .37281 L .61887 .37279 L F
.32 .808 .829 r
.61887 .37279 m .6171 .37281 L .61984 .37201 L F
.648 .15 .053 r
.61293 .37224 m .6171 .37281 L .61439 .37299 L F
.479 .852 .987 r
.6101 .37301 m .61439 .37299 L .61135 .37374 L F
.61118 .373 m .61293 .37224 L .61439 .37299 L F
.6101 .37301 m .61293 .37224 L .61118 .373 L F
.404 .411 .754 r
.6143 .36752 m .61554 .3711 L .61293 .37224 L F
.648 .15 .053 r
.61608 .37267 m .61673 .37454 L .6171 .37281 L F
.544 .368 .593 r
.61293 .37224 m .61688 .37157 L .61325 .37493 L F
.61293 .37224 m .61483 .37339 L .61688 .37157 L F
.491 .07 .168 r
.61472 .37357 m .6142 .37401 L .61325 .37493 L F
.763 .505 .544 r
.61325 .37493 m .61673 .37454 L .61483 .37339 L F
.61325 .37493 m .61483 .37339 L .61293 .37224 L F
.491 .07 .168 r
.6142 .37401 m .61314 .37488 L .61325 .37493 L F
.61688 .37157 m .61483 .37339 L .61472 .37357 L F
.61483 .37339 m .61314 .37488 L .61472 .37357 L F
.404 .411 .754 r
.61554 .3711 m .61578 .3718 L .61293 .37224 L F
.544 .368 .593 r
.61483 .37339 m .61673 .37454 L .61688 .37157 L F
.404 .411 .754 r
.61463 .37198 m .61483 .37339 L .61293 .37224 L F
.61578 .3718 m .61553 .37223 L .61463 .37198 L F
.61553 .37223 m .61483 .37339 L .61463 .37198 L F
.491 .07 .168 r
.61688 .37157 m .61553 .37223 L .61517 .37309 L F
.638 .461 .627 r
.61293 .37224 m .61016 .37605 L .61325 .37493 L F
.61293 .37224 m .61016 .37605 L .61325 .37493 L F
.491 .07 .168 r
.6138 .3743 m .6115 .37416 L .61314 .37488 L F
.404 .411 .754 r
.61528 .37263 m .61673 .37454 L .61483 .37339 L F
.61578 .3718 m .61601 .37246 L .61528 .37263 L F
.61601 .37246 m .61673 .37454 L .61528 .37263 L F
.573 .81 .989 r
.61984 .37201 m .6171 .37281 L .61882 .37036 L F
.787 .613 .05 r
.6171 .37281 m .61688 .37157 L .61882 .37036 L F
.542 .538 .8 r
.61703 .37375 m .61866 .37356 L .61688 .37157 L F
.787 .613 .05 r
.6171 .37281 m .61718 .3758 L .61696 .37277 L F
.542 .538 .8 r
.61718 .3758 m .61866 .37356 L .61703 .37375 L F
.425 .27 .565 r
.61688 .37157 m .61673 .37454 L .61766 .37268 L F
.74 .243 0 r
.61688 .37157 m .61973 .37476 L .61942 .37462 L F
.61766 .37268 m .61942 .37462 L .61884 .37437 L F
.61688 .37157 m .61942 .37462 L .61766 .37268 L F
.425 .27 .565 r
.61688 .37157 m .61766 .37268 L .61882 .37036 L F
.695 .583 .725 r
.61882 .37036 m .61766 .37268 L .6143 .36752 L F
.61766 .37268 m .61601 .37246 L .61691 .37194 L F
.771 .266 0 r
.61688 .37157 m .61755 .37256 L .61691 .37194 L F
.695 .583 .725 r
.61755 .37256 m .61691 .37194 L .61696 .37191 L F
.61766 .37268 m .61691 .37194 L .61755 .37256 L F
.61766 .37268 m .61673 .37454 L .61601 .37246 L F
.771 .266 0 r
.61691 .37194 m .61875 .37433 L .61712 .37413 L F
.61755 .37256 m .61875 .37433 L .61691 .37194 L F
.6163 .37229 m .61694 .37224 L .6162 .37241 L F
.61688 .37157 m .61691 .37194 L .6163 .37229 L F
.61691 .37194 m .61694 .37224 L .6163 .37229 L F
.491 .07 .168 r
.61688 .37157 m .6163 .37229 L .61553 .37223 L F
.695 .583 .725 r
.6163 .37229 m .61601 .37246 L .61597 .37235 L F
.491 .07 .168 r
.6163 .37229 m .6162 .37241 L .61597 .37235 L F
.6163 .37229 m .61597 .37235 L .61553 .37223 L F
.695 .583 .725 r
.61696 .37191 m .6163 .37229 L .61512 .36989 L F
.6163 .37229 m .61597 .37235 L .61512 .36989 L F
.61766 .37268 m .61512 .36989 L .6143 .36752 L F
.74 .243 0 r
.61688 .37157 m .61883 .37435 L .61875 .37433 L F
.161 .659 .914 r
.61875 .37433 m .61995 .37359 L .61752 .37406 L F
.61875 .37433 m .61752 .37406 L .61712 .37413 L F
.74 .243 0 r
.61883 .37435 m .61884 .37437 L .61875 .37433 L F
.771 .266 0 r
.6162 .37241 m .61712 .37413 L .61465 .37435 L F
.61694 .37224 m .61712 .37413 L .6162 .37241 L F
.491 .07 .168 r
.61553 .37223 m .61465 .37435 L .6115 .37416 L F
.6162 .37241 m .61465 .37435 L .61553 .37223 L F
.32 .808 .829 r
.61887 .37279 m .61984 .37201 L .62179 .37184 L F
.638 .492 .668 r
.47846 .43251 m .4781 .43513 L .47519 .43551 L F
.106 0 0 r
.47687 .43676 m .47519 .43551 L .4781 .43513 L F
.47687 .43676 m .47421 .4378 L .47519 .43551 L F
.536 .471 .73 r
.54711 .38504 m .54716 .38832 L .54901 .38535 L F
.04 .55 .875 r
.36672 .5704 m .36551 .56954 L .3628 .56899 L F
.369 .663 .971 r
.36672 .5704 m .36795 .56847 L .36551 .56954 L F
.36672 .5704 m .36977 .57072 L .36795 .56847 L F
.767 .579 .643 r
.43307 .48421 m .43437 .4898 L .43015 .48717 L F
.506 .31 .548 r
.43714 .48429 m .43437 .4898 L .43307 .48421 L F
.221 0 0 r
.53775 .36283 m .54321 .36148 L .53751 .36199 L F
.53775 .36283 m .54004 .36272 L .54321 .36148 L F
.669 .184 .09 r
.54321 .36148 m .54428 .36337 L .54364 .3611 L F
.597 .946 .807 r
.42052 .55854 m .42249 .55694 L .4246 .55648 L F
.502 0 0 r
.42249 .55694 m .42674 .55785 L .4246 .55648 L F
.506 .31 .548 r
.43714 .48429 m .43697 .48688 L .43437 .4898 L F
.653 .509 .675 r
.43965 .48378 m .43714 .48429 L .43988 .48079 L F
.77 .624 .698 r
.43965 .48378 m .43697 .48688 L .43714 .48429 L F
.795 .734 .796 r
.41294 .55565 m .41443 .55918 L .41727 .55575 L F
.853 .784 .783 r
.41562 .55359 m .41993 .55198 L .41831 .55203 L F
.41562 .55359 m .41727 .55575 L .41993 .55198 L F
.498 .03 .073 r
.42252 .55098 m .41831 .55203 L .41993 .55198 L F
.973 .759 .555 r
.39065 .55165 m .39198 .55564 L .39225 .55225 L F
.864 .921 .865 r
.39225 .55225 m .39065 .55165 L .39379 .54854 L F
.973 .759 .555 r
.39225 .55225 m .39198 .55564 L .39065 .55165 L F
.722 .521 .618 r
.39463 .55423 m .39198 .55564 L .39225 .55225 L F
.614 .428 .607 r
.3121 .62733 m .30929 .63068 L .31204 .63019 L F
.626 .441 .612 r
.31204 .63019 m .31495 .62706 L .3121 .62733 L F
.578 .485 .712 r
.39463 .55423 m .39433 .55899 L .39198 .55564 L F
.39463 .55423 m .39619 .55885 L .39433 .55899 L F
.75 .753 .855 r
.62971 .36107 m .63047 .36454 L .6266 .3642 L F
.787 .646 .707 r
.63047 .36454 m .62848 .36845 L .6266 .3642 L F
.787 .776 .842 r
.63372 .36139 m .63047 .36454 L .62971 .36107 L F
.634 .661 .859 r
.38788 .57204 m .38924 .57524 L .39201 .57319 L F
.813 .412 .292 r
.37245 .54574 m .37082 .54776 L .37042 .54564 L F
.173 0 0 r
.37497 .54488 m .37082 .54776 L .37245 .54574 L F
.827 .899 .891 r
.53807 .43168 m .54264 .43005 L .54099 .42848 L F
.753 .803 .893 r
.54099 .42848 m .54264 .43005 L .54491 .42825 L F
.443 .233 .498 r
.48146 .46 m .48155 .46318 L .47872 .46374 L F
.519 .29 .507 r
.4843 .459 m .48155 .46318 L .48146 .46 L F
.695 .435 .526 r
.49774 .44285 m .50226 .44014 L .49781 .43959 L F
0 0 .263 r
.58979 .36821 m .58962 .3665 L .58873 .36366 L F
0 0 .359 r
.58979 .36821 m .59038 .36869 L .58962 .3665 L F
0 0 .412 r
.59022 .37096 m .59075 .37011 L .58979 .36821 L F
.746 .613 .044 r
.59038 .37139 m .59037 .36822 L .59038 .36869 L F
0 0 .404 r
.59038 .36869 m .59036 .3673 L .58928 .36444 L F
.746 .613 .044 r
.59037 .36822 m .59036 .3673 L .59038 .36869 L F
0 0 .359 r
.58979 .36821 m .5904 .3694 L .59038 .36869 L F
.5904 .3694 m .59075 .37011 L .59038 .36869 L F
.916 .912 .8 r
.42931 .54849 m .43174 .54512 L .43021 .54371 L F
.77 .624 .698 r
.43965 .48378 m .44137 .48763 L .43697 .48688 L F
.701 .594 .732 r
.44419 .4841 m .44137 .48763 L .43965 .48378 L F
.075 .284 .77 r
.59024 .40013 m .58961 .4024 L .59246 .40444 L F
.965 .936 .691 r
.57995 .36905 m .58204 .36831 L .58102 .36694 L F
.57995 .36905 m .58052 .37213 L .58204 .36831 L F
.996 .856 .53 r
.58175 .36429 m .58102 .36694 L .58204 .36831 L F
.338 .05 .319 r
.50628 .39853 m .50913 .39766 L .50891 .39454 L F
.244 0 .272 r
.50891 .39454 m .51196 .39415 L .51221 .39144 L F
.227 0 .287 r
.50913 .39766 m .51196 .39415 L .50891 .39454 L F
.728 .543 .641 r
.42733 .49061 m .42955 .49509 L .42466 .49407 L F
.579 .473 .697 r
.43015 .48717 m .42733 .49061 L .42735 .48794 L F
.657 .584 .762 r
.43015 .48717 m .43226 .49141 L .42733 .49061 L F
.665 .517 .674 r
.43155 .49395 m .42733 .49061 L .43226 .49141 L F
.43155 .49395 m .42955 .49509 L .42733 .49061 L F
.661 .645 .824 r
.30248 .65093 m .30119 .65369 L .29971 .65365 L F
.705 .597 .733 r
.44265 .47736 m .44441 .4814 L .43988 .48079 L F
.705 .546 .669 r
.44441 .4814 m .43965 .48378 L .43988 .48079 L F
.44441 .4814 m .44419 .4841 L .43965 .48378 L F
.688 .589 .739 r
.44684 .48069 m .44441 .4814 L .44265 .47736 L F
.665 .511 .665 r
.44684 .48069 m .44419 .4841 L .44441 .4814 L F
.488 .836 .997 r
.51021 .41482 m .50857 .41396 L .50721 .41555 L F
.51021 .41482 m .50857 .41396 L .50721 .41555 L F
.972 .747 .539 r
.57795 .37306 m .58052 .37213 L .57995 .36905 L F
.57795 .37306 m .57968 .37437 L .58052 .37213 L F
.423 .132 .364 r
.41685 .47572 m .41993 .47316 L .41712 .47368 L F
.51 .239 .439 r
.41356 .4773 m .41685 .47572 L .41712 .47368 L F
.481 .278 .527 r
.30455 .64377 m .3079 .64412 L .3076 .64021 L F
.64 .493 .666 r
.3051 .64766 m .3079 .64412 L .30455 .64377 L F
.248 0 .102 r
.49882 .41746 m .49616 .41835 L .49682 .41673 L F
.722 .967 .937 r
.62482 .39353 m .62963 .39188 L .62903 .39127 L F
.854 .979 .862 r
.62963 .39188 m .63177 .38745 L .62903 .39127 L F
.62963 .39188 m .63271 .38878 L .63177 .38745 L F
.836 .595 .574 r
.35454 .56215 m .35014 .56238 L .35249 .56091 L F
.35454 .56215 m .35117 .56688 L .35014 .56238 L F
.725 .906 .959 r
.35807 .55867 m .35454 .56215 L .35249 .56091 L F
.498 .327 .58 r
.50474 .40568 m .50459 .40863 L .50248 .40913 L F
.693 .914 .97 r
.54021 .41095 m .53909 .41356 L .53663 .41137 L F
.181 0 0 r
.53864 .41149 m .54021 .41095 L .53663 .41137 L F
.53906 .41152 m .53985 .41113 L .53864 .41149 L F
.53985 .41113 m .54021 .41095 L .53864 .41149 L F
.53906 .41152 m .53663 .41137 L .53578 .41283 L F
.642 .944 .957 r
.53636 .41218 m .53501 .41211 L .53776 .4106 L F
.53578 .41283 m .53539 .41247 L .53636 .41218 L F
.53539 .41247 m .53501 .41211 L .53636 .41218 L F
.771 .997 .827 r
.54055 .41015 m .54021 .41095 L .53906 .41152 L F
.54179 .40901 m .54021 .41095 L .54055 .41015 L F
.693 .914 .97 r
.54021 .41095 m .53949 .41392 L .53909 .41356 L F
.937 .965 .739 r
.63177 .38745 m .6348 .38511 L .63428 .38396 L F
.63177 .38745 m .63271 .38878 L .6348 .38511 L F
.874 .983 .834 r
.6348 .38511 m .63695 .38058 L .63428 .38396 L F
.6348 .38511 m .63787 .38152 L .63695 .38058 L F
.564 .22 .345 r
.60348 .38737 m .60749 .38526 L .60408 .38531 L F
.60348 .38737 m .60627 .38806 L .60749 .38526 L F
.615 .242 .313 r
.60627 .38806 m .61006 .38565 L .60749 .38526 L F
.531 .185 .327 r
.41993 .47316 m .42285 .47297 L .4234 .47094 L F
.503 .209 .401 r
.42285 .47297 m .4261 .47016 L .4234 .47094 L F
0 0 0 r
.5916 .3817 m .59004 .38561 L .59117 .38322 L F
0 0 .018 r
.58924 .38799 m .59117 .38322 L .59004 .38561 L F
.688 .589 .739 r
.44684 .48069 m .44265 .47736 L .44733 .47802 L F
.852 .853 .842 r
.62848 .36845 m .62567 .37193 L .62398 .37016 L F
.838 .642 .638 r
.32792 .63103 m .32593 .62707 L .32588 .62987 L F
.814 .672 .707 r
.32588 .62987 m .32747 .63384 L .32792 .63103 L F
.698 .633 .78 r
.51021 .41482 m .51384 .41777 L .51458 .41567 L F
0 0 .028 r
.55496 .42284 m .55673 .41885 L .556 .42062 L F
.737 .941 .618 r
.55334 .42407 m .55496 .42284 L .556 .42062 L F
.144 .178 .638 r
.40641 .5591 m .40724 .56083 L .40831 .55746 L F
0 0 .398 r
.40831 .55746 m .40705 .56097 L .40641 .5591 L F
.52 .414 .674 r
.48087 .42825 m .47846 .43251 L .47819 .42937 L F
0 .163 .69 r
.52407 .37833 m .52631 .3801 L .52626 .37731 L F
.794 .905 .918 r
.42718 .54998 m .42772 .54731 L .4233 .55058 L F
.42718 .54998 m .42931 .54849 L .42772 .54731 L F
0 0 0 r
.4774 .42331 m .47404 .42624 L .47613 .42486 L F
.046 0 0 r
.4774 .42331 m .4785 .42337 L .47957 .42215 L F
.4774 .42331 m .47613 .42486 L .4785 .42337 L F
.718 .273 .192 r
.41374 .56482 m .41683 .56693 L .41442 .56624 L F
.41374 .56482 m .41442 .56624 L .41737 .56197 L F
.615 .242 .313 r
.60627 .38806 m .61023 .38753 L .61006 .38565 L F
.48 .222 .445 r
.61023 .38753 m .61327 .38443 L .61006 .38565 L F
.257 0 .089 r
.47404 .42624 m .47575 .42772 L .47613 .42486 L F
.47404 .42624 m .47318 .42833 L .47575 .42772 L F
.795 .734 .796 r
.41294 .55565 m .41727 .55575 L .41562 .55359 L F
0 0 .154 r
.50902 .44487 m .50741 .44615 L .50658 .44923 L F
0 .222 .724 r
.59643 .35795 m .59563 .358 L .59449 .355 L F
.59643 .35795 m .59803 .35987 L .59563 .358 L F
.42 .849 .714 r
.56101 .39313 m .56522 .39107 L .56265 .39141 L F
.746 .69 .798 r
.30427 .65504 m .30509 .64997 L .30248 .65093 L F
.30427 .65504 m .30697 .65336 L .30509 .64997 L F
.987 .876 .525 r
.58116 .37865 m .57961 .37998 L .58045 .38122 L F
.992 .741 .428 r
.57967 .37712 m .57961 .37998 L .58116 .37865 L F
.576 .824 .992 r
.61991 .39478 m .62128 .39265 L .61878 .39435 L F
.61991 .39478 m .62283 .39404 L .62128 .39265 L F
.556 .362 .573 r
.30931 .6334 m .31204 .63019 L .30929 .63068 L F
.585 .708 .928 r
.53585 .41558 m .53988 .41695 L .53785 .41602 L F
.821 .898 .896 r
.53785 .41602 m .53988 .41695 L .54196 .41496 L F
.925 .957 .783 r
.55149 .41702 m .55181 .42009 L .54938 .42221 L F
.801 .725 .781 r
.31907 .64727 m .32349 .64759 L .3218 .64369 L F
.78 .716 .793 r
.32349 .64759 m .32618 .64413 L .3218 .64369 L F
.244 0 0 r
.59803 .35987 m .59976 .36035 L .60209 .36038 L F
.849 .46 .309 r
.4029 .5715 m .40508 .57003 L .40044 .5686 L F
.804 .668 .713 r
.32304 .63338 m .32747 .63384 L .32588 .62987 L F
.806 .656 .697 r
.3248 .63749 m .32747 .63384 L .32304 .63338 L F
.498 .89 .728 r
.56174 .38622 m .561 .38664 L .56008 .38766 L F
.376 .831 .924 r
.55956 .38825 m .56008 .38766 L .55727 .38839 L F
.472 0 0 r
.56008 .38766 m .55548 .38703 L .55727 .38839 L F
.56008 .38766 m .558 .38845 L .55548 .38703 L F
.558 .38845 m .55741 .38841 L .557 .38811 L F
.55608 .38736 m .557 .38811 L .55548 .38703 L F
.558 .38845 m .557 .38811 L .55608 .38736 L F
.498 .89 .728 r
.561 .38664 m .5577 .38852 L .56008 .38766 L F
.472 0 0 r
.55766 .38858 m .5576 .38861 L .55716 .38846 L F
.559 .83 .996 r
.55458 .38922 m .55727 .38839 L .55548 .38703 L F
.55 .518 .772 r
.55762 .38862 m .55818 .39241 L .55688 .38839 L F
.472 0 0 r
.5576 .38861 m .55741 .38868 L .55719 .38849 L F
.5576 .38861 m .55719 .38849 L .55716 .38846 L F
.55 .518 .772 r
.55688 .38839 m .55818 .39241 L .55571 .3922 L F
.498 .89 .728 r
.5577 .38852 m .55741 .38868 L .5576 .38861 L F
.55762 .38859 m .5576 .38861 L .55761 .3886 L F
.5577 .38852 m .55761 .3886 L .56008 .38766 L F
.472 0 0 r
.558 .38845 m .55766 .38858 L .55741 .38841 L F
.82 .662 .686 r
.55736 .38684 m .5577 .38852 L .56174 .38622 L F
0 .003 .551 r
.55863 .38943 m .55774 .38871 L .55736 .38684 L F
.55774 .38871 m .55762 .38862 L .55736 .38684 L F
.472 0 0 r
.55766 .38858 m .55716 .38846 L .55548 .38703 L F
.55 .518 .772 r
.55736 .38684 m .55762 .38859 L .55719 .38848 L F
0 0 .478 r
.55548 .38703 m .55719 .38849 L .55736 .38684 L F
.55 .518 .772 r
.55736 .38684 m .55719 .38848 L .55688 .38839 L F
.55762 .38859 m .5576 .38861 L .55688 .38839 L F
0 0 .478 r
.55719 .38849 m .55741 .38868 L .55736 .38684 L F
.82 .662 .686 r
.55736 .38684 m .55741 .38868 L .5577 .38852 L F
.498 .89 .728 r
.5577 .38852 m .5576 .38861 L .55762 .38859 L F
.55 .518 .772 r
.55762 .38859 m .55762 .38862 L .5576 .38861 L F
0 .003 .551 r
.55877 .38849 m .55863 .38943 L .55803 .3882 L F
.5583 .38794 m .55803 .3882 L .55736 .38684 L F
.55877 .38849 m .55803 .3882 L .5583 .38794 L F
.55863 .38943 m .55818 .39241 L .55762 .38862 L F
.559 .83 .996 r
.55458 .38922 m .55548 .38703 L .55321 .38693 L F
.432 .563 .886 r
.54901 .38535 m .55321 .38693 L .55126 .3833 L F
.363 .58 .925 r
.55321 .38693 m .55262 .38334 L .55126 .3833 L F
.55262 .38334 m .55241 .38209 L .55162 .38292 L F
.55262 .38334 m .55162 .38292 L .55126 .3833 L F
.55321 .38693 m .55548 .38703 L .55241 .38209 L F
.565 .695 .928 r
.55241 .38209 m .55548 .38703 L .55509 .38465 L F
.53 .886 .66 r
.55126 .3833 m .55241 .38209 L .55163 .38265 L F
0 .345 .742 r
.55509 .38465 m .55182 .38276 L .55241 .38209 L F
.55182 .38276 m .55163 .38265 L .55209 .38232 L F
.55182 .38276 m .55209 .38232 L .55241 .38209 L F
.521 .281 .491 r
.55268 .38648 m .55095 .38424 L .55328 .38342 L F
.432 .563 .886 r
.54901 .38535 m .55126 .3833 L .54932 .38341 L F
.261 .286 .699 r
.54888 .3815 m .55126 .3833 L .54932 .38341 L F
.54888 .3815 m .55126 .3833 L .54932 .38341 L F
0 0 0 r
.55009 .38313 m .54932 .38341 L .55126 .3833 L F
.521 .281 .491 r
.55095 .38424 m .55009 .38313 L .55153 .38326 L F
.55095 .38424 m .55153 .38326 L .55328 .38342 L F
0 .345 .742 r
.55332 .38363 m .55328 .38342 L .55163 .38265 L F
.55509 .38465 m .55401 .38391 L .55332 .38363 L F
.55401 .38391 m .55328 .38342 L .55332 .38363 L F
0 0 .478 r
.55548 .38703 m .55736 .38684 L .55509 .38465 L F
.794 .804 .859 r
.55736 .38684 m .55668 .38835 L .55268 .38648 L F
.55668 .38835 m .55524 .39152 L .5535 .38809 L F
.55668 .38835 m .5535 .38809 L .55268 .38648 L F
.55 .518 .772 r
.55668 .38835 m .55571 .3922 L .55524 .39152 L F
.55736 .38684 m .55688 .38839 L .55668 .38835 L F
.55688 .38839 m .55571 .3922 L .55668 .38835 L F
.376 .831 .924 r
.56084 .38817 m .56008 .38766 L .55956 .38825 L F
.462 .876 .74 r
.56434 .38624 m .56277 .38672 L .56143 .38785 L F
.087 0 0 r
.56773 .38624 m .56277 .38672 L .56434 .38624 L F
.529 .035 .028 r
.56773 .38624 m .56569 .38823 L .56277 .38672 L F
.084 .345 .817 r
.56277 .38672 m .56569 .38823 L .56427 .38544 L F
.56277 .38672 m .56427 .38544 L .5641 .3851 L F
.462 .876 .74 r
.56143 .38785 m .56277 .38672 L .56084 .38817 L F
.467 .884 .925 r
.56277 .38672 m .56008 .38766 L .56084 .38817 L F
.332 0 0 r
.36587 .48885 m .36826 .48895 L .37022 .488 L F
.41 0 0 r
.37022 .488 m .36826 .48895 L .37255 .48908 L F
.856 .843 .831 r
.56642 .36957 m .56758 .37201 L .56833 .37185 L F
.399 .367 .707 r
.56833 .37185 m .56766 .36761 L .56642 .36957 L F
.56833 .37185 m .56979 .36646 L .56766 .36761 L F
.56833 .37185 m .57115 .37039 L .56979 .36646 L F
.543 .395 .63 r
.56793 .37383 m .57115 .37039 L .56833 .37185 L F
.895 .754 .698 r
.40082 .56538 m .40495 .56336 L .40285 .56283 L F
.817 .927 .907 r
.40285 .56283 m .40495 .56336 L .40705 .56097 L F
.819 .966 .648 r
.55954 .40703 m .562 .40258 L .55924 .40576 L F
0 0 .236 r
.55947 .40656 m .55954 .40703 L .55924 .40576 L F
.812 .88 .449 r
.55954 .40703 m .5597 .40797 L .56078 .40527 L F
0 0 .236 r
.56034 .40971 m .55954 .40703 L .55947 .40656 L F
.812 .88 .449 r
.55954 .40703 m .5593 .40898 L .5597 .40797 L F
0 0 .321 r
.56034 .40971 m .5593 .40898 L .55954 .40703 L F
.56034 .40971 m .55987 .41192 L .5593 .40898 L F
.747 .691 .798 r
.51384 .41777 m .51274 .42039 L .51043 .42116 L F
.814 .942 .583 r
.42674 .55785 m .42446 .56165 L .42476 .56208 L F
.564 .745 .962 r
.53223 .36789 m .53597 .36851 L .53525 .36665 L F
.629 .786 .957 r
.53525 .36665 m .53597 .36851 L .53888 .36761 L F
.53525 .36665 m .53597 .36851 L .53888 .36761 L F
.463 .67 .953 r
.55591 .37775 m .55726 .37554 L .55466 .37418 L F
.55591 .37775 m .55791 .378 L .55726 .37554 L F
.264 0 0 r
.55591 .37775 m .55802 .37795 L .55791 .378 L F
.55591 .37775 m .55437 .3799 L .55802 .37795 L F
.746 .783 .883 r
.53533 .42061 m .53681 .42279 L .53368 .42511 L F
.339 0 0 r
.39636 .48594 m .40069 .48356 L .39793 .48379 L F
.725 .789 .903 r
.38229 .55904 m .37796 .55861 L .38062 .5571 L F
.754 .796 .887 r
.38472 .55789 m .38229 .55904 L .38062 .5571 L F
.858 .498 .369 r
.64708 .36435 m .64756 .36631 L .64938 .36486 L F
.966 .726 .523 r
.64756 .36631 m .64932 .3679 L .64938 .36486 L F
.859 .785 .777 r
.42611 .5037 m .42724 .50742 L .42362 .50755 L F
.52 .414 .674 r
.48087 .42825 m .4836 .43276 L .47846 .43251 L F
.333 .218 .57 r
.48259 .43285 m .47846 .43251 L .4836 .43276 L F
.48259 .43285 m .4781 .43513 L .47846 .43251 L F
0 0 0 r
.42189 .56523 m .4197 .56672 L .41817 .56735 L F
.42446 .56165 m .42214 .56536 L .42189 .56523 L F
.42189 .56523 m .42214 .56536 L .4197 .56672 L F
.471 .305 .573 r
.3076 .64021 m .31024 .64028 L .31037 .63782 L F
.613 .442 .627 r
.3079 .64412 m .31024 .64028 L .3076 .64021 L F
.739 .649 .76 r
.32488 .64075 m .32649 .64122 L .3248 .63749 L F
.797 .636 .682 r
.3218 .64369 m .32649 .64122 L .32488 .64075 L F
.3218 .64369 m .32618 .64413 L .32649 .64122 L F
.792 .869 .905 r
.5205 .44692 m .52454 .44657 L .52325 .4456 L F
.786 .977 .91 r
.52454 .44657 m .52524 .44394 L .52325 .4456 L F
.52454 .44657 m .52798 .44396 L .52524 .44394 L F
.7 .673 .82 r
.30509 .64997 m .30697 .65336 L .30936 .65065 L F
.842 .989 .857 r
.63787 .38152 m .64021 .37728 L .63695 .38058 L F
.63787 .38152 m .64099 .37836 L .64021 .37728 L F
.812 .773 .817 r
.5077 .40494 m .50459 .40863 L .50474 .40568 L F
.499 .238 .45 r
.41071 .49425 m .41084 .49679 L .40754 .49718 L F
.735 .503 .577 r
.41296 .49387 m .41084 .49679 L .41071 .49425 L F
.504 .268 .49 r
.60229 .40077 m .60226 .39827 L .5993 .39892 L F
0 0 0 r
.51676 .39798 m .51366 .39966 L .51408 .39871 L F
.462 .774 .997 r
.48813 .43105 m .49232 .43206 L .48953 .43252 L F
.488 0 0 r
.48979 .43549 m .48953 .43252 L .49232 .43206 L F
.545 0 0 r
.34776 .56253 m .34603 .56343 L .34305 .56184 L F
.492 0 0 r
.34305 .56184 m .34572 .56283 L .34776 .56253 L F
.768 .991 .886 r
.34776 .56253 m .34857 .56059 L .35014 .56238 L F
.34776 .56253 m .34572 .56283 L .34857 .56059 L F
.987 .718 .409 r
.34776 .56253 m .34755 .56468 L .34603 .56343 L F
.653 .527 .698 r
.39935 .55558 m .39619 .55885 L .39463 .55423 L F
0 .16 .694 r
.59021 .37794 m .5916 .3817 L .59119 .37766 L F
.849 .704 .174 r
.5916 .3817 m .59117 .38322 L .59119 .37766 L F
.536 .471 .73 r
.54711 .38504 m .54901 .38535 L .54932 .38341 L F
.854 .96 .875 r
.50737 .45795 m .51045 .4574 L .51186 .45572 L F
.727 .709 .834 r
.37359 .55635 m .37533 .55956 L .37102 .55866 L F
.613 .657 .87 r
.37796 .55861 m .37533 .55956 L .37359 .55635 L F
0 0 0 r
.596 .34992 m .5986 .34741 L .59621 .34947 L F
.491 .385 .661 r
.55454 .39406 m .55219 .39562 L .55065 .39286 L F
.77 .29 .096 r
.55273 .3647 m .54979 .36324 L .54982 .36578 L F
.916 .912 .8 r
.42931 .54849 m .43021 .54371 L .42772 .54731 L F
.372 .555 .903 r
.47965 .43643 m .48396 .43972 L .48322 .43571 L F
.701 .98 .899 r
.48396 .43972 m .47945 .44156 L .48333 .43954 L F
.06 .164 .66 r
.48322 .43571 m .48396 .43972 L .48547 .43749 L F
.676 .97 .782 r
.48547 .43749 m .48396 .43972 L .48333 .43954 L F
.754 .796 .887 r
.38472 .55789 m .38062 .5571 L .38293 .5559 L F
.807 .89 .903 r
.38544 .55662 m .38472 .55789 L .38293 .5559 L F
.333 .294 .665 r
.58991 .37221 m .59026 .37501 L .59022 .37096 L F
.782 .791 .86 r
.57505 .35704 m .5721 .36016 L .57598 .36064 L F
0 0 0 r
.57287 .36382 m .57598 .36064 L .5721 .36016 L F
.57287 .36382 m .57467 .36233 L .57598 .36064 L F
.848 .826 .826 r
.57505 .35704 m .57598 .36064 L .57814 .35692 L F
.565 .032 0 r
.57598 .36064 m .57467 .36233 L .5793 .36275 L F
.549 .236 .39 r
.58888 .35104 m .58905 .35373 L .59167 .35299 L F
.035 0 .081 r
.51854 .38545 m .51553 .38873 L .51786 .38726 L F
.4 .172 .448 r
.51488 .39022 m .51786 .38726 L .51553 .38873 L F
.849 .696 .692 r
.63399 .35833 m .63372 .36139 L .63204 .35728 L F
.782 .595 .646 r
.32357 .6307 m .32593 .62707 L .32156 .62666 L F
.32357 .6307 m .32588 .62987 L .32593 .62707 L F
.759 .923 .943 r
.4925 .46871 m .49385 .46974 L .49742 .46764 L F
.75 .856 .928 r
.60243 .4009 m .60486 .3973 L .60226 .39827 L F
.60243 .4009 m .60648 .39919 L .60486 .3973 L F
.824 .641 .655 r
.4243 .49691 m .42604 .50109 L .42191 .50026 L F
.763 .455 .465 r
.42604 .50109 m .4217 .50309 L .42191 .50026 L F
.42604 .50109 m .42611 .5037 L .4217 .50309 L F
.688 .581 .73 r
.42887 .49743 m .42604 .50109 L .4243 .49691 L F
.169 0 .201 r
.45358 .44662 m .45063 .4499 L .45296 .44875 L F
.467 .249 .499 r
.45296 .44875 m .45582 .44543 L .45358 .44662 L F
.809 .655 .692 r
.6266 .3642 m .62848 .36845 L .62409 .36732 L F
.852 .853 .842 r
.62848 .36845 m .62398 .37016 L .62409 .36732 L F
.77 .29 .096 r
.55273 .3647 m .55127 .36595 L .54979 .36324 L F
.966 .641 .329 r
.55312 .36723 m .55127 .36595 L .55273 .3647 L F
0 0 0 r
.55673 .41885 m .55914 .41455 L .55832 .41676 L F
.556 .42062 m .55673 .41885 L .55832 .41676 L F
.306 0 .212 r
.46177 .43617 m .46436 .43539 L .46526 .43345 L F
.231 0 .174 r
.46526 .43345 m .46683 .43447 L .46725 .43231 L F
.46526 .43345 m .46436 .43539 L .46683 .43447 L F
.665 .338 .411 r
.40135 .49682 m .39705 .49925 L .39699 .49696 L F
.40135 .49682 m .39928 .50022 L .39705 .49925 L F
.695 .374 .429 r
.40356 .49994 m .39928 .50022 L .40135 .49682 L F
.747 .378 .354 r
.40356 .49783 m .40356 .49994 L .40135 .49682 L F
.828 .697 .72 r
.41387 .52781 m .41563 .53187 L .41415 .53042 L F
.901 .76 .696 r
.41463 .53414 m .41415 .53042 L .41563 .53187 L F
.521 .285 .498 r
.53317 .41931 m .53262 .42198 L .52978 .42254 L F
.415 .19 .461 r
.53533 .42061 m .53262 .42198 L .53317 .41931 L F
.901 .76 .696 r
.41463 .53414 m .41132 .53442 L .41415 .53042 L F
.878 .869 .825 r
.41463 .53414 m .41311 .53586 L .41132 .53442 L F
0 0 .305 r
.59022 .37096 m .59026 .37501 L .591 .3727 L F
0 0 .12 r
.59026 .37501 m .59077 .37644 L .591 .3727 L F
.59026 .37501 m .59021 .37794 L .59077 .37644 L F
.749 .65 .751 r
.55208 .37308 m .55149 .375 L .55276 .37198 L F
.591 .468 .681 r
.55276 .37198 m .55149 .375 L .55466 .37418 L F
.433 .137 .361 r
.44745 .45283 m .45003 .45224 L .45063 .4499 L F
.299 .02 .31 r
.45063 .4499 m .45307 .451 L .45296 .44875 L F
.45063 .4499 m .45003 .45224 L .45307 .451 L F
.921 .716 .609 r
.63204 .35728 m .63372 .36139 L .63185 .35893 L F
.787 .776 .842 r
.63372 .36139 m .62971 .36107 L .63185 .35893 L F
.725 .524 .618 r
.41296 .49387 m .41767 .49417 L .4173 .49721 L F
.616 .806 .973 r
.60486 .3973 m .60648 .39919 L .60908 .398 L F
.436 0 0 r
.61175 .34363 m .61098 .3445 L .60788 .34427 L F
.032 0 .206 r
.61436 .3408 m .61413 .34286 L .61175 .34363 L F
0 0 0 r
.61413 .34286 m .61098 .3445 L .61175 .34363 L F
.734 .617 .728 r
.43412 .49021 m .43015 .48717 L .43437 .4898 L F
.43412 .49021 m .43226 .49141 L .43015 .48717 L F
.694 .534 .666 r
.43412 .49021 m .43155 .49395 L .43226 .49141 L F
.873 .957 .857 r
.43697 .48688 m .43412 .49021 L .43437 .4898 L F
.481 0 .014 r
.37255 .48908 m .37534 .48923 L .37709 .48745 L F
.396 0 0 r
.37709 .48745 m .38005 .48825 L .37985 .4878 L F
.37709 .48745 m .37534 .48923 L .38005 .48825 L F
.651 .772 .938 r
.36977 .57072 m .37409 .57142 L .37222 .56918 L F
.637 .799 .96 r
.37222 .56918 m .37409 .57142 L .37589 .57004 L F
.79 .689 .753 r
.32039 .64003 m .32488 .64075 L .3248 .63749 L F
.803 .629 .667 r
.3218 .64369 m .32488 .64075 L .32039 .64003 L F
.246 0 0 r
.37161 .49364 m .36704 .49632 L .3676 .49442 L F
.37161 .49364 m .36976 .49578 L .36704 .49632 L F
.634 .188 .175 r
.37438 .49585 m .36976 .49578 L .37161 .49364 L F
.764 .691 .781 r
.41821 .51374 m .42199 .51702 L .41843 .51653 L F
.41821 .51374 m .42236 .51473 L .42199 .51702 L F
.921 .82 .73 r
.42199 .51702 m .4175 .51958 L .41843 .51653 L F
.42199 .51702 m .41947 .52093 L .4175 .51958 L F
0 0 0 r
.596 .34992 m .59813 .34894 L .5986 .34741 L F
.612 .781 .962 r
.60096 .34717 m .5986 .34741 L .60187 .34635 L F
0 0 0 r
.5986 .34741 m .60011 .34766 L .60187 .34635 L F
.5986 .34741 m .59813 .34894 L .60011 .34766 L F
.71 .507 .613 r
.31956 .62708 m .32171 .62367 L .32017 .62423 L F
.31956 .62708 m .32156 .62666 L .32171 .62367 L F
.703 .599 .737 r
.42466 .49407 m .4243 .49691 L .4219 .49757 L F
.824 .641 .655 r
.4243 .49691 m .42191 .50026 L .4219 .49757 L F
.749 .472 .512 r
.4219 .49757 m .41738 .49974 L .4173 .49721 L F
.4219 .49757 m .42191 .50026 L .41738 .49974 L F
.938 .966 .718 r
.38779 .5527 m .38544 .55662 L .38557 .55371 L F
.72 .98 .766 r
.38779 .5527 m .3888 .55068 L .39065 .55165 L F
.38779 .5527 m .38557 .55371 L .3888 .55068 L F
.356 .81 .687 r
.36298 .49027 m .36053 .49146 L .36125 .49098 L F
.888 .656 .581 r
.49411 .44174 m .49781 .43959 L .49551 .43796 L F
.49411 .44174 m .49774 .44285 L .49781 .43959 L F
.848 .463 .32 r
.62577 .35315 m .62764 .35721 L .62391 .3553 L F
.867 .967 .859 r
.64099 .37836 m .64325 .37333 L .64021 .37728 L F
.64099 .37836 m .64399 .37517 L .64325 .37333 L F
.626 .441 .612 r
.31204 .63019 m .3157 .62918 L .31495 .62706 L F
.628 .423 .586 r
.31495 .62706 m .31956 .62708 L .32017 .62423 L F
.697 .584 .726 r
.3157 .62918 m .31956 .62708 L .31495 .62706 L F
.228 0 .148 r
.49285 .42118 m .49046 .42224 L .49373 .41948 L F
.206 0 .136 r
.49447 .42009 m .49373 .41948 L .49616 .41835 L F
.49447 .42009 m .49285 .42118 L .49373 .41948 L F
.736 .665 .78 r
.30936 .65065 m .31424 .6516 L .3121 .64742 L F
.743 .667 .777 r
.3121 .64742 m .31424 .6516 L .31677 .64875 L F
.814 .79 .829 r
.35823 .56946 m .36003 .57205 L .3628 .56899 L F
.529 .347 .578 r
.51786 .38726 m .52072 .38438 L .51854 .38545 L F
.053 0 0 r
.5335 .3774 m .53139 .37914 L .53098 .37857 L F
.372 .018 .227 r
.53328 .37849 m .53007 .38022 L .5335 .3774 L F
.53316 .37911 m .5309 .37995 L .53328 .37849 L F
.53215 .37953 m .5309 .37995 L .53316 .37911 L F
.5309 .37995 m .53007 .38022 L .53328 .37849 L F
.053 0 0 r
.53139 .37914 m .53007 .38022 L .53053 .37939 L F
.53139 .37914 m .53053 .37939 L .53098 .37857 L F
.355 .065 .327 r
.5295 .38226 m .52941 .38212 L .52986 .38082 L F
.498 .268 .496 r
.53007 .38022 m .52941 .38212 L .52706 .38259 L F
.501 .276 .505 r
.52706 .38259 m .52954 .38232 L .52893 .38137 L F
.498 .268 .496 r
.52941 .38212 m .52931 .38242 L .52706 .38259 L F
.501 .276 .505 r
.52893 .38137 m .52948 .38211 L .53035 .38046 L F
.355 .065 .327 r
.5295 .38226 m .53288 .38206 L .52931 .38242 L F
.53314 .3792 m .53311 .37951 L .5295 .38226 L F
.501 .276 .505 r
.52956 .38221 m .52964 .38231 L .52972 .38209 L F
.355 .065 .327 r
.53311 .37951 m .53288 .38206 L .5295 .38226 L F
.53145 .38004 m .5295 .38226 L .52986 .38082 L F
.65 .935 .671 r
.5298 .38216 m .53288 .37921 L .53161 .37984 L F
.355 .065 .327 r
.5326 .37947 m .53014 .38172 L .53145 .38004 L F
.53106 .38095 m .53014 .38172 L .5326 .37947 L F
.53014 .38172 m .5295 .38226 L .53145 .38004 L F
.65 .935 .671 r
.5298 .38216 m .53161 .37984 L .53035 .38046 L F
.355 .065 .327 r
.53306 .37923 m .52986 .38082 L .53215 .37953 L F
.53314 .3792 m .53309 .37923 L .53306 .37923 L F
.53309 .37923 m .52986 .38082 L .53306 .37923 L F
.65 .935 .671 r
.52964 .38231 m .53079 .3803 L .53286 .37922 L F
.5298 .38216 m .53286 .37922 L .53288 .37921 L F
.52964 .38231 m .53286 .37922 L .5298 .38216 L F
.355 .065 .327 r
.53314 .3792 m .53106 .38095 L .5326 .37947 L F
.372 .018 .227 r
.53314 .3792 m .53215 .37953 L .53316 .37911 L F
0 0 .179 r
.53453 .38008 m .53288 .38206 L .53308 .37986 L F
.53453 .38008 m .53308 .37986 L .53314 .3792 L F
.193 0 .191 r
.5345 .38115 m .53288 .38206 L .53453 .38008 L F
.53445 .38293 m .53369 .38251 L .5345 .38115 L F
.53369 .38251 m .53288 .38206 L .5345 .38115 L F
.217 0 0 r
.5329 .37922 m .53079 .3803 L .53453 .38008 L F
.53288 .37921 m .53286 .37922 L .5329 .37922 L F
.53286 .37922 m .53079 .3803 L .5329 .37922 L F
.627 .501 .689 r
.53281 .37916 m .5322 .3795 L .53288 .37921 L F
.5286 .3759 m .5322 .3795 L .53281 .37916 L F
.355 .065 .327 r
.53215 .37953 m .52986 .38082 L .53007 .38022 L F
.627 .501 .689 r
.53029 .38032 m .53273 .37929 L .53288 .37921 L F
.121 .312 .782 r
.53126 .37479 m .53288 .37921 L .53287 .37636 L F
.586 .202 .281 r
.5335 .3774 m .53614 .37938 L .53314 .3792 L F
0 0 .179 r
.53453 .38008 m .53314 .3792 L .53614 .37938 L F
.217 0 0 r
.53288 .37921 m .53453 .38008 L .53287 .37636 L F
.447 .258 .529 r
.53604 .3738 m .5335 .3774 L .53339 .37468 L F
0 .089 .646 r
.53189 .37345 m .53604 .3738 L .53339 .37468 L F
.53189 .37345 m .5335 .3774 L .53604 .3738 L F
.53195 .37358 m .53386 .37556 L .5335 .3774 L F
.53189 .37345 m .53386 .37556 L .53195 .37358 L F
0 .253 .764 r
.53386 .37556 m .53614 .37938 L .5335 .3774 L F
.567 .618 .863 r
.53878 .37842 m .53614 .37938 L .53386 .37556 L F
.554 .17 .268 r
.53287 .37636 m .53493 .37666 L .53386 .37556 L F
.567 .618 .863 r
.53878 .37842 m .53386 .37556 L .53729 .37699 L F
.554 .17 .268 r
.53493 .37666 m .53729 .37699 L .53386 .37556 L F
.314 .017 .29 r
.53453 .38008 m .53729 .37699 L .53287 .37636 L F
.747 .235 0 r
.54012 .38316 m .53614 .37938 L .53878 .37842 L F
.54012 .38316 m .53785 .38178 L .53614 .37938 L F
.314 .017 .29 r
.53453 .38008 m .53586 .38009 L .53729 .37699 L F
.602 .677 .893 r
.53328 .37879 m .5353 .37981 L .53079 .3803 L F
.77 .262 0 r
.53614 .37938 m .53785 .38178 L .53453 .38008 L F
.602 .677 .893 r
.5353 .37981 m .53586 .38009 L .53512 .38012 L F
.778 .4 .34 r
.53785 .38178 m .5358 .38247 L .53453 .38008 L F
.5358 .38247 m .53445 .38293 L .5345 .38115 L F
.5358 .38247 m .5345 .38115 L .53453 .38008 L F
.057 0 0 r
.53488 .38013 m .53586 .38009 L .53453 .38008 L F
.602 .677 .893 r
.5353 .37981 m .53512 .38012 L .53354 .38019 L F
.057 0 0 r
.53079 .3803 m .53488 .38013 L .53453 .38008 L F
.602 .677 .893 r
.53338 .38002 m .53354 .38019 L .53079 .3803 L F
.5353 .37981 m .53354 .38019 L .53338 .38002 L F
.65 .935 .671 r
.52964 .38231 m .5298 .38216 L .53035 .38046 L F
.501 .276 .505 r
.52948 .38211 m .52956 .38221 L .52973 .38206 L F
.52956 .38221 m .52972 .38209 L .52973 .38206 L F
.52948 .38211 m .52973 .38206 L .53035 .38046 L F
.52954 .38232 m .52964 .38231 L .52893 .38137 L F
.355 .065 .327 r
.5295 .38226 m .52931 .38242 L .52941 .38212 L F
.627 .501 .689 r
.5286 .3759 m .53029 .38032 L .5322 .3795 L F
.53029 .38032 m .53035 .38046 L .53273 .37929 L F
.498 .268 .496 r
.53007 .38022 m .52706 .38259 L .52794 .38163 L F
.693 .534 .668 r
.52631 .3801 m .5301 .38044 L .5286 .3759 L F
.5301 .38044 m .53035 .38046 L .53029 .38032 L F
.5301 .38044 m .53029 .38032 L .5286 .3759 L F
.627 .501 .689 r
.5286 .3759 m .53241 .37885 L .53126 .37479 L F
.53241 .37885 m .53288 .37921 L .53271 .37876 L F
.53241 .37885 m .53271 .37876 L .53126 .37479 L F
.904 .925 .82 r
.4629 .4483 m .46438 .44977 L .46705 .44594 L F
.541 .369 .597 r
.46438 .44977 m .4692 .45148 L .46705 .44594 L F
.565 .369 .574 r
.46451 .45267 m .4692 .45148 L .46438 .44977 L F
.194 .721 .73 r
.59742 .40179 m .60037 .40126 L .60229 .40077 L F
0 .281 .784 r
.60177 .37124 m .60029 .37143 L .60009 .36971 L F
.60177 .37124 m .60318 .37346 L .60029 .37143 L F
.255 0 .274 r
.51221 .39144 m .51423 .3931 L .51488 .39022 L F
.51221 .39144 m .51196 .39415 L .51423 .3931 L F
.748 .757 .86 r
.38355 .57153 m .38548 .57462 L .38788 .57204 L F
.89 .965 .834 r
.47446 .48554 m .47288 .48991 L .47602 .48642 L F
.8 .957 .916 r
.47819 .48264 m .47602 .48642 L .47891 .4836 L F
.47819 .48264 m .47446 .48554 L .47602 .48642 L F
.704 .629 .771 r
.30248 .65093 m .3051 .64766 L .30215 .64987 L F
.89 .965 .834 r
.47446 .48554 m .47162 .48905 L .47288 .48991 L F
.636 .285 .358 r
.40634 .49976 m .40356 .49783 L .40754 .49718 L F
.40634 .49976 m .40356 .49994 L .40356 .49783 L F
.845 .734 .741 r
.56241 .36941 m .5669 .37103 L .56287 .36659 L F
.803 .601 .63 r
.56241 .36941 m .56532 .37325 L .5669 .37103 L F
.263 .534 .918 r
.56287 .36659 m .5669 .37103 L .56642 .36957 L F
.986 .902 .606 r
.5669 .37103 m .56532 .37325 L .56642 .36957 L F
.882 .992 .783 r
.56532 .37325 m .56758 .37201 L .56642 .36957 L F
.56532 .37325 m .56528 .37441 L .56758 .37201 L F
.76 .314 0 r
.54419 .42235 m .54689 .42597 L .546 .4237 L F
.54689 .42597 m .54705 .42618 L .54691 .42585 L F
.54689 .42597 m .54691 .42585 L .546 .4237 L F
.849 .73 .732 r
.54947 .42097 m .54705 .42618 L .54419 .42235 L F
.532 .923 .884 r
.54838 .4267 m .54928 .42532 L .54632 .42626 L F
0 0 0 r
.5468 .42642 m .54928 .42532 L .54758 .42668 L F
.54632 .42626 m .54687 .42609 L .5468 .42642 L F
.54687 .42609 m .54928 .42532 L .5468 .42642 L F
.594 .57 .797 r
.52978 .42254 m .53214 .41766 L .52925 .41886 L F
.52978 .42254 m .53262 .42198 L .53214 .41766 L F
.495 .221 .427 r
.53222 .42417 m .53262 .42198 L .52978 .42254 L F
.66 .667 .846 r
.53262 .42198 m .53222 .42417 L .52978 .42254 L F
.495 .221 .427 r
.52978 .42254 m .53262 .42198 L .53222 .42417 L F
.693 .55 .687 r
.42955 .49509 m .4243 .49691 L .42466 .49407 L F
.42955 .49509 m .42887 .49743 L .4243 .49691 L F
.79 .862 .419 r
.34096 .50092 m .33944 .50425 L .33977 .50273 L F
.765 .559 .62 r
.34181 .50418 m .33944 .50425 L .34096 .50092 L F
.728 .848 .412 r
.34096 .50092 m .34166 .49894 L .34344 .50306 L F
.34096 .50092 m .33977 .50273 L .34166 .49894 L F
.296 .267 .656 r
.34344 .50306 m .34181 .50418 L .34096 .50092 L F
.821 .898 .896 r
.53785 .41602 m .54196 .41496 L .54075 .41684 L F
0 0 0 r
.54075 .41684 m .54196 .41496 L .54365 .41292 L F
.534 .326 .544 r
.45885 .43952 m .46183 .43897 L .46177 .43617 L F
.338 .176 .51 r
.46177 .43617 m .46408 .43792 L .46436 .43539 L F
.46177 .43617 m .46183 .43897 L .46408 .43792 L F
.115 0 .044 r
.43593 .46389 m .43753 .46457 L .43852 .46306 L F
.43593 .46389 m .43507 .46566 L .43753 .46457 L F
.214 .473 .886 r
.53585 .41558 m .53578 .41283 L .53377 .41423 L F
.613 .372 .529 r
.41084 .49679 m .40634 .49976 L .40754 .49718 L F
.516 .231 .421 r
.45582 .44543 m .45869 .44497 L .45611 .44299 L F
.463 .257 .513 r
.45611 .44299 m .45878 .44225 L .45885 .43952 L F
.46 .249 .505 r
.45611 .44299 m .45869 .44497 L .45878 .44225 L F
.799 .998 .792 r
.52798 .44396 m .52885 .44155 L .52524 .44394 L F
.52798 .44396 m .52973 .44175 L .52885 .44155 L F
.753 .803 .893 r
.54099 .42848 m .54491 .42825 L .5434 .42669 L F
.602 .934 .956 r
.54491 .42825 m .54632 .42626 L .5434 .42669 L F
.54491 .42825 m .54838 .4267 L .54632 .42626 L F
.322 .768 .961 r
.60741 .37331 m .6101 .37301 L .61135 .37374 L F
.822 .619 .629 r
.56086 .35693 m .56505 .36027 L .56543 .36001 L F
.571 .57 .813 r
.56384 .35387 m .56543 .36001 L .56784 .35725 L F
.396 .236 .543 r
.46567 .47851 m .46352 .47702 L .46666 .47637 L F
.46567 .47851 m .4638 .48043 L .46352 .47702 L F
.358 0 .166 r
.40355 .48323 m .40616 .48271 L .40742 .48018 L F
.519 .188 .347 r
.40616 .48271 m .41018 .47959 L .40742 .48018 L F
.753 .77 .867 r
.64399 .37517 m .64529 .36997 L .64325 .37333 L F
.64399 .37517 m .64579 .37268 L .64529 .36997 L F
.413 0 0 r
.37985 .4878 m .3822 .48879 L .384 .48755 L F
.314 0 0 r
.384 .48755 m .38672 .48824 L .38667 .48731 L F
.384 .48755 m .3822 .48879 L .38672 .48824 L F
.719 .458 .53 r
.46705 .44594 m .4692 .45148 L .47259 .44701 L F
.133 0 .042 r
.4692 .45148 m .47032 .45143 L .47259 .44701 L F
.055 0 .021 r
.47259 .44701 m .47332 .44833 L .47415 .44587 L F
.76 .846 .396 r
.47259 .44701 m .47032 .45143 L .47165 .44774 L F
.47259 .44701 m .47165 .44774 L .47332 .44833 L F
.904 .925 .82 r
.4629 .4483 m .46705 .44594 L .46558 .44608 L F
.075 .11 .594 r
.46805 .44036 m .46898 .44502 L .46705 .44594 L F
.32 0 .09 r
.46898 .44502 m .46558 .44608 L .46705 .44594 L F
.667 .523 .678 r
.43155 .49395 m .42887 .49743 L .42955 .49509 L F
.738 .232 0 r
.55276 .37198 m .55466 .37418 L .55262 .3727 L F
0 0 0 r
.55276 .37198 m .55262 .3727 L .55393 .37058 L F
.491 .259 .489 r
.45878 .44225 m .46183 .43897 L .45885 .43952 L F
.556 .362 .573 r
.30931 .6334 m .312 .63279 L .31204 .63019 L F
.635 .439 .601 r
.312 .63279 m .3157 .62918 L .31204 .63019 L F
0 0 0 r
.56652 .39799 m .56979 .39501 L .56794 .39603 L F
.661 .958 .941 r
.57115 .39289 m .56979 .39501 L .57212 .39338 L F
.684 .953 .696 r
.57115 .39289 m .56794 .39603 L .56979 .39501 L F
.492 .89 .738 r
.48368 .42716 m .48741 .42518 L .48587 .42676 L F
.261 0 .26 r
.48986 .42399 m .48741 .42518 L .49046 .42224 L F
.005 0 0 r
.48986 .42399 m .48587 .42676 L .48741 .42518 L F
.735 .503 .577 r
.41296 .49387 m .41281 .497 L .41084 .49679 L F
.725 .524 .618 r
.41296 .49387 m .4173 .49721 L .41281 .497 L F
.509 .328 .571 r
.51779 .40522 m .51406 .40701 L .51316 .40371 L F
.313 .793 .908 r
.51406 .40701 m .51536 .40618 L .51469 .4066 L F
0 .254 .75 r
.51406 .40701 m .51354 .40735 L .50893 .40314 L F
.51406 .40701 m .51448 .40821 L .51354 .40735 L F
.769 .992 .883 r
.50966 .40909 m .51448 .40821 L .51406 .40701 L F
.50966 .40909 m .51406 .40701 L .51232 .40806 L F
.313 .793 .908 r
.51406 .40701 m .51469 .4066 L .51232 .40806 L F
0 0 0 r
.56522 .39107 m .56761 .39004 L .56859 .38833 L F
.973 .753 .326 r
.56859 .38833 m .56761 .39004 L .56773 .38624 L F
.598 .48 .69 r
.31037 .63782 m .312 .63279 L .30931 .6334 L F
.854 .96 .875 r
.50737 .45795 m .51186 .45572 L .51049 .45501 L F
.778 .868 .915 r
.51186 .45572 m .51342 .45168 L .51049 .45501 L F
.51186 .45572 m .51526 .4533 L .51342 .45168 L F
0 0 0 r
.49694 .40711 m .49793 .40625 L .49427 .40829 L F
.49919 .40572 m .49793 .40625 L .49694 .40711 L F
.49919 .40572 m .50045 .40508 L .49793 .40625 L F
.453 .316 .604 r
.49793 .40625 m .50045 .40508 L .50007 .40155 L F
.579 .165 .221 r
.36431 .49524 m .36088 .49463 L .36354 .49275 L F
.36431 .49524 m .3604 .49615 L .36088 .49463 L F
.88 .986 .715 r
.55267 .40093 m .55117 .40313 L .55191 .40031 L F
.909 .969 .661 r
.55267 .40093 m .55401 .39646 L .55546 .39782 L F
.55267 .40093 m .55191 .40031 L .55401 .39646 L F
.752 .426 .432 r
.63055 .35206 m .63507 .35307 L .63501 .35049 L F
.748 .423 .432 r
.63507 .35307 m .63733 .35349 L .63501 .35049 L F
.578 .876 .994 r
.50196 .45104 m .50318 .45204 L .50082 .453 L F
.676 .973 .905 r
.50196 .45104 m .50082 .453 L .49975 .45264 L F
0 0 .305 r
.59022 .37096 m .591 .3727 L .59075 .37011 L F
.822 .619 .629 r
.56086 .35693 m .56458 .36089 L .56505 .36027 L F
.671 .408 .515 r
.56458 .36089 m .56323 .36354 L .56505 .36027 L F
0 0 .018 r
.56078 .40527 m .5638 .40122 L .56243 .4028 L F
.759 .923 .943 r
.4925 .46871 m .49742 .46764 L .49544 .46692 L F
.741 .951 .946 r
.49827 .46506 m .49742 .46764 L .49924 .46594 L F
.49827 .46506 m .49544 .46692 L .49742 .46764 L F
.795 .926 .923 r
.40015 .54508 m .39548 .54666 L .39893 .54449 L F
.838 .989 .861 r
.40015 .54508 m .40079 .54235 L .40363 .54249 L F
.40015 .54508 m .39893 .54449 L .40079 .54235 L F
.733 .361 .347 r
.3676 .49442 m .36704 .49632 L .36475 .49375 L F
.814 .79 .829 r
.35823 .56946 m .3628 .56899 L .361 .56802 L F
.215 .577 .942 r
.3628 .56899 m .36367 .56762 L .361 .56802 L F
.3628 .56899 m .36551 .56954 L .36367 .56762 L F
.727 .614 .731 r
.36185 .56252 m .35831 .56602 L .35746 .56201 L F
.319 .198 .554 r
.60421 .34859 m .60096 .34717 L .60187 .34635 L F
.60421 .34859 m .60219 .35015 L .60096 .34717 L F
.512 .706 .959 r
.55726 .37554 m .55791 .378 L .55946 .37539 L F
0 0 0 r
.55802 .37795 m .55946 .37539 L .55791 .378 L F
.805 .67 .714 r
.32304 .63338 m .32588 .62987 L .32357 .6307 L F
.677 .522 .667 r
.49285 .42118 m .48986 .42399 L .49046 .42224 L F
.686 .706 .862 r
.35975 .55917 m .36185 .56252 L .35746 .56201 L F
.78 .739 .815 r
.36456 .55989 m .36185 .56252 L .35975 .55917 L F
.743 .667 .777 r
.3121 .64742 m .31677 .64875 L .31467 .64656 L F
.687 .715 .87 r
.31467 .64656 m .31677 .64875 L .31907 .64727 L F
.828 .603 .599 r
.55117 .40313 m .54802 .40364 L .55191 .40031 L F
.55117 .40313 m .55111 .40496 L .54802 .40364 L F
.538 .716 .955 r
.35407 .56802 m .35588 .57036 L .35823 .56946 L F
.55 .216 .355 r
.41018 .47959 m .41312 .47944 L .41356 .4773 L F
.436 .115 .322 r
.41312 .47944 m .41685 .47572 L .41356 .4773 L F
.771 .853 .912 r
.543 .42343 m .54099 .42577 L .53955 .42164 L F
.753 .803 .893 r
.54099 .42848 m .5434 .42669 L .54099 .42577 L F
0 0 .182 r
.54131 .42807 m .54099 .42577 L .5434 .42669 L F
.54131 .42807 m .54099 .42848 L .54099 .42577 L F
.632 .373 .509 r
.36475 .49375 m .36431 .49524 L .36354 .49275 L F
.631 .915 .98 r
.61364 .39455 m .61624 .3957 L .61878 .39435 L F
.834 .921 .892 r
.40831 .55746 m .40724 .56083 L .41294 .55565 L F
.933 .902 .771 r
.40443 .53716 m .40615 .5388 L .40506 .54007 L F
.696 .883 .967 r
.40807 .5372 m .40615 .5388 L .40443 .53716 L F
.93 .922 .782 r
.6266 .3642 m .62309 .36603 L .62522 .36261 L F
.6266 .3642 m .62425 .36712 L .62309 .36603 L F
.918 .874 .778 r
.62522 .36261 m .62309 .36603 L .62146 .36465 L F
0 .213 .738 r
.62309 .36603 m .625 .36654 L .62179 .36483 L F
.62309 .36603 m .62179 .36483 L .62146 .36465 L F
.93 .922 .782 r
.62425 .36712 m .62409 .36732 L .62309 .36603 L F
.815 .915 .906 r
.62971 .36107 m .6266 .3642 L .62522 .36261 L F
.991 .866 .61 r
.57823 .38247 m .58045 .38122 L .57961 .37998 L F
.57823 .38247 m .57936 .38491 L .58045 .38122 L F
.356 .81 .687 r
.36298 .49027 m .36125 .49098 L .36116 .49121 L F
.463 .886 .906 r
.36298 .49027 m .36357 .48946 L .36587 .48885 L F
.354 0 .134 r
.36116 .49121 m .36357 .48946 L .36298 .49027 L F
.653 .958 .936 r
.55872 .39471 m .56005 .39265 L .56101 .39313 L F
.532 .817 .998 r
.55724 .39337 m .56005 .39265 L .55872 .39471 L F
.5 .891 .954 r
.56101 .39313 m .56005 .39265 L .56268 .39163 L F
.036 0 0 r
.56169 .39248 m .55868 .39386 L .56252 .39238 L F
.56005 .39265 m .55871 .39384 L .56169 .39248 L F
.55871 .39384 m .55868 .39386 L .56169 .39248 L F
.42 .849 .714 r
.56101 .39313 m .56376 .39152 L .56522 .39107 L F
.56376 .39152 m .56493 .39084 L .56505 .39094 L F
.56376 .39152 m .56505 .39094 L .56522 .39107 L F
.313 .798 .75 r
.56522 .39107 m .56493 .39084 L .56761 .39004 L F
.772 .677 .759 r
.4208 .51073 m .42236 .51473 L .41821 .51374 L F
.527 .399 .649 r
.37042 .54564 m .374 .53977 L .37069 .54135 L F
.448 .175 .406 r
.44745 .45283 m .44938 .45451 L .45003 .45224 L F
.44745 .45283 m .44731 .45509 L .44938 .45451 L F
.54 .308 .512 r
.55132 .35813 m .55401 .35978 L .55401 .35716 L F
.642 .742 .922 r
.53533 .42061 m .53955 .42164 L .53681 .42279 L F
.281 0 .095 r
.42945 .46895 m .43164 .46891 L .43268 .46668 L F
.287 0 .175 r
.43164 .46891 m .43507 .46566 L .43268 .46668 L F
.225 0 .257 r
.48859 .41488 m .49117 .41449 L .49143 .41175 L F
.19 0 .172 r
.48859 .41488 m .49041 .41642 L .49117 .41449 L F
.48859 .41488 m .48801 .41755 L .49041 .41642 L F
.456 .18 .405 r
.51366 .39966 m .51316 .40371 L .50893 .40314 L F
0 .254 .75 r
.51406 .40701 m .50893 .40314 L .51316 .40371 L F
.209 0 .281 r
.49143 .41175 m .49324 .4104 L .49427 .40829 L F
.199 0 .25 r
.49143 .41175 m .49334 .41335 L .49324 .4104 L F
.49143 .41175 m .49117 .41449 L .49334 .41335 L F
.571 .57 .813 r
.56384 .35387 m .56812 .35389 L .56649 .3527 L F
.56384 .35387 m .56784 .35725 L .56812 .35389 L F
.148 0 .231 r
.47735 .44289 m .47674 .44506 L .47945 .44156 L F
.739 .628 .736 r
.32031 .63684 m .3248 .63749 L .32304 .63338 L F
.79 .689 .753 r
.32039 .64003 m .3248 .63749 L .32031 .63684 L F
.632 .373 .509 r
.36475 .49375 m .36704 .49632 L .36431 .49524 L F
.937 .718 .58 r
.63742 .3551 m .63965 .35422 L .63733 .35349 L F
.63742 .3551 m .63934 .35707 L .63965 .35422 L F
.915 .969 .791 r
.61819 .3567 m .62101 .35412 L .62107 .35663 L F
.61819 .3567 m .61961 .35241 L .62101 .35412 L F
.881 .906 .842 r
.62376 .35048 m .62101 .35412 L .61961 .35241 L F
.372 .166 .466 r
.62391 .3553 m .62107 .35663 L .62101 .35412 L F
0 0 0 r
.54703 .36259 m .55174 .36155 L .54979 .36324 L F
.74 .275 0 r
.54979 .36324 m .54979 .3645 L .54703 .36259 L F
.54979 .36324 m .55127 .36595 L .54979 .3645 L F
.543 .828 .998 r
.36095 .54815 m .36558 .54882 L .36353 .54726 L F
.36095 .54815 m .36558 .54882 L .36353 .54726 L F
.961 .867 .699 r
.60248 .38414 m .60348 .38737 L .60408 .38531 L F
.777 .626 .693 r
.56086 .35693 m .55864 .36034 L .56458 .36089 L F
.741 .491 .552 r
.55821 .36317 m .56458 .36089 L .55864 .36034 L F
.55821 .36317 m .56323 .36354 L .56458 .36089 L F
.807 .89 .903 r
.38544 .55662 m .38293 .5559 L .38557 .55371 L F
.886 .772 .731 r
.64529 .36997 m .64932 .3679 L .64756 .36631 L F
.64529 .36997 m .64827 .36995 L .64932 .3679 L F
.78 .739 .815 r
.36456 .55989 m .35975 .55917 L .36223 .558 L F
.678 .828 .956 r
.36674 .55829 m .36456 .55989 L .36223 .558 L F
.15 0 .001 r
.48256 .41939 m .48472 .41961 L .48545 .41872 L F
.48256 .41939 m .48181 .42084 L .48472 .41961 L F
.786 .806 .868 r
.59912 .38712 m .60348 .38737 L .60248 .38414 L F
.516 0 0 r
.60228 .38874 m .60348 .38737 L .59912 .38712 L F
.657 .118 0 r
.60618 .38984 m .60348 .38737 L .60228 .38874 L F
.562 .201 .314 r
.60618 .38984 m .60627 .38806 L .60348 .38737 L F
.39 .405 .756 r
.52287 .42934 m .52631 .43071 L .52695 .42863 L F
.52287 .42934 m .52443 .43217 L .52631 .43071 L F
.33 .795 .934 r
.51319 .44463 m .51274 .4453 L .51181 .44481 L F
.866 .991 .825 r
.48067 .47973 m .47891 .4836 L .48182 .48035 L F
.48067 .47973 m .47819 .48264 L .47891 .4836 L F
.842 .707 .715 r
.41387 .52781 m .41415 .53042 L .4093 .53007 L F
.844 .663 .657 r
.41415 .53042 m .41132 .53442 L .4093 .53007 L F
.498 .03 .073 r
.42252 .55098 m .42084 .55331 L .41831 .55203 L F
.481 .877 .961 r
.4233 .55058 m .4231 .54972 L .42252 .55098 L F
.664 .848 .442 r
.42252 .55098 m .4231 .54972 L .42084 .55331 L F
.837 .76 .778 r
.44002 .52329 m .44459 .52117 L .4428 .51977 L F
.44002 .52329 m .44204 .52508 L .44459 .52117 L F
.866 .872 .84 r
.4428 .51977 m .44459 .52117 L .44746 .51775 L F
.686 .706 .862 r
.35975 .55917 m .35746 .56201 L .35807 .55867 L F
.571 .806 .988 r
.62283 .39404 m .623 .39195 L .62128 .39265 L F
.62283 .39404 m .62482 .39353 L .623 .39195 L F
.091 0 .065 r
.49324 .4104 m .49694 .40711 L .49427 .40829 L F
.745 .742 .85 r
.53888 .36761 m .53628 .36768 L .53525 .36665 L F
.149 .646 .913 r
.54058 .36832 m .53628 .36768 L .53888 .36761 L F
.761 .775 .864 r
.37102 .55866 m .36674 .55829 L .36916 .55536 L F
.757 .773 .866 r
.37359 .55635 m .37102 .55866 L .36916 .55536 L F
.423 .132 .364 r
.41685 .47572 m .41971 .47517 L .41993 .47316 L F
.51 .179 .342 r
.41971 .47517 m .42285 .47297 L .41993 .47316 L F
0 .171 .702 r
.61383 .38144 m .61441 .37928 L .61129 .38012 L F
0 0 0 r
.61432 .38431 m .61732 .38312 L .61753 .38299 L F
.61678 .38319 m .61753 .38299 L .61866 .38233 L F
.579 .627 .864 r
.61441 .37928 m .61597 .38364 L .61866 .38233 L F
0 0 0 r
.61432 .38431 m .61866 .38233 L .61597 .38364 L F
.61432 .38431 m .61753 .38299 L .61678 .38319 L F
0 .171 .702 r
.61383 .38144 m .61578 .38345 L .61441 .37928 L F
.61578 .38345 m .61597 .38364 L .61589 .38342 L F
.61578 .38345 m .61589 .38342 L .61441 .37928 L F
.774 .307 .135 r
.49213 .4377 m .49419 .43733 L .48979 .43549 L F
.489 0 0 r
.49551 .43796 m .49419 .43733 L .49213 .4377 L F
.817 .927 .907 r
.40285 .56283 m .40705 .56097 L .40646 .56171 L F
0 0 .398 r
.40831 .55746 m .40816 .56117 L .40705 .56097 L F
.052 0 0 r
.40816 .56117 m .40646 .56171 L .40705 .56097 L F
0 0 0 r
.51676 .39798 m .51532 .39928 L .51366 .39966 L F
.591 .52 .743 r
.51532 .39928 m .51316 .40371 L .51366 .39966 L F
.623 .466 .649 r
.33944 .50425 m .34151 .5065 L .34181 .50418 L F
0 0 .241 r
.34344 .50306 m .34151 .5065 L .34181 .50418 L F
.775 .571 .623 r
.59167 .35299 m .59611 .35466 L .596 .34992 L F
.023 0 .402 r
.59611 .35466 m .59813 .34894 L .596 .34992 L F
.747 .994 .852 r
.62179 .37184 m .62284 .36935 L .62398 .37016 L F
.62179 .37184 m .61984 .37201 L .62284 .36935 L F
.503 .209 .401 r
.42285 .47297 m .42574 .47252 L .4261 .47016 L F
.422 .107 .323 r
.42574 .47252 m .42945 .46895 L .4261 .47016 L F
.505 .734 .976 r
.38098 .57205 m .38191 .5698 L .3793 .57039 L F
.38098 .57205 m .38355 .57153 L .38191 .5698 L F
0 0 .038 r
.58873 .36366 m .58882 .36186 L .58877 .3591 L F
0 0 .266 r
.58873 .36366 m .58928 .36444 L .58882 .36186 L F
.58873 .36366 m .58962 .3665 L .58928 .36444 L F
.846 .761 .768 r
.43734 .52678 m .44204 .52508 L .44002 .52329 L F
.43734 .52678 m .43976 .5284 L .44204 .52508 L F
.234 0 .246 r
.60433 .36541 m .60221 .36462 L .60485 .36361 L F
.60433 .36541 m .60174 .36665 L .60221 .36462 L F
.914 .87 .78 r
.44851 .51304 m .4526 .51063 L .45102 .50941 L F
.44851 .51304 m .45027 .51446 L .4526 .51063 L F
.833 .92 .893 r
.45102 .50941 m .4526 .51063 L .45575 .50761 L F
.545 .281 .466 r
.50007 .40155 m .50275 .40374 L .50296 .40131 L F
.431 .3 .601 r
.50007 .40155 m .50045 .40508 L .50275 .40374 L F
.545 .281 .466 r
.50007 .40155 m .50275 .40374 L .50296 .40131 L F
.907 .903 .808 r
.40506 .54007 m .40363 .54249 L .40079 .54235 L F
.635 .439 .601 r
.312 .63279 m .31571 .63413 L .3157 .62918 L F
.697 .584 .726 r
.3157 .62918 m .31885 .63001 L .31956 .62708 L F
.728 .518 .608 r
.31571 .63413 m .31885 .63001 L .3157 .62918 L F
0 0 .087 r
.52241 .43605 m .52165 .4385 L .52379 .43438 L F
.496 .04 .099 r
.38667 .48731 m .38921 .48873 L .39104 .48658 L F
.123 0 0 r
.38921 .48873 m .39377 .48679 L .39104 .48658 L F
.598 .48 .69 r
.31037 .63782 m .31339 .63682 L .312 .63279 L F
.556 .373 .589 r
.31024 .64028 m .31339 .63682 L .31037 .63782 L F
.709 .657 .796 r
.30509 .64997 m .30936 .65065 L .30773 .64674 L F
.74 .672 .784 r
.30936 .65065 m .3121 .64742 L .30773 .64674 L F
.339 0 0 r
.39636 .48594 m .39903 .4856 L .40069 .48356 L F
.362 0 .009 r
.40069 .48356 m .40315 .48439 L .40355 .48323 L F
.40069 .48356 m .39903 .4856 L .40315 .48439 L F
.739 .463 .512 r
.4173 .49721 m .4131 .49917 L .41281 .497 L F
.4173 .49721 m .41738 .49974 L .4131 .49917 L F
.768 .389 .339 r
.39705 .49925 m .39234 .49676 L .39699 .49696 L F
.472 .885 .932 r
.61819 .3567 m .61685 .35642 L .61419 .3574 L F
.61819 .3567 m .61685 .35642 L .61419 .3574 L F
.915 .969 .791 r
.61819 .3567 m .61685 .35642 L .61961 .35241 L F
.15 .684 .85 r
.62107 .35663 m .61685 .35642 L .61819 .3567 L F
0 0 0 r
.60543 .38037 m .60801 .37962 L .60976 .37969 L F
.866 .872 .84 r
.4428 .51977 m .44746 .51775 L .44682 .51633 L F
.877 .971 .845 r
.44682 .51633 m .44746 .51775 L .45027 .51446 L F
.03 .186 .693 r
.48361 .43116 m .4836 .43276 L .48087 .42825 L F
.923 .937 .795 r
.48516 .43217 m .48322 .43571 L .48259 .43285 L F
.818 .998 .842 r
.48423 .43317 m .48587 .43243 L .48522 .43257 L F
0 .155 .697 r
.48294 .43445 m .48352 .43388 L .48259 .43285 L F
.48322 .43571 m .48386 .43425 L .48352 .43388 L F
.48322 .43571 m .48352 .43388 L .48294 .43445 L F
0 0 0 r
.48171 .4347 m .48259 .43285 L .4827 .43298 L F
.48171 .4347 m .4827 .43298 L .48386 .43425 L F
.818 .998 .842 r
.48171 .4347 m .48386 .43425 L .48587 .43243 L F
0 0 0 r
.48343 .43391 m .4809 .4361 L .48171 .4347 L F
.4809 .4361 m .48044 .43649 L .48171 .4347 L F
.818 .998 .842 r
.48171 .4347 m .48388 .43352 L .48423 .43317 L F
.48388 .43352 m .48587 .43243 L .48423 .43317 L F
0 .155 .697 r
.48322 .43571 m .48547 .43749 L .48386 .43425 L F
.162 .203 .657 r
.60692 .3403 m .60966 .34175 L .61104 .34002 L F
.60692 .3403 m .60788 .34427 L .60966 .34175 L F
0 0 0 r
.47415 .44587 m .47526 .44674 L .47674 .44506 L F
.47415 .44587 m .47332 .44833 L .47526 .44674 L F
.623 .934 .7 r
.48255 .44393 m .48062 .44622 L .48421 .44304 L F
.881 .956 .612 r
.48255 .44393 m .48093 .44823 L .48062 .44622 L F
.81 .739 .786 r
.4345 .53021 m .43853 .53021 L .43734 .52678 L F
.4345 .53021 m .43691 .53177 L .43853 .53021 L F
.816 .772 .812 r
.43734 .52678 m .43853 .53021 L .43976 .5284 L F
.03 .186 .693 r
.48361 .43116 m .48087 .42825 L .48368 .42716 L F
.609 .792 .969 r
.36795 .56847 m .36977 .57072 L .37222 .56918 L F
.728 .518 .608 r
.31571 .63413 m .31858 .63297 L .31885 .63001 L F
.739 .628 .735 r
.31885 .63001 m .32156 .62666 L .31956 .62708 L F
.691 .555 .696 r
.31885 .63001 m .32357 .6307 L .32156 .62666 L F
.747 .611 .708 r
.31858 .63297 m .32357 .6307 L .31885 .63001 L F
.318 .734 .976 r
.41091 .56521 m .41132 .56597 L .40992 .56431 L F
.411 0 0 r
.41132 .56597 m .41413 .567 L .4122 .56721 L F
.405 0 0 r
.41607 .5668 m .41413 .567 L .41132 .56597 L F
.428 .871 .87 r
.41413 .567 m .41521 .56602 L .41227 .56719 L F
.41413 .567 m .41227 .56719 L .4122 .56721 L F
.405 0 0 r
.41683 .56693 m .41413 .567 L .41607 .5668 L F
.878 .672 .619 r
.63934 .35707 m .63929 .36075 L .64121 .3604 L F
.376 0 0 r
.63929 .36075 m .63981 .36141 L .64121 .3604 L F
.411 0 0 r
.64121 .3604 m .63985 .36133 L .63989 .36135 L F
.64121 .3604 m .63989 .36135 L .6436 .36348 L F
.867 .47 .282 r
.63989 .36135 m .64198 .36483 L .6436 .36348 L F
.63985 .36133 m .63987 .36136 L .63989 .36135 L F
.63987 .36136 m .64198 .36483 L .63989 .36135 L F
.376 0 0 r
.63981 .36141 m .64012 .3618 L .64076 .36098 L F
.63989 .36135 m .64076 .36098 L .64121 .3604 L F
.63981 .36141 m .64076 .36098 L .63989 .36135 L F
.411 0 0 r
.64121 .3604 m .64012 .3618 L .63985 .36133 L F
.444 .138 .349 r
.41589 .47892 m .41971 .47517 L .41685 .47572 L F
.436 .115 .322 r
.41312 .47944 m .41589 .47892 L .41685 .47572 L F
.994 .801 .538 r
.55454 .39406 m .55546 .39782 L .55401 .39646 L F
.763 .708 .8 r
.55872 .39471 m .55546 .39782 L .55454 .39406 L F
.811 .422 .316 r
.63185 .35893 m .62764 .35721 L .63204 .35728 L F
.173 0 0 r
.37497 .54488 m .37355 .54698 L .37082 .54776 L F
0 0 0 r
.37569 .54593 m .37355 .54698 L .37497 .54488 L F
0 0 .018 r
.58924 .38799 m .59058 .38575 L .59117 .38322 L F
0 0 .079 r
.58924 .38799 m .59003 .38823 L .59058 .38575 L F
.58924 .38799 m .58883 .39104 L .59003 .38823 L F
.124 .638 .892 r
.3975 .57017 m .40347 .57198 L .4029 .5715 L F
.265 0 .228 r
.47613 .42486 m .47813 .42679 L .4785 .42337 L F
.47613 .42486 m .47575 .42772 L .47813 .42679 L F
.704 .629 .771 r
.30248 .65093 m .30509 .64997 L .3051 .64766 L F
.83 .944 .898 r
.51809 .44976 m .51342 .45168 L .51526 .4533 L F
.825 1 .811 r
.48255 .47786 m .48182 .48035 L .48487 .47703 L F
.791 .985 .896 r
.48255 .47786 m .48067 .47973 L .48182 .48035 L F
.527 .399 .649 r
.37042 .54564 m .37516 .54495 L .374 .53977 L F
0 0 .292 r
.37042 .54564 m .37182 .54464 L .37516 .54495 L F
.37042 .54564 m .37082 .54776 L .37182 .54464 L F
.85 .615 .583 r
.55111 .40496 m .54645 .4066 L .54624 .40445 L F
.55111 .40496 m .55102 .40831 L .54645 .4066 L F
.387 .232 .546 r
.55111 .40496 m .55102 .40831 L .55323 .40705 L F
.765 .633 .071 r
.55111 .40496 m .55102 .40831 L .55323 .40705 L F
.91 .969 .662 r
.55401 .39646 m .55117 .39813 L .55122 .3955 L F
0 0 .12 r
.55122 .3955 m .55119 .39674 L .55175 .3962 L F
.55119 .39674 m .55117 .39813 L .55175 .3962 L F
.332 0 0 r
.55401 .39646 m .55122 .3955 L .55219 .39562 L F
.994 .801 .538 r
.55454 .39406 m .55401 .39646 L .55219 .39562 L F
.343 .779 .967 r
.55175 .3962 m .55421 .39584 L .55239 .39559 L F
0 0 .12 r
.55122 .3955 m .55175 .3962 L .55126 .39563 L F
.289 0 0 r
.55115 .39527 m .55122 .3955 L .54755 .39407 L F
.173 0 0 r
.54601 .39275 m .54973 .39225 L .54755 .39407 L F
0 .205 .7 r
.54833 .39289 m .55122 .3955 L .54996 .39413 L F
0 0 .12 r
.55122 .3955 m .55126 .39563 L .54996 .39413 L F
.289 0 0 r
.55219 .39562 m .55122 .3955 L .55115 .39527 L F
.015 .18 .692 r
.54996 .39413 m .55175 .3962 L .55105 .39307 L F
.349 .654 .969 r
.54973 .39225 m .55505 .39299 L .55454 .39406 L F
.724 .953 .662 r
.54973 .39225 m .5508 .38984 L .55505 .39299 L F
.343 .779 .967 r
.55175 .3962 m .55283 .39175 L .55105 .39307 L F
.027 .386 .847 r
.54755 .39407 m .55122 .3955 L .54833 .39289 L F
.343 .779 .967 r
.55175 .3962 m .55023 .3953 L .55283 .39175 L F
.55175 .3962 m .55239 .39559 L .55023 .3953 L F
.881 .906 .842 r
.62376 .35048 m .62259 .35103 L .6231 .35139 L F
0 .049 .553 r
.62382 .35189 m .6231 .35139 L .6216 .34992 L F
.672 .214 .156 r
.6231 .35139 m .62549 .35361 L .62726 .35193 L F
0 .049 .553 r
.62405 .3521 m .6231 .35139 L .62382 .35189 L F
.881 .906 .842 r
.62259 .35103 m .61961 .35241 L .6231 .35139 L F
.444 0 0 r
.6231 .35139 m .62726 .35193 L .62376 .35048 L F
.762 .872 .928 r
.399 .57398 m .3975 .57017 L .3972 .57319 L F
.613 .657 .87 r
.37796 .55861 m .37359 .55635 L .37622 .55598 L F
.701 .7 .846 r
.38062 .5571 m .37796 .55861 L .37622 .55598 L F
.829 .731 .757 r
.4345 .53021 m .43549 .53416 L .43691 .53177 L F
.886 .967 .838 r
.48476 .47445 m .48487 .47703 L .48755 .47417 L F
.88 .969 .843 r
.48804 .47092 m .48755 .47417 L .48941 .4719 L F
.48804 .47092 m .48476 .47445 L .48755 .47417 L F
.933 .902 .771 r
.40443 .53716 m .40506 .54007 L .40334 .53939 L F
.907 .903 .808 r
.40506 .54007 m .40079 .54235 L .40334 .53939 L F
.489 .878 .966 r
.60112 .39759 m .60226 .39827 L .60486 .3973 L F
.727 .82 .922 r
.49378 .44503 m .49774 .44285 L .49411 .44174 L F
.808 .456 .391 r
.55726 .37554 m .55262 .3727 L .55466 .37418 L F
.867 .838 .815 r
.64529 .36997 m .64579 .37268 L .64827 .36995 L F
.5 .671 .941 r
.60788 .34427 m .61098 .3445 L .60966 .34175 L F
.842 .707 .715 r
.41387 .52781 m .4093 .53007 L .41186 .52634 L F
.792 .773 .835 r
.4148 .52292 m .41387 .52781 L .41186 .52634 L F
.4148 .52292 m .4169 .52463 L .41387 .52781 L F
.916 .933 .565 r
.50585 .41471 m .5059 .41523 L .50699 .4099 L F
0 0 .125 r
.52379 .43438 m .52631 .43071 L .52443 .43217 L F
.241 .755 .764 r
.60966 .34175 m .61436 .3408 L .61104 .34002 L F
0 .437 .779 r
.41683 .56693 m .41664 .56656 L .41413 .567 L F
.41683 .56693 m .41817 .56735 L .41664 .56656 L F
.895 .917 .522 r
.56532 .37325 m .56399 .37601 L .56528 .37441 L F
.698 .649 .798 r
.4785 .42337 m .48181 .42084 L .47957 .42215 L F
.98 .694 .395 r
.38618 .56819 m .38617 .57091 L .38788 .57204 L F
.748 .757 .86 r
.38355 .57153 m .38788 .57204 L .38617 .57091 L F
.573 .592 .834 r
.38788 .57204 m .38904 .56741 L .38618 .56819 L F
.38788 .57204 m .39071 .57136 L .38904 .56741 L F
.634 .661 .859 r
.38788 .57204 m .39201 .57319 L .39071 .57136 L F
.731 .749 .867 r
.39071 .57136 m .39201 .57319 L .39484 .57196 L F
.676 .193 .096 r
.3852 .4976 m .382 .4985 L .38086 .49676 L F
.3852 .4976 m .38504 .49916 L .382 .4985 L F
.448 0 .072 r
.3852 .4976 m .38792 .49894 L .38504 .49916 L F
.435 .023 .157 r
.3881 .49729 m .38792 .49894 L .3852 .4976 L F
.505 .211 .401 r
.50296 .40131 m .5062 .40084 L .50628 .39853 L F
.213 0 .345 r
.50628 .39853 m .50833 .39958 L .50913 .39766 L F
.50628 .39853 m .5062 .40084 L .50833 .39958 L F
.245 .526 .916 r
.34385 .56006 m .34572 .56283 L .34305 .56184 L F
.121 .37 .83 r
.34305 .56184 m .34603 .56343 L .34385 .56006 L F
.877 .971 .845 r
.44682 .51633 m .45027 .51446 L .44851 .51304 L F
.266 0 .232 r
.52 .39499 m .51957 .39705 L .51676 .39798 L F
.371 .382 .741 r
.52234 .39406 m .5234 .39742 L .52 .39499 L F
.652 .286 .339 r
.52 .39499 m .5234 .39742 L .51957 .39705 L F
.393 0 0 r
.38005 .48825 m .3822 .48879 L .37985 .4878 L F
.834 .921 .892 r
.40831 .55746 m .41294 .55565 L .41131 .55431 L F
0 0 0 r
.41562 .55359 m .41131 .55431 L .41294 .55565 L F
.467 .198 .422 r
.46725 .43231 m .47028 .43165 L .4702 .42952 L F
.34 .106 .406 r
.4702 .42952 m .47269 .43063 L .47318 .42833 L F
.4702 .42952 m .47028 .43165 L .47269 .43063 L F
.789 .709 .775 r
.43177 .53376 m .43549 .53416 L .4345 .53021 L F
.802 .649 .693 r
.43177 .53376 m .43377 .53812 L .43549 .53416 L F
.747 .611 .708 r
.31858 .63297 m .32304 .63338 L .32357 .6307 L F
.774 .647 .722 r
.31596 .63637 m .32031 .63684 L .31858 .63297 L F
.778 .617 .681 r
.3176 .64044 m .32031 .63684 L .31596 .63637 L F
.767 .601 .672 r
.3176 .64044 m .32039 .64003 L .32031 .63684 L F
.743 .634 .739 r
.32031 .63684 m .32304 .63338 L .31858 .63297 L F
.771 .648 .726 r
.5721 .36016 m .5695 .36369 L .57287 .36382 L F
.735 .597 .702 r
.56972 .36585 m .56766 .36761 L .56979 .36646 L F
.78 .653 .722 r
.56311 .36451 m .56985 .36542 L .56323 .36354 L F
.56859 .36562 m .56985 .36542 L .56311 .36451 L F
.56287 .36659 m .56985 .36542 L .56287 .36653 L F
.779 .651 .721 r
.56985 .36542 m .56859 .36562 L .5695 .36369 L F
.56985 .36542 m .56766 .36761 L .56859 .36562 L F
.78 .653 .722 r
.56862 .36562 m .56766 .36761 L .56985 .36542 L F
.56287 .36659 m .56766 .36761 L .56862 .36562 L F
.735 .597 .702 r
.5695 .36369 m .56859 .36562 L .56862 .36562 L F
.56951 .36378 m .56862 .36562 L .56972 .36585 L F
.5695 .36369 m .56862 .36562 L .56951 .36378 L F
.56859 .36562 m .56766 .36761 L .56972 .36585 L F
.78 .653 .722 r
.56287 .36653 m .56859 .36562 L .56311 .36451 L F
.634 .395 .539 r
.56979 .36646 m .57287 .36382 L .5695 .36369 L F
.56979 .36646 m .57343 .3671 L .57287 .36382 L F
.499 .304 .547 r
.57287 .36382 m .57621 .36608 L .57467 .36233 L F
.57287 .36382 m .57343 .3671 L .57621 .36608 L F
.677 .607 .77 r
.3051 .64766 m .30509 .64997 L .30773 .64674 L F
.511 .814 1 r
.55312 .36723 m .55389 .36539 L .55127 .36595 L F
.945 .96 .702 r
.46123 .49783 m .46129 .50071 L .46352 .49669 L F
.84 .999 .808 r
.46549 .49286 m .46352 .49669 L .46656 .49361 L F
.46549 .49286 m .46278 .49594 L .46352 .49669 L F
.895 .986 .732 r
.46278 .49594 m .46123 .49783 L .46352 .49669 L F
.23 .548 .93 r
.61248 .35685 m .61419 .3574 L .6127 .3553 L F
.6127 .3553 m .61419 .3574 L .61248 .35685 L F
.698 .649 .798 r
.4785 .42337 m .48141 .42598 L .48181 .42084 L F
0 0 0 r
.47813 .42679 m .48141 .42598 L .4785 .42337 L F
.47813 .42679 m .48109 .42619 L .48141 .42598 L F
.006 .03 .534 r
.48181 .42084 m .48141 .42598 L .48386 .42241 L F
.527 .341 .571 r
.48109 .42619 m .48386 .42241 L .48141 .42598 L F
.665 .57 .739 r
.31339 .63682 m .31571 .63413 L .312 .63279 L F
.974 .718 .485 r
.57795 .37306 m .57967 .37712 L .57968 .37437 L F
0 0 .077 r
.37616 .54322 m .37618 .54081 L .37597 .54023 L F
.94 .736 .601 r
.5793 .36275 m .58102 .36694 L .58175 .36429 L F
.17 0 .11 r
.53628 .36768 m .54137 .36598 L .53865 .36766 L F
.149 .646 .913 r
.54058 .36832 m .54019 .36788 L .53628 .36768 L F
.17 0 .11 r
.53628 .36768 m .53792 .3674 L .53883 .36683 L F
.565 .443 .673 r
.53762 .36759 m .53793 .36763 L .53792 .3674 L F
.436 .342 .651 r
.53792 .3674 m .53793 .36763 L .54137 .36598 L F
.53793 .36763 m .53865 .36766 L .54137 .36598 L F
.17 0 .11 r
.53742 .36761 m .53981 .36745 L .54137 .36598 L F
.565 .443 .673 r
.53686 .36751 m .53762 .36759 L .53775 .36283 L F
.53762 .36759 m .53792 .3674 L .53775 .36283 L F
.17 0 .11 r
.53628 .36768 m .53742 .36761 L .53792 .3674 L F
.53883 .36683 m .53792 .3674 L .54137 .36598 L F
.436 .342 .651 r
.53775 .36283 m .53792 .3674 L .54137 .36598 L F
.149 .646 .913 r
.54019 .36788 m .53825 .36766 L .53628 .36768 L F
.17 0 .11 r
.53628 .36768 m .53865 .36766 L .53795 .36809 L F
.436 .342 .651 r
.53793 .36763 m .53795 .36809 L .53865 .36766 L F
.149 .646 .913 r
.54019 .36788 m .54005 .36772 L .53825 .36766 L F
.54005 .36772 m .53999 .36765 L .53865 .36766 L F
.54005 .36772 m .53865 .36766 L .53825 .36766 L F
.565 .443 .673 r
.53525 .36665 m .53686 .36751 L .53775 .36283 L F
.53686 .36751 m .53795 .36809 L .53793 .36763 L F
.149 .646 .913 r
.53999 .36765 m .53981 .36745 L .53628 .36768 L F
.078 .444 .879 r
.53628 .36768 m .53795 .36809 L .53525 .36665 L F
.694 .939 .644 r
.53807 .43168 m .54099 .42848 L .53934 .42948 L F
.513 .871 .633 r
.53934 .42948 m .54099 .42848 L .54131 .42807 L F
.532 .923 .884 r
.54838 .4267 m .55096 .42544 L .54928 .42532 L F
.356 .637 .96 r
.59643 .35795 m .59914 .35816 L .59803 .35987 L F
.126 .323 .791 r
.59914 .35816 m .59976 .36035 L .59803 .35987 L F
.599 .574 .797 r
.53214 .41766 m .53262 .42198 L .53533 .42061 L F
.371 .113 .387 r
.53533 .42061 m .53262 .42198 L .53222 .42417 L F
.74 .475 .529 r
.51957 .39705 m .51532 .39928 L .51676 .39798 L F
0 .205 .677 r
.34755 .56468 m .34786 .56445 L .34603 .56343 L F
.34755 .56468 m .35019 .56653 L .34786 .56445 L F
.763 .708 .8 r
.55872 .39471 m .55454 .39406 L .55724 .39337 L F
.752 .565 .642 r
.55401 .35978 m .5567 .35636 L .55401 .35716 L F
.479 .275 .525 r
.52434 .3867 m .52706 .38259 L .52543 .38519 L F
.944 .949 .748 r
.48259 .43285 m .4836 .43276 L .48361 .43116 L F
.923 .937 .795 r
.48516 .43217 m .48259 .43285 L .48361 .43116 L F
.598 .864 .993 r
.4857 .43033 m .48813 .43105 L .48516 .43217 L F
.523 .313 .536 r
.48361 .43116 m .4857 .43033 L .48516 .43217 L F
.736 .981 .756 r
.53252 .43878 m .52885 .44155 L .52973 .44175 L F
.507 0 0 r
.38672 .48824 m .38921 .48873 L .38667 .48731 L F
.862 .501 .365 r
.64413 .36576 m .64708 .36435 L .6436 .36348 L F
.64413 .36576 m .64756 .36631 L .64708 .36435 L F
.396 .127 .384 r
.44125 .45939 m .44384 .45872 L .44419 .45626 L F
.395 .101 .343 r
.44384 .45872 m .44731 .45509 L .44419 .45626 L F
.83 .944 .898 r
.51809 .44976 m .51658 .44879 L .51342 .45168 L F
.87 .957 .86 r
.51821 .44675 m .51809 .44976 L .5205 .44692 L F
.846 .944 .884 r
.51821 .44675 m .51658 .44879 L .51809 .44976 L F
.739 .623 .73 r
.31467 .64656 m .31907 .64727 L .31745 .64329 L F
.734 .621 .733 r
.31907 .64727 m .3218 .64369 L .31745 .64329 L F
.843 .873 .432 r
.33944 .50425 m .33861 .50504 L .33977 .50273 L F
.33944 .50425 m .33826 .50749 L .33861 .50504 L F
.623 .466 .649 r
.33944 .50425 m .33826 .50749 L .34151 .5065 L F
.844 .765 .774 r
.41947 .52093 m .4148 .52292 L .4175 .51958 L F
.41947 .52093 m .4169 .52463 L .4148 .52292 L F
.827 .833 .852 r
.4953 .4514 m .4969 .45354 L .49392 .45605 L F
.921 .973 .767 r
.48255 .47786 m .48487 .47703 L .48476 .47445 L F
.901 .986 .772 r
.45837 .50393 m .45613 .50468 L .45575 .50761 L F
.705 .952 .673 r
.45837 .50393 m .46129 .50071 L .45941 .502 L F
.705 .983 .812 r
.45941 .502 m .45613 .50468 L .45837 .50393 L F
.784 .763 .833 r
.4293 .53753 m .43049 .54127 L .43377 .53812 L F
.83 .785 .81 r
.42699 .5403 m .43049 .54127 L .4293 .53753 L F
.88 .635 .564 r
.43021 .54371 m .43049 .54127 L .42699 .5403 L F
0 .087 .63 r
.58984 .39484 m .59006 .39329 L .58883 .39104 L F
0 0 .425 r
.58984 .39484 m .59053 .39742 L .59006 .39329 L F
.811 .422 .316 r
.63185 .35893 m .62839 .35946 L .62764 .35721 L F
.88 .921 .848 r
.63185 .35893 m .62971 .36107 L .62839 .35946 L F
.857 .996 .769 r
.53738 .43138 m .53535 .43538 L .53807 .43168 L F
.702 .981 .807 r
.53738 .43138 m .53807 .43168 L .53934 .42948 L F
.746 .657 .761 r
.30773 .64674 m .3121 .64742 L .3105 .64332 L F
.65 .539 .715 r
.3121 .64742 m .31501 .64391 L .3105 .64332 L F
.3121 .64742 m .31467 .64656 L .31501 .64391 L F
.737 .599 .703 r
.31745 .64329 m .3218 .64369 L .32039 .64003 L F
.531 .741 .971 r
.35148 .5686 m .35257 .5662 L .35019 .56653 L F
.35148 .5686 m .35407 .56802 L .35257 .5662 L F
.48 .222 .445 r
.61023 .38753 m .61313 .38691 L .61327 .38443 L F
.389 .15 .426 r
.61327 .38443 m .61313 .38691 L .61597 .38364 L F
.802 .77 .824 r
.41737 .56197 m .41442 .56624 L .41091 .56521 L F
.515 .81 .999 r
.49392 .45605 m .4896 .45539 L .49286 .45394 L F
.827 .833 .852 r
.4953 .4514 m .49392 .45605 L .49286 .45394 L F
.072 .316 .797 r
.39484 .57196 m .3972 .57319 L .39579 .56979 L F
.39484 .57196 m .39579 .56979 L .3955 .57111 L F
.731 .749 .867 r
.39071 .57136 m .39484 .57196 L .3955 .57111 L F
.833 .92 .893 r
.45102 .50941 m .45575 .50761 L .45428 .50667 L F
.828 .951 .899 r
.45575 .50761 m .45613 .50468 L .45428 .50667 L F
0 0 0 r
.41562 .55359 m .41383 .55393 L .41131 .55431 L F
.41562 .55359 m .41831 .55203 L .4179 .55296 L F
.268 .774 .78 r
.4179 .55296 m .41383 .55393 L .41562 .55359 L F
.924 .896 .781 r
.48835 .43454 m .49232 .43206 L .48813 .43105 L F
.48835 .43454 m .48979 .43549 L .49232 .43206 L F
.408 .758 .994 r
.60872 .37174 m .60741 .37331 L .60592 .37243 L F
.60872 .37174 m .6101 .37301 L .60741 .37331 L F
.696 .66 .811 r
.5567 .35636 m .56086 .35693 L .5595 .35283 L F
.725 .554 .659 r
.5567 .35636 m .55864 .36034 L .56086 .35693 L F
.728 .679 .802 r
.5595 .35283 m .56086 .35693 L .56384 .35387 L F
.613 .224 .282 r
.36431 .49524 m .36243 .49832 L .3604 .49615 L F
0 0 0 r
.36704 .49632 m .36243 .49832 L .36431 .49524 L F
.865 .982 .847 r
.50133 .46161 m .49924 .46594 L .5025 .46282 L F
.50133 .46161 m .49827 .46506 L .49924 .46594 L F
.815 .799 .305 r
.55931 .41222 m .55987 .41192 L .56034 .40971 L F
.55931 .41222 m .55914 .41455 L .55987 .41192 L F
.671 .162 .024 r
.60011 .34766 m .60421 .34859 L .60187 .34635 L F
.736 .981 .756 r
.53252 .43878 m .53058 .43964 L .52885 .44155 L F
.848 .997 .768 r
.5347 .43471 m .53252 .43878 L .53535 .43538 L F
.5347 .43471 m .53202 .43802 L .53252 .43878 L F
.866 .992 .739 r
.53202 .43802 m .53058 .43964 L .53252 .43878 L F
.947 .896 .504 r
.52381 .39799 m .52243 .39936 L .5234 .39742 L F
.577 .423 .636 r
.52731 .39659 m .52821 .40032 L .52501 .40127 L F
.52731 .39659 m .52501 .40127 L .52698 .39817 L F
.325 .1 .411 r
.52698 .39817 m .52524 .39862 L .52503 .39582 L F
.93 .95 .617 r
.52381 .39799 m .52488 .39377 L .52503 .39582 L F
.52381 .39799 m .5234 .39742 L .52504 .39311 L F
.679 .893 .534 r
.52503 .39582 m .52243 .39936 L .52381 .39799 L F
.325 .1 .411 r
.52524 .39862 m .52243 .39936 L .52503 .39582 L F
.93 .95 .617 r
.52488 .39377 m .52504 .39311 L .52503 .39582 L F
.491 .259 .489 r
.45878 .44225 m .46166 .44167 L .46183 .43897 L F
.304 .109 .443 r
.46183 .43897 m .46166 .44167 L .46408 .43792 L F
.422 .107 .323 r
.42574 .47252 m .42848 .47191 L .42945 .46895 L F
.363 .068 .324 r
.42848 .47191 m .43164 .46891 L .42945 .46895 L F
.976 .764 .552 r
.4629 .4483 m .4626 .45275 L .46451 .45267 L F
0 0 .165 r
.4626 .45275 m .46289 .45315 L .46451 .45267 L F
.12 0 0 r
.46451 .45267 m .46289 .45315 L .46582 .45298 L F
.328 .004 .255 r
.46381 .45319 m .46319 .45357 L .46289 .45315 L F
.12 0 0 r
.46289 .45315 m .46272 .4532 L .4632 .45317 L F
.46289 .45315 m .4632 .45317 L .46582 .45298 L F
.328 .004 .255 r
.46568 .45206 m .46381 .45319 L .4626 .45275 L F
.46381 .45319 m .46289 .45315 L .4626 .45275 L F
.46319 .45357 m .46278 .45381 L .4626 .45275 L F
0 0 .165 r
.4626 .45275 m .46272 .4532 L .46289 .45315 L F
.565 .369 .574 r
.46451 .45267 m .46778 .45249 L .4692 .45148 L F
.12 0 0 r
.46451 .45267 m .46582 .45298 L .46778 .45249 L F
.925 .957 .783 r
.55149 .41702 m .54938 .42221 L .54947 .42097 L F
.737 .599 .703 r
.31745 .64329 m .32039 .64003 L .3176 .64044 L F
.857 .996 .769 r
.53738 .43138 m .5347 .43471 L .53535 .43538 L F
.503 .213 .406 r
.46683 .43447 m .47028 .43165 L .46725 .43231 L F
.133 .269 .739 r
.62398 .37016 m .62309 .36603 L .62409 .36732 L F
.073 0 0 r
.52811 .42925 m .52695 .42863 L .52631 .43071 L F
.52811 .42925 m .52977 .42801 L .52695 .42863 L F
.4 .172 .448 r
.51488 .39022 m .51802 .38981 L .51786 .38726 L F
.436 .133 .351 r
.51423 .3931 m .51802 .38981 L .51488 .39022 L F
.971 .834 .651 r
.57689 .38607 m .57936 .38491 L .57823 .38247 L F
.57689 .38607 m .57848 .38755 L .57936 .38491 L F
.728 .451 .508 r
.41281 .497 m .4131 .49917 L .41084 .49679 L F
0 0 .359 r
.52434 .3867 m .5242 .39083 L .52396 .38795 L F
.218 0 .181 r
.4938 .45131 m .49266 .45227 L .49176 .45252 L F
.418 .15 .398 r
.49266 .45227 m .4896 .45539 L .49176 .45252 L F
0 0 .329 r
.59119 .37766 m .59077 .37644 L .59021 .37794 L F
.757 .773 .866 r
.37359 .55635 m .36916 .55536 L .37193 .55427 L F
.573 .742 .956 r
.37458 .55358 m .37359 .55635 L .37193 .55427 L F
.37458 .55358 m .37622 .55598 L .37359 .55635 L F
.616 .806 .973 r
.60486 .3973 m .60908 .398 L .60778 .39675 L F
.674 .896 .977 r
.60778 .39675 m .60908 .398 L .61146 .39645 L F
.565 .443 .673 r
.53525 .36665 m .53775 .36283 L .53417 .36464 L F
.181 .078 .493 r
.34496 .499 m .34344 .50306 L .34166 .49894 L F
.726 .638 .76 r
.34496 .499 m .34166 .49894 L .34425 .49667 L F
.962 .743 .561 r
.34425 .49667 m .34474 .49828 L .34641 .49676 L F
.34474 .49828 m .34578 .49773 L .34641 .49676 L F
.24 .369 .793 r
.34578 .4983 m .34695 .49764 L .34425 .49667 L F
0 0 0 r
.34578 .4983 m .34575 .49833 L .34695 .49764 L F
.274 .349 .759 r
.34581 .49829 m .34695 .49764 L .34588 .49837 L F
0 0 0 r
.34575 .49833 m .345 .49892 L .34695 .49764 L F
.274 .349 .759 r
.34425 .49667 m .34695 .49764 L .34581 .49829 L F
.962 .743 .561 r
.34474 .49828 m .34496 .499 L .34578 .49773 L F
.274 .349 .759 r
.34474 .49828 m .34588 .49837 L .34496 .499 L F
0 0 0 r
.34553 .49834 m .34568 .49835 L .34578 .4983 L F
.274 .349 .759 r
.34425 .49667 m .34553 .49834 L .34474 .49828 L F
.623 .463 .644 r
.34425 .49667 m .34166 .49894 L .34553 .49834 L F
.34425 .49667 m .34553 .49834 L .34578 .4983 L F
.274 .349 .759 r
.34425 .49667 m .34588 .49837 L .34553 .49834 L F
0 0 0 r
.34426 .49854 m .34259 .50002 L .34568 .49835 L F
.34426 .49854 m .34568 .49835 L .34553 .49834 L F
.34166 .49894 m .34224 .49961 L .34426 .49854 L F
.34224 .49961 m .34259 .50002 L .34426 .49854 L F
.916 .704 .602 r
.63629 .35717 m .63934 .35707 L .63742 .3551 L F
.63629 .35717 m .63929 .36075 L .63934 .35707 L F
.543 .395 .63 r
.56793 .37383 m .57103 .37324 L .57115 .37039 L F
.43 .165 .409 r
.56802 .37635 m .57103 .37324 L .56793 .37383 L F
.613 .442 .627 r
.3079 .64412 m .3105 .64332 L .31024 .64028 L F
.556 .373 .589 r
.31024 .64028 m .31317 .63996 L .31339 .63682 L F
.563 .405 .625 r
.3105 .64332 m .31317 .63996 L .31024 .64028 L F
.883 .983 .701 r
.33826 .50749 m .3362 .50875 L .33861 .50504 L F
.756 .523 .581 r
.41738 .49974 m .42191 .50026 L .4217 .50309 L F
.77 .722 .807 r
.3983 .52695 m .39974 .53076 L .40269 .52763 L F
.51 .179 .342 r
.41971 .47517 m .42246 .47509 L .42285 .47297 L F
.568 .231 .357 r
.42246 .47509 m .42542 .47506 L .42285 .47297 L F
.518 .249 .446 r
.42285 .47297 m .42542 .47506 L .42574 .47252 L F
.751 .618 .712 r
.56784 .35725 m .5721 .36016 L .57086 .35666 L F
.56784 .35725 m .57074 .36153 L .5721 .36016 L F
.75 .617 .711 r
.57074 .36153 m .5695 .36369 L .5721 .36016 L F
.76 .748 .841 r
.57086 .35666 m .5721 .36016 L .57505 .35704 L F
.718 .909 .961 r
.39065 .55165 m .39117 .54908 L .39379 .54854 L F
0 0 0 r
.39117 .54908 m .39548 .54666 L .39379 .54854 L F
.713 .888 .961 r
.62482 .39353 m .62771 .38985 L .623 .39195 L F
.62482 .39353 m .62903 .39127 L .62771 .38985 L F
.682 .951 .694 r
.60662 .37878 m .60543 .38037 L .60976 .37969 L F
.60662 .37878 m .60499 .38057 L .60543 .38037 L F
.752 .565 .642 r
.55401 .35978 m .55864 .36034 L .5567 .35636 L F
.498 .279 .512 r
.45878 .44225 m .45869 .44497 L .46166 .44167 L F
.718 .909 .961 r
.39065 .55165 m .3888 .55068 L .39117 .54908 L F
.343 .133 .443 r
.44125 .45939 m .44343 .46112 L .44384 .45872 L F
.44125 .45939 m .4411 .4621 L .44343 .46112 L F
.815 .915 .906 r
.62971 .36107 m .62522 .36261 L .62839 .35946 L F
.686 .237 .181 r
.37859 .49618 m .37662 .49825 L .37438 .49585 L F
.628 .166 .137 r
.382 .4985 m .37859 .49618 L .38086 .49676 L F
.382 .4985 m .37662 .49825 L .37859 .49618 L F
.637 .799 .96 r
.37222 .56918 m .37589 .57004 L .37481 .56842 L F
.399 .668 .968 r
.37589 .57004 m .37698 .568 L .37481 .56842 L F
.37589 .57004 m .3793 .57039 L .37698 .568 L F
.781 .833 .892 r
.4233 .55058 m .42412 .54698 L .4231 .54972 L F
.4233 .55058 m .42772 .54731 L .42412 .54698 L F
0 0 .06 r
.34291 .50558 m .34103 .50999 L .34151 .5065 L F
.34291 .50558 m .34156 .50965 L .34103 .50999 L F
.823 .951 .903 r
.50658 .44923 m .50318 .45204 L .50196 .45104 L F
.091 0 .065 r
.49324 .4104 m .49616 .40956 L .49694 .40711 L F
.455 .248 .508 r
.49334 .41335 m .49616 .40956 L .49324 .4104 L F
.519 .188 .347 r
.40616 .48271 m .40922 .48219 L .41018 .47959 L F
.383 0 .173 r
.40922 .48219 m .41312 .47944 L .41018 .47959 L F
.64 .493 .666 r
.3051 .64766 m .30773 .64674 L .3079 .64412 L F
.789 .719 .787 r
.4165 .51027 m .41925 .50677 L .4208 .51073 L F
.792 .712 .776 r
.4165 .51027 m .4208 .51073 L .41821 .51374 L F
.777 .714 .793 r
.41925 .50677 m .42362 .50755 L .4208 .51073 L F
.613 .372 .529 r
.41084 .49679 m .41082 .49961 L .40634 .49976 L F
.713 .454 .532 r
.4131 .49917 m .41082 .49961 L .41084 .49679 L F
.796 .981 .708 r
.48523 .44058 m .48421 .44304 L .48678 .44164 L F
.48523 .44058 m .48255 .44393 L .48421 .44304 L F
.701 .7 .846 r
.38062 .5571 m .37622 .55598 L .3789 .55614 L F
.027 0 0 r
.3789 .55614 m .38293 .5559 L .38062 .5571 L F
.824 .771 .803 r
.54932 .38341 m .54525 .38261 L .54731 .38054 L F
.972 .729 .51 r
.54888 .3815 m .54932 .38341 L .54731 .38054 L F
0 0 0 r
.55009 .38313 m .54728 .38514 L .54932 .38341 L F
.739 .691 .804 r
.4165 .51027 m .41821 .51374 L .41351 .5135 L F
.647 .413 .551 r
.41821 .51374 m .41372 .51636 L .41351 .5135 L F
.41821 .51374 m .41843 .51653 L .41372 .51636 L F
.693 .534 .668 r
.52631 .3801 m .5286 .3759 L .52626 .37731 L F
.858 .953 .873 r
.50401 .45859 m .5025 .46282 L .50327 .46112 L F
.50401 .45859 m .50133 .46161 L .5025 .46282 L F
.677 .522 .667 r
.49285 .42118 m .4933 .42451 L .48986 .42399 L F
0 0 .498 r
.49488 .42325 m .49285 .42118 L .49447 .42009 L F
.49488 .42325 m .4933 .42451 L .49285 .42118 L F
.768 .646 .727 r
.42611 .5037 m .42362 .50755 L .4217 .50309 L F
.237 0 .147 r
.49882 .41746 m .49447 .42009 L .49616 .41835 L F
.531 .207 .364 r
.43753 .46457 m .4411 .4621 L .43852 .46306 L F
.348 .116 .414 r
.46436 .43539 m .46408 .43792 L .46683 .43447 L F
.639 .934 .968 r
.5205 .44692 m .52196 .44489 L .51821 .44675 L F
.5205 .44692 m .52325 .4456 L .52196 .44489 L F
.692 .743 .89 r
.61022 .35707 m .61093 .35972 L .60742 .35922 L F
.382 0 0 r
.61093 .35972 m .60746 .36145 L .60742 .35922 L F
.61093 .35972 m .60947 .36174 L .60746 .36145 L F
.151 .35 .807 r
.61022 .35707 m .61226 .3579 L .61093 .35972 L F
0 0 0 r
.61226 .3579 m .60947 .36174 L .61093 .35972 L F
.546 .828 .998 r
.54888 .3815 m .55066 .37955 L .55155 .38046 L F
.54888 .3815 m .54731 .38054 L .55066 .37955 L F
.514 .249 .451 r
.54888 .3815 m .55126 .3833 L .55155 .38046 L F
.415 .59 .915 r
.50186 .44072 m .50099 .44383 L .49921 .44319 L F
.50143 .44225 m .50185 .44381 L .50099 .44383 L F
.50159 .44216 m .50185 .44381 L .50143 .44225 L F
.50186 .44174 m .50185 .44381 L .50154 .44187 L F
.455 .611 .915 r
.50467 .44132 m .50402 .44376 L .50242 .44151 L F
0 0 0 r
.50186 .44174 m .50242 .44151 L .50515 .43993 L F
.81 .912 .909 r
.50186 .44072 m .50186 .44174 L .50515 .43993 L F
.455 .611 .915 r
.50347 .44106 m .50242 .44151 L .50186 .44072 L F
.50467 .44132 m .50242 .44151 L .50347 .44106 L F
0 0 0 r
.50242 .44151 m .50327 .44116 L .50332 .44113 L F
.50242 .44151 m .50332 .44113 L .50515 .43993 L F
.415 .59 .915 r
.50186 .44072 m .50402 .44376 L .50185 .44381 L F
.546 .068 .073 r
.50515 .43993 m .50467 .44132 L .50344 .44106 L F
0 0 0 r
.50515 .43993 m .50327 .44116 L .50339 .44109 L F
.546 .068 .073 r
.50515 .43993 m .50344 .44106 L .50186 .44072 L F
0 0 0 r
.50515 .43993 m .50339 .44109 L .5043 .44055 L F
.5043 .44055 m .49983 .4434 L .50358 .44107 L F
.50327 .44116 m .49983 .4434 L .5043 .44055 L F
.415 .59 .915 r
.50154 .44187 m .50159 .44216 L .50143 .44225 L F
.50186 .44072 m .50186 .44174 L .50154 .44187 L F
0 0 0 r
.49921 .44319 m .49983 .4434 L .50327 .44116 L F
.49921 .44319 m .50327 .44116 L .50186 .44174 L F
.81 .912 .909 r
.50186 .44072 m .49921 .44319 L .50186 .44174 L F
.59 .533 .76 r
.50467 .44132 m .50423 .4427 L .50402 .44376 L F
.497 .829 .999 r
.50402 .44376 m .50374 .44512 L .50206 .44553 L F
0 0 .17 r
.50308 .44637 m .50206 .44553 L .50481 .44486 L F
.59 .533 .76 r
.50423 .4427 m .50308 .44637 L .50402 .44376 L F
.497 .829 .999 r
.50402 .44376 m .50481 .44486 L .50374 .44512 L F
0 0 .17 r
.50308 .44637 m .5019 .44911 L .50206 .44553 L F
.545 .76 .976 r
.5379 .41991 m .53955 .42164 L .53533 .42061 L F
.479 .727 .98 r
.5416 .41973 m .53955 .42164 L .5379 .41991 L F
.416 .616 .933 r
.5416 .41973 m .543 .42343 L .53955 .42164 L F
.815 .952 .908 r
.46844 .49187 m .46709 .49088 L .46656 .49361 L F
.862 .984 .848 r
.46709 .49088 m .46549 .49286 L .46656 .49361 L F
.411 0 0 r
.60924 .38914 m .61023 .38753 L .60627 .38806 L F
.463 .838 .989 r
.61195 .38599 m .61313 .38691 L .61023 .38753 L F
.61195 .38599 m .61023 .38753 L .60924 .38914 L F
.005 0 0 r
.48986 .42399 m .48886 .42533 L .48587 .42676 L F
0 .51 .732 r
.48986 .42399 m .4933 .42451 L .49226 .42428 L F
.48986 .42399 m .49226 .42428 L .48886 .42533 L F
.042 .329 .811 r
.54419 .42235 m .543 .42343 L .5416 .41973 L F
.95 .951 .652 r
.45941 .502 m .46129 .50071 L .46123 .49783 L F
.776 .651 .724 r
.31596 .63637 m .31858 .63297 L .31571 .63413 L F
.739 .63 .738 r
.31501 .64391 m .31745 .64329 L .3176 .64044 L F
.737 .619 .728 r
.31467 .64656 m .31745 .64329 L .31501 .64391 L F
.665 .57 .739 r
.31339 .63682 m .31596 .63637 L .31571 .63413 L F
.635 .441 .602 r
.31317 .63996 m .31596 .63637 L .31339 .63682 L F
.563 .129 .175 r
.39002 .49828 m .3881 .49729 L .39234 .49676 L F
.734 .39 .398 r
.39234 .49676 m .39422 .49933 L .39002 .49828 L F
.768 .389 .339 r
.39705 .49925 m .39422 .49933 L .39234 .49676 L F
.821 .656 .679 r
.4293 .53753 m .43377 .53812 L .43177 .53376 L F
.096 0 .112 r
.44938 .45451 m .45307 .451 L .45003 .45224 L F
.627 .481 .664 r
.30773 .64674 m .3105 .64332 L .3079 .64412 L F
.134 0 0 r
.59976 .36035 m .60381 .36082 L .60393 .36065 L F
.346 .305 .669 r
.60746 .36145 m .60393 .36065 L .60742 .35922 L F
.60746 .36145 m .60485 .36361 L .60393 .36065 L F
.15 0 0 r
.60381 .36082 m .60742 .35922 L .60393 .36065 L F
.826 .991 .864 r
.57429 .38983 m .57212 .39338 L .57547 .39102 L F
.57429 .38983 m .57115 .39289 L .57212 .39338 L F
.527 .563 .835 r
.40269 .52763 m .39833 .524 L .3983 .52695 L F
.525 .264 .462 r
.50296 .40131 m .50275 .40374 L .5062 .40084 L F
.446 .095 .275 r
.50447 .42962 m .50524 .42737 L .50185 .42847 L F
.50185 .42847 m .50524 .42737 L .50447 .42962 L F
.733 .244 0 r
.54815 .41112 m .55135 .41477 L .54768 .41232 L F
.969 .649 .303 r
.55135 .41477 m .54978 .41381 L .54768 .41232 L F
.55135 .41477 m .55149 .41702 L .54978 .41381 L F
.123 0 0 r
.38921 .48873 m .3919 .48821 L .39377 .48679 L F
.329 0 0 r
.3919 .48821 m .39636 .48594 L .39377 .48679 L F
.631 .915 .98 r
.61364 .39455 m .61878 .39435 L .61722 .39284 L F
.691 .845 .957 r
.61722 .39284 m .61878 .39435 L .62128 .39265 L F
.998 .784 .447 r
.48547 .43749 m .48678 .44164 L .48982 .43834 L F
.48547 .43749 m .48523 .44058 L .48678 .44164 L F
.512 .304 .535 r
.48678 .44164 m .48975 .44139 L .48982 .43834 L F
.455 .321 .609 r
.48678 .44164 m .48925 .44429 L .48975 .44139 L F
.48678 .44164 m .48747 .44517 L .48925 .44429 L F
.692 .704 .856 r
.35249 .56091 m .35014 .56238 L .34857 .56059 L F
.916 .948 .805 r
.57689 .38607 m .57547 .39102 L .57848 .38755 L F
.57689 .38607 m .57429 .38983 L .57547 .39102 L F
.248 0 .186 r
.49919 .40572 m .50275 .40374 L .50045 .40508 L F
.678 .805 .943 r
.56802 .37635 m .56567 .37794 L .56399 .37601 L F
.241 .755 .764 r
.60966 .34175 m .61266 .34097 L .61436 .3408 L F
.363 .05 .294 r
.61654 .34135 m .61413 .34286 L .61436 .3408 L F
.243 0 0 r
.61436 .3408 m .61266 .34097 L .61654 .34135 L F
0 0 0 r
.54703 .36259 m .55068 .362 L .55174 .36155 L F
.375 0 0 r
.55174 .36155 m .55417 .36241 L .55401 .35978 L F
.55174 .36155 m .55068 .362 L .55417 .36241 L F
.622 .497 .688 r
.56979 .36646 m .57115 .37039 L .57343 .3671 L F
.823 .951 .903 r
.50658 .44923 m .50196 .45104 L .50498 .44808 L F
0 0 .154 r
.50902 .44487 m .50658 .44923 L .50705 .44595 L F
.804 .931 .917 r
.50658 .44923 m .50498 .44808 L .50705 .44595 L F
.723 .651 .778 r
.59449 .355 m .59611 .35466 L .59167 .35299 L F
.023 0 .402 r
.59611 .35466 m .59757 .35322 L .59813 .34894 L F
.224 0 .006 r
.59912 .35335 m .59853 .3546 L .59611 .35466 L F
.59853 .3546 m .59822 .35527 L .59773 .35513 L F
.59853 .3546 m .59773 .35513 L .59611 .35466 L F
.113 .072 .529 r
.59611 .35466 m .59822 .35527 L .59757 .35322 L F
.801 .329 0 r
.59451 .3565 m .59496 .35683 L .59449 .355 L F
.59496 .35683 m .59643 .35795 L .59505 .35585 L F
.59496 .35683 m .59505 .35585 L .59449 .355 L F
.467 .516 .825 r
.59695 .35563 m .59643 .35795 L .59502 .35689 L F
.073 0 0 r
.59488 .35764 m .59593 .35812 L .59682 .35595 L F
.59335 .35896 m .5948 .35849 L .59488 .35764 L F
.5948 .35849 m .59593 .35812 L .59488 .35764 L F
.467 .516 .825 r
.59729 .3541 m .59695 .35563 L .59451 .3565 L F
.59695 .35563 m .59502 .35689 L .59451 .3565 L F
.798 .659 .709 r
.4217 .50309 m .42362 .50755 L .41925 .50677 L F
.467 .249 .499 r
.45296 .44875 m .45571 .44814 L .45582 .44543 L F
.458 .185 .41 r
.45296 .44875 m .45514 .44997 L .45571 .44814 L F
.45296 .44875 m .45307 .451 L .45514 .44997 L F
.465 0 .056 r
.40315 .48439 m .40576 .48464 L .40355 .48323 L F
.399 .054 .26 r
.40355 .48323 m .40576 .48464 L .40616 .48271 L F
.75 .645 .744 r
.59167 .35299 m .58891 .35641 L .59449 .355 L F
.42 0 .038 r
.58891 .35641 m .59163 .35646 L .59449 .355 L F
.801 .329 0 r
.59451 .3565 m .59449 .355 L .59163 .35646 L F
.759 .864 .926 r
.4197 .56672 m .41664 .56656 L .41817 .56735 L F
.205 0 .078 r
.49616 .40956 m .49919 .40572 L .49694 .40711 L F
.133 .269 .739 r
.62398 .37016 m .6255 .36806 L .62309 .36603 L F
.622 .941 .954 r
.62398 .37016 m .62284 .36935 L .6255 .36806 L F
.808 .78 .827 r
.48547 .43749 m .48982 .43834 L .48835 .43454 L F
.983 .814 .595 r
.48835 .43454 m .48982 .43834 L .48979 .43549 L F
.774 .307 .135 r
.49213 .4377 m .48979 .43549 L .48982 .43834 L F
.516 .307 .535 r
.48982 .43834 m .4917 .44022 L .49213 .4377 L F
.48982 .43834 m .48975 .44139 L .4917 .44022 L F
.723 .631 .755 r
.3105 .64332 m .31501 .64391 L .31317 .63996 L F
.739 .63 .738 r
.31501 .64391 m .3176 .64044 L .31317 .63996 L F
.481 .26 .501 r
.45582 .44543 m .45835 .4473 L .45869 .44497 L F
.45582 .44543 m .45571 .44814 L .45835 .4473 L F
.787 .355 .223 r
.63507 .35307 m .63742 .3551 L .63733 .35349 L F
.205 0 .078 r
.49616 .40956 m .49863 .40868 L .49919 .40572 L F
.248 0 .186 r
.49919 .40572 m .50372 .40614 L .50275 .40374 L F
.262 0 .284 r
.50172 .40818 m .50416 .40725 L .50432 .40636 L F
.50342 .40631 m .50432 .40636 L .50455 .40507 L F
.531 .316 .533 r
.49912 .4061 m .50372 .40614 L .49919 .40572 L F
.50338 .40631 m .50372 .40614 L .49912 .4061 L F
.146 0 .217 r
.50275 .40374 m .50372 .40614 L .50455 .40507 L F
.531 .316 .533 r
.49863 .40868 m .50172 .40818 L .50372 .40614 L F
.262 0 .284 r
.50172 .40818 m .50455 .40507 L .50372 .40614 L F
.50172 .40818 m .50432 .40636 L .50342 .40631 L F
.531 .316 .533 r
.49863 .40868 m .50338 .40631 L .49912 .4061 L F
.529 .347 .578 r
.51786 .38726 m .52059 .3866 L .52072 .38438 L F
.673 .477 .612 r
.51802 .38981 m .52059 .3866 L .51786 .38726 L F
.833 .981 .879 r
.51721 .44048 m .51828 .44133 L .51319 .44463 L F
.806 .978 .899 r
.52165 .4385 m .51828 .44133 L .51721 .44048 L F
0 0 0 r
.42052 .55854 m .41913 .56044 L .42249 .55694 L F
.736 .618 .726 r
.47674 .44506 m .48006 .44544 L .47945 .44156 L F
.121 0 0 r
.47526 .44674 m .48006 .44544 L .47674 .44506 L F
.47526 .44674 m .47779 .44663 L .48006 .44544 L F
.441 .866 .743 r
.47945 .44156 m .48116 .44046 L .48333 .43954 L F
.347 .365 .738 r
.48006 .44544 m .48116 .44046 L .47945 .44156 L F
.48006 .44544 m .48255 .44393 L .48116 .44046 L F
.453 0 0 r
.48006 .44544 m .48081 .44669 L .48255 .44393 L F
.48006 .44544 m .47779 .44663 L .48081 .44669 L F
.83 .731 .755 r
.40807 .5372 m .40443 .53716 L .40669 .53354 L F
.736 .687 .804 r
.41132 .53442 m .40807 .5372 L .40669 .53354 L F
.623 .956 .913 r
.54775 .4025 m .54802 .40364 L .54624 .40445 L F
.77 .967 .926 r
.55168 .39893 m .54802 .40364 L .54775 .4025 L F
.55168 .39893 m .55191 .40031 L .54802 .40364 L F
.163 .688 .871 r
.51098 .44441 m .51181 .44481 L .50902 .44487 L F
.51098 .44441 m .50902 .44487 L .50705 .44595 L F
.285 .37 .775 r
.60976 .37969 m .61016 .37605 L .60662 .37878 L F
.809 .518 .497 r
.55401 .35978 m .55821 .36317 L .55864 .36034 L F
.259 0 .148 r
.39705 .49925 m .39283 .50323 L .39422 .49933 L F
.39705 .49925 m .39499 .50241 L .39283 .50323 L F
.61 .249 .331 r
.39928 .50022 m .39499 .50241 L .39705 .49925 L F
.753 .606 .694 r
.31317 .63996 m .3176 .64044 L .31596 .63637 L F
.39 0 .059 r
.50585 .41471 m .50161 .41709 L .50212 .41507 L F
.50585 .41471 m .50483 .41677 L .50161 .41709 L F
.916 .933 .565 r
.50585 .41471 m .50699 .4099 L .50857 .41396 L F
.022 0 0 r
.50734 .41546 m .50585 .41471 L .50787 .41415 L F
0 0 .386 r
.50804 .41308 m .50704 .41621 L .50734 .41546 L F
.504 .218 .413 r
.50734 .41546 m .50657 .41766 L .50408 .41817 L F
0 0 .386 r
.50704 .41621 m .50657 .41766 L .50734 .41546 L F
.022 0 0 r
.50734 .41546 m .50787 .41415 L .50857 .41396 L F
.50734 .41546 m .50483 .41677 L .50585 .41471 L F
.77 .53 .572 r
.5583 .36578 m .56323 .36354 L .55821 .36317 L F
.5583 .36578 m .56287 .36659 L .56323 .36354 L F
.237 0 .147 r
.49882 .41746 m .49811 .41981 L .49447 .42009 L F
.32 0 .229 r
.49751 .4224 m .49447 .42009 L .49811 .41981 L F
.49751 .4224 m .49488 .42325 L .49447 .42009 L F
.783 .62 .678 r
.41738 .49974 m .41902 .50315 L .41522 .50317 L F
.749 .523 .588 r
.41902 .50315 m .41466 .506 L .41522 .50317 L F
.41902 .50315 m .41925 .50677 L .41466 .506 L F
.756 .523 .581 r
.41738 .49974 m .4217 .50309 L .41902 .50315 L F
.63 .432 .596 r
.41902 .50315 m .4217 .50309 L .41925 .50677 L F
.563 .129 .175 r
.39002 .49828 m .38792 .49894 L .3881 .49729 L F
0 0 0 r
.39117 .54908 m .39267 .54827 L .39548 .54666 L F
.407 .823 .637 r
.39548 .54666 m .39685 .54568 L .39893 .54449 L F
.407 .822 .632 r
.39548 .54666 m .39267 .54827 L .39685 .54568 L F
.805 .717 .768 r
.54645 .4066 m .55102 .40831 L .54815 .41112 L F
.622 .744 .934 r
.60966 .34175 m .61098 .3445 L .61413 .34286 L F
.929 .963 .769 r
.54645 .4066 m .54775 .4025 L .54624 .40445 L F
.601 .815 .982 r
.61545 .35471 m .61419 .3574 L .6127 .3553 L F
.61545 .35471 m .61685 .35642 L .61419 .3574 L F
.61545 .35471 m .61419 .3574 L .6127 .3553 L F
.61545 .35471 m .61685 .35642 L .61419 .3574 L F
.263 .534 .918 r
.56287 .36659 m .56642 .36957 L .56766 .36761 L F
.793 .588 .624 r
.4917 .44022 m .49551 .43796 L .49213 .4377 L F
.4917 .44022 m .49411 .44174 L .49551 .43796 L F
.759 .244 0 r
.54075 .41684 m .53578 .41283 L .53785 .41602 L F
.696 .49 .605 r
.40634 .49976 m .40331 .50284 L .40356 .49994 L F
.40634 .49976 m .40744 .50345 L .40331 .50284 L F
.581 .386 .582 r
.41082 .49961 m .40744 .50345 L .40634 .49976 L F
.5 0 0 r
.41831 .55203 m .42084 .55331 L .4179 .55296 L F
.466 .261 .517 r
.374 .53977 m .37597 .54023 L .37609 .53741 L F
.556 .934 .884 r
.54928 .42532 m .55096 .42544 L .55334 .42407 L F
.435 .874 .879 r
.49226 .42428 m .4933 .42451 L .49488 .42325 L F
.411 0 0 r
.60924 .38914 m .60627 .38806 L .60618 .38984 L F
.569 .264 .411 r
.49262 .44906 m .49531 .4479 L .48908 .44653 L F
.825 .962 .634 r
.49618 .44637 m .49367 .45023 L .49452 .44759 L F
0 0 0 r
.49618 .44637 m .49452 .44759 L .49523 .44709 L F
.49725 .44555 m .49524 .44817 L .49618 .44637 L F
.666 .582 .752 r
.50022 .44953 m .50196 .45104 L .4982 .45003 L F
.50192 .44985 m .50196 .45104 L .50047 .44975 L F
.50074 .44963 m .50047 .44975 L .50022 .44953 L F
.50192 .44985 m .50047 .44975 L .50074 .44963 L F
.599 .422 .613 r
.5019 .44911 m .50074 .44963 L .4979 .44469 L F
.69 .453 .558 r
.4979 .44469 m .50074 .44963 L .49666 .44631 L F
.50074 .44963 m .5012 .45041 L .50022 .44953 L F
.50074 .44963 m .50022 .44953 L .49666 .44631 L F
.666 .582 .752 r
.5019 .44911 m .50192 .44985 L .50022 .44953 L F
.599 .422 .613 r
.5019 .44911 m .5012 .45041 L .50074 .44963 L F
.69 .453 .558 r
.49666 .44631 m .50022 .44953 L .49524 .44817 L F
.666 .582 .752 r
.49939 .44973 m .4982 .45003 L .5012 .45041 L F
.69 .453 .558 r
.50022 .44953 m .5012 .45041 L .49747 .44901 L F
.50022 .44953 m .49747 .44901 L .49524 .44817 L F
.666 .582 .752 r
.5019 .44911 m .50022 .44953 L .5012 .45041 L F
0 0 0 r
.49618 .44637 m .49523 .44709 L .49797 .44518 L F
.4979 .44469 m .49725 .44555 L .49618 .44637 L F
.452 .859 .963 r
.49921 .44319 m .50099 .44383 L .4979 .44469 L F
.678 .828 .956 r
.36674 .55829 m .36223 .558 L .36494 .55708 L F
.82 .891 .894 r
.36916 .55536 m .36674 .55829 L .36494 .55708 L F
.791 .999 .829 r
.54279 .36462 m .54058 .36832 L .54222 .36703 L F
.855 .992 .838 r
.54137 .36598 m .53883 .36677 L .53981 .36745 L F
.51 .835 .537 r
.54137 .36598 m .53981 .36745 L .54279 .36462 L F
.791 .999 .829 r
.54279 .36462 m .53981 .36745 L .54058 .36832 L F
.578 .779 .974 r
.36367 .56762 m .36551 .56954 L .36795 .56847 L F
.203 0 0 r
.55437 .3799 m .55761 .37926 L .55802 .37795 L F
0 0 0 r
.55802 .37795 m .55761 .37926 L .55946 .37539 L F
.868 .992 .74 r
.40125 .56326 m .40082 .56538 L .40285 .56283 L F
.07 0 0 r
.40646 .56171 m .40125 .56326 L .40285 .56283 L F
.15 .684 .85 r
.62107 .35663 m .6201 .35632 L .61685 .35642 L F
.412 0 0 r
.62391 .3553 m .6201 .35632 L .62107 .35663 L F
.027 .386 .847 r
.54755 .39407 m .54833 .39289 L .54601 .39275 L F
.802 .77 .824 r
.41737 .56197 m .41091 .56521 L .41546 .56122 L F
.083 0 0 r
.41546 .56122 m .41913 .56044 L .41737 .56197 L F
0 0 .241 r
.34344 .50306 m .34291 .50558 L .34151 .5065 L F
.538 .716 .955 r
.35407 .56802 m .35823 .56946 L .35663 .56754 L F
.705 .799 .923 r
.35663 .56754 m .35823 .56946 L .361 .56802 L F
.797 .414 .33 r
.40331 .50284 m .39928 .50022 L .40356 .49994 L F
.933 .727 .602 r
.57795 .37306 m .57756 .37613 L .57967 .37712 L F
.92 .568 .351 r
.57756 .37613 m .57784 .37839 L .57967 .37712 L F
.981 .724 .465 r
.57784 .37839 m .57961 .37998 L .57967 .37712 L F
.761 .633 .719 r
.41372 .51636 m .41086 .51708 L .41351 .5135 L F
.648 .414 .55 r
.4133 .51923 m .41086 .51708 L .41372 .51636 L F
.743 .566 .655 r
.41843 .51653 m .4133 .51923 L .41372 .51636 L F
.466 .195 .418 r
.56784 .35725 m .57086 .35666 L .57128 .35451 L F
.405 .142 .398 r
.57128 .35451 m .57354 .35542 L .57348 .35258 L F
.57128 .35451 m .57086 .35666 L .57354 .35542 L F
.83 .738 .763 r
.35503 .55766 m .35072 .55972 L .35383 .55692 L F
.35503 .55766 m .35249 .56091 L .35072 .55972 L F
.725 .906 .959 r
.35807 .55867 m .35249 .56091 L .35503 .55766 L F
.284 .672 .972 r
.35625 .55623 m .35503 .55766 L .35383 .55692 L F
.35625 .55623 m .35801 .5576 L .35503 .55766 L F
.45 .737 .989 r
.35801 .5576 m .35807 .55867 L .35503 .55766 L F
.019 0 0 r
.38904 .56741 m .38601 .56752 L .38618 .56819 L F
.744 .566 .653 r
.4131 .49917 m .41738 .49974 L .41522 .50317 L F
.83 .953 .897 r
.4702 .48793 m .46844 .49187 L .47162 .48905 L F
.4702 .48793 m .46709 .49088 L .46844 .49187 L F
.522 0 0 r
.63807 .36093 m .63929 .36075 L .63629 .35717 L F
.834 .478 .381 r
.63804 .36365 m .6398 .36139 L .63807 .36093 L F
.522 0 0 r
.63807 .36093 m .63979 .36139 L .63929 .36075 L F
.834 .478 .381 r
.6398 .36139 m .63985 .36133 L .63807 .36093 L F
.63804 .36365 m .64198 .36483 L .63985 .36133 L F
.522 0 0 r
.63807 .36093 m .64012 .3618 L .63979 .36139 L F
.439 .09 .275 r
.50212 .41507 m .50161 .41709 L .49882 .41746 L F
.287 0 .175 r
.43164 .46891 m .43432 .46825 L .43507 .46566 L F
.209 0 .148 r
.43507 .46566 m .43674 .46722 L .43753 .46457 L F
.43507 .46566 m .43432 .46825 L .43674 .46722 L F
.686 .226 .153 r
.63055 .35206 m .63379 .35471 L .63507 .35307 L F
.787 .355 .223 r
.63507 .35307 m .63379 .35471 L .63742 .3551 L F
.8 .695 .749 r
.5793 .36275 m .57621 .36608 L .58102 .36694 L F
.794 .633 .683 r
.57621 .36608 m .57995 .36905 L .58102 .36694 L F
.418 .15 .398 r
.49266 .45227 m .49286 .45394 L .4896 .45539 L F
.539 .443 .694 r
.49524 .44817 m .49266 .45227 L .4938 .45131 L F
.49524 .44817 m .4953 .4514 L .49266 .45227 L F
.827 .833 .852 r
.4953 .4514 m .49286 .45394 L .49266 .45227 L F
.135 0 0 r
.48545 .41872 m .48714 .41896 L .48801 .41755 L F
.48545 .41872 m .48472 .41961 L .48714 .41896 L F
.15 0 0 r
.60381 .36082 m .60746 .36145 L .60742 .35922 L F
.201 0 .253 r
.60742 .35922 m .61009 .35866 L .61022 .35707 L F
.475 .249 .491 r
.61009 .35866 m .60746 .36145 L .60742 .35922 L F
.189 0 .213 r
.60742 .35922 m .60746 .36145 L .61009 .35866 L F
.856 .942 .575 r
.54279 .36462 m .54428 .36337 L .54004 .36272 L F
.54279 .36462 m .54222 .36703 L .54428 .36337 L F
.395 .101 .343 r
.44384 .45872 m .44656 .45799 L .44731 .45509 L F
.341 .031 .285 r
.44656 .45799 m .44938 .45451 L .44731 .45509 L F
.667 .522 .677 r
.58905 .35373 m .58891 .35641 L .59167 .35299 L F
.553 .606 .86 r
.38355 .57153 m .38601 .56752 L .38191 .5698 L F
.38355 .57153 m .38617 .57091 L .38601 .56752 L F
.936 .902 .767 r
.43026 .53257 m .4293 .53753 L .43177 .53376 L F
.923 .936 .795 r
.43265 .529 m .43177 .53376 L .4345 .53021 L F
.43265 .529 m .43026 .53257 L .43177 .53376 L F
.541 .867 .994 r
.55505 .39299 m .55571 .3922 L .55454 .39406 L F
.499 .818 1 r
.55571 .3922 m .55724 .39337 L .55454 .39406 L F
.819 .789 .824 r
.42772 .54731 m .42665 .54391 L .42412 .54698 L F
.857 .807 .8 r
.42772 .54731 m .43021 .54371 L .42665 .54391 L F
0 0 0 r
.5638 .40122 m .56652 .39799 L .56501 .39924 L F
.712 .913 .562 r
.5638 .40122 m .56501 .39924 L .56243 .4028 L F
0 0 .432 r
.59006 .39329 m .59053 .39742 L .59084 .39604 L F
0 0 .117 r
.59053 .39742 m .5913 .39808 L .59084 .39604 L F
.59053 .39742 m .59024 .40013 L .5913 .39808 L F
.812 .862 .886 r
.43635 .52293 m .44002 .52329 L .43778 .5218 L F
.43635 .52293 m .43771 .52392 L .44002 .52329 L F
.846 .761 .768 r
.43734 .52678 m .44002 .52329 L .43771 .52392 L F
.825 .833 .855 r
.43778 .5218 m .44002 .52329 L .4428 .51977 L F
.88 .635 .564 r
.43021 .54371 m .42699 .5403 L .42665 .54391 L F
.45 .737 .989 r
.35801 .5576 m .35975 .55917 L .35807 .55867 L F
.655 .824 .965 r
.36223 .558 m .35975 .55917 L .35801 .5576 L F
.908 .9 .807 r
.41351 .5135 m .40936 .51597 L .41178 .51226 L F
.41351 .5135 m .41086 .51708 L .40936 .51597 L F
.75 .709 .813 r
.41428 .50862 m .41351 .5135 L .41178 .51226 L F
.41428 .50862 m .4165 .51027 L .41351 .5135 L F
.869 .875 .838 r
.48804 .47092 m .4925 .46871 L .49096 .46747 L F
.48804 .47092 m .48941 .4719 L .4925 .46871 L F
.715 .896 .961 r
.49096 .46747 m .4925 .46871 L .49544 .46692 L F
.075 .284 .77 r
.59024 .40013 m .59246 .40444 L .59109 .4028 L F
.661 .833 .966 r
.59109 .4028 m .59246 .40444 L .59501 .40313 L F
.59109 .4028 m .59246 .40444 L .59501 .40313 L F
.563 .399 .618 r
.48587 .42676 m .48361 .43116 L .48368 .42716 L F
.347 .486 .857 r
.37722 .55275 m .37622 .55598 L .37458 .55358 L F
.37722 .55275 m .3789 .55614 L .37622 .55598 L F
.906 .898 .808 r
.4201 .56397 m .42214 .56536 L .42446 .56165 L F
.816 .912 .904 r
.4197 .56672 m .42214 .56536 L .4201 .56397 L F
.815 .512 .476 r
.3604 .49615 m .35844 .49898 L .35618 .49837 L F
.589 .227 .324 r
.36243 .49832 m .35844 .49898 L .3604 .49615 L F
.099 .324 .798 r
.54996 .39413 m .54941 .39303 L .54833 .39289 L F
.173 0 0 r
.54653 .39268 m .54833 .39289 L .54973 .39225 L F
.724 .953 .662 r
.54973 .39225 m .54833 .39289 L .5508 .38984 L F
.124 0 0 r
.54818 .39163 m .5508 .38984 L .54833 .39289 L F
.54803 .39025 m .54867 .39016 L .54818 .39163 L F
.54867 .39016 m .5508 .38984 L .54818 .39163 L F
.54803 .39025 m .54899 .3905 L .54971 .39024 L F
.741 .478 .532 r
.54728 .38514 m .54888 .39017 L .54314 .38764 L F
.54888 .39017 m .54892 .3903 L .54871 .3902 L F
.54888 .39017 m .54871 .3902 L .54314 .38764 L F
.124 0 0 r
.54867 .39016 m .54888 .39017 L .5508 .38984 L F
.54888 .39017 m .54971 .39024 L .55062 .38991 L F
.54888 .39017 m .55062 .38991 L .5508 .38984 L F
.21 .174 .597 r
.54897 .39018 m .54892 .3903 L .54888 .39017 L F
.124 0 0 r
.54862 .39025 m .54897 .39018 L .54867 .39016 L F
.21 .174 .597 r
.54966 .38713 m .54877 .38984 L .54728 .38514 L F
.55004 .38744 m .54877 .38984 L .54966 .38713 L F
.802 .616 .65 r
.55004 .38744 m .54609 .38891 L .54876 .39022 L F
.54897 .39018 m .54876 .39022 L .54892 .3903 L F
.21 .174 .597 r
.55004 .38744 m .54897 .39018 L .54877 .38984 L F
.54897 .39018 m .54888 .39017 L .54877 .38984 L F
.802 .616 .65 r
.55004 .38744 m .54876 .39022 L .54897 .39018 L F
.124 0 0 r
.54803 .39025 m .54862 .39025 L .54867 .39016 L F
.54862 .39025 m .54971 .39024 L .54897 .39018 L F
.099 .324 .798 r
.54941 .39303 m .54803 .39025 L .54833 .39289 L F
.173 0 0 r
.54601 .39275 m .54833 .39289 L .54653 .39268 L F
.697 .598 .741 r
.57343 .3671 m .57115 .37039 L .57425 .37018 L F
.573 .344 .53 r
.57103 .37324 m .57425 .37018 L .57115 .37039 L F
.869 .912 .858 r
.43265 .529 m .4345 .53021 L .43734 .52678 L F
.383 0 .173 r
.40922 .48219 m .41243 .48121 L .41312 .47944 L F
.385 .002 .183 r
.41243 .48121 m .41589 .47892 L .41312 .47944 L F
.078 .275 .761 r
.38904 .56741 m .39071 .57136 L .39146 .56951 L F
.45 .719 .982 r
.39071 .57136 m .3955 .57111 L .39146 .56951 L F
.735 .522 .605 r
.52072 .38438 m .52059 .3866 L .52434 .3867 L F
.76 .748 .841 r
.57086 .35666 m .57505 .35704 L .57354 .35542 L F
.805 .717 .768 r
.54645 .4066 m .54815 .41112 L .54683 .41007 L F
.998 .777 .46 r
.54815 .41112 m .54768 .41232 L .54683 .41007 L F
.806 .978 .899 r
.52165 .4385 m .51721 .44048 L .52061 .43737 L F
.942 .953 .748 r
.52379 .43438 m .52165 .4385 L .52061 .43737 L F
0 0 .529 r
.58883 .39104 m .59004 .39133 L .59003 .38823 L F
.58883 .39104 m .59006 .39329 L .59004 .39133 L F
.84 .847 .384 r
.55842 .41631 m .55914 .41455 L .55931 .41222 L F
.55832 .41676 m .55845 .41643 L .55842 .41631 L F
.55832 .41676 m .55842 .41631 L .55852 .41618 L F
.55842 .41631 m .55931 .41222 L .55852 .41618 L F
.951 .885 .486 r
.55786 .41425 m .55852 .41618 L .55931 .41222 L F
0 0 0 r
.55867 .41597 m .55852 .41618 L .55818 .4152 L F
.55911 .41667 m .55852 .41618 L .55867 .41597 L F
.55807 .41464 m .55818 .4152 L .55786 .41425 L F
.84 .847 .384 r
.55845 .41643 m .55914 .41455 L .55842 .41631 L F
0 0 0 r
.55911 .41667 m .55818 .4152 L .55807 .41464 L F
.444 .138 .349 r
.41589 .47892 m .41862 .4783 L .41971 .47517 L F
.495 .177 .356 r
.41862 .4783 m .42246 .47509 L .41971 .47517 L F
.605 .485 .691 r
.60746 .36145 m .60433 .36541 L .60485 .36361 L F
0 0 0 r
.36704 .49632 m .36519 .49748 L .36243 .49832 L F
.389 0 0 r
.36777 .49742 m .36704 .49632 L .36976 .49578 L F
.36777 .49742 m .36519 .49748 L .36704 .49632 L F
.273 .053 .387 r
.50775 .42442 m .50524 .42737 L .50729 .427 L F
.213 0 .18 r
.50729 .427 m .50524 .42737 L .50447 .42962 L F
.273 .053 .387 r
.50775 .42442 m .50524 .42737 L .50729 .427 L F
.213 0 .18 r
.50447 .42962 m .50524 .42737 L .50729 .427 L F
.50729 .427 m .50524 .42737 L .50447 .42962 L F
.371 .113 .387 r
.53533 .42061 m .53222 .42417 L .53422 .42295 L F
0 0 0 r
.53527 .42074 m .53533 .42061 L .53422 .42295 L F
.53527 .42074 m .5379 .41991 L .53533 .42061 L F
.889 .626 .11 r
.59075 .37011 m .59038 .37139 L .59038 .36869 L F
.59075 .37011 m .591 .3727 L .59038 .37139 L F
.897 .854 .791 r
.423 .55832 m .42674 .55785 L .42249 .55694 L F
.423 .55832 m .42446 .56165 L .42674 .55785 L F
.479 .275 .525 r
.52434 .3867 m .52729 .38623 L .52706 .38259 L F
0 0 .193 r
.52706 .38259 m .52729 .38623 L .52731 .38618 L F
.429 0 0 r
.52729 .38623 m .52739 .3863 L .52731 .38618 L F
.464 .258 .514 r
.52731 .38628 m .52817 .38752 L .52738 .38735 L F
.52738 .38629 m .52817 .38752 L .52731 .38628 L F
.52706 .38259 m .52812 .38729 L .52731 .38618 L F
.52812 .38729 m .52817 .38752 L .52731 .38618 L F
.452 .383 .689 r
.52599 .38829 m .5242 .39083 L .52434 .3867 L F
.52658 .38885 m .52474 .39038 L .52599 .38829 L F
.52474 .39038 m .5242 .39083 L .52599 .38829 L F
.734 .908 .535 r
.52462 .39046 m .52599 .38829 L .52434 .3867 L F
.52599 .38829 m .52729 .38623 L .52434 .3867 L F
.464 .258 .514 r
.52706 .38259 m .52731 .38619 L .52434 .3867 L F
.734 .908 .535 r
.52664 .38719 m .52726 .38626 L .52729 .38623 L F
.464 .258 .514 r
.52731 .38619 m .52738 .38735 L .52664 .38719 L F
.52731 .38619 m .52664 .38719 L .52434 .3867 L F
.734 .908 .535 r
.52599 .38829 m .52664 .38719 L .52729 .38623 L F
.52664 .38719 m .52711 .38642 L .52726 .38626 L F
.452 .383 .689 r
.52817 .38752 m .52658 .38885 L .52434 .3867 L F
.734 .908 .535 r
.52462 .39046 m .52564 .38791 L .52711 .38642 L F
.52462 .39046 m .52711 .38642 L .52599 .38829 L F
.684 .396 .48 r
.53071 .38448 m .52912 .38639 L .52706 .38259 L F
.52912 .38639 m .52822 .38746 L .52793 .38644 L F
.52912 .38639 m .52793 .38644 L .52706 .38259 L F
0 0 .353 r
.52918 .38757 m .52817 .38752 L .53071 .38448 L F
.429 0 0 r
.52734 .38601 m .52918 .38757 L .52791 .38338 L F
.52731 .38618 m .52755 .38636 L .52734 .38601 L F
.52755 .38636 m .52918 .38757 L .52734 .38601 L F
.684 .396 .48 r
.52822 .38746 m .52817 .38752 L .52812 .38729 L F
.52822 .38746 m .52812 .38729 L .52793 .38644 L F
.452 .383 .689 r
.52817 .38752 m .52684 .39144 L .5242 .39083 L F
0 0 .353 r
.52918 .38757 m .52684 .39144 L .52817 .38752 L F
.429 0 0 r
.52761 .38645 m .52564 .38791 L .52918 .38757 L F
.52739 .3863 m .52721 .38647 L .52761 .38645 L F
.52721 .38647 m .52564 .38791 L .52761 .38645 L F
.52729 .38623 m .52726 .38626 L .52739 .3863 L F
.52726 .38626 m .52564 .38791 L .52739 .3863 L F
.464 .258 .514 r
.52731 .38618 m .52738 .38629 L .52731 .38628 L F
.429 0 0 r
.52739 .3863 m .52918 .38757 L .52731 .38618 L F
0 0 .193 r
.52706 .38259 m .52731 .38618 L .52791 .38338 L F
.501 .276 .505 r
.52706 .38259 m .53035 .38046 L .52631 .3801 L F
.684 .396 .48 r
.53071 .38448 m .52706 .38259 L .52931 .38242 L F
0 0 .193 r
.52706 .38259 m .52791 .38338 L .52964 .38231 L F
.868 .775 .757 r
.59993 .39846 m .60229 .40077 L .60112 .39759 L F
.194 .721 .73 r
.59742 .40179 m .60229 .40077 L .59993 .39846 L F
.573 .344 .53 r
.57103 .37324 m .57424 .37288 L .57425 .37018 L F
.556 .51 .759 r
.57343 .3671 m .57425 .37018 L .57711 .36938 L F
.741 .48 .536 r
.57425 .37018 m .57795 .37306 L .57711 .36938 L F
.57425 .37018 m .57424 .37288 L .57795 .37306 L F
0 0 .096 r
.60421 .34859 m .60145 .35207 L .60219 .35015 L F
.28 .001 .299 r
.47318 .42833 m .47511 .42962 L .47575 .42772 L F
.47318 .42833 m .47269 .43063 L .47511 .42962 L F
.76 .633 .72 r
.4093 .53007 m .41132 .53442 L .40669 .53354 L F
.55 0 0 r
.34385 .56006 m .34857 .56059 L .34572 .56283 L F
.906 .898 .808 r
.4201 .56397 m .42446 .56165 L .42292 .56089 L F
.997 .827 .553 r
.42292 .56089 m .42446 .56165 L .423 .55832 L F
0 0 0 r
.5286 .3759 m .53126 .37479 L .53189 .37345 L F
.942 .953 .748 r
.52379 .43438 m .52061 .43737 L .52205 .43516 L F
0 0 .125 r
.52379 .43438 m .52593 .43331 L .52631 .43071 L F
.322 .783 .653 r
.52379 .43438 m .52205 .43516 L .52593 .43331 L F
.007 0 0 r
.60145 .35207 m .59822 .35527 L .59912 .35335 L F
0 0 0 r
.58877 .3591 m .59163 .35646 L .58891 .35641 L F
.746 .231 0 r
.62764 .35721 m .62673 .35751 L .62391 .3553 L F
.892 .47 .165 r
.62764 .35721 m .62839 .35946 L .62673 .35751 L F
.867 .735 .715 r
.3967 .56694 m .40044 .5686 L .39861 .56388 L F
.737 .322 .263 r
.39579 .56979 m .40044 .5686 L .3967 .56694 L F
.849 .46 .309 r
.4029 .5715 m .40044 .5686 L .40267 .57015 L F
.51 .071 .142 r
.39938 .57042 m .40267 .57015 L .40044 .5686 L F
.124 .638 .892 r
.39932 .57043 m .4029 .5715 L .4028 .57091 L F
.39873 .57047 m .4029 .5715 L .39932 .57043 L F
.737 .322 .263 r
.39734 .5701 m .39938 .57042 L .40044 .5686 L F
.39729 .57012 m .39764 .57017 L .39734 .5701 L F
.39764 .57017 m .39938 .57042 L .39734 .5701 L F
.124 .638 .892 r
.3975 .57017 m .39873 .57047 L .39876 .57047 L F
.3975 .57017 m .39876 .57047 L .39932 .57043 L F
.706 .707 .848 r
.3975 .57017 m .39764 .57017 L .39929 .57057 L F
0 .509 .77 r
.3975 .57017 m .39929 .57057 L .39729 .57012 L F
.3975 .57017 m .39729 .57012 L .39579 .56979 L F
.124 .638 .892 r
.3999 .5705 m .4028 .57091 L .40267 .57015 L F
.3975 .57017 m .4028 .57091 L .39764 .57017 L F
.51 .071 .142 r
.39929 .57057 m .40267 .57015 L .39938 .57042 L F
.737 .322 .263 r
.39729 .57012 m .39929 .57057 L .39938 .57042 L F
.706 .707 .848 r
.39764 .57017 m .40267 .57015 L .39929 .57057 L F
.737 .322 .263 r
.39579 .56979 m .39729 .57012 L .40044 .5686 L F
.879 .739 .704 r
.39861 .56388 m .40044 .5686 L .40082 .56538 L F
.683 .968 .761 r
.60069 .38494 m .59912 .38712 L .60248 .38414 L F
.224 .338 .77 r
.60069 .38494 m .60228 .38874 L .59912 .38712 L F
.728 .978 .918 r
.52433 .44331 m .52325 .4456 L .52524 .44394 L F
.7 .954 .952 r
.52196 .44489 m .52325 .4456 L .52433 .44331 L F
.879 .739 .704 r
.39861 .56388 m .40082 .56538 L .40125 .56326 L F
.692 .704 .856 r
.35249 .56091 m .34857 .56059 L .35072 .55972 L F
.735 .964 .689 r
.56794 .39603 m .56501 .39924 L .56652 .39799 L F
.47 .21 .437 r
.42542 .47506 m .42848 .47191 L .42574 .47252 L F
.808 .377 .221 r
.64198 .36483 m .64413 .36576 L .6436 .36348 L F
.566 .33 .517 r
.52504 .39311 m .52234 .39406 L .5242 .39083 L F
.52504 .39311 m .52234 .39406 L .5242 .39083 L F
.485 .288 .537 r
.52684 .39144 m .52504 .39311 L .5242 .39083 L F
.922 .927 .796 r
.63177 .38745 m .63428 .38396 L .63288 .38285 L F
.862 .996 .77 r
.63428 .38396 m .63695 .38058 L .63514 .3809 L F
.766 .93 .94 r
.63288 .38285 m .63428 .38396 L .63514 .3809 L F
.913 .612 .46 r
.48587 .43243 m .48835 .43454 L .4857 .43033 L F
.913 .614 .465 r
.48587 .43243 m .48813 .43105 L .4857 .43033 L F
.48587 .43243 m .48835 .43454 L .48813 .43105 L F
.893 .812 .762 r
.64344 .3684 m .64756 .36631 L .64413 .36576 L F
.64344 .3684 m .64529 .36997 L .64756 .36631 L F
.986 .733 .46 r
.56773 .38624 m .56761 .39004 L .56569 .38823 L F
.825 .996 .851 r
.63695 .38058 m .64021 .37728 L .63776 .37791 L F
.841 .998 .781 r
.63514 .3809 m .63695 .38058 L .63776 .37791 L F
.809 .518 .497 r
.55401 .35978 m .55417 .36241 L .55821 .36317 L F
.133 0 .042 r
.4692 .45148 m .46778 .45249 L .47032 .45143 L F
.364 .831 .786 r
.46778 .45249 m .46582 .45298 L .47032 .45143 L F
.518 .871 .627 r
.53109 .42565 m .531 .42591 L .52933 .42699 L F
.63 .825 .416 r
.53222 .42417 m .53088 .42627 L .531 .42591 L F
.518 .871 .627 r
.53313 .42408 m .531 .42591 L .53109 .42565 L F
.63 .825 .416 r
.53088 .42627 m .52977 .42801 L .531 .42591 L F
.734 .515 .595 r
.4131 .49917 m .41069 .50256 L .41082 .49961 L F
.779 .577 .627 r
.4131 .49917 m .41522 .50317 L .41069 .50256 L F
.99 .751 .476 r
.41086 .51708 m .41064 .51965 L .40936 .51597 L F
.648 .414 .55 r
.4133 .51923 m .41064 .51965 L .41086 .51708 L F
.489 .878 .966 r
.60112 .39759 m .60486 .3973 L .60343 .39595 L F
.472 .796 .999 r
.60486 .3973 m .60628 .39543 L .60343 .39595 L F
.60486 .3973 m .60778 .39675 L .60628 .39543 L F
.768 .552 .604 r
.55417 .36241 m .5583 .36578 L .55821 .36317 L F
.747 .5 .558 r
.4777 .44856 m .47929 .44899 L .48081 .44669 L F
.881 .956 .612 r
.48244 .44421 m .48081 .44669 L .48093 .44823 L F
.413 0 0 r
.48093 .44823 m .48315 .44941 L .48411 .44836 L F
.859 .547 .458 r
.48081 .44669 m .48315 .44941 L .48093 .44823 L F
.747 .5 .558 r
.47929 .44899 m .48202 .44972 L .48081 .44669 L F
.881 .956 .612 r
.48255 .44393 m .48081 .44669 L .48244 .44421 L F
.398 .818 .971 r
.39861 .56388 m .39416 .56376 L .39608 .5647 L F
0 .236 .753 r
.39416 .56376 m .3967 .56694 L .39608 .5647 L F
.5 .891 .954 r
.56101 .39313 m .56268 .39163 L .56493 .39084 L F
.825 .675 .697 r
.55242 .36794 m .54901 .3695 L .55127 .36595 L F
.55028 .36978 m .54901 .3695 L .55242 .36794 L F
.761 .546 .606 r
.55393 .37058 m .54831 .37215 L .54901 .3695 L F
.814 .939 .577 r
.55127 .36595 m .54901 .3695 L .5498 .36719 L F
.55127 .36595 m .54901 .3695 L .5498 .36719 L F
.895 .957 .832 r
.54831 .37215 m .5498 .36719 L .54901 .3695 L F
.54858 .37124 m .54704 .37068 L .5498 .36719 L F
.54831 .37215 m .54797 .37176 L .54858 .37124 L F
.54797 .37176 m .54704 .37068 L .54858 .37124 L F
.825 .675 .697 r
.55393 .37058 m .55028 .36978 L .55242 .36794 L F
.761 .546 .606 r
.55393 .37058 m .55262 .3727 L .54831 .37215 L F
0 .224 .744 r
.60028 .36777 m .60177 .37124 L .60009 .36971 L F
.436 .342 .651 r
.53775 .36283 m .54137 .36598 L .54004 .36272 L F
.687 .93 .622 r
.531 .42591 m .52977 .42801 L .52811 .42925 L F
.667 .451 .583 r
.48116 .44046 m .48547 .43749 L .48333 .43954 L F
.749 .548 .623 r
.5208 .38975 m .52434 .3867 L .52059 .3866 L F
.5208 .38975 m .52462 .39046 L .52434 .3867 L F
.838 .798 .813 r
.62886 .38684 m .62903 .39127 L .63177 .38745 L F
.973 .883 .681 r
.62771 .38985 m .62903 .39127 L .62886 .38684 L F
.917 .892 .79 r
.60123 .38213 m .60499 .38057 L .60359 .37911 L F
.848 .795 .8 r
.59889 .38118 m .60123 .38213 L .60359 .37911 L F
0 .173 .703 r
.59961 .38137 m .60123 .38213 L .59889 .38118 L F
.917 .892 .79 r
.60123 .38213 m .60322 .38308 L .60499 .38057 L F
0 .173 .703 r
.60217 .38203 m .60123 .38213 L .59961 .38137 L F
.917 .892 .79 r
.60123 .38213 m .60248 .38414 L .60322 .38308 L F
.894 .934 .834 r
.60607 .37568 m .60499 .38057 L .60662 .37878 L F
.60607 .37568 m .60359 .37911 L .60499 .38057 L F
.599 .682 .9 r
.60592 .37243 m .60318 .37346 L .60177 .37124 L F
.006 .03 .534 r
.48181 .42084 m .48386 .42241 L .48472 .41961 L F
.345 .637 .962 r
.35257 .5662 m .35407 .56802 L .35491 .5662 L F
.467 .777 .998 r
.35407 .56802 m .35663 .56754 L .35491 .5662 L F
.498 .89 .728 r
.56174 .38622 m .56008 .38766 L .56277 .38672 L F
.759 .864 .926 r
.4197 .56672 m .4201 .56397 L .41664 .56656 L F
.181 .078 .493 r
.34496 .499 m .3454 .50193 L .34344 .50306 L F
.173 0 .322 r
.34564 .50324 m .34344 .50306 L .3454 .50193 L F
.34564 .50324 m .34291 .50558 L .34344 .50306 L F
.503 .213 .406 r
.46683 .43447 m .46975 .43407 L .47028 .43165 L F
.355 .083 .356 r
.47028 .43165 m .47229 .43316 L .47269 .43063 L F
.47028 .43165 m .46975 .43407 L .47229 .43316 L F
.61 .249 .331 r
.39928 .50022 m .3992 .50251 L .39499 .50241 L F
.797 .414 .33 r
.40331 .50284 m .3992 .50251 L .39928 .50022 L F
.817 .738 .776 r
.38792 .49894 m .38946 .50314 L .38562 .50156 L F
.783 .302 .082 r
.38946 .50314 m .38821 .50464 L .38562 .50156 L F
.626 .551 .751 r
.39002 .49828 m .38946 .50314 L .38792 .49894 L F
.39002 .49828 m .39283 .50323 L .38946 .50314 L F
.63 .106 0 r
.39207 .50517 m .38821 .50464 L .38946 .50314 L F
.569 .2 .302 r
.39283 .50323 m .39207 .50517 L .38946 .50314 L F
.869 .912 .858 r
.43265 .529 m .43734 .52678 L .43549 .52547 L F
.949 .837 .699 r
.43549 .52547 m .43734 .52678 L .43771 .52392 L F
.556 .51 .759 r
.57343 .3671 m .57711 .36938 L .57621 .36608 L F
.838 .917 .888 r
.50401 .45859 m .50737 .45795 L .50601 .45674 L F
.50401 .45859 m .50327 .46112 L .50737 .45795 L F
.837 .906 .885 r
.50737 .45795 m .50895 .45368 L .50601 .45674 L F
.50737 .45795 m .51049 .45501 L .50895 .45368 L F
.55 0 0 r
.34385 .56006 m .34626 .5612 L .34857 .56059 L F
.936 .965 .744 r
.34857 .56059 m .34912 .55604 L .35072 .55972 L F
.34857 .56059 m .34626 .5612 L .34912 .55604 L F
.759 .437 .441 r
.37438 .49585 m .36979 .49801 L .36976 .49578 L F
.37438 .49585 m .37256 .49864 L .36979 .49801 L F
.61 .256 .345 r
.37662 .49825 m .37256 .49864 L .37438 .49585 L F
.576 .043 0 r
.62726 .35193 m .62922 .35229 L .63055 .35206 L F
.706 .344 .359 r
.62922 .35229 m .63379 .35471 L .63055 .35206 L F
.803 .601 .63 r
.56241 .36941 m .55994 .37261 L .56532 .37325 L F
.72 .479 .561 r
.55946 .37539 m .56532 .37325 L .55994 .37261 L F
.55946 .37539 m .56399 .37601 L .56532 .37325 L F
.609 .792 .969 r
.36795 .56847 m .37222 .56918 L .37055 .56749 L F
.62 .78 .958 r
.37055 .56749 m .37222 .56918 L .37481 .56842 L F
.43 .165 .409 r
.56802 .37635 m .57095 .37556 L .57103 .37324 L F
.643 .401 .537 r
.57095 .37556 m .57424 .37288 L .57103 .37324 L F
.277 .002 .304 r
.46166 .44167 m .45869 .44497 L .4611 .44399 L F
.334 .144 .467 r
.46408 .43792 m .46166 .44167 L .46431 .44045 L F
.226 0 .284 r
.46166 .44167 m .46192 .44257 L .46431 .44045 L F
.46166 .44167 m .4611 .44399 L .46192 .44257 L F
.227 0 .287 r
.50913 .39766 m .51137 .39652 L .51196 .39415 L F
.365 .08 .342 r
.51196 .39415 m .51398 .3956 L .51423 .3931 L F
.51196 .39415 m .51137 .39652 L .51398 .3956 L F
.868 .936 .863 r
.47318 .48464 m .47162 .48905 L .47446 .48554 L F
.47318 .48464 m .4702 .48793 L .47162 .48905 L F
.602 .439 .634 r
.45835 .4473 m .4611 .44399 L .45869 .44497 L F
.66 .951 .952 r
.53501 .41211 m .53377 .41423 L .53578 .41283 L F
.387 .394 .745 r
.53537 .41543 m .53377 .41423 L .53578 .41283 L F
.66 .951 .952 r
.53578 .41283 m .53377 .41423 L .53501 .41211 L F
.387 .394 .745 r
.53537 .41543 m .53501 .41211 L .53377 .41423 L F
.13 0 .119 r
.50913 .39766 m .50833 .39958 L .51137 .39652 L F
.743 .566 .655 r
.41843 .51653 m .4175 .51958 L .4133 .51923 L F
.562 .77 .976 r
.61151 .37051 m .6101 .37301 L .60872 .37174 L F
.61151 .37051 m .61293 .37224 L .6101 .37301 L F
.781 .654 .722 r
.48925 .44429 m .49378 .44503 L .4917 .44022 L F
.698 .346 .376 r
.48908 .44653 m .49378 .44503 L .48925 .44429 L F
.728 .63 .749 r
.4917 .44022 m .49378 .44503 L .49411 .44174 L F
.89 .714 .658 r
.40123 .50572 m .3992 .50251 L .40331 .50284 L F
.756 .562 .634 r
.40331 .50284 m .40485 .50629 L .40123 .50572 L F
.669 .524 .678 r
.40758 .50591 m .40331 .50284 L .40744 .50345 L F
.40758 .50591 m .40485 .50629 L .40331 .50284 L F
.674 .896 .977 r
.60778 .39675 m .61146 .39645 L .61011 .39537 L F
.682 .805 .941 r
.61146 .39645 m .61363 .39297 L .61011 .39537 L F
.61146 .39645 m .61364 .39455 L .61363 .39297 L F
.381 .008 .201 r
.5434 .42669 m .54632 .42626 L .54131 .42807 L F
.713 .794 .915 r
.35934 .56605 m .35663 .56754 L .361 .56802 L F
.486 .671 .946 r
.361 .56802 m .36189 .56563 L .35934 .56605 L F
.361 .56802 m .36367 .56762 L .36189 .56563 L F
0 0 0 r
.5062 .40084 m .50275 .40374 L .50508 .40206 L F
.674 .572 .732 r
.50508 .40206 m .50833 .39958 L .5062 .40084 L F
.77 .977 .709 r
.61597 .38364 m .61313 .38691 L .61432 .38431 L F
.707 .948 .956 r
.61432 .38431 m .61313 .38691 L .61195 .38599 L F
.838 .798 .813 r
.62886 .38684 m .63177 .38745 L .6298 .38587 L F
.922 .927 .796 r
.63177 .38745 m .63288 .38285 L .6298 .38587 L F
.521 0 0 r
.36826 .48895 m .37105 .49044 L .37255 .48908 L F
.574 .089 .066 r
.37105 .49044 m .37534 .48923 L .37255 .48908 L F
.778 .742 .82 r
.41061 .5226 m .41186 .52634 L .40777 .52595 L F
.794 .698 .759 r
.41186 .52634 m .4093 .53007 L .40777 .52595 L F
.81 .758 .805 r
.4148 .52292 m .41186 .52634 L .41061 .5226 L F
.443 .171 .404 r
.48411 .44836 m .48688 .4477 L .48747 .44517 L F
.461 .187 .41 r
.48747 .44517 m .48908 .44653 L .48925 .44429 L F
.48747 .44517 m .48688 .4477 L .48908 .44653 L F
.794 .598 .636 r
.41522 .50317 m .41035 .50543 L .41069 .50256 L F
.41522 .50317 m .41466 .506 L .41035 .50543 L F
.564 .164 .241 r
.37534 .48923 m .37778 .49114 L .38005 .48825 L F
.462 .026 .124 r
.37778 .49114 m .3822 .48879 L .38005 .48825 L F
.842 .677 .677 r
.41466 .506 m .4165 .51027 L .41428 .50862 L F
.733 .632 .746 r
.41466 .506 m .41925 .50677 L .4165 .51027 L F
.846 .613 .587 r
.5583 .36578 m .56241 .36941 L .56287 .36659 L F
.5583 .36578 m .55815 .3686 L .56241 .36941 L F
.843 .665 .661 r
.55815 .3686 m .55994 .37261 L .56241 .36941 L F
.842 .966 .883 r
.47637 .48139 m .47446 .48554 L .47819 .48264 L F
.47637 .48139 m .47318 .48464 L .47446 .48554 L F
.763 .448 .453 r
.37355 .54698 m .37182 .54464 L .37082 .54776 L F
.581 .386 .582 r
.41082 .49961 m .41069 .50256 L .40744 .50345 L F
.027 0 0 r
.3789 .55614 m .38146 .55609 L .38293 .5559 L F
.839 .998 .78 r
.38293 .5559 m .38436 .55265 L .38557 .55371 L F
.38293 .5559 m .38146 .55609 L .38436 .55265 L F
.794 .633 .683 r
.57621 .36608 m .57711 .36938 L .57995 .36905 L F
.798 .676 .73 r
.57711 .36938 m .57795 .37306 L .57995 .36905 L F
0 0 0 r
.46593 .44666 m .4629 .4483 L .46558 .44608 L F
.386 .241 .559 r
.46587 .45162 m .4629 .4483 L .46593 .44666 L F
.46587 .45162 m .4626 .45275 L .4629 .4483 L F
.507 .801 .999 r
.3793 .57039 m .38015 .56838 L .37698 .568 L F
.3793 .57039 m .38191 .5698 L .38015 .56838 L F
.818 .709 .745 r
.4093 .53007 m .40509 .52962 L .40777 .52595 L F
.815 .719 .759 r
.4093 .53007 m .40669 .53354 L .40509 .52962 L F
.409 .133 .381 r
.44343 .46112 m .44656 .45799 L .44384 .45872 L F
.673 .477 .612 r
.51802 .38981 m .5208 .38975 L .52059 .3866 L F
.825 .833 .855 r
.43778 .5218 m .4428 .51977 L .44141 .51898 L F
.895 .963 .829 r
.44417 .51526 m .4428 .51977 L .44682 .51633 L F
.44417 .51526 m .44141 .51898 L .4428 .51977 L F
.415 .685 .974 r
.35019 .56653 m .35087 .56511 L .34786 .56445 L F
.35019 .56653 m .35257 .5662 L .35087 .56511 L F
.986 .88 .531 r
.50308 .44637 m .50481 .44486 L .50402 .44376 L F
.925 .575 .349 r
.63379 .35471 m .63629 .35717 L .63742 .3551 L F
.915 .854 .768 r
.64158 .37188 m .64529 .36997 L .64344 .3684 L F
.64158 .37188 m .64325 .37333 L .64529 .36997 L F
.545 .727 .959 r
.49975 .45264 m .4953 .4514 L .4982 .45003 L F
.631 .622 .823 r
.50196 .45104 m .49975 .45264 L .4982 .45003 L F
.861 .868 .843 r
.64021 .37728 m .64158 .37188 L .64004 .37408 L F
.64021 .37728 m .64325 .37333 L .64158 .37188 L F
.941 .935 .764 r
.63776 .37791 m .64021 .37728 L .64004 .37408 L F
.31 0 .172 r
.50061 .41904 m .49882 .41746 L .50161 .41709 L F
.50061 .41904 m .49811 .41981 L .49882 .41746 L F
.556 .221 .356 r
.40576 .48464 m .40922 .48219 L .40616 .48271 L F
.824 .577 .565 r
.4148 .52292 m .41064 .51965 L .4133 .51923 L F
.4148 .52292 m .41061 .5226 L .41064 .51965 L F
.733 .647 .764 r
.4175 .51958 m .4148 .52292 L .4133 .51923 L F
.277 0 0 r
.46558 .44608 m .46817 .4466 L .46593 .44666 L F
.32 0 .09 r
.46898 .44502 m .46817 .4466 L .46558 .44608 L F
.531 .207 .364 r
.43753 .46457 m .44045 .46428 L .4411 .4621 L F
.247 0 .252 r
.4411 .4621 m .44045 .46428 L .44343 .46112 L F
.949 .837 .699 r
.43549 .52547 m .43771 .52392 L .43635 .52293 L F
.208 .224 .657 r
.40992 .56431 m .4121 .56281 L .41139 .56323 L F
.289 .494 .884 r
.40992 .56431 m .41124 .56384 L .41091 .56521 L F
.552 .768 .978 r
.41091 .56521 m .41367 .56252 L .41546 .56122 L F
.41367 .56252 m .41397 .56222 L .41408 .56215 L F
.41367 .56252 m .41408 .56215 L .41546 .56122 L F
.41091 .56521 m .41124 .56384 L .41234 .56286 L F
.41091 .56521 m .41234 .56286 L .41367 .56252 L F
.208 .224 .657 r
.41124 .56384 m .4122 .56721 L .41212 .56353 L F
.40992 .56431 m .41032 .56483 L .41124 .56384 L F
.41032 .56483 m .4122 .56721 L .41124 .56384 L F
.552 .768 .978 r
.41124 .56384 m .41206 .56297 L .41234 .56286 L F
.208 .224 .657 r
.40992 .56431 m .41212 .56353 L .4121 .56281 L F
.552 .768 .978 r
.41124 .56384 m .41139 .56323 L .41206 .56297 L F
.41367 .56252 m .41234 .56286 L .41397 .56222 L F
.546 .504 .76 r
.41213 .5639 m .41268 .56341 L .41219 .5629 L F
.503 .494 .78 r
.4121 .56281 m .41397 .56222 L .41139 .56323 L F
.546 .504 .76 r
.41211 .56292 m .41219 .5629 L .4121 .56281 L F
.41213 .5639 m .41219 .5629 L .41211 .56292 L F
.4122 .56721 m .41521 .56602 L .41268 .56341 L F
.4122 .56721 m .41268 .56341 L .41213 .5639 L F
.289 .494 .884 r
.40992 .56431 m .41139 .56323 L .41124 .56384 L F
.772 .422 .393 r
.56399 .37601 m .56723 .37756 L .56802 .37635 L F
.446 .147 .363 r
.56723 .37756 m .57095 .37556 L .56802 .37635 L F
.9 .705 .629 r
.40451 .55938 m .40831 .55746 L .40681 .55637 L F
.40451 .55938 m .40816 .56117 L .40831 .55746 L F
.881 .93 .849 r
.40952 .55308 m .40831 .55746 L .41131 .55431 L F
.40952 .55308 m .40681 .55637 L .40831 .55746 L F
.341 .031 .285 r
.44656 .45799 m .44922 .45722 L .44938 .45451 L F
.096 0 .112 r
.44938 .45451 m .45193 .4538 L .45307 .451 L F
.177 0 .252 r
.44938 .45451 m .45133 .45607 L .45193 .4538 L F
.44938 .45451 m .44922 .45722 L .45133 .45607 L F
.862 .901 .86 r
.51049 .45501 m .51183 .45037 L .50895 .45368 L F
.51049 .45501 m .51342 .45168 L .51183 .45037 L F
.52 .328 .561 r
.41069 .50256 m .40758 .50591 L .40744 .50345 L F
.329 0 0 r
.3919 .48821 m .39476 .4878 L .39636 .48594 L F
.466 0 .05 r
.39636 .48594 m .39476 .4878 L .39869 .4873 L F
.43 .044 .204 r
.39636 .48594 m .39869 .4873 L .39903 .4856 L F
.657 .183 .116 r
.53126 .37479 m .53386 .37556 L .53189 .37345 L F
.425 .197 .462 r
.53189 .37345 m .53386 .37556 L .53454 .37237 L F
.691 .845 .957 r
.61722 .39284 m .62128 .39265 L .62032 .39013 L F
.603 .672 .888 r
.62128 .39265 m .62295 .38877 L .62032 .39013 L F
.62128 .39265 m .623 .39195 L .62295 .38877 L F
.424 .848 .697 r
.60307 .38348 m .60248 .38414 L .60123 .38213 L F
.60307 .38348 m .60069 .38494 L .60248 .38414 L F
0 0 .025 r
.52631 .43071 m .52681 .43158 L .52811 .42925 L F
.52631 .43071 m .52593 .43331 L .52681 .43158 L F
.74 .475 .529 r
.51957 .39705 m .5195 .39977 L .51532 .39928 L F
.522 .17 .313 r
.5234 .39742 m .5195 .39977 L .51957 .39705 L F
.82 .891 .894 r
.36916 .55536 m .36494 .55708 L .36664 .55565 L F
.869 .9 .852 r
.36916 .55536 m .37021 .5521 L .37193 .55427 L F
.36916 .55536 m .36664 .55565 L .37021 .5521 L F
.836 .922 .891 r
.40079 .54235 m .39893 .54449 L .39868 .54176 L F
.957 .949 .678 r
.39893 .54449 m .39685 .54568 L .39868 .54176 L F
.489 .291 .537 r
.46408 .43792 m .4668 .43727 L .46683 .43447 L F
.469 .239 .481 r
.46408 .43792 m .46431 .44045 L .4668 .43727 L F
.781 .654 .722 r
.48925 .44429 m .4917 .44022 L .48975 .44139 L F
.793 .534 .545 r
.57424 .37288 m .57756 .37613 L .57795 .37306 L F
.799 .903 .499 r
.55149 .41702 m .54947 .42097 L .55022 .41839 L F
0 0 .437 r
.54978 .41381 m .55149 .41702 L .55125 .41622 L F
.876 .901 .486 r
.55125 .41622 m .55149 .41702 L .55022 .41839 L F
.808 .456 .391 r
.55726 .37554 m .55302 .37545 L .55262 .3727 L F
.809 .753 .801 r
.55437 .3799 m .55726 .37554 L .55761 .37926 L F
.55437 .3799 m .55302 .37545 L .55726 .37554 L F
0 0 .052 r
.5577 .37146 m .55726 .37554 L .55946 .37539 L F
.832 .473 .375 r
.55502 .37286 m .55771 .37478 L .55761 .37461 L F
.535 .308 .517 r
.55946 .37539 m .55726 .37554 L .55761 .37461 L F
.832 .473 .375 r
.55771 .37478 m .55907 .37575 L .55761 .37461 L F
0 0 .052 r
.5574 .37424 m .55761 .37461 L .55726 .37554 L F
.5577 .37146 m .55761 .37461 L .5574 .37424 L F
.535 .308 .517 r
.55946 .37539 m .55761 .37926 L .55726 .37554 L F
.175 0 0 r
.37182 .54464 m .37616 .54322 L .37516 .54495 L F
0 0 0 r
.45514 .44997 m .45835 .4473 L .45571 .44814 L F
.146 0 .217 r
.50275 .40374 m .50455 .40507 L .50508 .40206 L F
.07 0 0 r
.40646 .56171 m .4044 .56271 L .40125 .56326 L F
.989 .792 .55 r
.40451 .55938 m .40646 .56171 L .40816 .56117 L F
.40451 .55938 m .4044 .56271 L .40646 .56171 L F
.641 .29 .361 r
.48315 .44941 m .48688 .4477 L .48411 .44836 L F
.743 .957 .942 r
.51364 .44306 m .51181 .44481 L .51267 .44225 L F
.813 1 .805 r
.51267 .44225 m .51181 .44481 L .51098 .44441 L F
.33 .795 .934 r
.51319 .44463 m .51181 .44481 L .51364 .44306 L F
.87 .784 .763 r
.57784 .37839 m .57823 .38247 L .57961 .37998 L F
.709 .67 .81 r
.40509 .52962 m .40669 .53354 L .40226 .53316 L F
.728 .586 .697 r
.40669 .53354 m .40443 .53716 L .40226 .53316 L F
.626 .308 .411 r
.36587 .48885 m .36357 .48946 L .36826 .48895 L F
.467 .516 .825 r
.59722 .35444 m .59914 .35816 L .59643 .35795 L F
.59752 .3546 m .59914 .35816 L .59722 .35444 L F
.636 .367 .494 r
.59757 .35322 m .59822 .35527 L .60145 .35207 L F
.296 .187 .557 r
.60081 .35437 m .59914 .35816 L .59729 .3541 L F
.59963 .35704 m .60128 .35758 L .59914 .35816 L F
.60081 .35437 m .60116 .35675 L .59963 .35704 L F
.60116 .35675 m .60128 .35758 L .59963 .35704 L F
.51 .456 .732 r
.60311 .3524 m .60152 .35646 L .60081 .35437 L F
.466 .417 .719 r
.60142 .35671 m .60276 .35638 L .60311 .3524 L F
.51 .456 .732 r
.60276 .35638 m .60383 .35775 L .60265 .35767 L F
.60311 .3524 m .60361 .35616 L .60276 .35638 L F
.60361 .35616 m .60383 .35775 L .60276 .35638 L F
.6016 .35669 m .60265 .35767 L .60128 .35758 L F
.60311 .3524 m .60276 .35638 L .6016 .35669 L F
.60276 .35638 m .60265 .35767 L .6016 .35669 L F
.466 .417 .719 r
.60385 .35611 m .60476 .35589 L .60311 .3524 L F
.319 .314 .697 r
.6041 .35735 m .60383 .35775 L .60311 .3524 L F
.736 .46 .511 r
.60396 .35622 m .60452 .35599 L .60168 .35665 L F
.60452 .35599 m .60476 .35589 L .60385 .35611 L F
.60452 .35599 m .60385 .35611 L .60168 .35665 L F
.282 .319 .723 r
.60311 .3524 m .60476 .35589 L .60615 .35435 L F
.134 .282 .751 r
.60476 .35589 m .60538 .35604 L .60615 .35435 L F
.275 .316 .723 r
.60509 .35667 m .60536 .35943 L .60434 .35831 L F
.60615 .35435 m .60575 .35693 L .60538 .35604 L F
.475 .249 .491 r
.61009 .35866 m .60947 .36174 L .60746 .36145 L F
.535 .304 .511 r
.61009 .35866 m .60947 .36174 L .61226 .3579 L F
.371 0 0 r
.60714 .35898 m .61143 .36025 L .60851 .36077 L F
.134 .282 .751 r
.60596 .35743 m .60721 .35904 L .60617 .35733 L F
.60575 .35693 m .60617 .35733 L .60538 .35604 L F
.60596 .35743 m .60617 .35733 L .60575 .35693 L F
.736 .46 .511 r
.60587 .35744 m .60721 .35904 L .60596 .35743 L F
.275 .316 .723 r
.60571 .35721 m .60684 .35884 L .60536 .35943 L F
.60571 .35721 m .60536 .35943 L .60509 .35667 L F
.134 .282 .751 r
.60476 .35589 m .60596 .35743 L .60538 .35604 L F
.736 .46 .511 r
.60452 .35599 m .60596 .35743 L .60476 .35589 L F
.319 .314 .697 r
.60476 .35639 m .6041 .35735 L .60452 .35599 L F
.736 .46 .511 r
.60437 .35605 m .60476 .35639 L .60452 .35599 L F
.60476 .35639 m .60596 .35743 L .60452 .35599 L F
.319 .314 .697 r
.60452 .35599 m .6041 .35735 L .60385 .35611 L F
.60511 .35588 m .60476 .35639 L .60452 .35599 L F
.275 .316 .723 r
.60615 .35435 m .60434 .35831 L .60383 .35775 L F
.442 .596 .909 r
.60128 .35758 m .59976 .36035 L .59914 .35816 L F
.60128 .35758 m .60381 .36082 L .59976 .36035 L F
.29 .502 .89 r
.60536 .35943 m .60381 .36082 L .60128 .35758 L F
.352 .556 .911 r
.60536 .35943 m .60684 .35884 L .60558 .36115 L F
.736 .46 .511 r
.60696 .35902 m .60721 .35904 L .60587 .35744 L F
.352 .556 .911 r
.60684 .35884 m .60699 .35878 L .60692 .35889 L F
.60684 .35884 m .60692 .35889 L .60558 .36115 L F
.15 0 0 r
.60381 .36082 m .60558 .36115 L .60746 .36145 L F
.461 .696 .969 r
.60692 .35889 m .60851 .36077 L .60558 .36115 L F
.60699 .35878 m .60711 .35894 L .60692 .35889 L F
.60711 .35894 m .60851 .36077 L .60692 .35889 L F
.501 .493 .78 r
.60383 .35775 m .60536 .35943 L .60128 .35758 L F
.736 .46 .511 r
.59897 .35825 m .60696 .35902 L .60686 .35887 L F
.60673 .35883 m .60686 .35887 L .60684 .35884 L F
.59897 .35825 m .60686 .35887 L .60673 .35883 L F
.60466 .35758 m .60684 .35884 L .60587 .35744 L F
.59897 .35825 m .60684 .35884 L .60466 .35758 L F
.275 .316 .723 r
.60575 .35693 m .60699 .35878 L .60684 .35884 L F
.60575 .35693 m .60684 .35884 L .60571 .35721 L F
.60615 .35435 m .60683 .35797 L .60575 .35693 L F
.178 .243 .693 r
.60862 .35629 m .6074 .35815 L .60615 .35435 L F
.134 .282 .751 r
.60715 .35894 m .60718 .35886 L .60675 .35638 L F
.178 .243 .693 r
.6074 .35815 m .60683 .35797 L .60615 .35435 L F
.134 .282 .751 r
.60538 .35604 m .60556 .35635 L .60675 .35638 L F
.60556 .35635 m .60649 .35786 L .60675 .35638 L F
.60649 .35786 m .60696 .35801 L .60675 .35638 L F
.60706 .35878 m .60713 .35882 L .60675 .35638 L F
.60649 .35786 m .60706 .35878 L .60696 .35801 L F
.275 .316 .723 r
.60683 .35797 m .60699 .35878 L .60575 .35693 L F
.51 .456 .732 r
.6016 .35669 m .60128 .35758 L .60116 .35675 L F
.736 .46 .511 r
.59897 .35825 m .60596 .35743 L .60437 .35605 L F
.61 .944 .94 r
.60704 .35804 m .60468 .35784 L .60675 .35638 L F
.185 .633 .942 r
.60468 .35784 m .60829 .35642 L .60675 .35638 L F
.60829 .35642 m .60862 .35629 L .60675 .35638 L F
.134 .282 .751 r
.60706 .35878 m .60715 .35894 L .60713 .35882 L F
.371 0 0 r
.60719 .35885 m .61143 .36025 L .60714 .35898 L F
.134 .282 .751 r
.60715 .35894 m .60721 .35904 L .60718 .35886 L F
.371 0 0 r
.60719 .35885 m .61012 .36011 L .61143 .36025 L F
.60699 .35878 m .6076 .35904 L .60719 .35885 L F
.6076 .35904 m .61012 .36011 L .60719 .35885 L F
.985 .726 .452 r
.60862 .35629 m .61012 .36011 L .60712 .35884 L F
.60709 .35862 m .60712 .35884 L .60699 .35878 L F
.61 .944 .94 r
.60721 .35904 m .60715 .35901 L .60704 .35804 L F
.985 .726 .452 r
.60862 .35629 m .60712 .35884 L .60709 .35862 L F
.371 0 0 r
.60699 .35878 m .60719 .35885 L .60714 .35898 L F
.61 .944 .94 r
.60715 .35901 m .60712 .35899 L .60709 .35862 L F
.60715 .35901 m .60709 .35862 L .60704 .35804 L F
.178 .243 .693 r
.60704 .35804 m .60699 .35878 L .60683 .35797 L F
.60709 .35862 m .60699 .35878 L .60704 .35804 L F
.61 .944 .94 r
.60712 .35899 m .60468 .35784 L .60704 .35804 L F
.178 .243 .693 r
.6074 .35815 m .60709 .35862 L .60704 .35804 L F
.275 .316 .723 r
.60538 .35604 m .60571 .35721 L .60509 .35667 L F
.60575 .35693 m .60571 .35721 L .60538 .35604 L F
.134 .282 .751 r
.60538 .35604 m .60675 .35638 L .60615 .35435 L F
.319 .314 .697 r
.60615 .35435 m .60511 .35588 L .60311 .3524 L F
.60511 .35588 m .60385 .35611 L .60311 .3524 L F
.466 .417 .719 r
.60276 .35638 m .60385 .35611 L .60311 .3524 L F
.736 .46 .511 r
.60339 .35645 m .60396 .35622 L .60161 .35668 L F
.6016 .35669 m .60161 .35668 L .60158 .35669 L F
.60339 .35645 m .60161 .35668 L .6016 .35669 L F
.59897 .35825 m .60339 .35645 L .60142 .35673 L F
.60114 .35681 m .60142 .35673 L .6012 .35677 L F
.59897 .35825 m .60142 .35673 L .60114 .35681 L F
.51 .456 .732 r
.6016 .35669 m .60116 .35675 L .60081 .35437 L F
.466 .417 .719 r
.6012 .35677 m .60142 .35671 L .60311 .3524 L F
.51 .456 .732 r
.60311 .3524 m .6016 .35669 L .60152 .35646 L F
.736 .46 .511 r
.60339 .35645 m .60158 .35669 L .6012 .35677 L F
.60396 .35622 m .60168 .35665 L .6012 .35677 L F
.597 .471 .679 r
.59682 .35595 m .6012 .35677 L .6012 .35654 L F
.661 .71 .884 r
.60122 .35297 m .60081 .35437 L .59729 .3541 L F
.334 .362 .742 r
.60311 .3524 m .60081 .35437 L .60122 .35297 L F
.597 .471 .679 r
.59825 .35498 m .6012 .35654 L .60122 .35297 L F
.59682 .35595 m .6012 .35654 L .59825 .35498 L F
.467 .516 .825 r
.59729 .3541 m .59752 .3546 L .59722 .35444 L F
.902 .898 .813 r
.61961 .35241 m .61685 .35642 L .61545 .35471 L F
.426 .73 .989 r
.61685 .35642 m .61787 .35445 L .61545 .35471 L F
.61685 .35642 m .6201 .35632 L .61787 .35445 L F
.842 .966 .883 r
.54857 .39906 m .55168 .39893 L .54775 .4025 L F
.643 .956 .934 r
.55117 .39813 m .55168 .39893 L .54857 .39906 L F
.924 .934 .572 r
.55117 .39813 m .55191 .40031 L .55168 .39893 L F
.91 .969 .662 r
.55401 .39646 m .55191 .40031 L .55117 .39813 L F
.918 .874 .778 r
.62522 .36261 m .62146 .36465 L .6235 .36101 L F
.795 .847 .89 r
.62839 .35946 m .62522 .36261 L .6235 .36101 L F
.902 .898 .813 r
.61961 .35241 m .61545 .35471 L .61893 .35168 L F
.563 .794 .986 r
.62123 .34989 m .6231 .35139 L .61961 .35241 L F
.708 .978 .911 r
.61961 .35241 m .61893 .35168 L .62123 .34989 L F
.317 .043 .331 r
.4668 .43727 m .46975 .43407 L .46683 .43447 L F
0 0 0 r
.53934 .42948 m .54131 .42807 L .54177 .42833 L F
.54177 .42833 m .54131 .42807 L .54477 .42716 L F
.54131 .42807 m .54632 .42626 L .54477 .42716 L F
0 0 .334 r
.59006 .39329 m .59087 .39396 L .59004 .39133 L F
.59006 .39329 m .59084 .39604 L .59087 .39396 L F
.655 .824 .965 r
.36223 .558 m .35801 .5576 L .36053 .55639 L F
.614 .8 .971 r
.36494 .55708 m .36223 .558 L .36053 .55639 L F
.196 .348 .791 r
.50998 .41177 m .50857 .41396 L .50699 .4099 L F
.623 .845 .462 r
.50734 .41546 m .50857 .41396 L .50998 .41177 L F
.748 .451 .481 r
.40485 .50629 m .40305 .50844 L .40123 .50572 L F
.678 .398 .49 r
.40758 .50591 m .40305 .50844 L .40485 .50629 L F
0 0 .502 r
.59024 .40013 m .59226 .40104 L .5913 .39808 L F
.59024 .40013 m .59109 .4028 L .59226 .40104 L F
.369 .818 .943 r
.41413 .567 m .41664 .56656 L .41521 .56602 L F
.871 .875 .837 r
.42509 .53953 m .42699 .5403 L .4293 .53753 L F
.953 .74 .577 r
.42665 .54391 m .42699 .5403 L .42509 .53953 L F
.715 .896 .961 r
.49096 .46747 m .49544 .46692 L .49371 .46576 L F
.755 .894 .94 r
.49371 .46576 m .49544 .46692 L .49827 .46506 L F
.849 .73 .732 r
.54947 .42097 m .54419 .42235 L .54621 .42231 L F
.773 .975 .916 r
.55022 .41839 m .54947 .42097 L .54621 .42231 L F
.556 .934 .884 r
.54928 .42532 m .55334 .42407 L .55203 .42495 L F
0 0 0 r
.55334 .42407 m .556 .42062 L .5557 .42257 L F
.55203 .42495 m .55334 .42407 L .5557 .42257 L F
.445 .273 .553 r
.54004 .36272 m .54137 .36598 L .54279 .36462 L F
.725 .589 .703 r
.39422 .49933 m .39283 .50323 L .39002 .49828 L F
.902 .884 .806 r
.44678 .51177 m .45102 .50941 L .4494 .50804 L F
.44678 .51177 m .44851 .51304 L .45102 .50941 L F
.804 .895 .908 r
.4494 .50804 m .45102 .50941 L .45428 .50667 L F
.522 .17 .313 r
.5234 .39742 m .52243 .39936 L .5195 .39977 L F
.656 .558 .732 r
.52504 .39311 m .5234 .39742 L .52234 .39406 L F
.071 0 .101 r
.49117 .41449 m .49263 .41508 L .49334 .41335 L F
.49117 .41449 m .49041 .41642 L .49263 .41508 L F
.936 .902 .767 r
.43026 .53257 m .42804 .53647 L .4293 .53753 L F
.871 .875 .837 r
.42509 .53953 m .4293 .53753 L .42804 .53647 L F
.44 .868 .757 r
.46805 .44036 m .46948 .43929 L .47066 .43962 L F
.483 .393 .678 r
.47139 .44362 m .46805 .44036 L .47066 .43962 L F
.47139 .44362 m .46898 .44502 L .46805 .44036 L F
.83 .934 .898 r
.51342 .45168 m .51386 .44843 L .51183 .45037 L F
.51342 .45168 m .51658 .44879 L .51386 .44843 L F
.495 .177 .356 r
.41862 .4783 m .42176 .47797 L .42246 .47509 L F
.242 0 .046 r
.42176 .47797 m .42542 .47506 L .42246 .47509 L F
.784 .667 .735 r
.57467 .36233 m .57621 .36608 L .5793 .36275 L F
.821 .782 .816 r
.55066 .37955 m .55256 .38154 L .55437 .3799 L F
.873 .916 .855 r
.47637 .48139 m .47819 .48264 L .48067 .47973 L F
.363 .068 .324 r
.42848 .47191 m .43122 .47113 L .43164 .46891 L F
.135 0 .246 r
.43164 .46891 m .43328 .46998 L .43432 .46825 L F
.43164 .46891 m .43122 .47113 L .43328 .46998 L F
.522 .449 .715 r
.61129 .38012 m .61325 .37493 L .61016 .37605 L F
.61129 .38012 m .61441 .37928 L .61325 .37493 L F
0 0 0 r
.556 .42062 m .55832 .41676 L .5577 .41873 L F
.5577 .41873 m .55832 .41676 L .55852 .41618 L F
.699 .524 .647 r
.59813 .34894 m .60145 .35207 L .60011 .34766 L F
.59813 .34894 m .59757 .35322 L .60145 .35207 L F
.641 .335 .438 r
.55262 .3727 m .54861 .37533 L .54831 .37215 L F
.55262 .3727 m .55302 .37545 L .54861 .37533 L F
.999 .808 .515 r
.49367 .45023 m .4953 .4514 L .49524 .44817 L F
.49524 .44817 m .4953 .4514 L .49367 .45023 L F
.611 .565 .778 r
.49524 .44817 m .4982 .45003 L .4953 .4514 L F
0 0 0 r
.5557 .42257 m .556 .42062 L .5577 .41873 L F
.118 0 0 r
.59109 .4028 m .59501 .40313 L .59424 .40314 L F
.537 .925 .875 r
.59664 .40155 m .59501 .40313 L .59742 .40179 L F
.539 .921 .796 r
.59424 .40314 m .59501 .40313 L .59664 .40155 L F
.999 .808 .515 r
.49367 .45023 m .49524 .44817 L .49531 .4479 L F
.611 .565 .778 r
.49524 .44817 m .5012 .45041 L .4982 .45003 L F
.886 .854 .805 r
.44678 .51177 m .44682 .51633 L .44851 .51304 L F
.44678 .51177 m .44417 .51526 L .44682 .51633 L F
.774 .746 .827 r
.37005 .55093 m .37193 .55427 L .37021 .5521 L F
.567 .654 .894 r
.37458 .55358 m .37193 .55427 L .37005 .55093 L F
0 0 0 r
.51969 .39192 m .52462 .39046 L .5208 .38975 L F
.593 .379 .56 r
.52242 .39165 m .52283 .39121 L .52235 .39127 L F
0 0 0 r
.52162 .39135 m .52235 .39127 L .52462 .39046 L F
.604 .937 .739 r
.52462 .39046 m .52235 .39127 L .52477 .38916 L F
.593 .379 .56 r
.52283 .39121 m .52477 .38916 L .52235 .39127 L F
0 0 0 r
.51969 .39192 m .52235 .39127 L .52162 .39135 L F
.604 .937 .739 r
.52462 .39046 m .52477 .38916 L .52564 .38791 L F
.453 .142 .347 r
.39499 .50241 m .39207 .50517 L .39283 .50323 L F
.547 .104 .148 r
.3822 .48879 m .38461 .49051 L .38672 .48824 L F
.435 0 0 r
.38461 .49051 m .38921 .48873 L .38672 .48824 L F
.354 0 .134 r
.36116 .49121 m .36378 .49092 L .36357 .48946 L F
.417 0 .018 r
.36378 .49092 m .36826 .48895 L .36357 .48946 L F
.814 .613 .631 r
.40226 .53316 m .40443 .53716 L .40039 .53633 L F
.854 .635 .606 r
.40334 .53939 m .40039 .53633 L .40443 .53716 L F
0 0 0 r
.53288 .38206 m .53071 .38448 L .52931 .38242 L F
.521 .761 .984 r
.41131 .55431 m .41225 .55214 L .40952 .55308 L F
.41131 .55431 m .41383 .55393 L .41225 .55214 L F
0 0 0 r
.53288 .38206 m .53193 .38423 L .53071 .38448 L F
.53193 .38423 m .52918 .38757 L .53071 .38448 L F
.574 .089 .066 r
.37105 .49044 m .3732 .491 L .37534 .48923 L F
.603 .124 .09 r
.37534 .48923 m .3732 .491 L .37778 .49114 L F
.844 .826 .831 r
.40121 .52941 m .40226 .53316 L .40003 .53179 L F
.823 .626 .636 r
.40226 .53316 m .39775 .53555 L .40003 .53179 L F
.40226 .53316 m .40039 .53633 L .39775 .53555 L F
.785 .796 .861 r
.40509 .52962 m .40226 .53316 L .40121 .52941 L F
.563 .163 .242 r
.41536 .48069 m .41834 .48079 L .41589 .47892 L F
.476 .208 .427 r
.41589 .47892 m .41834 .48079 L .41862 .4783 L F
.385 .002 .183 r
.41243 .48121 m .41536 .48069 L .41589 .47892 L F
0 0 .331 r
.58962 .3665 m .59038 .36869 L .58928 .36444 L F
.427 .096 .3 r
.61022 .35707 m .61009 .35866 L .61226 .3579 L F
.739 .98 .915 r
.52524 .44394 m .52602 .44152 L .52433 .44331 L F
.52524 .44394 m .52885 .44155 L .52602 .44152 L F
.789 .765 .831 r
.54683 .41007 m .54768 .41232 L .54365 .41292 L F
.544 .077 .096 r
.54768 .41232 m .54621 .41355 L .54365 .41292 L F
.534 0 0 r
.54768 .41232 m .54942 .41415 L .54621 .41355 L F
.54768 .41232 m .54978 .41381 L .54942 .41415 L F
.509 .328 .571 r
.51779 .40522 m .51677 .40652 L .51406 .40701 L F
.313 .793 .908 r
.51406 .40701 m .51677 .40652 L .51536 .40618 L F
.987 .729 .445 r
.52243 .39936 m .52412 .40323 L .52227 .40202 L F
.985 .716 .424 r
.52227 .40202 m .52412 .40323 L .52233 .40512 L F
.043 .265 .761 r
.52501 .40127 m .52412 .40323 L .52243 .39936 L F
.707 .902 .536 r
.52233 .40512 m .52412 .40323 L .52501 .40127 L F
.695 .762 .903 r
.35383 .55692 m .35072 .55972 L .34912 .55604 L F
.977 .769 .351 r
.591 .3727 m .59077 .37644 L .59004 .37408 L F
.988 .771 .522 r
.59154 .37837 m .59004 .37408 L .59077 .37644 L F
.59115 .37725 m .58984 .37739 L .59004 .37408 L F
0 0 .329 r
.59119 .37766 m .59154 .37837 L .59077 .37644 L F
.751 .619 .052 r
.59111 .38006 m .59109 .38137 L .59107 .381 L F
.59119 .37766 m .59109 .38137 L .59111 .38006 L F
.59119 .37766 m .59107 .381 L .59154 .37837 L F
.988 .771 .522 r
.59154 .37837 m .59113 .37813 L .59115 .37725 L F
.59113 .37813 m .58984 .37739 L .59115 .37725 L F
.751 .619 .052 r
.59119 .37766 m .59117 .38322 L .59109 .38137 L F
0 0 0 r
.59117 .38322 m .59133 .38336 L .59107 .381 L F
.59117 .38322 m .59058 .38575 L .59133 .38336 L F
.756 .738 .835 r
.54575 .37764 m .54731 .38054 L .54314 .37938 L F
.789 .701 .768 r
.54731 .38054 m .54525 .38261 L .54314 .37938 L F
.578 .655 .889 r
.55066 .37955 m .54731 .38054 L .54575 .37764 L F
.471 .265 .517 r
.54703 .36259 m .54979 .3645 L .55068 .362 L F
.75 .79 .885 r
.60607 .37568 m .60662 .37878 L .61016 .37605 L F
.074 0 0 r
.48801 .41755 m .48714 .41896 L .49041 .41642 L F
.89 .956 .838 r
.38557 .55371 m .38702 .5493 L .3888 .55068 L F
.783 .983 .722 r
.38249 .54832 m .37987 .55189 L .37984 .54948 L F
.547 .505 .761 r
.37987 .55189 m .38075 .55066 L .37984 .54948 L F
.783 .983 .722 r
.38098 .55038 m .3808 .5506 L .37987 .55189 L F
.879 .978 .836 r
.38436 .55265 m .38321 .5534 L .37987 .55189 L F
.547 .505 .761 r
.38266 .55315 m .38289 .55303 L .38244 .55251 L F
.879 .978 .836 r
.38436 .55265 m .37987 .55189 L .38244 .55251 L F
.38361 .55273 m .38244 .55251 L .38342 .55275 L F
.38436 .55265 m .38244 .55251 L .38361 .55273 L F
.652 .528 .699 r
.37963 .55199 m .37999 .55213 L .37884 .55292 L F
.37999 .55213 m .38259 .55316 L .38022 .55301 L F
.37999 .55213 m .38022 .55301 L .37884 .55292 L F
.547 .505 .761 r
.37987 .55189 m .38266 .55315 L .38075 .55066 L F
.926 .696 .208 r
.37988 .55169 m .37997 .55205 L .37987 .55189 L F
.547 .505 .761 r
.3821 .55243 m .38244 .55251 L .37984 .54948 L F
.652 .528 .699 r
.3808 .5506 m .38244 .55251 L .37963 .55199 L F
.547 .505 .761 r
.38266 .55315 m .38244 .55251 L .3821 .55243 L F
.38266 .55315 m .38321 .5534 L .38289 .55303 L F
.652 .528 .699 r
.38244 .55251 m .38321 .5534 L .37963 .55199 L F
.879 .978 .836 r
.38342 .55275 m .38128 .55223 L .38062 .55305 L F
.38128 .55223 m .37987 .55189 L .38062 .55305 L F
.652 .528 .699 r
.37984 .54948 m .3808 .5506 L .37722 .55275 L F
.3808 .5506 m .37884 .55292 L .37722 .55275 L F
.783 .983 .722 r
.38238 .54839 m .37997 .54989 L .37987 .55189 L F
.926 .696 .208 r
.37997 .54989 m .38062 .55305 L .37997 .55205 L F
.652 .528 .699 r
.38259 .55316 m .38225 .5533 L .37884 .55292 L F
.496 .394 .669 r
.38321 .5534 m .3789 .55614 L .37722 .55275 L F
.926 .696 .208 r
.37997 .54989 m .3803 .55344 L .38062 .55305 L F
.3803 .55344 m .38032 .55364 L .38062 .55305 L F
.37997 .54989 m .37997 .55205 L .37988 .55169 L F
.89 .956 .838 r
.38595 .55255 m .38436 .55265 L .38702 .5493 L F
0 0 0 r
.38436 .55265 m .38565 .55122 L .38702 .5493 L F
.294 0 0 r
.38121 .55284 m .38565 .55122 L .3847 .55227 L F
.38371 .55269 m .3847 .55227 L .38436 .55265 L F
.38121 .55284 m .3847 .55227 L .38371 .55269 L F
.652 .528 .699 r
.38259 .55316 m .38321 .5534 L .38225 .5533 L F
.783 .983 .722 r
.38249 .54832 m .38238 .54839 L .3808 .5506 L F
.38249 .54832 m .3808 .5506 L .38098 .55038 L F
.294 0 0 r
.38062 .55305 m .38121 .55284 L .38352 .5527 L F
.38342 .55275 m .38352 .5527 L .38436 .55265 L F
.38062 .55305 m .38352 .5527 L .38342 .55275 L F
.89 .956 .838 r
.38557 .55371 m .38436 .55265 L .38595 .55255 L F
.417 0 .018 r
.36378 .49092 m .36648 .491 L .36826 .48895 L F
.519 .051 .083 r
.36826 .48895 m .36648 .491 L .37105 .49044 L F
.766 .394 .352 r
.36976 .49578 m .36979 .49801 L .36777 .49742 L F
.678 .398 .49 r
.40758 .50591 m .40785 .50887 L .40305 .50844 L F
.52 .328 .561 r
.41069 .50256 m .41035 .50543 L .40758 .50591 L F
.501 .269 .494 r
.41035 .50543 m .40785 .50887 L .40758 .50591 L F
0 0 0 r
.58877 .3591 m .59072 .35782 L .59163 .35646 L F
.273 0 0 r
.59163 .35646 m .59072 .35782 L .59451 .3565 L F
.198 .419 .85 r
.34603 .56343 m .34694 .56205 L .34385 .56006 L F
.131 .325 .791 r
.34603 .56343 m .34786 .56445 L .34694 .56205 L F
0 0 0 r
.52964 .38231 m .52974 .38225 L .53079 .3803 L F
.52964 .38231 m .52791 .38338 L .52974 .38225 L F
0 .213 .738 r
.62309 .36603 m .6255 .36806 L .625 .36654 L F
.591 .52 .743 r
.51532 .39928 m .51779 .40522 L .51316 .40371 L F
.083 0 0 r
.41546 .56122 m .41878 .56083 L .41913 .56044 L F
0 0 0 r
.41913 .56044 m .42064 .55897 L .42249 .55694 L F
.41913 .56044 m .41878 .56083 L .42064 .55897 L F
.45307 .451 m .45374 .4518 L .45514 .44997 L F
.45307 .451 m .45193 .4538 L .45374 .4518 L F
.793 .629 .678 r
.41035 .50543 m .41466 .506 L .41428 .50862 L F
.019 0 0 r
.38904 .56741 m .38729 .5675 L .38601 .56752 L F
0 .329 .705 r
.39146 .56951 m .38729 .5675 L .38904 .56741 L F
.375 .207 .522 r
.34751 .50109 m .34496 .499 L .34695 .49764 L F
.34751 .50109 m .3454 .50193 L .34496 .499 L F
.436 .133 .351 r
.51423 .3931 m .5171 .39246 L .51802 .38981 L F
.235 0 .009 r
.5171 .39246 m .5208 .38975 L .51802 .38981 L F
.256 .03 .367 r
.34087 .51494 m .3381 .51827 L .33724 .51595 L F
.873 .916 .855 r
.47637 .48139 m .48067 .47973 L .47885 .47857 L F
.711 .95 .954 r
.48255 .47786 m .47885 .47857 L .48067 .47973 L F
.62 .78 .958 r
.37055 .56749 m .37481 .56842 L .3732 .56678 L F
.426 .64 .945 r
.37481 .56842 m .37571 .56604 L .3732 .56678 L F
.37481 .56842 m .37698 .568 L .37571 .56604 L F
.764 .693 .784 r
.40936 .51597 m .41064 .51965 L .40638 .51922 L F
.701 .473 .575 r
.41064 .51965 m .40597 .52213 L .40638 .51922 L F
.41064 .51965 m .41061 .5226 L .40597 .52213 L F
.721 .281 .207 r
.42249 .55694 m .42064 .55897 L .423 .55832 L F
.833 .981 .879 r
.51721 .44048 m .51319 .44463 L .51364 .44306 L F
.515 .329 .566 r
.55127 .36595 m .55068 .362 L .54979 .3645 L F
.55127 .36595 m .55417 .36241 L .55068 .362 L F
.55127 .36595 m .55389 .36539 L .55417 .36241 L F
.722 .368 .377 r
.5498 .36719 m .55389 .36539 L .55127 .36595 L F
.578 .779 .974 r
.36367 .56762 m .36795 .56847 L .36627 .56652 L F
.637 .754 .933 r
.36627 .56652 m .36795 .56847 L .37055 .56749 L F
.643 .401 .537 r
.57095 .37556 m .57401 .37595 L .57424 .37288 L F
.793 .534 .545 r
.57424 .37288 m .57401 .37595 L .57756 .37613 L F
.731 .685 .806 r
.54525 .38261 m .54012 .38316 L .54314 .37938 L F
.641 .218 .224 r
.54627 .38399 m .54012 .38316 L .54525 .38261 L F
0 0 .539 r
.54525 .38261 m .54728 .38514 L .54627 .38399 L F
.556 .221 .356 r
.40576 .48464 m .4087 .48459 L .40922 .48219 L F
.438 .089 .274 r
.41143 .48388 m .40922 .48219 L .4087 .48459 L F
.41143 .48388 m .41243 .48121 L .40922 .48219 L F
.563 .399 .618 r
.48587 .42676 m .4857 .43033 L .48361 .43116 L F
0 0 0 r
.48886 .42533 m .48808 .4263 L .48587 .42676 L F
0 0 .414 r
.4878 .42824 m .48587 .42676 L .48808 .4263 L F
.4878 .42824 m .4857 .43033 L .48587 .42676 L F
.47 .21 .437 r
.42542 .47506 m .42817 .4745 L .42848 .47191 L F
.384 .139 .414 r
.42848 .47191 m .43074 .47364 L .43122 .47113 L F
.42848 .47191 m .42817 .4745 L .43074 .47364 L F
0 0 .403 r
.58877 .3591 m .59073 .35984 L .59072 .35782 L F
.58877 .3591 m .58882 .36186 L .59073 .35984 L F
.493 0 0 r
.55571 .3922 m .56005 .39265 L .55724 .39337 L F
.786 .824 .351 r
.34181 .50855 m .34156 .50965 L .34291 .50558 L F
0 0 0 r
.34217 .51024 m .34156 .50965 L .34181 .50855 L F
.34217 .51024 m .34071 .51211 L .34156 .50965 L F
.52 .818 .484 r
.54075 .41684 m .5379 .41991 L .5393 .4184 L F
.546 .923 .788 r
.5393 .4184 m .5379 .41991 L .53527 .42074 L F
.479 .727 .98 r
.5416 .41973 m .5379 .41991 L .54075 .41684 L F
.89 .714 .658 r
.40123 .50572 m .39875 .50524 L .3992 .50251 L F
.839 .494 .4 r
.40305 .50844 m .39875 .50524 L .40123 .50572 L F
.084 .345 .817 r
.56277 .38672 m .5641 .3851 L .56174 .38622 L F
.769 .749 .835 r
.51957 .40316 m .52082 .40645 L .51677 .40652 L F
.142 .685 .812 r
.51677 .40652 m .52082 .40645 L .51981 .40629 L F
.985 .716 .424 r
.52227 .40202 m .52082 .40645 L .51957 .40316 L F
.52227 .40202 m .52233 .40512 L .52082 .40645 L F
.492 .904 .884 r
.51981 .40629 m .52082 .40645 L .52233 .40512 L F
.622 .744 .934 r
.60966 .34175 m .61413 .34286 L .61266 .34097 L F
.761 .834 .907 r
.61266 .34097 m .61413 .34286 L .61654 .34135 L F
.977 .769 .351 r
.591 .3727 m .59004 .37408 L .59038 .37139 L F
.523 .313 .536 r
.4857 .43033 m .48587 .43243 L .48361 .43116 L F
.48361 .43116 m .48587 .43243 L .4857 .43033 L F
.836 .922 .891 r
.40079 .54235 m .39868 .54176 L .39963 .53933 L F
.835 .809 .825 r
.40334 .53939 m .40079 .54235 L .39963 .53933 L F
.412 0 0 r
.62391 .3553 m .62257 .35707 L .6201 .35632 L F
0 0 0 r
.62549 .35361 m .62391 .3553 L .62673 .35751 L F
.271 .463 .865 r
.62391 .3553 m .62673 .35751 L .62549 .35361 L F
0 0 0 r
.62549 .35361 m .62257 .35707 L .62391 .3553 L F
.62549 .35361 m .62257 .35707 L .62391 .3553 L F
.33977 .50273 m .34102 .50117 L .34166 .49894 L F
.34166 .49894 m .34102 .50117 L .34259 .50002 L F
.235 0 .009 r
.5171 .39246 m .51969 .39192 L .5208 .38975 L F
.808 .501 .47 r
.38562 .50156 m .382 .4985 L .38504 .49916 L F
.626 .438 .608 r
.38792 .49894 m .38562 .50156 L .38504 .49916 L F
.842 .93 .887 r
.51386 .44843 m .51658 .44879 L .51821 .44675 L F
.799 .997 .858 r
.52885 .44155 m .53058 .43964 L .52973 .43898 L F
.776 .983 .904 r
.52602 .44152 m .52885 .44155 L .52973 .43898 L F
0 .509 .77 r
.3975 .57017 m .39579 .56979 L .3972 .57319 L F
.702 .628 .771 r
.52684 .39144 m .52839 .39344 L .52504 .39311 L F
.794 .612 .654 r
.52839 .39344 m .52503 .39582 L .52504 .39311 L F
.52839 .39344 m .52928 .39647 L .52503 .39582 L F
.44 .536 .858 r
.53052 .39158 m .52839 .39344 L .52684 .39144 L F
.014 .013 .509 r
.53052 .39158 m .52928 .39647 L .52839 .39344 L F
.745 .268 .112 r
.60504 .39123 m .60618 .38984 L .60228 .38874 L F
.136 0 0 r
.6079 .39052 m .60618 .38984 L .60504 .39123 L F
.6079 .39052 m .60924 .38914 L .60618 .38984 L F
.793 .629 .678 r
.41035 .50543 m .41428 .50862 L .4097 .50843 L F
.785 .627 .685 r
.4097 .50843 m .41428 .50862 L .41178 .51226 L F
.929 .963 .769 r
.54645 .4066 m .54546 .40611 L .54775 .4025 L F
.984 .709 .339 r
.54645 .4066 m .54683 .41007 L .54546 .40611 L F
.768 .552 .604 r
.55417 .36241 m .55389 .36539 L .5583 .36578 L F
.84 .993 .848 r
.59993 .39846 m .60112 .39759 L .59894 .39776 L F
.646 .967 .89 r
.59894 .39776 m .60112 .39759 L .60343 .39595 L F
.586 .226 .324 r
.39869 .4873 m .40315 .48439 L .39903 .4856 L F
.39869 .4873 m .40151 .48744 L .40315 .48439 L F
.54 .181 .307 r
.40151 .48744 m .40576 .48464 L .40315 .48439 L F
.854 .635 .606 r
.40334 .53939 m .39963 .53933 L .40039 .53633 L F
.936 .781 .664 r
.55831 .40865 m .56034 .40971 L .55943 .40644 L F
.55878 .40719 m .55943 .40644 L .55924 .40576 L F
.55831 .40865 m .55943 .40644 L .55878 .40719 L F
.819 .966 .648 r
.56061 .4051 m .56243 .4028 L .562 .40258 L F
.55954 .40703 m .56175 .4038 L .56061 .4051 L F
.56175 .4038 m .56243 .4028 L .56061 .4051 L F
.9 .98 .801 r
.56243 .4028 m .56422 .39852 L .562 .40258 L F
.56243 .4028 m .56501 .39924 L .56422 .39852 L F
.607 .37 .531 r
.47139 .44362 m .46817 .4466 L .46898 .44502 L F
.682 .706 .866 r
.623 .39195 m .6256 .38797 L .62295 .38877 L F
.623 .39195 m .62771 .38985 L .6256 .38797 L F
0 0 .003 r
.33861 .50504 m .34102 .50117 L .33977 .50273 L F
.462 .026 .124 r
.37778 .49114 m .38073 .4912 L .3822 .48879 L F
.542 .109 .167 r
.3822 .48879 m .38073 .4912 L .38461 .49051 L F
.772 .422 .393 r
.56399 .37601 m .56432 .37835 L .56723 .37756 L F
.703 .295 .271 r
.56432 .37835 m .56683 .38068 L .56723 .37756 L F
.446 .147 .363 r
.56723 .37756 m .57107 .37772 L .57095 .37556 L F
.414 .045 .226 r
.56723 .37756 m .56932 .38014 L .57107 .37772 L F
.56723 .37756 m .56683 .38068 L .56932 .38014 L F
.823 .429 .304 r
.55389 .36539 m .55815 .3686 L .5583 .36578 L F
.779 .366 .266 r
.57401 .37595 m .57784 .37839 L .57756 .37613 L F
.804 .895 .908 r
.4494 .50804 m .45428 .50667 L .45116 .50658 L F
.723 .978 .918 r
.45613 .50468 m .45116 .50658 L .45428 .50667 L F
.795 .897 .915 r
.61364 .39455 m .61722 .39284 L .61585 .39126 L F
.764 .889 .933 r
.61585 .39126 m .61722 .39284 L .62032 .39013 L F
.53 .886 .66 r
.55126 .3833 m .55163 .38265 L .55009 .38313 L F
.72 .354 .356 r
.62726 .35193 m .62955 .35452 L .62922 .35229 L F
.706 .344 .359 r
.62922 .35229 m .62955 .35452 L .63379 .35471 L F
.493 0 0 r
.55946 .37539 m .56273 .37711 L .56399 .37601 L F
.941 .573 .238 r
.56273 .37711 m .56432 .37835 L .56399 .37601 L F
.599 .682 .9 r
.60592 .37243 m .60177 .37124 L .60474 .37033 L F
.564 .697 .93 r
.60767 .36956 m .60592 .37243 L .60474 .37033 L F
.60767 .36956 m .60872 .37174 L .60592 .37243 L F
.183 0 .173 r
.43753 .46457 m .43904 .46613 L .44045 .46428 L F
.43753 .46457 m .43674 .46722 L .43904 .46613 L F
.797 .749 .809 r
.42412 .54698 m .4245 .54224 L .42253 .54599 L F
.42412 .54698 m .42665 .54391 L .4245 .54224 L F
.973 .859 .665 r
.4231 .54972 m .42412 .54698 L .42253 .54599 L F
.873 .984 .834 r
.56422 .39852 m .56794 .39603 L .56743 .39569 L F
.56422 .39852 m .56501 .39924 L .56794 .39603 L F
.64 .966 .846 r
.56952 .39405 m .56794 .39603 L .57115 .39289 L F
.56952 .39405 m .56743 .39569 L .56794 .39603 L F
.667 .451 .583 r
.48116 .44046 m .48523 .44058 L .48547 .43749 L F
.775 .715 .796 r
.48547 .43749 m .48587 .43243 L .48386 .43425 L F
.48547 .43749 m .48835 .43454 L .48587 .43243 L F
.755 .894 .94 r
.49371 .46576 m .49827 .46506 L .4967 .46368 L F
.863 .909 .862 r
.4967 .46368 m .49827 .46506 L .50133 .46161 L F
0 0 .165 r
.4626 .45275 m .46278 .45381 L .46272 .4532 L F
.328 .004 .255 r
.46568 .45206 m .4626 .45275 L .46587 .45162 L F
.398 .818 .971 r
.39861 .56388 m .39774 .56311 L .39416 .56376 L F
.982 .867 .495 r
.39861 .56388 m .39702 .56607 L .39774 .56311 L F
.011 0 0 r
.39945 .56494 m .39861 .56388 L .40125 .56326 L F
.39945 .56494 m .39702 .56607 L .39861 .56388 L F
.718 .876 .955 r
.39117 .54908 m .3888 .55068 L .38702 .5493 L F
.336 0 .145 r
.48259 .43285 m .47985 .4362 L .47687 .43676 L F
0 0 0 r
.48171 .4347 m .47985 .4362 L .48259 .43285 L F
.812 .773 .817 r
.56493 .39084 m .56569 .38823 L .56761 .39004 L F
.87 .425 .092 r
.54058 .3848 m .53785 .38178 L .54012 .38316 L F
.732 .687 .807 r
.54314 .37938 m .54012 .38316 L .53878 .37842 L F
.641 .218 .224 r
.54627 .38399 m .54058 .3848 L .54012 .38316 L F
.778 .694 .771 r
.60011 .34766 m .60145 .35207 L .60421 .34859 L F
.552 .657 .906 r
.60474 .37033 m .60177 .37124 L .60028 .36777 L F
0 0 .297 r
.46119 .447 m .46192 .44257 L .4611 .44399 L F
.46119 .447 m .4631 .44552 L .46192 .44257 L F
0 0 0 r
.46192 .44257 m .46697 .44062 L .46431 .44045 L F
.46505 .44136 m .46537 .44167 L .46697 .44062 L F
.566 .926 .757 r
.46537 .44167 m .46687 .44027 L .46948 .43929 L F
.565 .405 .623 r
.46665 .44054 m .46753 .44346 L .46687 .44027 L F
0 0 0 r
.46336 .44506 m .46432 .44439 L .46537 .44167 L F
.572 .497 .732 r
.46432 .44439 m .46432 .44439 L .46486 .44358 L F
.46432 .44439 m .46537 .4475 L .46487 .44365 L F
.46537 .4475 m .46538 .44749 L .46487 .44365 L F
.46486 .44358 m .46538 .44753 L .46753 .44346 L F
.052 .166 .665 r
.46461 .44419 m .46537 .44749 L .46432 .44439 L F
.572 .497 .732 r
.46537 .4475 m .46538 .44753 L .46538 .44749 L F
.052 .166 .665 r
.46537 .44749 m .46538 .44753 L .46537 .4475 L F
.46537 .44749 m .46537 .4475 L .46432 .44439 L F
.478 .297 .556 r
.46817 .4466 m .46587 .45162 L .46593 .44666 L F
.46817 .4466 m .46846 .45052 L .46587 .45162 L F
0 0 .315 r
.46932 .44757 m .46846 .45052 L .46817 .4466 L F
.607 .37 .531 r
.47139 .44362 m .47109 .4464 L .46817 .4466 L F
0 0 .315 r
.46932 .44757 m .46817 .4466 L .47109 .4464 L F
.748 .717 .823 r
.46753 .44346 m .46538 .44753 L .46932 .44757 L F
.341 .791 .953 r
.46564 .44734 m .46869 .4471 L .46633 .44738 L F
.602 .439 .634 r
.45835 .4473 m .46119 .447 L .4611 .44399 L F
0 0 0 r
.45835 .4473 m .45947 .4479 L .46119 .447 L F
.057 0 0 r
.45947 .4479 m .4631 .44552 L .46119 .447 L F
.45947 .4479 m .46288 .44658 L .4631 .44552 L F
.46288 .44658 m .46301 .44652 L .46307 .44577 L F
.46288 .44658 m .46307 .44577 L .4631 .44552 L F
.557 .93 .919 r
.46288 .44658 m .46069 .44635 L .46301 .44652 L F
.45947 .4479 m .46069 .44635 L .46288 .44658 L F
.627 .072 0 r
.46069 .44635 m .46242 .44714 L .46273 .44718 L F
.46281 .44688 m .46273 .44718 L .46538 .44753 L F
.46069 .44635 m .46273 .44718 L .46281 .44688 L F
.767 .335 .225 r
.46069 .44635 m .46538 .44753 L .46301 .44652 L F
.72 .635 .763 r
.46301 .44652 m .46538 .44753 L .46461 .44419 L F
.341 .791 .953 r
.46242 .44714 m .46602 .44711 L .46564 .44734 L F
.46602 .44711 m .46869 .4471 L .46564 .44734 L F
.46242 .44714 m .46841 .44688 L .46868 .4471 L F
.46242 .44714 m .46932 .44757 L .46538 .44753 L F
.318 0 .215 r
.46242 .44714 m .46599 .44757 L .46841 .44688 L F
.852 .997 .817 r
.46841 .44688 m .46599 .44757 L .46743 .44613 L F
.915 .588 .115 r
.46753 .44346 m .46841 .44688 L .46932 .44757 L F
0 0 .41 r
.46753 .44346 m .46841 .44688 L .46864 .44492 L F
.852 .997 .817 r
.46841 .44688 m .46743 .44613 L .46864 .44492 L F
.341 .791 .953 r
.46868 .4471 m .46841 .44688 L .46869 .4471 L F
.46633 .44738 m .46869 .4471 L .46932 .44757 L F
0 0 0 r
.46432 .44439 m .46451 .44411 L .46537 .44167 L F
.572 .497 .732 r
.46432 .44439 m .46477 .44379 L .46473 .44378 L F
0 0 0 r
.46444 .4443 m .46471 .44384 L .46537 .44167 L F
.604 .22 .289 r
.46537 .44167 m .46473 .44378 L .46406 .44362 L F
.572 .497 .732 r
.46406 .44362 m .46432 .44439 L .46486 .44358 L F
0 0 0 r
.46444 .4443 m .46461 .44419 L .46471 .44384 L F
.604 .22 .289 r
.46473 .44378 m .46461 .44419 L .46406 .44362 L F
.572 .497 .732 r
.46473 .44378 m .46487 .44365 L .46486 .44358 L F
.46477 .44379 m .46487 .44365 L .46473 .44378 L F
0 0 0 r
.46424 .44451 m .46301 .44652 L .46461 .44419 L F
.4631 .44552 m .46304 .44613 L .46424 .44451 L F
.46304 .44613 m .46301 .44652 L .46424 .44451 L F
.46432 .44439 m .46444 .4443 L .46451 .44411 L F
.565 .405 .623 r
.46406 .44362 m .46486 .44358 L .46665 .44054 L F
.46486 .44358 m .46753 .44346 L .46665 .44054 L F
0 0 0 r
.4631 .44552 m .46461 .44419 L .46336 .44506 L F
.052 .166 .665 r
.46461 .44419 m .46432 .44439 L .46406 .44362 L F
.565 .405 .623 r
.46406 .44362 m .46555 .44185 L .46537 .44167 L F
.46555 .44185 m .46687 .44027 L .46537 .44167 L F
0 0 0 r
.46192 .44257 m .46537 .44167 L .46505 .44136 L F
.4631 .44552 m .46537 .44167 L .46192 .44257 L F
.925 .575 .349 r
.63379 .35471 m .63436 .35724 L .63629 .35717 L F
.836 .445 .309 r
.63438 .35965 m .63629 .35717 L .63436 .35724 L F
.63438 .35965 m .63807 .36093 L .63629 .35717 L F
.498 .239 .452 r
.47511 .42962 m .47813 .42679 L .47575 .42772 L F
.319 0 0 r
.52928 .39647 m .52731 .39659 L .52535 .39587 L F
.014 .013 .509 r
.5293 .39638 m .53104 .39528 L .52928 .39647 L F
.53052 .39158 m .53104 .39528 L .5293 .39638 L F
.467 .332 .614 r
.53352 .39403 m .53104 .39528 L .53052 .39158 L F
.238 0 0 r
.53352 .39403 m .53204 .39465 L .53104 .39528 L F
.53204 .39465 m .52923 .39582 L .53104 .39528 L F
.435 .875 .848 r
.53104 .39528 m .52731 .39659 L .52928 .39647 L F
.275 .768 .707 r
.53104 .39528 m .52923 .39582 L .52731 .39659 L F
.347 .276 .633 r
.52996 .39756 m .52731 .39659 L .52923 .39582 L F
.53093 .39986 m .52731 .39659 L .52996 .39756 L F
.319 0 0 r
.52535 .39587 m .52731 .39659 L .52503 .39582 L F
.699 .609 .752 r
.50498 .44808 m .50196 .45104 L .5019 .44911 L F
.886 .98 .822 r
.532 .43536 m .53202 .43802 L .5347 .43471 L F
.893 .989 .759 r
.52973 .43898 m .53202 .43802 L .532 .43536 L F
.52973 .43898 m .53058 .43964 L .53202 .43802 L F
.699 .928 .966 r
.60898 .39426 m .60778 .39675 L .61011 .39537 L F
.655 .88 .981 r
.60628 .39543 m .60778 .39675 L .60898 .39426 L F
0 0 0 r
.57354 .39079 m .57115 .39289 L .57429 .38983 L F
.433 .819 .583 r
.57301 .39147 m .57115 .39289 L .57354 .39079 L F
.57301 .39147 m .56952 .39405 L .57115 .39289 L F
.87 .784 .763 r
.57784 .37839 m .57546 .38163 L .57823 .38247 L F
.968 .693 .272 r
.57546 .38163 m .57689 .38607 L .57823 .38247 L F
.87 .924 .859 r
.46283 .49265 m .46278 .49594 L .46549 .49286 L F
.46283 .49265 m .46108 .4947 L .46278 .49594 L F
.937 .902 .765 r
.46108 .4947 m .46123 .49783 L .46278 .49594 L F
0 0 0 r
.45514 .44997 m .45713 .44947 L .45835 .4473 L F
.45514 .44997 m .45374 .4518 L .45713 .44947 L F
.242 0 .046 r
.42176 .47797 m .42451 .47717 L .42542 .47506 L F
.152 0 .011 r
.42542 .47506 m .42714 .47605 L .42817 .4745 L F
.42542 .47506 m .42451 .47717 L .42714 .47605 L F
0 0 .052 r
.5577 .37146 m .55946 .37539 L .55994 .37261 L F
.535 .308 .517 r
.55946 .37539 m .55761 .37461 L .55907 .37575 L F
0 .453 .781 r
.55907 .37575 m .56273 .37711 L .55946 .37539 L F
.718 .874 .954 r
.35491 .5662 m .35663 .56754 L .35934 .56605 L F
.81 .576 .585 r
.54861 .37533 m .54656 .37585 L .54831 .37215 L F
0 0 0 r
.54831 .37215 m .54656 .37585 L .54791 .37421 L F
.54831 .37215 m .54791 .37421 L .54704 .37068 L F
.629 .853 .475 r
.34564 .50324 m .34181 .50855 L .34291 .50558 L F
.623 .364 .504 r
.47687 .43676 m .47362 .43943 L .47421 .4378 L F
.674 .572 .732 r
.50508 .40206 m .50829 .40035 L .50833 .39958 L F
.279 0 .17 r
.50455 .40507 m .50829 .40035 L .50508 .40206 L F
.642 .944 .957 r
.53578 .41283 m .53776 .4106 L .53906 .41152 L F
.77 .365 .285 r
.53578 .41283 m .53968 .4169 L .53537 .41543 L F
.759 .244 0 r
.54075 .41684 m .53968 .4169 L .53578 .41283 L F
.268 .774 .78 r
.4179 .55296 m .41453 .55344 L .41383 .55393 L F
.412 .862 .833 r
.41911 .55211 m .4179 .55296 L .42084 .55331 L F
.41911 .55211 m .41453 .55344 L .4179 .55296 L F
.763 .334 .232 r
.62549 .35361 m .62955 .35452 L .62726 .35193 L F
.866 .996 .78 r
.53609 .43249 m .5347 .43471 L .53738 .43138 L F
.082 0 .081 r
.53934 .42948 m .53609 .43249 L .53738 .43138 L F
.802 .731 .786 r
.40688 .52406 m .40278 .52518 L .40597 .52213 L F
.40348 .52529 m .40278 .52518 L .40688 .52406 L F
.907 .801 .732 r
.40638 .51922 m .40278 .52518 L .40222 .52176 L F
.852 .711 .707 r
.40597 .52213 m .40278 .52518 L .40638 .51922 L F
.802 .731 .786 r
.40777 .52595 m .40353 .52553 L .40278 .52518 L F
.796 .735 .795 r
.40278 .52518 m .40353 .52553 L .40222 .52176 L F
.846 .758 .765 r
.40222 .52176 m .40345 .5253 L .40138 .52389 L F
.40345 .5253 m .40353 .52553 L .4033 .52535 L F
.40345 .5253 m .4033 .52535 L .40138 .52389 L F
.802 .731 .786 r
.40777 .52595 m .40348 .52529 L .40688 .52406 L F
.811 .699 .741 r
.40777 .52595 m .40509 .52962 L .40353 .52553 L F
.693 .603 .752 r
.41061 .5226 m .40777 .52595 L .40597 .52213 L F
.321 0 .217 r
.48386 .42241 m .48714 .41896 L .48472 .41961 L F
.435 0 0 r
.38461 .49051 m .38746 .49055 L .38921 .48873 L F
.48 .051 .147 r
.38746 .49055 m .3919 .48821 L .38921 .48873 L F
.729 .392 .41 r
.54627 .38399 m .54314 .38764 L .54058 .3848 L F
.741 .478 .532 r
.54728 .38514 m .54314 .38764 L .54627 .38399 L F
0 0 0 r
.53609 .43249 m .532 .43536 L .5347 .43471 L F
.394 0 .105 r
.50408 .41817 m .50061 .41904 L .50161 .41709 L F
.398 0 .076 r
.50483 .41677 m .50408 .41817 L .50161 .41709 L F
.404 .411 .754 r
.6143 .36752 m .61293 .37224 L .61151 .37051 L F
.764 .913 .94 r
.41664 .56656 m .41826 .56308 L .41521 .56602 L F
.41664 .56656 m .4201 .56397 L .41826 .56308 L F
.795 .847 .89 r
.62839 .35946 m .6235 .36101 L .62673 .35751 L F
.581 .406 .609 r
.47229 .43316 m .47511 .42962 L .47269 .43063 L F
.678 .956 .949 r
.47332 .44833 m .47165 .44774 L .47526 .44674 L F
.799 .913 .917 r
.62284 .36935 m .61984 .37201 L .61882 .37036 L F
.563 0 0 r
.63985 .36133 m .64012 .3618 L .63807 .36093 L F
.883 .937 .848 r
.48348 .47333 m .48804 .47092 L .48648 .46966 L F
.48348 .47333 m .48476 .47445 L .48804 .47092 L F
.833 .973 .886 r
.49096 .46747 m .48648 .46966 L .48804 .47092 L F
.395 .115 .366 r
.51398 .3956 m .5171 .39246 L .51423 .3931 L F
.71 .88 .96 r
.38015 .56838 m .38191 .5698 L .38601 .56752 L F
.52 .818 .484 r
.54075 .41684 m .5393 .4184 L .53968 .4169 L F
0 0 0 r
.54365 .41292 m .54279 .41516 L .54075 .41684 L F
.949 .604 .321 r
.5393 .4184 m .5416 .41973 L .54075 .41684 L F
.5393 .4184 m .54075 .41684 L .54279 .41516 L F
.873 .992 .81 r
.36042 .53642 m .35809 .53675 L .35954 .53591 L F
.656 .959 .935 r
.36042 .53642 m .35954 .53591 L .36127 .53457 L F
.527 .898 .708 r
.35954 .53591 m .35809 .53675 L .36127 .53457 L F
.699 .983 .861 r
.36127 .53457 m .35809 .53675 L .36042 .53642 L F
.953 .74 .577 r
.42665 .54391 m .42509 .53953 L .4245 .54224 L F
.453 .5 .817 r
.52918 .38757 m .53052 .39158 L .52684 .39144 L F
.119 0 0 r
.60433 .36541 m .60308 .36698 L .60028 .36777 L F
0 0 0 r
.60733 .36527 m .60308 .36698 L .60433 .36541 L F
.605 .485 .691 r
.60746 .36145 m .60733 .36527 L .60433 .36541 L F
.748 .895 .945 r
.47032 .45143 m .46568 .45206 L .46846 .45052 L F
.47032 .45143 m .46582 .45298 L .46568 .45206 L F
.625 .382 .529 r
.46846 .45052 m .47088 .449 L .47032 .45143 L F
.46846 .45052 m .46944 .45109 L .47088 .449 L F
.866 .968 .644 r
.47153 .44806 m .47032 .45143 L .47088 .449 L F
.625 .382 .529 r
.46944 .45109 m .47082 .45189 L .47088 .449 L F
.866 .968 .644 r
.47165 .44774 m .47153 .44806 L .47088 .449 L F
.863 .909 .862 r
.4967 .46368 m .50133 .46161 L .49911 .46001 L F
.81 .809 .85 r
.49911 .46001 m .50133 .46161 L .50401 .45859 L F
0 0 0 r
.45835 .4473 m .45713 .44947 L .45947 .4479 L F
.699 .609 .752 r
.50498 .44808 m .5019 .44911 L .50308 .44637 L F
.772 .714 .799 r
.38314 .54626 m .38019 .54631 L .38241 .54328 L F
.631 .184 .171 r
.38314 .54626 m .38249 .54832 L .38019 .54631 L F
.404 .408 .75 r
.38541 .54263 m .38314 .54626 L .38241 .54328 L F
.38541 .54263 m .38618 .54606 L .38314 .54626 L F
.361 0 .159 r
.38618 .54606 m .38249 .54832 L .38314 .54626 L F
0 0 0 r
.54632 .42626 m .54758 .42668 L .54477 .42716 L F
.692 .501 .624 r
.61441 .37928 m .61718 .3758 L .61325 .37493 L F
.61441 .37928 m .61716 .37857 L .61718 .3758 L F
.632 .536 .728 r
.61716 .37857 m .61973 .37476 L .61718 .3758 L F
.409 .133 .381 r
.44343 .46112 m .44612 .4604 L .44656 .45799 L F
.211 0 .313 r
.44656 .45799 m .44821 .45915 L .44922 .45722 L F
.44656 .45799 m .44612 .4604 L .44821 .45915 L F
.859 .928 .872 r
.46283 .49265 m .46549 .49286 L .46709 .49088 L F
.317 .043 .331 r
.4668 .43727 m .4691 .43677 L .46975 .43407 L F
.715 .557 .673 r
.4691 .43677 m .47229 .43316 L .46975 .43407 L F
.57 .755 .965 r
.53635 .36964 m .53454 .37237 L .53729 .37159 L F
.53635 .36964 m .53454 .37237 L .53729 .37159 L F
.753 .994 .824 r
.43697 .52116 m .43635 .52293 L .43778 .5218 L F
.799 .997 .786 r
.43994 .51793 m .43778 .5218 L .44141 .51898 L F
.43994 .51793 m .43697 .52116 L .43778 .5218 L F
.858 .67 .647 r
.5577 .37146 m .55994 .37261 L .55815 .3686 L F
.763 .448 .453 r
.37355 .54698 m .36877 .54903 L .37182 .54464 L F
.37355 .54698 m .37317 .54971 L .36877 .54903 L F
.192 0 .316 r
.37569 .54593 m .37317 .54971 L .37355 .54698 L F
.37569 .54593 m .37317 .54971 L .37355 .54698 L F
.681 .276 .271 r
.382 .4985 m .3791 .50062 L .37662 .49825 L F
.836 .515 .445 r
.382 .4985 m .38308 .50165 L .3791 .50062 L F
.808 .501 .47 r
.38562 .50156 m .38308 .50165 L .382 .4985 L F
.9 .965 .82 r
.62886 .38684 m .6298 .38587 L .62875 .38462 L F
.827 .972 .891 r
.6298 .38587 m .63193 .38186 L .62875 .38462 L F
.6298 .38587 m .63288 .38285 L .63193 .38186 L F
.706 .762 .895 r
.36323 .55516 m .36494 .55708 L .36053 .55639 L F
.726 .767 .885 r
.36664 .55565 m .36494 .55708 L .36323 .55516 L F
.905 .983 .775 r
.59742 .40179 m .59993 .39846 L .59894 .39776 L F
.943 .947 .754 r
.48348 .47333 m .48255 .47786 L .48476 .47445 L F
.869 .987 .716 r
.5745 .38791 m .57689 .38607 L .57579 .38481 L F
.5745 .38791 m .57429 .38983 L .57689 .38607 L F
.968 .693 .272 r
.57546 .38163 m .57579 .38481 L .57689 .38607 L F
.429 .092 .29 r
.41423 .48332 m .41243 .48121 L .41143 .48388 L F
.41423 .48332 m .41536 .48069 L .41243 .48121 L F
0 0 .235 r
.4878 .42824 m .48587 .43243 L .4857 .43033 L F
.887 .975 .673 r
.57409 .38797 m .57429 .38983 L .5745 .38791 L F
.57409 .38797 m .57354 .39079 L .57429 .38983 L F
.795 .897 .915 r
.61364 .39455 m .61585 .39126 L .61363 .39297 L F
.726 .274 0 r
.54978 .41381 m .55125 .41622 L .54942 .41415 L F
.667 .854 .971 r
.36053 .55639 m .35801 .5576 L .35625 .55623 L F
.124 0 .113 r
.51137 .39652 m .50833 .39958 L .51124 .39762 L F
.372 .039 .264 r
.51124 .39762 m .51398 .3956 L .51137 .39652 L F
.612 .531 .739 r
.51957 .40316 m .51532 .39928 L .5195 .39977 L F
.596 .358 .526 r
.5195 .39977 m .52227 .40202 L .51957 .40316 L F
.5195 .39977 m .52243 .39936 L .52227 .40202 L F
.008 0 0 r
.35897 .49271 m .36378 .49092 L .36116 .49121 L F
.566 .234 .366 r
.57107 .37772 m .57396 .37787 L .57095 .37556 L F
.602 .209 .27 r
.57095 .37556 m .57396 .37787 L .57401 .37595 L F
.641 .29 .361 r
.48315 .44941 m .48662 .44982 L .48688 .4477 L F
.671 .317 .365 r
.48688 .4477 m .49262 .44906 L .48908 .44653 L F
.48688 .4477 m .48662 .44982 L .49262 .44906 L F
.653 .738 .912 r
.36189 .56563 m .36367 .56762 L .36627 .56652 L F
.866 .788 .773 r
.62673 .35751 m .62257 .35707 L .62514 .35721 L F
.62673 .35751 m .6235 .36101 L .62257 .35707 L F
.405 .265 .576 r
.62673 .35751 m .62955 .35452 L .62549 .35361 L F
.62673 .35751 m .62767 .35826 L .62955 .35452 L F
0 .356 .692 r
.62514 .35721 m .62767 .35826 L .62673 .35751 L F
.711 .95 .954 r
.48255 .47786 m .48131 .47702 L .47885 .47857 L F
.943 .947 .754 r
.48348 .47333 m .48131 .47702 L .48255 .47786 L F
.75 .79 .885 r
.60607 .37568 m .61016 .37605 L .60907 .37363 L F
.715 .751 .88 r
.60907 .37363 m .61016 .37605 L .61325 .37493 L F
.60907 .37363 m .61016 .37605 L .61325 .37493 L F
.089 0 0 r
.50308 .44637 m .50705 .44595 L .50498 .44808 L F
0 0 .54 r
.5913 .39808 m .59087 .39396 L .59084 .39604 L F
.579 .627 .864 r
.61441 .37928 m .61866 .38233 L .61716 .37857 L F
.631 .581 .78 r
.61866 .38233 m .62102 .37928 L .61716 .37857 L F
.61866 .38233 m .62183 .38218 L .62102 .37928 L F
.603 .352 .509 r
.61866 .38233 m .62178 .38493 L .62183 .38218 L F
0 .138 .638 r
.62017 .38315 m .62178 .38493 L .61866 .38233 L F
.62017 .38315 m .61866 .38233 L .61732 .38312 L F
.842 .93 .887 r
.51386 .44843 m .51821 .44675 L .51739 .44628 L F
.712 .923 .963 r
.51821 .44675 m .51859 .44417 L .51739 .44628 L F
.51821 .44675 m .52196 .44489 L .51859 .44417 L F
.453 .142 .347 r
.39499 .50241 m .39463 .5047 L .39207 .50517 L F
.789 .613 .663 r
.3992 .50251 m .39463 .5047 L .39499 .50241 L F
.451 .253 .52 r
.41453 .55344 m .41225 .55214 L .41383 .55393 L F
0 0 0 r
.54429 .41366 m .54365 .41292 L .54621 .41355 L F
.54429 .41366 m .54279 .41516 L .54365 .41292 L F
.279 0 .17 r
.50455 .40507 m .50726 .4043 L .50829 .40035 L F
.154 0 .258 r
.50829 .40035 m .51124 .39762 L .50833 .39958 L F
.50829 .40035 m .51092 .40258 L .51124 .39762 L F
.151 0 .129 r
.50829 .40035 m .5096 .40307 L .51092 .40258 L F
.50829 .40035 m .50726 .4043 L .5096 .40307 L F
.496 .394 .669 r
.38321 .5534 m .38146 .55609 L .3789 .55614 L F
.388 .482 .835 r
.54601 .39275 m .54833 .39289 L .54803 .39025 L F
.54601 .39275 m .54833 .39289 L .54803 .39025 L F
.97 .699 .463 r
.37395 .54452 m .37569 .54593 L .37616 .54322 L F
.175 0 0 r
.37182 .54464 m .37395 .54452 L .37616 .54322 L F
.97 .699 .463 r
.37616 .54322 m .37569 .54593 L .37395 .54452 L F
.599 .921 .688 r
.37616 .54322 m .37719 .54173 L .37787 .54379 L F
.37616 .54322 m .37395 .54452 L .37719 .54173 L F
.427 .156 .398 r
.37616 .54322 m .37569 .54593 L .37787 .54379 L F
.226 .408 .834 r
.55524 .39152 m .55505 .39299 L .5508 .38984 L F
.55524 .39152 m .55571 .3922 L .55505 .39299 L F
.357 .667 .973 r
.59109 .4028 m .59424 .40314 L .59226 .40104 L F
.589 .735 .945 r
.39146 .56951 m .3955 .57111 L .39579 .56979 L F
.907 .801 .732 r
.40638 .51922 m .40222 .52176 L .40449 .5178 L F
.844 .854 .851 r
.40936 .51597 m .40638 .51922 L .40449 .5178 L F
.431 .122 .339 r
.41834 .48079 m .42176 .47797 L .41862 .4783 L F
.058 0 0 r
.48886 .42533 m .49094 .42539 L .48808 .4263 L F
.48886 .42533 m .49226 .42428 L .49094 .42539 L F
.76 .99 .888 r
.51635 .43983 m .51364 .44306 L .51267 .44225 L F
.51635 .43983 m .51721 .44048 L .51364 .44306 L F
0 .269 .687 r
.52898 .41746 m .5281 .41667 L .52526 .41571 L F
0 .379 .744 r
.52681 .41624 m .52898 .41746 L .52526 .41571 L F
.782 .946 .929 r
.53307 .4142 m .52898 .41746 L .52704 .41637 L F
.372 .333 .686 r
.52716 .41607 m .52526 .41571 L .52708 .41632 L F
.52789 .41394 m .52564 .41545 L .52716 .41607 L F
.52564 .41545 m .52526 .41571 L .52716 .41607 L F
.782 .946 .929 r
.53307 .4142 m .52704 .41637 L .52724 .4161 L F
.53307 .4142 m .52724 .4161 L .53146 .41567 L F
.52724 .4161 m .52704 .41637 L .52681 .41624 L F
.372 .333 .686 r
.52789 .41394 m .52708 .41632 L .52798 .41511 L F
.782 .946 .929 r
.52724 .4161 m .52681 .41624 L .52741 .41617 L F
.52724 .4161 m .52741 .41617 L .53146 .41567 L F
.538 .58 .845 r
.53001 .41797 m .53146 .41567 L .52741 .41617 L F
.372 .333 .686 r
.52798 .41511 m .52708 .41632 L .52725 .41638 L F
.538 .58 .845 r
.5272 .41645 m .52741 .41617 L .52681 .41624 L F
.53001 .41797 m .52741 .41617 L .52734 .41626 L F
0 .269 .687 r
.5284 .41694 m .53001 .41797 L .5281 .41667 L F
.52898 .41746 m .53001 .41797 L .5284 .41694 L F
.538 .58 .845 r
.53001 .41797 m .52734 .41626 L .5272 .41645 L F
.372 .333 .686 r
.528 .41537 m .52725 .41638 L .5281 .41667 L F
.52798 .41511 m .52725 .41638 L .528 .41537 L F
.82 .703 .735 r
.40509 .52962 m .40121 .52941 L .40353 .52553 L F
.954 .825 .677 r
.43372 .52404 m .43635 .52293 L .43697 .52116 L F
.43372 .52404 m .43549 .52547 L .43635 .52293 L F
.8 .478 .444 r
.38562 .50156 m .38335 .5041 L .38308 .50165 L F
.711 .353 .369 r
.38562 .50156 m .38821 .50464 L .38335 .5041 L F
.781 .758 .833 r
.4192 .54928 m .4231 .54972 L .42084 .54827 L F
.804 .706 .757 r
.42084 .55331 m .4231 .54972 L .4192 .54928 L F
.973 .859 .665 r
.4231 .54972 m .42253 .54599 L .42084 .54827 L F
.672 .546 .703 r
.48116 .44046 m .48255 .44393 L .48523 .44058 L F
.451 .253 .52 r
.41453 .55344 m .41469 .55441 L .41225 .55214 L F
.476 .27 .52 r
.41773 .55107 m .41453 .55344 L .41911 .55211 L F
.346 .252 .604 r
.41225 .55214 m .41469 .55441 L .41473 .55263 L F
.365 .026 .251 r
.41225 .55214 m .41469 .55255 L .41504 .55079 L F
.41413 .55071 m .41504 .55079 L .41522 .54987 L F
.41225 .55214 m .41504 .55079 L .41413 .55071 L F
.98 .687 .343 r
.41408 .54857 m .41438 .55056 L .41522 .54987 L F
.41438 .55056 m .41469 .55255 L .41503 .55086 L F
.41438 .55056 m .41503 .55086 L .41522 .54987 L F
.644 .935 .967 r
.41225 .55214 m .41438 .55056 L .41295 .55083 L F
.41438 .55056 m .41479 .55025 L .41416 .55045 L F
.41438 .55056 m .41416 .55045 L .41295 .55083 L F
.817 .447 .354 r
.41522 .54987 m .41469 .55255 L .41827 .54992 L F
.41469 .55255 m .41471 .55258 L .41827 .54992 L F
0 0 0 r
.41827 .54992 m .41469 .55259 L .41773 .55107 L F
.476 .27 .52 r
.41773 .55107 m .41469 .55441 L .41453 .55344 L F
.632 .488 .668 r
.41473 .55257 m .41469 .55441 L .41773 .55107 L F
0 0 0 r
.41469 .55259 m .41468 .5526 L .41773 .55107 L F
.632 .488 .668 r
.41479 .55025 m .41473 .55257 L .41773 .55107 L F
.633 .486 .665 r
.41479 .55025 m .41759 .55104 L .41575 .54975 L F
.41759 .55104 m .41773 .55107 L .41768 .55105 L F
.41759 .55104 m .41768 .55105 L .41575 .54975 L F
.346 .252 .604 r
.41225 .55214 m .41473 .55263 L .4139 .55092 L F
.365 .026 .251 r
.41225 .55214 m .41468 .5526 L .41469 .55255 L F
.346 .252 .604 r
.41438 .55056 m .41472 .55255 L .41479 .55025 L F
.41472 .55255 m .41473 .55263 L .41473 .55255 L F
.41472 .55255 m .41473 .55255 L .41479 .55025 L F
.4139 .55092 m .41469 .55255 L .41438 .55056 L F
.748 .632 .732 r
.41295 .55083 m .41416 .55045 L .41319 .54756 L F
.98 .687 .343 r
.41319 .54756 m .41454 .55159 L .41408 .54857 L F
.748 .632 .732 r
.41416 .55045 m .41479 .55025 L .41319 .54756 L F
.98 .687 .343 r
.41319 .54756 m .41469 .55255 L .41454 .55159 L F
.41319 .54756 m .41468 .5526 L .41469 .55255 L F
.346 .252 .604 r
.41469 .55255 m .41473 .55263 L .41438 .55056 L F
.817 .447 .354 r
.41469 .55255 m .41468 .5526 L .41471 .55258 L F
.861 .822 .808 r
.41772 .54519 m .41827 .54992 L .4192 .54928 L F
.41772 .54519 m .41522 .54987 L .41827 .54992 L F
0 0 0 r
.41827 .54992 m .41773 .55107 L .4192 .54928 L F
.798 .996 .863 r
.52061 .43737 m .51721 .44048 L .51635 .43983 L F
0 0 0 r
.44045 .46428 m .44242 .46319 L .44343 .46112 L F
.44343 .46112 m .44434 .4618 L .44612 .4604 L F
.44343 .46112 m .44242 .46319 L .44434 .4618 L F
.723 .978 .918 r
.45613 .50468 m .45494 .50416 L .45116 .50658 L F
.909 .978 .783 r
.45747 .50061 m .45613 .50468 L .45941 .502 L F
.45747 .50061 m .45494 .50416 L .45613 .50468 L F
.809 .677 .719 r
.3381 .51827 m .33952 .5227 L .33743 .52266 L F
.881 .844 .804 r
.33952 .5227 m .33459 .52466 L .33743 .52266 L F
.33952 .5227 m .33682 .52647 L .33459 .52466 L F
.182 0 .275 r
.33889 .52497 m .33682 .52647 L .33952 .5227 L F
.462 .475 .786 r
.34156 .52171 m .33952 .5227 L .3381 .51827 L F
.206 0 .286 r
.33889 .52497 m .33952 .5227 L .34156 .52171 L F
.9 .965 .82 r
.62886 .38684 m .62875 .38462 L .6256 .38797 L F
.846 .696 .697 r
.6256 .38797 m .62771 .38985 L .62886 .38684 L F
.471 .302 .569 r
.50966 .40909 m .50998 .41177 L .50699 .4099 L F
.609 .761 .952 r
.36627 .56652 m .37055 .56749 L .369 .56563 L F
.571 .744 .958 r
.369 .56563 m .37055 .56749 L .3732 .56678 L F
0 0 0 r
.34578 .4983 m .34259 .50002 L .345 .49892 L F
.142 .429 .869 r
.6201 .35632 m .6214 .35481 L .61787 .35445 L F
.6201 .35632 m .62257 .35707 L .6214 .35481 L F
.784 .825 .884 r
.37705 .53287 m .37316 .53178 L .37532 .52967 L F
.817 .383 .21 r
.37705 .53287 m .37383 .53341 L .37316 .53178 L F
.131 .431 .871 r
.37681 .53083 m .37705 .53287 L .37532 .52967 L F
.858 .982 .855 r
.37681 .53083 m .37383 .53341 L .37705 .53287 L F
.794 .63 .677 r
.4097 .50843 m .41178 .51226 L .40749 .51171 L F
.786 .677 .744 r
.41178 .51226 m .40936 .51597 L .40749 .51171 L F
.804 .706 .757 r
.42084 .55331 m .4192 .54928 L .41911 .55211 L F
.402 .561 .897 r
.35257 .5662 m .3532 .56302 L .35087 .56511 L F
.35257 .5662 m .35491 .5662 L .3532 .56302 L F
.567 .654 .894 r
.37458 .55358 m .37005 .55093 L .37317 .54971 L F
.583 .613 .848 r
.37722 .55275 m .37458 .55358 L .37317 .54971 L F
.755 .602 .687 r
.41035 .50543 m .4097 .50843 L .40785 .50887 L F
.905 .983 .775 r
.59742 .40179 m .59894 .39776 L .59664 .40155 L F
.833 .973 .886 r
.49096 .46747 m .48964 .46667 L .48648 .46966 L F
.852 .972 .87 r
.49248 .46346 m .49096 .46747 L .49371 .46576 L F
.49248 .46346 m .48964 .46667 L .49096 .46747 L F
.557 .934 .848 r
.39945 .56494 m .39756 .5657 L .39702 .56607 L F
0 .236 .753 r
.39416 .56376 m .39702 .56607 L .39636 .56652 L F
.503 .301 .54 r
.39774 .56311 m .39702 .56607 L .39416 .56376 L F
.557 .934 .848 r
.39756 .5657 m .39477 .56683 L .39702 .56607 L F
0 .236 .753 r
.39636 .56652 m .39702 .56607 L .3967 .56694 L F
.921 .712 .605 r
.39431 .56736 m .3967 .56694 L .39702 .56607 L F
.39431 .56736 m .39579 .56979 L .3967 .56694 L F
0 0 0 r
.51957 .40316 m .51677 .40652 L .51779 .40522 L F
.355 .76 .983 r
.51677 .40652 m .51803 .40516 L .51536 .40618 L F
.51677 .40652 m .51981 .40629 L .51803 .40516 L F
.829 .608 .603 r
.40039 .53633 m .398 .53827 L .39775 .53555 L F
.40039 .53633 m .39963 .53933 L .398 .53827 L F
0 0 0 r
.44045 .46428 m .44144 .46512 L .44242 .46319 L F
.44045 .46428 m .43904 .46613 L .44144 .46512 L F
.859 .928 .872 r
.46283 .49265 m .46709 .49088 L .4661 .49043 L F
.871 .994 .762 r
.46878 .48683 m .46709 .49088 L .4702 .48793 L F
.46878 .48683 m .4661 .49043 L .46709 .49088 L F
0 0 0 r
.59058 .38575 m .59107 .38634 L .59133 .38336 L F
.59058 .38575 m .59003 .38823 L .59107 .38634 L F
.658 .187 .125 r
.33889 .52497 m .33459 .52466 L .33682 .52647 L F
.722 .368 .377 r
.5498 .36719 m .55457 .36765 L .55389 .36539 L F
.823 .429 .304 r
.55389 .36539 m .55457 .36765 L .55815 .3686 L F
.513 .292 .516 r
.46272 .4532 m .46568 .45206 L .46582 .45298 L F
.652 .907 .981 r
.54609 .41982 m .54621 .42231 L .54419 .42235 L F
.773 .977 .915 r
.55022 .41839 m .54621 .42231 L .54609 .41982 L F
.904 .885 .803 r
.45971 .49685 m .46123 .49783 L .46108 .4947 L F
.92 .84 .749 r
.45747 .50061 m .46123 .49783 L .45971 .49685 L F
.45747 .50061 m .45941 .502 L .46123 .49783 L F
0 0 0 r
.41546 .56122 m .41629 .56094 L .41878 .56083 L F
.41546 .56122 m .41397 .56222 L .41629 .56094 L F
.852 .823 .82 r
.37021 .5521 m .36877 .54903 L .37005 .55093 L F
.37021 .5521 m .36608 .55239 L .36877 .54903 L F
.849 .831 .83 r
.37021 .5521 m .36664 .55565 L .36608 .55239 L F
.718 .874 .954 r
.35491 .5662 m .35934 .56605 L .35739 .56514 L F
.664 .907 .979 r
.35943 .56435 m .35934 .56605 L .36189 .56563 L F
.35943 .56435 m .35739 .56514 L .35934 .56605 L F
.435 .019 .15 r
.36243 .49832 m .35819 .50096 L .35844 .49898 L F
.36243 .49832 m .36099 .50067 L .35819 .50096 L F
.411 0 .137 r
.36377 .50021 m .36243 .49832 L .36519 .49748 L F
.36377 .50021 m .36099 .50067 L .36243 .49832 L F
.871 .707 .676 r
.40749 .51171 m .40936 .51597 L .40698 .51458 L F
.844 .854 .851 r
.40936 .51597 m .40449 .5178 L .40698 .51458 L F
.81 .809 .85 r
.49911 .46001 m .50401 .45859 L .50237 .45713 L F
.828 .897 .89 r
.50401 .45859 m .50449 .45536 L .50237 .45713 L F
.50401 .45859 m .50601 .45674 L .50449 .45536 L F
0 0 0 r
.3362 .50875 m .33747 .50724 L .33861 .50504 L F
0 0 .003 r
.33861 .50504 m .34018 .50367 L .34102 .50117 L F
0 0 0 r
.33861 .50504 m .33879 .50585 L .34018 .50367 L F
.33861 .50504 m .33747 .50724 L .33879 .50585 L F
0 .494 .795 r
.61325 .37493 m .6115 .37416 L .60907 .37363 L F
0 0 .381 r
.58928 .36444 m .59073 .35984 L .58882 .36186 L F
.904 .648 .54 r
.55457 .36765 m .5577 .37146 L .55815 .3686 L F
.252 .452 .862 r
.34385 .56006 m .34626 .5612 L .34475 .55799 L F
.993 .746 .44 r
.34484 .55552 m .34626 .5612 L .34475 .55799 L F
.855 .783 .78 r
.34912 .55604 m .34626 .5612 L .34475 .55799 L F
.229 .424 .846 r
.34385 .56006 m .34694 .56205 L .34475 .55799 L F
.948 .746 .597 r
.55931 .41222 m .56034 .40971 L .55831 .40865 L F
.612 .531 .739 r
.51957 .40316 m .51779 .40522 L .51532 .39928 L F
.969 .716 .497 r
.6415 .36626 m .64344 .3684 L .64198 .36483 L F
.921 .821 .731 r
.6397 .3705 m .64344 .3684 L .6415 .36626 L F
.6397 .3705 m .64158 .37188 L .64344 .3684 L F
.797 .679 .734 r
.64198 .36483 m .64344 .3684 L .64413 .36576 L F
.74 .856 .934 r
.61011 .39537 m .61201 .39124 L .60898 .39426 L F
.61011 .39537 m .61363 .39297 L .61201 .39124 L F
.797 .425 .352 r
.35844 .49898 m .35819 .50096 L .35618 .49837 L F
.732 .687 .807 r
.54314 .37938 m .53878 .37842 L .54162 .37747 L F
.746 .979 .917 r
.54575 .37764 m .54314 .37938 L .5443 .37697 L F
.507 .712 .963 r
.5443 .37697 m .54314 .37938 L .54162 .37747 L F
.5443 .37697 m .54314 .37938 L .54162 .37747 L F
.455 .248 .508 r
.49334 .41335 m .496 .4126 L .49616 .40956 L F
.297 0 .149 r
.49334 .41335 m .49263 .41508 L .496 .4126 L F
.527 .352 .588 r
.496 .4126 m .49863 .40868 L .49616 .40956 L F
0 .322 .758 r
.62123 .34989 m .6216 .34992 L .6231 .35139 L F
0 .049 .553 r
.62405 .3521 m .62549 .35361 L .6231 .35139 L F
0 0 .301 r
.34217 .51024 m .34087 .51494 L .34071 .51211 L F
.794 .706 .768 r
.38019 .54631 m .37569 .54593 L .37787 .54379 L F
.614 .583 .795 r
.37984 .54948 m .37569 .54593 L .38019 .54631 L F
.765 .705 .795 r
.38241 .54328 m .38019 .54631 L .37787 .54379 L F
.452 .241 .502 r
.38249 .54832 m .37984 .54948 L .38019 .54631 L F
.708 .831 .386 r
.33553 .51147 m .33747 .50724 L .3362 .50875 L F
.632 .536 .728 r
.61716 .37857 m .62102 .37928 L .61973 .37476 L F
.578 .655 .889 r
.55066 .37955 m .54656 .37585 L .54861 .37533 L F
.841 .781 .794 r
.55302 .37545 m .55066 .37955 L .54861 .37533 L F
.804 .829 .356 r
.57409 .38797 m .57301 .39147 L .57354 .39079 L F
.718 .876 .955 r
.39117 .54908 m .38702 .5493 L .39027 .5475 L F
.029 .539 .871 r
.39027 .5475 m .39267 .54827 L .39117 .54908 L F
.874 .818 .79 r
.43076 .52741 m .42908 .52884 L .43265 .529 L F
.874 .817 .79 r
.42908 .52884 m .43026 .53257 L .43265 .529 L F
.85 .823 .821 r
.43076 .52741 m .43265 .529 L .43549 .52547 L F
.493 0 0 r
.55571 .3922 m .55868 .39386 L .56005 .39265 L F
.036 0 0 r
.56005 .39265 m .56252 .39238 L .56268 .39163 L F
.789 .613 .663 r
.3992 .50251 m .39875 .50524 L .39463 .5047 L F
.533 .336 .559 r
.47362 .43943 m .47066 .43962 L .46948 .43929 L F
.47362 .43943 m .47315 .44266 L .47066 .43962 L F
.623 .364 .504 r
.47687 .43676 m .47653 .43971 L .47362 .43943 L F
.533 .336 .559 r
.47315 .44266 m .47312 .44288 L .47304 .44277 L F
.948 .811 .363 r
.47265 .44156 m .47312 .44288 L .47329 .44171 L F
.47265 .44156 m .47329 .44171 L .47362 .43943 L F
.533 .336 .559 r
.47315 .44266 m .47304 .44277 L .47066 .43962 L F
.304 .272 .657 r
.47066 .43962 m .47312 .44288 L .47139 .44362 L F
.643 .967 .878 r
.46948 .43929 m .47074 .43746 L .47415 .43691 L F
.597 .441 .642 r
.47074 .43746 m .47138 .44226 L .47402 .43943 L F
.681 .446 .559 r
.47402 .43943 m .47215 .44144 L .47265 .44156 L F
.731 .536 .629 r
.46687 .44027 m .47116 .44246 L .47074 .43746 L F
.47116 .44246 m .47138 .44226 L .47074 .43746 L F
.754 .696 .797 r
.47312 .44288 m .47109 .4464 L .47139 .44362 L F
.47312 .44288 m .47526 .44674 L .47109 .4464 L F
.987 .773 .527 r
.47275 .44235 m .47047 .44274 L .47299 .44426 L F
.602 .429 .62 r
.46687 .44027 m .47047 .44274 L .4714 .44258 L F
.987 .773 .527 r
.47265 .44156 m .47141 .44223 L .47299 .44426 L F
.731 .536 .629 r
.47116 .44246 m .4714 .44258 L .47138 .44226 L F
.4714 .44258 m .4714 .44242 L .47138 .44226 L F
.987 .773 .527 r
.47141 .44223 m .47047 .44274 L .47136 .44328 L F
.47141 .44223 m .4714 .44242 L .47299 .44426 L F
.4714 .44242 m .4714 .4433 L .47299 .44426 L F
.597 .441 .642 r
.47138 .44226 m .4714 .44242 L .47141 .44223 L F
.987 .773 .527 r
.47265 .44156 m .47047 .44274 L .47275 .44235 L F
.681 .446 .559 r
.47223 .44146 m .47141 .44223 L .47265 .44156 L F
.597 .441 .642 r
.47141 .44223 m .47143 .4426 L .47402 .43943 L F
.4714 .44242 m .47143 .4426 L .47141 .44223 L F
.987 .773 .527 r
.4714 .44242 m .47136 .44328 L .4714 .4433 L F
.731 .536 .629 r
.4714 .44258 m .47143 .4426 L .4714 .44242 L F
.602 .429 .62 r
.4714 .44258 m .47047 .44274 L .47143 .4426 L F
.681 .446 .559 r
.47193 .44138 m .47047 .44274 L .47141 .44223 L F
.47193 .44138 m .47141 .44223 L .47223 .44146 L F
.47402 .43943 m .47193 .44138 L .47215 .44144 L F
.948 .811 .363 r
.47265 .44156 m .47362 .43943 L .47653 .43971 L F
.47265 .44156 m .47577 .44007 L .47494 .43931 L F
.47577 .44007 m .47653 .43971 L .47622 .43963 L F
.47577 .44007 m .47622 .43963 L .47494 .43931 L F
.794 .63 .677 r
.4097 .50843 m .40749 .51171 L .40785 .50887 L F
.839 .494 .4 r
.40305 .50844 m .39916 .5079 L .39875 .50524 L F
.857 .679 .659 r
.40305 .50844 m .39857 .51049 L .39916 .5079 L F
.40305 .50844 m .4009 .51186 L .39857 .51049 L F
.792 .584 .62 r
.40279 .51146 m .4009 .51186 L .40305 .50844 L F
.702 .52 .639 r
.40785 .50887 m .40279 .51146 L .40305 .50844 L F
.629 .853 .475 r
.34564 .50324 m .34338 .50605 L .34303 .50686 L F
.34338 .50605 m .34319 .5063 L .34317 .50635 L F
.34338 .50605 m .34317 .50635 L .34303 .50686 L F
.373 0 0 r
.34294 .50512 m .34404 .50512 L .34164 .50265 L F
.244 0 0 r
.34672 .50528 m .34346 .50631 L .34564 .50324 L F
0 0 .278 r
.34346 .50631 m .34308 .50645 L .34319 .5063 L F
.3435 .50631 m .34346 .50632 L .34346 .50631 L F
.34346 .50632 m .34308 .50645 L .34346 .50631 L F
.244 0 0 r
.34346 .50631 m .34319 .5063 L .34564 .50324 L F
.37 0 0 r
.34591 .50553 m .34294 .50512 L .34346 .50631 L F
.34672 .50528 m .34597 .50525 L .34591 .50553 L F
.34597 .50525 m .34294 .50512 L .34591 .50553 L F
.373 0 0 r
.34404 .50512 m .34612 .50511 L .34462 .50429 L F
.453 .298 .58 r
.34751 .50109 m .34564 .50324 L .3454 .50193 L F
.34751 .50109 m .34753 .50347 L .34564 .50324 L F
.244 0 0 r
.34672 .50528 m .34564 .50324 L .34753 .50347 L F
.37 0 0 r
.34672 .50528 m .34514 .50576 L .34294 .50512 L F
.373 0 0 r
.34294 .50512 m .34514 .50576 L .34612 .50511 L F
.664 .513 .67 r
.34164 .50265 m .34612 .50511 L .345 .49892 L F
0 0 .476 r
.345 .49892 m .34612 .50511 L .34573 .49971 L F
.286 .196 .576 r
.34514 .50576 m .34573 .49971 L .34609 .50472 L F
.34598 .5052 m .34609 .50472 L .34612 .50511 L F
.34514 .50576 m .34609 .50472 L .34598 .5052 L F
0 0 .278 r
.34382 .50538 m .34308 .50645 L .34294 .50512 L F
.629 .853 .475 r
.34319 .5063 m .34308 .50643 L .34308 .50645 L F
.244 0 0 r
.34346 .50631 m .34308 .50643 L .34319 .5063 L F
.37 0 0 r
.34346 .50631 m .34294 .50512 L .34308 .50643 L F
0 0 .278 r
.34514 .50576 m .3435 .50631 L .34382 .50538 L F
.3435 .50631 m .34319 .5063 L .34382 .50538 L F
.373 0 0 r
.34404 .50512 m .34462 .50429 L .34164 .50265 L F
.629 .853 .475 r
.34319 .5063 m .34308 .50645 L .34303 .50686 L F
0 0 .278 r
.34514 .50576 m .34338 .50932 L .34308 .50645 L F
0 0 .101 r
.34294 .50512 m .34308 .50645 L .34308 .50643 L F
.34308 .50645 m .34338 .50932 L .34308 .50643 L F
.629 .853 .475 r
.34303 .50686 m .34308 .50643 L .34181 .50855 L F
.069 .093 .577 r
.34308 .50643 m .34217 .51024 L .34181 .50855 L F
0 0 0 r
.49226 .42428 m .49345 .42457 L .49094 .42539 L F
.49226 .42428 m .49488 .42325 L .49345 .42457 L F
.53609 .43249 m .53461 .43415 L .532 .43536 L F
.082 0 .081 r
.53934 .42948 m .53864 .43218 L .53609 .43249 L F
.008 0 0 r
.53609 .43249 m .53864 .43218 L .53461 .43415 L F
.54 .181 .307 r
.40151 .48744 m .40468 .48727 L .40576 .48464 L F
.492 .134 .286 r
.40576 .48464 m .40821 .48641 L .4087 .48459 L F
.40576 .48464 m .40468 .48727 L .40821 .48641 L F
.386 .265 .591 r
.52501 .40127 m .52243 .39936 L .52698 .39817 L F
.726 .767 .885 r
.36664 .55565 m .36323 .55516 L .36608 .55239 L F
.763 .96 .933 r
.63193 .38186 m .63288 .38285 L .63514 .3809 L F
.779 .366 .266 r
.57401 .37595 m .57396 .37787 L .57784 .37839 L F
.161 .603 .935 r
.60851 .36077 m .60746 .36145 L .60558 .36115 L F
.60851 .36077 m .60947 .36174 L .60746 .36145 L F
.581 .514 .745 r
.60947 .36174 m .60733 .36527 L .60746 .36145 L F
.513 .292 .516 r
.46272 .4532 m .46278 .45381 L .46568 .45206 L F
.85 .823 .821 r
.43076 .52741 m .43549 .52547 L .43372 .52404 L F
.646 .967 .89 r
.59894 .39776 m .60343 .39595 L .60287 .39363 L F
.935 .928 .774 r
.60057 .39298 m .60287 .39363 L .60224 .3923 L F
.896 .952 .832 r
.59894 .39776 m .60241 .39411 L .60057 .39298 L F
.60241 .39411 m .60287 .39363 L .60242 .3935 L F
.60241 .39411 m .60242 .3935 L .60057 .39298 L F
.515 .664 .929 r
.60243 .39245 m .60343 .39595 L .60628 .39543 L F
.60224 .3923 m .60243 .39287 L .60243 .39245 L F
.972 .759 .33 r
.60287 .39363 m .60343 .39595 L .60224 .3923 L F
.515 .664 .929 r
.60243 .39287 m .60343 .39595 L .60243 .39245 L F
.798 .996 .863 r
.52061 .43737 m .51635 .43983 L .51753 .43768 L F
.556 .717 .948 r
.52205 .43516 m .52061 .43737 L .5207 .43399 L F
.855 .946 .877 r
.5207 .43399 m .52061 .43737 L .51753 .43768 L F
.799 .913 .917 r
.62284 .36935 m .61882 .37036 L .62159 .37034 L F
.437 .067 .236 r
.62159 .37034 m .6255 .36806 L .62284 .36935 L F
.93 .725 .605 r
.35618 .49837 m .35542 .49491 L .35574 .49416 L F
.853 .931 .877 r
.50601 .45674 m .5075 .45249 L .50449 .45536 L F
.50601 .45674 m .50895 .45368 L .5075 .45249 L F
.685 .964 .938 r
.52196 .44489 m .52309 .44277 L .51859 .44417 L F
.52196 .44489 m .52433 .44331 L .52309 .44277 L F
.267 0 .151 r
.43328 .46998 m .43674 .46722 L .43432 .46825 L F
0 0 0 r
.60733 .36527 m .60589 .3662 L .60308 .36698 L F
.476 0 0 r
.60733 .36527 m .61029 .36692 L .60589 .3662 L F
.581 .514 .745 r
.60947 .36174 m .6106 .36528 L .60733 .36527 L F
.459 .018 .111 r
.6106 .36528 m .61029 .36692 L .60733 .36527 L F
.851 .808 .808 r
.42649 .53162 m .43026 .53257 L .42908 .52884 L F
.905 .838 .768 r
.42604 .53493 m .43026 .53257 L .42649 .53162 L F
.42604 .53493 m .42804 .53647 L .43026 .53257 L F
.209 0 .119 r
.48714 .41896 m .4894 .41801 L .49041 .41642 L F
.278 0 .289 r
.4894 .41801 m .49263 .41508 L .49041 .41642 L F
.384 .109 .367 r
.52731 .39659 m .52698 .39817 L .52503 .39582 L F
.578 .655 .889 r
.55066 .37955 m .54575 .37764 L .54656 .37585 L F
.372 .032 .254 r
.5443 .37697 m .54656 .37585 L .54575 .37764 L F
.66 .949 .712 r
.54026 .40967 m .53906 .41152 L .53776 .4106 L F
.54026 .40967 m .54179 .40901 L .53906 .41152 L F
.505 .786 .996 r
.39416 .56376 m .39774 .56311 L .39259 .56228 L F
.503 .301 .54 r
.39774 .56311 m .39416 .56376 L .39259 .56228 L F
.321 0 .217 r
.48386 .42241 m .48642 .42168 L .48714 .41896 L F
.331 0 .22 r
.48714 .41896 m .48904 .42093 L .4894 .41801 L F
.48714 .41896 m .48642 .42168 L .48904 .42093 L F
.557 .628 .878 r
.62183 .38218 m .62406 .37713 L .62102 .37928 L F
.62183 .38218 m .62455 .38126 L .62406 .37713 L F
.378 .175 .473 r
.62183 .38218 m .62436 .3838 L .62455 .38126 L F
.62183 .38218 m .62178 .38493 L .62436 .3838 L F
.174 0 .317 r
.43122 .47113 m .43074 .47364 L .43328 .46998 L F
.042 .329 .811 r
.54419 .42235 m .5416 .41973 L .54379 .42195 L F
.611 .061 0 r
.54379 .42195 m .5416 .41973 L .5393 .4184 L F
.76 .441 .446 r
.37256 .49864 m .37216 .50091 L .36979 .49801 L F
.583 .274 .411 r
.37536 .50056 m .37256 .49864 L .37662 .49825 L F
.37536 .50056 m .37216 .50091 L .37256 .49864 L F
.869 .889 .847 r
.41981 .56052 m .42292 .56089 L .42064 .55897 L F
.41981 .56052 m .4201 .56397 L .42292 .56089 L F
.925 .763 .663 r
.42064 .55897 m .42292 .56089 L .423 .55832 L F
.886 .899 .833 r
.41826 .56308 m .4201 .56397 L .41981 .56052 L F
.504 .218 .413 r
.50734 .41546 m .50408 .41817 L .50483 .41677 L F
.557 .047 0 r
.62955 .35452 m .63242 .35615 L .63379 .35471 L F
.938 .584 .317 r
.63379 .35471 m .63242 .35615 L .63436 .35724 L F
.29 0 .022 r
.42714 .47605 m .43074 .47364 L .42817 .4745 L F
.643 .259 .301 r
.48662 .44982 m .48917 .45204 L .49262 .44906 L F
0 0 0 r
.49262 .44906 m .4915 .45032 L .49367 .45023 L F
.49262 .44906 m .48917 .45204 L .4915 .45032 L F
.645 .292 .36 r
.37662 .49825 m .3791 .50062 L .37536 .50056 L F
.951 .808 .666 r
.4245 .54224 m .42509 .53953 L .42264 .54042 L F
.945 .952 .743 r
.42604 .53493 m .42509 .53953 L .42804 .53647 L F
.42604 .53493 m .42397 .53881 L .42509 .53953 L F
.89 .975 .825 r
.42509 .53953 m .42397 .53881 L .42264 .54042 L F
.702 .52 .639 r
.40785 .50887 m .40749 .51171 L .40279 .51146 L F
.665 .187 .106 r
.40125 .56326 m .40392 .5656 L .39945 .56494 L F
.533 0 0 r
.40549 .56663 m .40125 .56326 L .4044 .56271 L F
.40549 .56663 m .40392 .5656 L .40125 .56326 L F
.659 .75 .917 r
.61151 .37051 m .60872 .37174 L .60767 .36956 L F
.768 .734 .821 r
.62257 .35707 m .6235 .36101 L .61982 .36054 L F
.796 .651 .702 r
.6235 .36101 m .62146 .36465 L .61982 .36054 L F
.695 .762 .903 r
.35383 .55692 m .34912 .55604 L .35166 .55594 L F
.598 .092 .021 r
.35166 .55594 m .35625 .55623 L .35383 .55692 L F
.764 .889 .933 r
.61585 .39126 m .62032 .39013 L .61888 .38885 L F
.691 .907 .972 r
.62032 .39013 m .62187 .38771 L .61888 .38885 L F
.62032 .39013 m .62295 .38877 L .62187 .38771 L F
.758 .973 .702 r
.61038 .38676 m .61195 .38599 L .60924 .38914 L F
.724 .907 .54 r
.61038 .38676 m .60924 .38914 L .6079 .39052 L F
.573 .807 .988 r
.3589 .55238 m .35633 .55323 L .35652 .55128 L F
.674 .642 .81 r
.3589 .55238 m .35795 .55368 L .35633 .55323 L F
.964 .831 .662 r
.35795 .55368 m .35652 .55128 L .35633 .55323 L F
.955 .824 .675 r
.3381 .51827 m .33743 .52266 L .33457 .52042 L F
.988 .885 .625 r
.33459 .52466 m .33457 .52042 L .33743 .52266 L F
.869 .941 .863 r
.46878 .48683 m .4702 .48793 L .47318 .48464 L F
.663 .775 .933 r
.37317 .54971 m .37005 .55093 L .36877 .54903 L F
.785 .629 .688 r
.61426 .36497 m .60947 .36174 L .61229 .3612 L F
.61426 .36497 m .6106 .36528 L .60947 .36174 L F
.621 .162 .142 r
.61281 .36674 m .61426 .36497 L .6143 .36752 L F
.61281 .36674 m .6106 .36528 L .61426 .36497 L F
.647 .731 .91 r
.61725 .3644 m .61426 .36497 L .61229 .3612 L F
.678 .465 .589 r
.61725 .3644 m .6143 .36752 L .61426 .36497 L F
.575 .674 .907 r
.34786 .56445 m .34908 .56158 L .34694 .56205 L F
.34786 .56445 m .35087 .56511 L .34908 .56158 L F
.775 .676 .754 r
.37569 .54593 m .37704 .55037 L .37317 .54971 L F
.583 .613 .848 r
.37722 .55275 m .37317 .54971 L .37704 .55037 L F
.614 .583 .795 r
.37984 .54948 m .37704 .55037 L .37569 .54593 L F
.555 .394 .618 r
.37984 .54948 m .37722 .55275 L .37704 .55037 L F
.48 .051 .147 r
.38746 .49055 m .39016 .4904 L .3919 .48821 L F
.573 .154 .209 r
.3919 .48821 m .39016 .4904 L .39433 .49007 L F
.507 .194 .372 r
.3919 .48821 m .39433 .49007 L .39476 .4878 L F
.29 .502 .89 r
.60536 .35943 m .60558 .36115 L .60381 .36082 L F
.573 .807 .988 r
.3589 .55238 m .35756 .54861 L .35904 .54955 L F
.674 .642 .81 r
.3589 .55238 m .36053 .55639 L .35795 .55368 L F
.667 .854 .971 r
.36053 .55639 m .35625 .55623 L .35795 .55368 L F
.646 .845 .977 r
.36006 .5474 m .35904 .54955 L .35756 .54861 L F
.524 .479 .749 r
.36006 .5474 m .3589 .55238 L .35904 .54955 L F
.68 .645 .808 r
.36323 .55516 m .36053 .55639 L .3589 .55238 L F
.947 .621 .378 r
.3381 .51827 m .33536 .51695 L .33505 .51432 L F
.955 .824 .675 r
.3381 .51827 m .33457 .52042 L .33536 .51695 L F
.256 .03 .367 r
.34087 .51494 m .34021 .51766 L .3381 .51827 L F
.462 .475 .786 r
.34156 .52171 m .3381 .51827 L .34021 .51766 L F
.053 0 .072 r
.54084 .43071 m .53934 .42948 L .54177 .42833 L F
.54084 .43071 m .53864 .43218 L .53934 .42948 L F
.591 .447 .654 r
.39049 .5073 m .38821 .50464 L .39207 .50517 L F
.62 .306 .417 r
.39463 .5047 m .39049 .5073 L .39207 .50517 L F
.765 .705 .795 r
.38241 .54328 m .37787 .54379 L .38122 .5422 L F
.456 .791 .999 r
.38541 .54263 m .38241 .54328 L .38122 .5422 L F
.294 .087 .419 r
.47867 .43824 m .47687 .43676 L .47985 .4362 L F
.47867 .43824 m .47653 .43971 L .47687 .43676 L F
.089 0 0 r
.50308 .44637 m .50631 .44624 L .50705 .44595 L F
.332 .793 .671 r
.50705 .44595 m .50892 .44498 L .51098 .44441 L F
.50705 .44595 m .50631 .44624 L .50892 .44498 L F
.884 .754 .714 r
.35668 .49176 m .35229 .49348 L .35556 .48995 L F
.35668 .49176 m .35542 .49491 L .35229 .49348 L F
0 0 .115 r
.60307 .38348 m .60228 .38874 L .60069 .38494 L F
.60288 .38474 m .60298 .38754 L .60228 .38874 L F
.938 .607 .169 r
.60196 .38546 m .60299 .38795 L .60298 .38754 L F
0 .079 .579 r
.60379 .38986 m .60228 .38874 L .60298 .38754 L F
.938 .607 .169 r
.60299 .38795 m .60379 .38986 L .60298 .38754 L F
0 0 .115 r
.60307 .38348 m .60298 .38754 L .60288 .38474 L F
.986 .71 .385 r
.60196 .38546 m .60298 .38754 L .60307 .38348 L F
0 0 .411 r
.60431 .3842 m .60379 .38986 L .60196 .38546 L F
.60386 .38903 m .60515 .38776 L .60379 .38986 L F
.60431 .3842 m .60483 .38641 L .60386 .38903 L F
.60483 .38641 m .60515 .38776 L .60386 .38903 L F
.544 .768 .98 r
.6049 .38148 m .60307 .38348 L .60217 .38203 L F
.6049 .38148 m .6062 .38329 L .60307 .38348 L F
.163 0 0 r
.60431 .3842 m .60307 .38348 L .60398 .38343 L F
.60431 .3842 m .60398 .38343 L .6062 .38329 L F
.349 .651 .968 r
.6049 .38148 m .60855 .38141 L .6062 .38329 L F
.474 .875 .711 r
.60714 .38254 m .60431 .3842 L .6062 .38329 L F
.60855 .38141 m .60538 .38349 L .60714 .38254 L F
.60538 .38349 m .60431 .3842 L .60714 .38254 L F
0 .173 .703 r
.60217 .38203 m .60307 .38348 L .60123 .38213 L F
.60217 .38203 m .59889 .38118 L .59899 .38334 L F
.163 0 0 r
.60431 .3842 m .60196 .38546 L .60307 .38348 L F
.848 .795 .8 r
.59889 .38118 m .60359 .37911 L .60177 .37714 L F
.59889 .38118 m .60177 .37714 L .59914 .37808 L F
.985 .861 .489 r
.59834 .37915 m .59889 .38118 L .59914 .37808 L F
.866 .64 .108 r
.59834 .37915 m .59899 .38334 L .59889 .38118 L F
.63 .59 .791 r
.60217 .38203 m .59899 .38334 L .59834 .37915 L F
.396 .797 .984 r
.60086 .38097 m .6049 .38148 L .60217 .38203 L F
.806 .525 .512 r
.60086 .38097 m .60374 .38438 L .6049 .38148 L F
.924 .54 .152 r
.6033 .38579 m .60515 .38776 L .60475 .38607 L F
.60395 .38475 m .60475 .38607 L .60431 .3842 L F
.6033 .38579 m .60475 .38607 L .60395 .38475 L F
0 0 .071 r
.60447 .38459 m .60439 .38515 L .60431 .3842 L F
.806 .525 .512 r
.60402 .38472 m .60439 .38515 L .60452 .38421 L F
0 0 .071 r
.6049 .38148 m .60452 .38421 L .60431 .3842 L F
.60452 .38421 m .60447 .38459 L .60431 .3842 L F
.223 .635 .956 r
.60431 .3842 m .60783 .38436 L .60755 .38406 L F
.60565 .38351 m .60755 .38406 L .60656 .38304 L F
.60431 .3842 m .60755 .38406 L .60565 .38351 L F
.806 .525 .512 r
.60374 .38438 m .60456 .38394 L .6049 .38148 L F
.298 .386 .785 r
.60452 .38241 m .60449 .38317 L .60432 .38292 L F
.60452 .38241 m .60432 .38292 L .60189 .37916 L F
.828 .789 .816 r
.60177 .37714 m .60359 .37911 L .60607 .37568 L F
.298 .386 .785 r
.60473 .37831 m .60452 .38241 L .60189 .37916 L F
.223 .635 .956 r
.60452 .38421 m .60471 .38422 L .6039 .38484 L F
.173 .639 .934 r
.60899 .38533 m .60783 .38436 L .60431 .3842 L F
.99 .873 .615 r
.60656 .38304 m .60452 .38421 L .60439 .38515 L F
.298 .386 .785 r
.60449 .3844 m .60526 .38389 L .60439 .38515 L F
.60442 .38444 m .60449 .3844 L .60439 .38515 L F
.223 .635 .956 r
.60471 .38422 m .6048 .38423 L .60394 .38481 L F
.60471 .38422 m .60394 .38481 L .6039 .38484 L F
.60431 .3842 m .60476 .38396 L .6039 .38484 L F
.806 .525 .512 r
.60402 .38472 m .60452 .38421 L .60456 .38394 L F
.298 .386 .785 r
.60449 .38317 m .60442 .38444 L .60343 .38286 L F
.60442 .38444 m .60439 .38515 L .60417 .38464 L F
.806 .525 .512 r
.60374 .38438 m .60402 .38472 L .60456 .38394 L F
.298 .386 .785 r
.60442 .38444 m .60417 .38464 L .60343 .38286 L F
.60449 .38317 m .60343 .38286 L .60189 .37916 L F
.223 .635 .956 r
.60478 .38406 m .60656 .38304 L .6048 .3842 L F
.60476 .38396 m .60656 .38304 L .60478 .38406 L F
.99 .873 .615 r
.60656 .38304 m .6049 .38148 L .60452 .38421 L F
.60656 .38304 m .60855 .38141 L .6049 .38148 L F
.298 .386 .785 r
.60473 .37831 m .60631 .38238 L .60526 .38389 L F
.223 .635 .956 r
.60476 .38396 m .6048 .38423 L .60452 .38421 L F
.298 .386 .785 r
.60473 .37831 m .60526 .38389 L .60442 .38444 L F
.60631 .38238 m .60579 .38379 L .60439 .38515 L F
.223 .635 .956 r
.6048 .3842 m .60656 .38304 L .6048 .38423 L F
.114 .332 .801 r
.60189 .37916 m .60417 .38464 L .60372 .38436 L F
.60417 .38464 m .60439 .38515 L .60402 .38472 L F
.60417 .38464 m .60402 .38472 L .60372 .38436 L F
.223 .635 .956 r
.6039 .38484 m .60432 .38456 L .6033 .38579 L F
.60432 .38456 m .60656 .38304 L .60553 .3839 L F
.60432 .38456 m .60553 .3839 L .6033 .38579 L F
.114 .332 .801 r
.60126 .38027 m .60372 .38436 L .60086 .38097 L F
.60189 .37916 m .60372 .38436 L .60126 .38027 L F
.298 .386 .785 r
.60631 .38238 m .60656 .38304 L .60579 .38379 L F
.638 .873 .516 r
.60379 .38986 m .60515 .38776 L .60373 .38958 L F
0 .079 .579 r
.60379 .38986 m .60384 .39015 L .60228 .38874 L F
.638 .873 .516 r
.60379 .38986 m .60373 .38958 L .60242 .39126 L F
0 .079 .579 r
.60379 .38986 m .60504 .39123 L .60384 .39015 L F
0 0 .235 r
.4878 .42824 m .48757 .43112 L .48587 .43243 L F
.446 .859 .699 r
.48757 .43112 m .48522 .43257 L .48587 .43243 L F
.904 .648 .54 r
.55457 .36765 m .55439 .3704 L .5577 .37146 L F
.929 .623 .442 r
.55502 .37286 m .5577 .37146 L .55439 .3704 L F
.55502 .37286 m .55761 .37461 L .5577 .37146 L F
.653 .738 .912 r
.36189 .56563 m .36627 .56652 L .3651 .56476 L F
.611 .737 .935 r
.3651 .56476 m .36627 .56652 L .369 .56563 L F
.783 .452 .427 r
.39875 .50524 m .39485 .50721 L .39463 .5047 L F
.39875 .50524 m .39916 .5079 L .39485 .50721 L F
.408 .269 .578 r
.62955 .35452 m .62767 .35826 L .63242 .35615 L F
.836 .639 .636 r
.62822 .35834 m .63242 .35615 L .62767 .35826 L F
0 .356 .692 r
.62514 .35721 m .62822 .35834 L .62767 .35826 L F
.994 .763 .475 r
.4044 .56271 m .40392 .5656 L .40549 .56663 L F
.399 .647 .957 r
.37698 .568 m .37799 .56608 L .37571 .56604 L F
.37698 .568 m .38015 .56838 L .37799 .56608 L F
.88 .745 .708 r
.57396 .37787 m .57546 .38163 L .57784 .37839 L F
.918 .901 .793 r
.54775 .4025 m .54413 .40404 L .54668 .40154 L F
.54775 .4025 m .54546 .40611 L .54413 .40404 L F
0 0 0 r
.54446 .40692 m .54546 .40611 L .54408 .4072 L F
1 .818 .506 r
.54413 .40404 m .54546 .40611 L .5438 .40745 L F
.784 .995 .787 r
.5445 .40239 m .54668 .40154 L .54413 .40404 L F
.148 .046 .472 r
.54413 .40404 m .54493 .40657 L .5445 .40239 L F
.54493 .40657 m .54499 .40675 L .54497 .40654 L F
.54493 .40657 m .54497 .40654 L .5445 .40239 L F
0 0 0 r
.5438 .40745 m .54446 .40692 L .54179 .40901 L F
.54446 .40692 m .54408 .4072 L .54179 .40901 L F
.468 .868 .695 r
.5438 .40745 m .54179 .40901 L .54026 .40967 L F
.395 .115 .366 r
.51398 .3956 m .5168 .39483 L .5171 .39246 L F
.192 0 .307 r
.5171 .39246 m .51896 .39343 L .51969 .39192 L F
.5171 .39246 m .5168 .39483 L .51896 .39343 L F
.974 .782 .358 r
.59154 .37837 m .5903 .37975 L .58984 .37739 L F
.59154 .37837 m .59107 .381 L .5903 .37975 L F
.498 .239 .452 r
.47511 .42962 m .47801 .42909 L .47813 .42679 L F
.374 .141 .427 r
.47813 .42679 m .48054 .42821 L .48109 .42619 L F
.47813 .42679 m .47801 .42909 L .48054 .42821 L F
.872 .93 .859 r
.5075 .45249 m .50895 .45368 L .51183 .45037 L F
.897 .791 .735 r
.40003 .53179 m .39887 .52778 L .40121 .52941 L F
.40003 .53179 m .39645 .53137 L .39887 .52778 L F
.885 .822 .781 r
.40003 .53179 m .39775 .53555 L .39645 .53137 L F
.71 .88 .96 r
.38182 .56814 m .38601 .56752 L .38271 .5677 L F
.296 0 0 r
.38729 .5675 m .38271 .5677 L .38601 .56752 L F
.38729 .5675 m .38543 .56814 L .38271 .5677 L F
.253 .61 .955 r
.38271 .5677 m .38543 .56814 L .3842 .56698 L F
.38271 .5677 m .3842 .56698 L .38362 .56643 L F
.71 .88 .96 r
.38015 .56838 m .38182 .56814 L .38271 .5677 L F
.78 .69 .765 r
.59729 .3541 m .59451 .3565 L .59682 .35595 L F
.073 0 0 r
.59335 .35896 m .59682 .35595 L .59451 .3565 L F
.597 .471 .679 r
.59682 .35595 m .60122 .35297 L .59729 .3541 L F
.4 0 0 r
.59593 .35812 m .6012 .35677 L .59682 .35595 L F
.121 .312 .782 r
.53126 .37479 m .53287 .37636 L .53386 .37556 L F
.865 .802 .787 r
.63697 .37389 m .64158 .37188 L .6397 .3705 L F
.63697 .37389 m .64004 .37408 L .64158 .37188 L F
0 0 0 r
.54928 .42532 m .55062 .42534 L .54758 .42668 L F
.54928 .42532 m .55203 .42495 L .55062 .42534 L F
.951 .808 .666 r
.4245 .54224 m .42264 .54042 L .42113 .54144 L F
.905 .784 .717 r
.42253 .54599 m .4245 .54224 L .42113 .54144 L F
.565 .812 .433 r
.40681 .55637 m .40534 .55828 L .40451 .55938 L F
0 0 0 r
.40952 .55308 m .40872 .55503 L .40681 .55637 L F
.40754 .55727 m .40681 .55637 L .40872 .55503 L F
.40754 .55727 m .40534 .55828 L .40681 .55637 L F
.869 .941 .863 r
.46878 .48683 m .47318 .48464 L .47136 .48319 L F
.799 .929 .92 r
.47637 .48139 m .47136 .48319 L .47318 .48464 L F
.529 .649 .91 r
.34908 .56158 m .35087 .56511 L .3532 .56302 L F
.93 .725 .605 r
.35618 .49837 m .35429 .49761 L .35542 .49491 L F
.804 .422 .332 r
.35618 .49837 m .35521 .49869 L .35429 .49761 L F
.35618 .49837 m .35819 .50096 L .35521 .49869 L F
.744 .839 .923 r
.49248 .46346 m .49371 .46576 L .4967 .46368 L F
0 .329 .705 r
.39146 .56951 m .38971 .56852 L .38729 .5675 L F
.04 0 0 r
.39431 .56736 m .38971 .56852 L .39146 .56951 L F
.655 .653 .836 r
.39146 .56951 m .39579 .56979 L .39431 .56736 L F
.716 .444 .514 r
.36979 .49801 m .37012 .50062 L .36777 .49742 L F
.36979 .49801 m .37216 .50091 L .37012 .50062 L F
.49 .875 .683 r
.61432 .38431 m .61195 .38599 L .61038 .38676 L F
.19 0 0 r
.54429 .41366 m .54621 .41355 L .54942 .41415 L F
.52 .148 .274 r
.41423 .48332 m .41834 .48079 L .41536 .48069 L F
.799 .602 .635 r
.63804 .36365 m .6415 .36626 L .64198 .36483 L F
.756 .56 .631 r
.53146 .41567 m .53501 .41211 L .53307 .4142 L F
.387 .394 .745 r
.53537 .41543 m .53307 .4142 L .53501 .41211 L F
.798 .783 .839 r
.39775 .53555 m .39351 .53474 L .39645 .53137 L F
.831 .637 .639 r
.398 .53827 m .39351 .53474 L .39775 .53555 L F
.827 .713 .739 r
.40353 .52553 m .39887 .52778 L .40138 .52389 L F
.40353 .52553 m .40121 .52941 L .39887 .52778 L F
.594 .835 .99 r
.54162 .37747 m .53878 .37842 L .53729 .37699 L F
.929 .895 .774 r
.63647 .37641 m .64004 .37408 L .63697 .37389 L F
.63647 .37641 m .63776 .37791 L .64004 .37408 L F
.431 .122 .339 r
.41834 .48079 m .4211 .48023 L .42176 .47797 L F
.397 .092 .326 r
.42176 .47797 m .42377 .47954 L .42451 .47717 L F
.42176 .47797 m .4211 .48023 L .42377 .47954 L F
.889 .941 .841 r
.44291 .5143 m .44141 .51898 L .44417 .51526 L F
.44291 .5143 m .43994 .51793 L .44141 .51898 L F
.552 .657 .906 r
.60474 .37033 m .60028 .36777 L .60308 .36698 L F
.57 .652 .891 r
.60589 .3662 m .60474 .37033 L .60308 .36698 L F
.60589 .3662 m .60767 .36956 L .60474 .37033 L F
.914 .972 .788 r
.44818 .50735 m .44678 .51177 L .4494 .50804 L F
.83 .921 .895 r
.45116 .50658 m .44818 .50735 L .4494 .50804 L F
.25 .188 .589 r
.62102 .37928 m .62252 .37326 L .61973 .37476 L F
.62102 .37928 m .62406 .37713 L .62252 .37326 L F
.48 .208 .424 r
.50061 .41904 m .49751 .4224 L .49811 .41981 L F
.715 .557 .673 r
.4691 .43677 m .47415 .43691 L .47229 .43316 L F
.92 .902 .499 r
.47415 .43691 m .47516 .43306 L .47229 .43316 L F
.581 .406 .609 r
.47229 .43316 m .47516 .43306 L .47511 .42962 L F
.634 .939 .706 r
.61545 .35471 m .61656 .353 L .61893 .35168 L F
.383 .732 .99 r
.61545 .35471 m .61787 .35445 L .61656 .353 L F
.652 .907 .981 r
.54609 .41982 m .54419 .42235 L .54379 .42195 L F
.872 .93 .859 r
.5075 .45249 m .51183 .45037 L .51091 .44985 L F
.788 .973 .913 r
.51183 .45037 m .51386 .44843 L .51259 .44774 L F
.831 .998 .833 r
.51091 .44985 m .51183 .45037 L .51259 .44774 L F
.61 .073 0 r
.56273 .37711 m .56683 .38068 L .56432 .37835 L F
0 0 0 r
.50515 .43993 m .50358 .44107 L .50467 .44132 L F
.741 .506 .575 r
.40279 .51146 m .40045 .51452 L .4009 .51186 L F
.40279 .51146 m .40536 .5148 L .40045 .51452 L F
.76 .507 .551 r
.40698 .51458 m .40279 .51146 L .40749 .51171 L F
.40698 .51458 m .40536 .5148 L .40279 .51146 L F
.577 .175 .244 r
.40821 .48641 m .41115 .48649 L .4087 .48459 L F
.474 .223 .452 r
.4087 .48459 m .41115 .48649 L .41143 .48388 L F
.327 .011 .267 r
.51398 .3956 m .51445 .3984 L .51583 .39618 L F
.578 .281 .427 r
.51592 .3962 m .51289 .40125 L .52114 .39724 L F
.51583 .39618 m .51502 .39757 L .51592 .3962 L F
.51502 .39757 m .51289 .40125 L .51592 .3962 L F
.439 .128 .341 r
.5128 .4003 m .51461 .39828 L .51419 .39859 L F
.343 .04 .299 r
.51124 .39762 m .5128 .4003 L .51375 .39912 L F
.439 .128 .341 r
.5128 .4003 m .51286 .40096 L .51433 .39859 L F
.343 .04 .299 r
.51419 .39859 m .51393 .39923 L .51432 .39863 L F
.51124 .39762 m .51375 .39912 L .51419 .39859 L F
.51375 .39912 m .51393 .39923 L .51419 .39859 L F
.372 .039 .264 r
.51124 .39762 m .51419 .39859 L .51398 .3956 L F
.51419 .39859 m .51445 .3984 L .51398 .3956 L F
.439 .128 .341 r
.51389 .39881 m .51419 .39859 L .51583 .39618 L F
.51419 .39859 m .51461 .39828 L .51502 .39757 L F
.51419 .39859 m .51502 .39757 L .51583 .39618 L F
.5128 .4003 m .51419 .39859 L .51389 .39881 L F
.343 .04 .299 r
.51375 .39912 m .5128 .4003 L .51393 .39923 L F
.439 .128 .341 r
.51433 .39859 m .51289 .40125 L .51461 .39828 L F
.343 .04 .299 r
.51432 .39863 m .51393 .39923 L .5145 .39869 L F
.327 .011 .267 r
.51445 .3984 m .5145 .39869 L .51583 .39618 L F
.439 .128 .341 r
.51286 .40096 m .51289 .40125 L .51433 .39859 L F
.372 .039 .264 r
.51419 .39859 m .5145 .39869 L .51445 .3984 L F
.327 .011 .267 r
.51398 .3956 m .51583 .39618 L .5168 .39483 L F
.592 .938 .938 r
.61875 .37433 m .61973 .37476 L .62252 .37326 L F
.825 .497 .434 r
.38308 .50165 m .37922 .50321 L .3791 .50062 L F
.38308 .50165 m .38335 .5041 L .37922 .50321 L F
.828 .789 .816 r
.60177 .37714 m .60607 .37568 L .60313 .3761 L F
.577 .943 .874 r
.60907 .37363 m .60313 .3761 L .60607 .37568 L F
.418 .277 .582 r
.47511 .42962 m .4778 .43176 L .47801 .42909 L F
.47511 .42962 m .47516 .43306 L .4778 .43176 L F
.812 .773 .817 r
.56493 .39084 m .56268 .39163 L .56569 .38823 L F
.037 0 0 r
.41225 .55214 m .40872 .55503 L .40952 .55308 L F
.755 .465 .492 r
.47526 .44674 m .47165 .44774 L .47109 .4464 L F
.345 .71 .985 r
.47641 .44532 m .47526 .44674 L .47312 .44288 L F
.47641 .44532 m .47779 .44663 L .47526 .44674 L F
.889 .946 .841 r
.44574 .51089 m .44417 .51526 L .44678 .51177 L F
.914 .972 .788 r
.44818 .50735 m .44574 .51089 L .44678 .51177 L F
.064 0 .057 r
.44922 .45722 m .44821 .45915 L .45133 .45607 L F
.609 .722 .925 r
.3496 .4973 m .34751 .50109 L .34695 .49764 L F
.34966 .4973 m .34965 .49732 L .3496 .4973 L F
.34965 .49732 m .34751 .50109 L .3496 .4973 L F
.34966 .4973 m .35176 .50055 L .34751 .50109 L F
.763 .622 .704 r
.35429 .49761 m .35176 .50055 L .35005 .4979 L F
.35429 .49761 m .35005 .4979 L .35083 .49739 L F
.35429 .49761 m .34968 .49732 L .34972 .4973 L F
.909 .694 .6 r
.35542 .49491 m .35429 .49761 L .35317 .4953 L F
.887 .691 .632 r
.35317 .4953 m .34966 .4973 L .35229 .49348 L F
.35429 .49761 m .34966 .4973 L .35317 .4953 L F
.322 0 0 r
.34763 .4983 m .34926 .49753 L .34966 .4973 L F
.763 .622 .704 r
.34972 .4973 m .34968 .49732 L .34966 .4973 L F
.322 0 0 r
.34926 .49753 m .35232 .49608 L .34966 .4973 L F
.482 .101 .239 r
.35029 .49812 m .35473 .49514 L .35378 .49543 L F
.35282 .49607 m .35378 .49543 L .3535 .49552 L F
.35029 .49812 m .35378 .49543 L .35282 .49607 L F
.763 .622 .704 r
.35083 .49739 m .35005 .4979 L .34968 .49732 L F
.322 0 0 r
.34968 .49733 m .35086 .49765 L .35282 .49607 L F
.34984 .49725 m .35282 .49607 L .3535 .49552 L F
.34968 .49733 m .35282 .49607 L .34984 .49725 L F
.34763 .4983 m .35029 .49812 L .35086 .49765 L F
.34763 .4983 m .35086 .49765 L .34968 .49733 L F
.35232 .49608 m .3535 .49552 L .35234 .49605 L F
.35232 .49608 m .35234 .49605 L .34966 .4973 L F
.909 .694 .6 r
.35419 .49435 m .35317 .4953 L .35229 .49348 L F
.35542 .49491 m .35317 .4953 L .35419 .49435 L F
.881 .696 .647 r
.39868 .54176 m .398 .53827 L .39963 .53933 L F
.437 .067 .236 r
.62159 .37034 m .62462 .36991 L .6255 .36806 L F
.402 .646 .956 r
.6255 .36806 m .62712 .36616 L .625 .36654 L F
.226 .099 .49 r
.62462 .36991 m .62712 .36616 L .6255 .36806 L F
.65 .114 0 r
.55736 .38684 m .55328 .38342 L .55509 .38465 L F
.859 .978 .858 r
.54857 .39906 m .54775 .4025 L .54668 .40154 L F
.708 .61 .745 r
.61982 .36054 m .62146 .36465 L .61725 .3644 L F
.699 .472 .576 r
.62131 .3674 m .61725 .3644 L .62146 .36465 L F
.372 .032 .254 r
.5443 .37697 m .54791 .37421 L .54656 .37585 L F
.21 .174 .597 r
.55004 .38744 m .54728 .38514 L .55009 .38313 L F
.571 .744 .958 r
.369 .56563 m .3732 .56678 L .37163 .56505 L F
.436 .702 .977 r
.37163 .56505 m .3732 .56678 L .37409 .56477 L F
.54 .818 .997 r
.37409 .56477 m .3732 .56678 L .37571 .56604 L F
.982 .838 .624 r
.54942 .41415 m .55125 .41622 L .55022 .41839 L F
.925 .716 .602 r
.33697 .54983 m .3381 .55277 L .33591 .55029 L F
.008 0 0 r
.35897 .49271 m .36186 .49203 L .36378 .49092 L F
0 0 0 r
.36186 .49203 m .36648 .491 L .36378 .49092 L F
.747 .5 .558 r
.4777 .44856 m .48081 .44669 L .47779 .44663 L F
.859 .547 .458 r
.48081 .44669 m .48202 .44972 L .48315 .44941 L F
.48 .616 .908 r
.42084 .54827 m .41772 .54519 L .4192 .54928 L F
.42084 .54827 m .42073 .54487 L .41772 .54519 L F
.863 .91 .863 r
.42084 .54827 m .42253 .54599 L .42073 .54487 L F
.68 .891 .974 r
.59424 .40314 m .59533 .40022 L .59226 .40104 L F
.59424 .40314 m .59664 .40155 L .59533 .40022 L F
.68 .645 .808 r
.36323 .55516 m .3589 .55238 L .36152 .5518 L F
.723 .738 .864 r
.36608 .55239 m .36323 .55516 L .36152 .5518 L F
0 0 0 r
.55911 .41667 m .5577 .41873 L .55852 .41618 L F
.647 .731 .91 r
.61415 .36239 m .61229 .3612 L .61601 .36056 L F
.453 0 0 r
.61209 .36098 m .61601 .36056 L .61229 .3612 L F
.61143 .36025 m .61424 .36044 L .61209 .36098 L F
.61424 .36044 m .61601 .36056 L .61209 .36098 L F
.647 .731 .91 r
.61725 .3644 m .61415 .36239 L .61601 .36056 L F
.872 .866 .83 r
.61982 .36054 m .61725 .3644 L .61601 .36056 L F
.61982 .36054 m .61601 .36056 L .6184 .35878 L F
.453 0 0 r
.61143 .36025 m .61429 .36112 L .61601 .36056 L F
.152 0 0 r
.61429 .36112 m .6172 .3604 L .61784 .35953 L F
.617 .35957 m .6184 .35878 L .61601 .36056 L F
.61647 .35988 m .61784 .35953 L .6184 .35878 L F
.61429 .36112 m .617 .35957 L .61601 .36056 L F
.61429 .36112 m .61784 .35953 L .61647 .35988 L F
0 0 0 r
.62131 .3674 m .61882 .37036 L .61989 .3694 L F
.781 .981 .714 r
.62096 .36775 m .61882 .37036 L .62131 .3674 L F
.699 .472 .576 r
.62131 .3674 m .61989 .3694 L .61971 .36905 L F
.62131 .3674 m .61971 .36905 L .61725 .3644 L F
.781 .981 .714 r
.62123 .36743 m .62096 .36775 L .62131 .3674 L F
.678 .465 .589 r
.61725 .3644 m .61971 .36905 L .6164 .36811 L F
.61469 .36711 m .6164 .36811 L .6143 .36752 L F
.61725 .3644 m .6164 .36811 L .61469 .36711 L F
.781 .981 .714 r
.6195 .36927 m .61882 .37036 L .62123 .36743 L F
.695 .583 .725 r
.61882 .37036 m .6143 .36752 L .6195 .36927 L F
.781 .981 .714 r
.61909 .3697 m .61882 .37036 L .6195 .36927 L F
.695 .583 .725 r
.61882 .37036 m .6195 .36927 L .61989 .3694 L F
.682 .358 .42 r
.62159 .37034 m .62195 .37198 L .61882 .37036 L F
.323 .521 .894 r
.61909 .3697 m .62195 .37198 L .61882 .37036 L F
.678 .465 .589 r
.61971 .36905 m .6195 .36927 L .6143 .36752 L F
.781 .981 .714 r
.6198 .36803 m .61909 .3697 L .62123 .36743 L F
.678 .465 .589 r
.61971 .36905 m .61989 .3694 L .6195 .36927 L F
.323 .521 .894 r
.6198 .36803 m .62148 .37111 L .61909 .3697 L F
.62148 .37111 m .62195 .37198 L .61909 .3697 L F
.757 .452 .47 r
.37012 .50062 m .36519 .49748 L .36777 .49742 L F
.993 .741 .401 r
.4192 .54928 m .41773 .55107 L .41911 .55211 L F
.814 1 .807 r
.51267 .44225 m .51098 .44441 L .50892 .44498 L F
.172 0 0 r
.59073 .35984 m .59451 .3565 L .59072 .35782 L F
.59073 .35984 m .59335 .35896 L .59451 .3565 L F
.63 .768 .945 r
.46846 .45052 m .46568 .45206 L .46587 .45162 L F
.491 0 0 r
.48202 .44972 m .48662 .44982 L .48315 .44941 L F
0 0 0 r
.44612 .4604 m .44682 .46083 L .44821 .45915 L F
.44612 .4604 m .44434 .4618 L .44682 .46083 L F
.891 .58 .452 r
.57336 .38096 m .5736 .38308 L .57546 .38163 L F
.88 .745 .708 r
.57396 .37787 m .57336 .38096 L .57546 .38163 L F
.926 .652 .502 r
.5736 .38308 m .57579 .38481 L .57546 .38163 L F
0 0 .052 r
.41878 .56083 m .41981 .56052 L .42064 .55897 L F
.215 .735 .85 r
.41629 .56094 m .41981 .56052 L .41878 .56083 L F
.782 .983 .722 r
.61893 .35168 m .61962 .34969 L .62123 .34989 L F
.61893 .35168 m .61656 .353 L .61962 .34969 L F
.343 .04 .299 r
.51124 .39762 m .51092 .40258 L .5128 .4003 L F
0 0 .381 r
.58928 .36444 m .59085 .36268 L .59073 .35984 L F
0 0 .508 r
.58928 .36444 m .59088 .365 L .59085 .36268 L F
.58928 .36444 m .59036 .3673 L .59088 .365 L F
.746 .613 .044 r
.59038 .37139 m .59031 .37004 L .59036 .3673 L F
0 0 0 r
.59038 .37139 m .5903 .3726 L .59031 .37004 L F
.59038 .37139 m .59004 .37408 L .5903 .3726 L F
.783 .857 .906 r
.61363 .39297 m .61441 .38957 L .61201 .39124 L F
.61363 .39297 m .61585 .39126 L .61441 .38957 L F
.618 .805 .971 r
.35943 .56435 m .36189 .56563 L .3651 .56476 L F
.879 .978 .836 r
.38436 .55265 m .38146 .55609 L .38321 .5534 L F
.859 .749 .741 r
.52593 .43331 m .5207 .43399 L .52419 .43198 L F
.52593 .43331 m .52205 .43516 L .5207 .43399 L F
.819 .942 .906 r
.52593 .43331 m .52606 .43033 L .52681 .43158 L F
.52593 .43331 m .52419 .43198 L .52606 .43033 L F
.708 .831 .386 r
.33553 .51147 m .33614 .50971 L .33747 .50724 L F
0 0 .439 r
.33505 .51432 m .33614 .50971 L .33553 .51147 L F
.88 .902 .841 r
.63514 .3809 m .63776 .37791 L .63647 .37641 L F
0 0 .301 r
.34217 .51024 m .34153 .51426 L .34087 .51494 L F
.09 0 .399 r
.34153 .51426 m .34021 .51766 L .34087 .51494 L F
0 0 .013 r
.51232 .40806 m .50998 .41177 L .50966 .40909 L F
.889 .946 .841 r
.44574 .51089 m .44291 .5143 L .44417 .51526 L F
.466 .891 .847 r
.47415 .43691 m .47286 .43643 L .47322 .43626 L F
.92 .902 .499 r
.47415 .43691 m .47338 .43663 L .47516 .43306 L F
.466 .891 .847 r
.47415 .43691 m .47125 .43721 L .47338 .43663 L F
.92 .902 .499 r
.47415 .43691 m .47319 .43701 L .47338 .43663 L F
.466 .891 .847 r
.47415 .43691 m .47364 .43655 L .47319 .43701 L F
.84 .553 .503 r
.47338 .43663 m .47319 .43701 L .47364 .43655 L F
.466 .891 .847 r
.47364 .43655 m .47322 .43626 L .47319 .43701 L F
.84 .553 .503 r
.47364 .43655 m .47319 .43701 L .47695 .43564 L F
.47695 .43564 m .47319 .43701 L .47753 .43649 L F
.47516 .43306 m .47338 .43663 L .47695 .43564 L F
.466 .891 .847 r
.47415 .43691 m .47074 .43746 L .47125 .43721 L F
.47338 .43663 m .47125 .43721 L .47286 .43643 L F
.87 .425 .092 r
.54058 .3848 m .53878 .38384 L .53785 .38178 L F
.764 .378 .324 r
.54058 .3848 m .53842 .38655 L .53878 .38384 L F
.54058 .3848 m .54314 .38764 L .53842 .38655 L F
.719 .712 .182 r
.40534 .55828 m .4044 .56271 L .40451 .55938 L F
.538 .58 .845 r
.53001 .41797 m .52681 .41624 L .5281 .41667 L F
.763 .96 .933 r
.63193 .38186 m .63514 .3809 L .63388 .37986 L F
.88 .902 .841 r
.63514 .3809 m .63647 .37641 L .63388 .37986 L F
.676 .965 .755 r
.52433 .44331 m .52602 .44152 L .52559 .44135 L F
.633 .946 .95 r
.52309 .44277 m .52433 .44331 L .52559 .44135 L F
.728 .718 .841 r
.62295 .38877 m .62178 .38493 L .62187 .38771 L F
.62295 .38877 m .62436 .3838 L .62178 .38493 L F
.62295 .38877 m .6256 .38797 L .62436 .3838 L F
.658 .187 .125 r
.33889 .52497 m .33689 .52689 L .33459 .52466 L F
0 0 .076 r
.34156 .52171 m .34057 .5232 L .33889 .52497 L F
0 0 0 r
.34021 .52412 m .33889 .52497 L .34057 .5232 L F
.34021 .52412 m .33689 .52689 L .33889 .52497 L F
.964 .831 .662 r
.35795 .55368 m .35496 .55491 L .35652 .55128 L F
.993 .87 .596 r
.35625 .55623 m .35496 .55491 L .35795 .55368 L F
.42 0 0 r
.38729 .5675 m .38971 .56852 L .38543 .56814 L F
.842 .728 .738 r
.51828 .41853 m .51942 .42239 L .51603 .42148 L F
.712 .198 .002 r
.51603 .42148 m .51942 .42239 L .51726 .42282 L F
.174 .298 .751 r
.52124 .4208 m .51942 .42239 L .51828 .41853 L F
.527 .92 .84 r
.51726 .42282 m .51942 .42239 L .52124 .4208 L F
.689 .251 .205 r
.33393 .5488 m .33591 .55029 L .33697 .54983 L F
.33697 .54983 m .33591 .55029 L .33393 .5488 L F
.881 .696 .647 r
.39868 .54176 m .39524 .54134 L .398 .53827 L F
.953 .896 .732 r
.39868 .54176 m .39525 .54447 L .39524 .54134 L F
.39868 .54176 m .39685 .54568 L .39525 .54447 L F
.736 .723 .839 r
.62436 .3838 m .6256 .38797 L .62875 .38462 L F
.799 .929 .92 r
.47637 .48139 m .47499 .48028 L .47136 .48319 L F
.871 .925 .859 r
.47651 .4782 m .47637 .48139 L .47885 .47857 L F
.88 .931 .85 r
.47651 .4782 m .47499 .48028 L .47637 .48139 L F
.577 .943 .874 r
.60907 .37363 m .60755 .37362 L .60313 .3761 L F
.17 .549 .929 r
.60907 .37363 m .61015 .37245 L .60755 .37362 L F
.60907 .37363 m .6115 .37416 L .61015 .37245 L F
.934 .779 .664 r
.55831 .40865 m .55924 .40576 L .55721 .40412 L F
.828 .785 .812 r
.55924 .40576 m .56064 .40181 L .55721 .40412 L F
.55924 .40576 m .562 .40258 L .56064 .40181 L F
.702 .782 .913 r
.45374 .4518 m .45193 .4538 L .45046 .45196 L F
.979 .751 .521 r
.45193 .4538 m .45133 .45607 L .45046 .45196 L F
.653 .834 .97 r
.38122 .5422 m .37787 .54379 L .37719 .54173 L F
.601 .261 .366 r
.39433 .49007 m .39869 .4873 L .39476 .4878 L F
.39433 .49007 m .39757 .49016 L .39869 .4873 L F
.54 .2 .34 r
.39869 .4873 m .40121 .4893 L .40151 .48744 L F
.39869 .4873 m .39757 .49016 L .40121 .4893 L F
.794 .665 .721 r
.40698 .51458 m .40449 .5178 L .40536 .5148 L F
.86 .777 .768 r
.49462 .46199 m .49911 .46001 L .49716 .4585 L F
.49462 .46199 m .4967 .46368 L .49911 .46001 L F
.781 .843 .899 r
.49716 .4585 m .49911 .46001 L .50237 .45713 L F
.483 .037 .112 r
.55818 .39241 m .55868 .39386 L .55571 .3922 L F
.52 .148 .274 r
.41423 .48332 m .41775 .48281 L .41834 .48079 L F
.465 .097 .255 r
.41775 .48281 m .4206 .48245 L .41834 .48079 L F
.427 .114 .33 r
.41834 .48079 m .4206 .48245 L .4211 .48023 L F
.193 0 .191 r
.53445 .38293 m .53193 .38423 L .53288 .38206 L F
.865 .763 .748 r
.56064 .40181 m .562 .40258 L .56041 .39797 L F
.831 .749 .773 r
.562 .40258 m .56422 .39852 L .56041 .39797 L F
.948 .746 .597 r
.55931 .41222 m .55831 .40865 L .55843 .41099 L F
.951 .885 .486 r
.55786 .41425 m .55931 .41222 L .55843 .41099 L F
.444 0 0 r
.3732 .491 m .37586 .49221 L .37778 .49114 L F
.519 .009 0 r
.37586 .49221 m .38073 .4912 L .37778 .49114 L F
.978 .918 .654 r
.52681 .43158 m .52606 .43033 L .52811 .42925 L F
.716 .948 .653 r
.52933 .42699 m .531 .42591 L .52811 .42925 L F
.726 .975 .737 r
.52811 .42925 m .52606 .43033 L .52933 .42699 L F
.621 .162 .142 r
.61281 .36674 m .61029 .36692 L .6106 .36528 L F
.616 .888 .989 r
.51803 .40516 m .51981 .40629 L .52233 .40512 L F
.281 .17 .545 r
.52681 .41624 m .52526 .41571 L .52789 .41394 L F
.766 .453 .457 r
.36519 .49748 m .3674 .50076 L .36377 .50021 L F
.757 .452 .47 r
.37012 .50062 m .3674 .50076 L .36519 .49748 L F
.831 .637 .639 r
.398 .53827 m .39332 .53779 L .39351 .53474 L F
.83 .606 .599 r
.398 .53827 m .39524 .54134 L .39332 .53779 L F
.814 .78 .821 r
.56041 .39797 m .56422 .39852 L .56269 .39501 L F
.798 .774 .83 r
.56269 .39501 m .56422 .39852 L .56743 .39569 L F
.099 0 0 r
.496 .4126 m .49263 .41508 L .49534 .41403 L F
.306 0 .014 r
.49534 .41403 m .49798 .41348 L .496 .4126 L F
.527 .352 .588 r
.496 .4126 m .49898 .41199 L .49863 .40868 L F
.302 0 .033 r
.496 .4126 m .49798 .41348 L .49898 .41199 L F
0 0 .332 r
.59003 .38823 m .59165 .38915 L .59107 .38634 L F
.59003 .38823 m .59004 .39133 L .59165 .38915 L F
0 0 0 r
.53422 .42295 m .531 .42591 L .53313 .42408 L F
.8 .943 .591 r
.53527 .42074 m .53422 .42295 L .53313 .42408 L F
0 0 0 r
.49345 .42457 m .49488 .42325 L .49751 .4224 L F
.815 .997 .775 r
.5508 .38984 m .55268 .38648 L .55524 .39152 L F
.106 .257 .736 r
.34021 .51766 m .34286 .51997 L .34156 .52171 L F
0 0 .27 r
.34286 .51997 m .34057 .5232 L .34156 .52171 L F
.659 .75 .917 r
.61151 .37051 m .60767 .36956 L .61023 .36825 L F
.828 .849 .863 r
.6143 .36752 m .61151 .37051 L .61023 .36825 L F
.971 .852 .667 r
.38221 .51146 m .38094 .51146 L .38062 .50802 L F
.941 .615 .388 r
.38221 .51146 m .38041 .51316 L .38094 .51146 L F
.558 .7 .936 r
.38473 .51064 m .38221 .51146 L .38062 .50802 L F
.547 .16 .259 r
.38473 .51064 m .38041 .51316 L .38221 .51146 L F
0 0 0 r
.6184 .35878 m .62257 .35707 L .61982 .36054 L F
.731 .22 .005 r
.63438 .35965 m .63681 .36222 L .63807 .36093 L F
.981 .749 .342 r
.63807 .36093 m .63681 .36222 L .63804 .36365 L F
.63807 .36093 m .63681 .36222 L .63804 .36365 L F
.73 .855 .94 r
.47885 .47857 m .47955 .47551 L .47651 .4782 L F
.47885 .47857 m .48131 .47702 L .47955 .47551 L F
.018 0 .079 r
.56268 .39163 m .56374 .39105 L .56569 .38823 L F
.041 0 .037 r
.56252 .39238 m .56374 .39105 L .56268 .39163 L F
.431 .773 .997 r
.61143 .36025 m .60947 .36174 L .60851 .36077 L F
.61143 .36025 m .61229 .3612 L .60947 .36174 L F
.503 .494 .78 r
.4121 .56281 m .41521 .56602 L .41397 .56222 L F
.827 .774 .803 r
.35193 .55248 m .34802 .55253 L .34965 .55205 L F
.477 .267 .515 r
.35193 .55248 m .34912 .55604 L .34802 .55253 L F
.35193 .55248 m .35166 .55594 L .34912 .55604 L F
.385 .791 .982 r
.34965 .55205 m .3522 .55176 L .35193 .55248 L F
0 0 .123 r
.35254 .55367 m .35193 .55248 L .3522 .55176 L F
.35254 .55367 m .35166 .55594 L .35193 .55248 L F
.87 .658 .613 r
.4009 .51186 m .40045 .51452 L .39857 .51049 L F
.717 .858 .949 r
.39027 .5475 m .38702 .5493 L .3854 .54774 L F
.972 .872 .486 r
.38702 .5493 m .38518 .54809 L .3854 .54774 L F
.38702 .5493 m .38565 .55122 L .38518 .54809 L F
.632 .689 .885 r
.3532 .56302 m .35491 .5662 L .35739 .56514 L F
.737 .721 .836 r
.34802 .55253 m .34912 .55604 L .34484 .55552 L F
.298 0 0 r
.34475 .55799 m .34912 .55604 L .34484 .55552 L F
.34475 .55799 m .34764 .5576 L .34912 .55604 L F
.855 .783 .78 r
.34912 .55604 m .34475 .55799 L .34764 .5576 L F
0 0 0 r
.34912 .55604 m .35063 .55537 L .35166 .55594 L F
.132 0 0 r
.34912 .55604 m .35037 .55652 L .35166 .55594 L F
.35037 .55652 m .3505 .55657 L .35069 .55647 L F
.35037 .55652 m .35069 .55647 L .35166 .55594 L F
.811 .909 .908 r
.34802 .55253 m .34484 .55552 L .34302 .55425 L F
.714 .72 .855 r
.34567 .55378 m .34734 .55701 L .35063 .55537 L F
.34734 .55701 m .34764 .5576 L .34873 .55679 L F
.132 0 0 r
.34912 .55604 m .34764 .5576 L .3505 .55657 L F
0 0 0 r
.34912 .55604 m .34764 .5576 L .35063 .55537 L F
.714 .72 .855 r
.34734 .55701 m .34873 .55679 L .35063 .55537 L F
.379 .162 .454 r
.49898 .41199 m .50172 .40818 L .49863 .40868 L F
.447 0 0 r
.36648 .491 m .36892 .49214 L .37105 .49044 L F
.521 .014 0 r
.36892 .49214 m .3732 .491 L .37105 .49044 L F
.543 .479 .734 r
.4777 .44856 m .48204 .45195 L .48202 .44972 L F
.4777 .44856 m .47948 .45287 L .48204 .45195 L F
.816 1 .817 r
.48204 .45195 m .48026 .45246 L .4816 .45107 L F
.426 .158 .402 r
.48202 .44972 m .48373 .45032 L .48521 .44979 L F
.48202 .44972 m .48204 .45195 L .48509 .4508 L F
.816 1 .817 r
.48258 .45073 m .4816 .45107 L .48311 .44953 L F
.48204 .45195 m .4816 .45107 L .48258 .45073 L F
.426 .158 .402 r
.48521 .44979 m .48509 .4508 L .48662 .44982 L F
.48373 .45032 m .48509 .4508 L .48521 .44979 L F
.689 .173 .002 r
.48509 .4508 m .48917 .45204 L .48662 .44982 L F
.795 .657 .711 r
.56932 .38014 m .57396 .37787 L .57107 .37772 L F
.905 .784 .717 r
.42253 .54599 m .42113 .54144 L .42073 .54487 L F
.798 .774 .83 r
.56269 .39501 m .56743 .39569 L .5654 .39444 L F
.547 .841 .998 r
.56891 .39354 m .56743 .39569 L .56952 .39405 L F
.56891 .39354 m .5654 .39444 L .56743 .39569 L F
.523 .632 .9 r
.33793 .54582 m .33697 .54983 L .33944 .54865 L F
.332 .795 .68 r
.33697 .54983 m .33944 .54865 L .33793 .54582 L F
.33697 .54983 m .33591 .55029 L .33944 .54865 L F
.33697 .54983 m .33591 .55029 L .33944 .54865 L F
.62 .306 .417 r
.39463 .5047 m .39485 .50721 L .39049 .5073 L F
.764 .834 .906 r
.61585 .39126 m .61729 .38696 L .61441 .38957 L F
.61585 .39126 m .61888 .38885 L .61729 .38696 L F
.719 .712 .182 r
.40534 .55828 m .40477 .56072 L .4044 .56271 L F
.906 .641 .525 r
.40179 .56368 m .4044 .56271 L .40477 .56072 L F
.40179 .56368 m .40392 .5656 L .4044 .56271 L F
.278 0 .289 r
.4894 .41801 m .49209 .41773 L .49263 .41508 L F
.491 .244 .468 r
.48904 .42093 m .49209 .41773 L .4894 .41801 L F
0 0 0 r
.49618 .44637 m .49797 .44518 L .49921 .44319 L F
.774 .415 .377 r
.53968 .4169 m .535 .41758 L .53537 .41543 L F
.53968 .4169 m .5393 .4184 L .535 .41758 L F
.477 .527 .83 r
.34694 .56205 m .34764 .5576 L .34475 .55799 L F
.34694 .56205 m .34908 .56158 L .34764 .5576 L F
.802 .987 .888 r
.49367 .45023 m .4915 .45032 L .49452 .44759 L F
.744 .839 .923 r
.49248 .46346 m .4967 .46368 L .49462 .46199 L F
.855 .992 .838 r
.39267 .54827 m .39525 .54447 L .39685 .54568 L F
.885 .75 .708 r
.35521 .49869 m .35351 .50105 L .35429 .49761 L F
.384 .091 .339 r
.35521 .49869 m .35361 .50306 L .35351 .50105 L F
.528 .23 .405 r
.35631 .50265 m .35521 .49869 L .35819 .50096 L F
.35631 .50265 m .35361 .50306 L .35521 .49869 L F
.89 .868 .81 r
.41319 .54756 m .41522 .54987 L .41772 .54519 L F
.611 .737 .935 r
.3651 .56476 m .369 .56563 L .3666 .56283 L F
.516 .756 .983 r
.369 .56563 m .36979 .56345 L .3666 .56283 L F
.369 .56563 m .37163 .56505 L .36979 .56345 L F
.59 .438 .643 r
.41521 .56602 m .41629 .56094 L .41397 .56222 L F
.41521 .56602 m .41826 .56308 L .41629 .56094 L F
.554 .433 .67 r
.41629 .56094 m .41826 .56308 L .41981 .56052 L F
.256 .465 .871 r
.5641 .3851 m .56569 .38823 L .56634 .38531 L F
0 0 0 r
.56569 .38823 m .5649 .38938 L .56506 .38969 L F
.5649 .38938 m .56374 .39105 L .56506 .38969 L F
.256 .349 .768 r
.565 .39159 m .56516 .38989 L .56506 .38969 L F
.799 .819 .34 r
.56634 .38531 m .56506 .38969 L .5654 .38737 L F
.256 .349 .768 r
.56516 .38989 m .5654 .38737 L .56506 .38969 L F
0 0 0 r
.56569 .38823 m .56506 .38969 L .56634 .38531 L F
.963 .673 .252 r
.52918 .38757 m .52993 .39188 L .53052 .39158 L F
.82 .941 .579 r
.52993 .39188 m .529 .39289 L .53052 .39158 L F
.476 .822 .54 r
.53052 .39158 m .53235 .38995 L .53331 .39084 L F
.53052 .39158 m .529 .39289 L .53235 .38995 L F
.467 .332 .614 r
.53352 .39403 m .53052 .39158 L .53331 .39084 L F
.756 .56 .631 r
.53146 .41567 m .53537 .41543 L .53501 .41211 L F
.687 .861 .965 r
.53776 .4106 m .53501 .41211 L .53642 .4106 L F
.064 .053 .533 r
.53501 .41211 m .53707 .41367 L .53642 .4106 L F
.53501 .41211 m .53537 .41543 L .53707 .41367 L F
.267 0 .151 r
.43328 .46998 m .43578 .46924 L .43674 .46722 L F
.134 0 .085 r
.43674 .46722 m .43578 .46924 L .43904 .46613 L F
.474 .329 .603 r
.62252 .37326 m .62462 .36991 L .62159 .37034 L F
.86 .661 .633 r
.63242 .35615 m .63438 .35965 L .63436 .35724 L F
0 0 0 r
.49921 .44319 m .49797 .44518 L .49983 .4434 L F
.82 .662 .686 r
.55736 .38684 m .56174 .38622 L .55981 .38326 L F
.492 .531 .824 r
.56174 .38622 m .56333 .38223 L .55981 .38326 L F
.56174 .38622 m .5641 .3851 L .56333 .38223 L F
.769 .522 .56 r
.54982 .36987 m .55457 .36765 L .5498 .36719 L F
.54982 .36987 m .55439 .3704 L .55457 .36765 L F
.573 .807 .988 r
.3589 .55238 m .35652 .55128 L .35756 .54861 L F
.06 0 0 r
.345 .49892 m .34966 .4973 L .34695 .49764 L F
.524 .479 .749 r
.36006 .5474 m .36152 .5518 L .3589 .55238 L F
0 0 .315 r
.46932 .44757 m .47109 .4464 L .47088 .449 L F
.552 .37 .588 r
.47165 .44774 m .47088 .449 L .47109 .4464 L F
.807 .585 .602 r
.40449 .5178 m .40045 .51452 L .40536 .5148 L F
.778 .4 .34 r
.53785 .38178 m .53878 .38384 L .53445 .38293 L F
.974 .672 .297 r
.62187 .38771 m .62178 .38493 L .62017 .38315 L F
.587 .814 .986 r
.62436 .3838 m .62178 .38493 L .62017 .38315 L F
.777 .95 .931 r
.51739 .44628 m .51259 .44774 L .51386 .44843 L F
.981 .718 .324 r
.41526 .53894 m .4166 .54142 L .41663 .53879 L F
.442 .279 .564 r
.4191 .53816 m .41908 .53499 L .41663 .53879 L F
.854 .504 .391 r
.41617 .53984 m .41663 .53879 L .41526 .53894 L F
.249 .007 .338 r
.4166 .54142 m .4191 .53816 L .41663 .53879 L F
.854 .504 .391 r
.41617 .53984 m .4191 .53816 L .41663 .53879 L F
.442 .279 .564 r
.4191 .53816 m .41908 .53499 L .41663 .53879 L F
.527 .341 .571 r
.48109 .42619 m .48411 .42532 L .48386 .42241 L F
.248 0 .231 r
.48109 .42619 m .48309 .42705 L .48411 .42532 L F
.48109 .42619 m .48054 .42821 L .48309 .42705 L F
.392 .091 .33 r
.35176 .50055 m .34753 .50347 L .34751 .50109 L F
.466 .417 .719 r
.6012 .35677 m .60311 .3524 L .60122 .35297 L F
.807 .585 .602 r
.40449 .5178 m .40029 .51744 L .40045 .51452 L F
.806 .668 .711 r
.40449 .5178 m .40222 .52176 L .40029 .51744 L F
.434 .273 .562 r
.48386 .42241 m .48642 .4246 L .48642 .42168 L F
.48386 .42241 m .48411 .42532 L .48642 .4246 L F
.515 .664 .929 r
.60224 .3923 m .60628 .39543 L .60504 .39123 L F
.631 .596 .796 r
.60628 .39543 m .6079 .39052 L .60504 .39123 L F
.60628 .39543 m .60898 .39426 L .6079 .39052 L F
.84 .553 .503 r
.47516 .43306 m .47753 .43649 L .4778 .43176 L F
0 0 .27 r
.34286 .51997 m .3425 .5227 L .34057 .5232 L F
.436 .284 .576 r
.3425 .5227 m .34021 .52412 L .34057 .5232 L F
.598 .092 .021 r
.35166 .55594 m .354 .5577 L .35625 .55623 L F
.993 .87 .596 r
.35625 .55623 m .354 .5577 L .35496 .55491 L F
.14 0 .004 r
.54337 .42966 m .54177 .42833 L .54477 .42716 L F
.54337 .42966 m .54084 .43071 L .54177 .42833 L F
0 0 0 r
.55203 .42495 m .5557 .42257 L .5551 .42499 L F
.5557 .42257 m .5577 .41873 L .55672 .42091 L F
0 0 .022 r
.55672 .42091 m .5551 .42499 L .5557 .42257 L F
.946 .886 .742 r
.62406 .37713 m .62455 .38126 L .62293 .37966 L F
.553 .813 .994 r
.62293 .37966 m .62455 .38126 L .62712 .38031 L F
.621 .464 .648 r
.62436 .3838 m .62712 .38031 L .62455 .38126 L F
.291 .011 .304 r
.49023 .42732 m .48808 .4263 L .49094 .42539 L F
.49023 .42732 m .4878 .42824 L .48808 .4263 L F
.29 0 .022 r
.42714 .47605 m .42913 .4757 L .43074 .47364 L F
.327 .125 .447 r
.43328 .46998 m .43074 .47364 L .43313 .47259 L F
.383 0 .08 r
.43074 .47364 m .43269 .47492 L .43313 .47259 L F
.43074 .47364 m .42913 .4757 L .43269 .47492 L F
.49 .875 .683 r
.61432 .38431 m .61038 .38676 L .61327 .38593 L F
.766 .532 .58 r
.61327 .38593 m .61732 .38312 L .61432 .38431 L F
.615 .222 .276 r
.40121 .4893 m .4041 .48952 L .40151 .48744 L F
.567 .251 .392 r
.40151 .48744 m .4041 .48952 L .40468 .48727 L F
.994 .765 .478 r
.53915 .39829 m .53775 .40069 L .53757 .39726 L F
.828 .849 .863 r
.6143 .36752 m .61023 .36825 L .61281 .36674 L F
.799 .602 .635 r
.63804 .36365 m .63816 .36692 L .6415 .36626 L F
.809 .646 .68 r
.63816 .36692 m .6397 .3705 L .6415 .36626 L F
.361 0 .159 r
.38618 .54606 m .3854 .54774 L .38249 .54832 L F
.533 .497 .762 r
.38851 .54489 m .38618 .54606 L .38541 .54263 L F
.717 .858 .949 r
.39027 .5475 m .38618 .54606 L .38851 .54489 L F
.39027 .5475 m .3854 .54774 L .38618 .54606 L F
.489 .023 .073 r
.38073 .4912 m .38285 .49253 L .38461 .49051 L F
.528 .065 .099 r
.38461 .49051 m .38729 .49221 L .38746 .49055 L F
.38461 .49051 m .38285 .49253 L .38729 .49221 L F
.514 .796 .997 r
.38015 .56838 m .38134 .56643 L .37799 .56608 L F
.38015 .56838 m .38271 .5677 L .38134 .56643 L F
.884 .89 .83 r
.45947 .49349 m .45971 .49685 L .46108 .4947 L F
.45947 .49349 m .45652 .497 L .45971 .49685 L F
.908 .84 .766 r
.45971 .49685 m .45652 .497 L .45747 .50061 L F
.861 .916 .866 r
.46135 .49133 m .46108 .4947 L .46283 .49265 L F
.46135 .49133 m .45947 .49349 L .46108 .4947 L F
.59 .533 .76 r
.50467 .44132 m .50631 .44624 L .50308 .44637 L F
.206 .723 .688 r
.50631 .44624 m .502 .44748 L .50308 .44637 L F
.50631 .44624 m .502 .44748 L .50308 .44637 L F
.796 .655 .706 r
.38821 .50464 m .38312 .50667 L .38335 .5041 L F
.38821 .50464 m .38586 .50808 L .38312 .50667 L F
.771 .618 .69 r
.38821 .50464 m .38763 .50809 L .38586 .50808 L F
.591 .447 .654 r
.39049 .5073 m .38763 .50809 L .38821 .50464 L F
.831 .738 .762 r
.37182 .54464 m .36703 .54596 L .36993 .54485 L F
.37182 .54464 m .36877 .54903 L .36703 .54596 L F
.285 .719 .967 r
.37182 .54464 m .37224 .5435 L .37395 .54452 L F
.555 .933 .877 r
.37182 .54464 m .36993 .54485 L .37224 .5435 L F
.911 .854 .773 r
.47955 .47551 m .48348 .47333 L .48184 .4721 L F
.47955 .47551 m .48131 .47702 L .48348 .47333 L F
.877 .906 .846 r
.48184 .4721 m .48348 .47333 L .48648 .46966 L F
.801 .968 .661 r
.50804 .41308 m .50734 .41546 L .50998 .41177 L F
.62 .107 .006 r
.53729 .37699 m .53984 .37921 L .54162 .37747 L F
.027 0 0 r
.54162 .37747 m .54267 .37827 L .5443 .37697 L F
.54162 .37747 m .53984 .37921 L .54267 .37827 L F
.603 .132 .108 r
.35819 .50096 m .3606 .50292 L .35631 .50265 L F
.512 .188 .355 r
.36099 .50067 m .3606 .50292 L .35819 .50096 L F
.934 .779 .664 r
.55831 .40865 m .55721 .40412 L .55453 .40764 L F
.834 .501 .425 r
.55843 .41099 m .55831 .40865 L .55453 .40764 L F
.04 0 0 r
.39431 .56736 m .39252 .56812 L .38971 .56852 L F
.42 .847 .704 r
.39477 .56683 m .39431 .56736 L .39702 .56607 L F
.39477 .56683 m .39252 .56812 L .39431 .56736 L F
.558 .313 .501 r
.41115 .48649 m .41423 .48332 L .41143 .48388 L F
.802 .999 .804 r
.42985 .52687 m .42908 .52884 L .43076 .52741 L F
.918 .965 .655 r
.43179 .52319 m .43076 .52741 L .43372 .52404 L F
.43179 .52319 m .42985 .52687 L .43076 .52741 L F
.445 .193 .437 r
.49209 .41773 m .49534 .41403 L .49263 .41508 L F
.4 0 0 r
.59593 .35812 m .59897 .35825 L .6012 .35677 L F
.48 .208 .424 r
.50061 .41904 m .50061 .42167 L .49751 .4224 L F
.286 .064 .392 r
.50295 .4204 m .50061 .41904 L .50408 .41817 L F
.50295 .4204 m .50061 .42167 L .50061 .41904 L F
.83 .921 .895 r
.45116 .50658 m .45126 .50442 L .44818 .50735 L F
.771 .823 .893 r
.45116 .50658 m .45307 .50257 L .45126 .50442 L F
.45116 .50658 m .45494 .50416 L .45307 .50257 L F
.037 0 0 r
.41225 .55214 m .4108 .5543 L .40872 .55503 L F
.653 .83 .413 r
.41295 .55083 m .4108 .5543 L .41225 .55214 L F
.814 1 .807 r
.51267 .44225 m .50892 .44498 L .51111 .44117 L F
.752 .746 .847 r
.51185 .43856 m .51267 .44225 L .51111 .44117 L F
.51185 .43856 m .51635 .43983 L .51267 .44225 L F
.786 .514 .524 r
.37216 .50091 m .36758 .50311 L .37012 .50062 L F
.37216 .50091 m .372 .50373 L .36758 .50311 L F
.573 .331 .511 r
.37495 .50313 m .37216 .50091 L .37536 .50056 L F
.37495 .50313 m .372 .50373 L .37216 .50091 L F
.383 .161 .447 r
.47801 .42909 m .4778 .43176 L .48054 .42821 L F
0 0 0 r
.48171 .4347 m .47867 .43824 L .47985 .4362 L F
.374 .84 .811 r
.47867 .43824 m .47494 .43931 L .47653 .43971 L F
.618 .805 .971 r
.35943 .56435 m .3651 .56476 L .36282 .56173 L F
.589 .72 .935 r
.36282 .56173 m .3651 .56476 L .3666 .56283 L F
.744 .416 .428 r
.37012 .50062 m .36758 .50311 L .3674 .50076 L F
0 0 .439 r
.33505 .51432 m .33653 .51243 L .33614 .50971 L F
0 0 .032 r
.33536 .51695 m .33653 .51243 L .33505 .51432 L F
.6 .849 .991 r
.6229 .36487 m .62131 .3674 L .625 .36654 L F
.71 .967 .723 r
.6229 .36487 m .6198 .36803 L .62131 .3674 L F
.887 .8 .758 r
.35756 .54861 m .35365 .54815 L .35564 .54471 L F
.735 .706 .823 r
.35652 .55128 m .35365 .54815 L .35756 .54861 L F
.63 .697 .893 r
.36006 .5474 m .35756 .54861 L .35564 .54471 L F
.998 .778 .456 r
.5736 .38308 m .5745 .38791 L .57579 .38481 L F
.759 .91 .942 r
.46135 .49133 m .46283 .49265 L .4661 .49043 L F
.765 .996 .831 r
.37532 .52967 m .37316 .53178 L .37358 .53034 L F
0 0 .438 r
.37316 .53178 m .37383 .53341 L .37358 .53034 L F
.773 .977 .915 r
.55022 .41839 m .54609 .41982 L .54925 .4174 L F
0 0 0 r
.54867 .41882 m .54925 .4174 L .5485 .4191 L F
.982 .838 .624 r
.54979 .4161 m .55022 .41839 L .54925 .4174 L F
0 0 0 r
.55079 .41549 m .54925 .4174 L .54867 .41882 L F
.982 .838 .624 r
.54942 .41415 m .54979 .4161 L .54925 .4174 L F
0 0 0 r
.36186 .49203 m .36452 .49166 L .36648 .491 L F
.429 0 0 r
.36452 .49166 m .36892 .49214 L .36648 .491 L F
.877 .906 .846 r
.48184 .4721 m .48648 .46966 L .48461 .46847 L F
.815 .84 .869 r
.48648 .46966 m .48778 .46495 L .48461 .46847 L F
.48648 .46966 m .48964 .46667 L .48778 .46495 L F
.709 .172 0 r
.62195 .35085 m .62123 .34989 L .61962 .34969 L F
.62195 .35085 m .6216 .34992 L .62123 .34989 L F
.521 .014 0 r
.36892 .49214 m .3716 .49254 L .3732 .491 L F
.453 0 0 r
.3732 .491 m .3716 .49254 L .37586 .49221 L F
.018 0 .173 r
.34102 .50117 m .34164 .50265 L .34259 .50002 L F
.34102 .50117 m .34018 .50367 L .34164 .50265 L F
.695 .316 .325 r
.38763 .50809 m .38748 .51009 L .38586 .50808 L F
.606 .238 .318 r
.38975 .50949 m .38763 .50809 L .39049 .5073 L F
.38975 .50949 m .38748 .51009 L .38763 .50809 L F
.272 0 .101 r
.51969 .39192 m .51896 .39343 L .52235 .39127 L F
.472 .174 .379 r
.42451 .47717 m .42662 .47888 L .42714 .47605 L F
.42451 .47717 m .42377 .47954 L .42662 .47888 L F
0 0 0 r
.61881 .35861 m .62123 .35805 L .62257 .35707 L F
.844 .837 .839 r
.6214 .35481 m .62257 .35707 L .62549 .35361 L F
.19 0 0 r
.62123 .35805 m .62514 .35721 L .62257 .35707 L F
.559 .387 .605 r
.62549 .35361 m .62514 .35721 L .62257 .35707 L F
.466 .749 .991 r
.62265 .35597 m .62364 .35749 L .62123 .35805 L F
.19 0 0 r
.62123 .35805 m .62395 .35797 L .62514 .35721 L F
.466 .749 .991 r
.62364 .35749 m .62395 .35797 L .62123 .35805 L F
0 0 0 r
.6184 .35878 m .62123 .35805 L .61881 .35861 L F
0 0 .013 r
.51232 .40806 m .51163 .41068 L .50998 .41177 L F
0 0 0 r
.51082 .41228 m .50998 .41177 L .51163 .41068 L F
.51051 .41209 m .50804 .41308 L .50998 .41177 L F
.50905 .41279 m .50804 .41308 L .51051 .41209 L F
.897 .707 .638 r
.50586 .4084 m .50752 .41352 L .5092 .41268 L F
0 0 .386 r
.50804 .41308 m .50807 .4138 L .50764 .41433 L F
.50807 .4138 m .50815 .41558 L .50764 .41433 L F
.897 .707 .638 r
.50871 .41347 m .50798 .41495 L .50879 .41345 L F
0 0 .386 r
.50764 .41433 m .50815 .41558 L .50657 .41766 L F
.50815 .41558 m .50816 .41593 L .50808 .41602 L F
.989 .725 .372 r
.50804 .41308 m .50748 .4138 L .50816 .41593 L F
.706 .614 .751 r
.50509 .41474 m .50777 .41493 L .50744 .4138 L F
.50521 .4137 m .50744 .4138 L .50586 .4084 L F
.50509 .41474 m .50744 .4138 L .50521 .4137 L F
.50777 .41493 m .50798 .41495 L .50768 .41404 L F
.50757 .41415 m .50768 .41404 L .507 .41193 L F
.50777 .41493 m .50768 .41404 L .50757 .41415 L F
.50777 .41493 m .507 .41193 L .50586 .4084 L F
.518 .01 0 r
.50865 .41349 m .50761 .4138 L .50834 .41328 L F
.50761 .4138 m .50743 .41386 L .50757 .41368 L F
.5082 .41319 m .5078 .41338 L .50804 .41308 L F
.50901 .41286 m .50804 .41308 L .50905 .41279 L F
.50865 .41349 m .50847 .41337 L .50901 .41286 L F
.50847 .41337 m .50804 .41308 L .50901 .41286 L F
.897 .707 .638 r
.50752 .41352 m .50761 .4138 L .50905 .41279 L F
.599 .897 .61 r
.5085 .41327 m .5089 .41278 L .50918 .41269 L F
.897 .707 .638 r
.50752 .41352 m .50918 .41272 L .5092 .41268 L F
.599 .897 .61 r
.5091 .41277 m .50918 .41269 L .5092 .41268 L F
.897 .707 .638 r
.50761 .4138 m .50865 .41349 L .50905 .41279 L F
.599 .897 .61 r
.5085 .41327 m .50918 .41269 L .5091 .41277 L F
.897 .707 .638 r
.50761 .4138 m .50792 .41478 L .50865 .41349 L F
.50792 .41478 m .50798 .41495 L .50905 .41279 L F
.518 .01 0 r
.50802 .41393 m .50743 .41386 L .50761 .4138 L F
.50793 .41398 m .50743 .41386 L .50802 .41393 L F
.989 .725 .372 r
.50777 .41493 m .50677 .41471 L .50798 .41577 L F
.50748 .4138 m .50706 .41434 L .50777 .41493 L F
.50706 .41434 m .50677 .41471 L .50777 .41493 L F
.631 .47 .646 r
.5007 .41249 m .50361 .41398 L .50284 .40967 L F
.50361 .41398 m .50509 .41474 L .50488 .41426 L F
.50361 .41398 m .50488 .41426 L .50284 .40967 L F
.706 .614 .751 r
.50488 .41426 m .50586 .4084 L .50284 .40967 L F
.50509 .41474 m .50514 .41432 L .50488 .41426 L F
.50514 .41432 m .50586 .4084 L .50488 .41426 L F
.17 0 0 r
.50419 .41413 m .50772 .41489 L .50509 .41474 L F
.536 .217 .375 r
.5007 .41249 m .50419 .41413 L .50509 .41474 L F
.414 .86 .899 r
.50167 .41579 m .50677 .41471 L .50419 .41413 L F
.50167 .41579 m .50561 .41449 L .50677 .41471 L F
.17 0 0 r
.50419 .41413 m .50677 .41471 L .50709 .41477 L F
.50419 .41413 m .50716 .41479 L .50633 .4146 L F
.414 .86 .899 r
.50561 .41449 m .50572 .41445 L .50677 .41471 L F
.17 0 0 r
.50709 .41477 m .50677 .41471 L .50716 .41479 L F
.50633 .4146 m .50716 .41479 L .50765 .41488 L F
.50688 .41471 m .50765 .41488 L .50798 .41495 L F
.50419 .41413 m .50765 .41488 L .50688 .41471 L F
.989 .725 .372 r
.50748 .4138 m .50798 .41577 L .50816 .41593 L F
.17 0 0 r
.50772 .41489 m .50798 .41495 L .50777 .41493 L F
.50772 .41489 m .50777 .41493 L .50509 .41474 L F
.599 .897 .61 r
.50677 .41471 m .50836 .41371 L .50798 .41495 L F
.897 .707 .638 r
.50905 .41279 m .50871 .41347 L .50918 .41272 L F
.50871 .41347 m .50879 .41345 L .50918 .41272 L F
.599 .897 .61 r
.5085 .41327 m .5092 .41268 L .50879 .41345 L F
.50844 .41367 m .50879 .41345 L .50835 .41426 L F
.5085 .41327 m .50879 .41345 L .50844 .41367 L F
.518 .01 0 r
.50869 .41351 m .50761 .4138 L .50865 .41349 L F
.50922 .41387 m .50818 .41383 L .50869 .41351 L F
.50818 .41383 m .50761 .4138 L .50869 .41351 L F
.599 .897 .61 r
.5085 .41327 m .50835 .41426 L .50798 .41495 L F
.518 .01 0 r
.51031 .4146 m .50761 .4138 L .50922 .41387 L F
.51031 .4146 m .50677 .41471 L .50743 .41386 L F
.599 .897 .61 r
.50677 .41471 m .5085 .41327 L .50836 .41371 L F
.518 .01 0 r
.51031 .4146 m .50793 .41398 L .50802 .41393 L F
.599 .897 .61 r
.50677 .41471 m .5089 .41278 L .50867 .41306 L F
.50824 .41348 m .50867 .41306 L .5085 .41327 L F
.50677 .41471 m .50867 .41306 L .50824 .41348 L F
.518 .01 0 r
.51031 .4146 m .50865 .41349 L .51082 .41228 L F
.50865 .41349 m .50905 .41279 L .51082 .41228 L F
.599 .897 .61 r
.50677 .41471 m .50813 .41302 L .5089 .41278 L F
0 0 .386 r
.50815 .41558 m .50808 .41602 L .50657 .41766 L F
0 0 0 r
.51082 .41228 m .50905 .41279 L .51051 .41209 L F
.815 .852 .396 r
.55672 .42091 m .5577 .41873 L .55669 .42023 L F
0 0 0 r
.55669 .42023 m .5577 .41873 L .55911 .41667 L F
.781 .843 .899 r
.49716 .4585 m .50237 .45713 L .50042 .45529 L F
.786 .808 .87 r
.50237 .45713 m .50449 .45536 L .50042 .45529 L F
.767 .646 .728 r
.36424 .5482 m .36608 .55239 L .36152 .5518 L F
.742 .635 .741 r
.36877 .54903 m .36608 .55239 L .36424 .5482 L F
.597 .666 .888 r
.61023 .36825 m .60767 .36956 L .60589 .3662 L F
0 0 .119 r
.59004 .37408 m .59039 .37529 L .5903 .3726 L F
.59004 .37408 m .58984 .37739 L .59039 .37529 L F
.546 .366 .588 r
.43313 .47259 m .43578 .46924 L .43328 .46998 L F
.934 .754 .634 r
.41514 .54354 m .41772 .54519 L .4166 .54142 L F
.89 .868 .81 r
.41319 .54756 m .41772 .54519 L .41514 .54354 L F
.309 .123 .458 r
.41845 .54358 m .4166 .54142 L .41772 .54519 L F
.39 .745 .992 r
.41772 .54519 m .42073 .54487 L .41845 .54358 L F
.764 .73 .821 r
.38656 .53772 m .38823 .54151 L .38359 .54097 L F
.757 .742 .838 r
.38823 .54151 m .38541 .54263 L .38359 .54097 L F
.533 .497 .762 r
.38851 .54489 m .38541 .54263 L .38823 .54151 L F
.717 .708 .84 r
.39094 .53834 m .38823 .54151 L .38656 .53772 L F
.598 .524 .741 r
.39094 .53834 m .39116 .54158 L .38823 .54151 L F
.523 .358 .598 r
.39094 .54415 m .38823 .54151 L .39116 .54158 L F
.39094 .54415 m .38851 .54489 L .38823 .54151 L F
.777 .95 .931 r
.51739 .44628 m .51603 .44526 L .51259 .44774 L F
.823 .919 .901 r
.51764 .44313 m .51739 .44628 L .51859 .44417 L F
.879 .955 .851 r
.51764 .44313 m .51603 .44526 L .51739 .44628 L F
.436 .866 .929 r
.47322 .43626 m .47753 .43649 L .47319 .43701 L F
.47322 .43626 m .4759 .43538 L .47753 .43649 L F
0 0 .451 r
.4778 .43176 m .47753 .43649 L .47958 .43317 L F
.543 .923 .921 r
.47753 .43649 m .47918 .43398 L .47958 .43317 L F
.47753 .43649 m .4759 .43538 L .47918 .43398 L F
.931 .922 .781 r
.59533 .40022 m .59894 .39776 L .59841 .39683 L F
.59533 .40022 m .59664 .40155 L .59894 .39776 L F
.896 .952 .832 r
.59894 .39776 m .60057 .39298 L .59841 .39683 L F
.797 .949 .92 r
.60224 .3923 m .60504 .39123 L .60379 .38986 L F
.813 .702 .742 r
.40138 .52389 m .39804 .52125 L .40222 .52176 L F
.40138 .52389 m .39988 .5255 L .39804 .52125 L F
.859 .792 .785 r
.40138 .52389 m .39887 .52778 L .39988 .5255 L F
.795 .712 .773 r
.56064 .40181 m .5584 .39649 L .55603 .40014 L F
.56064 .40181 m .56041 .39797 L .5584 .39649 L F
.848 .779 .785 r
.55603 .40014 m .55721 .40412 L .56064 .40181 L F
.592 .938 .938 r
.61875 .37433 m .62252 .37326 L .61998 .37416 L F
.474 .329 .603 r
.62252 .37326 m .62515 .3722 L .62462 .36991 L F
.526 .774 .988 r
.62515 .3722 m .62844 .372 L .62699 .37057 L F
.62515 .3722 m .62647 .37115 L .62639 .3711 L F
.62515 .3722 m .62639 .3711 L .62462 .36991 L F
.226 .099 .49 r
.62462 .36991 m .62638 .3711 L .62712 .36616 L F
.62638 .3711 m .62639 .37109 L .62712 .36616 L F
.62639 .3711 m .62648 .37105 L .62648 .37104 L F
.62639 .37109 m .62648 .37104 L .62712 .36616 L F
.62639 .3711 m .62648 .37104 L .62639 .37109 L F
.452 0 0 r
.6198 .36803 m .62509 .3712 L .62195 .37198 L F
.538 .793 .992 r
.62513 .37186 m .62639 .37077 L .62509 .3712 L F
.619 .832 .982 r
.62649 .37072 m .62495 .3688 L .62673 .36642 L F
.62648 .37089 m .6263 .37064 L .62649 .37072 L F
.6263 .37064 m .62495 .3688 L .62649 .37072 L F
.452 0 0 r
.6198 .36803 m .62263 .36992 L .62509 .3712 L F
.62263 .36992 m .62278 .37001 L .62509 .3712 L F
.62271 .36997 m .62317 .37025 L .62509 .3712 L F
.526 .861 .994 r
.62598 .37049 m .62295 .37014 L .6263 .37064 L F
.619 .832 .982 r
.62607 .37053 m .6249 .36888 L .62495 .3688 L F
.538 .793 .992 r
.62648 .37069 m .62648 .37055 L .62509 .3712 L F
.799 .718 .185 r
.62712 .36616 m .6265 .37089 L .62673 .36642 L F
.6265 .37089 m .6265 .3708 L .62673 .36642 L F
.62648 .37104 m .62648 .37089 L .62649 .37072 L F
.6265 .3708 m .62649 .37072 L .62673 .36642 L F
.62648 .37104 m .62649 .37072 L .6265 .3708 L F
.538 .793 .992 r
.62589 .3714 m .62681 .3704 L .62513 .37186 L F
.62589 .3714 m .62681 .3704 L .62513 .37186 L F
.226 .099 .49 r
.62639 .3711 m .62647 .37115 L .62648 .37105 L F
.62638 .3711 m .62639 .3711 L .62639 .37109 L F
.526 .774 .988 r
.62639 .3711 m .62653 .37098 L .62589 .3714 L F
.62653 .37098 m .62699 .37057 L .6265 .37094 L F
.62653 .37098 m .6265 .37094 L .62589 .3714 L F
.619 .832 .982 r
.62647 .37115 m .62607 .37053 L .62647 .37087 L F
.62648 .3709 m .62647 .37087 L .62648 .37089 L F
.62647 .37115 m .62647 .37087 L .62648 .3709 L F
.62607 .37053 m .62495 .3688 L .6263 .37064 L F
.538 .793 .992 r
.62513 .37186 m .62639 .37077 L .62509 .3712 L F
.62639 .37077 m .62681 .3704 L .6263 .37064 L F
.62639 .37077 m .6263 .37064 L .62509 .3712 L F
.619 .832 .982 r
.62607 .37053 m .6263 .37064 L .62648 .37089 L F
.526 .861 .994 r
.6263 .37064 m .62295 .37014 L .62509 .3712 L F
.62648 .37055 m .62598 .37049 L .6263 .37064 L F
.62598 .37049 m .62295 .37014 L .6263 .37064 L F
.62681 .3704 m .62647 .37038 L .62648 .37055 L F
.619 .832 .982 r
.62603 .37052 m .6249 .36888 L .62607 .37053 L F
.62603 .37052 m .62681 .3704 L .6249 .36888 L F
.526 .861 .994 r
.62647 .37038 m .62295 .37014 L .62648 .37055 L F
.619 .832 .982 r
.62647 .37115 m .62603 .37052 L .62607 .37053 L F
.526 .861 .994 r
.62647 .37038 m .62558 .37032 L .62648 .37055 L F
.62558 .37032 m .62295 .37014 L .62598 .37049 L F
.62558 .37032 m .62598 .37049 L .62648 .37055 L F
.62648 .37055 m .62598 .37049 L .6263 .37064 L F
.538 .793 .992 r
.62639 .37077 m .62648 .37069 L .62637 .37073 L F
.526 .861 .994 r
.62681 .3704 m .62647 .37038 L .62648 .37055 L F
.799 .718 .185 r
.6265 .37089 m .62648 .37104 L .6265 .3708 L F
.62648 .37104 m .62647 .37115 L .62648 .37089 L F
.538 .793 .992 r
.62648 .37069 m .62681 .3704 L .62648 .37055 L F
.526 .774 .988 r
.62589 .3714 m .62699 .37057 L .62681 .3704 L F
.619 .832 .982 r
.62647 .37115 m .62681 .3704 L .62603 .37052 L F
.526 .861 .994 r
.6263 .37064 m .62575 .37056 L .62509 .3712 L F
.62575 .37056 m .62295 .37014 L .62424 .37078 L F
.62575 .37056 m .62424 .37078 L .62509 .3712 L F
.538 .793 .992 r
.62639 .37077 m .62637 .37073 L .62509 .3712 L F
.62515 .3722 m .62589 .3714 L .62513 .37186 L F
.62515 .3722 m .62589 .3714 L .62513 .37186 L F
.526 .774 .988 r
.62515 .3722 m .62639 .3711 L .62589 .3714 L F
.591 .835 .991 r
.62252 .37326 m .62515 .3722 L .62509 .3712 L F
.565 .934 .81 r
.62509 .3712 m .62252 .37326 L .62515 .3722 L F
.318 .224 .588 r
.62252 .37326 m .62555 .37514 L .62515 .3722 L F
.526 .774 .988 r
.62515 .3722 m .62681 .3704 L .62647 .37115 L F
.61 .324 .459 r
.62555 .37514 m .62807 .37497 L .62515 .3722 L F
.587 .328 .491 r
.62515 .3722 m .62807 .37497 L .62844 .372 L F
.406 .582 .912 r
.62647 .37115 m .62681 .3704 L .62515 .3722 L F
.987 .816 .427 r
.62555 .37514 m .62493 .37128 L .62807 .37497 L F
.62493 .37128 m .62531 .3715 L .62807 .37497 L F
.318 .224 .588 r
.62252 .37326 m .62406 .37713 L .62555 .37514 L F
0 0 .224 r
.62406 .37713 m .62293 .37966 L .62555 .37514 L F
0 0 0 r
.62293 .37966 m .62438 .37812 L .62555 .37514 L F
.591 .835 .991 r
.62252 .37326 m .62509 .3712 L .62195 .37198 L F
.565 .934 .81 r
.62509 .3712 m .61998 .37416 L .62252 .37326 L F
.579 .941 .821 r
.61995 .37359 m .61998 .37416 L .62509 .3712 L F
.61995 .37359 m .62509 .3712 L .62295 .37014 L F
.987 .816 .427 r
.62555 .37514 m .62438 .37812 L .62488 .37096 L F
.986 .797 .566 r
.62488 .37096 m .62438 .37812 L .623 .376 L F
.62506 .37137 m .623 .376 L .62736 .37687 L F
.62488 .37096 m .62479 .37121 L .62506 .37137 L F
.62479 .37121 m .623 .376 L .62506 .37137 L F
.452 0 0 r
.62263 .36992 m .62271 .36997 L .62278 .37001 L F
.62271 .36997 m .62295 .37014 L .62317 .37025 L F
.987 .816 .427 r
.62493 .37128 m .62488 .37096 L .62531 .3715 L F
.43 .269 .561 r
.4191 .53816 m .42119 .53704 L .41908 .53499 L F
.41908 .53499 m .42119 .53704 L .4191 .53816 L F
.264 .663 .967 r
.37571 .56604 m .37648 .56485 L .37409 .56477 L F
.37571 .56604 m .37799 .56608 L .37648 .56485 L F
0 0 0 r
.51483 .40658 m .51232 .40806 L .51536 .40618 L F
.212 0 .149 r
.51408 .40956 m .51232 .40806 L .51483 .40658 L F
.51408 .40956 m .51163 .41068 L .51232 .40806 L F
.708 .697 .837 r
.36703 .54596 m .36877 .54903 L .36424 .5482 L F
.784 .321 0 r
.55743 .39269 m .55818 .39241 L .55877 .38849 L F
.55743 .39269 m .55868 .39386 L .55818 .39241 L F
.816 .642 .667 r
.47395 .44696 m .4777 .44856 L .47779 .44663 L F
.47395 .44696 m .47577 .44929 L .4777 .44856 L F
.808 .619 .647 r
.47577 .44929 m .47542 .4522 L .4777 .44856 L F
.796 .603 .64 r
.47542 .4522 m .47948 .45287 L .4777 .44856 L F
.554 .844 .998 r
.60008 .37538 m .59761 .37666 L .60177 .37714 L F
.944 .614 .374 r
.59761 .37666 m .59914 .37808 L .60177 .37714 L F
.587 .861 .995 r
.60283 .37465 m .60177 .37714 L .60313 .3761 L F
.60283 .37465 m .60008 .37538 L .60177 .37714 L F
.771 .626 .7 r
.39857 .51049 m .40045 .51452 L .39609 .51407 L F
.822 .503 .449 r
.40029 .51744 m .39609 .51407 L .40045 .51452 L F
.8 .636 .679 r
.39857 .51049 m .39485 .50721 L .39916 .5079 L F
.045 0 0 r
.55203 .42495 m .55246 .42509 L .55062 .42534 L F
.55203 .42495 m .5551 .42499 L .55246 .42509 L F
.456 .791 .999 r
.38541 .54263 m .38122 .5422 L .38359 .54097 L F
.461 .255 .513 r
.5498 .36719 m .54704 .37068 L .54982 .36987 L F
.378 .319 .665 r
.54704 .37068 m .54981 .37298 L .54982 .36987 L F
.54704 .37068 m .54791 .37421 L .54981 .37298 L F
.736 .723 .839 r
.62436 .3838 m .62875 .38462 L .62615 .38324 L F
.811 .853 .88 r
.62875 .38462 m .6302 .37975 L .62615 .38324 L F
.62875 .38462 m .63193 .38186 L .6302 .37975 L F
.366 .818 .938 r
.53394 .41492 m .53537 .41543 L .53146 .41567 L F
0 0 0 r
.53352 .41718 m .53537 .41543 L .535 .41758 L F
.607 .938 .95 r
.53707 .41367 m .53537 .41543 L .53394 .41492 L F
.726 .923 .577 r
.5167 .41993 m .51828 .41853 L .51603 .42148 L F
.174 .298 .751 r
.52124 .4208 m .51828 .41853 L .52098 .41781 L F
.791 .525 .536 r
.5167 .41993 m .52098 .41781 L .51828 .41853 L F
.517 .395 .653 r
.55163 .38265 m .55328 .38342 L .55009 .38313 L F
.521 .281 .491 r
.55268 .38648 m .55004 .38744 L .55009 .38313 L F
.763 .622 .704 r
.35429 .49761 m .35351 .50105 L .35176 .50055 L F
.889 .833 .785 r
.45652 .497 m .45395 .50028 L .45747 .50061 L F
.867 .865 .835 r
.45747 .50061 m .45307 .50257 L .45494 .50416 L F
.45747 .50061 m .45395 .50028 L .45307 .50257 L F
.777 .65 .722 r
.39887 .52778 m .39501 .52452 L .39988 .5255 L F
.39887 .52778 m .39499 .52795 L .39501 .52452 L F
.773 .596 .659 r
.39887 .52778 m .39645 .53137 L .39499 .52795 L F
.58 .655 .888 r
.34475 .55799 m .34302 .55425 L .34484 .55552 L F
.593 .836 .99 r
.33465 .53014 m .33617 .53163 L .33793 .53039 L F
.516 .345 .587 r
.51583 .39618 m .51896 .39343 L .5168 .39483 L F
0 .022 .588 r
.59133 .38336 m .5903 .37975 L .59107 .381 L F
.811 .67 .707 r
.40029 .51744 m .40222 .52176 L .39804 .52125 L F
.815 .997 .775 r
.5508 .38984 m .54899 .3905 L .55268 .38648 L F
.795 .657 .711 r
.56932 .38014 m .57336 .38096 L .57396 .37787 L F
.9 .918 .823 r
.33689 .52689 m .33335 .52869 L .33292 .52783 L F
.33326 .5269 m .33292 .52783 L .33246 .5269 L F
.998 .783 .44 r
.33459 .52466 m .33409 .52717 L .33374 .52559 L F
.505 .228 .428 r
.33459 .52466 m .33689 .52689 L .33409 .52717 L F
.964 .803 .632 r
.33409 .52717 m .33246 .5269 L .33331 .52363 L F
.9 .918 .823 r
.33689 .52689 m .33246 .5269 L .33409 .52717 L F
.33689 .52689 m .33292 .52783 L .33326 .5269 L F
.998 .783 .44 r
.33419 .52434 m .33374 .52559 L .33331 .52363 L F
.33459 .52466 m .33374 .52559 L .33419 .52434 L F
.988 .885 .625 r
.33459 .52466 m .33331 .52363 L .33457 .52042 L F
.37 .395 .756 r
.39094 .54415 m .39027 .5475 L .38851 .54489 L F
.39094 .54415 m .39221 .54786 L .39027 .5475 L F
.029 .539 .871 r
.39027 .5475 m .39221 .54786 L .39267 .54827 L F
.891 .95 .838 r
.47299 .44426 m .47088 .449 L .47395 .44696 L F
.47299 .44426 m .46932 .44757 L .47088 .449 L F
.65 .613 .799 r
.47088 .449 m .47577 .44929 L .47395 .44696 L F
.723 .54 .643 r
.47082 .45189 m .47577 .44929 L .47088 .449 L F
.865 .64 .107 r
.47265 .44156 m .47299 .44426 L .47312 .44288 L F
0 .411 .714 r
.47299 .44426 m .47641 .44532 L .47312 .44288 L F
.63 .86 .986 r
.61888 .38885 m .62039 .38629 L .61729 .38696 L F
.61888 .38885 m .62187 .38771 L .62039 .38629 L F
.392 .091 .33 r
.35176 .50055 m .35059 .50278 L .34753 .50347 L F
.729 .405 .432 r
.35059 .50278 m .34672 .50528 L .34753 .50347 L F
.828 .931 .899 r
.43531 .51991 m .43372 .52404 L .43697 .52116 L F
.43531 .51991 m .43179 .52319 L .43372 .52404 L F
.427 .612 .927 r
.61787 .35445 m .62005 .35164 L .61656 .353 L F
.61787 .35445 m .6214 .35481 L .62005 .35164 L F
.876 .639 .576 r
.38335 .5041 m .3795 .50572 L .37922 .50321 L F
.38335 .5041 m .38312 .50667 L .3795 .50572 L F
.519 .009 0 r
.37586 .49221 m .3788 .49256 L .38073 .4912 L F
.504 0 0 r
.38073 .4912 m .3788 .49256 L .38285 .49253 L F
.87 .831 .806 r
.63681 .36222 m .63585 .36597 L .63804 .36365 L F
.896 .679 .601 r
.63585 .36597 m .63816 .36692 L .63804 .36365 L F
.787 .71 .779 r
.51416 .43597 m .51635 .43983 L .51185 .43856 L F
.742 .695 .806 r
.51753 .43768 m .51635 .43983 L .51416 .43597 L F
.844 .837 .839 r
.6214 .35481 m .62549 .35361 L .62405 .3521 L F
.792 .526 .535 r
.56932 .38014 m .5736 .38308 L .57336 .38096 L F
0 0 .269 r
.59036 .3673 m .59155 .36771 L .59088 .365 L F
.59036 .3673 m .59031 .37004 L .59155 .36771 L F
0 0 0 r
.50482 .41882 m .50408 .41817 L .50657 .41766 L F
.50482 .41882 m .50295 .4204 L .50408 .41817 L F
.63 .272 .344 r
.35351 .50105 m .35059 .50278 L .35176 .50055 L F
.35351 .50105 m .35361 .50306 L .35059 .50278 L F
0 0 0 r
.51483 .40658 m .51536 .40618 L .51803 .40516 L F
.09 0 .399 r
.34153 .51426 m .34168 .51719 L .34021 .51766 L F
.19 .271 .717 r
.34168 .51719 m .34286 .51997 L .34021 .51766 L F
.629 .111 0 r
.47767 .45398 m .47948 .45287 L .47542 .4522 L F
0 0 0 r
.48204 .45195 m .47948 .45287 L .47767 .45398 L F
.816 .642 .667 r
.47395 .44696 m .47779 .44663 L .47641 .44532 L F
.661 .872 .978 r
.47641 .44532 m .47779 .44663 L .47908 .44396 L F
.47908 .44396 m .47779 .44663 L .47641 .44532 L F
.47641 .44532 m .47779 .44663 L .47908 .44396 L F
.678 .394 .484 r
.3791 .50062 m .37495 .50313 L .37536 .50056 L F
.632 .689 .885 r
.3532 .56302 m .35739 .56514 L .35587 .56164 L F
.698 .703 .851 r
.35587 .56164 m .35739 .56514 L .35943 .56435 L F
.506 .232 .432 r
.4206 .48245 m .42377 .47954 L .4211 .48023 L F
.885 .911 .839 r
.42531 .53054 m .42908 .52884 L .42657 .52962 L F
.42531 .53054 m .42649 .53162 L .42908 .52884 L F
.78 .991 .887 r
.42985 .52687 m .42657 .52962 L .42908 .52884 L F
.486 .295 .546 r
.38586 .50808 m .38473 .51064 L .38312 .50667 L F
.38586 .50808 m .38748 .51009 L .38473 .51064 L F
.648 .88 .983 r
.50042 .45529 m .50449 .45536 L .50291 .45408 L F
.829 .953 .898 r
.50449 .45536 m .5067 .45104 L .50291 .45408 L F
.50449 .45536 m .5075 .45249 L .5067 .45104 L F
.742 .671 .781 r
.39804 .52125 m .39988 .5255 L .39501 .52452 L F
.552 .898 .67 r
.38352 .54711 m .38249 .54832 L .3854 .54774 L F
.38352 .54711 m .37997 .54989 L .38249 .54832 L F
.817 .84 .866 r
.48778 .46495 m .48964 .46667 L .49248 .46346 L F
.099 .324 .798 r
.54996 .39413 m .54899 .3905 L .54803 .39025 L F
.54996 .39413 m .55105 .39307 L .54899 .3905 L F
.998 .778 .456 r
.5736 .38308 m .57319 .38748 L .5745 .38791 L F
.754 .259 0 r
.57319 .38748 m .57409 .38797 L .5745 .38791 L F
.616 .888 .989 r
.51803 .40516 m .52233 .40512 L .52025 .4055 L F
.537 .755 .977 r
.52233 .40512 m .52343 .40256 L .52025 .4055 L F
.707 .902 .536 r
.52233 .40512 m .52501 .40127 L .52513 .40456 L F
.537 .755 .977 r
.52233 .40512 m .52513 .40456 L .52343 .40256 L F
.678 .394 .484 r
.3791 .50062 m .37922 .50321 L .37495 .50313 L F
.855 .992 .838 r
.39267 .54827 m .39221 .54786 L .39525 .54447 L F
.587 .294 .438 r
.4041 .48952 m .40821 .48641 L .40468 .48727 L F
.765 .987 .898 r
.52602 .44152 m .52973 .43898 L .52889 .43823 L F
.787 .935 .575 r
.53067 .43644 m .53117 .4367 L .532 .43536 L F
0 0 0 r
.53067 .43644 m .53347 .43513 L .53265 .43556 L F
.305 .799 .821 r
.53013 .43614 m .53067 .43644 L .53265 .43556 L F
.52749 .43675 m .53067 .43644 L .53013 .43614 L F
.787 .935 .575 r
.53067 .43644 m .52973 .43898 L .53117 .4367 L F
.782 .99 .887 r
.52889 .43823 m .52973 .43898 L .53067 .43644 L F
.041 0 .037 r
.56252 .39238 m .565 .39159 L .56374 .39105 L F
0 0 .343 r
.56374 .39105 m .565 .39159 L .56506 .38969 L F
.8 .636 .679 r
.39857 .51049 m .39426 .50997 L .39485 .50721 L F
.796 .663 .716 r
.39857 .51049 m .39609 .51407 L .39426 .50997 L F
0 0 0 r
.532 .43536 m .53347 .43513 L .53067 .43644 L F
.532 .43536 m .53461 .43415 L .53347 .43513 L F
.44821 .45915 m .44995 .45782 L .45133 .45607 L F
0 0 .519 r
.45133 .45607 m .45216 .45403 L .45046 .45196 L F
.042 0 0 r
.45133 .45607 m .4525 .45689 L .45216 .45403 L F
.45133 .45607 m .44995 .45782 L .4525 .45689 L F
.078 0 .221 r
.50455 .40507 m .50652 .40544 L .50726 .4043 L F
.50455 .40507 m .50416 .40725 L .50652 .40544 L F
.702 .782 .913 r
.45374 .4518 m .44993 .44924 L .45262 .44852 L F
.45374 .4518 m .45046 .45196 L .44993 .44924 L F
.185 .018 .408 r
.45046 .45196 m .45262 .44852 L .44993 .44924 L F
.642 .122 0 r
.45262 .44852 m .45713 .44947 L .45374 .4518 L F
.379 .162 .454 r
.49898 .41199 m .50167 .41093 L .50172 .40818 L F
.103 0 0 r
.49898 .41199 m .49798 .41348 L .50167 .41093 L F
0 0 0 r
.44821 .45915 m .44682 .46083 L .44995 .45782 L F
.693 .634 .786 r
.6079 .39052 m .60898 .39426 L .61201 .39124 L F
0 .492 .783 r
.34608 .55087 m .34965 .55205 L .34802 .55253 L F
.34608 .55087 m .34789 .55127 L .34965 .55205 L F
.91 .977 .784 r
.34965 .55205 m .35114 .54665 L .3522 .55176 L F
.34965 .55205 m .34789 .55127 L .35114 .54665 L F
.612 .181 .198 r
.38729 .49221 m .3899 .49253 L .38746 .49055 L F
.555 .218 .352 r
.38746 .49055 m .3899 .49253 L .39016 .4904 L F
.944 .614 .374 r
.59761 .37666 m .59834 .37915 L .59914 .37808 L F
.338 .131 .445 r
.50172 .40818 m .50167 .41093 L .50416 .40725 L F
0 .306 .747 r
.46852 .44998 m .46846 .45052 L .46932 .44757 L F
.46852 .44998 m .47082 .45189 L .46846 .45052 L F
0 0 .54 r
.5913 .39808 m .59171 .39661 L .59087 .39396 L F
0 .013 .551 r
.5913 .39808 m .59226 .40104 L .59171 .39661 L F
.347 .276 .633 r
.53093 .39986 m .52821 .40032 L .52731 .39659 L F
.79 .728 .795 r
.3796 .53805 m .38122 .5422 L .37719 .54173 L F
.663 .664 .84 r
.38359 .54097 m .38122 .5422 L .3796 .53805 L F
.569 .381 .587 r
.52821 .40032 m .52513 .40456 L .52501 .40127 L F
.9 .674 .587 r
.63732 .36963 m .6397 .3705 L .63816 .36692 L F
.897 .955 .829 r
.63585 .37254 m .6397 .3705 L .63732 .36963 L F
.63585 .37254 m .63697 .37389 L .6397 .3705 L F
.984 .736 .474 r
.39116 .55829 m .39259 .56228 L .39085 .56104 L F
.39116 .55829 m .39259 .56228 L .39085 .56104 L F
.797 .85 .89 r
.63193 .38186 m .63388 .37986 L .6302 .37975 L F
.765 .987 .898 r
.52602 .44152 m .52889 .43823 L .52559 .44135 L F
.788 .696 .763 r
.39351 .53474 m .38921 .53416 L .39202 .53065 L F
.735 .626 .738 r
.39332 .53779 m .38921 .53416 L .39351 .53474 L F
.732 .668 .787 r
.39645 .53137 m .39351 .53474 L .39202 .53065 L F
.997 .849 .518 r
.63585 .37254 m .63647 .37641 L .63697 .37389 L F
0 0 0 r
.49345 .42457 m .49751 .4224 L .49574 .42368 L F
.297 0 0 r
.49574 .42368 m .49751 .4224 L .49958 .42306 L F
.292 0 .022 r
.49751 .4224 m .50061 .42167 L .49958 .42306 L F
.084 .129 .611 r
.59004 .39133 m .59263 .39198 L .59165 .38915 L F
.59004 .39133 m .59087 .39396 L .59263 .39198 L F
.54 .869 .994 r
.54026 .40967 m .53776 .4106 L .53642 .4106 L F
.801 .387 .264 r
.37532 .52967 m .37358 .53034 L .37681 .53083 L F
.96 .763 .595 r
.60088 .36384 m .60308 .36698 L .60189 .36288 L F
.855 .449 0 r
.60088 .36384 m .60206 .36622 L .60308 .36698 L F
.49 .509 .804 r
.60189 .36288 m .60308 .36698 L .60248 .36272 L F
.994 .805 .434 r
.60308 .36698 m .60206 .36622 L .60248 .36272 L F
.969 .828 .648 r
.42431 .53379 m .42649 .53162 L .42531 .53054 L F
.42431 .53379 m .42604 .53493 L .42649 .53162 L F
0 .453 .781 r
.55907 .37575 m .56089 .37627 L .56273 .37711 L F
.81 .349 .133 r
.56089 .37627 m .565 .37943 L .56273 .37711 L F
.61 .073 0 r
.56273 .37711 m .565 .37943 L .56683 .38068 L F
.423 .772 .996 r
.4542 .44885 m .45622 .44835 L .45713 .44947 L F
.642 .122 0 r
.45713 .44947 m .45531 .45057 L .45262 .44852 L F
.45262 .44852 m .45531 .45057 L .45713 .44947 L F
.506 .822 1 r
.45622 .44835 m .45831 .44763 L .45713 .44947 L F
.29 .006 .297 r
.45622 .44835 m .45531 .45057 L .45804 .4479 L F
.45622 .44835 m .45804 .4479 L .45831 .44763 L F
.423 .772 .996 r
.45262 .44852 m .45622 .44835 L .4542 .44885 L F
.637 .961 .912 r
.45713 .44947 m .45831 .44763 L .45947 .4479 L F
.847 .484 .366 r
.565 .37943 m .56947 .38316 L .56683 .38068 L F
.543 .334 .545 r
.56683 .38068 m .56947 .38316 L .56932 .38014 L F
.868 .66 .619 r
.35229 .49348 m .34966 .4973 L .3535 .49552 L F
0 0 .235 r
.3535 .49552 m .35513 .49268 L .35229 .49348 L F
.3535 .49552 m .35473 .49514 L .35513 .49268 L F
.723 .506 .596 r
.54982 .36987 m .55502 .37286 L .55439 .3704 L F
.829 .733 .758 r
.42119 .53704 m .42604 .53493 L .42431 .53379 L F
.42119 .53704 m .42397 .53881 L .42604 .53493 L F
.773 .712 .794 r
.55868 .39386 m .56269 .39501 L .56252 .39238 L F
.596 .418 .611 r
.56252 .39238 m .5654 .39444 L .565 .39159 L F
.56252 .39238 m .56269 .39501 L .5654 .39444 L F
.786 .978 .908 r
.5705 .39128 m .56952 .39405 L .57301 .39147 L F
.827 .996 .762 r
.5705 .39128 m .56891 .39354 L .56952 .39405 L F
.677 .356 .424 r
.54314 .38764 m .54052 .38826 L .53842 .38655 L F
.54314 .38764 m .54303 .38992 L .54052 .38826 L F
.393 .127 .387 r
.54609 .38891 m .54314 .38764 L .54892 .3903 L F
.54609 .38891 m .54303 .38992 L .54314 .38764 L F
.676 .425 .534 r
.36377 .50021 m .3606 .50292 L .36099 .50067 L F
.981 .693 .386 r
.5275 .38875 m .52918 .38757 L .52564 .38791 L F
.543 .606 .866 r
.52923 .39582 m .52937 .39511 L .529 .39289 L F
.981 .693 .386 r
.52858 .38799 m .52993 .39188 L .52918 .38757 L F
.52886 .39051 m .52993 .39188 L .52858 .38799 L F
.917 .945 .594 r
.52914 .39088 m .52993 .39188 L .52886 .39051 L F
.52954 .3914 m .52993 .39188 L .52914 .39088 L F
.52936 .39118 m .52886 .39051 L .5275 .38875 L F
.981 .693 .386 r
.5275 .38875 m .52886 .39051 L .52858 .38799 L F
.079 .252 .741 r
.53001 .39201 m .52977 .3917 L .53161 .39059 L F
.52977 .3917 m .5275 .38875 L .5302 .38996 L F
.52977 .3917 m .5302 .38996 L .53161 .39059 L F
.044 0 .123 r
.53193 .38423 m .53042 .38744 L .52949 .38719 L F
.53042 .38744 m .53027 .38777 L .53014 .38767 L F
.53042 .38744 m .53014 .38767 L .52949 .38719 L F
.667 .372 .463 r
.53418 .38823 m .53193 .38423 L .53445 .38293 L F
.53418 .38823 m .53036 .3889 L .53193 .38423 L F
.044 0 .123 r
.52949 .38719 m .52968 .38901 L .52918 .38757 L F
.798 .605 .641 r
.52903 .38944 m .5302 .38996 L .53033 .38856 L F
.044 0 .123 r
.52968 .38901 m .52968 .38902 L .52968 .38902 L F
.52968 .38901 m .52968 .38902 L .52918 .38757 L F
.53027 .38777 m .52968 .38902 L .52949 .38719 L F
0 0 .342 r
.52918 .38757 m .52908 .38646 L .52791 .38338 L F
.765 .412 .386 r
.52965 .38889 m .5275 .38875 L .52908 .38646 L F
.798 .605 .641 r
.5275 .38875 m .52903 .38944 L .53057 .38583 L F
.765 .412 .386 r
.52968 .38902 m .5275 .38875 L .52965 .38889 L F
.798 .605 .641 r
.52903 .38944 m .52969 .389 L .52972 .3889 L F
.52928 .38887 m .52972 .3889 L .53057 .38583 L F
.52903 .38944 m .52972 .3889 L .52928 .38887 L F
.667 .372 .463 r
.53033 .38856 m .52969 .389 L .53027 .38777 L F
.798 .605 .641 r
.52969 .389 m .53033 .38856 L .53039 .38787 L F
.52969 .389 m .53039 .38787 L .53057 .38583 L F
.667 .372 .463 r
.53036 .3889 m .52968 .38902 L .52969 .389 L F
.53036 .3889 m .52969 .389 L .53033 .38856 L F
.53036 .3889 m .53027 .38777 L .53193 .38423 L F
0 0 .338 r
.53039 .38787 m .53033 .38856 L .53067 .38808 L F
.735 .604 .711 r
.53419 .38807 m .53036 .38888 L .53418 .38823 L F
.53036 .38888 m .52968 .38902 L .53036 .3889 L F
.53036 .38888 m .53036 .3889 L .53418 .38823 L F
0 0 .338 r
.53033 .38856 m .53027 .38927 L .53036 .3889 L F
.53044 .38841 m .53038 .38924 L .53067 .38808 L F
.53033 .38856 m .53036 .38891 L .53044 .38841 L F
.53036 .38891 m .53038 .38924 L .53044 .38841 L F
.735 .604 .711 r
.53419 .38807 m .53235 .38995 L .5303 .38924 L F
.53036 .38888 m .5303 .38924 L .52968 .38902 L F
.53419 .38807 m .5303 .38924 L .53036 .38888 L F
.53516 .38787 m .53419 .38807 L .53418 .38823 L F
.53516 .38787 m .53416 .38861 L .53419 .38807 L F
.53416 .38861 m .53235 .38995 L .53419 .38807 L F
0 0 .097 r
.53453 .38337 m .53418 .38823 L .53445 .38293 L F
.53461 .38374 m .53419 .38807 L .53453 .38337 L F
.53419 .38807 m .53418 .38823 L .53453 .38337 L F
.53485 .38499 m .53418 .38823 L .53461 .38374 L F
.765 .412 .386 r
.52968 .38902 m .5303 .38924 L .5275 .38875 L F
.5303 .38924 m .53235 .38995 L .53033 .38945 L F
0 0 .338 r
.53027 .38927 m .5302 .38996 L .53036 .3889 L F
.765 .412 .386 r
.5303 .38924 m .53033 .38945 L .5275 .38875 L F
0 0 .338 r
.53036 .3889 m .53031 .38925 L .53038 .38924 L F
.53031 .38925 m .5302 .38996 L .53033 .38945 L F
.53031 .38925 m .53033 .38945 L .53038 .38924 L F
.489 .416 .701 r
.52974 .38225 m .53057 .38583 L .53388 .38462 L F
.53426 .3843 m .53388 .38462 L .53447 .3844 L F
.52974 .38225 m .53388 .38462 L .53426 .3843 L F
0 0 .338 r
.53057 .38583 m .53039 .38787 L .53119 .38598 L F
.53039 .38787 m .53067 .38808 L .53119 .38598 L F
.079 .252 .741 r
.53161 .39059 m .5275 .38875 L .53235 .38995 L F
0 0 .338 r
.53119 .38598 m .53017 .3904 L .53252 .38631 L F
.5302 .38996 m .53017 .3904 L .53119 .38598 L F
.798 .605 .641 r
.5275 .38875 m .53017 .3904 L .5302 .38996 L F
.917 .945 .594 r
.52954 .3914 m .529 .39289 L .52993 .39188 L F
.079 .252 .741 r
.529 .39289 m .52778 .38953 L .52954 .3914 L F
.52778 .38953 m .5275 .38875 L .528 .38941 L F
.52778 .38953 m .528 .38941 L .52954 .3914 L F
.917 .945 .594 r
.52921 .391 m .52936 .39118 L .5275 .38875 L F
.079 .252 .741 r
.52778 .38953 m .53024 .39081 L .5275 .38875 L F
.917 .945 .594 r
.52921 .391 m .529 .39289 L .52954 .3914 L F
.809 .595 .613 r
.52914 .39106 m .529 .39289 L .52921 .391 L F
.079 .252 .741 r
.529 .39289 m .52914 .39109 L .52778 .38953 L F
.52914 .39109 m .52914 .39105 L .52902 .39092 L F
.52914 .39109 m .52902 .39092 L .52778 .38953 L F
.6 .383 .558 r
.52477 .38916 m .52902 .39092 L .5275 .38875 L F
.52902 .39092 m .52921 .391 L .5275 .38875 L F
.809 .595 .613 r
.52471 .39484 m .529 .39289 L .52914 .39106 L F
.079 .252 .741 r
.529 .39289 m .52972 .39169 L .52914 .39105 L F
.6 .383 .558 r
.52902 .39092 m .52914 .39105 L .52921 .391 L F
.917 .945 .594 r
.52936 .39118 m .52954 .3914 L .52914 .39088 L F
.732 .623 .736 r
.52624 .39311 m .52471 .39484 L .52914 .39106 L F
.52914 .39105 m .52914 .39106 L .52921 .391 L F
.52624 .39311 m .52914 .39106 L .52914 .39105 L F
.079 .252 .741 r
.52972 .39169 m .53024 .39081 L .52865 .38998 L F
.52914 .39105 m .52865 .38998 L .52778 .38953 L F
.52972 .39169 m .52865 .38998 L .52914 .39105 L F
.6 .383 .558 r
.5269 .39004 m .52624 .39311 L .52914 .39105 L F
.5269 .39004 m .52914 .39105 L .52902 .39092 L F
.52477 .38916 m .52542 .3909 L .5269 .39004 L F
.52542 .3909 m .52624 .39311 L .5269 .39004 L F
.079 .252 .741 r
.529 .39289 m .52954 .3914 L .53001 .39201 L F
.543 .606 .866 r
.52937 .39511 m .52999 .39203 L .52911 .39272 L F
.52999 .39203 m .53024 .39081 L .52973 .39167 L F
.52999 .39203 m .52973 .39167 L .52911 .39272 L F
.52937 .39511 m .52911 .39272 L .529 .39289 L F
.362 .73 .988 r
.625 .36654 m .62712 .36616 L .62331 .36499 L F
.623 .36495 m .62331 .36499 L .6229 .36487 L F
.799 .718 .185 r
.62712 .36616 m .62673 .36642 L .6229 .36487 L F
.443 0 0 r
.62673 .36642 m .62514 .36524 L .6229 .36487 L F
.62673 .36642 m .62427 .36562 L .62514 .36524 L F
.234 0 0 r
.62539 .3653 m .62427 .36562 L .62829 .36601 L F
.62514 .36524 m .6251 .36526 L .62539 .3653 L F
.6251 .36526 m .62427 .36562 L .62539 .3653 L F
.362 .73 .988 r
.625 .36654 m .62331 .36499 L .623 .36495 L F
.698 .703 .851 r
.35587 .56164 m .35943 .56435 L .35883 .56074 L F
.652 .673 .857 r
.35883 .56074 m .35943 .56435 L .36282 .56173 L F
.655 .721 .897 r
.36254 .54509 m .36424 .5482 L .36006 .5474 L F
.738 .602 .706 r
.36424 .5482 m .36152 .5518 L .36006 .5474 L F
.734 .757 .871 r
.36703 .54596 m .36424 .5482 L .36254 .54509 L F
.724 .467 .538 r
.36758 .50311 m .36377 .50021 L .3674 .50076 L F
.558 .7 .936 r
.38473 .51064 m .38062 .50802 L .38312 .50667 L F
.547 .16 .259 r
.38473 .51064 m .38257 .51301 L .38041 .51316 L F
.7 .351 .382 r
.38683 .51305 m .38473 .51064 L .38748 .51009 L F
.38683 .51305 m .38257 .51301 L .38473 .51064 L F
.445 .104 .293 r
.48309 .42705 m .48642 .4246 L .48411 .42532 L F
.426 .113 .329 r
.41421 .48623 m .41775 .48281 L .41423 .48332 L F
.558 .313 .501 r
.41115 .48649 m .41421 .48623 L .41423 .48332 L F
.81 .742 .788 r
.42264 .54042 m .42397 .53881 L .42119 .53704 L F
.803 .985 .891 r
.53331 .39084 m .53516 .38787 L .53605 .39025 L F
.53331 .39084 m .53235 .38995 L .53516 .38787 L F
.478 .306 .569 r
.536 .39301 m .53331 .39084 L .53605 .39025 L F
.536 .39301 m .53352 .39403 L .53331 .39084 L F
.759 .91 .942 r
.46135 .49133 m .4661 .49043 L .46436 .48901 L F
.885 .889 .829 r
.46436 .48901 m .4661 .49043 L .46878 .48683 L F
.594 .634 .861 r
.42264 .54042 m .41901 .54035 L .42113 .54144 L F
.42264 .54042 m .4191 .53816 L .41901 .54035 L F
.42264 .54042 m .42119 .53704 L .4191 .53816 L F
.567 .896 .984 r
.6059 .37326 m .60313 .3761 L .60755 .37362 L F
.6059 .37326 m .60283 .37465 L .60313 .3761 L F
0 .137 .669 r
.51603 .42148 m .51726 .42282 L .5167 .41993 L F
.749 .668 .772 r
.35274 .53055 m .35428 .53467 L .3501 .53436 L F
.687 .283 .275 r
.3501 .53436 m .35428 .53467 L .35456 .53689 L F
.462 .505 .817 r
.35607 .53219 m .35428 .53467 L .35274 .53055 L F
.694 .555 .693 r
.35607 .53219 m .35456 .53689 L .35428 .53467 L F
.372 .032 .254 r
.5443 .37697 m .54721 .37624 L .54791 .37421 L F
.037 0 .111 r
.54791 .37421 m .54721 .37624 L .54981 .37298 L F
.732 .969 .933 r
.35254 .55367 m .35063 .55537 L .35166 .55594 L F
.601 .076 0 r
.3505 .55657 m .354 .5577 L .35166 .55594 L F
.206 .723 .688 r
.50631 .44624 m .50472 .44668 L .502 .44748 L F
.50631 .44624 m .50472 .44668 L .502 .44748 L F
.551 .511 .764 r
.50892 .44498 m .50631 .44624 L .50467 .44132 L F
.185 .018 .408 r
.45046 .45196 m .45265 .45082 L .45262 .44852 L F
.174 0 .386 r
.45046 .45196 m .45216 .45403 L .45265 .45082 L F
.913 .969 .795 r
.46878 .48683 m .47136 .48319 L .47018 .48238 L F
.788 .97 .916 r
.47136 .48319 m .47205 .48043 L .47018 .48238 L F
.47136 .48319 m .47499 .48028 L .47205 .48043 L F
0 0 .277 r
.34298 .51207 m .34153 .51426 L .34217 .51024 L F
.083 0 .397 r
.34392 .51505 m .34153 .51426 L .34298 .51207 L F
.34392 .51505 m .34168 .51719 L .34153 .51426 L F
.708 .543 .663 r
.39485 .50721 m .38975 .50949 L .39049 .5073 L F
.844 .786 .795 r
.37358 .53034 m .37383 .53341 L .37681 .53083 L F
.742 .695 .806 r
.51753 .43768 m .51416 .43597 L .51715 .43475 L F
.818 .84 .865 r
.51715 .43475 m .5207 .43399 L .51753 .43768 L F
.353 .707 .985 r
.6115 .37416 m .61282 .37236 L .61015 .37245 L F
.6115 .37416 m .61465 .37435 L .61282 .37236 L F
.366 .818 .938 r
.53394 .41492 m .53146 .41567 L .53074 .41695 L F
.764 .709 .801 r
.535 .41758 m .5393 .4184 L .53527 .42074 L F
.949 .604 .321 r
.5393 .4184 m .54279 .41516 L .54179 .41755 L F
.611 .061 0 r
.54379 .42195 m .5393 .4184 L .54179 .41755 L F
0 0 .058 r
.54179 .41755 m .54279 .41516 L .54429 .41366 L F
.9 .674 .587 r
.63732 .36963 m .63816 .36692 L .63585 .36597 L F
.723 .54 .643 r
.47082 .45189 m .47542 .4522 L .47577 .44929 L F
.904 .909 .815 r
.43795 .51623 m .43697 .52116 L .43994 .51793 L F
.43795 .51623 m .43531 .51991 L .43697 .52116 L F
.885 .889 .829 r
.46436 .48901 m .46878 .48683 L .46753 .48584 L F
.913 .969 .795 r
.46878 .48683 m .47018 .48238 L .46753 .48584 L F
.754 .977 .92 r
.57402 .38888 m .57301 .39147 L .57409 .38797 L F
.57402 .38888 m .5705 .39128 L .57301 .39147 L F
.456 .666 .953 r
.37163 .56505 m .37303 .56315 L .36979 .56345 L F
.37163 .56505 m .37409 .56477 L .37303 .56315 L F
.626 .618 .823 r
.34764 .5576 m .34908 .56158 L .35166 .55887 L F
.623 .612 .819 r
.34908 .56158 m .3532 .56302 L .35166 .55887 L F
0 0 .467 r
.5903 .37975 m .59039 .37529 L .58984 .37739 L F
.753 .709 .81 r
.39945 .56494 m .40392 .5656 L .40179 .56368 L F
.587 .294 .438 r
.4041 .48952 m .40826 .48861 L .40821 .48641 L F
.623 .317 .431 r
.40826 .48861 m .41115 .48649 L .40821 .48641 L F
.682 .559 .71 r
.39332 .53779 m .39116 .54158 L .39094 .53834 L F
.39332 .53779 m .39524 .54134 L .39116 .54158 L F
.703 .494 .603 r
.39524 .54134 m .39094 .54415 L .39116 .54158 L F
.921 .817 .727 r
.535 .41758 m .53527 .42074 L .53371 .42062 L F
.8 .943 .591 r
.53527 .42074 m .53313 .42408 L .53445 .42322 L F
.53527 .42074 m .53445 .42322 L .53371 .42062 L F
.956 .64 .39 r
.38094 .51146 m .38041 .51316 L .37821 .51167 L F
.946 .77 .308 r
.38062 .50802 m .38094 .51146 L .38008 .50699 L F
.971 .904 .692 r
.38094 .51146 m .37821 .51167 L .38008 .50699 L F
.822 .503 .449 r
.40029 .51744 m .39642 .51702 L .39609 .51407 L F
.81 .668 .707 r
.40029 .51744 m .39558 .52006 L .39642 .51702 L F
.40029 .51744 m .39804 .52125 L .39558 .52006 L F
.786 .664 .112 r
.41526 .53894 m .41514 .54354 L .4166 .54142 L F
.249 .007 .338 r
.4166 .54142 m .41901 .54035 L .41907 .5389 L F
.41722 .54061 m .41907 .5389 L .4191 .53816 L F
.4166 .54142 m .41907 .5389 L .41722 .54061 L F
.854 .504 .391 r
.41617 .53984 m .41901 .54035 L .4191 .53816 L F
.76 .994 .87 r
.42119 .53704 m .41901 .54035 L .4191 .53816 L F
.4209 .5372 m .42026 .53637 L .41617 .53984 L F
.42119 .53704 m .42113 .537 L .4209 .5372 L F
.42113 .537 m .42026 .53637 L .4209 .5372 L F
.309 .123 .458 r
.41845 .54358 m .41901 .54035 L .4166 .54142 L F
.638 .291 .366 r
.39016 .4904 m .3942 .49212 L .39433 .49007 L F
.608 .267 .367 r
.3942 .49212 m .39693 .49236 L .39433 .49007 L F
.604 .269 .376 r
.39433 .49007 m .39693 .49236 L .39757 .49016 L F
.801 .854 .89 r
.5075 .45249 m .50886 .44783 L .5067 .45104 L F
.5075 .45249 m .51091 .44985 L .50886 .44783 L F
.726 .633 .755 r
.39426 .50997 m .39609 .51407 L .39157 .51325 L F
.643 .489 .659 r
.39642 .51702 m .39157 .51325 L .39609 .51407 L F
.426 .199 .464 r
.35229 .49348 m .35513 .49268 L .35556 .48995 L F
.487 .301 .554 r
.48642 .4246 m .48904 .42093 L .48642 .42168 L F
.509 .235 .434 r
.53707 .41367 m .54026 .40967 L .53642 .4106 L F
.782 .655 .722 r
.39499 .52795 m .39278 .52794 L .39501 .52452 L F
.756 .589 .67 r
.39499 .52795 m .39202 .53065 L .39278 .52794 L F
.39499 .52795 m .39645 .53137 L .39202 .53065 L F
.804 .72 .772 r
.61281 .36674 m .61023 .36825 L .61029 .36692 L F
.37 .177 .484 r
.59085 .36268 m .59335 .35896 L .59073 .35984 L F
0 0 .008 r
.44242 .46319 m .44144 .46512 L .44434 .4618 L F
.782 .715 .79 r
.5584 .39649 m .56041 .39797 L .55868 .39386 L F
.773 .712 .794 r
.55868 .39386 m .56041 .39797 L .56269 .39501 L F
.439 .128 .341 r
.5128 .4003 m .51583 .39618 L .5145 .39869 L F
.516 .345 .587 r
.51583 .39618 m .52066 .39468 L .51896 .39343 L F
.578 .281 .427 r
.51583 .39618 m .52114 .39724 L .52066 .39468 L F
.86 .661 .633 r
.63242 .35615 m .63212 .35933 L .63438 .35965 L F
.679 .28 .283 r
.6325 .36164 m .63438 .35965 L .63212 .35933 L F
.6325 .36164 m .63681 .36222 L .63438 .35965 L F
.811 .909 .908 r
.34802 .55253 m .34302 .55425 L .34608 .55087 L F
0 0 .095 r
.53527 .38235 m .53591 .38091 L .53571 .38121 L F
1 .817 .513 r
.53878 .38384 m .53747 .38261 L .53502 .38287 L F
.53878 .38384 m .53502 .38287 L .53494 .38303 L F
0 0 .097 r
.53485 .38499 m .53465 .38394 L .53747 .38261 L F
1 .817 .513 r
.53494 .38303 m .53502 .38287 L .53445 .38293 L F
0 0 .097 r
.53465 .38394 m .53445 .38293 L .53502 .38287 L F
.53465 .38394 m .53502 .38287 L .53747 .38261 L F
0 0 .095 r
.53464 .38397 m .53567 .38149 L .53527 .38235 L F
.53447 .3844 m .53458 .38413 L .53464 .38397 L F
.53458 .38413 m .53567 .38149 L .53464 .38397 L F
.53567 .38149 m .53591 .38091 L .53527 .38235 L F
1 .817 .513 r
.53878 .38384 m .53842 .38655 L .53747 .38261 L F
.476 .177 .378 r
.53586 .38009 m .53984 .37921 L .53729 .37699 L F
0 0 0 r
.51483 .40658 m .51803 .40516 L .5182 .40585 L F
.472 .174 .378 r
.5182 .40585 m .51408 .40956 L .51483 .40658 L F
.63 .697 .893 r
.36006 .5474 m .35564 .54471 L .35827 .54356 L F
.633 .679 .876 r
.36254 .54509 m .36006 .5474 L .35827 .54356 L F
.627 .614 .818 r
.54609 .41982 m .54379 .42195 L .54179 .41755 L F
.419 0 0 r
.62514 .35721 m .62395 .35797 L .62822 .35834 L F
.766 .532 .58 r
.61327 .38593 m .61729 .38696 L .61732 .38312 L F
0 0 .342 r
.61732 .38312 m .619 .38284 L .62017 .38315 L F
.61732 .38312 m .6189 .38461 L .619 .38284 L F
.61732 .38312 m .61729 .38696 L .6189 .38461 L F
.824 .851 .868 r
.49299 .46051 m .4909 .46198 L .49462 .46199 L F
.81 .866 .889 r
.4909 .46198 m .49248 .46346 L .49462 .46199 L F
.871 .848 .819 r
.49299 .46051 m .49462 .46199 L .49716 .4585 L F
.817 .84 .866 r
.48778 .46495 m .49248 .46346 L .4909 .46198 L F
.561 .889 .63 r
.50816 .41593 m .50482 .41882 L .50657 .41766 L F
.518 .871 .627 r
.53313 .42408 m .52933 .42699 L .53237 .42699 L F
0 0 0 r
.53445 .42322 m .53313 .42408 L .53237 .42699 L F
.548 .469 .719 r
.52789 .41394 m .5281 .41667 L .52681 .41624 L F
.452 .538 .855 r
.5281 .41667 m .53074 .41695 L .52681 .41624 L F
.623 .941 .726 r
.54758 .42668 m .54337 .42966 L .54477 .42716 L F
.895 .8 .746 r
.55411 .4033 m .55721 .40412 L .55603 .40014 L F
.883 .991 .758 r
.55406 .40642 m .55721 .40412 L .55411 .4033 L F
.55406 .40642 m .55453 .40764 L .55721 .40412 L F
.638 .291 .366 r
.39016 .4904 m .3899 .49253 L .3942 .49212 L F
.339 .031 .287 r
.43578 .46924 m .43851 .46848 L .43904 .46613 L F
.477 .149 .332 r
.43904 .46613 m .44141 .46792 L .44144 .46512 L F
.43904 .46613 m .43851 .46848 L .44141 .46792 L F
.069 .093 .577 r
.34308 .50643 m .34338 .50932 L .34217 .51024 L F
0 0 .277 r
.34298 .51207 m .34217 .51024 L .34338 .50932 L F
.735 .626 .738 r
.39332 .53779 m .39094 .53834 L .38921 .53416 L F
.58 .655 .888 r
.34475 .55799 m .34567 .55378 L .34302 .55425 L F
.34475 .55799 m .34764 .5576 L .34567 .55378 L F
.778 .694 .771 r
.62293 .37966 m .62436 .3838 L .62017 .38315 L F
.974 .672 .297 r
.62187 .38771 m .62017 .38315 L .62436 .3838 L F
.62187 .38771 m .62436 .3838 L .62331 .38246 L F
.949 .845 .706 r
.62712 .38031 m .62436 .3838 L .62293 .37966 L F
.62712 .38031 m .62331 .38246 L .62436 .3838 L F
.621 .464 .648 r
.62436 .3838 m .62615 .38324 L .62712 .38031 L F
.879 .926 .539 r
.5553 .42249 m .5551 .42499 L .55672 .42091 L F
.835 .992 .857 r
.55246 .42509 m .5551 .42499 L .5553 .42249 L F
.797 .949 .92 r
.60224 .3923 m .60379 .38986 L .60057 .39298 L F
.253 .61 .955 r
.38271 .5677 m .38362 .56643 L .38134 .56643 L F
.873 .925 .857 r
.37395 .54452 m .37513 .54011 L .37719 .54173 L F
.37395 .54452 m .37224 .5435 L .37513 .54011 L F
.161 .659 .914 r
.61875 .37433 m .61998 .37416 L .61995 .37359 L F
.839 .784 .799 r
.6302 .37975 m .63388 .37986 L .63241 .37689 L F
.835 .783 .802 r
.63241 .37689 m .63388 .37986 L .63647 .37641 L F
.946 .77 .308 r
.38062 .50802 m .3795 .50572 L .38312 .50667 L F
.65 .114 0 r
.55736 .38684 m .55544 .38572 L .55328 .38342 L F
.794 .804 .859 r
.55736 .38684 m .55268 .38648 L .55544 .38572 L F
.852 .927 .878 r
.5586 .38247 m .55736 .38684 L .55981 .38326 L F
.5586 .38247 m .55544 .38572 L .55736 .38684 L F
.988 .792 .554 r
.55736 .38684 m .55741 .38868 L .55544 .38572 L F
0 .287 .77 r
.55544 .38572 m .55877 .38849 L .55736 .38684 L F
.444 .165 .394 r
.49345 .42457 m .49023 .42732 L .49094 .42539 L F
.871 .848 .819 r
.49299 .46051 m .49716 .4585 L .49602 .45734 L F
.92 .967 .783 r
.49857 .45377 m .49716 .4585 L .50042 .45529 L F
.49857 .45377 m .49602 .45734 L .49716 .4585 L F
.642 .624 .816 r
.35166 .55887 m .3532 .56302 L .35587 .56164 L F
.735 .706 .823 r
.35652 .55128 m .3522 .55176 L .35365 .54815 L F
.909 .741 .66 r
.35652 .55128 m .35254 .55367 L .3522 .55176 L F
.35652 .55128 m .35496 .55491 L .35254 .55367 L F
.482 .799 1 r
.50525 .43917 m .50675 .44083 L .50467 .44132 L F
.764 .992 .786 r
.50467 .44132 m .50358 .44107 L .50525 .43917 L F
.551 .511 .764 r
.50892 .44498 m .50467 .44132 L .50675 .44083 L F
.937 .849 .73 r
.39278 .52794 m .393 .52307 L .39501 .52452 L F
.818 .815 .847 r
.39804 .52125 m .39501 .52452 L .393 .52307 L F
.754 .259 0 r
.57319 .38748 m .57402 .38888 L .57409 .38797 L F
.374 .84 .811 r
.47867 .43824 m .47816 .4381 L .47494 .43931 L F
0 0 0 r
.48136 .43511 m .48044 .43649 L .47867 .43824 L F
.388 .259 .581 r
.48151 .43432 m .47971 .4376 L .48044 .43649 L F
.556 .926 .779 r
.48044 .43649 m .47816 .4381 L .47867 .43824 L F
0 0 0 r
.47949 .438 m .47816 .4381 L .48044 .43649 L F
.388 .259 .581 r
.47971 .4376 m .47949 .438 L .48044 .43649 L F
0 0 0 r
.48171 .4347 m .48044 .43649 L .48136 .43511 L F
.791 .531 .545 r
.35556 .48995 m .35513 .49268 L .35897 .49271 L F
.703 .494 .603 r
.39524 .54134 m .39525 .54447 L .39094 .54415 L F
.918 .727 .629 r
.42073 .54487 m .42113 .54144 L .41901 .54035 L F
.763 .649 .736 r
.54052 .38826 m .53605 .39025 L .53842 .38655 L F
.755 .553 .623 r
.54052 .38826 m .536 .39301 L .53605 .39025 L F
.54052 .38826 m .54109 .39512 L .536 .39301 L F
.261 .185 .578 r
.5429 .3933 m .54052 .38826 L .54303 .38992 L F
.5429 .3933 m .54109 .39512 L .54052 .38826 L F
.831 .802 .824 r
.63585 .37254 m .63241 .37689 L .63647 .37641 L F
.949 .845 .706 r
.62712 .38031 m .62479 .38118 L .62331 .38246 L F
.62712 .38031 m .62615 .38324 L .62479 .38118 L F
.724 .405 .438 r
.37224 .5058 m .36758 .50311 L .372 .50373 L F
.768 .531 .575 r
.37495 .50313 m .37224 .5058 L .372 .50373 L F
.426 .113 .329 r
.41421 .48623 m .41698 .48564 L .41775 .48281 L F
.502 .182 .357 r
.41775 .48281 m .42018 .48464 L .4206 .48245 L F
.41775 .48281 m .41698 .48564 L .42018 .48464 L F
.974 .876 .497 r
.33457 .52042 m .33373 .51874 L .33536 .51695 L F
0 0 .032 r
.33536 .51695 m .33618 .515 L .33653 .51243 L F
.715 .896 .518 r
.33536 .51695 m .33373 .51874 L .33618 .515 L F
.751 .633 .73 r
.38921 .53416 m .39094 .53834 L .38656 .53772 L F
0 0 0 r
.5443 .37697 m .5454 .37725 L .54721 .37624 L F
.5443 .37697 m .54267 .37827 L .5454 .37725 L F
.974 .672 .297 r
.62187 .38771 m .62331 .38246 L .62231 .38408 L F
.887 .916 .839 r
.62039 .38629 m .62187 .38771 L .62231 .38408 L F
.663 .664 .84 r
.38359 .54097 m .3796 .53805 L .38215 .53705 L F
.717 .649 .78 r
.38656 .53772 m .38359 .54097 L .38215 .53705 L F
.853 .833 .827 r
.43795 .51623 m .43994 .51793 L .44291 .5143 L F
0 0 .446 r
.59087 .39396 m .59217 .39445 L .59263 .39198 L F
.59087 .39396 m .59171 .39661 L .59217 .39445 L F
.697 .276 .243 r
.35513 .49268 m .35746 .49511 L .35897 .49271 L F
.262 0 .001 r
.35746 .49511 m .36186 .49203 L .35897 .49271 L F
.605 .632 .851 r
.47299 .44426 m .47395 .44696 L .47641 .44532 L F
.453 .223 .475 r
.49031 .43033 m .4878 .42824 L .49023 .42732 L F
.49031 .43033 m .48757 .43112 L .4878 .42824 L F
.586 .666 .894 r
.33981 .54586 m .33944 .54865 L .34002 .54586 L F
.34002 .54586 m .33944 .54865 L .33793 .54582 L F
.34002 .54586 m .34002 .54587 L .34002 .54586 L F
.34002 .54587 m .33944 .54865 L .34002 .54586 L F
.899 .584 .09 r
.33981 .54484 m .33979 .54533 L .33836 .54114 L F
.586 .666 .894 r
.33793 .54582 m .33836 .54663 L .33981 .54586 L F
.33836 .54663 m .33944 .54865 L .33981 .54586 L F
.272 0 0 r
.34002 .54586 m .33975 .54627 L .33793 .54582 L F
.899 .584 .09 r
.33979 .54533 m .33975 .54627 L .33897 .5434 L F
.33979 .54533 m .33897 .5434 L .33836 .54114 L F
0 0 0 r
.34274 .5445 m .33975 .54627 L .34057 .54545 L F
.34244 .54445 m .34057 .54545 L .3417 .54434 L F
.34274 .5445 m .34057 .54545 L .34244 .54445 L F
.693 .634 .786 r
.6079 .39052 m .61201 .39124 L .61033 .38901 L F
.732 .667 .787 r
.61201 .39124 m .61441 .38957 L .61033 .38901 L F
.29 .05 .366 r
.48054 .42821 m .4778 .43176 L .48009 .43059 L F
0 0 .451 r
.4778 .43176 m .47958 .43317 L .48009 .43059 L F
.981 .693 .386 r
.5275 .38875 m .52564 .38791 L .52477 .38916 L F
.623 .317 .431 r
.40826 .48861 m .41081 .48882 L .41115 .48649 L F
.481 .165 .352 r
.41081 .48882 m .41421 .48623 L .41115 .48649 L F
.708 .543 .663 r
.39485 .50721 m .39426 .50997 L .38975 .50949 L F
.801 .854 .89 r
.50886 .44783 m .51091 .44985 L .51259 .44774 L F
.823 .919 .901 r
.51764 .44313 m .51859 .44417 L .51864 .44193 L F
.711 .793 .915 r
.51859 .44417 m .52119 .44051 L .51864 .44193 L F
.51859 .44417 m .52309 .44277 L .52119 .44051 L F
.792 .526 .535 r
.56932 .38014 m .56947 .38316 L .5736 .38308 L F
.904 .659 .558 r
.56989 .38514 m .5736 .38308 L .56947 .38316 L F
.56989 .38514 m .57319 .38748 L .5736 .38308 L F
.298 .378 .777 r
.5641 .3851 m .56569 .38211 L .56333 .38223 L F
.5641 .3851 m .56634 .38531 L .56569 .38211 L F
.742 .629 .734 r
.39157 .51325 m .38748 .51009 L .38975 .50949 L F
.39157 .51325 m .38928 .51462 L .38748 .51009 L F
.684 .512 .647 r
.39157 .51325 m .38895 .51699 L .38928 .51462 L F
.39157 .51325 m .39301 .51779 L .38895 .51699 L F
.701 .595 .735 r
.39426 .50997 m .39157 .51325 L .38975 .50949 L F
.643 .489 .659 r
.39642 .51702 m .39301 .51779 L .39157 .51325 L F
.834 .501 .425 r
.55843 .41099 m .55453 .40764 L .55693 .40979 L F
.749 .499 0 r
.55693 .40979 m .55786 .41425 L .55843 .41099 L F
.678 .178 .051 r
.55306 .409 m .55453 .40764 L .55406 .40642 L F
.55306 .409 m .55693 .40979 L .55453 .40764 L F
.724 .907 .54 r
.61038 .38676 m .6079 .39052 L .61033 .38901 L F
.853 .833 .827 r
.43795 .51623 m .44291 .5143 L .44169 .51314 L F
.889 .945 .841 r
.44169 .51314 m .44291 .5143 L .44574 .51089 L F
.709 .172 0 r
.62195 .35085 m .62405 .3521 L .6216 .34992 L F
.716 .598 .723 r
.48009 .43059 m .48309 .42705 L .48054 .42821 L F
.795 .695 .754 r
.34875 .52971 m .3501 .53436 L .34706 .53205 L F
.877 .636 .57 r
.3501 .53436 m .34963 .53697 L .34706 .53205 L F
.75 .67 .773 r
.35274 .53055 m .3501 .53436 L .34875 .52971 L F
.687 .283 .275 r
.3501 .53436 m .35456 .53689 L .34963 .53697 L F
.765 .492 .522 r
.47082 .45189 m .47563 .45496 L .47542 .4522 L F
.342 .25 .605 r
.47563 .45496 m .47767 .45398 L .47542 .4522 L F
.416 .179 .444 r
.42662 .47888 m .42913 .4757 L .42714 .47605 L F
.546 .366 .588 r
.43313 .47259 m .43596 .4721 L .43578 .46924 L F
.458 .159 .369 r
.43269 .47492 m .43596 .4721 L .43313 .47259 L F
.676 .425 .534 r
.36377 .50021 m .36353 .50304 L .3606 .50292 L F
.724 .467 .538 r
.36758 .50311 m .36353 .50304 L .36377 .50021 L F
0 0 0 r
.33747 .50724 m .33614 .50971 L .33879 .50585 L F
.894 .918 .832 r
.44678 .50624 m .44574 .51089 L .44818 .50735 L F
.824 .891 .89 r
.44818 .50735 m .44959 .50294 L .44678 .50624 L F
.44818 .50735 m .45126 .50442 L .44959 .50294 L F
.889 .945 .841 r
.44169 .51314 m .44574 .51089 L .44407 .50969 L F
.894 .918 .832 r
.44678 .50624 m .44407 .50969 L .44574 .51089 L F
.771 .884 .927 r
.62615 .38324 m .62878 .37835 L .62479 .38118 L F
.62615 .38324 m .6302 .37975 L .62878 .37835 L F
.833 .669 .679 r
.38748 .51009 m .38928 .51462 L .38683 .51305 L F
.766 .592 .663 r
.38928 .51462 m .38449 .51626 L .38683 .51305 L F
.38928 .51462 m .38895 .51699 L .38449 .51626 L F
.569 .381 .587 r
.52821 .40032 m .52825 .40402 L .52513 .40456 L F
.344 .265 .621 r
.53093 .39986 m .5305 .40298 L .52821 .40032 L F
.446 .285 .568 r
.5305 .40298 m .52825 .40402 L .52821 .40032 L F
0 .08 .594 r
.59171 .39661 m .59226 .40104 L .5938 .39891 L F
.535 .837 .999 r
.59226 .40104 m .59533 .40022 L .5938 .39891 L F
.597 .666 .888 r
.61023 .36825 m .60589 .3662 L .61029 .36692 L F
.882 .936 .849 r
.47205 .48043 m .47499 .48028 L .47651 .4782 L F
.723 .506 .596 r
.54982 .36987 m .54981 .37298 L .55502 .37286 L F
0 0 .311 r
.59031 .37004 m .59159 .37056 L .59155 .36771 L F
.59031 .37004 m .5903 .3726 L .59159 .37056 L F
.722 .687 .816 r
.61033 .38901 m .61441 .38957 L .61327 .38593 L F
.707 .678 .82 r
.61327 .38593 m .61441 .38957 L .61729 .38696 L F
.734 .757 .871 r
.36703 .54596 m .36254 .54509 L .3655 .54416 L F
.653 .762 .93 r
.36761 .5436 m .36703 .54596 L .3655 .54416 L F
.36761 .5436 m .36993 .54485 L .36703 .54596 L F
.683 .393 .477 r
.52791 .38338 m .53057 .38583 L .52974 .38225 L F
.52791 .38338 m .52908 .38646 L .53057 .38583 L F
.531 .912 .764 r
.48171 .4347 m .48522 .43257 L .48402 .43309 L F
0 0 0 r
.48343 .43391 m .48171 .4347 L .48402 .43309 L F
.543 .209 .352 r
.39693 .49236 m .40121 .4893 L .39757 .49016 L F
0 0 0 r
.52235 .39127 m .51896 .39343 L .52242 .39165 L F
.937 .849 .73 r
.39278 .52794 m .39091 .52706 L .393 .52307 L F
.949 .831 .694 r
.39278 .52794 m .39202 .53065 L .39091 .52706 L F
.471 .317 .591 r
.43596 .4721 m .43851 .46848 L .43578 .46924 L F
0 .022 .588 r
.59133 .38336 m .5916 .3823 L .5903 .37975 L F
0 0 0 r
.59107 .38634 m .5916 .3823 L .59133 .38336 L F
.791 .525 .536 r
.5167 .41993 m .52124 .4208 L .52098 .41781 L F
.796 .778 .836 r
.35365 .54815 m .3522 .55176 L .35114 .54665 L F
.836 .639 .636 r
.62822 .35834 m .63212 .35933 L .63242 .35615 L F
.827 .998 .781 r
.54857 .39906 m .54668 .40154 L .5445 .40239 L F
0 0 0 r
.48204 .45195 m .47767 .45398 L .48026 .45246 L F
.63 .802 .965 r
.48509 .4508 m .48204 .45195 L .48311 .44953 L F
.62 .333 .46 r
.34018 .50367 m .34294 .50512 L .34164 .50265 L F
.34018 .50367 m .33879 .50585 L .34294 .50512 L F
.768 .778 .861 r
.37779 .51719 m .37923 .52056 L .37543 .51931 L F
.821 .409 .264 r
.37923 .52056 m .37743 .52237 L .37543 .51931 L F
.664 .823 .96 r
.38543 .56814 m .38971 .56852 L .3883 .56681 L F
.539 .544 .808 r
.38003 .51565 m .37923 .52056 L .37779 .51719 L F
.38003 .51565 m .38183 .52015 L .37923 .52056 L F
.285 0 0 r
.38016 .52182 m .37923 .52056 L .38183 .52015 L F
.38016 .52182 m .37743 .52237 L .37923 .52056 L F
.192 .554 .933 r
.3883 .56681 m .38971 .56852 L .39053 .56724 L F
.392 .795 .984 r
.38971 .56852 m .39252 .56812 L .39053 .56724 L F
.445 .193 .437 r
.49209 .41773 m .49229 .41848 L .49534 .41403 L F
.406 .148 .407 r
.49534 .41403 m .49775 .41621 L .49798 .41348 L F
.49534 .41403 m .49229 .41848 L .49775 .41621 L F
.66 .644 .823 r
.46852 .44998 m .46835 .45434 L .47082 .45189 L F
.714 .456 .533 r
.46835 .45434 m .47119 .45493 L .47082 .45189 L F
.765 .492 .522 r
.47082 .45189 m .47119 .45493 L .47563 .45496 L F
.818 .815 .847 r
.39804 .52125 m .39333 .52029 L .39558 .52006 L F
.39804 .52125 m .393 .52307 L .39333 .52029 L F
.173 .644 .932 r
.48798 .45116 m .48917 .45204 L .48509 .4508 L F
.678 .978 .862 r
.4915 .45032 m .48917 .45204 L .49038 .45008 L F
.589 .893 .989 r
.49038 .45008 m .48917 .45204 L .48798 .45116 L F
.506 .232 .432 r
.4206 .48245 m .42343 .48203 L .42377 .47954 L F
.378 .124 .398 r
.42377 .47954 m .42598 .48118 L .42662 .47888 L F
.42377 .47954 m .42343 .48203 L .42598 .48118 L F
0 0 .219 r
.60008 .37538 m .59834 .37915 L .59761 .37666 L F
.877 .584 .487 r
.60189 .36288 m .60206 .36622 L .60088 .36384 L F
.397 .211 .508 r
.60248 .36272 m .60206 .36622 L .60189 .36288 L F
.754 .921 .946 r
.51973 .43294 m .5207 .43399 L .51715 .43475 L F
.75 .92 .948 r
.52419 .43198 m .5207 .43399 L .51973 .43294 L F
.76 .704 .165 r
.3854 .54774 m .38547 .5463 L .38352 .54711 L F
.3854 .54774 m .38518 .54809 L .38547 .5463 L F
.11 0 0 r
.48757 .43112 m .48402 .43309 L .48522 .43257 L F
.282 .319 .723 r
.60311 .3524 m .60615 .35435 L .60571 .35169 L F
.319 .314 .697 r
.60615 .35435 m .60311 .3524 L .60571 .35169 L F
.148 .046 .472 r
.54413 .40404 m .5438 .40745 L .54499 .40675 L F
.028 .432 .867 r
.52343 .40256 m .52513 .40456 L .52691 .40393 L F
.521 .192 .35 r
.52712 .40435 m .52257 .4052 L .52276 .40463 L F
.52644 .40402 m .52276 .40463 L .52343 .40256 L F
.205 .733 .793 r
.52513 .40456 m .52696 .40393 L .52683 .40395 L F
.521 .192 .35 r
.52712 .40435 m .52276 .40463 L .52644 .40402 L F
.205 .733 .793 r
.52513 .40456 m .52825 .40402 L .52696 .40393 L F
.52683 .40395 m .52696 .40393 L .52691 .40393 L F
.787 .418 .358 r
.53045 .40478 m .52712 .40435 L .52689 .40393 L F
.436 .875 .826 r
.52695 .40391 m .52825 .40402 L .5305 .40298 L F
.787 .418 .358 r
.52691 .40393 m .52689 .40393 L .52828 .40355 L F
.436 .875 .826 r
.52691 .40393 m .52691 .40393 L .52695 .40391 L F
.52691 .40393 m .52825 .40402 L .52695 .40391 L F
.787 .418 .358 r
.52828 .40355 m .52689 .40393 L .52595 .40222 L F
.52697 .40392 m .52691 .40393 L .52695 .40391 L F
.436 .875 .826 r
.52695 .40391 m .5305 .40298 L .53045 .40478 L F
.787 .418 .358 r
.53045 .40478 m .52689 .40393 L .52862 .40374 L F
.436 .875 .826 r
.52691 .40393 m .52695 .40391 L .53045 .40478 L F
.787 .418 .358 r
.52862 .40374 m .52697 .40392 L .52828 .40355 L F
.52697 .40392 m .52695 .40391 L .52828 .40355 L F
.205 .733 .793 r
.5269 .40393 m .52691 .40393 L .52691 .40393 L F
.52683 .40395 m .52691 .40393 L .5269 .40393 L F
.671 .779 .931 r
.52309 .44277 m .52559 .44135 L .52119 .44051 L F
0 0 0 r
.49958 .42306 m .50061 .42167 L .50295 .4204 L F
.854 .8 .797 r
.39202 .53065 m .38819 .5306 L .39091 .52706 L F
.851 .808 .808 r
.39202 .53065 m .38921 .53416 L .38819 .5306 L F
.643 .956 .934 r
.55117 .39813 m .54857 .39906 L .55175 .3962 L F
.482 .405 .693 r
.55117 .39813 m .55421 .39584 L .55175 .3962 L F
.332 .159 .49 r
.55382 .39882 m .55421 .39584 L .55117 .39813 L F
.55382 .39882 m .55117 .39813 L .55175 .3962 L F
.879 .926 .539 r
.5553 .42249 m .55672 .42091 L .55669 .42023 L F
.294 .667 .973 r
.37799 .56608 m .37962 .56498 L .37648 .56485 L F
.37799 .56608 m .38134 .56643 L .37962 .56498 L F
.664 .513 .67 r
.34164 .50265 m .345 .49892 L .34259 .50002 L F
.832 .473 .375 r
.55502 .37286 m .55671 .37604 L .55907 .37575 L F
.805 .414 .315 r
.55671 .37604 m .55685 .3779 L .55907 .37575 L F
0 0 0 r
.55685 .3779 m .56089 .37627 L .55907 .37575 L F
.873 .818 .792 r
.53842 .38655 m .53605 .39025 L .53516 .38787 L F
.53799 .38672 m .53516 .38787 L .53773 .3869 L F
.63 .078 0 r
.53485 .38499 m .53773 .3869 L .53516 .38787 L F
.53485 .38499 m .53738 .38725 L .53773 .3869 L F
.606 .835 .452 r
.53773 .3869 m .53738 .38725 L .53755 .38702 L F
.079 .006 .464 r
.53842 .38655 m .54046 .38199 L .53747 .38261 L F
.606 .835 .452 r
.53773 .3869 m .53755 .38702 L .53853 .38566 L F
.873 .818 .792 r
.53842 .38655 m .53799 .38672 L .53773 .3869 L F
.079 .006 .464 r
.53842 .38655 m .54078 .3849 L .54046 .38199 L F
.667 .398 .505 r
.53773 .3869 m .54078 .3849 L .53842 .38655 L F
.174 0 .208 r
.53079 .3803 m .52974 .38225 L .53328 .37879 L F
0 0 0 r
.53864 .43218 m .53693 .43355 L .53461 .43415 L F
.53947 .43255 m .53864 .43218 L .54084 .43071 L F
.53947 .43255 m .53693 .43355 L .53864 .43218 L F
.19 0 0 r
.54429 .41366 m .54942 .41415 L .54783 .41085 L F
.752 .714 .816 r
.54942 .41415 m .55053 .40943 L .54783 .41085 L F
.54942 .41415 m .55044 .41283 L .55053 .40943 L F
0 0 .351 r
.54942 .41415 m .55079 .41549 L .55044 .41283 L F
.54942 .41415 m .54925 .4174 L .55079 .41549 L F
.543 .252 .424 r
.45262 .44852 m .45531 .45057 L .45622 .44835 L F
.515 .263 .471 r
.45265 .45082 m .45531 .45057 L .45262 .44852 L F
.254 .006 .332 r
.40754 .55727 m .40477 .56072 L .40534 .55828 L F
.767 .765 .851 r
.38921 .53416 m .38485 .5337 L .38819 .5306 L F
.797 .704 .763 r
.38921 .53416 m .38656 .53772 L .38485 .5337 L F
.699 .592 .732 r
.39525 .54447 m .39221 .54786 L .39094 .54415 L F
.851 .838 .832 r
.51416 .43597 m .51185 .43856 L .50999 .43731 L F
.927 .792 .69 r
.51185 .43856 m .51111 .44117 L .50999 .43731 L F
.499 .364 .628 r
.52066 .39468 m .52242 .39165 L .51896 .39343 L F
.346 .739 .985 r
.34875 .52971 m .35093 .52934 L .35274 .53055 L F
.481 .812 1 r
.35093 .52934 m .35532 .52992 L .35274 .53055 L F
.462 .505 .817 r
.35607 .53219 m .35274 .53055 L .35532 .52992 L F
0 0 .098 r
.5541 .38411 m .55328 .38342 L .55544 .38572 L F
.5541 .38411 m .55268 .38648 L .55328 .38342 L F
.375 .139 .423 r
.51155 .42371 m .51118 .42691 L .50884 .42724 L F
.50884 .42724 m .51118 .42691 L .51155 .42371 L F
.507 .365 .623 r
.51155 .42371 m .51465 .4233 L .51396 .42067 L F
.465 .213 .448 r
.51155 .42371 m .51118 .42691 L .51465 .4233 L F
.507 .365 .623 r
.51155 .42371 m .51465 .4233 L .51396 .42067 L F
.465 .213 .448 r
.51155 .42371 m .51118 .42691 L .51465 .4233 L F
.851 .838 .832 r
.51416 .43597 m .50999 .43731 L .51284 .43456 L F
.637 .846 .98 r
.51543 .43345 m .51416 .43597 L .51284 .43456 L F
.51543 .43345 m .51715 .43475 L .51416 .43597 L F
.543 .209 .352 r
.39693 .49236 m .39985 .49223 L .40121 .4893 L F
.698 .376 .427 r
.40121 .4893 m .40392 .49216 L .4041 .48952 L F
.40121 .4893 m .39985 .49223 L .40392 .49216 L F
.704 .566 .695 r
.3888 .51984 m .38449 .51626 L .38895 .51699 L F
.715 .533 .642 r
.39301 .51779 m .3888 .51984 L .38895 .51699 L F
.859 .839 .825 r
.3796 .53805 m .37719 .54173 L .37513 .54011 L F
.918 .727 .629 r
.42073 .54487 m .41901 .54035 L .41845 .54358 L F
.729 .405 .432 r
.35059 .50278 m .34918 .50557 L .34672 .50528 L F
.604 .264 .368 r
.35369 .50496 m .35059 .50278 L .35361 .50306 L F
.35369 .50496 m .34918 .50557 L .35059 .50278 L F
.882 .936 .849 r
.47205 .48043 m .47651 .4782 L .47512 .4777 L F
.909 .974 .794 r
.47785 .47403 m .47651 .4782 L .47955 .47551 L F
.47785 .47403 m .47512 .4777 L .47651 .4782 L F
.962 .897 .522 r
.33331 .52363 m .33373 .51874 L .33457 .52042 L F
.238 0 0 r
.53352 .39403 m .5319 .39551 L .52923 .39582 L F
.527 .026 .009 r
.53352 .39403 m .53602 .39549 L .5319 .39551 L F
.416 .18 .445 r
.536 .39301 m .53602 .39549 L .53352 .39403 L F
.557 .93 .919 r
.45947 .4479 m .45831 .44763 L .46069 .44635 L F
.768 .531 .575 r
.37495 .50313 m .37506 .50658 L .37224 .5058 L F
.665 .449 .581 r
.3795 .50572 m .37495 .50313 L .37922 .50321 L F
.3795 .50572 m .37506 .50658 L .37495 .50313 L F
.71 .665 .803 r
.38485 .5337 m .38656 .53772 L .38215 .53705 L F
.866 .994 .814 r
.6129 .34901 m .61042 .35011 L .61165 .34753 L F
.6129 .34901 m .60993 .3519 L .61042 .35011 L F
.687 .473 .591 r
.6129 .34901 m .61371 .3525 L .60993 .3519 L F
.52 .829 1 r
.6129 .34901 m .61165 .34753 L .61577 .34811 L F
.71 .613 .747 r
.61577 .34811 m .61371 .3525 L .6129 .34901 L F
.557 .934 .848 r
.39945 .56494 m .39722 .56541 L .39477 .56683 L F
.619 .959 .877 r
.40179 .56368 m .40052 .56329 L .39945 .56494 L F
.625 .961 .858 r
.40052 .56329 m .39722 .56541 L .39945 .56494 L F
.197 0 .176 r
.4108 .5543 m .40754 .55727 L .40872 .55503 L F
.3 .022 .313 r
.47119 .45493 m .4742 .45417 L .47563 .45496 L F
.495 .882 .966 r
.47563 .45496 m .4742 .45417 L .47767 .45398 L F
.597 .569 .793 r
.50042 .45529 m .50019 .44942 L .49857 .45377 L F
.50042 .45529 m .50181 .45074 L .50019 .44942 L F
.50042 .45529 m .50291 .45408 L .50181 .45074 L F
.776 .692 .771 r
.33793 .53039 m .33465 .53014 L .33689 .52689 L F
.726 .339 .318 r
.33793 .53039 m .33698 .53304 L .33465 .53014 L F
.34 .416 .794 r
.33689 .52689 m .34014 .5298 L .33793 .53039 L F
.452 .066 .216 r
.33849 .53252 m .33793 .53039 L .34014 .5298 L F
.33849 .53252 m .33698 .53304 L .33793 .53039 L F
.722 .687 .816 r
.61033 .38901 m .61327 .38593 L .61038 .38676 L F
.747 .994 .834 r
.40381 .56049 m .40179 .56368 L .40477 .56072 L F
.40381 .56049 m .40052 .56329 L .40179 .56368 L F
.509 .235 .434 r
.53707 .41367 m .54153 .41347 L .54026 .40967 L F
.355 .028 .265 r
.54346 .40919 m .5438 .40745 L .54026 .40967 L F
.004 0 .461 r
.54026 .40967 m .54233 .41214 L .54346 .40919 L F
.54026 .40967 m .54153 .41347 L .54233 .41214 L F
.811 .741 .787 r
.55421 .39584 m .5584 .39649 L .55868 .39386 L F
.831 .673 .687 r
.55603 .40014 m .5584 .39649 L .55421 .39584 L F
.901 .788 .726 r
.535 .41758 m .53105 .41921 L .53074 .41695 L F
.535 .41758 m .53371 .42062 L .53105 .41921 L F
.589 .72 .935 r
.36282 .56173 m .3666 .56283 L .36547 .56084 L F
.474 .639 .928 r
.3666 .56283 m .36789 .56044 L .36547 .56084 L F
.3666 .56283 m .36979 .56345 L .36789 .56044 L F
.491 .244 .468 r
.48904 .42093 m .49209 .42038 L .49209 .41773 L F
.411 .188 .462 r
.49209 .42038 m .49229 .41848 L .49209 .41773 L F
.844 .874 .864 r
.45126 .50442 m .45149 .50115 L .44959 .50294 L F
.45126 .50442 m .45307 .50257 L .45149 .50115 L F
.864 .724 .706 r
.3417 .54434 m .33981 .54484 L .33935 .54074 L F
.589 .13 .13 r
.3417 .54434 m .33975 .54627 L .33981 .54484 L F
.592 .63 .858 r
.34284 .54001 m .3417 .54434 L .33935 .54074 L F
.34284 .54001 m .34465 .54474 L .3417 .54434 L F
0 0 0 r
.34274 .5445 m .3417 .54434 L .34465 .54474 L F
.801 .826 .871 r
.62005 .35164 m .6214 .35481 L .62405 .3521 L F
.633 .486 .665 r
.41479 .55025 m .41468 .5526 L .41773 .55107 L F
.632 .488 .668 r
.41479 .55025 m .41773 .55107 L .41575 .54975 L F
0 .474 .86 r
.56891 .39354 m .565 .39159 L .5654 .39444 L F
.302 0 .016 r
.5182 .40585 m .51803 .40516 L .52025 .4055 L F
.214 .621 .952 r
.61465 .37435 m .61553 .37289 L .61282 .37236 L F
.61465 .37435 m .61712 .37413 L .61553 .37289 L F
.89 .878 .817 r
.48005 .47093 m .48461 .46847 L .4831 .46691 L F
.48005 .47093 m .48184 .4721 L .48461 .46847 L F
.855 .908 .869 r
.4831 .46691 m .48461 .46847 L .48778 .46495 L F
0 0 0 r
.53461 .43415 m .53693 .43355 L .53347 .43513 L F
.457 0 0 r
.54981 .37298 m .55275 .37419 L .55502 .37286 L F
.858 .475 .319 r
.55275 .37419 m .55671 .37604 L .55502 .37286 L F
0 0 0 r
.50726 .4043 m .50652 .40544 L .5096 .40307 L F
.744 .628 .063 r
.55053 .40943 m .55044 .41283 L .55039 .41103 L F
0 0 .103 r
.55044 .41283 m .55079 .41549 L .55039 .41103 L F
.159 0 0 r
.49798 .41348 m .5007 .41249 L .50167 .41093 L F
0 0 0 r
.50416 .40725 m .50167 .41093 L .50284 .40967 L F
.631 .47 .646 r
.5007 .41249 m .50284 .40967 L .50167 .41093 L F
.437 .875 .829 r
.60755 .37362 m .60865 .37246 L .6059 .37326 L F
.60755 .37362 m .61015 .37245 L .60865 .37246 L F
.826 .647 .66 r
.63354 .3683 m .63732 .36963 L .63585 .36597 L F
.833 .624 .62 r
.63354 .3683 m .63585 .37254 L .63732 .36963 L F
.642 .624 .816 r
.35166 .55887 m .35587 .56164 L .354 .5577 L F
.69 .658 .813 r
.354 .5577 m .35587 .56164 L .35883 .56074 L F
.488 .17 .354 r
.40392 .49216 m .40826 .48861 L .4041 .48952 L F
0 0 0 r
.54758 .42668 m .55062 .42534 L .55031 .4257 L F
.55031 .4257 m .55066 .42534 L .55246 .42509 L F
.54956 .42648 m .55031 .4257 L .55188 .42491 L F
.54842 .42725 m .55031 .4257 L .54956 .42648 L F
.55031 .4257 m .55062 .42534 L .55066 .42534 L F
.445 .104 .293 r
.48309 .42705 m .4859 .42677 L .48642 .4246 L F
.487 .301 .554 r
.48642 .4246 m .48924 .42382 L .48904 .42093 L F
.31 0 .249 r
.48642 .4246 m .48855 .42563 L .48924 .42382 L F
.48642 .4246 m .4859 .42677 L .48855 .42563 L F
.706 .682 .824 r
.50999 .43731 m .51111 .44117 L .50675 .44083 L F
.727 .601 .716 r
.51111 .44117 m .50892 .44498 L .50675 .44083 L F
.75 .92 .948 r
.52419 .43198 m .51973 .43294 L .52228 .432 L F
.621 .958 .83 r
.52228 .432 m .52606 .43033 L .52419 .43198 L F
.933 .969 .734 r
.45307 .50257 m .45416 .49787 L .45149 .50115 L F
.45307 .50257 m .45395 .50028 L .45416 .49787 L F
.815 .835 .864 r
.50886 .44783 m .51259 .44774 L .51176 .44496 L F
.772 .828 .896 r
.51259 .44774 m .51416 .44339 L .51176 .44496 L F
.51259 .44774 m .51603 .44526 L .51416 .44339 L F
.626 .618 .823 r
.34764 .5576 m .35166 .55887 L .3505 .55657 L F
.533 .237 .41 r
.42018 .48464 m .42343 .48203 L .4206 .48245 L F
.51 .016 .019 r
.54764 .39754 m .55175 .3962 L .54857 .39906 L F
.54764 .39754 m .54987 .39807 L .55175 .3962 L F
.73 .28 .182 r
.54987 .39807 m .55382 .39882 L .55175 .3962 L F
.895 .865 .802 r
.47785 .47403 m .48184 .4721 L .48005 .47093 L F
.47785 .47403 m .47955 .47551 L .48184 .4721 L F
.788 .295 .027 r
.62822 .35834 m .6325 .36164 L .63212 .35933 L F
.715 .533 .642 r
.39301 .51779 m .39333 .52029 L .3888 .51984 L F
.741 .637 .745 r
.39642 .51702 m .39333 .52029 L .39301 .51779 L F
.909 .799 .726 r
.41145 .54588 m .41295 .55083 L .41319 .54756 L F
.41145 .54588 m .40972 .54965 L .41295 .55083 L F
.998 .784 .473 r
.40972 .54965 m .4108 .5543 L .41295 .55083 L F
.727 .741 .863 r
.51726 .42282 m .52124 .4208 L .5167 .41993 L F
0 .047 .609 r
.59217 .39445 m .59171 .39661 L .5938 .39891 L F
.893 .971 .825 r
.4567 .4944 m .45652 .497 L .45947 .49349 L F
.866 .943 .866 r
.45958 .49061 m .45947 .49349 L .46135 .49133 L F
.904 .962 .815 r
.45958 .49061 m .4567 .4944 L .45947 .49349 L F
.946 .77 .308 r
.38062 .50802 m .38008 .50699 L .3795 .50572 L F
.37 .177 .484 r
.59085 .36268 m .59336 .36174 L .59335 .35896 L F
.349 .134 .44 r
.59085 .36268 m .59088 .365 L .59336 .36174 L F
.678 .291 .305 r
.35361 .50306 m .35626 .50564 L .35369 .50496 L F
.561 .317 .503 r
.35631 .50265 m .35626 .50564 L .35361 .50306 L F
.739 .888 .948 r
.38215 .53705 m .37812 .53693 L .38023 .53345 L F
.38215 .53705 m .3796 .53805 L .37812 .53693 L F
.784 .788 .855 r
.38485 .5337 m .38215 .53705 L .38023 .53345 L F
.641 .88 .528 r
.62293 .37966 m .62017 .38315 L .62161 .38094 L F
.851 .844 .837 r
.62231 .38408 m .62017 .38315 L .619 .38284 L F
.62231 .38408 m .62161 .38094 L .62017 .38315 L F
.487 .314 .571 r
.49038 .45008 m .49452 .44759 L .4915 .45032 L F
.585 .641 .873 r
.62844 .372 m .62996 .36706 L .62681 .3704 L F
.62844 .372 m .63134 .37132 L .62996 .36706 L F
.48 .236 .466 r
.62807 .37497 m .63134 .37132 L .62844 .372 L F
.76 .994 .87 r
.42119 .53704 m .41617 .53984 L .41901 .54035 L F
.819 .996 .854 r
.42119 .53704 m .42155 .53426 L .42026 .53637 L F
.42119 .53704 m .42431 .53379 L .42155 .53426 L F
.859 .839 .825 r
.3796 .53805 m .37513 .54011 L .37812 .53693 L F
.184 0 .149 r
.50416 .40725 m .50586 .4084 L .50652 .40544 L F
.50416 .40725 m .50284 .40967 L .50586 .4084 L F
.439 .132 .346 r
.41363 .48847 m .41698 .48564 L .41421 .48623 L F
.481 .165 .352 r
.41081 .48882 m .41363 .48847 L .41421 .48623 L F
.476 .269 .519 r
.48924 .42382 m .49209 .42038 L .48904 .42093 L F
.857 .873 .851 r
.53602 .39549 m .53757 .39726 L .53485 .39987 L F
.682 .522 .663 r
.53757 .39726 m .53775 .40069 L .53485 .39987 L F
.617 .806 .972 r
.54027 .39614 m .53757 .39726 L .53602 .39549 L F
.721 .552 .661 r
.54454 .40022 m .53757 .39726 L .54027 .39614 L F
.54454 .40022 m .53775 .40069 L .53757 .39726 L F
.627 .614 .818 r
.54572 .41962 m .54179 .41755 L .54478 .41946 L F
.846 .996 .762 r
.54371 .41927 m .54478 .41946 L .54405 .41879 L F
.54226 .42132 m .54478 .41946 L .54371 .41927 L F
.54196 .4218 m .54478 .41946 L .54226 .42132 L F
.627 .614 .818 r
.54609 .41982 m .54572 .41962 L .54478 .41946 L F
.244 0 .174 r
.5485 .4191 m .54925 .4174 L .54893 .41765 L F
.5485 .4191 m .54893 .41765 L .54609 .41982 L F
.5485 .4191 m .54609 .41982 L .54478 .41946 L F
.474 .355 .636 r
.54478 .41946 m .5477 .42175 L .5485 .4191 L F
.5477 .42175 m .54786 .42188 L .5485 .4191 L F
.333 .341 .719 r
.54444 .41552 m .54478 .41946 L .54179 .41755 L F
.846 .996 .762 r
.54186 .42189 m .54231 .4229 L .54478 .41946 L F
0 0 0 r
.54319 .42291 m .54519 .42235 L .54231 .4229 L F
.506 .377 .639 r
.54231 .4229 m .54519 .42235 L .54478 .41946 L F
.183 .221 .667 r
.54724 .41579 m .54478 .41946 L .54444 .41552 L F
.74 .99 .883 r
.54405 .41879 m .54478 .41946 L .54724 .41579 L F
.474 .355 .636 r
.54478 .41946 m .54519 .42235 L .54786 .42188 L F
.72 .643 .772 r
.54316 .41955 m .54186 .42189 L .54405 .41879 L F
.566 .49 .729 r
.54551 .41907 m .54319 .42291 L .54317 .41986 L F
.54338 .41951 m .54317 .41986 L .54316 .41955 L F
.54551 .41907 m .54317 .41986 L .54338 .41951 L F
.846 .996 .762 r
.54186 .42189 m .54196 .4218 L .54226 .42132 L F
0 0 .058 r
.54179 .41755 m .54429 .41366 L .54444 .41552 L F
.87 .831 .806 r
.63681 .36222 m .6342 .36561 L .63585 .36597 L F
.826 .647 .66 r
.63354 .3683 m .63585 .36597 L .6342 .36561 L F
0 0 0 r
.61933 .35854 m .62083 .35772 L .62123 .35805 L F
.62083 .35772 m .62025 .35934 L .62178 .35719 L F
.663 .973 .834 r
.62123 .35805 m .62083 .35772 L .62265 .35597 L F
0 0 0 r
.62083 .35772 m .62178 .35719 L .62265 .35597 L F
.6184 .35878 m .62083 .35772 L .61933 .35854 L F
.6184 .35878 m .6172 .3604 L .62083 .35772 L F
.881 .455 .179 r
.53105 .41921 m .53371 .42062 L .53445 .42322 L F
0 0 .146 r
.54499 .40675 m .5438 .40745 L .54346 .40919 L F
.63 .59 .791 r
.60217 .38203 m .59834 .37915 L .60086 .38097 L F
0 0 0 r
.54783 .41085 m .54657 .41276 L .54429 .41366 L F
.54429 .41366 m .54644 .41314 L .54444 .41552 L F
.54429 .41366 m .54657 .41276 L .54644 .41314 L F
.762 .933 .942 r
.56136 .38035 m .55981 .38326 L .56333 .38223 L F
.874 .89 .842 r
.56136 .38035 m .56333 .38223 L .565 .37943 L F
.898 .932 .829 r
.62331 .38246 m .62293 .37966 L .62161 .38094 L F
.62331 .38246 m .62438 .37812 L .62293 .37966 L F
.674 .419 .527 r
.36739 .50557 m .36353 .50304 L .36758 .50311 L F
.724 .405 .438 r
.37224 .5058 m .36739 .50557 L .36758 .50311 L F
.459 0 .016 r
.54454 .40022 m .53753 .4021 L .53775 .40069 L F
.54454 .40022 m .54033 .40221 L .53753 .4021 L F
.094 .231 .715 r
.54344 .39529 m .54454 .40022 L .54027 .39614 L F
.54344 .39529 m .54593 .40018 L .54454 .40022 L F
.753 .614 .705 r
.54593 .40018 m .54033 .40221 L .54454 .40022 L F
.762 .933 .942 r
.56136 .38035 m .5586 .38247 L .55981 .38326 L F
.647 .257 .292 r
.35675 .53685 m .3601 .53754 L .3603 .53624 L F
.636 .237 .271 r
.3603 .53624 m .35983 .53745 L .35675 .53685 L F
.719 .523 .623 r
.36266 .53633 m .36192 .53662 L .3603 .53624 L F
.36233 .53672 m .36145 .53698 L .3603 .53624 L F
.269 0 .21 r
.3603 .53624 m .3601 .53754 L .36129 .53688 L F
.719 .523 .623 r
.36145 .53698 m .35983 .53745 L .3603 .53624 L F
.269 0 .21 r
.3603 .53624 m .3629 .53599 L .36287 .53633 L F
.3603 .53624 m .36129 .53688 L .3629 .53599 L F
.663 .675 .851 r
.3629 .53599 m .36129 .53688 L .35754 .53221 L F
.36129 .53688 m .3601 .53754 L .36002 .53739 L F
.36129 .53688 m .36002 .53739 L .35754 .53221 L F
.719 .523 .623 r
.36287 .53633 m .36233 .53672 L .36192 .53662 L F
.36287 .53633 m .36192 .53662 L .36266 .53633 L F
.584 .634 .867 r
.36002 .53739 m .36007 .5375 L .35983 .53745 L F
.719 .523 .623 r
.36233 .53672 m .35923 .53896 L .35983 .53745 L F
.584 .634 .867 r
.35754 .53221 m .36002 .53739 L .35675 .53685 L F
.36002 .53739 m .35983 .53745 L .35675 .53685 L F
.36007 .5375 m .3601 .53754 L .35675 .53685 L F
.636 .237 .271 r
.35983 .53745 m .35923 .53896 L .35675 .53685 L F
0 0 .219 r
.60008 .37538 m .60009 .3778 L .59834 .37915 L F
.111 .218 .695 r
.60009 .3778 m .60086 .38097 L .59834 .37915 L F
.657 .521 .687 r
.54764 .39754 m .54593 .40018 L .54344 .39529 L F
.628 .826 .419 r
.54764 .39754 m .5445 .40239 L .54593 .40018 L F
.827 .998 .781 r
.54857 .39906 m .5445 .40239 L .54764 .39754 L F
.587 .707 .926 r
.35883 .56074 m .36282 .56173 L .36156 .55987 L F
.615 .72 .92 r
.36156 .55987 m .36282 .56173 L .36547 .56084 L F
.917 .967 .789 r
.45416 .49787 m .45395 .50028 L .45652 .497 L F
.906 .975 .798 r
.45416 .49787 m .45652 .497 L .4567 .4944 L F
.79 .7 .765 r
.35347 .54079 m .35564 .54471 L .35143 .54369 L F
.856 .751 .747 r
.35564 .54471 m .35114 .54665 L .35143 .54369 L F
.35564 .54471 m .35365 .54815 L .35114 .54665 L F
.654 .647 .831 r
.35827 .54356 m .35564 .54471 L .35347 .54079 L F
.4 .152 .419 r
.54602 .39195 m .54303 .38992 L .54609 .38891 L F
.54602 .39195 m .5429 .3933 L .54303 .38992 L F
.533 .767 .983 r
.61729 .38696 m .62039 .38629 L .6189 .38461 L F
.786 .664 .112 r
.41526 .53894 m .41503 .54141 L .41514 .54354 L F
.49 .323 .582 r
.41319 .54756 m .41514 .54354 L .41503 .54141 L F
.41319 .54756 m .41585 .54691 L .41514 .54354 L F
.89 .868 .81 r
.41319 .54756 m .41514 .54354 L .41585 .54691 L F
.416 .179 .444 r
.42662 .47888 m .42914 .47824 L .42913 .4757 L F
.46 .153 .358 r
.42914 .47824 m .43269 .47492 L .42913 .4757 L F
.823 .938 .903 r
.50999 .43731 m .50675 .44083 L .50525 .43917 L F
.559 .758 .971 r
.3657 .5209 m .3681 .52315 L .36513 .52358 L F
.757 .689 .786 r
.3616 .51834 m .36455 .52303 L .35936 .5218 L F
.784 .623 .681 r
.36439 .52328 m .36311 .5251 L .35866 .52445 L F
.36447 .52317 m .35866 .52445 L .35936 .5218 L F
.36439 .52328 m .35866 .52445 L .36447 .52317 L F
.757 .689 .786 r
.36455 .52303 m .36447 .52317 L .35936 .5218 L F
.723 .678 .806 r
.3657 .5209 m .36455 .52303 L .3616 .51834 L F
.679 .21 .132 r
.36354 .52478 m .36311 .5251 L .36518 .52186 L F
.36455 .52303 m .36518 .52186 L .36565 .52112 L F
.36354 .52478 m .36518 .52186 L .36455 .52303 L F
.36554 .52161 m .36447 .52317 L .36565 .52112 L F
.723 .678 .806 r
.3657 .5209 m .36467 .52322 L .36455 .52303 L F
.784 .623 .681 r
.36467 .52322 m .36311 .5251 L .36439 .52328 L F
.679 .21 .132 r
.36513 .52358 m .36354 .52478 L .36446 .52318 L F
.36447 .52317 m .36446 .52318 L .36447 .52317 L F
.36513 .52358 m .36446 .52318 L .36447 .52317 L F
.36513 .52358 m .36447 .52317 L .36554 .52161 L F
.784 .623 .681 r
.36467 .52322 m .36439 .52328 L .36447 .52317 L F
.757 .689 .786 r
.36455 .52303 m .36467 .52322 L .36447 .52317 L F
.679 .21 .132 r
.36565 .52112 m .36311 .5251 L .3657 .5209 L F
.36513 .52358 m .36772 .52589 L .36311 .5251 L F
.534 .283 .481 r
.3681 .52315 m .36772 .52589 L .36513 .52358 L F
.79 .667 .728 r
.61962 .34969 m .61656 .353 L .61577 .34811 L F
.71 .613 .747 r
.61466 .35047 m .61656 .353 L .61371 .3525 L F
.61577 .34811 m .61613 .35031 L .61466 .35047 L F
.61613 .35031 m .61656 .353 L .61466 .35047 L F
.79 .667 .728 r
.61894 .34999 m .61555 .35076 L .61803 .35039 L F
.61962 .34969 m .61813 .35008 L .61894 .34999 L F
.61813 .35008 m .61555 .35076 L .61894 .34999 L F
.61962 .34969 m .61577 .34811 L .61555 .35076 L F
.648 .156 .068 r
.61803 .35039 m .62195 .35085 L .61962 .34969 L F
.413 .58 .907 r
.37409 .56477 m .37572 .5626 L .37303 .56315 L F
.37409 .56477 m .37648 .56485 L .37572 .5626 L F
.623 .941 .726 r
.54758 .42668 m .54544 .42734 L .54337 .42966 L F
.164 0 0 r
.54842 .42725 m .54758 .42668 L .55031 .4257 L F
.54842 .42725 m .54544 .42734 L .54758 .42668 L F
.82 .775 .811 r
.53284 .39868 m .53485 .39987 L .53093 .39986 L F
.553 .228 .372 r
.53485 .39987 m .5305 .40298 L .53093 .39986 L F
.53485 .39987 m .53274 .40293 L .5305 .40298 L F
.857 .873 .851 r
.53602 .39549 m .53485 .39987 L .53284 .39868 L F
.592 .273 .398 r
.53485 .39987 m .53753 .4021 L .53274 .40293 L F
.662 .219 .187 r
.53485 .39987 m .53775 .40069 L .53753 .4021 L F
.915 .727 .634 r
.35496 .55491 m .354 .5577 L .35254 .55367 L F
.49 .323 .582 r
.41319 .54756 m .41503 .54141 L .41145 .54588 L F
.793 .634 .685 r
.35044 .54049 m .34707 .54042 L .34963 .53697 L F
.688 .549 .691 r
.35143 .54369 m .34707 .54042 L .35044 .54049 L F
.552 .382 .605 r
.35456 .53689 m .35044 .54049 L .34963 .53697 L F
.35456 .53689 m .35347 .54079 L .35044 .54049 L F
.552 .375 .594 r
.35347 .54079 m .35143 .54369 L .35044 .54049 L F
.621 .958 .83 r
.52228 .432 m .52533 .43014 L .52606 .43033 L F
.44 .878 .854 r
.52606 .43033 m .52811 .42896 L .52933 .42699 L F
.52606 .43033 m .52533 .43014 L .52811 .42896 L F
.754 .635 .728 r
.38683 .51305 m .38449 .51626 L .38257 .51301 L F
.553 .874 .594 r
.47126 .44556 m .47299 .44426 L .47047 .44274 L F
.65 .969 .868 r
.47143 .4426 m .47164 .44211 L .47402 .43943 L F
.681 .446 .559 r
.47402 .43943 m .47164 .44211 L .47047 .44274 L F
.65 .969 .868 r
.47143 .4426 m .47047 .44274 L .47164 .44211 L F
.681 .446 .559 r
.47164 .44211 m .47089 .44295 L .47047 .44274 L F
.65 .969 .868 r
.47164 .44211 m .47047 .44274 L .47222 .44073 L F
.47164 .44211 m .47222 .44073 L .47402 .43943 L F
.762 .991 .782 r
.47402 .43943 m .47265 .44156 L .47494 .43931 L F
.681 .446 .559 r
.47402 .43943 m .47366 .44434 L .47089 .44295 L F
0 .411 .714 r
.47299 .44426 m .47366 .44434 L .47641 .44532 L F
.605 .632 .851 r
.47299 .44426 m .47641 .44532 L .47366 .44434 L F
0 0 0 r
.47366 .44434 m .47126 .44556 L .47047 .44274 L F
.614 .183 .199 r
.47047 .44274 m .47251 .4443 L .47222 .44073 L F
.47251 .4443 m .47313 .44478 L .47292 .44386 L F
.47251 .4443 m .47292 .44386 L .47222 .44073 L F
.553 .874 .594 r
.47126 .44556 m .46932 .44757 L .46992 .44703 L F
.47143 .44543 m .46992 .44703 L .47299 .44426 L F
.47126 .44556 m .46992 .44703 L .47143 .44543 L F
.741 .637 .745 r
.39642 .51702 m .39558 .52006 L .39333 .52029 L F
.606 .574 .793 r
.3505 .55657 m .35166 .55887 L .354 .5577 L F
.077 0 .147 r
.54981 .37298 m .54721 .37624 L .54978 .37438 L F
.458 .054 .185 r
.54978 .37438 m .55275 .37419 L .54981 .37298 L F
.458 .159 .369 r
.43269 .47492 m .4357 .47455 L .43596 .4721 L F
.471 .317 .591 r
.43596 .4721 m .43861 .47139 L .43851 .46848 L F
.589 .268 .393 r
.43596 .4721 m .43868 .47431 L .43861 .47139 L F
.43596 .4721 m .4357 .47455 L .43868 .47431 L F
0 0 .29 r
.59039 .37529 m .59159 .37056 L .5903 .3726 L F
.965 .718 .513 r
.50019 .44942 m .50181 .45074 L .502 .44748 L F
0 0 0 r
.502 .44748 m .50034 .4495 L .50019 .44942 L F
.709 .625 .762 r
.50181 .45074 m .50472 .44668 L .502 .44748 L F
.431 .832 .629 r
.50472 .44668 m .50034 .4495 L .502 .44748 L F
.262 0 .001 r
.35746 .49511 m .36006 .49453 L .36186 .49203 L F
.496 .058 .136 r
.36186 .49203 m .36569 .49312 L .36452 .49166 L F
.36186 .49203 m .36006 .49453 L .36569 .49312 L F
.645 .762 .934 r
.37224 .5435 m .36993 .54485 L .36761 .5436 L F
.69 .658 .813 r
.354 .5577 m .35883 .56074 L .35647 .55745 L F
.587 .707 .926 r
.35647 .55745 m .35883 .56074 L .36156 .55987 L F
.488 .17 .354 r
.40392 .49216 m .40682 .49181 L .40826 .48861 L F
.348 0 .13 r
.40682 .49181 m .41081 .48882 L .40826 .48861 L F
.769 .609 .681 r
.34706 .53205 m .34963 .53697 L .34571 .53639 L F
.77 .6 .668 r
.34963 .53697 m .34707 .54042 L .34571 .53639 L F
.855 .908 .869 r
.4831 .46691 m .48778 .46495 L .48643 .46397 L F
.81 .96 .909 r
.48957 .46134 m .48778 .46495 L .4909 .46198 L F
.48957 .46134 m .48643 .46397 L .48778 .46495 L F
.802 .616 .65 r
.55004 .38744 m .54899 .3905 L .54609 .38891 L F
.552 .348 .557 r
.55268 .38648 m .54899 .3905 L .55004 .38744 L F
.888 .937 .842 r
.46261 .48726 m .46135 .49133 L .46436 .48901 L F
.46261 .48726 m .45958 .49061 L .46135 .49133 L F
.536 .3 .504 r
.35473 .49514 m .35746 .49511 L .35513 .49268 L F
.303 .011 .293 r
.49775 .41621 m .5007 .41249 L .49798 .41348 L F
.506 .365 .623 r
.51396 .42067 m .51465 .4233 L .5167 .41993 L F
.784 .733 .805 r
.34707 .54042 m .34465 .54474 L .34284 .54001 L F
.769 .661 .744 r
.35114 .54665 m .34789 .55127 L .34671 .54639 L F
.445 0 0 r
.34671 .54639 m .34858 .54788 L .34658 .54625 L F
.439 .146 .37 r
.34742 .54384 m .34671 .54639 L .34465 .54474 L F
.445 0 0 r
.34589 .54571 m .34658 .54625 L .34494 .54492 L F
.34671 .54639 m .34658 .54625 L .34589 .54571 L F
.011 .538 .854 r
.34481 .54486 m .34567 .54536 L .34529 .54494 L F
.34274 .5445 m .34532 .54526 L .34481 .54486 L F
.34532 .54526 m .34567 .54536 L .34481 .54486 L F
0 .091 .56 r
.34465 .54474 m .34486 .54486 L .34274 .5445 L F
.577 .467 .692 r
.34742 .54384 m .34465 .54474 L .34707 .54042 L F
.011 .538 .854 r
.34274 .5445 m .34529 .54494 L .34147 .54068 L F
0 .091 .56 r
.34486 .54486 m .34494 .54492 L .34274 .5445 L F
.34465 .54474 m .34671 .54639 L .34494 .54492 L F
.818 .768 .806 r
.34875 .52971 m .34387 .52977 L .3464 .52663 L F
.828 .722 .748 r
.34875 .52971 m .34569 .53363 L .34387 .52977 L F
.795 .695 .754 r
.34875 .52971 m .34706 .53205 L .34569 .53363 L F
.409 .581 .91 r
.34876 .52636 m .34875 .52971 L .3464 .52663 L F
.34876 .52636 m .35093 .52934 L .34875 .52971 L F
.791 .983 .9 r
.42657 .52962 m .42527 .52895 L .42531 .53054 L F
.788 .983 .901 r
.42867 .5262 m .42657 .52962 L .42985 .52687 L F
.42867 .5262 m .42527 .52895 L .42657 .52962 L F
.703 .433 .513 r
.36046 .50537 m .35631 .50265 L .3606 .50292 L F
.73 .473 .538 r
.36353 .50304 m .36046 .50537 L .3606 .50292 L F
.797 .646 .695 r
.38257 .51301 m .38449 .51626 L .38003 .51565 L F
.791 .675 .736 r
.38449 .51626 m .38183 .52015 L .38003 .51565 L F
.719 .572 .688 r
.38449 .51626 m .38643 .52036 L .38183 .52015 L F
.704 .566 .695 r
.3888 .51984 m .38643 .52036 L .38449 .51626 L F
.953 .947 .645 r
.42527 .52895 m .42431 .53379 L .42531 .53054 L F
.361 .171 .482 r
.59335 .35896 m .59611 .36028 L .59593 .35812 L F
.59335 .35896 m .59336 .36174 L .59611 .36028 L F
.375 .059 .296 r
.42598 .48118 m .42914 .47824 L .42662 .47888 L F
.439 .456 .78 r
.34392 .51505 m .34286 .51997 L .34168 .51719 L F
.716 .598 .723 r
.48009 .43059 m .48534 .43196 L .48309 .42705 L F
.289 .788 .787 r
.48634 .43305 m .48343 .43391 L .48402 .43309 L F
.586 .062 0 r
.48591 .433 m .48832 .43398 L .488 .43395 L F
.317 .482 .865 r
.48343 .43391 m .48591 .433 L .48581 .43296 L F
.289 .788 .787 r
.48634 .43305 m .48591 .433 L .48343 .43391 L F
.586 .062 0 r
.48591 .433 m .488 .43395 L .48415 .43355 L F
.11 0 0 r
.48757 .43112 m .48634 .43305 L .48402 .43309 L F
.317 .482 .865 r
.48581 .43296 m .48591 .433 L .48586 .43294 L F
.032 0 .101 r
.48009 .43059 m .48087 .43115 L .48534 .43196 L F
.48087 .43115 m .48257 .43176 L .48534 .43196 L F
.48087 .43115 m .48162 .43169 L .48257 .43176 L F
.582 .533 .766 r
.48309 .42705 m .48534 .43196 L .48877 .43035 L F
.56 .925 .94 r
.48877 .43035 m .48534 .43196 L .48162 .43169 L F
.48877 .43035 m .48196 .43163 L .48438 .4309 L F
.48196 .43163 m .48162 .43169 L .48438 .4309 L F
.582 .533 .766 r
.48309 .42705 m .48877 .43035 L .4859 .42677 L F
0 .263 .771 r
.4859 .42677 m .48827 .42972 L .48853 .42865 L F
.48827 .42972 m .48877 .43035 L .48853 .42865 L F
0 0 0 r
.48749 .43051 m .48853 .42865 L .48877 .43035 L F
.48438 .4309 m .48853 .42865 L .48749 .43051 L F
0 .263 .771 r
.4859 .42677 m .48853 .42865 L .48855 .42563 L F
0 0 .181 r
.48855 .42563 m .48853 .42865 L .48936 .42645 L F
0 0 0 r
.48438 .4309 m .48691 .43004 L .48853 .42865 L F
.768 .937 .59 r
.48853 .42865 m .48691 .43004 L .48891 .4271 L F
.48853 .42865 m .48891 .4271 L .48936 .42645 L F
.586 .062 0 r
.48591 .433 m .48687 .43016 L .48438 .4309 L F
.48687 .43016 m .48691 .43004 L .48438 .4309 L F
.317 .482 .865 r
.48396 .43226 m .48586 .43294 L .48438 .4309 L F
.48343 .43391 m .48586 .43294 L .48396 .43226 L F
.411 .188 .462 r
.49209 .42038 m .49468 .41965 L .49229 .41848 L F
.381 .126 .398 r
.49468 .41965 m .49775 .41621 L .49229 .41848 L F
.294 0 0 r
.38062 .55305 m .38366 .553 L .38565 .55122 L F
.675 .423 .532 r
.37944 .55582 m .38227 .55392 L .38032 .55364 L F
.38227 .55392 m .38404 .55273 L .38315 .55295 L F
0 0 .104 r
.38366 .553 m .38544 .54638 L .38486 .5491 L F
.38544 .54638 m .38547 .5463 L .38539 .54667 L F
.38544 .54638 m .38539 .54667 L .38486 .5491 L F
.968 .931 .682 r
.38565 .55122 m .38366 .553 L .38395 .55206 L F
.38525 .55062 m .38395 .55206 L .38467 .54974 L F
.38565 .55122 m .38395 .55206 L .38525 .55062 L F
0 0 .475 r
.37888 .55077 m .38032 .55364 L .37997 .54989 L F
0 0 .104 r
.38366 .553 m .38475 .54936 L .38499 .54806 L F
.435 0 .044 r
.38474 .54939 m .37997 .54989 L .38352 .54711 L F
.38474 .54939 m .38474 .54939 L .38474 .54939 L F
.38474 .54939 m .37997 .54989 L .38474 .54939 L F
0 0 .104 r
.38366 .553 m .38395 .55279 L .38475 .54936 L F
.38499 .54806 m .38475 .54936 L .38544 .54638 L F
.475 .305 .57 r
.38547 .5463 m .38478 .54947 L .38474 .54939 L F
.968 .931 .682 r
.38565 .55122 m .38467 .54974 L .38493 .54952 L F
.435 0 .044 r
.38501 .5499 m .38465 .5499 L .38474 .54939 L F
.38465 .5499 m .38448 .5499 L .38474 .5494 L F
.38465 .5499 m .38474 .5494 L .38474 .54939 L F
0 0 .104 r
.38395 .55279 m .38404 .55273 L .38454 .55044 L F
.38474 .54939 m .38454 .55044 L .38539 .54661 L F
.38395 .55279 m .38454 .55044 L .38474 .54939 L F
.38395 .55279 m .38539 .54661 L .38544 .54638 L F
.475 .305 .57 r
.38547 .5463 m .38474 .54939 L .38352 .54711 L F
.435 0 .044 r
.38465 .5499 m .38437 .54999 L .38448 .5499 L F
.38501 .5499 m .38465 .54995 L .38465 .5499 L F
.38465 .54995 m .38437 .54999 L .38465 .5499 L F
0 0 .104 r
.38544 .54638 m .38465 .54995 L .38547 .5463 L F
.547 0 0 r
.38404 .55273 m .38465 .54995 L .38474 .54994 L F
0 0 .104 r
.38465 .54995 m .38404 .55273 L .38466 .54995 L F
.38465 .54995 m .38466 .54995 L .38547 .5463 L F
.547 0 0 r
.38404 .55273 m .37888 .55077 L .38465 .54995 L F
.38437 .55176 m .38474 .54994 L .38501 .5499 L F
.38404 .55273 m .38474 .54994 L .38437 .55176 L F
.31 .8 .864 r
.38032 .55364 m .38366 .553 L .38062 .55305 L F
.38032 .55364 m .38404 .55273 L .38366 .553 L F
.675 .423 .532 r
.38227 .55392 m .38315 .55295 L .38032 .55364 L F
.968 .931 .682 r
.38493 .54952 m .38467 .54974 L .38482 .54925 L F
.435 0 .044 r
.38448 .5499 m .37888 .55077 L .37997 .54989 L F
.38437 .54999 m .37888 .55077 L .38448 .5499 L F
.475 .305 .57 r
.38486 .5491 m .38501 .5499 L .38478 .54947 L F
.38547 .5463 m .38522 .54822 L .38486 .5491 L F
.968 .931 .682 r
.38523 .54846 m .38482 .54925 L .38486 .5491 L F
.38523 .54846 m .38486 .5491 L .3852 .54827 L F
.38565 .55122 m .38482 .54925 L .38523 .54846 L F
.475 .305 .57 r
.38522 .54822 m .38501 .5499 L .38486 .5491 L F
.676 .484 .618 r
.38522 .54822 m .38404 .55273 L .38501 .5499 L F
.38547 .5463 m .38498 .54872 L .38522 .54822 L F
0 0 .104 r
.38498 .54872 m .38547 .5463 L .38518 .54809 L F
.38486 .5491 m .38547 .5463 L .38498 .54872 L F
.676 .484 .618 r
.38547 .5463 m .38489 .54891 L .38498 .54872 L F
.968 .931 .682 r
.3852 .54827 m .38486 .5491 L .38498 .54872 L F
.3852 .54827 m .38498 .54872 L .3852 .54826 L F
.676 .484 .618 r
.38489 .54891 m .38404 .55273 L .38522 .54822 L F
.968 .931 .682 r
.3852 .54826 m .38498 .54872 L .38518 .54809 L F
.435 0 .044 r
.38448 .5499 m .37997 .54989 L .38474 .54939 L F
.801 .826 .871 r
.62005 .35164 m .62405 .3521 L .62195 .35085 L F
0 0 0 r
.5454 .37725 m .54978 .37438 L .54721 .37624 L F
.811 .741 .787 r
.55421 .39584 m .55868 .39386 L .55743 .39269 L F
.749 .499 0 r
.55693 .40979 m .55739 .41235 L .55786 .41425 L F
0 0 .458 r
.55786 .41425 m .55739 .41235 L .55911 .41667 L F
0 0 .467 r
.5903 .37975 m .59167 .37752 L .59039 .37529 L F
.382 .325 .669 r
.5903 .37975 m .59336 .38107 L .59167 .37752 L F
.5903 .37975 m .5916 .3823 L .59336 .38107 L F
.769 .609 .681 r
.34706 .53205 m .34571 .53639 L .34569 .53363 L F
.692 .56 .701 r
.393 .52307 m .3888 .51984 L .39333 .52029 L F
.353 .101 .386 r
.44144 .46512 m .44391 .46457 L .44434 .4618 L F
.615 .482 .677 r
.44141 .46792 m .44391 .46457 L .44144 .46512 L F
.4 .159 .43 r
.44391 .46457 m .44682 .46083 L .44434 .4618 L F
.629 .926 .973 r
.47908 .44396 m .47366 .44434 L .47641 .44532 L F
.47908 .44396 m .47366 .44434 L .47641 .44532 L F
.774 .471 .475 r
.536 .39301 m .54109 .39512 L .54027 .39614 L F
.666 .622 .795 r
.5429 .3933 m .54027 .39614 L .54109 .39512 L F
.971 .705 .47 r
.41575 .54975 m .41773 .55107 L .41585 .54691 L F
.905 .701 .616 r
.38643 .52036 m .38389 .52185 L .38183 .52015 L F
.38643 .52036 m .38627 .52307 L .38389 .52185 L F
.69 .51 .639 r
.3888 .51984 m .38627 .52307 L .38643 .52036 L F
.739 .581 .678 r
.3888 .51984 m .39047 .52346 L .38627 .52307 L F
.692 .56 .701 r
.393 .52307 m .39047 .52346 L .3888 .51984 L F
.9 .918 .823 r
.33689 .52689 m .33465 .53014 L .33335 .52869 L F
0 0 .445 r
.33465 .53014 m .33511 .5307 L .33335 .52869 L F
.33465 .53014 m .33698 .53304 L .33511 .5307 L F
.664 .811 .954 r
.38362 .56643 m .38543 .56814 L .3883 .56681 L F
.691 .764 .908 r
.60993 .3519 m .60571 .35169 L .60952 .34934 L F
.131 .67 .845 r
.60571 .35169 m .60929 .35165 L .60993 .3519 L F
.422 .562 .89 r
.61042 .35011 m .60993 .3519 L .60952 .34934 L F
.666 .313 .365 r
.61371 .3525 m .61279 .35426 L .60993 .3519 L F
.22 .343 .777 r
.60993 .3519 m .61279 .35426 L .61042 .35011 L F
.875 .989 .727 r
.61042 .35011 m .60929 .35165 L .60993 .3519 L F
.74 .486 .546 r
.60993 .3519 m .60615 .35435 L .60571 .35169 L F
.7 .614 .757 r
.53328 .37879 m .52974 .38225 L .53571 .38121 L F
.489 .416 .701 r
.52974 .38225 m .53447 .3844 L .53571 .38121 L F
.13 0 0 r
.47816 .4381 m .47402 .43943 L .47494 .43931 L F
.096 .651 .702 r
.47494 .43931 m .47672 .43906 L .47402 .43943 L F
.444 .165 .394 r
.49345 .42457 m .49302 .42666 L .49023 .42732 L F
.411 .136 .383 r
.4958 .42585 m .49345 .42457 L .49574 .42368 L F
.4958 .42585 m .49302 .42666 L .49345 .42457 L F
.73 .473 .538 r
.36353 .50304 m .36302 .50586 L .36046 .50537 L F
.674 .419 .527 r
.36739 .50557 m .36302 .50586 L .36353 .50304 L F
.768 .727 .815 r
.34134 .53304 m .3428 .53722 L .33838 .53651 L F
.23 0 0 r
.3428 .53722 m .33823 .53934 L .33838 .53651 L F
.914 .579 .396 r
.3428 .53722 m .34284 .54001 L .34062 .53905 L F
.781 .457 .439 r
.34707 .54042 m .34284 .54001 L .3428 .53722 L F
.122 0 0 r
.33987 .54063 m .34147 .54068 L .34284 .54001 L F
.33935 .54074 m .34147 .54068 L .33987 .54063 L F
.288 .413 .815 r
.34147 .54068 m .34386 .54094 L .34354 .54075 L F
.34147 .54068 m .34354 .54075 L .34062 .53905 L F
.394 .476 .826 r
.34062 .53905 m .34386 .54094 L .34318 .53901 L F
.23 0 0 r
.3428 .53722 m .34062 .53905 L .33878 .53908 L F
.394 .476 .826 r
.34062 .53905 m .34318 .53901 L .34232 .53654 L F
.23 0 0 r
.33878 .53908 m .34062 .53905 L .33823 .53934 L F
.787 .737 .806 r
.34569 .53363 m .3428 .53722 L .34134 .53304 L F
.648 .523 .697 r
.34571 .53639 m .3428 .53722 L .34569 .53363 L F
.781 .457 .439 r
.34707 .54042 m .3428 .53722 L .34571 .53639 L F
.847 .484 .366 r
.565 .37943 m .56569 .38211 L .56947 .38316 L F
.502 .162 .322 r
.56634 .38531 m .56947 .38316 L .56569 .38211 L F
.56634 .38531 m .56989 .38514 L .56947 .38316 L F
.831 .834 .849 r
.51416 .44339 m .51603 .44526 L .51764 .44313 L F
.542 .463 .716 r
.48727 .44775 m .48509 .4508 L .48311 .44953 L F
.48727 .44775 m .48798 .45116 L .48509 .4508 L F
.843 .713 .72 r
.38003 .51565 m .37821 .51167 L .38041 .51316 L F
.797 .646 .695 r
.38257 .51301 m .38003 .51565 L .38041 .51316 L F
.466 .286 .552 r
.34302 .55425 m .34567 .55378 L .34608 .55087 L F
.15 0 0 r
.48904 .43212 m .48757 .43112 L .49031 .43033 L F
.48904 .43212 m .48634 .43305 L .48757 .43112 L F
.649 .787 .948 r
.52119 .44051 m .52559 .44135 L .52395 .43942 L F
.829 .984 .876 r
.52559 .44135 m .52637 .43846 L .52395 .43942 L F
.52559 .44135 m .52889 .43823 L .52637 .43846 L F
.655 .322 .397 r
.38979 .49469 m .3942 .49212 L .3899 .49253 L F
.38979 .49469 m .39249 .49513 L .3942 .49212 L F
.517 .17 .317 r
.3942 .49212 m .39653 .49409 L .39693 .49236 L F
.3942 .49212 m .39249 .49513 L .39653 .49409 L F
.236 0 .3 r
.33879 .50585 m .33614 .50971 L .34012 .50716 L F
.499 .053 .122 r
.34012 .50716 m .34294 .50512 L .33879 .50585 L F
.633 .679 .876 r
.36254 .54509 m .35827 .54356 L .36118 .54259 L F
.621 .726 .922 r
.36333 .54208 m .36254 .54509 L .36118 .54259 L F
.36333 .54208 m .3655 .54416 L .36254 .54509 L F
.639 .284 .354 r
.38285 .49253 m .38537 .49497 L .38729 .49221 L F
.666 .317 .372 r
.38729 .49221 m .38979 .49469 L .3899 .49253 L F
.38729 .49221 m .38537 .49497 L .38979 .49469 L F
.87 .984 .839 r
.59533 .40022 m .59841 .39683 L .59575 .39721 L F
.781 .926 .931 r
.5938 .39891 m .59533 .40022 L .59575 .39721 L F
.032 0 .101 r
.48009 .43059 m .47958 .43317 L .48162 .43169 L F
.439 .456 .78 r
.34392 .51505 m .34475 .51918 L .34286 .51997 L F
.447 .224 .481 r
.34509 .52198 m .34286 .51997 L .34475 .51918 L F
.34509 .52198 m .3425 .5227 L .34286 .51997 L F
.896 .972 .665 r
.59841 .39683 m .60057 .39298 L .5988 .39399 L F
0 0 0 r
.60242 .39126 m .60057 .39298 L .60379 .38986 L F
.518 .882 .662 r
.5988 .39399 m .60057 .39298 L .60242 .39126 L F
.91 .931 .556 r
.43106 .52203 m .42985 .52687 L .43179 .52319 L F
.837 .988 .864 r
.43404 .51903 m .43179 .52319 L .43531 .51991 L F
.43404 .51903 m .43106 .52203 L .43179 .52319 L F
.261 0 .198 r
.34021 .52412 m .33963 .52632 L .33689 .52689 L F
.607 .234 .309 r
.34218 .52573 m .33963 .52632 L .34021 .52412 L F
.436 .284 .576 r
.3425 .5227 m .34218 .52573 L .34021 .52412 L F
.861 .986 .845 r
.59575 .39721 m .59841 .39683 L .5988 .39399 L F
.723 .42 .466 r
.39047 .52346 m .38846 .52632 L .38627 .52307 L F
.85 .709 .707 r
.393 .52307 m .38846 .52632 L .39047 .52346 L F
.699 .275 .236 r
.36452 .49166 m .36696 .4943 L .36892 .49214 L F
.655 .219 .203 r
.36892 .49214 m .36696 .4943 L .37144 .49447 L F
.614 .241 .312 r
.36892 .49214 m .37144 .49447 L .3716 .49254 L F
.882 .656 .592 r
.41617 .53984 m .41901 .54035 L .41845 .54358 L F
.41845 .54358 m .41901 .54035 L .41617 .53984 L F
.64 .199 .185 r
.38389 .52185 m .38016 .52182 L .38183 .52015 L F
.559 .713 .944 r
.36979 .56345 m .37036 .55999 L .36789 .56044 L F
.36979 .56345 m .37303 .56315 L .37036 .55999 L F
.487 .314 .571 r
.49038 .45008 m .49195 .4471 L .49452 .44759 L F
.796 .916 .92 r
.49452 .44759 m .49596 .4438 L .49797 .44518 L F
.49452 .44759 m .49195 .4471 L .49596 .4438 L F
.404 .189 .47 r
.49302 .42666 m .49031 .43033 L .49023 .42732 L F
.424 .432 .763 r
.33963 .52632 m .34014 .5298 L .33689 .52689 L F
.606 .036 0 r
.53328 .37879 m .53591 .38091 L .53586 .38009 L F
.862 .879 .849 r
.53591 .38091 m .53984 .37921 L .53586 .38009 L F
.962 .897 .522 r
.33331 .52363 m .33261 .52193 L .33373 .51874 L F
0 0 0 r
.33331 .52363 m .33246 .5269 L .33319 .52478 L F
.33331 .52363 m .33319 .52478 L .33261 .52193 L F
.66 .644 .823 r
.46852 .44998 m .47119 .45493 L .46835 .45434 L F
.707 .381 .423 r
.46835 .45434 m .47076 .4572 L .47119 .45493 L F
.47119 .45493 m .47076 .4572 L .46835 .45434 L F
.653 .903 .982 r
.39053 .56724 m .39252 .56812 L .39477 .56683 L F
0 0 0 r
.61555 .35076 m .61371 .3525 L .61656 .353 L F
.601 .719 .927 r
.61555 .35076 m .61656 .353 L .62005 .35164 L F
.85 .709 .707 r
.393 .52307 m .39091 .52706 L .38846 .52632 L F
0 0 0 r
.55685 .3779 m .5604 .37686 L .56089 .37627 L F
.733 .236 0 r
.5604 .37686 m .56295 .37906 L .56089 .37627 L F
.81 .349 .133 r
.56089 .37627 m .56295 .37906 L .565 .37943 L F
.754 .876 .935 r
.51973 .43294 m .51715 .43475 L .51543 .43345 L F
.874 .89 .842 r
.56136 .38035 m .565 .37943 L .56295 .37906 L F
.923 .541 .148 r
.564 .38039 m .56569 .38211 L .565 .37943 L F
.564 .38039 m .56569 .38211 L .565 .37943 L F
.348 0 .13 r
.40682 .49181 m .40954 .49124 L .41081 .48882 L F
.479 .097 .237 r
.40954 .49124 m .41363 .48847 L .41081 .48882 L F
0 0 0 r
.52933 .42699 m .53051 .42763 L .53237 .42699 L F
.52933 .42699 m .52811 .42896 L .53051 .42763 L F
.703 .433 .513 r
.36046 .50537 m .35626 .50564 L .35631 .50265 L F
.499 .053 .122 r
.34012 .50716 m .34054 .50815 L .34294 .50512 L F
.519 .113 .21 r
.34054 .50815 m .34514 .50576 L .34294 .50512 L F
.89 .893 .825 r
.62878 .37835 m .63241 .37689 L .6312 .37517 L F
.62878 .37835 m .6302 .37975 L .63241 .37689 L F
.986 .734 .35 r
.63134 .37132 m .63241 .37689 L .63585 .37254 L F
.63134 .37132 m .6312 .37517 L .63241 .37689 L F
0 .146 .659 r
.53571 .38121 m .53591 .38091 L .53328 .37879 L F
.966 .788 .611 r
.33935 .54074 m .33981 .54484 L .33836 .54114 L F
.798 .605 .641 r
.5275 .38875 m .53057 .38583 L .52908 .38646 L F
0 0 .338 r
.53057 .38583 m .53252 .38631 L .53447 .3844 L F
.462 .551 .861 r
.47156 .44887 m .47119 .45493 L .46852 .44998 L F
.47156 .44887 m .4742 .45417 L .47119 .45493 L F
.3 .022 .313 r
.4742 .45417 m .47076 .4572 L .47119 .45493 L F
.47119 .45493 m .47076 .4572 L .4742 .45417 L F
.707 .633 .772 r
.50291 .45408 m .5067 .45104 L .50181 .45074 L F
.869 .965 .858 r
.3718 .51609 m .37223 .51288 L .37318 .51423 L F
.3718 .51609 m .37023 .51509 L .37223 .51288 L F
.765 .261 .006 r
.3718 .51609 m .37108 .51712 L .37023 .51509 L F
.3718 .51609 m .37388 .51885 L .37108 .51712 L F
.595 .525 .745 r
.37318 .51423 m .37412 .51671 L .3718 .51609 L F
.639 .282 .35 r
.37412 .51671 m .37388 .51885 L .3718 .51609 L F
.953 .947 .645 r
.42527 .52895 m .42395 .53097 L .42431 .53379 L F
.911 .969 .797 r
.42431 .53379 m .42395 .53097 L .42155 .53426 L F
0 0 0 r
.59107 .38634 m .59129 .38477 L .5916 .3823 L F
0 0 .356 r
.59107 .38634 m .59165 .38915 L .59129 .38477 L F
.877 .768 .739 r
.55411 .4033 m .55603 .40014 L .55382 .39882 L F
.831 .673 .687 r
.55603 .40014 m .55421 .39584 L .55382 .39882 L F
.784 .962 .923 r
.53394 .41492 m .52963 .41593 L .53221 .41405 L F
.53394 .41492 m .53074 .41695 L .52963 .41593 L F
.362 .831 .784 r
.53475 .41414 m .53394 .41492 L .53221 .41405 L F
.63 .962 .844 r
.53221 .41405 m .52963 .41593 L .53083 .41431 L F
.138 0 0 r
.53083 .41431 m .53475 .41414 L .53221 .41405 L F
.352 .812 .93 r
.53338 .41371 m .53475 .41414 L .53083 .41431 L F
.447 0 0 r
.53415 .4141 m .53475 .41414 L .53338 .41371 L F
.362 .831 .784 r
.53475 .41414 m .53571 .4142 L .53394 .41492 L F
.607 .938 .95 r
.53707 .41367 m .53664 .41384 L .53648 .41388 L F
.53664 .41384 m .53394 .41492 L .53648 .41388 L F
.362 .831 .784 r
.53475 .41414 m .53648 .41388 L .53571 .4142 L F
0 0 0 r
.536 .41401 m .53648 .41388 L .53475 .41414 L F
.53911 .41369 m .53648 .41388 L .536 .41401 L F
.447 0 0 r
.53752 .41582 m .53475 .41414 L .53415 .4141 L F
.635 .293 .375 r
.3788 .49256 m .38315 .49414 L .38285 .49253 L F
.69 .258 .217 r
.38315 .49414 m .38537 .49497 L .38285 .49253 L F
.768 .991 .886 r
.49299 .46051 m .49181 .45967 L .4909 .46198 L F
.918 .979 .733 r
.4941 .45613 m .49299 .46051 L .49602 .45734 L F
.4941 .45613 m .49181 .45967 L .49299 .46051 L F
.71 .255 .167 r
.56965 .38802 m .57319 .38748 L .56989 .38514 L F
.56965 .38802 m .57402 .38888 L .57319 .38748 L F
.499 .364 .628 r
.52066 .39468 m .52366 .39632 L .52242 .39165 L F
.561 .317 .503 r
.52198 .39837 m .52066 .39468 L .52114 .39724 L F
.52198 .39837 m .52366 .39632 L .52066 .39468 L F
.689 .307 .318 r
.3716 .49254 m .3758 .4944 L .37586 .49221 L F
.6 .306 .442 r
.3758 .4944 m .37843 .49481 L .37586 .49221 L F
.642 .299 .377 r
.37586 .49221 m .37843 .49481 L .3788 .49256 L F
.509 .313 .55 r
.3921 .5507 m .39211 .55359 L .39496 .55017 L F
.3921 .5507 m .39211 .55359 L .39496 .55017 L F
.46 .153 .358 r
.42914 .47824 m .43175 .47782 L .43269 .47492 L F
.588 .277 .409 r
.43269 .47492 m .43565 .47737 L .4357 .47455 L F
.43269 .47492 m .43175 .47782 L .43565 .47737 L F
.278 0 0 r
.61012 .36011 m .61429 .36112 L .61143 .36025 L F
.395 .079 .308 r
.5096 .40307 m .5128 .4003 L .51092 .40258 L F
.5096 .40307 m .51238 .40236 L .5128 .4003 L F
.363 .035 .268 r
.51238 .40236 m .51289 .40125 L .5128 .4003 L F
.774 .471 .475 r
.536 .39301 m .54027 .39614 L .53602 .39549 L F
0 0 0 r
.61555 .35076 m .61279 .35426 L .61371 .3525 L F
.76 .682 .776 r
.34567 .55378 m .35063 .55537 L .34789 .55127 L F
.614 .632 .845 r
.34789 .55127 m .35063 .55537 L .35254 .55367 L F
.932 .604 .154 r
.52963 .41593 m .53074 .41695 L .53105 .41921 L F
.52963 .41593 m .53074 .41695 L .53105 .41921 L F
.747 .918 .949 r
.54783 .41085 m .54888 .40813 L .54626 .40842 L F
.54783 .41085 m .55053 .40943 L .54888 .40813 L F
.515 .38 .635 r
.54888 .40813 m .54783 .41085 L .54626 .40842 L F
.989 .75 .481 r
.54626 .40842 m .54657 .41276 L .54783 .41085 L F
.515 .38 .635 r
.54888 .40813 m .54657 .41276 L .54783 .41085 L F
.766 .448 .447 r
.37506 .50658 m .37478 .50885 L .37224 .5058 L F
.502 .212 .406 r
.37672 .50812 m .37506 .50658 L .3795 .50572 L F
.37672 .50812 m .37478 .50885 L .37506 .50658 L F
.694 .555 .693 r
.35607 .53219 m .35675 .53685 L .35456 .53689 L F
0 .129 .653 r
.35532 .52992 m .35754 .53221 L .35607 .53219 L F
.584 .634 .867 r
.35754 .53221 m .35675 .53685 L .35607 .53219 L F
.91 .931 .556 r
.43106 .52203 m .4299 .52446 L .42985 .52687 L F
.87 .987 .833 r
.4299 .52446 m .42867 .5262 L .42985 .52687 L F
.489 .184 .376 r
.51408 .40956 m .51082 .41228 L .51163 .41068 L F
.568 .393 .604 r
.43851 .46848 m .4415 .47086 L .44141 .46792 L F
.43851 .46848 m .43861 .47139 L .4415 .47086 L F
.799 .711 .768 r
.34387 .52977 m .34569 .53363 L .34134 .53304 L F
.654 .647 .831 r
.35827 .54356 m .35347 .54079 L .35624 .5417 L F
.636 .766 .941 r
.36118 .54259 m .35827 .54356 L .35624 .5417 L F
.783 .99 .888 r
.52889 .43823 m .52749 .43675 L .52637 .43846 L F
.52889 .43823 m .53067 .43644 L .52749 .43675 L F
.772 .787 .865 r
.49008 .44424 m .48638 .44415 L .48913 .4423 L F
.56 .318 .506 r
.49008 .44424 m .48727 .44775 L .48638 .44415 L F
.49008 .44424 m .49027 .44706 L .48727 .44775 L F
.6 .702 .915 r
.49236 .44171 m .49008 .44424 L .48913 .4423 L F
.589 .494 .715 r
.49236 .44171 m .49027 .44706 L .49008 .44424 L F
.753 .912 .946 r
.49983 .4434 m .49797 .44518 L .49596 .4438 L F
.731 .964 .939 r
.49181 .45967 m .48957 .46134 L .4909 .46198 L F
.807 .924 .914 r
.51764 .44313 m .51639 .44193 L .51416 .44339 L F
.51764 .44313 m .51864 .44193 L .51639 .44193 L F
.06 0 0 r
.345 .49892 m .34763 .4983 L .34966 .4973 L F
.35 .074 .347 r
.45216 .45403 m .45531 .45057 L .45265 .45082 L F
0 0 .476 r
.345 .49892 m .34573 .49971 L .34763 .4983 L F
.608 .828 .984 r
.55544 .38572 m .55268 .38648 L .5541 .38411 L F
.809 .595 .613 r
.52471 .39484 m .52923 .39582 L .529 .39289 L F
.784 .788 .855 r
.38485 .5337 m .38023 .53345 L .38313 .5324 L F
.811 .881 .896 r
.38819 .5306 m .38485 .5337 L .38313 .5324 L F
.812 .806 .846 r
.46261 .48726 m .46436 .48901 L .46753 .48584 L F
.423 .027 .181 r
.51506 .40163 m .52114 .39724 L .51289 .40125 L F
.51506 .40163 m .5182 .40112 L .52114 .39724 L F
.304 0 .102 r
.52114 .39724 m .52113 .4002 L .52198 .39837 L F
.52114 .39724 m .5182 .40112 L .52113 .4002 L F
.533 .237 .41 r
.42018 .48464 m .42301 .48445 L .42343 .48203 L F
.471 .227 .463 r
.42301 .48445 m .42598 .48118 L .42343 .48203 L F
.592 .243 .347 r
.38008 .50699 m .37672 .50812 L .3795 .50572 L F
.252 0 .007 r
.54337 .42966 m .53947 .43255 L .54084 .43071 L F
.593 .379 .56 r
.52242 .39165 m .52624 .39311 L .52477 .38916 L F
.246 .088 .459 r
.35587 .53882 m .35456 .53689 L .35675 .53685 L F
.35587 .53882 m .35347 .54079 L .35456 .53689 L F
.792 .486 .471 r
.38627 .52307 m .38246 .52491 L .38389 .52185 L F
.38627 .52307 m .38611 .52557 L .38246 .52491 L F
.718 .42 .471 r
.38627 .52307 m .38846 .52632 L .38611 .52557 L F
.796 .717 .776 r
.61856 .36441 m .6157 .36798 L .6198 .36803 L F
.511 0 0 r
.6157 .36798 m .61871 .36944 L .6198 .36803 L F
.741 .688 .8 r
.61856 .36441 m .6198 .36803 L .6229 .36487 L F
.206 0 0 r
.61871 .36944 m .62295 .37014 L .6198 .36803 L F
.239 0 0 r
.35093 .52934 m .3538 .52993 L .35532 .52992 L F
0 .119 .656 r
.35645 .52847 m .35532 .52992 L .3538 .52993 L F
.35645 .52847 m .35754 .53221 L .35532 .52992 L F
.81 .367 .19 r
.54899 .3905 m .54829 .39159 L .54609 .38891 L F
.465 .485 .795 r
.54899 .3905 m .55105 .39307 L .55283 .39175 L F
.553 .061 .042 r
.54899 .3905 m .55283 .39175 L .54829 .39159 L F
.545 .422 .664 r
.60571 .35169 m .60929 .35165 L .60952 .34934 L F
.538 .349 .572 r
.60571 .35169 m .60615 .35435 L .60929 .35165 L F
.60571 .35169 m .60615 .35435 L .60929 .35165 L F
.012 0 0 r
.53911 .41369 m .53707 .41367 L .53648 .41388 L F
.53911 .41369 m .54153 .41347 L .53707 .41367 L F
.824 .992 .741 r
.40533 .55852 m .40477 .56072 L .40754 .55727 L F
.818 .998 .785 r
.40533 .55852 m .40381 .56049 L .40477 .56072 L F
.39 .615 .94 r
.38134 .56643 m .38188 .56391 L .37962 .56498 L F
.38134 .56643 m .38362 .56643 L .38188 .56391 L F
.405 .771 .994 r
.55053 .40943 m .55306 .409 L .54888 .40813 L F
.744 .628 .063 r
.55053 .40943 m .55039 .41103 L .55306 .409 L F
.64 .234 .258 r
.35675 .53685 m .35923 .53896 L .35587 .53882 L F
.103 0 0 r
.49958 .42306 m .50295 .4204 L .50185 .42214 L F
0 0 0 r
.50185 .42214 m .50295 .4204 L .50482 .41882 L F
.03 .602 .717 r
.60865 .37246 m .61015 .37245 L .61282 .37236 L F
.715 .589 .713 r
.63134 .37132 m .63585 .37254 L .63354 .3683 L F
.94 .596 .343 r
.41433 .5391 m .41503 .54141 L .41526 .53894 L F
.651 .107 0 r
.41526 .53894 m .41617 .53984 L .41433 .5391 L F
0 .474 .86 r
.56891 .39354 m .56724 .39214 L .565 .39159 L F
.94 .898 .757 r
.56859 .38924 m .56891 .39354 L .5705 .39128 L F
.56859 .38924 m .56724 .39214 L .56891 .39354 L F
.586 .166 .213 r
.39653 .49409 m .39944 .49431 L .39693 .49236 L F
.539 .197 .337 r
.39693 .49236 m .39944 .49431 L .39985 .49223 L F
.688 .549 .691 r
.35143 .54369 m .34742 .54384 L .34707 .54042 L F
0 0 .07 r
.33653 .51243 m .34012 .50716 L .33614 .50971 L F
.922 .931 .796 r
.37543 .51931 m .37601 .51538 L .37779 .51719 L F
.37543 .51931 m .37388 .51885 L .37601 .51538 L F
.773 .412 .373 r
.37543 .51931 m .373 .52159 L .37388 .51885 L F
.37543 .51931 m .37743 .52237 L .373 .52159 L F
.63 .078 0 r
.53485 .38499 m .53516 .38787 L .53418 .38823 L F
.88 .965 .846 r
.43692 .51577 m .43531 .51991 L .43795 .51623 L F
.793 .984 .897 r
.43858 .51375 m .43795 .51623 L .44169 .51314 L F
.824 .999 .836 r
.43858 .51375 m .43692 .51577 L .43795 .51623 L F
.531 .747 .974 r
.37037 .52226 m .3681 .52315 L .3657 .5209 L F
.466 .225 .463 r
.37042 .52524 m .3681 .52315 L .37037 .52226 L F
.37042 .52524 m .36772 .52589 L .3681 .52315 L F
.767 .425 .406 r
.61803 .35039 m .62005 .35164 L .62195 .35085 L F
.478 .534 .836 r
.354 .5577 m .35515 .55411 L .35254 .55367 L F
.354 .5577 m .35647 .55745 L .35515 .55411 L F
.635 .293 .375 r
.3788 .49256 m .37843 .49481 L .38315 .49414 L F
.724 .589 .705 r
.6325 .36164 m .6342 .36561 L .63681 .36222 L F
.689 .307 .318 r
.3716 .49254 m .37144 .49447 L .3758 .4944 L F
.686 .384 .457 r
.37224 .5058 m .36728 .50842 L .36739 .50557 L F
.37224 .5058 m .36999 .50847 L .36728 .50842 L F
.736 .452 .498 r
.37224 .5058 m .37478 .50885 L .36999 .50847 L F
.88 .965 .846 r
.43692 .51577 m .43404 .51903 L .43531 .51991 L F
.615 .72 .92 r
.36156 .55987 m .36547 .56084 L .36397 .55918 L F
.471 .616 .912 r
.36547 .56084 m .36692 .55871 L .36397 .55918 L F
.36547 .56084 m .36789 .56044 L .36692 .55871 L F
.476 .269 .519 r
.48924 .42382 m .49247 .42339 L .49209 .42038 L F
.295 0 .174 r
.48924 .42382 m .49098 .42473 L .49247 .42339 L F
.48924 .42382 m .48855 .42563 L .49098 .42473 L F
0 0 .278 r
.34514 .50576 m .34573 .50808 L .34338 .50932 L F
.34573 .50808 m .34575 .50815 L .34422 .50905 L F
.519 .113 .21 r
.34054 .50815 m .345 .50847 L .34514 .50576 L F
.83 .767 .792 r
.34726 .50785 m .34653 .50849 L .34575 .50815 L F
.34653 .50849 m .34522 .50964 L .34564 .50847 L F
.34653 .50849 m .34564 .50847 L .34575 .50815 L F
.519 .113 .21 r
.345 .50847 m .34575 .50815 L .34574 .50812 L F
.34501 .50831 m .34574 .50812 L .34514 .50576 L F
.345 .50847 m .34574 .50812 L .34501 .50831 L F
.643 .084 0 r
.34908 .50833 m .34514 .50576 L .34918 .50557 L F
.409 .188 .465 r
.35159 .5075 m .34908 .50833 L .34918 .50557 L F
.643 .084 0 r
.34908 .50833 m .34726 .50785 L .34514 .50576 L F
.292 .187 .559 r
.34514 .50576 m .34726 .50785 L .34652 .5062 L F
.7 .312 .31 r
.34918 .50557 m .34514 .50576 L .34672 .50528 L F
.476 .387 .675 r
.34726 .50785 m .34933 .50415 L .34652 .5062 L F
.409 .188 .465 r
.35159 .5075 m .34918 .50557 L .35369 .50496 L F
.476 .387 .675 r
.34726 .50785 m .3499 .50678 L .34933 .50415 L F
.169 .705 .732 r
.34548 .50757 m .3499 .50678 L .34787 .5076 L F
.34702 .50781 m .34787 .5076 L .34726 .50785 L F
.34548 .50757 m .34787 .5076 L .34702 .50781 L F
0 0 .278 r
.34575 .50815 m .34559 .50861 L .34422 .50905 L F
.34573 .50808 m .34422 .50905 L .34338 .50932 L F
0 0 0 r
.34559 .50861 m .34298 .51207 L .34338 .50932 L F
.34585 .50853 m .34541 .50907 L .34559 .50861 L F
.34541 .50907 m .34298 .51207 L .34559 .50861 L F
.83 .767 .792 r
.34559 .50861 m .3444 .51036 L .34579 .50805 L F
.34522 .50964 m .34516 .50969 L .34559 .50861 L F
.34516 .50969 m .3444 .51036 L .34559 .50861 L F
0 0 0 r
.34585 .50853 m .3444 .51036 L .34298 .51207 L F
.83 .767 .792 r
.34579 .50805 m .3444 .51036 L .34293 .50843 L F
.75 .752 .853 r
.34293 .50843 m .34585 .50853 L .345 .50847 L F
.34293 .50843 m .3444 .51036 L .34585 .50853 L F
.515 .258 .464 r
.34211 .51145 m .34456 .50863 L .34293 .50843 L F
.83 .767 .792 r
.34632 .5077 m .34293 .50843 L .34548 .50757 L F
.34579 .50805 m .34293 .50843 L .34632 .5077 L F
.515 .258 .464 r
.34456 .50863 m .34548 .50757 L .34293 .50843 L F
.75 .752 .853 r
.34293 .50843 m .345 .50847 L .34068 .50816 L F
.34293 .50843 m .34068 .50816 L .34054 .50815 L F
0 0 .278 r
.34575 .50815 m .34585 .50853 L .34559 .50861 L F
.519 .113 .21 r
.345 .50847 m .34585 .50853 L .34575 .50815 L F
.83 .767 .792 r
.3461 .508 m .34575 .50815 L .34579 .50805 L F
.34726 .50785 m .34575 .50815 L .3461 .508 L F
.34726 .50785 m .34579 .50805 L .34632 .5077 L F
0 0 0 r
.62807 .37497 m .62996 .37324 L .63134 .37132 L F
.841 .784 .797 r
.62996 .36706 m .63134 .37132 L .63354 .3683 L F
.989 .732 .364 r
.62996 .37324 m .6312 .37517 L .63134 .37132 L F
.865 .754 .739 r
.62996 .36706 m .63354 .3683 L .6342 .36561 L F
.818 .994 .863 r
.40796 .55513 m .40754 .55727 L .4108 .5543 L F
.853 .992 .738 r
.40796 .55513 m .40533 .55852 L .40754 .55727 L F
.363 .105 .382 r
.59897 .35825 m .60203 .35952 L .60721 .35904 L F
.61 .944 .94 r
.60721 .35904 m .60203 .35952 L .60468 .35784 L F
.533 .346 .573 r
.34608 .55087 m .34567 .55378 L .34789 .55127 L F
.439 .132 .346 r
.41363 .48847 m .41642 .48787 L .41698 .48564 L F
.408 .105 .335 r
.41698 .48564 m .41902 .48714 L .42018 .48464 L F
.41698 .48564 m .41642 .48787 L .41902 .48714 L F
.539 .389 .626 r
.52242 .39165 m .52471 .39484 L .52624 .39311 L F
.52242 .39165 m .52366 .39632 L .52471 .39484 L F
.97 .838 .657 r
.33935 .54074 m .33836 .54114 L .33823 .53934 L F
.122 0 0 r
.33935 .54074 m .33836 .54114 L .34147 .54068 L F
.812 .806 .846 r
.46261 .48726 m .46753 .48584 L .46529 .48412 L F
.843 .794 .804 r
.46753 .48584 m .46821 .48033 L .46529 .48412 L F
.46753 .48584 m .47018 .48238 L .46821 .48033 L F
.721 .752 .877 r
.47018 .48238 m .47101 .47744 L .46821 .48033 L F
.47018 .48238 m .47205 .48043 L .47101 .47744 L F
.752 .451 .475 r
.35114 .54665 m .34742 .54384 L .35143 .54369 L F
.35114 .54665 m .34815 .54648 L .34742 .54384 L F
.061 0 0 r
.34878 .54749 m .35181 .54766 L .35093 .54344 L F
.34858 .54788 m .34901 .54785 L .34878 .54749 L F
.34901 .54785 m .35181 .54766 L .34878 .54749 L F
.752 .451 .475 r
.34815 .54648 m .34671 .54639 L .34713 .54487 L F
.34815 .54648 m .34713 .54487 L .34742 .54384 L F
.596 .034 0 r
.62514 .36524 m .62191 .36334 L .6229 .36487 L F
.62514 .36524 m .62403 .36489 L .62191 .36334 L F
.432 .437 .764 r
.62514 .36524 m .62657 .35968 L .62403 .36489 L F
.62514 .36524 m .62839 .36573 L .62657 .35968 L F
.234 0 0 r
.62514 .36524 m .62829 .36601 L .62839 .36573 L F
.898 .932 .829 r
.62331 .38246 m .62479 .38118 L .62438 .37812 L F
.718 .829 .934 r
.62438 .37812 m .62479 .38118 L .62878 .37835 L F
.7 .444 .534 r
.61042 .35011 m .61577 .34811 L .61165 .34753 L F
.61042 .35011 m .61555 .35076 L .61577 .34811 L F
.441 .103 .296 r
.50652 .40544 m .50913 .40511 L .5096 .40307 L F
.379 .049 .275 r
.50913 .40511 m .51238 .40236 L .5096 .40307 L F
.472 .174 .378 r
.5182 .40585 m .51714 .409 L .51408 .40956 L F
.4 .107 .347 r
.5196 .40824 m .5182 .40585 L .52025 .4055 L F
.5196 .40824 m .51714 .409 L .5182 .40585 L F
.709 .625 .762 r
.50181 .45074 m .5067 .45104 L .50472 .44668 L F
.887 .902 .833 r
.5067 .45104 m .50728 .44675 L .50472 .44668 L F
.5067 .45104 m .50886 .44783 L .50728 .44675 L F
.153 .049 .474 r
.49209 .42038 m .49403 .4216 L .49468 .41965 L F
.49209 .42038 m .49247 .42339 L .49403 .4216 L F
.877 .768 .739 r
.55411 .4033 m .55382 .39882 L .55212 .40109 L F
.808 .659 .109 r
.55382 .40411 m .55411 .4033 L .55212 .40109 L F
.55382 .40411 m .55406 .40642 L .55411 .4033 L F
.939 .579 .181 r
.55508 .37495 m .55671 .37604 L .55275 .37419 L F
.55508 .37495 m .55685 .3779 L .55671 .37604 L F
.597 .441 .642 r
.47074 .43746 m .47402 .43943 L .47322 .43626 L F
.732 .593 .701 r
.62979 .36503 m .6342 .36561 L .6325 .36164 L F
.865 .754 .739 r
.62996 .36706 m .6342 .36561 L .62979 .36503 L F
.666 .622 .795 r
.5429 .3933 m .54344 .39529 L .54027 .39614 L F
.369 .16 .46 r
.49828 .42486 m .49574 .42368 L .49958 .42306 L F
.25 0 .024 r
.50185 .42214 m .49828 .42486 L .49958 .42306 L F
0 0 .29 r
.59039 .37529 m .5912 .37489 L .59159 .37056 L F
0 0 .468 r
.59039 .37529 m .59167 .37752 L .5912 .37489 L F
.818 .994 .863 r
.40796 .55513 m .4108 .5543 L .40929 .55319 L F
.998 .784 .473 r
.40972 .54965 m .40929 .55319 L .4108 .5543 L F
.378 .398 .754 r
.37601 .51538 m .37412 .51671 L .37318 .51423 L F
.038 0 .213 r
.37601 .51538 m .37388 .51885 L .37412 .51671 L F
.482 .101 .239 r
.35029 .49812 m .35327 .49782 L .35473 .49514 L F
.378 0 .183 r
.35473 .49514 m .35601 .49711 L .35746 .49511 L F
.35473 .49514 m .35327 .49782 L .35601 .49711 L F
.8 .731 .788 r
.36762 .54026 m .36761 .5436 L .36333 .54208 L F
.768 .756 .842 r
.36761 .5436 m .3655 .54416 L .36333 .54208 L F
.651 .61 .795 r
.37065 .53962 m .36761 .5436 L .36762 .54026 L F
.645 .762 .934 r
.37224 .5435 m .36761 .5436 L .37065 .53962 L F
.796 .584 .614 r
.5654 .38737 m .56989 .38514 L .56634 .38531 L F
0 0 .166 r
.5916 .3823 m .5927 .38279 L .59336 .38107 L F
.5916 .3823 m .59129 .38477 L .5927 .38279 L F
.788 .295 .027 r
.62822 .35834 m .6301 .36068 L .6325 .36164 L F
.903 .972 .808 r
.62964 .36264 m .6325 .36164 L .6301 .36068 L F
.62964 .36264 m .62979 .36503 L .6325 .36164 L F
.823 .938 .903 r
.50999 .43731 m .50525 .43917 L .50831 .43575 L F
.831 .868 .872 r
.51284 .43456 m .50999 .43731 L .50831 .43575 L F
0 0 .097 r
.53485 .38499 m .53747 .38261 L .53591 .38091 L F
.862 .879 .849 r
.53591 .38091 m .53747 .38261 L .53984 .37921 L F
.663 .567 .737 r
.53984 .37921 m .53747 .38261 L .54046 .38199 L F
.589 .848 .994 r
.55421 .39584 m .55416 .39429 L .55023 .3953 L F
.901 .936 .565 r
.55556 .39096 m .55421 .39584 L .55743 .39269 L F
.55556 .39096 m .55416 .39429 L .55421 .39584 L F
.286 0 0 r
.39944 .49431 m .40392 .49216 L .39985 .49223 L F
.39944 .49431 m .40234 .49378 L .40392 .49216 L F
.405 0 0 r
.40234 .49378 m .406 .49348 L .40392 .49216 L F
.375 0 .068 r
.40392 .49216 m .406 .49348 L .40682 .49181 L F
.527 .01 0 r
.37023 .51509 m .37318 .51423 L .37223 .51288 L F
.37023 .51509 m .37601 .51538 L .37318 .51423 L F
0 0 0 r
.59088 .365 m .59281 .36364 L .59336 .36174 L F
.122 .034 .474 r
.59088 .365 m .59221 .36702 L .59281 .36364 L F
0 0 .509 r
.59155 .36771 m .59221 .36702 L .59088 .365 L F
.754 .876 .935 r
.51973 .43294 m .51543 .43345 L .51825 .43283 L F
.41 .859 .886 r
.52228 .432 m .51973 .43294 L .51825 .43283 L F
.774 .71 .792 r
.37513 .54011 m .37224 .5435 L .37065 .53962 L F
0 .088 .624 r
.33335 .52869 m .33319 .52478 L .33246 .5269 L F
0 0 0 r
.60283 .37465 m .60009 .3778 L .60008 .37538 L F
.798 .565 .585 r
.52522 .39904 m .52952 .3992 L .52923 .39582 L F
.811 .744 .789 r
.5319 .39551 m .53093 .39986 L .52923 .39582 L F
.798 .565 .585 r
.52952 .3992 m .53114 .39927 L .53105 .39909 L F
.52952 .3992 m .53105 .39909 L .52923 .39582 L F
.811 .744 .789 r
.5319 .39551 m .53284 .39868 L .53232 .399 L F
.53111 .39909 m .53232 .399 L .53093 .39986 L F
.5319 .39551 m .53232 .399 L .53111 .39909 L F
.729 .699 .822 r
.53602 .39549 m .53284 .39868 L .5319 .39551 L F
.805 .975 .68 r
.39091 .52706 m .38819 .5306 L .38886 .52867 L F
.841 .466 .34 r
.39091 .52706 m .38886 .52867 L .38846 .52632 L F
.39091 .52706 m .38886 .52867 L .38846 .52632 L F
.658 .198 .149 r
.62395 .35797 m .62657 .35968 L .62822 .35834 L F
.765 .343 .248 r
.62657 .35968 m .6301 .36068 L .62822 .35834 L F
.766 .467 .479 r
.55039 .41103 m .55693 .40979 L .55306 .409 L F
.55039 .41103 m .55739 .41235 L .55693 .40979 L F
.497 .497 .787 r
.35587 .53882 m .35624 .5417 L .35347 .54079 L F
.722 .966 .938 r
.51864 .44193 m .51984 .43992 L .51639 .44193 L F
.51864 .44193 m .52119 .44051 L .51984 .43992 L F
.851 .844 .837 r
.62231 .38408 m .619 .38284 L .6189 .38461 L F
.62231 .38408 m .62331 .38246 L .62161 .38094 L F
.875 .873 .832 r
.6189 .38461 m .62039 .38629 L .62231 .38408 L F
.805 .84 .877 r
.47767 .45398 m .4742 .45417 L .47602 .45249 L F
.751 .833 .915 r
.48026 .45246 m .47767 .45398 L .47602 .45249 L F
.587 .707 .926 r
.35647 .55745 m .36156 .55987 L .35949 .55709 L F
.543 .738 .966 r
.35949 .55709 m .36156 .55987 L .36397 .55918 L F
.574 .293 .452 r
.36569 .49312 m .36696 .4943 L .36452 .49166 L F
.256 .349 .768 r
.565 .39159 m .56724 .39214 L .5654 .38737 L F
.653 .783 .943 r
.61856 .36441 m .6229 .36487 L .62191 .36334 L F
.664 .811 .954 r
.38362 .56643 m .3883 .56681 L .38638 .56532 L F
.318 .501 .88 r
.3883 .56681 m .38953 .56484 L .38638 .56532 L F
.3883 .56681 m .39053 .56724 L .38953 .56484 L F
.798 .565 .585 r
.52522 .39904 m .52923 .39582 L .52471 .39484 L F
.543 .606 .866 r
.52923 .39582 m .5319 .39551 L .53024 .39081 L F
0 .142 .678 r
.52923 .39582 m .53125 .39711 L .5319 .39551 L F
0 0 0 r
.53238 .39636 m .53125 .39711 L .53091 .39827 L F
.53322 .39528 m .53125 .39711 L .53238 .39636 L F
0 .142 .678 r
.52923 .39582 m .5303 .39775 L .53125 .39711 L F
.5303 .39775 m .53114 .39927 L .53125 .39711 L F
.843 .713 .72 r
.38003 .51565 m .37601 .51538 L .37821 .51167 L F
.806 .81 .854 r
.38003 .51565 m .37779 .51719 L .37601 .51538 L F
.319 .526 .899 r
.62488 .37096 m .62996 .37324 L .62807 .37497 L F
0 0 0 r
.55031 .4257 m .55246 .42509 L .55188 .42491 L F
.906 .914 .815 r
.55507 .41875 m .55669 .42023 L .55911 .41667 L F
.97 .876 .685 r
.5553 .42249 m .55669 .42023 L .55507 .41875 L F
.542 .197 .333 r
.5305 .40298 m .53329 .40489 L .53045 .40478 L F
.5305 .40298 m .53274 .40293 L .53329 .40489 L F
0 0 0 r
.54319 .42291 m .54231 .4229 L .54186 .42189 L F
.559 .911 .966 r
.52119 .44051 m .52257 .43875 L .51984 .43992 L F
.52119 .44051 m .52395 .43942 L .52257 .43875 L F
.892 .849 .794 r
.4941 .45613 m .49857 .45377 L .49705 .45217 L F
.4941 .45613 m .49602 .45734 L .49857 .45377 L F
.892 .893 .823 r
.49705 .45217 m .49857 .45377 L .50019 .44942 L F
.505 0 0 r
.5275 .38875 m .53024 .39081 L .53017 .3904 L F
.003 0 0 r
.53017 .3904 m .53327 .39011 L .53252 .38631 L F
.53017 .3904 m .53024 .39081 L .53327 .39011 L F
.367 .076 .332 r
.44682 .46083 m .44951 .46009 L .44995 .45782 L F
.472 .166 .365 r
.44951 .46009 m .45234 .45958 L .44995 .45782 L F
.404 .19 .472 r
.44995 .45782 m .45234 .45958 L .4525 .45689 L F
.912 .528 .274 r
.62829 .36601 m .62979 .36503 L .62964 .36264 L F
.62829 .36601 m .62996 .36706 L .62979 .36503 L F
0 0 .146 r
.54499 .40675 m .54346 .40919 L .54626 .40842 L F
.398 .41 .756 r
.5445 .40239 m .54499 .40675 L .54772 .40412 L F
.557 .543 .794 r
.54626 .40842 m .54772 .40412 L .54499 .40675 L F
.909 .955 .812 r
.44129 .5104 m .44169 .51314 L .44407 .50969 L F
.887 .949 .843 r
.44129 .5104 m .43858 .51375 L .44169 .51314 L F
.811 .881 .896 r
.38819 .5306 m .38313 .5324 L .38525 .53115 L F
.755 .977 .919 r
.38819 .5306 m .38525 .53115 L .38886 .52867 L F
.205 0 0 r
.5586 .38247 m .5541 .38411 L .55544 .38572 L F
.338 .527 .894 r
.5569 .38415 m .55991 .38532 L .55868 .38774 L F
.398 .19 .477 r
.55991 .38532 m .5588 .38691 L .55868 .38774 L F
0 .287 .77 r
.55544 .38572 m .55868 .38774 L .5586 .38835 L F
.07 .34 .816 r
.5569 .38415 m .55868 .38774 L .55544 .38572 L F
.398 .19 .477 r
.5588 .38691 m .55712 .38932 L .55868 .38774 L F
0 .287 .77 r
.5586 .38835 m .55868 .38774 L .55877 .38849 L F
.928 .805 .704 r
.55556 .39096 m .55877 .38849 L .55868 .38774 L F
.55556 .39096 m .55743 .39269 L .55877 .38849 L F
.251 .46 .868 r
.37572 .5626 m .37648 .56485 L .3774 .56251 L F
.413 .65 .955 r
.37648 .56485 m .37962 .56498 L .3774 .56251 L F
.564 .378 .588 r
.43861 .47139 m .43868 .47431 L .4415 .47086 L F
.724 .407 .441 r
.54829 .39159 m .54602 .39195 L .54609 .38891 L F
.486 .68 .951 r
.37303 .56315 m .37339 .5598 L .37036 .55999 L F
.37303 .56315 m .37572 .5626 L .37339 .5598 L F
.13 0 0 r
.47816 .4381 m .47672 .43906 L .47402 .43943 L F
0 0 0 r
.47949 .438 m .47672 .43906 L .47816 .4381 L F
.83 .988 .869 r
.51176 .44496 m .50962 .44521 L .50886 .44783 L F
.723 .897 .958 r
.50886 .44783 m .50962 .44521 L .50728 .44675 L F
.974 .734 .511 r
.55911 .41667 m .55739 .41235 L .55716 .41505 L F
.906 .914 .815 r
.55507 .41875 m .55911 .41667 L .55716 .41505 L F
.974 .734 .511 r
.55911 .41667 m .55739 .41235 L .55716 .41505 L F
.831 .868 .872 r
.51284 .43456 m .50831 .43575 L .51094 .4335 L F
.569 .907 .976 r
.51543 .43345 m .51284 .43456 L .51094 .4335 L F
.398 .003 .169 r
.59336 .36174 m .59602 .36174 L .59611 .36028 L F
.59336 .36174 m .59281 .36364 L .59602 .36174 L F
.625 .321 .435 r
.41902 .48714 m .42301 .48445 L .42018 .48464 L F
.724 .615 .736 r
.48638 .44415 m .48727 .44775 L .48589 .44646 L F
.542 .463 .716 r
.48727 .44775 m .48311 .44953 L .48589 .44646 L F
.529 .455 .716 r
.49038 .45008 m .48727 .44775 L .49027 .44706 L F
.49038 .45008 m .48798 .45116 L .48727 .44775 L F
.363 .035 .268 r
.51238 .40236 m .51506 .40163 L .51289 .40125 L F
.07 .34 .816 r
.5569 .38415 m .55544 .38572 L .5541 .38411 L F
.728 .66 .783 r
.34134 .53304 m .33838 .53651 L .33698 .53304 L F
0 .066 .628 r
.33838 .53651 m .33905 .53523 L .33698 .53304 L F
.532 .595 .862 r
.33823 .53934 m .33905 .53523 L .33838 .53651 L F
0 0 0 r
.55079 .41549 m .5485 .4191 L .54963 .4186 L F
.682 .736 .892 r
.54786 .42188 m .54963 .4186 L .5485 .4191 L F
.375 .059 .296 r
.42598 .48118 m .42875 .48046 L .42914 .47824 L F
.557 .215 .344 r
.42914 .47824 m .43163 .48017 L .43175 .47782 L F
.42914 .47824 m .42875 .48046 L .43163 .48017 L F
.784 .595 .645 r
.54233 .41214 m .54626 .40842 L .54346 .40919 L F
.615 .482 .677 r
.44141 .46792 m .4445 .46752 L .44391 .46457 L F
.474 .245 .485 r
.4415 .47086 m .4445 .46752 L .44141 .46792 L F
.882 .656 .592 r
.41617 .53984 m .41845 .54358 L .41503 .54141 L F
.872 .656 .607 r
.41617 .53984 m .41845 .54358 L .41503 .54141 L F
0 .434 .841 r
.41845 .54358 m .4171 .54233 L .41503 .54141 L F
.882 .656 .592 r
.41845 .54358 m .41617 .53984 L .4171 .54233 L F
.764 .731 .822 r
.37513 .54011 m .37065 .53962 L .37367 .53662 L F
.786 .741 .811 r
.37812 .53693 m .37513 .54011 L .37367 .53662 L F
.603 .273 .383 r
.59611 .36028 m .59897 .35825 L .59593 .35812 L F
.621 .216 .254 r
.41345 .4904 m .41621 .49062 L .41363 .48847 L F
.495 .265 .494 r
.41363 .48847 m .41621 .49062 L .41642 .48787 L F
.479 .097 .237 r
.40954 .49124 m .41345 .4904 L .41363 .48847 L F
.694 .612 .76 r
.34509 .52198 m .34218 .52573 L .3425 .5227 L F
0 0 0 r
.49283 .42951 m .48904 .43212 L .49031 .43033 L F
.404 .189 .47 r
.49302 .42666 m .49283 .42951 L .49031 .43033 L F
.72 .393 .424 r
.36302 .50586 m .36293 .50823 L .36046 .50537 L F
.71 .384 .424 r
.36728 .50842 m .36302 .50586 L .36739 .50557 L F
.36728 .50842 m .36293 .50823 L .36302 .50586 L F
.5 .409 .684 r
.54046 .38199 m .54267 .37827 L .53984 .37921 L F
.54046 .38199 m .54356 .38129 L .54267 .37827 L F
.308 .164 .516 r
.54046 .38199 m .5429 .38365 L .54356 .38129 L F
.54046 .38199 m .54078 .3849 L .5429 .38365 L F
.898 .971 .818 r
.44402 .50691 m .44407 .50969 L .44678 .50624 L F
.891 .969 .83 r
.44402 .50691 m .44129 .5104 L .44407 .50969 L F
.303 .011 .293 r
.49775 .41621 m .49998 .41541 L .5007 .41249 L F
.536 .217 .375 r
.5007 .41249 m .49998 .41541 L .50419 .41413 L F
.875 .967 .851 r
.44678 .50624 m .44959 .50294 L .44673 .5034 L F
.894 .973 .822 r
.44673 .5034 m .44402 .50691 L .44678 .50624 L F
.33 .016 .273 r
.52343 .40256 m .52257 .4052 L .52025 .4055 L F
.028 .432 .867 r
.52343 .40256 m .52691 .40393 L .52595 .40222 L F
.521 .192 .35 r
.52712 .40435 m .52343 .40256 L .52595 .40222 L F
.794 .519 .521 r
.49734 .43004 m .49302 .42666 L .4958 .42585 L F
.49734 .43004 m .49283 .42951 L .49302 .42666 L F
.636 .766 .941 r
.36118 .54259 m .35624 .5417 L .35923 .53896 L F
.458 .32 .605 r
.3642 .53976 m .36118 .54259 L .35923 .53896 L F
.3642 .53976 m .36333 .54208 L .36118 .54259 L F
.653 .903 .982 r
.39053 .56724 m .39477 .56683 L .39374 .56646 L F
.709 .839 .944 r
.39477 .56683 m .39654 .56321 L .39374 .56646 L F
.39477 .56683 m .39722 .56541 L .39654 .56321 L F
.567 .543 .788 r
.54602 .39195 m .54344 .39529 L .5429 .3933 L F
.54602 .39195 m .54614 .39441 L .54344 .39529 L F
.657 .521 .687 r
.54764 .39754 m .54344 .39529 L .54614 .39441 L F
.42 .239 .527 r
.39211 .55359 m .39209 .55667 L .39452 .55575 L F
.39211 .55359 m .39209 .55667 L .39452 .55575 L F
0 .007 .542 r
.59129 .38477 m .59165 .38915 L .59303 .38754 L F
.126 .164 .631 r
.59165 .38915 m .59417 .38962 L .59303 .38754 L F
.59165 .38915 m .59263 .39198 L .59417 .38962 L F
.4 .159 .43 r
.44391 .46457 m .44659 .46372 L .44682 .46083 L F
.452 .202 .442 r
.44682 .46083 m .44945 .46296 L .44951 .46009 L F
.44682 .46083 m .44659 .46372 L .44945 .46296 L F
.723 .633 .757 r
.4015 .53278 m .40556 .53286 L .40425 .52926 L F
.225 0 .049 r
.40464 .53375 m .40556 .53286 L .4015 .53278 L F
.40464 .53375 m .4046 .5351 L .40556 .53286 L F
0 .154 .679 r
.40425 .52926 m .40556 .53286 L .40598 .53163 L F
0 0 .003 r
.39823 .53469 m .39789 .53516 L .39681 .53295 L F
.865 .777 .763 r
.40113 .53279 m .39917 .53583 L .4015 .53278 L F
.39681 .53295 m .39836 .53485 L .40113 .53279 L F
.39836 .53485 m .39917 .53583 L .40113 .53279 L F
.39823 .53469 m .39884 .53627 L .39917 .53583 L F
.39806 .53499 m .39884 .53627 L .39823 .53469 L F
.41 .582 .911 r
.39789 .53516 m .39884 .53627 L .39806 .53499 L F
0 0 .003 r
.39823 .53469 m .39799 .53512 L .39789 .53516 L F
.41 .582 .911 r
.39789 .53516 m .39806 .53499 L .39681 .53295 L F
0 0 .003 r
.39811 .53494 m .39915 .53475 L .39799 .53512 L F
.865 .777 .763 r
.39681 .53295 m .4015 .53278 L .40003 .53217 L F
0 0 .003 r
.40003 .53217 m .39956 .53354 L .39811 .53494 L F
.39956 .53354 m .39915 .53475 L .39811 .53494 L F
.818 .711 .747 r
.39434 .53813 m .39884 .53627 L .39789 .53516 L F
.715 .554 .67 r
.39915 .53475 m .39584 .53709 L .39769 .53534 L F
.39799 .53512 m .39769 .53534 L .39789 .53516 L F
.39915 .53475 m .39769 .53534 L .39799 .53512 L F
0 0 .003 r
.40003 .53217 m .39799 .53512 L .39823 .53469 L F
.865 .777 .763 r
.39681 .53295 m .39806 .53499 L .39823 .53469 L F
0 0 .003 r
.40003 .53217 m .39823 .53469 L .39681 .53295 L F
.683 .497 .629 r
.4015 .53278 m .39884 .53627 L .40464 .53375 L F
.57 .273 .426 r
.40063 .53549 m .40117 .53829 L .40464 .53375 L F
.39884 .53627 m .40117 .53829 L .40063 .53549 L F
0 0 .127 r
.40141 .54143 m .40158 .54042 L .40117 .53829 L F
0 0 0 r
.40117 .53829 m .4046 .5351 L .40464 .53375 L F
.185 .429 .862 r
.40117 .53829 m .4046 .5351 L .40261 .53734 L F
.40117 .53829 m .39915 .53475 L .4046 .5351 L F
0 0 0 r
.40117 .53829 m .40261 .53734 L .4046 .5351 L F
.818 .711 .747 r
.39434 .53813 m .39638 .5396 L .39884 .53627 L F
.719 .563 .676 r
.39638 .5396 m .39948 .53951 L .39884 .53627 L F
.317 .29 .67 r
.39948 .53951 m .40117 .53829 L .39884 .53627 L F
.185 .429 .862 r
.40117 .53829 m .40224 .53656 L .39915 .53475 L F
.715 .554 .67 r
.39915 .53475 m .40182 .53727 L .39584 .53709 L F
.40182 .53727 m .40209 .53752 L .40182 .5375 L F
.40182 .53727 m .40182 .5375 L .39584 .53709 L F
0 0 .127 r
.40158 .54042 m .40183 .53894 L .40117 .53829 L F
.492 .47 .76 r
.4001 .53915 m .39584 .53709 L .40182 .5375 L F
.40188 .53769 m .40182 .5375 L .40209 .53752 L F
.4001 .53915 m .40182 .5375 L .40188 .53769 L F
.196 .431 .86 r
.40224 .53656 m .40209 .53752 L .40182 .53727 L F
0 0 .127 r
.40182 .53727 m .40224 .53656 L .40182 .53723 L F
.196 .431 .86 r
.40224 .53656 m .40182 .53727 L .39915 .53475 L F
0 0 .127 r
.40182 .5375 m .40224 .53656 L .40182 .53727 L F
.40183 .53894 m .40198 .53807 L .40182 .5375 L F
.40188 .53769 m .40224 .53656 L .40182 .5375 L F
.594 .364 .538 r
.40224 .53656 m .4001 .53915 L .40188 .53769 L F
.40224 .53656 m .40188 .53769 L .40209 .53752 L F
0 0 .127 r
.40198 .53807 m .40224 .53656 L .40188 .53769 L F
.40183 .53894 m .40182 .53723 L .40117 .53829 L F
.816 .58 .582 r
.40542 .53307 m .4046 .5351 L .39915 .53475 L F
.7 .78 .297 r
.40556 .53286 m .4046 .5351 L .40479 .53463 L F
.40556 .53286 m .40537 .53331 L .40585 .532 L F
.77 .505 .534 r
.40425 .52926 m .40003 .53217 L .4015 .53278 L F
.816 .58 .582 r
.40552 .53283 m .39915 .53475 L .40003 .53217 L F
.40608 .5329 m .40542 .53307 L .40552 .53283 L F
.40542 .53307 m .39915 .53475 L .40552 .53283 L F
.7 .78 .297 r
.40537 .53331 m .40476 .5347 L .40552 .53283 L F
.40572 .53234 m .40552 .53283 L .40575 .53224 L F
.40537 .53331 m .40552 .53283 L .40572 .53234 L F
.40537 .53331 m .40575 .53224 L .40585 .532 L F
.515 .782 .993 r
.40556 .53286 m .40778 .53236 L .40585 .532 L F
.209 .251 .687 r
.40598 .53163 m .40608 .5329 L .40575 .53224 L F
.40598 .53163 m .40575 .53224 L .40425 .52926 L F
.816 .58 .582 r
.40608 .5329 m .4046 .5351 L .40542 .53307 L F
.7 .78 .297 r
.40479 .53463 m .4046 .5351 L .40476 .5347 L F
.77 .505 .534 r
.40557 .53271 m .40552 .53283 L .40003 .53217 L F
.40561 .53196 m .40608 .5329 L .40144 .5312 L F
.7 .78 .297 r
.40585 .532 m .40476 .5347 L .40598 .53163 L F
.77 .505 .534 r
.40144 .5312 m .40557 .53271 L .40003 .53217 L F
.40557 .53271 m .40608 .5329 L .40552 .53283 L F
.40425 .52926 m .40561 .53196 L .40144 .5312 L F
.515 .782 .993 r
.40556 .53286 m .40863 .5327 L .40778 .53236 L F
.40585 .532 m .40778 .53236 L .40598 .53163 L F
.864 .757 .743 r
.48638 .44415 m .48589 .44646 L .48291 .4437 L F
.875 .871 .83 r
.48589 .44646 m .48208 .44633 L .48291 .4437 L F
.48589 .44646 m .48311 .44953 L .48208 .44633 L F
.369 .16 .46 r
.49828 .42486 m .4958 .42585 L .49574 .42368 L F
0 0 0 r
.53445 .42322 m .53237 .42699 L .53531 .42632 L F
.774 .983 .73 r
.53237 .42699 m .53348 .42445 L .53487 .42642 L F
.53237 .42699 m .53051 .42763 L .53348 .42445 L F
.483 .24 .469 r
.53348 .42445 m .53051 .42763 L .53317 .42691 L F
.757 .512 0 r
.53317 .42691 m .53237 .42288 L .53348 .42445 L F
.53237 .42288 m .53232 .42262 L .53348 .42445 L F
.774 .983 .73 r
.53487 .42642 m .53348 .42445 L .53531 .42632 L F
.555 .101 .128 r
.36046 .50537 m .35864 .50737 L .35626 .50564 L F
.775 .374 .294 r
.36046 .50537 m .36293 .50823 L .35864 .50737 L F
0 0 .07 r
.33653 .51243 m .33849 .51106 L .34012 .50716 L F
0 0 .02 r
.33653 .51243 m .33688 .51312 L .33849 .51106 L F
.33653 .51243 m .33618 .515 L .33688 .51312 L F
.751 .833 .915 r
.48026 .45246 m .47602 .45249 L .48007 .44903 L F
.856 .905 .867 r
.48311 .44953 m .48026 .45246 L .48007 .44903 L F
.852 .98 .864 r
.45149 .50115 m .44673 .5034 L .44959 .50294 L F
.45149 .50115 m .44993 .50027 L .44673 .5034 L F
.894 .974 .821 r
.45268 .4968 m .45149 .50115 L .45416 .49787 L F
.45268 .4968 m .44993 .50027 L .45149 .50115 L F
.893 .795 .745 r
.56859 .38924 m .5705 .39128 L .56965 .38802 L F
.747 .718 .825 r
.56965 .38802 m .5705 .39128 L .57402 .38888 L F
.193 0 0 r
.35626 .50564 m .35159 .5075 L .35369 .50496 L F
.993 .747 .394 r
.49734 .43004 m .49589 .42938 L .49283 .42951 L F
.49734 .43004 m .49711 .43267 L .49589 .42938 L F
.684 .445 .555 r
.5009 .42694 m .49943 .42803 L .49829 .42779 L F
.258 .494 .892 r
.49829 .42779 m .49734 .43004 L .49636 .42739 L F
.49829 .42779 m .49861 .42877 L .49734 .43004 L F
.595 .571 .797 r
.49861 .42877 m .49711 .43267 L .49734 .43004 L F
.596 .613 .839 r
.49711 .43267 m .49829 .42779 L .49589 .42938 L F
.595 .571 .797 r
.49861 .42877 m .50019 .43216 L .49711 .43267 L F
.594 .571 .797 r
.49861 .42877 m .50286 .43139 L .50019 .43216 L F
.49861 .42877 m .50286 .43139 L .50019 .43216 L F
0 0 .52 r
.49829 .42779 m .50019 .43216 L .49861 .42877 L F
.596 .613 .839 r
.49711 .43267 m .50019 .43216 L .49829 .42779 L F
.684 .445 .555 r
.49943 .42803 m .49712 .42975 L .49829 .42779 L F
.258 .494 .892 r
.49829 .42779 m .49636 .42739 L .4958 .42585 L F
.897 .707 .638 r
.50586 .4084 m .5092 .41268 L .51074 .4094 L F
0 0 0 r
.5092 .41268 m .51392 .40534 L .51074 .4094 L F
.5092 .41268 m .51097 .40998 L .51392 .40534 L F
.312 .783 .674 r
.5092 .41268 m .51067 .41187 L .51097 .40998 L F
.5092 .41268 m .50813 .41302 L .51067 .41187 L F
.35 .074 .347 r
.45216 .45403 m .45495 .45341 L .45531 .45057 L F
.257 0 .263 r
.45831 .44763 m .45531 .45057 L .45775 .44958 L F
.426 .135 .367 r
.45531 .45057 m .45755 .45247 L .45775 .44958 L F
.45531 .45057 m .45495 .45341 L .45755 .45247 L F
.614 .632 .845 r
.34789 .55127 m .35254 .55367 L .35128 .55133 L F
.431 .601 .917 r
.35128 .55133 m .35254 .55367 L .35356 .55126 L F
.359 .517 .878 r
.35254 .55367 m .35515 .55411 L .35356 .55126 L F
.005 .581 .734 r
.52751 .39906 m .53114 .39927 L .52522 .39904 L F
.838 .975 .88 r
.53125 .39711 m .53114 .39927 L .52751 .39906 L F
.657 .441 .58 r
.50586 .4084 m .50913 .40511 L .50652 .40544 L F
.431 .832 .629 r
.50472 .44668 m .50248 .44803 L .50034 .4495 L F
.76 .948 .94 r
.50728 .44675 m .50248 .44803 L .50472 .44668 L F
.786 .741 .811 r
.37812 .53693 m .37367 .53662 L .37607 .53514 L F
.803 .757 .81 r
.38023 .53345 m .37812 .53693 L .37607 .53514 L F
.753 .912 .946 r
.49983 .4434 m .49596 .4438 L .49873 .44253 L F
.623 .923 .974 r
.49983 .4434 m .50127 .43979 L .50358 .44107 L F
.49983 .4434 m .49873 .44253 L .50127 .43979 L F
.864 .757 .743 r
.48638 .44415 m .48291 .4437 L .4842 .44257 L F
.773 .79 .866 r
.48913 .4423 m .48638 .44415 L .4842 .44257 L F
.773 .683 .764 r
.34218 .52573 m .34014 .5298 L .33963 .52632 L F
.69 .579 .726 r
.34218 .52573 m .34387 .52977 L .34014 .5298 L F
.746 .629 .73 r
.34387 .52977 m .33849 .53252 L .34014 .5298 L F
.282 .242 .636 r
.60675 .35638 m .60862 .35629 L .60615 .35435 L F
.945 .921 .555 r
.55306 .409 m .55406 .40642 L .55382 .40411 L F
.205 0 0 r
.5586 .38247 m .5569 .38415 L .5541 .38411 L F
.6 .94 .762 r
.56136 .38035 m .5605 .38049 L .5586 .38247 L F
0 0 0 r
.56 .38234 m .5586 .38247 L .5605 .38049 L F
.56 .38234 m .5569 .38415 L .5586 .38247 L F
.746 .981 .913 r
.51416 .44339 m .50962 .44521 L .51176 .44496 L F
.79 .963 .919 r
.6102 .38239 m .60783 .38436 L .60899 .38533 L F
.6102 .38239 m .60783 .38436 L .60899 .38533 L F
.806 .98 .896 r
.61068 .38232 m .6102 .38239 L .60899 .38533 L F
.883 .874 .823 r
.48208 .44633 m .48311 .44953 L .48097 .44808 L F
.856 .905 .867 r
.48311 .44953 m .48007 .44903 L .48097 .44808 L F
.603 .273 .383 r
.59611 .36028 m .59921 .36072 L .59897 .35825 L F
.363 .105 .382 r
.59897 .35825 m .59921 .36072 L .60203 .35952 L F
.384 .076 .315 r
.45831 .44763 m .4607 .44869 L .46069 .44635 L F
.45831 .44763 m .45775 .44958 L .4607 .44869 L F
.431 .358 .674 r
.44391 .46457 m .44682 .46657 L .44659 .46372 L F
.44391 .46457 m .4445 .46752 L .44682 .46657 L F
.384 .568 .909 r
.35213 .52722 m .35093 .52934 L .34876 .52636 L F
.388 .573 .912 r
.35213 .52722 m .3538 .52993 L .35093 .52934 L F
0 0 0 r
.5454 .37725 m .54806 .37629 L .54978 .37438 L F
.11 0 0 r
.54978 .37438 m .55077 .3754 L .55275 .37419 L F
.54978 .37438 m .54806 .37629 L .55077 .3754 L F
.868 .842 .817 r
.4795 .467 m .47681 .47045 L .48005 .47093 L F
.767 .901 .935 r
.48005 .47093 m .47408 .47114 L .47785 .47403 L F
.48005 .47093 m .47681 .47045 L .47408 .47114 L F
.855 .834 .825 r
.4795 .467 m .48005 .47093 L .4831 .46691 L F
0 .045 .591 r
.34392 .51505 m .34582 .51758 L .34475 .51918 L F
.495 .559 .85 r
.34582 .51758 m .34509 .52198 L .34475 .51918 L F
0 0 0 r
.60283 .37465 m .60186 .37637 L .60009 .3778 L F
.6059 .37326 m .60536 .37388 L .60283 .37465 L F
.326 0 .186 r
.60536 .37388 m .60186 .37637 L .60283 .37465 L F
.612 .385 .549 r
.4357 .47455 m .43857 .47706 L .43868 .47431 L F
.4357 .47455 m .43565 .47737 L .43857 .47706 L F
.128 .224 .695 r
.34671 .54639 m .34789 .55127 L .34917 .54836 L F
.482 .649 .932 r
.34789 .55127 m .35128 .55133 L .34917 .54836 L F
.601 .719 .927 r
.61555 .35076 m .62005 .35164 L .61803 .35039 L F
.489 .184 .376 r
.51408 .40956 m .51373 .41181 L .51082 .41228 L F
.491 .197 .395 r
.51714 .409 m .51373 .41181 L .51408 .40956 L F
.802 .794 .845 r
.47101 .47744 m .47205 .48043 L .47512 .4777 L F
.549 .184 .299 r
.53274 .40293 m .53604 .40391 L .53329 .40489 L F
.53274 .40293 m .53753 .4021 L .53604 .40391 L F
.579 .249 .374 r
.52446 .40626 m .52025 .4055 L .52257 .4052 L F
.52446 .40626 m .5196 .40824 L .52025 .4055 L F
.789 .92 .925 r
.40948 .54499 m .4077 .54615 L .41145 .54588 L F
.879 .755 .721 r
.40697 .54879 m .41145 .54588 L .4077 .54615 L F
.40697 .54879 m .40972 .54965 L .41145 .54588 L F
.747 .918 .949 r
.41323 .54274 m .41145 .54588 L .41503 .54141 L F
.41323 .54274 m .40948 .54499 L .41145 .54588 L F
.636 .239 .275 r
.61156 .36943 m .6157 .36798 L .61389 .36602 L F
.61156 .36943 m .61564 .37059 L .6157 .36798 L F
.852 .818 .815 r
.61389 .36602 m .6157 .36798 L .61856 .36441 L F
.504 .133 .269 r
.6157 .36798 m .61564 .37059 L .61871 .36944 L F
.852 .818 .815 r
.61389 .36602 m .61856 .36441 L .61713 .36323 L F
0 .255 .68 r
.62191 .36334 m .6172 .3604 L .61856 .36441 L F
.62191 .36334 m .61997 .36196 L .6172 .3604 L F
.234 .372 .799 r
.61856 .36441 m .61997 .36196 L .6172 .3604 L F
.67 .926 .973 r
.61997 .36196 m .61713 .36323 L .61856 .36441 L F
.8 .874 .902 r
.6249 .36888 m .62681 .3704 L .62996 .36706 L F
.824 .801 .83 r
.47408 .47114 m .47388 .47378 L .47785 .47403 L F
.839 .766 .782 r
.47388 .47378 m .47512 .4777 L .47785 .47403 L F
.824 .801 .83 r
.47408 .47114 m .47388 .47378 L .47785 .47403 L F
.809 .803 .846 r
.47785 .47403 m .47681 .47045 L .47408 .47114 L F
.602 .429 .62 r
.46687 .44027 m .46753 .44346 L .47047 .44274 L F
.753 .599 .686 r
.38008 .50699 m .37821 .51167 L .37672 .50812 L F
.746 .629 .73 r
.34387 .52977 m .34134 .53304 L .33849 .53252 L F
.705 .586 .72 r
.3464 .52663 m .34387 .52977 L .34218 .52573 L F
.535 .025 0 r
.37144 .49447 m .37413 .49606 L .3758 .4944 L F
.486 0 0 r
.37413 .49606 m .37843 .49481 L .3758 .4944 L F
.193 0 0 r
.35626 .50564 m .35429 .50706 L .35159 .5075 L F
.574 .069 .016 r
.35626 .50564 m .35864 .50737 L .35429 .50706 L F
.488 .152 .323 r
.34573 .49971 m .35029 .49812 L .34763 .4983 L F
.494 .349 .613 r
.45216 .45403 m .45518 .45613 L .45495 .45341 L F
.45216 .45403 m .4525 .45689 L .45518 .45613 L F
0 0 .475 r
.37888 .55077 m .37988 .55199 L .38032 .55364 L F
.947 .601 .321 r
.37845 .55487 m .38032 .55364 L .37988 .55199 L F
.37845 .55487 m .37944 .55582 L .38032 .55364 L F
.795 .651 .703 r
.36626 .53857 m .36762 .54026 L .3642 .53976 L F
.8 .731 .788 r
.36762 .54026 m .36333 .54208 L .3642 .53976 L F
.652 .625 .81 r
.37065 .53962 m .36762 .54026 L .36626 .53857 L F
.882 .744 .705 r
.52963 .41593 m .53105 .41921 L .52863 .41887 L F
.857 .511 .398 r
.52863 .41887 m .53105 .41921 L .52909 .42136 L F
.775 .39 .326 r
.53105 .41921 m .53283 .42211 L .52909 .42136 L F
.881 .455 .179 r
.53105 .41921 m .53445 .42322 L .53283 .42211 L F
.773 .79 .866 r
.48913 .4423 m .4842 .44257 L .4874 .43925 L F
.736 .78 .888 r
.49145 .43991 m .48913 .4423 L .4874 .43925 L F
.6 .702 .915 r
.49236 .44171 m .48913 .4423 L .49145 .43991 L F
.728 .66 .783 r
.34134 .53304 m .33698 .53304 L .33849 .53252 L F
.783 .522 .542 r
.41433 .5391 m .41617 .53984 L .41503 .54141 L F
.792 .981 .902 r
.41617 .53984 m .41739 .53672 L .41532 .53821 L F
.41617 .53984 m .42026 .53637 L .41739 .53672 L F
.888 .459 .11 r
.41509 .54092 m .41617 .53984 L .41532 .53821 L F
.41509 .54092 m .4171 .54233 L .41617 .53984 L F
.607 .076 0 r
.50403 .43397 m .50512 .43356 L .50413 .43285 L F
.433 .242 .52 r
.50413 .43285 m .50512 .43356 L .50763 .42959 L F
.605 .757 .951 r
.50286 .43139 m .50461 .43307 L .50019 .43216 L F
.50461 .43307 m .50512 .43356 L .50418 .4333 L F
.024 0 0 r
.50408 .43335 m .50413 .43285 L .50461 .43307 L F
.605 .757 .951 r
.50461 .43307 m .50418 .4333 L .50019 .43216 L F
.024 0 0 r
.50461 .43307 m .50413 .43285 L .50496 .43253 L F
.50403 .43397 m .50408 .43335 L .50461 .43307 L F
.964 .695 .474 r
.50461 .43307 m .50476 .43321 L .50403 .43397 L F
.857 .801 .794 r
.50763 .42959 m .50644 .43147 L .50614 .43147 L F
.433 .242 .52 r
.50496 .43253 m .50763 .42959 L .50545 .43234 L F
.024 0 0 r
.50461 .43307 m .50496 .43253 L .50545 .43234 L F
.433 .242 .52 r
.50413 .43285 m .50514 .43191 L .50496 .43253 L F
.50514 .43191 m .50763 .42959 L .50496 .43253 L F
.857 .801 .794 r
.50644 .43147 m .50461 .43307 L .50286 .43139 L F
.433 .242 .52 r
.50545 .43234 m .50763 .42959 L .50685 .43179 L F
.857 .801 .794 r
.50763 .42959 m .50614 .43147 L .50286 .43139 L F
.50644 .43147 m .50512 .43356 L .50461 .43307 L F
.024 0 0 r
.50403 .43397 m .50461 .43307 L .50685 .43179 L F
.50461 .43307 m .50545 .43234 L .50685 .43179 L F
.964 .695 .474 r
.50286 .43139 m .50461 .43307 L .50403 .43397 L F
.50476 .43321 m .50512 .43356 L .50459 .43376 L F
.50476 .43321 m .50459 .43376 L .50403 .43397 L F
.347 .242 .59 r
.47126 .44556 m .46852 .44998 L .46841 .44688 L F
.47126 .44556 m .47156 .44887 L .46852 .44998 L F
.584 .194 .269 r
.55013 .40129 m .55382 .39882 L .54987 .39807 L F
.55013 .40129 m .55212 .40109 L .55382 .39882 L F
.921 .528 .192 r
.53283 .42211 m .53445 .42322 L .53348 .42445 L F
.468 .36 .649 r
.53445 .42322 m .53531 .42632 L .53778 .42506 L F
.595 .061 0 r
.53445 .42322 m .53778 .42506 L .53348 .42445 L F
.813 .888 .898 r
.48104 .46564 m .4795 .467 L .4831 .46691 L F
.731 .953 .948 r
.48643 .46397 m .48104 .46564 L .4831 .46691 L F
.658 .189 .128 r
.62395 .35797 m .62141 .35932 L .62657 .35968 L F
.967 .91 .704 r
.62265 .35597 m .62141 .35932 L .62395 .35797 L F
.471 .227 .463 r
.42301 .48445 m .42575 .48396 L .42598 .48118 L F
.441 .203 .456 r
.42598 .48118 m .42575 .48396 L .42875 .48046 L F
.745 .6 .696 r
.60952 .34934 m .60929 .35165 L .61042 .35011 L F
.699 .606 .749 r
.60952 .34934 m .61042 .35011 L .61165 .34753 L F
.697 .571 .709 r
.61042 .35011 m .61279 .35426 L .61555 .35076 L F
.694 .612 .76 r
.34509 .52198 m .3464 .52663 L .34218 .52573 L F
.5 .496 .784 r
.34749 .5214 m .3464 .52663 L .34509 .52198 L F
.34749 .5214 m .34876 .52636 L .3464 .52663 L F
.252 0 .007 r
.54337 .42966 m .54221 .43191 L .53947 .43255 L F
.54 .831 .497 r
.54544 .42734 m .5449 .42792 L .54337 .42966 L F
.5 .362 .624 r
.5449 .42792 m .54221 .43191 L .54337 .42966 L F
.122 .077 .529 r
.59159 .37056 m .59221 .36702 L .59155 .36771 L F
.589 .494 .715 r
.49236 .44171 m .49195 .4471 L .49027 .44706 L F
.487 .314 .571 r
.49195 .4471 m .49038 .45008 L .49027 .44706 L F
.648 .118 0 r
.61012 .36011 m .61311 .36243 L .61429 .36112 L F
.792 .495 .485 r
.61311 .36243 m .6172 .3604 L .61429 .36112 L F
.82 .757 .793 r
.47101 .47744 m .47512 .4777 L .47388 .47378 L F
.58 .47 .693 r
.33836 .54114 m .34274 .5445 L .34147 .54068 L F
.33836 .54114 m .33975 .54627 L .34274 .5445 L F
.683 .503 .637 r
.37402 .51159 m .36999 .50847 L .37478 .50885 L F
.776 .512 .536 r
.37821 .51167 m .37478 .50885 L .37672 .50812 L F
.37821 .51167 m .37402 .51159 L .37478 .50885 L F
.591 .251 .362 r
.406 .49348 m .40954 .49124 L .40682 .49181 L F
.753 .614 .705 r
.54593 .40018 m .5445 .40239 L .54033 .40221 L F
.533 .186 .325 r
.35601 .49711 m .36006 .49453 L .35746 .49511 L F
.519 .096 .179 r
.53753 .4021 m .5401 .40367 L .53604 .40391 L F
.53753 .4021 m .54033 .40221 L .5401 .40367 L F
.474 .245 .485 r
.4415 .47086 m .44424 .47021 L .4445 .46752 L F
.487 .256 .489 r
.4445 .46752 m .44703 .46955 L .44682 .46657 L F
.4445 .46752 m .44424 .47021 L .44703 .46955 L F
.96 .941 .636 r
.50358 .44107 m .50332 .43821 L .50525 .43917 L F
.50358 .44107 m .50127 .43979 L .50332 .43821 L F
.663 .675 .851 r
.3629 .53599 m .35754 .53221 L .3604 .53155 L F
.561 .653 .897 r
.36547 .53487 m .3629 .53599 L .3604 .53155 L F
.454 .345 .641 r
.36547 .53487 m .36287 .53633 L .3629 .53599 L F
0 .015 .562 r
.34423 .51259 m .34298 .51207 L .3444 .51036 L F
.34423 .51259 m .34392 .51505 L .34298 .51207 L F
.719 .523 .623 r
.36287 .53633 m .3642 .53976 L .35923 .53896 L F
.742 .533 .612 r
.36626 .53857 m .36287 .53633 L .36547 .53487 L F
.36626 .53857 m .3642 .53976 L .36287 .53633 L F
.442 .098 .286 r
.36772 .52589 m .36436 .52905 L .36311 .5251 L F
.36772 .52589 m .36744 .52826 L .36436 .52905 L F
.584 .217 .311 r
.37015 .52798 m .36744 .52826 L .36772 .52589 L F
.475 .246 .486 r
.37042 .52524 m .37015 .52798 L .36772 .52589 L F
.787 .463 .44 r
.38611 .52557 m .38393 .528 L .38246 .52491 L F
.724 .379 .394 r
.38846 .52632 m .38393 .528 L .38611 .52557 L F
.983 .77 .364 r
.5604 .37686 m .56136 .38035 L .56295 .37906 L F
.636 .744 .926 r
.38188 .56391 m .38362 .56643 L .38638 .56532 L F
.379 .049 .275 r
.50913 .40511 m .51188 .40448 L .51238 .40236 L F
.421 .108 .327 r
.51188 .40448 m .51506 .40163 L .51238 .40236 L F
.524 .326 .554 r
.43868 .47431 m .44151 .4738 L .4415 .47086 L F
.353 .085 .362 r
.43857 .47706 m .44151 .4738 L .43868 .47431 L F
.555 .375 .592 r
.55023 .3953 m .54764 .39754 L .54614 .39441 L F
.55023 .3953 m .54987 .39807 L .54764 .39754 L F
.474 .287 .546 r
.4415 .47086 m .44417 .47302 L .44424 .47021 L F
.4415 .47086 m .44151 .4738 L .44417 .47302 L F
.767 .564 .624 r
.38389 .52185 m .38246 .52491 L .38016 .52182 L F
.585 .79 .977 r
.52395 .43942 m .52502 .43679 L .52257 .43875 L F
.52395 .43942 m .52637 .43846 L .52502 .43679 L F
.626 .228 .269 r
.38537 .49497 m .38822 .49718 L .38979 .49469 L F
.585 .181 .245 r
.38979 .49469 m .38822 .49718 L .3922 .49669 L F
.606 .165 .176 r
.38979 .49469 m .3922 .49669 L .39249 .49513 L F
.803 .757 .81 r
.38023 .53345 m .37607 .53514 L .37919 .53299 L F
.495 0 0 r
.37919 .53299 m .38313 .5324 L .38023 .53345 L F
.496 .424 .706 r
.47402 .43943 m .4759 .43538 L .47322 .43626 L F
.47402 .43943 m .47672 .43906 L .4759 .43538 L F
.641 .412 .555 r
.47946 .44311 m .47402 .43943 L .47672 .43906 L F
.47946 .44311 m .47366 .44434 L .47402 .43943 L F
.407 0 0 r
.47222 .44073 m .47672 .43906 L .47402 .43943 L F
.499 .447 .73 r
.47402 .43943 m .47672 .43906 L .47322 .43626 L F
.218 0 .153 r
.50816 .41593 m .50799 .41788 L .50482 .41882 L F
.746 .981 .913 r
.51416 .44339 m .51307 .44276 L .50962 .44521 L F
.726 .959 .944 r
.51416 .44339 m .51639 .44193 L .51507 .44103 L F
.755 .983 .909 r
.51507 .44103 m .51307 .44276 L .51416 .44339 L F
.866 .868 .838 r
.4608 .4859 m .45875 .48747 L .46261 .48726 L F
.87 .862 .83 r
.46261 .48726 m .45875 .48747 L .45958 .49061 L F
.845 .871 .862 r
.4608 .4859 m .46261 .48726 L .46529 .48412 L F
.796 .584 .614 r
.5654 .38737 m .56965 .38802 L .56989 .38514 L F
.625 .321 .435 r
.41902 .48714 m .42293 .48691 L .42301 .48445 L F
.659 .463 .608 r
.42293 .48691 m .42575 .48396 L .42301 .48445 L F
.808 .59 .606 r
.54888 .40813 m .55306 .409 L .55039 .41103 L F
0 .241 .716 r
.55013 .40129 m .55382 .40411 L .55212 .40109 L F
.55013 .40129 m .55268 .40281 L .55382 .40411 L F
.999 .816 .475 r
.55382 .40411 m .55268 .40281 L .55338 .40693 L F
0 0 .406 r
.55268 .40281 m .55359 .40556 L .55338 .40693 L F
.945 .921 .555 r
.55314 .4085 m .55321 .40804 L .55338 .40693 L F
.55321 .40804 m .55382 .40411 L .55338 .40693 L F
0 0 .406 r
.55359 .40556 m .55362 .40567 L .55338 .40693 L F
.772 .856 .412 r
.55338 .40693 m .55362 .40567 L .55354 .40584 L F
.55338 .40693 m .55354 .40584 L .55243 .40818 L F
.945 .921 .555 r
.55306 .409 m .55314 .4085 L .55338 .40693 L F
.822 1 .812 r
.55039 .41103 m .55306 .409 L .55338 .40693 L F
0 0 .102 r
.59417 .38962 m .59263 .39198 L .59217 .39445 L F
.443 .679 .964 r
.33511 .5307 m .33698 .53304 L .33757 .53042 L F
0 .085 .629 r
.33698 .53304 m .33905 .53523 L .33757 .53042 L F
.749 .861 .931 r
.39654 .56321 m .39722 .56541 L .40052 .56329 L F
.832 .984 .702 r
.52471 .39484 m .52366 .39632 L .52198 .39837 L F
.712 .656 .793 r
.35923 .53896 m .35624 .5417 L .35587 .53882 L F
.88 .824 .789 r
.55383 .42103 m .5553 .42249 L .55507 .41875 L F
.838 .828 .838 r
.55246 .42509 m .5553 .42249 L .55383 .42103 L F
.379 0 0 r
.54033 .40221 m .5445 .40239 L .54287 .4032 L F
.398 .41 .756 r
.5445 .40239 m .54772 .40412 L .54724 .4014 L F
0 0 0 r
.54287 .4032 m .5445 .40239 L .54724 .4014 L F
.445 .514 .835 r
.35515 .55411 m .35647 .55745 L .35798 .55502 L F
.49 .573 .866 r
.35647 .55745 m .35949 .55709 L .35798 .55502 L F
.621 .625 .833 r
.36909 .53592 m .36626 .53857 L .36547 .53487 L F
.652 .625 .81 r
.37065 .53962 m .36626 .53857 L .36909 .53592 L F
.381 .126 .398 r
.49468 .41965 m .49738 .41882 L .49775 .41621 L F
.224 0 .282 r
.49738 .41882 m .49998 .41541 L .49775 .41621 L F
.724 .379 .394 r
.38846 .52632 m .38886 .52867 L .38393 .528 L F
0 .031 .54 r
.59129 .38477 m .59303 .38754 L .5927 .38279 L F
.288 .413 .815 r
.34147 .54068 m .34567 .54536 L .34386 .54094 L F
.011 .538 .854 r
.34274 .5445 m .34494 .54492 L .34567 .54536 L F
.516 .555 .834 r
.34386 .54094 m .34567 .54536 L .34645 .54014 L F
.619 .919 .977 r
.34567 .54536 m .3478 .54388 L .34645 .54014 L F
.34567 .54536 m .34494 .54492 L .3478 .54388 L F
.701 .781 .914 r
.34494 .54492 m .34858 .54788 L .3478 .54388 L F
.445 0 0 r
.34671 .54639 m .34917 .54836 L .34858 .54788 L F
.545 .671 .92 r
.3478 .54388 m .34858 .54788 L .35093 .54344 L F
.061 0 0 r
.34858 .54788 m .34917 .54836 L .35181 .54766 L F
.784 .595 .645 r
.54233 .41214 m .54657 .41276 L .54626 .40842 L F
.557 .543 .794 r
.54626 .40842 m .54888 .40813 L .54772 .40412 L F
0 0 .308 r
.54626 .40842 m .54657 .41276 L .54732 .40969 L F
.432 0 0 r
.54427 .41316 m .54657 .41276 L .54233 .41214 L F
.836 .999 .825 r
.54732 .40969 m .54657 .41276 L .54427 .41316 L F
0 0 0 r
.54638 .41128 m .54732 .40969 L .54504 .41228 L F
.54638 .41128 m .54504 .41228 L .54427 .41316 L F
.515 .38 .635 r
.54888 .40813 m .54879 .41183 L .54657 .41276 L F
.346 .047 .308 r
.54657 .41276 m .54879 .41183 L .54908 .41393 L F
0 .187 .705 r
.54638 .41128 m .54862 .41305 L .54764 .41034 L F
.947 .806 .356 r
.54639 .41103 m .54732 .40969 L .54638 .41128 L F
0 .187 .705 r
.54638 .41128 m .54764 .41034 L .54711 .40889 L F
0 0 .308 r
.54626 .40842 m .54732 .40969 L .54837 .40818 L F
.947 .806 .356 r
.54652 .40795 m .54732 .40969 L .54639 .41103 L F
0 0 .308 r
.54837 .40818 m .54732 .40969 L .54888 .40813 L F
.74 .989 .798 r
.48151 .43432 m .48044 .43649 L .48343 .43391 L F
.317 .482 .865 r
.48343 .43391 m .48438 .4309 L .48162 .43169 L F
.558 .14 .205 r
.37843 .49481 m .38091 .49662 L .38315 .49414 L F
.659 .263 .283 r
.38315 .49414 m .38547 .49648 L .38537 .49497 L F
.38315 .49414 m .38091 .49662 L .38547 .49648 L F
.189 .363 .807 r
.53024 .39081 m .5319 .39551 L .53298 .39306 L F
0 0 0 r
.5319 .39551 m .53322 .39528 L .53298 .39306 L F
.5319 .39551 m .53125 .39711 L .53322 .39528 L F
.789 .916 .53 r
.37821 .51167 m .37667 .51327 L .37402 .51159 L F
.37821 .51167 m .37601 .51538 L .37667 .51327 L F
.9 .658 .563 r
.40678 .55129 m .40972 .54965 L .40697 .54879 L F
.40678 .55129 m .40929 .55319 L .40972 .54965 L F
.531 .747 .974 r
.37037 .52226 m .3657 .5209 L .36878 .51923 L F
.532 .473 .736 r
.37108 .51712 m .37037 .52226 L .36878 .51923 L F
.37108 .51712 m .373 .52159 L .37037 .52226 L F
.517 .337 .576 r
.37308 .52445 m .37037 .52226 L .373 .52159 L F
.37308 .52445 m .37042 .52524 L .37037 .52226 L F
.5 .585 .872 r
.36789 .56044 m .36964 .55814 L .36692 .55871 L F
.36789 .56044 m .37036 .55999 L .36964 .55814 L F
.627 .621 .825 r
.61712 .37413 m .61871 .36944 L .61553 .37289 L F
.61712 .37413 m .61995 .37359 L .61871 .36944 L F
.286 .196 .576 r
.34514 .50576 m .34652 .5062 L .34573 .49971 L F
.488 .152 .323 r
.34573 .49971 m .3502 .50024 L .35029 .49812 L F
.336 .232 .586 r
.34573 .49971 m .34933 .50415 L .3502 .50024 L F
.34573 .49971 m .34652 .5062 L .34933 .50415 L F
.219 0 .187 r
.49468 .41965 m .49662 .42019 L .49738 .41882 L F
.49468 .41965 m .49403 .4216 L .49662 .42019 L F
.838 .828 .838 r
.55246 .42509 m .55383 .42103 L .55188 .42491 L F
0 0 0 r
.50185 .42214 m .50482 .41882 L .50423 .42151 L F
.548 .346 .559 r
.50799 .41788 m .50423 .42151 L .50482 .41882 L F
.862 .859 .836 r
.45875 .48747 m .45606 .49079 L .45958 .49061 L F
.87 .844 .816 r
.45606 .49079 m .4567 .4944 L .45958 .49061 L F
.473 .873 .703 r
.52366 .43082 m .52533 .43014 L .52228 .432 L F
.284 .763 .659 r
.52811 .42896 m .52533 .43014 L .52366 .43082 L F
.564 .266 .42 r
.43163 .48017 m .43565 .47737 L .43175 .47782 L F
.606 .243 .327 r
.36006 .49453 m .36247 .4966 L .36569 .49312 L F
.597 .233 .321 r
.36569 .49312 m .36713 .49613 L .36696 .4943 L F
.36569 .49312 m .36247 .4966 L .36713 .49613 L F
.87 .844 .816 r
.45457 .49365 m .4567 .4944 L .45606 .49079 L F
.949 .904 .744 r
.45457 .49365 m .45416 .49787 L .4567 .4944 L F
.45457 .49365 m .45268 .4968 L .45416 .49787 L F
.646 .469 .629 r
.52198 .39837 m .52522 .39904 L .52471 .39484 L F
.543 .738 .966 r
.35949 .55709 m .36397 .55918 L .36194 .55586 L F
.585 .69 .915 r
.36397 .55918 m .36463 .55514 L .36194 .55586 L F
.36397 .55918 m .36692 .55871 L .36463 .55514 L F
.728 .599 .712 r
.55283 .39175 m .55023 .3953 L .54829 .39159 L F
.772 .532 .572 r
.55716 .41505 m .55739 .41235 L .55039 .41103 L F
.709 .276 .219 r
.55494 .4136 m .55739 .41235 L .55039 .41103 L F
.662 .472 .618 r
.37546 .52365 m .373 .52159 L .37743 .52237 L F
.737 .351 .32 r
.37743 .52237 m .37994 .52478 L .37546 .52365 L F
.741 .347 .305 r
.38246 .52491 m .37743 .52237 L .38016 .52182 L F
.38246 .52491 m .37994 .52478 L .37743 .52237 L F
.626 .91 .622 r
.49247 .42339 m .49098 .42473 L .49403 .4216 L F
.569 .907 .976 r
.51543 .43345 m .51094 .4335 L .51305 .43312 L F
0 0 0 r
.51645 .43335 m .51543 .43345 L .51305 .43312 L F
.51645 .43335 m .51825 .43283 L .51543 .43345 L F
.762 .96 .934 r
.54233 .41214 m .54153 .41347 L .53911 .41369 L F
.751 .706 .809 r
.37367 .53662 m .37065 .53962 L .36909 .53592 L F
.464 .152 .351 r
.51373 .41181 m .51031 .4146 L .51082 .41228 L F
0 .088 .624 r
.33335 .52869 m .33464 .53001 L .33319 .52478 L F
0 .044 .609 r
.33335 .52869 m .33511 .5307 L .33464 .53001 L F
.589 .396 .587 r
.41621 .49062 m .41902 .48714 L .41642 .48787 L F
.196 .385 .824 r
.59336 .38107 m .59468 .37913 L .59167 .37752 L F
.207 .045 .429 r
.5927 .38279 m .59468 .37913 L .59336 .38107 L F
0 0 0 r
.33373 .51874 m .33514 .51705 L .33618 .515 L F
0 0 .057 r
.33373 .51874 m .33455 .51962 L .33514 .51705 L F
.33373 .51874 m .33261 .52193 L .33455 .51962 L F
.532 .595 .862 r
.33823 .53934 m .34062 .53905 L .33905 .53523 L F
.487 .314 .571 r
.49195 .4471 m .49312 .44931 L .49038 .45008 L F
.49038 .45008 m .49312 .44931 L .49195 .4471 L F
.641 .54 .724 r
.49596 .4438 m .49195 .4471 L .49236 .44171 L F
.924 .951 .79 r
.3657 .5209 m .36311 .5251 L .36467 .52322 L F
.718 .829 .934 r
.62438 .37812 m .62878 .37835 L .62736 .37687 L F
.885 .905 .837 r
.62736 .37687 m .62878 .37835 L .6312 .37517 L F
.596 .351 .516 r
.39585 .54251 m .39948 .53951 L .39638 .5396 L F
.39585 .54251 m .39909 .54221 L .39948 .53951 L F
.379 .234 .556 r
.39909 .54221 m .40117 .53829 L .39948 .53951 L F
.693 .397 .469 r
.3922 .49669 m .39653 .49409 L .39249 .49513 L F
.716 .594 .719 r
.54829 .39159 m .55023 .3953 L .54614 .39441 L F
.582 .853 .995 r
.55023 .3953 m .54915 .39697 L .54987 .39807 L F
.55023 .3953 m .55142 .39312 L .54915 .39697 L F
.55023 .3953 m .55416 .39429 L .55142 .39312 L F
.469 .346 .63 r
.52132 .4324 m .52371 .43325 L .52369 .43211 L F
.52132 .4324 m .52366 .43082 L .52228 .432 L F
.52132 .4324 m .52369 .43211 L .52366 .43082 L F
.41 .859 .886 r
.52228 .432 m .51884 .43271 L .52132 .4324 L F
.51884 .43271 m .51825 .43283 L .52132 .4324 L F
.731 .953 .948 r
.48643 .46397 m .48525 .46303 L .48104 .46564 L F
.898 .968 .821 r
.48769 .45959 m .48643 .46397 L .48957 .46134 L F
.48769 .45959 m .48525 .46303 L .48643 .46397 L F
.25 0 .024 r
.50185 .42214 m .50104 .42418 L .49828 .42486 L F
.588 .296 .44 r
.50423 .42151 m .50104 .42418 L .50185 .42214 L F
.384 .835 .733 r
.53347 .43513 m .53499 .43415 L .53265 .43556 L F
.53347 .43513 m .53693 .43355 L .53499 .43415 L F
.983 .77 .364 r
.5604 .37686 m .5605 .38049 L .56136 .38035 L F
.707 .513 .624 r
.36999 .50847 m .36722 .51141 L .36728 .50842 L F
.36999 .50847 m .37223 .51288 L .36722 .51141 L F
.683 .503 .637 r
.37402 .51159 m .37223 .51288 L .36999 .50847 L F
.739 .692 .806 r
.47602 .45249 m .4742 .45417 L .47156 .44887 L F
.444 .182 .421 r
.54267 .37827 m .54524 .38018 L .5454 .37725 L F
.207 .224 .657 r
.54356 .38129 m .54524 .38018 L .54267 .37827 L F
0 0 0 r
.54786 .42188 m .54519 .42235 L .54319 .42291 L F
.641 .21 .208 r
.38547 .49648 m .38822 .49718 L .38537 .49497 L F
.505 .271 .494 r
.4525 .45689 m .45517 .45897 L .45518 .45613 L F
.4525 .45689 m .45234 .45958 L .45517 .45897 L F
.892 .893 .823 r
.49705 .45217 m .50019 .44942 L .50034 .4495 L F
0 0 .095 r
.53447 .3844 m .53485 .38499 L .53591 .38091 L F
.654 .355 .452 r
.53252 .38631 m .53485 .38499 L .53447 .3844 L F
0 0 .181 r
.48855 .42563 m .48936 .42645 L .49098 .42473 L F
.517 .809 .999 r
.5594 .37568 m .55685 .3779 L .55508 .37495 L F
.5594 .37568 m .5604 .37686 L .55685 .3779 L F
.858 .856 .838 r
.46454 .48043 m .46821 .48033 L .46638 .47871 L F
.867 .839 .816 r
.46529 .48412 m .46821 .48033 L .46454 .48043 L F
.788 .855 .9 r
.46638 .47871 m .46821 .48033 L .47101 .47744 L F
.419 .515 .85 r
.62191 .36334 m .62025 .35934 L .61997 .36196 L F
.62191 .36334 m .62141 .35932 L .62025 .35934 L F
.62191 .36334 m .62403 .36489 L .62141 .35932 L F
.495 0 0 r
.37919 .53299 m .38127 .53403 L .38313 .5324 L F
.956 .939 .726 r
.38313 .5324 m .38393 .528 L .38525 .53115 L F
.38313 .5324 m .38203 .53125 L .38393 .528 L F
.997 .859 .539 r
.38313 .5324 m .38127 .53403 L .38203 .53125 L F
.828 .673 .69 r
.39434 .53813 m .39585 .54251 L .39638 .5396 L F
.486 0 0 r
.37413 .49606 m .37657 .49635 L .37843 .49481 L F
.59 .09 .035 r
.37843 .49481 m .37657 .49635 L .38091 .49662 L F
.696 .803 .339 r
.33618 .515 m .33514 .51705 L .33688 .51312 L F
.834 .625 .62 r
.36728 .50842 m .36305 .51051 L .36293 .50823 L F
.36728 .50842 m .36722 .51141 L .36305 .51051 L F
.495 .559 .85 r
.34582 .51758 m .34749 .5214 L .34509 .52198 L F
.845 .871 .862 r
.4608 .4859 m .46529 .48412 L .46338 .48269 L F
.867 .839 .816 r
.46529 .48412 m .46454 .48043 L .46338 .48269 L F
.803 .728 .781 r
.54829 .39159 m .54614 .39441 L .54602 .39195 L F
.294 .78 .707 r
.53499 .43415 m .53693 .43355 L .53947 .43255 L F
0 .053 .591 r
.34423 .51259 m .34582 .51758 L .34392 .51505 L F
.847 .992 .737 r
.42527 .52895 m .42283 .53084 L .42395 .53097 L F
.42527 .52895 m .42443 .5287 L .42283 .53084 L F
.764 .992 .881 r
.42597 .52678 m .42527 .52895 L .42867 .5262 L F
.795 .996 .78 r
.42597 .52678 m .42443 .5287 L .42527 .52895 L F
.277 .78 .839 r
.55077 .3754 m .55508 .37495 L .55275 .37419 L F
0 0 .41 r
.46753 .44346 m .46864 .44492 L .47047 .44274 L F
0 0 .237 r
.60186 .37637 m .60086 .38097 L .60009 .3778 L F
.60186 .37637 m .60189 .37916 L .60127 .37908 L F
.872 .672 .144 r
.6014 .37717 m .60189 .37916 L .60186 .37637 L F
.886 .569 .444 r
.60286 .37959 m .60473 .37831 L .60189 .37916 L F
.60266 .37925 m .60189 .37916 L .6014 .37717 L F
.60286 .37959 m .60189 .37916 L .60266 .37925 L F
0 0 .237 r
.60127 .37908 m .60189 .37916 L .60086 .38097 L F
.837 .966 .887 r
.42155 .53426 m .42042 .53368 L .42026 .53637 L F
.845 .971 .878 r
.42026 .53637 m .42042 .53368 L .41739 .53672 L F
.885 .905 .837 r
.62736 .37687 m .6312 .37517 L .62996 .37324 L F
.818 .998 .841 r
.49403 .4216 m .49098 .42473 L .49389 .42249 L F
0 0 0 r
.49098 .42473 m .49308 .4241 L .49389 .42249 L F
.49389 .42249 m .49662 .42019 L .49403 .4216 L F
.49389 .42249 m .49541 .42269 L .49662 .42019 L F
.49389 .42249 m .49308 .4241 L .49541 .42269 L F
.574 .527 .764 r
.62657 .35968 m .62964 .36264 L .6301 .36068 L F
.653 .217 .199 r
.36696 .4943 m .36951 .49645 L .37144 .49447 L F
.527 .066 .104 r
.37144 .49447 m .36951 .49645 L .37413 .49606 L F
.612 .174 .184 r
.52198 .39837 m .52113 .4002 L .52607 .39955 L F
.623 .219 .255 r
.52607 .39955 m .52522 .39904 L .52198 .39837 L F
.62 .817 .976 r
.53778 .42506 m .53531 .42632 L .53348 .42445 L F
.258 .494 .892 r
.49829 .42779 m .4958 .42585 L .49828 .42486 L F
.401 .557 .895 r
.38953 .56484 m .39053 .56724 L .39119 .56466 L F
.57 .733 .952 r
.39053 .56724 m .39374 .56646 L .39119 .56466 L F
.657 .441 .58 r
.50586 .4084 m .51074 .4094 L .50913 .40511 L F
.492 .354 .621 r
.50913 .40511 m .51392 .40534 L .51188 .40448 L F
.50913 .40511 m .51074 .4094 L .51392 .40534 L F
.667 .398 .505 r
.53773 .3869 m .54035 .38758 L .54078 .3849 L F
.472 .303 .57 r
.54035 .38758 m .5429 .38365 L .54078 .3849 L F
.72 .88 .955 r
.51639 .44193 m .51838 .4383 L .51507 .44103 L F
.51639 .44193 m .51984 .43992 L .51838 .4383 L F
.183 .221 .667 r
.54724 .41579 m .54444 .41552 L .54644 .41314 L F
.891 .646 .561 r
.61251 .38125 m .61037 .38012 L .61401 .37905 L F
.61251 .38125 m .61068 .38232 L .61037 .38012 L F
0 0 0 r
.61251 .38125 m .6102 .38239 L .61068 .38232 L F
.61251 .38125 m .61298 .38144 L .6102 .38239 L F
.327 .355 .738 r
.6157 .37853 m .61251 .38125 L .61401 .37905 L F
0 0 0 r
.6157 .37853 m .61298 .38144 L .61251 .38125 L F
.462 0 0 r
.39789 .53516 m .39262 .53713 L .39434 .53813 L F
.39789 .53516 m .39584 .53709 L .39262 .53713 L F
.547 0 0 r
.38404 .55273 m .37988 .55199 L .37888 .55077 L F
.385 0 .153 r
.5401 .40367 m .54033 .40221 L .54287 .4032 L F
.838 .545 .494 r
.36044 .52901 m .35623 .52529 L .35866 .52445 L F
.36044 .52901 m .35645 .52847 L .35623 .52529 L F
.474 .203 .422 r
.36044 .52901 m .35754 .53221 L .35645 .52847 L F
.36044 .52901 m .3604 .53155 L .35754 .53221 L F
.77 .681 .764 r
.36311 .5251 m .36044 .52901 L .35866 .52445 L F
.631 .489 .67 r
.36311 .5251 m .36436 .52905 L .36044 .52901 L F
.744 .552 .635 r
.36436 .52905 m .3604 .53155 L .36044 .52901 L F
.595 .238 .334 r
.3502 .50024 m .35271 .50034 L .35029 .49812 L F
.545 .25 .418 r
.35029 .49812 m .35271 .50034 L .35327 .49782 L F
.592 .733 .942 r
.3774 .56251 m .37962 .56498 L .38188 .56391 L F
0 0 0 r
.49283 .42951 m .49139 .43116 L .48904 .43212 L F
.386 0 .016 r
.49589 .42938 m .49139 .43116 L .49283 .42951 L F
.227 .128 .527 r
.59281 .36364 m .59522 .36503 L .59602 .36174 L F
.036 0 0 r
.59602 .36174 m .59921 .36072 L .59611 .36028 L F
.59602 .36174 m .59784 .36195 L .59921 .36072 L F
.071 0 .078 r
.59602 .36174 m .59747 .36383 L .59784 .36195 L F
.59602 .36174 m .59522 .36503 L .59747 .36383 L F
.03 .602 .717 r
.60865 .37246 m .61282 .37236 L .61156 .36943 L F
.498 .456 .741 r
.61282 .37236 m .61564 .37059 L .61156 .36943 L F
.61282 .37236 m .61553 .37289 L .61564 .37059 L F
.71 .72 .857 r
.5938 .39891 m .59512 .39356 L .59217 .39445 L F
.5938 .39891 m .59575 .39721 L .59512 .39356 L F
.564 .266 .42 r
.43163 .48017 m .43569 .47968 L .43565 .47737 L F
.548 .238 .394 r
.43569 .47968 m .43857 .47706 L .43565 .47737 L F
0 .413 .815 r
.41503 .54141 m .4171 .54233 L .41509 .54092 L F
.62 .924 .669 r
.41503 .54141 m .41509 .54092 L .41323 .54274 L F
.739 .692 .806 r
.47602 .45249 m .47156 .44887 L .47454 .44885 L F
.708 .732 .87 r
.48007 .44903 m .47602 .45249 L .47454 .44885 L F
.796 .6 .636 r
.37388 .51885 m .373 .52159 L .37108 .51712 L F
.355 .417 .788 r
.49145 .43991 m .49433 .44134 L .49236 .44171 L F
.641 .54 .724 r
.49596 .4438 m .49236 .44171 L .49433 .44134 L F
.826 .907 .895 r
.50525 .43917 m .50697 .43481 L .50831 .43575 L F
.50525 .43917 m .50332 .43821 L .50697 .43481 L F
.491 .197 .395 r
.51714 .409 m .51665 .41131 L .51373 .41181 L F
.46 .17 .385 r
.5197 .41061 m .51714 .409 L .5196 .40824 L F
.5197 .41061 m .51665 .41131 L .51714 .409 L F
.693 .397 .469 r
.3922 .49669 m .39526 .49718 L .39653 .49409 L F
.634 .333 .443 r
.39653 .49409 m .39923 .49673 L .39944 .49431 L F
.39653 .49409 m .39526 .49718 L .39923 .49673 L F
.346 .047 .308 r
.54657 .41276 m .54908 .41393 L .54644 .41314 L F
.562 .315 .499 r
.44951 .46009 m .4523 .46239 L .45234 .45958 L F
.44951 .46009 m .44945 .46296 L .4523 .46239 L F
.642 .138 .034 r
.49711 .43267 m .49827 .43247 L .50019 .43216 L F
.49711 .43267 m .49983 .43474 L .49583 .43443 L F
.519 .261 .463 r
.50019 .43216 m .49983 .43474 L .49711 .43267 L F
.642 .138 .034 r
.49711 .43267 m .49583 .43443 L .49827 .43247 L F
.976 .729 .497 r
.34908 .50833 m .34723 .50988 L .34726 .50785 L F
.474 .866 .97 r
.35159 .5075 m .34726 .50785 L .34908 .50833 L F
0 0 .002 r
.34012 .50716 m .34009 .50866 L .34054 .50815 L F
.34012 .50716 m .33849 .51106 L .34009 .50866 L F
.761 .643 .731 r
.5654 .38737 m .56859 .38924 L .56965 .38802 L F
.857 .801 .794 r
.50763 .42959 m .50286 .43139 L .50685 .43179 L F
.615 .899 .987 r
.50961 .4283 m .50763 .42959 L .50896 .42712 L F
.088 0 .18 r
.50685 .43179 m .50763 .42959 L .50961 .4283 L F
0 0 0 r
.50685 .43179 m .50763 .42959 L .50896 .42712 L F
.258 .408 .823 r
.37572 .5626 m .37602 .55882 L .37339 .5598 L F
.37572 .5626 m .3774 .56251 L .37602 .55882 L F
.37 .786 .978 r
.37023 .51509 m .37447 .5146 L .37601 .51538 L F
.686 .924 .971 r
.37601 .51538 m .37447 .5146 L .37667 .51327 L F
.971 .93 .64 r
.43106 .52203 m .42895 .52348 L .4299 .52446 L F
.81 1 .832 r
.43146 .51982 m .43106 .52203 L .43404 .51903 L F
.839 .98 .687 r
.43146 .51982 m .42895 .52348 L .43106 .52203 L F
.8 .874 .902 r
.6249 .36888 m .62996 .36706 L .62829 .36601 L F
.747 .738 .844 r
.3744 .53129 m .37607 .53514 L .37153 .53441 L F
.764 .715 .807 r
.37607 .53514 m .37367 .53662 L .37153 .53441 L F
.686 .708 .865 r
.37919 .53299 m .37607 .53514 L .3744 .53129 L F
.751 .706 .809 r
.37367 .53662 m .36909 .53592 L .37153 .53441 L F
.739 .865 .939 r
.48769 .45959 m .48957 .46134 L .49181 .45967 L F
.762 .755 .847 r
.49043 .43768 m .49145 .43991 L .4874 .43925 L F
.534 .636 .897 r
.4939 .43898 m .49145 .43991 L .49043 .43768 L F
.458 .379 .68 r
.4939 .43898 m .49433 .44134 L .49145 .43991 L F
.574 .527 .764 r
.62657 .35968 m .62839 .36573 L .62964 .36264 L F
0 0 0 r
.62839 .36573 m .62829 .36601 L .62964 .36264 L F
.774 .753 .834 r
.39863 .56156 m .40052 .56329 L .39887 .55968 L F
.749 .861 .931 r
.39654 .56321 m .40052 .56329 L .39863 .56156 L F
.777 .754 .832 r
.39887 .55968 m .40052 .56329 L .40381 .56049 L F
.507 .249 .458 r
.4607 .44869 m .46334 .44839 L .46069 .44635 L F
.627 .072 0 r
.46069 .44635 m .46334 .44839 L .46242 .44714 L F
.98 .893 .662 r
.52963 .41593 m .52863 .41887 L .52729 .4168 L F
.634 .958 .793 r
.53083 .41431 m .52963 .41593 L .52729 .4168 L F
.122 .077 .529 r
.59159 .37056 m .59295 .36983 L .59221 .36702 L F
.301 .196 .565 r
.59159 .37056 m .59394 .37252 L .59295 .36983 L F
.59159 .37056 m .5912 .37489 L .59394 .37252 L F
.785 .705 .776 r
.62141 .35932 m .62403 .36489 L .62657 .35968 L F
.828 .673 .69 r
.39434 .53813 m .39194 .54193 L .39585 .54251 L F
.728 .271 .165 r
.39194 .54193 m .39406 .5442 L .39585 .54251 L F
.988 .737 .459 r
.39585 .54251 m .39406 .5442 L .39597 .54552 L F
.495 .267 .497 r
.39597 .54552 m .39909 .54221 L .39585 .54251 L F
.505 .399 .667 r
.5429 .38365 m .54524 .38018 L .54356 .38129 L F
.595 .38 .559 r
.38001 .52759 m .37994 .52478 L .38246 .52491 L F
.735 .444 .488 r
.38246 .52491 m .38393 .528 L .38001 .52759 L F
.787 .418 .358 r
.53045 .40478 m .52595 .40222 L .52691 .40393 L F
.77 .705 .79 r
.61871 .36944 m .61995 .37359 L .62295 .37014 L F
.591 .251 .362 r
.406 .49348 m .40904 .49341 L .40954 .49124 L F
.555 .247 .401 r
.41205 .49321 m .40954 .49124 L .40904 .49341 L F
.41205 .49321 m .41345 .4904 L .40954 .49124 L F
.725 .947 .953 r
.50831 .43575 m .50964 .43288 L .51094 .4335 L F
.50831 .43575 m .50697 .43481 L .50964 .43288 L F
.64 .122 0 r
.53045 .40478 m .52915 .4061 L .52712 .40435 L F
.646 .129 0 r
.53045 .40478 m .53342 .40699 L .52915 .4061 L F
.581 .252 .377 r
.53329 .40489 m .53342 .40699 L .53045 .40478 L F
.982 .698 .391 r
.35623 .52529 m .35455 .52408 L .35457 .52134 L F
.61 .6 .816 r
.35866 .52445 m .35623 .52529 L .35457 .52134 L F
.896 .594 .466 r
.35623 .52529 m .35645 .52847 L .35393 .52626 L F
.959 .868 .705 r
.35623 .52529 m .35393 .52626 L .35455 .52408 L F
.606 .69 .902 r
.35645 .52847 m .3538 .52993 L .35213 .52722 L F
.708 .372 .406 r
.36293 .50823 m .35831 .5103 L .35864 .50737 L F
.36293 .50823 m .36305 .51051 L .35831 .5103 L F
.318 0 .215 r
.46242 .44714 m .46334 .44839 L .46599 .44757 L F
.507 .361 .618 r
.44682 .46657 m .44945 .46296 L .44659 .46372 L F
.885 .756 .714 r
.54567 .40008 m .54987 .39807 L .54915 .39697 L F
.54567 .40008 m .54724 .4014 L .54987 .39807 L F
.696 .463 .566 r
.54724 .4014 m .55013 .40129 L .54987 .39807 L F
.723 .678 .806 r
.3657 .5209 m .3616 .51834 L .36541 .51767 L F
.695 .82 .942 r
.36653 .51786 m .3657 .5209 L .36541 .51767 L F
.36653 .51786 m .36878 .51923 L .3657 .5209 L F
.864 .982 .848 r
.42895 .52348 m .42867 .5262 L .4299 .52446 L F
.42895 .52348 m .42597 .52678 L .42867 .5262 L F
.43 .196 .456 r
.45755 .45247 m .4607 .44869 L .45775 .44958 L F
.163 0 .048 r
.6172 .3604 m .62025 .35934 L .62083 .35772 L F
.443 .57 .887 r
.35128 .55133 m .35181 .54766 L .34917 .54836 L F
.35128 .55133 m .35356 .55126 L .35181 .54766 L F
.636 .744 .926 r
.38188 .56391 m .38638 .56532 L .38466 .56382 L F
.539 .78 .987 r
.38638 .56532 m .38709 .56325 L .38466 .56382 L F
.38638 .56532 m .38953 .56484 L .38709 .56325 L F
.717 .806 .92 r
.48406 .44146 m .4842 .44257 L .48016 .4418 L F
.852 .656 .637 r
.48291 .4437 m .48016 .4418 L .4842 .44257 L F
.801 .862 .894 r
.4874 .43925 m .4842 .44257 L .48406 .44146 L F
.985 .726 .452 r
.60862 .35629 m .60856 .35938 L .61012 .36011 L F
.458 0 0 r
.61113 .36099 m .61012 .36011 L .60856 .35938 L F
.61113 .36099 m .61311 .36243 L .61012 .36011 L F
.438 .218 .481 r
.47918 .43398 m .48162 .43169 L .47958 .43317 L F
.951 .812 .67 r
.40598 .53163 m .4046 .5351 L .40608 .5329 L F
.533 .186 .325 r
.35601 .49711 m .3601 .49698 L .36006 .49453 L F
.606 .243 .327 r
.36006 .49453 m .3601 .49698 L .36247 .4966 L F
.998 .798 .509 r
.55039 .41103 m .55079 .41549 L .54908 .41393 L F
.996 .762 .444 r
.54908 .41393 m .55079 .41549 L .54963 .4186 L F
.353 .085 .362 r
.43857 .47706 m .44116 .47619 L .44151 .4738 L F
.563 .335 .528 r
.44116 .47619 m .44417 .47302 L .44151 .4738 L F
.792 .495 .485 r
.61311 .36243 m .61713 .36323 L .6172 .3604 L F
.428 .329 .64 r
.6172 .3604 m .61997 .36196 L .62025 .35934 L F
.521 .27 .474 r
.6172 .3604 m .61713 .36323 L .61997 .36196 L F
.747 .52 .586 r
.36747 .51354 m .36305 .51051 L .36722 .51141 L F
.814 .787 .827 r
.37223 .51288 m .36747 .51354 L .36722 .51141 L F
.707 .556 .681 r
.37308 .52445 m .37015 .52798 L .37042 .52524 L F
.277 .341 .749 r
.35021 .52345 m .34876 .52636 L .34749 .5214 L F
.44 .541 .863 r
.35021 .52345 m .35213 .52722 L .34876 .52636 L F
.672 .432 .549 r
.39923 .49673 m .40234 .49378 L .39944 .49431 L F
.674 .516 .662 r
.42575 .48396 m .42899 .48381 L .42875 .48046 L F
.561 .384 .599 r
.42899 .48381 m .43163 .48017 L .42875 .48046 L F
.475 .495 .799 r
.35515 .55411 m .35731 .55286 L .35356 .55126 L F
.35515 .55411 m .35798 .55502 L .35731 .55286 L F
.088 0 0 r
.52446 .40626 m .5197 .41061 L .5196 .40824 L F
.52446 .40626 m .52212 .40966 L .5197 .41061 L F
.656 .635 .817 r
.52626 .40454 m .52446 .40626 L .52257 .4052 L F
.005 0 0 r
.52456 .40694 m .52212 .40966 L .52446 .40626 L F
.52479 .4084 m .52384 .40885 L .52456 .40694 L F
.5229 .40929 m .52212 .40966 L .52244 .4093 L F
.92 .706 .597 r
.5192 .41012 m .52357 .40928 L .5214 .40949 L F
.533 .37 .607 r
.524 .40877 m .52123 .41152 L .52212 .40966 L F
.52479 .4084 m .5237 .40936 L .524 .40877 L F
.5237 .40936 m .52123 .41152 L .524 .40877 L F
.296 .048 .359 r
.52212 .40966 m .51934 .41322 L .5197 .41061 L F
0 0 .065 r
.52123 .41152 m .51934 .41322 L .52212 .40966 L F
.533 .37 .607 r
.52479 .4084 m .52489 .41133 L .52123 .41152 L F
.547 .117 .176 r
.52459 .4133 m .52123 .41152 L .52489 .41133 L F
.92 .706 .597 r
.5192 .41012 m .52228 .41206 L .52368 .40926 L F
.52228 .41206 m .52253 .41222 L .52349 .40976 L F
.52228 .41206 m .52349 .40976 L .52368 .40926 L F
.52357 .40928 m .52368 .40926 L .52347 .40928 L F
.52357 .40928 m .52347 .40928 L .5214 .40949 L F
.005 0 0 r
.52384 .40885 m .5229 .40929 L .52456 .40694 L F
.5229 .40929 m .52244 .4093 L .52456 .40694 L F
.025 0 .443 r
.52336 .41009 m .52355 .4096 L .52368 .40926 L F
.52355 .4096 m .52515 .40557 L .52371 .40918 L F
.52355 .4096 m .52371 .40918 L .52368 .40926 L F
.52253 .41222 m .52293 .41122 L .52336 .41009 L F
.52293 .41122 m .52515 .40557 L .52336 .41009 L F
.005 0 0 r
.52479 .4084 m .52456 .40694 L .52626 .40454 L F
.52456 .40694 m .52446 .40626 L .52504 .4057 L F
.52456 .40694 m .52504 .4057 L .52626 .40454 L F
.88 .962 .847 r
.43376 .51604 m .43404 .51903 L .43692 .51577 L F
.919 .97 .78 r
.43376 .51604 m .43146 .51982 L .43404 .51903 L F
.777 .754 .832 r
.39887 .55968 m .40381 .56049 L .40142 .55844 L F
.778 .799 .869 r
.40142 .55844 m .40381 .56049 L .40533 .55852 L F
0 0 0 r
.47366 .44434 m .47313 .44478 L .47126 .44556 L F
.614 .183 .199 r
.47047 .44274 m .46864 .44492 L .47313 .44478 L F
.528 .328 .553 r
.44417 .47302 m .44703 .46955 L .44424 .47021 L F
.566 .359 .559 r
.37156 .51376 m .37023 .51509 L .37402 .51159 L F
.499 .266 .492 r
.37156 .51376 m .37164 .51378 L .37023 .51509 L F
.447 .189 .429 r
.37402 .51159 m .37166 .51375 L .37156 .51376 L F
.809 .777 .823 r
.37402 .51159 m .3716 .51383 L .37379 .51176 L F
.3716 .51383 m .37023 .51509 L .37164 .51378 L F
.3716 .51383 m .37164 .51378 L .37379 .51176 L F
.481 .319 .584 r
.37667 .51327 m .37447 .5146 L .37164 .51378 L F
.37166 .51375 m .37164 .51378 L .37156 .51376 L F
.37667 .51327 m .37164 .51378 L .37166 .51375 L F
.447 .189 .429 r
.37402 .51159 m .37667 .51327 L .37166 .51375 L F
.809 .777 .823 r
.37379 .51176 m .37206 .51338 L .37223 .51288 L F
.37206 .51338 m .37023 .51509 L .37046 .51484 L F
.37206 .51338 m .37046 .51484 L .37223 .51288 L F
.499 .266 .492 r
.37164 .51378 m .37447 .5146 L .37023 .51509 L F
.761 .643 .731 r
.5654 .38737 m .56724 .39214 L .56859 .38924 L F
.005 .581 .734 r
.52751 .39906 m .52522 .39904 L .52607 .39955 L F
.814 .787 .827 r
.37223 .51288 m .37023 .51509 L .36747 .51354 L F
.959 .641 .377 r
.37023 .51509 m .36856 .51494 L .36747 .51354 L F
.37023 .51509 m .37108 .51712 L .36856 .51494 L F
.875 .794 .767 r
.37108 .51712 m .36653 .51786 L .36856 .51494 L F
.37108 .51712 m .36878 .51923 L .36653 .51786 L F
.421 .108 .327 r
.51188 .40448 m .51497 .40388 L .51506 .40163 L F
.587 .239 .347 r
.51506 .40163 m .51497 .40388 L .51778 .40359 L F
.533 .272 .465 r
.51506 .40163 m .51778 .40359 L .5182 .40112 L F
.206 0 0 r
.61871 .36944 m .62133 .36993 L .62295 .37014 L F
.77 .705 .79 r
.61871 .36944 m .62295 .37014 L .62133 .36993 L F
.505 .353 .608 r
.62673 .36642 m .62295 .37014 L .6249 .36888 L F
.83 .979 .882 r
.43732 .51309 m .43692 .51577 L .43858 .51375 L F
.43732 .51309 m .43376 .51604 L .43692 .51577 L F
0 .1 .638 r
.54772 .40412 m .54888 .40813 L .54961 .40607 L F
.764 .92 .548 r
.54888 .40813 m .54732 .40969 L .54961 .40607 L F
.808 .59 .606 r
.54888 .40813 m .55039 .41103 L .54879 .41183 L F
.9 .573 .085 r
.52729 .4168 m .52863 .41887 L .52909 .42136 L F
.548 .238 .394 r
.43569 .47968 m .43825 .47953 L .43857 .47706 L F
.591 .381 .566 r
.43825 .47953 m .44116 .47619 L .43857 .47706 L F
.665 .706 .878 r
.49873 .44253 m .49596 .4438 L .49433 .44134 L F
.76 .948 .94 r
.50728 .44675 m .50629 .44555 L .50248 .44803 L F
.713 .817 .93 r
.50728 .44675 m .50787 .44372 L .50629 .44555 L F
.50728 .44675 m .50962 .44521 L .50787 .44372 L F
.552 .671 .917 r
.36692 .55871 m .3673 .55449 L .36463 .55514 L F
.36692 .55871 m .36964 .55814 L .3673 .55449 L F
.772 .532 .572 r
.55716 .41505 m .55039 .41103 L .55494 .4136 L F
.87 .767 .746 r
.55507 .41875 m .55716 .41505 L .55494 .4136 L F
.131 0 0 r
.60865 .37246 m .60536 .37388 L .6059 .37326 L F
.659 .463 .608 r
.42293 .48691 m .42593 .4869 L .42575 .48396 L F
.545 .295 .488 r
.42593 .4869 m .42899 .48381 L .42575 .48396 L F
.464 .152 .351 r
.51373 .41181 m .51362 .41425 L .51031 .4146 L F
.496 .177 .355 r
.51634 .41361 m .51362 .41425 L .51373 .41181 L F
.485 .184 .379 r
.51665 .41131 m .51634 .41361 L .51373 .41181 L F
.442 .531 .853 r
.52637 .43846 m .52787 .43459 L .52502 .43679 L F
.52637 .43846 m .52749 .43675 L .52787 .43459 L F
.656 .635 .817 r
.52626 .40454 m .52257 .4052 L .52712 .40435 L F
.263 .227 .629 r
.5912 .37489 m .5939 .37479 L .59394 .37252 L F
.5912 .37489 m .59167 .37752 L .5939 .37479 L F
.507 .432 .706 r
.4759 .43538 m .47949 .438 L .47918 .43398 L F
.4759 .43538 m .47672 .43906 L .47949 .438 L F
.633 .237 .275 r
.36713 .49613 m .36951 .49645 L .36696 .4943 L F
.903 .812 .747 r
.49202 .45464 m .4941 .45613 L .49299 .45201 L F
.91 .866 .784 r
.49009 .45816 m .4941 .45613 L .49202 .45464 L F
.49009 .45816 m .49181 .45967 L .4941 .45613 L F
.835 .78 .8 r
.49299 .45201 m .4941 .45613 L .49705 .45217 L F
.631 .257 .316 r
.48904 .43212 m .48591 .433 L .48634 .43305 L F
.69 .981 .836 r
.55556 .39096 m .55142 .39312 L .55416 .39429 L F
.825 .793 .822 r
.59575 .39721 m .5988 .39399 L .59512 .39356 L F
.589 .396 .587 r
.41621 .49062 m .4192 .49053 L .41902 .48714 L F
.597 .402 .587 r
.41902 .48714 m .42167 .48988 L .42293 .48691 L F
.41902 .48714 m .4192 .49053 L .42167 .48988 L F
.477 .278 .53 r
.54524 .38018 m .54806 .37629 L .5454 .37725 L F
.837 .773 .79 r
.49299 .45201 m .49705 .45217 L .49572 .44855 L F
.795 .843 .888 r
.49705 .45217 m .49853 .44756 L .49572 .44855 L F
.49705 .45217 m .50034 .4495 L .49853 .44756 L F
.449 .418 .732 r
.33319 .52478 m .33455 .51962 L .33261 .52193 L F
.818 .578 .576 r
.53604 .40391 m .53342 .40699 L .53329 .40489 L F
.53604 .40391 m .53751 .40783 L .53342 .40699 L F
.252 .27 .686 r
.53981 .40642 m .53604 .40391 L .5401 .40367 L F
.53981 .40642 m .53751 .40783 L .53604 .40391 L F
.823 .665 .687 r
.38991 .53797 m .39434 .53813 L .39262 .53713 L F
.38991 .53797 m .39194 .54193 L .39434 .53813 L F
.998 .798 .509 r
.55039 .41103 m .54908 .41393 L .54879 .41183 L F
.822 1 .812 r
.55039 .41103 m .55338 .40693 L .55338 .40983 L F
.644 .095 0 r
.55206 .41332 m .55494 .4136 L .55039 .41103 L F
.55206 .41332 m .55039 .41103 L .55338 .40983 L F
.813 .81 .847 r
.59512 .39356 m .5988 .39399 L .59787 .39062 L F
.799 .861 .895 r
.5988 .39399 m .60065 .38949 L .59787 .39062 L F
.5988 .39399 m .60242 .39126 L .60065 .38949 L F
.224 0 .282 r
.49738 .41882 m .49979 .41755 L .49998 .41541 L F
.335 .041 .309 r
.49998 .41541 m .50167 .41579 L .50419 .41413 L F
.49998 .41541 m .49979 .41755 L .50167 .41579 L F
.852 .656 .637 r
.48291 .4437 m .48208 .44633 L .48016 .4418 L F
.69 .981 .836 r
.55556 .39096 m .55465 .39076 L .55142 .39312 L F
.515 .822 .5 r
.55868 .38774 m .55712 .38932 L .55556 .39096 L F
.559 .935 .865 r
.55712 .38932 m .55465 .39076 L .55556 .39096 L F
.718 .529 .633 r
.35271 .50034 m .35601 .49711 L .35327 .49782 L F
.227 .128 .527 r
.59281 .36364 m .59221 .36702 L .59522 .36503 L F
.744 .552 .635 r
.36436 .52905 m .36446 .53268 L .3604 .53155 L F
.518 .343 .583 r
.36744 .52826 m .36446 .53268 L .36436 .52905 L F
0 0 .102 r
.59417 .38962 m .59217 .39445 L .59512 .39356 L F
.662 .472 .618 r
.37546 .52365 m .37308 .52445 L .373 .52159 L F
0 0 0 r
.51645 .43335 m .52132 .4324 L .51825 .43283 L F
.841 .77 .783 r
.60768 .36912 m .61156 .36943 L .61016 .36584 L F
.60768 .36912 m .60963 .37109 L .61156 .36943 L F
.03 .602 .717 r
.60865 .37246 m .61156 .36943 L .60963 .37109 L F
.833 .769 .791 r
.61016 .36584 m .61156 .36943 L .61389 .36602 L F
.606 .835 .452 r
.53773 .3869 m .53853 .38566 L .54035 .38758 L F
.541 .178 .3 r
.41205 .49321 m .41621 .49062 L .41345 .4904 L F
.439 .537 .86 r
.33905 .53523 m .34062 .53905 L .34232 .53654 L F
0 0 0 r
.49098 .42473 m .48936 .42645 L .49308 .4241 L F
.284 .763 .659 r
.52811 .42896 m .52366 .43082 L .52717 .43076 L F
0 0 0 r
.53051 .42763 m .52811 .42896 L .52717 .43076 L F
.561 .653 .897 r
.36547 .53487 m .3604 .53155 L .36446 .53268 L F
.495 .549 .841 r
.36744 .53394 m .36547 .53487 L .36446 .53268 L F
.621 .625 .833 r
.36909 .53592 m .36547 .53487 L .36744 .53394 L F
.888 .749 .702 r
.40678 .55129 m .40796 .55513 L .40929 .55319 L F
.726 .667 .792 r
.38886 .52867 m .38525 .53115 L .38393 .528 L F
.277 .17 .548 r
.59221 .36702 m .59554 .36748 L .59522 .36503 L F
.59221 .36702 m .59295 .36983 L .59554 .36748 L F
.407 0 0 r
.47222 .44073 m .47515 .4409 L .47672 .43906 L F
.59 .489 .707 r
.48016 .4418 m .47672 .43906 L .47949 .438 L F
.48016 .4418 m .47946 .44311 L .47672 .43906 L F
0 0 0 r
.47672 .43906 m .47742 .43993 L .47949 .438 L F
.47672 .43906 m .47515 .4409 L .47742 .43993 L F
.816 .804 .84 r
.61311 .36243 m .61016 .36584 L .61389 .36602 L F
.725 .749 .872 r
.61311 .36243 m .61389 .36602 L .61713 .36323 L F
.788 .855 .9 r
.46638 .47871 m .47101 .47744 L .46949 .47538 L F
.795 .715 .776 r
.46949 .47538 m .47101 .47744 L .47388 .47378 L F
.431 .277 .571 r
.45518 .45613 m .45755 .45247 L .45495 .45341 L F
.746 .713 .821 r
.47207 .47282 m .47388 .47378 L .47245 .46989 L F
.795 .715 .776 r
.46949 .47538 m .47388 .47378 L .47207 .47282 L F
.681 .678 .841 r
.47245 .46989 m .47388 .47378 L .47408 .47114 L F
.545 .295 .488 r
.42593 .4869 m .42878 .48643 L .42899 .48381 L F
.561 .384 .599 r
.42899 .48381 m .43185 .48325 L .43163 .48017 L F
.567 .314 .492 r
.42899 .48381 m .43151 .48578 L .43185 .48325 L F
.42899 .48381 m .42878 .48643 L .43151 .48578 L F
.266 .606 .954 r
.5541 .38411 m .5569 .38415 L .55557 .38149 L F
.5541 .38411 m .5569 .38415 L .55557 .38149 L F
.507 .361 .618 r
.44682 .46657 m .44953 .46587 L .44945 .46296 L F
.52 .364 .609 r
.44682 .46657 m .44976 .4688 L .44953 .46587 L F
.44682 .46657 m .44703 .46955 L .44976 .4688 L F
.495 .267 .497 r
.39597 .54552 m .39899 .54501 L .39909 .54221 L F
.379 .234 .556 r
.39909 .54221 m .40141 .54143 L .40117 .53829 L F
.028 0 .194 r
.39899 .54501 m .40141 .54143 L .39909 .54221 L F
.556 .381 .599 r
.43163 .48017 m .43452 .48242 L .43569 .47968 L F
.43163 .48017 m .43185 .48325 L .43452 .48242 L F
.644 .597 .786 r
.47313 .44478 m .47156 .44887 L .47126 .44556 L F
.675 .423 .532 r
.38404 .55273 m .37845 .55487 L .37988 .55199 L F
.38404 .55273 m .37944 .55582 L .37845 .55487 L F
.397 .484 .832 r
.38368 .5584 m .38336 .55804 L .38115 .55606 L F
.675 .423 .532 r
.38404 .55273 m .38115 .55606 L .38027 .55526 L F
.37944 .55582 m .38115 .55606 L .38404 .55273 L F
.397 .484 .832 r
.38336 .55804 m .38112 .55548 L .38115 .55606 L F
.675 .423 .532 r
.38027 .55526 m .38115 .55606 L .37944 .55582 L F
.733 .627 .741 r
.35738 .51775 m .35936 .5218 L .35457 .52134 L F
.61 .6 .816 r
.35866 .52445 m .35457 .52134 L .35936 .5218 L F
.704 .614 .754 r
.3616 .51834 m .35936 .5218 L .35738 .51775 L F
.619 .84 .984 r
.51838 .4383 m .51984 .43992 L .52257 .43875 L F
.111 0 0 r
.59921 .36072 m .60081 .36119 L .60203 .35952 L F
.59921 .36072 m .59784 .36195 L .60081 .36119 L F
.856 .497 0 r
.53283 .42211 m .53232 .42262 L .52909 .42136 L F
.53283 .42211 m .53348 .42445 L .53232 .42262 L F
.541 .178 .3 r
.41205 .49321 m .41568 .49285 L .41621 .49062 L F
.508 .148 .291 r
.41568 .49285 m .41874 .49256 L .41621 .49062 L F
.515 .145 .275 r
.41621 .49062 m .41874 .49256 L .4192 .49053 L F
.781 .682 .754 r
.54989 .4209 m .55383 .42103 L .55507 .41875 L F
.785 .615 .67 r
.55188 .42491 m .55383 .42103 L .54989 .4209 L F
.85 .508 0 r
.39406 .5442 m .39594 .54881 L .39597 .54552 L F
.44 .24 .511 r
.39597 .54552 m .39842 .5478 L .39899 .54501 L F
.39597 .54552 m .39594 .54881 L .39842 .5478 L F
.57 .628 .87 r
.36964 .55814 m .37036 .55999 L .37202 .55739 L F
.524 .566 .84 r
.37036 .55999 m .37339 .5598 L .37202 .55739 L F
.532 .731 .966 r
.49312 .44931 m .49572 .44855 L .49396 .4468 L F
.792 .985 .896 r
.49396 .4468 m .49213 .44849 L .49312 .44931 L F
.969 .718 .29 r
.49213 .44849 m .49299 .45201 L .49312 .44931 L F
.762 .96 .934 r
.54233 .41214 m .53911 .41369 L .54181 .41329 L F
.432 0 0 r
.54427 .41316 m .54233 .41214 L .54181 .41329 L F
.739 .865 .939 r
.48769 .45959 m .49181 .45967 L .49009 .45816 L F
.66 .769 .931 r
.623 .376 m .62438 .37812 L .62736 .37687 L F
.781 .682 .754 r
.54989 .4209 m .55507 .41875 L .55329 .41735 L F
.87 .767 .746 r
.55507 .41875 m .55494 .4136 L .55329 .41735 L F
.049 0 0 r
.49738 .41882 m .49662 .42019 L .49979 .41755 L F
.911 .931 .813 r
.42155 .53426 m .42395 .53097 L .42283 .53084 L F
.888 .749 .702 r
.40678 .55129 m .40432 .55563 L .40796 .55513 L F
.876 .849 .813 r
.40432 .55563 m .40533 .55852 L .40796 .55513 L F
.357 .36 .725 r
.59167 .37752 m .59468 .37913 L .5939 .37479 L F
.641 .391 .524 r
.42293 .48691 m .42581 .48961 L .42593 .4869 L F
.42293 .48691 m .42167 .48988 L .42581 .48961 L F
.99 .873 .615 r
.60656 .38304 m .60783 .38436 L .60855 .38141 L F
.811 .944 .912 r
.61037 .38012 m .60855 .38141 L .60896 .37897 L F
.654 .482 .638 r
.61037 .38012 m .61068 .38232 L .60855 .38141 L F
.632 .103 0 r
.61068 .38232 m .6102 .38239 L .60855 .38141 L F
.261 .424 .836 r
.60855 .38141 m .6102 .38239 L .60896 .37897 L F
.277 .78 .839 r
.551 .37538 m .55445 .37464 L .55508 .37495 L F
.55077 .3754 m .55272 .37499 L .551 .37538 L F
.55272 .37499 m .55445 .37464 L .551 .37538 L F
.241 .756 .837 r
.55508 .37495 m .55677 .37419 L .5594 .37568 L F
.724 .545 .647 r
.55435 .37714 m .55677 .37419 L .55545 .37439 L F
.55272 .37499 m .55545 .37439 L .55259 .37481 L F
.241 .756 .837 r
.55508 .37495 m .55442 .37462 L .55677 .37419 L F
.724 .545 .647 r
.55543 .37444 m .55545 .37439 L .55442 .37462 L F
.146 .69 .755 r
.55677 .37419 m .55423 .37452 L .55259 .37481 L F
.241 .756 .837 r
.55442 .37462 m .55423 .37452 L .55677 .37419 L F
.724 .545 .647 r
.55435 .37714 m .55543 .37444 L .55272 .37499 L F
.277 .78 .839 r
.55077 .3754 m .55423 .37452 L .55445 .37464 L F
.724 .545 .647 r
.55543 .37444 m .55442 .37462 L .55272 .37499 L F
.509 .172 .331 r
.55077 .3754 m .55435 .37714 L .55272 .37499 L F
.55077 .3754 m .55272 .37499 L .55259 .37481 L F
.556 .86 .997 r
.61037 .38012 m .61185 .37789 L .61401 .37905 L F
.61037 .38012 m .60896 .37897 L .61185 .37789 L F
.748 .593 .685 r
.37994 .52478 m .37736 .52799 L .37546 .52365 L F
.595 .38 .559 r
.38001 .52759 m .37736 .52799 L .37994 .52478 L F
.4 .184 .467 r
.52113 .4002 m .52358 .40279 L .52607 .39955 L F
.303 0 .126 r
.52358 .40279 m .52751 .39906 L .52607 .39955 L F
.756 .743 .84 r
.37153 .53441 m .36909 .53592 L .36744 .53394 L F
.558 .362 .571 r
.4523 .46239 m .45517 .45897 L .45234 .45958 L F
.738 .76 .87 r
.38439 .54495 m .38877 .54549 L .38734 .54177 L F
.083 .629 .837 r
.38439 .54495 m .38734 .54507 L .38786 .54538 L F
.915 .946 .806 r
.38534 .54049 m .38439 .54495 L .38734 .54177 L F
.216 0 0 r
.38439 .54495 m .38272 .54483 L .38014 .54432 L F
.38439 .54495 m .38272 .54483 L .38014 .54432 L F
.915 .946 .806 r
.38534 .54049 m .38272 .54483 L .38439 .54495 L F
.445 0 0 r
.38272 .54483 m .38734 .54507 L .38439 .54495 L F
.38272 .54483 m .38519 .54596 L .38734 .54507 L F
.747 .987 .774 r
.38734 .54507 m .38519 .54596 L .38656 .54461 L F
.116 .348 .813 r
.38734 .54177 m .38877 .54549 L .38968 .54365 L F
.747 .987 .774 r
.38734 .54507 m .38656 .54461 L .38836 .54285 L F
.083 .629 .837 r
.38786 .54538 m .38734 .54507 L .38877 .54549 L F
.638 .951 .944 r
.38877 .54549 m .38734 .54507 L .38968 .54365 L F
.483 .797 .999 r
.38968 .54365 m .39154 .54502 L .38877 .54549 L F
.431 .277 .571 r
.45518 .45613 m .4577 .45535 L .45755 .45247 L F
.527 .377 .621 r
.45517 .45897 m .4577 .45535 L .45518 .45613 L F
.672 .432 .549 r
.39923 .49673 m .40229 .497 L .40234 .49378 L F
.569 .311 .486 r
.40229 .497 m .406 .49348 L .40234 .49378 L F
.385 .423 .778 r
.49983 .43474 m .50019 .43216 L .50286 .43139 L F
.49983 .43474 m .49827 .43247 L .50019 .43216 L F
.473 .221 .451 r
.50286 .43139 m .49983 .43474 L .50019 .43216 L F
.859 .83 .818 r
.60242 .39126 m .6033 .38579 L .60065 .38949 L F
.60242 .39126 m .60515 .38776 L .6033 .38579 L F
.911 .931 .813 r
.42155 .53426 m .42283 .53084 L .42042 .53368 L F
.294 .78 .707 r
.53499 .43415 m .53947 .43255 L .53783 .43372 L F
.071 0 0 r
.53947 .43255 m .54081 .43321 L .53783 .43372 L F
.53947 .43255 m .54221 .43191 L .54081 .43321 L F
.658 .639 .82 r
.35798 .55502 m .35949 .55709 L .36194 .55586 L F
.774 .805 .878 r
.40432 .55563 m .40142 .55844 L .40533 .55852 L F
.118 .272 .747 r
.60768 .36912 m .60865 .37246 L .60963 .37109 L F
.554 .378 .598 r
.51392 .40534 m .51497 .40388 L .51188 .40448 L F
.79 .659 .718 r
.47522 .46632 m .4795 .467 L .47734 .46551 L F
.782 .687 .759 r
.47522 .46632 m .47681 .47045 L .4795 .467 L F
.728 .679 .802 r
.47734 .46551 m .4795 .467 L .48104 .46564 L F
.841 .578 .541 r
.5609 .38046 m .56391 .38321 L .564 .38039 L F
.791 .904 .92 r
.40785 .54366 m .4077 .54615 L .40948 .54499 L F
.937 .83 .713 r
.40588 .54544 m .4077 .54615 L .40785 .54366 L F
.40588 .54544 m .40697 .54879 L .4077 .54615 L F
.648 .802 .957 r
.50034 .4495 m .50248 .44803 L .49853 .44756 L F
.766 .584 .653 r
.47946 .44311 m .47313 .44478 L .47366 .44434 L F
.774 .63 .701 r
.37736 .52799 m .37919 .53299 L .3744 .53129 L F
.594 .535 .758 r
.38203 .53125 m .37919 .53299 L .37736 .52799 L F
.404 .185 .464 r
.38203 .53125 m .38127 .53403 L .37919 .53299 L F
.793 .692 .753 r
.47245 .46989 m .47681 .47045 L .47522 .46632 L F
.681 .678 .841 r
.47245 .46989 m .47408 .47114 L .47681 .47045 L F
.746 .749 .855 r
.40588 .54544 m .40257 .54832 L .40697 .54879 L F
.79 .544 .565 r
.40257 .54832 m .40678 .55129 L .40697 .54879 L F
.77 .717 .803 r
.36994 .53073 m .37153 .53441 L .36744 .53394 L F
.723 .696 .823 r
.3744 .53129 m .37153 .53441 L .36994 .53073 L F
.782 .753 .826 r
.39119 .56466 m .39374 .56646 L .39654 .56321 L F
.733 .624 .737 r
.53853 .38566 m .53893 .38917 L .54035 .38758 L F
.472 .303 .57 r
.54035 .38758 m .54321 .38673 L .5429 .38365 L F
.14 0 0 r
.54035 .38758 m .53893 .38917 L .54321 .38673 L F
.553 .796 .989 r
.5413 .38488 m .54035 .38758 L .53853 .38566 L F
.807 .786 .833 r
.62673 .36642 m .6249 .36888 L .62427 .36562 L F
.8 .781 .836 r
.62427 .36562 m .6249 .36888 L .62829 .36601 L F
.503 .208 .398 r
.52712 .40435 m .52915 .4061 L .52626 .40454 L F
.801 .518 .509 r
.52915 .4061 m .52479 .4084 L .52626 .40454 L F
.616 .525 .729 r
.51059 .41708 m .50677 .41471 L .51031 .4146 L F
.56 .36 .567 r
.51362 .41425 m .51059 .41708 L .51031 .4146 L F
.9 .975 .81 r
.44004 .50951 m .43858 .51375 L .44129 .5104 L F
.44004 .50951 m .43732 .51309 L .43858 .51375 L F
0 0 0 r
.54786 .42188 m .54445 .42264 L .54604 .42298 L F
.81 .343 .118 r
.54852 .42388 m .54786 .42188 L .54604 .42298 L F
.682 .736 .892 r
.54786 .42188 m .54989 .4209 L .54963 .4186 L F
.878 .64 .574 r
.54852 .42388 m .54989 .4209 L .54786 .42188 L F
.204 .329 .77 r
.54774 .42074 m .54873 .42357 L .54604 .42298 L F
.827 .856 .401 r
.54899 .42445 m .54842 .42725 L .5513 .42531 L F
.54899 .42445 m .5513 .42531 L .55188 .42491 L F
.475 0 0 r
.54604 .42298 m .54748 .42389 L .54899 .42445 L F
.036 0 0 r
.54842 .42725 m .5449 .42792 L .54544 .42734 L F
.54842 .42725 m .54801 .42754 L .5449 .42792 L F
.827 .856 .401 r
.54899 .42445 m .54801 .42754 L .54842 .42725 L F
.482 .111 .259 r
.5449 .42792 m .54801 .42754 L .54657 .4289 L F
.5449 .42792 m .54801 .42754 L .54657 .4289 L F
0 0 0 r
.54899 .42445 m .54657 .4289 L .54801 .42754 L F
.54777 .4267 m .54673 .42889 L .54657 .4289 L F
.54899 .42445 m .54815 .4261 L .54777 .4267 L F
.54815 .4261 m .54673 .42889 L .54777 .4267 L F
.475 0 0 r
.54604 .42298 m .54899 .42445 L .54852 .42388 L F
0 0 0 r
.54899 .42445 m .54923 .425 L .54673 .42889 L F
.204 .329 .77 r
.54873 .42357 m .5491 .42462 L .54604 .42298 L F
.475 0 0 r
.54748 .42389 m .54923 .425 L .54899 .42445 L F
.204 .329 .77 r
.5491 .42462 m .54923 .425 L .54896 .42483 L F
.5491 .42462 m .54896 .42483 L .54604 .42298 L F
0 0 0 r
.54445 .42264 m .54319 .42291 L .54604 .42298 L F
.755 .647 .742 r
.48406 .44146 m .47949 .438 L .4817 .43704 L F
.48406 .44146 m .48016 .4418 L .47949 .438 L F
.748 .748 .852 r
.48565 .4376 m .48406 .44146 L .4817 .43704 L F
.801 .862 .894 r
.4874 .43925 m .48406 .44146 L .48565 .4376 L F
.758 .479 .51 r
.35457 .52134 m .35021 .52345 L .35222 .52023 L F
.35457 .52134 m .35455 .52408 L .35021 .52345 L F
.847 .817 .82 r
.35738 .51775 m .35457 .52134 L .35222 .52023 L F
.592 .733 .942 r
.3774 .56251 m .38188 .56391 L .38021 .56183 L F
.524 .681 .937 r
.38188 .56391 m .38289 .56105 L .38021 .56183 L F
.38188 .56391 m .38466 .56382 L .38289 .56105 L F
.751 .897 .943 r
.40785 .54366 m .40948 .54499 L .41323 .54274 L F
.466 .502 .811 r
.34866 .5168 m .34749 .5214 L .34582 .51758 L F
.34866 .5168 m .35061 .52096 L .34749 .5214 L F
.445 .338 .639 r
.35061 .52096 m .35021 .52345 L .34749 .5214 L F
.921 .977 .735 r
.45606 .49079 m .45391 .49211 L .45457 .49365 L F
.916 .827 .743 r
.45097 .49575 m .45457 .49365 L .45391 .49211 L F
.45097 .49575 m .45268 .4968 L .45457 .49365 L F
.714 .603 .731 r
.54772 .40412 m .55013 .40129 L .54724 .4014 L F
.54772 .40412 m .55013 .40129 L .54724 .4014 L F
.705 .939 .634 r
.54826 .40271 m .55013 .40129 L .54772 .40412 L F
0 .08 .638 r
.54826 .40271 m .54772 .40412 L .54961 .40607 L F
.684 .7 .859 r
.35831 .51302 m .36225 .51798 L .35738 .51775 L F
.714 .57 .691 r
.36225 .51798 m .3616 .51834 L .35738 .51775 L F
.739 .715 .828 r
.36274 .51357 m .36225 .51798 L .35831 .51302 L F
.695 .527 .656 r
.36541 .51767 m .36225 .51798 L .36274 .51357 L F
.36541 .51767 m .3616 .51834 L .36225 .51798 L F
.754 .676 .775 r
.61564 .37059 m .61553 .37289 L .61871 .36944 L F
.125 0 .354 r
.54319 .42291 m .54186 .42189 L .54316 .41955 L F
.771 .655 .734 r
.48097 .44808 m .4776 .44547 L .48208 .44633 L F
.48097 .44808 m .47788 .44809 L .4776 .44547 L F
.771 .6 .666 r
.48097 .44808 m .48007 .44903 L .47788 .44809 L F
.769 .795 .874 r
.49043 .43768 m .4874 .43925 L .48565 .4376 L F
.811 .761 .807 r
.397 .55775 m .39863 .56156 L .39887 .55968 L F
.397 .55775 m .39414 .56135 L .39863 .56156 L F
.82 .732 .768 r
.39414 .56135 m .39654 .56321 L .39863 .56156 L F
.608 .39 .56 r
.42581 .48961 m .42878 .48643 L .42593 .4869 L F
.407 .496 .838 r
.38953 .56484 m .38979 .56079 L .38709 .56325 L F
.38953 .56484 m .39119 .56466 L .38979 .56079 L F
.43 .243 .525 r
.5009 .42694 m .49828 .42486 L .50104 .42418 L F
.5009 .42694 m .49829 .42779 L .49828 .42486 L F
.404 .544 .883 r
.36598 .51521 m .36541 .51767 L .36274 .51357 L F
.099 .219 .701 r
.36598 .51521 m .36653 .51786 L .36541 .51767 L F
.185 .633 .942 r
.60468 .35784 m .60856 .35938 L .60862 .35629 L F
.795 .93 .923 r
.60656 .38304 m .60783 .38436 L .6102 .38239 L F
.60656 .38304 m .60783 .38436 L .6102 .38239 L F
.697 .683 .833 r
.49688 .43847 m .49873 .44253 L .49433 .44134 L F
.358 .49 .855 r
.50127 .43979 m .49873 .44253 L .49688 .43847 L F
.769 .795 .874 r
.49043 .43768 m .48565 .4376 L .48832 .43398 L F
.644 .7 .887 r
.49297 .43595 m .49043 .43768 L .48832 .43398 L F
.534 .636 .897 r
.4939 .43898 m .49043 .43768 L .49297 .43595 L F
.754 .76 .857 r
.50962 .44521 m .50879 .44161 L .50787 .44372 L F
.50962 .44521 m .51307 .44276 L .50879 .44161 L F
.761 .342 .254 r
.53342 .40699 m .53751 .40783 L .53651 .41001 L F
0 0 0 r
.53651 .41001 m .53751 .40783 L .53981 .40642 L F
.847 .817 .82 r
.35738 .51775 m .35222 .52023 L .35524 .51621 L F
.684 .7 .859 r
.35831 .51302 m .35738 .51775 L .35524 .51621 L F
.528 .88 .984 r
.35159 .5075 m .3499 .50678 L .34726 .50785 L F
.588 .905 .982 r
.35247 .50564 m .3499 .50678 L .35159 .5075 L F
.71 .307 .282 r
.35159 .5075 m .35389 .50992 L .35194 .50928 L F
.588 .905 .982 r
.35247 .50564 m .3499 .50678 L .35159 .5075 L F
.552 .329 .53 r
.35429 .50706 m .35389 .50992 L .35159 .5075 L F
.518 .343 .583 r
.36744 .52826 m .36723 .53143 L .36446 .53268 L F
.495 .549 .841 r
.36744 .53394 m .36446 .53268 L .36723 .53143 L F
.829 .991 .863 r
.45944 .48511 m .45875 .48747 L .4608 .4859 L F
.945 .959 .719 r
.46133 .48168 m .4608 .4859 L .46338 .48269 L F
.46133 .48168 m .45944 .48511 L .4608 .4859 L F
.707 .556 .681 r
.37308 .52445 m .37525 .52864 L .37015 .52798 L F
.727 .564 .669 r
.37736 .52799 m .37308 .52445 L .37546 .52365 L F
.37736 .52799 m .37525 .52864 L .37308 .52445 L F
.388 .259 .581 r
.47949 .438 m .48151 .43432 L .47918 .43398 L F
.438 .218 .481 r
.47918 .43398 m .48151 .43432 L .48162 .43169 L F
.728 .679 .802 r
.47734 .46551 m .48104 .46564 L .48047 .4618 L F
.687 .634 .791 r
.48104 .46564 m .48525 .46303 L .48047 .4618 L F
.539 .304 .507 r
.51778 .40359 m .52113 .4002 L .5182 .40112 L F
.815 .836 .866 r
.47111 .46877 m .47207 .47282 L .47245 .46989 L F
.47111 .46877 m .46786 .47192 L .47207 .47282 L F
.846 .808 .813 r
.46786 .47192 m .46949 .47538 L .47207 .47282 L F
.858 .963 .87 r
.44308 .50639 m .44129 .5104 L .44402 .50691 L F
.44308 .50639 m .44004 .50951 L .44129 .5104 L F
.242 0 .019 r
.60865 .37246 m .60468 .37559 L .60536 .37388 L F
.60865 .37246 m .6075 .37481 L .60468 .37559 L F
.118 .272 .747 r
.60768 .36912 m .61028 .3713 L .60865 .37246 L F
0 0 0 r
.61028 .3713 m .6075 .37481 L .60865 .37246 L F
.522 0 0 r
.54826 .40271 m .55268 .40281 L .55013 .40129 L F
0 0 0 r
.53911 .41369 m .53475 .41414 L .53728 .41419 L F
.002 0 0 r
.53728 .41419 m .54181 .41329 L .53911 .41369 L F
.766 .584 .653 r
.47946 .44311 m .4776 .44547 L .47313 .44478 L F
.919 .976 .76 r
.48016 .4418 m .4776 .44547 L .47946 .44311 L F
.761 .621 .704 r
.48016 .4418 m .48208 .44633 L .4776 .44547 L F
.838 .975 .88 r
.53125 .39711 m .52751 .39906 L .53091 .39827 L F
.603 .437 .629 r
.44945 .46296 m .44953 .46587 L .4523 .46239 L F
.449 .418 .732 r
.33319 .52478 m .33549 .52605 L .33455 .51962 L F
.448 .417 .732 r
.33455 .51962 m .33549 .52605 L .33791 .52178 L F
.361 .306 .661 r
.33619 .52634 m .33791 .52178 L .33549 .52605 L F
0 .375 .831 r
.33319 .52478 m .33619 .52634 L .33549 .52605 L F
.37 .399 .76 r
.33319 .52478 m .33464 .53001 L .33619 .52634 L F
.478 .512 .814 r
.33511 .5307 m .33619 .52634 L .33464 .53001 L F
0 0 0 r
.54287 .4032 m .54724 .4014 L .54567 .40008 L F
.722 .549 .655 r
.37736 .52799 m .3744 .53129 L .37525 .52864 L F
.594 .535 .758 r
.38203 .53125 m .37736 .52799 L .38001 .52759 L F
.742 .648 .756 r
.50286 .43139 m .50403 .43397 L .50685 .43179 L F
.505 .399 .667 r
.5429 .38365 m .54562 .38285 L .54524 .38018 L F
0 0 .418 r
.5429 .38365 m .54409 .38408 L .54562 .38285 L F
.5429 .38365 m .54321 .38673 L .54409 .38408 L F
0 0 0 r
.50685 .43179 m .50896 .42712 L .50804 .42969 L F
.684 .91 .572 r
.50804 .42969 m .50685 .43179 L .50961 .4283 L F
.43 .196 .456 r
.45755 .45247 m .46037 .4517 L .4607 .44869 L F
.5 .254 .474 r
.4607 .44869 m .46302 .45103 L .46334 .44839 L F
.4607 .44869 m .46037 .4517 L .46302 .45103 L F
.497 .215 .416 r
.5197 .41061 m .51634 .41361 L .51665 .41131 L F
.631 .439 .604 r
.36994 .53073 m .36744 .52826 L .37015 .52798 L F
.36994 .53073 m .36723 .53143 L .36744 .52826 L F
.569 .311 .486 r
.40229 .497 m .40588 .49597 L .406 .49348 L F
.586 .3 .449 r
.40588 .49597 m .40904 .49341 L .406 .49348 L F
.718 .529 .633 r
.35271 .50034 m .35898 .5007 L .35601 .49711 L F
.417 .455 .793 r
.35601 .49711 m .35985 .49952 L .3601 .49698 L F
.35601 .49711 m .35898 .5007 L .35985 .49952 L F
.528 .328 .553 r
.44417 .47302 m .44696 .47242 L .44703 .46955 L F
.562 .386 .601 r
.44696 .47242 m .44976 .4688 L .44703 .46955 L F
.708 .732 .87 r
.48007 .44903 m .47454 .44885 L .47788 .44809 L F
.189 .363 .807 r
.53024 .39081 m .53298 .39306 L .53327 .39011 L F
.563 .335 .528 r
.44116 .47619 m .44406 .4758 L .44417 .47302 L F
.566 .362 .564 r
.44406 .4758 m .44696 .47242 L .44417 .47302 L F
.478 .512 .814 r
.33511 .5307 m .33757 .53042 L .33619 .52634 L F
.386 0 .016 r
.49589 .42938 m .4948 .43092 L .49139 .43116 L F
.024 0 0 r
.49712 .42975 m .49589 .42938 L .49829 .42779 L F
.49712 .42975 m .4948 .43092 L .49589 .42938 L F
.644 .597 .786 r
.47313 .44478 m .47454 .44885 L .47156 .44887 L F
.77 .552 .604 r
.35864 .50737 m .35389 .50992 L .35429 .50706 L F
.35864 .50737 m .35831 .5103 L .35389 .50992 L F
.97 .894 .528 r
.50896 .42712 m .50804 .42969 L .50961 .4283 L F
.934 .969 .716 r
.44518 .50252 m .44402 .50691 L .44673 .5034 L F
.44518 .50252 m .44308 .50639 L .44402 .50691 L F
.617 .406 .572 r
.43452 .48242 m .43825 .47953 L .43569 .47968 L F
.588 .296 .44 r
.50423 .42151 m .50408 .42413 L .50104 .42418 L F
.548 .346 .559 r
.50799 .41788 m .50699 .42091 L .50423 .42151 L F
.499 .224 .427 r
.50699 .42091 m .50408 .42413 L .50423 .42151 L F
.652 .247 .264 r
.38091 .49662 m .38343 .49893 L .38547 .49648 L F
.653 .249 .265 r
.38547 .49648 m .38771 .49895 L .38822 .49718 L F
.38547 .49648 m .38343 .49893 L .38771 .49895 L F
.548 .542 .8 r
.49583 .43443 m .4939 .43898 L .49297 .43595 L F
.49583 .43443 m .49688 .43847 L .4939 .43898 L F
.53 .429 .684 r
.49688 .43847 m .49433 .44134 L .4939 .43898 L F
.75 .752 .853 r
.34293 .50843 m .34054 .50815 L .34009 .50866 L F
.747 .572 .658 r
.38393 .528 m .38203 .53125 L .38001 .52759 L F
0 0 .361 r
.3918 .54155 m .39194 .54193 L .38991 .53797 L F
.748 .966 .684 r
.3918 .54155 m .38968 .54365 L .39194 .54193 L F
.3918 .54155 m .38968 .54365 L .39194 .54193 L F
.087 .222 .709 r
.39271 .54074 m .39406 .5442 L .39194 .54193 L F
.754 .584 .665 r
.37525 .52864 m .36994 .53073 L .37015 .52798 L F
.483 .317 .579 r
.45755 .45247 m .46039 .45467 L .46037 .4517 L F
.45755 .45247 m .4577 .45535 L .46039 .45467 L F
.545 .54 .8 r
.35731 .55286 m .35798 .55502 L .36028 .55227 L F
.629 .667 .868 r
.35798 .55502 m .36194 .55586 L .36028 .55227 L F
.631 .257 .316 r
.48904 .43212 m .48832 .43398 L .48591 .433 L F
.277 0 .169 r
.49123 .43281 m .48904 .43212 L .49139 .43116 L F
.49123 .43281 m .49011 .43326 L .48904 .43212 L F
.644 .7 .887 r
.49297 .43595 m .49047 .43489 L .49123 .43281 L F
.49047 .43489 m .48832 .43398 L .49011 .43326 L F
.49047 .43489 m .49011 .43326 L .49123 .43281 L F
.143 .336 .797 r
.48961 .43093 m .49056 .43335 L .49127 .43029 L F
.48829 .43144 m .49004 .43291 L .48961 .43093 L F
.49004 .43291 m .49056 .43335 L .48961 .43093 L F
.49056 .43335 m .49086 .4336 L .49089 .43342 L F
.49056 .43335 m .49089 .43342 L .49127 .43029 L F
.277 0 .169 r
.49011 .43326 m .48832 .43398 L .48871 .43298 L F
.49011 .43326 m .48871 .43298 L .48904 .43212 L F
.874 .816 .789 r
.46786 .47192 m .46539 .4756 L .46949 .47538 L F
.861 .849 .83 r
.46539 .4756 m .46638 .47871 L .46949 .47538 L F
.003 0 0 r
.54551 .41907 m .54316 .41955 L .54405 .41879 L F
.595 .645 .869 r
.35356 .55126 m .35463 .5468 L .35181 .54766 L F
.35356 .55126 m .35686 .55079 L .35463 .5468 L F
.598 .587 .812 r
.35356 .55126 m .35731 .55286 L .35686 .55079 L F
.998 .779 .444 r
.55901 .37824 m .5604 .37686 L .5594 .37568 L F
.55901 .37824 m .5605 .38049 L .5604 .37686 L F
.878 .64 .574 r
.54852 .42388 m .55188 .42491 L .54989 .4209 L F
.827 .856 .401 r
.54899 .42445 m .55188 .42491 L .54852 .42388 L F
.754 .584 .665 r
.37525 .52864 m .3744 .53129 L .36994 .53073 L F
.606 .69 .902 r
.35645 .52847 m .35213 .52722 L .35393 .52626 L F
.617 .433 .611 r
.43151 .48578 m .43452 .48242 L .43185 .48325 L F
.854 .84 .831 r
.45562 .48616 m .45606 .49079 L .45875 .48747 L F
.745 .65 .755 r
.44978 .48875 m .45487 .48955 L .45252 .48535 L F
.977 .898 .674 r
.45548 .48664 m .45439 .49181 L .45606 .49079 L F
.745 .65 .755 r
.45487 .48955 m .45488 .48955 L .45487 .48954 L F
.45487 .48955 m .45487 .48954 L .45252 .48535 L F
.977 .898 .674 r
.45562 .48616 m .45548 .48664 L .45606 .49079 L F
.45487 .48955 m .45391 .49211 L .45439 .49181 L F
.692 .609 .759 r
.45487 .48955 m .45391 .49211 L .45488 .48955 L F
.44978 .48875 m .45391 .49211 L .45487 .48955 L F
.752 .652 .751 r
.45252 .48535 m .45487 .48954 L .45562 .48616 L F
.45487 .48954 m .45488 .48955 L .45562 .48616 L F
.977 .898 .674 r
.45548 .48664 m .45391 .49211 L .45487 .48955 L F
.45487 .48954 m .45487 .48955 L .45487 .48955 L F
.45548 .48664 m .45487 .48955 L .45487 .48954 L F
.782 .753 .826 r
.39119 .56466 m .39654 .56321 L .39414 .56135 L F
.605 .226 .299 r
.4192 .49053 m .42175 .49236 L .42167 .48988 L F
.4192 .49053 m .41874 .49256 L .42175 .49236 L F
.79 .914 .924 r
.47389 .46515 m .47734 .46551 L .47657 .46167 L F
.47389 .46515 m .47522 .46632 L .47734 .46551 L F
.835 .854 .86 r
.47657 .46167 m .47734 .46551 L .48047 .4618 L F
.616 .956 .898 r
.50677 .41471 m .50572 .41445 L .50813 .41302 L F
.616 .525 .729 r
.51059 .41708 m .50799 .41788 L .50677 .41471 L F
.639 .713 .901 r
.3673 .55449 m .36964 .55814 L .37178 .55556 L F
.57 .628 .87 r
.36964 .55814 m .37202 .55739 L .37178 .55556 L F
.956 .72 .54 r
.37822 .5572 m .38035 .55888 L .37944 .55582 L F
.462 .235 .483 r
.3774 .56251 m .38035 .55888 L .37822 .5572 L F
.3774 .56251 m .38021 .56183 L .38035 .55888 L F
.468 .239 .484 r
.38035 .55888 m .38021 .56183 L .38289 .56105 L F
.562 .473 .712 r
.38035 .55888 m .38115 .55606 L .37944 .55582 L F
.38035 .55888 m .38368 .5584 L .38115 .55606 L F
.498 .234 .445 r
.38035 .55888 m .38289 .56105 L .38368 .5584 L F
.59 .633 .862 r
.36194 .55586 m .36281 .55165 L .36028 .55227 L F
.36194 .55586 m .36463 .55514 L .36281 .55165 L F
.003 0 0 r
.54551 .41907 m .54405 .41879 L .54724 .41579 L F
.326 0 .186 r
.60536 .37388 m .60468 .37559 L .60186 .37637 L F
.834 .831 .844 r
.44673 .5034 m .44886 .49844 L .44518 .50252 L F
.44673 .5034 m .44993 .50027 L .44886 .49844 L F
.626 .243 .298 r
.38771 .49895 m .3922 .49669 L .38822 .49718 L F
.38771 .49895 m .39055 .49905 L .3922 .49669 L F
.716 .352 .358 r
.39055 .49905 m .39483 .49951 L .3922 .49669 L F
.687 .36 .417 r
.3922 .49669 m .39483 .49951 L .39526 .49718 L F
.73 .77 .885 r
.54963 .4186 m .54989 .4209 L .54945 .41686 L F
.756 .789 .88 r
.54945 .41686 m .54989 .4209 L .55329 .41735 L F
.329 .132 .454 r
.50987 .41996 m .50799 .41788 L .51059 .41708 L F
.50987 .41996 m .50699 .42091 L .50799 .41788 L F
.785 .983 .902 r
.41589 .53591 m .4169 .53575 L .41532 .53821 L F
.892 .945 .837 r
.41589 .53591 m .41449 .53481 L .4169 .53575 L F
.836 .881 .875 r
.41689 .53575 m .41624 .5355 L .41589 .53591 L F
0 0 0 r
.41532 .53821 m .4169 .53575 L .41689 .53577 L F
.41532 .53821 m .41689 .53577 L .41657 .53628 L F
.785 .983 .902 r
.41589 .53591 m .41532 .53821 L .41657 .53628 L F
.894 .936 .834 r
.41624 .5355 m .41449 .53481 L .41589 .53591 L F
.989 .81 .571 r
.4169 .53575 m .41538 .53516 L .41624 .5355 L F
.41538 .53516 m .41449 .53481 L .41689 .53576 L F
.894 .936 .834 r
.41903 .53219 m .41449 .53481 L .41624 .5355 L F
.989 .81 .571 r
.41689 .53575 m .41624 .5355 L .41689 .53576 L F
.4169 .53575 m .41624 .5355 L .41689 .53575 L F
.41689 .53576 m .41449 .53481 L .41323 .53756 L F
.836 .881 .875 r
.41657 .53628 m .41689 .53575 L .41589 .53591 L F
.41689 .53575 m .41903 .53219 L .41624 .5355 L F
.41739 .53672 m .41889 .53257 L .41657 .53628 L F
.41889 .53257 m .41903 .53219 L .41657 .53628 L F
0 0 0 r
.41657 .53628 m .41689 .53577 L .41671 .53607 L F
.41532 .53821 m .41416 .54027 L .41509 .54092 L F
.41532 .53821 m .41671 .53607 L .41416 .54027 L F
.785 .983 .902 r
.41657 .53628 m .41532 .53821 L .41739 .53672 L F
.687 .891 .523 r
.33849 .51106 m .33688 .51312 L .34009 .50866 L F
.927 .876 .766 r
.46279 .47905 m .46338 .48269 L .46454 .48043 L F
.46279 .47905 m .46133 .48168 L .46338 .48269 L F
.862 .871 .844 r
.46279 .47905 m .46638 .47871 L .46539 .4756 L F
.46279 .47905 m .46454 .48043 L .46638 .47871 L F
.859 .837 .822 r
.44886 .49844 m .44993 .50027 L .45268 .4968 L F
.068 0 .218 r
.54175 .40499 m .5401 .40367 L .54287 .4032 L F
.54175 .40499 m .53981 .40642 L .5401 .40367 L F
.754 .632 .725 r
.45252 .48535 m .45581 .48609 L .45522 .4848 L F
.68 .862 .968 r
.45678 .486 m .45875 .48747 L .45928 .48564 L F
.45562 .48616 m .45592 .48628 L .45678 .486 L F
.45592 .48628 m .45875 .48747 L .45678 .486 L F
.69 .65 .805 r
.45522 .4848 m .45694 .48594 L .45944 .48511 L F
.754 .632 .725 r
.45579 .48603 m .45694 .48594 L .45522 .4848 L F
.45581 .48609 m .45594 .48607 L .45579 .48603 L F
.45594 .48607 m .45694 .48594 L .45579 .48603 L F
.713 .693 .83 r
.45594 .48607 m .45785 .48655 L .45562 .48616 L F
.68 .862 .968 r
.45879 .48571 m .45928 .48564 L .45944 .48511 L F
.45562 .48616 m .45928 .48564 L .45594 .48607 L F
.69 .65 .805 r
.45694 .48594 m .45785 .48655 L .45944 .48511 L F
.754 .632 .725 r
.45581 .48609 m .45785 .48655 L .45694 .48594 L F
.713 .693 .83 r
.45944 .48511 m .45785 .48655 L .45594 .48607 L F
.734 .691 .809 r
.35455 .52408 m .35213 .52722 L .35021 .52345 L F
.522 .39 .642 r
.35393 .52626 m .35213 .52722 L .35455 .52408 L F
.783 .734 .807 r
.50879 .44161 m .51307 .44276 L .51111 .43841 L F
.687 .69 .847 r
.51111 .43841 m .51307 .44276 L .51507 .44103 L F
.735 .629 .741 r
.47788 .44809 m .47454 .44885 L .4776 .44547 L F
.859 .837 .822 r
.44886 .49844 m .45268 .4968 L .45097 .49575 L F
.408 .18 .453 r
.3502 .50024 m .35244 .50268 L .35271 .50034 L F
.3502 .50024 m .34933 .50415 L .35244 .50268 L F
.795 .93 .923 r
.60656 .38304 m .6102 .38239 L .60862 .38083 L F
.60656 .38304 m .6102 .38239 L .60862 .38083 L F
.583 .645 .877 r
.6102 .38239 m .61185 .37789 L .60896 .37897 L F
.6102 .38239 m .61298 .38144 L .61185 .37789 L F
.751 .897 .943 r
.40785 .54366 m .41323 .54274 L .41032 .54225 L F
.628 .952 .934 r
.41509 .54092 m .41032 .54225 L .41323 .54274 L F
.772 .543 .587 r
.36305 .51051 m .35831 .51302 L .35831 .5103 L F
.36305 .51051 m .36274 .51357 L .35831 .51302 L F
.747 .52 .586 r
.36747 .51354 m .36274 .51357 L .36305 .51051 L F
.638 .314 .407 r
.39526 .49718 m .39891 .49898 L .39923 .49673 L F
.39526 .49718 m .39483 .49951 L .39891 .49898 L F
.591 .381 .566 r
.43825 .47953 m .44115 .47913 L .44116 .47619 L F
.585 .383 .574 r
.44115 .47913 m .44406 .4758 L .44116 .47619 L F
.9 .573 .085 r
.52729 .4168 m .52909 .42136 L .52497 .42046 L F
.188 .679 .922 r
.52497 .42046 m .52909 .42136 L .52578 .42032 L F
.264 .396 .809 r
.52909 .42136 m .5307 .41871 L .52578 .42032 L F
.52909 .42136 m .53232 .42262 L .5307 .41871 L F
.654 .355 .452 r
.53252 .38631 m .53738 .38725 L .53485 .38499 L F
.462 .235 .483 r
.3774 .56251 m .37822 .5572 L .37602 .55882 L F
.586 .3 .449 r
.40588 .49597 m .40891 .49593 L .40904 .49341 L F
.682 .431 .535 r
.40891 .49593 m .41205 .49321 L .40904 .49341 L F
.613 .523 .729 r
.34723 .50988 m .34423 .51259 L .3444 .51036 L F
.34723 .50988 m .34914 .51354 L .34423 .51259 L F
.471 .289 .551 r
.34914 .51354 m .34582 .51758 L .34423 .51259 L F
0 0 0 r
.51645 .43335 m .51936 .43296 L .52132 .4324 L F
.435 0 0 r
.52132 .4324 m .51936 .43296 L .52371 .43325 L F
.806 .687 .733 r
.62265 .35597 m .62025 .35934 L .62141 .35932 L F
.365 .775 .981 r
.61401 .37905 m .6157 .37853 L .61185 .37789 L F
.79 .544 .565 r
.40257 .54832 m .40247 .55121 L .40678 .55129 L F
.846 .686 .683 r
.40251 .55312 m .40678 .55129 L .40247 .55121 L F
.40251 .55312 m .40432 .55563 L .40678 .55129 L F
.956 .72 .54 r
.37822 .5572 m .37944 .55582 L .37845 .55487 L F
.102 .563 .912 r
.37845 .55487 m .38115 .55606 L .37944 .55582 L F
.597 .298 .432 r
.39891 .49898 m .40178 .4991 L .39923 .49673 L F
.639 .285 .354 r
.39923 .49673 m .40178 .4991 L .40229 .497 L F
.563 .584 .833 r
.34232 .53654 m .34386 .54094 L .34596 .53774 L F
.516 .555 .834 r
.34386 .54094 m .34645 .54014 L .34596 .53774 L F
.724 .733 .858 r
.397 .55775 m .39887 .55968 L .40142 .55844 L F
.558 .362 .571 r
.4523 .46239 m .45526 .46188 L .45517 .45897 L F
.527 .377 .621 r
.45517 .45897 m .45792 .45834 L .4577 .45535 L F
.515 .329 .566 r
.45517 .45897 m .45805 .46111 L .45792 .45834 L F
.45517 .45897 m .45526 .46188 L .45805 .46111 L F
.619 .84 .984 r
.51838 .4383 m .52257 .43875 L .5207 .43658 L F
.692 .642 .796 r
.52257 .43875 m .52371 .43325 L .5207 .43658 L F
.52257 .43875 m .52502 .43679 L .52371 .43325 L F
.531 .341 .569 r
.4523 .46239 m .44953 .46587 L .45236 .46524 L F
.537 .387 .625 r
.44953 .46587 m .45253 .46815 L .45236 .46524 L F
.44953 .46587 m .44976 .4688 L .45253 .46815 L F
.932 .788 .678 r
.55329 .41735 m .55494 .4136 L .55206 .41332 L F
.751 .655 .755 r
.4776 .44547 m .47454 .44885 L .47313 .44478 L F
.862 .764 .256 r
.56002 .3805 m .5605 .38049 L .55901 .37824 L F
.56002 .3805 m .56 .38234 L .5605 .38049 L F
.116 0 .09 r
.5609 .38046 m .56 .38234 L .5605 .38049 L F
.479 .504 .806 r
.35686 .55079 m .35731 .55286 L .35899 .55009 L F
.545 .54 .8 r
.35731 .55286 m .36028 .55227 L .35899 .55009 L F
.608 .39 .56 r
.42581 .48961 m .42864 .48934 L .42878 .48643 L F
.626 .422 .586 r
.42864 .48934 m .43151 .48578 L .42878 .48643 L F
.523 .335 .568 r
.4523 .46239 m .45512 .46459 L .45526 .46188 L F
.4523 .46239 m .45236 .46524 L .45512 .46459 L F
.598 .142 .141 r
.35271 .50034 m .35528 .50233 L .35898 .5007 L F
.295 0 .021 r
.35528 .50233 m .35985 .49952 L .35898 .5007 L F
.662 .888 .98 r
.52749 .43675 m .53265 .43556 L .53072 .43419 L F
.651 .884 .983 r
.53072 .43419 m .53265 .43556 L .53499 .43415 L F
.288 .751 .948 r
.51246 .43278 m .51094 .4335 L .50964 .43288 L F
.51246 .43278 m .51305 .43312 L .51094 .4335 L F
.193 .131 .553 r
.59394 .37252 m .59554 .36748 L .59295 .36983 L F
.533 .821 .998 r
.39406 .5442 m .39154 .54502 L .38968 .54365 L F
.38968 .54365 m .39154 .54502 L .39406 .5442 L F
.896 .735 .674 r
.40257 .54832 m .39899 .54501 L .39842 .5478 L F
.40009 .54603 m .39998 .54497 L .39899 .54501 L F
.40257 .54832 m .39998 .54497 L .40009 .54603 L F
.847 .749 .232 r
.39998 .54497 m .39978 .546 L .39991 .5442 L F
.028 0 .194 r
.39899 .54501 m .39998 .54497 L .40038 .54296 L F
.847 .749 .232 r
.39998 .54497 m .39991 .5442 L .40002 .54267 L F
.938 .68 .52 r
.39969 .54962 m .40257 .54832 L .39842 .5478 L F
.847 .749 .232 r
.39998 .54497 m .39961 .54836 L .39978 .546 L F
.028 0 .194 r
.40038 .54296 m .39998 .54497 L .40141 .54143 L F
.634 .35 .47 r
.42175 .49236 m .42581 .48961 L .42167 .48988 L F
.896 .735 .674 r
.40257 .54832 m .39961 .54836 L .39998 .54497 L F
.938 .68 .52 r
.39969 .54962 m .40247 .55121 L .40257 .54832 L F
.816 .908 .903 r
.40384 .54396 m .40257 .54832 L .40588 .54544 L F
.40384 .54396 m .39961 .54836 L .40257 .54832 L F
.554 .798 .989 r
.60186 .37637 m .60468 .37559 L .60294 .37411 L F
.872 .672 .144 r
.6014 .37717 m .60186 .37637 L .60294 .37411 L F
.668 .562 .726 r
.36994 .53073 m .36744 .53394 L .36723 .53143 L F
.102 .563 .912 r
.37845 .55487 m .38112 .55548 L .38115 .55606 L F
.709 .599 .731 r
.48047 .4618 m .48525 .46303 L .48312 .45842 L F
.696 .593 .737 r
.48312 .45842 m .48525 .46303 L .48769 .45959 L F
.9 .904 .819 r
.47111 .46877 m .47522 .46632 L .47389 .46515 L F
.47111 .46877 m .47245 .46989 L .47522 .46632 L F
.28 0 .285 r
.53327 .39011 m .53738 .38725 L .53252 .38631 L F
.53327 .39011 m .53576 .38916 L .53738 .38725 L F
.697 .621 .768 r
.53298 .39306 m .53576 .38916 L .53327 .39011 L F
.8 .808 .858 r
.50332 .43821 m .49983 .43747 L .50241 .43512 L F
.802 .38 .246 r
.50332 .43821 m .50127 .43979 L .49983 .43747 L F
.794 .804 .861 r
.50697 .43481 m .50332 .43821 L .50241 .43512 L F
.404 .544 .883 r
.36598 .51521 m .36274 .51357 L .36747 .51354 L F
.768 .448 .444 r
.36856 .51494 m .36598 .51521 L .36747 .51354 L F
.561 .674 .914 r
.38466 .56382 m .38547 .5603 L .38289 .56105 L F
.38466 .56382 m .38709 .56325 L .38547 .5603 L F
.114 0 0 r
.60203 .35952 m .60352 .35993 L .60468 .35784 L F
.60203 .35952 m .60081 .36119 L .60352 .35993 L F
.388 .259 .581 r
.47949 .438 m .4817 .43704 L .48151 .43432 L F
.371 0 .085 r
.47742 .43993 m .4817 .43704 L .47949 .438 L F
.388 .259 .581 r
.48151 .43432 m .4817 .43704 L .47949 .438 L F
.862 .552 .462 r
.56391 .38321 m .56 .38234 L .5609 .38046 L F
0 .17 .669 r
.5609 .38046 m .56306 .38205 L .56391 .38321 L F
.481 .822 .999 r
.56391 .38321 m .56306 .38205 L .56 .38234 L F
.857 .512 .4 r
.38767 .54012 m .3918 .54155 L .38991 .53797 L F
.38767 .54012 m .3918 .54155 L .38991 .53797 L F
.511 .395 .658 r
.39262 .53713 m .3918 .54155 L .38991 .53797 L F
.494 .516 .808 r
.59417 .38962 m .59545 .38485 L .59303 .38754 L F
.59417 .38962 m .59632 .38861 L .59545 .38485 L F
.767 .718 .807 r
.59512 .39356 m .59632 .38861 L .59417 .38962 L F
.891 .916 .834 r
.42283 .53084 m .42443 .5287 L .42022 .52915 L F
.919 .905 .793 r
.42042 .53368 m .42283 .53084 L .42022 .52915 L F
.584 .595 .83 r
.37202 .55739 m .37339 .5598 L .37602 .55882 L F
.617 .406 .572 r
.43452 .48242 m .43828 .48245 L .43825 .47953 L F
.633 .442 .606 r
.43828 .48245 m .44115 .47913 L .43825 .47953 L F
.563 .174 .263 r
.35271 .50034 m .35244 .50268 L .35528 .50233 L F
.85 .508 0 r
.39406 .5442 m .39533 .5482 L .39594 .54881 L F
.908 .98 .714 r
.39533 .5482 m .39404 .54971 L .39594 .54881 L F
.725 .415 .454 r
.39404 .54971 m .39842 .5478 L .39594 .54881 L F
.529 .515 .784 r
.33757 .53042 m .33905 .53523 L .34155 .53431 L F
.439 .537 .86 r
.33905 .53523 m .34232 .53654 L .34155 .53431 L F
.497 .166 .335 r
.4046 .49866 m .40229 .497 L .40178 .4991 L F
.4046 .49866 m .40588 .49597 L .40229 .497 L F
.662 .888 .98 r
.52749 .43675 m .53072 .43419 L .52787 .43459 L F
.852 .831 .826 r
.47938 .4582 m .47657 .46167 L .48047 .4618 L F
.849 .829 .828 r
.47938 .4582 m .48047 .4618 L .48312 .45842 L F
.657 .449 .591 r
.34723 .50988 m .3444 .51036 L .34726 .50785 L F
.668 .458 .592 r
.35194 .50928 m .34726 .50785 L .3499 .50678 L F
.35194 .50928 m .34723 .50988 L .34726 .50785 L F
.671 .275 .287 r
.37636 .49841 m .38091 .49662 L .37657 .49635 L F
.37636 .49841 m .37937 .49904 L .38091 .49662 L F
.649 .249 .273 r
.38091 .49662 m .37937 .49904 L .38343 .49893 L F
.539 .304 .507 r
.51778 .40359 m .52067 .40365 L .52113 .4002 L F
.4 .184 .467 r
.52113 .4002 m .52067 .40365 L .52358 .40279 L F
0 0 0 r
.54221 .43191 m .54357 .43214 L .54081 .43321 L F
.54221 .43191 m .54529 .43103 L .54357 .43214 L F
.5 .362 .624 r
.5449 .42792 m .54529 .43103 L .54221 .43191 L F
.734 .722 .839 r
.397 .55775 m .40142 .55844 L .39981 .55479 L F
.39981 .55479 m .40142 .55844 L .40432 .55563 L F
.361 .335 .694 r
.59303 .38754 m .59473 .38194 L .5927 .38279 L F
.59303 .38754 m .59545 .38485 L .59473 .38194 L F
.361 .071 .33 r
.49979 .41755 m .49662 .42019 L .49848 .41932 L F
.147 0 0 r
.49662 .42019 m .498 .42166 L .49848 .41932 L F
.49662 .42019 m .49541 .42269 L .498 .42166 L F
.544 .149 .243 r
.53752 .41582 m .53728 .41419 L .53475 .41414 L F
.833 .956 .893 r
.42022 .52915 m .42443 .5287 L .42597 .52678 L F
.477 .232 .463 r
.49983 .43474 m .49688 .43847 L .49583 .43443 L F
.49983 .43474 m .49983 .43747 L .49688 .43847 L F
.385 .423 .778 r
.49983 .43474 m .50127 .43044 L .49827 .43247 L F
.49983 .43474 m .50241 .43512 L .50127 .43044 L F
.434 .199 .457 r
.50241 .43512 m .49983 .43747 L .49983 .43474 L F
.639 .772 .944 r
.49396 .4468 m .49572 .44855 L .49853 .44756 L F
.632 .4 .547 r
.41188 .49606 m .41568 .49285 L .41205 .49321 L F
.682 .431 .535 r
.40891 .49593 m .41188 .49606 L .41205 .49321 L F
.776 .804 .876 r
.60895 .36365 m .60613 .36516 L .61016 .36584 L F
.824 .743 .775 r
.60613 .36516 m .60768 .36912 L .61016 .36584 L F
.824 .82 .846 r
.60895 .36365 m .61016 .36584 L .61311 .36243 L F
.638 .554 .743 r
.35831 .51302 m .35389 .50992 L .35831 .5103 L F
.554 .378 .598 r
.51392 .40534 m .51489 .40654 L .51497 .40388 L F
.352 0 .215 r
.51097 .40998 m .51489 .40654 L .51392 .40534 L F
.767 .718 .807 r
.59512 .39356 m .59787 .39062 L .59632 .38861 L F
.56 .36 .567 r
.51362 .41425 m .51341 .41645 L .51059 .41708 L F
.171 0 .073 r
.51341 .41645 m .50987 .41996 L .51059 .41708 L F
.666 .471 .612 r
.51497 .40388 m .51489 .40654 L .51778 .40359 L F
.499 .224 .427 r
.50699 .42091 m .50773 .42347 L .50408 .42413 L F
.058 0 .442 r
.50907 .42193 m .50699 .42091 L .50987 .41996 L F
.50907 .42193 m .50773 .42347 L .50699 .42091 L F
.617 .433 .611 r
.43151 .48578 m .43543 .48571 L .43452 .48242 L F
.61 .42 .6 r
.43543 .48571 m .43828 .48245 L .43452 .48242 L F
.62 .404 .567 r
.49848 .41932 m .50167 .41579 L .49979 .41755 L F
.49848 .41932 m .50313 .41929 L .50167 .41579 L F
0 0 0 r
.50167 .41579 m .50195 .41605 L .50572 .41445 L F
.392 .437 .788 r
.50313 .41929 m .50195 .41605 L .50167 .41579 L F
.185 .633 .942 r
.60468 .35784 m .60687 .35819 L .60856 .35938 L F
0 .194 .619 r
.60873 .35942 m .60856 .35938 L .60687 .35819 L F
.60873 .35942 m .61113 .36099 L .60856 .35938 L F
.958 .906 .536 r
.40141 .54143 m .39998 .54497 L .40002 .54267 L F
0 0 .127 r
.40141 .54143 m .40213 .5394 L .40224 .53656 L F
.758 .93 .577 r
.40141 .54143 m .40002 .54267 L .40213 .5394 L F
.586 .062 0 r
.48591 .433 m .48415 .43355 L .48691 .43004 L F
.713 .517 .623 r
.3601 .49698 m .35985 .49952 L .36247 .4966 L F
.632 .401 .55 r
.35985 .49952 m .36247 .49964 L .36247 .4966 L F
.368 .003 .207 r
.36247 .49964 m .36713 .49613 L .36247 .4966 L F
.763 .658 .746 r
.35194 .50928 m .35259 .51393 L .34914 .51354 L F
.767 .554 .61 r
.35259 .51393 m .34866 .5168 L .34914 .51354 L F
.35259 .51393 m .35298 .51739 L .34866 .5168 L F
.629 .549 .746 r
.35389 .50992 m .35259 .51393 L .35194 .50928 L F
.35389 .50992 m .35558 .51366 L .35259 .51393 L F
.642 .464 .627 r
.35524 .51621 m .35259 .51393 L .35558 .51366 L F
.35524 .51621 m .35298 .51739 L .35259 .51393 L F
.657 .798 .951 r
.49853 .44756 m .50248 .44803 L .50072 .44659 L F
.737 .726 .841 r
.50248 .44803 m .50374 .44367 L .50072 .44659 L F
.50248 .44803 m .50629 .44555 L .50374 .44367 L F
.592 .476 .69 r
.45792 .45834 m .46039 .45467 L .4577 .45535 L F
.858 .813 .805 r
.48124 .45677 m .47938 .4582 L .48312 .45842 L F
.849 .814 .816 r
.48124 .45677 m .48312 .45842 L .48597 .45479 L F
.703 .577 .711 r
.48312 .45842 m .48769 .45959 L .48597 .45479 L F
.477 .278 .53 r
.54524 .38018 m .54723 .38001 L .54806 .37629 L F
.427 .342 .658 r
.54524 .38018 m .54738 .3818 L .54723 .38001 L F
.54524 .38018 m .54562 .38285 L .54738 .3818 L F
.358 .102 .382 r
.46302 .45103 m .46599 .44757 L .46334 .44839 L F
.773 .698 .78 r
.48881 .45154 m .49299 .45201 L .49213 .44849 L F
.793 .661 .718 r
.48881 .45154 m .49202 .45464 L .49299 .45201 L F
.207 .045 .429 r
.5927 .38279 m .59473 .38194 L .59468 .37913 L F
.3 .117 .457 r
.54806 .37629 m .55025 .37799 L .55077 .3754 L F
.54806 .37629 m .54723 .38001 L .55025 .37799 L F
.793 .661 .718 r
.48881 .45154 m .49069 .45557 L .49202 .45464 L F
.77 .612 .684 r
.49069 .45557 m .49009 .45816 L .49202 .45464 L F
.566 .362 .564 r
.44406 .4758 m .44703 .47528 L .44696 .47242 L F
.562 .386 .601 r
.44696 .47242 m .44992 .47197 L .44976 .4688 L F
.542 .339 .554 r
.44703 .47528 m .44992 .47197 L .44696 .47242 L F
.556 .577 .831 r
.3478 .54388 m .3498 .54171 L .34645 .54014 L F
.3478 .54388 m .35093 .54344 L .3498 .54171 L F
0 0 0 r
.53051 .42763 m .52717 .43076 L .53044 .42912 L F
.148 .129 .578 r
.53044 .42912 m .53264 .43088 L .5317 .42865 L F
0 .099 .652 r
.53264 .43088 m .53161 .42918 L .5317 .42865 L F
0 0 .083 r
.53051 .42763 m .53044 .42912 L .5317 .42865 L F
0 .099 .652 r
.53161 .42918 m .53043 .42723 L .5317 .42865 L F
0 0 .083 r
.53192 .42725 m .5317 .42865 L .53317 .42691 L F
.53051 .42763 m .5317 .42865 L .53192 .42725 L F
.458 .076 .226 r
.3694 .49917 m .37413 .49606 L .36951 .49645 L F
.3694 .49917 m .37218 .49886 L .37413 .49606 L F
.613 .249 .327 r
.37413 .49606 m .37636 .49841 L .37657 .49635 L F
.37413 .49606 m .37218 .49886 L .37636 .49841 L F
.368 .003 .207 r
.36247 .49964 m .36505 .49908 L .36713 .49613 L F
.719 .404 .444 r
.36713 .49613 m .3694 .49917 L .36951 .49645 L F
.36713 .49613 m .36505 .49908 L .3694 .49917 L F
.58 .423 .634 r
.48769 .45959 m .49069 .45557 L .48597 .45479 L F
.48769 .45959 m .49009 .45816 L .49069 .45557 L F
.527 .116 .205 r
.53752 .41582 m .54181 .41329 L .53728 .41419 L F
.53752 .41582 m .54053 .41611 L .54181 .41329 L F
.857 .642 .61 r
.54053 .41611 m .54427 .41316 L .54181 .41329 L F
.845 .751 .76 r
.60467 .36724 m .60768 .36912 L .60613 .36516 L F
.9 .519 .298 r
.60467 .36724 m .60605 .37064 L .60768 .36912 L F
.671 .185 .089 r
.60605 .37064 m .61028 .3713 L .60768 .36912 L F
.471 .289 .551 r
.34914 .51354 m .34866 .5168 L .34582 .51758 L F
0 0 0 r
.54287 .4032 m .54567 .40008 L .54509 .40222 L F
.774 .77 .849 r
.54567 .40008 m .54608 .39631 L .54428 .39597 L F
.54567 .40008 m .54915 .39697 L .54648 .39639 L F
.54567 .40008 m .54648 .39639 L .54606 .39643 L F
.209 .341 .779 r
.54758 .39814 m .54567 .40008 L .54428 .39597 L F
.614 .182 .197 r
.54303 .39841 m .54758 .39814 L .54514 .39653 L F
.54393 .39665 m .54514 .39653 L .54428 .39597 L F
.54303 .39841 m .54514 .39653 L .54393 .39665 L F
.774 .77 .849 r
.54606 .39643 m .54648 .39639 L .54608 .39631 L F
0 0 0 r
.54509 .40222 m .54567 .40008 L .54758 .39814 L F
.634 .35 .47 r
.42175 .49236 m .42573 .49228 L .42581 .48961 L F
.647 .361 .471 r
.42573 .49228 m .42856 .49208 L .42581 .48961 L F
.603 .372 .538 r
.42581 .48961 m .42856 .49208 L .42864 .48934 L F
.764 .708 .799 r
.38979 .56079 m .39119 .56466 L .39414 .56135 L F
.258 .106 .476 r
.54229 .3875 m .54408 .38736 L .54396 .38669 L F
0 0 0 r
.53948 .38886 m .54229 .3875 L .54321 .38673 L F
.786 .872 .911 r
.54409 .38408 m .54321 .38673 L .5413 .38488 L F
.919 .535 .13 r
.54321 .38673 m .54229 .3875 L .5413 .38488 L F
.756 .913 .944 r
.54409 .38408 m .5413 .38488 L .54339 .38351 L F
.258 .106 .476 r
.54229 .3875 m .54396 .38669 L .54339 .38351 L F
0 0 0 r
.53893 .38917 m .54229 .3875 L .53948 .38886 L F
.849 .814 .816 r
.48124 .45677 m .48597 .45479 L .48418 .45332 L F
.832 .913 .892 r
.48418 .45332 m .48597 .45479 L .48881 .45154 L F
.671 .609 .777 r
.48597 .45479 m .49069 .45557 L .48881 .45154 L F
.57 .361 .558 r
.51634 .41361 m .51341 .41645 L .51362 .41425 L F
.626 .422 .586 r
.42864 .48934 m .43252 .489 L .43151 .48578 L F
.58 .369 .559 r
.43252 .489 m .43543 .48571 L .43151 .48578 L F
.622 .604 .811 r
.52371 .43325 m .52502 .43679 L .52787 .43459 L F
.75 .341 .276 r
.53342 .40699 m .53256 .40906 L .52915 .4061 L F
.685 .268 .249 r
.53342 .40699 m .53372 .40927 L .53256 .40906 L F
.761 .342 .254 r
.53342 .40699 m .53462 .40817 L .53372 .40927 L F
0 .019 .555 r
.53372 .40927 m .53437 .40788 L .53279 .4104 L F
.53372 .40927 m .53232 .41117 L .53256 .40906 L F
.53372 .40927 m .53279 .4104 L .53232 .41117 L F
.761 .342 .254 r
.53462 .40817 m .53651 .41001 L .53372 .40927 L F
.497 .215 .416 r
.5197 .41061 m .51934 .41322 L .51634 .41361 L F
.836 .881 .875 r
.41739 .53672 m .42042 .53368 L .41903 .53219 L F
.642 .714 .9 r
.49583 .43443 m .49297 .43595 L .49123 .43281 L F
.951 .884 .483 r
.5609 .38046 m .56 .38234 L .56002 .3805 L F
.539 0 0 r
.56002 .3805 m .56306 .38205 L .5609 .38046 L F
.687 .69 .847 r
.51111 .43841 m .51507 .44103 L .51383 .43724 L F
.73 .7 .822 r
.51507 .44103 m .51838 .4383 L .51383 .43724 L F
.55 .377 .6 r
.44976 .4688 m .45255 .47116 L .45253 .46815 L F
.44976 .4688 m .44992 .47197 L .45255 .47116 L F
.458 .242 .496 r
.50104 .42418 m .50384 .42622 L .5009 .42694 L F
.554 .196 .315 r
.50408 .42413 m .50384 .42622 L .50104 .42418 L F
.958 .743 .292 r
.55338 .40693 m .55243 .40818 L .55338 .40983 L F
.531 .281 .481 r
.51489 .40654 m .51805 .40651 L .51778 .40359 L F
.304 .122 .461 r
.51778 .40359 m .51992 .40469 L .52067 .40365 L F
.51778 .40359 m .51805 .40651 L .51992 .40469 L F
.82 .692 .723 r
.37675 .55144 m .37845 .55487 L .37988 .55199 L F
0 0 0 r
.37988 .55199 m .37845 .55487 L .37972 .55277 L F
.37988 .55199 m .37972 .55277 L .37675 .55144 L F
.498 .589 .877 r
.35686 .55079 m .3572 .54625 L .35463 .5468 L F
.35686 .55079 m .35899 .55009 L .3572 .54625 L F
.751 .742 .845 r
.5376 .39666 m .54178 .39557 L .53965 .39188 L F
.464 .032 .131 r
.54011 .39814 m .54178 .39557 L .5376 .39666 L F
.494 .537 .829 r
.54178 .39557 m .54374 .39205 L .53965 .39188 L F
.54178 .39557 m .54428 .39597 L .54374 .39205 L F
.498 .062 .142 r
.54011 .39814 m .54428 .39597 L .54178 .39557 L F
.585 .383 .574 r
.44115 .47913 m .44409 .4786 L .44406 .4758 L F
.575 .376 .573 r
.44406 .4758 m .44688 .47789 L .44703 .47528 L F
.44406 .4758 m .44409 .4786 L .44688 .47789 L F
.791 .537 .553 r
.54427 .41316 m .54724 .41579 L .54644 .41314 L F
.636 .167 .122 r
.54644 .41314 m .54908 .41393 L .54427 .41316 L F
.694 .791 .925 r
.48326 .43538 m .48565 .4376 L .4817 .43704 L F
.817 .809 .842 r
.48832 .43398 m .48565 .4376 L .48423 .43627 L F
.48832 .43398 m .48423 .43627 L .48675 .43442 L F
.48832 .43398 m .48326 .43538 L .48415 .43355 L F
0 0 0 r
.4875 .43387 m .48581 .43571 L .48896 .43374 L F
.48749 .43387 m .48748 .43388 L .4875 .43387 L F
.48748 .43388 m .48581 .43571 L .4875 .43387 L F
.817 .809 .842 r
.48675 .43442 m .48423 .43627 L .48326 .43538 L F
.794 .804 .861 r
.50697 .43481 m .50241 .43512 L .50566 .43388 L F
0 0 .349 r
.50697 .43481 m .50804 .42969 L .50964 .43288 L F
.50697 .43481 m .50847 .43301 L .50804 .42969 L F
.111 .318 .79 r
.50697 .43481 m .50954 .43648 L .50847 .43301 L F
0 .218 .685 r
.50747 .43471 m .50697 .43481 L .50566 .43388 L F
.50747 .43471 m .50954 .43648 L .50697 .43481 L F
.829 .737 .762 r
.36856 .51494 m .36653 .51786 L .36598 .51521 L F
.628 .952 .934 r
.41509 .54092 m .41416 .54027 L .41032 .54225 L F
.82 .692 .723 r
.37675 .55144 m .3744 .55437 L .37845 .55487 L F
.711 .632 .767 r
.3744 .55437 m .37822 .5572 L .37845 .55487 L F
.325 .561 .922 r
.37845 .55487 m .38112 .55548 L .37972 .55277 L F
.559 .635 .882 r
.36463 .55514 m .3656 .55131 L .36281 .55165 L F
.36463 .55514 m .3673 .55449 L .3656 .55131 L F
0 0 0 r
.54509 .40222 m .54175 .40499 L .54287 .4032 L F
.696 .7 .85 r
.59787 .39062 m .60065 .38949 L .59632 .38861 L F
.507 .299 .532 r
.33688 .51312 m .34109 .51434 L .34009 .50866 L F
.195 .095 .506 r
.34009 .50866 m .34211 .51145 L .34293 .50843 L F
.34009 .50866 m .34109 .51434 L .34211 .51145 L F
.273 .766 .902 r
.4697 .44489 m .47144 .44445 L .47313 .44478 L F
.332 0 .222 r
.47081 .44509 m .4723 .44423 L .47144 .44445 L F
0 0 0 r
.47313 .44478 m .47515 .4409 L .47222 .44073 L F
.4751 .44099 m .47446 .443 L .47515 .4409 L F
.47313 .44478 m .47446 .443 L .4751 .44099 L F
.591 .929 .957 r
.47313 .44478 m .47144 .44445 L .47446 .443 L F
.332 0 .222 r
.47081 .44509 m .47399 .44443 L .47446 .443 L F
.47399 .44443 m .47437 .44435 L .47446 .443 L F
.4723 .44423 m .47446 .443 L .47144 .44445 L F
.273 .766 .902 r
.46864 .44492 m .47144 .44445 L .4697 .44489 L F
.664 .391 .496 r
.4046 .49866 m .40891 .49593 L .40588 .49597 L F
.756 .913 .944 r
.54409 .38408 m .54339 .38351 L .54562 .38285 L F
.332 .808 .742 r
.54562 .38285 m .54719 .38202 L .54738 .3818 L F
.54562 .38285 m .54339 .38351 L .54719 .38202 L F
.824 .82 .846 r
.60895 .36365 m .61311 .36243 L .61113 .36099 L F
.612 .577 .79 r
.37202 .55739 m .3744 .55437 L .37178 .55556 L F
.37202 .55739 m .37602 .55882 L .3744 .55437 L F
.193 .131 .553 r
.59394 .37252 m .59546 .37183 L .59554 .36748 L F
.222 .197 .618 r
.59394 .37252 m .59621 .37427 L .59546 .37183 L F
.33 .185 .528 r
.5939 .37479 m .59621 .37427 L .59394 .37252 L F
.197 .036 .424 r
.33514 .51705 m .33674 .51641 L .33688 .51312 L F
.292 .265 .656 r
.33514 .51705 m .33732 .51911 L .33674 .51641 L F
.515 .274 .488 r
.33455 .51962 m .33732 .51911 L .33514 .51705 L F
.688 .555 .698 r
.35194 .50928 m .34914 .51354 L .34723 .50988 L F
.358 .49 .855 r
.50127 .43979 m .49688 .43847 L .49983 .43747 L F
.633 .442 .606 r
.43828 .48245 m .44125 .48206 L .44115 .47913 L F
.588 .406 .603 r
.44115 .47913 m .4441 .4815 L .44409 .4786 L F
.44115 .47913 m .44125 .48206 L .4441 .4815 L F
.427 .039 .197 r
.4948 .43092 m .49123 .43281 L .49139 .43116 L F
.778 .655 .727 r
.35222 .52023 m .34866 .5168 L .35298 .51739 L F
.35222 .52023 m .35061 .52096 L .34866 .5168 L F
.776 .648 .721 r
.35222 .52023 m .35021 .52345 L .35061 .52096 L F
.706 .607 .744 r
.35524 .51621 m .35222 .52023 L .35298 .51739 L F
.783 .648 .713 r
.38979 .56079 m .39414 .56135 L .3943 .55865 L F
.684 .563 .712 r
.3943 .55865 m .39414 .56135 L .397 .55775 L F
.632 .4 .547 r
.41188 .49606 m .41588 .49561 L .41568 .49285 L F
.694 .521 .649 r
.41588 .49561 m .41874 .49256 L .41568 .49285 L F
.722 .588 .705 r
.53468 .39639 m .5376 .39666 L .53711 .39369 L F
.647 .34 .436 r
.53436 .39894 m .5376 .39666 L .53468 .39639 L F
.53436 .39894 m .53755 .39907 L .5376 .39666 L F
.751 .742 .845 r
.5376 .39666 m .53965 .39188 L .53711 .39369 L F
.464 .032 .131 r
.54011 .39814 m .5376 .39666 L .53755 .39907 L F
.919 .905 .793 r
.42042 .53368 m .42022 .52915 L .41903 .53219 L F
.697 .621 .768 r
.53298 .39306 m .53711 .39369 L .53576 .38916 L F
.711 .571 .696 r
.53468 .39639 m .53711 .39369 L .53298 .39306 L F
.513 .507 .787 r
.53576 .38916 m .53711 .39369 L .53965 .39188 L F
.792 .886 .914 r
.40384 .54396 m .40588 .54544 L .40785 .54366 L F
.583 .359 .541 r
.45526 .46188 m .45779 .46396 L .45805 .46111 L F
.45526 .46188 m .45512 .46459 L .45779 .46396 L F
.397 .484 .832 r
.38368 .5584 m .38448 .55422 L .38112 .55548 L F
.38368 .5584 m .38603 .55774 L .38448 .55422 L F
.316 .194 .551 r
.38368 .5584 m .38547 .5603 L .38603 .55774 L F
.468 .206 .433 r
.38289 .56105 m .38547 .5603 L .38368 .5584 L F
.38289 .56105 m .38547 .5603 L .38368 .5584 L F
.711 .571 .696 r
.53468 .39639 m .53298 .39306 L .53322 .39528 L F
.678 .62 .783 r
.39253 .55659 m .3943 .55865 L .39303 .55529 L F
.783 .648 .713 r
.38979 .56079 m .3943 .55865 L .39253 .55659 L F
.704 .633 .776 r
.39303 .55529 m .3943 .55865 L .397 .55775 L F
.479 .288 .543 r
.46039 .45467 m .46302 .45103 L .46037 .4517 L F
.798 .703 .759 r
.50413 .44072 m .50787 .44372 L .50653 .44002 L F
.50413 .44072 m .50374 .44367 L .50787 .44372 L F
.796 .717 .778 r
.50374 .44367 m .50629 .44555 L .50787 .44372 L F
.761 .686 .779 r
.50653 .44002 m .50787 .44372 L .50879 .44161 L F
.323 .211 .568 r
.48326 .43538 m .4817 .43704 L .48151 .43432 L F
.694 .791 .925 r
.48326 .43538 m .4817 .43704 L .48151 .43432 L F
.547 .614 .871 r
.33757 .53042 m .33825 .52616 L .33619 .52634 L F
.33757 .53042 m .3402 .52985 L .33825 .52616 L F
.529 .515 .784 r
.33757 .53042 m .34155 .53431 L .3402 .52985 L F
.58 .434 .648 r
.45253 .46815 m .45512 .46459 L .45236 .46524 L F
0 0 0 r
.498 .42166 m .50313 .41929 L .49848 .41932 L F
.694 .503 .626 r
.52371 .43325 m .52717 .43076 L .52366 .43082 L F
.52371 .43325 m .52787 .43459 L .52717 .43076 L F
.568 .456 .686 r
.52787 .43459 m .53044 .42912 L .52717 .43076 L F
.312 .227 .596 r
.54657 .4289 m .54529 .43103 L .5449 .42792 L F
.899 .878 .806 r
.60065 .38949 m .6033 .38579 L .60181 .38419 L F
.8 .906 .915 r
.6033 .38579 m .60517 .38156 L .60181 .38419 L F
.6033 .38579 m .60656 .38304 L .60517 .38156 L F
.797 .73 .79 r
.54945 .41686 m .55329 .41735 L .55206 .41332 L F
.983 .733 .476 r
.53322 .39528 m .53436 .39894 L .53468 .39639 L F
.72 .723 .853 r
.54697 .39239 m .55142 .39312 L .5495 .3911 L F
.761 .646 .734 r
.54915 .39697 m .55142 .39312 L .54697 .39239 L F
.811 .898 .904 r
.55142 .39312 m .5529 .38914 L .5495 .3911 L F
.55142 .39312 m .55465 .39076 L .5529 .38914 L F
.326 0 .206 r
.33674 .51641 m .34109 .51434 L .33688 .51312 L F
.352 0 .215 r
.51097 .40998 m .5139 .40924 L .51489 .40654 L F
.803 .451 .39 r
.51489 .40654 m .51838 .4092 L .51805 .40651 L F
.51489 .40654 m .5139 .40924 L .51838 .4092 L F
.638 .554 .743 r
.35831 .51302 m .35558 .51366 L .35389 .50992 L F
.615 .462 .652 r
.35831 .51302 m .35524 .51621 L .35558 .51366 L F
.697 .887 .967 r
.55557 .38149 m .5569 .38415 L .56 .38234 L F
.549 .431 .671 r
.56 .38234 m .5569 .38415 L .55557 .38149 L F
.56 .38234 m .55991 .38532 L .5569 .38415 L F
.598 .367 .538 r
.42864 .48934 m .43138 .49157 L .43252 .489 L F
.42864 .48934 m .42856 .49208 L .43138 .49157 L F
.761 .646 .734 r
.54915 .39697 m .54697 .39239 L .54608 .39631 L F
.705 .21 .063 r
.54758 .39814 m .54915 .39697 L .54608 .39631 L F
.454 .429 .742 r
.5939 .37479 m .59468 .37913 L .59642 .37781 L F
.491 .331 .591 r
.59473 .38194 m .59642 .37781 L .59468 .37913 L F
.592 .476 .69 r
.45792 .45834 m .46095 .45796 L .46039 .45467 L F
.544 .355 .575 r
.45792 .45834 m .46044 .45999 L .46095 .45796 L F
.45792 .45834 m .45805 .46111 L .46044 .45999 L F
.772 .757 .839 r
.61185 .37789 m .61298 .38144 L .6157 .37853 L F
.833 .956 .893 r
.42022 .52915 m .42597 .52678 L .42452 .52574 L F
.802 .943 .918 r
.42796 .52313 m .42597 .52678 L .42895 .52348 L F
.42796 .52313 m .42452 .52574 L .42597 .52678 L F
.618 .393 .554 r
.54908 .41393 m .54724 .41579 L .54427 .41316 L F
0 0 .118 r
.54955 .41795 m .54945 .41686 L .54908 .41393 L F
.54963 .4186 m .54945 .41686 L .54955 .41795 L F
.9 .951 .827 r
.54945 .41686 m .55206 .41332 L .54923 .41438 L F
.618 .393 .554 r
.54908 .41393 m .54945 .41686 L .54724 .41579 L F
.9 .951 .827 r
.54945 .41686 m .54923 .41438 L .54897 .41448 L F
.734 .722 .839 r
.39981 .55479 m .40432 .55563 L .40251 .55312 L F
.57 .361 .558 r
.51634 .41361 m .51637 .41642 L .51341 .41645 L F
.536 .334 .554 r
.51934 .41322 m .51637 .41642 L .51634 .41361 L F
.51934 .41322 m .51637 .41642 L .51634 .41361 L F
.704 .633 .776 r
.39303 .55529 m .397 .55775 L .39546 .55393 L F
.717 .69 .824 r
.39546 .55393 m .397 .55775 L .39981 .55479 L F
.295 0 .021 r
.35528 .50233 m .35776 .50201 L .35985 .49952 L F
.557 .134 .195 r
.35985 .49952 m .36182 .50114 L .36247 .49964 L F
.35985 .49952 m .35776 .50201 L .36182 .50114 L F
.778 .716 .794 r
.39847 .55099 m .40247 .55121 L .39969 .54962 L F
.39847 .55099 m .40251 .55312 L .40247 .55121 L F
.303 0 .126 r
.52358 .40279 m .52642 .40189 L .52751 .39906 L F
.374 0 .192 r
.52642 .40189 m .53091 .39827 L .52751 .39906 L F
.171 0 .073 r
.51341 .41645 m .51231 .41898 L .50987 .41996 L F
.442 0 .083 r
.51341 .41645 m .51508 .41852 L .51231 .41898 L F
.51341 .41645 m .51637 .41642 L .51508 .41852 L F
.679 .865 .97 r
.5529 .38914 m .55465 .39076 L .55712 .38932 L F
.691 .706 .859 r
.59632 .38861 m .60065 .38949 L .59981 .38608 L F
.899 .878 .806 r
.60065 .38949 m .60181 .38419 L .59981 .38608 L F
.61 .42 .6 r
.43543 .48571 m .43831 .4854 L .43828 .48245 L F
.632 .437 .601 r
.43828 .48245 m .43831 .4854 L .44125 .48206 L F
.756 .662 .758 r
.51383 .43724 m .51838 .4383 L .51645 .43335 L F
.716 .642 .774 r
.51645 .43335 m .51838 .4383 L .5207 .43658 L F
.639 .772 .944 r
.49396 .4468 m .49853 .44756 L .49701 .44413 L F
.627 .628 .833 r
.49853 .44756 m .49957 .44263 L .49701 .44413 L F
.49853 .44756 m .50072 .44659 L .49957 .44263 L F
.602 .805 .977 r
.38734 .54177 m .38767 .54012 L .38534 .54049 L F
.38734 .54177 m .3918 .54155 L .38767 .54012 L F
.783 .651 .716 r
.50773 .42347 m .50384 .42622 L .50408 .42413 L F
.759 .767 .86 r
.38547 .5603 m .38709 .56325 L .38979 .56079 L F
.808 .741 .79 r
.52897 .4095 m .53083 .41431 L .52663 .41213 L F
.799 .315 .056 r
.52663 .41213 m .53083 .41431 L .52941 .41525 L F
.425 .819 .597 r
.52941 .41525 m .53083 .41431 L .52729 .4168 L F
.331 .462 .842 r
.53232 .41117 m .53083 .41431 L .52897 .4095 L F
.506 .674 .94 r
.53232 .41117 m .53338 .41371 L .53083 .41431 L F
.753 .688 .788 r
.50653 .44002 m .50879 .44161 L .51111 .43841 L F
.99 .75 .474 r
.52324 .42209 m .52497 .42046 L .52336 .41897 L F
.862 .976 .671 r
.52617 .41708 m .52497 .42046 L .52336 .41897 L F
.52617 .41708 m .52729 .4168 L .52497 .42046 L F
0 0 0 r
.52324 .42209 m .52497 .42046 L .52578 .42032 L F
.715 .657 .791 r
.44886 .49844 m .44714 .49545 L .444 .49855 L F
.44886 .49844 m .44859 .49651 L .44714 .49545 L F
.817 .717 .754 r
.44518 .50252 m .44886 .49844 L .444 .49855 L F
.768 .694 .78 r
.45097 .49575 m .44859 .49651 L .44886 .49844 L F
.822 .728 .761 r
.39093 .55287 m .39253 .55659 L .39303 .55529 L F
.39093 .55287 m .38814 .55658 L .39253 .55659 L F
.825 .702 .729 r
.38814 .55658 m .38979 .56079 L .39253 .55659 L F
0 0 0 r
.55259 .37481 m .55423 .37452 L .55077 .3754 L F
.509 .172 .331 r
.55077 .3754 m .55025 .37799 L .55435 .37714 L F
.466 .879 .745 r
.52941 .41525 m .52729 .4168 L .52617 .41708 L F
.33 .022 .282 r
.46599 .44757 m .4684 .44678 L .46864 .44492 L F
.256 0 .263 r
.46864 .44492 m .47081 .44509 L .47144 .44445 L F
.46864 .44492 m .4684 .44678 L .47081 .44509 L F
.841 .781 .794 r
.48691 .43004 m .48829 .43144 L .48936 .42645 L F
.569 .378 .583 r
.48749 .43387 m .48829 .43144 L .48691 .43004 L F
.48749 .43387 m .49086 .4336 L .48829 .43144 L F
.037 0 .476 r
.48936 .42645 m .48829 .43144 L .49138 .42766 L F
.143 .336 .797 r
.48829 .43144 m .49127 .43029 L .49138 .42766 L F
.857 .642 .61 r
.54053 .41611 m .54518 .41636 L .54427 .41316 L F
0 0 .499 r
.54427 .41316 m .54595 .41406 L .54638 .41128 L F
.54427 .41316 m .54518 .41636 L .54595 .41406 L F
.903 .983 .785 r
.43146 .51982 m .42845 .52079 L .42895 .52348 L F
.934 .966 .686 r
.42895 .52348 m .42845 .52079 L .42796 .52313 L F
.975 .925 .643 r
.55338 .40983 m .55085 .41218 L .55206 .41332 L F
.55338 .40983 m .55243 .40818 L .55085 .41218 L F
.582 .572 .807 r
.34232 .53654 m .34416 .5337 L .34155 .53431 L F
.34232 .53654 m .34596 .53774 L .34416 .5337 L F
.711 .632 .767 r
.3744 .55437 m .37602 .55882 L .37822 .5572 L F
.018 0 0 r
.51346 .4113 m .51838 .4092 L .5139 .40924 L F
.51346 .4113 m .51627 .41069 L .51838 .4092 L F
.514 .492 .77 r
.51838 .4092 m .51992 .40469 L .51805 .40651 L F
.51838 .4092 m .5214 .40949 L .51992 .40469 L F
0 0 0 r
.51627 .41069 m .5214 .40949 L .51838 .4092 L F
.565 .575 .822 r
.60468 .37559 m .60605 .37064 L .60294 .37411 L F
.60468 .37559 m .6075 .37481 L .60605 .37064 L F
.651 .884 .983 r
.53072 .43419 m .53499 .43415 L .53327 .43357 L F
.292 .78 .904 r
.53499 .43415 m .53728 .43283 L .53327 .43357 L F
.53499 .43415 m .53783 .43372 L .53728 .43283 L F
.725 .415 .454 r
.39404 .54971 m .39847 .55099 L .39842 .5478 L F
.426 .182 .439 r
.39842 .5478 m .39847 .55099 L .39969 .54962 L F
.617 .627 .838 r
.35899 .55009 m .36028 .55227 L .36281 .55165 L F
.855 .684 .67 r
.3918 .54155 m .38968 .54365 L .38767 .54012 L F
.601 .48 .687 r
.39262 .53713 m .39271 .54074 L .3918 .54155 L F
.58 .369 .559 r
.43252 .489 m .43551 .48871 L .43543 .48571 L F
.646 .42 .562 r
.43543 .48571 m .43832 .48834 L .43831 .4854 L F
.43543 .48571 m .43551 .48871 L .43832 .48834 L F
.596 .529 .75 r
.35093 .54344 m .35181 .54766 L .35463 .5468 L F
.617 .267 .354 r
.39483 .49951 m .39745 .50181 L .39891 .49898 L F
.696 .41 .486 r
.39745 .50181 m .40178 .4991 L .39891 .49898 L F
.527 .421 .676 r
.34933 .50415 m .35247 .50564 L .35244 .50268 L F
.34933 .50415 m .3499 .50678 L .35247 .50564 L F
.747 .987 .774 r
.38734 .54507 m .38836 .54285 L .38968 .54365 L F
.877 .96 .852 r
.53853 .38566 m .53738 .38725 L .53733 .3846 L F
.814 .986 .716 r
.53738 .38725 m .53576 .38916 L .53853 .38566 L F
.832 .913 .892 r
.48418 .45332 m .48881 .45154 L .48752 .45045 L F
.853 .944 .878 r
.48752 .45045 m .48881 .45154 L .49213 .44849 L F
.542 .339 .554 r
.44703 .47528 m .44962 .4749 L .44992 .47197 L F
.701 .559 .69 r
.44962 .4749 m .45255 .47116 L .44992 .47197 L F
.588 .427 .631 r
.54724 .41579 m .54833 .41886 L .54551 .41907 L F
.54724 .41579 m .54945 .41686 L .54833 .41886 L F
.824 .775 .806 r
.51936 .43296 m .5207 .43658 L .52371 .43325 L F
.853 .944 .878 r
.48752 .45045 m .49213 .44849 L .49015 .44703 L F
.798 .893 .912 r
.49015 .44703 m .49213 .44849 L .49396 .4468 L F
.716 .597 .722 r
.39734 .54112 m .39406 .5442 L .39271 .54074 L F
.561 .877 .593 r
.39734 .54112 m .3953 .54271 L .39406 .5442 L F
.07 .326 .806 r
.3953 .54271 m .39577 .54562 L .39406 .5442 L F
.528 .402 .652 r
.39577 .54562 m .39533 .5482 L .39406 .5442 L F
.818 .885 .458 r
.53285 .42602 m .53291 .42615 L .5317 .42865 L F
.757 .512 0 r
.53311 .42657 m .53291 .42615 L .53232 .42262 L F
.349 .21 .547 r
.53232 .42262 m .53291 .42615 L .53459 .42207 L F
.818 .885 .458 r
.53459 .42207 m .53291 .42615 L .53285 .42602 L F
.757 .512 0 r
.53317 .42691 m .53291 .42615 L .53311 .42657 L F
.879 .914 .512 r
.5317 .42865 m .53291 .42615 L .53317 .42691 L F
.733 .624 .737 r
.53853 .38566 m .53576 .38916 L .53893 .38917 L F
.513 .507 .787 r
.53576 .38916 m .53965 .39188 L .53893 .38917 L F
.645 .58 .767 r
.53965 .39188 m .54229 .3875 L .53893 .38917 L F
.664 .391 .496 r
.4046 .49866 m .40877 .49868 L .40891 .49593 L F
.66 .387 .496 r
.40877 .49868 m .41163 .49859 L .40891 .49593 L F
.672 .384 .475 r
.40891 .49593 m .41163 .49859 L .41188 .49606 L F
.716 .594 .718 r
.39584 .53709 m .39271 .54074 L .39262 .53713 L F
.716 .642 .774 r
.51645 .43335 m .5207 .43658 L .51936 .43296 L F
.654 .51 .675 r
.44688 .47789 m .44962 .4749 L .44703 .47528 L F
.716 .594 .718 r
.39584 .53709 m .39734 .54112 L .39271 .54074 L F
.492 .47 .76 r
.4001 .53915 m .39734 .54112 L .39584 .53709 L F
.591 .073 0 r
.40002 .54267 m .39734 .54112 L .4001 .53915 L F
.40002 .54267 m .3953 .54271 L .39734 .54112 L F
.173 0 .384 r
.54738 .3818 m .55025 .37799 L .54723 .38001 L F
.601 .543 .761 r
.34645 .54014 m .34854 .53676 L .34596 .53774 L F
.34645 .54014 m .3498 .54171 L .34854 .53676 L F
.759 .648 .738 r
.44714 .49545 m .45097 .49575 L .45172 .49357 L F
.44714 .49545 m .44859 .49651 L .45097 .49575 L F
.708 .645 .784 r
.45391 .49211 m .45172 .49357 L .45097 .49575 L F
.792 .886 .914 r
.40384 .54396 m .40785 .54366 L .40691 .54256 L F
.293 0 0 r
.41032 .54225 m .40691 .54256 L .40785 .54366 L F
.454 .429 .742 r
.5939 .37479 m .59642 .37781 L .59621 .37427 L F
.283 .77 .913 r
.54381 .41569 m .54518 .41636 L .54053 .41611 L F
.68 .974 .904 r
.54595 .41406 m .54518 .41636 L .54381 .41569 L F
.917 .916 .526 r
.43308 .5128 m .43146 .51982 L .43376 .51604 L F
.43308 .5128 m .43095 .51946 L .43146 .51982 L F
.693 .981 .826 r
.43095 .51946 m .42845 .52079 L .43146 .51982 L F
.801 .518 .509 r
.52915 .4061 m .52897 .4095 L .52479 .4084 L F
.673 .405 .508 r
.53256 .40906 m .52897 .4095 L .52915 .4061 L F
.59 .216 .302 r
.39034 .50193 m .39483 .49951 L .39055 .49905 L F
.39034 .50193 m .3947 .50152 L .39483 .49951 L F
.638 .257 .306 r
.3947 .50152 m .39745 .50181 L .39483 .49951 L F
.911 .877 .789 r
.37261 .55314 m .37675 .55144 L .37516 .55179 L F
.37261 .55314 m .3744 .55437 L .37675 .55144 L F
.024 .361 .833 r
.37675 .55144 m .3781 .55037 L .37516 .55179 L F
.37675 .55144 m .37972 .55277 L .3781 .55037 L F
.669 .515 .666 r
.4441 .4815 m .44688 .47789 L .44409 .4786 L F
.667 .421 .539 r
.41163 .49859 m .41588 .49561 L .41188 .49606 L F
.543 .571 .833 r
.34155 .53431 m .3425 .52978 L .3402 .52985 L F
.34155 .53431 m .34416 .5337 L .3425 .52978 L F
.639 .713 .901 r
.3673 .55449 m .37178 .55556 L .37003 .5536 L F
.699 .748 .89 r
.37003 .5536 m .37178 .55556 L .3744 .55437 L F
.455 .041 .164 r
.36182 .50114 m .36492 .5012 L .36247 .49964 L F
.406 .079 .295 r
.36247 .49964 m .36492 .5012 L .36505 .49908 L F
.694 .684 .837 r
.39093 .55287 m .39303 .55529 L .39152 .55118 L F
.635 .651 .849 r
.39152 .55118 m .39303 .55529 L .39546 .55393 L F
.883 .636 .562 r
.55618 .37725 m .5594 .37568 L .55677 .37419 L F
.55618 .37725 m .55901 .37824 L .5594 .37568 L F
.58 .434 .648 r
.45253 .46815 m .4552 .46734 L .45512 .46459 L F
.669 .537 .694 r
.45255 .47116 m .4552 .46734 L .45253 .46815 L F
.66 .477 .626 r
.44125 .48206 m .43831 .4854 L .44133 .48503 L F
.658 .513 .676 r
.44133 .48503 m .4441 .4815 L .44125 .48206 L F
.65 .486 .647 r
.41874 .49256 m .42157 .49516 L .42175 .49236 L F
.657 .448 .59 r
.42157 .49516 m .42573 .49228 L .42175 .49236 L F
.694 .521 .649 r
.41588 .49561 m .41875 .49559 L .41874 .49256 L F
.65 .486 .647 r
.41874 .49256 m .41875 .49559 L .42157 .49516 L F
.839 .863 .862 r
.43308 .5128 m .43732 .51309 L .43555 .5117 L F
.43308 .5128 m .43376 .51604 L .43732 .51309 L F
.881 .876 .826 r
.43555 .5117 m .43732 .51309 L .44004 .50951 L F
.371 0 .085 r
.47742 .43993 m .48065 .43948 L .4817 .43704 L F
.045 0 0 r
.4817 .43704 m .48268 .4383 L .48326 .43538 L F
.4817 .43704 m .48065 .43948 L .48268 .4383 L F
.69 .704 .858 r
.59632 .38861 m .5979 .38374 L .59545 .38485 L F
.59632 .38861 m .59981 .38608 L .5979 .38374 L F
.648 .451 .603 r
.43138 .49157 m .43551 .48871 L .43252 .489 L F
.753 .688 .788 r
.50653 .44002 m .51111 .43841 L .50954 .43648 L F
.717 .732 .863 r
.50954 .43648 m .51111 .43841 L .51383 .43724 L F
.498 .062 .142 r
.54011 .39814 m .54303 .39841 L .54428 .39597 L F
.877 .867 .825 r
.54428 .39597 m .54532 .39069 L .54374 .39205 L F
.54428 .39597 m .54697 .39239 L .54532 .39069 L F
.609 .449 .64 r
.54428 .39597 m .54608 .39631 L .54697 .39239 L F
.736 .642 .754 r
.60862 .38083 m .60656 .38304 L .60473 .37831 L F
.96 .64 .238 r
.60517 .38156 m .60656 .38304 L .60473 .37831 L F
.863 .913 .863 r
.60517 .38156 m .60656 .38304 L .60862 .38083 L F
.358 .102 .382 r
.46302 .45103 m .46558 .45029 L .46599 .44757 L F
.4 .144 .407 r
.46558 .45029 m .4684 .44678 L .46599 .44757 L F
.8 .967 .659 r
.54357 .43214 m .54529 .43103 L .54657 .4289 L F
.881 .876 .826 r
.43555 .5117 m .44004 .50951 L .43842 .50775 L F
.832 .835 .85 r
.43842 .50775 m .44004 .50951 L .44308 .50639 L F
.479 .288 .543 r
.46039 .45467 m .46311 .45397 L .46302 .45103 L F
.553 .449 .69 r
.46039 .45467 m .46359 .45696 L .46311 .45397 L F
.46039 .45467 m .46095 .45796 L .46359 .45696 L F
.142 0 0 r
.52067 .40365 m .51992 .40469 L .52358 .40279 L F
.757 .662 .756 r
.48415 .43355 m .48749 .43387 L .48691 .43004 L F
.262 0 0 r
.48326 .43538 m .48749 .43387 L .48415 .43355 L F
.48326 .43538 m .48581 .43571 L .48749 .43387 L F
0 0 0 r
.48749 .43387 m .48896 .43374 L .49086 .4336 L F
.461 .668 .952 r
.51092 .43071 m .50964 .43288 L .50804 .42969 L F
.51092 .43071 m .51246 .43278 L .50964 .43288 L F
.428 .497 .828 r
.35093 .54344 m .3515 .53882 L .3498 .54171 L F
.35093 .54344 m .35307 .54283 L .3515 .53882 L F
.596 .529 .75 r
.35093 .54344 m .35463 .5468 L .35307 .54283 L F
.169 .705 .732 r
.34548 .50757 m .34777 .50709 L .3499 .50678 L F
0 0 0 r
.34777 .50709 m .35247 .50564 L .3499 .50678 L F
.508 .845 .997 r
.53853 .38566 m .53733 .3846 L .5413 .38488 L F
.53853 .38566 m .53733 .3846 L .5413 .38488 L F
0 .08 .638 r
.54826 .40271 m .54961 .40607 L .54764 .4051 L F
.919 .978 .745 r
.54961 .40607 m .54652 .40795 L .54764 .4051 L F
.54961 .40607 m .54732 .40969 L .54652 .40795 L F
.736 .872 .944 r
.54697 .39239 m .54791 .38921 L .54532 .39069 L F
.54697 .39239 m .5495 .3911 L .54791 .38921 L F
.642 .714 .9 r
.49583 .43443 m .49123 .43281 L .49392 .43269 L F
.819 .836 .862 r
.49827 .43247 m .49583 .43443 L .49392 .43269 L F
.684 .445 .555 r
.5009 .42694 m .50127 .43044 L .49712 .42975 L F
.527 .332 .559 r
.50352 .42888 m .5009 .42694 L .50384 .42622 L F
.50352 .42888 m .50127 .43044 L .5009 .42694 L F
.819 .836 .862 r
.49827 .43247 m .4948 .43092 L .49712 .42975 L F
.49827 .43247 m .49392 .43269 L .4948 .43092 L F
.631 .638 .84 r
.50127 .43044 m .49827 .43247 L .49712 .42975 L F
.568 .456 .686 r
.52787 .43459 m .53072 .43419 L .53044 .42912 L F
.736 .642 .754 r
.60862 .38083 m .60473 .37831 L .60681 .37849 L F
.863 .913 .863 r
.60517 .38156 m .60862 .38083 L .60681 .37849 L F
.617 .335 .466 r
.59747 .36383 m .60081 .36119 L .59784 .36195 L F
.49 .33 .59 r
.46311 .45397 m .46558 .45029 L .46302 .45103 L F
.605 .315 .449 r
.60352 .35993 m .60687 .35819 L .60468 .35784 L F
.45 .369 .674 r
.59554 .36748 m .59747 .36383 L .59522 .36503 L F
.858 .735 .727 r
.46619 .47015 m .46786 .47192 L .46629 .46772 L F
.815 .718 .758 r
.46366 .47152 m .46786 .47192 L .46619 .47015 L F
.46366 .47152 m .46539 .4756 L .46786 .47192 L F
.744 .684 .793 r
.46629 .46772 m .46786 .47192 L .47111 .46877 L F
.778 .716 .794 r
.39847 .55099 m .39981 .55479 L .40251 .55312 L F
.799 .707 .764 r
.44128 .50202 m .44518 .50252 L .444 .49855 L F
.802 .697 .749 r
.44128 .50202 m .44308 .50639 L .44518 .50252 L F
.566 .49 .729 r
.54551 .41907 m .54604 .42298 L .54319 .42291 L F
.797 .69 .747 r
.38814 .55658 m .38547 .5603 L .38979 .56079 L F
.448 .417 .732 r
.33455 .51962 m .33791 .52178 L .33732 .51911 L F
.236 .716 .935 r
.51246 .43278 m .51645 .43335 L .51305 .43312 L F
.929 .736 .62 r
.44108 .50477 m .44308 .50639 L .44128 .50202 L F
.832 .835 .85 r
.43842 .50775 m .44308 .50639 L .44108 .50477 L F
0 0 0 r
.498 .42166 m .50068 .42085 L .50313 .41929 L F
.392 .437 .788 r
.50313 .41929 m .50724 .418 L .50195 .41605 L F
.482 .104 .247 r
.50068 .42085 m .50724 .418 L .50313 .41929 L F
.975 .893 .68 r
.45488 .48955 m .45391 .49211 L .45562 .48616 L F
.989 .81 .571 r
.4169 .53575 m .41323 .53756 L .41416 .54027 L F
.427 .039 .197 r
.4948 .43092 m .49392 .43269 L .49123 .43281 L F
.798 .893 .912 r
.49015 .44703 m .49396 .4468 L .4924 .44548 L F
.771 .923 .937 r
.4924 .44548 m .49396 .4468 L .49701 .44413 L F
.781 .661 .73 r
.45815 .47826 m .46279 .47905 L .46072 .47474 L F
.778 .647 .716 r
.45782 .4809 m .46279 .47905 L .45815 .47826 L F
.45782 .4809 m .46133 .48168 L .46279 .47905 L F
.753 .65 .747 r
.46072 .47474 m .46279 .47905 L .46539 .4756 L F
.763 .644 .73 r
.44961 .4915 m .45172 .49357 L .44978 .48875 L F
.759 .648 .738 r
.44714 .49545 m .45172 .49357 L .44961 .4915 L F
.692 .609 .759 r
.44978 .48875 m .45172 .49357 L .45391 .49211 L F
.636 .501 .682 r
.46044 .45999 m .46359 .45696 L .46095 .45796 L F
.614 .663 .874 r
.3656 .55131 m .3673 .55449 L .37003 .5536 L F
.361 .306 .661 r
.33619 .52634 m .33825 .52616 L .33791 .52178 L F
.173 0 .384 r
.54738 .3818 m .5497 .38087 L .55025 .37799 L F
.399 .035 .226 r
.54719 .38202 m .5497 .38087 L .54738 .3818 L F
.681 .312 .341 r
.38343 .49893 m .3859 .50127 L .38771 .49895 L F
.754 .406 .395 r
.3859 .50127 m .39034 .50193 L .38771 .49895 L F
.679 .417 .519 r
.38771 .49895 m .39034 .50193 L .39055 .49905 L F
.79 .858 .901 r
.50252 .43965 m .50653 .44002 L .50467 .43824 L F
.50252 .43965 m .50413 .44072 L .50653 .44002 L F
.841 .906 .882 r
.50467 .43824 m .50653 .44002 L .50954 .43648 L F
.664 .525 .685 r
.45779 .46396 m .46044 .45999 L .45805 .46111 L F
.664 .473 .616 r
.43832 .48834 m .44133 .48503 L .43831 .4854 L F
.666 .529 .688 r
.4552 .46734 m .45779 .46396 L .45512 .46459 L F
.778 .719 .796 r
.49957 .44263 m .50072 .44659 L .50374 .44367 L F
.752 .652 .751 r
.45252 .48535 m .45562 .48616 L .45785 .48655 L F
.72 .686 .816 r
.39546 .55393 m .39981 .55479 L .39847 .55099 L F
.737 .684 .8 r
.46072 .47474 m .46539 .4756 L .46366 .47152 L F
.783 .651 .716 r
.50773 .42347 m .50896 .42712 L .50384 .42622 L F
.764 .534 .585 r
.50896 .42712 m .50352 .42888 L .50384 .42622 L F
.50896 .42712 m .50804 .42969 L .50352 .42888 L F
0 .119 .651 r
.50922 .42461 m .50896 .42712 L .50773 .42347 L F
.316 .077 .385 r
.51058 .42867 m .50896 .42712 L .50922 .42461 L F
.51058 .42867 m .50804 .42969 L .50896 .42712 L F
.681 .63 .792 r
.40002 .54267 m .39961 .54836 L .40384 .54396 L F
.756 .675 .772 r
.50954 .43648 m .51383 .43724 L .51246 .43278 L F
.77 .683 .767 r
.51246 .43278 m .51383 .43724 L .51645 .43335 L F
.927 .561 .304 r
.60435 .36346 m .60511 .36635 L .60613 .36516 L F
.794 .523 .528 r
.60323 .36775 m .60418 .36728 L .60511 .36635 L F
.669 .871 .49 r
.60573 .36572 m .60511 .36635 L .60467 .36724 L F
0 0 .51 r
.60511 .36635 m .60605 .37064 L .60467 .36724 L F
0 0 .325 r
.60742 .36567 m .60605 .37064 L .60511 .36635 L F
.794 .523 .528 r
.60418 .36728 m .60742 .36567 L .60511 .36635 L F
.669 .871 .49 r
.60613 .36516 m .60511 .36635 L .60573 .36572 L F
.759 .728 .823 r
.60435 .36346 m .60613 .36516 L .60895 .36365 L F
.667 .421 .539 r
.41163 .49859 m .4159 .49844 L .41588 .49561 L F
.726 .5 .584 r
.4159 .49844 m .41875 .49559 L .41588 .49561 L F
.651 .608 .793 r
.34416 .5337 m .34596 .53774 L .34854 .53676 L F
.594 .644 .87 r
.3572 .54625 m .35899 .55009 L .3621 .54921 L F
.593 .636 .863 r
.35899 .55009 m .36281 .55165 L .3621 .54921 L F
.696 .41 .486 r
.39745 .50181 m .40172 .50165 L .40178 .4991 L F
.687 .473 .591 r
.40172 .50165 m .4046 .49866 L .40178 .4991 L F
.759 .728 .823 r
.60435 .36346 m .60895 .36365 L .60768 .36066 L F
.864 .85 .828 r
.60768 .36066 m .60895 .36365 L .61113 .36099 L F
.657 .448 .59 r
.42157 .49516 m .42564 .49524 L .42573 .49228 L F
.676 .464 .591 r
.42573 .49228 m .42564 .49524 L .42856 .49208 L F
.864 .85 .828 r
.60768 .36066 m .61113 .36099 L .60873 .35942 L F
.798 .713 .771 r
.44248 .49445 m .44714 .49545 L .44525 .49095 L F
.813 .678 .715 r
.44248 .49445 m .444 .49855 L .44714 .49545 L F
.779 .705 .782 r
.44525 .49095 m .44714 .49545 L .44961 .4915 L F
.414 0 0 r
.55151 .40385 m .55268 .40281 L .54826 .40271 L F
.93 .548 .197 r
.55151 .40385 m .55362 .40567 L .55268 .40281 L F
.334 0 .154 r
.50195 .41605 m .50813 .41302 L .50572 .41445 L F
.336 .365 .743 r
.34854 .53676 m .3498 .54171 L .3515 .53882 L F
.457 .298 .577 r
.38534 .54049 m .38591 .54454 L .38272 .54483 L F
.406 .111 .349 r
.38591 .54454 m .38519 .54596 L .38272 .54483 L F
.564 .748 .963 r
.38112 .55548 m .38231 .55234 L .37972 .55277 L F
.38112 .55548 m .38448 .55422 L .38231 .55234 L F
.792 .697 .76 r
.49957 .44263 m .50374 .44367 L .50413 .44072 L F
.726 .5 .584 r
.4159 .49844 m .41867 .49857 L .41875 .49559 L F
.645 .439 .589 r
.41867 .49857 m .42157 .49516 L .41875 .49559 L F
.646 .247 .274 r
.36492 .5012 m .3694 .49917 L .36505 .49908 L F
.36492 .5012 m .36756 .50151 L .3694 .49917 L F
.539 .123 .2 r
.3694 .49917 m .36756 .50151 L .37189 .5009 L F
.495 .159 .326 r
.3694 .49917 m .37189 .5009 L .37218 .49886 L F
.377 .488 .845 r
.3621 .54921 m .36281 .55165 L .36415 .54888 L F
.513 .653 .922 r
.36281 .55165 m .3656 .55131 L .36415 .54888 L F
0 0 0 r
.51864 .41504 m .51637 .41642 L .51934 .41322 L F
.706 .558 .684 r
.51864 .41504 m .51508 .41852 L .51637 .41642 L F
.821 .711 .744 r
.47716 .45637 m .48124 .45677 L .48006 .45326 L F
.47716 .45637 m .47938 .4582 L .48124 .45677 L F
.794 .821 .873 r
.48006 .45326 m .48124 .45677 L .48418 .45332 L F
.699 .748 .89 r
.37003 .5536 m .3744 .55437 L .37261 .55314 L F
.668 .847 .968 r
.54791 .38921 m .5495 .3911 L .5529 .38914 L F
.615 .581 .792 r
.50566 .43388 m .50241 .43512 L .50127 .43044 L F
.779 .645 .714 r
.45782 .4809 m .45944 .48511 L .46133 .48168 L F
.63 .706 .901 r
.56 .38234 m .56306 .38205 L .56002 .3805 L F
.999 .816 .526 r
.55846 .38395 m .56 .38234 L .56002 .3805 L F
.55846 .38395 m .55991 .38532 L .56 .38234 L F
.641 .508 .685 r
.56306 .38205 m .55991 .38532 L .56 .38234 L F
.668 .453 .584 r
.42856 .49208 m .42564 .49524 L .42855 .49496 L F
.655 .467 .618 r
.42855 .49496 m .43138 .49157 L .42856 .49208 L F
.169 0 .142 r
.52123 .41152 m .51864 .41504 L .51934 .41322 L F
.396 .43 .778 r
.3402 .52985 m .34111 .52521 L .33825 .52616 L F
.3402 .52985 m .3425 .52978 L .34111 .52521 L F
.669 .515 .666 r
.4441 .4815 m .44813 .48182 L .44688 .47789 L F
.654 .51 .675 r
.44688 .47789 m .4509 .47834 L .44962 .4749 L F
.655 .507 .67 r
.44688 .47789 m .44813 .48182 L .4509 .47834 L F
.74 .684 .797 r
.46901 .46423 m .47389 .46515 L .47187 .46078 L F
.757 .648 .741 r
.46901 .46423 m .47111 .46877 L .47389 .46515 L F
.771 .697 .781 r
.47187 .46078 m .47389 .46515 L .47657 .46167 L F
0 0 0 r
.53651 .41001 m .53981 .40642 L .53913 .40898 L F
.408 .22 .512 r
.54175 .40499 m .53913 .40898 L .53981 .40642 L F
.701 .559 .69 r
.44962 .4749 m .45366 .47484 L .45255 .47116 L F
.669 .537 .694 r
.45255 .47116 m .45641 .47133 L .4552 .46734 L F
.669 .54 .699 r
.45255 .47116 m .45366 .47484 L .45641 .47133 L F
.818 .545 .525 r
.53651 .41001 m .53508 .41349 L .53372 .40927 L F
.297 .002 .283 r
.53913 .40898 m .53508 .41349 L .53651 .41001 L F
.75 .648 .749 r
.53091 .39827 m .53436 .39894 L .53322 .39528 L F
.726 .323 .284 r
.53091 .39827 m .53289 .4009 L .53436 .39894 L F
.695 .284 .263 r
.53289 .4009 m .53717 .40137 L .53436 .39894 L F
.642 .322 .414 r
.53436 .39894 m .53717 .40137 L .53755 .39907 L F
.679 .865 .97 r
.5529 .38914 m .55712 .38932 L .55567 .38783 L F
.398 .19 .477 r
.55991 .38532 m .55972 .38805 L .55712 .38932 L F
.624 .863 .988 r
.55712 .38932 m .55972 .38805 L .55567 .38783 L F
.664 .473 .616 r
.43832 .48834 m .4429 .48863 L .44133 .48503 L F
.658 .513 .676 r
.44133 .48503 m .44536 .48518 L .4441 .4815 L F
.708 .492 .594 r
.44133 .48503 m .44529 .48816 L .44536 .48518 L F
.44133 .48503 m .4429 .48863 L .44529 .48816 L F
.761 .65 .739 r
.46629 .46772 m .47111 .46877 L .46901 .46423 L F
.939 .954 .755 r
.54833 .41886 m .54945 .41686 L .54897 .41448 L F
.389 .055 .274 r
.51067 .41187 m .5139 .40924 L .51097 .40998 L F
.493 0 0 r
.54551 .41907 m .54833 .41886 L .54774 .42074 L F
.939 .954 .755 r
.54833 .41886 m .54897 .41448 L .54837 .41818 L F
.738 .731 .208 r
.54774 .42074 m .54833 .41886 L .54837 .41818 L F
.507 .549 .834 r
.35307 .54283 m .35463 .5468 L .3572 .54625 L F
.994 .749 .408 r
.55846 .38395 m .55972 .38805 L .55991 .38532 L F
.45 .369 .674 r
.59554 .36748 m .59853 .36711 L .59747 .36383 L F
.228 .159 .567 r
.59554 .36748 m .59793 .36945 L .59853 .36711 L F
.59554 .36748 m .59546 .37183 L .59793 .36945 L F
.669 .52 .672 r
.4441 .4815 m .44536 .48518 L .44813 .48182 L F
.921 .783 .691 r
.39577 .54562 m .39404 .54971 L .39533 .5482 L F
.67 .471 .607 r
.39713 .54735 m .39404 .54971 L .39577 .54562 L F
.269 0 .253 r
.40002 .54267 m .39577 .54562 L .3953 .54271 L F
.40002 .54267 m .4003 .54598 L .39577 .54562 L F
.324 .809 .793 r
.4003 .54598 m .39713 .54735 L .39577 .54562 L F
.699 .533 .659 r
.44962 .4749 m .4509 .47834 L .45366 .47484 L F
.372 .466 .827 r
.5307 .41871 m .53232 .42262 L .53401 .42199 L F
.349 .21 .547 r
.53232 .42262 m .53459 .42207 L .53401 .42199 L F
.666 .529 .688 r
.4552 .46734 m .45924 .46783 L .45779 .46396 L F
.665 .534 .695 r
.4552 .46734 m .45641 .47133 L .45924 .46783 L F
.334 0 .154 r
.50195 .41605 m .50766 .41475 L .50813 .41302 L F
.817 .619 .636 r
.50724 .418 m .50766 .41475 L .50195 .41605 L F
0 0 0 r
.52324 .42209 m .52578 .42032 L .5259 .4206 L F
.039 0 0 r
.52578 .42032 m .52887 .42024 L .5259 .4206 L F
.52615 .42019 m .5307 .41871 L .52887 .42024 L F
.372 .466 .827 r
.5307 .41871 m .53401 .42199 L .53322 .41819 L F
.032 0 0 r
.5307 .41871 m .53077 .41875 L .52887 .42024 L F
.53077 .41875 m .5318 .41931 L .53073 .41965 L F
.53077 .41875 m .53073 .41965 L .52887 .42024 L F
.57 .394 .604 r
.52617 .41708 m .52885 .41729 L .52941 .41525 L F
.553 .252 .411 r
.52617 .41708 m .52885 .41729 L .52886 .4187 L F
.52797 .41918 m .52886 .4187 L .52887 .42024 L F
.52617 .41708 m .52886 .4187 L .52797 .41918 L F
.039 0 0 r
.52578 .42032 m .52615 .42019 L .52887 .42024 L F
.341 .185 .518 r
.5259 .4206 m .52336 .41897 L .52617 .41708 L F
.553 .252 .411 r
.52617 .41708 m .52887 .42024 L .5259 .4206 L F
.728 .21 0 r
.52663 .41213 m .52941 .41525 L .52739 .41403 L F
.187 .415 .85 r
.52739 .41403 m .52885 .41729 L .53021 .41548 L F
.582 .474 .696 r
.52848 .41589 m .52614 .42017 L .52456 .41899 L F
.52614 .42017 m .5259 .4206 L .52573 .42039 L F
.52614 .42017 m .52573 .42039 L .52456 .41899 L F
0 0 .203 r
.52955 .41781 m .52885 .41729 L .52887 .42024 L F
.53021 .41548 m .52921 .41681 L .52955 .41781 L F
.52921 .41681 m .52885 .41729 L .52955 .41781 L F
.032 0 0 r
.5307 .41871 m .53322 .41819 L .5318 .41931 L F
0 0 .203 r
.53021 .41548 m .52955 .41781 L .5318 .41931 L F
.52955 .41781 m .52887 .42024 L .53073 .41965 L F
.52955 .41781 m .53073 .41965 L .5318 .41931 L F
.054 .072 .559 r
.53077 .42027 m .52887 .42024 L .52848 .41589 L F
.743 .306 0 r
.52861 .41731 m .5301 .4194 L .52888 .41675 L F
.5285 .41616 m .52888 .41675 L .52848 .41589 L F
.52861 .41731 m .52888 .41675 L .5285 .41616 L F
.582 .474 .696 r
.52848 .41589 m .52887 .42024 L .5259 .4206 L F
.715 .596 .722 r
.52327 .41706 m .52122 .41675 L .52189 .41498 L F
.52456 .41899 m .52216 .41738 L .52327 .41706 L F
.52456 .41899 m .52327 .41706 L .52262 .41703 L F
.341 .185 .518 r
.5259 .4206 m .52324 .42209 L .52336 .41897 L F
.715 .596 .722 r
.52456 .41899 m .52208 .421 L .52122 .41675 L F
.706 .558 .684 r
.51864 .41504 m .51964 .42029 L .51508 .41852 L F
.303 .281 .669 r
.52122 .41675 m .51964 .42029 L .51864 .41504 L F
.677 .572 .729 r
.52122 .41675 m .51927 .4217 L .51964 .42029 L F
.52122 .41675 m .52208 .421 L .51927 .4217 L F
.152 0 0 r
.51885 .41765 m .52206 .4176 L .52262 .41703 L F
.508 .82 .5 r
.52262 .41703 m .52206 .4176 L .52211 .41754 L F
.715 .596 .722 r
.523 .41666 m .52189 .41498 L .52262 .41703 L F
.52216 .41738 m .52122 .41675 L .52327 .41706 L F
.508 .82 .5 r
.52262 .41703 m .52211 .41754 L .52422 .4154 L F
.715 .596 .722 r
.52327 .41706 m .523 .41666 L .52262 .41703 L F
.834 .908 .889 r
.52707 .41596 m .52262 .41703 L .52632 .416 L F
.52848 .41589 m .5249 .41659 L .52707 .41596 L F
.5249 .41659 m .52262 .41703 L .52707 .41596 L F
.52848 .41589 m .52456 .41899 L .52262 .41703 L F
.743 .306 0 r
.52728 .41546 m .52848 .41589 L .52665 .41598 L F
.52728 .41546 m .52665 .41598 L .52632 .416 L F
0 0 .187 r
.52771 .4151 m .52728 .41546 L .52772 .41493 L F
.743 .306 0 r
.52728 .41546 m .52861 .41731 L .52848 .41589 L F
.054 .072 .559 r
.53087 .42046 m .52887 .42024 L .53077 .42027 L F
0 0 0 r
.53038 .42074 m .52887 .42024 L .53087 .42046 L F
.915 .544 .31 r
.5318 .41931 m .53245 .42222 L .53038 .42074 L F
.776 .708 .788 r
.53079 .42035 m .53038 .42074 L .53087 .42046 L F
.52728 .41546 m .53038 .42074 L .53079 .42035 L F
0 .054 .598 r
.53401 .42199 m .5346 .42115 L .53322 .41819 L F
0 0 .535 r
.53459 .42207 m .5346 .42115 L .53401 .42199 L F
.53459 .42207 m .53598 .42297 L .5346 .42115 L F
.839 .491 .396 r
.53598 .42297 m .5318 .41931 L .5346 .42115 L F
.818 .885 .458 r
.53459 .42207 m .5317 .42865 L .53043 .42723 L F
.53459 .42207 m .53043 .42723 L .53367 .42448 L F
.026 0 0 r
.53459 .42207 m .53367 .42448 L .53598 .42297 L F
.839 .491 .396 r
.53598 .42297 m .53245 .42222 L .5318 .41931 L F
.915 .544 .31 r
.53185 .41934 m .53038 .42074 L .53275 .41989 L F
.5318 .41931 m .53038 .42074 L .53185 .41934 L F
.023 0 0 r
.52887 .42024 m .52538 .42317 L .5259 .4206 L F
.52887 .42024 m .52787 .4225 L .52538 .42317 L F
0 0 0 r
.53038 .42074 m .52787 .4225 L .52887 .42024 L F
.776 .708 .788 r
.52728 .41546 m .52601 .42106 L .53038 .42074 L F
0 0 .187 r
.5275 .41857 m .52728 .41546 L .52771 .4151 L F
.743 .306 0 r
.5301 .4194 m .53071 .42024 L .52974 .41836 L F
.5301 .4194 m .52974 .41836 L .52848 .41589 L F
.53071 .42024 m .53087 .42046 L .53071 .42016 L F
.53071 .42024 m .53071 .42016 L .52848 .41589 L F
.722 .566 .678 r
.4509 .47834 m .45378 .47787 L .45366 .47484 L F
.691 .572 .716 r
.45641 .47133 m .45366 .47484 L .45656 .47419 L F
.677 .528 .675 r
.45378 .47787 m .45656 .47419 L .45366 .47484 L F
.184 0 .179 r
.47515 .4409 m .47686 .44185 L .47742 .43993 L F
.47515 .4409 m .47446 .443 L .47686 .44185 L F
.491 .331 .591 r
.59473 .38194 m .59749 .38116 L .59642 .37781 L F
.622 .66 .866 r
.59642 .37781 m .59905 .37382 L .59621 .37427 L F
.59642 .37781 m .6014 .37717 L .59905 .37382 L F
.449 .193 .433 r
.59749 .38116 m .6014 .37717 L .59642 .37781 L F
0 .119 .651 r
.50922 .42461 m .50773 .42347 L .50907 .42193 L F
.024 0 0 r
.48936 .42645 m .49304 .42505 L .49308 .4241 L F
.037 0 .476 r
.48936 .42645 m .49138 .42766 L .49304 .42505 L F
.746 .59 .682 r
.45108 .48116 m .45522 .4848 L .45536 .482 L F
.45108 .48116 m .45252 .48535 L .45522 .4848 L F
.778 .717 .795 r
.45536 .482 m .45522 .4848 L .45782 .4809 L F
.69 .65 .805 r
.45522 .4848 m .45944 .48511 L .45782 .4809 L F
.79 .668 .728 r
.44525 .49095 m .44961 .4915 L .44978 .48875 L F
.645 .439 .589 r
.41867 .49857 m .42298 .4983 L .42157 .49516 L F
.685 .484 .609 r
.42298 .4983 m .42564 .49524 L .42157 .49516 L F
.906 .943 .82 r
.54897 .41448 m .55206 .41332 L .55085 .41218 L F
.915 .533 .116 r
.38968 .54365 m .38836 .54285 L .38767 .54012 L F
.772 .697 .781 r
.47187 .46078 m .47657 .46167 L .47436 .45753 L F
.78 .7 .776 r
.47436 .45753 m .47657 .46167 L .47938 .4582 L F
.648 .451 .603 r
.43138 .49157 m .43547 .49165 L .43551 .48871 L F
.656 .458 .604 r
.43551 .48871 m .43547 .49165 L .43832 .48834 L F
.579 .159 .21 r
.3789 .501 m .38343 .49893 L .37937 .49904 L F
.3789 .501 m .38185 .50116 L .38343 .49893 L F
.699 .3 .287 r
.38343 .49893 m .38185 .50116 L .3859 .50127 L F
.664 .525 .685 r
.45779 .46396 m .46199 .46443 L .46044 .45999 L F
.664 .528 .688 r
.45779 .46396 m .45924 .46783 L .46199 .46443 L F
.886 .569 .444 r
.60286 .37959 m .60517 .38156 L .60473 .37831 L F
.539 .321 .532 r
.60473 .37831 m .60517 .38156 L .60681 .37849 L F
.212 .737 .81 r
.53783 .43372 m .53853 .43318 L .53728 .43283 L F
.53783 .43372 m .54081 .43321 L .53853 .43318 L F
.215 0 .155 r
.51231 .41898 m .50907 .42193 L .50987 .41996 L F
.792 .697 .76 r
.49957 .44263 m .50413 .44072 L .50252 .43965 L F
.511 .278 .497 r
.53717 .40137 m .54011 .39814 L .53755 .39907 L F
.326 0 .206 r
.33674 .51641 m .33955 .51566 L .34109 .51434 L F
.511 .413 .68 r
.33674 .51641 m .33732 .51911 L .33955 .51566 L F
.523 .424 .684 r
.59473 .38194 m .5979 .38374 L .59749 .38116 L F
.506 .431 .705 r
.59473 .38194 m .59545 .38485 L .5979 .38374 L F
.456 .298 .577 r
.38836 .54285 m .38534 .54049 L .38767 .54012 L F
.38836 .54285 m .38591 .54454 L .38534 .54049 L F
.677 .528 .675 r
.45378 .47787 m .45815 .47826 L .45656 .47419 L F
.689 .573 .72 r
.45656 .47419 m .45959 .47068 L .45641 .47133 L F
.45656 .47419 m .46072 .47474 L .45959 .47068 L F
.695 .537 .668 r
.45656 .47419 m .45815 .47826 L .46072 .47474 L F
.617 .335 .466 r
.59747 .36383 m .60017 .36371 L .60081 .36119 L F
.751 .469 .504 r
.60081 .36119 m .60435 .36346 L .60352 .35993 L F
.60081 .36119 m .60017 .36371 L .60435 .36346 L F
.214 0 0 r
.49308 .4241 m .49495 .42458 L .49541 .42269 L F
.49308 .4241 m .49304 .42505 L .49495 .42458 L F
.635 .651 .849 r
.39152 .55118 m .39546 .55393 L .39404 .54971 L F
.675 .606 .771 r
.39404 .54971 m .39546 .55393 L .39847 .55099 L F
.148 .129 .578 r
.53044 .42912 m .53072 .43419 L .53264 .43088 L F
.636 .501 .682 r
.46044 .45999 m .46495 .46116 L .46359 .45696 L F
.69 .539 .677 r
.46044 .45999 m .46479 .46377 L .46495 .46116 L F
.46044 .45999 m .46199 .46443 L .46479 .46377 L F
.293 0 0 r
.41032 .54225 m .40956 .54284 L .40691 .54256 L F
.475 .891 .793 r
.41032 .54225 m .41154 .54106 L .40956 .54284 L F
.41032 .54225 m .41416 .54027 L .41154 .54106 L F
.744 .825 .915 r
.38948 .55021 m .39093 .55287 L .39152 .55118 L F
.38948 .55021 m .38672 .55249 L .39093 .55287 L F
.817 .719 .757 r
.38672 .55249 m .38814 .55658 L .39093 .55287 L F
.78 .7 .776 r
.47436 .45753 m .47938 .4582 L .47716 .45637 L F
.778 .694 .771 r
.60605 .37064 m .6075 .37481 L .61028 .3713 L F
.745 .601 .698 r
.44529 .48816 m .44978 .48875 L .44814 .48479 L F
.79 .668 .728 r
.44525 .49095 m .44978 .48875 L .44529 .48816 L F
.699 .58 .718 r
.44814 .48479 m .44978 .48875 L .45252 .48535 L F
.824 .514 .464 r
.55603 .37977 m .55901 .37824 L .55618 .37725 L F
.55603 .37977 m .56002 .3805 L .55901 .37824 L F
.684 .562 .711 r
.45924 .46783 m .45641 .47133 L .45959 .47068 L F
.651 .608 .793 r
.34416 .5337 m .34854 .53676 L .34653 .53333 L F
.36 .518 .878 r
.34653 .53333 m .34854 .53676 L .34992 .53445 L F
.242 .362 .786 r
.34854 .53676 m .3515 .53882 L .34992 .53445 L F
.667 .518 .673 r
.45108 .48116 m .45378 .47787 L .4509 .47834 L F
.45108 .48116 m .45536 .482 L .45378 .47787 L F
.721 .545 .652 r
.45378 .47787 m .45782 .4809 L .45815 .47826 L F
.45378 .47787 m .45536 .482 L .45782 .4809 L F
.723 .605 .725 r
.4509 .47834 m .44813 .48182 L .45108 .48116 L F
.701 .566 .699 r
.44814 .48479 m .45108 .48116 L .44813 .48182 L F
.44814 .48479 m .45252 .48535 L .45108 .48116 L F
.687 .473 .591 r
.40172 .50165 m .4047 .50201 L .4046 .49866 L F
.643 .409 .549 r
.4047 .50201 m .40877 .49868 L .4046 .49866 L F
.655 .467 .618 r
.42855 .49496 m .43263 .49509 L .43138 .49157 L F
.658 .469 .617 r
.43138 .49157 m .43545 .49458 L .43547 .49165 L F
.43138 .49157 m .43263 .49509 L .43545 .49458 L F
.645 .58 .767 r
.53965 .39188 m .54374 .39205 L .54229 .3875 L F
.721 .595 .715 r
.44813 .48182 m .44536 .48518 L .44814 .48479 L F
.745 .601 .698 r
.44529 .48816 m .44814 .48479 L .44536 .48518 L F
.505 .477 .76 r
.59621 .37427 m .59793 .36945 L .59546 .37183 L F
0 0 0 r
.51627 .41069 m .5192 .41012 L .5214 .40949 L F
.499 .535 .825 r
.5214 .40949 m .52402 .40415 L .51992 .40469 L F
.5214 .40949 m .52368 .40926 L .52402 .40415 L F
.605 .315 .449 r
.60352 .35993 m .60768 .36066 L .60687 .35819 L F
.655 .342 .43 r
.60687 .35819 m .60768 .36066 L .60873 .35942 L F
.691 .507 .634 r
.43832 .48834 m .43547 .49165 L .43848 .49136 L F
.666 .49 .637 r
.43848 .49136 m .4429 .48863 L .43832 .48834 L F
.8 .967 .659 r
.54357 .43214 m .54657 .4289 L .54673 .42889 L F
.996 .855 .521 r
.54826 .40271 m .54764 .4051 L .54671 .40499 L F
.454 .021 .126 r
.54671 .40499 m .55151 .40385 L .54826 .40271 L F
.656 .553 .727 r
.45959 .47068 m .46072 .47474 L .46366 .47152 L F
.698 .557 .692 r
.35244 .50268 m .35247 .50564 L .35528 .50233 L F
.374 0 .192 r
.52642 .40189 m .52902 .40128 L .53091 .39827 L F
.672 .321 .372 r
.53091 .39827 m .52902 .40128 L .53289 .4009 L F
.054 .464 .883 r
.5347 .41282 m .53338 .41371 L .53232 .41117 L F
0 .019 .555 r
.53372 .40927 m .53508 .41349 L .53437 .40788 L F
.799 .683 .737 r
.53437 .40788 m .53508 .41349 L .53913 .40898 L F
.054 .464 .883 r
.5347 .41282 m .53658 .41474 L .53338 .41371 L F
.447 0 0 r
.53752 .41582 m .53338 .41371 L .53658 .41474 L F
.411 0 0 r
.53915 .41721 m .54053 .41611 L .53752 .41582 L F
.53915 .41721 m .53752 .41582 L .53658 .41474 L F
0 0 0 r
.34777 .50709 m .35033 .50652 L .35247 .50564 L F
.271 0 .015 r
.35033 .50652 m .35417 .5033 L .35247 .50564 L F
.35033 .50652 m .35039 .50651 L .35417 .5033 L F
.819 .992 .744 r
.35521 .50241 m .35247 .50564 L .35417 .5033 L F
.271 0 .015 r
.35039 .50651 m .35319 .50596 L .35417 .5033 L F
.819 .992 .744 r
.35528 .50233 m .35521 .50241 L .35417 .5033 L F
.237 0 0 r
.35417 .5033 m .35776 .50201 L .35528 .50233 L F
0 0 .053 r
.48896 .43374 m .49127 .43029 L .49086 .4336 L F
.599 .701 .915 r
.53072 .43419 m .53327 .43357 L .53264 .43088 L F
.647 .308 .383 r
.37189 .5009 m .37636 .49841 L .37218 .49886 L F
.37189 .5009 m .37462 .50132 L .37636 .49841 L F
.656 .318 .388 r
.37636 .49841 m .37462 .50132 L .3789 .501 L F
.681 .311 .339 r
.37636 .49841 m .3789 .501 L .37937 .49904 L F
.841 .906 .882 r
.50467 .43824 m .50954 .43648 L .50747 .43471 L F
.833 .806 .825 r
.50847 .43301 m .50954 .43648 L .51246 .43278 L F
.623 .383 .533 r
.48268 .4383 m .48581 .43571 L .48326 .43538 L F
.669 .513 .665 r
.45959 .47068 m .46366 .4681 L .45924 .46783 L F
.45959 .47068 m .46366 .47152 L .46366 .4681 L F
.518 .575 .852 r
.34416 .5337 m .34484 .52941 L .3425 .52978 L F
.34416 .5337 m .34653 .53333 L .34484 .52941 L F
.698 .577 .716 r
.45924 .46783 m .46366 .4681 L .46199 .46443 L F
.6 .527 .744 r
.33955 .51566 m .33732 .51911 L .34024 .51801 L F
.603 .456 .654 r
.33791 .52178 m .34024 .51801 L .33732 .51911 L F
.343 0 .157 r
.50813 .41302 m .50979 .41405 L .51067 .41187 L F
.50813 .41302 m .50766 .41475 L .50979 .41405 L F
.749 .578 .664 r
.46366 .4681 m .46619 .47015 L .46629 .46772 L F
.46366 .4681 m .46366 .47152 L .46619 .47015 L F
.594 .364 .538 r
.40224 .53656 m .40213 .5394 L .4001 .53915 L F
.765 .722 .812 r
.5979 .38374 m .59981 .38608 L .60181 .38419 L F
.493 0 0 r
.54551 .41907 m .54774 .42074 L .54604 .42298 L F
.643 .409 .549 r
.4047 .50201 m .40861 .5014 L .40877 .49868 L F
.664 .422 .544 r
.40861 .5014 m .41163 .49859 L .40877 .49868 L F
.887 .949 .595 r
.41903 .53219 m .41971 .52971 L .41739 .5309 L F
.894 .936 .834 r
.41903 .53219 m .41739 .5309 L .41449 .53481 L F
.606 .234 .311 r
.41739 .5309 m .41302 .53308 L .41449 .53481 L F
.41739 .5309 m .41897 .53181 L .41325 .53303 L F
.41739 .5309 m .41325 .53303 L .41302 .53308 L F
.887 .949 .595 r
.41971 .52971 m .42015 .52813 L .41739 .5309 L F
.41903 .53219 m .42022 .52915 L .42015 .52813 L F
.766 .684 .772 r
.38448 .55422 m .38814 .55658 L .38672 .55249 L F
.38448 .55422 m .38603 .55774 L .38814 .55658 L F
.729 .59 .701 r
.38603 .55774 m .38547 .5603 L .38814 .55658 L F
.071 0 0 r
.39713 .54735 m .39215 .54938 L .39404 .54971 L F
.39713 .54735 m .39524 .54879 L .39215 .54938 L F
.324 .809 .793 r
.4003 .54598 m .39699 .54687 L .39713 .54735 L F
.614 .896 .594 r
.39699 .54687 m .39524 .54879 L .39713 .54735 L F
.751 .649 .748 r
.43975 .49809 m .444 .49855 L .44248 .49445 L F
.754 .636 .73 r
.43975 .49809 m .44128 .50202 L .444 .49855 L F
.685 .484 .609 r
.42298 .4983 m .42561 .49821 L .42564 .49524 L F
.675 .476 .609 r
.42564 .49524 m .42851 .49798 L .42855 .49496 L F
.42564 .49524 m .42561 .49821 L .42851 .49798 L F
.4 .144 .407 r
.46558 .45029 m .46817 .4497 L .4684 .44678 L F
.518 .288 .505 r
.46817 .4497 m .47081 .44509 L .4684 .44678 L F
.614 .663 .874 r
.3656 .55131 m .37003 .5536 L .36813 .55076 L F
.51 .654 .924 r
.37003 .5536 m .37155 .55096 L .36813 .55076 L F
.37003 .5536 m .37261 .55314 L .37155 .55096 L F
.49 .33 .59 r
.46311 .45397 m .46584 .45328 L .46558 .45029 L F
.611 .556 .768 r
.46359 .45696 m .46584 .45328 L .46311 .45397 L F
.686 .572 .721 r
.46199 .46443 m .46366 .4681 L .46629 .46772 L F
.402 .2 .488 r
.50804 .42969 m .50566 .43388 L .50352 .42888 L F
.50804 .42969 m .50847 .43301 L .50566 .43388 L F
.449 .367 .672 r
.51058 .42867 m .51092 .43071 L .50804 .42969 L F
.611 .556 .768 r
.46359 .45696 m .46836 .45856 L .46584 .45328 L F
.681 .527 .67 r
.46359 .45696 m .46746 .46007 L .46836 .45856 L F
.46359 .45696 m .46495 .46116 L .46746 .46007 L F
.815 .494 .445 r
.60036 .3655 m .60435 .36346 L .60017 .36371 L F
.60036 .3655 m .60511 .36635 L .60435 .36346 L F
.581 .513 .743 r
.60352 .35993 m .60435 .36346 L .60768 .36066 L F
.686 .572 .721 r
.46199 .46443 m .46629 .46772 L .46479 .46377 L F
.671 .431 .548 r
.41151 .50142 m .4159 .49844 L .41163 .49859 L F
.664 .422 .544 r
.40861 .5014 m .41151 .50142 L .41163 .49859 L F
.258 .106 .476 r
.54229 .3875 m .54339 .38351 L .5413 .38488 L F
.705 .614 .752 r
.46479 .46377 m .46901 .46423 L .46746 .46007 L F
.712 .577 .701 r
.46479 .46377 m .46629 .46772 L .46901 .46423 L F
.69 .606 .757 r
.46746 .46007 m .46901 .46423 L .47187 .46078 L F
.709 .462 .55 r
.4159 .49844 m .41856 .50128 L .41867 .49857 L F
.662 .437 .568 r
.41856 .50128 m .42298 .4983 L .41867 .49857 L F
.766 .642 .725 r
.4369 .5015 m .44128 .50202 L .43975 .49809 L F
.762 .596 .672 r
.4369 .5015 m .44108 .50477 L .44128 .50202 L F
.719 .537 .643 r
.4429 .48863 m .44525 .49095 L .44529 .48816 L F
.721 .636 .763 r
.46495 .46116 m .46479 .46377 L .46746 .46007 L F
.686 .516 .651 r
.42851 .49798 m .43263 .49509 L .42855 .49496 L F
.714 .784 .907 r
.5979 .38374 m .60181 .38419 L .59972 .38213 L F
.694 .667 .819 r
.60181 .38419 m .60286 .37959 L .59972 .38213 L F
.60181 .38419 m .60517 .38156 L .60286 .37959 L F
.833 .806 .825 r
.50847 .43301 m .51246 .43278 L .51092 .43071 L F
.331 .462 .842 r
.53232 .41117 m .52897 .4095 L .53256 .40906 L F
.774 .842 .903 r
.48241 .4516 m .48006 .45326 L .48418 .45332 L F
.796 .845 .889 r
.48241 .4516 m .48418 .45332 L .48752 .45045 L F
.615 .581 .792 r
.50566 .43388 m .50127 .43044 L .50352 .42888 L F
.771 .923 .937 r
.4924 .44548 m .49701 .44413 L .49549 .44297 L F
.771 .902 .933 r
.49549 .44297 m .49701 .44413 L .49957 .44263 L F
.954 .708 .527 r
.52663 .41213 m .52479 .4084 L .52897 .4095 L F
.222 0 .013 r
.51992 .40469 m .52402 .40415 L .52358 .40279 L F
.435 .282 .574 r
.50847 .43301 m .50747 .43471 L .50566 .43388 L F
.671 .431 .548 r
.41151 .50142 m .41583 .50145 L .4159 .49844 L F
.709 .462 .55 r
.4159 .49844 m .41583 .50145 L .41856 .50128 L F
.954 .708 .527 r
.52663 .41213 m .52489 .41133 L .52479 .4084 L F
.728 .21 0 r
.52663 .41213 m .52459 .4133 L .52489 .41133 L F
.52663 .41213 m .52739 .41403 L .52459 .4133 L F
.794 .874 .906 r
.38948 .55021 m .39404 .54971 L .39215 .54938 L F
.38948 .55021 m .39152 .55118 L .39404 .54971 L F
.594 .644 .87 r
.3572 .54625 m .3621 .54921 L .35957 .54636 L F
.376 .552 .9 r
.3621 .54921 m .3622 .54548 L .35957 .54636 L F
.3621 .54921 m .36415 .54888 L .3622 .54548 L F
.666 .49 .637 r
.43848 .49136 m .44257 .49168 L .4429 .48863 L F
.719 .537 .643 r
.4429 .48863 m .44257 .49168 L .44525 .49095 L F
.71 .535 .65 r
.43545 .49458 m .43848 .49136 L .43547 .49165 L F
.618 .564 .771 r
.54229 .3875 m .54374 .39205 L .54532 .39069 L F
.515 .258 .464 r
.34211 .51145 m .34461 .51202 L .34548 .50757 L F
.384 .143 .42 r
.34548 .50757 m .34742 .51103 L .34777 .50709 L F
.34548 .50757 m .34461 .51202 L .34742 .51103 L F
.71 .535 .65 r
.43545 .49458 m .4399 .49528 L .43848 .49136 L F
.722 .541 .645 r
.43848 .49136 m .44248 .49445 L .44257 .49168 L F
.43848 .49136 m .4399 .49528 L .44248 .49445 L F
.949 .802 .663 r
.55243 .40818 m .55362 .40567 L .55151 .40385 L F
.169 0 .142 r
.52123 .41152 m .52114 .41382 L .51864 .41504 L F
.547 .117 .176 r
.52459 .4133 m .52114 .41382 L .52123 .41152 L F
.52 .352 .593 r
.46558 .45029 m .46866 .45252 L .46817 .4497 L F
.46558 .45029 m .46584 .45328 L .46866 .45252 L F
.681 .63 .792 r
.40002 .54267 m .40384 .54396 L .40186 .54468 L F
.354 0 0 r
.40691 .54256 m .40186 .54468 L .40384 .54396 L F
.771 .902 .933 r
.49549 .44297 m .49957 .44263 L .49818 .44171 L F
.798 .972 .909 r
.50146 .43913 m .49957 .44263 L .50252 .43965 L F
.50146 .43913 m .49818 .44171 L .49957 .44263 L F
.587 .47 .687 r
.40213 .5394 m .40002 .54267 L .4001 .53915 L F
.22 0 .013 r
.52358 .40279 m .52402 .40415 L .52598 .40291 L F
.212 0 0 r
.52358 .40279 m .52598 .40291 L .52642 .40189 L F
.505 .051 .107 r
.35776 .50201 m .36031 .50342 L .36182 .50114 L F
.809 .593 .61 r
.36031 .50342 m .36492 .5012 L .36182 .50114 L F
.831 .72 .742 r
.59905 .37382 m .60294 .37411 L .60189 .37275 L F
.59905 .37382 m .6014 .37717 L .60294 .37411 L F
.798 .947 .92 r
.60533 .37025 m .60294 .37411 L .60605 .37064 L F
.60533 .37025 m .60189 .37275 L .60294 .37411 L F
.836 .619 .609 r
.55603 .37977 m .55846 .38395 L .56002 .3805 L F
.736 .48 .542 r
.3859 .50127 m .39023 .50441 L .39034 .50193 L F
.599 .275 .392 r
.39023 .50441 m .3947 .50152 L .39034 .50193 L F
.933 .956 .769 r
.41416 .54027 m .41323 .53756 L .41154 .54106 L F
.505 .477 .76 r
.59621 .37427 m .59905 .37382 L .59793 .36945 L F
.521 .749 .979 r
.3656 .55131 m .36657 .54891 L .36415 .54888 L F
.3656 .55131 m .36813 .55076 L .36657 .54891 L F
.762 .596 .672 r
.4369 .5015 m .439 .50602 L .44108 .50477 L F
.829 .78 .805 r
.439 .50602 m .43842 .50775 L .44108 .50477 L F
.69 .357 .407 r
.39726 .50407 m .40172 .50165 L .39745 .50181 L F
.39726 .50407 m .40165 .50413 L .40172 .50165 L F
.653 .326 .407 r
.40165 .50413 m .40431 .50418 L .40172 .50165 L F
.663 .323 .387 r
.40172 .50165 m .40431 .50418 L .4047 .50201 L F
.532 .305 .516 r
.54339 .38351 m .54922 .38368 L .54719 .38202 L F
.54922 .38368 m .54931 .38346 L .54719 .38202 L F
.776 .574 .626 r
.54696 .3862 m .54806 .38651 L .54847 .38452 L F
.54931 .38346 m .55148 .3875 L .5494 .38324 L F
.54806 .38651 m .55053 .38722 L .54931 .38346 L F
.55053 .38722 m .55148 .3875 L .54931 .38346 L F
.384 .347 .695 r
.54719 .38202 m .54931 .38346 L .54893 .38227 L F
.459 .235 .486 r
.54339 .38351 m .54696 .3862 L .54922 .38368 L F
.776 .574 .626 r
.54806 .38651 m .5494 .38324 L .54893 .38227 L F
.384 .347 .695 r
.54931 .38346 m .54967 .38369 L .54893 .38227 L F
.615 .508 .708 r
.54893 .38227 m .55148 .3875 L .55388 .38589 L F
.459 .235 .486 r
.54922 .38368 m .54696 .3862 L .54967 .38369 L F
.776 .574 .626 r
.54696 .3862 m .54847 .38452 L .54893 .38227 L F
.532 .305 .516 r
.54922 .38368 m .54967 .38369 L .54931 .38346 L F
.459 .235 .486 r
.54339 .38351 m .54408 .38736 L .54696 .3862 L F
.681 .508 .646 r
.5497 .38087 m .55435 .37714 L .55025 .37799 L F
.422 .067 .255 r
.40186 .54468 m .4003 .54598 L .40002 .54267 L F
.363 .446 .812 r
.35307 .54283 m .35351 .53842 L .3515 .53882 L F
.35307 .54283 m .35517 .54247 L .35351 .53842 L F
.507 .549 .834 r
.35307 .54283 m .3572 .54625 L .35517 .54247 L F
.47 .297 .564 r
.33955 .51566 m .34211 .51145 L .34109 .51434 L F
.8 .995 .868 r
.42015 .52813 m .42452 .52574 L .4227 .52461 L F
.42015 .52813 m .42022 .52915 L .42452 .52574 L F
.788 .918 .926 r
.42796 .52313 m .4227 .52461 L .42452 .52574 L F
.766 .643 .726 r
.43423 .50498 m .43842 .50775 L .439 .50602 L F
.43423 .50498 m .43608 .50955 L .43842 .50775 L F
.762 .636 .721 r
.43608 .50955 m .43555 .5117 L .43842 .50775 L F
.599 .275 .392 r
.39023 .50441 m .39318 .50435 L .3947 .50152 L F
.614 .271 .364 r
.39318 .50435 m .39745 .50181 L .3947 .50152 L F
.805 .723 .774 r
.55567 .38783 m .55972 .38805 L .55846 .38395 L F
.76 .59 .666 r
.43545 .49458 m .43975 .49809 L .4399 .49528 L F
.43545 .49458 m .43739 .49879 L .43975 .49809 L F
.78 .664 .736 r
.43739 .49879 m .4369 .5015 L .43975 .49809 L F
.756 .655 .751 r
.4399 .49528 m .43975 .49809 L .44248 .49445 L F
.66 .571 .744 r
.46836 .45856 m .46746 .46007 L .47023 .45668 L F
.687 .612 .766 r
.46746 .46007 m .47187 .46078 L .47023 .45668 L F
.389 .055 .274 r
.51067 .41187 m .51346 .4113 L .5139 .40924 L F
.743 .625 .729 r
.44257 .49168 m .44248 .49445 L .44525 .49095 L F
.996 .855 .521 r
.54671 .40499 m .54764 .4051 L .54652 .40795 L F
.237 0 0 r
.35417 .5033 m .35586 .50385 L .35776 .50201 L F
.596 .253 .359 r
.35319 .50596 m .35586 .50385 L .35417 .5033 L F
.449 .193 .433 r
.59749 .38116 m .60076 .38049 L .6014 .37717 L F
.715 .438 .505 r
.6014 .37717 m .60076 .38049 L .60286 .37959 L F
.54 .139 .229 r
.59747 .36383 m .60036 .3655 L .60017 .36371 L F
.324 .294 .67 r
.59747 .36383 m .59853 .36711 L .60036 .3655 L F
.662 .437 .568 r
.41856 .50128 m .4229 .50163 L .42298 .4983 L F
.658 .433 .567 r
.42298 .4983 m .42554 .50101 L .42561 .49821 L F
.42298 .4983 m .4229 .50163 L .42554 .50101 L F
.724 .545 .647 r
.55435 .37714 m .55618 .37725 L .55677 .37419 L F
.686 .516 .651 r
.42851 .49798 m .43264 .49804 L .43263 .49509 L F
.667 .501 .65 r
.43263 .49509 m .43264 .49804 L .43545 .49458 L F
.699 .761 .9 r
.47294 .45572 m .47716 .45637 L .47598 .45303 L F
.762 .68 .772 r
.47294 .45572 m .47436 .45753 L .47716 .45637 L F
.761 .795 .881 r
.47598 .45303 m .47716 .45637 L .48006 .45326 L F
.603 .456 .654 r
.33791 .52178 m .34037 .52279 L .34024 .51801 L F
.576 .471 .698 r
.33791 .52178 m .34111 .52521 L .34037 .52279 L F
.33791 .52178 m .33825 .52616 L .34111 .52521 L F
.73 .633 .751 r
.47023 .45668 m .47187 .46078 L .47436 .45753 L F
.668 .384 .48 r
.40431 .50418 m .40861 .5014 L .4047 .50201 L F
.799 .683 .737 r
.53437 .40788 m .53913 .40898 L .53953 .41055 L F
0 0 0 r
.54006 .40907 m .53953 .41055 L .53913 .40898 L F
.54006 .40907 m .53913 .40898 L .54153 .40804 L F
.408 .22 .512 r
.54175 .40499 m .54161 .40801 L .53913 .40898 L F
.824 .492 .426 r
.53574 .40562 m .53953 .41055 L .54006 .40907 L F
.179 .322 .773 r
.53437 .40788 m .53953 .41055 L .53574 .40562 L F
.824 .492 .426 r
.53574 .40562 m .54006 .40907 L .53896 .40802 L F
.53786 .40714 m .53896 .40802 L .53852 .40761 L F
.53574 .40562 m .53896 .40802 L .53786 .40714 L F
0 0 0 r
.54006 .40907 m .54153 .40804 L .54161 .40801 L F
.296 .787 .889 r
.54498 .40874 m .54006 .40907 L .54161 .40801 L F
.854 .911 .872 r
.53852 .40761 m .54006 .40907 L .53913 .40786 L F
.726 .606 .723 r
.53919 .40821 m .54337 .40845 L .53913 .40786 L F
.992 .735 .41 r
.53896 .40802 m .5397 .41146 L .53852 .40761 L F
.54006 .40907 m .5397 .41146 L .53896 .40802 L F
.726 .606 .723 r
.5397 .41146 m .53939 .40954 L .54006 .40907 L F
.53939 .40954 m .53913 .40786 L .54006 .40907 L F
.296 .787 .889 r
.54498 .40874 m .54337 .40845 L .54006 .40907 L F
.445 .166 .395 r
.54006 .40907 m .54337 .40845 L .5397 .41146 L F
.726 .606 .723 r
.5397 .41146 m .54144 .41003 L .53919 .40821 L F
.54144 .41003 m .54337 .40845 L .53919 .40821 L F
.467 .183 .398 r
.49495 .42458 m .498 .42166 L .49541 .42269 L F
.717 .504 .6 r
.42554 .50101 m .42851 .49798 L .42561 .49821 L F
.39 .85 .837 r
.54081 .43321 m .54108 .43243 L .53853 .43318 L F
.54081 .43321 m .54357 .43214 L .54108 .43243 L F
.364 .528 .885 r
.53264 .43088 m .53327 .43357 L .53728 .43283 L F
.668 .847 .968 r
.54791 .38921 m .5529 .38914 L .55148 .3875 L F
.752 .891 .941 r
.55388 .38589 m .5529 .38914 L .55567 .38783 L F
.55388 .38589 m .55148 .3875 L .5529 .38914 L F
.796 .845 .889 r
.48241 .4516 m .48752 .45045 L .48571 .44909 L F
.879 .891 .838 r
.48571 .44909 m .48752 .45045 L .49015 .44703 L F
.614 .271 .364 r
.39318 .50435 m .39726 .50407 L .39745 .50181 L F
.518 .288 .505 r
.46817 .4497 m .47111 .44944 L .47081 .44509 L F
.59 .341 .508 r
.47081 .44509 m .47435 .44822 L .47437 .44435 L F
.47081 .44509 m .47111 .44944 L .47435 .44822 L F
0 0 .325 r
.60742 .36567 m .60752 .36845 L .60605 .37064 L F
.68 .979 .859 r
.60752 .36845 m .60533 .37025 L .60605 .37064 L F
.355 .452 .822 r
.3572 .54625 m .35764 .542 L .35517 .54247 L F
.3572 .54625 m .35957 .54636 L .35764 .542 L F
.108 .661 .724 r
.54371 .41568 m .54381 .41569 L .54053 .41611 L F
.54371 .41568 m .54053 .41611 L .53915 .41721 L F
.411 .332 .657 r
.34024 .51801 m .3423 .51491 L .33955 .51566 L F
.34024 .51801 m .34244 .51762 L .3423 .51491 L F
.516 .421 .685 r
.34037 .52279 m .34244 .51762 L .34024 .51801 L F
.782 .656 .724 r
.43128 .51122 m .43555 .5117 L .43608 .50955 L F
.784 .646 .71 r
.43128 .51122 m .43308 .5128 L .43555 .5117 L F
.9 .822 .76 r
.4285 .51764 m .43095 .51946 L .43308 .5128 L F
.911 .815 .739 r
.4285 .51764 m .42845 .52079 L .43095 .51946 L F
.766 .643 .726 r
.43393 .50768 m .43608 .50955 L .43423 .50498 L F
.782 .656 .724 r
.43128 .51122 m .43608 .50955 L .43393 .50768 L F
.513 .417 .683 r
.59749 .38116 m .59972 .38213 L .60076 .38049 L F
.59749 .38116 m .5979 .38374 L .59972 .38213 L F
.667 .582 .751 r
.46584 .45328 m .46836 .45856 L .47023 .45668 L F
.748 .633 .733 r
.4327 .50109 m .4369 .5015 L .43739 .49879 L F
.753 .595 .682 r
.4327 .50109 m .43423 .50498 L .4369 .5015 L F
.749 .591 .679 r
.43423 .50498 m .439 .50602 L .4369 .5015 L F
.717 .504 .6 r
.42554 .50101 m .43001 .50158 L .42851 .49798 L F
.733 .511 .591 r
.42851 .49798 m .4327 .50109 L .43264 .49804 L F
.42851 .49798 m .43001 .50158 L .4327 .50109 L F
.716 .571 .691 r
.43264 .49804 m .43739 .49879 L .43545 .49458 L F
.791 .921 .924 r
.4227 .52461 m .42633 .52159 L .42206 .52115 L F
.4227 .52461 m .42312 .52346 L .42633 .52159 L F
.788 .918 .926 r
.42796 .52313 m .42312 .52346 L .4227 .52461 L F
.792 .916 .923 r
.42633 .52159 m .42796 .52313 L .42845 .52079 L F
.42633 .52159 m .42312 .52346 L .42796 .52313 L F
.73 .633 .751 r
.47023 .45668 m .47436 .45753 L .47294 .45572 L F
.618 .564 .771 r
.54229 .3875 m .54532 .39069 L .54408 .38736 L F
.47 .297 .564 r
.33955 .51566 m .3423 .51491 L .34211 .51145 L F
.511 .278 .497 r
.53717 .40137 m .54009 .40081 L .54011 .39814 L F
.568 .322 .504 r
.54011 .39814 m .54009 .40081 L .54303 .39841 L F
.679 .717 .878 r
.54408 .38736 m .54532 .39069 L .54791 .38921 L F
.367 0 .164 r
.47686 .44185 m .48065 .43948 L .47742 .43993 L F
.879 .891 .838 r
.48571 .44909 m .49015 .44703 L .48672 .44683 L F
.687 .944 .961 r
.4924 .44548 m .48672 .44683 L .49015 .44703 L F
.357 .069 .332 r
.54443 .40501 m .54175 .40499 L .54509 .40222 L F
.609 .526 .735 r
.54443 .40501 m .54161 .40801 L .54175 .40499 L F
0 .005 .538 r
.52402 .40415 m .52368 .40926 L .52515 .40557 L F
.668 .384 .48 r
.40431 .50418 m .40861 .50413 L .40861 .5014 L F
.695 .433 .523 r
.40861 .50413 m .41151 .50142 L .40861 .5014 L F
.643 .935 .679 r
.51089 .41973 m .50907 .42193 L .51231 .41898 L F
.56 0 0 r
.51231 .41898 m .51478 .42054 L .51089 .41973 L F
.473 .209 .432 r
.51508 .41852 m .51478 .42054 L .51231 .41898 L F
.993 .746 .405 r
.51089 .41973 m .51231 .41898 L .5103 .41759 L F
.46 .423 .731 r
.3425 .52978 m .34392 .52459 L .34111 .52521 L F
.3425 .52978 m .34484 .52941 L .34392 .52459 L F
.202 0 .226 r
.38836 .54285 m .38519 .54596 L .38591 .54454 L F
.748 .633 .733 r
.4327 .50109 m .43739 .49879 L .43264 .49804 L F
.798 .798 .853 r
.38231 .55234 m .38448 .55422 L .38672 .55249 L F
.475 .549 .853 r
.34484 .52941 m .34653 .53333 L .34849 .53081 L F
.431 .487 .816 r
.34653 .53333 m .34992 .53445 L .34849 .53081 L F
.687 .965 .937 r
.50467 .43824 m .50372 .43745 L .50252 .43965 L F
.696 .973 .923 r
.50372 .43745 m .50146 .43913 L .50252 .43965 L F
.587 .385 .575 r
.34211 .51145 m .34518 .51409 L .34461 .51202 L F
.34211 .51145 m .3423 .51491 L .34518 .51409 L F
.769 .833 .902 r
.38497 .55051 m .38231 .55234 L .38672 .55249 L F
.745 .827 .915 r
.38497 .55051 m .38672 .55249 L .38948 .55021 L F
.518 .429 .694 r
.55435 .37714 m .55603 .37977 L .55618 .37725 L F
.499 .066 .148 r
.35776 .50201 m .35586 .50385 L .36031 .50342 L F
.263 0 .163 r
.50979 .41405 m .51346 .4113 L .51067 .41187 L F
0 0 0 r
.54509 .40222 m .54758 .39814 L .54607 .40098 L F
.872 .784 .288 r
.54458 .40175 m .54509 .40222 L .54607 .40098 L F
.54458 .40175 m .54443 .40501 L .54509 .40222 L F
.661 .526 .688 r
.53289 .4009 m .53678 .40389 L .53717 .40137 L F
.089 0 .046 r
.53678 .40389 m .54009 .40081 L .53717 .40137 L F
.734 .533 .62 r
.41133 .50414 m .41583 .50145 L .41151 .50142 L F
.695 .433 .523 r
.40861 .50413 m .41133 .50414 L .41151 .50142 L F
.758 .574 .648 r
.54607 .40098 m .54758 .39814 L .54303 .39841 L F
.681 .508 .646 r
.5497 .38087 m .55602 .38092 L .55435 .37714 L F
.518 .429 .694 r
.55435 .37714 m .55602 .38092 L .55603 .37977 L F
.508 .285 .512 r
.47437 .44435 m .47686 .44185 L .47446 .443 L F
.964 .806 .638 r
.55064 .40694 m .55243 .40818 L .55151 .40385 L F
.945 .837 .707 r
.55085 .41218 m .55243 .40818 L .55064 .40694 L F
.667 .582 .751 r
.46584 .45328 m .47023 .45668 L .46866 .45252 L F
.403 .255 .563 r
.59793 .36945 m .60036 .3655 L .59853 .36711 L F
.723 .523 .62 r
.41583 .50145 m .41572 .50441 L .41856 .50128 L F
.71 .505 .609 r
.41856 .50128 m .41572 .50441 L .41852 .50429 L F
.708 .552 .675 r
.41852 .50429 m .4229 .50163 L .41856 .50128 L F
.706 .652 .794 r
.46866 .45252 m .47023 .45668 L .47294 .45572 L F
.562 .564 .814 r
.51089 .41973 m .50922 .42461 L .50907 .42193 L F
.822 .506 .454 r
.38185 .50116 m .38342 .50348 L .3859 .50127 L F
.771 .508 .538 r
.38342 .50348 m .38601 .50452 L .3859 .50127 L F
.736 .48 .542 r
.3859 .50127 m .38601 .50452 L .39023 .50441 L F
.758 .587 .664 r
.42985 .50441 m .43393 .50768 L .43423 .50498 L F
.42985 .50441 m .43171 .50852 L .43393 .50768 L F
.775 .636 .708 r
.43171 .50852 m .43128 .51122 L .43393 .50768 L F
.685 .752 .902 r
.37155 .55096 m .37261 .55314 L .37516 .55179 L F
.399 .035 .226 r
.54719 .38202 m .54893 .38227 L .5497 .38087 L F
.803 .64 .68 r
.43128 .51122 m .42923 .51416 L .43308 .5128 L F
.9 .822 .76 r
.4285 .51764 m .43308 .5128 L .42923 .51416 L F
.765 .65 .734 r
.43001 .50158 m .42985 .50441 L .4327 .50109 L F
.721 .58 .697 r
.42985 .50441 m .43423 .50498 L .4327 .50109 L F
.502 .634 .912 r
.37972 .55277 m .38097 .5503 L .3781 .55037 L F
.37972 .55277 m .38231 .55234 L .38097 .5503 L F
.354 0 0 r
.40691 .54256 m .40466 .54451 L .40186 .54468 L F
0 0 0 r
.4079 .54181 m .40691 .54256 L .40956 .54284 L F
.4079 .54181 m .40466 .54451 L .40691 .54256 L F
.516 .421 .685 r
.34037 .52279 m .34343 .52249 L .34244 .51762 L F
.565 .46 .693 r
.34037 .52279 m .34392 .52459 L .34343 .52249 L F
.34037 .52279 m .34111 .52521 L .34392 .52459 L F
.429 .027 .173 r
.52598 .40291 m .52902 .40128 L .52642 .40189 L F
.664 .149 .007 r
.60036 .3655 m .60323 .36775 L .60511 .36635 L F
.734 .533 .62 r
.41133 .50414 m .41572 .50441 L .41583 .50145 L F
.706 .652 .794 r
.46866 .45252 m .47294 .45572 L .47345 .45442 L F
.656 .673 .854 r
.47345 .45442 m .47294 .45572 L .47598 .45303 L F
.696 .435 .525 r
.54893 .38227 m .55602 .38092 L .5497 .38087 L F
.736 .624 .735 r
.42549 .50396 m .42985 .50441 L .43001 .50158 L F
.74 .601 .703 r
.42549 .50396 m .42701 .50789 L .42985 .50441 L F
.719 .571 .686 r
.42701 .50789 m .43171 .50852 L .42985 .50441 L F
.687 .944 .961 r
.4924 .44548 m .49116 .44458 L .48672 .44683 L F
.845 .975 .874 r
.4941 .44156 m .4924 .44548 L .49549 .44297 L F
.4941 .44156 m .49116 .44458 L .4924 .44548 L F
.397 .489 .836 r
.3515 .53882 m .35189 .53437 L .34992 .53445 L F
.3515 .53882 m .35351 .53842 L .35189 .53437 L F
.557 .43 .663 r
.51377 .42575 m .51058 .42867 L .50922 .42461 L F
.51377 .42575 m .51354 .42809 L .51058 .42867 L F
.471 .383 .674 r
.51318 .42944 m .51058 .42867 L .51354 .42809 L F
.51318 .42944 m .51092 .43071 L .51058 .42867 L F
.896 .985 .728 r
.50847 .43301 m .50656 .434 L .50747 .43471 L F
.872 .992 .809 r
.50656 .434 m .50467 .43824 L .50747 .43471 L F
.839 .852 .854 r
.60076 .38049 m .59972 .38213 L .60286 .37959 L F
.562 .564 .814 r
.51089 .41973 m .51179 .42413 L .50922 .42461 L F
.563 .605 .853 r
.51179 .42413 m .51377 .42575 L .50922 .42461 L F
.809 .593 .61 r
.36031 .50342 m .3648 .50425 L .36492 .5012 L F
.361 .044 .286 r
.3648 .50425 m .36756 .50151 L .36492 .5012 L F
.493 .659 .934 r
.36813 .55076 m .3692 .54793 L .36657 .54891 L F
.36813 .55076 m .37155 .55096 L .3692 .54793 L F
.748 .61 .705 r
.42689 .51097 m .43171 .50852 L .42701 .50789 L F
.42689 .51097 m .43128 .51122 L .43171 .50852 L F
.462 .048 .166 r
.36739 .50355 m .37189 .5009 L .36756 .50151 L F
.36739 .50355 m .37009 .50332 L .37189 .5009 L F
.644 .252 .286 r
.37189 .5009 m .37009 .50332 L .37439 .50328 L F
.634 .256 .31 r
.37189 .5009 m .37439 .50328 L .37462 .50132 L F
.679 .717 .878 r
.54408 .38736 m .54791 .38921 L .54696 .3862 L F
.642 .728 .911 r
.54696 .3862 m .54791 .38921 L .55148 .3875 L F
.761 .795 .881 r
.47598 .45303 m .48006 .45326 L .47842 .45123 L F
.754 .77 .866 r
.47842 .45123 m .48006 .45326 L .48241 .4516 L F
.736 .624 .735 r
.42549 .50396 m .43001 .50158 L .42554 .50101 L F
.708 .552 .675 r
.41852 .50429 m .42275 .50446 L .4229 .50163 L F
.692 .538 .674 r
.4229 .50163 m .42275 .50446 L .42554 .50101 L F
.701 .554 .684 r
.42689 .51097 m .42923 .51416 L .43128 .51122 L F
.544 .408 .645 r
.46817 .4497 m .46866 .45252 L .47111 .44944 L F
.361 .044 .286 r
.3648 .50425 m .36739 .50355 L .36756 .50151 L F
.878 .696 .653 r
.52871 .40285 m .53289 .4009 L .52902 .40128 L F
.52871 .40285 m .53287 .40462 L .53289 .4009 L F
.693 .544 .679 r
.53287 .40462 m .53417 .40504 L .53289 .4009 L F
.661 .526 .688 r
.53289 .4009 m .53417 .40504 L .53678 .40389 L F
.945 .837 .707 r
.55085 .41218 m .55064 .40694 L .55 .40932 L F
.893 .884 .817 r
.54897 .41448 m .55085 .41218 L .55 .40932 L F
.712 .568 .691 r
.42554 .50101 m .42275 .50446 L .42549 .50396 L F
.872 .992 .809 r
.50656 .434 m .50372 .43745 L .50467 .43824 L F
.735 .979 .744 r
.50843 .43186 m .50847 .43301 L .51092 .43071 L F
0 0 0 r
.51243 .4304 m .51092 .43071 L .51318 .42944 L F
.51243 .4304 m .50843 .43186 L .51092 .43071 L F
.696 .435 .525 r
.54893 .38227 m .55426 .38313 L .55602 .38092 L F
.892 .736 .682 r
.55602 .38092 m .55426 .38313 L .55603 .37977 L F
.804 .613 .644 r
.55426 .38313 m .55846 .38395 L .55603 .37977 L F
.867 .831 .809 r
.55388 .38589 m .55846 .38395 L .55426 .38313 L F
.55388 .38589 m .55567 .38783 L .55846 .38395 L F
.755 .609 .695 r
.4227 .50744 m .42701 .50789 L .42549 .50396 L F
.74 .584 .681 r
.4227 .50744 m .42689 .51097 L .42701 .50789 L F
.631 .253 .31 r
.37462 .50132 m .37929 .50287 L .3789 .501 L F
.695 .304 .303 r
.37929 .50287 m .38125 .50361 L .3789 .501 L F
.634 .313 .41 r
.3789 .501 m .38125 .50361 L .38185 .50116 L F
.735 .979 .744 r
.50843 .43186 m .50656 .434 L .50847 .43301 L F
.758 .574 .648 r
.54607 .40098 m .54303 .39841 L .54551 .3992 L F
.525 .261 .456 r
.54009 .40081 m .54537 .40025 L .54303 .39841 L F
.194 .284 .729 r
.54303 .39841 m .54537 .40025 L .54551 .3992 L F
.727 .981 .911 r
.53956 .40313 m .54537 .40025 L .54058 .40076 L F
.53956 .40313 m .54058 .40076 L .54009 .40081 L F
0 0 0 r
.53956 .40313 m .5388 .40487 L .53883 .40483 L F
.727 .981 .911 r
.53956 .40313 m .54134 .40128 L .54537 .40025 L F
0 0 0 r
.53956 .40313 m .53883 .40483 L .54134 .40128 L F
.895 .659 .575 r
.54537 .40025 m .54134 .40128 L .54458 .40175 L F
.54537 .40025 m .54458 .40175 L .54551 .3992 L F
.872 .784 .288 r
.54458 .40175 m .54607 .40098 L .54551 .3992 L F
.443 .201 .451 r
.34777 .50709 m .35027 .50991 L .35033 .50652 L F
.34777 .50709 m .34742 .51103 L .35027 .50991 L F
.303 .281 .669 r
.52122 .41675 m .51864 .41504 L .52114 .41382 L F
.913 .928 .808 r
.53095 .40966 m .53232 .41117 L .53437 .40788 L F
.669 .132 0 r
.53095 .40966 m .5347 .41282 L .53232 .41117 L F
.817 .619 .636 r
.50724 .418 m .50775 .41791 L .50766 .41475 L F
.352 .253 .601 r
.50766 .41475 m .5103 .41759 L .50979 .41405 L F
.50766 .41475 m .50775 .41791 L .5103 .41759 L F
.907 .502 .203 r
.53322 .41819 m .5346 .42115 L .5318 .41931 L F
.525 .378 .623 r
.53322 .41819 m .5346 .42115 L .536 .41749 L F
.755 .609 .695 r
.4227 .50744 m .42549 .50396 L .42275 .50446 L F
.591 .534 .759 r
.59793 .36945 m .59905 .37382 L .60189 .37275 L F
.544 .847 .998 r
.54595 .41406 m .54897 .41448 L .54862 .41305 L F
.961 .81 .647 r
.54605 .41612 m .54897 .41448 L .54595 .41406 L F
.54605 .41612 m .54837 .41818 L .54897 .41448 L F
.893 .884 .817 r
.54897 .41448 m .55 .40932 L .54862 .41305 L F
.467 .183 .398 r
.49495 .42458 m .49745 .42427 L .498 .42166 L F
.417 .15 .398 r
.49745 .42427 m .50068 .42085 L .498 .42166 L F
.706 .491 .594 r
.41572 .50441 m .41843 .50724 L .41852 .50429 L F
.746 .568 .654 r
.41843 .50724 m .42275 .50446 L .41852 .50429 L F
.41843 .50724 m .4227 .50744 L .42275 .50446 L F
.658 .239 .237 r
.38601 .50452 m .38983 .50617 L .39023 .50441 L F
.687 .295 .298 r
.38983 .50617 m .39275 .50686 L .39023 .50441 L F
.613 .319 .446 r
.39023 .50441 m .39275 .50686 L .39318 .50435 L F
.367 0 .164 r
.47686 .44185 m .47969 .44124 L .48065 .43948 L F
.821 .696 .727 r
.47969 .44124 m .48268 .4383 L .48065 .43948 L F
.396 .463 .812 r
.36415 .54888 m .36482 .54447 L .3622 .54548 L F
.36415 .54888 m .36657 .54891 L .36482 .54447 L F
.609 .526 .735 r
.54443 .40501 m .54527 .40831 L .54161 .40801 L F
.36 0 0 r
.54527 .40831 m .54498 .40874 L .54161 .40801 L F
.788 .4 .319 r
.53506 .40487 m .53557 .40503 L .53473 .40491 L F
.552 .463 .708 r
.53557 .40503 m .53437 .40788 L .53417 .40504 L F
.913 .928 .808 r
.53464 .40596 m .53437 .40788 L .53557 .40503 L F
0 0 .5 r
.53417 .40504 m .53437 .40788 L .53464 .40596 L F
.53417 .40504 m .53474 .4053 L .53472 .40524 L F
.53438 .40494 m .53627 .40474 L .53678 .40389 L F
.788 .4 .319 r
.52871 .40285 m .53506 .40487 L .53287 .40462 L F
.53506 .40487 m .53473 .40491 L .53287 .40462 L F
.552 .463 .708 r
.53557 .40503 m .53417 .40504 L .53287 .40462 L F
.655 .385 .499 r
.52515 .40557 m .53056 .40558 L .52871 .40285 L F
.788 .4 .319 r
.52871 .40285 m .53012 .40493 L .53472 .40524 L F
.52984 .40491 m .53114 .40612 L .53472 .40524 L F
.655 .385 .499 r
.53056 .40558 m .53064 .40558 L .52871 .40285 L F
.788 .4 .319 r
.52871 .40285 m .52984 .40491 L .53012 .40493 L F
.684 .444 .552 r
.52515 .40557 m .52981 .40777 L .53062 .40563 L F
.52515 .40557 m .53062 .40563 L .53056 .40558 L F
.788 .4 .319 r
.52984 .40491 m .53058 .40626 L .53114 .40612 L F
.684 .444 .552 r
.53056 .40558 m .53062 .40563 L .53064 .40558 L F
.52981 .40777 m .53075 .40821 L .53069 .40668 L F
.52981 .40777 m .53069 .40668 L .53064 .40558 L F
0 0 .53 r
.53106 .40622 m .53095 .40966 L .53464 .40596 L F
.067 .072 .554 r
.53069 .40668 m .53058 .40626 L .53064 .40558 L F
0 0 .53 r
.53058 .40626 m .53064 .40674 L .53069 .40668 L F
.53064 .40674 m .53095 .40966 L .53106 .40622 L F
.067 .072 .554 r
.53069 .40689 m .53058 .40626 L .53069 .40668 L F
0 0 .53 r
.53058 .40626 m .53144 .40773 L .53109 .40913 L F
.53058 .40626 m .53109 .40913 L .53095 .40966 L F
.067 .072 .554 r
.53075 .40821 m .53058 .40626 L .53069 .40689 L F
0 0 .53 r
.53058 .40626 m .53069 .40668 L .53106 .40622 L F
.53472 .40524 m .53464 .40596 L .53557 .40503 L F
0 0 .5 r
.53417 .40504 m .53464 .40596 L .53471 .40529 L F
0 0 .53 r
.53058 .40626 m .53464 .40596 L .53472 .40524 L F
0 0 .5 r
.53471 .40529 m .53464 .40596 L .53474 .4053 L F
.53472 .40524 m .53474 .4053 L .53475 .40525 L F
.53501 .40492 m .53574 .40562 L .53627 .40474 L F
.53417 .40504 m .53472 .40524 L .53501 .40492 L F
.788 .4 .319 r
.53506 .40487 m .53472 .40524 L .53557 .40503 L F
.53472 .40524 m .53472 .40524 L .53506 .40487 L F
0 0 .5 r
.53472 .40524 m .53574 .40562 L .53501 .40492 L F
.53417 .40504 m .53627 .40474 L .53438 .40494 L F
.788 .4 .319 r
.5345 .40469 m .53472 .40524 L .53506 .40487 L F
.52871 .40285 m .53472 .40524 L .5345 .40469 L F
.913 .928 .808 r
.53095 .40966 m .53437 .40788 L .53464 .40596 L F
0 0 .5 r
.53475 .40525 m .53437 .40788 L .53574 .40562 L F
.821 .696 .727 r
.47969 .44124 m .48445 .44208 L .48268 .4383 L F
.511 .288 .512 r
.47686 .44185 m .47657 .44464 L .48134 .4424 L F
.816 .741 .781 r
.48134 .4424 m .48123 .44818 L .48501 .44485 L F
.957 .624 .331 r
.48238 .44329 m .48137 .44242 L .48134 .4424 L F
.816 .741 .781 r
.48134 .4424 m .48134 .4424 L .48238 .44329 L F
.48134 .4424 m .48501 .44485 L .48238 .44329 L F
.957 .624 .331 r
.48238 .44329 m .4825 .44322 L .48137 .44242 L F
.511 .288 .512 r
.47686 .44185 m .48134 .4424 L .47969 .44124 L F
.957 .624 .331 r
.48118 .44237 m .48134 .4424 L .47969 .44124 L F
.48238 .44329 m .48134 .4424 L .48118 .44237 L F
.4825 .44322 m .48445 .44208 L .47971 .44125 L F
.4825 .44322 m .47971 .44125 L .47969 .44124 L F
.48238 .44329 m .48501 .44485 L .48445 .44208 L F
.479 .46 .759 r
.48445 .44208 m .48618 .43877 L .48268 .4383 L F
.48445 .44208 m .48694 .44141 L .48618 .43877 L F
.204 .031 .411 r
.48501 .44485 m .48694 .44141 L .48445 .44208 L F
.797 .998 .797 r
.54357 .43214 m .54673 .42889 L .54442 .42967 L F
.777 .995 .871 r
.54108 .43243 m .54357 .43214 L .54442 .42967 L F
0 0 .209 r
.54652 .40795 m .54638 .41128 L .54711 .40889 L F
.544 .847 .998 r
.54595 .41406 m .54862 .41305 L .54638 .41128 L F
.685 .752 .902 r
.37155 .55096 m .37516 .55179 L .3738 .55023 L F
.676 .808 .946 r
.3738 .55023 m .37516 .55179 L .3781 .55037 L F
.667 .266 .276 r
.51964 .42029 m .51478 .42054 L .51508 .41852 L F
.739 .519 .595 r
.41121 .50706 m .41572 .50441 L .41133 .50414 L F
.41121 .50706 m .41562 .50735 L .41572 .50441 L F
.706 .491 .594 r
.41572 .50441 m .41562 .50735 L .41843 .50724 L F
.631 .253 .31 r
.37462 .50132 m .37439 .50328 L .37929 .50287 L F
.694 .62 .769 r
.46866 .45252 m .47345 .45442 L .47111 .44944 L F
.6 .529 .746 r
.47345 .45442 m .47435 .44822 L .47111 .44944 L F
.47345 .45442 m .47598 .45303 L .47435 .44822 L F
.745 .827 .915 r
.38497 .55051 m .38948 .55021 L .38749 .54963 L F
.385 .83 .942 r
.39215 .54938 m .38749 .54963 L .38948 .55021 L F
.754 .77 .866 r
.47842 .45123 m .48241 .4516 L .48123 .44818 L F
.707 .701 .842 r
.48123 .44818 m .48241 .4516 L .48571 .44909 L F
.527 .247 .432 r
.49304 .42505 m .49274 .42651 L .49495 .42458 L F
.49304 .42505 m .49138 .42766 L .49274 .42651 L F
.501 .873 .66 r
.54595 .41406 m .54381 .41569 L .54371 .41568 L F
.822 .506 .454 r
.38185 .50116 m .38125 .50361 L .38342 .50348 L F
.089 0 .046 r
.53678 .40389 m .53956 .40313 L .54009 .40081 L F
.667 .266 .276 r
.51964 .42029 m .51927 .4217 L .51478 .42054 L F
.585 .443 .654 r
.34244 .51762 m .34518 .51409 L .3423 .51491 L F
.465 .717 .978 r
.53725 .41253 m .53658 .41474 L .5347 .41282 L F
0 0 .058 r
.53725 .4153 m .53658 .41474 L .53725 .41253 L F
.411 0 0 r
.53915 .41721 m .53658 .41474 L .536 .41749 L F
0 0 .058 r
.53725 .4153 m .536 .41749 L .53658 .41474 L F
.74 .584 .681 r
.4227 .50744 m .42438 .5114 L .42689 .51097 L F
.745 .612 .71 r
.42438 .5114 m .42419 .51418 L .42689 .51097 L F
.709 .557 .68 r
.42419 .51418 m .42882 .51473 L .42689 .51097 L F
.701 .554 .684 r
.42689 .51097 m .42882 .51473 L .42923 .51416 L F
.663 .868 .977 r
.4941 .44156 m .49549 .44297 L .49818 .44171 L F
.979 .779 .566 r
.54923 .425 m .54685 .42588 L .54673 .42889 L F
.917 .979 .75 r
.54442 .42967 m .54673 .42889 L .54685 .42588 L F
.973 .84 .433 r
.54703 .41928 m .54837 .41818 L .54605 .41612 L F
.54703 .41928 m .54774 .42074 L .54837 .41818 L F
.721 .472 .549 r
.39992 .507 m .40165 .50413 L .39726 .50407 L F
.703 .461 .555 r
.39992 .507 m .40431 .50418 L .40165 .50413 L F
.616 .049 0 r
.51928 .41188 m .52253 .41222 L .5192 .41012 L F
.51928 .41188 m .52332 .41354 L .52253 .41222 L F
.025 0 .443 r
.52253 .41222 m .52541 .40891 L .52515 .40557 L F
0 0 .351 r
.52189 .41498 m .52114 .41382 L .52459 .4133 L F
.489 .421 .706 r
.52332 .41354 m .52541 .40891 L .52253 .41222 L F
.429 .027 .173 r
.52598 .40291 m .52871 .40285 L .52902 .40128 L F
.728 .892 .954 r
.40956 .54284 m .40983 .53996 L .4079 .54181 L F
.40956 .54284 m .41154 .54106 L .40983 .53996 L F
.893 .801 .751 r
.42633 .52159 m .42845 .52079 L .4285 .51764 L F
.585 .443 .654 r
.34244 .51762 m .34554 .5171 L .34518 .51409 L F
.513 .386 .644 r
.34343 .52249 m .34554 .5171 L .34244 .51762 L F
.996 .855 .521 r
.54671 .40499 m .54652 .40795 L .54527 .40831 L F
0 0 .209 r
.54652 .40795 m .54498 .40874 L .54527 .40831 L F
.54652 .40795 m .54711 .40889 L .54498 .40874 L F
.703 .461 .555 r
.39992 .507 m .40422 .50704 L .40431 .50418 L F
.7 .474 .577 r
.40422 .50704 m .40861 .50413 L .40431 .50418 L F
0 0 0 r
.50386 .4207 m .50775 .41791 L .50724 .418 L F
.50386 .4207 m .50629 .41955 L .50775 .41791 L F
.647 .165 .094 r
.50775 .41791 m .51089 .41973 L .5103 .41759 L F
.50775 .41791 m .50629 .41955 L .51089 .41973 L F
.512 .592 .871 r
.35517 .54247 m .35611 .53881 L .35351 .53842 L F
.35517 .54247 m .35764 .542 L .35611 .53881 L F
.917 .731 .238 r
.41302 .53308 m .41323 .53756 L .41449 .53481 L F
.403 .255 .563 r
.59793 .36945 m .60045 .3685 L .60036 .3655 L F
.591 .534 .759 r
.59793 .36945 m .60189 .37275 L .60045 .3685 L F
.263 0 .163 r
.50979 .41405 m .51262 .41367 L .51346 .4113 L F
.486 .156 .331 r
.51262 .41367 m .51627 .41069 L .51346 .4113 L F
.218 0 .054 r
.53574 .40562 m .53956 .40313 L .53678 .40389 L F
.746 .598 .692 r
.41843 .50724 m .4199 .51082 L .4227 .50744 L F
.735 .581 .683 r
.4199 .51082 m .42438 .5114 L .4227 .50744 L F
.709 .481 .577 r
.40861 .50413 m .41121 .50706 L .41133 .50414 L F
.785 .485 .479 r
.36031 .50342 m .36328 .50592 L .3648 .50425 L F
.529 .219 .385 r
.36328 .50592 m .36739 .50355 L .3648 .50425 L F
.392 .375 .721 r
.34392 .52459 m .34484 .52941 L .34665 .52648 L F
.515 .533 .813 r
.34484 .52941 m .34849 .53081 L .34665 .52648 L F
.701 .401 .464 r
.39318 .50435 m .39716 .50693 L .39726 .50407 L F
.39318 .50435 m .39275 .50686 L .39716 .50693 L F
.623 .383 .533 r
.48268 .4383 m .48618 .43877 L .48581 .43571 L F
.545 .405 .642 r
.48618 .43877 m .48896 .43374 L .48581 .43571 L F
.979 .779 .566 r
.54923 .425 m .5474 .42347 L .54685 .42588 L F
.983 .74 .49 r
.54774 .42074 m .5474 .42347 L .54923 .425 L F
.436 .324 .628 r
.34518 .51409 m .34742 .51103 L .34461 .51202 L F
.7 .474 .577 r
.40422 .50704 m .40871 .50706 L .40861 .50413 L F
.709 .481 .577 r
.40861 .50413 m .40871 .50706 L .41121 .50706 L F
.422 .21 .484 r
.50979 .41405 m .51185 .41579 L .51262 .41367 L F
.50979 .41405 m .5103 .41759 L .51185 .41579 L F
.605 .425 .611 r
.42882 .51473 m .4285 .51764 L .42923 .51416 L F
.784 .579 .623 r
.4199 .51082 m .42419 .51418 L .42438 .5114 L F
.4199 .51082 m .41972 .5137 L .42419 .51418 L F
.779 .652 .722 r
.41972 .5137 m .42142 .51772 L .42419 .51418 L F
.706 .543 .666 r
.42142 .51772 m .42685 .51845 L .42419 .51418 L F
.666 .531 .69 r
.42419 .51418 m .4285 .51764 L .42882 .51473 L F
.42419 .51418 m .42685 .51845 L .4285 .51764 L F
.766 .699 .788 r
.51908 .42395 m .52097 .42772 L .51644 .42814 L F
.022 0 0 r
.51644 .42814 m .52097 .42772 L .51799 .42817 L F
.489 .564 .858 r
.52336 .42735 m .52097 .42772 L .51908 .42395 L F
.111 .661 .702 r
.51799 .42817 m .52097 .42772 L .52336 .42735 L F
.578 .366 .557 r
.49274 .42651 m .49745 .42427 L .49495 .42458 L F
.682 .613 .772 r
.51621 .4247 m .51377 .42575 L .51179 .42413 L F
.644 .507 .681 r
.51621 .4247 m .51354 .42809 L .51377 .42575 L F
.681 .482 .61 r
.55064 .40694 m .55151 .40385 L .54671 .40499 L F
.482 .104 .247 r
.50068 .42085 m .50386 .4207 L .50724 .418 L F
.996 .855 .521 r
.54671 .40499 m .54527 .40831 L .54443 .40501 L F
.525 0 0 r
.54324 .40523 m .54671 .40499 L .54443 .40501 L F
.54324 .40523 m .54761 .40606 L .54671 .40499 L F
.681 .482 .61 r
.55064 .40694 m .54671 .40499 L .54761 .40606 L F
.755 .329 .239 r
.38342 .50348 m .38591 .50617 L .38601 .50452 L F
.658 .239 .237 r
.38601 .50452 m .38591 .50617 L .38983 .50617 L F
.721 .472 .549 r
.39992 .507 m .39726 .50407 L .39716 .50693 L F
.779 .718 .795 r
.41739 .5309 m .42015 .52813 L .41581 .52756 L F
.217 .4 .83 r
.41581 .52756 m .41897 .53181 L .41739 .5309 L F
0 .099 .652 r
.53264 .43088 m .53312 .42998 L .53043 .42723 L F
0 .368 .821 r
.53264 .43088 m .53421 .43142 L .53312 .42998 L F
.364 .528 .885 r
.53264 .43088 m .53728 .43283 L .53421 .43142 L F
.745 .667 .774 r
.41871 .52416 m .4227 .52461 L .42206 .52115 L F
.41871 .52416 m .42054 .52588 L .4227 .52461 L F
.697 .554 .688 r
.4227 .52461 m .42054 .52588 L .42015 .52813 L F
.561 .573 .823 r
.35764 .542 m .35957 .54636 L .3622 .54548 L F
.807 .661 .701 r
.42015 .52813 m .42054 .52588 L .41871 .52416 L F
.706 .488 .591 r
.54967 .38369 m .54696 .3862 L .54893 .38227 L F
.615 .508 .708 r
.54893 .38227 m .55388 .38589 L .55426 .38313 L F
.22 0 0 r
.51354 .42809 m .51439 .42848 L .51318 .42944 L F
.51354 .42809 m .51545 .42866 L .51439 .42848 L F
.627 .483 .667 r
.51621 .4247 m .51644 .42814 L .51354 .42809 L F
.257 0 0 r
.51644 .42814 m .51545 .42866 L .51354 .42809 L F
.516 .463 .736 r
.34392 .52459 m .34618 .52198 L .34343 .52249 L F
.34392 .52459 m .34645 .52395 L .34618 .52198 L F
.392 .375 .721 r
.34392 .52459 m .34665 .52648 L .34645 .52395 L F
.317 .362 .75 r
.34992 .53445 m .35074 .53013 L .34849 .53081 L F
.34992 .53445 m .35189 .53437 L .35074 .53013 L F
.508 .285 .512 r
.47437 .44435 m .47657 .44464 L .47686 .44185 L F
.502 .376 .642 r
.47437 .44435 m .47435 .44822 L .47657 .44464 L F
.754 .693 .794 r
.51478 .42054 m .51179 .42413 L .51089 .41973 L F
.682 .613 .772 r
.51621 .4247 m .51179 .42413 L .51478 .42054 L F
.741 .739 .849 r
.38097 .5503 m .38231 .55234 L .38497 .55051 L F
.807 .661 .701 r
.42015 .52813 m .41871 .52416 L .41581 .52756 L F
.756 .328 .235 r
.38174 .50525 m .38342 .50348 L .38125 .50361 L F
.38174 .50525 m .38591 .50617 L .38342 .50348 L F
.436 .324 .628 r
.34518 .51409 m .34759 .51348 L .34742 .51103 L F
.519 .432 .697 r
.34554 .5171 m .34759 .51348 L .34518 .51409 L F
.748 .599 .691 r
.41553 .51043 m .4199 .51082 L .41843 .50724 L F
.752 .55 .624 r
.41575 .51347 m .4199 .51082 L .41553 .51043 L F
.41575 .51347 m .41972 .5137 L .4199 .51082 L F
.601 .752 .95 r
.37155 .55096 m .37171 .54748 L .3692 .54793 L F
.37155 .55096 m .3738 .55023 L .37171 .54748 L F
.513 .386 .644 r
.34343 .52249 m .34618 .52198 L .34554 .5171 L F
.748 .599 .691 r
.41553 .51043 m .41843 .50724 L .41562 .50735 L F
.596 .539 .761 r
.51908 .42395 m .51621 .4247 L .51478 .42054 L F
.766 .699 .788 r
.51908 .42395 m .51644 .42814 L .51621 .4247 L F
.81 .665 .703 r
.41972 .5137 m .41715 .5172 L .42142 .51772 L F
.81 .667 .705 r
.41715 .5172 m .41888 .52134 L .42142 .51772 L F
.781 .624 .686 r
.41888 .52134 m .42206 .52115 L .42142 .51772 L F
.653 .471 .625 r
.42206 .52115 m .42685 .51845 L .42142 .51772 L F
.745 .667 .774 r
.41871 .52416 m .42206 .52115 L .41888 .52134 L F
.653 .471 .625 r
.42206 .52115 m .42633 .52159 L .42685 .51845 L F
.774 .597 .659 r
.41112 .50995 m .41562 .50735 L .41121 .50706 L F
.41112 .50995 m .41553 .51043 L .41562 .50735 L F
.73 .66 .78 r
.60045 .3685 m .60189 .37275 L .60533 .37025 L F
.628 .447 .619 r
.42685 .51845 m .42633 .52159 L .4285 .51764 L F
.689 .579 .727 r
.47435 .44822 m .47598 .45303 L .47842 .45123 L F
.641 .456 .617 r
.49127 .43029 m .49274 .42651 L .49138 .42766 L F
.49127 .43029 m .49532 .43125 L .49274 .42651 L F
.578 .366 .557 r
.49274 .42651 m .49772 .42671 L .49745 .42427 L F
.466 .383 .679 r
.49274 .42651 m .49801 .42985 L .49772 .42671 L F
.49274 .42651 m .49532 .43125 L .49801 .42985 L F
.754 .616 .706 r
.48123 .44818 m .48571 .44909 L .48501 .44485 L F
.623 .526 .724 r
.48501 .44485 m .48571 .44909 L .48672 .44683 L F
.525 0 0 r
.54324 .40523 m .54443 .40501 L .54458 .40175 L F
.354 0 0 r
.53912 .41814 m .53915 .41721 L .536 .41749 L F
.244 .449 .862 r
.53912 .41814 m .536 .41749 L .53725 .4153 L F
.676 .808 .946 r
.3738 .55023 m .3781 .55037 L .37639 .54865 L F
.518 .72 .964 r
.3781 .55037 m .3788 .54747 L .37639 .54865 L F
.3781 .55037 m .38097 .5503 L .3788 .54747 L F
.494 .1 .223 r
.5419 .41903 m .54371 .41568 L .53915 .41721 L F
.501 .873 .66 r
.54595 .41406 m .54371 .41568 L .54605 .41612 L F
.399 .006 .173 r
.54605 .41612 m .54371 .41568 L .5419 .41903 L F
.385 .83 .942 r
.39215 .54938 m .39075 .5489 L .38749 .54963 L F
.582 .877 .993 r
.39524 .54879 m .39075 .5489 L .39215 .54938 L F
0 .005 .538 r
.52402 .40415 m .52515 .40557 L .52598 .40291 L F
.655 .385 .499 r
.52515 .40557 m .52871 .40285 L .52598 .40291 L F
0 0 .351 r
.52189 .41498 m .52459 .4133 L .52332 .41354 L F
.104 .572 .912 r
.52459 .4133 m .52533 .41265 L .52332 .41354 L F
.52459 .4133 m .52739 .41403 L .52533 .41265 L F
.471 .306 .576 r
.60045 .3685 m .60323 .36775 L .60036 .3655 L F
.60045 .3685 m .60323 .36775 L .60036 .3655 L F
0 0 0 r
.51439 .42848 m .51243 .4304 L .51318 .42944 L F
.204 .031 .411 r
.48501 .44485 m .48641 .44433 L .48694 .44141 L F
.623 .526 .724 r
.48501 .44485 m .48672 .44683 L .48641 .44433 L F
.794 .523 .528 r
.60323 .36775 m .60752 .36845 L .60742 .36567 L F
.616 .52 .722 r
.47435 .44822 m .47692 .44675 L .47657 .44464 L F
.689 .579 .727 r
.47435 .44822 m .47842 .45123 L .47692 .44675 L F
.663 .868 .977 r
.4941 .44156 m .49818 .44171 L .49636 .43997 L F
.795 .825 .876 r
.49636 .43997 m .49818 .44171 L .50146 .43913 L F
.741 .739 .849 r
.38097 .5503 m .38497 .55051 L .38348 .5491 L F
.589 .831 .991 r
.38497 .55051 m .38619 .54799 L .38348 .5491 L F
.38497 .55051 m .38749 .54963 L .38619 .54799 L F
.707 .62 .758 r
.47692 .44675 m .47842 .45123 L .48123 .44818 L F
.855 .697 .685 r
.4168 .52008 m .41871 .52416 L .41888 .52134 L F
.4168 .52008 m .41433 .52354 L .41871 .52416 L F
.846 .74 .747 r
.41433 .52354 m .41581 .52756 L .41871 .52416 L F
.78 .731 .807 r
.5259 .4206 m .52208 .421 L .52456 .41899 L F
.591 .567 .796 r
.52538 .42317 m .52208 .421 L .5259 .4206 L F
.596 .539 .761 r
.51908 .42395 m .51478 .42054 L .51927 .4217 L F
.376 .754 .99 r
.51478 .42054 m .51324 .41917 L .51089 .41973 L F
.73 .66 .78 r
.60045 .3685 m .60533 .37025 L .60323 .36775 L F
.701 .781 .913 r
.60323 .36775 m .60533 .37025 L .60752 .36845 L F
.519 .432 .697 r
.34554 .5171 m .34799 .51637 L .34759 .51348 L F
.53 .408 .658 r
.34618 .52198 m .34799 .51637 L .34554 .5171 L F
.022 0 0 r
.51644 .42814 m .51799 .42817 L .51545 .42866 L F
.894 .678 .602 r
.55 .40932 m .55064 .40694 L .54761 .40606 L F
.356 .463 .831 r
.35189 .53437 m .35351 .53842 L .35505 .53615 L F
.37 .481 .842 r
.35351 .53842 m .35611 .53881 L .35505 .53615 L F
.417 .15 .398 r
.49745 .42427 m .50061 .4242 L .50068 .42085 L F
.263 0 .179 r
.50061 .4242 m .50386 .4207 L .50068 .42085 L F
.596 .253 .359 r
.35319 .50596 m .3558 .50614 L .35586 .50385 L F
.646 .295 .362 r
.35586 .50385 m .36025 .50602 L .36031 .50342 L F
.35586 .50385 m .3558 .50614 L .36025 .50602 L F
.579 .327 .499 r
.35033 .50652 m .35303 .50934 L .35319 .50596 L F
.35033 .50652 m .35027 .50991 L .35303 .50934 L F
.775 .578 .633 r
.41112 .50995 m .41289 .51371 L .41553 .51043 L F
.757 .551 .619 r
.41553 .51043 m .41289 .51371 L .41575 .51347 L F
.759 .541 .601 r
.4087 .51018 m .41121 .50706 L .40871 .50706 L F
.4087 .51018 m .41112 .50995 L .41121 .50706 L F
.711 .717 .854 r
.48672 .44683 m .49116 .44458 L .48641 .44433 L F
0 0 .351 r
.52189 .41498 m .52122 .41675 L .52114 .41382 L F
.735 .647 .762 r
.52208 .421 m .52327 .42433 L .51908 .42395 L F
.489 .564 .858 r
.52336 .42735 m .51908 .42395 L .52327 .42433 L F
.591 .567 .796 r
.52538 .42317 m .52327 .42433 L .52208 .421 L F
0 0 .429 r
.52498 .42565 m .52327 .42433 L .52538 .42317 L F
.52498 .42565 m .52336 .42735 L .52327 .42433 L F
.494 .1 .223 r
.5419 .41903 m .53915 .41721 L .53912 .41814 L F
.71 .469 .558 r
.4041 .50982 m .40871 .50706 L .40422 .50704 L F
.4041 .50982 m .4087 .51018 L .40871 .50706 L F
.709 .452 .534 r
.39989 .50976 m .40422 .50704 L .39992 .507 L F
.39989 .50976 m .4041 .50982 L .40422 .50704 L F
.753 .58 .662 r
.41575 .51347 m .41715 .5172 L .41972 .5137 L F
.965 .785 .347 r
.54665 .42216 m .54774 .42074 L .54703 .41928 L F
.54665 .42216 m .5474 .42347 L .54774 .42074 L F
.795 .825 .876 r
.49636 .43997 m .50146 .43913 L .49937 .43692 L F
.704 .805 .928 r
.49937 .43692 m .50146 .43913 L .50372 .43745 L F
.449 .454 .772 r
.34849 .53081 m .34929 .52614 L .34665 .52648 L F
.34849 .53081 m .35074 .53013 L .34929 .52614 L F
.731 .458 .515 r
.3971 .50958 m .39992 .507 L .39716 .50693 L F
.3971 .50958 m .39989 .50976 L .39992 .507 L F
.838 .995 .843 r
.41323 .53756 m .40983 .53996 L .41154 .54106 L F
.568 .13 .169 r
.37439 .50328 m .37701 .50509 L .37929 .50287 L F
.674 .261 .255 r
.37929 .50287 m .38174 .50525 L .38125 .50361 L F
.37929 .50287 m .37701 .50509 L .38174 .50525 L F
.775 .652 .727 r
.4168 .52008 m .41888 .52134 L .41715 .5172 L F
.527 .401 .652 r
.49772 .42671 m .50061 .4242 L .49745 .42427 L F
.486 .156 .331 r
.51262 .41367 m .51716 .41358 L .51627 .41069 L F
.406 .111 .349 r
.51716 .41358 m .51928 .41188 L .51627 .41069 L F
.423 .065 .25 r
.51627 .41069 m .51928 .41188 L .5192 .41012 L F
0 0 .053 r
.48896 .43374 m .49072 .43274 L .49127 .43029 L F
.751 .438 .454 r
.49072 .43274 m .49532 .43125 L .49127 .43029 L F
.591 .532 .757 r
.48618 .43877 m .48694 .44141 L .48969 .44041 L F
.739 .626 .734 r
.48641 .44433 m .48969 .44041 L .48694 .44141 L F
.691 .638 .791 r
.47692 .44675 m .48123 .44818 L .48134 .4424 L F
.799 .611 .648 r
.41117 .52986 m .41897 .53181 L .41581 .52756 L F
.766 .694 .784 r
.41302 .53308 m .41897 .53181 L .41117 .52986 L F
.529 .219 .385 r
.36328 .50592 m .36577 .50723 L .36739 .50355 L F
.553 .243 .397 r
.36739 .50355 m .36577 .50723 L .36976 .50575 L F
.548 .244 .403 r
.36739 .50355 m .36976 .50575 L .37009 .50332 L F
.716 .427 .485 r
.39266 .50937 m .39716 .50693 L .39275 .50686 L F
.39266 .50937 m .3971 .50958 L .39716 .50693 L F
.785 .485 .479 r
.36031 .50342 m .36025 .50602 L .36328 .50592 L F
.505 .908 .906 r
.40038 .54556 m .4003 .54598 L .40186 .54468 L F
.684 .94 .964 r
.40466 .54451 m .40038 .54556 L .40186 .54468 L F
.489 .524 .82 r
.35764 .542 m .35973 .53958 L .35611 .53881 L F
.35764 .542 m .36012 .54161 L .35973 .53958 L F
.489 .552 .846 r
.35764 .542 m .36124 .5443 L .36012 .54161 L F
.561 .573 .823 r
.35764 .542 m .3622 .54548 L .36124 .5443 L F
.617 .806 .972 r
.3738 .55023 m .37459 .54697 L .37171 .54748 L F
.3738 .55023 m .37639 .54865 L .37459 .54697 L F
.668 .536 .695 r
.52208 .421 m .51908 .42395 L .51927 .4217 L F
.691 .638 .791 r
.47692 .44675 m .48134 .4424 L .47657 .44464 L F
.633 .101 0 r
.48134 .4424 m .48238 .44329 L .47969 .44124 L F
.589 .579 .809 r
.36482 .54447 m .36657 .54891 L .3692 .54793 L F
.545 .405 .642 r
.48618 .43877 m .48889 .43817 L .48896 .43374 L F
.591 .532 .757 r
.48618 .43877 m .48969 .44041 L .48889 .43817 L F
.735 .451 .498 r
.38563 .50895 m .38983 .50617 L .38591 .50617 L F
.38563 .50895 m .38828 .50946 L .38983 .50617 L F
.697 .407 .48 r
.38983 .50617 m .39266 .50937 L .39275 .50686 L F
.38983 .50617 m .38828 .50946 L .39266 .50937 L F
.628 .643 .846 r
.36124 .5443 m .3622 .54548 L .36482 .54447 L F
.575 .735 .951 r
.38097 .5503 m .3815 .54662 L .3788 .54747 L F
.38097 .5503 m .38348 .5491 L .3815 .54662 L F
.111 .661 .702 r
.51799 .42817 m .52336 .42735 L .52149 .42759 L F
.568 .939 .865 r
.52498 .42565 m .52149 .42759 L .52336 .42735 L F
.843 .739 .749 r
.41198 .52727 m .41581 .52756 L .41433 .52354 L F
.799 .611 .648 r
.41117 .52986 m .41581 .52756 L .41198 .52727 L F
.516 .385 .64 r
.34742 .51103 m .35024 .51281 L .35027 .50991 L F
.34742 .51103 m .34759 .51348 L .35024 .51281 L F
.738 .573 .669 r
.4127 .51674 m .41575 .51347 L .41289 .51371 L F
.4127 .51674 m .41715 .5172 L .41575 .51347 L F
.586 .514 .74 r
.34618 .52198 m .34645 .52395 L .34945 .52334 L F
.527 .367 .608 r
.34665 .52648 m .34945 .52334 L .34645 .52395 L F
.708 .387 .431 r
.37009 .50332 m .37392 .50576 L .37439 .50328 L F
.484 .202 .41 r
.37392 .50576 m .37701 .50509 L .37439 .50328 L F
0 .359 .806 r
.52739 .41403 m .52845 .4136 L .52533 .41265 L F
.52739 .41403 m .53021 .41548 L .52845 .4136 L F
.424 0 .002 r
.50614 .42202 m .51089 .41973 L .50629 .41955 L F
.50614 .42202 m .50929 .42177 L .51089 .41973 L F
.358 .282 .634 r
.51089 .41973 m .51185 .41579 L .5103 .41759 L F
.51089 .41973 m .51324 .41917 L .51185 .41579 L F
.151 0 0 r
.51089 .41973 m .51219 .42095 L .51324 .41917 L F
.51089 .41973 m .50929 .42177 L .51219 .42095 L F
.801 .676 .726 r
.41253 .51966 m .4168 .52008 L .41715 .5172 L F
.806 .621 .651 r
.41253 .51966 m .41433 .52354 L .4168 .52008 L F
.758 .408 .392 r
.36025 .50602 m .36271 .509 L .36328 .50592 L F
.688 .34 .379 r
.36328 .50592 m .36701 .50899 L .36577 .50723 L F
.36328 .50592 m .36271 .509 L .36701 .50899 L F
.676 .965 .758 r
.53367 .42448 m .53043 .42723 L .53182 .42518 L F
0 .166 .695 r
.53043 .42723 m .53157 .42643 L .53182 .42518 L F
.53043 .42723 m .53312 .42998 L .53157 .42643 L F
.53 .408 .658 r
.34618 .52198 m .34881 .52093 L .34799 .51637 L F
.586 .514 .74 r
.34618 .52198 m .34945 .52334 L .34881 .52093 L F
.739 .626 .734 r
.48641 .44433 m .49116 .44458 L .48969 .44041 L F
.698 .605 .748 r
.48969 .44041 m .49116 .44458 L .4941 .44156 L F
.766 .574 .638 r
.40845 .5131 m .41112 .50995 L .4087 .51018 L F
.767 .575 .638 r
.40845 .5131 m .41289 .51371 L .41112 .50995 L F
.917 .731 .238 r
.41302 .53308 m .41282 .53678 L .41323 .53756 L F
.838 .995 .843 r
.41323 .53756 m .41282 .53678 L .40983 .53996 L F
.894 .678 .602 r
.55 .40932 m .54761 .40606 L .54711 .40889 L F
.883 .739 .699 r
.54711 .40889 m .54862 .41305 L .55 .40932 L F
.801 .676 .726 r
.41253 .51966 m .41715 .5172 L .4127 .51674 L F
.554 .759 .973 r
.38749 .54963 m .3887 .54668 L .38619 .54799 L F
.38749 .54963 m .39075 .5489 L .3887 .54668 L F
.489 .887 .734 r
.53598 .42297 m .53367 .42448 L .53182 .42518 L F
.505 .908 .906 r
.40038 .54556 m .39699 .54687 L .4003 .54598 L F
.569 .599 .843 r
.36012 .54161 m .36124 .5443 L .36388 .54282 L F
.628 .643 .846 r
.36124 .5443 m .36482 .54447 L .36388 .54282 L F
.371 .264 .601 r
.48896 .43374 m .49047 .43561 L .49072 .43274 L F
.48896 .43374 m .48889 .43817 L .49047 .43561 L F
.769 .395 .348 r
.53064 .40558 m .53058 .40626 L .52871 .40285 L F
.669 .132 0 r
.53095 .40966 m .53296 .4119 L .5347 .41282 L F
.774 .565 .616 r
.53021 .41548 m .5347 .41282 L .53296 .4119 L F
.53021 .41548 m .53625 .41557 L .5347 .41282 L F
.013 .202 .713 r
.5347 .41282 m .53725 .4153 L .53725 .41253 L F
.5347 .41282 m .53625 .41557 L .53725 .4153 L F
.263 0 .179 r
.50061 .4242 m .50349 .42284 L .50386 .4207 L F
.432 .053 .219 r
.50386 .4207 m .50349 .42284 L .50614 .42202 L F
.358 .115 .403 r
.50386 .4207 m .50614 .42202 L .50629 .41955 L F
.493 .392 .669 r
.34799 .51637 m .35024 .51281 L .34759 .51348 L F
.071 0 .093 r
.52538 .42317 m .52787 .4225 L .52498 .42565 L F
.708 .387 .431 r
.37009 .50332 m .36976 .50575 L .37392 .50576 L F
0 .56 .759 r
.54498 .40874 m .54711 .40889 L .54337 .40845 L F
.582 .877 .993 r
.39524 .54879 m .39348 .54768 L .39075 .5489 L F
.811 .938 .912 r
.39536 .54597 m .39524 .54879 L .39699 .54687 L F
.39536 .54597 m .39348 .54768 L .39524 .54879 L F
.527 .367 .608 r
.34665 .52648 m .34929 .52614 L .34945 .52334 L F
0 .403 .685 r
.53728 .43283 m .53674 .43267 L .53421 .43142 L F
.53728 .43283 m .53853 .43318 L .53674 .43267 L F
.86 .719 .705 r
.40896 .53338 m .41302 .53308 L .41117 .52986 L F
.745 .486 .539 r
.40862 .53659 m .41302 .53308 L .40896 .53338 L F
.40862 .53659 m .41282 .53678 L .41302 .53308 L F
.493 .392 .669 r
.34799 .51637 m .35064 .51593 L .35024 .51281 L F
.509 .393 .657 r
.34799 .51637 m .3512 .51995 L .35064 .51593 L F
.34799 .51637 m .34881 .52093 L .3512 .51995 L F
.135 .657 .883 r
.53849 .42336 m .54032 .42365 L .53955 .42314 L F
.626 .109 0 r
.53876 .42499 m .54032 .42365 L .53598 .42297 L F
0 0 .097 r
.54011 .42302 m .53955 .42314 L .53876 .42499 L F
0 0 0 r
.5419 .41903 m .54167 .41971 L .54142 .4211 L F
.54167 .41971 m .54032 .42365 L .54142 .4211 L F
.756 .995 .855 r
.53955 .42314 m .54032 .42365 L .54142 .4211 L F
.54142 .4211 m .54032 .42365 L .53955 .42314 L F
.75 .931 .583 r
.54142 .4211 m .54032 .42365 L .53876 .42499 L F
.701 .238 .148 r
.54142 .4211 m .54006 .42293 L .54067 .42284 L F
.54142 .4211 m .54067 .42284 L .54112 .42278 L F
.54142 .4211 m .54112 .42278 L .54377 .42243 L F
0 0 .097 r
.54142 .4211 m .53955 .42314 L .54011 .42302 L F
.135 .657 .883 r
.53598 .42297 m .53849 .42336 L .53955 .42314 L F
.647 .116 0 r
.53092 .41044 m .53095 .40966 L .53144 .40773 L F
.53092 .41044 m .53296 .4119 L .53095 .40966 L F
.809 .656 .694 r
.40826 .51605 m .41289 .51371 L .40845 .5131 L F
.40826 .51605 m .4127 .51674 L .41289 .51371 L F
.751 .438 .454 r
.49072 .43274 m .49503 .43343 L .49532 .43125 L F
.559 .264 .423 r
.49532 .43125 m .49807 .43264 L .49801 .42985 L F
.49532 .43125 m .49503 .43343 L .49807 .43264 L F
.594 .819 .986 r
.53853 .43318 m .53998 .43126 L .53674 .43267 L F
.53853 .43318 m .54108 .43243 L .53998 .43126 L F
.711 .802 .921 r
.49937 .43692 m .50372 .43745 L .50201 .43554 L F
.847 .827 .827 r
.50201 .43554 m .50372 .43745 L .50656 .434 L F
.641 .667 .86 r
.48969 .44041 m .4941 .44156 L .49224 .43952 L F
.713 .684 .82 r
.49224 .43952 m .4941 .44156 L .49636 .43997 L F
.821 .523 .485 r
.38174 .50525 m .38563 .50895 L .38591 .50617 L F
.261 .442 .851 r
.53421 .43142 m .53591 .42911 L .53312 .42998 L F
.53421 .43142 m .53674 .43267 L .53591 .42911 L F
.792 .574 .607 r
.40826 .51916 m .4127 .51674 L .40826 .51605 L F
.40826 .51916 m .41253 .51966 L .4127 .51674 L F
.527 .401 .652 r
.49772 .42671 m .50054 .42636 L .50061 .4242 L F
.498 .281 .515 r
.49772 .42671 m .49801 .42985 L .50054 .42636 L F
.617 .564 .771 r
.48889 .43817 m .48969 .44041 L .49224 .43952 L F
.657 .221 .202 r
.53342 .4181 m .53625 .41557 L .53021 .41548 L F
0 0 0 r
.53725 .4153 m .53625 .41557 L .53342 .4181 L F
.415 .429 .766 r
.35074 .53013 m .35189 .53437 L .35424 .53379 L F
.42 .457 .793 r
.35189 .53437 m .35505 .53615 L .35424 .53379 L F
.684 .94 .964 r
.40466 .54451 m .40335 .54363 L .40038 .54556 L F
.841 .97 .881 r
.40622 .54074 m .40466 .54451 L .4079 .54181 L F
.40622 .54074 m .40335 .54363 L .40466 .54451 L F
.715 .528 .636 r
.40845 .5131 m .4087 .51018 L .4041 .50982 L F
.847 .827 .827 r
.50201 .43554 m .50656 .434 L .50482 .43238 L F
.775 .857 .911 r
.50482 .43238 m .50656 .434 L .50843 .43186 L F
.985 .846 .466 r
.54685 .42588 m .5474 .42347 L .54595 .42497 L F
.98 .858 .475 r
.54595 .42497 m .5474 .42347 L .54665 .42216 L F
.752 .529 .594 r
.39962 .5124 m .4041 .50982 L .39989 .50976 L F
.39962 .5124 m .40395 .51279 L .4041 .50982 L F
.715 .528 .636 r
.40845 .5131 m .4041 .50982 L .40395 .51279 L F
.63 .442 .609 r
.35319 .50596 m .35303 .50934 L .3558 .50614 L F
.525 .366 .608 r
.51185 .41579 m .51716 .41358 L .51262 .41367 L F
.51185 .41579 m .51586 .41594 L .51716 .41358 L F
.489 .351 .62 r
.51185 .41579 m .51597 .41803 L .51586 .41594 L F
.51185 .41579 m .51324 .41917 L .51597 .41803 L F
.47 .571 .875 r
.36482 .54447 m .36646 .54225 L .36388 .54282 L F
.36482 .54447 m .36728 .54412 L .36646 .54225 L F
.589 .579 .809 r
.36482 .54447 m .3692 .54793 L .36728 .54412 L F
.617 .564 .771 r
.48889 .43817 m .49224 .43952 L .49047 .43561 L F
.502 .576 .862 r
.3692 .54793 m .36976 .54361 L .36728 .54412 L F
.3692 .54793 m .37171 .54748 L .36976 .54361 L F
.875 .67 .621 r
.54062 .4044 m .54458 .40175 L .54134 .40128 L F
.54062 .4044 m .54324 .40523 L .54458 .40175 L F
.715 .453 .527 r
.39704 .51235 m .39989 .50976 L .3971 .50958 L F
.39704 .51235 m .39962 .5124 L .39989 .50976 L F
.399 .006 .173 r
.54605 .41612 m .5419 .41903 L .54422 .41811 L F
.899 .575 .425 r
.54422 .41811 m .54703 .41928 L .54605 .41612 L F
.464 .451 .759 r
.34881 .52093 m .34945 .52334 L .35174 .52252 L F
.562 .47 .707 r
.34929 .52614 m .35174 .52252 L .34945 .52334 L F
.713 .684 .82 r
.49224 .43952 m .49636 .43997 L .49488 .43633 L F
.692 .629 .781 r
.49488 .43633 m .49636 .43997 L .49937 .43692 L F
.624 .46 .639 r
.35027 .50991 m .35024 .51281 L .35303 .50934 L F
.551 .606 .861 r
.35611 .53881 m .35752 .53568 L .35505 .53615 L F
.35611 .53881 m .35973 .53958 L .35752 .53568 L F
.815 .604 .617 r
.54337 .40845 m .54761 .40606 L .54324 .40523 L F
.54337 .40845 m .54711 .40889 L .54761 .40606 L F
.644 .457 .616 r
.3558 .50614 m .36031 .50864 L .36025 .50602 L F
.691 .414 .498 r
.36031 .50864 m .36271 .509 L .36025 .50602 L F
.709 .462 .549 r
.39251 .51232 m .3971 .50958 L .39266 .50937 L F
.39251 .51232 m .39704 .51235 L .3971 .50958 L F
.75 .541 .611 r
.40384 .51574 m .40845 .5131 L .40395 .51279 L F
.40384 .51574 m .40826 .51605 L .40845 .5131 L F
.455 .403 .711 r
.35074 .53013 m .35276 .52728 L .34929 .52614 L F
.35074 .53013 m .35311 .52948 L .35276 .52728 L F
.415 .429 .766 r
.35074 .53013 m .35424 .53379 L .35311 .52948 L F
.745 .931 .95 r
.39892 .54347 m .39699 .54687 L .40038 .54556 L F
.39892 .54347 m .39536 .54597 L .39699 .54687 L F
.484 .521 .82 r
.35973 .53958 m .36012 .54161 L .36214 .53906 L F
.569 .599 .843 r
.36012 .54161 m .36388 .54282 L .36214 .53906 L F
.464 .451 .759 r
.34881 .52093 m .35174 .52252 L .3512 .51995 L F
.811 .884 .898 r
.4079 .54181 m .40792 .53862 L .40622 .54074 L F
.4079 .54181 m .40983 .53996 L .40792 .53862 L F
.639 .454 .617 r
.35303 .50934 m .35635 .5091 L .3558 .50614 L F
.644 .457 .616 r
.3558 .50614 m .35635 .5091 L .36031 .50864 L F
0 .063 .598 r
.51928 .41188 m .52189 .41498 L .52332 .41354 L F
.489 .421 .706 r
.52332 .41354 m .52533 .41265 L .52541 .40891 L F
.804 .62 .653 r
.40993 .52292 m .41433 .52354 L .41253 .51966 L F
.797 .67 .724 r
.41198 .52727 m .41433 .52354 L .40993 .52292 L F
.792 .602 .644 r
.40993 .52292 m .41253 .51966 L .40826 .51916 L F
.704 .611 .75 r
.49047 .43561 m .49224 .43952 L .49488 .43633 L F
.824 .929 .902 r
.54108 .43243 m .54306 .42839 L .53998 .43126 L F
.54108 .43243 m .54442 .42967 L .54306 .42839 L F
.218 0 .054 r
.53574 .40562 m .5388 .40487 L .53956 .40313 L F
.684 .444 .552 r
.52515 .40557 m .52541 .40891 L .53075 .40821 L F
.657 .221 .202 r
.53342 .4181 m .53021 .41548 L .5318 .41931 L F
.915 .544 .31 r
.5318 .41931 m .53275 .41989 L .53342 .4181 L F
.489 .887 .734 r
.53598 .42297 m .53182 .42518 L .53245 .42222 L F
.524 .244 .433 r
.53598 .42297 m .53955 .42314 L .53876 .42499 L F
.604 .759 .953 r
.38348 .5491 m .38425 .54585 L .3815 .54662 L F
.38348 .5491 m .38619 .54799 L .38425 .54585 L F
.6 .427 .619 r
.35303 .50934 m .35024 .51281 L .35315 .51226 L F
.57 .355 .55 r
.35315 .51226 m .35635 .5091 L .35303 .50934 L F
.562 .47 .707 r
.34929 .52614 m .35276 .52728 L .35174 .52252 L F
.53 .372 .611 r
.35064 .51593 m .35315 .51226 L .35024 .51281 L F
.631 .802 .965 r
.51545 .42866 m .51688 .42661 L .51439 .42848 L F
.51545 .42866 m .51799 .42817 L .51688 .42661 L F
.769 .536 .581 r
.38805 .51191 m .39266 .50937 L .38828 .50946 L F
.38805 .51191 m .39251 .51232 L .39266 .50937 L F
.639 .814 .967 r
.37459 .54697 m .37639 .54865 L .3788 .54747 L F
.847 .713 .715 r
.40707 .52932 m .41117 .52986 L .40958 .52575 L F
.849 .701 .698 r
.40896 .53338 m .41117 .52986 L .40707 .52932 L F
.801 .694 .747 r
.41117 .52986 m .41198 .52727 L .40958 .52575 L F
.469 .053 .167 r
.36973 .50825 m .37392 .50576 L .36976 .50575 L F
.36973 .50825 m .37259 .508 L .37392 .50576 L F
.366 0 .112 r
.37392 .50576 m .37491 .50751 L .37701 .50509 L F
.37392 .50576 m .37259 .508 L .37491 .50751 L F
.873 .989 .824 r
.54685 .42588 m .54306 .42839 L .54442 .42967 L F
.54685 .42588 m .54595 .42497 L .54306 .42839 L F
.751 .526 .589 r
.40384 .51574 m .40395 .51279 L .39962 .5124 L F
.419 .277 .581 r
.53574 .40562 m .53852 .40761 L .5388 .40487 L F
.585 .677 .904 r
.39075 .5489 m .39147 .54543 L .3887 .54668 L F
.39075 .5489 m .39348 .54768 L .39147 .54543 L F
.531 .401 .649 r
.50054 .42636 m .50349 .42284 L .50061 .4242 L F
.775 .857 .911 r
.50482 .43238 m .50843 .43186 L .50755 .42915 L F
.706 .768 .9 r
.50755 .42915 m .50843 .43186 L .51243 .4304 L F
.978 .754 .532 r
.40983 .53996 m .40862 .53659 L .40792 .53862 L F
.746 .68 .787 r
.40983 .53996 m .41282 .53678 L .40862 .53659 L F
.797 .67 .724 r
.41198 .52727 m .40993 .52292 L .40958 .52575 L F
.828 .377 .153 r
.53725 .4153 m .5419 .41903 L .53912 .41814 L F
.709 .596 .729 r
.49047 .43561 m .49488 .43633 L .49503 .43343 L F
.699 .608 .752 r
.49488 .43633 m .49807 .43264 L .49503 .43343 L F
.49488 .43633 m .49937 .43692 L .49807 .43264 L F
.647 .578 .763 r
.49807 .43264 m .49937 .43692 L .50201 .43554 L F
.738 .43 .461 r
.37701 .50509 m .37945 .50818 L .38174 .50525 L F
.783 .492 .495 r
.38174 .50525 m .37945 .50818 L .38194 .50836 L F
.821 .523 .485 r
.38174 .50525 m .38194 .50836 L .38563 .50895 L F
0 .063 .598 r
.51928 .41188 m .52156 .41414 L .52189 .41498 L F
.794 .765 .827 r
.52156 .41414 m .52262 .41703 L .52189 .41498 L F
.525 .606 .877 r
.36388 .54282 m .36466 .53851 L .36214 .53906 L F
.36388 .54282 m .36646 .54225 L .36466 .53851 L F
.709 .596 .729 r
.49047 .43561 m .49503 .43343 L .49072 .43274 L F
.732 .43 .468 r
.38563 .50895 m .38805 .51191 L .38828 .50946 L F
.68 .516 .656 r
.49801 .42985 m .5009 .42953 L .50054 .42636 L F
.531 .401 .649 r
.50054 .42636 m .50333 .4256 L .50349 .42284 L F
.598 .456 .659 r
.50054 .42636 m .5038 .42848 L .50333 .4256 L F
.50054 .42636 m .5009 .42953 L .5038 .42848 L F
.672 .76 .917 r
.40038 .54556 m .40089 .54193 L .39892 .54347 L F
.40038 .54556 m .40335 .54363 L .40089 .54193 L F
.53 .372 .611 r
.35064 .51593 m .35351 .51549 L .35315 .51226 L F
.448 .316 .608 r
.3512 .51995 m .35351 .51549 L .35064 .51593 L F
.855 .904 .869 r
.52845 .4136 m .53021 .41548 L .53296 .4119 L F
.483 .516 .815 r
.35973 .53958 m .36084 .53552 L .35752 .53568 L F
.35973 .53958 m .36214 .53906 L .36084 .53552 L F
.785 .599 .648 r
.40361 .51856 m .40826 .51605 L .40384 .51574 L F
.40361 .51856 m .40826 .51916 L .40826 .51605 L F
.587 .814 .986 r
.51799 .42817 m .51998 .42591 L .51688 .42661 L F
.51799 .42817 m .52149 .42759 L .51998 .42591 L F
.792 .416 .346 r
.38194 .50836 m .38368 .51108 L .38563 .50895 L F
.792 .417 .346 r
.38368 .51108 m .38805 .51191 L .38563 .50895 L F
.531 .495 .761 r
.36577 .50723 m .36973 .50825 L .36976 .50575 L F
.36577 .50723 m .36701 .50899 L .36973 .50825 L F
.57 .355 .55 r
.35315 .51226 m .35625 .51192 L .35635 .5091 L F
.586 .369 .553 r
.35635 .5091 m .36047 .51076 L .36031 .50864 L F
.35635 .5091 m .35625 .51192 L .36047 .51076 L F
.887 .637 .555 r
.54388 .42092 m .54703 .41928 L .54422 .41811 L F
.54388 .42092 m .54665 .42216 L .54703 .41928 L F
.663 .739 .907 r
.53591 .42911 m .53674 .43267 L .53998 .43126 L F
.164 0 0 r
.51324 .41917 m .51464 .42012 L .51597 .41803 L F
.51324 .41917 m .51219 .42095 L .51464 .42012 L F
.527 .517 .788 r
.35505 .53615 m .35685 .53314 L .35424 .53379 L F
.35505 .53615 m .35752 .53568 L .35685 .53314 L F
.767 .525 .568 r
.39723 .51542 m .39962 .5124 L .39704 .51235 L F
.39723 .51542 m .40152 .51562 L .39962 .5124 L F
.751 .526 .589 r
.40384 .51574 m .39962 .5124 L .40152 .51562 L F
.559 .444 .678 r
.49801 .42985 m .50025 .43196 L .5009 .42953 L F
.49801 .42985 m .49807 .43264 L .50025 .43196 L F
.666 .327 .389 r
.36271 .509 m .36484 .5102 L .36701 .50899 L F
.58 .294 .446 r
.36484 .5102 m .36973 .50825 L .36701 .50899 L F
.706 .768 .9 r
.50755 .42915 m .51243 .4304 L .51044 .42828 L F
.768 .827 .899 r
.51044 .42828 m .51243 .4304 L .51439 .42848 L F
.492 .345 .608 r
.35315 .51226 m .35582 .51473 L .35625 .51192 L F
.35315 .51226 m .35351 .51549 L .35582 .51473 L F
.735 .517 .598 r
.53913 .40786 m .54324 .40523 L .54062 .4044 L F
.53913 .40786 m .54337 .40845 L .54324 .40523 L F
.647 .578 .763 r
.49807 .43264 m .50201 .43554 L .50025 .43196 L F
.73 .608 .721 r
.50025 .43196 m .5038 .42848 L .5009 .42953 L F
.694 .436 .529 r
.39242 .51531 m .39704 .51235 L .39251 .51232 L F
.39242 .51531 m .39723 .51542 L .39704 .51235 L F
.541 .661 .914 r
.37171 .54748 m .37309 .54482 L .36976 .54361 L F
.37171 .54748 m .37459 .54697 L .37309 .54482 L F
.512 .622 .897 r
.36728 .54412 m .36911 .54142 L .36646 .54225 L F
.36728 .54412 m .36976 .54361 L .36911 .54142 L F
.448 .316 .608 r
.3512 .51995 m .35385 .51912 L .35351 .51549 L F
.448 .363 .667 r
.35174 .52252 m .35385 .51912 L .3512 .51995 L F
.785 .577 .619 r
.40567 .52234 m .40826 .51916 L .40361 .51856 L F
.805 .607 .635 r
.40567 .52234 m .40993 .52292 L .40826 .51916 L F
.724 .64 .764 r
.50025 .43196 m .50201 .43554 L .50482 .43238 L F
0 0 .487 r
.52541 .40891 m .52533 .41265 L .5273 .40987 L F
.291 .448 .846 r
.52533 .41265 m .52845 .4136 L .5273 .40987 L F
.808 .687 .732 r
.40647 .53233 m .40896 .53338 L .40707 .52932 L F
.822 .667 .69 r
.40862 .53659 m .40896 .53338 L .40647 .53233 L F
.757 .527 .584 r
.40361 .51856 m .40384 .51574 L .40152 .51562 L F
.525 .466 .733 r
.35424 .53379 m .35587 .52882 L .35311 .52948 L F
.35424 .53379 m .35685 .53314 L .35587 .52882 L F
.067 .072 .554 r
.53075 .40821 m .53144 .40773 L .53058 .40626 L F
.772 .518 .551 r
.38783 .51471 m .39251 .51232 L .38805 .51191 L F
.38783 .51471 m .39242 .51531 L .39251 .51232 L F
.8 .658 .705 r
.40958 .52575 m .40993 .52292 L .40567 .52234 L F
.828 .377 .153 r
.53725 .4153 m .54046 .42001 L .5419 .41903 L F
.868 .969 .856 r
.54036 .42034 m .53955 .42314 L .54174 .41932 L F
.54046 .42001 m .53967 .42025 L .53955 .42314 L F
.758 .9 .94 r
.53955 .42314 m .53967 .42025 L .54142 .4211 L F
.945 .602 .338 r
.54016 .42049 m .54006 .42293 L .54142 .4211 L F
.53967 .42025 m .53975 .42079 L .54016 .42049 L F
.53975 .42079 m .54006 .42293 L .54016 .42049 L F
.868 .969 .856 r
.54046 .42001 m .54036 .42034 L .5419 .41903 L F
.54036 .42034 m .54174 .41932 L .5419 .41903 L F
.64 .428 .58 r
.54142 .4211 m .54422 .41811 L .5419 .41903 L F
.616 .284 .384 r
.36047 .51076 m .36271 .509 L .36031 .50864 L F
.448 .363 .667 r
.35174 .52252 m .35418 .52191 L .35385 .51912 L F
.563 .505 .749 r
.35276 .52728 m .35418 .52191 L .35174 .52252 L F
.8 .658 .705 r
.40958 .52575 m .40567 .52234 L .40523 .52528 L F
.818 .668 .697 r
.40707 .52932 m .40958 .52575 L .40523 .52528 L F
.502 .339 .592 r
.51716 .41358 m .51586 .41594 L .51861 .41468 L F
.596 .449 .651 r
.51597 .41803 m .51861 .41468 L .51586 .41594 L F
.759 .428 .426 r
.37491 .50751 m .37945 .50818 L .37701 .50509 L F
.715 .866 .953 r
.51998 .42591 m .52149 .42759 L .52498 .42565 L F
0 0 .487 r
.52541 .40891 m .5273 .40987 L .53075 .40821 L F
.827 .433 .303 r
.53075 .40821 m .53092 .41044 L .53144 .40773 L F
.53075 .40821 m .5273 .40987 L .53092 .41044 L F
.822 .667 .69 r
.40862 .53659 m .40647 .53233 L .40406 .53565 L F
.826 .542 .508 r
.40792 .53862 m .40862 .53659 L .40406 .53565 L F
.502 .339 .592 r
.51716 .41358 m .51861 .41468 L .51928 .41188 L F
.52 .291 .508 r
.51861 .41468 m .52156 .41414 L .51928 .41188 L F
.639 .814 .967 r
.37459 .54697 m .3788 .54747 L .3772 .54558 L F
.606 .745 .943 r
.3772 .54558 m .3788 .54747 L .3815 .54662 L F
.855 .904 .869 r
.52845 .4136 m .53296 .4119 L .53092 .41044 L F
.616 .284 .384 r
.36047 .51076 m .36251 .51132 L .36271 .509 L F
.666 .327 .389 r
.36271 .509 m .36251 .51132 L .36484 .5102 L F
.55 .47 .717 r
.35311 .52948 m .35484 .52661 L .35276 .52728 L F
.35311 .52948 m .35587 .52882 L .35484 .52661 L F
.483 .284 .534 r
.50333 .4256 m .50614 .42202 L .50349 .42284 L F
.73 .608 .721 r
.50025 .43196 m .50482 .43238 L .5038 .42848 L F
.635 .55 .741 r
.5038 .42848 m .50482 .43238 L .50755 .42915 L F
0 0 0 r
.53725 .4153 m .53342 .4181 L .53615 .41738 L F
.299 0 .195 r
.53342 .4181 m .53275 .41989 L .53615 .41738 L F
.589 .359 .535 r
.53409 .41886 m .53517 .41806 L .53615 .41738 L F
.813 .39 .24 r
.53615 .41738 m .53786 .41619 L .53725 .4153 L F
.589 .359 .535 r
.53517 .41806 m .53828 .41575 L .53615 .41738 L F
.813 .39 .24 r
.53615 .41738 m .54046 .42001 L .53786 .41619 L F
.563 .505 .749 r
.35276 .52728 m .35484 .52661 L .35418 .52191 L F
.64 .773 .944 r
.38425 .54585 m .38619 .54799 L .3887 .54668 L F
.741 .505 .572 r
.39679 .51831 m .40152 .51562 L .39723 .51542 L F
.39679 .51831 m .4014 .51882 L .40152 .51562 L F
.757 .527 .584 r
.40361 .51856 m .40152 .51562 L .4014 .51882 L F
.499 .505 .794 r
.53312 .42998 m .53452 .42644 L .53157 .42643 L F
.53312 .42998 m .53591 .42911 L .53452 .42644 L F
.776 .819 .886 r
.51297 .42665 m .51044 .42828 L .51439 .42848 L F
.736 .807 .908 r
.51297 .42665 m .51439 .42848 L .51688 .42661 L F
.688 .502 .631 r
.54134 .40128 m .5388 .40487 L .54062 .4044 L F
.54134 .40128 m .5388 .40487 L .54062 .4044 L F
.626 .571 .773 r
.5038 .42848 m .50612 .42483 L .50333 .4256 L F
.5038 .42848 m .50755 .42915 L .50612 .42483 L F
.483 .284 .534 r
.50333 .4256 m .50612 .42483 L .50614 .42202 L F
.553 .394 .619 r
.35351 .51549 m .35681 .51843 L .35582 .51473 L F
.35351 .51549 m .35385 .51912 L .35681 .51843 L F
.663 .739 .907 r
.53591 .42911 m .53998 .43126 L .53894 .42791 L F
.759 .795 .882 r
.53998 .43126 m .54306 .42839 L .53894 .42791 L F
.61 .4 .572 r
.35582 .51473 m .36047 .51076 L .35625 .51192 L F
.737 .72 .836 r
.39147 .54543 m .39348 .54768 L .39536 .54597 L F
.801 .994 .872 r
.5397 .41146 m .54337 .40845 L .53984 .41022 L F
.638 .408 .553 r
.50614 .42202 m .50922 .42412 L .50929 .42177 L F
.50614 .42202 m .50612 .42483 L .50922 .42412 L F
0 0 .562 r
.53852 .40761 m .5397 .41146 L .53984 .41022 L F
0 0 0 r
.53984 .41022 m .5397 .41146 L .53953 .41342 L F
0 0 .562 r
.53852 .40761 m .5397 .41146 L .53984 .41022 L F
0 0 0 r
.53953 .41342 m .5397 .41146 L .53984 .41022 L F
.89 .725 .671 r
.53245 .42222 m .53182 .42518 L .53038 .42074 L F
.794 .765 .827 r
.52156 .41414 m .51885 .41765 L .52262 .41703 L F
.467 .844 .987 r
.52262 .41703 m .52422 .4154 L .52632 .416 L F
.474 .555 .858 r
.36646 .54225 m .36713 .5377 L .36466 .53851 L F
.36646 .54225 m .36911 .54142 L .36713 .5377 L F
.781 .761 .834 r
.40089 .54193 m .40335 .54363 L .40622 .54074 L F
.882 .665 .603 r
.54388 .42092 m .54595 .42497 L .54665 .42216 L F
.577 .55 .788 r
.35685 .53314 m .35752 .53568 L .35957 .53273 L F
.595 .574 .8 r
.35752 .53568 m .36084 .53552 L .35957 .53273 L F
.811 .545 .538 r
.38352 .51393 m .38805 .51191 L .38368 .51108 L F
.38352 .51393 m .38783 .51471 L .38805 .51191 L F
.835 .716 .732 r
.40647 .53233 m .40474 .52815 L .40235 .53149 L F
.40647 .53233 m .40707 .52932 L .40474 .52815 L F
.833 .682 .696 r
.40406 .53565 m .40647 .53233 L .40235 .53149 L F
.723 .471 .546 r
.37945 .50818 m .38368 .51108 L .38194 .50836 L F
.854 .911 .872 r
.53852 .40761 m .53913 .40786 L .54062 .4044 L F
.596 .449 .651 r
.51597 .41803 m .51885 .41765 L .51861 .41468 L F
.381 0 .104 r
.51597 .41803 m .51716 .4191 L .51885 .41765 L F
.51597 .41803 m .51464 .42012 L .51716 .4191 L F
.785 .597 .646 r
.40109 .52172 m .40361 .51856 L .4014 .51882 L F
.768 .572 .633 r
.40109 .52172 m .40567 .52234 L .40361 .51856 L F
.802 .993 .755 r
.52498 .42565 m .52787 .4225 L .52584 .42316 L F
.957 .62 .325 r
.52584 .42316 m .52787 .4225 L .52601 .42106 L F
.773 .277 .034 r
.52787 .4225 m .52992 .4252 L .52588 .42317 L F
.96 .744 .567 r
.53038 .42074 m .52992 .4252 L .52787 .4225 L F
.53038 .42074 m .53182 .42518 L .52992 .4252 L F
.773 .277 .034 r
.52585 .42316 m .52588 .42317 L .52584 .42316 L F
.976 .737 .319 r
.52992 .4252 m .52859 .42243 L .52584 .42316 L F
.52992 .4252 m .52973 .42602 L .52859 .42243 L F
.666 .76 .921 r
.52959 .42558 m .53142 .42171 L .52859 .42243 L F
.52973 .42602 m .52984 .42574 L .52959 .42558 L F
.904 .542 .341 r
.52992 .4252 m .53182 .42518 L .52973 .42602 L F
.666 .76 .921 r
.52984 .42574 m .53142 .42171 L .52959 .42558 L F
.773 .277 .034 r
.52787 .4225 m .52588 .42317 L .52585 .42316 L F
.712 .843 .945 r
.53038 .42074 m .52787 .4225 L .52601 .42106 L F
.501 .521 .81 r
.36214 .53906 m .36323 .53455 L .36084 .53552 L F
.36214 .53906 m .36466 .53851 L .36323 .53455 L F
.861 .682 .659 r
.40474 .52815 m .40707 .52932 L .40523 .52528 L F
.52 .557 .833 r
.53157 .42643 m .53413 .42512 L .53182 .42518 L F
.53157 .42643 m .53452 .42644 L .53413 .42512 L F
.655 .537 .708 r
.50922 .42412 m .51219 .42095 L .50929 .42177 L F
.58 .294 .446 r
.36484 .5102 m .36982 .51093 L .36973 .50825 L F
.653 .35 .446 r
.36973 .50825 m .36982 .51093 L .37223 .51079 L F
.591 .356 .53 r
.36973 .50825 m .37223 .51079 L .37259 .508 L F
.73 .73 .85 r
.39147 .54543 m .39536 .54597 L .39405 .54228 L F
.699 .713 .859 r
.39405 .54228 m .39536 .54597 L .39892 .54347 L F
.715 .866 .953 r
.51998 .42591 m .52498 .42565 L .52351 .42479 L F
.714 .95 .953 r
.52584 .42316 m .52351 .42479 L .52498 .42565 L F
.697 .512 .633 r
.36251 .51132 m .36647 .51407 L .36484 .5102 L F
.508 .289 .516 r
.36647 .51407 m .36982 .51093 L .36484 .5102 L F
.692 .516 .644 r
.5388 .40487 m .53852 .40761 L .54062 .4044 L F
.127 0 0 r
.52973 .42602 m .53182 .42518 L .53413 .42512 L F
.608 .516 .725 r
.50755 .42915 m .50922 .42412 L .50612 .42483 L F
.50755 .42915 m .51044 .42828 L .50922 .42412 L F
.696 .726 .873 r
.37309 .54482 m .37459 .54697 L .3772 .54558 L F
.452 .424 .737 r
.35418 .52191 m .35484 .52661 L .35733 .52419 L F
.445 .414 .73 r
.35587 .52882 m .35733 .52419 L .35484 .52661 L F
.781 .761 .834 r
.40089 .54193 m .40622 .54074 L .40385 .53836 L F
.778 .727 .805 r
.40622 .54074 m .40792 .53862 L .40385 .53836 L F
.559 .421 .649 r
.51861 .41468 m .51885 .41765 L .52156 .41414 L F
.801 .596 .625 r
.39256 .51774 m .39723 .51542 L .39242 .51531 L F
.39256 .51774 m .39679 .51831 L .39723 .51542 L F
.713 .462 .545 r
.38783 .51471 m .39256 .51774 L .39242 .51531 L F
.595 .748 .95 r
.3772 .54558 m .3815 .54662 L .37982 .54493 L F
.583 .743 .953 r
.37982 .54493 m .3815 .54662 L .38425 .54585 L F
.767 .6 .671 r
.40523 .52528 m .40567 .52234 L .40109 .52172 L F
.167 .367 .816 r
.36976 .54361 m .37079 .54173 L .36911 .54142 L F
.32 .565 .926 r
.36976 .54361 m .37309 .54482 L .37079 .54173 L F
.736 .807 .908 r
.51297 .42665 m .51688 .42661 L .5162 .42525 L F
.561 .756 .969 r
.51688 .42661 m .51872 .42377 L .5162 .42525 L F
.51688 .42661 m .51998 .42591 L .51872 .42377 L F
.577 .549 .787 r
.35685 .53314 m .35823 .52824 L .35587 .52882 L F
.35685 .53314 m .35957 .53273 L .35823 .52824 L F
.64 .428 .58 r
.54142 .4211 m .54388 .42092 L .54422 .41811 L F
.61 .4 .572 r
.35582 .51473 m .35998 .51576 L .36047 .51076 L F
.677 .459 .582 r
.36047 .51076 m .36227 .51435 L .36251 .51132 L F
.36047 .51076 m .35998 .51576 L .36227 .51435 L F
.445 .414 .73 r
.35587 .52882 m .35823 .52824 L .35733 .52419 L F
.59 .466 .68 r
.35385 .51912 m .35702 .52129 L .35681 .51843 L F
.35385 .51912 m .35418 .52191 L .35702 .52129 L F
.826 .542 .508 r
.40792 .53862 m .40406 .53565 L .40385 .53836 L F
.762 .576 .646 r
.3966 .52128 m .4014 .51882 L .39679 .51831 L F
.3966 .52128 m .40109 .52172 L .4014 .51882 L F
.777 .553 .594 r
.37491 .50751 m .37677 .51096 L .37945 .50818 L F
.727 .475 .546 r
.37677 .51096 m .37919 .51098 L .37945 .50818 L F
.723 .471 .546 r
.37945 .50818 m .37919 .51098 L .38368 .51108 L F
.717 .726 .857 r
.38425 .54585 m .3887 .54668 L .38686 .54483 L F
.73 .728 .849 r
.38686 .54483 m .3887 .54668 L .39147 .54543 L F
.798 .742 .801 r
.53894 .42791 m .54306 .42839 L .54161 .42453 L F
.763 .679 .77 r
.54306 .42839 m .54377 .42243 L .54161 .42453 L F
.54306 .42839 m .54595 .42497 L .54377 .42243 L F
.767 .6 .671 r
.40523 .52528 m .40109 .52172 L .40091 .52468 L F
.808 .629 .659 r
.40474 .52815 m .40523 .52528 L .40091 .52468 L F
.61 .455 .647 r
.35582 .51473 m .35961 .5177 L .35998 .51576 L F
.35582 .51473 m .35681 .51843 L .35961 .5177 L F
.341 0 .013 r
.52131 .4185 m .51885 .41765 L .51716 .4191 L F
.52131 .4185 m .52206 .4176 L .51885 .41765 L F
.452 .424 .737 r
.35418 .52191 m .35733 .52419 L .35702 .52129 L F
.699 .527 .651 r
.37223 .51079 m .37491 .50751 L .37259 .508 L F
.89 .665 .592 r
.54377 .42243 m .54595 .42497 L .54388 .42092 L F
.846 .687 .685 r
.40015 .53546 m .40406 .53565 L .40235 .53149 L F
.735 .637 .75 r
.39989 .53846 m .40406 .53565 L .40015 .53546 L F
.39989 .53846 m .40385 .53836 L .40406 .53565 L F
.512 .53 .811 r
.35957 .53273 m .36084 .53552 L .36323 .53455 L F
.73 .728 .849 r
.38686 .54483 m .39147 .54543 L .38971 .5417 L F
.731 .731 .851 r
.38971 .5417 m .39147 .54543 L .39405 .54228 L F
.696 .726 .873 r
.37309 .54482 m .3772 .54558 L .37557 .54397 L F
.573 .804 .986 r
.37557 .54397 m .3772 .54558 L .37982 .54493 L F
.89 .665 .592 r
.54377 .42243 m .54388 .42092 L .54142 .4211 L F
.806 .589 .608 r
.39224 .52068 m .39679 .51831 L .39256 .51774 L F
.39224 .52068 m .3966 .52128 L .39679 .51831 L F
.655 .537 .708 r
.50922 .42412 m .51293 .42637 L .51219 .42095 L F
.679 .559 .712 r
.50922 .42412 m .51297 .42665 L .51293 .42637 L F
.50922 .42412 m .51044 .42828 L .51297 .42665 L F
.718 .501 .595 r
.39648 .52457 m .40109 .52172 L .3966 .52128 L F
.39648 .52457 m .40091 .52468 L .40109 .52172 L F
.061 0 0 r
.52584 .42316 m .53038 .42074 L .52601 .42106 L F
.52584 .42316 m .52859 .42243 L .53038 .42074 L F
.132 0 0 r
.52859 .42243 m .53275 .41989 L .53038 .42074 L F
.458 0 0 r
.52601 .42106 m .52859 .42243 L .53038 .42074 L F
.697 .512 .633 r
.36251 .51132 m .36227 .51435 L .36647 .51407 L F
.808 .629 .659 r
.40474 .52815 m .40091 .52468 L .40066 .52741 L F
.813 .694 .734 r
.40235 .53149 m .40474 .52815 L .40066 .52741 L F
.752 .494 .543 r
.38344 .51734 m .38783 .51471 L .38352 .51393 L F
.38344 .51734 m .38785 .51771 L .38783 .51471 L F
.713 .462 .545 r
.38783 .51471 m .38785 .51771 L .39256 .51774 L F
.625 .565 .768 r
.53591 .42911 m .53894 .42791 L .53452 .42644 L F
.838 .706 .718 r
.39989 .53846 m .40089 .54193 L .40145 .53959 L F
.39989 .53846 m .39676 .5415 L .40089 .54193 L F
.806 .788 .836 r
.39676 .5415 m .39892 .54347 L .40089 .54193 L F
.746 .669 .775 r
.40145 .53959 m .40089 .54193 L .40385 .53836 L F
.699 .713 .859 r
.39405 .54228 m .39892 .54347 L .39676 .5415 L F
.624 .751 .938 r
.5162 .42525 m .51293 .42637 L .51297 .42665 L F
.851 .805 .805 r
.5273 .40987 m .52845 .4136 L .53092 .41044 L F
.493 .492 .784 r
.35957 .53273 m .36077 .5277 L .35823 .52824 L F
.35957 .53273 m .36209 .53226 L .36077 .5277 L F
.497 .533 .824 r
.35957 .53273 m .36323 .53455 L .36209 .53226 L F
.577 .601 .84 r
.53452 .42644 m .53752 .42441 L .53413 .42512 L F
.53452 .42644 m .53894 .42791 L .53752 .42441 L F
.741 .477 .53 r
.37919 .51098 m .38352 .51393 L .38368 .51108 L F
.572 .477 .709 r
.51219 .42095 m .5162 .42525 L .51464 .42012 L F
.51219 .42095 m .51293 .42637 L .5162 .42525 L F
.583 .743 .953 r
.37982 .54493 m .38425 .54585 L .38292 .54438 L F
.72 .747 .873 r
.38292 .54438 m .38425 .54585 L .38686 .54483 L F
.699 .527 .651 r
.37223 .51079 m .37677 .51096 L .37491 .50751 L F
.516 .536 .815 r
.36466 .53851 m .36558 .53383 L .36323 .53455 L F
.36466 .53851 m .36713 .5377 L .36558 .53383 L F
.525 .724 .964 r
.37309 .54482 m .3737 .54163 L .37079 .54173 L F
.37309 .54482 m .37557 .54397 L .3737 .54163 L F
.626 .509 .7 r
.35681 .51843 m .35702 .52129 L .35961 .5177 L F
.831 .701 .72 r
.39813 .53104 m .40235 .53149 L .40066 .52741 L F
.835 .671 .68 r
.40015 .53546 m .40235 .53149 L .39813 .53104 L F
.735 .637 .75 r
.39989 .53846 m .40145 .53959 L .40385 .53836 L F
.567 .431 .655 r
.35702 .52129 m .35986 .52087 L .35961 .5177 L F
.448 .254 .524 r
.35733 .52419 m .35986 .52087 L .35702 .52129 L F
.62 .751 .94 r
.51998 .42591 m .52151 .42246 L .51872 .42377 L F
.51998 .42591 m .52351 .42479 L .52151 .42246 L F
.892 .856 .8 r
.54006 .42293 m .54161 .42453 L .54377 .42243 L F
.754 .612 .701 r
.35998 .51576 m .35961 .5177 L .36227 .51435 L F
.621 .424 .594 r
.36227 .51435 m .35961 .5177 L .36263 .51722 L F
.642 .439 .593 r
.36227 .51435 m .36708 .51499 L .36647 .51407 L F
.36227 .51435 m .36263 .51722 L .36708 .51499 L F
.72 .747 .873 r
.38292 .54438 m .38686 .54483 L .38558 .54159 L F
.781 .832 .891 r
.38558 .54159 m .38686 .54483 L .38971 .5417 L F
.209 .299 .738 r
.36911 .54142 m .36951 .5371 L .36713 .5377 L F
.36911 .54142 m .37079 .54173 L .36951 .5371 L F
.508 .289 .516 r
.36647 .51407 m .36965 .51364 L .36982 .51093 L F
.551 .332 .536 r
.36708 .51499 m .36965 .51364 L .36647 .51407 L F
.432 .827 .983 r
.52422 .4154 m .52728 .41546 L .52632 .416 L F
.828 .66 .675 r
.39194 .52358 m .3966 .52128 L .39224 .52068 L F
.39194 .52358 m .39424 .52441 L .3966 .52128 L F
.807 .628 .659 r
.39424 .52441 m .39648 .52457 L .3966 .52128 L F
0 0 .401 r
.53953 .41342 m .54052 .41264 L .53984 .41022 L F
0 0 0 r
.53953 .41342 m .53984 .41022 L .54052 .41264 L F
.596 .352 .518 r
.37655 .51397 m .37919 .51098 L .37677 .51096 L F
.37655 .51397 m .37903 .5138 L .37919 .51098 L F
.741 .477 .53 r
.37919 .51098 m .37903 .5138 L .38352 .51393 L F
.573 .804 .986 r
.37557 .54397 m .37982 .54493 L .37774 .54345 L F
.563 .834 .996 r
.37774 .54345 m .37982 .54493 L .38292 .54438 L F
.127 0 0 r
.52973 .42602 m .53413 .42512 L .53265 .42467 L F
.541 .779 .986 r
.53413 .42512 m .53594 .42262 L .53265 .42467 L F
.53413 .42512 m .53752 .42441 L .53594 .42262 L F
.837 .714 .729 r
.39778 .53398 m .39989 .53846 L .40015 .53546 L F
.39778 .53398 m .39506 .53742 L .39989 .53846 L F
.839 .709 .72 r
.39506 .53742 m .39676 .5415 L .39989 .53846 L F
.693 .445 .542 r
.36982 .51093 m .37218 .51356 L .37223 .51079 L F
.36982 .51093 m .36965 .51364 L .37218 .51356 L F
.745 .56 .644 r
.37218 .51356 m .37677 .51096 L .37223 .51079 L F
.721 .527 .627 r
.40066 .52741 m .40091 .52468 L .39648 .52457 L F
.714 .93 .961 r
.52345 .42164 m .52447 .42101 L .52131 .4185 L F
.52463 .42114 m .52558 .42074 L .52443 .42014 L F
.52463 .42114 m .52443 .42014 L .52131 .4185 L F
0 0 .187 r
.52739 .41707 m .52601 .42106 L .52728 .41546 L F
.5275 .41857 m .52706 .41931 L .52739 .41707 L F
.52706 .41931 m .52601 .42106 L .52739 .41707 L F
.159 0 .395 r
.52578 .42018 m .5275 .41857 L .52772 .41493 L F
.432 .827 .983 r
.52422 .4154 m .52772 .41493 L .52728 .41546 L F
.159 0 .395 r
.52548 .42038 m .5277 .41497 L .52422 .4154 L F
.52578 .42018 m .5277 .41497 L .52548 .42038 L F
.647 .477 .64 r
.52131 .4185 m .52522 .42056 L .52422 .4154 L F
.52522 .42056 m .52548 .42038 L .52422 .4154 L F
.683 .979 .874 r
.52459 .42094 m .52522 .42056 L .5275 .41857 L F
.52522 .42056 m .52695 .41949 L .527 .41941 L F
.52522 .42056 m .527 .41941 L .5275 .41857 L F
.52466 .42095 m .52601 .42106 L .52537 .42046 L F
.647 .477 .64 r
.52522 .42056 m .52558 .42074 L .52548 .42038 L F
.159 0 .395 r
.52558 .42074 m .5275 .41857 L .52578 .42018 L F
.683 .979 .874 r
.5257 .42026 m .52601 .42106 L .52695 .41949 L F
.52537 .42046 m .52542 .42052 L .5257 .42026 L F
.52542 .42052 m .52601 .42106 L .5257 .42026 L F
.52459 .42094 m .52466 .42095 L .52537 .42046 L F
.159 0 .395 r
.52558 .42074 m .52578 .42018 L .52548 .42038 L F
.5277 .41497 m .52772 .41493 L .52771 .41493 L F
.5277 .41497 m .52771 .41493 L .52422 .4154 L F
.683 .979 .874 r
.52427 .42091 m .52459 .42094 L .5275 .41857 L F
.714 .93 .961 r
.52151 .42246 m .52345 .42164 L .52131 .4185 L F
.52345 .42164 m .52463 .42114 L .52447 .42101 L F
.971 .655 .302 r
.52459 .42094 m .52584 .42316 L .52601 .42106 L F
.52427 .42091 m .52463 .42114 L .52459 .42094 L F
.714 .93 .961 r
.52463 .42114 m .52427 .42091 L .52558 .42074 L F
.52151 .42246 m .52427 .42091 L .52463 .42114 L F
.971 .655 .302 r
.52427 .42091 m .52472 .42155 L .52463 .42114 L F
.52472 .42155 m .52584 .42316 L .52459 .42094 L F
.745 .56 .644 r
.37218 .51356 m .37655 .51397 L .37677 .51096 L F
.741 .716 .828 r
.38971 .5417 m .39405 .54228 L .39291 .53876 L F
.613 .64 .854 r
.39291 .53876 m .39405 .54228 L .39676 .5415 L F
.775 .704 .785 r
.53752 .42441 m .53894 .42791 L .54161 .42453 L F
.548 .417 .654 r
.35961 .5177 m .36279 .52022 L .36263 .51722 L F
.35961 .5177 m .35986 .52087 L .36279 .52022 L F
.774 .425 .395 r
.38785 .51771 m .39224 .52068 L .39256 .51774 L F
.762 .519 .566 r
.39388 .52739 m .39648 .52457 L .39424 .52441 L F
.39388 .52739 m .39853 .52822 L .39648 .52457 L F
.721 .527 .627 r
.40066 .52741 m .39648 .52457 L .39853 .52822 L F
.49 .435 .723 r
.35823 .52824 m .35992 .52351 L .35733 .52419 L F
.35823 .52824 m .36077 .5277 L .35992 .52351 L F
.93 .764 .654 r
.53828 .41575 m .54046 .42001 L .53615 .41738 L F
.53828 .41575 m .53967 .42025 L .54046 .42001 L F
.448 .254 .524 r
.35733 .52419 m .35992 .52351 L .35986 .52087 L F
.775 .704 .785 r
.53752 .42441 m .54161 .42453 L .54006 .42293 L F
.532 .463 .724 r
.51464 .42012 m .51872 .42377 L .51716 .4191 L F
.539 .381 .615 r
.51716 .4191 m .52151 .42246 L .52131 .4185 L F
.51716 .4191 m .51872 .42377 L .52151 .42246 L F
0 0 0 r
.53828 .41575 m .54052 .41264 L .53953 .41342 L F
.53828 .41575 m .54052 .41264 L .53953 .41342 L F
.495 .49 .781 r
.36323 .53455 m .36503 .53137 L .36209 .53226 L F
.36323 .53455 m .36558 .53383 L .36503 .53137 L F
.66 .326 .398 r
.38337 .52 m .38785 .51771 L .38344 .51734 L F
.38337 .52 m .38779 .5201 L .38785 .51771 L F
.774 .425 .395 r
.38785 .51771 m .38779 .5201 L .39224 .52068 L F
.563 .834 .996 r
.37774 .54345 m .38292 .54438 L .38141 .54177 L F
.723 .865 .949 r
.38141 .54177 m .38292 .54438 L .38558 .54159 L F
.819 .63 .647 r
.37878 .51623 m .38352 .51393 L .37903 .5138 L F
.37878 .51623 m .38126 .51737 L .38352 .51393 L F
.806 .611 .638 r
.38352 .51393 m .38126 .51737 L .38344 .51734 L F
.532 .463 .724 r
.51464 .42012 m .5162 .42525 L .51872 .42377 L F
.782 .627 .688 r
.39813 .53104 m .40066 .52741 L .39853 .52822 L F
.558 .365 .576 r
.35992 .52351 m .36279 .52022 L .35986 .52087 L F
.609 .305 .428 r
.37223 .51688 m .37655 .51397 L .37218 .51356 L F
.37223 .51688 m .37648 .51674 L .37655 .51397 L F
.618 .312 .429 r
.37655 .51397 m .37648 .51674 L .37878 .51623 L F
.585 .315 .473 r
.37655 .51397 m .37878 .51623 L .37903 .5138 L F
.794 .657 .711 r
.39778 .53398 m .40015 .53546 L .39813 .53104 L F
.647 .477 .64 r
.52131 .4185 m .52422 .4154 L .52206 .4176 L F
.503 .318 .563 r
.36263 .51722 m .36543 .51933 L .36708 .51499 L F
.36263 .51722 m .36279 .52022 L .36543 .51933 L F
.447 .829 .595 r
.53275 .41989 m .53409 .41886 L .53615 .41738 L F
.551 .332 .536 r
.36708 .51499 m .36987 .51648 L .36965 .51364 L F
.646 .425 .569 r
.36543 .51933 m .36987 .51648 L .36708 .51499 L F
.132 0 0 r
.52859 .42243 m .53142 .42171 L .53275 .41989 L F
.783 .497 .502 r
.53142 .42171 m .53409 .41886 L .53275 .41989 L F
.856 .577 .043 r
.53894 .41883 m .54006 .42293 L .53967 .42025 L F
.825 .526 0 r
.53828 .41575 m .53894 .41883 L .53967 .42025 L F
.856 .577 .043 r
.53894 .41883 m .54006 .42293 L .53967 .42025 L F
.84 .62 .605 r
.39194 .52358 m .39388 .52739 L .39424 .52441 L F
.701 .78 .913 r
.52151 .42246 m .52351 .42479 L .52584 .42316 L F
.538 .502 .763 r
.36209 .53226 m .36367 .52688 L .36077 .5277 L F
.36209 .53226 m .36503 .53137 L .36367 .52688 L F
.781 .832 .891 r
.38558 .54159 m .38971 .5417 L .38782 .5402 L F
.78 .8 .869 r
.38782 .5402 m .38971 .5417 L .39291 .53876 L F
.613 .64 .854 r
.39291 .53876 m .39676 .5415 L .39506 .53742 L F
.47 .461 .766 r
.36713 .5377 m .36845 .53332 L .36558 .53383 L F
.36713 .5377 m .36951 .5371 L .36845 .53332 L F
.692 .437 .534 r
.36965 .51364 m .36987 .51648 L .37218 .51356 L F
.776 .555 .6 r
.36987 .51648 m .37223 .51688 L .37218 .51356 L F
.783 .61 .666 r
.38779 .5201 m .39194 .52358 L .39224 .52068 L F
.635 .509 .692 r
.38126 .51737 m .38337 .52 L .38344 .51734 L F
.801 .645 .688 r
.39374 .53039 m .39853 .52822 L .39388 .52739 L F
.39374 .53039 m .39813 .53104 L .39853 .52822 L F
.502 .653 .926 r
.37557 .54397 m .37651 .5404 L .3737 .54163 L F
.37557 .54397 m .37774 .54345 L .37651 .5404 L F
.666 .76 .921 r
.52973 .42602 m .53265 .42467 L .53142 .42171 L F
.688 .844 .958 r
.53752 .42441 m .54006 .42293 L .53594 .42262 L F
.798 .661 .711 r
.39778 .53398 m .39813 .53104 L .39374 .53039 L F
.39778 .53398 m .39374 .53039 L .39351 .53335 L F
.849 .736 .738 r
.39351 .53335 m .39506 .53742 L .39778 .53398 L F
.78 .8 .869 r
.38782 .5402 m .39291 .53876 L .39073 .53687 L F
.734 .784 .893 r
.39073 .53687 m .39291 .53876 L .39506 .53742 L F
.571 .491 .725 r
.35992 .52351 m .36077 .5277 L .36367 .52688 L F
.783 .61 .666 r
.38779 .5201 m .38768 .52324 L .39194 .52358 L F
.795 .584 .616 r
.38741 .5262 m .39194 .52358 L .38768 .52324 L F
.38741 .5262 m .38942 .52689 L .39194 .52358 L F
.814 .613 .631 r
.38942 .52689 m .39388 .52739 L .39194 .52358 L F
.558 .365 .576 r
.35992 .52351 m .36256 .52309 L .36279 .52022 L F
.571 .491 .725 r
.35992 .52351 m .36367 .52688 L .36256 .52309 L F
.404 .436 .78 r
.36951 .5371 m .37079 .54173 L .37231 .53931 L F
.464 .514 .825 r
.37079 .54173 m .3737 .54163 L .37231 .53931 L F
.646 .508 .68 r
.36256 .52309 m .36543 .51933 L .36279 .52022 L F
.805 .584 .603 r
.38934 .52979 m .39388 .52739 L .38942 .52689 L F
.38934 .52979 m .39374 .53039 L .39388 .52739 L F
.796 .663 .716 r
.37878 .51623 m .38076 .52039 L .38126 .51737 L F
.635 .509 .692 r
.38126 .51737 m .38076 .52039 L .38337 .52 L F
.8 .665 .714 r
.37635 .51964 m .38076 .52039 L .37878 .51623 L F
.689 .342 .382 r
.37613 .52257 m .38076 .52039 L .37635 .51964 L F
.37613 .52257 m .38078 .52281 L .38076 .52039 L F
.711 .359 .38 r
.38076 .52039 m .38299 .52286 L .38337 .52 L F
.38076 .52039 m .38078 .52281 L .38299 .52286 L F
.719 .768 .892 r
.52151 .42246 m .52584 .42316 L .52427 .42091 L F
.595 .558 .783 r
.36503 .53137 m .36558 .53383 L .36805 .5306 L F
.566 .517 .76 r
.36558 .53383 m .36845 .53332 L .36805 .5306 L F
.774 .513 .541 r
.36987 .51648 m .37166 .51979 L .37223 .51688 L F
.702 .442 .528 r
.37223 .51688 m .37635 .51964 L .37648 .51674 L F
.37223 .51688 m .37166 .51979 L .37635 .51964 L F
.787 .709 .778 r
.39351 .53335 m .39073 .53687 L .39506 .53742 L F
.589 .359 .535 r
.53409 .41886 m .53894 .41883 L .53828 .41575 L F
.672 .764 .919 r
.53265 .42467 m .53594 .42262 L .53142 .42171 L F
.763 .593 .667 r
.38299 .52286 m .38779 .5201 L .38337 .52 L F
.38299 .52286 m .38768 .52324 L .38779 .5201 L F
.802 .724 .778 r
.53594 .42262 m .54006 .42293 L .53894 .41883 L F
.783 .497 .502 r
.53142 .42171 m .53594 .42262 L .53409 .41886 L F
.599 .426 .618 r
.53594 .42262 m .53894 .41883 L .53409 .41886 L F
.59 .534 .76 r
.36367 .52688 m .36503 .53137 L .36805 .5306 L F
.646 .425 .569 r
.36543 .51933 m .36945 .51997 L .36987 .51648 L F
.727 .499 .58 r
.36945 .51997 m .37166 .51979 L .36987 .51648 L F
.775 .807 .879 r
.38665 .53672 m .38345 .53984 L .38782 .5402 L F
.799 .773 .829 r
.38345 .53984 m .38558 .54159 L .38782 .5402 L F
.796 .818 .869 r
.38665 .53672 m .38782 .5402 L .39073 .53687 L F
.696 .516 .64 r
.37648 .51674 m .37635 .51964 L .37878 .51623 L F
.654 .746 .917 r
.37651 .5404 m .37774 .54345 L .38141 .54177 L F
.8 .576 .598 r
.38911 .53279 m .39374 .53039 L .38934 .52979 L F
.38911 .53279 m .39351 .53335 L .39374 .53039 L F
.646 .508 .68 r
.36256 .52309 m .36659 .52377 L .36543 .51933 L F
.642 .524 .704 r
.36256 .52309 m .36367 .52688 L .36659 .52377 L F
.723 .865 .949 r
.38141 .54177 m .38558 .54159 L .38345 .53984 L F
.537 .499 .761 r
.36951 .5371 m .37124 .53277 L .36845 .53332 L F
.36951 .5371 m .37222 .53652 L .37124 .53277 L F
.404 .436 .78 r
.36951 .5371 m .37231 .53931 L .37222 .53652 L F
.335 .132 .449 r
.52772 .41493 m .5275 .41857 L .52989 .41464 L F
.52772 .41493 m .5275 .41857 L .52989 .41464 L F
.77 .545 .592 r
.38281 .5253 m .38768 .52324 L .38299 .52286 L F
.38281 .5253 m .38741 .5262 L .38768 .52324 L F
.698 .612 .756 r
.36367 .52688 m .36817 .52706 L .36659 .52377 L F
.59 .534 .76 r
.36367 .52688 m .36805 .5306 L .36817 .52706 L F
.678 .527 .673 r
.36543 .51933 m .36956 .5222 L .36945 .51997 L F
.36543 .51933 m .36659 .52377 L .36956 .5222 L F
.641 .54 .725 r
.36817 .52706 m .36956 .5222 L .36659 .52377 L F
.36817 .52706 m .37064 .52673 L .36956 .5222 L F
.659 .489 .643 r
.36817 .52706 m .37088 .5296 L .37064 .52673 L F
.36817 .52706 m .36805 .5306 L .37088 .5296 L F
.762 .915 .941 r
.52427 .42091 m .5275 .41857 L .52558 .42074 L F
.519 .377 .629 r
.36845 .53332 m .37088 .5296 L .36805 .5306 L F
.36845 .53332 m .37124 .53277 L .37088 .5296 L F
.801 .56 .574 r
.37175 .52195 m .37635 .51964 L .37166 .51979 L F
.37175 .52195 m .37613 .52257 L .37635 .51964 L F
.794 .588 .622 r
.38741 .5262 m .38934 .52979 L .38942 .52689 L F
.63 .533 .726 r
.36956 .5222 m .37064 .52673 L .37354 .52612 L F
.617 .479 .67 r
.37064 .52673 m .37088 .5296 L .37354 .52612 L F
.834 .725 .745 r
.38911 .53279 m .38665 .53672 L .39073 .53687 L F
.784 .704 .776 r
.38911 .53279 m .39073 .53687 L .39351 .53335 L F
.748 .635 .736 r
.36945 .51997 m .36956 .5222 L .37166 .51979 L F
.296 .029 .328 r
.36956 .5222 m .37175 .52195 L .37166 .51979 L F
.63 .533 .726 r
.36956 .5222 m .37354 .52612 L .37175 .52195 L F
.747 .514 .578 r
.38078 .52281 m .38281 .5253 L .38299 .52286 L F
.565 .562 .809 r
.37231 .53931 m .3737 .54163 L .37651 .5404 L F
.77 .545 .593 r
.38281 .5253 m .38495 .52932 L .38741 .5262 L F
.8 .589 .616 r
.38495 .52932 m .38934 .52979 L .38741 .5262 L F
.482 .301 .558 r
.37088 .5296 m .37352 .52897 L .37354 .52612 L F
.512 .373 .628 r
.37088 .5296 m .37342 .53157 L .37352 .52897 L F
.37088 .5296 m .37124 .53277 L .37342 .53157 L F
.747 .514 .578 r
.37605 .52541 m .38078 .52281 L .37613 .52257 L F
.37605 .52541 m .38061 .52577 L .38078 .52281 L F
.38078 .52281 m .38061 .52577 L .38281 .5253 L F
.77 .556 .609 r
.38465 .53224 m .38934 .52979 L .38495 .52932 L F
.38465 .53224 m .38911 .53279 L .38934 .52979 L F
.577 .549 .787 r
.37231 .53931 m .37482 .53592 L .37222 .53652 L F
.37231 .53931 m .37651 .5404 L .37482 .53592 L F
.654 .746 .917 r
.37651 .5404 m .38141 .54177 L .3791 .53929 L F
.77 .721 .807 r
.3791 .53929 m .38141 .54177 L .38345 .53984 L F
.462 .406 .709 r
.37222 .53652 m .37342 .53157 L .37124 .53277 L F
.37222 .53652 m .37482 .53592 L .37342 .53157 L F
.783 .705 .778 r
.37175 .52195 m .37354 .52612 L .37613 .52257 L F
.424 .224 .502 r
.37354 .52612 m .37605 .52541 L .37613 .52257 L F
.501 .316 .562 r
.37354 .52612 m .37566 .52827 L .37605 .52541 L F
.37354 .52612 m .37352 .52897 L .37566 .52827 L F
.777 .705 .783 r
.3791 .53929 m .38345 .53984 L .38189 .53576 L F
.705 .669 .812 r
.38189 .53576 m .38345 .53984 L .38665 .53672 L F
.76 .542 .601 r
.38041 .52879 m .38281 .5253 L .38061 .52577 L F
.38041 .52879 m .38495 .52932 L .38281 .5253 L F
.766 .627 .706 r
.38465 .53224 m .38665 .53672 L .38911 .53279 L F
.714 .498 .595 r
.37566 .52827 m .38061 .52577 L .37605 .52541 L F
.37566 .52827 m .38041 .52879 L .38061 .52577 L F
.629 .521 .712 r
.37342 .53157 m .37566 .52827 L .37352 .52897 L F
.69 .612 .764 r
.37482 .53592 m .37651 .5404 L .3791 .53929 L F
.734 .613 .724 r
.38189 .53576 m .38665 .53672 L .38465 .53224 L F
.739 .57 .664 r
.38029 .53167 m .38495 .52932 L .38041 .52879 L F
.38029 .53167 m .38465 .53224 L .38495 .52932 L F
.629 .521 .712 r
.37342 .53157 m .37778 .53257 L .37566 .52827 L F
.634 .508 .692 r
.37342 .53157 m .37482 .53592 L .37778 .53257 L F
.69 .612 .764 r
.37482 .53592 m .3791 .53929 L .37937 .53666 L F
.686 .566 .714 r
.37937 .53666 m .3791 .53929 L .38189 .53576 L F
.719 .639 .767 r
.37482 .53592 m .37937 .53666 L .37778 .53257 L F
.705 .632 .772 r
.37778 .53257 m .37937 .53666 L .38189 .53576 L F
.733 .612 .723 r
.38029 .53167 m .38189 .53576 L .38465 .53224 L F
.705 .632 .772 r
.37778 .53257 m .38189 .53576 L .38029 .53167 L F
.713 .557 .675 r
.37566 .52827 m .37778 .53257 L .38041 .52879 L F
.749 .608 .701 r
.38041 .52879 m .37778 .53257 L .38029 .53167 L F
0 g
.69882 0 m
.93564 .37358 L
s
.93564 .37358 m
1 .96995 L
s
1 .96995 m
.73687 .79033 L
s
.73687 .79033 m
.69882 0 L
s
.0869 .22952 m
0 .90341 L
s
0 .90341 m
.73687 .79033 L
s
.73687 .79033 m
.69882 0 L
s
.69882 0 m
.0869 .22952 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{268.313, 275.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006B0001W2000`400?l00000o`00003oo`3ooolH
0?ooo`800000N@3oool00?l0oooo5@3oool3000000030?ooo`000000000007P0oooo003o0?oooa<0
oooo0P0000040?ooo`800000N03oool00?l0oooo403oool3000000H0oooo00<000000?ooo`000000
M`3oool00?l0oooo3@3oool3000000T0oooo00@000000?ooo`3oool00000MP3oool00?l0oooo2`3o
ool2000000`0oooo00@000000?ooo`3oool00000MP3oool00?l0oooo203oool3000000h0oooo00D0
00000?ooo`3oool0oooo0000001e0?ooo`00o`3oool50?ooo`<000004@3oool01@000000oooo0?oo
o`3oool0000007D0oooo003o0?ooo`<0oooo0P00000D0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0LP3oool00?l0oooo0`00000F0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0L@3oool00?`0oooo0`00000I0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0L@3oool00?X0oooo0P00000M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0L03oool00?L0oooo0`00000O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
K`3oool00?@0oooo0`00000R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0K`3o
ool00?80oooo0P00000U0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0KP3oool0
0>l0oooo0`00000W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0KP3oool00>`0
oooo0`00000Z0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0K@3oool00>X0oooo
0P00000]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K03oool00>L0oooo0`00
000_0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K03oool00>@0oooo0`00000b
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J`3oool00>80oooo0P00000e0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0JP3oool00=l0oooo0`00000g0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0JP3oool00=`0oooo0`00000j0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0J@3oool00=X0oooo0P00000m0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0J03oool00=L0oooo0`00000o0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0J03oool00=@0oooo0`0000120?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0I`3oool00=80oooo0P0000150?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0I`3oool00<l0oooo0`0000170?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0IP3oool00<`0oooo0`00001:0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0I@3oool00<X0oooo0P00001=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0I@3oool00<L0oooo0`00001?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0I03oool00<@0oooo0`00001B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0H`3oool00<80oooo0P00001F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
H`3oool00;l0oooo0`00001H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0HP3o
ool00;`0oooo0`00001K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0H@3oool0
0;X0oooo0P00001N0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0H@3oool00;L0
oooo0`00001P0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0H03oool00;@0oooo
0`00001S0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0H03oool00;80oooo0P00
001V0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0G`3oool00:l0oooo0`00001X
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0GP3oool00:`0oooo0`00001[0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0GP3oool00:X0oooo0P00001^0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0G@3oool00:L0oooo0`00001`0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0G03oool00:@0oooo0`00001c0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0G03oool00:80oooo0P00001f0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0F`3oool009l0oooo0`00001h0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0F`3oool009`0oooo0`00001k0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0FP3oool009T0oooo0`00001n0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0F@3oool009L0oooo0P0000210?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0F@3oool009@0oooo0`0000230?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0F03oool00940oooo0`0000260?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0E`3oool008l0oooo0P0000290?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0E`3oool008`0oooo0`00002;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
EP3oool008T0oooo0`00002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E@3o
ool008L0oooo0P00002B0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E@3oool0
08@0oooo0`00002D0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0E03oool00840
oooo0`00002G0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0E03oool007l0oooo
0P00002J0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0D`3oool007`0oooo0`00
002L0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0DP3oool007T0oooo0`00002O
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0DP3oool007L0oooo0P00002R0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0D@3oool007@0oooo0`00002T0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0D03oool00740oooo0`00002W0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0D03oool006l0oooo0P00002Z0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0C`3oool006`0oooo0`00002/0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0CP3oool006T0oooo0`00002_0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0CP3oool006L0oooo0P00002b0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0C@3oool006@0oooo0`00002d0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0C@3oool00640oooo0`00002g0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0C03oool005l0oooo0P00002j0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0B`3oool005`0oooo0`00002l0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0B`3oool005T0oooo0`00002o0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0BP3oool005L0oooo0P0000320?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
B@3oool005@0oooo0`0000340?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B@3o
ool00540oooo0`0000380?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B03oool0
04l0oooo0P00003;0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B03oool004`0
oooo0`00003=0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0A`3oool004T0oooo
0`00003@0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0AP3oool004L0oooo0P00
003C0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0AP3oool004@0oooo0`00003E
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0A@3oool00440oooo0`00003H0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0A03oool003l0oooo0P00003K0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0A03oool003`0oooo0`00003M0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0@`3oool003T0oooo0`00003P0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0@P3oool003L0oooo0P00003S0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0@P3oool003@0oooo0`00003U0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0@@3oool00340oooo0`00003X0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0@@3oool002l0oooo0P00003[0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0@03oool002`0oooo0`00003]0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0?`3oool002T0oooo0`00003`0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0?`3oool002L0oooo0P00003c0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0?P3oool002@0oooo0`00003e0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0?@3oool00280oooo0P00003h0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
?@3oool00280oooo0P00003h0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0?03o
ool00280oooo00@000000?ooo`0000000000mP3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo03/0oooo000R0?ooo`050000003oool0oooo0?ooo`000000m@3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo03/0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0l`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03X0oooo000Q0?oo
o`030000003oool0oooo00@0oooo0P00003c0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0>P3oool00240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3`0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0>@3oool00240oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
>03oool00240oooo00<000000?ooo`3oool0203oool200000>l0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0h0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0>`0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`008@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0f0?ooo`008@3oool00`000000oooo0?ooo`0<0?ooo`800000j`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo03H0oooo000P0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0j03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03D0oooo
000P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo03D0oooo000P0?ooo`030000003oool0oooo0140oooo0P00003W
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0=03oool00200oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`3P0?ooo`0504_7/@3oool0oooo0?ooo`0000001P3oool0
0`2e@000oooo0?ooo`0e0?ooo`030000003oool0oooo03<0oooo000P0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0gP3oool01`1^N/l0h^7B0000002n?`d0dgeZ0000003>I`00103o
ool00`23]_H0]D000?ooo`0f0?ooo`030000003oool0oooo03<0oooo000P0?ooo`030000003oool0
oooo01D0oooo0P00003O0?ooo`080>_=]`000000dgeZ0==mJP000000eWQL0>RHL@0RS^`30?ooo`03
0000K`3oool0oooo03H0oooo00<000000?ooo`3oool0<P3oool00200oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`3K0?ooo`0906]Z`03[cKL0a:>h0<BS^03oool0000007O8o`2f`>80
c50=03d0oooo00<000000?ooo`3oool0<@3oool00200oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`3I0?ooo`0<00/8Q023Ch/0Pdn;0?;;Z@1=S>/01C6c00000000T;H0]/3R08>onP3`
YG@0SlWk>`3oool00`000000oooo0?ooo`0a0?ooo`007`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0=P0oooo0P3AW9l01P3Xa[@0JaiH06/NF02^hoT000000000NP<0[FIn?@3oool0
0`000000oooo0?ooo`0`0?ooo`007`3oool00`000000oooo0?ooo`0K0?ooo`800000e`3oool01000
0000Af790<bc`P2bS[420:^9/@0702@`Y`000000001j0000K01kYnl0hgLC000>VP0m0?ooo`030000
003oool0oooo02l0oooo000O0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0e03o
ool0100304L0GUnk09:Ie`2TXM820:KDn00:0000@P000000IggF04FBl03oool0^CX>000>VP1BFkd0
Q@00098103X0oooo00<000000?ooo`3oool0;`3oool001l0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`3B0?ooo`030<?nb@22Qll0X;GW0080O8cH00D0WZ;H078hN@0D06X000000=FX
ZP020?ooo`040<c5d`3J_;`0cjVb0;jYa080TP40>P3oool00`000000oooo0?ooo`0^0?ooo`007`3o
ool00`000000oooo0?ooo`0O0?ooo`800000d@3oool03P2Se6`0I2]c01<0A`20SML0RC9F07b<f01J
F[P0NW6n0:m/Q@000000d?2B0?ooo`2SO:P0l98`0P2Yc_<00`2nZL@0hnkG0>OadP0j0?ooo`030000
003oool0oooo02h0oooo000O0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0c@3o
ool0301XeJd0PTj:03D0D@000000JU:S0<nia02<U]P0FUZh0000002dOi/0dK_400000080^6Yf00H0
l98`0?ooo`31[/H0a7Mi0>7_f@3WlM8k0?ooo`030000003oool0oooo02d0oooo000O0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0b`3oool03@0000009`0403d00P0S0000;00K09I>
M@1;9h<0000001<0002NKY`0knK30=:6000000000`3jbI<00`27=Ul0b;_=0<Rkc@020:XY2P80oooo
00<0a[340?ooo`3oool0=`3oool00`000000oooo0?ooo`0/0?ooo`007`3oool00`000000oooo0?oo
o`0S0?ooo`800000bP3oool02P000000700003d00@0m0040FQaV04h@G`1A8WL0BbN306iJZ`1/G:l2
07gLn`0709oed`000000dGQU0=5hI@3No;L0TiCB09fKd@0208U2L0040;ll003:VZD0n<ZK03L003T0
oooo00<000000?ooo`3oool0;03oool001h0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`370?ooo`040040000O0000M00?05/00@80I1aL00P0DB^406iJZ`1^FZ/0F5>a09YQR`000700
WoGC00000080ahJ=00X0VIgG04ED_@2BGi<0TUnC0=Bc]`3`g;/0g>j<0?S:V`3^TRH0`Zg4>@3oool0
0`000000oooo0?ooo`0[0?ooo`007P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0<D0oooo00D0000S07M2P`0a0480Uc9309A1H@02084kKP0:06i8T`25FIL0ETf/05QC/@1735l002JW
09a2F@000000gIR709D90080bFMF00L0N@0007L0003oe8d0k]g0000>W038[/40k^7303/0oooo00<0
00000?ooo`3oool0:P3oool001h0oooo00<000000?ooo`3oool0:03oool200000<@0oooo00<0U_38
00h0001L00h00P2T=C<0202XFg<0VVJC09YVT`2?KJL0SfjY06eS]P1JE[80A`aO0P20dol01@000000
9P0002H0003HKd40mkn@0080lKfI00<0nnRR0>o>/@003Y`00P3^hL<00`3oool0nmE`0?ooo`0h0?oo
o`030000003oool0oooo02X0oooo000N0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0_`3oool2044000060=b40@0g01H0_UmH0;iOF02TGWd0[VIl0P2=I9d02P2SPK00W7b_06eS]P19
?J40`Ynd0?C:Y01O000000000;alS@3Z[8d20?NoT0090>o9[03liIT0ln^?0>3Jd0003Y`0eMgM0>Oh
Z`0004@0nmE`03X0oooo00<000000?ooo`3oool0:@3oool001h0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`2n0?ooo`040007VP3i]GL0g8@108]3L080efH]01P0c:6/0;>6Y@2cQZD0
SFBM0:=_U`2HK9h0Le6K04TmX@32Wk@0ZShk0<^jbP000000^iNb0=6IVP3ac:`0mkn@0=gFd@3liIT0
ln^?0>3Jd02^^N80eMgM0=cXg@3Q_chl0?ooo`030000003oool0oooo02P0oooo000N0?ooo`030000
003oool0oooo02`0oooo0P00002m0?ooo`0500/0001R<Wl0g95m0=bAO@2oQ9@00P3UZI801@3?Vj40
VEn;09UOR`2GIIH0XfnG0080LdB90P29N[d00`0RYN@0SnCk000000020=JWY`0;0?7<[03mcfd0hoGF
0?cUV@3Ri=D0h=[@0:jihP3EgMd0g>SM0>6o?P3i`E@0>`3oool00`000000oooo0?ooo`0X0?ooo`00
7P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0;T0oooo00<08P0f05E:Z01VU>T0
0P3<jnX0102oLWX0k9MU0>nQL03<RX`20:=bV`0@0:ijV`2QNjT0TX_909:;b@1bJ[/0RGZm07=da@1i
@h8000000<F/`@3C/[T0lLb/0?g?K@3j/dl0cZVd0=g;C@80072e00@0h=?;0=cXg@3Q_ch0nL5D?03o
ool00`000000oooo0?ooo`0W0?ooo`007P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo0;L0oooo00X0000007Y@T`1/AI40LK7h0<b`_P2nYQL0_g9j0>^JK`3XVgL0aWQh0P2kSJD02P2i
T:d0]hn]0;N?[@2BRlT0LVZk08Qi_01cM<D0ND>200000035[<420>k?]0070?g?K@3j/dl0cZVd0=g;
C@3CV9L0ZH>[0>og/`020>KPcCd0oooo00<000000?ooo`3oool09`3oool001d0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`2e0?ooo`030000000N04H0TgN`0080ZYo;00H0jn770;E`
P`2eL8<0jiY_0?6`QP3CVIT20<BIZ`80[7fQ00@0_8FJ0:>9^@2HU<d0Y9[;0P27__T03@000000UIOC
0<W3e039`m@0oMnO0>kTa03>ZK@0kI<S0=>HU`3]lLP0koNc072Wl`3Vh<d0?P3oool00`000000oooo
0?ooo`0V0?ooo`007@3oool00`000000oooo0?ooo`0b0?ooo`800000/`3oool20000000400000P0N
04H0KcAf0;ajR080aWj20P2kOY001@3YZhh0lj]f0=jHQ03DVIH0_8BI0080`hZI00L0`ZBk09b5^P2j
fo00^]_`0;K1hP2/foP000000080QMSo00D0JM7j0=oUf03XdKh0j=6n0>fC8`020?kOS@030?:V=03o
ool0000003l0oooo00<000000?ooo`3oool09@3oool001d0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`2_0?ooo`0701l0=00000004`0;00D0001M3D/0H`]10<^4Q@020<=jP080agn2
00D0jJ>20>b/R`3<Og/0b7em0<1gO`020=6OXP070=FRXP2`eo@0/=Od0;[Kl02ciOL0[_;d00000002
05;1n0070531m`38cMd0b<gM0>cdb@3LjMd0f_;P0?oEO@0204Vnm0030?W:G@3oool0oooo03d0oooo
00<000000?ooo`3oool09@3oool001d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`2/0?ooo`0800000003000000000000000W0000D`0A07M4QP2LKih20;^7W@050<AhN`3DR7`0e8Ql
0>R^U03XXX800P3<Og/20<9jP@80f9R?00L0d]OL0<7Yl@37kNh0eOWR0<WkiP000000K[7i0080N[ck
0P33io001`1UfND0f^oP0=[_h03oeGd000000?_WY@3ibUd0@03oool00`000000oooo0?ooo`0T0?oo
o`007@3oool00`000000oooo0?ooo`0f0?ooo`800000Z`3oool30000000304h00@1200T0PB540080
SRi900@0T4E]0:mNKP2_GVh0cX5k0P3TZYH02P3YY8<0iJJ>0<f?TP35PHP0a8ZG0=VLT`3_d[D0o>BQ
0?O`[03HgM/20=Wbh@04083DR@000000XL?a0;_4h@80ZI_700P0XgNR04nWn02U[]h0ZMkj0?oEO@1Z
TNH0lOJb00X>S440oooo00<000000?ooo`3oool08`3oool001d0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`2Q0?ooo`030=RY7`3oool0oooo0080oooo00T0000001`0000S02@01@00
04`0<P1703/0AP0Q07D15P2<6RD00P2R?TX20<R1Q00M0=68P@3[Y840jjB10>B?JP3UYXh0ei^E0<>6
T@3FTh`0fIbC0?gQT03/fl40m>Bj0>SWcP3^kLL0e_2C0>76_@000000VjKN0:JLb`2<V]/0XJGI0;=c
RP0Q[/80_;oL07?3oP35lIT0ZHVc0<[gjP0:3X`0@@3oool00`000000oooo0?ooo`0S0?ooo`007@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo09l0oooo00P0Va800=RY7`0D00005000
09j]hP0A0000W8o5028000<0HLOl0P1;00h2094R;P050:4g?@34OXD0cXj?0<j>S`3=QH@00P3TTVl0
4P3TSfX0gInA0=fOT@38Tih0eY><0>:cYP3mhI00k=_10?CT^P3RkMP0ioW<0=K`T`3Qa[d000000:?3
l02Zanh0S9[K09>EdP80/g>:00D0Fb=`08g@oP2Sc_H00P1`0;bV``130?ooo`030000003oool0oooo
0280oooo000M0?ooo`030000003oool0oooo03X0oooo0P0000230?ooo`80Ll_o5`3oool01P2gm_40
00000?KX]`2ZiXl0f:TO0>:gZ`80mM:Y00@0NP0009>Yi@2CZND0T]3m0P2Tf?X0101f00@0SQ<A08hC
4@2S=3<30<5@=P80cGYa0P3VVg`04@3MSG<0i8]Q0=EoK03PR6D0h;F[0??VQ03ik9l0k=_10?SMZ`3^
kLL0f^n@0=g/R03Nh]L0000006jlo@22SmP0RiKI0080ZK;O00D0e]7D09R9`P2?e_l000000=^l^P14
0?ooo`030000003oool0oooo0280oooo000L0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0O`3oool203Y=^`0300@b]@3oool0oooo00l0oooo00@0Akkb0280000R00008P000P1Id;/0
1`1d<Vl0gKfi0>fcT`3_]Y80bZbk0=WoaP2RcOH00P2/`^X0202_/]/0[[SP0:jhh027g?h0^n_d01NC
i`1o0000T``00P3DPg<03@3LUhL0gXU[0=VDR03IU8P0i:VE0>bVP03ITX@0kj^30=JIU03LTgl0llNQ
0>[9CP3kiil00P3adk803`3ekKP0cnEk0>KOc03BoMh000000<2W`@2O/>@0UIKB09TiC@2Y/]l0:@00
06Mdc01g?7/0T[O`0?[XZ`150?ooo`030000003oool0oooo0240oooo000L0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0NP3oool00`1mBhT0PDZ608gAM@0205f;iP0603Y=^`2MS/@0
WQ8009/C003m`h40nlB91`3oool20000P@0402l0001ceI/0000105mI]080000]00T0Wkk_0<;Ej032
eNP0`]GX0;o@i`3fj;L0_m3W0>nfTP3gi[@00P37o]l0102?[n`0PZ__08:[k`2G]nh20<k1c@080;_[
m03NOU<0cU8?0>B<H`2d<P<0gHEV0=bGQ`3PVhD20<acI@0@0?NUEP3Y[Y<0i[VW0>jgU`3BP7<0k:j>
0>oZR@3ZbDh0oMJI0?WV[P3adk80mNfh0<oUN`3Co]T0d_gN00000080^Jc=00<007S305dRK@3chkX0
0P3Jg]X00`2h`N00J<nI01H?Q`160?ooo`030000003oool0oooo0200oooo000L0?ooo`030000003o
ool0oooo03l0oooo0P00001i0?ooo`0409QaY@1mBhT0F]3^04P<GP80^_Ri00<0oooo09?QU`2@UmH0
0P2@UmH00`3ijj`0LT660?ooo`030?ooo`0A0?ZdK`0R05@0B15V00X0000[0000C@0006Y8UP1cOm40
^JG404k;i01oZo00K`000<j9R02@[NX0_m3W07QkbP0a03@00`2D82D01@10Z_H0P;7d082am003U[h0
d;Bn0080d<?>01L0gjTR0<a[EP3LMdX0hh5?0<iaGP3QQf80`54h0>nCC`3GME@0b7=/0?BKB03^a:L0
fjJN0=J6MP3JWI@0m]6V0>oZR@3ZbDh0oMJI0?oHR`3hj[40n^B;0<O`kP020:jni@030;G2i0000000
Vej70080J3N100D0ln>j06MP]`2gT[40`YV^02dVUP170?ooo`030000003oool0oooo0200oooo000L
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0M03oool01P1jOl`0_HjU0<6>W`31
SYl0HU:Y0?NaA@<0oooo00l0i:PT092FeP2@U]H000000=^b[`3;T`80fhT302H0A@2hO980U=b90:jO
b03fe6P0`7Em0000002DH9800`0000020>?ce`0407noo031amh0`LON092]jP80N7_:00P004o40>W?
^`3Yck/0f:>O0=W_S`38]/T0:P0005800080Q@000P1i0Q000`2T:ad0^HnZ0>Aj=0020==kI`030>J3
B03OODh0egMF0080_UY@00`0i7/e0>NUR@3WYHT0gi5h0?foGP3_jXT0l;Ln0?gFV@3of8/0omN10?G_
V`3:f><20:bRc0030:NUe0000000OZkb0080b]cV00@0ln>j00D04`2gT[400000B@3oool00`000000
oooo0?ooo`0O0?ooo`00703oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0780oooo
00<0bhR;0<JebP36]LX00P2jIF/00`31SYl0]<KX0?ooo`020?ooo`80HlWl00X0AS:F0<chj@00G]D0
001F0?cJNP0X<:D0001g0000001bhM/0@P000P170000101NdK0000000;:6Y@37/LD209hnCP0;0;:K
_`2cLHP0/g6804Fnl03:Z[X0]B`00;Oja@3Idm80b9bY0:7db01GZoT00P2gU;<06P0079D0m:ag0:/b
7`2[<Ql0VU9e0?c4H@3Nc/T0b6iT06`YJ00m0000X1P00?B/M03INEL0i;nb0?cDV@3ab:H0fH1T0;YO
H03[VVd0oKmN0000S`3`]ch0oMIg0?o=LP3oeh4000070P20[O40102[Ym<0`ZJl0000002@]O020>Oi
[`80YZ?C00<04cjl0?ooo`3oool0B@3oool00`000000oooo0?ooo`0N0?ooo`00703oool00`000000
oooo0?ooo`130?ooo`800000L@3oool209R6_P05044iX00008L0[OWB0000003h^Dd00`3oool00`1N
B:00BH?U09BFd`020:eYP`08001Vd@0005H0dfD0001SeP0007X0000n00L0M02DG8`207_Io@070<JB
W`0506H0/XJU0<^:SP1AD;80RfbY03QGaP020;:B]@0409Vhk@34K6L0cM?N0<gCgP<0T`/001l0`6e^
04T0003>LV00cW9P0=O8c02oA1T0dh5b0>oe`03la640cGih0<MnP01H86h0nKAd0=b_9`3hZdT0h9Z5
0?2JF`3le9T0m[^<0=V0I03CTi00k:Eo0>nN:P3RM2D0liiG0>bk?P3i`5<0l>=k0<7QM`2N_>h0P:ga
0080ZZ3=00H0000008DaFP1L`O`0iGm00<cfjP3Vo;e<0?ooo`030000003oool0oooo01h0oooo000L
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0K03oool200l000<0S0<000@02004
0:MmY@2<51T0002?0P25b_h0101bF:D0GTRP0;:Xc`2j[Ld209:Ad00507LaJ`1W96D0Yo:g0;]59P3C
^c@00P0707@0300002D0S3aS0;VVa`3=E000MhCC0:VehP1gJ[P0DE2b0298`0060000000<0:J1Z`80
KIc]0P3He]H00`33EC/0]5QK0;AHF`020<UJ>@080>ngU03/d;T0elS<0=nIQ@3WgLT0koG00?c4H@3F
QW@20<jka`0;0;?=kP3L[bL0mZ960>J>HP3hk9`0k_2G0?JkS03>Q7l0c7ae0?>]NP3^ST800P3RM2D0
103ih800n:M>0?3SN`30`=T20>N/:`80]hZV00@000000:6NdP2fVKX0iGm00P00001=0?ooo`030000
003oool0oooo01d0oooo000L0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0JP3o
ool01P0=02L0000N00T000090000H00R094O9`80BP0100D0S1@I06e7T`1]Ai<0QDAh02<000020;:X
c`0>0;RZb`2BTM00Mc5[07LaJ`32_mL0dfD00=N?PP3Tim<06BJP0001P`003i<0J`0904D00037/<<3
09Qh[@0A0;aePP18?J80o;Uc03Z<kP2Id?/0KK[m02A]gP000000gLW506M3T`1XA9<0l9EA0>bCF@3Z
]9X0n<6>0?3H^@3Gb<`00P3Of=000`3_mL00XdaQ0?RWC@030<jka`0H0=jaZ03fXTH0k:N40000<`3J
]K<0m[^<0<nEV03[/YD0n=BU0?VgNP3Tf//0gX@40?WPP03ma8800000086Xk@1SUn`0]Z;40:ZC_`24
L[L000000:6NdP000000@<:oD03oool00`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo
0?ooo`180?ooo`800000J@3oool01P137G/0000101`0B01402D0PX?;07LB=@80LA0i0P3D`lT00`0W
89<0KDNC08Y>P`020<2@Y080aZ2a00<0ZfR305=be030W[H00P38b]`0203Idm<0i>OC0000N`0e:iL0
00B80000I`0/0000G2]k0P2JAF802@0M0000VU1b000aWP00<Ih0GP000:[e_P0Y00`0cZnk0?OX]002
0:P`80050:Pb9P3LZJ80eW5?0=IaC`3P[9h00P3KN4h03@3>Ke/0ek>f0<=lQ033O8@0n:M=0?bhJ`39
PhD0g[6X0>ndT03__I`0nKEg0<UWE@3=UY`00P3?Ui/0403[/YD0g^[K0>;`f03Tf//0n>VB0?WPP03m
d6l0?P00086Xk@2fc>/0H3b?0:ZB_@2@MK4000000;OPm02koMUA0?ooo`030000003oool0oooo01`0
oooo000K0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0IP3oool01`0E>KH0QejL
0000>@22Pl/0000004@0:`2@LJ`00P0h0000102[;aL000000000001O00020<n4O`80_Gf=00@0ZfR3
05=be01CL]@000000`2@20001P3obGd0=B^G0000N0000640GRek06D0:`80700000L0`7R109B3_P3M
fM<0gMWC07D0003:OW`0QDEi0080Jh?I00P0b;C606i_``000000ioS>0:e7B02k>040T00006000080
Y2lV00<0YA/00;Q2:00Y00000P0f]nL20<ong@0>0;W_m03HLP00]59C001e^`3AW9l0fZ>L0<jQZ@3[
/YD0iNGA0>;`f03Tf//0n>VB0?o=N03`m[D20?ooo`0600H[[@1P?8l0ZY:m091e/@000000koJoD`3o
ool00`000000oooo0?ooo`0K0?ooo`006`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo06D0oooo00H01c:d00lh]`27RLh0QhW>02h08`2@LJ`206mGYP030=_aT`2[;aL0o=>H0080PeB@
0P34SIX20;emS@030:]XP`2^=1d0_9Rc0080Odf<00T0b:Zl0<ba_`3nfhL0ZI2l04]L`P000880>R26
01804`2MEGL00P30N8430<:jdP0?0=3=e`2i_ml0Zngi0011[P1[PmT0YlSa06i_``000000^iNc0;VF
]03Ne<h0eGYQ0=ehB02j?a/0gXMY0080cWY_00X0e:^^0<RT]@3Uk]@0PE:A0?WS[03LgML0f7800<fh
aP008Jd000J@0P3L[jT01`3KmIl0iNCA0=_eg`3^l<P0k>_;0?3f]@3fh7`00P3oool0103EO000RhkA
0:RPcP3FnN42000005<0oooo00<000000?ooo`3oool06`3oool001/0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`1S0?ooo`0<04U3Z03NKAh0U^jm08Ml`00`88d0T;kf091a[00VYNT0
b_oD0=[meP3diK/0<cf]0P2hGV020=9]C@040<F7TP37YkP0ajNh0<NW^080XVF900@0Odf<0<ba_`3<
/Kl0o]^70P14G<H01@0004@0AR^<04H[S01cGZ`0DT^[0080ZBH100<0001C0=3=e`3@cML00P3JdM00
302m/<`0VMWm05bjo00k000000000=g1_@3Ne<h0iJfI0<bJXP3h]gl0g81M0?NiQ@80g:2F00D0e:^^
0>G^e03Vlm<0bnW[0<Kgk0030;O=j`060=Gm_03/gL@0d=3I0?3]a03Bi>@0hOGH0P3<k^/00`3am:T0
e_NS0<gWO`030?ooo`0408^>d@3;eN40bmGQ000005D0oooo00<000000?ooo`3oool06P3oool001/0
oooo00<000000?ooo`3oool0C@3oool2000006<0oooo00D0V3]A09j<`02NS<00Qgc0030PS@02092n
mP05091a[00hT>l0b_oD0=K<d02/Y]400P34QHl20>NURP030=RLUP3H^kd0@hS[0080IUfd00`0Wgn`
08j2`P3;XZh0mnn`0?kKQ`2m[B40BfW?0000C`0O4hL0<B6=03XXT@1W@I020;ZXa`050:kjf`3GaLP0
XSe60:8mAP2200000`35]<X0203<gnH0UJCO0=O8c03CYJP0iZbF0<nU[P3[d[/0i<o30P3RaK/02@3i
g:X0co_T0<SofP38omX0Vo;60=3Bf`3CcmD0`nK`0<?mi0030=Cgi0070<Ch[P39o>@0bOcT0;knf@00
0000Uo;W00009@040?ooo`040000AP2Y:Pl0oooo000005H0oooo00<000000?ooo`3oool06@3oool0
01/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1O0?ooo`030000G00003/00000
00805P0000<0000000003`2A`OL00P2M]^X00`3Fc=00XmWk061AZP020;V1V080kIma0`3=VJ400`3K
em@0IUfd099HQ`020;ejR@090?RoR@3j`XT0_JdQ03Qdg`0004l0CC:@034QS@21N/80UhS20080c?;[
00P0[_[K00NJ]`07V[L0OgBm0<6]aP35]<X0U?3B0?c@K@80UJCO0P2gU[H02P3ofH@0jm:k0>[Ja03Z
f/@0hoSD0<35gP3Ao]`0b?kM0=[n`@30oLP20=C?e0030<;mh`2moMX0k_?60080]_cD00L0VNoc0<Ch
k034n>`0boWX09gdc`2ClN40[oW;00P0oooo00<000000?ooo`3oool01@3oool02@2R]>D0TJWV0?oo
o`20[?00/Da=094Y>`2/_nP0oooo03icg@160?ooo`030000003oool0oooo01T0oooo000K0?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool0GP3oool01`2;O[l0000o05DGH`36OX<0`k;9
08Ef^`1/<WH00P005ZD02000I]@0B00008KQn`1PDJX0M@d_088/E02iRjD0?L7F0P2hNXl0103UjXD0
RfFQ08]UX@2BF8L20;ejR@080?VgO03ocG80/m]a001LaP0001h0@cZQ05@_Q`21N/820=Bh_@0>092C
dP000000:hc]05Zdo00fW_<0X9kC02VXj@1A>IH0o<b@0?c@K@3m^ed0o;]I0=C=dP3ofH@20=cNe`80
f_[M00T0`<GN0<kof`3?n^D0f_k10=[Ug@3Ek^D0d_kK0=Cn`P3Zm<d00P3AlNP0202fl_@0`_c10<Ck
j02Jl/d0M>;C07OTe03Gm^80eOoE203oool00`000000oooo0?ooo`040?ooo`0607j>f@000000Q@`C
06D0001d0000Q0000P1=00001011`>H0W^ci09k/n@3V/S140?ooo`8000006P3oool001/0oooo00<0
00000?ooo`3oool0D@3oool2000005d0oooo00P0ZJ_H08MDS@0001l0ZoO/0<InP`1gh;X0X82`01i?
b080SB]400/0oooo08KQn`000000000001`00022;5@0^H^U0>:RS`3oag4007?707h00003078UG009
0<^8R`3^^YX0nKMl0?o=LP2eLXL0]]AR0000M`1KG;T0M6fm0080WjSM00<0SLcm09?ag`3CbM000P25
L[L01@2aP9l0XHVj0:69^P0o<9H0o<b@0080h^OF00T0o;]I0=C=dP3ofH@0l>o30=ggf`3@n>H0d?WV
0=7ii03Gn>400P3:h>P0103=m^T0eoCR0=OdhP33o/X20<G_k`090;Gjj02eo>00S^oG0000001XeJ`0
c?cS0>7ff03m^F80nKaA00P0oooo00<000000?ooo`3oool00`3oool200000006070mP`2>5QX0SQHJ
09@B0P170000G`0Z0P2L>DT0102QPk<0gKB^0:[Zn@3/UV8o0?ooo`@0000000<0oooo0000003oool0
6@3oool001X0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1J0?ooo`050000001G
45L0O2mP0:_gk000:K000P2aR:/01`2PP;00VZgT07T]H0060000LBi[07Y7Q`1<7G@00`2^PZD01@3B
PgH0olMa0<mI8P2cBdD0J@/i0080bjRf00H0aee40?^iM`3m_Fd0oleb0;EbQ`0005T2065CZ`0707eD
U`1b<Fh0LS5^0;M`P@3RTG40B5k608kLo`0305g6n`040:69^P2>X>00]mC_0;ODk`80e/S<0P3Qi]L0
4P3GoM/0gOgB0<CliP3FiN40b>_]0;WkiP2dmo00UNkb09S_lP2`nm/0cOk30<?nbP2El<T0_?gF0;Cj
i`2eo>0000000<G`k`80dn_V00<0eMOI0>WUc03i_540203oool00`000000oooo0?ooo`020?ooo`80
_?_500D0U;gc0;o:C@2=Eh`0XWJR0<2DZ@020<Vlc@80ZUaa0P3F_<000`1SGkP0k9IR0000D0020?oo
o`0308_6n`3oool0oooo03D0oooo100000050?ooo`030000003oool0oooo01P0oooo000J0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0F03oool0102<dGD0Ea1G07o9o`0002820;V7
X@050816P@2cWL40/ig10;>M`@2YTK`00P1oJ:l00`21IZX0IPPi0;9_QP020;9_QP050<fLY03od8H0
XKCV0:6diP2;EH/00P3:QXP03P3Q_[D0mk550?gMW03gkYl0001F01E4`0000380=0]]07eDU`23JZh0
e][J08=Z[P3RTG40g>WL0P2EYN000`000000U:3M0:6Da`020>G^e00?0<GRk@3?f^40`oG^0=Ooa`3G
oM/0h?g<0>[h[@3Yl/l0hncF0<KQk02hn>h0b^c/0=OfhP3@omP0`og80080000000@0e_KS0;WkbP2I
jk00@/>l0P2djoL0103<k>/0d=KN0>WUc03/lLX90?ooo`050000003oool0oooo0?ooo`2h`>000`3o
ool01@26<EP0P6BY0:QfV`2cD4l0VSeC0080/]gf0P1W0000102;00005`0001L0002E1`060?ooo`03
0000H03oool0oooo02d0oooo100000090?ooo`030000003oool0oooo01P0oooo000J0?ooo`030000
003oool0oooo05H0oooo0P00001H0?ooo`030241KP0o6GT0RF6N0080^Tm000P0NTJ60:iTNP1mJ[<0
OFZc0:4C003odH<0505f0<7Yl@<0R4j400H0WH:e0<fLY03=W:@0o[mX07f7dP1<H<H2080YDP80ijR>
00X0mk550?gTV@3Xe5h002^`0?[1Q`0005l000N:05aE/@21K[@0]/SX0P3<inX01@3;k^`0c_[U06/f
O@000000001G0080fMSF00D0WWJU0<oJh@2l^MH0doST0<C^l0020<__k080l?Jk00/0olmn0=1kK@3@
Nfd0Zm_h0>?Ic@33o//0fOfm0?BLC@3Aemd0^?_70;WkbP020<78h080cMWR0P34c^<20;Wbl`T0oooo
00@000000?ooo`3oool0TUjB0`2kIFT0201SB9`0U5^;0:J5/@1ZHKD0SS=C0:=OOP0J6i<0:`000P00
000208/000030?N]K`3:B`00aF1?00D0oooo00<0001P0?ooo`3oool0:@3oool4000000d0oooo00<0
00000?ooo`3oool0603oool001X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1D
0?ooo`040000>01;25H0C`1308MHT`80_8FJ00<0MT:30000<@0005H00P2WFW<0103PmMX0N4fA048K
N@1e?7`20<JBX00509f2]@3Me<l0gMC?0?joJ01ohkX00P3;UId20;E1:P0:0<52003g/DD0oNBI0000
0000:;8002N`000010000HX0OXC>0;2df`80i^3>00D0Xmn409dmD03:m^/0OMn^0<B8U00208S4n`07
0>?ZeP2j]mL0_;WF0>Kgd@3Fc=00j_R^0;?Xn0020=WXh00;09c<G`3Xkm00jN7:0=Bb]`3SfLd0oM=c
0;cBG023f_h0Uj_U0?o;PP32`]X00P37b]`01@33d^H0`lkS0<CKjP31k_40000000/0oooo0`000000
1`3YXh40bJ^l0<5kQ@29H9`0Ibif08eNUP3Rm=P00P2>XN401@1aNL`0YL_c0;B?/031X[X0bJno0080
gK>/00L0m]6W0>JBK01m0000O@000;4]00006:80f;:c0080TY3?00<0fHmo0>J34P3oool0903oool4
00000180oooo00<000000?ooo`3oool05`3oool001X0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`1C0?ooo`0300L0>`0Q0000IRab0080[7ZL00L0_hbO0?^aHP3k/F80542m00000017
04P0^inl0080YIC400<0[KOP0:_Hm`2[f?L00P30i?001@3>^LH0o[mX07KP_@11FL@0`ZBk0080]D4Z
00T0`D800>[bcP3mi9T000210000L0000000001D020YX@1nQ<h00P2`]=/01@3Ke=4001BD06T0002i
j8X0^:o@0080`mGW0P2`j?P02@2j]mL0nN:^0=K<d03ZnK40o/=d0?k2MP39]LL0]ocK0774o`020=KK
g00>0>;kd03O`KT0oM=c0;cBG00006H0^c<00?o;PP1eI;80NjO_0<WOj@35f^T0^o?b0:Kgi00h_Lh:
0?ooo`0305K@a@1E01@000000080N2UM00T0e9040<6bb`21C8P0QTEi0000000l0000^F9V0=m`2`2T
[=d00P0000000`33ZL00_J6l0<^X]P020=bk]`0<0?KAY`2^OZ40aGb10<ElP@3PLAl0?U_806A_b@2F
T</0[Ik80>SG``2lET`000N4803oool4000001H0oooo00<000000?ooo`3oool05`3oool001X0oooo
00<000000?ooo`3oool0FP3oool200000580oooo00H00000093Z]`1104H0Kb9I03`00P00000209MQ
S`0509URSP0`G<h0<5c>0;:Na023PLT00P2UU<@20;cOl@80cnGW00D0SnoM0<QB000900002P09045I
a0020?3U`@80`O[[00L0dok40;:m>`0019L0001d0000L@0E8I`0000J0080a;O>00D0c=cU00000000
59@08P000;6Rb@020<SKi`030<?SkP2`f?@0VZcS0080]^?f00P0ZNnY0<;mb`0005`0aN3/0>Clc@20
g?`0IKkn06bko@80al?F00X0gLk:0?gCL`3kbi@0kI5A0=2V[@0j]^d0d/cC0=oDc@35f^T0hmW=2P3o
ool208;Rn00>0200001g9UP0?`000000001f8E80_WJ10440001oBXL0SE:406<gQ@2@SL`0RWBe0:Ib
U`0B000205X2?0030000001REk00PWW00080g;6[0P3KY9`02@2NA5X0H@m:09PB002H4P00H[?k06A_
b@2FT</0S<Wl02hn/@020<jJX@03001G^@3oool0oooo00h0oooo0P0000000`3j[U00oooo0?ooo`06
0?ooo`@000006P3oool00`000000oooo0?ooo`0G0?ooo`006P3oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo04h0oooo00d04`000000000n04D0@@1606DMG@0a04h0OefP08mAP029Hj00
ciRL08^Kg@2bW/@0nk]i0080`;gH00T0OXWD0>3Md`32YK/0`ZFk0;3keP3Vki00ckg90<RgbP2HJi`0
0P00NM`02P1^dID0ZOG`0:CgdP2Om>/00000001=a00004L000VI0000E@0001X20=3?f00408CQZ@23
ZNd0PjW]0:6Hb`80_M__00L0bnGZ0;3Hm02Qj_X0Tm;m09;>o024io00P>SA0080H`0000<0AP0008_F
o`3g[d@00P2MXML02P1Z[?L0_LgV0=7fiP31kYH0hKV^0>75_03@YZd0oN6I0=;<d`3Lk]h80?ooo`0A
04G7c`1g=G007P000380002@CGT0VVRF09MAN@1f8E40=P0G0000002PJi@0Lef[08a_[@2OQkX0j=e]
06<gQ@2@SL`00P2V/N00102MY=X0XjgO0?;dZP0L:Z<2089i`0040>g=]03UUgH0iIMf00000080hgXh
00D0oKa/0<WNj02^eoH0[]Of0>G2/`0202a/g00404YTb`2_DUX0[e9J0:mBFP80UaX@2@3oool0101M
e]`07@000?ReN@0000020;f;X@030?Z^D03oool0oooo0080oooo1000000N0?ooo`030000003oool0
oooo01L0oooo000J0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0B`3oool01`3k
]e@0A<:/05H?EP1F3540>P1905L:C01C0T@00P2CAfd00`1=01X0c92E0<b@U@02000T[@080?^kN@30
_MP0`;gH07j9e02KLZ<0`ZFk09CJoP2FfOh20<nmb@030<Ffb`3@am80c<KD00<000000P2XfoT0203m
a840XaL0004UZ@0008H00012000<V`2e^=/0g?cH0P2Umn<01P23ZNd0/^gg0:k>l02/iOX0T>?l06SL
f080B/WL00D0i?7F09W_lP21]_L0PKKg0<FW6@0206nYm@0307?@oP1lb_l0Bjoi00801iVm00T0dOKV
0>RILP3TR5T0k>S90=2V[@3Sj=D0j?7@0;ombP0K00000P3oool01`0O0000000004@0101U2C`0M29D
07LeL025@gL00P2?C7T02`2>BGL0dk_2048_U01X;740a;?:07jBg@000000OeZL08a_[@2NS<40ThW6
0080YZCD0140V9cF09jUf`2>SLd0]Z;50:4c=01bC9H0TG>]0:NLb`3bh;`0Y[SV0000002lZ<H0cK6n
0>Kcd`3^]3T0bMkX0:6Jc@020=>=Q@060=G[h`3aVRl0;5kA0?V]H@2RJi<0[U9K0P2O@eH0201R0000
>P0003X0000j0000oooo03>h/P3ggk40T];m0`1M00001P3h]GT0_Zc70:n]e@2d[m@0nZi@0>37A`<0
00008P3oool00`000000oooo0?ooo`0G0?ooo`006@3oool00`000000oooo0?ooo`1O0?ooo`800000
BP3oool020000000@`0<09jai@0001L0=P1H02L0@P1G2T`0G`U30P1/1Rh07@2O>4400IBk0=Kih@3F
nN40_jFo0?^kN@1f2240O`lT0358^P3UZ9<0a/GI09CJoP2jAbh0e:b_0<^fa@38]lX0d<OB0;cf/037
`]H0c<cI0;GkhP2]c5H0n]Qd0>RT903cZWH001jY0000H`0001d001BH0080k^c700T0g/K10;oKk@2o
fnd0WLki07CQj`1:bLD0H6_7061/a`1800000P2Hh_d20;?Gl`0307Z`m@28]O<0@KKc0080DL_[00d0
@jcg06dgO0000000YlC_08JTi`2[hOX0`?gR0=3ii@2hh_@0TmWn0:_hd02g;`00nn6X00<0^DPd00H0
I@0006/0001[0000P2YD07XSC`2H?UP208e;N`0;09IGPP1B02l0G@0K03l000000000;@0b0000002=
L:d0Z9C109j<`@2CRLH00P2DYN40102QXmL0TicI08FBf@2>JZD20826d00:0726f@3NiMX0FdfX0?oC
P02FgX/0_:S60000002/WLP0k[@i081la@80[7RJ00<0XWn]09<_@`3aVRl00P1gB8`02`2RJi<0^T@V
0:YBHP2ZDV80XeIb07006`1M00004@000000002`Jh80mmna0080T];m00D0f;jo0=Ojh03h]GT0_Zc7
0:n]e@020;jbcP030>37A`3oool0oooo02<0oooo00<000000?ooo`3oool05`3oool001T0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`160?ooo`80000000D0D`00084fIP2/T[/0[9:k
02L0@P0205`8A00606`6;P29CH40IRmg06H_M`1O0340[59O0P2aB4<01P22Agl0`9fd0>FXT`260000
glQ909DaA080h<Bm0P3IalP03P3Vn/d0c]OP0<KHi`1]dID0W^ZT0?bfI02dhGh0oK]N0?>[M`3/`JL0
C4NZ01=8a@000hd0[^Ci0`0a^;X01@1:aJd0VZ;J0;WIl02ifO00000000807G7Q00L0IK3j09SRo@2H
h_d0Z>Gk0;omhP2fn>h0/o_U0080]_Ga00@0/?[@0=km^@3Yn/@0YlC_0P1P__d02@30oN80Wnci0;SR
m0000000cgid0000S`0000P0V0h006/0000208hA3@040;5LJ@2RCF<0J00005@000807P0000T0H`0]
06OJc`0A0000R5F>08]GSP1H9WH0KcEh0000002MT/L00P2/WlX01@2m]]<0X:cO09JVh@2N[>00TicI
0080PXkF01D0T97@0826d01`Q]T0`ZW105]=Z00X05H0VGne0;nAY`0dD<40[9g80>jd>@1U0000WM[l
0:9o[@2]Q:P0j/Vc000d[`3h[VX0SP@009UBN033Kfl00`2^ATH0301`6T/0B0120000000206`0[Lkb
0;[IJ@3^^Cd0f[2/0<N4RP1ec?l0g>7I0:Fnk080TJ[W00<0_>Kc0?:[>03oool0903oool00`000000
oooo0?ooo`0G0?ooo`006@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo04<0oooo
00`0000002/0:`000000Le2J06i<V@0U03L0A`0[02H08@1Q34H0Ja]C08ePV@1=7gH203P00`030001
R@1]1R`0bFIA0080bFIA00<05P0;0;20X@3OZih00P2600000`1d1B00m/jS0?7[SP020=?8c`0@0=7g
Y@3AfMh0^Oc=0:g[V@27f8X0i?g30<WAh03^VV<0j/Q=0000F`2aUkd0gO7M05^Zn@0N0000ALK:0:[B
m@80P[Ce00T0RkWd0:kc/@3<aM<0[o3f0:G1k@0PJmd04fWL0=:naP2Wlo<00P2gmnl0403DmND0b?oD
0000003_lIT0hoSE0>SHa@3T`[D0fKfm0=K:c`39]LH0a/;G0;cf/0000280[C8L08<0000008l20:b7
[P80Zcll00l0VCM;08XYA@28;Dl0I0m607hgK02P;2P0U20R06dIC00E01h0Pdj808QESP1Q=XD0KcEh
0:^9/P0000000P2UW/l00`2VY=@0/K[P09ZXh@0208JXj`0409ZZh@2;X^<0IXWP09JPf`80<U[<00T0
F4fZ05]=Z0150140ckS40<B[`@0>0WX0NfB]07U6Q`24IjX00P3<LV@0202ROjd0lKZE0?cAV03gaIH0
cU<?0>=g;P3HQG00PBUA0P1`0b40201`6d`0001?04@WR02dGfP0CVG;0:kjfP2oL7D0f[2/0P1<0003
0;]cO`0409o1l02VbO80fmkH0?;A[b@0oooo00<000000?ooo`3oool05`3oool001T0oooo00<00000
0?ooo`3oool0H`3oool200000480oooo00D0?P000000001H76P0R6NV0000000208M@R00501<0>02X
L9@0Z72D07eJWP27Ag/00P23OLD02P1oR=<0[g6=0:maS@34IET0dfi=0000O`1[AY@0f^WO0;b4V@3@
VYd20:ikW00=0?7F]03ajhh0klNY0>o7Z@000340j?_30>ClaP2@jK80X>^V0>7_fP39dN00g=3=0>[8
C@0208b3a0070000C02@hOd0Sn7m08oQo@30Y[l0Tj;O09R_i`020=Sgh00I0=Soa@3Co]/0ZLK^05/f
R`2RS[l0YOG50<[naP3HmN80`ocU0;_h]P2Yi8X000000>3dfP3^hl@0j=S50=W9bP3Hb/`0d/790<Jk
c`39_<h0ZNB;00008P32MGX0_5940<AB<0020;U;>P030:<V502O;B`0U3I>0080YE9Y00h0/gB<08UB
R@1fB8h0MTR>00002`2=?VH0R5RA078YHP2BI9T0/Y_00;2Uc0000000]JS<0;W7i@80_LoW00H0Z[oY
096[j01jW>L0WjkR09Vgk@1[W^l209jmkP04039Jc03flJ`0QgRk0:>Vf@80`[K>0P1FJLX02@1/Mld0
PhS@08>8d02QY]T0dLkG0>kE^@3ldIP0mlFF0=MbB`020:/W0P0605/0002JDWH0`XbL0<:<W00Y0000
FCJ<0P12`n<0202KLjD0X8Fg0=:ka03B^l@0hkRZ0>^6;P2R;b/0`GQo0P3K[JP00`29c_h0l]6_0?Vk
C`0S0?ooo`030000003oool0oooo01L0oooo000I0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0?P3oool01`0U0000LbIM0000000000005`0@03@04`27D8P00P0_02H20:Q`U00505X0
=`3=Lf<0cG=S08=ma@1oR=<00`0007`07@3CKTd0001o02eBa@000000_8BI0=2JW@00Sl80i>;A0?7F
]03ajhh0_gl00?:nV03/mZH0j?_30?kCN03]eF80Y>Wj0>7_fP39dN00d][N0000003JS7T0mJDk0000
C022Di00ih<G0?ODY`2mZlP0Tj;O00<0W]gm00<0XLCb09>_jP0406l00P33_mH02P3JcLd0a^3[0<Wl
h`2loMP0^oRf03L0>`3Cf=`0iN7?0=gKe03Xf<D20>SNb@080=Fj_`36^/l0l??20:3Wn`2H@5/0XAh3
0:V4[02nE4820:PS00<0`Fe]00@0Y3e308<Q@@238D40[ff60P1200001@1303<0Md>5091=NP2RL9X0
^IVg0080`Zg500H000000;Rfe`32bMl0`/WO0;c0g@2[^nD208BHgP0409JRg@2H[>D0UJSS0:6Od`80
aKoD00`0UHG0079X^@2EQ;l0^YFa0=CPh@32o/d0BfW@06Qab@1dO/l0PhS@08Z5b02_Oj020?cAV003
0=YdB`3^/8`0`iFW0080_hnT00H0]HNU08Y7M`0f00l0100009a`W`2`OYh209]cY@090<Zlc@3Hin00
am_X0=WIe`3J`;l0fH=Z0>6cZ03aaJ<0o/9b0080^<3Q00<0nK]?0?ooo`3oool08P3oool00`000000
oooo0?ooo`0F0?ooo`006@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo03`0oooo
00T0U<mZ0404F@0@0000000003D0A`1d?h80QUZF064YM02QN:D00P2dWL001P1?b:`0H`i600@0001/
43l0W@`007e[]080BW;H00h0fLk>0==^C@3<[[`0000>00000038V:D000000000=@3Th]40lMJd0<Ag
NP2oO`00l[jH0=?j[`80o]=h00`0bHT00?OR/@3jfjH0n]^V0=C;d@0Z37L0Q;7b0?oBPP000000001J
0?c>T@3^]iL20<k8e0050<O_kP2Sk?T0e]?F0>Sk^03B`<T00P2b_n<02@33_mH0fok30=O4aP3Ga<H0
l^:m0=Wlf`1j:ET0_?J]0>3Fc@020>7:`P030>CEb03C^L40dKBm0080l??200<0m9lm09jok`00L;@0
0P00L;@0102941<0^fIZ0:DH002R500306L00003095CPP2OCFL0S3eU0080S3eU00L0GQ9C0;JF]P2f
U[H0_ZBo0<Nda`2o/</000000080c<oL00P0_lGN0;[3h@2j`n40WjKK08VFfP2EW=P0UIWE096Dd`80
[jkF00d0Md:309F5`01/F:T0UHBo0;k6h03If=H0XU]k02mRd`1UMm00NX_H07V5d`2:QLP0[gnP0080
fHio00<0fWA;0=1oM@2J60H00P2oSj@0101l<F@0?`=H09Um]02KT/X20:6Ba@0=08ib[`3?^/D0in?>
0>OScP37fnP0`kgD0;>G^P30]Ll0gLW50=k?bP3OcLL0WKW/01mAb@0U0?ooo`030000003oool0oooo
01H0oooo000I0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0>P3oool01`2ZjYT0
AP0a0000000@0000>@1101T0001>00<00P1=0T/01029=el0:`000=6NXP1302T207`WE009081FU`25
BX80bl?C07e[]00X06D0f^ON0<J@W@03<kH0000>008000000100001o08_Ho`3Th]40Y1P00=k4_P3i
^h8000000=;diP3H]KH0a:dQ0<V9003[m</0fm?@0=O;cP2Wi?/0ZI_80P2dXlL02`000000l[^C0?KR
O`3^]iL0gZbS0<^<T@3Pdl/0:UK:0;Kfl@03ULH0000000<0YnOk00D0Rn;l0004Q@0R0g00ho>I0>3V
O0020?CJ/P040=Vo_`3WeL<0g]3;0>gJ_`80b]kX00<0fNcQ0?3c`P1n<V@00P2h`=l20;=MI`040;4i
8P2a>bH0^5580<Z@U`80aINX00L0`H^K09]KPP25A7P0QDAh08i4KP2@BG@0/WZF0080]YJf00H0_ZBo
0<Nda`38]<L000000<g;e`38c=d20;o4gP030;2`f02OY]/0QI3F0080NiWT00D0RY_N08^Oh@2_[]H0
a<OM06Qgc`0206ZGjP0409mZU03>]L80cIVP02=CbP80EhKT00D0F7CD07Z@g01iQM<0Y9C50<jIW`02
0<aoNP80`69L0P2X:a800`2CDGd0VGfd09^BbP020::ci00409jdi`2a]md0d>;U0<KIj080S9kO00L0
^[kM0<S1d`3NclX0iMO80=o=a`2e?@00h>SI02D0oooo00<000000?ooo`3oool05P3oool001T0oooo
00<000000?ooo`3oool0J03oool2000003T0oooo0P000000200T0300I1UH0300;01704T0LC5_06LU
J01=0T/0E@Y?0P3AWZ802@1J@9T0K3Ek08IMV`26GI/0V7:V0<_3d`1gf?`0YGZS05DQLP030<J@W@0K
0=1S?@3CQP006jVi083OZ03fcjD0l?C10<bjbP3Na;h0inW@0000002bioP0//[/0?KU]`3NT@`0clI4
0=O;cP1g4cL0RD=b0:4Q2`2YVlP0iOWA0>Clb`3icI`0m^9o0>[Xc02d[M80cY^Q0080/C8B00d0B005
06<fQ@3@am80d<OB07=mcP2dXlL0mmna0000002Xh_/0ho>I0>3VO03SkMH0m=Zb0080jM6m00L0lmNa
0>?FbP3_gKl0d<_E0=W/h@3bkI@0[hFX0080`W=g00<0a5Hj0;QFD`2hEU<00`39LVX0103<Ng@0`75f
0:UON02[FVh20;B3X00:0:b:/P2ZR[<0_9jj0;bN^P33/LP0^JG50<W3e035fNP000000<[=g080^LkZ
0P2U]^D01P2WcoD0Zk;M09Bhl01kVN@0PI?L08nMg@80b;K800@0DVK909RGd03Kh=T0c[G20P0Q>;40
3020^_T005WA03iXe01HPMl0MI;R07V5d`2JVm@0akG80;NK_03;YK40_fe`09MBNP80N`0000D0agEb
0;^ge@2k]mD0Y;SW0::ci00209b_i@0:0>Sjb@2ldNT0_=7Y08bNg`2d]=T0^J_;0<K5f@3PhMD0glg7
0>KMbbH0oooo00<000000?ooo`3oool05P3oool001P0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`0e0?ooo`0;0000000:0340DP0h02H0000R0000=@0N04L0B@1Q86D0>00_05`BE02N
Ii400P1TKlT20:DZ600405]8XP1Q01X0E`0305L00`80YGZS00<0[_[O0;i>001be9P00P2FFhP07@3K
T`/0IP4/0>JCK03gb5P0l?C10<N^`@3Na;h0inW@00004@36W:d0m]nb0?KU]`3bVeD0`dH00=3Oh`2B
Sld0b?o?0:hX0031Y;`0l;260>jmWP3icI`0fh@00?JV@@2B2000cY^Q07D0003E[K00JFJl0080[iNn
00L0g>CK07=mcP37Oh<0jl=60;2H_`32^]80hog70080hlo400@0fMCC0=CGfP3cek40lmNa0P3_gKl0
203nfY<0g?gF0;^K^02kVkP0U8W508liFP1U0000cWEV0P2jCd020;i@>P030=Z7K`3GQgL0ehMg0080
YfN700L0]GF;0;V:Y032XkX0`Z>j0;bQ_@39ZKX0a;_A0080aMWX00<000000;3Dl`2mdnX00P2AiO/0
102SfO/0Yk[V0;:nh`2lb>@203E^f`<0XZ;E00<0PigS0;:ef`0R<ZT00P3Hdm@00`0005T0Q:KZ07:8
f@0204V=k00306b5fP1kT=`0VY_D0080]i^l00D0]H>O0;f1TP2nUJ`0_YF/0=Rh^P020<o1c0050;kD
jP2OcoP0Wloh07JSkP2M`_800P3=LV40203<XJd0^;_L0<K5f@3AfMh0g]oF0=_Cd@3Qf<d0i]g;9P3o
ool00`000000oooo0?ooo`0F0?ooo`00603oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo0380oooo0P000000200`04D0000002l0?`011hP0DP0g05@0>01m?WL09`ai0P00000207/J?`03
05/MI`1/00009P000080TWZe00H0R7Ji08UQW@2fk_H0n:M=0:kjg`0Q00020<QoP0090<fia`3KT`/0
hjZG0>>ZU`3jfgT0^/GR0<N^`@3Qd/T0hNf90080b^7Y00D0jNC<0?O_[`3bVeD0P<?m07@000020=f7
J@040?BQFP35R9<0nJmW0>NFK`<0@[[b00<09jC[0<jKX@2DEhD00P3G/;0208;Co`80b]_V00@0dg1B
06h0003hYU@0hLa?0P35bmh01@3gfG4077?R0;bXa@2lZ<D0llVT0080bJfn00X0o]ZC0=_HHP2EUM40
]WnH0;^K^02>E8L0YVN70<ieIP3IXY`0`W9d0P3>LV000`3QXi80fXej0<AgNP020;n;W`070<JJZP30
WkL0`9ng0<RX^P2kYlD0enKP0>_?^@020<[]k0030000002bfoD0/nGg0080bm_V00T0V:CM0;_4h@2k
a>40N6bi071JZ@1EIlP0RIWL0:j]e`3Ib<P00P2eXL@03P25Q/d0?F_F09:1_P0dHm80J8ON07BCh`1l
[O80FY_a01eXf`1HX?@0L8cN092If02OYm`0]:O<0P2^/MX01030[/P0ekZl0=Vh^03Idm820<O7fP09
0<G6fP2^Y/l0WLSf09g8mP2`W/D0b:^m0;68ZP38SiX0blSG0080dkk50P3VgL/V0?ooo`030000003o
ool0oooo01H0oooo000H0?ooo`030000003oool0oooo06d0oooo0P00000a0?ooo`0=000000000080
00000000000;0000/ZK<0047R01_AHl0O4f=04/0;026?fh0MbiU06XVI@0204<0;@0307]8R02SJ8d0
YhVe0080TWZe00H0R7Ji09k0l02N`?00/lOY0<E6202Z`^/208[7o0050;3Hm@3KT`/0a[C80<>]a@3j
fgT00P3CffH03`0;0000jOV^0<?<h@33c>40jNC<0?O_[`3aj<40o=2E0??K]P3_dK<0`4L00>6<J@3`
UeH0nJmW0?O7V0020<V3Q@060>NFK`3eWe<0mlMG001A``0VOnP0cm3J0P3Df=/01@2BjoH0X8o30:2?
``3OcLH0emcK0080cmoT0P2o^M<03@1^c?h0L`000<fja`3cbJ@0/jO<0?3Xa034i7/0UYWD09FEd@22
X^P0Mb5?0;VR`@2hV[T00P3;UId01P3BVi`0hHQT0>68I03QXi80dHf90<QnO`80dJJ/00d0aYf^0<NY
^`37ZK/0b:Zk0=Jd]`3@h>@020000;GJl`3=fN8000000;WFkP3Jem@0cKk<0080V:CM00H0SYGF0=gR
f@1hK;T0TXk<05]Va@29VM`20;72i`0702mWf033cn<0BU_203A;_01`Yo<0U[ca07FRkP0205n3gP05
07:6f01^Om<0PKkj03ZAl01`Sn400P2<[^d00`2]_^H0Vi[A0<2_b@020=Vh^0030<:^a@3iZed0alOJ
0080[C`b00<0ZZ3=0;:[dP2`W/D00P2aR:X01033]lh0hif40?2YO03Uf/T2000002H0oooo00<00000
0?ooo`3oool05P3oool001P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0]0?oo
o`050000000F00X000000000001101H00P000002074JB`0504l0?`0907T0Tef>09=MSP26IZH00P27
IZH00`2PT/D0VhBi0:f?]P02099j]@0709o0l02ggO<0]mgc0;OMl`0U[=l0800008F>e@0209>Ie`07
0<Jdb03<_Ld0`jg50?cHM`3CffH000000;KKK`020=OMg00G0<[UjP3dl[80kO790?3G]`3ld9D0lm^f
0>oA/`3m_W80n[Uk0?VhO01@b[D0e/M60;N?[@3Td/@0im?20>kD^@3gaeL0mZLn07:an03?d=X0_^;a
09;[mP2_U;/00P2PSl<04P3G/K80emcK0=6@SP3SlML0g>WL07B8f027;E00M;7h0=G;d03cbJ@0ZB40
0;_meP34i7/0O5FI04PcU@2LL9l0][3C0;F`d`80^[_J00@0`;gG0<^lc@3M[:D0g:^S0P3Ma/802@3H
TXL0djR/0=be/035Z[l0cLWG0<Baa`1QcZ40ZoO^0<KUk@020<39hP030;o6g`000000c];L0080cKk<
00@0i9Uk05AifP35_=40TgB]0P2BS/`207ZAgP0@09V[i02h[/l0fMGD08Z=d00nFlL0E7gM08n^j`1j
CY40BWKK07F@g`0RG=40IXKM07fTk01RXO<0LYo]04V3iP80JjWf00P0R9OK09^Jd@2n[LP0_Zg80:jn
iP32[/D0d[o80<U`I080^inm00/0^Ijm0<fia`3=^LL0/JW@0:2Aa033]lh0`:[30>G<_@3Ydkl0k>_;
0000000V0?ooo`030000003oool0oooo01H0oooo000H0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0:P3oool20000000601l06@0N0000000004L0C01o?G<0GbA]0P2gVKT01@2DR<@0
elO;00T0N@2TM9d0Mf:]0080[XBW00<0VGBX0:2Ba@2KQ;T00P36dN802P2QcOL01@0001bY/`050000
Q2Y?0180000001D001VV07n1b`2OT<@20<bmc@0N0>[j_`000000gOk?0>gga@3bfkL0i/no0>ShZ@3B
mNH0kO790>cZb`3RgM00n>f]0>ZoZ03/RdD0Wi750:RF``38Fcd0`j:h0025_02^]c80eHl30=c=b`3Y
i<`0mlMG0>_2Z`00;;@0I<gj0>G>_`2T6P00T>>O0P2bT;<01@3G/K80hoGF07>fnP3D][`0S^:N0080
Kh_N00X0Qd^00>RoZ`3GZJT0kZ8Z000000007JL0N3A]07iNX`2//mh0]joA0P2g^]`01`2j^mX0^KKF
0;VfeP2i/m@0a;?90=o5_P3Xd;h00P2o[/T0103@dm/0cLWG0<Chk00K00020;?Mm@060;KCk`2hanD0
]<KW0<?7gP000000`lSN0P2WZMP02@2cT;80QfZ[09FFdP2EU]80UigH09^Pf01_TnD0Fg;A0:FZfP02
0:RojP0608Z=d01FOml0EWoO06NIk@1kUN40K83E0P1QL/h01@0EDL/0GWOC0:^ih`22Y^/0FYcb0080
KZCb00@0M;3g07JXlP2Mfod0R/;j0P2T]ND02`37[l80/i^o0;^O_@2kWkd0eLkC0=;9d@38`mH0]jO9
0:>Vf02c[m@0ak_>0080hmG900<011ZK0?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`00
603oool00`000000oooo0?ooo`1a0?ooo`800000:@3oool40000000=07LbK01G6fL0U6NK06]6U01:
35d0200I08o/l02F3`00TF2E02AFc02TM9d0Sd=/08ma[@020;ZK^080a]_Y00L0]<CV0000001jU^80
[ik60;ijQ`1hF:40B<>X0080TGB_00P005kB049af@2Y_NP0d^gV0<KngP000000gM]W0?3g^@80in7<
00<0i>3@0>ShZ@3_d;<00P3ail400`3_i<<0j/>^0>NkY`0207oHoP030>f>9P36WJl0`Yb`0080aWj3
00T0eHl30=c=b`3W]j<0ikNS0>_2Z`3<XA8000jN06V4f`3WfLH00P2SWLl01@1ggK00iNSB0?;dZ@2T
d_P0h]kA0080cKG300T0L3Yn0<B^a034[/@0ejVY0>jR:P000000S97C0;>UbP2IZ>400P2e/mL01P2c
_N40/;7I0;fge02m]m@0^;CE0<Nca`80glFn00H0j=2n0<_6eP2oj?80_nSb00T0002hg?820;cHkP08
0<_@g@2hanD0`KkG0<>ne@2h/]<000000<Bjd02h[<h20<>bbP070:jihP2JW]L0S:KV09:Sh00?01T0
000005N<j0020;>mhP0A0<;Lk@3NhmP0DY;^05:BkP1_WNd0JHkS04a^d`17Jm<0DG;E04UXc`1NMm<0
ZkWS0::Vf@1RPM/0Ui[E06bBi@2=^?<00P2Te_T00`2SbO<0Nk7e092/j@0209RFd0060;b^c03Cc]D0
d/WA0=;9d@2eX/D0]jO90P2c[m@0102b[mH0fN_Q0<O>g`3alj@X0?ooo`030000003oool0oooo01D0
oooo000H0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0903oool40000000;0280
000k02`0P3IW05XEF`2DIi/0ehf00000L`1`=g/000000<6Y`@0000000P30L7@20;:K`0050:FC``2i
Xl<0f=?C0;cj_P3Uo;X00`0l]nl206l0000F0;60X02AM:l0TGB_09VcjP1MQn80V=7l001W[`0f_<l0
enMn0>7hYP3`mkT0kNC60>CPd03Ykll0mnjM0>o@/`3Oa;`0m=nh0>[3[P3Tcl80jLZg0?KBZ@80ij:3
00`0`_g60<J[_`23dOl0Pm7o0=F?0`3LcL/0WIO=0>?l^`0d000000060?V_J01l^?T20<Fhc@080:[?
G@3/nKX0X_3e0>K^d`3>^LH0/Xja001Nc`1oCH/209FJeP050=CAeP3Jmml0`:hS0?3]a@1[QMX00P2b
n^D00`26YNT0WlOd0:Fii`020:VagP030;jfdP2aZ<l0emcK0080emcK0P24jNP01032e>L0bM_V0<WK
iP39fnH20;Bhg0070<6leP31_MH0^Jg>0<:bb`2l[/`000000;j`b`020;Vad@0:0<>bbP2//]d0Xk?T
0=OTg`2Sd_P0;P000000000oLm`0<6[J0;cFk@<0]]kd00D08Xc/06BMl01TWO0005;?04M[d`0205IW
b004055RaP2YVlT0XZKI06:1f`80ZjWE00@0Y[OU0:W;l@2XcoD0VlSg0P1eZ?800`1SW_40Yj[I0;jh
e0020<>`a`070<VV]P2dV[d0aKgC0;??k`2ki_@0fo_J0000000Z0?ooo`030000003oool0oooo01D0
oooo000H0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool08@3oool02P2Km>000000
0000000`03L0600001L0001>03H0FAeY054;E01gi=P206oMk@05085^]01S@Y@0/L[/04<0002;Ij@0
0P2eV;X20;:K`0040:FC``3Hdm<0]/g[0=OWh@80`Jc50P31ZL800`2gY<H0/JC;0767fP020:WSnP0G
04k<dP3Ym<h0eooA0=?fXP3^hgX0h^OF0?3aa03^hl<0l^6l0>_UbP3[hlT0imK50>o@/`3Y_jT0n=^[
0>k@]@3Tcl80k]2d0?KBZ@3KYYh0MH;B0<;maP2_mkd00P0000000`3Ijn00hOfn0:ndg00208cHo`05
0>;dW@3i[fP0d5L003deWP003IX00P34`ML03`3Vk]<0:cN[08mi]`2bS[40dnoV0;1hU@2>Hi/0em3C
0=kkeP3Emn<0k=Jm0?_YX01[QMX0XJCG0>^lXP0206^bnP80IHkT00/0WJ;H0;^dd`33f^X0aM?U0;kd
l@000000e>CR0=oYfP37cml0bMWU0;W=jP020;33j00:09fej@31_ML0^Jg>0;V]cP2mYL40`:Fn0000
0039/lD0^k[H0<76g`80_/KO00<0/;kT0<?Di`33e>L00P24X>H0102K[^@006_B09[Wn`1^gm@208K4
o007032hd00dW_<076KJ06^>hP0XH=<00DS805IWb00206f>hP0606b=h@2<Q<D0TX2l0:^Ye@2W_n/0
_=K]0P2Ua_00102H[>@0VjoU034fYP2WZ]T20;V^c`090<k=f@32eNP0/]Sd0;;Hm03Cl^H0cn?V0=Kf
h`3Aolh0I]F_02T0oooo00<000000?ooo`3oool05@3oool001L0oooo00<000000?ooo`3oool0MP3o
ool200000200oooo00l0H]Bf00000003000000000040I`0^03@0R5>;05H]PP1h?G/0YoK40;^9X@2H
L:@0Og:j05h05@0;00000P2OHXP0102;Ij@0WI350;J_d@2f[m420<_Ch0050:ogk`3Gin40b]_V0<2`
b@2_/=P00P2j/m8209kGn`0<09G:nP1aQmX0i?g20>Cm`P3Jm>00e?Z`0>C_T03[mj/0d_Z^0?3aa03^
hl<0l^6l0P3ah;d0203Wckh0flS60=_8aP3_hl80m=bf0>C?`P3UReh0a/GI0P3SYY<01`006IP000J6
0?7c_`3alkl0>UO50;g^l`1oZ>h00P3SdlL01P3/f/00m:ij0?6[OP0m=Ih0001j07RXl@80em7B00D0
S==j08mi]`2Tf_/0I7;<09RDc@020=GDe`060=gle`2=bo`0SL_l0?S<W02?Vm/0XJCG0P39SYH00`35
PX/0C:ci07B@h0020:?7lP0505oFh02[nMD0T>Vc0=CThP3NjM/00P3;en820<C2f0030;k0f`2h]MH0
WKGY0080[Yg600H0_:C10<B`a`34/<L000000<Zca031]m020<33g0060<K?h@2db>T0]<SY0;;NmP2I
_O40Rl[m0`2WgoX60?ooo`0:000LZ@0[I=H00DO703i`fP11Mml0JhoS06b=h@1XO]D0TYSF0;JZc@80
`KoI00D0`l7H0:2fj01eOm00Lf:`07ZUkP0209f`i@040;[8i@2ne>X0cnOW0<oWi`80]=_d00<0c]oU
0=7ocP3Aolh0:P3oool00`000000oooo0?ooo`0E0?ooo`005`3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo01/0oooo00T0RngE0000000000009P010000003<_L`00@1W07I1P`1m@Wd0
0P0000020;^9X@0306P0000_02d0PTV30080m9mD00D0NWG209N8`@2TZ]`0Y:[L0:WNnP020<chj006
0<Zb`P3</l80`Zo70<RkcP2_/=P0^>7d0P2hmo00102VbO80`ocU0<Kki`3<om/20=kke`050>gUaP3T
ki00mNfi0=Wne`3`lL@00P3Yg/P0103_k/H0jLZf0>O?_P3Rd/P20>oS`P050=2g`@3Eb<d0a/GI0<K5
f@3MblL00P3RnM@03P1;X?H0S=3n08c@oP1_XNl0dh^30?2QK01n^_T0k=[00>c_b`3bUdP0n:eX0000
E00YF/h0GH_V0P0000020:dX000<0000B@2>R<P0`LWP0<79h03Mo=L0/Z7604=Uc`2f[]40n<bL04im
h02M]^T0Yk_X0P2/d_@0203=gVh0LH[L001@[@2ann40F]3]0>;]f037h^/0a=?U0`3Fgmh20<>gcP05
0;VjfP2QW=00YhRd0:N8]02aXlX00P2m[LX00`33/LL000000=;0b@020=CBe`060<??h`36cn40a/oQ
0<?Bi@2EjoL0XO3e2`3oool01@13S^h045OA04eig@17N^00B7oS0080QJGY00h0TYSF0<70f@31`=T0
_<KR0;S8iP2OYm/0QYOM07Eod02M[n@0N9SU0:Rlj02X_NP0eN3O0<OXk@80a^G]00<0[mSe08S[jP3o
ool0:`3oool00`000000oooo0?ooo`0E0?ooo`005`3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo01P0oooo0`0000002`0600000@0003P0<`0i04L0:P0B03<0D01e?h40AP1=0000002@
Iil0001X0080@@1300D0PTR30;2SbP2`XlX0m9mD03@7J@020;fP^`060=Sig`35i^h0aNK^0<GVkP3:
//80c;?20P31`]/02P31nnP0c^cY0=;[iP2fbnX0X_;c0:ofl036oL00gnSI0=kmd@39o]h20>C_T009
0?G]^@3/kL/0k>g;0>g=/`3Sgm00i=K90>;3^@3Wckh0jMS40080jmBn00d0d;O10=O7b`3TdlH0a/GI
0?;H]03Wn:P0oKa^0?o:L03e_I00LZkf07Roo@2Qd_T0G9_a0080Ulgk00`0k>o;0?^mO03naVT0m=5Q
000MY@3X_j`0jKnZ0?O2TP3CQGX0DA9P0000B@25EY8209_dh00;0<[5e@3?]l80olj00;fmf@3Y_JL0
CX;S0;Big@3;a]D0ZLO_0<FO/P2IPKP00P2`]md01P1Vf<00g>cM0>?Db@3Sim@0`>C`0<k>f@80_lWR
00/0a<OL0<>gcP2QW=00XIc@09Am]`2ZUL00]I^m0<2/aP2nZlL0aKC9000000020=37dP050<kVj02[
g_T0Zmki0:[_m`21jM/03`3oool00`001iL0CgWL03IFaP0208FUj@0605j:i@2<ao/0S=kn08cNoP2[
g_T0MZG`0P03RmT02@2K`?80LZKa0:[?l`2Zco<0gNkM0<C[l03<mnT0c_KX0000000]0?ooo`030000
003oool0oooo01D0oooo000G0?ooo`030000003oool0oooo07X0oooo0P00000G0?ooo`80000000L0
3@0<000000000000HAUK00001`1704H0D0iI0080Nd:000L0a5Di0540=`1A03L0E0E808A9P@2GEh80
P62T0080/:?:00<0d;g709n6^@2_lOH00P2_lOH00`3<i>T0XlGa0:2Pe@020;bie`050;KAkP3Do=h0
aM?U0<GCi@3Qm=T00P2SkoL0102jn^/0b?O[0<Sgj`3@olL20>kTa00G0=ciZP3dl;P0knc60>ZoZ03]
cK<0hmo@0>;JcP3IfmP0k/nc0>o^a@3Sf</0o]VA0>WRbP3WflP0f/S80>o>/@3bf;@0o>:P0?o<N03_
fkd0m<FM0=^a[@1S]?`00`2Lf_d02@32ih<0Y^gi0:K]n@009Z<0m=5Q02MBb00>@Kl0h8EN0;95>`02
0;>?/007085BT02YjY/0WmUi0<[5e@31/LX0ckO206mic@020<[ej`030000>025]_D0Z]ci0080aInb
00P0VH6h0?3;Z`00064000290=7Dg03Wb[T0j^W=0=o[f`80c/GB00L0cLKD0:bMb02/WLP0W9?:0;2<
/02WTl40ZYG00080`:c600@0bl7A0<K4f0000000clC@0P3Qm]P00`3AmnH0oooo0?ooo`0@0?ooo`09
0001TP0B@;d0I5F/09_5m@2Gco/0Rm[o06oLl02NjOX0F=;C00@0oooo00<027kR06FYm`25aO`00`2D
h?h00`2Hko<0Wo7c0?ooo`0]0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool0403oool00`0000008Zfd00000002000000070180000M01P0
700H050>F`0k02P0?`1402/0<`0206c5oP04068CD021?gD0PCme05/JH@80Q4V100D0UeN20;2D^P2`
U;X0]9k20<6M]0020>7TeP050=[ah03h]dX0R;_g0<_Gh`2UcO@00P2eWl<01@3Si]D0d=GM0<gJh`3G
k^<0g^cL0080a?_W0P30o>H20=[Tg0040=_Xg@3Ik8P0k^o80>o/aP80flS700H0kLfc0>f_S@3IfmP0
j[nX0?;B/@3Sf</20?kIT@080=6g_`3WflP0f]SF0=WFe03bf;@0o>:P0?bhG03_fkd20<oGg`040>:K
P`3YZ8/0:D>h04YWcP80PXWB00H0hog30<_Gh`0[XNl0g;:]00e1_`29PL<20<VR[`090<O[kP28k>40
A0000=cLeP3CbM00/L[]0;39k@0006T004:m0080_:k<00T0d^CT0:BljP2I]^`018cJ0:6mk03Qj]P0
ZMOg062;i03>c=L00P3blKh02P3Oj]X0bLgM0;nle`2o_=L0/;?K09fPe`2JWmL0[J3:0:nafP2c/mT2
0;O5i0070<GAh`36a=P0a/CH0000003@n^@0c?OY0:Wc]@0C0?ooo`06000`]P0^P>P0X=ol0:3Oo02b
koL0Mn;51`3oool0101G]_/0D<_X002@^P0005Ta0?ooo`030000003oool0oooo01D0oooo000G0?oo
o`030000003oool0oooo07d0oooo00<000000?ooo`3oool02`3oool05@3=d]d0AP0004H000000000
;@0301h000080000000002l060000000>P0P05DBG@1?04D0>@0o06hSG00_16P0Pd=h06dRG@1^<W@0
Od5i05/JH@0208EJU`80/Ik400<0VHNn0;2D^P31aMd00P3;f><01P3JlN00aK;70?RgBP3FaLX0i>CB
09RAb`80]Io30P3Ok]/02P3DomD0e?7U0=gnc@3So<`0d_[S0=oQeP3Mal<0ko340=_Xg@35o]h20>k_
b00B0>W<^@3Xc;X0iMS80=S5aP3Zc;L0n/^F0>jlWP3cd:`0nk5T0>Bm[`3nfI40kMZo0>Obd@3Ie]@0
j^?90??Q^`3lhZ00n>nW0P2>a_X02P2m^]L0e;o50=Boa@3U/Id0kKjS001Pb`2:k<`0bmOS0?o<PP00
00020=ng[`0;0>71^@1_^_`0V=_n04g6kP000000lnRl0<CBi@2gi?D0UlGg0014^02]T;P00P36[/80
1@2mZ/H0omF;09;8nP0WW^h06IkR0080000000H0jJh^04MigP39_<h0bKc>0=7=eP3Bf=h20;O4i003
0<6hd@2_/=T0WJ3G0080VJcT00X0YK?R0;C0h`2j`Ml0Z/S_0<CDiP2ZcO80[=oi0000002mo>D0bo[X
5@3oool00`1]`_h0T>Cl03Bh/00n0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool00`3oool205@0000707IY]`3Ej^@0G@0007GSdP0`0000
<`000000000201L00080000000h0300000D0000N0000A@0Z03l0<@1V8V@0B@YK02P0<@1b;6L0600L
05TBF01^AY80Ne6D07Y9R`80OEBG00D0ZYC00;BVb`2dY//0VHNn0<;;h@020<KGi`070=CYi02[VlH0
bjVg0>O?_`3Eal`0i=W;09RAb`020=Cci@090=[^h037g^X0amkZ0=gnc@3@lnP0d_cP0=KQg`3EdMD0
ko340080h/Rn00L0k_C40>gYb03^klP0jL6/0>[F`03[g/D0gLK10080nM2N00X0k[bN0?^aI03k/F@0
jnO;0>SQbP3ck[h0fNcQ0<76gP3Dd=D0mM^b0P3hkjL03@24YNT0T9oN0<2gd@3>d=/0gLg90=_<b`3U
d<80oLF10=bSV@3haiH0l_BX0<jd`03=]/<00P3Q`KT04`3acjh0lmVd0?SX/@3ji:/0mmZ]0<VDWP3K
Y9`0;U_=08>@f035[l@0h^OF0;W3hP2^jOT0e<_@0>C4]`3VgL/0`;C>0?>eR02eKX000P2LaO@00`2a
WlD0`m?V0=cQf@030=7Df`030;:fg02l_MX0W:oU0080Nkck00@0W[o_0;C0h`2[hOX0WlSe0P2ag_L0
0`2Rm>d000000?ooo`1G0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003oool0oooo
07l0oooo0P00000206800080[UIR0`2331H05@140000K@0D02T0000S00004P0002h0000000000`00
0000000j04H0:`0>04T7EP1803`0F`<m05L3@00c01`0DP0Y05L7B00]0400OUVL06i6TP0209Mi/004
08eb/02LS/@0W8k40;BVb`80^Z;000l0`jk50=:f_P3Id=00/i>f09A/XP35W:l0j=g80>CIb`3[mlP0
V97;0:GQn`39c]h0e^OR0=[eg`2lnnP00P3Gm>800`3MfM<0fM_I0<_of`020<K>h0090?;L^03]jLP0
k]o20>kO`P3Y`J`0l<f]0?G6V`3Y/i/0hLg30080k[bN00T0jo7=0=7ob03[il/0f_CQ0??^_P3]jLL0
`LKN0=C@e@3F_l@00P1ZRn0209^Gc`0B0<k@f`2W_^X0g]?=0=kCc@3M/j`0kjj80=bSV@3Ye<000000
0<jd`03=/Kh0h<W20>KGaP3_c:l0lmVd0?7E]@3ji:/0j[JM0P3Qg=420=Zi^00A0?^oOP3:g^L0b]kW
092jl`3;dn00i<Bg0=oKdP2mYL80lkF80<nGVP3^a:H0liU304>HlP36mNd0Yloe0000K`3Jd]400P2g
/mH01P3DbLl0c=OR09;0mP2Ka_D0]M3^0:c0j080^>We00@0W>Gl0;Ofl@2>k]000000F@3oool00`00
0000oooo0?ooo`0D0?ooo`005P3oool00`000000oooo0?ooo`1o0?ooo`040:?[nP0WP^T09h;Y0000
=P80L`8I01X0HP0L06l04`1A0080D@0202@0001:0000000002h0000M00009`0B0000001<03d0>`07
05@6B01V7el08@0P03X0801V1340>P0l06DPHP1U6EL0000006L`N021AGh0QV2N08]JT`80XX2^0P2^
QZ/01@2_W<@0^Z;00<Fba`37/lH0fm3>0080/i>f00D0U6bR0;gMl02mgO00g]WA0<OGiP020<o?f@03
0=KZh`3Hmn40booA0080dOKV00L0eooD0<38h@34fn/0booK0<CGi`36jNl0f=WH0080oMnN00H0m=>/
0>S;^03XbkP0h[6T0>VcV`3g`i@20=_He00>0>;ma`3TjMD0io[<0<cTj@3ck[h0kNW70<j@T`2@/>`0
en;N08Jnn@2BjoH0JG[A08ODo`25`o`20<OHi`0D0=O5b03Ul]@0^<7Q0=bSV@3Ye<0000000=Nh^P3C
^l80i]O60>S8]P3_c:l0ko740>CSd@3ag;X0hL6g0=fUVP2;GiT0f[Vh0=Bc^03Bg=l20>cQaP0=0<bo
c`31ZL80`JW20=oKdP3Yj<h0LXGG0<6meP3<li`0/^Gh09:Jf000>[80B`0007Vhn@020=72c0070;>/
d@3DbLl0a[oC0<Jod`2S[n40U^?m093Vn`050?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0503oool001H0oooo00<000000?ooo`3oool0O`3oool207<0100507@gMP1O0340G`0a01H0
000h00000P0a00005P0;0000;0000000001A0280000002X0000000008P0705d<BP1A0400J1YE03@0
401J3e40LS1^05H7B01K5U`0Eb9a0000001M4e@0Se1o08iLTP23E9020:V6[`040;29[@2^QZ/0[ic4
0:nLa080aK;700d0f]CC0;FI^`2eVK/0/YNl0>GgdP2km_00a?gR0=;IgP3La/@0g>SL0=_cg`3Dm>D0
aokO00<0b^G[00H0dnCS0:camP3>b]H0iMS80>;Gc03Re<X20=[WgP0:0>kWa@3Xjll0g<g:0>_<]@3T
`K<0jK>K0?oHRP3dlk<0c_oB0=Cfi080gOKM00L0amo[0>kda@2[koL0Znog072lo@2^mnd0Q[ki0080
F;Ol0P0[KM`04P00M/d0N8?A0>OaU@2cjOL0Z?3g06K?nP22go/0fLG60=?3bP3C^l80ilJe0>S8]P3n
a7X0lmVc0?CQ^@3dbJ<0hL6g0=fUVP80c[c800h0_^Sb0=7/i`0I?k/0XE1Y0;_Zm01XbOd0dlkD0?OP
/@3oool0P:K]0=?of03<li`0Yl;]09FLf@<0UlOh00<0Yj;A09jik02^do<00P34d^@01038nNT09P0:
0;iiQ@2nNHD20:VagP0404JWm`3oool0oooo000005T0oooo00<000000?ooo`3oool0503oool001H0
oooo00<000000?ooo`3oool0O@3oool01P3j[eX0PRI:088VBP3?F1l02`0001/00080=00000/0F`0N
07H;:01f2bP0D00603/0600d0000000004L0<`0I0000<`0;05l5?00203/02P0<05P08`1R4Tl0HQaN
068LGP27=5d0000000000P1V:6h0Lc=a09Y_X@25EI40UE^:0P2YQZl00`2`RJd0]9g00;BM`0020;f_
c0050<Fba`3Ef]`0^Zg=0:nRbP3Umm800P3Aemd20;kFk080g>SL00P0e_CS0<Ong`37o]l0cn_X0<gR
i`3LhmX0glS20=oOe080g=_F00<0h]C:0>_E_P3gkjP00P3WgL/01`3LcLX0j_3>0<>kdP3Rbl80f[nn
0?oHRP3HolD00P3Wg<T03`3Qkhl0_OgS0;gmh`2moN<0l_>X0:WOnP15a/00=`000;gEk02^Xld0a/3E
08Zmm`23]?D0M/ko05_?l@020;NB/0040<f__03D_L@0e;g40=W5aP80ckc800<0flW60>W@_03na7X0
0P3^d;D02P3V`k80nm6J0=_Tg03Ki=`0_^Sb0<o=f03d[GL0d<gG0000000o01060?ooo`80O;;f00D0
Wj;G09FLf@1eFZD0WEn70:o4j@020;G3i@050:COn`2Dj?X0M^?P05T0>@2lI6D00P31VZl208I_/P03
0000A03oool0000005T0oooo00<000000?ooo`3oool0503oool001H0oooo00<000000?ooo`3oool0
O03oool08@000000PRI:088VBP2LAf80[hnd07QLY@1l>G40DQUX01P06`1V0bl0N18c03d000000000
9`0H03`0@@0000005P000480:01=01L0E0E906@GE01W5e40HQ9?05T5@P0j03H0=@0U02h0;0000000
WG^]06iK[021G9h0QeNA09A_Y@020:Z7/0060:V7/02bTkL0[i:h0;JC/`32Y[d0`JFm0P3:jN`20;Z]
c@040=[XgP3@emh0f_SN0=[hgP<0`NC`00<0e?3V0=W7b03IalP00P3:en<20=7Gg@80f]GC0P3Ge]L0
0`3[eKh0gL>n0>cXbP020=G?d`80`k_B00<0WM7j0=kYf`3TmMD00P3VkM<01@3OoM80_OgS0<oSiP3?
hnH0b?7^0080mZHn0P25`?X01`2UW/h0=`000;o_lP000000XG2J0:=ZT@2fNI000P30Ujd0103?Xj/0
hkBV0=Jo``3@Yjl20=c:a`080=_9aP3Vg</0j=?00>_3[03^d;D0b_G[0?_AVP3Yi<`20=Wk/P80^M7/
00<0c=_T0>>n/`3oool01`3oool00`1NX?<0F@0006ihc00209ONoP060:cOn@1L^?`0000008HE9003
02X0ISf<0`0K00000`21d_l0gZJJ0?c5R0020:JFa@030000002Se6`0oooo05L0oooo00<000000?oo
o`3oool0503oool001H0oooo00<000000?ooo`3oool0N`3oool01035iGh0TUB303PGO030WkL20000
K@80;`000180AP0007PC=@1C01/0001H04d0000I01T0900002P0100S00808`0304l0<P1c8eL0IA18
05@2@P1=02X0G@0Y04L0601402H205H7B@0507XVE01i?W`0O45m08EMV`29Hil00P2[RK40102ZR;40
/Y>g0;:C]`2_T[P20<:V_@080=3Fg@3;/L00b:o20=[Ed`3Sh=40d=ON0=GihP3NgmH30<;/l@050:c`
mP3HgM/0cMOQ0>CZe@3?d=X00P3Dg=d20<CDiP<0aNo_00D0c<_H0<S6f03/j<X0gO_I0=WRg0020<KK
j@050=WahP3DnN<0f>gR0=S]hP3Do;P00P3NnmH01@3GaLP0d^oW0=J000000000/O_D0080Q/3j00H0
N1e70:1>I`2SLIT0XFnI0:QhW@2bR:P20;B7Y0060=BY[03?Yk00f;Be0=^c/03P]Zd0h<k60P3Jc/h0
203Kh=T0i=_<0>gL`03]g<00j_S:0<GXk`3HgM/0__7b0P0RL>000`0C<k40;@000?ooo`060?ooo`08
09OSo@0c[Nh0<jg^08kEo`2?`oT0PL[o0?ooo`0D000207mHVP0306mic@1V?H`0LdF;0080_gIn00L0
Pe>@0540001o0`T0mkI7001JcP2;Hih000000080TQ8500<0dUX00?ooo`3oool0E03oool00`000000
oooo0?ooo`0D0?ooo`005P3oool00`000000oooo0?ooo`1j0?ooo`030?jnIP3:]<@0b[C40080SR]3
0P3DX:402P001YP0001N06H00`0005X0?000004000234B00@P030000000a000205`06@0307038@1G
0000J@4X0080C00K00X0K1]B05`ADP2;GIH0RefF07QAU`2AI9X0NCil08MCS@2?HYT0S62I0P2[RK40
1@2_SkH0Zh>Z0:^3ZP2oTjT0d;O20080d=KM00<0[ZgG0<CVk`34i^l00P3PimP0103NgmH0goWH0=Gi
h@3EnN430=GLg@060=GWh`3Yck`0jLnl0=CWi03BhN<0f<C60P35e^H20=S]h@80iN_C00@0gO_I0=Kh
h@3Mk=`0b?oB0P3DlND03P2nj_<0d_[R0=;jhP3KoK`0jOW80<Gij`30jO80]ocA0400?`0U02`0@@0j
070RF@2?93@0/eaU0P2dO9L20:MfW0060:UfVP37YKH0ajFf0=>`]`3H];D0i;b]0P3N_kT02P3Vc;d0
g^7G0>O=_03clJ00lM:b0>Scc`3Imn00dMgQ0<Wnh00000T20;^G/`030<kJhP0C<k40oooo00`0oooo
01D0EP8o05`2>P1`64P0O`0003d0003dWS`0ECnK09<Q9`2GUm80`YZ`08=CT01n=f/0PCQ[0?NfA`3I
f]T0=73M0000002XO:<04ioG0=i`200CWmL00P3oool30<>K[U00oooo00<000000?ooo`3oool0503o
ool001H0oooo00<000000?ooo`3oool0N@3oool20<ZAVP0307U7R@000000fkRe0080_[SC01D0/Vb1
07YT[@1jI:d0K:kh00@000140000@@0004D0001>03D0@`0V05D1?`1P0300=P0005d5?@1[4D80QbmC
080eIP1h=Fl0HR=Y0680501e:5h00P2FA6@01026Dhd0NDV;091LT02:EXd20;>?/0090;2B]`2`T[P0
_:o<0;b_c03@]l80gm390=S>d03@e]d0d/gD0080iMg=00L0jM[50>7he`31oLT0fMOF0>7jeP37ind0
_=_`0080fMgJ00<0d=3I0=kWfP3NimX00P39j>`0103_h<00m>jk0<GZk`35j^l20=KBe@050?3f_@3W
k=80koG10=kef`2Om<`00P3Ta[T20>;EbP030=cndP3YnLP0eo_N0080`__X00L0=`1=01T03@0R0000
0@00068[MP3=TYL0/gJ?0080/G:<00`0WfF<0:abTP37W:`0aib/0<RMZ`3DYjT0e[>g0>:cY@3Ka<80
j<fj0>K<_@3cjKd20>SMb0080?oCS03;hgL0dMgQ0=_Xg@2>kmP0000900T0001D02/90?ooo`0>00d0
000g0000=`000?ooo`1M0280La<m06hFA`1H0d00B@0I0;1NKP3l]fD0200007DD>`2C;Cl20:mWO@80
Fh;O00l0Tkcc00002P3b_YT0RAPU0000001l0000eO^b0=i`2000DkX0Mmod08]5M03_WBX0hN_H0=33
cP2e;@00C`3oool00`000000oooo0?ooo`0D0?ooo`005P3oool00`000000oooo0?ooo`1j0?ooo`03
0?>XL@000000h>cI0080d9nT00<0N00008<B900^[N/00P0000004@0_0000TcA<07PK@`0n02/0>007
03h01`1R0c@0K0`h04d4C@22?G00K25M088]E`2A>e/09P0204X01@1e9e/0UTIX0080W6:<00<0FQEL
091EQ`2@G9000P2WPZ`01@2bR:P0[HN/0;69Z`37ZKX0`:Jo0080gm3900H0bkO60=71b`3Fa<P0j?W;
0>WJa@3al/420>?de`030>7jeP3MiMX0fnGL0080^mW_00<0cNCX0<kKh`3YjLd00P3Nd</0203:b=P0
f=GE0?C^^`3PmmT0fN7L0<OMj@3Ni]X0jOW80P3_mL404@3RgM40jO?>0<nobP3fl;40b]OS0>?fX@3L
o]80Y>bU08_U[01>0DL0EPM902003@1I4EL0GQmW064ZM@2?EhX0agam0080c81l00<0/h^/0:EhXP2g
PYX00P3:X[003`3=YJl0f[2]0=^a[@3R/jD0gKfh0=n^X`3meIH0m/jS0>SWc`3FeML0l_6n0>O^d@3[
iLT0eOcO00h0000:0?ooo`0@0<N8T@2;FY80?@1808@aF`0;07P0GP0708/cEP2>BgT0TEZ<078nP`23
?6h0L]?m04d0;`23:4h0]YZl0:=WS0<0ZXF]00d0OS9T0900001]0000l[jI0?6QJ00000001`J30<RN
[@2mV;8000B@07PD=P2L<3T001JQ0080d<;<0P36CAl>0?ooo`030000;@2I=d/0TC]K0080Yf1l00<0
^W1m04NVm`3oool0>03oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`1k
0?ooo`0407DjNP3l]eT0o;AS07eKX080Ra`Z00d0;`000000000U00009@0007hVC`24:e40K0@Y06@0
9025;UD0L1a?0580;`2<=eX0KaeB0080LB=I00L0OReK06DGD`1h;640JRea07DWF`2@A6/0S3aT0080
Uf6@00H0UF:B09=PTP2WPZ`0Yh:/0;R@[@2]Qj`20<NY^P80g=kH00D0bM[V0;S0h03=bmP0j?W;0;[J
l0020;Kcm0040=kcg03Xn<`0j?S<0=_Ug080a[[?00@0h=kC0=oLd`30_=H0`;cF0`3<Rhd02P3DlND0
a]CU0<KDi@36e>D0`NC`0<?fkP3@kNP0bogQ0<GLjP3Yllh30<[hj@0:0<_ck03;ol`0a_oB0:C/Y@0H
00h0<P0Q02<07@1Z85d0TG6[08hdE@80/72900H0cHN70;n3TP2oPi80Xeem0:EOOP2iPYT20<jDU`0C
0>F^VP3I[JX0gkff0>[5/03`_Yd0kk^J0;U[MP000000n=RY0>_C_@3blKh0L=oA097`e`3oool0UXBn
05kFfP28@6l0RP000<oNKP050?ooo`0408F/kP2e_n80PJob07000080N`0200X0D00005h01`2F=dd0
K@0007P46029>5l0RceV0:9?J02]QJ/0Y82]0P2PS;h0302[QJ`0OS9T09UYVP2fTK00ZHNa0;jW`P3a
cZh0000000L6P`38X[80dK_50:3`]P80D`0000D0RdAa0<n0N01LIL<0/GZG0>^RO00206h000`0oooo
00D0j>o@0;AIG`3;SY@0QDEj0:=JN00208h>1@030;UlT03oool0oooo03L0oooo00<000000?ooo`3o
ool04`3oool001D0oooo00<000000?ooo`3oool0NP3oool02P1b>7X0oooo0?ooo`3oool0_Z6k0000
H`0J00001@0005T0001L000306l0000:02h0001@02D0IP0L05h02024<5P0HP0/0680;P2@:Cd0KAeD
084kKP80H1mU00@0G`m;08hgF02>HIT0WFNB0P2RLI/01P2FIiX0Zh>Z0;VJ^@2iV[T0ZXB/0;R;YP80
ajFg00T0kN340=gFd02h`>00^<3P0>7_f@3Qk]T0gn[J0=gmd`3MnMX00`3AnND00`3OhmL0b]WT0=SI
f@020=oLd`030=S9b`31cN@0`LgT0080docO00<0hO7J0<oHh03He]H00P2ljo@04034kO00f>kR0=Km
_@3Tnll0_OK`09[cj02ak_L0]_cI0:Cge`1dg[T0oooo02d0?`1I24L0IAIB04X08P0G03L209AGQ080
]7bG00H0`HNG0;a_N031QiH0`HNF0;V7X@2iQj020<jJW`070=^]Y`3A[K@0jlF^0:ll;P3NM3d0_:G2
0?CT^@020?^eE`0;0?O_Z@2Yl:h0oooo00`0001Z;g<00000078SF@2dFf<0YMOi0<oNKP0OPnT00P3o
ool01@38g6X0<00004@000140000UTab0080SRTo00P0XTQL084XD01G02T0WUMi08a8N0183f@0XgJP
0;:@/P80_9Vc00L0/9Rn0:FA`02PS;h0Xg^V085GU`2fT[40/iZn0080_ZO200L0d/S@00000034YKX0
b:Nh03I1/@2PG7h0jZnC0080i>kF00@0ch1h05aU``2oGeL0_emG0P37LVd00`35Qi008`00080TB@03
07;Do080=ZSb0P3oool01`030000j>o@09oQR`2OhH/0ZjKB0:jVc`2>T]800P1nIJ`00`2iO900bE0L
0?ooo`0g0?ooo`030000003oool0oooo01<0oooo000E0?ooo`030000003oool0oooo07`0oooo0P09
00001@0e0000E00008DH;0190000J`000080L00000D08P0006L2;01m:ED0G00207L03P0208hhF`06
070FAP1]5dX0QBE6080^F`28?6P0N3Yf0P2/Q:T01`2?HYT0WFjL09a[V@2QKiT0Z7ZP0:R3[@2[QJ`0
0P2cT;80202nUjh0/:K>0;2VcP37YKH0lOFh0=gFd03Gbld0jOS;0P3Gmn800`3MoM<0h>OH0>3Wf002
0=WTg@0D0=cEd@3:fN@0g;2Z0=SIf@3?[;H0f<W;0=cagP2CjoH0Xn3l0;cik03QlMX0__S]0=SFeP3Y
m<h0dokK0<g_j`2kl?<0e_fm0<Khj`39j^d20;Scl`0<0:_bm02]n]/0Y?OG0?ooo`000000;@0i04<0
@`1I1dH0IQE?06/hO`2PL9/0/7fL0P32XKL01@2lU:h0^HbV0;V<YP2jS:H0`iNZ0080bijY0P3K[JL0
4@3L^;@0_K??0=NXY`3@_lX0kk^J0?CT^@3iiJh0o]f;09_KP01/f;80IR5Q000000150280=`0E07PL
A`2hFeX0EJ7f0080elW<00D00GgN0?ooo`2_JH00STQe09YAM@0207LXF`0908dnI@2@=580VBDT08i3
K@2SEW80YgjV07=FXP2UNZ@0]9:c0080]YFf00H0aJFi0;NN_`2YX<d0Th_7081[/@2GT<X209lh@`0C
0<2^b03:aMD0T=Wo00000034YKX0=`0007`0000007P0Z8^g0;JH^@2Wjil0Sn6J05@0003Oe/l0g9V9
0<^;S`2oPi80XUQf0:U^S`0209IAN@80U6JI00<0^WjB08haCP2]CeL00P2_DEP02P38Wjl0k?7;0<[6
eP2me>/0YZ[I08jBdP1oJ[40VFZK0<1/KP0002lh0?ooo`030000003oool0oooo01<0oooo000E0?oo
o`030000003oool0oooo07H0oooo0P1i00T20?ooo`0504/02P3CWId0000003h000202aT00P2=6R80
0`2F;cl0IP0F08TL;00208HP>@0503d0501^2c@0USUB08X^CP1m8TT00P2C;3h01@2>D800KAaD06PJ
E@2ODVl0Z7JK0080Rd]l00<0TE1m09e^W02LJiT00P2XNZ00102XPjd0_YVb0;jI/P2bU;L30<2V`00:
0;Jae03?c]P0clkH0>Whb`3Nl=`0g^oL0<cdjP3RjML0e_SR0=SneP80d]3G0P3I_Kd00`3J/[00e8Mk
0=B7N`020>Kdd`050>Kk]03Hk^80c=SS0<cHh`3>e=h00P3@l^P0103?l>T0cNo[0=KUh@36n>/20<Wl
i0040=O[h`34ko00^Oc?0?ooo`<0000000H0@@IK03D08P1A0240C00Z09eXU02_Oj420;F7Y0030<N<
UP30SZ40^HNQ0080^HNQ01`0^G^?0<^NZ@3;WZT0d[:i0=R/Z`3I^[X0iK^[0>C:_@3Nal80knS40>;V
e@3Cl980o]^604d3C01k<VH0A@0K03<02@1h=Vl0B0QH00T0001L4E<0XdiT01d;OP1>03T0fHA]0<E:
6@0l04d0TcmP0P0000002@1iFZ80L`0003P0000h0000500007404P1=0000TdQ_0<UlN`020<6P]`04
0;BPa02m]m@0[;?N0:bcgP80RI3D0P2UY=D01P2m]=00Y;cZ0:BljP2aVKh0000003hNP080N4V=0P2]
JX@01`3;P7d004:/0;Cij`2dnN/0aDdR09IWV@21ilP00P3A_lT01@2UGG/0NbIB07/VDP1m7400<01C
0080YWFL00<0_VQ[0=NAQ@3<XJ`00P1[A900202YaNh0gNCJ05k7n`1Nao/0001m000UZP36W:`0000_
>03oool00`000000oooo0?ooo`0C0?ooo`005@3oool00`000000oooo0?ooo`1e0?ooo`04088`G02^
R[00/JK>04Zdn@<0X4iY00@0J00007/00`1U0000I@000P1T0000101@0000P@0001l0001D000209U2
G@0408XcE`2M>4H0UT]`09mAKP80NbYJ00@0L25H09IUUP2HIYH0Y6B60P2KHhl00`2PK9H0U5j?0:E[
S`020:UiW@030;EmV02nVK80_YVb0080_ZK100@0nNB^0=[Ge03DoM`0hnoG0P3Rhm@01`3Nkm`0aOK]
0>7ff03Fn>80bObm0;Gik02lg?000P36g^/01`3@[kP0eZn`0=J_/03HmIh0d?[T0=[Ug@3Hk^800P3@
d]/0103GoM`0d>_X0<okh`3?knT20<o[j0050=KUh@2KlO00W_7b0:K]n02[nM<00`3oool02@000000
2`0B03X0901H0Sh0HQYL0380802MJ9@0/IJk09QdZ0020:A/T@080;j2T`31PXl0/6j50;1^Q@2jMHD0
aYb]0=RERP3P/JH20=Ve]@0?0=Vj^P3Va[H0i<Zm0=k7`P3Tk=D0i_GB0=?`TP0D01`0=`12078ND01L
2dP0IaYF07/_H`0f01/0@`0g00<08Z?W00P0e8j50>SB`000000000290:Sb]@2GAVL0VgBV06<[L`80
[hN[00H0Wgj^05D0001E0000e:jb0<9iP03CSXP20<6P]`080<BkdP2n`md0_/?M0:Nji`2EWMT0RI3D
08NFf`2X`N/20<fjb00508AoaP2aVKh0000003XaW01cIkL00P2eRJL00`3E`/P0a;W?0?37Y`0208/0
0080KP0000<0PS]^09h/:`2UHH000P2aEUh01021F9P0KDRD09]fZ02PQ;H20<VEWP0<0=2QYP38R8h0
JdB@095g/`2AMk80gNCJ09Fhk`23/o@0V>NT02`cY@0_01@0i>oF>03oool00`000000oooo0?ooo`0C
0?ooo`005@3oool00`000000oooo0?ooo`1e0?ooo`050;JXb`3:Qh/0001M05X08P0000000`1]0000
1@250`00Q08008@200240P00RQ/Z0080Qa0I0P2SBUd01`2JA600RcEJ0;9PK@2bH6d0O2]J05T08@1j
63`00P2N=d400`2FIIH0VSU<0:9IN0020:ELN00609UMR@2ULiX0/86R0;21XP2ZOJ<0^8VT0P3:ZkX0
1@33Y;X0/I_20?WT[P3LfmH0hnoG0080`^Sa00D0e??U0<gki@35m^d0e?_P0=SXh0020=SDe0<0_m_]
0P33`=L0103Fi^80g_bh0=CUhP3Fhn020=?RhP0;0=7_i`3Hm^40f?KQ0=;of03DknD0^o_W0;Ckh`3F
omH0`oZi09Sbh`0000000`3oool02P2inK/01@0600`0001B03d0E00n07d`H@2>G980SD1Y08e3K@2T
@e020;^?Z00O0:U`T`2nOXd0_XZO0;j:W`3<WjT0aYb]0=6X[`3I[:T0kk^K0=Ve]03I^[X0km>f0>C:
_@3dek40ioFP0=Cl]`0000T0DQ5L05PAE`1Y6U<0KBa]05P0301T7V00900Y08=WZ`1iHJ/0bOBR0;9Q
L03EYjP0cj^f02PfZ`0208ADT0030:1fX`22EiH0UfbO0080[hN[00<0Wgj^0:MjXP2hJG@00P3>OgP0
1@3KZ:80dJ2U0=^n_03jcIL0fo?O0080`^K`00<0VJOO09:ZiP2BZ^H00P22SmL02P3=^/P0WY[?09jJ
c`00000031nO07b1c@2@UmL0Qfna0<R=U@2o/</20<IVE`0;0<M`J03:N780bWQb07U;SP2XLYH0SGbl
0:f:/02OU<P0M7G607AT/P2KMZP00`3:[[h02034Y[/0Z:SG09NQf`2GXM/0]kCF0=gTfP21VN40Ui[D
0P2KZn800`2MaoH0n<]N0000FP0g0?ooo`030000003oool0oooo01<0oooo000E0?ooo`030000003o
ool0oooo06X0oooo00@0Nd5m00ZIc@0Y0000@P000P00T;L00`2Dgoh0nL280?ooo`020?ooo`0306db
MP3:Qh/0bXN;0080OPhR00<0TT]c0:Lh<`2W>3<00P2`CU430:9;G`080:=8FP2ZDEl0Ye9U0:MBI@24
:e40URXf04T0001W000209M0G00:08hoIP2:;D`0PRE:088UBP2VO:D0Z7:G0:efU`2[LiD0YgNN0:Qh
W@80]HRV00P0^8ZU0<bfa@3<]/D0akC80<:U_02eYLP0g]S@0>Ofd080g>[M00X0g?_I0=Kob@3FolT0
a_3_0>7Bb@3Va[H0kMZo0=c?c03Ib<T0_KcI0P2h_]h01P2nlO80d?oA0>cfa`3/m/L0e^;O0=3/j080
g?cH00P0g_OK0;cjjP2nk?<0dOgM0:Kgi@3Iom00`oc10<?j^@@0oooo00X0OM>800l000000000B`0e
02L0?01C02@0RD1^08M8O@2[M9D0[gbK0P39Y[H00`2iWkh0XGBO0;V4W@020<JCX@0N0<bOZ@36W:d0
c9ZS0<fLY@3/`:H0gKfi0>_C_03Wc[d0l?Bo0>Wk_`3Dnk@0e?bg060TK01F5V40Hb1T01T0A0100000
OeZM07I@V022FYX0PfN[0;6Tb`2WIhH0djJY0=FWZ03e/7`0X7RV0000M`24E900OHgH0P2MS<401P2I
R/80SfVR09f3]P2GO[L0^6Ud0<MSD@80_H>F00@0k;^O0?C4V`3bm;L0^^cd0P2_a>T03`2?bO/0HKSm
07VGi02VjoX0S/on0;K5i@1hM<40a;W?0000000VA;/0QhgC096Fe02EVmL0_k;=0;YdQ0020<EdL`04
0<5ZI`2I8A`0VB4L09TQ7080J00000L05@000000001]Ik/0KFNk096:b@2MSl@0aif/0080a8ZF00T0
Wf^E09`kC@2L>dd0d=AJ0<74g02=BWP0IWcD0:RC`02do=/00P2nSjD00`2`<@h0oooo0?ooo`0e0?oo
o`030000003oool0oooo01<0oooo000E0?ooo`030000003oool0oooo06T0oooo0P1k@Gd00`0H05<0
N@0007<00003050000050022e016FL80bLY;0=jXWP0003`00P28;e<0102K?U<0V3]B09PkDP2R?4H2
08H@6P0407`0002G5`P0Z4=80:Q3B080Y3De00H0UBhn0;5UN02REG40XUEa0:a^S02ACg`209I<LP06
0:i^R02QIX`0/HFV0;65YP2VO:D0Z7:G0P2[LiD01`2WMih0ZX2V0;NB/032UjX0`JO00<2V_`3@[KL0
0`32YK`01P3bikh0h^?D0>ORc@3_i/<0fm_G0=gnd@80emSH00D0i/Jf0>gJ_`3]f[l0ilRg0=W8b@02
0<;6g@080=?]iP3BmnD0fO_L0=gif`3Kh=X0e^;O0<_VjP3DknD20=kgf`070<khi`3Dmn@0b?[X0=Cd
i@3En^40ioCB0=c`g`040?ooo`80000000<02@000500@@1o=f/00P2FD7P0202YIX<0Y5mo0;UbP01m
5S@0Rb@l0:9lZP2GCgH0bYJO0P3>XZ`09031VJl0bYZU0<ZJY@3=W:D0k<2V0=Fk`@3gdjL0k^S70?3d
_`38kY80oooo060TK01X:6`0DQQX06PWJ@1k;f80Sf2F068`O@2@GY<0;P0F06m:UP2aY</0X9[?0=2/
]P3dc:D00P0m0:jJ`P25SM<0Xj3B08]`[P2GMjd0VV:>09UcYP2KNZd0WH>f08Ia]080bko>00H0`;K@
0<kGh03^^IP0m^bg0?;d]`34lNl209[2l`0:0:o;kP2QaO80S<Gj0:joi`22^OP0YJgM08JXj`39a]P0
000006VLkP80QJc^00D0UI_G0:^D_`2[U;l0_Z:l0<NV]`020;^G/P0:0;JD]02MMZH0WUf20:UYR01n
?gP0Rgfo06iX^`1WIkh0VYkG09RLeP80/Yc100`0^9no09UJQ02WIH@0XT1<07P]H`1k<6@0^jo=0:jS
c@00J/P0]?cK0;^P_P3Nh]L20=Rb/SH0oooo00<000000?ooo`3oool04`3oool001@0oooo00<00000
0?ooo`3oool0J03oool207Zln`090?ooo`0000X0O3Q_0000001=01`0[44m0>^KK@3hZDT0000000<0
O2IB0P2gQj800`1ZM</0XFJ<05h0=0020;QWL@0507DC>@2L?e<0W3mC0:]6B@2V?dD00P2W?d<00`2P
?T`0]eYK0;MJF`020:=@J00609Q<KP1o:UD0ZFAn0:UTOP2XHgh0ZV^90P2iOiD01@2UL9H0[g^K0:ai
V`2/NI/0[hBV0080]i:`00<0`YNZ0<2V_`30Y[l00P2gZ<X02P3Ke]80i?WB0>[gb@3Xel@0jmNo0>oV
``3[kLd0h]350>CCaP3A`/`20=gLe@80flS70P3?m^P20=?]iP0>0=;ii03Kh=T0fn3I0=offP3Qm]P0
cnWX0<Wgj`3Ml=d0g?GN0=[`h03DmN@0f_SN0=;oc`0000040?ooo`0809?RV00000009P0S0000000N
00L0KQ0m080YDP2GDGT20:=JM`040:9FLP2eIW@0Z5U_09mSR@80_7f>00l0ahJ=0<jR[03>XZ`0dJ2U
0=FTY037Z[d0g8AV0>oWa03E^l40n]NT0?_XX@3/mZL0boNX0?ooo`1G3U@00P1_=GP02@2<GIH0QeF>
05HBG01C14L0OCM/09e^V`2eNI40]iZj0<^T/@020;f?YP0:08B7c`2e_n80]KoR00005P2;L:h0YiO5
09=f/02^VL40YI?309JLf080W:WP00T0bko?0=;2bP3DgMh0glg70?K/]`2W]>80jO_009Vgk@2N/ND0
0P2kf>h0402@[^/0XZgO0::]g`1YbOh054C10:o4j@000000TP0005FRmP1`YO407U?;05mmf@1kDiL0
`i6R0<F?W02iPiX20:a`SP0809]SSP2`P:00SUF809QMR@2;OKl0O7o<08NCf02JW]L207F0d0050:fT
c@2HUm40Uh6i0:RJb02SQ[D00P2NUl`0202k[ld0[9o:0:bObP3XY8H0eJNX0=kRe`3bV3X0o]nC=P3o
ool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`1[0?ooo`03000KX@1Z00P0
YC@`0080YC@`00P0f7aP0000002YPj/0BC:C05HkUP2H?5D0VB@T0=7m_P80SR8a00D0M0XY0:DoAP29
7c<0RAlc0:E>HP020:MAH`0409@X=@3BPG@0`FMU0<5WI@80UcM=00@0Xd5>0;9XO02bJ7`0[gVG0P2T
J8`01P2YK8/0Zfj<0;EfS02eMX`0ZFnA0:Q^T@80]h6I00<0^h:G0;nR^`2oX[/00P34Y;T0203]_9h0
dKO10=GDf03TnM80k_Rk0>?Eb03[ekl0lo>V0P3[kLd01@3`c:d0g=gF0=cMeP3MgMH0e<W?0080g^;H
00@0booG0=K`i03Fl>@0d^cW0P3>hnL0303Om]X0dokI0=?nf@3PjMT0hnCC0?G^]`3No/d0f_3P0;Wl
i@3Jn=h0jO_001L010<0oooo00X0000000d01P1502d0000000805`1^:6D0Ia1609eEM`2SFgT0]Fn2
0P2hLX<04@2`NYP0/W690:Y[R@2ZJhT0`gb30<RAV`3BW9h0eIfK0=6PY@34P8P0/W::0=b4IP3_il@0
l=>d0?[GY03kj:4000000080oooo01<0K42:04LIL`1003<0TE^>06DlRP26<EP0OCM/08Qb/`2LOk<0
]GVA08I2M03CWYl0m=F_0;jke`0008<0N7O50>oB]P29EXh0SU220080YHJb0P2]/]`02P2eZ<`0S:GV
096Rh02ZQ:`0fZBL0?NmC@3]n<40kO:M0:NdhP3Ynl020:6nkP0A0:33l@2_a>T0Yj_I07R?g@1kO//0
XjSI0;?2iP2BY^<0nLMK00000039//@0Hg;<03]Ha@1OHkl0V8W20<2Za02jX;h00P2cS[00202`TkT0
/9Nn0:JB`02QS/00XhVi09R;a02BUmD0UJGP0P2EWm/01@1eP=00[ZG>09RGd@2GPKT0V8[30080ThK3
00@0]I2`0;K0hP2U^^P0/[[O0P3;^<P00`3Nh]L0o]nC0?kOT`0g0?ooo`030000003oool0oooo0180
oooo000D0?ooo`030000003oool0oooo0600oooo00<0[?Cc0?ooo`3oool0103oool0102@?El0A`00
09/N001n000304l00080V`l000L0iH5400@0;02YPj/0BC:C05HkUP1X;W<0/Xja0080Oa0U0P3?Ui`0
101L2dT0MP`Z0:A0B@2T@4T20:50C`050;5=C@31Dc`0_7Z:0;ajRP2IAV@00P2MAEd20;1KJ0050:MC
J02[HWX0Zf9j0;5^Q@2kR9h00P2ePI/0102eSJ`0]Y6`0;bO_02lWk`20;RD/P060<2H[P2oUjd0`iR/
0>flWP3Ee=P0f_[M0P3Hgmd01`3Xn/P0]?_?0=C]i@3DlND0jng=0=KWhP3Cfmh00P3Nf=400`3KalH0
i?CF0<CnfP030<SUk0030=Goe@3Jk=l0docO0080gOOL00D0hO;I0>3/fP3Pn=P0g_k=0=Sn``020;cd
l@030=[hgP3Ynl00oooo00<0oooo00<050070000000C03P00P0000001@1V3T80F0A108lcD@2R?TP0
[69j0080^VAY00<0Yemj09]CMP2nO8X00P3<Si<00`3CVYX0dYbN0=RVXP020<>J[P060;ned@3Do=h0
j]2k0?3C]03Pc/L0l?2H0P3oool030179H<0E0090815OP1G66<0A`0Y09UgZ`2NS/<0O7Bo08Qb/`1V
I[h0MU2H0<F/`@80k]Vl00`0bN?Z0<[ak00005l0IWO@08RYj`1IMmH0Qe><0:F6/P2n]=40[K;L09o@
n@2<YNH207VMj@080:jmi@3g_Dd01@0g0<_3d`3Gb/h0d;c60<Nhb`2b]M/20:R]f`80T9kM00/0P9GN
0:VfhP2IMj`0[8J/09:Vh`000000bK;40000001c0000IYKZ08VMh0020:2^h@040:nVc`2^W/L0Z9G2
0;6D^@<0Z8jk00X0ZiFo09nIc@2YZML0Z:WG09>dk@2HV]@0PXcD07ajaP2SUlT0V8[30P2CQ/<00`3>
e]l0^<GT09BXh`020;6df`80i?CE00<0d<_E0?kOT`3oool0=P3oool00`000000oooo0?ooo`0B0?oo
o`00503oool00`000000oooo0?ooo`1P0?ooo`050:cdl`3oool0oooo0?ooo`3=d=/00P2WZ=L01@3f
fJh00P0003l0000o0000M`0@0080/THm0P3<F2/20000000507l=7`19<Y<0000004D00`2H@5/00P2U
Be`01038O7X0QcQR08dnI@2=?VD20;ESKP0407/cJ02/@T40[4910<5C?080Z3dl00@0[d]<0;=VMP2c
IWH0^7R<0P2cMXh20;=iT`030;EkT`2mQ9P0]7fH0080_Y6W0P31Vk400`2mVK<0^9:_0<:FZ@020;nG
[@030=C7cP3]_9h0i?WB0080e>_U00P0aM;T0=?ciP3YlLl0e?7U0>_Ma@3`k<<0dm_N0<[6eP80g=gG
00<0h^oH0<KoeP34o]X00P3Jg]T01P38jnd0fnkO0<[Oj03Jo]@0a^o_0=o/f`80e^cT00D0dok10=kK
e03Po;D0Zo7f0=WDd`050?ooo`080000000a03P0=`0j00D000000000AP0j05P4@@2;=5P30=:EU080
]fMc00<0VDAQ0:iUN`33OXH00P3?SH`00`3LYid0difM0=RLU@020<jJX@060?kHU@3Zd;/0j]2k0?3C
]03jiY40m>nK0P3oool01P0004L0AQI_081FU`27G9P0TgF_0:AnZ@80fZRT00D0002?06IV_P001YP0
a;770=Woc@020>gL`@070<Bne01FV?00UTEV05N1h0000000a/gO0:K8l@020;W5i080]=Wc00H0IKOl
066cn`1B]o/0L/co0<W9fP34a]`20=2laP80aKK;0180_;SF0:joiP2d_n80RJ?U08BNi025XnL0hM37
07^fn02Ga?H0000001i1^`2=MkL0>C^X052;j@1OR^@0RIgP0:2^h@2_Y/l20:RE`P80]ifm00D0YY?2
0:bOb@2XWL/0/K7H0:Z]f@0209fOe@0709RJe00019@000BD09n0/@2g[<l0aK?808j/jP020;J/c`08
0;jac@2Y/=d0cKo=0>CDa`3=d]d0f?k20<fC0`2:eolf0?ooo`030000003oool0oooo0180oooo000D
0?ooo`030000003oool0oooo05/0oooo00/06dW30:;Jn`1A`_L0W>Kl0572m`2J3P00i?g60:Kbm010
O^D0Y_;d0<g@f`0203X01`030?k=KP1m1A80TRLf0080^EI@00@0e7i[0>R0=0000140000A0P2o`=X0
0`1R96/0LC=c09ACO`020:=dW@070:AdW@2`JGl0/5MQ0;1GH@27O/80N0dZ05d070020<9]K@030<Qm
OP3BQG`0_7=o0080/VQj0P2gKG`00`2kMH<0]G>80;EcR0020;EhSP050<::V@36V:P0_iV`0;nI/02n
VK400P31Vk420;RB[`030<:FZ@34Y;T0a:Bi0080foKN00D0i>_D0>Whb@3=iNP0eN_T0>Wac`020>;M
d00G0?3/``3Qb;l0hLRo0<foc@3Me<l0h^oH0>Khd03Pa;`0l^6k0>CLc03WiLl0i^GA0=_^g`38lNd0
hOg=0<SWk036m^d0`?k@0=kSf03Iiml0bOoC0<CWPP1_/OT01@3oool020000000A`0L01P0001F03<0
000006L;?@000000KAA50P2[A4L0102bBdH0WTYU0:m@E`2_D5L20;M_P0060<BGY`3;TYT0cY:F0=6W
[P3BZJl0bZ>a0`2cGFL0103//iD0i/Fe0?;B/03jiY430?ooo`0702P;MP1bDYd0LdF:088nL`2JKId0
Y7jY05`0000208flmP8000JH00T0T9KE03o1hP1LdnL0G=?W0=k<aP2W;Qh0VkK[0;cik@0FPNH00P2M
d?X20<kCg@070<Sbk@2`d?40RlSl08_;o@0b^/D0f<K80=:la0030;75j0040<c0c`31]m00_;CA0;Vk
f`80]KOJ00<0SZSV07bNj01PQMl00P2G]^d02P000000af]N08eg]`1aS=d0CG3D06f3f02EXml0RY7D
089h_`2OR;/20;2Yd@030;:Yc`2_X<T0[9o90080YZkM0P2IZN80202IWML0X:WM08>Bf@23T]T0Pj7W
0:RPcP3@Q000YO6e0P2N^nd0202/Ym80ZJKC0>CDa`3jdj40c;S70<oBf`3Ho/80nN^M=P3oool00`00
0000oooo0?ooo`0B0?ooo`00503oool00`000000oooo0?ooo`1H0?ooo`0802jSl00NZML07ZWG01jY
e`3A`/`0coOW0;fR_@3CmZ<20>CmaP0700000010O^D0eOOS0<7la00005H0000e08PK;@020:Dm@P80
a6iY00T0e7aV0?FXJ@000700[nB5034HP@23@WH0HRA[074cL`2OMJ<00P2AFX`00`2FGXd0WDQR0:YC
H`0209A;LP040:MILP2bQZH0/XJV0;YiR`80^GR;00<0bVYH0<B9U034RI@00P2eMX`00`2gLhH0`8NH
0<27V0020;N7XP040<::V@36V:P0_iV`0;nI/080_9B^00@0_IF^0;nL]02oW;@0b:Ni0P3Qh=<00`3V
nLl0j?C?0>Whb@020>KRcP030=kFc`3QimL0hNOG0080h_;H00P0eLcA0>78_`3Me<l0f_gH0=ghf`3S
k]L0e/O<0>kh_080inG?0P3OmmX0203Snm00i>7@0>CQd037m>d0hnSE0>7@a`3:olh0eOo51P3oool0
201G03T0600001L0001H0240000003L0300I0000QcEN0P2[FVh02@2lHf<0]f=]0;MSK@2gHfd0Ve=g
0<N7SP3FW9P0a9NW0=2]]P020=6W[P090=:Y[`3:Xk40dJBY0>;JIP34YQP0l]>b0?7U_`39bDX0nM9X
0080oooo00/0800/08I@R@0000<0LdF:0;B<[02DHiH0GPY509IANP3NQ`D0c:^g09icX@020=STgP04
0?Z^D@2LGHD0^[OF0;Bnh@80[<ob00@0^]ca08Rfl`2CY>40`;;=0P3Khm`20:oAlP060<C:g`2Mgod0
cM3K0=:la03D`<L0dKc50P36_m<00`3;`]80`[?;0<?1f0020;Rhf@0:0;6^e@2HXMX0QikR0::/gP2M
X]P0WY_A0000000QD/T0G8ST07ZJiP80fNcQ0P28Sm<0101jOld0TiKD0:NRd@2`ZM420:nggP0?0;:h
g@2]/md0Y;CT0:jdg@2IZN80SJ;R0:jcg01J=8P0RXK909RGd02XX<h0d8@0000;V`1H0000VjSO0080
[joH00H0`KG>0?[CX@3<^<L0/KcR09kJo03ijidf0?ooo`030000003oool0oooo0180oooo000D0?oo
o`030000003oool0oooo05H0oooo00@04P000000001M2DD0000Z0P1g00002`21a_h0cMKQ0?o;L@3G
o[h0Tnbk08CZeP2nY;l000000<7fk`3NeLl0L<?n00<0b8ZA00d0`5a@0=2AT@3@TI40hjND0?6hT@00
0700PDb807Q<T02FHY<0Ke:P08ARX`27Gi`0OERK0080W6JB00D0[GFD0;:3XP2bPj80PTV40;5aRP02
0;j?Y00409QJQ02mNXL0cYbS0<n;R@80aHB=0P2aKhL01034QY40`8NH0<27V02gQj820<BCX`030<6=
WP30S9l0`8bO0080b9BO0P2eSZh0102JK9`0e]cL0=KLg03VnLl30>?be`040>;JcP3_klD0kno50=cX
g@80gm;;00H0eLcA0=WDd`3DknD0hMoB0=_ig@3Og=<20=K7c0040>kh_03Nh=L0fOkC0>?SdP80eNoU
00L0fMoK0>KNc@3Vg/d0f<W;0;CQO@3Ho;H0c_oF00@0oooo00P0NM69084P@@0b01<0000004005`00
0000JRea03/03P80Q1HY0P2RD6T01@2gEU@0^5IB0<VDW@39U9d0bi6H0080cH=o00@0dIVK0>JMOP3L
YYd0dJN^0P3R/jH01P3EfM/01G[P07m@T01oD900goJQ0?3dY`80oooo00X090=_03PCM@15:X/0ABZ;
081JW02ZNj40Zh6W07e5P@2`JX40ck2k0P3F][T00`3JkMl0e[k30?Z^D@02000000060:cgkP17P^D0
//KY06=gd@10=Yh0e[Zn0`3?hnH0103@dm/0amSV0>Cfe@3Um=<20;ndc`060;jgd`3K][<0c::^0<nT
Z`36Oh<0_:S60`3;^/X0102`[mH0HHcU066<i@2b]md209fRf00;0000002ZUL40=G3M07BZl`2:d?l0
FGOF07ZBg`1hRmT0NWo=09jPeP2/[mT00P2a_>40102]^>40/;SO0:Vdh02Y]>0209VJd`0308nAd@1n
OlX0CEk40080`kO>00@0[:cG07Ioc`3Tf/`0KMZi0P2=Wml01P2M[n@0_Jo<0;f_c03jfJ@0P00007ba
mCL0oooo00<000000?ooo`3oool04P3oool001@0oooo00<000000?ooo`3oool0C`3oool00`1G0000
000002d00002036ha08000000100=00H05hCE00002X0/5m_00001@2ko><0000506>Ik@3igJX0ol]a
0<Sjj02nY;l0WK7V0=c/g@34^Ll0oN6J0P2iKW`00`31OHL0_6ee0;a]M@020<YgK`090>bRN@3f/7D0
<PU/05<0=01hC900UG6W08A^/P1nI:/0QenL0080SFBN00H0W7BU0<6L/`2TL9L0Y72G08eDR@36SYT2
09]>K@0409i?K@3AXJD0XX:a0<1nR`80]WJ;0P2aKhL20<B6T@040<26UP2oRY`0cjNa0<nW/@80_9:[
0P3?Z[<01P37Y[P0]8^Z0:Z7/02JK9`0j^Z60=Cjh@80f]GC00@0ho3G0>;JcP3Pn=P0gOgC0P3Mj=/0
0`3Bc]D0iN?@0=[Ad0020?3X``040>Klb03Og=<0ingB0>O]dP<0gmkC00@0hn?B0>CceP3TlmH0gOGL
0P3Ii]h00`3HbL/0gn_J0>3l]P040?ooo`0:0000000]0000@`0005T0000S0000000001h000000000
C@0006`000<0TaTD00<0de`L0<UfL039MW000P2iHVL20=63N@0=0=6FU`3KXYT0eYB=0>6l/@3O^[<0
mK9n0=Rc/`39]<D0hL[20<RZ7@3kbI40goJQ000000020?ooo`0800<04P1E?9L0CQU]09i_V`28GYX0
WF^G0:^1Y`1^@HX20<:FZ@0_0>74_03F`LD0n]>O0=Rn_`3_kLH0OnK]09]AL`3I/[40l<^/025Md`0f
DL40Vi370=kRe`0JT>T0d/_C0=3LhP3=c]X0h^?D0=_Ac`3DdmP0a[O;0:jI`P3:[[d0^iFa0<bR[P2m
Tj`0aYRW0>2OS@3Hb<X0b[W:0<o2cP3<`<l0cg]`0<G1e`1QOMP0ZZ[G0<6meP00000004Vg001Mc@29
_?L0:fcL0:[cl`006Z00QJ3U086Vk02NX=H00P2b_>40102a_>40[k7J0:nafP2Y]>0209bZh00<09VJ
d`2?TM40LH7C04UH`02@/>`0_L3L0:kImP1DX_H0i=[<0<^oc`1j/oL0WKo`0P2C[>L00`3Hmn40oN:B
08J6b`0h0?ooo`030000003oool0oooo0180oooo000C0?ooo`030000003oool0oooo04h0oooo01T0
_OK`06d^L02G;ch0GP0004hFJ@0d0000FPE10000000d01P0IP0S02P0001;1U809P0I0;_lh`0Q0000
]WB906liO@000900bMWU0=WZP`3FhW<0dM?K09^ejP3b`d`0XSHk0080_7V800/0cHB10;mfP02oMX00
aGb00=J?Q03j`8H0000>08=6O02IQ[h0JEBX08=RY00208MXZ080LU2K00@0SFBN09adY@2<JZL0P56@
0P2UK9401`2jOi@0/g670;=aQ`3<Z[H0bjVg0::2/@2XDfD00P2fMX/20<fHW`80_H6B00@0`HJE0<RI
Y@3:TY/0bY:K0P3=[KT02P36Y[X0cjZd0;B;ZP2dRjX0ZXN`09Y/W03ZjXH0hOOH0>OXd03Sl=L20=gO
e`030=gmd`3IgMX0gm?<00<0eLK;00@0f/K60=Shh03SoL@0f=gK0P3Mk]d01`3WkM80gMgE0>3`fP3U
km@0hoc<0>KbdP3NlMd00P3ElN@20=G`i@040>S`d@3oool0oooo0?ooo`80100000D0A00007]JW`1k
FYl0K@Xd02P00002000000<0blCD00H0VbLU08TB60294QP0Q0P;0<I/HP2iFeX20<j4P00>0>>^W@3F
XIl0fJ6L0>6aY03UZYD0hKba0>>QRP3d_Y<0lNG00?[2R@3Qb/80n[j10?gPW03OmZ420?ooo`0804/0
?P0505D0img907QCVP2:EXd0YGfX0:9kZ00n03020=Rj_0060<k4d03NclT0g/o90=OBe03fj[H0l>^;
0P3Oell0102]XL/0gk:X0=nbZ0004:020;C8j@050:CInP007Yd0b[o@0<Zod03Ed=@00P3=^LL03@2l
YlD0/Z770;:Qa`2gS:P0b9j]0<JL[@3H/;00gKNa0>7;`P37^<`0fmgI0<k>f@2Z^><00P1/T>@01`2/
^>80c]?M0000002gn^T0001h06:;h`0WI]P00P2N]nX01P1j_od0GiO]03U/f@2;Y^L0/koS0;Vge`80
[=Of00P0^LWV09^cj@2?X>00T9[I08fGf01aPM<0FYgb08fkm@80];[M0P2<RL`20;i<<0050<>^a@2=
`OP0P]3o0?o6L@2<dOh0>@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?oo
o`1=0?ooo`0J0000000N00007P000000001H0040>P0004`000000000E`I505007@1@0380H`a305P0
=P0002P0Pe:?0;b3UP2^Ukl0enCP0000T02li?<0IRU`0868d@2]V/<0Q3UX08LmJ`36GDH30<f4P@0:
0<MlO@3;SI40bhfA0=RMUP3j`8H0LV^k079Z^`2JM:L0Q6^_08=RY080QfRX0P1bG:X00`2GMjh0TFjW
08aZY`020:F2[P050:f6[01;1e<0cHnB0<f?TP2`Ef400P2RP[400`2XDfD0aVaU0<I/I@020<jFV`80
`i>U00P0a9:R0<RCWP3>Vj80bYZT0<fNY`3>WZH0aZJj0<NO[`80YgRO00X0b^[/0>Okb03Fo=d0inS@
0<3ndP3CeMX0e/;70>cabP3[l<d0gm?<0P3HemL0103Wg<T0engS0=Shh03IlN420=Wch@040=gYg03J
hM/0f^7K0=knb`80gmO?00@0lmQY0<oXj03VjM40fogG0P3?jNP02P3Nn=X0fo^`02F``@190000N4F6
0:VE`@2IYml0H/[k0?>LD@1^b_h20000000502H0001=0000C@0004d0001c00000P2b=QL00`3NUh<0
eHb10=B:OP020=1iJ0030=bXX03KYj00eZ6O0080hK6T01<0i;BT0>6l/@3<TYP0m;jC0?J^M03LdLh0
jMW40?BJAP3VTA@0kOVn0?ooo`0;02H0JB]_034=L`0Y0000WGb^08UXY`1kGjL0I1]K0080/JcC00h0
e<K=0=;;d`3Oell0em;D0=2laP3fj[H0i_NW0<gUj@2MXMP0WjoR0<?6g@3H_/00MZof05bNlP80Y]Kh
00<0_>;b09nciP2O/nH00P36`MD04`35[<40W9?:09bCbP2_SkD0]hbX0<VCW@3AWJ40eKk30>bdUP3R
`[P0lMNf0=kZf`3Ghml0c>c[0:kjg02Ck_4000000?ooo`0000000P3oool02@1;J]00=e7104V0i023
Rm80IGcF09^VgP22]_H0CJGg09RSg@020;o]lP060:WQnP35/LH0aK760<FaaP0[ONL0N8OF0P21W><0
1`2>X^80P9kV0;:Zd@2]]n40Y6jE05YO_@2;Xn@00P2^f_H00`3[n<L0Rl[m0?ooo`0i0?ooo`030000
003oool0oooo0180oooo000C0?ooo`030000003oool0oooo04/0oooo0P1203d00`0000P0G00d0000
000207T[G@0907]W/00L06l0EP0Q08PnK01G4e/0Pce`04/>GP2FAFH0FR=a00<00`0000@0000006_8
oP1/;g80SgFb0P39]lP00`39amP0TUjA0<9bM0020=>1LP80bXJ900P0d9:C0>6ST@3VW7`0cK_9079[
^`1bJ[/0TgRb091e/@80Q7Jl00H0UX>m07Ic`P2@PKl0Lfbl0791QP2>GI<20:F2[P030:B:^@2QR;T0
b;C70080/5MQ00<0]U]Q0<>GZP33UjX00P38W:X00`3CZ:`0cZ2X0;N0V0020<BIZ`80cY^R0P3=WZL2
0=Zb[`0;0<jY/`3:j^`0b^[/0<[Zk03MnmT0dnkV0?CC[@30o]80cmcR0=K2a`3/lLX00P3A`LX0103M
e]00emCF0=O]h`3FnN420=C_i@040>KB`P3Yel<0coSV0<WKiP80kMg200D0jNC<0?gLW03mg9`0hMoB
0>Ofd@020=KVh@0=0=khfP3Fom80n=b]0:_7kP3nbfh0U][n00X0000[0000FP000000001W0000H005
03h000020:8/8`80]D<a00<0_48L0>F1B03QSfl00P3BQgl01P3?Pg/0gH5N0=^2I03VYhl0hkBV0=RK
TP80j;BM00<0dHMo0<EdM035M7@00P2;f_l0102Q4000l]:_0?77Y@3eji820?ooo`0:06//K`1R9fl0
000006i6T@2MO:h0MDN<08QKU`2PPK40[j_D0;6/d`80bjbk00`0j;ZU0?G8WP3ZnLP0kn_50?_BV`3J
^;L0kiaV0=O^h`34]<X0gLK20=[0`01K_?`20:kLm`0508B3bP2CbOX0TlWj0=6maP34_M<00P2`XLP0
0`2LTlX0[hne0;N<Z0020=6MX@040=2GV@3K`l80lMNf0?oCN`80a_kO00<0ZOSU0200:03oool00P3o
ool030000000oooo0?ooo`0008X0D6G90667h@1RNM<0QYkS09VXh@29X><0PYoU086gm`80^mC/00T0
^o?b0:;Qo02RhO`0Q;kj07FXlP00>k/0Q9_Q07jCg@2R`o400P2>/Nh0202L^>`0lknF05YO_@3ae;@0
02BT0000001LeMH0LLco>`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?oo
o`1;0?ooo`040;Nad`00000000000<j/]`80Jeb`01@0a7Um06@0:@1aCi/0aG]o03/05@1m5S<0PSa_
05<<E00A0000G2Qf06@ZLP28Dh`0l;6:08F;d@3FRG/0>`UV09agZ0000000002208DbF`80e89a0P3F
WIX20<n?T0070<V:T@3RYI80j:nF0>VNN`005Yl0G4jY09=h/P0207E/^`0706AO^026GI/0SgRd0921
_`1aJKX0OFni099m^@020;:L`@030:B:^@2QR;T0K3V000<0_h>C0P35RiL01@3;UId0d9bQ0=2LX@33
Q900^8JP0080cZ6X0P3<Z;@00`3<ZkT0ekfo0=Rm_`020<jY/`060<cngP3=lN/0gO_I0=gkf@3Id]80
l]Jb0P3H`/@20>cabP030=[9b@3Me]00gm[A0080gn7F00<0hO?I0>g/b@3Hnmd00P3Yel<20>Gfd`08
0>7Re@3Yi<`0dMgR0=?biP3mg9`0ioKA0>OTcP1]01L2000000050?7dZ@2E__<0T/Oj09;7nP3Zkld0
0P31Ri`20<61SP0508A7O@0J01/0QRM60:YML`33KV`00P2[BE00302c@2h0iH580>64F@3@MF40`V9H
0=YfC@3MUH<0jjF00>RjY@3S]:H0gjVL0>VnZ080iJnJ00@0o;mK0=;XiP3IfML0TL?h0P2Yc?803P3`
]i<0cjlT0?ooo`1b<g40E00l06@GE01g?gl0REfH08E@R`27DX/0QEbJ09YYV02lTZ/0e:ja0P31V:d0
4P3X`Zl0mLRN0?O/]03hfZ/0j<bj0=Zh]`3MfM<0m;U50;b`cP3:_/l0e[Bg0>^cU`0008d0Z:?A0:Z^
f`24Q</0[i_30<_1d@80/[3F00@0UhO10:VPc@2a[=<0[[KO0P2mY/<20=_3`P030>gcb03odg/07@0K
00H0oooo00P000000?ooo`3oool0oooo05Iif@0gI]@0LHKI08JNh`80SY[J00H0RYSK09ZRfP2JiO`0
W^7m0;3Vn@0?TN830?ooo`0905iedP2>U]L0;77O07NOj`2O/>@0TjcW0:bni`3c_iH0_mGZ0080GMC6
00<0jOBN0?ooo`3oool0>`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?oo
o`180?ooo`05077=o`0=00@0000H03P0000000000P2n[<P01@1E9WT0000006@HE@1U02P0UBm100<0
V35000<0M1U405<<E01?7W<00P2LL:002@2eS:/0S7Je0000S`2?T]80mnV?06800010;iD000000;en
SP020=JCRP80eYfJ00@0bI6J0<jDV03>U9P0gZFH0P3X[iH02`005Yl0NX?@08bMgP1UK/L0MFbk08>8
d01bM<D0M6Nf08ah]`1aJKX0OFni0080RH3300@0UhS20:QmY01kCHh0P52?0P2fOiP20<::V@80c9JM
0P3>UIX01@33Q900^8JP0<jQZ03>XJP0g:jX0080f;Jg00l0c9bU0<jY/`3>ZK<0cZVc0=Gdi03clZD0
aogS0<goc@3OdLX0g^WK0<nmb@3_gkl0mO2f0=O^h`3QeL`00P3J^KL00`3dl[H0`oC_0<KHi`020>7X
f0060>C/e@3ffk40i>CB0>7Re@3Lj=d0fOo=0P3PhMD20=g>bP0>0>OTcP2VXM00W]5X0;2l>P3laXL0
clcG0?ZbJ03fXd80HbM_07i@T02]d_<0aL?H0240000001T203d000060;5XO@37IE<0afEC0<6N]03N
QVH0fG=90P3=EA/01036ES<0jiab0>c1Z03O]J/20>nLIP060=nf[P3Y_ZP0g:^S0>F^VP3l_e/0fMWG
0P3Ld/h09`3T_[00lKB<0?o<O`2k_S/0R2];05h4>`20@g`0Ec:808QMV@21E9<0OTn?08aDR@2:Ehl0
^9Fc0<RX^P3D[[40aZNj0=ZVX03Udl@0n>Rb0?O/]03hfZ/0i<g00>GBa03:/l<0m;U50000S`1RW?00
e[>f0>^cU`2f;`007eC<0;?3iP1jR=H0][CH0=;CfP30b>40]:;609N7`@030:^liP060::jjP2M[^<0
gm7:0>C>`@3_j/D0e=IN1`3oool03@000000oooo0?ooo`3oool0001f03B3j@1CQ>@0S[C`07FZl`29
]?80T;Sa09K`kP2Ak^h01P3oool200^Ag@0305j3gP2F^o40T;Sb0080RlOl00<0_^ob0?g?TP3oool0
?`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`180?ooo`0901T03@1d
0000M00000004@1J02h0>kji03P0001>03807P0P0080R6>P00L0ZgRK09iSRP29DHH0RE6607HjN@1C
35@0<`0/0080W72P00@0]Hb[0:<i?P2Uf?X0]KSL0`1HaOT0103ii:l0cfl00=jPTP3NX9820=RERP09
0<V>U@3IW980fIbB0=NYZ03VXXP0j:J70<JR/`1jPm00S9gN0080Ri;E00T0Q9?J079da@1ZKL@0JVg4
08Ig^`2CS<T0OWg808V0``2GR<800P24H:420:65]P030;J>[02mTJT0_I6Y0080aHjK0P3<TiT00`3=
YK00e;>h0=Bc^0020=Fg^`030<j_^`3I/k80c9bU0080c9bU00H0ho:H0=Sm_03clZD0fLk>0=oAbP3/
kl/30<nmb@070=O^h`3AfMh0dMWN0<k2c`3dl[H0ioZe0=3:d`020=_^g`80e?KU00@0i_CB0>Sec`3J
n=h0fOo=0P3Vh<d0103^f;`0jN;;0>SF`P3QjmP20??`_@070;2l>P3laXL0dJfe0>S@_@3i]7H00000
0<5]0002086]l@030240001`0000VTi`0080^G^>00D0cH1l000gW@00=id0nZiB0>:>J`020=AeF@0K
0?ReN`3f^HL0l[B:0>Z]S`3^aZX0jL2Z0?CF[`3ZaJl0fKo00=bi]P3ZXWh0j/B^0=g7``3Ld/h0i;ja
0>k3YP3fl:D0QEJB08=DT@1n?WH0LBaY085PX`1eBY00PDIo08aHSP2WPjh0/8R[0080/Y:f00d0aIJV
0<ZHXP3JYZ00`I6T0?[JN03Xf/H0n=Z[0>C=`03O]k00Zj_G0>2FOP1f0000HYc`0080jk>G00L0g<K3
0>S<^@2?ZNL0Zi[50;VR`P2l^]L0ZK?P0080`=W/00@0TjkY0:34lP2aa>P0Z<3[0`2/[mX00`3_j/D0
00000?ooo`060?ooo`030000003oool0oooo0080oooo00H0IiK[06ZHj`1=Z?P0SLGj00@0003Ggmd;
0?ooo`0509F/iP00R]H0XY[=0000001QKlX0@@3oool00`000000oooo0?ooo`0A0?ooo`004`3oool0
0`000000oooo0?ooo`160?ooo`0;01L0@00e02P0;@0h01l06`1g2bH0G`0L06P0001>87L0IcZ605dY
M`22Fi/00P28Hj002`2IK9d0SE>6099BO`1d=gH0H2Ma04H8FP0m04L0G`0R0:Q1A@1g0000000000<0
N6Rc00@0ajbo0>fdU@3>b=@0c/SD0P3NX980203=W:@0`WQn0<n:Q`3?RXL0ijnH0=NYZ03GX9`0iIQf
0P36X[<030005J40Qh?808^Be@24TmX0KWc@055L_`1ZKL@0QWNk09><b@1oR=80OWg70924`P80Q62Q
00@0MVNe0::2/@2dXLD0]:750P2kW;T05@34X;@0c9>I0<bY]P3<ZKH0bjRf0=F[[P3H[jl0eJjb0<j_
^`3L^;@0j[/l09/kC`3TkmD0jnO;0>Whc03clZD0imK40>c_b`39]LH0n>Na0>;PdP020=[<b`070=k8
``3AfMh0hO?I0?KY^03UelP0kO7:0=[lfP020=CMg`070=C_i@3Dm>D0e?CU0>oA/`3Ig]X0jn770>KP
c@020>SRb`0?0>7[f03RkmP0kNS80>W_T@2SWm40I]Ka0?KYS`1Ue_40S5fE07]AU02_KHL0]gV>054a
S02VB5@0L0000080YU]e00X0^G^>0;acOP2lLgh0ejVX0?Z^DP2nIfT0g7iK0>=i<`3dX5/0lYQ<0P3b
[7`20>W0ZP030?KQ/`3ZaJl0a:>g0080a:>g0100l_>W0=nRTP3T_[40i;ja0>g[R03]j8@0FR1/099K
S@29EHh03`0c06@DD01o9e40VfZI09aj[@2[PjT0Y7RS0P2lV;806035X;<0gkRa0=ZVX03ldiX0nmYi
0=RYYP3b^Y<0ll6K0>2_Y036N7P000000=O2a@2:=5T0XIS<0=_4``3La/<0l<^[0?O`[P2[V/D0^J;2
0=cYg@2ARLP0XYC50;Z]c080_<?O00H0?VcG0:gBl`2]d_<0/OGb0;;fl01gfjT80?ooo`030000003o
ool0oooo00<0oooo00D002nb07OMmP22ilH0T>7m0>Ck/`1A0?ooo`030000003oool0oooo0140oooo
000C0?ooo`030000003oool0oooo03l0oooo0`2S`o005`3oool0KMkV07@0000O00006@0f04K6`@18
8Gd07`0K03`@K`0V02`0BAAZ04hPM`1S<h40ICF1078oP`2AGi@0VFbM09QdZ02?Ij40NdB206X_M01=
66`0A`QI0080G`0R00X0IQ5801H0J00006<0LW320<STN@000000XaT00;^mf`3>b=@0]9Rj0P32XkX2
0<R1Q080dHn<00<0ijnH0=B7NP3RW8D00P3WXH<01@2EKZ<0012P0729g02DT/h0YY_;0080?Ec900<0
FgKD08J4b@2HT/`00P20QLl01024RM00N7K408Uo`P1fIkD20;RSa0040;BQa@2kW;T0^ibi0=Fi_P80
bKG700@0fKbl0=Jf^P3H[jl0f:n_0P3BZ[001`2nO8T0j[/l0=KQg`000000dOkJ0<;ngP3D^l800P3_
i/@02`3BYjd0n>Na0>kg/03cl[X0e/G90=S5a`3Vh/h0[?2Y0=Onf03Nj=/000000080[mOe00H0_/gV
0>3=a@3Yn:h0km6c0?OY]@3Ig]X20>;`f0040>7[f03^gL00k]g00>kg[P80kNS800H0Al;/04<00037
B`00IC5l00008`2/a>`202@000070000@@2fJGP0RD]n0:IKM@2`Ef40[fMm0:iAF@020=NYZ00=0;In
U`006:<0hGLk0>jKI`3Xdl00oN2K0?cMW`3[f<00i<g10>c?^03fhK<0hm_>0=S?d0020>oN_P0@0=jc
Z`3Q/ZH0h[>V0>[3[@3ej;T0kNR4078hN@25<E/0E`4n09M_X`25HZ80R5^G0:9bW@2GJid0TfJJ0;J1
W080a9FV01H0cYjV0=nh/@3H^kd0jm[30?_JN@3HZJH0m:Yb0>BgY`3LW8h0cJjk00000032[/H0hlk3
0=Jj_@3HZJL0jkfT0?3;Z`3gl:h0QHoF0:cSn@1Od[@0THW80`1Zd_X01@2hg_<0Rl;i0:kBl`2Pl?D0
U^ge00X0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`00
0000oooo0?ooo`0h0?ooo`0Y02/0003oool0b5<W0<QC9`0n04d0mIiA0740001MdO00?l;500000010
000010000000001J9WD0000S08A?RP0B05801`1k04@GLP0>04T0>PQU048IM`1B9gd0Hc>108aWX`2:
JjT0PfJY0:=hXP2?Ij40OdV606P^M00c0480201B06XcNP0c2Vd0Sg2[08mi]`0F06P0YZSG0<Vlc@3@
/kd00`2NIHh01@2UV/X0]XRU0<EiNP35NGX0difM0080ciNJ0P3W[iP20=je[P060>2/W`3n`WL0LTJ>
08RHg00j0000agA`0P2IRl802@1FGKh0GW_G08fKg02=Vm`0NhC@0825c`24RM00=Dbl06M_a`0209><
b@070;2L``36]<P0]:_?0<K>h@3;dMh0alcN0;_8i0020=Jf^P<0_:>o00L0n/680;j^b@3Z^c`0oLnB
0<[kiP32o]h0ckg90080g]oF0P3BYjd00`3hik40lo:j0<_8e`020=37d@040<7g[@34oL@0cM7M0>ci
`080k_K20P34hnh0103TkmH0cmoT0<oOi03gjKD30=SYh@080:FMc@3^gL00k_N^0>kg[P0S0000L@00
0;Ta000000020?NfA`070000002>CG/0WFJA09eVT@2^M980]GZC09iZUP0309<H50<0b6=?01h0`lkS
000HX`3Bbm80iLbo0>SC`03mh9/0o=fO0>g4ZP3TcL40km^l0?KQ/`3]dkT0jkfU0=gHdP3V^JL0g;6[
0>6bYP3OUQ00n/VB0?GX^@1G6VH0MCUg08M7N`25ChP0TEnC07=3R02=Eh`0XW:M09=CP02]JhD20;bB
[0030=B_/`3B[kD0gkRa0080jm[300P0o]RD0=ONg@3dZW80h<S10=bLSP3Sa;T0fl2o0=?3bP80_m3V
00L0h;N^0>kG^`3lfg`0oMQk09k8mP18`O00LkWk0080Wlgh00<0Q]gn077Ao@2Pfo`00P2Pfo`00`2e
mo00oooo0?ooo`090?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool04@3oool00180
oooo00<000000?ooo`3oool0<03oool202d0000:0000001K0000F`0007/0000?0000000007PQC@1l
9E40T9GD06`SH080000000T0C@000:3/n@2Pk?T0L=BL00`0000c0000EM7K0000000000D00P0]05P0
5P0L0G00;`mh030>M@0n6GT0J4nQ04I5[01I>I00S6NS050ZP`2dUkX0MVjm08QHTP1oBHH0IS9k03lB
K`0A0580DRAi050CHP1i:U`0NbmR05TbQP2VZ=L20=2c_@0308EVY`2ML9h0`XVI0080]F5Y0P3IPfT0
1@3DWih0eJ6P0=FQX03T[i`0iJ^G0080fZfY00<0hJnQ0796SP0000000`0O00001P24S]D0VH_206eo
d`1LL/l0PiON07f6d@80TIWG00D0QY_P07V>f`1fPm<0MX?C092?c`020:NnjP80^Mgb00D0c<GD0<OD
i02m]m<0W:?J0=Jd]`030<O2e@050<oRi@3Fo]L0k_C407WTb`3QYiL00P2HX]`03`3ccZX0e<S?0=O]
h`3GkN<0jn370=W1`P3/e;/0IM2R07WUg@1]gLX0XOKL0>ci`03Pe/d0ckO30=bl^@020=g/g@0<0=RB
QP3Ujm<0e>[T0=SdhP3Zg/L0k>G809?HoP2UWLd0k]g00:P^6`3Yj/d0LB]V0P0GY[T00`38UZ<0:P00
02X000020:B@_`0607YX/`28GIT0Xf^A09aBM02@@FH0QSUV0P31D3<00`3WWWl0gYXC06WLbP020:6T
f00;0=BWZ@3ggk80j=?00?gPV`3ibIH0nN^P0?O/]03/nKd0jMBo0=Ff^@3[_JD00P3V^JL20=VQV`0=
0=nF403jbI80m]ee05/AE027AWP0Vf:=099PU02;Ehh0LTF<09UNRP1_<G40[gnP0;Z>Y`020<2G[@0B
0=FHU03DYJH0gL2k0;mmRP3lcI<0mji_0?:iS`3f_D`0h[^_0=k>b03M`Kd0h=?;0=kZf`2]Z=80`;G?
0>CWe03UakP0OaTf0`3oool01`1HUNh0LGkA046[m`1kcOl0T]On0;cYm00000003@3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003oool0oooo02h0oooo
00<0000001d04@1ca_l00P1ca_l02@1n<V<0000002<0001L0000200002@0001H2T`0IB5S01X00002
000000090;WQNP0l00009`00000000030000L=FQ00009P000000001C0080LUFQ0P0g88P03`0`3WD0
DcjK06Q?X@1_AHl0P6Z`07ET/@1E>980U6bR08mTW01hBHd0Lcn206</MP0Y0600=0AS01/09@0206Dj
R080d<G@00D0S6BN03MLb`25IZL0QFJW0<2M]0020<:9V@050<fZ]`3<ZKL0c8b@0<b<T03EUHl00P3G
Zj/0103@Og<0iI9]0>FBK@3Q[j42070eMP070;FI^`2DN;400XWJ08B>e@2>Tm@0KGoC05abc`0205Yc
dP0708nBdP2PY=P0N9;O08>Oi@1AT>d0Q[Wf082Wk@02093EoP80^;oO00<0amCT0;Zjf@2k^mT00P2b
]]/0802/`^X0eoSQ000000000000`>Ga0;o[lP39ZA`0hJNG0>^jX@3Wb;L0c;o?0>6RT03oagP0jn37
0?N`MP3H^[/0000L02Z^h`1PbO/0cK:o0=GfX@3YkLl0jMK10<ng``3L_;T0e?GU0:fniP3HalT0m?6f
0=CZi03Jln00d<oI0P3:YK<0102nWkT0c/??0=2<R000000204jhn@030=iiB02hMXX0VHBk0080ZYW4
00H0Y92o08mCQ02@Dh@0W6JB0;1nWP2iQId208FAf00Q09]XUP3LZ:0000000?C8EP2JR/80XJCH0000
7`3ggk80kiD[0?WZ[03ibIH0nN^P0?O/]03Re//0f/O70>JjZ@3N_kX0g:FK0>JiY`39Y;<0eJRZ0=nF
403jbI80000:084iJ`2>AFl0Td9U08ToJ`1=0340RBa<09YVU02<Fi80]X^X0080]hVU00d0]HRV0<nS
ZP3FViL0eY^G0>RdWP3lcI<0n]VU0?:iS`3f_D`0h[^_0=gHdP3Pdl/0gok<0080_:_800<0i>OD0;k3
gP3Se<P0603oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0140oooo000B0?ooo`03
0000003oool0oooo02d0oooo01404000000000000000DQmb00`0000;0000000000@0001B00@0=`00
0000000X0000200005/6@@0<00000000008000030000000Q0300B@00000000000000000003X08Q>5
06aBXP1EC:/02@n=02DFQP15<iL0<`md0716S`1_AHl0QE^I04T_S`1_>h40PWNo079>V01^@hh0GCJ9
05hTK`1H86h0DAe_04TRO@1U>XP0B`0a05P01`0V0000RT]m0<FhcP2fRJH0]hVV0080^XZS00<0b9NS
0<bBV03<TYP00P3?U9L01P3EUHl0fIV@0=VIT03HYZ<0k/ba0>b^SP80ikbX00/0gZNK04D0003VUAL0
ZE1N0;?7j@2;Zn/03`0009R7_`21S=D0FW?B08nBdP0206Efc`0509JDc`20Tm`0/[WO0;:ig`2BcO`0
0P2E__<0102h_ml0^[[I0;Zjf@2j^]T20;k^l`0C0:c2jP3@j>L0kmBf0<[Wj`2ojo80bN_/0>?Nc`1S
__d0ilRg0<boc`3AbM80flk<0>[Yc03g/GH0mk1f054AGP000780][cN09>DdP020=GfX@80jMW500<0
en;O0>kg_`2]_^H00`2DkO@00`3EgMd0d<oI0=3?f@020<Z^_P80c/??00P0d8b8000000000000iWhj
07UBV02K8Q/0QVNW064bP080K1E800D0Se>409f3]P2QQ;@0YXNc0;N8Y0020:QcU`0Q09]XUP000000
a:c20000J03XXH00[4mH0>JRQP3ggk80nn240?WZ[03/n<D0i/no0>ONbP3JalL0cKo<0=^i^03?Z[<0
fjjY0=BJV@38Y[L0jKFM0?3;[03fYV80i?:H07PdKP2;@Fh0QSIQ0991I02XOJD0ODf=088eI02fQJ40
_I2X0080]hbX00`0a9jb0<nSZP3G[Zh0hZFB0>RdWP3ch;T0n]VU0?_MY03f_D`0l=:c0>oB]03[il/2
09BEd@030;_Ik`1[eZ/0oooo01T0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0@
0?ooo`004P3oool00`000000oooo0?ooo`0[0?ooo`0C06C>V`0O0000GP0D0240000000003@0005T8
A`000000F@0L05<08`100080<P0001d0000R0000;`0@01l0001ceIX0000003l0;@020000000K0400
=P00000000000000000003L0001n0000O01aIKD09AB50000H@0h88P0BBV802P5K`1M>8`0IEJ]07=F
XP1G@9/0V8Jn089g_`1/=gd0I2ii04XJLP2@E8@0E2=f03L<K@1lCi404`9h0080/Hnc00H0T6VS07=F
X@3=UY`0cIJL0:mVN`2ePih20;ajR`80fZVU0P3?U9L03@3OZ9/0fk>_0=Zj^P3J^[X0k/ba0=^k^@3b
`ih0jlbd0>bjW`1Dbjh0UZ[T0:U@GP3;LfL00P0?000209RUgP0607nFh02HY=h0H8gV06Efc`2FU<l0
P9?L0P2Mc_P0702Sd?L0Tkcc09[2l`2J`_<0SL;i09F]i`3?l>T0U>3n0180003@j>L0l:j50;jofP3Q
`KP0olQi0>S<^@3h]7P0g=;>0<fd`@37`]D0amGT0>[Yc03MhMP0f=OF0?N`MP0002h0KRUX0;b`cP3U
gld207gQmP060=;Gg03Gh]l0e][K0<_nb03MoM<0gog>0P3;g^L01@2_]mh0elS;0=O8b`3;Z;L0iLk0
0080fMoK00L0B1]d0=Fe;03KOEX0ce8007UBV01iAhT0O5>F0080SU^A00D0WGBU0:MlY02NQ[T0W8:f
0:J5/@020:IlY@0C0;21XP3:[;/0bZbk0<Z/^`3[d[`0bIf[0=ORL`3b[X00F0000?_PQ03PcLD0k?S5
0>K?_`3OfM00j<:_0>Fl[P3H]KD0d:F/0=V[Y`020=NUX`0<0>RSP`3`bj`0mZIR06DZL@2BFh`0RDf2
099EQ02]KXX0V6:@09]PRP2dRjX0/HBT0P2bQ:@03`33UjT0a9^^0<nSZP3S^Zd0g:jW0?cRX@3jfJ@0
n]VU0?GU]`3/]IT0nKM<0=OTg`32mj`0//o_0080000L0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0403oool00180oooo00<000000?ooo`3oool0:P3oool01@1S13D02`0000L00011
00008`0000<0000000h01@0002P00011000060000000000l01L0;`0@04h09P0R00h0:P0B01l0000i
01P0I1YJ01`00080000000h0000R03<=L@0004001@1801P1L`1Z:fd03P1Z0100?@13>Il0:a^903/a
V`2JR/40KW3407=FXP80Ogg600d0CBb706`gO@1o0000TTei09=BOP1O8f`0600f05406`000000YgVQ
0:jA^02@JJ<0^j_:0080Q4Il00@0[fIk0<:9V02kPI@0^h6D0P3VZi@01@3?LP00b:^l0=JSXP3FXj80
hJRH0080i/Jf00D0fk^i0>_7/03W_:T0E<^^07A8S`020=JSXP03001mb01kY^h0NjK^0080V:GN00@0
OiKP09NRg023Yn`0QKoj0P1nZ>l00`2I`?<0[Lkb08BhmP020;fmf@80_]?Z00<0bmoW0::Vf@2/VlD0
0P37]l/20<Z;T00H0>JXT03ob7T0j<bi0?RdN02QO:/0cKC107_PmP3;in/0bO3]0=;IgP3jjj<0Slm_
0<^ib@34dN@0inK?0>GOc@2ob>40d=ON0=;Gg033o>D0C<Ne01`0003DiN<0e/W=0P3WfLL05@3;[;X0
cjfg0<6U_02k^MP0i<o20<koc`33[lH0B1]d0=Fe;03SUWL0Kcn707UBV01iAhT0O5>F064bP026O<80
YIC40:67^@2NQ[T0W8:f0:j@^0020:IlY@030;^O_03A`L/0j_K;0080XJ[M00D0i<Fh0=VYYP3IZJH0
o]n?0>3=a@020<bnc@030?cQRP3OfM00e9fL0080f::N00l0d:F/0=>VZP3CYZX0e9VF0>RSP`3`Y740
kNAl0502AP2LE7H0MR]R09m?J@2EEh@0YFbA09IQT@2bN9800P2mSZD03@2gSJX0aIJV0<NGY@3T`K@0
djne0>:h[@3ce:l0mlbN0=9L7@3eiKL0g/2j0?VgC00000007`3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo0100oooo000B0?ooo`030000003oool0oooo02P0oooo00T04@0003`0000U
00<0QC5I04h0?P0o00h0DP0Y00P0000M00000P0000002@0P02H07@0003<0;`0X00T0=@0d02P09@00
0000?`0J02H000020000000E01d09@000000000@00`0>00E03/0000G0000000001l0=QV10000000k
:i<0=b><06Q@X`0N99/0DSB?08PoK@1Y=Wl0YX^h08Yi^P000000HPTn0080ICR400D0R4n507LXG@1H
3e@0IRmg08aRW0020:MiX@0=0>FYT`2NbOH0bFIC0<UVD`0002`0aXRB0<:AX`3<WJL0^iNc0>J[U03K
[jX0cg800<J9T`020=VKTP0:0>6XV03OYYP0gjJH0?K<X@3/b;00jLnk0=[9b@3M][00IWcD07M9S@80
`Zk600@0WJ7H05^4h01iO/`0Rh[<0P2GX]`00`2?X^40WJWO08:Wk0020;:oh`070=6a^@20X^T0a=GV
0<CEiP3<c=X0/JoF0::Vf@020;R_d00>0<Ngb`3H[jh0f:n^0>>o/`3ob7T0QL;k0=5bFP1Yg=D0cKC1
0<nb_@2Z/]h0d]WN0<_mh@0000020:Y<F0060=cYg@3Jl^40c?o@0;o8h@2k`]l0f>KO0P3Cnn40103B
iN@0e/W=0<g9e`3ChN820<^/^P030>g[b02m_m/0c<OF0080aZZm00`000080?ooo`3oool0H[gm08^@
dP2AUmH0M8GF09:=b`2DPkh0TXK30:FA`02XVlT209b?a@0409N8`P2CNK<0[8N_0=71b`80n^N/00<0
cKc:0?3aa035TZ400P3IZJH01`3nghl0h=380=No``3aajH0o>6:0=oId037WJd00P3@X:D00`3FViL0
e:6Q0=NVY0020=ff/@050>c0YP3Oigh0Mc1Y02h01027>F@00P2[JHH00`1g6400/ff20;QaPP020<:8
U`040<BK[@37XK40i<6d0<^W]@80f;bm00H0lmB_0>k>/`3feJ/0j:`[0000003bjklQ0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool0403oool00180oooo00<000000?ooo`3oool09`3o
ool09P0L0000<00=01d0000g00004P0003l03P0N0380000001l0000m00<0A`0W064IF`1G2D`07P00
038010000000800002/0000S0000<@0f03L01`000000E00n03T0<00J02@07`1H03d4G00H02`00000
01@0L@000340KTNC01LKU@1NBZ<0HUR`065G/00d;9T0DdFS0P1A;hT0102=BWT06`0007DeLP1H;802
07XfK`0405lPJ01k>740NCil02X0:`80_Z_600H0W:7I0>FYT`2=I9h0]Te30<UVD`0002`20<J8TP04
0<bMY`3=/;d0cK2m0<jGW080gIR700D0c:Zh0=V_[@3PYYL0g<K40?O5UP020>oB]@0:0>VmY`3M][00
kknP0>noX02KhOd0U:OS0;JhfP2kn>h08@0007Z8eP80XJ[N00L0Uj;L08f[jP2=ZnX0XkKV09bCbP2f
XL@0Dho/0080IG_D00<0a:o50=:j`P3B^/800P2dX/H01P2g/=80^kSF0;^heP3S_k<0dOkL0=G[i080
bk_;0P3;/;l0302=FHh0^gZ;0?k@LP2=fXX0QUVD0=;3b`0V?;<0bm7N0=_dV`28T]L0f<S:0>7Qe080
b<cM00@0[kGM0<WHi@3ReLX0dn7R0P3?bM@01`3H_l00_KoK0;fof`3Rbl40^IZh0;9gT@0000P00P3o
ool01`000000Ri3B08I/[P1LFKH0Qg>f09B3_P2BQ/<00P22Qll01@2FR/@0YY?208j6aP2F]>d0/k7F
0080fl;100d0g=3=0?W3E@2cW/<0LRm[0=j5HP3nei80lM5O0=No``3R`[P0lLNV0?cQRP3HY:40dI6?
0080d:2V00X0h:^M0>>i[03>YJh0i/2`0>Fo/03/`:H0REVC04P0AP27>F@0ZDE;0P2KBFH0402WKY80
`Y:U0;V7X02iQj00]g^A0<^<T03>XZX0g:RP0>6^X@3L[JL0ikBO0??D[`3_g[l0m]F[0?cUU000000R
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0403oool00140oooo00<000000?oo
o`3oool0:03oool0<00J0000@@0B04H0?@1I1D<0;`0003806`1202T00`0008M2LP0F0000AP0l0000
000J00T0<P0003/0901Y8f80B@iP0340EP0l04H06P1303h2F01X;780C1EY0000<00N01T0:00l0080
@00005`0001a04eig00S58H0KTNC01T0<P1NBZ<0E2Qm044IM`111U/0>a=c02D6L@0Q02l0QVf_085X
[@1;;H`0F2b007M7R`1gBHh0OSac060SJ`80/emY00D0001n08mYXP2nRId0iJVC08eTWP020;I=@`80
ZZGA0P3]_Z820<>]a@040<f[]`3L`Kh0f/700<bZ^080i;nb00X0g<K40>>eYP3mfIX0j]2l0>VmY`3_
_9d0jlbf0?GR]P3W_JX0U:OS0P2PW]802@2KT//0NXSF09Jdk@2F]>d0Rkcg09F`jP2=ZnX0TJ3N09bC
bP0207HlN`80SgVf00D0^YNc0<b`_`3C/kX0b:Ff0;BRaP020;^heP050;Vkf`3JoK`0001U0<MhMP2h
nlP00P1SN=803P0000d0iM[:0>GJbP3nd78000000?[MY`000000k]o10=;oe@3fj8`0R9;G0>7j[@3Y
n[d0j>G>0P2M_>h01@33b=h0el;50=O2a@3S`K@0b;[=0080dKBm0P34[<800`3n`g80/j7600002002
0?ooo`0<0000<`2GSlX0Uho:0:6bi01ZV>/0Q:?X08FIg`2KZ=l0PXO?09J:a02^]]h0X[3R0P2<Xn@0
1@32/<T0g=3=0<;Sk`2?QL@0/SXQ0080X3e:0P3`d[<0103MYid0l<BT0?BjS@3GXId20=^a[@030>Bn
/03>]<00h:^M0080cY^S00L0kL^b0=bl^@3kiZ@0P3=S09Q[W@2DJ9`0]gbC0080/7NC00P0]HVW0<6C
Y`2nV:l0_YR_0;^D[P3>W:<0dIfP0=^c/080g;Rd00D0n;Il0>2i/03X`Zh0n>fO0000000S0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool0
9`3oool0<@0=0000300005@3A01I1D<06P0001T08@0d02@0AP0L02h06@0T01/0@@0l0000001204T0
CPaI04D0:@1904007P1204H0A`0:0000@`IK01<00@1M76<0GRUf04D0<`0000009P0l0000@P0b3G80
:`1F02/0@P1`LlH0GTBJ01<0J`102f<0GB=^05@XO@0g8HX0@@IK01X^Z@1O@iT0PV^_08I][`21J:d0
001n05Y1VP1D?IT0EQ]Y07@mO`1K:g`00P2cGfT01P0002X0UF^O0;j9W@2O[N40001b09n9_080@P00
0P2fYLL20=>GU0030<:GZ`37[/40g<6n0080d;S200<0hLo60=_1_`3La/@00P3mfIX02P3[b;00hKjf
0>6n]P3_a:H0jk:D0>NmZP0jK=P0NXKD09nLd@2TWm020;2Xd00509Jdk@2M^>/0N9gY07nEg`26T=L0
0P12J=800`1f?7/0Mcek07LdKP020<b`_`80b:Ff0P3?`/h20<K1e0050=7ob00=0000VEb609ULQP00
00000P0g_=T0303odhd000000:;UT`3Qk=P0hNSH0000002nnl40bmgV0=mkB01F0000k?Vo00ZFe`80
d[[200<0`kkF0<Fkd@35^m400P3S`K@00`39XK00_Fie0;e^M@020<]lN0040?k3LP3_Z7d0^SX;06d0
0080oooo00@0Q8_B092Ad@2CUM<0TiGC0P008jh01P23P/T0XJ7D0;Big@2d^Md0OiKP0:J/g080ZLK^
0P29j/<2068000070;U4:`3Jbl/0k>;70<W7AP3MXYH0l[N?0?BjS@020>:TT@0;0=JMV03>]<00b:fn
0<RDW`3AW9l0cY^R0>FQQ@3L_;T0nnJT09mSR@2EFhX00P2QKiT0102JJi/0[gFB0<65T`2lOHh20;Ag
S`0:0<J:U033Qi<0iJ^F0=NKUP3?U9P0m[=o0?K1T@3YbKH0l?BV0>G7BB@0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0V0?ooo`0F01l0
100S00007P0^04/0A`0f00H0C0E@0280<P000000A`0`04807@0n02L0=P0j04h5CP1>35T0F1aX04T0
@00Z0280=@0W03X05@1I6F<0?00j02<01080000001X0A0II02h1I0000500001O00P0A@0:03`0Ne6D
00004@0Q;JD0CTV]06=L]01OFK<0Abf>05A0W@1D@Ih0000J05m3V@2<P<40R7o303PVS`007J<0>2::
05DiU01eD9T0HCnB04<0A080O1Pj0P2EJil01P0^MN80HP<e0:UaT`2FIiT0l^fo0<RZ_080]XFQ0P3N
`[`01P3F/kL0djR]0=>X[@3O]Jd0g<g;0=_1_`80ekZm00H0m<NQ0>_8/03[b;00l<b^0=c8a@3Y_JL2
0=J:O003025CbP2C[>P0QjKX0080XK3R00P0/[?I09k>n02Nc_P0U[S_07VSk@2?]_40O:kc049XdP80
Uk_a00@0QZk_08n/j@1XO]H0J7kF0P38`=<01@2og>h0a/3E0>NTQP2h]Rh0eY:90080BGkR01H0Ug2T
0>;Ve@3WiLh0inG>0000003jg:H0hNSH0>CFb03Tg<d0___10<Sek03<lN/0EP000<7Ai`3@];h0fMOF
0=:na`35^Ll0g:^T0<Fkd@3=VZ80dJ6V0P3J];820;o8h@070<ODh`3n`g80001A0:V3Z`3_gg@0aT@0
000]]P0202imi`80TiGC00<0i^1b03<YUP23P/T00P2Gh_d00`2S`Nh0PJ;Y086Rj@020<o_j@0<09a/
V@2/]n80[;OR03iMbP3B]Kh0k>;708S/i@3nbH80mjmc0>Bk[@3[/9<0j[jW0P3FWIP02`3DXj@0eI><
0<Z=U03LZJ40iJ650>V/T@3ic9T0ble?08mSVP2/Q:T0d9>C0080MTJ;00X0KD>>0<5iPP2aL8P0]VEa
0<V9S`38RY40aHRD0=2[/`3KTGl0l/RT0P3f`I400`3ifZP0l?BV0?ooo`0T0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool09P3oool0:P0m
02d0>P1A05P:C@1L5EX0DP0d03X0:@1100H0>`1102D01@0X03/0900005H2@00000005`0004P@I@00
0000>00o01l0<@1h:E`04`1600h0000`0000:`0h04T;G00n3FT05`1O0000F00004d0200l0000F00/
D<@0MW7003=7^00WA[`0Hebd08Ag_@0P8iX0E42M02TTUP0e;Y/0HUji0<eL0080N5nY00D07bFL03PR
RP1H=H`0G32304hKK`0208iSW00407iNX`2oR9T0f;2`0:N7/P80`iZ^00<0l^fo0000G@3/gl@00P2S
YmT0103N`[`0ekJh0=Fe^@3E]KT20=>_/`0>0=bg/P3Y`:/0fKVi0=Vi^@3/f;h0k/FX0>CAa03egK<0
gkVa0>6l/P3T^:X0fkJc0=>Y[@00=:d206J?i@040:6`hP2Yj?X0ZNSj09k>n080W;c_00@0Q<7k07BZ
l`1YU>P0JJKd0P1SWO003`2R_^d0RLOl06J>i@2A^o<0]MKa09off`2>kmT0`;G?0?k3N@1m:EH0=CVX
08^1`P33jO00G]7a0=3Yi`020000000<0?[LYP3ZdK`0oN6K0>CLc@2Gl<L0bO7]0>?ma034/<H0d;Bn
0>CDa`2n[LP0d[k70P3LZj@20;j;W`070>FTR`3ab:P0RE670>k6ZP3j/6L0^mS_0=WDe0020:V3Z`09
0:4Q2`3:QhX0400;0?Z^C`2FA6D003k207m//`0007P0TJCR0080W;c_0200d=3J01:3iP1cbol08000
07=MZP1b7e800@0I08mOU@2;Rlh0]X2J0>Wj^033S9X0m^Fe0>k</03T^j`0i;^]0>^`T`3`^YL0f:FR
0=JMV03BUiD0dijN0=FFT@3NY9P0eI:<0>n^QP3YWGL0ble?04D0001o9Dd0Q2A40:CYW080SPl80P32
KVd20=>ETP090<NS]03@Zk<0d:^c0=F]/03Z`Z`0k<ff0?K1T@3ifZP0n/iT02D0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0U0?ooo`0b
0580=`060000@P0k02d03P0Y03P0=00L07Q;S`1N3T/0@@0o04`0=00n00/0?P0/06<SJ00Z02D0>`0/
0240200M0000000G0380000N03l0B2f=05TgS@0f47<0?a5^01<3NP0003L02`1L0000J00005T05@Aj
00dKVP0003P0MW7004iae@15L]X06D>n08Ag_@0h?jh002Vc018=Q`0j8hX0HTNL08ie/P2lQi`01@1U
0000D@0h5g`0NUfU04DfVP1>6fl208iSW080[WVI0P2WQk820<>J[P80[7:A00<0k=o40:VQc@2YXLd0
0P3C];/0103B/kX0eKBh0=6g`@3R_k@20>?8_@050=^l^@3/f;h0i/jo0?[OZ03TdL@00P3O]:/02P3G
[:`0i;RZ0=>Y[@3De]X0;c>T0000M`27_OP0MlKo0;K;jP1lZo8209?7n@070:?1kP2NaoD0W/Oe06fS
l@1VYO@0Pl_o0;GQm@020:WBm@050:OWn`1Tbo/02P000;aB@`3Q_K@00P3QZ9T01@1bB900KLSn08^1
`P33YK/006o70080ZHF^00`0lnfn0?[LYP3`l<<0l?330>CLc@3Vgl`0Xm?i0:YQNP2kED`0i=C70>?B
a`2h]mP207mHV@0D0:>1[P2nV;00_YR`0>>i[03ab:P0RE670>ZQN`3g_4`0cKg;0:W2A@1gEId0hG<[
05^io02kf>l0VigE0;I1:@00Ckl0`Sl007m//`1i^o/20772oP08000DT@3odW/0N83>07R0cP3>ZkH0
00000>c5[03j`UL208^;cP0:0<JY_029d?l0h]O;0?KU]@3[`JX0dZ2S0>Bk[@3X[Y@0gjJI0=^DQ080
d9jS00/0cH^;0<n?S`3SXHX0fZ^W0=^k^03YWGL0W5Qm06/LE@0a00X0O49n088000020<EF>@070>Vf
W@3?UYX0dING0=6GU`39T9P0ei^F0=2[/`020>[2[0040>RhX`3b`Yh0i]IP0?3f[RD0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0T0?oo
o`0P04d0601302T0A`1801X000172E/0D00Z03d0?@1?2E80=`190000001<2UP0KBe^05DVN@0^05<0
8@0C01X0000Z1g00;@0a04XEJP0B03P0GTZR04P]S@0d4GD07@1P03lSQP0Y0VT0801Z01H0K`0705l0
001R028>OP0h9Hh2079fa`090:RC`0000000IGK@06Efd02QUl/0=BjK0000M00j8hX0HTNL008049gD
00l0GbQd06P]LP1dF:@0BAI/04`IKP17:HT0KR9L09V;``3cYSH0Lf>b0<6>X02USK/0e_o60?bhK@0o
@:X00P35Yk/00`2j^=L0/N_h000e^@020=:c^P040=Vk^`3Le=00g=C@0=?3b`80fkbi00d0j<6]0>W3
[`3jgjP0i=740=Ba]P3<Y;00f:RV0>o5Y`3=Xjd0h[2R04effP1`Yo<0T[_c0080Rjo^00@0]O>[0=?6
c@3Ca/d0GZWh0P2VaO0206J[m`04087=o`2=Vm`0SI_L09:Ge@80LkSk00@0_5930;Bdf@2d]=T0];CI
0P39kNd0303J[ZX0ggY80<[m_P1m4bl0NEFL0>W@_03ckKh0ko;50>GMc@3`l<<0/[La05D02`80ejf/
00H000000;7gk`3SYI40iYak09fej@2/TKX209Ym/P0P0<:AX`3AYZ`0XCDi0:4e>@3e/7/0mka<0=n^
9`1l=FX0N3]h0>fJ902eL8<09a1n000]]@3Pl]X0mZQW0=YW9P3oool0eobd0?ooo`0L06`0AEFn07bS
k0000800N83>0;meO@3QN@T0b8bD0?[2E`3eaih0^6M`03Ygh@2Z`^/20;jlf080cJ>^00@0f85Z0=j4
H@3/U5d0hIV00P3CThl03`3MVh/0gJnX0>>QRP3X[Y@0iXmS0>3HHP2IBfd0H0@i06h]K@2ME7D0M4jG
09MQT@3;Si@0l[^C0<jMY0020<N:TP080<jDV@3UZ980ejJT0?C8XP3]]YL0kL^`0?gIN`3VeV0L0?oo
o`030000:03oool0oooo00L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0?0?oo
o`004@3oool00`000000oooo0?ooo`0T0?ooo`0d0586B`0h04006P0604T8E`1Q6E/0AP1=04/JLP13
0U80=00V05L=DP0m04l0CR1f02h0D`125W<0F2Yl06@fP`0f3Fl0;0I/0617W@1A=900BB=o04/^S@18
7GL09@mm03HGO01798<0;0mi0000N@0705l0000[01X2L`0:0Wd070Mi079fa`24Bh<0QEbK0000I01U
M]00FL^R03TYT`0U<:H0Ff2n03MC``07?;d00A:E059Vb@0004P0LC9a04TFK0146WH0MDR>099i]080
E`0U00T0Lf>b0<6>X036Oh<0]eeP0:J4/0000000`Zo80<6^a`32[/H00P3BPgP20<j[]@050?3>[`3X
d;h0dl?;0=?3b`3Wdl800P3B]kl00`3Qbl80n]nX0?Cc/P020<bT/080i;RY00T0hjFB0>;@a@3I[JX0
V`T001ITf@0^G<h0YRPC0=^CPP22R=400P32[lP01P2/anh0T/om09S6m`2Ha_L0JkCk09B_j@80YZ_J
00<0XZWK0;G0hP2e`>800`33gnd03@36//H0i[ZW0=Z^ZP1]a?h0FSjF0;6;[@3]gl<0000/0=W^h@3_
l/D0e;6f02e?``1GcNl00P38[/020925``050?cVWP2lCc`0_4ll0;U4:02/TKX00P2JOK801`3?YZh0
b9FQ0<REX@3[bkD0nK=c0>RQP@3O[RL00P2GBVd02@3]VR@0lYaG0?:LE`00;KD0`Zk605H0003ZW200
/Rd00=Ol]0030?ooo`0407bSk00006H0000T0<bMY`80aF5@00@0`U4c03/9IP0k2FH0YUM_0P2k]mH0
1`3]dKP0e:6Q0=BQX@3EZjd0g;2Z0>Z]T03DRGd00P3=P7/03`37Til0g9J50<EhN@3>MfT0gZZO0?oK
R02:FY<0NS5V07/jL`2@@FP0PDIo0<5hP02iUkD0h8mb0<FIZ@020<61S`070<=gNP3QSg40gKNa0?Zi
D03N]:d0kL^`0?KQ]00I0?ooo`0706l0002:7c<0cibQ0<nLX@0002P0bKoA0000@P070?ooo`030000
003oool0oooo00`0oooo00<05jK408e8M@2jV[L0B`3oool00`000000oooo0?ooo`0?0?ooo`00403o
ool00`000000oooo0?ooo`0U0?ooo`0S02h0>P1dCYL0000e01X0<@1904T0BaYb05TEG00g03`0BP9=
03d0C`1>2eP0CR1f03@:K@0l6gd0KTNC04/]R`0b47L0GSfB06a?WP168h40Dc2901l0I@1><8d06P5c
01d<O`0B07009BRM0000J00N17<0;QJ20000MP1;Ekd0L8OI06MmeP0_=ZL00P0EGmH03`2a:@00MGS8
05EE]P0U<:H03BVY09/=001^E:<0CDjc0000N01K4ED0I3J305`_P@2ILZH0Ug6V08ig]P0205L09@06
0816P@36Oh<0aWn30722eP2PVll0`Jo80P31[/L20<Bbb080f;Vk0P3Q`k/00`3Xd;h0e;Nl0>G1/`02
0>G1/`050=g9a@3]k<T0k_N]0=Ff^`38/L<00P3IcLd20=6b^`0:0=k8`P3C]K`0f:n_07N^m@0^G<h0
T7B`0;6Rb022R=40nk9D02agh`80_n3`00<0GXcV07n9e02K[><00P2A/^d0302VZmX0HIK/066Fk02e
`>80j>c@0000;`23Tm/0YJOH0=BRXP2Yc?8000000;Z]c@80bjFb00`0000/0:O1k03>b=@0c/SD02e?
``2RG7`0O8KC0<R^`03Ko=T0001a0?cVWP3HSGd20<McKP040;9aR@2GIID0/7^J0=VAP`80giIo00l0
k=Ro0>>hZ`3XXH40000i09Aj/`2BM:h0kIXT0?VkPP3b/CX0HcR60000A@3HH`00jY`P0>fDG03JKP00
103oool00`2GKZ80E5Jh0;jL]@020:aUOP050<9A<`2W8000Yb000;6df`00;K@00P2hXL801P37Wjl0
e:>U0=VUX03O/jX0e:b`0=B9O@80fXik00T0ciNJ0=n>LP35N7T0m<:I0=jZW`3ofhP0QCe^07hjL01i
=Vl00P2PHHH01038UJ00^INe0>6gZ`3BU9820<24TP040<j?T@3X/IP0fhYb0?K<X080kL^`00<0mjE7
0?ooo`3oool05@3oool02`0c0000aX2509Qg[@1i7dT0B`0008/5002;NKX0ghmd0<WDhP1/Gk80eZb/
00D0oooo00<000000?ooo`3oool02`3oool01P0002T0KRa/08e8M@2eT[<0bibW000BTDT0oooo00<0
00000?ooo`3oool03`3oool00100oooo00<000000?ooo`3oool0903oool08@1D7F`06@0602P03P1B
6fd0:P1D048CK@1I7V/0BRj<04`RN`1H:7X0AB:104PTP@1U?H`0=aUn05XdR@199X<0ERMk04dUOP17
9840K4nN03D[U`1C<8T0916204h`S@0X4Gh09bBG03P[U@0L6Y40001X000<SP0D1W`0HeN_01hZX`02
04eM`P0709R;a01EQ><0002008^9c01eN<P0Di?^07^Ii00202L0000:06iDX`0005L0O=ki05/AE@1`
>7/0=@e`09UbYP2GLJH0SWNf05L09@80QZ;V00H0R8G9000Y[@2M3@00000009lZ900i04T200=2``04
0<OUOP2m_MT0e<O=0=C5b`80j=2n00@0el750>75_03Uf//0iM[;0P3]k<T01P3?]<00eKJk0<^`_`3T
c;l0flW70=2d_P80g/S200H0bZbl0=R/Z`0007/0S76_0;b`cP2aX/P20;gGk@0703>VlP00RkH0J9;W
06RBi`2FZnD0K/7n06:Jk`020:K_m`060;kFj`18^_D0di^K0=>KV`1kc?l07`000P1U^od00`2mFDh0
fWmR05f^nP030:k>l@0:026^aP2]bNh08Jk6069ccP2RG7`0O8KC0=_lf@1Oc?P0e/c@09L>0080`fAI
0P31JfX01@2LLJ40eKNl0=Fg_03=WZH0dZN]0080hkR[00h0o=Aa07aAU02=GYH0hoWC0?VfMP27Dh`0
l[4j031A``3bhkd0f6<00?c=I`3WQdl0khhe0<Z10080oooo0P16S^d02@009k40FUfl05YM_03@_<L0
h/Bj0<FL[P2[KH`0R5>;08mUW@020;NR``030<NO[`3P^:h0g[jh0080dJZa00`0ej2L0=JGT@3FUi40
e:JX0=^RV@38UZ<0llBN0=jZW`36dEL0PcQW095AOP2>CWd20:iaS`040<REX03Ra;X0chb;0<Z=T`80
cjF]0P3M_;P0103U`k@0m/bP0?c3Q@3mgilE0?ooo`0808KPo01Z9fP0Q^3l0<J0Q@1T00H0RT=a0:UJ
L@2ZGgL208DG:@050:@N00231PX0]eUJ0=J/[02E7Ad00`1U00<00`3oool000000?ooo`0;0?ooo`06
02D0>`000700Teb<0:iiV@2eT[<0XZWL0`1=00170?ooo`030000003oool0oooo00l0oooo000@0?oo
o`030000003oool0oooo02@0oooo02X0?`1;054GJ01B66L0A`mT04PHL01V@I40Ebn4054fT`1C>9@0
GCbA0597Y`0h=Z80GD2G03hTQ`0m:Hl0?bZ@050_R@1DAJ<0CCnQ04l`S00g8XX0?BN=04m3Y00006d0
E4>P02LTU`0l<IX061VB0080OP0H8id0G6C20456/01oS=H0BFG<04eM`P2HRl@0Fh;O05I0W02;RL`0
QdAf050>FP0003P208PbF00708_Do`000000C5Rn03L9J@1`>7/0HUJ^08Ea]@020;VWb0030:^ih`21
WnH0QZ;V0080]2h000<0TeZ:0?^eJP2gi?D00P2JKId01@2Vmm00TmOn0:o7k02_an`0c;K40080hnKD
00<0d]3G0=WLfP3NgMD00P3T`;80203]k<T0j]o80=:`]`3<[K/0dKJo0>^jX03@];h0aGb10P3IZ:D0
0`3/a:/0eJNX0;k2g@0208O1nP0609Kad03k/U@0e[^n08BUj@2]Be40HJKf0P2EkO<01P0ZZNT0WLOe
09g7m@1ibol0QLgo00de]080K00000L0C0000:0U603FPF`0eX5/0=bNT`3OWhd0l^Bl0080aOg50P2o
b>40200e6X80>aUk074/J@3PTgX0k?C90>?ae`3OPed0olmd0P3C];/20<I]I@0?0>FjZP3K[:L0f:^Y
0=:X[@3BYjd0c9nY0?g7Q03le740FjCf09EJR02:DXP0Z9C10?VfMP0m5GD0>3^Y00<0?P0000@0n/F?
0=UT0P3<C`00FGWH0`3oool01P0;59<0002@014o_@3C[kD0h/Bj0<FL[P80<FWI00H0SfFM0:B6/`3<
]<<0c;C30=o:a03>XJX20=6RZ00;0=B_/`3DZ:`0e:JX0=BVZ03AWIl0gJJM0>b/S03k`XL0a]5G074H
A`1X1C000P2VGgd20<fAUP050==hH03NWHd0d9FG0<b=T@3IY9l00P3P[9l0103U`k@0oL5i0>O1[P3^
j8@D0?ooo`050000101D0000Sa<?01P0002GAfL00P23AWh02P2[H7L0P=ZI08D0003JOUl0ikVV0>>H
O03W^JD0U8_70:f1Y@2DRlL30<UYF0030000002F0`00oooo00D0oooo00T000000?ooo`3oool0oooo
09NAc01C00P0Wh6b08mSV`1Vfm/00P24/o<00`25U]`0IcV508mIS@020;bnfdD0oooo00<000000?oo
o`3oool03`3oool00100oooo00<000000?ooo`3oool0903oool09`1?9h00ERn604dFJ@1jH:P0CbEl
06A2U01L>i00BBf<05@hT`1K?YD0FSB9044]T@1DAZD0ESRA0617WP0f=:40DdVY05U9Y@1MCJH0:RbN
05UB[`1HF;L0=B6:02`EP@1FF;T0?BfD0000Q@1QBZ00;DJj01L6N`0fDl<0<SRX07n<eP1KJ<L0Cf34
0:NYf02/H7L0:Pmk0?BO>`020<cUj@050>?=`P0;6IP0G`000869d`0002000P0008402@2FP;T0HUJ^
09BQg@2DXMd0Q9SN09EAN`3D[:l0LA0j04h09@020;nJ/@0609=JRP2el:80:D>h03]ihP2JKId0I3^;
0P2g_n401`34a]`0d^7S0=cAc@3LdLd0h=_A0=WMf@3?`</00P3VkM<20=:`]`80dKJo00@0jkZP0<n`
^`35Zl00c[[60P3/a:/01`3I[jd0i7LG0=No``0lVO<0V?3`07GRj03FW9P00P38_M020>?Ve@0808c8
o02cdO00olUn0=6h`@0001l0ck_60>OjbP1<000209UHP@080;nDZP3O[jD0gZjV0?7f]@3_fkd0l^Bl
00006P2IX=T20;k1f`0:00005P2c/2H0WL3a09g0l@3/m<T0lM:a0<nHW03ocg@0d=?K0<BN/P80cJ6[
01H0iKZZ0=2c_@3BZ:d0dZR]0=:W[@2ekj00g?kA0000002CCgX0TgZd0:9kZ@0>0540UTif07Yb_P3b
ZC@0a5`00:ebT@3k_h00olMe0?JmSP3dXS/0a5T00`3oool02`1YYO@0>ES60000S@3H[Zd0j;j[0=^j
^03FOfT0001O00m:a`22Qm00/Z?90080e[Ji00H0bKK80=6RZ03R/jH0e:nc0<nZ/`3@WZ<20<^AV00?
0=fVW@3JTX80nl:70000001m<fL0STMb0:5GM039Q8L0fIV@0<b3P@3BR7l0lZ]k0=2AT@3CVIP0g:6F
0080gI1j00@0;Ped0?V]C03W`Jh0k^R44`3oool04`0006P0IPi308dkH025:D`0JAmL08eTW@2MFWh0
]8FS01P0=02PSL00`I^a0=:DT`3MRFh0OTn?0=N9N@2kI6P0]5mZ00`0002WHX000P3=MVT010000000
J[7j091CQ02<000205L00080I`e000H0Q3YX09U3G`3LYil0bn1b09NAc02GWMP20;cmf`05096lm01o
]OH0OkGf06Qkd`1oW>D00`2AjoI50?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003o
ool0oooo02@0oooo01l0000l03HDN@1@;HL0GT:H044OO`19;H`0DcF?05PeR`1D>9<060Ik05Q=ZP1O
Bj<0AcjS069O^@1UDjP0HU6Y03djY01>AZT0@TN`04m1XP0a:iT0BSnR06=K/`14A:`0HUVb01`YX`1?
=i@0;Tbo04E:/P0S=J`0<B:>0080LWc>0140AD^c05i<Y@0i;YP001FT08aQV`1`DYl0b7Yh05nYn00i
>ZL0BBj=00nLe@0003l0K2UY0;7Al@000840UX2i06AleP0209BQg@0708BHgP0E04/0OM3o07g@o`32
Q900E00C09I/W`020=[Ge@080<OkiP34^<l0MdV=07DiN02o/</0]koQ0=;Qh`2jgO420>7@a`040=;N
h@3?`</0gn;F0=oReP80_Z6k0P3B`LX00`3?`<`0bjVh0=2[]0020<jjaP040>2l/`3I[jd0fJn]0<NJ
Z080ajZl00D0dZ2S0>>i[03A/[X0dK:j0>?Ve@0200001@080<Fcb02aWL<0`k;909O>n`1idol0_mCY
0;f[a`1C:Gl209VCc080bm_U00d0lOJe0=3gi`3Ejn@0l^Bl0?>V=@3Mi]/0Kmk909XC002iARd0/k0V
0;kmc@2Q^n/0SkC`0080e<gC00@0olmd0<Bjd034^]00dlG<0P2`aNX02@2mc^H0R5VC08QIT`2cji@0
Y_G]0??a^`0000l0Sg6]05P0=P0207]EVP0;06YBY020D8l03`0@00000027EXl0oKUX0=ac?`3]S2l0
fVP00>nBB@2a:0000`3oool02@0:6IT001VU000b]`3YXR@0c6Q@0=1T?@0707P0T8g<09B[iP020:bn
i`80c]_S01`0Y:cM0=:k``3B^l<0]KoQ0<b__@3;TIP0ikfZ0=FQX@3ggWT0nl:70000001n;E`0WUAd
0<bFW@3JR740bHZ?0<N2Q`3R[9/0jkBI0=JKU`3:Ti/0g9fA0=^KSP3;I4/0gFh30:iaSP3Uo<@0k^R4
203oool00`0U00D0R];o08[Bo`0203g1f@80GP000`3oool05@0000005bVU07jin@0A00X0UU^809U5
HP180000=kZ_05lGF@0W05@0[hZ^0<^Y^03A[K@0G<Si0<JU^00RW^X0oL=n0:RE`P15FL<0ej^[0000
J`02000000090:I9F01ZZoL0/5AL08Q6N@2F9Rh0KhCG0:B=_02=DH<0YVjB0080bG=/0P2:^_H209>i
l@0508Vhm028[^h0QgNj05EB/P2S]>D00P2LbOL00`1_0000oooo0?ooo`130?ooo`030000003oool0
oooo00l0oooo000@0?ooo`030000003oool0oooo02@0oooo01L0L5NU04M0YP0/47/0FdFN05Q2W019
;H`0>c6K05=4X`1/FJ/08SN_04]3YP1RFK80F5:`06EO]`1kIJl0Je^_054oW@1mMl80BTfc03i<^00k
@jl0@d>[00XFU@0206Uid009000OY`0Z;j80EE:b050nWP0007P08S>[04mG^`1bO<h0PeVI008002J^
00H0LT6602X?N`1`DYl0=P000008T00?06P209EOS`0401L0702<T]@0XMMc00000080^H>J00@0GdJL
068SJ02nTZX0_Y:Z0P32Q9002@1gD9L0D2Ek07ldI@1o=6D0@C>I07M3Q@2[SKH0Y?7e06[BnP020<Bd
b`040=Nl_`2cm_40/oKa07/:7P80`m[[00<0a:Vo0=c;a`3]/Y800P35[/<00`3E^Kh0bjVh0<^Y^002
0=Bb]`040=Bg_@3=ZK@0fJj/0=V_[@80cj2W00D0eZb]0=Re]@3H]KD0fJRT0=>VZ@0200001@0807;J
m`1QXO<0HJ7c02bZj`2_j_P0`O^o049khP2QHXH20>;ef00509Fek@1[^?`0JkSl01fZ^@3@mnL00P2i
[/h00`3cYSD0e=?G0=CCe`0207CPk@090;>`9P3@c]L0[:KB0:bVdP2P/><0e]_L0<Ra``3M_[T0akC8
0080f]kJ00`0/<GZ0<KbkP25Rm40Zc4M0?KXS@3clK/0nn:80594Y02Tm<@0McA_04h/Q`2AJJ4209Ho
G@0908=IV@28KZl0:UK:0;A`QP3LLcl0kH`_0?BJA@3IH`@0gJTR00<0oooo00`0QXG;0000H@0GA/80
EUo00:eUO01c?H00KI;U06^1eP26Znd0U:_V0;O7i`2IcOX20=?FfP030:oGm@3;bmX0]KoQ0080`Yjc
00D0]HZX0=V]Z`3ggWT0YLE>0640000209lU600>0;e]M03JR740fZ:J0<Z=T`3QX8d0lkV?0=>IV03K
YYh0eZ6P0=VIS`3UXh/0j;fX0:iaSP3i`Xd70?ooo`0804H0000j0000000004402@000000300009/h
B03MjM`20:n`f00=02<0003oool0T=gn0?VgN00001/04@0:0;5nW@2AE8@0ZGVN0;RK^P2iWK`0XiK7
09n5^0020<2=X00406iN[`36YKP0=00000000080?@0000`0dYjO094kF`2A>e/000000<F=V02HLZH0
W4]X02T000000000Sg:^09UfZP2POjl20<6^a`0508ZIg01?Y_P0YgFK000CV@1R/o/00P1RZ_P01P27
MkX0TikL0:Ndh@3Zh/T0j/]A0>7@adD0oooo00<000000?ooo`3oool03`3oool00100oooo00<00000
0?ooo`3oool0903oool0401198H0ETNT04/kW@1dK;/0CDR[05eD/00k<I/0Gf[603@_W@1@H/D0BdFY
06]Q]@1JCj/0ETbZ07]T[@0c78H2081[/@0?06EM]00nC;P0F5Bc04a:[`1]AI00THG407</I@0Z9IL0
DbZ103HDN@1G<hT000>>02LdZ@1TGkP0J4RH0080T:3O0P1XUNT02`1QR>40;e7308Z:cP0l3V/001fV
06``M01[J[l0NGK308bBe01Z?8L0T7Zg0080?P0300<0PCmf07M3Q@2o]]400P2]f?L00`2@XN000000
07Y>TP0209O3m@0<044cV@0006`0001/0;JH^@0L03h0d[2h0<N/_P3J^KL0BAig0>6GOP0A0000XMCj
0P3>^LH20>O>_@80`k;:00L0eKVn0=Rl_P3Bam00d/O@0<6`bP3D^;h0d;[50080a;?:0P3M]:h0103<
ZKL0fZBN0=ZTWP3IZ:@20=Z`[@80bjVg00<0j<^i0>cA^@2mJ`000P2mJ`020;Zog@0606`0000hXO@0
bk700=3Ri@3?m>T0Caeb0P38X[80102nW[P0in3<0>?Hc03Fa<P20=gIdP040?SV/@3>^lL0c=SS0<cH
h`80^KCD0P36a=P06P39_m40g=WC0<kof03>omP0B@0c09fIc`00BLT0b>g^0=3mh@000000KSAh04FW
m`2HT/`0000009UbY@034Y@0000008=IV@1hBH`0f8=/0<R9S`3TOdL0o]bH0?2B;`3IH`@0]bl00`3o
ool01@26QL/002nh000DV01DGKl0TY7@0080THc:00H0Jh7F0:2Xg02j]mH0S/km0;BUb@33^M030:oG
m@0D0;fjeP3Sg]00N<Cn0;b`cP30/</0mmii0=?ob`1=00H0Na8^0=b?N@2bD540bedk0=9YA`3@XjT0
gZfT0>fkWP3W]:00fJRT0<b@U@3^[HP20>fdU00301/0A030[B40oooo00D0oooo00l0JRQZ03/0000k
0200900005/09`2L>dd0d9^N0=gYg02cVKd0hl^o0;U1003d^TH0h>V20000001bF:D00P1k;V40102Z
Khl0[8V`0:n</02fSJ/20;nJ/P030:J?_@2bXLH0^jC20080V8W200`0mkn?0:Q^T02XKY00dYjO0<24
T`2@>ET0^fI[0000000`0000W5Ag09E=M01k>G42089oa`80XZOJ00d0THc:0;6Oa@23FIL0Me6H0:Qj
X@000000dYnQ020ER02eXlH0Y/cd0017_`37oN80/JG;0080hM3700<0jJ>10?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0?0?ooo`00403oool00`000000oooo0?ooo`0T0?ooo`0Z01LUX017?:00ET^Y
05aB[@1=B:/0F5Zi05=@/@1XGkH0B5Ro05m/b01TG[H0L6Jh05Y?Z`1_FZX0LFfn069Q^`1O?i@0P6^a
04P[R`19;8/0OE>E00h1N@1dEj807P1H0000N0000000Ke>R0000GP15?jH08bNL04M7[P1TGkP0FHCQ
07:Bh`2@X=l0<53206fCiP0CAL80LHoP08Z:cP18>Id000000P2oW[L01P2lji40PDIn06XlQ`2@N[L0
KH3E086<e@80XjKH00`0S9kO09]YU`34X;@0000007Q=T@1jCY80L5JU0>C[e@3n`740GCR<064lSP2T
S[h20=:`^0030<bc`P18;Hh0JDFD00<09ZKY00@0fmGB0<;:h03:d^00g;fi0P37^Ld20;j2TP80eKFi
00@0`Zg50=2ja@3>^<@0c[S40P34/lX00`3L_KX0bk2o0<^a`0020>6_X@090=JVY@3R]jX0f;6a0=Ra
/@3Xc;X0lnZl0=33c@3dX3X0mZEO0080GMC70P2AYnD0103Hol/0Uncf00fIeP0gEL@20<B`aP0409;^
l00nX_D0G`000:WQnP80k<R`00<0kLV_0<?8gP2ga>@00P39b=T04@2K]^X0b^k/05_:m`2N/>D0olam
0<kof01:akH0Sm;n09UdY`0:0000N^;`0000001^7580KSAh08ESX`2DLJL0U3M@0080bZ>`00/0JcMn
014WY@2bOid0^lkY0<U9003[/980o>>R0<cZQP3IH`@0oMJF0:HJ00040?ooo`0@000;V`002iD0[:KA
0:bVd@2AS<X0Pffb09ZJdP2PZ=`0Zio<0;BUb@3Cbm40^/cX0;2eg01cMlP0aJBh0<bY]`80_;3>00@0
^k?A0;7fl@1=00H0/4Ho0P3=Gc/20;5MJP0<0=>LW@3JKc/0kieY0>RTQ@3/[H`0aHNA0;UUK038HT`0
ikJR0>NIM00K04@00000103oool03035o/L0C1=U03@0;@030000KcUm07e@T@2DK:80/7VF0<=cM@25
A7P0LcId0=Z:M080[DmG0P1E;8801@00=[D0NE6F0:UmX`2WOJD0^HZT0080_J:n00H0^JK60;ZVa@2Y
W<T0^:O80000A02DKjH20<61S@0L0<M=002OM:80`8BC06P0002_X//0^fI[0000002KDgH0W5Uo07d^
GP24DH`002fd04i^d`2MYM/0XZOJ08n>cP20K;<0JUR[07MAV02l[<X0CSjO08e[Y`2AII`0YHBa08I_
/P1XD:<0QVRY07R/l`80dlK>00<0b/[J07VNj@3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00
3`3oool00`000000oooo0?ooo`0U0?ooo`0G06AM]@1]HkH0IVFl06AT_024NKl0AU>k001Cd01HM=@0
AT^b00@HV`1TG[H0GbYg07M>U@1YS^<001BR069Q^`18>9/0O5jT03@AM`1H:Wd0OE>E07Alc@1DIlT0
0P1NH[h0301hCi@0Ke>R06MjdP18QnT0QI;I02Q^g@0O:J00SJGU0004TP0n?:H0<5320:R0Z@80Z3L`
00L0B3VM0;o_V00N<j`0000003/00021AWh0PdMo0080ZZGA00D0NHOE03@kZ`2KPKH0ZYo<06kMa002
0<BP]0090000002>Rl/0SX_;000<V`2HF840000T07@jN`1iM<40]YRi0080a=;U00@0ZOSU06]7U01F
G[h0]jC7103Di^<0202fi_H0c:Zg0<bZ]`3<Z[L0b:Be0;bO^`3K`[l0ekNj0P3;^LT20<RY^P80bZ^j
0140e;Rn0<^a`03;/L00f[Rf0=B_/P3B[[@0fjfW0=Ra/@3Yb;<0l<na0>2eZ`3ijZ/0j?K?0?JUG`3n
`fH0n=ii0?cINP0203:6j`040?WZUP00G=@008o40;G/mP80[=;d0P2W/=h01P2QYMT0d?oC0<o8d`3]
bJl0b=CS0;O4i080S;[e0P2_j?T01034e>H0T>_d0472^P1Aaj<20000000905[<m02Dknh0:K7J08mb
[P090000J`0B0000A@1Q9Fh0a[350080F@0e00P0F`0f09b1]@2bOid02P1S09RFc`0LA/00o>>R0<mR
>`80liTj00<0omV40?ooo`3oool00P3oool02@000580001Y03n0iP2?P/80ThO407IP[02bXLH0[JC?
0;[4hP020<G`k`80/;GL00<0LgO80<RX^@2f/=<00P00NKX00`0000X0Um5]0:8f=`020:8f=`0?0=]/
;`3;R8X0bhR:0>BJO@3f`iL0kieY0>VIK`3FNEh0b8jH0;FXc03@_LP0m<6H0=>OX00K04@0j>1c00@0
oooo00T0D`0K03h06@1]:f/0PTAl06lgN`1lCY00^9nn00001P0e/^d00P0BVMh01`0JX]`0aD@00?NT
C`1?7G80aj>c089=R029DXP00P2lRJ020;B>[P040;nBZ02iY/H0^ZK50:VLb@80]j3100D0;e3306AS
_01i0000@00`0;>7Y`020:EMN@0306P0001D000000000080N@0000h0RDAc0;[SO@1mKKH0BWkR07N5
e02HULl0Shk>089TZ02AQ/@0VIG>04L00000B/T0SF^W0:6Lc`80_j[500H0J52S08AXZ`2ESLT0?F;?
0<S5e`3b^I550?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo02D0oooo
00@0I5fe07]ob`0^D<<0Ig?<0P24OlH01P00Dm00F7CD00LTYP0lHLh0R9SL03<eY080[JWD00@0V:3J
04H00000:[<0U:CP0P1lLkl0101T]_`0026/05^jo02Hdo`205iR_P0K09Zfk01FSn/0002@08FBf@0P
E/d004?407ilaP003Y<0<2bK04i2X`000700hnOE0=Z?1`3?M`00Q`0001hc[025S=<0UYKA07VGh`1M
NmP0WIcB0:ZUd@1P;W`0j?[908EQX01baol0L0000080N14a00<0cH^=00NI^007VKP00P0000020:XY
2P040;O/mP2fV;T08h_/04dGJP<0000000P0YWjX0>GRd03RjmL0h^_G0:naf@2j^=P0U:GP0<JndP80
b:Be00/0fl:o0=o6`036[;l0aZbo0<j`^`34XK@0bJ>a0<Z``@3>]L40e;Rn0=Rm_P020<bd``0B0<6^
b03K[JL0h;>Y0>2cZ@3Ma<00l<na0>2eZ`3ijZ/0h;je0?CTP@3n`fH0n=ii0>?KJ03kj9/0oN>F0?S^
Z03chgd0PKKf0P1a_Od01`1D0000OK;f08>em@2Hl^H0b^;Y0:Rch@2n]=000P3Je=804@2Kg_d0W<Ke
09kEn`2EV]H0000008B0a`1UE:T0/8N[0;6Yd02/l:X00000085HV0001I@0SFJQ07oGoP3A];d0IBmi
0080D5o300<001fN0000AP2W=2X00P2W=2X02@2[=b`0X5]l01a6`01oM;`05`1_0?6KF@3g]4D0Q@00
0:/W00040?ooo`060000T@0007L0SX;104`bT@1KFkT0^9Zj0P2c`^D00`2Kc?P0_/7K0:G=m@0209RW
h@0:0=2laP2>^?<0__kD08QHTP0000X000000;Y6;@3;Mfh0dF400=3BF080^UmP00/0hGXo0>NbW@3l
c900oL^;0=R][03=PWh0g:JL0?;2W@3d`IP0o/b80<jh;`040?ooo`0;0400A@1T2Cd0>P1205@DH@1h
=6d0X6660:J1[03obg40Pg2f099NT@3][H/00P2fEeP02`35A000NmVL01h0A`0dHm<0PTf80:=mZP2c
U[T0`Y^`0;jT_`2_W<@0cjRa0080b<_L01<0][KI0:Z^f`2a]]`0Bl7b01LOVP1YAI<0Uef;0<>8U@2G
M:X0TfRM0:M^T@2TNJ@0000009T`?01?00H0QG2d0:62/@2>P;l0TZWU0080LXgN00H0PhcD07YmbP29
/>l0X[[Z0>kP``27XN@20:fSc@080::/gP2<kNT0ShC30:2ok`2ESLT0W/Wf0=3Hg`22E9950?ooo`03
0000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo02D0oooo0P2ZVlL01P0^D<<0O8;=
09:LfP0007l0D63403lUR@80^<o[00H000BG059O`P1gK[/0eojn0;0m;012V?8209Bml`0801f4j@1h
/oL005[>03jQm@1U`?h0Fk[l03:Wl@2k]]@207<aK`0509DnF`1[EZP0I66i0013a01c@hT00P26G9X0
2014?ZH0001W09=MS`3jiZ`0n:UH0000F@00:k40QHcC0P2bkoH205d8@`0:099GQ`3L]c009P000=a[
201K=HT0^5YI07];S02O;bl0Xb<<0=AK0`80^jS60P2Nhod01P2EXM`0000>0>jlWP1>35X0CB1g0;^R
_`80/Fb200D0B8o^0>GKc03Xe/80/9Fk0<6M]00209BUh080`KK?00D0`kO>0=fn^P3M_[X0e;2d0<NZ
_@020<BQ]0080=>c^@3>]L40e/;70=K2a`3H`lD0c[C00<bd``31[/P20<RgbP0:0>OFa03Ma<00l<na
0?kLT`3ijZ/0^LY>0?CTP@3gl:X0fOjn0>?KJ080oN>F00D0n^ZQ0=O@D`0NQ^T0RLcn07d0000207k<
o`0406c2oP3Mh]T0Z;?Q0:Rch@<0Vngg00T0Vh_206MCY`29GYT0dIZL014IUP1R@YH0YhRc0??c[`2C
EH<00P36Q8/01032nnL0B@0>08eVX@2OM:82064PIP040;5=C@1>4V80Q[?c0;bc:P80a8nN00X0E4b[
0<_aV00007h0=`0^00T0J`3^ZX@0nk]G0?g1N`3]kHh0o]1c0P3oool0200004d0Ka900000IP000980
>U[8076an01KFkT0WmWl0P31/ld01P2PcoP0^]_`0;[Kl02aa>P0S;Kb07eCU@80h?SH00d0000008AK
VP37KF<0c5T00<ETE`2fDTh0YQP009XfAP3AOFd0oM=b0>nZP03gYUd0jXDm0080cZB^00D0fZj[0>>U
T03`[H<0olE]000000040?ooo`0B0300E`1UCj@0<`1708QKU`2;H9X0Gd>I08`W?@2;I9l0U]=c0;^M
^P3][H/0cJ:/0>O9^@37S9D0ZXjh0:VTd@1jU^80RV:N0P2cU[T01`35X[H0_ZBo0:kOn02^goP0aL[N
0:_;l@2TZMX00P2^]=`01`0628L0=5;307]^^02YS[T0[H:V09MdZP2CJ9d00P2TPJh06@000000RW6`
09=g/@25L;@0XH:a09R9`P2>R<P0F6_;07^6d`2BVmT0M8[J0:RXeP2f[]40YZCC0;4W002Xb_80?000
0580103h]DP0hm?80?W2S02Vg?X0AF;<0=?Cf@3_j<@0A@3oool00`000000oooo0?ooo`0>0?ooo`00
3`3oool00`000000oooo0?ooo`0U0?ooo`80YH>`0P1@ILT02P22Q<`0W9?:08aWXP3Nm=`01bBV09_M
o@1`@HP0P[Kf04ZkmP2ddNl204Efg@0809ZRfP02Mmh0AF_C07Ban01I;7l0000A00007P1FZ_T201T0
000E0<oRiP1nD940UCiK0<>bb@26?F`0P4j<07mHVP2:god0=h?Y05MK^`0006L0=cZW0?2MHP2X`4@0
k_K308T@5@1k@h40QioS0000M`1_?H@0gO?M00<0N00000h0i=[<050JK01kBh`0U5b<09gb``2OJY<0
SWjm089e_02Lm=80S@8009^Dc03Z`:T0NTf?0>oP`@80000000L0^j:o0=Bl`@3D_<40e;c10>OHaP3X
e/80/9Fk0080ZC4R0P38[;d00`3A_/P0`;[D0<2je0020=B`]080`jBj00<0d;W30<ne`03?]L000P3<
WjX0103KZjD0c[C00<RX^@3X`Zl20=W6a`80gLC00P3Vj=403P3hhk40^LY>01H0J@3]jhX0hog;0>?K
J03fl:@0i=YV0=C<CP2NM:<0901:0:B:^P2dUkT0:6_K0P1BXoL0300l0500]iNf0>ke``3^mL<0[7:B
06i]`@2KRl80Qfb^09Yk[`3=YK00_7B109Ak]080RD1^00@0i7m407F3d`1feid0S3]R0P2PFgd00`21
?G80HB1V07a7Q@020<R<T`0609YYV01g5C/0GD>J09HY<`1L6f80UQT?0P30WkP01P1O;7X0000i0?^k
E`3m`G/0j8lH0?k@L`80oooo00X0000006h@?P2DRLH000NE07f>f@2R/n@0a^7/0=KNg@2T9@l0Z[3M
0P2a^n801025Umd0XZWK08eOU`3?f=l20;;Sm`050;Tk001IMmH0jMMS0>Mn9P38IeH00P2?2`00203k
/f<0jH@P0?gCLP3^_Yl0j9I]0>Z5?@36VJP0dYZK0P3SZYL00`3]_J00llFO0=?7AP040?ooo`0B07UA
UP1W:Fh0FBYk09=SU`27F9<0GSR<0:UdV02=GI@0G00f00X`/@3][H/0h<6i0>O9^@0000002CFf0;VQ
`01@8WP0Ugfd0P2cSk401@35X[H0fmSD0=_He032g>`0WlSe0080QL3j00T0UZoX07nVk@1kPll0XY32
0865c@2EQL00/9Bk09BCc`2IR<000P2TPJh010000000VHS00963`02DQ/8209Z;`P80UhO000P0PHoH
07Ic``2ES<L0UHc70;fQ_02ZV<@0ZIW6091UW080WK3U00L0/=;b0=kFc`3Ne/l0QMnQ0<Nmd@0002`0
kXhi04D0oooo00<000000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool09P3oool01P24
S]D0SY?D07]b_P1[bOh0CHOW0=kdg080Ojgb0P1^__h04026col0PK[i03iWd`1ZQmd0AGKM02QBa`2a
Y</0NikX03idgP1IWO<0RDn403>?k`2E`?D0Ym[i08^3a@0000h20;WFk`050000000PHMD0022[000B
V`1SHKX00P1oQLl02P1[g]`011jQ06mic02X`4@0lYiN0600000`0000UGff0000M`2V>3H20:RQc`0D
0<J_``1T5e<0K2i`04Bok@1c=gH0001206Fio@20Ah80SWjm07TmN@1F8700B3>E03X8I03Z`:T0:00[
0000000N0480Ee^k0;^R_`2bZm420=Bl`@070=fXW`32_=D0alOJ09NNf@2m//l0`KSA0<Bid0020<[1
dP060<2je03BcmH0alkO0;bWa032Z/80/7NC0P3L[:D20<bOZP060=^[Y@3K^KP0dKS10=6h`@3Ia/L0
iMk>0P3PhM@03P3hhK00`jXL0000002ibTh05P1Y0<kRM@3Sj800iOBL0?K`Y03cm;P0e<a>09YHP00Y
05<0Y7BM0P2KGHH00`1M>Hd0DZ?g065^b@020<;Yl0060:eGI@2/LY80VGJZ08EXZP27K:h0VW^_0P2l
M8402`0005`0RD1^08U0KP1W>8<0A0II0>ZCH`24A7X0RCm[05L0=P2=@fh0ScMF0080YFZ>0P37V:H0
1@1B?9T0TfRN06a>W00004<0T9[J00<0USmK00H0liaF0:4R003och400000000_X@3oool200003@0<
0000>03UVW/0>3f[07f>f@2R/n@0TnWh09^Oe`2[^^D0Di7]0;gPl@3ld9D0_Mg`0P0iU_804`000000
a[W=0:bH`P3RjmL0Qe680<Z7RP3WORH000000<F9U03JQFd0ffLH0>b::03mdg80k[jO0=Zj^@3Wb[X0
e9:<0<N6S@3d]XP00P3]_J000`3e_i<0n[A_0?ooo`020?ooo`070000D@000000XY3208YPV`2IR<00
[gNE09ATU`020:BB``0<0<j_^P0A<[40a;S?0=W0`@2m[//0kLV_02Dk/@2l[l`00023091f/P2QP:l0
a:_00P3@nND0303Po;D0`/kT0;>ig@2c^Md0VkGZ09:^j@1>Q^L0Nh??000T[`33[L@0=XW/08>ZkP80
Gi7Y00T0V8S109b;`@000000VHS009R8`@2AQ/D0Uh[409B6`@2GQl000P2LWmH03P0jHLl0L6^m09^6
_02^YLh0ZYS40;6M``2lXkl0GgkJ09jRf02i_mh0cORY0000002`]=`0/k?H0P2KS/D00`2Sc_H0oooo
0?ooo`120?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo02P0oooo00`0
H:Og04B0i@1cT>00N9kZ08Fjm`0?H=L0GX7L06n3eP2;[nh0YKWW03UTdP1ZQmd203j3j00=07nWkP1k
Y^h0E8WW07JKj029Ch@000jC04g;f`1J^o`0=7CO06W7oP1Gb?D0^Nod05Z7h`0201E?bP0<001WfP1X
Ikh0QZKY07n5c`0008X011jQ0<JU^02kP@00lYiN0<B6T@0S00D010000P36Ngd0201ROmT0ZIk;0=cE
d@32f^/0;kGM09Q^X01L@i/000120P1ed_h02@0W04T0>`i]04lNL`000000Aaag058CG`0^05@0000h
000000020:bYe0070=G_i02lgO00g_SJ0=cAcP2me^`0alOJ0:alWP020?Cc[@050<>M/@2mNhX0000n
0;bYa`3B/kX00P2oWKD00`2jWk`0`jVo0<NY^`020=^ZY0090=Fi_P3Nal<0f<G70=6i`P35/<D0h[Z^
0>GPcP3af;L0eK6e0080`jXL00@0g_k?0>?PL03AkH/0c^^80P3ggk401P3fl:@0loBh0=;<C@0002<0
clGA0=UkF`80MaY300D0nkAB0<^JY01X`oh0M3Ab09A>N0020:=3D@04080C:P2SJi40@BbA08Y?P`80
^hJL00T0_7B108=ET`23EI<0QUVE04@6F@2`HgD0000/04T5DP1>02<00P1iDIH01@1H03L0M1M20<NH
YP37V:H0DSbI0080IaA<00X0f^oP0?6_P`2KJIL0S6fZ0<gfj@3cW5H0mlNH0?;;Z@3[jhP000140P3o
ool00`007Yl01bZ/0000I@0204QH_`0;08;6oP2>ao/0S/Ok0;j^bP22NL00o=2E05K1nP1O>H/00000
0:N2[00006@00P37//H01022EiL0QU^H0<VAVP1h1QX20:@k?`070<eQ?P3cZgH0_dP00?RWCP3a[H00
f[Zi0=RWY@020<5iPP050?BfR03Y/IH0lkN;0?NfOP0000000`3oool05@0605h0S7^k0?ZcK02OWM80
VHS009Ii/037Zkd0UY;=0;C1i02__^D0001Z0<Zib@35/<D0kLV_0?g>SP1MRN@0_Z_70757T02WY=<0
c/SD0=KOgP020=;`i`040>3l]@31_ML0/kWM0;>ig@80XKk^0140K9OY07Yha@1VR=l0TZ7N06V?i013
Q^T0EZGg05f>i`1gP]40VIC=09:5`P000000/j7609JBc@2UX]80SYGF0:6Qe00209bOeP0603eVdP1f
Smh0S93B0:jUcP1iUN80/9k60P36]<T0200NHMH0gKJ_05P0003GZ:H0`kW@0<o`j@2Tc_H0iMg=A@3o
ool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`0X0?ooo`0805QbdP2EUm<0
PjO/05J<j@1ALM@0R97F06JZm`1Ra_`208_Po@0:06L_MP1lO/T0YHnn0:7]n@1kZ?00AY?`04j9j02K
^^h0BGoS0000QP80LhKH00X08TW103ARdP0JA;l0HHkV076ko00HO>D0F8KS046@k`1_=gX001jX0P29
Rll01`1RUnd0`YZ_0?_4R@3j]g@0Rb0c06RLkP1CL=800P2dUKL05P28Vml0`][[000000000000M2aU
08Y4L`0204l0001207<kO01H3U<09`190=oMJ`3;^C00U9?@088nL`1f@hD0M<go0?[[X@1QG;L0E4BQ
0:_[n@37d>820>?Nd0050=W;c02j/M40Xhbk0000CP2mE@000P31Ykh01`2RTL<0000009HE1@2F5@D0
oKYY0<>R^030Y[l00P37ZK/0103lbVD0bK[<0<nlb03Nal<20=6i`P0C0<F`a@3M`;`0iN3>0<Vlc@3j
[f<0j_[40<>Z703lfYh0hn1`0?CYS038jhX0hOGI0000DP3jdih0l>f?06hIC01/CYd0:@1C0:UJK`02
0;1PL0060?^dDP2BKJD0Vi7807e`^@2NR;`0TDii0P2?BgP00`2eI700Xd9>0;UfQ`020;UfQ`030000
5`2NLZ40Lc]m00805P1Y00T0/6=e0000@P1H00P0X7NT06<[M@1F2Dd0ZFnA08aHS`2Z=2H00P000000
2@3oool0HbI]08Y9NP3a[h<0K=cY07LdKP1M86T0BbR50=Z]Z@020?2GEP0;0000A03oool0oooo000B
XP0[O^L0PhWA0?VgO02c:@00K]Cj07JHiP27/O400P11]_<03@2Cl>/0ak[=09=UV@1<TNh0W<aO0<Z<
TP0J=K00J`0;0?c3Q@3CVYP0000009mm[P2fIW<00P37V:H0303cZgH0gO7M0?RWCP3ha9<0jkRO0=RW
Y@3I[J/0e:2P0>^cUP3^]980mkZ70?B_N`<0oooo00`0=PIV04dhV01f<FX0Y8fm09f>``2IR<00UWV`
0<>bb@3?Xj/0aInb0<JR/`2DPkd20<F`a@0?0;;;k02`cNl0R:CV05^1gP2[Ul40bLgM0>7ff03I`L<0
i^3>0<[6eP3:]LH0_LcV0;7Gl`2dcN`0Y<;_0080Wj[N00P0T/Wj04>Om@1WK/H0TVVP0=gDc`2<[N`0
<hc^0?c8R`80IgWA00/000000;>QaP2IYMh0VJGN0:BZf`2M/>D0[<3X08fNg`1bT>40M9g[08V/k002
08CHo`80RY7D00L0XkKV04<0002FXmh0k?FS0=;CfP3;d=h0Z?SN04L0oooo00<000000?ooo`3oool0
3P3oool000l0oooo00<000000?ooo`3oool0:@3oool05`1:Q^P0THo>096?cP1eU><0N8_I08fKg02J
d_/0T>Wg052HlP1lQ=00?8W/04aC^@14LMT0QicP07FMj`0hO>@0:5_?06j8g022T]X0AgcQ04R1i00k
Im<0O9WT0080KJkh00H0Lkgm0875o@00K<L0Q0P:09_5m@1GD:h2063Bl@0301j9jP3/SR<0mNjh0080
MT:300T0LLgn0:>Zg02WhXL0[XFY05c>l`3Ol]/0000009c=n@2EJId00P3FNEd20=3Xi`0307]8R02H
HHl0gme[0080087I00L0EaQS06LcO@1TE:/0TgB]0618WP1DA:40c/C@0080b=KT0P3Hc/l0301U0000
To7K0>BDM01`FJP0000H07lmM03A/k/0^TXd0?[DW`3g_4`0oKYY0<FdbP80YI[;00@0aZZn0<Rea`39
cMd0bLgM0P3J_[d03@3;/l80imW70>OIa`3Uh<h0jm[10=c=bP3JlI@0n>:_0?cJWP3Sh700m>V<0>Wh
ZP33[/D00P34[/D01`3Pl940<BRF0;31@P12K]P06aR?09R3^`34`Sl00P2BKJD0101K6F00T82n07=<
U02ALJ/20;F7Y@0<07hO@`2IHHh0eX9^07iOY@0b9I408cJ^07PhL`000000d:6V07EGX@0e00008000
0P2;;4X01@25?g40Qd5a0<^[^@23Q</0:P00008003Bi00`09[3D0?ooo`3oool0oooo0;nU_P1a00@0
8@0E0?Z^F`3E`lL0k^O50?W;H021c?l30?ooo`05076<gP0[04P0>;SX03Rhj00FU>H00P1leoh07@0a
0000<01N08YHT03a[7d0QEND05TbQ`1>0000@3>K05TOK@0/78X0_ijh0=^TW024SM@0Wgf^0:nQb@2b
gOD0dLkF0?>[MP3elK40k[jP0?S4T`3]Z840gjbP0=2FV03IXid0kJ^70>VhX@3NWi00[6b80080oooo
00T0:@1M06m<U`0O2W/0]GfG09aTS`2LGXH0L@0A0;NSa@32Z<000P1ldOl207gAo`060?6ULP1EdMT0
];?H0>?he00008T0WMOl0P2Yb_40:`3Me]00fL730>o0X@3?a]80g>cM0=;lg`3Cg^40_/CO0;Bdf02B
Xn00Xj?F0:6`h`29YNL0Y;WX05J=j@2Qc?H0WleO0:Rgh`3Nd/`0gMG?05]jf0000000VJSQ0:JnjP2D
/n`0WkGW0:>gi`2CYn<0UJcV08Vfm01m]_P0LZog06VBiP2H_o80`l?J0:6Lc`2EUM40WZ;G09j^hP2]
a^`0d]?J0<flb`2Fl]d0A`3oool00`000000oooo0?ooo`0>0?ooo`003P3oool00`000000oooo0?oo
o`0[0?ooo`0604^1i01YO=<0PhcC06n4f02=Vm`00I3?0P1@N=X01@2HU<l0IH?L03YTd@1mR]D0Y9_=
0080JIW/00H0M93P05fan`1>WO@0AgcQ04akg`1ZUnT200F<f`0309Fbj`25d?l0QM3o0080P:ga00P0
/KgS06eX_00YI]P013bm04Eoh`008Zh0YfR807I2P`80K9SZ00<0LLgn07T0000]QN/00P0/0000300;
=;@0Qci^0000000102T0Kl_n0=3Xi`1Tf>X0000005b?j@3OgF/0c_JU0<Woc080X;OY0`1]fo002038
Q@00NDN90000003:g^L0___20000002hV;L0dIZM0P2ICG002`1^gm/0TffS0=6c^`3fl;00n]BO0<aN
>@0005T0L`000<K0e03H][P0b;G70080f=;C00l0bLgM0;^heP3HaLL0bkc=0=[Lf03bcjd0jm[10>KK
b@3LcLX0f_6D0>WSbP3Gm9`0_L4n0005U`3ClYL00P33[/D01@2md5T0j]]Y09][V@0005P0XeUf0080
`XB@00T0[KcU0<kGg`1V8V@0;P000<;nd`1T1cT0N`000000000i00000P2/Y]400`3FPVh09@A^02D4
KP0207`>9@80U4IY0P1o<V80402OIXl0XfV?0:=YS`2JKj00nkUe03X0001a9f00NbmR07T[G@2^Rk40
dl;90>K:CP3kb900oooo0<V=U032LgH203^Wm@030>kWa@3kcY@0nljD0080nlF<0P3oool01`0<HMP0
L9OW0;Jff@3?WjD0?TJb0?oCO03O]jl00P0006h03`2hSZT0djJZ09=8K`3[YH40JdJD0000B@2CWM/0
;1b:0;nN^033Y[`0V5Em07J:fP2U=S<0?8;W0<g2d0020<mP=P0D0>jnX03fbil0iZjH0==lJ03?VYl0
f:RV0>JfY03Y^:40^]IT0?3FI@3oool0EPU=06DfP`1_C9L0SlCi0;J7Y0000000ObaH07m8Q02gXlD2
0?3W``80djR/01P0al_M0;^nf`2^W/L0N^CZ0<R^_`2TU<@0QeB>03<aW`2XcO<0d>GV0<S?g`3[fL40
l<6P0>?Jc03Od<P0]Z_>0<:fcP2^Zm@0UIcH0:>SeP2a^=h0VKc`0;;7jP2B`OL20<6oe`050;_0g@2G
fOh0S0000<^[^P0000000P2O^N/03`2P^N/0YKSW0:Fhi`2O]NP0V;W_08BZkP1`X>h0UZKP04U?]P2;
RL`0Yj;A0;R[c02FaoP0T;Oa09fnk`020:k;k`030;W`m03oool0oooo04L0oooo00<000000?ooo`3o
ool03@3oool000h0oooo00<000000?ooo`3oool0:`3oool00`1YV>/0FHST08><d`0208BTj@0A07^J
i@1dRm/0FX;O052Ck`1hZ?408gOT021^gP2K/NL0R:_/06VIk000BLT0MJ3/02m/f`0eE<D0Ef_<03mh
h01BTnh00P2;[^d03@1DZOT0:GCQ07R6e@1lW>H003Zn0010``17P^D004_:07BRkP1:^_L0YfR802/0
?`0i00000P2SFGH00`3^ml00e__O000KZ0020?C<Y@0I046:k00003H0P@D90<8m002;fOl0XA@00=KT
h@1`AY0000100:_YU@2GUM00V<Gf09bJd@2BH9@0jN;:02RKk`0aVo40m>6h0<CNj`000000C@0j02P0
<@1m0000c7EY02/0000206PSHP060;YgQ`30AAT0]Z;40?[DW`1L0000001I0P3GYjL0103H][P0A8W[
0>F`W03U/9`20;^heP80d=[P0P3Tf/`04`3VflT0`ORb0?;a_`3blKl0fo_J0<OgZP3fi[D0foNS0=?b
U`33/<L0e=OJ0;g@F@2QV<`0kL6V0000702NM:<000000?OQO`0>Im/00P3KXiX05@32Ge<0^hFJ0=JD
S02idU`0c8R90:ZF`P2kWkd0]ZkA06R2f@0U16h0i??E07US[P0_03L0PBmL07hN@P000000SSUL0;5Z
O`1n;el0D@QA04l000030:<k@P0807iBT`2OOk00YNSk08nAd@3VbTh0nlR@0?70W@39SI@207Ulb@06
00h0@@1C:7h0o/1Y0?oESP3k_Wh0JJoi0`3oool02000?;`0XJGI0>o]a@0FWMl0/Fj50=ng[`16R^/0
/]U]0P38WZd20;iB?`0608ACS`0004T0]^Z@0<S5e`1DF;T0/XJV0P19]?P201RW_P0M0<g2d03LalD0
001f0?gGV@3Y]il0iZjH0=baZ`3<SY40nlF<0>S3/@3Y^:40llBN0?3FI@0R04P0B@5<06h^KP1_C9L0
[W>A07m?S@1@;hT0S62I0:jC^P3Qj]P0d<C>0>FgY`2mYL80i/6`0000003XZhl00P3?/;/0102[X/d0
cZ^f07V7e@1iQmD204ISc080dZ6U00@0l<6P0=o@b039Z[X0`Zo70P3>`Lh04`2WY]D0V9kH0;ZgeP2c
Z/l0bL7B0=:[/@2WX]00`;OA0;jke`2f`N80TL[k08UFSP000000Y[KT09>ak02>YN@0WjGJ0:^_f`2X
[]`00P2D`OH205N?j`0605nDk02;RL`0_<;N0;c2gP3Ii]l0TkO_0P2Jb?L00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo02`0oooo0240OicU03YP
cP23W^@0Q:CY07FOk02F_O80AgcQ03A`g@20ZNl0KhkQ07jUk01LYoP0Q;[h05I_d01dS=`0HWC?07b?
f`0jHm00Ef_<07:2e025W^<0VJKO06jUlP1hZ_80JHoT041XdP1lSm/0G7CB04Ifg01JWO80002307:S
l01LLm400P1H2dd03P38//D0n>R>0=Kkg`33L000UGR`07i:R00007@0Y4MG0;^9002TAeL0eInN06hi
OP000000/OGa0P2o[<H207Q>TP040000000N0000A1mn0<n^^@80i>oF00H0KP000000000000000000
04h0<P237CT207//G@0609<oH@1k?GP0Nceh0;YgQ`35I5L0]Z;40P2TFWH208h000060>>l[`3H][P0
nN:^06^SlP3A`/`0l[fF0P3=c=T20<nja@0>0=o_f`30nkl0in?>0>gg``3`mk80fo_J0=KXO`3fi[D0
00000>SGa03c`IT0h_Za0=34@@0A06H20:4U5@03092;bP2fXL<0HCjA0080WWna01H0<01F07I7S02@
40P0R`000?Ja@@0f0000i[^Z09eOQ`2PLYh0J8;I09j>`P2@GiD0A@0U02l0=`21;e`0QEFA04/FJ`36
TIh0WE^108i3K@1;1e@0J1980P2oL7D0201O5eX0JbIU0;5[P@2aJh40VH:h0:8`;03kb900I`0E0P2n
cNH01@1iO<T008^n05<XOP1[doT0omF>00H0oooo00<0:5350<N?V@3nc8D00P0k0000103CNV@0:000
0:;fe02<Bg/209<^@@0:07;Co@2WAU40]4<c0<S5e`2k^MP000000;fR_P30Yl40B/3c0<bBV080o/j7
00d0001f0?gGV@3P]jd0iZjH0=baZ`33QY80dH9g0?[[XP3c_I@0n/RC0>kKK@1<2eT0RUnJ0080SdE_
00@0>`1=07]=SP2MIi<0]Hf/0P36[<406@3R[Yh0iKNW0<>N/`33W[<0kOS00=KGf026V=h0ZXZc0;NG
]P2hOI<0S:3R09mUS@2Pg?`000240;Zkf`3>cMP0l<6P0=6[/P3S_;00c;O60;JP`P3Bb=40Q8kE0:N]
f`2hZld00P2TU/H02`0007/0000006^]n01@TNd0SI3B01Mii02P_Nd0000007RDhP2FVmL0TYgK00<0
[/;Y00P0_mo_05Jjn`1F^_/067GS04j/n@2Z^><0am3P0:^liP80X>giC@3oool00`000000oooo0?oo
o`0=0?ooo`003P3oool00`000000oooo0?ooo`0]0?ooo`0:09jJd023W^@014g;08N/kP1iYo00L9OW
04fAkP1ZTND0CH7S07jUk080IY3V00T0X;3S07>RkP0QL^408G;Q07ZQj`0<H]P0Wi_@052gnP0jU?40
0P1KQ>006`25Z^d0BX7T06^Ok`1LM=8001f[05ZMlP19QnP0KI_/05j_nP2HhOd00015066Ql`00<;P0
n>R>08ACT03HemL09eS=03T]V02jM8<0000B08V2a@2/<1T0J`040<4m0020CH/0eOFO07Z8e@0308`>
2`050<caV02keNd0`>Sa0<3Xl@3Wd/400P000000100_78P0YH^i0000PP23@gX209Q>LP0;09MAN031
RIT0e:NY0=BWZ@3NZZ00glS1001]]02WDFD0ki580>f@9@21Q<d00P3SS`l0103id9d0iM310>G@`@3I
a<D30=2X/@040>OHaP31fVT0io^f0=cYg@80hnWF00<0e^Qo0?KV]@21eol00P3c`IT00`2hceP02BVZ
0821bP020>cQa`030:`P002GHY40=D>c0080WWna00X0NT^=07I7S03QZY`0cKG309GKoP0?0000i[^Z
05[9m`2GJI/0N4R;0P2@GiD0401U=H80NE>I09UXV01k?g/0Vg6Q0:AOP02hZ//08CF]0000?038PH@0
eM5F02L0D01H7FX0Y7jZ07LbK02NE7H206K1oP090<a>1P2_HG<0UE9l09EBO000?JH0oLV90?ooo`3V
U1H0dVe;00L0oooo00L0ahnI04l]Q`1?;HL0]Fal0>6;J02hP9P0L3Ym0080O4=o00<0WG>S0:N7/`2W
AU400`1H0000103Zlld0NiOR0:TS003SPTl20:Ohi@0/0?oAO`0003H0j/jh0>6ST@3CWIh0`hJB0<N6
S03W`k80n<FB0>ncT03f/7P0JaE906lYI@2VRKD03PN103/0C@27DHT0/Y>g0:R;]P2cU[T0ajRk0>G6
^03I`l@0aZFh0<>S^@3E_lD0kOS00=Weh@2BdW<0[GVI0;=mV@3>XJT0^YVe07id_P27Nkl0QURD0;[5
h`3Mi]/0cMCO0<flbP38_M00al3C0;JP`P3IZjL20:nOa`80Z9k<00d0Y9K6000^]`2b_n@0Ql?k06b[
mP2Jc?T0[M3b0:4`00000000HkOl09;7n@1?]?X0EkSl0080]]gd00P0d=_P0?ooo`3oool0oooo04I/
e01_Vn/0Z=Gg0=[lfDl0oooo00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool0
;@3oool01@1TN]@0Ki3S0:F/g@1iV^H0MKCi0080Ji3T01L0NKOi03=_g@1MTn`0PJK/06RAiP17P^D0
SZCS06ZBiP1HOmd0LZ7^051de`280000YM3f000i_@1FR>H0=7SR06ZKk@1SSND0KZ3_00YNeP1>Jll0
:gKS07NSkP0204alg`0508>Qi`1kT=d0U=Cm001nf@38g>P00`1jiM`01@2NiO`0000000004P3[^C/0
j_BO0080[6n<00D0nJaK0<Feb`00000000000:nE^`0208?9oP0:0;GLm037ki<0H0Lm0000000R01<0
000002lLR02XRKD0ODj=09aTS`80X6bF00l0]H6L0<NGYP3FZ:T0eZRY0=o8`@3cc:P0jK8b0>Il9@3L
hmX0dK@[000@VP3`Wb`0nJi=0;C8C03^b:d00P3Ia<D01@3@Z;40001Z0000JP3bk<40`MYY0080g^?H
0P3RimH00`3IkH/02@0Z0<:cb`020>geX`040?6GBP3FI2/0F;ok05Ron`80[20000<0m]2V01lRV@2X
Qk800`2_c_001`2WFG40G19E0=9gH@28S]80i[^Z0000O@2CMJh00P1hB8/208mk^@0=04I7[P1iCi<0
McA^09]aX@2TGh00Zf9j0000?023Kk@0TXS60=GAEP22=VD0WFnM07LbK0020:iHI`040?SEYP3JRW@0
^VUb09Ui[@80Yc@]00@0Z2`F089;Q@0c[Nl0001G203oool0300b=:@0LGG7075ea`0001h0]S0008MF
T@21IJT0O4=o08n8b02?O;X0YHNe0:V=^080]7R@00h0bi6G0:;Cn@2RdoT0ZB<00;C?kP2N_^l0KHGJ
0?oAO`33nnT0hWPh0=bCO`3b]Xd0_YN_0>Bk[080n<FB00<0m[j@0?o9MP1o?G@00P3eaY`00`1S?8d0
UfNH09=m]`020:F1[@80`ZNn00T0iLJh0=nm]P36YKP0eKo50=;>eP3/f;h0Q5FB0:J9]P2dT;400`3;
]lL01@2<TM<0QURD08IKV00306l0^ifj0080blCC00P0_Z_60:^Ob`2jWkd0ZIG20?2C;`2bXLH0/YVm
0<6fc`80`LCM00<0dm_N0:WOnP1_aol00P00B[h02@00Dll0000006>`nP00F=40/koS09Vjk`2W`N`0
Un;m0=Kl]0040?ooo`0308S2nP2BknT0oooo04l0oooo00<000000?ooo`3oool03@3oool000h0oooo
00<000000?ooo`3oool0;P3oool00`0>E<l0YJSI08ZIg0020563h`0F06nAh`1GLM40A5S207ZFh@21
Y^`0JgoE08>>e@2>Y><0JY;V074mP@2Q[=h0J46?07V/l`1fZ_<0SISJ05J8iP1_V>P0N:C^02a_gP1L
S^P0UIcH05O:Y080K:_f00D0Mk7g02AXfP1ARnT0H9G/01>1iP0208K8o@030:K2kP2OlO<0m^bh0080
Qn?j0P2PdOT03P000000bIj[0:V=^03i[5/0aKG;06g0oP2Ne?/0//OZ08P91@36[l<0LTB:0;CVm`0g
00001@050P38XK00102>N[P0000708lX?02LI8l20;:E^@0A0;fP_038V:D0eZRY0=JXZ@3I[:T0m;60
0?N]K`3VO2D0iH990680000049X002F`0?V^C@2X^^H0k/R]0?GAZ02N^N/00P0006X0203^be<0g_KK
0?KLL`3[ckT0aoFT0;Y`0000Km`0c[2l0P31Z/<03@000200Z=1P04^0h`1DOml0126T059N`@2NS/<0
m]2V0<6ke017B:l0eZ6N0000003Um=@00`1R00001P3Ed=@0=T:a0=E_C0000800CP0003X0@080ZYo<
00H0Sg^i06=ec`0002@0U6>E089IV@2TGh020939n`0703hEM@26>fT0Q3]/09E:K`2CDG`0_Zk:05`J
HP0206`00@040:AWR`1UC:40VGV]09i5F`80WR<F00<0o;AQ0:LI000005L02@3oool02P1YT>D0TKSa
0>>4301hB8`0STI`09NFd02:SM00ShS80964`P1nG:020;>A/`070;FB/`32WkD0`XND0<:7U02Y8`00
07^k0=?1b0020022cP040=Wlf`3fc:00gGiE0>BCL@80kMJl00T0h/W00?S5TP3eYF@0o]R008A1M01m
HZP0LURV05l/N@2FKJ400P2MMZL02`2gT:h0^IJc0=^l^P3K_;X0j<Jb0>Gae03ieZ@0gMYU0=RSW`3<
//40XY320080aKS>00<0dL7;0=6`^021U=d00P2a_^@01`28VMd0fNGO07F[m02eW/40^9no0<FS]`2Z
W//00P38`mD02@2gY<H0/l3T0;?0i035cN00]jW<0<^c``3Ok=X0_=G/0=_bg`020?ooo`0400000022
_o/0B6_B05bAj`80];?G00<0bofo0?ooo`3oool0E@3oool00`000000oooo0?ooo`0=0?ooo`003P3o
ool00`000000oooo0?ooo`0W0?ooo`80:J_W0P1he?h30?ooo`80Figb01H0K:kh08BMi01APn<0O7K2
06R3fP14F<80MZ3/06ijcP1[OmD0PhkE06IidP2=TM80:87Y07:4eP0YW^l0H9kb00000014H//0WY[@
06^Jk01hY>h0MZof0P0fX_<208bDeP0>087?o`2MaO@0e]_L09g5m000OKh0/lk^05V/n@0aW?80LI_Z
0422i`0BG=@000200;VYb@3Jkhl2000000060<VNZ`2gU[H0cYJJ0<jFVP2Ci?d0]G:60P38]/P20000
000905@4A@1g;F<07@0c0<RQ/02mGUX0F1IN099WW@2MKI/0XW2I0080^XBK00<0/8jb0<RHY@3FY:<0
0P3M/JX02`3`]Y40lZem0>^6<@3UPTT0kiMJ0=jDOP0008H048CU01@j]`3Dj>@0_l7K0080Q/Gl01/0
Y]7f09S]mP00000000000;;2iP007j`0Tn>K0<j`_03</;h0^jK40?ZfMP3GeUh0c;P_04]ff`0oL]`0
<3j`00YFd@00;[@0A7oT0<6ke034BQX0eZ6N0<>fc@28T]L0SC]P0>1kB@0006400P2OT<@00`1NJ<D0
3P000;:H_@0209F7`P060;ZVa@000000Ji[[06JTm00L3H40PUVI0P35VZ/01`3FVI<0HS9o0:=RQ02S
HX@0S5F908E?R01_:VL00P3?Xj/00`1c=7<0XUal09XmD`030:=0C080]E9@0P2jBC@00`007iD0oooo
0?ooo`040?ooo`0L0:53D`000000000002];_`2?doh0JRQY08CSn@2@TM00[:3;0::Vf01^Q=P0Mh[I
08bKg@2S[=h0_jg70;f/b@3]`jT0o>JS0;bU`@2dX<<0PFbb0>k=/P3d_d/0ml9A0?K<X03hjK<0dJZb
0<BBX@80h/W00200cZ6X0>^gW@3db5H0LRUS058_R0000140U6bQ09]^WP2RLY`0WGZ/0:aoY02jSZP0
ck[50>jfUP3KZjD0kMg10?WFY03mcY00e:R/0<R]_`2jb^L0YJKF0;NP`@3>]L80dK2h0>beV026YNT0
[:WD09nWg00jGL/0a:Fj0<2^a`80/hj_00/0ZHF_0:NGa@3P^k80h;^b0<JX^`2l`Mh0/:G=0:N^g03`
mJ`0000D0=Z]Z@030?ooo`060000000YP>P0k_;60>nJH@1>aj`0Yh6[F03oool00`000000oooo0?oo
o`0=0?ooo`003P3oool00`000000oooo0?ooo`0_0?ooo`0>06^Wm00ONnH0QXcB07b>f@1lM/80MY3O
07ZIi01ZT>D0IiW/01QDc@24XNH0Qj?W08g0n00]Fld204l0;@07062NlP30Z<40AF;;0:C9l`006JH0
a:[0015^g`0208VclP80D/kO00D0:fgL05VVm`1Dcl<0000?0:nni@020:CEn@0<04bbn@00HlT0?h7V
0000002gXlD0^JW90=[_S`009jl0000002]6^P22f_h0nkal0P2bZ<h0201mAX<0OmSn02X000000000
000A05@4A@1g;F<07@0c0P25BX401@2BJZ40TFRO08iLTP2RL9T0^XBK0080_ibe0P3=ZkH20=bPU00F
0?2fT@3b[Gd0kJn=0>FWT03NN`80gZfT0<N0000L0000h99i0<G@h`3Cj^D0n>jZ0=SXh@3MjM/0ioW<
0?k>K`38_m40^]Y/000O[02hgO<0P^Cf0<b`_P80lMVh01P0emIN07fNj00mAk@0DEo20003UP0G@Kd0
01fX07Mnc@31^m@0fhei0>C5^02Dd_d0<0IZ06/HC`2TFgT0W7NX0;]4002<HY/0G3jD0:N@_P2bT[H0
500d05Q1W000:K0209J7`@040;:9ZP1h:E`0I1QE02eLc`80eYVC00d0JD2>0:9IM`32OXL0`Wj70000
002KH8X0dHAk03h0001o:E80[VMo099CP@2GD7H0TTYb0080/fb100@0PPdJ09PJ3`1]0000A`000P0W
00000`2F4`00F0000740300208PQ>@0=07d0003oool08To704Rlm02^SK@007?M092Ad02/X</0YLC_
02mTe@1lZO00S9_M0:f_fP020:c6k@0R0;_Dk000?Jh0_:G108=FU020E9@0iOWA0?BoB`3kd6/0mJig
0=^XX@3AZ[80aZVl0=BTYP3/^9/0kJR20>NdW`3db5H05P0Y0>K@E`2?J:40W7JW09UQSP2RP[40ZH>[
0;VH]P3C^l<0ck[50>72^03KZjD0Q5>@0?WHY`3U]Z@0e:R/0;VN_080`Z2f00D0/8fb0=Z^[03J[Z`0
WS]9076AhP020<:meP0?0:6Ld035[/<0XIc@0;VTa031]Lh0_[oK0;Jkg@3Gfm/0k<Zb0<JX^`3Oal40
dmGJ0<??i03ngYD0nmNP00@0oooo00<000000?ooo`00H=D00P21c?mI0?ooo`030000003oool0oooo
00d0oooo000=0?ooo`030000003oool0oooo0340oooo00D0JH7G08^Si01YP]P095K<07f@f`020000
0004071CX02_XLT0OI_U05R1g`80/Z_A00@0;E_=0:F?_P1:M=T0E7[K0P2;/Nl00`14G/L0SZOV08jW
iP0208Vbl@0@07JTk`12QnX0Dikd07non`2>_oL0Nlgo07>Mj`0o/_@01iCC002;c@1JaoT0H;Sl04>n
k@0f^N<0<jWa073;o`80KLom00D0;jkZ09I]X@1;]oP0FmCA0:fhh@040000000:04X0B01W:Fd0IbU]
0:A3D01iGZL0NEjX0:6Ca@20JK00VGZ`0:ZA_@80aZFh0P2mX;`0203>Yk80cjVc0<bX]@3`]Y40giR2
0>RAHP3UYi00S`X00`2700003@3k`840<kKT0=_Ug03hkZX0a>__05_Ca@2`lo@0ioW<0=gZg02jfV`0
6:K;0=[4a03I`/@00`38gnT208N<d@070000K@1GA:0031jM04iB]P00=;T0C32?034fYP020>jVN`0<
085BT@22JZl0M/co01FAiP37SiT0OUJH08aQV`1h?gd0[XJZ09Z4^`0D03@0G3V>0P2?Hi/01`0001d0
nkmG08MBR`2hVKP0/UIL08Q9O02C;Cl00P2ZB4l200000080Vf2:00L0?B6603TdW`2EBFd0X6J>09UQ
S@2DG8`0UY7<0080Y49=00@0WSe=08PL<02LDG80W55b0P2YEVT00`2Y7P00TB@a05L0000205L00007
09PU:01H00T0H`0008:Dg02AKJD0YjSG000^[`020:JTe00808eSW023U]d0PiKM04UF_@2/a^d0b9>M
09a^W@2man820;O0h@80iOWA00`0hN_H0?_@J`3VWWl0j[6E0>FLO@3;SiD0k[:@0<b4P`3]^id0mk1e
0?C8EP25c_l209YDNP0>0:AYS@2WP:X0Zfn>0;^;X`2jTJd0ej>P0=bXW`3]b:l0cjfg08ACT03XaK40
d;2j0=BX[03EU8h20:jOb080]Zg@00<0aYf^0;RG]P3kf7H00P2SaO401P1iQ=<0TIgL0;Zhe`2j/=00
[Z[D0<Feb`80`M3V00L0[kSP0;;Jm02kYL<0o]ZF011Le@3:in/0nmNP00@0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0=0?ooo`003@3oool00`000000oooo0?ooo`0a0?ooo`80OhcG
00P0M8gM02AFc01_Om80Oi3J056jnP0:Nn80V/_i06bUl`80NJ_c00<0YlC^08_>oP1CVo800P1CVo82
03b]m00909Vhk@23/?80Ok7d09Fml`1be?`0CXk/08^gm02knnL0GKWl0080NMkh01L08JOQ03NZl`0L
WNH079gV05g8nP0UO^L0I;Kl07;<o`0FP>H0JlKn06O3oP1H^o`006?G0000G03j[UH0Ef[;0000003_
Y2d0;`1I04hTO@0002P0@`II08MBR`020:A3D00802I>a02NU<T0XI?5081Y/02>GiH0XW2J0<2K/@37
WJh20<Z``080cjVc00<0gkfe0=bi]P3O_kT00P3O_kT0103e_8l0llBM0=?m^@1B000204;1j0050?S^
ZP33QI40kNf>0>g]SP0000000`26d?l0203Dh^40e=CH0<KOj`36gn/0c]?N0=77d@1HS>P0:CR]0P1G
O=/03P16ILh0002706UU^`00:k@0Jeb_076:g03l]fD0NDjC06F0f@2DN[<0SEB80:/T001nEYP0]8^Z
0P3@XZL01`2_NiX0DSRD0=32c@004Yl0U5n?00007@3k_eL00P2^UKd05@2hVKP0PUFC0:5fX`21>fh0
YVN80000000W03D000000;RSa00?<K00Da9N06/SH@1a5T@0Rc1@08dbD@20=VL0RcIJ09m8G`2@>ET0
Te9n08e<N`020=J[[@03014040160000AP000080N2YN0P2U9a400`00F;d0TP800:a2?`0200nLd`09
07R6e@1XU>T01SRi08BJh@29V=/0PiKM04UF_@2/a^d0L@000080]nGe00/0TN7m00`0003Ha/P0mk=k
0>7[f03V_J`0iYio0>VVQP3QWh`0b8N>0>fQMP020=2>S@090>NPPP0l02@0XFN>089>RP2WLYH0YWVQ
0:N0ZP2kUK00^I6]0080aYb^01@0fK6`0<^kb`3`gkh0l>g30>ZfW03GY:80`iV]0<n/]P3ofhl0LU:M
0:^9/@3<Z;D0e;c20>O:^@3kf7H000000?ooo`00=Jh0V:gU0:neg@80`/cR00T0[Z[D0<;1f@39]lP0
b[O709Zgk02df_<0o]ZF000CV00d^kl01@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo02X0oooo00<0?L7B0>Ok`P0m`M801@3oool02@24
ZNd0LX;D07Z6e01GGKd0Ul7d08?7o@1dVnT0>7KQ0;:Ub`0209c0lP090425j@29Z^/0ZK;O0:Vbg`1N
]O`0Q]km04BOm@0RKMd0^9o00080OlSn00@0@jSg08BgmP2=coh0VmGl0P25dOl0201YaOh0Ej_i0;C8
j@2db>T0H/Sl046el`1RcOX007;=0P29a_`01018SNd0HJOg08XiHP2:>F820?Z^EP0;091@O`2GW=H0
000401h0500i0540000004@2DP1m=6L0NBYM05T0202JJi/00P2DHiD01@1hCY80SUnF0<2K/@30Vk40
a9V/0080b[3001L0_JK20>?2]P3G[Jd0ejf]0>2g[@3O]Zl0kLN]0=6UZ`3`ekP0h:RI0>6i[P3^cK40
jKFM0<:Q4@3Jo/40g=cF0=KAE@3^mJD000000>3Qe@3dd:/0l?C10<gmh0020;Zng@0706m;UP0:G]H0
G9kc04=lhP0QClL0OlGn049Ma`0202mPdP0902L`Y@1DDK40GUjj0:ND`P0003h0000l07MLYP27IjL0
PdZ30080]8^Z0P1Fc^`209^Gc`0;053=a`2=HY/0IPm500007@2SO:P0SF6J00000029Kjl0PC]^07e=
S@3OYIL00P3CPP003@1G>i@0B`MD06H0002HEh40Re^C08Y=P02JJi/0QTn70;1oW`2_RZh0UGJ]02LL
SP1H02<00P39d^001`25ZNd0a7f40:5iY`2@HIH0mkN00?>VK@0DPnH00P2kET`02`00AK@0fVX009_R
o@2U>S/0jmi`09WIo@1/ML/0O9CO0:LH001WU^X0Tl_k0080T/;g00@0d/WB0::Xf`1V]?/0CY[c0P2H
/^T03@2R[Ml0ikf/0>Jm[03SX8T0jJJ60<R>U`3AP780kim^0=nCNP3LZ9l0l;jL0?o7K`2NKY/00P2Z
QJd02`2^Q:L0YX^h0;6<[`2hU[@0a:Bi0>?6^`3Ma/80jlZc0?3O_P3hkJ`0ikf[0080cYfS00P0cjbf
0?oKS`27JZ/0YJgM0:jgh03?bM@0bJfn0?BoU0<0oooo00<04XSV07C5o`2U`>d00P2D[nT01@2@^_<0
]mWa0<cAg@3<dMd0b__V00P0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`0b0?ooo`07051Yc@1WM/h0P[Sg06N1f028RLd0MWk>092=c@02
02YkiP030000LP2;TM@0J7_C0080HL?m00L0RmSo07RVl01hY_00ChKV000X/02eo=d0LL_o0080@Zgg
0100@:gf05jJl01L`o/0OM?o02F/g`0b[Nh0PmOo000Y/`19W?@0L]jo04>]m`1J`O/0Bkke02NOk@12
Z?L0063F0P1Zc_`209hC000?02L0?`0005P0UicF0<72fP000340000004@2DP0M03<0EP0B06<06P0c
02@0V6BC08]TW`1kAhH0W76P0080^J7100@0_J6l0;bI/`2lVK<0c::^0P3DWYd20=NWYP040>2g[@3]
ajd0kLN]0?3G^080h:RI00/0hjnN0??7X@3Y]Id0`Z4A0000=`000000h>R10000002c_n80gMgF0>?d
eP020>Wja0030<^]_02GJIX0^KPa0080:`000P0>00007P2[7P00KGkB06endP0bHM406RfX0000001?
=Y<0Xg>M0000?P2dIW@0PE:A05`ZNP1]<WD0/WJ?07HfL@1<W_D0b8bD09U3G`2o^300TfBH0?_TY@2F
M:/0M5fZ08I9OP2lMX<0o;M^04P5D`040000_ijg09i[U`80ZOWJ00/0>aMi04TTP00a03d0LDVC075:
T`29FY<0Xg:K0:5lZP2^PJ@0Z7VO09miZ@02099e[`0306Idc@2US[d0YHjm0080KdjJ00/0000j08;K
oP22foh0002C0?>eR000AK@0cX^:0<UH<@39C000hX=F09L800030:gGmP0M01U;a@0000X0aWan09;2
m`3AG@00e/oC0<:T^`28TMH0@00006jRl02R/N<0lM^j0>:]WP3V_J`0cJB^0>VVQP38SYL0_X^O0=Ig
F@3KNE80jjAn0=M[>@3oafl0LAY:09Ef[@2_MiD0^8VT0;Z?ZP2lXK`00P3:/;l0103BYJX0jlZc0>_:
/`3`_9T20>NmZ`050=G4bP3H^KX0lMZh0?oKS`2>X^800P2=e?l00`2^]n00O9oY0?ooo`040?ooo`08
06R>i02?ioT0_?K`09oHo02;`oX06Y7Y02RVjP29j_090?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0<`3oool01@1/Om@0UjSR09jPeP28
RLd0800000<0Pm7o00T0S;Gb04n8j02:YnP0Ulcj06F_n@29aO/0T/Sj04bVn00PI]X00P2baNP01@2_
hOP0BJCg08g8o02Ceoh0Fm7]008068OX00`0A;Oe03bn]P1e`oh000000000MP2YZ=H0ZeU/09T7001k
M<00`H2;0<_]k01MIL820<g<f@0;06iCXP0P03/0J@0009:dkP1Y0000`L;J0000001`;fh0D1AT06`X
J024=V<00P1nChh00`0oA:l0LdjG0:=nZP020;jX`P0>0:J9]`2mWkX0_Inj0;^N^`37]l/0^j?10=BL
VP3GYjH0i/Nh0=Nf^03Y^jD0hJJG0>S^d03RdLL20=Zo_P090>OHaP3VjH<0`Z4A0000=`2IlmX0@P00
0000002jW;X0cooF0080bl;B00@0amoZ0<STk03SfF@0n;5a0`1V00006P1?0000d5@000^Ag@1]O]80
02:]024h/00V>k80026V0:bF_`0003h0;RFD0=^QUP1Ib_D0KC9e0;9fS`0807<0NT5n09XM000g01`0
C`000<>6T`2R8@X0Pc]]07@^J026CXL0^7:20P181E<03`2LW=8070000:j@]`1103`0GRA_03/GN@19
9800100W08aJT@1cAXd0RE^D09]TT02OIi40V5V30:idT@020;AiTP0:01T0001[64l0M@TV02J]h02N
l^l0VeZ20000>P0NE<`0G@0008A@R`80R5J?00P0M`000<Zda025EI40k>o:03nkk@3[UVD0Nj;[07O1
oP80SMkn00<0BHCV0=cCc`3AG@000P32Y;/0203aaJ80`gb404D0700IC<H0Xk?T0>:]WP3DXJ80gKF_
0P3I^;P01`3BUiL0ej>Q0=NSX@3[Y7h0nKMk0?V_B`2<B7L00P2fNi<01`2iPIL0_h^N0;n;WP36UjD0
cYZQ0=Za[P3Wb;P00P3`_9T00`3H[:/0ilBb0>?1]0020?3;[0030=OkgP27fY40oooo00T0oooo00D0
?iOb0:7?n01dhNT0UNWi08CNo@0;0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0<`3oool02`2VY]H0VJ;K0:jVc`2^Y/l0QYcQ07S?o`1k
ho00Zn?j09;KoP2Oao@0UL;f0080Vj_R00T0_/3K0:gHmP2ad_40/M;a07nUk02TlO@0B<GX08SJo`1T
bO`00`27iOP03P2[`NT0Mkom03/06P2Acod0OX_F00007`2IK9d0bFIB03EXeP2RU<H0Ga=C01IOeP1M
IL80D/Sa0P007JP02@1V;gL0fV@909i^VP3YmZ<0S6RS00T0D00@00008@0708QNV`0209=TV@060;VE
/P2CIY/0LdjG0:fKa@2eZ</0_Jc80P2nZ/H0102_]mh0cKW70;^S`@2kXl420=CGf`090>;Aa`3<XZh0
hJJG0>6VU`3m^VD0jjf=0=VDR@3_g;d0imS60080m>Fj00/0G1]S0:IaUP2mW[T0_Iji0=kcg02`nNT0
ZkWS0<U>003Wn<h0mJad0>Gid0020:[DmP0@0<>6TP1a4Sd0kHi50=1D000m0000O`00001H[P00E]00
7RbU0000001FDK0023>d081c^`3KXIH0FL[e04c1l`80ai:M00<0NT5n07R^m03C`/X00P1GJLX01`2B
:ch0J56T07@;:`2gBCX0`I2R02T0G@1a54400P2S@Dd03@1g;VH0;01302D04P0n01T0?P0l05P6AP1b
7Tl0M5>N074OE02dKGl0Qci/07TUE02YE6L00P2@9SH01@1F03T0B`0f03H0>`1615@0ai:O0080VeZ2
00H000000819Q024D8/0R5J?0=:OXP3;EbT20:8E000A09FTg`1H00L0dVd00?ooo`00<KH0EFG705]n
g01fV>H003:i0=_PK`2do=d0kL6V06dnQ`1[:fd0KRe]05AN`02RYmX00P36Vj`02P3I[jd0cj:Y0=^V
WP3BUiL0gjbP0?7@/03Wa;80nKMk0?V_B`2hNi420;f8W@040;R3W039X:h0c:jl0<b^_080f[6^00L0
lMfk0?GL/`3PdLP0hJNG0>KB`P3S`K@0cm?M0080f?GR6`3oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02L0oooo00<0/k;G0?ooo`3oool0
2@3oool02023J:`0^Z[:0;ZZbP2fn>h0QYcQ05NTm`2Mj?/0SikN0P2HX]`03`2LU</0K97T09^[hP2n
`=/0T_3T05;8l@1Wc?`029W804NnlP0h_MD0Ll_o0>Gae02NWm@0]/7S0:_YUP050?ooo`0<0<_ij02I
K9d0[;gV0:bmiP1o]_L00`0008Ema02T_N`0QMCo0;khkP3Jl^406@000P1G^o/202L000090000P01F
<XT0Zic70:VHa@1OK/X0FUVg09=VV`18=IP0]:750080]JS;0P2lZ/L0103;`]80Zk7M0;ZWaP2jYlH2
0=WIf0040=CGf`3FdmD0c::^0>o=/080nLfK00L0jjf=0=VDR@3i^h@0c9@40?OR/@3An[00aJBh0080
]Z3300T0000c0026f02@PL00WXVm09_Do0000000/o_S09kBJ@37D2000P3]lLP0203^aZ/0]HRV0?JP
A03ccU/0QA0K05h04`1D0000001d0P0cBK/01@36_CL0P7>k0<Ngb`37]l/0YIG50080@[7f00<0SiWI
08^Hf`24dOl00P24dOl01@1n@gh0W4e/0<5lQP31O8H0i:270080/8V]0140[hV]08UES@1g;VH0@P0j
04H0BP2>CWh0GR=]0:1DL`23GYl0_X2@08]HT00A03h0Udaa09ELRP2=EHT0QbiA0000=P020:MiX004
0:AgX@2enm00_Fie0932n0<0[;oW0100J`0>0:UnY@2YOZD000000;eDA@2f<P00ffPG0;Hb0034J@00
Z1l00?ooo`0039P0J7cD0006RP0T<ZP07Sjh0P2^WlL01`3Cb]00RWZk09:0_012E/40DEo309f>a03A
]Kh00P3Hd=420=:GU`050=^a[@3MbL@0l;290?2`R@3i[d/00P2fRjP00`2aOI`0^HZT0<bNZ0020<VL
Z0090=6JV`3J/Jh0lMfk0?CD[P3PdLP0dLK@0>KB`P3gY4l0V=;l01d0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0W0?ooo`030;>be`3o
ool0oooo00`0oooo01@0Bl_D06;2o@1f[?@0BZ_h06>an`0mTO00V:;L04Jll`1]__h0000008CMo@2Y
mO00`^S`042am@3_`:00ZmWh09C6n02>T]80/:G=0??2V`L0oooo01/0_YN_0<R[_038Zk`0UicG0?Zj
NP000000001c0<^a`@2=Kj`0FL^T0?^jM`0/03/0R1X/0;:>/00002P0RHg@09;GoP002i`0XUj00:VH
a@1OK/X0FUVg04@0002CIY/0TIGC0;j`c02a/mX00P2GUm40202ZP:H0a:Nl0<BW_02jX/00a[K:0=WI
f03FdmD0g/W50P3d_YD00`3//iH0jjf=0>^]S@020?OG[00:0<bD102fh7T0`KO@0=SMf`2Lc_T0a_?^
0000<`3E/kP0T87006HbN`80/o_S0180F[;k09_bj`34^]00K<Cn0000R02A0000iKj_0=RTX@0039T0
O@hS08XS>P1V0240JD:?04I5[02Cb_/0000L0:9cW@2?VMT30;bfe0080?Z]GP27AgX0JRea0000002]
Del0000n0852N@2IFhD20;mgP0050>O@_`1F=8d0U3aJ09@lFP3m^fH00P1=YoP0300a02<0M39]09]f
Z02XN9h0A@1>09VCc@2DLJP04@0n01l7MP2;HI`0REB;09d>00<0YgVP0140Y7NQ0;Gkd03k/5L0IJch
03jHl`2H@5X0RfFR0?FXJ`1_2S00`:Fo06W=o03f^hT0e;[10>J:FP3ZR4L0R0000?RXB@02032Dl00?
02M5^`1^M<P0Gd:G09XS000CI]/0Ndb=08IDS`33Y;T0TX2m065J]01AGl<0Wj;G0<nla`3Wa;80aZk2
0080`ijc00D0k<N_0=g9a03Rhm<0n[1U0?6C>@020;f9WP030:ikV`2oSj@0b96L00<0`hJA00H0kmjn
0;=4=P3de:h0g<o<0:OSn`36b=/O0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
303oool000`0oooo00<000000?ooo`3oool0=`3oool0102Jd_/0MZ[c0:Bnk02T_^`206jJj`080;Vg
eP1^f?L0Tn7m0:[XnP1ie?h0T]kn09_[n@17Z?P306@dP00307A=U@3oool0oooo00H0oooo00H0<73N
0;:^e02bXLL0g?fi001jf00000020=2TZP0907C?o`1:H<L0TYKE02<4L00n>jD0O5nU0=c/gP0bB;T0
RHg@0080UIGA00<0GgSD04Y]d`1;00`00P2=^_D2096Ed`050<C1e`2deo80]=Ob09NGd@2ZP:H00P34
Yk`20<JfbP80gk6X00`0dZ^a0;fZaP3K][<0h/Rn0>Bn/03`c:h0j<jl0?KaZP31T`40ele?0<c1d039
^ld2028000030<C=h@3?j^P0]/?T00<0P/;l00<0a[O;09_bj`37VJP00P0000001P2A0000iIIc0>R0
7`1Z0000?`0009IJR080ZTYB00P001bY05UC/@2XADh0ODV705`MIP000000c9VR0<RodP80R=Co00D0
nKIi0:=GL`1a<6h0Kcj6081=RP02002>c@0500jFg03Wd;l0U3aJ00002`1;04L00P1laOh03P0g0540
HReh08I;P@26Bh40mkAl0;BRaP2S_nh0MC=_0140?P21d?l0`9bd03>El@22Y^/0Gi?[0P2b[m@00`2c
n>d00YC30:Hl?P0208l000040:VHa01f`oh0mJQ[0:dh9P<0F@0000h0[Vb60>J:FP3RRVD0hihJ0?2K
H03V]S<0dJhR0008U`1>F[l0<3JW000JX0005jH0R8c@0;^WaP80WY[@00D0?Dfj09bIc`2OX]L0c[[6
0=;9d@020<6/a@050?o=P`3EemT0gLW40>[=^03]jlT00P2nPY<0302oQYL0`9>X0<N3R038VjT0dJR_
0=2SZP1E00X0kmjn0>3?a`2Jlm<0_?gO087R/200oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`0<0?ooo`00303oool00`000000oooo0?ooo`0i0?ooo`0809WHo@2Df?h0Pk[h09[Co02i
]mH0I;Gl0000002Tb_<207oFo`0709_Lo@3oool0kNC50000002AHIH0M4fE0:R4[P020;VD/P060>bL
KP3iZE00^NjI0736o`1gbOl0Hkkm0P2UZ]X01@3Zf/@0d<_E07aCUP2HRL80kK6@00@0oooo00T03Dg9
01Q@bP1dP=40K6Vn0000B01UDJH0UIGA05AYb`1FKm000P39QX/0102>Sm00KgkA0<K;gP2BS<T209me
X`030:5gY038[;d0b:bm0080]YFe00L0jkNK0=jd[03=[[/0dZ^a0;fZaP3Rb;h0gL:m0080k<Za00<0
lNo10?KaZP31T`400P1Hd>X0103Fb<`0gNCJ03B?k`1D00020;n9V`050000001VYO@0a[O;0<Jgb`1h
eod00`2EboX03P3KQFP0dUdS0>R07`3QbD/0JP0005`0001l2A`0M0<L01Td/01IDk40Pdj800/0A`1^
FJT000000P2D6aT01P3j[Eh0301:0?VfN@1E=i00LC1^08YNV080[Z[C00D0_J[606iEY02RNjP0B`17
00002`020<FO/P04054>F@1`<6l0KTfJ09AZW`80T/om00d0Hfk808HdGP1o8DH0]LSY0000B01]=GX0
KcMj07UZ]P2iTk00?SRQ07d_H01d9ed0`?:P0080SHK600P0Ti?@0000002/Rk<0[8^c0:QVQ01`>7/0
SfRQ04H00080W0l000l0o;QN0?gLPP3`Vf00i[Hc0=6^8P0P>K80Ie6U02lPS@029j/0002508R<d03M
fm@0_[SD06fen`1@DK@00P2NW]@01P2]YM00d:bd0>No[@2LVM00olf30=^g]080j/fh00X0fNSO0<N@
V`37T9/0/gB<0;eeO`2hU;<0b9ZX0=:UZP3@XjX0j9ah0P3HYJ400`2Jlm<0oooo0?ooo`0P0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool0303oool000`0oooo00<000000?ooo`3oool0
>P3oool0203;^<P0X]gl0:;Mo03J/RX0[=oi02ZNk`0001T0giTC0P3oool05@3FbLd0E`a@0::Qd`2A
HIH0M4fE09b?a@3g`900Dlc[04h1A`2Yd?@0N<_o08kPoP00;;D0Sj;Q05cDhP2gJ7<0Wah:09=<M026
e?l0V8W206<DD@030?ooo`0?0540001aE:80001R07B0d@1RFK4000R;0000SP2OQ;H07XOZ03JGlP39
QX/0W9O>071T]01_O]40`[C=0080Q8cD00<0YJ;B0;Nee`2g]ML00P2ZUL000`30[<H0e/_?0<f^^`02
0<NV^00B0=cHe03YcKT0emcK0=oDc@3akl40n>f/00004@3ei84018;N0000003IL400OKCf04aig@3d
lKH0SfNO0;ZZb@3D^l80TVjW0`2=51H06`2MS/<0K7[?0>O4/P3F^;`0i;6P0?k8Q0000240G0000;8n
;01j2R40O3U`05UC/@0008@000020=k3_P2^DEX0_I6X08]UXP2gX/<0aJVm0<N``P3i]WT0D@0Y09=Q
U00G0gL0FT>L0:Q:EP0304T00009000h_P2MTLL0WI770;fT`025Bh<0VGV^06a4S`3MjM/0TZCQ0080
^JC400@0PIcT02Zag@0Z/Md0fYbB0P1fBXl0<`1iJ[H0OE^O07mNXP0D0000000001l00017aNH0`U`0
06mld02SOj`0K@0?0000002VBUP0000>02e<`00001T0cY2B0>ZYRP2`>280nkUF0000S039BP00001Z
0?ooo`0T@KP0CT:T0000K`00;[<01TC308:BfP24L[P0K66d049<]P2__^D0Y[cY0:^miP2ZgoX0^K[J
0<G8g@3ocH<0aKG:0>C5^03hkjX0`mIP0<R:TP38RI00_92W0<NKZ`2hU;<0eIfJ0<nDUP020>WSb`03
0=RUX@3cjkd0oooo02<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0;0?ooo`00
303oool00`000000oooo0?ooo`0V0?ooo`050:jKa@3;m^/0oooo0?c>U@2J:2T04@3oool02P2Qf_`0
QMOo07bRj`2WYmH0016R0=nI4`3oool0SU:405=ng`2=PL4209:kl`070:g@lP2ilo<0aLSM05eog03o
ool0KWK:0?^iE@020?ooo`0@0000Q@0006T0]Vaj0;I/NP2Ef_h0YhRc0:UAH@1;a>l07YcX08QHTP00
0000_DT]07MgaP007j/0001J06QbbP80?FWE00@0AgCK07ib_01nL[`0S93B0P1aQ=L00`12JM<0[[[R
08V>d@0208RQi0050:Rbh02V[]d0V:GN09RUgP34fnX00P3McLT02@3A_/P0_[7=0;jac@3YcKT0gmC=
0;Na:03M_k/0n^VO000000020;W5h`0;06jio02YEf/0ZEM[05bgo026dOl0h>7E08KAo`2EVMD0IAIA
05L<D03>/Kd00P39`M<03@2`PZ80e[Rl0=Jh_03h`8d0m;B400008@2GGH/0NdB209=HQ`27LkH0ReV@
0:1MP03N`kh00P27YNP02P3d^Hd0[Vb60;NR``39[l00j_O;088<5`29AWL0J1=90;JI^@1J@i`208md
/@0C09RKe@0?>[T0`h6:000;V02QR[/0000003T0701N0000PdZ30>oaa01>02d0oK]T08CCo`2RP:h0
QJGY09?:n`1o@gd0VDQX0:Z4[00209A1HP0506i[_P280000mjUU07MMY`1eBi800P2IQ;`05@000040
001809V?b01hKk/0QU>=0>3Ec03l]F80001/0>f?C@2`>280nZmJ0?;J]`2oA@00kliH0?ooo`0XF<d0
CGSL02<LS`008JP0KFk308:BfP0209>Jf00307>BhP2lYl@0Zl_a0080Zl_a00L0Zk[U0:c5k02ei_H0
]NKf0;kVlP2lk_<0_X:B0080b8V@0P39Ti`01`3;VZ@0dj6S0=BQXP3gaiT0f[Ng0>79`@0001<0903o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000003oool0
oooo02T0oooo0P1a00080?ooo`<0VA80203oool01`2Fb?T0IXcS0000000029L0oooo07U4Q0009j`0
0P33DC40101FKm00aLSM0?ooo`27?fd208LnK@0306ifbP3k^ED000000080V>^_01h0001Y0?ooo`2V
O:H0UM[n0:N8/`2jcnX0<GOS0:RQc`28F980;P0i0<C_l01gMlH0VXW10000FP2;O[l0IgkF03IYe`00
E=00DW[L07ib_01MP]h0EGgM086JhP12JM<0Ai;`09FZi@22X>H0R:7T0;Bmh@2V[]d20:W<lP80`<3J
0P3D^l820<B=V`080>W=^@3=TID0]k4X0=jn^03jjIl0`jc20=Nm_`0002`205>on@0407T0000K<:/0
PDEm099i/`80T/7g01@0Md:308LoK`27?fl0j<Fb0;a37P2^Ni`0f:FQ0>2g[@3feZ/0i];30:gKM02D
H980TVJL0:5n[@1mBHP0TfjU0:j2YP3IW9<0Le6K0:f?]P80OMKn00L0^JK60=_gX`3Zml/0_5A8078I
A`29BG`0]YVi0080W8[000H0SgBa09RKe@2KWMD0XhJe05L0>P1102h208EIU`0707_Co`3eXU`0Nm?o
0?ZfLP3>^lP0iK^[07]AU0020;:G_00V0>gHI@14W?@0DIOa07m=RP1n21L0001W07i1N`2gM8L0>kni
08g>o@1T7f40Vg:R0:QHK@0004P0h_c>0000003m`F<0BcJF0?fjJP3XZhl0V<ok0>O<^`3m^V@0i<Fi
0?bjFP3La480oooo0013a@0`K]`0=DRh0000P000>[l0RYOJ07R8eP2CV]P0HHgV07BOk02e`>820:nk
h`80inG?00D0gM3<0<_fjP2omO00c>b:0<N2Q`020<^DW@080<ZDWP39SYL0b8^C0>2^X@3Sbkl0h;>X
0=Zg]`3>_cXU0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool02`3oool000`0oooo
00<000000?ooo`3oool0?P3oool02@2W=c<0U>;m05X0003cWE@0/Ff309mLO`3oool0BlW10>Fo?`02
02jai@030000402Hj_T0Hfk80080L^7?0180S<cm08mNU02?GY@0kk:=0?ooo`1U3T<0dI^N0:CBn02^
e?@0e/W>046@k`3oool0R5RB0>SQb`32]/l0ScYM0>_Ka01LEk<2069X``0807ed_`0VAkd0EfS909>/
i`2I/^T0EGgM086JhP1CXoL204jZn@0403f6jP2MX]P0[<;Z0:c2jP80ZlW`00D0]KkQ0;N^d02g[]00
d[S10<B=V`020;jjeP070<kng`0004l0bo:K083T^@1jgZd0NEBJ0000;0020<N_``0K0=34c`25i_@0
G1aU0:Scl`2[WLP0QUjL05X0=`1c64D0Q>7k0>S5/P3CW9`0PDZ60>b`TP3j^G`0dh=f0?KTP`28SM40
3@0R08eZY@27DXX0S6>N089DT`1;14h0Zj;>0<aaH`2]SkH0SFZU0080ZDUC00H0000009^Me@213al0
X5ao08T]CP23A7T308XXA00409AFP`0004X0XhJe069M]`80WV::00D0DcB>09UcYP3eXU`0n[Ib06/0
0002016Q`0090:5lZP0K02@06`0T0>gHI@2aQZL0Odf:07/[G01I:7P0S3eV0080/g:900D0^[4V099o
^`000000>P1=09Em]`020<ZCW00509]aX@26FYL0TUZ:0?fjJP3WVgT00P2Hco/01@3g/g/0i<Fi0?C=
F`2kO@00ij4Q0080oooo00<001NQ04mWb`1HO=`00P2:T=<03@2DVMD0Ui_E09N^i`2YdOD0U[C/0;O:
j@2F]>`0gM3<002;^P2jnnP05@000<V2P`3?Qh800P3;SiD0203;T9H0bYJN0=2OY@3QZ9P0d[[30>V[
SP3GP@00c[lj9@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00/0oooo000<0?oo
o`030000003oool0oooo03d0oooo00H0D/Cf06<OI01B>iP0ZKWU09RVg`3;SY@206G2oP030000EP2`
Y/h0/:K>0080/9o600<0:X7Y0:S0j`3oool00P3oool30;?Bl00804aUc03>YZl0cZJ_00003P000000
MDF:0<:oe`1^8eh20:YUP0030?ooo`0806H0IAUF0080RH;500H0HVS307ed_`000500EfS909>/i`2A
/nd206j/m`0606JQlP0_N^D0R:W[06nXm01]`oh0HiW^0P00000206^SlP0?09:]j02^^>00Z^ci0:[/
n@2oan00^_Cb0;k:i0000000bo:K0080002Z@dL0Q4Z20000;03Qe/`0^:S90080f]3?0P3RLb80202h
o=l0a?6K07]S[01;0040b<CF0;9>C@3SMb80PDZ60P3MUH<03P3Tk]H0m^B30:TN002nO`00QebH08E?
R01^<G80E`iC0000C@2=<Dl0ODB00000002EIiT0B00?0P1hK;T01@2NO:d0TD=X0:=VRP20BhL0SDEa
008003b_00D00P0008EAR`27DX`0Qe:<06`LD`020<1jQ@80olIb00L0RJo_0<gDg`1ZLlT0T6:I07E;
TP0106H0YF^?0080/WJ@00L0/HJW0:b3Z@2[Df<0N3E_0:f:/@3FgMd0>@AO0080ULol00<0Z<G^06H8
>02_90000P2`9P001@28@g<0QUZG0:N9]02=SLl0P5:B0080ZV1i00D0m[^:0?o7M`0001P0^gd00=UT
3@020?ooo`06000000008YD0>cZV019hh`1`__h0C[7j0P1ZWNl03@2;Zn/008K>09[6mP2?G980m;1o
093<o03[Vg40gjJH0=:SY`3@XJL0c9ZR0<VGXP3;T9H00P3@V9X0103?Y:`0d[[30>V[SP3GP@0V0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3o
ool0=03oool00`24CHH0k<R_0>c8[`060?ooo`<0JL_m0P3a]8`01P3`Ubd0oooo0?ooo`1oXn/09UO<
07jHhP80KVg00100]YFf04l00028c?h0R<cn095KS@2?g?h0ZJGC06=V`02Z`^/0fLW:00003P0g0000
PU2=07E6R`2gM8H0dY^L0P28000306K<o00A0<E40029P/D0G29]05`RK@000500LW_>0:6gj02I]^`0
UkW_082_l`1WYO@0Bi[c0=_JeP1L7FH0_Wf<04jhn@2SgO/00P2SWm402`2LWM@0TZgX08@gI@39^<T0
dl[@0>;cf03:T9P003:O00001`3<TiP0:@000080n;5800<0glQ909:Cd03@d]/00P3Af=d0101DQN@0
NdV90>?]RP000I@206I^aP0C0<S4eP3?jnT0^[7@0<o[j@2RY]P0e>KS05h0003_d;@0olej0??UP@29
Hj00HdJJ099/X`22Gj40Q66R08mf/`2RT<40J3J007A;TP020:bKa@0507Q/^@000340TV>G07`iL01j
=Vl00P2bXlP02@26J:T0ciFG0000003eXUX000000?ZnP`27AgX0VG:U0=;5cP0207c6oP0=095NT@1h
<f`0R6^[0040IP2:GYP0O6jh08`gF`2QBV40O1Tj05h00P2>Hi`0PefM03nbm0020:IXRP060:=0B`1m
63P0;00J09ISU01?PN80a7Ig0P2c<P/0301gGjX0DL;f0572mP1A`_H0gZjT0>neTP3f^hX0o/j<0<In
003SQ@`0=5_;0?ooo`80000000D0M;om000CUP27_OT0Qkgi06c7oP0207RCh@0308NWj@1[Q]/0UFNJ
0080PNSX00P0i9Mg0=2=R`3IUHX0fIF:0=>=QP3ATY40dj2R0<^;SP80ai:O00<0kkND0?BoUP3ncg80
9`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00/0oooo000;0?ooo`030000003o
ool0oooo02/0oooo0P1Xa_h80?ooo`80QFjb0P00P<`60?ooo`0=01009`2^S;40[Xba08EAS02[BDl0
PJO]0?ZnP`1X:F`0iJ6607=6S00oG<P0a9:R09E`YP020<na^`0?07^9eP1/00`0GP0008=>R029g_h0
Z/;[0;^AZ`2Da_P002Ja0<bCV@1eAX/0^hFK0<W6e`3e]XD0J@000080R8G:00X0^cL00;fZaP2mZ/H0
R@P00>;PL03C]K`0LW_>07nknP2N^nd0UkW_0P2;VM/00`17LMP0DgWJ05`MIP020:c7kP0806Qme01l
YNd0MZof0;31iP1f[oH0bKS907l0003G_/420<Z@V00308GGo`0000L0`Gj90080`Gj900P0/Rh008L9
000001H0UY7<0;ITKP1T2Sd0`lkS0:QlY0807@0000L0/e1@02/00038a=H0n[Y@0>WYQ@0mT>l0PXgF
0080/lo_01d0Y>FB0?^kEP0001`0Q6NX08Qb/`22JZl0R6FS06e9UP2?M[<0fjnZ06m6T00gD;l0002A
099:LP2:0000000a05H_Q@1d8E<0Xf>609mYT`1dc?l069?W04TMM`1h;fD0SfVS07O=o`3j_X<0@<?:
06kNd0020;eA?`80N`0000H0N3=/05o@m01Od?@0O6jh06V]n02ACW/20;QlTP0307]g``1dCiL0QSe]
0080U5N400X0S4=_07dH=`1_2c<05DC10:=RQ@0j03L0I2ih0:N1ZP1iI:h0O7k;0P2MSL804`3>e=h0
c;;10<bb`@3DWI`000000<k6A@3SQ@`0h]oA0?^bF`1903L0IQYH0000000G000057[T08jUi02BJj80
JjKd0:`P0000FJh00P1h>7@02P3_XG80gYZ80>RiY03@SH/0cXf=0=6HVP3<S8l0ei^E0=:LW@3<V9l2
0<nMXP030=Zb/03Z_:D0l^Bm02L0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0;
0?ooo`002`3oool00`000000oooo0?ooo`0o0?ooo`050000002I1`00WgFS064lS`2lO8d00P2=0`00
1@3LaL<0I46B05h05P0:0000YQ`00080XcTl00H0LG3208LR?02[Be@0HMOU08M/[@2NT/L209DN7P09
0>bd=`3oool0bNS]0<WXk@2EgOh0c[S40:aJK03oool0Fl7k00<0oooo00@000J?0;AfSP3c[G`01000
0P1GMMD02@3f]H00/ZcB0<;<hP32c>80Pkok06RBiP2BbOX0S>7m096If0020:Nch@80TmSn00<0^]O_
07l0001o00000P3icil05P000000ZW6B0>VGJ`3F/;<0iO^h0;iC@P2b;P00]:W>09JRg@1J=hd0LdVB
0;jbcP33c^<0Z7bT09MUUP2m?`h0MPHN0<YXD`2eHV`0SFn[0;ERK010=Yd209^@a`0F09FNfP37/<<0
o;]K07]OY`24IjP0NURN07iIW@28FYD0LU>O0714S@1b@hT0OUFG07]EVP00>kl0`koF08H00039S980
29Zn07haHP2NCf/0K25K08[?oP80O]Wn00@0N2mU09E4IP2EA6H0nlmY0P1[_?d306oAo@0305lfR03]
ckD0C0000080ZLK^0100Rl7i06lWH`16J=00AVS@0<IoQ026?Vd0QD=g06D<@@3VUQL0YUYc07``H`3k
_eH09`000;AFFP0W04X0JB=R0P2lN8H0802<5Q`0RH?709f=`P1mX^X0bk700;CCl03mcF`000000<k6
A@3hk:`0h]oA000LY`09000003jk01P0200@07D0>e?108jUi03jjIP0000009hE0037RI80TM;n09AQ
TP3LPf<0hHm_0>jVO@3BTHl0eYVD0=ZGR@3EV9@0fj:I0P3BVY/20<jCU`030=Zb/03k`H@0l^Bm02L0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0;0?ooo`002`3oool00`000000oooo
0?ooo`0l0?ooo`80`J>k00X0/FAf06VXm@2I1`00WgFS05bTmP39e^<0d?[T09`M2`0003X000130P35
SIX0103_gKh0<@1P0<J/_`278S`209acX`80QP8000L0bHbC09=PTP2CH980000006/[K@3hYdH0i>CB
0080000000H0WDMQ0?ooo`0:0000`K3909H@003<k>/309XfAP040000R01j/?D0EgGE086Sj@<0Zloc
0P2X/]l00`0]RN`0EYC^096If00206fio00:072ko@1_aOl0_/KP0;k6h02Dk;T0d;k:06PJE@000000
I`000>?m`@80000000H0^JG508DdGP1104<0>V[F05TeR`14^o8207WMn@0308eCQP2GIIH0_IVc0080
OM[m01l0`XnQ08e_Z`3<g^H0F5:`08:3b`2KT<L0UIkJ0<N```2UPZh0QFnb06aT^01mHZT0PFFY07]T
[@1bDil0kZdb075DX@21Chd0QDn808OMoP1/Cih0JCEm05/YN@1eB8d0L4B=06@9?@1]<G@0JBea09Y[
V`1lCHh0el_>00<0L@0000P0nkel0;^M^P2n^=@0MWS70;^R`01/Qm`0kLne09iRR080/6Z100<0aD@0
09UTTP2oYAH00P0000001`2<BGL0QD=g0000F@3VUQL0dZfd01@0I@1L00@00P2kD4020;?OmP0508W>
oP3Xe/80RH?705k4o03U_:/00P2=a_/02`2Wao00oLe/0?S9V@3gk9P0n>j^03/hX`007:L0>@0S04@E
K`2WEV`0Y6J90080UeR30100fY200?FRF03VReh0n<=E0<]YE03SVWl0g8=S0>NWS@3STW40dXn:0=fN
T03NY9T0bXjD0=^MT@3?U9H0e9RD0P3AVIX00`3[[i40nL>?0?W<G`0W0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool02`3oool000/0oooo00<000000?ooo`3oool0?@3oool01`2<TmD0
C8GV01RSf@1LK<X006_E0?[LN`2]MI@00P33Wk@0200003X0GRMc000[/@2[^><0gm_B08I;P@2CIY/0
mjI20P2cV[h02P28Rm00OI?N0;n8VP2kV;@0mnR=00004@2<?fT0diJD0000P0287cH209e7H@0<09fM
d`21`od0`K390;J]d@0000T0V[O]0000003oool003BS04b5iP2_f?D0083K0P1=X?H20:B`h080LYSX
00<0002:065=Y03GolL00P33ZL003P28R/h0TXo=00000031^=40?00K07[AQ@0000008@0001h0002K
NZd0Z7RN07]5Q01R<Gh0/J370P2fMHX02`210000A4jg0000002SRk/0eI:<0;fI/`3idFL0d];I0?KN
/`0G0000801O00805@0901L0JgoF09XX:`3E]k/0lJUj071ba@1VEZ`0O7>n071X^P1hHjd0PfR/06iN
/02CP[h0K6Rl07MNZ@1WDZH0L4nK07aNY@0i6Wl0JSj9064^NP1d=gL0L3Um0500:`0204<0:@060<ek
L`1^__h0Kkgm09>HeP00000090000P1C=Y420<J7T00C0>g?]@2ULIL0^HRR0;V8XP1YEjX05@000?FV
I03=QH<0IAA?08</E02RHXD0[Ua]0?GS^030_mT0o/9g084^FP2`<aL0l;JA0?W@X0020<Nda`808JOP
0140h<6i0>FlZ`12`[L0Sl3g0<OBh`3fgK40n>2^06aDY@3biH40>cRS08Ioa@1XJL404`0Y0:MFK01=
04L0aJJj0:FPd00204L^S`0809eQR@2ZLiD0N`000>n/Q03SVh00kJAl0>RCJ03SWhL20>N/T`080>6X
V@3KYYl0fjVS0=ZWX@3LWY40j[ZR0>RlY`3i`hlX0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool02`3oool000/0oooo00<000000?ooo`3oool0>@3oool209]8I0@0oooo00<0=AIl0:]b
T`2[LY<00P35A@D02P2Q8000aKdh0013a01YDJ80032e0000001Z0040`kK=0>7Se@3SjX@20:7Wo008
08eo_`2:OKl0;`0=08H5000>03@0M5RS06a5T@2X[=X204A]eP04091f/@1kJ;40WIgC0873o@80`K39
00<0000906VQl@2?gOh00P2^c?001001GmH0C[Ki055ff02ke^d201d000080000002lbnD0LYSX07:H
j03SoL40R9gQ00Inh@28boh209:il@0:05XWM`1]0000KQ90078^J`2`:P00Jd^J08]YYP2KNZd0Z7RN
05i3V@80^[cK00h0/J3708bCe00T[]H0h?V[09Eo^@2HNk80_JC00000003idFL0clkI0?78Z02YIX80
001l0;JVb@<0KLWn00P0oLa[0:cJL`1bDI`0M5^W07ac_P24I:H0HTVN07=<U@80Ofnh00l0J5V^08E/
[`1WHk/0LEJS079FXP1H?IH0GU2Y05U8X`12=I`0LUJS03D@M000000043:a0<ekL`3odGH00P1;EK/0
1P2YUl@0X/gf03]9]`2TdoP0/Rd006U<W@80`6a/00<0UI[F07H0001/6U000P2N91/02`1P5E@0^Fij
0;U^NP2iKWX0mlUJ0>GgYP2MMZH0Kd^G08EJU`2>Sm00l;JA0080[f^302P0Umcn0>SF`P3:`m@0`JS0
0<Vgb03Mmm`0G9W_0<OBh`38g>P0YiK406aDY@2mkO<0^[L`0000002/EfL09`ej05T0702:CH40g[bf
0:5WSP2XEV/0HCf?08Yl_P000000cUPT0000FP3BT8`0CC:@0>:EN@3XXGl0jZjB0=VOU`3SUWL0eJBT
0>>XU03AYJ/0fjjZ0=NWY@3SZRH0jnN0:03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo00X0oooo000;0?ooo`030000003oool0oooo03l0oooo00L0001V00d02P1G1D@0^5mS02H0001f
D9L0k<J^0080TVnW00D0032e01AUfP1_TnD0YZ_J0;BQa@0206Flo@0;09I4H`3oool0^92]0000000>
03@0Rf^X07AHX`2i@P00^cd@09BLf@0^J]X00P3SdLD00`1?S>X0oooo0?ooo`080?ooo`0709=YW`2E
LZT0S6bY081EU@2IKZ00MLko0020^P020>?9_`0308fdl01nR=<0U9SD0080T[Wa00P0FRMg06m4S@1l
Ml80JAA9050bSP0gG/d0RFn_0;BN`P80Zi:l00P0U9??0;Zlf`2YBE80ZDUB08L_E03On:P0UGni09Qk
/P80`[?;02`0Vm7j0;D[002gAcD0JdjM0=C?DP2fY/T0b;[=0?k7JP3Gf=P0oLa[00007P2@O;T0E52`
06e0R@1oPld0O7[608^3a@1bN<T0Ofnh07UhaP1eHJh0JU2Q08A`]@1XEJP0HDnV07MQ[@1gGjX0EcjH
07INZP14B[80002808j2`P3f`I80o/]_02efhP2C]Nl0Xk_Z06d06@1j/OH0001F0=a_=@27GYX0SU^A
08ACS`<0YF^?0P2UNZ@02@12Ak40`F]Z09hlBP2N?4X0SUR;0000:@0]01L0UdEU08MRX@0206Jgo00:
07?8o`1jBhd0[e5H0;gOl039]lP0L9WY0>_]c@3acjl0iYA_0>;Lc`80YiK401d0k<jf09_cj`2j]c00
PSAS03@0AP1:0D/0I2ef05<LK@250000ahN>0<^Q[@1Q?Hl0Oe>D0;e^M@36//H0olA`0=^>N`3SMbX0
hYEi0>f]R`3/]IP0kKRJ0>>FM`3KSg/0gjfR0=NMV03R[Yh0ejNU0?oJS`0Y0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0?`3oool04P2f
NI00Z7RO0;:]d`2a/]T0O0@@0000;`1_H;40j=o:06m>V`3mhIl004W706nCi@16<YD0/hf^0000002A
MK00_/3K02000080SiGE0P2Y[MX01`0l0000oooo0?ooo`2DW=T0HaUI0<Gkj03/ilX00P3@hN@0102>
/>d0@cbT03IniP226C850?ooo`0408UQW@22EY@0@IOb0:W@m080DJCg00h0NUVP09iiZP281`00`/SO
0<CXl02=]?000026000LV`0005P0KdB=07ag`P1FB:D0RGJh0:dd7`80^l7O00<0Z[WT09:Qg`2j]]H0
0P2>P<000`26IZH0UGZc09f<`@020:naf@070>Wj]@3Pelh0d/O?0=;7c`2_@3D0ND5o0=6j``0209gX
n`070=GQh02GZN<0^>fH07MW/`2>MK80Jejb08V9c@0209m[U@0@07e_^@1lK[T0Qg^o07UhaP1LBJ<0
G3fC09Mh[P1VF:h0Fd^U07MQ[@1JC:L0HDjU059H^P1<>IX0@BV=0:6ah`803F_M00T0;GKR03U0[@1_
FJT0PFR]04YB^03=IT/0=`0c05Emg@1<DkT00P2DSl/02@2VHh80C00000L0001nU^00@TNa0;jH/03@
Z;4000:;08I^/@0208]7M`80`FIR00@0;`mf0000702;F8l0/ik20P2MR[l01P1iNLL0g/_50>7Ve`3a
cjl000000;kNk`80/n3f00T0k<jf0000O`3@[200H29Z0000002VDVH0K4^I07PmN`1Q2d@00P29;Tl0
402U90L0T`400;iVIP2nIVH0_fH00<IXG@3SMbX0k:N10?2ZOP3^]iL0hI^60<fV/@3AW9l0gjfR0=:N
X03GUhh20>?Ic1X0oooo0P2SiO`=0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
2P3oool000/0oooo00<000000?ooo`3oool0?@3oool0202Qd?P0HKGl066eo00000X0Q39M0:E[T01C
D;40Elf^0P3Pi]P0501a:fL0oN6O0>fWP@3MnmP0AS:E0?ooo`0<00`0OEbQ0<^>T`1kGjL0XIkA08nE
e@2Khod0_>cc05P0003oool0SBa609Obf02ALJX0/DDm0`3@hN@207T76`050::^g`2Q7`H0XAl60?oo
o`1CYoP00P2ab^`0602;H9X0UVbQ08ANW@29NK`0PE:@08aKTP2HKj<0SgVg09QdZ032b=l0QfRY079C
WP2^Vl@0H8_T000LV`1R5U@0001A08R>d`24Qlh0>Uc:08fFe`2k`Ml0TjWU08BRi`80]k7C00X0SX30
08IVYP2UW<`0YIc<08^=d02jVkP0WjCI0>3GcP3Aam00[d0e0P2biOP07@000000C00004`0003BeM/0
ZKST0000001dO<d0M7_<07m1N@2VQk@0B3JI09m[U@1X<WX0V7FZ05TbQ`1d@hL0?aQh04<@J02GN:h0
FdZT07e?S`1oHZP0PF^`06=W`@1BF;X0DT6O05eG/`1LE[<0V@H000<0L00000H0000008>Vj`0IP^L0
Y=3g0=Bc^000000206:io@0809B?b`21CHT0C8?U08R^k`1nU^00S9WJ0:1SR@2500020:0kA`80V3]B
0P3@XjT0102494@0KSb302<00034Qi820=K@E0050;n[aP3NblD0YkkZ0?^`EP11^nl00P1ifoX07P3F
d=<0oLj@0;galP3@[200ZcDU06LCB`2RD6T0O4n@07iBT`1fBXl0PcY[0;UaP@35OX<0T`400=N_/03;
VZ@0lkfD0;MdR03m_W@0ji4O0>C8_03a]Hl0h;J]0=Rb/P3N[:<0eYRA0>[5[`3^`J<0lK^F0>GjcQH0
oooo00<0bK[<0:W<lP2Yc?800P3oool01P3i_880F@0?08``C`2<<4l05`00012MdPP0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`100?oo
o`0902MAa`2HR/<0V8[30?kGO00E06@0Pd^507800@130000K6Fi0080]V5Y00T0;`0000P0002RQK@0
XXFd03M=_03[mlP0//SZ097Un`0000000`3oool00`1_gl/0Uo;H0999L@020;RYbP070=;PhP1Ibo@0
=9Ca03BDl@2oYl40XZkO03l0:0050?ooo`80Wh6b0140UhBl08QPW@2KOK40TGB_08eZYP29IjH0VGne
095c[P1aDI`0SfNP0000S0001iT06c6[00IDd02>ZnT0Bhg/08FDf`02082`l`80PioU00@0HWcG0:bV
d@2dY<P0]:C80P2BS<T01P2UW<`0Rhg@0:S]n@2XkOT0i<Zm0=_2`@80b]OS00H0nkEW0;k2g@2C^?00
TkS`0:V:]00000020:Z<]P040554Y@1_V>T0KiSY09UBM`80g<g90140Q6FW04HfVP1X@8h0<VcJ08Yd
]@2TQkH0Q7Fj039<_@2UPJ`0C1Q/069M]P1LFKH0DT6O03</VP1IDZl0Pg6f0>^dVP020?c6R@0?07fh
n@21SmP0_Zg8000NZ@19Fl80hIZ30000O`2iZ<P0PJka01j[aP20JJl0000009m6G00700d02cFf0080
XeYi00H0[GNG07`aI033T:40`i2Q08@A7P1M00020;YkS@0O0<B7TP2HDGH0NT^=08ECSP07@l<0PUZJ
09IWV@1dAX`0?RfC0>SEG`0000000@0d0:Xj<`3>a=40OSIY08ToK02jM8@0UU9k050>FP2?Ag40Pe2;
0>^L8@2GM:X0a7n60000S@39WZ/0oN2J0=[5@`2oPI00omN;0>C8_0020>2f[@80gZbS00@0cJF`0>[5
[`3TVaT0lK^F5@3oool20:5o[P030:Lo@`3Re//0TY;@0080oooo00P0K00G0:I>H02RBf00TcQC0<57
702e;000ij610<]>3@H0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0:0?ooo`00
2P3oool00`000000oooo0?ooo`100?ooo`0A06ljO`0L@;/0V8[30:b5ZP2NLj40?L7D07800@2=KJT0
]J?708]d]022KkD0GS610000003ajHL0/m[d03BjeP3[mlP00P3oool01@0?0000TNOj097WnP1oi;/0
]=Ob0080TTUa00H000nJ0;RYbP1/b?h0oooo0<FY_@39NgP80?ooo`09099`Z@2>IIh0PE2>08eRV`2G
KJ00UVbP08eZYP2=K:P0VGne0080RWVk00`0TGRc09MdZ@2IO;80QP0005Mee@2?ZNL0L:?a07_7oP1b
`_h0GjKf07NHi@23WnD20526iP040::_h@2X/]l0OH[F09BJe`80?[?c02T0MXgL08aJT@2kE4T0^eA9
0=WNfP3[m//0e<;80;k2g@3Ja480YgFK0;kaW`3<aTD0KVBg0:Z<]P3i]WL0S:KW06nHj@004Yl0iGXK
0>C<_`2LR;h0JGWA09Fkl@33Z/4000000<edI`24MKX0=E7102YTeP1b=gP0U5R706`eN`0V=jd0GVk;
05a^c@1nI:T0dYFD0?RYG03l]6@0`:_504<000020;5jU`0@07emb@2YVlP0Z4130:Q0@`2XY=80O]_l
0:FTe01KM]@0I4VM0;nV`024a?`03SBd09Mo]`28G9L03`1Y05<QM080F`030140VXg50:Zcg`2Cl=D0
S>7m0<AnQ@3Vm]80f?kF04@0003j]WD0GcB5068cP@0n;I<0j=EO07TdK@0103@0Rd]m06/nR@020681
<00C06/dNP1b74d0F`U60:i_RP2bLXX0[nVB0:^1Y`32SId0lYLe0>V7703mh9X0dNj>0?[3F@3oeh/0
nMZY0=VSWP3P]Zd0di^K0<JBW`020>N^U`030>BK6@000040oooo01<0oooo00<0RFb/09KCo@2Fdod0
0P1g00003032FTT0VRX^05D0002UFG@0MDnG04LfV@0m0000gH9O0>>MP`3WXH40ghUX0=YeC0D0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?oo
o`0/0?ooo`0304><k@3oool0oooo00l0oooo0P1ac_h01P2@JZ<0E@I805c;m`1f]oX0F:Cf03a2[P80
/[kS0P3@i^H00`1I;Gl0XJOK0:6Wf`020:_6k@040:jYdP3oool0ID:C00T00080bkK600@0`Zc403:L
lP0n_n40o]b90P3Ie]@306c8oP030?ooo`39NgP0oooo00<0oooo00L0Ik[m00^L`P3oool0oooo09MT
T`29Ei00UfZM0080Yh>]01H0WGb^085X[@2SQ[@0Y8jm08ek^`2BL:T0QVBS09iiZP28HYl0NEFK09J5
_`1iXN`0XM3h04VRmP0XLn40OJkc09VSf`22/?80O:_a0526iP2R[n40T9[I0P2@/Nd00`1jdOl0?[?c
07J=g0020=W`h@050?S5U02KcOT0Vlgi0000003D`/P00P2KT<L03`2;eH40GXKQ08bCe@1CN=X0SY;C
09EFP@1fZo<001:O07/0000006<0n;b503808`2UT;l0000006aS]`020<Jgc00B065K]@33[L@0H/gj
0:bYe00=GmH0IiCY019NeP1JMmH0001f06=K/`2RW]40[R<00000000DI]/0LTZB0240000VMn@0J42>
0P2WbeP0200001h0OP000;OleP1l0000eINB08PgH@2ONZX0DSnN0P3:]/L00`1`[OH00@0f04ETc@02
09Z=a@040?^kN@2Yc_<0fYN:069ac0<0Sb4^00@0QVRY06hjP029k=H0aJ_00P120000300103@0C0aJ
02T0001X0040PRI;09MAN01e?h40FQQO093Zm@21=6<0UV2?0;Z7W`80ZV=n0P2200001@2Y7`00n^JA
0?oGR`3gYDX0e9^J0080gHie00D0c8nC0>BYU@3S/jD0i<Rl00000@0D0?ooo`0:08K3n`1oCX`0Rg^l
08]k_02POZh0aH><04=XdP1b8EH0Qf2N079AW0<0]g630P2kC3P0103>Qh@0fWE<0<efJP3RMA830?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool02P3oool000X0oooo00<000000?ooo`3o
ool0;03oool0102;[N`0E/g]05K=k@1FcNd:0?ooo`80ZJkK0`3oool02P1jI:h0STMd08=X[02kX/00
N8_I0<f^^P1^Sn807J;S097`hP13YoL30?ooo`050000000008D0Zj;>0:jYdP3oool00P2GSLL00`2T
U/L001NU000U/00208FBf00509^6_01:TNh0fMKD0;IlU01T>HP0103oool00`2?fOl0=h7X06/00002
0?ooo`80:@M`00d0R6NV08]YYP24HZ<0YH6]08ao`02?MkD0R6RX09A^Y@2JKId0KDNC08i[Y`2ILjH0
X8Vk008008o@00H0UXFo0<QH001>F;d0KWW>00004@2AWM`204VWn00E07f@f`11Rnd000000000002@
V]T0WIK<09ZDc01_Rmd0066n0:6Lc`3NhmT0bNC[0<;hk@0003l0000[01RRf@22eOl0Vi3705ldQ@2O
U<T0FfW70080[Xjd00@0n^^O06MneP000000/:370P1X>H<06`21I:P0Vh>h09^3^02@W]d0XJKI0;jW
``0D03h0c8nD08m?O@2lWk/0K6Rl05mie@0nHll0F7OG0000I01SFk<0BFW@0:hS00000000jjb<0<Bc
bP3b`Yd0img;09N:``2IPkX000000:8_:P0207>>gP0?04PKM03EUi80eINB08]DR@2cGfT0OhSB08^?
d@3Uim<0hiHC06=V`02P?T`0VXg50:?Po02LDG40L9CU0080a9nc0140]G65000o^02_Z]<0000004`0
1P1M5e`0KD2:00000027NK`0Lc=a07XjL`2IH8d0QEB?089BS`0`04`0R3AK0:i[Q@020:YfV@0@0:ib
S`2_M900f9nK09l?002b9`00hH=I0?[VT@3Yg/P0D`000=Fa]03A_lT0gha^0>F_W03@[KH0fkZh0=be
/1@0oooo01@0F00?0;YIE01NAI/0TG:/09Mf[02POZh0[6V502H0>P1b8EH0Um3k0=65N`1B?Y/0`GMo
0>RDJ@3>Q7l0j:nH0<j7Q03IR7<0^3000>9e4P<0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`0Z0?ooo`<08@004P3oool01@16HLT0I[7j
0:PJ000U[=h0N8_I0080^DLa00l0oooo095]Y@2KX=P0000c0:AQPP2XEf`0RS1B0<a=003d^8X0^GnE
02l=M02>Y>@0]kKH0828dP2EIYT00P3D/;@01`3oool0g^OJ0?ooo`3oool0000Q0?ooo`3ofhl00P3o
ool01@22cOl0oooo0?ooo`3oool0C`E=0080U;gc00d0hYf707EW]P2EM:`0[8V`09J6_`2<Ol00SfRQ
08IWY`1oEiX0V6VJ08UXYP2>JjL0WHVm0080_V1K00X0OFF/0:AoZ`1gCI<0BURn04UE_01aO]40KWgA
08nDe@0==;@0OX?>0P2O[n<0502>bO`0YIS809jZg`2NZ]l0bJZj08Ej_`3NhmT0cNCX0>og/P3Wn<l0
l?BU0000:`3Qg]80b;;40814O03BfF@0WiC909>3_`1YI;X0[Xjd0P15]OH02`1n?gP0SYOH0<;mi029
JZT0M=?m07h0001@YoP07YG[0=7Vi@00A/80=@000080PJC[0180X<We0>NmZ`1c?h80OfN^00@k_000
9JX0AEc50799T@2][MP000000<B`a`000000RUN?0<b6QP28@6h0PCY/08^fl`009:T207>>gP80_UM:
01<000030891MP22@GH0PT5f05/iSP2;WN00hiHC01hVW`0MZ=80I00H0000SP2DJ9d0Z6f?0;YnTP1?
HLD05ZG10:aSNP3/UV00QUF@00<0000000L0VGnf06TRH01L3Td0YFR<04IYd@0nJ=<0Oc]a0080XVF:
00H0[7NH0:j0XP2^P:80ZWNK0;bBZ`33V:/20=:KV`0<0>JlZ`3UW1X0^C`G0=^=N03NWHd0hkJY0=jh
/P3H[Jd0d:Zb0=^j^03L]K00il6_2@3oool05P13WOD0oooo0?ooo`3oool0Ke:P0??5WP260000oooo
09?7n@2@I9/0[k_R0000;@1lBXT0^9Bb0:fI`P000000XI?60000;`28K:`0[WfO0=ZAPP2XL9<20;el
R`80Y41900D0bG=[0;mOE`2h<000^30004eN``020?ooo`030000003oool0AP0205d0oooo00<00000
0?ooo`3oool02P3oool000X0oooo00<000000?ooo`3oool0:`3oool202Z]i@03076ko03oool0oooo
00l0oooo0P2J^nl02@0f0000nZiS0:mkV`2@V]T0gmO?00h0001Oe/X0/Hf`0?2`Q`020>ci_`040?oo
o`1^T^D001JU0?ooo`80RJ7T00<0PEJF0?ooo`3oool00`3oool01@2K/NL0oooo0?ooo`000240M008
0080a7Ad00<0oooo0?bmF03oool01@3oool05P1f@XD0VXRo0:BEa@2HSLL0HC^=03l03`1]Ai<0LamA
0:ESQ02AN;@0Whg108YOVP1KE;00Z:_H08I[[@2HO[D0P5>C07M=T`1`W>`0B7CJ07f^l`1^OM420:>e
iP80a;_A00@0Xj_M07h00038_<h0Figb0P2jN8T04@1oMKh0gn?F08kYm`2>jOL0QbiB0?3dY@2iV[T0
00nO07Q:SP22TMX0SEB70:1XT@1G<XT0TF6F0:1n[P25Dhh0ZY2j0080NYST01<0PiWQ096LfP2JY=`0
L8GH06B4g@33eNL0WLch05j^nP1_R]d0N:O`04NGlP24Z>`0P4n>0;fH/@2APKh0@dZd049Wd@0mD;d0
9Tc20080Pdj800L0OM3o0<Rnd038_]00ELo508J5b`04Em80Y:kN0080Tkkd00`0DE6c01D6O02eNi<0
000308Y?P`2R=c`0Xg:K0:6Xg02[/=/0T_3G0000000P[<l20;mXJ00>08a9N@28AGH0o]Ai06@00023
7CT0Z6^;0<:0R`24D8/0D93]0=BI3@21cOl0W]Ck081=R`1/=G/20<fga@0408Q3L`2/OJ40XVF:0:9U
RP80[h6R00<0Yg^T0:YiWP2kR9h00P3@[;@02@3/_Z@0i[b[0>R5A@3]]9@0h<:j0=jMS@3UZI@0d:nh
0=>TYP020=^j^0030???Z`3oool0oooo00D0oooo00T03@000007T@30Y;d0FP0U09RhkP1/01h0[44l
05@PLP3caIh00P0Y00002@3Fi7P0V3A50?>I?P0@;Z`0/Y6d0<NY_02TT/<0<@U]0:`e9@0209HA0003
07V=fP34MgX0GYoc0080WDaX00@0^VYc0<9dN02R5`00WE=d0P1R00001P2Y8P00`j_2048000000000
F`0;0;B2WP80X30_00<0ZS<S0?ooo`3oool0F@3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`0e0?ooo`0306hhO@3oool0oooo00L0oooo00X0ETJT028SV011LMX0@G7J0:;A
I@1Z<WP0]ibl09n<_`0004D0Mcim0P0PZmH50?ooo`030000002dfg00KdJ@00<0oooo00T0HPHk03<0
7P2_Ef40[eMQ0?ooo`000240X/Sc08g@oP23WnD02@3oool20:AjY@0:0;:3XP2bSJh0/Xf^06e7T`2C
JIh0L4>;0;1II@2[Fg00TF:G05]D/080[I6i00/0/9:h00XTY@1E`oP0SZ[Y072Lk01hYNl03ESB07:4
eP27UMX0>FSE0<Bkd@0207h0000@0<RlcP1U]?`0;XW/0<_`k00a/nH0ao?]0=Z/Z02ROjd0000008RX
jP003il0n]5X08Eoa@2HN[00T:KT08FLh@80Uh:k00H0SXC40;22X`37h>/0an3[06Zho01HX?@208k2
n00D09W7m`0DE<h06jGJ0<Gli`3El^@0oooo07;In@0Y000003>j03BFl@1@Tnh0XK3R06>1fP1kSm/0
Dh;R0000N01EOMd0IHKN07g@o`3g^HD20;55?@06091ZX`0N0340mJig0<abHP1o0000SWJd0P2eNi<0
0`000780aKcB07<000020000000H0>[cc@120000=bJ@08mWX02SAE@02@0>0?joK03=^LH0o]Ai0:Z]
f@0i0180Q8?;0<6P^03Wm]00K;on07?:o`1O4e80YW:I06M5U@0`;9/0OFZb08Q3L`1o>g40[7fQ0P2T
LIT03`2]RK00]Hf]0:^<]P2UQk@0^i:/0=6IV`3I^;L0k;jT0=f`Z@3XQDD0j<fk0?W8U03I/[00iJVD
0=JLV0020<f@U0030?NcNP3b/880oooo00D0oooo00D0FR5]01`02@28god0aKO<06L6=0020;IgS@0A
0>GUd@1D87800`^;02lJQ@130000@2:508>3b`2lC3H0TYgK0;N3W@30Pi40fYnE09N<aP2i[Ld0`6=M
01L4N@2/GW800P3]fKl00`3clk@0/7NC0;R0V0020:9AJ`090:EJM@2B:cd0O`TG02d0002YUL40SIWJ
0000001UK<D0]8:N0080`iNY00<0[Y6g0:Xc8`3oool0F@3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`0f0?ooo`80U@L01P3oool00`2dFV40g?_I05Z4h@020<S1d`070:kh
k014FlD0_MO]000^]P0004D0oooo0;D]00030?ooo`80/hRX00<0ICf=00000026>FL00P3OcLL00`3o
ool0MG?207Ec`P0208CJoP0304h0?@007jD0LlGo00d0oooo00L0Whk20:0kAP2P>dH0[hnd08QRWP2C
JIh0LdF;0080MEj[00l0TF:G03P3G`2]P:<0XY[=0;7<E@25NKh0Z8ji0<R[_01`;6T0P:ob02edh@25
PlP000RC08J3b02?R<P00P3FH@000`2?^?80U=_n09CMoP020;ngd@0309RPfP2>W]h0SYkN0080TioL
00T0Qi[N0?[AJ025OlD0/8JX09VJd`1kS]X0ZUec09N2^`27O<400`2jf>l60?ooo`0306K3oP3oool0
000000D0oooo00/0TJSU0?ooo`2Lc_T0Kg[>05>2hP0008T0PGO006F6gP25SM<0mkV507UNY`0209PU
9`0:03H0D032LG80c79R0=U]>`2EQ/00Q6JX0:jB^P0005h0JEV/0;J:Z080gn7F00`0?00i0:UFJ@29
Nkd0RG^m0;omb@2iDTT0ZA/00;U>@P3j]WL0000005IJ^P24Pl/20>Ofd00904Ucf@3i_H@0b9FQ010;
Q@1hbol0DSJA08A^/P2NOk40Wh>e0080XgfZ0P2]RK00302eSJd0/9Bj0:F7]02gZ<X0_Jg90=NPV`3W
nLd0`;OA0>R5A@3_T340ikJQ0=^n_@80`XfM00@0aXnL0=JAR03e]8<0mKB31@3oool01P2YMIT0@@0G
0000001M<840RUnI08QMV@80^XJN00D0Zm=U000000180000B00007aHW0020;1iUP0606409P2BGY00
QgZm0=>[[`1=6Fd08Dk60P30Y[l03032Y[d0VW>U0:@[703k/eL0NS]g09]NR02[Ih80G@000000002@
^O80ZdiH09O8n080@L7S0P2RVL`01`000000Xk_[0:>kj`1[G[80aXJ?0;/d003obW40F@3oool00`00
0000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0g0?ooo`030:Bij03oool0oooo00@0
oooo00P0W=Wm0=o8`P2LfOd0]jTL0;kh]@3NimX0O3mk0000<0@0oooo00P0]Bd00000KP25CHH0LAU9
09VHd@1_?H@0cN_Z05D>EP80G]GS00/0WEIi08OOo@27god0oooo02ini`0VF/l0/Nkg0?ooo`1Q?8l0
B0020<6A000;0?ooo`<0092o0180fFHR069Za@3?/K/0LdF;0000002fD4/0Qdf30<75gP2LUlh0C000
05@09@1M0000nMRX09VOf00000004cfk000X[`0003L205l@C@050=S`h`1`fo<0eV400;fBZP1T7V00
0P2HZN80200C00P0Hg[D09N>b@0`4GT0YXnl09>Og00k04d0AP0R0P2ghO@00`3IJ000iN7?0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00@0001n08BBf@1EJ//0PhK>0P3g_Xd00`2B0000HRA[09=>
N00205C=j@0;04`=G024>f`0]UaR0;ILHP25Bh4059[O05`/O01C5fD0000006hC@P0000000P1iFJ40
1@26Sm@0bUdm0<IUEP3;PGh0LT2500<0S<[m0140cinV0?W6T03oool0A5O007i:R01/Dj@0KcAg0:1^
V@1B=Y40R87507ef`@26LK@0TgVc09aiZ`2eS:X0[8ng0;jR_0020:>XfP80XHBd00d0aJZn067GhP3U
hm005hoX0?SK[03W]Z40cYVO0<RCW`3<XJ/0aYj_0=o4_@3VcKd0o]bI00@0oooo00H0kOK508=MW@23
GId0F1US0;n/a`2;U=L20:Q[S00I03`2F`0R0400ObA90:>Gb030YKh0Q7c2061J]02[SKH0O4N60:Ub
U039Y[H0eKJj0=NYZ011F/D0Kf2a07I7S02NLIh0VW>U0;f3UP3gYdH0NBUK08lnH`1d:f@0000008E]
/@02099h/`030000001j<FD0YIO70080YIO700L0000006Ikd`2KW=<0j;dm0?JfPP3N]k00olYa05T0
oooo00<000000?ooo`3oool02@3oool000T0oooo00<000000?ooo`3oool0@03oool02@2CFh/040Em
0?ooo`3oool0D`000;fbd03faIL0W^gh097_jP020;93=`0608f3``2Xk9l0`H>@09VHd@1miml0eogJ
203oool01P3aZGX0oooo0?ooo`3QhmD0?`000=k=D@@0oooo0`24S]H02@28d_l0oooo0?ooo`3oool0
000_06Y:VP2kJ6h0fFHR0<N^`0020:MQOP0<0;Qa002gPI/0Qf>R08MSXP0005H0H@0F0=V5KP3li:<0
00000666g`3CO6P0U9;>0P1jcOl02@3kiHl0Dl?g02X0002WRkL0JBIW0>_i`P3][h`0J5>V08mEQ`02
0<job`040:VOc02ORkh0P6BY07i<RP80Ph_C00@0LHOJ0<Wj/@2Ie_d0Va803P3oool20:K9lPT0oooo
00@0NHSG04=6[`1lCXl0Ui7<0P2Hj?X01@2=eWl0YGBM0000003_Xg80`;?=0080Y9O800T0joW30?N`
L`2TCV80Y4iR0;9TL`2=HIX0LCUl09efYP2AHiT00P3mb6@01@2n?P/0_9B]07?7o`1b@8D05`000080
]dm60100iOOB0;kDG`3oool0oooo02IDbP1NDZ`0QEbJ09Qm]02GQl40R87508JBf01_QMP0Rh?50:ND
`P2XUL80bk?20P2a]md20;Bcf00:0>;^f03gf:`0eZZ[0;62XP3al9T0l[650<RX^@3>Si80mZmf0=>U
Z@80e9ZG00<0oK]S0?ooo`3oool00`3oool01@0Q7940F3VA0=:ka01B>9<0_jc70080V7FZ00`0X7NT
0:YKL@1`gnD0P6Za0:Z3Z`2dMhl09Q6005/oU`3>Y[00g[Zd07:1d`33Z/420<bW]00J0>JLO023PLT0
JW7707]ia@2YU/80QDUo0?NWAP1<0000KAmH00L0000B1gl0aZk20<VY^02O_Nh04Q6;09ZGc`2?T]80
V[K/0;2Xd0000000VH>j06HgPP0001X0m[J20>kF^P3cg[QI0?ooo`030000003oool0oooo00T0oooo
00090?ooo`030000003oool0oooo02L0oooo00<0ViO>0?ooo`3oool05P3oool0302PXMH000000000
001l0000mZIU0994JP0[O>H069SV0:IWR01l@Wh0d<kG08>6c@H0oooo0P0P00000`39SYH0OSIZ0?oo
o`020?ooo`06000=WP3oool0B5[209>HeP27TML0g/eA0P3oool01@0003<0oooo0?ooo`2@GI40OTb:
00<0oooo01h09`000=e]:@3ANf`0]9bo0=MU001mHjX000000:]KL02hL@00KHKJ04HoYP27Hj80iXI>
08nXi`15I<d0o>BS0:6nkP1eE9d0/JoF06Y=W@2=WMh0lmU/0=fc[@2JRL40W9?:0::Fb00:B<H02Sbl
0>f_S027F9<30:W9l0030<fc`019A:P0oooo0080Lkgm00<0VQ`@0?ooo`39n[40403oool00`000000
oooo0?ooo`0:0?ooo`0>07a>S`2BVmP0TY_H000b[@2hIg4000000<96603_Xg80Z4A;08oGo`256c<0
bY^V08=X[02W]>820:_Hm`0;0000002cB3l0^SlK064SJP3lc900fGH00<E/IP1/=W`0DQ1L0790Q@2n
[LP00P3^f[d00`3Umm80TP`00?ooo`020?ooo`09014/Z`25LkP0X8Rk09B0^`2eZ</0QY;H06n4f027
SmD0/[SM0080]LCV00l0]<k]034WU01dNLT0`ZNo0=>na@34F3l0eZZ[0;62XP3m`640l[650>fWO`3^
ilH0kLjd0=VHS@3EU8h00P3KVXl50?ooo`0Q09NGd@2nZlH0j?W<0000003:S980emoL01<0003CVPd0
RnZo00000020J[40YI?20;JA/03=]/<0NX7>0:1]U`3fXeX002fa09R8`P3WakD0f<K80>[]c@1jN<D0
GVG207eg`P1VJ<40QDUo09ecX`2jGUh02`1W08UMV@0003`0SEN<0080T6jX00T0hn_F0;jS_P0eK]/0
=FkK0<6dc@00000001^O07DnP032jo400P3B_/H00`3cg[P0oooo0?ooo`1G0?ooo`030000003oool0
oooo00T0oooo00090?ooo`030000003oool0oooo02L0oooo00<0ViO>0?ooo`3oool03@3oool20:CB
n0L0oooo00@0ZK?O05l0;@3Ahn@0VM_n0P39SI@01031^=40000^088?7P0000030?ooo`80Umon00L0
W??[0?ooo`1J01d000>F03YNc032PXd0000000<0oooo00@0Nd^=0?ooo`2LaO@0W<Gd0P3oool208a_
[@030?BjSP3oool0oooo00@0oooo00@0_jo:0:LJ0027UMX0QiGJ0P2@Slh0101/L/P0000m0<V=U@00
02h205:Yn@0608eQVP3]S440kHa109VZh`27W>00NE:H0P2VS;T0302MVLl0SI_L09gal@27QL/0U76X
0:MeVP30e>T0Z9g:081PX`23S]H0T;;^0:Fkj0<0EL7j00D000000:@Y5P2T:AH0Y2TF03P0000200jI
f00404G2j01Wc?`0CP0006D000<0?[[]00D0L@0005H0001E00005:7E04L0000206D00080;:oU00@0
B`0000bM`P3oool0EJSh2P3oool00`1Q0040000G0;ZK^0020;ZK^080E8GT00d0a6aV0000J@1m@gl0
fHn10>6n]@0]G]00>SbY0:;@n036S9P0n[1U09]SS`2QKYP0o<b@0080f6`i0`3Ij>001`2n[LP0f^;L
09_YY@2D7Ah0P00009X7000nO><00P3oool03`1cFJH0T7Fa0<Rjc02HY=d0WY[?0:FNcP1f[_D0Q[[g
0:Vcg`3=cMT0Q]J60<j]^01dNLT0ckc80>F^VP020<AH?`04050<E`3m`640jk6C0>fXP@80kLjd00@0
c8B30=:9P@3a]8/0oKaR103oool00`0_]Mh0aUi7002Ba002002Ba0080;A^PP33ZKl0Rh[=08eJT03o
ool02IW;000?W`2UTl820;6M``0606I@Y03g/WL0K3Il0<Z0P02HR<80JKgn0P3Gbld01`2M=000GVG2
04Q>]02FQl40Sgfk09ecX`0000000P1KOm`02`29h?d0@I7`0?Z`C`2aXlT0Uj_T07n<eP0kGl`0LhWJ
0:2[g`000000hn3B0080OL_o00<0`;kH0000000018/0F@3oool00`000000oooo0?ooo`090?ooo`00
2@3oool00`000000oooo0?ooo`0o0?ooo`030=KOgP0005l0jIeg0080`Mg]00<0f]oJ0?ooo`3oool0
0P3oool02@1:`o00kmRk0:IOO02VGg`0b]=J0000R0000000]j_>05=lg@020<F[`@030<:2S@0F6Y@0
oooo0080oooo00<0ME6I02007P2hK7T00`3oool00`1U?hl0S6n]07WAo`070?ooo`0;0;Kgk`38Uj@0
K5V[0;^3V02?RLP0000d0;:Rb00000X0000^0=fEP@3aYG000`32]Lh0103k]eD0]j?40000:02LXMP2
0<RZ_003049Rc02MlO4001j[00<0300000P0OKWi0:oel@0:AlD0WYoD0000>02^9`00;`0005/0;@80
S8g?01l0aJ_005D05P1`0100PaL]0680201B0000E@0006<00P1g2B<0@`0006d0001l2A/0HP0008lL
901U00`0N@/T080E;P1J0000N`<A05D0001R0000N`0406P0001n0000G@0007l42P2A8B/0R00008<1
000j^n@02@000080P@0000H07JVd09eo/@0008<0i>OC059D]P3nbXD208QAR00409M@N03:b]X0NCah
03a2[P80hKje00@0BQmi02h0@`000000J]7j0P1;`?@02`1I_o/000000:]nY00000006P000;U9=P3_
[H@0_Zg80:[>l`2=8S@0T2Hf00<002^I00@0;00004<0001a0000G8cW0P0`E/P0102KZN00XZgO08:J
hP2CY^<20:Fnj`0:09GSo@2egO@0LI3R0:KDm`2NX]P0iLNi0:A;GP3EnZl0fiN90>^aT`80kJR100D0
cHB10=JLV039QX/0lKB;0>B=I@030?ooo`04075W^02MPkL0RejH0;51=@80SgZh00/0<I_b0<>Y_`24
boh0ShC30;Bkg`0J02L0K4NC0:AYSP2[V/D0Z9_908Ug^@0209fIc`030<g9eP21aoh0PLOn0080c[W6
00h0nkI^0017a`2;FI40YXjl079]_P1Q@iP0IDNI089]/P1@RnT0MX[I09JDd02@QlH0n[1?07mc_080
QXkD00P0MY?Q09VPf@000000Y/3/0;:I_@2LU/d0[M7c0000D5X0oooo00<000000?ooo`3oool02@3o
ool000T0oooo00<000000?ooo`3oool0=P3oool00`2kY/@0oooo0?ooo`070?ooo`080>7^f@2o_]T0
_kkI0;nnf@3oool0000=0=36d02AkL820;iG00060>Z59`1/b?h0g<6n00HRY02>6bD01HKN0P2gZlh0
0`0KPnP0gnGH0=oUf0040?ooo`0602007P1Q3d/0bJNg0<VW]`3oool0I0000P0000090?ooo`80[Fj9
0P00Ell07P2=DX@0W>Wk07kNnP2DJj00001c0;eSH@33SYd0Y7VT06`bM`3k]eD0im_708]h^@1bI;<0
[9g80:n7Z`0006d0Q/Kl0<NX^P2koM/0_OVi0:RTdP0005H0L00A07D78`1R01l000170;EJGP1b4C/0
;@0009U_X@80H/Kl00<0@`000200001G00000P1d32`05P1J01P0PATd07/H>`1P0240PQTc07PE>P1`
01T0L@0J08hU>@1o5Rl0Nae408XeFP21<5d0MaDj08/X@P258Sl0M@0?08XV?`2?9SL09@0005l0002D
;Ch208XQ=@0?07<<;`2F=4P0USA8090]A02>:Cl0M08I06UL/@3n`6P0o/Z507U4Q01g9eX0HaAA04l0
2@2A?V40QSYW00<0KK7i00P0UX_605/jT03;OWX0GWkJ09]QS@10^nh0IKgm01VSf@80>KO[0P32dNH0
1@2Zc_<0Pd5e08Q5MP2<:440M@PT0080U@/00P1o00001P2V<000^4400?ooo`0FClX05YST05<LK@80
[YBl0P1Xc?d0103T^JX0bHJ;0:g1j02;ho/209jRf0060=Zg]P3V[IL0fiN90>nUMP3VPTH0cX1h0P3?
P7P02`3FRgh0bg]f0<]kMP3APG@0oooo08]PV`2KR/00PfN[0;B_d`3Zd5T0TEnD0080000000h0n]2L
08]d]@1?4F00DA9P0:>5/`31^=80XZKI0;2kh@000000VQ`00:FbhP2G_o<0`_G_031Ba080g=C@00<0
i<bo0>[Qb@3^SS`00P1ZU>L0201VI;`0P5^N07M`_P2OS;h0WZ;G0:2Od`26`OX0KiSY0P1iXnd02P2=
Okl0WhJi07JCh@1eYo4000000;N`dP2`_^@0fnKL0;kNl000051J0?ooo`030000003oool0oooo00T0
oooo00090?ooo`030000003oool0oooo03L0oooo0P21fOh60?ooo`80_:k<01<0;@000>fjW03oool0
IP0000003@2jMhP0MdbA09?`d03:gNL0HP0005fdo034FdH00000050/QP30en/0_=ka0<FdbP1EQN@0
00n<00D0oooo00<0MeJN0000003oool0303oool03@2PFGX0Q2iG0=78dP1g0000U:3L08ZKgP2LjO/0
Sdek01]Qe`1/DZ80WL;b0:GNn`1bc?l00P34Zl801`2IQ;/0QF>T09M]X@2BKJD0L]BI0680000006d0
0P1W00003@2aS:l0FP0g0:RTdP3Yi</0?@0O060:A01U01T0FP0G05d05@1H0240GP0R06/GC@0CX/d0
0P000000601`2Bh0L`hc08/W@@1c3S80Q2U>078C?P1l6C/0IP0S07HNC@227CX0S39C08d_B`228dD0
SRHj09LmF01_4Ch0MQa807hTC02A=U80QRY<07PI@02J?580Q2=207l_G@80RS9F00T0W3]=080H<`1]
0040O`PD084;5@1k2Qh0M08J0001SP0000000P2H?UL01P1fcol0Mam=02@00P1n=f/0JAM?078YHP80
b9BP00P0Od9j02/000006ZD0bgij09>Ge01=bNL09B2C0;=hT@80jnk=00L0Vj;J03H01P28DXX0UEn?
09YeZ01[=gh0?00]0080U1dL00L0[dmD0;<i6`2g;`00_3`8000HV`2S5P00DW?E0080UhO100@0;cf`
05Z7i02o?`00MXCD0P2dACL04P3Nd<X0aKW?08ZZjP1dP=00YGjY0=N_/03>[;H0cWEV0=jj/`3OVHD0
aFaU0=EhG@37N7L0d7md0?NTB032Zl<0oooo08eQV@80Q0dH00T020060:=bV`2?>E`0CPE>08mMT@3j
d9`0cI6F098_A@1I6F800P2^k?P0502I[>@0/oS^0<Fic`3Hin00PH7:0<JX_03_mL40G:kj0>?l_000
QK/0i<bo0>[Qb@3i^Wl0`jBj0;R[c@00OM<0PiKN07M`_P1_QMP0Yl7/0`28Z>T02`2AZNH0Q/Sm001g
cP1NY_H0AhKX06^NkP000000NZC]0;OMl`35dN<0001^05`0oooo00<000000?ooo`3oool0203oool0
00T0oooo00<000000?ooo`3oool0@03oool04025CXL0Zmch001L/`00G;<04T?002LXW02jMhP0MdbA
09Ul/P3:gNL0DLk70?O0SP3oool0eLW>0>gKK000D<`H0?ooo`0=092>c@2m^]H0dLSA0;Ce/P3A_/P0
d<SC0<ci[P2kdn`0E4BR0>jCD`140000KUFT0:RLbP020<VU]00H09V4^`2Vb?80Y/Sb02UCb02>GiL0
ReJ<08EHU02/>2`0e_;T074FA@3M^K@0m^R;07lYD`1P2T@0J@Lc070A?@26<EP0Wej307`eJP1]9fD0
G`U3060MH`1i1a`0<0000`1c00000`0C0000J0000:7In`020:7In`0308;Ao`2EAFP0RSYS0080P]Oo
01D0QbU9088L>@2CIY/0WE=d07lXD@27B7/0RdEc07hSBP1j7dP0RRU509E7J`27<EP0Rc=F08lmH`2?
?V@0N1m;07LNB`2?9c/0QbmD09L`?`1/[?L00P2c[m@01P35^Ll0]e=?06T;>@22=F<0Ia570;JE]@80
]:W=00@0NLoo0=oXfP1K02X0gmWA0P0GY[h03`2NjZ@0K:Cb08_Po@2;h?d030000:MZS02QJI40T5b@
09=OT02II980PE6@05l[N01O2T@0X4QO0;MCCP030<A?:@090<U9002e@B`004C009c>n@1OIl@08CZc
061J]01QM]40NX_H0080XM7h00L0g]3:0<RCW`0J06T0ODf=0:EnZ@3?SH`0g:nZ0080g[Zc0P3:PX<0
203;OW/0_7N50=67P03gY4P0oooo05D09@3i/Fh0X:CH0P0000000`2FLjX0[jC=09B]i`020<BoeP0=
0<Feb`0l<IX0WgZZ0<oRi@2TWLh0UYWD0715SP3ATI00hHe/0;nG[P21PLX0ah^C07;?oP0208MNV`07
0>C<_`3RdLH0nKYo0>>n/P37[/00aJk30:>Wf@020;n8V@0>0:_3j`2^hoT0GI;Z05fBjP1<00/0>P0B
09n/h027YnX0L9c[06n`n0000000UmGm0<Kfk@2Hj?YM0?ooo`030000003oool0oooo00P0oooo0008
0?ooo`030000003oool0oooo02P0oooo0P2ARlX00`19__<0/?_M08X300090?ooo`0305o8n`3oool0
oooo00D0oooo0P1`@h/00`2HV]@0Mm3o0;;Un0020=CDf@0603IniP3YVal0oooo0?ooo`0QYN<0`/mD
0`3oool01@17?Z<0oooo0?ooo`3IYj<07P000080[U1I00T0]8FR06kCW01^di`0[gjO07WHo020A7d0
PEFE0?W/YP0TZmd01P3oool02@1Aao80TMCn097DoP3oool0hMcA07[?o`1nVN80DP0007i;RP020:?V
UP80/?[U00<0N`00056Ek`2oZL<00`2FcO/20::Yg00H0;2ZdP2D]nl0T>Gk0:gGmP3OiMP0SC=C04L<
GP2II940WFNB07LcK@3fj8/0ZdaE06/SH@1Y01L0NCah08iHS02SHH<0D@0001X0002D50L0I0/o05d4
?01Z9F@0b8F90P1K00003@2>?VD0a9:R07k=o`2?G940Q4=h06D^M`0h0000`HJE0640001]3c`09000
0>KOc02KAV400P2TD6H02`23;eT0Sd5X08`kH`2<>f<0T4A[08e7L`2<@V`0RC]V08/nI`2??F80S35A
0080LQI200L0U4Q/08i1J@2;:dP0OL[o0;>_e02c/mP0];SK0080JP000P1C`oL01P1fZ_<0T=3m0<J5
S02?d?d0UGF/0=oId@80YMGh00d0000003^Um@33QI40V5j;09UPS@2]JhH0^f]c02L0G`25A7P0ZWFH
08N[k@0300002@0G0080KaiE00D0c6aG0<m[D@3BL5@0bDT00<eB00020;`e000507?Do@25OlH0;do2
03]fg`0008L00P2=YnH0503Nd<X0301B06HSI@0oFlL0_jK00=2[/`3OYiX0eXao0>BBL03W^:D0eJNW
0=MgE`3S/9l0eJ:Q0?o@O@2BGHl0TfNM091`Z`2PY=P000000P2POZh02P2TU<@0a:g20<B]`P2d`nD0
/;oU078gN@3Yj/h0ZIK30300001X9FH20=6AT00D0>6=K03BW9d0SXS80<R@V`2[Qjl0O6^e0>5c3@3c
cZT0h]760=c1_P3G[Jd0aYn`0=K1a@38_m40/kGJ0:nTc@1iXN/0>H7W0=Odh`2>]O420<3Ok`0609G1
m@1oTM/0Qj[/0:Zmi`000000001eG`3oool00`000000oooo0?ooo`080?ooo`00203oool00`000000
oooo0?ooo`0X0?ooo`0308_MoP3oool0oooo00/0oooo00<0GlSk0?ooo`3oool01@3oool20;o:h`80
oooo00<0:7_V0:UiWP3oool02`3oool0301eF:80@KoY0<kRiP1e]oX0IkCk09;>o01GdND0oooo0:;4
l@2cSZl0900j0?ooo`80dedN00<059SR0?ooo`3oool01`3oool01`3Qg=40oooo0?ooo`1FaOP0n[Ul
00Lf]`0n`]L00P34[/@0201c_od0f<C60:Nlj03e_i@0`M[/0>^NM`2Ci9h0S>[c0P3oool0:@1o;U`0
KaiD084cHP000000<000091^Z@2FEX40Y6>40:6?`P2UI8@0H@0404`0002@FX`0Y5il09ITU@24J:/0
Nf6Z08]2K`23AG/0HbQ`08==R027Jj`0KC5e07@VG02RLih0MU2G0:E3CP1601/0000009Y<K02aHW80
XWNS09AZW`0:02<03@0009R1^@1fAHT0SeN:09i3F01]>7l0W2<L0080Yo2/0100Nai508PWA02QEgH0
TTYc08@gI02;@g40TDaf09I@N02WJH/0QD5c08m7L@28>fH0O259098gD`00@KH0];SK0P2YmnT02`1/
;6`0MSA_08k[l`2>jo<0:P1L07SEoP1ee?d0DZoj08SZk@2;hjD0PCec0080`hFA00H0[gjN0:R4[@2G
OKD0ggd309b^i02fW;h203i_fP070?RYH01^KL40KVg10;2?/`35M7<0dhn80;I5=00208<0000B0=IO
5@3ocWl0b4P008EoaP19EK`0E3nK00@j_0005jD0?e_70:ENO02=R//0/5QT07Q?U@2VXM40^Z_;0=B`
]@3U^jX0eZj`0P3HV9008P3DUI40h99g0=FOW@0X@KL000000;29[@0[02@0KbMS08HlJ`2BM:h0X7j^
0;7KmP2a`^L0al_M0;5SM02CBG40XYW<09B@c@2BN[D0S4en0:f=]02XR[H0a8nO0>RYSP3JW980S9gO
09VFc`27aO`0gZ4I0?FWI`3ccJP0gKbh0=6[/P3B[;<20=K1a@070<j/^02bYL`0XM;i0:7Bn@1J^O`0
:I[_0;9iU00208[YlP030000QP00=;<0WK7V00800000H03oool00`000000oooo0?ooo`080?ooo`00
203oool00`000000oooo0?ooo`0c0?ooo`80`<WQ2P3oool00`3Ik^40oooo000NZ`020>S]d0<0oooo
0`0c/nT50?ooo`<0/M[e0P2Wd?H0103oool0XWn]06Q9V@1XBIT40?ooo`030?3YQ`3:SI80nken00D0
oooo00<0GR=]0?ooo`3oool01@3oool02@2oR9X0gl=2065nf@009jd0MdJ90:LL003Ha<H008fm07eO
Y@020?ooo`<0T]gn02/0X/kg01/0001_85L0TUN608]DRP2;AG@0IBAX08]HS`2TNjH0PcMW08mKT01k
DI@0TUf@08iHS02NJiL0UVBE08IES`25F9D0M4R>08Y:O020HZL0N4:206daM@1kC8d0T5fA09e/V@21
B8<0R4j40:Q]SP1L:GT0R5B<09UST01O8fd0Mb=C08j1`@2<P<40OU2A0:nC^P2;OKh0PVfb08YTX@15
0000O@0000@0=`0000l0d8J008/dF@2@DX80V5^608DoL@23;eP0MR9B08T_D@2LDgD0WD9H09]HOP21
`O`0ZBP008i6L@22A7/00P1I02h02`1W4DH0<00Z06T19`3Jb<P040000000001_12<0_XJI0<MlO@36
S9L0@C2E0080SaDC0180ZJcI0000001Q0000hW`:0:NE``000880n:UP0::=_`1^KL40/8nc0=:[/03?
S8T0_6]b0>J3AP3@Fb<0nl>70=AZ001L000205Bfn`09031Ba@0004X002B^04DjX02SQKD0SH[;08m[
Y@1^;g00_:k<00<0e:RZ00D0bk2o0=Ne^03;X[00c8:00=6EU0030:O4kP0:07M5R01jIk80TGNb099j
]@2]XL/0`J_30<O3e`3G`LD0fLK70:J7]080/IVn00<0[YNo09:<bP2>Q<D00P2e[m820;^_c@030=:Y
[P3KhMX0`LoT0080jM2m00L0U^Z_0??=Z03M_;P0k;ZM0<N/_P3J/Jh0gkR`0080bi>J00`0k;BG0;Jg
fP2na=h0QjSZ08Moa00[Y^d0X/Kb000NY@1;M=X0^^Cd0=_@E@00001P0?ooo`030000003oool0oooo
00P0oooo00080?ooo`030000003oool0oooo0400oooo00D0=P00000NZ`2m/m00iWhj0=k7`P0202<0
0004000]/P22FYX0]ZO:04bfn@80>K[W00D07`0008C8oP24b?h0Q<Sn048000050?ooo`0302D0003o
ool0oooo00@0oooo0P1@bnH<0?ooo`0707eNY03^lil0oooo06k7o`1i:5T0b?JV0?ooo`0202`06@@0
oooo0380QSi]0:QlX`1o:eH0PC=R09=PTP2=Fi40J2MY08Y4L`2;Hih0PcMW08M6N@2>FXl0Ic=l09mb
WP25Ei<0SUN;080fJ01j<FH0QTn707a8R01m@Wd0[8J/08MCS02;G9D0PUFD07i:R01iGZL0QejL07eH
W01M4e@0RE67099_Y`2EKJ80T6fW07XWE`2TDVP0MRaR09]OR@2GFhP0XVF;09YWU@21GJ00K3b507Q=
T@2GJ9T0ZWJJ0500202^B4T0^T4O0<=nQP80T3IC00T0U4]b08e5L@2@BgL0H00_08HkJ@2:=U/0SSUM
094fE01X9VP00P2@@VP01P1g:Ed0KRQV0640;@1004H0I`0009KHO@80[C<M00X0SejD07[R`02^`nT0
[/?Y044`U@060000[n[h01`0002KFX40VgFW0P1W00<00`1Q0000NGc9000000020<]UC00=0<nIWP2f
K7/0_6]b0?VfN03XYXP0nl>70=QhE@3TMbH0o<9o0000?@2>Q<@0?TVf03ITd`0203]Fa0080:>Jc02L
U/d0OFni0:Z2ZP2jU[80W7>S0?c;T03<[[/20<^R/0060<nS[03G/k@0elc>02Q1]`28GYX0EbYm0P24
OlD01`2SUlT0`/3H0<g4dP3=a=80f/K60;F?[`2kY/D00P2aVKh0402QX]H0Ti3=0:6Ic02Q]^L0R7k2
0;FG^02lV[@0eYjJ0>2g[P2l_m`0h[R[08iQV@31X;L0_Yni0=:ma@3Y^:820<:P]P040?O>X`3D/kP0
jNj=0;FI^P80aJ^o00X0]n^D06bko@0mS^h0]3/00?G^^02XQk80UjOR09lQ3`000000052`G`3oool0
0`000000oooo0?ooo`080?ooo`00203oool00`000000oooo0?ooo`0m0?ooo`80QN?h00`0oooo0000
002/RK00NgW60:QPN`2GK9l0`8BC02i@``00;K80000008lK8P2mT:L20=Cai@0305R^nP3oool0oooo
00H0oooo00H09@000<jHW03>V9`0^S<00?ooo`2j`Ch>0?ooo`030000EP1L]o`09ZgO0080oooo00@0
YiG30:2Yg@3oool0/5QS0P13HL/40?ooo`0^0:>6]@1]e:80KMBR08UES@2FIIH0OTV708UMV028G9P0
Tg:[09AaZ02:AWH0TVBH07QCV@2NNJT0RFZX06m2R`22CHT0PE^L09mhY`28JZT0OTAo07ToO@2<HYd0
Qe><0:9kZ02>L:`0RF6M095UV`1hD9H0O5FJ09U]W@2@JZ80Q62Q091^Y`2>LJh0L2MQ08]XY@2AK:D0
SE>708M?Q@2DJ9`0LCEe08aOV01fEj40R6:Q085AS`<08`0001L0VeUo0999L02;@Vh0Rd9^09U=K`1]
6Tl0OBA=06<4=P1U8fH0PRI;05`0=P1l6cl0D`0604D0001I02@0N1@h05H0:@2l]=40LT660:WFm`3O
U7h0300008XR>0020:]7B`040:Ll?00f[?80Jlgm0:oZn080S=;o00T0i^C?0<28V@1lGjL0UfbN01>B
i02Gd?`04i;T0<6ecP2=L:d00P31LG@0403;MV/0i8170=MT9P3;CP00ji9M0>f@8`0005L002fb02LV
V@0I7IL0I4FH06IX`@2SV/`0TfjU09NFd02WS;P206807`0@0;C6j03GaLT0fknl0<NgbP31Y[l0l;VF
00000024Jjh0NUZR07]KXP2>Pl<0PefM0:fG_`2eVkd0bk?20<^od080aJBh00X0`;3:0;VZb`2l/<h0
XJ;F09>@c@2RPK00WX2a08i_Z`2VNZ<0aZ6b0P2oOXd0103BQgh0MXOG000?W`2f]mX20=:ma@090>Vh
XP3W`Jl0YX6/0?O>X`3Q]:P0jNj=0:aLK`2k/m40d9>C00<0oooo00H0S9_M09bYg`36_=40/lo^0<gQ
i`00001P0?ooo`030000003oool0oooo00P0oooo00080?ooo`030000003oool0oooo03X0oooo00<0
F<We0?ooo`3oool00`3oool02`2QL9X0KT^H07]iaP35j^l000030?ooo`2dn^T0Wo?]052Gl@2`foH0
^_3d0080h>7E00<0hnkG07W4oP3oool0103oool00`1Qc?T0el[=06lYIP0209m<I@0408YNV02MEGL0
N3ek09J=a`L0oooo00<0=jo`0:[Bm@2Zd_D00`3oool00`21Chd0O4^<0?ooo`050?ooo`0309Z9`01Q
7f@0l?>Q00@0oooo0340001[0>3@b02BG8h0T5Z=095KS@2HK9h0XhBb081//P2mSJ80QTZ008=OX@2<
GYH0QERE0895O@2BGi80Vef6085OXP21Fi`0UV2?07I2P`28G9P0Qe^H09eiZ`2FM:X0QFNY08UKUP2;
H9X0SfVS08IKV02CM[00RFFR09aIO`2=GYH0VW>U09EdZ`22IJP0RV6M09M/WP20EiT0TfJK09AXW02J
LjH0TWB_09Qi[`22JZl0CSnO08m[YP2NMjL0WWFT0080>P0001H0VTi`08doI`27<UT0Q4Il08E1LP1Q
86D0NSml080lL02=CG`0Nceh06<JFP20;ET0BR5l09UIPP26B7d0OTZ80791QP2Jl^/0mZ570=nDOP2d
Jg`0XVfD0`2XKY006@2N<CD0UF6B07=]_@248Cl08`19091PU@1eDi`0UfbN06lZI`2PUl/0^nCc0<UN
@@1<I/`0WU]o0=J=PP3ORVX0i8170>61E03UV7P0lK:80>^BG@3cZSP002BV00006P1iGZL00P1nTmh0
101QVNl0UJ;M0524i01nR=<20;kk``040:S6k`2:Vmh0^9jn0?g9R@80`ZS000T0YnNB08eQVP1UAYT0
U7F]07aSZ`2TSK`0Zic70<2]a`39/<400P36Y[T01034YKX0]I2`0;R]cP2`Sk<20:^@^P0:07eh`P2K
LjD0/ZO>0:2Hb`32YK`0_J>n0<bib@3FXj80m;jC000RY`80a:Zo00X0ajVk0;nW`@3>WjL0ZG^Q0<b[
^03Q]:P0inC>03ZGlP2`]M`0>Kfo203oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
00P0oooo00080?ooo`030000003oool0oooo0480oooo00<0600/0<GZk`0000<0103oool00`28E8`0
oooo0?ooo`040?ooo`0809>3_P2231L0J`0006/0003>WJ@0S=5f07ec_@2]QJX20;G@kP060<kdW`2F
SLL0UXg70:?To03oool0c=gV3@3oool20>9d9P<0oooo00<0OSIZ0:EEK@3oool00P3oool01`2<FY40
oooo09]VU027Hj40RVFQ091JS@28FYH00`1>^oP0:02GKZ40UUb;09=QU01oEYL0Rf:L070iO@2=DXD0
T5nD08AHU`22EiH0QENC08aNU`1lDI<0R5^G09][VP1nCH`0QeZF08]OV@2?I9`0PEVJ08QESP1f>WT0
TgJ`09am/02@JZ<0TVbS08QGT@2:HI`0RV6M09=^Y024HZ@0RF2L089JVP2CKjH0TeR60891MP22BhD0
MUBM08m[YP2NMjL20:edT`80[VIm0180V4mc09QHP`23AG`0OD5k08e@P@1A0340F`0f08LXB01`4Cd0
K@L^00H0000l00P0D@000000003WYbH0002707I6RP2T?4<209YDNP0409U9J@2CBW40TdYa0:UON080
_G1g00/000000:F4/02EEX80^hfU09=ZX02GK9h0Vg>T0<Jgc00OY><0mJih0;BK_@0209ICO@0C0?;1
V`3IOV00fgmN0>FHN03`WBd0o;ET0?2A<P0004D0@4^f06^cnP00F<L0L:_e000>V`2HT<X0@IKb06P_
MP3>en00`=7W09JJe@0308k9o0090;_@jP000000MSn109A/X@2<GYL0PV>V09Z6_02jVkP0/ZC:0080
_jc700@0bkC40<Rib`2k[/d0/jC90P2WS[/00`2PQkT0Uk3Y07iMXP020:FOc`0309YcY@35VJ/0aIV[
0080cJ2Y00<0k=Fl0>b^SP2^f_H00`2SR[T01`3DeMX0mIho0;_OlP37bM`0inC>03ZGlP3N/B/02@3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00P0oooo00080?ooo`030000003oool0
oooo03D0oooo0P1E000:0?ooo`80i>kF00<0/GB>0?cTT@3oool02`3oool01@00?;h0Y3i708mFR02J
BFT0LbEK00D0oooo00P0cNAj0?ooo`3oool0oooo0<cMiP000900`?O^08h400@0oooo00<0:ZoQ08cV
n@2<i_T01@3oool00`0N00<0K;_m06bko@060?ooo`0309cBn`2HGHT0TV:F0080J;gm00`0?;W/089>
R@2=Eh`0TUJ508mIS02>GiH0T5jC08ADT@28G9L0U7F^07mJW@23FIP208mYXP0]0?^mEP2=KZX0P6:V
08IRXP2?HiX0RenH08UKU@1oFYd0QE6;08]NU`29JjX0SFBM089PXP26FID0S5F:07e8QP2IHi40W6JA
09=aZ@2BHiL0TVBI09=c[01`Ci/0SFJP06lhO02BIi`0QE^I09=VVP2QRkd0SW>_07QT[`1R00@0EP00
06H7=`1i@h80jIae05l0901j9U@0MSMd06TSH@1K0S/08P0209Q=L@0700D0>00d0080/EUS00<00000
08PR>P2?9cX00P2O>4<03`3IIAl0XUn10:9OP@2RGh40HCb>0>bWP`3:UYl0aIb^02H=N`1cFJH08`19
0:amX01]9V<0V4]]08i@P00209<_A00P0:ojeP3>W:<0cYbS0<^b`P3b`I/0dgQQ0>VCI@3PS6/0l9d]
0?cOW`3a/CX0o/EZ0:0T000dBKX001bS06=me`1]L<D0V93:046FlP2=CWl0c_oD0<3Ai`36Xk@0W<oj
0:kLm`2Ml?@0Rn[007Q?U02<J:@0REnJ089HV02AFhh20;BH^P0>0;fU`@2h[/l0]jK80;fJ]@2k[ld0
aZ:d0;JB/@2[S;D0/Hf_0:R=^026N;d0ZHZd0;2>/P2UWll20;fAZ@080=6TZP3G[Zh0cjZd0>RWRP3c
a9d0BHKX0?OTQ02a^=h20;WQl`050:fKa@2eioL0X_G[0:;ej`1lgZ/02P3oool00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo00L0oooo00070?ooo`030000003oool0oooo0440oooo00D0Qdb2
0>;IcP0I02D0oooo0?cTT@020?JkR`030<:Z`P1H]_`0oooo00<0oooo00@0R^Sd06O:o@1^^O`0K[Wl
0P3oool00`1oHJH0oooo0?ooo`050?ooo`0302fMl02:d?h0oooo0080oooo00<0002@0>c;/P3/bk80
2`3oool00`1naOh0Rm7o08_Ao`060?ooo`060<O/S02Ld_/0HBA/0:9aV`2:E8X0TEN70P2HK9d01`25
H9l0TVZQ08MQW`2=J:80TF^S08iVX02FMJ`00P1J`O/0:024HJ40PUjP0?6`QP251P00SFjZ09EYWP1o
HJD0QFFV08=LW02<Hih0UW2U08Q^[`27Jj`0RF^Z095[Y01iG:@0SFbX07mHVP2BIid0TfjV09E[W`2F
LZP0RfBP08MJUP25FIH0TEb?08IJU`2;JJH0PeVH0710Q`2>FHd0Se2006/SH028IjD0GQ]R06XVIP24
C8D0RC5F09XkD024G9`2078F@@0505@05`1J86d0D01105H05@2=k>d00P2kYL<01`000000TTE[0995
J`2UDFL0V3iI0;QQIP1a00H00P2nQYT00`2aRJ/0P]Go08;Eo`020?>OG@0309=CO`2=CWl0XV^B0080
XV^B00X0000A064LH02C<DL0bn_[0000I02DNK80^I6^0:9RQ@3FN5/0g:6E0P3VTFT02P00L/D0n[]B
0>f9=P3kfWT0oooo03]F``1]V>X02E7>03nJl`1`SMl20<FX_@0A07[@o`2P]NL0TJ;P0:C[nP21go/0
Qe><08Y;O@2?Hi/0SFZV08i/Y`2KPKD0Y9G50:jSc02ST<00_JG10<J^`P2l[ld00P2l/<h02`2hV;L0
/i6c0;>A/`2cV[h0T93?08b2``2<JJH0/:3709BSg`005jD0Z8B^0080b9RT00`0gZfS0>6fZ`3ca9d0
o]j?0?ooo`050000BJci00h0001jd?l0S^c_07CEo@28k=T;0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool0@03oool01`1nBhT0b]e]0=O]
R`3oool0Rd=`0?WTR02Qm>/0103oool00`0i0000:jcX02^/j00205;1n0030<NLZ`0=:JP0oooo00h0
oooo00<0002@0?ooo`00J[h0103oool204S0l@@0oooo0P2Dk_<00`28fOl0000K0?ooo`070?ooo`80
Rf:M00H0Tf2C09aXU02JK9`0WG:Q08QRX02EKjD208UMV00a09I[WP2HLJH0QEZH07mEUP2AJj<0S6VV
082>f03dXCT0E<?h09=XW@2<J:<0SF:L08=TYP2=JZH0RVRV09I`Y@20J:h0LeFP09A^Y@2<Lk80NEbT
09If[@1aF:H0UWBZ095f/@2GLjP0Sg6^08UXY`25Hj<0Sf^U099]Y@28Hj00Q6FV08EUYP24I:D0QV:R
07U8R@26J:T0K3Z207YEVP1YB9L0Q4b509]dYP24G9`0OCAX07<VG@1D4EX0OTAo06dbMP020:^0YP04
0:o8k@1o[O80[fj70;1iUP80/8:T00P0Fb1/09PnF@1b00l0M@000?ZlO@1MZOP01YK>05XDFP80Sd1V
0`0[0000202DCG@0@/CJ0=cm^`28DHP0?@1508i9M`000000cXB00`2fioH07`3<WJP0m/jS0>JgY@3V
TFT0m;B30?^bH@0LWn@0blM60?ooo`01:jl0@fSB07nDgP13Rn`0gfdH07?Jn02OdoX0PJob0:74l@30
hNl0P^7i08MCS02LKih0VW6S09I`YP2=KJT0TG:/09ek[@2SQ[H0[8ng0;ND/`2iXl<00P35Yk/01@31
Ykl0^Ifl0;ZO_@2gXlD0/ZK<0080XhZj0P2`X<L02@2ZgOT0Y:;C05Q_c`2VMil0b:Fe0=>TY`3CWil0
k[^M0=[DdP0D0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool01`3oool000L0oooo
00<000000?ooo`3oool0>03oool00`2TDFH0N3Qc08i;N@050?ooo`0507i;R@1k@X00RlWm08]3L02=
A6l00`3oool01@00Fl<0[]3b0?ooo`3K_kd0m;=000P0oooo00<0/iNj0:hj:P3oool01P3oool00`0N
05L0oooo0?ooo`070?ooo`<0Tn;m3`3oool01`2EK:40OM?o07gCo`2UOJP0SfNP099SV02?HIP00`2G
gOh0@02EKZ@0ODn?08iKT02:HI`0S6bX09=]Y02BLJ/0V7N]079JY`2>KJL0Rg2_08i`[027Jj`0SW:_
09Il]02DN[@0Q5^J08eSV`2EMZh0SFj[08I/[P29KZh0NEZR08QZZP2FL:D0MU^V08aJT@2=I9d0UG>Y
08QYZ@2DKjH0Sf^U08i]Z028H9d0QEjL08eYY@1kFZ40RfFP08EVY`1dD9T0F3N?08]JTP2KM:H0Q5FB
07E<T`2=Kj/0GRak09=TV02?LJ`0S7fn09_@nP1gD9L0ZH:Z0;2:[@2UP:`0e9^I02>[g@0dZ?80lZ5U
0:MEJP0_Y^l0n[am07/;802lHF0209T700060740002a9P00KPL[07TOBP0g03`0Ob]G0P3hihd03`1N
Vo404P150?Z_E@0006d0cXB00=F9O03fZ6T0bjbj0>:fZ@3Q]JT0k;^N0?kKUP3mfi`0nLiR00006`02
0?ooo`0305Q/c02YeOL0QJS[0080UjWS00<0C<Ca05P0001Me]P00P25?g402P2/Oj@0Uf^M0:1aW@2L
NZ`0PTb70:=YSP2LNZ`0ZX6Y0;NJ^P30Y[l20;VS``050<>V_032YKd0bJbm0;JZc@2dZLd00P2MR;`0
2`2ETLd0/:370;>QaP3Co=l0Pjc_09FEd@38YKD0/l_/0<[9f@3:[kh0k[^M01D0oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`070?ooo`001`3oool00`000000oooo0?ooo`0o0?ooo`80
E/RO0`3?e]lJ0?ooo`030000E`3oool0oooo0140oooo00<0R>Ci032ci00`/n@01@3oool0902>Fi00
REVC0:IlY@29FiH0UfNH095WWP2CJIl0SVFN09UcYP2CJZ00UG>Z06a7U02<HY`0Vf^I08Y][029I:80
SVJP08QRX02BLj`0TW:/06LcO@1nA800TUJ5095SV02CJZ00Qfb/08UYZ02=K:P0S6VV08mXXP2DMjl0
PeZI095_Z@2PNjX0NEfV09=PTP80W7f`01/0OEjS09A_Y@2KNZh0HCj@085DU028H9d0N5jX07Q;SP1c
B8h0REVB07=HY@1nFId0QEnN08Yb/P2?M[<0LDnJ04d?G`1c<6`0YWNO08R5b@26Q<X0001G0=7ocP2H
b?P0>5S708=UZ030MG`00`23>6T01@36X[@0[U9L0>jmX02L^nh0AP000080R00000D0]3/N0>=e8020
AX00MC1Z01L0?0020:A_UP060?SWS@39YkL0Thg90:i_RP3j[eD003Bh0P2eTk@02@3fZ6T0gJZQ0=JF
S`3MV8H0nL:>0?kKUP3mfi`0i=e[00006`020?ooo`0403=WeP00N]/0UIWE08000080jIhP00T0XE1Z
09ECO`0Q0000Xg>M0:YfV@2?HYP0UUf;0:MlY02ZUl800P2TR;L02@2gX/<0`Jc50<6/a@2kYL<0aKW?
0;jed@35Z[l0bJbm0;6WcP020;2SbP0909f8_02UZm/0UZKP07OLn03?]/40kYm^093QV@2AfOl0@L>m
01P0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`070?ooo`001`3oool00`000000
oooo0?ooo`0n0?ooo`0408??o`2?doh0Sm?n01jYe140oooo0P1ndOl20=[lfP0309g>n@3oool0oooo
00@0oooo00<0001G0=?mg@3oool06@3oool0B02;GIL0S5nH08mi]P2NNj`0U6nV08YTX02>Ij00QEfK
09Q^X02BM:h0SFJP08eRV`2>M;40VWN[091a[02=IIl0S6:K099/Y01gBhl0TF>H09F0^P26M[X0UGR`
08e]ZP28JZT0PVFY085NX@2@JJ<0Ug6V089PX`26I:<0PTf809m`W02RLY`0TGNb089^]02:K:X0W7f`
08Q/[@2IRL40MURR07YKXP2;Lk<0Tg2X08a_[@1jJ;<0P6bc07MV/P1mFil0RVZX08=SY@1oG9l0DAib
07YEVP1_@HT0TfRM04HLM`0VZND0FUnm0;nM2`33Zl80Y]n208mSV`2AJj@0M5FP09Ie[02mDT<0YaX0
064bP00005T0lIYH09YUT`<0XHNi00H0XV^C09CMR`120000DY7]05W5n@0000020<ZBV@060>7Yf02C
KJ<0O97L0?^aE`2ZNj00Yi_90P2[`NX04P3G_;l0a:6e0<BQ]@3Kj=d0n]I`0?gKW03TgF/0i_^i0?oo
o`2Ul_<0F@0e06d7;P2A?5d0WDm^0;ImUP24C8D0JC5h0;FH^P80Yg>I00D0Zg2@09igY`2NMjL0X7RV
0:UlXP020;6?/P060;>E]`2fXlH0_JO30;NP`@3:Z[T0]ZS;0P34[lH01039]<H0]J[>0;NhfP2V`N`2
0;RYb@0309F?b`2onl00oooo01`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`07
0?ooo`001`3oool00`000000oooo0?ooo`100?ooo`0309G6n03oool0oooo00808@0D00D0DEbo0?oo
o`1b;6L0oooo00005@0:0?ooo`0304`06@1B[_X0oooo00L0oooo00<0001G0?ooo`3oool06@3oool0
A02HKIl0WG2O09Y[V@2EIi/0TVRN08YNV@2AI9X0R66M08aSWP2FJId0VWJX09=VV`2DL:L0TfbR08YU
XP2LMZL0Vgb`08QZZ@1nHZP0Rf^Y09F0^P2>OK`0OfR_08ib[`2CMZl0P6BX0:5]UP1oK;<0S6:L0:5a
W01ZDJ80OH3<0:c:k`24I:H0VW^_07AP[@2FLJL0YHZh06mL[02HJIX0PeNF099f/021JJh0MebV07Q/
^029KZd0OFF]085]/`1VGK@0PfR/07YMY@20HJH0KUBS06QEZ@0W8YD0HDRN0000000<05L0FUnm04LT
PP000740L@070<BY_P23AG/0LCb00:aZQ@2ZJhP000000P1S00002P2;FI40Wa<009B0^`3NfF@0YK?R
0:9[T`3IYj@0002207X?:P0005D308l500040910I@1l7D<0UcQ>0?^aE`80P04200X0>Dbj0?_TY@2k
Xl40^KWI0:^mi`3Kj=d0dOoA0?gKW03TgF/000000`1J01D02P2I:Bl0YE1U0:E@I@2PBf@0Md200:5<
I02eV;X0WgBQ09U_XP2cS[020:9fX@80WX>f00H0Z8B^0;jK]02hV[T0a:2d0;jM]`2fXL<20<6L/P08
0<FY_P2[PZP0]kWK0=2g`@2ib>H0/L_]09nok`2/k?TO0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool0?`3oool20;Z6W@0309k8m@2VDF@0
7P000080k9ea00@0Xlog05h0<`2Ek_<0UNkc<03oool08@2TNjH0VFnQ095VW02OLj40R5^G095SV02F
Jil0XGFR089X[02FLJL0Rf^X09=^YP2?J:80OefQ08eJT02LMZL0SW^j08If^P1hHjh0TWJ_09ao/`2>
NKL0SVn[08I^/02;LK00QV^]0:V:]@1B;HD0SF6I09QYVP2URKL0T7fj0828dP020:BB``0409fCb@25
NKh0MUfX08I/[@80Z8bh0180IDZN08e`[@2@Ljh0K5nb09Aj]01kHJT0Q6JY07AO[01bHK00HTRM06I;
WP1`Ai40MeVS028LT00e>JP07@1N03H^VP1F@il204W1lP0609aHO@2OFWd0m;>409YbY02/QZ`0ZV^8
0P2400004`2P<300GP000?RfN`1U]o`07jSJ001Dc@1/HK@0QX;70;98@02oZlD0001E08MJU@2[;aP0
nZeN09HL5P37SIH0UH6k0<=dM`39_<h00P2aO9X0402<FY40X]am0<:U_03]e[`0imG40?kAM@3/kl`0
OUVM03l0001K0300MA<i0:QCI`2]KXX0TEF507PUE@1nIJ`20;n;WP0=0:mmWP2YOZH0Xh:_0:MnY`2W
O:@0YWnY0:iiV02_RZl0Z8Ja0;VD/@2hTk40`jJl0<FY_@020;n`b`030;f_c03=a=40^]W`0080^]W`
00<0`^ka07cUj`3oool0803oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00L0oooo
00070?ooo`030000003oool0oooo03l0oooo0P2kPYH01`0Z0000;J7`07]3P@0C0000;00006/aMP1`
S=h02@3oool00`20D8h0oooo0?ooo`0V0?ooo`0L09I]X@2OMjH0TFbS08mZY02BKJD0Vg>U099aZP2:
FI80SefB08]ZY`2KLJ80UG:X09AbZ@2DM:`0WX>f09R4^`23HZD0RVJT09b6^`24K[80Qg2b09E]XP2S
P[40W7ja08I][P24Jjh0He>[095[X`80a;7802<0V9C>09R<a01^O]<0LgO705T@E02nS:40S6f[08io
_`1jL[h0Rgbm07]EVP2CO;L0V8Fn08am_P1/Gk80JdB@08iYY01lFIh0MeFM07eEV02?FXh0FDJQ07EL
Z01RCjH0F4bX06MG[01CBZX0AdN^0311/`0007/0XfnH0:j</@1Lbid0m;>40;V@[@0206ieb@0?0:IL
N03B/KP0/DmA0;5?D@1QKlX0Vi?:0=Rk_@1E0000_L?O0<S5e`2Xn>80cOgQ09UHP@2`HW<0UDY_0080
ILOm0P2J=dL00`2gdnl0Sf:I09ebX@0206jmo@080:;LO@3@cML0d<gG0=?Gf`3ndGD0i?NT0?WAW`1d
11h209lc=`0A0:eKK@2[G700[gNE0;B?[`2BMJl0UHK10:b1Y@2^PZH0WfjJ0;66Z02VOJL0UFBF0:Ea
U`2YOjL0/XFT0;jN^02gVk/00P2mW[T20<jga0050<bmc031eNT0`MGY0<SJi`2[k_P0903oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo00L0oooo00060?ooo`030000003oool0oooo0400
oooo0P2QV</@0?ooo`03081@SP3oool0oooo00@0oooo00@0Fl7l0578k`1Ab>l0DLS_1P3oool00`2m
Uk00Mm3o07O@o`020?ooo`0308UJT`3oool0oooo00P0oooo0`2Hd?/50?ooo`0=09I]X@2OMjH0TFbS
09QbYP2QMJ40VG:U099^YP2=JJD0V7>X09YdYP2DL:L0YGNQ095f/00209=c[00e09MaYP2<GYL0Wgf^
08mb[`1H<8D0QUJA09MZW02SP[40VWJY08EWZ@2XNIl0Q7Rn06mR/`1MP]h0TW2X08UYZ03[nL@0^65W
08]f]P14Dkd0W:CK0::_h@2NP[@0HUVb05UXa`0`>:T0QEJB09Y/W01mEYT0Q5RF06i<V01cEj80HD6E
08eTWP1bHJl0NU^S06Y=WP26K:h0F4BO06LfPP13<IH0T5nD00LDU00D48T01@1?0:=_V00o03<0001N
0?BcQ01mdHD0bH`00000L@1gAh/00P2Z>2h0103>YJl06Dk80>3[Q@3KgV`20840000705bBj`2iaN<0
^LGS072;g@3;T9L0H=3e0000B00201BQdP0709Mh[P2JEW`0Ml[o07O:o`1f@840Pcia0=G/i0020=kL
e0080;o_lP3ndGD0`gh008XD701]00D0_fa_0:4^:@2nH5/20<idH`0=0;^0U01^Cid0TUjA09]LQ02X
J8P0YfR80;9kU`2SKiL0[GJF0:f9[`2/R:l0]YFd0;jI/@030;nV`0060=K5b@31/ld0fLo?0=_/g`2l
oM4000009@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00H0oooo00060?ooo`03
0000003oool0oooo05X0oooo00<0>YGa0?ooo`3oool00P3oool00`0N06d0oooo0?ooo`0I0?ooo`0J
09]eY`2MMZL0S6^W0:9kZ02IOK<0TFjW08eQV@2FKj<0S6NS0:]nXP21HJ@0Ug:W091VWP23F9L0U6JI
08iOU`2JLJ80Xgf[08EVY`1^Gk40TGRc08][Z02WNj@0OF^c05HmV@3[WgT209=<M00U08Qc]@0ML>00
YMgk0:GMn`2R^NT0Uhg605MogP2VXm<0SW2/07=MZ`2DQ;l0FFS709JLe`2<S<h0JfVn07mJW@2CLJX0
CZ3f0:1]U`1bH:l0T7B_08]QW02HNk00J3Am06mR/`1:56P0@11[07PnO01_CIT0RDn40000BP1CH<80
F@0009QbYP2?Ij00O@000<C6g0020:Lh=00707M7R`2M3000W@`00000I01SPm`006?40;MoU`020<Qc
K@030>:i[P3n_V`0RlGk0080RlGk00D0V=Wm0000B02G=4L0TWB^08MRX@0206`dN@060;NO`02WKY40
CK_h04fkn0000000hnSE0P0000001033OP00T@h009l_<@2oK6l20<5bMP070<MoPP2_L8/0[g2;07L0
002XJ8L0ZgFF0:9n[0020;:?/@050:n2Y02jTJ`0[HV_0:b8[`2gUKD00P32Z;l20<F^``80cJ2Y00<0
f<o@0=gSf@3EolX09P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00H0oooo0006
0?ooo`030000003oool0oooo04@0oooo00<0_nbA0?ooo`3i_hP04P3oool0101oNlD0>YGa02h0001J
a_T209E1H@030?JnS`2ah_P0oooo01T0oooo01L0W7:R0:1eX`2CK:<0VWJZ09YaXP2CL:P0RVVW08=R
Y02LLj@0[HN/099[XP2DK:40NeNL09UOR`2MMZH0S6VU09i_V`2GJ9T0T6:H09QaY@28M[P0YYO6099h
/`0204REl@0409mfY02E`_H0UL;f088UB080/[KK02L0YgbT0::=_P2[T[d0SXc=06]I[02MNjd0VGR]
08el^`1oJ[40UYcG08]k_022MK/0Pgo708j<c02DYn<0Q/;k05inf`0eImD0Rf6L05@UN01U?8/0501@
08Qi_015B[80F3^C06m=V@2?GiD0CSVI08j8b@2POjl0000/08A3N02^Z]@02Sfm09=[XP1bDI/0MdN;
09=[X@2LXMP00P2Rk?T03@2:IJ4005OA08oCoP2?doh0SUbB07iBTP2Qm^<0@A9^095BP03NhmP00018
0;ZN^`3_Sbd00P2fS:X02@1/=7T0MR]P000@X03>bmL0ON7f0000003QiMH000000=gQf0020;=2<`03
0;]MF`30IF40^eM=0080^eM=00/0Ze5N0<R>U`2aP9l0/H2O0;V6WP2UMYl0]86M0;F=[02_RZh0/hVY
0;fM^0020;6E^P070<:Z`P32Z;l0^9fl0<Fjd03@_/T0gnkK0=[Tg00X0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool01P3oool000H0oooo00<000000?ooo`3oool0@@3oool202j_j004
04@0001]eOT0KMGi0?VoR140oooo00@0b[k?0;0Y002[FF`0ZeU/0`3oool00`0N06d0oooo0?ooo`0I
0?ooo`0:0:AkYP2NMZH0Qe::09aQRP2KIY<0Z8>/07mMXP2KO[<0PFBX089BS`80YM7g01T0Caea0:n=
/P2@NKH0_c/0091[X`2YQk00V7bc08E`/`2LOk<0R62M07QDV`2aMi<0XYkA0=Kai01]]?X0UL;f088U
B01^UnP0M9g[06aO/P31V:d0YXFa05mI/`2@MK40T8G40080WIO=00T0ViK>07b5dP2;OKh0U8g9096A
c`23Pl/0N8SG0:VMbP2FZ>800P2KPkT0201:C;40J52S0714S@28NK`0BeJl05]I]P0h8HP0001k0P1X
LLP09P3Bo]/000F808f/jP2@Xn40jj^:07a=SP1Y;740ai>P09Yj[P23CXP0MdZ?0;jJ20000000nnJS
0;lk002ZRK80`6e_0<bJX`1]8EX0ScmU0<;SNP3fXT00S3II00li^02_G6`0O0XO05`?D03BZ:l0[ik7
09R]iP3>bmL0000009acX`2dTK<0000h0?N`M020BhL0VCE60P2dB3h00`281`00]e1:0;]=>P020<b;
S@070;UhR`2nOH/0`gb40:EfW`2dPId0[GJF0;Z0U0020;N:YP80`Y>U00L0bJZk0>:VU035^]00aK[@
0=Wmf03Qo;T0000002P0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`060?ooo`00
1P3oool00`000000oooo0?ooo`100?ooo`0604<0D@2<BGP0Ilcl06O<o00S[/h0GCV>0P2DFHP207[G
V0L0oooo00D007_80000702TeOT0BJSh08CRnP020?ooo`0305803@3;gNH0bmgV0200oooo00d0TlOj
07HiM`2RGh40Wg2L0:b3Z02TNZD0TEf@08QGT@2;FY40XHFf06Q[``2HMZ/0^8VT0080gm[B00H0_c/0
0:;_/02eRJL0Z82Y07]W/@2PMjD20000000909Q1G@0M01h0Tf>F07UY]01dI[@0YhF`0;NA[`28Z>X0
[Yg60080V97;01T0Xh>b09FNfP1V;gL0GW;>09fGc@2KU/h0JhCJ08^[j`1@V_<0NJ?]08VWj02@/nh0
MZ_d08b?d@2@W=/0N8oM0;nZa@1VM<d0KG[?07U/]`1UEJ/0<Qn:05ldQ@1@AZL0QXoD0080e?cN0140
AaM_09oNo@1TA9H02@1/09eXT`2>G980^FE[08=_/`0Z0000[B400;jJ202janD0nnJS0:Z9/P009k40
00110?gPWP020;G`mP030<;SNP2lNHP0S5ZA0080000000/0G0m@0:8c<`3BZ:l0d;Fo000@X02edE`0
lJA^0?oAR03nd90005Jk08T80@0208XhG`080;0m;`2`?c80cWY_0<ijK`3HSh80hH=H0=FBRP33RiX2
0:i^R@80_7V800<0_X^O0;28Z`2nV[<00P30WK@01`37UjD0aIJV0>:VU03LdLd0mnJd0=[[g`3Ikn40
:@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00H0oooo00060?ooo`030000003o
ool0oooo03l0oooo00<0IR5Q07SRkP11a=400`3oool00`3aZg`0L6bn071/_P0:0?ooo`030000003o
ool0oooo00/0oooo00<0OTn?0?ooo`3oool0103oool20633oA80oooo01l0KCQn09a`X02bR:T0UW:X
0:EaU`2NJiH0WWFT09mo/02KPKH0XHFf09^1]@2MUld0OXC?09J7`@22Z>d009>l0:;_/02^Y<d0SgB`
0:FKb`2FW]T0YJkN08F8c`2=S<d0`:k709=SUP2RY=L0JHGK0::Ea`2^Ukh0IFc50080[Z7:00<0V97;
06e?WP24HZ<00P39/<40202@dOh0UMWn01fLi`0MW>L0Llko06G?nP0UZ>H0KM?j0P3oool01P2@W=/0
Dj[i05>Zn@1VM<d0OiGO000X/P80MGK600P0Bd:V020@PP3HK3X0jJV<06/LE@1B1D/0nkal03Big@80
[7jQ00H0LiWX09Al]@2FVMD0UYWE0:dQ001n42D20<I^IP060:Z9/P1A000000110?gPWP2jKg`007?8
0P1lhOH20<QoP0070:OTS@2ZYM80ZZGB00l0J@30HEX0ZJWF0=O6b@0209^Yh0040?k@T01O0000G`00
0;MTK@80_fmd00h0e8Mj0=YlF@3__ih0ikNR0>NNO@3GW9L0_gN10;N4WP2lR9d0]GR?0;n1T@2nPI40
^9:_0;nE[080`9fd00H0aZ^n0=:c^P3B/kX0g=7=0?OV]03YjlhZ0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool01P3oool000H0oooo00<000000?ooo`3oool0@03oool01@2mcnP0oooo
0?ooo`3oool0000<01/0oooo0P0o[oD00`21e?l0oooo0?ooo`0F0?ooo`0:07YW/@2OPK<0Z86Z0:>5
/`2BN[D0RE6609U_X@22@WT0Uf^L09^0]@80^I>`00D0K6>g09Am]`2SQ[H0Lg[;0:BFa`0209ik[008
08QPW@2YNYl0Y7JO08UHTP2PZMd0/:oG0000RP3:U9d20;c@j@80Y9C400/0Ti?A0:BLcP2M[N80Oi[S
06e?WP009:`0]MC`09W`k`1kdol0oooo0000000:0?ooo`0=03U[f00fQ^/0JXWO041`f@1A9gh00001
05a4W02`N9D0dYFD0:4a<@2G=DT0gYF102X00002000000090:B>_P2NVm00QI?I0:VKb03<[[`0M6^j
09Qf[03k_7`0P4Z60080oN2N00`0OLgo0;YoU03iZED0001]0?R[H`2bc>d0El_c00X00031JVT0V:?M
0>n@;03Mem420000000D07SM[@2[MiT0ZgNI0<>BY02/PZL0`G^40<f@U03KRG40dFmC0?kJV03jaXl0
eJj`0<F4S03>UYX0]hBN0;fH/P2gU;<0]XfZ0<6AY030Vk820<BM/0030=6c_03W^:D0f;Ri0080jm:k
00<0mnJd0?ooo`3oool09P3oool400000640oooo00<000000?ooo`3oool01P3oool000H0oooo00<0
00000?ooo`3oool0@`3oool209GWn`@0oooo0`1j00000`16/OP0oooo0?ooo`040?ooo`030<S7f@3o
ool0oooo00d0oooo00<0KmFQ0?ooo`3oool03`3oool209;/l`@0oooo01@03@1J0;B6Y012;I80WW2M
06XfOP2VQk@0PT9i0:>=_@1A03d0]6Uj0;ifP01`95`0NbiQ09U]WP2IJ9T0S6n]0:5o[P2QOJ`0WW^/
0:>2[`80`KK?00D0U:3L0862b`2/PZL0[8:W0:BB`P020000000607jZl01IU>d0Eicb0:]]RP000000
HHSR1P3oool00`000000oooo0?ooo`0:0?ooo`0C00@0F@1TDJL0Fefk08EUYP2JMZP0LV^l0:UGK02Q
?TT0/DDm0<V3Q@2DRlP0QH;804/EJ@36`MH0H7gI08VIg@2QY=L0ak_>00008`02002>]P040<JW^`3Z
l<h0o;ef0:@l@P80kOJW00h0B;[f0:WBmP1WbOd0IlWm0?;0W031JVT0/8fb0;>YcP009Jl0/jW>0>Ga
U02jF540^U960;QhS080Zf5h00L0_h6?0=RKU@3MRg40i8m[0?kJV03^`:80djFX0080_8JK00h0`8:@
0<RAW02iSJP0^i>^0<>I[@2jSJH0`8nR0;nEZ`3?X:H0ikRU0>7;``3Me]00jm:k0>WZQR80oooo1P00
00040?ooo`800000G`3oool00`000000oooo0?ooo`060?ooo`001@3oool00`000000oooo0?ooo`11
0?ooo`030:]8C@3<[B40oooo00D0oooo00@0MRYP0000000000000@001`3oool01038amT07@0001d0
001Id>`;0?ooo`030;>Vb`1_eJ40oooo01H0oooo00X07AV?09MST`2b`ND0//7U0:J7]01bJ;P0`;K@
04Q;/P1V:g40dYjP0`2AMk80502lV;80F0000::Qd`2BKZD0TF:G0:BUe`2SPZl0[lk`09iEMP2_OYh0
Fb=`0;aLF03Ge=H0Y9;2087Do`26bOh0Ymcj04E]eP29[Nd0Ngg9203oool00`000000oooo0?ooo`0;
0?ooo`0:06EF[00l>jL0001=0;CGlP1];6`0HRQa09UFOP24DH`0MdJ909B;b080Q6Z]00@0T66G0<ZH
XP3:V:80Q6:S0`2d]m/02P1P__d0PdR108=8P@2bD540GEnl09i;I@1iAXL0C`0[091RV02<:T@20:V7
/00:0912J@3E/;@0bkK5000U[`3nfiP0Zh:Y0;>7Y`00Rkd0W?CV0;ULG080`7f800H0WV:90<bS[`3_
dEd0o]ZH0=RVX`38Uj@20;n6V00=0<NFX`32RYT0`HVI0<69V@33RYP0^i>^0<nV[P3</L00e[Fh0=o9
``3Qbl<0il^k0?3R`00L0?ooo`L00000303oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo00H0oooo00050?ooo`030000003oool0oooo0440oooo00<0VJ3I056nn01A__P0>@3oool308[C
o`<0aiBP00L0MDB8099PU03BWZ00=S>Q09Y^W`2CN;80PeBA00<0000000d0Sm[o0;[?jP2ib>H0Q5:=
03iZe@1]J;`0]OcK0;9O002^lJ/0?XW/07aLXP2kh?80dIfO0080Wlgg2@3oool00`000000oooo0?oo
o`0;0?ooo`0b04nIlP0007`0Vh6f08mf/P2e]mX0QeNA07QLY@24DH`0kZX`000^X01CD;40bL7B09B_
j@1MUNd0]joA0??b^`2BHYH000000>V_U@3obgL0eI280;^5VP28EXl0LZ;_07U6Q`1VFJh0NWo=0;j1
T@2>P/80R8S=0=GhZ02aIGP0eK2d08j[j@3nfiP0UF^O09j9_P2eV[`0VfNE0:A_UP3@Yjl0f;>c0;RM
_@2094X0hI`F0>Z;C@34[L@0eJJW0=>PX@36Y;L20;nDZP040;f=XP2jPYP0^X:H0<>CY080a9JX00D0
fIfF0>Bk[03d_Y@0ikVU0??S^`0G0?ooo`H00000503oool2000005`0oooo00<000000?ooo`3oool0
1P3oool000D0oooo00<000000?ooo`3oool0@@3oool00`3al[l0o/IW0?ooo`0L0?ooo`0309QSTP3o
ool0oooo0180oooo00<0K]Gj0?ooo`3oool0103oool03@0n03d0[GBC05LmV028CX@0/72:08eFRP1/
0RD0MebV0:nK`P2nXK`0FcjF0:2;_P2=U=H00P2/RK002P28R/l0Ui3:0>^9@P37EC40kYm_09N<aP2k
/M00J[Kl0>KIb@0000020?ooo`0306NVm02Jj_X0Sg>_00@0oooo00<0HaIC0?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`040000?@000980Uh2i04lNL`80U8_700@0^Jo@0<nka`2>0000000I
0P3>d=/209bmk`030000502>@V/0Ud1K0080U3eK0P2UXm<30<bnc@0306II[P2Fa_L0[]Gd0080[]Gd
00T0_XFF0;1TM`1K00l00029000000262PX0EP0008`lI02fIg<00P2lQ9P0302hOiD0[9_60;N:YP3Q
W1H0j^j?0=BMW03FXZ40cj2W0<JCX@34TJ00`iFW0<2DZ@80]XVV00P0`i>T0<BCY02mX[d0fjVR0=;2
b@3d_Y@0jMW50??S^a00oooo1`00000L0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool01@3oool000D0oooo00<000000?ooo`3oool0H03oool01@2HHi80Z_G`0?ooo`3oool0?19b0140
oooo00<0QUJ@0?ooo`3oool00P3oool02P2YLI<0/hZZ0;>:ZP1P?i<0R4j40;1`RP2gNHl0QdYn0;fW
``2_Vl<2069nf@070:2;_P3k^74004>T07Q8R`28R/l0N]On02A_g`020:O0k0040<2_b@0nJ]D0?JCf
0<:6U0L0oooo00@0QVVZ08hfE`17aKH0AlFf1P3oool00`000000oooo0?ooo`0=0?ooo`0>0000TP2:
FiD0Pg[008n2`@2g<@00B:Cg0<nka`2mCST0VIG>0=1M;037LF`0UHk:0>oCH01S=8820;bI]0050:HU
203obgL0]mG_03Nmd`3QoLL00P3Si=<01@2<EHT0WYO<0>?Ud`000000mjma0080000000D0e:NY02h0
6`2;EX`0SeV<0:1hYP020:IcVP0>0:UkXP2nJ6P0_VQX0<bLY@2gRZH0S>6N0>:]9`3AZK00cjfg0<nP
Y`34UJD0b9ZW0<:DY`2jRZ<20;f<XP070<>O]03B[[D0b;S;0<Rhb`3B`/T0gL?00?G9W`0:0?ooo`L0
0000903oool2000005X0oooo00<000000?ooo`3oool01@3oool000D0oooo00<000000?ooo`3oool0
CP3oool207059PX0oooo00<0T5fB0?ooo`3oool00P3oool00`3_kLD0L4690?ooo`020?ooo`0303`B
LP3oool0oooo00l0oooo00<0VVFC0<j[]P3>ZkH00P3oool20:O?m00409@1002KWmL0VWFW0;B?/080
d;S300h0=CJT0:a5A@2/ADD0HWkI0<3nf039dn8004>T04Vlm@2MW]D0OWW30>^9@P1^fo80MlGo0340
@P807:OD00H0Tm5`0?ooo`3Tfld0i=_=0?ooo`2J__8<0?ooo`80U:kX3@3oool04P1WYoH000000697
W01iN/P0UJ3L08_7o018Y?L0_eiE05P03P3h/gT0[9g8081V[02ES/X0/?6Z08^6b01gNl/0X6:80:HU
2080EP0001l0^o7c07D`JP1`T>80`hND09X:002NUl`0hnGC0;[Tl`0a0000XLGb02IAa`27JJT0TFVQ
0;6K`@2TSkl0X7RV0:AjY@2oW;@0WHVm0;b>YP2Cc_`0mZ9@0?gPV`3mchl0jKn[0>JgY@3?[KL0^:;3
0:FHb03<WJH0`I:U0080]XFQ00P0cZ6Y0<NN[P3B[[D0d<7<0>RjY@3ReLX0h]?70?G9W`@0oooo1P00
000]0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool000D0oooo00<00000
0?ooo`3oool0M`3oool00`0k_N<0gocD0?ooo`020?ooo`0309BKf01XQM`0]YVj0080]YVj00@0X[7S
02/3J@2LXmX0]o3d0P1lc_l02P2941<0_Og>0:nPb03?/;/0c92E0<30fP24[_00CI;_0??cZ`32FdX2
000000040<bb`02[EVL09g3O0>Gl_Ph0oooo00<000000?ooo`3oool03@3oool00`3a`Yh0PUnR0?;L
^@020:boi`80VM7k0P2L[^@0203Me<l0]fMc0;o>D`2]:@00E`0000000037Vj/0eJna0P38/L@01@2J
j?/0Z:KD0:O3kP2W`nh0Z1X00080/m3^01D0X>Kl02@00P2?8Bl0P`T@079HY@29KZh0XGRV099RUP2P
N:H0Y7ZU0;nL]02MRKd0gh]]0<fR[03Xl9@0`Y^`0?C6W`3_`Z<0d:nh0>Z?F03OPEP00P1oOlT0202h
MhX0a9:R0<BBXP3GXZ00g[bg0=^o_@3L[ZP0g/Bn1`00000d0?ooo`800000E`3oool00`000000oooo
0?ooo`050?ooo`001@3oool00`000000oooo0?ooo`140?ooo`04002?``25j>h0000008GXkR40oooo
00<0000<0?ooo`3oool03@3oool0502<EX`0oooo0?ooo`3oool0000005^9i@23HJ<0kkFA0<CNL@29
Hj00Y:WJ0:WJn027YnX0Ri?F0<6]a@0006P0ck2k0>GdW@2Rlkl000000P3oool01@3clj/0oooo0?oo
o`0003d0gOCM0140oooo00<000000?ooo`3oool03@3oool0300007<001BQ0=6_^03A[kP0BKge03^]
m03<g>D0S7bl07OQk`3Me<l0PhS@099QU080Tlkl00L0G[?k08C;oP2]U;`0`YBW0<Raa025T]T0[M[g
0080fXUc00<000000;IKG`2fFel00P1[0000203CcmD0DP0j08]/Z@2=Kj/0Tf^Q0:5dX@2jX/40ZY[6
0P31[<D03@2>c?d0jZ5m0<:K/03`^980m<JO0>o5YP3@[kP0a:Nl0=n1F02WDVD0ZXRa0;VB[P33X[P0
1P0000020>K3/c/0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`050?ooo`001@3o
ool00`000000oooo0?ooo`150?ooo`0302L0@@3oool0oooo0200oooo00<0m?2i0?2]P`3oool01`3o
ool00`3c/840Gkcm0?ooo`090?ooo`0:09N=b013Ak00kkFA07VAg`25NKh0/INm076=g`2V/N00UMon
001?/080XY;400<0M4F;0?ooo`3oool00P3oool0103H_;h0oooo0?ooo`1f<fl=0?ooo`<0D<;f00@0
J[gm0?ooo`000000jK^U3P3oool03`1[00@0332`09F>bP38QX/0o/9g0:k6k02Cdod0/i:c0<?Pk@39
QXX0RjGV0<iaG@0kX?@0`[[C0:WWnP030:fD_00706d0003Tb[d0000008C2n`000000]/GU07SHWP02
0;MjT@0A0;mEA02/7`00TEb?06ZUl`2IXm`0V:3J08f@d@11^_00dO?W09MUUP34YKX0T8K50:BA`P3@
/;T0l;RB0>nlW03GXIh01`0000002036Y;L0c:Jc0=>GU@3RVX40gkni0<ZFW`3V`[40n>fZ?03oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00D0oooo00040?ooo`030000003oool0oooo
06@0oooo0`29G9L0103oool0hL[10<30f@30`=TE0?ooo`06084J=`0007l0001o0:VRc`1C^oX0a_3_
1@3oool206_8oQ@0oooo00<0LISX0?ooo`3oool00P3oool00`2YQ:d0jK^U0?ooo`080?ooo`0804L0
000/0000KP0B0:5;HP1f6T@0B`000000002ES/X209WTo@80PN?e00H0hM;80;bbd01KM=<0<00005O;
l`1Rf=D206800080/92d00l0=kcI002<cP1S:g@0/lWZ096nm@2ghgl0TKke08oMoP0R@[X0^5h00;Te
00230000dET00;K7i`3c_I<00P2Jd?/0102[X/l0_Jk;0;f^b`37]LP6000000040>2XV`37PhP0d9^O
0:iKJ`80bGUd00P0a9FV0<jHWP3D[k<0cjnj0=jo^@3BUiD0bYJO0?[TRSh0oooo0P00001C0?ooo`03
0000003oool0oooo00D0oooo00040?ooo`030000003oool0oooo05D0oooo00@0_HfT0=cId`3LfM<0
g=WC2P3oool200800080^5aN0P1mY>`00`3dl;T0oooo0?ooo`0C0?ooo`030;2I`02?Okh0S6n^0080
`i^_00<0Kkcm0000R03oool01@3oool00`2=VMX0oooo0?ooo`070?ooo`<01YS61`3oool00`1oG:00
oooo0?ooo`020?ooo`0309cBn`000000oooo0080oooo0P0m`=/208H3000403/000000000F`0006L0
0080P@L>00l0E00009QHPP1^00`0I`0N07469P0I000003N_0;bH/P2RFGP0QHkE03iZe@1^01/0L:Kb
03R5jP3RkML00P2PV<`02P1D00D0SDQf0;OUmP00E/P0a;360:;Dn@3`TCX0I`070:Hd;`1beoX205Nn
n`040;Ln7`33A@h0hY=d0>R1:@L000000P30cnD0203BZ[40UjOQ0>ZaUP3VYhh0agam0=://P3GSX40
_Ibg0P2jPIH0203<TIP0eYVC0=B_/`38X:l0kjf40<nU[P3_VEh0n^B:@03oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo00D0oooo00040?ooo`030000003oool0oooo05D0oooo0P2?cOd0
0`1bdod0oooo0?ooo`090?ooo`030:Rgi03oool0oooo01/0oooo00<0DY7]0;>9ZP0d[?000P2OdoX0
0`2HcOX0oooo0?ooo`070?ooo`<0AK7g1@3oool20:_@m0@0oooo00L0KD290?ooo`3oool0;;CF06oM
k0130000H@000080Q0D500T0KP0606/0001G0000GP0007`0001m10l0VS0j084B9@2H<D000P2?9CL2
08LL<00;09DlF@2HF880OQTg08a0JP26@gH0OcU]09M>L`279T@03P0007lI=P1G00000P234R<01P1`
?XD0B@000880002n]]80O<7m06_?o080Ze]^00@0TFjW085DU02cUk/0QJCX0P3IhM`60000000=0?NU
EP3<Q`00oooo0:Ffi03CYJL0F;_l000X[028PlL0^Ybi0;Fde`3CYZX0dY:>0=NUY0020<b4P`080=N>
P@2iRZ@0^HZT0;N4WP38S9@0eYJ?0>BYUP38X:l20=5aF@030>S<^P39eUl0oooo0400oooo0P00001@
0?ooo`030000003oool0oooo00D0oooo00040?ooo`030000003oool0oooo06T0oooo0P0UW>d00`2i
<P0000N@0?ooo`0:0?ooo`80@KCd0P1^gNX01P3oool0mKN70?ooo`3oool0/:C<08n8b0d0oooo0P3C
UiD50?ooo`0>08CBOP0GWmh0eN_T0=G[i01fDYT0I@0?06/0401T0000KD2906L01@1T00<0AP0008/J
9`236cD309/nE00?08hU=`28:4H0OTR507jWkP3dWcT0SHO809m3E`2273T0VG6T07QJX`2@:Sh0S2U3
088VBP2G@5`0JP0C0080QAT^0100H@0[08HXBP1J0100P1H^0:=HL`000000[XR]09CHoP2U:AL0MP0>
0<bX]01QUnd0Sj;Q0;RngP36Z[h0[G>A1`0000002@2aDeP0]7F<0;MjS`39RHl0fV``0=QT903odHL0
hhL<02BSj@020:3[nP0404`0003:M6/0VI390;B^dP80]9bo00H0eZj_0<2T_@2dKX40]6j10<eoN@2e
FEh20<B0R0070<f=T03WZi80g[^d0?C;X`36Y;H0e/C80>S<^P140?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0103oool000@0oooo00<000000?ooo`3oool0@03oool206h02@03083O
nP3oool0oooo01/0oooo00<0[;CN0:cii@0c^]801@3oool01@2DGi40QUJB07]=S`1g@X<0RU:800@0
oooo00<0^ibh0:4B003oool01`3oool01P0007h0HgC?0?FgQ`3oool000000;2Tc0h0oooo0P0[W>l0
3@3oool0001f077>oP1ac_h0bKC509EPT@25Dhd0D5Nk0;Xb0029Ql/0I00104P0000400000P2:4QL0
2P000000HBej0:aUO`1W00H0<P0007H0001B000002^b08@61`2^LXl20;Z=YP0=08f7b01i32D0S5V@
08//BP2>;d/0WCQ408/cEP2G@5`0[65h08DoL@1f6D<0I@Tk00@01@02042nj@060;?5j00f26P0KE^]
0:j8[@1ab?l0W?CJ1`000000300LWNH0YkCS0:/W002DLZT0W6VG09eSS@3BO6`0/e]S0<m^E`1gP<l0
`h290?2hU080oKQU00`0n<=E0000003oool0[9Jo0>^jX@3@VId0VI390:fRc@1oLKX0`Z:i0=NYZ030
Y;d20;Z2V@090<^9R`2jPIH0_gj<0;mnS03=TiP0h:RK0=nUV03f`940d;_60080l>F0A@3oool20000
04h0oooo00<000000?ooo`3oool0103oool000@0oooo00<000000?ooo`3oool0@03oool01@1QOmX0
P4f;083OnP3oool0Y4mT00D0oooo00@04@0007gCo`1mdol0OM?o4@3oool00`1R2Ch0El_c0?ooo`0@
0?ooo`030;K=EP3oool0oooo00H0oooo00H0063D086/l@20fod0oooo09j;`02gY/P20;FbeP80AKk_
00<0F/Gi0?ooo`3oool02@3oool0100H0000W9_B09bKdP2LVm820<J:U00:0;:?/P1U;gP0[e1F07XI
?@2c>A`0I@0@09LoFP2J@e`0[VEk09aDM`80Xe]i01P0]VYh080D;02<7Bd0Yemk08Q@QP2CFXX0/GbI
0>bjWP2jIFX0VD9L09aDM`2NC6P0TCmR090mH@2?;dT0T3UJ08TW@P213A/0USmM07DfLP0/01P07P00
06/0002ZGG@600000003089LWP2`Ef40Yb000080VBdg02T006GB0<^?U@1K7VP0Sc=@0;mC?@21=VH0
3`0007Qmb`2/W<H053nl0>^DHP3?KUD0cElj0<ENBP3c[gh0k:V50?^hEP3JN`00oooo0?:HB`3>IdT0
Bh_[0;nZa@2]X/d0LCb109E[W`2dR:H0Mfjl0;5CF02^P:<0_Ybf0;jN]`1;?j80`8VJ0=2OY@3PZ9/0
m<JN0>FZU03e`iP0h>WI0?3UP0170?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
103oool000@0oooo00<000000?ooo`3oool0A03oool00`15/OL0UmSn08OIo`0208OIoad0oooo00<0
Q5:>0?ooo`3oool01`3oool00`22eol0MmWk0?ooo`0@0?ooo`80U_3_2`3oool20480000309]LQ02M
GXD0[<ga0080BI[c00d0VTe^09?Vn`2BIY`0Sgfk0<QiMP2IJ9P0VF2=0:Y^S@2RIhd0/7fL09YIP@2M
L9h0[7RJ0080WE5`00D0T4ej0:MQO@2SLIT0/GbI03h0000204P0000706^mo@2==e/0LDJ?09UFO@2>
?fD0VTMT08PeG0070000000605@05`1oD8l0cnOX08Fim`2W=c80Y;[Y0P00NL`209TZ<0060<=H@P0n
`/h0?/;>09mRR02IFhD01IO40P0l`=P05@2KKYh0jIae0;C6B03[U680cY6D0?R^KP3NLC@0f8=[0?Zi
NP3VPdH0nl630?ooo`000000cjbe0:aWPP0706T0NdF30<>]a02EJil0Mfjl08UHT@020=BARP030;jL
]P2]MID0[GFE0080aFML00D0h[BW0?gJO@3`m[40mL>H0>3Yf@190?ooo`800000B`3oool00`000000
oooo0?ooo`040?ooo`00103oool00`000000oooo0?ooo`1U0?ooo`0308ABSP1_fOH0KmWf0080oooo
0P1cfOTN0?ooo`030?RXFP1G@9/0oooo0080QE2:0P2M<SP0402KAV80SR8a07h64@1k:e`0[51J0:5L
OP000000TnKk0;5gTP2MG880/86R0:=kY`2YP:P0Xg^W09ESU@2PKIL209e/V@0;0:=eX02LHhd0T4ej
0:mOL02QG7d0PE:A09/G002DGi00ZGNK0:9bW00600001P0000003P1^6Th0=`0007l]FP1B3eT0B`UG
091GR@3JkH/0VhBj0?oDQ@2W=P00GKCl0:aML@2XF6h0W5Mk0P31Vk40202WJX/0]G^D0;EkU03;RXd0
YIC405aac`2AU=<0PdZ40P36RiD0403T`;80dY>@0>JRQ`3JlYH0n:i^0000003ka8X0n[Uj0>2XVP3P
WaT0oooo0>VR8`3?[;D0RUbF02hXU`1gFj@20;ReeP0309JOfP1gK[`0>WGO0080RZk^00T0`hfL0<1h
PP30N880gi=k0?_0P@3mfWd0h;>X0?oGS@3Wo<@0B`3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00@0oooo00030?ooo`030000003oool0oooo06L0oooo00D0000P069/a`3oool0oooo
04D0000A0?ooo`<0G<[h203oool0102OKIL0@[Oc04:gl`3hZ5X305l0000B036di@2[JXL0YFB409iO
QP2bRJX0]G:608mNT`2Al=l0Wf:908iCQP2VJX`0[V1c09aQR`2^Kh/0ZG:D09YOR@2RIh`0[X>V0P1^
A8h01@2VN:00VW:T09MXVP2UNJ80R6RX00L0000000<0bHfE07h=802AAFd00P0006l01@2/>Rh0D00K
06/TH@1f;VH0JRAS0080F`0000T0K/7n07O5o`0003L0000g0=>7O@3Wc;`0_j:k0<5hO`33NGl00P2f
Y<L20;6K`P0A08I;PP1n<600LB=J096Dd`2HQl00Kg7401i9`P3T`;80g:BI0>BfY`3JlYH0n:i^0>V<
D`3f[G40n[Uj0>2XVP3PWaT00P3oool0301WMll0[Yk708Ana@2ARLL0[i[10:j9[P2VQK40/YBg0<F[
`02SR;L0ZX^e0<>=W080bIn]00D0gkJ^0?_0P@3mfWd0g[Vc0?oGS@1=0?ooo`800000B03oool00`00
0000oooo0?ooo`040?ooo`000`3oool00`000000oooo0?ooo`1W0?ooo`0405Jin`1O_Od0:`0008RM
h@80[?3g6@3oool01`2MK9P0QEbJ09m]U`3oool0V9_E0:2Pe03oool00P2/PjT04`2XPJ/0Xh>`0;:=
[`2RNZP0TeZ:09iTS00V/Kl0TO3O09=PTP2=CGh0Y5aj0;JD]@2TKI<0ZFj@0:aaT02DH940[7RI08aL
T`1^A8h01P0000004P2SOZ/0SfJN0:9dW`2GJ9X0XW6K08m>O@2TDFT0OPdP094mGP23;UL0XVJ;0;mo
SP2BCgX0MSAa08Q9O01I6600`Wj706dUHP80`JJn00d0XTmW0:ECJP2nO8X0JS1e0>O<_037[/00Yi_:
079od@2>Sm00[WFB0<R>V01n0PL0VVjO0080c9RP00D08Cjg079``P2WW/d0bHV>0>C0/P020:`k<P0C
0=[bUP2a>B@0/CTT0=agBP3j]540dMKM00003P3N/bd0oooo075ic02^W/L0Q7k5051ig02ARlT0Y9G5
09Ih[`3_T3L0]o2O0:>8]`020;BJ_@070<:[``2J`O<0gkjg0>gXP`2R<S40g[Vc0?oGS@1?0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0103oool000<0oooo00<000000?ooo`3oool0
F@3oool303nlk0d0oooo00<0XjKH08RMh@3oool0503oool00`0_0000VSQ909XhB@020?ooo`0307=9
T@2MK9P0@lCN00@0oooo0P1M[_X0202SMZ00Y7BM0:AiX`2^Oj40W6^H09IVV02RL9T0]i:`0P36_=40
0`2bK`00WHNl0::4/`07000000030:ImYP2TN:80I@000080000001D0YWRP0:=nZ`2KLjD0VG>U0:=j
YP2ILJ@0Vg6R0:UkXP2RKiP0TV>H08Q;O`2YK8/0X5j108e>OP2TMj40ZHVb044nY`2SFWL0UHk:0<NR
/`28Jj/00P2UDfX06`000000/fb009`N402=4Q80[diB079od@1YI;T0K3^4091JS@2XCU`0^6Yf08XU
?03@XZT0ciVN079``P0005d0`JJm09io/@3BKe<0N5jX03EHb03O]jh0nmZS0=3Wi`3jciT0o>:T0?k?
R`020?ooo`040000002MZn00MGk?031^g080]jk@00`0QX770>n@=`2[[]T0ZjkI07]oc02mb><0V/7c
0=S7b@1[g>D0cjZd0=://P3Gg]aA0?ooo`800000A@3oool00`000000oooo0?ooo`040?ooo`000`3o
ool00`000000oooo0?ooo`1T0?ooo`80ZTE90`3oool00`2SY]P0oooo0?ooo`0C0?ooo`06081^]@2@
N;D0T^k_0?ooo`1nAX80mkN0203oool02019AZ`0ZWZO0?JhQP2RMJ00VfFA09ej[02OK9H0XWBO1P00
00003`2/R[40XhBb0:J3[`2[QZh0XgfZ0:EoZ`2FJI`0W6jM0:1[U@2]OZ40ZgfQ09Q_XP2MMZH0X76L
09mgY@020:1n[P0<08=LW02OLYl0Y7FO08A:P@2CFX/0P4Z607LQD0219dd0ORA<0;f]b@1VAIH0?;kQ
0P2Ec?/01P28Jj/0HRii068^N@2@Q<<0YW6F05C7m0<0Q=Ko0100YDmS0?^jN00007P0QfVY09MDO@2Z
HGX0V55g0999LP2_Ukh0001Y04DCK03?YZl0WWna000OX01afk40QG:f0P3kfZ<0102KULd0n/nI0?o?
M`3AR@030?ooo`0506JHk026WN<0DHk[06>?iP2QX]H00`30h_002@3CWYl0QY_P09ZolP000000a?gT
05cDi@3Ki=`0io_50<kfY01C0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103o
ool000<0oooo00<000000?ooo`3oool0HP3oool00`2YSKP0oooo0?ooo`030:CAm`040?ooo`2Xg?X0
Z=cj0:SLnQ80oooo00H0aZ:d0;CIl`2dfO<0f<C60?JhQ@27CXD70?ooo`80Q^Sa00<0oooo00000000
00001@0000004@2YQZl0XWbZ06`FB@3Q]jd0ZhF/0:b5[02QNZL0XgbX0:n4YP2GK9l0VfnP0:AbVP2Z
MiX0Xh:`0:20/02_RJd0XgRT0080WGJV01/0X76L0;6;[P2NL9d0UF:C09aWT`2NMjL0ReVA08ADS`2A
Fhh0UVVL08ARX`2@EhP0WV28070dMP0k4G40OTAo09UKQ@0`03H0Le^X09ao/P2YWl`0Me:J0;=oV`2j
KGL0^C4008]KU02i<@000P2/@3`01P3?S8X0Lh7B07I^_03;]lL0Hg_F05e`cP80Qm?o00<0001/0<>9
U`2mbN@00P25_oX01`007j00^5mS01Uoi`1hf?`0n/nI0=_WO@3]iLL00`3oool01@1fOLd0PGk70:bK
aP2AXMl0Rk3^0080VM?l00D0Xlkf06jko@1aRmd0WK[]0;Bnh@020<OUk@030=?kh@000000oooo05@0
oooo0P0000130?ooo`030000003oool0oooo00<0oooo00030?ooo`030000003oool0oooo0640oooo
0P2BN[@K0?ooo`050;Bef@3oool0oooo0=_Bc`3f^8D0103oool70000000:0?ooo`2YQ:`0ZHB/0:1`
W02NLj80/8JX08iSW02[OZ<0YGbW0:YlXP80L=cb00`0VVfM0:9eX02RMJ00YWRP0:5]U`2SNjL0XWZW
0:EfWP2[PJP0ZX6X0:62/P2@Iil20:V3Z`0F0:moX02PMZ@0X7RV08ePV02PNZT0SfjX08]PV`2SPZl0
TW6[08i^Z`26Jjd0SG2]08=TYP1d@H@0VHS004m?/P2AN;@0HDjU07=KZ01bAXd0Y76H091NTP80aJBg
00D0SDin0;McQ@2hM8H0dI:A0;31iP020<RIY`030461iP1i]oT0oKYY0080:@0000@0e<S=0280CP2X
SKT0UcA70P3KfmL01`2dn/D0^5mS04R;j`18Rn/0cJnk0?KYS@2fS@000`3oool00`0`0000U[G]06b;
g`020:CEn@0309Obi`03U[/00iJk0080096o00@08i;]0;3Om`29g_h0RMknF@3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo00<0oooo00030?ooo`030000003oool0oooo05P0oooo00<0
Wef10?ooo`3oool04P3oool203FYlP<0oooo00<0L/Go0?ooo`3oool0303oool6000000@0oooo00L0
J8KM0:>Zf`0[0000oooo0:AfW`2cR:L0XWVU0080ZWRL00H0YX2Z0:MnYP2UMil0YG^U0:b7[`2VO:H2
0:5lZ@0T0:j=/`2QPk@0[8^b0:F9]`2MO[00XWj/09e_W@2^OIh0VVnO09mn[`2SPJh0XX2^0:^0YP2Q
NJH0XgfY09]n/P2FKJ80Vf^J09]l/02@JJ80SfRR07a?TP2@JJ40O4nA07YBU`1aBiD0VHS009]o/`2A
N;@0ICn?09Ag/01iGjP0R9;F091NTP2VV<L0OT5k0P2gLhD209P?0080R]Co01<0a8nM0:NnjP1Xd_T0
ZFF209^?aP196700n[Uk0<Sbk@1g@H80Klgn0<M]I0000000ajbn0<fib00f05@0ZH2X0?GBZ@3fjHd0
G@0000D0oooo0P2ehOD01@1@VO80U];m03Vhj@1Kco80HMSJ05l0oooo0P0000100?ooo`030000003o
ool0oooo00<0oooo00030?ooo`030000003oool0oooo05P0oooo00<0Wef10?ooo`3oool02@3oool0
0`25ChT09WcV0?ooo`070?ooo`0309CEoP0M0000oooo00T0oooo1`0000030?ooo`80V8[300<0oooo
08MGTP3oool01P3oool0202gSZ/0/g^E0:enX@2TNjH0YGJO0:EcV`2VN:40WgNV0P2XOZH04`2QLih0
Xg6J0:=aVP2UNZ<0XGRU0:1gYP2XN9h0ZH:Z0:J0Z`2TPJh0WgJU09]cY02OOZl0Xh6^0::0[P2[P:H0
RUnJ0:M`T`2YLI<00P2QO:/0502=IIh0TFRO08QNV`27HZ00LDZD07]>T@1oCH`0LDN@07AMZ@2`Rjh0
I56W09>0^`2^Y<h0TiSE08RBeP2dY<P0Xic>07Qmc02kX[l0VjON0P2KS/D0502NLj80O3E[0000D@3/
_:40I29V07Y`_022G9d0SZ_Y040UR02MKid0OEJI095PU01Qe>l0`:O00=_Cd02^QZ/0ZYo<0=i/503n
bHD0ol^1KP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00<0oooo00020?ooo`03
0000003oool0oooo0640oooo00D0ZjSD0?ooo`3oool0oooo08E?R@0?0?ooo`H000002`3oool00`1o
hOP0oooo0000C`070?ooo`050;JC/P2/PZL0Z7ZQ0:=gXP2SMZ000P2cS:d20:^0Y@090:e`S@2OJI<0
/HNX0:UhWP2SN:<0Zh2V0:MmYP2TO:P0[HJ/0080Mm[j01P0Y86^09im[`2XPjd0X86b09j0/P2FJ9X0
VWJY0:AnZ@2XOJD0X7b/09QaY02KM:H0QVFU08]YYP2BM:h0MFFb07IHXP2=JjL0VgJY07m^]P20LkX0
N62Z05eC[`2/Ul420:]7C0060<NJZ036//H0a[;60?^gL02OMJ@0D@0Z0P2NLj804@3Ro;/0[gfM0:mm
W@2G7a/0ZFF20:J_g`1BK]40PGNn09EXW03=b]L0ZYc809Ii/@32SYh0oooo0>fHI03Bi^D0gV`D0740
oooo0P00000m0?ooo`030000003oool0oooo00<0oooo00020?ooo`030000003oool0oooo06h0oooo
1`0000050?ooo`0409nhjP3HnMl0WkSZ0;:TbPX0oooo00D0001?0?ooo`3oool0oooo03f?k`030?oo
o`090;><[@2WPJ/0YGfX0:b7[P2TP:d0Yh6[0:f1Y02TOJP0WfnK0080YXNc00D0[8Za0:=mZP2VOJL0
YWfW0:QgW0020:EiX`0N0:5dX02KJIP0XW2I0:iiV@2RNZL0W7BU0:QmY@2:JZP0W82d09ao/P2PP[80
UfnS0:9hY02HLjP0OeZM09ejZ`2ALJ/0RFFS099m^@1hI:l0R6FT07m^]P20LkX0D3VG0<:AX`12Nn80
aK35049khP2C:SX0^7>50P2eMhl03@2hki/0diJC01T0J`2LW=<0`[7804l0@P3J`<00fLC609]VTP2f
bNP0UYOC06iT]`2OS/800P2BL:P01P1T01d0]Z[=0:O8l@2Wb?40biVS05P02W<0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`030?ooo`000P3oool00`000000oooo0?ooo`1U0?ooo`03
03dVR`3oool0oooo00H00000103oool206g@o0D0oooo00<000B:08Jem03HnMl0303oool00`0004l0
oooo0?ooo`02088TA`<0oooo0100[W^K0:anXP2cS[00YGjZ0:EoZ`2^Rk00X7JS09a]W02^Rk00YH6/
0:^4Z`2[R;00UGN^0:5dX02QLI/0ZGjT0P2_Rk005`2IK9d0XWJR0:QjX02TPJh0UVFG0:1aW@2/NI`0
WgBR09]aXP2RMJ40VGBW0:9n[02IMj`0W7JW091]YP2CJ9h0Ug2U09IaYP2@K:H0K5NY08=b^02@Mk80
NWg;0080YG>K00`0MhSG08W2nP3n`6P0[V^40;QcQ@38Gd@0e;6f0;S_V`0h/?40<eG609J=b023PLP2
09ARU@0>0>7>a02UFWH0`Yfb0<:M/P3?Z;80W93709VSg01R^od0c<oL0?Z_FP35WK00V]f60000002[
mO5d0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00`3oool00080oooo00<00000
0?ooo`3oool0H@3oool7000002@0oooo00<0QUNB0?ooo`0@Umh00P1me_l04@2YN9d0[WZK0:=]U@2b
RJX0Zh6X0:^8/02/SkL0YH>`0:F1[02MKY/0ZW:C0:b7[@2JNjl0WGRY0;><[02XPZ/0ZH:[0080XW^X
01P0[H6U09mfY@2QO:X0Zh:Y0:AnZ`2AKZP0WG6P0:UjX@2<HY`0YgbT0:=n[02<IJ40XWFQ07QJX`2;
HI`0UWZb08ic/01f@hD0O4N508aLT`1<87T0N5RP07IMZ02nQi/20::nk@030?kMTP2jMXD0eXb00080
YTE@00P0a8RD0<25U@3:_<`0[I[307[=o`3J`<00nZiT07bUk@80_mK[00D0cjRb09BGe021Gj80OEbR
0<c?g0020000000309[MQP23eOl0oooo07D0oooo0P00000i0?ooo`030000003oool0oooo00<0oooo
00020?ooo`030000003oool0oooo05/0oooo1P0000040?ooo`030000003oool0oooo0100oooo0P2G
R<8A0?ooo`0309^Me@26Ei80oooo0080oooo01D0Yh:/0:b8[`2VO:D0ZH>/0;:8Z@2MKih0[X6S0:Ym
Y02VOJH0Vf^K0:9lZ@2PLId0/7nN0:F3[`2WR[H0XGRU0;:3X@2EJId0/X6O0:F2[@2TOJT00P2UNjD0
202cS[00SV2H0:Z5[P2XQ:h0V7BX07iIW02HHi80UEZ80P2LKYd0402RKiP0Qg2b08]NV01D76`0Od5j
09]/V`2AIY`0J4NH07QHX01fGJP0kknP0>oYa@23DH`0QeB>0000002/M9D20:iLK0040=>=Q@3e^HX0
eH9_0;IoV@80_KCA00<0[Z;<0;UGD`1C7Vl00P1[=gh01022a_d000000:SRn`2Xh_/208aBQGX0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`030?ooo`000P3oool00`000000oooo0?oo
o`1D0?ooo`L00000603oool00`2VSKX0oooo0?ooo`0B0?ooo`05082@fP2ZKi00P93J0?ooo`004:00
0`3oool0402/S;@0Z8F`0;BF^02SRKP0W7BT0:R3[02^QJX0Y7ZT0:AhXP2TKYD0X6nK0:1`V`2OL9`0
[GFD0;B6Y@2bQJD207JYlP080:^eh02UQ;40W7jb0:B4/P2[RK00VGV]0:9o[P2XPJT20::3/P0=0:B5
/P2RT/@0TX:n09J4_P28JjX0RdQh09ULQ`1jJ[D0IDnS08Ib]P2LP[D0JTVI06M@X`0209Z3^@0;0:fM
a`3i_HH0V6VJ08]PVP2hG5d0SFjZ0:AmZ02YGGD0aF1>0<abI@3jjZ@00P33P8T0200j;9H0^:?40=Rc
/`3H/k<0WAT00000002nOX`0Y2880P1NdO400`20j=/000000?ooo`1j0?ooo`800000=`3oool00`00
0000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`1=0?ooo`L000009@3oool00`1]0000
oooo0?ooo`060?ooo`03000d^034[<80oooo00<0oooo00<0FSJ<08M@Q`3oool01@3oool0<02fRZL0
YgJM0;J4W`2OJI80V5b70;R=Z02TMj00W6^I09eXU02ZR[<0XXJf0:25]P2SQ;80Sf6H0:fMb02NdVX0
]gfD0:N;^02GIIH0YWBK0;2;[`2VQk@0VgBV09IaYP2VOjX0Z86Y0:V=]`2RPk80YGVR0:^:/`2KOK40
SWBb07]T[@2<JJH0Lb5C0:IfWP2:GYT0TGnl08Q[Z`1]Dj<0NGW70:InZ03MP@80LCb108c^gP2YDV<0
Ngk:07kT_P80Il;n00<0mKnB0;b2U@1<Z?P00P2jdn`0202mOXd00`0_03l0B00o04P0V?;?0;F7Y@2T
N:40[GVK0P25EI400`1T^_d0P>SK0?ooo`1m0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool00P3oool00080oooo00<000000?ooo`3oool0A`3oool6000002`0oooo00<0]i6`0?ooo`3o
ool0503oool03`2LLJ40Z7ZP0;AlU@2JJIP0^i^g0:5hYP2QMJ80V6bM0;5oW`2^T;L0/H:R09AcZ`2N
Nj`0VWFX0:fMb0020:mnW`040:]oY@2WQ:l0WWRW0;J6XP80X7RV0140]9Vl0:FA`@2QR;T0WXJi08mX
X@2BKjL0WF^H0:McV026I:D0ITFF054eTP1cCYL0Y6nG0;FRa@2;QlX0I6o906IQ^002061I/`0I0000
I01a>G`0<QEm06<lS@1kO/X0U82k09AXW@2bEeh0mKnB0>BQR02lPYD0QUZF0:0N1P2OM:<0X7JT0:lT
002Hl/l0d<_E0;F7Y@2TN:40[GVK0=Soa@3AMEl0D<g90000001o0?ooo`800000=03oool00`000000
oooo0?ooo`020?ooo`0000<0oooo0000003oool0@P3oool7000003/0oooo00<0Whbo0?ooo`3oool0
2`3oool01`2LLJ40[86V09UWU@2WNZ80^XVR08AFT`2HCg@00P37Wjl0:01cC9D0bYFN0:=dWP2`U[`0
VhVo0:J5/@2/Qjh0/i2b0:V8/P2TOJT0[hFX09IYW02TN:80NdF30:abT@2lTZ`0/Xf_095o_02LTLL0
X9S<08RLh02DPK`0Xi?5089ma@2PV/h0CF?909VDc@2[/Md0KX3D04=;]027K[00UhW3061I/`1nFYd0
3P0000`ET`2@H9H0]Yo108Mi_@2]S;@20:7?H`0;08>Tj@32G4/0`Ua;0:i>E03@J4L0To7E07D0001g
0000]e@001IniP2?RlX00P3HolD00`25f_l0oooo0?ooo`210?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool00P3oool000030?ooo`000000oooo03`0oooo1P0000130?ooo`030=nM5P3o
ool0oooo00X0oooo00P0[hJY0:>3/P2`V/00/9[00:nI`@2=G9<0/:C<05O7m`80Z<G^0P2kT:T01@2^
P:<0SV:J0;61X@2XPZ/0M5NR00805@000P2_bnh01`1`@XT0bZNf04RKm018Vo@0LP000;RK^P2LTLL0
0P2`W/H0402AV=L0PWNn08b5a`2GYn40O9_U0:31l02canT0KX3D001NeP1[QM/0RiGH07AX]`1;:XL0
[jC=02e9_025PLL20:N1Z`0509acY03M][00`5U90?Z_DP2[JXL00P2dJg`00`2D:cP0ah^E0<N;U@02
0<:gc`0301IniP2obN80_lWR08H0oooo0P00000a0?ooo`030000003oool0oooo0080oooo00000`3o
ool000000?ooo`0e0?ooo`L00000A@3oool01@09V/L0<kSM03>hg@3oool0e<3600`0oooo00D0Xh>b
0:5gY02]Q:T0TGB`089>R@020:ZF`@0@0;2>/P2DMk00B/[E04[:e@1G02l0aGIg07NQk02SY]P0[h>U
08id/@2fT:l0[IW30969b01kGjH0ZhV`09n0/@80ZhF/01@0WLOe0:7Qo02QhO`0Oi3J0;2NaP2A]_00
Wk_/0731oP12Z_L0L[3h06:Tm@2TXm@0W9_B05mL]`1@Il/0>GKP08I[[@0007`0CcBB07=S/P80BeRn
0P2bZLl00`2j/]80aJg20?Z_DP020:F7]@0409mEM@2jRZ<0bYbX0?S/W080eZFU00<0jL2/0<_:f03o
ool0R03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00000`3oool00000
0?ooo`0_0?ooo`H00000=P3oool00`33?`00oooo0?ooo`0O0?ooo`060<fU/03oool0Vm;k0?RoR`3o
ool0_W=l0P2mVkH03P24h:@0YSHb0:Hf<P0001d0W6JB099QU@0007d0`9>X09il[@2hU[@0[hR/0:f7
[@27Hj80[;CO0P2Xd?D02P2OIHd0PU>A0<BN/@2RR[X0NGc;08CVm034[/@0oN6<0?joL`1f]oX209nj
k00=08Ffm@1g]?T0N@0007jQj@2g]]P0Hl?m0000001YWNl0O7S40:FB`@0AVm/0E97/01Pg/`020;:S
b009076FiP2@ZNL0YkKT05S@`00fT>l0nZmB0:cbm@37Q8X0SYSH0080a/CH00@0n>bL08EIUP25FIH0
ZN;jR`3oool2000002h0oooo00<000000?ooo`3oool00P3oool000030?ooo`000000oooo02P0oooo
1`00000j0?ooo`040>GSd033SYd0Pm?o08?Cob80oooo01`0U9OC0?RoR`3oool0_[C@0>;UeP2[MiX0
FUFb08U=P02?g?l0XX6`0:^>]`2JN:`0YgBI09ZTg032LG<0Z7jV0;24Y`2XO:@0]Ig00;bkf@2_S;40
UXJo0;NUa`2gY<H0X]_k096/j02j/=00XKCV0P3n_g<01P000000DLkN08oDoP1ig?T0>;WV07[2o@80
J;[m00@0TYKD0;FM`03=i>P0KP0?0P3oool00`0HUNL0KLOo000<V00201jFj`0509F8a02cQjH0/INl
09eiZ`2^/m`00P2nmnl01P37Q8X0SYSH0;_6h`2He_d0_Nkc05/nUHl0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`020?ooo`0000<0oooo0000003oool08P3oool6000005H0oooo00<0
`9R_0?ooo`3oool0203oool00`1D^?/03Ig;0?ooo`070?ooo`0E06?3o@1?0000VJOP06:oo@2;jnl0
V>Cm0:i3?`2DIIL0/:3809ZTg031V[00XXFd06c3oP33Y;X0TFVQ0<FS]`2/QJ/0aJ>g092ilP3@gN80
^=7]0080K00000X0`k;:0:6fi`1VcoX0XnCl0:KXnP2;c?h0J;7j05B^nP2?d?h09Zna0P3oool00`2A
UmD0k;nU0?ooo`040?ooo`07001@c@00KMT0000009R/i036X[@0_/7M0:JPc`020=[kf`050<GDiP36
eND0V=gn0>OOb`3Df=/0TP3oool2000002/0oooo00<000000?ooo`3oool00P3oool000030?ooo`00
0000oooo01/0oooo1`00001a0?ooo`0>0?RiP02@J:40UWB/096Fe01Ve?D0n:Q60:Vii@2FaOL0Z9K3
082;e@2f]MP0XXFd0:><_02m]]<20<K7f`80/JS?00T0YjKE0<7?i@2]f_L0[N7i0;cWl`3Y^Z@0V>?m
08OWm@1Kdn404P3oool02000B/P0H<;m09;6n@2hi?D0KkSl07kDo`1=^OT0^?S_U`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0040oooo00000`3oool000000?ooo`0D0?ooo`L00000
I03oool00`2BOk/0]g^A05<MK`0@0?ooo`0;096=c03h^H00]Hf/07j9d`2CTm40U[kc02heY`2Y^ND0
X;OY0:RGa02/VL<00P2YgoX0102;U=L0QJ_^0=ocf`2Peo/20:3Lo080P4N200D0[Ngh0:W/n@2>bO`0
jKZT0:fgh@2d0?ooo`800000:@3oool00`000000oooo0?ooo`010?ooo`0000<000000?ooo`3oool0
3P3oool6000007P0oooo0P221`d40?ooo`050;;0@00nZOH0?ZWf0:FNcP2c/MH00P2<dOh20<Zca009
092Ad027aO`0QlGl0<3hk@000000H;gm0=Kl]`2Ld_/0ZlW`0080aKkD00D000000?ooo`3oool00000
0>VjY0020:Xl=kD0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`010?ooo`0000<0
00000?ooo`3oool01`3oool7000005P0oooo00<0VV>?0?ooo`3oool0:@3oool0103>ih00oooo0:NP
cP2gYLL20<gYjP0509ZSf`2a_N<0eN;P0>;Qd`3?`/h00P2Cknh0102Ci_/0Xo7d08oFo`29jn/60?oo
o`0307_Nn00n_^L0oooo0;L0oooo0P00000V0?ooo`030000003oool0oooo0040oooo000010000000
oooo0?ooo`3oool6000005l0oooo00<0X9G90?ooo`3oool0;03oool00`00OmP0[;_T0;2lhP0208_1
n@0503Rbk`2]n>T0cl;>06cJl@1Ne>D02P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool00@3oool000@00000U@3oool01P1S_od0Y[o[087Xj02Ui?/0
T=gn067Gg0H0oooo00<0GH;N0;SKlP3oool0103oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool00@3oool00080oooo1000002F0?ooo`030=Bf^`3oool0
oooo00<0oooo00D0Ug:W0?ooo`3oool0GH;N0;SKlP050?ooo`030000003oool0oooo0;/0oooo0P00
000R0?ooo`030000003oool0oooo0040oooo00060?ooo`<00000P@3oool20;IHFP80oooo00D0SEB8
09`P4P3oool0oooo0=O>d00D0?ooo`03099bZ`3oool0oooo0080oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0040oooo00090?ooo`@00000OP3oool0
0`39om<0oooo0?ooo`0I0?ooo`03099bZ`1Bc]d0oooo0080oooo00<000000?ooo`3oool00`3oool2
04R/n003002=_P3oool0oooo0;H0oooo0P00000O0?ooo`030000003oool0oooo0040oooo000=0?oo
o`<00000O`3oool207CMm@040?ooo`0jX_@0>Z;d0819Q1L0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0040oooo000@0?ooo`@00000Q@3oool00`2N
G840oooo04dKL00@0?ooo`030000003oool0oooo0<40oooo0P00000M0?ooo`4000000@3oool10?oo
o`00503oool300000840oooo00@0T6NO0=[7aP00I]T0?@00403oool00`000000oooo0?ooo`330?oo
o`030000003oool0oooo01X0oooo0@0000010?ooo`40oooo000G0?ooo`@00000O@3oool0102klo80
V:KO0?ooo`0=HMP@0?ooo`030000003oool0oooo0<@0oooo0P00000J0?ooo`4000000@3oool10?oo
o`006`3oool3000008h0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0G0?ooo`40
00000@3oool10?ooo`007P3oool4000008<0oooo00<00000083Xe`20j=L0103oool00`000000oooo
0?ooo`370?ooo`8000005`3oool100000040oooo0@3oool00280oooo0`0000270?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool0503oool100000040oooo0@3oool002D0oooo1000001`
0?ooo`030;bL]`3oool0oooo0100oooo00<000000?ooo`3oool0bP3oool2000001@0oooo0@000001
0?ooo`40oooo000Y0?ooo`<00000K@3oool00`2lW;L0oooo0?ooo`0@0?ooo`030000003oool0oooo
0<`0oooo00<000000?ooo`3oool04@3oool100000040oooo0@3oool002`0oooo1000001Q0?ooo`80
]ibm6@3oool00`000000oooo0?ooo`3=0?ooo`8000004@3oool100000040oooo0@3oool00300oooo
0`00001i0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool03`3oool100000040oooo
000c0?ooo`@00000I@3oool208EJV0h0oooo00<000000?ooo`3oool0d03oool2000000l0oooo0@00
00010?ooo`00=`3oool300000780oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0<
0?ooo`4000000@3oool003X0oooo1000001^0?ooo`030000003oool0oooo0=<0oooo0P00000<0?oo
o`4000000@3oool003h0oooo0`00001[0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3o
ool02@3oool100000040oooo00110?ooo`@00000I`3oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo00P0oooo0@0000010?ooo`00A@3oool3000006@0oooo00<000000?ooo`3oool0e`3o
ool2000000P0oooo0@0000010?ooo`00B03oool400000600oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool004`0oooo0`00001M0?ooo`030000003oool0oooo
0=X0oooo0P0000050?ooo`4000000@3oool004l0oooo1000001I0?ooo`030000003oool0oooo0=`0
oooo00<000000?ooo`3oool00`3oool100000000D`3oool3000005H0oooo00<000000?ooo`3oool0
g@3oool2000000<0oooo0@00000005H0oooo0`00001C0?ooo`030000003oool0oooo0=l0oooo00<0
00000?ooo`3oool00@00000005T0oooo1000001?0?ooo`030000003oool0oooo0>00oooo0`000000
05d0oooo0`00001<0?ooo`030000003oool0oooo0=d0oooo1P0000000600oooo100000170?ooo`03
0000003oool0oooo0=@0oooo2P0000060?ooo`00I03oool3000004@0oooo00<000000?ooo`3oool0
b@3oool;00000100oooo001W0?ooo`@00000@03oool00`000000oooo0?ooo`2o0?ooo`X000006`3o
ool006/0oooo0`00000m0?ooo`030000003oool0oooo0;@0oooo2`00000U0?ooo`00KP3oool40000
03T0oooo00<000000?ooo`3oool0ZP3oool:00000300oooo001b0?ooo`<00000=P3oool00`000000
oooo0?ooo`2P0?ooo`X00000>P3oool007D0oooo1000000b0?ooo`030000003oool0oooo09D0oooo
2`0000140?ooo`00N@3oool3000002l0oooo00<000000?ooo`3oool0R`3oool:000004l0oooo001l
0?ooo`@000007@3oool00`2HN:h0oooo0?ooo`0;0?ooo`030000003oool0oooo0800oooo2`00001I
0?ooo`00P03oool3000002P0oooo00<000000?ooo`3oool0MP3oool:000006@0oooo00230?ooo`@0
0000903oool00`000000oooo0?ooo`1[0?ooo`/00000KP3oool008L0oooo0`00000Q0?ooo`030000
003oool0oooo0640oooo2P00001i0?ooo`00RP3oool4000001d0oooo00<000000?ooo`3oool0EP3o
ool;000008<0oooo002>0?ooo`<000006P3oool00`000000oooo0?ooo`1<0?ooo`X00000SP3oool0
0940oooo1000000F0?ooo`030000003oool0oooo0440oooo2`00002H0?ooo`00U@3oool3000001<0
oooo00<000000?ooo`3oool0=`3oool:00000:<0oooo002H0?ooo`@000003`3oool00`000000oooo
0?ooo`0]0?ooo`X00000[@3oool009`0oooo0`00000<0?ooo`030000003oool0oooo0280oooo2`00
002g0?ooo`00W`3oool4000000P0oooo00<000000?ooo`3oool0603oool:00000<80oooo002S0?oo
o`<000001@3oool00`000000oooo0?ooo`0=0?ooo`/00000c03oool00:H0oooo100000000`3oool0
00000?ooo`040?ooo`X00000e`3oool00:X0oooo1`00003Q0?ooo`00\
\>"],
  ImageRangeCache->{{{78.625, 292.25}, {373.938, 154.875}} -> {-0.260535, \
0.606874, 0.0031348, 0.0031348}},
  CellTags->"RenderCTData"]
}, Open  ]],

Cell[TextData[{
  "Creating a large number of polygons is not always an option, because large \
amount of memory is required to store the polygons. The current data set size \
is ",
  Cell[BoxData[
      \(TraditionalForm\`256\[Times]256\[Times]225\)]],
  " voxels. A data set with double the resolution would be eight times \
larger. That's why MathGL3d can create density plots with a very low number \
of polygons and textures. Since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has no texture support, you can only show the renderings in the notebook. \
The quality of the rendering is influenced by the ",
  StyleBox["MVTextureSize", "Input"],
  " option ",
  StyleBox["MVListDensityPlot3D[]", "Input"],
  ". The first two values should be a power of two, and the third value \
determines the number of slices in the view direction.",
  StyleBox[" These values should be chosen with care, so that the memory of \
your graphics card is not exhausted.",
    FontSlant->"Italic"],
  " MathGL3d uses 2D textures for portability (the default values are not \
suitable for this example). The option ",
  StyleBox["ColorFunctio", "Input"],
  "n determines the transfer function for the volume data, which determines \
how the data values mapped onto color and transparency. ",
  StyleBox["ColorFunction", "Input"],
  " can be a ",
  StyleBox["GrayLevel[]", "Input"],
  " call that is translated into a transparency value or a list of a color \
(",
  StyleBox["RGBColor[]", "Input"],
  "  or ",
  StyleBox["Hue[]", "Input"],
  ") and a ",
  StyleBox["GrayLevel[]", "Input"],
  " for the transparency."
}], "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MVListDensityPlot3D[\[IndentingNewLine]Evaluate@\[IndentingNewLine]\
ToFileName[$MathGL3dDataDirectory, "\<foot.v3d\>"], 
        MVNewScene \[Rule] 
          True, \[IndentingNewLine]MVTextureSize \[Rule] {256, 256, 
            256}, \[IndentingNewLine]ColorFunction \[Rule] \(({Hue[#], 
                GrayLevel[#^2]}\  &)\), \[IndentingNewLine]ViewPoint \[Rule] \
{1.086, \(-2.00\), 1.0}, ViewCenter \[Rule] {0.42, 0.5, 0.46}];\)\)], "Input",\

  CellTags->"RenderCTData"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00238095 0.0238095 0.00238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
1200 string
400 400 8 [400 0 0 400 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010000020100040200050200070200090300080300
0A03000702000802000B02000C04000C0700130800180D001A0F00180C00150C00150B00
140B00110A00100900140600120800140900150B001A0C001D0E001E10001E1100241100
2311002413002717002814002918002A19002E1B002D1D002E1F00322100342300382600
3827003425003321003021003221003323003323003622003921003A2200392300382100
3B23003B2400402A00412C00442B00452D00462E00432A00442E00472E004A2E004A3000
4A2F004B2F004C31004C3300533B00544000533C00523B00523900513800543F00574500
544800564F005557025359075065104C6F224077363778423279523586513D9B41429F2F
42A02641A1223BA62C31AA352BAB322CAB2C2DA825319F123C9708448D044A87044C8505
4983024B820246840546840546850741810A40810F3F7B103F750A447106456B04486405
4A62054A62044B61034E5C02535800514E004F4100493500432C003E2500372300331F00
321B002F1A002B1A002B17002A17002E16002D18002C19002D15002C1400281100251000
241000241200220F002110001F1000200D001E0E001F0E001E0C001D0D00190900150700
1407001404001305001005001004000E03000A0100080000040000020000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
0100000100000100000100000100000101000301000301000301000701000803000A0200
0904000A02000B02000C04000E0600110700150A00190D001A0F00180E00190B00170A00
180900150A00140900160900150900130C00190D001E0E00221200201100201300231100
2314002413002613002718002719002919002B1A002D1B002E1B00302000342400372600
382400342100311F00312100321D00321F00351F003723003720003A20003D21003E2300
3E24004026003F2B00422C00462A00472D00482F00442E00472F00492F004930004A2F00
4B2E004B2F004E32004E3600523E00554300574200523F00564000513F00554500594B00
5A52005758005461064F690F497220467534426F4D3A745B347C61348A5C3A9A4D3BA53F
37A83E33AB3B31AB422BAE452AAD3D31AB3233A6273C9C13409307448E04468C05468B05
438A05468B04438D04448D05418B093F860D3C82103E7D113F770E427009426B07456606
466205476104495E034F5B01575600574F004F42004D39004631003C2700342100331B00
301C002E1A002B15002A13002916002C1700301A002D19002B1500291300281100221000
230F002512002411002312002112001F1000201000220E00210C001F0C001A0800160600
1406001407001407001106001005000E02000A0200080000040000020000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000030100030100
0401000401000501000601000700000601000701000602000A02000A04000C06000B0700
0A05000D03000A04000B06000E0600170A00180C001910001E12002111001D0E001B0D00
190D00160B00160C00160C00180B001C0C001E0F00211200271800271700271A00251900
261800271800271900271A002918002918002919002D1D00301D00341F00352300362400
352100311F002F1D003020003020003220003620003321003420003822003822003E2400
402500402800432700412A00422B00432D00482B00452C00482C004A3000493000493000
4B32004C36004E3700533900553E005444005446005449005546005646005C4A005A5300
565B005366024F6F0A4B781A407C3140754B466A65417271328173318D6E349B5F33A655
2DAB4B2BAC482AAF4928AD462CAC3835A7283A9F1D42970E468E05458E03468D06439007
4092083F94084194084090083D8E0B3C870F3A82143E7E143D7A143D730E406C0B436507
426306456104496002515D015557005352005143004B37004232003C2900382300341E00
301C002E18002C15002B14002A17002D18002B19002B18002C16002A1300281000250D00
270E00271100251100270F00231100221000221000210F00200D001F0B001B0800180800
1609001509001508001207001005000E02000A0100080000040000030000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000020000020000020100040100050200050200
0402000603000803000704000805000A05000A04000A04000E0600120800130900120A00
1108000E07000C06000E0800120A00160B001B0E001D11002015002214001F11001F1100
1E0E001C0E001C0F001D0E001E0E001C0E001F10002614002A1A002B1B002B1C002A1C00
271C002A1B002C1B002D1D002E1E002F1D002E2000312100362000372200362300342200
362200332000321F00311F00351F00352200361F003321003622003720003A20003E2300
422400422900442D00422C00452F00452D00462E00442900452E00462F00492F004C3100
4E3500523900503A00513C00554100544400524B01534B02564B01584B015B4F005C5901
586604527409487F1642802D3F7947446E61526372496B78357F7A2D897831936B30A063
2AAA592BAD502BAD4A28AC422FA92E35A11D3B991242910B4391064294064096093E990B
3A9B10399C103A9A0E3E93103A8E123A88153C84183E80173A7B163A77143F6E1144670C
446609436305486304516201546001555801524D004B3D004234003D29003A2400331E00
301E002F19002C15002F16002D17002E17002B16002B1700291500281400281100251100
260F00270E002710002710002610002310002310002210001F0F001F0C001C09001A0A00
180B00180A00150A001309001006000D05000B0100080000060000030000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010100020000050100070200050300050200060300
0903000A04000D05000C05000E06000D07000C0900110800160C00190F001B1100190F00
160B00140B00110A00120A00140A001A0F001B10001D1300211600241400221300211100
1F11001E10001D11001D10002111001E13002013002416002B17002E19002C1B002E1C00
2B20002C1F00301F003220003120003121003222003424003724003927003A2600392200
342200352100342000362000361F00351D003820003825003B24003F23003D2400412900
442B00482F00483100483000472E00473100462F00472D00433100482E004B30004C3200
503600533C00543F00514000534300514A015150054F5407555605585501585A005B6502
5871084B8316438B2A408240436F5A46606D465D783C667C32767D2B807A2E8A742B946B
2AA4602BAB532CAC4829AB3C33A626389E173A98113C940B3E95093D9A0B3B9E0F37A115
34A21934A019379A183C9217398F1A378B1C3A871D3E82183D7B163E7415406E12426B0E
42680A4467074A6806516903546501565B00554F004F3E004434003F2A003C26003B2200
3621002F1E002E19002E19002D19002E19002C19002B1600291400271300271100240F00
260F002810002711002A1300271200251300241300221100201000200E001D0C00190A00
170B00170B00140A001208001105000D05000B0100090100060000040000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000101000501000502000602000704000604000804000A0400
0B03000D05000E0700110800110900120800130900160900190F001E13002014001E1200
1A0F00170A00160A00150B001A09001B0D001C10001F12002313002112002011001E1000
1D0E001B0D001D0E002011001F13002210002312002713002A1A002B1B002A1C002A1D00
2C1C002E1F002D2000321D00311F00332000361F003921003B26003D27003B27003B2100
372200381D003A21003622003520003820003625003D25003E26003F2600412800412A00
472E004832004D35004B35004B35004A33004832004933004932004A33004D3300503300
553600553D00584000554000544700524E034F59094D601051630A566504566B02577707
4E8315448C2B3F864442715A4A586C45517938557F305C802D6A802A757C2A7E782B8671
2898652DA2522FA8462EA83636A2253B9D173A99113C990C3D9B0A38A00E36A21631A31A
30A31F349F24359B23389324359225368E273A8922407F18427913407211416C11426B0E
426B0B416B09476F094E7005526D01576100574E004D3D00453100402A004029003B2500
352100311B00301A002E19002C18002B17002A15002A13002A1400291200271200291000
2611002613002914002B14002B1400281400271200221000200E00200E001D0D001A0B00
180900170A001309001208001006000E06000B02000A0100070000050000020000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000100000100000301000501000603000603000504000704000904000A03000D0400
0F0700120900130A00140B00130B00160A00150C00180D001A11001D11002015001C1100
1B10001A0E00170B00160C001A0D001E0F001F11002014002515002113001F10001D0E00
1A0D00170D001A0E001B0D001C0E00200E002310002615002819002B1C002B1D002E1A00
301E00301F00302300312000311F00321E00341F003821003D25003C27003D2800382400
3721003324003521003623003A24003C25003E25003E2900412C00422B00452E00462E00
472E00492E004C32004D34004D35004D35004D35004B35004C36004C34004E3500503600
523700523A00583D005440005448005154044E610E4A6C1750711153750A537A08508513
4A8E254189464A6F615152735A477850457E3C48833250832D5F7E296D7A297776297C73
298E682F9D5632A74630A73736A2273A9F1D369C17379C13389E1037A21237A31836A21E
35A022349D25339A2731952A30932D35902E3E8827467E1848740F456C0F426A0E426B0F
406B0C426E0B46710B4A75074F6F025861005A4B00503800422D003E2A003D28003B2300
371F00301E002D18002A1A002817002915002A14002A12002B12002A1300271300281300
2A14002B14002814002915002B1300271500261200231000210E001E0F001D0F001A0C00
180B00180A00130B00110B001009000F05000C03000B0200070000060000030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
0201000401000501000402000602000903000803000902000B04000C03000D0700100800
110A00160A00150A00160A00150B00150E00180C00190D001910001C11001D13001C1000
160F00180D00150D001B0C001E0F00211100241500251500281A002318001D12001E0F00
1A0F001B0D001D0E001D10001C11002011002213002615002818002D1B002C1D002D1E00
3020003220003320003320003220003521003722003825003E28003D27003C25003A2400
3722003721003624003A26003E21003C27003F2A003E2B00412D00472C00492F00492C00
4B2F004A34004B31004D33004E32004D35004E38005037005037004E37004D3700503700
533C00523D00564000584400534E00555E044F6C0D4B77184B7C154D82124C8B184D9328
4D923E557C5A5F5A705F497C5D417F543E824642843A498037587E30657B2C6E79287075
29846C2C995C31A64E2EA73F33A32E35A022339E1D339E18339F1736A21837A51B36A420
34A322319F272D9B2B2F97302E963136902F3F88264A7E164B750D476E0D426D10426D13
406C0F44700A4676084777074E7003565E015648004934003F2D003E2A003F29003B2400
351F00301C002D1B002C15002B15002B17002B16002A14002A14002913002A13002B1500
2B13002A14002815002816002714002415002611002310002011001F10001D0E001A0E00
170A00180A00130A00130A001109001006000E04000B0200060000060000030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010100020100
0501000603000705000904000A04000A04000A05000B05000E04000E0600100700120A00
160C00170C00170C00160C00180C00180E00190F00190F001B0E001B12001C12001A0E00
180C00190D00170C00180D001E1100221300261700271B002B1E00251A00221600210F00
1E12001D13001E1100211200220F002113002313002514002B14002D1B002F1E00322000
3321003423003523003621003721003524003D25003C2A003F2B003E29003F2A003E2800
3E29003E26003F29003C29003F2600412900422E00432D004730004B34004E33004D3500
5135005134004D34004F34004D3500533700563A00543A00553D005239005037004F3800
543F005541005A4700584B0057550057640452700C4E7B154C8316488F1B47972755963D
6385566C6E6874547568447D5E3B825532834E3484443F8240527E355F7E2E667C2A657B
297B702B92622DA2562DA64B32A53F36A32E2FA32330A42035A51F37A51C37A82035A724
32A3252DA12B2A9D2F2C9A3130962E3B8E2845871C4E7E104B780D47720F447114437016
41701147720A447707467807506E04585C005442004833003E29003E28003F28003D2600
3A2100361C00301A002E1A002C1B002A1B002B1A002C18002A14002915002B16002A1600
2B14002813002615002615002713002513002610002411001F12002212001E11001B0E00
1A09001A06001509001409001109001005000D03000B0200080100070000040000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000000000000000030000030100040100
0602000904000C05000C06000C08000F0800110600110700120A00140B00160B00170C00
190E001B0E001E0E001A0E001B0E001D0F001A10001B10001C0E001D0F002010001C1000
1B0D001A10001B0E001C0E00211000241700281C00291D002D1F002A1A00251500221300
2210002011002014002315002614002716002617002918002C18002D1D002E1D00301C00
301F00312000331F00321F003420003826003D2A00422B00422E003E2D00422D00432E00
422C00432A00412A00412A00422800422B00442A00462C004931004F3500503600503A00
513C00533800533900533800553800553B00533C00543E00564100533F00543D00544000
564600544B005A4C005C54005C5C0157690654760E4F8115498D1B429929439C3F5B8D53
776F687962737E517874417A66397F5A3582573C81494C80415A813763872C648126607A
246D702782632A945F2D9F572EA74F30A93E2BA8302CA72A33A72735A62232A9232FA827
2AA52E27A43428A2362C9C3535962A428D1D4A86114D800D497E0E437815437519447419
447513467609467906477606526C025958005440004832003F2D003E2A003B2600392500
3D2100381C003320002F1D002E1A002F1B002E1A002E19002B1800291500281400271600
2814002613002715002814002914002611002710002411002112002112001F11001B0E00
1A0A001A0800150A00130A001109001006000E06000B0300080000080000040000020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000FF0000000000FF0000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000010000030000040100050100080200
0902000A04000F07001007000E0900140A00120900140C00160C00140B00170B00180C00
1C10001E0F001E11001E11001E0F002110001C13001E11001F14002213002311001F1100
1F12001E11001D10001D1000231200281800271B002C1E002C1F002B1B00261800261300
2512002412002415002515002513002B1700271800291A002D1D002E1D002E1E00301F00
321E00312200341F003520003921003B26003F2A00432C00422E00422C00432E00452F00
453100462F00482F00472F00452E00452E004830004732004B3700513A00553A00533900
563C00543C00543D00543A00563D005840005A3F005944005944005A4700594700594800
5C4E005A51005C57005F5C015E660358750B4F83174A8E2042992D3D9C3F4992525C8164
6D68746B587D6F4D7D6D3F816539825B3A8058417D4D4E7F455782355F8B2B5E85255A7D
2461732570682981662994622BA25A2BA84B2BAA3C2EA9302FA72831A82630AA2929A930
26A73624A73A25A4382D9E35359625418D1847850F48810E457E12457A1946761A49771C
487815477B0E417C084478074F6B03565200523D004934004230003F2B003D26003E2500
3B2600372000342000331F00321A002F1A002E1A002A17002A1500271500271300281400
2713002913002B14002814002913002611002611002311002112001F13001D12001A0F00
1B0C00190C00150C00150B00120B001106000E06000B0300090100080000050000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000010100030100050300070300070300080100
0903000C04000F06000F0600120700120900140A00150C00170C00170C00170B00170C00
1A0E001E13002115001F13002013002114001E12001E1500231300241600201700241600
2212002013001E1400201300251400281B002A1C00301F00301F002E1D002A1A00271500
2513002311002310002714002915002A16002A1A00301800301C00342200332200352100
3825003826003925003927003D2A003D2A003F2A00412A00422A003E2C003D2B00452F00
472E004531004633004730004833004A32004D3500503700533900523E00523F00533E00
523A00553D00533D005540005A41005B44005C42005D44005E47005F48005E46005C4A00
5950005A55005B5A025A6104576D095081134692263A9F3339A0443F9357548166606E6F
645C775F4D7F6545836A3D84633A875F3F835B4580534B81474F893B538E315486294F80
2953792A5C712E6C6E2B86692B9A622DA65B2DA94B2FA93831A82E2FAB2E2CAC3426AD3B
24AE4024AB4025A4372C9F32349A25409219448B12488514458115477B154876144A7716
497B154380143E800C4078084F6702544D004E3700453200402B004028003E24003F2500
3A2400392100392100342000301A002F18002D17002A16002814002816002A15002A1200
291500261400281500281600271200250F002510002210002211002011001E0F001D0E00
1D0E001B0E00190C00170C00140B001108000E05000B0300090200080000030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000301000601000803000A0400090400090400
0A04000E0400100700100700150800130B00130C00160B00180C00190D00190D00190D00
1D11001F1300201600221500241700231800241800251700291700281800241700241800
2215002014002010001E10002314002817002D1B003020003324003222002D1E00271900
2515002012002213002514002714002914002C1900311B00321F00342000352300382500
3E27003F2A003F2D003F3100403200432D00432D00412C00432E00412A003F2B00402C00
452F00472E004731004930004C32004D3700513C00553D00563E00564200554100584100
564100564000583F005A44005B43005F46005D46005E47005B48005D48005D47005B4600
5A48005B52015B5A0656680D5177174987293F943D38994A3E8F5E52786B6D626F735475
684B795E3E7E6042845D43885D448D60438D66458A5A448B52429046418E3844892F4482
2D447E304A783455722E75682A90632AA05D2CA6512DA7412BA73F27A93F25AC4224AC45
23AC4926AA4A29A73A30A232359E273C951C428F16448818478313497C0F49780D4A7C12
4480153F85173D830F4378085060025348004C3600442D004229004128004027003F2800
3A2400362100362000352000311C002F1B002C17002D14002A1200261400281200291200
271200271300271300281100251100240F00231000220F00230E00220F001F0F001E1000
1D0F001C0F00180E00170C00130B001109000E05000B0400090200080000030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000500000600000702000904000806000A06000B0500
0E0400110400110600130900140A00160C00150B00180C00190C001B0D001D0E001D1100
2112001E1300221700221700251A00291800271B002B18002A1A00261C00281800251500
231300221400210F001F13002818002A1A002F1C00352300372800362800311F002B1900
2815002414002813002818002917002B1B002F1E003521003523003A25003926003D2600
402B00402D00422E00442F00423200413000452E00452C00442C00412C00412D00442F00
4830004A33004B36004936004A38004F3D00534400574300564600584500574400584600
5B46005D45005D49005C4800604C005E4D00604D005E4B005E4A005F47005C46005C4800
5D48005A52025A620C52771D4A852F438741438257467D624D766B65636F7B5372754975
6A48795D42805A44835548865B478867408D723E8F693B9064378F53398A443E86384081
35437C364779385174306D702888692A96672E9B602E9E572C9F51289E5128A25225A654
24A75528A8552BA54531A63837A22D3C9A2241931B438B1849840F4C7D0A497C0A46800E
4284133D86163D8410467609515D03554800503500472D004329004129004029003D2400
392400362200332100342000321E002F19002E17002B1500291400281200281200241200
261200231400241300241000220F00231000221000231000230F00210F00210D001F0E00
1C0F001C0E00190F00170B00150A001109000F06000D0500080500080100050000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000FF0000000000000000000000000000
000000000000000000FF0000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000200000300000501000902000802000B03000C04000D0600100800
140700130A00130A00150C00160B00170E00160E00160D001C0E001F10001E1300201300
2312002114002214002517002D1C002E1C002E1D002E20002E1F002A1B002B19002B1900
2816002715002716002616002B1B002E1E00312200382500392B003627003320002E1C00
2719002616002A18002A1B002E1B00311D003721003B23003B27003D28003E2A003E2D00
3F2A00412C00442F00443100432E00442F00432E00432E00423000453100483300493500
4E39004F3D00503C00513B004D3B005140005444005847005B49005A48005A48005B4B00
5B4C005B4F005B51005B51006052005E56005D56005A54005C52005E51005E4C00624E00
5A4F005B580356701645893341884F4671644C6072575F6A5E5E666E536B754B736D467B
64497F5C48835946825540825B3F896B378D79358D75318F6F2E8E5D348A4A3B833D407C
3A437B3848763553742E6873287C6F2A85712D8B6D308F683091632C91642A97612A9E60
28A05E29A45B2EA64C32A74037A6333C9F2B3D9821408F1947870F4A800B497D0B44820F
44841141871441821145730B505D035449004E39004A3000452D00432B003D27003C2300
382400372200382200392100341E00321A002F17002D15002A1400271200291200261300
271300241400231300251100241000231000231100231000220F00221000200E001E0F00
1D0E001C0E001A0F00190C00180A001408001207000F05000A0400080300060000030000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000FF0000000000000000000000000000000000000000
000000000000FF0000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000401000701000702000A02000B02000C07000F0800100900150C00
170D00180D00180F001810001A10001A11001B10001B11001D1200211200211500231400
1F10001D0F002314002618002D1F00301F003220003120003020002B1E002C1B002A1A00
2E1A002C1A002A1A002B1C00332100352500382800392D003C2E003728003022002D1C00
2917002619002818002A1A002E1B00321E00341F003A25003C2A003E2A00402B003F2D00
3C2B003F2E003F2E00402D00432E004530004730004531004835004B39004B39004E3A00
503F00504500534600514400514200514300564800554A00584B00594D005A4D00585000
5B51005A5500575500555600575900585D00595B005A5C00605900605600625600625600
625A015D6A0A597E234D874E517769595C795F4D79654E68724E567549626F457467447F
6147815E45835D3F85593682613286702B8B7D288C78238C74278D662C8A4F36843F3C7F
3F417B3D4978395279315E7A31677B316E78347477327B7832817730877230916D309967
2D9C622EA15932A64C34A94535A74036A138389B2B3C9320458A16488311468111428511
43861142861244811247730B525B045048004D38004530004228003F28003C2300392200
3B23003923003920003B2100382000361D002F1B002F16002D14002C13002A1400241600
2416002514002613002812002612002512002412002311002411001F0F002110001E0F00
1D0F001C0D001B0D001A0D00180B001509001208000F05000C05000A0400080200040000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000FF0000FF0000FF0000000000FF0000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000300000702000803000804000C04000D07000F0900120D00140E00180D00
1A0F001A10001C0F001B0F001D12001F12001D13001E1300201500211200211400231300
2012001E10002317002A1C003020003021003323003325003424003020002F1C002F1E00
2E1F002D1D002D1D002E1D003521003A27003D2C003B2E003E3100372A003323002F1C00
291B002719002917002A18002B19002C1800301C00381F003727003D29003E2B003F2B00
3C2A003E2D004132004534004836004835004A39004B39004F3F005041004E44004F4500
4F49004E4F00504E00524C004F4C00524D00554E00565000585100585100545000565400
555700505B004D5A004E5B004E60005461005463005760005D5D00615D00625C01696304
66700C5F801B5E813A656F6769617B71507C704B776649706347685F436E57437B544380
504284543F83573A855F38816D33837D2B828A278187228781258770298A543386423B80
43437F494C7F465380445881485B80445F7D42627B3C69773B7175367C7134886B309265
2F995A329F5035A54639A94534A84235A240339B3534952D3E8E1E438818428515408713
43861043840F43801348720B515C045349004E3900442C004028003E25003D2200382200
3A23003A23003B24003B25003B2000391E00341C00311B002E17002A1600291500251600
2815002713002812002812002612002513002512002413002411002210002011001F1200
1F11001E10001E0E001B0D00180B00150A001409001008000D06000A0500080300040100
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0200000400000501000902000A03000B04000F0500110800140A00160D00190D00190E00
1A10001B11001913001C11001E1400201700231700231500231600251500231400221400
2210002013002818002B1D003224003326003426003225003122002F21002F1C002C1E00
2E1D002F1E002F1C002F1D003622003927003D2B003D30004031003A2B00342500332100
2D1E002918002719002919002D18002D18002D1C003520003925003D2800412B00402E00
413000433200483800483C004B3C004E3F004D40004F42004F48004F4B004B4D004A4E00
4A53004A5700505700505B01505A02525902555901585800575900555900545700555C00
515F004C62014860004863004966014F6500536700596300606400636400696F046B7A0F
60872357853C647057785278774C8079477B7545776443795841764F40784C407E4C3E83
4D3E804E3880543580653B807D388091337B982C7493287889297F7A2C846136844D3C80
4E4281564A805C528057547F58518055567F545A794A5F7545636F406F6A377E652F895E
309154329C4936A34539A74137A64035A138379B36379635419128458B1C458818458713
46840D45820B437F0F49740A515D03524B00493800442E003F29003C27003924003A2400
3926003E25003E24003C26003B26003C1F00371E00371A00311800291700281500271400
2A13002A11002915002A14002A1300291400281200261500251500241300241300221200
2111002111002010001E11001B0E00160B00150A001209000D07000B0500080300060100
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
0500000601000A03000C04000C05000F0700110800130800150A00150C00160E00190E00
1B0D001B0F001B0F001C1200201400231600221700221500221600221600251600241400
2516002215002A1A002D1F00322500352700372700372800332500322300311E002B1D00
301E002F20002C21002F1F003323003B29003D2B00432E004130003D2D00352500322200
311E002F18002B1A002E1E00311C00321E00331F003C2300402800412D00432F00453500
4836004C3D00534200524800554A00514A00504C004E4E004D53004B55004A5701465B01
4760024663034A63044C65064C6808506607526204535E01555E01556000576200526301
4E66024A6A03496B03496D034D6C02506D02526D015A6B015F6D0163750363830C618C24
55884454735F6C5C6E7E477E723F816C3B7F65397C593A804E3B804C3B7F4D3C7F513A83
4E3A81523A7B5B377E6D377E88387B983876A336669B326C9032787F36806E3F7D5F437E
60467C6C4A7E714E7E6E4C7F6A4B8265537D625A78555D734A606D436B67397B63348659
32904E379A4639A44038A63C36A434369F3039982E3A9330448E24498B1C4B8A124A840C
4C8108488008427E0A487106505C02504800463A003F2E003B2C003A27003B24003B2400
3D22003E25004224003C24003C22003A2100361E00341C002D1B00281700281400271400
2815002C15002D14002E15002916002A1500291400271500261500271600271300261200
2312002210002111001E10001D0E00170C00170A001209000F07000C06000A0300050100
030000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010000040000
0803000A05000C06000E08000E0700100800120700140700130900150A00180C001B0E00
1D0F001C11001F1100231200231300241500241400251300251300241500251800251700
241500241700291C002D1E00312200362700362900362A003425003225003022002F1E00
301E00322000331E00331D003922003B28003D2D004232004335003E2F00372300342300
3320002F19002A1A002B1900311D00342200372300402900412F004531004836004D3D00
534100524800544B005452005554005056004A5600485900435D00436001416204406707
3F6D0842700A42700D4673104775154B710E4F6C08506404516604546803566B03546B04
4F6E064B74074A75064D73075073065472065272055C7504617E06618B0F5C911F588639
5A76565C666B70597479477B6B3B80613781563882543782523D80513F82564181603A81
59398057387C5E397C6B33797D31798D3579953B78903C7B843C7B7D3E7F74497C734E7B
7D4C7B8C4A788F477887407A793D7D73497B66517C565A78486175416D6F3E7F66378B59
37964B37A04439A53D39A23435A02C359C283C99273D9326448E2147891949860D4E7F06
4E7D06477D064579064B6C034D57014E4500473600402C003A2800392600392400392200
3E24003F26003D28003C24003B2300392000331D00321C002D1A002C16002C1600291500
2916002C16002B16002D17002B16002C17002A1500281500271500271600271500251300
2212002311002310001E0F001B0D00190C001809001309001107000E0500090300050100
030000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000020000040200070200
0B06000E0900100800100900110900110700120700110900130A00140A00160C001B0F00
1C11001E1000201200211400221400251600251700251600271800291700291800291800
291900281A002B1A002C1E002F2100342500372A00392D00382900352A00352400352300
3320003320003121003121003822003C28003E2B004130004235004134003C2C00362800
3224002D1B002A19002B1E00311E003420003B25003F2800422E00463500493A004C4300
4F4D004F51004C53014D56014A5A01485D014260013E65013C6802386C06377009367410
3877133779173C791C3F7B21447C244778184C730F4D6B0B506C09536F07547008517309
4F760B4C7B0E4F7C104F7A1155790E57790B587E0B5F860D5D91165B8F275885355E7A47
646F59656A696B60766F507B653C805C3882553989533988573F885A428D5C4383683F80
633C7F5F3D7E633D7E71317A7D2977833280873C808542817F407D7D437C7B51797F5476
8A4F7392436F923E6E914070853F737B427868447C54577E436B7B3F77714086643E9255
3D9E4B3FA3413EA4383EA12B3A9D253A98223B95223D901F408C1B4786144D800A4F7D04
4B7C054A7B044675044D67015057004E43004734003F2C003A2700372300392100382300
3822003A24003A25003A24003C2000381E00351E00331D00301C003119002E18002D1500
2C16002D16002E15002E17002B18002A18002B1700291700271700271600231600241500
2512002211002010001E1000170D00180C00170B00120A001006000D0500080200050100
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000020000030200070400080500
0C07000E09000E0900120800120900130700110800120900140900150900190C001B0F00
201100201300211300231500261500281A002A1A00291D00291F002B1C002A1C00291B00
2B1C002B1D002E1F00302200342800362B003B30003D31003D30003B30003A2A00392500
3521003320003020003320003925003E29004228004531004839004538003F33003C2F00
362B00311E002F1B00301C003420003922003E2500402D00453200453500493D014A4902
4A54024A5903465C03435E04425F034262034063043D67043B6D0538740C357916327D1D
327E1F337D24377E253D7F27437F2A467D1F4A7B174B75124C75114D78104F79114D7A15
4C7D184A7E1B4E7E1D4F7F1F57811B5B8718628E196793216491305E853B5C78445F714F
676C596D6A656D656D7159726E4B796C467E6A427E6B417F6D40836F41846B438169457C
67437C69417E7140827D397C8B327587337D8338827D3E827F437C81437A8353748C5570
8F496E933D6C8E3C708C42738345747D45756950745166774775724C766650875A4E9A4D
4DA4434AA5354DA0284C9B1D469717429216418F1B3F8D1C3F8A1E4484134B800A4E7F05
4A7E064A7A054A74034E69024F55004F4300483400422C003E29003B23003A2300372400
3925003C27003926003E27003B2300392200351F00351E00331C00311B00321700301400
2D17002C1800311900321A002F1A002F17002C18002C18002B1700291400261400241500
2514002313002211001F1000180F00180D00180B001309000F07000C0500080200040000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000301000603000907000A0700
100700120800120B00140A00150C00140A00110900140A00170900170B00170D001D1000
1E11002013002316002617002617002719002A1C002B1F002F21002F1F002B1F002D1E00
2F1F002F2300342500382A003A30003D31003E36003F3C00403A00403700403500402C00
3C2800382300341F00351F003A29003F2C00443000453500483D004640004239003F3400
3C3100362200321D00341D003924003D29004831004838004B3E01474202484B05455607
475F0845640942680A3E690B3E6B083D6B073E6B08416F093D750B3A7B18338125328730
34862E33842D3783283C8227408026417F20457E1E467A19467A19457E1949811C49821F
4982224885264D852C508A2E58912B5A992C5F982E628D38638541617D495E77505A7757
58765E5A76655B726A636C6C6D5C6F6E5373734F747947777B407C823A807741806A497B
634C7C6C497E7A487F873F7C9739768D357A80327E7536807B427B82497889536D925467
9043688F396A893972874275824B707E5367666B65517E644F865B55874C578F47589D41
57A23757A0285B981D589312538E0F4D8C0E488A124888194888214883174A820C4B8206
497E04497B044C6F024F64015052004F4100453300402C003E29003B27003A25003C2600
3C27003E29003E28003C2500392500392200362200351E00331F00331A003319002E1900
2D1C002F1D00331B00331B00301900301B002F1A002E1A002C18002A1700271800261700
2617002616002214002111001B0F001A0E00190B00150A000E07000C0400080300040000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000401000803000B07000E0600
110700120A00140B00170C00190E00180D00170C00190C00180E001C0E001B0F00201000
211100231400251C00271900251800281900291D002C2200302300321F00302100311F00
3421003527003A2C003930003B3600403C003D3F003C42003F4300424200433F00433900
3D33003B2B003727003823003E29004030004633004839004A3D00463F00453900413600
4130003C2600362300392500402700432E004D3A004F4702495103445707435D0B436711
426E124173123F76143C79153B751038760E3777103C78143D7B1838812135872D318B35
2E8C35318A3132892A3587233A861F3F851C40841C41821941831C42851D43871F448921
458D2647912D489738499C3F49A0404B9F42529542598A4459854C598051597C5758765E
58775F5978625D7765646E657361647B5769824E6C89466E8D3C7A93387E85427E6E4D7D
6051826C4F7D7A4A7B83447C8D4376853E78753B7B693B7B7444777E4A7586516D914E65
904C639048638B3F6D8A3C77814C6D77675E61805A548F4F59924158903A58943E579C38
579B315D97255B8E1C588B12568B0E51880B50870E5085174E861E4E831649840E478408
498206487A064B6E054D5D024E4D014B3D004632003C29003928003927003B26003F2500
3F26004027003E25003A2500382300342200361F00371E00311D00321A00321A002F1A00
2E1C00311C00341C00331C00311C00301D00301C002F1B00301A002C19002A1700291700
2717002414002212002111001D10001C1000190B00140A000F08000D0500080200040000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000100000501000903000E0600110800
150900140C00170D001B10001D0F001C0E001A0F001B0E001C10001B12001E0F001F1200
201500251600261A00281700271500261900281B002E1F00312200322400332700362700
372C003A2E003D34003B38003C3F013F45013E48023E4C03414E03415002414E02414801
414401403B013F2E003E2B003E2F00443600453500493800493E00473F00463900433300
4333003F2B003E28003E2800432D004938004E46014E57044763073D690B3D70113A7518
3879173A801A36811D31821C31811932811833821B36811F3785213387272D8B2F2C8E33
2B8F2F2D8F2C308D24338A1F36891D3788193C87163F86143D87163E8C1944911B46951E
479A2446A13142A4413EA54E39A0553A9958418F554B8557518157528059537E58567B5A
5B7A5D62785E6A7861657161666362665862685369704B707C47798A4577854C78764E78
674D7D6C4D79754D78744C7B794C7A6B4A7A63457B5E437A6D457177476D844C678B4A66
8E506591526A8D49718B4A737E5C6D6D775E638B4F5E9340589336549135518F3A549337
559531599227578B1B57881257860E53860B52830C5582115484145385114C870F49870B
46840A437B0A496F064B5C034B4701493C004531003E29003A2600392400362200392400
3C23003E25003A2200381F00352300331F00351E00351F00331D00311A002E18002D1900
311B00321F00301E00301F00301D00301D002F1E00311D002F1D002C1A002A1900291700
2717002614002513002012001E10001A0F00190D00160A000E08000C0400080200040000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000201000602000B05000F0700130A00
160B00170C00180E001C10001E10001D0E001B0F001C10001D14002013002212001F1400
2316002615002818002818002A18002719002D1B003021003324003929003C2F003F3100
3E35003F39003F42003C47023751033853043858063B5B083A5C073B5C07375C06375605
3952033C4B03443F014336004836004B3A004936004E3A00493C00463C00453C00463900
443900433400452E004733004C37005142004F54024C63073D6F0C347610327914307E19
30821B2F861C30881F2B891E2C891C2D89202D87262D8A292D8A2B2C8B2F298D30298F2D
2B9027308F20338D1F328D1D338B1E3789193B8A133B8C123E90183D971C3F9D1F3FA026
3EA13237A344309E532D97612A91662D8C672F8566398463418061477D5F497A59527A56
5D765967745A746E5B6E675E655E5E61546161536766506D6E4D74804E728253727A4C73
74447A734A79764D7A6F4F7C6B4F7A5F4E7D5B487C5A447968467172436C824864884568
8C506C8E51728952707F54716A6869637E596688475F894055883D4F88404A8B404E8F3B
539030528E26518A1A508615528210517F0C507E0B4F7C0B517F0A4D830946880D43870E
41850F3F7D0F476E084957044C4501483700442F004229003E27003C24003A2300392200
3A25003922003B1E00371C00351E00331E00331B00331B00341A00301900321B00311A00
341F00352000331E002F1D00301C00311C002E1D002F1D002D1C002C1A00291800281700
2718002415002314002111001D0F001B0E00190D00140C000F06000A0400060100040000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000FF0000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000300000302000903000D04000F0800120B00
160F001A0F00190F001D0E001D11001F0E001E10001F1200201500211600221400251700
2817002B18002D1C002C1E002B1E002B1C00302100352A003B30004039003E3E00414300
414300414A013F50013B5804345E0534620633660931690E33670D32670D2D640C2F5F0A
315C08385705404B034440004B3F00524100513F004F42004F45004C4100484000484200
4A43004A3B004C37004E40005046005056004C680443720C367D113082142C84142A8616
278718298A18298B1C268E1D2A8D1F2C8E252C8E292C92302A91312E8F312D912E2F9126
33921F3B8F183B8F153B8D16398D1A398D153A91143B9616389E1F36A32835A63032A23B
319E472F99532B8E5E2A87652A80692F7D6B377A6C42786B42786B45766148705857704F
666F4E6E6C547366576C615B635C5E5C5A635A5B656258696C546A7B52688052697E476C
7B3D767A43767E4B796C507B5E4F7D54517E5C4F7C5C4C7B6B44706F426B7D4364844168
8A4B6D8C4E7382546F6E5E6A646E60667B4D667446586E474E7049487B484A81424E8737
5388284F8A1F4E85175083124F7E0F537F0B507D094F7D094D800849850B418A0F3F8B12
3C841141790F466A09485403494101463400422E00412A004129003F27003A26003B2500
3C2500392100372100361F00381E00331D00321A00341B00311B00301C00321900351E00
352000372100332000322000301A00301C002E1B00301B002E1A002D1A00291900261800
2617002415002414002011001F10001C0E001B0E00130A001006000B0400060000020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000301000701000903000D04000E05000F0A00130B00
160D00170D00190E001D1200201200201400221500211200221300211400261600271B00
2C19002C1E003122003124003526003527003E2D00413700443F014549013F51013E5602
3C56023A57033B5B03385F03326205316605326A082D6C0D2E6C0C2D6B0B2C6A0B2C660A
29640B345E083E5405444C014E4D01534B00534800544D005150004F4B004A4700494C00
4850004E4B00534A00584F00595D004F6B03427708398310318918298C1D298D1A278F18
278F1729901928901A2B901C2C8F1F2B91232B91262B932D2F922F30933332942D349425
3B912141911A4192174193163F981B3D99193A9E1935A41F30AA2C2AA83C27A448289A50
299556298F5B288660277F642A796534766A3E716D49717144726F436F66446B60517054
61714E636D4E6266545C615A5B615B59625E5D635F675E606A5C6371586672516A734A6D
7741738142798A457D754A80574E814C52825B557D6055786D4B6E7145697C42667E406A
7F476D7C4B6E795167695F5E6570536F744669634C58595249665346764C4883404D8530
4F831F5085175082144F831252821055800D567E0A50820A4C850D4686114189143E8712
3E7E0E40720C4A6107484C034A3B00453300422E00412C003E2D003F2B003E29003E2800
3D26003B24003A24003822003A2100342100341E00341E00341D00321D00341C00322100
362300362400352100322000311C00311D002F1C002E19002D1800291900271A00261900
2518002516002415002212002011001D1000190E001309000F07000A0400060000020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000200000200000401000801000905000D0600110900120C00150D00160C00
180C00190B001A0E001D1200201600231500221500231400201200221600271700281B00
2D1D003020003324003729003A2A003B3100433A014648034552043F5904396305356605
356204375F043A5D03375E033860023C6305366707306B0A306B082D6B072E6807306809
2E670B35640A3A5D074259044D5702555001564E005453005157014D5702495803465B06
4764054C6202525F015766024F7304467D0939870F32901729951E25972028951F29971F
24971E279A1F28981F2A95202A95202A97242B98282C992B30982E32992E33962E35942C
37932A3D9725419B223F9D213DA32538A62632AA292CAB3126AD3B23AA4922A658239F5C
239B5C24995A239558239159258E5A31895F3E83674B806D497D6B4A77634E6D5D5A6D57
636B4E5B6B504D695647655C4D6B56576B555C6559675F5D665C61685A6466576C6E4B6F
7443767C427A80467F674F824A528247577E605B7A695F7571526C6D486B7D45677C3F6E
7A476A734C677C5A62726D5570764A8269477A58515E56544D65534B754D4B844050882E
53861E57871956861555861555881457861058830E54870F4C8611488717448416408110
4277094869074E58034C4700493800432F003F2C00402A003F2A003F2A003E2D003F2C00
3C28003D28003825003A27003A26003B2400392000382100361F00321E00352000361F00
351F00361E00341E00322000311D002F1D002C1C002C1B002A1A00281800291800271900
2619002417002413002111002010001A0F00160D001209000F06000B0300060100020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000100000200000301000502000A04000E0600130900140C001810001A12001B0F00
190E001A0E001E11001D1300231600241700251600241500241600231500271800291A00
2D1E00302300352700392D003D3500403D00454B024159063A6508366808316C072F6B08
3667063C62043E5F033C5C013B5C013A6404366607316A08306A072D6B06306B05336A06
2F6B093269093A64063D6106486005535A02565600575C014F6303476406456609436E0D
3B760B4277084A76064B7F0942890D37911430981E299E25239E29239E2B279F2826A027
24A02723A028289D27299C232B9B232C9B232D9D262F9D28309E28329E2A319D2A309D2C
2E9E2C32A32B38A72B34AA2F2FAB362AAB3A26AC4021AC4422AA4924A94F26A85824A659
25A75729A75627A65326A45428A1582D9B5E3599673D93693C8F693F846342776248725F
4E6E57496E564173593E715B477355556D545E65576658616455665F5D685C5F6F665376
70477976457F7346845D5086455283435B805E60756760736C556F6B4D6D7E46697D426E
7C476A72506878635F7475507873498B614D7A575365555454694D50784650863B548B2D
578A1E568B19578C18578F16588D15588C11558B114F8D134C8A174B8816448115467A0E
4A6E074E60045051015143004B3700442B003F2600402800402900402900402A00412900
3F28003C25003C23003E25003B27003C21003D22003E21003A2200382200382000382100
371F00351C00331E00321C00301B002F1B002D1D002A19002C1B002D19002E19002A1B00
281700281700241300221100201000190E00160C001107000E06000B0300070100020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000FF0000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000301000401000601000804000B0700110800120B00180D001B13001A13001B1100
1C11001E1100201600221700261900261B002818002719002B1A002A1D002A1B002A1C00
2F1D00332300372A003C3100423F00444B004057043A670930710E30700C30720B317008
3C6B064065033F61023F5F003E5C003C62033A65053569053168052E6E07316F07346F07
316F07346D07386A06376908406B074B6605566502546D054A750944750B457B103C8219
2E8919308A13368C123893192F9B212B9F2A24A33222A53822A63A20A53524A52F23A42B
21A52E22A33026A32D28A12A29A0272FA02732A12632A22634A32531A42831A6292BA72B
24A62D26AB2F28AE3427AC3B23AB4422AB4A23AC4923AB4C26A94D29A84E2AA94E2BAC50
2BAF4E2DAF4E2DAD492CAC4E2EA75631A35C309E65319F65309763308C5F367E603B755F
406E613D6A633B74693E766841765F516B5A5C615B69556566536E576270516774595D79
66507B684780674485534B854155813D5D805361775D6075665674694C717A476A7A446B
814D69765C67716B5F73744F766C4A73624D67604B656146597140537F3A55872F568B27
578E2054931D52921A5293165691125690105290124E90194B8E1C48881A487F154C720D
516508525804554A01543C004C3300482900422600412400432600432900422A00422B00
402B004027004325004025003E25003F24004024003D25003C2100372300362300362200
362000332000301D00311F002F1B00301B002E1C002C1C002F1C00301C002E1B002E1A00
2918002616002417002112001E1100180D00160A001108000D05000A0300060200030000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0200000402000502000903000B0500100700130800120B00180C00190E00181000190F00
1A0E001D0F00211200261800271C002B1D002C1E002E1C002E21003123003220002E2000
3422003A2B003E3200434001434E03425D0639670A3171102A7B142F790F2F780D34750A
3A70073C6A063D66043F62023C5D003B6202396104396505356806326D0932700B357009
31720833700836700836710A3D720C4473094674074C7C0947810F407F113D8418378D24
279328289522259924249F3020A43620A83E1EAB461EAD4A1EAB4A1EAA441EA9391EA835
20A63524A63427A3302AA42A29A42A2EA42830A4262EA5272DA8292BA82B29AB2D24AA2E
20AC331EAF371EB03A1FAF3D21AB4323AB4425AC4028AB402CAA4031A93D35AC3E34AD40
33B04032AE4531AA4530AB4D2FA9552FA65A309F5D2DA1612D9B642C92622F8861337E63
377366396C6A3C6F7045727041716C4C6763555B64665668695870546573456B774A5F7C
58577D604E825946844B4F813F5B7E3B667C496678576073665673675275794D6B784C6D
7F536A72636A6D6F5E77754B726A495F5F4A576641597140547E39528936578B2B548E22
52921D4E961E4E96195093155092135091114E9014478F1A438F1D48861C487C154E6F0C
526007545403564800533F004F3500492E00482800432700442900452A00452C00422E00
462D00412B004027003E26003D26003E23003E25003F26003B27003D2300372100352100
341F00352100341D00341C00311B00301B00301F002E1C002F1900301B00301C002C1B00
2A17002715002314001F12001C1000190C00150A001109000D06000B0500060200060000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0201000401000502000804000D0600110700120A00160C00190E00190F001911001A0E00
1D0D001E0F002313002719002C1B00312100312300332200342600392700372600362600
382B003E3801424503455105416109376E0E307510287A13247E152B7D0F2D7D0D317B0C
357409346E093868073C66053964063865053C63073C6408396809356C0B35700D37720C
2F770D31760D35760D3877103A7B113D7A0E3F7E0E4688143E8B1F37881F378B24329233
259737229B30209F351CA5441AA9481AAB4B1CAE521AAF541BAF5219AE4719AB3D1CA837
1FA73824A93727A73427A83025A62D2AA72C28A82926AA2B24AB2D24AC3122AC331FAB33
1CA7391CAB3B20AD3D22AD3F24AB4125A84128A93B2BA9392DAB3935AA353AA9323CAA36
3AA73637A74032A54130A74C2FA85331A75235A55135A257339E5F2F9A5E329561308A61
337A67326B6C3469733968733B6B73496668535F67665A6B6F5C715664754268793C627F
44597E494E824948863C558134697D30717B3B6A784D617461587366577270556C6E596C
785B697068636E7553737E446D71425C6441556E40547B3C51853A548F3850942E529723
4F981F4D9B244D9A1E4D97184C95164B951747931944921F428D2047851C4E7412506309
525503534B014F4200503C004B3500483000472D00442B00482C00482D00442C00432D00
432D004129003E26003C25003E23003B23003C23003D27003A27003A26003A2500392100
392000332000341F00321D00321E00321F00342000301E002F1C002F1B002F1D002D1C00
2816002317002215001F13001D0F00160C00150B001008000D07000B0700080300050000
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0101000401000702000B04000F06000F0700140900170C001C11001E0F001D11001D1100
1C0D001F1100231600291800301D003021003326003425003428003629003B2D003B3100
3E3A0144480344540742620B3970102B7C192D7B16297D14247E12297C0C2B7E0A2E7D0A
31770A31720C336D0C396C0D36690E3A6A0E39680F38660E376A0D316C0E346F0F357410
307B132E7D15307D163180183583183782153585143C8C1D398F2C33902C308F322F8F40
2294481F9D4220A3451AA95417AC5419AE5617AF5713AD5714AD5415AB4A16AB411AA83C
1DA83C22A73823A63725A93523A83126AA2E23AA2A24AF2D23AE3125AE3724AE3A23AC3D
22AA4121AA4227AD452BAB452DA5442EA2442AA3402BA6402BA94034A9393AA7353FA631
3CA43236A53A32A2402FA4502DA6522FA85034A74D35A64E33A355319F59359B60318F66
2C7E692B696B2D656E325F733064763E657245646E4D676E506771486B714169733A617A
3D587C3F4F823D4E86335C87296F8125767D2F6B78416174585B6F5C5C71655D6A666068
6F62666F71596C854969893F667A395F7237577240507E424F88414F933C4C9A32509D27
4D9D214A9E24499D22489A1C49981945971D45941F4290224289214A7D1E506C10535B06
524E01534300533A004E34004D32004A3100472D00442E00452F00452D00442E00432F00
422D00412B003E2A003C29003D26003D27003E23003F22003B24003E24003D22003C2400
3A2000362000322000311E00331F00332000311F002E1D002F1C002D1A002E1C002A1A00
2A18002318002216001E13001C0D00170B00170B00110A000E08000C0700070500050000
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
00FF0000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
0300000702000A04000D07000D0700130800180A001A0F001D11002011002014001F1100
1F13002214002616002B1D002F1F00342000312700332700352B00372F003C3701404402
435104415F0B3B6B123774163379152B8015308114307F122E7F112D7F0D2C7F0A2B7E09
2D790B2D770E30741237721535701A36711B336F18346F143370122E73122F74132F7A16
2C811C2D821C31821C2C862031891F34891A36891C3B91253A9437319536308E3D2A864D
1F8A54209B4E20A5531BA86515AE6217AE5D16AD5E16AF5C1AAF5618AD4A18AC411AAC3D
1DAA3821A83721A63320AA3621AA3023AD2C24AF2723AF2B23AE3129AD362CAA3A2BA93D
28A84227AA462AAC4C2FA84B329E4931974C2E99492B9D4A2DA14D30A24536A33D3BA438
38A63537A83D31A54331A3512EA6542FA75430A85132A74D33A551349F59399A60328F67
2C7F68296C6928646C295F74296478356773386C6E37706C37756D38786B3F736B3D6474
40557C3B4D84334A882C538B246A86247580286E7B3A657650616D55616D5C61695C6766
636A61697E54678D4561893A5E8035597A395378444D8046498C414D97384A9C314EA025
4E9E204DA025489F26479E21489D20489B2247962448902149841E4F751759660B585303
594A00543D005338004C34004B32004A2E00462F00463000472C00452C00472D00432D00
422E00433000402E00442B00432700412A003E28003B26003A27003A24003B23003C2400
3C23003922003522003223003322003522003220002F1E002E19002E1A002B1A00291A00
2717002419002215001D11001D0E00180C00160A001409001006000D0600070400040000
000000000000000000010000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000020000050000
0701000C05000D0700140900170B00180B00190D001D10002011002113001F1600231300
2212002415002B17002C1E003220003723003627003A2A003A30003B3600434704415D09
3C690E3772152F7C1C2D801B2D81182B84182F82183084192F85192D83112A830B298209
2A7D0A2C7C0C32791134781631751E3175202F771C2E771A2F78182978182A7B15297F19
26851E2C891E2D8A222B8D272E9125308E23318D2538932E36933E30953E2D8C42267E53
1E865C20995624A65C1BAA7214AD6F18AD6816AE6615AE6619AD5A19AD4E16AD4419AD3F
1DAE391DAC351EAB331EAC3220AD2E22AE2923AF2626AD292BAC2B30A82F32A72E33A62F
30A5342DA93E2EAA4630A34B32974E318C51318B513291543096572E9B502D9D472CA146
2CA6422DA6482CA64C2EA3552CA1572DA35A2EA3572FA154319E5A339A63339564338B67
2D7F6827716A24686E236176276679316D762F77712B806A2785662F8663397F64406A72
43537C3A48812F448829478B245E87246E84276F7F316A7B4369724B6B6F546A67526F68
5774625D8350648B406084365A7A38597C3D537D454B8A424A94394A9D354CA12D4DA225
4E9F1F49A02747A02D46A02D47A029489D284D97264D8D1D4E7D1756700D606006614F01
5D4300563D00523C004D37004F31004C2E004C2F00472F00472C00482E00452E00453000
442E00442C00442D00442E00482D004229004127003F27003925003923003A25003A2400
3A2400382100352000332100311F00332300321F002F1D002E1B002C1A002A1900271500
2617002116002113002010001D0F001B0D00190B001409001108000E0600090400070000
030000030000030000020100010100010000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000200000500000803000E0400
0E0600120900140B00170E00190E001D0F001F1300201300221400211600231700201700
2315002411002818002D1C00341F003826003B2E00403400413F013E48033E5C0C366F18
2D7E1F2B832524872C2889252D851C2D84192D84192C861A2B88192A871228860D2A820B
2A800A2B7C0A307B0E347A14317A203179232E7C212A7A22287E2021802024801A23841C
218923278D2328902526952E2D952E31902E308D2F3991343592442F95452D8D48268059
1E885D209D5625A85C1AAB7414AB7817AC7217AD7116AE7117AF6319AF5617AE4818AF40
1BAE351FAD331EAD331EAD3020AF2C22AE2829AD252FAB2834A7293BA42A3FA2273EA129
3AA42A35A5312FA6392CA6402D9F462E994A31994C339B53329C5A2A9C5826985825985A
289C5728A05E24A05D299C60299C602C9C5F329B5F319A633097692D976D2B95692D8C6B
2B856C27796C2371701F6975216E79297874288770248E662092642690623387653B7272
42567D3C4285323C88283B8A244E8A26648A276F88326C7E4072744977704D766A4E7766
527D5C5D8C486593386385335E75395A783D537D3E4E8A3A4A973449A02E4CA22A4C9F25
4B9F2347A02B46A13144A130469E2C459B274A942350871B55760E5967045F59015E4B00
5D4100543C005437004F35005033004D34004A3200483000462C00452E00443000462F00
443000432C00422D00442B00432A004228004027003D25003E26003D24003B24003A2500
362300312100322100332000312000322100301F00311D00321E002E1C002B1A00281A00
2817002414002114002212001D10001F0E001B0C00170A001408001007000B0500080200
060300060300050200050200050100040100030000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF0000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000200000401000903000A0700100800
120B00140900170D001810001810001C11001E1200201300221500231700271500261600
231300251700291A002D1C003624003B2B004132004644024251073A5F0F38711B2F802B
288A322A8A2F298C2E298B282B871F2A851B2D85182988172989162B87112A870F29830B
2B7E0B2E7B0B327C0D357E1530801F2F81242B82242781262483221F862321851E238923
218D2B24922A26972C239A33279B352D95352F92363394383490472D944B2B8C50267E5E
1F885E239F5626A95E1AAA7612AC7D18AE7616AC7814AC7614AE6915AE5917B04E1CAF40
1EAF3720AD3422AC3323AC3121AC2C24AD2828AD262EAC2733A8283DA52741A126439E26
459D293D9E2E31A5342CA63D2DA4412FA5482FA54C30A4512DA25E299B62229367258D6B
258D6D258C6E238F6C278E6D28916D25936E25957226967525957926957B299277288B77
268576247D752178751C75761D7D761F89742097721F9A691E99652391632B866B39717A
3E5A8539498B2E4889264A862455842B61852D6985326C813879793C826E4680634D8161
558A5163954163983561863658763F557A40518241508E3C4D9B3649A33148A12E499F2C
49A02D46A22E45A43145A52F449E2E4499274893204F7E15566C075A5E015F53005B4300
563E005238005137005137005235005034004E35004C34004B33004A2E00462F00462D00
432F00442C00442E00452C00442D00422A004026003E26003B27003C27003B26003A2600
362200352300322100322200302100341F00341D00341D00331D00301E00301C002C1A00
281900271700241300221200200E001E0F001D0E001B0C001709001408000E05000A0400
090400080400080300080300070300060200050200020100020100020000020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000401000802000C0600110800160C00
170D00170D00181000190F00190E001A0F001B0E001E0C001E1100231200261300281800
2717002618002918002E1D003426003F3000433D004854083C66143174222F7F2C268939
238F3D278F38268E38278D2F298C26298B202A8A1C2B89182A89132C8A112C8A0F2D8610
31810F307C0F337D113480162F831B2F821F28831E24861F238721208925228B24228D29
219131239532239A34209D3D239D3F24983E29963D2E973E2D944A2C964E2B8C52277B61
23866226A1572AAA5E1CA97711AB7F18AB7A15AB7C10AC7C12AB6E12AE6018AF521DAF42
21AE3A25AA3526A92F25A92C26AB2826AB242AAE262EAC2730A82937A6283AA0283E9D2A
3F9A2B3F9B2D35A03130A23A2FA6402DAA482BA94E27A85726A363239969248973247F7B
217C7D20777D207D78247F7724857A21897C1F8F7E1F937F20967F23988124937F248D7E
238A7D21817C1D807E1B807C1B8A751B94731BA0741CA26F1C9C67209367288370346D7B
3A5A8A3753912D578A255A84255C802A5F81306581316C7F317C7735876A4285614B8956
599449659C39629436607D3956703C517E39528C394F98374CA23848A43748A0364A9B37
49A03748A23445A53245A332429D2E4496244D891A55750B5A65035C55005C4B00563E00
5036004D34004D36004C34004D35004D38004A33004A31004A3000492F00472F00473000
463300463000472F00462E00452D00432B00422A004128003F2A003C28003D29003D2800
392400362500351F00351F00322000331E00341E003321003822003423003221002F1D00
2B1B002A15002715002315002211002110001F0F001D0C001A0C00140B001007000C0400
0905000A0500090400090400070300060300070200070200070100040100030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000200000601000C0500110900170B00190D00
1910001B10001D0F001F0F001D10001A0E001C0E001F13002014002013002416002A1800
2819002819002A1C00301F003729003F3600444801445F0D3673232982352887341F8D39
259038278F371F8F39208F32228F2A229029258E20298B172C89122C8A132A8C142C8A15
2F86153281153181163082152D85172E84182785162088171F8B1F218F2925922C229332
20953E22983D219C411D9C491D9D4820994722994824994626964D289851278A56237663
24856627A05928AB601BAB7812AB8018A87E16A8810CAC800EA97611AB6416AF551FB146
22AD4026AB3728A92E2AA9272AA9242CAA262DAC292EA92C2EA72E32A230339D2F359C2D
369B2C389B2D359D32359F3732A6402DAA4628A85122A45F22986A1F8C72217A7B206F81
1F67811D60801D677D216F801F78871B7F871A86861C8E831F958221998122997D24947B
23907C2089801E867F1C877D1A8F77179A761AA47919A6731E9E6A208D6B297271315F7C
3253863354872C608429647F2960812B60832D66822C70812D7D7532856840875F479153
599A4767983869863560723B5571394F81344E92314E9D364BA23A49A53C45A040439C43
489F4045A53D43A63643A236429C2F498F21507F0F5767045D5801604C00564400533B00
4E35004B30004932004C31004A32004B31004B32004B35004D3400493100473000473200
4A33004A3000473000462E00432C00412D004329003F28003C26003D27003C27003B2700
3E28003B2700392300372100341F00371F00352000361F00352300362100362200331D00
3020002E1E002D1A00271A002417002514002213002010001E1000190E00140900100600
0C05000C06000A06000A0400090400080300080300080400070400060300060100030000
020000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000100000201000502000B0400120A00150C00180D001B0D00
1B10001E11001F11001F11001F12002012001F1300211500221400231500261800291A00
2E1D002B1C002E1E003121003E2C00403E013E52033C69142C7B2923863928892E248B2B
258E2C248E321E8F391F903222902B229227278E1E2B8A152B89102C8A1429901828901A
2F8B17318516328316318214338214308315278513208914218E211E94301E96361E973C
209944209A441F9B481D9A4F1D98521D96521F9754229A51229851219751258A57267564
24876429A35A29AC5C1BAD7213AB7B16A87D11A6800FAA7E0EAC7510AF6419B0561FB24C
22AE4525AB3A27A82F2AA7272CA8282EA82A2FA92E34A53233A135319F372F9D36319D32
339F2D35A03037A03134A23632A63F2DAB4728A65421A1662095751E8A7822787E1F6B85
1D5F85185782175C801A65821B6D851B7088207887218386238D85219980229D79259F76
219E772099781E947B1E917B1B967D199D7C1BA1811B9F7C21927323816C2D66722E5A7C
2E54812B5A812A647D27687D2C67802E6A822D6F842C75812C7C7533836D378563439354
589B426697316587305C7B35567D31538C2F4F96334E9A374A9E3848A23C44A13C41A040
41A14045A43D45A34041A13848972E4E861C5670065D5C015F4E005D4500573E00533A00
5135004D31004F31004B32004C31004F31004D33004D34004B3100492E00482F00482F00
4A3200493000472E00432B00432A004129004129003F28003F2A00402900412900412A00
422C004029003D25003C22003B2100392000361F00372200372400382300382300342200
3221002E1E002C1D002A1B002817002613002214002213002011001A0E00170C000F0900
0D06000D06000D06000C06000B06000B05000B05000A06000A0600090600060500070100
060200030200030000020000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF0000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000301000400000701000B02000D0600120A00150A00170A00170D00
1A11001F11001B0F001F1100201200241600271800271A00281900281A002A1B002B1B00
2C1D002D1C00352000392600413300414603375C06366E142B7D262587332A8825268921
238B22248D271F8F2F228F2A228F24208F20278D172B89122A880D298D1228911727911B
2E8B173186163484183583183A7F193084192C8615238B182090221E96341C99401A9846
1C984C1C984D1C9A4F1B9A581D9B5C1D9A5E1D9B5E219D58229954219553228A59257865
25886329A4582AAB581CAC6D13A87A15A57D12A5810FA87E12AC7413B0631AB2531FB045
24AE3E2CAC322EAB2A32AA2535A92438A8273BA72B3DA22C3C9F2E379F2F379E30379F2C
34A12B37A12F37A33234A6372DA84028AB4D24A65B22A06B22967420897A2179811E6A88
1B5B86175083145880176380186A821D6C85207183277C8027878025947C279F7024A46C
1EA66E1EA2731C9E781E967C1E97801C98851F96861F8F80287B752C6C7038587A32567E
285C7F22687E24727926767A2D717B2E737D3074802F787E2D7C7A328173368567419554
589E3A64972D5F8D33588A38558B365590355197374D9A3A489D33459F31429F33419E35
43A13645A23444A03347992D4E8B1F5B76106263046051005F46005C4000583C00553B00
5238004E36004F37004E33004C35004C34004C33004B3300482E00472E00462E00472F00
463000473000453000432E00422B003E2C003F28004029003F2D00422D00432E00433000
432E00412D004027003F26003D24003923003C23003A2300372400382300362100342300
331F002F1E002C1900281A002917002715002415002112001D0F00180D00140C00120A00
0F09000F08000F08001008000F08000F07000D07000D07000E07000C07000A0500080400
070400070300060100040100030000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000300000302000501000901000D05000F0800140A00160B00170D00170B00
190E001C0F001C0F00210E00211300281700281800281800291800291B002B1D002C1C00
2E1F00331F00382600412D00433E004050033064083070102B7F1D2789252C881C28891A
248A1C248C1E1F8E24238E23258E1E268D192A8D132A8A0F2B8C0E2A8F102A921727921B
2F8F17308B1933891B38871D3786213389202F8B1A248E192292222095301C983C199842
1B994D1D9A4D209B511D9E5A1E9F5F1FA0641DA2631FA15C1F9C551E994E1E9057227E66
218D622BA5552EAC5720A96B15A77A13A07D14A08213A57F14A97216AD5C1BAF4720B038
29AF2E31AE2636AA2038A91F3AA91F3FA72043A62244A323429F23409F243F9E263CA028
3AA12A35A32F32A8342BA93F26AA4823A95522A66121A16A229872228B78207A7F1D6885
1E57872049871B53831A627E196C80206F7F25767D2B807C2C8A782A967229A16724A869
1EA86B1CA36F1A9C751D937E1C93821C8F8422838128767C316476385C7544587A38647D
2B707E227E7D258676258576277D782B797B31747D31737B337479337C76368668469952
5E9D38658F325C8640568942528D4051933D509B3E4D9C394B9C2E479B27479B27479B27
459F2B479E2B4998264F8B1D577A13636708665701634B006144005C3F00593C00593D00
553A005338005335005133004D33004C3100483200472F00462E00462D00452800442A00
442D00462F00463100432F00422E00412B00432900412A00422D00432E00453000443100
462F00432F00422B004029003D28003E27003B28003A27003B2500392200352300342100
341D002F1F002E1A002B1A002817002617002415002013001C0D001A0B00150A00110A00
100900110900120A00110A00110A001009001009001008000F08000F07000C07000B0600
0B05000A0500080300060300050000020000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000401000603000703000904000E0700110800130900180A00190E00190F00
1D10001C11001E0F002111002413002917002818002B1800281C00291E002B1D00302000
321F003525003E28004635004649013D5B052D6C0A2A750D2B7F142989182E8B162B8D18
268F19288D1A268C1C278C1B2A8C182B8C162E8C112F8D10308F0F2F8F0F2E93122D9216
2E901A2D8F1E2E8F20328F1F328E2033901F30921D29941F25942120962A1E99311C993C
1C9B471F9C491F9F4B1FA2571FA6611DA76A1FA76C20A462229C571D9E4E1D98561F8666
2594642FA55432AB5422A76E16A27E179C82169D8615A38017A67218AC5919AE4021B12D
2AB12335AF1D39AE1A3AAB1C3CAB1D3EA91E41A81E46A52148A021489D20439D253B9E2A
32A12E2FA5332CAA3B28AB4824AA5325A65D24A264239C6B2191701F84761F757C1F6781
2457802A487F26517D245F7C246B7E27757A2A82752E8C712E946A2C9B612BA35B27A760
23A8671E9F721A947B1A88801B84841B7C831F747C28667730597832667934757B2C8478
268F7A239878259A79269475268479287A76327075366B763867793976763E89644D9E49
6498376685375E7B41577F47528345528C4052973E4F9C384E982C4C98224895214B9621
4697244D9620528C195A8011636E08685D036451006047005D3D005B3F00583E00583C00
563A005537005435005131005133004E33004B3100482F00402B00412900462A00452C00
472E004C32004A3400483500473500452E00432E00452E00452F00472E004832004A3200
473000412D00412E00432F00432D00402D003E2B003B26003A24003B2400382200342100
341E00321C002F1A002C19002917002716002415002013001C0F00190A00160A00130A00
110A00110B00130B00130B00120B00120B00130B00120A00110A00120A001008000E0800
0B08000A06000A0400070300060200050000020000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0101000502000803000903000A05000F0600100800140A00160C001B0C001B0B001C0F00
1D12002014001E13002112002715002A1C002919002A16002C1A002E1F00312100322200
3525003C2700403000463F004652023965072A720D2B770D2C80112C8912318C142A9018
28911A2C8F18298F17298B182B8B172E8A16328B10348B0D368E0C37920E3292132E9319
2D932028942B26942B2994252995242E97212E9A22289A25279A24259A25219A2C219C37
1F9D40209D4526A14C21A6591FA8601EA8681FA66E21A4621F9F581CA44E1CA053219661
279C5D32A84E35AB5022A96917A27B189B7F15998314A07F16A27115A65B19AB421EAD30
2AAE2633AD1D39AE1C3CAD1E3CAC1F3BAB223BAD2740AA2544A62640A52738A12C30A030
28A33824A64025A74926A85226A65E28A364259969258D6D2181731F76781D6A7D20657B
2A5D7A3055763058752F5E732F6A77307A712E8D71309567319A5F309C562DA2532CA658
27A664219D6F1D907D1E83821D7D821F727D226A772B5C763258772F75772A917826A073
25A77323AB7327A7722B9B752C8A782D817435756F3B6B6D3E617140736B468F5D56A345
6898346682355B7740577B465280465289435195404F993A4D98314C95264B93224E9121
508E1D548715617C0E6773076A6202675301644A005C43005A41005941005B3D00593D00
5539005437005232005031004E34004C3600493000472F00462C00442C00482D00472D00
4D2E004D33004D37004E3700473500453100442F00432F00482E004A2F004A31004C3000
492E00492E00452E00432B00422D00402C004027003B29003A24003A22003B2300382200
341F00331C002E19002A18002A17002615002214002113001B1000180B00140A00130A00
120B00110B00130A00130A00140A00150B00150B00150B00150B00140A00110A000F0800
0D08000C08000B06000B0400080300060200050000010000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020000030100
0702000804000C05000D07000E0700110700130A00150C001A10001C0E001F0F001E1400
2017002216002516002715002819002C1C002A17002D1A002E1B00302200332600392700
3A2800402D00453800484800465C03396C0B267A142D7E133082112F8A11318E132E9019
2A90172E8D132E8D10308C12308B102F8C11348C0C388E0A368E0B378F1230921C279526
25952C2195351E98371F99311D992D259D2B2BA12B2BA02A299C26279D27229D2B209D35
21A04122A24724A54E25AA5B21A96220A86520A26A23A15F23A0561FA54920A64B27A055
2AA34F33AA4232AE471EA96015A17418967E19948214997D159A70169E5D18A44A1EA73E
27A9352EAC2E34AD2A36AD2A36AD2D33AD2E31AC3336AC3238AB3333A6372CA03C279B43
239B4520A04D20A15521A35E21A56423A166208F6C217B72216B7622667822647B286977
2E6C70316E6E33696D3566683571683180692E91692E966030985E32995530A0512FA754
29A662259F6C23927821858023808022797926776F2E716A3277672E8F6E2BA57329AC71
28B17028B16D2BAB6F309D70328D74358470387B6A3D6E68406B66457E63509A5461A53C
6B962A63862C587F3656833B4E88404E8F414C98404C9B3D4A993349962E4D8F2551891C
5881135E78076871036C62016B56006550006147005A42005842005A3F005C3E00563B00
5337004F35004D32004E33005035004D36004B31004B2D00482E00492E004731004D3600
5034004E3A004E3A004E3A004C3700473300483100442F00432E004A30004A2F004A3000
4A2E00492C00462C00452A004329004229004027004026003E26003D2700392500392200
331F00321E002D1B002A18002718002616002417001F12001C0F00180C00140C00130C00
130C00140A00150C00160C00160D00160C00160C00160C00160C00160B00140B00110A00
100A000F09000E08000D06000A0600070300070200050000020000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000FF0000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000030000050200
0904000E0600100700120700120B00140A00160B001C0E00211200221300221100241400
2615002614002316002714002619002B1C002A1A002D1C002D1F003324003723003B2800
3F2E004436004843004450003F630634751127821F2E831B3289172D8E163190172C911A
2E8E15328F10338F0C338D0B348F0B2F8F0C338F0C348E0C308F0F2B911C27952E20983C
1F98401A99431A9B441A9C411B9E401E9F3D21A23926A2352AA22D28A12E239F3222A13A
21A24320A54A22A5521FA75E20A6651EA2641F9C69229B60229E5422A84322AA412BA748
2DA74034AA3530AD3A1BAA4F17A0661C90771C8D811A907F168D73159265169C541EA34A
27A7412EAA3734AD3135AE2F34AC2E35AD2C31AC3033AD3631AC3E2EA842279F4824954E
20984F219A56229B60219C65219E6921986920876D227372206773246971296B7129766C
2D8269308969338164377C60348260338C5C2D975B2D975C30955B349757319F562EA55D
2AA56728A36A279A6F288F72298C732A88722C8C68328F5E35975D34A26534AB6D32AC71
30AE7030AE6E2FA86732986B358D6C3B836B3E7B683F736441796148905755A2446AA02E
7092226580225D83265589324F903A4D9840499A40439B4046983D47952E4B8A205A8016
6271096A6801696100675600664E00634A006044005C41005844005B44005B4100573700
5138004F32004F33005133005036004F32004C2D00492D00482B004C2F004F31004F3900
533B00513A00513B00523A004F36004C3300483000482F00472D004A2D00482E00492F00
4C3200472C00472D00452D00442B004629004027004327003D27003D25003C28003A2500
381F00331F00311A002D19002A1A002719002416002114001C1100170D00150E00160E00
160D00150E00170D00160D00170E00150D00150C00150B00150B00150C00160C00160D00
140C00110A001009001009000F06000B0500090400060100020000020000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010100040100080200
0E0500100700140800120900140A00150B001C0F00201000201500231500251800251800
271B00291A00291900281900261C00291C002B1A002E1B00321D003922003B2200402900
413200463C00494A014058023A6A0C307B172689272E8B25308E222D951F2F941C2E9118
2F8F11338F0D308E0A328F0A30900C2D910D2E900F2B91142693192596262399351F9B41
1E9B401D9B3F1A9B40199E4118A0431CA1411DA33C1FA43D24A53623A43321A43720A640
1DA6491AA64E1CA6541FA56122A3651F9E6421946A249461279A4F25A73A2BAA372EAA40
31A93434AB2A2EAC301CAA47179D5E2189721E83841A8683168478168B69189A5920A34C
27A9402BAC372FAD2F31AD2C32AC2633AA2432A92A30AB352DAD422CA94B249F52229457
21945924955C26966625966B25966A218F6C22806E237071236F7026736C257867288564
2F955F30995E33965B3592582F95562D9A552C9C522E9A502F994F319C5230A25A2EA464
2BA46B2AA36B29A3672A9C6A2C966D30926C33996132A25B35A85F34AA6633A86D33A275
32A47433A571329E6C31886A33826A3B797040776D407C6342915C4EA14965A12D779016
787C0E717411647B135B841C528F284F9738459B40469A4245963B49902B51861C5F770E
6A69056B5D006C5500674E00654C006447006143005C42005A44005B4100574000563A00
5139004C39005236005336005337004E34004B31004B2B004C2E004E3100503400523B00
563B00543C00533C00533D00543800503600493200483000472F004A2E004933004D3000
4D3200473100462D00442E00452C00432900412B00442700412A003D26003C26003A2300
372100351E00331C002F1B002B1A002718002415001E14001D1000190F00180E00180D00
180D00190E001A0E001A0E00190E00170C00170C00170C00170C00170D00170D00160B00
140C00150B001309001209000F09000D06000B0600090400060200020000010000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000100000200000401000A01000D0400
110500140A00160D00160B00160B00190A001B1000201000251400271600281600281A00
2B19002B1A00281B00261C00251900271B00261A002E1B00301E003A25003A2800403000
4336004542004750023C600536710E2C821D248E2C2A90292C942A2B97262E961C2D9216
308E11338E0F2F900C2D930C2B930E26940F26931623931C1F942420962B229A33229B39
219B36209D341E9D361E9F3A1B9F401CA14019A33B1AA63B1CA7381EA83A20A83D1EA848
1DA6551BA6581DA35D1DA364209E692195691F8770218A6526975026A5372BA92E2EAA35
2FAB2C34AC262FAD2E1EA9421B9A5824826F227B851D7E8818827D178D711B9C5D20A94C
24AC3A2AAD2E2DAE2531AE2035AA1D35AA1D34AB2231AC322CB04327AA4E239E5823935D
23925E269162278D67288C6A278B6827836A267A6F296F7428766F297F69258A6329955E
309F5733A65236A54E36A54D31A54B2DA64B2CA6472FA44430A34331A5482FA75530A166
309D712FA06D2EA6662DA567309F66329C6134A25C35A96136A76531A06B2F9A722F9574
339676359777349370348670357F6A3F776A437B6A438E6547A44E58A7307098127A7E09
796E04766B05706F09617C11568A1C528F2C4A973B4A963C4C91355087245C7A166A6B09
6E5F016B55006A4E006849006248006243006142005D43005C43005C4200594000563C00
4F3C005037005438005137005239005137005034004F3300503400523400523800523A00
513B00543E00523B00533C00533A005339004E34004B34004B30004732004B31004D3100
493100482D00442D00452E00462D00432E00422B00452A00412A003F25003D25003A2500
392300361F003320002E1A002B18002415002217002111001F10001811001910001B1000
1C10001B0F001E10001D10001D0F001C0F001B0E001B0E001B0E001B0E00190D00170C00
160E00170D00160B00140900110900100A000F07000B0600090300050100020000010000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000101000502000A03000C05000F0A00
130B00170D001711001B10001A0F001B10001D0F00211100211500231600241700281800
2A19002B19002A1900281900241900291A002B19002C1B00331E003C2600412D00453600
443C004745004557023B6707347A112A872122923229952F27983328982D2A961E2C9115
2F8D11328E0D2D920B2E930D2B930F27961325951F23942A1E9534209634229933239834
249930219D2E229D2D209E331F9F391CA2391AA1381AA2381BA73B1BAB401DA8441BA94E
1BA7581DA65A1DA35D1EA06721986C218B6F1E747620796A24915125A7372AA92D30AA2D
2FAA2835AD282FAD311FAA441D9659247C6F2274871C7C8719837B19916E1CA0591FAD47
23AF372AB02C30B12232B01F34AD1D36AC1D31AD232FAD3529AF4E23A85A22985E208B64
218C63258A6527876828836A28806726786B2A736F2C6B722D79702A886B27976728A05C
30A65433A94C35AB4636AB4132AC412FAD402FAC4030AC3C2DAA3C2EAB4530A85430A363
2B9C6B30A06B32A5672FA96532A55E32A15C36A0633A9C6A37956D358F752D8B772F8975
358C753A90743B926F378E6A3E8A65458462488F614CA35556A839659F1B718907767301
7867007561006F69026771075D80145A8B2252912F4F8E2D528827597E19676F0C6C6204
6F5801695100674B00604C006046005F41005A45005D42005E44005B41005A3E00573B00
553B00523C00533500573900583A00563D00533A00533600513600503600533900513900
513600533C00543C00563A00543A00543A004D36004E32004B31004C31004D2E004A2D00
4B3000483000473000462E00452F00452E00452D00462E00422C004429003F2800392700
372300382100301F002D1B002C19002517002213002112001E11001D12001D11001F1100
1D10001F11001D11001D0F001D0F001C10001D11001E11001E10001C0F001A0E00180D00
170C00180C00150C00150A00120A00100A001009000E07000A0600070300050000020000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000200000501000803000E0400110B00140B00
190E001D0F001D0F001E1400201300201200201300200F00211000221300261600261800
2814002A17002D1B002917002816002613002817002D1C00331F003D2B00423300453C00
483F00494B01475D0637710C318019288E2B22973B269836269835279A2E2C961F2E9218
318D13358E0E338F0A2F910E2E93122795192496272296381D96461E98401E993E1F9A3B
239A35249C30219D31219E351DA03F1DA2401CA13E1CA13D1EA4401CA8441DA94C1AA755
19A55E1DA65D1DA3611E9C691E906F2480711F647A226C6A268C5022A43A28A7332DAA2F
2EAC2835AD2B32AF331FA9441C945A247772226B881B798618867817956B1BA4581FAD44
25B03528B02D2FB02731AF2334AD2132AD222EAE2E2AAE4226AF5A22A56624936823846C
25836A27836928816B277A6E27716F256D6E296F6F2B6B732B7E6E2D906928A1652CA65C
2FA95634AA4F32AC4832AD4132AD3E31AD382EAB382FAC3C2EAB402EAB4A2DA8542FA561
30A46634A66536A76138A75D35A15B359C5C3A97663D8D6F38867538857A348777338B73
3A8E6B3E9268419A69419B674895604C98584DA35155A64063A0236C940B727E01736D00
756400716100706400696B0163770F5A801B598625568321597D1C6672106D65056C5901
6B5000654C006449006346006142005940005641005841005A3F005A42005B3F00583D00
583E00553E00543900593B005B3F00583F00583F00543D00513600513800533500513800
563800553B00583D00573D005B3D00593C005139005238004D37004E36004B31004C3000
4C33004B34004935004932004933004934004A3100482E00452D00412B003F28003B2700
392300382200341D003019002B1800291800251600231600221500221500211600231500
2316002016002013001F12001F10001D0F001D10001E12001C10001C11001B11001A0F00
1A0D001B0D001A0D00180D00150C00130A001009000F09000C0700090400070100040000
020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF0000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000030000050000070200090500110500160B00180E00
1D0F001E12001F1300201500211600221400211300201100201100221600271600271700
2816002A19002F1B002D1A002A16002714002918002F1C003723003F2E00443900484500
48490049560342690B347D182E8A27279536249A44289B39259C32249A2A2A981F2B951A
309015328E10338D0D31910F2D921329921A24962C21993D1D9B4E1C9C4A1C9E4A1D9F47
219E42219F3D219E3D1F9F411E9F4D1EA04C1D9F451FA04621A34520A64A1CA6531AA558
1AA66119A6611B9F631B926B1D8470247571255C7928676630894A28A23B28A53D2DA834
2CAD2D36AE2F31B13A1DAB4B19925D1E7276216188187783168977179C691CA6521FAD41
23AF3728AF2F2CAE2E2FAF292DAE292DAE2B27AD3726AE4D25AE6225A56B23916E257D6E
267C6D267D6E257C7026737426697625677426726E257A6B298A662F94622EA15F2CA65D
2EAA5931AB5531AC5031AD4631AD4032AB3933AA3C31AA4132AB4930AA5330A85831A560
34A7603AA75B3AA8573BA654379E5B3795613B8A693B7D713A79733B7E783B86723B8D6D
438F64459560489C674A9C624F97564F9F4F58A64061A12A6A9414708306737700736900
706100705D006E5D00666401646C095C77155D79195B76176373116C68086F5B016C5800
6B52006A4D006648006343005E3F00583C00563F005640005942005A42005D4100593E00
594000593F00573E005941005D41005B4200553E00533C00513800523700523800523700
5639005539005C3B00593D00573E00583C00553C005438005139005236004F37004E3400
4F36005336005236005134004E34004B35004A3100482E00452B004028003E2500382200
372100352000351D00301A002B18002A1800281400291500231600241800271800271800
2519002316002215001F14001E12001E12001E12001E14001C11001D11001D11001C0F00
1C0D001D0E001B0E001A0E00160D00130C001208001109000E09000B0400090100060000
060000030000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF0000FF0000FF0000000000FF0000FF0000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000401000602000A03000F0500130800190C001D0D00
2012002012002014001E15002317002616002515002213002213002815002818002C1800
2B1B002F1C00321E003321002C1F002D1C002E19003120003B2500412F00473D00484600
485000455E05407313308624299230269942229D49299D38259A292798202C971B2B9519
2F93163292142F91112E92102A94122994182498261F9C381C9F481DA0461FA1461FA244
24A140259F40279F44259D4A209A51239C4E289F472CA2432BA64226A74422A64B1CA456
19A36317A36616996518876D1B7570226A6F2956773566633D8A432FA03728A0412AA73F
2BAE3737B03732AF411DAA52188F661B717C1E5E871A7782188E741BA26620A95323AD40
27AE3527AF3229AE3128AE3129AA3229A83925A94728A9562AA967289F6E258A6E25756F
237271227273217277236E7B29677B296C76287C6B278B6629945E2E955D2A9D5B29A35C
2AAB592DAC5430AE4E2EAF4731AE4034AE4033AB4133AB4632A95133A65A33A65F32A162
32A35E38A35637A2523A9C563A91603B86683B7B6C38736E38736F3B8072408C6E479364
4C975750975954985C539557559251589A475E9D3265951A71870A767C02746F00726500
6E6000705D006D5D006B6100686504656A0A616C0B6467096A61076D5E036D55006D5100
6B5000674E00644A005D45005A3F00583C00583E005B3E005C42005E44005B41005B4100
5942005A41005742005A42005D41005C3F005A3B00553C00533A00513700503400513500
533900553B00593B00583B00593B00563A00513800513600533500533700543900523600
503700523A00533A004F37005033005031004D3000452E00442E00412C003F28003C2400
392400352000351E00331D002D1B002B1A00291700281600261800271900271A00261C00
2919002719002417002216002114002114002214002214002114002215001F12001F1100
1D0E001D0F001E0F001D0F001B0F00160D00130B00120A001009000D0700090300080100
060000030000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010100010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010100030100050200060300050300040100010000
0000000000000100000200000302000502000C0400120700190C001E0F00221000231500
2317002416002515002517002817002818002B16002915002616002C16002D1D002C1D00
2F1D00311F00301E00312100301F00311F003123003827003B2E003F33004941004D5303
4463073C761333882C239446259A4A20A04B20A34828A130289B1D2D951132930E35930E
3392103294133196162F9817299A19239C1D239D1F229F2323A126259F29269E2B29A02F
2B9E342A9D3D2A9C3E2E9D3C2D9D38319E3534A23231A7322CA73128A93420A74020A54F
1BA163169D711B8F6D1B746E2361742C6273335F75427459478C35349E33279F4829A447
28A84A37AA4832A9531BA46815907B1878861A67891B8079209B6124AE4D2BB03E2FAF30
31AE2C2BAF322BAE3B2BAA462E9B52337F603B706D446B735268794A66783A62752A5C76
2359781F5C7A1E607C217977258C722C9B6438A45639A84E33A85130A34F2AA54B2AAA4A
2BAD472FAF412FB13F32B13F34B13B34AD3A36AC4034AD4A32A95630A76131A65F34A15D
3498573890573B895B4381654275703A6C7639746F3981683D90624C9B5F56A0555C9B49
6498446B8C4C5F834F587C4E5B774362852F698E1E70890F777F09757100766800746000
6E59006C58006B5A006C5D00695D00685900625500665000694F006A4C00694B00674900
6748006448005D4300583E00583F00563B00553A00553C00553C00553C00583C00553D00
583D005A3F005A41005B44005D43005C44005B41005B3F00593D00563800533800513700
503800533900573D00573C005A3E00573F00573D00563B00543A00553900543800523A00
5037004E38005039004D37004D36004C35004D35004831004B2F00472D00432C00412B00
3D2700382500352000351F00321F002D1B00271800271600271800291A002B1B002D1C00
2D1D002B1C00281B00261B00251900251700241600221500221600221400211300201200
2012002011001F12001D1200190F00190D00170D00160B001309001208000E06000D0500
0B0400060300030000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000100000200000401000805000905000A0800080700070300030100
0200000100000100000401000402000704000F0700160C001B0F001E1100221100241400
2317002214002317002715002A18002917002918002B19002C1C002B1F002F1F00311E00
321B002F1A002F1D00341C003120003424003A26003A29003F30004538004E46014F5D09
4272133A82252E8E421F955F1F9A561FA14B1DA44323A22E269D1C2D971331950F34950D
33941135971632971C309A1D2C9D2024A024249F2323A22322A22527A12728A0292AA12F
2C9E34299C3F289E3F309F3731A03135A12B33A32B2FA8302DA83425A73C21A74520A455
1DA26218A06B218B6A286A712D58782F6476306F77417E55498D32399B332A9D4728A547
2CA74F3BA95136A65D1EA67017937D197A841C68891E8174239F592BB04230B03734B230
34AC2D2FAC352BAD412CA651308F5A35726540616D4C5F715A5A74505F6F40646C2D676A
296A69296C682773692A8C642B9F6130AA5637AC5036AD4C2EAC4E2CAB492AAD422DAD41
2EB03E34B03C32B23D33B03F33AF3D34AC3C38AC4037AE5032AF572FAC5D30AA5733A052
3693503E8557457B5E4774673E686E3965713A7E663E925E4C9D5657A0505D9B48609447
678A496D80535D77535775495A77396382246B8A1970820B787906786F00756900716100
6D59006C54006A5300675400695400665000645000655000665100684D00684C00644800
6647006348006144005D3F005A3C005A3A00553600533B00563B00573C00563B00573D00
583E00593E005A40005C42005F42005A4100594100563F00533C00523D00533900533800
543800593B005940005C40005D40005A42005941005B3F00573E00543900523B00523C00
503B005038004E37004F36004E36005237004F35004D34004A3300483000412F00402B00
3D2500382400342100361F00351F00301C002D1A00291B002A1C002A1B002E1E002C1F00
2C1C002B1C00271B00271C00281A00271800261400261500241500231600231500231400
2114002113002012002012001D10001B0F00190E00180C00160A001309000F08000F0700
0D06000B0400060200030000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000200000202000302000602000905000C08000D0B000D0B000D0A00090600060300
0401000200000101000501000804000E0600130B001A0E001E10001F1300211300211300
231500241500271600291800291800291700281A002C1B002E1D00322300382400352500
332000331F00331C00361E003722003A25003D2900402E004636004A3E00554E0253690F
428223368E3D2B93561F976D209D5C1CA24A1AA53C21A32C269E1D2A99162D9A142E9B12
309D16349D1C339E21349F262FA12828A12C25A22923A32824A32728A22929A22D2BA22F
2CA1322BA03C2EA13C32A23132A12A35A32733A52A2FA8322CA83B27A545249F5323A15C
1FA4631CA365298B6733686F385B73356C72317C7243864E518D2E3B9C352CA0422BA443
30A65040A5533AA55F1DA97218967C1D7980226184247D6F289B572EAE4733AF3E35AE38
33AA372DA8402CA64C2B9B562C8B5A2F79613572653D71684471673F796236815B2F8755
2D8C4D2D91492E974A32A14B35A74F35A94D36AA4F2FA95327A95328AA4D2BAB462FAC40
33B03C34B13D32B14131B0462FAD4732AD4734AF4D30AF5B2BB0602BAE612EA95534984C
39884D447C554C775D47756442706140795A468B554E9C545A9C4F5F97495D8B49637E4E
6876536A70585E71515D76425E7C356282206C8411727F0B767405766A00736400725C00
6F56006C5300685100675200634C00624B00614B00654D00684F00694F00694E00674A00
654900664A006447006144005F3F005B3E00573D00583800583A00533B00573D00543E00
593E00573C005A40005E43005E45005B4300574200534200523D00523A00533A00573800
553A005C3C005D3F005C3E005A41005B42005E41005C4000593D00543B00533B00523800
5138004F3A004F35004D31004D34005036005035004C34004C3200462D00452C003F2700
3B26003B2300372000362100342000321F00311B002A1B002B1D002D1B002A1B002B1F00
2A1B002A1A00271D00291C00281B00281800261600261500241500261600251600251500
2413002213001F12001F12001D10001D0E00191000170C00160B00130B000F09000F0700
0E07000D0400080300050200
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000301000602000804000A06000E0A000F0C000F0E001010000F0D000C09000A0600
0603000500000500000702000D04001609001B0F001F1400231400211300231500241700
2618002918002B19002818002716002717002819002D1D002F2000362200352A00352700
3825003520003521003822003826003B29003F2C004132004A390051430159570454751A
3E8C372E944E24985E1D9A6D1C9F5D18A24719A3371FA229249F1E299B17299E1527A018
2BA11C2FA12034A02734A22D32A12E2DA1322BA32B29A62628A5242CA3252DA1292CA12B
2FA02B2EA23331A23432A12C35A22533A42732A62D2AA83A28A447259E55249962219F65
1FA46523A4612D91613777623A6D623B7A623884624D8B40598F283D9D342DA44029A43F
2FA14D429D563AA06520A8751B977723767C2B597E2D786B31995833AC4A33AE4635AC42
32A8442EA44D2C97562C8C5D2C885E2A83612D885F2E905D31975A319C4D2FA0442EA439
2CA9312DAB302FAD3334AC3D35A545349A4C3198502C9755299A552CA0522EA74B31AB48
32AE4234B14235B14931B0502CAE552DAD5C2CAD6128AC6B26B06825AA662BA158368F50
3C835045825645885C438B59418A50488D4852944A5A98505C964D5C8A4A5A784D656951
686757676754607348627C3E617F2F63821B697F0D6F780A736C03725F007059006F5200
695100694D00685000654E00614A005F4800604C00614900664A00674D006B4B006A4C00
684E00684C006448006143005B4100574000563C00593B00583B00573E00583D005A3E00
5E3E005D41006047006048005E49005E45005B42005A4200573E00543A00553700583700
583A005B3B005D3D005B3E005E40005E44006245006242005D4200574100533C00523B00
5138004E37004D36004C34004E35005136005136005033004C3100482E00462D003D2600
3F26003B2300392300352100342100321E002C1A002A1C002919002A1C002C1C002C1E00
2C1E002C1E002D1F002D1D002A1D00271A00261700261600241700251800251700251700
2515002515002214002213001F12001C1000190F00160E00150B00140B00120A00100900
0E08000D06000A0400070200
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0200000502000905000B07000F0B00120E00141000131300151300121200120F000E0900
0C06000804000B03000F06001409001B1000201500251700241600211500241600261A00
291C002C1B002F1C002817002616002616002718002C1E00312200362400352800392700
3B27003826003827003E29003F2E00402D00443400473A014B430252500458630D4D7E2A
338D4F2793612198671A9B7118A15C17A3431BA23120A027259F1D2A9D162AA11427A419
28A41E2DA22231A12633A32D30A4302CA5342EA6292EA32030A11B31A01C329E1F359D23
369F22359E24379F26379F2435A12332A2292DA13724A048249E54249B6023976C239F69
27A4652DA75D2E9D58319154378A4E3D8C4E428B525A8C335C8F1F3DA02D31A5372AA53D
339C4D45955B3C9B691DA4741F957629757932577C347969359A5736AC4B36AB4733AC45
32A94830A34E309454318C56308C5B2E8B5C3097572FA35030AC4832AC3931AC2C30AE21
2FAF1F2AAF252BB0312CAA3E329C47308C4C2E8B4C2C8C4C2C914D2F9B4D32A24B33AA49
34AE4736B24835AF4F30AD592EAB612BA86A28AB7027AD7326AB6F27A36B2A9A5D328E56
348A52399354399E543EA24E449F4151993D5B944560924D5D8B4B5C7E4D6368536A5C57
65655463694C607940618033638023637D1266770B6C70056F64026D57006B5400684D00
684D00694E00664E00644F00654D00634B00614800624700644600664A00674C00684A00
694C00654A006248006045005B4100573C00583C00583900553A00563F005A40005C4200
604500604700624B00614A006149006249006146005D4200583B00583A00573800583A00
593900593D005B3D005C3F005E42006244006347006149006144005D41005A4000583E00
543E00523A005239005035005336005236005034004C34004B32004A2F00452B00412900
3D29003D23003A2400352300331F00321D002F1C002D1D002F1B002E1B002E1E002E2300
3121002E1F00301F002F1E002C1D002B1B00291900271800261800271700261600251700
2515002514002315002315002114001C1300191100170E00170D00170B00150B00110A00
1009000F06000C0400070300
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010000000000000000000000000000000000020000
0201000603000B07000F0B00120F001512001715001A1600181700171600161300110E00
120900100600120A00180F001813001D1700221A00251A00251800261600271800281B00
2B19002D19002E1C002819002316002613002616002C1A002E1D003321003824003C2700
3F2B003E2A003F2A003F3300443800453900453E004B440150540653630E4E751F408442
288768228E6D1E996C199E6D19A35A1AA5431CA33022A22724A22029A1172BA21729A419
26A21E299E21299A29299F2C29A32F24A7362CA42B2FA01F339E153A9C143A9B16389B17
3E9B14409C15409B193B9B20389C2C329B372B9544268B59249160249863229B6829A263
32A75D34A75734A45232A24E379E48419843498F415D8B26588C16409D2135A5282EA334
359A4C48915D3B966B20A1722396702D7A73396277397F62389C5038AD4436B04031AF40
30AE422FAB4533A74937A14B3B9C503D965037A04838AA4035B03836AF2937AF1F34AF1C
31B01E2FB0252DAF302DA73B2B9B3F2E8F42318C44318B43349245379C443AA14638A747
38AA4B37AF4E35AC5730AB5E2BA76727A26C25A56E23A67326A26C289C662C975C319256
33954F38A04B3AA94842A9434F9F3B5B903B5F8843617F495F734A676451735855765357
6A6550637348648136658426678317667E0E6979056D6F026F64006D5600675000664C00
684E00695100664E00675400695000655200654900634600614400634800684800664900
6447006343006243005F43005C41005C3E005A3F00593F005C3F005C43005D4400614600
604700624700654B00654B00654E00654B006549005E4400593F005B3D005A3F00563F00
593F005B3F005A41005E4300644600644900644D00634D00624A006146005D46005A4200
574300563D00533A005237005136005336005035004F34004C31004E2D00482D00432C00
402A003F27003B2600392400362100351D00311F003020003121003021003021002F1F00
2F22002F23003122003120002F20002C1C002A1B00291A00281A00271800281A00271A00
261A002717002614002514002215002013001C1200191000190D00190A00160B00120A00
1109000E06000B0400070300
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010000010100010000000000000000000000020000020100
0402000905000E0900120E001613001A15001B18001C1A001C1A001D18001A1500161200
140E00150B001A0D001E1400201600241A00251C00261C002718002A19002A1900281A00
2818002916002B18002718002616002515002717002C1A002C1900331D003627003F2A00
422D00413200443400453A00454100454600454C014758054B6912467A24408736358954
238673228D721F9A6A1AA16A1CA45B20A74622A73624A52C23A62626A61F26A61E28A51E
27A123259929238F32249533229E3521A43929A22C309E21319B183C9A133E9B113F9B0F
409B0F3F9A113F9C143D9C22369A362E9345288653247665268860299A5B29A65735AA52
3CAA503BA6513BA153369F563BA14A439E404F96315C8B18558A0B4399103CA01F2EA22D
389C4A49925C3C986A24A36D279C692C886B34776E398C563AA34439AF3B37B13A31B03D
2EB23E33B03D37AF3F3EAC4142A84643A5443FAA3A3EAD2F3CAE283AAE2338AE1F35AE1F
32AE2432AE2A2FAF302FAD3631A43935993C37933D3C8D413D92413B99433C9C463D9E4F
399F5535A55B33A55F30A3642A9E68269C6B239B6B249F6B289D66299D612C9B52319B4B
38A1453EA74144A7404E9F3E58953C5F8440627C4464714765694B716351835C52845E4C
7069465D7338627E2869821C6C7E0E6D7A0D6C7505716F027266006E5C00685300664F00
694C00684F006B4F006D51006B50006A4F00674C00664700614600624A00634700614700
6041006241005C42005F40005B3F005C41005D43005C40005D4300604500634700624800
624800624900644800644A00634A00654900664B006449005F43005F43005B42005C4100
5F42005D42005E44005F4700644800664700654D00665000654B00614B006148005C4500
5A4300564200563C005139005439005235005035004E32004B3100492E00442C00412A00
3F27003A28003B2600392200382200331F003220003323003223003122002F1F002E1C00
2C1E002E1D002F1E002F2000311F00301F002D1C002D1A002C18002A1A002C1C002B1C00
2A1A002918002816002815002214002012001F0F001F10001C0F00190C00170C00140B00
1209000E07000C0400080300
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010000010000010000000000000000010000020100050300
0605000A0700100C00140E001814001B18001C1B001E1B001E1B001D1900191500191000
170E00190E001A0E00201400211600241700221800281700291B002B1A002C1C002C1B00
2B18002B18002C19002A1D002A1E002D1C002A1B002D1E002E1D003321003C2900423000
463A004939004C4000484901444E01435203435B0547670D437B23388840308D532B8D63
248C752290701E996B1C9F661FA55924A84C24AB4124AA3521A92D21AA2625A92228A822
239F272194321E833C218D3C23983C209F40299F32319C24359A193D9C15409F123F9E12
409E163F9D1A3F9F1F3D9B2732953E2D8B4C2982572374672788582B9F4C2EAB453AA947
3FA94D3CA0573C935D3A90614198504CA23D52A026578F145288094A900A41961534A127
3F9F4549985A3B9C6629A66728A25E2D985C328D5C399C483CAB3C3DB2343AB13537B136
35B3373BB03240B22F44AF3248AD354AAC3045AE2842AD2340AB243EAA273FAA2A3BAA2F
3BAB3037AF3135B13535B13937AA3D3BA2403F98453F8E48418C4C3E8B503B8C55388A5B
358D623393673493683292672D906A278F6B249368239A6526A06026A45A30A54C35A542
40A53C44A140489B3F55933F5E8A3F657E44687745687246676C486C6B49796947766E41
6875375E7A2A657F1C6C800F727D0B767807757102766A01736100705B006B53006A4F00
694A006B51006E5000694F006A5000684E00674B00654800614500624200614000604200
6242005D43005E41005B43005D4100614500634A00654C00654C00684B00695001694E01
674D00664D00684C00674E006653016753006B4F00654E00654F00654B005F4500614200
614200634300604600604600624900654A00665000665400635700635200604B005E4800
5C4600564100553E00533C00533A005437005334005035004C3200493000442B00412900
3C24003A2300382200372200352000311F00302000322100312200301F002C1D002C1C00
2E1D00301D00311E00321D00311F003222003021002D1E002A1B002C1B002B1D002C1D00
2B1B002A18002917002716002314002212002112001F12001F11001C1000180D00150C00
140A001108000D07000A0400
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000020000010000000000000000000000000000010000030100060300
0907000C0900100B001410001713001B16001A18001B17001C16001D17001B17001C1200
1A11001B0D001E1100201300241500241900231600241500261900281900281B002C1B00
2E1B00301D002E1D00301E003221003123002E20003322003423003725003F2A00473200
4D3B004F4500524C014C5703465E04436709406D103E771F37823B2B8861288B6D25906F
21937621926C1E9767209E5F23A35527A94D28AB4525AA3C1FAB341EAB2D25AA2626A922
23A2292095331D8142248B4128953D299C3F2E9C30359B21379A153B9C163AA11938A21D
39A22436A02E389E2F3B99333490422D8D4B298D542489612C974E34A64137AD413CAA48
3CA6593898643A86693A7F6B4591544CA04050A22B51941A4B890F5087084B900E3BA21F
41A53E4A9C57399C6129A65D2AA74F2DA64732A1433AA73C41B03642B4323FB2323FB235
40B03245AF2C48AE294DAC2650AD2351AC1E4CAC1A47AA1D45AD2348AB2C49AC3546AB3E
43AB3C42AC3D40AE423EAC453DAA483DA34D3D94553C8E573B8E5C3989603985643A806A
3C826F3B84703E826D37826D2F816B298669268E66279D602AA4572EA95036AA443DAA40
42A440489B405092415D8B436682466E79496E734B6C73476671436673406A74386B7932
677F29657E206B7F126D7D09787804797302786C01796700746400705E006E56006B4F00
694E006B51006C50006A4B00624B00614A006545006647006543006043005D41005D4200
6044005F43006340005F4100614800684C006B53016B57016B5B016C5E026C5F046C6104
6B5C026D5C026E5E01695F01676103675F02695900685700665701665000624800614500
5F4500604400614600644800644A00635100655800625D00635F00655A00665400644D00
5E4700594600594300543D00553B00543A00533A005339004D36004E35004A3300412C00
3D28003B2400362200342100331E003320002F2300332300362300332000302000312000
311F00321D003320003723003526003524003222003021002D21002D1D002C1B002E1B00
2D1B002B1A002917002817002617002312002114002112002010001E0F001C1000170C00
150B001309001107000E0600
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000020000020100010100010000000000000000000000000000030200070400
0A07000C09000F0D00140F001814001B14001B17001C15001C16001B15001B15001A1000
1B11001F10001F1400241700271A00261B002619002816002A19002B1A002C1E002E1D00
2E20002E20002D21003323003024003223003421003621003A24003C29003E2C00483600
504300505000525B024C670842710F3F7718397F24398534308853228774248A7A219273
1A99731E97691F9761249C5728A34F29AA4C26AC4624AD3C1DAC331EAB3023AC2826A924
24A5271FA02F1C9737279B342F9C30339F2F399E233C9C183A9D1038A01831A42432A42D
31A33531A240369F3E39963E358C452F8D4C299952259E5C32A44B3CA5463CA64B39A355
389F6737926C3B8467387D5F488C504D99454E9E384C99284B8D1854850A51880742A018
42A437479C523698572AA74F30AA4033AC3937AB333DAD3043B13043AF3046AE3345AC37
47AC314AAD2B49AC2A4FAC2452AA1A54A91553AA1351AB184DAE1F50AC2A4AAC374BAB45
4AA6454AA04848A04E44A45340A35A3D9D603C94623A95643A98663992693B8B6B3D846C
428570468170437F703A807031836C2C89682794612DA35A31A94C3AA8423FAB3F42AC41
4BA24654974E5D8E4D6788486E7F4778734A7470496A7143656E3B646F3464742B6A7E24
6D801D6F82176F7B0D7577047875007A6C00796700766600776400745E007057006E5200
6B4F00694F00644D006247005E4400603F006341006644006244005E43005A4100604300
624700674300644400684500694F006C59036C6206696809696C08676E0966710E65700E
67700D676F0B626C07616E03607307617105646902636401646502675A01655100654E00
644900654A00664A00684D00695400675A006660006366005E6600636300685C00665600
634F005D4A005A4300594000553F00553900543B005337005036004F3600493200462F00
3E2B003B2700392400341F00322000322100362300362500362500372300352200352300
3624003624003624003824003826003726003625003323003022002E1F002E1E002F1E00
2E1A002D19002D19002A1A002619002515002313002314002014001E11001B1100180D00
150B001309001208000F0700
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000030100020100010000010000000000000000000000030000060300
0906000E0A00110C00150E001713001915001C13001D15001D12001B12001A1300181300
1C10002012002318002A1B002C1C002D1F002D1E002D1A002C1F002D1F002B1D002B1D00
2F1D002F1D002F2000322100311E00301F00351F003822003B24003F2A004230004C3B00
574C00565D01506A0844771139811E37862B328B3D308B4D2B8C641E897E208B7C1E9173
19966E1C9A611F9E5226A24828A54A23A94E22AB471EAC3D1AAC381AAA341EAA2C23AA24
24A82626A62727A22A2FA22835A12435A1223A9E193A9E14359F1532A21F2BA52E27A53B
2CA43F2DA24434A044389940338E472D934C2AA14D26AA5736A74F3DA05039955C399563
37936D368D6A3A855F3A8655478A4C4A8F4B4996434698334A9122538509578404519A11
4BA32F44A04A369B4E2EA74234AB393DAB313FAD2E44AB2E48AB3548A83349A33748A235
46A43845A63543AB3244AD2B46AD224AAD174CAC184EAC1D4BAE2248AF2C46AD3945AC45
47A649489A4F4696584095603D96643B94663C92683C98693C9A6C3F9A6E3F926A3F8A6C
44886C468570428B703A8F702F92672B985B2AA05231A94C3AA5403FA53742A53847A441
539B485C9152648A556D855071794E756F496D734467763A64762E67772769761A717713
777A0F7A790C7B72067A70017A6B00766700746300766000765F00715B006E58006D5600
6C4F00684E00634D006046005F42005D41005F3F005D41005E40005E3E005F3F00624200
644600684900674901695002695D05696908687711667B1666801662821662851A60831B
5F83195D83175D7F0F5C7D0C5D810D627D0B5F73045F7202606F056668026B5F00695900
6854006A52006852006C56006A5F01656301656601626B00626A00656D006A6A016D6201
665D006255005E4A005C4300573D005539005138004E38004F36004C33004A3000433000
3D2B003A2900382400362300322200352400372400392500382500372500362700372500
3626003728003928003B28003C29003C28003A2A00352900362400322200331F00301F00
2F1E002F1A002D1A002A19002619002517002414002415002012002012001C10001B0F00
180D00120B00120A000E0900
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000020100030000020000010000020000020000010000040000060300
0A07000E0A00110D00150F00180F001911001E13002015001E13001A1000180F001B0E00
1E11002015002618002B1C002E20002E1E00302100312100312000301F00281E00291D00
2E1D00311E00332300331F00321F00341F003423003A26003D2C00413200493500534400
5858034F6C0647780E3B861F328E2E338E3E2F8A4E2A885D258A6B1C8B7B1E8C72198D6A
158F67199A591EA24B24A54423A54821AB4820AE401DAD3818AB391AAA3420AB2A25AA24
2AA82031A71C37A5193CA3153EA1153A9F153DA114389E1A2F9E2233A4272DA33928A542
2EA73E31A73E36A54038A13D339B472D9D492BA74B26A95237A2533C945A348666358568
34846D3886613D825441844B4A844E4987544B8D4C46944046912A51870D5B82045C940B
56A22746A24139A04335A83B3DAA3643A93548A8364AA73949A73B4B9E3A4A973E4A9740
469C4045A23E42A93A42AD3341AF2D45AD2343AE1E43AF2242AE2640AD2C3EAE313EAC3B
40A8433FA1523B9D553A9B5C39975E3893613991633A92633F916641926C448D6C428A6D
448A6C43916D449B6940A0633EA45537A44A38A4453DA33C40A03244A02D459B3650953E
5B8F4567884F6F80517F7B5278774C6C704666733D657B31677D2869791A6B7710717409
7B71057C6F027B6A01766700766600746200745C007059006F58006B54006E56006B5400
6C5500654E00634A006147005C44005D3F005C3E005F3E005B39005A3C005F3D005E4200
6546006B4C00695302666009646D0F627A1362811D608823618B29608E2A5F90265C8F21
5B8D1E5E8B1C5C87165B89165F8B175D87115D7D085E7E065F7C07647506676D04696302
6D5A006B59006A59006B6201636802656A02646A02626A01626D006572026975036E7201
696800665B00635000604700594200543B005138005136004A3500483400463000422F00
3C29003C25003B24003421003121003923003725003B27003C27003D2A00372900372800
382B00372A00392A003B2A003C2C003A2C00372D00372C00362700342400332500322200
2F1D002D19002C1B002B1A002819002619002514002414002212002012001F10001B0F00
190E00150B00140A00100A00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000020000020000020100030000030200030200030100040200080300
0C07000F0900150C00150E00190E001A0F001B11001C14001D1200191100190D001D1000
1F1400221600251800281D002D1C00301E002F1C002E22003120003021002E1E00291C00
301C00341F00342300372200341E003620003823003B2B00422F00473A00504000565402
546C08437A123E861C33923030963F318F49297F5B247F671D856F188B79178B6E158866
158B611A97521EA34922A64423A84123AC3923AC3321AC341CAC3D1EAC3523AB2727AB1E
2FA81A3BA71340A20D42A10D44A00E419F0F40A0123CA11931A32031A4292AA33726A442
2FA73A34A83735A93637A73B2FA2482CA4492AA74729A550379B533A8E59348462358166
377F663C845943824E45854D4F7F5449805D4A855445924C4393344B8A16578409658F0A
5E9E204BA13D3EA3413DAB3A41AC3947AB3A4AAB3E48A74045A043449544478948448B4B
41934B419C4642A7423DAD3E40AE3843AF2D42AF263FAF263EAE293CAE2B3CAC2A3AAD32
3CAC403AA9503CA75239A156389A583A9459398B593E845E407A63427C6745766F477F72
45867143976C4AA16250A5564D9F474A9E3E4A9A3A499E34489F2D47992F4C8D39568A40
6583426C7E4874764D7E744F727848657D3F607A2F677E226B7F1B727C0F757608766E03
7B6D01796A007B68007767007568007562007159006F57006D52006A53006B53006C5000
6B4F006A4C006746006041005D4000583B005A3C00593A005A3D00583E005C3F00623F00
674A016B5503685C0367690B637513627E1A62852461882D608D335D9033598E275A8C1A
5A8B145E89155A86165E88185F8E17608B125C880B59890C59880E60830F647C0A686D07
6C63006E5C006A5E00666701646D02656E02616B02656801656F01657302657804697702
6A7201696800675A00614D005A4600574000533A00533A005137004B3500493200452E00
402C003D26003B23003721003322003324003A27003B29003C2C003F2D003C2F003E3000
3F30003E2E003C2E003C2D003A2C003B2D003A30003B2D003A2A00382A00352600332300
2F1D002D1C002B1A002A1A002919002616002613002612002312002212002011001C0F00
1A0D00180D00160C00130C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000000000000000000000000000000000000000000000000000000000
0000000000000000000100000301000401000502000502000702000801000803000A0300
100800110A00150D001B10001B13001C12001D12001C18001D14001A10001C10001D1000
1F1300211500251600261B00251A002A19002A1C002E1A002F1D002F2100312000312200
311D00311D003623003720003B1F003920003F2400452D004935004D43004E4E01556406
4B77143D8625368E302E983E309B482D8C561C726E1B75741A7E6E18876C1A905A179754
199A511D9E4E1FA44D24A74423A63C23AB2F29AB2B24AB2E21AD3124AB2B2AAC202FAA16
34A8113DA50C3FA30843A20944A10B44A10D42A3103EA61834A71F33A8262FA8312CA73A
30A73432AA3333AC3830A9402AA65327A54D2DA54829A14E369B4F399255378D5C388A5A
39855A4087554684524A8453517E584C7A614F7D5A4787593F8C4B468E2B528A1861910C
5E9A1B4B9C3842A04143A93E43AE4146AE4246AC4144AA4143A04842934845824F428052
3F894F3D954B3DA3463DAE463EB0403FAF373EB02F40AF2C3CAF2C3DAF2E3BAD2C3BAB30
3CAD3C3EAD4B3CAA4D3AA74F3BA251389C563893573E8955417E5C40746242646C437668
438C6B47A26254A25B599D4D56944756913C578C375B95345B93335A8D3A5E8142657D48
6B7A456A78496F754C6F764B69814061863063861F6D8016747E0C7979077E73037B6C01
7B6C00796E007B6D00786F00786B007666007460007158006E50006F53006D51006B4F00
6B4D00654B00664A005F43005941005738005D3C00593C00593D005F41005E4500624900
635305625D0A66630765670964730E5F740E5E7E155E83215F87246388205B84185D8311
5F800F5E7E0F607F0E5F8411608914608811628A105A8E13548F17598F195A881962770D
696C03696600676700666D00686F01666C01696901676600646F01647403627905657C04
677802696F006A62006555005F4C005A4100553D00523C00513A004E37004A3400472F00
422C003E28003929003825003927003A26003A28003E2B003E2E00423300423300433400
4235004435003F33003E31003E2F003D32004035003E36003E33003B3000382A00352500
3320002E1C002E19002B19002818002719002715002314002114002012002011001C0F00
1C0D00180C00170A00140B00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010000000000000000000000000000000000000000000000000000000000
0000000000000200000201000401000602000802000905000A04000904000D05000E0700
140B00190E001C10001E13002214002015001F17002019001F14002013001D11001E1100
2015002014002115002318002217002818002819002A19002C1B00302100322500342700
332000331C003422003621003923003E29004430004936004E44015053034F60074E7111
448425328E3E2F93482D984F2F96562C8C621E7C741F80701D87641A905A1A994E1D9F4E
1DA35422A15125A24D29A2402BA3332CA7262AAA2426AD2622AB2724AC232BAB1B31AA11
36A50D38A50C38A40B3DA30D3FA60F3CA6123AA71534AA1C2AAC212CAC242AAC2A29AA31
2FAB3330AC3830AD412BA84D24A25E27A3552FA5492FA44A38A04C3A9B52369759399655
3993563F905846885B4A855B537D5C4B766151775F4B7763447D5F4787494F8B2E5A9414
5C9D194C9D3346A13D45A93E46AE4348AE4447AC4643A6453F9F4F3F954B41864D438053
3C8356398F55389D5338AB4E39AF493AB0433DAD3B3CAE343CAE313AAD353DAC2E3CAD31
3EAE3841AE4440AC483EA94E3FA7503B9F563C9B583B97563B8B583D795E3D6564428060
43995D4D9E585899515A954F56934957923F5990395E893A5F7F426475496B6E4F6C6B4E
69684C656D4C63744660794062842F668A1E6A851772790C7675017A72007A6A007D6900
7C6C007A6D00796E00796D007969007666007360007059006C57006D56006F57006D5200
655000634D00644B005F47006044005D43005E3E00603F00624300604700624B00665300
665D0665670B676707676B04636D066371075E770F5E7F175F84185F84155E84135D8311
5D81105D7F115C7C0E5A80105686145986165C8D175492194E931E5095245590245C801A
647707657101677200686F006C70006C6E006D6B006A6D00647001627303627806637E06
617B04657301676A00615B00604E005B4500573F00533C004F36004D3500473300473000
442C003F29003C27003927003B2B003E2C003E2E00423200423300443500473800463B00
483C00453C004139004038003F36004035004037003E38003E3A003D38003D3500382F00
352200321E002D1C002D1B002A19002819002717002516002113001F12001D11001C0F00
1C0D001A0C00160C00130A00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000201000502000602000905000C05000E08000F0900110800120800150A00
190E001E1300201700231800221B00241B001F19002115002216002116001F1400211300
2313002214002216002317002117002418002518002819002B1C00301F00362400352500
332000331E003222003C2300412B004432004A3D014F4902525C044F690C487516418023
348C3E28905827915C269160288E622788671E80791F866B1E8D5F1B9452209C481EA14A
1CA55123A55124A44B29A43E2DA1332BA82A29AA2925AE2720AC2323AD202BAC182FAA12
30A71132A81230AA1334A71537A81632AB1A2FAD1F2BAE2825AE2E28AE2927AD2828AE29
30AE2F30AD3D2CAE4927AA5820A36825A55930A74730A9443BA54840A24F38A15639A353
37A15942965F4A8D644F8761547F5A51765E586E63526B68496C6C4E785D4D8643519821
54A0194DA2214DA52A50AA3053AA384FAB3B4CA63F46A345439A523F96513F8A52408555
3A865D398B6137956238A65B3BAD533BAC4A3DAD423CAF383DAF3240AE3040AD2E40AE2D
42AE2F42AF3843B03C42AF4840A84D40A156429D5C409A5D3E91623D83653A806243925A
4A9E5658904F5B8E4B588C4E56934757993C5795405884485D764E6669556F6658656954
626D4F6277475F7E3F6280306A841F6D8312757C0D7873057B6C00796B00786800766800
756A00756900786900766600746200755E00715F006F59007156007057007056006F5400
695300674E00664E00674F00664C00654A00614900664900634C00684E00695300675901
646003656505686905666C05656F076274095D7A0D5D80115B85125B88135B8A155D8815
598417588518528315528616538619538B1A5593205597224F992A50963B568D3E5E8527
627F11657D05687D026A78006976006C73006B7401697304687304677604677705617806
607D05647A03676E016661006252005F4400563F00563B005038004E3200483400463400
473000402E003B2B003B2C003C2D00432E004230004434004637004739004941004B4300
494700454600414100413F003F3B00403A003F3B003E3D003D3F01403F00403B003E3400
3A2B00372300322000301C002A1C00271A002617002415002013001E12001B10001B0E00
1B0E001B0B00190B00150B00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
0100000201000501000802000907000F0700120900150C00170E00150E00180D001B1100
1F1400211700221B00241E00282100241C00231A00221A00221500231500211600241200
2315002314002515002518002717002515002516002717002B1A00301E00372200352500
3120003622003926003C2B00423100493900524C01525D064C6D0D447B1D3E8330358743
2D8D55248F66238E6A1F8A7221876F238969208968248F5721944C1C9A491F9E4A1DA04F
1BA35521A35222A64C27A54128A43927A83324AA3224AD2E1DAC2420AD2126AD1A28AA15
27A91728A91D26AB242BA9212DAB2029AF2528AF2A22AE2F1FAD3424AE2B26AD262AAC25
31AC2E31AD3E2BAF5324AA5E20A46C24A65D32AB4834AD403DA7403CA34C39A65739A957
39A765449D614B8D6151865F577A5A556E5E5B686457616E50646E5269624E7C524E9731
50A6224FA71C52A71C58A82055A62C52A53053A3374C9F4045964E3F96553F8D563D8B5A
39885D388C5E36966238A45D38AC543CAC4A3EAE403FAF3542AF2C45AF2A44AE2841AE2D
3EAE2E3FAD3343AF3841AE4541AB4741A34E439B584090663C8D6C3A8F663D9A5E489F56
51994C59894D5D8E455B9245599641599C4054954756854E5A7553646A596B6759646D57
5F7150607D456286376388256F8215777C097B77047C70017E6B00796A00786500786600
766200746700736600735E00705D00705800715A00735900755A007457007456006C5300
6C4F00694F00695000665100684F006550006852006951006652006B56006A6001696601
666601686C0168700566730A62790D647D125E7F105B810E5A850E5C89135A8B155D8A16
578C19548C1A548A19518B1C4D8C21528F235797294D9B2E4E9743538B515E7F545E7A43
5F8721618E10648C07698404667E02677C036780076A830A678209648009637C08627B07
5E7E07627F06657704656901655B005E4B00574400553C00523B004A3700483700493500
4832004431003D30003C2E003C2F00403000443500463A00473C004742004A49004C4F00
485500435401414E00404900424400424601404503404804404806404902404500403B00
4032003A2900352100301D002D1A00291B002717002616002412002211001D10001B0E00
1C0F001A0E00190D00170C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020000030100
0401000703000A05000D06000F0800100B00150D001911001911001913001B15001A1500
1E16001F1A00231A00261E00252000271F00221D00221A001F1600211600211500231600
2513002614002815002919002915002A14002716002A18002E1C00332100352100382500
3622003724003C2B004132004638014C45025659074E6B12427A1E3B843432854C2E7F5D
2584661E85742083741F807A21817322896822935C24984B209C461CA1481CA2491FA148
1DA24821A44622A64426A64026A83E24AB3A21AC3820AD331DAE2D20AD2525AC1E22AB1B
23AB2123AB2B20AC3521AB3022AD2E21AD3320AD351FAD3920AF3A28AD2C29AB222FAB1E
31AE292EAE3F29B05123AD5C1FA96B28AB5A36B0463AB0403FAB403DA54C38A4563BA85A
3DA962479E5B4D8E5C5182585C77575E6B5C6062615D59675A596A5A5F615371564C933F
4AA72D4EAA1F55A91858A61A57A524539F2653992E4F99384392503D95523D91573D8F58
3A8A593A8B5C37945D3AA05A39AA5238AB483DAB413FAC3845AD2B4CAE2649AD2743AE2F
41AE2F3EAD3541AD3C3FAB4241AB3E3EA74B3D9B563E86623E8C633E9A5D46A358519C4E
52934C528950589245579B40589E3C579C3E55954655864C587854616F56646E555E7551
5C774D5E8341638C306D8B207781107D77027D71007E6E007F6D00786900786700796500
796100735F007161006D5D006D59006C57006D5B007259007459007357007156006C5200
6A4E00674D00664B00684B00684F006651006852006759006C59016D61026A6802666B02
666C02667203627808627B0D5E830F6288125E88115A86125889105A8B105A8A115A8D14
578F1A51911D51911C5093224E952B4D98304C9A364D9A404D8F52577B5D63715B5F7D4B
59912E5A981D60981760930D618C06638908648C0D658E15638D14638D135F87125F840E
5E8A0D5E880A5E8107657303646100624F005B4300563D00513A00503A004C37004B3700
4A3600463300403000403000403200453700453D00464000454701454F01485601475C01
4262023F60023E5C013F57013E540340530640550A3C560F3A580E3B55063C4E02404500
4037003B2E00362300311F002B1B002A19002A18002716002514002511002010001D0E00
1B10001A0D00180D00170B00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000030100060200
0906000C06000E08000E0900120A00130B00160C00180E001C12001E14001C13001C1300
1D1600221900241A00261A00281F002A2300292200281D002617001F1500201600241400
2415002613002716002919002A19002B17002D19002F1B00311D00362300382400372700
3828003E2700422E004B390150460455550A566B15487A2638833832864F2783652B7A6E
257C6F227C76217C751B7A7D1E8475239068219C5A249F471EA14018A64119A6431BA443
1CA5401EA54121A74121A74021A93F21AB3E1DAD391CB0391BB0361FAE2C20AC251EAC23
1DAC2D1CAD3B1DAD4A1DAB421DA9411CA8411FAB3E1FAD3D20AE392AAB2A2EAC1A33AD16
32AD262CAF3924B14A23AE541EAD612CAC533EAF4340AE3D3EA5403BA04E39A1563EA558
3FA85D479D524D8C50567D5463705766645D645C626255665F556A5F5F63597359508F48
4BA2394DA92653AA1C5FA6175BA11C549823508F2C4B93344A8F4843954E3E9358419258
3D8E5A3E8B5B3E915B4099583DA4523BAA4C3CA84840AB4141AE3645AE3145AD2C44AD33
40AD3841AC3B42AA4341A64642A94141A64E3E9A553E895C4494524AA24F52A24B549948
52904953864A58954058A13B58A138579F3A5292405482485B78535E70556171565C7350
5A784C5F843C688C277282187E770A7E6D01816C007D6E007A6D007B6D007B68007A6300
786300746200735E00735B007359007058006F55007357007558007158006D54006B4F00
6B4D00664C00644D006851006B4D006C51006D5400715E046E6609686E0A66730962730A
62750A61790D6180136085155F89125D8C145A8E13598A1258881158860D5C880C59870D
548B12528F184E941C4B9A264E9A2E4C9C3A4B9B454D8E524E7F5E546D645D6F5C588347
579A3251A42855A624579F1A5A97115C960E5D97155F961961971A61961E5E911E5E9118
5B9017598D105A830B617B06666A06665B03614F02594401563D004F3A004E3C004F3B00
4C38004A3800453700443600473C00464000474600424C013E56023E5D034064053F6A07
376D09356A09356605376306385F0736600A346210336616316110315C073456023B4B00
3E40003D33003829003121002E1C002C19002B1900291800261500251200221100201000
1C0F001C0C00180D00160B00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000200000401000804000B0500
0F0800100A00110A00110B00130A00140C00160D001910001B12001E15001F13001F1300
211400241800261A00271B002820002B23002D23002A20002419001F1200221200261200
251400261400291800291A002C19002E1D002E22003222003322003721003825003B2300
3C27004130004A370055470257590B506E1B497B2F3D7A482E765D277D6A1D7D77247874
217479216E7C206F7C1E727D2083712296641EA35820A5491CA64317A94418A84319A742
1AA6411DA7421CA9411DA9401DA93E1BAB3D1BAE391AB0371EB0361EAD2D1FAD2B1BAD2E
1AAD381AAD441AAE541AAA501AA85319A5551CA8491EAC4121B03D2BAD292EAD1B31AF19
31AE2529B03625B14224B04C20AF5934AE4B47AE3E42AA3D3EA2443D8F533994573C9E53
3CA056489C4A4A8F4C5380506371556B645B6A5B5A674D656155665E646358765A53884F
4E98434DA73354AB2460A6195DA11758992252912E538F33518843489349439A54429957
419056428B59418B5B42905A3F995A3C9F533AA44C3CAA4740AD3F42AE3C3DAE383BAD3C
39AD403DAA423FA74443A74546A84746A451439A54428A544A994852A34052A242549C46
5299445595415C9D325CA03359A030549F2F539735568745587B505E6F57606C585C7951
5C7D4966862F72811979730B7C6D047B65007969007C66007869007A6C007E6B00796A00
7C6800786200776000745B00715A007253007253007252007053006D55006D4F00674D00
6A4B006850006B52006B55006B55006C5700715F02726F0C697815647C16617F16618017
6282195E82195E891D618C1D5F8D195C9016589117578D15588D14588C13588B10588A0F
588D135190174D9821479E2A489E324A9C434C94524F825C57795E596F66577956549040
53A0344DAB3150AB2E52A52655A01B559E175C9F1B609E1E629D21639B255E9A215B951C
55931D558D175687135B8014607913656D0F61610B5C52045545015040004E3D004D3F00
4C3D004C3B004A3F004842004B47014B4D01495703466007406A0D3D710D3C7612397B1A
327B1E33791F357118366E1639681639651738671932671C2F67142F610C335A06364D01
3942003A3500392B003323002D21002D1A002D1A002918002715002615002213001F1000
1D0E001A0D00180C00160C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000100000400000602000804000B04000E0900
120A00140C00170C00160D00160C00190C001810001F0F001E1500201700231900241900
251A00261B00271A00281B00281F002A1E002C22002B1D002216001F1200201100231500
2314002314002613002A17002A1B002F2100342600362300342000302200352300382400
3F2B004833005443005B5405546D17417F313880492F716627687821727D19768321777C
20767A257576277D6F24886D23956320A15E1DA6581FA74C1EA64619A84718A84817A549
1AA84A19AA4919AE4319AD401CAA3C1EAA3A1EAC351FAD3222AC2E21AC2D1FAD301CAE39
1DAE3F1BAE4A1AAD571AAB561AA95A18A75E1BA74A1EAE4121B13F28AF2C2DB0222FB01F
2EB02828B13823B04024B24423AF4935AE4047AC3840A93B409C463D855838895B399452
399B5545A046439C454D8E4D5D7C54646D5765645A6959615F61605D6D5E567A57558650
50914851A03854AB295FA61B5CA316599E1F57982B59922F5785404F924147A04D42A250
429B54408D5545865A47835C478858478D58419B523EA34C41AB443EAE4339AF4838AE4C
36AC523CA74E3FA14B44A24847A14A459D544790534683554E954250A43C50A44650A149
52A24550A53758A32E5EA22C5CA1265B9E2557992E5A90405D804E607157606F585F7C4E
5E85417384217E770C7A67017763007561007562007360007860007A66007C67007B6900
7B6A007B6600776300755C00735B007358006E53006F50006E50006B5000694F00684E00
6B4B006C4E006C55016D5C02706104776809777311707E1C678422618924608D23598C1F
5A8D215A8A215C8B1D5B8B1C578D185A8E16588F185B8D195A8D1A538E1C528F1E538F1D
52911955941C5298244C9F2E45A137439B4C498A5F5673655C70646078635A8E5155A03A
50A7334DAC344DAD334FA92A52A91F53A61D57A61D58A6225BA5215C9F21599C1F569A1E
4F9A2254951D509221558E235689235986215A781958650F535308534D07534A07534A06
5048054E4A054F4D054E53064C5C06476607426D0E41791837832436852434892A308B31
2E88372F843A307E3332772F39712E376B2A356A2A316B262F6A1D2E6A162F5E09345002
374400393600382C003223002F1E002D1A002A1900291900291900281700251500211400
1D12001A0E00180C00170C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000301000702000903000B05000C0600100800130B00
160D001811001A10001D10001B11001D1400211300231600231700211800231900261800
261A00271B00271900281900271900291D002A1E00261C00221700221100221300231300
2613002616002715002818002B1A003122003424003825003522002F1F003524003B2A00
463100543F015A540357680F487B2832824B297A6428687A2760841F6B851D7285237C7A
2181792684722B8D68299766249D5C1EA3581AA65320A64F24A44A1FA64D1AA44F19A056
1BA55519AA511AAC441AAD3E1DAD3C21AA3A24AA3328A92D2CAA262AAC2825AD2C23AF34
21AC361FAC3F1FAD4A1EAE4E1DAC511AAB561FAD4822AD4223B1412AB1322CB02B2FB128
30B22F2BB23D27B34427B23E24B14039AE3549AB3242A83D3D974D3B7D5A3A815C398B5A
3595573FA14441A54045984C5184525877595E6E5964645C5B655E587159577B5653874C
508C434F9A3953A52B5BA81E5CA8175BA72157A02C5B933058833B528D40499F4347A546
44A14B3F9352488856517B594F7D5A4F825B4A8F5843995042A3493CA84A39AC4F37AE50
39AF4D3FAC4441AA3C41A94048A94649A7464C9E414D94404F9B3950A3374FA43B57A43B
58A53758A62F59A3245DA3215FA21C5A9F205B9A295D953B5A844E5C74575C735260813D
688A2A7C7E16806E047D6600776500736100735F00745C00745C007A62007C6200766400
7967007A6400795F00735C007257007055006C5400684D00674B006B4E00694F006A4E01
6E50047355087A5C0E826714887018877B1F7C84297883306F853366912E62972C609727
5F9427608C225F831D5B811A5883165C85155A8715598915598A17578D19518F1E51901E
4F931D4F97214D9D2C48A238459E4646905D4A836A53756C5E71656082585A9D4453A733
4FA3344BAA334DAE334DAE294EAC1F53AA1F54AA2257AA2558A8235BA22357A22254A223
50A223509E224F97254D94254C93234C902954822B5871275A64215C5F1E58591D575B19
505D154F64144C6A13497111427813397F193187222D8F2F2A943D2B933D2A943D27923F
2A8E4027874028813D29793830733530722E3171292F6E232C6B1B2C68152D6009315202
3645003A3800352E00342600301F002F1B002C1A002A1A002A1900271700231500221200
1E10001D0D001B0C00180C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000200000401000703000B05000C07000E0700130800140B00160E00
1910001B11001C1400211400201700271600261800241900221700231900221800241900
261A00271800241700241600221800261800271D00281900231600241500251500251600
271B00291A002A1E002A1A002D1F003321003726003B25003521003520003A2800403000
4F3E005A5405566B0E4C7A24397A442E6F642C68722A5F822762852071871D7C84208375
1D8A70239368269C6325A06121A2581EA2561CA35220A44A25A54722A4481EA34E1B9F56
1DA4541FA94A1FAD3F22AE3625AB3529AB342DA52D32A72732AB212DAF222BAF2426AE27
28AD2A29AD3024AE3B23AE4221AE4A1EAF5123AD4828B04329B1422BAF3A2DAE3831B232
32B0342CB13E2AB14129B1372AB1303BAB2D46A73040A4423D9452407B5C3C7E5F3C8960
35925F3FA04641A63D439B484B894F4E7F575675565F6A58566C5752755652814F508749
518B4452973752A02F5BA8225FAB1C5FA8215BA02E5B932F57843B518A3C4C9240459945
419C4B3F9754468A58567C58557C59597B5B50865D438D553C974E38A25136AB5134AE4E
38AE443FAE3C3FAC3441AB3746AC3A4BAB3650AA2E4EA92A4EA72D50A82B50A82F55A52B
5DA32860A11F5F9F1962A11862A0175D9D25609B285F983A5A8D48567C545B7A43628629
7186167C790A806D017E69007B6600776600766600765E00755B00745C00756000726000
756100776000765F00755E00725C007059006B5400675300684D006A51006A51006B5604
6B5C11716719806E268974348A7B3A88774384764E837A4878833E718E3B6D933C67913A
6392326288275E83245A85235987225A8D215B8F225A8D26549024569522539526519526
4F99244D9F2D49A44045A24844905A4D766E4E78744F787055786555944D53A3364B9E2D
4B9C3047A53447AF3449B0294CAD2251AB2253AB2454AD2655AD2656A72653A32A4FA42A
4EA62750A324509D1E4E971C4B99224D943352873E587840566B464F66444B6442476738
436E31457931497C2D42822D37832E2B8334278A3C279243279548279445289540269540
249240258F3825883227822E2E792A30772432751F2F701A2C6E162C69123063092F5A04
374C013B4000383400372A003524003220002F1E002B1C00281B00271600251400231300
1E10001C0F001C0E001A0F00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000300000702000A05000D08000F0A00100C00170D00191000191100
1B13001F13001D1300201400261700251700241B00261700201700201600231500231800
241800241900241800241A002317002618002817002917002918002817002719002A1B00
291C002D1E002E1D002D1C003120003825003D2B00402B003F2A003D2C00423200493D00
5549015B680E497D243B7E43336D5F335B7433587F3456882F6682247B79228B71219266
1B99641D9D6320A26320A26021A055219F54219F5023A14725A34222A3401FA5451DA248
1DA6451DAA3F23AB3526AC2F2AA92E2EA92C32A72734A92032AE1D2CAE202AAE2227AE27
29AC2829AD2F26AD3F23AE4624AF4E22AF5625AD4D28AF4B2CB04730AF4032AF3C32B138
32AF372CB03B2EB23931B02F37AD2D3FA83044A4383B9F503D8F5B437463447A66408666
39946543A14A43A83F46A0454F944B4C89534F80555373564F74574D7A524D824A4F8A46
518F40519835539C325CA52860AC2261AB1E5CA323599626548E33518C384B893E468C44
41944D3E9256448B574E7F5C50825A59855A508A58448D553C9251349C5231A75131AE50
37AD463AAD3C3AAD373DAB3341AD3348AC2C4EAC284DAD284EAD2B54AC2558AA2260A51F
669D1C68991A679D1969A017689C18649B21649A275F9A3558904651854D558437648C1B
758709807902806E007B6B007A6A007969007B6600796300745D00745B00735B00725A00
755D00755F00786000796300796200765E01725D026E5904765B05745A036E560271630B
73711879792B89723A8C7348877A4B857B4C827C4C8586417E8B3A78884272804A6A8247
628C405B8A315A8E2958922954962A57992D579730569337529837539E31539F2E4D9F29
4BA32C4AA83647AB46449E564086624E696E546B6F5574725380624F99494B9437489130
49973243A63248B02F4BB12D4AAF2A4DAF274FB0254FAF2850AC2750A8244AA62C4CA62F
4BA62D51A52756A220509E1E509A28499A364B95404D87474A8151457E5441765442704D
426F484D714B537550487B543B7A522E76512C7F4F308650348A4F318A4B2A8E44289247
2899462797442791372C8930308229327B263076273074272D72252D751C2D7013306709
3858033B48003A3C003A30003627003322002F1F002E1C002A1A00261500251500231300
2212001F12001D10001C1100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
0000000000000200000401000803000B0700110B00140D00160E00190D001B1000201300
1E15001F1300201300221500221900261A00261A00211600211300221400221700231700
221A00241800251B00261A00251500251600281900261C002A1A002D1B00281C002B1C00
2B1D002F1D002E1C00311B003622003B2500402B003F2D00423200452F004C3701544602
5C5B095873233C7C4233725D315E7036507F3956823C5D83347174278666219662219D5E
1DA05F1EA25C23A05B259E56269D4F249B4E219A4D229D4722A14321A33E20A53E1FA53D
1BA83A1FA93322A92C27A92B2BA82C30A82C33AA2733AB2234AD1C2EB01E2AAE202BAE24
2BAD2B27AE3922AD5021AA5521AA5D21A86223AC5D26AF5827B25230B14732B04033B03D
32AE382EAE3831AF333AAC2E3CAA3442A439419B4836936039836B44696F447367408264
39916542A14B42A74046A5414A9C464996504A92544E894F4A8A4C4A874C4C8D464F8F43
4F9140539737569B345BA4305EAD2B60AB1F5FA71C5EA01B58972B52912F4B8E35458D3F
3E92453D9050448D524780594E8558568657518B55488B543F9056389A5433A45534A952
36AD4A39AD3E39AC333DAB2D42AD2C47AC2751AD2454AE2256AC255BAA2261A71D669D1B
6C981F6C95226D9C1C6C9F1A6E9E1C699E21659C275E9836579443528E49588F31689117
7A8A04857F00847300806D007D6F007E6B007E6A007C6700796200755C00735800705800
745700755C007B5C017E61027F650581680C7B6811856B1498671E9366118C6A077B730E
867A1D8D75388E70408B704A837D4C7B81487E8543858D3C848A4082854A737B546C824C
638E445D95315E9A2759992159961E5B942257922758912B57942F559C2D4FA02C4EA32A
4BA62E4BAB404BAF4848A55640925F448367517767547A665B85594D934548804045823B
49923646A53144B02A47B22C4AB22D48B22A47B2294CAF2A4EAA264CA52347A82B48A836
4AA6374CA8334FA72C4FA02A4B9C2F48A032489C3B48974646965046905A40805C44775A
4F715A5C6C5D636F5F5A76634B7C5D3D7F573D81544481514B7F523F7F4E2F8147278C49
26974B28984A2896402991352C8B302B842C297F2C297E2E2B7C2D287E2729791B2A6F0E
3561063B4F013D3F003C32003628003523002F1F002D1B00291900281900271800251600
2515002212001E11001C1000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000010000
0100000201000402000902000F0400120A00160E001A10001A12001911001E1200211300
211500211500221600221600231A00271B00281B00281900251600241700241800261900
241700241B00271A00261B00281800281800281C002B1C002D1D002F1D002F1B002F1A00
2B1C002D1B002A1B00321D00372300402C00442E004632004536004938005846045E560E
5B69224D73413A6C5E31676D2C5B7430587E2F657F2D738028826D2192631E9C5F1EA35D
1EA25D22A0562B995332964F2E964D26984C26984D269B4926A14522A44020A43C21A537
22AB3025AB2C2CAA2631A92735A82737AA2638AA2435AA2033AB1C2EAE1D31AE2031AC24
2DAC3227AB471CA8631DA66A1EA26E1CA0721EA86621AD5D24B15532B04936AE4236AF40
37AC3B31A73834A8333EA63640A24146984640905632866E3672743D5D76426F693B7E65
358E643A9E4F3CA84142AA404AA4444AA1494AA2494C9D49499C494B98484B98464E9745
4F973E549C38539C3359A5305EA93062AA2663A91C62A6185C9E1D4F96234B902C439136
3E923D3E8E46418B4C4381514986525386544F86564685573F8955399158339D5632A655
35AC4E39AD433FAD3644AE2A40AC2B48AE2455AE1D5BAA1D5BA81F63A61967A217699D18
68981A6A961D6D9E1B6D9F1C719E1E689D22639B2A5B923756943D53954059972B6E9415
7D8F04838301867B02877301827100836D007E6B007B6900796200775E00745900725700
745A00785B007D64047B6B0B7C71117E741D7D7A3490773EAB6A46A56826A56F127E7218
92741C9E782B917D3B877B4081824281853E8787398C85438A814F847657736B5D677556
60884A5C92385B972E5D98255A97235E96225C91235B9325579626569C2951A02B4DA42E
4EA93250AD404FB1474CAD52449F5C41966548876550875F5698524F9640467C40448240
47944045A83643B02947B22948B32B44B32B44B42F4BB2304FA82950A42649A72C48A63A
46A03E489C3F48A3344AA4314C9F2F48A02E469C354995434F9A4E5794584B865E51815F
627F5B667E55628255558957438F563892573B9157458B564A82533D80512F804C26874E
268B50268A5127894A248A4524894023863525853227842E2982292880232B791A2E6E0F
3562073C54023E42003B3500392A00362600332000301D002C1B00291900271900271700
2416002111001E10001C1000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
0401000603000A04000F0500110A00170D001B10001E14001B13001F1200201400201600
221500231700231600251800261B002B1C00281C00271A00261800231700251500241800
251700241800241A00261A00271800281700281B002D1E002D1D002F1D002E1F002F1D00
2F1E002E20002D20003624003B2A004330004532004636004F3B005347015E590D5A6726
4A6B483F6B5F36646F316275285D7C28647B257773218B6B1F94631A9A661B9E661CA362
22A05D279B53329050378E4E32934F2B984E28974A289C4526A14124A33E25A43C28A531
2AA82631A92239A6223CA8233CAB243DAC223AAC2236AA2236A91C35AB1C34AC2231AE2A
2BAA3A24A94F1BA4691BA26B1C9F6C1C9D6D20A66025AC5627B25135B0463CAE443AAE44
3AA73D369A403D9A3D429B4140994E468E513D85592D766C3167713459733A6C69397A66
328868339C5437AA483DAB4047A84447A7464DA8464BA74449A64647A24847A2474E9D46
4D9D40539D37569C345AA3315BA4315FA82A66AB2165A71B60A21859991B4D932442932E
3F913A3F8D44458C4C4681544783534E7D544A7B58467E5B41845A3B8E5A37965636A053
38AA4E3CAD4142B13245B02647AD254BAB205BAC1964A61865A31C699D19699A18689716
6B95196D951A6B9A196C9E1B6CA01D67A124639C2B5D94365B9836599D37649D24769910
7F9206828D05858908878109887D088778098270087F6C038066037C68037E65037A6406
7B670A7F6D0F7D7714807A19807B2684773889784993754C9E704E96783D917A2F747C30
7C8B2A8098327796397391387A8D3B7F8836817F357F79497C755A73695F6559625C625A
5B6B525C7E465E863C5B8F3559992F5D9B2F5B992C5A9A28589D25589E26539F2B4DA22F
4BA73550AE4050AF3E4CAD4B46A35544985F4A8E614C965D4EA34F4C9941498240488540
47944446AB3842B22A41B32843B32E45B42F4AB6364CB43353AC2950AA2C4CA73548A340
439744428C45479B3C4AA4394BA233479B304896364E934158964A5F95555491564F9154
52985052954D4F8E4A47914F3F95553B946239916A418A69437F673B7E61357E602B7B61
297563267360247060267659237B4E22804423844027873629832E2B80272C7A1E2E6F13
31640B3556043948003B3900383000362800352100301F002B1C00281600281600271400
2514001F13001E11001D0F00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000040100
0804000C05000D0600110800150B001A10001E16002015002212002013001E1500211700
251800241800251700231A00271B002A1C002B1A00281700271800261600251600241600
261800271800261800271800291B002A17002B1C00301B002F1C002D1E002F1D00322000
3722003625003928003B2C003F2F00453700493A00523E005A4D025C5C065C6C214E6E46
3E68673568743163782F647426697121716B1D856518965F1A9D5C199E631D9E631F9E5D
269A552B934F348A523589563191542897502998492A9E4028A33E23A63924A73729A62A
2DA72137A61F41A5203EA9243CAA2737AA2433A82432A82434A92034A9222FAB3028AC40
25A94A20A25A1B9B6C1B9C671D9F631BA06025A7502CAB482FAC493DAC4542AC4940AB48
43A5413E9744429544469248428C554385553A7B58296F68306A6E33637136706B30776C
2F7F6D33955E32A7523CAB4746AA4347A9404CAB404CAB3E45A74149A7454BA5454CA041
4BA13A529E37539C3556A13357A6335CA73362AA2E5FA9295DA41E5AA019529A1C499922
44963141954442954D468A56448755477C57467959467C5D45855C3F8F5B37975839A052
39A8483EAD3D43AE3049AD254CAA2153AA1D61A91B69A71D6BA21E6C9F1B699B1B6A9718
6898186B9819669A1A659F1F66A12362A3295EA22E5F9F33619E2E61A22970A11D7D9D0E
7E9C0B81970B80990F8394108390148587198282188278128675118475138574148C731A
8C781F8E80259083318E7E3690733E9A7145A36F4C94744D8A774C7F874776914072903B
719533689835649639639A3D659546668B496A794A6C6956656C5D5E675D58655D576E57
59794E5E84445C873D5E92325C992E5C99265D9A285D9B29599D24599B2057981F509B29
4FA1334DA63C4EAB404BAA4845A44F4A98574C935F4C9D5B4BA14F469B41488B41498843
49934344AC3744B42B42B32641B52A46B5304BB4344FB42D53AB264EAB2E4AA43A449C45
41934B3F8D4F439B4646A44545A240489E374A9937489D3B459E484C9D594C9856499457
499B534699523F8D533F8A59478B674B89734585774083763E7D74327E6E307F6C2A7B68
2972622A6D602C6B5D2C6D5C287455277C4C27834228853C27822F2980262C7C212F7216
2E660D3158043749003A3A00392F003628003220002F1D002A1900281500281700271500
2414002113002011001D0F00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000040000090200
0B04001005001109001609001A0E001D1300211500231700261500231600211700251700
281A00291A00291800241900271C00291A002B1B00261A00271700241800241600241400
2312002416002A16002919002918002A19002D1B002E1D002E1D002C1F002F1F00392000
3827003A2A003B2B00402E004131004738004F41005A51035F650B56741F4D7740436F63
3A6A742E6C762C6A742A726F23796C1D7F60188E55199B511BA1531CA1591F9E5B269A55
31944B318E4A2F89542E8A5B2A9159279851289947279D3D25A13A24A53424A92F28A725
2CA61F35A61D38A92036A92833A82E33A72C31A62A32A42C30A62A2DA53228A84024A950
22A7581F9F5E1E9765219C5D21A25225A74C2EA94435A84336A44A43A34C43A45241A452
429D4B3F934D448E4C4C87514B7D5F45795B37715E2C6B6A2F6E6D2F6B7131706D31706C
2F7171328B64369A5C39A64F3EA74542AA404CA93B4EA9394BA7394FA73951A53751A239
4FA234519F33529A34539F3152A73255A93756AA3C53A73754A43150A22656A01A559C18
4E9A26489D38419E473E98573F945B42835B417C5B47805C48865B40905D3B965B3A9F53
39A8473BAD3B42AD2F4BAB284EAA2459AB2162A92367A72168A31E67A21C67A11E6C9E19
6B9D18669C195F9F1F5EA2265CA02A5DA03458A4375BA6385FA62F63A92871AA1A7FA810
81A60D80A40F82A4167EA31D7EA0227F9B297E952D7C8D2A76842A76822C797E327F7A39
897C3D927940977C479C7B47997242967940947D42887F42817F42808B4083953883983A
77983868973866963C6B964675894F707C576F705A76635D726661706C5E69725D687A58
64814F6086455D8C3F5F8F305A932A5F94246196255D962A5F97255E95205C941E539624
4F9D3150A13A4EA6444CA94D44A24F459955479A5949A2524CA7494BA040489640489440
499C3E48AF3548B42C46B42844B62947B7314AB43B4AB3324BAF2F49AF3C47A44142974D
3E95563B965B3B9C543B9B4D3F9E44439D424399413F98403E94493E8F5541895747865A
4B875A49865B4078623C747144777F4875824371803D737F35777C2C7A7429816D298763
2786572A83502E814D2E7E4F2A7F5226834E278442258338277E2B25781E2A74192D6F11
2F65093156043646003738003A30003826003320002C1E00291A00271700271900261800
2516002013001F10001D0F00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010100010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010100010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000101000201000801000904000E0400
100800130900160C001A11001D1000211500251700271A00271900251700251700291B00
2921002A1D002B1D00281A00291A002B1C002C1D00291C002A1B00281900251600251100
2413002514002717002A1B002A19002A1B002B1C002E1A002F1D00301B00321E00372400
3729003D2B00412E004334004938004D4100554E015C650A5779214381463B7D66397779
3872792B757527796D2282661D89631B8E5417954B1C9B4A1FA04A23A051269C4F2D954A
388F45348D4A2D8D55298D6028935B279752299B48299E3E2B9F382AA33027A82C2CA825
34A82232A82234A72731A82E32AA3535A72F36A72D35A43230A7372EA74529A75524A764
25A465269B632691602C97552EA14D30A64737A64339A2453B9F4E459F4C479E52419B58
439252418A564986535181574C7364427263376F652B6B6A2F706C316E6C346F69316A6D
316876387D683A87663A96583FA14F41A94649A63A4EA73350A73453AA3157A92F56A930
52A92E53A62D50A33150A42C4DA62F50A93550AB3A4EA83B4DA83D4EA53355A31D5B9F13
569B184EA02646A43B3AA64F39A0563C8E594283594D845A4F865D458B603D945B3B9D55
3BAA483FAE3F42AD364EAC3157AC285EAB2665AC2664A82563A72066A61D69A81F67A71B
63A71662A3185FA52157A6285AA52E58A23758A53C5AA63C60A93265B02973AF1C7BAF10
7DAC0D80AB127CAA1C7AAE247AAF2D79AE3475A73C709B3F6E8D436B85467182477B824A
8382478A83488A864A868A427F81437C80447B813F7D803A7C803B818D37879B30869D32
7796356B8F32698C397189457A785478655C7F5F5D895A638F5860955D6092635F8E675C
816856716D4C62744461833D5B8E335F94295F98265D95265E94225F941F5F921C5C9520
589B2D53A03653A24053A2494B9C4F469B56449C514DA14E50A74C4CA3434C9C404D9B37
4CA6354EB13349B43047B42C48B72F4AB73748B5424AB23E4AB13D45AF4044A6433F9D4B
3C9A573998603A935E378C5B3A95583C995B3C94573D8A523D81523C7A553D79563D775D
3F7C6741736F415D7842547F4759814C5B7C455B763D5E763368772F6D702A796B268760
298E522B8C4A2D8B462C8B4A288D51268D4F258B4324843E267A312674212972192E6B10
305F08345102354000373600392D003828003324002F1D002C1B002A1A00291700261700
2515002013002011001D1100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000000000
010000010100010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000201000501000A02000C03000F0600100800
140A00190B001F0F002013002416002516002A1A00291A002A1B002A1900291B002A1E00
2A20002C1E002A20002A1C002E1E002D20003020002D1D002A1D00271A00281500251100
2510002415002614002D18002C17002A1A00291B002E1A00302000351E00372100392600
3A28003E2D004531004C3C005541005B52035A630958771D4B803D3A7B62367974347D7B
377B6D2C81642387631C8E6219985B1C9C4A1D9943239A42269B45289B4B2D964C30914E
368A4D328B522B8C5A258F6028945A299C522B9D462D9F3C2F9E392EA33330A63035A731
34A52F30A72E31A73330A93633AA383BA7323FA7313AA63932AA442EA8502CA45E2BA06F
2D9D682D985F2E905A33965238994C3A944F3F954E3F98513E9A54489C50459A553D945F
428859447A584D7F524D82534877674079633577642F736630756236735F377360396D68
38667439796A3C82653C8E5D3F9554409B4C469E404DA2394DA63854AB3357AF3057AE2E
52AE2A52AC284CA6294DA5294BA52C4BA5344BAA394FAB3C4DAC404CA83C52A5295BA416
5B9A15579B194EA42A41AA453EA6513D9556418A5549875B4D845F4587613E8E5E3E9B57
3EAB4E40B14342B13D4CAD3558AB2A62AC2566A92166A81E67A61A6AA61C69AC1F68AD1C
64AC1A5FAD1E59AC245AAD295AAB2F57AB395BAA3C5BAA3864AF2C6DB01F73AF1A77AE11
7CAA0C7CAC0F78AF1872B1216FB12774B23273B03876A93C72A13F70963F719442789540
7F94407F97407F95417A9541758F42718C4074923D75923A7694367E9D347FA33579A33A
74973D6E8C39708743768151796D5D81595D8957639154619755619A575E935E59886353
7E6D4D6E7845617C415F8A405F903560922A6196235E941E5C94196093175E92175F9419
5B9B255CA03257A54154A24D4E9F50499E564B9C5354A14F50A44B4A9F414C9937509833
4FA8304CB0334FB2314CB42D4CB62D4EB73249B43949B23A48B14046AE3E44A54140A14B
3C9955388D5F378366347A6A3E7D6B498072507C6B4E7266496B6344675F3C6B5E3D6A6B
3D66743D587939497F394B7D3A5A7B3A6B72377764337D643082623180632C815F268457
27844D2A83472E84402C88432A8B44288C402689392683392979342D77262A761B2D6C10
305E08344E03373F00373400382F00392C00362400311F002C1D00281A00271900261800
251500241400211400201000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
000000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000400000701000803000D0800110900130900140B00
1810001D0E002214002314002416002618002617002A18002A1A00291C002F1B002C1D00
2D1F002E20002F1F002D20002F21002E1F00311F002C20002B1C002A1B00281800271500
2715002A14002A1A002C1D002E1A002E19002B1800301C00341E00342300352200382500
402700422D004D3D005647005E57066169135A73264E7A3D4577543D73663578702F8170
2E846628906121955C189B5A1C9E55219D482699412E97422F97452E964C2D92512C8C55
2E86572C885A278D5B238F5C2895552D9D4B2EA04229A33C2FA33B2EA43E2DA73E2EA640
32A54332A74332A84233A94034AA403EA8393EA53B39A64232AA482DA9542F9E5F35916C
388D67398A5E36855A388B573A8D5539815C3F8359408C5A40905A479154469159428F60
488A554E7F5151834D4D8755407C663C85633781652F7C6335805B377D583A7D593C7561
3E70683C7B633E7D6440875E3F8A583F8F554295494798444B9F3E4FA83850AF3253B12E
52B12B50AB294BA92A4EAA2949A82C48A7344AAB374BAC3D4AAC4047A8404CA83354A824
5D9F185C9B1353A22446AA4043A74E419B534191554688594A855D4485613F8C5E40A057
43AE4C45B1414BB33A56B13460AF2765AB2268A92068A51E6DA51D70AB1B73AE196CAF1C
5EB01D5AAF2458B02B53AF3158B03258AE3759AD3859AD3863B1286DB11D72AF1878AE13
7AAA0E7AAB1077AF1671B21E6BB1266CB32C71B13474B03670AF3673AA3573A93375A537
759C3A759740769440769043778B47758A437A923E82933F87913A8D93398F9339878F3E
8387457F7E4988785492715E93645F9A565F9B57609B575D94595F8D565C835F55736D4C
677B495F87455B8E435A92405D92345E92285F941F5C94195F92175D94175C93185F981C
5E99245E9F3456A44151A0514E9E534B9A584D9E5251A7524FAC484EA6354F9B2B519C2A
4EA82D4EB0324DAE304FAF2A4DB0294BB32C4AB42F46B03145AE3346A83945A040439C45
3C974E3A895635776337686F485E7B665680725282744F81674E7F534F7C45557A485281
4C4B80473F803C388130417E2E59782E746C2F8A5F2C98592A9C562B985127924B278D44
2B8C402E8A402F8A3C2E8B382A8B382888332886312882332B7E332B7D282774192D680F
325906384B02383800353200392C00352700342300301D002B1B00291800281700241900
2517002514002414001F1200
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000010000030000
0201000402000804000C05000E0600110900140A00190C001D1100211100221200231800
271A002B1B002F1D002A1C002A1B002C1B00271D002B1B00331D00351F003620003A2400
382500382700372500322200342000362100322400342400322200301F002F1F002F1A00
301B00301C003720003726003724003525003A27003F2B004031004436004B4101535208
5C691659732B576A485463614C656D3D6E753C737033836E299169219A5E1E9850229848
229D482C9B4C37984F3B90503A8C54398D58378C5F358D66338E6B319172349164339358
3195502C994B2C9C48319F4833A24B30A35229A45723A5541FA3511FA44A20A94326AA41
2DA93E30A83B33AA3B35AA3C32AC4130AC4429A6482991532A73652F6871336D6F366D72
3E6D6B3F72653B70693F7169486F6B4E5E734D6C6C4571693E7068407A593D7C573E7E54
40894F3F8A573E91533C96503B91543F96463F934341944842964C41895740805B417161
44676449725A477B5846865943925844905D44815F466F65427364417D5C40875943924B
449849439D4943A24144A73E42AA3E3DA9403DA2423E9E443DA14739A24936A8483AA940
45A83651A92C58AA1F59A91556A81D55A62C4BA73B46A94447A74C4AA0524A995D4A995B
4C995751A44959AE395FAF2961AE2365A81D69AB1D6CAB1869AC1869AB1B66AE1D5CB11F
50B32F4BB43C44AF4445AD4549AD3F51AE3153B02461B42366B12B68B03769AF3C66B03B
67B1346AB42A6AB3256CB22272B1226FB12270B3266DB3306DAF346BA4366A963B6B8541
67863F698640698E3F69963B6B94376990386E8C3C6B82416C7549776F4E835F55894F61
964A649E4A5E994E599256548F62578F695C8665537D654C866C4987724874713E647236
64783263842B658328628527618926608B256092215D991D5E9C186099196099165E9C1B
5D9F2E5FA23C5DA0465F97506094515D96505C94555BA14C57AE4057B33553B33552AD36
4FAD3C4EB0444BAF444AB23C44B32F44B12B46AC2F49AC2A4DAA2653A8294EA22C4A9F37
48A33B48A04041934635844D2E79582C7069296672275E75255B77205D741F626F1F6C6A
2571642C74632F7B5C368654378E49328F463392462F894C2D8252297C5826795C267762
267E6628845F28914F289940259335258F2D248B24258B21218B262880242E6C15325207
354101373500392E003A2A003A2C003C2A003525003121002E1F002E1E002A1C00261900
2616002214002011001F1000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000020100010100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000030000060200070200070200070300
0802000902000A02000B0600120800160C001D10001F13002016001D13001E13001F1200
2513002715002717002D1A00311C00301D00311A002F1C00301F00332300352600382800
3727003424003526003121003322003522003525003D29003C2D00442E00443200453200
482E00452C00412F00412E004431004434004A34004A37004C3D004E4200514500524500
5A5002605D076274165F7C3461725762645F6957526F4A485D4C63494D773B5E79287279
2082791E917722966F259566229367218B6E1F80752376752B73752F717A31737F32787A
387E6F3D7E6B3A776B366D6E376E6F3C7B6C3E816B3C826A3C81693B816A3D7C6F3A736C
36686F3878603A8F50349D4B299F4C259E5323975F23985E229865239B7126966C26916B
278E6F2C8C6B2D846D307A7232746D39696D40556F4E536E5A4F7366517362586D5C576E
5D56716959747759786D5E7051646B3A6D68427B5B458757428C564A925644925B42965E
40995C3998603D9A543E9F4E3DA151409D533C915C388863398A5F388D623C995A3EA257
3DA8583DAA593CA96137A86134A96035AA6035AA5F33A66B36996F368B6D3E876B488564
4F79644C7E614E835C4E855C5084574C81564E80574C7D5848805848805243824E3A884A
37894D3D8E4F408E4E498B464F85435397395CAB2C5BB0385BB04458AF4E54A85350A653
53AD4256AE2F58B1225CAF1C5EAE195FAE1664AD195CB01D55AF284FAE3646AB46449F56
4CA5535CA84268A03F75A5337DA61E809B0E76990F6AA51A66AD2A63B13562B03B63B23A
67B13A6CB2366AB12D68AF2768AB2868A92A65A93461A6405DA0445C98465D8D4E618451
697257676B5B67695E62765C608054618556648C4F668943658C3F678E3F6B9039689135
698F346A88366884406A7A39697D376A83386B8539678736688F31699129689720649C1D
68A21E67A41E65A21A65A31E67A42068A42067A72067A71968A4146AA31166A41562A719
60AC205FAB2861AB355FA33C5D9341608942628A41628C405F8F406098355CA336599F42
57A14857A64554AD374FAA2C4BA6244CA2204C9E204C9C22499A224B98244C98274B951F
4895164294133E93123A981C379C33359D50359353378555378757388955368B56358E5F
3392612C97622A9D60269F5E22A35C25A35523A35024A148239E44279C402A99412B9847
2B9747329441318F40328B393186322F7C213072103B63054350004543004239003F3400
3E2F003E2D00392800362500352300301F002D1D002E1B002C1B00271800251700241600
2215002212002110001B1000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000302000502000502000504000804000A05000904000C0200
0A01000B04000C0500100600130900190C001B0C001B0D001B0C001A0C00160B00130900
130600170A001B0D002110001E13002512002013002311002113002719002B1B00291A00
281900291A002D1B003020003922003D28003C2C003D30004232004733004A3700523B00
5740005C49005B4B005E50005C52005C5901586200516C04497B0D4384163E891D3D8D22
3B902340941B43921C44901444921145921142941A3D95263896333A913D388948357F54
36745D38695E435D5D51496854415E503B6D5942726348667C42586B375E593B625B4962
67495B7344596B395E602D65682C6875306E803274813079802C827F2285781A91760F98
7D10938B11879E11789B15649A19519A1B49931E5B8B226A7D2A7C6D308D5F369D4E3C99
354591224E89245B8026677A296C762E6B76316B75346D773773743A78703A796F397A70
3977723874743C7077436A7347647348646F49706D4A756948706851686B5A5A7566477A
6B3D78702D7C7939777D4675834D717F476D75416F6A3B7460536D5763634D725E477A60
427F623D8064427A5E3E6E5B426660486860486366486A6148705B457A584082573B7F63
3577753A6A763F577D415E793D7675398978428B62468F5142954E4298563E9D5F3A9D5E
389A5134984D349B4F349F55379C574098504294574A8F3B55871F5E830E6D7D0B717108
736A04756C01796F007F72008174008275008173008073008076047F7E0B86901787922F
927D2CA567159D731BA0752C9075467C7650706F58856E569D6F56AA6944AE632BA96034
A25C419D5B4AA65F4EAA654CB5573DBB5335C14B47C04A52AF6755A5765B9379508E784E
947B43987743928044838C4E75A64B69A35269985A6A9D4A6EA040729E4070A03A6DA233
6CA43070A62770A52174A52175A62472A322719D1C72991772981B76981B79921A808A0F
828A0880910B7F990E7AA0137AA51478A41374A110729E0E6FA0106EA3156CAA196BAD1D
6BAD1F6CAF256FAE326EA8336FA33472A031759C2D78971E7E8B10818009817A027E7900
7F7B007D75007C7700797A007C7C007C7D00797A00767500757200746D00716900736A00
796B00776D00786C00766C00726800726500736700736600726600726400746000726100
725F00735F007361007861007360006F5F006A5B006C5A006B57006A5500685500655200
654E00654D00644E00655100645300614E005F47005B45005843005D4800604900634800
6348006148006049006048005D45005E44006044006243005D46005E44005D45005E4500
5B45005D46005C43005B44005B4200594000533F00533A005139005234005036004F3500
4C36004B3600493300443100432E00402C003C2900392800332400311E002E1D002B1D00
2A1D002918002513002112001E12001A0F00180E00180E00160B00150B00110B00100700
0C0600080300050100020000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000200000301000802000904000905000A06000B09000F0600110A00140C00150D00
180F00191000190E00150C00150A00140A00160A001608001609001A0B00190D001C0E00
190D001C10002013002413002715002717002818002B1A002B1D002C20002A1B00251700
281A00271900301C00372300392A003C28003724003221003423003C2B004438004A4300
4F4700534A00565500536100546B025070034C7A06507F065482065484084D880B4B8D10
4993184594224296293D953339953C38923E379340388D47387F4F3570563170572C7158
2D6F5F2F6C68326C713464742E60772A577E324C85413F8A5338875F3A826B3B7E743C71
793D5F7B3D517A3654763256722D546E2C5A6A295F6B276275215D84205C7026526D2E5E
7C31726A24706F136C880D6C8F107698137C99177E981C7C982175902680872A8A812D93
792F997132A06A33A057369A4B3C943A4B8B2A5E841B6C8019797B1D80751B8074207677
237777287A742D7B76317A7037816D39846C3C84663F8466448367458164447863456966
465F6E4A606F4959724F5873565D745B65765A5F6F525C6C4D566A4D546C4E4F6D50476F
504F734F53784D5A7A4A66714B6C6C4D6F625072555170574D725C4D7064525F75515473
4B4B744748784B5D67456A633F6C68436E6D416C763F6A78426C714062754A6571576A6B
6370655F7260576A62555E65555F684E5F7648686E42745F467D485D78286C6F116B6607
6D5C036654006558006656006D5B006E5A006E5D007161007264007965007967007A6700
7C6C00776C01797104797F108D822F976E479E6C3AA45938A06345916E507A77596F6D62
7169627E675D8E61599A5C52A25646B6563ABA5A2CA85F2C9063369D5830B64E23C44532
BD4446B44D4FAD6548A9684DA1654C98664E956E50976E55A37448A07045A16E429D6A4A
886D57827355837C4E79884770924471983A719E2C74991E7A95147D92127E900E808D0B
818706848002877B00887100856E00836B007F6A00806A007F6D007F6E00806E007F6A00
7E6E007D72007F76008278008178007D71007E6E007D68007C66007D6B00827401817E05
81890B7C93117E9A117EA31276A71374A81976AB1875A91874AC1A77AC1679A90F79A80D
75AD0D77AB0C76AA0C72A80A70A308729F0A72A40F76A71376A91B76AE1B7AAD1073A70D
709F0A6D99086E92056F9406729B0B74A30F739E1274910D727C04756D01746B00756D00
766B00756700786A00786A007A6900776400716600706400716500726200725F006E5900
6A56006D57006D56006E5900705F00705D007263006F68006A6F0363750A617E115F841B
5F841F5F80245E8125617F21647C18697A0F6C71076C69016C6000675500644C005E4400
5B43005942005942005840005A43005B40005A4000574300543E00513C004F3A004E3500
4A36004A3300493500493400463600462F00412C003E29003826003420002C1C00281600
2014001B0F00180C00150B001209000F07000B05000B0200040200030000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000200000601000903000D03000E05000E0800110700
120800130800150B00170E00141000160D00180C00190E001A0E001A1000200F001F1300
2312002315002517002517002017002114002814002A1600271A002A18002B1900281700
281C002919002D19002F1B00351800331C003420003723003725003729003A2A00392F00
3F3300443700473A00483C004B3D004D3E00513F005C5100626A025A7D08498A11408E14
3F911342931748941C45932340932D3A8D3A368E3E348C40368E40378C48378945388945
358F443197492E9C522A9B5C2B97602998632B97662B96682B91642B8B652D856A317D71
36747937697F3E61834659864E528955538B5D508B674C8A684581693E797137736D3674
75317B76347A7B35777E357080326F842B6B9122688D2660862B5A832D58832956852655
872660832A707E2D807C2D897A2D907A2E9776309C6F31A06833A15B34A15337A24C3A9E
414594394D8E3354882F607C286873266B7227766D267E6A28826C2A816D2C7F6F2F816D
328066348067347A6A38786E38756C376B6F3E636E416B6B456D6E466E6F487767477E65
497C694977714B7C70508068557C604E76624B735E47765E446F6740697040616D44516D
4F5968546566576D63546B655064694B57734B5D724B5F78505F754D6F6E447A6B447B65
467A6448736F546E7062677171557B784F777C4E78824F777D53727351786B58715F5C66
51585F586D355E7612656F046D67016B5D006C59006B57006B55006C5900715F00725E00
735F00705B00725D00735E00736100755E007962007B64007B6900817A0C7D821D7C8126
8E7B3197753E916C409E61587A7355647A6263865B678658717D5881685C8C5E639E5D5C
B05656B5534FB85249AF5134AA4C24B14A23C7442AC5413EB53C56AC495AA85C4DA25D50
925960915A66A06364A665649B6F5E9871569D764F9A7751917A518B8A4181942A869314
898803867E008176008071008472008772008777008A79018A7F048D8307878207868307
897E02867800857A008A80008B83008880008A8600848F017F97087D9C0E779E1070A111
71A71871AD2472B02A75B52C75B42E75B43574B33271B32F71AF3373AC3471A9336CAD2F
6BA82F69A1316D9A326F95366D8F376E8F3F6E92426C993E6BA43866A92F66B02B66B335
65A83E6297485E9A4C5B9B4B5BA14B59A44F5DA44F5FA8485BAE3B52AE3150B02E52AE32
53AE3751B13F55B14759AB495EAA455EAB4063B33A67B5306EB7286DB62E6DB3396AAD3B
6CA43A6E9D356E99337495357E91338789338C873792893B8A8B3C888C3A7F89386D9037
62963E5A9D43539D49549C52599C575D9C56659D4D6A95476B8E45778C467B8A4C738D4A
6890405D9036588E2D5193294F9D29509F27539A2550911C5A7D0E607202646800676100
675800655300614A005E47005B46005C44005E43005B42005A3F00543E004D3A004A3300
4330004027004229003E29003B2700382300321E002F1A002716002212001C0D00160C00
110C000E0500090300060100040100010100010000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000302000602000504000903000D0300110700130800160B00170B00
190E001C0D001C12002113002114002015002014001F12001C12001C0F00201000211200
2110002111001F12001F13002313002719002D1A002E1E002A1C002C1D002F1C002E1900
2A16002B13002918002E1F003725003F2E00433100423600403500423600433600443A00
453D00484400514B005852005D5600675A00686701647703578809469417389C2336A026
379E273B9F283AA12E37A13234A234329E38339E38359D35389D34389C40359D4C319E55
2CA05929A25C269E66239771218F781E8E7A1F8C7B238978257D75296F7731617A415680
554982674281713D827B34827C2E847A2F867A30867D2E80802D78822B6B832C71832B76
842B7C852C71832D6A822B608027647E23677F25678026668029647D26637B246179215C
77226B7126846B2C9C6632A26934A36C34A16935A45E3AA6563CA7443FA135439D2A4697
255590255C89275E8529677A287571268371268C68278D652A8C672F8C64328E62348F61
399161398A6238806533776734746A37726F3C6E7245716B4871684A72684F7B664F8268
4F81645280644F8762508B62538A5B4D835D4C815F427E633976713B6D7643646B505669
5B5C625A6656546B5C546E644F6B6C4D677353696C546D6A576F6456785E4B7C6246806D
4B746F525F7566577573556D87506787585E8C5C66945B6E806A656473625D7849647B28
71740F747409777203756E00736300735B006E54006A51006653006954006E5D00725C00
736100736200755F007A62007D64007E69007B67007E7006787E1879882790773F996D45
A0653A954B4D8459597562687272617372587A6A5B8A5D639359669E5B65A35D61A55754
AB5443AD5436AF4E26845637785A5181563BAB4E21BF4830BE464AB75050AB61499D5F4F
935A60925868905D59906054926848936B419D7441997B3B84882E838E18848404877E00
877A00897B00867D00867F0284840885890884890C878E118598117E9D147D9F10819C0E
86960C8A890A817A02837B00868E0583A10F7EAB127CB2157AB72079B72275B72970B72F
68C02F64C03364C03965BE376AB9366AB53C69AF3D6CAC3B6EA6386CA33769A13F639B45
669146688E45689044689743699D4367A13D66A43966A43B67A63E69AB3A68AD3A5FAB3D
5C9F435B984861934A63984B5B9E5255A35351A35357AB5057A94749A04245A94047AA4B
48A85547AC5448AE554EB15B54B05553B14754B63B59B72C5EB82860B72866BA2762B72D
66AF2E66A732699F306BA1326EA43F6FA54171A13F749E3E70A43F68AD455FAF485FAB51
5EAA5B5EA55A5D9C5B649C5E6D9D5A719E54749A4C6B98476193405B8A3A61843C6D873F
628C3957913455992E519F2B51A32C50A42B519E274C951A528B1159800E5D7605637000
6764006759006753006250005F49005B4400594000583F00573C004F38004E38004A3200
432F003E28003B2500362200321E002D1B002C1A002A18002514002011001F0C00140B00
1008000A0500060100020000010000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0400000703000B04000D0700130A00130B00150B00140900120800150900180C001A0E00
1A11001E1100211400241500231600211600231300221200241600251800281D002A1D00
291B002A1C00291E002C1F002F20002F2300352400372200352600342500342600342500
3724003821003928003F3500463D004942004644004744004747004746004A4A004B5000
515600535B005862006269006872006A7F02618B084F94123F9A1835A01D32A61E34AA23
31AB2930AC322DA93E29A74B28A45129A35629A55A28A65B29A45929A257249F6022A066
20A06A20A4651FA2691CA17015987D14948E178F88178980167C7F1A6B8220588C304793
443A9A5530995D2998662197671C956919956B189069168B67158868148668138F6C1398
7111A0770F987B0F8E790D83760E87720D8B720D8E720C88720D806F0C7E6D0C806B0D83
67128A62189B5E1FAA542BAD4835AA3D3CA63A3FA43B41A03C429C2F4D9324568F1C5B8B
1C637F1F6A7A2671792E71772E7E6F2B8C6A2E95642F965F30995C33995A3A97593E9560
4492644187633D7867376E6E34786D3881713F7F6F4580674A846252895E50855D4A7A66
417269407B61418265498664538A5D5588605384664D7A624B6E655265635C685A646755
676E4C65724359714C56705D4F6D6A506B6F55706C5675655375655577645571705D6576
6364726D5F7178586D74586771575F7B694B7B793C7A833775862A6C831F737E10787909
757100746F007667007567007364007464007462007360006C5E007058006E5600705700
755C00745900795D007A6000775D007F68057D70108689218C8334937338A76836A85F49
9E5F4F9F535F9957629D5F60A16054A65D4AA25A519A526097495D9E4850A34545A54348
A73D4AAE3B4BB5384F98485084585D7F60519B573CB05440AA5259A05E619C6A599A665D
936261916A5B93704E947647917739927F309A8729938D1B848104857700876F00876E00
8A76008E850B90921D89991E859E1A819D1B829F207BA62C77AC2376AD2273AD1C79A812
79A8137DA5157C9E0F7B99097D9E0A74AE186CBA2B67C03969C03869C03168BF2D67BC35
62B73760A93E5DAC3F5EB14060B23A60B13C5EAA415DA14660984C63925067904C6A894E
678B50608B535F8551658A4F6F924D6C95416D973A70A23474AD316FAD326EAB3066A135
64973E639049608D4B5E904F5C975253A1504DA3524DA7554AA54C41AA463EA04B40975D
409869439F6441A7643FAF6540B76444BB6349B9554CB74751B33B56B63758B52E5EB130
65B12C65A72D68A3346DA237799D3772A0326AA12F63A52F61A63061A43D5E9F4A5A9753
579B5359944F5F934F66944B6396486296405A9F3B54A83854A73053A025569C22519D1F
559F2753A02F4E9E314E9F314EA2374C9F33479E2B489B214B96194F8E1659800A627201
696900685B00645200604A005A4400574100583C00563D00513A004C34004A3000483200
402C003A28003524003421002F1B00291800271B002718002513001E10001C1000160B00
0F07000A0500050200010000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000020000
0703000D0800130B00170D00190F001A13001913001A1000160F00180D00190D001C0E00
1C11002011002213002816002717002618002715002A1A002F1B002F2000332400331F00
2E1E002B1D002D1C003020002D21003424003727003A28003C26003A28003D28003F2A00
3C2E003E3100403900434100464A00444D01474C01474D004A4D00494F004D4F004F5500
555E005860005D6700636E00677C00648A05549511409E2132A1232EA42130A91D31AA25
2AAD3328A84027A24F239C5D239C66229C68229E6D22A07120A06F209E6B1E9A6E1D9B72
1D9B741FA2701DA36F1CA27317997F17928B168A8A1783871573871A62891F5091304199
43349E542BA15E22A0661BA06A169D6F13997111906D118D68128D670F8D690D946E0D9C
760BA47E089E83069581078D7C0A907809957608987406917304896D058468078963098E
6111965C18A25A21AD4F2CAC3D38A92B40A428449F2C459A2F439525518E1B5C8A176187
19677C1E7076237A762D7A732C846A2C91662E9B61319C5A319D57379B583C955B408E63
428A67448964417F663A7B6D3A826B3B846A3E826A4586674D8A634F8B5E50895D497D60
3F73653C7B623F82624785624F885F53886352816B4F7966506D66596B5C637056657552
66774C5F7B4657774F53735C516E63506E685A73635C7C5D567C5F5878655F6A706E5774
74596D81596A845C64785B5E72595C756F476D852F5E89246881176F760A727104756F02
716900716300706100725F00725A006E5E00725A00715C006E61007157006E5700705600
725300755700795A007B5E007C5E007E7011758827898C2E9A763BA16A3BA86933A26745
9464549058648E5E668F5F619D5E5FA75762AA51649F4C669C4D64A44960AD475BAC4651
B24441B74443BB4246AF484B9A5255935C52A05B43A95A46A0565C9C5E5F996E5C946E5C
8E6F5D8A73548F764D917D478C7D3D91862B8A91198B860B867A018978008B78038D7F0A
9A8910968E1D94912890932D89982881982A819E297BA53179AC2777B02475AD1E71AA14
6EB11C6EAC2271AA1D75A31177A10B72B1186CC03864C43F62C03E64BE3E64BB3B61B647
59A75259855C5A97565DA94E5BAB485DAC485D9E505B8D56608C57608E55658C48628A4B
6195515E91525C844F63904C6F974D6F9542739C3A759D3773A4326EA53068A62E66A332
5D9B3E5B914A5A894D54984C51A64F4AAD5144A856469F5E41A4543DAC4C36A050389A60
3F99653F9B6541A06641AC643FB76542BA6341B75B46B1534BAC514DB34951B54158B242
5EAF3F62A83E64A53E64A43B679E3A6A9C386B9C3C63A5375C9E4058925157855C567C61
51825D4E8A5D52915D58985759984E589541549D3F50A83F50A93553A52659A32356A020
57A02052A22151A3274DA4284CA5284BA62846A327469F2247971B4F901756840B5E7302
656600675700624E006049005C4300594100584000563C004F38004B3400463000433000
3F2E003C2700362500322200301A002719002317002115002112001D1100190E00150C00
0F09000B0500040200000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000010000010000020100050200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000000000000000000000000000000000000000000000000010000020100040100060300
0C0600140A00160F001811001B12001A13001C13001F14001F1400221600231800261200
221400231400271900271C002D1F003021003624003928003825003B26003A2900372500
321E002F1B002719002C1C003520003827003C2A00422E00442B00432F00453200453D00
424900415001425401415102444E01484D014B4E00514F00575800565F01546301536502
536D025971015D76016281045D8D084D9814399F2E29A24824A54627A43C2CA5362AA540
23A352219B6521926D1E8B721C8A731B90711B936F1A92721890741A8B751A8C7817907C
19917B199879199C741B9E721C98761A8F7F187D881A6C901D569B2148A12342A52E40A8
4039A45031A15C2CA167289F6F239C7721997A229675249372249173218F7C1D8C871989
9217909813939F11969E0F909A0C93940C988D0A9A870998820994710B93600D995110A2
4B20A7422EA83C3BA73542A32C499D224D971F4E8E1E50881E52871C617D1C6C781D7472
20776A1F7D652582662982682C89662E94612E9B5E30985B3697573D965B3E8F5D3D8564
3E8066438765488E6247936647945F42935F439064418F67408D6C438B6D4A8765488461
438463448657458554438859438B5A4687634F7F664F7F624F7E62577B5C607E54647E53
5C8150577E504F755F49706A486C684B656A536F6154765D526B685B64686B5B6B7F4F6C
7954677659657860547375426D813A6E83286C7F16686F096B69046C65016E5F006B5C00
6B5C006C5F006B61006E5E006A5B006858006B57006A5E006C6000715E00735D00755D00
7363007664007963007E720C7A891A948F28A37838A57334AA6A35A1654697644E8E635C
8465637C606989596698585DA45853B25850AD54519F534D9057508755548555578A564D
8C57449E5436BA4D2FBF4548B84160AE5161A76056A06551956355906B5A9076558D7657
8973588B744F8F73489080388298278990188B81058E7E018D800093880399941197961D
9F9427A7932DA2932F9C88388D8E31828D38769B38729D396FA63B71B3356BB7326AB835
6ABB4467B9486DB4426FAD3072AD176CB32269BB4166C04A64C04261C04360C14560B947
5FB44860A74C5F974C5B864E5F855267875F5D886B528F6852A75B4EB84E51B25055A458
58935B5B8E525D9544689B3D729F37789E3976993A77973B7199376F9B2E6C9E266CA22A
66A32C60A0335AA23750A43D49B24444BD4D47BC5145B9533EB3533BB64F3DB65248AB58
50A15648A0533EA7523BAF5739AE5E39A5623896663B91663D8D674090604A905F509060
54935B588C5A5C855361884F618B506889546D8A5E69866466706662646971606B82626C
836C6A7D736C64786756776556805F528F53519E4A4FA7434EAA3E4DA73C50A23B519A2F
4F992A4C9C264AA5254BA3254AA1224CA1244C9D2350991E5196154F9112508911577A07
5D6800625F006157005D4C005A4800543E004E3800473100432D00442E00412C003C2800
392200342200301D002C1D00261D002418002314001E12001A1000180F00170F00170E00
120A000A0500060100000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000000000000000000000000000000000000200000301000602000806000C0500
0F0900120D00190F001B13001D15002014001F1200201400241500241500261A00271700
2619002B1A002B1B00281C002D1E003523003828003D2C003F2B003E30003E2C00372700
3623003320003120003620003927003C2C00403000463100453400483600483B00494500
485200445D01465D034A5B034F52015251005751005957005A5F00586901576C02546E02
527503527903567F075D8B0B5296113D9C232B9F40209E5B20A15A23A15026A04B249D53
2099631F91751F8B771C86771A8876188F7218936E19926F1B8D741A88761A8978198C7A
1A937818977A1C99761D99751B91791A84801973861C63901E4F992542A0273BA5313AA9
3F36A64F32A55A2FA2632CA06A2A9D71299A752A98752B96762B92782A8D7F268A892387
961E8B9C1B91A31793A6128FA310919F0F93940D96890C967F0C976E0D995A12A24719AA
402AAA383AA92F48A129509926549220548B1D548419568115598318657C1973731D7A6E
227E672582622586652A88642E8F612E985E309C5C34975B39935A3D8D5F3D89633B8466
3C836943896247905F48935F47975F42975D4092654191613F8C67418B69448964488861
43836448865C49885C4A85614A8A634C886451876051865D54845D5B805A62824F62844C
588252537D584A7560476D674972654A736A51786353775F57646A5E5B696F566783555D
7A5C5A755D557764496C7F39628728647E18686E0A6860016C60006A5F00685D00675800
6C5C006B5F006963006E62007060006E60007060007262007465007865007967007A6400
7865007B69017B6B0585871A81972BA0842CA96F339D69429B6747935F53845F5E776266
7D6A648664678F5B629B5951A85A4BAC5C41AC5D3EA55A3B945C3E745A5870506F74556A
735A64835C44A95629B44E3FB34C60AB5763A5675B986D558E6859866F568772548C7353
8E735391794B937F408B932C8097188B8A0A8E83018F8600928800969608A0991C9C8F2C
A7942EAE9238A89732A58D34978D2F8F8A3980913E76963B72A1396FAF3668B53769BB43
69B85068B6526DB04C6CAB386BB02067B12562BA3F60C04A61C0445DC1435CC0455EC045
5BB3495C9A4C648C4D74774E6F7C526B82605989654E93654FA85B50B94B53B44F50A65B
56935C5890515D954463983F67973C6A993A6F923D748B406B8F40639438639733639E34
5EA9325BAE3558AD394EAB4047B54747C05146BB5542B55739B4523DB24F3CAE524CAA52
56A54E54A34C47AD4B3CB2553CAD5A39A05E3689663787663982673B78643F71674A706C
4E7366596B6B67616B676167686763736867796B6B776F6F77686F6A616E775D6C885D66
8D6562866A5F696F5D5A705C557E5C5190594DA34F48B1464AB2444BAB444BA7404BA235
4B9E2E4A9E284A9D234B9C224D991F4F98214E931C4D9014548F12508A0F50850F547B06
556B015C60005E54005E4B005C45004F3D004A3800453200433000412B003E2700382300
3420002F1F002D1C002B1B00291C002616002113001E11001B0E00180E00171000150F00
130900090600030200000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000000000000000000000000000000200000302000603000903000D0700100A00
120C00160E001C11002116002317002318002016001E1500241500281A002D1A00291E00
291D002C1D002B21002E1F003322003725003A2C003D31004131004135003C2E00352B00
3826003926003B2800402900433100443500493800483900483B00513E004D4600494E00
4858004763014867034D6103565A015A5A005E5C00606200626C005D6D015C7001556D01
547802557D06548611538F1A459924319C37239951209765269B602C9C562C9F51259C58
209467208C751F89791B8879178979158E79168F79168B7918867C18827D18867A188C78
1897761997781A967B19917F168880147B84166C89195F8F1C4F981E429E213CA4293AA7
3439A84137A74D34A65630A5582FA25C319F60339D6532996D3097702F95722D95772A95
8327958C2194961D939B18909B17919B149489129878109B69109C5A169F4420A4342DA8
2E3EA72A4AA326549A245C8F2260881D5F811A6379186674156977186E751B766F1F7E6A
24826428865F298A602D8C5E31945B339B5C369E5C3B985C3A90603B85633C80653B8265
3D876A428D6243945C44955C469560439564419267419061408E633D8F62408F5A418C5B
3F856046885A4A8A584E895D508860538A5D568A595588565A83585F815664854B5E824E
527E5D4B7963456D67466A6947746745776F4A766C5371665E626B645C65695B5F755C5B
73694E70704574753D6D832B687C19696E0B6A6304645C00635B00635C00655D00665E00
6C61006C64006E64006E63006F6400746700766400766500776A007B67007E6C007E6900
7F690085770C7B86189391279E8040A97531A56D3D92664C8F62528B5F5878665C69685E
746D5B816C5F89635F925C5C975F58986A58956E539467519263528E5A568B4D5E89515F
895A64846448A1622CAE5839B05558A563619D725D947259886B5D846A58856E528D7054
8F734F8E834682963C849A2483890D8B84058E8900908C00989209989C11A0991F9F912A
A19230A98D3DA29537AA883DA7863D99824084844078923B70A5346FB2326FBB3C6DBA44
6DB94D6DB14D6BAB476EAD3D6CB4256BB32167B63363BE3C64C44062C4435BC2435BC048
57A84C588551787154A762508E6C567579615C8A654C96654FAB5A4FBC4E50B6564FAC59
58A14D629E406A9B3A679A3E689A40699C396E98377396386893365E93335E992D60A42C
61AF2E5FB4305BAF334FB13745B74148BC5048BB5741BB583BB6563BAE4F3BAB4E47AF46
4BAF424CA84743AF4A39B45434B05635A75D35976B34916B32886D386F6D405F714D5F74
5E61706C5D757E54727E56737B5C6B8461698E626E8B6B6A846C6B736C6C6C656B725A68
6F645B6F68595F6C56566F584F7C5C4C8A5B4AA25646B14F48B34C49B04747AC4248A83C
4BA338489F2C419B2245971B49971E489724488D19508A10568A0E56850A52800B567908
596F03585F005B52005B4B00574500503F004C39004836004730003E2B00372900372200
3121002F20002C1D00291D00271C002418002017001D13001D10001A0F00161000130D00
0F0900090300050100000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000000000000000000000000100000301000503000904000C07000F0A00130B00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0000000000000000000000000000000501000702000A06000D0700110800120B00130C00
140D00190C001A0F001A11001E13001E19002319002518002A1A002D1D003020002F2400
3324003321003522003522003624003B2800402D004131004634004136004131003F2C00
422D00453100443600483F004A49024754054957044C5D03516204546B04506D03516E04
5168045568055766045563025A5E015E6000656500607201537B014D7D024A7E084E810E
4F831250881D488A2B428A36388F442A915B21906E2291752A8F6D34925F2F975B279464
258A6D2286761C85761A8575188278168380168585168189177F8B167D8713828113887D
16947919937C1A8E80168285137A8A10708D116392145997164F9A18469C1C41A0213DA1
283CA33239A63C34AA412DAC422DAC3F31A84434A64D33A6572FA4592EA55630AA5534AB
6034A76E31A07B2B978327918822908C1D8E731B97571A9F401AA53527A5243DA215559F
146698176A9119678D196B8419707B187578177F6D188D661891691D8B6D228864258B5C
2B8C5B30905434984F379F4E3AA24E3DA34F3F9F54419A5841925E408B633F8A64418E60
41905E40925B41925B40925E40925E41925E428F6346925C46965941995B3B9857379059
388660408C594A9156568F5B5D885E5986575783525A874E5C84515F84555C8753568159
467766447764427764417868427B66446E6D4960735B5F67725A63736059656153716250
6B75415C86355C83226C7B0F6E6601686000655A00635A006760006C64006F6A00716F00
726F00706C00706D007169007564007760007660007761007862007A67007D6E00827407
7E8412929022937F44A278339D6F3E90744B926B4F87685576725877755577744A707247
73724A7F694D8B624E935E55935F589263598F64588F605B915C5EA75455B1504BAF4A4C
AB47569754549B5943A15F429C5D55916C5C887A5E86775F84676185615C846155856C50
86774B808E3777951881860C847E028980008C8601918B06989718988B2DA28F2DAA8C35
A68E34A68933968A3CA28B408E97447AA44073AD3874B42E72B52975B52970B62D6FB439
6EB1486AB3496AB3486AB34469B8316BB42968B33062B9375FBC3A5DBC3E5CC03F58C048
56BB4A52B95453AD58589E6162915E678E62579B614EA6584CB0574BB6634DAE6052AC4D
5FA839619E2D5E9B305E9E39638E4269834776834A7289446290405E9B3B5EA9395EB235
59BA3357B93157B42E52AF374CAF3B4AB0404AB74646B64D45B6533FB94F38B74A3BB73E
3EB23B43A63E46A84540AE483CB14D3AB25838A961349F622D97612F896438846D437575
4E617762577B784D80884A7E9C4A7BA94E76B04F719D52698F5D657C635D7469556E6E52
6473585A7D605483635180635287594F91574B9F5548A65245A54645A53944A330449C29
47942A47932949962949932048981D45941B478A1449870D4B810C518010537D114F750B
536D05576100585600594B005343004E3B004835004031003C2D003A2A00382600342600
3424003123002C1E00291B002516002214002315001F13001C1100191000180D00140A00
0C0700070400030100000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000000001000500000601000A06000F0700140B00150E00170F00181100180F00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0100000101000201000602000B0600120A001610001B12001C14001D17001D16001B1400
1F1400211700231500261800231B00281C002C21003224003727003B2B003C2B003C2900
3928003827003D2B003F2E003E3100402E00402F004231004335004438004A3B00493E00
4947014E51044F610D4D721B477B1D3E821940851343880C438407498406518005557F06
557F08567E0F557A0C5774075E6E0464710763790A6080055485024987083F8B1839922D
379335398E3D38884335864538874D338860278D6E218E72248D6C268F60218C601F8868
21906922926E1B8D6E18847117827915898415898E138093117394126E910F738E0E798D
11808B1584891985871A84851C7D841D73891A68921D619821579C224E9E23499D254499
283B9A2C329834269C3721A23720A53721A53A21A63B1FA93D21AB3928AA342FAA2F37A9
373CAA483DA95B39A65F339F5C309A5A2C99492C9A36349A233E991F4E981E59941A6491
176F89187281186F7E18737719816C1994671D9D6422A262249C632694652C8D5C319253
36924D399A4B3CA34A39A84B3DA84E3DA6513AA1523D9D593D9B5D40986140995D419B5A
42985A44935F4395623E96623F98573D9A513D9A53429A49409D413E9F433C9F483D9D4E
409B504895514F9256568E6059895D5A8750588542558847558B504F8F5D4A8C5A42805E
3E6E653E76603E7F6240826D497F6F53696E5F596F655D657759627565555D704B566F52
5F7D36667F166A74076B6D026964006A64006965006B6A006F6D00706F00736D00727000
706D00706A006F6800706300716400776400796A007A6A00776F007B7104827D0C858F21
8587409E7736956D478F754893705588715E7A775D6F78616F745A7463567B66517E6B52
7969527368597368597062606D6066705D6678536C7B48727B41707F4E5F8B5247A34E38
BB4230A7434E9643638A56607D6B5D777E5F807D6187705F896656846653866D53867B49
7B9431859117848305817700817700847D0087870787970F8EA01D9E8D2E948E359F8A40
8F8E42888E4681954A799D4C76A54B76AB4275A64078B43571B52970B52672B93573BB3E
6FB7416EAB476CA84E6BB15169B04268B32B67B62960B5305FB5375AB13F57B94452C047
52C0444FBC484DAF4A4DA04B5195444E92454E92514B9855429D5F429A61439F534FA240
56933D4E8342507A48567E4657903A589E3056AA2A56B22E5BB3335BB53159BA2856B727
57B7255BB62A5BB33255B23F52B44150B34650A94852B7434BC04740BD4937BC4535BA40
37B44437AC483EB04C3FAE4A42B2413DB84B3AB25137AA5638A85437A84D37AF5338A661
3990673D826B467674546E7B65697F6D647F71637C6562765C686D5C7466617D63648162
6A7E6156895D49915A469A5641A65441AB5040AA4941A93C40A53043A121449C17489B15
48981C4D961F4D95254F92224A8F1C4A8C19468516438110447B0C4479104870104A6509
4E5602524E005149004E4400503F004D3B004638004133004031003D2D00382B00372600
3523002F21002C1D002818002417002215002114001F12001C1100170E00110D00110800
0A0500060300010000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0100000201000402000804000D0900140E001913001C1900221C00241C00211900211900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0201000502000605000A05000F0700150C00191100221600231A00231900241A00251900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0603000806000F0800120B00140C00180F001C1200221700241B00261B00281D00291E00
301E002E21002E22002F2100301D002E1F00362200382800392F003C2E003D2E00412E00
413200413700483A004C3B00513A00503F005446005C5200605F03606D07597A124F8827
458A3A3E8C4D3A8F52359A52349F47349F40389C2A3D9B1642980B4B94094C92094F9210
5192175694195792135192144D951B49981B46961845931F4993204A952448982C449C34
439633459237418E40378E4C2E8B512398531E9E58209C602396631D9762159266168B6B
18916C1B92711B8D721F8272207A771A7486156B93145E94124A9614469617529419628E
1B6C8A19708917728A186F9218699E1764A7185EAA1863A91969A6186CA51A63A21A59A1
214E9D24469B2A3A963332933B2C96412B9A3F2C9D3E2AA03D29A2382AA3342AA63231A8
2F42AA2F4FA92F51A7284E9E204F961D50911E588D1B5A8F16608F1974821B837D1B877A
1B8A731C8F6B1C93671F9563209E5E21A85925AB562AAA5530A75533A45732A35232A84F
30AA5034A95436AA5635AC5837A7533AA2533D99593F975B3E96593C91563B9055429152
44925445964D469A4444A43D45A63C46A63A41A23D42A24246A24248A34844A253409D52
3F9F53439F5745995E449262478D5D4C895650805A4A87554A8F5446905E4089653E8265
3C7C69407C6A437069495C6F575F6A6C6261856453746B4D656C4B666D4366792562790B
6277076674026870006D6D006E6D00716D00736900726800726A00736F00736C00756A00
756B00796F007B71007E74007B73007E74007F78047D8814749C268390407E7E54817953
826B58737F5564855F558863517D675A7968667666706F6372715B72705877745A79775A
77775F73775D6D75616C6C657166697F5C6C86516E795D5A726259855156894962815959
9E564B955553825164785C6070645D766C60866A678A7461927351887D50738D4F759C33
7B9A0C7F8D027F88008385008382008084008B8E0F87942987923A878A4480984877A645
6DA54970A34C6DAC466EB53D6EB6366BB5336EB62F6DB72E6BB72970B82673B52177B61B
76B61977B81B77B92374B82D75B93275BD3077BC296EB6246DB2246AB22A67B42B6BB631
62B73858B0434A9751459956409E5444A34A4BA1484B99474D9247508A4B4C89444D8D3D
4D992F49A02846A72449A72250A91E53AA2056AC2656AE2D5BAF2F5EB52C5DB5265EB324
5CB4275EB4275CB72957B63954B84154B34955B34B51BB4C4FB6444CB33E4AB83C43C03D
3EBC3B3FB63639B63F38B63F3AB0323DAD2C3EB1373CB5443AB45337AC5A3AA86136A169
359D6E3A9173398775398278397F7B3A7F803B81853A81883E7E8D3E7A8D407688427583
3D82793A9072379D6732A55A33AE5A32B05D37AD5336AA4834A63933A3302FA22A31A027
339F25369D243E971B478E12468A154583174382113F810F3E780A416E06495E044C4A01
483E00473C00493C00493E00493D004737004633004032003D2E003B2C00382800362800
3226003124002C22002B1E002A1E00271E002718002215001C1200170C00120B000D0600
070300030200010000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0A07000F0A00120E001810001911001E13002317002318002619002B1A002E1D00332000
3725003726003A26003626003326003622003827003E2F003E3200423100463200473600
4A3A004D42005447005A4C025A51055F5B0965680963760C60840D548E1849982D419A4D
3A9362368D6B339168329B5B319F4D37A03D3CA028419F1846990F52950A55920857910B
5A920E5A921055900F5093144399223F9E27399B3136963E3A95403E9A413D9B3B3F9F34
3E9D3542993A3E9440378F49318A4E259B4E1FA3511CA0581E99611B9963159468178E6D
1893721991771D8C751F81731F77771B6D83166192145195144097163B9716479418598E
1B668B1B6B8A186C8F1669981664A2155FA8175AAA1760A71669A4186A9F1A5F9E1E569A
1F4D9A21499B2640952C3B9234379138369435359735319C392F9F362FA1352DA53433A9
3145AA2954AA235AA1195B99135C910F5E8E15658C17678F18688D1B7B7F1B8B751D9172
20956C1E9D641FA25F23A15A25A05923A85428AB542FAC5133A95132A55432A45630A855
30AA5432A95434AC5535AE5338AA4D3BA74B3EA14F419E4E3E9D4B3E9C493F9847429944
459843449C42469E3D43A63C43AA3C47A73748A13D47A2464AA24549A34A43A152419C53
3F9C53449A5744975B3E925F438C5C4A8A594F875F469059469553408F5C3E87643F7F65
3E7A6C3F776C466E6D4D5D6D5B5E606C64557F6A487075455E764560793C627D1A5B7001
5E6F006473006A71006E6B00716900737000766D00716B006C67006E68006E6600726A00
7870007B77007E7A00817D027E8108848611868C1D7A982B72993F798B4C6F8156708253
678153609052588E62558A675182675B8162697D5E7776597977597A765A7C77597F775F
7C785F79735D7B6F5D7B66617E5A69834974863B787062646E82667C6554AD48619D5E61
9A62558D5C5679575D725E5F6F635A7369608567658C6E61917058887C4E70943977961C
7F8B067C82007C83007F81017E80018483008B910F8E903388963C7A994377A64771B045
72B1456DB34265B83F65C03D6DB6376CB52B71B6236FB82770B52670B62574B62174B41A
72B41777B71C77B82075B62173B92473C12E72B92E70AA2D6DB2266DB32B6CB32D6EB930
66C0345FB63A56A04A48A84C41AE4C40AE4947A84B4A9B51528A555B715B517A51488B41
49992C4AA42344AA2249A71C4EA5144FA61953A81F5AAC285BB22D5CBA315EBA2D58B82E
57B92F55B72E55B63855B64751B44A54AF5057AE4D55B64C51B8424DB73650B9334EBA2F
49B92E47B62D3FB43340B2333EAF2E3DAF333AB24836AF5A34A66832A174359D7B349583
308A882D808E327D90317694347293366D923A6A934166984A61994E5F9952609451628E
4971874286803B947036A46637AB5B39AC5336A84C33A84632A7412FA4382AA3342CA02E
329D283898243E901A43881345841046810F45800C3F78093E6D054364024C57004D4500
484100463D00493E004B3E004A38004637004433004131003D2B003B2E003C2900392800
3527003222002E21002F21002C2000291C00251900211600191100140B000F09000C0500
050200020100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0E09000F0D00170D00171100191100201200211500201300211300271D002E1E00372500
3D28003D28003B2A003A2D003A2A00392A003B30004032004636004837004D35004E3F00
5147005750005A5901606507647110637B1A5F881D56921E4A9A24439F303A9F4736945F
348B7133916F2E986C289C652EA25238A53B3DA52841A31F4B9E18539B1259941059940D
5A940E57960D53960D4E9711459E1C3C9F2A399B3B36944B39924F34954D349548349D39
389E37389E3C37994036914633894C29994A21A2491BA34F1C9E561B9C5C1898641A9369
1A96701A94751B8A761D7B771D707B1A6A8316608F165195164198183B9516469318568D
1D628A1E6B8B1A7090186E9717699F1563A3155EA51560A318659E19609D1C549C1E4C9C
20499C21489A22459424489126468F27468F244193293D972D399B30399E2E3AA12C3FA4
294DA5225AA21C639A19649016628A14608C156E8C17778F187E8A1B887B1D91701E976E
209D6820A36221A45B26A357279F552AA6522DAD5233B04F32AD5031A8552FA55932A857
30AB5733AB5537AD5336AC4D3AAC483FAA4742A94741A84541A74240A44140A24341A03D
43A03C43A03A44A23A42A83E41A7404AA53B4F9F424E9E4850A1454CA04A44A055409B55
3F9C55469A5942975741925C418D5C4B905C4E8E6045955A4396533F905C3D87623E7F66
437671457170486D6D5061695F635C6B6952796E47667B3D5685325583225C790E576E00
5B6E006773006B71006E6F00716C00716D00736F006E69006C67006968006C6A00756C00
7B74007C7D018188037B920777981573912E738A40738B446F8C48698B4E5E88595C9055
57915C539C5850995A508F594F8B575A835867785970745B777D577E7E5A7F7B587D7B5B
7B785C7B7260796E617B69638B5C6A974D6A973D6A7F56656E6D6086615EAE48699A6067
8F676182675C76685E74695770665E7565618C615D8F6C5A906E5A898144759B1F7A8E0E
7D7D027B75007C79007C8001807F01818A028C9719958C3C84974474A44375A94875AF47
72AE446BB7416AC04069BB3F6BB5396DB53072B52A71B52D74B52C76B42178B41B74B319
74B21776B31B77B41E76B71C78B72078C02A76BB2A73B82F6DB92D6CB6326FB2356DB932
67C03260C03856B54C4EB34647B24247B2404DAB4250974952884E577C574F824A4B8E3D
4C992A4BA42043A82043A81B43A91A4BAC1F4EAB294FAF2F51B53356B7345BB7335EB931
5CBB315AB83458B64556B24F56B34D56B34A57B44856B44554B73B50B42E50B3264EB426
48B42644B32A40B12B43AD2943AB2A42AE373EAE52399F64398A703A817A3D7E87397889
366F8E346B96386B9B38699C3C64983E6192445B945057965853915D568B5F5C87576388
4F6F89467D863D8B7637996639A3543BA3473AA04037A13734A13633A1302DA02C309F2B
349A2437992341901B428C1443860F40810C407A0A3F6F063F60024559004E4C004D4400
4D3F004C40004E40004E3F00483A00483800453600443600403200392F003A2900392700
3626002F24003020002C21002B1F00281C002418001F1400190E00140C00100800080500
040200020000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
110A00150C00180D001C10001A10001A10001C0D001A10002112002516002B1A00352100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160E001B11001B12001F14001E12001B0E001B0C001C0E002012002B16003120003B2600
3D2B003C2B003E2C00382D003A2D003E2E004732004F37005540005A47005B51015F6105
59710C52831351911D4D9B294B9E3540A24037A44330A5432DA4432F9F48358D573A7A65
347B6D2D826E29866D2889642C9F4530A92D36A82338A5203FA221449F234C9E274C9E28
49A02A4AA22649A22646A42A3CA83830A94329A74C32A04E38974C308C4E2D854E2E7D4C
31765034804B3296452EA1432D9F4128A23F20A5401CA4431DA6451DA1521E97631D9271
199079148C7D187A8019638618598C175D8D185A901853931A4A972144921A488F184B8D
17598D1A698C1C788D1D7991187696136F9A106B9D11649D12609B15559C18459D1B3F9F
1B47A01C519F1B589C185F9816629316608C16588D1B4F8F214994254D97265398225A97
1B6196186C9314788A16757F1770801B67831A80821992821A9F7E1E9C7321A16A1EA16A
1D9E661E9C63209B5C259F582A9E532EA25132A65331AC502FAC4F2FAA5231A95532AA52
36AD4C39AC453CAC3D3EAD3B3FAE3843AF3643B13543AE3743AB3844A74040A74340A53F
3FA43C44A44144A34242A44541A149479F474C9949489C4E4B9C4E4B9B4F4B984F4A9750
469C524B9A544B984C48944D45915249954A4B9948429D493F984A3F8F573F8662417B66
45696D4A646F546A6462675C6B6B546B71516F7451608334548818507B09597204616F00
6575006677006C7900707E00767B00737B0073780072790071790074830178920B6CA014
6AA41E61A8295CAA2F54AA354FA53551A03A52A43B51AC474DAF5444B25C42B26743B15D
45AD5C4BA95B4B9A5A4F8F505C844D5C79525D765E6173656E7762737D6572775F706B5D
73695D7D67627F65667B626A81596D985764A94D608B506C884B7B9B506DA94E6A8C6170
7F6F70787E6476825579785682636287665E9666528C704B75834F7D8E2D85850A7D7401
7B6D007E6E007C7400828100908C0C898F24948D2E9B8D3A829C4875A0507096586B9456
6A9B4B66B04C61B7535CB6505FB24967B04470B24270B73772B73071C02672B92374B519
77B10F7AAC0A7DAC0E7FAF167BB4187AB51877B51B74B9266DC02B6FBA2B71B23271B926
70BD2167C02761C03258C03F53BB434EC03C52B23C529848539D4955A14651A1424FA23B
50A92C4CA92446A71F47A31D43A32543A73849A04648A64E4BAB5551A85756AB575BAD56
5CB3515EB7505CB64D5BA74F5CA44B5BAE445FB03D61A82B63A01D6298125E900B58940B
4B9D1544A82944AF3A40AE3C3FAA43439A604776764C5B8062548774518A70578B6E5F8B
71638E6B5F915A5A90505E8B4A5D854F5F7858656C57686655655D5166574D6B55486E59
40755A3B805A3D8C5640994945973646952B4794264492224394223E951C389A1C39971A
3B95163E9315418F1041880D45840C497A094E6D08515F055253015147004F4400514100
4D3F004B3D00483B004839004834004436004737004334004132003F2F003B2C00392700
3428003320002D20002B1C00251A002318002115001D1100180C00110A000B0500060200
020200000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
1C12001C15001F16002117001E15002010001E0F00200F002814002E1C00372700402C00
402E00403400403A004136004635004E38005340005E4B005E5600615C006166035B770B
4C8A1C3E97283AA13237A64037A64532A7492FA7482BA74A2A9F512B8F5935835F3B7666
2F777127727329786E2E7F5D319D3D31A52635A61D3BA31940A01A439D1A4C9B194C9D1C
4D9F1E4DA11E4DA11F47A62839AA372CAB4328A95031A54D359C4A3093492C8A4D2C8051
2C74572E7A593190512EA14A2DA54228A53C20A23D1DA0421EA4431FA14F22965F20936D
1A95741792761B827B176D8416608B145F8D155C8B175D8E1A5C9223598E1F5B8A195A8A
1765891875891B80891C808E177A9611739B0E6F9D116B9B136899155B9A164C9C174A9F
1457A217649F186C9B187195167190186F881A69861C668B21658D236B8D24708B227689
1D7C8919808C14868617887E18877C1A867F19937A1B9B721CA06C21A06523A36021A262
1F9C6220956125985E279E592AA0562EA25530A55830AA552FAA5230AA5032AB4F37AD4B
3DAF463EB03C42AD3541AF3641AF3343B03241B03541AE3941AB3D44A94342A7463FA642
41A63F46A64046A63D44A63B43A13B489E3D4A9A44469B49489B4A4D994B52994D55984B
519B4C559A4D519A45499749459652479948469B4C409B52429355458A60418169447469
45626F4D5F6A566660656459696B516378505A7C4B57832B537C0F577505627201657000
6874006B7800717E00738501758A04748B06738F087690086F92086C990B66A51355AE22
51AE294DA9354AA73849A53B4AA63A47A93743AD3D41B0543AB36937B46A37B76E3FB265
3FAF5F46A85C4A985F518A5D5B7B5A5D72585E736363716B6D736A756E6C73656A70586D
6A5B6D76656A81656A755C6C6F4D767F5C71985C72815B747E4A7D8A556A9A5468886A69
7D766C7883636C88586F80577F695D83675D8E635480734B628D41788D22857A077A6F00
786E007770007F770086850198950F9C92259C8D32958F3E829F4F729B566F9257688C56
64915368AB4F65B7535DB54C60AD5068A1556E9E516CA63F6FB13670B82F6FB82775B61B
7BB5147BB00F7CAF137BB31A79B21B7BB41977B71773B81D6CC0266CC0266DBA286FB91A
6DB81668BD205FC02B5BC03F55C04756C04551B54053A24454A84455AF4652B1474FB13B
4CB03148AD274AA82048A42148A333439F4945895F4795634AA1664FA96550A96057A756
5BAD4A5FB14460AB39649E2F669924649C1E659516638C0E67840B667D086577035D8002
528E0D4AA02846AD3D41AF4042A64A429161496C705657826C4A8D7C45917B438C744E91
6A589B5E59934E6085426A764776654B7D4C567E335A78285B782059771E54771B4F7A20
48812D40883441913A409432419128448D21488A1C4A8B1B4A8E1845941C3E971E3C961B
3C9113408B0F40830B427E0A4776064C6903505701554E014F4300523F005040004C3F00
4C40004A3900483600483900483500463200453300453200423100402E003B2B00382900
3226003023002B2000281E002719002316001F13001B0F00150E00100A000A0400030200
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
1C12001C13001E11001F11002011002210002213002313002B1500301C00392300402A00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2012001D13002012002210002313002211002510002816002B1A00341C003824003E2800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261A002617002915002B1500291A002D1A002E1A00301E00361D00372000412400462D00
4A30004D3700533E005B47006057006761006C6C006D7603628009568D13489A263BA539
349D46308F59289B5F22A76122A96123AA5F26A55B2897632A836A2C706E31676A3B5871
454884385F852E8080269C7123A75127AB382FAB2932A92633A62632A7263AA7223DA91D
41AD1D3DAE223AAB2737A93138A73437A73D30A6462EA7482CA94827AB4B27A84827A943
2EA542349E4037994138964332A1382CA53024A333239B3F23A04621A35122A65421A759
1EA3611EA06C1C9C72188D7C177881196E831A6C861876871B7E851D80821E817D1E807D
1F8680188E80149484128F8C11879A147E9E19789D17799915789214788B13788A11798B
13818A148888158D831890821A92811B977D1E957B219578209879209B781E9E751BA370
18A46B189D6A199A6B199E6B16A56E16A66E19A26A1B98611C97581C99511E9E5221A153
25A35527A5552AA3552B9F592E9D5B30A05C2FA15E2EA45D2FA65A31A5533AA94B3DAC3D
3EB23642B33441B4363FB1383CB1393BB2403DB04A3CAE543BAE523BAD4F3DAB4A41AB42
41A93C3FA8393BA7363AA73540A53746A1424F9A494C9A4B4C9F484BA146479F47499F42
49A3434AA64A4AA64C43A64F40A45743A05343965B418C5D418B5C4780644C7669537368
5D6E6468695D696D596D6C576776475A87305483155B7A0B6276046A7401727A00778400
748C007193036D9A0765A3085DAA0B5DA9115FA81364AD1562AD1860AE1E60AA1F5EA822
5EAB255BAD2C5EB02D5CB12E52B53448C04141B55140B25E3FAC6847AF564DAF484DAE4D
46AB5845A3664A996E50916A588F63598C5F5F836562736B6770696761736962736D6174
68657461666F63626D6C5D646E566D686A6D6D69696572645C696C5A7063556D695B735F
617559697A5B6B71697069647C625775675673675D7484407496147A87047E7D007B7A00
7C7D007F7F00958C0FAD812CB07F2CAE87339787497D825378785E828457858755818252
78725B6D7161726B5E72685F7A6F5F837C5A82885573974E73A64174B53B74BA3A70C032
70B62375B82574C02878B82078B7197CB61F7AB92279B82072B92C6FBB326DB53571B62F
74B82B72B62B70B63172BD3C6BC14065C04368C04067BE3669B53269AE3065AC365DA340
5294454B944848A14543A14B429E5044A85447AD654BA96A51986255964B5F9D2B688C13
6C7F08707505706D036D6A016C6A006A6200666100626300666400686300636300616200
6168015D7706578C1451A12943A93A3FA63B409B4A3F9A553E975D3E9A6140A45D44A444
53901E5A76075B6601615E015C5C005D5C005A5A00595A005A58005F58005E5E005F6202
5A6A0754730B497D14468616498A194C8C1B4D8A194F86194A831A4C7F174E7712566C08
566501565C00565700555200544D005445004F3E004B3D004A38004C3B004A3700473700
443600433100433200432F004532004634004231003D2D003A2A00392900372700352400
3021002D1E002B1D002719002016001C0F00130F001108000C0600090200050200010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2D21002F1C00311D003420003421003721003923003D2600402900442C004431004C3600
4C3D005342005648005D5100636600677501637E065E8810518E21449B2D38A4372FA53E
2A984D25806C2192781C9F7A1CA3761CA178219A74258A722C787031686F3A6071405A76
475683386E802A8779249E6523A94A29AB3833AC2C38A92A3BA72A3EA72642A82248AA1D
40AE1D3BB02337AE2639AC263DAB253BA92A35A83435A73C32A7442CA54F28A24E28A14A
2B9E493697453B91453B8B4535983A2DA13526A335279D3B279D3F259D4C27A15424A55A
20A5651FA26D1BA372179B76168C761A827C20808023828125818020817E1C847D1D847D
1D8580168A80149283149389148F94178597187F99167B98137C9212808A108485128582
16897F178E7C1992791B93751E96771F9A711F9B701F9A701D9B72209C731E9D751EA26D
1BA0671C9C651A9A65189D67189F6A17A26B19A1681B9A601B98571D97541F9B5422A153
25A4542BA8542EA3562FA15B319D62309D642F9D6531A05F34A45535A74F39A8453DAA39
3EAE3A40B1403DB2463EB1443DB0423EB0453EAF4C3CAF533CAE503CAD473AAC473CAC40
3DAA3A39A83539A83A38A9393DA73E42A543499D46479D47469F4246A14043A34043A641
45A94044A84942A94F3FA84E3FA55542A153439857428F59428A5E4C7C61546B675B6768
64676270685A6D6D596B705D627C445D8B225B8207637A04687A036E7A01757F00768700
738F007296046AA10863A70A60A9105FAC145EAE145EAF185CB0195DB11C60AD1961AD17
5FB01958B02057B22352B5264BBD3445BA473FB4593FAF5F3DA76546B0564CB3434BB248
45B05647A7654A8F6E4D82744F7F6E52806F57777261677468706A656773636A7664667A
6465745F636C59626B5F666461616A5E75616171615B7A6056716A577766557766587758
5A7656617B5A70666F775C6A7E58577864507270587A883A7E930D7B85017A81007C7C00
838103888C0E938E1BA98423AD7C2BAB7F3E928A517D8558777A567F82517B7D5C797659
766C58726E5C756A6083635F956060A06D5F978353779A4B75A4447FA74077B53F70C03F
6DB5316EBA2E72BA2E74B92973B82579B72978B92A79C02678B82D71B33672B13174B52E
76B32E7BB12C74B32E70B7386ABA3B64C03D67C03D66BB376AB72F69B42B68AD2F5CA138
5490434C8C4B49924F449651419B5B46A45E49AB684EA862529A4F5B942E658B166D7D0A
6D76016C6E006E68006F68006B6500696300646400626400645D00645B00625A005E5A00
625E005F6A00577A0A51901E49A03149A339499D39469D3D499B3E4D9D3D509D3256911F
617C0B6368016060005B59005B56005D58005C55005A56005D56005D5A005E59005B5901
595C025B6504546F0953790B557C0C557D0D577C0C5B780B5A730C5D6E095C6806606203
5B5900575000594F005449005244004F3F00493A004934004833004A3600483600463000
4332003F33004330004131004232004333004030003D2B003C2800362900342700342300
2F1F002A1F00281A00241900201300190E00150B00100A000B0600070100020100010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
311D003520003520003A24004129004129003F2900452B004534004B3600503900503C00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381E003923003B2700402E004534004932004B30004B2F004831004A34004C36004F3700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3E28003F2C00452F004C36004F3900543B004F38004A34004930004830004834004A3400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443300473500493400523C005543005A49005646004F3A004733004731004B37004D3900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4B32004838004C3E00523F005C4B005F4C00574800503F004D30004530004433004E3A00
5347015860034D79133A822D2C87502589702482852D768E396691474F9447499A42489B
2D5D8E266887207589207787236F8228637E3762864C608C5A628E57608D4D63914D5F8C
317E802A90662B9F4932A7333AA72B3EA5263CA7223CA8213DA81E3EAA1E3DA81E3EAB1F
41A92140A82D40A53740A44439A34E36A35632A6502EA64C24A34F23995C249862269562
2F985636A34737A8403FAA3E3DA63835A4362DA43F27AC4025A94224A04427A14627A74A
27A74B279B4D27994F2A935A2B8F6929887624847C25797E2A76802E7C7E2F827A2B8678
238677228E782690732B8F732D91742C927527937123986C1F9A6624A16327A2622D9E65
309A65349B60349B5F379A60319D5F309D5C379A53359D4D349B4B30994F28985C229562
218D66218567228B6520926221995B229F5223A34D24A44D20A44C25A24E2BA6502DA74B
2FA54832A24735A14934A15135A45531A35731A25D349E6537A05D34A55A33A75B37A857
3BA9453EA93142AA2347AD1C49B01C44B02541B12A3FB02E40AF3044AF2B46B0284AAE27
4DAA2F52A93553A3404DA242459D44469F4146A23A44A53C45A74046A34146A34343A346
41A64641A84C42A8523E9D553C8E5F3C9060438F645182675A7065616B586D624F706B4D
686D535C774E648D2B6F920D718E03758E017892007792007793017199046D9F076AA507
68A90861AC0A60AD0F5EAC115AAC1356AE144FB0144EAE1947B22549B13548AF4042B146
43B34242B34046B54745B1543DB05539B05236B25135C04D36C04E39B3543DAC5E40AA5B
43A1564EA75458AA5758AD515CA94959A74558995151846E5F875E63835C5A85555C8158
568458548F5957915A58894F59884A598944538C46518C4A548A535D8651597F5F637462
6D606D745A6A88566A815D647B5E616E794668901B7585087E7E03818A0E86961E9D8C2F
B27332B17127AA603AB26640AC72469673568B745F89775692685FA0655CB06A55B86B57
BD6459B75C63B05664A5545A9B5B509D684099703C98734682864A78944B7B9D457EA043
7EA93A80AD3B81AD3985AB3683AB3182A9347CA9347CB03C7B9D4283854A8C88408C9132
7EA01E7AA21675A11871A71F70AD236FAD2669AA1966A91761A9205EB0285FB5335FB63A
5FAC4A5EA6515A9A585B934F5C9B375F931A6C7F09696C00666200646100655D006A5C00
6858006655006355006153005F4F005C51005A4F005B4E00594D00554900544300554200
5445005947005F4D005F53006153005F51005C54005C56005B5400594F005950005A5100
594F00574E005B4B005B48005A4A005A46005A47005844005645005A4900584B005A4A00
5747005546005245005744005444005043004F42004D3F00513E004E3C004D3E00503D00
4C3D004C3900493700463300443200402C003C26003A27003A2900392A003928003A2800
3925003826003726003728003929003929003828003426003428003123002E21002C1D00
291B002718002116001C1200170C001108000B0500050300020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4A34004837004C3700523C00584100574300513F004B3300452F00482F004A3400513F00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473500493400493800503900513B004D3A004B34004A31004832004D3A005444005A5201
5B6508507C1938813E2A6E6924707F1D7492276C9A39619D4751974E3F963E429E3649A0
2A6094296A8D2976862E7A823E6E7C62556D6C4F736D5079514F81384F852A5789267680
22976926A6472BA93230A92834A92535AB2237AA2037A71E38A91F3BA61E46A41D45A721
40A6273FAA2F3CAA363BA84032AA4A26AA5524AF561EB15419AE5523B05327AD5329AB54
28A9522BA9522CA95630AC4B2EA73E2E9F3A2E98412DA5402CA6422D9B442E9D472AA648
27A64B27975323965A288D652F826B3676732B7A7423787920757F227C7F28847B2D8977
269470209D71219D712698722E96702D926C289669209C5F1E9C59239E54299E51309A53
329255328F53329150359552309C522E9E522F9C4F2D9D512B9D58259E63209E6B1B986A
1F91681F8F6A1F99631F9E5D1FA2551EA44F21A44724A64824A64728A4462CA54431A644
30A240339F42339F40339F4934A05033A257319F5E339664349A6135A45C38AA553EAD46
48AB374AAA2C4AAA2549AB2244AE2743B03542AF3545AE2F46B12B49B0264BAD224BAA29
4CA7324AA83849A93C49AB3847AB3643AC3D45AA4044AA4042A84146A53947A43844A044
479F4C479850439258408C613D876C3E816D497D6D5D736B6C6B63716A5D776B536B754D
5985484F96345F991A6995076C95037092017293017296016F980466A30D5EAB1958AF24
58B02E57AF3156AD354FB03749B03949B03647B03849AE3646B13747B04246B14E45A951
459F4F3E955C419A643E9E6F3BAB643CB4573BC0513CBD563ABA563FB43D40B33247B136
48AD3752AD3F54AD4B4FB04C4FAE434FAD3D52A64751945858964D57964C58984758984D
57964C5A96475C95465F8D4262923A5E963A5E9F3D5D9B3D5E9148628E535E87616B7765
855D718B557290516B7F626367795B718A397E880B827C007F8404918B259A73437E772B
826831A26A27B57023AF6E3FA35F518D6E5989625F8F615C9A6358A56352B56655BA6455
BD5F55B75B5DB4505DAE564C9F5E489B6A409F753DA4793D8A85447E93467E9F3E87A73E
8AB03C8CAD348AA9308CA93087A6367EA33C7A9D427693457E8A4A827E4D82893E819725
7E9C117D91077B8A0778900977960E73A01472A5166CA4186AA52365AA2C60AE355FAD3E
5FAE3969A42C7092137183086E73036B6D016C6B006C6A006C66006C66006C65006C6A00
6C69006B63006660006357005E51005D5000594D00584D00564600514300524000544000
5644005749005D48005B4B005C4D005A4B00534C00584B00574F00544E00565000574E00
594D005A4B00594C005E4B005D4C00584700534200544500514000534500544200514000
523F00504100504200534300534300524200523F004F3F00504000533E00513B004D3C00
4D3E004A3A004838004632004032003E2E003B2B003A2D003C2A00392800372200322500
3524003624003625003425003424003626003627003427003524003323002D2000271C00
2419002217001F15001A0F00140B000B0600070400030000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4939004A36004D3D004C39004E38004B39004C34004C37004B3E005B480064580261690A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4534004336004937004A37004F37004C36004F33004D3A005842006252006665045D7D17
4F8A383A8F62317E7A2F7187286D961F5EA32D55A83F55A54D4F9F4E42993847972E519B
2E5F963C65903E6A87426683525C736A4E665D5577525A814060872F7080238076219969
20A95923AC4928AE3F2CAD3430AD3033AA2A34A92837A82B37A72E3AA62B3EA6263CA624
38A72337A82736AA2A36A93130A63F2AA74A27A75024AA5224AD5429AE462CA93F2AA848
29A64D29A74B2BA64B2BA93A2DAA2F2CA8332DA2402BA93D2AA6392F9A3F3297452DA147
27A44A289B5024A154269B5C2C88643473692E736B266E702165781F6C78207377287376
247D762086752087732587752E83713A7F6736885E2D8E5D23935823994F2C9A4B37974A
3793503193512E8F542E96562C9D5A28A15C2A9E5B2C9E5D2F9C622D9D68299E6D279B6D
28956D26966B259D6422A65E23A95322AB4927A9412EA93D33A93A36A53B35A73C34AA3C
2FA63D32A54035A54534A64733A64F2FA55E2D9E612F9460349B5A37A54C3DAB4045AD36
4DAE344CAC384BAB2F44AC283EAE2D3AB0393AAF3F3CB23C3DB13940AE2F44AB2648A927
47A83048A92C48A82D48A72F49A73148A9324AAA3546A83946A43F46A43D43A144449453
458A614383634382664281663F766A43686E56616E6B636C7A65647368636A66605D7E50
539D3458A71967990D7095066F9403709501749601729C016DA2066AA81167AE1B5FAE24
5AAA3059AB3355A53E51A244519F4850A3494AAB554AAB5246A9564CA652479F50419854
468E6044886F438F713E93743C9E703CA86A3EAE5B43B14D43BF4148C0394BB5344DB32E
48B12F49B13B45B14C43AF5145AD4B40AC4B4AA94A4CA4545CA4445CA33E58A13F589E44
5F92465F8D42608E3E62903861963B5C99415E9C495C8E4B55745354715B516B68666C67
795875855A70935768837160658B5073962D87900B888C157D86308982299B6840A66230
AB662BA46432A8633FA46D50A76D5F9A705D9C655AA35F56AA5D56AB5B55AB5B46AF603E
B86933BB6544BC5E47B169409E7440997740A28240A687408F864780834E878A4882974D
7DA3517AA3467A9F4180A83983AA3982AB397FA1397E943C7D99387E9D31809A1D84940F
888903867F00867A00857D018380027D82057D83057C80057E840981870A7B890B78800A
787908757405716E026D66006C60006860006460006461006D6700716E006E6C006D6C00
6B65006B62006A6300685E006052005B4C005A47005A4800554500553E00503D00504100
513E004F40005542005545005746005346005042004A4200504400544600554800564900
5444005644005345005849005648005848005345005445005245005242005040004F4100
5244005545005443005348005747005743005640005241004F3E00503A004C3900473600
4336004535004432004334004635004130003D2E003B2C003C2A00392600352300332100
301F002F1F00311E00311F003221002E1F002E22003224003022002D1F00261700211400
1C1400180F00120B000F09000C0700060300040100010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3E2E003F31004034004937004B3600513500513A00584300624D00695F006B76045E8C19
4C973C36946731867D2E7C86277493245AA03349A4444AA74F4CA14D4998364A94315091
365B91495D8A4D58854E4F80504C77574B6F4358863D5D9135658E287C7E208E721FA265
1FA75624AC4B2AAE412EAE3C31AC3731A83332A93032A83233A73535A63138A72B38A729
34A72830A92C31AA2C35A92F33A8382CA64626A84E21A95622A95A27AA4729AA4029A741
2CA64730A74431A64432A83233AB2734AC312EA7412DAC3C2DA7372F983E3196402D9F45
27A147289A4929A44828A04F2A8E57307C5D2A796127706A2168741D6A761E6877236478
246D781F727B1C757A23767B2D737B357273357D6A2B8763248E5E2396532C9A4B39974A
3996503098542A95582C985D279F6322A063249E63289D612E9E6530A0682BA26B279F6D
28987025976D239D6423A55A24A85027A9482DA83E32A73938A83839A83A38AA3C31AB3C
31A93E33AA4133A94434A94730A7532DA55A2EA35A2E9F5438A44C40A74144A93A49AA3A
4BAA3A47A93D42AA363FAB2C3BAD2F3CAF393DB0453EB1433FB03E42B03345AB2C44AB2E
45AB3448AA2F49AA3147A43849A33647A63A49A93D47A74045A044449D4644974B438B5C
42826A42816C3E806D3C816B3E756A46676D575F716D5E6E7B62646D675E5C6B5C538247
539D2661A40F6E97077392037392017295007299026FA10468AA0965AE1262B11D5DAF22
5BAC2A5BAB2D5AAA3A52A9424EA54A4FA65045A95F44A55F419A6445975F468F5C45895E
46826447816A45856F428176428C764195713EA56540B15042C04547C0354BB52E4BB42C
46B12F48B33A47B24A40B14F40AA563CA75945A7544BA7555DA7455FA53D5BA03B589B42
628A45668246638B4062903C5F98395E94455C964E5B8E52517E58527463516670686672
8861708F6069955E658477576A963E789C218A960F8E96198E842F9078268D65249B622A
A1622DAA6835A96B3EA0704D956E5A916C58A16A5BA86650A85843A85148A6523EAC5E36
B66B31BA6A3FBC6647AE64409B6C4098743F9C77409E793D8C80487F814F84834C808A54
7C93537E994C809B4884A03E84A63B83A834839F30849A297F9C23809D1883940E828E04
8A8501867C008274007C72007E77007C7B01827D008278007F7C00807A007E7900787100
757000736B006D67006B62006B6100676100625A00665E006C6500736F00717100716F00
706B006F6B006B6600685D006357005F4E005F4B005E4F005B4800574200504000533E00
513E00574100594800554800564A00574A00534700534500504800534800564600564600
5344005045005241005345005647005545005646005546005545004C3D00493B004B3900
4C3C00503F00514100534400534600554300534300523F004F3E004E39004C3A00463500
4533004330003E31004130004231004431004132003F2C003B2A00392C00382600332200
3121002F20002B22002E21002D1E002D20002B1F002F1E002C1D002A1C00281900201700
1C1300160D000F09000C0700080400040100010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3B2B004234004837005041005544005C4B005F4B00635200656000707100718905629C16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3C3300493D005246005D51005F5800625E006862006767006976006F8502719B0961A519
49A73F369C6A2D937F2C92812B7D882956953B429A4B449D4E4E99434F8F37538A345C84
396982446D7F4C66834E5A8642598F34678E27768D257B852181801F8C761F996D22A860
28AE5129AF412CAE3531AC3236A83433A93A32AA4036AA4135A94337A93F35A73F38A63F
37AA3F33A94237AA3C3FAB313EAC2A35AB342CAB432DAA5227AB5F28AF5627AA502EA74B
31A44634A242399F4538A4363AAA2B3BA92D3BA43A3BA83336A83233A037349D3A31A33E
2BA4422BA04528A54027A24428984A298D5027894F2582551C805E1985651E7F6929726B
2E736C2E73712C747826707A286A7D29637E28737C277F7127896B269261299959309B56
2E9D5A27A15D219E5D229E5F219F611F9F62209F60229F6325A06429A26625A56525A366
279C67279B622A9F5229A5482CA74330A84037A73B36A6373BA8373CA73A37A83632A735
33A83B37AA3C35AB4331A84D2FA5582FA65A30A84F33AC4639AB4642AA4644AC4442A94A
3FAA493AAD443AAF4139B04540B03D42B03146AE2A49AE2C4AAA254BA91E4AAA1D4CAB22
49AA264FAA274FAA2E50A7374CA7394CA93B4AA93A4BA73C49A0414A9C4247974B46895C
417D693D786E3A7273397074436A734D60765D5D746C616D7168665C725E4C7A58528D3F
619B1D6C9C076E9404729300739400789200789600799902759F096DAA0C62B01259B016
59B02159AF3357AF3B58B03E54B14553B0504AAC6044976C3B7D75407475456871496671
4D6B714E726D4B726B455C7B446B7E46787948926A45AD5F45C05248C04047B63548C031
47B23147B12E4EB0364DB24046AD4946AD5058A74057A4405B9F3C61A038639D3A659C3E
6F9339738938698E3A659338659438608D435C895558845D5388635A7D675D5E76725874
8D59709161648F63637F804D76A22587A91998A321A2921FB28123A27419AE6A1A9F682B
A7663C9F694C996D529A704A996C439F6B43A76847B06047BC5540B25845A1604FA16047
AE5F3BB36941BD6746A85D489D62479F6E38A0753BA2753D997D428F7D4C858A49838E4A
8D954282A63A82A82B85A51F889C178A98148D930D8C8D03898603868703858702868600
807F00837A008174007D71007E73007A70007973007870007B6800796C00776A00786D00
776D007167006D6000685B00695300675600655800665F006964006D6B006E6D006C7100
6E70006C6E006C65006A6200685F00655A006052005D4B005C49006048005B4900584300
5743005746005B4A005E4D005E5000604B005B49005B4500564800544600544600574400
5342005142004F3C00523E005340005848005A4A005A4A00574600574300513F00513B00
4B3A004E40005242005044005343005441005140004F3F004D3A004D3C004D3900493600
493400423100403200423000433400453600483700453100432F003E2E003A2B00332B00
3024002E1F002B1D002C1F00291B00281C00271D00271A00261C00251A002216001C1300
191000140B000C0700070300010100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
453B00504700584E005F5C00606A00616E00647602637F03648D076B960D68A4145AA928
3CA3512995792686892B7F85306B87304A934342984C469C4B4E933C528A365A8235667F
32747F357C8140748B4568943D63992B76941E848A1E88801D8B7D1C91771D9D6920AA5D
22AE4D26AF3D2FAE2C32AE2A37AC3033AA3734AA3936A83F37A73F38A93F35A73F35AA3F
36AC3F37AC4339AB3C3FAC2F41AC2A3AAD3633AD4030AA4F30A95A31AC5531AA5331A74C
34A54636A044379D4837A13A3AA92E3CA8323EA33B41AA353AAB3036A43733A23A34A83D
2EA8462EA5492AA64427A348299B52269254278E52258D552093571C985E1F9362278766
2D82682E816E2D8075287B7B256E7B25667E24737A24807424866E2491682898622E9B60
2E9F6327A16521A0651FA1611EA15D1DA35C1DA35E1DA36221A36420A36522A46422A260
219E5F28A1562DA24B2EA5402FA63C31A63935A33537A63239A9333BA53336A63230A635
30A93832AA3D30AB3F2DA84A2EA85833A95935AB5138AD463CAB4841AA4842AA4643AA43
3FAA453EAC463BAF463CB14B40B14148B0324AAD2647AB2649AB214BAA184BA9164CA81F
48A92B4FAB2C52AB3251AB384EA9394DA73A4DA9394CA33C48994247954547964B468F5B
417F653E736A3C66703F64754764745261755A5E7365626E686B65597C5E4B8A5855963C
679A187094067095037494007593007991007E95007F96007D9A0272A10768A80A5DAE10
5AB01A55AF2456AF3053AF3452B03E53AD4648A4584194653A82723B7574436A74486273
4E65754F6E724A776E3F78773F86773C9A743DA7623FAF5642B54848B33B4AC03250B333
49B3324FB43250B13B4AB34245B04B44AF5259AD425BA4425DA13963A23965A53569A438
6E9D3670913566923567913A6B9040688A4B5F8953588C59518B64567D65665972765273
8752748C5F688D695D8184407AA31991A719AE8B34A48423B8762AA7721CA86C24986640
A064559B69589D6D53A76B46A9673CA6663EAB5C46B65146CA5143BF5949B76357A85C50
AC5445AF6143B96746A763509961519C7237A0773EA37D499C7C4B8C80518292487D9F42
81A83680A620879D148C900E8C8E0D918A0A8F89058A8501888601858501858601828301
827C00817A008177008076007E71007B7000776B00776E007B6F007B73007B72007D7100
786E007569007264006D61006E5D006B5B006A62006A6900676900706A00707000707100
6F73007072007170007069006C62006C5A006553005F5100615300604C00604700574600
5643005742005848005B49005B4D005F4900604B005D4D00594B00594C005749005B4800
5D48005746005741005741005B48005C4C005E4E005E4E005B4D005A4700584400523F00
523E00513F00544700534500514100534200534000513F004F3D004B3C004C3700463600
4837004432004031003F3200413200443400463B00463700433600442F003D2E00372A00
3323003020002B1B002A1D00271A00241A00261B00251B00231A00221800221500191200
180C00100B000A0500060300020100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4B46005951005F5D006168005F7A0462850965930F68991370A11978A02069A02451A333
329D5B228F80207D8A2A6A823455823D418E4F4491514B9247548A38598132687B32757A
2C7F7D2B808439768C396F92316D94227F8E1F8B841E8F801E957D1A9D6F1FA65A24AC47
2AAE3C2FAF3235AD2A36AD2838AD2C35AE3138AA3238AB3637A93837AC3B35AA3B34AC3A
36AD3C36AD4037AB3B3AAB3338AD2D36AB3635AB3C33A64733A55035AA4A39AB4B3AAB47
3BA64439A443389C4838A2403DA7363EA83642A14043A8373EA93339A53734A53C33A540
30A7492EA34D2AA54A27A55125A15B239663228C64208F641D99621BA0651B9B671F8E6B
228B6E28887629867B25807E21717E22667D23727B237A77228073238A7324956F289B6E
279E7020A3721FA16C1DA4641EA35A1DA4571AA85D1AA9651BA5661DA5651EA6621FA558
20A55528A5492EA43D30A43731A43231A33135A43235A93037A72E35A42F32A7302BA937
2FAA382EAA3B2DAB3F2DA94B2EAA5835AB5B3AAD553CAC4D3CAB4C41A94F46A94646AD41
41AD433EAD483EB1473FB34843B04048AF3749AC3145AD2B48AC2349AC184BAA1649AB1D
4AAB274EAA274FAC2D4EAB344CA8384CA83949A93B48A04146964446954844964D448D5D
4180673F716B3E5E6F405C74485E765161765761745D636C5D6E6550865A47995257A035
6A9B147198057696027795007D94007E94008296008095007C9B0173A0026BA2095EAA0F
5EAB0F5CAD145CAE1E58B22756B03052AF3843AB4A3FA2573B90693A7F703F6F71456176
4E62764F647543757439807C35947B33A97238AF663CAF5640B24948B33D4DB53652B534
4AB2354CB43C4BB24046B24941B1543EB46353B04758AA415EA63762A83664AB2E65A933
69A4366B9E3A639638628C3C6A8C446D83516584535F8B5956866360766375586E7C526D
854F6B85616283715B83893981A31B8F971AA08528A37E20A1781D9E7227A36A2DA26F42
9A784E937A548D7751936C4C976C4C9C6750B05D4DBB5744C95336C1563ABB634CAB5C4E
AE5243AF5F42BA6744A66A459B64479C6B439F7946A2864A9B83518C82537F954481A334
83A522819811858604897F008D82008E8200908300898100867F00878000857D00838001
817B008276007F79007E76007D73007A6E00796A007D68007B6F007E7500827500827600
7E7300796E00747000767000726A006E65007064006A6C006B70006F7400727A00717400
6F7000757800727500726D006F66006D6000655F00695B006756006350006250005F5000
5F4E005A48005A4700584C005C4B005D50006151006151005D4E005A4E005D4F005B4D00
5E4C005D4E005C4B005B48005C4C005F4D00604E00614D00614D005D4A00594400564200
544300554300574400564300574600544600544300544200513F00503D004E3C00483B00
4936004633004533004335004330004131004434004434004433003F31003D2E00392C00
3524002F23002B1D00281C002419002017001F15002014001E11001E13001C1200190D00
140B000F0800080400040200010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
524F005C5F00626D01637F07609512619B216A992C6D94337593347097305B9E2C3DA040
299864208C80217A872E697F3751803E41874848894455893B65832C747B2B8570258B6D
1E8876247F832B778E29759123758D1E83851E8E841E93881D9C7E1BA46321AE4D29AF38
2FAE3136AC2B39AD273CAF253CAD2B38AE3038AD313AAE3239AD333CAC3440AC363CAB38
39AB3A36AC3B37A93837A93433AB322FAB3531AA3833A64138A44A3AA8453DAA453CAA40
3CA63E3AA43E3A9C483BA23D3CA6353FA93844A24043A8373DA8353DA23939A33837A73C
38A64337A44530A7432BA94D25A55621A16325996823986C20A06A1EA46A1E9D6C20906C
248C6C2B8770308772298370247D6F26766F257C6E26807023836F228D70249473269873
229D711CA3701BA66B1AA7601DA6541FA5551BA75E19A7641BA7641DA7631FA85B22A750
25A74929A73F2FA5342FA42F2FA72C2FA72E31A82F2FA9302FA93133A5302DAA322BAC39
2DAB3C2FAD3E2FAB402FA84A2EA95533AA5E3AAB5F39AA5838A7563EA55543A84741AC45
3DAE4B3BAE513AAE4D40B04B43B04247AF3848AD3447AF2E48AE214AAD184DAC174CAC1D
48AB2649AA264AAB2A49A92E4AA63447A83844A33D489D42479B46479B49469C4D438F5D
41826942776C42696E4262724960754C62735163735C646C5E70694F895A489D4C57A42E
6B9C10729B04779A017999007C97007E96007E97007B98007A9C0070A1026CA5095CAC13
5EAA1160AC0F5DAD1359B02054AF2A4FB03442AF413CAE4437A84E389E5C3B8D64428370
487D6F4677704181763C897B39987530A97135B0643CB05744B14D4DB33D50B13556B334
50B2344DB43947B04244B34D41B2613FB27054B04C5EA93E5FA5385FA83A67AA3461A638
62A03B659A44609340608C4362904C658252687754667F575C7F5D69735D855C648A5766
8854617E6659727458788C3D8791358D8923AA7F30A27525AC6D2AAC683DB36B36AA7843
967E558C78578A7057926754956451996552A86443B46135B95A29B45D2DBD6242B15D4E
B25049B05B43B76140A76841A2683B9C684E9A7855A48553A084558B8C5085A3318E9E1D
8F900F8A88058A7D018B7F008F82009185008E8300898100867F00897E00867D00837A00
807A008476008075007D73007B7100786D007A67007A65007C6B007D7100817300837400
8274008077007A75007B7900797400756D007167006F6C006A7100717700767A00767300
7672007577007477007071006D6D006E66006E63006E63006D6000645700675700645600
644F005E4E005C46005C4A005F4D00614F00625200665100645200615200614E005F4F00
5F50005E52005E50005E4C005D4D005F4C00624D00614F006350005F4B00574400554300
5744005645005545005543005846005747005548005647005645005544005340004F3E00
4A39004A37004B36004735004433004231004231003F32003E2F003E2F003B2C00392700
3425002F21002C1D00281B002419002015001C12001B11001B1000191000190F00130C00
1008000A0600050200010100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
556608577B0F598F1A5C9825619F3263913C6F884174853C748D3A6B992C51A62E33A34D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5A891A619225678E2E6C89337682407D78467E704280723A768637659E3041A53E2AA15B
209872208E7725827B2E6F7732597B2E4C7E34527E2C6180247781239175209C691C936C
197F771A76841775931A818D1A8B84189A781CA16E23A56029A95230AC4138AF2F3FAF26
44AE2245B22349AD2748AE2C41AE313BAF343BB0323CB1333FAD3442AC3742AE3E3AAB48
33AA502EA85131A74D30A74731A64132A53C35A73E39A8413BAA463BAC3F3DAD383BAC35
3AAA373EA8383EA73F40A83A42A93243AB3348A73C4AAC3348A93244A83843A63D3FAB3A
39AD3936AB3834AB382BAA4326AC4E25AD5125AA5922A56220A9651FAC6720AA691EA76B
21A26F259971268F752386751F84771F82741C87751D8A731E8B741F8B7A1E8C801D8F7F
1A967A19A2721AA7671AA75F1CA8561DA8591DA7651EA96520A95F21A65923A64C24A842
26AA3C29A8362DA73431A7312FAA3231A9362CAA352AAA3329A7332CA6342BAD382BAF40
2DAD452FAC4630AA4131A2422EA14A34A3583BA55E3CA75A38A75A3BA7543DAE4C3CAE4F
3BAD5A40AC5340AD4340AF3549B02F54B12454AF1F53AF1D53AD1853AB1153AD1455AC19
51AB1F4BAB2547A82845A82D4AA72F48A53543A13747A43B4AAA3F4BA845459E53418B64
417F6F437F6D46766E466D6C456B7045676D4D696A5A6A6864736656935551AB3C5DAB21
68A4106BA8096DA80970A70976A50979A1097A9D087A9D037D9D017BA30172A70960AB14
5DAC1A59AE2455AD2451AF1F4DAF214EB1274CB3334BB53447B83543BC393FBB5239C05D
39B05937A56234A16B31A0713BA36C3AAA6C3BAC6444B15A48B6524DB4394AB12E54AF28
52B2274EB53543B04B41AE5543AB5B48AC6259A7495B95445D9D405EA14961A2485EA350
5D984E60844C5E864A5C9350609A46648B476981536684595B7D657374629A63619A5F63
905C63796A6060845D728E3D92893392793DB26B38BB5E3AAB62398F614E8166577B6D57
836D5C8D6E5E9E6B63A96A5CA8624C966348856A57897363A271649F6949B75D34BB5549
B24B61A85D57AC6354936B4C9B6A49A16F4E9D79599B8354899F2D8D9D1993900E928704
9086009383008E84008D8100897A00867900877700847700867B00888100847F00847C00
847C008379007F6F007E6D007C6A007C68007A67007C6B007E67007D6B00806D007F6F00
7F7200847500807900807A007D73007E6F00756C00736C00746F00727400757700777D00
777800797900767700707200716F007066007163007161006F61006B5D006D5900655700
5F5100614D00644D00635000634F006553006856006A5800685900655800605100615000
5E5100604E006250005F4B005C4A005D4E00624F006252006350005D4A00594500564100
5844005746005946005A45005A4600594700594500564900564400554300554500554100
4F3D004B39004735004833004733004B3500493800473400412F003F2F003E2B00382A00
3627003223002C1F002619002216002016001E15001D12001A1300150D001109000B0600
060200030100010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
678E41737C456F72446E7548746C547E644E82693D8672337C892A609C2D3AA14A299E6B
249B7925957B27857D2A75792C66782B5C7E2C5F81286586256D84237F781F8D721C8D72
187B7B167086146D931A838F1D96821BA47620AA5F2BAB4537AE383FAE3241AF2E48AD25
49B0214AB3204DAF254EAD2A48AC2F43AD3142AC3444AC3145AB3246AC3741AB443BAA56
33A7622DA66330A75D34A75534A54B37A2463EA54541A84540AB453BAC3B3CAB3537AB36
3AAA3940AA3A43A83E41AA3845AC2F47AC304AAC394CAE2F4BAA2E4AA63645A63C42A937
3EAD3A39AC3636AA3732AB3E2DAA412FAC402CAB4728A85028AB5524AB5924AD5A24AC5D
24A96527A16727976B248E71228A71218870218F6B21926B23936B23906E239171209174
20996E21A26520A95C21AA5522AB5226A95427A95A2AA85D28A65727A55528A74A29A842
28AA3D29A93B2EA83B30A63631A93730A93B30AB392DAB342CA8342EAA352DAF3B2EB142
2BAE4B2DAD472EAA412DA3452DA44C31A55738A45B38A95738A95639AB5638B04F39AF52
3BAF5A3EAB4F40AD3942AF264AB02353B11D53AD1754AC1A54AD1954AC1A53AB1C54AC1E
52AB214DAB244BA92848AB2C49AB2C47AC3047AB3346AC3746AE4048B04C419E5C3D856D
3E7C70427A7046756F44736B437269436B68486C68546F665B776257974657AE2A5DAF1F
5FAD175CB01662B01762B11467AE1566A9156DA91171A60A71A30374A60270A80669AA0F
61AC125DAD1955AA1C52AD2150AE2253B02051B0224FB3274DB32F4CB73245BD3A3FC047
39B34D34A05E309D64329765399D5F41A85844AB5546AF504CB44C4CBD344CB82354B421
4FB5234CB53248AF4646A9504BA4534CA3525BA2445A8D485E98465BA04D5F9D4D579D53
5C99525E844D5C824E58924E62984268904361914A5A9058527D6F74716DA0656F9D5F6E
955A6F7A70686196587C95399B8527A27631B06733A8643A94624D826A59757658777254
8869559D6056A26058A86054AD5B4CA15B4A936456916665946365956355AF6047B75755
AD4E64A55F58AA66489B6D409E6D40A1724A9A7F4F8D953B8A9E1E8D8E0C908202948200
8F83009181008D83008B8100887B00877700857B008878008C7D008B7C00897E00877B00
817D00807900817600816E007D68007C6800806800816A00816D00826A00816E00826F00
8470007E71007E75007A6E007A69007869007A6800756600706B006D69006E6F00737300
767200777500767500757500747000716C007063007362006E60006D5D006B5E00685800
6454006353006253006856006955006B5800695A00685900685700665700645300635100
635000614D00614F005D5100604D00624E005E5300635300655400614F005F48005C4700
5C46005C49005E4700604A005F4B005B4C005D4B00594A00594600524100534000544200
503D004E3C004D38004A37004A3600483800473700483500453200412E003F2D00382800
3325003324002D2000261A002118001D13001C0F00181000160F001209000B0700060200
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
757E467B72407E713A776940795D468259428866388C7533788C2C559D363AA1552DA071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875D4189604182653F70634C6C5D5678594D7A6F3D7C812D66952E46A04235A2602FA27E
2DA4832D9F802F8D792F83702C7E73287B7C257389236A90235D8B20767A1E8C7218937D
178586177A881776891B8983219A7824A46D2AAA5532B03C37B23537B2383BB03C40B235
48B1294AB01F4CB02149AF2348AE2A48AE3647AA3748AB3347AB3045AB3643AA453EAB51
36AA5732AA5034AA4739A6443BA7443FA54744A54643A74640A94740AB3C40AC3741AA3D
3FA94042AA4043A94143A84142A74041A73E43A74249A93648AA3948A9454AA9444CAB3D
46AE3942AE3240AC2F3DA63836A63D32AB3F2FAD3E2EAB432AAC4729AD4D29AD5028AE4E
26AE4A28AC4D26AB5126A95826A55F23A16421A36922A46B24A66623A466269D66249966
249563249F5B25A55324A85125AC5227AC5227A9522AA8542BA9522DA8522CAA4C2EAB47
2DAB442FAA4431AA4133A94032A93F31A93C2EAD3C2AAE3C29AF3F2AAC432BAF472AAB4D
2AA64A2AA94A2AA84C2CA6512EA55530A75B35A75D36A95533AB5137B15139B25238AF54
38AB583EAB4B41B13341B02242B12543AF1F45AF1E43AF2445AF2944AC2E45AD3048AD2E
49AE2E4CAF324AAF304AB02C48AF2A4DB13049B03A44B1453CAF563CAC65369970368378
337B76387F76407D713E7E693C7C68416C6B44716B4A7B664B8859579F375EAF1C59AF21
57B12055B41D56B21F57B22257B12458B22B59B22E5AB02E5FB22E66B12069B01C66AE0D
66AC0467A90560AA0D5CAD1C5CAB235BAD1C51B0185CAE1960AF1A60B01A55B11A4AB423
47B43341AF4843AA4F45A65649A65745A75249A64E49AE494CB3424FBB2E4DBB2251BB21
51B1284FB23150B23B51AF4150A1474E964D5C9650667B615F975559A15356A04B52A14A
58A5435B9E3E5E9B425B93505B8F56598A595A835B5776655E5976765D7A935D78955C72
8A5A67787A596F9C408C912AA97922A26E2BA06E36956942846C5977716377735C7A735B
906960A6615BA95D57AE564DB2534FB3564BAD5646AB5747A4554FA15455A75C5CA85B5B
AF5C5CAE694EAF704CAB7A45A57C4598804790962F8590108882058A7D00877900877A00
8A7E00887C00897D00897C008B7B008D7A008A7D008E7C008F7F008A7C008B7E00897F00
8979008A78008B7C00857500847000837300847100867100897200867500857500877500
8575008071007B6800746000715E00736000796C007D6E00766900736500706B006F7100
717400767400747100737200767100776F00756A00756D00786B00786B00766E00746D00
7467007063006B58006A55006F55006B5600665300675200645400675200695700695800
685900645600645100615000615600605300615200645700665900655600655500604E00
5E45005948005A4A005C4E005F51005C4F005D4C005A4C00574A00554400544200504400
514300513D004E40004C4100473F004935004435004332004233003F32003F3000392900
2F23002E1F00271C00231A001F15001A1000110B001009000D0600090300040200010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
8A563E87564077583C6D583C735B427D653C7C762E708D2B5597383B9D5531A06F2EA07F
2FA57F2FA376319C683097662B936E288C7B277F82227587246D80288C6A289D691B9E7F
189288158586167F811A8A7E2299752A9F6E2EA85831AD3F37B0353BB1363CB13945AF36
4BAD2C4EAA214BAC214AAE2748AD3147AC3F49AB374AAA2F4CAA2C46A83340A73F3EA945
3AA84A3AAB443BA9403FA7403CA94241A64A42A74942A74942A94A42A93F45AA3744AB3F
43A94442A73E41A73F40A54441A54342A74643A44745A94045AB3E49AB434EAC434DAD38
4AAC3146AC2E44A7323DA43836A34332A8472FAC462CAB4728AC4728AD4E29AD5129AE4A
28B04728B0462AAE4829AF5029AC5427AA5A27A76228A76A29A66729A4692A9E69289766
299164289B5D29A15A29A45A27A85A27A85B2AA6592BA8552BA9532BA8522BAA4B2BA948
2DA9442FA74133A84234A84233A74033AA3F2FAD402AAF4229AE492AAC522AAC512CA457
2BA2562AA55528A4572DA2602FA16231A66635A56437A65937AC5533B05636B15737AE58
35AE563BAE483DAE363DAF293BAF2A3EB1273FB02C3BB13137B2353AAE3840AD3745AD37
44AC3745AD3C45AF3848AE2F47B02D48B23843B0443FAE5136A95C34A16A339571338875
328772388A763B89723D876B3C826840746B44776B45856449935458A3385FAB2357AC2A
55AE2D54B12859B02759AF2C59B02D55B03652B03D53AF4053B14058B33959B02B61AE18
68AD096DAD046EA9066CA90C69A81167A81062AD106AAD116EAE106AAD0F65B01159B114
56B32353B03751B03F51AA4F51A9564EA15D4DA15752AD4F4DB74650C0374FB72D54B627
51B22553B12C57B23256B03C54A73E4F9F4956A24E579456599F5053A55250A34B509C4B
549F4257A241539A43578E5358825F5783625C7C6760696F68527A775A79925E7890626F
8C5E687C7C557A9A3A908D30A47737B36047AB5D41A1554686645C76705E76755E7C7F5C
92745FA46F5FAD6852B85F44B75E4BB65A4AB75A3EBD563EC65348BC5551A7575CA65D58
AF6657AC6F53AC7555AA7D51A0834F838E478C9222898106867C01887700857900897E00
8A7D00887D008678008A77008B76008F76008E7A008D7C008C7B008D77008C78008A7900
8B77008A78008C79008773008670008974008672008275008875008974008A7400877500
8678008375007E6A007662007462007361007C6B007B69007A6D00746C00756D00717000
717300757A007778007879007777007775007773007B73007E77007B7800797600797500
746E007466006F5D006C5B006C5A006956006A5600665200664E006752006A5500675600
675A00635A00635600645500625400635300655600675900645D00645900685700625000
5D49005A4800584C005D4D005D4C00594C005A48005B4700574C00564300544500534600
5047005043005243005144004F41004A3C004737004331004030004131003D2D00372C00
3225002D1E002519002115001A1200160F000F09000D0700080300050100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7E4A557E4555764D46715344715F4F796B447B7C30668F354D94443499632D9D772CA081
2DA57E2CA7712CA9642CA65F26A3682A977528887E257F7A287C702D9D5A2EA45F1FA47C
199D8514918015887C188B7F239A722BA16C2DA85631AD4138AE3938B0363DB03246AE30
4BAC284FA8214EA7234FA82A50A7344EA53953A73157A72A55A7264FA72E45A63841A83E
41A94440A94040AA4043A63D41A34441A44A44A54645A64446A64148A7394DA7374AA63B
44A84245A93F3FA9403DA7463FA64841A54843A44A45A74249AC404BAC434BAC3F4DAD35
4FAD2E4EAB2B4BA531429F3A3B9D4535AA4733AC4732AF432CAF442CAE482EAE472FAF41
2EB13F2FB13E32B03E34B24136B14632AE4A33AB5331AC5630A75C2EA4602FA0632E995F
2B945E29975D279960279962299D6229A3602AA4602CA55B29A65628A75227A94929A844
29A84031A73E34A73E34A94137A84033AB432FAE472CB0492BAF4828AF502AA95429A45A
2A9F5928A2592BA15A309D5F2F9E6030A26133A56035A65D35A95A33AE5934AF5930AE56
2FAF5233B14538B23A37B23036B43434B43138B43433B43B32B24135AF423BAE4040AE42
41AE4242A94943AC4245AE3747B13746B04144AE4E3AA85C359E6034936B339071348A72
328F75348F76378C793E89713E8369417B6B427F68438D61459E5357A7345FA9225AAD25
56AF275AB2245DB12558AE2B58AD2C55AE2F52AF3252AF3651B33955B33755AE335BAE2A
60B02266B2156FAE0F70AB0B6CA8066AA70964A90F66AC0D67AC0D68AE0968B20863B00A
67B2145CAF255FB2325DAF4554A6554A9B614C9C5F4BA95149AF474EB1404BB23556B32E
54B12D5BB3275DB2285BB13157AF3B51AB4352AA4354A6465CA44854A351519E4E4F914E
4E914D53994E529550538458517863507C6C55767567657C7C537F7F5A788E5F768E616D
8B61697C7D527299338A9027A27A32A2653F9A62488E63587A785B7388577988527B8C51
8E83549E735AA5694DAE603EAD5B3CA25A3F9A5E3BA35E36B35536BB573DAC5B47AB674A
B26A4AAE714DA77651A47E4F9B814B7F9533878A168677028471008975008B77008C7800
8D79008A7B008D7D00907C00917D008D79008B7A00897C00867700877100867600877300
897300887500867300867000877000886D00846F00847300857A008C78008B7D00887A00
897E00887A008274007F6E007A69007668007466007867007D6C00756F00746C006D7100
6F7500737800767C00777E00767B00777D007778007A76007B77007C76007B7800797300
766D007369007364006F60006D5D006C5A006B5A006C5A00695700675500685500675A00
655900655B00685E00695C00685D00695B006A62006760016661006A5F00655E00625600
5C4F005C4B005A4B005B4E00604A005E4A005B4900574400574600564800564400544600
5046005142005044005246005245004E42004B3B004134003F32003C2E003B2D003A2800
322400281D002517001B1400181000120A000A0600080300040100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7C5052794E4A75533F6F5C386A653E6A6F4068803D588A44498E5A3594762F977C2E9D7F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8255497E57476E5E4069693D5F6B4A576F545B794E4F8155478464378A74339077319872
2EA06726A95527AF4B29AF412EA74A29A05E259C671E9C621F9F5621A64E25A75924A870
1FA76C1CA36A199D6E1D9F7523A16A2AA1612FA84F3AAC403CAC3F42AA3A48A8304EA72A
52A5294DA32949A32C54A23055A32F54A42C54A42A58A52757A52652A62A49A93346A53A
43A83C40A93C43A94149A347509C514C9D534BA34748A73549A82D4BA72E4BA83447A940
45A84943A64C40A44D41A44F44A44944A74544AB424FAB3B4EAD3B4DB03D4EAF3B4DAF3E
4CAA3F4BA9394BA438479F3A419E4039A54035A94034AC3F34AC3C34AA3E36AA3935AD3A
32AD3C31AC3A31AC3B33AE3E35AC4435AA4B34AA4F32AC5832AC5F30A66A2D9B6F2B8C6E
28836F2A806D287F71267974248374249172259D7525A26F24A56623A95C23AA5025A944
26A8402CA83C2DAB3B2EAB3F32AA4330AD4A2FB04F30B0492FAE4330AA472FA64E30A155
30A0552D9D592E9A5D32955C2E975A299E5A2CA55B2DA65E2FA85E2DAB5D2DAE5B2BB057
2DB05431B25034B24934B64536B34536B33F36B33C37B23C36B04335AE4638AE4A3EAE51
3FAC573FA75840A7553EA7533DA7543CAA553BAF5E37AC6033AB6031A95D2FA3632F9C69
309871329476338D7C378A7A3C87733E806F3C88633E9B5B47AB4958AA2B62A91E60AD24
61AE225AAF255CB02458B22955B22B50B72B4FB22F4DB1304FB93152BA3752B33A54B340
4EB24A57B1425BAE3562AF2465AE146AAC096DAB076EA70371A70372A60277A80178AA01
78AA0677AC0971AF1567AD2560A93A56A55450A06254A25855A05157AA4B57B14260B03C
60C03865C02260B31B60B3215DB33155B13B55B03555AF3856A2445692535390554F8F59
569056569654519751508C5B4D7E634E7E6C5175755D697B7A578082537B8F5175825972
765E79727956788E308F85309C763E9A684F7F7956748B567495486E99416A904A6D8E58
79825C8D6B679B6453AF5348B34D42AE4E409A6048966046A76133B95A3AB65149B15E4E
B8684FB07249A2784D8F8D418A9138858E138580048579008779008A7A008A7F008E7C00
907E009180008B82008E7F008F8100917D008F7A008D79008976008B76008A74008B7800
857B008776008977008A78009081008A7B00847500827000806C00857000877400867500
8272007E70007D6D00786C00796C00766900756B00766D00746C00726B00746C00737300
6E75006D78006D7F00738000777F00797E00797A007675007770007872007977007A7500
7A74007C7100797000776F00746A00726600726B00756D007769007363006D6100696200
655F00685D006A61006A64006C69006E70016776066375086176096575066C70026B6D01
6B6600665F006257006159006155005D52005A4F00584D00594A00594B005B4800594700
5447005444005246005346005145004D41004B40004536004030003A2C003A2700332800
2E2200261A001F1100140C000D0900080300030200010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7E5D517562486B69456370485F6F4F606E515D754C53795C44796A3A7F72368875309466
29A25523AA4523AF3B2BAC3534A83F2DA25723A1611EA45C1DA6551CAA501EA85A23A56D
20A4671DA56922A06C22A26A26A45D2EA54E37A73F3BA93840A63B46A8364CA92C53A82A
53A42C4EA22A4FA22C52A32F55A62D53A62D53A42F57A52D57A32A55A62B4CA63244A73B
3EAB3C3EA93A45A83C4EA6474FA2474CA54645AA3C40AB323FAA2F44A83444A93842AB43
40AB4B3FA8503FA75044A35046A74746AA3F48AD3B4FAB3A52AF3A4FB33C4DB23C49B13F
46AD4646AE4449A73A4A9E38479F3B43A5403CA93F3AAB3B35AC3737AA3A36AB3A34AD3B
33AD3B32AC3B32AE3B34AB3E37AA4237A94434AB4835AB4B33AC5232AB5D32A4622E9961
2D91612D935F2D94632A9167289567249C6526A16624A46523A66025A65725A84F26AA47
28A7422AAA3B2CAD3930AB3A32AB3D32AE3E32B14431B04430AD4432AB4931A550329D57
329E59329E59309A5B32955A2F955A2B9959299E5B2EA15E30A75E2DA95E2DAC5C2FB05A
31AE5731AF5532AF4F33AF4F36B24B39B34838B44738B44535B24834B1463AB04A3FAF55
3FA95C3BA3603BA05E3CA25E38A45F35A76231AC6130AB6433AD6331AA6330A463329C6C
33977035947534907A358A783A88773B84723B8A683B9F5642AD425FAC2864AA1D61AC1D
61AD1C5CAF1F5BB22258B42556B42853B22950B22A4BB82B4DB82D4BB7304EB1364CB343
4BB15654AF5458AE505FAE3963B01E6AB0146EAC0B6EA70470A40179A0007CA2007DA301
7DA40277A50678A80D6FAE1C63AE2A5BAC4B54A85B57A357599D5B57A75155B04B5DB044
5AB1425EB22C5DB11D5CB2225BB32D5AB33C57AF3C52AB41539D4E53865650845F4D8765
508D614C935C4C955E4B8F684A866F4B7C6D4D6A7359677B6F57837D527D8F4A6F81576E
685D796B7755808035A27548A56F54A069637D8564698B616A8E5B6E865A6B7D5E677868
76726A8D646AA55F54BE563BCB513BD05238B54F41A95144AB6142B26149B75655B26158
B46C53B0784BA47E4C869A3D7C9B25838B0B888201897F008D7C008F7D008D7A008C7A00
917F009281008E7E008C7C008E7C008C7D008A7B008C78008979008776008B79008B7600
8A7600887500867400887B008C8000887D008278008073007D6800826C00887000847000
7F6C00806E007E6E017A6E02797003777703767801797C017B7C01767300766E00726D00
727400717C017280017881017B84007A8100787C00747900767300766D007671007B7400
7973007D7600787400766F00746A00726C00756D00756C007469007268006E61006B5F00
6660006A60006867006E67006F71006D780467810D60830F5C83145D7E10607B08687703
666E01686500626100625C00625A005F54005F51005E4F005B4C005A4A005A4800574700
5244005245004F44004E44004F41004C4200483C00423400402F003B2A003424002E2200
2C1E00251A00181000120B000C0800070400030000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7368596D665E6B65636A686368695E6C6556626E555970614772704075743C8077309369
29A25322AB4328B0392EAF3633AB3E2EA55229A35924A35A1EA45A1AAA591DAB601CA56E
1BA56B1DA56D23A36C27A9612CAA4C31A94037AA353DA73241A63545A8324DA8314EA732
50A3324FA030539E3357A13358A63158A72F56A33257A13553A1344EA53646A7393EA840
3AA73D3EAA3847A83D4DA7434AA54345A84141AC3B3CAC353BA8333DA63D40A74040AB45
3DAB483FAA4B42A94547A74649A93F4CAC364DAE324FAB3350B0354DB3394EB23D4AB03F
47AC4249AC4049A63E49A43C48A43947A83943AB3A3EAD3739AD3635AC3A36AD3B36AE40
33AB4433AB4034AB4035AA3F39A94039A94037A74337A84636AB4D33AB5532A95D2FA361
2D9E5F2EA25D2CA3622CA2642BA35E2CA25E29A16029A36128A45B27A65528A85028A94D
29A9492BAD402CAF392FAF3B31AD3931B03A33B33E32B14231AD4831AA5032A356309A5B
309D5E2E9D5D2F9A602E935D2E8F5D2C905B2B975C309D5E2FA05E2EA45E2FAA5B2EAB5A
2EA95930AC5732AC5133AC5034AD4F35AD4F37B04D37B24735B44637B4433AB4443DB44F
3BB05838AB5D37AA5D37A95E36A95C33A95830AE572FAF5A32AD6230A76031A362329F63
369C69389971379674388F76398975368575348D653C9F4A4AAD3461AC2067A91C67AF1C
6AAF1D67AF1F66B02160B5225BB82657B52257B72353B22452B8274FB92B4AB1364BB344
45B2584FB15959AE575CAF435FB22A66B41B6AB0126CAB0876A702799F00809E007F9D00
819D027A9C0579A2086CAC126AB0215FAF395AAD4A59A64F59A35A58A85356AF4E59B147
58B1405CB52B5AB41F57B41F5AB13056B03B55AE3F4DA54D5296524C815C4C80664A826E
4B8D67479B5E4BA05C4C9B644B936F4C866F4D70785C667973587F8154778D4E7282576F
685F766B76558682399C76409573528B71617E7F5C737E5E73865E75865872845E6A7E69
7A7470956171A0645BB25735BC5A30C65A2FBB5B31B15A38AB6944AC6D4BAC654BAE674B
B57047AB81459D824A839F2E829515848606897D008F7F008E84009186008D80008F7D00
907D00948200908000917F008F7D008D7F00897800877A00877800847600857600867200
867000816E00816C00817400847A00877D00877A00857500836D00846A00876E00847300
846F01837A027D7A0675820A79880E798D0F798E0A7C8F09788E08778703767E03777701
7379006D7D026E8405728403768400768300747E00767700767100776C00776D00787100
7D78007C7400767100766E00746A00746D00746F00756D00746A00736A00726600706700
6C68006A6A006D6A006D6F006D7801697F0B638B185B921A57911C5B8E175D8A0F67820C
697C06686F03676902666601666100645C006356006050005B4D005D4B00574800564400
5041005143004D41004F41004C40004A3D00473A004434003B2F003827003421002B1D00
271800201300180D00100700090300030100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6A63807259876D537F7156736E5B64745F556868555B70604A736F417578388378319769
2AA85326AF472AB13E2EAE3D32AC4630A94D2EA5522AA55423A75B1CAC5C16AA5F18A56A
1BA46B24A46C2AA46630A95036AB393CAC2F3FAB2B40A72C48A42E4EA42D51A82D52A52C
57A6305BA42B5CA42C60A52B63A42962A32B5CA33058A3334FA33C4CA33D44A53E3BA73C
3AA83844A6324BA6374AA63B49A63A46A83644AB333BAA373AA73B3EA64643A74440AA44
43AB4440AC4143AA3E48AA404BAC384BAD314BAF2D49AE2D48AF334AAA3A48AB4345AB44
44AB4048A7404AA63F47A63C47A93843A93543AA333DAC3337AD3137AD3739AC3C38AA43
34A84534A94435AB4534AA4739A7443AA6413AA34138A34434A64B30A8562FA85F2CA666
2DA3662DA6682EA56E2DA76A2FA56131A35C33A25B30A55E2EA55C2CA55B2EA5562CA754
2DAA4D32AB4232AB3D31AC3B34AC3B33AE3B32B04130AE4A30A95232A8572F9E5F309560
3099602F9D5E329761328C612F875F2E865C2E8E5C2F94612F99612D9E5C33A25E32A15E
2F9C5E31A05932A35731A75630A6592FA45A32A75435B04C37B34936B5423AB6423BB44A
39B45532B15D30B05E33AD5F33AD5D30AA5B30AC5630AC5831AB6231A86131A65E34A160
35A067379E6A3A9B6E39916F358B7231897133935A3FA33E53AE2364AB1967AC1668B018
67B11869B01B67B01C61B61A60B51E5CBA1F5DBD1D55BD1F54B81F50B6264CB72B44B23C
43AF4B49AF5551AD5A5EAE4762B33A63B22F69B01D71AC0F79A80980A100809D01809B03
7E9B02809D037CA70872AE0E69B01C5FB12C58AF3C59AA4D54A66153A85850AC5953AE48
51B23B56B62954B32154B42157B12D53B13E4FAA4B4D9B594B8D5A48805B497D634A7D6A
4C8C62469F5548A5554C9E604B946D4A8B744C747E60637A79537988537A8F577B7F5975
635B766B705387812A946B3A846B598E6669826C637E66607B765C778956728D5C6F8663
827571A96375A86063AB5936B45E2ABC6124BF601FBB6324A7673DA2654AA16A3CA46A37
AB71359F8338908942889F1D879108878502867E008E7B008B80008E87008E80008B7400
8D7800917900907F008E81008E7F008E7D008C7800877800877700887500857800857100
856D00836D00827200827800817900877E008C7E008A7A008B75008974008C7900887F03
8582057F8C0878940C78990E789A13759B15769C1176990C71960A759505759504758C03
718A056C85066982066F8503738001738000757C007778007A7400787000776F00787200
7A77007977007875007571007672007573007771007772007571006E70006D70016D6E01
696F016972006973006A7600657D035D8A165A9726579B2E599F2C589D275898225B9418
6389125F810C607608626E056265016560006159005F4F00594900564500514500514100
5041004D40004B3D004B3E00493C004739004436004030003929003424002F1E00261800
1F1300191000140C000E0800090300040100010000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
694B6A63416A66406567425E6D495B7F5B516C6A4D5D735A4D756F46767F37877A309E67
2BAA5427B04A2AAF442FAC4530AE4934AA4831A9452CA64B23A7521CAC581AA8611AA069
20A06825A2682EA55E35A8463BAA343FA82D40A82847A7244EA42658A5245AA62258A726
5AA5265CA5285BA62959A72A5FA62A62A3285BA32754A5274EA82D4BA93147A72C41A62E
3EA83245A73545A53D47A43E44A63843A93343AB313EAA393CA8403AA5483EA8473FA843
42AB4147AA4046AB3F49AC3C48AC3545AC3244AD3245AD3343AC3743A94241A84E41A64B
43A84349AA3F4CA93F48A83B44A83B43A83842A83840AA383BAB353BA93A3EA8403FA541
3EA44338A44437A94A37AB4E3AA7483AA444389C44399E4635A34C32A75230A9552FA753
2DA5552FA55830A65D30A55B32A35237A04D3CA04C38A74E35A85234A75634A95236A94D
35AB4836AB4035AC4033AC4034AE4233AE4430AE4D31A85234A85A33A760319F66319764
329C60329E5F349760358B6133836033835E328E5D33946131966432985E33995E33985D
2D9660319A5F2FA05A30A45C2FA15A2D9E5A32A55731AC4F35B54A34B44337B34136B347
35B64F30B55931B25D30B15D31AD6030AA5E33A95D32A95E33AA6135A56037A45C3AA25C
37A16439A06A3B9B713B8E72348C703088703894554BA72F60AC1565AC1368AF1665B317
67B01865B01C64B11B5DB3195DB31B63B41D61B31C59BD1C55B81D53B6224EB7264AB12F
45AF4049AE4F4AAB5E52AC4F59B2485CB13F62B32C6CAE197CA90C829D00809B037D9B07
799B047B9D0277A4066EAC0867AD185AAE2A56AE3652AC4C50A7674EA65F4FA0624DAF4D
52B23A57B52F53B42452B62252B02E4CB0414DA455498F64468363467965477C6747836A
448F64459D57499C584E93634D8A724C847B4E717F5E617B7D5577855477895A7C7D5F77
6361736A745283883389764286745389756088735B8F6B57807A557A8850788456737A5F
837162A86060AE5B54AE5640B05D3AB4612EB96522BA6421B4623BB2654DA6703FA57639
A7793E9A874188993E8CA1188B8F018B8400887D008778008B7A008E7C00887700857200
8973008C74008C76008C7A008D77008C78008E74008A75008B79008A7D008C79008E7700
8C7700877500827800847B00857900897E008C7E008A7C00897B00867C01898604848A0D
808D0F7D990F7B9D1276A21579A61774A61A74A217719F11749E0A729A017597016F9A05
6B9E0B69920C6486076784056486056B82017182007684007A7D007C7A007977007A7700
7678007A7D00797900777500767600767800767B007779017477016F75016E74026C7804
7078036F7D036F80036C860661900E5D991D59A12C59A32F5CA5305EA42B5CA22B5A9D24
629518648D1362821064790C646E06636A02625E006053005A48005545004F42004C4000
4E3F004C3D004B3A00483B00473B00473A004334003F2E003526002F2000271A00221500
1B0E00170C00130A001107000A0400040300030100010100010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6F2E6663295B682A58732E52853A578C554C6F67485D6F5C5270724B70803C837B319E66
2EAB502CAF432FAC3E34AC3739AE3435AE3234AD322EAD3729AC4223AE4F20A75D209F67
249E6A2A9F6831A5563DAA4042AA3245A92B49A82352A51E5CA2215EA41F60A61C5FA51E
61A62161A4215BA7255BA82562A52764A5235DA42056A62053A71E51A82053A9234BA827
4AA83248A6374AA14348A34145A73744AB3044AC2E40AA363FA73F3EA64B41A84840AA41
46A83F4CAB3C4DAD394BAB374CAB2F46A92C47AB3246AC3C45AD4343AB4E40A85641A74E
44A74049AB3A4BA83C45A63A43A63D40A6403FA74140A5403DA63E3EA73F40A44341A242
40A5403BA84239AB4536AC4939A8483AA4473CA04538A04A34A45232A65331A74C30A648
31A34733A84835A94D33A94A36A64539A6433CA3433CA8473AAA4D36AA5236AA5039AB48
3CAB4639AD4038AF4035AF4335AF4931AB522EA8592DA46133A56534A66C30A26C339B65
33A06135A161359B5E348E5C36885E368C5E369460369762359667339461339A5D329E5F
2FA15F31A55D2FAA5B2FAB592EA9572DA5542EAA5031B04936B44335B54033B5402FB541
32B44732B4522FB05931AF5C33AD6033AC5E31AB5D34A95C34A75C36A25939A0573B9D56
3D9E5F3A9C663C956F3C896E378B6937906B409C5159A9296AAF1268B21368B31865B31A
67B31B67B11E61B21F5CB21C60B41C66B41F66B5205DC01D55B8204FB92051B6204BB627
49B33147B24147AD534AAF544FAD4F53AF4A5CB24265B02F73AD187AA1077F9D067E9B04
7F9902809A007E9E0378A6086DAD1263AD215CAF2F53AF4849B05947A55F4998684DAA52
54C03C56B62E52B5254EB5214EB13449B04D49995C4B806B507669496E6A467B6B408A6D
459268459264448B6553826D52797A4F79804F66805C617D715A797C5A78815A78716474
5E716E757F4E93833490684E85625E8A67698B6C658C6A638072607A7259796D5A73625F
806258A85E49BB543FC84D38BA4C42B14C40B25B2FB86222BE5E39BE5E4CB07241A27F41
9E824A8B924E7DA6368C99178D84018A7E008A7900877800877900897A00897400887200
8B72008972008C73008B71008F74008C7800907700907A008D7B008D80008F7F00947F00
937F008C80008778008777008575008B79018D7D02877E038A820683880B84910D819711
7E99137A99167BA01977A82076AB2178AF1D77AF1A75AD1B73A61575A41374A8136DB013
66B31366A70F609B106092126691116B9111708F0D74920B7C8F067F88017E84007D7E00
7B7D00787B00757800747900747B00747900737B02727C047178046F7B036E7C056E8108
7086096A880B658D0A60981458A12056A82E5AA4315DA1355F993B60983D5D993B5F9E34
619E2B64962C638E24628617647B11636E0A6262015F5A00584E005249005141004B3E00
493C00483700463900483B00463B004339004033003A2A003421002A1C00291A00231300
191100180D00130D00100A000C0900080400050200040100020100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7927616D2956732C527D30527B345079553C6862515A69675569784D6A843E7F7D359B69
31AB532EAE4234AD383BAD2C41AD273CAA2433AC252FAC2C2BAD4029AB4D27A85F259E68
279A6B2C9D653AA55643A94148A9344DA92B51A71F5AA41763A31A64A51D68A61865A41A
64A41C60A51D5EA41F60A32263A31E69A31F63A31959A21752A41652A61B4FA7264EA82E
4EA83B4AA64547A24E46A34A43A63F40AA3541AB3143A93542A6403FA65141A84B45A740
4CA3404FA63C52A83451A73150A72A49A92A45A83347AA4045AB4B43A95443A95744A64B
48A73F4BA93748A53C43A53C43A6403EA6483EA35041A04B40A2463F9E44449C4842A044
3EA6433AA93F38AB4139AA483BA44A3DA2483C9E493A9F4D369F5337A15335A14636A13F
36A43D36A74038A94135A84035A93E36A63F37A64139AA4834AA5135A95736AA5037AB47
38AC443AAE4237AE4236AF4B35AD5531AA612DA4662C966E319B7133A07434A170329D67
35A16435A362359E6035935E348D5F37925E359962369865349369338F6331995E30A25E
32A85E2FAA5D2EAB5C2FAC592DAD542CA9502EAE4E30B14633B64232B74431B5412FB23D
32B14032B14A31AE5433AD5F30AF632DAC5F31AB5D36A75B35A25B359E57389C553C9955
3A995E3895653A8D6B3C8666398C6438946646A24F64AC246DAF1166B31264B31962B11E
61B32059B52559B42758B5215FB32069B22264B1275CB52350B92347BA2048BF1F49C023
4AC0274BB53546B14C45AB55459E5B4AA75F4DB15D59B4506BAF2470A80C7AA4087E9E02
819700829800839B017F9C0378A3096DAB1560B12352B03B44B24D45A459458C6F4AA556
4FC04053C03150B52950B4294CB13B45AF544C94604D756D4E6F6C4B676E4A776E418B72
458E7343837446797750747A4F6C854C68844C5A87595A84695C7F71597C76547B686577
587C6C6F88548A884384745484725E867B60827D5F8B755F86745C7F705D7D6A607C6162
89605BA15D42B15A36C15230B84C41AA4850A45741B36036BC5A41BE5B4DB36F45A67B46
9A825285954A78A728888F0F857D018B76008873008B7800897B008E7D008C79008A7A00
8D77008D78008D75009174009076009374008F76008E7A008E7B008F7E00947E00958000
9283008C8000887E00857B0088760087790482800C8289118093147E99147D9E137D9F13
77A01676A51A73AB2272B22A6EB6286EB82271B7246EB12F6FA82B6EB32B6CB92C5FBC29
58BA1B56B41658AD1C58A31F5E9E245D99215C9721629B19689A0E7992057C88007F8000
7C7D00757800707600737600737900747B00717E036F7E0870830970890B6F8F0E6B9310
6895106498125FA01457A71D51AE2E58AD365CA1405E95485F884E5B8A4F5A924E57994A
58A1445C994062942F638E1C6383126476096369015F61005954005249004D40004A3D00
483B004639004338004436004338004233003C2C00362600302100291C00251900201700
1B13001B1100150E00140C000F07000B0400070300040100020100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
8837458738458A384791384D87344D7A54316B5B535F606B595F794F65863E79803A976A
33A7532FAA4234AB383FA8303EA52D39A32A34A72A2CA73327A84926A95428A95C2CA45E
2EA35833A25040A8464CA83753A82A51A72352A71A5BA71764A7196CA71E72A41C6FA41E
68A11F619F20649D1E6A9E1869A1166AA11968A1175AA3174FA5184FA81F50A82A4EA630
4EA8354BA73849A43F47A33944A73540A93241A93146A8334AA63546A84047A93D4FA937
52A73853A83653A8304EA82D4FA9284BA72D48A53844A94743AB4D43AA5345A95048A747
4AA63F49A53C4AA43F49A54249A74445A64A43A45245A35045A24740A14A439F4E44A44E
40A64E40AA4641AA4642A64C40A04C43A04B439C4A3E984B3D9A523B9C513E9D483C9E40
3BA13B3DA6393CA73C3CA73D3AA93D37A94037A84136A94934AC4D35AA4F36AB4A37AB47
37AB4938AE4637AD4835AB5136A65733A55E31A06631976A359B68379F6638A063389F5F
3BA15E3AA55F3AA45C379C5934985C34975D339B60339C64339965359462339E5F31A55C
32AA5B32AD5831AE5730AC5430AF502FAE5132B14D35B54A37B84136B83F34B33A34B13F
33B04034AD4735AC5232AC5F30AD652DAC6233A85E36A458389F523E9B513F99503C9653
3D915C3C8B613C8766428364418B63419A6150A94769AC1F6DAD1367B11463B21A63B01D
60B0215DB02460B12461B32266B22067B41F62B2205BB11D56B5204FB91E50B92150BE24
50BE2451B92A4DB23B48AF4646AD524FAD564DB15958B44F65B22D69B01B76A80F7D9D01
8297008494008498008398007F9C047AA10970AC155BAF2D49B03947A351488B6E4CA45A
4FB74D54BF3A51BF304FB42B4EB44046A9554B92604D786751786A526F6E507C714C8479
4982784F7A7A5170794E707D4969864861894C548B5757876E56896D5B7E6A577C5A697C
508D7362955F798D507B7A5E7E79628F7765996F6B996C6490676482686881666E89666D
9261609A5D47A55B37B55D2AB75633B5544A9B5A4FAA594BB45A4AB65B51B46B45A5744B
9279537D953B7A9C1A858708887B008A79008A7B008881008979008E7C008F7700907A00
9278008E75008D75009178009073008E7600917800937C009077008F7A00947C00958000
9383008E8400898100877C008B7D0082810A7E8C167B9619779C1A7AA01A7AA71A7AAB1C
75A91E6FAB2471B02F6CB3316EB92C6FBA296AB7316CAE3C6CA63A68B1366BBB345FBB33
59BC3057B92A59BA2D59B42E57B13053B03352A92C58A7285CA5216BA11B799E147F990F
80900B7C8707758508737F07727F077081056D860A6A94116F9717709F206CA3246BA428
64AB2861AE2C5EA93159A63759A636699D397191427289496C834D66874C5F894E589251
52974D5798445A9E315D991D638E11667F07647500606C00595B005246004F42004A3D00
453B004436003F35004136003E32003B30003B2B003325002F1F00291A00251A00201700
1E16001E14001A1300160D001109000C0700080500030100010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
93452E98463398453B9C404796374980592B71634F6265625A636C53677048816B3F9960
35A64F31AA4036AB353CA62E3AA42D36A82930A8282AA93426AA4B27AC5129AB5330AA4F
35A9443BA93946AB3251AB2659AA1E5AA91D5EA81662A8156BA61972A51B75A41971A11A
6CA01E6D9C1E6D9B1E669B1A659E1761A01762A11C5CA41E4FA41F4CA52752A8294FA829
4DA72D49A82D49A82D48A62A49A82546A9264CAB294EAA2A53A92E50AC3553AD3157AD2C
58AC2F54AB3454AB2F4FAB2D4CA82C50A62F4DA43B45A84345AA4448AB3F48AC3A4AA73A
49A33D4B9C434A9F454AA3454CA44549A74544A84A46A84846A94542A84942A5503FA752
3DA95540AC5145A95245A35248A051479F4D46984D43974C3E994D3F9D4C429F4640A13F
3E9F3D409F3940A13A40A53C3CA83D38A94137A94836AA4A35AC4A37AB4A35AB4535AA46
38A84B38AA4E38AA5235A65B37A05F349B61339865349767399763399F5D38A55738A656
3AA95538AC5638AA5536A55534A15A349F5C339F5F30A26334A36334A36331A75E33A85C
35AB5832AE5132AF4D30B14B33B14C34B14C33B44C36B74A38BC3F36BC3836B63834B73F
33B34633AF4B30AB582FAC612CAA662CA76633A46236A3583BA052409D4D41994C40974D
3D8C533D8A5940896142886547955F4AA4515DAE326BAB1C6AAE1764B21A60B11862AE15
5FAF165FAF1765AE196AAF1D67B32065B21E5EB31E59B11F5CB11A59B71A59B92458B825
58B52554B92452BA2B4CB73C45B14E4EB25251B55454B34A5BB23860B13070AA167E9A02
7F9600819400839800819C00809D027DA20779A90E65B01D50B02C4DA4464888704BA461
4BB4574DC04149C0384AB63449B14747A15E4B8A624B726651736A596F7259727D56777F
5C757F656B7A676579516A8141638846598C504F8E5D528F6E558E6A59835E577F51717B
4B9E7263A6597F8E507C7A5F7D7F5E8178607F736A816D67806B667F646982606E906969
986C5F9B65509D6445AE6639B2603AB55A40A55A4BAA5754AD5C4EB35C55B06F4AA1754D
8E7B568093347C900E858203897B008B7D008A80008C7D008A7C008A78008A78008D7500
8D76008D74008D75008D72008C77008D76009481009B8100947A00937800968000958500
9283008F86008983008D8400898A027D931174A32572AA3073A12C6FA1286EA9276DB12D
6CB2346AB63A6DB83B6AB7346BB9326BB6396CB14769A44D68A24866AB4165AF385BB53D
54B64650B34C53BD4B4FBE4B48C04B48BD494EB74050B43B50AE4356AD4059B03C5DB22F
69A8186E9A0F709411698B0F6A8A0E698F0C64991260A12461A6345EAA4262AE4062AB47
5AB24650AF45569F4C5D9751668D4A7380497B7B4D767A4D6D82496687486183495A8C4C
50914B4E96484FA33852A1245698175C87095E79015A6D00535A005048004B4100453600
4039003D30003D2D003D2E003B2C003B2C00372D003525002E22002E1F00291E00251900
2015001F14001E11001A1000130C000E0800080500030100010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
904B29994A299649339146428D41457E602E736D40646D50576860506F644B8962439D55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864A2496492295492B89443F9144478C5C3A7A713968724A5E6F575472625289604A9E54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89492D90472A904439833F468C454F8C594777713E65764C5C755C557864508662479C55
3AA54B35A54037AA383CAB2E3AAC2A35AE292EAE3025B03922AD412BAD4032AE3A3BB02B
45B01F4CAE1C50AD1D4EAD214AAC2753AC245BA9205DA61B5FA61F67A32370A12270A122
6FA01F6DA1236CA12A69A02B5FA02C5CA22760A1265CA22859A229559E24549D1F55A11A
52A41850A51D58A31D5AA51756A41451A91951AB1F56AB1C5CAA185CAB1A5BAB1C56AC1D
4CAE2549AC2D4BAB374DAD3A55AA3A56AC3453A8334EAA344CA9314CA8304AA93146A638
44A342429B4A45A2484BA7434BAB424AAB4046AB4546A94D46A94F48A95546A65846A15C
469662479265479A65479C6147995A45965A428C5D438D5D43905A429355409F5144A24D
459E4B4A97494B8F4B498C524D9651509651518D4B4D994845A04541A6423BA83B3EA939
3CA63942A8393EAA393DA83D3EA83E3AAB3D39AD3D3AAC433BAD453AB1443AB24439B142
37B04032B24432B14832AE4836AB493AA84A3AA84D3AA7573BA76339AA6234A96233A85D
35AD5439AF4A38B24036B53A38B63938B93B38B93F35B64732B65031B2552EB05E2DAE63
2EA8662FA168309B6B329C6B349E66359F5D35A35A34A65337A84C39A6463BA54539A442
3DA6423FA63F42A93948AD3559B22860B62361B21F64B21E61B11660AA0E62AB1061AB19
5FB0235EAE295AB02C54B11E53B01957B21B5EB01C68AC0F6AA90C5EAF0F5CB1175AB71C
55B52C52B42B52B02751B13149C03F4EC04151C04455B34159B44058C0465EB3345CB029
74A6167D9404848B00868A00898D008A91008698067FA30F72AB1C63AE4047B16343AD6C
439D7643AA6B45B85E43B65642AE5F47A2654C876B4B6A6A45756A3B7E693D8167408463
4783644D7E6F4E7B754B75784D6D796B5F7783567778567C69557F5E647D5F70795E9260
59AF4869AA416E954B638E59618E58649155678E596D835F74796572746B7F6A6AA2585A
A354558668528A6E49B15744AB554EA0594DA95D49B95D4CAA6E55A86E579C6E57897A54
71A03B769A1F7D8607827C00807B00817A00837A00887B008A7A008E7B00947D01988404
9B880B9F920FA09C129EA41397A71392A9158AAA1782A71E84A3258AA11B8E9C15959509
9595029597078C9E0E84A51280B2147DB6197BB61D79B52879B92A79BC287BBA2277BB24
73B52E70AC3B6DAB3F6CAC3D6CAE3F6FAD4076A24374954C6D9F4B63AB495EAE5056B559
50B35452AE5549B45843B45444B25047AE4C49B54A48C04649C0424BC43950C43351C03A
51BE4452BA4753B84A56BA4758BB4056BB3C52BA494EB75A4BA86D47AA6B48B7654EB55C
51AD464EA530539E295A994959954952953552951F56920E54901451901753931B509416
4E981A4C9A1D479E2541A22643A01A4C9312507E0D48710E435F05455500464A00464000
423C004035003C31003A3000372C00352C00332C003226002F23002D2000292000281E00
261C002318001B1600171100130D001009000D0500060300020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
8D493D894838864148853F5688445D85584D746F41647A4E5B795C537C634E846241965A
3AA55131A84836A94039AB343AAC3035AF332CAF3D22B14121B3442AB34031B2393DB125
43B01E4BAC1C51AC204EAC284BAD2F4CAC2B53A82459A71E5BA7215EA42867A4286EA227
67A22462A32860A42E5F9F31569E2F50A42751A6234EA72351A42056A01A589D19539F17
4FA2174FA11956A3195BA31857A61253A81554AB1C58AB1659AA1455AA1750AC1C4CAC1F
48AD2847AD2E4FAC3753AB3C56AB4058AB3855A73450A5334BA53347A83546A83744A63E
44A54544A34C44A74645AD4347B14148AE4145A94846A75544A65944A65C46A45F489B63
45876747856945926D45986A44976241945E3E8D5D418F5E42905C41925A3EA05340A852
44A64E489E4C4A8D5048825A4D865E50895E5682564E8B4C4A984845A14241A93840AB36
40A83642A6353FA8343FAC3741AF363DB3343BB53A39B2413DB1443BB34239B43F37B03E
36B0392FB03D32B14234AF4039B1433BAE443CAA4A3BA6523AA66338A66735A46234A55F
34A95636AF4D38B24336B53939B53638B93636B84033B54D31B45B31B1672EAD6F2DA66E
2E9B6D33906B378C6A379169349866339F5731A54E32A84B32A84633AC4436AD4235B23E
36B5373BB72E43B8254BB91E58B71A61B61B63B41D64B31F60B21B5FAF1162AB0F63AC12
63B0195EAE1A5DB01C5BB0165BB01461AF1664B01266AF0D6AAE0D63B0135FB1165AB419
58B52457B32259B21A55B32450C03754BA3956B53C59B5395AB4395BB53B5DB4315DB32D
72AC18819A05849200878B00898C008A9400899A02829B097EA61468B12B4DB44B47AE61
439E7C41A97942B36944B15D48A5594B9B5E4B9262498761418B653A916D3C8C6B408464
4D7F6659776B5B7171587273586A736E5E717E5A71725D7663617C5F71705B776B669050
6BAA4070A54166964C5F8F58608561648A586C875C73795F7A706677736B8273649C6854
A25648865F4C816A47AB5D40AB514F9D4E54A75D4FB6614AAA724EA56F53956B55867B51
6FA02B789A16828C05878100847E00837D008B7D008A79008D7800977B00998806969612
999E1B98A31D98AF1F90B6218DB31D8EB3218CB02486A92F849A37859733889A2D939F15
939F048FA70F83B0187AB21C79B71D79B52A7AB42C79B52B79BA297DBF2C7CC02C79C02F
76AE3B71914E6C8F546C97506AAC4A6CB64269AC466B9D4E699F4962AC4C5EB25C56B45E
54AE5254B15444B9543FBD533FBC5346B05746B25645B55649BA4F46C13E43C53B3EB945
41B44945BB4D47C25149C84E49C54648C24843BA543FB5603AA6743CA56F3AAC6B3FA852
44AA3C46AA3E43A82F47AD3A4EA737509F2A4B9B1A4F97155099254F97264C94294C971F
4B971F4A9521459429409E26409C18489114478114447313456007465500484A00464000
423D004038003F3400393200382F00342D00352C003528003225002E25002B2100281E00
281B00231A001B1700161300130D00110B000C0600060200020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
88444681464385435187456088485F84574A7368446772515D765F587766527C62459059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724154674B556752566F5B5774635375694A676E4A6774556373675D746C5879634B8A58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5E3A625A456264535C7062546F6F5568755765755569745E66746A6372725F7466508559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5E4B675B54626460566A6D51687751607C55617A5466796066756661756A617961518655
449C4A3CA64137AC4133AD402CAE3B28AF352BAF2E33AC2638AB2139AC1D3BAA193EAC15
49AC1C4FAC1D4FAB1D52AA1B56A41D5FA02069A31E70A41E6EA4176FA41571A31774A418
76A2157A9F1574A0176DA11764A22060A2255EA025559F29569E2759A0225EA22464A024
66A024679B276B9922699919699E1864A3165DA71858A81E53AA234FA9294EA73255A938
56AA3855AB3855A53955A339579F36559F3654A3384FA43C4CA64548A64844A94343A840
44A94044A84246AA3F48AC4346AA5144A85E41A263439D63449F5E449C60469862459662
469064438A654488644681634B7A5E54765C60715E5B755E507D5E49876049945D499A5F
4A955B478E5A488D584A8C5A469456439C5242A24E44A64644A64046A84049AC364EAF32
4CAE374EAE354CB12D4BB12D4DAE2E51AE2A4FAF294CB12B54B22757B22358AD2557AC26
58AD2251B11E48B12645B02A43B02B41B02C3FAF343AAD4334AA4D35A95337AB5636AB56
3AAD523DAE4B40B14245B4384BB32F48B32A46B5294AB2284DB12E4EB13151AF3058AE2C
5CAF295DB1235FB31D62B51864B41766B21465B41265B40F62B51064B41366B41964B41D
63B41864B71666B41965B42364B22966B02966AF225EB3275CB11F63AF116AAD0D6FA90F
6DA70D6CA50C6CAA1268AC1C6AAF1B65AF1B62AB215FAA2462A92263AA1860AE1760B110
61B00C61AE0C62AF135EB11454B11752B21853B11C51B22351B32F52B63C56B23759B336
65B02668AC237AA4148597068D97008E97008B99008C9F008DA50284AC0974B11365AF34
4C9F6549A06845A26F48AB654DB45550B6514BB65747C06048B3604BAC604DA4664E966D
53896E4D7C6F4A766F4974714E796F647A6E707F6A6B815B66864A64AA2A5DC02760B829
64B53162AF3E66A05864995C6493586C8A536F785970796178766A84696792546E9D5D61
AC5862996B5D906B6B87736B8F6E71A16A71A36268A05F5CA16451A26850828540728B36
7C8F168183028681008E83009185009584009C8A0A98961B969A279B95378DB03587B433
86AA3380AB3482B4327DB9347FB8327DB7337EC0387DC0367EC03D81B04389A04087AA35
83B41F7EB41877B12C729D4771A64A71B9436FC03B78C03A76BD4076BB407BBB4079B63E
74B04572A74B729C4A71A04870AE4370B33A72B43275AF3575A33675A23C70A2445D9F4E
5F9A635699774BA1764AB87344C86D3FC7723FBD683FAD6645B06047B3574AAD5249A655
4B9C5548874F437C49416D5946766B4F6A6E645C607862606086554B8C4E457C59439456
47A64F45AA3B45A43648A83444A927479B2D3F983840A33A3CA7383B9B3438883A3E9729
3D991D3A98173F95163A9118358D19328616318411367C084371014D5E004E4800453E00
453B004238004135003C34003B32003A2F00362B003225002D2100271900271A00271800
2215001F11001D1400191200130B000C0500060200020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6367615C6B5E5873575C7C4D5C824F59855A577F5C587E62587E67587A69588364509055
43A04834A6462DAB4F26AD5424AF4F25B2412CB03432AD2436AB1E3CA9193BAC1642AA14
4AAD184EAE1C51AD1F53AB2157A8235FA42467A32170A41B71A5136FA61472A31774A218
769E19759D1B6B9A1B639C1C5E9E215F9C1F5F9C205D9A235E9A21659D1E689C1D6C9C1C
6B982169971E63991A649F1666A11860A61A59AA1E54AA2450AD2C4FAC314DA93453A938
53A83755A93756A63856A235569E33569E33519E324EA33A4AA74246A94243AA4242AB40
44AB3E44AC4246AB4143A84A44A655449C6243956543936342986544986546966647956A
47946B468C67478565487C64507B625778646371665B7466517F674A89674B966049975E
4D8F5B4B8E554B90524993554A9650479D4E46A04B48A64546AA3F47AC3F49AF3D4AAF37
49B03950B0354FB12D4CAE2C4FAC3352AC304FAD2B4DB22C54B22A5BB22259B12359AE28
59AE2058B01C51B01C4AAE204CAC204EAF2147AE2A3FAD343CAB403FAB483FAC4A3FAE4B
44AD4348B03C4CB22E50B52355B41F56B51B55B31B57B01E5FAD2166B0226AB1216FB01F
6FB21D6EB21D68B41C66B41E65B32267B62065B51D64C01864B61566B41466B61767B81B
65B71A66B41965B31C67B22465B12764B22563B0215FAF2266B01C64AF1665AC1666A81A
64AA1A64A8186BA6176DA71871AA176DAA1868A9186EA71771A91567AB1B5EAE1F5AB216
5FB20F64B01164B11864B31656B31952B21A53B21B56B32255B22F57B23B5AB13461B630
6CB2266DAE2377A91486A0068B9A009097008D94008F9A008DA10087AA057EB10A67B32B
4FAC564BA35C4997604C9F614FA8584FAF544DAC5A4AAC5E49A8614FA45E539B615D9067
59846C54796F4E756D4775714C806956946461A75765AA3E6AB0276BB61C62C01A67B61B
69B02C65AD3864A44864A44F5EA64964A345689B476B8D4E717C5D7F7459995F588D6A62
8D5C718D6F62916E667E6E67826B709D6870A5646DA45B59A66450AC694F888B3C77982C
828E14867F01887E008B800090820094850099900C98971F98A02895A73190B22E8FA932
8DA43789AC3488B52F87B82E83B62B83B92D80BA2E81BC3385B83E8DA647889C4784A53C
84B72583B51C7CA92E799049769B4978B94472C0407BC03877B83D7DB83D7CB33C7CAD3A
77A84074A24075A03E74A53E6FAE3B76B23376B42E75B32D78AF2B72A9346CA945609C4F
5C955A539F654AAE6D48B96F43C26843C26846BA6748AB6B46A66945A55C46AC4F4CAE53
4C9A574D7A58547054546A5C547667596E6F5C6B6266665A5C7B4E4B8E49449254439D4C
47A54842AC3945A63A47A63445A828489F2E439B37409C3F3C9C4336973B358F3938992B
3A9B22399B1D3C991E3C981E389520358D1E318615377D094270034D5E014F4C004B4100
463D004338004035003B30003A2F003C2E00372D003225002D20002B1E00281A00241800
2017001E1000180F00140E000F0800080400040200020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
62775F627B5B597E525A854B588B4F598B5753875C5086604F83654F82675188604C9453
3EA0492EA54B21AB5A1EAE611FB15C24B3492EAF3636AD223BAB1C3EAB183EAB1447AC12
4CAE174DB11C4EB12253AF2756A9285BA62761A5216BA3186DA5126FA5106DA115729E17
749E1D6D99226897216099245E9D215C9D1F62971F6997206D9A1C729B1973961872931C
6F911E699615639D1660A2195EA61B57A62051A9254FAB324EAC3B4BAB394CA93A53A839
53A63854A73854A63A54A238549E3351A1314DA0334BA33B49A64046A74144A93F43AC3C
44AC3D44AE4245AB4643A651449E5E449366418E69438A6941906943926E43906B47906F
47906E4488694880664A7C67527A68587566626F6C58776C4E856C488F6C4997654C945E
4E8A594E8D554D93524C93524A984D4A9B4B489F4B4AA4444AAB3F47AF404AB03F49B13A
4CAF3B4FB0384FB02E4FAE2F4EAC3952AB3650AE2D50B02A58B22A5EB32759AF2459AE2B
5BAF285BAD1D58AE1C53AC1D57A81959A91E54A82849A92E44A93845A63F46A93C45AC42
49AF394FB5314EB62553B6205AB5185DB7185AB61D5FB01E66AD2169AD236AAF266CB126
6AB4286AB52564B62463B62861B52E62B62A61C02965BD2567BD1C69B61468B61668B61B
64B61D65AF2162B02362B42B5FB42964B42761B22060B02664B01D61B11D5EB02353AE2D
56AE2A5AA92563A81C67A8196DAA1866AA1B66A81869A8136EAB1066AF215CB22E5AB41E
5DB31365B21362B51D5FB31C54B61C52B71E53B31E57B3215AB33057B53C5AB53461B531
66B72667B42570B01584A3078799008D92008F92008F99008FA2008DA70080B5066EB727
4EB5494BA9544C8D604A89664D90624E95624E96654995684D91694E8E665D876667786B
62766F5B766F50776A4C7A684B90604DB15459C04464C02466C01767C01762C01665B317
60AD2E59AC455CAB4D5CAE5153B05953B34B53B4405E9F48687E5F7C785AA86B4C85795E
766E7982756E916F69766A697A64729E6A75AB686DA85C5AAB6550B36F4F89933D79A323
87960F8887008586008686008B8600928C00939A0D9A962496A62B92AB2A90AD2B8BAD31
88AC3C8CB4378CB83189BD2787B82683B9277FBC2C7CBC3589B2479A9C4C889A4F82A244
83B92E7EB7247CA3387F8A4C76994779B94676C14978C03E78BB3F78B8407AAD4377A444
759E42749B3F75A03E71A63F6FB43E70B73871B23872B23473AC2F67A63665A749629F50
5D94554EA65A48B86846BC6A42BD6443BC604AB76448AB6E46A07243986446AB5147B452
4A9A584E6D61596660636762676A6A6B657853736D546D5E4E724A468448449C5441A554
40A14F3DAF4144AD3F47A93743A82F43A3363F9F3E3D994B3A94543498442F983C29A032
2FA127319F2538A1223AA0243C9D2C35922230871834800D4073054C5F015052004B4B00
484300443D003B36003931003A33003A3400363100352A003125002F2000291D00241800
2017001B1300180F00130B000E0700080400050200020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5C835B5B805959804F5B82425C89405D9042579040538F44528D49538B4E53924F4E9944
3EA33E2DA53E22A74821AB4B26AC462CAD3837AB283DAA1D43AC1947A9174DA81556A912
5EAA125CAB165AAD1559AB175AAA1A5FA81F68A41C6FA31671A31370A6166EA11570A015
6F9C176B9D186A9B1C6A9A1F699B206C9A226F961E6F951C7195186F9715709816749A18
6E9816689B14629B185FA1185BA51E54A4244EA82C4DA8344AA83B4AA6394EA63851A738
54A43857A63555A43354A12E52A03254A035509F40509F404CA24349A43E47A73A48A83A
48AB3A46AE4145AD4844A455439762458D6A47866C487F6C45846D44867043886F438971
46886E458268497D635476625F72615F75625D75665480624E8C634897634A975E4C915A
4F825A4F87594D8B5B4A905C4B92514A984D4A9D4E4AA5404AAA394DAD3B4EAF3B4EAF35
50AF3451B03553B03052AE2E51AC3455AC3457AF2858AF235BB0255EAF235CAD2258AC25
5BAD295DAC1E5CAC1958AB1860A81666A3175FA21C56A4214FA52753A62D52A83051AA36
55AE305AB3285DB5265DB32161B42165B11E65B11F65B02164AE2368AF256BB02968B12A
6CB22B6AB52668B52469B5246BB52768B62768B7246BBD256DB7236FB31E6EB21B71B519
6AB41667B31967B32067B42569B4226AB21E6BB21C6BB21A6AAF1B65AD1E65AD255EAB29
5EAA2261A51F66A6186CA71770A3186EA41E6BA71C6FA7176DAA1B66AD2366AF266BAD1B
6BAF146CAD1266B01661B2165AB21859B3175CB2175AB11C59B42957B4345CB32F5EB22E
69B2216BB01B75AB1480A306879601909200938F009093008C9D028AAA0983B50C6FB528
50C04950AD514A995C4996614B9D5C4F9F5C4C9E5F4A98644C9366518E635488625B8265
578965549561549D4E56A0405EAB3564B4306ABA2772BF1B6FB5146FB5156FB7156EB11B
69AC2D64AF3A60AD3C62AD3D5CAF415AB04658B2445DA14962835B777E5AA471557D8562
6C777574756D7B70676E6F66776568986065A76160A45D54A96A51AC74548B923C7A9E20
88960F8C87008B83008A7E00947E0097890C959914989A2293A02A90A5298EA82E93A431
92A3388EA73489AB3586AF2D85B62482B92283BB2281C02F83B3428A9E4E83A04D80A346
82B33281B8227DAC31809E407BA0467AB44970BD4A77BC4077B5407EAE4680AD3A7CA939
7D9F3582A03585A23181A5317EA9307CA72D79A8287AAD2679AC277AAB3471AC3D6BA946
61AA4A55B64851C04C4FC05345C15344C24D4AC04F44BE5945B35F49AA5C4CAC4D4BAC4C
4EA14E4B905A4F835A50795B53705C5C6B654E795F4C84574D894A4B92454B9D4843A055
3FA5543AAC463DAE4640AC4441AE4043A74041A3413DA14339A24938A53D34A63533A633
33A53035A42D38A32F39A12F3F9B263C8C1B3F7E0F4172084963025055004E4C004F4600
484300463D004036003D3300382D00362B00342A003327002C23002A1E00261A00241900
2317001E1300190F00120C000E0600080400050300020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5788625A86615B82555D83475D86405F8F3F5C943A56963C4E973F4E97415199424EA03E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5B8F515A8E4F5C8E455F8D3B5E913963963B609A3A5A9A395A9A38599838599B37549F34
43A62E30A72E26A9352BAA3330AA2F38AA283BA9213DAB1A46AC194EAE1558AD125FAB14
65A81461A9115BAA105AAA0E58AA125CA71760A41764A3146BA3186BA6166CA71469A616
68A51569A41667A2196C9F18709C1B73982274981F749717719912699A16649D17659F17
65A11363A0115CA11A54A52450A83048AA3548A73848A23643A03642A43742A63447A535
4BA1304EA12D4DA32B4CA42D4CA4344EA2424EA14D4F9D4A4CA24548A53C49AA3549AC34
48AB3948AC4047AA4C429C5C428A69428171477A734F6B774A73763F767A3C7B7A3C7C79
3F7E74417C6B4F7761606F5E6A6E625A7760527A5D4A9059489957469E58469754498D57
487C5E4A806243886A448F644A9257499A5249A24F4BA73F4DAC3153AF3156B13453B333
54B13150AE3657AE3256B02B56B12F58B1305CB2235FB01C5AB0215BB0265BAF215AAD24
59A8285EA72362A81A65A9146CA212719A146D9B12669D1A67A01B69A31F66A72565A72E
62AC2665B02466B12866AF2E65AE3063AD2C67B13067B23163B22F66B22D68B12E69B130
67B22E69B62B69B72968C0236CB9216DB5246DB3236DB3266FB32C71B52C6FB7246FB718
6DB5176CB41D6EB2246CB2246BB3206EB41A71B2186CAD1769AD1E63AA2A64AF296CA829
6BAB2365A61E66AA196CAA186AA71A6CA6216BAA1E69AD1E6AAC256EAF266FB02374B219
71B0136DB10D68B30D69B20E6BB3106DB40F66B30E65B4125FB2185CB8215EB7235EB428
68B31A69B01476AE0E83A504899B01919500918B008D9100899C0381AE0A77B8136DB828
56C04052B6484BAF5147A8544AA4534CA0554C9F584A9F584FA25750A6524EA74C4BA446
52AF405EB9386CC0256FC01B6FC01872C01A75C01874C0186FC01770C0186EB41B6CAE22
6DAC2C68AB305EAC305CAD325EAF3D5FB34858B15156AD58599C5C6A965784855D728C5E
5E8966638562667F68657A6B72676D8C5B6A9A6162A3635B9F6F5B9B785F83963B7BA218
89950A8E89008E87009282009886039B9719939E2D92A32E8D9D328D9D3690A23A939F3A
8E9D3B8D9E3787A33683B72F80BA2880C02083C01E82C02183C02F7FBA3E7DBB407EB842
7DBA3880C0277BBD257DB83B7FAD4677B64672C04678C0437BBA3F80B23E83B6387DAC37
81A43785A23087A62987AC2481AB1F81AC1A7FAA1D79AE2078AD257DAD3074AB306FA733
68B13562B83761BB3759C03A4FC5414BC43A4AC33647C63D4AC53C4BC3394DBB3F51B13F
4FAC3C4FA6454C9F484898444894474B924C4A95474D9748519F484CA64749AB4943A84F
40AC543BAE5439B14F3AB1503CAD4C3BA84C3DA54A44A7433EA8423BA7453BA549369E4D
379C50359C4D389C433B983140891D48760B4F6105515501514E00504B00504C004F4A00
4F4900494300433C004036003C3200382B003327002F2400282000271900221800231800
2017001C1600170E00120B000C0700090400040200010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5D92355A94385A94355A96335D963362993E629C3C5E993662993366972F64972E5C9C29
4BA4263AA62732A62C30A82E36A92C3BA6273CA9213FAB1D41AD1848AE1350AA1359A616
5EA4155EA41361A7135FA8125EA9125FA5165FA31667A21770A0186FA21873A31574A616
72A31970A2176A9C1871991677941A779217799016759511779A1279951971971C6A971C
7098146D9E0F64A1165BA52852A72E4DA8334CA8324BA82B48A63048A4314CA1314E9F31
4EA02F4EA12F51A22F4DA52F4AA5374DA5404FA5464FA24546A44146A63947A9304AA831
49A93949AA4544A654439965448C6C458470487C704C6E6F4573724277793F7A75427A72
487E6D477E69507B6158735F5871615279604A815F459256479952499853489253488958
49805F488A5E46935C47965549994C4DA24750A8474FAB3950B02953B02657B22D58B22D
55AE2A52AE3156AE2E57B02459B1265EB02A5EB0215FAE1D5FAC205EAD2864AA2361A820
61A42962A32465A61B6EA116739D147494177398186D9D19719F20739F246EA42A6AA52C
6CA9286BAB276BAB2A69A23067A53467A8336AAB366BB1326BB22E6EB12C6DAE2E6DAE32
6BB23069B72D69B52E6AB52B69B72B68B62768B2256EB2286DB1326EAE2C70B3236EB321
6EB11F6FB01F6BB1256BB1226CB2216DB21D69AD1C6AAE1F69B02468AC2E69AD2D6AAB2B
6BA92765A72460AF2365AE2565A92966A4286BA52067A62765AC2A68AD236BAE1670AC0F
70AC0D74AE096FB00A74B10A76AD0777B2086EB40D69B51066B60F63B71165B51763B222
6BAE1670AD107AA90981AA028AA1008F9400908D008F9100899B0283AF0979B4146FB327
59B83454BA3C50B8464DB44A4EB04C4AAD5048AE534BB0534CB84950C03B51BD2D57B823
63B5216FB82473B91E72C01C71C01E70C02070C02073C01E6AC0186EB5186DB41C6AAC25
76A82C6EAA305EAC335CAB3960AE405DB24F56B05453AD5C56A55A629E5772875E668661
5F8A605E8C616089686A80717D6D768D5C729C5E6BAD6765A269678F716480923782A013
8A94078E89008E89009587019995089D9D2091993A93A03993963C91A33695AA3A91A53C
8CA24287A04085A73C81C0327FC02A7FC02682C01D88C01D85C02384C02F82C03880C039
7CC0397BC0297CC1227EBD3681B5417ABB4379C0407BC03E7CC03D7AB93D7CAE4080A93B
83A73882A43185A52A84A62385A81F82A81E7DA7217AA62675A92971AF2D6EAF3171B02F
6CB6306CB93463C13859C43250C3334AC2314BC1354BC43B4FC4344CC42F4BC2344BBC33
4EB4314FAC3A51A23D509B3E4F9C474FA64852AD404FB2474AB54F43B55542B15E3DAF5F
3AAE6A38B16C38B46337AF5B36A55539A15B3CA7573EA84B3EA7463BA5503BA15937965B
33905A33905437943A3A8D2341780D4D6201535400534A00524900534E00534F004F4B00
4C4F00474500454200423C003F3800373200332C002D25002A1F002519002217001F1800
2018001C1400161000120B000C0900090400030000000000000000000000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
61992B589B2D539C2E569B315A9A395C9D415F9E3E5E9B3664982F6C90306C9227609824
53A12240A52436A62632A82938AA2939AA273BAC243AAE1F3FAD183EAD1544AC1646A918
4EA81752A71656A81C58A81A58A81558A51659A51862A4186AA01C6EA11971A21373A416
6EA31367A111619F146E9E167799197994187393147396127A99157F951977931F719620
6D9614689B0B65A31859A72552A82D4CA9324BAA2F46AC2A44AA2F47A4314E9E31509C31
4F9C344AA13249A23246A33645A53A47A7424BA5404EA24043A54041A83A42AB3545AA3A
44A74640A64F3FA05F3F966B408F70438B6D457E6E467070467172407776417C71447E6C
4B83674F7E664F7E604F79624C7563487865438363429459459953479455478A5949855C
49855F499357449D52479F4D4AA1454EA9404FAC3F53AD3254B02255B32357B42A56B228
54B22A52B02F57B02D59AF2158B02059AE245AAC225BAC205AAB2760A92D6CA62266A122
639D2A63A02867A11D719D1977951976931C76991D719C1B749F23799E2A6EA32D6EA62B
6DA92A6CAB296AAA2B6BA2306CA4326CAA326DAD306EB32C70B4276FB3296EB02C6CB22E
6AB4316CB62E6DB62E6CB52969B5276AB3296CB22C6DB22B6DB02F6EB22A6DB32669B222
68B3216CB41C6BB4226AB5246CB22169B11E66B01C6AB11E6AB0226CAF2969B12D69B12E
6DAB2D68A82C64AF2D5DAF385DAB3664A52A64A71F64A72966AE2969B21A70AE1070AD0A
75AC0978AD0875AE0777B1067CB3057AB3076FC00D6BC00E6AC00B6BB60D68B71467B51D
6DB31370B2107CB20985B3038BA8018E98008E8E008A9200879A0187A7087FB30E7BB51E
65C02761C02F5BC03652BB3E53B84054B83E50B74651BA4853C03E59C12E5AC3215FC11D
69C01D71C01D70C01F72C01F6DC0206EC01F68C01F70C01B71BA1775B51776B32074AA25
73A62870AD2C62AE3460B13862B33C60B54658B64F56B15559A5545F9C526C865D66885C
5E8F5E60985C5D946469856E7F6E77925E72A0616CAD6A63A06C6483725E7F932F869E0C
8E9504948C00938A009D8F0C9596199B9A2A9A973D92A0398D9C3791AB3390B5388DAE3D
8BAA3F84A23D83A63481B62E84BB2784BB2288BC1989BC1587C01785C02481C02980C02E
7FC02E82C02982C01C7DC02877B73A78C03C7EC03483C13881C03481BA3381B03983AE34
83AD2C84AD2389AA2088B11D89AC1C84AF1D81AA237FA32A7AA82979A92779B0267AB524
71B7216EBC2064C0225CC22156C32653C02855BB324EC13E4FC3394FC1324FC02A4DBE25
53B32459AC265EA62A61A32D5EA5325BAC3656B2374FB3404BB74E48B15749A65D45A25E
43A0663FA16A41A5623EA45A3E9E513DA1503EA44840A24240A040429F42469D45409846
3D93423D8E334487234A7C11546906575800544A004F42004F43004F4700514700504600
484800464000443B00413A003F34003B2F003428002C1F002A1B00241B002017001F1800
1F18001A1300160E001109000A0500070200010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
64972D649C285D9F275D9E2B639D2E67A13268A02E6B9A2C6F972871932B6F9527629D22
52A32248A8223AAB2437AD2938AE2A38AF293AB0293FB12440AF1E40B01A3FB11A44AE1B
4CAB1850AA1557A9195CA7195FA7175FA61962A61865A6156CA5156DA5126DA51271A315
6FA2126F9E0F6E9F10749F12789C167C9817769412749815799B167E9A16779819749918
6D9711649D0F61A61658A92554A82852AA2A4DAA2C48AD2A49A82E4DA42F52A0304FA22F
4CA33247A23447A43346A63146A73347A83847A63C47A73E40A73C3EAB3C3CAC3F3BA946
3DA74E3CA4593B9F633E946D40906F42896C42806F43716F467671467973467D704A7E65
508162597B60567C604F7F60477E614484623F8F5C439C50439E4A489750478D59488D5C
478F5C479851459F4A47A2444BA63C4DAB3852AE3354B02756B11C59B41B57B42454B226
53B12452B32555B22659B11E5AAF1F5BAD2159AC245DAC2360AD2564AB286CA9246CA127
699E2E669D286E9D1D74961D78921B7A9322789A20789C23769C2B7A9D2E6CA42E6AAE2A
70AF2A71B02B72AE2E71AC2F6EAC2F71B12E73B52B75B42573B62474B42770B02E71AC30
70AC3070AE2C72AD2875B12774B12674B12774AF2C70AF2B6EB12A6EB52A6FB4286BB61F
6CB41C6FB51970B51C6DB5246EB2236CB1206CAE1C6BAE176FAE1272AE1670B2256BB12C
6DAE266AAD2F66AC3C5BAD425FA83069A7216BAA1B6CAE1870AE1274AF0E79AE097BAD06
7DAA057CAC047CAD027EAF047BB30677B7096CC00F67C01167C01166C01166B71663B523
6CB5156EB41377B20D82B30788AC048F9C018E94008D93008B95008A9E0089AC097EB419
71B8206BC02762BD2E62BB2E5EB62E5DB82B5FB83061C03266C02E67C02A67C02765C027
69C0256DC0226EC02173C0226CC0236DC0226EC01C70BB1573B31778AE1C7CA6237DA528
75A8286EAA2969AC2E64AF3560B0325AB23B54B34B55B05158A1515F924C68795F64845C
5C94625C9D5A619B5E6A84677A6B72955E72A6646BAA6F5B9C6F5B83715580902A869C07
8F9401958E00988F03A39711988E289991369B93428FA2398FA0378CB4358CB53688AC39
87AA4188A83686A92D83B22A87B8248BB7208DB5188EB8128CBA1389C01A87C01E82C025
7EC0277FC1267FC01E7BC02271C03577C03883C03186C12F86C02D82B82B7FB53380B42C
82B32381B12081B21E86B51C86B51E82AF217FAC297EA72B7BA82C7DAB2A7BAF2779B322
75B81C6FB91964BA175AC01B56C32254C02A58B93651C0424DC13C4BC1384AC32847BE1E
4DB41F54AC1E5AAC2157AC2955AD3251B03F49B25041B05E3EB16F3EA874408D75408772
3E87763D86783F8F6A3E945E409A523EA0513E9F41409B4141974944994547984141953C
429637418B234D7F0F5770045E5E005A50004E43004A3B004A42004B43004942004B4400
484000453C00433B003F34003C2F00392B003727002E2000281C00261B00211A00231A00
1F18001C1100150D000F0600080400050100010000000000000000000000000000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
649632679B276499236098265F9A2A609C2B61992B64942B6C902D70912C6C972A5C9B28
50A12944A42A3AA82A35AB2C36AB2F3AAA3140A72F42A82E44AD2E43AD2841AD2143AE1E
4FAC1B5CAA1C63A81A67A71967A81968A81D64A71B61A51664A60F67A70B67A60D6AA414
6CA315719F10719F10749E0F789F16769A17759714749A17739F1871A11771A018729C10
6A9810629E1461A41758A72158A62656A7284EA92A49A82D4DA3304DA2324FA2324CA433
4CA53548A0384AA2334BA62B46A92D45A83442A63940A53E3DA6403CA64138A74738A451
37A1573AA05E3D9A613E906940896D40816D447A6D47706C46757047777048786E4E7767
5874626870625E7860507E6145855F42915B429F5046A54545A14245954E488F5746905B
47915A49904F499B444CA2404DA73750AD2D52AE2654B1205AAF1A5CAF1B58AF2057AF26
56B01F55B11F59B0235EAF1F62AD1E61AB1E60AA245FAC2463AD2366AB276CA72570A329
6F9F2C6F9B2A7A9620788F207C8E238191267F972982962C7F95327B9A326DA72D6AAE28
74AE2A75AF2B74AE3074AE3173AD3073AF2B73AF2478AF2379AF2473B12B71AD2F72A42F
72A32E74A12D76A52979AC2A79AE2A77AE2D76AD3172B02F6FB12F70B32F6FB32D6FB31F
71B31C6DB22069B02267B02A65B22E6CAF2673AB1F72AB1970AC0F70B11569B22761AE32
5DAF3259AB4856A8554FA9505EA83162AA2665AE1B69B01070B10C71B40A72B1097AAE06
7EAD027EAE027EB20080B3037BB40774B70D69BC1363BC1664C0175EC01960B51D5EB428
65B21966B41476B30F7BB30A84AB0790A1028F9A008E96008A9800879B0085A5097EB211
70C0186DBE2164BF246BB62665B5296BB4286DB22C6DB6306CB93368C02F69C02C6AC02C
67C0286BC02067C01C6BC01F65C0206CC01F6DC01A70C01572B31775AC1A77AE2278AE24
74AC266EAA2764B12864B42D5CB52D4DB6384DBA4C51B353549F5155924F5B8061598760
5A94625BA155609D5B6D81638469699A636BA66767A5705C9A70527F754E7E8C27849306
8E8F009692059B9812A8991EAB90249B913B9698448AAB3F8CAA398BB23789B83884B23E
85AB4080A83686AD2D88B6258DB7218CB7208EB61D8BB7198CBA128ABD1085C01487C01F
85C02481C0267DC21F79C02277C02D7EC02D80C32980C52A80C0277FBC2081B81C84B618
84B81782B71584B91581B71B82B31F82A81E81AB1C80AB1E81AB207FAB207BB02079B41F
78B31975B3146CB41367BC1A5FC51F5DC12B5AC0365BB83F57B74253C33B4FC22952BC1A
56B41659AD1A5AA71F59AB2B54AB374CA94544AC5140AB6040A86947AA594C9B49508E3E
50873D4E8940488B3E429141439649429C4C449843439036468C314886254C871E4E841D
517E185575105969065C5C015B4F005543004A3D00493A00463A00463D00493C004B4100
4A3A004535004336003E36003C3100392E003427002F2000291C002517002118001E1600
1C1200150E000F0B000B0400050300010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
669E2869A02569A22463A22463A12662A127629D2A66982D6A962E6D943063992D559D2B
4DA03542A63139AA3233AC3134AD323BAA313CA7303EA93542AB3640AE303EAE293EAD22
4BAF1D5BAD1F60AB1D65AA1967AA1869A91F68A81B5FAB145CAA0C5BAA095EA91065A713
66A61470A2106CA10F6EA114709D1A6C9E186D9F176E9C1769A11866A41A64A21565A111
689F1366A3135FA71657AC1D59AA2057A62552A62A4CA63148A63345A53440A73541A83A
41A44042A34042A5363EA62D3BA82F36A73636A74236A84635A74B34A74F32A25532995B
3399603699653997673B8C693D836B3F7A6B41746E456C6E486F6D47737148726E536B66
65686777666763716550806244905F439D5846A74947A93D46A545429653438F5A458E5C
49905A4D894F4E994251A53B4FAA3551AD2652AF1D54B01A59AF185AAF1A57AD2253AF29
54AF1F54AF1E59B1235FAF2463AC1F64AE2060AB2861AD2668AF236AAB266DA72C70A42C
72A12C799A2881901C7B89217C892A7E8F2B7A902D7E8E2D7A9236769C366EAC2E6EB326
75AE2476B02476AD2778AF2977B12974B02776AF247AAE2379AF2377B12570B32A70AF26
72AF2376AC227AB01F7EB51F7FB41F79B42378B12E74B13272B33270B32B71B32375B31E
77B21F70B2216CAE2467AE2966B02D6DAE2474AE1F70AF1F6CB31A6EB41C6BAE2867AB2E
68A52F659F3965A23967A63066A92268AE1B6BB11771B11675B31472B41374B30F7BB10A
81B2067FB20679B50777B70579B30776B50A6BB71067B6136AB71467B9146CB4156BB01C
6BB1146BB41077B10C7DB30C84B10A95A301929C008F9A008C9A008B9A0084A0037FB00A
77B91071BE1F6BC0266FB52A6EB23079B02F7FAE3179B03172B33372B73170B9316DC02A
6CC0226EC01D69C01872C01A6EBC1C73C01E74B81A76B4167AB01775AA1974AE1E74B123
76AA246EA9265FB22558B52857B8314BC03F4FB74A54B34E549A4A57924B578C59548A5B
5A8D5B5E9B4F64995579785B925D5AA3655DAA6D5FA46B5897704F797848828C1F899206
908C0195950E979D1DA99A26AE8F2B99983F8EA04789AF408AB1388BB43886B73B84AF3F
85A23C83A33684A5318AB5248DB7248BB4278AAE228DB31C8FB5158CB81290B81389C01B
84C02182C0247BC02178C0237BC02B82C0287FC02778C62A76C12A79C01C7DB91785B916
88B91586B41184B81580B41B7FAE1D7FA71A81A9187FAB1C7DA82079A32079A82275AB1D
72AD176EB0106AB21169BE1E63C3225EC22D5AC0365FB63D5BAF4051C03D4FC32755BD16
54B61756AE1E52A82A53AA3953A9474A9D53459F6442A06F42A06C48A34C4D932B54821A
577611537C184C7F1D43892743913B41954641904841853244801F49740F4B72054C6C03
516401555B01575100554A004F47004F3E004C4000483E00453700423200463800473B00
463C00443A004235003E36003E32003A31003429002D2500291E002519002016001C1200
170D001108000B0700090400030100010000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6B9D286AA12666A52667A52167A12167A22565A02669A0286F9B2A6C9B27619D26519F27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719C2968A02964A32665A22263A2225DA1265C9F275FA02867A02664A01F59A0204BA225
47A32A46A22B3EA4273DA62341A82249AB1B4FAC164EB0164AB01C43B02141B02542AE26
4AB02A51B02B51AC2A58AC205BB01964AC1464AF0E5DAD0C55AE0D51AE0F4FAB1355A915
5BA71365A6116AA4146CA1166EA2176AA11969A51968A51A68A11C6C9C156F9F126EA214
68A61663A71559AD1A51AD254BAA2C45A83040A83538A93D33AD3D2FAA3D2DA94036A742
38A64437A54636A54135A83E34A6402EA5442FA24A2FA64C33A75032A65432A65733A356
33A45534A55439A3593B9D5D3C9261408660477F624E7C6256766257775F59775D5B735C
59705F5870654F8564479460459E5A49A3514CA84252A53E4DA04D4B965A488E61468D5B
46865C497C554A91474EA73E50AC3A55AE3156B02758B0255BAC225EAE1F5EB1235DB02F
59B12D58B02B56B3285CB1285FAF2560B0275FAD2B67AD2D67AC2C69A8316AA2336FA223
76A21D809E1A87931C828E227C89307E8932738D2E73912D69993367A62F6AAF2471B320
74B32077B22076B21E77B22073B22272B32272B42172AF2474AE2574B1266FB42471B122
76B12276B21F7AB21E7FB11F7EB02379AE2676A82D6FAC3271AD3075AE2974AE266FAE26
70B0266BB22468B0266AB02A69AF2A6BB9246CB91D6EB42466B0375EAD3965A436679838
659A36609D3862A43260AE2765B2216AB22673AF276DAE296EB02372AF1B77B2147BB615
7DB20D78B3076EB30B6FB60A6EB40870B2076FB20970B20B71B30D75B50B78B50C79B20D
79B30C75B30B7EB10980B10B8AAC0894A90296A90294A4018FA0008F9D008A9F0088A703
83B20778B70E6FBF1A6EBF2372BE257DB12E7CAC3978A93872AB3772AD3372AF3375B42F
70C02A6EC0236BC01F6FC01D72C01D73C01A75BB1776B31575B61C70B42470B7236FB520
6BB31F5EB4265AB5294FC0304FB8374EB64250B44B53B24E53B0455BAC4063A5485D9A52
5895595E9A5B648C64827062995D64A06A63A36C619F695A8A7D4B7C9C298A9D139A9A0A
9EA913A9AB17B69D1EAC9D33A298438EA64783A94083B03782B53880AB43829D48879B3E
919C3A94A03498A03094A32B91AD2992B52593B71A95B21797B51193B5118DB6118AB813
88BC1B86C02382C22483C22783C12B86BA2884C0247EC4287CC6297AC22B7DC02481C024
7FBB2181B31C84B11C82AD1A84AA1485A8117FA9137AAB167CA41C74A3216EA4246DA51D
72A7166EA91169AE1266B91A60C1245FC32F5FC22B5BBE2750BE2749BA2151B82155B017
5AAA105DA5185CA018589D1650A0254DAD4049B2524DB35358A728678B09686D00635E00
5F58005C55005459034E68154475274675254B721C4F640C525801565200544C00594600
5242004F42005042004E3E004C3F004A3800473800493600453300412F003E30003D2F00
3F32004033003C3300383000382F00372E00332700301F00271B002319001C1300170F00
130E000D0800080400040200020100010000000000000000010000020100020100020100
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
71A22968A02961A4275FA5265CA42657A32859A12C61A22C63A42763A22158A3204EA221
46A22742A22541A32242A61E47AA1A53AC1656AD1254B0114BB21646B11D44AF2441B12B
45B03243AE3140AD2D49AC2953AD2056AF1C55B01552B21551AE124AAE1347AD1747AD1C
4DAB1B59A91868A51471A21572A4176AA41765A31D62A22165A01D6EA01070A2116CA413
68A7175CAA1956AA254FAB2E46AA313BAB3333AA3D2AAB4925AE4923AE4529AC442CA845
2EA54830A54B30A54E2FA64930A5482DA5492D9F4C32A35234A75634A95835A95934A755
35A65137A75138A85639A15B3C9560408A63487F65517A695D78655F785E5D7A585B7957
54775A487965448C60439B60459E5D49A54F4CA8434EA1434D9E4E49975C48915E448E5E
44845C44795C478E4D49A8414EB03D51B03755B03058B12A5CB0285FAE1F5CB02859B031
56B03456B12E58B22A5BB2295BB2245DB0255FAD2B65AB3064AA2E60A62E62A42F6AA823
75A51D7E9D1F869320858D23828D2F7E8D33748F316E962F619F3060AB2866AF1F6CB11F
71B02274B32275B22175B12371B22571B22372B22872AF2971AE2A71B02672B32674AF26
75B02577AF1F79AD237CAE297DAC2C78AA2E75A72D72AB2C72B13174B02A73AD2B72AC2A
6DB12D66B22967C02466B42468B42B65BC2669B92365B02D649E4360A44066A839659B3F
5F9D405C9D405DAC385FB42F6BB32D6EB12F70AF2E68A8366CAC2F72AE1F76B21B77B61B
77B21074B30C6DB5106CB7126EB51271B21172B50F70C00E73B70D7AB90B7EB6077DB105
7AB10877B50E84B20883B2058AA90493A30291A50193A30190A100909D008BA2008BA400
88AF027DB70C72C01A70C01B70C01F76B82478B13077AD3475AB3779AC3076B03271B533
6BB93369C02E69C02867C02667C0216CC01F74B81977B41872B51F72B92375B82071B51E
62B32559C02D53C03453C03B4EC0404CB44C4CB1544BB1544EB44558B34062AF455AA44F
579C595B976365876A7E726B9766689A6B669E6B659560627F774E789F208C9B109AA011
B09E19B2A11CB5A024A8A1339999408B9D42829B3E7D9E407D9F457F964D8A8D498B9841
909C3A999C349AA13293AB2B93B72794B81DA0B6149FA80E9AAE0B91AE0E8AB41187BA18
86BC1F87C02A8AC02A84C02B82C02F82C02F82C02482C02080C02980C02880C02384C01F
84B51F82AC1E81AF1F84AE1E83AC1784AB1582AB1480AD157EAB2077AA2071A81D70A61D
6FA71968AA1868B11A67B82563C03262BE3764B52767AD1C66A3145E9F1258A41757A318
59A71761A41461A1155E9D17579C2157A02958A3355AA2296596156B7D03676300605300
5C4D00585200575301545A09516212526110565E0C565204534A00514500514100543F00
503E004E3E004A3700493400483600493600473500433000442F003D2C003A2B00392C00
3B2D003C2F003B2F00392C00382A003427003223002D1E00251D002218001A1200160E00
1009000C0500080400030100010000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6BA12F639D2D5B9C2D5D9E2B5BA02B5A9D2F619A33699C356F9E306E9D2A619D2A5C9F2D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64A32D5DA02D5A9F2E5C9E2F659E2C669B2D6F9730749B33749E306DA12E659D2D5F9B2F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5F9B305B9D345D99326694316A962F6E932F779331799634749E3067A12C5FA02E619E30
5D9F2D5BA22555A62251A92150AD2050AE1F4FAB1E4DAD1D4BAE1949AE1E45AE2249AC24
4BAB284CAA2C47A83246A83449AA3948AA3E47A94747A74648A73D48A9394CA73251A72E
54A82955AC2355AD1D53AA1753AD1850AB1B55AD1A57AE144EAF154AB0174AAF224BAB24
4BA82647AA2C46AA383BA9472FA65425A95D22AB6321AB5F20AA5C21A95924A65723A259
239B5C239D5E27A45B28A85628AC4A26AB4627AD492AAD4E2BAC512AAA572CA95831A955
2EA1592E9B61329268398C653F8668498365527E5A5D7D5064794C577A4E497B50487E53
4C7B5B4D7B654E77624B855A47955449A14848AA454BAD4749A84949A2504B95554D9E4A
4DAC414FB23B50B13152B42755B42158B6225EB61B5EB61A5CB31E58AF2557B02559B02C
57B2325BB22D5EB02C5FAF2B5FAD2B63AB3164A93765AB3968A83467AA2969AB2474A71F
7F9E2081962480902B7D90377B8C3B779137759830769F346FA6396CAB3469B0336CB128
72B32471B42270B42473B22877B12D78B32D78B1237AB32180B2217CAF217AAD2378AD28
75A92B77AE2B75B42973C02973BE2472BE1C72B2246CAE2B6DA9356EA33868A13768AD30
65B22D68B13169B13B69AE366AA83467AE3563B2405FB4415BB43B5FBB3859C03961B72E
5CB4255EB2265FB3255BB22860AB325CA64061AD3365B2216DB31A75B21975B41775B91A
78B5267AB02D78A5337EA432829D3386A028879F2482A5257CAA2C77AF2B75B42573B618
77C00E75B70A81B2078EAF0590A5028E9F018E9C0091A0008EA6018DA70089AC008AAF00
86B1008AB10086B2037FB70A77C01577C01A77C0207EBA257DB72777B92673BA316BB83B
66B74165B54463B64664B44A64B44B64B54A62B33F62B83865C02A65C0235FC02760C024
61C0285EC0295DC02A59C03253C04052B4504EAA604DA36453AE5156AF4B5AA54C579C59
5999605A9760648D6B7A7A748D6D77926D618F6A5281765A7E8C448BA82198951E9D8B21
AB9224A7A02E9B9C3994A03D88A83A84A5428D9C408E8F48858A568889578C884E928D45
9792439A923B989D308EAA2C95B81F91C0198EC01991C01C92B81C90BB1C8BC01E8CC021
8BC02687C02B87BB2E89B62F83BA2684C01E89BB1B86BB2285C02884C02A82C02B81C024
83BB1E83B22081B01E7FAD187CAA1A80AD197FAF1A7DAD1B74AA216BAA2468AC2A6DAB33
6AA83A66AC4260B03863A02C6E8B1C707A0F706704646100635E00635F00606701567708
5388174E9120538F115D88095D8A0B5F85046476006A6E00676700646000605B00615500
5B4A00564200503E004C3D004A3C00493900473700453400473600463500423000423100
433100413300453500473300432E003B2C003A28003C28003C2C00382C00382600362900
3427003123003223003224002E1F002C1E002B1F00261C00231C001E17001A1100130B00
0B0600050300020100010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
69972D669A2D699C2D6C992B72992A749929769928759B2A76A1296DA42864A32760A127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74912D709428719928739A26759526779928739B26729A28709E286FA22969A2265FA021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799B24779A24769B27759D26749B24749C27759C27749A2C739C2E749F2D6EA32A66A225
64A11F659F1C65A01E649E225F9B28629C2B609D2D639E2A669F2866A02760A2265DA424
62A4265FA4245CA72358A92250AC214EAB204CAB264BA92D48A93249A73448A83347A733
42A92F3DA93237AB3532AC3936AB3439AC3239B23236B03135AD3138AB313DAE333AAC38
33AA482EA95727A65F24A56524A86222A85A1FA55A22A26522A16B219D6F25937725867B
28787A287676257775217879208B6F1F9D651EA167229B6E239D68249D68269E6B289C6A
2F99672D9B65309C663596653C8B633D83653D8466398E6336955C3599573A9558438E4F
45854C45884846904C489D4C49A6484BAD454CAA4548A147459B4947A7424AAB3E49B037
49B2314EB42E52B53054B42558B41F5AB51D5DB81F63B5215FB1265DB0275FB3235FB426
62B32960B3275FB12962AE2E65AA3565A83B66AA3968AD376CB13176B02784AF1C8BA61D
8AA22388992685982984972B85962F83992E82992B82972A819B2E7C9E3279A73671B034
6DB43070B62773B62278B1257BAF2A7AAF2A79AF2A7BAC227FAA237CA92A75AC2A77AD27
7AB0227AB02479B11E77B21B77B2187AB51578B6157AB8167AB5187FB51682B31980B11D
7CB52174B91C71B91D6BBD2168BB286AB1256EAE2569B02163BC2662C02E64BD3164C033
67B13267AF3A72AC3175AD2874AF1F6FB0186DB1146DB61175B81479B31B7EA72D85A42D
889A37959B3498933993942E95912A808E2A8B883392902E99912997932D8D972D839A30
888F3F7DA5406CB22D72B2167CAB0783A404869F03809F0484A20486A10188A5018CA800
8AAF0189B0058AB0078DB20590B4038CB60388BB0A80C0127ABA1979B41F75B22375B42C
6DB53665B53A5EC03F5CC04460BB4C5EBA4E5EB84B5CB64E5DB74961BB395EC02F63C01F
68C01764C0185BB32656B43A5BB54755B157509E6151975C659D4D689D4E69A455659D5C
5F995D6C8A6173736779636F835F6B956D5FA2755C887A5E77894F96992FB19122B88F23
A0933189A03F87AB3D869E428E9141A98646978A4D9283589E7E57A57754B07458AB7551
A77B4B9F953D99A23692A6338AB8288FBB2493B42995B72F95BA3291BB2F8CBD3689BD3A
86B53D89B3418AAB3A8DA83690B5298FB61A8DB4198CB1118AB81889BD1A89C01D89C023
87C02389C02086BE2085B81C84AF1D85B3207EB52977B43A759F4D768A51718D4F6D9749
6B9D3B6A9D2C69961D70850F6F7301686600615C005E4D00594C00584F005B4F005C4700
584B005E53006359016158015F58005F5500625A00675D00635900645900604D00584800
5242005140004F3D004C38004530003E2C003D2B003F2D003F2F003F2E003F2B003D2D00
402A003B29003B28003B28003B2800382800362600332400342500352800352700302000
2B1F00271E00281B002A1900251D00291F00282000231C001B1800150D000E0500060300
030100010000000000000000000000000000000000000000000000000000000000000000
000000000000010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
73A01E729D1E719E20719E21709C226F9E23719E26749B28749A29729D2D72A12B70A225
6E9F1F6C9C1D689D1C6A9F20689D27659C27699D29689E2C659E2A63A0275FA5265DA527
5EA6245CA7205AA72255AB244FAC244CAD244EAD224BAC2548AF2C49AC2E4AAA3048AB31
42A92E3CA93339AB3837AC3C3BAA3A3EA93841AC3640AB393CAA3B3AAB3839AC3C35AC43
2DA95325A75A22A66221A76422AB6622A75D21A25A219B6720976B229473278C7C278080
2B717F286C7C276A7E1F66831F7B7B1F9174209B7421987524A06B25A46725A36A25A169
2A9F642C9E622FA06234985D37925B3D8F5A408F5E3C9459379954349A5236944D3C8D4C
3F8B4C40914C42994E43A34A45AB454AAD404BAD414CAA464AA3474AA94247AD4045AF3E
48B0374AB52F4EB72951B32457B41E59B52159B5255CB52A5CB42A5AB5255EB32463B628
60B52F61B42A62AF2C64AD3564A23C659F3D65A3386BAC316EB12E7CB22287AD1B8AA820
8CA4268A9E29889A2D879D27859B2C84992D7F952C83962A84972B7E96347C9D3A75A73C
6EB1396FB52F6FB52775B22878B22875B42D77B22B79B0247AAF217AB12D76B12A76B125
78AF207DB21E7FB41A7CB3167AB21777B71777BD1477BB147AB71481BC1383BD157FB617
7CB61A79B81A77C01871B61872AE1873AE1873AE1A70B31E68B62A67B7276AB5266AB62B
6DB42B6EB02D7AAF237AB11A77B01277AF1077B01178B6157DB31E84A9238AA5298AA62B
859D33879C3A8A973D869C36819A3281963387912E8E96299197288C9D2B8D9C328E9835
90883F898B467F95477A9F3D7DA72E82AB2781AE2087AA1A84AB1984AD1182B30E82B20F
80B61084B11083B40F87B40B8DB4068AB30287B70784B90B80B8117AC01974B92071B52D
6DB43766B8385EC03D5DC0405CC04B5DC04C5BB84F59B35156B65152B64A53C03757C01F
5EC01A5BC01B54B62558B33358B64253B75251A35B569B56649B4A679750679B575E965B
61955B6C88627576697F6B6D8B6068956861A0725F887A5A808D489CA027AF9C23B19926
97A83289B23B8EB23B909F399E903FAE8446A18053987E5395774E9F754DB2764BAE764E
A47F4D9F953E97A03B8CA93787B5328DBB3293B83291B8328FBB358DBB318FB53289B33A
89AE3C88A63B8AA0388FA4368CB0268CAE188FA60D8FA30D8FAA108DB61688BC1C8AC021
8CC0248BC02387C02186B91F84B41E81B5207DB32778B13677A14277974076982E799522
7C91187A8513737A0F7472056D6A00645F005F54005C4B005B48005A48005D4B00594100
5040005645005D4C005A49005945005A48005E4F006355006153005E4E00594500514200
4F3C004F39004E3C004A37004433003F2C003F2A003A2F003A2C003C2D003C2B003F2A00
412D003C29003B28003727003928003928003825003628003629003529003425002D2100
2B1D00281D00271A00241900271C00271B00261D00221B001A1100140B000B0700050300
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
749E1E749E1E709D226E9C26709B276E9C296F9B29729A26729A2A749A2D769E2C77A026
759B21729A1E6C981E6D9A206D9A266E9626709B266D9F2866A02A5FA32A5CA72557A924
56AA2255AB1E52A91F4BAA2548AE2941AC2A48AC2246AD2346AD2746AD2A46AC2A45A928
41A92A43A92E3FA92F3BAC343DAA3540AA3745A93944A8413CA74B37A84B32A6502CA456
24A25F1EA4611DA5631DA96220AD5C20A855209F5A1C91641E8E6A1F8A7321817927767D
296E7F296B822468831E658A1D73821B8B7C1D987A21987622A17022A36B24A16F269D6D
299B6B2A9C642B9A632F955D3395593A96563F95573B965537985335974C3794473C8C49
3E8D483D954C3EA14D40A84944AB4246AB4249AD444CAC484AA84649AA4046AA4344AE47
46AF4049B32E4FB52751B21F55B31E57B42058B52956B42C58B2295AB42557B5275CB62C
5DB4345EB33161B03361AD3661A43C64A23C64A4366BAE2870B31F7DB0198AAD188AA81D
8CA5228DA12685A126859F27839E2B859E2B8798318A952F8B933482913980944077A13D
71A93C6FB0346DB12B6FB02771B02477B12977B32774B02073B02171B12670B02774AF25
79B1217AB31C7AB41A79B31775B01870BD1B75BA1A78BD177CBD1680B41581B3187EB317
74B31A75B31779B21677B21376B11472AF1670B11A6DB22869B3326BB5256AB21F6BB31D
6EB01979AD1981AD177AAF1A7AB2137DB01180B21783B11B85A72587A72790A32886A629
7C9A3D849B408697437E9A3E7D96398F93319592239295238D932791952A9F8D33A18338
A17942937555887C5B76885A699A546EAB4D6BB2496EB5416CB8336EC0276FC0226EC022
6EC02273C01E78C0197FB80F82B80A86B70585B70487B50884B50C84B8117DB71A7FB227
79B32B73B42F6BB83962C03F5DC0475CC04F5DC04E5DB85059BB4D53C0404EC0344FC026
52C02455C02558C02358B62856C03458B93F51AC4D55A04E619A4E628C585A865C568464
5D83616E78667D6F6A876C6C91656B97666296645F847759808949A29D1BAB97259D9637
90A83A87B63D89AC3D9398439A8D48AB794BA9764BA577489C7349A27145B57840B07E46
A1814C9E8E3D959A3A87AE3986B93289BA368CBA3D8CB63C8EB93F8CB43790AD3D8DAE3E
8CA8378EA3348EA13290A52E8CB32091AC148E9B0690970390A00A8EAE128BB71B8ABA23
88BC228AC02388C02489BD2285BB2081B9227CB4297AAE3279A2357A9E2A7A95187C8108
767000726A006D69006C6600656000645A00605500584D005B4700594800584800584500
553E00523F005444005445005143005545005846005A4C005E4900574000523B004F3B00
4D3B004C35004936004A33004432004030003F2A003B2B003C2B003A2A003B26003B2600
3E28003B2B003A28003824003725003827003626003627003529003326002C27002A2100
2A1B00291900251C00241900241900231B00221A001D1700151100100A00090500040000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
739C22739E22759E24759D23709F26709F25729C27789827789D29799D2A799C2B76A025
70A0226B9E20669D1E6B9D216C9B256D9A22719B2073A1226DA32066A6205EA91F5CAA1E
57AA1E52A81E52A61F4CA52548A82743A82B4AA9294EA8244DAA234DAA254AA92747A827
48A82548A82743A9273EAD2B3EAD3242AB3A49A9403EA94C30AA6229A46A24A26F219F6F
1F9C701B9D6C19A3691AAA6120AF5921A75620985C1D87651B816B1F797422747A2B6F7C
2E68812A678725658A1D5F8F1D6D871D86801D957E2099781FA0751F9E76229B7B259577
27957325946C28966D2890632C975B309B583799573798533599513696493795423A9345
3C9548409D4740A44441AB4144AB3F48AC424AAD424CAC4048AA3E46AC3945AF384AAF39
4DB1384FB42D52B42452B32056B22157B82058B12556B12759B22858B42A59B62E5BB334
5AB23A5BB2395FAF3860AB3760A63A60A03A63A0326AAA2272B01482B01289AC198CA81F
8CA6218CA52689A026859F27829F28849F298B9A2D9095328E8F3887943B83953E7C9B40
76A23E6EAD376BAE326AAF286DAF2475B22677B22275AF2275AE266FAE2870AF2B71B02A
74B22973B42775B52770B32273BD206FB61F71B52173B61F75BE1C7ABA1B7BB41F79B31F
73AF2374AF1F78B11878B31672B21972B31C6FB1226CB2296DB42C6CB72367B4216AB11C
72B01278AE0B7CAC0B7CB10F7EB51180B41A89AE208FAB1F92A21F8DA1268AA12F80A72E
7BA03B80A83D79AE3C77AA3978A23582A03188A029859F2D8799328E94329A873C997A46
957A4C887959817F5C708E5666985667A95566B25666B64A64BA4165C03368C02E6BC02C
69C02D6FC02B74C0277BC01E7DC0167FBB1282B90E7FB80A82B60B85B60C83B41282B51F
7DB7217BB32772B53666B73E5DC04A5FC0535BBE545CBF5454BA494EC0394FC03048C02C
4DC03053C0335AC0265CC02358C02E55C0374FB44454A84F6199515C845C577C64537B66
5F77686B706C776B6C806E6C8E6D69926A629362627E755B7A8A4C9AA1329D9D35909A40
89A3418CA643919A43978647A27948B26A4DB66D48B77245AA7041A56F3EB27939B18444
AA8948A49140959C3D89AD4088B23D87B23B88B1408EB3408CB6408BB1398EAF3390B533
8FB6308DB72E8BB7258DB51C8EB31395A90B949B03949602939B048FA50A8AB01189B619
87BA1E8BC0228EBD228ABD1F86BC1E85BC2184B4277DAB267FA01D85971784880A817B02
776F00716C006D6B00686300626000635A005D54005D49005A4700574500564900584500
554000523E00543E00554000524200554300544400564A005846004F3F004A3900473900
483600473400473300443500443400402F003F2B003A29003D2900392800362700352500
3622003623003A24003321003220003527003426003625003527003125002D23002A1F00
271A00281C002818002517002517001F17001F15001B1300130D000C0500060200010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
739C1D739E1E76A01F759E21729F22749F24779E25779C25799F277B9D297B9D2776A027
739F27709F276D9F246E9C256B9E246F9E22729F1F759F1E75A21E6EA31E68A51D65A81C
5DA61F59A62053A4224FA4274DA3274EA22754A4275CA42557A82252A92151AB224EAA22
4EAA224BA81F4AA91E46AC2147AD284BAC354AA4433D9A592C9B72229C761D9E731E9F6E
1EA1661AA4671BA7621BAD5E1CAE581EA45B1D91601A7E671D756F1F6E7622697C2A6780
3163852F648A2563901E5F931B6F8A1E86801E947D1E97761F997820987F23968024947A
249676219A75269A6E2899662A9A5D2B995B2D985632965433935536974E359B4A379F48
3C9E453CA44341A83E44AA3E48AD4148AD454CAD424BAB3947AC3848AF364BB3314DB432
50B43554B93051B52754B62259B5235CB81F5BB42158AF255AB22A5BB42F5BB43059B135
5BAE405EAF405EAE3E5FAB3B61A73A63A53664A72E6DAD1E7CAF1187AE108EAC188CAC1D
8BA91F89AA2084A62384A4257FA3247FA32886A02F8E98378C933D8692408391407C933D
769F4070AD3D6AB2386CB12A6EB02576AE2377B02373AF2172AF256EAF2B6FB02871B82C
74B32972B52575B12974B12872B3226FB82071B62474B71F7BBA1877B71A78B42579AF2A
73AD3374B02678B31A78B21979B51778B01979B01B7AB31B76B41C74B61D70B22070B31A
75B40F7AB20880B4097CB40B80B51783B32190A72492AA22959F23909F29869E377CA134
769E3C74B43573BE3373B53374AB3577A5347AA13479A43A7EA13D7D9C407F8C4B7F7C56
7F74587B775B7F805174934C6999546DA25570A7536DAD486AB04069B53C6AB8386DB637
6FB6396EB53876C03A77C03277C02D7AC0257AC01D7ABA137DB40D82B40B84B70F83B91B
83B71E83B32180B22475B22C66B63663C0405FC04B5DC04C5ABA4B59C03A5AC22F5BC127
5CC02960C02566C01A64C0185FC02158C03055B73F5BAD496096515D835E597D6858776D
64776D6D766D71716F77716F836F6C8D68659562627E7563778857989B37A2993A959842
9094489C8D49A77F47AA6F40AD643EBC5E44C76044CE6340B9663DAE6A3AB27735B4833D
B38D47A899409B9F3F88AA4085AB4384A54884A3428AAF3E8BB73A8FB52F8EB22793B925
91BA218FB92290B81990B21292A80B959F059596019691009492009099018C9F0589A911
88B41A8AB81F8BB9208CB91E8BBC1B8CB71B88B21F87A71A8699108789078380017D7700
776F00736A00696100676200666100645A006050005A4A00584400554600594E005B4B00
584600563F00523F00523E005442005540005741005642005644005241004D3800453200
463200443200483400453600433400412C003D28003D2A003B2D00392A00362800352800
312200332200322000301F002F1F003120002F25003125003026002F21002F20002A1E00
261B00281800251A002217001F13001C1400171200141200100C000A0500050100010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010000010100020100020100010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6FA11971A01974A11E74A11E749E1E73A12177A32179A2217AA32278A12377A12378A11F
72A11E71A121719E23729D25749D27759D26749E24769F23759E246F9C246A9F2367A124
63A1245DA62357A52752A22A55A0275BA12864A22665A5235EA82254A9204DA91E4BA91E
4BAE1F4FAE1C4AAC1945AF1C42AC2342A732409149377F66287C7F1F8D7E1B97761A9A6B
1EA2621CA96119AB6117AB611BAB621A9D671A88691A76701C7075206A7C2865802F6183
385E8B33618F2565951D65931B7A891D8D7F1E937A218F77218D7A1F8A7F228D8124947A
229775259C76279E742B9D692D98642D965F2B945D2B8F5C2E8D5F2E93602F9E5834A44D
38A4453CA54041AB3A47AB3A4CAC3F4BAC474EAD3F4CAC374CAE384DB2344EB63152BB31
53BD3255BA2A57B9235AB91E5DBA1D60BB1C60BB1D5FB32160B52862B42D62B6345BB13B
5CAD405AA8445DAA4262AA3F64A63B65A93364AD2B6EB01D7DB2128CAC128AAB1886AB1C
83A92185A92083A52080A3237EA0267FA32A87A12D8E9A349297398C903F838C407C8F40
75964674A64371AD3C70AE3070AD2D75AB2B7BAC2C7CAA2B74AA2A6FAD2B6CAF2C6EAD2A
71AF2573B22178B22476B12776B22775B42573B82477B61B79B81876BD1874B51F77B323
79B1247BAF1974B41475B21176B11576B11775B11873B21974B31A74B21B6FB11A72B311
77B40F7CB60B7FB6127DB21B8BAC2096A91F92A62490A62291A32789A33081A23B7CA837
74AD3571BA2F70C03075B53274AE3479A8347B9E38779D40779D49719D4E6D9A576E8D5C
6F835B70885576914D70A4446CA54868A94B6EAF4A6DB2406CB63569B93364C03168C035
6AC03C6FC0406FC03C6FC03570C03374BD2E75C02779BB207DB81483B81082B50D87B510
84B61880B71F7DB61F78B2206FB62367BB3161C0405FC0465CBA4761C03D66C03764C031
63C02F65C02066C0156AB81163B9185EC0235BB73C5DAE4B6091525F81605C7C675A7C71
637E6E697C726F717671667C776877876A7194636A7D766A738C5F90A1389AA531979D3D
949845A58C47AE7B43B36C3CB65F40C66344C26549C4604BB3663EB16D37B57337B27E44
AB8D4F9B9D4091A43E89A044889C45849949839F4886AA3A86B82D8BBA2191B21493AE10
93AE0F96A50E95A60C95A20B929E04949D01969200938F00939300939500949502919B09
8EA20F8DA7138EAC128DAC118FAA0E94A60E94A30D919E0C899106888602827E01817700
7972007568006D5E006A5F00686000635C006355005E4C00594C00574C005A4E005A4D00
594C00564A005342004E3F00563F005344005341005642005847005445004C3E00483400
4532004431004534004537004135004030003C2700382400352700392500382800382800
3325003323003323002F1F002B1C002D1B002B1F002F1F003020002F22002E22002A1E00
271C002319002316001D14001A1200171100130B00100A000B0900080400030100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6BA2196E9E19759B1B7A9C1F7A9C1F789E1F77A01F7DA1217CA1207BA21D79A31E76A21D
72A31C77A11E779F237C9C257B9C2B799D2A779B2A769A27769B27719B266C9F266CA228
6AA32768A32663A22862A02962A02866A1256BA2216AA41F66A81C5EAA195CA91852AA1A
4FAC184EAD174BAD1842AC1C3AA92630A03C317960315E7B275E8A1D7D821A92781A966A
18A26219AA6115AC6315A76A18A36E1A93731D80731F6E75226B7A26667F2D6183375C85
41588A3A5E8E2C6490216C901F83871F947E1F947E21877A22827B237D82228382249279
249B7224A07428A37629A2722A9A6E299664299160278E642B90692A9B6A2CA55B2EA84C
35A94039AC3940AE3148B1304FB0344FAF3B4FAC384FAE354EB03452B33554B63255B92E
57B92A59BA245FB71D62B71963B61A64BA1C62B8215DB5205FB52760B73062B7375FAF40
5CA6455AA1485BA54A60A74462A94062AD356AB32573B51A7EB11382B01382B31581B218
82B01B83B21886AB1A83A91C83AC2082AB2489AA268CA6298B9E3187943C818943778B49
74944B709E4A6EAA406CB0376DAF2F72AE3070B02F75AF2A76AE2C71AF2B6BAD2C6BAF27
6EB12274B41D76B41E77B22573B3286FC02774C0227BBB1A7BBE1778B41876B21E7CB41B
7CB3197DB4137BB20B76B20E72B01570B21A70B01C70B11B72AF1B72AE1D74B41475B710
78B3107DB41583B22080AA2A94A32898A124949E298BA42B8BA32F83A73580A5377AB233
73B53575BE2E73BE307AB33179AB317FA5327E9B407498456F96516AA1576AA45566A856
64A85468A64E6AAA466EB43F6CB64169B7456BB8426BB5396AC0336BC02E6BC02D6DC02E
71C02E72C02C6DC02D6EC02E70C02F75C02E76C02D7BC02979C0207FB91782B41386B510
85B4137DC01A7AC01C7DB7237BB82575B72C68C03165C03E64C04568C04268C04069C03A
6DBB3069C02769C01A6AB91269B91266B91B61B8355FAF4962945563845D647C6B627C70
60806C667C6D6D6B786F657D7E647E87657790647478766B6C8E6188A0399B9D36A0993D
A19B43A58D3EAD7941B86E39C36A40CE653EBF6A47BE644EAE6E39B77133C2703EB17D4B
A08D548FA1428CA1418F94468F95458B9F4283A93D89AD2D8CB21F8FB01494A90D939C01
949900959400939500939500939500919400929400939100959100919400919000939400
9098028D9B078A9E088C9A088F9A039597009298008D9500898D00838800857F00827B00
807500776E007167006B61006C5E00665E006656005F55005B4F005B4D00594E005B4E00
564E005A4B005545005342005641005742005545005541005643005245004E3B004A3600
4A36004736004531004530004231004131003A29003A2400382300382400362800382600
3827003327002F21002B1F002C1E002B1D002C1D002D1C002D21002D1E002C1D00271A00
2318002116002115001D15001A1000160D00100A000C0600090400050200020100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
75A31B76A21A78A01C7AA11E7DA01F7AA01D7BA11D7DA01C7EA51C7AA51879A51A77A51E
77A51C79A21F7C9F1F7E9B267B9A2A799A2A799929789C28769A29759A25759E29749E29
759C2C739B2D719D2F6E992D709C2A709F27729C256E9E206DA21D69A51969A71961A719
55AC1B4EAD1F48AB2A42A93239A13E2F944F2F7E6729737623727D228D701C9C6A17A263
14A76112AC6611AA6B13A272179A761C8B741E79722769762C677A2F6483355F843E5B89
45558A3E5E8C2E688C216E8C1F85891E92871E9285208180247D80247984257D81268E75
259B6F22A07024A27427A1762B9B78299A672A945E2A955F2C9B622DA45E2AAB522DAD46
34AD3C38AE3240B0294BB02851B22C51B13350B03851AF3751B13553B13C56B23A59B433
57B9245CB71E61B41B65B41A63B81E62B82061B6265FB3285FB32C60B53461B13C5FAA40
5AA044599D475BA1475DA74162AD3B6AB12971B61C7AB61180B30F7FB5107FB7127EB813
80B31482B31287B31282B51283B51483B41787B41988B31D85B12180A62C789E3F749745
739747719C456CA44069AD3B67B0386DB03270B02C71B02773AF236DAF236BB12465B223
6BB41F6FB31D72B61E75B52276B42278C01E7AB81B7DB5167CB6137AB41875B21E78B618
7AB5127FB40F7BB30C75B01273B01C6DAF1F66B3216DB01C71AC1C77AC1A75B11778AD1D
7BAB2287AB228EA8288EA52B96A025939F27919E2A8BA22E87A23580A83382AA3576B432
76BE3176BC2C77BC3075B42F74A8317C9F3D7F98467194476D974C6AAA4E6BB04B67B34B
63B54765B74365B73F68C03769C03C62B74064B93B66C03265C02D6AC0276EC02572C025
71C1266FC2266AC02869BF2D6DC03070C03071C03473C02E77C02B7ABD1D7CB61682B312
85B30E7BB81378B9187CBA207EB6227AB12971B52A6CC03368C0416BC03F6BB84A6BBA43
6CBA3A6AC0316BC0226DB71767BA1363B91E64C03A5DB4505E955C627F626C786D6A7571
66756F69716F6B647773627E7F658281657C8061756E776F61956183A739949F33999A3E
9C9847A58B40AE8339B77734C27433C97036C46D3CC3674AB16A3FB06E36B47539AD7E44
A6884F9997489096488C924A86A34684B23984B62789B3198BAC108FA70A93A103939800
939300948E009A95009896009296009290009290008F8F008F8E008E93009291008F9100
9293018C92028D8F028F90029190019293009192008B9500868D00878400867D00837C00
8178007A7300766E006F6B00706A006D64006A6200685D006059006052005D50005B4F00
5B50005B4E005A4C00574200514400554000554100513E004E3D004E3B00503D004F3D00
4E3800493400432F004635004332004030003A2900392600332400322500332300332400
3523003125002B1F002A1F00301F002F1D002B1E002C1E002C1F002A1D00281B00271900
2518002015001C11001E1000171000100D000E0800090500050300020000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
80A11D7FA21C7DA11D7BA01F7EA020819F21809F227DA01D7AA31A78A51979A51A7AA122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73A2107EA3197FA119819F1A869E1D869A1E859E2083A01F7DA21C7CA31C7DA3207EA127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6EA50C78A3167BA21884A01A859C1D859C1D84A01D84A11C7FA21B7DA11E79A0207CA124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6CA50670A71576A5187BA1197DA11B7FA11981A41A7FA41980A41A82A21C7EA11D7CA11C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669E066BA2126FA11673A21974A41976A51678A7187BAA187FA81880A21880A4177EA018
7AA1177AA41778A41577A8177AA7177DA5177CA5177BA6167AA5177CA6197EA81680A516
82A41782A3187FA6197DA31B7FA31B7BA41B77A51C6EA71960AC1656AE134FAE1049AD11
44AD1C41B02C34AC43299F601D8D751D7E8017838912838B119B7B14A77315AC7617AC7A
19AE7A17AF7E1AA78018968016827F157C7D17747E1A6C7D1F687B266380286085285D8B
27519529419D2833A22531A72344A41E55A41D65A121699A2071971C79971E83911B8F8A
1A95891E958A229188218A861D88811E8C7B1F9A761EA47123A96724AF5827B34A2EB440
32B23738B22F3DB52A43B62B4AB82E4FBA304FBB2E4EB72D4FB72A54B5275DB11F60B120
5EAE265BAF315AB13159B2355AB3405BAE4C5BA94D5CA44B5FA64C60A94A62AB4362AB3D
61B02F66B51F68BC1767BE1267BE1269B8126EBE146CBB2069C02466C02E69B9316FB333
81AF2290A51E989E219BA220A0A221A4A020A6A01CA9A517AAA518A7A217A7A018A99B1E
A49E1EA1A51F94A61E85AD2472AF336CAC3C6BAE3370B12473B32172C01D73B71B77B71B
78B61B7BB71C78B51D72C01E6AC01C65C01B6CB61A6EB61572B71474B81771B81871B81B
74B2207AAD287FA9337AA62F77A73171AB2973AD277CA7257AA42182A0227EA120899B26
8798208B93218F952B8E9530869637829C318597327E9E3677A33675B32F77C02A77C01E
74C11876C01879C0197AC01C77C02574C02E70C0306CC02F6BB72E71C02E74C0326FC031
67C03569BB3569BA3268C0256EB82273B8246EB82D71C0286DC02472C01B74C21774C315
71C41672C31571C31571C1196EC01F6FC0256CC02B67C02A61C12C64C02D67C03873C02D
76C02583C01589B71190B1098DB20989B40C83B5137CAC227CB41E77B62A6CB83269B243
65AC5564BA4067C02C67C0226CC0226EC0336BB74466A94F63965D5F94645F90655F7E6F
6C6B727064777067786F6D777373746A7A7063816869A05A75B5478EA831AD9135BC7F38
C2723DC9713BCA693CC66F45B37049A6714F98773EBD763DAD8843A88F509D984D8CA43D
88AC2991AF1894A10D949201968F00938E00918900938C00958E00958D00969000969300
969600959500999500989700989600989000969000909000939600959300948C00918800
8C8A008B90008993008C9600899200918F008D8B008B88008A8900888D00848C00838600
8086007C7F00777B00797C00777B00757600717300716E007069006D68006D65006B6400
696200686100645D006155005C5000584B005549005949005443005241005141004F3E00
493800463700413500413100412E003F2F003F2E003D2D00392A00342600322700302500
3024002F23002C20002A2000291F00281E00271C002417002116001F19001E1500190E00
150B001008000A0700050400030200020100010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
659B05639C066AA2136EA61577A51876A81679A8157EA81683A51884A21783A21681A317
7BA41579A71676A61975A71974A31A7AA31D79A41B78A51576A51479A6157DA81584A316
87A11985A01B82A11D7CA41F78A41E73A71974AA176DAC1561AF1254B00E4FAB0B4CA90D
48AB1443AC2836A5462A965B1F8A6B1C7E7D148390128790109A8514A47F16A97A17AC7A
16AB7B18AD8015A383168B831671841174810E767F0E777C14737E186F801B6B851E648A
215194253D9D2633A12534A223489C22599A1F6A9A2471952079951C81961D88941A8B90
188F8E21918C2492862290852091801D957D1EA0771FA57320A96823AF5727B44C2BB645
33B54039B73141B82A47B62B4DBE2F52C02F55BA2B58B62859B6275BB12260B0215EAE26
5CAE2D5BAD375BAF405BB14259B24559AE4759A84B5DA34A5EA44961A64661AC4163B136
63B52366B7166AB7106AB6126FB31570B31670B11671B41871B61A70B5206FB3296FB22A
7EAE1C90AA1097A2129BA1169DA1199DA0199E9E18A39D1CA89D1DA6991FA39225A28F2D
9C99299A9C25939C2882A32873A63467A04368AB3C6FAF3371AF3073B12974B22471B223
74B1207AB11F7AB01E7AB11C6FB11974B11975AF197AAE167EAD167BB01378B11378B116
7DB01981AC1D80AC2480A9237BA82675A82372A92170A91F76A41F7BA6217BA51E7BA21F
7D9A23829527869331879C307D9E367C9D337B953874A23A72A93872B72D6DC02470C01D
72C01977C01578C01477C01874C01F75C02671C02C70C0286EC02770C0276FC02F6DC02A
6AC02A6CB8296BB42970BA2671B62D75B22871B52574B92A73C02B79C01C77C01476C014
71C31574C21572C41774C61972C12072C0206CC2216BC02967C2306AC02E69C23671C036
71C03879C0247EB61688B40D89AF0989B30A85B3157EB3217EB81E78B42373BA2571B138
69AF5066B84367BB3369C02B6DC02A6CC03567B44963A2566492616A8B6775846972796C
766971786872786E777473776C7372647D6C5F8C6767A75476B8448CA8309E932EAB8132
BC7633C07135C56B37C97439B8703FA06C49A87241B97345AB8949978E4A8A954884AA23
8FAB11989B09969403959100948B00938F00938F00938E00928F00918C00948F00959300
9395009693009690009891009892009A8F00978D00959000959100948E008D8E008C8900
878D00858F008793008592008692008A91008E8A008B8600888600868B00818B00818600
8082007B8100767D00737C00717B007278007178007474007370006F6C006C6A006A6400
6B67006D6600696300645C005F56005D54005B5100595100584D00584B00574700504300
4D3D00483C004339004637004233004230004135003D2D00392D00382700352600342500
3425002E22002D1E002A1E002B1A00281B002518001F17001F12001E13001D1300171000
120B000E0500070300020100010100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
669803699C066DA50E70A5107EA8177FA91681A71586A81788A61889A21987A21884A31A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6D97016E9A0372A10875A10975A20B7EA51480A4168BA41A8BA31A8C9F1A8C9F1A879F18
82A21681A7177EA61C7DA3207BA11E7CA01E839D1A859C158B9C178D9F18869F1B849F1F
7DA21F7BA31D76A51D79A72276A91A73A80D6FA8086AA70860A60858A70A52A4094DA60D
45AA193BA23A298E5C24796E206C7A1C73811A868B17988A12A08D139F9114A19413A296
15A38A14A08116957A17837616727C16897D1799791CA1701C9A751D92811E878C1E7491
1E54971D49992051971F609523668C236E8A26708C247D8D22898B20908D1F8A8F217F8F
207F8C24878A288D87279384239C8521A47E1FA9771FAD7024AE6727AD6029B05631B149
39B44446B43453B52458B41F57B7205AB51F5AB42059B0255DAD275FAD2F5AAD3359AE38
5BAD3D5BA9415CA5475BA3455DA34361A33F63A2376AA03867AD335CB22958B62758B622
58B61C5DB7195FB51B63B42162B32564B52365B61D65B61966B21D64B11F63B12964B234
6EB1287BAE1587AD1598A9169DA8169BA9199CA718A0A31CA29D1EA2931C9F911DA5931F
9C901D9A941E9D9A21979B1C85A2237AAB3275AF2B76AD2378AD207DAC1B76AE2071B022
72B31E71B11C6FB01774B1147CAF137FAF1581AF1384AD1287AE1280AE137FAB147EAB13
78A8147FA91A7FA92081AA1E81A9217AA82174A72077A6247BA82681A8257FA12D87A12B
8A9A2E829934749B3B709F376F98386BA03564A13769B0346CBA2A6BC0216CC41C74C018
78C0177AC01B77C02175C02175C02178C0257AC0297CC0267BB2277AC02276B72771B62B
6EBC2F74B52A76B12A72B32E72B33073B82474B92175C01A76C0147BC0127EC0137BC014
75C11475C31571C41573C31672C21872C1176FC1196DC0236CC02D71C02D6CC2336DC130
6DC0376DC02B72C0207DB81387B00A8CAF058BB40B82B71882B81C7CB5247BBA1D76B32D
6DAE3E72AA466DB14966C04065C33D6ABA4368A7576B995F708E60758D5E79925E778E5D
7B855E817E627D776B74746B6B706E647C6A5E91686CAB5387AD3EA092359A8B3E9B8544
9B8642A97936B6722AB9752DB97439B47240B27A48B48150A396498EA53E81A81C8F9F0F
919600939200988C00978D00988F00968E00948D00948C008E8C008D87008D82008C8200
8F85009087009185008F84009186009089008D88008B86008A8900848500827E00807D00
7F8300808000818500848A007D84007D84007E81008083007F83007F8500858600828600
787F007278006F72006D6F006A75006D77006D76006E71006D6D006A6B006A6B00686800
686B006869006766006A67006A6A006B66006660005F5A005F58006054005E55005E5400
5D54005C4F00574A00504400493C00463C00463900463A004434003B2F00382700352800
3526003426002E2100291D00291A002519002216001A0F00160E00150C001109000F0800
0B0400020100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
749900729901789E0677A107799E0878A50C7AA1108A9F1A8CA018909B178E9D1888A014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7594007A9700789A00789D00779C00779F09799E097C9B0B8C9D158E99178E9A17879C16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759403769701779900789D00769F00739E00749E06799D077CA10F7E9F11879F1886A118
8B9E178B9F168AA2188E9D1A8F9B169096158A97168C9F178BA41787A3147FA5157EAA12
7AAB0D77A90973A409759D097998077996066F990964A10B57A4134AA52143A22B42A52E
3EAB3035AC382CAE4224AE4E20AB511CAB531AAA5416A95915A36916A17C14A68B14AB8F
15A79214A094179C8A19A07F1FA37A1DA57A1DAA7C20A77F23A08421918C1F8492217897
256A99285B9A266098206D94207B8F22848F248D9223929223939725949725949527928E
298F862A92852B97872B9F8229A87F29AE692BB2592EB44F31B34D36B04C39B0413FB529
4AB51D56B41C5FB3245FB22B61B02E62AE2F61AC3160AA345FAE3F5CAC4257A9495AA848
5DA7415EA43B5FA43566A82E67B0225FB31D5BB61E5EB91B5FC01861BB1764B91C5FB923
5CB82D5FB5305BB63358B73953B63C51B53951B43750B3394CB53C52B33B52B63B58B33F
5DB03868AE237AAC188FA7169EA417A69D19A7981DA79C21A39D1CA69D1AA49A1DA1951B
9D901EA1961BA3971D9D911C939B1A85A81D7AAD2174AD1F71AD1B76AA1C7BA91D84A41D
84A71F7FAE1C78B01977AD1880A8197DA80F87A71287AA1784A8167FA61780A51B8EA71C
85A31A80A2257CA9267EAA1F78A82373AA257C9C24819C2A7CA53481A52C83A22780A228
76A53175AA2F72AE2F70B22B70B32770C01D6DC0186EC01473C0117AC00F7BC01179C014
7BC01274C00D74C00D75C00E7AC00E7BC00D7BC00E83C00F7AC0137CB91479B8127AB714
7FC01981C0147EBA167EC0157DC01380C00F7EC00E82C00F83C00F84C00F83BA1085C011
81C0117DC01375C01772C01467C21663C02162C42C67C62D6AC5316EC62C6BC52A70C22E
70C03372C22F72C02974C0187BC0118AB60A90B3018EB6048FB80A88B8117EC01578BB22
71BD2970B5386CB54470AF4B709B52789554808F566E8B5869805D687B5E65755F6E7A5E
807E587E865D7E8A6170905B6B945872974D819940989239A68531B1791FB77C1ABD771A
C96915D26328D65A3EB7603DAA623EA66D4B9E7C4E8D8E4785B0278DA711929503969100
969300959400928D008D87009085009085008F86009088008E88008E82008B8200857E00
857A00847900837800847C00837C00847E00887F008682008A83008A8100867E00877B00
827E007F7F007F7C007F78008073007B7200786F007169006C5F006E5E006E5F00686000
6A67006A6700666500656100605E005A5A005B5D005D5D005C5F00606200616200636600
636700636500616100645E006863006A66006A69006865006465006562006160005D5900
5C57005D58005A5800585300514B004F47004B4600493E004339003F3400362E00322500
2E22002C1F00271E002518001C14001A0D00120C000F0B000D0800090600070400030100
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
749600749B01719C00729F0071A000729E00729E0073A00073A40A75A20A77A10A7FA413
83A41282A71283A71285A015909B198F9B188B9C1A86A31683A5157CA6117BA70D7BAA0C
76A80873A70772A30775A007759D03749E046DA2086AA50A5FA70D51A71848A52244A72B
3DA93035AB372CAC4324A64E20A4531AA25618A55317A6521AA35C189E6F19A37F17A587
16A48B16A08E189C8A1DA27E1DA6771EA9791CA9801EA8851EA089208E8F208493237E93
2479972A7096277391217E8D20848C23888E228E912190911F929222928E24938827947F
28947C27997D2B9D7B2BA47829A9732AAF622EB45631B64935B54039B43F3FB5364AB728
55B6225AB4265CB3345BB13B5EAF3862AF3661AC355FAC395EAB405DA8485BA5485DA845
61AA3B62AD3164AE2765AF2161B4175CB4175CB5175FBA1962BF1E64B82162B6265FB727
5BB42D57B43055B73156B73552BF3351B63A50B63B4EB6394FB73753B63950B53D55B342
5BB33F64AF267FAA188FA6159CA116A59F1CAC9720AF9121A89718A79B18AB921BA88E1A
A38D1BA7901CAB8D1CA3941D999A1C87A31C79AA1E75AB1E73AC1974AC167CA81984A41C
83A61C7BAB1776AC1577AD1880AC177FA90F7DA70F80AA1C80A81B79A51A7CA91A8AAA1C
7EA41F77A62776AA2579A72177A4267B9F267B94267B952C819F3383A52C87A0217CA02C
769D3573AA3372AF2E71B52970BE2572C01F72C01874C01576C0127AC00E7AC01076C011
77C01179C0107AC00F79C00F81C00D7FC00D7FC10D81C00D82BC1083BB107DBA107DB810
7CC0117DC0127DC0157AC0127DC0127FC00F80C00D85C00C80BA0C7FBA0F7CC01184B80C
82C00C7FC01274C0156BC01762C01962C02064C22A68C22668C52F67C12E63C13168C036
6BC0446CC0366EC02E74C0207CC0148EB80A93B00093B1008EB90683B9097AC01170C020
6FC0296DB6376DB44572AA506F9B5871975B7396586F9851739351758B54728058778455
798956788B5A73945A65AC4F66B6497DB137929C34A28438A87D3BAC7B389E8234A37E2F
BC7316C96922D46335B65F42AA634DA9704F9782537E9B4284AB1A8D9F079195018F9400
8E9500909600919000918E008F87008B8000887F008D82008B84008C83008C7F008B8000
8C7F008A7C00897B00877B00867800847C00897F008883008D81008B8200887D00847D00
8579008279008375007E6F00826D007C6C00756A007165006B61006B5C006B59006D5C00
6E63006C65006869006666006260005F5B005B5C005C5A005D5C005B5C005C59005D6000
6363005F6500615E005F5900625A00635E00656100636100656300646000625D005E5A00
5B55005A56005B5700545100514A004E44004A41004940004339003D3600392E00332800
2D22002B1D00261B002419001A1100130A000E07000B0500060300040200030100010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
709A006F9D016D9D006C9D0072A000749F0076A100769F0074A00077A40778A4087CA809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719900719C006D9F006E9D0075A00077A00077A50073A50076A20079A30077A10076A406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779300749500729A00719B00769F0179A30176A60175A40076A30078A20077A00071A300
70A60271A60275A50779A1077AA30778A50778A50779A7077BA40778A30876A00874A00A
719E0C6F9E0B72990C739A0B749C0C789B087A9B07799B02719E03629F0A58A1134EA325
46A5333FA53932A2442A9653268C63248269268A6B25906525926424916623956B1F986D
20976C1F976E1E98751A9B7F199B8A199B8D18998D199A90199A941A9B9A1B9C9D1B9B9B
1D9A971D9D8E1E9F87209D8421968622948A1E948E1C978C1E9D8524A07D269F702A9C66
299F6827A36B26A46A28A46628A9602CAE5B31B35237B6413BB63743B6304DB52754B02A
58AE355AAC3E5CAB3F5FAC4164AD4068AC3C63AB3867AD3366AD2E66B22565B11D64B216
65B61167BD1164B71360B51563B21B60B21E62B22661B1295DB42F57B43450B33A46B241
45B34544B34845B74148B93D49B33E4BB2414BAF474BAF4947AF4B44B24F45B35849B253
50AD4C58AC336BAF1C88A814999D109D9518A29312A8940F9F901C9E8E1DA89016A2881A
A18222A68A23A99022B5831EAC8C19989B1988A52186A7237DAB1F7AAD1F80AB2687A725
829E22819A23809D2572A02576A52781A71F85A61B839D1D81A11E85A21C80A11877A220
7CA5217DA21E7BA51E78A72277A72178A7217AA82B81A62989A52776A73267AA3662B433
65BA316EC03076C02474BF1A74BA1778BC187BC01782C0137FC0177FC0197FC01780C016
7CC0157CC01782C01983C01C81B81C81B81B83B81887C01184C00C82C00B81C00C80C00F
7EC0117FB91384B91487BA1184BC0D83BC0C81BA0D83BA0F7FC0107EBD0E7CC00D7CBB14
78C0187AC01676C01572C21C6AC32A68C12164C02165C0225FC02960C02560C02962C130
65C13769C32D6AC12972C01E75C01D82C00C8CBA0297B60396B70A94BC0A90C01485C11F
7FC12076C02E71B8396DAE426BB03F66B83863B83A6AAD4073A5457D9D447AA0446FA63D
69B1336EB72975B22C7DAE307FA23A8B9443928644AB7D31B47C2FB77827BF6C34C06041
B35747AF634AB76F4BB66B4EB36953A27E4C8F973585A11691950B8D89008883008A8000
9081008D81008C87008C86008B86008D82008C81008881008B84008C82008A83008A8400
948B00928A009189008D84008B7B00867700837300847000816F00837400857800837600
7E75007C7200796D00766C00706700746600776800766D00766D00726C00716800736900
7367007366006E60006B5700665800655A006864006967006A6A006B6A006B68006B7200
6C6E006968006463005F5F005A59005A5B005B5C005C5800585800575600515300514F00
4D4A004D4A004F48004D4B004C46004A4500454300403B003C35003A32003830002F2800
271E001B1600160D000E0900070300010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
769301759200749700739801759E03789D01799F01789E00799F0079A10076A10076A000
75A200779F007D9B007D98007D9A007EA0007EA2027BA3087AA20977A10973A009759F09
719F0A719A0A729708729D08759E0779A00877A008789E08729D0A6B9D0C609E12569F1E
4FA32B47A73638A0452E91552A856729786D267A6F267F6D27846D258870268F74229678
239A75239A7821997D1D9A81199F8719A28618A086189C8816958E179397189399189398
1A93931C939020948D21978C1F938F1E90941D91971D97961D9E8D21A38124A274299F6B
289E6827A16D27A26929A36729A85E2EAD5C34B4523DB74241B53947B33151B02B59A631
5CA43C5EA74362AB4467AC3D69A93767AC2E67B12C69B3276EB41C6CB51869B61367B611
68B71269B71767B61C63B22161AE255DAD285CAB305AAD3756B03A4CB53E46B64141B442
41B44742B74645C03E45C03B49B73D48B44348B34D44B25141B15441B45744B3594BB24B
54AE3F5BAD2F66AB2386A415999C129D90209A9011A88E10A08622A68923A99118A1871F
A87E2AA98822AB8F22B38820A28E198F981E89A22384A91D77AB1B76B01D81AD2280AA22
819F2E829E2C829F237A9D2A7E9D2A84A321849F1E859A24879A21889D1B799F1D72A527
7FA12388A01D7F9D247CA12778A21F82A32585A3238CA4208CA1227BA42D6EA93267B230
6BBA2E6EC02974C02273B91C75C01875C0177AC0197EC0167FC01A7CC01880C0147FC013
80C01181C01781C01F80C01780C0177EBA1582B51185B90F84C00C82C00D7DC0107DBB19
7EB6177FB71487B91384BC1183BD1082B80F81B90E81BE107AC01177C01174C11273C017
73C01F73C21771C21770C3206CC22F69C12263C02162C0255EC02D65C12865C12868C22D
64C3386CC02E70C02374C11874C0117EBD0A8BBE0898BB0B95C00C91C1188CC01E87C01D
83C21B7BC51D71C32A6EBA3B69C03768C03268C03069C0316CC02B71B82475B92574B727
70B22B6EAF2E71AF3379AA3280A03C8C983D978D42B27E3FB4793BB3772FB96F2DC05D39
BA5450B3595EAF6664A8695BA16C558D815389962C88920E8B89028B82008B7C008B8000
8C83008E81008B7B008A7C00897E008B7D008A7C008A7E008C7E008980008B83008A8300
8E83008E84008F84009184008D81008B7C008A7900827200816B007E6C008273007E7500
7B7000796C00786D00766E00736C00756900786C00756B00756E00746800746A00776C00
756E00766F007163006B5B00655700675400675A006760006766006969006B6D006D7400
6F71006E6E006A6C00686700616700606600626200615E00605C005A5600594F00564D00
524900504A004D49004B47004A4800494700454100423A003D3500382F00322B002B2200
211900190F001209000A0400030000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7199036F9801709901739A02749A02759A01799A007C9B007A9B00799D00789F00789C00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749901729901729C01729C02769B02799C017797007A9A007A98007999007C9F007C9C00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6F9B006F9C00709D01729F01749F01769C00789B00779900789A00799B00789E007A9C00
7A9B007D9900809800829B007E9D027EA2077FA0097EA00A7BA70D78A50A77A009769E0A
76A00979A30A79A10B76A20A76A10973A20976A10A75A008709D076C9B076A9F0862A10C
57A3194A9F2D44A03B41A4453CA14F379362347C79396786355E8533637D2A717E237E83
22838123817F257D7E24847F2191811DA08320A484239D82259784238F8922888D208790
238A8C238A8B2288902087961F8899208A97208C92219390239A8A249F8427A07E29A077
289D6F2E9F6D30A26B31A86236AA573BAE434BB23356B22960B31C70B11573AE1474AE15
76B10F7CB10F7EAF0F78B10F72B3106BB51467B61C65B52463B2255FB2255FB2295CB22D
5CB23058AF3356AB3554A83255A6334FA9374CAD3F4DAA434CAC4045AF4042B54242B843
44B84343B74040B54440B64240BC413CB83F3CC0483BB5533FB55D3AB4583FB34A44B43F
4AB23852AF3663B03081A823929D189C8F1EA48A1DA68718A081229C811F98891AA2871E
AE8420998C199B8F1DAC8B12978B1590891E8499168EA0168E9B228C991A80A32584A220
8C9F1B7EA81C7DA82C89A3238B9E1E9096269298208B9820859D2087A11F7BA22180A026
7E9F297EA2227AA0207CA02286A02488A01F899B277FA6297EA5317BAF3377B62877B927
78B82774B92575B72774C02479BD2279BE237AC02179C02377C02179C01F7CBC1B81C017
82C0197FC0147FC0117FC00C83C00A81BE0C81BD107EBB127BBC137CC0157BC0177BC017
7DB91980C01B81C01F81BA2180B9217DBC177CC01580BC147FC0157CC01874C01D77C021
73C02973C0246EC01E70C0196EC01571C0156CC11567C21867C31C69C3196DC01B6CC11E
6BC0216EC0206FC0266FC41D74C3167DC6187FC31C88C02884C33082C7307EC72A84C725
85C92384C52280C1237FC51C7DC91B7EC6187FC3187CC3197BC11B7CC02079C02776BC2E
74B03378A9357FA33A889E3B899340919142998A43A0823CAE7835C06C389D6F49887958
A0784BB4704EAB6862A07164947D59809A36819218847E06817400847400887A008C7F00
8D82008981008A7B00847800897A008B7E008B7E008C80008A81008C80008B7E008E8300
8F83008D7F008D7C00877800857D00847B00827A00828000817E00817A00827400817000
837400837A00817500817900837B00867D00857F00837E007B7C007B7D007A7C007A7500
777000716C006D6B006C67006B6200686000635C005959005753005C5500635F006C6700
6C6F006C74006D76006C78006E78006D78006F77006E73006A6C006B6B006B6D00686900
6260005C5B005A5400544D004C4600494200444200433D00383300302800241B00181200
130A000B0700060300020100010100010000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
699F03699E026B9F026EA1016AA0006DA200719E00739D00769E00729D00759F00789E00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63A30268A30668A1066AA0026BA1006CA3006EA40173A00075A100729F00749A0077A000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66A3036BA3066EA30772A2036FA00070A10173A10178A100789F01769F00789C0076A100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6F9E0171A10574A104749B01739C01749E0179A10179A101769F01769D01739B00719E00
72A10174A0027B9B037B99037C9B087C9E0A7CA40D7BA41176A21077A10C75A00A769E0B
759F0B76A10D75A10D74A40E73A20C73A30C76A30C79A00C79A10B7AA20B76A10971A308
66A50B5EA91255AA1A4DAC2149AC2342AD283AA93336A04239924A448B504B825E4E7E6A
4E7C714A78734478703F71723E70703C716F3A776934806731866430846632806B367B6F
39757237727735757B347A84307E89307F8C317E8C2F808731828130897B2F907432976E
399F6044A84B49AB3253AE215FAE136BB00C72B10871B20771B2066DB20B61B3125CB41C
59B42A59B33753B2424DB2444BAF4249AE3E48B13B48AD374DAB3250A93755A93C57A93C
57AB3A57AA3A53AD3E4DB13F4DB23C47B33A46B33C45B34043B3473FB34C3BB24B39B24D
3CB2513CB14D3AB04D3BB14A40AD483FAF483BB45633B16034B16138AE5A40AF5043B046
4AAD3E55AC356BAD2583A7279F9A1FAC9515A3921FA68B23A58C20A58D1DAE8A18A98A19
A38927A68C21A9921EB18923A58C159F961C989B1F9C9E19989C1990A11287A71D85AA1A
8BA80E92A21D93A11B87A11E8DA0209F9A139999179F8E26968F22918C238094247E9D24
8E95199293259E8C399B8A39A0833D95983E92A63684B9287AC02176C01D79C01C7BC01D
7DC0237AC02479C02079C01E76C02279C01F7CC01D7CC01E7CC01C7AC0177DC01084C00C
86BD0C86BC0C82C01086C01188C01183C20E84C10D81C20E82C21380C01C7EBB2278B821
76B82076B72475B72772BA2774C02675C02275C02277C12675C52771C3296DC12B6BC027
6DBB2574C01E78C01D74C01D6DC0226FC01C6EC01F6DC0136CC20D6FC10D70C11070C313
71C41871C41B71C72172C9216EC52978C32079C21C7FC21B79C11B7BC2157AC2167CC11F
7BC52D7CC31F7FC31983C11886C31B8CC3148CC01288C01481C0167BC01B7BC11D7EC121
7EBA267BB32979AC3281A63791983B93904295834CA98648AC7A52A77752A97653B26F61
9B6C628F6F619775588A8F4C7DA0338391148683008A7D00887D00867E008A7D008D7D00
8977008670008674008470008373008976008978008A7F008C84008A8300887E00817700
807300827600827B00857C008278008079008180008587028B8D058B9307919B0690A004
8A9F028CA1028E9E038DA0048FA3068BA80688A6038EA6028EA1018A9601818C017D8500
7A80007B7F00767B00747100706A00686200635F006160005C5B005858005B56005B5800
605F00636400646300625F00615E005E5A005A58005A5E005C60005F62005F62005A5E00
555400504A004E49004E4900484400483F004038003934003530002F28002C2800272300
211A00181300130B000A0600050200020100020000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
739D00779F01789D02749D02759C02759C01779E007B9D017B9B017C9E00779C00769E00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6E9F0071A00170A001719F01739D01749D00779C007A9C00799B007C9E0079A20077A200
79A4007AA2017AA3087EA1087CA10A79A60C77A90D79AB0D76AC0A78AA0979AB0A79A90A
79A80A77A90C76A50C77A20A79A10A7DA30A79A50A78A60A75A80B78A50D77A40E79A20C
77A20A75A6096FA90B68A90C5FAB0E55AB114DAB144BAD184BAF1E49AF2748AE3241AA48
3D9C563B8D64387E63387368366B69376E6A367068387663397D623B81633B82683D7E6E
3F766F3F727041716D417270406F73436B763C667B3A68733B7067417F593E955346A646
51AA3459AF1E65B10D73B1067BB10380B30379B2086FB00D66B11B5EAF2E55AE4052AE44
4EAD4448AD4442AF3D41AD3745AD3747AE3A49AF3A47AE3647AF374BB0384FAD3953AC38
53AF3550B1334AB3374AB23844B33F41AF453EAE4B3AAD5138AC5238AA5338B0523CB34D
3CB44C3BB24E3BB04A3DAD513EA7553EAC593CAF5A39AC5F36AA5D3AA85241AA4B45AC45
4AA94356A83C73A32A84A42299A026AA921AA68D1BA28823AC891FA58C1FA88628A28A1E
9696279C981E9D9114948E239E9221AC9912A6991CA2951C9391228F992395A31898A81C
9D9D1C95A0209A9D229E991E959C1EA197209D941D9F89269287289583349787269D8215
A1860F8B9619A1831B97862FA37A3991983C85AF3479B82473C01976BE1A7EBE2283C01E
87C01F86BA207CBB2079C01D7AC11B7BC1187FC01382C11181C10F7FC00E82C00D85BF0C
86C00D85C10E85C11280C11681C31384C20F81C21179C21279C0167BBA1E7CBA2376B723
74B72575BA1E75C01B79C01977C01875C01A75C01E79C11F76C02071C01E68C0246EC028
72C02E74C0216FC01A73C11870C01A72C01A6FC01B76C31577C4137CC41379C41479C713
74C71371C71571C91876C81876CA2184C91982C71680C3137CC30F7DC30F79C7197EC51B
79C71B7FC6167EC81782C4137FC31585C31582C21283C21485C1167CC31F77C12879C222
82C02083B92781AF2C85A8318B9D38899D3487943D9398429C8F509977609878659D7967
97765E8B79588B87498997218593058687008282008880008A80008A7C008A81008B7E00
8C7F00897A00887500877200817200847100867B008A81008C84008B8200878000817B00
7C7500807400857B00848100838600898A018E960391A10890A50C8CA80D8DAA0B90AB09
91AA098BA80A88AC0787B10585B50885BC0D84BC1180BE0F7FBC1281B8167DB11E79AB21
76A824739B18738C0F738206747801716B00676300625A005E58005D56005A56005C5800
5E5B00656100636100615E005F5900605A005E5B00605D005F5E005C58005C55005B5600
585000544B005147004F4B004F4B004E4700494200433C003D3500372F003329002D2500
282500231F001B16001710000F0B00080400020000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6CA0006DA1016EA20171A001759D00779D00759F00769F0078A00079A20077A20077A001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70A00070A10073A10072A001749F0176A0007AA2007AA30079A30078A10077A20178A202
7AA2017CA3007CA5007DA4007EA4047EA40979A70978A80B7AA90A7CA7097CA5097EA10B
78A20C76A20E72A20F70A30D71A40A74A70B74A60D76A50D76A60C78A40C7AA4097CA109
7BA3087AA8097CA90978AA096FAC0C60AD1355AE1A4FAF224DB12647B12F40B2403BB14E
38AC5536A25C399E613D985E3F945E3F93553C98513B9E5037A050359E5734995E339366
329166358A64328266317D69337F72348571338F63349D4940A6304CAF1A58AF0F64B308
6BB2056BB1056DB0056EB10770B01169B02162AC385DAB415AA74155AB404EAD4448AD44
45AD4142AE3C43B03445B13247B13448AF3A49AB3B4DA8374FAB3250AF3250AF3154B230
53B52D4CB62F47B43544B13C44AE473EAD513AAD5A38AD5E37AD5C37AD5636AD5538AE55
3AB0503BB24E3FAD5142A558429E60409E5E439E55449C54429955409D4C41A45045AC4F
4CB04B5FB13481AB20979E1B9D9A1EA58C22A0921C9E981CA49320A28C1D9E921FA09420
AA931FA08F219D8F22A2981EAA9F23AD952B9E9A1F9C9A279C9C249F9E239D992B9C9C25
969D20969B1F9795249A942B939C27959C2C93972B928A308C882E92862F958E299E9223
A88719A48926A97D3D9485418C82477B954875A33E75B52A76C02177C01A81C01E87B81B
84B8187EBB1878BF1979BF1D7BBF1D7DC01B82C01686C01386C0107FC20E7CC1137BC21D
7BC61B7FC7157DC61579C51C76C51971C71374C31472C01A73C01F6FC02075C01C76C01B
78C01B73C01E71C02276C02179C01C7AC2177CC0177AC01677B81979C02073C02573C022
71C01C75C01872C01877C11178C0107AC10F76C10F79C40F78C81075C81572C91675CA16
71CC1570CE1471CE1574CF157CCC1882C9177EC6147FC3167EC3187FC61B7FC51D81C519
7FC71581C61482C71584C61182C30E80C3107FC21580C61680C51581C21684C01883C024
7FC0277DC02A7DB32E87B22E8BB82E89B72A83AE368DA3449692549E8159A27B60A97659
A5735C9A7C5484933C859719858705817B00847700867D008681008981008A8000887F00
8B7F008B8000897B00877500847800807700837900827800857800877C00857D008A7C00
887D008B7F008D8A008F90008C92018A960388A70A88AE0D8BA70589AB0589AC0C89AF11
81AF1485B21185BB1080C1107DC4127DC2167BC21679C8197CC71F7AC5287AC6297CC129
7ABA2B78B72E72AE2A72A31F72950F728A047679016D6E006365005D58005B57005E5900
5B5B00605E006263006664006661006261005D5F00595C005A57005958005C54005D5600
5F54005B4E00564D00534B004E46004C46004A4200443D003F3B003D32003A3100332800
2D24002C2100271F00211900191200110900080300030100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
709E006F9F006E9F016DA0036D9E0371A30173A00076A20078A40076A200769F00769E01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6AA0006A9F006A9F0168A1036BA3036EA201709F00709F0071A000769D007A9B007A9B00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6A9E00699C00699C00699F01699D016A9C006C9A006E9B00709D00739B00799A017A9901
799600779601779703759A06759906739907749F0D72A00A749F096F9F0A6CA20B6BA20C
6FA40A6FA2096DA20A6FA20A72A20B75A10B739E0B749C0B78A0097AA10579A30476A206
73A60A75A90D73AC0A72AD0972AD0872AE066CAC0763AF0860AE0A5AB01055B11852B226
51B33650B43950B2354FAF3649AB4146A84746A64549AC3E44AF3644B03344B12F44B129
47B12544B12644B22343B32243B2204CB21D51B3165AB30C5FB30767B2036CB3016EB401
68B30368B50862B6125BB82253B72D52B33852AE3F53AE4552B04653B14050B13E51AF39
51B03B52AF3C4FAF354BB23148B43947AF4545AE4E43AE4A43AD4743AC453FAB4040A940
3FA6463EA4493CA45239A65739AC5D37AB6634A56C34A46B32A86434A56334A56535A268
3A9E664198614395624098644199693F99693F99643D9A5D3E9E5941A95544AF5648B24E
5BB14C7FAD31979F1C9E9D1D9DA11F9DA5199EA21CA59B1A959F199EA119A1A1189DA217
9B9E199DA4179CA51BA29F21A29D1E9E9E1A9C9E1CA29E1E95A41D9CA3229DA621A1A523
A3A3239DA025939A2B939B2E949E2B92A22B93A42E989E2F969F32949B338F9A3C8E983C
89944085934385924A7A9F436DA5416CAA406FAB4074B13176B92472C01F72C11873C116
76C41479C3157DC0137DC1147CC2147CC1147AC0127BC01475C11373C01173C30F78C212
7FC01084C00E88C00D83C00F7CC01074C11C73C22272C01D73C21E74C01D75C01E74C01B
74C01676C01C7AC01F76C02272B72B7AB22E78B42C76B82872C02775C22074C41D75C514
78C7117AC51177C51579C10F77C00E7AC10E7FC00D79C20C6FC70E6ECB1371CB1F74C81E
72C71A71C71B73C41C80BF2080BD2383C2267FC7227EC81F7EC81D81C71A82CA1581C815
7CC91A7CCA1B7CC8187EC81681C81481C61784C4188BC1208AC02689BE1E7CC01B79C422
78C02A7DB83281BD2884C0297EC1287ABB2D77AA3875A7447F9C4D9390529A8853968256
90885188964A7FA528849E14879007898B008B8B008E8C008E8B008B84008D85008E8300
8F81008E8900898B028A910C87910A8A92048C94029199018D9A028D9D0A87A51387A513
94A012949E0A91A70191B40690B70D8FBC0F90BE0C8EC00C8BC30F8AC31685C31D82C520
84C52283C32382C6277FC8257CCE1E79D02276D22572D32770D1246FCE2F6ECD3D6ECC42
6EC83D6EC4316FC42C74C12A6EB72E6BB62669B31B71AA14779A0C7683016D7200686C00
676A006267006062005E5D005859005A5B00595E005D5F005C5E00585A00585100574E00
534B00534800544900544C00544D004F47004C4100494000453E004136003C3200392A00
3729003225002D2000271B001E1600171100160B000E0A000A0800050400020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6C97006D97006A97006D97006D93006D94006B94006A9500719A00769700769500779601
789701749702739703729A04759D0773A00C71A50E73A20D76A10B74A2096EA20A6CA40A
6CA40A6EA00971A30870A40972A50873A30776A00877A10778A40978A50A76A30A77A30A
76A80B78A90B77AA0978AB0974AA0777AA0476AA0471AC066FAE096CAC0B6AB00D67AF14
66AF1C64AE1C63B11B60B01C59AF2258AE2458AF2259B01E56B31B52B41A54B41856B415
55B41253B4114FB4124DB6124EB61053B5115BB40C63B30869B5056DB40270B30070B301
71B3036AB5095FB61156B71D50B72A51B53751B24055AE4456AE4755AE4353B13E53B13A
52AE3A4FAD4250AD414EB0424CB24647B14E46B05645AD5644AE5244AC4C44AB4841AA48
3EA54D3FA2533FA05B3BA46438A66834A26D329A72319871349A6A35A06334A66634A668
3BA167419B643F99683D966A3D97713D946E4093653C975E3D9D5A42A75545AF4E54B241
6AAD3D90A6299E9D1DA1991C9D9C1C9CA0179F9F19A3991E9A9C1A9A9F1AA29D1D9A9E19
97A018A1A11BA7A01CA19D1DA39E15A4A210A6A01AA59A2497A11B99A41E9DA821A0A521
9BA92197A82394A52392A22793A12A90A62C90A92C92A43191A0308D99348A9C3C8C9D3F
869C407F9A427E9947799B45779F4371AA406FAC4074B33175B92B75C02874C02075C218
76C1157AC1137CC3107FC20E81C20F7CC11179C41278C01377C01175C01076C10D78C00F
80C00F89C00D88C00B80BB0E7DC01075C01877C01C79C01A7AC0197DBD1A7BC01878C014
77C01479C0177BC01B7BC01F76BC2178BA227BC01F79BF2074C12173C21F6FC31C75C712
79C70E76C71075C61574C21075C00C77C20C77C40F75C50C6FC50D71C90F74C91574CB19
6ECA1D71C61F71C3207AC0227AC02B77BF2A7AC52C7FC42A7FC62581C81F7FC91B7AC71C
79C82078C8227BC8207CC91B80CA197FCA1780C91782C61B81C7237FC5207CC52278C52C
73C53375BF3383C12584C3237DC32577BE2D76AF3D75AC467FA250908F519C8851A28350
9A8B4F8F974484A31F859A10888F058C8B008D8C008C8F008F90008E8C008E8300908801
918C048C900A85900C84960F829B0E859B078CA00490A7058BA40984A81081AF1682B11B
8AAF1E91AD1192B0058DBC0D8CC2138BC3138DC00F8BC10D8AC60F8BC6148AC71B86C925
85C72483C9267EC9267DCE257DCD1F78CC207BCF2177CF2174CE2672CC2B70CF336CD03F
6BC9436BC53C6CC8386AC43969BA3D65B83861BF3463BC2B67B21371A106738C016D7A00
67760365760861720858710B556C0C516A0F51690B566908586204565E01595B00585A00
565400534B005347005248004F49004E49004D4400483D00453900423600413400393000
362C00372A00302400281C00211600190F00170E00110C000D0A000A0500040100010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6D96007098006F96007495007293006F9000708F00719501729702739501799500789802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729A007498007497017597017395017293017392007191016D95037495017694007B9C02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729B00749B00749D01739A01759A017696017895007593017497017995017C95007A9B00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759900729900759D00739E00749E00749C00769B007599007699007899007A9800799900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709B00709B00729E0071A00073A000759C00769801749801749901779C01779D007C9A01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6C97006E9A006E9B00709C00739900769B00759702749902759702759A037A9B037B9C01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7095006F9600709B00739600789300769701769502759703759603759904789B04779C01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7197006E95006E9500729500739300759500739401749401769903749905739A03769E02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6F97006D94006D9300719600719100729000729000719400739601709602709803729D04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6C95016D91006A8E00718F006F8D006E8A006F91006F8F006E91006D8E026E8F04719206
72940876960578970776980A749F0D6CA10E69A30F68A10F65A10B659F0A619E0C659D0C
669D0A689C09699B0A6899066B98036E9704719506759408769605779807769709779608
7999057B9D067C9A077E9C037D9E017C9E037FA2057EA3077AA6087BA9097AA80979A808
7BAB057CAE037CAF047DAF0180AB0183AC0082AC017FAE027AB0057CB00379AF0279B100
7CB2007DB2007CB3007FB10184B20183B1007FB10081B2007FB20082B10084B10086B300
86B40086B50084B50083B40181B70384B50389B4018AB3008BB30185B40679B50871B40D
69B31663AE2762A838619D485B9A4F589B52519E534CA7574EB05C4DB0594BB25948AE5E
45A46543986D4098713E99723F94733A8E763A8975398A773D9474439C6F43A26146A257
47A1514CA04F4EA14957A23A65AE2B73B8217CB41A84B21A8AAD1B91AE1993AF1A91B01C
92B21C96B31C95B3208FB21D8FC01893BB1294BA1096BB0F96BB0F93BF0E91C00E90C00E
92B60D93B70E93B90E92C00A91B60892B60A94B80994B80B94B40D95B20C96B50B96B90A
94B60A94B50A97B70A97B80897B80795B60792B20696B00495B00295B20293B20293B002
8EAE0192B10096B50196B40099B50096B60096B7009AB7009AB7009AB30197B4078DB80E
82BB157DBB1B78BC1B7BC01582BC0E81C00E7FC00E82BC0E84C00D86BD0E84C00E7EC00F
7EC0107DC21780C51882C0158BBE158AC01588BB1A89B91D8AB81E8AB91E88BB1E86C01E
83C6167ECC127CCC107ACC137BCD177AC81C78C6237BC02578BC2679C02070C01F76C121
76C22376C22374C2217AC02175C0267FBD2781C12385C71D8AC8108BC70B8EC7098FC707
91C60389C80484C90A84C70C81C7187CC4217AC82777C7337AC63877C73775C9347AC236
77B93C74AE426DB6476BC0406DC9306FCB276FCC2073CC1F73CB246DCB2A6BCA306EC33A
70C24370BA4474B73F79AA497BA94978B0497BAC4A829F50899552A18A52A7864FA08A48
8FA62D86B4138EAA0A91A101919E0093A10294AD0D90B21588AD2185B51D86BE1888BE17
86BF1B83BD2087C01988C3138FB90F90BA0C92BA0F8ABB0D85B90B8BBB1189C31388C824
87C4318ABD3C88C3338AC51E86C41B88BD2F8BC03284C43085C93086CA2D83CD2985CE1C
85CF1C84CF1A7FCE207CCA2379C91F75CA1F71CB286DC93C66C43F68C1435FB9505AA662
4D9E704D91724C996A4AAC6846B1643EA3623E965B3E9E5740A75241B3563EBA673ABD72
3CC27538C76E3BCB5D41C94D45BF3F45B34341B15643AE5946A4405397196384086A7001
656900645E00605800595100564C005349005145004E3F00493B00463500413100413100
3E33003D2F00352B003328002E21002A2000251D001F1300160D00130B000B0500050200
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6A8D026C8C016E89006C8A006E8C006D89006B8B00698E006A8F00708D016D8902718C03
728F05739007719608719A0A6DA20F6AA31167A50D65A40C65A30D65A00C669D0A6C9D08
6B9B066A9B076D9C05709A05709A04729603769404769604749904729F066F9E08749C09
779A057D9E047E9F087CA00879A20778A6077AA6087BA5087CA60B78A80D79A70C7CAA0B
80AB0781AC0382AD0480AC0382AD0183AC0081AE007EAF017AB0027AB1047FB00281B101
81B00080B0007FB20081B20084AF0085B10082AE0084AF0081B00085B10087B00088B100
88B40088B60086B30085B20083B50182B40083B50085B50186B50180B40379B70773B709
71B60E6CB51567B32166AF2E5EAE3659AC3D58AE4251AB4E50AD574BAD5B4AA86044A467
43976D408972408A743F8B76408E76438A773E89743B8E7440986D41A36344AF5549B048
50B33D55B4375EB12E6AB32375B61B7AB51884B21989B41B8EB21D92B11F8EB31E91B71C
91B81893B91590C0108FC00F95BB0F94BB0E94BA0F96BA0D9BB90E9BB50E97C01099B610
96C01295B61295B71295C00F93C00E91C00F8FB7128DB5188FB1208FAF1D96AF1A98B11A
97B11999B3179CB4139FB611A0B6129FB8109FB70E9EB80F9BB60F9BB7109EB60E9CB80D
9CB50D9BB40B9BB60A9BB80A9AC00996C00994C00996BB099AB90A9BB90B9CBA0A95BA0A
8EBB0D84C0157DC0177CC0157FC00F81C00F81C00E85C00E88C00E86C11087C21287C013
88C01783C11882C11688BC1888B81A88B61E89B71C89B61B84BB1A83BD1C87C01D84C31A
7CC6147BCA0F7CCB0F7DCB137BCA1379CB1878C9217DC0247EB8257BB92176BB2375BE26
74BD2977BC287ABC297CBB2B7AB93080B62E7CB82F7AC12F7CC61F80C91486C90D8CC90B
91C70A89C80785CA0882C90981C80D80C91482C91A80C82280C62D81C62F7DCA297CCC2D
76C73072C43A6EC43E69C53E6AC7346DCA2E6ECD2571CC2671CC316CCA316CC73771C33D
72C04276B5427AAE427AA4497BA24C7CAC4C7DB14F81A153859651A08A55A888569F8B4B
8DA43484B5178CAD0E91A10392A10494A60A93B1158FB41B8BB41C86BB1786C01788BE18
87BE1A81C22083C21985C3178CBA148CC11192C2118CBB108ABD108FBC1190C3128FC415
8BC72389C52F89C2348AC4248CC31985C02585C03084BD3280BA3382C53385CA2A82CF1C
82CE1D7FD1227BD0227CC81F7CC21977C21971C6226FC92A6BCA2E69CD405EC65258B15C
4EAA614DA2674CB76648C85D45CA5446BA4D43B44440B84344B64742B9523DBB633CC06A
3DC3693DC7613EC95841C35043BA4B43B05244AD5A45A74D529D29608C0D6A7D016B6D00
666600656100655E005F5800594D005445005042004A4100493E004739003F32003E3200
3F35003B2B003927003328002F2100291C00241A001D1300160C000D0A00080600040100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6D8F016F8C006E87006A88006E88006E85006B8B00698D006A8F006F8E00718900728B01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6C8F006C8F006C8C006B8A006E89006E88006F8D00718E00708E00749001748A00728800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6B8E006D8C006D8B00698A006A8C006A8C006F8D00738E00748F00779400789100778F00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6F8F00708A00718A006C88006D8800708A00738800788E00758F00769000749200768E00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749200728E00749100718F00728C00748D00758D00778E00788F00778D01789201799301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739100758F00729400729400709300749400749000738F00768C00778B01779302789201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748B00739000719000719200729300739300739000738900748B00748C01748F01728D01
728C0672920B72960F709F0F6AA10E6CA30E6EA00B6B9E0C69970E6B940E6E980D70960B
76950878900475920272930775950873960873980A709B0C709C0B6EA10B70A40A6DA409
6EA50572A70175A60276A80379A90478A70578A70479A50274AB0571AD066FB10672AD04
76AF0377AD0675B10774AF0774B00779AD057BAE017DAE0081AD0082AE0085AF0085B100
85B20085B20085B10086B10084B20088AD008AAD008FB10090B2008DAF018AAF018AB100
88B30087B30089B30087B10188B40189B50086B60186B40183B30282B30481B30783B407
80B6067FC0077FC0077CB50878B70777C00877B70778BC0879BC087AC00A7FBF0983C00A
7FBC0B7AC00D7AC00E7BC00C80BA0B81C00883B70883B80884B80882B80782BA0785B908
8AB8088AB60787B90884B90985B80A8AB60A90B70B93B70A98B30C9AB8109FB311A0B10C
9FB20E9DB1109DB40F9DB40F9AB110A0B4119CB21296B41097B61198B51498B2119BB213
9BAD1B9FAF11A3B011A3B1199DB10E98B00E94B40F96B30E99B50C93B61199B0169CAF16
9BB2149AB61697B11194B00E96B01097B01297AE1397AF1096AC139CA813A5A412AAA515
A3A511AAA412A9A516A5A711A3AA0BA3AD0BA8AC12AAAC11ABAC0EA7AB0DAEAA0EAAA90E
A1AA0D9FA70E9CAF109EB512A3B11197B20C94B40F91B8108EB81387B71387B6128CB513
8EB80F84BC1287BB1789BA2288BD2382BB247FBC2184B92281BE227ABE1F78C0197DC315
7CC6167BC91777CB1A74CC1571CB176FCE1D72CB1F78CD1B7CCB197CC91C79C61E7BC71F
7AC6237AC5277AC5257DCC247ECC177FCA137ECA157CCB1E7ACB1C77CD277ACC2C7DCD2B
80CC287BC9277ACC2A7CCC297DCD2A7FCC2982CA2480CB2081C9168AC80D8EC8098DC60B
8AC61388C71682C01D7EC0207CC02777C03773BF3E71C04171C83773C92671C9216BCC24
69C7306BBF456DAC536E9E5A6E9E5C70A05A70A256749B5A77995A72935A718E5D6A9459
6FA54781BD2B96C024A0C0299EC12B9ABD2C92B72C8FA9328DA73291A92F8BB02B83B22A
84B82C89B9298AB42386B31C87B71A87B7178BB81889B71690B71394BA1396C21593C619
92C81B8EC91B8AC92087C82E85C03986B43D84B64083BD3882C12D81C5227EC22279BD2D
78B93577C23776C83971C42B70C02671BC2475B81A6DB1176AAD1967A31463A41464AA18
61AB1D69A21470980B729407679A0C5F9F105BA7195BAE1A5BAF1559B21356B41655B015
57B01661A30B648C026A7A00686D00666700656700676500686300696000656300636000
5A52005449004E42004F4500514100504300493F00483B00413800443600403A003D2F00
3429002D2100231A001F17001E1300191100130E000D0A00070300030100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
728D00748D00758900768A00778C00778B00778A007288006E8B026C89027084016F8800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6C84006E8300708000748100747E00737C007380006F84006B89046A8A036C81016E8200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6771006876006B78006E7C006F7B006C7D006C7F006E83006C8401698902688202678502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5E6A00667300687100687200697700677E006681006882006882006A8701648401628704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617300617800617500617600617C005F80006082005F84006086006288005E8800608600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627B006281006182005B81005C83005A84005A87005B88005C85005B8B005E8901608901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627700657900678000607E006083006085015F86015F88005F85005B83015F8502628301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657B00677800697700687700667C00668200668601678800638500627F016784046A8002
668904648907638E0A61950B63940A6793076C8E066A8B066B8D076B9107718E03728D00
758B02759104729405749A03759C04779E05769B08769B0B779E0D789D09769F0772A108
74A00676A00476A50476A90573AA0876A90774AB0774AD0576AF0176AE0179AF047AB007
7FAE0482AB0084AD007FAF007AAF0076B2007AB2017BAE017EAD0081AC0081AC027CAF05
78AE0480AD0283AE0081AE0081AC0082AC0083AA0088AB0089AE0089AD0086B00088AF01
89AE018AAD028AAC018DAF018DAF008DAE008BAF008CAF008EAE008FB10087B20083B201
82B20482B30582B40381B20285AE0288AA018CAF008DB2058EB2078BB3088CB4088BB806
8BB8038BB8028BB7028AB50385B6058DB50690B6048DB60494B60496B50197B40093B80B
95B70C97B90A97BA0C9DBA0DA0B90C9FB60BA3B60DA3B50D9FB10C9FB20E9FB20E99B30C
9CB20E9EB10B98B50B9BB50F9DB20F99B60B99B60B9DB30E99B410A0B310A6AF0AA3AF0E
9DAD12A3AE159CB21098B00EA1B011A2B10EA6B111A6AF19A3B0179EB01AA7AF1BACAB1C
A6A714A3A41CAB9B259FA319A3A31FA79D1DA79F1497AE15A1AC17B19F1CAE9E1DA4A41D
9FA11FA89D1EAC9C1DA9A019A7A41AA7A320A4A5209BA91F98AB1F9CAC1B9CAE1F9FA81E
A7A7109FAB0D95AE1493B2148CBA1394B914A4AF1996B51A92B71D9AAD21A1A729A1A32B
9CAA2E93B02D8CBB2684BB2581C2237EC32380C42482C02689BE2387BA2085BD2081C01B
80C11D7EC11F80C21D86C81987C81887C51783C31883C11B80C41985C81284CB1086CC0F
82CF1082CB1583C71986C01D85C11C84C11980C3187EC22181C21F7AC32276C62775CA26
74CE2371CF226CCE246DCE2D6ECE366ECB406DC6496DBF536DB14C72B04674B03D76BC38
77C2337CC81986C70D88C40988C60A84CA107BC91A79C4247FBC307DB8387BB03B7AAE3F
80AF407EAF4482AB4380AB437AB34476B53F74BC3E77C63482C52D84BE2F84B9378AB33A
8AA83892A3378EA2459497459B8F46A79646AB9943A99B40AC993AB39838B5963EB19141
AC953FA19A3B9DA03397A73493AE3390B6308CC22F87C92A89CC2687CC2888CB2888CC25
8AC92984C8247DC42878C5287CC52F7EBB297DB72582B31C83AB1484990E858D03848600
7F81007B8000747800706D006F6A006C6100645D006560005F5F00615F005E5B005A5A00
585B005D5F005C5500554C00574E005C57005E52005950005A54005B5000575100555000
554E00524C00534A00534800534C00534B00524E00574E00554A005145004D4100504600
4F42004A3F00483E004A3F00483E00423B003D3A003A3700383500373300322B00292500
251C00201B001B1400130B000A0300020100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
667C006477006974006874006875006B7F00698300698100688200687C006981066A8003
68860765890663910964960A6894086B8F04718B01708800708A016F8E017088016F8700
728B01758F02739403749904749D06729E0671A00971A00E71A21071A10D6FA20A70A40A
6DA60871A80771A70B73A70A72A70971AA0876AA0776AB0476AC0179AB017AAA047AAB07
80AC0482A90181AB007EAE0177AE0276AD0278AD0178AC017AAC0281AD0182AC0180AE02
80AF0284AC0186A90088AB0087AC0088AA0188A8008BAB008EAA008FAC008CAE008BAE02
87AE0784AD078AAE048DB00290B10091B1008FAD008EAA008DAC008EAF0089AF0085AF00
84B20283B30683B60682B50284B1028AAF0189B00087B10286B40583B50786B40887B405
8BB4038BB5038CB60489B60887B9068EB70391B80391B50492B40294B10096B3019BB60B
97B90A96B60C95B60B99B6099CB60D9BB40C9DB5099DB40E9CB30FA2B00DA1B10C9BB210
A1B10BA3B20A9DB40D9DB40DA0B30C99B30C9BB60A9CB30A94B3109DB010A4AF0A97B211
9BAE14A2B10F97AE1096AF14A0B20E97B30DA2AE19A5B1159CB11499B01FA1AE16A9AE10
9EAE19A1A91DABA316A1A61AA6A426A6A017A8A2139CAE16A2A817AD9F18AD9F1AA69E1C
A79823AB9C1FAE9F1AAAA319AE9F1FAB9F1CA7A21BA09E2B9DA32B9FA92DA1A920A7A717
9FAF149AB21595B11792B41391BA1091B51397AF1695AF1894AD21A1A42BA5A12EA0A430
99A9318FB22E8BB82A86BE2881C3207FC4217EC42482C12986BD2A83BB2780C02580C123
7FB9237DB9237FC02084C11B87C21688C31587C01887BC1A87BE1C89C31386CB1288CC10
82CD1082CA1481C51882C41C80C7177ECC1680C9187DC5207CC62177C72174CA206FCB20
6DCD246ACF2567CF286BCE2C6CCE3969C84A6AC05169B5566DAB536DAA4D72AC4974B53B
74B9357CC62483C80F8CC0078AC00884C90E7DCE157BC9227AC0297BBF317BB93575B937
7AB73E7AB64179B14077B14177B93E7AC0317CC52B83C42985BE2C86BD3386B33B8EAC3A
8CA0378DA334869D41979945AF9148B59543B79542B29545BD973AC09331BE933FB69446
9C9442949F3D8CAC3C89AF3D8CB63D8DBD3B8CC23A88C23886C73685CD3183CB2883C623
85C61D87C31884C11480BA157EB6157FAF127EAB1180A40F7F9B0A828E048183017F8000
7B7D007977007370007068006C61006759006057005D54005A53006059005E5A005B5C00
5F5D00616000625A00594E00584D005C54005853005C5400595000565000565000554F00
524C00554900544B005248005246004D47005248005249004F43005140004A3F004B4500
4E45004F43004A4200483E00443E00413E003E3900393300383200332E002F2700281F00
2318001B18001611000C0900060200010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
627700647600657400687800677C006A8200697D006A7B00697B00687900688305677F04
678308648E076690066596066996066B92066F9104708F04738E03718F026D8D016E8C00
6E8E016E94026B99066E9F076EA00768A10668A2086CA00A6E9D0B6F9F0A6DA1086DA609
6CA7096FAA0C70A90F71A70C72A60A74A50876A90876A90976AE0678A90279A9037BA904
80A80380AA0281AB007CAC0276AC0476AE0576AC0477A90479A80380AA0283AA0086A900
87AB008AAA008CAA0089A80089A9008CA9018BAB008EAA018CAB018EAD008BAE008CAE02
89AC0789AA078BAD0490AE028EAF008FAD008DAE008EAD008EB0008FB10087B20086B400
85B50186B70285B70384B80282B9068AB80888B50685B40581B40480B50480B60384B802
88B40189B70288B60289B70588B8048DB9028FBA038FB9048FB80391B30396B40599B60C
96B50D98B30F99B30997B30994B30E98B5089CB80898B60D9FB211A3B108A4B10DA3AF11
A4AF0C9BB30C9BB10DA1B00C9FB20A99B312A0B50B9BB40A93B0119DAF0F9EB30C92B212
9AB212A1B30A9AB11297B31599B80A97B60C9BB11495B51096B61399AE209AB1129EB212
9FAC1FA4A616A8A70DA4A31FA39E24A5A415AAA914A9A520A7A21BA5A518A8A118A99E1A
AC9B1DA59D16A59E1EAA9E20A99F1CA6A51AA39F20989A299B9F2D9FA82DA1A6239FA621
9FAE23A1AF1C9FB11396B4169AB51C93B614A2AF10A0B019A1AD209CA42D98A8318BB033
89B63085BC3084C03082C22980C0217FC12182C32581C1267EC32678C7247AC8247CC520
7EC12283BF2682BF2384C51C83C61B8AC51789C51687C51686C31787C5168AC8118AC611
83C51083C3137FC51782C31E7EC71E7FCA1D7FCB1D7EC6247AC72176C91E72CD1A6ECB1E
6DCD256CCD2869CD296ACC2C6BCD3D69C84D69B9546CB0586FAD5470A95172A94870B03E
74B33A7AC5248AC61192BE088FBC038AC30A80CD137BCA1C7DBF287EC02C7ABD3277BD32
7BBD3579BE3777C03777C0337EC13082C32483BC2B85BC2F83BC3383B9358BB33792A836
92A4398DA83C8C9C429C9943AC9447B39442AE9843A99746AC9642AC9839A59B419BA344
94A83E8AAF3A8BB7388AB63989B7408CBA408CBB3D88C13A83C33880C8347EC32F80C11E
83BB1788B60E88B10689AA0685A103859E03849702829503818B017C85007E7E00807B00
7A7B007477006E6F006D6900695F006156005F5200584E00554B00574E005D5400605800
605C00635B006359005F54005B51005C53005952005750005350005750005A5100555000
534A00514B00544D00514A004E42004F44005145004D48004D44004A41004B4000494000
4E45005248004E4800494100423F003E39003D37003A3200342D002F26002A2200232000
2118001A1100130E000B0800060100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6170005D75005D7700607D00668000697E006B7D00697A00687D00687E006A7E00698706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5F71005F7700617900637D00657E00667D006A7E006D7D006D82006D84006B85006A8B06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5F6F00607800647900677A00697B016A7E016D82016D8300688600688A01668A01669103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6073005F7800647C00657A00687F01668502678B01668800648700608D02608E035E9403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607001607601637600677B006681016182016387015C88006086006087006188025D8B02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5D6F005F76016177006378006180006080005B7F005C80005D79005C7D005F7E025E8405
608E075C90065D9806609906619506608F056089025E8901608D03628C03668D03678D04
6C92036D92046D92056D95046F9606719A08709906719806709C06709D096EA20B6EA10F
6EA70D6FA9096BA9096AA90A6BA7096FA80970A80470A9006FA60070A50070A50171A602
75AD0473B00377B20278B10077B20077B30075B60178B3017BB0007FB0007DAC007AAD00
79AE0177AD0278AA017AA9007BAA007EAB0083AC0083AC0084AE0084B10084AE0182B001
80B1017DB1027FAF0481AD0284AE018AAD008CAB008BAD008AAF018DAE0088AE0085AC00
88B30187B2018AB10288B60287BA0586B7028DB70090B60091B2018BB40288B20289B100
8CB20093B20094B00093B30094B6008FB5008EB40092B30091B1018DB1018FB00991B109
93B30B98B80A9BB40B9AB80B93BC0C92BA0B96B90B8CB80A90B30E97B60991B70993C00B
9DB7129FB80A9CB80997B70E98B80C95B8098BBB0C90BB0F99B90B90B70E9AB614A6AF0F
9EAF0F9BB313A7B112A5B30F9FB412A1B513A7B310A1B110A3AE15A9AD159FB311A0B412
A1B3189EB11595B3199FB11BA5AB1DA1AC169DAD18ABA81FA9AD14A2AF12A5A6179EA515
96AE1B99B31B9EB1148FB21498AD1490B21096B414A6AB2393B2159BAA17A5A816A6A316
9F9A2DA59F2AA99E27A0A22F99A23092A2338DA53385B03185C02A85C82483C72483C627
84C42386C91E83C91D82CA1C7ECB227FC9297DC92780C9207ECA197CCB137CCB117BCD12
7CCE157ECE137CCE157ACE167AD11977CF1976CE1D7DD2197ED01A83CC1D81CD1A7DCE1B
76CF1B7BCD187ACC1D73CA2272CF2175D12178D01C74CF1A74CE1C78C82479C91C77CA18
74CD1F6BCE2969CE2D65CE2F67D13069D13D67CD4D66CA576AC94F6AC74872C14474C631
79CF2184D01290CB0F97CA1694C61E93CA2292C81A94C51892C81791C71790C21991C01C
8DBD1F8BC4228AC02786BE2686B82787B02C88AB338FAA3595A33E9C9944A6924AB28450
B47C51B58351B4894EA688539C8A52928F4E8F9B4992A147989E45939E45909B4A8AA43A
88A7208D9D138E90068987008A88008A8800858800888B00898A00878600878700848700
8182007F83007F8000817E008380008284008584008583008080007B77007A7600797800
736F00706A006A6500665A005C4F005A50005A51005B4F00594F005552005953005D5500
5E56005A5200565000584F00554C00564800554A00544A004F48005047004D4500504900
4E49004B4100493E00463B00493D00494000494000463A00473B00464000473E00453D00
3F39003A3200363000332A002E27003128002C2500221A00191300110C000E0800070400
040200000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
596B00576D005A74005875005C7C005B7B005C78005873005B6F00576F005B7604598008
5A8B085893075796065D9706629402659001608C016089005D8E025E8F03628E03678F01
6A8D016C8F02669004649307659A0B679C106A9E0D6C9E0B69A10B679F0C69A10C6EA20C
6EA40A6DA3096CA4096AA80B6DA60A6FA80770A90371A80072A70070A70072A80073AC02
76B10774B10677B10577B0017AB0007BAC007CAE007DAE007DAD0080AA007FAC007BAC00
7DAD007EAB007CA9007EA80080AA0084AC0183AA0181AD027FAE0281AE0186AF0184B100
86B10086B00186AF0386AE0286AE0188AA008CA9008CAD0188B00286AF018AAD0088AD00
89AD008BAF008BB3028AB40187B50286B4018AB4008BB3008FB3018BB30189B2018CB300
91B10197AF0197AB0096B10095B40091B3008EB3008DB5008BB4008AB2018DB6088EB50B
8CB60996B60995B60A94BB0B90BA0C8EB8098BB80A8EB50D90B4098EB40890B70A99B70D
A0B4149FB50C9EB80B9BB4149AB50D96B8098EBA0B92BB0E9ABA0991B90DA0B114A9B00E
A5B00E9DB213A2B2159FB70FA1B811A2B713A3B3119DB3109DB311A6B115A6AF10A1B60F
9DB3189FB61799B9179FB019A6AC1A9FB1149CB114A3AE19A4B2149FB2109AAA1E9CA81B
96AE179AB11E9CB11D90B51892AE1895B00E99B013A2AB2697AE1898A7189EA814A0A919
A9A02CAB9C23A398219B9F2A94AA2E88AE3182B3317FC12A82C52483CB1F82CC1C83C81F
85CA2182C92480C8217DC6207CC9217EC5277EC82980C9247DCA1C7ACD177ACC1479CE15
78D11580CD137FCF127AD01477CF1779CE1C76CC217BD21E7CD21C7FCD1C7DCD1C79CD1E
75CA1E76CB2077C82775CA2A72CC2275D01F76CF1A77CD1A76CB2074CA2D75C72971C722
70CC1E6CD1236ED0226CD1266CCF2F69D03A67CF4764CE4C66CD456BCA3F72C63E73CB31
7ED02389CC1897C8159BCB1996CB1997CC1C95CC1795CC1593CB1793CB1695CA1791CA15
8DCB1790CA1D90C5238CC12488B82586B1298AB22A8DAB36919F4293914AAB8F4DB78852
BC7E4FBA8252B38555A488559989549496518F974B90944A97944B96954A8F98427FA11F
869412858704868200848000868100868400848300848400838200848200838800858A00
8287007F83007A80007D7C00807E00847D00847E007E79007D78007A75007B7800787700
7876007572006B6900625C005A52005A5000595300555200534E004F4B005651005A5400
5E55005B54005954005A4C00564D00544C005149005048004F47004E46004C46004E4400
4B47004C42004B4000443B00483A00483C00473D00453B00453900453C00454100433E00
3D3500342D003128002D23002B24002D25002823001E18001410000D0700060300030100
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5C67005A69005C6F005C6F005C6F005C74005D71005C71005C6F015C72025E79035D7D07
5B8A08568E065993065D98056097045F9403619101619001609401609502609402639303
649405639504608E035F92075D980D619D13619F1262A11061A00F5E9F0C659E0C6B9F08
6D9C066DA3066AA40767A60A6AA8096DA90671A90572AB026EAA0071A80075AA0075AC01
73B00874AE0776AF0579AC0179AB007CAA007EA9007EAB007FAB007EAC007EAB007EAC00
7FAB007EA90084A40085A60087A80085AA0281AC0483AE057FAC0581AF0486AF0287AF00
89AE018AAE0185AC0287AE018BAC008BAA008CAA008BAF0187AE0186AB018AAA008CAC00
8AAE008DAE0088B20089B50086B30086B40089B3008CB3008AB20088B3008DB3008CB100
8DAF0190AF0192AF0194B30092B20093B4008FB2008FB1008EB4008BB4008AB8098AB609
8BB70891B7098EBA0991C00A93B80D8BB50C86BD0A8CB20F8EB2088BB60991B60A9DB50F
A6B40F9BB60C96BF0D9EB61298B80C95BF0995B90D94B70E9AB7098EBE0C9BB412A6B30F
A1B30D9BB7119FB7139BBB109CBE119EBB169DB71596BB1298B913A5B416A6B313A2B411
9FB117A2B419A4B916A2B315A6AD189FB113A0B311A4AF16A0B31299B50F97B21C98AE1A
92B11498B319A0AF1E92B21695AE19A2AB159CAE16A4A924A1AC1A9BA8129BAB1594B218
A6A424ABA024A498299BA32D90B02C80B4337EBA307DC62F7FC82780CB2082CC1C81C81F
81CB2180CC247CCA2378C91D76CA1C79CA207CCA1E7ECE1E7CCB1C7DCB1879CD177CD117
79CF187DD0177ED21779D0157ACE117ACE1775CE2078D22076D02378CC207BCA1E78CB1D
79CB1C78C92078C72575C72674CB1E73CD1B74CB1B76C81B73CB2071CC246DCB2469CB22
6CD01F6BD0226FD31F70D1266DCA2F68C93368CE3C68D14366CF416ACC3C6DCD3275CE28
7AD32589D01992CC1892C82093C82193C81F93C91C92CA1B8FCB1A90CB1A94CB168FCD13
91D11490CC178EC5218DBD248BBB248AB8288CAB2D939F3B9F9545AE874CB4894EB88953
BB8654B88357B6845A9C8458938A569794589593548C8A57948E578E9741889D27809213
858704838101837C007E7C007D7A007C7A007E7C007F7C007F7D007E8100818200848200
8587008086007F8200797C007F7A007F8000807C00797A00797100766F007A7600797700
777D007079006D6F006562005E5A005C54005C5500565300555100534F00564F00594F00
5950005A5000595400575300585100544B00534700504A005045004E48004B4400494200
4B3E004A3F00473E00423800433800463900463B00443E00433A00423900423A003D3700
3A3100312700292200272200231D00221B001F1A00181300100D00070400040100010100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5B5E005C63005A6801576A005A6B005D70005F74005F7C005B7D02607E035F84045D8506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5D61005C63005D6D025A6D005D6C005F72006075005C7D005A8702598A045B92065D8F05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5C6A005A6F005A72005B74005C75006075005F7C015C84025A8F03569304579403589A06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5F79005D7C015C7D015F7F005E7D005E7B016286045C8E06579905559D05539C0556A005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5C80015F85035D84026086016281005F85025E8F065E93065A98065C9B065B9B065B9F05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5D81035F85055F8504608A016088005F8B035F90055D93045E9007608F08608E08609406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5B7E03607F035F7F025E7D015E86015E84035D8A035D89025E83046182065F7E045E8104
618B03618B02648E045E8D03598E02568F025790015C8C005E87006286006487006A8600
6E87006B86006A8800688C016190026193016491016893026995026B95016E9A006C9E01
6AA3036CA2046BA0016C9B006B99016B9D036E9E0270A300709F006C9F00709F00719F00
729F00719E0073A30075A70075A80174A40272A60274A80373AC0476AD0378AE057DAE07
7FAD0380A90081A80082A6017DA5017DA7007EA60081A60283A80284A90782AD0380B002
7DAF017FB0017DAF007DB0007FAD0082AF0080B00085AC0085AC0083AC0080AF007BB200
73B40273B50479B4027CB4007FB40082B50080B20182B50185B60188B60084B40084B100
88B40089B30089B30089B20084B2007DB50081B60183B50387B70389B3028BB5098AB809
91B80A9CB70B9CB70A96BE0A98B80D98B60D9BB30C99B70A94B50C91B60D96B50B90B40D
8DBB1296BB1199BA0B99BA0B95BA0A97C00E9FBB0F9FBB0BA1B90BA1B510A1B311A1B20F
9DB70E9EB90E9AC00F94C00D90C10A91C00A8FC00B91C00B8FC00B88C10B8CC00C92C00D
95BE1092BE1091BB1195BC139BBD1695B91794B81895B71A97B71B91BA1890BF158BC112
89BF158AC0178DBF1C8DBB218DBB218ABB258CB52A94BA2E91B23588AE3787AE348AAD34
8FB1388CAF3A88A93F81A1437FA23F7BA63E7FB23C7EC1397CC92E79CB2478CC2476CB24
76C72176C52274C92271CC1E6CCD1B6CCD1C6BC61D71C51D76C51C78CA1F73CA2272CA20
70CF1F76CD2177CC1F75CC1E71CF236DCB296BC92E6ECD2B72D02A6FCE2C71CC2A73C829
70C72976C92A70C82A6DC92C6ECC2670CC2273CA2074C72075CC1D72CE1B72CD1471CD11
72D11371D01471D10F74CF0D73D11075D40F71D81674D7177CD31183CC1188C9138BC816
8DC91A8BC91E8BC91F8BC5228DC42493C12797BA299BC02393C02291C21F8FBF208FB721
8BB1238CAE278FAD298BA62A89A52F89A0338C9C3C899A428C9A49929C549D9D509E9B4C
8F8B51908F5096955499954A8CA63982A21987940B868900858700807F007D77007A7400
7873007A74007D79007C79007B7200796F00766E00756C00726900716C00756D00757100
7672007873007A73007A7300737A00757A00767400716E006A67006E66006F6B00707000
707200666C006163005E5F005B5E005A59005855005A5700585A005E5E005D5A005B5600
5C51005A56005959005A5200554D005049004D44004C43004E46004A4400484300463E00
443C00443C004038003F37003B3400342F003029002D2800262400231C002016001A1400
181200100C000A0600020200000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5B73025D74025A72015D72015D79035A79035C79015F7D015E7A045A7C075778085D7D08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596701546101546600586600586F025A6A01596B005D70035A740858760A577E0D5A8611
5A8C1459930F56910C559408559306599106588F035D8A01628700618900638B00618900
6484006389005D8A005D8D015991015B8F035991085A9508619803629B01659800649A00
6499006598006995016698026597016795016C94037393037A96017A980075A00072A300
72A60074A40074A40175A60279A5017AA50078A50079A5017AA0027AA5027AA4027AAA00
79AC007AB0017CAD017CAC0279A70276A90174A80377A80875A80879A8027DAB007EA700
80A9007DAD017FAD0080AF0081B20081B10080B00081AF0082B10081B3007DB2007BB000
7CB0007EAF0082AE0086AF0085B40083B40082B00085B10081B20082B00085B00086AE00
81B20082B40081B70082BA0085BA0084B90088B90188B80288B60388BE028BBD0299B60C
9EB70C9BB50C94B40E98B6119FB30FA2B60D99B70C98B60E9CB5129FAF14A7AF12A0B10D
9EB60F9FB6109FB610A2B60E9FB60CA0B90FA4B511A7B511A6B80D9EB70C9BB70F9BB611
9DB60F9DBA0B98BB0B99C00C94BC0991BC0C93BB0F94BD1190C11192C11194C0128FC213
8DC31889C21987C11888C21687C41689C31788C41587C61287C9128CC61392C3118EC510
8CC50B8AC80B8AC90B8DCA0B91C90A91C50B90C60B90C60C8DC50B89C80E86C41285C315
86C61885C42180C02D80BB3681B4377CB33879B6357AC2327ACB2B78CC2478CE1E74CC1D
72CA1F72CA2272C92575CB2274CD2173CE1D70D21870D01772CF1872CE1C77CE1D74CD22
6ECD2B6FCF236ED32073D31D6FD02371CB266AC92972C82C75C42F78C22C74C82B73CB27
73C91E7CC8187DCB1679CC1874CE1570CD146ECE1472CF1075D00F78D10D7DD00D7BD10D
7AD10C74D40E6FD7106BD61170D61370DA1772DA1676D6137ED21185CF178ACB1E8BCD1E
8CCF1C88D21B8BD21B8BD01D90C42793BC288FBF2795C41A93C11C8EC3218FBA2494AA26
9BA228989D29939A2C909A3091A03190A4348B9C3C828C458192508B9854889C55899D4D
8A97519796499A9C3F88A93385A615819802808E008383007F7A007D7400787100796F00
7974007D7A007C78007D79007A7C007775007D79007A7500776A00756E00766D00736B00
7671007C77007C7B00787A00777D00757A007374006F6E00686400625800645900646500
656E00627100636C005F61005E63006162005F5F005E59005C5D006063005E5D005E5900
5C5D00595800525400534D00514D00504C004E44004C42004941004A4100474400473F00
433B003E35003833003731002F2800272300242000211D001B17001511000D0C000A0700
070500030100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
515A00505A00525B00575A00596001565F00555E00596A0858720B57750B57840D5A8810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535B00515B00555A00535400545300565800555B0059750C597B0F5C800C598609578809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576000546600556100555700545500565C005865005B710259850B5B86085C87055A8102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586D005A6F00596A00576400576200576F015A74005C7A016183035E83025B8200598100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547A01567B01567200586B00576D00577100597900597D005D81005B7D00577C00597E01
577E005883005C82015E8001617D015D7C005C7D005C7F015F8001617F02637D02648201
6788026687046987046B8703668902688C00698B006C8E00698D006B91016C8C00708900
7189007188007191016F90006D9200699B00659A00659D00689F006D9F00719A00769B00
779C01749D0473A30975A30674A50275A40074A30075A00076A00072A00070A20071A100
73A20175A50176A20276A102769F0178A40079A2007AA5017BA60379A90675AC0573AD03
77B00279AD0276AB0274AD0377AD0279AD0177B00075B0007BB2017CB20276B40277B301
7AAF007DB00082AE0085B20084B3007FB4007FB50081B70087B70189B6018AB50388B408
8CB1068AAD0484AE0688B20489B4028DB8028BB5038DB7028CB9018EB70391B70B91B60B
95B51199B41299B51299B61299B91199BA119ABB119CBB1398C01295C00F94C00F94C012
97C01599C0139CC01197BD1094BC0F96B91199BA1199BE1295C0128FC0118CC31389C312
8BC60F8CC60F89C80B88C50A89C60887C70983C40881C30880C2077FC20782C30784C308
86C50789C4068DBF028DC0018BC2008AC4018CC2008DC0008EBD008EC1008DC30090C101
92C00293C0028EC1008BBF008BBE0091BD0096BF0095C30093C2008FC3008BC5008CC600
8DC4008EC10093C10096C20094BF058AC10E83C81178CD2474CD2375CD2575CC1F72CB1D
70CC2574CC276FCC266DCC2969CC2A6ACC2668CC1E66CD1F66CF216ED01973D01776CE17
78CF1B78D11D72D22073D31972D21574D11172D00F76D11177D2127CD10E7AD20C7DD30E
7CD3117CD30D7BD20C7CD10C76D60C71D70C6FD60E72D40F76D00D74D00D77D00B78D00C
7CD50D7ED50E7ED51280D61786D51885D41C85D52086D02787D12889D12887D52387D51D
88D31B87D21F88D12484CD2685D11B89CF1A8ACD1F8ACB198AC5158AC3188AC0198ABF17
8CBD168ABC1685BD1B7FBC267BB8397DAC417DA44B8797528C915C8C925F929754999253
9E93518BA927819812868E04898C00858800828400807F007D7C007D7A008077007F7A00
797600746E007269006D64006E67006E67007068006F6B00706C00706C006F6900736900
717000706C00706C006D6800656200655D005E5B005B5100584F00574F00524900494000
3F34003C3300453D004A48004C48004D4E00535300535500565200544E004F4B00494700
484700474400494300474000413A003A3300393200373000352D00342E00302D002E2800
2A24002220001F17001511000D0B00070400030200020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
527A03547702566E00576A00566C005870005B78005A7A01597E02567A04567C06568307
5686055985035C8D055D89055D88045E85025D82015F8100627D00657C01657F01678000
6B87016B84026F84016F85016C8B016C8F006A8F006B9400689000688C006A8A00698500
6D87006B88006E8C006F8B006D8F006D96006B95006898006798006C9A006D9A006F9400
729800759702769C05749F0375A10171A000729E00759A01769901759E0173A30174A201
73A40074A50075A30275A30376A2027AA1017CA30177A90376A90473AA0473A90379AB02
7BAB017DA9017BA70179A9017BAB017BAD007DAD007BAC007AAC027AAF0579B00477B202
79B1017AAF0081B30082B50081B60182B60381B60580B80285B70085B50088B50286B305
88B10587AF0389AF0285B10188B3018BB5018DB4028DB80290B7038FB7078CBE0A90B50A
92C01097C01298BA139BC0129CC01197BB1196B91597BC1897BE1797BE1394BE1193BE13
92C01293C01194C01290C2118BC0108CC0108FC0108AC11287C21286C31086C50D88C70B
8DC60A8CC50B88C70984C70785C90681C60381C30283C30784C20884C20885C30882C409
83C40489C3058BC3068AC5048AC60787C8058BC4018CBF008DC1008EC0008CC00090C101
94C00293C2018FC30092C30193C00091BE0093BC0094C00096C10095C00092C30091C100
90C1008EC0008EC20091C40091C4048FC40B85C80D78CB1873CC1C73CD1F75CD1C72CC1C
6FCC1E70CE1E73CC1D70CB236BCD256BCC266ACD226BCD226BCF266ED31C71D21878D115
77D21877D41A76D21B75D31A74D41978D41177D10E7CD30F7BD5127CD5107BD50E7AD60F
77D6107BD60E7BD60D7BD50D76D50D70D40F6FD30F70D31275D61177D80E78D60C76D40E
79D60E7BD51080D31084D41287D51686D31A87D42388CF2A89D02C85D22984D82182D71F
82D52085D22285D22485D12389D31D89D21889CB1B88C71688C20F8AC01287BC1288BB13
8BBA1489BC1788BD1985BB2881B03C85AC477F9F507B94587E925C829A5E949B4F959D4B
919B418CA018849009848802858B00848B008380007C7B007C7700797A007C77007B7C00
7A7800797100746D006E67006E6600716500736B00726E00726E006F6C00726B006F6C00
716F00727000716D00726E006B6500656600615B005A5600544D004F4500474100403200
3726002F20003728003B3400413C004643004749004B48004C4A004E4C004A4800484300
464300434100423A003E39003D35003B3200363100332C002F28002C2400292200241D00
201600191400120F000B0B00080500030200010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4F6B01546B01566600576200556800596C005A7200567301527506507B094F7C0A50860D
5287095688065B9206589406588F065B8C045B8702618100637C00657C00637E00678200
6C84006C82006C82006F85006F88006D8C006A8D00689000648F00608B00628A00638C00
648D00658D00668C006D8C006E8E006E94007090006E92006D8F00708E00729400729300
749800729600739801719601719C006C9E006E9E026F9E06719F08729F06729D05739D05
739F0475A00174A10277A50477A30175A40178A60274AC0672AF046FAF0272AF0377AE03
7BAD0380A90181A9007FAC007BAC007FAA0080AB0082A8007FA8027EAB057CAE047BB302
7CAF017EB00182B30181B40081B40181B50881B60980B70482B50082B40083B70383B401
86B1028BB00289B10187B00081B30085B3008AB4018DB60193B8038FB80B8CBA0A8CC00B
8EBD0B90BD1090BE1296BE129DC0139ABD1392C0128FBF148FBE1692BB1393C01393C013
93C11394C0118DC1128BC41187C41085C30E85C50C83C50C82C30C80C1087FC20883C607
87C50987C70884C70883C80784C80785C50482C40385C10589C1068DC3058CC30688C004
8BC30189C4048AC6058BC50587C80986C9088AC7028BC50187C50088C4008DC10090BE00
92BD0092C0008FC00090C00090C1008BC2008FC00194BC0199C00094C10095C00194C102
92C3018FC30088C6008CC8008DC6038DC60788C80B7EC81376CA1A75CB2375CD1F71CD1C
6CCE1B6FCE1973D01870CD1D6FCD1C6ECF1F6ED0216FD01F71D02072D41D71D61B76D613
79D31277D31176D2127AD1157AD41B7AD5127BD20F7DD5117DD6127DD8147BD5137BD610
77D61077D50F79D70D78D70E76D60E71D4136FD31572D4137BD8127BD8117AD80F78D812
7CD50F7CD30E84D20E89D21089D41883D21D87D2258AD02D86D33084D52A83D82282D620
83D52282D32185D32084D22089D11B88CE158DC80E8AC40F89BF1087BC0F87B90F87B210
86B21189B71984BB1F82BB2D7DAD4580A64E80A1577C995B80955E839F57929B4D8CA147
7CA02F889D12848E01828B00848A00838400817A007874007574007777007778007A7800
7A7C00767500736D00716D006E64006F6400706A00746C007272006E7000716E00737000
716F00706F006E6B006D67006D6900696A006563005D5A00555300494200433800392E00
2F21002317002317002A2000362D003C3700423D00413C00413D00404400403E00433E00
413F00423D003F3900393400363100342D002F2D002F2700272200241D00201600181200
120D000C0B000A0800070400030100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4F5C00515C00505700505400555D00586400586D06566D0953780B4F7D0A4D7E0C4E810D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4C53004C54004E5300515100555901585E0353650554760F4E770C507908517908527F09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4A4F004B52004B50004B50005556014F5C074D630A4D78114D740B506C04547304507908
50850953880E53850F53850F567C065A7A035B77025973025B74005D77005F7B005D8100
5D83015D8002557A02547C02527D02517F025883015984005989005986005B82005C8700
628700648200617D00667900647E006883006987036A87016D8C026F8D00709702719702
719304729804719B02749E02759D01769E00769E0077A100779B00769500789400759501
759A03739905729E05719B02729C01769E0278A20379A3017BA6017DA7007DA7007EA800
81AC017DAE037EAD037EAA0380A80482A90182AD0081AF007EB50083B30082B1007FB100
80B4007FB50182B10282B20381B60183B40085B60184B10188AC008AAC018DAB0188AF02
8AB1058AB4068BB4058BB3038CB2018DB2018AB4018DB4008EB3008FB7008DC00988BA09
84C00A82BE0D85BD0E8BBD118DBD108EBF118DC00F8EC10F89C31087C31088C4108BC40C
89C30B88C40A86C40988C10989C10887C20986C4098AC40986C30884C10885C20886C308
87C00887C00983C00880C2087FC10885C00789C5048BC50489C50386C6038BC7018AC801
8DC60190C4018CC30189C40189C50189C80189C90589CA038CC7028AC80287CA0285CA02
85CA0385CA0686C60684C60187C70189C90187C70185C50187C30189C2008BC1008FC000
8CC0008AC2028CC30389C70788C80885C90884C80981CC0D79CB1C75CB3072CF3071CE2F
70D0266ED0266CD0246CD0226ED1216ED2216FD32572D52173CF1B70D31772D51978D516
79D31478D51571D61B6ED81B6DD71673D31478D4157AD51677D31678D71474D81574D517
6ED31972D61573DA1374DB1670D91F6EDB2372D91F77DA1C7FD51887D41A88D2198DD71B
8BD51787D51188D31089D31287D31884D31B86D41B86D41882D41B81D41F81D22283D424
81D82482D6257FD42483D11E89CD1489CA1685C9157ECA127EC81180C51187C01086BD0E
86BB1085BE1481BC2A7ABD3C78B54876AC5578A45A7CA1598F9F50989A4988A04684A626
819A09849101828D008189007F8200797B00747200716C00706B007169007069006D6900
6E6C006E6400736700756D00706C00706A006E64006F62006E68006D6900676700676400
686100696400696500686200615900594E005A4D00595400514D004D4800453D00343000
271C00110B000301000100000400000D07001D13002A23002E2A002E2B002B2500282200
271F00231D00221F002119001D1800171200120E000E0600080500060200030100020100
020100010100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4A51004C50004C51004D4E004D56014E5B044C62064B71084C6E04506903516D044F7307
507E07528107557F08587F075877035872035A70045A6D02587001587200567500557D00
4F7D024D7C054A7A064A78054D7C07517F075780045A7D015D7800637B00627800657C00
668100688400657C006579006A82016A84016F87046D8C03719502719400719501759901
749603729B03719B02739C007399007997007C97007B93007B94007A9500779900759800
759A01759A04749806749704719C02759A037BA0047AA0017CA4007AA6007EA5007FA800
7DAD0279AF0678B00779AE057BAB0381AD0182AE0082B20182B50183B20185AF0089AB01
86AD0184AB0285AD0286AB0184AD0084AF0085AE0087A9008DA8008CA4018DAB0288AB03
86AC0289B20387B50889B30886B2058CB5048AB3028AB8008AB7018BB6018AB90788BB08
87BE0A82BA0986C00A8FC01092C00F90C20F8DC11090C0108EC00E8CC50D89C50B8AC509
86C50985C40983C50988C30988C40882C60983C50887C30587C30586C10685C50887C605
88C40488C10985C0097DC2077BC20583C5038EC30291C3028EC2038AC40389C60387C803
87C8028AC6018AC50186C60182C60187CA0189CA058BCA028EC60089C80085C70183CA03
85CA0583C80383C60385C50388C80585CA0284C80283C70385C90289C8018AC8018EC503
8FC60592C60A94C60C94C80A8ECB0B8ACD0A86CE0C85D00C81D01679D02874D02972D32C
73D02972CE276FCE216AD1226AD0236AD2216DD32271D22377CE2376D21E77D61A76D516
78D51476D81574D61E73D41971D51476D61277D71477D71476D81674D81371D9146ED716
6FD61972D91673DC1471DA1571D91571DB187BDA1782D91289D7148DD7188BD61C8DD81A
8CD5188CD4138CD5128DD31289D31386D51285D61680D31680CF197EC92083D02081D322
82D72280D82881D42784CE2388C91786C61780C51880C7167CCB187DCA1A83C61685C00E
84C01180C2187EC02D7BBC4474B94B73B45276AE5C79A3588D9B55979A4D82A54283AA1F
829806828C008288007C82007B8300797A00727400706A006A67006D6300706C00726C00
6E66006C64006F67007066006F6800706B006C65006963006A65006B6600676600666300
645F00655F00656100666000615C005C5500594E00514B004C45004740003E3700322800
2217000E09000301000000000100000602000F08001A1200201A00201C001E18001C1500
190F00161000171100151000110B000D0700060300030200020100010000020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4756004C52004F4F004D4D004D4F00505B014E61014D6B024B6B044A67054B6C074D7308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4953004A50004A51004A54004C57005060004E66004A68044B720B466E084D6E06527005
5673035975015D78005B76005A7300537001526F025170024F71015175014E77014F7B02
4E7602517803577C045C7D055E7E07658005667D026B7B006E7900707A006D75006C7800
6C7C006D83006B84006B85006A89016E8B016E94016F9D016D9F016E9D006E9900709A00
7195007298006F97006D9500739500749300759100729300759700769300759600719A00
6F9C016E99016F9B01739B00749B0078A0017BA30178A60176A80078AB0078AE0078AC00
77AB007BB1017AB1017AAE017AAC007DAC0181AC0184AB027FAC027FAA0283AA0081AC02
7CAF0577B1097AAA077FA60282A80083A80083A60089AB008CB0028CAD048EAD0388AD01
8CAE018BAC008CAC0189B1028AAF0289AD028DAB018FB1018CB3028BB5018AB8018CB705
8EBB098DC00A8FC00A8EBF0A8EBF088EC0098EC0068EC00A8CC00A8BBF0B88C00889C108
88C1098AC0098AC4098BC30989C50588C6038AC40286C70282C5037FC20282C40181C600
88C6028DC4038AC30389C40387C40387C50388C60286C60184C50186C70486C90788CA08
88CA0585C90189C9048AC8078AC90989CB0989C8088DC80991C70A93C80A92CA0B90CA0D
90C70D88C80D89CA0E8ECB0D8FCB0D8BCA0F89CC0C8BCD0B8CCD0B8FCC0B92CD0C99CE0B
9ACE0C97CD0C94CB0E94CA0E95CB128FC8118DC8108ACA0E84CE1680CF1C7BD01D78D022
77CE2175CE2274CF2073D01F6FD1216FD21C6DD3186ED4166CD5166DD7176CD71771D714
6FD61473D61374D51472D4166CD51C6FD51A6FD61973D71B6ED8216FD6206DD91F6DD81D
70DB1775DA107DD60D80D70E88D80D8FD70B93D60C91D8118DD6158AD61B8DD41F8DD523
8CD42590D32391D61C8FD50D8FD10B8FD20B8AD00C83D40D7FD41480CE1E7FD52280D624
80D62580D62B7DD02E7CCD287ECB187CC8127CC31376BF1D7DC12380CA1E83CA1E82C91E
7BC72A75C53A75BB4874B55072B75471B75274B35874A4567E9D56879C537EB03285A815
8494057E85007B80007C83007C85007B86007C80007975006E6C006D6A006F67006E6A00
6F6A00706F006E6E006A68006B6100675D00696000676500675F00655B00615700646200
636300625B005F58005D5A005C5A00585200554A004D4600484700424000373200282000
150B00070300000000000000000000000000010000020100020100030100010000010000
000000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
495300485200475400455500485C004866004C6601496A0647740D446E09496B04516F02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4B4A004748004548004552004554004962004D6401466705456F08456C054C6E024F7301
547701557A02517A03507C05507C03537D035681025584015983015B84015882015A7D01
5C7C025D7A01667C00667C00687F006C81006B7E006C84006D82006D83006E8200678200
6984006B89006C8E00678F016290026793016891006C93006F96007095007293006D9300
6B9A006C96006E94006F8F006F91006C91016C94026F98027096006C92006A91006D9200
6E96006F9A006B98006E9E0073A00074A50073A50078A50075A40074AA0176A80177A700
78A80077A80176AC0377AD047CAA0179A70176A40178A1017EA5007DAC027CAA007CAE00
7FAC007EAD017DAB027CAA047EAB0382AC0085A70086A6017FAA027FAF0380AC0583AF05
83AF0283AE018AAD008AA90087A90087AC008AB10089B10087B2008AB6008BB9008DBA00
8CBA0089C00986BB0989C0098BC1098BC30986C20982C40982C40584C40286C50286C601
84C4008AC20190C2038DC30489C30786C30884C40883C30682C40382C30383C30284C502
82C70284C50487C60588C80785CA0582CC047DCD077BD00879D0087BD0087FD20982CF09
83CF0989D1098DCE0A8ECE0D8DC8138ECA1191C71197C6109DC40E9FC70BA0C80B9CC70C
93CC0A85CB0A84CA0A83C90B86C90B8FC70B8FC90D8EC70F92C61095C80E97CA0D9BC70D
A1C50EA3C60FA3C70E9DC70E9AC90B98C90A98C80B91CB0C87CD117DCC1C73CB236EC927
6FCD2471CE1F72D11B77D1197CD0147BD21378D51573D61473D61271D91270D71371D913
6DD9186CD91670D61571D91472D51573D71473D81174D81372D81377D60F7BD70D86D70D
8CD90C8FD50B8FD50B8AD60A88D60A89D60E88DA108BD6138AD41D8AD6228AD52488D323
8AD4268BD32488D3218CD41890D20E91CE098ECC068DD10E88D11180D31F81D22683D22B
82D12C7ED32F7BD42F78D42878D01D77CB1B79CC1E7ACB247CCA2A7ECD257CCB237BC928
7AC23778AB4873B04E70B2586BAD5A6DAC5B76A7617F965F7C905D7E965180A4177C9604
7D8701787F00767A00787A00767C00737D00727200717000727000736E006F6C006C6700
696E006F71007271006E6900676100696200686600676100666100635E006058005F5B00
5F5A00615B00615C00605D005B5700524F004D4200453C003C37003530002E2900211800
0C0900020100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
454500424200414100424A00474900464C00485D05445C04446902456B00497000497701
4B7C024C7D05507F074D8006508003557F02587F015982005C7E005D7F005F7C005E7700
607600637600637600687E00697D006A81006C7D006B80016B7D00688100678100678000
6A7F00698300668800608B015E8A02608E01668900678F016794006B92006A92006A9200
6994006C95007295006F92006F90006F91026F93046D96046C91036E96016C95006F9600
7298006F9D016F9B0171A103769F037699017B9E017B9B0079A00075A00177A50479A201
78A40075A50177A90276AA0377A90176A60079A5007CA3007EA8007CAC007BAC007BAB01
7CAA027DA90280A7027EA60280AC0284AD0385A90180A7027AAC0576B10875B50978B507
76B1047EB50284B20085AF0086B30083B50086B70087B30089B8008AB90089BE008ABD00
8BBA008AB8078CBA068CC00A89C30A8AC50A85C60980C4097EC2047FC40182C60183C701
80C40185C5028AC5038CC60388C50280C4037BC8057AC90583C80385C40485C40585C504
84C60282C70187C60387C70A84C90A84CC0980CD0980CD087ECF097ECF0B84CE0A8BCD0A
8CCD0A8FCE0A95CC0A99CB0B97CA0C95CA0E92CB0E8FC90F90C60F8FC60F91C60F92C80C
8ECA0B8CCB0A8ACC098BCC088FCD0994CB0B95CA0B97C70A96C90A99CA0C97C80C93C70B
9BC70B9ECA0D9BCA0F9AC60F95C70E92C80D95C40D96C90F90C81287CB1A81C91E7ECA1F
78CD1C74CE1974D11477D2137AD1137BD31377D61378D51475D71573D61471D71572D915
6ED9186FDB1770D91773D71676D51275D80F76D70F77D70E76D70D7ED30C86D50B8BD50C
8BD80C8CD60D8BD40B8AD40E89D5118BD71289DB128AD81288D81886D82088D6238AD627
89D6268BD7258AD4248CD31992D11094CC0D93C60590CB0E8CCC1085CB227FCD2882CE2F
82D22F7FD52E79D73279D72A78D22078CE217ACC227ACA2679CD2A7BCD287CCF2A79CE2C
75C83771BB476CBE4D6CBB516DB45C6DAF6277AA6484945F7B905A78954A7F9F14809100
8187007C7F007B7A00777700797900737600716B00726E00706B007067006A6A006B6400
6B6C006B6F006E6C00696600696500686700615F00665E00655F00605F005F5B005E5800
5E57005D5600595700595800575600534E004C40003F3900342C002D2500251B001A1100
0C0800020200000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4142004040003D3E00424500434900454800475C08455B04465D01486B00496F004A7800
4C7C024A81084C860C4A83074E7F02547E01537B00557B005A7A005D78005E73005B6E00
606E00606F00607200627B00627A00618001627A01627900637901637B00638000647D00
677C006A81006583006087005F8401618501638500648500698C00688B00688D00648E00
6D91006F8F006F9200709100728F007291026C92056894066A96056E9902729800759700
769700739E00759D01739C06729B067596027A98037B9801799D00779C0279A2077AA403
7AA20277A10278A40172A20174A40076A3007CA20180A30182A1007CA50079A5017AA604
7AA7057AA9057CA5027BA2007EA9017CA5027FAB037AAC0177AB0477B20876B30876B406
7BB50380B40181B30083B50080B5007FB80082B90086B5008BB60088B90087C00088BC00
89BB0089BB0289C00286C20488C30585C40785C40684C20682C10381C30181C8027DC803
79C80480C80682C50684C70583C70381C8057CC8057AC9047EC80482C80484C6047FC703
7FC9017FC90183C80286CB0988CA0A86CB0988CD0B86CD097ECD097CCD0B82CD0C86CB0D
8CC80D8ECA0C97CB0D9CCA0B99CB0B96CC0C92CB0D8DCD0E88CD0D84CE0F86CD1087CC11
86CC1186CC0F8ACC0E8ECC0E91CD0E92CB0C92CA0D93C80B99C90B9FC70C9CC60C9AC90C
9ACC0B9ACB0B9BCB0B9AC70B95C80A8FCC0A93CD0B9ACA0D91CC1187CB1384C9167EC919
79CF197DD0187BD1167AD0167DD3147BD71379D6127CD6147CD5177AD5147CD51278DA11
76DA167ADA147BD91479D91277D71079D50F7BD60F7CD70C7ED70C84D50D8AD50D8BD70D
8AD80C8BD60D89D90D87D60F86D81389DA1489DB1489D81789D81A86D72089D8258CD527
8BD72689D9278BD9228CD61D8FD11695CC0D90C5068FC50C89C60F88C82181CE2B7CCD32
7ED43280D62E7DD92B7BD62A79D42679D1227DCF2379CD2676CD2975CE2F76D13173D039
6DCA4A6CC6556BC5556EC05271BA5A72B85E75B16281975E789A5078A2368099117F8900
7C81007978007871007676007574006D6E006F6D006F6C006E66006F66006D60006B6300
6A68006869006768006A6600686900666B00635F005F5B005F5E00615C00615C005E5C00
5D5600565100565200575200554F004E4900443B00382F002F2500221C001A1200100700
060200010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3B39003F3C003F3B00434700454A00444E004760054A5F024B5F004E68005069004F6E00
537703537C055381064E7D035278015474004F7300517000547000586E005A7000586700
5560005763005969005B74005B71005A71005C76025E6F015C73015F7400627C00627E00
617C00678200658000668200657E00627A006583006785006A87006B87006E8B006B9000
698A006D8C006D8F00739000718D00728E016E91026C95036C9703719901749700779700
799600789A00789D01779C02769C02779801779D03759E01769F01759E0376A1077AA308
77A50575A60272A60170A00076A1007AA0007DA30180A4027DA1027E9F017EA3027CA502
7BA8067AA7047FA5027BA1017BA2027FA0027CA9017CAB007DAC037DAF0379B30378B303
80B20182B50081B50084B70181B90083BA0183B9028BB6028EB5028AB90086BA0183BB01
7FC00283C00284C10386C30585C30285C50284C40586C40885C00783C1047FC6057CC905
7AC8057CCA067CCA0881C80983C90780C80880C7087BCA0679C9057FC80182C60180C701
82C70086C7018BC80A92CA0A91CA0B8FCB0A91CA0A8BC90B83CB0A7FCB0A7ECB0E82CC0E
82C81085C9108CCA1292C81291C7118EC80E8CC60F8DC90F89CB1088CB108ACB108ECA10
89CB0F8BCB0F8FCC0F8ACB0D8ACD0D8CCC0D8DCB0D8CCA0B90C90B9BC50C9CC70E95CA0D
91CC0B90CE0A93CA0B94C60D95C90D95CB0A92CA0B97C80C95C90F91C90E8ECA1285CA15
85CC1984CE1883D1167FD1167ED4127FD61180D61083D51083D41083D50E83D40E82D60F
81D81082D71283D90F83D80E83D60C87D50B88D50B89D60C88D80D8AD7108BD80F8DD70F
8DD70D8AD80D89D80C87D70F88D91488D91688DA1C87DB1D86D72084D72587DA2587D621
88D92285D72289D81C8CD81E8ED51C8FD00E8BC80A8CC10B8BC60D87CC177FD3277BD430
78D32E7AD4297DD72577D62978D42B7DD12B7AD22B77D02A72D3296ED52E6FD3366ED042
6CCB526ACC6167CF5F6CC95872C05A71B65B73B05B769D5E77A84078A81F7E920D7C8200
767C00787100746C00736E007170006E69006D69006D69006C65006F64006C62006F6A00
6E69006A65006B66006861006868006869006A6600636300605B006158006061005E5E00
5B5900565100544F00524E004E4B004A4400413800362F002E2300201900120D00070200
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3C35003D3900403D004342004551004653004B62024B65014B60004D64004D63004D6502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3C3900414100444A00474D004B58004956014A58024D62014D5F004C6000495C00495C03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4140004747004A4D004B50004A5700475802465A034D5F014C5E004D5D004A5900475B01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4643004643004A4C004B4E004B5000495D01465F014B61014D64004D62004C5F00495C00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4948004949004C50004D55004959004D63004963004B69004B6A004C64004B63004B6100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444F00454F00475A004C60004A64004B6F004A6B014B6A024C6C034A69034E66024D6501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435300445500465500486500446600456E00466C03456A05496B064B69064B69044C6B01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4050004351004555004661004563004363004664024661044A64044869054A6B034C6C01
486A00466C00466D00486E004A6C004A6C004B6C00486501455C014958014F59004D5B00
505D005159004F5A00535E00505F00536600556B00557100537200527100527700517800
517A015175004B7201497C02487E044B8103517D03537F025583015981025B8301597900
5976005D6F005C74005D7E01617D00697F006B7B016D82016C8A01698F00688A00698401
6F88016E8C00749000758E00759501779502749B02759D01769F037B9B02799F0378A204
75A70A70A60A74A4097A9F037AA20176A50078A90079AC007AAC0079A7007BA50178A300
79A70379A7037EA6017EA5017DA8037DA7027BA5017CA5017BA80076AC007AAC0578AA08
7AA80478AA0079A8007DAB007BAC0080AF027CB3037EB3017FB10082B90282B80483B906
82B80481B50281B9017DBB017ABD017FC00480BE0580C10A82C20B7EC40B7AC4097DC705
7DC5017CC6037BC80781C50A81C4097FC8097DC8067FC60682C20585C10283C30A80C50A
79C60982C50E8BC50F92C20C92C30A88C8097FCA0A7ECC0A7FCB0D86C90F8FC50E92C40B
8DC20A87C70C86CC1182CB1289C50F8EC60E8CC70E8AC60B88CA0D8ACC108FC81298C014
98C11599C111A0C20D9BC50B93C70C8DC41591C41592C31394C40D90C60C90C41691C314
98C0119BBE119AC11495C31692C11591C31492C21991C31E8FC52287CA1F7FCC1A7CD114
82D61485D61986D51182D41282D51384D51385D31480D3107DD40C7CD50B85D50C88D80E
8AD61088D21489D5118BD70E8BD60C8AD40C89D20E8CD3118BD0158ACC1B88CE1D88D31D
89D31F88D41C83D51584D51489D41485D31380D31381D21182D41083D11184D11084D111
80D1137DD0167AD2177DD31985D1178CCB0F91C00592B70090B50093B9008FC60A87CD11
7DD02779CD3076C63A71C14071C04B74BB4B75BE4976BB4571B64570B34C6EB14D65AE53
6BAF5565B35264AE4A6AB63974B11E7A990E778003757A017076006D7000696B00636300
666600646100635C005F5B00615A00666000676200676000655F00665E00636000615D00
6261006763005E61005D60005F6000595A005558005859005359005352004C4A00424400
403800332E002E2600251C001E1600140D00050200000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3F4A00414F00405200425B00465C00465A00465C01475701445601456302466201456300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3B42003E48003E4900414E00404E00404E003F5100434E014053013F5D01415C00435700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373D003A3F003940003A41003A4500384801374D01394C03384F053B54033C51013D4D00
404C00404900434C003F46003E42003E42003B43003C44003D48003D45003F4800434D00
445500465A00465800496000455D004760004B69004B6B004D6C00506C00516B00566B00
536900557200547800557800587D005879015B82075B85095B89045C8402627E01647F01
648300638A00688B006D92026C8F046A8E036A8B016B87006C87006D87006A89006D8900
6F8B006D86006B8A006C91006B94016C97016D9601719C09749605759202738900758D00
759000749803739502749502789702779701759B0070A10070A00076A00076A20076A500
73A10272A60671A30674A50571A40372A90270A8006FAA036EA6056EA50270A20078A000
77A70077A9007CA70078A60077A90077AB0074B10074B20176B70376B90875BE0972C009
73BE0976C00577BD0677C00A7CBE0A80C00481C00079C30075C40174C6017BC8047DC903
82C60181C5017DC8027BC7047DC70680C6067FC6087EC4097AC60479CA0281C90D86C70E
88C70D82C70C7CC70A77C80A7FC60D92C40E94BC1192BC118DBE0E8CC10C88C60A85C70A
89C50D8CC0148BBF1587C11285C20E8FBF0D9AC00E8CC91089C71196BF1194C1108FC00D
83C80F85C4118FC01592BC148FBE118EBE0F92BB1098BE1193C11B94BC1BA8B4169DB711
94B90E97B8129BB917ABB222A2B52B95B5328CBC2E8ABC2E88C03085C92884CD2482D020
84D11D84D21986D11986D01A83D01A89D1178AD41387D31786D51987D21488D4108AD60E
88D80E8AD50E86D50D89D40F8AD21288D21388D3148CD1128CD2108FD20E8CD50D88D20D
88D20E85D20F83D00F84D00E80CE0E82CE0E82CF1183CC0E82CB0D83CC0E83CB0D83CD0F
83CA0F83CD0E83CC0E82CA0E84C30F8BB6088BB00088AA0087AC0089AA008BA50087AA00
86B20183B20186AB0186A70282A60182A303849F03869D02819B017D93017C8B00798800
7783007A84007684007784007486006D82006D7900666600635F00625D00666500626100
605B00615D00636100656600676900636400645F00665F00626500656600626500625F00
5A5D00595A005D5F005E60005759005351004C4A00454A00444400413E003A3600312C00
2820001B1600100B00070300040200020100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
333400353800343700333A00354300334901324D01344D03344C043D4F023E4A01414800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2E2C002E34002E39002C3E00304900314D003350003853013E5101414E01445600455300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2C2C002D3000304406304A04305A03335D00395F00426100455E00476100486601476600
486800486A01466D01466D00456800426400456200456200496600486700486C004C7300
4A71004A73004877004779004B7A004B7C004978004D7B004E7A00528002557A00567500
597501597400597700596F005A71005A70005A6C005A75015671015D75005E6F005E6B00
5F68005E6B005F6E005E68005D64005B62005B6A005966005967005A6F00617300637C00
667900667E006581016590026B91026C8F056A8E0A69900C648F0960940861990A639B0B
6797076C95036F94016F97006F9B006D9E006E9B006D97006C93006A95006D9C026C9D00
6F9E00729900739A00739800759900759700739B00739A00759A00799800799C00759F01
75A10074A70074A80073AD0075AE0075AF0077AE007BB0017BB20279B3017AB70375BE06
74BF096EC00570C20376BF0078C20375C60473C60371C60472C50474C50774C60577C503
7BC7027EC80480C60581C40282C6007FC60182C8047EC80981C70686C50189C2018ABF0A
81C20C81C01089BE128FBD1592BE1394BD0F89BE0D81BF0F8CC00E85BF108ABD1298BB11
97BC1098BC0F8CC40D8BCA0E8BCC0F89C51090C01697BB1D9BBA199EBA1095BB0D92BB0F
8CC01A8DBB1F90B71F97B5179BB50F9EB80C94BC1897B7259DB81AA1B810A2B90D8EBC15
88C01F9FB11CA2AF1597B218A2AF2AAAAB2FA3B62C93BA308ABB2F83CC2984D22584D42B
84CF2D84D12987D22483D31D82D51982D41882D41782D41485D21385CC1484CD1286D114
88D2118BD0108BCF108DD00E8BD11188D31183D41489D31684D01986D21586D51384D611
88D1138CCD1187CB1182CB127DCF147FD20F7ED11078D00D76CF0E79CE0E78CE0D7BCA0B
7FCD0B81CA0B82C50C88C0078EB3008FA5008E9E00899C008A9C008EA3008EA50087A000
84A001839D01839900829400859300859300818E007E89008089007F8B007D8700787E00
768300748000707A00727400727400717500727900727E00707B006C7100666700625C00
645E00625F00615B00605C00605E00635D00605D00595A005958005B5C005D5D005F6000
5B5D005656004E4D00484600484700474500423E00373600322F002B2B00231900140F00
100700050200000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2E3700313D0031590D335E0B336207366C03376A00406C00456E01466F02477603487302
4475024275033E74043D73023E6E00406900456600466700496C004C6F004A73004B7800
4974004973004875004777004B7C004A78004978004C7A004E7A00527701517300536900
567105546B01546901546600525E00546100535A00526000525D00556300575E00515C00
525A00555B005663005463005863015964015865015B69015866005D6C00606B00647200
647100657600647B0162830265920365910668950B69900A669008629509629B0B68990A
6C98056E95026F97016F9A006F9C006E9D006B9A016C96016D97016C98006D9D026C9F00
70A30072A001709F01719702759600729300749700749B0074A20075A00076A00079A300
79A90075AC0076AD0076B00071B4006EB10072B00078B20079B30077B30178B70179BC04
78C20770C00574BE027ABD017BBE027DC0047CC2027AC70679C20676C20471C6036DC804
74CA0578C6077CC5067FC20380C1007BC4007CC1037EC30583C50386C20087C40885C40B
81C30D84BE1091BD1593BE1399C00F93C20D88C10D8EBE0D88C01391B815A1B216A7B411
A0B61196BC0E92C30D92C60E8DCA128BC31690BB1991BC1D9CBB15A4B809A2BB0C9ABE11
8CBB1F90BC1B98BB1198BA0F95BB0B8EC1148DC01D95B625A1B21A9DBA0F93BD108AC017
8AC01B9FB615A0B30F9BB418AAAD27AEAB2BA0B42D8EB83289B93184C72B87CF2287D22A
85D22883D12686D41E84D31B81D31781D41084D41085D30E83D30D81D10E83CF0F85D013
89D0148AD2158DD4128CD21086D31285D51186D51788D21687CF1683D11583D40F84D710
89D51388D11389CC1286CA1181CD1383D10F7ED10E7ED20E7FCF0F7ECB0F7ACD0E7ACB0F
7FCB0D87C60C8CBE0691B50193AD0092A7008F9C008A98008A9A008CA0008AA20085A300
83A500809D007F94007E9100829100819500838C007E84007B80007D85007E8800788200
7681007680007180006F79006E74006C7200727400747D00787800747700696B00636300
616000636300646500656600615F00605A005E5200585200575400585A005B5D005C5B00
5857005254004B4A00464400454200423F003F3A003633002D2800241D00170F000B0500
020100000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
324500334F0033680A346B0A366C083A6E033B6E003C6D01417404407507437C07437A04
3F75033C7003357106346F04376E02376C013D6900436B00436F00477100477400457500
457100466C00486800496A004A6C004F6D004A6F004E72004D72004C6F004C66004D5F00
4F65044D5A014A50004C51004C51004D5300494B00495100484F004A50004E59004C5A00
545900535900566701566602586402576D04536E045970025D6D015F7000606D00657102
637100607100627C01658301668E0165910469950569920464930566950C63990D689707
6A96026A96016E99006C9C016C9B01699D02689D026A98036B94016E91006E95016D9A01
6FA00171A1026EA003719A02749401739400739C0070A0016FA80171A70074AA0074A901
74AF0272B20272B30072B4016EB50169B9016CB60172B50072B40277B60577B5027CBA00
80B9017CB9037AB70179B80176BB027ABD027CC0027CBE027BC20478C00272C50273C606
75C4097AC2067EC30381BD0284BD0082C0007DBE007EBE0183C10188C10089C40B83C50C
81C50E87C21093C01599C21099C00C8EC10E88C11191C1128DC01298BA16A3B319A3B215
99B80F8FC61196C10D95BF0F92C0178CC01990BD1897BD169EBA0FA0B80B97BC1196BA1F
93B71D94BC159DBC0F96BB0D8FBE1087C5178FC01D9CB524A5B11E98B81493BE2392BE1B
9EB81EA1B61592BB1388B923A0AE25AAAA2B9EB22F8DB83387B72F86CA2B85CE2887D129
87D32383D52185D61A84D41781D41381D31080D41183D61086D51284D31188D21587D317
87D21588D21388D21282D41280D41983D41A80D31D84D21983D01782D2137ED40F80D410
81D41383D31887D1138BCF0E8ACD0D85CF0E7DD00E80CE0E82CC0F81CA0E7EC80D7DC50E
7FC60E84BC0E8CB50492B00093AE0090A9008BA2008A9D00889800849800869B0081A100
80A6007F9C007E90007C8B007E8E008191008391007F89007C84007F86007D85007C8200
798000748000718100707E007278006E71006F73007173007272006C7900697400666C00
646600636600646800656A006262005D5B005A5300534F005552005A59005A5E00555800
5253004C4F00454300404000403E003A3700383400302900231D001A15000C0600040100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2F4F013256003368063868073C65063E68023D670039680338730738750A37780B377909
347405316E052E6D072D6C05326C04336B01386A003A6A003C6B00416E00416F00427100
426A00426000435A004758004B5D004B61004B63004D65004C5F00495700475600454E00
474C013F40003B35003E3E00414400494900444500434100494B004A51004E63004B6800
516C00556B00556C02577605577404567103576D035B71015E7400657700647500607700
617801637800638200668400698D016A91016A960167940165970364940A629409619503
6593016696006795006692016290026598036798036A96036993016C8F006B8F006B9200
6C94016E99016C9A03709B02729901709C006CA2016BA8016BAC016CAB0171AE016FAD03
70B10570B30270B7016AB7026AB9026BB4016EB1006EB1006DB40473B50978B4037CB500
7EB6017BB40177B60176B70175B80178BB0379BC047ABF0579BF0875C0076DC00472C206
76BF077BBD0482BE0181BE0181BF0084BD0183BD0182BC007EBD0082BE0088C10E87C10F
88C01191C10E98BE0E9DC00F94C10D85C60F86C6108AC61390C3128FC4168FBD148AB813
8DBC0C93C10C91C10D8BBD148EBA1E90BA1A9CB910A2B70C9FBA0A9FB90D97B9189AB825
9FB41F9EB7199EB91399BB1193BF1590C01491BC209FB7249DB416A1B4169AB41C9BB724
A8B123A7B11593B6178ABB24A1B225ABAF2A9EB4348DB73688BB3086C82E87CC2E84D02C
86D22184D51C81D61781D7167FD51582D51581D31A80D41E81D51C81D41585D31288D413
85D21185D00F82D10F84D21182D21383D01783D11E82CF1986D01583CF1080D00E7ED10E
7FD50F80D81384D31186D41083D30E7FD40E7ED10D80CC0D7ECB0E80C90C7DC80D7DC60D
7CC10C82B4078EAE028FA7008DA7008DA6008D9B008A9B00899500859200849300869F00
86A000869E008290007D8400818400838E008494007F90008189007E86007C83007B8700
7A8200798300748400718300717E006E77006C74006E6A006B6E006A7200687200687100
6669006367006067005E68005D63005E5F00585600565100585500585700565900525500
4E51004848004141003C3B00363500312C002E2700241A001710000E0800060200010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
304A01314D003351003A5B013858013A5B00375D013062032E6D062D72082E750B2F730C
2D6E092B67052B66052B64043065033366013566003764003B61003B5F004064003F6300
405B004153003E4D00424900445100465600445600465300434D004144004041003D3C00
353500312B002C26003830003F3F00444800464800494B014D58014E60004F6E004D7200
5672005777005776035A7E05587A035B75015971005F7800617900647A00647F00648200
658601618200628900658901629104659303679B01669B00629602629507609406609402
628E00659101668F01658602648501638E036290026496036695026B93006B8D00678E01
6893016B9B026D9B026FA20172A30170A5006CA90069AD016BAE016CB10169B4036BB304
6FAE0471B0026EB2016CB4026EB20170AD0073AA0075A8006EAF0271AD0375AF0275B200
75B40175B3016DB4016FB70171B50275B90375BE0377BD0877C00A73BC096FC1076FC108
72C00779BE037DBD017DC0007EC10083C30185C10280C1017EBE017FC20180C4038AC113
97BF1398C00E92C00B90C00C8EC30B89C40E8AC8138CC51292C1138DC41482C31079C70B
81C10A91C10D92C11195BE1D97B8229BB618A0B50EA2B70B94BD0C9DB61499B21A9DB321
A4B2279AB41699B6119ABA1098C01792C0179AB81D9FB01A9CB5129BB3129FB1169CB028
A4AF26ACA9149BB21392B91F9FB627A4B12C9EB53390B83086BF2B83C62A87CA3184CB31
86D22789D41E86D6197FD51482D51580D3177CD2197BD21979D4177BD41080D60F86D50D
88D41183CE1780CD1386CE1386CE1187CE1486CF1E89CB1688CD1289CD1281CD117ECE12
7ED41181D81085D41184D6107FD30F7BD20D7FD20D7CCF0E7ECB0E80C70C7EC90C7CC60C
7FBD0784B20188A7018C9F008BA10089A0008A98008A9600899300858E00849400859B00
8AA100869D00818F00828400808300808600838B00808E00818D007E86007E85007C8200
7A83007A8600758000728300728200737E00727C006D70006A7000686F00676C00686D00
656C006265005E65005D62005C60005A6200575C00585800545500525500535800515800
4C5200454400403D003934002F2B00272000211900150F000B0500050300020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
314101324100334400334B002F4B002C4C002E58012A5F03276C04266E04256E07296B08
276305275E042A5E022D5801315301355400385500385400384F00374F003653003B5100
3C4A003A43003A3E003C3E004140003F44003E41003C3E003A4000383C003A3D00383A00
342F003027003128003F3A00464700495300495B014961034C6801516900516900566B00
586D005C71005D72015F79025D7A015F7B005F7C005D8000638500637F00678602648B01
6291025D8F005C92015C8C045D8F0A5E94085D96016096006093016294035E9303609101
6288006088015F84036282025E81005C89015E8902629707659A046A9701668E01679202
64990369A1056BA5036FAA026EA8016FA7006AA70069AC016EAB016FAC0269B2056BB504
6CAF0271AE036FAE046EAC036DAA026CA80174A60071A6016EAC016FAB0072AA016FAB02
68B00269B10268B30267B7016CB20172B70274B80277B9047DB90978BA0775BD0875C009
74C10A74C20875C00274C20079C4017FC80182C4037EC1037EC0017DC1017CC2068ABE13
94BD1099BE0D8CC20B83C40B8AC10C90C30F8BC21490BD1994BE198FC01083C40B78C709
76C60A83C2118FBE1798BA1DA2B324A2B315A3B10FA4B00B92B40E9DB51395B31F96B124
A3AE2999B213A2B4119ABB1298BE1490C11B97B71AA6B2159EB10E9AB81297B5209CB126
A5AE25AAAD17A5B1179EB21C9FB7289FB82998B92F8CC12D81CB297CCE2782CB2D85CF30
89D1288BD42085D31C7FD61981D51580D5167CD3187AD51A79D51D77D7187DD61381D510
89D31285D01C81CF1587CE1587D01687CE1687C91D85C91382CB1380CD1280CE1280C916
83CF1186D51088D40F83D0107CCE0F7FCE0F7CD30E7ED20E7ECE0D7FC90E84C50D82C007
81B60386AB0085A600869E00899F00899E008998008696008A9300888E008690008A9400
8A9900859A00848E00828A007D82007B7C007C7E007E81007F88007E83007B81007E8300
7B84007E8900778400738200727D00707D007380007275006E7100697000666E00626700
6266006266005D61005C6000575C00545900565B005557005350004C4E004E4B004B4D00
494C00414100393700322C002720001D1400150B000A0600060300030200000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2F36002C37002C35002E3F00294000244500285103265906245D042562032760032A5A02
2956022754012953012F4C00314100333D00313C00323F00353F00323900353E00373800
323200313500343600363400353200353400373500363200373600383C00383C003B3E00
3B3C00403900423E00464E004D60004B66004E6A01526D01557501556E00556800586600
576700586E005B6D005D75005D7A005E7F005F83005A89005F8B006186005E8B075B8E03
5A8F025C8C005E88005C8A035A8E085894075990015C90005E90005F91015D90005E8B00
628400637C01617C025E7D015B7E005F84015F8901648D01689C06689701699601689502
689D036BA2056EA8036EAB016CA9016BA70068A40166A3026AA3026EA90369AC036AAF03
68AF086BB1096BAE0A69AD0967AB0767A90471A50171A3006EAA016BAD006FAD016CA901
66AA0363B10462B3036CB20172B40174B50178B40277B70278B60575B70475B90579B805
7ABB0676BE0772BD0275BF007AC0007EC3017EC2037EBE037EC0027BC0017AC1038BBF10
92C00F8ABD0B87C20B89C30B8BC20E89C11289BC178DBA1996BA1790BE0D89C40A84C50C
7AC4107FC11487BF1593BE1AA2B923A8B511AAB00EA7AF0B9AB2109DB61791B82296B322
A8AF1BA6B00F9DB40E96BB1692BE1B8BBA1A97BA18A3B811A4B60E9BB60F99B7219CB324
A7AF24A7B11BA3B1199FB12197B62B94BA2B8EBE2E87C82D82D02F80CB2B85C82A85CD2C
88CF2B8AD12784D42680D41B7DD6167AD61878D6197FD51880D4187ED31780D41480D311
82D51382D6197FD41980CE1982D11B86D01985CA1A86C91484CB1483CE1284CF1282CE12
85D01089D10F8BD10F86CC0F7ECE117ED3107AD10F7AD10E7FD10D82C90E86C00989B900
87B20089A8008AA5008CA1008AA4008B9D008797008696008695008A9500899300879700
869700839100808A007F8A007A8600757E007777007677007C7D007B7C00797900777A00
7B7E007A8200788400778400707C006E7C006E7A007076006E76006C7100686F00666C00
646A006469006165005A5F005559005354005053004D4E004F4700484200453F00424100
403E003B3A003631002B23001D1500100700080500030300020100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
252D00272F002632002A3500253600233D00264801264D03234F02274F01284900284600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212900232E00242F00253200233600223800213C00233D01223D00273B00273700263400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1F2700232E00243300243700243800233700213700243300223000252B00272D00282C00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1D2800213200233A00203C00243E00223900223600233200232F00252B002B2F00283600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192F001A34001F40001E3F00204000213900213900243B002738002636002B3D002B4300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1631001932001C3D001B3C001C39001D36001F3900254000264000273C002C42002B4100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1232001432001A38001C36001D33001E3200203500223900274300283C002A3C00293800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1530001630001A35001C31001D2D00202E00212F00223200273900273300252D00222A00
1E22001A1900141100100D00120C00100E00110E00140E001210001A16001B1D001C2100
212500222500232600252500201F00211D00221C002422002A2B00292F00313700313900
3438003740003947003B52003D50003C4E004054003E4C00404D003D4B003F57013E5600
3C53003E58003F5400415E00436000446500445F00415600445800465B00496200476200
486700486300476400477308456D01487100476600476000475A00475C014660014A6C01
4D7301517700537400537100526800526C00506D014C72044E75044F7601507600507200
4D72004E6C00547200556D00576B00586A005974005C8000617F00658701648901668D04
638901638800658A00689100689000699402689402679A026A99026CA2026EA80572AB06
71B0096DAC066CAF096CAC056DAF046FB50570B5066FB1036FB10175B10276AF0276B402
70B5046DB50271B60174B40079B3017AAF0176B40278BB0277BC0277BF027AC1047DBD01
7BC5108ABF1591BE1694BA1B98B81C92BB188CC21587C31585C51288C5138EC3138EC013
8BC0188AC21B89C4158AC6138BC61287C7108BC70F91C11092C01490BF178DBE1D8FC021
8FC42491C8258DC62789CA2387C61E87C52087C51D8FC81A93CA1996C81894C61C94C522
95C2248FC1228DC4208DCA1E8CCF1B88D21689D11486D2137FCE127FCE117ACD1376D015
79D1157AD31B7CD5217CD62971D63374D42E6ED0316FD4316CD72D70D62F6DD62D69D42B
6AD62770D52077D71C7AD51B7CD31779D41C73D42170D11E69D11C6CCE1573CA1377C816
7BC0107DB90D86AE058AAA008DA6008DA6008FA70090AB008BA90088A70085A20085A300
84A100859F0086A20089AB0086AC0086A1008699008594008291008091007E9400809700
8199007C98007B93007D8F007C8D00778A007A8B007A8B00788700788600768100717B00
717C006E78006A75006973006770006369006163005D63005C6400575D00535600515100
4C4B00474200454300403E003939003433002923001F1800150F000B0700030100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
162B00172B00162A001D2B001C28001F29002028001F2400222B001E22001C1F001C1B00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152600162400162100192000181D00161A001919001617001A1B00181600141500141500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152100161D00151900151600121200101000141400121300121200171400131500131600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0F1100121500111000110F00100C000D0A00111500111B00121C00172200171F00181D00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0908000D0C000C0A000A08000D0C000D0F00111E000E25000E2500172B00162700162000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0504000908000705000705000E0D000D0F000D14000F2700112300121F00172200161B00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0302000606000505000505000C0E000B0E000B1200102000111C00111700151900111400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010100000000040400050300090C00090B00090C000F16000E13000E11000E0F000D0B00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0000000000000302000302000201000606000706000606000B0A000909000A0700070500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000000000000010000010000010000030200030200030100060400040300030200020100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000000000000000000000000000000010100010100010000020100010000010000000000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000000000000000000000000000000000000000000000000010000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020100020100
0404000505000605000C0C000C0E00121F001424001528001823001D22001B1F001D2000
1D2000202500212700283500273F002A49002A47002D3F002935002C35003140002E4601
3250003448003340002E3C00313A00334000344700345300345B013653003D4E00404D00
414E00435000455100414F00404600434B00435000434D00424A00454C00465600485200
4855004A5100515900556800586F005A6F00597701566D00556E01566D01576F00546F00
587300556E005175005271005376015475005873005C80005E8401617E006078005F6F00
6170006070005E77005D7E00587A005876005870005C6C005A6E00567A01557C00577D00
5979005875005A75005B77005A75005A6D005B6D00586A005A6D005C7200607900617A00
5E7D005B7A00597400566E00566800556800566500515D004C5A004A5F004C6000496300
4859004555004047003A4200373A002F3100292700221B001711000D0900070500020000
010000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010100010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000100000000000707000808000808000D18000A1A010E2701
0F2301142101131900181C00191D001B22001A24001F3100223A00233B00253800233000
2533002234002738002838002938002A38002F3C002D4100314200303E002A3A002E3900
2E3C003340003540003A4D003E51004159004159004055003D51003B4F003E51003D5600
415B00476C014A68004A63004A5F00465500414F00404900424B00444F004859004F5F00
4E69004E6B004E6B004D6C00546E00546E00527501527A015978005A6F00566700536200
586700566901536501526B01566E00556A00576D005A7700597A00577100546A014D6402
4C65014D63004A64004B64004C61004D5F004C5E00465F004159003E52003A4500333800
2C31002A2B002323001F1B001B1700110D00080500060100030100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000404000404000913000816000D2501
0F2001121F00121800161800161700181C00171E001F2F00203600233A002234001F2B00
1D2700232F002738002736002A38002936002B39002C3D00324500314100303E002C3A00
2D3E00323F00333E003846003A49004056003E59003C57003B5300384D003D52003D5700
3E5F00426100466800486C00456701455D00415400404A00404A00424D004755004F5F00
4C69005169005068004F6C00506E004F6A004D6D004D7200547200556B00546600526500
546600576700526500536900546900556800536300536700546F005769005160004E5D01
475A00455B00445C00475A004656004452004354004053003B4D00384900313800262A00
2421001C1E00161600130F000C0800060300010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010100010100060600070A000B1D00
0C17001218000E10000C0C000D0C00131700131B00192D001834001B39011D34011D2E00
1F2C00212A00202600252F00273100272F00242C00262C002830002C3D002F4300324300
364000323B00363C00313800353E00394B003C5400395801385600365100355400365800
3C59003B59004264013E6D01427301457801436D014866014D6200475900454F00464F00
4E64015071014C6E004D6B004870014C7C004E77004E6B00526A00556D005369004F6100
4C60004F62004A69004D6900506C004F6C00496400465E004458004052013F5000424E00
404A003F45003941003A43003345002E3F002C3D01273200252800202200191600100E00
080600040200020100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000040400050500
0B0C000908000C0D00090700080800080700111700111E00143200183D011A35011E2E00
1C28002026001E2200252B00262F00272A00212600222300252C002C3D002B4000324500
353F00323A00334000323E003745003649003A4D00385300375500345500345600355600
3554003857003C5E003964023E7204417603427001486B014B6A01496100465600444F00
4A5C004B67014C6D004B6E004B6F014E7B00537B00517000556D00546D005366004F6200
4C5C00515F004C64004B64004E68004B6700466201445900404E003F46003B4600383E00
353B003236002E2F002E3000262D002426002225001B1800161100110B00080500060300
030200020000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`002P3ooooE000000800@0000X00P4000@200050P001`8000T300080`00
2P<000L200080P002`800P0<1000900<1`004`P001P=000J3`0060`001D<000E2`0050/0014:000@
2@0050H00188000D2@005@/001X<000M3P007Q0001hA000T4@008a4002@C000W5`00:1@002TH000Z
6@00;Q/002dM000^7`00<R4003@S000h9P00>2L003@U000c8@00<240038Q0080<b<002X0=R8003TQ
000i8@00>R8003TS000h8@00>b<003/T0010:P00@B`004@[0015;@00ARh004<Z0014;P00Abh004X^
001:<000BRl004/_001<<@00C3<005<k001D@000Dc`0058k001B>@00DCP005@o001GA@00E4P005I?
001EE`80DeT7051U401<Kb80@7Lf03Mh@P0bNE80=HIA03fK@@12Wbl204:P9P0=046Q8P0kYR`0<JXe
02^[<P0/Zb`0;JPU036O4P0lU`P0A8d404Z7101<Q@D0BH<204^20P0204J41@0H04J51`11P@X0@84?
03mk400oM@X0A74604E[1018I0D0BV8504YR101;H@<0CU`205=H001ACP00Cd4004Te0013;000?RD0
03LS000c7`00<Q/002lJ000[6P00:aL00P0Z5`007@0^5P00;AP002`I000]5@00;1@002PA000U4000
910002@B000R3`008A0001l@000P3@007Ph001l>000N30007@d001T9000E1`0050L001@4000C1@00
40D00104000>0`002P4000P0000400000P0001l00000303oool000X0ooooc`0000070040000;0041
00030@000`4000<100070@0020<000X2000910002P8000/2000<10000P0>1P009`0A1`005@X001T=
000J3`0060h001T;000G2P0060T001D:000D2@005PT001D9000C30006@d001h>000R4P008140020C
000S4@008a@002@C000V4`009aP002LI000Y6@00:aX002dK000^6`00<20003@T000g9P00>2@003@Q
000a7`00<B40038M000b7`00=Al003LS000203LP000W03XP000m8@00?R<003hT00109P00?b/0048/
0016:P00Abd004P_0014;P00Abl004T_0019<000BRl004/^001;;`00CS8004hf001B?P00ED<005M2
001B?`00ET00054o001EA@00FD/005YB001GF000E64604mY3`19LR00AWDd049_C@0jM5/0=7aQ03B:
G00jVTd0>jDo0080=jPn02L0<j/k036[@P0[[TD0:Zdm036[<P0cYRL0?9`C042C1`14SP@0AX`504J;
1@13RPD0AX/404>=1014S@D0@H/903n63@0lPQ00?WdA03mg3P12L0T0@V/704EV1P16HPD0Af4404UN
0`1?F`40EeH005M?001?@P00CCT004Ha000l9`00=24003<K000`7000;QX002/E000Z4`000P0Y5P00
500/5`00<1X002dI000[5@00:A<002PA000R40008`l002DB000T4@008a80024B000O40008100028>
000Q30007``001X8000F1P0050H00P0D1`001`0A1P0040D000h2000:0P00200000@0000200007`00
000<0?ooo`002P3oooo>00000003004000030@000`400080104000h01@4000H1000700001P4000L1
00060P002P8000X4000<1P002`L000X5000=0`002P@000/600803PH000T05`X001P<000I40007Q80
024A000M3P006`d001T=000F2`000P0F3000300H2`0070`001h?000Q4P009aP002LG000W6P009AT0
02HH000W60009aT002LJ0080:AP000T0:AT002dM000`7@00=1l003DS000f9000=B40034O000_7@00
0P0`80000`0b8000=R0003<Q000203@P0080>28000/0?R@0040U0010:000@bL0044Z0012:`00@bd0
04P[0015;000B2`004X`000204T`000H04/b001<=P00CSL005<i001E?P00E4@005A6001DB@00EDH0
05I6001LBP00FU<005IK001CIP80Cfl:04]h6P10O340@7E;04IZI@11LW40<X5c036=KP0dVel0<jIE
0P0]Zd/09`0[[4P0:Zm902R]AP0/[3P0=JLX03ZO7@12U`h0AXh504F>0`16S@H0@i07042B200oU0P0
@I@8042@200mSP/0?8L?03Z2500nOQ@0?GXD03ec3P10K0/0@fD7049S1P15H@@0BF02055M0@1EE`00
De800553001;=`00@S8003`Y000h8`00=1h0030L000^6000;1D002/D000202XG000<02dH000[6@00
:aP002`F000Z4`00:10002D=000W3P009a4002DA000W3`008a400P0R40003`0Q3`0080d001l;000K
200060P001H9000E2@005@P00187000@1@003P8000X100080000100000<0000O000000`0oooo000:
0?ooolX0000000D00@000080000200000P4000@1000200D2000600@200060`0020<000L400081@00
2PD00P0:1000200>1P004PP001<9000B2P004@P000h7000<1P003PP00P0B2P001@0F2`006`h001dA
000P5@008Q@000807a4002007Ph001`>000L3`007@h001h>000L3P007a0002HD000Z6P00:a/002/L
000Z70009a`002XK000/6`00;Ad002hN000_7@00;R00034Q000f8000=b8003HS000d8P00=R8003<P
000b7`00<Al003DO000e8P00=Ql003<Q0080=R8002L0=b0003XP000n8`00@R@0048Y0014;@00@R`0
04D_0015;@00ARh004@Y0015;P00ARl004T_001<<@00CSD0058i001@>P00DC`005E1001DA000DT/1
05=;0P1FB`40F4/105]?001LF@40F6H4059d2@18OaH0@X0]03miA`14KV40DV=b04U[N00eOgX0;HUh
036CJ`0`X6<00P0ZZUT09`0[[E00:je:02R/@P0_ZBh0=J4M03^I4P12T@/0@i4604:D1P10UPT0?YT;
03ZK400iW100>YX>03jC400jSQ80>XPE03b4600nP1L0>W/F03Yg500oKQ40A6L<04AV2@13H`D0B6<4
055R0@1DH040EEP1059=001;?@00@S@003dY000j9000<ah0030N000_6@00;1D002lF000202dG0009
02hG000[5P00:aL002TE000X5000:14002DA000V3`009`h000809a0001<09Q0002<@000S40008Q00
01l?000O300070T001X:000H2`0060X001D:000C2@0040H000d5000;0@00200000H0000300000@00
01h00000303oool000X0oooob@000000600100000@40008000050@001`8000D300050P001P<000T3
000:10003@D000`5000>1P003@L000`9000A20005P`001T?000K4@006@l001H;000D2`004@X0018:
008050X002L06Pl001/@000M4`008AH002@D000R4`008A4001lA000N40007A4001d@000Q4@007Q<0
020C000T5P00:aL002hI000/6`00;Q`002/P000/7`00<1l0038P000a8000<B40038R000d9000=b@0
03TW000j9P00>B8003@R000e8@00=20003HP000f7`00=Ad003PP000h9@000P0k90009`0o8`00?B@0
044Y0014:`00B2l004Pa0018<000Abh004La0016;`00Abd004<a0018;P00Bc0004`b001@=P00Dc`0
05@o001A@000Dd<0055:0@1AD0D0Ce@705EF1@1HE@40F5X005]U0P1HL@P0Bh<F04>;:P10PT00@fmJ
04IPK@16GGP0?6Il039fO@0[P7X0;XYd02^DJ`0202ZTH00U02^[D`0/[4P0:J/l03>V9P0hWQL0>YPA
03bD2`0nU@T0?IX;03^N3`0gXAD0=:8I03BP6@0gVQP0?98G03V?6P0gRa`0>XLM03j2600mNaH0?W@E
041^4P12J`h0@VP:04AW1`1:J0H0DFT305AU0@1FF`00EDl004ln0014=000?bX003`V000k8P00=R40
02lN000202hI0080;AT001<0;QT002`I000[5P00:A@002LC000W4@0090l002H?000X40009a4002XC
000W4P009A<002@C000R4@008100020>000M30006@X000805`/000P050X00188000A1@003@D000/1
00090@001P0000@000800@007@00000<0?ooo`002P3oooo80000000I004000010@001@4000D20006
0P001`@000H4000810002P@000/3000=1@003PL00148000A2@004PP001<9000F2@006@l001hC000P
50007Q8001X?000G2P005PX001D;000201X9000W01/=000L40007a8002<C000Q4P00814001h@000M
3P006`d001d>000P4@007a<0028@000S4P009a<002XJ000[6`00:Q`002XM000/7000;Ql002dP000b
7@00<Al003<P000f7`00>B4003/V000m9`00>bL003/Q000g8P00>1d003XQ000f8P00=B0003PP000f
9@00?BD00080?RH000H0?bH0044X0011:P00Abh004Pb001==@0204/e000O04Xc0018<P00BC<004Tb
001:<`00CC<0050c001E=P00ECd005Q0001E@000E4L0059>0`1?F@T0CF0@055S2P1FI@@0EV/205Mg
1`1>PaD0A8`[03n6A012LEX0BUQ/04EAN@0hEGl0<5b002eZP00ZMG`0:Wih02^6L@0202RHI@0W02fR
DP0_Z4H0;ZPf03JR9@0kWAL0>YTA03bI300mV`X0>:0>03JR5P0aXaX0<:<O03BO900eVb<0>9<T03FB
9@0fSRL0>XTR041o6012NA<0@78A045/4@12J`h0@V/;045[2@17K`T0CW05059]0@1GH@00Edh004dm
0015<@00@2X0040Y000k9@00=B40034K000`6P00;QT00080;1P000X0:aL002XE000Z4`00:Q@002TB
000W4P00:A0002HA000V4`00:A@00P0[50000`0X50009a80028@0002020>000>01d=000J2`0060T0
01L:000C2@004PP00106000>1P002`8000X1000700001@0000800001000M000000`0oooo000:0?oo
olD000000`0100006@030@001@4000H300060`001@@000L4000910002P<000d4000?1`004PT001<:
000D2`004`/001H:000E300060d001XA000M4@0081D001`A000K40006Ph001L;000F30000P0J3@00
9`0N3`007a40020D000U5@008A<001l@000M3P006Pd001L=000J3P006`d001`>000P3P008a0002HE
000X6@00:a`002/M000^6P00<1h0030O000`8`00<B00034O000b7P00=1l003PQ000m9@00?2L003dX
000h9000=b4003<T000e8@00=R<003XT000l9@00?RD003hY0002044/0007048[0015;P00ARh004L^
0019;P00C38004dd000304de000M04/e001<=P00C3@004he001@=P00DSL0058j001H?@00E40005A8
001AE0@0CV4>04Y/5`1@LA40DgD:05=j201@QA<0BXhU0469AP1:Kf40DE9c05Y7N01@AGh0?4R3039@
P`0]Ggh0:Fej02UgMP0YO7<00P0YSVP09`0_WEH0<ZM6032W=`0fXRL0>YlM03JL5`0gW1<0>9h@03NR
4P0gXaP0=Z8N03FP8P0dWBD0<iXW036E:P0`Tbd0=I0^03j89`16OQP0B7@?04E/3`12JPh0@V/?041[
3012KP/0AW4;04Ye1`1?K`80F64005Y;001@>000@Rd003hZ000m:000>b<003LO000`7P00;AP002XJ
000202PG000O02TE000Z5000:Q8002/B000Z4`009a<002PC000Z5000:a@002PD000Y5@00:a<002LE
000V4P008a00024>000N3`007@l001X<000H2`0060X001<;000A2`0040T000l5000<0`002`8000L0
000600000`000040000M000000`0oooo000:0?oool<000000P01000070020@00104000D100040P00
1P8000T300080`002@8000/4000<0`003@L00108000A2P005PX001D:000F2P005@/001D>000H3000
6@d001T@000L4@007A<001`@000F3`0060d001D=000K300201h?000E024A000T5@009AD002PJ000S
60007A8001h?000J3`006`d001d>000M40007140020A000R4`009QD002PH000]6`00;1d002dN000`
8000<R000080<b000100<R0003DQ000g8P00>2D003hX000m9`00?2D003XT000g8P00=b4003HT000j
9P00?R4003`W000o:P00?R/00P11;@002P17;000BBl004T/001;;`00BS@004/a001=<`00CS8004de
001>>002050g000K04hg001==`00D3L005<l001B?@00ET0005Q4001CCP00EEh404m/3@1;MaP0Bg`E
04f24P1<RaP0CI<X04fB?P1EO5X0GeY`05m9O01M@Gl0E3j204I2Q00jBH00=eQn031UN`0/KWT0:71e
0080:HA/02L0;9UL036VCP0^Ycl0<j<^03FP8P0cWQd0<ihH03>O5`0fXQP0=jDK03JT800dXb80<IlW
02fK:`0_Uc00;YHa03J@;`0oR2H0BWhF04]e3@17KPd0@Vd@049]4`10K0l0A70:04If2017M`L0CW03
05IN0@1FB000BC@003l]000n:P00?bT003/T000e7`00<1`002dK000/5@000P0[5@005@0[5`00:aH0
02XD000Z5000:A<002XC000[5@00:a<002XD000X5@00:1H002LD000T5@009Q4002<@000P4@007a00
01d>000J3P005`X001P:000201<:00040149000@1P003P@000/200801P0000<00`00004000000000
7000000<0?ooo`002P3oooo300000006004100020@001@4000H300071@002@@00P0:10001`0:1@00
2`D000h4000>1P0040L0018:000F30000P0G30000`0F300060`001P>000201T?000801/>000K4P00
718001X>000H30006@d001L<000H3@0201hA000W028C000V5`009a/002/N000U6P008QH0024?000N
4P007A<001hA000Q4P008Pl0024C000S4`009A@002/D000]6`00;ah0038P000c8@00=2<003DS000f
8@00=b4003DT000m9@00?2X003l[000n:@00?bX003hX000n:@00?RH003lY000l:@00?bH0044Y0012
;P00@bd00080Ac0002L0Bc@004hc001==@00DCD0054d001==000Cc@004de001C=`00ESX005@j001E
?@00DST0050g001?>000E3l005E1001JA`00F4/005ME001GI0@0DW0<04ik5@1<PaH0B8lK04NG9`1E
USd0HhEF06a^J01dE7D0J4Am05hkPP1E<X<0CSB404@oPP10DWh0=Emn02iVO00ZIG/00P0YNg009`0[
TV80;J9F02fVB`0bYCl0=Z<^02nS8`0`Y200=JDO03NU700gZ200=JLT03:S9@0]XB/0:Yd_02bJ<@0`
URh0>hhX04F7701>OQ00BgP=04Mb3`14LA@0@g0F045`4@17LPX0A7L704Ih1`1@KP@0F5`005A20018
<`00?RT003hX000o:000?BH003XQ000f7000<1X002hJ000202`K000902XK000[6P00;1P002XD000Y
5@00:aH002XF000[5000:1<000809QD001@09a<002DC000V4000914001lB000R4P007Q4001/>000J
2@006PH001D9000D2@004@T00105000=0`002`8000P1000700001000004001d00000303oool000X0
oooo_`0000008P01000000000000000300000`4000@100060P002@@000`5000<1P0030P000l8000A
1P004@L0018:000D2`005P/001L<000I3P006`h001h>000J3P006`h001d?000J40006a0001`>000M
3`00810001`@000K3@006Q0001/>000L3P02024@000Q02@G000X7000:Ad002dO000Z6P009AD0028C
000R40008140020D000S5@009Q@002LF000V5`00:AP002`H000]7@00;Qd0030L000`7`00<B0003<O
000b7`00=20003PV000m:P00@R/0048^000n;@00@Rd004<^0012;000@bX00080@BX000@0@RP0048[
0014:P00AR`00P19<@009`1?=@00D3H0050j001A?000DcP005<i001C>000ECP005Dk001C?000E3h0
05I1001C?`00E3d005A0001FAP00E4/005Y<001LE000G5`105MY1P1DMPh0Ch4E04V=6`12VBT0@i`o
05^=D`1gKfP0NF9c07iAN01d@GX0ISUo05XePP1G?840BDb0045JP@0gHhL0;6B102IPNP0202A]L00W
02N2H`0ZU5l0;ImG02jWC`0`ZCh0:jP`02bW:P0cYbL0=JHR03:Y8`0_Z2L0:ZD^02NT=00XXSH0;9`e
03FF:P12SAd0BXHA04f03@19OPh0@gPE04=e6@14M1T0A7DC04If2@16N@H0AgH6059/0P1IF000E400
04Pb000o;@00?RX003/V000i9@00?B4003PL000c8000;ad00080;QX000l0;a/002hJ000^6@00:aP0
02TE000X50009aH002PD000V4`009aD002PD000Y50009Q4002L@000T4@000P0Q4P002P0O4@006`h0
01X:000J20005@X001<:000A2@0040H000h6000;0`0200P0000300@000020000000001`00000303o
ool000X0oooo<P0000030?l000040000003o0000o`000?l008H000000P0100004P030000104000D1
00080P002@8000X4000?1`0040L000h9000D2P004PT001@<000F300050/001L;000H3000710001h?
00807Q4000X07Pl0024@000L4`007Q4001lD000R4`008a4001lA000O4P007Q400P0M400202<B000S
02PH000W6`00;1h002`O000[6`009QP002HC000U4P00918002@E000U5@009A<002/G000W6000:AX0
02dM000^7@00;Qh0030O000b7P00<B8003@O000e8000>B4003/V000o:P00@b`0048^0012;000@bh0
04D_0015<@00ARl004P_0017;`000P15;P003P18<000Ac8004/g001;=`00DCX005Dj001C>@00ES`0
05@l001D?@00E3X005Hm001H@000FSl00P1IA0006`1JA`00FDL005U8001LCP00FU4005aG001OG040
GVH305Qe2`1?PaL0BXhP04:I;@0mW3l0BI9B05b1I01]J7@0JeQm06m=O@1]?h40ICV205/jP01H@Gd0
CDio04EGPP0eGh/0:ej502EJO@0202AQL`0W02E`J00YPFH0:IAR02^RFP0[Z4/0:jXl02jY<00_YbP0
<JPV032Z:@0YZC009ZLf02BW>P0UY3P0;Ihe03FF9@11SAP0AhD?04R13P15OQ80AGXI04If6P19Ma`0
B7PE04Mk3P11O0P0A7P704m[0`1FDP00DSd004Td0012<000?b/003dV000n9@00>bH003LP000d8000
<al00080<QX000`0;aX002hJ000Z5`00:QD002LE000W4`00:1@002LC000Y4`00:a@002PD000Y4`02
02HA000A02<A000Q4P007a<001dB000J3`006``001T<000E30005@/0018;000A1P003PH000/30009
0@00200000D0000100007@00000<0?ooo`002P3ooolc000000050?l00000000000000000003o0000
QP000000100100000@4000<100050`0200L3000300P100090`0030@000803`H000@04PL00189000D
2P005@`00P0G30004P0G2`005``001X>000N4`008AD001lC000P4`008A@001hB000N5@008a<002@F
000P5`0091H0028B000P4`007Q@0020C00809A@001L0:1/002XL000`7`00<1l002hM000Z6P009aD0
02DC000S4@008a0002LD000Y5@00:QH002XJ000`6000<1`003@R000c8P00=B4003PU000h9P00>BD0
03TW000203dZ000>03lZ0011:P00@RX003h/000m:`00ABl004L^0015<@00AS<004L`0018<`00BS80
04de001@=`0205<i000W058n001B?`00Dch0058j001E?@00Dcd005E0001J@@00Fd@005a2001MA000
GTL005m8001NAP00G4X005U@001JE@00FeX205YQ101GK@T0D84C04JB9P0jWc<0>J1403nCE`1DPFH0
H6i_06ALM`1OCGl0IDF306XmQ01S>XL0Gcn305]5P01CBh40Adn903]CSP0aE8H0:Dn00080:E=i02@0
:Uaa02i/KP0[QVT0:iYR02fVF`0]ZD/0;jTh036X;P0_Zbh0;:`d02J]>`0T[T009:]002FT=`0/Wc80
=9XU042B6@14Ra80B8DD04F15@17NaD0B7HD04Yg5P19NaD0@h0D03j03010N0P0CfL205A=001>=`00
AC80040[0010:000?R@003lU000j900203TQ000E03@P000`6P00<1X002lH000]5`00:QH002PD000X
5P00:QD002XB000Y5@009Q@002PE000X5P009a8002D?000U40008Q00028A000P4@007Pl000807@h0
00/06`h001T<000G300050/00148000>1@002`<000T2000800000`000040000M000000`0oooo000:
0?oooc@0000000<0o`000000003o0000Q`0000001@0100000`4000H100080`002P@000802@@000T0
2P@000h4000@1`0040L001D8000C2`004``001H;000H30000`0I3@00400M4@007a<0020F000R5@00
91L002<H000T60009AL002TG000X600091L002@H000R5@0081@0020@000N400202<D000H02PG000]
6`00<20003<T000b8P00;Ah002LI000U5@008180028C000U50009a@002TD000/6@00<A/0038O000d
8000=B<003PU000n9`00?bX003l]000o<@00@3800P13;@003@11;000@bh0044Z000o:`00@2`004D_
0017;P00Ac4004T`001<<P00CCL0054l001E?@000P1F?P009`1F@P00ED4005Q1001F@@00ET0005Po
001JA000Fd<005m6001MAP00GTL005]8001MB000GDL005]6001JB000Fe8105]J1P1FJ0d0DGLG04V7
:@0oU3d0>9U:03j?GP1BN6/0KF9_07=DM@1XBgT0GSin0612Q01M@hP0GDB=0613S@1VAHX0FTB;0592
T016@Hh0>4B902m4PP0202e4OP0W031:N00dEG80;WEX02Z@H`0ZX5d0;:IA02fW@@0[Ycl09jTo02F/
@P0T[4D08ja902JZBP0YYcX0<:8b03FN9`0lUA`0@XlF04B86017Pa<0BG`?04Uh3@1:O180A80E03n5
5`0mP`l0@gP8051P0P1CB000C3H004@]0012:@00@BP0040W000o:000>R@003HQ000f8000=B000080
<A`000P0;a/002`G000]5000:Q8002HD000X4P00:A8002LB00809a<001D0:14002DA000T3`008a00
028?000S3P008Pl001l?000N40007@l001`?000H3P005``001<;000A2@003PD000/400090P002000
00<0000100007@00000<0?ooo`002P3oool]000000030?l000000000000000D0000000<0o`000000
00000000Q00000005`0100000P0000D0000600001`8000T400081P002PH000/5000>10004@@00146
000C2@0050X001H<000E2`0060`001T<000K3@007@h001dA000Q4P007Q<000808QL000`09AX002TH
000W6`00:aP002XJ000V7000:1P002DE000S4`008Q@0024?000O4`0202PH000W02XJ000_7000=B<0
03LX000f:000<Al002/I000X5@0091@002PC000X6000:AL002/K000_7P00=B4003DS000j9@00>BH0
03dV0010:`00@2d0048^0014;`00@S80044`0015;P00AB`004@/0011;000@Bd004@_0018<000BS<0
04/f0019=P00BSP004lm001CA000Ed<00080ETH002L0F4D005M4001HAP00FdH005e5001MB@00G4P0
061<001NC@00H4d005i;001NBP00GdL005a6001LB000GDP005YB0P1JHP`0DWLM04Z5;`13Qd40@h9G
04ImHP1=MV/0IF=_07]CLP1eBGD0JTQi05e2P01JA8<0EDR605]7R01W@8d0LSj?06TkT01T=hl0DcV:
04@nQP0h@8400P0e@g`09`0fAgT0>55d031]L00XR6T0:YIW02jKH00^WUL0;9mA02RND@0XXU809JID
02BWE@0XZ5D0:jE5036V>00gXRd0?9XR046C6`13RaP0BH@?04am2P19O0X0AX0>04:44`0mQQH0?H@@
04If2@1AG@<0EDP0050e0017;@00@bT0044Y0010:@00?B@003TT000f8P00<b4003@P0002038N0004
02lI000^5`00:aD002TD0080:18001T0918002HB000S500091<002@@000R3`008a00028@000S4000
8`l0024?000Q3@007`h001`?000L3P006@l001L;000E2P004@T000l6000=1@0020D000P100050000
0@0001d00000303oool000X0oooo:`0000020?l000L0000000<0o`000000003o0000Q00000002`01
00000P0000<000050@002@8000P2000;0`0030@000d6000@200050L000804`X001<05@`001H;000G
3P005Ph001H=000L3P007a0001hC000P4`008a80024D000R50009AL002dL000^7000;Qd002hP000^
7`00:Q/00080:aT000@0:1H002LE000W5P009QH00P0[6`006@0^7P00<B8003PU000i:`00=RL003<P
000^70009aT002HF000Z6000:Q/002hK000a7@00=b4003/S000k9`00?BP003hZ000n;@00?bX0044/
0014;`00A34004<^0014;`000P13;P003012<000AC4004Pc0019=@00CST004lm001@?000DC/004dk
001A@000E4@005Q70080FdT00P1JB0000`1KB`00Fd`005]?000205]A000P061B001NEP00GEH005YD
001LDP00GU4005i<001RCP00FTl005]H0`1FL1H0AHTc0468C`16LF@0C61b05MOJP1NGVH0KU=[07E;
L`1]AW/0I4Uo05a8P`1IAX80ED2205/oR@1[=hd0NCF=07DaS`1_;Xh0GCB:04XkP`0m@7`203Y3N`0W
03Q8MP0eDg@0;VQc02QlK`0ZQG40;H]]032?J00`TF<0;95T02ZGH@0ZWV00::1N02VTF`0^YT`0<ZM0
03NV<`0lWb/0?IPQ042?6@17Q`l0BX0;04Um2`14PPl0A8@A04675011PQ40AG<;051M0`1DB@00CST0
04X`0015;@00@b/003dW000l8`00>2@003LR000h8P00>B400080=1h001l0<QX002lG000]5@00:Q@0
02LB000Y4P009Q<002LC000T50008a<002DA000T40008a0002<A000S40008Pl0028@000P3P007Pl0
01d>000L3P006Pl001T<000H2P0050P00187000?1@002P@000P3000600000`0001d00000303oool0
00X0oooo:@0000020?l000P0000000D0o`0000000000000000000?l000230000000V004000040@00
1`4000L2000:0P002`8000`7000?200040T001D<000G3@0060d001P?000H40006Q0001XA000K4000
6a4001dB000Q4P008AD002<D000O40007@l002<D000V6000;Al0030O000b8000<B00030P000[7P00
;1/002XJ000^6P00;1X002XJ000[700203<Q000D03DU000h:000>Bd003`^000g:000<28002dL000Y
5`009QT002PH000Z6P00;Q/0038N000d7`00>RD003`Z000n:P00@2/003l]000l:`0203l^0006040]
0013;P00AC0004L`0015<@00B3D00P1;>@002@1>>P00D3l00515001CAP00DD@00552001A@`00ETP0
05E:000205Q;000=05U=001JC@00F50005]A001JE@00EeD005EF001GF@00F5d005UK001JG000H5T0
061F0002069F000H069J0@1MJPX0FGhS04f7CP1AMfT0FEai05m=N@1UCVP0LTiF07E9HP1_AG@0IdAo
0657P@1NAH<0GCn505TfPP1Q<XH0L2^;07dXS01h8h`0M2N=06H/RP1?=X@0?cao0P0o@G/09`0mBGP0
>E9i035NNP0aIg/0<Fih03AdM`0bNgP0<X5g0327LP0`TFd0<9UW02fLHP0^XET0<ZI<03BYA@0eYd00
=Z4h03RK:`0lTb00AHXF04R34@16PA40@XDA04>64@12QQ80A84B04Mc2`1BF`@0D4P004dh0015<000
@RP003lX000l8`00>B8003/S000i8`00>B0003/Q000203PP000603HM000_6`00;aH002dD000/4`00
:Q@00P0T5P00600U50009Q<002PB000V4P009A8002@B000S4@00914001l?000Q40007Pl001d?000L
3@006`d001X=000H2`005@T00188000?1@0030D000X400080P001000004001`00000303oool000X0
oooo:00000000`3o0000000000000007000000<0o`0000@000000?l0003o0000o`00P@0000009001
00000`0000L200080`0020@000`4000=1`003`T0018=000D3P0060d001X?000J400070l001/?000M
4P007a8001dC000N4`0081D0024B000Q50008a<0020B000N40008aL002XL000`8000<24003<S000c
9@00=2@0030P000_7000;ah002hO0080;Ad002X0;Qd003DQ000e8@00>RL003d/000k;P00?S4003LZ
000c8`00;a`002TK000W6@00:AL002XH000[6@00;1P0030L000h7`00=bL003dY000n:`00?b/003`Z
000n;@00@C8004Dd0018=P00B3D004Xi001;>@00Ccl00511001>A000CdD004m9001>C`00D4h0059<
001?C000DTd005E>001FD00305QA000V05A@001FE000EEL0051K001=FP00CU/004iP001DH@00E6<0
05MP001MG@00HEd0069L0@1YH`@0IW0<05n06`1NPCX0IFmW06UQN`1aD7`0L4]g06I9L01SAfP0Gd=^
05M3N`1D@h00D4:405@oP`1G>XD0GcR106dcP`1m:h80RRN108LRQ`219HL0L2V:05@cQP12>h0204=3
O`0S04U<O`16Dh00A5R104QKP014Ggd0@V9k03aYM`0kLGD0=Waa03B8J`0`TVD0;iUJ03:OD00eYDH0
>JU503BX@P0eXT00<i/e03BE;@0nSQh0@hPH04:55@10Qa<0@hH@04>43`13P1<0B78;055L101CB@00
CST004@/0010:000?RD003dR000h8P000P0j8`003@0k9000>bD003/P000k8000>Ah003@L000a6`00
;QL002XF000Y5@009AH002PE000W4`000P0X4P005@0V4P009A<002DB000T4`009140028@000P4@00
7a8001lA000N40007Ph001/=000H2`005@X001@9000@20003@H000X500080`0010400080000L0000
00`0oooo000:0?ooobH000000P3o002@000000800P0002L0100000D100090P002P<000/4000?1@00
4@P001@:000F3@006@d001T>000J40006a4001TC000L4@007Q@0020G000S5`008aD002<F000U5@00
8a@0028D000R400081<002PH000[7@00<R@003<V000d9P00<RD0034R000_8@00;a`002`N000^7@00
;ah002lL000_7@000P0f8P002`0i9`00?B/003d`0010<@00>R/003@U000c8@00;Ah002TH000W6@00
:AT00080;AP001X0;A`003DP000i9@00?BP0044[0010;P00@C0004<b0018>000B3`004/l001>?`00
CD0004m2001?B000Cd/004]=001:CP00BU<004YG001@E`00D5/1051J0P1BF@80EET105QH0080EeT0
02L0EET005AG001EG000DEl004aR0@18H000B6<004UV0@1?I@00DfL005US001PI000Hf@006U_101[
NPl0H8LS05N5?01TL5L0N59h07M<P01iAg/0MDEg06A3N@1H@GH0Cd1h04a0OP1<?X<0CCj004hhP01D
=H00IC^007dhP02A<g/0V2ad09<XN029:Gl0NRb4064fQ01=?8000P1>@X409`1FBX00G5:005MDO`1H
DH00EEIo05AJN@1:GgD0AF=_041_JP0gOVD0;hUN032AE00bW4T0=Z=503VW@@0gYT00=J4h03NK=P0g
USD0@I4X04F;7015R1P0AHLC04J43@15PP/0@gl?04Ud2P1AG@<0DT/004Th0014;P00?bT003`W000i
9000>R@003TV000n9@00?R@003`V000203/V000@03`O000g7P00=aX0034H000Y5`00:1D002LD000Z
4`00:Q4002TE000Z5000:Q<002TD000X4P009QD002DE008091<000h08Q80024A000Q4@00810001hA
000K3P005P/001D:000B2@003@L000/500080`001P40008001`00000303oool000X0oooo90000002
0?l00940000000l00@0000D0000500001P4000X3000<100030D000l7000A20004`P001D:000E3000
5Ph001T>000K3@000P0K3`001@0L4P0081@002<F000R5`008QD000808QH001809AH002@D000U5P00
8QD002XJ000]7`00<RD003DW000g9`00=bP003<U000b8`00<Ah002/M000`7P00;b0002`Q000_7`02
03<S000W03/Y000m:`00@bh0044`000m;@00=BD0038R000a7P00;aP002/J000^7P00<A`0038N000c
7`00?2<0040X0011;@00@bl004De0018=P00C3d005=2001BB000EDX0055:001@C000CTh004eC001;
E@00BUL104IK0@17H080AV<304YS101<I@H0C6P8051V1`1BHP@0Deh10080EEh102L0EF0005MR001B
H`40CVH204YZ0`19J`<0BFd304e/0P1@K@80DVd105Y[0@1OK@40HgD306>3301QS2@0EHQ405AcG`1/
G6h0OTMn078oP@1/>gl0ICUl05TjP01>>h00C3]o04dlO`1A>X<0CSZ1058jN`1K=gh0KCMn08PhN`2H
>7H0XcIV09/bK02@<WP0OcJ006hoO@1O@gh00P1PAW`08@1/BWh0LDin06i<O`1ZBh80IE=m069JN01E
GG<0BV1]04=[I`0iNf<0=8II03:@CP0gVTH0>JA003RV?00fY3@0=Yl`03VH;P0jTc00A8hT04V;701;
RQ80BX@<04b12018P0P0@Wh:04Qa1P1@G080D4P004Hj000o;P00>b`003XW000203/T000403dR000n
9@00@R@003`T0080?2800200>R4003HN000d7000;A/002PG000X50009a@002PE000/5@00;A@002hE
000Y5P00:QD002TD000W5@009QD002LF000W4`009Q8002<B000R40008A4001h@000M3P005``001L:
000B2@003`L000`6000:0`001@4000<001`00000303oool000X0oooo8`0000000`3o000000000000
002?000000800@0001D0100000P300080`002PD000`6000>20003PL00108000B1`0050L001<9000E
2P0060`001/>000M3`00714001lA000S4P008a<002@E000T50000P0U4`004`0T5@009AP002DG000T
5@0091L002TL000]7P00<B8003HW000f:@00=RX003@U000b9@00<28002lN000`7P00<R0003<N000c
7@000P0i8P009`0k:000?Bd0048b0013=@00?Rl003LS000d8`00<b0002lI000Z6P00:aT0034M000d
8P00=b<0040Y0011;`00AC4004Pf001=?@00Dd400598001DB`00E58005ED001@EP00BUH004QI0013
G@00@f01045R1010I`L0?fd8049`2P12L0d0AW<@04Me5@1;L@h0Cf`8051T1002055V100W05AX0`1F
J`<0E6/404m^1P1;M0L0BWD604ec1`1@L`H0E786059b1@1LM@@0HGh6066;3`1LTAl0F8Hi05YfEP1L
IV/0L5Ud07U7N`1[>h00HCN105HhPP1D=h80DSf0054oPP1F@H40H3Z105TiP01G>7`0GSUl06/cN@1m
<GT0SCEi09DkN02@?7/0Q3ak07dnO`1dBG`0Ldik0080ODak02L0S4Yh08m7N027@7X0NCem07=9N`1V
DG`0EUYh04QQM@11KFl0?WmV03N;F@0gUT/0=j1403VU?@0iXS@0=J0/03FL:00lVBL0?I<V04B>8@17
RAT0BHH=04io1P1>O@H0Agd604Ei1P1;K0<0CEL104i50017=P00@2`003XX000i9P00>B@003TR000n
9000?bH003dX000l90000P0k8`00100i8000<ad0038L000]6P0202`F000J02TE000Y5P00;1H002/F
000]5`00:aH002`G000Z5@00:1D002LE000W5P009aD002DC000R4P008a4002<@000N3`006`d001T<
000H2@004`T00147000>1@002@<000D10003000L000000`0oooo000:0?ooob<0000000<0o`000000
00000000S`0000020040000E00@000080`0020<000X5000<1P003PP000h7000@20004PL001@7000C
2@005@X001P<000K3P007@l001`A000O4@008a8002<C000T5@0091@000809A<001<091D002DH000U
5`0091D002@G000Y7000;Ah0034R000f9`00=RT003HZ000d9@00<RD0030R000_7P00<1h0038P000c
7P00<ad00080>B8002L0>bP003d]0012<P00@cD003h_000g8`00=2<003<P000_6@00:QX002/I000a
7@00=28003LS0010:@00@Bl004Da0018=P00CCd005=1001BB000E4/005AB001EE000D5H004YF0018
F@00@ed004=P0@11HP@0@6L703m]2012L0X0@W0=04Ic4017MAD0Bg4>04m/201@I0@00P1AIP@09`1D
J0<0EV/305A[101?KPH0Bg@704Ye1P1=L`L0D7<605Ab1P1BLPD0G7D4065n1P1QR`l0G94O05R6>@1J
MUH0G6I[071IM01iAg/0Jc^0064gP@1F>880E3N2058mP01A?h80ET61060jP@1I>H00EcQl05hiO01[
<gT0OC5i08deN@2E>gP0T3ak08@lN`1m?Wl0M4Ul07=>N`0207e<N`0W08a:N02?AgP0Qd1j07TmO@1c
BG/0IU5l05IJN018HGD0@Fe_03ioIP0gReT0=iI;03NPA00iYCd0>J8d03FP;00eW2P0?9TW03fC9P14
SR40AhTI04V63@1>O`H0CWd604Mm1P15N@H0Bf`304eG0@1>A@00AcH0040/000j:000>BH003TT000i
8P00?R@003lV000m:000?2@00080>b<000@0>B0003<M000b7000;AX00P0/5P006P0Y5@00:AH002`F
000[5P00;AL002/F000/5`00:QD002PE000W5@009aH002LE000U4`008Q8002<A000S40007Pl001/=
000I300060T001<9000A1`003PD000T300050@000`007000000<0?ooo`002P3ooolQ00000080o`00
T@000000100100000P0000@200070P0200/6000E00h9000@200040T00149000A1`004PL00149000C
2P0050X001H<000K3`00714001h@000P4P008A@0028D000U5P009AL002DF000W6000:AL00080:AP0
00`0:AT002PJ000[6P00;1h002lQ000d9@00=bX003T]000h:@00=BX003DT000e8`0203<P0080<B40
0P0h8P009`0l:000?R/0044`0012=@00@C@003`/000f:000<R@002dK000Z6@00:ah0034N000d8000
>bD003lX0012;P00ASD004Tj001<@`00Cdd004mA001<D`40CEH104YJ0@18G@40@V0103iU0@0lJ080
>6`603M`2@0fM100>7LC03Mi5`0lNA`0?g/Q04Al9017N1P0C7<?04e[2`02051/2@0W05=_1`1DL0P0
DG<904mf2`1<N`h0Cg`@04mj4@1EN@h0EgT;05Qn2`1OQPd0GI4F05^?9`1HQCD0GWY706A_F@1UJVT0
Jf1f06m@N`1U?800G3R205DiR@1C>HP0Ecn805Y2S@1L@h<0J3n006<lO`1O?Gh0Hcen074aNP1m:GL0
Pc:008LlP025@X40Od1m07e3O01kDGT0OeAf0080RTmc02L0TT=_098nKP2A@700QCmc07]2N01XA7`0
E5Mn04=[N`0oMg40@8IT03jBE@0mWT/0?j=103jT>00nXB/0>YdU03ZH8P0kUB80?I0O042<6`17QQ@0
CH0:04mm101;O0D0BW/404Ie101=I`40D5L004i30017=000?b`003XW000g8`00>B4003PS000h8P00
>R@003XU000j90000P0l8000800h7P00=Ah003<M000`7000<AT002hH000]5@00;1H002dF000^5@00
;QL002/H000Z6000:aL002TG000W5`009aH002<F000T5@009A80028A000P40007Q0001L=000H3000
5`/0018:000@1P003@D000P200050@000@007000000<0?ooo`002P3ooolO00000080o`00T`000000
100200000`8000L400081@0200`700803PT002D04PP00189000C1`004@P00189000D2@005@T001T<
000K3`008140020C000Q4`008aD002HE000X6P00:QX002TM000Y7`00:a`002XL000Y6`00:a`002/M
000^7`00<28003@X000f:`00>c0003da000m<000>c0003XZ000i9@00=B4003<P000`8000<b000080
>BD002L0?RT0048X0015<@00B3T004Dh000o<`00?2l003H[000a7P00;a/0030L000d8000>B8003hU
0010;@00AC8004De0019?@40BTT204YD0P1:F@<0AU`304=N1012G`<0@V83041S100mI`@0>fd503Qd
300eNAH0<WdM039n7`0cOB@0=ghU03eo9`13ObX0AWdO04Yk5`1;MA800P1<MA409`1=N100CgTA04ej
5@1<OAP0BWhK04in7@1?Oal0Eh4K05^7601RSQT0Ii<Q06BA<01NQC/0G7Q405maC`1WK5T0KFYU06eU
K@1aFG80KT]i06a6OP1Z@Wh0Jd5o06e0P`1_@H@0Jd>106U5O01W@g`0JD5n0750PP1m>G`0Rc9e08Lc
O@23>880OCj207m3O021@gX0Pe=d08aEL00208m9KP0W09<mK02>?700S49c08=5M01mAGD0JE1d055V
M`17MG80C7IV0527FP1>VTd0CJA304ZU=@1=X2P0C9/M04JG5`12TQH0@HlK03n=700oRQh0A8@C04^0
2P1>O`D0BWh604Yj1@1:M0<0CVT204mE001?@`00B3@0048/000n:@00>b<003XS000g9000>BD003`W
000i9P00?RL00080>b<000d0>B8003DO000e7P00<a`0034K000b5`00<1@002dG000/6000<AT0038J
000_6P00;aL00080;1P00140:aL002TD000V500091D002DD000S4`008Q4001l@000H3`0060d001P;
000C2@003`L000`500080P0010000040000L000000`0oooo000:0?oooad000000P3o002E00000004
00<100060`002@L000X7008040L000h04PP0018;000D2P005@`001@:000A2@0050X001L9000G2`00
5`d001d@000N4@0081<002<F00809QL001L09aT002XL000[7`00;b4002lO000[7`00;Ah002lO000_
8`00=2D003PZ000j<000?C4003hf000o?000@3X0040g0010=@00@2`003`X000h8`00=1l003DO0002
03XY000V03l/0014<000ACD004Pm0016@000@ST003ld000l<@00=R80038M000d7@00>B@003dY0018
<@00B3P004/n0@17@P80B4/504EF1`17G`P0AF@9049X2P0nJ@/0?V/803e[1`0nJ`P0@Fl903ee2`0j
NaP0<h4U03:7<00dQRh0<h@]03N3:00lPRL0@80V045o8015OQh304Ij6@0W04En6@19PA`0BH8O04V2
8P18QBH0CHD/052:;P1HTB/0FYT/05nH;P1RSCP0HhE1065mB@1NMe00FWMG05QfGP1JMVD0Fg9Z06=/
K01]G6l0KU=c07=?M01iAgL0Nd1l088jP01g@H00JTUk06=<O01/BGh0NTQo08LoO02G>GH0SCEj080b
OP1e=X00Nd9k0899N029Dfd0TUAW0080T4=X02L0ScUZ08TiLP27@WD0PT]`07iCI`1VJfD0DGiT04n6
F`1EQd`0Ehm705RM@@1GXSL0Ej0X05^H7@1HTa80Dhh?04f<3P18RQ80B8PI04R88@18PaL0BX8<04^2
1P19OP@0BG/404a_0P1?I040D58004m10015<`00@2`003hY000k9`00>RD003`V000l9`00?RT003hX
000l9@000P0i9@002@0i8P00=R8003DN000c7`00<aX003<I000^6@00;A`002lM000203<K0007030I
000`6`00;aX002hJ000/6000:QL002LH000202HG000<02HF000R50008A4001/?000J3P006@/001D:
000>1`0030@000P3000400000@007000000<0?ooo`002P3ooolL000000030?l000000000000009D0
000000@0104000P3000;1`003PH00P0A1`009`0B2P0050/001L<000I3P0060d001L<000I300060h0
01`>000K3`008100024A000S50009A`002LI000U6000:1T002TM000/8P00<2<0038O000`8@00<Al0
03@Q000e9`00>R`003T`000k=P00@3`003do000l@P00?d<004920013?`00@cT003dc000k:`00=bL0
03PS000203hY000W040`0016<`00B3T004Xm0016?`00ACT0044f0011<000?2H003HS000i9@00@2L0
04<^001=>P00CdL204UA0`14E`L0@ed;04=W4@12KQ80@G<B03mf500lNAD0>gD@03Qf3P0gMa00?7PD
03ek600hPB40=HL]036;=@0^S3D0<HXa03:9:P0eQb<0>XHO03n57010Q1`0@H8I0080@H<L02L0@XDM
04>77`14RB40AHdV04NA;@18UcP0BI`o04VP@01;Wd80DYE205V:A01IQD`0FH1A05UlE`1HMUh0F7MO
05UhHP1MMfD0I6iU07=QI01kEfT0PTi/08U6KP2=?7X0TcQn08E2OP1^CGd0H56206a?O@1jBW/0PdAl
08e3MP25?WP0MC]k06TkN`1dA7L0OTYe08IAK@2ACVD00P2@C6<09`2@B6<0Rcm]08XlM`21C6d0MfMN
0660FP1DSdl0FI9105R@>P1HU3h0Ei`h05NK<@1MUbD0FhhL05R;4P1FR`h0DHP;05273P1@QAL0CXHN
04j35P19Q0h0Ah@804V21P18NPH0Bfh504eM0P1>C@40Bcd004Hb000l:@00>BP003TW000k9P00?bD0
03lV00109`00?RD003XU000203PS000403@R000f7`00=ah0034M0080<QX001T0;aX002hL000a7000
=1`003<L000a7000<1d0030L000_6`00<1X002`I000Z5`00:AL002LG000T50008Q80024A000M4000
710001T;000D2P003`P000d500080P00100001d00000303oool000X0oooo6P0000020?l009H00000
0P01000010050@002@<000h6000A200201D9000W01@<000G3@006a0001d?000L3P006Pl001/>000L
40006a8001h?000O4P0081D002DF000V6P00:1L002LE000V6@00:1/002hO000a8P00<R@003<W000f
9`00=b`003X^000m=000>cP003`o0@0oA@40?TP203i<0`11CP<0@E02045>0P11B040@D@1040k0@0o
;P00?R/00080?Rl000H0A3H004De0019>000BCh004Lo0016>@0204<c000O03l[000n:000?RP004<]
0019>000CTH104iG1017H`L0?FT;03e`4@0jMAP0>7TG03Z06P0fPAd0<H8L03616@0bPAP0<h8K03J1
7`0gQB40<hLW02f;;`0/SS<0:hl_02f?;00`SB@0<hXO03J97@0gR1T0?8LF03n6500203f75P0W03j<
6@14TA/0AYDN04NJ9016XC40@ZA103jUCP0iX5D0>YUH046?E@1;QEL0DH5G05:0F@1COUP0EW]J05]j
G@1RN5h0JWQQ06EaH@1VHf80IUQR06QCJ@1`Bg00O4Mi08Y5M`25C7P0MTih06M=O@1/CGT0MDeh07A<
N`1iC7X0JdYj06=5N`1N@gX0KDEa07M7K@24C6L0RdYV0080SU1U02L0TE9Z08e9L@2;BW<0OUa]06eg
GP1SRdl0GY=005RC=P1DTCD0DHlj05BC=`1EUC40FI8W05N;6`1GR180EhH>05>62`1BP``0EH8A05B4
501CQA40C8L?04V72`16Q0X0@g/:04U_1P1;G0<0BdL104Tl0015<@00?RT003XV000i9000=R8003TT
000l8`00?RD003XR000h7`000P0e8`002`0c7`00=Ah003DO000c7@00<AX002hH000]6@00<A/0038O
000`7P00<1l00080<1d00180;ah0034M000_7@00;1X002XI000Y5`009aL002HD000U4`00818001h@
000J3`006@d001H:000>200030@000P20004000M000000`0oooo000:0?oooaT0000000<0003o003o
00000000UP0000001P0100000P4000H2000;1@003`L001<:00805P/000d05``001P>000L40007Q00
01d>000K3`00710001dD000P4`008Q8001lD000S5P009QD00080:1P001P0:QP002LI000]6`00<240
03<T000i:@00?2l003la000n=@00?cT003m2000lA`80=e4303QC100hF0H0>e/803YL1`0kG0L0=e`6
03MF1@0iDP<0?4/304@o0@13=P0204Pf000W04/j0019=P00CSX004Tl0016?000AC`004Hi0014>@00
@c@004D^0017<`00C3L00552001?E080C6<703e_300dMQ00<WTD031n6@0`PQ/0;hHL03287`0[RAh0
;8TL02f9800]QbH0;HXY02f::`0/Rbl0:Hd`02V?;@0[T2L0<8lP03>=7`0bSAd0<h/N03N96@0kRQ<0
>h`B0080?Y0H02L0?ILL03nM7`0oX2H0?Z4b03NSA00`WU<0;IMQ02ZAIP0]S6L0;hEV03V4H`11P640
AgeO04UjF@1BNUH0GGII06MdFP1dKU/0KVMN06ENGP1QE640HE=W06I@K@1^CG@0P4ib089CLP1jC7<0
M4Aj07=:N@1fCGX0Kdml06]?NP1OCWd0FdQl05Y4N@1XAW40LT=/0898I028AFP00P2<D6`09`2>DG80
RE9`07mDL@1ZJ6T0HgiI06J8A`1ORD00EHPm04n8@01:Rd00CXlk05>@<01BSRH0DHXJ05265@1BPQ00
DGl<051n2`1?O0/0DGl:04f32@16R0d0@hL>04653`0oO@l0Afh804UG101<A@40B3L004@_0012:@00
?RL003`T000j8`00>B8003XU000i8P00>ah003LL000203DN000O03<N000c6`00<a/003@J000`6@00
<Q/0034J000d7`00=B0003<N000_7@00<1`0034L000^7@00;ad002dL000/6P00:AP002PG000W6000
91D002<D000Q4@007@l001/>000I3@0050`000l6000:10001P4000@0000M000000`0oooo000:0?oo
oaT0000000@0003o00000000o`000?l0U00000001`0100000`0000<200090`003@@000l8000B2`00
0P0F3`005P0J3`006@l001d>000M4@007`h001h@000O4P0081D0024F000R50009AL002PG000[6000
;A`002`N000[7P00:a`0030Q000e:P00>c00040i000n?P020453000?045:0@0oD040>eP403AN1@0d
HPH0<fH9035Y3P0cI`d0<VL=02eT300_G`X0<E`803QG1@10B`<0A4000080Bcl002L0DT40054o001?
@P00CdD004a10018@000B48004Y3001:>`00C3L004i0001@AP00D5H004aX1013LP`0=WdA0322500/
Q1@0:XHF02N7600YRQP0:H/L02J>7@0ZSAl0;8hU02b>:@0/TS00:Y4a02j?<@0]TBh0;i4V03>B7`0k
SaP0>hlE03^=5P0iSAX0>HdE03ZA500kUQH00P0hWQl02P0fXbP0=JH`03:R>`0aWTL0;iUC02^>GP0Z
QfD0:X1Y02mmJ`0gNV`2049hJ`0K04EfH@18L5P0Eg1?06I_CP1^K5@0LfIG06aQF`1SG5h0G5YS05YK
I@1RF6T0K5AZ07]BJ020DVT0OTM/07/mMP1j@gH0OT]i06a@N`1NCgd0E55n05a?O01LC7/0JdA`06m2
J`1m@f@0Q45X0080RT]]02L0S4ic089DK`1^GVX0I6iP06IkC@1VM4H0F6i704i`B@18NdP0BX5204j7
=`1CR2P0ChXO04j55`1@Pa80Cgh?05=o2`1@O@T0Cgd904f02019Q@/0@HX?03n;4P0lQ140@GT?04IZ
2@18E0<0BD4104Hd0012;P00@BX0044Y000o9`00>RH003/U000l9@00>B4003LQ000f7`000P0h7P00
7`0c7@00<QX003@K000a6`00<1`0038I000e7P00=B0003LQ000c8000<R00030J000`7000;Q/0030K
000^6P00;AX002TI000V60009QL002@E000T5000814001l@000L3P006`h001<:000@1P002`@000H0
000200007@00000<0?ooo`002P3ooolI000000050000o`000000000000000000o`00T@0000002@01
00000P0000<100070@002@<000d4000>1@003`X001<;000201H=000W01L=000I3P007A80020B000P
50008QD0024B000R4`008A@002HF000W6`00;1T002`N000a8P00<B@003DV000e9`00?Rd0044g0014
?`40ADT103mA0@0nEP80?5H203YG0`0kF`<0>5l3039R1@0aIPD0<VX802e/3@0^K0`0;F/;02aZ2`0/
IPX0:F@;03AN200nE0D0A4`10080CTd102L0Dd/005=8001DC@00DE0004m;001:A`00BD`004Q@001>
B`00DdX005Q?001IG@00Cf/3049g200iPa00<HTH02V<7@0YSAX09hlH02N?5`0YT1T0:90J02^@700/
Sal0:i4S02^A9P0[Tbd0;i8_032C<`0bU2d0=9@U03^A8@11TAX0@I8G046C5P0oV1/0?ITI03ZN6@0e
Y1l00P0`ZR`09`0ZZ3`09jA802RJD00YUEH0:HmK02R6H00WOf@0:WUU03AfJP0nLFd0BG5a04AbK`13
KfH0A6]P055`E01QLDh0Hfe>069VE01LHEX0Ff5K05URGP1MHel0IeiP06YLH`1aF6H0LU5Z07=:K@1g
@G<0PD9i08Y5O@1eBX00Edj104aBPP1KEGd0H5Eh06e;KP1aAFT0O49V07i0JP0207m7K@0W07a;KP1i
DFL0JEmN06E`D`1_M4H0JF=<05QIDP19IU<0AWI<04R3@01=QC00Ch<O05255`1@PQ@0Ch<B05:2401E
P0d0EWh:05222P1<Q@d0AXHA0469500nQa80?Wh>041b301:H@L0B4`304Xk0015<`00@Rh0044/000n
;@00?b/003hY000n:000?BH003/T000j9000>2800080>R4001l0=24003@N000d7P00=1d0038M000d
7000<R4003HS000f9000=B40038P000a7000<Ad002lL000^6@00;AP002TI000W6P009QT002DH000U
5P0091D0028B000P4@007A0001T>000C2@003`L000X4000600000P0001d00000303oool000X0oooo
6@0000000`000?l000000000000200000003003o00000000000008d000000P02000020040@002040
00T5000=1P004@T0018<000E3@005P`00P0H30009`0I2`006Ph001dB000P5P008aD0028E000S5000
8180028F000W5`00:1/002dM000`8000<b@003LY000j:P00>c4004<j0@16B0<0AE8403mI100iH`D0
=FH503ER100gG`@0>Ud303MN0`0hH080?6<503IW1`0`J`X0<6/802e[1`0^J0L0<6P902iW2`0eI0X0
>Ud7049I100204eG0P0F05E@0@1FCP00E5<0055G0@1=E`80BEP304IK1P17I0D0C682059O0@1GIP80
Cg<404Im2@0iQ`l0<Y0G02VE7P0UUb00:9DO02VG7`0TUah09iXO02RH7`80:YDP00l0:YLT02^H:00/
VB/0<9P^03:I;P0cURh0=I@/03NC:P0mUbD0@I/R03nM8@0mXbD0>:HV03:Z:@0/Zc400P0V[C/09`0S
ZTT08ZIH02>OG00SVe`099UJ02>EF00STET09HiJ0369G`0nPfL0Bh1]04UmJ`1:Mf<0CVeM05Y]E`1S
Jdh0Ff]@04eYEP17IE`0CF]F05M[E@1LIET0IemM06ILH@1XFV@0IUM/06i;K`1d@gH0O49j0816O`1W
Ch80BU:204MGOP1PFgX0JEme075BK01]B6/0ODEW07`oKP0207Y7JP0O07=<I`1lFV80LVeE071fBP22
JDL0NUQA05iFE01=IE<0BgE=04^4@01@R2h0DhHN05N76@1FQQD0EHHE05F8501GQQ00F8<>05B73`1<
QQ40B8LG04B45P10PA00@WL904QY1`1>F0<0C4L004Th0013;`00?b`0040Z000203lZ000603h]000o
;000?2P003dX000h9@00>RL00P0j9P007`0k9000>B0003PQ000f7`00<Qh003DP000f7`00=Al003HN
000d7P00<R00034M000_7@00;1`002`K000Z6P00:1P002TH000W6@009QT002@G000T4`008A40020@
000J3`005Pd00189000?1P002`<000H1000200007@00000<0?ooo`002P3ooolI000000030000o`00
0000000000<0000000<00?l0000000000000RP0000020040000:008000030@001@8000X4000>1P00
4`T001@<000H40006Q8001/?00806@h002L06Ph001hA000M4`008aH002@G000U5P0091D002@F000S
5@009aP002TJ000]7P00<2<003DW000i;@00?CD0040m0015B`80@ET603YU200fJ0P0<F`702m[200f
I`H0?68403iO0`0lG040>e`103YT100fIPL0<FX8031Z1`0]J`H0<6/503=Z1P0_J`T0<VT903YT1P0m
H@H00P18H0D09`1CFP80EUH005ML0@1?H`<0Af@604EV2@13KPd0>gH;049g201:MPH0Bgl904:93@0g
TA@0<9PN02VN9@0SWRT08ih[02NO:00VX2L09:0W02>P:00XWBL0:I`S02^K8`0/Vb<0;IdV02nM:00`
WRP0<YhZ036M:P0`WB`0;Yh/03:S:`0hYb/0=:X_02n[=P0ZZcX09Za0026/A00202:ZB@0W02BYC`0V
Z5P09:II02FWE`0YYeH09jIC02JTE00XXEP0;I]N03FII`0mTfT0?8mY03n4H`12Mf80B79O04i^E`19
KUH0@G=I03iaF`17LeD0EFeD05iUE`1VF640I5EV05mMJ01LGfl0IU=f0717N@1fAGl0LdJ405e@QP15
DX<0@e^005iPM@1WH7<0K5E_06]=K@1nAVT0OD9^0080O4MZ01l0LU1X07QSG`1dME00N7=908]QC@1j
Ee<0IEED05AYC@1@N4H0D8Hk05B;;@1GRQh0EX/I05N<601GSaH0F8dE05R<4@1ERa40ChdC04b:5`1;
R1H0A84E04Ij3P1:KPL0CV04051A0@1A@`00BcL004@[000o9P00@2P00080@2T000H0@2X0044Y000o
:000?2D003`S000n9@0203/W000C03`Q000m8P00?R4003XR000h8P00>20003PQ000g7`00=A`003<N
000b7000<1/002lK000]7@00:QT002`K000]6@00;QT002XK000202PG000:02@C000R4@00810001T>
000F30004@L000h6000;0`001`40008001d00000303oool000X0oooo600000000`000?l000000000
0005000000800?l0RP000000300100000`4000@100060@0020@000/7000A20004P/001P=000K4`00
6Q<001/A0080714002L07Q40020F000R5`009QT002HK000X60009aT002/J000Z7@00:Q/002XL000_
7@00<b<003LZ000l<@00@Sl004A;0010E`@0>VL9031a3P0`L0`0<78;035`200lJ`H0@6D303mQ0P0o
G`00?U`003aR0`0jI@D0=FT5035X1@0^KPL0<Fl703A_1`0aK`L0=6d703QZ1P0gJ@P00P10J`L09`1;
IPD0EVD205A]1@1:M@T0A7D;04Ek400lPQT0;XTI032:4`0fS180>9<I02nK8@0[WbX09:<b02:U>00R
YSX08:De02BU;`0SY2/08JD^02:S<00VXbd0::4Z02VP9`0_X2L0<Z4V03:R9P0dXbD0<J@X036V:@0[
Yb/09:H]02J[;`0X[S@09j`k02>[A00RZdX08ja902>[C00202JYC@0W02VXCP0ZZDh0:ja@02^_CP0]
[dh0;Je902b/CP0^YeH0<J=L032NI@0aWfD0<9MS032<G`0fOV00>gEO041^H@0mJV<0>gAY03ifJ011
MUl0DF]J05aQF`1YEFD0IU=^05MRL01AIg@0FEei06I@N`1XAh00IdB505=;Q@11EH40?Ef005=QM`1M
H7D0IUId06U<L@1jAfX0NTA[0080PDeY02L0MUaW075[G`1cM4l0MVa:07=RC@1WH4/0IF5605Ua@01C
OcX0EHL_05J;9`1GSR00E9<M05:B6P1BTaH0EY4B05J@401BT180CY0I04^>7018R1X0B7lE04ab3@1A
I@P0DUP405E:0@1D?000C3<004PY00129P00@B@004<V0013:@00@RX0048[0010:`00@2L004<U0010
9@000P0n9@00800o9000@2@003dU000l8@00=b<003HS000f8P00=R0003<P000`7@00<Al002lK000`
6`00;Q`002`L000_7000<1`002hK000^6P00:AP002HF000T5`008A8001hA000H3@005PX00148000=
1@002P<000H2000300000@007000000<0?ooo`002P3ooolH000000030000o`000000000000L00000
00<00?l0000000000000Q`00000030020000108000D200090`002`D00107000C20004P/001P<000I
3P00610001T?00806Ph002L07@l0024B000V60009a`002/M000/7P00;Q`002hQ000a8`00<R0002hP
000d8P00>R/003hb0013@040@dh3049M1P0iI`X0<G4@02Yk500_N@l0;gP=03Ae2P0jL0L0?6X603eV
100oHP80?5d003]R0P0iH@@0>FD503EX1P0bK@T0<W0;03E`2@0aLPP0<g0803I`200fL@X00P0mLP`0
9`14L`T0AW@704al2@17P@l0@7lA03f4600gSB@09i<X02RE8P0UVB@099l`022T=P0PZ3h07Z]601j]
BP0NZdX07ZY401jY>@0NZ3D08:He02BV=00WXc00:Z@Z02VT:P0^Y2P0<:@V02jU9`0]Z2T0:jP[02V[
;@0TZRh08:`c01j_=`0N/3X07jlm026[@`0SZd@09Ja002R[@00202bZ@00W036Y?@0e[3h0=:e003>`
@00b[TD0<JY5032[C@0_ZED0;jIJ032OG@0]XF40;I]T02bBHP0_R640<giS03McIP0iK6X0?6m`04Eb
L011LF`0C6MS05EKI01VEVP0JEQ`05AUL`15JgL0BUml05QGO@1PCX80FDJ404]?P@0oFgh0>fIl04UV
N01GH7<0IUIc06MBM@1iCF/0N4a]0080Oe=Z02L0LV=Z06e_GP1gMD/0LVY905mOBP1GIT40FG5005An
>@1BRCH0Eh/[05B>8P1BTQd0CYHN04jF6@1@TaD0D98C052A4@1>T1@0AhlJ04>?7@18QQ`0B7`E04i_
301BH0L0E5@305I8001C?`00CcD004T^0018:000@bL004@Y0015:P00AB`0048^0016;@00@B/0040W
000n9P000P0m9P00800n8`00?RD003lV000k9`00?B<003LQ000e8@00=1l003DQ000d7@00=1`0034K
000`6`00<1l002hL000_6@00<1/0030L000/6`00:QL002LE000S50007a8001`@000I30005@X00149
000=1P002`D000H2000600000@007000000<0?ooo`002P3ooolH000000030000o`000000000000P0
000000<00?l0000000000000QP00000030020@00104000D2000810003@H00147000B2P005P`001T>
000I3`006A4001X>00807@d002L07Pl002<C000W6@00;1/0034Q000a8`00<b8003@V000i9`00=bH0
03HV000h:`00?SP104950`15D@D0@F4903M^3P0`MA00:7XC02An5@0[O@l0;Gd=035k300eM0T0=6h9
03QX1`0lIPD0>F@603QU1@0lH`L0?6@803UX2@0eK0/0=G0=03Mb300_M`d0<GH=03Ef3@0hMa000P0j
Na409`0mNPh0?gh>04J8500nRal0=hPO03N;900bTS<09ILg02:K<00PWcD07:E401ZYB00JZd/07:iB
01Z_E00K[e806Ji701V[?@0LZ3L07jLh02BY=`0WYc@09jP`02FV;@0ZYb`0::PY02JZ:`0TZbd09:`a
02:/<`0OZc<07:Li01b[>`0P[Cd08Zdo02B[@@0UZ440::Tk02^Y>@0202f[>@0W03FZ=@0jZC80?:Xf
03ZW=P0gYd00<ZE1032WC00_Z5<0<JMB03FUD@0eXUL0<iiO02nJGP0bUF40<8YQ03=jI`0bJf`0=6Uc
03UXL`0kJg<0BFIX05=OI`1VFV/0Keaa05ITM@12J7T0?69o04AIOP19CX80BDR603aEP@0dJGd0<75k
03]ZN01=HG@0HEQc06IGLP1`EF`0KUU/0080N5]Y0280L6QS06ieD`1cOT@0KG5205aT@@1EKT00E7/l
0565>P1DScP0D9@^05:G8`1?V1l0CI/T04fJ7P1=UaP0C9DF04^E5`17TaT0A98O04:=8017QA`0CW@B
051S2@1BE@<0Dd/104m2001@?000BcD004P`0017;@00A2/004P/0018;@00A2`00P13;@000`11:@00
?RH003`U000203hS000P03/S000l8`00?BL003XW000j9P00>RD003TQ000i8000<b0003@O000b7@00
<Qh0038O000d8000<1h002lL000_6`00;ad002dL000X5P008aL0028E000O4`007@l001H<000E2`00
40P000d7000;1`0020<000D00002000L000000`0oooo000:0?oooaP0000000<0003o000000000000
2@0000000`00o`000000000000250000000:004100040@001`8000/4000?1P003`L001@9000G3000
714001h?00807A400P0L3@009`0O4@008aH002TH000`7@00<24003<V000d9@00=2P003HY000k;@00
>c4003hj0@14B0<0A5@7049R2`0iL100:g`I02ek5P0YOA@097hB02Ul300[OPX0;Wd:035g2P0aLP`0
<fd<03U/3@0fJ@h0>VX>03UX3`0hIPh0=fX=035/3P0dK`l0=G@@031k4`0^OAD0<7dF0360600203F3
600W03N25@0eQA@0?8`M03V?;00cT2`0<8lb02n?@00RU4P07ie2022SA@0JZE@05jaD01V^EP0G[eL0
4jeG01B]E00EZdX05Z]101ZX?00MZ3`08ZLh02>V=`0UZCD08jPa02JZ;P0SZRX09:l]02>^<@0U[SL0
9:hj02>/?@0RZT408JY202N]A@0[ZdD0;JE402jRA00ZXd00:jI00080:jU002L0=:Ti03ZW=@0oYS40
?:@b03JU>P0bXT00;jA@02fVDP0_Z500=:M=03FVCP0cXeD0<ImI03FKH00aSfH0;7iY02]YJ`0]IFh0
<Umc031TMP0nIG80AFA^04eWKP1@Ig40B6]a045YL`0jHGX0?EQl03m?PP0mCXH0<eb702U_P@0UMWd0
;f]h045QM01HFfl0G5aa06EMJP1VH6P00P1_HVH09`1_LET0K8E906V9?`1VNST0Gg8g05Mb@01@OT80
ChQ104nC?01<VS80D9dW04fM8@1:WR@0BIdR04RJ7019V1T0AILM04FD7`12T280@XTQ04Ym7P1@K100
De/6059>0@1C@`00DcX004hd001=<P00BS4004L]0014;P00ABl004D]0014;P00@bl0048]0011:`00
?RX003`Y000203dV000H03dW000n8`00?b8003/T000n9000?B8003`T000j8000=R00038P000a7P00
<al003<P000a7`00;Qd002lL000]6P00;Q`002XJ000Z60008aP0028F000N4`0070d00P0G2`001P0A
2P003PP000`700071@001@00008001`00000303oool000X0oooo600000000`000?l000000000000:
000000800?l0Q0000000100100000`0000L2000:100200d7000701<8000H2P006Pl001dA000P4@00
81@001lA000201lC000W028D000V5P00:ad002lO000d8000<BL003<W000e:`00=bl003`g0@10A080
@e44045O2`0kJa80=g@F03=i5@0[P1D0<84D031o4P0^Oa40;Gl=02ao2P0[OPT0;GT;02eg3P0`M180
=g8E03E`6P0fLA/0<flH03A_500cL180;W<B02md4`0_NQH0;84L02f2700aPQ`0;8HP0080<HTO02L0
=8TJ03J9700kTBD0>Y@g036E=P0`SSd0:XI=01n:E00PVdh08:EC01^XI@0E[V805jiM01J]GP0F[e`0
6ZmF01R]BP0H[4406Z`m01fZ>00QZ3L08JHc022Z=P0QZS008jd/02B_9`0S[b/08jha02V]=P0/ZSX0
:jTm02RX@P0WZTH0:Za<02nXB`0bWTT0<IM<02jIB@0[WDX00P0]XDd09`0`XTD0=Z<m03^T>00hYSD0
=jPm036U@`0aXe40;ZID02nWE00`Z540<ZM=03>UD@0dWeT0>IYP03:?I`0/OfP0:FaY02QTK00YGg@0
:FAh03EWL`0hK6h0=g1/03MeK@0hN6/0?g=[03eTM010EG`0>df403=:R00/Dh/096Z602AeP00XKW/0
>VEf051QK@1EHFd0G65Y05aWIP0206=ZH@0W06UnE01WSDD0HHTj05j0=@1INST0DgQ404f0AP19S440
CILh04ZL<@1>X2D0CYhP04fP9@18WbH0AihQ04RM8018Vb80AiHT04R@8@19Q1h0CgDG05UV2`1HD`<0
FDX005@m001C>000C3@004/b001:;P00ARl004H`0017;000AB`004L]0013;@00@Rh004<`0010;P00
A2/00080@bL001l0@BX003hX000k9P00>RL003XT000k8`00?2@003`S000i8P00=B80038S000c8P00
=B80038P000_7P00;QT002hJ000[6P00:AX002LG000T6@008QD001dA000M3P0060`001H:000D2@00
40H000d600071000100000<000000P01000H000000`0oooo000:0?oooaL0000000<0003o00000000
00003@0000000`00o`0000000000001o0000000?0040000200001@0000L1000<1@003@L001@9000G
2`0060/001T=000M40008140024C000O5P008a<000808Q8002L091D002/G000/7P00<R0003LS000f
9`00>RX003X`000k=P00@dL4045M2@0lJ@h0=g8E02ml700]P1/0;H4H02^4600_PQP0<8@I02n56@0]
Pa40:X<;02V22@0ZO@X0;7`<039i4@0dN1H0<GDN035e800_Ma`0;WLJ02mh600YN1P0:W/E02Uo6@0V
QAh0;8TN02f:8P0[SBL00P0^TBD09`0`SR<0<HdU03RC;P0fTch0<9Dn02f<@P0VOU<07XIL022IEP0T
YU`06jYb01B]K`0H[FP05ZiV01F^IP0I[EX06Je>01J]A00I[Cl07Jhi01f/=@0NZc<07Z`b022];P0R
[RT08jlV02J]:@0[[2/0<:P_03:W;P0cYRl0<:Dd02fY?P0^ZTH0<:=;03:GCP0aS540<H]A03:AE002
032FE`0W02jKD00]WDL0;:5602bV@P0]YTP0;:I<02jSE@0/XEL0;J=J02jSE`0_XE@0<IiJ03>JH`0c
UF@0<h]W02eoJ00WLFX096Q^02=QMP0WIWT0<Fef02mgL@0[P6X09hEV02n6H`0iOf@0@6Yb04=CO00j
B840;dB802U7R`0TGXL096j402M_O`0aJW/0@fUb04][K`1DJVL0DVmX0080EgAR02L0GH=@06B;@01P
Q3H0FWXh05Ul?@1CODD0BhY204ZD>@1:WCD0C:4]04fR9@1>Wal0BJ0W04NP;@16X2d0Aj0Y04RM:01=
UbH0CHdM04im5`1FL0d0H606065?0@1M@`00ESd0058l001==`00Cc4004`^001<;`00Abl004L/0018
;P00ABh004D`0014;P00A2`004@]0014;P000P18;@001P12:@00@BL003lW000i9@00>B<003XU0080
>R@001L0>24003DP000c8@00<Al003<S000b7`00;ad002hK000/6P00:QT002LE000V5`008AH0024C
000P40007@l001/=000I2`0050T00148000>1P002@@000L0000300<00004008100010@000@000040
01H00000303oool000X0oooo5`0000000`000?l000000000000>00000003003o00000000000007d0
000001000P0000D000080`003P@000h6000B2@0050/001L>000I3P007@l001lC000P4`008Q@0024F
000S5`0081L00P0S5@00400T4@00:1P002dL000d7`00>2H003/^0010=000@Cl103i80`0nG0`0=VlH
02en7`0[PbD098L/02R99@0]QA`202f46@0E02b66P0[R1T0:XLB02R63@0ZPP/0:X0:02]l2P0`N`h0
=7XD035j800aNB<0;W`Q02Yj8P0XOR008H0P02B06P0SQ1`08HTS02N=8`0XT2D09YD^0080;ID^02L0
<I0^032=;`0iTC@0=I9402nEA@0]SDP09X1I01j8G@0PWEH09JQL01Z[M00DZgP05jab01N]L@0F[W40
5jmS01V_EP0G[TP06:m001^^=@0O[C<07Zdc01j]<00P[b`08ZhX02V]9@0_ZbP0=:LY03^T:P0oXRL0
?Z4Y03ZT:P0eYC40;jHi02bV@00]WdH0;YU:036IC00cVe<00P0bW5X01P0ZW5P09YQH02FHFP0XW5L0
::1N02BPG@80:IaP01l0;9aO03:KG`0aVV<0<9MY02fGK@0[UFT0;Ha[02^5K00WNF`08g5`01mYM@0Q
KWT0:GQd02R7L00TSVH0899T02J@HP0cQfD0>g9b049FO@0l@XD0<Sb802PkRP0TCXX09VB:02M_R00b
K7h0@79d04UgL01=MVX0CWMV0080DWeL02L0GHa806FC>01SQC<0GWDi05Yh?@1COCh0CXXj04ZG=019
X2h0C:8Z04bO9@1;Wb<0Aj0[04JQ<@14XC00AYh/04FK9`1:U2<0D8LK05Ef3P1II`@0GeT105i;001M
@@00E3`005@g001?=@00D3<004dd001:<P00B30004H/0015;P00A30004H_0014<000@b`0048]0014
:`000P13:P007`12:000@2L003dU000n9P00?B@003/T000j9@00=R<0034Q000b8@00<b00034P000b
8@00<1l0034M000b7P00;Q`002/J000X6P00:1L002@D000Q50008Q8001d@000O3P006``001L:000D
200040L000/500080P000P060`0200D2000400D100040@000`00004001D00000303oool000X0oooo
5`0000000`000?l000000000000?000000800?l0O000000020020000104000T3000:1`0040P0018;
000D2@005`d00P0H40001`0L4@007Q80020C000R5@008aL002LE000V5P000P0S4`009`0U5`00:AX0
02dL000f9000>b/0044b0016A080@U4703YO3`0hLA/0;h0[02R:<P0ZRRl0:H`^02V;:00[Qal0:XDK
02f5600YR1L0:HTF02^74@0ZQ`l0:H<;02]n2`0^N`/0<W`=03En5@0`P1l0;h4T02^2900WPBH098<R
01n68`0QQAh08hTS026=:`0TTRX09YL/02>J<`0202NK=@0W02fE=@0_TSH0<i@h03B@A`0]U4/0:ha@
02InGP0OR5h08imF02JYGP0JZWH04Zam01R^MP0F[7P05:af01B^J@0E[UT05k1>01b_@00N[cL08:dd
02:/<`0S[3408J`/02B]:00X[BH0;Z`W03>X:00mYBL0@J4V04>N9P15WBT0?Ih^036U=00/YSd0;JA1
02nUB00_YD`0<:AA0080;J9N02L0:I]R02:CI`0USF/09He]02F<KP0SSf`09hi]02RAK@0UTfh09IEb
02JFM@0UUGT09YEk02VBM`0XRgL09XEf02AmM@0QN7D077Ef01emMP0ORG@089Mb01nJJ@0NVFD08i5S
02^6J`0iLGX0?UZ503U9R`0^B8T09TZ602AEQ00[HHD0;FV5039/P@0hNGT0?89^04J0H`1=PF400P1E
RU406@1SUD40HiPe0666=P1HMSl0EGY00562@@1@SS`0CI/f04VS<@18XBh0BIl/04VP;@16XRh0AJ@a
04FU;`14WRh0A9TW04RC801?OQD0EV`705YN0@1OD`00Fd<005Hn001B>0000P1A=`00301B=@00D3@0
04he001<=000Bc<004X^0016;`00ARd004<_0014;000A2h004D/0080A2d000d0@RX0040V000n9P00
>bL003`W000k9P00>RH003HR000e8`00<R40038R000`8@00=1l00080=1d00180<ad0030N000`7000
;1X002PI000W5`0091<0028B000P3P007Pl001d>000K30005`T001@8000>1@002P@000T400081002
00P3000300L300060P001@8000<00P400P02000A000000`0oooo000:0?oooaL0000000<0003o0000
000000004@0000000`00o`0000000000001h00000006004000040@00208000`6000A20005P`00P0G
3@002P0H40006@l001T>000J3`006`h001h<000N4@008a8002HC000X600202LG000W02HH000Y6000
;Qd003@V000o<000@cd004QD200lIQ@0<G@R02mo;00VRCT08hlm02N?>00VSSP09hd_02V<9P0YRb00
:XXL02^9600ZRA<0;8XA02b:3`0]QQ00<H4?031l3`0cOA40=80F02n36`0_PQl0:8<N02B67`0SQb40
88TU02:;900RSBT08I4a02>E<P0SVS@089dm00808ido02L099Pn02VF?@0^Uch0;IA:02bFCP0[S580
9g]Q02>6HP0VXEL0:ZYN01bYM`0AZgl06:]j01F[O00@[7`04Z]^01:^H00H[e807Jm2026^>P0UZSD0
9ZT_02FY;00VZbP09Z/T02Z^9P0^[2L0<:PY03NV:00jX2P0?YdZ03nJ:`0oVbd0=J0a032R>P0_YT00
;JY802^YCP0WZ5L00P0VXf<09`0SVFT098Uc02AoN`0QO7d087Mm021mN00TOgL098Ej0269O00OSgh0
7i=o022FO`0SV84099=o02B=OP0SRWd08H5l01f0OP0KP7`06hYe01^DL`0KX7@07:9_01bLI`0PTfL0
:8=`03A]N`0jFXX0=e>A02eGRP0UFX@09Eb002YOP@0`IH40<Fao035lM`0eQfX0@XEQ04^9EP0205VD
B@0W06FL>@1RU3H0H7di05I`?01AOST0DX`i04nH=`1<XSP0B:@g04RP=P1:VcL0BJ0g04RR=015YC80
AJ<b04:M;P14UR@0CHTJ05Ee2`1JI@<0G5D005a;001F?P00D3H004dd001==P00C3@004de001=>000
BS<004Xa001:<000BBl004L_0017<000AS<004H`0017;`00ARh00080ABd000T0@b/0048Z0011:000
?bX003`X000m:@00?BP003TT000f9@000P0e7`005P0b8000<ah003@N000c8@00>28003@S000b8@00
;ad002/K000Z5@009aD002<E000R4@008A0001l?000M30006P`001@;000@1`0030@000T5000:1@02
00T4000400L300060`001`8000L200801`4000<0104000<0000100004000000<0?ooo`002P3ooolG
000000030000o`00000000000180000000<00?l0000000000000MP0000004`0100000P0000H1000<
1@004@T001L;000I3@006A0001/@000M3`007`l001d@000J3P0070h001lC000P500081<002@F000Z
60000`0X6@009P0Z7000<1l003LY000o=P00A4P104AO3@0fLb<0:H8e02R7=00OSCT09I0h02N?=`0O
ScT088lb02:?:P0RT2T09HhP02V;5`0/RA80;8XC02Z<500/RQD0;hHE03:15@0aPAH0<88E02f55`0^
Q1P09hDF02285`0ORal08HlY02FB;00RTc8089Dn02:H?@0QW4407Ia90P0MWDP09`0PVDL08YU802BI
AP0VUTd0:9QA02N:EP0SMV<098EV02NPF@0XZf006j]h01:[P00HZ7h05ZR100b/P00>ZGH04J]T01J_
E@0O/DH08Ze002J[=`0XZBh0:ZTW02ZY900/ZRH0;J`Y02jY;00^Ybh0<Z8`03>M;`0eW2d0=Y//03RK
;@0eWC80=Ilg03:V@00]ZTH0::QA02:TG`0202:HJP0W01n<LP0QNW/086n101mWP@0MH8007FMm025_
P00ON8L06gn701Z6QP0LSX<07iF2026IP@0RVGd099Ak02>@O00PRH007XIo01b7O@0JSgL05iYf01ZT
N@0IYW<07YiZ022=J`0YLW40<Eml039CQP0cE8L0;62402UTO`0YH840:f2302eVPP0/L840;Gee03:5
J010Qel0Ai5C0080FIY702L0IiPh06V6=@1PLS/0EG4i04n1=01>TS40CYdf04^R>P19YC`0AJ1004>L
@`18Wd00AJDm04>V=P13XSH0@Y`_04V?8@1@O`l0EfL405eH0@1PC000ET@005<k001>=@00Bc0004Tb
001<<@00BS8004/a001;<P00BcD004dd0019<@00Ac0004Lb001:<`00BS0004L`0016;P000P13;000
9011;@00@bT003lX000l9P00?BL003`W000k9`00?RP003/W000i8`00=b4003@O000g7`00=B0003HO
000e8`00=R4003HR000c7@00<20002hN000]6P009aX002@G000U50008Q<0020@000N40006@h001@9
000@1P0030D000`6000:1P002P@000T4008020<000L020@000L4000710001P<000H1000300000P00
00800@003@00000<0?ooo`002P3ooolF000000030000o`000000000001@0000000<00?l000000000
0000M00000002P0100000P4000D2000;10004PX001D<000H3@006`d001/@000N4@0201lA000801lB
000P4P007a<0024E000R50008aD002HH000Y6P0202hM000W02/L000^7P00<B4003h/0010?P40?U83
03aY500/NbT08hHi02R9;P0TRb/09Hh/02B><P0NScT07i0b02:@:`0RTRL09hhN02^:5@0[RA00;8XD
02V@600XT1X0;h/G03655P0bPaH0<H8D03>2500`PaD09hDC0229500QSR407Y@`01jF=P0NUc`089U4
022JA00OVdP07IY?00807IQB02L07IIB01nGE00RVU408YQA026GD@0URUL09WET02B7I00YXeX0:JaL
01^]LP0CZg/05ZQm016VP00?ZWh03Zae012_I00I/5H07k9<02:^A@0UZcX09jP_02ZW9`0/Z2P0;ZPZ
02nY;P0dYC80<j4e036O=`0_WCH0<Idb03>O;@0eX300=j0a03BR=P0bYSl0;J]702RVE00QXFH00P0P
UGD09`0NRWP08WQn01m[Q@0MGhD065N201MLP00JIH806ff501]`R00PN8L08H>602>=Q@0QVH008Yei
02FOMP0QWWL089Uh01jDN`0NTG/06iIm01VMO00KXH406iml026BL`0SPF`0;FIb02iJO00^E840:eZ1
02YTO@0WJ7d0;6N002iZPP0]Kh@0;7F102alM@0cPfd0=hES04>CE00205RK@P0Q06JG<@1UQc00G7/e
05Im<@1CS2l0CiHc04jJ=`1:WSP0B:8l04BQ?011X400@J5004FT?@15Xd00@J4h04RG;P1>QQ`0EW06
05eL0@1OCP00GDD005Ln001C>P00DCD004da001?<@00Bc8004`a001?<@00CC<004dd001;<@00BBh0
0080B2l000@0BS8004T`0017;P00@b/00P13:P02044Y000>03lX000o:P00@2T0044Y0011:P00@R`0
040Y000m9@00?28003/Q000i8000=Ql003LR000g900203PS000=03@R000b8@00;Qh002`M000Z6`00
:1L002HC000R50008Q<0020A000J3P005``000l9000300d6000400`6000;1P002`D000/500<02PH0
00L02@H000H500070@001P8000<2000300000P0000`00000303oool000X0oooo5P0000000`000?l0
00000000000E000000800?l0LP0000005P0100000`4000@000070@002`8000d6000B2P005@X001L:
000G3@006Q4001lA000K3`007a40020B000T5P009aP002LJ000X6@00:1X002XK000[6`0202`M000W
02dL000e8000>BH0044c0011AP<0=e`603I^500[OBH09HLc02Z89@0VRB408h/R02B=9`0OSbl08XlZ
02:?900PSb009hdG02^94P0ZR0d0:HdB02RA5`0WTA/0;X/G03665P0dQ1P0=H<H03Yo6@0`Q1T0;8HE
02>;600PT2807YHd01bI@00JV4H079Q<01bHC@0LVTl06iYH00807I]L02L07IYN01fKGP0QWEP08YUD
026ED`0RRUT09GQU02F8H`0YY5P0:Z]H01b/K@0CZ7X05JEm01:UP@0?Z7h04Zad01>`H`0J/U<07k15
02B^?P0/[380;Z/Z03:Z9@0eZB@0>:PW03^W:`0mXR`0?9l^03NO;`0gWS00=il/03BQ:`0gXBl0=j<b
03BV=`0]Z400::]=02BVF`0RX6/00P0RUW@09`0PRGX08GV101iZR00KFhH05e2301AHP00GHh0066Z2
01e/Q@0PLH<09gb002N7P00UU7`09im`02BTK00NYVh07Z9c01bNN00NUW`07YN001bHQ@0OUXH07hn0
02QkM@0/K700>5Qj039FOP0XG7l08VQn02AbN@0VMWX0;G5k02icO@0`M800;gQn02elNP0bPG<0=XEW
046EE00205RN>P0W06BG;@1OSC<0F8Xh05F;=P1ET3D0DILg04fJ>P18WC<0AIla04:O<`11WSD0@j4f
04FR=014X3<0AiT]04j;7`1KMQ00HV<4061A001OAP00G40005Pl001E>`00DSP004hf001?=`00CS<0
04`e001<=000C3<004/c0018;P00Abh004H^0017;`00AS0004L`0015<000@bh00080@R/00200?R`0
03lX0010:@00?bd0048]0013;P00@c0004<^0011;@00@2L003lV000m9000>B<003`S000j8`00=b@0
03PS000f8@00=2<003<O000_7P00;1T002PJ000Y5`009aD002@E000Q4P007@l001P=000D30004PX0
00l900803`P000<040P000l8000?1`000P0=1`0200h7000800`7000:1@0020@000L400070`001P40
00@10003000;000000`0oooo000:0?oooaH0000000<0003o000000000000A`0000000`0100000000
0000000n0000000<0040000300000`8000D100090@003@D000l8000D2P005P/001L=000G2`006@h0
0P0L3`000`0Q3P008A<002PG000202PH000402TH000Y6`00:ad002`L0080;Ql002L0<al003PV0011
;@00@ch0041@0`0`I0P0<70@02]o7@0WRBD0;8PL02R96P0TRQ`098`N01n>900SSR<09HhN02J=6@0Z
SA<0:XX?02^<3P0ZSa00:Y8G02NB6`0_SaL0<8/I03>96`0hQad0=hHQ03>9800_RaX098hI02:B8P0P
UC0079Pl01VH@P0KVDd07IY=022KD@0MWUX00P0NWel09`0OX6@07J9S01nQG00OW5D07YU>01j@E`0R
OVH08HeR02^UE@0^[5L08:U[01FWNP0CX7d05:2201>UO`0DZG805ZeL01^_A`0P/3P0:Jl^036^9P0f
ZR00>:TO03ZY7`0oYb00@jHR04BS8`12Wb<0@9lT03nN9P0lX2P0>Z4Z03FS;`0bZ3@0:jTo02JZB00S
ZED08ZIQ026QJP0202:HLP0W02:;N00PNWl07FR501iGQ`0PBHL06e>301YROP0IK80086mo02EfO@0[
P7`0;8Yh02ZFLP0YXFL09:QY01jXJ`0LXfl06Yae01fCOP0LTh8078n402:3P@0XMW`0<FAf03QLM@14
F7X0>6Am02]`OP0ROWd09HIf02F5MP0WOGP0:gUk035dO@0aLg/0<gAi03=lMP0fQVP0AYUB0080GYdh
00P0IHlb05b6@01FRD80DXe0056C?@1@Vch0CI`i04^L;P<0Ai/W01`0AIl[04NN:`19V2H0Ch/M05Mj
4`1SI`P0IUL106=;001QA000G3l005Tl001I?@00ECX005<h001C=@00DC<004dc001<<@00B38004L_
0016;P00ARd004DX0014:P00A2d004H_0016<@00@bl00P12;P008P11:`00@bT0044Z0012;@00@bh0
04D`0014<@00ARl004<_0012:`00@2T003dX000n9`00>bP003XW000k9@00>B8003DS000d8@00=1d0
02lO000^6P00:aX002PG000V5`0091D0020C000L3@006P/001D:000A2P0040T00149000B2P02014:
008040T000`040P000l8000?20003`L000`7000;1P002`D000X500080`001P<000D00002000:0000
00`0oooo000:0?oooaH0000000<0003o000000000000AP0000000`01000000000000000o0000000G
004000040@001P<000L3000910003PL00148000C2@0060X001T>000I3`007A0001`A000N3`008A40
02@C000Y5`00:1P002/H000X7000:Ah002/M000`80000P0b7`009`0e9@00?RP004He0016B@40?E/5
02e/2P0ZM@d0:glD02V9600^RaH0:hdH02J?6@0XSAX09X`L02N<6`0ZS1P0:h`F02j<4@0_SA00<8l?
02n?3`0^Ta80;I8F02j@6P0]Sah0;XlP03:?7`0bSR00<i0O032B7@0YU1l09I@Q022F:P0NVC4079Tl
01bKA`0OW4T07im;01nRE`0201nVH@0W01fWJP0OYf`08:AR02:LE`0MWTh07IQF01n6IP0UU6@0;jED
03:[E00RYfh05Z9n01NLPP0FWHH05J>001NVLP0H[5T06Ji0026a;@0Z/B<0=JlM03V^6P0jZa`0?:/M
03jY7P11Z1h0AZDQ04RP8@18WB00@idU03^N:P0bXBh0;jDc02bZ>`0XZdP09:YC02FVG@0TXV@08ia[
00808I5`02L07hAf01meO00OIh4095N002Y8O`0VDGd095ml02A[OP0WMGX0:X9e02j<L@0^U6X0;9]Q
02^SF`0WYf008jQW01jOLP0JU7/06XR001^4Q00KO8<07gAl02QVM`0`FGP0<VIi03AeN`0/Q7P09Xmj
02>HN00UVWT09YAe02J4N@0XNWH0<W1e03I[MP0hIgT0>GIf03j9I01=WTT00P1TV3L09`1VQCL0GW]1
05MoA`1BPdD0DXa005:G?P1?W3P0CYP/04bH8P18UB40BiHQ04JG901=UR00DX`I05Z04@1SKPP0J5d3
06AA001PA`00GCd005/o001H?P00F3`005Hj001E=`00E3D0054a001A<`00CS<004/a0018;`00@2/0
044Y0016:P00AB`004L^001<<P00BS@004Pe000204Le000Q04D^0013;P00ABh004D_0017;P00B380
04Xb0017<000@Bd0044^0013;`00@bd0040]000n:`00>bH003XT000k9000>28003@Q000d7P00<Q`0
02lJ000/6@00:AL002LF000T5@0081<001`?000I2P005PX001<:000A2P004@/000804`/00P0B2`00
3P0C2`004PX0014:000A2P004PX00108000>20002`P000X6000:10001`<000H2000500000P002@00
000<0?ooo`002P3ooolF000000030000o`000000000008L0000001P00@4000D200080`002@<000X5
000?1P0040P001@:000F30006``001/;000L3`007A80020D000N4`008A8002LE000Z7000:AT002XF
000/6P00;Ql0034Q000b8P0203DU000W03`W0010<000ASl004IB0P0iI@L0:W8=02]g3@0/P140;8TB
036<500ZT1P0:94J02b?600YSaL0:H/H02^;5`0^RQH0<X/@03B;3@0fSP`0=i8>03:B4`0^TaT0;I<P
02RD:`0VU2/0:I@U02VE900^Ub40;YXR02RJ9@0WVR@09IXU026J;00QW3L07ie0022MA@0VXD`08JII
00807jQP02L07ZQX01nVKP0QY6807imH01bTCP0LX5<08IIQ02NLG@0bZ4h0=J]@02:YJ@0GXW/069]o
01FIP`0DX7l05Z9a01FVF`0IZd807Zd`02Z^9P0c[Ad0>JhL03b]7P0l[1l0>j/R03^]9`10ZRD0A:HV
042U9`0hXB`0<:0`02RS>00TYT009JM902JXDP0VYUh0::=T02FIJ@0USFd00P0QPG<09`0OMWP07FYm
021UN`0ZGGX0<5Ef031HM@0_GW<0;fYg031jL@0^SG40<9EW036JG`0`W5H0;J9C02bVF00WYV@08Ie_
01f@O@0NPh807Gf201mbO@0RJWL0:eaf039HM`0_MGL0:Y5h02JPL`0UYg<08j]c02NWLP0[VgD0;8Yh
02f1M00eMFl0>f]]03iQL@10Lf/0AXmM05JSA@0206RH=00W06J2=@1KMd00Eg]605:0AP1BRD<0DIE0
04nI>P1=V340C9DV04^C8P1>TB40D8hM05B75@1QO0h0Ig<706YR0P1WD`40I4X005a3001J@@00FD40
05/m001I?@00ECT005@g001B<P00D34004hd001<=P00BC0004L_0016;000A2`004P]0017;@00CBh0
04dc001==`00CSL00080AcD000L0AC4004@_0013;`00B2h004X_001:<@00C3000080BBh001P0ABh0
04<[0012;@00@2`0040W000k:@00>R@003XR000k8`00>28003@O000c7000;QT002XH000Z5`009QD0
028D000Q4`006a0001P;000D2P004`X0018;000A2`0201<:000301@:000E2`005@/000<05@/000/0
50X0014:000?20003@P000`8000;1P002`@000P300060P001@0000400008000000`0oooo000:0?oo
oa@000000P000?n80000000J008000030@001`8000P4000<1@003@L000h7000A1`004`X001D<000J
400070h001l?000N500081L0028F000U5P009aD002PI000/7000:QL002dJ000^6`00<28003<V000i
9`0203XX000W040]0015>000B4P004IL0`0iK0/09WXD02en4`0`PQ40;hXA036>4`0^T1T0:Y0G02j=
4`0^SA00<8`B032;400_S140=8`<03R>2P0fSP/0=hlB032B700WUBH09ID/026E=@0NV3L07iTa01fI
;@0UWB/0:j4[02^P:P0YW2H09idW02:M:`0PWCD08J1102:RA`0TYDh09JYK00808JUR02L08:QU022R
JP0SXEl08j1F01nUB@0PYT/09j1E02ZSC`0cZT80<Zi701jYH00EXG@069In01VDPP0DVGd05IY`01JN
G@0HY4X07ZLn02NY=@0^[2h0=:dZ03J]:P0f[Bd0<jd^036/<`0f[380>:/c03>V=`0/X3`09i]302>K
A@0PX4d08:5E026SGP0QYF@08j5V022?K00QNg800P0QJgH09`0RIWP08VAk02QYM`0^K700<Fi^03=Y
K@0eIVP0=G5X0360J@0^TFT0;YIP032HGP0bVED0<:1A02nWE00YYV809Im/02>BN00QQH008h20029i
N@0VMfl0;W5Z039gI`0^Sfh0:jEc02V/L@0X/G00:;5]02^[K`0`WG00<Xed03F4L00hNfX0?FiX041[
IP15OV<0D9YD066U?00206^F:P0T06>6;01HOcH0EX<k04j8@01>Sd40C9Q004bK?@1:VC<0BIH^04f?
9@1ARA`0F84C05ih1`1XL@<0K68106]F001UD000HDL005Y2001H@P00FSl005`n001F>`00DcL004le
001=<P00CS<0050e001==P00Bc4004/]0018;P00BBh004La001==P00D3@00`1>>P0204`g000N04Lc
0018<@00A2l004<^001:<000BRl004X`001:;P00BB`004H/0015:P00@bT0048Y00109`00@2H003hV
000m9`00>BD003TR000c7`00<Qh002dK000Z60009aP002HF000T5`007a8001`?000H300050`00P0C
3000100D2P005@`001H<000F3@0501H<000<01H;000D2`004@X0010:000?2@003PP000d6000:1P00
1`<000L2000500000P001`00000<0?ooo`002P3ooolD00000080003o8@000003003o06<0000001/0
0@0000<000050P002@@000h6000@1`004PL0018;000D2P005P/001`>000Q4P008Q<0028A000T5000
9QD002HD000S5P009a@002HI000[7000:QX002dL000]7`00<b@003LS000k:0000P0o;P009`14=P00
B4<004A@000oH`H0=7DA02N27`0^Pa/0<XTG02f>5P0aT1L0;94J02j>5@0bSa00<hl<03>=2`0dS`/0
;hl<03>?300dSP`0<8l?02^A700WUBh089Pl01nH@00JVD<06Y]401ZL@@0KWT007Ylm026R>@0VXSD0
:Z8]02RQ;P0SWc808Z4j026R@`0PYDX08ZEB01nWGP02022VI@0W01jRI00OW6T08Y]P02:NE00RZ4<0
8ZY102^WB00]Yd00=:Xe032]>P0KZTl05j1V01b@M`0LSH406Y1o01J=L`0ETVD05YaD01jSBP0WYd40
;ZXg03B]<@0e[Rl0=:`^03F];00a[300<jdf036/?P0^Z4809im802BECP0PV4l08IYF02:KH00QW6D0
8IiY026HJ@0PQfd08W=b008086Mc02L096Ua02U[L@0YMV`0;H9Y0329J@0cPF@0=gaP03B2H00cS5`0
;IMK02fGG00`UE/0=9MG036OEP0^YEd0:ZEW02RSJP0WVVl0:8mb02V<L`0ZR780;8aX03:?GP0eUed0
=:9U03B[K@0b[740<:i`032^KP0_Z6L0<YQ[03F=K00kPf/0?W]X03mcI011NF40B91G05FRA01ZX2h0
0P1`TR809`1UP280GH<V05F9<P1?T3X0CIQ004VJ@013Vd00AYPm04NE;P1;RR00FX0F069a2@1ZJ040
JF4006MF001VCP00HdX00614001L@@00F4@005]4001K@@00EcL0054h001?<P00Cc<0054c001@=P00
Cc8004`]0019;@00B2/004`_001?<@00CcT005<k001A>P00DC/0058j000204lf000V04`c0018<000
B2l004L]001:;@00B2h004T_001<<P00Ab`004L]0015;@00A2/004HY00109`00@bL003dW000m9@00
?2P003XU000h7`00<al0034J000]6@00:QX002LI000T5P008A@001`A000G3@005@h001H>000F3@00
5@h001L=000F3@005`h001D=000E300301D;000501D<000F30005Pd001@<000A2P000P0@2@00100?
1P002`D000T400060@02008000H00000303oool000X0oooo>00000000`00o`0000000000001Q0000
000>004000010@00104000P2000>1@0040L001@8000B2@0050X001D;000L3`008100020E000S5@02
02DH000<02LK000Y6P00:AT002PI000V7000:A`002/J000^6`00<Qd003TR000k8P00@2T00P11<P00
9`16?000BDX1041H0P0jJP`0<7/G02J99`0^RbD0<8hR02fE7`0_U1`0;Y4H02n?4@0cS`d0<8h:03:?
2P0`T0`0;I4=02j@3`0[TA@09Y<I02FF9P0SVCD07i]101jK@00MVcl06Y]001VN@@0HX4<07:5101fS
?00OY3d09:Df02>T<`0QY3L08:I001fVB@0JYTh07:ID01nUH@0202:SI@0W01nNI00QU6X099AQ02NJ
C`0UYcX0:jXg02jZ@00aZC@0=:/Z02j/<00LZTL05ieN0269LP0NPh@06XJ301J4N00FRfT069YI022S
C00WZD00:j`g02n];`0a[B`0<Z`V03>Z900bZBX0<:/e02f]@P0/ZD/099mB02:DE`0QU5T099EL02JF
IP0UUV/09IIZ026?K00RP6h08g1a00808fm`02L09W=/02EhI`0XQF@0;iEO032IGP0cUU/0=I9H02nE
EP0]VUD0;9aB02jJD00_VDl0<IaB032RFP0^Y6@0:jA[02ZSJ`0YXfL0:YaZ02bFK@0`TV`0<iUQ03:R
F`0eZ5l0=:YV03>XK@0cXWD0<ZAd03>UL@0bWV`0<HQZ03>2JP0kNG00@7M]041lH`12TE`0CZ5906FQ
;@1gT1H00P1hO0h09`1aM140I7/C05^4701BSbP0CiLh04FK@016VT80AIHk04V@:`1AQQ`0GgL>06YY
1@1[G@00K5D006M>001UC000I4L00653001L@P00FT@005]1001G@000ESX0054i001<>@00DSH005<f
001C=`00CS@004/a001;:`00C2h004ha001@=000DS/005Hk001D?000Dc`005<m000205@h000N050f
0019<P00B30004L_001:;P00BC<004d`001=<P00Ac4004H]0014;P00AB`004<Y0011:`00A2L0044Z
000m9P00?2H003XS000g8@00=Ah003<L000_6`00:aX002LH000T5@007Q@001d@000I3`0060h00P0H
3@00100I3P006Ph001X>000I3P0501L<00805`d000`05P/001@<000E2`004`T00189000?2@003@H0
00/6000910001P80008000010005000000`0oooo000:0?ooocP0000000<00?l0000000000000H000
0000200100000P0000@1000:0@003@@00145000D2P005Pd00P0F2`004`0I2P006a00020@000U5000
9aH002PF000X6P00:aT002/J000X6`009Q`002DI000W6`009QX002hK000`7P00>RD003XX0010<000
0P13=P009`15@P00Ae0203aP1@0fL@h0;88M02B>;00ZT2T0;9@Z02^G9P0^UQ`0;I8F032>4@0cSPl0
;i0<02fC300[T`h09Y@?02JC5P0STa`07i@T022F:`0RVS<08Y/i026K=P0PWC@07Ydf01jO>P0KWd00
7:5001VS>`0JYS/07:Lh01jX>P0PZ3d07ZQ801fVE@0KYUP07J=M01fSI002022NJ@0G026EJ@0OQg00
8HYU02JGD00VYCL0:jT^02jZ=@0_Zb`0=:`V02n];P0NZD806iYH02B2K`0RNhD07Gj801R2O@0GSG40
6iaM022YC00T[3X0:Zd^02f^9@0a[R000P0eZQd03P0dZb80<J`b02b`@`0WZTh08iiH02>CG@0STUh0
9Y5R02N=I`0XS6X09h]X02N3JP0VNVl0:Fmd0P0XMVl09`0YOfT09HYS02VEGP0`WeL0<jIB03JUCP0f
YDd0<JE;02fVB`0/YTL0;jA4032S@`0aYDP0;jME032QIP0`WG40;j1]02jVIP0]YFL0<9mV03:LH@0d
XU`0=JUQ03JWI@0aX6/0;iYb02nEM00cUWH0=IMg03BCL00dQW00=GmZ03mgJP13NfX0@hiU04NTCP1H
Yc00L9PB07Yn2@0207U^100W07I[1@1`K`T0HG`A05J:701BSb`0BYLk04ZF?01<TCD0D8LT05aj5P1Z
J`T0KUl106]E001ZCP00J4T00698001R@`00HD8005e3001L@`00G48005U0001F?000Cc`0050g001D
>000DCL0058i001A=`00D3@004lc001@=000DS@0058h001B>P00DC/005@n001B>`00Dc`00080DcX0
02D0DcT004hd001;=000Bc0004Lb001;<@00CC4004Ta0018;@00A2d004D^0016;@00@bh0048[0015
:P00@BX003lU000m9@00>RD003TS000f7`00<b0002hJ000[600091D0028G000Q4@007a0001PA000I
40006a0001`@000K3`007Q0001d@000M3`0070l000D06`h000h06@d001L<000F3P005`d001H;000D
2@004@T0010:000?1`002`H000T300050@000P00004000@00000303oool000X0oooo=`0000000`00
o`000000003o001P0000000N004000010@001@8000X3000<1@003`X001<;000G3@005a4001/@000J
3`006a0001d?000Q4@008AD002<F000T5`00:1P002XI000[6@00:QT002PI000T6@00:AX002/I000/
6`00<ah003`V0011;@00ACH00P14?0009`17A@00AEL203]W1`0dNQ40:XLQ02:B<P0YUBl09iPc02RH
;@0ZUQh0;94E02n=4@0bSPd0;I8;02jC3@0[T`l09iHC02FE7`0SU2X07YDd022F=00RVC<08iPd02BI
<00QWBh08Yd]022N<`0OWcT07:8i01ZQ>00JXSP06jLk01^[@00MZ4@06jU>01^WF00MYUX07J=M01jP
I`02026HK00W026;K`0NM7H087UZ02BAD@0UYcL0:ZT]032Z;@0_ZRP0=JdX02n]<@0OZT@07III02Al
K`0RM8L077b701V3N`0ITFh07:1I01n]A`0S[cL0:[0/032a8P0b/1l0=:dM03J/7@0a[B<0;jde02V_
CP0SZ5X08YQN022;I00QS6<09HYU02N7J00XPfX0:81W02IhJ`0ZLfl0;6]b0080;GU`02L0:XQ[02NG
I`0XX5`0<:ID03>YC00eZdH0=Z]103:/@@0_[D00;ja0032/?00]ZS`0;Z]5032XE00`Xf<0:ia[032P
J`0bYFL0;jUU03:UGP0bXE`0=Z1S03ZLJP0gUFd0=Hme02f;M`0_RGD0=Hae03Z@M00kTVl0=hiZ03j:
I@15Q680B8mQ04bSE@1FZ3T0IIlK07691`1fL`400P1hI`009`1eH@00KfT206Ma1`1MP1@0FX/R05:A
;`1?SRd0DXPW05Un6@1WK``0K68406mH0@1YD@00Id/0061<001PAP00Gd4005Y5001M@P00GT@005]1
001J?P00Ec/005Dk001B?000DcD005Li001H>P00ESd005<j001C=P00DCH0050f001C>@00DCT0054f
001C?000E3`005Hj000305@j000Q04df001><P00Bc4004`a001=;P00BRd004/`0018<000Ac0004H^
0015;`00ABh004D]0016;P00@R`004@Y000o:000>BL003LS000h8@00<1l002dK000/6@009AL0028C
000Q4P007Q4001dB000M4@007a4001d@000O4@007A4000807@l000<0710001dA000N4@000P0N4000
3`0L3`006Ph001P=000G300060`001D<000E2P004PX0010:000@2@003PL000X600070`001@000080
0004000000`0oooo000:0?ooocL0000000<00?l000000000o`00G`000000200100000P0000D10008
0`003P@0014;000D2`006@h00P0M3`005@0N500081<0020B000P4`0080l0024@000R4`009QH002HH
000X5000:QL002dK000Y5`00:1H002HC000X5`00;A`003<O000m:`00@S<004Dl000204Po000W04U;
0@17G@H0=g4<03606@0XSR/08YLk02JH=P0VV3D09iX^02bF7`0^TQP0<HdC03F>3P0cS`X0;i4>02jC
4P0WUAT099HW02:F>00MUTH07YQ001jI?P0OVS/08iXe02BL<00QWC408Ihe01fP?`0MXT007:4n01bQ
?@0NY4007:Q401fYC00JYeD06JEN01fVG@0MXf407YaY00807Y1_02L0981a01mTNP0RK6X09Xa@02:T
>P0XYc<0;JX_02j/:00e[B/0<Zlc01nYA00LU5X097Mb029[R00KNHH068Ih01NEJ`0KY5P07je402F`
=@0X/2d0;k0W036_8`0d[B40<ZdR02j^;P0Z[T809ZmJ02:UIP0TTfP08hA/02F3JP0WPfT0:85[02Mj
KP0WLFl09Fe^02U_K`0[Jg<00P0[OVh09`0]T6T0::5U02bVG00_ZEH0=:Y?03:/B00b[D40<Zdn036]
>00^ZcP0;j`l02j[@00^ZdX0;JQD02nUH@0`Y6H0=:IU03JWH@0hYed0=J5K03FLG00jUfH0?He_03R6
M@0hQGX0=8Mg03>;L`0jSV/0?Y9X046JJ@11VfL0B9EP04bHF01=Xe40EJI006>P8`1/U0/0LWh107=]
000207ET000L075Q001`I000JF/106=g3`1JP1/0FHHU05J38@1IOA`0IW8@06eU1@1/F@40Je0006E<
001TB@00HdH00652001I@000ET4005Q1001J?`00FT8005/o001H?@00F3h005Dn001D>@00FC/005/o
0080F3l000T0E3d0054f001A>000DcD0054h001F>000EC/005Pm001G?@000P1K?@006`1I?000DCT0
058h001==`00CSH004/a001<<000C3<004/d0019=@00BC8004Tc0019=000BS4004P^0015;@00@B/0
03lX000k9`00>B<003PR000d7@00<1T002/H000Y60009AH002<F0002028E000:024F000S5@008aH0
020F000P4`007a8001l@000M3`007A0001hB008071000100714001/A000J3`006Pd001/=000J3@00
60d001D<000C2P0040T000l9000<1`002@@000L1000400000P000`00000<0?ooo`002P3ooolf0000
0005003o00000000000000000000o`00GP0000003P0300001@0000L200091@004@D001H;000H3P00
7@l001hB000O4`0081D0024F000R50008A<00P0P4@003`0R5P009aH002LG000X5P00:QT002lK000]
6P00:QH002LD000Y6000;a`003LS000o;P00A3T004Q5000204Q9000W04UF0`12J@/0=7dH02j:9`0W
UCH099Y402RK>@0UW38099XZ02ZH7`0[UAX0<90E03:>400cS@d0<I4?02fB4`0YTQX099H/026I?@0M
Vdh079a:01bNBP0MWdL08Ii2026O?@0QWSd07im101jOC@0NX4`07Im501nPAP0QXdD08:I:01bVD`0J
YEP06ZIQ01VVH@0KWf<06i9[00807HA`02L097Ea02ELN@0XIfH0<8U:02RR>`0XYCd0;JPd02b];@0f
[Rl0<K4j01f[B`0ITUd07W9f025QR00HMh<05XUg01NLJ@0LYU807je102>_=`0X[bl0;:h^02n_:@0]
[RT0;Jh[02N]=`0V[Td09JiR02FUJ`0STFh09Ge^02IlK@0VOFh09Ga`02IcM00VJGH09FMd02IbKP0U
NV/00P0YRVH09`0_U680;Z5O02bVG@0^ZUT0<J]E036/D00a[DH0<Je003:[>@0cZS`0<JY103:[B@0`
ZU<0<:QH036UH00dYf00>ZMK03ZXE`0kYU@0=iiK03NEH@0kRVT0>gea03YiL`0kOWP0>hIb03^=K@13
Sf@0AIEP04RLI`1:W680CiMF04nOC`1HYT00HJ4Z06ZD501`P`H0LgL007=Y0002071Q000W071M001^
G@00IV@106A/2@1LMaD0GGTI05]f5`1SLa40K6P806mK0@1/F000Je8006Y=001VB000Hd<005ho001H
?000ESl005I0001I@P00FT8005e1001I?P00FD0005To001G?P00FD4005e1001K@P00ECh005<l001A
>000DSL0058h001B=`00EST005Di001L>`00FCd00080Ech001d0F3`005Dl001D>000DCT0058f001?
=`00CS@004lf001C=P00DSH0054d001>=000BcD004Xa0018;P00AB/0040X000n9@00>28003LQ000e
8000=Ad0030J000[6000:QP002PD000Y5@008aH002@H000202LH000402DI000S5P008QD001lD00<0
7Q8000<07Q@001`A000L4@000P0M4@00300L3`0070d001d>000K3P006Ph001H=000C30004PP00149
000>2@002`@000T100801P0000<00`00004000000000303oool000X0oooo4`0000060000oa`00000
0`00o`00100000000?l0003o0000o`1K00000009004000020000104000H2000:0`003`D001<8000I
30007@d00080818000D081@001hE000S5`009QH002DE0002028C000?02PE000X6000;1P002/K000_
7000<Qh003<Q000/7`00;A`002hI000a8000>bD0044_0017?@00B4H00080B50002L0AEh5041c4`0`
QR@0:I8`02JI@P0RWDT0:Idh02FJ:@0WV200;9LK02^E6@0_TaH0<Y8D02nA4@0^TQ00:Y@B02VD600T
V2H07i`h01bOB00MX4H07j5601nRA00TXD009Im002NOA00UWDX089YA02>LCP0XWdL0;:9302^V@P0V
Yd@08ZI;01bTEP0IXf<05j=V01JII@0HQfd00P0KMG009`0RJVl0:EIg03EVH`0mRT<0;j0g02RP@@0Z
Ycl0:jhg03N`=`0b[d407JYB01R?IP0KLG`07Uj701YgPP0HSW@06j9V022YD`0S[D009jhe02N_<P0Y
[S40::ha02VZ<P0YZ3T09JU702RYEP0ZZFL0:9m^02F:KP0UMFl08g9a029bL`0QLWL08fik02UWN`0Y
K7H0:7a[02N;IP0202VDGP0W02jEG@0ZWE/0:J=L02Z[F@0][5@0<:i>02j_A`0a[T00=:i003>[@@0c
ZdH0<ZUA03>VFP0cYUl0<Z5R03:SGP0hXeH0=j9B03ZLEP0jTF00>hIX03]kK00hLfh0>7=_03^0LP10
S6h0Ai=T04bGE`1@UeT0E9QL05>EE`1ETU40F9Y705jM<P1UUAX0LHL:07Il0P1dK`00LVD00080KV00
01D0L5d006eM001[H@00J6D406EZ2P1QK0/0I6L906YQ1`1]GP<0KED006eA001[D000Idh006A:001M
A@00FSl005Pl001H?P00Fch005a2001NA0000P1K@@00401I@P00FT4005M2001J@P00GD4005`o001J
>`00EC`005<j001A=`00D3@0054e001C>@00EC/005Tk001H>`0205Tk000S05Hj001A>000DCH005<e
001C=`00E3T0058f001@=`00DSX005<j001?=`00D3<0050a001=<000ABh004@^0011;000?bP003`T
000i9000=B0003DN000c7@00;A/002/J000Y5`00:1H002HH000W6@009aX002HL000Y6@009aT002@G
000R5P000P0Q5002028D00808A@001<08QD001lB000O4@007@h001d?000N3`007@l001/?000F3@00
4`/0018:000@2@003@L000T300080@001P0000<000010000000000`0oooo000:0?oooa<0000000<0
003o0000000000000P0000000`000?l000000000000Y0000000300400000000000000240000000<0
0@000000000000008@00000200400005008100030@000`40008100010000100000008@0200000`00
00@100080`003@@001H;000K30007Ph0024B000S5@008QD0024B000Q50009AL002DI000W5`008QH0
02<G000X5`00;AP002XH000/7@00<1h003<O000c8@00<Ql0030O000_8@00<R<003/Z000o=000ASl0
04Y<0@0204AH0@0E041[2@0kOQ/0:8lb02FG?00RW4L08j5:02ZO<P0WVR40:YDF02fD4`0^TQ<0<I0C
032A500^U1@0:iDC02^F5P0XV1P099/R022N;@0MXCP08Z4f00809:4e0100:Z0g02ZO?P0]WD40:I]6
02ZHB@0/Vd80;j0m03:T>P0aYSP0;JLi02BX@`0MYE006J1T01>MK@0ETfT05ge]0P0LJG009`0UHfl0
<5Qd03m[G@14RcX0<J0c02NOAP0/Yd@0::e303F]@00`ZTP06ZML01J?L@0ILX006f6;01YkP00JUVh0
8JUM02R]BP0Z[3P0;:l_02V`<P0Y[CH0:Zdl02ZUA00/V4l0:XmO032AJ00gTW80=HUc02ekL@0UJW40
86Ae01aRN00MIG/08Vmk02YaO@0[Og@0<8eS03:KFP0202fKE`0802nGE@0XWUL09jAF02VZE00[[4`0
<;5703>a@@0e[d0203B/@00M03BZBP0dZUH0<ZEP03:TH`0bXF@0=9mL03FJE`0gV5H0?I1M0424I`0l
N700>WAa03IeK@0eOVT0?h]Z04bHIP1CV5@0FIQ906:DB`1MSU<0F8M@05Z0CP1MRD00HY<V06Z?501c
P@T0MWD107A/001bGP000P1aF`002P1^FP00KUl006MP001[H@00If<106=N0@1ZF`40KUH106eE001[
D`0206Q=000E06A@001RA`00GT4005Tl001G>P00EC/005@l001H@000FT8005Y1001H?000Ed0005Y2
001K@`00FT8005a5001LA000G3l005Y0001G?@00E3T00080DCD000@0DcL005@h001F>`00F3X00P1H
>`00201A>`00DcT004lf001B=`00DS@005Dg001@=P00DCH00P1@>0006`1>=P00BSD004/`001<;`00
B2h004T/0017;000@b`0040X000l9`00>28003PQ000d7P00;a`002`I000V5P009Q@002HG000X6P00
9aT002PK000Y6`00:a/002LJ000T60008aD0028D0002028B00808A@001<08QD0028B000N4P007Pl0
01d?000O40007A0001/?000H3P0050`001<;000C2P003PL000/5000:0P00208000<0000100000000
00`0oooo000:0?oooa@000000P000?m@000000800@0000<00@400040000000008@0000000`010@00
0`4000D2000200H3000300D300040@000@000080000002800@00008000030P001@8000`4000B1`00
6@`001h?000R40008aD002<G000T5P009AD002DG000X5`00:1P002/F000Y5@009QH002`F000]7@00
;1d002lM000a7`00<1h0034Q000`7`00<Al0034S000h9`00>bh003lc0019@@00CE<30P14H`L09`0l
MQ<0<hP/02>DAP0UVTX08:1;022SB00XXC00:9/M02fE4@0bT`h0=I<>03>B400bU1<0<IHF02nH5`0Y
VQT08i`M02>M7`0RWb<08j4V02FO:@0VWR/0:J0_02^N=00ZWCd0:Y`n02jM?00]WCP0<Ihe03BR<P0a
Yc80;:La02RY=00PYd008:E?01^QH`0FWG406hm]01]dKP0202=QM00W02aRL`0cGgD0@WAI04N<=@0d
WS<09im802VTA`0XZ4X0=jY803:YD`0KY6P05I1k01QhQP0JIhT06h1i022KH@0T[Td0:k0n02n_<00a
[R`0:jlb02^^>`0[ZTH0;Y]B03=oH00kL6d0A6]c059XN@1:IWP0>V9e02YLMP0SFGP07eaj01iPO00Q
NGL09Hab02bKI00hY5H0>JQ>0080<jQA02L0<:=?02ZUB`0ZZTX0:je702n_@@0_/Cl0<[4o03Ba>`0d
[CX0=Za003B]BP0bZEH0<:MQ036VG`0dXEd0=9QG03R@E`0kRE/0@h5U049eL00jK7H0>GA_03V1J00m
T680C9]O05JPE@1LVdT0I9Q406^<C01OPdl0F7a>05]g@`1RQBl0JHhN07293`1gO`T0MG4007IX001d
H0000P1^F@004P1/F000JeX006aM001YG@00J5T0069E001VD000JDl006Y<001YB`00IdT006M8001T
B000GD<005Pn001H?`00ES/005Dj00<0EC`00180F3`005Dm001H?@00FSl005Y1001KA000GD<005a4
001K@@00Fcl005Tm001F>000DcP0054g001@>000DcT005Lm001G?00205Xn000W05Lo001G?@00ES/0
05@j001E>@00E3P0058j001@=`00CSP0050i001==`00CCH004`e001==@00B34004/_0017;@00@b`0
044[000m9`00>2D003DP000e7`00<Ql002dK000W60009aH002LH000Y6P00:a/002dL000]7@00:a`0
02PK000V6`009AT002DG000T5P008QD000808QH001<08Q@0024C000P4P008180020A000O4P007A80
01T?000I3@005`d001H;000C2@004PP000h6000=1@002`@000H300030000000000`0oooo000:0?oo
oaH0000000<0003o000000000000C`0000000`01000000000000000N000000800@0000@00P0000@1
00081@002@D00P0:200010081`001`<000<1000200020040000Q00@100040P001`@000l7000F3000
6`l001hA000R4@0091@002<G000R50008aL002LE000Z6000:AL002TH000[6@00;1`002/O000_7`00
<Ah0038K000_6P00;ad003@L000a8000=2@003XV000j:@00?c0004Dh001>AP40Ced90080@W8C02L0
>X8U02j>@P0OUEl07iYF01nQB`0MY4<08j8^02JM700]Ua<0<ID?03BE3@0cU140=ILF03:G700`VQd0
;9dP02BP900TWb<08j8S02:R9@0WXBL0::0Y02ZQ;`0/WS@0:I`o02RN?`0`WcL0<J0a03FQ:`0cXb/0
;jP`02fX=00UYc`08JM5022TE@0MXV806:1[026;JP0XJW400P0]F7P09`0_I7H0<6mg045nE@19SC80
>I/c02ZMA`0XYDL0;:M?03^YD@0fYUd07ZI`01NCO@0INX@076R901j1M00SWeT0:k12032`=`0d/S00
=:`]02n/=@0[[D40;:IA032?FP0eLVD0@65]04aOL@1JFW@0D5m_041TK00]IfX0:FYY02U/J00WLfT0
:XaT02^OH@0`ZUH0=ja@03J]C00202j/CP0W02b[B@0Z[D80;Je102j`?P0d/3`0<[8m03>`?`0c[cd0
=:`l03R/@00g[U00<ZmG02n/G@0`ZUL0<j1B03JCD00nQEL0AG]N04MdI`0nJ6h0>FEa03YnIP0nTUh0
C9eF05NPD01MVdP0H9A706N:B@1]P5<0GGMC05MeB@1JMcT0Hh8T06^:6@1`PP/0N7T607Q_001eJ@00
LF400080KET002L0K5@006YC001WE000JE@006I@001TD000IE0006IA001XC@00J4`006A8001VA`00
HdP00654001M?`00FS`005Xj001E=P00Dc/005Hk001G?000ES/005Lm001H?P00FCh005Y0001L@P00
Gd8005Y1001I@@00ESl005<l001B?@00DcT005<h001D>000FC/005U0001L@0000P1M@0009`1J@P00
FD4005/o001G?P00E3T0058k001B?000D3/0050h001>=`00CcH004hf001B=`00CcD004dd001:<`00
B300044_0010:`00?BD003PT000d8@00=Ql003DO000`7000;AX002TK000Z7000:Q/002hN000/7`00
;1`002/L000W6`009a`002PJ000W60009Q@002HE000202@E000502<F000S5@008a@0024D000Q4`00
0P0P4P00300M40006`l001T>000H30005PX001<9000?20003`L000d6000;10001P8000<000`0oooo
000:0?oooaL0000000<0003o000000000000CP0000000`01000000000000000M0000000600800002
0P000`8000H200091@0030P00`0=2`003@0=2P002@H000H300040@000P00004100050@0020@000h6
000C2`006Ph001h@000O4`000P0Q4`000`0S5@0091D002LF000202TH000C02TG000X6P00;1/002hM
000b8`00>2@003DU000c8000<al003<L000f7P00=b8003XU000m:@00@2h004Hf001:?P00EDh205=Y
3`0204:28`0W03J>?@0[TeH07iM]022MG00LXTX06ZDl026S;00VWQd0:YTF02fJ500^Va80<9dF03BM
700cWR40=9lV02nQ:00XXB`09J8Y02>S:00TXbL0::8Y02VR;@0[XRl0;:4b02^P?00^XC`0<Z8a03:Q
:P0eXbL0<jDZ02nX<P0/Z3/09jE502BOD`0SXE`07jAS01bSI@0YRfL0<fQ_0080>5]c02L0=Fab035l
LP13QTh0DHd^03^L=@0/X480:jA3032VD010YE<0>ZEO01fYLP0HUW`07GV0029QQ00TOFl0:9]G02j^
A`0c[ch0=Jhh03>Z=`0]Z400;:I<02^KEP0/ReX0;gUQ03EbI@0mLFP0A75W03miHP0fPE/0;hME02f<
C@0]TDT0;YM:03:QB`0eYdl0=JU=03JZC`0_ZE<00P0WZE<09`0XZTd0:j]602n/@00c/3`0=;4m03:a
@@0a/4H0;je703:]A`0d[dd0<:mK02^`H00[[V40;ZUE03BHC00iR4d0A7aE04agG@17MF@0@W1Q041i
FP16ReD0CYaD05ZLC`1OUdT0GH]906=nCP1XMU<0JW1H05iaD@1MMT80GW`e06:2801/Q140LWl;07Id
1@1fJP00Lf@0079L000206mF000W06aC001XD@00Ie8006=<001RB`00HD/006E=001XC`00JDl006U>
001WBP00IDT006I:001TA`00HD@005lo001K?P00Ecd005Ph001H>P00Dc/005Lm001D?P00FCh005Ll
001J@000GT<005i5001K@`00Ed8005=2001B?@00DSX005<j001G>000ECX005`l001M?`00G3h00080
FT4002L0Fd8005i1001L@000FCd005@k001C>`00DSP0054h001?>P00CcD004da001==000D3H0050e
001<=000C38004H]0015;000?bL003/V000k8`00=b0003HQ000d8000<Ql0034K000Z6`00:ad002dK
000Z6`00:al002XK000Z6P009ad002TL000X6`00:1P002HF000V5@000P0T5@001@0V5P009AH002DE
000T4`008Q<000807a8000`07A0001d>000I40005``001H;000C2`003`T000l7000>1`003@@000P3
00050P0<0?ooo`002P3ooolC000000030000o`00000000000080000000<0003o000000000000K000
0000200100000`4000H2000810002PH000h:000?30003`h00P0@4000100?3@0030T000X600060`02
00D0000Q00L2000=10005PT001/?000O50008a@0024C000S5@0091L002HH000Y6000:aT002PH000W
5P009aL002PI000]7@00;b0003HR000e:P00=BL003PU000e8000=B4003PR000h9P00>bT003l/0011
<P00BST005530@1IE`@0E7DJ0080?X`g02L0;YA>02BHGP0MVVd079mM01RRA`0IXcL07j8Y02BO7P0Y
VaL0:IhE02NP600[XA`0;j4P03BP9`0dXRd0<Z4^02fQ<P0[Xb/0:JHV02RU900/XbD0;J4Y02bQ:`0_
X2/0;Z8c036R=00bXB`0=J8U03>T9`0bYRd0:ZPj02RTA`0UWUD099UR026OI@0OY6D08jAQ02fAH@0g
Mf800P0jKF809`0kNV80>8AR04f;@01ISbP0?Idd02fT@00YY3l0;j5=04:MEP0jX6D08:Qe01^GM`0S
MW`0:eUn02ehJ`0aVEP0<ja:03>^AP0e[480<ZQ402jTC@0/UeH0;8aM02b8GP0ZPf40;HQO02j@G@0a
UeX0<Ia=02nPA00^Y3T0;:Ta02f[<00_[C<0=:`m03FUA@0dVT`0<IQ@02bGE@0202VJE@0W02bPDP0^
Yd/0<J]803:^@P0d/D80=K59036`D00/[UD0;JeL02b]H@0X[6/09[1X02FZIP0[XEP0=Xm@03b3D015
PUH0AHQL04>;F@11RU00B8e805:DBP1JV500G9I=05b:BP1JN4d0IFUA06QWE`1WIe@0H7=8069l?P1Q
Obl0Hh8K06Uo3@1_N0X0Lf`3079O001`F@00Ke800080JE4002L0JDd006Q@001UCP00HDX005m8001P
C000HDT006I:001WC@00Jd/006Y<001XCP00J4`006A8001Q@`00Fd4005M0001F?000FC/005Pk001G
?P00F3d005Xn001N?P00GD400617001PB000GTT005i5001K@P00FT8005Ln001D>P00ECL005Pg001H
>P00Fc/005dm001K?P000P1N@000301NA000HTD00692001M@P00Ed4005<l001B>`00DCP004hg001=
=P00C3@004he0080DCH00100D3<004`a0018;P00ARd003dV000o9P00>b<003TS000e8@00=240038N
000/6P00:Q`002TI000Z7000;1`00`0/7P001P0]7`00;Ad002XM000W6P009QL002HF008091L000<0
9AP002DG000U5`000P0U5@003P0R50008Q<001lB000L40006@l001H>000E2`0050/0018:000@2@00
3PP000d6000:10001`80303oool000X0oooo4`0000060000ofh0000000P00P0000D200091@002`L0
00l;000B3P00510001<C00805A<001<04Q80018?000>2@0030H000P4000;0`003`H001@9000K4000
81D002DG000T5P008AD002@F000V6P00:A`002`K000_7000:1L000809QH001809aP002`N000a8P00
=R@003DX000i9`00>bL003PV000h9`00?RT003l^0010;@00A3@004Lj0@1;@`80DU0405QS3@1=ORX2
03>=C`0W02NCH@0QV6L06Y]a01RQG00GXd<06j8a022P9`0UWad0:YdF02ZQ500WY1T0::@N02fR8P0a
XBH0<j<]032T<00/YC@0;ZHY02jS800`XA/0<J0L03:N7`0eWB<0=YlR03FN900gWbH0=ilT03FQ8`0b
XRT0;J4g02BPB00TWU@099]P02>GK00SWfT09jAU02fWG@0^WEP0<I5D0080=hY>02L0?Ha>04:;DP1J
S3<0G8lO03fP;@0aYCL0:ZDm03>LC@15UE/0?9]Y01fTM00OUGH0:GEi039GO00dNFT0=IYG03J/B`0f
ZdL0<ja503:YB00`Xdh0<9AD036<EP0`S5/0;X]L032GE`0_Xe00<:a803:/>@0a[2`0<:hQ02n_7`0Z
[bD0:k0a02bZ?P0bW4L0<8a<02j;C00/S4`00P0/TDd09P0_Vdd0<Z9;03>ZB@0d[TL0=[9803F_C`0`
[ET0;Z]Q02^XJP0XZg009jec02J[K`0WXf/0:YYM03:>EP0dRU80>I=D03VNE00nXTh0A9m1056I?@1K
U4D0H99=05f;B`1LOTd0HfQC06YLE`1UIE@0HfU<061i@01QP3<0Hh0S06=m4P1VM`/0K70506mT0P1]
E`00Je@00`1XC@009`1YCP00ITh006A?001UC@00Hd/00658001RA`00I4H006I:001WC000J4X006U<
001UBP00HTP00615001K@@00Ec`005Pl001H>@00ECX005Ho001J@000G4800615001PA`00HT/0065:
001QB@00HTT00656001M@P00F3/005Pj001G>000F3X005Ti001I?@00Fcd005`o000205i2000W0694
001SA`00HDT00654001M@@00FT0005Pn001D?P00DSX0058i001@=@00DcH0058f001@=000C3@004/b
001:;`00AB/0044Y000m:@00?B<003XT000e8`00<al0038M000_7000;Ad002lK000^6`00;Qh002hS
000a8@00;Ql0030O000_7P00;1d002/K000Y6@009aP000809QP000D09aL002HF000U5`009AD002DD
000202<E000<024D000L4`006A4001L>000G3@005`/001D;000A2P0040T000l6000<10001`<0303o
ool000X0ooooO`000002004000D0000000T00P00008100060`002`L000l;000B3`005A8001LE000J
5P000P0H5`009`0G5P005Q<0014>000B2@0040H0018:000H3`0061<001dG000R6P009AX002DH000V
5P009aP002PK000[6@00;AT002hL000X6@008aH002HC000V5P00;1X002hM000c8@00>2@003`W000o
:`00?RX003lZ000o<`00A3P004Di0015?P00Bd@1051D1P1CH`h0CWDO0424@P0202R7J00W02:>K@0N
VF`06Ii]01VSFP0JYD<07:<`02:R9`0TXR00:J4G02^R5`0YY1T09Z8N02VN8@0YVRT0:Il/02VS;`0T
YcH0;:@[02nP7`0cWQD0>Y`D03ZK5P0hVaL0?Y/D042L5@10VaT0>i/P03RL;00bVcL0:iE402J;F@0T
TF0099QS02:KJ00YXV<0<ZMM03BWE`0dY580<Z9>0080=ii802L0@IQ304V?@@1MRbH0F8`F042M8@0e
YBP0;Z<d03FJC018TEd0>iI[022QLP0SUW00;GYc03URM`0iOf80>9a@03R]A00f/400<Jm0032^@P0_
ZdD0<jM903NQB`0kW500?II@03NPB00hZT00=K0h03J_:@0g[al0=:lL036`7P0_/2D0;Jl`02fW>`0[
Vcl0;Xm2036<A00aRd<00P0dTTD09`0gW4@0>Z5603RWA`0hZT/0=jm>03F/E`0`Zeh0:jMW02NRK00U
YFh08jIc02JRK00XW6H0;9ML036BEP0cUDl0>:1;03ZYB012ZD<0Cilk05^@>`1OR4<0HGm905mcBP1W
I540LeQE07ICE`1ZIE00Hg=806B1=P1UQ2H0Ih<G06In3P1YN@D0KFl206mT001]EP00Ie0006I<0002
06Q>000I06UA001VCP00Ie@006U@001UDP00IDT006=6001QA000HdP006Q8001VB@00I4L006=3001R
@`00Gd<005a1001L?P00FSl005To001L?`00G4<005e4001QAP00H4L00697000206E;000<06E>001U
B`00IDT005i4001I?`00Fcd005Xo001F?`00FCl005/o001J@@00GT<00P1TAP00701TB@00I4d006==
001RBP00HDH005e6001J@P00Ed<005Hm001C>P00DSL0054f001C=P00D3D004ld001<<@00CRd004P]
0013;000@2X003lW000k9P00>B@003HQ000e7@00<Al0030P000a8@02030Q000902lO000_8P00;b<0
034R000a8000;b0002`L000Z6`00:AX00080:1X001<09aP002PJ000W6P009QX002LG000V50009A@0
028E000P4`00718001T@000I3@006@X001H;000B2P004@T000h6000;10001`<000`0oooo000:0?oo
ogl000000P01000500000009008000020@001P<000/7000?2`004Pl001DB000G5@006QH0008061L0
02L05aH001HC000A3P004PT00106000B2P0060l001PC000M5`008QX002DJ000U60009QH002LH000X
6`00:aT002dI000^7000:1T002<F000V4`009QH002`J000^7@00<b4003PT000l9`00?b/003hZ000o
:P00?c<004@h0015>@00ACh004]40@1@E0H0Df<>04ie7`10Q4800P0XQfP09`0RSVd07YU/01VNK@0I
XeX06ZE301bS<00RXRL09:8P02VQ5`0[XQL0:J@I02JR7P0YWR40:IXY02VO;00YXbl09:Lf02bT:`0_
X1l0<ihE03ZL500jVaH0>9/G03jK5010W1D0@9/I03^K800hW2`0<Y/g02^EA00VReT0995P02BHH`0R
VfP0:J9S03:WG@0dYeL0=:AB03:RCP0203NNB00W046H@`19Sd40GH/V05R<5P10WB40=JDX02jS=00e
VT`0B95M03^FJ`0PXG808iI`02ejL`0iHWL0>GmR03RLD00h[D@0=[10036_@00`[T80;j]503>WB@0g
XD/0>ia@03fFD00gX4P0>:Y003F`>00f[bT0=jlO03B_700a/1h0;k0U02f_<00]Yc/0:i/o02j?@P0a
S4@0<H]30080=99502L0=ia403ZQAP0hYdL0>:Y;03N_CP0e[5L0<:]N02^WI`0WXV`09JE^02>VL`0V
XV`0:9aV02bGG00aTUH0<iE?03RPB`0jZDP0@ZU304nO>`1KT3/0GhQ3065oB@1OLdX0IfAA07=HE@1f
DeL0JVE@06=cB01TPCH0IH@V06N35`1VOPh0JGT506e_0P1_I000KEH006M@001VC0000P1XCP006@1Y
D@00ITh006MD001YD000IE8006E9001SAP00HD@006=8001XB000ITT006A7001S@`00HT<005m3001L
@@00G3h005Xo001I?`00G3l005a3001MA000HDH00617001RA`000P1UB`00301UCP00ID/006E9001N
A000FCl005/m001J?`00ESl005To001K?`00FT4005i30080I4H001`0I4T006A=001SC@00HTX00656
001MAP00FT8005M3001F?@00DcX0058g001A=P00DcH0050e001?=000C34004h]0018;@00@b`0040Z
000o9`00>bH003TT000f8@00=Ad0034O000`8000<B400P0`8@002@0_7`00;b8002lS000a8P00<B00
02lP000/7000:Q/002TJ000202PJ000C02LH000X6P009aX002HJ000W5`009Q@002DD000R5@0081<0
01`B000I40006@d001T:000F2`004PX00149000>1P002`@000L3000<0?ooo`002P3ooomn00000080
0@0000<00@400040000000000P0000002@0200000P4000@200091@003PT0018>000F4`006QD001/H
000301`J000<01dH000J5@005Q8001@>000E2`006Pd001hD000P5P0091X002DL000V70009aP00P0Z
6@006@0X6P00:1P002TF000[60009aP002HF000U5@009aL002`J000/6@00<ad003HW000o:P00@Rd0
044b0014=000ACX004E10015AP00AD`104MH1@1;JA80AWXT0427=P0eRE@00P0SQW<09`0RSG807iYZ
01ZQJP0LY5/08:M602:W=P0TYB`08jHV02JV7`0VYQh0::DN02NQ8`0UVBT08hlb02BE<`0RWSD08J@i
02VR;00`WR40<I/H03bJ4`0nVa40?i/?042K3`0oVQ40?i`D03fL8P0fVSH0;Y=502R6D`0TMVD09XQP
02VJF`0YYUL0=JYB03bZD00kYU40>j5C03JOEP0203^QBP0W04>N@01?US40G8/H05F:2`13VA00?:0O
02jR;@0hW4X0BI9L03bHJP0TXfd09iaY02b8J`0dMfh0>HaF03ZSA00i[c/0=k4j036`?@0^/Sh0<k0m
03N_?`0n[440@ZQ604>UA00oZSX0?Zd_03b^:00j[R<0>:hO03F^7`0b[R@0<ZhZ02n_<00_[CH0<J@i
03FI?00gTcd0?8e10080?I9102L0>iU303bLAP0mWTl0>ImE03FUF`0cYEl0<:=T02ZNJ00VW6/08i][
02BOJ`0XWFH0:IeQ02bKDP0aVd/0>:5503jW@@14Yd00CYln05RE?01OQ400HWa406AaA`1UJD/0LF=A
08=LDP24GT`0L6U605ec>01RORP0JH8L06an3P1]NPd0K7D5075_0P1bIP00KU`006QC001VC`000P1Y
C0005P1XC`00Jdl006eA001[D000JTl006M<001VA`00HDH0069:001SA`00HDL00611001R@@00G480
05m0001K?`00G44005e3001L@000GD<00615001SA`02069800070699001TB000I4X006=:001UB@00
IT/006A9000205m3000605]2001L@@00Gd8005e2001NA000GdL00P1TB0009`1VA`00IDd006I@001U
B`00HD/00658001LA@00FT<005I2001F?000DCT005@i001B=@00D3D004hb001;<@00BBh004@/0011
:P00?bL003XX000k9P00>B8003PR000c7`00<R0003<S000b8`00<B8002lO000^7000;1h002hM000_
7P00;b00034O000`7`00;A`002dJ000202`H000C02XJ000/7000:a`002XJ000Y6000:1H002PE000R
5000818001l?000O400070l001T<000G300050/00189000>1`0030@000P3000<0?ooo`002P3ooomn
000000@00@000P0000002P0100000P4000D300061@002PL0010<000D3P0061@001/H000L6`0301hK
000?01dI000I5@006A0001L>000I3P006Ph0020D000Q5P0091L0028H000X5`00:A/002/J000/7000
;1/00080:aP001H0;1T002XM000Z7P00;A`002XK000]7P00;Qd003<Q000l:@00@S0004Hj0019>@00
C40004Q90@14CP40@e8304=K1@17I`d0@g/S03R8@00`SE<0:heS0P0TS7D09`0RT7007YU[01bOIP0O
YET09:Q<02B[@@0TZSD08JT]026Z9P0UZB80::PR02>O9`0QU3807X<l026=?00SV3`089m002VO<P0a
W2@0=IXI03fL5@10Wa80?ihB042N5P0oWAX0?ilO03fK9`0bUCh0;H]<02V2E`0SM6L09hQH02^OC00^
ZdD0>ZU703nYC@0lX5L0?9=M03Z@H@02046HD00W04bR?@1BX2H0EhlD05:82@1:T0X0@IHE03BQ9`0o
WdD0BIQJ03^LIP0YYVL0::9N02fHG00bSE`0>Ia803b[?00m/S@0>[4e03Na=P0e/cL0>k0b042b;`14
[c80B:de04Z/<015[RP0@ZdS042[900nZRL0?jXZ03^Z;`0kZc00=jla03Fa=@0e/CT0=jXm03^R@00o
V4D0?hi80080@Ha<02L0?X]@03^<E@0hRU/0=HeR03>CI`0dTfP0<Y9W02f@JP0WSf/099=X02>JI@0V
X6009ZAJ032UC00eYD80@:Dl04BQ@018Vcl0EI<o05j:?`1UOT@0J7M506QbAP1WK4P0K6]907UYA`1f
KT40J7Dg05ij:P1UOa`0K80?079m2`1fN0L0MG4207IZ0@1cH@00L5/006]C001ZC`000P1YBP004P1[
D@00KU0006U?001ZD000J4h006M;001UB000HDD00692001Q@000H4800692001M@`00GT4005]3001M
@@00HDD006=:0080ID`000h0J4/006U@0@1YCP40Idd006I=001XC000Idh006IC0@1WD`00Jdl006E>
001UC`00ID/005m50080HD8000<0Hd<00616001PAP000P1RB@009`1UBP00IU0006ID001SE`00He80
061;001NB000G4H005I1001E?P00Dc`005<j001D=`00Dc@0050e001<<P00BC0004@[0011:@00?2@0
03XS000h8P00=b8003DP000a7`00<200038Q000a8P00<1l002`M000/7000;Qd0030M000a7P00<Qd0
034O000b8P00<24002dN000202XK000C02`K000[7@00;1d002/K000Z6000:AL002LF000S50008Q80
024B000O4P007a4001`@000H3@005@`001@:000A20003@L000X4000<0?ooo`002P3ooomn00000003
008000010000000000<0000000/00@0000<100060`002@L000`9000@2`00510001LC000K5P006QP0
01/G000201`F000W01dG000K5`00718001XA000K3@007Q40020C000T5@0091T002<F000T5@009QT0
02PI000X6`00;1/002hK000`7@00;Qd0030N000b8@00<B<002hP000c8P00=2<003LU000o:P00Ac80
04dk001?A@00DT`104aG0`16GP@0@fL9041]400nMal0=h8k02^8H@0XRfd09I1_00808I=f02L08I9/
01jGI`0PWUl08j=E02NYC@0XZdD09JXl01n[=00NZbd09JXV02JY8P0SXRT089Dc01f1@P0TRd40:9Dm
02VL?`0^W300=I/Q03NJ5@0kW1H0>Z4I03RR7@0iXR@0=Z0^03RN;`0kVC<0=91202f=B`0YSE@098UQ
02bGCP0dYT40=je103bZB00lYUT0>9QT03Z6J@0jOf/00P15TE@09`1<X400D:8[056D6P1;R@l0D8L8
04^@3P0kXQl0@JDn04ZLE`0iW640:JIM02ZWC`0]YTL0<Z5303ZW?011/3H0@[@b03nb<P0o/SD0@;0b
04F_;018[RT0CJ`V052]8`1A[1h0C:`J04NZ7@15[B<0B://04V/=@16Zch0@j/l04:/?@10[T80?Za5
03fZB00mXdd0?IAE03b>E`0203^>G00W03V9H00iQF@0>X1Z03b2K`0kQ700?X9]03N2K@0_PF/0:HIY
02J>IP0WWF00:ZAG02jYD00fZT@0?JY004:T@018Vd00D99105f;@`1VPTH0KWU906icB`1/LdL0IW53
06Ic@01ZM3P0JgTb06Mo:@1UOR00JglB06em2@1hN0@0NG<207Q/0@1iI`00M6@0071N001^EP00Jdl0
0080JDh002L0Je4006a@001ZB`00HT/0065:001UA@00ITL006E3001P@`00GD4005e2001PA000Gd<0
06=0001O@@00HDP006Q<001[D`40JeL106]K0@1/GP80K5l406aQ101[G080KE`206iN0@1YG`40If43
06MO0P1YF@00J5L006IG0@1VD000HTP00655001OA@00H4@00656001TB0000P1TBP009`1SD@00IEP0
069M001SG`00IEX006ID001TC@00GTL005U6001I@`00E3d005Dk001D>P00DcX005<i001==P00CSD0
04Xc0011;000?BP003/T000f8P00=24003<N000c8000;b<003<S000f8`00<b00030P000a8000<Al0
038M000c8000=b<003DV000e9000<R80030Q000202dQ000C02dM000/6`00;Q/002dK000[6P00:AL0
02PG000V5`008a80024D000Q4P00810001h?000L40005``001D;000C2@004@L000h6000<0?ooo`00
2P3ooomm00000004008000020@000@40004000@0000000X00`8000L4000:1`0030T000l=000D3`00
61@001/D000K5`0071D00P0L5P0201/E000=01X@000K4@007a0001lD000T5`009aX002HK000V6@00
:1H002XI000[6P00;1h002hM000202hP000F02dQ000c8`00<2@0038S000d8@00=R4003XT000l:@00
?R`004Pf001@@`00D500059K0P1<I`P0@W4?03mg600iOb@0>HDd0328D`0RQg@098Yj026BL`806YUc
02L07YMY01nGH@0TW5L0::=?02VZC00V[4H09:dl01f/<`0NZc008j`X02JY900TYBL07j0_01bG=`0W
Vc@0;i``03>O;`0iWR<0?9`H03ZM400hX1P0<J@T03:T;@0aXcD0<J9003JO?P0iUSh0=Ha502n=C00Y
VE809IiL03:TB`0lYDH0?:I;03VSE@0hWfL0=i9/03^4I`0hOEl00P18S5009`1=VDD0CYhh04bI:01;
SAP0E8D:05681`12X1P0@Z@g04NLDP0fV5L0:ZM?032Z@00c[3T0=j/c03f]<013/C00@jl`04J^<`15
[3L0Aj`a04Z]:`19[2X0Cj`T05:Z6P1DZAD0DjXC056[601=[Ql0D:`Z04Z/=`1;ZdD0BZI504ZPB018
X4h0A:AC042SFP0mWF00?9AR03ZEI00203ZHIP0W03VBJ@0kRf/0?HA/04:5L016PG00@gm`03Z0L00a
Pf`0;8UX02NDH@0]XeX0<JU<03ZX@P0oZcl0@Za104^RAP1DUdh0GHi=06N8B01^OdL0N7=:07A`B@1Z
LD<0IFhk06A_=01TM2/0JWhT06f07@1_PQL0Kg/=07Eg101hM@00NV`007UW001fIP00Mf@007AN001`
E`00KU800080Jdl002L0JDl006A=001RA`00GT@0060o001S@@00IT@00694001N@`00FT400613001R
A`00Id<006A4001XA@00JDl006aI0`1/HPH0JFP906U/201WKPT0IW4>06E`3P1WL0d0Ifl;069/1`1Q
KP<0H7<7065a1@1TJ@80Hf@106AU0P1WFP40IE4006E>001TB@00IDX006I:001XC@000P1YE0006P1W
FP00IV0006=V001NIP00Hf<006QL001VEP00Hdl005e:001J@`00FD0005Do001E>@00E3/005<g001@
=P00CcH004Tb0016;`00?R/003/W000i9000=1l0038P000b8@00=R<00P0f9@000`0g8`00=B8003DS
000303HT000503PT000h9P00=bH003HU000c8`000P0`8P00100^7`00;Qh002lN000^6P0202dI000=
02XJ000V6@009AD002<C000S500081@001hA000K4@0060d001D;000C2@004PP000l7000<0?ooo`00
2P3ooomm00000003004000030@000P4000800@000`0000002P0300001P<000T6000>2P004@`001D>
000G4`006AD001`C000M5@0201dB000=01/B000J4`0061<001`@000P4P008aP002XK000/7000;Al0
02dN000]6P00;1l002dO000202/M0080;ad001H0;b00038Q000a7P00<1l003DO000h8P00>b@003lZ
0012<000C3/005M<001FG@40D6X804Ag4@0iPAh0=hH[03:;?@0`Rdd0:haT01j9OP0PRg`07Y5c0P0I
UVh09`0LVV407iiB02JRB00XYDX08jU>02:[A`0N[3d06Z`h01ZZ=00NZR`08jXT02BX9P0VYRL09j8Z
02nR:00eXB@0=J4R03ZN6@0jWQ@0=IlE03:R7`0[YBh09jDk02bT?`0]XT@0=:1403RI@00cSTL0;I=<
02ZQC@0VZUL0=ZM?03fPD00iUE`0>IES03NCK@0fSFX0>XEO03Z6E@0204N:C00W04Z?B`19UT<0AYPc
04ZA8P1CQ@T0Eh@4056J4@1;Xbl0A:1:03JKCP0^Yd80=:/i03f[<@0o[Bh0A:/^04R[=@18Z3<0BJ<g
04RR=@16Y3P0AJHe04>[<P14[B/0AZdR04Z]5`1<[1P0CZ`M04^^8P18[b`0AZdi04F/A@17YTT0B9Y?
04JFF010UF00?IIT03^DIP0lTVP0?9QY0080?9Y/02L0?iY^03nBJP0oRV`0A8Q/04J5L012Rg00>Xm`
02nBI`0[V5/0:Z1B036YC00jYD00?jDg04:U>017Y440Di]805bADP1TRUD0KHE@075iCP1eKdT0KG=4
06Mf>P1TMRh0IgLW06Uf6P1aMa<0MgX?07Yi301kLPH0NW0107Y[001fI`00M6<007IP001fG`00LE/0
06iH001]EP000P1/C`009`1XCP00Hdd00616001O@P00GD4005lo001M@@00GT0005hn001O?`00HT80
06A6001XB@00IdT106U@0P1YG@D0JFT806Qg4@1VNaH0IX0F06:25P1RQAX0H8<K05n36@1MPaL0GGl?
05am301MP@d0HWd;05mc101OLP80H6l506IX0P1[G`00JET006QD001ZDP00J58006aF000206YO0@0W
06ES0@1UIP40HV/0069Z001UK@00JVX106eR0@1VG@00HUD005i:001L@`00Ecd005Di001A>000CSP0
04lf001<<`00BS0004<`000m:`00>RT003PT000f8`00<R8003DT000g9000>BD003PU000g9@00=RL0
03LU000f9P00=bP003TX000k:000?2T003`X000j:P00=BT00080=R@000/0<R8003<O000`7`00;ah0
02lJ000]6P00:QT002HI000U5`0091@002@E0002020B000601`@000K3`0060d0018;000B2P003PT0
303oool000X0ooooO@0000001@0100000P4000<0000200000@0000800P0000/00@0000@000060`00
2PL000h:000A3@005@l001P?000I4@007Q<0020E000201hC000W01X@000H3`006`h001hA000P5@00
9QP002/L000^8000;Qh0030Q000a8@00<B00030O000X7P00:Ad002hM000a7P00<b<003<O000b7`00
=1l003@S000j9P00?B`0044b0019=@00Dd@005QH0`1?K0H0AgP>03^67`0bSRh0<hhn02n:CP0ZR5d0
9HY[01b;N`0NS7806HeZ00805HmW02L06IYI01jRB`0TYD@08jE8026[B00P[T007Jdh01R[>@0JZS@0
8:/Z02FZ900ZZ200<JLL03NU6@0lXaD0?Z4E03ZO5@0mXA@0>9hJ02nN8P0cY2L0;J<i02RU@P0^Ych0
<JLn03JU@00hXCd0<i]702fMB@0[Yd/09ZUB03NRD`0lU5X0=8IV03F5J00dQ6d0>8IQ03f2E011Q4/0
0P1:Q4h09`19Qe@0Bhe<04JD@016TBX0DHL=05^2101LU0/0EZ8W04JR@@0iX4<0=JPk03fZ=P13ZCD0
B:Pf04ZW>@19Yc/0Bihj04ZG?P1:Ud00AYa004FR?P12ZCX0@Zdc046_;@15[B<0@jhN04>_8P12[RH0
@:d/03j^<@0n[3/0@:Q303nQDP0kWED0>Y]L03VGGP0hTf40>I5S03ZBH`0203nAIP0W046BK014SF`0
@XY]04B:K013TFd0A9]Y042PH`0nY5D0=jA:03RTA@0mXc`0@:0b04BP;@15VcH0D9Dn05^?A@1WR4l0
Kh1A07mkDP1hMd`0K71606Ic?@1UNc40IgdX06Ui6P1[Ma00LG@907]a1@1lK`80NfX107IW001fIP00
M68007AL001`F@00KeP006]D001^EP00Je@00080K5D002L0IDh006=:001QA`00G4@005do001L?P00
Gch005/i001J?000Gcd005i2001UAP00Jd`006UC0P1VH0T0I6d?069j4`1RPAd0H8PS066;:@1PSRX0
Gi0V05b?8@1KSAh0GX/L05b75P1KRAH0Gh/G05f74@1MO@P0GWh605ml1`1TM@H0Ifd406US0P1]FP00
JeT006YI001[HP400P1SJ0809`1UJP80I6X2069Z0@1RK@00IG8206Ue0`1^LP40JFP006IK001SD000
H4L005U2001D>`00DCP0054f001:=@00B3@004H`0012;`00?2T003`U000k9000=240034Q000i8`00
=bD003/W000l9`00?BX003LY000g:000>2/003LZ000i:P00>bX003`/000j;000=bd003L/000203HW
000C03@T000c9@00<R8002lM000]6@00;1/002/J000X6@009QT002DD000T50008Q80020B000O4000
6`l001T>000E2`0050X0010:000<0?ooo`002P3ooolm000000800@00?`0000020080000?00810003
00000`8000<200030@00108000P3000<1`003`T001D<000E3P006@h001X?000K4@0071@000807A80
02L06A4001T=000M40007a@0028F000U6000:1d002dL000`7P00;a`002hR000a8000<24002hN000Y
7000<1`003@O000d8`00=b8003@N000f8000>2<003/[0012;`00AcX00510001FE080E6`804=j4P0n
QQ`0<i8`032F?`0aSdT0:GmK02AoI`0MQFl068]i01N;KP0ER6H00P0ERf409`0JUe807Z=902:VA00S
Z4408j`i02>/<`0Q[3@07:`m01j/=@0SZbL09j/N02nX6P0kYa<0@:8=04:Q3@14X0h0@Il?042P4P0l
XAT0<J<P036T:@0ZXcL09ZA202nW>P0dZ3L0=JTf03NW>`0_XTP0;:A902ZWA`0YYE00=i]C03Z>F@0d
Q680=H5V03MoIP0lQ5T0@h9>04F5C@0204moE00W04V0G@1:QE@0AI9<04>C=01;RQH0Eh@906F?2P1N
WR00Bj4m03jS@@0mZcX0@J`i04N[>P1:Zch0B:M004FP@`14UD@0AhU804B;B`11Td/0@Ia604:W@P0m
[Ch0@:hh04>_;@12[bH0?jlV03j^:@0l[R/0?:`Z03Z]<P0l[400>ZU@03bWDP0iXEH0>9YH03ZDF@0i
ReT0?XAN0080@7YS02L0@WaW04EfK`17Og80AHIa04>GK01:XF80D:EF04fOA`1:WSh0BYXj04VN=018
Wbd0AiT_04b=>@1FRT00IH=206anB01dMTd0OWA?079hB01UOCl0H7X_06Mn8P1[Oa/0LW`?07Ef201f
KP<0Nfd107UZ001kJ000MfL007EX001eHP00LET006mG001]DP00JU<006]C001/D0000P1[C`009`1Z
C000IdH00611001M@000F3/005Xl001I>P00FSd005Pn001L?`00HSl006M:0@1[E@<0J5`306MY2`1S
MA<0HWhJ06:5901QR2d0H8dc05f@<`1ISRL0FX`J05Z;501NRAD0FXHF05j8601OSQL0H8/B05b82`1I
R@`0FHP>06233`1TO0X0J6d706aS001^G000JUh006IW0@0206A]0P0=06E^0P1QJ`80IFP106E_0@1U
L`80IGP406Ug0P1ZLP40JFP006MJ001QC@00FTH005M0000205<j000H054g001;=@00BC8004D^0010
;000?BH003/S000g8@00<b8003<T000j9`00>bT003`/000o;@00?2l003h`000o<000?Rh003`^000l
;@00>R`003/]000j<000>bd00P0j:P004`0h:P00=BH003<S000_7@00;A`002/J000Z6P00:AT002HF
000V4`009Q8002<B000R4P00814001`?000J3@0060d001H<000C3000303oool000X0ooooL@000000
0`01000000000000000:00000003004000030@00104000801@8000`01`8000P100080`002P<00108
000A2P005@d001/@000K4`00718001dB000L600201dD000?01X@000L40007A0001lC000Q5@009AH0
02HK000U6P00:QT002XL000^6P00;ad002lQ000a8000<B800080<Ad001H0=R<003LP000k7`00>B00
03lT0015;@00BCD004e3001>CP40EF@604]g500mQRD0=Xh`02jH?P0`VdP0;HaF01abKP0KMG@06Wi^
01R7K00JT5X05iMD0P0IVU409`0MWTh07jA=02BWA00SYS`08j/_02V[:`0TZbh08Jda02B[:`0Z[200
;jXF03BX4@0mY@`0?j<804>R2@14X@/0A:4=04:S400nYQP0=:LO03>X9P0_Z340;:Lj032W=00bZS<0
<j`h032Y@00ZYU<09jE=02fUB00YXDh0=Y]?03VBE@0gSE`0>8YJ03V5FP10QeD0AXAB04Z4D`02055n
F00W04ajH@1?OEX0AhMI03n<B`16SR/0DXXH066A301NVQ/0Bi`h04:P@@13ZCh0@ji104J^@P16[440
A:Y104>PB012TdP0AH9?04:0DP0oRDl0?IE;03fSAP0m[TH0?[1003n_=`0n/2l0@:l/03b_;00m[bh0
>jd/03^[<00l[C`0?Ze;03bZC@0jYdl0>j9A03RLEP0hTeL0?XUE0080@GiL02L0@7AR049TK013MVP0
@ha[04NRHP1DXU/0FIe=05JDA`1FTC`0Eh`g05^E=01KTc<0FXdj05j1@P1UODP0JgY506YhB@1_MD`0
KgI;06V1@01QQS00HhHO06f05P1dOP`0NGT707ic0`1kK040Nf`007U^001kK@00N6l007Q[001fIP00
M600075H001^D000Ke<006eA001[C`000P1[C@009`1UB`00ITX005m3001I@@00EcP005dl001I?000
FCd005m1001NA@00HTT006=C1@1RG@X0IV<706EW2@1TL`h0Gg@>05in5@1NPb40GhLT06>8801KQ1P0
GH<A05n03`1NOPl0H7l>05n44@1PRA@0H8PA06::401JSQ<0E8lG05V?6@1JR1T0HWL=06U/0`1YIP00
IfL006I]000206Q_0@0L06I/0@1YJ@40IfH006A_0@1TM0<0HWT506El101WN080JFl006YR001UE@00
Gd`005Y1001E?@00DS`0054j001>=`00BS@004L_0012;000?RP003TY000h9@00>BL003XV000j:000
?R/003h^0080@S<000T0@c@0048e0014=@00?c<003ha000n;`00?C80040e000n=P000P0n<`004`0k
<000>2X003DU000c8000;Q`002hI000[6@00:1P002LI000W5@008a@0024D000P4P00814001`?000L
3@0060`001L:000D2`00303oool000X0ooooL0000002004000/0000001800P00008100040@001P80
00P200091@002P@000T4000=1@003PL001@;000I3P00710001hC000R500081D001lG000P6@0201lD
000W020C000M4@007Q40020E000P50008AD002<H000R5`00:1P002PI000Z6@00;1/0030Q000b9@00
=2L003<P000c7000=28003HQ000i8`00?RT004@`0019=P00CT@1051C0`1?H0L0CW4A04B49@0bSSh0
;i=802fHC`0_UUH0;8aR01ilM00OP7007HMT01Z@FP0JVDh07Im>00807J=D02L08Z5A02FRC@0YXT00
:j<c02bW9P0ZZR@09ZdV02:[9`0T[2<0:j/K036Z4@0fY@d0>:D<03RT2`0mX`d0?jH?03bV4P0jYaD0
=:XL02Z/8@0/[2@0:Z`Z02VZ<@0_Zc<0<:`h032]@@0[Z4d09:9N02NSE@0_YDT0;jA:03RPC00jVe80
=YMI03VFE@0iTeH0?i1H04J8F`1:QE/00P1COE`09`1;MV40DGMO04]gH`14OEl0AhM904n;;P1JU1@0
G9dI04bM<`16XCd0AJTn04J^@`18[T@0Aja604>VA@0oWdl0?iE;0466C@13P5<0?8=F03V?E@0hWE<0
>:]>03V_B@0j/4<0?Jdk03b^=00l[S40>Zde03f/;P0l[C40?Zhh046^A010[4P0?ZU>03nWD00kWeH0
?9]H03^GEP0203^;F00W03eiGP0mIF@0@X1P04>IG@1=WUP0F9UA05ZEC`1FTdT0Ei8o05V@>@1NRCX0
Ggm206AeB@1[KTl0K6]>06UXC01UKD`0HgA6061i@01RQ2l0IXXN06Z55`1bN@`0MWD107Yb001jJP00
OFT007a/001jK@00NFh007U]001iJ@00MVH007=P001`F@00K5L006eF001_E`00KE800080IE0002L0
Hdd006A;001OA`00H4@005e3001N?P00H3l00693001PA`00HT/006IC001VG@H0IFL;06MW1`1WJ`@0
Hfd606=a1`1NM`l0GWlG05n4601OQ1D0GX@C05f34@1MPA00GGlA05al3P1JP100EXHD05V65P1LSAL0
E98I04jC7P1@UB@0EI0T05b06P1TM`L0IG4106Mb001XK`000P1/L0009`1/KP00KF/006Y]001TL040
HW<3069h1P1SOPH0HG/406Ec0@1WJP00HE/0061>001KA@00Ecl005<l001?=P00CCD004Lc0017<000
A2`003lY000l9`00>BL003/[000n;000?Rh0048b0012<`00A3D004Lh0016>`00B3`004Dl0011>@00
@3P003lf0010=@00@3L003hh000203hj000C03dh000m=@00>2l003DR000b7P00;A`002dK000Z6@00
:1T002LG000U5P008A<001lB000M4@0070l001`=000J30005P`001<:000<0?ooo`002P3oooml0000
000C004000020@001@8000H200091@0030D000h8000?2@004@P00188000E2P006@h001hC000P5`00
8aP0028K000T6`007aT0024E0002028F000W024F000O50008A<002<C000R50008QH002<G000Q5`00
91P002DH000X6@00:a`0030O000f9000=BD003<P000c7P00<R8003`S0011:`00A38004Xm0@1?B@80
DU`404mY3018MAH0@H0S03B<?P0XT5P09i5L02JAH00XSV809hQW01j0N@0OQV/07XeO01^DDP0PW4P0
7Z5:00807:EA02L08jEA02BTB`0YY3h0;J4c02^X:P0YZRT09JhW022/8`0S[B00:j`H02nZ4P0`Ya40
<ZPB032Z4`0dYaD0=jPF03:[6P0_[Al0:jhX02F^;P0X[RT09jdX02R^:@0`[Rl0<:dm02b^B@0WZUP0
8:=X02FUF@0`YdL0<:U403^UB010XTl0>:5F03VSD`0gXET0@YIO04Z=I01?Qf400P1DOeX09`1AMUh0
F6iS059[J019K6`0CWQM04f6@`1AV240E:0I04fR8@1=YBX0D:X`05>Z>01?Zc/0C:Ho04JSA@13VU80
?iIA03n:DP10QED0>XIM03V;H@0gUF80>:IK03^]D`0k[4X0?Je203b_>00m[c80@:h`042];P10[Rd0
@Zh_04:_>013/3`0@Zm8042XC@10XEH0@YeL042JG@0203jAHP0W03f3I@0jP680@i9J04ZNEP1HT4l0
Fhi;05R<CP1FTdL0EiTl05NE@01HQ4P0GGI>06IYE@1_IUP0IFUD069]C`1RMdL0Ggho06:0<01ZQ1l0
KH<B07El3@1hL`D0Nf`007U[001hJ000MVP007EZ001eJ@00N6T007IV001dHP00MEh0075O001_F@00
LEH0071G001`EP00Ke@00080JE<002L0Idh006I>001WC`00IT`006E:001QB@00ITT006=<001XCP00
JE<006MI0@1TH0<0IFD506QY1@1VK0D0IFl7069d2@1MNPd0GH0A05^54P1KR1<0FhXE05f85@1IQ1L0
F8DH05:35@1BQQH0DhHI05>;6P1ETb00EILR04nI:P1@US/0EXdn05j59`1ROa40IGd506Qm0P1ZN000
0P1YMP009`1/L`00Jg@106Uc101XL`@0IgH406Mg1@1QN0H0H7d506Aj0`1WKP40IV40069B001OA000
ESl005Hk001@>000CS8004Pd0016=000Ac00040^000k:`00>b`003`]0013;P00@S0004@d0016=`00
AcT004U1001;@`00BDL004E60011@@00@Cl003lk0010>P00?c/003hm000203do0@0>040o0010>`00
?S@003X[000g8`00<R00030L000Z70009aX002HG000T5@0081<001hB000K400201/>000301/;000I
2`005@/000`0oooo000:0?ooogX000000P0100004`020@001@4000P200091`003`L00189000E3000
5`h001D>000H3@006a4001lD000Q5`008Q/002@N000X8@0091`002<J000R6P000P0R5@009`0S5@00
8AH002@B000S5@008a@002DE000U60009aL002DE000U5P009aL002/J000`7P00=b8003DU000a8000
=R8003TV000l:`00@S4004Ti001BC040DUd604a]3@14Nad0?X<`03F7@`0]SED098mV02>>JP0ORW80
8HM_02>9J@0PRFP098mG026DC00LVTT07ii:01fPC`0201^SE@0W026SDP0RYT`09jE102RT>@0WZ3<0
9:Xb02B];P0M[2@08:dQ02J]6P0XZQD09jTG02RY7@0VZb@0:jTQ02f[800Y[bD0::lZ02:^;`0O[C@0
9:h[02J]9P0Z[2D0<J`^036]?P0[[e<09:YN022TK00TYUd0<Z]803B]@00mYd00?:=<03VVE`0iZEL0
>JMU04BMH@1;SF40DHIO0080EgYJ02L0EFiN05]XI01GHFh0D6A^059YHP1>O580CYLa052V8P1?Ya`0
DZLL05RX801EYR`0DZD`05>S=`1<Wd00AII>03nFE@0oSEH0?H]J03V8G@0hS5h0=YIR03RTG@0h[5@0
?:a:03j^@00o[cD0@Zl/04F_:P14[RP0@Jh]03j^;P0o[C<0@jlh046^A@11ZdL0@J=>04>KF010T6H0
0P0lSF`09`0jSfH0?IYN04ROEP1AVD`0FHU=05f>A@1KTTD0FII105VL@01DUDL0EXE>05YeD`1TJUT0
JfMI06A]E`1OLE00H7e506:6=`1SR2D0Kh8E07Ml2@1kM`@0O70107i[001iJP00N6D007QV001fHP00
M6L007=V001cGP00L5d0071H001aFP00LeT007EJ001dE`00M5H006aC000206a?000W06U?001YD000
IU4006Q?001UD000J58006UA001VDP00JeH006YP0@1YIP40IVH106Q/0@1XL0D0IW<:069i3@1TOA80
GWl@05^13P1JQ@h0G8TC05Z;5@1MRQH0Eh`I05B<6P1DRQT0DH/L04f<8@1BSb<0EiLY04fK;P1>Ud<0
Dh]A05ioE01NNT<0GhLQ066>401TS0L0JH@40080IWh202L0Ig`306N01`1ZP`X0Ih8906B02@1SO0P0
HW/705in1`1RO`H0IGL406EY0@1UF`00GT/005M4001E?000DS/004Xg0018=`00BCD004Pb0014<@00
?C0003`^000l;`00@30004@e0016>P00Ac`004M2001:B@00C4l004QE0013E040@Dh004190012A000
@TH104150`10B0@00P10B0H04`10B@80@4D0040k0010<P00>RT003DQ000`7@00;AX002TK000W5`00
9QH002@B000R4@007A0001/>000L3`006Ph001T=000G3000303oool000X0oooo;`0000000`010000
00000000000800000003004000000000000003`0000000T00P0000<100040@001`<000X5000=1P00
3`P0010;000E3@000P0I4@002`0I4`006aD001XE000N5P007aX002<J000V7P009B0002LO000R7@00
8QX000807aH002L08AH0024E000S5P009A<002HD000X5@00:AT002TE000Z50009aH002XH000^7000
<b4003DQ000h9@00=R8003LT000l:`00@C8004Hh0@1<A@80EUT704i[4P12NQh0>h@d03:5C00^Oed0
9HAV01j5M00PPg@07h1j0261L`0RRFP08Y=L02BHB`0PW4H07:5801bRB@0OXDP00P0MXTP09`0QY4H0
8ZI402JV@00VZ3h09:/j026/>00P[C<07Jh]022]9@0U[1h08Z/K02>[8@0SZb/08:`e026[<00R[Bh0
8Jdc022]=@0O[CT08:lj02R];00YZb80;j/N036^:@0^[Sl0:K1A02>]G00OZF/0::]J03J`AP0j/400
?j]003fUC00hY5H0>jQJ03fYHP17WU/0CHiL0562F00205agE`0W05i[G01PHV40GEUW05YIJP1JGf40
Dg5F04bC?`1:Ybd0CZXO05FY601HYQX0EjDT05>O9P1CVBh0CiTh04>BD00mUE80?I5G03f?F00jRUT0
>X]L03NDG@0jX5X0>JYB03R[B00mZd40?j`h04F]:`1<[RH0BJdW04>^;`11[Rl0?Zde046]?00oZd80
@J/n03jWB`0mVeH0?XIR0080?XaS02L0?YYM04JSF01AW4h0DY=<05:9D01HTTD0Ei]005RN?01GW3h0
EIE605F6C01HN5@0HFmF06A^E@1NME40G7M=05j3@@1SS300KH/P07N1401mM`80OG4007i^001oK@00
N6T007QW001iI@00NF4007=O001aH@00KEd006eI001/E`00KE/0079I001dF@00LeL0075F001/DP00
0P1ZCP009`1WC@00IT/006Q;001XC`00IU4006QB001WF@00K5T106eQ0P1ZJ080IV/206I/0P1VLP<0
HWP8069k3@1NP`l0HXPB05j84@1JQQ80F8T@05Z;401JRQ40FXdD05N?6P1ATAd0DI4L052C8P1>UB/0
CIP`04bJ=P1=VT00CHmB05MkG@1SLE/0Gge;05VA;P1JV1d0H9PG062C3@02066<1P0E06>9201TS0d0
IHhE06>=501SSA<0GhLB05n43P1NRPd0GXP:05j11`1UL`<0I640069?001K@`00ESd0054j001@>P00
C3L004/g001:=P00AS<00080@3000100@38004Dg0015?@00AT0004E70@15C`40B5H104ML0@12HP80
?f0203iL0@0oE`40?U@3041C1P10E@X0?5H?0P0jF0h04`0kE@H0?4h204150010=`00>bh003HS000a
7`00:a/002XI000Z60009aH002DD000U4@00810001d>000K40006Pd001P=000G2`00303oool000X0
ooooCP0000000`01000000000000000W0000000=004000030@001P8000T6000<1P003PP000h9000B
2P004`/001H<000H3P00718001hD000201`C000801dF000R6@0091X002HJ000X7`00:R<002TR000X
7@0202HG000W01lE000P5P0091@002@E000V4`009aH002TI000Z6@00:aL002dI000_6`00<Ad003HS
000h9000=bL003PX000n9`00@Rh004/i0@1@AP@0EED:05I[5@18NRH0>8<h03:6C`0WPfD0:gY^02El
K`0RO7H08Gae01]jO@0NQ7D08i1X026LFP0TWdL07Z5001RV@@0IYT<06jA300807:E002L07ZE1026W
@@0QYd008JTo026[?P0M[CT07;0i01^`=P0O[R`08:`U01j/8`0M[2d07:dk01f]BP0MZd807JU101bX
@@0OZch07jdm022^>@0ZZbX0;Z`J03>]5P0b[BH0;:li02BaBP0S[U@07ZeQ02b/D`0n[d<0@:hm03jU
@00kX4h0>J5F03jUF00oZ5d0AieB04f<D01FOE@00P1SL5L09`1VI5d0I5aR069EIP1OEFX0GemS05Uc
F@1@SdP0Bj8i04fY9P1CZQ`0GjHG05^Q701DV2<0D8l/04^C=01:SdP0@iE>03jCF011TUP0?HiJ03j;
F`0nTE/0@9UH03fTDP0kZT`0?:Q8042[@@11[SH0AJha04F];014[C<0@:dh046/>`12ZT<0@JI604:Y
@@11YTh0?YYE03j9G00204BDDP0W04ZRC`1BXT/0E9U805:@B@1CQTX0F9E005RQ>`1HXCP0Eilj05:B
@01DPTP0FgQC05i`E@1QLEH0G7=@05YhC01OQ3`0J8`W07:2601nM`X0OVd1085/001mKP00NVd007]]
001kJ000NV<007QS001dHP00Leh007=K001cF@00L5P006mE001cE`00MEP0075H001]E000Jdl00080
Jdd002L0IT`006A=001XD@00Jdd006aA001]E000LEh406iV2@1XKPX0IW<9069c2P1RM@X0HGT=0660
4`1PQAD0GhTB05f<501JSQ<0FHXB05R84@1HQPd0G8P<05V73@1DRa80DXlH04jD701;VRH0CYX^04bL
>P1;VdD0CHiB04ioGP1DKF@0GFmL05R3A`1GVS80DJ@X05FV901GWaX00P1JUa409`1LUPh0GILE05nF
6@1QUaX0HIHN05jA7P1NTAP0Fi0G05V=401JP`/0HG/606IZ1P1VF`<0HDl205U40@1F?@00CcX004hl
001?>`00C3P004Xh0015=`00A3H004Ll0016@000AdH0049<0@0nEP80?Ud3041T1@0oJPL0=fd903EZ
2@0eIPD0=f<603QO1`0fH0X0=68@03=V5P02035Q400C035L1`0dEP80>d/003i0000m<`00>2T0034Q
000^7000;1T002/I000Y60009QD002DB000R4@00810001`?000L300060d001H;000<0?ooo`002P3o
oomg0000000>008000040@0020@000/5000?200040X0014:000A2`004`X001@<000F3@006A0001/B
000N5@0201lC0008024D000T60009QX002LK000X8000:b<002dS000Z800202@I000W01lB000R4P00
9Q8002DD000V5000:AP002TJ000/6@00;Qd002hR000b8P00<b8003LQ000h9@00>b<003`W0011<000
BSL005E70P1GF@/0D6hK04Uk;`0mNTP0;WIM02MmJP0MOGL097Qd025dN@0QKW`086ml01ibO@0PPg40
8YIT01jSF00PYDT07:I301NYA00HZ4<06JM200806ZI102L07JM201bY@@0MZD007JTn01^[?@0K[ST0
6[0g01j`=P0N[Bd07jd[01^];P0J[CP06Ze401Z^E00JZU006ZQC01VUE@0LZ4T07Za1026`?@0[[BT0
;ZdK036_6@0a[RD0:K0f02Fa@P0T/4`08:mI03B^B`17[Sh0@ZXm03jRA00mSe<0>IAG03bND`0lX5H0
B9a:04Z?C01CP5000P1SLED09`1[I5/0JU]J06M=I@1QEFH0GVAS05QfFP1CR4l0CYQ304fW<`1DZb@0
H:HI05fQ5`1HVB80DY4^05>?<`1AR4<0B9=904>JE012VEL0@I1F04:;F@11Re/0@Y1J03nIFP0lWe<0
>ZA<03bZA`10[Cl0@Zhl03f^>00k[C`0>Je003fZ@P0oYd@0@jM504JXA`16Y540@iYD04::E00204ZI
B00P05:S@01BXT80E9a605:IA01EUD40G9db05bP<`1IX300E9l_05>G=@1FQdD0F7]@05i_E`1PK5P0
G7UA05amB@1VQRl0LX4I07Uc2`1lK@@0NfD007UY001lIP00N6T007Y/001nJ`00NFX007aX001hHP00
Mf0007AK001aFP02079C0005079B001`D`00KED006e?001WC@000P1ZB`009`1XD000Je8006]E001[
E@00K5L0075O0P1bK``0JGPE06Al5P1QOaH0HH0G06:26@1NPQT0GXTM066<7@1OSAT0G90F05RA5`1G
SAD0F8dD05R<4`1HRa00F8X?05R=4`1AT1L0CIPQ04NN:P18WS80BYa304bDDP1?PU`0EgUN05U_IP1G
NEH0E91005>P=01=Zc40D:/^05:U9P0205FP6`0W05FN5`1LWa/0H9hN06:M8@1SVbD0GYXQ05^E701E
Tad0EHdG05J74`1KP1@0H7TC06E]3`1QH@/0G58405E50@1@@000CSd004do001<?@00C3/004Xo0018
@P00BdL104]=0@19E`<0AV07041Z3@0mL@d0?7HB03Uk6P0bNah0<gTO03Ea600fKQH0>FPF03UU5`0h
IaT0<VLL0080;fLD00P0;f4<03=J1P0fC@40>D8003Xe000i:`00<b<002dQ0080;AX000T0:AP002LE
000V5@008Q<001l@000M3P006Pd001P<000F3000303oool000X0ooooM00000020040000I00@00006
0P0020@000/4000>2@004PX001@<000G30005Pd001H<000I3000610001l?000N5@0081L002<I000T
6@009AX002HK000W6P00:1/002PO000Z7P00;28002/M0002028F000301lB000P4@008aD000808a@0
02809Q<002XG000Z6`00;b4003@V000f8`00=200030R000e8`00>2@003l[0018<`00E4<005]D1@1D
KAL0@Gla03R0B@0_LFH09fQh025bO@0IMX<08GMl021fNP0UMGH09ge_02B8K@0SUF<08:5N01fVF00O
Yd`07ZI601VXA`0HZ4P05jE90P0JZ4X09`0IZTT06Ji301V]@00LZS`07ZXj01j/=@0O[C808Z`^026/
;@0O[C007:hi01f^?`0K[TX06ZeG01Z[EP0JZEX06:MN01^WBP0N[T408K4o02R_;00]/280;k0O02j`
:00X/CP08k1002BbA00S[dT0=Ji004N/>010ZC/0@9a603f5F00hRE/0>IAB03VKE@15X4H0@ia504f>
C@0205elE00W06A]E`1UI5X0JEUQ05mQH01MKEh0EWYG05F6D01@TDP0DJ0h05B[:@1OYQ/0G:<F05VN
7`1GV2/0FI8_05N5@01?TT40Aj1=04:RD012Ve@0@8eE04F6FP17Pe`0AhQH04N=F011Ve80?Z=<046[
A00n[T<0>Jm803R^C00f[580?:M>03nQB`14XTP0Aj5:04FME017T5<0AX=E0080CYE202L0D:@l052T
AP1@XDT0DZ95052U=`1HXbh0GZ8/05bQ9P1KWRD0EiT^05Z@@01MP4h0H75G061_F01OO4h0GXE107>4
8@1nM``0NVL107MS001eH@00MF8007=P001hH000NVH007aW001kJ@00NfX007]V001gH`00ME`007=K
001cF000KU<006m@001^D000Je0006U?001XCP000P1[B`009`1/CP00K5D106eL0P1`H@@0MfP907Mc
4@1`OQ`0Ih@R0669901PSB<0FH`O05Z=8@1JRR40G8/M05^;701GSAP0FXhF05R?601KSAT0FXdJ05>>
701BSah0DhlM05:A6@1EU1`0DYPT04bO;P15XCL0@i]<04V:G`1FLfD0G71T061hH`1JSU40EJ0j052W
<`1=[3@0CJdc04nY:P0205:Y7`0W05>V7@1GYQd0F:HR05^U8@1LWb40FI`O05JJ7P1?VR80E9DM052B
8@1ESR<0EXTS05V68@1JN1T0F6D?05=C201CC@L0DdX705=:1P1@B0D0CTX504m=1@1>D`H0C5`604MV
1`12K@h0@GTH03N3900fQB@0=8TZ032;<@0^R3L0;h@j031n<`0bMbl0>G4^03M[:P0eJRX0<F/V0080
;fXM00X0;VXF02mN2@0dD080=d@003Tf000h;000<R<002lN000]6P00:QT00P0Y6@001`0X5`009AD0
024D000M4P006Ph001P<000G3000303oool000X0ooooC@0000000`01000000000000000R0000000M
0040000200000`4000L200090`002`D000`6000@20004`/001H=000H4@006Q0001d@000K4@007A@0
024C000S5P008aL0024H000S6@009QP002HJ000W6`009aT002PI000W6@00:Ad002XN000V70000P0R
5`009`0R4@008Q<002<C000V4`009QH002LE000X6000:aX0034R000d9000>2D003DR000_7`00=B@0
03/Z0016<@00E3l105YD0`1GJ0l0B7/X03:2B`0YNV@0:6Qj02MPQ00OJhD07G:502=lNP0QPGT09XAb
02^=J00YUfH099eL01jSF00JYU<08:I?02BTBP0OYTd06ZA?01VPEP0201^UE@0W01VZD@0J[4@06Zdn
01f]?00QZSX09:Xc02RY;@0/ZRH0:Z`X02F];00S[c@08J`f01n/?`0O[DX07Zi>01f/D@0JZeH07je8
02:]@P0S/D40:[4b02b`:`0_/BP0<;8_02^b?@0W/d@09k8n02Ba@00i[SD0BJ/b04:X?@0mUdd0>geJ
03Z1G00iReX0=IEG03nQA011YD00AIQ<0080DHAB02L0F7MI05i^F@1TI5`0FfEN05QaF@1GNeH0DhM<
052<@`1?VST0DjD[05^X7P1LZ1L0FjLQ05NP;01KTc00F8<k05:=@019Wd<0AjE604BQB`0oTe80B8QF
055kF@1?OEX0Ch9K04Z?F013VE00@Z=903bXBP0i[4l0=ji@03V_C@0o[4@0@JXl046Y@018ZDH0BJM6
04bN@@1=U4000P1?VcT05P1@XcL0Cj@k05NT>`1HYCL0F:H_05VS901MXb40Gj8L05ZO801KVRT0GIDk
05Z4CP1LM5L0G7=B0621?@1XRRX0O7hF081^101mIP00MfD007=Q001cG`0207AL000?07YR001lHP00
MV@007UW001jI000NEl007=L001bE`00L5D006aD001XC@00Id/006]>001YC`00JTh10080KU0402L0
LeD807YL3P22Ia@0R70H08Mk7`1lQ2T0N8<`06n5<`1VTBh0HYL/062G9`1OU2L0H8`R05n37@1KPAX0
F8<F05b55@1JQaD0FHTE05V:5`1GSAT0DHlN056@7P1?Tad0CiLQ04fM;018XSP0AIi604J@G@1:PfX0
DgE/05iaI@1PPUP0FYe405>W<`1?Xc@0BjXc04f^<`1=[RT00P1>[1l09`1CZQl0E:XR05NZ9@1HZ2<0
Fj8S05NR8P1DXR<0D:8S052N8P1?UbD0CI@U04bC8`1<T2T0E88[05Qa9`1JI240G5lN05QI7@1GFaT0
D5dE04mT501<JQ<0BG4A049h4`0iOaT0<HLR02f?;`0ZU3d0:i<m02ZD?@0WTSl0:Xi002N7@00XPCd0
:GTh031c=@0`LRh0<G4Y02m^8`0202a[6`0C02aX5@0]H0T0<E8203I5000j>000=Bh003@V000`7`00
;a/002`J000Z6P00:QT002LG000S5@008Q8001h@000M3@006``001P<000<0?ooo`002P3ooomb0000
000M008000040@001`<000/5000<1`003PL001<8000D2`005Ph001T@000K4@0071@0024D000P5`00
9aH002HH000T6@008QL002<I000R600091T002HJ000W600091L002@F000R60009QP002LM000X6@00
0P0S5P009`0T5@009AD002DF000W6`00:AX002XN000Z6P00;Al003<Q000g9P00>bD003DQ000e8000
>RP0040`001??P00FU@505I[3P1<NR@0>GY402i_I00/J780:Un202MRQ@0PLHL07Gb40223M@0MRW00
8i=X02JLH`0UX6408J9H01jREP0LXe808:A:02FUA`0RY4P07Z=>01^OEP0201fTE00W01nYBP0O[Cl0
8Zhf02F[=@0YZc@0;JD]03:W9`0bZb40;JlR02^_900V[RL0::dZ02V]<00T[S/08ji2026^BP0N[e40
8je802R`@`0Y/D80:jlj02f^>00a/S80<[0d02ba?P0Z/D40:K4g02Za<00kZbd0AZL`042T@P0mU580
@7]L03anG`0lRF00=I9O03nPAP11YSd0@i]80080BhU?02L0CWmG05IeEP1OJUP0EVaG059eEP1BPDl0
D8M9056;A01BUcL0DZ0_05^X8P1OZa`0GjPQ05^P;P1KTbl0Eh@k056:?01<TT00AIU5046LB`0oUe@0
AXYH05IlF01EO5T0FG]K0526G@13SED0?9M>03RRD@0fZe40=:i>03R^A00o[S`0?j`d046[=`16[3X0
Bj/f052Z;P1>ZBX00P1>Ybd0901@Z2/0D:P_05FU:`1MXbP0H:4O05nO6@1RXAP0HZ0G05fM9@1PVbP0
GiPj05Z=B01FO5@0FgY306:6:@1aQQH0O7T:081]0@1nJ@00NfH007MV001fIP00MUh007EK001dG000
MF00079P001eH@00Mf0007IO001eGP00LU`0071I001[E000Ie<006Q=0080JU4002X0JeH406]L4@1[
G140LFLI081^9P29M3@0RW/j08Qg@`24MTh0PgY807R3?P1aSS/0KI<l06NA>P1STS80HXPW05j3901J
QB<0FHLR05Z=8@1KSb80FXdV05B@901FUB80DiDV056E9P1?VB@0CIl]04VT@015XTP0A91J04efKP1>
N7@0CgQ`05EhI@1EU4d0Dj<f04^N;@1;W300AjDd04N_=019/2T204b]8P0W056[8P1CZb@0E:dV05F]
9P1FYbH0Dj<Z04nT:P1>YRL0D:<T052M7P1>Ua`0BiTR04fD<`1BQch0F7Q005I[AP1?IT@0BfA204MW
>013KS40AGTa04Ul;@12PRd0=h<^02^3=00WRS`09i9302NEB00WU4D0:9E002JE@00TTT009Hlh02F8
<P0WPRh0;WTZ031g900bMAl0;g0J0080;6hF01<0;6TB031S2@0_FP@0=d`103]0000h=000=bX003DT
000b8000;ah002/L000X6`009aH002DD000S4`007Q0001`?000L3P006Pl000`0oooo000:0?ooog80
000001d00`0000L2000:1@003@P000l:000@30005`d001T@000I4@006a<001lC000M4`0081@002HG
000U5`0091/002HG000P5`0081H002<E000S600091P002@I000T600091X002<G000V6000:1L002TG
000202TH000W02PG000W6@00:Q/002TL000]7P00;Qd002dL000a8000>2D003d[0010:`00?bX003d/
0012<P00BCd005E90@1KJ0h0BGdT03]n@`0cKEl0<e]d03=HO`0dEXP0;fJ202AkN@0RRg408I9V01^I
I00MWF<08:9S022RH00QX5D08ImD026OD00SXDL09J=202:S@00OYDD07J9800807JI502L07JXo02>[
=@0V[2l0:ZT^02jY;00bYbL0=:TP03:^7@0/[R00:ZhR02N^9`0Y[2P0:Jd_02J]?`0S[TH09:m>02:_
EP0U[Dd0::m;02b`A`0`[d00<Zll03:a>00b[cL0;;0k02jb>@0a/2l0=jd]03nX<014Y3P0>im@03f?
F`13M6<0A7YV0426IP0iU6D0@j5:04>X?`16X4D00P1?U4/09`1<RE<0Ch1E05=cEP1?M5L0CGYB04f2
BP1?RTH0DHm0056H=@1CW380G:DX062/8P1QZah0G:<S05VF9P1DSS<0DH`h04^9?P16S4@0@IA=03jB
EP14ReL0CWmL0522FP1IQEX0D8YH04B=E@0lTU40=9aB036WD@0a[U00=je603Z]?00j[CL0?J/c046]
<`18[2`0CZ`X04f]:00204j]:`0W05B/9@1HZR80H:DO06JM701XVAX0IidI06VP5`1XW1P0I9/Q06BJ
9`1OVSD0F9160565C@1EQ3L0I8`K07F72@20N@80P6h007][001jJP00NFT007]V001iH`00M5d007AK
001cF`00LUX007EM001eG`00N60007US001iHP00MUh1079M0P1^F@@0MU/507AJ0`1^EP80LF<;0080
Lg4H02L0NGT[08Ub>P2<LdP0QgY;08EkC022O4`0QHI107j;>P1hR480LX1:06Z2A`1RS400FhXa05Z>
:@1HTRT0E9HZ05NI;@1GUc00EY<g05:H=`1CWS40Dil^04fO:@1;Xb`0BZPf04N[AP14WUH0@8IR04iY
KP1DJfl0EGAb05>0HP1?VDT0Bi@g04RA<019Uc80@jHb04R`;`1;/Bd00P1:[bX09`1=[bL0Ck0U04n_
:01@[2L0D:PT04ZV;01<YRl0BjH]056U9`1FXR00D9hN052J:019VSH0BiE004f7A`1:PE40AGiD045f
E012L4d0@Vm804eaB`1CME00B7]D03]jDP0^MU40;7m?0326D00dRTl0<HY;02Z>A00XTTL0:9U602NG
A00WTCL0;8T`0322:@0bNbH0<7HW031d9`0202eb9@0C02ee700]L1<0<6L903QH0`0kB000>S`003X`
000f9`00<b8002lO000^7000:QX002HE000U5@008a<0028B000O4P007A0001`A000<0?ooo`002P3o
oomR00000003004000000000000000`0000000l00P0000@100080`002`L0014;000D3@005Ph001T=
000K400081<001hE000O4`0081<0028E000R6@000P0V6P003@0Q5P008A<0028D000R5`008aL0028J
000T60009A/002HJ000U5@009AH002PI000V70000P0Z6P009`0]6`00:1`002/L000[7@00;ad002hL
000a6`00=R8003/U0010:`00?bd0048b0015;`00C3L105A60P1LF`T0F7<S03al@P0cLUd0<Ei`03I@
O`0iEX80?5f303AaM00WQVH08IIR026MGP0MX5l07Z9L02>PF`0UWUH09Ye?02BKCP0QVTd08Ye702:Q
@`0QXch08:Dn01nU?@0201^X>P0W01nY<`0RZB`09jT[02^X;00`Z2`0<jXW03>[8P0d[A`0;[0N02Z^
800[[R@0:jd[02N^>@0R[E008JYE026ZG@0QZ6808jaM02J_F00W/U80<;5703:`@00c/3d0<Zhh02j^
>00a[c<0>Z`^03bZ=012Y3T0@I]803JCH00iPf/0A6U_04AcI`10PV@0>I5U04:QB`12Yd00AZE10080
BYa602L0BII@04ZBE01>RDl0BXY<04Z7C01<SDH0Chm304nA@01CUcL0EY/d05^T<01N[B/0H:/O05nW
701NX1/0F9L[05:A;`1;SSD0AHdo03jBA@0mT500A8eB04N0F@1>QEP0EXIG056;E@18Re@0?i1F03RJ
E00cY5D0=:UB03J]BP0i[Ch0>J`c03f[;@12[B`0Aj`W056]901D[R800P1F[2D09`1KZR80HJLM06JM
6`1/V1l0K9DR06fL701/WaX0KYhL06VN8@1UW2L0GYPf05ND@`1BSTT0F8la06RA5`1jRP@0QGl008Ac
0020K@00OFl007i[001nJP00O6L007UR001eG000LeP0071H001dE`00ME`007]L0@1nH@80OfD5085X
301kJ140QF/D09QW7P2CIQ40S6X707]c3P0208Ij7@0W08ee>02>L400Rg1:08=mC01kPDP0OXE308F=
?024RT00PXE:07=kE01/PT`0Hhi405fE<@1NVRL0FITQ05VF7P1KU280Ei8W05RA:`1GU2l0EI`]04nP
;01>XbX0BjH^04^[@01;[dP0B:EF042BG`14PfL0DGMW05AjIP1KQET0CI=504R0@015PS/0BI8f04JU
<@14/2X0Ak8/0080B[8]02L0B;8Z04Nb:@1<[bX0CZXV04bU8`17Z2/0B:Pf04ZV=`1<Z3<0CjL/04nP
:P1;W2l0B:0b04RL>`18UdH0AYI@04J@FP10P5`0A7MJ04maFP1LK5d0HfmO05YfH`1;O5d0?GmG03f1
E014PE40BgmB03moCP0_PDL09ha902JGB`0XV4X0:9I002VA=@0/Rc00:h@/02Uo;00YORh00P0[O2d0
4`0XORL0:GTK02Y_3P0eH@H0>dl103do000l<P00=RP003DS000_7`00;A/002TI000X6@009aP002DF
000U5@008Q8001hA000L4000303oool000X0ooooHP0000000`010000000000000009000000800@00
00/00P4000@200090P003`@0018:000F3P006Q0001XB000I4@007Q80024C0002024E00808QH000`0
8aX002LK000X6`00:1T002DF000T5`0091P002HI000T5`0091/002LJ000V6`0202PH000[02PL000[
7000;Ad002dM000_7@00;a/002lJ000[7000;A/002XK000b7@00=b<0040/0014;P00AS8004Df0019
>000F4H405iF3P1KJB80CG=103Y/GP0aIfd0;5]d031HOP0_IGl0;G>002R2K@0QTV<07YaO01jSG@0N
XUd08Z1F02^ID`0bUTl0;YI=02JHC00VV4d09Y]902JQA@0RY4008:@l026U=`0202:[<00W02F[;00/
ZRH0<JTW03FX9`0gZRH0>:XT03FZ800cZa`0;ZhM036^800a[2@0;J`b02N[A`0LZ6<07JIZ01jRKP0L
X7807ZQV026]G@0T/ED0<[1903J^@P0f[d00=j`k036W>00dZ3<0?ZHf042R@@16V4H0@91F03:6KP0f
LW@0?Eef049_J@0kOVD0=HiT03ZNC`0lZ440@ZY00080BZA402L0BZ5904ZRB@1<WDT0BIa904^HB01;
V4H0CYM504nG?P1DW3P0Di`c05VU<01NZC00HZXV06>Y701RYQP0G9hM04nF8`1;T2`0@i4f03jB?@0n
STH0@H]<04>1D@19QU80DhID04n6EP16QEL0?hUE03VAF00cWEH0<ZIE03F/CP0i[D<0?jdf04B^:P10
[2/0B:hT05F^7@1KZQd00P1KZ1l09`1SYQT0Ij8G06VM601XV1X0JYHM06fN6`1]Wa`0LIhN06RM8P1S
VbX0Fi8g05JD?@1CUD00FIL[06jD5@1mS`@0Ph<108Ik0P27L`40PW4008=]001nJ`00NfT007UR001g
GP00M5T0079G001dFP00N5/007eT101kJ`/0O74A07id7@1mNS@0T7Ln0:]ZAP2UJ2H0YFlB07ib6002
099d700W09ih:`2AOC/0Qg]00862@P21QCh0QhLi08b5@`2:PDl0Q7IG07=[G@1WMEH0H8Q:05bB>01K
Ubh0GIPU05ZG8`1NUR80G94S05^C9@1GURH0EY`Y056P:`1=Y2h0CZTb052]@01?/DL0C:eB04BOG011
UVD0B8MU0527G`1FV580CiI004Il@014PT00AiA004FX=P13/2T0Ak8Y0080B;<[02L0A;<[04Bd;`1;
/S00CjPY052T9P19Yb`0B:Hj04JP?P18W3l0B:<d04ZT<@1<Wbl0B:0^04JL=@19UD<0CiY>05NDF01;
QUh0DH5O069oF`1VOUD0HX9E05F9E`13SeH0>99G03^AE`15ReH0BX9C03f0D@0_P4`09XM>02J;D00V
RU409hU:02B:A@0TRD008hHe02F5<P0WQ2h00P0YPRT04`0XP2<0:gTJ02i^3`0eHPL0?5@203i2000k
=@00>BX003HV000c8000<1d002`K000Y6@009aT002LG000T5P008A4001h@000L4000303oool000X0
ooooKP0000008@010000104000H3000:10003`D0014:000G3@006a0001hD000K4`007a80020D000P
5P008QD002<G000S5P009AP002HK000[7000:1`002LJ000V60008aL002DE000T60009AL002@H000T
6P009QX002LH000X5`00:1/002dN000202dM000W02lM000^7`00;ad002lN000^8000;B0003HT000k
:P00@c0004Db0016=P00Cc/005=70@1NF@d0FVLV04Y[B00oJel0=VA_035RM@0XGG`0:6Ak02EgL`0Q
Rf/07iAS01ZJIP0KWVH07:=R02:PG@0WVe<0<Y1@03N>CP0bTdl0:iQ>02RGBP0XW4D09Z5102BS?P0U
Y3`0::Da0080:ZPV02L0<JTR03VV8P0lZ2<0?:/T03f/8P0j[280=ZXR03JY700eZa`0=:`R036^:P0[
ZSX09:U?01^TJ@0KXV/079m/01bMK@0PYV009JaF02NbD@0e/4H0?:i403Z^A00jYcd0=YY003fJ?@12
Vd40@9U>04J>D@0mQET0;GI/035WL@0dFG<0>VaY03UjIP0bR6P0<iaD03NZB00mZd000P17Z4@09`17
YdH0CJQ604^WA019YTH0Aj9804NRA`1>WDH0CIe005>M=`1FW3@0FZ<a05^T<@1OZ2X0IZ/Q06FW6`1P
XQP0FITK04fC9012Tbh0?i4j03n=A015S4`0AX5D04N3D`1>OE@0BW]H04InF`11Q5X0>hiJ03NFEP0f
X5<0>:Y>03b]@@12/C80AK0V04N]9@1;Zb00Fj`I06BV600206FS700W06VM6@1YVQP0J9LF06^E6@1]
UAX0JiXI06bN6`1/X1d0Ij4T06>L:`1MU3H0FiPf05VM=`1TWB@0MYT@07nB1P22S@D0QHT808N12@28
O@P0QgP9089`201oK0<0P6H307aX0`1nI@<0NV@607]W2P1oK@l0OGLD081j6@20NbH0Q7Lh08UhB@2C
MD`0WW1>09Ih?@2ANRl0M7``0080O8/Z02L0P9Pb07NF>@1cTCP0NXdk07n8=P21OcD0OgU907aeFP1c
JEl0IEUR05aRFP1KJe80G7i605j6?01KScD0FIT_05fK;`1KVB`0FYXX05RM9@1HWRH0Dil[04fR;`1;
YcD0D:i0052_?P1<[D/0AZ=E04BHG`1:SV40C9IM04jSC`1<VD40BH9004R5@017U4@0AZ/h04:b:P11
/bP00P13/bh09`15]2l0B[Hf04bd<`1C[2T0D:X/04bW=@18Xd00@iM404:<A@17Vc`0BZ@i04^R<`17
Vc00B9Hf04jC@@1HUTX0GiEE05BAEP1?TE@0DYQ@05:EC@1?STX0Ai5?03nEE@0kU680>I5Z046:J@13
OfL0>giQ03EnH00[Nf40:GES02IcH00TL6009WII02=kCP0RP4@08hA002N7=P0202V3;P0<02^09`0/
NQh0;VlC035T2`0eEP@0>DP003/i000h<000=RP003DQ000`7`00:a`00P0X5P001@0W50009A@001lC
000N4@007@l000`0oooo000:0?ooofd0000002800@0000@10008100030D000d6000A20005@/001X@
000N5P0081D0028B000P4`007QD0024G000U600091P002DG000S6P009a/002XL000[6P00:1L002LH
000V5P009AH002@F000V60009aP002HH000W6000:A/002XG000[7000<1/00P0_70009`0]7P00;ad0
038P000g8P00=RD003TX000k;000?bl004Dg0019>P00DSh005Y=0P1LG0H0G6`Q04i^AP0nJ6L0=FQd
035SN00_I7@09VUa025aJ`0MQFD069IO01ZMG00IWV<07IiS01nNG@0VVUD0:i=?03B:DP0eREH0<I5D
02RGD00YV4T0:Yi002RS?P0SYST09:Lg02VV:P0202fW8@0W03NV7`11YB00?ZTT03bZ9`0gZR@0<jPT
03:X900dZB00=:TR02n[<00X[4009JU:022RFP0KVf`06iaW01fOH`0KX6009JM@02b[B00_[4T0?Ja5
04:/B@10ZdP0@jE103jGA012UD@0AY9804:<E@13QED0>W]H02U_J00`JVh0<f=a03I`J`0`Mf`0;gm]
03>EGP0bYe80?:]70080AZY302L0AjU004b[@01<Zch0AJM104VWA@1;YDD0C:1104^Q>P1BWSL0Di`e
05JQ<`1GYS<0G:Lc06:Z;P1OZBT0GJ@N05ZP6@1BVQ`0BITR04BF<@11UD@0@YE=04J:EP14QeD0AgaG
04IiF@16O5d0AHEL03n?F`0gUeP0>J1B03VXB00n[Cd0@jh`04V]9@1<ZR40DjXM066Y6`1YYad00P1[
XQh09`1/Wa/0JI/K06ZG601XV1P0JiPI06JJ6P1UWal0IZ4S06:S:@1NXRh0Gilc066N;P1QXRT0L:4M
07fM3P1nW0/0PIL;082I3`23U100Pi0D08F76@22PQP0PWPB08Ie4@24MA<0QG@D08ac6P2<N1l0SX0U
0923<@2>OSH0T7<n09YaA@2SKd`0U7A=08YgC01oQdL0MY5007:@>`02076E<`0W06RH=@1TUST0HiXm
06FEAP1VRdT0JWU:06aYEP1UK5d0GVMM05QUG@1GKUL0FGU>05j4A01LQcd0GY8b05bI;P1LVBH0GIXX
05fK:@1IWB@0FI/P05NH7`1@VbT0Cj4c04fV?01>Zd00BjY804FTC`1:V5L0C9=O04bMF`1;XDl0AY]1
04R;@@19R4<0BI=304B/=`14]2/0@[<V0080@KDZ02L0A[D`04^d=01?]2d0Dj/V04j[;P1:Y3X0A9a5
046CB`0oSDl0@i]604JTA@15XT00B9hg04ZI=`18WC/0AIi804bMF@1<V5H0BIAG04VKD`16VE80?heC
03n:F@17RfL0BhUc04F5M`10PgH0?Wed039nKP0`Of`0:W]X02UbHP0ZKF00;6]M02a]G00XM5D09ga<
02N3@P0XQC`00P0WPRl04`0YP2H0;7`Q02mb5P0^IPd0<EP403M9000j>P00>Bl003HX000b8000;ad0
02XI000X5@00:1L002LE000T50008A<0020A000M3`00303oool000X0ooooA`0000000`0100000000
0000000Q000000800@000240100000T2000;100040D00149000F2@006Ph001dC000Q5@008aL002HE
000S5P008AL002DG000X6P00:AX002TH000T6@009a`002TJ000[6`009QX002LG000T600091H002@D
000S4P0091H002XF000Y6@00:AP002XI000]6`000`0^7@009`0/7`00;al003TP000h9`00>RX003/[
0010;P00@C4004Lh001?@@00FU4305mU2`1FM1l0CGM004=_H`0jJW@0;Vaf02aZM00ZLVl08gU/01eo
H00HSUD06I]A01^QD`0LXET07iiK02JJE@0aU4/0<Hi:02n9E00^RU/0:Y5I02NHD@0XVDL09idm02FQ
>P0TYC@09:T_02RW9@0202bV7`0W03FV7@0hZB00=ZTX03>X;P0cYb`0<JHZ03:T;00`YRX0;JDb02RX
@00TZE008ZMH01nOGP0NUfD08IaM026RDP0UYd`0;ZU403FX@`0fY4X0@j=<04>TDP11Y580@Ye;03nC
C@14ST`0C8MA04]mG`15NE/0=g5N02a[JP0_KVd0;f]a035`K@0aL6`0;g5a03:;I00fVU`0>JI?0080
?ZM502L0@ZY004bY>`1>ZCT0BjLi04nW>@1AYCL0DJ8i04nR=01AWc<0DYXd05>O<@1BYc80EJTg05JZ
?01CYcL0E:@a052R9P1FX1X0EI`H04jJ9P18WCP0@Ii703jHE`0oU5/0@X=K045lF`17P5`0B8IK042@
G@0kUU/0>YmC03VXA`0k[C/0@Zd_04^[:01>ZR@0FJ/Q06:Y8`1WYb400P1XXah09`1WXQ`0Ij4N06bN
6@1[WAP0IY`I05nO7`1NXRH0G:0Z05fP=01HY3L0FjHh05nV;`1SZBP0LJXJ07nX4021YPd0P:@?08:T
5P1nXad0OZ0R07nK:@1nUBd0O8dZ07J4:P1fPR`0NGhb07mj>@29O3d0TWU009MlA`2LNdL0VG9209Ii
@02DOD80R7m2085o@P20Rd00PiDh08>H>P0207NH>00W06RG>01VUS`0JiI607F9C`1`O5L0Kg1J07IS
G@1bIV40L6aN06UbG@1XNUP0I85?0626A@1MS3l0Ghl`05ZC:P1OU2@0HIHU05fF:P1OUbD0GYDP05bD
7P1CUR@0Cida052Q>P1>YT@0C:U=04BRC`15VED0AiYI04VRDP1<YdT0Bj1004RF@018U400BI`n04R_
=@18]2`0A[@X0080A;HY02L0AkLa04Zd>`1:/c80Bjl_04V_?017Y440@YM=03jEEP0kUU/0>iaD03^K
C@0oWT@0@ie204>I@@0oV400?YA903j?E@11REL0AhIJ04^7FP19QU/0@7QR03adL@14Mgl0B7F204=a
P00mLgl0=GMl02ajM00YPFd0:HMS02N6E`0ZPe00;X5=02inC`0ZOe809X=>02N4@P0UPcP00P0WOR/0
4`0UN1h0:W@I02e_4@0_I@T0<EH403I6000g>000>S0003PV000c8000;1h002TJ000W5`009aT002HH
000U5P0081<001l@000M3`00303oool000X0oooo<@0000000`0100000@400040000C000000030041
0001000000000200000000h00@40008100080@002@@000h4000@20004`T001H<000J4@007A00024E
000U5`009aX002LI00809AL001D0:A/002TQ000Z7@00:ad002PJ000Y6P00:a`002`M000Y7000:Q/0
02PI000U5P009A4002@C000U50009aL002XK000Z6@00:Q/002/L000^6P000P0_7@009`0`6`00<Qh0
03LT000g:@00?B/0044^0013=000BCP004e1001ECP40G6D:05Mi8@13PDH0>geV03UgN@0hLWT0:gEe
02MiK@0RPVH07HUS01^>E00GUD/079]:01nPBP0SX5409Ya?02fEBP0hSdD0=8e:02f=E@0YSF00:9=K
02NGDP0YVdP0:Ihn02^O>00ZXc009jP/02bX9@0203BX8P0W03:X8P0dYbL0<JP^03:Z=@0eYbl0=ZL]
03FT<P0`YcL0;ZM502VWE@0TYf@09JAU02JKH`0VTF00;9ME02jQC@0`YTL0=jI303VRA@0kWdh0AIm<
04NNDP11VeP0@i9B046:EP19QU<0DH5G04acI012LV<0=fmU02][JP0_L6`0<Fi/03A_J@0aJVd0<FQf
03QmJ00jQfH0>YIH0080?j5?02L0@JU604VV>P1>Yc<0D:Ld05>Z<@1GZBl0EZT`05:Y;P1CYRd0D:<a
052T;01=YRl0D:Te052[>P1>Z3/0CJPm04jU<`1EXad0FilC05JK601>X2H0AZ@k03ZVC`0iX5H0?8iI
04:3F@1=Q5X0ChIM04F;H00mU5/0>ieE03^ZB00o[Sl0@Zdf04j/<@1G[2P0GZ/V06F/9P1TZ2D00P1S
Yb009`1VYQd0JJPO06NW6`1SYaH0HZ<H05nU8@1GYRP0FZD^05RR=`1HYC`0FZHl062Y<P1U/2T0LjlL
07^_401m[0d0P:/B07bZ701j[R@0NZl]07V^=01eYc`0L9/o06j=@`1[QDH0LH9707^2BP23PTL0RX=8
08Z6BP26RT80Oh5307b0A01kPCl0OH0j07b0>`21SCL0Qi/`08JM<P0207NF=@0W06^?<P1YS3T0LHU5
07YhE01hIE`0OemM08UJH`2?F600UEeP099SG`2>Ie`0PFQF075]C01RM4@0HH<m05^><`1OU2T0GiPV
05fE9P1NU280Gi@O05nB701LUB00F9/]05>P=P1CXT00Dj9904^LC`16VeH0A9aA04fQCP1@Yd`0C:=3
04bL@01=VcL0C:He04ja<`19]300Ak@/0080B;L_02L0B[Lg04Re@P1:/Sh0B[4m04F_@014YT<0?ie;
03bJE`0iV600>Y=N03N<F`0jUEP0?9UK03bDE`0mRU80?H5B03ajE@0mNEH0?GMM03mlI`11Lfl0@Eeh
049DO`17FH40C5]l04EKMP0mGWH0<fQg02m]L00ZNF/09XMP02V>DP0[S4X0;H]602b;BP0XSE409Xe?
02F;@`0TQ3h00P0VNS404`0VM240:G8I02i[400`G`P0=54203E0000g=P00>Bd003PX000c9000;ad0
02`K000Z6P00:AL002HG000U5@0081<0020A000M4@00303oool000X0oooo;`0000001@0100000000
004000010@000@0001<0000000<00@000000000000007P0000009`0100000P4000D1000:0P0030<0
00l6000@200050X001T;000O3`0081<002@F000U5P00:QX002TJ000Z6`00:QT002TK000Z7P00:R00
02`N000Z8000:Q`002hN000]8000<20002dM000Z7@009aX002PE000U4@009A0002@E000V5000;AP0
02`G000Z6P00:A/002hJ0002030P000W03DN000g8@00>BH003XX000n;@00AC4004`l001E@@00Fe83
05YS2@1HMad0Bh0m03YkHP0fNG@0=7ek03MkK@0/PF@08hMS01b>HP0IV5/079a:01fI@`0SVT809Y]5
02RKB`0]UT`0<95>03J:C@0bRe80:haJ02F?H00XU5X0:IaB02^MAP0]Wc`0;ihi02jS<`0`YS00=JLa
0080=:D_02L0<:L^036W<`0`ZCH0<jXh03^W<P0oYc40>ZHi03:ZA00^Z500;:AN02^PK`0]WFP0;IQO
02j@FP0cUU80>9U<03ZDC`0oUDh0?iQA03jJE018W500AIYE03fDG`12R5T0A7YH04eoDP1=PU<0B7MW
041iH`0eMf@0;g=V031eHP0fLel0=g=P03U]J00hIW@0>GUZ03b2I@0lSUd00P0oUE@09`10Vd`0AYi0
04fR>@1=YSP0E:/c05N_<01G[Rh0DZhZ05:/:01<YRT0CJDY04^U;01;YC@0BjXi04n[?01=[400C:Pl
05:U:@1KY1H0FiXE05NK6@1>Y2X0@JY503jVD@0mUEH0@HYE04V7F`1=Q5l0AHMQ03j>GP0nVeL0?Z]>
042a@`12/Cd0C:de05R[:P1R[2D0IZTQ06JX7P0206NV6P0W06ZV701Y[1l0J:dL06B/6P1O[Ah0FJ`T
05Z]:@1JZbl0Ej/i05^Z?01KZSP0I:l/06f`7`1c[aX0MjhA07bZ301l[0l0N:lH07:a8@1_/BL0M;8b
07>`>01fZC`0LZ4o072F?`1aU480N9E007nD@01oUd00OiE107ZE@@1eSd80LHa007BB?@1eTSX0MY@f
07jM=01oXcD0NJ<j0080M9Lm02L0KX`i0727@`1fPE40NFeM085IG@29Ef<0TEAQ09MEH@2JEeh0TeiI
08QSD`1nKDd0KWQ5065l@@1ORT00Gi0e062B:P1QUR<0GY@N05bD6@1PTaL0GY8G05nD6@1KVbD0G:0b
05NU@@1DXTd0CYm@04VNEP1;W5<0E:5?052TB`1:Wd40C9Tg052H<`1?Z300C;0c04nb<@1<]2d00P1<
]Rd09`1>]c80BK@i04Vb>P18/D00AZhn04BU@@10XD/0?9UE03R=G`0gPfH0=7YZ03imJ`19P780D7a[
04ibIP19Jf<0A6MO03a[GP0mJV/0?FId03eHN@0iBGl0>D]m03YJN`0jJg80=gMT03=mI00`PV80<H1S
02b1G`0VQ5L09hA=02Z3A`0^Q400;8Q302Z;A00XS4009XTi02J3>@0202Ui=00C02eg9P0ZMQ/0;F`@
031N200dCP<0=cl003Ld000h;`00>B`003HT000a7`00;1d002PJ000W6@009QP002DE000T50008A@0
020@000<0?ooo`002P3oool_000000800@0000<00000004000010000<@0000008@0100000P000080
000400001`4000P3000=20004@T001<9000D2`00610001d>000R50008a@002@F000V60009QL002XH
000Z6P00:A`002lK000/7@00;Al002hP000_7`00;B0002lQ000^7`00<Al002`P000[7000:Q/002PH
000202LE000702XD000Z6P00;1d002hJ000^6@00:aP0030L000203@N000W03@S000e8P00>2D0040W
0012;@00CCd005I7001NE`H0HFTC05Yc9P1>NSd0AGMD03ecIP0eN700;h5`02j4IP0XT6408IEL01RK
FP0LWUD08Ie802JI@@0^Ud80;iM502jFC00]TU40;8aE02j6E`0/R5X09heK02>?G00XUED0;Ie;02jP
@P0YXc`0;j<k02jT?P0]Ych0;ZI00080<ZE302L0<ZM303:X@P0cZD00=:Y003jX>@0nYC/0>JI203:Z
B00]ZE@0;iiO03FAK00hSFL0>HYN03J5FP0hReL0>XeE03V1G00oPeT0@8aJ042@FP17TE@0AY5I04:?
H018RUD0CWmA0563C@1=QeD0@7aV03b5H`0gPFD0;gaS03F0F`0gOEP0>WeI03aeH@0nL6P0?7]S03im
I010Qeh00P0oRUP09`0oSeD0@YE904NHA01;Wch0CjPh052_<P1C/Bh0D[4[052[:@1;ZBX0CZXY04VX
;018Yc@0BZ/g04^/?@1:[400AjQ004bX<`1DZ2@0GIlH05bK4`1CXR@0AZY004>WCP11Ve<0@I5E04J8
F@1:QEd0A8EQ03n<GP10X5L0@ji<04Fa@@1;/cX0E[4d062_9`1UZb80J:TP06RU7P0206fU7@09072[
6`1c[QT0K:lL05j`7@1J[b@0F;0[05>_<@1H/380F:hg0080FJdh01`0Hk4X06fa7@1b[aP0N:hC07ZZ
3P1jZa00MjlF076b7P1[/BH0K;</076a=01d/3H0L:lf07>Z=@1cZC<0MJDg07FL>P1eUd00MYA007J@
@`1gRdL0MHY307ZB?P22Tcl0Qi4j08fC>@2?TcT0Qhln0P23QdD09`1oOTT0R7QD099aGP2CI5l0VUIO
09]GH02KEed0U5UO08eFG023GeD0Lfe<06MkB@1OQdD0Fhi305ZB@01MTS@0GY8X05nD7`1LU1T0Gi8G
05fD5`1LTaP0GiPL05jI901NWc@0EZA1056PD@1>WU<0BiYH04fNDP1AYe80Cja804jV=@1?Vb/0DI`Z
04jX;@1>/380CJh`04n_:P0204f`:@0W04^c;01:]2l0A[0a04F^<`16Z3T0AJ1004>LA@0lUdh0>XUF
03EgH`0gJ6l0B5ik06IFP01bDX80M4n106M>O`1CCg`0AEEj04QBP@1<Bh00Acn003`hP@0`@Gh0;UUh
02idK00_RUl0;9QI02ZLEP0[V5409i9;02N=A00[S400;XY002n:?00^RcP0:X/h02R8<`0XQS40:88c
0080:ghc01<0:gdX02Md6@0]J0l0<UT603Q;0P0h>000=C8003T/000e9`00=2<0030M000[6`00:AP0
02PG000T6@009AL002DD000T50007a8000`0oooo000:0?ooobh0000000@00@00008000010@000@00
<P00000200800080108002L0208000P6000>1`004P/001L:000H300070`001hA000S4P009Q@002@B
000U5P009QL002LH000]5`00;1/002dP000_7@00;Q`002lM000_8@00;b<0030P000d9000<280038Q
000^8@00;Qd002/M000[7000;1L002PG000W6@00:a`002`K000]6`00;Q/002dK000b7@000P0c8000
8P0e8`00>B8003/V000n:`00B3D005E80P1NG@P0G7<G05Ej=015MU40@G5L03mcG@15LeX0=g]V02b4
I`0USV4099IF02>LCP0MWDd089]=02JJB00^UdH0=9M803>EB`0bTe40<I1G02j<G@0/RF00;8YN02Z?
F`0ZTeL0;iM>03>LB@0_XD4202ZV@@0302RVB00XYTd0:jEB0080;jIC02L0<:I=032XB@0bZdD0=ZY2
03NX@00dZ4@0<:M:02fYD00YY5T0<Y=S049jJP18LVP0@G5T03U_H`0jO5/0>hAJ03QmIP0nOf00?WiO
03anI012Peh0B8AU04R4H`1:RE@0B8=C04V<C016S540>X=Q03V8G@0eQF80<X1P03J6EP0gQeH0>hME
03anFP0kMV80?GiK03j2GP11R5P00P13RUP09`0nS5T0@8eC04F=D`18UTX0B:0n04RW>01?[3D0D;4b
04n];`1:[Bd0BJ//04>Z;P0oZC@0@jdh04R/>`17[3d0AZQ104NY?@1<ZS<0FJHO05nN4@1HX1X0CJXb
04ZU@P15VTl0A9AD04B@F@17RF00A8aR03nCGP10YUL0AK1=04Rd@01B]SH0H;<[06F^801Z[240JJPR
06bS8`0206bR8P0W076/6P1b/1D0JK4J05j`8@1F[b/0D:hc04ja=01E/c@0F;0c05^`<@1L/S00IK<V
06V`8P1^[al0LjhL07N]6P1d[AT0Lk0L076a801`/RH0K;4^06b_=@1`[CH0LJPj07FQ>`1dVcH0M9Lf
076C?01aTD00Li1207B?A@1dRDD0LXE207F<?01mTSP0P98b07f@;P1oSCL0PXXm0080OWm902L0Pg1E
09MVF@2]FU/0/5YP0;AEH02VF5l0Te]N08IOG@1kHEh0M6AG06]/D@1SMDX0Gh5805f=@@1MTCX0GY4/
062?8`1PT1/0Gi0G05j?601NTAT0HYDN06FG801RVR40HJ4^05JO?01DV4H0DIM=052ED`1BWeD0Dk1D
05:cB01D[380DZDX05:T:@1>Z2h0CZhf04b]=`1<ZBl00P16Zbh09`16[Bd0B:d^04RZ;018ZRT0C:H[
04fN;P17WCL0AY]103f@AP0fOe40=VIV045DM`1LA8<0LCn707XnR`1^@8X0Fd>60597QP1KBHP0GTN2
0594P014@W/0=Dab02aNJ00]MEh0<8]F032KD00/XT/0;:1702VH?`0ZU3/0:YDn02fC@@0]Td00;I8k
02ZA>@0WRc@09hXc02F:=P0202R9>@0=02F5<`0TN280:fTC03AF200i@P80>SD003T`000g;000=bT0
03@S000a8000;Ad002/J000202HG000402@F000R50008a<0020A00`0oooo000:0?ooobh0000000<0
0@00008000010@00<`00000020030000108000L200070P0030@00147000G2P006a400P0M4@008@0P
4`008aH002HH000W5`009QP002LF000X5`00:1P002`I000/7@00;R40030N000a8@00<Ql003<S000d
9000<2<003<U000d8000<b<003<Q000c8`00<R<0030M000[6`00:AT002`K000[7@00;Ah002hN000_
7P00<1h003DS000203DT000W03LU000l9P00?RX004@b001@AP40G5l6065e5`1@PSD0?h5K03QfK`0j
Mfh0>GeX03Z2G@0bR600:HiK022GEP0VW4`0;9e602VJB@0XU500;9=?02nBC00eSe80=91D03>AFP0d
TEX0<HiL02n?FP0^TED0;YA=032EB00cV4H0=Ye403BRA00YYDD09Z=:02:TD@0RYE@09Z=H0080:ZII
02L0;ZQB03BYC00iZDL0=jU403FZAP0]ZTX0:JA?02FKG@0UTV@0;XMV03]fJP13KFL0@FaO03iYGP0n
LEh0@7aS03ihLP12NfL0?7UV039aJ`0oM6@0BG5U04ecH@1:Q5<0@XEB04:?C`10T5<0=XQM03R>E`0g
S5P0=XIH03R<E@0fSe<0>8aC03aoG010Lf80@7aI0420FP13REL00P15SUD09`11SET0AHUH04F3F013
Qe00@Y1604>I@@1;Xcd0CJTi04bZ=`19[C80B:`a04J[<@0oZST0@:/n04BZ?P14ZSd0@JU2042[@014
Zcl0DJTZ05nS5@1KXQL0CjTT04jU<`15WDT0@IMA046BD`15ReX0A9=K04JIGP11YeH0B:i>04ba@01J
]380I[4T06F_8@1W[2@0IjPR06^Y8@0206j/700W06n/5`1^[aD0Hk4J05bb8@1E/Bh0D:li04nb>@1B
/c/0Ek<b05^a9`1M]2@0I;8W06Ra9P1Z[R/0LZdW07B_:01b/2P0Jk4T072`8`1//BL0K[0[076`<`1a
[3T0Li]007FC@01dSC/0Lh/i06b<>@1XS3`0IXhn06R@?@1XSS`0IXdl06N>>`1YT3L0J8`g06Z7>@1]
P3l0M7e60080PFm?02L0SF=G0:=KEP2eEEH0]U5P0;9AI02GFF@0OUiN07AWG@1`KE`0K6]A06MWB@1R
Ld@0H7e405n6?01ORc80GXTV05n:7@1PSAP0GhdG05f<5P1NSaH0IIDN06>I9@1PW2P0Gilb05bK>`1J
TT<0F99905>IDP1GWED0E:aC05BbAP1E[ST0DZ/^056Y;@1?ZCD0CJdn04j`?`18[3P00P16ZS<09`15
[2h0AZ/^04^X8`1=Z1l0DZ<O05:O7`1=WRT0B:0c04BH@00kQdX0=FeK03AKKP0iCGX0ATB104i1QP1;
@hL0@4F403]8P@10EGl0AEmi049PLP0iI6P0=feM03=jD@0_QTL0=91603BEB00bUd/0;YE702f?A00X
SDD09i1;02N>B`0VTdH09iA002VA=`0XSC009H`^02J=<@0202F==`0C02J:@00WO2T0;fDE03M>1`0i
?P40>38003X^000h;@00=R`003HW000_8`00;Qd002XK000X6@009aP002HG000Q50008A8001hB000<
0?ooo`002P3oool]000000040040000200000P4000410340000000@00@00008000050P0020<00P0=
1@009`0=1`004PT001X=000O40008a@002DD000T5`009AT002XH000/6000:A/002TI000X6000:1X0
02PM000^7000<1h003DP000h8000=R@003DV000e9`00<BH003<S000c9@00<RH003<U000c9P00<b40
030Q000Z7000;AX002hK000_7P00<Qd002hS000e7P00=24003LT000203/X000W03h/0011<000AcX1
05990`1KGP/0I70N05ih>@1<N5L0>GI`03EbMP0cO6d0;HUX02^AHP0WTe`099MC02BLC00[WTH0=Ya4
03NEA`0cSU00=8eE03>=F@0cSEh0<hmP036AI`0cTEh0<I9I032DE00_UDh0;iM903>JA@0gWTL0=Im9
03:RC00YYD`08Z1>01nQC00QY4X09JM:0080;:M902L0<ZU403NY@@0iZD00=jY203B[A@0ZZDX0:IUF
02Z1I`0XNFd0;WU[03MbKP0nKfP0@FmP03i[H@12LF40A7IW04][L`18LfT0@7QZ03EbKP11N600AG=L
04EdF`14P540@8AF03n?E00kTE@0=XaK03fBCP0lSd`0>he=03bAC`0iSED0?HQD049gG`12JV80AGMH
04ElEP16RED00P14TE<09`13T5L0AHAH049gG`11O5/0@HM@04:>C@17UdH0BIe404VU@@16ZC`0Aj/g
04:Z=010ZCd0?ZQ0042W@@0oYd<0?ZQ703Z[A@0mZT00C:Xc05NW801JZ1H0EjPG05>W9@1=XSX0A9m5
04:LC011VU@0AiUH04NJG@16XET0B:M>05>^@`1M/S<0Hk8V06J]8@1VZBD0J:PT06Z[7@0206^]6P0W
06bZ601Z[QL0H:lL05Rb9@1>/S<0Bk9004Z`@@1=/3h0DJh`05R`9P1M/RD0H[8X06Ra;@1[[c80Kjl_
06ja:P1^/RL0K[DS06fc9@1[/BD0L;8W076c:`1`/C<0LJ`g076R=`1bUcH0KXlh06N<>@1XRcX0II4j
06VG=P1XUSL0II@e06R@>P1XQSl0JgY;06icD@1`H5H0PeQK0080WE1Q02L0]DmN0;m>CP31BdP0_4aH
0;A:I`2?E680MeQP07QUGP1kJUP0JfM?06IWA01TL440HWa005n2=@1OQ2h0GX8Y05n6901OSA`0G98H
05fD5`1PUAT0GiTT05fL:P1KVc80GiXi05fE@@1MSTX0Fi9@05JKE01EVE@0EJQ=05Fc@01F/cH0Dk4d
056^<`1?[3d0C[1304fa@`1;[d000P15/3<09`15[Rd0AjX/04JZ9@19Z1l0DZDO052P8@1;X2/0Aj<f
04FK@@0lRTX0=7AE031THP0YE6d0:TYf02m5N@0]B7h0:T]k02A@N@0WI7<0;Vm/03=aI00eMe/0=h9?
03R:AP0eSD80=iA103B>A`0cR4`0;H5?02YkDP0VMeP097eL02B0E`0VST/09iI002JB<`0VSBT09X`U
02F>:@0202J?<@0C02V8<`0/Mb<0<Ud>03M7100h>@40>Bl003`/000k;000>B`003DV000^8P00;Ah0
02XJ000X6`009aT002HF000S4`0081<001l@000<0?ooo`002P3oool]000000<00@00;P0000030040
000500<000020@00108000P4000<1@000P0>1P009`0A2@0050X001T<000M4@008A40028B000S6000
9aX002/K000_7@00:Q`002XK000/6`009ad002/K000c7@00=Al003HP000j9000>2D003PW000g9@00
<R8003@P000f8@00<R@003@T000b8P00<1l002lO000_6P00<1/0030L000g8000=bH003LT000e9@00
>RL003l[0002040a000W04@f001;@@40De8805aY5P1ILb/0EfY805ASH@1<IFd0?Fie03acL00cPfh0
:I5Y026JGP0NV5008YQ802:MB00/Vd`0=iQ?03^@D00jS5@0>HeH03N<G`0eSFH0<hi[036ALP0dTF@0
<i=H036ED00/VD/0;9a8036OB00cXT/0<:=B02VTE`0SYE@07j=A01nTBP0PZD<09ZY10080;JTn02L0
<:Pk03>Z>`0eZS`0<Za1032/A00YYTP0:I5C02YcI@0_J740<fe_03I]LP0nKF/0?g9U03]`J@0oLFT0
B6m[04iNL`1=K6`0AG5Y03i`J010NUT0?GaG03inE010RDl0?hYG03jAD`0lUU00>i5D03nFAP0oTd<0
@IA804:FC011REL0@81K045aH@14If@0BG9J04MkF016QUT00P13TUP09`14T5d0A85O04I_I@12Lf@0
@GeL0427F@13TT/0A9Q904>MB@13XT40A:Ln04:Z?P0mZD00?J9203jNA00mXDL0>J9903JXB00jZD00
AJPf056Y;01HZQl0FJTE05JX7@1EYR`0BjLk04JYA017Yd`0BZ1B04ZIG@1:VE/0C9UG056TB@1I[ST0
GjlY066^8`1UZ1d0JJ/M06b[600206V/600W06V[6`1V[Qd0G;4O052c;`1;]3`0A:m404F]A@19[Cl0
DJha05>`901Q]2<0I[4[06R`=`1Y[c`0I[0k06Na=01Z]2X0J[<U06bb8P1b/B80Kk4R072c9P1]/c00
KJld06^T=P1ZUS/0JhE106N6?`1YQT00JHho06VF>`1[U3L0JI0h06j<?01[PT40K7E907M_CP23GeD0
RDmQ0080UTYT02L0WTYN09U>F@2BEU@0Sf9G08mYG026IE<0OFE<08I/B@27LTP0M74n06Ab=P1TN380
Hh@[06F3:01RQBL0HHTV062;9@1PTR40GITM05jL601PVAT0H9TF05jL6`1MWbh0Gj8l05fPAP1OUe00
H9AA05fFD01LU5D0Fj5<05N^@01G/cD0Dk<e05:]=P1?[C`0C[1404^_A01:/S`00P14/bl09`14/B/0
AZ`_04V/:P1=ZRH0DjPY04jR;01:WcL0B:<k04RP@011TdH0=HA=02iiF00/L6T0:FIb02MNM@0UFgL0
85ed01mRK`0OK6X09G5T02adH`0_Ne`0=XID03N>B@0bSdH0<i9602n9C00]PU80:GaH02IiG00VMf80
9WiV02R4G`0XTDl0:9U002FC=@0USbd098/T02F;8@02026;9P0C02R0900^K1D0<U8703E10@0g=@00
>Bh003XZ000j;000?2X003DU000a8@00;Ql002hN000Z70009QT002HF000R5000814001l@000<0?oo
o`002P3oool]000000800@005@0000000`01000000000000000G000000080040000200000P0000@1
00060@002`8000d4000C1P0201@7000T01D;000H3`006Pl001dA000N3P007Q4002<D000X5P00;1`0
030L000^7@00:ah002dK000/7`00<Ah003<Q000h8@00>B8003/V000i:000=RH003@R000g8@00=B00
03@P000a8P00=28003<P000`6P00<Q/0034M000a8@00=B<003TU000m:`00>b/00P0m:`00:P10<000
B3T004Pi001?AP80EUT905U`6@1ENcT0Cg1B04EEKP0nDWX0@5m`03YaJ`0kOF<0<8YR02^FFP0UW4l0
9iM602ZDAP0WUe00:iIH036DF00fT5P0>HmK03f?GP0iSVD0>8i[036>K@0`T6h0=91R03JCF@0fUTl0
<9Y=02jOC00^XTd0;JAC02NWEP0TYe`09:MG02>VD@0TZ4D09jXn02f[=`80;JTf02L0;:Hk02jX@00_
[4H0;j]702f[B00XYdX0:I1E02eeH`0aJ6d0?6Y[045XK@14JfP0@G5X03YbK00lMFX0A6mW04QJM@1;
JVX0C7AS04YdH`18PED0?HYA03b<D011Tdd0>i1E03nICP0lWD`0?YY>042JAP10UD<0@II5042BC@14
Oe/0@gUP049aIP13JVH0BGIJ04AjF@12R5X00P12TEP09`10TEh0@h5S04E]J`14K6T0AGAU04EnH015
T500@IQ?046JB013W480A:1104>V@@0mY4D0?9a103jFA00jW4/0>Ii>03NQA`0lXd00@jDc04nZ;01E
[R40G:XD05fV601HY2P0CjTb04b^?018[TH0BJY>04ZNFP1<UUX0Ai9F04bQBP1E[SD0H:dV066Z7@1X
ZaH0J:/D06Z[4`0206V/600W06F^7@1P/280E[8/04Ra>`12/DD0@:m>04B^B015[S`0C:lV05Za7P1V
/B00J;4a06N]@01YZd00IZi106N`=P1V]2T0J;4V06^`9@1//BH0J:hY06Va:`1Z/S@0JZle06RU>01U
UC`0IXM306F8?`1[SCd0K94m06fC@01ZS400HhM206IoAP1YLTP0L6IA085QE02BEET0UdeP0080UD]S
02L0SdYU07mCH01gGe`0N6aK07EdE01cLdT0L7Do07F2>@1dRSD0KXT/06F68@1VRAT0I8LE06>;501T
SQ@0IIDC06>F5@1RUaH0GIXF066K5@1QVaH0Gi/E05fP6P1JYS40FjI305VMC01KVTh0HY9=066BCP1P
TDl0FYQ:05JW?`1D/CL0DK8h05:`?P1A[d00CK1504^/@P1</CX00P17/S009`1;[b`0BZL^04fX:01A
Z2@0DJHW04ZP;@16WCH0A:4e04FP?P12WT00>YA70369D`0/Q6H0:ga^02QeL00UJW@086Eb025YL00T
JW009fY^02Y/K00]MFX0<h5S02n9F`0/S5D0;8eF02Z<F@0VRUX098UJ02F9G00TRUX09XmK02RCD@0X
U480:9<i02FA<`0VSc809Hd/02B<8`0202:88@0C02al6`0dI@`0=dh403To0@0l=P00>Rl003d/000j
;000=bP003PW000d9000<Al002dM000Y7@009QT002HH000R5@008A8001`?000<0?ooo`002P3ooomK
000000800@000P0300001`040@00204000`2000?0P004PD00188000E2@000P0G2@009`0I3P007Q40
024B000O4`007A0001lC000U5@00:aT002dO000b7@00;b0002hN000^8@00<1h003@Q000f8P00>RP0
03`S000n:000?2T003TT000e9000>R40038R000d7`00<Ql003<M000d7@00<Ql0030Q000c9@00=RT0
03XY0012;P00@c40048c0012<P00@c<004/j000205=70P0W05]M301GLR00CgHo04QZH014EV`0>T]h
03=EN00eKFH0<X5L02j>F00WVE/0;9]C02jJA`0aTd40<Y5802fCEP0[TUh0;XmN03B>F`0jSUh0?HeO
03V<IP0hRfX0<h]Y032;JP0cRV@0=XmK03FCDP0`W4d0:j1>02RTD00TYU808JQF022YE`0SZUD0::a<
02jY@`0_ZSX0<JTh0080;jHi02L0;ZPn02nYA@0`Zdd0<:Q=032TD`0YW5T0;8eO02aiI`0cKfl0>g9Z
03mdJ011MfD0@GUS03afIP0oLFH0@fU[04EEMP1>JfH0CGMM04YjGP17R5@0@I1B046ECP12V4`0>YIC
03nLB@11XT/0@:1>03nPAP0nVTL0?IU<03jDD00oOEl0?gQQ03ieI`0nMVD0AX9J04:6F`12SUd00P11
UEh09`0nTF00@HQT04AdKP13KVl0@g5Y04=hHP12RU00@9M=04>MAP15W4<0A9m4046TA00lXd<0?9Y0
03jC@P0jUT/0>YE;03ZKAP0nWCd0@j4e04bX;P1?[R<0G:XH062V5@1MZ2<0E:Xb05:]=@1<[Ch0C:a:
04NSF@1:Teh0B8iM04ZQB01B[C<0H:dQ06F[5@1ZZPl0JJX=06B/400206:]5P0W05Z`8@1D/B/0CK4k
04:aBP10[e<0?JiE042^B`17[S/0EZ`S06N^5P1^[Q/0Jjl`06JY@01WYT00IJY006J_>`1Q/2l0JK<[
06Na:P1Y/RT0IK8W06>a:@1R/S00I:lb06JQ>@1YTD00IHU106R8@`1YT440K99006f?@`1YQTP0IWU?
06Y[FP1bFU/0P51O091=HP2TCF<0X4mV0080T5AT02L0Q5]R07QOG@1gI5T0PFYH07eZE`1hJ4l0KWA8
06^1@01/RC@0JHX_06N?7@1WTA<0Ihd=06F?2`1WT@/0Ii8<06ND3P1RUPh0HiP?06NJ4@1TVQD0GYdD
05jR7P1JZCP0Ej1705^=C`1NT4/0HY1?06>?C@1TS4X0FYE;05VT@`1G[cl0E[4o05:^@@1A/4D0C;54
04b^@01=/3<00P1<[b/09`1=[R/0CJPY04fW:01?YbP0BZ0[04FL<P14VCd0@9Xm04BO?P15XT@0?Y]9
03^=C`0dQEX0<GmO02iiHP0XK6L0:5m^02ULK`0/Ffl0;EU`02aILP0/Hfl0;75Z02akIP0YPF@0:8ET
02N:HP0USUh09I5K02JDEP0XUU80:9I@02RD@`0ZT3X0;Hdc02Z<=@0ZSSX09hdd02B;:00202B67P06
035h500kH0P0?D`203hn000o=`00?C400P0k;@002`0g:P00=RD003DS000a7`00;Q`002TK000T5P00
8aH001hC000N3`00714000`0oooo000:0?ooob/0000000<00@00000000000000100000000`010000
00000000000T000000030040000300000P4000801@4000H01`<000T3000>10004P@001H6000G3002
01P<008070d001X07Q40024C000T4P008a@0028D000V5000;1P002hN000a8000<b0002lO000b7@00
<Ql003DR000g9@00>B@003LV000l9`00?R`0040Y000n9000>B4003PS000i8P00=B0003DN0080=al0
00/0=b8003LU000j:000>b/0040^0016=P00BSd004hm001=?`00D44105I<100205]S3`0W05Qh:01=
M4X0B61V04A:N011A7<0<TQd02mLL00^N680;HmG02^ID@0VWED0:9UA02^FB00^T4X0<I5D03:@H00_
SfH0<8aU03R<G@0nSEl0@HUR03^8J00jQFH0=HET03:5I`0cPfT0=8]P03BBF00_Ve809j5D01nSE`0O
YE@08:AA02:WC@0U[4`0:je703:[@00bZCh0<jDn0080<:Hn02L0<:M103>XA00cZD`0=Z=A03JGG@0b
RfL0<gmY035bKP0dKfl0>GIY03^2J`0nQFL0?h1R03mhI@14K6H0BFIZ04eGLP1AK6<0CgUO04UnGP16
RUL0@XiF046AE012UT`0?9I?046NA`14XDT0@Z5?04:PB00mW4d0>iY@03^DDP0jOel0>7aP03YmI`0m
P680@i=F04FKF@12WEX00P11WEX09`0mVEd0?XeV03mmK`11MW40@W5Z04=fI012R5<0@YA<04:LA@19
Wd<0AIa604:QA@0lWdL0>YY0042?@@0mTD/0>YA903^K@`0oWC`0@ilk04JV=P19Zc40Ej`R05n[6P1P
[B@0Fj`b05J]=`1A[d00CJm704JWD`18UUh0BI9G04bV@@1C[bX0HZhJ06Z[4@1^ZP/0JZ/9066]3@02
05V_5@0W05:a801;/Rd0A;5003j_D`0m[Uh0?:aS03f]B01=[C80Gj/L072X401c[AP0Jjd/06NX?`1V
Zch0Ik0k06>a=01S/C40IK8a06Bb=01T/S<0H[4^05n`;P1O/380H:`j06BH@01[PdP0IhA;0666BP1W
QdL0J8Y406f6B01^Nd/0LVUB07MPG029DV40VTER0:95J02QB6L0SU9T0080Mf5M02L0KFiK06MhDP1`
MDh0Ng1:085]BP23K4`0Og5407Qj>P1cPS<0KXL[06b=6P1^T100L8d906j>1P1[SPH0KY0806fD301[
U`h0JIX@06RN4@1TWa<0H:<G05jU8@1NZS@0GJ=105jAB01PTd`0HYAA06>@CP1TS4`0GII:05bRAP1J
[3l0Ejdm05B[A01A[DD0CKA404V`@01</3@00P1=[bd09`1=[R`0D:/[04bY;P18Yc<0AY/g04Z>?@17
ST<0AY5304BG@013WC`0@Idk03nC@00jRdH0=XI>02j1D`0/NEX0:VmR02YYI`0[IF/0;61]02eOK00Z
If`0:7EY02V0IP0XRFD098iU02>CH@0UUE@09iI@02RGBP0/UTT0:Y=:02j@>`0]RS<0;XLa02j8<`0Y
RCL0:8/^02J:8@0202R35@0A03Ab3@0nF`D0@DP1040k000n=@00>S4003P]000g:P00<RD003<S000d
8@00;ah002TL000W700091H0028F000O40000P0M3`0<0?ooo`002P3ooola00000003004000030@00
0P4002@0000000h00P0000@000040@00208000L200090P002`4000l6000B20005`X001T<000K4P00
7100024A00809A8002L07aH002@E000U5`009AH002HI000^6P00<ad0034U000f8@00=2@0038V000a
8P00=Qh003DP000h8P00>BH003XW000k:P00?bT003lX000k9P00>RD003PU000e9000=RD003PU000i
9@00>2D003PT000i9`00?B`003l/0012=000BS/00557001ABP00DU0105MH1P1JIa<00P1ILc409`1G
M5<0EF1Y04a6O00h>XP0=4Ih02UGLP0VKVT09hQL02jDDP0bV4`0;IIB02N@E00VSe80:HmH02Z>H00[
SVL0;HiZ02n;I@0iReX0@8YJ04F9G`0oRF@0@HIQ0425H@0mPFH0?81V03Z6GP0eSU@0;iQ?02RPDP0Q
XeH08ZEB026SBP0TYT<0::a702Z^A`0_ZdH0<jM703JQB00203>RB00W036QB@0cXDT0=Im=03FHE@0d
RF40=GY_03QbL00hJG00?VQ^03ifJP0kPVl0>h=Z045mI@18JFP0CV1/051MK@1>F780DfMT04ebH@14
NEl0@hIG04:5FP11R5@0@I1=042?C`16VDX0AYm904>OC@12XTX0?JE?03bRC`0kUU80>7mM03V1H00k
QV80?8aO04JPE018Ze@0A:YC0080@JIH02L0?ImM03ZGI@0jRfl0>X9c03ijK`10NFX0@HEH046<D016
V4H0B9e004RMA@11XdH0?:9703^LA00oSd@0?91;03ZDB@0jVT<0>Ylk03fQ@010XSd0@ZI004nY;01G
[2@0GJhX06:^<P1L[SP0Ejlm052`A@18[4`0C9iD04nOD01CZc@0F[0T066_6@1X[Q80K:d>06^]3@1R
[Q400P1G/1/09`1=/B@0B;<b046cA@0h/5P0>JiV03b[I@19[TL0E:dY06RX6@1dYQ40M:dL076];01V
[3h0J;0m06Ja=@1R/C00H[@_066c=@1O/C/0G;5005b_?01J[SL0GZXi05nP@01TUT@0IXM<06:5BP1O
PTX0Gh5806UjB01bNDl0N75@081ZE`2;GU`0WUEP0:e<GP2UCFH0VTe]07eJI00206=WH00W06EgF@1d
P540MWU:07QaBP1cLdL0LGQ506mn>01]Qbh0L8`V072>7P1_SQH0Khd@076>3@1`T0T0KY8506jF2P1/
U`d0K9XB06VP501WXQH0HZLJ05jY7`1OZBX0GJhi05VW@01JU4L0GIQ805bJCP1OTTd0Ghe;066CB01O
WT@0G:Po05NY?`1EXTH0DjQ904n`B01:/T<0B[4h0080CK0a02L0DJl_05:/:P1:ZB/0B:H`04NL;P19
Tbd0BI@^04RE<@11Uc80@I/]046M;`0lVS00>9Hh03FBA@0`SE00;8EJ02Z0I@0[N6T0;W=[031/K00b
J6d0;FmY02akI@0/R6D0:YEV02RII@0XW640:9iC02RMC00XVDP0:iM402ZC@`0/SS/0;HTe02b5=@0Z
QcD09hTc02R::P0XQa/00P0/O0l04`0eJ0H0@E<204=4000o>@00?C4003T^000g:@00=2D0038S000a
8000<24002lQ000[70009QP002<F000T50007a0001d@000L4000303oool000X0oooo;`0000001@01
00000000004000030P000P4002<0000000l00@0000<000070P002P<000/5000:10002P<000d5000B
20004`X001T>000K400081<0028D000W5`000P0Y60009`0Z5P00:1L002PI000Y6@00;Q`0034R000d
9000>2D003PT000g9P00=BD003@Q000c7P00<Q`003PP000k9@00>2T003PU000j9`00?BH003lV000j
9P00>2@003PR000j:000>bX003h/000n:`00?RP0040[000n;000ABl004Xi001?@`00EDh005YG0`1I
IPP0EVlJ04m`>00205=YF@0W05iLL`1VBW`0FD2004DoPP0fFG809WE[0228H`0RU5X0;IMB03JCD00b
SED0:hMH02J5G00WQF809hIY02R;JP0[RfT0;XET03MnG@10OUl0A8AR0428IP11QV<0A8=O049oG00o
OV80>X=I03B:E00bU4h0;9m@02RSE@0VY4`0::A102^V>`0X[3l0:Za602bYD@0cXEH0=iaI0080<ImN
02L0;iaJ02nGE`0`SUL0<XEN03=lJ`0eLG@0>Fa`03mXK`13Ifh0Ag5Z04AjJ@17NFT0CfiX05]JJ`1K
EVd0DeY^04=ILP16JfD0A7YN0425G@18R5H0AhAM04B6F@12RE40?8AG04>@DP13W500@Ii>046SB`0m
YU00>Z5C03VCE`0fOf40>HEO03f=G00kV5L0@jI?04>`CP12[5000P10Ye@09`0mXUl0=iiW03NCK00i
Rg80>h5c03enKP11Q640@hEI04N@BP19V4@0BIa604NRB@11XD`0@iU?04R=CP13Sdl0?i5:03^GA00k
VSh0>Ya203^M@`0mX4D0BJDh04n/;`1L[Bh0Hjd_05j/>`1JZd00E:i:04b]C@1;Ye80CJM805Z^;@1O
/280Hk0K06N`601X/1D0I[0F05f^6@0205>b8P0W04Vc;P15/c`0?K5>03R`G00k[f@0A:]I05R]?@1R
[Qd0LZHB07JS501bZa/0K:d[06R]?P1V[Sd0I;0d06B`;`1S/R`0HK8/05nc<P1Q/3P0GZ`f05f[>01M
WT40GI17066BC@1PS5<0H8a<05b4BP1HN4d0HfeD06a/F@1jJF00P6QL08YTFP2<H5X0QU]M081UGP1k
LV<0JgAH0080IW1A02L0OG5>08YdC`27Kdd0Nfe706]j@`1RPT40Ih/g06V=<@1[RRl0KHlW06jC7@1^
UAL0LiDC07JF4P1cUPl0L9P?06nL401/WQ@0JZ8F06JT6@1RYQl0H:HW05nZ;`1N/3X0GZa005bRA01K
XDL0FYa905fBB`1MSdP0Gi1406:O@01OYcl0Fj=005ZOB01GXdP0DZ]905:`@`1C[cL00P1D/C009`1B
[b/0CjPT04fT9019XRD0Ci`R04bE7`1;UQl0B9LR04>H8P11VR<0@idZ03nP;@0nWS@0>Ia303JAD@0d
QEh0<WmW039eJ`0gKFd0?FI^03aWK00cLFL0:g]X02b;JP0ZVFP0:imX02RTHP0XY5L0::1A02VMC00Y
VTD0:IQ302^A?00]SCH0;hPa02j5;P0^QBX0:XHR02R15`0202ac300C03QO0P11B`00@Sl003lg000l
<000>2h003LZ000b9P00<R80034Q000b7`00;ad002dL000W5`009A@0024F000R4P007a0001/@000<
0?ooo`002P3oool_000000030041000100000@0000800@00800000020040000@0080000400001`40
00`4000<1P003@@00105000@1P004@T001@<000I2`00618001`>000Q4@008QP002LJ0080;1d002L0
:Ah002TK000Y6@00:A`0034Q000c9P00=2P003DV000h9@00=RH003DU000c8000<Ah003<N000f8@00
>bD003LZ000m:000?RT003`[000n;@00?BX003XW000h9P00>RP003d/0010<000@bh0040^0011;P00
@S<004@i001:@000E4d105YK1@1MJPh0F7TP051f?@19HUP00P1DDVX09`1PCGP0ITQf0599N@10DWd0
;G1d01n9K@0KUF0079UJ02FGF@0_Se/0;hEP02mnH00]N6<0:gUX02V1J`0[R6T0;hIW031lI00eL6<0
?VmU04AlIP11QFX0?hAZ03inI@0nNf@0>gQT03MmF`0bP5L0<X]@02jIC`0^XU<0:jA<02ZT@`0/Y3/0
:ZTo02NZBP0YYe/0;:9P032PI@0202bPJP0W02VIJ@0ZRf`0:g]_02ahL00_KGL0=V=k03iSL`18HW00
D61^051XJ01<KFP0CfUZ061OJP1bDg00K51_05AFK`0gF780>ViU03^3F`0nSE/0BHiG04^<GP14S5`0
@hiE03j<GP10UE@0?iaA042MC`0nXdd0>jAB03^LE`0hSUX0>GeU03^9G`0lV5X0?j=E046ZD`10[UD0
?JaF0080=jUG02L0>JQQ03FUJ00dWG40<i1b03V6L`0lPFl0@8ET04F3G@1;SE<0Bi=904fIB`1:WTd0
A9eD04VEF@1AReX0BHaH04B;C@0kS4D0=i1003J?A`0lUTH0?YM504JI?`1>XST0FJPc062]<01K[SX0
Eja505J^DP1B[500DJQC05F/B01L[bd0I;0O06:a7P1R/Qd0H[4K06>a6P1K/2000P1>/RX09`17/cH0
@[5<03bYFP0mY6H0@JUM04nXC01VZRh0Lj`J07NR3@1`XA80LJ`M06b_;01U/3h0H[4m06J`=`1U/c00
I;8[06Bb9`1S[bL0H:`[06:Z;@1MZ3L0GIm005nEB01OTdT0Ghi=062;B`1NQ4/0FWID05iTG@1[Hf80
OF=V08ETHP2<HU/0Nf5L06YQF`1UO5d0HY5G06>BAP0206J<?00W072;>@1hQS/0LX8f06j3<`1[S3H0
Jhhj06n>=P1]SCH0JY0c06^B;@1/Ub<0Ji`P06nL7`1bVa`0LYTE06nJ501ZVa@0JYhG06JQ5P1UXAH0
Ij4H06:S7P1RYb@0GJ`]05^`>01JZT80Fj=805fIAP1OT4P0Ghe905nB@P1NWD00GjLo05fV@01JXT@0
EZ5804nSB@1BZd00Dk0g0080EK<f02L0CZhX04nX8@1>Xb40BJ0M04fK6P1@UAP0CiDK04ZI7012VAh0
?Y/P03jN:@0kXc40>j@n03ZMB00iU580>8]I03N7F`0fPE`0=WaO03]kH@0fP600;XUL02V@G@0YVV40
9j1L02JQF00VXU409j5:02RNB00VWTH09Ia602JLAP0VUT00:Y0d02b9:`0_Q280;H4L02]n5@0[N0`0
0P0fIPH04`10DP40@d<0044k000o=P00?C4003X]000f:P00=B<0038R000c8000<1h002lL000Z6P00
9QH002DD000P50008A<001lB000L3`00303oool000X0oooo;@000002004000800P4000<00@000000
000000007P00000050030000100000@000040@001@0000L000090P002`D000h5000A1P005@X001L<
000I3P006Q0001/?000L40007`l0020C000T5`00:a`00P0a7000400]7000;1d002`N000/7`00<240
038Y000f:000=bH003DX000g9`00=B8003@S000b8P00=Qh003`T000m:P02044/000E044_0016;P00
@2l0048[000m;@00?b/003h]0011<@00AS<004Pc0017=`00ASP004Dk0019?`00E4X105aN1P1OLQ@0
GGda05UgB01MI540GeAA0080GdmU02L0DTmj04aENP10G7T0=VMj02J4L`0RUF/07iMQ01^HH00MTfD0
8XU^02IlL@0/LFh0;FQb02e[M@0bNg00=hIV03^4H`0hLfL0>5Y_03YOK`0oMFh0?H=`03b2K@0lOfL0
?7eU03QiIP0gN640<g9R03F0F00dUE00<9mA02VRB`0VXDX08im902BRC00TXUL09:=T02JNI@0XVVH0
0P0YVf/09`0XTV`0;89`02e_M00_KW@0=FMe03aKM`15GG80Ce]b05IJK`1GI6P0DfIY05INK01UFW00
N5Ec06iGK01CGF/0=fA^03agH010R5`0@I=L04bDE`18TUd0A9AL042EF00jTUh0?IUE03nND00mX4`0
?j5=03VKEP0gTUd0>8MM03UoH`0iT5X0?YmG03nWE010[5H0?JeL03JZF`0303>YGP0V03:XJ00bXW00
=99a03^3L00lOfl0AX9S04]oH`1=QeL0CHiA052@D01@TU80BI1F04b:E`1AQE`0C8QM04F3D@0jQ4X0
=hM403>5BP0hTDP0?99704R?@01=TCh0FIlg062];@1I[ST0F:a;05R]EP1DZeH0DjQB05>]A01I[bX0
G;4Q06:a701P/1X0H[4G06:`601J[ad205>b9P0W04Za=016[DX0@iaN04:KH`1:Ydh0FjDm07:X;01m
YaT0OI`>076N4P1YYa`0Hjl/066a>01S/400Hk4j06Bc=01X]2`0Ik8X06N^901SZRL0I:@/06BV=01S
Y440HI]705jEBP1LRe40HHM<069jD@1RL5P0HfMO06MXH`1^KEd0KfmN07MbF@1^KUD0IGM>06F6C`1U
UDX0HYPn0080IIXg02L0J9@b06J==@1YQC@0JX@d06^8=P1^RcH0KhTg06f>=@1[TB/0JYDV06FM8@1X
X1d0Jj8M06jP601]WQT0JYdI06ZN601WXAT0IJ<F06FQ4`1YX1D0Ij4H06>X6P1LZR40G:l`05j]@01M
XTD0G9170629A`1RSDH0HHm1062F@01PX3H0FZLj05BR@01BXDH0D:5805:]@01A/3@00P1>/3D09`1;
ZRL0C:HP04jQ7`18W1`0B9XM04fH7`1=UQd0BITK03nH600jVAT0>I`S03NQ=@0hXTH0>9]>03F@D@0e
SED0<haD03:<D`0bReD0<heG02jDEP0XW5409j1B02JSE`0WXU40:J1:02VNA00VWD00:9Y002NK@@0X
WDL099e:02RJA00ZU3d0;8db02^6:00YPA/0:7XA031^1P0203iJ000C04=90014?@00@3P003lc000k
;P00>bX003PU000c9000<R8002lO000a7P00;AX002XG000V5`009AH002<E000T4`008a0001h@000<
0?ooo`002P3oool^00000003004000020@000@4001l0000000<00@0000<000060P000P070P004@07
0`00208000T2000:0P002`H00188000F30007A0001lC000P5P007A<001hC000O4P009A<002LE000W
5`00;AX00080<A`002L0<1d0034J000_7000<1l003<S000e9P00>2P003LW000d9000=BH0034Q000c
8P00=B8003DU000m:@00?2d004@^0014<P00AC8004P^0015;000@Bl0044^0014<@00A3@004Xd001:
=`00C3d004i2001AA@00DTD005Y@0P1PG@L0HW@F05ml=01QLUL0HVAO06UGDP1_BTP00P1MC6<09`19
CGL0>eii02QbN@0PPWT07Y5g02:FK`0UUFH08Y=W026;KP0OP7D08gIe02]cM@0_LGX0<G=o039hNP0h
OVl0?Gi[03YgJ`0fKFh0=fi_03akK00nPF/0?89Z03b1J@0kPFX0?Ga_03YcK00fJ6l0>7QP03Z?D00d
WD/0:Im<02FND`0SUel08iQN02:HI@0SVg409YI/02JAJ`0202N>K`0W02b<J`0]Q6d0<7Yb039dK@0i
JFd0@5E_04iCKP1JCg<0IU5c069HK@1LEfh0GEIa06UIM01gFGP0KEi`055TJ`0jKFP0@W]K04F7E`12
S5H0BY9F04BBF`12UUh0@9UL03VHH00mVU@0?Ym>03fQD@10WE<0?95L03R8H`0iRUl0>8eR03bIFP0n
XUL0?JQH03fZF@0lZF40=jQQ0080=:UP02L0=JYP03FZG`0cYV/0=YU_03J;K@0nQf/0B8ET04miI01<
OV40CX=L04j5G01@Q5L0C85F04j0E`1<OEP0B81H04R0DP13PTh0>XQ:03N9C@0mSTl0@8i>04V;AP1?
QD<0DiLi05b[;01K/3P0Fk1405R_CP1DZ5<0D:IC05>]@P1F[Rl0F;4R05b_701N[QT0GjhF06B]6@1L
/1d00P1E[bP09`1?[SH0AZ]604BOEP1<YE<0G:Q206RP?`1eYC<0OJHN082K3P1fV@l0JZDJ06J]:P1S
/CD0H[0k06>b>P1W/CX0K;8f06Za;@1X[bL0J:/X06RY:P1UZC@0HJI005fPA01LV4H0GHe>0664D@1Y
LUL0If]K06MYGP1RMU`0H81D0665EP1TS4l0IXU306F<?`1WSSl0Ji0i06RA=@0206V?=00W06Z8=P1X
Q400JWXi06Um=`1ZPcP0JhDi06N7=P1XSc40JI4Y06RG801TW1d0J:8N06NT7P1UXQX0IJ<N06NT801X
Y200IjLP06NW6@1XY1@0JZ<A06JT5@1RYaT0H:`P05n[:01QZcD0Gj<l05fC@@1PRD80HXY106:<@01O
Sd00H9Pe05bS=P1IWd80Ej5805NVA@1D[CL0CjX/0080BjHT02L0C:8P04bN801<W280BIXR04^H901<
V2L0BiDO04RE5P12U1<0?Y<B03ZH700gW3<0=Ie@03FCD`0gQED0=hMG03R9E@0fReH0=HiO03>BH@0/
Uf80:YeP02JOGP0RXe`09J=E02>SD00TXDP08ii402NL@00ZVD40:iQ702^GA`0bU440<Hm003:;>@0a
QS80;g`Q031b400kH`D00P13D0004`15@`00@ST003ld000n;`00?Rd003TX000f9@00=B<0030O000]
7@00;Q/002`K000W60009AL002@F000R5@008Q80024@000K4000303oool000X0oooo;@0000001001
00000P00008100010@0600000003004000000000000001D0000001L00@0000<000030P002@<000`5
000?10003@@000d3000?100040@00187000E2P006a00020E000S60008QL002<C000S4P009a<002HD
000V5`009QT002/K000202lL000W02lK000d7000<b40038R000c9000=RP003LZ000h:000=2@003<M
000c8@00=24003PW000l:P00?Rh0048^0013;P00A30004<`0017;`00A300048_0017<P00BST004dk
001@?@00Dcd005I5001GC@00Fe0005aH101RI@`0HgHM05Ym=`1OLU80JUe]079CI`1^DUd0J4aL0080
CE1^02L0=eAm02A^P00GQ8005Xmm01^>N@0QT7009Y5Y02R?K`0XPW@09WMj02M_NP0/Lg`0;GN002mh
Q00^MXD0=7Qn03MjN@0fNW/0<WEj02m`N@0eMGD0>GUb03QlL00gO6`0>7]`03aiL@0nMg40>gM_03j0
H@0mSdl0=I]:02bLD00VW5T09IAT02JGI00WUVT09iEb02V?L@0[RVl00P0/Q7409`0aR6X0<8EZ03=m
L@0iMFX0@6I/04ADK@1BE700HTme06e>M`1[DG<0Ie9d06Q@M@1`E7H0N51j06]JMP1DIfd0@fi]04Ye
GP1<OUP0Ah5I04R:E@14ReX0?heO03bDH00iTfP0?9MK03nJE@0mWUP0@9EH04>2GP10P640>hiM03VN
HP0jXeT0?:=H03^TFP0lYEX0?J9O03NSH@0203RVH@0W03N[G`0fZed0=:]V03FPJP0iUfX0?9AZ04N;
I01=N6L0BWQX04YgJ01<MfH0DGQT04ieHP1>MEP0BgIG04eiF@1ANUP0CgiF04N9D`10RUL0BHmD04Z:
DP1>QTd0Ch1=056@@P1HZcH0F[0g05^`>`1I[TH0DjAB04fLE01B[4H0Ek0e05Zb901L/Ql0Gk0I066]
6`1Q[R80F:d^0080DjDm02L0C9]804bVB@18[DT0G:e006fX?@1^WD<0M:4h07VW9`22XA80MIXA06VR
6@1QZbL0Fjl`05f_=P1Q/CX0IK9006Ra?01X/C80J:l]06B_:P1U[Bd0HZ`d05b[@01NZ4<0GJ9405bN
C@1JVE40GhiE06IoD@1TPD/0I8U;06R>BP1WTTL0II=006F=>`1USCT0J8`g06V;<P1YSC400P1YRc00
9`1]RRh0J8Xa06V:<01[SBh0Jhh`06R<<01RT2d0I94X06ND9@1XUR00IYXQ06BO8P1TYB40J9lI06JQ
6P1ZY1d0IjHQ06JX7`1WZ1P0I:@C06JR4P1VXA<0IZ@I066Z8@1Q[2H0H:P_05nT>P1NVc/0HHll06:@
?01STCl0II@h062I;P1JVBh0FI=005JL@P1GYD40EZLe052S8`02056N6`0W04nK701AV2<0D9HT04nD
901?TBH0BY0R04Z>6`16T1P0@i8I03jG7@0iV2P0=9Q0036CEP0`SUL0<X]J03J<F`0cS5`0<XmU032>
J`0/T6h0:Hib02^;N00WTWL08ia/022QH00QXeH08:I:02BRA00VWD00:9Hm02b?>00_RS<0<hHa03F2
;00eORT0=7TO03M/4@0mG`L0@U020080@d8001<0@c/003hb000k<000?Bd003`/000j:@00=bH003@R
000a7P00;a/002`J000Z6@009QP002DH000R5@008aD0024B000M400070l000`0oooo000:0?ooob`0
00000P0100000`0000000@00004000060000000500400000000000000000000100001P0000000`01
0000000000000005000000800@000`0200005`0300000`4000L2000:1@003PH00108000A20004@L0
01@8000F20005`/001X>000P4P0091L002<L000T6@009AD002@C000U4`008AD002LH000X6@00:QP0
0080;1`000H0<1d003@T000f9P00=BD0034W000d9`0203LU000O03@T000a9000=R4003/T000m:`00
@S8004<f0011=000@bl0044]000o;`00@Bl0044b0013<P00B3P004lj001@@000ED8005E7001FC000
GeT006=S0`1RL0l0GGdW05Yk@@1NKUP0Jf1R075IJP1cE6d0JEAb05]@MP0203eEO@0W02eGQ00JN8H0
58>901B7QP0GOh007HIh022<N@0TSX809h:202IdP00YKgl0;7Mm031nP00aOXD0<7F803=^R00cLXD0
<7V102akP`0[M880<WAi03QfMP0fMg<0=GAa03EaL@0kLW40?7Ua03f2KP0kRF00>Y=A036GD`0YU5`0
9YMN02VEH`0[UV@0;IAZ02fAMP0`T7<0=Y1/0080>HeZ02L0>XUW03Z2K00iKG@0@VM`04eLJP1HCfX0
HDe_06Q>N01_CWX0Ke5f06mBN01_DgT0KeUf06mGM`1XGg<0G69^05AVK01GK5h0DW5K04IcG`13PEL0
@81K03f4I@0kSVL0=91^03VAI00jTEd0?9AN046AFP13Oeh0A81L04:DG@0nXel0?jEJ03nOF`0lWE`0
?YaN03^DHP0hUf800P0hX5l09`0fZV00=ZaM03N[HP0eYV<0>IeW03^IJP15T6P0AgU[04YbJ`1?Jg40
D6aa055`K01@KV`0CfmT04a/H@1?L600DgIP05MmGP1AQ5`0BHMN04V<FP1>QUL0BhAD04Z0E01@T4/0
F:Tm05Vb=`1O/SH0FZi005>MB`1ATEL0DjA<05Zb@01K/c40G[<R05nb701I[bD0F:lc05:[@@0204bH
B`0S04^<CP1DXSl0FZlf06V]<01cYCH0KY]006nO?@1dZ340MjLJ06jV5P1ZYad0Gj/Y05n^;01P[S40
I;0d06Bb?P1T/d00Ik4i06R`<P1U/2h0Hk0a066`?01Q/T<0H:e8062VB`1JYE00GZAA066TB01QWD00
J9`f072D?01dV3l0LYE006j=?P1YQD400P1XQ400:`1WQcT0IX/b06NB;01WTR`0IiDV06JF:@1VV2X0
J9LY06VF;01WUR/0IILX06BD9P1TSRL0HHXY05n<;01TSb/0HYHZ06>I8P1TWB<0JJ8W06ZU9@1UZB00
Ij@H06JO401XW@l0IiT=06RL4P1SY1X0HJPU06FW<01QXcL0I9hm06FF>`1VUS/0IYHl06NH<01WV1d0
HIDI05NA8P1CV2d0Cj0h05BR=P1FWbL00P1FVAT09`1JV1T0F9<N05:A7`1DSR40E8`S04f=7`18SQh0
A9LQ03fL:P0gXCH0=Im802fFF@0YQVD0:H=Y02^:KP0]RV`0;X9/02j3LP0]PWH0;8Qd02V9MP0ZQG/0
:8mi02BLK`0VXV<09J=F02JRB@0[WT00:iU002^A<`0^R2h0<8<Y03=o:@0fNB<0<G<K03=Y4@0iF`H0
?d`20411000203lf000C03``000h:`00>bX003`Z000k:P00>2X003HV000e8`00<al002lM000/6`00
:AT002LH000U5`008Q@0020A000N4P007Pl001d?000<0?ooo`002P3oool/000000800@0000<00000
0040000100001P0000001@01000000000000000000000@0000H0000000<00@000000000000001@00
0002004000<00P0001L00`0000<100070P002PD000h6000@20004@P00147000D20005PP001L;000J
3P00818002@G000S700091T002DE000T4`009A<0024E000W6000:1T002XH000202`L0006030M000d
9000=RH003DU000a9`00=2L00P0g9@007`0d9000<B@003HQ000k9000?B/0048b0013=P00@C@004<_
0011;@00?bl0044_0011<P00@c8004Ph001?>P00D40005E2001EA`00ET`005mI001SH`<0HW0?05em
9`1JNd40GViH06]PHP1aFFX0LeA]06UDLP1KD7H00P0mEGd09`0]Eh@06WR601B3R@0DQhH05gn001f6
N00PS7T098j202N2PP0VM800:Fmo02agO@0`OX00<Gj5031eR00cKXP0<g:5031iP@0/Nh<0:gB2039d
N@0hMWH0=WMc03EdL@0eLG40>g9a03aiL@0mPVh0>hUP03ZCD@0aUe<0:IAL02JGGP0YUF<0:iIT02fD
JP0]TGH0<91c03J@K00203V=JP0W03Z9I`0jPV`0>Fed049WL01=G6X0F4mZ065=K`1XCWP0Kdij06mA
MP1_DWP0Ke=i06mIMP1_EgL0J5mc05aRKP1DIV`0EfaN059aF`16Lel0@h5G0420F`0mQ6D0>hiW03B@
KP0iTF@0>Y5M03bDGP11TEX0@gmN04B0G012U5d0?Z=O03nUFP0oWe/0?9eL03jLGP0kU680>9MR0080
>:1O02L0=ZYP03J/G@0gZf80=JIS03VMI`0kVFX0AI1X04MiJ`1:LV/0Cf]a051/L@1AL6`0D6i/04m_
I01<K640Cg1P05=fH01GOEh0DHAL04V7GP19S5X0CXIG04^4E01:P5@0D91;05RY?@1I/SL0Gk8f05Z^
@01CWD/0DI5G05>TC01J/T00Fk<a05jc8P1O/Q`0FJlU05R_<`1BZd400P1<V4/08`1;S4h0E:8o05Z_
=P1Y[C00LjDf06jK@01_Wcd0M:Pa07NW6P1^YQH0JZLM05n[:@1O[R`0H:ha06B`=01T/Sh0I;=006Na
>@1X/380IK0^06>`<@1Q/3`0HK93062]B01PYT/0FZE@05jTD@1QY4P0HIe006RL=P1`U3`0M9Po07:E
@01^SCh0JHE10080J8A002/0IhLi06J;<P1WTR`0Ii8/06NE9P1VURT0IYPZ06RG:@1YUR`0IiH[06FG
:01TU2H0I8hW066::@1OS2`0I8l[06:F:P1SVB80I9dS06VR9`1ZYBD0IJTP06NT601VWa00J9d?06NI
3@1XW180Hj@J066X9@1UYc00HJ<g06BN?@1UUS/0IYHk06JF?01WV300IiPM066E6@1GTB80DiP]04nP
>01DXSH0EYlW0080EYTI02L0FYPI05RC7P1BTAl0E8hQ05B<8`1=SAl0B8hN04BG8@0mW2X0=j4f03FO
B00]UUT0:HIU02V3J@0[RVh0;HY/02j2K00^Pg80;H9f02b8M00YRGH0:XEk02R?N@0TW6l09Z9S02FS
EP0VXTT0:ii002^I@00[TC<0;XP^0323:@0cObT0=WTS035c6`0cJA40>E/603m<0P10@@000P0o=P00
4`0l<000>2/003/Z000l:P00>bX003PZ000f9P00=B<003<O000_7@00;1/002TI000W60009AL0028D
000P4@007Q8001h?000M3`00303oool000X0oooo;0000002004001<0000000<00@00008100010000
1@000002008000800P4001T0108000D200050@00204000P3000>1P003`P001<9000A2P004`X001D9
000G2P006@d001`?000M4`008QH002<H000Q60008a@0028B000V4@009QD002XH000Z6@00:aT00080
;aX002L0<B8003PX000j:`00=bT003@T000d9P00=BL003DX000f:000>2H003dX0011;000Ac<004Pi
0019>@00BS<004Dc0012;P00@2l0040^0010;000AC8004di001A@P00DTL005U7001KD000G5`1069Z
1`1RM1@0GGd[05UhB01TIUd0JeaX07=HI`1kDV<0MDmc06i<OP1FCX800P0aGHL09`0OIH`05GND01=g
V00EMY8056R;01QhQ@0IRHT06Y6B01j:S@0OPHX08WR502EgQ00WNHD0:gV602afQ`0^M8L0;GV702em
P`0]NhH0;gN803AiOP0gNg/0>7Ug03EcL`0cKG40>79`03UoK`0iS700>I1W03JCG`0]TF809h]Z02J<
JP0XRVX0:h]/02j<K`0`S7T0<hmb03^AJ`02046BI`0W0469I011N6T0AU]d059EKP1UDfP0O4eR07M?
IP1dCG80M4ei07=FM@1bFGH0Ke]f06YOL@1SGGD0HF1]05eUJ@1GI6d0F6]P051`GP13LV40@GaL03]f
HP0iNFX0=hUY032>LP0hRVP0>X]Q03^?H`0nSe/0?hEH0468E`11UeL0@J1M04>PF012WE`0?iQQ03fC
GP0mQf80>XaO0080>9YP02L0=jQS03N]F`0h[5d0>JIQ03RMK00kVFd0A95X04QnJ`1>L6X0FVI/05QQ
L01IJFl0E6ic04iZJ@16IFL0BFUY04ibJP1?NfX0DH9T04b1H`16Q5d0AWiM04AlF`18OEX0DXaC05^W
?`1M/CD0H[8_05j_=01DWTL0DHmJ056ME@1F[Dd0F;1005Zc<P1F/Rl0Dk0i04fYB@17XDh00P18WD/0
9`1@WCP0H:TX06f]9P1i[bT0M:Xh06jQA01`Y440KJXe06n]801]ZQ`0IjTO06F/:01S[RP0IK4V06Ja
:`1U/340IZhm06J^=P1R[C40G[0]05nb<01L/cP0Gk=606:[B@1OWTX0GIY=06:KCP1YXCl0J:@b06nP
;01bVRh0LIXg07FC>01dRc@0L8@f06^7>P1[S380JXd[06JC:@0206JF900W06RJ801XW2@0IidX06BM
:`1UW2h0Hi/_06FL;@1WTB/0HXH/0660<P1QQ3H0GXTd05b?<@1NURd0HILX06>R:P1WYBL0JJ@Q06FR
601UW1@0IYPC06NE4@1ZUa40J9/G06ZO701ZWAd0II`W06VL;01^UR`0KY<Z06nD:01^UAh0K94C066:
3P1JRA80EhhK05BH9P1FVBD0FIPI0080GY4E02L0GXlF05R;6@1CSAd0EI8V05:?:@1=TB<0BYHU04BP
;@0iYSh0<ZUA032SJ00WUFl09X9c02QkM`0YNg@0:WEb02maLP0]LG40;7=a02Z2L00ZQVl0:HAb02N=
K`0XVfP0:J9O02VSC`0[X4@0;YXl02jE<P0`S2`0<hHV03>09@0dNB80<g<H03EZ3`0lG@P0?Td20490
0011=P000P0n<@004`0k;@00>RT003XY000j:P00=bX003XY000f9000<b40030O000]7P00;A/002TG
000W5`009AD002@A000P4@007`l001`>000I3`00303oool000X0oooo;00000000`020@000@400000
000A000000800@0000<00@400040000100000`0000007P0100000P00008100030P00108000L40008
100020<000X5000=10003@P00148000D2@0050X001@;000E2P005`d001`?000O4P008A<002<E000V
5@008aD002@B000V5000:1H002XJ000/7P00<20002lN0080;R4002L0=B<003XZ000h;000>2P0038V
000f8P00>RH003`/000o;@00@2d0048^0015<P00B3X004ho001A@000Ccd004Tf0017<P00AC8004Hd
0018=000C3h00591001FAP00F4P005aA0@1OH@@0HG8<05il7`1INcH0FFe>065QF@1^EVL0NTa^07]?
J`1lCFP0LDac06I:P017EH@00P0YIH/09`0JJ9005fVI01ISW00GHiD05Ef=01QbR`0GQY<05i:J01N@
V00IRYD06h2C01]eT`0NKY408F^>02=`SP0TLH`09W6;02]cQ`0_M8H0<GF903AiQ00gO7`0=Weg03Uk
L00hNVP0?7eU03j5I`0jSFh0>91^03N@KP0_RW80:X=e02YmL`0]MW40:gQ`02n1M00aQgL0=8]_03Z<
JP0203j:JP0W0463IP16LFT0CeEd05a@L01]D6P0PDYN07aCHP1iE6L0MeM]07QKK01hFfd0Kei_06AW
K01LI6l0GfAW05eZH@1AJfP0Cg9N04QhG`0nP6D0?8EP03EhJ00gNF`0=HUW03:8J`0fQFD0>hMS03b=
H`0jTUL0>XmF03f@D`11VU40@9iH042QEP10Wed0?iYQ03nAH@0kR5l0>I=N0080=ImO02L0=ZYK03ZZ
F00lZUX0>jAP03fJI`0nU6X0A91U04V9I`1DNFH0IVMU06ASI`1NJF/0E6ib04YZKP11I6/0@VIc04Ac
M@15Ng@0C7eX04amI018Of80A7IQ049fGP11OEX0ChaC05^W>@1N/bh0H[8U066`9P1FXS`0DYUH05BM
E`1CWeD0E:E=05:ZBP1@ZdT0BZ1A04F@FP18UU400P1=Y3@09`1L[b@0LZdM07R_7P1j[bP0Lk4d076Z
?P1_Ycd0L:Xc07:_901a[Ql0KJPK06VZ8@1U[B40IJlO06Fa801Q/Bh0H:dd05j/=@1O[S80H;4^05jc
=@1P/c`0GK9405f]?P1NXcX0IYU106nC@P1_V3/0LIPb07>J<01aVcL0LYhl07BJ?@1`UcD0KY8c06ZB
=@1XTc80IY@Z06FE9@02066H7P0W06>I701XVah0IIhT06>O:P1OVR`0HI//06NJ:P1TTRT0HXhZ066B
;`1QTc@0HYPe05nG<`1NV2h0I9/Z06NM:P1WXbH0JJ0Q06NN7P1TW1l0HIHO06BE7`1RUQX0IiLF06fE
5P1]Sa00IHhA06V<4P1]RA<0KhTD07:44`1dP`h0LX0:06Ul2P1RO0h0G7lC05R85@1GRa@0FHX@0080
GXXB02L0GXdG05N>6P1@T240D9@]04jA;P17U2L0A9`[03jS=`0fZ4`0;:QT02JLM@0URWd09Weg02Ui
K00[N5l0;GQD031gC`0`MU40;gYB02f3D`0ZRUP0:XaN02JBF`0WW5H0:Z1?02bQA`0/X400;Ydo02jE
<`0_SBT0<8@R03=l700hLaH0?6L<03mL1@14C`80@T40048f0011<P000P0m;`00100k;000>B`003PZ
000j9P0203PT000=03DT000d8@00;al002lM000/6P009aL002DE000S50008a<0020C000N4@0070l0
01T=000<0?ooo`002P3oool[00000003004000020@000P4000L000000`010008000000800@001@00
00007`0100000`0000<100050@001`8000L4000910002`H000X5000>10003`P00188000C1`0050P0
01D9000E30006Pl001l?000N4`009AD002@I000P5`008a@0028F000T5`009QT002TH000Z7`00;Ql0
03@Q000c80000P0d8@002@0f8@00=2L003HX000e9P00>2L003XW000l:000@2d0044]0002040_000L
04Da0018>@00CT400512001A?`00CS`004dh001:=`00BC/004do001AA000E4X005YB001OF000HfP6
05mk4`1JPBX0DWM5059OF`1NBF@0IDYM06UAH`1eCVL0N4iY07A>J`1WC780HD>003eEQ`807f>B02L0
56:F01MIV`0JEI`06eNC01MES@0KJh`06h2C01^>V`0LSiX07H^I01b4VP0IM9`06V>L01iIV00MHID0
7FVA029[S00ZK8H0<6j403=bQ@0hMH80>7Mo03YmN@0iOfh0?H9U0462H`0nQFH0>hQb03N;N00eRG@0
=8=c03=oL`0bOFh0=7M^03AjJ@0ePFT0>8AY03Z6J@0mPV/00P0oN7809`11L6/0BfM^05]AN`1WCGP0
K4]]07E7I@1cDF80KUUT06aLIP1[HFD0JVAX06ETJ@1OIfH0FVAV05]VH`1GKF40BWAR04QjF`11PUh0
=hQZ03::HP0aOVH0<WmV03R;GP0fQV@0>8MR03b9H00oSf40@9AG03b@EP0mTUD0@IYB03nJEP0mXE@0
?YmJ03ZJH@0kU5d0>HiP03JHG@0203FSFP0W03NZF00mYeL0?Z9L03jMG@10V6<0@I=T04N?HP1>R6D0
FgMT06YWI@1RIfX0EFi]04i_L@19KFd0@6e_041/M00oMgT0@Gal04IkL@19N6`0BGQV04YZJ015K6D0
AGMQ04b:D@1LYc80H;<P06Fa6`1T[Ql0FZLe05FOC01BVE40D8mD05:DE@1?WEH0C9mH04ZCF01:QeD0
E9M00080H:XT02L0Jk0G07J]501g[a`0L[4W076_<`1`[3<0Lj/c076];01a/280J[4O06V_6`1Y[1X0
J:`K06J/701Y/1/0Hk4U05fb;P1K/340G[4k062b>@1S/400I;1206F]A01T[cP0IZh`06fW=01bYBl0
L:8]07>Q:`1aVbh0KYd`06fR;P1bXS40MJ0^06jN<01_WC80JY/^06VJ:`1TVBL00P1VUb809`1TUQl0
I9PQ066I9`1PVBd0HID]06:E:@1SUBX0IIHV06RL9P1TXRl0IZ8f06BO>01TUSX0I8do06J<?P1VUS`0
I9hf06FN;@1TXBP0IYdW06JH8P1VUR40Ii8K06b>4P1^R0d0KWl606ik0`1_NP@0KWD3071g0`1aM@80
Lg02071Y0P1YI`D0JVd906Ed2P1SOPX0FhH:05^8300205f:4@0W05Z94`1FR180DXhJ04jC:018UBT0
@iD]03bI?@0hVTh0<iYP036HK@0/TG40:He`02b<H`0aR4T0=h4d03im:@0oO280?gXP041m8`0jPbX0
=h`g036B@@0^V4H0<9]2032M?`0_WS/0<9`h02nJ=00`Tc40<H/W03>26`0fMa80?FX904AJ1014C040
A440048j0010=000@2l00080?R`000<0>B`003PX000h:0000P0j9@003P0f9@00=B<003HS000b8000
;a`002XI000W60009A@0020C000R50008A<001/B000J40006@d0303oool000X0oooo;00000000`01
0@000@000000000500000004004000010@000@40004000L0000000@00@000000000000000@000`00
00005`0100000P00008100020P001@8000L5000:1P0030H000l6000?1@0040L0014;000E30004`T0
01D8000G2`005Pd001/>000N4P009A@002PG000W60009aD0008091D000L091T002PJ000/7000;1h0
02lO000e8@00=R<000<0=R0002H0=R<003DT000h9P00>BP003XX0010;P00A380048e0013<@00AC00
04Dd0019>`00C4000553001??@00Cch0054n001@@000CT<0051=001EE040EUd405aX1`1OL`h0G80N
05B0=P1DJ540FUED05i5I01O>V`0Hd5L06m:D@1bCUX0LE1U079<J`1SBg@0E4V1039JR`806V2F02L0
55bF01];V@0MAYL06T^A01I?S@0IIHl06GVC01b6U`0OQYH088JJ01n4W`0MMJ407EnQ01m9WP0RDIP0
8eVC02EPS`0/IHL0=6R103I^O00iLW`0>GIm03alN@0nP740@X=[04:1J@0nOVd0>7Yi039iO`0dN7P0
=WEd03IhL00eNVX0>7eX03J2H`0gRU`0>hmH03n<G013PVD00P15K7009`18J740F5ic07A>N`1gB7P0
LTAd074lL01]C6T0IUEW05iGJP1NGVT0GV9[05]TJP1LHfD0G5iU05aUH`1BKf00AWMP04=oF`0oQVD0
<Xa_03:>H`0aPVD0=89M03^;EP0kQ5`0?hIN046=GP13TV40@iAI03j?FP0nTeP0?IYG03^MFP0iXEL0
>YeJ03RHG`0iUEd0=IMP03BOG@0203JXG00W03RXG00oWU`0?iEN042CF`11TE`0AH]I0565G01HOEl0
HfmT071TJ@1OJFl0D71]04UdK`16Lg00@GE`03mgM00nOGX0?7mk0421MP16OW80AWaZ04IcJ`11Lf/0
AGEV04^;CP1QYRX0J[0N072`6`1a[Ah0IjdW05fY<01JY3H0EY`m056Q?`1BZ4<0Dj]605NT?01NWS40
K:DS0080LjdG02L0NJ`@07Z^4`1c[AP0LJhQ07B_;P1b/300Lk4[07>b9`1_/b@0J;8T06Rc7`1//Q/0
JZhG06RZ6@1YZAT0J:lO062`:@1N[c80Hk0i066a>@1R/C`0IZlm06N_?P1_[CH0KZhf06j^=01][S80
KJP_06bS;01^Xb/0KJ<V07>T8@1fY2@0MZHZ072Q;01^XBh0JZ4Y06VP8P1WWR400P1WWB@07@1QW2D0
GiLX05nE;@1PTRl0II8]06BD:`1UVBX0HY`U06FR901WXb/0J:4b06FI=P1TTCl0IX]206Z:@P1YU400
J9`f06VO;@1^WRL0KY`W072B6`1bSQD0M8PA07N2301hO@D0LWP0071c001dK`00LfX00080M6`000P0
LFL006YO001/F`40K64206eW0P1[M`<0IH0406241`80H8H;02L0FhP:05J;301CTQL0BY/Y042L<`0k
VT80=hiH03>2IP0gPFd0=h1[03N0H`0mR5<0@h]504N2;@1>NQH0DW4<05Eb201FL0P0DG<904]g3P16
PAT0?H`Y03JB;@0dU2`0<iHY03>F:00dU2L0>8lT03b88@0mP1`0?gPC049Z2@15G0<0BDh104U50016
?P00A3D0048b000n:P000P0m:@004`0j9P00?2H003TU000h9000>B@003DQ000c8000<Qh0034N000]
7000:aX002TG000U4`008a<0028C000Q4P0070l001T>000I3000303oool000X0oooo;00000020040
0080000000D00@000000000100000@0000800002004000d000000P01000080020@00100000D10006
0P002@<000`5000@1`0050T001<7000A1P004@L001<<000G3@0060`001`9000J2P006`h0020@000T
4`00:aP002dG000Y5P009aD002<F000R4`009QH002LI000W7@009aT002dK000b8000=RH00P0g9@00
9`0g9000=B@003XW000j:000?BX0044]0013<P00AS@004@f0014=000ASP004Pj001<@000DTD00516
001?B000CdL005E9001EC@40EeD205IR101GK@X0EgPD05J17@1CQBh0CX15059ZF01LA6H0KCEF06/b
F`1X<V80Ic]H07=7CP1/D5/0JU5U06E>K`1CBGd0AT:;02]?TP0201]AV`0W01e@U`0WAiL09DNE01Y<
TP0BD9404Un@01=^U00GMiH067JH01agV@0OMY/07VbN029KV@0UB9P0:DbG02YETP0YGi80;FN903E]
O`0jMG@0?GYb03enL@11PG40@X5b04AoL`11NWP0?7=l03EYP00_HH00<V=i039TM@0eJ780=W9]03Ah
JP0dO6D0=XIL03V;F@0oReh0@gmW0080@fid02L0BV=g065GMP1nAWL0PD1e07Y1L`1i@6l0LDU[065<
JP1FDFl0EUi[05ESKP1FI6d0FUiX05eGJP1HHFP0CFaW041aIP12N6D0?H9]03B;L`0eQfH0=giT03b1
G00nR5L0?h=N042:G`11Te`0AYQL04FFE`11T5T0@9=J03fKF@0mWf40>j=J03VNF`0eVeh0=Y]M03JM
H@0eXUX00P0hYeP09`0kYeX0@:5F042LE@12Te80AhaB04b7D01FP580GWiC06IdH01^JfH0FgE/04f0
J@14PVP0A85/0425KP0mRG40>H]c03V;NP0nQWD0?h9h03n5K`0kQFl0?89]0461J01:Rdl0IZH^076]
9`1i[200N:`P07B`7@1W/Ah0HjlQ06>^9`1R[b`0HK0a05n_=@1X[RL0M:XM07^Y5@0207f[4@0W07V]
4@1c[1D0L:hE07B]5`1d/1l0L[<Q07Nd9@1b]2L0KKDW06Jd9@1Z/b@0Ik@R06bc6P1//1L0KJ`H06b_
701W/R<0I[4]06Bb<`1W/Bl0Hk<a06Jc<@1X/S40KK4e076_>@1`[CT0Jj`j06ZY=`1ZZ2`0K:HW06jY
901`YR80Lj@X076V:`1]Y2`0JZH^06RT9P1WYB80I:DT0080HjLZ0200H:0^062H<@1OTC<0H8dd06>:
=@1UU2d0I9`[06:P9`1PXRT0Hj8_066L=`1PU3d0HXi506B;@@1XSc/0JY@e06^F:01^Ual0L9<F07><
501jQ0h0Ng/807Qj1P1fN@D0N7/107ah001nM000Nfh007UY001fH`00LF0006eJ0080JUP000D0KET0
06mS001]KP00JW/206>00P0205j71@0W05R91@1FS`/0CiTH04:P:00kXST0<iYA0323JP0cLFX0=G5R
03ifD016NcX0Cg`Z05Yf7P1MJA00GF@605mQ0`1RH`80I6H105eW0P1HK0@0DW8804Im3`0nPaD0=h`K
03F=7P0cSah0=XdM03b65`14OA80BG<?04UV201:E@<0Bd/004Q40017?P00ACP004@d0010;`00?R/0
0080?2P000h0>RH003TU000g9@00=RD003@Q000c7`00;ad002hL000_7P00;A`002hK000U5`008aH0
028E0080818000<06`h001P<000G2`00303oool000X0oooo;00000001P010@000P40004000010000
0@40000000<00P4000<00@000000000000002@0000007P0100000P00004000010@000P4000@10005
0000208000T3000>1@004PP001H9000E3@0060P001<9000F2@005`h001/?000P2`008@d0020=000P
40008Pl002HE000/6@00:aP002PI000W5P008a@002DD00809aP000D09aX002XI000_7000=RD003XX
000203`Y0080>BT000/0>R/003l[0011;`00A38004Lf001;>000AS/004E10014@P00AdD004a50002
059?000H059E001AF@00E5h305QV101HL@/0EG`D05>68`1=RcD0AHE504EfE01<GfD0FDQZ06`hH`1f
;5X0HRIR06L^D@1Y@UL0J5=S05eHJ@1YBG40H4Ii04a3Q@10?I<0:T:I0P0R@Id09`0XA9P0<T2E02a5
T`0NC9804E:B011MU00AJIL0572H01I[V@0GIid06F6N01eMV`0REiH09djC02eAT@0]FY80;FBA02m/
S@0fL840>WEf03aiKP0mNV/0@gQb04AiL`12NGX0?GEo03Q_P00aIGl0;EYm039IN00dGG<0<f5`03=Y
J`0cK6`0<g1Z03EgIP0hNfH0?WU^049`M`0204=WPP0W04aIPP1PCGl0MCen07XoN@1h@W80NDA]06a8
KP1OC6l0EE1_05ALJP1DHf`0Dem^05INJP1JFVd0F65^04aXK011HVl0@Fe_03ehM00jOWP0>gaV03Yh
H@0lO5l0@H=N0421H010Reh0@IAI04:JF011VE40?IA@03nED`11W5T0?:1T03VSG@0iWeh0>IiO03ZP
G`0hXV<0>ZAO0080>ZMK02L0>Z=H03nOE@12W4l0A9E>04F@C@17SDl0Ch]?05B8DP1IPeT0GWeT05>2
I@1;RV00A95R04BEH`11Vf40?IaR03^LI00kVFT0?I9/03f?L@13UVT0@IYX042EJ013RfD0Ci1C06VT
=P1eZ3@0NJ//07f/8@1h[aP0Kk4F072`601e[ah0MZlR07R`9@1i[RD0O:/S07^/7@1nZQ/00P1lZaH0
3P1i[AT0LJ`F07>Z4`1fZ140MJXF07J_6@1f/bH0LkDZ06je:`1[/RT0Jk4Y06fb9`1/]Al0JK8M0P1Z
/R005`1X/Ah0I[8T06Vb;`1Z[c00JK0_06Zd<01/]300K;<c06b_<P1[[3P0J:Xe06NW;@1XYBL0KJTS
06fZ:@1_Z2H0LJDV072T9`1]Y2D0JZDP06RR7P1TY200HZPX0080H:Lb01H0Gj@g05jL=P1LUCP0G9@g
066G<`1UWB/0Hj4X066U:P1PYC@0Gim405f@C01PQDd0HX1;065mA01XR3d0Jhhc06j?7`1_Ra40MHH>
07Yn2@1lMP<0Ng800P1iL@003`1kL`00P7@0081^001jJ@00MV<0075M001^FP00JUD006mE001_E000
LUT006mQ001^JP00JgD006Mm0@0205n30`0W05R91P1BT0/0BiPC046M800kX3P0<iiA02n@GP0bQED0
=h1104Ek901DLA40FVX:069R1P1REP<0HUD1069E001UF000I5`0065N001LH`00FFT104ma0P16N@D0
?gh:03n03`11O`l0@W`=04Ab2019JPH0DF45051E0`1CB`00D4<004ho0017>P00B3D004@d0012;`00
@B`00080?2/001<0>2D003DU000f8`00=280030N000/7000;QX002/K000/7000:Q/002/I000X5P00
91D0024E000Q4`007Q8001X>000F300050`000`0oooo000:0?ooob`0000000@00@40008100010000
00000P01000200410003008000000000000000H000000P01000200<0000>008000020@00108000D2
00070`002`8000h3000:0`003`D00107000B2@005@`001T8000F2@0201D:000;01/=000M3@008A40
02<B000T4@008Q80028A000U6000:aX002TK000X6`000P0X6000200Y6000:AX002/N000/7000<1h0
03@T000i;000?Rl00P10<0009`12;P00@Bd0048`0015<000AcL004I00017AP40BDD104U50018B@00
B4d104U=0019D`00CeX0051Q0P1>IP<0C6l7051e301BOA@0CXXQ04b=<`17QTP0@GUF03aYHP18DG00
Ed1`060dK01Y;W00KRYR064RH01`<TP0K4MM06AELP1@EgX0CT^004A8Q@0i@Hh0=C^H02XeWP0202Xa
X00W03HgVP10>Y80>4>B02A<T00EEI004ejB019WU`0GKYT05fNL01YIV`0LC9X084bG029?TP0ZDXd0
;EZ<02mOSP0bIhh0<fj803MbP@0lLgH0@75^045XK012HG@0@fUg03i^OP0eKH80=G5o03=]O00dJgX0
=V]c03E[KP0cJfX0=71T03E[IP0gHfd0>fAa03mMN`17Egl0CEB50080E56802L0FTV606A0P`1]=HH0
Lcak07A5M01cAG80I4Qb05I;LP1>D700C5Y/04mNK01@GVd0DV5]05=UL@1DIFl0BfE^03aMM@0nHg<0
@6Y_04AYL012Kf@0?W9S03igH`13Of<0?h1Y03n:HP0kUe`0>imG03fMC`0hVdh0>J1@03bSE00mYEd0
?:IJ03fTF@0oX5d0?j9Q03jRJ00mXf400P0mX6009`10W5h0@iQE04BDCP14Td/0@i9=046CC@15TDd0
Ai5=04b=E@1?RUl0BhiN04VDG017WU/0A:MH04B/E@13[5H0@ZIH04:SFP12W5d0@YUR04:UG`14Z6<0
@JES04NOG`1EWdl0KZHk07>T?@1iY3@0OZLZ07^]7P1a[aT0N:hM07V/9`20[2L0PZ@Y086R9`1nXBH0
OjLO07^[6`0207Z[6`0W07JX801gYaX0NZ8@07^P3`1lYQ80N:lJ07>b:01a/bd0L[4_076`;P1^[bd0
Jk<[06Bd901O]B@0I;D/06Fb9@1S/b40Hk0U06V_;P1_[380Kj/`06n^<P1_/C00K;4d06VX>P1VWd00
IIdf06BN<01XYRh0JZT]06fY;@1[YbX0K:@W06^T8`1/YQh0K:@G06JU6@1SY1h0HJLZ0080GZ@e01L0
Gilm062L?01MW3h0FYm005VT>`1LXc80GZ4_05fV>01KXD80FY5>05^7D`1OPdX0I89006b0<`1cPBX0
MhHP07J04`1cOP`0NG`507ad0@20L000OV/007Y[000207a[000>07][001lI`00MfL007ER001dG@00
Ke/0075H001^F@00LUH0071H001bG`00LVL006eb001WN`0205in0P0W05b41@1IQ`P0Bi4@046F8P0n
Vcl0?IaA03jIC`11SSX0AglP05I]2@1MH@40HeT0065E001VD000He8006AE001UE@00IU`006=Q001Q
HP00GF@005UV001EJ@40DV/304m/1P1?JPH0CfD404mL0@1DE@40Ddl005A9001EA@00Dd4004i0001;
>P00BCL004@e0012;`00?2X00080>2L001<0=280030O000b7000<Qd0034L000[6`00;A`002/K000Z
6@00:AX002XH000Y5`0091H0028A000O3`007@h001T<000G3@004PX000`0oooo000:0?ooob/00000
00@00P0000<100020@000@000P010@000`0100000@4000410009000000800P000P040@000`050@00
1`8000T5000200`5000>00h5000A1@0040D00188000C2@0060X001P9000H2P005PP001X:000I3000
7`d001lC000S500202@E000@02LE000V5`00:QH002dM000Y7000;A/002lO000Z7@00;Ah002lO000b
7P00=24003TR000i:000?Bd0040a0080@cD002L0ACH004Dg0016>000C3/004m5001@C@80BU@304YE
0P1=E@80C5T504]Q2@19IPX0BF/;04Yc3P1:N100B80C04J67018SBH0BHhc04F<A014Pe80AFmP049I
J`18D6L0GT5^06LgKP1U=F<0KS1X06lbG`1W=5h0J41Q069@K@1CEgP0AU:804A2TP11?iD0?SFL03df
W00f<Yl00P0g;Y`09`0i=YL0>SbA03A3T00VBY006U:?01QJS`0GHYL06FVO01iQW@0OEI/084FG02E7
U00VDhl0:Uf<02aVS00^KH/0<G>803AhOP0kNW@0@7A]04A[K@13GW40A5Ie04=OMP0oI7X0>F1o03Y_
O@0iMW/0>GUj03]iL@0jN6d0>7=Y03QcH`0lJFT0@5Qg04YAO@1@Ah@0FD280611Q`0206I0QP0W06hl
Q01`?XD0Lc^707=1O@1]AW@0I4Id05Y;L`1ACW40BTmb04eIJ`1;F6X0CEU_04aQK`1=I780CVI`04=V
L00dI7T0=fm/03]dI012Mel0AGYJ04AjF`14O5h0AH9O04:4I`0lT5d0>IUJ03JOF@0iX580=J=B03VW
D00kYE@0>j1K042RE@0oXUL0?:=M03bUH`0nY6P0?Z5U0080@9iY02L0@iaP04BGD`17UDP0AIQ404JF
AP13UdH0AII304NDAP1:Sd/0BHe@04R?D@18UTl0BIm:04ZZBP18/D/0AZe704RYBP17Z4L0AjQ604VX
B01;[4X0C:eI04j/FP1AZe<0GJM<07:V@01hXT00Nj@h07jY<@1i[BT0LjlW07V];01gYcT0Oj4l08JF
@021U3T0O9<f07VY901f/1h00P1i[b409`1hZb80NJHI07^R4`1lXQ00OJTB07V_6@1a/BD0LK4Z07B^
;@1`/2d0KK0^06Fc;`1R`2d0H/0W06Zc8P1^/B00K;0O06J`9P1V[bX0J:l]06j^;@1_[300Kjlc06^`
=P1YXCP0J9@l06VG<`1YVC00Jj<^06fX;`1^ZBh0KJ</06^L:P1XXb@0IZTR06NY7@1UYA/0HjDP06>V
;@02062U>`0W066R>P1RXCP0Gj8l05ZYA01LYdD0FYi505VKA@1KWd`0FXmD05imD`1PQ500I8A306Z3
:P1_P1T0LWLB07Qd3@1fL0P0MFh407e`0P1oK`00Pg8007m`001mJP00OFP007QV001iI@00Nf<007YW
001fH`00Lf80071O001cG000KUX006mH001/F000KU`006iP001/J000Ifh00080HW0102L0GWX205an
101ARPh0BY<R04VD<P1=TcP0Dhda05Ik7`1JJ0T0H5d1069F001SD`00He4006I=001SCP00HUD006=G
001XF`00IUd006=O001QG@00GeX0061J001OE@00G5<105eE0@1MDP00FT`005Q:001DA000DD00058o
001@@000CC/004/i0019=@00@c8003l/000j9P000P0e8`004`0c7@00<A/002hH000Z6@00:aT002lJ
000]7@00;1/002/K000W6P00:1L002LH000T5P008Q<001l@000M3P006@`001P;000C2P00303oool0
00X0oooo:`000000100100000P40008100010002004100<00@0000<000000040000200000`010000
0`0000000@000040000200D1000H00D200080P002P@000X6000>20003@X00108000B1`0050H001@:
000C1P005@X001L:000H3P005`l001/=000L40008A8002DC000R5`009QL002@F000W6000:QX00P0]
6P000`0_7@00;B4002lO0002034Q000803<S000d9000=B<003PU000h:@00>B`003d/0011=00204Dl
000W04]0001:?P00BD4104e40@1>C`<0BeL704]O2@1;H`T0BfP=04a]4`1:MQP0BG/K04N18014QBD0
A8/[04B?=017TT00Bh];0561D01BNUT0D6mQ04mMIP1DCFL0IdAR07hmH01f=F00K2iS06laH01[@5l0
J4eM061BL@1VCX00GDR604i2S`1=>ID0Bc^H04TfX015>9l0?C6O0080>2bK02L0=SRD0350T00/AXl0
9DZA021>T00ODi<085VJ02IMWP0SEj0094fJ02I3U00[BXh0;5N;02aVS@0]Khh0;gB;035iQ`0hNgP0
?Ga[049hI`19LVL0Afa[04MUKP16Ifl0@fUb041UN012Lg@0AGea04J1LP16P6d0@WY]041_K`11K6T0
BUib05U:O01QB7l0ID6506`kQ`1]?8D00P1c>X@09`1e?X@0M46107A4P@1_AWX0Hdad05Q>LP1CE700
CeA/04iBJP1=EVX0BeM[04UFK01:GV/0BEi`04IRL@0mJW@0;Vmj035jJ00hP5/0?X5J04B4E@18PeH0
B8EH04N9F@13Seh0?YMH03RKEP0cX5@0>:9B03VUE@0jZ580?:5F03^DG@0nUeP0?IaJ03VMH00mWV80
?J1U04:MH`0204BIJ00W04>LF`13WTX0AIe004VO?@18WC/0BI`f04^L=01;VSP0BYLj04ZE?P18V3`0
B9dl04bT>`1?[Cl0DJi204n[A01@ZTH0CZe104j/=`1?ZcH0Dje005>_D@1F/4h0Fji806NVAP1fWch0
NiE307^P=P23Yc<0OjT^07VY<P20Y3P0NiM6086EB02?RTT0PY5307JF?`1g[B/0Mk<V0080M[8V02L0
MZlV07R[7`1iZ1H0NJHB07N[4`1h/a`0M[4W07N`<`1f/3L0MK4b06nb<P1[/S00K;@^06bd9`1^]1h0
L;<L06n]6P1`/Al0JK8U06Vb:@1[/Rh0Ijda06Za=P1Y/S`0K:Hh06^M<P1^XBh0KZH[06jY9`1_ZRT0
KZT]06fT:P1_XRH0JjDR06RY7`1VYad0IZHN06BU901QYBh00P1PY3H08@1NX3D0G:4`05ZT=P1IZ3h0
EjE005ZRA01IX4P0FiQ?05f2D`1PKe00JGE806el=P1_O1/0LW4:075Y0`1cI000LV<007IX001iJ000
OFX007mZ0020JP00OFH007]T001eH000Mf4007UQ001hH`00M680079O001aG@00KEL006UD000206UB
000406MD001XEP00JEd006UQ0080IV<00140IFT006Ea0@1ONPD0G7l<05Yo501LO1D0H74B069U201R
E`40H54006E?001RCP00Hdh0065@001RC`00HU8006ID000206IG000406AG001SE@00He8005i@0080
GDX000h0GDH005a8001LB000F4@004ln001>?000CCd004`k001<>000BSP004Xe0016=000?Rl003`]
0080>B@001<0=1l002lM000_7000:QP002XJ000Z6@00;1T002/G000[6000:1P002LE000V5`008aH0
028C000N4P007@h001/=000E2P004@T000`0oooo000:0?ooobT0000000H00@000081000100000@40
008100010002000000800@0000L00000004000020@000`40008200020@000@4000800P0001L00`40
00@200040P001P@000X6000=20003`L000h:000A2@004`L001D:000D2@005``001T>000L3P006a00
01hB000P5@008QD002<B000R50008aD002DF000202DH000A02TH000Z6`00;a`0034N000d7`00<b80
038T000f9`00>2H003TX000j:@00>BX003PZ000j;`00?300044c0016?P000P18B0009`19CP40Ae02
04]@0`1<D`<0B5/804QU4019KAD0Bg8F04ai7@18PBD0AXP^04>;<@10T3d0?Y1503f@B`16ReP0D8=R
05YhH@1OKUl0GfMV06=NJ@1WCfT0KTaP07Q6FP2@=5/0PC5D07@WF`1]:eP0IC]K06M7F01JDGP0HTV=
0611T@1N=I40H36A05XfW01E=ZH0C3NS044^XP0203PXV`0W02lfU@0X@hl09DV?02E9T00RBY<09TZE
02e:VP0cAih0<DFL02m3V00]@9D0<4b@02iNT00]Khh0;WR?031lR00bNX40?7a`041jJ015NVL0AG]V
04AiJ`11MG00A7E_04EdL@13Lg80BG]W04b0HP1<PV<0DH1R04]fJ@17IG00B61e05eCN020@gX0PT9i
08=0O`22?H40NSio0080NSn202L0NdB007U8OP1eBg`0JTih05i@LP1;E7<0BeU/04iLJ01?EVT0CeMY
04UKK@16G6l0Bf9/04AQK010IVd0>W1^031hL00bPFD0>8YN03f:G@11REL0AhEI04R8F@14TEP0@I]N
03jLEP0hWE80=iiA03bPC@0kY580>:IB03VJEP0jQV40?hUO03b;H`0lT6<0?IMT03fKH`14Uf<00P15
U6<09`17Ve@0Aj9304VO?P1;XSd0C9li056Q<@1>Wbh0CI``04^H=@1<UcD0CYTb052P<P1@ZC40E:dc
05Z/?P1IZS`0FJU005R[>`1H[Bl0FZda05^/=01L[4<0IJi506R[@`1_Y4<0NI=107Z0A@1kTSh0O:8i
07VP?P1jVT00Pi1308MoC02@Qd/0UXY:08:HB@1bYd<0MK0j07N`<`0207>_;P0W07:a9`1e[1d0NjPG
07FX501bZaD0Mk8P07Bb9`1d/bh0L[8g07Fb=@1f/C<0L[0`07Fc:`1^/bP0KK<V06fb8`1][a`0K[8K
06Ra8@1U]R@0J[D/06R`;`1W/C40Ik4e06b/=@1ZYc<0Jjd^06Z];@1[ZRd0Jj`_06^Z;`1]ZB`0KZPU
06fY8P1[Zb40JjPO06RY8P1UYbL0I:<b0080HJ8i02L0GIdg05bK=P1IVc/0FYm005VP@@1GX4L0EiM9
05V9CP1MQ4P0IX0l06mn9`1fM1T0Mf/=07=S0`1dG`40L5`0079M001eH`00N6H007YW001mIP00MfH0
07QR001bH000MEh007MM001cF@00M5T0079H001]E`00KeT006aB001YCP00Idd0065=001UD000He<0
06EG001VF@000P1VG0007P1XG000Iel006IX001SJ040HFD1065R0@1UF040I5@006=>001RB`00HT`0
06A>001RC`00Hdl006I@001UD@00IUD006M@001VCP00He00065?001PC@00G4/005]4001I@P00FT00
05Y3001HA000E400054o0080D3/000L0BST004Pi001:>000BCH0048d0010<`00?Rd00080>RH000L0
=240030N000_7P00;1/002TJ000Y6000:AT00080:AL00P0W5`00200T5P008aH0020A000N3`0070d0
01L=000E2@0040P0303oool000X0oooo:@0000000`020@00108000410002004000@000000`010000
0`030P000P8000@1000200800003004000040@000`<000801P<000`02`@000d8000@2`0040/001<9
000C20005@X001D<000G2P005`l001dC000R5002024E000302PG000V6P008aL0008091@001@09AD0
02HG000V5`00:AP002XK000_8000<b8003HR000f8`00=bD003/X000i;@00?Bd0044^000o<P00@S@0
044g0011>@00B3l004a;0P80BUH502L0BEh804MT2@17H0P0Af@904MZ3`19LAP0AgXN04R08@18QBT0
@hT`042A>`0nUcl0>9Y503RBC@0iQe/0Ag]W05IWM01SH6X0IF5R06EMK@1^DW00LdeZ07i6F@21B4`0
QcU<07HcD@1X;eL0GCQH04a6IP1:C7D0Cdj=06TjX01^<IT0Lb>@07@US01Z;I/0HRnW05@^Y@16:Yh0
0P0m:IP09`0i=I<0=46@0398T@0`BI<0;4ZH02i9V00aAiX0=4>K0391UP0`@Y<0:d>C02eCT00]JHl0
;gN=02ekR00cNGh0>GEf03ejJ@0oNfL0@WaZ04>0J@0nPV`0?Wia03inL`0oP7<0?gmc04AoI@16PEd0
Bh=K04ioGP1:MFL0AF=g04mJO01`CWT0Ucib09LnM02??W/0QT2208=6N`020857N00W08A;M`21CWH0
NTai06Q>M@1GDg<0A5Eb04EMK@18Ff/0BE=]04aJKP1;GG80BV9_04MVK012JF`0?Fi[03MdJ@0aNFT0
=X9S03Z7G@0oREd0@hQH04B9F@15SeP0B9IL04BNHP11WV00?IiJ03bOD`0nWdh0>ImD03RNE@0jVUX0
>99P042BG@13TF40@99R04>AH@15TV00AYEK0080AIUG02L0Bia804jQ@01BWcd0Dj4g05>R=@1DX2h0
E9P_05:D<`1?ScP0DHdk05BB=01NWC00Hj@d06BX=P1/YcH0IZDe06>T>01QXSL0HjHc06RT=01WYSL0
JZU006nVAP1bXd@0NIQ707Z8B01gNDX0NHM307^@@P1gTd40P8]908J0B`2GK4h0VWY;09j4B`20WTH0
K:]5076/?@1cZD000P1/ZST09`1X[RX0LJdR07JX6`1bYa/0LZPK07>/7P1`/BD0LK8/06ja<01g/S@0
MZla07:_<01]/R/0JK</06Jb;@1P[2`0I[0R06Ra801U]200J[@R06^d9`1X[RX0IK4/06>`<@1X[S40
K:`a06f[<@1YYc80JZX_06^[;P1Y[2h0Jj/X06b[8P1Z[280J:/T06VX9P1XZb`0IjP`06VW>00206BS
>00W066O<P1QVc00HYhf05nO>`1PW3h0GiI705^3C01PM4`0I8<n06N79`1dOA80Lfd607MS0P1cG000
L5`007=I001eG@00N68007UV001iI`00N6@007ET001hI@00MV4007IN001dG@00MEP0071G001_FP00
L5P006aJ001YEP00K5@006U?001WC000Jdl006EE001UFP00J5H00080J5L000@0J5H006IG001XEP00
I5T00P1SD`001@1YD000IDl006A>001SC`00HTl00080He000P1UDP00601UE000J54006MB001TD000
HTh0069?001RC@00GT/005i7001LA@00G3l005U1001G@000FCd005I0001C@000Dd4004Xl0017=`00
B3P004Hb000o<P00?Rl003dZ0080>2L001<0=B4003@O000a7000;AT002`H000X5P00:1P002PG000W
5P009QH002DF000S5@008a<0020B000L4@006Ph001@=000C2@003`H000`0oooo000:0?ooobT00000
00<00@400081000100001P000003004000800`8000H00`4000<0000200000P4000@10005100200/4
000W00h6000B2@005@`001D=000D3@0050/001H9000F20005@X001`=000S5@009aL002@I000W6`00
9a`002TM000Y6`009AP002DJ000W6`009aX002HH000T5@00:QH002`N000d9@00=R<003DT000i9@00
>bT003h^0011<@00ACH004@i0017?000AT4004E60@15C@80AUT60080AfD=02L0AF/D04=^4`1;K140
Ag0B04Qb6P1:NB40AglU04J;;P0oSc`0>Ha903R<D@0eTDh0<hm@03R2E@0lMF00A6YZ04iLK@1IDVX0
ITa[06Y8KP1`AVP0JdmO079@D`1nBDL0Oci706XhC`1M<ED0E3mF04A?K@14CX00E46;07<[UP1h:Xl0
ORF607XYQ`1^:9P0Ib>U05XTX`1?9I`00P17:IH09`15<i@0ACbB04=3TP0mAYH0>DZI03U9V00hAiL0
=d>E03=3TP0_Ahd0:Dj=02aOS00]K8/0;WJ9031dP00bM7D0=Vi^03afJP0nOF`0@HE`0465K@10R6X0
?hE^0464L012PW40A7aa04EmI@17Of80BH9R04QoHP19LFh0C5Yl05]@N@1gAG80VC][090lK026>gT0
Od:407e>N@0207UDL00W07]FL01jEg<0MEUh06QKL`1IG6`0B5]Y04YKJP1=F6l0Ce5d059FLP1DFg40
Df5_04YYKP0nKG40>g9`03EeJ00_LV`0=WiW03^4HP0mPf<0@hYM04>AG`15UeX0AiYJ04JNH@16WEd0
@9]J042KD`10V4l0?HmF03^DG@0jV5l0?9IT04JCH@16Tf<0?iEX042>I`10SV@0@YYB0080A:9302L0
CZ8k05JO=`1KW3H0GYd`06:L;@1NVRh0GI0g05b:>@1IP3/0Fh8i066:<`1/TS80MiHb07VI<P1oWBl0
OYdc07BM<`1bVC/0NILi07JE=`1bVcL0L9hm07RN@`1jW4@0P99807^8B@1jOD/0OH1807j5B020QdP0
Sh1?091gBP2EJ580U7E<0926BP1kWT40KZ@m07BV>01bYSd00P1][3d09`1[[bl0K:lW06f/8P1_[B80
L:dS076]8@1^/2H0JK8/06b`;P1b/Bl0M[4^07>b;01//b/0Ik4/06V_;P1^[R/0KK4O072`7P1^/A`0
L;8N06n_8`1[[BH0Ik8X06Bc:@1W/RL0JjlX06^[;P1]Z2d0JjX^06V[;@1XZbh0JZXU06RZ8P1X[BT0
IjT_06RU<`1UZCP0IZa006BZ@00206>Z@00W06:W=P1QYC40G:8f05jM>`1NV3`0GY8l066;>01UORd0
LH0P07Qo501hM@P0MfT107IP001cG@00KUX0071I001fG@00NF<007QV001gIP00MfP007IV001fI@00
MFH007=P001`G000LEL006mF001`EP00KEX006aL001/F`00K5@006QA001TC@00HTl006A?001TD`00
He800080Hdl00P1PC@009@1PC`00H4h0065=001TCP00Hd/006=<001OC000HD`006=>001QCP00HT`0
06I@001WDP00He<006Q@001VD000IDh0065>001RCP00HDh0061=001PBP00GTL005Y2001I@@00F400
05I2001G?`00E3h0054o001<>`00Bc@004Dc0012<@00?S0003hY000l:0000P0h9P004`0f8@00<Ql0
030K000/6`00:AP002LF000W50009Q@002HE000V4`009AD002<B000Q4@007Q4001/?000G300050/0
0149000=1@00303oool000X0oooo:000000200400003004100000000000000D0000000D00@000000
000300000`4000@1000200D2000400L100060@001`<000X400802`H001/03`T0018:000E3@006Pl0
01X@000I3@005`/001H:000I2`0070l0028D000V6P00:A`002`M000^7000:Qd002XN000[7P00:A/0
02PL000V7@008aX0028G000V5P00;A`0038Q000e9`000P0j9P002P0l:P00A30004Tf001;?`00CD80
04U5001;C040AeT404EP2013KA0203ec6`0W03ai8`11N200AWLJ04Ii7018O200A80Y04>7<@0oTSl0
?9=903V=D00iQU40?7]=045bD@12JUP0A6IN04IMHP1@DV80Ed]P05m1I`1X?VD0JT9S07=;E@1jBdh0
PTE<07lhD01Z=eL0GCIM05A3HP1<CW80E4Ii068bP`1g98@0O2R2084ZOP1j:hD0L1nD06dBX@1R6Il0
F22J0080DBRF02L0E32D05PgU@1E?YH0Cd:H04]6V@17B9@0@DJB03U4T@0bAhl0;4j<02MIR00/JHD0
;g2702ibR`0^Kh00;f]f03=VL@0hM780?85d03n<L`13RV`0@hQV0425IP16QVL0Bh=W04YjJ@1=NV@0
DGiS04f2IP1:PFX0DFa^06E=L`1c@fd0QSY/0:8cJP27>V/0MSYk07E0R@1_CWX00P1YEg809`1YFW80
J5ee06ILO01OH7<0EV1Z04]NJ@1:GFd0C5Ue04e>OP1?E7D0CUIc04eNL014JG00>g1d03EbMP0cM6d0
<75^03MkI`0oNfD0@WMU04>5H013U5l0@YUL04>JE`14WE/0A9UH042JEP0oVU80@iMA03j@G00mTEd0
@IAR042CJ@15Tf<0A9=W03bGJ`0lUV/0>IaP042RB`0204JU>P0W056Q<P1KVS00H9La06:I;@1SURX0
Hi8Z06B<;P1ZRbh0K8P_072><01dSR`0OH/T086:8P27S1l0SI<[08VA>@1iV3P0M8m207V<@01kS400
NI1007RE?P21Td@0OI94082>B01iQ4X0NGa<07mnC020Me80S7e<0:1lBP2FLDh0UfMA08ihC022QDT0
MIA006fC?`1]WSP0L:Hl0080KZdo02L0Kk4`06fb8P1/[ah0LZlP072_8@1a[b80KK4T06j`9`1_/BT0
LjlZ07F_:@1c/RX0Kk<Z06Zd:P1_/RP0L:lU076[7P1eZ1d0LjlP07>_8@1a[b@0KZhS06f_8`1[[b80
JJ`Q06j/901`[2P0Kj`W076X901_Z2T0JjX_06bX9P1ZZB40JZXY06Z/<P1VZcP0IJ`o06:_B01Q[TT0
0P1PZdP09`1PYd<0Hj50066K@@1STT00GX/k06>;<P1WRb@0Kh0C07=`301iJPD0M6H107=S001_G@00
KUP006aF001]EP00LET0075L001cG000MEd007MP001dG`00Mf4007MP001dG`00LUT0071I001^D@00
JeH006]G001YF000JE8006Q?001RBP00HDP005e5001PAP00GdP0065:000205e7000605i8001PAP00
GTP005i9001OBP00H4X00P1PB`007`1PBP00HD/0065<001OB`00HDH006==001SC`00I4l006E@001V
D@00I54006E?001SDP00HE4006=@001QCP00GdL005i3001J@000E3l005<m001B?@00CcT0058k001;
=P00Ac4004@a0010;000?Rd003d]000l:`000P0l:0002P0h8`00=2<002lL000/6000:QP002HG000U
50008a<0028B000R4@02028B000701hA000L3`0060d001D<000D2P0040L000d5000<0?ooo`002P3o
oolX000000030041000100000@0000<0000000D00P000040000000000000004000020080000800@0
00050P001`8000H40008100020D000`4000?0`02014500040189000C2P0050`001P>00807Pl00240
5`l001T=000K3@007A00020E000U5`00;1`002`M000[7`00;b4002dP000_7`00;1l002TQ000X7`00
9ad002LH000]6`00=20003/V000j:`00?B/003h/0012<000B3H004hn001@AP00DDP004m>0P1;G0H0
@fL>03ib600mMb000P0kNRL09`0nO2L0AG/R04Yj701<OAd0BX4N04J7:00oScL0>iA603RCD@0fR5X0
>G]J049XF@19H5`0BF5I04USE`1;GEP0E55N06E4GP1^?V00MC]J06Y2H01`AE`0Od1K08TnF01i>U`0
H3MW05LgK@1K?g<0K3if070gLP1f8WP0Oaad084VN@23:gX0P2R407`MTP1l4Y`0LARJ06LOUP02068U
U00W05l]U01N<iD0EcNG04`mV@14@YH0@4RB03Q>T@0`D8h0;EN>02eTQ`0[KhD0<7J2039fQ00bK8L0
=FR003IVN`0fIWT0>GUg03^9M`0mTGP0@8Y]0463I`0oOFL0AgeW04aiI01:LVH0DGAS051nHP1>QFL0
CGe/05eSI`1g?eh0OCaL08=0G@2K@5d0ODAO06e0K`1a@800J55f0080FeY`02L0F5eb05QNM01IGGd0
EUec05=TJ@1<Hf/0CFA^04]MMP1<Cgh0CE5f04UFLP15GW40?FYc039^N`0`L7T0;gQd02ioL@0iPVH0
A85Q04UnI@1<RUh0BiEP04JIFP16VUH0@YQJ04:GE@11V5D0@IUC04BGEP10UUh0@iEN04FCHP10T6X0
A99V04>HJ@11WFD0@jAR04:TF01:XT800P1?VcD09`1FUS40G98`05n?<01PSc00HXd/06><9`1ZQRP0
LH/T07JB8@20URD0S8Pc08^58P2=S1X0S8`N09:9<`27QdD0NX]40768B@1cQdH0N8M407J5@@1iRSh0
OY1307n=A`21Qdd0OH5>07]eC027L500SVQH09UgD02VMTh0WGA>09EbDP2;Nd/0O7e<07R6A`1aQD/0
L9A206ZRB00206ZXA`0:06^_>P1[/2/0K;0Y06ja:P1`/BL0L[0X07>a9@1c/B@0LK0V076`:@80Lk4Y
01/0MK0]06n`;P1c/BT0L[0R07:W8@1eXb80L:dU076a901`/280KZlM06f^6@1][AD0L:LB06fU5P1_
YQX0LJLM07BV8@1cXbH0KZ8Z06^S901/Y200JjDT06ZU:01WZ2`0IJXa06J]?P1UZD@00P1WYDD0401]
WD00LYTg07:D=@1`Qbd0KgdZ06]n7`1_OA<0LgH907E[0P1cI000M6<007EN001cF`00KeH006UB001^
E@0206eF000E079I001bF000M5X007MK001gH@00MV0007IO001eGP00Le`006aG001/E000JeD006YB
001VD@00HDd0065<001NAP00FdH005]7001QB@00GD/00080FTP00100GDL005i6001KAP00GDL005i:
001PB`00HDX00698001NB`00H4/00619001PB000Gd<006=9001TC@00I5400P1TD0003`1TCP00IE40
06=A001QDP00H500069=001NB@00FdD005M2001C?000CS/004di001<>000CcT004`d000204P`0004
04D_000n;@00>bd003XZ0080>RT001<0>BD003HR000_7@00:aP002XH000U5P008a@0024B000O4P00
7a0001lB000M4`007A4001T>000G3@004`X00189000>1`002P@000`0oooo000:0?ooobP0000000X0
0P4000410001000000000040000200000P400080000100000@400P0300002@040@000`8000D20008
0`002@D000X5000<1`003@D000d600030148000H01@9000F300060`001`@000N400070l001d@000P
40007a80028B000X5P00;Q/002hM000a8`00<R@0038P000_7`00;24002dR000]8@00:b4002`Q000d
9000?B/00P16=P003017=P00AC@004Pd001=?@00ED8005U;001FD@40DEd504Q/3P12NQ`0>H0/03R2
<@80>h8i02L0@8<b04>5:@13QRP0B8LX04B9;P0nScH0?IDo03VHAP0gUTP0=HY@03EnFP0oK600AEY/
04aEI`1IDF80HE1T06E>IP1_AFL0MS]^06llI`1V>VT0KcMV08HbJP2K;fH0Q3AS06/dJ@1X=fd0KcQg
084bN021;780PB9`088QK@1o9W/0OB>6080QS@216i@0QQJI07/KUP1a8I800P1[9i409`1X;Y@0Hc>H
05TfV01=>IH0A3bC03]8SP0bE8/0:Eb902QVRP0/KhL0;WV5031jQ00dMh80=W2403a`O@0nMGL0?Gaf
03j8MP0mSWH0>heg03n1LP10MVh0@F]`04Q]J`18KFL0AVMX04e[H`1>MFD0C7Q]05A[L01VCf@0NcEG
07hiF01kA5/0PdYM0797GP1W@f`0HDAf05eEL00205AQK00W055VJ`1?HFd0D5Ua059IK01AI6D0BViS
04eYIP1=Gg00Cdam04]BM@0oF7D0>69e039]M`0/JWd0;6in02amN00[RG@0>hUV04J7H`1;Pf<0DX]I
052@E@1=U540CY=B04^AEP18Te<0A9AH04FFFP15Ved0?ieT04BLG`14TEl0>hYV04BAHP12Vf40Aj9E
04^SA`1?Wd00FYHh0080G8hc02L0HH/_06>::`1TR2T0I8LX06R58P1[PAd0LH0L07Z:7`1kU280Qi4X
09an:P2EP1X0VH<N08n6<028QCh0OW]<07N5B`1jPd/0NWm707amA@21ODL0O89707j7B021PD`0Ph1@
08AfC`26IeL0T6AG09YQGP2NLU80[7E;09MjC`2?MeH0QWa?07]kD01hR4`0LYA;07:QB01/Xd`00P1W
X4l09`1XZd80K:di06na>01a/SX0MK4e07Fb;P1g/RP0L[0V072]9`1^/2X0LJl/076`;@1d[300M:@b
07:/9@1^[1h0L:TK076W7P1bZbD0MK0T07Fa801d[QD0LJdA07BX3`1aXPd0KYl@072Q4`1aXad0KJ<W
06nM:`1ZX2l0Ij4[06bX:01[YRT0JZHX06FS;@1RXC40I:8i06NO?00206ZN<@0W07>G7`1hTQX0NXdE
07N34@1gO@l0MGD;07A]1P1eK080MF`007AV001gI@00Mf8007=Q001aG000L5/0071H001`E`00KeH0
06iF001`E000L5L007IK001fGP00N5l007IO001bGP00M5l0075L001_F000KUH006aF001XDP00ITl0
06A>001RB`00H4X006=;001TD000H4h00080G4/001L0FT<005I2001F@`00FD@005i6001MAP00H4X0
05m8001NA`00GTP005e;001LA000Gd@006A7001RBP00I4/0069>001UCP00IDd006I?001RCP00H4h0
05m:000205e6000>05]5001F@000Dc/0050i001@>000DS/0054h001;=`00BCD004Pb0013<000?c00
03`/000j:00203TV000C03HU000c8P00;Q`002/H000X5P009Q@002<E000O4`007a4001hA000P4000
7Q0001/@000I30005P/001<;000?20003PH000P3000<0?ooo`002P3ooolX000000800P4000D00@40
000000010@000P80008100030080000:00<000030@001@8000P3000:1@003@@000l5000>1P0040L0
00l700<040L002L04`P001<9000E300060`001/=000L4P0080l0024D000R5@008Q8002@D000V5`00
;1`002dP000b8`00=28003DT000`8P00<R80034S000a9@00<bL003PW0011:`00BSH004Xn001<?@00
CC/004Xi001??000ED<005a:001KEP40F5l504m]2P14NQ@0?H4M03V59@0kRBD00P0lRBL09`12RR80
AXdR04J?8@15TbL0?iH/03ZH=@0iVST0=iU003>DA`0aR5H0;GMW03Y]KP14FWL0ADao05Y8N`1XCG/0
MDA`07<lJ`1c=6H0L3QT06dgI01h>5h0PCMR08LgI01a?6T0Hcea06XlM@1l=GT0SRYj08dXL`299F/0
PBE_07/NP`1k49P0Q1BI08hGU`2F69H0RajB088RSP0207TWS`0W078^U@1Z=9X0GCFH04deU@12>8l0
>4J:031FQP0VHX<09VZ402efPP0_OH@0<g^003EeP00iKh00@7Ij049lM00nPWD0?hMb03j5LP0lP7D0
?W=e049[LP13IW80BFE]04MVJ`16H6X0B61X04eSJ01HGG00IDi_06lmI01k;5@0OCMK07a1IP1mBW00
K4=]05i3L@1?AGD0CeMa0080C6E/02L0AVe[04EVK015FVh0BUaX04aYG@1:L5X0Bf]S04aUJP1:FgH0
@f9`03i[K@0fMG40;gEf02MZO00XKW`0:geg02n9L`0kSFT0AXmS052:HP1ESUH0Di5D052@E01>T5@0
BHeE04R>E@13T5@0@IEE04BIFP12WV00AiaH04J>G@12Q600B8iD04ZKC@1BW3X0FYTW062D6@1YSQT0
0P1^R1T09`1`PaH0KGlG06mk5P1aN1<0LgT?07Ek301iO@d0PhXG07n?;P2<Qbd0ZgHG0:9l5@2KObH0
Th<k08F8?P1iOTd0OX1?08UlD02=ODh0R7U?08UjE01mNe80P7UB07iiDP20N5<0Sf]C09aPEP2IGeL0
UV9K09Q`C@2JNDh0SXAC08eoF@2:OU80PWa@07ZBB`1bXDD0KjY006ZZA00206bTBP0W06nW?@1_Z3H0
L[0c07Ba=P1g/C00Mk0/07Na:P1a[bD0KZX[06b[<01^[Bl0K:T]07>T<01hWS00LjLQ072/6`1bZQP0
L:`J076X9P1`[2D0Lj`S07B_5@1cZPl0LJT<07:S2`1_X0/0LYl?072R6P1^Y2T0JZ8_06RQ<P1WY340
JJXf06N/=@1XXcH0J9Lm06ND?P1ZUSl0KYTd0080LiTL02L0N94>07F<2@1gQ`D0NGl207Mf0@1dK`00
N6/007AZ001`I000Lf40079P001eHP00M6D007MV001gI000LF8007=N001_F`00KE@006eC001bFP00
N5d007IM001dGP00LUX0075H001bG`00Leh007EL001cG000Ke`006eK001ZF@00IED006E<001RC@00
H50006=@001OD0000P1QB`009`1LA`00FTD005]7001NBP00HD`0061;001OB`00H4H005e8001QA`00
G4D005a6001MA000GTX00658001RBP00I4d006A<001PB`00HD/005i:001OB000GDD005]5001G@`00
FTD005Dn001E?000E3/005Dl001G?000DSL004he001:<`00AC8004D/0010:`00?RT003/W000203HV
000C03DV000a8000;1d002`G000W5P0091H0024D000N4`007a8001d@000L400070h001T>000E3P00
4P/00107000?1P002`@000H2000<0?ooo`002P3ooolY00000006008100010@000@0000<100030P00
0`400P02000030030@001`4000L100080`0030H00107000@2@004`T00189000B2P003PP001870080
4@T002L04`X001D=000H30006@d001/>000K4000818002DF000W6P00:1L002DF000W6000;1T002hN
000`8@00<bD0038S000c8@00<240038U000f:@00>2X003l^0018<`00C3T00510001??000D3d00591
001DA@00FU0105eK0P1II`H0DW<<04Yl5012QAP0?hTJ03b:700nSAl00P0mSah09`12T1/0@I8K04:D
8@10VBT0>i`[03NL<P0fVcL0=9E1036:CP0bOel0=GA[039XN@13DGl0Ed5i06A3L`1ZD6h0Ld1_06/f
K`1W>FD0JCiP06a1F@1c?5l0LS=W07@bK@1/>Vh0Kcm^07XjM02=:X00WAeo09HRM@2<9FT0Q2Aa080J
Q@2239H0Ra2@098FQ`2J6X<0T1b308PQQ00207`XR@0W078]TP1X<i/0FcBH04PhT`0k>Xl0=TN802mL
P00ZIg`0:fih039aMP0bMGT0=g=h03UcM`0jLWX0?gUe03enL`0jOGH0>Wad03ehLP0mKGH0?fQe04A/
M014KW80AVi[04E_J@15IVd0B5Y`05EDK@1Y@W<0NCa_07hjH@23>580QcmH08Y1KP2>@840MT5l05Y0
MP15A780AeY`0080A6]_02L0@7A]03mZJ`0lG6`0@5aU04ETH016J640AfEV04IWJ`13IG80?G5[03Uk
J`0dPG00;Wea02UcM`0YLgP0<H5b03F:LP10SVL0BI5N04j@FP1AUE80BiQB04JJD`13UU00>YE@03^H
DP0hVUH0>IeK03nLD`11X5l0AYQF04J4E@18NED0D8U805RF>01PTB40Ih/?06f71@1dQ`P00P1jPPT0
9`1iOPP0MgP707Yb1@1kK0<0Ng8107ij1`22P0l0R8lO08Z9=@2FMbh0YG4R09mb9P2@N3@0PH<n07b;
@@1fP4d0QGU?09]eD02PMe<0UW=G091_F`27LE`0QG1J07a^EP1oK5@0W5iD0;EFD`2XG5@0VFEC099`
B`2;MDh0SH9?09>1E02>P580QXM?07bM@P1aZ440KZdn072^@`02072Y@@0W07FT>P1cXcP0MZLc07R]
<@1f[Bl0N[8Y07Rb9@1c/2L0M:d/076Z:@1[Yb`0KjD`07>Q;@1fXR/0Nj8K07NT4P1hXQ<0LjHH06jT
901_YRL0LJLV076Z5`1^YPh0LZ4:07FP201fWPT0M:4<072T4`1]Z200K:LU06^R;01]Y2h0J:Ph06JW
?01ZX3H0JYHc076D;01fTb<0OI4I0080PH`<02L0OHL607b60`1mP`40N7l007Uh001hM000MVd007=X
001aHP00LEl0075N001aG`00MV4007MT001fI000L60006eK001[E`00Je<006eE001bF000ME`0075M
001_G000KET006eK001^G000LEl0079J001^F@00JUL006QI001[E`00Ie40069=001RC000HTd006E=
001SCP000P1QC0009`1NC@00HDd005i>001OBP00I4h006I>001RB@00HDP00617001PA@00G4L005a4
001KA000GTP005i7001TBP00ID/006=:001SB@00HTX00619001PAP00G4P005Y1001IAP00FTD005M2
001I?@00F3h005Ll001B?`00CSL004lg001;<@00ABl004D]000o:P00?BX003XX000203DS000C03<T
000a8000;Ql002/I000X6@0091D002<A000P4P007Q0001`?000L3P006``001L<000D30004@/000l7
000=1@001`<000<1000<0?ooo`002P3ooolY0000000900@1000400000`8000@200050P001`@000L1
00050@001`800080208000D02`D00149000B3P0060/001L<000201H;000[01<:000B20004PX0018:
000F30006@d001d?000O40008Q00020C000Q4P009AL002HK000/7P00:Qd002`H000[5P00;Ad0034O
000d9000=B@003HT000g9@00>2T0040Z0013<@00BSD0050i001D@@00ED@005I2001FA@00F4T005YC
001KGP40E6/704Ql3P13Q1H0?hXQ03^>800nSQP0@XlG04:=5@0204:@4`0W04>A4`13TQL0@YDN042K
9P0jVb/0>9Hf03BA@@0`Q5@0;WMJ03YYI014GVX0?U=_04=2N@1B?gX0GDE[071;G`1Y?fh0J3=m06lg
L`1f?eX0NT5607HiE01/;6@0KRa/070fKP1l>V`0PcEa08`[N`2@8gd0Qb=n07lQO`1m7X<0P1N808/>
R@2@57d0TaQ_09TJJ02A7W40RR9h0080O2V202L0KbnA06<eWP1D>9T0?SnC02i4R`0]DH@0:f9l02U[
M`0^K7@0<Vid03IaM@0kMG@0?7I`03eiKP0nNVh0?GQ_03YbL`0jJg@0?VEd049IN015G7H0AFUb04Ic
L@15MF`0Ag1Y04YUL01CEWD0GTUb06hhM`1i=g<0P49[08A5H@25AF80PT5/07hmN01/Ag@0Fe1]04]K
JP17IfX00P14M6X09`0nNfT0?gAV03eUIP0oGV<0A5iQ04MJJ@18GfT0A6U/045aK@0jNfH0=h9Z03>0
M@0aNg<0<Fee039]M`0gOfl0>h]c04R=H`1@SU@0DI1?04nEC`1:VeX0@I]J03bKDP0cVDl0=ieA03:P
F`0fXEl0?9eD03fJF`13UT`0BH/l04n5;P1QQb80JX8I06el3`1bNPH0MWT107]m0@0207eh0P0W07ii
0P1nM@40OFh107]a001nL040P8DA07j=802<Sbd0ZGDX0:a_9P2]Kbd0WW8j08Eg@@1iOdL0OGm:08Uk
D02DLdP0Y6]10:EXAP2LJTl0UFEH09EVF`2EIUP0T69=09INB02^D4h0_T]C0:]SDP2IL5@0T7I<08Ue
C02CNdL0WWU809YnB@2<S4`0N:M306f[AP1]ZD`0JZQ40080KJLo02L0Lj4m072T>P1cY3H0LjLb076Y
;@1f[2@0MZhR07N^901fZR80MZHQ07:Q8@1bWRH0MilV07VM901jVQP0O9L?07VL401hX1D0Mj@J07JU
701dYAX0Kj@C07>O3`1eW@d0M9d=07:Q3P1bY@l0KjLF06b[8@1`[2X0L:Pc06fT>P1[YSd0JZDl06ZP
;P1`V200O8`E08653023P0D00P21O@809`1nN@40OGd007Yl001iO@00Ngd007Ii001gL`00Lfh007AZ
001dI@00MFH007AP001gIP00M6H007QU001bG`00Kel006mL001_F`00L5T0075L001eG@00Le`0079P
001dG@00LEh007=N001_G000K5/006YJ001ZD`00JUH006ME001TDP00HT/006=:001SC000ITl006M@
000206E@000W069=001RB000HDH00696001SB000IDP00699001RBP00GT`005m8001OAP00G48005]5
001NA`00GDL005m:001OB000Gd/005m6001PB000H4D005i3001OA`00GT8005U3001J@`00ECh005Hi
001E>000E3P004hg001>=P00C3L004Tc0013<000@Bh0040Z000l:@00>2D00080<B8001<0<2<0034Q
000_7P00;1`002TI000U4`008A4001hA000K40006@l001L=000E30005P`001@<000@2P003`L000T5
00050`000`0000`0oooo000:0?ooobP0000001D00@0000<200050P001@8000D4000810002PD000T4
000<0P002P4000/4000<1@0040H001<9000I30006``001/=000K30006P`001H;000C2@000P0C1P00
9`0G2P006`d0024@000N4`009A80020C000S4@008A<002LI000[6`00:AX002PI000Y6P00;A/0030P
000i8P00?BP003`/000m<000@S8004Lc001:=`00DS/005M0001LB@00Fd/005i@001LDP00G5T105QR
001AK0@0BG/=04>45P0nRAd0?HdR03^@8`10U1/0@i8L04B@500204BB4@0W04FB4@12U1X0?IDV03RF
<`0jTCd0>8U803EoE00fM5d0>6UN04=MG@1ABFP0E45N050kK@1I@W80HdQV07a2F01[=eh0FC]R05]9
HP1WBE/0LdAI06/iGP1P;FD0J2aX07D`KP20<W@0PC1i080/PP1o8XD0N1ZA07H?V01m49<0Ra6709hA
N02K5F@0VQUA09XKB@2C7U/0Rb9Z0080OBYl02L0KC2=05lfW@1>?9T0=DFA029>R@0TFh009VMj02U/
MP0^JgH0<F]e03A]M`0gLg@0>WQ`03YiK`0iNW00>GMb03QdM00lL7L0@fYc04MTL`18I6l0BG1]04Ye
J@18L6P0DFQ[05YJM@1VAgX0Jceh070]O01i>GL0ODIe08==L@1oAfd0MD5_06XkM01PDfd0Ef=S04eb
GP17NV000P12Of809`0mP6@0@WYN03i^F`12IV00B6QP04QSIP18JV40B71K04EjF010PUL0>gmS03Eg
M@0jJWH0?eMm045NN@0mMWD0>HUh04:;HP16Se40@YE>04:HEP0nWEl0>YeN03RJD@0dV4d0=9]?03BO
E@0gW5L0@9Q@04:DE`1:Sc/0EHLO05j33P1]O@/0LG4807=Z101eK040NFl007mb0002085d000W089e
0021L`00P7<0081f101oOP/0QY0G08NB;`2BOB`0YFLE09ec6`2PMB`0T7E607afD01`KeP0QFiF09e_
EP2ZJD@0[V<[0:UP=02RG440WE]:0:IOCP2ZID`0]ELm0;]C=@31BdL0`4YB0:mWE@2UMU/0TgU@08ih
CP2DNd<0V7M309:0A023S4h0MJI;06VSDP1YV5X0JYe:0080KZ1002L0LYi0072P>P1]XS<0K:@`072V
9`1`YB40M:DQ07FV901bXb80LIdL07:I5`1bV1/0MYPK07VB6P20RPl0PXX8082A2`1oV@h0NZ0C07ZU
501hY1<0M:4@07:N3P1_X100KZ<E06bZ6@1[[Ad0JjdO06b_9@1_[S80KZPc06nS=01bX340MI`]07RG
7P1nRa00PH09085j0P1nN@000P1oN`009`1mM@00O7L007Uj001lO000O7d007Uj001fM@00MG8007A]
001aJ@00LfX007U[001gK@00N6`007I/001bJ000LVD007=W001cIP00LVH0079T001dH000LV40079O
001cG`00Lf4007QQ001cH000Kel006YK001/FP00JeL006YE001XE@00IE8006E>001UC@00I4h006EA
000206AC0006065>001OA`00FdD005Q3001MB000H4T00P1SB0007`1QB000H4T00618001MA@00GT@0
0614001R@`00GDH005i4001MA@00GTD005]5001MAP00G4<005]4001K@P00FD0005<o001C>P00DCT0
058d001@=P00CcD004`f001;=P00BC<004@a0013;P00@2`003`Y000i:0000P0c90002@0a7P00;Qd0
02/M000Z7@00:AP002DC000Q4P007Q8001X?000201P>000801H;000E2`004@/00107000<1P0020<0
00D10002000<0?ooo`002P3ooolU000000800@0001D00`0000@100060P0020<000L300080`002PD0
00h6000>1`0040H000d5000@1@003PD00186000E20006@X001`=000L300070d001/<000H2P000`0F
20009`0K2`007100028D000S50009A@0028C000S40008Q8002@D000W6000:AT002/I000]6P00:a`0
034R000l:000@2h004@b0016=P00C3L0058j001C?@00FD@005e<001PD`00IeP006EL001MH@40F6P1
059^0P1:N@D0AH@>04:;5`0mSQ`0?HhK03fA7@12UA`0A9LK04FE6@0204>G6@0W04>I7@0nV2P0=i@h
03:;B`0dP5P0=WES03AWJ`0eGFl0?eA]051=J01O@FX0HSMR05`cJ@1R?VP0JdMS0790H01N=6T0DCA[
05dlG@1a>E@0O3IA06l_E@1T8f00Kb9W084QM02>8Wd0QBAn07`SQ01k7XP0NAFH07`:X0243I@0T162
0:0DKP2L5f00VAYC09HMC`2<8680PREb0080Kben02L0GCF:04dkU@11A9<0;U6<01mJQ@0RHg`09VMe
02]ZMP0/JgT0<Fej039]O@0eL7L0=gEc03QeM00iLgH0>7Ig03QcN@0mKGX0@fee04QZLP1;KFh0D7AV
04e`IP1<HfT0F5Y]06M=N01fAg`0MD5f07DkMP1k?W@0OTIe0857N@1hAGH0ITAb05A3L@1DGF<0E7IH
05J5DP19REL00P13QUh09`11P6@0A7]N049/GP14J680B6]S04Q[HP15LEX0AGeA04>8C010QU00>h1R
03QdMP0oJGP0A5Yl04MMMP12MW<0@8E`04::HP10S5h0>HaT03R@I`0fUF/0=iIU03NFG00cU5L0>9IF
03JKE00lUe80BHi605:8@01KQ2<0Hgh=06]f0@1`K@40LV@007=T001cIP00NFL007m/000207m_000W
085/0021L000P7D107n13@1lRaH0SY4U09im<P2DK280UFTC095a6@2DKS@0R75A07ebEP1mJe`0T6UH
0:ESC@2XGT40ZEXf0:IG?`2RETH0XEM=0:YRC`2aHTd0_EI20<9=@02iD4P0[e=@0:QUE@2WJeT0Y7E@
09ieB@2KLd00TWE108MlA`1kQE80Li=>06jGC`1]VE40JYe90080JJ5102L0K:0i06^P<@1]XRX0L:8T
07FO7`1cWQ`0L9lM07:N8@1bVad0L9PH07>B4@1cTPl0MXh>07b93@27Q0L0QX<208>91022T0D0PIP8
07fL2`1lWP`0Mi`<076K301]XA40JjHF06N[6@1X[Ah0IZ`N06^Z801_Z2@0LJ<O076J6@1fU1@0Oi0C
08:93024PPH0QW/307mm0021P0000P1mOP009`1nO000NGh007Un001iOP00Mgl007Mk001hM000MW00
07I]001gJ`00NFd007E/001iK000MfX007EV001bI000LF80079U001bJ000LfP0071U001bH@00LV00
071M001aG`00M60007AT001eH`00LF4006iL001/F@00IeL006MC001WEP00JEH006IE001WD@00JE80
06QC000206IA000=069@001RC@00GdX005m:001QBP00IE4006I?001VD@00Idl006E<001PB@00GDH0
05a3000205e3000H05i0001L@`00HD@00614001NA@00GTL005e7001KA000FT4005U1001C?`00Dc/0
054j001C=`00DCX0050h001?=`00CCL004Td0016<000A300048_000n;000>RX00P0g90004`0c8@00
;a`002/K000X6`009AL0028C000N4@0070h001T?000I30005`/001D9000A2`004@L000l7000<1@00
20<000@000000000303oool000X0oooo8`0000020040000H004100030@0010<000P300090P002P<0
00T3000:1@002PL000d:000B2@004`H00145000B1@0040L001<9000G2`006Pl001d<000O3P007A00
01`?000G3P006@`00P0H3P009`0N3P008A<002DF000U6@009aP002HH000R6P0091L002DI000W6P00
;AX0030O000c7`00=b8003PX0011;000BSL004`k001@@000E4<005I4001K@`00FTP005eB001PF`00
I6D006AY001RL000Fg@105Ih0@1AP0H0BXT=04B@4P12TA80?i@C042D6@0mVR40>YhY03ZM:`0203VN
<`0W03VN=`0fUT<0=8eB03=oH@0cKfL0=F=[031HM@0`DG`0@Dei05Y<M`1U@gL0GSEe05PZMP1S=6P0
MceI07LkEP1Q=FP0FS9^05ThF@1R=4X0Kbm@06hZE01`8ed0NBAS080UK0268g80Ob5f07PIO`1n5XD0
Pa:@08d>UP2A4XX0U1Ei09/HJP2F6fP0TaiT08lPI`209GD0LRZ00080GSB702L0AT2;03I9S@0]EXX0
9VF5029^P00VLGL0:6ic02e`L`0^M7P0<WMf039gN00gN780>WYa03YfL`0jMg<0>gMf03YcN`0mIW`0
A6Uf04YZM01<Kfh0D71V04eXIP1<E6l0EU1c05e8NP1WAWh0JDMf06]5M01_@W80MD5a07I1M`1/A7L0
GTU`051AJP1BJ5T0Dge:05F:@`1?R4T00P1=PUT09`17MVL0Ag1S04EVIP16I6/0AVQX04EZH`11Le`0
@81D03^9DP0jPe`0>WQ^03]/OP11I7/0@Ual049QMP11Mf`0?hQU046<H00nS640=hMY03R8JP0jRW00
>X]^03V;J@0gQVH0>8eE03^BA`16T3d0FXLX06Qm701^N@l0Kfh4075V001eI@00M680075T001eJ000
Mf/007a/0002081]000W07i^001lK`00P7P208>:5@23URT0U8LU0:I]902CJb80W6/N091a:P2<KdL0
OfmJ08=XGP2CIF@0W6=D0:=M@`2SDCl0YTY10:I1BP2NADl0WdaC0:UOD@2eHdh0`UU;0;mDD`2XGED0
WF1L09=TF@2FI5@0XW9;0:MfA@2TMT40VG=408QoB`1kPE00N8Q:07:?BP1aWDL0JZA80080J:M102L0
Jj@d06bW9`1`Yb@0MjHS07ZU701iX1X0MYdL07RJ6`1gUAT0NI@A07NA2`1jT`T0OHd808:81P29Q`80
QX0008=o0023Q000PHP2086D101mT`L0NiD907JH2`1hW@d0N:<D07BU5P1`Z1T0LZHK07FS5P1hW1<0
N9D=07^@1P1kR`<0PHP108:60026O`80QH8408B31@26QPH00P22R0@09022QP<0P8@107f2001jOP00
NGh007Ui001jLP00N6l007Y^001gJ`00NV`007Y[001fJ`00M6P007=V001dH`00Lf@0075R001_I000
LV8006mP001`G000KUl006mN001_F`00L5d007AP001bG`00KEl0075M001/F@00JE8006QA001VD`00
JET006QI0080JEP000/0JEL006QD001XE000Ie0006M>001RC`00I4l0069A001VE000J5@006UD0002
06QB000M06A?001PB`00G4P005Y4001N@000Fd8005m3001QAP00HdH00659001RBP00GdL00616001P
A@00GT8005U1001G?P00E3`005@j001C>@00D3/0054h001?=`00BcH004Lc0013<@00@c00048/000k
9`000P0i90004`0d8000;20002TM000W6P008QL0020A000M4000710001T=000E3P0050X001<8000@
1P003@D000/500090`001@80008000000000303oool000X0oooo80000002004000<00P4000@00`40
00H200080`002P800P0;1P004P0;1@0030H00148000E2P0050X001@8000B200050T001H;000G3@00
60l001`?000L40007a<0020C000Q40007A4001`@00808A0002L0918002HI000Z6P00:AX002HK000V
5P009a/002DK000V6`00:A`003@O000i9`00?2/003h[0010<000AcT004i1001AA000DdX005Q@001M
DP00Ge0005eD001OG000I6P006Q`001TL@00H7H005ik001HO`00DHP604b@3017U140A9LD03jH5@0n
V1h0>Ih/03JQ>@0bWd400P0aWTP09`0bVTh0<i1H03J4I@0fL6d0<Eeb02m>M`0[Agh0;4B903m5R`1G
AHP0ISj106HdO01Y<G80LSUT07e3E`1j@5@0KC]L06<eF`1?>e@0@cYD05<dH@1V;680NbAW080VIP20
9fT0P2=Y07XJLP1h37`0PP^108l@R`2R58`0WAMo09PKLP2G7FP0TQm]08dQM02697/0MBZ506@aR`02
04dlS`0W03E:S00QF8P086N302=fP00UOG`0:G]e02aeLP0^LWD0<GEf039mL@0ePFl0>h9/03j3JP0o
Pf`0@Gm]049lKP11L740@69c04IUL@1<JG00C6e_04aXKP1@Ffd0E4Af05A6N01CAh00E4am05Y>M`1Q
B7L0ID5i06HlN01W=gT0Gd=j055AL`1:GF`0CW5F05>1AP1CRch0EHA80080EGQE02L0CFeW04][I@1:
IFP0BFMZ04]]I`15L6D0@GIQ03emH@0fOF/0>gIc041[NP14Gh40@eml041HO`12H7H0?7YY03B9I@0h
RF<0>HMV03F5K`0iQVl0>XIa03V3K`0nP6T0?WYQ04:4C@17Rc`0E8PW06Qk4`1aL0H0LFT207EP001h
GP00MV40079S001eJ000N6X007]`0020K`000P1kK`009`1mL040Ng@407b02P2ATAh0WHDm09Uc8@2T
JR<0T74]09eZ=`2HId<0SVQA08UZGP2>IeT0WF9M0:9LCP2YEd@0ZU190;15BP2^?Tl0Z3YC0:A4DP2Y
GD`0]FI80<1OC02iGED0WVeL095aH@2;J5l0TFAB0:9]B02^MDD0ZGI609UdC@22NT`0MHA?07NBB@1b
UTT0L9a806^R@`0206fZ>00W06jX:@1`Z1h0LJXP07>[901gYah0NJ0K07fE6P1nSA@0P8T>08671`21
Q`<0Q8X108B50@27Q000R88008Ik0025O@00Pgl008:30`1hR`D0M8`607J>201hTP/0N9L=07RJ3`1i
VPh0NY/>07bJ3@1oU0X0Phl808F<1@23Q`40PXH008290@22R@80PX`808>B3@22TPh0PY8?0080PI0>
02L0OI<907b;1P1mQ`40Oh@00865001nOP00NgX007]h001lL`00O7D007Yb001jL@00Mg4007Ib001f
K`00MW4007M^001eJP00LF0006iN001^F@00KUd006eO001bH000LV<0075S001`H000LF4006mN001a
H`00Keh006iG001[E@00J58006QD001[E`00K5X006mI001YE`000P1YD@009`1UD`00Ie8006EB001T
D@00IU@006QD001WEP00IeD006UB001WDP00I4h0065=001PB000FdH005U0001H@@00G4<005i7001Q
A@00GTX00698001OB@00I4X005i7001LA@00FD@005M0001I>`00Dc`0050j001@>000CCP004hf0018
=000BC<004Da0013<@00@B/003`W000203PT000C034S000]7P00:1/002DJ000Q4`008A8001d@000J
3P005A4001H<000C2P004`H000`5000;0P002@4000H100020@000@000000000<0?ooo`002P3ooolN
0000000?00400003000010<000L3000810001`<000P300090P002P<000`4000<1@0030P000l5000>
1`0040X000805P/000T05`X001D9000H2`006P`001`>000O40008Q40024A000Q5@000P0T5P000`0O
5@007Q40020A000202@C000W02@I000Y6`00;1`002XH000Y5`0091L002PI000X6`00:A`002`N000f
8`00>R`003hb0013=000ACX004Y0001?A`00Ed`005MC001LF000H5L0061K001TG`00JFL006Y^0@1/
M`40JWX206Ek0P1PP0<0FXH505B=2@1ATQ00B9HG04>G7`0lUbT0=iHe03:E@@0aV540:iMG0080:YIN
02L0:i1Q0326IP0aN700;V]f02UKNP0WCGl094N402I9SP0`C9L0?TVG054lTP1O:h`0KbMi08@/F`2C
<d00QcM107DgC@1T<e<0@cQN03XeKP1><WD0K2Q]08`SK02:9FD0Q2MQ07lPF`1m5VH0O@M`08X;N@2I
4X40Z1R009hMO@2E8gH0SbAd08HWN`1m:X<0Lbb805lbSP1@>I000P0kBHl09`0WFhX05ff301]kO00S
PgL0:HAh02b1MP0^O7@0<GEh03=fMP0fOfd0>HIW046:IP13SF40A8aT04B4JP14NV/0@fe[04ASKP1<
IF`0CFQ]04aYKP1:GWD0D55g0552OP1?Bgh0Bdj004]?OP1AD7P0E4Ui05A4N`1E@7d0ECmn0599N@1>
F780BF=]04edF@1?PD`0D8E905=nD00205A_G00W04eNK`1:I6`0B65/04]UK01;KfP0@g=V045gI`0k
OV<0=gab03ifLP15K7D0CEeh04iOM01@G740CF1_04AfK00aOg<0=81_03=mL`0]MW`0<GIf02meM`0d
MF/0>GME04Ag@01@NRl0G7/N06Ye4P1_KPL0KVH006mR001_FP00LUd007IQ001jI`00O6L007m^001o
L`00O7H00080NW8002L0OG4107]m301kSQ@0WHDU0:M]=P2RIbP0YVdX09Ua?02FJTH0RFI>08YZE`2<
KEl0U6MC09eHCP2SE4d0/51A0;]>DP33A4h0`SeB0;8jD02XA4l0ZeY20;AR@030GT<0^f5D0:1aF@2G
Lel0TFmG09EYC`2PK480YW100:EaB02GLU<0OWY>06f5D@1]Tdl0KHeB06j:C`1[VTD00P1^ZSH09`1a
ZB<0Lj<H07BR7@1fXAl0MYhO07BC6`1dR1<0MWd>07ah1@1mM040P7H0089h0021M@00P7P007mg0023
M`00PWh008>30@21QP<0NXX707B8201dR0T0N8`907R>2P1lT0X0OI0908>>1P22R`<0QhH108R40029
QP00QhL108R<0`25T`P0PiP;08FK3P20X140O9hB07bK4`0207^J4@0E07^L3@1jV0T0Oi83082?0@1m
RP40OXD007b1001oO`00P7T007ig001nN@00O7T107Qg001hN000O7/007ej001kM`00MVh0079V001/
H@00KV000080LfH00100MV`007QZ001eIP00LF80075O001bG`00Lf<007AS001bH000L5`006UH001W
D`00KEL006eH001/E`00KE800P1XE0007`1XF000J5L006YF001ZF000KEX006mI001[F@00JUH006YD
001WE000I58006A>001SCP00GdP005a0001K@@00FT0005e2001PA@00GdH00695001QB000HT/005e8
001L@`00FT<005Ln001F?P00E3l005<h001@=P000P1==@001P1:<@00BCD004Dd0013=000@Rl0040/
0080>bL00140<b8002`L000W6@009QH002<E000R4`00714001T>000F3P005@d001<8000@1@0030<0
00P100060@000@4000400002000000`0oooo000:0?oooad0000000X00@0000@100060`002@H000`6
000>2@0030L000/7000>1P0040L00P0A1`00500?20004PT001<7000C2P005@`001L=000I3@0060l0
01P=000L3P0070l001lC000S5@009QP002PJ000Z6`00:A/002HI000Q4P007A@00P0P5P009`0T6@00
;1`002hM000]7@00:AT002DH000V6P00;1d0030P000a8`00<bX003`^0012=000BCX004/m001BA000
ET/005QC001IF`00GU`0065Q001QIP00IF`006Qg0@1WO`<0I84606:0201QQ0P0GHL905B<3P1:TaH0
AYDR03nE;P0iU3T0<he20366C@0_PE@0;8AG02b8G@0202V:GP0W02b9GP0YPf<09WY]02=`N00OGgl0
7U:50254RP0YAi80<TRJ0493V01F=hl0JBN507dWKP2=:580Vb/l08l`@021<dT0LRi304PgCP0_AU@0
>T9K05X/G@2086L0Pb1X08DPJP2576T0QaEa08X<LP2B47L0V1Ii09hKN`2C8gl0RBZ3084/QP1c<H/0
IcF@05TiS`16?Y00=T>?0080:5B;02L07FV:01QjQ00KPWX09HUb02^:L`0_QWH0<X5c03AlL@0gNFd0
?8=W042;H`18SUh0BY5J04Z<H@15PF/0AGEZ049[K015H780Bei_04iNL@1?EW@0DTmk0559OP1?Ah80
CE2004aDOP1<D7`0CTih05A:N01DAW`0Bdem04YDO01?Gg00DVYT055cG@1CO5<0E81E05=mF`1CMeh0
0P1BIFP09`1>E7<0BUYa04IJLP17HG40A6]c03U`L`0iLVh0>7M/039fM`0oM7H0Bfee05EUM@1CJfd0
CW1X04ecI@1:MVH0?GA_03]^L`0gI7/0<eJ103EMNP0]HWD0=VaH04Ef=01?MAH0Gf`A06MV2P1^HPH0
Kf4106iL001]G000L5/0071L001dH000MfP007]`001lMP00OW@007eh000207Ye0@0W07]k1P24QaP0
Rh<^09]m:02TH3<0Y5hf0:]T<`2OJD40R69D07aOE@25IeL0T6QN09UQD02QD4H0ZDe70;I<B030BTD0
cD=40<PoB02d=dd0[4960:iK@02gHcX0_Um50;YRE@2TM5P0Vg=I09M]D`2FJdd0VVa009e^?P2OLD<0
TgQA07^7D01`Se00Kha@06b3D`1_OU80LIA80080LZ<j02L0M9lV07FL6P1eVaX0N9TJ07>B6@1aR1D0
Lg`=07Eb1@1jJP40OVL0081[001lK@00Nfl007U^001jLP00OgT008:00022P`00PH@208260`1kP`<0
N7l407b01@1oO`<0PX02085m0@20N`40PG/008Al0028PP40QhH208R>1@27U@T0PYl>07bX501m[1T0
O:hF07VZ5`1gYaD00P1oY1<09`1mYA00NZ8<07ZL201lV@H0Ni4407f:0@1oR000PhH008B0001nN`00
O7d107Mk0P1fNP40Mg/007ak001iN000OGD007U`001eJ@00LV<007=S001cI`00LVP007IZ001eK@00
MFH0079R001dH@00Lf0007AT001bI000LfH007=K001]E@00JE8006YA001WEP00J5L006UH000206YG
000B06YH001YF000JeL006eJ001_GP00KU`006iM001]FP00K5/006MG001YEP00IU4006AF001TCP00
HDL005m4001P@@00GT800P1NAP004`1QAP00Gd/00618001NAP00G4@005Xo001G@@00Ecd005Hm001A
>`00CCT004hd001<=`00C3P004/f0018=@00AS<004<`000l:`000P0i90003`0a8@00;Ad002HH000U
50008aH001lB000L3`0060h001<9000A2@0040H000h3000;0P001`8000<10002004000800000303o
ool000X0oooo700000001@0100000`0000@3000910003PL000803`P001X03PX000l8000A2P004P`0
01@:000B20004PX001D:000E1`0050P001<:000G2`006@d001`>000I3@0070d001dC000T5P009QP0
02PG000/6P00;1h002XN000Y6P008a<0024B00808aD002L09AP002`J000[7000;ah002dN000]6`00
;Ad0034R000h:000>RX003h^000n=@00BSL004e1001DA`00FDh005YF001GH000Ff<005mU001RI`00
HG41065k0@1NP`@0GhX:05V=401DSa80DhdC056>5@1:TQl0@9D/03fA?@0jSdL0=hY@0362E`0`N5d0
;g9Q02aeH@0ZNF400P0]Nf809`0/Mf@0;71Y02eTM00^GGX0;e=o039?P00gBh00?Tmo04IAOP1?C7X0
Fcif06HbLP1f<6H0Q2eI08d/D`2:;5@0QRiH07H[@@1E>D40>d]703/mE@1C85l0Ma=/080CK`2<4g@0
TQAa09HDLP2L4VX0VaM[09LLL02C8WL0R2V407haTP1e=9X0HcVI05E0VP17AI40=DR:02E<R00201YN
Q`0W01QdP`0HP800785i02B6L@0]RG40<HQb03F6L00iQf/0?8QY03n;I013Seh0C91F04b@E@18QU/0
@gMU04EYJ`17HG40BeUj051>N@1CB7T0FCil05E0PP1=@hH0B4^304]DO@1<EWT0CU5g04e:N@1=AgT0
C4Uk04MHN`11IGX0BViV055eFP1DNU40EWa@05=lE01ANV40DG=R0080CfAY01l0CDec04]EKP1:G6d0
Af9`04EULP0mGW/0>eim03UXM00cIWX0@FQj051WNP1OI7X0DgA^04UiI`17MFH0BgIS049dK011KG40
?Em`03eCL`10EFL0@UQM04]U@01HLAP0GVD306AM0@1/E@00K5H006eJ001_FP00KUX00080LUX000H0
MEl007UU001kK000O6h007e]001kLP0207Uj0`0W07V:3P2EQBX0Wg1309mc;P2]I3P0XfY109EYAP23
IUH0M6IK075XE`1nIeX0REmN09mEE`2dBDT0^TTn0;e::`31BbX0bT<a0<93?02b>DP0[4A<0:mKA@2c
Hd80]e]90:aOEP2LL5L0Vg5F09i`CP2QKTH0X6hl09a`?02JLdD0T7Y@08N>C021STd0M8U=06Z7DP1_
RTh0LYPj0080MIX^02L0Mi@T07RE7@1iV1h0O9@E07Z93`1kQ0`0NWT407]`001lJ000OV`008E`0022
L@00P7@007mc001oM000OGT007eo001lP@00Oh<008B1001nM`00OgD107mc0@21M040QW<0089d0023
M@00Q7H108R00`29Q`D0Qh`808BF2P1oXPh0Nj`C07J_7@1d/200Mk4M07J/6@1fZAP00P1gZAH09`1g
ZA80MJP<07JT2P1hX0L0NIP707jA1P1kTPP0Q90:08F<2P1oQ`@0Kh@206j20P1dP`40NH8007V40@1h
QP80N8D307Aj0`1cK`40LFP006eQ001aH000LfD0075W001cI000MV@007AT001cHP00L600079P001f
H@00Kf40071K001]F@00JE<006YF001YE`00JUP006]I000206YJ000Q06YI001_F@00KeT006mM001]
H000Kf@006YT001XI000Hf8006IL001XE`00JE/006QI001YE@00Ie4006=:001NAP00Gd<005i4001O
A000GdH00616001L@`00Fd0005Tn001G?000F3`005Lo001C>`00D3T004hg001?=`00CSP00080BcL0
00@0AcL0044c0010;000?BP00P0f8`00400d8@00;Ql002`I000S5@008A4001d>000E3P005@`00188
000@1@003@<000T300080P000`80008000010003000000`0oooo000:0?oooa/0000002800P0000<1
00050P001P<000X4000<1`003`P00109000A2P004P`001<=000D3P005@`0018;000D2@004`/001D8
000A20004@T001L;000I3@0070X001X=000L2`007a40028B000Y5P00:AP002PJ000Y7P00;A`002XJ
000X5`008Q@00P0R5P009`0W6000;1P002dM000d8P00<b40030Q000`8000=2H003/_0011=@00AS/0
04/l001:?P00E4P005UC001NF`00F6D105E]0@1IKP40G7<105ad0@1IO@<0E8D605::2P1AT140CI4G
04ZC7P18U280Ai<U04BF;012U3D0?he203b5B@0jPd/0=Gm<03EkD`0cN5P0<GQM031fGP0202ecI00W
02UZJP0_GgH0>5600499PP1;AH@0DDB105a1O@1U@6h0JT9O06Q2G01T>VH0IBm^06lZM01l87T0QQee
08hLJ@2E7V80NRE306LeA01S@EL0DBmN05TEI@1h2fd0Q0]b09D=M`2K47D0WaEd0:DIJ@2N7W00Tb9f
08/WO@21:h/0Mc6I06hcWP1K>9`0CT2D03m<R`0/EXD075b200805f]n02L067Yl01]mO@0OMW`09Gif
02f5M00^QWD0=8Ea03V8K00lRfH0?haT04B:H@19SEl0BXQL04IoG@11KVH0AfI/04QOLP1:EWT0DT]i
05Y<O01QBGh0GDQj05E>NP1?DW@0DUEa05=CL01ABW80Cd]c04m9N@1?Cg`0Af1h049ZM@17L6L0CWIG
04miD@1?Me00CgMI04eaJ`1>IfT00P1;F6`09`1;BW40BeU[04MSJ@16K6/0A6e_049VN@10I7/0?VEh
03aMN@19GWH0G5ie06mQLP1PL6X0C7=X04UZIP1;L680@G5_045`J`11JFH0@6QO04i/A`1JKC<0HVTL
06QW301SF`00I5D006UB001[EP00JeX0075I001/E`00LE`0075N001fH`00N6H007YW001kJ`00Mfd1
07Qd1P0207f35`0W082::02JNc<0WF@d0:UV>02XK4L0RG5C07]UFP1`Ff40L6AR07EVG023GUd0Te5J
0:m>C@35CSd0`DhY0;AB6P2dCQT0`T`P0<97=02d@DT0[dU>0:mQB@2_I4P0[65?0:=QDP2HL580Ug5F
09idC`2PL4`0XFa209]aA@2CLU00S7MA08n4B@21RTX0Lh]<06f?B`1WUD40KiX[0080MIHL02L0N9@C
07jD4@1mTPh0Ohl=08242@21NPD0PgL2085b0020L000QG4008=e0023NP00PGP007mf001kL`00NWD0
07Uh001kN`00OWh0081j001oL`00Ofd007eY001nIP00Ofh0085a0022N000Pg`408B93025T`d0PY`=
07^U3`1kZQH0MjdM07F^7`1f[RD0MZ`H07VX3`1iY`h00P1fZ0d0901hY``0MJL<07BS2@1cW@H0N9X7
07^J2`1iWQ00O:4A082S4@1kW@/0Li@706nA101_SP40LX`2076A101`U`L0LIL<07>?3@1bP0L0LW42
071]0@1`IP00LVL0071Y001bI@00MFD007UV001fI000MF80071Q001`H000Ked006iM001_G000JU/0
06aH0080KET001/0KU/006iM001^G@00L5/006mK001^GP00K6@106e[0`1[L0H0J7<=06Yd3P1UL`l0
JG0?06]]3@1/JPP0LFL506mT0P1[G000JU@006A=001TB@00GDD005a5001MAP00GT@005U1001K@`00
0P1H?0003@1G?@00E3d0050l001@>`00C3D004/f001:<@00B3@004Lg0016<`00A2l003lZ000l:@00
0P0f:0001P0c8`00;al002TI000T5`00714001L>008050`000L04@L000d3000;0P00208000D20003
0@000@0000@00000303oool000X0oooo6P0000008`0200000`4000P2000910002@D000X6000;2@00
3`H0014:000D30005@d001P?000I40006@h001D<000E2P0050X001H:000F20005PT001X;000I3@00
70h001T=000L400081<002@C000W5@009aL002PH000[6P00:ad002`P000Z6`009AL00080:1X002L0
9aT0030L000g8`00>BX003`X000g9000<R4003@S000l:`00A3P004Y3001?A`00DdX005IE001CH@00
E6/2051`0`1<NPH0D7l605B21P1DQ0P0CHP;04^=4019TaP0AI@R04:F:@0mUC<0>IDl03RB?P0gTd00
>8e703QoC`0eL5H0<G1G02aaF00]Kel0;faX039/L@0dI7@00P0^H7L09`0ZEgh0<Tb5044oRP1C>8L0
GcZ206/kOP1d?740NCeO07/mD@1j=U@0MS9F078]E01^;5X0JRUO06/WHP1e8Ed0Q21L070VDP1];Uh0
O35b06XTL01_4f`0R0e/08l@MP2H4g`0VAMn09PLO02H8GD0T2J008LZRP21;I<0NBnI074bX01Z<j00
EcJJ04/lU00jBh/0:Uj401]/P00201UiN`0W01f0M@0KP7@087Ig02=gM`0XNW@0;G]f035jL00gPFd0
>HA/03b4IP0oQ6H0A8=W04F1I014N6<0AFUV04IOKP1:H6l0BEUb04mHL`1FGG@0FfEf05YOK`1BG6`0
CEIZ04eDK01>Cfd0D4M_051?L`1?DgP0CEYj04YVL@1;K6`0CFmR051bE@1AL5L0CG9L04e`I01BGgD0
DEAc0080Bd]d02L0AdQh04]MI`15JV<0?faX04=^K@11K7H0?fYh049/L@10HWD0BVEa05MZJ`1SL6D0
Gg9P05MZHP1EGVD0EEmX04iOMP18J6h0@WAO04ImB01MN2P0K6lA06]V1`1]G0<0IU@006EH001VEP00
KE/006iJ001^G@00LF40079T001iI@00NFL007YW001lK000Mf`107Ua101iOa000P2=PRl09`2GKTL0
WV`j0:AI>02PHdD0TFi@07YgF@1_KF80LFUR07iWG@2>HET0VUaB0:9FAP2fESX0^UX/0:QO;02@HcH0
WEP`0;I>8`34AC80_DA60;A=C`2]IDP0ZFQ=0:5UC02HITh0UFi@09M^E@2SM4P0X7150:5^@P2MJTX0
R6eG089cE@23O4h0NHQ7072BA01aV3X0LIh/07BI7P0207ZE500W07fB4P1nT0h0P8d;08671P24P080
Qg/008Qa0025KP00Pf/007mZ0020JP00Ofd007m^0020KP00OfX007i^001mLP00OgH0089h0021N000
OG4007i^001mJ000O6H007e[0022M040PGh508692`1lTa40OYXA07jS4P1fYa<0M:PI07J[601eZAP0
M:`J07N/5P1iZ@l0NJP=0080MJd=01T0Mj/<07JZ301bZ0X0L:<807:O2P1bY0l0MZLC07JY6`1f[Q/0
NZd@07>W3@1`W`X0KIT806jB1@1_U0H0LY/;07BS3`1cWQ80M94=079l101eK@40M6/007E]001fJ`00
MFL00080N6X000`0NVT007MT001aIP00L6@0075U001bHP00LUl006iI001ZEP00KEL006eF001^F@02
071O000D071M001bH`00KfP006Y_0`1SM@X0HGhA05n46`1OQ1l0Gh0T05j19@1QOb40I7`H06Uj3`1/
L@L0K6T106aP001WE@00I4`005i4001K@`0205U2000A05Q0001J@`00Fd0005Y0001G@`00E3h0054l
001?>P00CSD004Xf001:<`00BCD004Td0016=P00ARl0044/000n:@000P0h9P003@0d8000;1`002PF
000P50006`l001P<000E2`004PT000l7000;1@002`8000@2000300001P00000<0?ooo`002P3ooolI
0000000C008000050@002@<000`7000=20003@D000h5000>1`0040H00189000F3@006Q0001d@000K
40006@l001H<000D30005PT001X9000201P<000?01`>000L3@007@h0024?000P4P0091H002@G000X
6000:AP002TI000]6P00;R00038S000^8@00;2400080:a/002L0;aX0038Q000k:000?Rl0044^000l
;000=RH003PU000o<000B3d0051<001BD`00EEP0055Q0P1:K0<0B78504Ii3013Q180@XXD04B<6016
SQT0@i<O042E900lURX0?YP]03bH;P0iUc40>9Dg03ND>@0iT3`0>Xa003V2AP0bNU80;gYH02miG@0_
N640<GMV035fK00aL6d00P0^JVl09`0[HW@0<EIo03]6P@1B@880Icj007djNP22>Fl0OcaR07PmG01[
?680ICiY064lJ@1H>Vd0DSU^04d`K01J8F@0LQMR06/JJP1a87`0PbF9080LO@2>4W40WQ1[09dCM@2J
67h0UAj108lTP@2;:H<0Pbf@07/bWP1g=:P0LCBW06/eY01V=9/0EcFF04TjT@0gBH/09VJ401akP002
01^6N00W01b8L@0MR6h08Gmb02AlL`0XOG80:gea02mkKP0dOF`0=GmZ03YoJ@0nOF/0@G]]04AiJP16
M6T0BVYY04aRK01:HF/0BEm/04iWI`1@KfP0DGeY05IeI01?Iel0AUMV041BJ@16BG40BDAe04]BM`18
FGd0BUai04e[K`1@LfL0E7QN05EjE@1ANeH0CGQL04m[I@1AEg@0DTmf0080De=c0200DEI_059UHP1;
JV00A6QW04I^J`15K7D0B6Ue04MZL@13HG@0BVE_04]_JP1BLfL0GFmP05mVH@1OFVL0IEIV065BI01G
HUP0EG=205Ef:P1VKAD0Jf8306MD001YEP00JUD006aG001]FP00Kel0075M001/GP00MF@007UW0080
OFP000D0OfX007i`001nM`D0OX4E08F48P0209Yg<P0W0:=O@@2IHd00VEY708EWD`1cKe`0IgAQ07Ab
H@22KF<0UfAN0:YKFP2cFT80^5Da0;MN9@2aHbD0Sf<j08AVDP2@G4/0ZddZ0<M9;`36BdH0_EM?0:mZ
B`2UJdl0VVI>09MVC`2FJdl0V6e;0:1f?@2OLcX0X74l09Y/A@23LDl0OWIA07agCP1gR4<0LI8j07FH
901lUa<0Q90>0080R8/<02L0R8T908J42026Q0<0QX4208Un0029N@00RgH0085[0020H`00O5l007US
001fI`00NVT007]Y001mJP00PFX008Aa0023N@00QGP008Ej0023NP00PWL108Ab1027M`/0Qgl?08V3
4@28SAL0OiHG07NK5`1jXQL0N:@F07J]501dZAD0MZXD07J/5@1g[AL0NJhF07R_5P1i[A000P1g/0l0
8P1f/Pd0LZl<06nY2`1^YP`0KJP=06j^4`1a/200L:lU072`9@1a/aX0K:hD06RY4@1VX0h0J9d:06ZM
301]YPh0LZ`C07BX4P1gWA40NX`?07Yo301iMPL0NW8207U/001iJP00MfP007MY001hIP00N6D007AT
001cJ000M6H0079V001^H00206aL000306YI001ZFP00L5h00080KF8001<0KVH0071/001_K@40J7H:
05ao5P1HQQ`0EhXV05R::`1HQc80FhLh05b8<`1MQR<0HH@L06En5@1YL`L0JVP006YL001VC`00GdL0
0080Fd@00180FT8005]5001MA000G4@005a2001IA@00ET8005Dn001C>P00C3P004/h001:=P00BCD0
04Tf0015<`00@Rd003hZ000j9`0203DQ000<02lJ000Y6P009QH001hB000H30004`X00107000>1`00
2PD000/400070P000P001`00000<0?ooo`002P3ooolF0000000?004000010@000@4000L100080P00
2P@00107000B20004@P00187000?2@0040T001H;000M30007`h000807a4000@06a8001D=000G2P00
5`d00P0K3000400K3@006P`001X;000O30008a4002@E000T6@009QP002XF000[5`00:a/002dS000_
8`00=2@0038W000e8P02030O000W03@M000g8`00@2h004<g0015>000@3D0040a0011<000BSL004a9
001AEP00DF81055W0P1;L0@0AGH504Eh2@15Oa40@HTK03n>9@0jSbh0?I0c03RD=`0fVC`0=Ia103FK
?P0fVCP0=YPe03BF=`0hT3T0>H/m03V2A@0gNDl0<WAO02ieJ00/MV`0;WA_02abK`0/LW<0:W9d0080
9W1e02L08VAi02ECPP0]@8T0CCF@07HYTP2M8Xl0WB>009LULP22;VX0HSe/05M;P01DChX0CdZ904Y7
R@10=g/0CB1[06`@HP1_4W40NaJ208hNR`2?6g`0WQQ]0:PGI`2O77@0UB1o08hUQ`26:HT0PBb;07X`
U`1d<j<0L3FZ06TdZ01S=J40GcJH04llT@10@8h0<4n702E^O`0NPg/00P0OSWL09`0PTG00891_02B8
LP0UPW00:X=/02n3K00dP6X0>7mX03IoJP0hO6h0?7U_03mfL@13MFd0AW9[04aWK01?HFh0DFIZ04]X
JP1<KFP0BWUQ04f4HP1AOe`0B6iN03]LIP0hEVT0@51`04Q6N@18CW/0B5El04YGN`1<JW00CgYW05>0
G`1DOeT0BgYN04=bI@1<Hfh0C5=j05AEN00205IRKP0I05A/I@1FMUH0D7IH04QcHP1=LVD0DVIZ05QL
L01CGfh0CeIe04mMLP1?JFd0E6U^05m[I01KJ6H0FUmV05aODP1GH3l0FFL]05iZ7P1QHa@0IU`906UJ
0P1YEP00JeD006eF0002079N000<075S001cH@00KV00075T001hH`00O68007iW0023KP00OW810821
3`2;Q2@0U7di0P2OLC009`2LH3l0TfM309AYB`1lMeD0Ih1M06J2F`1mMEh0T6=N09UTF@2VIe<0[68n
0:aI=02GFSH0S5e308INB`1oFDh0REM30:U>;`2nBSL0^T]?0;5FF@2XJ5D0W6iE09I_D@2FKdd0UFm6
09Ic?P2KMSL0WG@c0:5c?@2HN4<0PH1608B5@@1oQcP0Oh`a086>901oT100PHX708V80`0208R0000W
08Qn0026O000Q7d008Il0025O`00Qg/008Uf0023K@00Of<007IQ001jH@00OV/007m^001oL@00PG@0
085e0023MP00OGX007al0020O`00Pgl008>31022Q`d0Oh`H07^?;01lRS40OhLn07FJ=01dXC40LjPZ
07FZ8`1a[200LZdP07>]8@1a[al0Lk0M07:_601e[aD0MK4B0080M;4B01X0Lk8?07:a3P1][Ph0K:lF
06fa8`1]/RH0Jk8^06V`<`1X/bd0I[XX06Jf:P1V[b80Ij/J06F^5P1W[Q@0JjlF06^b6@1a/1H0MjhJ
07RW6P1hVQH0Nhh@07j41P1lMP40MVh007IU0080M68000/0LfD0075V001aIP00L6D006iS0@1]H040
Ke`006eM001`G`00KV<0071U000206m/0@0W06ma0@1^L`40JWL606N65P1OSB`0FH/b05V;>@1NR3d0
I8Q106>4A01MQT00G8hg05V?<P1JQRX0GG`?06=/001YH000J5@006==001NB000FTD005Y1001H@P00
FT8005Y0001I@@00FT<005Y4001E@`00ESh0050k001@=P00BC0004@b0012;P00@2`003lY000i9`00
=B400080<al000H0;Q/002XG000R50006a4001H9000?1`0200/6000300X400070P001@4000P00000
303oool000X0oooo500000020040000Q008100040P001P8000P3000<1@003`H00149000B2`004PX0
01@;000C200050P001D;000L3P007`h001lA000O50007A8001X@000J30006@`001`=000O3P0080h0
01d?000L3`007@d0020B000T5`009QD002XG000W5`00;A/00080<20000@0<Ql003@R000h8@00=al0
0P0f80009`0c9P00>2X003d_0011=`00A3P004Tg0018=P00BCh005=6001EF000E6D0059a0P1<N@D0
BW`704Qn2@18P@l0B8@I04B::00mSC<0=i1003B=B00cTTT0<YI;03>IB`0cVDL0<YY103:J?P0eUSl0
=Y9003N<A`0hPdd0=gQI03AfH`0bMf`0<7A_031`L00]K780;6ef02]_MP0202]`M`0W02iWNP0eFH00
?dR505PmQP1g<H<0Sbaj084`KP1c<fH0ISU]05]6NP1GDhX0E5><04m:Q@1?@7d0DCAc05TTJ`1W6VL0
MAY]084ML`278gD0SB=_09HSJP2J8Fd0TR=h08XVP`25:HT0Ob^=07X]SP1d<9P0Kc:R06/cZ01P=:D0
ESJL050iT`11@H`0<d^902QIP`0ULWL08hMb0080991a02L0999c02J@L`0WRWD0:X9_02j4JP0bRFX0
=hIV03V2J@0fOG80>GQa03ecL@10KG<0AV]c04QZL@1;H7<0Cema04mYK`1=LFd0C7=V04agH019OV00
CGYL04IdG00kJV<0=fIU03eLJ012Cg40B5Mb04mKL`1AFgH0E6e/05=kJ01DPF80CgiQ04AaJ@0mI740
@5Yg04U@P@1BFg/00P1AK6l09`1<NFP0D7iM051lG@1>L6P0E6aX05ENK@1JE780FEQ_05AKKP1EGFd0
GEi]06]IL01]HFP0HF=V05ETG01FJ3L0D6LL05]U4@1QFPP0He@206MF0@1XG000KU/0075K001cH000
M60007EV001eI000M5h0071K001dG`00MEd007IN001mI`00PG43081m4@1oPAd0SgP_09i]?00209Y[
=00W09EO?P2;Jd@0Og]=06j<D`1ZS5X0KhAJ08Q/FP2LE640WV=L0:9ZC`2QGT80WTm008==C`26DUT0
Q4mC08M6BP2JBC`0[E8a0;E=@02^DEL0Z5QT09m[G`2GLU`0TWIF09AeC02DMDP0TgM009Ul>02JP3T0
WH5109:5@@1oRcl0P9@^082D6`26RA80S88>08J01`24NP80QWX00080QWP002L0QGD008If0026M@00
PgH008Aj0026O@00RG/008Yh0021L000Nfd007a_0021LP00OWD107ai0@1oN`<0P84607n62`20Q`X0
OhP:08292P25S@/0P8l@07nD5@1lUb00NITX07NH;@1gW3<0L:La06f^;@1][bT0K:`V06jZ9`1_ZbT0
K:/Y06n^8@1^/ad0L:lG072^5P1_[aD00P1`/AH09`1/]AL0J[8I06^b7P1Y]2d0I[<o06Va?@1VZCl0
HZXm066g<`1K^Rl0Gk8h06:_<`1S[c<0Hk8_06Bg:P1W^RL0IkXS06bh7P1/^1l0L;@Q07:]801dXaT0
O9<A07j93P1oO0d0O7H;07Uc201hK`P0N6h807I^1@1dKP80L6l306e/1`1_K@T0K6`606e]0P1^K040
Jfl106]d0P0206]k1@0W06b01`1RP`X0G8/C05fD:@1IUSd0F8m505b:B01UPTX0J81706]iA`1OP3l0
F8dj05V?=01IRbH0FGlC05mb201VI`@0Jf0106YF001VC000GDP005a5001I@P00Ech005Xo001H?000
FCh005M3001E@@00E3d0050i001<<`00B2l0048]000n:P00>bP003TW000i9000=B800080;Qh000/0
:aX002@E000P4P0060l001@:000>20002`L000P400070P001@4000800008000000`0oooo000:0?oo
oa<0000001400@0000<0000300001@4000P3000;0`0030@000d7000@1`0050T001@:000G3@005@d0
01@<000E300060d001dA000401hB000E01/D000I40006@d001d=000S4@008Q@0024C000P4@008A<0
02@G000X5`009QX002`E000Z6`00:a`002TO000a7000<AX0034L000b7@00<ah00080>2D002L0>RP0
03`_0010<P00A3D004Dh0019>`00Cd0005E4001GE080F6@3055e1019P0H0B8D:04Z53P1;QQ00BhDH
04^39P15Qc80?XXf03Z<?`0fRDL0=h]603V<A00iSd00=YA103BGA00bVDH0<iU703>IBP0cUE00<Y9A
03:?D`0`S5X0<HYR02j3J00/Nfh0:GAd02U_N`0]KWh00P0bKWl09`0iIX<0@ef7051?R`1OAH@0L3Uj
07TdLP1S>W40HCIf05lkP01R@HP0IdZ?06I8R@1Y>h00LRmd07@ZJ`1c9fD0Mb=R080QH@278V40RBIS
08TZJ02;;6h0RbYg08DYP020:X`0O2^B07L/U01f;Y<0KbnI06/aX01T<Z@0FCBP04leV014>i40=dR:
02]BQ@0TGH009W9`02B2K@0202B;LP0W02N=M@0YRWL0:X=f02amKP0_PfL0<hIW03N7I`0jPV`0>7Yc
03]aLP11KW00AFUa04ETL`18HVl0AUa`04QMM01:Jg@0Bg=b04YeK@1;MF@0Ag5T04]cHP14MF40?W=V
03YZH`0lGVP0?e5_04ILK`1;HVl0DFMa05MbJP1GNVH0DGeT04IgI@10K700?5ik045KMP1@FgD0E6Ac
0080D7=[02L0C7a[04ikIP1CLVT0F65e05aML01KD7@0GTIl05UCM@1CFWL0F5Yc069KK`1/Ef`0KEmP
05iVC@1CIcX0FfTL05YO2P1PF0@0IE<1065@001YEP00JUl0075T001gI000MV<007MR001gI@00MVP0
07IS001eGP00NF4007aR001lI000NFX1085j3`24P2L0OWHa08ia<P2RGT/00P2QH3h09`2GH3`0PG94
0763D@1/Sdl0LHIB07YhD`2BIE`0ZEUP0:UNF`2YIU00ZEi50:E=>@2MAT80WTI>09Y6D02J@T/0Y4U8
0:eE@02_Dd/0Y5QJ0:9OI@2JJV40UW5O09YcF@2PL5D0Ug5B09=fB@2COT80U8I308n:B028TC`0OIDZ
07nF5`24S@X0QgT408Id0025L@00QgL008=k000208Am000W08Qh0023N000PW0007ic0021M@00QgP0
08Ul002<P000RGT0089g0021M@00PWX107en101hPPL0NXH<07bA4@1mUaL0OYTL08:J8`22X2<0QJ4S
086R9`1oYb`0P:/]07fW:P1gYbL0M:`Y06j^:P1Y/2d0IJ`_06ZT<01/YS00KZD_06fZ;P1/[RL0JKDQ
06Ze7@1/]AP0J[HO0080JK<S02L0Ik<Y06Fb;`1U/SP0I:e4066VC`1UXdL0I:5406:V@01L]S80F[D]
05bX>01PZcL0Gj`j05n`>@1Q/CL0H;0f06Fa<`1U]R`0J;HY06nd:01b[b/0LJL`07JI;P1jTBP0Nh`P
07N;6`1fQ1H0MX0D07F05@1cO`h0Kgh706]o1`1XOPh0Ih4C06R53P1VQ0P0J84606621`1RQ0`00P1U
SQ809`1RUQP0GiTO05bJ:P1OVCP0HYY206FCAP1STDH0Hhi5066=@01LR3T0F8Pb05N?;P1GTR/0EX`R
05R05`1OMQ80HV`806US0@1XF@00Ie<006I>001RB@00GDL005a5001LAP00Ed0005Q0001H?`00ET00
058n001<>P00C3@004Da0014;@00?bT003`Y000i:P00>2<003DR000202hM000;02PG000P4`006`d0
01H:000A1P003@<000X300080P0010800080000100002000000<0?ooo`002P3ooolC0000000Z0081
00090@002@4000X3000<1`003`L00106000?1`0050T001@=000E2`005@X001P;000G3P0060l001X>
000O4000814001dC000O4P008AH0028E000R40007Q80028A000U5@0091D002DF000V5@009QH002LH
000[7000:aX002TL000]6P00;ad002/L000`7@00;Q/002lL000c7P00>B800P0j:`009`11<000@SD0
048f0018=@00ACP004dl001CA@00GEH105eX101CMPL0BH8:04>83014S@l0AI4D04N?7@14RRT0@88k
03^3@P0jQT40=hM503B5C00gPdX0=X5503R7@00fSd@0<9I<02nHE@0^W5H0;IiJ02bKH@0]V680;IIN
02^BH@0[SVL0:8A^02AjM`0TKH00:FB803=PR@0203eMR`0W04UIS@1EEHl0I4f@06Y4P`1_>WD0KSA]
05djN01Y<HL0L3F=07LiS@1m?8T0OCN3088[N@2F7g00TB5V08TWGP2::UX0RBMG08`UE@2?9E/0RbUV
08L]L@24;7/0P2^507d[S`1j;I@0MBjH078`VP1Y<Id0HS>O05ddX@1A>I/0ASbC03e2SP0bChH0:ER0
02ENO00UKg009ga^00809X=b02L09hAg02Z2MP0/PGD0;Wi/0361J@0cPFP0=X5/03UmK@0jLg40?FY_
04=]K017KFl0B6U_04Q/J@16KVL0BVi^04QaM@1:NG80Cg]/055fH`1:Jf@0BFaT04]]I019JVX0@f1[
03iEKP0lBg@0@Ua`04UXK@1CKfX0EW=V05=bI`18Kfl0B6]]04IUM@15GWL0BVI`04Y_J`1>N6H00P1;
OF809`17O6X0D7Y/05i[K@1_DWL0KTmf06Y8N@1^AWX0IU9i05MFO@1KEGH0GUY]05aHK01OHdd0GFd]
05e]601WJ@h0IUh406MI0@1WE000JE@006UF001^H000MEl007UR001dH@00MEh007MO001cI000MFD0
07AR001jH`00NVP0081]0P1mN0P0OhTG08]o<`2;LCP0R78a08]W@00208=Y@`0W07IaD01[Q5@0I8YH
06R8DP1aLED0PF=K09YJH@2`EV40]EAM0;UFF@2lDT00aDHQ0<M1:@35?Cd0]ci90:hmE@2YAU@0ZEM<
0:EJB`2LFU`0V5mW09eWHP2OK680W71L09m]F02ML5L0VGA@09UjB`2CQDP0RH]808FG;027V180R8d9
08Mm0`26M@40Qg8008Qg0027O000R7d00080RGh002L0Rgh008Mj0026M000Pg@0085e0027N@00Rgh0
08b00027O@00QWh008Im001mP`80N8`807R?2`1hU@l0MJ0E07FW8P1dZBT0M:`[07B`;`1f/C<0N;4c
07V`<@1h/3@0MZ/d07BW<P1a[2X0KK0/06J]<@1XWCD0K9Lm06jF>P1^Uc/0LIdk06nV<`1^/bX0JkHT
06Vd8@1Y^2P00P1T]S809`1R/3T0H:dm05nYA01MYT/0GJ9C06BKC`1TWTd0Gje005Vh<01H/b`0EjPb
05Z^<P1J[CL0F:dn05^T@@1KWT80H:9106FX?`1Y/CP0K[<a06n]>01^YSh0K9]206jE@@1`UC80LI@Y
076B901dSQd0MXhI07b>5`1nSAH0OXhF07j>6`1gS1l0L8lL06RB6`1VU1`0HI8Q06:@900206:I;@0W
06:P>@1SXd<0HiU906F?B`1aS4l0MX]A07J;DP1]SDX0FXY005J9>01DSc<0E9H]05JH:@1ITb40F8PJ
05ag3`1PK0L0If<106YN001WF000Idl006I;001PA`00GdH005U5001H@`00F3l005I0001C?`00DSd0
04hg0018<000@Bl0040/000m:P00?2P003XT000g8P00<1h00080:aL000X09AD001lB000H3@0050T0
00l7000:0`001@8000H200030P000P402@00000<0?ooo`002P3ooolA00000003008000060@002@<0
00803@<001403PD000h8000A1`004PP001<8000E2`005`h001@@000F3@0060`001T>000J3P006Q00
020?000O4`008a8002<E000202DG000D020G000Q5000:1@002XF000W6P00:QP002/I000X5`00:1`0
02TI000]6@00;a/003DH000c7000=20003LS000g9@00=bT003XZ000i;`0203lc000W04@g0017>P00
B3`004/m001=?P00DCl005aA001RJP80FWd804V:4@10SQ@0?i4C04:C5`18U1`0AI<S042C;@0jSCX0
=Xhn03B<@00fST00=ha803N9A@0hRDD0=Hm4036GB@0^W580:Y]L02^GH00YV6<0:iMV02^FJ00[TF@0
:h]U02f5JP0aOG40=WAi03MYO`0nHH<0AUV60080CU:902L0EE>;05e@R`1WC8X0J4F106TnN@1a=g<0
KCId07DaN`1f=7X0NcEg07heL020<Vl0Q2][094RJ02=9V00QR]J08<]F023:EH0QBIE08LVH023:W00
ORf007`]R@1j;I00NRjG07H`W01_<J00J3>Q05/dX@1C=j80C3ZN0455U00iCHh0<eB802mPO00XJ7<0
9V]b02MfK@0VOVX00P0XPV`09`0ZPFd0;7m_02n1K@0bP6H0=81W03AjJP0hN6h0>7E/03M[K`0nHfh0
@F][04E]KP16KVl0B7MW04MnI@19O6T0BGMa04]lL01@P6P0EGaP04ifHP1;Leh0AgIN04A_I`10JG00
@65]04AAK@1?FFP0E6EV05M]H`1DJfD0D6AY04]GL`1;GG80Bemh051OM@1=Kfh0A7Y[04AkI@0204Ij
I00W04QcK`1DKW00HVMa075EN`1hCgL0O4ih089?M`1mDg80Le5h06]HL@1OG6H0DEQO05Q]=@1NMQ80
IFl406eW0@1[G@00K5T006]G001[E@00K5T0075O001bGP00Lel0071K001bG@00Leh007=Q001eGP00
NF8007]T001kJ@00PGX<07f27@1lPBH0SW/a09Me?P2AK400WV5H0080NW=E02L0I7YR06>6F`1WQUP0
LGeH085XG02<GV<0WUeL0;1FEP2eDdl0^5990:mA=02ZC2@0/DXS0<M4:P35@Ch0]CaF0:a9FP2XG4d0
XUe@099IH02AFVH0X6=T0:IUI02KKeh0V75F09efC`2JMe40TGYA08^:@@21U2X0QY<D08V80`26OP00
PGH0081a0024LP00Qg8008Mg002:N@400P2:O`@09`2=P`L0Qh8708J31`29OP80QWP008Ej002:P000
Rh<008R0002:QP00Q8l107nG201mW0h0Mih@072Q4@1aYaP0LJdT07:`:P1e]B`0MK@^07Fd=@1d/c80
LK<_076_<`1c[3@0LJTc06b];`1[Z2l0JJ4a06fJ<P1_UCH0KHlg06j??`1^TT80K9Tn06^T>01VZBl0
I[0[06Jc=@0206FX?P0W06:GB01NVT`0Fi];05^QB`1IY4l0GJA?05nXB01K[S/0DZha052`;P1B[S80
Djhg056a?`1E/DL0FJ]905jZA@1NZd00Hk<j06Ne<01^]bP0KKH^06fc>@1Z[C/0K:@j06jM=@1^VC<0
M9De07jA<`27RC<0S8Lg09:9>`2:Rc`0R8`j07n9>01]T3L0HYHn05ZM@`1CWDT0E9aB0080FIaG02L0
GIaF06FMC@1ZUDL0Jhi507N<AP1kRT`0Lhe:06R@@01MT3H0F8h]056C:@1?WBT0D9lW05>J9@1@TA`0
FWd>061b0P1TJ000If4006MH001UD`00HDX005i7001KAP00G4@005i3001K@P00FSl005@n001=>P00
BS<004<`00109`00@RT003hY000k9`00>2<0038N000_6P000P0W5P002P0R4P0070d001H<000A3000
3PD000T300060@001040004100010009000000`0oooo000:0?ooo`l000000P0200000`050@001`@0
00d500020147000W0188000B2P0050/001@<000G2`006`d001`A000L4`006`l001`@000M4@006`l0
01X?000O3`007Q<002<C000R50008a@0024F000S50009AP002XG000[6P00;1X002`K000/7000:QT0
02TH000Z5`00;AT002lM000c7`00>B8003/W000n;`00?S<0040a000o<`00?cL00080?S/002L0AT00
04a5001BA`00EdT005U7001ND000HF@105il1@1BS0h0?iDJ03^I700nV1d0@YLN04>I8`10VBH0>YX]
03RE<`0dUCH0>9@d03VE=@0iTcl0>9=603JEBP0bV4d0;IiB02RMG00TV6X09I=^02:DK`0STW809Hm`
02R7K@0YOVh0<7Ac03][M`16H7l0D5N105Y?P`1TAXH00P1X@HT09`1X@hX0JdB;06i2Q@1`?X00LCYd
07TeM01k<G@0ORmi07haLP20<Vd0P31V07l^IP20:FT0QRMW08HZI024;F00P2eM07lYFP1n9UP0ORIU
07XYO01d;900LRnI07<aV`1f<I`0LC:R06PfY@1P>:P0CcVT04<mX`0i@9d0<djD02eGS`0[GXL0:VQh
02IdK`0TO6h0985Y02N6I`0202R8I`0W02^4I`0]QF@0<hMU03J9H@0gQF80=WeW03MiJ00fMFT0=F]_
03YPL@13J6h0AVQ^04MYK`18NFX0B8MX04^6IP1>PF/0BhA[04j9I`1DQEl0C7mP04UnG@13OUd0?GEX
03i_L011I6X0BEUY05MMI@1LIeh0Eg1J05Y_GP1CJVT0D5ia05=QK`1FHfl0F6A]05E`IP17N6H0@gQY
0080Ag=[02L0BVEe05QRMP1WGW@0O4ml089ALP27DW<0SU=h089JL@1[Gfl0HfAR065[B01KJC<0IG<I
06mc2@1^KP00K6D006eJ001]F000Je8006UF001/F@00LU/0071N001aG@00LUX007=K001cGP00Mf<0
07aQ001iHP00NVD007Y^0@1mPQT0OGhf07mh=`2NLSD0VfY308eVC027HEh00P1cLe/09`1XMV<0JWQN
07M^H@26JF00Tf9X09YRI02RGEP0[eI;0;AE?02eD2/0UU@^08MB>P2GDRT0]d`Q0<=5;`2nA4h0]4eF
0:YMC@2PGU80TUYQ095EI`2JFFD0WEiN09QZDP2GKDP0X7A809aeC026N5<0PI4]08>I4@29R`H0RX40
08]j0027N000Q7H008Qi0P23NP<0QW`508Qm200208V63`0W08N@4@24T0h0Pi8<08R61P25N000Pg80
08Mg002;Q`00S94308NG1`21Y``0Oj/>086^4@1j/1P0M[8N072c9P1/]bd0KKTb072g=01b^C@0Lk@k
06j^>`1_[CP0KjHi06jU>01[Y3`0IZE106NHA@1WU4D0JIDm06^A@@1[Rd40JhU806Z:B`1XS4h0Ii=9
06JO?P1S[3d0I;120080Gj5702L0GXUB05b;DP1JSU<0FiE@05RPD@1FYeD0FJa;05N[@01=X3X0BJ`e
04Z]?01:[D@0Bk1904ndC@1H/U@0F;9?05Vd?`1J]SD0HkHX06Bc8@1X]bL0J[Xc06Re=P1[Zc<0LJ4g
07:F>P1cUC/0P9Lm08nC@02BST40SI1108>GA01kWD@0L9a106FQ@P1KYd`0DJQE052VFP1CYEh00P1I
YEh09`1NYE80HZ96062O@01LUSd0H8dj06V<?01^SSh0HI<e05VE<P1GUR/0DYTZ052R:`1@Xb`0DZ4Z
04jG8P1GRa<0Fgh7061a0P1XJ@00JE/006EB001SC000H4T005i7001KAP00FTH005Q4001D?`00D3`0
04/h0016<P00@Bh003hZ000l9P00>bL003TP000d8000;aX002/I000202DE000801lA000K3@005`T0
00l:000=10001P8000<10002000;000000`0oooo000:0?ooo`h0000000H00@0000<200060P001@@0
00T3000=0`020147000W01<8000F2`005`/001T>000L3@007180024C000Q500081D0020D000O4P00
718001`?000P40008A80024@000Q4@007a8001lC000S4`009aT002dJ000^7P00:Q`002`M000_7000
;QT002XF000[4`00:AP002hO000g9@00?bh004<a0012=P00@3D0048f0013=P00A3X00080ACd002L0
B4@0055;001HDP00GEH006MJ001XI`40I7L305N82@16U1L0>9`S03JP9P0gWRL0>ilX03ZQ;P0gXC80
=:8d03:N>00cWSP0=Ide03RM=00hW400=Ie<036NE@0/X5T0:J9L02JNIP0SUg408Hmh01j>NP0OS7/0
8hUh02EmM@0YKgL0<F5j045FP01EBH80Id:1074mPP1k=8800P1l;X@09`1j;hH0NS2607d^P020;GP0
PR][08</L@23:gH0Q2]l08D/L@23;FX0PR]P080WI01n8fL0ObEW080VIP20:F@0OBIS07/TH@1i8E`0
Mb9[074VQ01[;9`0IS:R06TdX`1/=:40JCFT05hjYP1F?:L0A3nQ03E3W@0ZAYL09EF@02ELR@0WGXD0
:FMj02QeL@0VPg409XaX02N=I@0202Z<I`0W02n<I00bSV80=8mQ03VAH@0iRV80>81U03=gI`0dM6X0
=g9_03a^LP15LF/0B75X04YbJ01?NfH0Ch9X04n1I01BP6@0ChMR052;HP1CRU/0CH=M04b1G`12OV<0
>GIa03]]MP13I6/0D5IY05]LHP1JIUH0E6]L05A^I01?Jf`0CFMc05=YK01DKFX0EfmT05IhGP1;O680
AX1]0080BgA_02L0DUme06IGM@1cEFd0Qe1W08MHGP2<G6H0U5]^081ZI@1TLf80GGQ906Ak:01aM0l0
M7@907Mb0`1eKP00Lf<007=K001^E000JU4006IC001YE000KUd0079L001cH@00Lf8007EO001jHP00
OF@007iY001kI`00OW0607Qn601iR2L0T7Lo09U]A@2PICX0UD]=08AIF@1eHVP00P1bLV409`1cLUP0
NVYK08YMH`2CFFH0WU]U0:=MH@2UEe@0ZeA30:eD=P2_CRH0Q5Hg07QJD@21ES/0ZdhQ0;m8<02nATX0
]e1@0:]QB@2MGdl0TeYP099HJ02@GET0T61D099XB02CJd40WGA109Uk>`24R2h0PhhH08B41027OP00
QgX008Uk0026O@00QWl208B42025R@P0Q8T<08N>4@0208FH4@0W07jM501mWa00PI`>08JF302:R@X0
PGX208=k0026SPD0Pj4?07j[4P1l/QD0N[LP07Vg8P1e]bT0L;L_06S0;`1T`3<0I<0i06Fn=`1Z^CH0
J[Dl06V_?@1/[3/0KZHh06bS=`1YXCl0Hi]506JAAP1XSTD0J91406RG@`1YWD<0Ij4m06JT>@1VY3/0
IjHn06V[>P1X[CX0Gj/m0080G9m302L0FiQ8066CBP1SV4/0FiiB05FSD`1AXe<0Ej]@05NYA`19X480
AJU004NZB`18Z5D0AjaD04R^E@1>/E/0E;1E05>aA`1D]S/0FKL/05jh:01P]bP0I[XW06:g;@1V[bh0
IZLb06VO<01[XC80KZ@o06nU@@1aXCl0M9hn072T?`1X[DD0Gjm805n[D@1NZU/0GZEJ05fLF`1TW5h0
0P1]WEX09`1aWU@0M9Y<06^HA`1QTd00FhXj0664?01]Qcl0HX`i05NA=01EVBh0DIl[056S;01@Y2/0
DIhW04bE6P1BRa40FH0>05ef1@1SL000If@006MI001WD`00HU0005m9001KA000FD0005Po001G?000
CcP004hh001:<P00@bl003hX000k9@00=R80038N000]6`00;1X002XH000202DD0008020A000O3000
50/00108000:1@001P4000800001000;000000`0oooo000:0?ooo`d0000000H00@0000<100081000
2PD000d5000<1P0300l8000W014:000G30006@d001/@000P4@008A4002<A000P500091H001lB000N
3`007A8001lA000T4P0091@002<D000T600091H002PI000Y6`00;Qd002lO000b7P00;Ah0034O000b
7`00<1h003@J000b6P00<al003LW000m<000@cP004Hi0017?000ASh004Lo001:@P00BdH00080C4L0
0140Be0005=G001QG@00J6@006Q_001XN`80GXL604ZC400jVad0<j8W03FV9`0fYbL0=jPZ03FV<@0b
YCP0<:Hm036T?`0203:T@P0D03:S@@0cX4<0;YiB02VPF@0UX5`09JAN02FQI00SWVh07IAi01^BP00L
SWl07X]i01moN00QL7/0:V2003UBQP1=AXT0GCf:06HiR01_<XD2074]R00W06l/R01`:XP0LBV3078W
OP1e9GL0MBEo07HTQP1i8hh0OB:407hSO@1l87<0NQef07LKNP1g77`0N1ig07POL`1g7740M1Ya078I
LP1`7G`0JR2?06<XXP1M<:P0F3FX05@iY@1A>j<0CCfS04PoX00jAYT0;DjD029BT00QGHH08f6202IS
P00^IgT0;GIc02Z7K00/T6P0;I=U0080;99T02L0<99Q03BEG`0kUf80?IEQ03j;H@0kOV<0=75Z03=e
K@0gOG40?W]a04AlJ`18O6D0D7]R059nH`1?OVL0BGYU04MlG`16Q640C8MR05B8G01ER5d0DHEQ04Ym
HP12KfX0@f9]04iLIP1LEf80HEmH05eXD@1CJUP0CfYV04YZLP18IgP0D6i]055cJP1>LFL0EWYO04em
JP1=NG800P1ALW809`1NHWH0KEU^07AHJP1mDel0QF1?08YZB@2BKE00P7Q:06F1@@1TPBL0Kg`?07Ac
001dK`00N70007UZ001gI000L5h006eJ001/D`00Ie8006Q@001ZE`00L5/007AS001cI000Mf@007aU
001jI`00O6P007aU0023Na<0N8/[08B:>P2WJCX0[ei30:9P@02KDU80SEeL08IVH`0208]ZFP0W08]U
DP2<GU@0SUUP099AH@2HDUH0W4i=0:5;BP2VATL0ZDE40:]1?`25CDX0NEaL07iKB02PDRl0^D/j0;M=
D`2/E5`0XfID09]RF@2AGf<0TV5S095VDP2AK4`0U6hk091a>P2INc`0U8PW082>4023PPP0PgD008=`
0023M000R7`30927302<RPh0R8h?08F>3`21UaD0NYdO0080O:0K02L0NZHI07ZT4`1nYA40PZ<A08JM
4@25S`L0P8d1082G2P1kZaD0LK<Q07>i9P1b_2h0K/0U06o09@1Z`2/0Ikd]06>m;P1O^c80H;/c06Bl
;`1R^3H0H[8k06B`>01UYCd0IiY206VHA01/TTH0JHe:06J7C01RQ4l0Ih]@06bIC01XWT@0IYlj06VX
=`1Z/3T0Jjll06VY>`1PX4400P1OT4T09`1RQE80JH1H06N8F01LUeL0DimB05:RE@1E[ED0E:=;04BP
A012YTP0A9mI04FMI015YF00@j]M04B[H016/Ed0BKUF04ZiBP1@^CH0EkL]05Zg:01J]R@0H[LV06Bc
:01TZ2`0I:4a06ZP<P1hWcX0K:4h06BN>01WWSL0Kj0g06nW?01VZdH0Hj]B06JWD`1]Wd`0M9Q907JH
C@0207JKB@0W07>KB@1`WD80J9lj06JK<@1OUb`0GY8]05bE;P1HUC00E9H`052I;@1?W3<0Cile052O
<01?VBH0DIDI05>@501DR180G7X706Ad001ZJP00K5`006QE001RCP00GTT005Q2001G@@00ESl005Hl
001A=`00CC@004/d0014<@00?2T003XR000b7@00;Q`002PM000Y60009aL000808aH000H0818001`>
000G3@004@T000T500050P0=000000`0oooo000:0?ooo``0000000P0100000L3000;10003@L001<:
000C2`005@/001@900804PP002L05@T001P<000J3P006Q4001hA000Q500091D002<F000Q5P008a<0
028B000T5P009AP002PM000Z7@00:A/002XL000Y7P00;1l002lP000_8`00=B@003LR000e9P00=2D0
03@V000d9@00=b@003PQ000i:000?cD004Hm0019@P00AT@004M40017A`00AdH004Y:001;D0000P1A
EP009`1CF`00F680069Y001XLP00JWl2066;201?U180?iXH03FP7@0bYQh0=:XS036[:@0`[380;JTn
02VWB`0XY540:J=F02VUFP0XYU/0:JAI02VRE`0TWf008Z1V022PJP0PY6D07j9Y01bQL00EV7d059B>
01N?R00GRH005Wao01Y[PP0PF8`0<4NC04@jVP1E<9T0GBVH06HQU`0206LLU@0W06TIU@1[6900JAJ;
06LER01X58H0J1>?06`CV01a4J00M`nH07/?SP1i3H<0MPj7078=R`1b3Hh0LPb8078=P01_37h0K@b0
06/=P`1W4XX0HQRK05hOZP1D:jd0B3FZ03dlYP0j?j@0>d6P03a2W00_CI<095J?01aKR`0LHgl07fYj
02IaN@0^LGL0;Wi_02^<JP0^UF@0;iIO0080<9UL02L0<iUJ03ZGF@0nUF00A99T0467H`0mN6L0=fi^
03AhK@0hPG40?gm_04F0I`1:Q680DXUN0525G@1:NVH0@G9Y041kH@11PVD0BHIT05>:G@1ER600DhAV
04ejHP1;KVD0DVES05aXFP1TIeD0Ifi<06Eb@`1ILD`0EW1M04m]JP1@Jfl0EG1/05IeI@1CMFD0EGMT
05EaL01MIGH00P1SI7809`1]Gg40N5Q]07AHI`1aEel0NfU;07]i?01jPcL0MHHZ06b37`1cOQ00N7T9
07Ea001dK`00MVL007EW001cI000M6@007AR001cH000K5h0071H001^EP00L5L007EL001dF@00NEd0
07YP001gG@00OfP507e`4026RB40S8<d09=c>02WJ3H0Z5m909iOC`2ODel0VEMR09eOH0020:5PE00W
0:IMBP2RFU40VU9P09M9G@2NB500XdE50:E3B02W?DX0[S];0;DhC`2HB500Q5QM07mPD@2KEc`0/5A0
0:YBF@2PGV40W6YI09YVG@2CHV40TFYK09=`CP2DMTL0TGLi099o<02JQbT0ThdK08B11025M`00Qfl0
08M^002:MP00SXD;092B7@29VAh0QIhJ086M6`22Wb00NjH/0080Mj`S02L0MZdR07>]701iZ180NJPC
07fU5@1lWPl0NiT907fN2P1d[QP0K;X[06O0>@1Y`3P0JL0a06Ro;@1W_3D0H[Lg062Y?P1M[3l0G[50
062b>P1P/C`0GZY105fQAP1PV4`0Hi9@06N@C01ZRDh0Ih]@062;D`1OQE40IHY?06nBC@1/UD40KILj
072R=01d[C40Kjdb06j[<01VXCD00P1TUch09`1ST4T0H8e;05j@C`1LUe80Dj5@04fSDP1=YeD0BZE<
046ZAP0nX4/0@9MM042HJ@13Wf@0@JMT03n_I@10]f@0A;]S04ViE@1<]dL0DK<k05Jf=`1H]Bh0G[4`
06Fa;01UYbd0J:<d06fR=`1iWCL0LZ0b06ZQ;`1SYBl0HJH`066T?@1NWdX0FYMC05NKD`1IU4l0Gi=?
06JDB`0206>FB00W06:F@01JWc/0E:Ph05BW<01CX2D0EY`R056M7`1EWbL0Dj0_04jN<@1>Wc40CZ8g
04bO<`17WR/0B9/Q04^F6@1?SQH0FH0:069b0@1YJ@00J5/006AB001PBP00FT@005M1001H?000ESd0
054j001<=000BS0004Pb0010;000>RP003DT000d8@00;a/002TH000W6`009aP000809A<000L07Q00
01`@000F2`003`L000X500050P000@0000`00000303oool000X0oooo2`0000002@0200001`<000d8
000C2`005`d001T?000J4`006A<001X@000201H?000W01P=000I3@0070h001`A000P4@008Q<002PF
000W5`009QP002LE000Z6P00;a/002lP000c9000<al002hN000[7@00;A`0030P000]8@00=2@003LW
000j:000?2H003XX000m:000?bX003`^000n<@00@3T004=10016BP00A4d104M<0@17C@00BTd004U?
001=C`00CeD00080EEh002L0F60005eW001SKP00Ig`006B:1@1DUA40@9hQ03:Q8`0^Y240<:TM036Z
9@0Z[C<0::Q002NRC`0SW5d08iaV02:LJ00RWVd08Z1a022PK`0PWV/07YY^01fKLP0MVg@07j9`01fS
K`0LXW<05iUo01NBR`0FRXX05h>701EcQ`0JHXT07e2A0311V@13=9h0E2^Q05hRX01V6j000P1Z5Yd0
9`1_4iT0LA6@06dAS@1X4Xd0I`n=06T=U01^3I`0MP^T07h8WP231YD0P@N=07`:T01h2ID0MPRH07@6
T@1c18T0K@F406P7R@1S2Hh0HA6F05`HXP1J8Jd0Cbb/03dhZ@0[@:@0:4BO02a5VP0_@iD09E6>01]L
RP0GHHL06FMl01i`MP0SNWH0;GYc02b4JP0/TFH0;Y]Q036LFP02036ME`0W03NKF00lUE/0@8iS04::
I`14RF@0@GmV03YkK@0jPV/0>hAZ03j2JP15QVL0CHYS04n;GP1@REd0BGeP03mcI@0lNf80?h9R04N5
HP1?R5l0DhQS05:1J`1?NFH0D6eV05U[G01SL5H0IGEB06IgC01ONdH0EgM?05=cG01AKV<0D6iX05Yc
H`1LO5d0EWaO05QhI@1OJW00KUMd0080M5U]02L0PEUZ08ALI01hFeh0LUUL07E_A`1]QBl0GXTT06R1
5`1_MPX0LW4407E_0P1aJ@00LF<0071Q001bG`00LUX006iN001bFP00LE`006iQ001aE`00KUL0071F
001bD`00MEL007UJ001kGP00O5h007i`4@1eR2L0RH`^09Yf>`2QJS/0Z6Tc0:9WA@2DI5@0T5QT08iN
IP2?Gf400P2MGUl09`2WEf80ZU5T09m<IP2LCF@0Y4UP0:e7F`2/AU40/TA10;M4@`2k@TH0[dQ;09YB
E@2CG580X5]30:UJAP2PEU`0W5iO09U^G02DKU`0SVmM08YcE02?MTd0TGe708am?@2AQR/0RY4I08^6
2`26NP40RGP008]h0`2=O`X0VXT@09J>7@2DTBP0T9<]08VH:021V2X0PIhY07^U<@0207V/9`0W07N`
901e[Ah0LJXD06ja701^[280LJXM07FS4@1gX@/0L[4H06c0>01Ta3l0H/0n06Bn?P1T^c/0HKI705VW
DP1IQE`0FYMF05fYCP1KZdP0GJa805fND01KSEH0H8aG062>E@1US4P0HXY;066ED@1NTE80G8A?06>@
C01_Udd0KiE207>L>P1eWCL0Lj@b06jU<01XYRh0IZ<b0080GI/n02L0Fi5:05Z9C@1DV4`0DJI?04Z]
D@14Z5H0AYmN046TE00m[4`0=Z1@03RJH00oVFD0?i]U046PIP11[6@0?kMU04:jH`11]e/0A[5C04^/
D@1=/dT0DKE105Rb@P1N[cl0HZPn06BU?P1TY3/0Iihj06ZL>01[W3`0HjDg05bN@01HTU40EhEL05Il
H@1APUd0CXYM05:AG@1HV5L00P1IV4h09`1HUD40E9do052X?`1@ZCD0DjDV05VS8`1FX200Ej0P05:R
8@1AXbL0CJ@X04bU:01;YRP0AZ<W04JO8P17Ua/0Ci0G05J42`1NL`80IFH006MG001RCP00H4T005a3
001I@@00F40005Hl001?>000Bc@004H`0013<000?bh003`W000f9@00<R80030J000W6@008aL0024E
0002024B000601dA000I3P005@`000l9000;1@0010803@00000<0?ooo`002P3oool8000000800@00
00X00P4000D2000;10004P/001L>000G4P006Q<001dC000N50007A400P0P4@009`0L4@007a0001l@
000O4P008Q4002@C000Z5P00:aX002dL000_7@00;b4003@R000a8`00=2L0034S000/7@00;1`002PI
000Z6`00:Qh003@T000k:@00@2/004<[0010;@00@Rh0044d0014>000?d0004A40014B@00@dh104=B
0P17C`40BU4004iD001AE@00E5D005EJ0@0205ER0@0W05]X0@1RK@00I7X106B60`1HTP`0AI`R03>T
>@0[YSD0;:H[036Y9@0_ZS009j]002:SD`0QUeh0899Y01nBK@0NUFl07YA_01jGL00NUW407IE_01ZD
L`0LUGL079Qf01fLM00KXG<06Z9c01RKNP0HTH<05h>901MiR`0HIXl07UJB0299V00b@Id0ACNN05H^
WP1M9Ih0IR6N0080KAbL02L0LQVJ07<JU@1]6i<0J1^A06LIT01]5I80Ma:E08<@V`2:3Y/0T@^G08l9
S`292i80Q0ZF0848V01m1iD0NPJ?0707S01T2I80FPbG05HHWP1@8jH0BbbZ048eZ@0d?JD09DBN02=:
U@0WBhl0:4b:025JP`0KIGl066Ql01]/M00PMVh09Ge_02YnK00[QVP0;99R02fLG@0_W5P00P0dW5H0
9`0jVUL0?I9M03j:H`0oQ6D0A8IT04>8I@10RFP0?XYU03n<HP10RFD0@haT04J:IP1<Rf80C8MO04V0
H010O6<0?X=H03n5E010QeL0AhQJ04Z6H@1@OfP0CW]T051fI@1HMEd0H7]D06EkE@1POE<0FWe<055h
F01=LV80BFiU04QZJ01EM640FGiK05=jI01ILVP0Hf9]07=AM00207MGK@0W081JH`22HUH0N6Y=07A]
B@1eOC/0JhHU065j4`1ZL@X0JfP206iV001^H`00K60006]P001[G`00K5l006eH001/E`00KUH006aJ
001ZG`00KUX006mJ001`E`00L5X007=L001jHP00OFT207I]1`25R200SX/f09Qm;P2UJc80YV8i0:=U
@P2SHE<0T61N089GJ`24E6l0TDmZ0080XTmY02L0^D]X0;Y7J@2TBFL0WDiR0:M=HP2]CF40[d]<0;I=
;032B340dDHe0<U1B@2l?e/0[U1K0:UMD@2TFdd0VUUJ09UTG`2ELed0TWEL08UfF024NE<0SGU;095k
@02AQ3L0S94Q08B72P27O@80Q7/008Yl0@2=R0T0U9PD09^C8`2HSRd0UX/`0967=028TB`0QY8d07jP
<@1fXc@00P1bZS409`1d/2X0LK0X06nc8`1Y]C00JkDc06^`;P1`Zah0LJLA06nf7P1Z`D40I/9406K1
@@1T`4<0HKa605bfB@1F[E80EiEK05fFE`1KVDl0GI]@06:NE01NU5d0EHmP05RNE`1IYE80Fj1=05^L
C@1LUeT0F8iI05b7E01[RED0N8YC07V:C`1iSTX0MXi6076A@01]UcT0JiTd06RK>00206>D@@0W05n>
B01IQd/0D9U:04Z[C@14]Dd0@;Q<04:^D`0m[5<0=k5>03J]E@0lWf<0AIQW042HI`0nX680?jUO03f`
H`0n[FH0?ZYT03jRH@10VfD0A:AO04f^F01E[E`0F:]E05^SD01OWTT0Gj=505jR@`1RWTD0IiY?05nL
DP1LReP0F7YO061bI01SJfH0HWUR05f5H`1GRV80EXeP0080EY1E02H0EYA:056MA@1BYT80D:Lf05BS
:`1EX2d0EITT056J8@1?WQl0CJ@R04jW901:YR80BjLT04VU9`1:XB@0B9LJ04bC4P1BR0d0FG@4069V
001VE`00He0005Y9001M@`00ECh0054j001==P00Bc<004H]0016;P00@2d003hY000j9P00<R4002hN
000[6@009AL0024E00<07A8000H07@l001T>000E300040T000/500060P0=000000`0oooo000:0?oo
o`P0000000/00@00008100040@001P<000`6000D2P005Pl001PA000K4P006Q<001`C000301lD000W
028F000S60009Q80028D000S50009aT002LL000]7`00<24003HT000i:000>2D003/V000j:@00=bD0
038N000_6`009aT002`L000e8000>2L003`Z0012;P00A2/004<_0015<P00ACd004990011D040@U@1
045A0P14CP40B4d104]>001AC`00EeP005IO0@1DH`40DfD20080Dfd202L0FG4105ef0@1RP@@0GHd8
04fH500iWbh0:J9802BUAP0WY3`0;:Df02ZU@00SXe808I]U026BK@0NRg8078Yc01^@L@0KTfl06Y9b
01R@M00JRgD06Xah01N@O00ITG/06IQi01VLM00KWW8079Qf01Z?O`0HOHP06Vb@01eFV`0QB:408d:U
02i0Z010>J@0D36Q05`/X@1W:9l00P1_8i`09`1g8IT0NR:F07DTT`1b9940Lb6?07`MS0276HT0TQN@
09PCT`2O4IH0WPn@09X<T`2D39P0S@ZJ08L9V0222I@0L@^C060=V@1A4:80Bb2W048^Z00l>jL0=D:S
02a9W@0RCIL07dj>01i@R00NDXL0765m01a/N00MM78087MZ01mmI@0UPVH0:H9X02b9IP0^U640;Y]N
032HF`0203JGE`0W03fFF`0nSed0?HET03j0IP13QfD0B8iR04NCIP17U5l0@Y=O04>@I011SfL0@8e/
04>;K@1:QfD0B8AQ04>4H`14QUL0AHED04>8F@13ReX0AXMS04moIP1?Of80CgiR05MkG01POU@0I7iC
05b1D01GOU00CgEO04U`JP18K6P0BfEZ05=_H@1DMUd0DV]X05]TJ01[Ff/0Odm/0080NEAW00X0MUUU
07QPE01cMD80KH4j06j3:01/OaH0J6l906]Y101/I@40KUl00P1[G0006`1/G`00Jf4006iN001ZF`00
J5P006]G001ZGP00K600075N001cG@00MEd007=S001fI000NF<007ib301jRAX0U8lX0:=h>02ULc@0
ZVXe0:5UAP2GI4h0SV=L08AUH`1lH6T0REUV09QHG@020:AHD`0W0;9HD02]E540We==091GD027EE@0
QEEG08YFC@2<Ed@0WU@f0;Y=;`2oADP0^45P0:iAH@2WH5H0X6EA09ESE@2@JeX0T7IE08efE`29LeP0
RgA?08mcB02@P3P0PYPW08V@602;P@D0SWh108f0002CR0<0VI@A09NF7@2OU2L0Yi<]0::C;`2LR3P0
SHha08:=>01fVcP0LYdi0080KjHk02L0LK<e06^g<P1Z^3D0J[]406NiB01]]480Kjd`07:]5`1//b80
JK]106K0BP1T`480HL130631A@1P^DL0GkA8062WC01OUd`0FhI>05n5DP1WQel0GHQ[05:?J01BYe/0
C[Q>056bD01EY5P0F9=K05^>DP1MUD@0J9/m07:O=`1hWST0MYTj07NG>`1aVCL0Ki/^06bN9P1/XRX0
0P1VXb`09`1PX3<0FZ8g052T?@19/T@0A;e=04NlD@15^E<0?[=C03^fC`0m]U80B:]H052QEP18X5<0
?ZMB03^_E`0i[Uh0>JER03RFIP0kTFH0?HeW042@H01:T5l0D91P05BCF`1HS5X0G8EC0668C`1QRe00
J8UD06f:GP1YQV@0IW1V069TJ@1aH6/0PV9/08=/JP1mLf`0I7QW05IgI@0205J0G`0W05:?D`1AWTX0
CjM304jZ?P1=Yc`0D:8k056J;`1?VBX0C9`V04ZU9@1;XbD0BZ4R04bQ901<WB<0D9TN056F5@1?TA80
D8TA05Mj1`1MJ000HUl0065G001MC000FTP005@n001>>000Ac4004<]0014;P00@B`003`X000i8P00
=280030M000/7@009Qd002@H000S50007Q8000806Q0000H060l001L?000G3P004PX000X500060@0=
000000`0oooo000:0?ooo`P0000000/00@00008100040@001P<000`6000D2P005Pl001PA000K4P00
6Q<001`C000301lD000W028F000S60009Q80028D000S50009aT002LL000]7`00<24003HT000i:000
>2D003/V000j:@00=bD0038N000_6`009aT002`L000e8000>2L003`Z0012;P00A2/004<_0015<P00
ACd004990011D040@U@1045A0P14CP40B4d104]>001AC`00EeP005IO0@1DH`40DfD20080Dfd202L0
FG4105ef0@1RP@@0GHd804fH500iWbh0:J9802BUAP0WY3`0;:Df02ZU@00SXe808I]U026BK@0NRg80
78Yc01^@L@0KTfl06Y9b01R@M00JRgD06Xah01N@O00ITG/06IQi01VLM00KWW8079Qf01Z?O`0HOHP0
6Vb@01eFV`0QB:408d:U02i0Z010>J@0D36Q05`/X@1W:9l00P1_8i`09`1g8IT0NR:F07DTT`1b9940
Lb6?07`MS0276HT0TQN@09PCT`2O4IH0WPn@09X<T`2D39P0S@ZJ08L9V0222I@0L@^C060=V@1A4:80
Bb2W048^Z00l>jL0=D:S02a9W@0RCIL07dj>01i@R00NDXL0765m01a/N00MM78087MZ01mmI@0UPVH0
:H9X02b9IP0^U640;Y]N032HF`0203JGE`0W03fFF`0nSed0?HET03j0IP13QfD0B8iR04NCIP17U5l0
@Y=O04>@I011SfL0@8e/04>;K@1:QfD0B8AQ04>4H`14QUL0AHED04>8F@13ReX0AXMS04moIP1?Of80
CgiR05MkG01POU@0I7iC05b1D01GOU00CgEO04U`JP18K6P0BfEZ05=_H@1DMUd0DV]X05]TJ01[Ff/0
Odm/0080NEAW00X0MUUU07QPE01cMD80KH4j06j3:01/OaH0J6l906]Y101/I@40KUl00P1[G0006`1/
G`00Jf4006iN001ZF`00J5P006]G001ZGP00K600075N001cG@00MEd007=S001fI000NF<007ib301j
RAX0U8lX0:=h>02ULc@0ZVXe0:5UAP2GI4h0SV=L08AUH`1lH6T0REUV09QHG@020:AHD`0W0;9HD02]
E540We==091GD027EE@0QEEG08YFC@2<Ed@0WU@f0;Y=;`2oADP0^45P0:iAH@2WH5H0X6EA09ESE@2@
JeX0T7IE08efE`29LeP0RgA?08mcB02@P3P0PYPW08V@602;P@D0SWh108f0002CR0<0VI@A09NF7@2O
U2L0Yi<]0::C;`2LR3P0SHha08:=>01fVcP0LYdi0080KjHk02L0LK<e06^g<P1Z^3D0J[]406NiB01]
]480Kjd`07:]5`1//b80JK]106K0BP1T`480HL130631A@1P^DL0GkA8062WC01OUd`0FhI>05n5DP1W
Qel0GHQ[05:?J01BYe/0C[Q>056bD01EY5P0F9=K05^>DP1MUD@0J9/m07:O=`1hWST0MYTj07NG>`1a
VCL0Ki/^06bN9P1/XRX00P1VXb`09`1PX3<0FZ8g052T?@19/T@0A;e=04NlD@15^E<0?[=C03^fC`0m
]U80B:]H052QEP18X5<0?ZMB03^_E`0i[Uh0>JER03RFIP0kTFH0?HeW042@H01:T5l0D91P05BCF`1H
S5X0G8EC0668C`1QRe00J8UD06f:GP1YQV@0IW1V069TJ@1aH6/0PV9/08=/JP1mLf`0I7QW05IgI@02
05J0G`0W05:?D`1AWTX0CjM304jZ?P1=Yc`0D:8k056J;`1?VBX0C9`V04ZU9@1;XbD0BZ4R04bQ901<
WB<0D9TN056F5@1?TA80D8TA05Mj1`1MJ000HUl0065G001MC000FTP005@n001>>000Ac4004<]0014
;P00@B`003`X000i8P00=280030M000/7@009Qd002@H000S50007Q8000806Q0000H060l001L?000G
3P004PX000X500060@0=000000`0oooo000:0?ooo`L0000000d00P0000<100060P0020H000`5000?
2@004Pd001T?000K4`007AD0020D000O4P0081@000<091D002H09QX002LG000V6@00:aX002/K000X
7000;Ah003DS000h:000?B`003l[000n<000?R`003LW000f8`00<b00034P000f8000>BL003`/0010
<000AS4004Dd0018=P00B3/004U50018DP00A5d104IM0`1:F`<0Ce81059A001GD@00FEL005YO001H
J@40Ef`205A^0P80DWD302L0DWT305Io1`1MR`/0DYHA03fL8`0[Wd0089iK022QFP0SXE009Z1;02BM
D`0PVF<07i5e01n;M`0LQWL06XQf01R?LP0HTfh06I9_01^=M00JR7H06XUh01V<NP0JTgP069Mj01bI
MP0MVGD06i5i01Z4P00ILhH076>@01i?V@0U@Z009c^U034jZ@0o=ZH0Cc:U05X_XP1S;:000P1Z:Yd0
9`1a:IX0MBZH07D[UP1f:i80N2Z=07lVRP298hL0UQj;09`KT@2S5i<0YQ:?0:<@T@2O3i<0U0fF08T<
UP1o39L0KPfI05XBXP176JX0@2ZZ03PjZ@0_B:40:E2I02IDTP0PE8/07EB401UFP@0EFH<066El01Uc
L`0MNVh08WiW02F2HP0UQVD0:XQT02j?H@0^V5h0<9aL03BGF`0203VCFP0W03f=G`0mRF<0>hAV03b3
J@13RF80Ai1O04RCG`17Uel0@YMM042BI@11TF40?haW046;J@14RF@0B8QQ04>3I018QU`0BHQL04Z5
H@1:RV<0C8QT0567H01AQUd0E8AM05^0FP1RPTl0HXA<05R2DP1COEP0BWEP04M]I`19LVD0BW=Z055h
H`1CMel0EfAZ05iKJ@1_EVL0PeEM0080NUaJ02L0MEeE07MTB@1/OcT0HXLX06An601XKPX0J60106aP
001ZG`00J5d006MH001/G000Jel006US001^HP00L60006iP001`H000LV8007AU001hI@00NFL007YT
001hI@00NfT107][1@25QaX0PIL[0:24;02YKc<0WFU209]WA`2CGe<0Q5mN07MRIP1mJV@0QVAW08mK
HP2KFE400P2XFT/09`2/G440[5dn0:EJ>`2DG3h0M5YH071@K`1dEFX0LeYT08=LA02YERT0]4ho0;=<
H02[Ef<0YFMK09Q]E@2>J5T0QVmF08MbE02<Le<0SW=C095iB`2COd00Ri</082G602;RPX0SX<108n6
002BR000UYH80:2I702LSb`0Yi@^0:jB>02XUc80YHdd09N=;`2?RST0P94n07JF>`0207:Q>@0W06n_
=P1X]CL0JK]306VhD01X]U80KK1<06b[>01[/200Ik4U06:j?`1P`4X0HL1405g1@`1L`4D0G/1505^c
B@1LVT`0I8a=07AgCP1_O580Jh9P05V9I@1>TfD0CjQK052iB`1C]4l0D:IK05JCG01HT540GIE406>H
?`1WUc`0JYTj06nB?@1dRd00Jhm006>D>01SUc<0Hihd0080GZTb02L0Fjhe05R]>@1>Zd00AkE704O0
D@16^eD0@[EG03VdDP0m/Tl0?:iB04bZDP1FYDh0E:=<04N]B`0l/UD0?:eJ03VPGP0fRFH0=hMV03V2
I`0kN6@0?g5W04Y`K01>LfH0FF][06MQJ`1WHFL0J6MS07=XI`1iJf/0Mfm_07MXK`1ZHFh0Mee/08QM
IP2=IF80QVYO06U_G@1JL5`00P1EOU`09`1AT5T0CJ=?04RaAP1:/T@0Bj]404^W@01;XSD0Bih^04ZN
:01:WB<0Bi`R04fI7`1?V240CY<L04f@501DSa80D8X?05253`1DN`H0EF/105aP001NE000GT/005a5
001??@00BSP004Db0013<000@B/003hW000h8`00=20002lO000]7000:a/002TL000V5P008A<001hA
000201/>000601P>000G40005@l001<900091P000`803@00000<0?ooo`002P3oool60000000>0080
00030P001P<000T3000=1`0040X0018<000F3P007140024F000S5`008aP0020F000N5@0202@E000W
02PJ000]6P00:Ah002TM000/7@00:b4002hO000c8P00=bD003X/000m<@00@C40044e000l;P00=B/0
03PV000i9P00>bP0040Y0013<@00A3D004Th0018>@00B3/0054n001=AP00BDh004QH0017H`40B6L3
04eQ0`1FFP40FUX005iL001PHP00HV`005e]0@1LL040EFd10080E7P202L0EGd605B64@1CSaX0AITT
036L=`0SVE4089MU02JKH00/W5H0;9mA02FLF00PU6L088ae01n9N@0KR7T05hUi01F>N@0FSgT05X]i
01R6O00HPWd068Ij01R<N00HUgH06IMh01ZFN`0ITGl05XR001AkQ00FK8T06En?01a?V00N@Yh08CbT
02TjY`0d>JP0@CNW04ddYP1F<:D00P1H;j809`1L<Il0H3>M06DbV@1]<9L0L2nE078]U@1g:YD0PbNE
08`QU02F7I<0VaR@09/GT@2K59@0RA:H07P@V`1Y49`0FQJO04@PY00d;JP0;SjW02Y:X`0VE9X095b?
029PR00MGh406V=i01QVM00EJGL066ie01]fK`0OOVX0989T02R6G`0YRV00;HaN036DF`0cVe`0=YiL
03^HG00203Z@H00W03^5H`0lP6D0>h9U03f7JP12SF80@iAL04BEG016UF00@iET046BI`11T640@8iS
03f?HP10SeX0@HaK03n5H016R5X0BXYH04j9G@1@R600DhYM05J:F@1ER5H0FX=H05n1EP1TQD/0GX9>
059nG@1;NF<0AFeW04IZJ@17M6L0AGM_04YfK01CLFH0GV9[06ALI@1YFel0MEaK0080LfU>02L0L715
07Ae?@1]Pb/0J7`I06U^2`1ZH`@0I5`006=K001SG000IEd006IN001/H@00K6@006iT001^H`00Kf@0
07AW001fI000MVD007MZ001kI`00OV`007iY001oJ@00QGL<07^6602CTBL0WX100:Ue<@2UKCd0TVI<
08mRDP2;GeP0N6IL06UXGP1dKE/0PFaO08USG`2BG5`00P2GGeP09`2HJUP0UFiC09AWD@2BHe80SUYF
08]=GP29DEl0REYT08ATB02QHR`0[UPi0;1EF02UHf40WG9M09AbF@28Jed0Q6YH08E^DP2=L5@0Sg=?
08j3AP22US`0Q9XT08>93@2;Q0D0SXT0092<002HTPT0V9`A0:2I7`2OTBX0XI8`0:V=?@2RUCL0ZXPm
0:N6?@2IPT00Q8A007RB>`02072U=00W06nb<P1_^c`0KKY406fiC@1]/Dd0Jj]706j]?@1/]2D0Jk<Q
06Nf<`1S_S`0I<A006;4@`1K`T<0Fl1805NXC01HQE40N75D0:MRD02>K5H0MGUQ05b:I@1<UVD0Cj]J
04nlCP1@]UH0CjaI05RQC@1RWT00JY/j06NJ?P1XVT00JI`i06jH=`1cUSP0J9<f05jC<`1NVBd0H:@/
0080HJl^02L0Gk@`05^_<`1?/CL0AKM104RlD018^eL0@K]H03^fEP0k[Tl0>j]>04N_AP1;[d80C:Q7
04>_BP0i]5@0=;1F03FWG@0eUf/0=95[03:8K@0hKfd0@5ma04eOM01NHG00K5ee07iDLP1nEW<0Nea[
08AQJ@2>HVh0Rf]Z08A/J`1cK6`0K6E[079JJ01_I5/0KfQI05m/EP1FKeP00P1?O5`09`1<RU/0BZ9F
04JaC`18/d`0BK1704N/@P18Z3`0Bj<h04RO;011Vb80AILK04VG7P18Ub@0B8dI052:401FRPh0EXD:
05:02`1FN@P0FFl305QO001KDP00Fd/005M5001@?`00C3T004Pf0017<000?R/003LY000g8P00<B40
02lP000/7@00:Ad002LL000T600081L001dC000201d@000601X?000F40004`d000l900090`001@40
3@00000<0?ooo`002P3oool50000000?004000030@001@<000T4000<1`003`X001<;000E3P005Pl0
01XA000N4P008AP0028H000O5P007a@000808AH000@0:AX002dN000]8@00<B400P0_80008@0_8P00
<b4003LT000n;000@bl004@e0014=P00?Bd003TX000j:@00?Bh0048b0017=000BCd104Q40P17A040
BdP1055;0@1AD`40D5T104]K0@1<F`00DEh1059S0@1FH@40FU/005iL001RH`00HF`005Ud0@1EM`00
EG@205Md0`0205Mm100W05F23@1@SAl0Ai0a03VF?`0WUU80899U02BAKP0_T6T0=YEN02jKE`0WVEd0
8XmZ0229M@0MR7H06HMg01N7N@0ER7l05XV101R5P`0GPXH05h2501J7O`0DSGX05iQh01RGN`0MSh00
5hJ4015nR00?L8/04FB>01AITP0GCYL06TBM01dlXP0S>ZL0;3VX03PhZP13=J`0BS6^0080BC6]02L0
BCFX04lhYP1I=J<0I3:P06HcX@1U<jH0IS>W074_X01m:YX0RBBC094OS`2E78h0V1N>084FUP1X5IX0
DQBQ04DNY00c;ZH08d:U01eCX`0PFY`08EnC025UQ`0NJGl06Fek01YbLP0FNfX05H1[01R0K`0MPFT0
8XES02R7H00]ReX0;91F03:FE@0gW5D0>YmD03jPE`11UeX00P0nS5l09`0mPFL0?WmY03n3J@11RVT0
@8mQ046BG00oTEd0@Y9P04:AJ011S6d0@HmU042@HP0oTf80?I=G03^=F@0kQF40@H]J04b@E`1DSE`0
GHQK05Z7F@1JR5@0GHY>06F5C01VPDd0IHI805j4C01>P640B7MV04E]J013KFT0A7AY04IaKP19JVl0
E6AZ06QKK@1/G600IUmO06ePE`0206a_AP0W06An?01WQS40KX8M075c2`1/I`@0J5l106AJ001TF@00
If0006US001]I@00KVD006eY001`K000LFT007AV001hIP00NV@007UT001fI000O6L007i[0020J000
Ofh108R95P1lUbh0VXDc0:E]>@2OLc`0VFe608aWD01lJUL0M6iK06mbE01WJUD0LVIH08QQF`2MFEd0
YEAQ0080ZEQN02L0Z61N0:ITHP2UH5l0Y5eJ0:YFE`2`AeL0Z4]J0:5@I@29H5H0Wehe0:YN>`2[FEH0
WVMR09AeG`2?M5h0QVIP08IPF`27Ie80Rfe@091kBP27S400LZ0_07^B6025P0D0Rh0008Z5002>RP00
UYHA09:D902STR<0Z8`^09n?=`2VQC/0WH/i0:Z7?`2OS440Ri9107bL?@1fZ3H00P1d/2l09`1^]b`0
KkPb072h?01a]4T0L[A806jaAP1_/T00L[Hb076c8`1Y/Rd0Hk/f06?1>`1O`3`0Fl0m05g0A01H]Dd0
EieC06N=E@22PUP0MhEH06^9GP1KUEh0DImI056aDP1?^eD0CkAM05:bE`1KZTD0IIld06>I;`1OWSX0
H9Y006R?>P1aTC/0L8he06:D<01IV300FJ0_05Z]:P0205fe<`0W05bh>P1H/CP0Cjlk04J]@@17ZTP0
B;I?046iDP11/UD0@;5@03^^BP0n]400@[8j04>V?P10ZTP0=k5C02n`F`0^[6P0<j1e02nBMP0^QWH0
>6Uh04IBNP1HDG`0K4el08E;P02MB800V4ek09IEL`2PF6`0Z5][0:9NJ02KI6L0OV]V06iUH`1TGUh0
G6AN05Y^HP1ALF80CgAM0080C7QH02L0D8AJ04^MF@16ZeD0AZa>04J/@`15ZCd0AJDf04RN=P13WB/0
@Y`T04FG7018V1`0AYLN04V=5@1@R0d0EH<;05J02P1FOPT0E7L805Q]101HH@40FUH005];001CA000
CS`004Pg0016<@00@bX003dY000h9P00<b<003<O000^8000;1l002`K000W6@009AP002<E000Q4P00
0P0M4@001P0I3`00610001D>000>1`001`@000@200d00000303oool000X0oooo1@0000003`050@00
1`8000X6000=1`004@P0018;000C300050d001T<000J3`006Q4001hC000N6@008aT002DH000202XJ
000502dM000`8000;b@003<T000c8@000P0e8P00800f9000>bP0040]0011<@00AS@0044f0011<@00
?b`0048]0015<@00A3H004Po001:B@80Ae@504UG101<G@<0DF8405A[101@K@<0DFh4055X101EJ0D0
EfH405ES0P1JGP40GV0006EU001PLP40Dg/104em0P1:OPP0CX4>0P1?Pa809`1@R1d0B8X[04::=P0h
Sd@0:Y5K026@KP0RTGD0:Xm]03BBG`0_Ue/09iAT02F:K@0RQWH078Ef01Z5M@0HPWP05X>001J5Q@0F
PHT05gn;01ImQ`0CPX404hQm01JDN@0ITg`06Xj001J2Q@0CNXX0472=015STP0DFIL05TnJ01Q6W00L
@J008CfQ02PlX`0b>JH0?3BZ044][002048][00W03laZ014=:H0CC>V05L_Y01I;ZD0ES2Z05DdZ`1P
=:L0KS6P07/[U`239i40R2:@08`MSP1c6iL0EaZO040JY@0e9jD093fR01EEW`0DIYP05fZA01UWS@0I
Jh@06G1k01QeN00GOfd068eV01RAJ@0MRfd08XQT02F;G00[S5/0<91D03BHC`0gWdh0>Z9>03fSC`0o
We@0@IYH0080@I9N00H0@8]S03n:I011SV00@I1N042BF`11TU/2042BGP0O046BGP12Sf<0AY9L04JF
F@11VE/0>iQG03N@F@0hQV00@8aI04ZAEP1FSe/0GHQN05V6E`1GPe80FXM>05b4D@1OQ5D0G8MC05J1
F@16MfH0A7MT049gI011N6P0@W]V04A^K@19H7<0FemW079JH`1cH5T0IF5C075RD00206]e@@0W05b6
=@1LPb80K7/?06iV0@1XH000IEX006=J001WH000K6@006mZ001aK`00LVl0071/001`K@00LFT007ET
001gH000MV0007MQ001hHP00NVL007e^0022M0L0OX@B09:@8P2COd@0XWPc09e_?P2@M4/0TV]?08MX
E@1fLUP0MgEE07MdBP1`LTL0Lg9:07mYC@2;HTh0TeiE0080TemH02L0TV=I08mTF02?H5/0TEaN0:MD
E@2aD4/0[dY<0:]7EP2GE5@0VeU30:5O@P2LGED0TFaL08QjGP26Mel0Q6MQ08EQG024HED0QFa@08Ig
B`20SSL0MiDH08663024OP80RH0008b60@2AR`H0V9LH09R;;@2RSbd0ZX`e0:J>=02VRC<0UXXl0::;
@02>Ud@0NZA007>]>01d]2h00P1b]BT09`1e]BT0L;H]06nd>@1^/DP0J[=906ZcB01Z/d@0JKPa06^d
:@1X/c00H[Tg05nl>P1M_3h0G<0o05S0B01F^dX0D[UD05>]F01HWV40HY5N06N>HP1GVf40CZIH04b`
E`1;]V<0CJiP05:/C@1OZ3T0HIh]05jK<01NWST0Hhi206V3A`1fPdX0LXU406:@@01NVc/0GZTi05jb
=@0205Vj<`0W05Ni<@1G]2h0DZlg04b_>`1:/400B[M604JfC@15]U<0?kU?03RgBP0k]ch0?[8k04>V
?P16Z4D0@:i803baC@0j/UP0>:UQ03BOHP0]Uf40;hUT03R4K@13MGD0CV5g069GN`1hCH00R4Yn09a:
N`2YCWH0/4ma09eBJ@2?GFD0O6=M07AYE@1^KU80I7=H05YmH01DPf<0DH1S0080DXMI02L0Ci5G04^O
E@18YU80AJE604FU>@14Xc00A9`Y04ND:P17TbT0BIHY04VC8018V1d0AI@K04N:5019Q`d0Bh4<0560
401COA40CgD;05=]1@1GH@00F5H005U;001C@`00CS/004Pe0010<@00?2d003XZ000h9P00=2H003@T
000a8`00;1h002TK000U5P008Q@002<E000O4`000P0L4@001P0I400060d001@:000<1`001`@000<1
00d00000303oool000X0oooo0P0000004P000@001@0000H1000:1P003`L001@;000E3P005`l001PA
000H3`005`h001/A000M4`007A40020E000R6000:1X002XM0080;b0000<0=Al003PT000e90000P0f
9`008P0h9`00>bT003TV00109`00@R`004D^0016=P00AcD004@d0015=000ACT004`o001?A@@0CeD8
04]N2`13KPh0@W4;04Md2@19N0L0B7h704ao1P1?O@H0E7/805=h2@1DL`X0F6/605mT0`1TJ@<0IVd3
05mj0`1EO040AX0404>64@10RQl2046=:00W042=;P0kRCT0?HDn03R9B@0bRf009Xi^02:?L`0XSf`0
;I5P02NAGP0QTFH08hm]02:>M@0MRW@06H=d01N1N@0FQ8405HJ:01J2S`0ENi004WN?011lRP0@P8P0
58V501V:P`0JR8805h:501IkQ`0GLHX05VJA01QMU`0JDid074ZN01m5WP0R@9d0:3bO030gW`0g;Z80
>bRV0080>bRY02L0?2^W040]YP14:jP0BBVY04L]ZP14<Z/0@3NZ04XhY`1J=j@0Jc>M07<^U`1b:9H0
LbBE05dSV@169Il0<B^Q02XjW`0PC9/06UfE01Q/SP0IKhP06Vb501Q_O00HN7<05hA_01Z?I`0NV6D0
89UX026@J@0YRV40;8]J036=E@0fTe00=Yi<03NUBP0kYTh0?JE@03^QE00nVUX00P0oUE`09`0nTf<0
?Y5O04:EG00oUUT0@Y=L046DG@0nU5h0?YIL03nGFP0mUeP0@iMA04BKC012WT`0?Ye=03^HD00lT580
A8mE04fBE`1ESUl0GXQO05^2EP1IPd/0EXU;05N9DP1FR5l0DHQN04YlI@0oJV`0@7AV041jIP0mOf/0
A81/04Y_K`1@GW<0GUaW079JH01cHE@0HVM<06MWCP0206Qj?00W05n2901SNa<0JW4806]U0@1XH000
JUl006UO001[I`00L6/0075^001dL000LG40075/001_J`00MFL007EU001hH@00Mf<007QS001fI@00
NVL007]^0P1mPQ@0MY4R09Z4<@2PJDT0WFli09U`A`2=LU@0Pg9I07=eG@1aMEL0MfEG07aWD@1jJDh0
MVI@071QDP1fH5P0MeaN0080M5US02L0LUYX07=IJ01jCfd0ODa[08aEG02ZE400[d/k0;M3?@2OBDd0
VU5C09MLD`2:IE/0Q7IM08=mHP25M5h0RFQO08=RE`22JED0PW1E07enB`1nR2X0PHH;08=k0@24N000
QWd008Z:1@29UPd0UY/L09f7<P2MSc<0[8Tk0:2>>02ETCH0SI<n08jFA020WTH0M:I107BY>@1g]C40
0`1e]RD09P1g]SD0LkLm07:dBP1]/4`0J;5?06NeD@1T]CP0IK0[06N^<P1Q^3/0H;Ln05^fA01F_TL0
D/1504g1A@1@`4`0CZm@05JIE`1SSEH0IhUI05N?GP1=Veh0BJQT04NTK@17XfT0DZ]905ZR<P1FUS00
E94j05V?@01JTD40G9A105nM?P1QZ3X0G:Xh05ja=01N]S80GKP/0P1K^BT09`1I^BT0FKD]056g>P1<
^Cd0C;M604b_C01:]T`0AK]@03g1D00f_T`0=;Q303Nc@00mZTH0@Jm8046cA010]d<0>kID03V^F00f
XeH0<jIA036XD00d[U`0=i]X03YgL@16IgD0F5Al07a9PP2N?hH0ZCf00;0nO02?AWH0Me1_07AKJ@1f
HF40NfEQ07e]I@1RPF@0C8YS04^@H@0204RNF`0W04ZVF015Z4l0AJ]404BV=P15Y2H0AYhO04VH7@1:
Tb00CI4R04nA9`1?SR40C90K04V@6018RQD0AHH>04B03P18OQH0BWXH04Y^4@1?I@H0CeT105EB001A
B@00DT@004`n0014=`00@C4003h^000j;@00>BP003<W000d9000;b@002lO000Y700091L0028C000T
50008A<00080714000H06A0001H<000A2@003@L000L40002000=000000`0oooo000:0?ooo`0D0040
00010@000P4000H2000;1P004PX001H@000K4P0071@001dG000M5P006a@001lD000Q5`008aD002HH
000S6`00:1`002`Q000b900203LW000W03/[000l:`00?2T003TX000h9`00?B/003l^000n<@00@2h0
040_0012<@00@cD004@h001:>`00BCh004U70@1>D@@0Cf4=04eb6`17Nad0?X8I04254`13R0`0@h@7
04V41P1AP0D0EGl605Eo201FOPl0EGX<05Md1`1NKP@0I74706=i2P1PP0D0E8D204V7200oRaP0>I8]
0080=i<e02L0>Hhm03R8@`0eQTD0>8M=03>8H00WSFh08Hib02B=K00VSf008HaP01n8J00QT6T08Y9^
01^=KP0HQ7405h9i01F9Q00ERHh04h2C015cU00BKY403g>>00iiS@0AP8/05HB901V5Q`0JQ8D077f4
01ecR@0JJ9807F6H025GW00RCYh08dVM02E4V@0X>iX0;3:H03@VW00g8J800P0g8:D09`0g8JD0>R6V
03/OZ@0m8J/0>BRZ03@_ZP0_=jT0=cbZ04PmZ@1K>JH0Gc>O05``VP1J;9T0BBbJ03HdVP0S?YT07djH
01iIU00JI9405fn901QbP@0HKgh067=g01V1K00IU6L07IeT02:RHP0TW6<09YAU02b=G00aTU<0=Y9=
03VJB`0lXdX0>JQ;03fXCP0mYU40>Z5B03fMF@0203fKG@0W042HH@10VEd0@I]J04:HFP14Tel0@iER
03jFHP0oV5L0?IYA03fJD`12VTT0@9e103jO@`0lWdP0?Ie>042KD018UE40Ci9F05J>H01IREd0FXM@
05R5@P1ER4L0EH]@04n?G@1:S5X0@X1N03i^I@0nMV00?WmR0422K@19Ofl0DfU^05mIK`1UGFD0MeUR
07EUE@1ML4/0EVmB0080Ggdf02@0IWlF06Yd1`1[K@80JF@006YT001YI@00JfX006m]001`K`00Lfd0
079`001`K@00L6X006mX001`H`00LF@007MT001iJP00NVX007M_001kL@@0PWd<08F?8@25Qd00WWLf
09E]A`2?MDP0Tg1E08QaGP1jMed0KgQQ06mdFP1dHeH0NfIA07i[DP1iJE8207=XF@0I071RH01]H6H0
KF1V071MIP1hDf`0NdQb07]1L01oCUl0Re970:=>>02k@S00Yd=>09I3H`2:EV00OF]M07MnG`20OF40
Qg1O08UVEP24IU<0QVeC08IkB@1kU340QI4G08B31@02085g000?08Am0027Q`L0QiL?08jP7@2NSBh0
U8he09n:@02?ST80R8i6086EBP1iWD`0MZE;07J[@P1eYT00N;@e0080LKDY02L0L;DV07:i=@1c^ch0
KkM106j[A`1/Z4h0Jk5A06V`@P1X/b/0IkHY062e<01O]CL0F[4o05NiA01B`4L0D/1404nlB01=[dX0
CJ1;056EA01>TTD0CY9A04^HE@12WEl0@YYQ04>OD`1?XT00EY<m04j3@P1@NTP0EWi605N@>P1HWS00
EZXZ05Jb;P1K/c<0FkDa05Vj:01F]bL00P1G]bD09`1K]RX0Fk<b05Fb?`1B]440D;=6052YB01B]d<0
Bl17042mB@0g_4D0=KY003NdA00g[4P0?[1<03n^BP12/T40?KQ;03ZbD@0gZUH0>:QD03NXC@0g[e<0
>:IQ03V@I`0mPV/0AWId05A^N`1UJGl0KFAo075SO01UHWH0G6Q]05adIP1QOF<0I85R06YnH@1FREd0
BI5J04JJEP02046VE00W046[D010ZTT0@JTl042U<013XB40A9`G04RK5@18V1`0CIHO04fE9@1?TR80
BXlL04Z<6@16QAH0@h4@04Ak3014NA00B70@04YU2@1>EP80DTh00559001>A000D3l004dk0016>000
@C<0040a000m;@00>2/003LV000e8`00;b4002`M000X600091L0028E000Q50007a800080714000H0
5`h0014=000A20002PD000H30001000=000000`0oooo000:0?ooo`0:004000020@00108000P4000=
2@0050h001TC000L6@008Q`002@L00808AT000P08aP002DK000Y7@00;Ah002`O000[8@00;R@003LX
0080>RT002L0?c0003lc000n;000>B/003/V0010;P00@S@004Df0015<P00@cD004Df0019?000CD40
0515001@BP00D5P304iZ2P19O1d0@hLb03f=<@0jTRT0?I@N03jB4P10S@P0AXX50566101IPPD0Gh08
069o2@1PN`P0HGD506Eg1P1NNPT0G84805R:201CS0D0C8`<04NB7`0mUSD00P0gTSP09`0kScX0>Xm1
03:@A`0_Sdl0:IAL02>FJ@0QUFl08i=X022BH@0JS6<06XMV01fBIP0PU6/07Ha[01R3M00HPGX058R6
01>6U00@NIP04FNI019RUP0DJ9<04G6@01=gSP0DO8d05h6901^2Q`0MNXX07W:?01aWUP0OHid08e^P
02IFX00UD9l09dRK02TnV@0/=9T0<BNK03@QW@0203PMXP0W03TNX`0k7jD0>ajX03XQZP0d:ZT0;C2X
02LiZ00[@:X0?4:Y050nY`1@=j80B3BN04LbV@0j=ID0:D6C01Q@T@0HHHl06FN?01M/S00IL8H06G9m
01Q_OP0IMG@06H]X01^PHP0QZUl08ZUN02BQG`0YVF40<IIE03JLC00hWdP0>J=<03^WC`0jZ540?ZUA
03nUDP0mWUH0?9eJ0080?YaJ02L0?YMM03nGFP10V5L0@iMH04NDFP17VUL0@ia@046MB@0nWDP0?9a:
042NA00nX400?:5503bPC@0mWe40?j5E04VME`1<V5`0BXiS056:G@1CR5<0EH1<0564C@1ARU40C99I
04B@F011QET0?G]L03moFP11Q600@X9[051kK01PJfT0LeaS07APEP20Gdh0NfM805iaBP18M4/00P1J
NbT09`1XN`/0JG0006Y^001YJP00JVH006eS001]JP00Kfh0079a001dL@00L6/006mX001aJ@00LfP0
07AV001eJ000MV/007Q]001jLP00O7X207Z23@1iT1T0T8`a09EeBP2EN400RGA907]jDP1eMEh0L7=P
071dH01bKF<0KV]O06eTFP1cIeL0MVaE07=`F01XKU`0IVmS06aZJ@0207AWJ@0W07iPIP2AEfL0VDY^
09PlL@1nA6T0JdiN07iAAP2[ACP0WcmB08e0I`22E6P0LfQR07=gH@20MV<0Qg5M08a]D@26L4l0RGAB
08J;@@1kXAd0Pi8;08J60@26OP00Q7X008N0002;R0P0PidD08bP:02MRSH0SHY008b:AP21ST/0O8m<
07VHB`1fY4<0Lk1007Fe?`1f]Ch0L[M00080K;Lf02L0Jk@d06^c>01/^CH0J[Pd076a>@1`/3d0LJi8
07:[@01b]Bd0K[TQ06Ni9`1U^3<0H[Hl05Vn@@1J`400EL1404jeCP1:We@0AHaK04AlF`14OUd0B8=P
04>6I@0nS6X0A9MH04NN?`1@VcH0E98h04n;@@1>RTD0Di0o05JN<P1IZ2L0EZlT05N_:P1G[2d0F[0V
05Vf801I]Qd00P1I]2009`1L]R<0FkHU05Rd<01G]SX0D[Lo052hA01B`DD0C/1704FjA`10^D40>;/o
03Rd>P0jZd40>Zi803b`A`12/SX0?;Dh03ZgB00i]EP0>:YE03VND@0dVe<0=IIR03F=JP0lPfd0?Wed
03miM`15MWd0B7B204UcQ019Kgl0B79c04iiL@1@PG00D8=^04n4K019R6H0@I9O046KE`0203fTE@0W
03j[C`10[400?jLc03fT;@0lX2<0A9/N04>K6P12WA`0@Y`O04JG8@17U240AhhP04R86@17PAL0@h4B
041l2P11M@/0A6`<04iM1@1;CP40CTP004i7001=A000CD4004hl0018=@00@S8003`/000h:000>2H0
03HV000c8P00;R4002/N000Y6P009AP002DE000T50007a@00080714000D05`h001<<000>20002P@0
00H3000>000000`0oooo000:0?ooo`0D008100050P001PD000X5000?1`005@`001TA000R5P008aX0
02<I000T6P009AT002LK000/6`00;Qh002hP000_6`00<1l003<R000f:00203P[000W03l]0010<@00
?2h0040/000m;@00AC4004De0016=@00B3H004Pi001B@@00ETT005]A0@1LF@<0F6D<051a5`18P2H0
?h/g03^DA00iVD00>I`f03ZJ9@0iVa@0@IH804N?1P1?S0H0EhL805f92@1NQ`X0GXH905j32@1JQP`0
EHX>05:;2`1?S@X0D8l904f?4@19UBD0@9Hl0080?Hlm02L0?Xdm03j;A00bSU00:heF026GF@0NVf80
7iQZ02BCIP0PTf405XiU01R8J00LTFH0799]01f=K`0LQ7406Wmi01MoQ`0CNY@046ZG015HV00CDYL0
5U^C01EXT00EKh`05WF;01MiRP0INXd07G:C01aZV`0JHj406fBS01]UX`0MHj407U^O01mBW00SAiX0
9cfI02`aU`0b:YT00P0f9Y`09`0j9Yh0?2BQ03dSY@0m9:H0=bVW030_Y`0]=JP0;T:Z03I9ZP0mAjD0
>D6P03=0VP0_@I<0:dN@02=?SP0HF8`06Fb701QfQP0IO8806gil01YoMP0KOW407H=Z01nGI@0OYel0
8JeM02J[G00ZY5`0;9iM032ODP0cY4`0<jM903JYC`0jZU<0>J]F03ZXE00kXE80>i]H03jKF`0203jI
F00W03jFF@0nUEL0@iIE04FEE016V5D0Ai]=046Q@P14Y400@j8m042Q@@0nXd40@j9004:RAP0oXU00
?Z1B03jQDP18X5T0BI]O04JBI@1;S5h0CHAF051hEP1<O5D0CX]E04NCG@13SEd0@HAL03imHP13PEd0
@giR04IdK@1DKf/0IfIV07aNG@1cITl0L6Y;06e[A@1RMCP0EWTW0080HgXC02L0I7H606M_001XK@00
K6X006mW001^I@00LF<007=/001eL`00Mfl007MY001eJ000MFL007QV001jK000Nf`007U]001kKP40
OGT907^74P1oU280PY8c0922@@2BK540PgIA07MkG01QPF40G75U069ZI@1aJVH0MFUV071ZG@1_J5L0
MF]H07EaF01_Leh0IWEQ06=dJ01ZKFX00P1dJFX05`27H6L0V5YR09a?H02J@6<0S49V07M9J@1_E4h0
WTTj09a3E029@V`0OUEZ079XHP1eM600QGAU08adF`2<NE00Q7e@07b5D`1iV3P0N9hA07f@1@22R040
Ph800080Q80000h0S8d<08FL7`28VC00THPo08F<B`1nVDL0MIY>07>BC@1cUDT0M:Dn072_>@1_]cX0
L;Ln072e=P80KK@c02L0KKHa06fb;`1_]RH0L;LR076e8P1a]bh0M;<i07Nf>01e^C40Lk`Q06^k8`1/
]R`0IkLg06>i>01O`3H0F<0l056fAP1;Xe00AiE?04Z8D01?SDh0DhmA0568E@1<Re<0BiQ<04fH@@1B
TSP0D9Dg04^H>P1;WcX0CJ<e04n/;@1E[BP0E[4]05J]<`1FY3D0FJ`/05Rb9P1I/b800P1N]B@09`1M
]B80F;PV05Ni<01F^Ch0DkU2056kB01@_D/0CkQ804f_A@14^4D0?<1003Fg>`0h/400>[=803ZeA@0n
[cL0?[4_03be?@0l^T/0?[1B03bPD@0kV5L0>I1R03b:J011PVX0@W]a045fL`14MWP0B7Mo04MgQ@15
MH00A7N104MfP017MGh0AGIi04:0M00jRFh0>iAR03JNF`0203ZVFP0W03Z^E00m[DH0@:Lh03nR;@0j
X280>IhM03^L700fWQh0>Z0Q042K7@16TaP0AX`G04V35`19Oa<0@gh@045i3010LP`0BVT<04UC101:
A`00CT4004`o001?AP00CD<004Tn0015>@00@c@003/Z000e:P00>2P003HU000c9@00;b8002/S000[
6`00:1T002DH000V5P008a<00080714000D06Ph001<<000?1P002@@000<2000>000000`0oooo000:
0?ooo`0D00H300081P003`P0018;000D300060l001`B000R5`0091/002HK000X7@00:Ah0030N000^
8@00;R8002lQ000`7@00;Ql003HR000h:00203T_000W03`^000m;P00@Bh0044b0011=`00B3X004`k
001A>P00D3l005A6001LDP00H5l3061]1`1INQ80ChPW04F:>P0nS4d0>XmB03FJDP0dWdL0=9m003RL
:P0mVaH0@YP;04^D2@1<TPT0Ci8@056B5`1FU1T0Ei8C056B501=UA/0BIPK04JF6015Tal0BI<P04ZE
9018V2`0A9`d0080@iHc02L0AI8g046>@00gST`0;X]A02>HD`0NWUP089aP02>FH`0MUf805I9V01J;
J`0HTF`06i9a01^=LP0OPW8087Yg01YdQP0EJi<055jD019:UP0DAYH05e:D01URSP0KK8X06G2901Mb
RP0HKi8066VN01MTY`0HGZX066>Y01UYYP0HK:D06V>R01YIX@0QCYd094JK02XjUP0c<Y<00P0k;9H0
9`11:iX0?bbM03hZX00m:J80>2ZS03@ZYP0b<JP0;d:Z02m?Z@0_DJL0:4jN021?UP0MD9407UR=01]J
S`0FH8l06GB201^3O@0KQgX06hYc01b?J`0LTfL07iES022NGP0QZ5T09J]F02ZZE@0`YeD0<jAG03:S
DP0bZ4l0<:Y@03BYE00fZUH0=JaH03NWD`0jXU<0?IUI03nGF`0203jFF@0W03bAEP0kT5D0@Y5B04BB
E015UTd0AYY404BT?@15YS`0AZHj046R?@12XT80AZ9204RSB014XU<0@9eB03nOD`13WeL0AIUN04BB
HP17SEd0C8UF0520FP1:QeD0BXmD04J@GP10RFD0?X9U03alJ@10O6X0@g1Y04ULK`1GGfX0K69Q08ET
D`1dJdd0IFa;06I]@`1VNBD0HWT;0080HWL702L0IW@206Q`001]K@00KVd0075]001cJ@00LVP0079Z
001cK`00Lf`007EZ001eJ`00NFl007]a001nM000Ng<007id001oN0@0OHPD07BL9P23T400OWiD085i
D`22JeP0LgmE06B5G`1ER6<0DGeW05YiJ01VMVH0L6mS079aF`1bL5P0MgAJ07UgFP1gMel0LgMM06ee
H@1/K6D00P1aIVT09`1oG6`0QU5^07UMFP1bHUT0QE5F08U9HP21FET0WUI;09EED`22DF@0N5aP071T
G@1fK600QVYW08YdH@2BLe40R7e@07>=C`1eW3<0NiX<07n=0P1oR000PhD008>20020Q000Rhh?08ND
:@27TSX0QhY4082HB01gYTD0KJE9072SC01][4H0K[Dm06jf=P1[]C<0K[H_06fg;P0206^g:@0W072h
9P1c]B40MkHK07Jf6@1g^1/0MkTS07Bh;@1e^C80MKd`07Nl:@1^]R@0KK8T06Zb:P1W]2/0JkHa06:g
>01H/4<0BYMA04FIEP10WU@0A:=:04^QB01;VDL0CI97052:B`1<RD@0CHdm04fI;`19X2P0AZLT04VW
8P1@ZAh0DjXP05J/9P1F[Rd0Fjl_05je;01M]BH0G[<T0080G;@W02L0G[@W05bg:@1G]ST0E;Q105Bc
B@1E/d/0DK]<04nfA01</ch0B[Pl04?0?@0n_3/0?kHf03Vf?`0h]Sl0>[0b03f];00n/CL0?;E403Zd
D`0g[5X0>ZQQ03JQJ@0eWFh0>Y5c03V7M@0iPWP0>Gmk03YoP00kPHD0>X6803inS@0nNXd0@7J8049e
P`0mPWT0>Y1b03NMI`0bYEX00P0c[UX09`0b/5d0=jeC03JZB00dYST0<j<`02nR:P0aX2L0<ilU03JM
900nUa/0AhhB04J:5@15PaL0@h8A03n13`0nN0X0@Fh604UN101<BP40B3h004Ll0019?000BCh004Tm
0017=`00AS<0040b000m;P00>b`003PX000f:000<RH0034T000/8P00:ah002XN000W7P009aP0028E
000201`B000601L<000B2`003@H000L300030P000@003@00000<0?ooo`002P3oool0500:1`003`X0
018>000H40006A4001hC000S5`008aP002HI000[6P00;Qd003<P000g9@00=bH003XV000f9P00<bH0
03HR000h9`00?Rl00P0n<P009`12<@00AS8004Lf001:>P00CD8005A7001JC080FU4505mK2@1UJ0T0
HgH<06243@1DSQP0BIP]046JC@0jTf80=Xe[03>AJ00bVe/0<Im=03NP?@0lX2P0@IlH04JI3`1BU@X0
EI8805NA2`1JTPh0FY8@05F@3`1@Ta@0@iTR03nN9`0iVc40=YHn03ZE@00nVT40?I/k03nO=00203jM
=@0W04:I>P0nU400=hm9036:CP0UVdh07j=A01bPF00NVF406iUS01FDJ00GSVd069=b01VAM`0MS7D0
7h5c01mgM`0KKH<05V6B01AAU@0D@9L05S^G01I7U00HFHh06fJ;01][RP0HK8l05VVH01ITXP0EGjP0
5eZZ01MPY`0FJJ@066ZO01YOWP0NEYX07dfJ0259V`0V@9D0;3^B0080=3NA02L0>3JD03DeU`0e<I`0
>BnO03H_X@0e;JD0=3>Y0355ZP0YE:X08eZQ01UKV@0CG9403ej>01EUS00GIhl066R=01]kO`0KRgD0
7I5b022EK00NWF@07j9O02>QFP0UX5T08jQD02R[E00_[540<jUA03:UE00bY5H0<:QE032ZE00bZE@0
=:aE03F^D`0hZTd0>jM;03jQC`11WTh00P0nWD/09`0nW4T0?iQ704:IA015V4<0A9a204JN?@13YS`0
@jXl04NW=`18XCd0Aj9604ZRA@19XdX0@j5B046LD`0oW5<0A9YG04BGF`0nTUl0@haL04Z:F@1?Qel0
AY1I04JED`10Se`0?XMT03moI@0nNV`0?gM/04I^K@1=GFd0FeiP06aTE@1oJTP0L7E505ifA@1PNC`0
HWdJ05]`0@0205i_000W06Ac001ZL@00KV/0075Y001cL000MVd0075[001/I`00KVP006iV001bJP00
N70007]g001nNP00PGd207j12024QQ40QX`M07ZH:`1bVCl0NH]<06n1EP1`PU<0Ih5C062@DP1HSV80
EHYW0562I`1KPF80JGeN07MfF@1iMeT0NWIJ07agF@1oMel0O7QO07UcG@1kKed0NfIQ0080OUYY02L0
PdUd08HkN01`HV@0KX9V07aUE02]B640WEiQ09YRE@2=G5H0NEMM079NG`1_HeX0LfUP08EWI@2<KV40
TG1H08QlCP1`U3T0MiHL07n;1P1lPP00O8<007n10@1nP040Q8<008^A3`2>T3<0R9Hl07ZI@`1gYTL0
LK1507:aA@1]/d80IKPo06G0?@1]]SL0K;D[076f8`1_^2L00P1`]BH09`1`]RD0M;HQ07Bd6P1b]1L0
MkLL07Nh801e]R40LkTT07?1;P1b^Bh0L:X]06fb9P1]/b/0K;<]06ji<01V`3@0GkHj05JPBP18Z4`0
@Ji<042^B@17Z4/0BY]A05::E@1KLE/0DGYA04R;@@19VB`0BZ@S04BZ8P19Ya`0CZDD04nV6@1CZ1l0
FZ`X05^b;@1L^S40G[X]05Rh;P0205Ni;`0W05Fg;P1E]SP0EKI7056dBP1D[e00Eji=05FfC01A^480
CKLf052i<`1>^Rl0BKT^04Nf;@0o]3<0@;8c03j_;P0m[c<0>[9803J_FP0dYVP0<Z5d03FMN`0dUH<0
<8Z802f0SP0bOI00<GJD03AbT`0fKI80>VZC045VV01:HIT0CUnI059PU01AHXh0BG6704:6P00kU700
=ZAV0080=j]K02L0>JaC03JXC00cZ4H0<ZM102nT>00ZXc@0;:0^03:M:00hV2@0?Y0J04>84`15Q100
AX4?04F0300oN0T0?Vd504=T0P1<E`00CDD004Q10016?@00BCh004/n001:>000ASL004@c0011<@00
?B/003/^000l:@00>BP003DW000b8P00;R4002lQ000/8000:A`002DI000Q5P000P0I4@001@0D2`00
3`T000`500050P000P4000h00000303oool000X0oooo00`03PT000l=000G3@005a4001TA000P4P00
8AD0020C000Q4`009ad002hN000g9@0203dX000603/Z000j;@00>RX003TZ000k<000@3800P16=P00
9`18=`00CCD004ho001AA`00Ee0005YI0@1PI@L0I74@06=k6P1OR1d0EY8N04ZJ9013Wc00>Ym703JD
G`0dRg40<i5_02jHK00XW6D0;Z9B03RU>`0mYBP0@J<O04^N601CVa80FI@@05VD3@1JU0h0EiH=05>F
3@1>Ua40AIhL03bO:P0iVc/0=YA;03VBC`0dUDd0=9E803BM>@0203RN=`0W03RN?00gVD00=Y5603>9
C00YVDX08J9901^SC`0LWUH06iaL01RHI00JTfT06YI`01ZDM@0KRWH07G]g01e`N`0JJX<05V2?01IA
U@0F@IP063^E01I6T`0HEXd07F::01i[R`0JL90066jG01MYW`0EHj<05EjU01EPX`0HIIh06F2M01aD
W00NC9`084VL0258VP0RAI@094RA00809TJ?02L09dJ?02A1T`0Y?IL0;CVK030iWP0^>Z40;3nT02U=
Y@0RFZ8076>J01UTT00FHXX0562<01E^S00GMhl067j:01^8N`0MTG007YM^022MJ00PXf808JAK02JS
E`0WWeD0:ZIB02f]DP0c/4l0<Ze@036XE@0_YET0<ZQG032[E`0cZeD0=jeC03J/C@0j[4P0?jY704:Y
A`11Z4D00P11Yd809`10Y440@:93046P?@13X3`0@j0j04BR>P12Z3h0@JM004ZU>`1?Wd80CYi8052Q
A@1<X4X0A:1E042KE@0oW5D0AYYI04:GE`11TU`0@HeL04^@G01>SV00AIEJ04>FD`0oT5`0?HMR03io
IP13MW40AG5`04Q]K@1@HFT0Gf=L06]YDP1iKTL0IW/m05J5<P1EPb80G7T>05M^000205]^000W06Mc
001[L@00KVl0075/001aK@00Lfl006iY001/I`00JFP006aZ001eK000Ng@007am0@21R0<0Ni8707NH
5@1cTBh0LhY007>;A01_S4P0JH]>05j8F@1LT5D0Ei5L05>LF01@VEX0D8mI04n;E`1JPeP0IgQI071d
F`1gOEL0OWiJ07mkF01mNe/0NgQL07]bH01iKV40NfUS0080ReaZ02L0UdeZ09LmJP1oEVD0KVeP08IQ
GP2^B6T0VV1W08mWH@22Ie`0MVQN07AYE`1`IUh0MFEQ08aQG@2?K5X0T6iJ08V1A01eVal0NXh>07em
0P1kM@00O7T007b00@20O`40PHX208bG6@2ES3`0Q9M407BT@`1eZDP0MJm707:^A01[]d40J/1006Vk
?`1[]CT0KKD`07:e:P1a]Bd00P1d]B`09`1f]240N;@K07Bc6@1d/QL0M[<K07Nd7P1f]a`0N;LP07S0
:P1f^bX0LkP_06fi;@1/]S80Kk8e06fi<P1W`380H<0h05JeC01>/dH0Ak9204Nb@01=Zd80D9M905:8
CP1GO5L0Ch9:04^>?@1<VBX0Bj@P04>X8013Z1/0@jTJ04^/7`1>ZbT0Cjl_056e<`1F]c@0FkLc05ji
<@0205bk<@0W05Zh=01H]TD0E[9?05JcC@1F/dX0EkA805JdA@1D]c/0D;@^052c9P1>]2H0B;@V04Bc
:P10/B/0@jdY04>[:P12[SL0?ZiB03VOI00iRW00>X5j03enQ`0iN8T0=Vn>03A[UP0hJi/0>6VL03aT
V00nHI80A5^D051GUP1HDi40GEJ;05mLQ`1GHhP0Cfn904ImQP0mRgH0=iUV0080>J=D02L0>j=703ZP
@00gXCL0=:4f03>Q<00]X2`0<9l[03BJ900gVB<0@I0K04:<5013QPl0@84<041j2P0oK`H0?f0204EI
001>C000CD@004do001<@000CT0004ho0018>P00B3P004Df0014=P00@38003T_000j:@00>BL003HV
000_9000<20002`Q000[7`00:1`002@H000O50000P0I3P001@0D300040P000P500040P000P0000h0
0000303oool000X0oooo00@04@X001D<000H3@0071000P0J40002@0L3@006Q00024B000U5P00:aX0
03DQ000i9000>bH003TZ000203XZ000303/Z000o;P00A3000080B3H002L0D3T005@n001FA`40FUH3
05QW1P1NM@/0GX0C05j<8@1CUBh0Bi`a04>Q<`0fXcH0<ZA202nIE@0_OfX0:WYi02^?L`0XUVl09IIZ
02bRDP0eZ3T0=ZT^03ZW:@12XbH0AihU04jL8@1@W1l0CYlN04bO6P1>WQL0CIhK04BR900lY340>J52
03RJB@0jU4T0=I1:032=B00bST000P0gSSl09`0fU3d0=i`m03>K@00_UDD0:Yi3026S@`0KY4L07J9;
01^PD`0LVF406iEZ01VFL@0GTGH0689m01U`OP0IJ84066J601MOT00GDIH0646I01XlU@0GAI00652;
01UNS00KJX`06gB@01]cT`0HLIT056ZN015SX00BGJ0055fL01MFV`0LBI/073nO01i2WP0OB9h07d^J
01iAUP0201aEU00W01YDS@0ICHh07TJB02M1U`0ZA9T09dJM02M=W`0SEi`06V>K01I/T@0GK8L05fR3
01IRQ`0HMXH06HF601ZAQ00OTgL08IQ/022LK00NWVT07ImT01jOG00TXEL09iiC02fSD00_ZE40<Ji=
032^CP0^ZU40<:QH036ZE@0aZeD0=JeB03V^BP0kZdL0?Za2042]?`14[Cl0A:`h0080A:Tg02L0A:Dn
046W@`10YS/0@ZDi04FR>P14Xch0@:I204:TAP19XD80DIY804nMBP1?WTP0CIe<04NKD`15VU80@Y]C
04JJEP17Ue40AI9C04F?D`1;TU40C9AA04>KCP11VT`0?Y9F03j:H@10P6H0AVm`04M[L`1?K6T0GFEQ
06MUF01_Je00N6m<06>2>@1DS240DH8B05Yf1P1LK0000P1SL@009`1VM000K7D006mc001bK`00L780
06e`001_KP00Kf/0075`001hN@<0OX@8086=301lUA00N:8C06^V5`1UY2D0IY@k06V=AP1_UD<0JZ14
062UC01CYU<0CZUE04^UH@1>XEl0CiMG056BE01CQe00FGaF06=aG01XJ6@0Lg5R07eiH01mME/0OG1K
07i/F`21HVD0OV5Z07mRM@0209=LL00W0:Y@F`2_@ED0SDiX08=ALP2KDFP0/DM]09IMKP23Jfh0O7IU
07]gF@1lM5@0Nf=Q085RG@2@HU@0T6iA08MjE022RcX0O8lD081n101kK`40NfX007aa001lO000QXH7
08^@402:UR<0Uhdo07nMA01cYTP0LZ1@07:LBP1_Y4L0KKA506JiB01Q^4P0I;Q006jd?P1`]SD0LkPc
0080MKT]02L0MkXR07Ji701f]QT0LK0C07F]4@1i/AL0O;@H07bf6P1i^1h0M[TU07?0;`1[^c80L;Db
07:_=@1a^300KL0Z06C0=@1K^TL0Dk=604^_A@1;^Cl0Cjm1052>C01BRDl0CHU=04n8?`1@ScX0Di/W
04^S7P13Z240@ZPM04B[8015[2X0C:hd04ba?01@/4<0EJi205Z_@01N]D000P1L^3l09`1J^T@0FKQ?
05Z^D@1H[TX0F;I705^g@P1J]C/0Fjl^05F[8@1AYaP0CZTI04Z[8P18[RH0A:`[04:Z:P12Ybl0@J=7
042DH00oPFd0BG1i05AXQ01AKH/0C6j804a]R`1;Ji@0A6NH041WU@10HY80@ef@04ULT01=Fhd0BeN:
04iLP@1;GW`0B6]l041dO`0mOX00>8Md03^BH@0203fJB`0W042K>@0nW340?YTZ03fL:`0iVB40=iPP
03RL800mVAd0?9HM03jB600oSaL0@8XE04243`0nO0h0@6h804MO0P1:D`00D4T004m0001>?@00Ccl0
04lm001:>`00BCP004Lh0017=@00ACD0040c000m;`00>b`003PX000c9`00<24002dQ000/7`00:1h0
02HL000U5P007a4000806@l000D04PX000d6000710000P400040000>000000`0oooo000:0?ooo`0D
01H>000K4@006a8001lD000N4P006`h001/<000L3P00818002/F000a8000>bH003d[000l:`00?R`0
03P]000j;@00?Rh004Lb001?=`0205E0000W05Y7001KD@40Gf4505Ua301BPa<0DI4M04fK:@1;WSD0
@:9003NT@`0`YD<0;JA302nOB00eSEL0>WYU03AkK@0]PVh0:HI]02R9I00/WdD0<:T]03JX8`0hYB00
?j8Q04BO8`1<WRL0C9hX04VP:P1:XRH0BJ8V04JT:P0lZ3P0<:U302VWC00bX4h0>9M<032<CP0]QDh0
;We<0080<GI@02L0=81;03:FA@0^XD<0;Im102RR?`0PYD007:A301fVA@0MXE807YMS01fBL@0IT7T0
58am01QjP00IHhH065V<01MMS@0HFY0065>C01Y:U`0QA9806TR?01Q;S@0GFHd06VV<01ahS@0MNI40
67JF01=_VP0@Jid04FBM019PV`0EEI`064FM01/oW`0KAj00756O01]HW00HGiP00P0FHY<09`0FH8`0
5UR=01]?S`0QBI@09DfG02ICV00RFYL06f6F01Q/T`0DN8X05WEo01M`P00KIh<06X2201VBPP0JWgh0
7Yac026QJP0NXFX07IiV01jLH`0PVe`09ImH02ZND`0^XU40<ZIC036/D00_[4l0;jYB036YE@0bZU80
=Ze<03V/A@0l[3d0?Zdk03n^>013[cH0@k4e04>^=`0204>[>00W04BW@010Yd<0@:Do03nT?014Y440
A:=204:TA@11XDT0Aim704bIB@18W4h0Bia>04^KC`1;V4l0BYM@04JLDP1;VU@0BiQ<04RDC@15TE80
BIE:04^IB012WDT0?iQ:03n?E`0oQV80@G]V04EYK@1:I6l0E6YT069WG01[Je@0Jg5A06mdD@1PPc@0
E8PH051k2@1ILP@0HFl00080IGD002L0IWL006ai001`OP00MW/007=k001cN000LWT0075i001dP`40
N98;06bP501ZY1h0HJPY05bZ;`1DZSD0CjDe056P>P1BY3/0DJa704f_E014/U`0@[9W04>aG@15[E`0
BjUK04^JFP1?Se00G8A=05aiDP1MMUh0HG=U06igHP1cOFD0LWMO071[G@1cJEd0OFMR07mUIP1kHVX0
0P21FFd09`2HEf@0ZDeP08]@K028Bg/0Ve1]0:U>JP2<HG00Ofm`07QnI01fPUD0NGQF089SHP27IUh0
UVIB08a`B`1ePdl0OHh]08F52P1mM040Nfd007i^001lM000PX40092<3029Sb@0U8d^09^=>P22W4P0
MJ1@072FF01[U5H0JY];06J`C01Q]e<0G;I@05nbB@1W/4@0L;92072g=`0207:g<00W07709P1b^B<0
M;DI07Na3`1j[0X0OJ`>07n_5P1k]1P0N[DH07Ne6`1d^BH0KL0[06nj:`1a/S80LKTV072m8@1W`2L0
HL0b05S0?`1C^d<0C/0l05:b?01BV4P0Die905FQAP1AXD80Cj8k052Y;01<ZB@0AZLO04NS7@13XbD0
@jLh04VPAP18YTh0Bj]E056XE`1FZeL0FjeF0080G;=A02L0G[M@05bfC@1KYdl0G:A;05^^A01O/3d0
HJP[06>P7@1RV180GY0;05RD2`1;WAD0A:PY04B_>P10[S`0?jY304>JH017MWH0C5^0069DQ`1dDHX0
L5N;06iOR`1aHhh0JenA05YJT01@GX/0BUf504mON01HIF`0EfQV05EUG@1AIUL0CF]E04Q^F@10MEX0
>h1J03f<EP10VDT00P15UcH09`16UB/0Ai@V04BB8P13U280?YDL03RJ700iUaX0>iDF03jC5@11Sa00
@HP=04F43019NPT0CVd8055O1@1BD`40DDL004m4001A@@00CCl004/m0018>`00B3T004Pd0014=P00
AcL004<d0011<P00?bl003//000i9`00=2P003<P000]8000:a`002DJ000S60008AD001dA000201P<
0004014:000;1@001P80008200l00000303oool000X0oooo01@0718001`E000O5P008AL001hE000P
40007Pl0020?000X5000;Q`003LW0010;000@2h0040d0010>P00@CH004He001>>000Dd0005i;0080
GUH002L0HE`0065V0`1KM`/0C8XL03jG:00jXC80=jI003NVA@0bYdT0;jM802^WBP0ZWe40:hmI03F3
G`0kMVH0;gMa02MbL`0YN6h0;WmM036M?@0aYBH0=JHM03^S6@10X1X0@idJ04bK6@1<WA`0CIlN04fQ
7P1=XAl0AjHX03VZ=`0/Zd<0::U@036UC@0eW4X0<9=902b:C@0/P5400P0/M5L09`0^NUT0<I1A02jQ
BP0]YD80::Dl022R?@0MX4807ZA301nQC`0RUUl089=]01ZEM00GTWH06h9k01M]Q00FH8/055n=01EL
R`0GGHh06UbB02=ISP0OFhX06EZ:01MUR@0HMHT06h2901b0SP0GNYH04G>K00i_W@0AJi/04fRI01EK
VP0FC9`05dZO01AGXP0GI9l066bK01QaU@0201IaT00W01Q_R00JJHH076J;025US@0SJhd0972;029f
R@0MO8T06H2<01B6QP0GR7h068Ml01Z6O`0ITgX06i]b01bPK00QX6D08j=P026RHP0OW68089EQ02FH
GP0WWUT0:Z1F02jRE@0`YEP0<:YE02nZDP0`ZU00<Z]?03N]B`0m[dH0?[0l04:]=@11[cH0@Jlc04>`
<P11/3D0@Jhi0080@J/m02L0A:U304:WAP0oYT80@JHo04JV@016YSd0A:Hk04>Q>`18WSd0BYY404JK
B@18VdX0CIU;05:IC@1EV4/0DI]<05FJC@1AVTD0BIM904FFDP17VDP0AY]<042KDP12TeD0AHYP0461
J@14M6T0AF9_04eOJP1FIV00IFAI06U[D@1SN500FWa;05N3:`1CO0l0EgD5069b0@1UL0000P1XM000
9`1[N000LGh007>50@1eRP@0M8/607>?201fT0P0Ki8806bI2`1VYA<0EJhR056^:@1=ZCD0BZLh04VU
>`1:YSX0AjTg04>]?@11/5@0>[=Y03NdJP0g]fh0?k9U03n_G`16Z5`0BYQO056:G@1KNeX0GG9H05ic
H`1SLF/0KG=Z07E^K01cIFX0L5Q]06YKK@1fIFX0PFEZ07ELK00206m=MP0W07mLL@2HG780PE]d07i:
O@2:EFX0VUAX08QZJ@1mMV`0N8=S06b8F01_P5L0OfUM08=WG@2>He@0P7=;06:=@@1hSB80QGX707Y_
001hKP00Mg0007mg0026Q@40V9D?09bB9@2LSC80UHln08:OC`1bVeH0Ki9G06R<EP1TTE<0J:]?06Fg
D`1M]D`0H:e@06RQE@1^WU40K:Ho0080Kk4f00/0L;P_06nh9`1e]Q/0NkDD07^`3`1l[a<0Nk<J07Vb
6`1k]1T0MkLG07>h7@0206c09P0J06fj:01_^AX0KKPF06Rm801O`2/0Fl0o05G0A`1F`4D0DKE005>R
A01DZ4@0EJm605:aA`1?/C/0C;0a04R]9`1:Z200B:@Q04RS<`13WdT0AHUO04NEH`1:XFH0CjUU052Y
H01GYeH205^]BP0W05naA01PZcT0I9h_06JI901TW1h0IIDF06><3P1WQ0/0IWd806Eg0`1MP080DXh=
04ZP:016[Cd0@Jm004:VBP12TF40BFa`05IGPP1/BXd0O4FA07]3S01dCY40JURK05iIT`1>H8D0@VYf
04MfI@1;OD`0EWhc05Yh:01KN200FGLN05Ag6`1?NR00B84]0428=011TCX0@9@b0080@I4X02L0A8dQ
04R:701:Ra/0BXhH04FD700nUah0?9HK03bA4`10R`l0@8<;049n2P17MPH0C6T3051G0@1ECP40Cd<0
058o001@@000C3l004a0001:>@00B3H004Pi0018=@00AS8004Dc0015<P00@S40040^000k:`00>2T0
038V000`8`00:b0002PN000W6@008aH001lC000K3`000P0E3P00100@2P002P@000<20002000?0000
00`0oooo000:0?ooo`0D01`B000L4`007Q4001lA000P4@008Q00028C000S4`00:aD0030L000i8`00
@2X0040`0014=000A3T004Tk001=?000FT<0069D001UG`0206IZ0@0W06=_101NO0X0DH/L04:I;@0g
X3H0<JDl02^V@@0YZ4D0::Q702ZXB@0WY5H09YEP02MnKP0eN6`0>Vi_035/NP0]IWh0:gId02j9G`0^
X400;ZH]03:U9@0fXR80=ilR03^N8P10WAl0@YdO04^Q801@XR00CJDQ04JX:`0jZSL0<ZY202^YCP0`
ZD/0<jM8036SA00/WTD0:YI60080;I1=02L0=8i=03JFA`0dX4H0;ZHk02ZT=@0QXcH07ilo01nU@`0N
Y4d08IeJ022LI00KWFd06IY^01Z<M00GMX<05FB>01=MSP0CFhX056><01Q/S`0RKHd08Fb801]XR00J
LhP05X:701R;R00HQHl05GZH019bW@0DLId0572J01A^V00EHYL05EFJ01=GW`0BIj004GJQ01=mV@0G
P9800P0HPH`09`0HP8H06Gf401ilQ00POhD08hB302>9OP0NSgd06i5l01R@PP0FTX405YEi01JJN@0G
WGX06Imd01bPIP0MWe`08J5H026TE`0RXET08ieK02NIG00XVUT0:ImH02bQEP0`XeL0<JIJ02jXF00`
ZUH0<JYC03NZCP0mZd@0?jlm04>a=@14/Rl0@Jl_042a;`0n/C00?K0f03^^A@0203j/B00W03nYC00n
Z500?JM904:W@@12Z3d0AZPh04JW<@18XC80C9lg04ZJ@019VTL0BIa804^LB@1>Vd/0DiQ9052KA`1G
WdL0E:1204bN@P16WTX0AIe704FID@11UEX0@i1K04>7I016O6`0B7=]04aWJ`1HH6D0H6IJ06iRE01]
K4d0G7e=04^2A01?OB<0DWL805ab001TLP00K7D00080L7L002L0L80007680@1_S`@0JYT806NL2`1Y
XQ00J:LE06BX4P1UZQD0G:dO05V/:01HZb`0EjXa05N/<P1BZcD0DJde04Z_>013/4<0>k1G03FbJ@0k
[f80?[1Q046/G@10YEh0@jIM04bRG`1GW5/0GYAH062>E@1RPUd0HWEX06Y`I01]JVX0LfQ[07=JK`1`
HW00KfQ[07ISJ`1aFVd00P1ZCGH09`1eHW@0RF=f07MUM@1dEWL0P5eY08]MIP22LVH0Ng][07J8H@1U
QeL0Ih9H07EaGP1mJe/0Q6IG07AgB@1NUbh0LHdI07eh0`1hM@00NG8007Mb0020N040QHX409FP4P2[
Sb/0VX`j08bA@@20V500OiEB07jCCP1fSTh0KhY@06VIC@1XWd`0I9m:06JKE01/U5h0Ki9F06jKB002
06Z/?@0W06Rg<@1^`2T0M;PV07^h7P1n]a`0N;HN07Fe8@1e/B00NK<J07Nf5`1c^AT0KL0W06g0:`1`
`2H0KkLH06ne4`1Z^A`0I<0^05o0>@1M`4D0Fl1;05Nk?`1D/CP0FZhj05Z/@01H[d80D:]004ZU?017
WcT0BZ@`04^Z<P18Yd00Aj9A04BHI014W6T0AZ5W04fYI@1GXE`0GIiB0080Gj9802L0HZ@j06FM9@1W
TA@0JHH;06R21@1SM040Hg4006=[001RIP00HVT0061`001OO0P0E9@L04^X<P18Zcl0AYe?04:6H@1:
IVP0F5Ej06a:R01o@Hh0Pcb>07Q;SP1MFXh0CfAg04U^HP18Le80BWe004eo9P1CLA@0EVX805QR0`1E
H`80EVL305I_2@1=O1D0BXHP04F;:@12S2D00P13RAh09`17Q1T0CH<D04j24`1=R1D0BH`I04V>7@16
RaL0B8@>04Z12P1:O0P0Bg@7055Z1@1DG040F50005E6001?@000BcX004`l001??P00BCh004Th001:
=@00BSL004Pi0016=`00@c@004@c0013<000?bd003/Z000f:000<280030Q000[8000:Q`002DJ000P
5P007A8001X>000201@:000300h600080`000`4001000000303oool000X0oooo01@0818001dC000P
4P008Q0002<C000R4@009A0002PF000[6P00=1`003PT000n:000Ab`004P_001>=P00Dch005a5001S
D@00K5h006i]0@80JG4302L0GH0805J>5`16WS00>Ym003:MAP0[XTT09jI=02FWB@0YYdL0:jI602nO
DP0_Se`0;7]Y03=eJP0gJ700=ej003=QP@0]NgX09iA^02JUD00ZZ3T0;JL/02jS:`0aWbd0;Z4_03FR
;P0mY2P0@JLW04FY9@12ZB/0>jLc03JW@00aYTT0:jEF02^XDP0[ZTd0:Za<02NZ@`0XYT400P0/XDD0
9`0eWT@0=Ya103JN@P0`YSL0:JL`02>T=@0RW3l08J=501nTC`0PY5H07j=N01fSI@0KWf/079Ac01Io
Q@0DJ94055^>019GS@0CIH`05gJ<029jR00SNX808WR301moQ@0JS8804i:501B:S`0COiX05GNN01Id
W`0GMI/05g>E01E]T@0DIY804VVE019gV00CQ9L058^C01F<SP0201R=RP0W01R>Q00LSH40891o022B
OP0OUg/07i]j01ZPM@0GXG@069ai01NJNP0GWWL05JEg01JXM@0HYVd079mS01bMEP0PWe<08:9@026P
DP0SXED09j1G02ROE@0YX5H0;J1G02nSF@0^Xe`0<:IJ032XF00bZ540>:Y;03j]@010/SL0@k@`04Bd
<011/S40?K<c03^c=`0m/Ch0?Ji<0080>je=02L0>j]=03fYCP10ZDH0@jQ0046Z?013Z3D0@:P^04>T
<`19WSh0BiU504ZHB`19WD/0BIm:04ZMB`1>W4P0CYm705:QB01?XTD0BJ5704>RCP16Wd`0@iQD04:B
FP10SU/0A8MU04UkJP1<MV`0Dfi[061UHP1SJUX0KfMC06YcCP1IPD00Bh@]055k5@1JM0H0I7<006eg
001aN`000P1dP@009`1dR@40L94406ZJ1P1UX@P0HJD?05jX5@1OZQP0H:/L05j]8P1K[RT0F:Tc05^/
<`1I[3<0Gjlb05Za<01F/c80BKLj04:eAP0j/UT0>jmW04>^F`15[5H0AjMK046OI014X6H0Aj=Z052R
HP1KWUX0GiYH05n;H01OMVX0HVYY06ELK`1/Gfd0Lf1_06]WL@1VK740JfA/06mMJ@0206iDM00W06iU
K`1jIfd0Jf]Z06QRL@1[JFH0LFIY071cI@1^NEh0KH9K06J0H01[NEd0NFaN07]YF01iIe`0LH1606>I
7@1aR0X0MgX107Yj001hNP00NgP008R2202ETAL0X98O0:Z<;`2DS440QXa;07Z8E`26SU40RHi=08F;
C`1iOEL0LWeG071kF01ZNET0JWiL07>5G01gSUD0LIA=0080Jj8o02L0JkLf07;0<01c`2h0N;PR07^j
7`1h^R40MkHN07Zf6@1k]QT0O;LK07>j7@1/^bH0JL0e06Zk<@1Z^2<0KkPK06fi8P1W^C40Ik/k06C0
A@1S`4/0H/1105nk=`1Q[CD0HJPf05fZ@01GY4L0CI5?04V:D`19Wd/0Aja:04FXB@14[540B:mS04FY
I`18Y680E:QD05jV@P1ZWS800P1`UbH09`1bT1/0LXLB06j02P1^M`<0Ifh106AY001UIP00If4006MU
001UI@00I6P0065b0`1KR100DYlU04jZ>@16YTD0@iI;04N3F01@Mf@0FgE^069cM01RNGT0GH9b0565
D`1CP380FW`T05md7P1OLQH0Ff`=05aW201HGP<0F5h105iO0@1MH@40GV/605Ec301@OAL0AhDM04B9
7P0204J87@0W04R96P1:QaD0BX@F04N76016R1`0@h<I04Um4@1?M@H0DVl405=Y0P1DH@80FEX105YA
001DB000E4<004dm001=>P00BcP004Xj0017=@00A38004Da0015=000AcP004Ti0016=000@Rl003l_
000k:`00>BP003HU000`8`00;Ql002XN000X70008aL001lD000H400050/000804PP000<03@H000L3
000300004000000<0?ooo`002P3oool0500V6P009QL002TE000[5@00:AX002dJ000^6P00<1h003HM
000g8000@B@004H]001:<000CCL005<n001KA`00H5L006MQ001/K000KGH30P1RP0T09`1FSA<0B9XV
03^U>@0dWDH0<8mI02RKG`0RYf408ZUQ02>ZG`0VYE/0:9MS02Z3JP0/L6h0<FMZ03]HL@15B8@0>5n5
02j0P00VW7408jMA02N[>00_ZbT0<ZTV03>V9P0bYbH0>ZLR03fY7@11[Ad0?JhR03Z[9`0gZC40>:Ld
03NW?@0`YTH0;ZM802bYB00WZd/09jQ802NY@`0202jU@P0W03BN@00gVD40>9I303:Q>00/YC009:<c
02>K?`0SX4H08J=A02:VE00QYeT07Z=Q01jPK00LW78068el01MhP@0IKX<06Vb601QfQ`0KOXD07H22
01j1O@0NP7d07hJ001R>P00DU8@04Xn<0167VP0DOYh06GRM01MiV@0EN98057R;01=hRP0ANH/04h6:
01B8R00ESH<0692200806Y:102L06iMm01jEN`0QUGP089Qi022KN00NWWD06j=`01RTJ`0HWFX06IY[
01VNJ`0FYFh05ZI^01VRJP0KV64079MH01bID@0NWU808J5C02FSE@0WYED0:Z=E02^OF@0^WE/0<:1L
02nQGP0^Y5d0;jIJ036UD`0jZD/0?J`m03jb=P12/c@0@K@f03na>00l/CT0>k9003f`BP0l[U@00P0k
[U809`0k[Dl0?J]:046[@P11ZC`0?jPi03^W=P0jYcD0@:Dg04JQ@P1?VTT0C9Y;04bOB01;XDH0Aim7
04VO@P19Xd<0BZI:04ZVC013YTl0@:AG04>PD`13UU/0@HaM046;G017P6@0C7IY05=cJ01MKV@0J6UM
06U]F@1]K5L0IgI705Z7<01DPaD0FgX;069f101ZM040LWX007N4000207B<000W076C0`1]VPL0IJ<8
05fZ2`1MZA40GjPC06B]5@1R[AP0H:hN062Z7`1NZ280GZ/U05^];01N/2d0G;4^05:e=018`440@KEA
042bGP0o[6P0AjmF04f_B01=[Td0AZ]H04FSIP1:VFh0D95Z05R?H`1IS5l0Gh=U069cJ`1WL6T0If5c
06URL`1]HG@0J6Ed065VK`1SHVd0K5eT0080KUI]02L0J6Y]06eYJ@1ULV@0G6U/05Y`H`1EKFT0Fg=O
065eF@1YNU/0Jg5Y071YI01lHUL0MFMF07=WG@1dQ400M9HD07Z7101nO@00NgX007am001oO`00UH`?
0:f1;02`Ob`0[XLc09N7B@1mPU<0N7QN08:4E`25QeD0PH9B07QbF`1]LF40LV]N079XG`1jKel0PgaJ
08:8E@1cUdh00P1cYT409`1d]C/0M;Xj0730<P1`]R<0MKPU07C0:01h^200N;LI07bf7`1j^B80NKPP
07:i;01_^c80KKDe076f;`1d^2/0L[H[072f<@1b_C`0Jl5006G0@`1X`400Ikhf06Ve<P1Y[S00IJ`f
05fS@01BU4D0BiA804RQA@13XD/0@Yi@04BXE017[FD0BjUZ056HHP1EUT/0Gid[06R<4`0206ao200W
071e1@1`K@<0KFX106aZ001ZHP00IV40069S001VI000J6<006=S001QHP00HFP105eg1P1GS1@0DJ4Y
04>Y>P0oYS/0@9]:03nJE@0nUed0?YYQ042TG@14Y4@0Di0N05Yf1`1KIP40HEh105aL001MG000FUX0
05UJ001JF000GeP005iN001OHP80FVX705Ac2`19OA@0AXHF0080BHXI02L0C8`K04f:6@1?QQT0BX<J
04ao5`1>Ma80EV`805IU0@1FG000EUL005EB001DC@00E4D004ln001;?@00BSP004`k001:=`00AcL0
04@f0013<@00@c8004<_0015<P00AS@0048a000m;@00>RX003TY000g9`00=B@0030Q000]7P00:ad0
02LI000P5P0070l001<?000A20000P0<1P000`090P001@800040000@000000`0oooo000:0?ooo`0D
02dQ000_7000<Ad003@P000d8@00=b4003TS000m9P00@2T004@/0014<@00C3H004`m001C@P00ETP0
05eA001SIP00IgD106=n1P1NR102056>8@0W04BK;@0hY3L0;jDn02ZHC@0UP6`08I9h01bONP0LXgH0
7:5h026JM00URW80;7Q`035XK`0jH740@5Yf04MFP`0hKX00:XMi02BNI@0SZDX0:J/h03>/;00hZBX0
>jLZ03jW9P12Z280B:XM042^7@0k/2<0=jhV03V/9P0mZbD0>jTZ03FX=00eYc`0<ZM402bUC`0XXTh0
::5:0080:ii902L0=YM503^AA@0kRdD0=IPj02fQ=@0VXcD09idk02NM?`0UWD`09j5D02BUFP0PYFD0
7j9]01^SLP0GVgH05Xaf01Z2O00PP8008h:102F1P00PPGh078Am01f4O@0MQH005XZ001BBP`0DThT0
58nD01N5U`0HOiT05W^H01=lTP0BP8X048B501:5PP0FRGl05hil01VBN@0KTgD00P0NUWL09`0OVW40
7i]`01nJL00MVg8089ac01jMM@0NXVd06j1W01bLI@0JVVD069eW01ROJP0GXV/06J5X01^JH00KV5L0
7IMD01nKE00RXE<09JAD02^XE00^XeH0;j5K036MHP0`WF@0;ieU036PG`0dY5D0=JM?03VXA@0mZST0
?Zhj042a@00m/TH0?[5403f`@P0n/4D0?Zm<03b_D`0203b^D00W03b]A`0j[4L0?:a003fZ>P0iZ3D0
>JPj03RY>@0mYch0@ZE304VMAP17WDL0AYm204JQ@013Xd00@jI104FY@014Z4T0@ZU?03nXCP0oYED0
@Z5C04>HE`12SeT0@XYN04alH@1DJfL0FfMX06AWHP1`J5X0KFeI06]`G@1RO4@0GH/R05^21`1SNP@0
J7X306ij0@1eO`00MXL00080Lhl002L0LYH406ZQ201SY`X0H:T@05n/501N[Q@0GZlH05b`6@1M/A`0
H:dI066]5`1O/1T0F;0P05Nb8`1B]BH0Bkdd04FjA`0o]5T0?jmO03fWI@16/5H0C;=304^bB015/5H0
AjMU04Z?KP1=PW@0Cgm^05:0K`1GMg80HFMd06Q`JP1UIg<0HfYf06AVNP1TIG@0Gf=/05URJ`1OIV@0
0P1QHFX09`1NMF40HG5Q05]jH01FLFX0EgMV05EgIP1HMeP0FWIF065kFP1`IVl0MeaZ07iHE`1hI500
LW1H07Z8>P1nT`d0NhD107Z1001lO000Ph4308R<3P2CSQ/0ZH@S0:el:`2[Och0TXYA07f5F01gNUH0
Oh9A07]mG01iMUT0MVaH079^G01eJV00Pf=O09EPH02PKEl0Uh=C07NJB`0207FTA00W07nW@01g]Cl0
L<0o06fe<@1^^Rh0L[X^07Bi:@1c^2D0NKLY07Ri:P1i`2H0N;P]076c=P1b/C40M;D^07Jc;P1k/B`0
M;<^072g>01Z^S/0I<0m06O0?@1V^cL0J[L_06Vd:`1X[Bl0G:4h05B@@`1<S4/0BI9?04BFD@11Ve/0
AZAN04V[J01>Z680DYY?05^D;P1URaH0KGd:0080KGH102L0K6h006iX001_J000JfD006US001TI000
HV@006AM001TF`00HUX005iJ001RGP00GfX005Mj2P1AT1h0BJ0a04VS>@19WCT0AYdm04VK?P1=WCd0
D9db05JA7`1QO0/0HfP1061P001KF@00FeH005eH001LE@00FUH005eF001MFP00GUT005]I0@1IG080
FfD405A_2@1CN@/00P1EO0`09`1EO@d0Eg`<05]h2`1JL``0GFh905aX1P1PHP<0FeT005M@001IC`00
E4T00594001??`00BCX004Td0018<`00BSH004Pf0016<000@c8003lc0013<000@C40048b0013<`00
@30003d[000l:000=RT003@W000d8`00;al002XO000X6P0091T0020C000I3P005@/0010:000200/6
000300L100020@000@0001000000303oool000X0oooo00@0<Ad003DP000e8000>R@00P11:@003P0o
:@00AB/004Dd001;=P00D3T0050l001?@000DTH005Q@001LFP00Gfl205f3201BTA<0A9TY0P0hVDD0
9`0`X5809j5E02>KE@0WREd0:7Ie02:9O00OU7h079:001b:O`0QQW`09Weg031/L@0fH7H0?EQm03mN
P`0oH8`0:gN402>:M@0PWel08:M<02RW?`0`YCP0?9hh04>L>@16VcP0C9/c04RM:`15XbL0@JPY03^Y
:P0kZRP0?JHS03^V9P0gYS00=J<l03JRC00`X5T0:9]K02>GGP0202RAG@0W036<C`0kPd`0@7e<03b=
@@0bVc`0:9ll02JO>00YW3T0:YQ602^JDP0VYE`08ZQT026VK00MZ7405jIa01NML00MTg@09Hmi02j:
O@0cPG`0:7en01n0P00KP8007Gj001J0PP0HS8@05i>801VBS00JRXl07X:>01]oS`0IOX`068B801R:
P@0HSGd07Hig01bBL`0NTg408IE]00808YIZ02L08iQW02BKJ00RVV/089]_02>KK`0SW7008IiY01jL
H`0LVf806iUS01ZHIP0GV6X05j1X01VRI00KWU`07YUH01jHD`0PVE<08j1D02JUE00]YU<0<JEH03>R
G`0fWfL0=9eU03:LI00dVV00>:=B03RVB@0kZDD0?JQ103jX@@0nZdH0?Je203n_?014/3D0A:lb04B_
=`14/3h00P13[d<09`10[cl0?Ji003f`?`0m[3X0>J/j03JX>`0hZ3l0?JQ2046UA015Wd@0@im604FO
@@16XD00@JQ003nZ@00o[4<0@:U>03nYD00mYe40?Z9H04>OD`13UUD0@Y1J04B9G`1@NV00GVQU06EX
HP1^If80MfUL06ieE`1PPE80G8/h06B=6@1VQ0D0Jgl307200@1aPP00MXH007^9000207R?0P0W07>I
1P1]Y@L0J:H906B[3P1UZa<0G:dF05^]6P1K/Qd0F[8P05^`7`1I/1h0FK8O05Fd9@1F/bT0CkT[04Zi
=P16`4T0@kIF04:cE@12[E80B;5A04JaC`17/U80AjmI04fXH@1:UF/0D8Y/0568J@1AQFl0EWUd069P
MP1RIg40JVMc06aZM01[J7@0IVA[061TI01BIVP0E6YS0080DVIX02L0DgaF055hEP1AOUl0DGM[05Ik
H`1LP680GWaD05IgE@1MNEl0LFIc07eIK`23F5l0M6YB06R2C`1gUBl0OI4807F6001fPP00NGh008V:
2@2<S1l0UX<W0:]o8`2XMC80Y7U508f3F020QE80Oh=A08B3D@24NET0R75I08E[F01oK5/0OVYM08mX
H02QIV<0ZVYM09amD01lSTT00P20Td409`2=U4H0NK=60770A01_]d40LKDk07>f=@1e]C40MKLb07Bi
;P1e^2h0N;PX07Vg;@1gZcD0Lj/b07Rb;01j]Bl0NZl/07F]<01b[3P0KK9006Vh?@1W^S/0I[/e06Jh
:@1W]B80IK0R066Y9`1JW3D0D9M504bHC01;WUD0B:1S04ZUI@1:YF/0Cj5E05NN<`1RSQ@0Jgh706ae
0@0206i_000W06][001/I000Jf<006YU001VG`00HU`005]I001NE000GUL006=H001UF@00Heh005mR
001IJP@0E7`?04f:7P1<Tb80C9PV04VG9019Ub80DY4M05Z8401RN`H0HfL1061L001NF@00Fe8005]@
001MD000FU40061C001PE@00Fe8005]C001JD`00Ee8005]F001JGP00F6X10080Eg0102L0EG0205Y_
0@1LK040H6H006AO001PFP00Ge@005e=001GBP00EdD0058n001>?000BS`004Lh0018=000A3<004Hg
0010<P00@30003l^0010:P00@2h003l^000m<@00@34003d^000l:P00>bT003LY000g9`00=2<002lP
000Z70009QX002<F000N4@006@h001H:000@2@000P0<10000`050@000@000000000@000000`0oooo
000:0?ooo`0D03PN000i8`00>bL0040^0015=000BC8004/`001;;`00B34004Xd001<=P00CcL004ll
001B@`00FU4005iS0@1ONPX0DhdK04:K<P0cW4h202fGI`0W02^EL@0RTWL088Qi02EgNP0ZK8808gn7
0227R`0OP8H07726021_P@0[KG/0=f5e03eBP015DXT0@5f@03]US`0ZOH408i1/022TD`0SZ440:JHd
03:S<@0lX300AYlc04bL<`1?VBl0Cid/04fP9P18YBP0?ZH]03fT<00jXS00>:4d03NP>@0dWT40<ia@
02VHGP0PUF80891U00809XeQ02L0<Y5A03R>B`0oPd`0?Xe403BJ@00XWSh09ili02ZL=P0]Td<0;9E@
02RSFP0UZF809JIV02:XJ`0KZ6X07J1Y022HJ@0UTG<0;H]g03J3MP0aP7P09X1l025nOP0NNH006gZ0
01f8P@0OTGh089=m026=O@0SRgd08HUm01n9OP0PSWh0899l022CN`0SU7D08iQb02JHK`0VUfX00P0X
UVH09`0ZUVD0;IIS02JGH00TVF80:9MT02NIIP0TVF408iQO02BHH00PV6<07IAW01bBJ00NWVD07Z=O
022RFP0QVeH099IE02FEEP0VWED0:jAF032WEP0cY5/0=JAR03FRI00cXF<0=9]Q03RGH00lWdh0>ZM3
03ZXA00mZ4P0?ZQ:03j[B@0o[Cd0@Zhc04F^9`15[b@0B;0X04Z_<00204N_=@0W04F_=@0n[SP0?K0h
03b]>00kZSL0?JLl03bX@@0oZCh0AJM304>Q@@14X440AJ1004BR?`0nYd80?ZQ403fZAP0jYe40?:UC
03jTD`0mWET0@9UF046DE@11T5/0AXIQ05EfG`1VJ640KfEP079ZG@1kKEl0JH9A05VD@@1KTbL0IX`@
06b61@1aQP80MHD107V;001hT000NI<10080NIH402L0LIl606RX201WZ`X0J:T>06B[501K[aT0G[0N
05fb7P1I/R80EZhQ05J^7`1E/RD0D[8^04bg;@13^3<0B;Tn04JkD@13/eL0AkA904JeA`13/dl0@;=L
04JbG@1:[FD0Bj]V04RQK01<Vf/0CiIZ04VBN@1?P7H0EfEj05m]L`1aK700Lg9/06U^JP1VL6<0HWIM
05UjH01DNe`00P1?N5X09`1>QDl0C81E05:4F01GPEd0Fh=J0625H@1UPUD0FgUJ061eHP1iHg80PUU`
08AEI`1cL5@0Gi=407NF9022Q`H0OH0107^20`21Q@L0SILC09VB902RPB<0YWlX09mi<`2FNTX0QWUI
08>2E027RE@0Sh=D099]F@2LJ5X0YFIN08mXG025J5`0V6YS0:EXI02VJeh0UWM=08F1B`0208^8B@0W
08V>BP1eZ4L0L;9707>cA@1c]440MK0g07N`<01h/SL0MK@c07Re;P1g^B`0NkHd07b/?@1oZ3H0Ojh]
07jg8@1k/Ad0MJhQ06n/=@1Z/c`0JkDk06Rj<`1W]b`0J;DQ06Bf701U/A/0H[8N05^_:01A[CP0CZa8
04jYEP1=X640Bj=Q04RRE@1AW3X0Gi0L06]o2P1[L@80JVP00080JVL002L0If<006MK001UG@00I5X0
061E001JD@00Fe4005]D001OFP00HEX005mH001RFP00Ged005eR001FJ`80CWT=04n66@1<Sb00Bi8T
04n@7P1BR1L0FWP905eY0@1QGP00G5@005iF001LD`00Fe4005YD001LD@00HE<005mF001LD`00G540
05]D001LDP00GED0065H001OG0000P1PH0009`1NH000GUl0061K001QFP00HE8005i>001HAP00Ed@0
0592001B?P00CC/004Pf0018=000AS@004Hb0013;`00@Bd003l[000o;`00?bh003l]000n<000?bh0
03d^000m;`00?R`003`Y000i:@00>2P003@T000c9@00;b4002TM000U6@0081<001d@000G3@004PX0
00l7000200P4000300@100020000000001000000303oool000X0oooo01@0?RP003l/0015;`00C3H0
04li001D>`00CcP004Xd0019<000B30004Pd001:=000Ccd005E;001HG@40G7D805B97@13Tc/0<IMJ
02RHM08099:602L0:hR;02YnSP0ULY409fV;02QUS00SN9007WjA01acSP0OIHX09fF603ITP017H7h0
DER6059LR@19HHd0=g6902b3N@0VUf40::E602fX>00aYBd0=ZLV03nW9P14YRT0C:<Z04bS:@1=Y2@0
AZTR046Z:@0mZC80?JLm03RT@00fWdD0=Ii302nOA00WVdl08I9P01f@I`0NS6P00P0WSEl09`0`VdX0
=9e403jGA`0oVCl0=9ll02ZQ?`0YY3P09j8h02ZI@@0/Vdd09jEC02JXF00XY5/09jEN026SH@0PW6D0
899[02>=L`0ZQWH0=H1e03>0M@0ZPWP08gek029iO`0QOgl08HMm02F>NP0UTGX09I5f02>?M@0RTW<0
8Y9b02BGL`0UVWH09YUf02RJL`0XW700:ia^02^KJ`0202VKJ00W02^KIP0_V600;9YJ02VIE@0/V5H0
:YQK02VIF00VUed08IIO02>GG`0QUF408IER026OG00RYED08ZAE02>OE00SVe@0:9]E02VODP0/YE<0
<jAC03FSG00eXf40=ZAN03FTG00gWed0>YYN03fQC`0jYDD0>ZM<03VTE@0mYe40>j]503n]=P11[b<0
@JhM04>^7P15/280AJdX0080@:`a02L0?Zd_03n`<P10/C80@jha04:Y<P13Yc`0@:I004:TA016Xd40
Aj4o04JQ?@16Y3d0AJ=004:T@`0nYTH0?JQ403ZXBP0lZE00@:AA03jIE@0oUE@0?iAE042<G017O680
Eg=M06YXF@1dJET0N6eN07YbG@1SRTX0FI`Z06:C5P1^RPT0LX/407J=0P1iSP00NY0007JD001gUP40
0P1aV`@09`1/Y0L0HjX:066Z301O[140H:dG05Za7P1J/B00FK@Q05Fa:P1D[R/0Dk0]04na;P1<`3D0
BL0f04;0?013^D<0?[YA04:bDP14^4H0@kQ204BaCP0o[Eh0A:eK04V[H01@ZF00D:EY04jTK01@XFX0
Bia_0526L01FKWP0Ifm_07E^L@1dLFX0IV]]05m]I@1MNV00F8EP05J5FP0205:2EP0W056<C`1ERU80
EHM?05N4E@1MOeX0HgQQ06MjGP1OKf@0J6]V07eQKP21GFT0OeAV06ibDP1LVCL0LI<L08661`20P040
OhH608:?3P27Y200XhXX0:Ye;`2/NC40WGA708mbC`22K5/0QX1D08UnF@2EMeP0WFMM0:URGP2gH5l0
X5]T08iLI@2NHfD0XFMU09YZE`2ELe00UWA:0080T7]<02L0PHEC07JIB01bYTP0LkA<07Ba@`1g[C`0
O[4k07f_=`1j/3d0Mjhd07Fd=P1i/3X0NYm008:L>`2:XBh0P;@N07fa5P1e[AT0KZl]06Jb=P1Z]SP0
JkD[06Jc7P1U/1X0HK4M05n`701Q/b40FkD[05:d@@1@[E@0DZ9N04fHH@1;W5T0D9i205FC8`1RO@d0
J6X106QR001ZHP000P1YH@008P1VG`00Ie`006EH001QE@00Fe<005m?001MD000GU4005i@001MBP00
G4/0061D001QF@00H5X005aN001JJ0D0F6l<05]h3`1KOA00Gg`=065c2@1PI`@0GU`005]A001KC@00
Ge8005eC001KC@00FU0005UA001LD000Ge0005eA001KD@0205iB0003061C001OD000Ge000080GDh0
02L0GDl005m>001KB`00G4T005U6001EA000E400058n001??@00BcT004/h0017<`00AS<0048`0010
;@00@B`003hZ000k:P00?BX003`[000l;000?BX003l[000o:P00?B/003`Z000k:P00=BL0034W000_
9000<B8002`O000Z6`0091P001lD000K40005`d0014:000<1P000P050`000`02000000000000000@
000000`0oooo000:0?ooo`0D04@c0017=@00BC@0058l001E@`00FTT005I6001?>P00Ac<004La001;
=`00CCT00511001JE@40EG0504f5500lScL0<XiJ02^7N`0YQHT202imSP0W03M]T@0kI9D0=5jG02eT
R00WIhL08GJ;01mkS00QLHL096B2031RP`0oHXT0DV6805YOS01FHXl0E5n?03IbR00[QWD0:IQM03:S
@P0fYC@0>Z8[03bT9@10YB@0@JDU042S9`11YBD0@ZTR03nY8P0oZBd0?jLk03jTB`0hY580<YmF03:P
C@0/WTX08IMC0225IP0NQF/0889/00809hYL02L0<Im403JU?P0kYSh0?:Dj03>T>00WY3l09Z/m02FW
>`0XWd80;9i802ZXC@0XZE<0::1B02JPE00VVeh099IX02:?L@0NR7H09Gek031kO00bOWX0;81i02Im
O00SNX008H9m02B8N`0XRgP09hmf02RAM@0RTgD089Ma022IK`0TX6l08Z5`02BNM@0[W7D0:iia02jN
KP0]W6h00P0YWVT09`0YW6L0<YYL032KDP0`VD`0;iI>02VGD`0TV5P08Y9N022>H@0PTEl08YAR02>G
H00RWeL08Z=@02>TC`0QXTl09J1A02RPD`0[XU00:jA=036SCP0dXe<0=J9F03JTE`0eXeH0=:9K03ZO
G`0lX5D0=ZE@03JXD`0hYUP0?:M:03f[>`11[2`0AZdO04F_6`15/Ah0@jlU042`:`0203n^<P0W042_
;`11[c00@Zl`04R/;P1;ZC40Bj<n04JPA@14WDP0AYi604JR?P13Y3X0A:Ln04BRA010XdH0?j=903fW
A@0kZDP0?JU@046ODP0nTUD0?99E042AFP17RF00D7US05YbE`1XIe@0L6YD06i^FP1YM5L0IHTi06NF
6P1/S@X0L8/607F>0P1iT040NHd007ZB001fU@00LIX10080Kil302L0JZ8806BZ2`1SZPd0HJ/A05^[
4P1F[aD0E[4K04n`8`1=/Bl0C;0i04Ra@018]3`0A/0j04Nn?P14`4T0@L1>03JfD00d/dl0>KQ803bh
A`0n/U<0?JmU046[G@14YEX0CjEI05:XH01CZF40FJEK05JQE@1ESUl0EGYb06AnJP1[N6H0IgMP05eb
I01IM680FX=M05>=G@1CRe000P1DRdd09`1CS4X0E8a:05B9C01EQED0GWeE05m`H`1ULEl0IF9V071Q
J022FV`0OUaT07eFH`1]LT`0Gi<Y072<4P21PP@0QH0708J;3`2;U1H0UXhR0:B1:02ZLBl0[G0g0:Ia
A02CM4l0R7=H08V1E@2ALE/0UfaL0:MWFP2bHed0_5iK0;1JJ02YEFX0YEYX09iOG02JJDh0UG9509Ic
B00208anC00W07Z9DP1iUDP0N:1907b/A@1l[Sh0NZdj08:c>@1o/CH0Ojdk07fX?01jZC`0NJ9007ZC
A024TCh0SYHc07jW8P1jZQD0N:PI06n/8`1//B/0Ik@Z06Vb8P1V[Q/0HJhL05ba7`1N/bH0GKD]05^c
=`1F[TH0DZ9E05BLD`1EWDP0E9/d05jA7@1VO`l0IF`506EO001RG@00IV000080J5l000<0JU`006QJ
001WE@000P1QEP008P1PE000GE4005]?001GB@00E4@005I6001KB`00GTl005iD001ME@00GUH005eI
0@1NG`40Gf<105mP0@1OG000GEP005mC001KC`00F4l005e?001KB`00FTH005Y8001JBP00FDH005I8
001IC@00FU4005Y>001JDP00F4`005]8001KB`0205U7000>05Y5001E@`00E44005=1001B?`00DT80
0551001=?P00Ccd004dh001<>000ASH004Hb0010;@0203dY000903/Y000l:@00?2/003`X000l:@00
>BL003T/000j;000?BT00080>BL000`0=R@003@S000c8@00;b0002TM000V6P008aP001dB000I4000
50d000h700071@0200H001<00000303oool000X0oooo01@0Bc8004Ph001<?P00DSl005a;001OC000
EdP0050o001=<000AC0004@c001>>P00DdL105QP0`1=NA<0>X8]02b7D00URG0098:502efSP80>FJA
02L0AdnD04M9VP12B9/0;Ef>02IXQ`0PMHT087N702=_PP0XHgh0=f:604aPS01JHXh0Ef2=04eST@1=
Gh`0<Gj002Z@IP0[WdT0<ZLc03ZW:`0nYBH0?:LR03bX8@0mZ1h0?ZXN03fX7P0nZal0@JTQ042X;@10
YCL0@:A403VSCP0fXeH0<ZI@02jVC00TXdl08iUL02BHHP0VUF800P0_V5H09`0fXdL0=jQ003nZ?P0m
YSP0=J@f02fT?`0W[4009JU202BPA00WXDH09jM:02NWB`0WVdd09iU?02ZCFP0[SfT0:HQf02B4O00U
NGh0:WJ002ilOP0_PWX0:hIh02>6M`0RSWP09Y1c02^?L`0]TG@0;99e02NCL@0SV6`07iYV02BQH`0W
XV80;IiU032JI@0dVf00=9]O03NJH002036MG`0W032MG00gVU<0=Ie=03BKB`0`VDl0:9QL02:EHP0Q
SFH08HEW02:;I@0PTV808IUK02:ODP0SXdd09:A=022TC00UXTh0:jI@02fWB`0_YDP0<Z9703FQB@0d
XE40=JAE036SE`0aXUd0=9iU03NPG@0dYEX0<jMK03NXE`0kZDD0?ZTa04:Z8`17[A`0BK0L04B`9@11
/BX0?k0^0080@:l`02L0A:l[04J`:01:[RL0CJX_05:Y=@1CXd00CJ9204FMA016Wd40AZ8j04BU?015
Yd00AZ=104JS@`13XdH0@JI6046XC012Z580?YeE03b>G`0lT600@hmT0562I`1JL6D0HF]H06eRC`1`
Jdd0J6eC05agCP1TSB/0Ki8=076>0`1eSP40N98007NB001gT`40LIT406fO1`1ZY@L00P1XZ@P09`1Q
[0X0H:d?05j/4@1J[1<0EZhD04n`501>[QT0Ak8U04Va=@18[d00@[5604>c@P12/d00A[E704FaE00m
/5D0>K1B03JbD@0e`4d0=/1>03VcE00m[5h0@:YK04>QEP1>Ye@0F:YG05R]D@1LZDT0FJM505RID@1A
Q6h0GhMN06>3G01JQED0G85H05J4F01DSeT0Ei5J05R9C`0205V8BP0W05V9A01CS4H0DHa:05B:D`1M
QU40FGmO06=dHP1]H6d0M5YZ08QFJP21GF@0NeiQ06iiAP1XT1/0MHD807in0`21RPh0QYHN09f<;`2b
Lc80/G4W0:YP>P2bIT00[79609IcEP2;M5l0RGMF099XG`2PIE`0/6YE0;Q[E`2mI5T0]eaS0;1FI02U
E5X0Ve]@09eX@02IL3`0V7=60080PXI:02L0N9A;07^MA@1nX4<0OZTj082]>`21[CT0QJ/f08>[<@22
ZC@0O:Td07b`?01kWD80PhE:08b8@02<TC80OZ0N07ZR5P1eXAP0LJLO072]8`1_[BH0JJXI06JY5`1Q
ZB00G[0X05ne<`1O]SX0Gja:05jVD@1JVUP0Fi=?05bK=`1OTaX0K7l906U/001VHP00I64006EM001Z
G0000P1XF0009`1VE@00HeD0065C001OC`00G54005Y?001KCP00FDd005E9001D@`00ED8005A5001I
A`00Gdd005mC001QD`00Ge4005aD001LEP00Fe@005U?001ID000FU4005U?001GCP00Fd/005]8001J
BP00FTH005Y7001HA000ETD005Y9001HB`00FTX005M7001EAP00DTD005M4000205A4000G0513001?
@P00CCl0054n001>?000CCh0050m001<?@00C3T004Tg0016<`00A380040/000l9P00>RL003XY000i
:P00>BP003XX000i9@00>2H003LV000g:0000P0i:@003P0h:000=2H003@X000a8`00;R4002`M000Y
6`009aP0024F000L4P005``00148000;1@001@<00P02000C000000`0oooo000:0?ooo`0D04Xd0018
=`00C3L0058l001H@@00Ed<0054o001;<`00ABl004P_001:=000DCl005M>0@1CK`X0@GlW02eeCP0U
MVT07Gj202AfT@0eIID204EAU@0W050mU`16@I`0@TJL02eNT@0XJ8T0:7B602UgQ00aK7h0A5Qf05=I
NP1LFX80DU^604MJR@0iGXh0<Vb802R=LP0WWeD0:JPi032Y:@0fZb@0=jXR03Z[7`0iZa`0>jXL03^Y
6P0mZA`0?jXQ03nY9@10ZBh0?ZTi03^W@`0gYdX0;Z]F02Z[E00T[U<08JaD02:XF@0UYU/0:ZAK0080
;Z=D02L0<ZI;03JYB@0gZd<0>JPk03BR>@0^WD00:ZQ202RU@`0YWdH0:J1802JWA`0VYDT0:9I>02FC
E00[SEl0<8IW03=nLP0ZPWH09G]l02IgOP0ZOG`0;hAh02n:L`0VTG408IQa02>GL00[UFl0;iA`02nC
J`0ZUfT08i]T026KG`0UWeP0:Z1E036KF@0cUET0=9IF03FFE00gVEH00P0aWEL09`0`WE<0=Ie?032O
B`0^X4d0:ImE02:MHP0NUfT088mY022;J@0PTFD07iMQ01jNF00LXU808:=>026VB`0RY4T09jE:02^U
BP0_YdP0<:=303>R@@0dX4<0<j1<03>QDP0`XeH0<Z5O03:KJ00dVfP0<j=R03FYH@0jZU@0?jQ0046Z
;P17ZR@0Aj/N04V_8@15/2h0@:la04:`;`0204B`;00W04Ra9P19/B<0BjhU04fZ;`1?ZCD0CZQ004VY
>P16Z3X0AJPn04JX>`14Z3l0A:U004VW>`18Y3/0AJ9004NUA017YTX0AJ1@03jHF@0jSfD0>hiY04J9
K01FNVl0IFYX06UYF01bJ4l0K71:05mhB`1APD@0HHlO06fD201^TP40M9<107BE001bU@00LiH206fO
201WYQ40HZ`G0080H;0L02L0FK4P05ba801I/R80Dk0V052^8`19/R80B:hW04Ja;P15/CP0Ak5404F`
BP17ZdD0A:M=04NXE@11Z680@:aL03b`E@0i^e80=KmC03BoD@0i]4L0>[=504:]A@18ZDD0D:]605^]
BP1J[Td0GJY205VW@@1HW4/0D8aS05b>E@1HRe@0FHm>05J@C`1ETE00EiE@05^BD`1NRDX00P1PSDD0
9`1PT440FiI005FF@`1ETd/0GI9@05^:G@1XNf80NV1[089FJP2<E6P0PV1R06m]H01aQT00N8dB07n0
101oP@<0Qi8H08b=<02>OBL0T78W0:A]:02cIc80[VY00:A[C029L5H0Q6eR08Q[H02CHEd0XfEF0;EZ
EP2kIUH0`6AK0;MIH@2dD680Z55J09]HC@2KIcd0W6m009ic@P0208F2AP0W07bDB01nWd40P:<m08>[
?@26[CT0RJXe096S<`2?WcD0Pilg07VQ>P1fYd@0OIM7089oB`2<Pcl0RXl`07VN7@1jUa<0MI@>07VG
4@1fWaT0LZDL076U5P1ZYaD0IJLM05n[9P1P/c40HK@k066[A@1UYd00K9/e06jD:01^S1L0KH<<06mj
0P1^LP00K6T006YY001YI@00K6@00080JEl002L0Ied006ML001SEP00G50005Y:001KC000Fdh005]:
001FA@00DD000591001A@@00FT@005m<001MD@00H4h0061:001IB`00FDL005U;001ICP00F4l005Q>
001IC000F4`005Q;001LB000GD/005a9001HB000F4H005E6001HA`00EdP005I4001DAP00DD@005=2
001EA@000P1B@`009`1B@000DCl004i1001B?`00CSl004ll001=?@00C3`004Xj0018=P00AS<003l^
000m;@00?BP003X[000k9`00>RL003TU000g9@00=b8003DT000c9P00=R@003HS000h9P00=bL003DX
000f9P00=2D0034P000[7@00:1/002<J000O5`006A80018<000<200020@000<1000E000000`0oooo
000:0?ooo`0D04Le0019=000BCP0050i001A>`00CCX004/d001:<@00B38004dj001DA000FU8105]U
201@O1T0>84n02Y^J@0TL7l07GBB02M/VP0iHId204MAU`0W04hoUP0n@Yh0=TVP02YPU00YJXd0:GJ6
02ijPP0nKW`0HUE]06a?L`1]D7T0DDn103Q?Q@0ZEhT09WJ002:GJ@0VYTL0:jTb032Y:00dZBD0=J/R
03NZ800gYah0>:TO03^V7P16Y1d0AJLQ042V9`0oZRl0?:Xf03^X@00bZTX09ZYE02B_EP0N/E@06JiE
02>`D`0W[E<0:J]D0080::UB02L0:jUB02bYEP0`[4/0;ZLn02jO>P0^V440;JE002bV@P0]Vd@0;Ye7
02ZVB00WYT/09iMC02>FFP0XSFD0;h9[03IfL`0[NW@08gQi021eO`0RO7l0:8Ak02f9M`0VU70089ea
026ML@0VV780;YI`02fBK00XUVT089aO01jLF@0SWU@0:IiA032JD`0bTUD0<XmC03:AD00eUE800P0`
W5809`0^WU80;ia?02fMD@0[WEP09IiS022NJ`0KV6X07i5X01n?JP0OVF<07iiM01nRE@0NY4l08JA7
02BVB00TYTL0::A602bUA00aYT@0<:9003>O@P0cWd00<im903BPD00cXUL0<ImN03>FI00dVV40=JAL
03RZE@0n[DH0B:/g04ZZ;01:ZRD0BJ/R04B^9`13/3D0@Zle04F^;`0204Ja:`0W04V`9P1;[B80BjXY
04bW<P1:Z3P0BJTl04V[>017ZcH0@j`m04FZ@014ZT00@ZQ104JU>@17Y3P0A:1404NOC017V500@i9H
042<H@0mQf`0?X5]04UmK@1MLf/0K6]S075ZG@1gJe<0JgE=05V5B01?US@0GiTJ06VE1`1/U@<0L981
07:C0@1bUP40KiP406JS3@1NZaT0F:lT0080F;0^02L0Ejla05J]=@1?/3L0BK0i04V`=P17/3P0BJhf
04Ja=`17/480A[5>04FYD@15Wdl0?YEL046JI00nWVl0>j]T03bdE`0k`540?;eF03ZjEP0o]3d0@;<b
04Na=P18[CL0DZdo05B]B`1?/4`0Cji304n]?@1BYTL0DIAH05RFC@1GUT`0F9Q705RHC@1GUT`0FYI7
05bEAP1OSD800P1RTSX09`1NUSX0GYlm05fK?@1NTDP0HXiC05j7H@1[MfD0QEea08]ELP2@DF/0Of9S
06MiF`1aRST0OXP;089l001oQ0@0TH/U09Yc@`1nMb/0PVPa0:9Z9`2eL2<0[fho0:=OD@2=KUT0RF9O
08mQG02JHeP0YF=B0;EVE@2jI5D0_EmE0;MKG@2dD5d0[UI<09mNB02KJT00WgDm0:Ai?@0208Z5A00S
07jCAP1nWch0QjLn08Z`?02<[C@0RZT`08bY<027YSH0OZ<l07ZM@P1fTdD0OXY:089nC@22RCh0PILU
07jL4@1mT@L0NhX707R@2@1gUPh0Lj0D07:U5P1/Y1P0JZDS06FZ;01P[SD0Gjdn05n^>@1YY2`0L98C
0763201^L`<0Jfd106a[001/JP000P1/IP00:P1/I@00K6X006aY001/J@00Jf<006IP001SE`00GU40
05e@001IC@00F4d005I6001A@`00DT0005A0001FA000EdT005e8001KB`00G4d005Y;001CC000F4/0
05M?001DCP00EU0005M>001IC@00FT/005U<001NB`00GD`005Q7001C@P00E4D00550001CA@00E480
0550001B?`00D440051200<0Dd<002L0DT80058o001??`00D40005<n001A>`00CC`004dn001:>P00
B3P004Hb0010<P00?Rh003/[000j;@00?2X003TX000g8P00<RD003DT000f9000=RD003@U000d9000
=RH003HW000d9`00=B@003<S000]80009a`002@I000R5`007aD001X?000D2`002`H000L400030000
5@00000<0?ooo`002P3oool05019>@00BSH004dm001<>@00CSP004/i001<=000C3L004/n001KB000
I5P2065Y2P1JNah0AhPh03EoF`0/LGT0:7::01iYX00YHJH0?UfT0P1;D9`09`1@?Y<0>dBI031>W`0X
HIH0;Ff?02YfR00aNX80C6ad07E?H01bD6d0JDmi04]?PP0cG8<09FZ002>9LP0RXUh09J]702^Z=P0]
ZBh0<:/X03BZ900iZb<0>jPS03VV9@0mYB80A:DQ03nV8@0mYR@0?:XX03VZ;`0gZSL0;JQ202JXD00S
Ze<08JaA01n_D`0W/4`0;:e902JXC00202JWC`0W02RYCP0WZ580::Y502ZX>P0/XCT0;YY002fW@00[
Yc/0;i]003:IA00`Y4P09J9:02JJDP0SWUd08YEW02f3K@0cLG@0;G9e02A_N00OJW`07G=n02EmOP0Z
PGT098ae022EM00PUg8099Ac02f?L@0bS6H0;i5N02NGF@0RV5@08Y]<02^JB@0eUDh0=I5A03:?D00a
S4l0=9=A0080;IeE02L0:ImD02bMEP0ZW5L0:Y]P02RJJP0SW6d08YQ[02FBJ@0SU6T08YeS02>SGP0Q
YU@08JI>02:VB00XYdT0:ZM402jV@P0`YT00<jI0036T?`0bX400<Ym103JPB00fXTh0<j9J032LHP0b
TfD0<iQR03FUE@0i[DX0@jhl04f]<P1=[Bh0Bj`Y04J[9011[BX0?k0d03n_>013[c@00P11/C409`18
[bT0B:hV04R[:P19Z300B:Lb04VY<@18ZRh0B:Xa04N[>017ZcT0AZXl04JY?`16YSX0A:@o04>IC014
TeL0AXUM04>2GP12PF@0?WY]041aK`1AK6d0IVU]07QYI01fJel0Mf]L06MlD`1FUD00DZ@W066L4`1Z
V0P0JiH506nE0`1_U040KiD006fK101YY0h0Hj/H05f^900205Z_;00W05R[<@1AZS/0Cja004Z[@01;
[Cl0Aji504N^@`15/4H0Aji904b[C`14Xdl0AiMH04>>I@12UF/0?YUd03bUJ00j[Ul0?k5D03njD@10
_d`0@klm04Ve<`1:/S40Bk0b04n^?@1<[4P0Aji=04J]A`17[T00CZU5052ICP1EWDP0EJ17056NA@1B
WdX0EiM605^F?P1MTSh0HXdj0080Hi8e02L0GITn05fO@01PUD80G7m?05emF@1HMVP0I6e[07mGN02:
CgD0TE9^085XH`1SPUH0LY0b08>92`25Q@X0Oh/I08V5:02=MSH0TVh^09iV:P2PKBH0Xg4b0:A`B@2Y
K5T0UW9N09ATG02KH5l0Z69M0:YRE@2`Hdl0]f5<0;aPAP2jFdl0^EAB0:mS@P2OKcl0VgHo0:>0?@2X
QCL00P2@R4409`20SDH0QI]408ZS@`2;[d80Qjhf086V;P20[2h0Q:Tf08BV?`1lVD<0NX]80826B`20
QdX0OI4c086F6@23TPP0QHL208:50`20R0@0OX/907bC3P1hT`l0NiHC07NH6`1fVQh0KYhV06fJ9P1^
V1l0M8lF079o2P1^L@40Jf@006UR001ZI@00J6P006YU001[I`00JVP006]Y000206]W000W06QT001Y
GP00HUT0061E001LCP00EdX005E8001E@P00DT0005<o001C@`00ESl00590001EA000ET@005M8001F
B@00D4H00555001@A@00Dd/005=:001HB`00EDH005I7001MB@00G4`005Y=001EA`00ED<00551001C
@@00DT800590001A@000DT800553001B@000DD800080E4<002L0E4800551001@?`00DSh004hk001=
>P00BcL004Tj0018>000ACD004Dd0012<`00@Bd003h/000l;000>RT003PW000f9P00>24003@R000e
8000=B<003<U000b8P00<B<0038R000c:000<b<002hO000Z6P009AP001hF000M40006Ph001H<000A
2@002`D000D100010@005@00000<0?ooo`002P3oool05015=000@cH004Tg001:=`00CcL004`f001?
<`00CCX005Q2001RDP00IVD405em5`1?RSP0>XmR035nNP0_LHL0:6fF01mNX`0]EJP0?eFU0P1=Cil0
9`1>@YT0>4NG02iAV`0^GiH0?6F@03iZQ`12IX<0DUac06Y>IP1MEGL0DUZ1041PQ`0_L8008h1f026I
J@0PZET08ja902R^?`0/[C@0<:d`03>Z:P0dZBP0=jP[03NW;P0jYR/0?ZHV03bV900hYb<0=jPW03JZ
:P0fZC40<:Ho02ZWBP0WYe009:YB02B]E00Y[TH0;:To02ZXB00202VVC@0W02VWB`0[YT/0:jTj02fZ
;`0/Z3<0;J9002^Y?@0ZYST0;iXo03:GA@0]XDL09jA:02RKD00TXE@09Y]L02b8I00dLfT0;W=[02I^
L00QIGP07fah021cM`0XLgH097ef0226M@0PQg<09HMe02j3L@0jOfL0=XQN02f>G@0STeP08iU?02bJ
B`0gUdX0=i=@036CD@0^Se@0;YIF0080;9eJ02L0::5L02ZNF`0/WUd0;iaR02fMJ00YWVd09i]]02RE
K@0VUV/09IeT02:VGP0SZE<08Z]902NY@@0^ZCd0<jTj03JU>`0eYc`0=:Xl02nV?@0bYD00=JE503BV
A`0cYTl0;jEN02fNH@0_U600=9]J03NUC00mZd00AJdf04f^=01<[3P0Bj/_04B/:00n[Rd0>[0i03Z_
?`0l/S`00P0m/CT09`10[Rl0A:/V04RY9`17Z300B:T/04RX;@18Ybl0BJLa04RY<P1:ZSD0AZPi04JT
?`16Y3d0@j5404BDD`15RV40@h=S04>2IP12PFH0?gIZ04=XKP1FHFh0Jf=/07YUI01cJ6<0JVIP05en
D01CWC@0F:LI06NI3@1`U@H0Ki@3072E0@1dUP40LY`106fR1P1ZZ140IjhK05n^900205ZZ<00W05V[
<`1EYCh0DJ94056OB01@XdT0BZ]E04Z[DP16ZEH0C:IB04NOD011V5@0AXiP04B8K`13Sg40?Y=d03bN
L00lZ6X0?ZiK04>aC@13_d40B<0i04^e=01=/bh0B;4_04Va>`15/D`0@jmA04F]B`10[4/0BZU:04bT
E01LY4@0G:<n05RQ?`1HWT@0Gi9605n=@P1PSSh0HY0h0080HIHk02L0G9U105jLB@1LST/0EGAC05Aa
F`1AJfP0IVaW07UHM@25FW00TeMX08=aH01URe00LiH]08N@2`28S1D0OHH`08V2:@2KJ400YV8`0:]V
:`2TI380Z6<o0:A]D02WKEl0VW1M09aUFP2SGeH0ZUeF0:]KE@2[FdH0[f0n0;QY<`2kID@0_5i70;5Y
@02NM400VGM00::2@02VQd000P2?QTL09`20Pdh0QhY808:GC@1mXe40NZ=607ZO@@20Z3T0PjXi08:[
>@1oXCT0OY@l07fI>01nWC40P9XM08BD3`28R@<0QWl008Ij0025O@40Ph0207f21@1mP`D0O80507j4
2@21Q`X0NhT;07R02P1hN@P0MG@5075^0P1]IP00K60006QP001TH000I64006eW001aKP00KV`006e/
000206]U000W06]R001ZH`00J5h0061B001KC000FTL005Y8001EA@00ECh0050m001@@@00DCh004m0
001E@P00EDD005M6001CAP00D48004Y2001@A000E4H005E8001FB@00E4@005I4001CA@00F4T005I8
001HB000DdD005A5001BA@00DT800510001?@@00DT@005E5001D@`00DdP00080EdL002L0Ed<005I0
001B@@00Cch0050j001<>@00AcH004<f0015=@00A38004<d0016=@00@C0003d^000k;000?2X003TV
000e8`00<b40030O000_7`00<Ah0034O000b8@00;Ql002hR000b9000<28002dO000V5`008A@001`D
000H3`004P/000l9000<1`001P<000@1000100005@00000<0?ooo`002P3oool0500n;P00?c40040d
0019=`00BcH0054e001A>P00F4<0069=001YG`00JgH405j<6@1<Uc`0=YAW0366O@0^O8H09gBC02AJ
X00cBJ@0A4ZW0P1?C:409`1=BIP0=TZD035@T@0fFi40BEf:04eHQ@1>Ch00D4ag05M;K`13F8H0?EfA
03EUSP0XO7h088ib01nRI@0OYeH09:a;02Z^@@0^[S`0<J`g036X<`0bZC00<ZPb03>W=@0eYS40>:L[
03RW:@0dYbP0<:T/036Z;00eZBl0<jPh02bVAP0VZ4h08JUF02:YFP0WZTL0:JY002VW@@0202bVA`0W
032WA00aYT@0<ZPb03>[9`0d[340;ZM102f/?00]YcL0;iPn036F@00]WdD09j5702RJB@0YY4P0::1?
02Z>E`0`O5d0:WUQ02M`JP0QJ7@07FYf01iXM`0SI7P096eh01mbN`0LMGX08gIk02ecN`0eLW<0=GeZ
02^7H`0TSUh08iIC02bJB`0iUdX0>II@032HE00ZUEP0;9QM00809imS02L08Z1S02BNH`0XWF40;YiU
032PJ00[XV/09im]02RHL00UUfd08ieT02>UFP0TZ5009jU802fX?P0bYcT0>:Ph03VX>P0hZS`0<J/l
036Y?P0cZT40<jU403BYA`0`Ye<0;JEJ02jSFP0^We@0>:A<042W@@14ZCX0BJXj04^Z>P17ZCd0@ZXf
03n[;00k[Bl0?:li03f`A@0n/D<00P0o/3h09`12/3<0AJ//04B[;P15Zc@0B:X_04VZ<@17Y3P0BJ<f
04NV>P19ZCd0AjM004FPA014WDH0A9M;04>;G012PVX0@X5/03j0K@0lPF/0?WEZ04IWK@1GGg40KEi^
07]RI01]Ieh0G6]L05>2A`1CWBH0HJ@?06jG1`1cTP<0Li8107:E001bV@80Kj4406RZ2@1U[Q80H[4M
05f_8P0205^/:P0W05^[;@1JZSX0DZU204jUBP1?YU00AJUO04BUG`11VV@0AIMO04J?G015REh0AX9T
04N1JP15QFl0@X5f04:<MP11UG40?ZEU042aD012`4D0Al0e04^e;P1;]2`0A[4_04Rc>P17/TX0@;5?
042ZEP0lYeT0AJMD04^WE@1MYdD0GjDm05^P>`1HVd80HXY506J2AP1SRd00HY0l0080GiPi02L0GYA5
05bFCP1KSU80DGiH059dH`1AIW00J6Ib08QQL02?H6T0UEiU08AgE`1ZUSh0N9`Q08ZF3`2>UQT0SX@_
091h9P2=IB@0Vf8Z0:5R;@2ZJ3D0ZF/n0:1`C@2EKUX0TFaH0:5ZF`2XIU00Z5Q30:QAB02VDSh0[5hf
0;I[<@2jJSl0_6I70:iT@02KK400V7@o09ag@02NNCd00P2<P4P09`1oPDl0Q8=<082:E01lTe<0OYU<
082KB024X3h0Q:Hk08>X=023Wc00Q9XY07nL8`20WAP0Pi@>08:>102:Q@40QW`0089d001lLP00OWL0
07ak0@22O@00PWP007ml0020NP00OWT007Qa001eL000Lf/006eW001[HP00Jf4006MQ001RFP00IUh0
06aU001cK`00LG40075_0002071[000E06m[001[IP00J5d006=G001OCP00Gd/005i?001KB000Ed80
0510001C?P00DCh005M1001IB000EDP005I:001GBP00DdL005=5001@B000DdP00080ETH00100Dd@0
0515001B@@00DdD005I7001EA@00ETH005E6001EA@00C3d004Tk001;>@00C3`0050o001A@@00Dd@0
0P1CAP009P1E@`00Dd<0058o001??P00CST004`j0016=@00AC<004<`000n<@00@C00048a0014<@00
@C8003l/000k:P00>B`003PV000c8P00<B4002lP000[8P00;R4002dN000]8000:al002lN000/7@00
:Q`002PI000P5`0071<001H=000?2@0030L000P400040@000@005P00000<0?ooo`002P3oool0500k
:`00@S@004Pg001@@@00ED@005a;001OB`00He8006EP001`L@00LHT506:L5P1<X3X0=IYU02j@NP0]
SH<0:gf=02IHVP0i@:00AcnV0P1?C:L09`1;C9T0=TVA03=@R`0nG8X0E5^305MDP`1HBX00CT^004]C
N`0hIHL0<Fb=02]cQ`0TQgT089I^026VH`0SZU809je702f]?P0aZc`0=:/j03BZ>00cZCH0=JPj03N[
>`0fZCH0=jLc03NV<`0fZ380;jPe03>]=@0h[340>ZXa02nY>P0TZ4/08ZUI02BZGP0T[U809ja802ZZ
A`0202jUA@0W03>T@P0dXT@0=ZHd03J[9`0gZbl0=JLn03:[=`0`Z3@0;i`j03>J?`0]X4409j9302NN
A00VY4009j9602RFC@0XQe@09XAF029hH`0MKG<076Yf01]RN00VEWX095]i029OO@0QHGd08f=o02US
P`0aH800;71h02YoK`0VRfL09IAK02ZIDP0eVE40=9]G02fMF@0WVU`0:9]U008099eY02L089e/02>M
I`0WWFH0:imV02jRJP0XYF`0::5^02JIM`0TUfl099eO02>VD`0WZDP0;:U5036W?00gZ3/0>JPi03^W
>`0hZC`0=:Ph03>Y?00eZSh0=:]403BXB`0_Y5D0;:=K02bUDP0^Yd/0>jM604BX?P19ZSh0BJY104J[
@`11ZT<0?J/m03Z_>00n[S@0@Zld046`=`14/3H00P17[S<09`17[2H0B:XT04NY9`17ZRh0CJ`Y04fZ
;P1;Y3H0Bj@i04^W?018ZSl0AjQ204NOAP18Vd@0AYM904B4F`12NfT0?GY_03]mLP0jNW40@75_04YR
L@1LFg@0Kea_07URI@1VIeh0DFeK04b5@@1IWB00Iil9072E101fT000MY<007>C001aV040JZ4406NY
2P1P/AL0F[0P05N`9@0205^_;P0W05N]=P1K[T80EJe904j]B`1A[UP0AZ]V04BLI`0nRW40@8E[04Ej
J017LVH0BWMY04]hJ`19Mfh0AFMi04EaN`15O7D0AIEY04B`FP14`4l0B<0m04S0;`1:/Rd0A[4`04Bb
<P19/Sl0A[55046[C`10ZU@0CZY804jX@P1OYc/0HJDh062O>`1SVT80IXlo06^9?`1YSSh0IiDj0080
HiHc02L0Gi9005bBDP1IReL0DH]Q05ElJ01CHWD0Kf1d09=PL@2GHV@0UF1Q08=jE@1_W3<0OZ0N08FR
5P2MVAT0^WPi09ac8@2XGb`0Z5d^0;ES9@2^JRh0ZFa209M_D028J580SV]?0:E]E@2ZJdT0/5i00:IC
@02PET00YUhi0;5U<@2gKSP0_FU30:eP@02LH400W74h09a`>P2JJS@00P2=NSl09`27OE00R8==08J;
C02<R4`0QIa8082Y@025ZB`0Q:TR08VT7P29WaL0RiPD08RD3`27T@`0Qhd808J60@28PP00QW/0081b
001kJ`00O70007ig001kN@00OW4007ib001kL`00O78007U_001hK000MV/0071T001YG@00JEX006AK
001TE`00I5X006US001`J`00Kg0006e_0002071_000W079Z001/H`00JEh006IJ001VEP00GU0005];
001IB@00EDT005E1001E?P00Dd8005I3001JB000G4T0061<001MCP00FDh005M:001CB000DDD00519
001DAP00DD<004i0001=?`00Cd000511001CA`00EdT005M6001B@`00Cc/004Xj0017>000BCH004dn
001=@@00DT400080Dd8001T0Dd@00553001?@@00CS/004lm0019?@00BSP004Lh0015<P00@S8004<b
0016<`00ASD004Df0011<000?Rd003h[000g:000=BD0030T000_8P00<2<002hS000]8000;Ql00080
:1/000/09A`002PI000T5`0081H001XB000E300040T000L500040@000@400040000F000000`0oooo
000:0?ooo`0D03`c0019?@00DTH005eA001OF000HUh006QR001WI`00JGH006n50P1aV`T0HJDI04VW
?`0fW6X0;I=o02bBP@0[OHP0:EJE03]2VP1;A9d204i>V@0W04=?S`0gDhX0=5b403UYPP14KGl0C6J3
04iJQP12FHl0=6N>02MfS@0UNhD08H6001n<MP0OVFd08ZQP02R^D@0Y[d40;:he036/<P0fZ3@0<jTj
03:Z@00fZT40=JU303NY?`0eYcl0>:Ho03NZ?`0cZD80=jXl03n[<@0n[2X0=J/d02b[@`0]ZU809j]O
02R_EP0WZU00;ZM;0080<JA602L0=:9203VOA@0hY3H0>ZX[03^Y;@0kY3X0>jPc03JX<P0cX3L0=9dj
036S?P0[Y480:j1502RU@00WXT@0:9Q:02V=D00WRDl09H9E01b0GP0IQFD07WmY02UbJ`0^Lf`0;W=a
02adN00VL7X0:6Ym02USOP0XLg`09gma02N9J`0VTV40:IUI032KEP0^WEX09j5M026NG@0RWUl00P0Q
Wf409`0OWf8089mP02:OH`0UX6@0:J9V02FUI@0UXfH09iaW02NKHP0ZWe80:JE802bW@`0`Z400=jLk
03JV=`0kZ3L0?:Lj03NX=P0bYcD0<jPk03NZ?00eZd<0<JQ=02nUF00_YUX0<:Q?03>/AP0iZdH0@ZY6
04B/A012ZDX0?jY903Z]A00j[d40>K15042`?@12/340AZhZ04V^;00204ZZ9@0W04^Y7P1:ZQd0C:/R
04VZ9P1?ZRL0CjX^052W=`1<YcT0C:Tk04ZY>P1;Yc`0BJ1104ZL@P17Ud/0AXUL045mJ@0mN6h0>W9c
03U`M013JW<0CF1f05eMM01/HFd0LFQV05abGP1<NUP0DXdo066K7@1/W0L0KY@407:C001cU000N980
07RF001iV@80MIl906fZ301R/180FK0F0080FK0Q02L0FJlc05N_>`1H/3h0E;5505>`D01:[600A9M/
03]mM@10M7D0AFQa04UVL@1=Jg40CW9]04]bJ`15G7/0A6]n04IhN@18TVX0AJeO04G0DP18`400AkHe
04S0<@17/S40Ak4^04j`=P1=/T00AZe904J]D01HYd00EjA005^O?01QX3P0Hidj06FL?P1_TcT0LhTh
06V>>P1UTcP00P1UU3P09`1PSD<0G8UE05R4G@1CR6<0FWeW05eNMP1bF7@0SEU`095QI02?Hf<0Oh1=
07JR9@27ZAT0V:<Q0::B7`2bPB<0XW@I0:iZ6P2OJ2/0YfHl09mYC02IKE80VW1:09U/@`2OJd<0YfQ7
0;1PA`2lED00/UQ50:5PC`2QH4L0[Ulk0;=Y@@2mIdH0Z5e809eRA`2OKSP0X7Dk0:9e?@0209Um@P0W
08mmC025RTT0Phi:08fE@P22YSX0PZP[08FU7`28W1L0RYPD08fC3@2<S@<0RHH308J70`25Q`80QXH0
081o0023NP00PG@007ea001nL`00NW0007Uc001hL000NfP007U/001gJP00N6d007M]001aI`00KF00
06QK001YD`00IeH006EH001VG`00JF@006e[001^K@00K7400080KW0001@0K6h006aU001ZHP00J5l0
06EJ001PDP00GD/005a9001PB000FdT005Q3001G@`00EdH005]:001NC@00GU00061;001KB@00FdD0
05I80080E4H000L0Ed@005=2001A@P00Cc`0058n001C@000F4P00080FTX000P0EdH005M3001A?`00
DC/004/j001>@000DT8005140080Dd<002D0E4400550001??`00CCX004dl001=>@00BCH004Td0012
<@00@380048`0013=000ACH004Pg0015<@00@bl003h^000j:`00<b/0030T000^7`00:ad002`O000Y
6`00:1`002LM000W6P009Q`002DJ000R5P0071<001T@000D2`0030L000L300010@000@0001L00000
303oool000X0oooo01@0AC/00517001HCP00Ge`0061Z001QKP00I7H206=o0`1TS@L0JiH=06RT501J
ZBP0?:=A02VEN@0VQXT0:gn5031[Q`0`BY<0@d:H04a6W080BdjC02L0?5::03IJPP0eIWl0<WAo03El
P@10M8/0AFRD03eSV@0[MY@07XB:01j8P00MRgd0795g01fMJ@0PZUd08Zi=02J_?@0_[R`0<ZhZ03N/
<00cZSL0=:Xi03JX?`0gYcl0>:To03FW?`0eZSl0=Z`o03N/@`0iZc`0?j`_046/:P0j[CH0<je0032Z
C`0`ZEX0<JaE036ZD`0aYd`00P0dYDH09`0fX4@0=ie803NQ>P0jZBh0?:Pb03jS>`11ZSD0>Z/`03JT
=`0cXSX0=:Pm02jXAP0^YDT0:ZI402NSB00YVe809Y9D02N>DP0USED089=G01bHGP0OTf809hMV02f2
J00^PFh0;H1e02QkN`0UKW/09FIn02AcNP0TP7@098I^02BAJ00XV680;Y]P02jOH`0WXFD08J1U01nQ
H@0201jQG@0W01fSG00MXeh07J=R026SI00PXfD08ZAT02:RH00QWUl0::5F02fRB`0^YD00;jHl036V
>@0eXcD0=jHb03VY<`0kYC<0=ZHb032V=@0`ZCP0<ZXm032[?`0]Z4X0;ZQH03>YF@0eZe40>:e603b[
B011ZTP0@ZY604>Z@`0oZTD0?Za603^_AP0l/D/0@;5104R`<P1:[BH0Aj/V0080BJ/Q02L0BjXH04^Y
5P1<Z1l0B:T[04n[;01BZc80DJ/h04jY>@1=YcX0CJTi04bS?018VD80AiE504NFB`16Se/0@GmU03ic
JP0lIW00?fAe04MTM01BHGD0FUic06ERKP1XJfD0FGaN04^:F01EUS`0IiXH072D1P1`U@<0M9@007FC
001iT@00OYD007nF001mVP80LZ4706RX2P1M[Q000P1J/1X09`1E[b@0EZl`05>_=01B/3h0Dje604RT
F011U6D0>X9b03]eM013JW@0B69c04iUM@1?KW80BWM^03mhM`0oQWL0?9Yd03fWHP0o[eH0@[E804Rc
>`1:`380D;<c04Vc<P1?]380D;4k04Zc@P15/4/0A:mB05V]@P1KY480GJ4i06>R>@1UYCD0JJ@h06jM
=P1`TCD0IY8e06NA>P0206^@@00W06R:B`1ORE<0F8aI056;I01FOFD0IUUb07IBL`27DW@0S5mX08eY
G@21Q400NZ<I096W6@2^Rc@0Y8@S0;Qf:P2WLQ`0Z6`T09QV@02PI5D0VfUH09e]D`2WJdH0ZFLl0:IV
?P2[G4H0]U560<YA@`2oFDT0]f=G0:QLD02/E4D0[f530;UWAP2WHe00VF5A09ab=`2PMch0Xge90080
W7a;02L0S81A08:BB01mWd80PJPf082V8027WA@0S90>08b>3@2ARPX0ShT508Z50@28QP40QHD108F6
0@22P`40PW`0085j0021M`00P7H007ia001kL000Mf/007M^001kK`00Ng<007]b001mL@00N6h007EY
001bI000KF4006iM001[F`00JV8006YY001WJ@00L6X0071`001`L@000P1_L`006@1`LP00LG00071Y
001/HP00K5X006EC001OD@00HE<0061<001PA`00EdH005I3001G@P00F4P005]9001KC@00GdT0061;
001MC@00FD/005U<001GB@00FdP005e8001GAP000P1G@@00301KB000G4`005i>001NCP00Fdd005Y7
001HA000DSl0058n001A?`00E4L005=50080DD4002@0Dd8005=0001A?`00Ccd004/l001<=`00ASH0
04Pg0014<P00@34003lb0011<P00A3@004Hk0016=`00@cH004@_000m;P00=bX003<S000`8000:a/0
02XM000W6P0091X002HK000U6`008aX0028H000R5@006A8001P<000@2`002PD000H300020@0H0000
00`0oooo000:0?ooo`0D04]6001ID@00Ged0065X001ONP@0HXD906FC3`1XVA<0L:4I07RP801YX2@0
DJ<c03:MF`0RSh0087f:02YZPP0dEH80?D6>04m4T@1ABi8204MDRP0W03QIP@0bJ7/0<WEj02aoO@0[
P8@0>GJ<03U_TP0aKI@08Wn>01n;Q00NSh007YEm01ZMK`0OYUX09:a702Z^?00_[c80=JdZ03J]:00h
[B`0=Jha03RZ<P0hZcH0=jTh03N/>`0eZS/0=:`j03J]?00f[D00=j/k03Z[<`0h[Bd0=Z/f03F[?00c
YTL0<jE@03FZBP0iZd/0>Z]70080>jI402L0>JA303RLB00hXT00?JLf03jX=P12XD00@jPg03jY<`0i
YCL0=:Dl03>U@00`YdT0;Z==02ZUBP0WYE409J5K02>FH`0RS6@088mT01fIHP0KX6D06i]W01n>J`0R
Rfh0:8Qf02V6N`0UP7h08G5n029VO@0SLW/08gYg02:0L`0SRW<099E_02RKKP0WWW008:=b01nQK00M
Y6@00P0NXeX09`0MY5L06ZQM01ZYI@0KYFH07JEU01jVHP0OYEP08:EE02RUB@0^Y3d0<:@g036T<P0a
Xc40=J@b03FY<00gYbh0=J@_03:W<00[ZCL0;jXh02jZ>`0]Zcl0;JU;02jZF00eZe/0>ZeE03b/C@0l
Zd`0@JU?04JYAP16[D40@Je303j]B00n/DL0?k=804>`@018[cL0BJ`a04F]:`0204R/8`0W04V/601;
ZQH0BJ/M04Z[9`1>ZRL0Cj`]04j[=01<Z3P0C:Pi04VY>`18X440AYI404JEB014UTd0A8eM0460I`0o
LF/0?Ui_041LM018GWH0DF5f05MQM01MHf`0GFiU0526FP17VE80Ej0e06ZK501aV0D0MYH207NE001m
U000OY@008:F0020U@00O9/107>P0P1[XPT0GZX?0080GZ/?02L0G:dD05b^7P1H/RL0E[0`05:_>013
ZdX0?j9G03^@J@0jOg00?fma04EQMP1>HWH0CfAe04=eM00iP7`0=IAk03>YLP0h[fH0?:mF042bB@18
/cd0CKDf05:e=01:/SD0C;@l04^b@016/TT0@K5D03jdH`1C/4L0F:Y105jV=`1RZ3H0I:/^06FY<`1Y
Y3H0Jihj06>F>01RS3`00P1ZS4@09`1]Pe40IHAC05n;F@1FQV<0H7IS07EHKP1lDVd0QDm[08EQHP23
LE/0PhTi086S6`2?UaX0X8DX0:=n802QN1d0WW8W0:=Z;@2RKd80VWQ>09=jE02=Me40Tfa<09M/C02L
Ie00/5e=0;]GA039DcH0`EHj0;]SC02[G4h0[U930:mO@P2jId@0YVY509]TA`2LJd<0WgU60::6BP02
09^3D@0W08b2D`1oUD@0PJ<d08>U8P21V140QHH408Uo002=PP00SX8009230029P@00QWl008N00025
O@00Ph01085k0022MP00OgT007if001mL`00NVh007UZ001mJ000Nfl007ie0022M@00PWH007ic001i
KP00M70007I`001bJP00KVD0071T001ZK000Jg0006md001bNP00LG@00080Kg000140MGP0079e001b
K@00KfH006eP001UG`00JE/006MF001SD000HU0005m@001OCP00FTP005Y7001HC000G4/005e@0002
065A000;05e>001JCP00GDl005]=001NC000GDh005a;001KB000G4`005m=001PCP000P1QC@001`1M
BP00FD@005I2001D@`00ED<005M4001F@`000P1GAP003@1DAP00E4<005A2001A?`00D3d004hl0018
>`00BCH004Hc0015<`00@cD004<`0011<@000P14=0005@14<`00?c4003d^000i;000=B@002lS000[
7@00:1`002@I000P5`007aD0020D000N4@007Q<001`B000I3@0050/000l80008100010800040000H
000000`0oooo000:0?ooo`0D059?001LG`00HVd106=o1`1PUA80HI/Q06ZI;01]U3<0MI<d072G<01K
WR`0?J1002VHI00PS8008GZ702iYO`0gDH00?T6704Q8R@14EHT203]UP`0W02adN`0[QG009H]]01j8
MP0TOh<0:gN>02UeT@0SMHd07X>501j>Q00NThP07Ian01^TH`0Q[Td0:Jlh02n^<@0f[2/0>JdW03b_
9@0l[B/0>:h`03R]<@0j[S80>Jdc03b/=010[3H0?:/h03V[>P0f[3/0=jTh03NY=00cZc80;j/e036Z
>00cYT40>:A:03ZXA@0mZTD0?:Y00080?:Hn02L0>Z@n03ZLB00kXSd0?:He03nY>014XT00@jPg03fX
=@0mXST0>J<h03NW?00hYT<0=jA5032W@`0[ZDd09JEF026QH`0UVFP08iQ/022PJP0NY6X07Ye/022@
K00TS6`0:hM`0327LP0YPg0097e_02IfK`0UO6h09X1`02>3K`0RSG0099Ac02JHL`0RWG407:=`01^V
J`0JYf000P0MYU@09`0OYED06jMN01VWI00KYf@07JMS01nXF`0RYe009JM902VW?`0_YC@0;j@_02nW
;00_Ybh0<JP_02nY<00_ZC40<jD`02fZ<P0[[3T0;J/l02n]?P0_Zd00;jQ:02jYE@0cZUh0>Z]O03VZ
F00hYeH0?ZEE04>XA`11[4D0?Ji;03^^D@0j[Td0@;1;04>`@P17[cP0B:dd04N_;P0204R^8@0W04Z]
601=[1L0C:`M04R[9P19ZRH0BZ/Z04VY;P1:YS@0AjPh04BS?@18WD80Ai]604NKB@16W4d0@hmM0462
J@12Mf`0@VU^049RLP19H7D0C69c055SL`1LI6`0GW1Y04n9FP18WD`0Ej@^06^L401bV`@0MiX107VI
001lU`00OYH007jG001kV000NY`0072Q0P1/Y@T0G:`C0080GZXA02L0H:`?05f]4`1I/200E:lZ04n`
=012[d40?:i403NXCP0hWU`0>heT04:3L018OFl0AWM`0461MP0lRG/0>IQe032YL@0e/6@0?;1G04Ba
C@1=/cd0D;4e05Jc=01@/S@0CK@i04N`@P14/dd0@K9Q03nbL01D/4`0GZTn05nU>01OZ3X0IjXd066V
>01RX3/0IIY4062C@01PS4<00P1RT4`09`1UPU80J7MD06IoE`1LOed0JG=M08ELI02:EfH0R5AQ07iV
F@1bM5P0N8`m08NA=@2=RB<0ZWl`0:9e9@2/KBX0[6Pm0;=[=P2ZN4<0UWiE08ahE`2:L5L0TVMD09ET
D@2IIE80Z6A30;AQ=@2iFRT0]5d]0;eR@P2aGDh0/U190;1K@`2gHD00YfQ10:9X>`2LJ4h0VWQE0:B5
D`020:24E@0W08^<D025Xc40SYhM08n@3`2:R0D0RWd108]o002?PP00THD008j30029P@00QWl008Un
0026O@00PgX0081j0024MP00P7D007ec001kL@00N6d007YW001jI@00O6/007ea0021L`00Pg@0089d
0020M`00NWD007]i001iM000MFd0075W001_K000JW40075g001fNP00MW<00080MW8000D0MGL007Ag
001`L@00KFd006iV000206iS000P06eP001TE`00IeL006AF001TC`00GTh005a6001LBP00Gdd0065?
001RDP00IU4006AB001QDP00HDh005m?001OD000GU8005i@001NC000GDd005m<001RC@00HDl006=@
001OB`00Ed@005E3001GA000ETD005E5001E@`0205Q6000<05M7001EB000ETL005I5001EA000Dd00
04ln001:>@00BSL004/f0017=@00A3<00P12<@005@0o<P00?Rl003h_000k;000>BL003@U000_8@00
;1d002PK000T6@0081D001`B000K4@006a0001T@000I3`004``00108000:1P001@800041000I0000
00`0oooo000:0?ooo`0D05EV201GN`l0FHlJ05bH9@1QWc80Hi4l06n8@@1dQC`0M8dj06^I;01AYRh0
<j==02>IJP0QSG`09Wj002e^O@0eDgd0>4J103m;P@0gFh0202edO`0W02N;N@0QVFd06YA[01N1M`0L
N8D087N@01ejS`0JOHT06HJ201^CP`0KVH807J=f022YE`0X[c`0<ZlX03^`9`0o/2@0A:hT04F`:00o
[Bh0>Jhc03R`<P0h/3<0=jle03j^=`10[c/0>Ze003F]@@0a[D80=:Y003>[>P0]ZcH0;JXh02nY=`0b
ZCh0=ZI503Z[@@0j[3h0?Zdj0080?JXh02L0?JHg03^P@P0lYCd0?jTi04:Z>016Yd80AZTj04>Y=`12
YS`0@ZHk03bX?00iZD00>:E003>X>`0Z[4D09ja>02>XF00TXf408j1W02>UIP0PYf/08JAY02:HJ@0W
UVP0:i5Y02j:KP0YR6d09hI[02B2J@0TQF`08XI^02>8KP0RSG808I9f02:DN00NVW@06J9_01RXJ00I
ZEh00P0LYeH09`0OYUP07:MQ01ZXI00KZf006jQL01jWD`0RYTP09JQ002VW>00/YS40;:L^02^Z;P0]
Zbl0:Z/`02^[;`0/Yc00;Z<`02^/<P0][SX0;Zi002n]@@0b[480<:=6036TCP0bYU/0>JQO03^XG00h
YUX0?JEC042[B00n[TX0?:mE03j]D`0n[D/0@Jm504J`@01>/CD0Cjlb04^^:P0204^]700W052]501C
[1<0D:dH04^^8@1;[2H0B:XY04JW;P1:YC80A:4g046M?@14W400BJ1304VSA`15WDl0AHiO0462J`11
OVh0@7=_04EYLP16I7D0Af9b04eVK`1JJFX0GW5V056?F@19YTD0EjLT06RN3P1^WP80LYl107NL001m
VP00OIP007nG001lUP00O9T007JP001_XPL0GZTC0080G:`E02L0G:dG05Z]5`1F[Q`0CZlW04b_<P13
/D00@[4j042c>00m/T@0?:aH03^YJ`0nXVH0?IAV03RBL@0kTgL0>ii`03FWK@0f[FL0?K1L04VcEP1=
/cd0C[4a05:a;`1B/R`0D;8e04FcAP13/E40@K1L04B`J01I[DT0Gj4o06>S?`1QYT00HZPo066T@`1Q
WDP0HXi:062<A@1PTdP00P1QV4`09`1QQ4l0J75E06UkF@1NNUh0L7AM09ERH`2DFf80S5UI07YVFP1R
M5L0KhU008F<:@2ANbP0Vg@U0:I`9P2[Jc<0W6Y309E/B`2<M500RGME08edF`2EL5/0WVaH0:1ZCP2F
Id@0QVa7095_A@2PJd40X6Ha0;EP>02gEDd0/TUK0:eKD`2_HD`0WVE60:5W?P2PJ540WgMG0:23F002
09R?B00G08nI=P2=W1/0Shh>08j50@2>P000S7l008in002@PP00SX0008ao0026OP00R84008R30028
O@00Q7X008=h0022N000Og@007i`0020KP00NfX007UY001kI@000P1kK0003P1mL@00OVl0081b0023
MP00Q7X007mk001mM@00Nfh007M[001cJP00LVl007Ih001gNP00NGP00P1lMP007@1gNP00MG<007=a
001bK000LFP006iT001_H`00KV4006UI001WE`00IEH006M?001QC@00Fd`0065:001OCP00HU0006MD
001TE`00IEH006MF001TDP00HE8005m@001QD000H58005i<001QBP00H4l00080HE4000P0GU4005e;
001I@`00ETD005M3001H@000Ed<005I30080EdH002<0G4@005U4001HB@00E4D005U3001D@`00Dd40
050m001=>@00BcH004Tg0018=000A3@004@c0014<P00?bh003h_000k;000>2/003<U000a8@00:R40
02PI000Q5`007aH001hE000M4P006a8001P@000E3P0040P000/600070`0010400041000I000000`0
oooo000:0?ooo`0D05Z96P1QTRD0Ihh^06b9<`1fPT00OGQ607i`@P20LSX0MXHg06FN<011YCh0:Z5K
022HLP0PSWL09H9k02i_M`0bFG/0;Tan03ABOP0/HH0202AgP@0W02>AM@0PW6T079=/01UoM`0JMX@0
5gFC01Z1S@0JRh@069Yh01bQKP0SYF00:JUB032/@@0h[bl0?jlV04B^8P15/R<0BJdW04R^;011[S40
>jld03^`<P0l/C<0?jdd04:/=`12[Sh0>Z]803>ZD00^Z540<JM=032WA`0aYT40<ZDl03FW?P0iZ440
>jY603^/?`0m[CP0>j`e0080>ZXg02L0?ZPh03jW?`10Z3X0@ZTb04>[<`18Yc`0BZ`c04RY<P14Z3P0
@jHm03n[>P0i[CT0=Z/h03B[>00[ZT<09Za>02F]D@0UZUT08ZER022YI@0O[6L08:YY01jWJ`0QXVl0
9IUa02J?M@0SQWD07hAg01n2M00LQgD07HYc01j;M00ORgX07Xb001f?O`0JUWX06J9b01ZWI`0JYel0
0P0LZ5H09`0MZ5T07JMU01jYI@0PZEl08JII02>VC00TZ4809ZXl02VX=P0]Yc@0<JLa02nZ<P0aZCH0
;:Xe02ZZ<`0YYc<0;:Hd02^]>00[[d00;Je502n/AP0`ZT40<J9202jQBP0dXeP0>jEN03bWFP0hYeX0
>jMD03f^C00l[Tl0>jeJ042/D`10[D<0@:le04V`;`1D/B@0E:lO05>_7@0205>]600W05>[4@1C[A@0
EJ`I056[7`1;ZbD0AjPX04FX;@1:Ybl0B:De04>Q=`17Y3/0BZXo04^XA@15WU<0@H]T045oK`13Ofd0
AWI^04I]K015Jg00AFM]04eYJP1JJVP0I7=V05JCE@1AZc`0GJ/Q06RT401[Z0T0KJP9072W2@1fY@T0
NJ4907ZM201jW@<0OId107^S0@1bY`T0H:/D0080GJ`J02L0FJhT05F]901A[al0CJlQ04ja9`1</c<0
BkDd04Nh=@13_3T0?k]B03W0G@0i/5T0=jER03BQJ`0aX740>j=/03ZZK00k[6@0A;5J04RfDP1=]3T0
B[4^05B_:01B/RL0C[De04>`B`11[UD0@j]K04R/HP1IYdT0FiE405fM@01NXDT0HJ9805jSD01MV4h0
H8A<05j6BP1LTe000P1PVTH09`1TRdL0JH5C06J4F@1KOFD0LgAR09YSH@2JGf<0T5aS07UZH01PQ5d0
LXhm09:9<`2BNCd0/V/h0;]N>P2[HST0Sf5>085VE`1kKEL0PfeL08e^GP2NJf<0ZFYL0:QRC02FHdP0
QFYG08UcH`2RLF@0WfU90;MM=02kEDT0/T]Q0:QME`2/He@0Tf]<09]ZB@2QKdh0WGUI09^3E00208VO
;@0>08fM6@2CT0h0TXL40926002CP`00SX@008f10029NP00QWT008Mg0024M`00QW/008R10024O`02
08Al000G08=i001oK`00OVd007aZ001lJ000NVL007a[001nI`00OF/0081]001oK`00Og8008Ae0020
N@00P7X007ec001nK`00MF`007=/001dK`00LW@007Eg001gO@000P1gN0009`1iN@00MWL0071b001a
K`00L6H0075S001aH@00Kf4006]M001]F@00IEL005mA001QC@00I4d006=@001SC`00IE<006QF001Z
F000J5T006EH001PD@00HE0005iA001PCP00HU0005m;001LBP00GDh0069?001RDP00He0005e:001I
A@00ET4005Q4001GAP00FDH005Y5000205Y6000R05U7001IA@00ETT005I4001E@`00EDD005E1001?
?@00BcT004Le0018<`00Ac<004/e0019>000Ac@0044_000o;`00?R/003PZ000f9`00<R<002`O000V
6@008QH0020F000N5@007A8001XC000E3@004@T000/600060P000`40004001X00000303oool000X0
oooo01@0Ihi107=lA@1_LT@0KWE807A/E01nI4h0PVTm08Ib<`1lRBX0H9`]03ZQBP0YWV/099]i02FE
N`0WQGd0:WEi02aVN00[G7h0;5n102QUQP809Ff402L08gmh01n=LP0LSG8067]k01I`QP0DKI<06X>?
01fFPP0KY7H08:YO02^[A@0g[SP0?jhb046_;P18[BD0BK0Q04Zc801=[bD0CZdZ04R/;`13[C40@Z`d
04B/<@15Zc80AZ`g046[A00kZUH0<jMR02fVH`0`Yed0=:ME03BUB`0gXTH0?ZE5046XA@10ZdD0>j`k
03b[=@0gZcH00P0jZST09`10ZSX0@jPn046Z>015[2l0Aj``04Z/>@1<[Rl0BjX^04ZV=P15YS`0@ZTg
03j]>P0i[3H0=ZXg03:[?P0]ZT40;ja002b[A`0XZ500::]E02B[F@0T[EX09:aM02BYI@0WXFL09iM[
02B>L@0RRW408HQ`026?J`0QTV/08i=[02>@KP0STG40895d022IKP0QXVD08:UL026ZE@0202:[DP0W
02JYE00WZEX0:ZQM02RVE`0WYED0::M:02VX@P0XZSd0:JTk02jX>`0`YSH0<JTg032Y>`0`ZcT0;J/d
02bX=00^ZSD0;Jlk02ja@P0[[T/0;Je702jZ@@0]XdD0;JA<036UE`0hY5/0>:UG03RYEP0iZeH0>;1?
03V_DP0k[eX0?Z]?042]>@12[bH0B[0S05>a7@1C[AL0E:`J0080E:dI02L0E:`J05>[701D[1h0DZ/Q
04f[901;ZBP0B://04V[;017[300Aj/c04J/=`16[T00B;1<046NG00mQFd0?Wa`049jL016MFl0A7=[
04=bJ@13JfP0B6aX05A_IP1KMf80EiM605N^:P1M[al0GjdG05b`5P1R/1L0H[4D06N^5@1VZAD0KJTA
076V2P1aX`<0M:H2072X1P1YZPl00P1Q[1809`1M[AT0EJXL05:]8@1@[R80Dk0P056`8P1?/bL0CK<_
04bg<P15_CX0?l1703VcC@0dX5h0<9eT03:GI@0iWEl0@JQH04B[E@16[e00C;A<04bm=01<^2<0E;@Q
04ne8`1<]C80B:m604JYD01;Y5<0C:=B05^RA01JSDP0GYQ605^PC@1OWDd0EieC05bIDP1NQ4d0G89>
05RBCP0206:H@P0W06R@@`1QTDX0FY1H059mK`1dLFd0X6E_09eOKP2EFVl0NW1X066FF01lUCT0VhDW
0:9f<@2`Ic<0Z6@j09ARC@22JUT0MGIH07MbE028JED0WF1F0:9PF02XH5@0[E]<0:5KBP2CI5H0TFIU
09ASI@2EHeD0[f170;MGE@2]CV@0YEmH0:YVB02KKD00WVe00:5bBP2JOdl0SIDk0080RYhN02L0SHh<
09220P2DPP00Sh<00961002=P`00Rh4008Qk0027M`00QG/008Qh002<O@00Rg`008Un0027N`00PGd0
081i0021MP00PFh007eX001lJ000P6P0085Z0021K@00PVX0085^0022K`00Q70007ia001nM@00NVh0
07YY001hJ@00NVP007EV001`J`00KFT006i_001cL`000P1fLP009`1gM@00MWD007Ee001dL000LF`0
071S001cHP00KV0006eM001[GP00J5P006AD001SD`00HU<006QF001YE@00JeP006UJ001XF@00J5L0
06IG001TD`00He4006=@001QC@00HDl005eA001PC@00HTh005iC001SD`00IE@0065?001OB000G4L0
05a6001LB@00GTL0061:000205m;000P05]<001MB`00FDX005U6001B@@00Dd0005A2001@?@00CS`0
04dh001:=`00BSH004Ph0017=`00B3D004Db0011;P00?bd003PX000c9@00<b@002dP000V6P008AP0
01dC000L3`00610001H?000B2@002`L000H20002000L000000`0oooo000:0?ooo`0D07EnAP1kLT00
OW4j07MY@01iGDH0PUU208QV>02<MC<0N8`/05FM=P0jXED0;J1a02JOO`0WVX00:XQl02ajN00[LWL0
9Veo02QZR@0UI9D202=ISP0W01mYP`0IOGX05hAm01MfQP0CJX`05VRD01b6S00MVX007ZE]02N/E00d
[cL0?;0/03nb;P14/340Ak<[04bc8P1=/Qd0C;4O04b_9P16[b/0A:lb04>[=@14[3D0AJ`d04:[>P10
Z4L0>JUG036WH`0]Z600;jQG03FWC@0gYDX0?:=804>SA011YTH0?ZY803^[>P0j[CD0?:/i0080@J/o
02L0@j/l04>[?P14[3T0AJXf04NZ<P17Zc/0CJ`_04fZ<019YSX0B:Q104R[>P14[ST0?k0c03n]<@0h
ZSL0=JPj03B]=`0c[3X0<JY502j/BP0[[Dd0:JmB02R^E00WZe<0::IE02RTG00VWV409I]V02FFJ00R
W6P09:5V02>QH@0VWFH09YUU02FFIP0UVV809:EH02BYD00SZU000P0U[Dh09`0Y[Dl0:jaC02ZZD`0/
ZU00:jQ@02^WB00[ZT40;:Xo02jZ?`0aZCl0<:Pk02nX?@0bZC/0<:/j02n]=`0][SP0;j/j02n`?@0^
/D<0;:a802V/A00[ZT<0;:I:02fWD00_YeL0=JQJ03B/E00e[540=k1B03R`D00h[e@0>jaL03jXC`0o
[SD0@[4P04Na801:/AT0C[4H04f^700204n]7`0W04f/9@1=Zbd0CZ`W052/8`1>[RL0CZlZ04b^:P1;
[R`0AZh`04Na=016/cd0@[E;03jaF`0kWFL0>85e03UfM`0nMW80@g9_04=hJ@0mNFL0@FaZ04=[J@1@
LVD0EWiK05RI?`1M[ad0GjlN05f]6`1J/aT0F[4I05Z_601L/A/0GjlM066`6`1V[AL0Jjd@07:Z3@1b
[0X0Jj/90080IZ/702L0Hj/;05^[501C[B00E:dZ05F/8@1@[aX0D[0N05Fb8`1F]280CK@X04;0<00j
]T00=ZYB03FTF`0hWUh0?YmI04BWD@19ZDh0CZe904nc@P1>_2l0CK/O056f7@1@/RD0CK4a04fa@P1:
ZTL0Bj1;04jKCP1NWDT0GXEB05jKC01IXU80FIiA05bND@1MWTP0G8i505b=A`1LTU000P1PU4/09`1R
Rd/0GhaB05V6GP1JKW<0MFMg09]NN02IGG@0SUM^07AfHP1/VU00Ri0c0:]n902gIRl0[6H/09AV@027
He`0Nfa[071bIP1eJUd0TEUG0:UAD`2WCe@0Z51@0;1?D02ZE580X5UK09UMGP2;EF00REYI0:MLE02a
FU/0Ze=O0:eXC`2cJT40YW8l0:Ab>P2RMT`0U8Xl08FQ800208jA3P0<09640P2?O`00SGl008an002;
P000S84008V10027Q000RWd008Qn002:O000Rgl00P2:OP006@29N`00QGP0089g0028M`00Pg<008=/
0024J`00QV/008=_0022LP00Pg8008Ec0023M@00PW@007a`001kJ`00MV80075P001bHP00NF<007IT
001dI@00KfH006aY001bL0000P1bMP002P1eL`00M7<007Eb001fL@00LV/0075X001`I@00LVL006eS
001^HP0206]O000706aK001VE@00J5@006iD001[E@00J5L006YA000206UE000B06ME001WDP00IDl0
06A?001RD@00H4d0065?001OC@00I540069G001VF@00IUD0061@001NC@00FTX005Y4001LBP00H4h0
0P1OD00205e;000N05e<001IB@00ED00050o001BA000CT<004ho001=?P00Bc`004Tg0017>@00ACX0
04Hh0018>000A3<0040b000i;000<bL0034S000[7`009a/0024G000M4@006@h001<>000A2`0030L0
00H300030@000@007000000<0?ooo`002P3oool05027GD40RF11089U?`1`Hd`0K5eF07QIC@1jKcd0
O84]06JE;P16X480=J9P02nROP0]Y8<0;In002n=N@0_Pg00;7ic02QkO00ULhT08fZ@0P0SGH/09`0P
MWX07Xab01RCO@0GQHH05gZ801MfR@0KRH<08IYh02BTK@0ZZUD0<[0l03Nb=@0g/SP0>k0l042b=@18
/BT0B[0O04b`8@19[b<0B:hZ04R^=P17ZSL0B:/c04N[<015ZcH0@jY503j[D@0fZUL0<ZY@03BZA`0i
YT@0>jM403nUA`14YDH0@jM6042YA`10Zc`0@:`g046Z?@0203nY@00W04:Z@013ZD40@jQ104:W@011
Ych0@jM204VY=P18ZST0B:U504ZYA01<Zcd0AZhi04:^<P10[2l0?JHh03JV?@0bZcl0;jdn02j[@`0Z
[4L0:Je=02V]D00X[Th09Zi:02R/C@0VZe409ZUH02JUG`0SXF@08J=Y02:TJ`0TYVH08jAV02JMIP0T
VFH099ES02BOF`0UYE<09:QA00809JaB02L09jaB02NYDP0ZZ5@0:jUB02fXDP0/ZT`0;Z]702f[A00_
ZT@0<JY103>Y@00bZCl0<JTl02j]?00Z[S`0:Jlo02Z/@`0[[dL0:Z]=02ZVBP0ZZDX0:ZQ<02bVD@0^
YED0<:MK03FWG@0fZED0<j]A03NaD@0i/U80>:mD03R[F00nZd/0@K4c046`8P12/BD0@jlO04F_7P13
[b@00P15[bT09`14[2h0AJd`04R];P19[Rh0C:lb04Z_<01:/2`0B:lZ04fa<019/3X0A;5503b_EP0l
[6D0=YU`03J3N00cNgH0>7mf041mL@0nOVT0?7aX045/J`14LF/0BW]V04^8F@1GWcL0GZlL05V_8@1G
/B00EK@M05Jb7`1G/R80Ek4T05Rb:`1I/Rh0F[0^05nb;P1V/B00JK0L06J^3@0206J/100W06NY1@1P
ZPd0G:dL05b[8`1K[A`0DK0H05b^6@1P[aX0H;0J05Fa6P1:]2<0Ak@c046_B013ZTl0AJIF04VVE`15
Ye80BJI>04V^B@1</d80Ck/^04fk8P1A^b40DK4X04nb<@1@/S/0DJm1052QA`1>UTd0G9I@06IkH@1O
UeD0FJ5C05JPB`1BXDX0F:E305^N?P1NVd80Fi=@0080FhmF02L0FHYI05Z3F`1GMVD0GUUf07IMNP2C
GGP0UEab08YJI`1hNUT0Kia008bA:P2YNB80XVh[0:1^=P2EJD80Q6aI07MaH`1gLe`0NW=K091YH02V
HE/0ZEeG0:iFC@2bDdl0/eI;0:eFAP2[EdL0Y5E?0:5DE@2WG5`0Z5]K0:mLG02^JDh0[g1<0:]jA@2U
O4D0V817092F;`25T1000P28PPD09`2:O@00QgT008Mj002:OP00R7`008Um0029O000Rg/008ej002:
O@00SW`008mo002:O000Rgh008Uo0029N@00RWP008]l0025M@00Q70008=c0024L@00QW4008Ub0026
M@00QGD008Me0025M@00P74007]X001dH000LEh007=P001iK000OFh007IY001cI@00L6/006ma0002
075d000707Id001dL@00Lg8007Ia001gK`00MFX007E]000207Q[000N07I^001dK@00M6L0071S001[
F000JUD006mE001[EP00IU<006MB001TE000Ie8006UG001YF000J5T006AF001TD@00HE00065F001P
D`00HE8006AG001VF@00IEH006EE001PCP00GTD005U8001JBP00G4h00P1OD@007`1LC`00GD`005Y<
001GBP00ED@005A2001@A000DD<0054m001>@000C44004Lo0019=@00A3D004<b0012<`00?c8003l`
000i:@00;b<002hO000W70008aX001lE000J40004@/00109000=1P002@<000@2000100007@00000<
0?ooo`002P3oool0502:ESh0QeI007MH?01]F3`0Le]207eU?01lMRh0L8d[05FG>00kWED0<J1_02jP
O`0_YGl0;j=f036LJ00`UfH0:i=^02R<N`0WOh808WF70P0TKH008@0XS6X0:9eY01^NO`0HTXP05HF6
01IoP@0JRWh08YUe02ZOKP0^Z5P0<Jdo03N`=@0k/CH0?;4i04F_=P1;[B`0CZXQ04^/8@1:[RL0B:da
04N/?`19ZcL0BZX_04bZ;016Z3<0@:Lo03jYA@0jZ4X0>Z]403^Y@00oYd00?:U2046VBP0204:WB@04
04:YBP12ZCl0AJXg04B[?`80@jU402L0@ZLn046W?`10YD@0@JE304:WAP13Y4L0AJU004F[?P19Zd<0
CZa304f]>01:[340AZ`^04BW<P0mY3P0=Z=303:XA`0_[4H0;:]702R/A`0X[Dh0:JeA02V^BP0X/4L0
:;1602Z^B00Y[e00:JaD02NZFP0WYf80::MZ02VVI`0YY6T0:YiY02RGIP0YTF@0:9]M02VQFP0YY5X0
0P0WZ5X09`0WZ5/0:ZII02^XE@0[ZE<0:jQB02^ZB`0[ZDP0;JU402nW@@0cZ480=:Q203>W@00cZSl0
;je002Z_@P0Y[TT0:ZaB02Z/D@0/Y5L0:j9F02ZUE@0XY5L0;J9P02nQHP0aYVH0=JET03NVF@0g[5D0
<k1F03JaE`0g[UP0=JiF03^^B00m[SH0?JlY03^_:P0n/BL0?k0/03^a<@0203Nb=@0W03Z^>010[CL0
AJdg04B/=`15[C`0AJlh04R^;`17/2d0B;8h04>`A00o[U40=ZUL03BQJP0cUG40<hQe03:7LP0hRWH0
>hUb03f7J`0lPVP0@7A[04AgJ`15QF@0BI=D05RS>01OZb<0Ej`Z05F^;@1D/BP0FK0W05V_;01I/2d0
EK0f05:`?@1C[d00Dk5005Rc>@1I/2/0HJhH0080J:d902L0KJd406jY1P1/Z@`0JJPA06NX401R[A00
JZdA06j^401Z[@l0IK0A05Va501F/b<0Dk0g056`?`1AZTl0DJUF04jQG@1=XEL0DZe?04fgAP1@`3L0
CkL]05Bf9`1A/RD0Dk4/05Nb<P1F/3`0E:Ln04nOB@1FXTh0EiAF05VOD01CYE80D:=;052LB`1DWd80
Ej9105>J@`1GSU<00P1HPUl09`1GPf80G7aW061YK`1XDWX0MeYi099NN02@HVl0S5iX07alE@1jVSX0
T8d`0:Ag=`2cH4L0Zee10:5EAP26I5`0MW1N07IeGP1lOe`0TWAO0:A_G`2]J580^5m40;MNB`2fFTX0
]eXn0;eF?P36DdP0_5EA0:MGG02VGEP0[fIG0:a_D`2/MED0ZWeA0:23C`23STL0S98R08V11P0208Il
0@0W08Qg0025N@00RGh008Ym0028O@00QWP008Yg002;MP00SgH008ij002=O000S7/008eg002<N000
RWT008]g002:N000S7T008Mc0026L000RG@008Ib0022M@00R7D008Ud002:M000QgD008Ih0023M@00
OVX007IR001dHP00Lf4007a[001kJ@00NVd007A/001eK@00LG000080LG<002L0MGX007Mh001hN@00
MgL007Me001gL`00Ng<007ig001kN000NGH007Ue001dKP00M6H006mM001/F`00K5X006UF001ZEP00
IU8006I>001WDP00JUD006MF001WFP00HeX006=F001TE@00HU@006=C001UEP00IeT006AM001TF@00
J5L0069@001MB@00FTP005Q<001MC@000P1MC0007@1IC000FTP005]7001GC000ET<005A5001CAP00
D4L00513001B@`00DD@004m1001:?000AcL004<a0010<000@C4003d]000g;000<RD002dN000U6@00
8AD001XB000F3`003`T000d700080`001@4001l00000303oool000X0oooo01@0OTYE07i5E@1fCDH0
LE=4075OC`1iJd@0Ng``06J?=@1=U4@0=9US02fMM`0/X840;JEn02bWL@0/ZF@0;:IO02JSJ00ZUgD0
:8Qn02EoNP80:7a`02L0;IeJ02jTG`0OY7`06If501BAP00ER7`068]o02>JLP0[XF`0;JQF036]@@0h
[ST0>;0f03f`<P16[S00Bj`X04nX8@1>Yb<0CjPZ052W=01>YCT0DjLa05NW:P1EYbH0CjL^04FV>011
Z3h0@JU4042Y@010ZT00@jHm046SA011Y4X0A:E604FVA016YT40B:Li04fW=`1:YS/00P14Z4809`15
ZCl0?jU003fWAP0oYTP0@JE804>TBP15Yd80BJa004^/@`1;[3l0CJde04n];P1>Zb/0BjDa04:O>P0k
WDD0=JY703>/A`0b[d<0;:m402b^B00^[TL0;jm102ja?`0_/Ch0<[0n03Bb@@0f/DH0<Zi:03>[D`0a
[5H0<:ML02jTH00_X6<0;YUO02^DGP0YUed09iUP02NIHP0202VMHP0W02VSH00ZY600;:EK02VVEP0X
Ye809jU902VXA00YZ400<JLn03BW?P0dZD40=jQ003>[@`0_[TL0;;1902^_B00X[e00:ZUD02VTFP0Z
WeT0::9I02^QFP0`WEl0;iiP032RH@0cYF00=JIM03FYFP0c[UT0=:mI032^EP0_[e80<k5503Rb>P0g
/S00=[@d03Bd<@0h]3@0<k@k0080<[9102L0=Jm203^^@010[T80@Ji204:YB@13[480AJhg04Na=`16
/440A:i>03ZXG00eWV00=9=[03>@L@0dRW80<Xme03B?MP0gS7T0?XUa03j3J@11Nf/0@WmX04>=H@15
WU<0EjLd05nY8P1J[BD0EZlW05Zb901M/BD0F:h[05R];01E[Rl0DZlb05:_=P1A/cT0EK<g05F^<`1K
[RX00P1P/2809`1V/QD0Kjh?072[2`1/Z0H0JZL906BY3`1V[0d0Ij`=06R^2@1X/PP0Hk0:06Nb501L
[bD0Gk8b05f_A@1DYUD0BY]Q04bLG`1;ZE40BJm704ja@01;/SD0E[<^05Ba;@1K/bL0GK8X05^a<@1G
[c/0DJ]305:Z@`1DYTH0G:A805BSD@1AWTh0Ci5>04jAC@1CVDh0DYE@05>4F002055hH`0W051lK01E
MWD0IfEl07aCO`1oFWP0SUmf08iQK@2;HFT0O7eB07:I<`2:T2L0XWXb0:9U?`2JHTP0SV=H07YhF`1c
R5L0NHQB07^<D@2>Pe@0WW=J0:EYC@2^H3h0[E/l0:9J?`2JGS/0Xehf0;=E=P2kEcd0[5]70:]WBP2b
JTX0[W5=0:MfD@2TOTl0Vh5;07nE<`27RQH0QWL20080Q74002L0RGD008]g002<N000SGT008Yk002=
O@00T7`0095m002=N@00RgX008Ul0026M`00Qg4008If0027L`00RG<008Qe0026L`00QW0008M`0028
K@00Q6l008Ac0025NP00S7P008]m0028NP00RGh008Qj0022M000Ofh007YY001fJ000M6H007QW001m
K000MFl007A/001]L@000P1_M@009`1cN000MW`007Mn001fN`00Mgd007Mh001jMP00NgL007af001k
N000NG<007I]001cJ@00Lf@006mP001]G@00K5X006]J001/FP00JEL006ME001XE@00IeX006EI001U
F`00J5h006UL001XG@00JE/006YR001WH040IV4006YO001UGP00HUH005a?001LB`00FT/005]>0002
061:000L05i:001KB@00Ed@005M6001FB000ET@005A6001@AP00DD800514001BAP00DTD004i2001;
>`00@C@003lb000l;P00>bd003XX000b9000:1d002DG000K50006100018:000:1P0020<000@10200
0000303oool000X0oooo01@0OTYE07i5E@1fCDH0LE=4075OC`1iJd@0Ng``06J?=@1=U4@0=9US02fM
M`0/X840;JEn02bWL@0/ZF@0;:IO02JSJ00ZUgD0:8Qn02EoNP80:7a`02L0;IeJ02jTG`0OY7`06If5
01BAP00ER7`068]o02>JLP0[XF`0;JQF036]@@0h[ST0>;0f03f`<P16[S00Bj`X04nX8@1>Yb<0CjPZ
052W=01>YCT0DjLa05NW:P1EYbH0CjL^04FV>011Z3h0@JU4042Y@010ZT00@jHm046SA011Y4X0A:E6
04FVA016YT40B:Li04fW=`1:YS/00P14Z4809`15ZCl0?jU003fWAP0oYTP0@JE804>TBP15Yd80BJa0
04^/@`1;[3l0CJde04n];P1>Zb/0BjDa04:O>P0kWDD0=JY703>/A`0b[d<0;:m402b^B00^[TL0;jm1
02ja?`0_/Ch0<[0n03Bb@@0f/DH0<Zi:03>[D`0a[5H0<:ML02jTH00_X6<0;YUO02^DGP0YUed09iUP
02NIHP0202VMHP0W02VSH00ZY600;:EK02VVEP0XYe809jU902VXA00YZ400<JLn03BW?P0dZD40=jQ0
03>[@`0_[TL0;;1902^_B00X[e00:ZUD02VTFP0ZWeT0::9I02^QFP0`WEl0;iiP032RH@0cYF00=JIM
03FYFP0c[UT0=:mI032^EP0_[e80<k5503Rb>P0g/S00=[@d03Bd<@0h]3@0<k@k0080<[9102L0=Jm2
03^^@010[T80@Ji204:YB@13[480AJhg04Na=`16/440A:i>03ZXG00eWV00=9=[03>@L@0dRW80<Xme
03B?MP0gS7T0?XUa03j3J@11Nf/0@WmX04>=H@15WU<0EjLd05nY8P1J[BD0EZlW05Zb901M/BD0F:h[
05R];01E[Rl0DZlb05:_=P1A/cT0EK<g05F^<`1K[RX00P1P/2809`1V/QD0Kjh?072[2`1/Z0H0JZL9
06BY3`1V[0d0Ij`=06R^2@1X/PP0Hk0:06Nb501L[bD0Gk8b05f_A@1DYUD0BY]Q04bLG`1;ZE40BJm7
04ja@01;/SD0E[<^05Ba;@1K/bL0GK8X05^a<@1G[c/0DJ]305:Z@`1DYTH0G:A805BSD@1AWTh0Ci5>
04jAC@1CVDh0DYE@05>4F002055hH`0W051lK01EMWD0IfEl07aCO`1oFWP0SUmf08iQK@2;HFT0O7eB
07:I<`2:T2L0XWXb0:9U?`2JHTP0SV=H07YhF`1cR5L0NHQB07^<D@2>Pe@0WW=J0:EYC@2^H3h0[E/l
0:9J?`2JGS/0Xehf0;=E=P2kEcd0[5]70:]WBP2bJTX0[W5=0:MfD@2TOTl0Vh5;07nE<`27RQH0QWL2
0080Q74002L0RGD008]g002<N000SGT008Yk002=O@00T7`0095m002=N@00RgX008Ul0026M`00Qg40
08If0027L`00RG<008Qe0026L`00QW0008M`0028K@00Q6l008Ac0025NP00S7P008]m0028NP00RGh0
08Qj0022M000Ofh007YY001fJ000M6H007QW001mK000MFl007A/001]L@000P1_M@009`1cN000MW`0
07Mn001fN`00Mgd007Mh001jMP00NgL007af001kN000NG<007I]001cJ@00Lf@006mP001]G@00K5X0
06]J001/FP00JEL006ME001XE@00IeX006EI001UF`00J5h006UL001XG@00JE/006YR001WH040IV40
06YO001UGP00HUH005a?001LB`00FT/005]>0002061:000L05i:001KB@00Ed@005M6001FB000ET@0
05A6001@AP00DD800514001BAP00DTD004i2001;>`00@C@003lb000l;P00>bd003XX000b9000:1d0
02DG000K50006100018:000:1P0020<000@102000000303oool000X0oooo01@0O51B07U>BP1eDcl0
Ke`h06YU?P1ZKd00J80m05R:A019SUX0=IAf02nGO00^WGl0;J=h02^YJ00Y[U/09J]B02RXFP0ZWVP0
:9E^02>AJ`809i5P02L0:Z=B02^XFP0RYgL06j9l01BJMP0FTgH069If02>OK`0ZX6H0<:Q@03J]@@0k
/3P0>jlh04F]<019Zbd0DJPY04nV8`1?YBL0DZH`05FU<01EYC40EZH]05ZV:@1IYRH0C:L[04NX=@13
ZSh0@:U203jY@P0oZT@0A:=904FHDP14UeP0A9e>04JSA017Ycd0B:Lh04^V>@1;Z4000P16Z4@09`11
Z4<0?ZI803^VC@0nYDT0@:E604:VB019ZC`0CJhm04b]@01=[S/0C:dg04jY<@1=YC00BJ<e04BP?`0n
X440>ZQ103:[@P0a[400;j`o02j/@00`Zd00<Zho032_?@0_[cT0<Zhj03B_?`0h[d40=Jm603>^CP0d
[ED0<jYK02nUH`0]WVD0:i=V02J<I@0VQfT098U]02>4L00202><L@0W02JEL@0VWVd09Z5V02JVGP0V
ZEL09:Q;02NZ@@0YZCd0;jLk03:Z>`0dZD00=:Q203:[A`0][dd0;jm802j_AP0][4P0:jI?02fQEP0]
WeL0:j1G02bPF`0`VUd0;iaK02bRG@0/YEd0<jEL036YF`0`[EX0;jiK02n`E00/[e40<k9803Fb@`0d
/Sd0<K@m03:d=`0f]3D0=K<k0080=;=102L0=Zm403^^A@10[TX0@J]=046WDP11ZT`0@:e704:/AP0n
[T`0?JiE03^[H00fYF80<imS03>LJ@0aUFl0<99b03>AM`0fSGX0?HYb03n8J`0oP6`0?XEU03jDGP13
Ye40EJT`062Y7P1K[B40FjlS05Ra9@1I[b@0Ek4Y05Fa:@1F[b/0DZl^05:`;`1?`3D0Cl0h05;0?01C
/cX00P1E]3T09`1N/Rh0I;4O06R_501Z[0T0KJL606VX2@1YZ0P0KJ/806j[1@1b[0D0LJd606n]2`1X
[Q@0IK4O05n]=01JYd/0CYYR04bII@1?XUH0Dj=@05FZ@P1F/C`0Fk8d05fb<`1R/b<0HK4N05jd9`1J
/C@0E;0o05J_?01F[SP0F:Q205FOD01DV540DXaD05F<DP1ETeH0DI=E04n0FP0204ecH`0W051eKP1D
M7T0J69n08eAP026Eg`0SUYc08YML`28Gg80N7YH07:@<@2KQQd0X7@U09AN>@28He<0NgEL07J8D`1a
UdX0K91:07F>D022PEP0UFQU09aND`2TCch0YDdl09I<@02@HDd0WfM:0:EH:P2kEBX0/ELm0;5Q?P2e
JD@0/G980:UiA`2GOdD0U89408FF7@24PP`0R7P10080RGL000@0RWP008el002;N`00SW/00P2AOP00
1@2@P000S80008io002;N@00QgP00080R7<001X0RW@008Uc0029L`00Qg<008Ic0029M000RgH008]b
0025L000QG<008]f002<N000S7`008Yn0027N`00R7X008Ic0021K`00OFd007MY001cI`00MV`007U[
001eJ`00MVl007=d0080L7H002L0KgH0075k001eO`00Mh4007Qo001jO`00O7L007Uc001jMP00NGX0
07Yd001gL000MW4007Q/001cIP00KVD006iR001_IP00LVH0079T001^H000K64006YS001[GP00J5h0
06YP001[H@00KF4006aX001XJ`40IVd206IZ0@1UJ000JF@006EP001RF@00GeD005m@001ND`000P1P
D@00701LCP00FTX005M5001FA@00FDH005E8001FA@00E48005E4001EA@00E4D00553001=@P00C3`0
04Dd0010<000>bl003XY000g9`00<24002PK000N4`006@h0014<000<1`001`<000@20002000P0000
00`0oooo000:0?ooo`0D089EB@1nEdL0KUi006UY?@1OJdX0EfmD05]iCP1?PED0AhAT03N:M00cT7L0
<IQb02jPI`0VZED09jm;02V_@@0^YdX0:J1N02FLI`0NW68201nOEP0W026VCP0UYeT09:Q`01nWK00L
XfX06Ie^01fOM@0SXFX0:Z5Q02nXC`0j[400?:`o04:Z>P18Z300CZLZ05:U:@1=XbT0BJ</05BR<01E
Xbl0E:@/05BT:P1HYBL0EjDV05:V:P19ZC<0AZDj04>X?010ZC`0@jU104VSA`1@W540C9eC04^SA`18
YcD0BJP]04^W;P1;Z3@0AjU00080AJQ902L0@jI<042TC@11Y4l0A:A904BWA@14Zd80Cj/k04j]>`1=
/3d0CZlk04f_?P1<ZSl0BjTi04^T>017WcX0@Ii003VU@00eZD00=:`o03B/?00dZSh0=ZXi03F]>P0b
[C`0<J`j036/>`0c[Sh0=Ja403FZB`0dZTl0<ZaH03:/G`0`YVX0;I]_02^<KP0XPfl0:X1]02QoL@0V
NG@00P0TPg@09`0TTG809Iee02FRK`0TYFH08jUL02>ZD00UZD@09ZQ002bX?00]Zc/0;Z/o03:Z@`0`
[DX0;k1?032`B@0_[T<0<:Y702nVCP0`XED0<:1E02fMF@0^VUd0<YEL02jGFP0YWUX0;:EK02fVGP0_
Z5h0;J]M02f^F`0[/5L0;K1D036bD00d/TT0=;I503JcA@0f/cl0=[<l03Nb?00203J`@`0W03F^AP0h
[TX0?ZiA03n/E`0oYeP0@:ME03jWD`0mYe@0?:YE03^_GP0g[600<j]P036YG@0_Xf<0;iaY032HL@0b
U7H0<hel03N:NP0lQg<0?X1_03b8H`0nVe/0Aj]905RZ:`1RZAh0H:dT066^8P1J[bD0G;0T05Rb:@1E
/R/0D;L[04nb;`1=/C00CkTa05:j=`1B/cX0E;=00080C[9:02L0Ek5205^^=@1R[b@0IJhD06Z/2@1]
Z`L0KZL3076W0`1bYP80MjP107RZ0@1hZPH0Mj`9076_5@1W[BD0H:Tj05JUE01@X680E:9H05FPD@1G
ZT/0Ek52062`?01P`3P0IL0R062c6`1P/b40GK<a05Fa>`1E/3D0EJlh05JRA01FTU<0Di1E04n?F@1F
T5H0EYID056GD@1@S5/00P1=OV<09`1>OV`0DGEe05eYN`1jEh00PU=k08mAM@22FG80MUii079iEP1h
SS00ShD`09af?P2JJ4l0OgUF07B;EP1dUDP0KYU106Z@BP1]SUP0NH9L08e[I`2KI5<0[e=80;==@P2^
CT00VV1809IPAP2WHC<0^EXj0;IAB@2aGTh0^6Q?0;1bB@2RN4d0She108ZA>025SQ<0QH0408Ei0002
08Mi000W08Yj002:O`00SW`0091n002AP000Rh8008io002?P@00TGd008mj002=N@00RGH008]f002:
M000RgP008Ek0027MP00RGL008Yh002@P@00RW/008Ae0022L000P6`008E`0027M000QWD0089b001n
L000OFd007Q/001iK000MVT007E[001fK@00M6`0079[001dK000Lg<00080KWD002L0KGP006eo001c
P000Mgl007Un001iNP00MWD007M`001hLP00NGL007Ye001jM000O74007U`001gK`00M6X0079V001b
J`00MFd007MY001cH`00KF4006UR001UG`00J5d006YQ001ZI000K6T006i`0@1WMPH0HgD8065f2@1U
M@H0K70206]]0@1[IP00IUl0069G001QF@000P1QE@006`1MDP00FTl005Q=001IBP00FD/005]8001I
A`00E4L005A4001BAP00DdH00555001=@@00Bd0004Df0010<000>R`003XW000c:000;R8002HJ000O
4@0050`000d900080`000`800040000Q000000`0oooo000:0?ooo`0D07iMD@1eHTP0JfU506=`B01O
Kdl0H6iA05eeC01CNE`0A7UZ03YoLP0fR7D0<9AV02VRE@0SZTD08jlk02^/=@0dZ3l0;J9G02>QH@0N
Y5`201fVE@0W01bZD00NZ5X08jE]022TI`0MYFT08Z1/02:RJP0VY5d0;ZE>03NW?`0kZCP0@:Hk04JX
=P1<ZB`0DjPZ05>T;01>XRX0Cj8/05:S;`1EYRd0DjH]05>T;`1GYBd0Ej<Z05FV:`1<YS80A:Lk03j[
?00nZCX0AJPl04jVA`1?XTL0C:E604FZ?010Zc80?jX_04BX=014ZCP0@Z]30080@:];02L0?jQ@03nW
D014Xe00AZM704JZ?`18[C/0Cj/j05:_>P1?/c`0CK8l04Va?`16[DH0AZi404VW>P1:WSP0Ailk04>U
@00lZCl0>Z/k03F/=`0gZSX0=Z/j03B]>`0c[C/0<Z`k03:^>`0dZch0=jY203NYA00dZdP0=J];03>/
DP0bZed0<ZAR02jIH@0]TF40;I=O02fDH`0ZTFL00P0XUFL04`0TW6D09Z5V02BTI@0SYV009JIG02FX
C`0VZTL0::M202ZZ>`0/[CT0<:/j03:[?@0b[Sh0<[54036`A00`[D@0<Z]9036UD00bWEL00P0bWUT0
4P0`VU/0<YEJ02nEFP0[VET0:IiK02jQGP0`Yeh0;JUN02f/G00_/5X0<JiG036_E@0b[dl0<jm?03Jb
B`0i/dP0>;A703RdA@80=K9802L0=;5603Z`BP0o[eD0?jUL03^SH00kX5h0?:9N03RTG`0eYf80<JaQ
032[I00c[F<0<JYS032TH`0bW6`0<iM`03FDM@0dT7X0=HYh03Z8M`0kQ780>hYX03^OEP12[D80Gj`X
06BZ7@1Q[1d0HJdL05b_7`1K/R80F;@U05Jd:01C/RT0D;8Z04^h:`1=^2d0BkL`04ja=P1</d<00P1;
/EH09`1D[e@0F:i@05n^>@1S/1h0J[0D06j/2`1^Y`@0L:@107VP001lXP00OJ<107fT0P1gY@H0N:P=
06n^701S[RX0Fja;05BXF`1GXeL0FIeK05NWD@1E/4/0GK1405Za@P1N/R`0GK4M05bb8P1K/bd0F[<l
05N_?01BZd40Die>05>6EP1@Q5l0CHMU052=H@1<Te`0C9EN04^?J00204Z6K`0W04]lK@1=JW<0FFMk
06mGP`1mDWd0SdY_085GKP1XGGT0JgME0820=@2RMDP0YFmD0:1YH`1mQF@0JH]Q06Z>F`1^QUX0JgeN
06MhJ01fLVX0SFAZ0:EOE02nES/0be4k0=1B>02eCd40ZE540:]Q@P2bHDT0]eIE0;9QF02dK5<0/7Q;
0:AnC026VSd0O9/U08>;2`28PP40RGl00080SG`002L0Sgd008ej002<NP00TGl009:1002>OP00S7`0
08il002<O@00RW/008ah0029N@00QgH008]i002;MP00RWH008Qe0026M000R7/008b00028O@00PWP0
081c001mJ000PV`008Q`0024L000Of`0081^001nKP40NVh207U`0`1gM`<0MWP107Ul0@1kO040MW<0
07I^001bK@000P1bM0009`1aO040LX0107R10@1kQ000NX4007Ql001dN@00MW<007I]001fL@00Ng@0
07Uc001mMP00N7@007I_001dJP00LV`007E]001eK000M6T0079X001^H@00Jel006IP001ZH000J6L0
06iW001_L@00KGP406N13@1PP`l0G8<D05en401PN`P0J7L306I^0@1XI@00HV40069L0002069J000J
05mD001OD@00GTl005]<001JBP00FTP005M7001BA000DTD004m4001>A000Cd4004a20018?000@S@0
040_000k:P00=2@002hR000/7P009AX001P@000B2`0030P000L40003000R000000`0oooo000:0?oo
o`0D07=XF@1]IUh0JfES06YXH`1XJEh0K6EF069^E@1IL640Ag9`041eM00lP7L0<9=Y02VRD`0RZd<0
:;0i02j_=P0cZch0;ZEB02VSF@0TXeX201jTFP0W01ZZF@0MZf007:E^01^UJ`0MYFd08j=/02NYH@0/
ZT`0<JU003NZ=@0mYc80@JHe04FX<P1=Z340CZLb052S<P1?X300Dihc05NQ<`1HYS40F:L_05JS<P1G
XCD0Dj4d04jU=P16YcT0?ZQ003ZW?@0nZSP0AjPm04fW@`1:YD<0AJQ1046/>`0l[3D0>jPc03fV?@10
Yd00@:]50080?J]801/0?jY;04:YA@17YdH0BJTo04b/=P1=[S80Cj/c052`=@1=/cT0C[8m04Z`?`17
[480BJa004VV?P19Y3`0B:@i04NX>@13ZcX0?Zdg03V]=P0e[3X0=Zdk03J^@00cZd@0<j]003B[@00e
ZSl00P0iZD002P0gYd<0=jQ603J[C@0cZeD0<ZUM02nSH@0]WUl0;Z9M02bSHP0/XV@202^SGP0W02bR
GP0YXF00:J=Q02RTF`0WYUD0::Q@02RYC@0YZDT0:je002b_>@0_[c/0<Jdi036`>P0c/ch0<[52036]
B00aZU00<Z=F032JF`0`WEh0;YeM02nJH00^Ted0;XmM02b@F`0[Ue`0<9eN02nPGP0^Y5h0;jYK02j[
FP0^ZET0<:aG03:/D@0c[500=:e?03F]C`0g/4d0=k970080=KA602L0=kA303ZdA00m]4l0>k1H03R[
G@0gZUd0=jUN03JYG00cZEP0<:iG02n_FP0b[F80<:MP036SHP0bWf<0=YaY03RIL@0gUW@0>8mf03V9
M@0fQGD0=8eU03bOBP1:[C@0HJ`P06NY701W[a`0JZlM06N_7`1V/240H;DR05^h9P1G]B80EkLS05>b
901B^2L0CkT[04Za=P1;/d@00P15/UP09`1?/ET0FJiG05b_@`1O/RX0I[@K06Z`4P1/Z`P0MZL207VO
0020WP00Oid0086M0P1jW0D0NJ8806b/4P1Z/240Gjli05Z]BP1IYTl0FJ=J05RXD`1F[dh0FK5705Ra
@01L]B/0F[@O05Nd7`1J/C00E[0k05F^?`1=YDd0DYIB04b1G01<P6H0BX9^04^=I`17Veh0Bj1L04bK
I00204^CK`0W04b6K`1=L7P0G6Ii07=HO`21E7L0SDib089GK`1XGgH0JgIE08J2>@2LMT00UG=B08]a
H@1nOe`0LgiN07>6GP1eQUP0LXAN06YnJ@1jM700UF5a0:1TF`2bEcD0_5X`0<IJ;`2kFc40/EXh0:]Y
A02/KD/0[6E;0:iWB`2eL4L0Zh5509f2BP23Wbh0PYDE08B61P29O@00Sgl00080SX@002L0THH008f0
002?O@00T7d009B2002@P000TGl008mm002=O`00RGP008Mj0027N000Q7H008Ef0026LP00QW00085^
0021K000PG@008Aj0027O@00QgX008Ee0023K@00Q6X008M^0024L`00Q6l108=j0P1mNPH0MH8:07V8
3P1iS@l0NHh:07b?2@1hSPP0MhL307In0`1gM`400P1cN@009`1]O@80KX@507:40`1fQ000MX<007An
001fM`00MW4007M/001gK@00N74007eh001lM000MW4007I^001dJP00M6d007A_001eK@00M6X007=Z
001bIP00L6L006aX001ZJP00KFX006e_001]N040JGl;06>;601KTQX0Ei4L05^>5`1MRPl0Ih8<06Ul
1P1XK`<0IfT206IV0@0206IQ000I06AL001SEP00H50005]=001MB`00EdP005I4001@@@00DD<004e1
001?@@00C40004Xm0017>P00A3@003/_000h9`00=24002/M000W600081<001P=000@1`002@<000<1
000S000000`0oooo000:0?ooo`0D06YSP01bFHL0KE=o075FL`1^Ff@0M5mE06QXE@1KL600BW=_045e
N00hPgP0<IMY02ZXD`0V[dL0:[4n02j^?@0b[4H0<:U=02jUDP0ZYE@202>WF`0W01b/G00FZUl06:EZ
01^TJ`0TY6`0:ZAV032YD00fZcT0?:`_03n[:`10Yb`0B:@^04jT;@1AZ2d0DZD/05NV<01KY2/0G:@/
062U:`1SY2T0HZ<[05bS<01HXc<0Cj<l04bS?@14YCh0>jLl03ZX>014YS80BjHg04ZV>`19YSX0AZPf
04B[<`0kZSL0>ZLk03jVAP13Yd@0@:Y40080@j]402L0@:a104>Z?P18ZT00Bj`h04^]<@1;[bd0BJh]
04R_<`1:ZSX0B:]304F[A014Zd00B:M004ZV?`17YS`0AjTh04>Y=@13ZS<0?J`c03N]<@0g[CL0>J`l
03RZ@`0dZ4D0=:U403F[A@0dZTL0>JM403ZV@@0jXd40>:=403BVB`0`Z5H0;jQO02bVIP0]XfH0;JIX
02jUKP0]YfX00P0_YF409`0aXe`0<j9K032UGP0^YE`0;:EK02jUEP0/Ye@0;JY=03:[@P0bZcd0<J`k
03B/>`0c[S/0<[11032^BP0`ZE80<ZQG02nNG`0`UF00<9UP02nMGP0bUf40<XaQ02n7G`0^QU`0;XiL
02nDH@0_VF40;IiL03>RGP0bXEh0;iaN036PF@0bXeL0<JMF032VF@0_Y5X0<ZMD03F`C00203NcB@0W
03Je@P0j]T80>kA:03VdE@0b/Ed0<;1N03>]G`0c[Ed0<:YK032/EP0`[5P0<J]R036XH@0aYUh0=:5P
03FPI`0gWVX0>Y]^03VAK`0eRg80<HUa03>CFP0oXch0DjhS06B[6@1W[1H0J;0H06Na601Y/1/0Ik0L
066f6P1P]Ah0G;XO05fm7@1E_Al0E;PO052f9P1<]b/0A;8l0080@jm;02L0BJmE056]FP1N[TL0H[<j
06>b;`1Y/1d0LJ`?07VX2@20X@00P9d1082K0`1nV`80P9d307bW201b[Ph0JK0L05na;01H[c`0FJY=
05BVH@1CZ5P0D:aI05>^B01A/S/0E[HY05Bc8@1D]240Ek4]05>a?P1?ZT/0CI]I04^=FP18P5/0BGeS
04YmJP1<S680AYmE04RUE@1<WV000P1;U6d09`1:Rg@0C7An061SNP1iDgT0R5=j08mGN`1oFGD0He]f
06]`D`27PBX0U6/j08A[F@2>IVT0PVaS07iVH01kMU`0MhUF07:=G01_QV<0PWEa0:USM@2XH6<0ZeTf
0;AN:P2lHB@0_f0O0;]S902WIcd0XVE:0:5Z?02TJSL0Zg4e09n3>02@RD80R9lM08NA2027Q@80QWh0
08ik000208^0000W08j7002>P000Rg@008eh002AN@00T7l008j1002>O`00SWd008ah0027N000QgL0
08Qe0025N000QG4008E]0023K@00PW80089h0021N@00Qgh008an002:NP00RgD008Ud002<N@00R7l3
08F21@1oS0P0N9@<07RI3P1hVQ<0MI/E07JL4@1fV@`0LIH:07FE1@1eU@@0MH`30080LHX502L0K8D6
06V21P1_Q@<0Lh0107>0001eO000MgP007Yd001hL000Mfl007Qb001jM`00NGL007Qe001eL@00MW80
07Ec001gL@00Mg8007Ea001^L000KG0106e^0@1YK`40JG8006Uc001ZMP00IGd305f:5P1JUbH0Ei/^
05VO;01HWBL0F9PR05^D601SRA80Gh4<061f201RKPD00P1RI@406@1UH000HET005m?001IB@00ETD0
0555001A@@00D44004e0001;?@00Bch004Tl0017>@00A3H0040`000i:@00=2@002lN000V60007a<0
01T@000D30003PP000T300040@000P01000Q000000`0oooo000:0?ooo`0D06U;JP1S@FX0IT1U06M2
GP1]BE/0Oe]A06aZC@1MLeX0CGE_04IfO`0gQgX0<9iW02^ZE00W/4X0:Zm402n/A@0`[TT0=:Y8036Y
A@0/YT/202>WDP0W01b/F00JZ6406Z1Y022PJ00UXVP0;ZEN03FXAP0kZS@0?jP]042X:017Yb@0CZ@V
05RU901JYR80F:LV05ZU9P1LYBP0FjHY05VW:P1OYRX0HZ<X05^S9`1DYBL0CZP]04^Y<@17Yb`0@JH^
03jX<P15YcD0AJDm04NT?P14YSP0@jTc04>[<@0nZST0?:Q003ZUB00nZ4L0?jQ30080@Z]102L0AjY0
04J[?`19[3`0B:`e04F/<P14[C80AJdc04>/=`13ZD80@JQ>046VB`13Z4<0BJXo04bY?`18Z3/0A:Pk
04>X>012Z3P0@:Xh03^[=@0kZCX0?ZQ003nU@@0nY4<0>:A403NYBP0gZdh0>ZM803ZTA00hW4@0>Ii6
03FSC00bYe80<:UE02nWD`0]YED0;jEH032VG@0`YE/00P0bXe809`0gX4d0?:1<03RWCP0eZ580=:MF
03BYDP0fZDd0=J]803J[@00e[400<ja003B^@P0c[T@0<:i=036XDP0dZ5X0<jMP036OIP0aUf@0<YaP
03:NG`0dUf00=H]Q03>3H00cPeh0<XiM03>DH@0aUV@0<YQN03>IGP0cV5d0;IIP036JG`0_X5X0<:AL
02nQFP0]WUX0<ZEG036/C`0203FeBP0W03Bd@`0g/d40=[=703FfC`0`]ET0<K9M032aG@0a[F00<:YN
03>YG@0bZEh0<jYQ03FUH00gY5`0>Z9L03NQI00iX6X0>i]a03^>LP0dS700<8Q`03RDE@1;Ybl0H:`E
06F/4`1X[aH0IK<G06N`601U/1`0I;4K05fc6@1M/a/0Hk@M066c701I_A`0EKPM05>f8P1>]bH0B[4_
0080AJm002L0BJi?04Z[GP1B[4l0FK9805ba?`1R/b`0K:hI07bY3022W@00P9/307fK1`1iV`@0Nid2
07NT1P1^[0P0IjdH05Z^:P1F[SH0DZa<052WI`1>YUl0Cj1R04f_C@1B/SX0EkD_05>d901B]R80D[0^
04b`@@1=Y5D0BHmT04J3H`16NFD0AgaW04N3JP14Sf@0AIeG04VLF01>Tf<00P1=RW809`1<Q7/0CW5o
05iQN`1mEGL0QEAg08UJO01mGgL0Hf5c06YdDP23R3<0RGI208IdD`29MF00R7=K08m[E`20NUD0NXQ@
07R4EP1cNUl0Pg5R0:QPH02^Fe@0[UI00;1M>P2dHBh0^FDR0;YT8@2dHS/0/VE=0:I`?`2UMST0YgTn
09Z7@@28VCh0S:4H08^?0@2;Q000R7d008Mh000208]j000W08il0028M`00QG8008Uc002<M000S7H0
08aj002=M`00S7P008id002:M@00RgT008Ym002<N@00SWL008ag0027M@00PWP008Ak0025N@00RGh0
08an002:O000RG/008Il0@29QP@0Q8X=082=3`1mV@l0NidB07JR5@1iYQL0M:HJ07BR5`1aWa40M9h:
07:J0@1eU`40KiX50080Jih;02L0JI8<06B61`1WQ0D0I8H506^20@1aPP00MX@007Ym001lNP00NGL0
07Yg001fN000NWd007Ui001gM@00MWH007Ih001fN`00MgT107Ag0@1_M@40KW@206ah101`N0<0Kgd3
06n00`1/QPH0HI0>05fI7@1IXB`0FJ<_05bU<01NY2/0G:8[05ZM901RUAP0I8dC06:2401TN@`00P1T
KPH0701SJP80HUh0061C001JB000EDD004m2001<@000CSl004`m001;>P00B3/004Lk0017>P00@c@0
03l^000e9P00;b0002LJ000R5@006`h001L<000C2P004@L000X400040`000`4000410001000P0000
00`0oooo000:0?ooo`0D06l^IP1S:E/0J2YH07<^DP25>UL0S5E<06mWB01MKe`0DW1b04]`P00lPg/0
<IiV02j[D00/[d<0;j`n03B/=`0i[S@0=Jhb03B]<P0^[CL202V/@P0W02>^C`0PYed089mW02BNJP0Z
WfP0<JEF03fZ@012ZS80AJT[04VX8`1BYAh0G:8Q05jT7`1PYQ`0GjDN066V8@1QY240FjLU05^X9@1R
YBL0I:DS05fT801FYR00DjLN056X801CZB<0BjPW04ZX<P18YSL0BZ5304RS@@15YcL0A:/`04B/;P10
ZSH0?jLo03jVB`11Z4P0@:Y10080AZPo02L0C:/l04f]>@1;ZcL0C:/_04JY;017Zc80AZ`l04F]@`13
Zdh0@:QF046WCP14Yd00BJ/j04^X?015YSX0@jHm042V@00oYd40@:E003fV?P0nYcl0@:A3046R@P10
YD00>jQ203V[A@0f[4T0>JQ803ZTA`0lX4D0>:1:03BTDP0bYU<0<JM<032VB00aXdL0<jQ803FYC@0c
ZDX00P0fYTD09`0iYT<0?:=303bXA`0jZTd0=ZYB03JZD00iZdP0?:]603V]@00h[d00=Jm303F_B@0a
Ze80;ZQI02fTH@0cYFD0=:I/032RK00cVfD0<j1Q03FQH@0eVeh0=8iL03J8GP0fS5h0=YAP03JGHP0e
UVL0<iAQ03>JG@0bWUl0;j5O036UG@0_ZU/0;j]I02jYE`0]YE@0;ZY@036`B@0203Jd@`0W03Fe@00c
]D00;kE103:dA`0b]580;k1I036_G00c[F00<jaN036[G@0dZE`0=:ML03JRF@0iX5L0>ieF03fNG`0j
W6H0?9E_03b9KP0gRfT0=i1[042LD@1IZBT0JZlB06Rb4`1X/aP0IK<J06Nc6`1W/Ah0HK8O05bb701P
]1`0I[@O06Je801M`1d0EKPP04ni801A]R00BkHW0080BK<a02L0Ak9104N]D`1:[e@0Cje?05>_BP1L
/T80IK0_07>]601jX@L0Oid607jK101oV@80P9X007jN0`1hYPP0KJdB06>]8@1L[bl0Djm804V`F@17
YEl0BIQX04fZDP1D`3`0E[H^05:e9@1>]B40C[4d04V`C@19VE`0Bh1[051fJ@19KVX0AW][042:K@15
TVP0AI9T04B;I@1CPVd00P1BNGX09`1?NH00CfJ005aQO@1aFWT0O5Yh085JN01aI7@0GW5^07EoCP2C
Pc@0T6Q>08ERGP2:IfT0RfaU08aZH`20LV00NW9I07U]FP1cHUl0P69H0:QNB@2kE3l0b4dh0;Y<@P2a
C400/U/_0;QR8P2nGST0_Ui<0;1b@@2ROd40WX9:08^BCP1mYSH0S9TG08f40@2:OP00RWT008Mh0002
08Mi000W08Uj0029M000R78008]b0029LP00S7<008]a002?M000S7P0091g002@NP00SG/008f0002?
O`00U7l009=o002<P000QgP008Mg0025M@00RgT108em0P27OP<0RX8608>82`24T@d0PILA07jI4`1j
VAH0Nj0I07NX801fZb40N:lM07N_6P1e[A/0LjHE07FT4`1dZ1<0KK0C0080I[<C02L0IZL?062K401P
TQ80IY4A06^A4@1`S`d0M98;07b?1P1oR040OX@007en001kO@00N7/007Eh001dN@00M7/007Ai001c
N`80LW`4075h101_N`<0KW`506j1201`QPT0JXP;06F=2P1PV1@0F:4P05JX;P1JY340GJ4e05nI>`1P
V3d0GITk05nN=01QWR/0I9H/06>>901RQQL00P1TNa40701SKPX0HV8105mJ001HCP00DTT00551001;
?P00BC`004Pg0016>@00B3/004Hk0013>@00@3<003XZ000d8@00:Q`002TJ000S4`006A4001P=000C
3@0040X000`9000810001@8000@100020@0P000000`0oooo000:0?ooo`0D07TWH@1]:EH0LbaB07d`
DP1k=500NEDl06QRD@1JJFL0EFUh04eZQ00nOgd0=I]Y036[D`0^[T80=:dh03^];011[BL0?:XT03>/
9@0_[2`202^]@00W02V[C@0WZ5l09IiX02NJJ`0/WFD0>ZEF04>Y@@18ZC@0CJT[056W7`1JY1L0Hj<J
06BU7@1XYQP0IJ@J06BT701PYAd0GZ@O062S8P1SXah0JJ<O06>S6@1IXQL0DZ@F05:V6`1?YbH0CZP^
04jX>`1:YTD0Aj9>04JSBP13YSl0@:Xe046[<@13ZCD0@ZI003nVD@11Z4/0AJM00080C:=002L0CjHl
05:X=01AYc40D:LZ04VY:P15Z3<0AjY004F[B`13ZE@0@jUG04BVB`18Ycl0BjTg04RU?013YC`0@jI0
03jVB00nXe00@J1;042RAP0oWT@0A9a804:PA00nYT<0>ZTo03R[@@0iZTP0>jA:03fRB00lWTT0>Ym=
03JOD`0gXE<0=J5603JQ?`0fY3d0=ZM003RY@@0eZ4000P0eZCh09`0fYSl0=jI103VZB00dZU40=JUG
03JZD00gZdL0>:a403Z^@P0g[T80=Zm;03F]E@0aZV40;JAV02bFKP0aVg40<j1d03BQL00bWFL0=J5T
03FSHP0eWV00=I=N03B=G`0gTUh0=IUR03JHI@0dTfT0<hmS036IGP0`XUh0<ZQN02nZG@0^Ze`0;jaI
02f]E00/ZE00;Zi>032aAP0203>f@P0W03:gA00a]D40;k8m03:a@00b/DX0<JiD03>]G`0`[f<0;JaO
036[G@0fYe/0=J9K03FNE`0hW5D0?9UE03ZIGP0hUFD0>Xe[03b6IP0iS6@0>9AV04JRC`1T[2@0KJlA
06Jc4P1T/aT0H[4N066c801I]BD0FK@W05Re8@1O/b00JK8R06Ba9`1L]B<0D;TS04Nj8018_al0BL0S
0080B/0W02L0BkDe04JaC015ZeD0AIiK04ZWG`1=/Ed0FKA@06^_901`Z0`0NZ@807jN0P21U`00PYP0
08>K0@1oW0<0N:<906f[5@1P/B<0D[0k04BbC@15Y5T0AHa_04ZUEP1?`400Dl0a052e:@1@]2T0C;4k
04F_E01<U600CGE]04i_K01;Ifh0BWM^046;LP15SW<0@h=d04IiM`1@M7X00P1?K8D09`1<J8@0C5Z7
05UJQ01YG7l0LEUl07IDN`1XIGL0F7a/06n8E02:R4<0Q7AD08AbGP26Nf00PWeO08]eG`26M5`0Og1M
07eZH01lHF80RF1K0:5M@P2aFSH0`E8`0;Q<@@2ZB500Y5M10;=P=P2lFT40_U]=0;=_A@2VNdH0VX9B
08FEBP1hYbP0R8l?08Em0@2;MP00R7<008]h000208Uk000W08im002<N@00RWX008eg002=N000SGD0
095d002@MP00Tg@008mf002>NP00SW/008mn002DOP00UH0009:3002<P000R7h008Ek0028MP00QgT4
08:03022RA40P9<D07jI501mWQ<0OIlC07NP5P1fYAX0Lj/R07:b:P1^]RP0K[PR076g901^/Bl0KjP[
06jc:`1/^B`0Gk`Y0080F;XK02L0E[@F05R]701HXal0GYhT05fI8@1LUb40HY/I06RJ3P1iTPD0O8P0
07n0001lO@00MGP0071f001cMP00LgT007Ak001aOP<0Kgh807232@1`R@/0Khl>06^C401XUA00I9PB
05nP501GYad0DJh^05R]=P1LXD00GYE805n8CP1KRTl0FY9>05NIBP1HXD@0G9U006:D;`1SSQ`00P1S
Pa80701TMPT0HfT105mQ001IE000DTT004e0001:?@00B3/004Hi0013>000A3H004<h0012<`00?2`0
03HV000`8@00:A`002DI000P5`006a<001/A000E3P0050`000l7000;10001`<000@100020@0P0000
00`0oooo000:0?ooo`0D08PgA@27>4D0RSQ7094hC@27=4d0NU@a06]KD`1OH6/0FEmi04mUQP0nNH00
>YMZ03>WD`0_ZT80=:/h03nX<00nYBd0>J<Z03BW:P0/Yc<202NXB@0W02JYE00XZE`0;:AN02jSF00c
XU00@:Q604bX=`1CZ2X0DJLS05:W6P1KYaL0I:LI06bW7P1bY1`0Kj@N06RQ7`1QWb00I9dN06ZN601Y
XAH0JZ4I06RQ5`1JXaL0CjDH04nX7`1@Z2X0CZH`04jX=@1;YcP0BJ@o04NS>@14YcD0@:Tb046Y<@16
Z3<0BZHe04JX@017ZCd0CjTg0080DZLh02L0DjPf05>X<01>Z2d0CjTX04^W;@18YCP0A:U704>[C@13
ZU<0AJU@04RWA`1:YSl0BJDl04ZT?`19YD80BJM404FVBP13Y580AJ=@04FRA`10XDX0@im>04BTCP10
YTh0@:Y6046ZAP12YT`0@:1<04>PB`13W4X0?YQ;03fJDP0kW540?Ye803bN@00kXC/0?JHi03bW?00l
Ycd00P0jZCd09`0gZD00=jQ103JYB@0d[4d0=JY?03J[BP0gZdL0=j]903R^AP0g[DP0=J]A03JVE`0c
YEh0<J1V036GJP0eVfP0=imV03RPH`0hWel0>j5N03ZUG`0jY5`0=iaI03BHG00dUed0<i]P03>LI00c
VFD0=IAR03>NG`0aYE`0<ZYK03:]F00a[UL0<:aD032_D00_[U40<[5=03FeBP0203Nh@@0V03Jh?`0d
/cX0=;4o03>`@00d[DL0=JaB03:/G`0`[FD0;JaR03>XGP0fY5P0>9mB03jKD@0oVE00?9IC03fAG00l
Rf40?8MV04:3I011Rf<0@IYQ052YA`1Y[1l0KJdC06Na501S/QX0Hk0M062`8@1M/2@0H;4T066c8P1V
/R00Ik@O06:b801K/Ad0E[DP04ni7P1@^B43052n900W056i:P1=/S/0B:m604J]DP1?[EH0CK5I05Rd
C`1U/Rd0JK0K07JX3`1mW@40PYL008BD0024V000PiP007nL101jX@T0L:`E05^_;@19/3T0Aj=A04R;
KP1<Y5X0CkM=05Bo>P1A_c00Ck@[04jd@016ZED0Bi9P04ehI`1AN6X0DVm^051lL@1<Q7T0BH9h04mj
NP1AL7T0CW1m0080BFV602L0B66904aDR`1GEhL0KUJ906eKOP1ZEg`0FVUl052=L`1RUEl0NHe@07]j
GP1nNF80SgMU09U_J`2IK6@0T6MT089XJ021IVh0RFI]099QH02JGDL0YE/g0;EM:P2gES<0]EA:09]J
C`2ZFD/0]5Y:0;IKD@2dJdD0YGA;099iD`1mUC/0NY`J08F72028N`00RWT008Yk0028P@000P29N@00
9`2>O000SgL0091j002BN000SWD008ee002AN000T7<008if002AN000Tg`0091g002?NP00U7`009F0
002CP`00SX@008V10027O000Rgd008:12P1nS1H0NiHI07NL6P1jX1X0NZLJ07Z[701eZAh0Kj/T076`
;`1//c40K[T/06nj:@1Z]c40K:hl06bV>P1X/CH0Jk/d05nk<`0205Vl<00W05Ni:P1I^Rd0FK@^05Na
<01C/3<0DZT/05RW:01LYB40Jj4K07VN501oV@l0P90;07b71`1eQ@P0Lgl7079o1`1`P@D0KHH:06ZD
4@1_UaL0L9lP06bS901[Y2P0I:/X066^;01NZC40FJHg05VV=P1YWCT0LI5207:9B@1/Pdd0IXM<05n9
CP1HTU40DYM=05NHA01JWS40GITM0080HhhA01`0IWl706Ae001PK000FE/00596001?@P00BSd004Dk
0014=P00?cD0044f000n<P00>c0003/[000c9@00;al002TJ000U6P0081L001hF000N50006Q<001H=
000A2@0030L000P500030@000@008000000<0?ooo`002P3oool0502CABh0V4Hc09Q5>`2L@4L0USM9
081I:`1aHdl0HVER05YSK01CIg00B85[03nIH00eYTl0<JY003J[=@0lYRh0>Z@]03JX:@0`Z2P0:ZTd
0P0VZT/0700W[540:J]C032ZC`0eZD@0>jTi04J[<P1AZbH0FJXN05ZY7@1NZ1H0HZPE06^V6@1bYA/0
MJ@I076Q6P1/X1h0KI`N06fK7P1VVaX0IIhG066P5`1RXA`0G:@N04nT7`1<YBL0DZPY04nX:@1=Ybd2
04VX;@0904RV:P19Z2D0AZTV04b[:@1>ZRX0DjT^052/=@1C[C40Ejd/0080F:`_02L0E:/d05B[;`1?
Zbd0C:P/052V;`1=Y3/0AJQ304FZA018Zcl0B:`j04ZW>P19Xcd0Bia304ZOA@1:XdD0C:A504VWA@14
Z4X0AZQ804JYA@12Z4T0@ZE@03nWDP0mZED0@:aA04FYDP15Xe80B:1A04NOC@16V4d0@iM<03jIC@0o
WD`0@Ym6042Q?`0nWcd0@9li042Q>P10YC`00P0lZ3d06`0hZD40=jU803JZBP0e[4X0=j]:03F[A@0e
ZTH0>:Q;03RZCP0hZU80=JIK03NPG`0dVf40<iQU03BGI`0iUf<0>ImM03RUE`0hYUH0>ZUE03R/EP0h
ZUD0=ZEE03BQFP0dWe`0<imO032RH`0203BSH`0:036WGP0cZ5`0=J]H03:^D@0b[dd0<;5;03>aC00d
/D`0<kA<03JgBP80>;`o02L0=[`h03Jf>00d]cl0<k=603>_B`0`ZeP0;jaQ02bZIP0/YfH0<jAR03JS
F00kX580@9e=046IC010Udd0?HaC03f:F@10RF40@XQU04NEG`1:Y540GJhb06^[701Z[QL0I;8J062a
601R[QD0GjlF05n_5`1U[QT0JZlM06Nc801U/Qh0G[<N05Va7`1L/AX0FKLJ05Vi901H^2D00P1H]BD0
9`1D^B@0D[X[04bg?015/Dh0C[9B056eE01D/dX0Fk8h062a<01`ZQH0OYX207nF0021U000PiP0086L
0020W@80OJ8707VY3P1U/1d0D;0/04fTAP18R700BjAQ04^dE`1=`440BL0h04Zf=019/DL0Aj5N04^:
HP1;LVH0DG=Z05U_LP1ILWd0EWMo05aeO`1UJgX0IfEi055ZP@02045SR00W04IIS01@Chh0GE:?06iE
SP1ZFH<0GUMo055aN`1;WW80HjII07n>D01lNUl0OGmN085hH01oLfX0PFeW081[IP1oI6T0PV1^091Y
J@2HK5l0VfE@09eTA@2^IST0/V0j0;EJ@02UFT/0ZUMD0:eLCP2cG5D0/6m:0:5eC@2>NeH0P9<d07b@
3P25PP<0RG/008]m002:P000S7d00080RW`00P2:N0009@2=M@00SGH008ed002=M@00SG8008ag002=
MP00U84009^1002DNP00TgP009J0002EQ@00TX<008n60029P`00SH@008V:0P1mTa40M:<U07:Z<01c
XB`0Kj4X06jY9`1]/Bd0K;8d06Zf>P1]^3/0J[Ld06^i<P1[]ST0K;5706VTC@1XXTP0IZ]106F_>01K
]Cd00P1D]TH09`1@/d`0Dke;04nnB`18`4/0B;e904jg@01@]3/0D:i305J]@01I/3`0GK8_06VX601^
VPl0L9@A06V;3`1ZRPh0JHl<06BI4P1PXB@0HJHd05jZ@P1R[T00HZ]705ZbAP1@[dD0EYm<05fGD@1V
SDX0Lh1907]kC@1fNTd0KH9906J7B01QPdT0FXa<052AB`1>UTP0Cj<h05:Q900205JH5`0;05b72@1N
N@40FVd005=J001@B000Bd4004Df0010>@00?C0003d]000m;P000P0k;0003`0g;@00=BD002hR000^
7`00:Ah002DI000P5@007a@001hA000J40004``000h800081@000`400040000P000000`0oooo000:
0?ooo`0D091;:@2IBRT0UTTc0956@P2=@DD0OV0^07=]@01TKE00EfQP051_I01;RF80@ieE03ZXB@0e
ZC/0=ZXa03ZX:`0eZ2X0<jPY02f[:00UZSD202:YCP0W02>ZDP0WZe80;:Y:03JZ=@10[2T0AJdU052/
7@1EZaT0G:TJ066W5`1XYAL0JZ@L06jS6P1_XaT0J9lN06RN801_W200LYdS06JN8P1OX1h0GZ4Q066S
:`1NX2d0DZ8/04jO<@1@X2`0C:DU04RW9@14ZbD0AZPT04JX7P1:Z1`0BZPM04nX9`1@ZBX0E:P[05FY
:P1HZbL0Fj/W0080EZ//02L0DJTc04^Y>01;ZSL0BjLb04fW<01;Y3P0B:Q304RY>`1:Z3<0B:T_04JV
<P15WSl0B8e;04VDC@1:W4/0Bj9704RW@P15ZD@0Aja404FYA@13ZD/0@JQA03jXEP0nZEX0@JQM046T
G014X5`0AiUF04FED@14Se80@I5B03jEDP0oVTh0@Z1904>O@`10VT40@9Ho046F@00oWD400P0mYSl0
9`0hYT<0>:9;03JXCP0d[4/0<jY703BXA00cYdT0=Z5?03NTE00iY5l0=iUT03F@I`0fRfH0=H]W03J>
J00kTF80>I]K03NXEP0h/580>K5A03JaD@0f/500=JaF036TG@0bWel0<J1Q02nSH00aYVD0<ZMT03:X
HP0bZEd0<jYG03B]C@0e/DD0=K=203NcB00i]4`0=KA=03FfBP0203Fh@P0W03Jf?P0c]400<[=9032b
D@0b[UP0<:]S02jYJ@0^Y6l0<9ma032PKP0fWf@0?9eH042KC@13UTX0?hm803f7C`0mQED0?8YR03n@
J@17WeT0DJm306>_9`1W[Ad0Hk0N05jb7`1M/1T0GJlB06>]3`1VZQ40J:/C06B]6@1U[ah0GjlQ062`
8@1K/Q`0H;8D05nd5P1O]B00G;PO0080F[LQ02L0E[@Q05709@1>`3D0B[E505:eB`1B]4`0E[=:05Rb
@01I/c`0J:`S07JK2`1hU`@0O9<0082E0022W000Qil008FO0022Y`P0LZhG05bd8`1FZD<0AiI^04^Y
IP17/600BKQ>04Fk@015^S/0AK5804NTF@1;REl0Bg1R04i`I@1?Kfh0D7=f04iiM`1BNgT0GWEj05ad
NP1<MWd00P12Kh<09`1=HHT0Ge:806IDQ`1ZEhL0I5j105iTOP1CPWD0DZET06bOE028QE80O7]U06mm
H`1/Mf00IG1U06U]K@1eJFd0OeiX08UFJ@2HEVH0XF5P0:M/E@2]HU80/UQ;0:]MB@2`HDP0]UUB0;Q?
E`2]H5T0[FAM0:EeCP2FOTh0PGmF07fB<@1oR@X0Pg`108Im0026O000RX0008Yl000208Uj000W08]g
002:N@00S74008e_002BM@00UWP009Ij002GO`40VH<209V:102JS@H0VHH909J6102GP@40UX@00964
002?QP00T8<008Z70P27U@T0N:4C07Z/8P1h/bd0M:`Z07F^9`1a/RD0KkDX06jh;P1^^Bh0KKP_06^g
<`1^/S@0Kjdn06nTA@1bV500Jii=06RXAP1TZd80FkI90080FKA=02L0F;9D05>eEP1:]e@0A[Q@04Fj
BP18^d80CKe004nm@`1?^d40Dk/l05Vk>P1N]c<0JJXY076O:@1cWbP0LIlU06bV901Y[2l0H[=206F^
E01R[640H[MM06BcH01K/Th0DjXk05bE>`1[SD<0LXTo06j3>P1[RRd0JI0M06NA6@1STa/0GILO05RM
8`1@WBP0Cj</04fU9P1<YRD00P1@X1`07@1HS`l0F7`2055Z0@1>F040B4`004M10014>P00?cH003Xb
000h;`00>2`003LZ000g;@00=bT0038V000`8P00;20002PM000W6`0091L0024E000M4`00614001D<
000>200020@000@100010@000@0001l00000303oool000X0oooo01@0QTXT09I98P2EBB/0RD@o0954
A`2<G3X0NW4i06QbBP1NKeL0E79R05:9H01:WU@0?j=803^R@00nY3P0?JH]03VY:00dZRH0;J`Z02FZ
=0809:Y302L0:JY602j[@`0gZcT0@:X[04N]8P1=Zb40BZ/M04jY7P1CZah0G:PJ05nV6@1UXQh0JZ<O
06fR7@1^X1d0KIlN06nP801_XRD0J:0V062S9`1LXRP0GJ<]05bR;`1CWS80Cid`04nP:`1;Y2<0AZHR
04RW8`1>YR40CZLM04^U6@1>YaT0D:XS05B/8@1HZB80FJTR05^Y8@1JZb400P1BZbT09`1=[C00CJTh
04ZX?@1@ZSL0DJLd04nV=`1;Z3/0AZTd04^Y;`18ZBh0AJDe04BM@014T4/0AYa>04ZRB01:YT<0BJU1
04JZA014[4L0AZU804NWD014YU@0A:MH04BQG012WV80AIiQ04JJGP17UET0AY=E04F;F014ReT0@95F
046EDP14WT/0A:1804NGAP17TDH0B91:04VCA`0204NQA@0W04NRA@17VTP0@j9903nVB@0jYT@0>JQ0
03RV@00kXd<0?:E203bVB@0kXDl0>Ia?03NLC00eW4l0=iiA03ZOD@0kYdd0>:e;03^aB@0j/TX0=[9:
03FaC@0eZdl0=:QB03FSD`0gXUL0=j=M03NTH`0eZ680=:]P03JZGP0fZUH0=Jm803Jc@00i]3`0=kA2
03NfA00h]TH0=[M90080=KE702L0<[A503:aC@0a/UP0;jmM036YH`0bYFT0<:=^03:PK@0bW6/0=9eT
03ZNGP0mX5H0?ia<04>GB011U4H0@H];042=D@0nUeD0@iaD04f[@@1I/Rh0Hk8P06J`701T/AX0IJlE
06J_4P1U[A80HjhF06N^701U[Qh0H;0H05b`6`1M[AX0Hk4L06V]5@1Z[@d0HZlB062d5`1N^AT00P1J
]ah09`1E]280C;DS04k0<01;_400Cl1404g0B01F]4<0F;E105JdA01S[Rd0K:PH07BN3@1kU080Ohd0
08FC002;U@00R9P008BO201g[1@0Jk4Q05b^@@17[F`0A:]Z04JXK014/e`0@/1<04:jB017/e00B:MN
04^:H01@JV@0BVmV04AdI`16NV/0A81X04V4K@1?Og@0Cgaj04IlO00204QcOP0W05eTOP1hEgl0LUF0
06YDP@1QHH40Ffen05F=J@1F[5H0L:A7086DB01_RUT0K8YE06J8EP1TPE/0JWaS07EcJ@20JF@0RUaY
09iDI02PEf@0TfQJ0:1TDP2eEU00[5UC0:YRD02cFe80_E5I0:YWF02YJed0VgEH08mmE01dSTh0NI8X
08:62021O000QGh008Im0028O000Rg/00080RG/002L0Rgl008ai002=M`00TGD009J00@2JQP40VhT5
09V@3@2JT`/0UIL@08fI4P2@VAT0Si@@09B;0`2DQ`40ThP0096:002>S@00Qi<607fQ4P1c[1D0N[DK
07Rd;@1f]c00MKX]07Bg9P1c]RD0L;PX07:k;01_^C<0KK@i06b/@@1^X440NIE707j:C@1/VdX0HZM9
06:YB@1J]5L00P1E]5D09`1@/5H0Bk1M04N[E`10ZU80@:e=04JiA018aSl0A/=204S1@P1?`3/0Dl14
05JiE`1IYU00FYeB05bQD`1MYDL0Fj]405b]D@1JZf40FjIb05RVN01F/gD0G;5f05B/FP1<Y3/0Ehdc
06QgE@1UOU80FW`m05N98@1KS@T0G8X505J;201FS`d0EIPB056L6@1<XAd0AJ@R04BV:@0204FT9@0M
04fF5@1DO0D0C6X404MM0P15DP00ADP004=10010>P00?C@003X`000h;`00=b`003L]000g:@00<bL0
02hT000[7`00:b0002HL000U6`0091T001`E000G3`004``000h9000;10001@800041000100007`00
000<0?ooo`002P3oool05029BBd0T4LZ0914>@23?dH0S4E?08aIA`1gLCh0IGI<05aeG01EN6@0D8IR
04NLE@0jYD/0=JE003NZ>00lZbh0>Z`Z03F^:@0^[S009K0i0P0R[D403@0[[D00<Zhj03^`:`15/1l0
C:hL052]7@1>[B40BZ`W05>/901KZB00GJHK05nV7`1WXb<00P1`XB80601_X1l0KJ4S06bQ:P1YX2/0
Gj0/05bR9`1PXBH0G:8X05VR:@1EWR@0E9dO05FQ6P1BY1P0D:DM05RS7@1JYAL0EZ@D056Y6@1AZal0
EZ/L05bZ601LZaX0Fj/L05J/7@80C:hU02L0BJ`]04^[=`1=[CX0EJXj05J/=01CZ3<0CZXd04bY<@1<
Z300BZTa04JV>014Xd80@Y]:04FRB01;Yd<0Bj]204Z[@016ZdD0AZU=04JYC`18ZED0AZIH04JQG016
UV80Ai9U04NJI@17W640AiUJ04FFFP12S5d0@heM04>@FP12TeD0@9mA04BRC@15WT/0BYM904^?B`19
S5800P1=UU409`1@UU40DHe;04fIB015X4D0@JI203^X>`0nZCT0?:Hi04:X>@0nZST0?JPm03jX?P0j
Zcd0>Jdm03Z/@`0k[DD0>[5403ZbA00i/D80=k1003:bA00b/DP0<Zi803J[B@0jZ4X0>ZQ=03ZWE`0k
Yf<0>JYR03BYHP0cZ5d0=JeD03V_BP0h/T00=[Dj03Rf>@0h^C/0>;To03FfA`0203:fD00W036bE@0^
/5h0;JiS02jXIP0_XFP0<9][03:LJ`0dWVH0=ImM03FSFP0dYU<0=jQ<03VVAP0kYDD0>JA203fV@P0o
YSl0@ZTi04R]=@1I/RP0H;HS066b7`1T/Qh0HK4F062Z3P1RZa00HJ/I05n`8`1N[RT0F[0/05Ba7P1C
/1T0Ek8K05j`701X[0l0JZT<05j_3`1L/AL0F[LL0080EKD/02L0D[@[05:`9`1A/C40BL0o04k0@@1A
`4@0EK=105Vd@01H`4H0G[<d05b`:@1dYQH0OI@408B;0026RP00RHd008ZA0026V0H0Oj<?07:[701S
[T00Ak5S04>]K013WGH0@jY[04FhGP13]UH0@ZiO04NRI@1<Qf/0BfYZ04EeJP0kOVT0?H5W0424H`17
Pf@0CGi_04ikM@1;MGP00P1=KGT09`1[GgL0PeIg07QFO01YEGl0GVAm05m`N@1NTV00FJm806VZ@@1^
UD/0HhiI066>F01TTED0IhiI06f3G`1dNFD0LWA[07mZJP2RF5X0XeAE08IXDP2:KTT0/EM40:]ECP2P
FDd0ZEe90;UMC02ZKUD0Z6iG09a^E`29NU@0LJ0k07JJ7`1mQPL0PW`0081k0021NP00PgX008Qk0002
08Yj000W08ik002DO@40V8@409^82`2OTPl0X9`B09jT4`2GYa<0TZTE08ZZ5`22Yah0Q:<U08ZQ6`2>
W1D0UID909FE0P2EU`L0S9h>08BU4P20/Q@0OKHI07^f7@1i]BP0NKTZ07Vl:01k^R80Mk/T07>e;P1`
[3/0KJ/o06b/?@1/[Sl0Kje007JR@`1dUD`0KIm;06>[B@1N[U00E[EI0080D;=D02L0DZiE04VdF013
]5@0A;9@04N^C019]DX0B<1604W0@P1;a3T0D<@c0570>P1A_T@0D[Y705>hBP1F^TL0F;]005Jk?01B
^TT0C[MJ04^XK@17ZV/0B;MU04jeG01A[DH0CZD`05>N:@1JVDT0FIE905:E=@1BUAl0EY8>05B@501A
T1L0Di<K052D5P1>V1X0C9XM04NN9@11XRH00P13X1X0701<Ta80D7h=04Qa3P13G`D0AED004I:0016
@000@S`0040e000l<@00>S0003L/000e;000<b`0038V000_8`00;B0002TP000X7P009Q`002<H000K
5P005a4001<=000@2@003@D000H30002000P000000`0oooo000:0?ooo`0D08e9?@29B3P0QT5808Do
EP28A5d0QEQ=07A_@@1TNTh0FgUL05=lH`1>Q680@IIJ03ZUD@0aZ4P0=ZU003V[=00j[300=Jlc02b_
?@0R/D42026cA00W02Zc@00a/ST0?K4U04>`7P1;[1`0DJ`P04j/:01;[Bl0C:`[05>X901IYah0FjLQ
05jT:01WY2P0KZ8W06NR901RXbP0H:@^05nO<@1FWRl0D:@W056V8`1>Yb<0DJ@P05JP6P1HWAT0DilG
04nR5`1?XAT0EZ<I05^S601GYQ80DjPE05B[701HZaH0FJXD05FZ5`1@[1`0C:`O0080B:dX02L0Ajd^
04n/=`1CZc`0EZ]005R[>01EYc@0D:Dc04^U<`17Z3D0AZPg04BV?P14YDD0A:=<04BWAP15[D<0Ak51
04R^@@15ZDP0AZME04BVF@14YU`0AZAO04RKH`15QfL0AhEY04FBK@15V6X0A9MR046DGP0nSEd0@HmN
04:@G011TUX0?Z1C042XDP14YTh0B9i<04Z=D018PUX00P1=QUh09`1@REh0EX9F04j;C01:V4P0AJ52
046Y>010ZcH0@:Pf04:V=@0oZ3@0?j`g046_=P0m/c@0>kDj03Vb@@0m/D@0>k=203Vd?`0g/3h0=[0i
02n`?@0b/D80=:m003Va@`0k[T@0?:Y:03^VDP0jYV<0>:IW03FTHP0dYEl0=:UF03J_C@0h/T<0=[Di
03Ve=P0h^CH0=[Q003>eC@02036dF`0W036aI`0^[Fl0;JI^02jKK@0cT6/0=haZ03NAJ@0dV6H0<imG
036UCP0bZ4/0<ZQ603>/A00f[D80=K8n03Je=`0k]bh0@kPU04^i7P1H]aX0HKHK06>d7@1T/al0H;8K
05n_4@1RZ`l0Hj`B06>`6@1N[QX0GK0L05^`5P1K/1@0HJlF06B`4P1V[`d0JZh=06>`4`1O/AH0F[@I
0080F;DT02L0Ek<R05Vb6P1E/b@0D<0g05Bj>@1F]C`0FKDi05Zd>@1K]C/0GK@a05fc;@1b[1P0PIX5
08BB0027R`00RH`008ZD0029VP80PY/907jV501X/B/0CKA;04N^H@13WW`0@JUi04:cJ@14/Ed0B:EI
04^KGP1;TV80BHMQ046;I@0jTFd0?8a[0424I01=OfH0FGM[05]aL@1HLW<00P1HJW<09`1^GW40OUYa
079MMP1SHG`0Gg5`05]gJ`1VT500JjY0072U@@1VUT`0GhmH0625H@1TRUP0K8ML07=iG`1jL6H0Mg=[
089cI02LJ5@0XUI808IOC021JTL0Zee00:]AC`2MCU@0Yee?0;IQBP2ZLTh0YFmC09E[E@26Ne40Kj0[
07RJ5P22S0D0Qh4008An0023O@00Rgd008Yi000208eh000W09Mk002IR0H0UYHB09VN6`2HXad0V:lO
092f8@2=/ad0S[<Q08b`9026ZBl0Q9Xg08FG<`28VRd0TilE09>O102?Y`l0Pk0H07Zb701i]ad0NKDZ
07Zd;01i]B/0NKXY07fo;01l`2`0NL0_07J^>`1aTDh0K8mD06bGD01Z[4X0K;I206V/AP1[WDh0JIm9
06:/C01N/U`0E[AN0080E:iB02L0E;5D04BiE00o_E<0?kaC04J`E`16/UH0AKEF04VjC`16`Ch0@lDk
03jiA@11]4T0AK]=04O2D@19b4h0BLE604S2B013^U@0?kEP03ZVM00lYFl0>Za[03nXDP14ZS`0AZXn
04>X;`17[CX0CZLg052O:P1;VaX0CiLE052I9@1?UbH0C9@Y04bG7`1;Ual0BYDQ04FD:@10WRH00P10
W1P07018TA@0Ah4D04Ac4`15H0L0AUD004Q:0016@000@Sd0040h000o=000>C8003P_000d;@00=B`0
03DX000b9@00;RD002/Q000X7P00:1/002<J000K5`005Q<001<=000A2`0030H000H20002000P0000
00`0oooo000:0?ooo`0D08Q4AP21AT<0QD=A08M5H028B5l0Q5M:07=XA01WLU40GGIO05QgIP1BO680
AI1I03bQC`0iYDD0?JTm03j[=00iZc40<Z`d02b_>00U/CP202Rb>@0W02nd=00d/Rh0?K0T04>^7P1;
[1`0DJ`O05>Y8@1=[2L0EJ/U062W7@1UYQ`0IZ@N06JS8`1^Xb@0Kj4Q06fQ8@1]Xb40K:@V06ZQ;01O
Wb/0FJ4V05VT901AYB80Dj@S05NR701KX1P0Dj0I05:O7@1CWAh0FYhN05nO6`1LY1@0G:TG05fZ701M
ZQ<0FZXD05FZ6@1?ZQl0DZXT0080D:hZ02L0CjX_04n[=`1CZcX0EJ`m05BV=`1EYcP0DJ<h04bS>`18
Yc`0AZLn046V?P13Y4@0A:9904JY@`19[c`0A[8n04N`@`16ZDh0AjMH04FUF`14Xel0AZ9P04NHH017
QfD0AXAX04F=J@16TVL0AhiO04J;FP17QEX0B8IJ04F:FP14SEL0@YeE04BUE015XU00Aia=04R<D`18
Q5/00P1:RF409`1>S5`0ChUF04^@C@18VTL0B:1004RY=P19[340B:Pf04ZU=016Z380AZ/b04J`;`16
/bd0@[@`04:a=014/3P0A;8c04B_<P10[340@:d[03b`<P0h[c`0>;8m03Vc?`0j/Sl0?:m403ZYD00d
Y5d0=JES03FTHP0dYUh0=JQI03F^E00i/D/0>;A003Vd?00e]CT0=[Q003>fA`02032cE00W032cGP0^
[F40<:MO03BNF@0hUE@0?YAD03nGE@0oWTd0@:E504>Z?@15ZcL0AZhf04B_=018/S@0BKD/04^g:01=
]b80D[HN05Vf6`1P]Q/0I;<R06F_901R[bH0GK<O05^^4`1M[A40Gk0A05n`5@1I[a80F:h@05b^3@1R
[0d0IJ`>06F_3`1R[a<0GjlI05j^6@1O[QX0H:lL0080F[4Q02L0FK<H05bc401J/a/0DkH_05Bd<@1F
/S`0F;8g05Nc=01F/Cd0Ek4b05Fd<@1^/1`0O:07086E0026TP00RI4008ZG002:W000Ri`208FS301`
/240C[@f04Z^D`10W8<0?jMo042ZNP16XVP0C9MG04bCEP17TeT0AYAG042HI@0fW6d0>Xe^04=kJP1B
K6`0IfQ]06mVK@1UJfh00P1OJfl09`1/HFh0NE]a06aPM`1NHWX0FW=]04mfJ01[SdH0LZ`n06RZA@1U
ZE40HI=K06=fH`1UOE/0IW]J07QaH`25IF`0S6aY099aI02@Je/0TUmQ081PG024HE<0YVA:0:EJF02K
Ef<0XeaJ0;=[DP2SLdh0VG1?08QhDP1jR4T0M:8M086L2`25S`<0SHH008R2002:QP00T8D009600002
09N1100W09^9402OVa<0W:HK09RZ902C[2L0S[D/08fh;@2<^2T0R[P[08bg9`29]2/0RjX`08VQ>P2;
VcD0S:HK096U402;[A40P;HN07Rh9@1g^bL0NKXY07Bj8`1i^bD0M/0T07O3:P1h`380Mk`f07Fa?P1b
Td`0LXe@07>BC01/XDH0J:Tn06NZ?@1ZXd<0KYi206fVA`1_[El0HjaL0080IZME02L0HZaE05f`E@16
_5L0>[]K03jhEP14^d`0AkY404Ri?@16_c40@<0]042l;`17_S00CL4a04c2>@1<`C/0C;lj04nk?@1:
]D40B:i?04FVG00oYe/0@JMR042YDP14[Sl0?jhm042Y:`14Zb/0BJ@X04NK9`15V2@0AYdP04RO:01:
UbX0B98`04ZB9`18VBL0AILY04:G;`0lWRh00P0mVad07012SaL0AX8H04Ec4018H@@0BU<004]60015
?P00@SX0044h000o<000>2h003H/000e:P00=BT003<U000b9P00;B8002`N000Y70009AP0028G000N
5@00614001<:000<2@002`D000@20001000P000000`0oooo000:0?ooo`0D0791E01WBeD0Ie9F06mK
E`1dHe<0MFU:06M^BP1WM5D0Hg=W05edK01HNF<0BhYH03nPC00nYd<0?j`h03^^<P0h[Bl0<:d/02Z_
;`0Z/30202na;P0W03>a9`0h/B00>ZlL04B^7@1:Za`0BZ/O04f[7P1=ZR40F:TN066X6`1XYaP0JZDH
06VU6`1^Y1`0LJ0J07FP6@1fXaX0MJ@O06fS901UX2@0H:8W05^S9`1BYBL0DZDV05NU8P1HXal0Ej<R
05VP9`1FWR`0Fi`T05nL6`1OXAD0GZLE05nY5`1LZ1H0Fj/F05B[701=ZbH0DZT]0080E:/^02L0DZTb
056X>01BZSX0E:Po05FX>@1?Yc/0CZHn04RVA@15YT<0@ZM304>X@P16YT@0AZE604RZ?P17[SX0A[8o
04B_BP16ZUH0AJQL04BVFP16XeX0@j1N04BGH014RV<0AXUV04>?IP15RVD0AHMM04^4E`1AP5D0CX5C
04R5E019R5L0AIUG04FPF014WeD0AYIH04F=FP16R5d00P14Sed09`19UU/0AIMB04FMC016XT<0B:8o
04fZ=01>/340C:/f04fZ=019[340Ajl`04b`;@1?/RH0BK8W04Na:P1<[b/0CJlX04V`:P17[R`0BJhV
04>c:@0m/cH0>[8l03^d?00k/cd0>k1003R/C00bZET0<ZUO03:YH@0`ZF<0<jaP03>_F`0g/E<0=kI8
03Zf@P0g]Ch0=kDm03Be?`0203:dB@0W02jdC`0_/U00<Ja;03NY@`0kZCl0A:Th04^/<01C[2X0EZ`V
05b^9P1J/R80FK@O05Rf7`1M]b40G[HN05bh6`1L]aP0G[DJ06>e6`1U]200JK<V06N`9@1S/2H0Fk4M
066a4P1U/0d0JK0>06F_3P1PZQ00HZX>05n[4@1UZa40J:dA06B^5@1P/1/0H:hM06:_6P1Q[aH0G;0F
0080G:lG0100HK8B06>c3@1O]AL0F;DO05Jc8`1G]2H0F;<Z05Fb<@1D/CT0E;4d05Je=@1Z[R40N:8>
08>I1`29T@40Ri000P2=V0005@2?VP00S:8607Z_5P1R/RH0EJe604NKN@15Y7`0@jag04BYIP1>YU@0
CZEC04fYE`19[5d0AZYP046XIP15VVP0BhQW05=oIP1NO680GgYV05InK00205ImK00W06AcKP1_KVd0
J6i/069/K01KPE@0EiQ406fS>01Z[SD0Ije006F/C01SUEL0IGEP06IkF@1YNEH0M6aU08UML@2BH6d0
Vf=^099RIP2=EVh0PVES08ePH@2OK5@0Wf9L09eLJ@2RGf40ZVEH09i^DP2EKE00PGU?07N7@@1iVAD0
OXl408F:0P2<Q000RhL008j8002BRP00UX400080WXH@02L0UH`S0:N?;02QTcD0SiTe08NM@028ZCd0
QZdh08:g;`24^BX0Q;PV08Fj8@27]RD0QZhe08NH>`2:YBP0QjXH08>_501l]240M[Hf07C0<01d^bX0
M;DQ07:e9@1d_2T0ML4e07G1>`1f`440Mk=407RGC@1iT4d0OHY=06f@A@1VV3T0JITg06fG?`1bUSl0
NiY507fSG@1aYE`00P1cX5`09`1bXf40Mj9P056dI@0f_6@0=/5L03c4BP15_ch0AkPj04:l;00l_2P0
?KTZ046j<@11^bl0?;da03^m=P16]d00CK1:04ZR@P1:V4h0B9aB04>LB013WEX0@JIC04B]A`10[c`0
?ZXX046Y9@13YAl0AIXU042F;@10XBl0@:D`042J<012SSD0AI@/046M;P0kVc00>YPb03RM<`0203FI
9@0;03^<7@0nPa`0AW@B04US101>EP40BDH0048n0014?000@SH003dd000g<@000P0d;P003P0b:@00
<2H0030S000[7`00:1`002HH000U60008aT0020G000J4P004PX000d6000:0`000`408@00000<0?oo
o`002P3oool0501N>V80FTER06ACG01`HU@0KfmE06QeE`1UMED0JGAN06IdJP1SLW80GgAV0525F@14
Vdh0?ZI103^^?@0i/CP0;k0d02R_;`0Y[b`0;;0[0P0a[bH09`0d[1h0>:lK03V_6010[al0AZ`P04V/
7`19ZQX0BZPM05^V7@1QYA`0I:DM06FU5`1VYQ@0JJHG06bR5`1^Y1@0LZDD07>U6P1[YAd0H:<S05fS
:`1GY300CJ<`04jS;01BYRD0F:DW05ZT:@1OX2h0GJ0b06>L:P1SVQh0HYhH062U5@1NYaL0FJXJ05B[
7@1?[2H0CZ/_05BY=P0205BZ=`0W05:X>01@XS`0D:Pn05:W?01?YCd0C:M104ZWAP1:Z4h0AjM>04FW
BP11Y480AJI404JUB017ZSh0AJln04>aBP10ZeX0@jUR046XH015Xe`0@j1I04>JG`12UV00@HiQ04><
I012RV80@H5U04EjG01?NEL0FWMG05IgE@1>OE@0Ah1J04VAGP17Vf80AiYN04N?G@12Red0@XYR0080
@i9I02L0A9]I042TD011YTX0A:M104RQ?P1<ZS@0C;0`04b]=P1:[C@0Ak4^04Na<019/bd0CK<W04Vc
9`1</b/0DK0X05F_9P1A[R<0DZhV05:b8018/R@0?k<b03^c>P0k]CP0>K@k03N`@@0aZTh0<JUH02nZ
GP0aZf00<JaT036]H`0b/640=K9J03RfE@0k]dX0=[A003Je>00d]3T00P0b]4009`0`]4@0;k53036]
?P0i/3L0@;@_04Zf8`1F^1P0GkDB06>e401T]@l0H;L=062f3`1P]a<0I;PI06Ne6P1T]QH0HkHE06Be
5`1S]200IK@W06Nd:P1X/BH0GK4U05jc7P1T/Q00J[0;06n]301aZP/0K:T906N[401W[1T0I[0K06Fa
6P1M[al0FZhT05b]901R[QH0Gk0D06:c4@0206>a3`0W066`3@1S/A40GK<D05>e601B]1T0D[@L05Jd
901@/bd0D[Dh05>d=`1J/cD0JJlV072Z701jW@l0R9<408f@002>U`00SIL008nJ002>Y0<0P;4?06^d
6@1R[Cd0Ai]_04>UMP15Zg@0@ji[04fcFP1>/U40CKIG04VgGP16]6D0AjaQ04VRIP1<U6P0CXU/05>1
I01?OVP0C81]0080CX1^02L0HgU_075eL@1YKV`0HVeV06:G?01I]RX0H[DZ06Fg;`1U/SX0IZQ<06>N
E`1ZS5D0LHY?06]iE@1aMf80O6e]08QVKP2DGg40WV1U0:1EIP2@JEl0RfmU08ieH02IK6<0XfQ[0:AT
H@2VHUP0W6UB09AXC@21OdP0MX/n07VG5`26R@<0RXD008n7002BQ@00THH009N80P2KS0`00P2MT1/0
9`2MUbP0W9la096Y<`27Yc<0Q:Hm086_>P1m/cP0OK@a07nf<01o^2h0PKXZ082l;`24/3/0RIhm08JY
<@24]1d0P;4F07b`:01a[Sh0LKHn07Bj=`1b`2T0Lk`^07Nk<`1h`3`0Nl0j07Vi>P1g[d40LYm607JH
B@1gV4@0L:0m06nV<`1aYBd0M:8c07ZG=P1lW400N:=;06NRD`0206FJH@0W06BLJ01RX6L0CK=Y0431
IP0m`f@0?/9C04FiC@17]TD0A[Pl04Nd>P15[cd0Aj/k04NU=P14WS@0@iQ504JHD`1?SUX0FGm>05mn
E01BTU00Bi=704B:E@15Ve80AZY804:[>016YRh0AZL/04RT8018VBL0A9D`04BO<@12YS<0@ITa0467
<`17TbH0@IPQ03fG7`0oUR40>i<R0080=i0M01/0>XLH04225P18M`/0BfP204iG001;A`00ACd004<i
0011=`00@C8003/_000i<000>Bd003DX000a8P00;Qd002TL000V6P0091T0028E000M5P007Q@001P@
000@2`0030H000L2000200008@00000<0?ooo`002P3oool0501NBfL0FeAR06APEP1ZKE40J7MA061l
E@1QNU@0IWUP06IeIP1QMFX0HGUQ0566E@14W4X0?:I103N/@@0c[D00;:hk02R_=@0[[bh0<j`V0P0h
Zb409`0i[1d0>jXI03j/5@19[1`0Cj`M04n[7@1BZQ/0EZ@M05nP801YXah0L:@N06jT5`1_Y1D0LJ<G
07BT601fXQD0NYlE07BP5`1]XAL0I:8P062R9@1NX2D0EIlY05JN9`1IX280GZ8T06BP901VX2@0Ii/W
06^I8P1YVAT0JIhH06BS5P1MYaP0F:PN05>Z8`1?ZBT0CZLb05FY>00205JZ>00W05F[>01EYCT0EJ<i
05NO=P1EWcH0E:<h04nT?01<YTD0B:I804BY@`13Z400A:U004BX@P16ZSl0B:a304JZD@14Z5h0@J9S
04>MH`14Weh0A9aP04JHHP15UV80AY1T04>:I@14R6@0AX5S04]jGP1DMU`0H75N05]eGP1@OEh0BHMP
04VDG@19VUl0BYEK04N>FP18SEP0BXaJ0080AYAF02L0@iaB04:RCP14YTH0A:I004JX@019[3H0CZlb
04b^=`1>[SD0C;4]04^a;@1=[Rh0DJhZ04n_:@1</B/0E;8W05Nb8`1H[BD0Ej`V05R]8P1A/Ah0B;4V
04F`:P13/2/0@K0/03n_=00j[D<0=:Y=03FYD`0gZeH0=Z]F03Z]DP0m[T/0@;5204Fd>01;/bl0B;<Z
04Je:@1:/RP00P1=/Bh09`1>/C40DJl`05R^;01L[bT0GK4S05nc7@1R]AP0I;@G06Jb501U]180IK@?
06:e401T]1<0I[@I06Bd7@1S]1P0I;LF06Jd6@1U]2<0I;8Y06J`:@1V[b80G[<W05ba7`1S[a40JZd=
06nY3`1]Y`d0K:D<06bZ4P1X[1`0JZlK06F_6`1RZb40GjXT06:Y8P1SZQP0H:hG062a4002066`300W
066^301R[a<0G[4D05Ba5`1B/QP0Dk4L056b8`1A/bl0D[Hl05Jb=`1I/cH0IK0V06R/8`1jY1@0QIL6
08fG002>U`00RiT008bO002=Y@80Q:`907Ba4`1U[c@0C9mU04VPJ015XVl0B:]U04fdE@1@]U40BkIG
04O0H018/f00BjaP04fTIP1>UVd0DhU^04elK`1:MVl0BGAa0080CWU_02L0I7Y^071oJP1[PE/0IXI:
06BZ:P1M`2L0H;PY06Be<@1R[ch0IZ1H06BIG01TTeP0K8YC06mhF@1`NF40N7IZ08AYI`2BE6h0WEeQ
0:aHHP2IJed0T6][08McJ`2?KW40XFYa0:=RJ02PGe`0XFAA0:9XD022QD00LX/f07b?5P21P`80QX40
08j3002AQ@00UH@009b:2P2HUQ/00P2FVRL09`2KUCL0SK0e08Nd<`26ZS<0P:/d08:d<P1m^C@0OkPb
07fg<`1n`3P0OL0f07k0?@21/4<0RJ1008NZ=@23]1l0O[@H07Na;01bWDL0LJI:076i@`1_`3/0N<0j
07Jm@01f^d00Nk]007Vf?P1d/4D0LZM;07:LBP1aX4P0L:i3072c>P1b]380MJle07FS=P1eXS`0L:94
05fOCP0205nJH`0W05JIM`1;XGH0B[Qc04C8K@0oag80?keX03n]IP15/600Ak=G04Z]DP19YUD0BiaE
04R7C`13O4T0@FeI04IfJ`1?JVh0I5aP07QRH01PQUD0Bha>04ElF@13U5H0AjI?04FZ>`15Y3H0B:Pd
04BY9`17Vbd0?iPh042S>P0lYcP0>i/d03R8>P0nUbT0?ITM03ZH5`0oUAH0>Y4H0080=HdI01/0<XHF
03644@0fO0P0@g4104eN001>B000ACh004Dk0012>000@CD003`d000k<P00>Rl003H[000b9@00;B40
02LI000W6P009aP0028E000O4@007A@001TB000C2`0030D000H2000200008@00000<0?ooo`002P3o
ool0501SIf40G6]N05QcE`1LO4d0G89?05V5FP1GOe`0F7iR05QnI`1HNVT0F8=T052@E@13X4P0=:I6
02f[C`0V[E@09:m?02Fb@@0//3@0<ZdT0P0fZah09`0lZAT0>j`F04:Z501:[AP0CZhL056]7`1CZb40
EjPS05nT901WXb40L:@K076U4`1_YQ@0LZ<G07BR601fWQT0MIdK06^J6`1SW1`0GYhQ05nL7`1OW200
GIXS05jJ8@1UWAh0J9`M06bL701[V240JILN06>I6P1TWaH0IZ4H062V6P1IZQh0E:XT052];01?[340
CJTd05>Y>00205>X=`0305FY=`1FYSP0EZ8e0080EYhc0280DIhb04jS>P1:Yd80AZU204>Z@P12Zd00
A:/n04B/@P16Zd40@jQ:04BVE@14W680@iEU04>CH`12V6D0A9QU04JFIP17UFX0AiA[04J<I`17QFD0
B7aT051kHP1GN6@0Hg5V05]dIP1AOfL0BXUW04^FH019Ueh0CHmK04^>E@1;T580BI=E0P1:UU009`17
WDh0AZ1;04RVA@16ZSl0Aj`o04V_?@1:[cL0BK0i052`=@1?/Bd0C:h/04n/<`1B[300Cjd[04fb;01D
/RX0Fk8R05Va8`1I[RP0FJhP05R`701A/1`0BZhP04b/801>[b40AjhZ03n]=00lZd00?j]803n/BP0o
[T/0A:e304R`?01</Rh0D;DS05Fd7`1F]A/0EK<K05N`7P0205n]8@0W06J`8P1Z/B40Kk0O06nb7@1^
/Qd0J;@L06Jd7P1U/b80IkHP06Fe7@1T`1P0I;HE06Jd501V]QL0IkPK06Fg6P1V]1T0IK<L06Nb901U
/BL0I;8U06>`8@1O[b80I[0L06B_5P1U[1H0IZPJ06BZ6P1TZ1P0JjHG06fW601aZQL0KJXH06RY601^
YaL0LJTE06N[6`1N[Ql0F[8F0080Gk8?02L0I;0A06Ba601T/aH0E[<I05:b6P1C/Q/0E[<R05Fb;`1G
/S/0F[4d066f<01//RH0KJhS07NY5026X0H0RiX0092G002=U000SiX008fQ0027ZPD0O[4:06Nc:`1?
[5H0Bj=L04VGH01<Wf40CjQH04n_E01=[5X0BZaN04VXH@1?Y5h0Di]Q05f@I`1IQ6`0E7U_04ieK@17
MG400P1<P6T09`1FU6@0HJMG06FZ?P1Z/2L0JkHL06;06P1W]Q/0JK0/06F]>01TY4P0I:A?05jVB@1T
XdD0J9]706^=CP1aO5d0OgAI09UOF02=JV80SEaa08e_HP2AKVH0OViW089[L02MJ700YFA]0:AKF@2V
I500[6U?08R;?01gV2`0PXhD08Io0@28OP00Rh000922002DQ@00VI0<09RG7`0209RP:00W09FW<@2@
/Rh0SjTb08fT=`29[3@0R;D_08Nh;P23]R/0PkT]082j;P21_3<0QKPn08fVA`28W4L0Q:Dl08Bg9@23
]A`0O:T^07V@B@1fVdT0N;U407;0@01k`3P0MkPm07fh?@1l/c`0O:dj07NX@01dXT00MJ0n07BU?P1_
[S/0M[8c07Jd;P1e/bd0N:l[07:Y=01/ZDD0H9a?0080G9EJ00<0DimU04Z^K@18^Fl00P13`VP08P16
^VL0B:][04JVJ@15YE`0AZa?04b^D`1<VUL0CGYH05A`E01DJU`0E7IW05U^K`1LJf80IVIJ05akCP1;
STT0A99D04>MC017YDP0@Z`i04FV>P17YS@0AJPX04RO;P13VcL0@9`o03bL@`0fUc/0=Hli03RI:`0j
Vb80>I/M03bI7P0lV1h203RE800K03F=7P0aQQD0=gd9049`0`1=GP40Cd`004]10016?@00@cP0040e
000k<000>Rl003`^000g;@00<RD002dP000[7P00:1X002@H000P5`007Q0001P?000D3P003`P000P4
00040P000P0002400000303oool000X0oooo01@0HWMO069kF`1IOU80FXE;05R;C`1IReL0DhML0526
H01?PfD0Ch9W0568H01<U5<0?Z1902jUB`0QZeX07ZiQ01naG00T/dT0;Zlf03J]8P80>j/L02L0?Z/H
03j[5017[180C:hG04fa701>/B80DjlW05JY:01KYRL0HJDQ06^S601]YA80KjD@06fQ5@1bWQL0M9hM
06fI8P1XUb40H9TT05jM8@1LWAl0HYLO06VG801]VQ`0LY/I07>F601bTa`0Ki4N06VF5@1SWAH0H:8I
05jV6`1GYR00DJTU04n[<P1>[3/0Bj/i04bY>P1CZ3T00P1CYSP09`1DYcP0E:Hj05BR>01DWS<0DJ4a
04fP<`1;Xc/0BJI004JW@@14ZCl0@j`l04B/?@14[T80AJ]604>VD@14WUh0A9=V046>J@13RVT0@I1Y
04>BKP13T6/0Ai1_04N@KP14R6T0B81V04YlI`1BNVP0F7EV069_K01HMf`0CXE/04R?K019UfD0C9AN
04j:F@1>SED0CI=B04bCDP0204ZHC@0W04ZKB`18Wd/0BZA404Z[?`17[d00B[0o04Va>P1<[c/0Ck0h
04n`;P1?[Rl0CZ`i05:[=P1@[Rd0D;0Z05Rb:P1N/bL0FJlT05V^:`1K[bP0FjdM05R^701C[1d0EjPI
05VY7P1DZ2P0BJT^04BY>015YSl0AZTl04F/@P19[cT0CkDa04jf9@1C]R00F[DH05fg601J]Qd0Gk0N
0080IZdQ02L0JJdS06Z_9P1//BH0J[@X06Ze9@1T]R@0HkHX066e;P1R]RX0HL0Y06Fm9@1W_A`0JKHD
06Rf5P1X]Q/0I;HM06F_8@1R/2<0H[@[05nd:@1T]2L0HK8P062`9P1T/1d0HK4M05j`8`1C[Rd0EZhZ
05ZY9@1SZ1`0IjPI06fZ601VZQ/0IZPH06VX4`1^Za00IZlQ05bb;P1J]1h00P1M/a<09`1U/Q<0H[DM
05nc701D]Q`0D[LN05>c7P1G/b40F[<`05Ne?01J]C@0HKDa06Jg9P1W]2D0L;0E08BS1`27V@00SI80
08nB002?V@00Sj8008fW0020]@H0K[LW04jeB@1;ZE@0C8eP04Z9IP1=T680CYER04jFI@19UFP0CI5Y
04j>IP1MQfH0IgQ[069fK`1KMVl0D7MZ04ajJ00204^@H00W04faE01I`4@0I<0T06K05`1W`1L0H/0F
06Fc5`1P[Bh0FJa505b[C@1L[U40Dk1I05>cB`1C]400GYm806QnG`1lN5X0Z6]<08EiGP1fKWT0PWE^
095_J@1fJVT0NVAb09iZM@2[J6d0Z5aJ0:]UD02cKdl0RI<m07VS8`27UPl0R8L008F60026QP00RhH0
09:<002CVPd0VYHT0080UZH[02L0TZ/Z092]:`2;[C40R:`l08bd=`2<^340RKdW08Nh9P23^BL0Ok`/
07bl=@29/TL0VYa<08RJC`22XT@0PkT^07jg901lXcP0OhY<07JIA`1i^DH0M/5907S0?P1h^cl0N;Q0
07Z]@`1gY4@0MIi207BK?`1eX3h0LJHo06nd?P1`]cP0LK8h07:b=01c[2l0IjHf06FWB@1RWe000P1M
U5D09`1>YUX0B;QX04JlJP12_F@0@kaP04ZgI018Zfh0AZ1b04>HI016Ze40AkAB04ZJF01>KF40FFIP
06=WHP1WJVX0JfEh05=cK@1DKEh0CW9:04J4B014W5@0@JED042QC`0m[d40A:do04NY=`13Z2l0@j<f
03nO?P0mVD/0>YAD03BHA00_V3`0:J0b02nQ9`0aWbD0>:4R03ZP900203bM;00K03FB8P0`QaP0=80=
041c1@1<G`40D58004];0018@`00A3d003/f000i<@00>S<003Xd000f<@00=BX0034U000_8000:Ad0
02@H000P5`006a<001P?000C2`003PL000P400050P000P0002400000303oool000X0oooo01@0G8=K
05^0F@1IP4l0Fh9205b9@01MT480Ei1005>?A01BSDT0Dh]>05>BC`1>VD@0?Z<n02fU?P0RYdP08J];
02J/AP0/[CP0=j/X03fZ7@80@j`I02L0AjTG04fX5@1FZA80GZXB05b[5P1J[AD0FJ/G05ZZ6P1OZ1l0
J:@L06nS5P1aXa<0L:HF06jQ5@1`X1D0Ki`G06^M601ZVa`0JYXO06VK801/VR80KiHN06nE701aUAP0
KiLE072H5P1dVQP0KYPF06RK501RVaP0Gj4H05^U7P1DY2@0CZP/04fX=01:Z3/0BZHi04jV>01AYcP0
0P1DY3P01@1GYSD0EJ@c05BQ;P1BX380E:0e0080D9m00200C:9304VT?P17YcX0B:Pj04R[>P16[T40
AJe804BTE@13Uf80AHeZ04N6K018Of`0AHA]04B6L013R6l0@hUa04J8KP15PVP0BGeS05AfHP1OLV40
GgER05eeIP1DP680CXaS04RGH`1:Ueh0C95J04n2FP1?QeT0CH]K04Z@G080Bi9A02L0BYQ=04ZMCP1:
YD00BZXi04f]>`1>[c/0CZle052_=01A/3D0Dk0`05:^;P1A[3@0EJ`d05N_:01H[b<0Fk0U05j_8`1L
[B80F:`U05^]:@1M[1h0G:`I05R[601PZ1H0IZ<G05nR701FY240CjDW05>V;@1BZ300DJXf05F^<01J
/bP0GKDV05fc8@1Q]240IK4N06Fa7`1U/2400P1T[R<09`1X[bD0Jk0Y06Ra:P1//R/0J[DV06Re901Y
]B@0JkDW06Rf9`1X]b@0JkdU06fg8`1_/ah0K[8K076e6@1Z]1H0Ik<I06Nc801W]2D0JK@R06Zb7P1[
/Q`0Jk8J06Z_6`1U[Ah0IJdU05j[:@1NZR80HJDO06JV601/YaL0L:<H06jT7P1[Ya`0KjLG06fZ6`1V
[B<0IZlV06^]6`0206^_500W06b]4P1V/1H0HK8F05Zb601I/aL0G;8G05Za701I]2T0Ek@d05bc;`1N
/Rh0JK8Q06^`6`1eZa@0P:<608NF0@2@TP00Thl0092C002<W@80RZX908>e301_]BP0D<19052]D@1:
VE`0BIIQ04^MG01?We`0C9iO04ZHI01<TfH0DHiS05B8HP1KPVD0EhUU05BEH@1DWDh0EZ100080GZ/e
02L0I;@`06Zj9`1b_a/0KkDD06ne5@1_]aD0K[4K06V/;@1T[cX0H:dl06:]?@1L[d40F[1605RbA01M
XDT0HX=K07MnFP2TLED0OHER06agM@1dMFd0Ng1W06i_IP1gIFP0V61U0:MQH02TGE@0ZFYA0:adE02;
TS`0NYhP08RF3`2<Q`00Rh<008Yn002DOP00UhT<09FI502HVR800P2CX2X09`2@YBT0SZP^09>T<@2B
XcP0SZLd08V[=@26[bd0QKHT08:i8P23^b80PL0_08>c@P2:WTh0Pj1=082SAP22/c80PKPR07f/<@20
WT00Nj1607ZdB@1`_DX0Mka007Ne@01n[TH0P:dj07bY>@1mWcD0PZ0e08FR<@21YC40OZT`07bW;@1i
Z2P0NZdV07V/9`1jZc@0LJ`m06^YAP02066ZBP0W05FfB01A`4`0Cl1C04G1D`14`Td0B/1?04BnF@15
/el0BJYL04b/C@1;[4`0CZ5>04^@FP1?PeX0D7UK05=`G01LJfD0CWUO04b4E`1=RDX0Bi9504^MB013
X5D0?jED03Z/AP0m[TH0@:a4046^@013Yd00@J=103fQ@`0iXTT0>:Dm03BV=@0cYS<0<jD`03FT;@0h
Xbl0>J4_0080?i/V01/0?8`K03mn3`11LPP0BF<2051E001>C000CdH004Q30016?@00@3H003dc000h
;@00=R/003@Z000c9`00;2<002XN000V6P0091T002<G000N4`006@l0018<000>1P0020@000D30002
00008@00000<0?ooo`002P3oool0501GR680FXIQ05^2E@1MPdL0GHI005n??`1LU3X0EYHl04jG?`1>
Ud40DIU204jP?P0mYcP0:ZTi02:Y?P0SZCX0:jXf03BY:P0kZB<0@J/J0P16[1X09`1=[AL0Ej/C05bZ
4`1SZQD0HZTD05^Z3P1IZA40F:`E05fZ6P1TYaP0JZHD06bW5@1]YAP0KJDF06VR6`1WXAH0KZ0F06VS
7`1]X1`0LIdO07>N:@1cVR80MILK06jF5`1VVa@0II`I06NP601VX1<0HihD05jL7P1JXB00DjPZ04fX
<01;YSD0B:<g04>P?013Y3P0AZLg04ZV>@0204fR=@0W056Q<01?Wc00C:0]04^P=01=WD00DIa8052K
B01=WTL0Bj=004ZW>P19ZCL0B:/h04N[@016ZdP0AImJ04:>I`13Q700BGed04mdL`18Mg@0@gYf03mo
MP0nOgH0@H5c04AmJP1>Mf<0GG9P06Y^HP1MLf00EWIN04j9G01:Tf00BI]P04VJE`19SeL0Bg]N04ao
HP18PfH0BH]T0080BI5G02L0BYUA04ZND@19XT<0CZ/i052`=`1C/CX0D;0d05:^<P1C[SH0E:lb05J_
<01E[c@0FK0f05bb9@1M/1h0FK0R05b_9@1J[R<0EjdU05ZZ;01LZB@0GZ/K05n[5P1XYa@0KihI06VK
6`1HVQh0FYlQ05jU8@1JYbH0F:P]05b_:`1P/RH0HKDZ06Jc:01U[bP0IK0X06Fa:@1R[bh00P1S/300
9`1T/Bd0IK4_06F`;`1Y[c40Jk@/06Ze9@1Z]R40K[LP06bf8P1/]2@0JkDV06fc:P1_]BT0LkDU06nf
6@1[/aD0J;8I06Nb8@1X]BP0I[@Q06Zc701//aT0Jk0H06N_7@1K[B/0FZh[05b]<01QZBH0GJ<T062Z
6P1U[1P0JJTL06R/901Y[RH0H[4S066`:01S/Bd0IZl[06ba800206fa600W06f`4P1S/Q40G;<D05^e
601M]1H0Fk@C05bc5`1E]B@0F;Ta05Zh;@1H/S40Hk4O06Na5`1`[A40Nj@608BJ0P2@TP40SI0008^D
0025X0@0PZ`<07Ng4`1[^Bh0D<1=04ZaDP15X600A9]V04NJGP1;VEh0BIQN04^GHP1@T6D0CXeX04^>
I@19SFL0Aj1P04bbD`1E]SH0Hl0Q0080JL0K02L0K/0H07705`1c`1P0JkHH06jh501_]QT0K;4P06B]
;`1J[CD0FZlb05N`=01H/T00Ek1:052_E01CZ5T0EX]R06j7G@2MO5l0NhiS06>2L@1/NFd0KW1[061f
I`1/JFL0Sf1I09UQD`2LHe40XWAD0:MlE02:VT00Nj8P08NJ3P2?S000SXP008^1002?O@40UY0E08jP
7P29XBD00P2:X2h09`27Ybl0S:@i09:S=P2@X3P0S:0b08RT<`22ZRh0PKDV08707`21`R40O/0^07^j
?@1kYTT0Mja?07^/B01k/3T0O/0S07fi:P1n]Ch0O:a307>gC01/_4h0LL1707JiBP1lYdT0N[Hm07Zf
=@1mWcH0Q9Pc08NJ;@26WC40Oi`[07jK:01lWBX0MJDV07RS:`21WcT0NZM006fTA`02066]AP0W05Vk
@@1B^Sl0BKe904?7E00nadH0?LM103[:BP0ka4h0A;YE04faD@1<YU00BJM904FTE@10VF00?XQJ041l
E@16LET0?gMF0421F014REP0BIIE04BOD@0mTe`0=IeT03>RG`0_ZeX0=;1N03BcF`0e[E@0>:M;03RW
A`0f[4/0=:Y002nZ@P0_Yd/0<ZY>03:ZD@0eZ500=jE60080?9`Y00D0@8PJ04=f3017H`@0BUD004e=
000204e9000D04i5001;@P00@S`003df000j;P00=RP003<W000`9`00;28002LM000R6`008a`002@J
000P50006A8001H=000?20002PH000H40002000Q000000`0oooo000:0?ooo`0D05^?D@1JSTl0G8i5
05n=>`1NTCT0HiHk062J>P1JVST0FYXh05VH>01IVcL0E9ld04>V;P0`Ybh09ZTe02^Z<`0`ZRl0>:XX
03^Y8@0mZaX204J/6@0W04j^5@1H[A80Gj/D06FX501QZA40FjX@05ZZ3P1HZQ80G:LG062T5`1TXa@0
Jj<H06^V5P1/Ya@0JJHF06RU5@1YY1H0Ij8I06bO601`W1/0LiPR07BH7`1dUaL0LITB06VJ5P1TWAL0
IIlG06FQ4`1SX140G:4J05BU901@Z300B:Xe04RW>018XSH0@j0f04:T=`12YS@0AjDe0080Bj4`02L0
CZ4]04fS:`1<Y2d0C:@d04jR@P1>XDd0Cie:04bRA@18YC`0BJXe04V/=018ZcT0B:a004NZC012W5`0
@XYY04:1L@17NW<0Cf]g04YcMP0oMWX0?7]j03alN@0oOW@0@Ga[04mgH@1PKeh0JViR05YgH01BNUd0
BY1I04RIE`16WUP0AYMD04V=E`18O5h0BX1R04>8JP14Sf@00P1:TUL09`19VU80BJ9?04^W?`1=[340
Djla05Ja=01C/c<0E;4a052^=P1G[S80E[0[05Ja;`1H/C00G;8S05n`701J/240Fk0V05^_8@1J[B@0
FJPX05jW8`1RZ1X0IJTD06bR4P1aVQ@0KI/B06JM6P1WX1/0JJ<O06JW9@1UYbh0HZ`V06F`901V/BP0
IZl^06F^<01S[B`0Ik4`06Nb<@0206>b;`0W06Jb;@1X/Bh0JK4`06Nb;P1Y]R/0JKLY06S08`1/^B40
KKDT06fc8`1]/bH0Kk</076e;01_]b@0KkLH06fe5`1/]1d0K[8T06bb901[/b00K[@J076b601/[AL0
JJdN06>Z:P1T[bT0K:PY06^[8`1UYQh0IZXI06bZ601ZYaX0K:HQ06^Z7P1Y[Ah0JZ`U06j_9P1_/2<0
M;8I0080LK0C02L0KK4=06Rc3@1Y/Ph0Jk<@06fd3`1V/`h0IK@B05nb601L^240G[LS05jd:01X/aX0
JK0D07J^3P23Y@@0RI/1096E002AR`00SI4008VL0`21[PX0MkPC06fh:01F`400D[I804^_D@17Z5@0
BZAC04bPE@1<WeP0BYmH04nRE`1@YU80CZM<04^TAP1B[d00G[Th06c09@1_`1/00P1_`1P09`1b`1X0
ML0H07C0601_`1L0L<0H06jd6`1/[R80KJ`/06R[<01N[300G:db05j_?@1O/dP0F;5A05J]F01IW5`0
JYIG08B5G@1bS5h0GXUV06>5HP1VOfP0IGY[079WK@2<FfX0VV5R0:=SF`2OKe/0VgQO08>F>`1kXQP0
RID:08j9002>Q`00TX8009R60`2KUaT0Tih]09:S;P0208fM<P0W08fM=P2@XSX0Tilj08jM>`2=WSL0
Qj<f08>g;`20^RP0P<0P08?07P22`240Pl0_07nj?P1m^d00O[Q207fj>020`2L0NkdU07fh>`1o[DH0
MkI607;0AP1h`4<0NkXo082b?P23]SP0OJ`g086T=`25XS00QjHY08N/9021Zal0PJ`J07nZ7@1i[R00
N:dU07f]<01dZc00KjLc0080J;4e02L0H[Pg066k=`1I`3X0ClE104_4>P1:`cH0AlHm04[5?01;`cT0
CK/o056a?`1?[3`0CjI504bOB018V4@0B9A704^BC01:UDL0CIM8056OB01<YTL0BJ]904>XC`10[5@0
>jiD03VaC`0j/E00?:e<03^XC00mYDX0A:M303jX@P0kYdD0>jE903JNC@0gW500=Ia=03RL@`0kV340
0P10RAd06`18MP/0Cf45055E0@1ACP00D4/0051<001?BP00CdT004U30013?000@3H003`b000h:`00
<bL002lT000X80009aT0028H000S600081L001`F000G3P004P/000`70009100010800040000Q0000
00`0oooo000:0?ooo`0D05fB=@1JU3P0FY@e05ZF<`1MUS<0HYTn06:L?01NVCH0HYTc06JG;`1TUbh0
G9`Y04^T9P0jYRL0<ZH/032X;P0fZB`0>jHW03bY8@0oZad2046]600W04R^4`1@ZQ<0FJHF05jT5@1N
Y1<0HJLC05nX4P1NZA80GjDF05nS5P1WXQL0L:0H06nR601cXaD0M:HF07:S6@1`XQL0JY`H076I5P1g
U1X0Mi8G07V@5P1eUA40MiXB07VE6@1aUa`0JYLL072H501]WPl0I:4F05^U:01BYbh0CJPc04bX<P1;
Z2/0B:H`04RT<@1<XC40CYla0080CZ0_02L0CZ4_056R;`1=YBl0BZDg04fU@01?YDH0Cj9504JT@@16
YST0AjT`04ZX<@19ZCT0BJY504BVE013VFD0A8a/04F4L018O700C6i_04EcLP12MgT0?gYe049jLP18
OVd0AgiY051kH@1HLel0F75Q059iH01:PEl0AI9F04NIDP19V5<0B99C04R9F019P5l0B8YN04JCG017
UUD00P19VD`09`1=XTL0D:Q704n[>@1@/2T0Dk0V05Nb;@1H/Rd0EJhZ05:^<@1F[Rh0Ek0T05Va9P1N
/2X0G[0Q05n^7@1O[200GZdX06BZ8`1QZ200HJ@Y06:S901UYQ/0KZ4F07>M501dU1L0LiPH06fM6@1a
Wb00LilT06jT:P1ZYB`0K:TX06^[9`1[ZbX0JJ8`06NU=01WZ3<0JZ/f06^a<P0206^b;P0W06ja;01]
[Rh0KJhb06^b<01Y]bd0JKD^06Ze:`1Y]b/0J;HW06Rb9@1^/RP0KK4b06j^;01`/b<0K[<Q06ja7`1_
/1l0Jk4U06^a8P1//R40KK8M06V]701Z[Ql0JK0T06R/;P1Y[Bd0JZ/[06^Y9`1UYb@0H:lS06F^9@1U
ZBT0IZ@X06^U801WYRL0IJ`Z06R]8`1[[QH0L:`?0080L:`=02L0M:h906n`2P1d/@X0MZd707Nb201^
]0d0JKD@06Jf3`1S]a40IKDG06>b8P1[[QH0L:d@07ZY2@21ZP80RZ4008nD002@S@00Si4008VK0P23
[`T0NK@D06nc9`1I^3@0E;Xl052hAP1=]4X0C[1<04Z]D018[U<0Bk1C04bhB@1@`3/0DKd]05Nh8`1S
]B40KkPT07>i7P1b`1`00P1a`1h20730800N07?07P1Z`1P0K[DH06fd701Z[2D0MZP/06jZ<01N[3<0
G:/i062^@01M/Tl0E[1D05>]G01FYEX0HYiG07:7GP1VQV40GhYP05j<H@1PRFP0JX1a07e]MP2=G780
W5i[0:eWI@2RJFL0Sg5T082B=`22X1<0RY@70P2>R@001@2EQ`40VID809fM802AVCX0Tj0i0080TiHl
02L0TJ<f09FZ>P2AYC`0S:9208NP@025Yc`0PL0b07o0:P1o`2H0P/0M08S07@25`2<0Q<0_08;0>020
`3T0O<0i07_0:@1l`B80O[df086e@@1j^d<0NL1007_0?P1l`3d0N[Tm07b^@020ZC/0PjLh08:T<@25
YBX0Q:HS08FX7`22Z1h0OJLQ07ZV9P1eZBT0LJl]06j_<@1a/2l00P1/]S009`1/^C@0Hl4h05W4<P1@
`c<0B/8a04_1=@1;a3/0Cl@d04c4;`1;`S@0Bk`c04jd<@1?[3X0DJ8m052K?P1?W4L0CjI805:]@01?
/TL0B[E?04>eE@12/Eh0?JmO03Z^JP0h/F`0>;AS03N_F`0fYED0>J5K03bWE`0nZ4/0?ZM603^UD00k
XET0=iIK03>@FP0cT5@0=i@j03Z=8`02045h3@0J04eR0@1CE000DdX00599001CCP00Ddl004m;001<
C`00AdD004E20012?000?cP003Lb000c;000;BD002XO000U6@008QL001lH000P600071@001H@000B
2`0030T000T400030003000000800@007@00000<0?ooo`002P3oool0501QVB/0F9/]05>L;P1FVc40
FYXi05bM@@1OWSh0GY/f06BH;`1/T300K98W062H901CXB80@:DT03JV9P0bZ2T0>:XY03VZ9`0k[2@0
>ZhO0P0o[AP09`0n[AD0A:`F04JY601>Z1L0DZLF05JX701HZ1X0F:PE05RU5P1IYAP0HZ@H06ZP701^
XAT0LJ8C07>T5P1^Xa<0Ij4A066O501^WQH0MiTI07VD601cTa@0LiHB07ZI5@1oUAT0Mi<O076F801]
UQ@0J9/;06FS601IYbD0DZP]04bY<P1;ZRl0AZ`Z04BZ;`17Y340CYha052L<@0204nL=00W04ZQ<P19
XS80AZ<f04FU>P17Yd80BjE004jR@013YD00@JPj04:[=@15ZSX0A:M6042VC`0oX5l0?iI[042?L013
Rfd0AGi^04I`L016LG80@7Mf045lL@14OV`0Bh=W04mnIP1?OV00CgUR04aeH`18N6D0@h=S04:DF@15
VE<0AiAE04N:F@19QE`0BHEO04VCE`14WE80Aim=0080BZ5502L0CZU004n/?`1C[C80E;0R05Fc8`1G
]2X0E[8X05Bb:P1B/2l0Ek0]05V_8@1H/200FJhT05Z/8P1K[200FZ/W062Y;@1/YR80IZ4R06>M:P1S
X2P0Ij4M076M6@1gUAT0MY<L07JI7@1aW1/0M9lS07VN:P1^Xbd0KZH[06fY:P1/ZbT0JZX[06^R<01/
Y380K:Xb06f]<01^/b`00P1`]2L09`1_/bT0K[0/06bb;P1Z]340K;H^06ff;P1/]BT0JKDW06Zc:@1/
/R`0KK8[06f`;`1^/RX0KK<V06Vb8P1X/b40K;@L06^d8P1Z]B@0K;8Q06Va7P1V/1`0J[4N06Z`8P1/
[bT0JK4]06Va;P1]Zbd0J:P/06B_;@1M[cP0GJ/f06BU:P1TYal0I:LY06J^:@1Y/QX0L:h@072]2P02
07F/2@0W07R]201e[PL0Mk4607bc1@1j/`L0Kl0=06_03P1Z`0/0JkH=06Rg501W]Ad0KK<C072b401l
/PT0QK<308^X0@2>V000SXh008ZB0027VP40QjL807nc3P1k]Ah0IL0W0670;`1K`3H0D[/n05>h@01D
^3h0D;M6056jB01C`3h0FL4^05[38@1O`Ad0JL0M07707@1``1l0L/0O0080KL0P02L0K/0O06S07`1`
`1/0LKXG07Fe5`1f/b00M:XU07>V:01`[B`0HZhd062a>01R/c`0H;E605RfC`1F/ED0FJED05nLDP1/
QUd0IXQL05j?GP1PV5`0GIAT06V5KP1oKWL0TUib0:1QK02]JV<0X6aT08=bGP1oTbl0QYh<08jE102D
S000ThX009f?302EUQT0ViXZ09ZG?@2BX3T00P2=W3L09`2AZc<0T;Dh08f^?@2;ZSl0Q:8m08>V=021
]Rh0Q;/W08Bk8P28_1T0RK`E08O05`25`2@0PL0Y0830;P1o`2h0P/0Y08;0701m`2P0MkLj07S0?01n
`3@0Pl4h0870=021^S<0PK0i08>^=023[B`0Q:dS08VZ8028/Ad0RJ`L08B_7@21ZR<0Oj<Z07ZX:@1i
ZBL0NK0V07Ze9002076g8@0W06jl801T`280G<8Q05K39P1C`2P0EK/b04k1?P1?`cT0Cl4b04o0:P1=
_RD0Dk<T05V/9P1NYRX0HJ<]05jU<P1K[3H0E[8g04nc@01;]dh0B;5G04VVG@15XUh0@j1V03nQJP11
YF80?ZAJ03jND@0mXE00?ZA8042R@P10X400@Ym204JMA@10V4H0?I=203f><`14Qb<0BW`A0080E6T6
0180EeP005A:001?@P00Cd<004m7001AA`00D4H004Q80016@000A3/0044j000o=000>bl003@X000/
7`00:Q/002@K000P5`0201lH000601XC000F3P004@T000X500070P000@008P00000<0?ooo`002P3o
ool0501TUbd0I9`X05fO9`1MWR/0Hid^06NQ<P1XX2h0JiX/06nG:01aTb/0KiDW06:M8P1BXb80B:PR
03Z[900g[BT0>:hZ03R_:@0j/2T0?k4T0P10[ah03010/1X0?k4J04B^6`1<ZaP0D:XE05NY6@1LYaT0
GjLG05nV6@1RYQP0IJHE06bU5@80KJDB01T0LJ<E06nR4P1_WPl0KYl@07BO4P1hW1H0O9PG07JD4P1d
V1D0NI/F07jJ5P1gV1T0M9TH06fG4@1TW@l0HJHF05RY9@1DZ2P0DZXZ04fZ;018[BX0BJP^04fT;`1B
X300Cj8_0080C:<b02L0Aj8d04NT<`16YS40AZLc04NX>017YS`0AjLn042W?00nZc`0?:`o03^YAP0m
Ydh0?:AI03^OH`0nU6d0@91_04:9K012P6l0@g5_04IfL@16NG<0AWe`04YnI@1@PF80FG]P05IlH01?
Of00AgiQ04B4HP0oSe`0@ia@04>NBP18Ue00AheI04R=G017Se`0AiQA04FOBP17XT@00P1;YS`09`1=
ZcP0DZhc05B`9`1F/A`0FK@K05Nd901D/RH0Dk4T05:c9@1E/RH0FK4N05Z_7`1K[B40FJ`T05f/8`1P
[BD0I:/X06bY901/XBL0JIh^06JM:01^WAd0M9HM07RB6`1jTb80N9XP07RL8`1fW2/0NYd^06bT;P1Z
[RX0L:lZ076`:`1b[Rh0LJ`_06j/;`1a/Bh0LkD[07Fd9@0207>f900W07Bd9`1`/2h0LJ``072/<01`
[R`0LZdX07Fa9`1d/BH0M;4W07B_;01`[b/0K[4Z06je:P1_]2P0JkHO06bd701_]AT0L;DL06fe901^
/R<0K;4P06b^701[[QL0KjhB07:^5P1`/RD0Jk4/06f^9P1Z[Bl0IZ`l05^]@P1OZ300JJLQ06^Z6`1/
[QP0L:hB07B_3P1i[PT0Njd60080OJX500H0O:`407b]0P1n[`@0Nk<607Ng2@1/`0l206O04@0O06K0
4@1V]aH0HkDS06be5@1^]1<0Mk8=08:c1`28[0@0Si`108jD002=T`00RiD008ZN0029[0T0O[@I076h
801[`2L0H[d^06:k;P1N]Rh0GKP[05nh<01Q`380I/0^06O0:P1W`2L0IL0W06W09@1]`280K/0Q07?0
8P0206c08`0W06g08P1^`1`0L;/E07>c5`1h[Q`0O:HS07fU:01eZ2P0KZXY06V/;P1T[cD0H;0b05Zb
>`1D/d/0EK1A05RQD@1OTT`0J7UO06B4G01LU680G9eJ066KGP1ZQ6L0NV]b09ENLP2VI6/0ZVmK09a_
F`23LED0P90Z08JL1`2?U040UHh009R?0`2SUa40V8hX09VA=P2KTd80Sj8i0080Sj0g02L0S;@e08be
=P28[3T0QjY108RX=P26ZBd0Pk8Z08Nh902;]b00SKDH08jh4P2<^Q<0RL0J08O07P22`2D0O/0W07o1
9P1o`1h0Nl0R0770=@1g`3P0Pl0a08K1;`26`2d0P[P[07ne<`20]2`0P[<S086a8021/Qh0Q[DL08Je
7P22[b40Oj`Y07jW:`1kZ2`0OJ/Z07^_9`1i/b800P1e^1`09`1_^AT0I;XG05[06`1F`b80E<0Z05Ri
=P1A`480CL4l04_1>01:`bP0AkhN04fd7`1D[1h0FZ`Q05N/:@1E[C80DK0o04VbD011/5h0?[5_03jX
M010SGD0@8Mb03j7MP0mQWP0?hmZ03jDGP10VU80?Z1A03jO@@10Vd40@IM904BIA@17V440@IDl04:F
=`11Rb<0CGl?05M`100205iN000J05Y@001>@`00BS/004Y2001;@`00BD8004]40018@000AC`004<k
000o=000?2l003T[000g9`00;R0002PL000V6`008AX002<J000O6000714001D=000?1P0020@000D1
00010004000000800@007000000<0?ooo`002P3oool0501TUS80Ii/W06BI8`1PV2H0GiXZ062L:`1Q
VB/0I9@[06b@;@1`TB`0K9LZ05bK:01@XBT0A:@Z03ZX:P0eZb`0=Z/_03ZZ<@10Ybl0@ZP^0P14[Bh0
4013[BP0@JdQ04>^7P1?[1/0G:XL06>X6P1WYaT0IjPI06RX7@1TYa/0HJDF06BV3`1WY`/0IjH=06ZT
501/XaD2076O400E07BN3`1hWaH0MYXG07FG501dVQL0LilH076Q5`1aX1P0LY`@06ZH401RWQ@0HJ@G
05RW8@1HYRH0EZLX04jY:P19Z2d0CJ<`04fR<P1?XS80C:@c0080C:De02L0B:0h04ZR<`1;YR/0AZT]
04FX=012YST0@:Dn03fV@00lYT40>:M703RTD@0gXEL0>Z1N03fJH@0nT6T0@8U]0421K@14NVd0Ag1/
04IeL017Mg00B7Q^04igI`1HM680J71R05ihH01@OV40AHEO04:AF`12We00AZE504FQ@P15UDh0B8mG
04J@F`17TEX0BI1?04VKA01<XT000P1=YcL09`1@[Bd0DZhV05Ba801J[aX0G:lK05R_801G[bH0E[0O
05Fa7`1I/2<0GZlO06:]7P1QZah0H:XT05n/901S[B<0IZ/W06bW9@1`XbT0Kil/06nK:P1jUR00N8lP
07b>8`21TBH0OiLY08:F;01oUC80NiXb06fW;@1Z[RP0M:hZ07F_:`1d[S00M:ha07>]<01c[b/0LjlT
07R_8`0207V_900W07>a:`1a[Bl0LZ@_07:S;P1dXBd0MZDY07V/:P1i[RX0Mjh]07J]<@1b/2l0Kk4_
072c;`1_/bd0Kk<O076c701]/R00JK0R06N`:P1U/Rh0K:lV07>[7`1bZaT0L:`?072a5@1Y/RL0HJhb
05f_<P1IZdP0EZQE04nYD01NZ340HZXV06F^6`1Y/100L;4<076d2P1b/@T0NZh60080OZd202L0OZh2
07jb0020/`<0Nk@707Bg3@1Y_1<0Hk`F06C05`1N`1T0H;DM05jd:01U/QT0I[@D07Jc3`1k/`X0Q:/7
092Q0P2?VP00SYH008ZH0027V`00QJD907jb4@1``1P0KKhQ06Bo901[]RH0IKDY06^d:01]/R`0KKH`
06bi<`1X`2l0JL0/06[0;01W`2P0Jl0P06O0701[`1l00P1U`2009`1/`1l0KL0J07305@1b/aL0MJ`J
07N^8P1h[R@0M:`V06jZ9`1T/BP0I;@]05be;@1=]SP0CKY<056cD`1DWe40EI9?05^0H@1IQf00FYAR
05^QE@1PWE/0KH5S08AYJ@2JHf/0YVMW0:E`G02JL580OgE>07j<9`24T`H0SXl009JB1@2KV180Z9TN
0:^@902KTC/0UYQ408Z[?`0208bZ>@0W08^b=`29^3P0Q;8n08F[@020Z3H0QZd]08Rf9@2=]b40S;LP
08jf7@2;]aT0S;XB08Zm4025`1@0Ql0O08G09021`2H0OL8O07W08P1g`2d0O/0]0833:@20aBX0P<0W
07nl8021^1`0Q;HH08Bh5`22]aD0Q;TE086g6`22/al0PZPN086[7020Zah0PJ/P07n[801k/200NK@O
0080N;<I02L0MK<D06bd4`1W_1X0GlDO05g1:`1J`3H0FkPo05Ng@P1C`c/0Cl8Y05:l6P1F]1H0FJdJ
05ZW7`1IZb/0E:/g04bYA@14[540@:]P042XJ@17ZUT0C9]9052>?P1@Qcd0CXU004R;?P12TD40@iI9
04:LC014V4<0@i0f04J<<@18QRD0C8LN04j47@1AOQP0EGD@05UY1P1LG0400P1KC`006@1E@`00BSd0
04Tj0016>P00ASd004Tl001;@@00BSX004De0013=P00?SH003`a000i;P00=2L002lP000Y70009AL0
024H000N5P00718001D>000?2`002`@000D3000100008`00000<0?ooo`002P3oool0501VWRP0JJ0U
06VR901SXR@0Hj4V06:Q9`1RWBX0IYP]06ZF;P1]U300HiT]05FM:`1=X3D0@ZHa03VZ<P0c[340=:db
03^Z<@0lYc00?ZTe0P12ZcH09`10[S00?ZhY03j]8P1;[ad0FjdO062[7@1UZQT0IjXH06VY7`1XZ1/0
Gj/D05bZ301KZPT0GZT@06FW4`1VYQ@0L:8@06bQ3`1^XA@0L9dJ06bN601]WaL0KY`G06VQ601VY1X0
I:8E06FQ4@1XWa<0IZ<C05nW5P1G[1d0FJXP05NV9@1BYRX0C:Ha04RV<`15YC@0@:Le046X>P02046T
@00W04:S@012YCH0?ZH]03^X;`0fYcH0=ZM203JXAP0eYd/0=:M?03:RE@0bVE/0<iUP03JII@0iUfL0
>haY03f3J`0oNV/0@GA^04E/KP18Kfd0Ag=a04QbKP1CJfH0IFQW07MVI`1SLFD0D81R04B@G`13WEP0
AZM904NY?@16YDD0@YIC04>?FP15SU`0BI1J04f9C`1>VD80DJDk0080CjXe02L0DJdV05:_7@1D/1X0
FJlH05Z_6P1G[B80DjlY05B_7`1D[ah0FK4S05n_901S[1l0I:hP062[:01Q[BH0J:lS06Z[9P1]Yb`0
L:@/07:Q;01iVRP0PI0L07^98@1lRBX0OXl[07Z@;@1nSRd0NY8f07JL=P1^[2h0K[<V07F^901f/2@0
MZdW07R_:@1g/BT0M;0W07J_901j[R<00P1i[b<09`1g/BD0L;<Z072_9P1b[b<0MZ`R07Z`7`1n]Al0
Ok@O07Vd8`1h/Bh0M;4b07:c<P1`/b/0LK<S07Fc7P1g/Ql0L;8Q06b^901W[RT0I[0]06f^901d[Ql0
L:lO06bc6P1^]1`0JjhX06N[;P1XYBl0IIli06FR>@1WYS00IZTR06R^6`1[/AL0LK4F07Fc501b]1<0
M;<?07^a2P02086b1P0W07nb1P1i]@L0MkL507Vc1`1f]@X0JkL@06Nf4`1Z]a@0IkTD06bd5@1[/1`0
Jk4D06^d401g/@`0OK<<08Ba2P2EX`40TY`008nJ002<VP00RiX008BP0`1o/0X0MkT@076n7`1[`2H0
KkDZ06jb<01i/2l0Ojha07V`<@1b/c<0L[La072i<@1]`2X0K<0R06k07@1Y`1P0L/0J0080K[`L02L0
Ll0N07Bh6P1f]1H0N[0G07FZ6@1d[Qh0M;4S07JZ901^ZBH0Gk8U05Re:01G^340Bl0o04ngBP1D/dh0
E9Y:05NBB`1GS5T0E8YK05Z=F`1NVdl0I9UE07UhF`2BGEX0XfEM0:Y]G`2TJeP0Ug1?07UhB022S1l0
RI86092<0@2EU@h0UidM0:VJ9P2^Sb/0VIPo08jPA`29[d000P2:/CP09`2;]3P0Q[Lk08B_?`25XS`0
Pj<f08BU<@2:]B@0SKLT08^d9`2:[R80SK<L08ne5@2<^180T;PC08W06`24`240P/0T07_08@1h`2<0
Nl0[08;0:01o`2L0N<HZ07K1:P1i`1`0OKTG08Fi5P28^AD0Q[@A08Bh5@20]1/0OjhM07nW6P21ZAP0
Oj/L07fX801iXb00NJPR07F[7@0207:]5`0W06j`401Z/Q40JKhN06?38P1N`Rd0F/0f05nf?@1K[d00
DL0m04o39`1E_AH0E;HG05J^7P1BZ2X0DjXi05>YA`1:WE<0AImT04:PK`12X6`0B:=<04fC:`1DPQX0
EgHA05=l601<Oad0@hTW04>A>`11UDH0@I180465<P14P1l0BG@?04]b1@1<K0<0DF@105EK0@1GD@00
EDX00080CdL001T0Cch004a00018?P00ACL0048b0016>000Ac/004Hl0014>P00@SD003hf000n<P00
>S4003@Y000]9@00:Ah002DI000P5P00718001L=000A20002`L000T400030@000@0000<0000000<0
0@000000000000007@00000<0?ooo`002P3oool0501[WBP0JZ4V06JU9P1WYB40Ij4Q06NR9@1UX2H0
JJ0X06nK:P1/VbL0HIdV056O9`19Xbl0AZH^03fZ;00g[R/0?Zl[04F^9@19[b80B:hT0P15[bP09`15
[RL0?k0U046`8P1;/B40FJdT062[8`1T[1`0IZdI06f[6P1[ZQ<0Hj/?05V]2P1IZ`d0Fj/@06>Y4`1Z
YQ80LZ8@06fO4`1^X1X0KihK06^Q6P1_XaT0LZ4G06jP6@1^WQX0K9lF06^Q501[XaH0JJHC05n[5P1G
[B40E:/T05:W:P1>Ybl0C:Ta046/<P0kZS@0>:Xf03R[?`0203fY@`0W03fW@P0lZSX0>J/e03FY>P0a
Z400;ZM802nZC00]ZU40;jMD032TF@0bWUh0<imO03>PG`0jWV00?9IV03Z:I00oP6@0A7YW04UeHP1<
LfH0D7IU051cI@1FKf<0GV]Y06QXJ`1GNFL0B8aR04BJG@16XU40BJU504^Y?01<YTP0B9IG04F@G`15
Sed0B8aK04b3D@1>UT40DJTj0080DJhe02L0DZlW05Bb7`1H/Ah0G[4L05fa701K/280F[8Z05Jc8P1J
/b00F;@T05Za9P1P/200HK4S05j]:P1U[BL0K:dW06n[;01aY2l0Lj4W07^Q8@22VR40RY8E08F88P1k
Q2h0NXT_07F>:`1jS2T0LI8d06nR<`1[/bd0KKLU07Je7`1g/ad0MZlR07Nc901f]B@0Lk@T07:h7`1g
/al00P1f/B809`1b/bD0JKLT06^e7`1_/al0MK@N07fb701m]QT0O[PM07Vc901g[Rh0Kjhe06fb<01_
/bL0K[<R076c8P1b/B<0Kk0T06V[:P1T[c00IZd^06V_9`1//R40JK8R06Jd;P1P/C<0GZPf05nN?@1P
USL0HI4i06JL<P1QYRX0HjhP06Ba6`1[/al0JkDU06jc8@1_/Q`0MK@E07Zc400207Vc3@0W07Je201`
]`T0LKD907:c1`1`/PL0KkH<06je4P1^]@l0L[<>07Ja4@1e[a80MK0?06jb301o/@X0Ok<>08N`302F
Z0<0UZ<109>P002?X000RY/008JO0P23Z`P0N[D=07?06P1^`2@0KkD[07Fb<021[c<0NjXe07JZ<`1`
[SP0L;0d06ne<`1``2d0K/0R06[0701Z`1T0Ll0H0080M<0J02L0M<0M07Fg6@1c/aL0Lk4I06j_7P1/
]200M;<R076`8@1W/2<0G;DT05:f9`1@`3@0C[M105>fB01B/dT0EIm905ZLB@1KVE00FI1B05N;E`1M
WU<0IYMI085aF02EEeP0Y6AL0:M/G02QKE@0U7I=07f;>`26UAT0TiH509BG2@2QXa@0[YPO0:jF;P2Y
UCd0Tj=708JZB@24/S`00P26^SP09`22]cd0Q:Y108JS?02;WCd0SZ0d08nS;`2@YBP0Sj`Z08fb;P2?
]1h0T[HG09:e4`2A]a<0SKXA08fk4`28`1`0Ql0R08708P1n`2@0P<0Z08Jl9P22`2D0O/D[07_2;@1j
`2H0OL0M08;07@21^ad0PKHG07nc5@20[aL0PjdE08>U5@23ZAD0PZdI07jS7P1lXB80Mj8T07FW6`02
07FX500W07>Y3@1`/100J[`K06G07`1O`bd0G/4]05fm<01I`2d0D<<[05;07@1H]QD0FZ`B05bV6@1I
Y1d0FZ<R05RU;P1BYT40CZYC04f/F`1@YTD0GiTR06R24`1UK`/0H6P605eY2P1GK0d0C7XN04R3;P18
Q3@0BX4_04ag7@1BK@h0Df@605EM0@1FF@40Ee<005I:001CB000D4800080DD0000H0CC/004Xi0017
>`00AC80044`0012<P02040f000A044d000n<P00?2l003`_000k;000<BP0030Q000X6`008aT001lE
000K4P005Ph000l80007100010<000<1000100000P0000001@0100000P40008100020@000@0001`0
0000303oool000X0oooo01@0LI`Y06RP:@1TXbH0IJ8R06>R8P1MXBH0G9lW05nP:01WX2H0I:0O05VP
801;XRD0Aj<Z04JR:`0nY2L0?JHS046X8P19Za/0Cj`F04j`5P80B[0L02L0@k0Q046`9@12[RH0B[0Z
056`:`1A[2X0F:`P05^`6@1T[1@0I:l>05f]301E[Pd0DJh?04n[4`1EZAD0FjLC06FV4@1ZY1@0K:4F
06jR5`1ZXAT0JJDI06RU6P1XXA`0K9`E06nO4P1^XQ@0J:HF06>W5@1I[AX0DJdU04^Z;015Z300@:Pe
03RY?@0c[Cd0;jXm02fY@00fYd800P0hYT@09`0gYDH0=ZE103FX?P0dYT00;ZE402nRBP0_YT`0<jM@
03:VE00bYUL0<j=F03>TE@0dYE@0>J=I03^MG@0lTV40@8IP04MoHP1>O680EWIR05MgG`1IMed0Fg=L
05U`G`1HL6D0ChET04NDH015WUX0BJ=A04bX@P1BYCh0CJ1=04^FFP18SV40AXeK04J6G019O5D0BY57
04jW?P02052/>P0W05F^<@1F/2L0F;0U05^/8P1N[Ql0G[4S05f`;`1I/Bd0F;0[05Jc:01L/BP0GjlU
062`9`1O[B/0Ijd]06N/;01YZ340JZ8c06nR8`1fXQd0P9hJ08NC7022SR80O8T`07j9<P1cSBh0Li4]
06VI<`1WYRl0JZlT076c801d/b00Mk8P07Jb7P1g/R00Lk8R07:c8P1b]240LZlT0080M:hU02L0M;4V
06nd901a/B80M[4R07Jb7`1j/Qh0Ok4O07j`8`1i[RH0MZP]06n/<P1a[C00MJhY07B^9P1_[RH0L;0V
06^b901X/2H0J[0Z06V_:P1[^B@0K;TM06jd901V/3L0GZdi06FT=P1WV3P0IIXf062M>01RY380H:hW
06Fb8@1Z/RH0LjlW06f^:@1^/2<0LZlK07Nb501k]QD00P1m/Pd09`1h/`L0K[<;06nf2P1^]0P0L;87
06nb2@1`/P/0LK<=07Fe2`1h]@`0NK8=07Vc301e/`/0O[49082a2`2:[0P0U:T209JY0P2DY040Sj00
08nM002:W`00R:L308>b1`1h]`h0KklJ06jo8`1b_RD0OK4^07b/>@1hZCP0LZ/g07:]<`1b[c<0MK@_
0730:P1^`2<0Jl0O06o07@0207;07@0W07?06P1e^aL0M[<E07Ff701`]2@0L;LS06ne801[/al0G[@V
05Ze:@1?`300CkPg04jf@P1@]4/0Dk9>05>`A@1K[400HjE805fJDP1HUET0GYYK06B<I022L680VEeT
0:1ZH`2SK640WfUJ08YmB`1lW2T0RYdC09ZJ2P2NZA<0ZJ/G0;JM7P2/WC<0XYQ308jVA`23ZD00Pk0g
0080P[Dh02L0P:]308:MB027Vch0TI`j09BP=02HX300U:<[096]:@2B]BD0TkLJ09Fb5`2G]A40TkDA
08ff4@2:^1<0R;`K08K08`22`R@0Pl8W08?1:`26^RP0Q<0T07k4:01laRT0N/8[07g09021`2@0Ok/Q
086c7024/A`0PZdJ08BZ5025Z140OjTC07Z[5P1lY1`0M:<Q06jT901]YAd00P1bYaH09`1^ZA40JJhB
06Ji6P1P`B@0Gl<_05o2:`1K_RL0D;hW04Vj8@1A^240EK0G05ZZ401MYAP0G:0H05RM5P1@X2D0CJe0
04VbDP1=/e<0F:LX06N;2@1XK@00Heh005mH001LE@00E5T304iX5@14MBL0AWDU04]b701?I0`0DUP1
05IB001DC000FDH00592001?@P00D48004hn000204`o000I04Xh0017>000BCH004Dc0011;`00?S00
03d_000o<P00@3<003`c000h<000>2l003L^000c9`00<1l002LK000S6@0071<001L?000C3P003@P0
00P400040P000P400040000200000005004000020@000P400081000100007000000<0?ooo`002P3o
ool0501aXRT0J:0Y066T9`1OYBH0G:@V05NS:01IXB`0HJ8/06>T9`1SXR40F:<P04jR8@16XRL0@Z8U
046S8P12YQh0AjXJ05>/5P1F[A80E;0A0P1;/QH09`16/Ad0A:lT046a:`15/380@jha042];@19[2T0
DjdP05J_701E/1D0D[8E056^4P1:[Q<0AjdG04N]701=Za/0FJTH06RU501aXQD0LZ@G06ZT5`1UXad0
HZ8Q06FP7@1^X100L:8A06bT4`1XYaL0G:XI05JZ9@1?Zbh0AZXa03^[<`0cZSd0:Z]902F^B@0S[TD0
:Ja402bXA@0202jUB00W032UB`0`YDh0;jI9032UB00]YDT0;Im<03:SDP0dYeH0=:UH03FYF@0dYeD0
=JIA03NWD@0hZ5H0>J5K03bEH010RV<0B7mU055jJ@1MN6D0GgQN05ejF01KNEL0E7MJ04QiI@14S600
@i]P04FNG@19YDl0C:Q304jQ@`1=WTh0BIML04RAGP14SUh0A8AL04AiG017STd0BJQ10080C[0m02L0
DK0g05F`<01H/BX0G;0X05n^7`1L/2P0FK0a05J`=01F/Bh0F;8Z05^b:@1K/R@0GK0U05n]:`1UZc00
I:X^062V;P1RY2l0JZPS07FU7@1nWAl0QY<P08F=8`22SBl0OXdc07B?<@1^URl0HIl`062[:01V[al0
K;4O076`8P1d/b80MK8Q07Fa8`1a/RD0LK8S07:b:01b[bT00P1a[RX09`1a/2H0L[<V07B_9P1e/2D0
MjlO07V]8`1l[RT0OJ`/07RZ;P1eYbd0LZ//07:a<@1d/2X0Ljd[07:/:P1]/Bd0I[8Y06O0901V]2@0
J;@[06Fl9P1Y^B<0IK0]06BN@`1PY400IZPi06FK?`1OWD00G9e005f/>01O]2l0Jk<]06ja;`1`[bh0
J:Pf06b/;`1b[Ql0M[8K07Nf6`0207Nb400W07Bc301]]A00K;LB06je4P1a/Q40L[D?07303P1c]`d0
N[T;07jf1`1m/@D0N[4807Ne3P24/PP0Pk8508ZY102CX`80TJD109>S0@2@X@00T9d008^R002;Y000
R:l207fg301b`1X0L<0K07307`1f^2@0N;4`07N]=01eZcL0NJ``07J`<P1a]C<0JkTc06W0;P1Y`2P0
Il0V0080Il0Q02L0K<0O07Bh6@1g]1P0L[DO07:i8`1e^200LKDN06:c9@1I`2d0Dl0d05?0>`1>`400
C;A<04baE01;/E@0C[A505Rc@01R[dD0FZA?05NLF@1KUf<0IHMZ07ibJ`2GIVP0VV]V09i[I@2EH680
OgM>07RO802<Va00VZ0A0;2N6@2bXA`0]J0T0:RQ<`2IVD00Rie208:K?P1mWT000P1mWdD04`1oUTd0
RXe908^H@@2@W3X0VI`d09ZQ<P2CZb/0TkLW09Bh7@2P]Q@0WjP>09Z^2`2A[Ph0R[@A08Nj6026_1l0
Ql0Z08[0:P24`2/00P22`2l04P22`2@0P/0P0830:@20`2P0P<0S08C07`24]Al0PZ`N086_7`24[Qh0
Pj`G08B[5@22Za@0P:dE07j[801gZR00LJPM072V7@80KjLI02L0J:XH06Ra6P1W^2D0Hl0b06:n=`1T
]BL0IjdL06JS501NWa80F:@G05NS601IYaL0HJ@D066Q5@1NWAL0Ei`Q05NP:@1HXcD0FZ8Y06FF5@1[
O@<0If<0061C001LC@00F58005MC0@1DFPT0DF8B059Q401FGP`0EU8405=:001AA@00DD4005@o001@
?P00CSh004Xg0019=0000P18=P005`19=P00AcD004<`0014;`00?B`003X[000i;000>bd003`_000k
;`00>B`003PZ000d9`00<R<002dN000U7@008QP001XB000F3P0040T000`5000810000`4000800@00
8`00000<0?ooo`002P3oool0501[XBl0Hid]05^L;@1MWR/0Fj0[05ZM;`1QVS<0JI`e06nN<01^WBX0
HIdZ05bO;@1CWR`0D:8W04jU8`1;ZAl0CjhH05R]4`1H[Q40FK8@0P1D/AH09`1</Al0AK4X04B^;`15
Zc<0A:/e04:[=015Zc80B:`_04f^;P1?[b/0DJhV056^7`1B[A`0DjlI05:^601C[Q`0FZ/J06RW501_
YQ80J:HA06JW5P1UYAP0IZHL06FV501YY`l0IJL=06>X401O[1H0EZlM05B]:01@Z3<0@jXg03N[>`0Y
[4D08:aA01n^CP0Q[DH08Zi602BZA@0202NZB@0W02VXC@0YYU00;:Y<02^YA00[ZD40;jM303:XBP0f
ZTh0=jaA03J/C`0gZdd0=jI;03NVC@0lXU80>YeE03n@FP16Pf40DWYN05]iG`1UMeX0GWUE05MkE01C
O5D0DWiJ04UoH`18RV40AY=O04RKF01:XTl0BjU304jY@P1<Ydh0B9mI04RFG018UE/0A9EE04FDD@15
XT<0B:df0080C;8e02L0D[<f05>d:`1G]R<0F[HN05ne7@1J/R<0F;8`05>c>01G]2d0FK@Y05bd9`1M
/b80H;0T06:/:P1UZBl0I:H`05nV;01TYBX0LJHS07RS7`1mVB80P9LT08B?:`20Tc00O9Hc07FG<@1_
W2l0JZ<f06V_:`1Y/R00L;@M07:d8@1c]2<0Lk@R07Fc901f]2H0Mk8T07>b901d/BH00P1g/BX09`1h
/RH0NK8T07Za901i/B<0Nk4P07Ja8`1h/2L0NK4]07B`:01fZRL0MK4X07Bc;P1e/2h0L:L^072^;@1]
/c00IkD/06C0:01S`2/0IKD^06Rf:`1U/b`0HJ/h066@B@1LWdH0FZm405BYBP1AYdD0EJDo05^`=`1R
_3<0J[4]072Y<@1][C00Hj`h06^a;P1b[al0M[0H07Fd6002072d500W06jc6@1X/280J:lT06nX9P1d
ZR@0MjXQ07:e701c`1X0N;PA07^e1@1n/@40Nk<707Nc3@20/PL0QK4108^X0@2@X@00Rj<008ZU0@2:
YP40SJ8008bV002;YP00Qjh108:c201h]P/0Ll0C06g06`1c_B00MKhV07Re;01e/c80MKH`07Bg=P1d
]cT0JKU106Rg?@1W]cL0Il0g0080I<0_02L0Il0Y06^j9@1a]B<0LKHV06jg8`1]^1h0J;DP05o09`1F
^Bh0E<0`0530<P1<`3l0B[Q>04N`F017[5T0C;A:05>b@01M[TL0EjY@05FSGP1HVV40I8e/07YiL02C
K700VfUY09aYI02:HfD0NW]807ZM5`2CVPl0YiPG0;2F8@2[WR<0Zj@Y09fU=P2@X3d0QjA208:M@@1n
TTP00P1kSE009`26Qe80RHQ=08fF@02?WcT0Uj0g09bS<P2@[c00T[LR09S05`2L^A80V[DB09^d4P2D
]a<0S[LD08Rj7@25`240Ql0Z08Bj;@26_Bd0PL0/08?0:P25`200QL0O08309`20`2T0Q<0S08S07`25
]B00PZTO08>[7@24/1/0OjTH08J[5@21ZQD0P:`F07fZ7@1kZAh0Lj/L076X6`0206nT700W06^/801W
/2<0Hk@[06Vb<01Z[2l0KZ4L06bD4`1ZQPT0Hh@705JA4019W1l0Aj0T04fQ6P1EWQP0EihN05NE7`1C
UR40EIDO05b<3P1VP@40JVh006EL001PC`00G4X005Y<001EC000Dd`0059@0@1DB`40E4P10593001A
?@00BcX004Xe001>>000D3`004/i0017=@00@c400080A3<000@0@S40044c000o<`00>R`00P0j:000
4@0i9P00>2D003TZ000k;000>R`003@Z000`9P00;2@002PO000T6P007aT001XC000D3P003PT000T5
00060`000`0002D00000303oool000X0oooo01@0I:<]05fP;@1JWbh0G9h_06FN;01VVbd0KiL`07BK
<`1dWS00KJ4^06FM;@1OVbl0GId[05NQ9`1CYR00DJXO052^6P1E[QP0Ej`E05F_5@80C[0I02L0B[0R
04Ba;010[3<0AZTg04>V?010Z3`0@j/l04B[@017[400B:]404Z[?@1;ZS00DJ/U05F/7`1E[QX0F:XN
05^Z6`1SZAD0I:LC05nW5P1HZ1`0FZTO05fX6P1JZaD0FjTB05Z/4P1H[1T0DjdI04n_8P1=[Rh0AjXg
03^[@00^[4T09JaA022/E@0R[4l08jY9026ZAP0RZ4d00P0RYU<0100XYED0:ZIC02ZYC`0XZdH202^]
@P0Q02f]A@0b[DX0<Zi?03B]C`0cZdh0=:E?03BRDP0hVUH0>iAL04:8GP1<Oeh0EG]L069iE@1[ME40
G7M?051iD`1<NeH0CgaN04UlIP1;Nf<0BHUP04JDF@1:WTd0BjQ304^/A01;ZTT0BImG04RCF01;UU@0
BJ9:04ZYA`1;[ST0CK0]0080D;8Z02L0E;@]05Nf8@1H]Ad0FK@O05^d801I/B<0E[4_05Rc?01K/Rh0
Gk0Y05n`:P1O[RP0I:d/06RZ<`1XYS@0Ij<c06JU:`1YYR/0M:LR07ZN8023V280PY<Y07j>=01hT3D0
N9Dc07JH<01cWc<0KJHc06Z];`1Y/BP0KK8Q07Bc8@1f/B40MK0T07Fa9`1f/RX0M[8V07Va8P1k/2<0
0P20/B@09`1n[BD0O[0S07b^901jZBH0Nj/Y07J_:`1j/RX0Mk4V07J`901d[RH0LjhZ06n_<`1bZC<0
KJ4b06nZ;`1[[R/0J;8^06Fb<@1V/C00Jjh/06^a;@1Y/SD0I:lj066[>P1Q[cH0G;Dj05fc=@1L/RX0
HJlS05fd8`1Q^RT0JJ``06^G?01WYSX0H[4_06bc9@1d[al0NK8I07>e6P0206no800W06ne9@1^Zbl0
M:Hc07NT<P1kXR`0OilV07Jc9P1^`2L0M;hJ07Jg3@1l]P/0OKD907Ne2P22/@H0SJd2092V0@2@X@00
SJ00092T002?Y`00T:L008fZ002<ZP00RK4008Na0@1o]PL0Ml0=06o06`1]`2H0Kl0^07K0<@1a`3@0
L/0c0730@01^]dD0JKM806Jd@`1U/T00HkM50080G/1602L0H/0k06Bg<@1Z]Rl0J;TW06O08@1R`200
GKPR05bi9P1I`340D/0b05;0=01;`440BkQ@04bZG01;YUd0CK5>04n`@P1GZ4D0EJQD05JUF@1IWUh0
IXmX07UmM`2<Kg`0UVa[09Q]GP24K5d0Mh94082Q6@2@VAT0XhT]0;>;9@2]VBP0Xi/`09^N>`2;XD<0
Qj=308RM?`24S4T00P25R5809`26REH0RXY=08jH@02@X3h0VY`e09VO<P2AZB`0T[HN09Ni5P2B^a@0
T/0K09Bi6`2B`1`0S/0I08Zj8026_B80QkPZ08F`;@25/B/0PL0T08?08P24`1l0PkdQ08;0;024`300
P/0Z08;09`24]b80P:`S08:Y7P27ZQP0PZdG08BY6@23[1H0PJTF07b[6`1aZ1l0KZXQ076V8`02072S
:P0K06VW=P1T[3H0IYlf06bL:01_SQh0MGh=06ee101/LP80J70105ei1`1DQa<0B9<N04fG6`1HUa40
GYH@05nA4P1NS140Gh<=06Il1@1[LP00JFH006=J001QE@00Fd`005Q7001EA@00DTD00080D4@000X0
D3d004Xm0019?000B3H004H`0018<@00BCD004Pd0018=@00A3<00P10<0005`0o:`00?B`003`^000m
:`00>BX003TV000d:000=BH003@W000e9P00<bL003<V000]8@00:b<002TN000U6`008AD001XB000B
30003@D000H200030P000@0002D00000303oool000X0oooo01@0Gi/`05^M=01MVC80IY@a06ZF;`1^
Tbl0Mi<a07VF=01dWS00Ij4/05nP;P1QWS00GIl]05^R9@1EYR80DJTQ052]801@[Ql0Cj/N04f]7@80
BjhI02L0BJhN04F^8P19[2@0Bj/X04bZ;017Z380AZPd04VZ>@18ZSh0AjU704NWAP18Ycd0B:Ti04bW
<P1AYbh0E:PY05F/8`1E[Ad0DjXG05>]601@Za/0EJdJ05N^501>[aD0B[0G04Z_8P1;Zb@0BjPV04NZ
;016ZSP0>jU702nVE00UZEd08Z]S026[G`0PZU`08JUI02BVE`0SXUT00P0SVe`09`0SWEh09jAK02RX
EP0X[4X09Z]602N]B@0Z[Dh0:jaA02ZZE`0/ZEP0<JUE02jQF@0^Vf40<Y9X03V<I@0oQVP0BH=U059n
FP1MOE00I7U<05MjCP19Ne00B7iC04akF`1=NfD0CWMR04^5FP17UE@0BJ5804RZA@1;[DL0BJQ904VR
D01;UED0CIi:04f/@@1?/S/0D;4a05:d9`0205Fd8@0W05Rf8P1N]Q/0G[HJ05bc7P1H[bD0Ek0U05V`
;01G/S80Fk8]05j`;01O[b/0Gjd[06>[<@1TZCL0IJ/i06RX=01WZRT0JJ/T07BW7`1oWR00PIHT082@
:`1mT3L0Nh`k07NA=`1eV300MYld06nV>@1/Zc@0JK0c06ba:01b/b@0LK@R072d901c/RP0Mk4]07Rc
;@1h/B<0N[<Q0080P;8Q02L0O:lQ07Z]8`1h[BP0MJT[07N^:`1e]2T0Ll0Y07>n901b_Q`0L[8T06b^
:`1]ZCD0KZ<h06RQ=`1X[C00IK8]06Ra<@1Y/C/0JJhf06ZX=01W[SD0Hk9005nd@@1K]3/0Gk/h05W0
>@1Q]bh0G;@U05jb9P1O/bD0Fk8X062[<P1LYT00HJdc06Fb8@1]/aX0MK8I07Fd5`1e^AX00P1h]BH0
9`1j/2d0N:Dc07jT<P22WC<0QZ0X08NO9022YBD0O:X/07N_:`1e]2D0LkHH07O03P1e]`X0PK8708j_
1@2@Y@80SYl108jL002AX000SZH108fW0029[000RZl008Ja002:/@00Q[8307ng2P1g`1D0Ml0J07O0
801n^RD0OKLW07Ni9P1c^S40JkPk06Jg@@1U]D@0HkI606BdBP0206BdB`0W06BeBP1R/cl0H[Ph06G0
:P1U`2<0Gl0W0630901Q`2P0G/0Y05g0:P1I`380Dl1005:dD01>ZV00CJ=T05>^D@1F[d/0FZE<05NL
F@1IVF00FYMP06B=J`1jNW@0SFeg099]H@2?JU80PGIJ07j<A02;Z240V9DN09f;8@2[TR@0Yj0^09^L
>@2DX3d0R:Pj08BU@P2=W400SXm80080QHYF02L0R8UG08b8CP2BSDD0Ui9309ZB>`2HWC00SZX/09Fh
7`2A`1T0S/0I0970702B^1`0T;/L08_07P2<`240Rl0V08O0:`27^bh0RKH_08>j9P24`1h0RK/K08Jk
8P25`2P0Q<0Z08;0:`21`2@0Pk/N08>b8021/1h0OjdH07bZ6P20[AT0OjlJ07f]6`1dZR40JjXT06R/
:P1]Zc<00P1ZZ3X09`1V[480H;0h06>P;01^Ra`0L7X?071W101TH@00Heh006=O001PI`40EWL805>8
5`1>TB00DhlA05f82@1MRP/0GhD406Af001ZKP00IfL006AP001PF`00HED005]:001F@P00D3h004`m
001:?000BCT004Lg0015=000AcH004He0012<000@S4004<a0011<`00ACD004Lc000204<^000G03//
000j:000?2P003`/000h;000>2H003HY000d9`00<B<0038S000b9000;Ql002`N000[7`009Q`002<L
000N5`006Q4001<;000;1P001@<00081000100009@00000<0?ooo`002P3oool0501YUbd0IYX]06VL
;@1/VB/0LYTZ07BI:@1fVBP0MI/Z07JQ:@1]Y2P0I:<W062Q9`1MXR@0G:@O05NX7P1EZ200E:XR05BY
8`1EZb40D:/O0P1BZa`09`1DZad0DjXN05BZ7P1BZQl0E:XT052Z9`1;ZRh0BjLb04RW>@16YT@0B:=9
04JTA`17Y480BZ90052O@01@YCP0CjT^04b[9`1:[2@0BJlP04N_7`1;/A/0Ak8H04Fa7014/R40A;4Y
04ZX<P1<Y3@0A:@i03bX@`0bZE00:JQK022XGP0OZEl07jUR022XHP0PZ6D08ImS02:HIP0202:=J@0W
02BAJ00WW6@0:ZAR02RYD@0WZdd08je?02F[E`0WZEP0::IK02VWGP0/Xeh0;9aO02bIHP0^U6H0=95Q
03^;H@14QEl0BHEK04j7E@1=R540AHU@04:9D019RTh0BhAA04f3EP1=PeD0C8eD04VKD@18Z4P0C:]5
04ZZAP1:Y4T0B:5904bRB@1?Ych0D:lg052f=01E]340EkDS0080F[DJ02L0G[HJ06:f5`1V]AL0H[@O
05^a:@1I[bP0F;0Y05Va;01M/B/0Gk0]05j_;@1P[Bh0H:dg06B^>`1U[Sd0IZdf06N`:@1]/200MZXN
08:O7@21URD0OXl/086@<P23T3D0OID_07^J;@1iVS00MJ@b07>Z=01a/C@0L;@^07>d:@1c]BD0M[HV
07Jb;01l/300O;4]07^`9`1o/A`00P25[a/09`24Zah0P:TR07^]9P1hZb`0MZlZ07Bd:P1a^2@0M;<O
07Jb6P1f/Qh0LZhR07:[;01`ZbL0LJhU06nc9P1_]BT0K[8V06Vb<01V/R/0JZd_06Nb<`1S]cT0HK4g
062a=01R^Rl0G;X`05nj:@1M/b/0HJ/d06FZ>01TXS`0Hj/i062a=01W/b80J[HD076f4@1g^1<0N;LF
07^c7@0207j^:@0W082[:`22YBl0QIda08FA>@2>Tc00UY<W08bD<025TcT0Ni`h07BY<@1/]b80M<0H
07W04@24/PX0R:/808JS0P2;WP40RiX008VN0@2;YP80RZL108N[0028[P00Rk4008f`002</P40QkD7
07^g3@1j`140N/0G07Rj7P1k^2<0N[LS076h:`1X^3D0I;I406:dBP1S/T/0I[950080I[1:02L0H[5>
062_C01O/dH0HL0h06G0;P1R_c40H;P[06C08`1Z`2<0I[TT05k0<@1G`400D[AE04^WI@1>WVX0EjAE
05bWE01NXET0FhmU05j4HP1QQ680JgU[07U`L@2:Ig80RVYF08IXCP1lNE/0N95=09RG<P2LSah0Ui0M
0:NB:`2aT3<0U9E008FVA@1o[Cd0PZHm08^Q@@2CVDd00P2:SUD09`28QED0V8=@0:>9B02VQD<0WXHo
09RG<`2=Y2`0TKLR08k07`2;`1/0SKTO09:f7`2;]b40Rk`U08_19`2;`2l0Q/4e08S0=@2<^3@0R;LY
08bk6@2=^AT0R[TQ08Rk9@29^2T0Q[TX08C08@28^ad0Q[XP08>h8P20/a`0OZ`K07fb7@1e]B80MK4Y
072^;`1`/Rh0Jk0i06ZWB00206>XC`0W066^BP1U[cH0JilQ07=m401/I040IE/0061E001ODP00Fe@0
05iO001MJ0<0G78905an3`1GPPd0GX48065o101TO040J78006]]001YH`00IUd0065G001ND000G4/0
05Do001A>P00BCL004Le0018<`00AS<004<d0013<@00@380044a0010;000?b/003dZ0014<`00@SH0
0080@30001H0?2T003TT000h9`00>RP003PZ000f9`00=BH003<T000a7`00<R00030N000[7`009R00
02LN000T70008AP001/B000D3P0040X000P500030@000@009P00000<0?ooo`002P3oool0501dTBd0
L9@X076I:01cVRH0MIDV07NI:01cVbH0LYXX072N:01_XRT0JJ8V05nP8@1OX1l0Gj<M05fU7@1LXal0
FJ@R05ZT:01MYRL0FZPS0P1NYb009`1OYR40G:@N05VV7P1JZAl0FJPR05RY8`1CZB@0C:XV04RY:`18
YSP0B:4o04BU@P16YD<0B:E304^P@019YCP0@JXb03jZ<00j[Bh0?Jd/042_:00o/2T0?JlY03V`:00l
/2X0@Jl_04BZ<P0nYc`0>JM503BYD00/ZU@0::UI02B[EP0OZEL08ZMR02:VI00RXfT08iY/02B?K@02
02>4K00W02J4K00WRV/09i5/02FNGP0SYUX08ZMJ02:SH@0TXed09Z5Q02RQH`0/WF80;YQR02jHH`0^
UfL0=99R03Z<GP10Q640@XAR046;G@0nSUP0>Y5D03fAE@15SE00B8E;04^5C@19RDh0C9A=04fQC@1<
ZTP0C:]704ZTB@16VT`0AZ=704bZ@P1=[cH0C[<`05:e;`1E]S40F;HS0080Fk@I02L0GkTH06Je6P1V
/Q/0H[4Q05^_;01K/BL0F[8V05Zb:P1M/Rd0G[8/066_:P1S[2l0I:/f06N_>`1W/3h0Ijlf076`9`1j
[b00R:TN08RO7`25UBP0PY4Z08>>;`26TS40Pi@^07nH:@1mUR`0OYd]07^Q<`1f[3<0L;<`06je;P1a
]2@0L[<N07Va9P1j[bd0Mjl^07F^:01m[Qd00P20[1/09`1oZR@0Mj`Y07J^9@1d/B<0M;8U07>k9`1b
_B40MK<I07Ve5P1h]QH0N;4G07J_7`1i[1X0OJhL07Z`8`1l/2@0MK<R06fc9@1Z^BD0Ik0^06Jc;P1W
[bh0IZlX066_9`1S^Bd0H;X^066l:P1R]Bh0I:dm06N[?P1[YCd0Jjld06Ba:@1W]1/0J;HB06ng401b
^QD0Mk0O07n/9P0208FV:@0W08^Q;02BWBl0TIHZ08n@;`2:T2T0T9@S092G9P2BVBH0RYdW07jW9P1a
[b40OjhT08>e801n]A@0PJh>082U0@28X@00S:0008NN0`28YPD0QjL208NZ0@2;ZP00Rk0008f`0P2C
/0<0SK8508Rf2P26^`/0Pl0>07o0601j^1d0N[HQ07Be9@1_]Rh0IkHm06Ff@01S^4@0I[I00080H[U:
02L0HkE=05jaB@1M/TT0H[Q106K0=@1S`300H/0[06Vh7P1Z`1X0H[HS05^e=P1N]dH0D[1E04ZQIP1;
V6P0FYiE062QE`1SXe`0GYAR05n?GP1XR5l0LgQU07M[L@24IVd0SFmL08i`E`1nO5l0NHi>08bK9P2U
UQ`0XY@V0:J?<@2QTCX0RJ=1082[AP20Z400R9M008jEB02FT5<00P2DQUD09`2ENUD0Z7]D0:^0C@2Y
PdT0WXa009ZI=P2AY2h0SkPS09308P2A^240UK/W09Jf;02@^R/0Rk/^08W1;P29`3H0R;dk08Zg=`2:
]3@0RKTT08fj6@2>]aH0SkHI08^k7P28_Al0Q<0N08O07`29`1d0R<0O08Jk8023]aX0Pk0J07f`701f
]240M;@/07B/>@1fZcX0KZM006ZUA`0206>UA@0W06>T>P1/Y2`0L94F079f201WI000HeX005e@001I
C@00F4`005YF001KE@00GE`005eV0P1OJPP0GVh7061^0@1TK@00IV<006IQ001VG`00IU/0061D001L
C@00FDL00590001=?000BSL0044a0013<@00@2h0048`0012<P00@Rl0048^000o;000?2T003TY000n
;@00?bh00080?b/001D0>bP003DV000f9P00=BD003HW000g9`00<b@002hQ000[8000:Qd002XL000Y
7000:2<002HQ000T70007aP001L@000B2@0030H000H300010@009`00000<0?ooo`002P3oool0501i
Vb@0MiXT07JK9`1eWBH0M9/T07BL9`1eW2L0M9X/07>L;P1dWbd0KZ<Z06JR9@1TXAl0IIlL06FP7P1T
WR80Gi/X06:L:`1PWBd0HihZ0P1VWbP09`1VX2L0H:8V05fT901RY2H0Gj@T05bW8`1HZB80D:`Q04j[
801<ZbH0BjT]04RY<P19Yc@0B:Pc04NW<`12ZBl0?JTb03N[=@0b[3T0=Z/d03V/<P0i/S80=[0a03F]
<@0hZc40?Jhc03Z/>00cZTP0;ZUG02NVG`0TYFD09:QR02:XFP0OYEX08Z9U02:QJ`0QWFl09I=g02F6
N`0202QhNP0W02QfMP0UMgD08GQi022;K`0OWFD07Z5W02:KKP0SWFP099eX02JNJ`0XW6X0;iUW02fK
I@0`W6H0=IIU03b;H`0mPfD0?HAV03V>H`0fUE`0=IUG03ZEF013STl0AHE<04F8B016T4`0B9e<04VV
B01;[DD0C:Y504RQA`15VdT0AjM204Z[?P19/3L0BK8a04jd;P1B]C00E;@U0080F;@O02L0F[DM05fh
7`1S]B40Gk4V05f`9`1O/b<0Gk@V06:c:@1P/bL0Gk4Y06:^;P1UZSD0IJPk06JZ>@1X[CL0K;4a07J`
9`24[a`0RjHM08ZR8`28VBH0QIPY08BG:`25URl0PiT^08:I:`22UbX0PI/^07bN<P1iYcH0LK0d06fd
<01`]RL0LkHR07Ra9@1k[bX0NZlZ07V_:P1k[2800P1oZR<09`1lZBX0MJ`Z07N]9`1j/280N[0T07Va
7P1g/Q/0Mk8H07Ze5@1h]QD0N[PF07Ze601o]AH0P[<I082a7@1l]B40M;TL076i7@1[_B40J;/X06Za
9@1^[RD0JK0Q06>l9P1R`2h0I;da06C0<`1W/C80Ijlj07:/<@1e[BP0M:lO06n`601]/A@0KKHA07Fh
501i/a/0OZL]08FT;@0208RJ=`0W09FK=02HTcT0Ti@^09FA:P20SRX0RhPc09:@;P2ITBT0Ui<]08fG
;@23VS00R8lo07fU@01//Rd0L[8F07b[1`23Y0@0QYl3082O1024XP@0QZ4108RU0@2<Z000RZl108V`
1@2:/0L0SK85092d0`2<]P<0R;/:08304P1j^QT0NK@O07Fb8`1e]2`0KKDf06Fe>P1N`3l0G<140080
H;]<02L0G[Y>05jhB`1L]Th0GKM9066k>@1N`2l0Hl0O06S05`1T`1P0Fk<V05Jd>P1K]DL0EK5G052N
H@1AUe`0IIe=06RMCP1YY5D0IIeL05nIG@1/RV40Lg=W07USK`23Gf/0UFeO0:9eG028NUh0MhU?09JI
;`2aTB80^8lS0:2C<@29X3l0Qj/m08JN@P2>TD40ZHI609N:C@2BPeP00P2NOUL09`2UMe@0/7AH0:]e
D@2WNd/0WiDm09VR=P2BYS<0R[PX08nk902C]2T0UKL_09Fj<P2A^bl0S;df08Vm>P26]Cd0RK=108Z[
>P2=Z3H0T;DY08nf6P2=]1T0S;4A08Zh6029_AX0RL0M08W08`27`2<0RL0P08Jn8025^1`0Q:lM08Fc
801n]BT0Mk@j07FOC@1fRU40LHe?06fGB@0206^M>`0U06ZM;01YUQd0L8D?06mc0@1XIP00HE`005i=
001IC000F4l005]?001LA`00F4/005iC001SF@40HEP105mH001OE@00HUX006MM001SF@00I5T0061=
001HB000DT800550001??@00C3P004D`000n;000?B/003l]000o;`00?bh003l[000m;@00@2X003/Y
000403/X000E03PX000f9P00<b@003@U000e:000=BL0030P000[7`009ah002PK000Z6@009Ad002TO
000X80008a`001/H000E3@003PD000H300030@000@0000`000000P01000I000000`0oooo000:0?oo
o`0D07>P7P1bWAh0LIhP076N8@1`W280KihS076N9P1dVbP0M9XY07:M;@1bXB/0L:8U06jO7`1/W1d0
J9dL06ZO801XWBL0II`W06VM:@1XWR`206FN:P0W06>P9`1OYBH0GJDW05jV901LYb00FZLR05F[901?
[2@0C:dT04j]8P1;[2D0B:l/04V/;P1:ZS00B:/a04:Y;P0lZC<0>J/h03N/?00kZSX0?ZTh046/=P10
ZcT0?:Xk03Z[>00i[3`0=Ja302fYD`0UYeX08ZIR026WI00RZfH08ZMM026RFP0QVfL089M[02:DL`0W
S7`09h200080:g5o02L0:6al02MZOP0OIX<07g]k01nAM00PVg@08IQe02BPJ`0UY6L09J=Z02FQJ@0Z
Wf@0;9iR02nPHP0dV5d0=i9K03f?FP10Seh0?9AI03NIE00dVU80=YA=03b=C00oRd`0@95<04:ICP13
XdX0AJ]504Z]@01;[D40C:Y604ZSA`1:ZD80Aje004F_?P18/3L0B[D_04jg:@1A/b@00P1G]1h09`1I
]B40FKDU05be:P1L]2X0F[DU05jc901S]RP0H;D_066d:P1R[b`0I:de06BR?01UWcd0IJ<h06^/<@1^
/Bh0O;8R08N]6`2:Z200S:@V08ZN:@28VRd0QidW08FK;024VBd0OiD/08>F:P24Ub/0OYHd07bM>P1e
Yc`0K[4i06ne;`1_]BL0MK8X07Rb:01e]2d0Mk8[07V`900207Z_8@0W07Za;@1f/BX0M[4U07R_801m
/Qh0Ok@J07bc5P1j/QL0MkLG07Nm501g^a@0N[LD086l4`23_AD0OkHG07bf6P1i^1X0Ml0H076f601b
[QP0LjhH07>^6P1`/ah0J;HZ06Ng9`1Z]BH0J[H[06fd:`1^/2d0NZlS07Za6P1g/180Mjl@07N`4@1h
]QD0OK<N08BY8`2:YBT0RZH[0080QIdc02L0Qi`j08ZG?@26W3H0PIXb086F<`27TBh0SYHY096G:02<
WB/0SI`b08jH=@2@R3l0RH]607nEA`1jWcd0OJL^08:[9`21[R00QjXJ08B[6@24[A40P[<>08:b3`20
]Q00Q;4@08>d3`27]0/0SK@608Zc0P27]`L0Q;T;082h4@1j`1T0M;TP076e;@1]]3L0I[Ph05k0?@1M
`4000P1L`4/09`1M`4`0FkQ?05VcD@1F]U40D[I:05?0=`1G`1l0G/0J05_06`1D]RD0F;<c05Rf@P1C
]e80DJ=K05JKEP1TVdX0IiM@06NKE`1NUU/0HIEK06b8HP1eMVT0Of]]08]PJ02EJ640X79O08QjFP20
SDP0W:0W0:nL8`2aVBH0UjPb08Vb>`2>/S/0T9li09j@?`2^Q4H0XH1C09QnD`0209EgCP0W09meC@2b
MT/0[WI>0:AoC@2OUCh0Uj0k08bY=`27]C80SK/b09>h<P2A^380Sk/e08fk<@2?]C80RK<j08V^?028
YS/0RZ0h08nT=P2</2H0S:hH08nV3@2?X`d0SjX@08ff5P28_1`0R/0Q08c0902;`2<0Ql0Q08Ji7`24
]1h0PKDP07fc9`1h/CH0Mj5207NG@01fV2h0NIDR0080O94H02L0NXDC07=j3`1dLPD0KFX006AO001O
E000G4/005]8001JB000GD/005U1001@@000ETD005e<001JB@00FDD005Y8001NC`00HeD0065C001N
CP00FDD00552001??000CcT004hl001:=`00A3<003l/000o:P00>Rl003X/000l;@00?2/003lZ0011
;@00?2T003/X000g9`000`0i:0004`0h9@00=RP003HY000e:@00=2D002dQ000[7@00:1d002LJ000T
6@009a`002LK000V7@008Q/001XA000D2`002`L000D300010000:000000<0?ooo`002P3oool207BN
7P0B072M8P1^W2H0L9/W06jL:@1_VbT0LYXV07:J:P1dVRd0MYh/07NP9P1eVb40LYXN06bH7P1]VR00
KIXV06jF9P1`VbH0KIlX0P1VX2X09`1OXbX0G:LU05NY901FZR80EJ/N05:Y7`1;ZRD0B:hY046/:P18
[280AZdS04J]9`16[BX0AZ`Z04FY:011ZBX0@jT^03nY;`0k[3@0?JXe042Z=`15ZCT0A:Q103bWB`0g
Z4/0<ZI@02bTEP0TXUl07ZAQ01fUH`0MZF808:eL022XE@0PWeX0795T01j>JP0ORW<08H5i02MfO@02
02U^O`0W02U[PP0TJ8<07VF:01ecPP0KRg`07IQj026HMP0RXG008Z=[02BQK`0VWFd0:I][02ZLI00[
VV<0;iEM03>EF@0jUUH0?iEG03^FE@0gV5<0=IM<03NDA`0lS4T0?Xe803fEC00nXDd0@:Q904B[@P16
Zd80BJe404b/B01:Z4H0BJY004JZ@`14[TL0AZm004Vc;P1?]BL0DK8O0080EK<N02L0Ek@P05Re:@1F
]2`0F;8Y05Zd9@1G]BL0G;H/05fd=01N/c40HK0c066]=P1QY3`0I:8l06BT=P1[[RP0L;<O07f`6@2:
[AP0RZPM08bU8P2=XBH0QJ4V08FO9`23WR/0QIh[08NH<@2:UBl0Ri<d08:A>@20U400Mj4m076Y?01_
/3@0KK4[06n`9`1a/2@0Mk4Y07Nc9`1d/2000P1c/2409`1a/BH0L;0W07B_9@1i/B40N[<L07Zd6P1i
/aL0MK0H072m6`1e^QX0N;dG07bm5P20]1D0PK<H07jc5`1d/aX0MK<G07Vb5P1g/Q<0M[4D07:_5P1`
/AX0KK8X06Vc<P1[]BD0J[8O06^c7@1^/1T0NJdI086]5`1j[aX0N[8C07f`4@20/QL0Pk4K08FW9@27
YbL0T:<X08JV:@0207bJ?@0F08BK@026Ud<0OYXn07fF>@2?Tc40UI8S09:E8`2=TbL0TIDZ09n=<`2Q
PcP0XGU209=eE@28O5/0MXQJ06VJE01^Zdd0Jk9906je@@1/^3<0K/0W06o08P80K/0R00l0Ll0N07S0
6@1o^0l0P[P:08Jg1@25]`@0QkD808Be3024^140OKLJ07nb9`1i/b/0Lk@_06^h>@1R`3l00P1M`4L0
9`1L`4l0GL1>05fhD01I^dd0Dl1004k0=01?`2H0D/0T05G09@1H`2<0F;HX05K0=01H^Cl0DJa=05FP
CP1QVTh0HXaH05Z6G01FQ6@0GH=Q06ihIP1mKfX0Qfa/095UJ`2GIV80UVAO08AgF@20RDT0XYdK0:^G
9@2MUSL0T:Pj08Nf?@29[3d0TiQ309Z=B02[ND/0ZGI;0:EgB00209acB@0W0:9aA@2eN400/7i60:61
C02NSSd0UIXj08N^>@26^C80RKXf08bj?@2<]S`0S[To08bd=`2@[Cd0SJhn08bX=`2>Xc@0SZ4b092U
;P2</b00TJ`D08jK1P2@U`<0T:0:08j^4P2;]a/0R[XS08Rl8P2:`2<0R<0T08Vm8P25^b00PKTR07bd
:@1j[S80NJ8e07ZN:P1jUAP0O8480080MW000240LVX006eY001/IP00IF0006AJ001PE@00F4d005]7
001IB000F4P005Q5001E?P00DSl005A4001DA@00DD<005E5001HAP00FT`005i9001G@000DS/004lk
001=>`00C3D004Tf001:<`00A380040`000o:P00>b/003`[000j:P000P0k9P00100n:000>b/003XX
000h900203LU000:03PW000f9P00=RL003DY000c9P00;2L002XQ000Z6`00:AT002DL008091T000L0
8a/0028J000M5`005A40010:00091@00100002T00000303oool000X0oooo01@0Li`R07>N8P1eWR@0
MIdS072O9P1`WbD0LY`W07RH9`1hWBT0NIdZ07VL:`1fX2D0L:0R06^N801VWAh0JidQ06bK9@1]VR80
LI/P07>Q8P80KJ<P02L0IZHP05jY7`1LZQh0EjXN05:X7P1BYQl0C:DU04RX9`13Z2/0BZTY04jX901=
ZR<0CJXU04ZY9`17Z2L0B:PU04RX9`13ZBL0?Zd[03j]<P12ZcX0BJU003jYC00`ZV80:JAZ02BRK`0Q
Wfl07ia`01^MK00IXfT06ZYQ022_F@0QYeH089QL01f7I@0KPF/07gUd029dNP0[Kg`00P0^J8409`0Z
IhL09FF:01eOS`0MKHL07HJ001fEOP0PVGP07j1e01nNMP0RVg/09IEg02NEL`0UU6`0:9I]02R@H`0/
Ue/0<9]H03NIE`0gV5<0=IUA03JFB@0gUD80>Y=503bEB010WDL0@:A4046[@@14Zcl0B:a204Z]@P1<
[400B:Xn04J/>@15[cP0BZli04fa>01?]2d0D[@T05:c800205Jb8@0W05Nh801H/BD0E[4W05Vb:01H
]2X0FKH^05^c=01J/SX0Fk8i05n_>01PZcL0H:Hj062P>P1SX380JZXR07:`5022/180RJ`I08bX7`2<
YR40S:DV08VP9P25WbL0PYlX08BO:@2;VRd0T9Db08j?>027U3/0PiDn07bK@01fXSh0KZdg06^^<P1Z
[bP0KJlT07Fb9P1g/R80MJlR0080MJhV02L0KjhX072_:`1a/2X0M;8Y07>d9`1e]BL0L;<R07>m801_
]Ql0LKDQ07>f7`1e_Q`0N[XK07^d7`1i/al0LjlS07B_7`1h/AP0N;<F07:b6@1b/a`0Kk4R06bb:@1]
]2`0K;LS06Nd8@1Z/A`0L[0B07R^2`1l[0/0O;4?07je4@20]1X0RJhP08n[7`2BXQl0SJ4V08ZQ;`20
Ybh00P1kX3/09`20Z3d0NJhl07NZ>@1hXSD0PZ0a08RP:@25Wbd0QiTb08jD<P2JQc`0VGY609EjC028
NET0PGmL072>EP1VV5H0IjUE06JbEP1V]TX0I;Y106G0<`1X`2h0Jl0/06W0;@1_`2/0M<0W07_07P1m
`1H0Ok/B08:i3P1o^0X0P[H;08Ff3023]180P[DO07fg8@1k/bL0L[Df06Jg?P0205g0BP0W05o0D`1K
_U@0G;mD05BjB@1>`3T0Cl0`04S0;01=`300Dl0c05[09P1L`2<0F<0^05G0=`1?]4@0E:Q?066ID@1L
Q5`0EgaT05=kIP1OMfP0Jg1/07M[K020KV`0SVeY099ZHP2CHV80OWEK07Z:C02JXC80WIde092J@029
Xd40S:I3096J@`2GQTL0XWU80;9ZC@2fKDP0]g950080ZW1102L0YFln0;9i>@2aQ4@0ZXU80:BA@02E
W3d0RJe008Rb?@27/S/0R;5008jc@02<]T00Rk4i08j_<`2@]C<0SkH`08fg;P2;]bD0SKDL08jc4`2E
Z@/0U9/309BF0P2CV`@0SjD:08Z`4@29]QT0QkXN08_08P2>_B80R[dO08Jl7P25_240Q;@W07f[9P1o
X1d0QILG08B82P21N`800P1gK`009`1aK000KF/006QS001RH000HeX005eD001MB@00FTL005M5001F
B@00F4D005E0001B?P00E3h005E0001B@P00ED<005A4001FBP00F4H004lo001:>@00AcT004Pf0017
=000Ac<004@e0014=000@2l003l[000j:@00?BT003TX000f9`00=BD003HR000f8`00>R@003<Q0002
038P000:03DW000d9P00=RD003DW000a9@00;B<002XO000W6P00:1`002PH00809AL000L07aL001lE
000K4`004`d000`500060P000@0000l0000000<00@000041000100005`00000<0?ooo`002P3oool0
501cW280LihR07FN901eWB<0L9lV072O9@1bW2L0N9PW07RM:@1iWBX0NI`[07JP9@1`X280JihP06JM
7P1[WB40K9/U06fJ8P1aVb00Lj4R0P1]Xb009`1VYR00GZTO05bZ7P1GZQh0DZPN05:V7`1<YBD0B:PW
04>X:`1:ZBT0CZPT04fZ8`1=ZRD0BZTW04NX9`18Z2D0B:PW04>Y9`0n[B/0?Zdb04:[>P19ZD00?ZU<
032ZHP0YY6X09:9_026OK`0OW7006ie/01VSJ@0JZV408:mI026WEP0PV5`07HMU01^1J`0ONG@08WAj
02]_O00202iXP@0W02YWQ`0UIHX07En?01e]Q`0MQX007IEn022IN00OX7D07iif02:KN`0UUGL09iEc
02FDK00XUVd0:91S02bGF`0`VeP0=iUG03NHD`0eVE40=YI903NE@P0jTdD0?9E8042MA`10Y4@0@J]1
04B[?`18[480BZe204b/@018ZSh0AZ`i04F_>01:[cT0CK4h04nd;@1B]2@0D[<P0080E[8Q02L0EkPP
05Ra9@1F/BL0FK8X05Rd:P1I]Rh0Fk<d05Zb>P1K/ST0Gjlh062[=`1PYSX0H:0j06>P<P1ZZR80L[0D
08:`4P29[1T0S:PO08bV8@2<YBH0RJ0V08FO9`22WbP0Q9lY08^J;@2@UC80SXlh08ND>`23UCh0O9]0
07JR?P1^[CL0Jjhb06Z_:01][b@0MK8V07Nb8P1e[b800P1e[RH09`1_[RP0L:l[076`:P1d/RT0Lk@W
07Fe9`1`/b80LkdP06nf7`1a]B40LkHO07Fn701j^Q/0Nk@O07Vc7`1c[b<0M:lO07Ra601h/aH0L[8I
07:c701_/B80K;8Y06fd;01/]b<0Ik@Q06Za701b/180N:h;07b/2`1l/@l0O[DA082d6P29[R00Sj/O
09:R7`2=XBH0RZ4_082W;P0207^P>`0W082X?@1i[S`0MjXi07RR=@22X340R:0Y08FO;@27VC80SY@b
09Z7?02INTH0UGY<08QiF@21Oe`0L8iF06JHEP1WZED0I[9F06JfBP1T^T40IL0c06S0;P1[`2`0JL0]
06o0:`1d`2L0Nl0N07g05P1o^a80P[T>07nh2P22]P/0QKH<08>d4P22]Al0OKLQ07^c9`1b]CH0I[Ln
0080GL1:02L0Gl1C05^nE01L_e@0E;Y904k0>@1?`300B<0/04g0<01C`3<0F/0V05c08`1H`2h0EL0g
04ndA01DZ4l0HIUA05b4G01GO6@0Dg]V05mgJ01[L6`0Mf]/081^K02>KFT0TVYR09=RHP1nME/0NXY<
09ZQ<P2MWCD0T9Y008VS@@2<YT<0TIY309N6A`2RNDP0/VY=0;I]B02gLTD00P2ZL4409`2UKch0/WTi
0;64A02ZRDP0Y95009FL?@29[D00R;8m08Nb>`28/D00S[=008bf@02;/CT0SZlc092e<`2?]S00SKL^
08^g9@2=]A`0S[<C09FY2`2DV`<0U9H209>K102?Y@X0R[0A08Vf6@27^Qh0Rl0R08jm8P2:_Al0Q[`N
08Fl8@24]2L0OJ/V07nP7@25UaL0Q8P:085k0P0207M_000W075/001]J`00J6<0069P001SFP00GE@0
05e9001JA`00EdD005I9001HA@00ED00058n001D?P00ED000592001E@`00E4@005I:001HAP00Ccl0
04Xi0017>@00B3H004Ld0017<`00A3D004@d0010;`00?b/003XY000m:@00>BP003HW000e9@00=R80
03HS000j9000<b400080<R0000X0=BL003@V000f9@00=BL0034U000]8`00:Ql002LJ000X7000:1P0
0P0U5`001`0O5`007aD001/C000C3@0030D000H2000100003`0000000`0100000@400040000G0000
00`0oooo000:0?ooo`0D07>L7@1cWQh0MZ0O07FN8@1bWb80M9lT07NN9@1gW2D0NIlW07^M:@1kWBL0
MZ0W07>O9`1`WbL0KIlT06jL9@1[WR@0KihR07:O7`1eWah207FR7P0>06jS7P1XYAd0IJPL05fV7`1I
YR00Dj@R04nT9`1=XbL0CZ8W05BT9`1LY2D0EjPR05:Y8@1AZb8204jZ8P0G04^X7`1:ZAh0AZ`Q04N]
:01;[3D0BZA303fJF@0/Vg808Yaf01fNL`0NWfh07Z5V01ZTI`0KYf806jeN01b^F00NY5/07I5P01Yn
I`0MMFl07fif029YO00ZIh000P0aHhD09`0_I8X09F>@01iOT`0KKhX07XJ001jDO@0NUgH07iUh022H
O`0SUX0099Aj02BFMP0QVWD09YY^02RIIP0ZVUd0:iUK02fHEP0bUU@0<i=E03JGCP0eVdX0=im803bN
A@0lY4<0@JPn04BZ?P18[D40B:e504b]@P1;ZcT0Aj`h04R_=P1;/c40CK@b052d=@1D^C00DKDW05Bf
8P0205Ve8`0W05bh7`1K]240F:lU05Zb:P1K]2l0Fk@`05Va=@1K[T00GZm005j^?P1OZc/0HJLj06>U
=P1TYbh0KJdN07b_4@27[Q00SZ`H08b/7@2;ZAl0RJXP08BV8`24Y2D0Oj<T07nS:026X2l0SYPg08bC
?@26TT00Pi5007bC?@1fWd00L:dm06Zb>01//BX0K[0U07J^8`1g/2<0LjlQ0080LZlU02L0KZl[06n`
:01a^2`0M;<Y07:e9@1e/BT0M;4X07:c8P1_^200LKHT07Bg7`1k^QP0MkLJ07Rd9@1i[bX0Ljdc07B`
9P1h/aX0N;8I07Ve5`1h/1T0NK0K07Zc6`1f]1`0M;HM072b801`/aX0MK@?07Zb2020]0T0O;@;082e
5`23/b40T:LT09:Z8P2EWb<0T9lY08JN=`1lXC@00P1fWS`09`1d]3D0Lkhc07>e<`1dZcD0MjDd07ZQ
=01iY3X0OZ4m07fL@01oS4/0OgaF07mdF01kMe/0Oh1A07BCC01YVE@0KJ9E072WD`1][DP0J[1006Ve
?01Z^3P0KKHg06nf>@1^]CP0M/0j07O0<P1g`2d0N/0U07[07@1j^Q<0OK@=08:d2`24]`l0PkTK08>g
7P23/b40P;8T07Fb;00206Jf=P0W06?0@01O`4/0GL1<05ZjB`1I`3X0F/8_05_19`1L`2T0H<0U06K0
6P1T`1P0Gl0Q05S0<01E]cl0Fje9062FD@1MPeh0FGeX05QgK@1TMfd0KGI]075aK`1gLFl0Pfm/08eX
I@2EHV80OWES07N8E`2HVcL0XYTj09FH@P2@U4P0W8e90:MoA`2ZKd00[F@n0;aNA037H4@0cV=00080
^FHm02L0[VXj0;9g=@2dPcd0/he70:RI@02KWcl0R:Y008F[@`24YDP0Q:=208Z_?P2;]cX0SkD_08jb
9`2C^BD0TKXQ08ni8P2@^1T0T;8B09:X2`2EW`D0UIH109JA002DTP00T9T108bO1@29ZA40R;@J08Zh
7`2;^B00S;TN08^l6`2<]a/0R;8O08NW6P26VA00QhT708>00@1mM`000P1gK`009`1cJP00JF4006MR
001VH@00I5X0061@001JBP00F4@005E6001ICP00Fd/005Q6001F?`00DSl0058n001D@P00ED0005M1
001F@P00ET@00591001=>000AC8004Hb0014<P00B3@004Df0013=000@B`003dX000m:P00>bd003TZ
000f:000=BP0034R000c8P00<R00030O000202lO000C034P000_9@00<BD0030V000_8@00;b0002XN
000V6`00:1P002DJ000R5`007a<001`D000G4P005180010<000:1@001@400040000=000000800@00
00@00@40008100020@000@005P00000<0?ooo`002P3oool0501_XAT0LJ0I07BQ7P1dXAh0M9hN07>Q
8@1gXb40NJ8Q07ZS8P1hXB<0Mj4S07RQ7`1bXAh0LJ4Q076N8`1bWBD0M9dW07FM9P1dWR@0MYlS0P1e
WR@09`1_W2@0JYlS06NQ901SXB@0GJHS05NU9`1BXRX0EJ0W05^Q:01TXRH0IJDS05jX8P1DZB00CJTN
04^Y7P1;[Ql0CjhL04Z/6@15[a`0@Z`S04:W<P10TDT0=gmV02QlO`0OSGh06iMf01ZJJ`0NXV807:UQ
01V[H@0GZf406j]R01ZMI`0JR6T06WI`01a`M@0PJW`0:6F002mQP`0203QNR`0W03=QS`0UIID07FFC
01]jR@0MSGl07Y=j026?M`0QSGX07hYo02:=P@0TU7X08YMe02FLMP0WWW@0:ieY02fHI00]UUl0:iAM
02^?G00^SEl0;Y=P02nNF00dY4d0>:A503bU@011ZcX0Aj/j04b/?`1;[4L0CZdo04b/=`1<[SP0CK8d
04jf<@1B^c40Dkdb05Fj:P1G^B<0F[TN0080GKXM02L0H;/L062k7@1O/b40H;DX06:d;@1R]S@0Fk4k
05b]@01JZ4@0GJY206:Z?`1TYS/0IJTc06B]:`1^/1d0OK8B08b/4P2:ZaP0QZ/L08>Y8@25ZB00PjDP
082S8`1nX2H0Oj<Z08NQ;@2>VS@0TYLi08b@?`23S400O8m007FFAP1dYT<0LJdl072^<01`[Bd0MJ/[
07^/;01lZR/00P1dZRX09`1_[B/0K:l/06j]:P1a[bD0Lk8Q07Rb901f/BL0M[8W07Fd9@1c^2@0MkHK
07Vh601f_AP0M;DO07Nc8`1i/B@0NjlI07Bd501e/Q40M[4E07Ja5`1e/AP0Lk8I07Bc6P1d/Q/0Kk4J
07:c4@1g]0l0O;H;07nf4P1m/Q/0Rj`P09JY7`2BYR@0T:HR096S9`29Xc00PJ8k07bX=`0207B]=@0W
076j;`1``300MKDb07B^=01iZ3@0Nihh07NM@01gWDT0LIe>06fJE`1^SE`0Kh=K0728E@1fTDd0L:A4
06bUB01XZD/0KZm:06fb@01/]SD0JKTc06C0<@1X`3D0J/0l06o0@01_`3`0Kl0e0730<`1d_Bh0ML0W
07Vk801m^1@0PkP@08:e3@27]A00Q;HH082g7`1m]Ql0N;8P0080KkHS02L0Ik/a0670@01O`4H0G;Y7
0670?@1V`3L0I<0a06?0;`1U`200I/0E06Zh4@1S^AP0G/0S05^g?01M[T/0H95B05n1H01LO6L0FWaa
06=nKP1YO780Kg5f075VO01gJ7L0QfYa09ASJP1mMVX0LhaO092Q>02JYC40Uidm09BHA@2US4L0[W]3
0;=/?02fGd00aV=40<9UB@34H4/00P2cISh09`2aKCL0]G<g0;9nA02[SDl0Vie0096T?P29X4@0R9a5
08BIB@23WdP0QZXj08Jh;@2;^R40TK8D09>^402C[Pl0UZD>09FV302EXP/0TYh409BM0@2FTP00Thl0
09>C002CU@00U9D2096K2@2>XPl0SJLC08j/4P2=[140SjX>09BV3P2DX`d0TIh<08VA1P28QP80PWh1
085g000207Ub000Q07EX001]GP00JUl006QP001SG000HeD005i<001IC000Ed`005Y>001JC@00FD`0
05I:001C@P00CSl005Ho001CA000Dd4005I2001HA`00E4D004`n0018=000AC8004@a0015=000ACL0
044e0010<000?2L003PT000e9`00>BD00080>2P000@0<bD003<S000c8`00;al00P0[70004P0]6`00
:al002lO000`8000;b8002hR000Z7P009a`002<I000S5P007A@001XB000G4@004`/0010:000;2@00
20@000<10140000000<00@000000000000005P00000<0?ooo`002P3oool00`1[XQT0KYhI07FK6`02
07ZL7`0?07RN7`1gX1l0OJ4Q07bQ801kXQd0NJ<N07JR7@1bXa`0Mj4N07NO8`1lW2D0Ni`[07VM:P1g
VbX0MYXW0080MY/W02L0LI/V06bO9P1/XRP0JZ<W06RS9P1SXRP0HZ0Y06:P:01VXBD0Jj8Q06ZT7`1V
Z1`0GZXI05bY601BZQX0Cj`H04j]5`1;[AP0@Z`L03ZY9P0`X3`0<GUP035NN`0WGXX07Gf201ZBN00J
UVX06:9R01VZH@0E[6<05JMZ01RSKP0JTg<07H1c01m^M@0RJgX09VIo02eQP`0gG8D00P11F8X0100j
GXh0;6B@025/T00OPhL201nDOP0Q0267NP0RPW/08gf202:3PP0TTWT099]b02BPM00XXgH0:J9b02ZJ
KP0YUV@0:I5P02N>I00[T6T0:Y]Z02bUF`0^Z4`0=JU003V/>@10[S40B;4`04n`=01?[c/0Cj`h04n^
=@1>/3@0D[<e05Bf<P1E^Bh0EkTZ05Vj901O]ad0H[LI0080HkHJ02L0I;XL06:h8@1M]B00GkDW062g
<01R]cL0Gjm005bVA@1JXDP0FjE:062WA01RZD00HZde06Zc9@1c]AX0O[4C08:`4`22/aD0PK8H08:`
6`23/QP0QZ/J08>Y7023[200PZ/T08VZ9P2<YRT0Riha08ND?021RD<0Mh]907BDB`1`WTX0KZY006b`
=`1][bl0LZh`072`;`1e[bX00P1f[R`09`1a[b/0Jjd/06^_9`1^/B80M;@M07Jd7P1g/RD0Lk<X06o0
9`1d`280Nk/J07^n5`1h]1P0M[8N07bd6`1l/aT0OK@C07^b2`1f/Ph0L[0E072b6P1`/1`0L;4K07:_
6`1b[Qd0M;@D07Fg401h/a00OK@E08>b8020ZRX0U:<X09RQ902DWRT0Rj@[08^S;`23YcD0P:Dg07Zb
<`0207>e=@0W07Fn;P1c_S00N[<a07V[<@1oYC80OY]007BHA@1_UU40JZ5G06ZTE@1VZ5H0I:QD06RV
CP1ZZTH0K[@o06bf@@1Y]dD0JkQ206^e>@1Z`3<0Jl0^06_0;@1]`2h0LL0^07;0;01]`2d0K/0^0730
;`1e`2h0M/0]07_0:@1i`200OkTG08:d4`26]A00QK@C07g06P1j`1`0OKLS0080NkPU02L0MKL/06S0
<@1U`3h0I<1506S0@P1X`400JL0j06fk<01Y`2L0JL0J06Zi4P1Y^A80I[TK066h=@1O[dT0HYAE06>4
G@1TO6/0HWa`0620K01VO6d0KF]h06mUO@1nI7h0QfEg091TM01hMV/0K8iQ08RP>@2KWCH0X9Tm0:6K
@`2USCh0[GU10;Q^>@33JT00cVDn0;mZA`2nI4h00P2^KST04@2gLC<0`W0n0;5mB`2PSE@0Sj5208bQ
@@2?U4H0SiE508^O@P23ZCd0RJd]08bb7`2?/1@0U:T=09>L0@2DV@00UI@000<0TiD001<0TI@009:D
002CT@00UI40096D002AT000Ti@0092H0P2=V`L0RYh808bJ202?VP<0UIL009:H002=U@00RHd008>8
0025O`00PW/00080P7D001H0Mfh0075W001[H@00K5h006IN001VEP00GeD005]?001KC@00FDh005]>
001FCP00FT/005E5001C@P00ET4005M2001EA@00ED4005I3001BA@00CS/00P1:=P003`17=P00AC40
04D`0012<@00@C4003XY000j9000>2<003PT000f:000>2H003PW000c9`00;b4002/O000202`N000B
02/M000/7@00;A`002dQ000]7P00;1d002LJ000S60008AH0024E000M5@006Q0001H=000@2P0030H0
00T400050P000P40:P00000<0?ooo`002P3oool0501eXa/0MZ8J07RP701jXAh0OJ0O07ZP7@1kXAd0
OJ0L07jU701jYAP0NJDJ07NU7P1gYA`0NJ8O07bO7`1nVbH0NiXZ07VJ:P1iVBT0N9`X0P1fVRT09`1e
VRD0MIhY07BN:@1eW2`0Li/]076M;`1^VBd0L9`Z072O9`1bW2D0KYhP06fR7@1YYAT0JJLI066W6@1E
[1/0CZdO04R[:P12ZC80>J4n02nDC`0_OVL0:G=f02=bO@0RSG0079aZ01NRH`0DYf404ZaV016ZJ`0C
XW805iYf01b;M00NNG809fUf02aWNP0_I8<0=En403iKR@0204EERP0W03iNS00^J8`08Fj<01n5R@0N
TXL07Y:50221P00TOH0097V402EmP@0VSWD09I]_02:PL00TXW@09j5f02^KN00YVVL0:YAN02ZEG`0/
Vf80;JAN02Z[DP0][DH0=:dl03R^<P10/2T0Bk0X056b;01A/C<0D;0h056_=`1A/CD0Dk4l05Jb>P1I
]3<0EkTT05bg7P1Q]1/0IK@J0080HkPN02L0H[PP066f9P1O/bP0Gk</062e=01Q/C`0GjY005ZPA01I
WDL0Fj5705fW@@1R[C/0J[4Y076f701j]Q40P;<?07ne401o]a80O[PC082c5022/a80Qk<B08:e4P23
]A@0Pk@G08Nd6@28/ad0QK4Q082V;01hWSl0M9M507>GA`1aW4D0K:A006V]>`1W/3P0KK0b072`;01a
/2L00P1c[b<09`1][b<0Jk4T06Fb8`1[]1l0Kk<M07:f7P1e]B80M[@R07S07P1j^1/0OKDF07bf4`1j
]1P0MK8N07Rf601j]A80Ok@?07^c301e/180Lk0L06f_7`1V/b40KK0L076/701g[1X0MK4G07R]7@1k
Zb80Qj/R08jX:02>YB/0UZ0U09>O9`2AWRX0Rj8^08NR=@20Z3<0PZXe07Jd<P0207Jn<@0W07Jl;01g
_300MK@_07BX<@1lWcd0OiQ6076DA`1]Ud`0JZY>06^`B`1W/d/0HkE706Fg@`1U]cl0J<0g06W0?01R
]d00I;Tk06K0<P1U`2d0J/0W06k09@1b`2D0LL4V06o29P1Z`2P0JKl]06g0<01``300LL0d07?0;P1g
`2/0N[dM07bf5P22/a80QK<>07^h4`1h^AP0O;XP0080O[HR02L0N[4Y076e:P1/`3<0J<1106_0?`1[
^4X0JkY306bj>P1Z`340Jl0R06fg5`1W^Q<0HkTN06C0>P1M]500GYEL069oHP1/N6d0JWEa06IeK`1Y
LFl0JfAg07=ROP1oIH80PFEl081QM@1^Mfl0HIEQ08>W>@2DWc<0VIXn09bHA`2URd00[X<i0;Mg=032
M3<0bG0f0<A]?033IdX00P2aJSl0502`KSH0]7Di0:enA02VR4l0VIM8092FB02<TTX0QZ=608Bb>@24
]RL0RK<I08^/402?Y`X0Tj4309>H002CT`00U8h009ZE002HUP00TYH00P2BT0004@2?S`00Shh008jC
002BT@00Si4009:C0@2<TP80SHl208n@0P2AT040TY<0096B002;U@00QXd008N40026O@00Pg`00080
PGP002L0NW<007I^001_J`00L6X006eT001ZHP00J5d0061I001PDP00GE0005]?001KD000Fdh005Y<
001G@P00DD@005E0001E@@00DCh004hm001>>`00D3d004lm001>>000BC@004<_0016=@00@c80040`
000j:@00>BH003<T000b9@00<b<003<T000e8`00<BD002/O000Z7`000P0`7`004@0_7@00:ah002`N
000/7`00:Qd002PK000W6@009AP0020E000L4@007Q0001L@000@3@003PP000T500050`000P0002/0
0000303oool000X0oooo01@0P:4M07nR701mXAd0Nj0O07jP8021Wb40P9lR07fP7@1jXaX0N:DI07VU
6P1jXB80Mj4U07bN9@1nV2H0OID[082A:020UBH0OiPY07RK:080MITU02L0MITV07NM9P1gWBP0MIdY
076P:@1bWB/0LY`Z07BM:@1eWbD0M:4Q072P701[X1T0Jj8I06VV6@1MYQ`0BZXT04:Z<`0kYD<0>9U=
03F=F`0aPV/0:h5c02N7LP0SR74089QU01ZNIP0FYFH04ZUZ012[K@0AZG805Z5e01RJM@0NS6l09G]`
02aYM`0dJ7h0>f2403mKR@10F8X00P13FX/09`0kGX`0<FF:029[S`0OPhh07hn>01f;S@0PNhP08gb6
02AjR00YOhH0:8Qi02BAL`0SUg@09Y]j02RKO00WVGX0:9QY02VEHP0ZVF@0;:1T02bYF`0Y[U00;;14
02n_>P0g/2d0?k0V04Za9P1@/RT0DK@`056a=P1@/SD0C;0d04j_?01C[cd0Ek<f05Zf8`1N/a`0IK0L
06Fa8P0206Bg900W06Ff9`1P[b`0Gjhf05n`>@1L[c`0GZQ405bNA01IVD@0EYQ405^L@P1QZCL0H[4b
06^e7`1g^140P[@:08:d2021]PP0Q;H808Fc2P2:/0`0Sk0:08fa2`2=/`d0S;@=08jc3P2</Q40Rk4E
08Na6022/1d0MZ`[07BV=P1bWCl0L9M406fIA01VY440Ij`o06Z`>@1`/B`0Kk0S0080LJlP02L0Kk0M
06Z`7@1Z/B00J[4P06f`801a]1h0M;<N07Fd7P1i]AX0NK@G07nc4`1n]1<0O;DI07Ng701e`1L0O;PA
07bd4@1k/a80NZlJ07NW9P1`[2P0K:`X07Ba801j/QX0N[@J07^b801lY2/0PYl^08jM<02@Vc40U9X]
08bL:`2;Vb`0T94/08nE<P2AU3`0QJ4e07b^<`1d]Rh00P1a_Bd09`1d_BH0L[dZ06c0:P1^]C80M:@n
07RGA01bVT80K:=0072c>01c]cT0Jk`l06[0?01V`3`0I/0o06G0>01V`3P0I;He06Jg<01[`2`0KL0V
0770801a`1l0Ll0P07;28@1aa2D0K<0_06[1;P1[`2l0K<8`06k0<@1``S@0M<0c07K0;`1h^B80P;@C
08Be2021]`T0P;P@07fk7@0207ni7`0W082c9P1f/b@0LKHW06[0;P1Y^CX0J[U=06fiBP1Z`4<0J<0j
06W0;01^^Qh0KKPJ06Nh901U^3L0GZmC05^?H01OOV<0J7YZ06MjK01SPVd0IGi^06Y^L01[J7H0LFUi
06i/M@1aJ6d0IgmZ06FMH021Zd00TIXh09N?A`2QST/0]8/n0;^7;02jPB<0_GdT0<1i:037M3D0dFQ2
0080/f=002L0YVhj0:Eg>@2WQST0/8a909nFA@2EUDL0SII308V^>026]RL0R;8H08fV3@2>W`T0T9h1
09>G002DT000U8h009RB002KU`00V9T009NJ002BT`00T8h008j?002@T@00T8h009:;002?S000S8h0
08Z=002=S@00SX`0096>002BSP00SY<008b@002=R`00Qh4008Uo0022N`000P1oNP009`1mM`00Lg<0
071a001bK@00MFd0079]001`I`00J60006AE001MCP00GE0005m@001MCP00FU0005Q9001CA000Cd80
054l001>>@00C3H004dh001<?000C3d004Xi001;=`00BC<004Tg0011=P00?c@003d_000f9`00=B@0
03HW000c9P00<B80030Q000_8P00:ah002XO000202dN000A02dP000Y7`00:a`002LL000T70009AX0
02@I000Q500070h001P>000G30004`/000h:000:1`001P<000<100010000:`00000<0?ooo`002P3o
ool0501cXQ00OZ<I07nQ6@21WaX0QYhM08JJ7P25WR00Pj0O07fR701lXa`0OJ<P07jQ9`1kWRP0NY/V
07bF:`20TRh0Phd[08N?:`28TBX0PY@/0P1kTRh09`1jTbX0NY/U07^M8`1hX240MJ8U07BQ:@1fX2X0
N9`X07^M9@1nWRL0MIhT06bQ8`1UXB00Gj@P05BV8012ZRh0<j]002nWE00^UV@0<H=c02elP@0QRH00
7iMh01fGKP0MVfH05i]/01JUL`0AZWD04j]d01>XL00GXW405Yic026@L@0WNg00<VMh03iRP017FhD0
C5B:04IFS@0203iHS@0W03AJSP0/Fi00862F01ejU`0JQY/06X:J01icT`0PN9008gZ>02QmRP0YPH00
8h]j02>AN@0UUGh09IQo02>JP@0SVfl08YmV026QI`0VYVT0::eM02JaD@0Y/4T0;jlj03>a:`0j/2H0
Ak4X052c:`1@/bX0CK8/04fb;`1</S00C;4g05:b>01F]340FkPS05ne6`1R/200H[<V0080H;LZ02L0
G[8]05j[=`1MZD80FJa605V[A@1KY4L0GI]405RJ@01GW3/0GJ8f066]:`1Q]Ah0J[LD07Jg2`21/`L0
P[@208:c0`28]0<0S[43092/102B[`H0TZh909>_202E[`L0UK4809N^2P2E[`X0Sjl=08^`4023[aD0
OJhI07Z/7P1bXbd0LJDi06J/@01R/4<0I[4k072`9`1b/Ah00P1c`1X00`1]]1H0J;DG06Re7@0206Zg
7`0R072d6P1e]AT0M;@I07:g6P1c]Q40N[8=07bd3`1h]AT0M[HI07>h501j]@h0N[8A07^b5P1n[280
P9Da07>P;P1ZYRl0Lj/Y07^]8`22[B<0RZHS08nN8@2DVbH0UIdY092L;`29WR/0P9d]08>K;02>SC<0
S9<d08fD>`21YCT0NK8h07Jh;P80K/0U02L0LL0R06^l9`1/`2X0KKDa07BS?@1eTd00LYU006jY?P1b
]c00M<0^0730<@1_`3D0J<0h06S0@01U`3l0I/0i06K0;@1U`2X0LL0Q07C06P1c`1T0L<4F06k26`1_
`Ad0L/4X06g0=`1]`300Jl0c06[2;01Y`2l0K<0f06g0?P1a`3L0LL0Z07ff5P23]@/0QKD708Re2P29
]`h00P26]a@09`20^Qh0NkXN07Jf8P1_^ad0J[Ld06FiC@1X]dl0I[Q@06Nh@@1V`3<0K;/R06nk8@1[
^2d0JK<k06:UCP1NS680GX5S06EiI@1ROV`0H8=c0620MP1TLVl0I6U`06MWM`1VJG@0K6Q`06F1J01V
XV00OZ/m092J>@2MT3P0Y8Xk09b8>`2SQCL0]7`/0;Il9P2jMBT0`G<c0<]Y@@020;=[@@0W0:Ae@@2P
PCh0Vi1009VA@02ETT00SY=208bP=@2:/Ah0RJTC092N202>U`<0SiD208jC002CT`00U94009JD002E
V@00UIX009BI002DVP00TYD0096@002?T`00TI80096>002DS@00TX`008j<002>R`00S8X008f;002C
SP00TY80096?002?S000SH/008^80028Q000QG`00080PgT002L0P7P007Qe001cL`00Mg@007Me001f
M000Lf`006]R001RF000He<006=?001ND000H58005a@001HC`00FDT005I5001@?@00BSP004Tj0017
>@00C3P004`i001=>000B3P004Dh0016>@00AS@0048a000k;P00=R@003LX000e8`00=2D002hQ000^
7P00;Ad002TP000[7`000P0]7@00400/7P00:ad002PK000W6`008aT0028F000N50007Q<001/A000G
3P004P/000l:000:200020@000<20001000/000000`0oooo000:0?ooo`0406jU301hXaH0Nj8H08BP
6P80QI`M00h0Q:0M08BQ701oXQ/0OJ4N07VP801lXB@0NidU07^N9@1nWBL0Pi`W08ZE9@28UbD0R9LT
08RH9P80PYDY02L0P9PU07bP7P1iXQ`0NZ<K07fV6P1oYA`0PZ8L08:Q7@24XAd0Oj8N07>R7@1XXQ/0
GZLK05JZ601?[1`0@JlX03J`>00a[4H0;J9E02VCK00TRWd07Y9j01RKM`0IVfl06ImX01JSL@0CYgL0
4j]i01>[LP0GYg005JA]01VQL00PTFl0:7]d03=WNP0oH800BeV4051ERP13E8d00P0jEI007P0`EI<0
:4nF01mBWP0KJil06WVP01QgWP0KJYP07gFC025jTP0UOhl08XJ201j>O00PTWh099B202:FQP0MVX40
7Yma01bSI@0QY6P09JYW02F_G00T/E00:K5602n`>P0f/Rh0?;4Y04Fb;01;/bX0C;@Y04Vd;080B[H_
00L0C;Da05>d<@1L]RX0GkPR06:e7`1P/RD0H;D[0080G[D`00h0Fk0j05ZZ@01MZDL0G:Q905fYA`1P
YdH0G9m105JQ?@1KYcD0H:/`06>d7`1W_A@0JkT?07Fh3P80O;L>01L0OkH?08Fe3P2>/@`0TK4;09B`
202H/0L0U[8709Ra0`2I/040V:l209>_0P2A/P80S[4208Z_1`28[`L0Q;0?07f`5`1d/2T0Jjli06>e
AP1U/ch0Kk8_07:a7`0207>e600W06jc5P1/`1D0Jl0I06bk6P1Z^ad0Kl0K07707@1/]1d0IkHL06^e
4`1e`0l0MKl?076o501__QD0Lk/D07Re4P1n/QD0Q;8K086b8@1k[BH0KjlT06Va9P1^[BH0NZHV07jR
:`27WRL0SI8[09>?:02BV2T0SiXb08jJ;@2:UBX0RiD]09:?<P25US@0PIXg07^]<`1g]c<0ML0X0080
L<0M02L0Kl0J06c07@1c`2@0M<0/07Fd=@1a[CP0JK8e06Ze=P1_`2h0L/0]07C0;P1e`2l0L/0`06_0
=P1V`380J<0`06c0;@1Z`2d0L<0S07;07P1b`1T0LL0J06o0701V`A/0K/8R06k2:`1_`2h0L<0a06_0
:@1Y`2T0JL4a06[0=`1_`300Kl0/07W07020^A80Rk@9096c0`2=/`L00P2:]Ph09`22^aP0Ol0L07^d
7`1g^A/0L[L`06JjA`1Y]500JJmE06NhA@1U`2l0IkdR06^h901Z^Rd0JkPk06JZBP1STeX0GHQQ05f5
I01KP6X0HGed065hN@1TK780JF]^06a[L`1]KG<0JFaa06N:IP1]ZET0SJH`0:>D;@2_QRX0Zh<X08n6
?P2BN4L0Zfli0;I/=@2gN2d0_7L`0<=b?P020;9i@@0W0::5@`2LS4@0UY=1096E?@2>USL0Rid`08jR
802>YA@0RiP708n;0@2=RP00ThT009><002DT000UIH009JK002HV`00V9`009>J002DU`00TI@009:@
002@S`00UY0009FA002FSP00UH/00968002AS000ShX008Z:002BS@00T8h009:=002AS000T8/008n;
0028R@00Q7h00080PG/002L0OWX007Uj001iOP00NWd007Yh001hM000Lfd006aT001VG`00J5/006MG
001QE000G4l005U<001GB@00F4`005E5001>@000CSd004lm001>>`00CSX004hi001<>`00BCT004Dj
0016>000A3<004@`000n<000>b`003HY000`9000<b<002lP000/7P00;1l002/P000Z7`000P0Y7@00
3`0/7`00:1`002PJ000W6P009AL001lE000M400060l001L?000C2P003PX000/600080`001@800081
000]000000`0oooo000:0?ooo`0D06bU1P1`YaD0MZDH07^Q6@1mXA/0Oj4I086T6P1oY1T0P:@J08:R
701nXAd0O:4L07^P7P1kWQ`0O:4O08:O8022WAl0RI/O08JH7P24VB0208:H8`0W082G8`1oWAd0O:4J
07nR6P20XaX0PJ@K08>O7022WAh0P9hS07bL9P1_Wb80HZDQ05V/7@1A[QP0BZhL046^:00i/3H0<:i5
02RTE`0SUF`07HYm01R>P00DTGl05Iic01BSK00FZ7@05jYk01F/N@0E[gL05JMg01VPMP0ITgT078Ig
01mgNP0XJ7`0<6An03QOPP0lFHP0=5R=0080<5>D02L0:T^J02I3W@0P@J<07UNT01YXY00GKJ8076ZK
021dU@0OOID07h>A01n;Q`0LTX407iF402BDP`0RTHD07I=o01fJL`0OYFT07ZUW026[IP0R/UX08[5<
02Vc@`0^[cT0=K0^03^`:P13/R/0BKD/04Zf:`1:]b/0BkD[04fg:`1C]bP0F;LS062e8@1R/b00Hk8V
062b:@1L]C000P1I/cT09`1I[DL0FJY;05ZWC01LYd/0GZY:05nZAP1OXT00G:Hi05n_;01Q/B@0HkLH
06Rl401]^Pl0L[XA07Bi6P1d_1/0ML0O07^j8020]Ad0SK4D09N`4@2K/180WK4@0:6a402Q[@l0Xjl@
0:Ba3`2R/Pl0V;<>09Na3`2D[a40SjlA08^_4P24/Qd0M;PY06Jc@01X^c`0JKd[06ff7P0206jd6@0W
07705@1c]1D0LKLH076e6@1`]Qh0LL0N06g07`1Z`1l0IL0N06W05`1^`180LKlC072o5@1]^AX0LKHK
07Jb7`1o/BD0R:`Y08>[:P1m[2P0MjlS076_7`1j[1d0O:DM086Q7P25Wad0S9dO08ZM902>W2<0Rj4_
08jK;P2;TS@0RYH_08fE=025W380Mj0g07Fa=01g]S00Ml0P0080LL0I02L0Kl0H06k06`1c`280Ll0Z
0730=`1/]3P0J[Df06Ne=`1^_2l0M<0_07G0;`1_`S<0K<0c06K0<P1W`2P0J/0R06o0:@1]]c40L;DZ
06fh8P1_`1d0K/4P06o06P1a`1T0L<0K06o0801_`2<0L<0W06g09P1W`2`0JL0]06S0<01/`3<0K<0f
07O0901l`1D0RkX>09:e202A/@D00P2>/P/09`25]a00P;HJ07Vb801g]Ad0MKP_06Vl?P1V/4/0IJUJ
06Fg@P1W`2`0J<0Q06g0801^`340L[U006b^B`1QVUT0GIAP05VBI01HQV/0I7Ie06QYN01VIg<0JfIh
075YM`1^LG@0I7Y[06BGHP1^]T`0T:d^0:JH<02bQS40]80^0:Yo=`2XLS`0/fa00;5]@02WN3X0Yg`e
0;]j?0020:^3@P0E0:N;B@2PT4T0TIU508BS?@26[2X0SZTI09>P3P2CTPH0TX`20927002BQ`00Thd0
09F;002HS`00V98009JD002IU@00V9X009JI002FU@00Ui400080Thl00100Ti@009BE002DT@00U8h0
09:;002?S`00SXh008^<002?S@00THh0092:002AR000Sh/008f;0028R@00Q8@00P24P0009`1nO`00
Ngh007b1001lO@00NG/007Ib001aJ@00KfH006aS001/H@00Jel006ML001QF000GTl005Q?001FC@00
ETH005=3001A@@00DD0004hn001A?@00CC`004`j0019?@00A3T0048h0013<@00?C0003l/000l:`00
=R@002lR000b9000;R80030Q000`7`00;20002/O000202XQ000>02hM000X7@00:AT002HJ000P6P00
7QH001X?000F3P0050`00109000:10001@<000@10001000^000000`0oooo000:0?ooo`0D06JN1P1[
XQ80Kj4F07>R6@1dY1T0MZDF07RW601kZQP0OjPH082R6020Y1L0OZ0H07ZQ5`1jY1L0N:@E07NX5`1j
YaL0OJDG07bU5`1kYQH207ZU5`0W07bV6@1nZ1H0P:DF08:T5`22XaP0OjHI07fS6`1oXa/0Nj@K07NU
701^YaT0H:`F05J^4`1?[Q00BJdA04B]7011/2`0=:a302VOH00MSGD07Gj001N3R@0BPh/04I]k01BW
L`0E[7H05jaj01V^NP0G[gh06ZN001RFP00FPWl05Gam01MdOP0JK7d07fQk02ISP00XH8D0:5f;0080
9e6E02L0:D6M02PcXP0U<JL08dBT01iEY00MIJ408FVJ021aU`0LNIL07X>A01^?RP0JUHT07YF:02:A
R00QRXH07HR101j<N`0OVWH07ZAa02>YI`0T[eP09k=:02jd@00b/SL0>;8_03fe:P13]R/0B[P^04nj
<01?^bh0C[L]04ng:P1D]BL0GK4O062a801N[RH0Fjla05Za<@1I/SD00P1J/d002P1K[T`0FjU=05bT
B`1OYT`0H:U:06:[@`1RZcd0HK0_06Je7`1X_1L206Nn4P0K06Vh4P1^_Q@0K;/P06W0901V`2h0JKTa
06nc<`21[b80T:DN09RN8@2KXR00X:8Q0:BP802VX1`0ZJDG0:ZU602WXQL0Yj0H0:VK7P2TWQh0XJDO
09BV7P25[B@0LZlc06b/?01[[S<0L;4T0080Lk<Q02L0L/0M07>g6`1g]a/0N;HK07^g701h]Ad0L/0N
06[0701U`1/0K;HJ06jf5@1b]a@0M;PG076h601a^1/0M;8P07Z]:01oZC<0NZH_07NW<@1aZbT0LjdW
07bW9@1jY240PZ0R07jQ8029VbH0QiPP08^C8@2?UB/0SYD`08JF=`22W340QILb07jN=P1gXcH0MK<_
07O0:P1g`1h00P1d`AP09`1f`1P0NL0I07[0701g`2D0M<0^0730<01/`2l0JkL^0770;P1d`380Kl0a
06O0=@1Y^cD0JKXb06S09@1^^280LkPT06jh;@1a`2P0KL0T07;06`1d`QL0M<<E07745P1b`aD0LL<E
07716@1^`1l0Kl0U06c0:`1W`2X0HL4/06C0;@1W`3P0Ll0]07K09@23`1D0RKLA092a2@0208fb2@0W
08Vd3023]A<0O:`R07bd7P1g]RX0K;Pb06Vb@`1U[5D0I;Y006O0;01W`280K<0R06k0<`1[]d@0IZU?
06>FG@1OU6@0Gi1U05mnK`1/Jg80L6Ag071WN01_KGL0Lg=d06YjL01SPFP0JJ1J07FeA`2>Z340[I4e
0;ao>032LSd0bG4k0<YY?036KdD0/g190:IaC`2HMch0_GHm0080[HQ302L0Z8m@09fHC@2<Y3d0R:`Y
096_602DX@d0U98109J?002CSP00THT009><002ESP00UHd009J@002FT`00UYH009FE002IU@00V9L0
09RF002HT000UY00092@002CUP00UI<009B<002AR000S8X008^@0029T`00S9H008VB002AS`00SH/0
08^8002:R@00R8d008B<0023QP000P20QP009`1lO`00Mg/007Ul001gN`00MGH0075c001aKP00L6T0
06eX001]I@00Jf@006UR001XH@00I5d0065E001LD000F4/005E9001IB@00E4<00591001A@@00Cch0
04Th0016=`00@CD0044a0011;P00?bl003l^000m;@00>BX003@V000b9`00<2D0030T000_8`00;200
02XP000202TO000>02PN000W700091L0024F000O6@007QD001T>000E2`0040P000X7000510000`80
00810001000^000000`0oooo000:0?ooo`0D06FK1@1SW0H0JZ8C06jV5@1gYAP0MZPF07VX5@1nZ1H0
PjDH08BR5`23XQH0PJ<G07^T5@1iYaH0MZHI07FW6@1dXaX0NZ<M07VT6`1hYAD207JU500W07VV5@1m
Z1D0Q:<F08NQ6@25X1/0PZ4M07bT7`1hY1h0LjLI07BZ5`1][1D0HJlB05B`3P1?Z`/0C:T=04R[5013
[2P0=ZE602ZFF`0ORV/077im01B3T00BQi0049Z501BTO`0FZGX05jaj01J[N`0H[H005J>301J;P`0F
LH@04GB100ifO`0>Mg`057=n01Q_P00KJhD07VB:00808E6D02L09CfM02HcX@0U=:808dRL029IVP0O
JYX0976E021iU@0LPIH07HRD01Z;T00HShh08I6<02BBQP0RT8D0896001fEO@0NX7L07jEc022YJ00S
[eL09kA<02^fA@0c]D00>KLa046h:P17]R/0CKh_05;0;`1E^R/0F;HX05Vf9`1K/B80H;0Q05j^9P1L
[Rd0Fjdg05^_@01K/D800P1I/TD09`1I[TL0FJQ;05fSBP1NY4T0HJI6066/@@1S/CH0HkDS06Jg5P1Z
]a00J[HB06nc5@1`/aH0L;4F076d601a]QX0L;DP06nc:@1_/RX0OZhL092Z402GXQ80Vj4F09fQ6@2M
X1T0WYhH0:>M702XWAd0YYTO0:>B9@2RSbd0W9TY09ZL9@2CW2P0PZ<X07>V=01WX4<0J:/l06n_<`02
076_<00W07>a:@1d/R@0LK8S07Ba801j/Al0N[0N07Za701_/AT0M;4I07F_6@1j[QH0OZdF07^`4`1h
/A<0N;4F07f`6@21[1d0P:`T082Y8`1kZ2H0MJPS07:Y8@1`ZAl0MZ@O07^V8@1kYAh0Nj8O07fJ8`22
UBL0QY<a08NL<01mWSH0O9dc07^E>01dXSX0LZTh07:g;@1]`2@0L<0M0080L/0I02L0Ml0E07S0501g
`1P0M<0O07G09P1a`2`0L<0X06k09`1``2L0Kl0_06g0:P1Z`2X0K;PY06^d:@1`^RH0LKH]07Fb:01a
]BD0M;TZ07?0:`1i`1`0Ml0D07K0501a`aD0M<8E07;45`1daQT0L/4P07;0801/`R40Jl0Y06O2<01Z
`2h0JL8f0770=P1a`3P0NL0T07jf5P28]0d00P29[`T09`29/`X0QK<E07jc8@1n^1h0N;@S07>j9@1a
/CP0JJm@06Jh@`1W^c<0JL0[06g0:P1/`3D0IkA906>REP1TTV40JX]W07F4J@1bNF`0MVUa07QXLP1h
KWL0M7=g06acLP1TOF`0GhaW06NWE01f^4@0S:P`09jC;P2[PC80_7Hc0<1a=@35JcL0bG@i0;Q`?`2P
K4T0Z7910;UcA@020:^9B@0809N>BP2:UDP0Q:XS08n[4@2HV`T0UY@309FA002DR`0209>?000M09>>
002BS`00TH`009B?002ET`00TiD009JC002FT000V94009RB002JS`00Uhd009F@002ET@00U8h008f>
002<R@00Qhd008F?0027T`00QI8008JB002:T@00SXX008^60028QP00QX/0086;0021QP000P20PP00
8P1kP@00MWd007=l001aN`00LWP0075h001dM000Lg0006m/001/JP00JV@006]W001]IP00JF<006AL
001OEP00GE@005]A001ID@00F4d005Q;001GA`00D4<004dm0018?000@cT004Hg0012<`00@S00044e
000m;@00>Bd003PW000e9P0203@U000302hR000]7P00:Qh00080:aX000d0:1/002DH000O5`007a80
01hC000M4`005a00018;000>1@001`<0008100010@000@0002l00000303oool000X0oooo01@0IYP3
06VL1P1]Y@h0L:D@07jX5`1oZAH0PJLE08JX5`28YQP0RJ8I08NR6024XaX0OjDE07bV5P1jZA/0MZDN
07FS7P1kXAl0Oj<I086S5P80OZHD02L0OJLB082V5020XaL0P:4J07jS6@1nXAL0NJDK07B[6@1_[Q40
KJh;06V]2@1P[PT0EZd<056W2`1=YPT0BZTB04:V;@0cVTd0:HQP025lK00MNG`05hB=01>BSP0CWhT0
4Z2801FVQ`0FZHD05jZ101JYO@0HW7/05XMl01AaP@0AOWl04XQm01B>N00EQgd06X2101akR00NKHl0
0P0ODiH09`0QA9/08TBL029?V`0SFY@09FN>02=]S`0UN8d088:A01b9TP0NRI4078F?01^5S`0QRh/0
98n802>@Q@0PUh807Iio01fUN`0PYgL08jY^02R[G@0[/540<;E903JcAP11/cH0B[DX052e9@1B]RL0
EkLT05Zf8P1J/b<0F[0U05j_901O[bH0F:l[05Z_<P1G[Cl0FZ]805R^C`0205V^B@0W05^ZA@1NXd00
HJ1106:W@P1Q[CX0G;8a05^d:@1L]a`0G[HF06>e5P1W/aH0JK@O06Ra7@1_/aL0Kk8F072a601_[ad0
JK0X06Z`;P1i[b80R:`A09NZ4@2PYPl0XZ<A09fX3`2QYQ40YJ@E0:VQ5@2WVQD0YYHF0:VH5`2MWQL0
WJ0F09bP5`2?YAL0O:HR06j[>01/[c80Mk4X0080M[0V02L0M;0Q072_801_/B00K[4N076b7P1`/QX0
MK4F07J`5`1k/1P0OZdJ07n[6021Z1P0O:`G07b^6@1jZQd0O:/M07jX8@1lZ2L0PjLW07^U9`1nY2/0
M:LU076W8P1hYAd0Q:<Q082S9`28X2<0QY`X08:E;P1oUSH0NZ0b07ZO<`1fX3<0KYlh06n]=@1_]S80
Kl0U06o0801`_AT00P1a_A@09`1i_1D0N/0H07W06P1h`1/0ML0T07C09P1g`2@0Ll0S07K0901b`2L0
KL0V07309P1b`240Mk@T07Bf:@1b/S00K[HT06bh8P1d`240Ll0P07c0501h`180ML0B06o24`1aaA@0
LLDE07;55P1d`QX0L/0H06c07P1X`2L0J/0e06k0<P1/`SL0L<<g06[0?`1_`2`0M[PN07jf4P0208Rb
2P0W08Vb1`25]A80P[HQ082f7P1j/RL0M;TQ07:d<@1Z/4H0K;9506Ze@01Y`3L0JL8c06Vk>`1T[dd0
HieK06J@IP1bRVP0NhEZ07aoIP1nMVP0O7=/07Q`L@1^LWH0JW9`05j2K@1ITFX0IZUD07jc?02DWR/0
QI@o0967>@2iNb80^W/T0;Ye:@31LbH0_74b0;1d?P2dMdD0_7UA0080Z8]=02L0S9E;082M>028YAT0
T9d409NF002FTP00U8h009J@002DTP00Ti8009>A002CSP00Sh`008b9002?R000T8h009F=002CR@00
THP009::002@S@00T8T008n<002=S`00QhT008N30024Q@00Q8P008>80024R000PXX007n90021R000
Ph<008B50023QP00PhT008F;0021QP000P1kPP009`1dO000LW`006ei001aN`00Lg`0079j001cNP00
LGD0071`001/J`00JF<006YW001YI000IF@006=P001UHP00IU`0061E001JD@00Fdl005m>001JCP00
FE0005I<001CA@00Cd0004hm0014>000@CD0048e0015=000?Rl003X[000f9`00<RL003DX000c9@00
;Al002PM000202TM000;02PI000X5@007Q4001/=000J3P00610001D;000?2@002@<000<000010000
<@00000<0?ooo`002P3oool02@1]U`40KYX307:Q201eX@T0MJ8;07jU5020Y1H0Rj@J08^S6P0208bO
6P0908NO6022XQH0PJLG07jV701mXb00Nj4N07bP7P23WAX0QI`E0080Ri`G02L0SIlH08JO6`24Wal0
OJ8O07^S7@1fYAd0NJLR07JY6P1cZ0d0KjP806ZW201PYPP0F:L:05:T2@1=YPd0AJXI03^R>P0YSU`0
97U^021/NP0LLh406XJ;01NHRP0BX8d04inA01BQU00CXYH05J>:01BPP@0FUGX05h=f01IbO00FRGd0
5iUi01bQL00LVWD07I:101j7S00NM9400P0NE9L09`0MBIT0856G01mPU@0SIX`08fj:02I`S00TOHd0
8XV;022@S@0ORXl08Gn?021oS00TQhX0:8f702NCQ00SW8D08JAn01nYM`0O[G009:iW02N]H00Y/5H0
<K5903VdA016]3@0DkDT05Rd7`1G]b00F[DO05Zd801I/2D0GJdW05n];`1J[C<0FJhh05^]?@1KZD40
G:E705^SA@0205fS@`0W066S?`1SXSL0JZ0h06N]<`1L/RT0F;HW05Rf8P1H]Q`0GKLI05ne6`1S]240
H[<U06Be8`1U]Qd0IKHI06Jb7@1T/Al0Hk4Y06Bb=01^/BP0NjhE08N]5@2HZAH0WJPF09^Y6@2LYaP0
X:<L0::M7P2RTa`0Wi4M0:FC7`2LT1d0VY@N09fJ8@2GVa`0QJ8S07Z[<P1e[b/0MZdS0080N:dP02L0
OJ`K07J^801a/280L[<N076a701_/1L0M;4D07b_4`1o[aD0PJlC08B]4P27[Q80P:hC07n[501nZa<0
N:PD07nY6P1oZB00PJXN086Y8@1jZ240M:LP07NV901kZ2H0PJPU07nQ;@27XB/0RYX^08:I=01dVc/0
L9lg06nH>01[X3D0I:4g06V`=01/^RX0Jl0Q06c4701d`1P00P1h`1L09`1j`1/0Ml0Q07G08@1e`240
N<0U07[0:@1l`2H0Nk8W07[08P1f]bL0LKH[06jl;`1d]BX0M[4Z07:c;P1b/c00LkPT07Bi8@1e`1X0
M/0D07_04P1n`1<0Nl0D07G1501e`aD0LL@E07?35P1b`QP0L/4G06o16@1]`2<0K<0]0770;@1/`S<0
KL4`06g0=`1]`2/0L/0P07fh4`0208N`2P0W08b_1@2;]0/0P[LH08:h701l]B@0NkXM07Jc;@1][Sh0
LZY606faB@1V`400IL<m06Zj@`1XYeL0JiUO072>H01eSEh0NI9N07N>G@1kQEh0PGiR07egJ`1dM6/0
Jg1^06AlJP1NTFP0K:]C08N]?P2PTSD0VX/n09^5A02KQT80ZGTf0;Ib:P2iMBd0^G@i0;Ab@02bNTP0
]85@0080XiI901l0SZDn086X702?W`l0TIH009>B002HS000Uhd009R?002FSP00U8d009B<002>S000
SHL008f2002<PP00ShD00927002AQ@00Sh@00966002@R@00SHP008^6002:R@00Q8D0089n0020O@00
Oh<008200021Q@00Q8X00080OH@000H0OX400823001oP`00OhD008F60022QP0207Qo0008079h001_
LP00KFl006Ye001]M`00KGH006ia001]K@0206Y[000M06QX001XJ`00J6T006MV001ZI`00JVX006]V
001VH000GeX005mH001PE000GUD005iD001ME000G4l005M:001@A000BC`004Hl0016>@00ASX004@d
000k;`00>2L003DX000e9P00=2H002hQ000Y7@000P0Y6P002@0U6@008QH001X?000F3P005@`00149
000?20002`@00081000G00000003004000000000000001T00000303oool000X0oooo01@0M9T007:I
0@1hWPH0Mj4707VN201hY@`0NZ4@08ZO6P2<X1P0T9/G08jM6028X1@0Pj@D08>T5`23XaX0Q:<K08BQ
6`23W1P0PiXJ08RI5`80Ri`K02L0SIhJ08JO6P21X1/0N:DM07NU8`1eZAh0MZHD07JT3@1cX0X0LYh9
06VP2@1NX@/0Ej0A04jP5P1;XQL0@ZLP03JV>@0WW5407heT01n3KP0KRW806IAg01FQN`0CXHD04Z2B
01:RV`0CXi/04YnC01:GRP0DS80068Ak01QkO@0HTG/06j9f01jVL@0PXGH089Z2022=S00MNI@00P0N
FYP09`0LDIX07UNF01mXTP0QKh`09GR902MnR`0UR8/098n:02BERP0VT8`0:8N:02J5R@0WS8P0:Y27
02VHQ00VXH009:Qf026/KP0R/FD0:JmP02b^F00][T/0<k8l03bd<`1<]2D0G;HM05fg701L]1l0GK<R
05Z_9@1I[RT0G:h_05^]=`1I[400EZe705^ZA`1KXD`0G9Y;05bJA00205nL?P0W06:N<P1XX2l0KYl`
06Ra9`1P]ah0G[`M05bh7@1K]R<0GkDW05jd;01L/S@0FkDh05fg<@1K]BX0G;DW05^c;@1J]300G;<e
066c>P1W/2`0MjhI08B]5@2D[180Uj/C09ZY602NYQT0WZPI09nP5P2TWAD0WY/J09VG6@2MSaT0VIPK
09ZN7`2IV1/0RZ0N07b/:P1h[RL0LjdS0080MjhM02L0N:dH07R]7@1g/240Mk0J07J`6P1c[QP0MZdE
07j^501o[A<0PJTD086Z5P28ZQL0QJTG08:R6@26X1d0OJHH07fS8P25YbD0RjLL08>U7P22Xb00OZ4S
07fP9P1lYC00PZ@[086O:@27WbT0PiX_07nT<01gYC<0K:L`06FS<@1X[Rh0I;HZ06Jj9@1Z`1l0K<<H
06k35P1f`1P00P1i`1L09`1h`1L0M<0L07C07P1d`1h0N<0P07c09@22`240P[TN07c07P1e`2H0L/0Z
076h:@1f^R@0N;PT07^i8P1h^1d0N[TH07S05@1g`180NL0B08304P20`140PL0D07g0501l`1@0LL0D
07?05P1c`1P0K<8I06[0701/`2@0Kl0a07;09`1^`Rd0K/</06c2<@1^a2H0LL0L07fk4P0208Ve2P0W
08j_0`2=]0P0PkT>08Fj5`22^B00Pl0I07ji:@1c]c@0LZm006bcC01W`4@0JL1306fbCP1]Vel0KI1T
07>5H@1bRU`0L91J07B@E@1kR5/0Ph5S08=lH`1gN6H0LGIT06F3I01UUEd0MjU709^M>@2gP400`G=4
0;IbA`2aN500Y6a:0;1R=02dL3T0^G=50;M/B@2cMTd0ZXU@0080W:5200P0TZlZ08nT502BW@L0U9L0
09F=002DQP00TH/0096900<0Th`001`0THT008b50029OP00Q7/008Mi0028OP00RH8008Z4002?PP00
S8<008V00026P000QHP008240020O@00OG`007aj001nO@00QHD00825001oQ@00Oh4007io001oO`00
O7l007in0020O`00OWh00P1dN`003P1_M000J6T006ER001QHP00HfL006IY001YJP00J6/006M[001X
J`00JF/006E^001UK@00If`00P1/J0001P1]I`00J68006AM001UF`00H5L0061F0080GeH000l0GEL0
05QA001DA`00DD8004a1001:?@00Ac`004@f000n<`00>BT003@U000`8`00;b<002/M000X70000P0T
6@002@0P4`007A<001X?000D3`004@X000/600090`0010800080000H000000030041000000000000
01P00000303oool000X0oooo00h0MI@007ZG001hVP00N9d007NL001gW`T0NIh907bK2`2<WAD0SYTG
08jJ5`27W1H0QIdG08ZO6080RihI00@0S9XI08ZF5`2;UaP0SITK0P2?W1l09`2@Wah0Q9lI07jT601g
Z1P0NJXG07NZ3P1iXP`0NIX:07BF2P1`U`/0HI`;05FO4P1:WR40AY`Z04>R9`0nYbX0=JLg02bVA@0S
XU@07iiM01bPG`0KXf<05j=X01:QMP0CX8H04Z>B01:WU`0BXi@04Yb>01JHP`0HU7`079Ag01fNN@0L
Y7X07jIh026NO@0RU8T08XN?01ihUP0201mRVP0W025GV`0PG9T08FVB029dS@0TP8`098NA02B>T@0T
TY40:9>@02FCT@0[S8X0:HN602^=QP0/U8H0:ib602RTP@0WZW009k1Q02ZcF00]/5L0<JiD03:/B00i
/C40@KHS04jg6P1L]aT0H;DO062d9@1O/2P0Fjl/05f^<01K[cT0Ejm005J/B01GZTd0G:a:05fTB01M
X440H:4h0080HjL]02L0HJdU066`901Q/R<0HKDH05ji5`1M^aP0G;TN05fh;01P]C40F[<c05Rd?P1F
]d40EKPh05Bd<P1C]S@0E;@l05Be?@1D]Sd0Fk<n05j_<`1][B00O:`H09>Z5@2OYAL0Y9TI0:BJ702U
X200XZ0G0:JO6@2VVa`0X9PJ09fC6`2OUa`0XI/M09VB602CWA/0QJ`R07f_801e[Al00P1f[A/09`1h
[QL0MjlH07^_601l[QP0NJlI07J`6@1g[QD0O:h@07f]3P28ZPd0Pjd=086^3`1mZA40P:DE08VS6020
YAL0OjHN07j/8@1o[A`0OJTM07VU8P1kWBL0OI`/07ZP<`21X2l0Qid]08JM;01nWC<0OJ8b07NQ=01]
ZC00IZd^06_0:01Z`Ah0Il8J06k05@1c`A00M/0A07_0500207W05P0W07Rk4@1b_0l0Ll0D07?06@1i
`1X0OL0M08C0601o`1X0O<0L07Bi7`1i]Ah0N[HT08>h701o^AP0O/0E07c04`1n`100OL0A08;04@23
_140QkX?082j3`24`140P<0C07g04P1d`1@0L/4C07325@1]`Q`0I<8R06W2;01/`380Kl8X06_4:@1`
aBL0KLH[06o59`1aa280N/4D0080Pk/=02L0SKL6092f1@2<^@P0RkP@08Jj6P24`1L0O;XR076j;@1a
/cX0K[A906ZjB01Z[T/0Lj5@07ZBE`1cRE`0K85O06R1G@1YQ5X0LH9H0821F@28PU`0QH=O07j2H01a
P640JhQL06nEDP28Y3/0YYD^0;J0:@2nMC<0_W@d0;Q^=@2eHS`0]e/m0;=Y>02aL3l0[Ve70:QfC@2L
Sdh00P2:/3809`2?[QX0Ti`909NG0@2DUP00TI<0092<002>R000S8T009:;002CR`00THd008n6002=
O`00RGd008Ef0024MP00QGT008Ak002;OP00RX8008R00024P`00Ph8008J50024P@00OW/007ag001i
N@00Ng/007Z0001nO`00P7d007eg001mM@00O78007Qa001hK`00Mfh007EZ000206i_000W06a[001W
I@00HUl005YJ001OG000H6L0069X001PJ@00I6T006=Y001RI`00HVX0069V001SI@00If8006YT001[
H`00JV8006EP001VGP00HU`0065J001MEP00FUH005aH001IE@00Edh005A7001=A000BT<004Ll0012
>000@3D003P^000c9@00;R@002/R000[7P0091T0008081H000P07A8001T@000E3@004P`000d70008
10001040008001T0000000<00@000000000000006000000<0?ooo`002P3oool0501eU0<0MYL107NI
001hW@00MYl007>N001dWPH0NId707bQ3`1nWa40QilH08JQ602;WQL0RilF08ZR602>WAX0Si/F092F
5@2:UaH0S9lG0P2;Y1L09`27Xa@0OjDE07jZ4P1jZ`d0MjT907>T2@1eW@T0NIP707VF1P1_V@T0I:4;
05NT4`1:YB40@j8[04:U;P0nZc00=J`h02b^@P0T[Th08:]A01b[D`0JZU@05ZUI01FSJ@0FXG`05:J;
01B[S`0EYi805:2D01NLRP0IX7l07j=j01fUNP0MZW`08:Mo02>PQ00QTH`07hBB025hU`0202EZV@0W
02QKVP0VH9P086fD021kS`0RQ8l098fB02>BTP0STiL09IBG02FDU@0WTXh0:Hn602ZBQ@0[UhL0:in2
02VXO`0Y[VT0:k9I02jdC`0a/dd0=[1<03V`@@0o]BT0B[DM05Jd701O/b@0Gk8[066`;P1R[Rl0HJ`a
062Z=01O[Sl0G:a205NYB@1JZ4P0GJM105jT>`1OY3D0IZP^0080Ik0R02L0Gk<M05^f7P1N^A/0Gl0H
066k5`1T^A`0GkTS05bh;@1O]C00FkHc05Rg>@1C]S`0DKDi056d=`1@/cT0C;Dl05:c>`1B]S/0F;<o
05f`>01X[R<0NZ`H08nW5P2NY1L0YYdI0:NH7@2WW240XidL0:JM6P2TVQd0XIDK09f@7P2QUQ/0XiLM
09fA702CVaX0QJPM07Z]8@1d[Al00P1a[A/09`1fZQ`0NjTM08BT7@24Yal0OjhL07R`6@1g[AP0P:PI
07fX3`27Ya80QjXG08BX5P1oYQL0P:DK08jW7025XaX0P:8U07bY9P1nZQl0N:PS07>Z9@1lW2@0PI`Z
07bU=021YB`0Pj8W082R:01fYC40MJX_07:^;`1`/R/0L;<W07307@1]`1P0K/0D07?04@1j`0l0Nl0A
07W0500207_04P80M<0=02D0ML0>07[03P1k`0d0Nl0>08?03`1j`1<0O;TD07Vh4P1j]a@0Ol0I0870
501n^QH0O/0E07g04`20`0l0O/0>08;03`23`0l0Q<0?08>j4025`140PL0A07g04`1e`1L0L/0D06O2
5P1S`240H/@/06O6;@1ZaC40K/H/06_5:P1``Rh0L<0c07;2;`1b`2T0M<0H0080Nl0A02L0R[H:092c
0@2>]P@0SkP:08Rh4@1n`1D0N;/R076m:@1`]CP0K;E4072_B`1`Ve80N9ED082?EP1^ReP0JH1M06Qk
GP1UMEl0KWYN081nF01nQUd0OXYQ072@F`1[U5P0LYM=086I@02HTST0YXDa0;5i7`2gO1X0_GLJ0<UY
5@3BHbP0eUXn0;MP?@2ZHSh0YVe;09ilCP2=STL00P25/2L01`2=Ya40TYD309JA002FT`00UI@009:=
002=Q`000P2@Q@007P2?QP00T8P008j8002>PP00Rh8008En0025NP00Q7T008=h0024O000Pg`008An
0028O`00QX8008Z3002:P@00QWh008Mk0022OP00Ogl007ml001oN000P7<007]b001hK`00LFT006aO
001^GP00KUl006QP00<0JVL002H0IVD006EQ001PGP00FUX005]M001MG@00G5l0061R001QHP00HfH0
06=W001SI@00HF4006AN001XH`00JVH006YY001XI@00I6D006ER001QH000GET005aG001MF000FUP0
05QC001AB`00CdL004]60019?P00@cT003ld000f;P00<RD002hR000/7`009ah002DH008071@000P0
6Pd0018<000?2`003@P000T6000710000`40004003@00000303oool000X0oooo00D0M9H007BK0@1a
W000LYl0076P000207:N000=07>P001cY0X0MJ8:07NQ2P1oY1<0Pj@B08:W4P23Ya80QJ0E092K6@2?
VaP0Ri`J08JS5P0208>U5@0W07bV4@1kY`d0NjX<07JX201cY`L0LZ<707FP1`1eW@<0M9h406fR201Z
Y@X0GjL=056W6018YB80A:L[03fY<00eZcL0;:a302BVCP0PY5<06Z9F01RUD`0GYU806Z=L01RNK`0I
Xgl05jF701JTR`0FX8h069b:01fROP0MYWL07ZUi01bYP00NZ8D07Z29022>S`0PQ9<08gjC008097VG
02L0:W2F02McT@0QOXd088B<02>8SP0RSY408I2A01nBTP0RTXh099>802NDO`0XU7`09iUm02^MN`0[
Y7P0:JUc02Z_HP0^]5H0<KI903Fe@00i]3l0?kDf04Zg:01E]R80F[@V05bc=01K/C/0GZlh06:_=P1Q
[3D0Gj`i05j[@01MZ4P0FjE805fXA@1QZS/0HZda06B^9`1U[b400P1Q]1L09`1L]1L0G;DG05nj6@1R
_ah0I;PQ06:f9P1O]bL0Fk@]05Nd<01E]c40E[Le05:o<`1A]SX0D;Hk04jf>@1?]cL0DkHi052e?@1E
/d80Fk<o06B_9P1oZQP0SjHE09bQ5P2UWa`0[9LP0:nA8@2XUaP0Yi/H0:^B6`2XSQX0XhdK0:N@702[
SA`0Xi@M09VJ7027Xa`0NJXN07F[7P0207>/6@0W07B/5P1lZ1T0Q:@L08>V701kZaL0MZ`E07N]6020
[1L0OjT?07fW3`20ZQ`0P:PK07VU6P1lZAX0RZXL07jT7`1gYRL0MZXU07VW8@1gY2H0NilV07^D9P1k
UB`0PIlc08>U;027X240O:0/07JM=@1cZS<0LZl^076e:@1`_RD0L/0O07;0601d`1D0M/0B07[03P1j
`100M/0A0080Ml0A02L0NL0@07[03`1i`0l0PL0=07o03@1o`@d0PL0=08:l4023^a00OKX@07fh401l
`140OL0B07g05@1j`180OL0B07o03`20`0d0QL0<082j301o^Pl0O<0A08Bh3022`0`0Ol0B07C05@1[
`1L0H/0I06;0801T`RX0J<8V06S5;`1W`Bh0Hl4a06S0=P1[`4@0K<0f06k0;P1d`2000P1l`1@09`2>
^0X0Tk0009>a002>^@H0PkT907[04@1``200Kl0Y06ff=`1]]4D0LZY@06nKF01aUe/0LiIH06nHD@1c
Te40MH]D07:0F01gQ5D0NHUF07R;FP1cU5X0IJa?06JfB@1m/CL0TY`d0::4>02XOC/0[7/h09j2=02S
ORl0_7<F0<UY8P3DHcD0]Um20:YSC@2YL4l0Uh9C07jK@P0208B[6P0W08fO1`2AU@40Si@008jE002@
UP00TI00096>002?Q`00Rh0008Qo002=PP00Rh@008b3002<O`00Rh0008ao002:O000RG/008Mk0026
N000Q7`008Uo0028P`00SH4008^20028O@00Q7d008Ei0022N@00PgD007i_0022K@00O6`007EZ001a
I@00Jf4006]L001[F@00KE`00080KV<002L0K6D006QY001VIP00HV0005mK001KG000G5X005eL001K
G000G5T005eP001SH`00GfD0065N001OF@00HUX006=N001UH@00Hf4006ES001TH000HUd005iJ001K
E@00FUH005]G001DD@00DDX004i4001:@@00BD0004<i000m=P00>Bh003<X000]8P00:ad002HK000T
6@000P0J4@001`0C2P003PL000/500060`00108000<100010000=@00000<0?ooo`002P3oool0501`
VP00Kid106fM001/W@00LZ0007BO001fX@00MYl007BP001gY0L0N:@807bX2@1jZ0T0N:T:07fV2P1o
Y0X0RJ<E08JT5@26YA@0Oj/D0P1nZa409`1jZ@d0NZP:07VU201gYPP0LjH907JS2P1eX`X0LYl8072P
201bX@P0LJD806NW2P1HZA00CJXK04:X:P0nYcH0>:Lk032TA00VWdl08iYI026FG`0PXU/07jEF02:R
E00OWF8079m_01bPMP0JWG/06IYm01VHP00JW7l06imo01bPPP0GXh`06:F@022OT00OU9@08Y6B02><
T`0202B;TP0W02N:S@0SSHT08Hn602:>Q`0UShX07hj;022@R@0MTXL08I>402>BN`0UTgD0:IYc02VO
L`0YXgH0:JI_02VZJ@0/[el0;[9E03:eAP0f^C`0?;Xe04Ji<01?^2/0F;DV05bb;@1G/ST0E[4n05j^
?P1T[Cd0HZ/l062X?01OYSl0GZHn05bT@01RYcP0I:h[06>c8`1M]Qh0E[LH0080EL0F02L0EkXF05Zi
5@1Q_QL0IKTS06Bh:01R]R/0F[H^05Re<P1@/c@0D;He05:g<P1B]C@0D;Dm05:g?@1@]ST0DKDf04jc
>@1>/d<0D;A605Ja@`1Q[BT0MJlD08nZ4P2LXa<0XJ4E0:RI702cSa/0ZY<J0:JC702[SQX0ZX/I0:>3
7@2YQb00[8/P0:FD8P2JV1d0Si/Q086R8P1iYQh00P1dZAl09`1mZ1h0OZPK08:U702:X200OZ@D07:U
701iYad0PjPI086W3P22ZQ40Q:TJ086W6@1jYQ/0PjTH08^Y6@1mXa/0MJXW07:Y8`1gY2<0Mj<O07RM
8@1iVBT0OIl_08:Q=022Y2l0NZD]076Y;P1^Zc40L;8`072f;@1/`2H0KL0R06k0801d`1/0N<0E07[0
4@1j`1<0M/0D07C04P0207^i4@0@07^f4P20`1<0Ol0C08;04P24`0`0Pl0=08;03@21`0l0Pl0@08Bj
4023]`l0OkP@07Zi4@1k`140O<0?08Bk3P80Q<0=01D0P/0;07k02`1l^Pd0O/0=086i2P21`0`0O<0D
07?06`1/`1h0GL0R06?08P1Y`BL0J<4R06G39P1Q`RX0H<0a06?0>01V_4<0J<0f06[0=P1b`2<00P1m
`1D09`2B^P`0Uk0009:a002<]080P[L607g03@1d`1X0L/0T06jg=P1_/T80LjM806fME@1_VeD0Li]D
07NGE@22Ue@0QhmD08>9E@1iRe00NY1<07^FB01^Z4H0K;`k07K0=P24YcL0TIDk0:j0>@2hN400^g93
09imC02AOdh0[7TX0;ae7`39JbD0/f=30:]RF02aLe@0VhM>082V=P0208BU4`0:08^I0@2<U`00RYD0
092D002?TP00TY0009>?002?R000S8D008Yo0080Rgh001/0RH0008Z0002;O@00Rh4008]n002:N`00
Qgd008Ii0028OP00RGh008Z3002>PP00SGl008Um0022M@00O70007i[001lJP00NFL007MU001cIP00
LV40071V001]I@00Jf0006aP001ZG0000P1_GP00501]H@00JF@006EQ001UF`00HV8006AT001SI@00
Hf00065N001RGP00H5h0061M001MG000FUD005UF001HF000F5T005UI001NF`00G5X00P1KF@004@1L
F000F5@005AF001DD@00EDl0055;001?BP00BdD004]20017@000?cT003d`000d:@00;B4002DJ000R
5@006a80008050`000@03@L000P300070P000`800P01000f000000`0oooo000:0?ooo`0D076I001a
W000KIl006jM001eX000Mj0007NU001cY@00MZ8007VS001gX@00MZ@607>T101cY@<0MjD807VR201n
Y@h0O:@=07bV3P1kZ0l207VV2P0W07ZY2@1kYPP0Mj@:076U3@1cX`d0Lj8<07BP3@1cWP/0LZ0:07NO
2@1eX`L0KJ<805fV301>YaL0AZHX046U=00jYS/0<:A602NID00SU5d08hmW02BII`0TW6808i]L02:I
G@0PVVL07YU^01jCK@0MTg006YEg01^HO00GVXH05iV801RKSP0HWY4079fE01jJV@0NVIP08IRD0080
8YVD00`08Yf9026OP`0QW8008I>2026AR00OT8X07Y2601fDP00TV7`09YQa02VHJ`0WWV`202NTKP0I
02RVIP0XZV80:k9H02jcDP0e]T80=kPd042i;P19^2L0E;DY05Zc;P1J/SL0F:m005^^A01P[TD0IJ`o
06J/?`1SZC/0HJDk062V=`1TYS<0I:`U06N`6`1X_AT0HKdE05fm4`020630500W062h4`1Q^aH0H[XN
06>g:01O]Rh0F[Hb05>e=P1<]S`0AkDm04Ne?01:]CP0Ck@h05:d?P1B/d00CK8n04^`?P16/D@0B;=@
04^bC`1A[4T0Fj`/06n_5P2<ZPl0W:8@0:6M4P2VVAH0/9<E0:FB702NTAh0ZhdG0:J:6P2SPb80YXPR
0:Z>7`2XTb80Xi<L09>K7@22Xal0MjLS0080Mj/T02H0NZdQ07ZY8P23Yb<0RJ8N07fO6`1eXR40M:@P
07JX701e[1H0PZPG08:V7@1lYQ`0Nj@L08BS6P2;X1H0N:@N076Z:01aZB<0NZXU07ZP;01lWBL0Lj@a
07NW=@29WS<0O:<c072T=P1Z[C00K;<`06fi;P1``2L0K<0N06jo6P1]_aT0MklJ07fo501l_a@0N/0F
07_060@0Ml0H02H0Ol0G08C06026`1L0P[XE08;04`22`0l0Ol0>08303@26`0d0Q<0=07k03`1m^Q80
OKTA08Fi3P24^Pd0Q;h<08703@21_Pd0P;`>082j3@1o^P`0P[T>07g04`1i`1@0Ll0F06c06`1V`280
J<0R06O08P1V`Al0Gl0T0630901P`2d0Gl0b0630?@1T`C80Il4_07708P80Nl0G02L0S[/:09Fe002G
/@00Tk80092g1@2;`0h0PL4K07g09@1e_3D0L[I307BWA01`ZD80JZa506Z[B01`WTh0NIQ@082BDP1l
Te80KYQ:06fQ@01[/SD0LKT_07Rk;P1m]3<0RI`l08n=@@2/PC<0^7Xf0<1c>@2aL4@0YVm40:ae>@2g
Kc<0_78_0;QZA@2_JU40[7A;09>FA@25ZR400P2=W1405@2:S`00RXT008j:002<R000ShX008j;002<
S`00T8`008b5002:O`00RH0008f2002;O@00RWl008^1002@P`00T88008ao0027O000Q7D008Af0002
08Mi000@08Mk002:OP00Qh<008Eg0020K`00OVh007a]001eI`00L6D007=T001dIP00LF`0071[001`
I`00KfD006]Q0080KUh002L0KF0006]L001YG000IUP006EK001TIP00JFL006QY001YI000Jf<006QT
001YI000HUd005iH001KE`00FEP005QI001GF@00EEH005QE001GD@00Ee@005MC001BD`00DDl0051?
001?C`00Cd/004e8001=A000B3l004<m0011>@00?CD003@/000[7`008QP001`B000E3@000P0<1`00
10060P000`4000800002000h000000`0oooo000:0?ooo`0A07NC001dU@00LYX0076K001fW`40NJ<1
07JV0@1eY000MZ<007RR001gX000LJ<0072V0P1aYP80MJD707VQ1`1jX`L00P1hY@L0:P1iY`L0Nj@7
07^T1`1hX`P0MZ0807BP2P1aWP`0Kih;07:I301cVP/0M9`<07RK201jV`L0NI/2076N0`1RW`X0F:4C
04jS9@16YC<0?jDi03:RA00ZUU<09XaS02B2J@0VRV/09I1U02FBI00TTFH08iE[01nHK@0PUf`07iM^
01jHM@0JVgl06I^:01VKS@0HVHd06IZ@01VJU00JViX06ibM01^KV`807IZG02L07If>01jOQ`0PWH@0
8IJ602:DRP0NU8h079N<01jMQ@0TX7d09Ym`02ZLIP0YWfP09j=[02JTJP0XY6H0::UP02b^F`0a/e80
=kI103^f=`13]S00CKDW05B`:P1H[SD0FZ`n05b[?`1O[440I:e006R/?01SZcP0Ijdc06J];P1V/RD0
IK4M06Bb5P1U]Q40IkdA06Bg4`1P]AD00P1S/Q/09`1P/Qh0H[8V066a:@1M]2l0Ek@d052c>P16/T40
AK=504BcB015]d40B;Tm04Vc?P1;/T40Bjm704^_B@17[d/0A;9?04FcF019/U<0D:e<05R/<`1[[a`0
R:PD09VM402MUAP0XY<B0:RD3`2OT1`0WXhM0:R@5P2RR1X0XH8R0:J:8`2YT280]H<N0:b<6@2HVaT0
R:DQ08JW8`0207f[7`0W07Z]7`20ZbH0QjLU08:N8P21VR<0P9dU07:P9@1fYBL0PJLO08FV6`23WAd0
PJ4N08FR7020XAP0Mj8P07bU8@1mXQh0NjDN07RW8P1gYb40N:LQ07ZX:`21YRT0RJDW07JW<P1WZSH0
H[@c06Fj<@1^`300M/0T07Bo6P1d^QL0N;`H07_05`22`1<0Ol0G07o06@1o`1L0P<0F0080O<0E02L0
O<0G08;06@23`1`0PKPL086h6`23^1P0Ql0A08C03022`0/0PL0<08303`1n`140OkTC08Bi5027^Q40
Q;`=08>l3021^Pd0PkX?07o0401n_@h0O<0=07bk501h`1P0N/0F07K05@1b`Q`0J/<Z06S18@1T`240
IL0R05o0:@1P`2D0H<0Y06;1<01U`CL0JL<]06[1:@1b`1h00P1e`1d09`22`0`0S;X209Nf0`2F]`X0
U;`:09305025`Al0Ol4P07K0;P1a^3T0KJi206^`?`1V^3P0HkPj06Z]@01cYDD0OIe407ZPA01_YSd0
JK4c06jg:@1e/R`0OJh`07nR>P2;U4<0TXI40:]m<@2dO2l0]gPW0;m/=030H440/eM70:mSBP2gKd/0
]V]>0;=YD`2ROT`0SiLe08FQ5P02096E2`0R08f90028P`00RX000921002=P@00S8L008b6002;QP00
SH8008b10028P@00Rh@008b2002:P`00RX@009B;002BRP00THT008f4002;N`00QWL008=c0024L000
PFl008=d0025N000PgH007ie001lLP00NFd007I/001`I`00M6H007MX0080MVd000<0LV`0075X001c
J@000P1cI`005`1cIP00KV0006]G001VF000IEX006QT001YI`00JVX006]Z001[J000Jg8006a^001Y
J000I6<005mO001JF@00FU/005]L001LF000F5P005MF001AD`00DDl00080CDX000h0CdP004e;001<
AP00BTD004E30010>`00?3D003Xb000h<000;bP002LN000K5P005Pd000h900801`<000<00@000000
00000000>@00000<0?ooo`002P3oool0501fT`40MI8007BG001cV040MIh307RM0@1iW`40N9h007VO
001iX@00MZ4007JP001eXP00Mil007fK001mV000OIX007jP001nXP80Nj<80P1jXPT09`1gX@T0Lj09
07FO2@1aW`X0LIX:07:G201bW@P0MIh707VP201gX0P0N9h807:M2P1[W@`0H9hB05JO7P1?Xb/0AjLf
03RPA@0^TED0:XEW02UhK@0VNVl09Wm]02N4K@0UR7009Xmd02:FN00SVWD08iYh026IO@0MVX406In7
01VRQP0HX8H069b801JESP0GTiL069>I01RCV00201ZCT`0W01bCT00PU8d08IN<01nCS`0NT9@07I6G
01fGUP0MWXd08J>102BRM00YWf/0:9iX02NQK@0WXVT0:J=W02VXGP0^[E`0=;AB03fg@P11]CT0Ak<a
056`:`1IYS40G:@l05jW@`1RZd@0Ij`m06VY=`1W[2h0Ik4/06Vc9`1^]1`0K;DH06Vf4`1W]Q40J;LB
06Vg5`1W]Q`0Hk8Q0080HJhU02L0GJdX05b[<01J[CL0E[0j04be?P16]T40@KA2046dA`12]dH0AL0n
04G0>`19]cd0B;A304RcC@14/U40@K5D046dE`14/eT0Bk9;05B^?`1K[Bl0IZ/S08JT5@2IW180WI0P
09Z@4@2XSQ00X8HR0:J98`2YTAP0XHLO0:Qn:P2YR280ZhlR0;>8802RSQT0SiPN08VR8`24ZAd00P1g
Za/09`1f/1d0PJdR082Z8P21Wbh0PYh/08:O8`1jWBX0OYdZ08BS8@24Wah0QIXT08NJ8@28WA/0NIlM
07:U9`1oXB<0R:0M07nM901lXBL0N:8O08:S9@25Xb<0S:@P08bQ8P1kY2d0KZTb06Nb<01[^Rh0K/0Y
07C08P1c^A`0ML0H07G05`1j`1T0O/0F07o06P1l`1P0P<0D07o04`0208304@0P08705`21`1l0P<0G
08305`1n^QD0P[DA08Fi3`24`0`0P/0=07g0401m^aT0O[HG07ng5027^A<0Q;`A08>m4022^0l0PKT>
086n401j`140Ml0A07C14P1c`1L0Ll0O07?25`1a`QL0L<<P06c2;`1Y`B80Hl0Q06;09@1N`2d206G1
:00506S2;@1T`cP0K<0^07308`1d`AP00P1d`1409`1n_@X0Rkh809Rk2`2E`0`0TL4H08c07P27`1d0
Pl8K07_57@1a`bX0K[Xk06W0=`1X`380J<0`06W0<@1/`2/0LKPT07Fi9@1d]bL0L;8[06j_;P1a[c<0
NJXb082P?02<V3d0Uhe20;9n?`2dNC/0/gL_0;U_;@30GCT0^UA@0;=IGP2_IV@0Z6UK0:5/E@2=PE<0
RIH/08RB3P0208^90P0W08^2002;O000Rh0008b3002>P@00Rg/008Yl0029OP00Rgd008Yl002:OP00
S7h008V0002;P`00RX<008j3002>Q000Sh@00964002=P@00Rg`008Yi0022LP00PF/007i/0022L`00
OWD007]`001iK000N6d007I^001cK000MFT007Q/001eJ`00MFh007AX001dJP00Mf`00080MFh002L0
MVl0075S001[F`00IEL006MD001WFP00If0006MV001YJ@00Jfd006ed001_L@00KVh006Y/001XI`00
HFL0061V001RHP00HEh0061L001JEP00FDl005I=001BB@00D4X004e9001;A`00BTP004U70015@@00
@SX003de000h;`00<R/002/R000Q6@006@l00189000:10000P03000l000000`0oooo000:0?ooo`0D
076I0`1_V040L9T107>J0P1dVP80MIX107VJ001lV`00NY/007VM001hW`00N9`007ZK001lW000PYX0
08:I0022U`00Q9h1086P1P1oY0/207bS300W07RQ301bXPX0Li`907>L2@1dV@L0M9X607BM101dXPL0
MJ@807BU1`1bY0P0LZ0906nP2`1WX0d0GZ8G05JT8P1;Xbd0@:4m03BHC`0aRV80:ga_02EeM@0WMG@0
:7Ye02R2N00VRWd08YB001jIP00PVh007iR601bFRP0HW8/06JB901RRQ`0IUhP06HR:01R4T@0IPiD0
6H>C0080686C02L06gjC0261T@0QR9L07hbI022;V`0KSJ007IBJ01fLT`0OXHT08j=m02JQL`0WWW80
9:5d02NRJP0ZY6L0:jUQ02n]GP0k]500@KE304Nc=P1?/Rd0F:l[05jX<@1PYSH0IJXe06Z^=@1]/2d0
KJlQ06^a6@1/]QP0K[DH072e4P1]/`l0JkD=06Rh4P1X]aX0IKLV06:c:`1K[S800P1MYSD09`1KXcD0
Ej@l05J[@01@/440AkA2042cA`11]DL0@KI804:j@`15`3h0A/0j04Ri>P17]T40A;E8042dC`12/EX0
@;9I04RbDP1=]480F;0e05f`:@1X[RD0QJPH09FM5@2NRQl0VXXD0::<5@2PPRH0YX@S09f=602QQb40
[W`Y0:N86`2VSR40/hTU09^:602>SbX0RI`T08BV6@0207RZ6`0W07fZ8025ZQ/0QJHP08jN;`27WRX0
PZ8U08BM;P25X2L0PJ0R08RN8@2=Ual0Q9dM08NN7`1oX280NZ0T07fP9@1lY2@0OJ4R07^R7@1gWb80
Oj@S08bS8@2>XR80RYTZ086S=01gZcL0M[@/07O09`1e^B80M[HP076i7P1f`1d0Ml0J07[06@1m`1L0
Ol0I07g15020`100P/0B0080Pl0B02L0Ol0G07g07`1m`1H0O;TF07Rd7P1j[al0OKPC08?03P1m`140
OK/I08Ja8P29[2<0PkHE08>i4P23_A40P[PE08:g601o]aX0OK/G07S06@1g`1P0L<0I07?07`1c`BT0
LL4P06[06P1Z`1l0JL4V06S17`1R`Ah0H/0V0630;@1V`RD0I/8W06[2:01W`3<0KKhZ06k08P1d`Q<0
0P1f`0`09`1n`0X0RL0<09Bm302@`AT0RL8S08S28P2:`B80Pl@L07g96P1gaQd0LL<U06_19@1_`b@0
L<DR07C38@1c`ah0M<4M07S07@1f_2D0M:l]07FV=01cYcP0OZLg08JP?02<UCl0V8Y60;Eo@@2hM4<0
]VLn0;Ea;P2kIbX0aU]80;YNFP2/H6X0WFEV09I/G021SDl0PYTW08J7200208In000W08Mk0028NP00
Rgl008^2002=P`00RX0008]i0026M`00QGH008Af0025M`00R7X008Qm002=OP00S80008Z20029Q000
Sh0008n2002>P@00SWh008Ie0022L@00PG80085c0020L`00OVl007U]001hK@00Ng8007]c001iLP00
NW8007]`001kK@00N6d007E[001fJ000Mf`00080LVd000/0LF/0079W001/H`00J5`0065@001NC`00
G4d0061D001VH000Jfh006]a0002075b000J075e001`LP00KgD006aa001ZK000IfL006IQ001TI000
HUl005aI001ID`00EDl0059<001>C000BDH004Q60018A000@C`003Xb000b:000:b00028J000N4@00
4PT000/60006000n000000`0oooo000:0?ooo`0D07BI0@1bV@40LY`107:L0P1fV`80NI`107NG001j
VP00NYP007VI001lW`00O9`007fM001mVP00P9H0086G0022V000Pj0308>N2P20X0/207bT300W07VT
2P1aY0`0L:0;07BM1`1gWPP0Mj0:07:T2@1dY@L0LJL7076T201`YPL0LZ8806jQ201WX0T0Gj8@05NR
7@1<X2`0@ilk03bOAP0gUUL0<HEX031hM`0aKW`0<6im02ecO00YOWd08XZ101nAP@0OT8<08Hj301n?
Q@0KVHD06J6501bQQP0KV8D078V901b4S00LPhl06h:@00806X2>02L077b@0220T`0OQIL07hZM01j<
W00PS9X07YFH022LT00PXXD08J=m02BQM`0SXG409J=`02ZSJ00]Yf@0;jYL03J_DP10/TL0B;@i056d
;01O/Ql0Hk0O06R^8`1Z[200K[0L07:`6`1d/AH0Lk4B06nd4@1Z^A<0J[/F06Vc5`1U/a@0Hk8H06Fc
6`1S/bL0H;8^05Za<P1IZS000P1IZ3809`1EYc@0DZTj05:Z@01=[T00@k5103jdA`11]DT0@[M704:i
A013_480AKa004:l>`13^3l0@[M3046fD`0o/ed0?k=J04BbD@1;/cl0EK8e05Va:`1W[bT0QZXN09BN
5P2NRah0X8TI0:F7602VOb<0WX8L09:<6P2PRAh0[h8P09n=6@2OTR00[hTL09V=5P2<S280P9PK08>U
600207jQ800W08>R801nYQ`0R:DQ08bL9`23XB40O:LV08^N:@27WB00RiLV092J902?UR00RITT09>J
9P2<VR80QYXQ086P;01nXRX0Oj0L086Q7027WR80SJ@O08jQ8@28Xb80QZ0`082[=01j[c80NkD[07S0
9@1b^B80LkHS07>l8P1h_2<0M/0S07G07P1l`1/0O<0L07c26@22`1D0P<0E0080PL0E02L0O<0D07k0
5@1o`100P;/?07nj4@20]1@0PKP?08303@1n`1<0O/0I08Jh6`27/Q`0Q;/F08Bj4`25`1H0P[TH07ji
6@1j_AX0Nl0F07Rm601f`1/0L/0N07C09P1c`2h0L/4R06o0701]`1d0JL0K06g1601X`AH0I<0O06G2
9P1Y`b00K<8Q06k38@1Y`BT0K/0U06g09`1d`aT00P1ha1009`21`Q00Rl<D09306@2=`RD0QlDZ0875
9P27aBP0QLPS08?3801l`Ql0NLHN07?77P1faA/0MlDJ07[27P1h`b00Ml8T07S0:@1d^C00MJlf07JU
>P1fWcT0P:8g08fJ>P2=T440ShY70:N7?02fNCl0^V=80:5`A`2BMT40^6i20;IZDP2^HV@0X6IT09Ed
G01kV480OiPP08>31`0208If000308]d0028N`00RWl00080SX000280R7d008Qg0029M`00R7X008]l
0024O`00QX4008Qo002:O`00Rh0008Z3002;P`00R7h008R2002<P@00Rh0008Mh0025N000PgD007id
001mLP00Nfd007a`001oLP00Og@007ee0022M`00PWX008=m0023N@00Ng<007Uc001jM000NW<00P1c
KP009`1`JP00KVT006e[001/H@00IeT005]>001IC000FDd0069I001YJ000LFl006md001bMP00M7H0
075l001bN000KWL006ec001WK`00JVP006UZ001ZJP00I6<0061J001IE000E500051;001=AP00Ad@0
04I30012?000>C0002hU000R60006a40018<000<10001`400040000n000000`0oooo000:0?ooo`0D
06nK001_W000L9d107:O0@1dW`40MY`007RK001gV@00N9X007VK001hWP00NY`007ZK001mV@00P9P0
08:K001nW@80OZ8707nP2@1nX0X207^W3@0W07RU2P1gX0T0MYh:07JP2@1iX`X0NJ4;07JR2P1fX@T0
Lj8907JQ2P1eX0P0L9d706bK1`1ZW`P0HZ4<05NS6@1:Wbd0A:0k046TA@0lXDl0=i=R03AlN@0iIhH0
=Ej503=SO@0ZLGh08gj302:3P@0SPGl09Gen02B4O`0QTH407J23022TQ00SWH809IN402>?R@0RR8d0
88N@00808hZ<02L08hZ;02:8T00PQiH07hRI022:U`0PS9808I>@02>JRP0TWh@09j1n02VPM`0XWFl0
;Ym]032RJ`0aZ680=ZYG03^^@`1;/S<0E[8Y062c701`/AD0LjhD07B^5@1f/@l0O;4?07j_3`1h/@l0
L[<@06^e501W]Q`0IKDT06>b9@1O/RD0Gk8Y05bb;@1L/S00F:lc05J[=@1DZ3800P1EYS<09`1?ZCL0
C:do04fZ@`1<[400AJm004:e@P12^4<0A;Q304>g@010]D@0@;I2042l@@0l^3l0?<1803^eD`0o]Ed0
>[AH03ncBP14]3l0B[8h05:_=P1S/300PJPS09:M602LSah0Y8XM0:J7602PPB80W84O09R96P2RQah0
[X@P09V<6@2KSad0[8/B09N;5@2@RAh0Q9TF08jP5P0208jK8P0W08bI6P20XbD0Q:8P08bO6`1nZ1`0
OJP/08VS8`2;WQh0T9HV09:H802;V200QIdP08NQ7`1kXR40P:0V07jO:@1nXR80NZ0P07bP8P26X2@0
R:0O08VK9`1oYRT0OZDa07^_<`1g]RP0MkTW07Rh9`1d^BD0MKLW07C0901i_B80NKhS07[08@1i`2<0
Ml0Q07W07`1l_1/0PL0G0080P/0I00T0Ol0D07o04@1o`0`0Pl0:086n3021_A00O[/B07^l4`1l`1D0
0P1k`1L0701m^AT0P<0K08707`21^R40P;TQ07fl5`1l`1D0P;`D07o05@1l`1P0M<0M07O08@1c`2T0
Ll0T06k07P1``1T0K/0E07705@1/`AD0Il8H06O3701Y`aT0KL0K06c17P1[`240K/0P06o09P1_a1d2
07C35P0W07g6601o`a`0R<0X08C3<022ac00O/LZ08C79@25bB<0Q<DR08318`1oaA`0OLTK07k6601o
`aP0O<<I07_16`1l`200NL0W07Jl;P1d/3<0N:Te07nS>P28WS/0RI=0096A@P2IRT<0X88l0:ih=@30
K3P0WFm908QiF02PN4/0]71>0:]XHP2PLF@0U7eI082J=P21TQP0Q7h60080PG@000P0Q7@008Qj002<
O`00SH8008V1002:N`00Q7P008Uj0080Rgh001d0S80008Z1002<P000Rgh008j3002?P`00SGl008el
0027N000QGd008Ak0022NP00PX00085n0021NP00PW@0085`0023M000PgX0085e0021N@00Pg/008Im
0025O`00Pgh007]l001kO@00NW`007Ye000207M`000W075/001]J`00K6L006]R001XH000He`005UI
001GD`00G5D006=O001/I`00K6l006ad001]MP00K7P006ih001]N000KgL006ic001ZK000Jf/006]]
001XJ@00HV0005aK001JE000E4d004a60019@P00A48004<m000h<`00<2P002@K000H4P004`X000/7
00060`000P4000800@400P01000j000000`0oooo000:0?ooo`0D06VO0`1YWP80Jil206jQ0@1ZX000
KJ80076N001cW@00MYh007:M001eW`00N9h007ZO001kWP00NYh007RO0@1gX0@0N9h707RP201lXPT2
07^W2P0W07^V201kY0L0Nil607VO1P1hXPX0N:8;07RQ2`1fX0/0Lid;07>L2P1dV0P0LIT606jJ1`1X
WPX0GJ@>05BT6019Y2X0@ZDj03nY@`0lYTT0=YiJ03>8L00cKX<0=Uf303=NO@0`Ig`0;GF202UjP@0W
M7h0:G5l02YlN`0VRGd089N102>NQ00VWXH09iZ602NBQ@0WRHP09XR;00809Xb>02L098j=02::S`0O
R9D07hNI022:T`0OSXd08I>802:IR00XVX80:Y]n02jJM`0aVVl0=9a/03FPJ`0fYUh0=jY804>_=01F
/R80Ik8H07Fb4@1i/@`0NZl:07Fa2`1d/PX0Mk<>07Nc401^/a40IKDJ05fg8P1J]B/0Ek<b05Va>01K
/3d0Fk4n05R`?01F/SH0EJdh05FY>`1AZcT00P1?ZST0201;[c/0A[5104R/@P19[ch0Ak4i04Fd>P14
]c`0@[Hm0P0o]3d07@0m]3h0?KI103ZfA@0g]Tl0>KIG03VeG`0i]ET0?;U8046f@018[d<0BZlo05n]
?020Z2l0V9lG0:2H7P2RT1T0YXLF09N58P2HRRP0XhXH0:N;802[R2D0V8PU09N68`2aQQ00WGlF08f1
9`2<U1L0SIhB0080T9TN02L0QYPF07VP8P21XQL0S:@@086V6`22YRH0R:<S08^N902DUR40TITJ08ZG
8024WQ`0OjHK07RV9@24X2`0QY/X08NK9@24W2L0QYhX08NL:P25WBL0Pi`_07nX:P1k/b`0N[XZ07Bn
901a`280M/0T07K0:01g`2L0Ml0T07S08`1l`280O/0U07W1901g`240N<0M07[06P1o`1X00P24`1X0
9`21`1T0P<0B08703023`0/0Pl0=086m4@1n_A40OkdB07_04`1f`1L0NL0K07S07`1o`2@0NL0Y07O0
:01f`2<0Ml0K07G3601k`AT0O/0H07_06@1i`1d0NL0T07C0;P1i`2@0N<0N07C16P1``AT0L<<H06c2
6`1[`QX0Jl4H06c0601]`1/0Kl4H06_16@1]`a/0KL<W06c5800206_47`0W07S7701iaAh0PL8S07g2
<P21`b/0OLDU07k67`22b280PlPS08?58P26aaP0Q<TE08O54P21`a80PL8D08;05P21^Qd0PL0S07c0
;@1k/c<0O:`g08:U?P2<UT00SX=709^;@P2[Q440Z7]80:]e?@2hM2d0[Vm109]^E@2WME<0/G5C0:iV
FP2PM5X0SH1B08>D9@21RA80PWH50080PG0002L0Pg8008Qf0029M@00R7`008Yo002:NP00RGP008Ii
0028N`00RG/008]j002;N`00Rgd008mo002?P`00SH4008io002;N000PgL0081d001oM@00OWP00863
0024P@00QX4008Ek0024N@00Q7P008Ig0023MP00Pgd008J20025P`00Ph<00864001oPP00OWl007]i
001jL`000P1fL0009`1dK000L6T006]Z001[H@00IV8006=S001NH000FUX005UH001NG000Hf4006IU
001XJ@00JV/006Y`001^M@00KGL006mb001`L`00KVd006Y/001XIP00IV80065N001NG@00FeH0055>
001:@000ASl003lk000j=000=S0002`V000Q70005a<0014?000=2@0020D000@2000200<100800P40
00<00@00000000000000=`00000<0?ooo`002P3oool0501SX`80J:<606RQ1P1ZX080Jj4006bS001^
Y040Lj0007FQ001bW`00M9X007NP001eX@00N:@007JQ001fX`40N:0507FP1`1gY0X0O:8;0P1lY@/0
9`1mXPT0OY`507fL0P1mW0L0NY`;07ZP301cXP`0M:4<07>M3@1`V`d0KiP:072J1`1`W0L0JJ4:05^U
3P1BYaH0C:TT04BY>011[4@0?JY603JVCP0cV5h0;gmd03=^M`0lJG@0@F]g045dNP0kNWP0=gQd03Ae
M@0dN7H0<H1h02f8O00ZTGd0;9Il02RGO00WSWX0:HN002V6PP0302^5PP0V02R3Q`0VQHl08hNC02::
S`0RS8P08hj302JAP@0YTWh0;Y=i03BEL`0jTV`0?YA[03jGH`0jWeL0?Z@n04^_:01N/QT0LK4>07ba
2P1m/@@0M[4706ne2P1]]100L;LF06bf7`1U]B@0F[LZ05>c;`1B/3D0Djlf05N]=`1G[3T0FZ`n05V[
?@1I[CH0EZTj05BY?P1>Zcl204V]@00W04R`?`17[Sl0@Zm004>a?016/CT0@K@k03je?P0o]d40?K@o
03fa?P0l/3`0>k1003VcB00f]ED0>;MO03NcH`0e]5X0?KI804Fd@016[Cl0Bjho062`=P20ZRT0W9hJ
09bJ6P2PU1X0XX/J09^<7`2MRQl0[X`H0:V;7`2]Qbd0XghV09em9@2cOA00[7`H09mn9`2IS1/0Sid@
0080TI`A02L0QY`?082O6@27X0d0RZH;08bW6@2<Y1h0Q9hR08BO8`2DVQX0Ri/I08NH8@28WA/0QilK
07jN8P1nWR/0QYDZ08^E:@25V2P0PI`^08BF=022US<0PILg07Z_;01k`2P0ML4X06o0901]`280L/0S
07K09P1k`2@0M/0S07O08P1m`240Ol0S07c0901k`240O<0K07c06P21`1X00P20`1X0101n`1X0O/0E
08323022`0`208703`0Q08;03@20`0d0N[dB07Vl6@1m_Q`0O<0T07Vh;@1h]S00ML0Y07O0901e`1d0
M/0N07K0801h`R80N<0N07O08@1h`2P0Ll0`07G0801f`A/0Ml8J07C36@1``QL0K<4K06W26P1[`1P0
K<4G06S06@1/`1P0K<<G0732601^`b<0K<LP0080JlPS02L0MlDN07g38P22`R80P<4V08G38P23`ad0
P<DN08?79P23a2@0PlDR08S46029aA@0R<D?08723`21`A40Ol0D07c0601o_Al0Ol0Y082b;`1nZS@0
PZ8i08nE>`2UQ3<0WhHm0:n0?@2`NDP0/gY60;Mn:@2iM4@0_6MS0;AaGP2`KeT0/6MF09mkF02;QDT0
QXlL08F42`26N0<00`27M@009P28L`00Pg8008Eb0027L`00RGH008Ib0025LP00Q7D008Ic0025M`00
RGX008ao002:O`00RgX008Uf0028M`00QW<0081_0023K000P7@007ij0021O@00PH@008:20026Q@00
R84008]n0028OP00RGl008V50027RP80RHh208^>0028R`00Q8L007n1001nN@00NGD00P1eLP009`1e
K@00LFT006e/001[JP00J6H006IS001RH@00GUh005eK001MG@00HUd0065Q001TJ000IfP006Q/001[
KP00Jg4006Y/001WJP00J6L006QV001UH@00HET005]H001LEP00DTh004a20016?000@3/003Xg000g
<000<Bh002`V000P7`006aL0018>000?200020L000D3000200<3000300<200020@000@0003T00000
303oool000X0oooo01@0IZ<306^S1P1^X`L0LZ8306nP001`X@40Lj4107RQ001hW`40MYl007RL001f
X@00M:4007NR0@1jWP00NY`007^N1P1iW0P0Nil>07ZP3`80N9l>02L0N9h<07VJ2`1jVPP0NIT807VM
2P1dW`d0Lj8=072P3@1aWPh0LYh=07BI3@1dW@X0M9l906nQ2@1WX``0FjD@056X701;Zb/0@j/f046^
=`0m[C`0=:==02f?HP0aNFd0AVa/05IUN01HJ7X0Dg1l04i`MP15LGD0@g1f045bM@0lMgH0>H1c03F6
KP0^S6h0:XI_02j0L`0aOW@00P0bNWL09`0cMWX0<7N002]nRP0XQ8`09XF>02R6RP0YRHL0:hb202^?
O`0_T7X0<iAc03VGK@0mWF<0?j5A042U?P1<YbX0GZlH06bb3`1f/@P0Nk4607Nb1@1/]@L0IKD@06>g
6P1U]R`0HK8g05Jb>P1B/3h0CK0k04f`?01=[CL0D:Tc05:T>01GYSX0FZXj05NZ>P1DZ3/0DJU004f^
@00204Vb?P0304N`>`16/C`0A;4o0080@k500280?[E203^eB00i]D/0?KE;03fcA@0k/D00?:i103Zb
A`0e]UL0<;IO03:cH00c]5L0>kI=04FaAP18Zd00DJ`g06J_;023ZBT0X9TN0:JG602QUAl0YhhT0::<
7`2TSAX0[H`C0:^;7P2ZPRX0YHDR0::8902dPAd0YH@M09N89@2HUAh0U9/B0P2CWA<09`2<Wa80PYlL
08:T4@2<Z0`0TZ@J09:O6P22Wb80QihT09VL3`2>WAD0Vi8V096D802ATQ/0OYHQ07bN:02ATbD0TI@T
08ZI;P29Uc40Si8e08VI=`26XC@0OKHZ07c0901c`2@0L/0N07306P1i`280NL0U07[08`1h`2<0N<0R
07_08P1l`280OL0P07o07P1l`1T0OL0F082k4`0207o0400W07nn4@22`180PL8?08C03023`0/0Q<0:
08;0301n`A00N[XH07Rf8@1i_Al0N[/R07Rf;01f/c<0LkTZ07C08`1e`240M/0R07W1901g`RH0N<0W
07C09P1a`2T0K/0Z07C08`1g`200Ml8M07G27P1``1T0J/0M06S05P1]`A40JL4A06_0501Y`AH0Kl0H
07726@1``b00LLPP0080KLP[02L0MlHS07S39@23`B<0Nl8R08716`1n`A/0PL<Q08?5:`22`B<0Ol8N
08G46027`aL0Rl8?08W23P25`140O/4C07g06024`1h0PK`V08:c;@20Y3@0P9Tj08fD>@2[RBl0W8Po
0:1n@`2_PDT0/8=;0;23>02fMd/0^VMV0:I^J02MLF<0YfiK0963E@1oTd00PhlF08Mo1026NP400P25
N0009`24N@00QgX008Ei0025M@00Q70008Qc0024L@00Q6l008Ed0026L@00RGP008Z2002<P`00RGh0
08Ie0024L000QW@008=e0021L`00P7<008Af0022O@00P80008660024S000Si4008jB002=U000R980
08VA002:U080R9`808RN1`2=W040SYP008bA0025R000PX8007in000207Ui000W07Ef001cM@00Lg<0
06m]001WI@00IEh0069P001OG000FE`005aJ001OG@00Gf00069Y001SJ000HV<006EX001SI000HV40
069O001QH000I640069Q001KF@00F58005E=001?A`00BT@004<o000n?@00>SL003@b000a;000;2T0
02LU000S7`0061@0010<000:1P001P<0008010<000<00`80008100010000>@00000<0?ooo`002P3o
ool01P1_WP40LJ4507BQ101dV`40Li`107BN0@80NJ4100`0MYl107JM0@1cV`00LIh007:Q0@1dX080
Ni/307^I0`1lV`P0O9h:07bT3@1kY14207JR400W07NQ301eX0X0MYh;07FO2`1fX@d0MJ4=07BT3P1c
XP`0Lj<<07JS301iX0`0NJ4;07ZR2`1fX@T0LJ<806JU2`1NZA80EJXJ04f/8@19[2<0@ZdX03ZY<`0f
X480>I9:04B;D01;PUh0CWiZ04ilL@1:N7<0A7Q`03maLP0nL700?75_03YgJ@0dP6L0<HIT0324IP0b
P6/0=W]_0080>GEb02L0=g9g03EeN`0dNX@0<7j9031oS00aOX`0;h270362P@0`RG/0;i1d03:GKP0i
Wf00A:Q;04V[<P1C[R40GjhC06^`301b/@P0LK87076b1P1]/P/0HK<B05bd701I]2X0FK<g05>b@P1=
/T@0Bjm204V^?P18/C/0B:dg04f[<P1@ZCL0EJTl05NY?01GZcX0EjXj05>]?P1=/Cl00P1=/S`09`17
/cX0A[<l04Fc@013/dL0?k=<03^bB`0i/Td0?;9A03baC@0j/4d0>k5:042]B00o[dP0>kAF03>aH00d
/F40>:iJ042_D013/4H0BZdn05F/=@1[[BD0PjLW09nJ7`2/UAD0Xi8O0:J;8`2US200YHdM0:j:602Y
RQT0XhTW0:J<8@2YTQh0/HTS0:F<5@2OUQ`0V9/O09bN6@0209RL6@0W092Q4P27Yad0QJXJ08^X3P2B
XQd0Tj4K08NQ7P2=X200WiXC09VI5`2OSRH0UXlR096<8`20U2@0OYdT08jE6@2BTbD0WX`i09^:>@2P
Pcd0UIPn09:V=P24^BP0N/0Q07K07@1i`1`0Nl0M07g08`1j`2@0NL0P07W07P1f`280NL0O07c07@1l
`1h0O<0L07[05`1m`100Q<0<0080Q[d<0100Q[`<08;04026`140R<0A08?23P24`@d0PL8>08;24`20
`1`0O[/R07Rh8@1f^200M[LT07Fg9`1b^RL0M<0V0P1e`2805@1g`BH0MLDW0773:@1]`B/0Jl0W06fk
9@1d`1h0N<0M07C07@1]`280Kl0L06k07`1]`1<0K<8=06o13@1``A00L<<C0774601aa1/0LLLQ07;9
8@0206k5:@0W07S3801i`Q`0Ol8K07W16`1k`QD0N/8F07c17`1kaBd0O<<O07o36@23`AP0Q/<K08c3
502<`180R<0D08705P1k`1/0Nl4M07k18@1n^RH0Nk<Y07V/<P21YSL0TIPk09>@@P2EPd`0ZHI80:aj
DP2WMe80ZGIC0;9_H@2KK680SfmQ09MeF02:Sd`0OJ0c08>A5026P`00RWd00080R7d002L0QWh008Ym
002=O@00RGL008I`0026M000Q70008=c0029MP00RGP008Yo002<Q000RX<008Qn0021M`00P7<0089f
0022N`00QG`0089h0020N@00PH0008F70P2;S@D0Ri<7096K1P2@X0@0RYl208bQ0P2>WP<0SJ0408nS
1P2;Z0H0R:H308jV0P2>X@40RYH1086<0@1mQ@000P1jP000501kO`00MW/007Aa001`JP00J68006=O
001QH000G5/005QH001KEP00FeP0061O001SI000I6<0069O001QGP00GUX005YH001JGP00G6000P1O
HP000`1JGP00EE@0051:000204i9000<04Q40018?`00@3P003Td000e<000;bP002`X000W8`008AX0
01PC000C2`002PH00P050P000`020@000P000040000i000000`0oooo000:0?ooo`0D07>M001gW`40
N9d207BM0P1eW080MI`107NN001kW@40Ni/107bN001gW000MYh007NO0@1hX080NIl607^L1`1lX`X0
NJD:07RV301jZ0h207RX2`0W07VW2@1gYPT0MJL;07RW301iY`d0NjD>07RU3P1jY0/0N:D;07ZU2P1i
Y`X0NJP;07RX2`1hY0`0MZ@:072R2@1^Y@`0HjP>05Z[4@1AZa<0CJ`F04JZ7013YbL0@jD^04JR<`18
X440B9QC04N=H@12PfH0?GeX03eeJ@0mKfT0>G1Z03QcI@0hNF80>7iR03R1I@0jOfP0?7a^0080?GA`
01/0?W5b03]bM@0nMGP0>WIl03]cO`0hLH40=g2003MdNP0hOW<0=Xa/03NKI00nYE00Bj`b05Nb5P1T
]0`0Lk8607R_101e/@L0L;4806fa301V[a/0GK0W05Ja<01B[cL0C[0n04R`?`13[Sd00P15[C/02P15
[c`0AZlf04N^=@1<[ST0DJ/m05>Z>P1C[CT0DZhg04n`>01=/CL204Vd>P0W04Ba?011/3h0@;9603fa
C00j[e<0>;1>03^bC00k/E00>k5B03f_C`0m[d`0@Je@03f]E@0i/5X0=k5R03B]HP0fZEP0?jeA046^
A@19Zch0EZTf07BX9P20YB<0VY/R0:j@5@2/SA/0[8@S0:^:7`2ST240[XHU0:B=7@2EU2`0X98N0:6@
5P2NS2D0WXhJ09VI6`2HWAh0VYXL0080UIPN02L0TI`I08ZV6P2AZa/0V:@K09RM8@2RWAl0X9hK09BN
802UUAH0Yi@G0:Z9902JR2L0ThLa08^>8`2<T1T0SI0C08VH7`2LR2/0UHXd0::2?P2AUc/0RZTc07c0
9P1e`1/0N<0J07bj7`1o`240PL0R07fk901j`200NL0O07_0701j`1d0Nl0K07k16P1n`1H0OL0@0870
3025`0/00P27`0X09`24`0`0P<0A07k16`22`AP0P/@B08;04@1n`Q40P<0E07g08P1k^bT0M[DU07Jc
901g^Al0NK/M07O07`1d`1l0Ml0L07O08P1j`b80NL<T07C0801Z`2D0K/0V07:i9`1f`1X0NL0D0771
501]`QX0L<4H07725`1``a<0LL@@07S4401ba1<0LlDC07;55P1`aQT0L<HO07G7800207;39`0W07g2
7020a1H0P/4E07k04`1ia100M/<D07S3701laB80Ol@H08335@25`aH0R<4F08c04`2<`1@0R;hD08C0
5@1n`1`0Ml8R07g08P22`240O[PX07be<023ZSL0RZ<l08jC?@2?Qd@0Wha80:InE@2MKUh0WgQJ0:Qi
G`2LME/0SWEL08YoD@27U380Pi/E08J>3026P`00RXD00080S84002L0Rgd008j1002<PP00RWd008Ih
0024LP00QWL008Ad0025M`00R7l008^1002>Q@00Rh4008Ul0022N`00OgL0081g0025O@00QH4008=n
0021OP00R8@008bC1P2<W0h0Rj<@08bX3P2;ZP/0RZT808ZV1P2<YPP0RZH708j]1@2;/PT0RK@:08Ff
2@25/@T0R:T<08BO3@1oUPh00P1nS`h0501iR@/0N7l607=f0P1bK000JVL006EN001NF`00G5H005QH
001KF@00FUP005mJ001RG`00HV0005mL001JEP00FeD005UF001NFP00GEd00P1NG@004@1JG000EU@0
055:001BBP00D4X004e70019A000@c`003`h000j<P00=R/002dV000/9P00:B4001hK000H40004@X0
00802PH000<01@40004000000000>@00000<0?ooo`002P3oool0501^W`00LJ01072P0@1aW`40Lid1
07BM001gW000NY`007VK001lWP00NJ8007NR001iY000NZ8107ZS201nX@P0O:4:07VV301gZ@d0NJ/=
0P1f[0X09`1hZPT0NJ/:07VY2P1iZ0X0MjT<07JU301gXPX0NJ4:07fS2P1iY@X0N:H:07FX2`1hY@d0
Mj@>07VR301gXPX0MJH906nY2`1XZ@`0Gj/>05F[4@1=Za@0BjdH04^_7P19[bL0B:hb046ZB00mW5H0
>heT03QnH`0hLfP0=V]Y03M^JP0fL6P0>7IS03UmHP0kPF<0>h9X03enKP0203mfK`0W03mbL011LFd0
@G9`041_L`13JgH0?6Ik03YXL`0kL6L0@GmI03jED`16YTH0DJXd05V_7P1U/@d0Lk4607^a0`20/`<0
NK8806n`3@1V/A/0GZl^05F^@01B[T@0CZe404R]A012[cd0@Jdg04F]=`17[SX0BJlj04N^=P17[cL0
Bk0h04n]>@1C[3P0Djle052a<`1:/cL0B[8h0080A;<o02L0@Jm503j^B`0j[E40>:aB03RZD`0h/580
?;==03bdC00k/Th0>k1:03f]D@0nYeD0?ZaI03b_FP0i[5l0=ZYM03ZXDP11ZT/0AJa504ZY@`1FZ3`0
Lj<Z08BT8P2IX2H0ZY8J0:J=6`2RR2<0[8TO0:F<7`2XQRP0XXXN09JF9`2LV1h0WI4D09B>8`2NTR40
[9TB0:JI702RUA`00P2CTB809`2?VB<0UJ<H09RX702MWA`0UJ0P09ZM8P2NVAh0UI`N0:6G802MU1d0
WhTV09:7:02EPc@0UhLV09f25@2QQPl0RiHI0:636`2GQRl0XgXi096H?025[c@0NKPT07?06@1f_QX0
O[hR08?07P27`1l0Q[XP07bk801i`1d0N/4K07_1601o`1<0P/4A08713`1o`0h0P/0=08Fo300208K0
3@0W08G13P25`A80P<4F08734`24`Pl0PL8A07W24P1i`1H0NkXN07bj8`1f]b<0M;LU07Fj7P1e`1/0
NL0I07O0601e`1X0ML0N07W17`1f`200LL0N06S0901^`2P0L/0^07C08@1_`1X0Ll4H07306P1b`1X0
Kl0K07K35@1ga1<0O<@C07W4501iaa<0M<LC07775@1abAP0M/PH0080M/XQ02L0Q<TI08;75P20`a<0
O<<?07g33`1iaaT0O/DK07W76`1oaQH0O/PG08;44`1o`aD0QL<E08;24P23`Q@0QL4F07c37`1g`BP0
NL8R08;08023^BL0PJl/08FX<@2;WCP0RIdd08ND?@2CV480W8m@09UgH02HN6D0WGUW09MfGP2;NEP0
RhM908VG8@25T`D0QXL008:20028P0000P2:P0009`2:O000RX4008]n002<O`00RGX008Qe0027LP00
PG8008Aa0026N`00RX4008b4002;PP00Qh00085k001lM@00P7@008Ek0024P@00PhH008V:0@2>UP<0
TJ48092U302<Z0d0SJX;092[2@2AZPT0RjP:08R/1`27/@D0QKD808Fl3@24_140P;h?07nl4P21^1H0
OK4N07V[8@0207JX900J07>K601cS0l0Lh8607Ah0@1aJ`00If<0069J001NF000GEH005YF001LF000
GU/006EQ001SH@00HEh005mI001PFP00GU/0061M001OGP00G5P005aE001KEP00F50005A;001AA`02
04m;000;04i70019@P00@c`003de000g;`00<bT002dU000X9@008al001/F000G40000P0?2`000`08
10000P000000000i000000`0oooo000:0?ooo`0D06bP001]X@40KZ81076P0@1eW@00Mid007FO001f
W`00N:0007VR001gXP00Mj0107ZT0@1jYP00OJL607fU1P1lY0P0NjH:07JX301h[Pd207R/2P0W07^Z
201l[@T0OJL907RV2`1dZ@d0MZD<07FT2`1eX`X0MZD907FW2`1fZ@X0MZT;07RW301hY@`0NZ<;07ZS
2@1iZ0X0MjL907:Z2P1Y[@d0Fj`B05:/5P1;[a/0Bk4R04Z_;014[cT0?Zi903bVEP0hV5`0>I5M03f8
G@0mPEh0>hAK03V8F00hSET0=i5I03NAG`0fSf@0=XY]0080=hE]02L0>H1/03UkJ00iN6/0>7M`03]d
L`0eNVh0=X5N03^<B@12VCL0BJPY05F^801Q[QP0IK0>06^`1`1b/@D0Nk0807Za401b/1X0IjhR05n]
:`1G[3L0DZe204b/AP17[4L0A:i104:`>@12/2l0AZhb04Z_>P1:[3d0C:dj04b_=@1=/SD0D;4e05Fa
<`1D/S40DK@_04Zd=@17/c/00P14/D<09`10[Td0?:eD03R[F@0gYeX0=ZMG03R_E@0j]540>[A@03fb
C`0n[dh0?jUF046SGP12YEd0?ZQJ03jTG00iY5X0?ZAC046YB`14[4L0BJa205R]>@1jYB@0T:4J09^P
902[Sah0YY<J0:BE8`2VTAl0YX`I0::;8`2QRb80X8dL09j>7`2KTA`0VYDK09fI8`2YUB80WIPT09fG
8@0209ND8P0W096K8`2KX1l0VJ8O09jL7`2BWQT0V9PP09bE802CVa/0WiHY09FD9@2HRR/0RXPY09B4
<P2ERBL0X8LL09j04`2HRQh0Y7`Z09J4>@2JOD00Q9Y107Z/>`1d`2L0ML0M07K0701n_1d0Q;TI08Jl
6021`1/0Nl0J07O07P1k`Ad0Ol0G08?04P23`0l0QL0>07o13@21`140P<<I0080P/@G02L0Q<HD08C5
4`20aAH0OLHE07_34@1k`140ML0F07C06P1g]Qd0N[DN07Rh8@1e`240LL0P07;08P1j`1h0OL0H07g0
5P1k`1P0OL0G07S0601d`1d0JL0U07708`1c`2L0M<0T06_09P1a`AX0Ll4H07?25@1b`Q@0NLDA07_9
401jaa80M/PB07K:4@1aba@0LL`D07;>5@1gcaP00P1icR009`25bAL0QLTF08345`20`a80P<DA07g6
601naAL0OlHE07o74`22aQ@0Q<@A08744P1n`a<0Nl<E07k35022`Q<0P<8H07k1801m_b80P;XS08>h
:021[Bd0QjL_08^R=027YS<0PJ8h08nO@`2FUE00WWaJ09afJ02SMVL0WW9P09=hF028ST<0RIPK08R=
1@25O`00Q7`008Mm000208Mj000W08Qm002:O`00Rgh008al002;N`00RGH008=_0022K`00PW<0089g
0025N000RGh008N00027N`00QGP007mh0023NP00Qgd008J30026R@00Ri0108RP2@2;Y`T0S:L808b/
2@2>ZPX0S:`>08Z]3`27[0h0QK8:08:i2@1n`0h0PL0B07k05@1i`A@0Nl@E07c26P1i_R40N;HW0080
NK0Y0180MjXS07BM6@1hUA40N8T9075k0@1_J`00IF40065P001NF`00FEL005]J001PG@00Hf8006AX
001SI@00IV40065N001JH00205aM000C05]H001LE000FUD005aA001GC000E4T00559001BB`00CDP0
04]50016@@00@CT003`b000g;P00;bL002`U000X8`008Ad001dE000201D>000300`700060P000000
03T00000303oool000X0oooo01@0L:00072Q001cX@00LZ0107BO0@1fX000NZ8007ZS001iX`00N:40
07NR0@1hXP80NZ8107bS001lY@00OJ@007jT101nY0T0NJL907RX2`80NZT:02L0O:L907bU2@1nX@/0
N:8<07JR3P1bXPl0L:<=076T2P1dY`/0M:H=07JU3@1fYP`0N:@<07ZT2@1lX@T0Nj<807ZX2@1lZ@T0
N:X906n/301P[A<0EJhJ04n_8P1=/BH0Ak4_042b@00k/Dh0>:aE03JRG00iWV40?IQN03nDGP0oTeD0
?9QA03^ND00gX500=IiG03BIGP0cTfH00P0bTFH09`0eRV@0<X9V035mJ@0cOg80=8Ea03>?H`0dWDT0
@:H`04b_6P1H[`l0I;<806^b1@1[/@D0KK0506ja1`1`/140JK0Q06:/>01MZd40FZM105F[@01>[D@0
B:e404F]@@12[S`0@k0d04Fa<P17/C@0B:lj04V[>`1=Z3L0Cj/b052_<P1@[c40E;8`05>e;@1<]Rl0
Ak@e04Ba?00204B^A`0W03j]D@0j[EX0>:eN03N]G00g[EH0=ZeE03R^E@0j/500>k9>03n]D@12YEP0
@YiP042NGP13WUD0A9aD04:IE@10WD`0@JA@04F/C`1</4/0Gk4d086[802GWQ/0WIXN0:F<8P2PTQ`0
WYPL0:BC802RS1d0WY8O0:2D802ZTal0X8lQ09f?8P2RV1h0ZYlS0:fE:`2NVQl0W9XW0080W9`T02L0
WihS09fI:`2LW2D0UYdP09JK7`2GUB@0VY@[09>L9`2EW2`0TiL[09::<02<R2h0TXH_09F>:@2NTR<0
Z8LI0:B99P2YOCd0U8E108b2A`1kUDP0MJ<n07Fe:P1f`240Ml0J08707P27^1/0Q;PH07jk601h_aT0
NKlM07^o7@1m`1/0P/0F08K04`26`100Ol8>07c14`1k`Qd00P1kaQ/09`1oaaD0OLHE07W5701faAT0
LLLC07C3501b`1X0Ll0O06o0801e`1`0M/0K07S06`1c`1h0LL0R07K08@1i`1`0N/8G07c05`1j`1H0
MkPI07W0801c`2D0Ll0R0770701e`1P0L/0H07O14@1h`100N/4?07K13`1ia0l0N<P@07G85@1bbAH0
MLXF077<5@1`cQ@0LLhE07C?5@0207c<600W08;95`1naQ@0Ol<F07k3601oaQ/0OlDM08756@1oaaD0
PLHD08;75@24aQ40P/<>0833401o`QD0P<HF08355@21`QH0Q<0H08?0901o`2L0OL0Z07fc;P27/Rh0
RkP^08Vg:P23[SH0SJ=409JBE02NPET0XW]P0:UfF@2ULe`0VWaD08BC?025UaT0QHL5085k0024M`00
QWd00080QX4002L0RH4008Z00028O`00Rgl008^00029N`00QgD008Ah0020M`00PgT0089h0025N000
Qg`008Em002:O000R7d008]o002=RP00Si0008bB0@2:UP<0R:L:08R^3@2;Y`D0RJ/508V/3029[a40
PJlD08Fb4@25^a00P<4@07g44P1m`QH0Nl8F07W86@1laal0N/DX07[6:@1l`BT00P1j^R/09`1h]bh0
LZhZ07:S7`1bU@l0LXX407Ii0@1]KP00HfD005eH001KE`00GUT005]K001PGP00HV<006IT001VH@00
HV4005eO001IG000FUL005UH001LE000GEH005mD001KCP00ETd005=;001>AP00C4H004Y20014?@00
?c/003db000j<@00<bP002dT000/8@009al0024I000201TB0003014900080`000`4003T00000303o
ool000X0oooo01@0L9h006nO001^W`40KJ0306fN0`1aX`40Lj0007JR001hY000MZ8007JO001fWP40
NIl107^O001iX040O9l307^M101kXPX0Mj@:07RS2`80N:H;02L0N:L<07JV2`1eX0d0Lj4=076S301^
Y100KJ@A076T3`1bX`h0LZ4>07:Q3@1hX``0Nj8:07fS1P1kY0H0N:D707NY201iZ@P0Mj/8076/2P1V
[Pl0G:lA05J_601B/Ad0Bk<T04:e=00l]480>:m=03ZYEP0nYeX0?J=N03jMH00mWET0?J5D03bYB`0j
ZdP0=ZQ<03FSD00bXEP00P0bWeP09`0bVeX0<IEJ032@G`0aU6D0=9UL03VUB@10/Bl0CK8J05Vb3@1T
/@H0JK<106^e001^]0@0J[<606Zc3@1T]1T0G;0_05F^AP1E[D`0Cj]>04n]BP1;/4X0A[1404Fa?`17
/ST0BK<`04Vd;`1;/cH0B[0m04b]?01<[3X0Cj`b052`<@1@/c<0C[@a052d<017/CD0A;0k046`@@02
03j^B@0W03n_DP0k[e/0>:iN03V^G@0g[5P0>:EM03NPFP0kZ5@0@:YA04>WD`12X5T0?YiS042JI014
W5`0@iYE042IDP0oXTl0>jUE04:/E`1<[U@0IJdd08NT8@2MVaL0XILK09ZF902QVal0XYhG0:2F7P2S
Uad0WI`I0:BP702TVRL0Vi`S09^G9P2WURL0[9XX0:>G9`2KWa`0Uj<M0080W:8T02L0WZ<R09RN:P2N
W2T0WihN09^K9P2MUB/0VYHd08nK;P29X300TITb092C=02FTCH0UI4g09BC>P2ITCD0UhT_09J;<`2F
RT40Qi=108:AB01bV4L0L9e607Bf:`1k`1`0N<0G07_05@21_Q@0O[dE07jl6@1j`1d0N[lL07_06P1m
`QH0P/4D08G25@24`140P<0=07c13@1m`a000P1ka1002`1o`a40Ol@?07W24`1i`a@0ML@E07726@1e
`1/0M<0O07;0801c`1d0ML0J00<0M<0J01T0N<0H07[15`1j`aD0Ml8F07C06@1b^240M[PV07Fk;@1_
`2D0K/0L07C05P1d`180NL0C07_03`1m`0h0N<4=07[33P1faQ40M/PF07;86P1cbA/0M<TL07C;601b
baT0O<LJ0080OlHK02L0P/DI08;65P1laaD0P<PM08366`21a1T0Q<@G08355`22aQ@0PlPF08?:4@23
aPl0Pl4D08;35@21a1T0Pl<K08Jo6@25_AX0P/0O07c09`1l_b`0PKL^08>d<027`BX0QK`Y08:_=`25
YTP0SYAD09b3FP2LOE/0VX1I09ElG@2@R500PIhg08>L6026R0H0QWh008N00026Q0000P28Q0002P29
PP00RX8008b10029P000Sh4008j2002;PP00R88008J20026OP0208ao000K08Z6002:R@40S8T108f6
002BSP00T9T009FL002CXP80S:H:08V`4@2<]A00SK0908Vb3`28]Q<0QKTK08>g7@25^1h0Q<0L08;9
6@1oaaH0OLPJ07[;7@1hcB<0N<`Y07O<<01hcCD0N<Pa0080Nl<`02L0M[l/072f:P1`Z2<0KZ8M076L
5P1aTQ00M80606e^001SG`00H5l006=P001RH@00Gel0061N001UH000HEh0069M001QG000FeT005]F
001LE`00GED005]B001HC`00Fe0005U=001BA`00BSl004Q00018?`00ASd0044i000m<`00?3<003T^
000d9@00:b4002@N000R60000P0J4000100B2`0030L000L300030@0h000000`0oooo000:0?ooo`06
06ZP001ZW`00JYl106RQ0`1[X`<0KZ810P1`W`00301aX000MYd007ZK001jV`00NYT007^I0@1hW0<0
Mil707ZK1@1iV@L0M:0:076S2@80LZ@:02L0Kj<;06bT301^X`d0KjD;07>U2`1_X@d0L:8?07:U4P1c
X@d0LZ0=076O3@1eX@/0N:4607VT101gX`D0MZP807FZ2@1e[0P0M:`806n^201X/0P0H[0;05f`3@1J
/Q<0Dk4H04ja9@17/cH0@k16046_C013[4d0@j]B042TF00lX5L0>j1D03fXC00l[4D0>je303V[A00i
[4@00P0hZd409`0iZSl0=ZLm03FU?`0jYd80?jXj04Na:`1=/Q/0Ek8@06>a1`1Y/P<0Jk8106Ve0P1[
]PH0IK@<066h5`1J]R80E[@b05:_@01@[DH0CZm:04j`B01:/4T0AZm204^a>`1</ST0CK4a04Rb;@18
/c<0B;1004F_A018[Cl0B:di04Z^>01:[cT0BJlh04R_>@11ZSd0?jU503n[B@0203Z/D00W03^]E`0h
Zf40=jYS03N[G`0eZ600=:1S03NKHP0kWel0@iiI04JMFP12W640@I]V03nJIP12Vf80@I]H046LE@10
YU00@:iI046aE@1>/E40LJlb08^R702JWQT0W:0K09VT7P2MXah0WZ8I09NR6P2QX1P0WZ<E09jX602P
Xb00VJDN09RS8P2RVbL0Z9PV09fF9P2MWQh0XJ8G0080VJ<P02L0Vj@U09ZU8P2PXB@0Y9`S09jM9P2H
VBP0TI/`08fO;@2:Xb`0S9d^09FJ<@2HVcL0VILm09BG?`2CT3l0SXQ108b8@028SdX0OYQ307BN@`1]
X4<0LIm207Nd;P1i`1l0ML0J07Jl5`1l_1D0OKdG07^m6@1j`1X0Ml4K07c25P1laAH0O/DD07k15`1k
`1D0NL0>07K13P1ia0h00P1j`Q407@1n`a00PLD>07o53`1k`A40M/8H06o38@1c`R00LL8S07;2:01b
`2H0LL0O07>l7@1c^R00Ml0O07_07@1k`200NKXR07Nj8@1g`280Ll0R07?08@1c`R<0M<8J07O44`1k
aA80N<@B07g1401m`@l0O<4>0080Nl0=00P0Ll@@06k8501^bR00L/TO07K86`1eb1/0Ll@L07k38P80
Pl8P02L0Q/@L0836701mb1X0O<TL08796021b1L0QLLI08376P1nbAL0P<TF08784P23aA80Pl4F08?0
6@28`200R[lR08^m7@22`AX0O/4N07W0:01l`2l0PKd]08Bj;P26`b/0O/0X07f]=P1lYDL0RYQ?09Z8
E@2GPEP0RX1G08R5E`23TT/0NjDb082R5`26S`P0QhL008J6002;R@000P29R0009`28QP00RhH008^5
002=O`00T88008j6002:Q`40RhL108V8002;R@00SHT008b@002:T`80RiT7092G1P2BT080TiL009BT
002FZP00U:l608ja3P2@^@l0S[`>08jj3P29_A@0Q/8L08?08@26_R@0Q;D]08C1;021cBL0OlhL07_>
7`1jdR@0M=<S077?9P1ac300ML`k07?:>`0207C6=`0W07K1<@1c_C00KkD^06bb<@1Y[bX0J:@G07>D
3P1dO`80KF`006MX001VJ000I6H0061R001PH000Ged005aJ001MG@00HEd005iM001QG000G5P005]C
001FC@00E4T005A:001FC000DDL004m6001:@P00AT0004U00015?000@C<003``000j<000=BH002hR
000Y70008aT000806Q<000D05@h0014:000<1`001`<00080000g000000`0oooo000:0?ooo`0D06ZN
001YW000JI`006VO0@1YW@40JY`006bJ001^V`00L9d007>K001iVP40NYT107VF001gUP40MiL307FJ
1P1eV@H0LiT707BO3@1bX0X207BO2@0W06nO2P1/XP/0Jj8<06nT2P1_XPT0KJ8:06nR2P1bXP/0MJ4;
07>N2`1dW0/0N:0907ZQ1@1iX`@0MZ8607>V2P1eZ@d0Lj`:07:]2@1b[@P0LZh606b/1`1S[`P0H:h:
05Z`401E/AP0D[8V056c=P1@]3T0D;8e04n_=P19Zd40AZQ704JVA@19[3h0A:lf04B`<`14/Bl0A;4Y
0080Ak4U02L0A;4V04Bb8`13/b80@k8P04bb7@1A/aH0F[<<05nc1`1W/P<0K;<106jd0@1X/`<0J;D8
06:f4P1K^280DkL]05:c>01B[Sl0Dji505:`AP1C/D00D;4n056_>@1A/3/0DZll04n_=@1;/S40B;@i
04N_A@15[Th0@ji:04>]A`13[4D0?j]0042Y@00oYTH0?ZA903bTDP0iYUL00P0i[5d09`0gZfH0=:E/
03BTJ`0bZ6@0=:ES03BUI@0eXVP0>YiV046HH@13UF80@9QT046IJ@0oVFT0?iUT03fJG@0nWUT0@JUE
04B_EP18/Th0Fk5<07n]<@2GWa`0WYdM09fQ7`2MYAT0WZ8L0:FK6P2EWaT0WZ4I0:6Q602MXQL0VihI
09fT5`2LYA/0XYlQ0::M7P2NWQX0W9hL0::N7P0209FT7@0W09bS8P2MYR40XJDS0:>S8`2MX2D0TiX[
09>K;P2DWR/0TZ8[09>T;P2HWRl0UYlb09BK<`2?VS`0SYPl08VD@025Td<0QI9:07ZO@`1]YD40K:Y0
06n[@01d/C40M[TT07;07`1b`AP0Ll4F07K4501i`aD0OL0C07g1501l`Q@0O<4D07[04P1k`1@0ML4C
07?04@1c``l0N<8B0080Ol0@02L0Q<0>08S03@23`0l0O<0@07C1701c`R80L/0M07?27P1d`1d0ML0N
07C06`1d`1H0M/0L07[07`1f`280L[L[07Zb;P1h]2`0M[PX07;09`1e`R00M<@M07G5501haa40N/DA
07O55@1i`@l0Ml0>07[13P1o`0d0NL8<06o73P1^ba<0LL/O07C87P1baaX0LLLK07?47020_b000P20
_B<09`23`RH0OlLR07k87`1nb1d0PLLJ08;:5@21b1D0O<TJ07c:6`1lb1P0O/PF08785021aQL0Q<@H
08_1802:`2H0RKhN07c06`1ia280N<0Z07fh<P21_BP0Q<0Y07k1:01j^bd0MjXh07FWA01oW4d0Ti1B
09Z8D`2FPUH0T8QA08RFBP1oYBP0Q9hD08N@1`29R`00Rh/008j<000208j;000=08^4002=Q@00SX<0
08n1002>R@00RH/208ZA3027T@X0RY8408bD0P2AV@40SIX208fM2P0208NU4`0H09BP4P2DWPX0TJL1
096d1P2@]`d0Sk`?092n302>`0`0Rl<?08[35P25`ad0P/DP08C58P23`b<0P/HW07o89@1lcQh0NM0R
07KB9@1bdbL0L=4T06o>;`1^cCd0K/a20P1^b3d09`1^a340Kl@/07C1:P1^]bh0JkHV06Vc6`1aZQ@0
MiX<07J30@1]LP00J6`006MZ001RI`00H68005iM001HF@00FU/005UN001MG`00G5h005QJ001HD@00
Edh005=;001CB000E4T005A<001DC@00CdL004a10019@000ACh0044f000l<P00>BX003LY000b9@00
;B0002LK000201hF000601LA000F2`003PX000X8000510000P00=P00000<0?ooo`002P3oool0501/
U`00KIL006ZG001]U`00KI<006fD001[U000JYD0076J001fU`00MYD007NF0@1hU`40M9L207>G0`1b
VP@0MId707>P301aY@h0Lj8=0P1fX@/09`1dXPT0KZ8:06bT2P1/Y0X0KZ09076S201`Y0T0LZD807>S
1`1fX0P0Mj4707RT2@1hY@X0MZ<:07NS2P1fZ0/0N:T;07NZ2@1hZ`T0M:X707NZ101fZP@0LJ`606n^
2@1/[0/0J[0=06N_501V[a`0I:hL06>a6`1P/1`0FJlR05R^901H[b80FK0N05Jc6`1B]1X0E;@H05Jd
5@0205Fd4P0W05>d4@1?]180CKHB04jf401C]A40Fk@<06>c201Y]@D0KK@2072c001`/`40LK<306Ze
2@1O]Q40E[LM052g:P1A]CL0DK9005F^A01F[TL0EJi305>a?P1C/CX0DZhj04n]@P1@[D40C[1204bb
AP17/Dh0A[1F04F]EP14[U80A:a<04B[B011ZTP0?ZE=03nRD`0oX5/0>jAT0080>:IX02L0=:9]03:J
LP0aV740=9YZ03FPH`0dYVH0=:IX03^QI`11Vf@0?iUX03fFJP0mUg40?IA^042CI@0lUeh0?IeJ04:W
E@15[dh0E;9106Z]?@2@YRT0WYdM0:6I702MW1`0W:0G09nO6@2SVAh0VY`J09ZO6P2RWAd0VYhI09NP
602QXA/0Yj0L0:6M7@2SWQD0Y:8@0:JP6P2UVR@00P2GXA/09`2IY1h0WJPQ0:2U8@2KZB40UjPS09BU
8`2BXRL0Tj4Z092V;02@ZB`0TZ@a096P<02=VC@0RY`l08bM?`26W400OiY207jIA`1iVdD0Mim3076Z
@01_[400M;<a07Fi:`1e`2P0M<0P07G2601f`AD0N/4C07c3401o`Ph0PL8?07c14@1ia180N<0C07O0
4@1e`100M/4=07S03`0208303`0W08W03@28`0/0P;/>07g0401e`1P0Ml0L07W06P1j`1T0OKdJ07_0
601h`1@0Ml0D07W05`1k`1/0Nl0O07Jl8@1h^R80Nl0O07Vo801d`B40Ll8O06o3701eaa80NLL>07K7
401eaQD0M<8@07G0301g`P`0Ml@?07G5301_a@d0LLT?07C95@1dbaT0K/XM07767`1a`b00N/0R0080
N/0[02L0MklZ07[5;01oa2X0OlHU08787`1obA/0N/LL07W8801hb280NlPP07c96`20bQT0OlXG0839
5`22aQ/0PLLS07o5801laB80N<D/07?5<`1e_c<0Pl4U08C38`1m`bD0Mkh]07J_?@1e[4H0Oj9@092?
D@2LR540XX=@09Z;C`2?Ud@0Q:<O08FJ4028S`D0S8/008f<002<S`000P2?T0009`2>S000SX<00928
0@2AS0@0S90:08F@3024UPl0PY/>08FK1`2<X0@0T:L508^T2@24Z100PJlF08:a6`2:[ah0TJdA09:`
1@2=_0d0S<8C08_34`2=`0l0Rl4=08[63`2;aQ@0R/LK08K99@25ab@0PlTV07k99P1mcRD0OLdO07S<
801kcb40MllQ07C>9P1bc2/0L<lc06c@?`0206_9@`0W06_5?01/b3P0J/@i06Vj?@1U^3P0HKld06>l
:`1W/Q<0LJ4607><0@1]NP00IgH306Ef201QLPP0F74;05E/301AJPl0DFT;05IY201HHP@0EUh105UK
001HFP00EU@005=;001CA`00DTP004m9001>B@00CD@004Pm0015>@00@SH0044d000i<000=R`003LZ
000`9000:1`000808AH000L06@l001L>000A30003@X000X500040@000@0003D00000303oool000X0
oooo01@0KIH0072H001_UP00M9D007:C001_T000L8l0076E0@1bU`80LiD107VE001hV080MYT307BI
101dW0@0MIX407BO1P1cXP`0LZD>076V3@80MJ8=02L0N:4<07FQ2`1aX0`0LJ0=076P301bXPX0M:@9
07>V2@1eX`X0N:<907NS2P1gXP`0MJH<07NT3@1gYP`0NJH<07bU2`1mY@X0O:H907^Y1P1jZ`H0NJX6
07N/1P1eZ@P0MjP807J/2`1e[@/0MJh;07>]2`1a[`/0KJh<06J`3P1V/Ph0I[@<06Fe2P1U]PP0HK@8
06:e2P1P]P`00P1M]0`09`1L]0`0GKD:05Re2`1J]PT0FkH906Jf2@1^]0L0L[@307Jd0@1e]000MkH0
07Jf0@1b]@L0Ik@<05Ze5P1B]RD0D;@a05>d@01D[d@0Ejm705>]B@1B[d<0DZdn05BZ@01@YT`0CJU?
04^[F01;[U/0B:iN04>`H014[VL0BJiK04V`DP17[dd0AJY<04:VCP10Y5L0?J5N03jPI`0203jQJP0W
03RRJ`0dWVl0<i]a03>KK00cWfT0=:=X03BSJ@0lXF/0?Z1Y03fNK`0lVW@0>iAi03fCL00lSf80>iAN
03bMF014Y500CJ]505n^<`1cZ2X0TYlQ0:2J702NUad0VYPO09nK6`2NW1H0W9HR09nI7`2PW1X0WYTS
09bK7`2IYQT0XZ@J0:NL802RWQh0X:0H0::Q5@2OWaT0WIhP0080VJ8L02L0UjPN09FZ8@2HZRD0UZhQ
09>_8P2EZBD0TjHZ09:W;`2<YC<0SZXb08nX=@2<YCL0RJ8i07nR@020XSl0NZ4n07NS?`1eXD80MZ=0
07NN@P1dZD<0LZe107:`?01g]3D0M[/g07O0;P1g`R@0N/0O07S06P1k`1H0Nl0E07_1501j`AH0Ml@F
08335@1l`a@0NL8F07?05@1c`1800P1l`1009`1o`0h0Ol0=07c0401i`1@0NL4F07[05@1k`1D0Ol0H
07k05P1m`1D0M<8F07C05`1f`1h0N<0P07K08P1b`2D0Ll0O07716`1b`1`0LL0Q07Bn8P1e^a`0Ml4A
07S33@1ga@l0M<@G07C23`1f`0X0N<8:07_3301ga0T0L<D;07;73P1bb1<0LL`I06c9801_bR40L/DV
07G39P0207C1:P0W07G0:P1k`2P0Ol0W08749@1nbB80O<XN07W:7@1fbb00NLPT07[:901mb2@0O<XQ
087<6P20bQL0P<PI07[88@1gb2T0MlH`07G5?01aaD00LLHf07c78`24aB@0Ol0Z07Zi<`1g[480MZa8
086PDP2CSU40W8MB09f4C`2BU4P0Ri`m08RU6029UP`0Rhh308b;002?S000SY400080Si<002L0T8l0
08b@002CU@H0TIl=08nS502;XQD0RYXA08NM4025V``0R:<?08nY3`2=Z`d0Rj`<08Na4028]a@0S;XL
08bf502;^100S;dC08[36@28b1H0S<T@08[83`28aa<0R<XG08_<6`25cB40Ol`[07k<<`1kcC00O</V
07_:8P1jbRD0N<hU07W?9@1gdB@0MM0U07GA:@1cd3800P1Zc3h09`1VbSl0I<Q205o6B@1J`4L0G/17
05c6>01MaBd0H<0R06Jj6@1_/140K:8906JD3P1OV1@0FY<G056?701=RR80AXDZ04En801?MQP0EV`<
05QY0P1KI@40GEh005aG001FD000DTD004m6001?A000CT8004a3001;?@00B3h0044f000l<000?2l0
03T_000g;000<RL002/M000202DI000701d@000G3`0050`000l<000<2P0020<00081000e000000`0
oooo000:0?ooo`0D07:J001dV000M9L107FG0@1cU@40LY<107>B001aT@40KID307BE0@1fU000Ni`2
07VL0P1iV`80Ni`307VL101jX0L0MZ4:07>S301bY``207JV3@0W07VW2`1hXP/0M:4<07BR3`1bXQ80
M:@>076V2P1aYP`0MJ<>07JR301hX``0NJD<07JT301eY0/0MjD;07^U2`1lX`X0NjD807nV201lYPP0
NjH907ZW201jZ@T0NjH907bV2P1jZ@X0NJ/907V_1`1h[PH0MJh7076_1`1Z/@L0J;<606Nd1@1Z/`<0
J;<106Nc0P1V/`H0IK<70080H[D900P0HK8806:d201Q]PP0I;P706Jg1P1^]PD0LK@307Nd0@80NK@3
01d0NkD107bf001f]PD0K[H906Be4@1K]Ah0E;<Y05Bb>@1G/480EK1205F_?@1F[ch0F:]005NW@01E
YDL0DJI;04fZE`19Zel0AjeP04R/H`17[VH0BjeM04f_E01=[D`0BjQ;04BUD@0oXUT0?YmR03nPIP02
042PI00W03fSI@0kY6X0>:A]03FRK@0eY6/0=ZI[03NUJP0iY6h0?J9b03fNM`0fUW/0=hek03RAK@0l
Sf40@XmN042CF01:Wdl0EZI206f[:P1nYQ`0TilO0:2I6@2OVA/0VYPN09fH702LVaT0V9TM09fM802Q
Val0Ui/R09bM8@2GY1`0UZ8O0::E9@2RWR40X:@N0:>M8P2RVB80Wj0Q0080WZDQ02D0Vj8S09JV8P2D
ZBD0TZ/S08f^8`2<ZRL0TZP[09:V<`2?ZC`0RjXg08^Z>P2<ZCP0RZXh08BW>01nZ3h0MjE007JRA01e
Xd<0MZHn07bO?@1eYSl0L:]106n/@01b/3`0Ll0l07C0;`1b`2@0NL0P07c06P1k`1T0Nl0G07c04P1i
`a40O/8@08?34020a180O<4G0080M/0E0P1j`1409`1i`100NL0?07Zm4P1i_1@0NKhC07g05@1m`1@0
Pl0A08Jl3P20_@l0N<4?07_34P1la1H0O<0J07O06P1a`1d0Kl8L06o17@1c`200M;HY07Fa9P1h]280
Nl4F07[54@1maA80N<<F07O43`1fa@T0N<D907O6301gaPT0M/H:07?8301dbA00M<XC06k:601fbAd0
N<PS07O9900207?7:00W07Jn;01l^R/0P[l^08769`1jbB@0N//O07_97@1fb1d0NlXS07c8901lab@0
O/PQ083;6`21bQT0OlTL07W6901haRl0N<De07W5@01bb4@0L<Lf07K79@1ka2L0N[`Z07^h<P1k/C/0
Mj]8086KC`2KRe@0VHAD09=nDP29TTP0Qihe08bO4`29T@@0S8/108n9002=S@00THl00080TI4001D0
TYD109FL1@2BY@/0TZd<096]402;/140R:/@08RX4P25XQ@0QJ<L08Z/4`2=[`l0S[8508^g2028_a40
R<8P08O28P25_1l0Ql0S08O2:P29aQl00P29bQ004026bAL0PlTK08K<8024c200O/`S07o><01ncRh0
OLdR07_<801icR<0N<l[07GB;P1fd2L0M=4S07W?8P1gcRH2077@<00W06gA;P1Uc3T0HLM805jlC01L
]4l0F/1405[5@@1Ia400ElTl05W9;`1La1l0G[hU05Nh=01B[S80CJ4a04VG=P16US<0A8hY04R67`1>
PAD0FG/<05]a1@1KIP80Fe`105U<001EB000E4L004m5001;@`00CD0004a00015>P00?c8003X_000m
;P00?2l003X^000d9`00;Ql000809aX000P07QD001XB000F3P004`l0014<000=1`001@80004003@0
0000303oool000X0oooo01@0LY/007BK001dW@40LiX107FJ0@1fUP40N9D007FC0@1dU`40NID107bE
001jV`00NId007bN0@1mW`80Oil407jP201kX@X0N:H;07J[2`80MjX<02L0N:T;07FY2`1bZ0`0LjH@
07BX4@1eYPd0MZ@<07FQ3`1gX180MJ4B07NS3`1hY0/0MjD:07NV2P1hY@P0NZ8707fT1`1kY`L0O:P9
07bZ2@1lZ@T0NjT:07^Z2P1lY`/0NjH<07fZ2`1n[@T0Njl507R]1P1g[PL0M;4706^`1`1V/@H0I[43
06Zb0@1[/P00JK<106Nc101W]0H00P1V/PP09`1Y/`L0J;@606Vg1@1[]P@0L[H307>f0`1f]@40NKD3
07fd1`1n]@P0P;@207ne001i]P<0LkD706fc2P1T/QD0G;0R05Ra;P1H/3L0Ek8i05Jb>01G/3/0EZa0
05JVAP1IY4P0E:A=04fVE`19ZEd0BJUR04^[H`18[6D0CJYO04jXD`1CYTh0D:9>04ZND`12XEX0?J=O
03nUGP02046VG00W04>YH@10ZfL0@:UZ03^XJ@0jZG00=JMe03JVMP0hX7P0>IYk03RGO00eTGX0=Hei
03RCK`0oTVH0@HYV04J<IP1CWU@0HJ/o07R[9@28YQL0TJ@I09nN602LVaX0V9/N09^M802OXQh0Wj4J
09nO7@2TVal0U9XQ09bL7P2LWR00WIXQ09fD8P2RWB40Wj<N09RQ802IX240Vj0R0080Vj4U01`0V:<X
092X:02=Z2H0T:LW092Z902=YRL0UJ@V09VU:P2BYS80SZ@c08jV<P2CYbh0TJD_08^X<024ZcL0O:Pi
07^W>P1iYc`0MZXg07JX=P1b[SL0KZXm06fT@01cYDH0L[To07O0<`1e`2P0N<0R0P1k`1h02@1k`1T0
Nl0E07_14@1n`0l0OL8?07_1401l`140OL0B07[0500207c04P0W07c0501j`1<0NL0E07c04@1l`1<0
O/0C08304P21_100Q[T>08:l3`1n`0`0N/8=07[35@1k`1T0N<0J07G06@1c`Qh0Ml0Q07Zk8@1h_RH0
Nk`Z07_08P1naA<0OLD@08353`1na0l0N/D<07W7201gb@P0NLP;07O72@1eb0X0MLL;077:3P1ebA00
M/XH07W96`1ic1h0MlXQ0080MLXP02D0N<DT07Zo;01l`bd0NlD[07W5;01haR`0N<LZ07W8:020b2X0
P<@X07o79@20ab00OlLO07c97@1hab40M<H[07?2=01daCP0MLA00775B01^acT0MlLY07c4:@1l^Bh0
N[Xb07Jg?P1lYd`0QYI?0:29D02QPE80W7]B08R?A`23W340Ri/C08ZE0P2:TP00S9400080S8d00P2B
TP009`2EV0D0TJH>09>/402A/Q00Sk0@08bb4@2</A00RZdB08^/502;[1D0T:lA08fc3@2:]PP0RkX=
08S45021`bP0O/4a07k0:`20`2/0QL4/08O69P2:b1T0Ql/G08C97@23bB@0Q</V08;;8P22cB00P<l/
07g>;@1mcRD0Mm0Q07?=9@1cdB/0L=4`06k>;@1bcbL0M]0V07KB9@02073@:`0W06_@;01Sd340GlXk
05[4AP1C_E00C/I@04S7C016aD`0A<Q;04?5BP10`T/0?l9F03jnF@14^E<0AJY:04BNB014XT40@9lh
03nE;013TR<0Bh`M051m401EK`L0Eeh205Q?001HC000Ed/00556001@A@00Cd@004a10013?000@3<0
03hd000o;`00?bh003P/000f:@00;R0000809a`000T091T001lE000H4@005Q0001<=000?200020<0
00<100010000<`00000<0?ooo`002P3oool0501eV@00LYT007FM001cWP00M9h007BL001fV`00MIT0
07JI001hV@00NYP007VI001jVP00NIX007ZO101kWPL0Nj<:07ZV2`1fZP`0MZ/=0P1hZ`d04P1fZ`d0
LJTA072X501`Ya80LJH?07:T2`1cXP`0M:<=07>T3`1bYa00MZD>07NS2`1jX`P0NjD607jS101lY0H0
NZH907RY2@80Nj/901<0NZT907R/2P1iZ`T0NJX;07jZ2P1oZ`/0PJd807f`101f/@D0MJl6076`1P1Z
/0D0I[0306Jd0@1//`40K;8006^b001Y/P40J[@30080J[<602L0J;D606Nd0`1Z^0<0K;H607Fe1@1j
]0@0NkD307nd1022/@L0Q;8608Fc0@20]000O[D107Zb0`1c[`T0K;8;06Fc4@1P]1X0GKLV05Zf:01I
/bX0E[<f05J^@01IYdD0Ej5:05:PC`1<XUL0B:EN04RWG01:ZV80BjUP04^WG@1?XEH0DiYE052GD`1;
UUT0@iaK03jTFP12ZUd00P16Zel09`13ZFH0@JI]03jVKP0lZ740>JId03JRO00bWWX0=9el03JEO00d
T7`0=Xee03Z@LP0nV6T0AY1W0523J01CPf`0G9mF06N^?024[R40SZXB09JX602OXa`0VJ<G09BV7@2K
YAl0WJDH09^W5`2IYA/0WIlP09VJ7P2HW200VY/U09^K8`2MVR80WilP0:2S802GXad0Uj@O09BS7`02
09JS9P0W09FV:P2?ZBT0TZL[09:Z:P2AZRT0TjD[09BV:@2DZ2T0RjhY08^`;027/BT0RK<X08^`8P2;
/R40P[<S07Zc9P1k[bH0N;<Y07Jc:`1f/bX0Mk<a07:^?@1cYd<0Lj=407Bb?01h`3<0N<0]07[0901l
`240N/0M07_07@1j`1P0O<0E07c04P1o`140PL0?07g03P1m`100O/0C0080P<0A02L0O/0?07c0401i
`140OL0C07k04P20`1<0Pl0B07nn5P20_AD0OK`D07W04P1f_QH0K/8L07?0901g_al0N;dP07K09@1e
`2X0NL0[07_0:P1l`2X0O<<Q07_54`1jaPl0OlD<07o52`1maPT0NLX907W;201lb0T0OLD:07c62P1k
b0X0L/L<07W73P1haa80MlTD07[95P1ibQX00P1hbAh09@1jab80O/D/07c3=01k`S40Ml0d07K0=`1d
`3P0L/4d07c4;`1m`bX0O/@V08;77P1nb1h0O<PN07[69@1b`Rh0L/<e06o4>`1]`480Jl=406g6?P1e
acD0O<<^07k0;01j`300NKPm08:PC@2ASTl0Z8U80:b7C`2XPE@0SY=5086M=029WA<0RiH108^B002=
U0000P2=S`02096E000W09BL202>Z1<0SZlA08fc4`2>/a80S;8E08Nb4P2:/Q@0SK8B08jd4P2:/Pl0
R[<;08Ff3026_100R<DJ08C3=@1n^d00P/4h08?5:`24`300Q[l_08G7:021bad0P/`K08387023b200
Q/TQ08C=7P1ocb<0O//Y07W?;01dcbL0L/dY07;A;P1ccc00LL`_07;?:`1dd2`0L]4[0080L=4[02L0
J<l]063;<01Od300D]@i04cCA014dTT0?Le=03k8E@0kbeP0>;mQ03VYJ`0hYW00>ZI/03^cI`10/Eh0
A:QE04NZB`15Yd@0?id_03jJ9`16TR80C8@H055f3`1HH`<0FE4005A=001EBP00E4d005A7001?@P00
C3l004Po0015>@00@c@003hd000l;`00>2d003@W000/8P000P0W6P002@0T6@007A@001L?000A2P00
3`T000h9000:10001@800040000c000000`0oooo000:0?ooo`80L9/00180LYh0076P001cX000MI`0
07JH0@1dV040M9T107NL0@1gW@00O9X107^M0@1iV@00NZ4607VR201gX`X0N:L<07F/3`1gZ`d207FY
3P0W07JW301cYPd0Kj@>07:Q3`1`X@`0Kj0<076P301`X@X0LZ0:072O2`1dX0X0MYh807^O1P1mXPP0
Nj8807VW2P1hZ`X0NJd907R^2P1j[@X0N:/:07N/2@1e[PT0Mjl907^]2P1nZ@T0P:/607f]0`1j[`80
N:h407Ja101_/P@0KK8206jc0@1`]000L;<0072d001a/`00L[<10080K[8302L0J[<206Ve0@1Z]@H0
K[@707Jd1`1j]0H0O;4607jb1@21/@@0Pk4308Bc0@23/`00PK8007bb0@1i/0@0Lk4706nb2@1Z]@h0
I[HF06>e6@1O/al0F[4a05V^@01MZDD0GJ9:05RODP1BWeT0D:5K04fUFP1;YEX0BJIL04ZTGP17W5`0
C9IM04bFH019TV00A9YM04FTF`14ZE/00P13Zf009`11Z6H0?jIb03bTM00hYGP0=j5h03JHO`0eU7l0
=IMl03RDO@0fSWL0>he^046AJ@18UF<0CI5P05>>G@1HUUT0I:U8076b<028/1h0T:hD09F/502NYQ`0
UJPD09:Y5P2E[1d0WZDI09bQ6@2NX1P0WY`N09fM902LW2@0U9PO09NN8@2KXRL0Vj<V09ZV802F[280
TJhN08n]800208n_8`0W08bb9P2:]1l0SK<P08nb7`2C/2<0TJdT096]8`2>[b80Rk<Q08Nd7P23]Ah0
PkDM08Bg3P21^@d0PL0>07nj3`1k^0l0OKPE07ff5P1l^1T0O;HO07Re;01e[c40Mjdh07Nd=P1j^CD0
N/0^07W09`1h`1l0Ml0J07Rm5@1m_Q80O/0@08304023`0l0Q/0>08G03022`0d0PL0?0080P<0@02L0
PL0<07o03@1o_140P<0B08304`21_100Q[`>08>m3P21`1D0P<0E07Zn601j`1`0ML0R07;08`1h_R00
Nk/R07Zm9P1f_2H0NK`U07^n9P20_R<0P<0P07k06@1kaA@0P<H<08362P23a`T0P/T907o92@1jbPX0
N<L907c62@22a`T0O/L;07k63@1laA@0MlHI07O87@1fab000P1ka2D09`1k`b/0Nl4f07O2>@1ea3X0
ML1207Bb@`1c/d<0L[8o07Re=`1e_300NLDV07o:6P1mbQT0O<HN07[59@1ea300K/De06[3>@1Z`cd0
Jl@i06_3>01bach0N/4e07g0<01j_cH0OKA408fGC`2JRDd0YXY:0:^:CP2YSE<0Si]8082U<027Wa00
SIH1092B002AU`00TY<009:A000209:I0P0W08nP3@2?ZQD0RjdC08bc4P2<]Q80RkDD08Rb4P27/Q80
Rk<A08^i4@28^Q00QK`?082j4024`AP0Q/HS08Jn?023]4D0Q/0i08S6:`26`Bh0Okh`0873:`21bb<0
PLdR08G<6P27bAT0RLLT08_:8P23c2D0OL`^07G==`1`d2d0K<X^06g:<`1accH0L]4a07?B:`1ce2d0
KM4_0080Jldc02L0H/dd05[;?@1@cd40Bli<04O>E`0mbeX0>lQT03[9J00jafP0>;]a03J`M@0f[WP0
=:ie03>fKP0i^F<0@KIJ04NgD`18/TP0@jXf042Q:P13UbD0AXdQ05=m5P1MI`@0GET005A?001ABP00
E4`004m6001<@`00C48004`m0016>000?S<003``000k<P00>2d003<W000^8@000P0Y6`002@0R6000
71D001P@000B2@0030/000h7000:1P0010800040000c000000`0oooo000:0?ooo`80L9/00180LYh0
076P001cX000MI`007JH0@1dV040M9T107NL0@1gW@00O9X107^M0@1iV@00NZ4607VR201gX`X0N:L<
07F/3`1gZ`d207FY3P0W07JW301cYPd0Kj@>07:Q3`1`X@`0Kj0<076P301`X@X0LZ0:072O2`1dX0X0
MYh807^O1P1mXPP0Nj8807VW2P1hZ`X0NJd907R^2P1j[@X0N:/:07N/2@1e[PT0Mjl907^]2P1nZ@T0
P:/607f]0`1j[`80N:h407Ja101_/P@0KK8206jc0@1`]000L;<0072d001a/`00L[<10080K[8302L0
J[<206Ve0@1Z]@H0K[@707Jd1`1j]0H0O;4607jb1@21/@@0Pk4308Bc0@23/`00PK8007bb0@1i/0@0
Lk4706nb2@1Z]@h0I[HF06>e6@1O/al0F[4a05V^@01MZDD0GJ9:05RODP1BWeT0D:5K04fUFP1;YEX0
BJIL04ZTGP17W5`0C9IM04bFH019TV00A9YM04FTF`14ZE/00P13Zf009`11Z6H0?jIb03bTM00hYGP0
=j5h03JHO`0eU7l0=IMl03RDO@0fSWL0>he^046AJ@18UF<0CI5P05>>G@1HUUT0I:U8076b<028/1h0
T:hD09F/502NYQ`0UJPD09:Y5P2E[1d0WZDI09bQ6@2NX1P0WY`N09fM902LW2@0U9PO09NN8@2KXRL0
Vj<V09ZV802F[280TJhN08n]800208n_8`0W08bb9P2:]1l0SK<P08nb7`2C/2<0TJdT096]8`2>[b80
Rk<Q08Nd7P23]Ah0PkDM08Bg3P21^@d0PL0>07nj3`1k^0l0OKPE07ff5P1l^1T0O;HO07Re;01e[c40
Mjdh07Nd=P1j^CD0N/0^07W09`1h`1l0Ml0J07Rm5@1m_Q80O/0@08304023`0l0Q/0>08G03022`0d0
PL0?0080P<0@02L0PL0<07o03@1o_140P<0B08304`21_100Q[`>08>m3P21`1D0P<0E07Zn601j`1`0
ML0R07;08`1h_R00Nk/R07Zm9P1f_2H0NK`U07^n9P20_R<0P<0P07k06@1kaA@0P<H<08362P23a`T0
P/T907o92@1jbPX0N<L907c62@22a`T0O/L;07k63@1laA@0MlHI07O87@1fab000P1ka2D09`1k`b/0
Nl4f07O2>@1ea3X0ML1207Bb@`1c/d<0L[8o07Re=`1e_300NLDV07o:6P1mbQT0O<HN07[59@1ea300
K/De06[3>@1Z`cd0Jl@i06_3>01bach0N/4e07g0<01j_cH0OKA408fGC`2JRDd0YXY:0:^:CP2YSE<0
Si]8082U<027Wa00SIH1092B002AU`00TY<009:A000209:I0P0W08nP3@2?ZQD0RjdC08bc4P2<]Q80
RkDD08Rb4P27/Q80Rk<A08^i4@28^Q00QK`?082j4024`AP0Q/HS08Jn?023]4D0Q/0i08S6:`26`Bh0
Okh`0873:`21bb<0PLdR08G<6P27bAT0RLLT08_:8P23c2D0OL`^07G==`1`d2d0K<X^06g:<`1accH0
L]4a07?B:`1ce2d0KM4_0080Jldc02L0H/dd05[;?@1@cd40Bli<04O>E`0mbeX0>lQT03[9J00jafP0
>;]a03J`M@0f[WP0=:ie03>fKP0i^F<0@KIJ04NgD`18/TP0@jXf042Q:P13UbD0AXdQ05=m5P1MI`@0
GET005A?001ABP00E4`004m6001<@`00C48004`m0016>000?S<003``000k<P00>2d003<W000^8@00
0P0Y6`002@0R600071D001P@000B2@0030/000h7000:1P0010800040000c000000`0oooo000:0?oo
o`0D06bG001^VP00KY/0072L001cV@00MY/007FG0P1dV@80MIL207FJ0`1jV`<0Ni`107VN0P1iX@80
N:8207JS1`1dYPT0M:L<07BX301cYPd207BV2P0E07>Q2P1cWPX0Kid;072K2@1^W@P0KIh906bP2P1_
X0T0Kj0706fN1`1aW0H0M9/707JM1`1hWPX0N:8;07NX2`1hZ@T0Mjd907N`2@1h[@T0MZl80080M:l9
00T0Mk0907^`2@1k[@P0Nk0607V^0P1k[`00Mk0007Jc0@1b]0800P1`]@4207Fb0@0307Ra0@1f]080
Mk<20080MK<102L0Kk<106bd1@1]/`L0K[@707Jd1P1j/`@0N[4407^a0`1n/P80O[<1082d001n/P80
Ok8407nd0`1l/P@0N[@407Ne1P1g]PX0M;H<07:d3P1[/A40HjhT05^_=`1OZT@0II]=05bHD`1EVUT0
DiaJ056QF01=XUP0BJ9L04RMH@14Vf00A9IN04JFG`14Ue`0@imM04BUG014Z5h00P12ZV@09`0nYW00
>J5m03VPP00hXG/0=j1k03NIOP0hVGH0>YUe03ZHL`0jTf`0@8mR04Z;G@1=SUL0CY9A05ZOB01/ZcH0
N[4V08>c7P2=[QX0UK0D09Z]602OY1d0V9lH09>Q5P2GX1X0VZ0O0:2M8@2OVR40WYdR09jR9P2IXRT0
T9lW08jT:02C[RP0UJdR09FZ7`2A[R40TK0O08Zd7`0208Re7P0W08Nh7027`1<0RkL?092f3`2<]Pd0
QkH=08Zd302=/P/0RK@;08Vf2`28/`d0S;<=08Zc2P2:]@T0R;D:08Ne2024]@L0QKL:08Bf2P1n]`d0
OKL?07bj501o^Qd0N[@S07Ze:@1i^C<0Ml0c07G0<P1d`2T0M/0Q07Fk6@1j`1@0Ol0B08;04020`100
P/0A08C03@23`@d0OL4B0080N/0C02L0O/0A07jl401m^a40P<0A07fl4@22^A40Q[X=08G03`1m`QH0
PL0M07bn8@1i`2P0M<0T07Fl801g_B<0N;`U07fm9`1k^2X0O[XS07nk8@25^Ql0QKPO08:j7`1l`Ad0
N/DF07o63@22aPT0PLP:07o92P1ja`X0O<P907_:2025aPL0R<D;08O43021`a80NlHH07[66`1iab00
0P1kaR@09`1h`bX0N/<`07K3=@1_`ST0L/1407>^B01fYDP0NZ5707ZW@01b^3H0M<0Y07S:701eaAT0
M/DM0777901_b2l0K<Pb06_7=01WbcD0J/Pc06c1=P1c`cT0OL@c07c0;`1g_Sh0NJY:092BDP2OPe00
YXE=0:R5C`2^RTl0U9m407jY;02:X@h0SY`1092J0@2@V000TiH009JI0@0209FR1P0W096V3P2@[100
S[4A08bh4`27^A80R[HB08Zb402:/100R;0@08Ng4@25]Q<0Q[XC08>l5@24_aX0QlH^08Jm@025[D00
Rl4c08[:7`27a2@0P;`/07jn<020bBX0PlhX087=8@20cAh0QL/U08S88P27b1h0O/`R07G?<@1`dBX0
J/Tc06c<>01]cCh0Kllh077?<01_dbl0L<l[0080JllY02L0HLh/05G>>@15c4T0?lmI03[?GP0jcV40
>]1Q03W@IP0jc680=<AQ03S5J00i`W80<l=b03?5I`0i`e`0@/AE04K2C`18^cd0@KPc03n`=@12Wc00
AXlY05J15@1QJ@80GE`005YC001HB`00DdL00515001B@P00CDH004Xl0011=000?B`003X/000k:@00
=bL0034S000a8P000P0[7000200S60007QD001PB000D30003`T000d7000:1`0010<0=000000<0?oo
o`002P3oool0501`U@00KiH0072K001cUP00N9<007JG0@1fU@80MIL307FF0`1eV@@0N9/407NL0@1e
W`80M:@507FS0`1cYPL0LZ@8072V2`1`XPh0LIl:0P1bW`T09`1_W@L0Ki/406fH0`1ZU`80JiP206jK
1P1`WPL0L:0706fQ1P1]W`H0Kid807:M201bVPX0M9h=07JQ3@1gYP`0MjL907RY201gZPP0Mjd807N[
1`1g[`P0N:h807N/2@1j[@P0N:/707N]101h[P<0N:l207Fb0@1a/P00L;@306je0P1_]@40Lk8107R`
0@1h/@80Mk8407Vc100207Rd0P0W07Fd0@1d]0D0LKD6076e101i]P40N[D007Rb0@1h/`00MK@007Bf
001h]P40OKL507jf1P20]PD0PKH4086h1021^0<0P[L508Bg1`21]0L0N[4<06j^5@1X[bT0IJXj06VM
A@1PV4`0FYEE05RHF01FVUh0CI]N04ZHH`14UfH0@9AU04>DGP11UUd0?iaN04:PG@12YF40@JMW0080
?jUX02L0>JI/03>SM00dXgX0=j5h03ZPM`0iX7<0?:5/03bNI`0jV6D0>iAP04J=F01>RE@0D8Y?05NH
AP1TZC@0Mk0U08ba602@[Q40TjlC09R^502H[AT0Vj@O09fJ7`2NW1X0V9`M09bM8`2JWRT0Vi`]09^O
9`2HY2T0U:D/092W:`2;[RP0T;DL09:e5P2A]180SK8A08nc402?]Ph00P2=^@h09`2;^0h0SKH=096f
2P2E]0X0T[H608Zg1@2;]@<0SK@108bc002>]080SK4608j_1`2@/@<0TK<208nc0@2>]080S;<308be
1029]@L0QkD808Fg2@2:^@`0RkP=08Zg4@23]Qd0O[PZ07Rj<P1g_c00Lk`Y07S0801g`1P0O<0C07g0
5@20`1<0Ol0E08;05022`0h0PL0>07c03P0207Zn400W07g0401o`140OK`@0870401o`140P/0B08W0
4028`1@0P/8L08Jl8@22^BL0O[XZ07_08P1g`240ML4R07O2901j`2P0N[/^07Vl9P1j_B@0PkXR08:k
8P22^240OL0P07W36P1iaQ<0NlX?07_82`1hb0/0MLD;07[62@23a0<0S/0108k2102:`PP0PL<<07k4
401mbQ@0O/LK0080O<HR02L0Ml@Z07W5=P1ha3X0M<8j0770@`1cZ4`0MiQ@07jIB@1oWD80MZli06o1
<01eab40LlPK07;77@1ab2L0L<X`06_8<@1Xac80Jl8f06S1=`1Z`cP0ML<c0832;`1l`3<0MKY007NQ
CP29SU<0V8E@0:1lA`2SPDd0ZXM=09:P>@20ZAh0S:8=08fO0@2=V`40TI/009FJ002HXP@00P2GZ`h0
9`2D/0l0T[<?08fd4@2<^A80RK`B08Rj4P2:^Q00R[D=08Zd3@27]0d0R;@=08fe3P29^A00Q<0E08G6
:027`3`0R:m00931<P2?b1X0Rl@K08Fk:`1n_2X0OlH_087<:P20bb00P=4M08C<8028a1h0Ql<L08?:
7P1icB/0M=0/06_@>01]cS/0Jla206K;@@1[cd00K=0k06_:;@0206;><`0W05_<@@1=`U80@KUN03W8
H@0gd5l0>M1>03gC@P0idd@0>]8o03CC@00`e4l0<m1P03;BK@0gdUh0?l]>04;7AP13_D<0@k/g046k
=@13]S/0A:Hj04NC<P1LOQ<0HVD005iI001JD000Edd005A8001B@`00DTD00513001;?P00AcD0044a
000n:`00>b`003PY000d9`00<RD00080:ah000P091`001lH000K4P005`d0018;000>20002@@000<0
03@00000303oool000X0oooo01@0LIL006jE001^U@00LYD007>C001eU@00Li@107BD0@1fV@<0M9T5
07>J0`1fWP80MIh207NO101fW080M:8707:Q1`1]XP`0Jj<@06fM2P80KiX90100K9P806VG201YUPP0
J9P706^I1P1^V0D0Kih4072M0`1]WP<0KIl7072M2P1dW0X0MIT907VK2`1eW`/0MZ0;0P1gX`X02@1f
Y0T0Mj@707^W1@1nYP80OJL707fY2@1kZ`P0OJd507Z^0`0207V^1@0:07F_0`1b/@40L[@207Bb0`1f
/@40N[0207Z^0P1i/0<0M[4407Nc0P80N;@102L0MkD207Je0`1d]0@0M[D307Ze0P1j]000M[<007>a
001c]000M;H007Ne0@1l]0<0Ok85082c0`25/P<0PKD508Bf102:]@80SkH108Zc0@21[`L0Mjh=06b_
6`1YZbT0I:@j05jJB@1KU5H0FIEP05JFIP1>UVL0B9QY04FJI`14W640@i]J04FNFP14Y5h0A:UV046Y
KP12YW000P0oYFX09`0iXV/0=Yib03NKN00iVGP0?YYh03nOK`14XVT0@9YQ046AGP14S5X0B8]B04nA
A`1IWS/0JJP`07>]8@25/QX0U;0E09V_4P2I/100V:XF09fY602MXb40W9dU09^J9P2PWB@0XIlV09ZU
;P2CZ2d0T;4U096e7`2=/aP0Sk@F096f502A^140TkL>09Bc2`2B/`T0Tk8409Bb1@02096c1@0W08n`
102=/080T[0309Fb0`2A]@40R[<108fb0@2@/P00Tk<009Ba002C[P40U:l309Na0P2B]040U;@0092e
002B]`40TK@209:d0P2@]080TkD509>c1`2G]@X0Uk4=09Bb402</a@0P;TW07Rk;01e_2d0N/0L07k0
5@1n_180O<0A07jn5P20`1H0Pl0D08Jk3`25`0d0O[`>0080Nk`=02L0OL0@07g04P1m`180P<0?0872
4@28`1<0S;TJ08^j7@29^ah0R;PS086k9P1o^2L0OL4P07[47P1haQd0O<LM07o48`1n`2T0OL0W07o0
9@20_280P;XO086k7P1k`1h0N<@M07G8601fba80L/T?06k74P1_aaL0O<D=08S5102B`@80S/0108K3
1@26a`X0P/L@08785P1ob2800P1kabP09`1daC00MLXd07W8<P1haS<0M<Dj076f@@1cZU40NZ1;07jN
A@1g[D00Kl0i077::P1bbQ`0L<XP077:801bbRH0K<T[06_7<01Z`3P0K<0k06c1?01ea3@0NKhe07Vh
?01e[T<0NYm;08:?DP2@S4l0W8=40:23A@2RRDL0SJ@a07nY502@XP/0TI`1092L0@2@W`00U9l309NR
300209N[4@0W096b4@2>^140S[PE08bl5@2=^Q40R[XA08Vl402>^Pl0RkP>08bc1`27]PP0RkL608Rh
2@25_aD0Q<HU08Jm?@27[T<0SL4c08g96028`Qh0QKP^086i<P21`380Pl/`08?=9026d1l0Q<`L08W7
6`2;b1/0R<dM07c>8P1dd2P0K]<k06g??P1/bTD0JLY506K8A01SaT40Hl<m0080FLM402L0CLQE04Nn
IP11]6L0>kaT03S7G@0lc4D0@Lde047>;P13d2/0>]8d03;CA@0de5/0==EK03[CD012cDH0@l8n046f
@`12]cl0@KLo04F`@P19Xc80Di8O05mm2P1SH@00H5@005U;001GB`00CdT00555001BAP00C48004/k
0015?000A3H003he000l<000>Rd003HW000c9P000P0/8@00200Y700091X001dF000G3`004P`000`7
00070P000P40=000000<0?ooo`002P3oool01@1_U`00KI@006fC001aUP00LI400080LY0000d0LI@0
07>F0@1`UP80L9P307:M101dW0H0Mi`407RI0`1gV`L0Lj0906^P301YYQ00KZ0<0080K9l901/0J9d9
06BJ301TWP/0Iid<06RL2P1ZUPT0JYP606ZL0`1ZW0@0K9/706jK2`1eVPP0MiL607VG201jUPP0N9d6
07VN201hX0X0Nj4707bQ101nX`@0Oj8207jU1P1kY`P0NZ/707Z[1P1k[@D00P1j/0D02P1i/0<0Njl1
07f_0@1n[040OZh207b]0P1k/0@0N;4307J`0P1f/@4207Fd000W07Vd0@1i]@40OK<107fc0@1n/P00
O;8007Vb001h/`00NK@007fc0021]000P[4108Bb0@23/P00PK<3086f1P22]0D0R[D208fe002;/`40
Pk<707^b301a/Q@0J:lQ05jY=01PWT@0Gi=B05b?G@1HSf00CIES04NMI@17YV40B:YM04R]F@17[5T0
AZMS046TKP10Y7D0?Z=e0080>im`02L0>YY]03RHL`0gUGL0>iEh046FL`15VF/0B9MV04RBG@18S5l0
AHaI04V<DP1GX3`0Ik4/07Fc801n/QT0Rk4D09B_4`2F[Q<0UJdG09JZ5`2I[QT0VZhP09ZZ8`2HZ280
VZ`O09j/7`2K[B<0T[0R09:o6P2B_a40RkPA08nf402A^A00T/0>096e302D]0D0TkD4092c102B/`@0
0P2E/@809`2D/@40TK4109:e002E]@00Tk<009Bc002F/P00Uk4009Rb002G/000UZd009F_002C/@40
T[0109:c002<]P00T;H109Bf0P2F]P40UKL009Bd002H/`00V[<009fc0@2I/@H0T;8=08Fg6@1j^B40
Nl0W07W08P1g`1T0Nl0B07g03`1n_A<0OL0D08;04P26^a00QK`>07o03P0207c03P0W07k04P20`Q<0
P/@B08S34P23`Q<0QL4H08Rk802<]R00SKLO08Ji8@23`240Ol8N07_56P1jbQD0NLTF07g;6P1laAh0
Nl0U07Zk:@1j^RT0NKTS07Jk8@1g`280Ll<O07357P1_bAh0M<TJ06k56@1`aad0L/TN08784@2=a0X0
Tl<909;3102<a0@0R/D908S52`24b0l0P/HJ0080O/<T02L0N<0]07S6;P1jb340NLPc07G7<P1ca3`0
M;U907VUB`1iWd/0M:];06nl?`1_bC00LL/W073<7`1ec1/0M</M06o;9`1^b2d0K/4h06c0?P1]`480
M/4i07Nd@@1k[4D0MZQ507ZQB`20Ue80QiEA09f8C02SQDD0Wh]308jV;`27[Q80TZL909BS002@W`00
TZ8109FW2P2E[@l00P2@[QH09`2;/aD0R[`D08^l5P29_AL0RkdH08Zl4`2<_a40SKd=096h302>^0/0
QK/;08Fg2@25^Pd0R/4D08O9:@27_S`0RK9008_1=02:aaX0Q[lK08Rj;`25_c80Q<Hb08G:<026cBX0
QM<Q08G>6@28c1P0RLXI083>701kcB00MlhT077A<`1^cCT0J/9706NiB01W[dL0H:a?05fWE`02056/
H@0W04fVIP19ZFP0AJeX042bHP0k/5P0@;5?03nh@011^cX0?l8g03W8A@0fc5<0=/mR03GBG`0id580
@<]7046l>P12/Cd0?kE:03jbD`13YdX0Bi`W05^>4@1VM@@0IFL005mI001JDP00ET/005A8001AA`00
DTH004/n0015?@00A3L003ld0010<@00>c4003`/000d9`00<bP00080;B<000P0:ah002DH000P4`00
6A0001@<000=20001080008103@00000303oool000X0oooo01@0K9D106fA001ZSP00LHl006n=001^
RP00Ki4006n?001^T@00KHh206j?101aTPH0LY@807JF1@1hU`L0MYP:07BO3@1/X@h0JJ<?06RQ3`80
IJ4;02L0IIl:066N301UW@`0IYd:06RL2@1YV`X0J9T606^H0`1^U`@0LID607FD201fUPD0MiP707JG
2@1gUPP0NIT507^M1P1lVPL0OY`307fN0@1lWP<0Oj8507jS1`1jYPP0NjT907ZX2@1iZ0P0Nj/507b^
0`1l[`@0OJl1082[0@23[000PZ`107n^0P1j/0D0O;0307V_0P1i/@000P1l/P009`1m/P00O;<007na
0@24/P40Pk4007na0021/P00Ok8008:a0024/@00Q[<008Jd0026]@00Q;D008>d0@21]`<0Q;D308Vd
0@2:/`00Rk<108Fd1P1i]@P0LK@=06Vc5P1S[RL0HZPh066MB01KVTl0F9]B056ND`1<YeL0C[1L04f`
F@1;/UT0B:iN04FTI@13V6d0@9Qa03jILP0203nDL`0J03Z>MP0jRGD0>HYg03fDM013W6l0@j9Q04JR
E`17XE40C:1?04jQB@1GXSX0IJh[07>h8@1l]1X0Q;8J08Z]6`2A[QT0TjlJ096`702B/Q`0U[<L09Fc
802?/Qd0Sl0H09>k4P2D^Q0209Jk3`0;09>o3P2A`0h0T<0>09:f3@2C]`h0TkT>09;02P2A]PP0T[H:
09Bh2@2D^0/00P2D]0d05P2E/P`0U[D;09Ji2P2D]PX0U;D:09Ng2P2G^0P0UkP709Ff1`2B/PH0U[04
09F`0P2E/P80Tk8209>`0P2>[P40T[4009Je0@2F]000VKD009Jf002F]`0209Zg000?09Zc0@2G]0L0
SKP>08:k5@1m^a/0N;`K07_05@22_0h0PL0>07o03P22_0h0Q<0=08Jm3P24`0h0O/0?0080O/0@01L0
OL8G08356022`1D0RkhE08[05@28^aX0RKTM08Zh7P2:^Ah0R;/N08K07P23aQH0O/`B07c<401jc1<0
NldG07[8701haR<0Nl0U07Rl9P1i`200L<0O07K18@0207K28`0>07C28@1j`240ML0V07nm9`21`B<0
QLLM08[8402;a`/0S/L908o71`2AaP<0RLP408C92P24a``20877600W07c48@1jb2L0MlLc07[6>01g
acL0MLTd07[2=P1g^C`0M:i206ffA`1[`400KLT`06o;9`1_c200Ll`O07?;901]bbX0JlX`06k3>P1`
`T<0L;Y407Bg?`1iZTT0NjU907R`B@1k[4X0PYm@08VEDP2QRU80YhI?0:2:B02?YRd0Q[@C08jZ2P2A
X@40TIh009>Q0P2D[@d0T;8E0080R:dQ02L0QKDM08Jn6028_QL0Q[lK08>m8027`1T0R<<C08ni3`2@
^P`0T[X?08Zk3@25^@/0Rk/A08W34`28b2@0Ql@a08Zm?028`c<0R/DN08K46`28_Bl0Rl0b08C4<025
bC00Q/X]08?=:@25cQ`0QLlL08C?6P1ocR00O<XS07W97`1ebQl0LL/X06g9?01Va3l0J<5305niD01J
YV800P1=WW008@1=TG80C9UZ04Z/J016/F@0?Z=R03jFF`0nWUL0@:MB046cEP0n^VL0>[eb03c2M@0h
afh0>l]M0479C@15_cl0AK=3046aEP13[UT0AZA005>G6@1SQ0P0JW0106EY001TGP00H5P005UA001F
C000DdT00555001>?`00BC/004He0002044a000403hc000m;`00=B/003<X0080;R4000P0:R0002DM
000O4`005Pd001<;000;1@001@80004003@00000303oool000X0oooo01@0JXd206b<0@1^R@00K8X0
06j<001]R@00Jh/006V>001ZS`00L8d106f90P1aS0<0LXl507>@1`1aUPP0LIX:06fR3`1ZXa40IjD=
06FT3080IJ<=02L0IJ0<06JM2P1/W@P0Ji/606ZK1`1]W0D0L9X5072J101bUP<0MY@407JF101dV@@0
LYl606nN201dW0T0MiX507fN101nW`P0O:0807VR1`1hYPL0NZH807^U201lYP/0N:P=07VW301lZP/0
P:/7086/0`22[@@0P:`308:]0@23[000PJh007j_0@1j/080N[4407n`0P21/@400P21/0009`20/000
Ok80086b0024[`00QK4008:^0024[`00PK0008Fa0027/000R;4008Rd0028]P00Q[<008Fb0023]@40
P[@008>e0025]@40Q[D1082d0`1i]`L0LkL9076f3P1/]AD0Ik<Q06J_;P1N[SH0FJ`m05R^@P1AZdh0
D:eG04^]F`1:Z600A:AW04>GK@10RG80@8Yd03n;MP02042>MP0W04>:M`0nRG@0>hid042HK@11Xf<0
A:mE04V`B01@/cd0EK@g05ja;P1Z/b<0MKHK07Ze6024/QT0RK@K08jb7@2B/Al0S[<N096g702A^1P0
TkTE0930402?`0l0UK/?09Bk3P2D^Pl0U[X=09^i3P2K]@h0Ul0@09Vf402F`180UKHB09Fg4P2E`0l0
Tl0>09703`2?]a80SKDH0080Sk4P02L0SjlM09J_6P2H/AX0Uk4I09Vc5`2L]1<0WkHA0:2f4P2O^100
WkL>09jh3`2K]Pl0VkL@09jf3P2L^0d0W;D=09^d2`2K]PX0VkP:09[02@2F`0T0U<0909Jk2@2J^@X0
VkT;09bj2P2E^PX0S[/=08C05@1m`1L0O<0E07o03`21`0l0PL0>08G03P28`0h0Q/4@08O24P27`1<0
0P28`1L09`23`AP0P/4F08Rl6028^1X0R;HN08Vg7029]Q/0Q;/J08>m7027`1d0Q<<J07c6501kbPl0
O</?07g;4`1kbQ<0NL/H07S98@1m`2@0O[PU07^i8@1f^b<0MKhV07Bm:@1g_2P0N[`Y07bk:`1j^C00
P;H^07bh;`1j`Bl0O<HO08395026b@d0S<T;09772P29b0L0QLX808;92@0208783@0W08395022bAX0
P<PR0836;@21aRl0OLXY07c<;@1fac00L/@j06k4?P1YaCh0J/Ld06g:;P1^cBD0LL`V077<<@1/bS40
K<Lg0773?@1b`480M[E207Z^@P1jY4T0Nj9<07b/C01m/Dl0PJ5C08FFD@2PRUD0Z8QF09n;B`2=Y3@0
Q;DG08b]3P2AX@<0TZ4409BV2P2C/AD0Sk@K0080Rk@L02L0Q[/G08K05`28_QP0QkhJ08728023`QT0
QL<G08bj502<`A40T/8A08bk402:_A00Sk`A09334P2?a1D0RlLS08W5;`29`S@0R/@T08c36@25`2D0
QL0`08Bm<P20^S<0P/Dc08G::P22ca`0P/hM07oA8P1kd280O<PO07c26@1g`QT0LLHR06o9:P1[bRh0
JLe005k6DP1H/E`00P1>ZV409`1=XVL0C;MV04S8G@15bU@0A[Y=04>dA010^4<0A;I704:iDP0m^f<0
?<1Z03g3J@0maf40?/UH0473D013^T/0@k1B04B]FP15Ydd0DYdY062<3@1ZO@40Jfd006IV001UH@00
IEh005mH001IC@00E4D00512001:@@00BCh004Li000o<P00?S8003le000k:`00>BL003<X000202lQ
000702TL000T6P007A<001H<000=2P0020H000@1000e000000`0oooo000:0?ooo`0D06f?0@1_S000
KXL006Z8001^R000KXD006^;001YS@00JXl006n>001aR@00LX/107:>1`1cT@X0M9@906nG1`1]XP`0
K:8A06VQ201XY0P206JS2P0W06RQ201/W0L0KiX2072J0@1/VP80KiT306nK1P1`V`L0LY`8076N1`1`
X@H0Jj<606VU1`1[Y@P0KZ@807FS1@1iX`P0NZH;07^W301iZP/0NJP;07VW2`1iYPT0NjH907RU2P1k
Y`T0OJL807f[1@20ZPD0PZ/608:^1@21[P40PZ`008:^001n/000Nk4007fa0`1n/0@0P[430080P;41
0100OJl007jc0020/P00Q;8008Fa0026/000QJl008B`0026/P00R;8008Rc0027]P00QK@008>c0021
]040Ok@10P1m]0405@1o]@80P;L2086h001l^@D0MkT407Ri201h^0/0LkXB06g06@1W_2<0H;P`05^c
=`1F[D80DjY>04nPF@19UVD0@Y5W046:I`11PVh0@89]04:4K00204F5J`0O04R7K@17RV/0@XmW04BL
I@16[U`0BkA904jh>P1J^R/0IKPS072h6`1e^1P0N;TH07jh6@25]aT0QkLI08g06@2?^QL0T;XF09;0
5@2D^Q<0Uk/A09Fl3`2B^Pl0UKX@09>j4@2F_a<0TkXG09jd502N/A@0W[8D0:6`60020:N^5P060:Na
4@2Y/A00YK4?09ja4@2E/a80TkDH0P2@/Q`07@2@[Q/0S[0K08n]7P2A[B<0UZ/U09b]8`2Q[Al0Xj/P
0::Y702Q[1X0XJ`H0:>]602XZQP0Z:/A0:V/4`2/[A40ZZlA0:Ra4@2U]0h0Xk@=0::g2`2N^`h0Vk/?
09S03P2I`0l0X;/@0:704@2I`140R/4D0080Ol0K00P0Pl0D08324021`0l0P/4@08C04`1o`AP0Pl0N
08Zj7`80S;PO02L0S;dI08fj4`2;_1@0RkDF08Zb7P27]Al0P[PO08707`20`280P<0L07[46@1gaaP0
NL/A07c<401nbA@0NlXF07W;701gab80O<0Q07Zh8P1i^R@0M[/V07>k9`1a`B/0M<0]07C1<P1n^B`0
PkDZ08Bd;P1m]300MKD_07Vi;@1i`bD0PLPR08O<6@26c0d0QLX:08C92@22bPT00P25bPT09`24b@X0
R<T<08W84026aQP0QLPS08?98@1mbB@0N</W07;::@1abR/0KlLc06[6<`1]aRd0LlXV07?<:01bcB/0
L<XX06k6;01]aCL0L<0k07Ni@01f/d00N:i307V`B01i/D`0NK9=07nSE026TU@0VHU@0:B7CP2PQTD0
RJ0e07je8@27[A80T:87092V302A[a80T[0R092h8`0208o06P0W08g25@2<`1@0RL0I08O16P24`1h0
QL0H08C05`26_1@0R[dB092m402>^Q00SkhA08fn402?_Q80S<<B08W76P26a2@0R/@[08_58P2=aaT0
R<DK08S0;`27^3@0PkPe08>o<023abT0QLhN08C>7P20dR00P</Q08346`1o^aX0O[TJ07Vl6P1g`1X0
J/DI06C89P1Lac00F<<h0080C/A302L0C<1<04[;C017eT80BMHl04c;=@1<`cD0Al0h04K3@P0k_580
>;mO03[3G@12a5H0@/YC04?5A`14]DP0AZY:04FXB@1;XdD0DZ0_05nD5@1ZP`@0KG4006YX001VH`00
IUd0069K001ND`00ETT00512001;?P00BCd004Xo0018>`00@cH003h`000h<000>2/003LZ000d9`00
0P0_8`001`0V6P008AL001/D000D3`003`X000T500040P00=@00000<0?ooo`002P3oool206b?000B
06b<001[RP00KXT006j8001_S@00LHh0072>001dT040M8X007:8001aSPT0MI4:072F2@1`U`@0KYX4
072S201]X@P0KJ450P1[WP@09`1/W@D0KY/5072J0`1bVP40KY`306jP1`1_WPP0Kj8906nU201`YPT0
KjH906nT2@1_X`T0L:D9076T201bY@H0M:@807>Y2P1dZ`/0M:`;07R[2`1fZ@/0N:P807Z[1@1gZ`H0
N:T407N/1@1k[080O:/307f]1P1m/0D0O:l1082`001n/040O;D007Vf001m]P40OK@207jd0P0207^d
0@0W07Vd001g]000NK<107jb0@21/`00Pk8008Jc0024/P00P[8108Bb0@22]000PkH1086f0@1n]P40
N[H207Ze0P1k]040O;@107fe0@20]@40PkH008:i001l^@80O;T707Vi201c_0X0Kl0A06g06@1Y_b00
H;DZ05^]<`1IYc`0EYe:04fDF018TEd0AHeN04:7H@13Q600AH]L0080BHmI02L0C95H04jIEP1;WU80
CJY;05>dA01K^C<0H;XU06Zg7P1f]A/0O[@I07fe6P20^aP0Ok/H08;05027`140R/0?08k03P2>`180
TkTD09Bd5@2L/Q@0Wk<@09nb3@2M/Pl0Wk@?09^b3`2J/a40WK@@09jc402J/aD0V[0I09NY6`2NYah0
XjHJ0:^V502]XA<0[jDB0:fX4P2U[a000P2O[@d09`2L[0`0VK8=09Vc3P2F/100V[0F09b_702OZaT0
XZTG0:2W5@2MZAP0WZ`H09V]7`2OZQl0Yj<K0:RW5P2XYQ@0[:HG0:nW5P2]YA40ZjPC0:j[4P2^[A00
[K4B0:Z_4`2Y[QH0[[0H0:fb5@2X]QH0U;TG08Zi6@26`1`0Q/0D08?03`26`100RKd?08Zl4023`1D0
Q[/G08ff500208bf600W08^i602?]Q/0S;PK08jd6P2</b40R;DU08Jh:023^bP0P/0N07[46P1caa`0
M/`J07K<501gba80M//C07O85@1haaX0Ml<O07K07P1f^Q`0N[`P07bm8P1n_2<0N<0T07c0;01k_C`0
R;8c096Y<02@ZCD0RjXc08ZX<`22/340O[Ta0837;@21bbD0P/hL087;5022c0`0P//:0080Q<`902L0
R//908[92P29b`X0R<P>08O:5@24bAH0Ol/E07W?601cc1`0L/XT0739:`1_a2l0Kl0[06k6:P1dbbd0
M<`U07?98@1eab80L<L/06c3>@1c_D<0M[Y507JiB@1e^dT0MKM807J]BP1lWU80Pi1E09>:DP2OPd`0
VH=808NJ@01l]2H0R;4B092Y2P2C[Q80UK0L09Fc9`2B`2L00P2Aab409`2@aa`0S/HJ08W27`29_Ah0
Q[`M08>g6P27]AD0Q[P@08bh3@2?]`d0TkD<092k3@2D^`h0UKh@09314P2<`aL0R<DM08_19@2=ab<0
SlLM08c8602;aBT0Ql4b08O3<P25aRd0QLXW08?:8@23bAh0QLhN08798P1o`a/0O[`N08:e7P1m]ad0
N;LG07>k4@1Z`180GLLG05S;7@02057>:@0W04[B=`18eCH0BmP/04gF8`1@cQX0D/LN04c2;017`SX0
B<E804G9B`13c4P0A/Q704K8@`13`cL0BkPg056Y<`1CYB/0G9LS062<5@1WO`H0J74006aX001YI@00
I5h005mI001ME@00GE0005A7001<@`00BC`004Hl0018?000AS/0048d000m;`00>2`003DZ000d;000
=2/00080<2H000P091X0020C000H40004Ph0014<00081P000`40004003@00000303oool000X0oooo
00@0Jhh006f<001]R`00JHX00P1ZS0003P1_S@00Lhh007B?001gU000N94007N?001dU0D0M9H707>M
1`1bV@D0LIT5072Q201aW`L0MIl50P1eV`<09`1aV@H0L9P706jH1P1_W0L0KI`7072O201_X0P0KJ48
072T2@1aYPP0LJD907>Q2@1cX0`0M:4;07BT2@1fYPL0MZD707NX1`1fZ@T0MZX907JZ2P1iZ`T0NZX7
07Z/0P1hZ`<0Ljh307>^101h[P<0NZl307Z_101j/P@0Nk8107^d0@1h]040Mk@107Bf001g]040NK<1
07fd0@0207bc0080N;<002D0N[@107ba0P1o/P40PK8007nb001o/@00Ok8008:c0@22]000P[P107jg
0P1m]@80NKH307Ne1@1j]0<0O;D1086a0022/`00QKD008Be0@22]@00OkL107Ri1P1b_0P0L;d:07;0
301/`180I<0N05bc:@1Q/RX0H;0`05b[=@1GZT00DZTm056V?@1?YSP0D:Ld0080E:P`02L0F:Xa05^^
;`1O/BX0I;HU06Nn8P1^_AX0LKTE07Zj5@22]AP0PkHE08Fi4@24_A00QK`?08^m3@2>`0`0UKT:09?0
302B`0l0T;HA09:b4`2F/1D0Wk8F0:6c5P2O/A@0Xk0C0:2c3`2J/`l0WK@?09nc402N/Pl0YJhA09n[
4P2O[100WJ/D0:2Y502WXQP0Zj4M0:ZS7`2XYAX00P2TZPh09`2O[0h0W[0?09ja3P2Q[`d0YJl@0:Z/
402]ZPl0[J`=0:b[2`2WZ`h0Xj`?0:BY3`2O[A40YZ`C0:BZ3`2PZA40XZ`E0:JY5@2[Y1<0Z:HC0:bW
5P2[ZQT0Z:hJ0:FW7P2YYR80[JPU0:fX8P2WZah0WJhO08nc7@29]QX0SKLG08fg502?]Q@0T;LB09:f
4`2A]a40U;H?08ji3@02092k3P0W08jh4@2D]a80T;LG08bj6@2;^b00R[XR08Ng9`23^R80P;hK07W5
6@1fb1H0MldH07[<4`1gb100LlP?07K6401gaQL0M<HM07746P1_`aX0LL8M06k37`1_a1h0M<DS07_3
:@21_S80QK@f08Z]>`2=[3h0RJLm08ZZ?`1jZcd0Ljhk07O3<01lcBH0OLdR07g=7@21baL0Q<`D0080
RL/;02L0R/X;08S;2@2>a`P0R/L:08K93024aa00O/XB07_;501ibAP0N<TP07O::@1caBh0L;`_06k2
;P1abB`0M//N07S65`1gaQX0L/PW06g6>01]`TH0LKY<07>gD01e^DP0L[E<076XB@1hWE00QY9E09J:
E`2OQe@0V8QB08jL@`20]B80SK0B09:]4@2I/AP0Uk8X08nj:`2BaBH00P2>aR809`2=aB<0S/DS08W1
9P29`200Q;`O08Ng6024]Q<0PkL?08Vg3P2@]@h0TK@@09Be4@2E^a80Ukd@09;04@2Aa1L0SL8L08c1
8`2;aB80R/PQ08c<7@26bbP0Q/P_08G9<@25bRT0P/PW07k69020b2D0Pl/R07o1901j`Al0O;/Q07^c
8`23/R40OK4I07V`4P1c/a00JKXE06335`0205S97@0H053B9`1;eBX0CM8Q04g?6P1@ba@0DLDI04g0
8`18`3<0B<@m04S7=017bS00ClDj04[3=P1<_BD0DkDT05^V6P1SV140JhL:06Yh101UK@40HfD0069P
001TG000HE/00P1MD`003@1JC@00E4d004m3001;?000B3/004Pn0015>P00@3@003d`000g:P00<RP0
03@[000b:P000P0]8`001`0U6`007a@001L@000A2@0040L000L300010@00=@00000<0?ooo`002P3o
ool0501_S`00L8X0076:001/R000KHP0072:001cR000N8h007F?001fT000M98007J>001fUP40MIP1
07FI001cW0D0LY/807:Q2@1bX0X0LZ090P1fWPT09`1bV@X0KiT:06nI2P1aW@T0LZ4;076M2P1`W`L0
LIl707BQ2@1eX0P0Lj08072O201`X0T0MJ4907>R2@1cY0H0MJD207JW0@1jZP<0N:X807F/2@1f[@L0
MJd207R]0`1i[P@0MZd507>_1P1f[P@0Mk8307Ra0P1f/`@0MK@407Jd0`1c]0<0Lk@107>c001h]000
N[<007Vc000207Zb000W07^a001k/@40OK0207j`0`1o/@40Ok40082a0023/P00Pk4008Bc0@23]@00
Q[L108Fe0@22]080OKD307jd1@20]@80P[<008N^0026[`00QZl108Bb0P25]0@0OkH407Nj1P1c^PL0
LL070770201]`0`0JL0H06;07P1W^aX0J;TI06Jf7@1S/b40H[DO06Jf7@1W]aP0IKPG0080IKLH02L0
I[LH06^g6@1b^AH0M/0D07Vl501l_140PK/=08Bl2P27]`/0R[L=08Nh2`2:`0X0R[T<096h3`2D]0h0
V[4<09ba3P2I]@`0UKL>09Re3P2K]0d0X[0?0:2_3`2N/0l0W[8?09^d4@2G/A<0VZlH0::`502S[Q<0
Z:`E0:NZ4P2VYQ00YJ`A0:>[4@2UZa00YjL?0:VY3`2Y[0h00P2U[@h09`2P/0d0X;4?09jb3`2N/100
Y:lD0:Z/602/YA/0ZZLH0:^Z502ZZaD0Y:PA0:NR4P2WYAH0[:/B0:BZ402U[0l0Y;0?0:N_402YZ`h0
Yjl=0:B^3@2YZPl0ZjL?0:ZV3P2[ZQ80ZZlI0:V[4`2X[1<0XJTF09fa4P2B]Q40U;HB092e502<]Q<0
R[DD092e602@]1@0TK<E096e500209:d5@0W09Bc5P2K]A@0UkHC09Bi4`2A^aD0S;/L08Ji7@1o`AT0
O<8G07S7501gb1D0N<dC07W;4@1hc0h0L/T=07773@1daa<0M<HI07386@1/bAd0K<LO06W38P1a`b<0
Ml<S08309`21_B`0OK/e07jm>@1k`CH0Nl0`07c4<P1j`3L0LkPg07K6;P1hc2D0NldV07k=9@21cR@0
Q<`M0080PLdF02L0Pl`?08G9302;b@T0Q/T808K:2@26b0d0QLTB08775@20bAL0OLPP07K79@1aab/0
Kl4g06S3<P1ZaR`0L/PN07S7401haQ@0MlPQ06o6=P1[_dP0K;E@06b[DP1a[U40L:U@076WE01kVED0
RhmE09:5F`2GQEl0U8IS08ZKD@1m^BP0R[PH09F_6P2H/b80U[H^092m:`2>`2D00P2;`2809`2>_B`0
SKd/08Zl<028`2@0R<DM08Jo4P28_A00QkT=08Jj3P26^140T;DD09:h5@2D`1D0Tl0B09;54`2B`Q/0
T<4T08fo:P26`BL0Rl@R08[:8`28c2@0Q<X^08K5<P24bBT0QLDU08;0:P22`S80PLXZ07c48`1j_al0
N;HR07Z_8@1o[AL0OZ`F07Z[701gZA@0LZ`A072b4@0206Jl5@0P05k<7`1EdbH0Dm4P05;?701<bA`0
ClHL04g27`19`2D0Bl<_04g2901<`Qd0D/8V05Fi801J[a00HJ4?06ZB2`1]P0@0K7@106Yb001TJ`00
HV8005mL001QEP00HE<005aB001JD000ETl005E:001AAP00BSh004Pm0016>P02048g000503`a000g
:000=2P0038[000b:0000P0[8P001`0T6P007AD001D=000?2P0020D000<100010000=@00000<0?oo
o`002P3oool0501dTP00LXh007BA001aS`00LX`007B=001eS@00Mhh007R?001gS@40N98107VC0@1h
V@H0MYT107NH101gW0L0LYd907>R3`1cY140Lil@0P1aX1409`1_WPl0KY/<06jJ2`1`W0/0LJ0:07BO
2@1bW@D0MY`507NM1P1fW0@0Mih107JM0`1bW@<0LYl7072O201eX0H0Mid107^R001nYP40OZH407^Z
1@1hZ`<0Mj`107J/101e[`L0LZh7076_1`1e/P@0MK8707>c101c]@D0LKD707:d1P1d/`<0M[8107Vc
001k/`00O[8007jd000207Za000A07j`0022/040Pk0208:a0`22/@40PK8008:`0023/000Pk4008:c
0@23]000Q[D008Jd0@24]P40P;D208Fd0P2:/`400P2:[`005027/000Q[4008Ja1`24]`L0O[L607Vg
1P1b^PH0L[T7072j201^_0`0JK`?06Vl501/^Q80L;PA07704P1b_180M;`C07Rm4@1i`0h0Ml0?0P1f
`1009`1a`100L/0A07Vn3`20_Ph0Pl0;08?02@24^PT0Q;X808Bf2027]`P0R;L908Ze2P2>]`/0T;T:
09Jf2P2K/`/0W[@=09nd402J]180Vk<D09^c4@2P[`l0YJh?0::a3P2Q/`d0X;@>0:2a3`2V/100XK4B
0::`4P2U/1L0XZ/B09n[5@2O[1H0WjhC09f_4@2NZa00X:`A0:B_3@0209f^300W09n`3`2P]@h0Wk@>
0::a3`2V/Q00YjlA0:NY3P2RZ`h0ZZX>0:^Y3`2YY@h0XiX=0:NT5@2ZYQX0YZ<C0:BV4P2YZQ<0YjXD
0:NX502V[a40WZl>09nV4@2/YP/0[j<;0:NS3`2ZYa<0Zj/@0:JY302XZ0h0YZd?0:2f3`2O^Ph0U[P=
08Vg3@29^@h0TkH=09Bc302E/`d0S[L@0080S;PA00T0T;<@09:e4@2@]Q80SK/B08^j5P27`1`0QkdM
07bo6P1m_Qd00P1jaQL0701iaAD0N/LB07G<401`c180LLTC07395@1aaQ`0L<LN06g;8P1_ab40LLDS
07[08P21_bD0P[/Y07jk;@20`C@0O<@_07[69P1laRH0NlT^07k2;`1j^cH0O<8a07S9;@1kbRd0O/``
083=;P24d2X208C<8@0W08?;6P25b180R<X=08W92@2<b@X0SLT<08_84@27a1H0P/LI0835801haB<0
LlD[06nn>@1YaST0JLD`06g;7P1bbQ80MlPE07C=8@1_bC@0KKi806ZaD@1[YEH0KZAG072TFP1cXeT0
N9]H07nBF@1oRU/0OHMQ07b8H01jWE80O[`^08jo7P2O]2@0V[XY09No;@2D`2T0SKTX0080S;@Y02L0
T;@_08Vh;`28^RP0Ql0N08[05@2<_Q00S;`A08Nl4@26_1<0R;<H08nd602D]QL0T<0E08nl502C`A@0
T<@I08o58P28`R/0R;h[08Zl:02;a2H0QlXX08G<<025ac40P/TU08G59024`2/0QK/c0837<P1gb380
M/8U07Rh8P1i/R80NJhF07R^5P1hZQh0MZ<E072R4@1/Y`l00P1Z]1H0801T`ah0HlXR0636701G`Qd0
D<HQ04k07P1@_a/0CkdI04bo901;`2@0Ck`S05Bm9P1L/aT0Hih506^;0P1[O040KFl006UY001/K000
Jf/006MW001QG@00GUL005iC001HDP00FT`005M=001GB@00DdL004Xm0015>000@cL00P11>@001@0j
<@00<RH0034V000^:@00;B<00080:1h000H08aP001P@000C20003@H000H400020@0f000000`0oooo
000:0?ooo`0D07>A001eS`00LY@007:D001`T`00M9@007B@001cS`00MX`007N;0@1gT`80N98107VA
0P1gU0H0M9L807>O301aX@h0KJ<>072T3P1`X@l206fP4P0W06nM4P1aV0h0L9L<07FG2P1fV@P0MYL5
07JI1@1eV0H0MYX507NI101gVP@0MYd307FL0`1fW0H0Lid707>M1@1hX@00OIl0086T001oX`40OJP2
07^V0@1iZ080Mj`507:_1`1^/@L0L;4607>a101f/@L0MK8507F`1`1e/PP0MK4707Ra0P1j[`00OZh0
086_0024/@00Q;000080P[400280Pk8008Fb0024/@40Q;8108B`0@27/@00R[8008^a0029/@40R;41
08Fb0024/`00Q;@008Fd0025/P40Qk8108Rc0@26/`00R;8008>b0022/@40QK@708Bg1P1n^@H0O;T6
07Rf1P1f]PL0L[X706nl2@1b_0`0KkT<06jj2`1b^P`0N<0=0P1j`0d00`1k`0d0O<0<07c0300207_0
3P0W07c03@1m`0d0O[h;082i2@23^@P0P/0808Jn2@2:^@P0Q[P708Bd1`25^0T0R[L:08fg3P2B]``0
UKH;09fd2`2Q]`/0Wl0=0:2f3`2N/`d0V[4?09^a3P2L/0l0Vk<A09j`5@2Q/AD0Wk4B0:F_5`2S[Q<0
X[0B0:6b502Q/Q00X:h>0:2_3P2O/`h0WK8>09b`302H/``0V[<=0080U;<>02L0U;@A09Za5P2Q/1P0
YjhF0:Ba4@2M[Q40WZ`?09^`302T/0d0YZ`@0:JX2`2YYP/0Z:@@0:^S4`2YYQ40YZH@0:^V3P2[Z@d0
Xj`>0:B[302R[Pd0Y:/A0:N]3@2Y[0d0Y:L@0:VS4P2TZ@l0WJ/>09JX5P2P[1L0Wk8E0:6d4P2B]0l0
R[DC08fe502H/aH0SKDA08^f4`2=_1800P2=^Ph09`2;^`d0S;P?08Zj4`26_QD0Pl4K08726P22`A`0
OL0N07^j801k_1/0NL0J07_16P1maaH0NlXF07G=4`1cd180L/TI07387P1abR40L<XU07;67P1ga1`0
OL<N07o39@1k_bX0MlD/07_:;01mbal0OlXE07o9701kabD0NL@X07S0;`1iaBh0NL/^07_=:P1ncB/0
PLhX08;>:`02087::@0W08;;9022bad0QL/B08S82`2<bPT0TLX:08k73@2:`a@0Q<HF08367P1iab40
NL0/07Bn?P1ba3l0Kl<i07;;:P1abah0L<XL06g<9@1ZbS<0K;e606^bD`1ZXEP0KIeM06jQG@1cWUX0
M9UJ07NEF@1cT5T0KX]L072;G01eXTX0O[/a09>l9`2V]BL0Wkl[09_3;02J^bP0TJl^0080SZP_02L0
SjXb08Za;`25]2L0QK/P08Vl6`2;]aD0R;XF08Zm5`2;_1L0Qk<I08fa6@2B]aP0SkhE09:m5@2A`aP0
S/LK08g67P2;aBD0R[d_08Ne<@27]S<0Q<4c08C7;`25b2d0P/DU08739`1n`Bh0PKTc07c2=01dbcL0
LLH]06nn9@1d^RP0L[DI07B`5P1_Zah0K:DF06VR4P1XZA800P1T[Qd09`1T/R00J[<H06V^4@1M/AH0
D[PK056j7`1F^Q/0E[/H05:l7@1A^b00DKLQ05>g8@1L[140IiD306^2001/L@00K6`006MX001ZIP00
JfP006UZ001RHP00GUL005UB001GBP00EDX005=9001EB000DTL004/n0016=`00A3D0040f0014>000
>C00038X000^8@00:R0002DI0002028E000601lD000D3@003`P000d400040P000P00=P00000<0?oo
o`002P3oool0501dR`00Li00076@001aTP00LY<007>C001cT000LhT007B;001dS040M8l107:=0@1b
S0H0LY8;07:F3`1`W`l0JZ4>06bS3P1^X0/0Jih<0P1YU`h09`1[U0h0KYP=072F2`1fU@P0N90407FB
0P1bT`L0MID807>F201cV0X0L9/<072L2`1^X@/0L:@:06fT2@1^Y@D0LZL107FV0P1fZ0<0NJT407RW
1@1hY`@0NJD207B[1@1a[@H0Kk4607:]101f[`<0Mjd607Fa1`1d[`L0M;0707V]1@1k[P40OJh0086]
0022[P00QJl008Fa000308Fb000G08Fa0026/@00Q;8008R]002:[@00Sk40092b002=[`40RZl108Za
0028/`00Qk<008Vc0027/@40R;@108Ve0026]P40Q[@108>c0P22/`@0PK<708>d1`20]PH00P1o`0L0
3@1l]@P0N;L707O0201g]`L0N;`807Vl201j`0X0Okl908?02P1o_0/0N/0=07[03P1k`0`00P20^P/0
5@21`0P0PkL808>h2024^0P0P[P708:j1`25^@P0R[P808Zf1`27^@P0Q;T908Fh2P2:]PX0T;L;09>g
2P2H/``0V[P@09nc4@2P/@`0Wk8>09fa400209fd3`0@09Za402P]140W;8B09Jd402G]Q40V;DD09Rb
4@2K/Q<0VjdK09n_4@2S/140Xk4I09fa3P2H/0h0U;@?09Jc3P80VKD<02L0TkHA09V`5P2L[aH0Vk8D
09Zf5P2G/A40U;0>09J`402G/180UjhC09N_402F[1<0W:PC0:FT4P2ZYAD0XjDA0:ZT4P2YYAH0YJLA
0:>Z2`2S[@/0Z:`B0:Z/4@2[[0h0Yj/=0:jZ3P2ZZ@h0XJX=09nW3P2L[a00W[DB0:>a4@2G/P`0U;@?
096h402>^1<0QkLC08Nf4P2<]A<00P2>^0l09`24_180Qk/G08Vj8P28_B<0P[/T07nl8@24^B80PKhR
07Zn7`1h`1T0OL<E07c65P1kbAL0Ml/J07C<5@1abaL0KlhM07;;7`1hcA/0O</I07c9701iaQh0NlLO
07[68`1jaBL0N/DU07g<901nc1L0OlXC07k:5@1lbah0N//L07O=9`1jc2`0OLd[083<:01kbBL0N/`Z
07c<:@0207g=:P0W07o<:@22bR@0P</P08795P2:b0d0S/P908g62`2:aQ<0R<LF08;07@1n`200O<0W
07O0=`1c_ch0LL110778=`1cbBH0LLTQ06_<901Yac00Jkm506f/D`1^WUX0KYiL072PFP1`XUH0M9]J
07NIFP1bTeX0LHiM06ZDF@1_YDL0PKd[09K0902P`2T0W/4[09Zm;02B]b`0SjTb0080SJLb02L0TJT_
08^`:`23/RX0Q;P/08Vi:@2:]2<0Q[<L08Ng6P27]aL0RkPH08Vg5P2@]a<0U;XC09K25@2CaQT0T/PK
08k96`2:bB00QlP^08G0>@26]3d0Q;I008>m>022`Bd0PLDR07k28P1i_Bd0N;Te07O2=`1fb3T0LL@[
07309P1a_2@0MKPJ06fa5`1Z[AT0Ij<D06>T501TZQP00P1QZad09`1YXQ@0L9P;07:D1`1WVP`0Gil@
05^W6@1K[QX0FjlE05Vb4`1F]1H0EK0E05N`5P1QX`/0I8`206Yj001XK@00IVL006EW001WI@00J6<0
06UP001UH`00Hf0005YB001DB@00CT8004m5001A@@00D4<004To0018>`00@CP004@f0010>P00?Bl0
03@Y000]8@008aX001lG000201hC000501TA000C3P003@X000L300030@00=`00000<0?ooo`002P3o
ool0501bS@00M8d007F9001fRP00Mh`007N;001gRP00LXP006j;0P1/R@80L8@106n8001bR@H0Khd;
06jD3@1`V100KiT>06jI301aVPT0KYL70P1]TPP09`1^S`H0K9L706jE1P1bSP@0M8`307>?1@1`T`T0
LIP:072H2P1^V`d0J9dD06VN501YXA40JZ8A06bT301_YPH0L:P306nY1P1aZPP0L:/:072/2@1eZ@H0
MjT407:Z1@1^[PD0KZh307:Z0`1f[0D0Mjl807>`201d/@H0M[0307Z^0@1m[040Ojh1082]0@20[P00
Ojd008:a000208:c000W086d0@21/`00Q;4008F`0@2:[`40S:d008n`002@[`00Sjl108j`0@2</000
S;8008ja0P2=/080R[8208Vc0@26]040Q;@208>c0@22/@40O[45082c1P1o/`@0Pk@6082d1`23]`L0
PKD707jk1`1l^PP0OKX707jj1`20^0T0OkX9086i2024^PP0O<0707[0201k`0T0P;T80080P[D602L0
P[<708Bc2026]@L0QKL708>f1`26^0L0QkP6092e202?/`D0T[P;09:g3@2A^0/0U;L<09Be2P2G]@/0
UK@=09Rb3@2K/`h0V[4=09Z_3P2N/100Vk8E09jb5@2O/1@0Xj`F0:6^4`2L/`h0W[L>09nd402J]100
WK4B0:2_5P2RZa80XZlB0::b602L/1@0U[4D09Ja4P2D]A800P2E]@l09`2I]Q80V;DC09Fa602G/1P0
Wk@G09je5@2H/1<0UJhB09R]502I[QL0V[0E09Z`502J[Q<0XjdA0:>_3P2SZ@l0YJT>0:F/402YZPl0
ZJ`>0:FZ3`2XY100Zj/A0:Ra3P2R[`l0ZJDG0;>S5`2TY180Xj8C0::Z5P2S/A40Wk8=09Rf402D^QT0
TKlF08bn4@25_A00R[X@08^h3P0209Fg3@0W09>f3`2?^a@0S[dI08Zi8@24^2D0P[XU086m8`1n`280
Nl4M07c06`1na1P0O//H07_=5@1ec1H0L<hF07?>5`1hcaH0N/lD08?>5026cQ@0Pl/G083:6022bAL0
PLXC08G85@25bQ<0Q/TH083:4`1kbQ40OLXD07S=5P1fbR40MLP`07O8=01jbC@0O<T/07S7;@1ebRh0
MlX]0080N/`^02L0OLd_083;;`1nbb`0PL/U08G<5@28bPd0S<P:08k73P2:aa00Q<0K07o1801n`BD0
Ml@[07Fm=01_^T80KlHk06o;;01]bR@0J</V06O5<@1Z]dP0KZUA072ND@1^XEH0L:=C07BPD01cUeP0
MiAJ07B>GP1iRV@0KY5R06jTB`23^RT0TL0U09[0:P2H_2`0U;X_08fa<02<YCL00P2=XcP09`2=Zbd0
RJh^08J_<@29/S<0S:d^08fX;@28YbD0QZ/M08^f4`2<]a<0RkPC08fn5@2C`1H0ULDH09;56P2Bb1`0
SL`M08c;8028bC00PL=3086aA026ZdP0P[Pn08?3:`1oa1`0O<<K07Zn:01h_C@0L[`i07:o=@1c_BD0
K[LO06bd6P1_]aX0L;<G06^]5P1XYa<0HZTE062[600206BW6P0W06nG401cP`40KgX006eo0P1XQP@0
HH`:05bA4@1LUQ80G:8E05^V5`1KY1L0GZ<@06RE2@1ZPP80JW<006MS001UGP00IF00065O001TG@00
He`0065M001PG@00G5D00599001<@000Bcl004Y0001;@@00BT8004Tn0013>@00?cX0044h000l<P00
=bT002hT000U700081T000806a@000D06A@001@?000>2P001`800081000g000000`0oooo000:0?oo
o`0D06b4001^P`00L80007B1001dOP00Lg`007>0001_Q000JhT406Z:0`1/P@40KX8006j21P1/SP/0
Ki<<06fE2`1ZV0T0KI<706nF1`1/U@H206fA1@0W06jA1@1/TP@0Ji4306^>0`1YSPD0KIH:06jJ2`1^
W`/0Jil:06FP3`1UWQ@0IZ4F06JR4`1XY140KJD<072U1`1aYP@0LZP6072Y201^ZPP0Kj`907>Z2@1a
Z@H0L:`407:/101cZPH0MJT507JZ1`1g[0P0M:d807>_1@1h[P40Njd107f_0P1o/0<0Nk4207b`001m
/@00P;800080O;<002<0Ok0207jb0022/P00Q;8008Z`002?/@00S;4008n_002BZ`00U:/009>^002B
/040T[4308nb1029/P80R;4108Rb0P2:/P80Q[40086a0@1m]@<0O;D308:c0`23]0@0QK@708Bg1`24
]P@0Q;P808:l1@1o]`H0OkL807ji2P1o^PT0PKP707bi1P0207_01P0A07ji1P23]0H0PkD708>e1`26
/PH0Qk<508Ne1P27]0H0RK@708^d1`2>]`L0UK@:09Be2P2D`0X0UL0=09Ne3@2H]a400P2I/a40602K
/A80W[8@0:2`402O/@l0Wk4=09j]3`2M[a<0X;8A09na402P[a80Y:dA0:6`3P2Q/Q80Y;4C0:6a3P2Q
/1<0Y:dF0:J]4P2S/180XK0E09b_502J/1<0UkDD09Fc5P80UkDD02L0UkH>09Fh3`2F]QH0VK<C09Vg
5@2L]1H0WK4E09:`5P2DZQT0UjTM09ZZ8@2H[1l0V:TP0::/702UZQX0X:TD0:FW5@2X[AL0ZZhD0:^/
502V[A<0[:TB0:b_4P2//@l0ZZl;0:^]3@2`ZPl0ZZ@?0:fT3`2T[a00W;@@09Bh4@2A^AH0SKXL08Zn
6@2=_Q@0Q;/A08:j502:]Q<00P2?]A<09`2>]a/0SKTG092i4P2;^QX0PkTS07c0801haQh0M/XM07W:
6P1kb1H0Ml/C07S<501jd1D0M]0E07O?6P1hcAl0O]0E08G?4P26cA<0Pl/C08C<6024c1T0QlXC08K9
3`26bPl0R</@08W:4@25c100Ol`>07c<4`1gcaL0NLdM07W:9`1hbR/0N</[07W;901gbRD0N<X[07S9
<00207S9<@0G07_8<`1obc@0OL`_07o::01mbR@0QLXG08O63@27b0`0Q/T>08G26025a1`0Q<DS07_9
901j_Bl0LKU50775@@1^bc<0J/T[06S=;P1X`cL0Jk=<07:TD01jWU<00P1gXTl03P1hVE40NY5F07V<
F`1jR6D0MhQ]06bJIP1`/4P0Q[/X096k:P2B_C00S;h`092a<02AYS80SY`l0P2<XSX09`2?/SD0RZ`g
08RU>`2<Xc`0T:4k09BH=P2;VbT0RJHM08nb402=^`l0Rk`A08k4602@b1d0SlPL08o57P2>b1l0S<TP
08c88P26aC40Pkhn08F/A@27Y4P0QZa008>m:P27`1/0P<8D07c06@1h^b`0LkH^07:e9P1`/A`0J;4H
06B`5@1X]1/0Jk<L06R]5`1U[1D0Hj`F06JY5P0206:T600W07B@3P1`M`40KFh006a]001YL@00I742
05ic1@1MN@L0Gh4;06N72`1ZPPX0KWl6071f0`1^K`40K6P006AP001QF`00Ge/006=K001QF@00GU<0
05YF001KEP00G5L005I>001<A000Bcd004Ll0019?000Acd004Hl0014>`00?c/003`i000l=000=B/0
02lP000U5`0071<000806A8000D05Ph0018;000;1P001P800040000g000000`0oooo000:0?ooo`0D
06Ma001XMP00JgP006il001_N`00K7d006ao001^P`00K8@106V90P1XPP80IhD206F10`1ZRPP0JYH:
06ZG201WW0L0IY/706>E201TU0X206JB2@0W06NC2@1VUPX0IYL:06JG201XU@T0JY/:06ZP301_XP`0
Kil:06fN3`1`W180Ki`B076O4@1`X`h0L:D907>S101dX`80N:T107F]101a[PL0L:`9076Z2@1dZ0P0
LZd307>/0`1b[@L0Ljh6072[1P1e[@L0N:/507V[0P1mZ`00OJd1082_0@1o/P80O;4107ba0021/000
Q;400080Pk0002L0Q;01086b0022/@00QK0008^`002:/@40R[<208^^0P2CZ`40UJ`009>_002C/@00
TK4208na0P29/P80RkD108^a0@2=/040RK4008>b001m]`80OKD1082d0@23/`40QK8508Nc1P28/`@0
R[@408Vf0`23^0H0O[D807Zh2`1k_0X0Mk`807Nj1P1k^@H0Ok@508Fd1P2:/@H00P29/PH09`2=]0@0
RkH708Zg1P2<]@<0S[43092c102E]@T0UKL909fe3`2J]Pl0V;L>09jh402O^100W;H?09Ze3`2L]A<0
WK8@09nd3P2M/Q80VZh?09f_3`2M[a@0Vk4A09j_3P2Q[a40Y;0>0::b3P2R/A00Wk4@09^d402L/@l0
X[8?09ne402Q]100WK4?09ba4@2L/180Uk8F09>a6@0209R_5`0W09^`4@2N/@l0Vk0C09^b5`2T/1L0
Xj`G0:2/6P2Q[Q`0UJ`H09:]6@2KYah0WJHL09RX7P2MZ200Y:LN09nU7@2OZ1`0X:dL0::_6P2SZaP0
WZ/L0:F[702[[AP0ZZdD0:J]4P2X[Q@0[j`B0:B_3P2T]140X[LF09jg5@2M]A00VKL?096m4`2;`1<0
RL0?08Vi3`2;]Q00RKT@0080SkP@02L0R[TD08bk4`2<^A40QK/M082m901ka1l0M/LN07K;701ecAT0
M/`D07;;4@1bc180N/`E07g=601ncQP0PLhJ08S=4`25bQ00PlX>087<3`26cAH0Q/XH08W95`29bA@0
RLLD08W;5028cA80Pld@087=4@1lcQH0N<`K07g<6`1jbb00N/TT07S9:@1fbB@0LLXW0779<P1gb3X0
0P1fb3/09`1ibCP0N/Tc07c<<01kbc80OLX_07_=9@20bQ00R<X;08c83026bQ<0Q/LJ08K67P1nab80
P<0/07Nk@`1c`T<0K/Tk06O==P1WcCT0JKi006jSB@1kWTh0PY]A086JD`22Ue00PYIB08:?E027RUh0
P8AX07V7K@1_Z6<0N[m2096l:02?^2h0Q[X_08Nh<P2=[2l0TJ0a096M>@0208jR>P0W08jZ=P2;[CH0
RjHf09>O>P2HVcT0WiTc08jM:02;Z240TKDF092k502=`A@0Sl<F08o6702=c1l0Rl/M08k;7029bAh0
R<PT08C6;`24_3d0QZ]008NRAP21X4@0Q;8`08>g701o_Q<0OkdC07Vj701c^Ad0L;4K06b^6P1/[aP0
IJlH06Nf9@1W/RH0HJdO06:Y6`1WZQL0JZ0B0080JI<?01d0LHD706mb0@1ZJ@00J68006MT001UH`00
H68005iO001OG040H6<106AQ001QGP00Heh006EP001QGP00Ge`0065I001NE`00GeL0065D001ID000
E4X005E=001ED000Ed`00593001:?@00B3X004Hi0002048i0008044k000n>000>S@003`b000g;P00
;b<002@H000J4@0201D@0004018=000?2@002@H000@103P00000303oool000X0oooo00L0GVX006Ic
001XL@00J78006Ug001WOP00IX400080J88000/0JXL106B40@1RQ`@0IHT106:=1P1SVPT0IY`806:Q
201TXPP0I9d;06BI300206FI2P0W05nG3@1OW100Gi/?066N3@1RW0P0Ij0;06bS301_X@d0L:0=06nM
3P1bW@h0MI/>07VM301eXPX0MZ<607JU0P1gX`40NZT007J]0@1b[PD0LZ`707:/201eZ@H0MJX107B/
0`1dZ`H0L:`606nZ1P1f[0H0NZP207fY001mZP40OJl107f`0P1l/@80O;4107n_0022[P00Q;000080
Pjd002L0PJ`007j`001o/@00Pk4008J`0025[`80Q;4608J^1@2>[P40TK41096a0P2B/P40TK80092b
002?/@00S;8008b`002;/@00RK@008Jd0@24]P@0Pk@208Ja0@25/P40Q;D608Nd1`29]PD0R[<208Jf
0@23^0@0OKH707bf2@1j]`P0NKP607^k1P1l^PH0P[@608Bc0`26]0800P28]0402@2?/`40TK@208fd
0P2A/P40S[0008fc002B]@d0V;D=09bf3P0209jh3`0L09fg3P2Q]Q80WkP@09Ze3`2L/a00Wk4@0:6a
402O[a80Vk0A09V^3P2H/Pl0W;4@09fb3`2N]A40Wk8@09fb402M/`l0W;8?09Nc4@2J/@`0Vk<?09fc
4P2L/0h0WK0A09ja4`2L/A40VK8C09>e5080V;0A02L0V[4A09ba3@2O/@d0W[4F0:F^6`2S[AP0XJdL
0:F]7`2D[QT0TJ`M0:6U8P2PX1/0U:<N09fV802YWb40Z9/Q0:>N802LYb00XjTK0:JY602JZaT0Vk4L
0:2_5`2V[A@0Y:`D0:R]4P2N/Q00VkDA09fa4`2K/a@0V[4C09j`4@2I/Q40U[8G09Ff5P2@]a@0R;DG
08Vb6@2?]@l00P2C]@h09`2C]1X0SK<K08bf7@29^b80RL4R08K48021aQd0O<PK07S76`1gbaL0M/XE
07W:5P1laaP0OLHI07g96@1obQP0Pl`B08?:3`22b`d0Pld?08C;5`25bQX0R<XF08[95029`aL0R/DE
08G95`24baL0P</G07c=5`1ic1P0O//I07_<701fbb80MlXZ07K:;@1`bb`0K//f077:>`0207G8>00W
07K8=`1ecC80N<he07_;>P1hcC<0N/dX087:5P29b@h0S<H<08K74`23aaL0P<HM07_48@20`B/0Mk`n
07Nk@`1c_480LLDl07G0@01h/4@0NYU908>PC024XE80QI]I08RFEP25UEL0PY=F07jBG@1iTV@0M9iT
07JiB@25_S40U;LX08ff<P28]SH0RZhh092U=@2AXCD0U:0l0080TjLm00d0UJPi09:Y>02BZ3D0Wilh
0:^G=@2[U3<0U9TX08ZU9P2:/R00RkXL08g56@2<aaD0R/LH0080S<XN01P0RLLO08[87`25abH0Q/Db
08>k@`28[4L0R:=9082JA@23YC00Pk<P08Bk4`20]@l0N[TB07Bf6@1a^1l0KK8P06Zb8P1W/RH0I;La
062e>@1K/CH0HjLX06RS701aU`h207660`0W075i0@1ZJ`00JfH006MR001SG`00HUl0065M001NF`00
GED005YG001KE@00FU@005QE001KE@00FeL005iH001MF@00FeD005eA001ME000G4`005I<001BC000
DDT00558001@B000BDD004Do0013>P00@SD004<h0011?000?3T003`c000k=000=bl0030U000R6@00
7A@0008050l000@03`d000d900071@000`00>000000<0?ooo`002P3oool0501QL`00HGP0065e001Q
MP00HG`005n0001PPP00Gh@00626001RR000GXP00626001NS`40H946062J2@1PW0T0HZ8>06BT401S
X@l0Hid=0P1PV``09`1LVPd0HI`A06:K4@1WV`d0I9T906jM2P1bW``0LYh>072O3@1_WP`0LI`907NL
201gW@H0N9l707FR101eXP40Mj4007NU001bZ@80MJd407B]1`1dZPH0MJP307F/001hZ`40N:/307JZ
0`1hZPH0NZX707R[0P1iZ`00OJh107j_0`1n/P<0Ok8407na101o[`40P:h0082]0@0207f]0@0W07b^
001l/000N[4007j`001n[`00P;42082a1P20/@D0RK0108j`0P2=/0H0S[8308nb002>/P00SK0008j^
002:[P00S:l008Za0029/`00Rk<508^c0@2<]040R;<308Fc1`29]0P0R[D508Ne0024]`80P[L0082g
1`1o]PL0OkL707ji1P1o^@H0Q[T608Rh1@28]040R;800080Q[<002L0RK@008fe002?^000SkH108^d
0@2=/`40Tk@909Zg402P^@h0X;P>09bh3P2K]`l0WKD?09Zg402G]`h0V[8@09jc3P2O/Pl0VZh@09b/
402M]0h0V[0B09n`4P2O/`h0Vk@B09^c4`2J]A40V;@B09Vc402J/@l0WK@>09fc3@2J/`d0V;4B09^b
5@2I]@h0VK8>09Ja4`2C/a000P2G/a409`2Q/1L0WJl>0::`3P2R/AL0YJlD0:>^402M/AL0Y:hJ09R]
702LZA/0WJDM0:6R7@2NWah0WJ8K0:JO702SVR<0Y9HW0:FP;02TXb80Yj8M09fU8P2OZR@0YjTM0:RZ
5`2XZQ@0WJlC09Nc6`2L]AH0Y:hA09Jb5@2F/Q<0XZhA0:6]402I[a<0VK4D09b`4@2@]1D0SKLF092h
500209>d5P0W08Z`7@29/B80RK<X08nn:02@`BP0RL@W08G38P21`b00Nl@P07g76P1nb1H0Q<@G0875
6P1oaQ`0OLTI07k85P1nba<0O/X>07o;401mcA@0P/dG08G:6P26ba<0R/XD08W26P2:`QX0Q<<J0877
6@1ob1`0Ol/G07g;601nbA`0O<TS07O79`1faS00M/T]07C8;P1bbc40LLXh0080M<Th02L0LLXi07?<
=`1dbcl0N<A307S8>P1ic2h0N/XN08C84028a@/0Q<P=08;84P1laAd0NL@U07g0;P1f`400NKE207ZY
A@23[d00TK4n08fX?@26X480QZI808RSDP28WET0RIaI08JKF`21XEP0NJAJ076/F`1b^D`0O/<b08Zo
:P2C]c80T[8e092Z>@2CWd00X9ln0::R?02OXCd00P2JZCT09`2GZSP0U:Hf09NT<`2TVSD0ZiHg0:^D
=02HWR`0Rj@Z08N_9P29_2<0QlPO08K<8@2:cR@0R=4[08C=;@26c2T0QlP[08C4;`22`3T0OK]908>/
CP22ZTT0PZU2086a<P21]R40PkLD08R]3P1k/Q80Mk<G07>_701]ZR00Jj/K06jW6P1^Yal0Jj<O06NH
7@1VSAL0JhD@07:11002071h000W06a^001VI000IfD006MQ001TF`00HUL005iI001LG000FEL005MB
001ECP00F5<005MB001HE`00Fe@005YH001HE`00FU@005]B001KD@00F5<005MA001CBP00CT@004Y5
001>B000Bd<004Ln0013>P00@3D0048m0014?000?CL003/b000g=000=RP002/R000T6@006aD00080
4``000@02`L000X600060P000@00>000000<0?ooo`002P3oool0501RN`00HX400662001KP@00G8<0
05Z4001JQ`00FhP005b5001KR`00GXT106290@1QS@80GXh705jH2P1JV0/0GYlA062U4`1RXQ40IJ4<
0P1QV@`0601OUP/0IiT;06^H2P1_V0P0L9H7072I201_VPT0LIh:07>P2P1dW@P0MY/307RK001gU`40
MY/207JL101fX080N9l107NR001fY`80MZX407N/1@1f[0@0M:d207N/0080NJd000@0N:h007bZ0`1l
Z`D0NZh20P1i[`001`1i/080OK8407nb101o/`@0OK0107f^0@1g[@400P1g[`403@1f/P40O;4007Va
001j/000OJd0086_0@24[P80RK4208b^002>[@40Rk0308nb0`2?/P000P2@/000102?[`00RJh008N`
002;[`0208f`000B08^d0@2;/P80R;4708Ja1`27/@L0PkD208Bg0024]`40QK@008Jd1026/`D0Qk@5
08Ni1P28^`L0RkP608fg0P2<]@40R;@00P24]0402@27]P80R[D108jf0@2@]0<0SKH208ne102B]`T0
VKT?09jj300309fg3`0K09nf4@2P^140WKP=09jc2`2I]@/0V;@<09fb302O/0l0X:`=09f]2P2K/0`0
WK@=09fa4`2G/100U[@@09Jd4`2G/a40W;0A0:2d3`2L/`d0V;8@09^a4P2K]@h0UKD?09fa4`2R/1<0
V[@C0080W;4H02L0YZTG0:>/4P2U[AH0Xj/I0:JY4P2SXQD0Xj@M0:bT5`2VXQT0XJ8K0:FP802XX1l0
Yj0L09nT702VXal0Y:8N0:ZM8P2XWB<0XJ<S0:FV802UZ280XZdN09^_6P2L[1P0WJhE09R_4`2C]1H0
Vk@D0:Ba5P2F[1P0WjPG0:NY4`2L[AH0VJlK09Bc4P2K[Q/0WjhQ0:2`7P2O/A/00P2K[ah09`2C/240
Sk0W08Z_:P2<]b`0R[ha08W1:P29_bH0Pl0P08317@1oa1d0PL<J08Nn6`2;`1d0Rl0P08S38023`Ah0
Q<8I08;35@22bAD0PL/D08G;5@24cQH0QLd@08O;4@28bA`0QLTJ08;66`1oaaX0NlHJ083:5`1nbaT0
O//L07c7901gaRP0MLP[07O6:@1gb2h0Lld^073><`02073<=P0W06o>=P1`cC`0LLY207VfB01h_d80
MlTk07G7;P1ib1/0P<L=08G72P24bPd0O/XE07S67`1k_B`0O<0f07bf?01k[440Oji008Rb?@28[C/0
PZY008B[@`24YTT0PJM?07nVCP20YE40Nja@07FdD@1b_D40O<D^08[5;02:^380T[0h092S?P2AVd<0
V8m70:RG@02[XCl0Yj0n0080WYhm02L0Vidg09VP=02NVc@0ZYPe0:ZL<P2WWC80VZH]08jX:`2>[b/0
Qk/W08G;8P26cBD0RM0V08W><P24c380QLXf08?:>P1obC/0P<0m07fjAP1m/4P0P;5107nc>@20]2d0
PK@M08NX4P27W@X0PIh807bN301eW@h0MYP?07>C301dS`P0MHh707261@1/N@@0Ifh106=T0@1THP00
0P1VH@009`1PG`00GE<006=H001SG@00HEP005aC001JD000FU8005]C001FD`00EU4005U<001GC`00
EU<005ME001IE@00F4l005M>001JD000F4l005I>001GC000EDX004e40018@@00BD8004Y10019@000
@c/0044f0013>@00?SX003/h000h=000=2h002dU000W80008AX001`B00020109000400L500040`00
0P40004003P00000303oool000X0oooo01@0HWL006Ei001WP000H7h00623001PQ@40GhH105n8001O
Q@00Fh<105n50P1RP`40HXT305b=201MT0/0GIH=05fG3@1QW0`0HiX<06JH3080I9X<02L0JY8;06jD
1@1fT@<0M98307:E1`1cU`P0LI`507>M1P1fW`H0Mi/507NI101mV0@0NiT207NK0`1gW@H0N9l407^P
0@1iX@00N:H107JW101gZ@D0MJT607B/0`1e[@40MZh007N_0@1h[P<0OZ/308:Z0P21[`40OZl007^_
001j/P00O;8107n`0@1o/@40P:l1082]0@1j[0<00P1d[@<09`1h[P40OK0007ba001k/000OJ/008:_
0027[P00RK0008Z`0027/000Qjl008b`0@2<[000T:`0092]002@[P00Sjd008^`002;[`00S;4008^`
0025]000P[8208Be1`21/`@0PK4107nd0023]040Q[@108^c002;/P<0Rk<408ba1`2=]PL0R[L808Zg
1@2?]`80SK@108Re000208:f0`0W08Vf1`2;]0<0RkL208bf1P2A]0<0T[@209>i2P2J^0d0V;/<09^k
3@2M^0d0X;T<09nk302Q^@h0XKP=0:6c2`2I/P`0W:l?09na3@2N[A80VZ`;0:2`202I/Ph0W[<@09^c
3`2H/`d0Uk4?09Rb3`2L]0l0X;0B0:6a3@2M/Pd0W[0D09fc4P2M]@d0Vk4C0:2c502V/@h0W[0G0080
XjlK02L0Z:/G0:RZ6P2]Yb80[J<E0:RP502[VR40YI`H0:NO4P2UWQP0Xj0F0:>T602UXaP0[J0K0:BT
7`2SYAd0Y:@K0:VK7@2YUal0ZIhQ0:jU702ZYa/0XZ/M0:>b7P2R[aX0XjlB09^`4P2F]1X0X;4@0::^
3P2O[0h0VjdA09B]5P2E/Q<0Uk8>09Be5P2>[R00TjdS09V/8`2SY2`00P2LZ2d09`2A/2/0RkDY08Be
:@22_b/0Pl0Z08C29`27`B40Ql8L08;06P21`A`0P/8K08:m6@24`Ah0R/8R08[38P29`ah0Ql4P08?2
7P22aa`0P/`J08?<5@24c180QL`@08K=4023baT0PlTK08S28025`1h0Pk`K08;46P21aQl0PL8L07g1
8`1ia2H0M/LT07W<8P1fbb@0L/dU073?;@0206o?<@0W06g>=01]bD40K<E=072gC@1d^D80MK`l07K3
=`1ea2T0OLLA08;42P27b0X0PL/?07k95@1n`b40O[h^082h=@1i/S`0Nja107f]?`21[Sh0Oj`m08:Y
@P20ZDH0NZa507B_AP1e/D/0M;]807K3?`1ma2`0QL4X08S0<@2:ZcD0Tj<k09BNB02ATdP0UHY709nC
@`2TW3l0Xidk0080Xi/j02L0YiTi0:NG=P2YTcT0/iLj0:jM=P2UWS40WJH_09F[;P2:[b/0R;hV08C;
8`2:cbD0RM0U08SA:`26cBh0PlLc08?8=@1maSH0Ol<e07o0>P21_3P0P;Xe086k;01m]R00OJPC08>H
2027S@40P8P007f:001hQ`00MWl007Ai001fL`00LWD006i^001[J@00HV80061K001IEP000P1NF000
5@1KF000Fdl005QB001LD`00H5L005eC001ICP00Fe0005QB001GD000FE4005Q>001FCP00ET`005I=
001GD000ETd005E?001HD000F4h005I<000205E:000@04i40019?P00BSh004U00018@000A3X0040g
000o=@00?3X003/i000g<`00<BT002TR000T70007aL001PA00803`D000<01@80004100010000>@00
000<0?ooo`002P3oool0501UN`00IgP006Ug001XM`00IW`006J2001VQP40IhP006>5001RO`40Ih@4
06Z00P1VR@@0I8T706>>2P1QU@/0Hi@:06NC1`1/SPH0JX/60P1[S@L09`1[T@L0LHh307:=001eR`80
MI4407:D1@1dVP<0MI`407NN1@1fV`P0MY/;07NN3@1hW@T0MYl707:Q201dX0H0MZ0407JU101fZ@D0
LjX807JY1`1dZ`L0M:d507J_0@1f[P40NJl407Z`1`1o[P@0PZ/008B]001o[`00NZl007Jb001j/P40
Njh107j]0021[000PJ`207b_1@0207R^100W082]0P23[P00PJh0086/0022[000PjX008R[0029[P00
RJd008J`0028[`40RJh108Z]0P2:[040SJl108f_002=[P00Rjl008b_002>[P00Sk4008Nb0023/P40
P[8408:c1@22]0<0PK8208F^0P28ZP40S:l008fb1@2>/PL0Rk<808bd202;^0H0RkP308^h0P2;]`80
R[D30080QKH50100SKD6092f102=]P@0U;H409Je0@2G]000TkP;09Fg302G^@X0UkX<09fj3@2P^@`0
WkH;0:>f3@2S]@d0Wk4<0P2O/Ph01P2I/``0W;8>09ja2`2H]@/0VkD?09fb3`80VKH;00d0WK<>09Vd
402P/a00YZl:0:>_3P2M[A80XjhE09bb402H/0h0XK0A0::a3P2V/A40YZlI0080Xk0G02L0W[0J0:N_
6`2/Za`0YZLD0:>T702[VbD0Wj<I0:>S7`2WWAd0YilD09N^5@2Q[1L0/IlL0:jN7@2TY1d0Wj4O0:RM
7P2/W1d0ZJ0I0:NT6P2WXb00Y:DP09^Y7`2HZal0W:`K09b^7`2OZ1h0YjL@09n[3@2E[Q@0Tk8D08bj
4`2D^A@0Y:lI09Je6P2B]ad0VZdQ0:6W:@2QXb/00P2LZRh09`2C/2d0S;/V08Bk9@21`R<0O/<S0834
9022`2H0RKhS08Nj8025_B00PL0K08317@1n`Al0P<8M08K86@27b1P0QlDG08?36023`A/0P<@I08G8
4P24ba00Q/`?08;?4022baD0PlLI08K07@25`A`0Q<4I0833601n`R40PL8O07[38P1faRL0MLXV07C>
8`1acb80K<hT06g>;@0206k>=P0W06k;@01]aTT0KKmC06faC01b/4H0M;0m07Jl>01g`S<0O<PI08K7
3@28a0T0R<H:08C:401kbAX0NL@T07nl<01m^3P0Nk0k07Z^?`20[d00OZm408:[@`20Zd<0N[=407Je
?`1d_3h0MlHd08;5;@24_Rl0Q;Tg08Zc>P2:Z3P0TZ<g08jRA@2DUdD0Vhm60:NFAP2[VD<0ZI]00080
[9Tj02L0/iPh0;FF?P2aTD40[9Do0:6J>`2MX3<0UjLd09>^<`2@]S00S<8_08O9:P29c2H0Ql`X08S;
:028c2D0R/TY08C8901ma2P0N<DX07c5;`1n^bT0OKLU08:c7023Za@0Q9T>08F=0`24QP00Oh4007^0
001dN000L6d006mZ001/H@00I5d006EP001OG`00HEl005iK001JFP000P1HF`009`1MG`00G5D005E<
001GCP00G5L005iB001ID000FU@005]@001GD@00EE0005E>001BC000DdX005=8001CC000Dd/0059>
001GCP00EDX00555001=@@00D4H004m2001:?`00B3h004Xo0018?P00@S/003dj000j=`00>3D003Lc
000b:`00:BD002DL000P6`006a@001<;000200X30003008100000000000003T00000303oool000X0
oooo01@0IW`006Ag001YM000J7@006Qe001[O`00JH<006V1001XPP00J7`006V11P1ZP0<0J8H706F9
1P1ST@T0I9H:06RD201[S`@0LH/107280080L8X102L0Khh107280@1_Q`00LX/107F?0P1cU0<0M9T4
07BM1P1bWPH0LJ09076P3P1aXQ00LJ4=06nR2P1`Y0X0KJH8076X1`1aY`/0LjL:07:W2@1aZPP0MZX7
07J[101f[040NJ/107ZZ101jZ`L0P:`408:Y0@21Z`00OZh107N^0P1f[@80N:d107R/0@1j[080PJd1
08:/0@20[P800P20[`809`24[040QZT008R[0027[000R:X108RX002;Z`00SZX008n/002<[P00Rjh2
08N^1`24[@L0RZh408f`0P2@/@00TK4008n]002>ZP00SJ`008j_0029[`00QJl008Bb0P23/`H0PkH6
08:e0P24/@80RZl108V`0027/@80Q[@508>e1`26]0P0Qk@508^d0`2;]@<0S;H408Vf200208Ni1P0E
08jg0`2A^0<0TKD409:d0P2D/@00U[<109^f2`2G^@X0U[H<09Ff2`2I]PT0W;H=09^d302M]@T0WK@>
09bc3`2R/0d0XK4<09^b402Q/@/0Xk8:0080WK@=0100X;<<09Vc302K]PX0W;<:09Bc402M/100Y:l:
09Nb4@2K[Q@0X[4?09N^402F[a@0X;8>09Nc3@2R[QT0YK4E0P2L/A@09`2I/1l0XJhF0:V^402N[QT0
XJTM0:^S5P2QYQX0YZ@V0:JP5`2XXQ<0W:hF0::X5`2]WaP0[IlJ0:JN702WV2<0Zi`O0:jO6P2ZXaT0
[YlO0:^O702WXQ/0X9h[09fS:`2OZBd0XJTP0:NW5`2O[a@0V[8E09Fa5`2B]1<0TKX@096e4`2G[aH0
UJlH09B]8@2QY2/0YJ4^0:2T<00209VY<@0W08nb;P2;^2X0Q[hX0873801oa240O/@T08;1:@26_BX0
Pk/W08309@20`B<0OkTS07fi8`1o`200Q<4K08O25P28`aD0Ql0H08Nl6P27_Q`0RL<C08K;4P28c100
P/d@08;:5021aAP0P/@L08375`1nc1H0P<TH07g5801laR40MlLQ07C:801_bb00KLdT06[?9@1WcbP0
Jlh/0080K<hi02L0JLQ:06[0D@1Y]EH0KJ]C06fZC@1b[4T0M;Dk07Bi=@1laR@0PlP?08c01`2:`0P0
Q<T>07g>5@1kbB80N/0Y07^o<@1k^CD0MKTg07Zg?P1j]T40NK5007Na@@1g^Ch0N/0a07c5:`23a2T0
QKh/08Jm<`26/c/0SZ`j08bP=`2=Xc@0QYe109NIA@2_TDP0]IE30;NE@P2bUDD00P2mUcX09`30Tc40
_Y<o0;JDAP2LU480U9lm08b/?029[cd0S;Hm08fm>`2<`SX0R<8h08K7=P25cC40Pl/X08?68`25aQd0
Ql<H08C15020^QD0O[HE07n_4P1nZa40P:@?07nK2P22SP@0PH<107n0001kO@00NGL007=`001`J000
K64006MI001PE`00GE@005YC001PF@00GUX005]L000205mM0008065P001RFP00FDh005Q=001LE000
F5<005aD001ID00205I@000M05E?001BC000EDT005A;001BB000DTH004e7001BB000DTT004m3001A
@000BSl004]5001>A@00Cd<004Y20018?P00A3h0044n000n>@00>C<003Pb000c;P00;bL002PO000S
60006aP001HA000<2@000P060P000`01000000000000000i000000`0oooo000:0?ooo`0D069g001T
MP00IG@006Qh001WO000JX8006Um001ZN`00JG/006Qi001XP`D0Igl406N3201TSPL0IY0606FF1P1Y
UPH0Ji8606nA101`S`@207>>0`0W076?0P1]S@40KX`006j>0@1^U080JiT606jO1`1^X0L0J:4606RR
201/X0X0KYd;06nO2P1]X@P0KJH906bW2@1_ZP`0L:T?076W301bYPX0M:D807JY201fZ@T0MZh607RY
0P1iZ@<0NjT4082X0`20ZP80PJ/007b/0P1f[0@0MZh507J/101gZ@@0NJP3082Z0P23ZP00QZT00080
Qj/002L0RZX008bZ0029Z000RJT008bY0@2;Z`00SZX108b[0@2>[@00Rjh008b^0P29[0L0RJX708^]
102@[P80SZl008n]002=[P00SZd008j`002?/@00Qk8008Jd0025]@40Q[L208Fg0`24^080P[T608Zh
2028]@H0QK@5086d1020]@@0P;H308Bh0P28]040RKL208Rf0P29]`D00P28^0@09`2=^@80SkX308ni
102?^0<0TK<309Jd1@2I]P`0U[D=09Rc3`2I/`T0Uk<909Bc3P2H]@P0W;P809Rf3@2O/Q40Xk480:Ba
3@2S[a40Y:l<09^c302K/@d0XK0<09nb2P2I/a80X;D;09^d2P2C/140WJl?09jc302B/Q80V[8B0:6c
2P2J/A80Uk<E09Vh2P2G]P`0Vk4D09Fe400209Jf4`0W09V^802J/A80W[8B09n/7`2TYQH0Z:L=0:BS
7`2SWR@0YJ@E0:ZY502YYB00Yj8K0:FU602XXAP0ZIhJ0:bK7@2UWAH0YIhN0:ZN802YWa`0YZDJ0:>O
802HVRT0Vil]09nX;@2QYR<0WjHQ09n^8`2Q[a`0Wk4C09Jd5P2J]A`0TkHD0::_402P/1T0XJdP09bT
;@2HZ340Rk0c0080RKH`02L0QK``08C0<022`RT0P<0Q07o18@22`bD0PL4V07k39P1hab@0N/PT07c5
801n`B80PklV08:o8`24aA`0PlHK08[55`29aAH0QlDF08K35`27aAH0R/PA08[64@23aA00Pl<C07o5
5`22`ah0O/LN07o:7@1obad0O/HT07[78@1fbAh0L/dJ06k;7P1]cBD0K<dX06W=:@1Zc2`00P1[cCd0
9`1Yb4d0JKUD06b`F01_[E@0L:UA07:YB01`/3h0M;<j07[5902:aQ40T[h808nl0`2:``X0P<dC07_:
701m_bP0O/0/07Zm<P1g_C80Nkde07Vn=`1g`3L0Ml0c07k1<022`b@0Pk`[08Fl;`23_3<0PkTe08^c
=`2BZ3H0TZ@i08fX?02<W480W9U30:bDA`2cU480[YQ30:VGAP020:bF@P0W0:bH>@2UVd40Vj=409BX
?P2:[cX0RkLh08Zf>@29]d00S;Y008bk?@28`CX0Pl<h0838=01n`bl0P<4N08>k5`28]Ph0R;4608VZ
1P25X@<0QIh308BG0P22U@<0PH/107b5001nOP00P7/007Yk001dM`00KVl006eY001YG`00HEH005mB
001HCP00ED/005M>001ME000H5P00080H5`002L0He/006=I001OE000Fe4005aC001IDP00Ee0005=@
001GD000FU4005E@001CBP00DD/005A=001ABP00CT8004m4001AA@00CDP004e4001:@@00Bd0004U0
001>A@00DTP004i80019@@00@Sl003hi000m=`00>S8003@]000_9P00:R8002<P000Q60006Q4001<>
000;20000P060@0l000000`0oooo000:0?ooo`0D065`001MM@00GGL0061m001VP000JGh006]m001Y
NP00J7d006Qn001ZOP00JHL606N<1`1VTPL0J98706VD1`1VV`T0JI/806ZL201^VPT206jH2@0W06^H
1@1ZT`<0JID406FG1@1QV@H0H9d;06>P4@1VX`h0IZ<706RS1`1]XPH0Kj8406fS101YY@<0JZH606bU
2@1_Y`X0LZ@=07BO2@1gX@H0LZ8807:U2`1dZ@l0MZd907NY101fZ0<0NJP307ZV1P1oYP<0OZH307bX
0`1fZ`D0MZ`607RZ101lZ@<0O:@1086V0@24Y`00QjX00080Q:d00P28Z`009@28ZP00RjT008fZ002;
Z@40RJ/208RZ0P28[P40Qjl008R`0@25[P80RJ/208Z[0@2:[000R:`008R^0029[`00RZl008ba002<
/P40QkL208Fi0P26]`40RkH308Vf1@29]`D0Q[L708^g202:]0P0Pk<707ne1@1o]`80PKP108:g0@27
^080Q[L408Fh1029^0@00P28]`<09`2:^080R[H408Zg2027]`P0SK<8092c2P2A]@X0U[D>09Zi2P2F
^0X0T[D908^f202A]`L0T;P809Bf302N]0/0W[D:0:>e302S/`l0X;8;09Re2P2H]Q00WKH:09Vf2@2O
/1<0XK4;09fb2`2I]1D0V[<<09Jg3@2@/a<0Uk8=09be2P2J/a40U;P=092m2P2A_0`0U[LC09:h3P02
09Ff4`0W09fY7@2H/Q<0X;8J0:JW6@2RY140X:XG0:2R802SWAL0WJPB0::_5P2XXRD0WJPD09f/402S
X1P0YZ4I0:RR502NYAD0Z9XW0:VM702WXa@0Xj<Q0:NP902VV200XYhR09jV:02KYAX0WjPH09N_7P2C
/Qh0U[@H096d6P2J]1h0UKHL09f]8P2L[b40VJlS09JZ;@2>[S00Q[Da0080Q;TZ02L0P[lW08;0:023
_BP0P[/U08Bl9`22aBX0OlH[07_38`1j`R40Nl<Q07c68022aQl0QLDQ08G28@25a1l0Q/LK08S86`23
bAT0Q/XG08K:6P29bAT0QlDH08?05`1o`1L0P<8G07o65`21`R00Ol@S07o78`1naR80N/DT07S6801a
aal0K/XP06k9901/bBL0KLX^06_;;01Yac000P1Xbch09`1XbD/0JkUA06b[F01`Z5<0LZI>07:[BP1`
/480KkHh07S39027`Q<0T;X7096l002?`@X0Rl`<083<5`1l`2D0PL8Y08;1;`1o`Bd0Ol@[07[9:01i
b2D0P<HV08;39P1o_R/0OK/`07jk<`1o]cD0QJhe08fY<@2@YC80Tj@n092XAP2JU4L0WIM40:FBAP2a
Td/0[9E709jFC00209bAB`0W09NDB@2<W4H0S:]408Zc@`2=]Sd0TKPk08ne>`2?[T40RZY408B^?`22
]S@0P<4]086l8P22]al0Pk0E08JX3P29Y0H0Rj<008fP0025W000QYD008J@0023R@00OhD007]l001k
NP00NWP007Qj001eN@00LG8006]Z001WH`00H5@005M@001ECP00EDd00598001FC000GE<00080FeD0
00L0G5H005iC001NF`00GeL005]E001KD000ET/00080Edl000l0Edh005MB001GCP00DTT005=:001@
@`00CD0004dn001<@@00BD0004Y1001=A`00CD4004Y2001:@0000P1=AP003@19@000@cP003db000k
<@00<bd0038X000[8P009Ad0020J000M5P005@h000`9000910000P03000l000000`0oooo000:0?oo
o`0D05ma001OM`00HGT006=m001UOP00IWd006Yn001]O@00KH8006f4001[Q@00JX/606VA1`1WV@L0
IY/906NN2@1ZX0/0JYl906^O201XX0T206NN2P0V06BL2@1TU`T0I9P805bM1`1KW0P0HYd:06BJ3@1/
V`X0KY`806nN1@1]X080LJ4007>R001bX`00LZ<207:U1@1bY@H0M:<807BQ1@1eX@@0LZ0507>T1`1e
Z@`0MJ/707RY0`1eY`80MJL607FW201jZ@P0O:H607bV1@1iZ0D0NJL407jV0P1nZ080OjH008:W0@24
Z00308FZ000E08>[0@27Z`00QjX008^T002;Y@00RjT108F[0P27ZP80Q:d108>_0025/000Q:l008:]
0025[@40Pj`107n^0@21/@80Pk8108Ra002:]000R;H20080Q;P400@0R[L208bf0`2<]PH0S[@60P2>
]@P02P2</`L0QK@3086f0`22]P80Q[L108Ff0P25]`H0P[@708Jg2029^0P208^e0`0W08Vd0`28/PH0
Qk<708Rd1P2?]0H0T;@:09Fe302K]@`0V;L:09Bf302B]@/0TK<709>c202>/`h0Uk8909je2P2L^0X0
X;@=09ff2`2I`0X0T[P<092h302<^PP0TKP;09^c3`2M/P/0Vk8<0:2a602J]0h0TkPA09^d5@2N/0/0
W;T;09bf3@2C]P/0Rl0<096j3`2I/a80SK/@0080Tk/B02L0XZ/I0:2_502T[aP0ZZDG0:6W4@2NZaP0
XjHE0:NR3@2H[A00XK@H0:ZS9P2TZ1@0YJL>0:NU6P2XY1X0YZD?09fU4`2VWRT0XJ4F0:BQ5@2WVbL0
[9/T0:JM8@2SWRH0Y:DW09FW602RYal0Wj`X09Z]902K[1d0VjlM0:2`802P/1h0WJlP09F]9`2?/2/0
Qk8b08Fg<01i_2`00P1m`B@09`20aB@0P/0X08:j:P25^B/0Q[L_0834<@1o`b`0OL0Z07Jj:01g^2T0
N/8V08388`23bah0QL/L087<6020bQP0PlXH08?87027bQ/0R<`L08S86025aQD0Ql0C08C13`21bPh0
Ol/H07k:8P1nbRD0O<@T07K69P1c`RP0M<@W06o79@1_b2@0LLHW0736:`1/aC80K/<e06S4?00206O:
@`0W06O:D01[^EL0K:YL06jTF@1`Xe80LZi:076`@01a^S/0O<<W08O0502?^0D0T[h708o52P2<b``0
Ql/C08K<7P28ab00QlHQ08C:7P25bAh0Q</L083:7P22a280P/8W0831<01o_3L0O;Hk07n`>@27YcH0
TJ<f09NS=P2DWD<0VYI>0:V=C`2ZTDd0[8]>0:^>D02NVdL0TJ970080SjI:02L0SZM508nRB@2=YdX0
RZi508Z_@P29[T<0RZe108nX@02=Xd00Qj8k08V_:@25]Qd0RJPA08VN302:V0P0Qi4308BB0@28U000
RI4008NB0026T@00Phd007n6001mQ000NWT007Yg001fL@00MW@007Ae001_L000Jf<006IK001NE@00
F4h005UB001MDP00ETd005A;001HC@000P1FC@002P1JC`00GED0065G001PE`00G5H005U?001DC000
EdX00598001ABP0205A9000K059;001?B000BD<004`n0019?@00BCX004Pn001:@000CD<004a4001;
@000BCd004Hn0018@P00AT40040f000k<000=R/003<[000]9P00:1l0020K000M5P006Q8000l=0009
1@00108000800@00?000000<0?ooo`002P3oool0501OK`00H7P006Ai001WNP00JG/106Yn0@1]PP40
KH<006R6001XRP40IXX106JA0`1VTPH0I98706BL2@1VW`X0JJ8;06ZQ2@1XW`P0HYl:0P1SW@X09`1P
VPP0GIP805fG2@1MV`X0G9`906FI2@1YU@P0KHh706nA1P1`U@@0LYX107>M001fWP00MI`007FM0@1d
XP40M:<207FU0`1eY0<0MZL207NV0P1dZ@@0LjX507B[101gZ@80MJD207FX101cZ`H0MZd707RZ201j
[@L0N:T507bW0P1mZ000OZ/007b/0@1m[080P:l2086`0@0207n^0P0W07j^0`22[P80QJP108RX0023
Y`00PjP008>X0@22[@40Ojh0086a0020[`00O[00082_0020[`40P:d108:`0@20/@<0Q[@208Na0@29
/`00R;<108Bf0P26]P80R[D108je0@2?]0D0SKH508fc102?]0<0S;@008Rc0025/P40Pk<408Jd0P29
]040Q;D708>c1P27]0L0S;@60080Rk8302L0S;4308N`0`28/P<0Q[8408fb102C/`h0VK@=09jf2`2H
]Pd0U;P=09Zd302J/`P0VkD909Jc502M]0/0VK@909>g302H^0h0VK/:09;02`2=`0d0S<0908Fk202=
`0/0V[<:09>e2P2C]a80Wk<=09Jf302H]@`0V[<@09Ve3P2G]`h0XKH>09ff302C^0h0Vk<B0:6`3@2C
^Pl00P2G]a@09`2V[1/0Yj`D0:N/5P2ZYaP0YjPB09fZ502TYQD0Z:HB09^^4`2R[1/0Zj8P0:JY4`2R
Za80YjLM0:NV602TZ@h0WJPG0:RQ:02KYaH0XZ8J0:fL8@2[WAT0XJ0Q0:>T802QZ1T0U:TH09VU902L
Z2P0WZHY09bQ902KY2L0YZLW0:6V8@2GZ2<0UJ`Z08fa:`23]300O[XW07O0900207[5800W07k;801o
abD0Ol0/08:j;@24]2l0P;d[08329@21aa/0OLLG07g55`1nb1`0Ol/R083>7@20cA`0Ol`G07g;5`22
bQP0PLTK08G;6P25c1/0QlHN08K86`29aaH0RLPD08S;4`23c1H0O//O07c:8`1gabH0M<PV073::P1a
bRT0L<TZ07389@1`bR@0L<P[06g8<01/acH0JL@n0080J<e402L0J<]B06ZmEP1Y[e`0K:aI06j]D`1b
[4P0M;E007C3>P1kb2L0Ql<D08nk2P2@``X0S/TA09C95`2CaAP0SLPH08c:6`26ba/0QLXG08K85`29
bA/0PlLQ08?78P22bRL0Ol@/082l<`22[cH0QJXf092Q=P2KWSh0UYi309R@B`2VQ4l0_H5@0;Z6D02g
QE80X8]=08nNB028ZDD00P2;[4@0402B[DL0UJA;09BOCP2@X4P0Sj5708ZWB026[C/0S;0T09BY6P2F
XA<0Tj4@08bO3`29U@D0R8h008J<0023RP0208>9000E08J40023QP00QHX00826001nP@00OGl007Qi
001fM@00Mg4007Md001aL@00KfX006]P001UEP00G58005]A001ND@00G50005YC001HC`00ETh00080
Edh000T0FE@005aG001NEP00G5T005]E001ID000ETd00597001@A`000P1BBP002@1ABP00DdX00596
001=A000Cd<004`n0018>`00BT0004e4000204U0000A04Xo0018?P00@cL0040d0011>P00>c@003H/
000a9P00;R@002PR000U70007QL001TB000B3@002PD000D100020000?P00000<0?ooo`002P3oool0
4P1PL`00GgP006Al001UNP00J7l106J50P1WR`40IXP006B7001PS@80H8h305jD0`1PTP<0H9@606>J
201SW0P0H9h8062Q2@80HYl90P1QW0T09`1QV0P0Hi8806BC2@1TV0X0J9P:06^C1`1_S@<0L8d106j@
0`1_T0<0KiD107>G001hVP40Mi/307BI1@1`X0@0LJ@306fX101[Z@<0KjT3076Z0P1bZ`00Kj/106jY
0P1_YP80LJ<0076Z0P1c[0<0MZl607J^1`1l[PH0NZ`307V]0@1l[`40O;0107R`0@1i/P<0N[4307^b
0P0207V`1@0W07N^1`1j[PD0PJ`1086^001n[000OZX0082/0024[040PJ`007j_0@1m/040N[0207f`
0P1o/`80P[0108N`0029/040Rk8108Zb002=/@00R[<008Rc0028/P00R[8108jb0P2=]0@0S;L408Zg
102<]P40RK@008^b002:/P00Qk@208R_102;[`80R[0608Jb0P2:/`40SK<10080S;8102L0SZh108f^
0@2<[P00R;4208bc0`2>/P80U[@:09be2P2F]Pd0V[H>09nb2@2I]@T0W;H?09jc4`2S]@/0VKH:08ne
3`2H]`/0Ul0:092o302;^`X0Sk/908_0202?_`T0TkD908bh302=]a00VK<:09:f2`2H]P/0W;8>09Zb
402N]a40X[D@0:Jc3P2P]0l0X[4E0:F]502G]A<00P2O]AP09`2Z[aP0XjdB0:B]5P2[ZAL0Z:XB0:2V
5@2SZ1`0XZXH09VZ5P2UWah0/i`K0:RU3`2SZQ80ZJPG0:VW4P2C/180VZhI0:NV7@2JZQ@0XZ@H0:JQ
6@2RYa<0Y:HR0:>[6@2R[aH0VZTL09ZX7`2OXb40Xj4T0:NN902PYBH0XZLS09VW:`2AZ2h0S:d]08Ra
;`23]S@0O/0W07bn900207_18P0W08788`21aRX0Ol<_0871;`26_Bd0Q<8U08C56@22bAH0Q<T@08?:
401obaH0M/TR07_:901nc2<0Ol`K07k=5P1ncAD0O/dI07g;701lbB00P<LT07g79P22bR@0Q<dO08C<
8@20bR@0Ol<S07_19P1eabT0L//T06g=8P1`bB@0K/LY06c9:01^bbH0KLXZ06S:=01Yc3@0JLdf0080
K<lm02L0J<e;06W2D@1X]eL0J;QD06ZeD01`[dT0LkU007K8=@1lc200QLLC08k4402?aA@0T<@K09C7
702Bb1d0Rl/J08W:6@28bAP0QlPK08[5702;b200Q/PS08?79@25aR<0P<<Z08Ff;`2;ZSD0VJ<h0:FK
?02IUd<0TXm=09>9CP2RQE@0_85A0;F5D`2YQ5@0V8a=096MA`2=ZT<00P2B[Sl04@2E[D00UJ9309BO
B`2@VT`0TZ1;09>Y@028[2P0T:TC09:J202AT@40S9<108VB0@26RP00Q8@008240020PP00P8L00080
PH@001@0PhD00865001oPP00Og`007]i001jL`00MW@007Me001gLP00LG40071X001TGP00H5@005eA
001ID000FDd005U>001JC`00G50005UD0080Fe8002D0G5D005]C001JD000G4h005Y?001IEP00F540
05A=001DBP00E4`005E=001BBP00DDD004i5001<A@00D4@004lo0018?P00BD4004]3001:@P00Ach0
04Q00015?P00@CH003Ta000i=000>S8003D[000/9P009B0002@J000O5P006a<001DA000>1`0010<0
04000000303oool000X0oooo01@0H701061f0@1SMP00Ig/006J10@1QPP40HhL105b8001PQP00H8L0
06680P1MR`80G9<405ZA1@1LV`L0GYX705^L201OU`X0Gi<7066F1`80H9H802<0I98506JB101XT@T0
J9@806^F1P1/T`H0L943072?0@1_T080Ki41076D0@1bU`40LYT3072K2@1_W@/0KJ<:06jY201[Z`L0
J:/706^Z1`1_ZPH0LZ`206n/0@1/ZP40KZH106nR0@1aZ080MJX107N]0P1j[PD0NK0207R_001g/P00
M[H107Nc0@0207Zc0@0[07jb0P1k/P40N;<307Rc0`1g/@D0NZh307^]0@1k[000OJ`007n]0020[P00
Pj`007n_0@1n/040N[4207Na0`1j/`@0O[4408F_0`29[P40RZd008b^002=[P00SZl008^a0027[`00
Qjd008R_0@2<[`80S[4308^d0`2:]`@0R[H208ne002>/`00T;8008bc0`2:/0<0R;0108^`0@2</`40
Sk@0096e000208nd000G096e002?/`00Sk4008jc0@2;/@80S[43096b2@2C/`X0V[D?09je3@2Q]@/0
VKX<09Vf402N]0d0UKH;092f3P2B/Pl0T[L:09Bo2P2D]`d0UKX:09C02@2@^@T00P2B^@X03P2;_@`0
SkP>09^h302@^0d0TkXC09j`302N/Ph0W;<A0:Ra402X[Q00Wk0C0::_4`2W[a80W;4C0P2T/AP09`2Z
[aL0WK8B0:>_5P2Z[AH0Xj/C0:2/6P2T[1h0YJ/L09^[5`2SY1`0[j0M0:>W4`2S[a40ZjHE0:NV3`2B
]1X0V[@I0:F^3`2F[A80X:PB09:]5@2J/aL0YjTS09Ra5P2L/1H0XJ`M09fU602GWB40XIlU0:ZP;P2T
XbT0Wj0W09ZR<@2@XS@0RJTa08Ne<027_Rd0QL4Y07o0:@0208C0:`0W08O09`24`BD0P<DU07o79P22
b2P0Q/TS08G<6`21bQL0PLTD083:4`1kc1D0M/`N07W=8@1lbbH0N/dK07_@601kcQL0NLdI07g=6P1n
ba/0P<PO08398020bQd0P<dK083=7`1nb200MlPP07?:901ec2X0LlhQ077@6`1`cah0LlPT07?<801c
cQd0KllV06_<<P1ZccH0JL`e0080J]0e02L0JLm406O:C@1Ua5P0Il1I06VmD01_^DL0M<0i07G;:P1l
c1L0R/X>0975602A`240T/8S09777P2Aaa/0SL/G08g;5@2<aQL0S<DK08W27`28ab<0Q/HU08O29@26
_BP0QKDZ08F`;`2=YcD0VJ4h0:BL@02JTTX0VH=A09b3E02YQ5<0_8A>0:Z5D02KR5@0U8e@096GC@2B
Y4X00P2GZ480402CZCh0TJ=309JNA@2;ZC`0S:d[09>V5`2>VA40SIL608f>0@26S`00RY4008R@0026
QP00QHD008220020O@020823000E08>50024Q000QHL008B60021PP00OgL007Ua001fM000NGL007Ia
001`K000KVD006QH001LD`00FU4005Y?001HD000Ee0005Q>001JDP00GED00080GUH002D0G4l005E@
001ICP00EdT005A:001JDP00EDl005==001@C000DdT0055<001@B@00C40004/m001<?P00C4<004]4
001:@000B3h004Hn001=?`00ASl004Ll0014>000?S@003/`000f;@00<B/003<Z000Z9@008Q`001dF
000I4@005@/00109000:1@000P0004000000303oool000X0oooo01@0GFl005mf0@1QM`00HgP00660
001PP000Fgl005b0001MN@00G7d005mn0P1NQ0D0H8h705b@1P1MV0H0H9T6066E1P1PS`D0H8T205j9
0@80H8d302L0HX`306J=0`1WS@@0K98306fB101]TPD0KID406nF1P1aVPP0L9T6076H1P1`W0H0L9d9
06jR2`1^X@l0KZL=06nY2@1[Z@T0JZT:06^W2@1_Z0T0L:P4072Y001_YP00L:D0072U0@1aYP80MJd4
07>`0`1g/P80N;4007Nb001g/`00MKH107Rc0@1k/000Ok0007f/001j[@000P1i[P401@1g[@80N:X1
07ZY001kZP00OZ/00080Pj`00200Q:h008Ba0024[P40P[01082a0@1m/@80Ojl4086]0P24[P40RZd0
08b[002;[@00RZl108f^0028[P00QJ`008Rc0@27/P40R[4208Rf0P27^PD0Q[L208fg002@]P00TK81
08^d0P28/P80RK4008bb002C/P00U;0009>c0080U;H002L0SkD008jd002B/`00TK4108fa0@2?/0T0
TK4909>c2`2H^0X0Vk@;09Zh2`2C_0`0T[X;09Ji2`2<^0X0T;<>09Nf2@2A]`T0Tl0;09fg4P2O^0X0
W;P909Ng3P2H^0`0UKP908^k302@^`l0VKT;092g3P2J]Q@0YZl?09j_3`2K/a<0Yk4B0:Fc3`2O]180
XKDC0:Nc402Q/A000P2S[QD09`2Y[AD0Wk<A0:2d4P2Q/aP0W[4E09Fc6@2O/A/0YJ/M0:6/5P2M[AP0
ZjPO0:V]502R[a80YJHG09jU5@2F[Q/0VK<K09ja502?/Q@0V:dD092b402F]1@0YZ/S09>b5@2KZQL0
YJPF0:JS5P2OVRd0YIlZ0:VN9`2PXRl0VJ8`09:R<`2=YC<0QK0a08G0:P25b2@0PlLT08?69`0208C4
8`0W08K97P23bAd0P/XL07k;8P1obBT0OLTW0839801nbQT0O</C07c;4@1kcA80O<hE07k>4`1lcQD0
N/hF07[A6@1gcaT0M/hM07gB6@1nd1X0Pl`M087=6P1mcQ/0M/lK07_=601jc1d0LlXR07;?8@1edB40
N=0L07C?6P1dcQ`0N<PT07W9701gbQP0M<dO06_>:@1YcRd0ILh_0080Im4`02L0JM4m06O=C@1VbUL0
J/U?06[7B01b`D@0M<Ha07W?8@24d180T</?09O:5P2DaQh0TlXR09;86P2DaAP0T/PG09775`2@`QT0
TL0L08fm7`2;a280R/0W08Jn9P26^2L0Qk0/08R[<`2?ZSD0UJ<n09bIA02VTTX0/XA@0;AlD@2ePe40
]8U>0:J8D`2LRU80TXm>08nKB@2BXDL00P2HWTD01`2CWTD0T9]:08ZT>P28Yb00SIdC08j@1P29Q`00
0P2:R0007P25R000R8/008V:0027QP00QhL008B70021PP00Oh<007n00021OP00Ph0008:40025Q000
QH<00820001kM`00NWH007Uh001cK`00L6X006YU001VFP00G4l005Y@001JD@00Fdl005U?001EDP00
FE<005eE0080GUH00100FU8005I@001HC`00ED`005I8001EBP00E4X004m8001@A`00CDD00519001>
B@00Bd4004Tn0016>`00BCd00P19@0004P16>P00Ac/004I00017?P00ACd003li000j<P00=S0003<Z
000^9`00<BP002`U000R6P006A<0014<000>20001`@000@204400000303oool000X0oooo01@0FF/0
05M]001JM000F7D005al001KN`00G7P005Qc001KK`00Efl005]f101IP0P0FX/805RC1`1GUPH0GIL6
06:D0P1UT040H8`106290080GHh202L0GXl306:>0`1WS`40JXd106b?0P1VT0@0I9<706FJ2`1WW100
JYh=06bN2`1YX@/0Iil<06VQ301^XP`0KZ@:06fS2@1/Y0T0JZP;06fV2P1_Z0L0L:T3076X001bY`00
L:L007:X001c[080M[4707Ba1P1g/@D0Mk0107Z`001k[000O:h007f^001m[@00P:X007n/001k[000
0P1m[@009`1nZ`00O:T007jX0020ZP00Q:`108>Z0@21[@80Ojh2086^0@26[`40Q;4008Ja0026/040
QZl308J^0P26[P40R:X008bY002<[@40R;0208J_0@2:[@00R:d008V]002;[`00Rk<208Zd0@27]@80
Q[@108Zd002;/`00Sk<108^c0@29/P40S;<0096a0@2G[`40Uj/009Ja000209Fd000W096c002>/`00
SKD008^d002:/P40SKH808je2`2<]PT0U[H909Ff2P2D^`/0T;X<08jh2@2;^0X0S[D=092d2@2>]0P0
T;L:09Vg3@2P]1@0WkD<09jh2`2K]1@0V[D=09Jh2@2>^P/0T[/>09Zj2@2A^@d0X;4D0:V`3P2U/0h0
WK8C0::b5@2O]`l0XKPA0::g4`2S/a40WK<@0080WK<A02L0Y[4E0:J_402Q]Pl0WK<H09nf5`2I^AL0
Wk0I0:J/6P2O/A@0W;4D0:>^6@2T/Q@0Wk8@09ZZ7P2LZ1/0UZhG09Za7P2L/Ad0T;DH09:^602E/0h0
VK0C0::[9P2G[QP0V:LH09jX502PZAT0ZJ0/0:^L8`2SV240VilZ09BZ;P28[S40P[<a07o1:P22aB@0
Pl/O08;<7023b1l00P25bR409`22bB@0P<PQ07g6801lbB40O/DW07k8:@20bB@0OLXL07[=5`1jc1@0
NLhE07SA5@20cA<0OllB07[@501gcaL0NLhL07K<8@1kdQh0O=8L07o=701mcA`0NLdN07G:7P1fbb00
MlPW07G::P1bc280MM0O07K?6P1gcAX0M//P07C:;@1eabT0LLLR073<7P1/dB<0K]0R06cA9P0206c?
;`0W06W@>P1WcdL0I<i<06K=A@1[bSl0L/Hn07?;<@1nd2<0RL`H09O85@2KbaT0U//I09O<702Ec1L0
UL`E09?;5`2CbaH0ULXG097:5@2=baL0T<XM09358`2<`B@0R;PU08Ja:@2:/RX0SJ/f096O@P2CTDX0
Zhm=0;N8DP2lOTl0^X9B0;>5E@2TR5D0VHUD09BFD@2?Ud/0T9A:0080UiA;02L0UYE:08nH@P1oXAl0
QY@B08F71026PP00Q80008J10026Q000Q8<008B40023PP00Q88008>80025RP00PXL007n3001jP000
OG`0081n0024O@00Q7h007ii001mN000NWD007]h001hM`00N7H007Eb001[J@00HU`005YB001JD000
FE<005EB001CCP00Cd/005IA001JE0000P1NE@00901KE000FE@005Y<001FC@00E4`00559001@B000
CdL004i6001<AP00CT@004]7001<@P00Bd0004@k0018>P00B3`004Lm0015>`00ACT004Dl0015@@00
@ch003de000d;@00<BP002dS000[9000;BD002PS000N6000510000d700060`000`40004004400000
303oool000X0oooo00<0G6L005YY001LK`000P1LK`003`1LM000GG4005aa001LK`40G78205ii0`1M
O@L0FhX805J>1P1IT`H0GIP5062G101OU0<0HI41066@0@02062D0@0W062E0P1PU080Hi<306BD1@1S
U@@0H8h305nB1`1MV0d0HIdC066O4P1RXA00HJ0?05jO301UWP`0Jil806fL1P1]X`H0JZ@706NV2P1Z
Z0T0KJT6076Y1@1bZ`80KZX0076X001eZP00MJ`107>`201d[PL0MZl507V/0@1iZ`00O:X007jY001n
Z`00Oj/007j/001nZ`00OZ`00080Oj/002L0OZT008BT0025YP00QjP008FZ0P21[0@0Pjh507n/1@21
[`@0QZl208N_0029[P40RZh108F/0P27[P40Rj`008^Z002<ZP00Rjl108N^0@26Z`40RZX008b/002:
[P00SJh008Rb0029]@00Q[<008Jd0029/`00S;<008Zb0028/`00SK<008ba002=[`40T:l109:_0@2D
/`000P2B/P009`2C]000Sk8008na002>]000Rk@008Zh2@2:]PT0RkL8096g2@2>^PT0TL0:09>h3@2;
]@`0Q[d:08bb3`2>/PP0RkH9096f2P2M]@l0Y[@?09^f302F_`d0W[HB09Rh302E_`T0UKT=09Bg3P2J
]`T0S[h<09^d4P2V/`l0XK<=09^g4@2O]a<0Vk/@09bn4@2N^aH0WKLE09Jk4P0209Ri4`0W0:Fd5P2V
/a<0X[@A09na5`2R]1T0Y;TF0::c5@2V[AP0Wk4C0:2c4@2T[aH0X;<B09Ve3`2G/Q`0V:hJ09:a502H
/aT0X:lN09:b5P2E[QT0XZ/E09b^5P2TZB@0XJ`J09^X4P2KZaD0U;8H0:JT902[X2@0Y9PY09^S;@2@
/2`0P;@c07jj<01maRl0OlPW083;8022c1`0PLPO0080PL/Q02L0P<`T07c:8`1hbAd0M/XL07W:801l
bQh0O/hN07c;701mbaP0NLdG07cA5`1icaP0OM0G07kB5`1id1D0N/hA07[>5`1ecR00N=8P07K@8`1h
c200NlXN07S;7@1iba`0N<TP07S79@1eabH0M</N07?=6`1dba/0M/PK07?;801ac2@0KL/T06W;8P1/
d1l0Jm0R06oC7`1`dBH00P1]bRl09`1XbC<0J<hl06SA@`1Vcd40J/`l06g=<P1ecRP0N]<U08W@6@2B
c1P0T/PP09?88@2Cb1l0TlTL09;:6`2?baX0T</J09C;5P2?cA<0TM4D093<5`2>aB40SKdT08^k902:
^2P0S:/]09>O>`2OUDD0[XM<0;B9CP2hRE<0^hID0;R3E`2fQ5X0W8AH09>:EP2GU5P0UI=D08b:E`02
09B>E`0W08jG@@28WBL0P98C08F71023P@40Pg`007il001mNP00O7X007il001oO000Ogd007j10021
PP00Q88008F70020QP00Oh8007Ul001oNP00Oh00081l001iNP00NG4007I_001jMP00NGL007Mm001`
N@00KFl006ER001NFP00G5@005aE001FD`00EE4005=?001FC`00FDl00080FE0002<0FU0005UD001G
D`00F54005A;001CA`00D4X00515001>B000Bd@004U2001;?P00BSl004Ln0012>000@cP004Hi0016
>`00A3h004<j0012>@00@SX003dg000j<@00<BL002TR000W8P008ad0028K000O6P0061<0010=0007
1000104000410012000000`0oooo000:0?ooo`0D05]N001LH`00FVP105MZ001JJ`00GG0005md001O
O000Fgd2061n0`1OQ0@0GHD605b81`1JT@H0EIH905^M2@1JW@@0GYH205fC0@1STP4206:G0P0W062H
0P1NU0@0GYT605^I2@1KV0P0GI8505fB1P1MU0T0H9P;066J3@1RWP`0HZ0;06:N2`1WW0P0JiT506jJ
0P1_X0<0K:D706^V2@1/Y`L0K:D606jX1P1_YP@0L:D1076T0P1dY`80LjH207FT0`1eZ0H0MZL207JW
001fZ@00N:T007^Y001mZ@00OJ/007n[001nZP00NjT00080OZH001T0PJH0086Q0022X`00OjL008:Z
0023[@@0Pjd508:/1P22Z@D0Q:/208B/0026/080QJd208F^0@26[P00R:/008Z[102;ZP40Rjl008J`
0@26[`40QZh108Z^002;[P00S;000080S:h000`0Pjh008Bc0@25/P80RK8308Nc0P27]040S;@008bc
002;/`40RK@108jc0@2?]P0208fe000W08ne002=]@00S;@008Ve002<^000QkT908Vg1P2;]PL0TkT8
08fi2@2?]``0V;8<08ng2`27`0d0Sk4B096d2`2@]PX0UKL>09Ve4P2T]@`0VKP;09Ro3@2P]a40Uk/;
09>o2P2K^0d0WKT>09Zf2P2?`0`0UkTB09nh3P2J]`d0U;dB09fh4`2N^100VL0?09o05@2R^AD0UKXB
0080VKXC02L0X;8E0::g4P2N^@l0W[HD0:>e6@2V]aP0VkLG09fc6P2P]A80WK@@09ba602M]1@0V[L?
09Ne5P2G]1L0T;L@09:h5@2O/Ad0VjlE09b[5@2UYaT0XZXH0:FV8@2HZAT0TZPJ09B^4@2C/a<0Z:4L
0:VR7P2[VR`0WJT_092`<`20/S40O;P`07[7<`1lbRP0O<XT07o9701kaa`00P1oab409`1oab80N//P
07O=7`1fcA/0N/hM07[@701odQT0N=4N07S?7@1icQX0NllG07c>6@1gcQ/0N<dK07W;6@1ibAH0MldH
07CA6`1ad2@0LLlZ07;7:P1baRT0MLLW07K88`1f`2X0Ml0/07K7:P1gbB<0MLXX07;8:@1^bB/0L/`U
07;>8`1^cb<0J<dS06W?8P1VcR<0KLhT06o<;@0206g7=`0W06g9=01Zcc80I/le06G?>01WcS<0LM4X
07CD7P1hdQT0Qm0C08k<4`2>bQd0RlTL08k:502?baD0T<`J09;:6P2@bA`0TL/H093<4`2@c1L0T/LJ
09728@2@`BH0S[hV08fg:@2@[B/0WJ4g0:nC@02kRDT0]hY>0;>=D`2/Se80Yh]I0::0E`2BQe`0ShmJ
09^AE`2JReH0UHQI0080Ti1A02L0Qj0X07nB4@23Q@D0QX4108N10020N`00NWH007I`001iL`00OGL0
085l0021O`00P80007em001mO000OX0008290021QP00OGl007mn0020O000Ogh007Ql001hM@00MW<0
07Me001iNP00Lg/006mk001XKP00Hf8005iI001GDP00F5@005U@001EE000Edl005UA001KD`000P1L
CP008`1IC`00F54005U=001GC`00EDd005I9001GC@00E4d0051:001:AP00BD<004M00018?P00B3d0
04Hi0014=P00ACP004Pk0015>@00@3T003hh000k=@00=S4003H_000_:@00:R<002LO000Q6`007AD0
01PD000C3P0030H000<200010@000@0004800000303oool000X0oooo01@0GF4005aS001MK@80FVd0
05e/001OLP00H7D005am001JQ`80FHX405^B1P1MS`D0G90405jI1P1LW0L0GYd606>L101QVP<0H9L5
05jG0`80H9T401H0HYX406>G101LV@L0F9T:05NF2P1LV0L0FI<605jD101NT`<0HYH406>I1@1WV0D0
JYX506ZG0`1]UP40KYT106ZO0`1XX`D0JZD806ZR1P1/XPH0JJ@50P1/X@<03`1/X`L0KJ@807>V1`1b
Y`H0LjH507FU0P1gX`00M:H007BX001lZP00OZX007b[0020Z@00OZH007VT000207RT000W07JT001h
Y`00N:D007^Y001lZ@00Pj/108B[0P24ZP80QJT208B[0@24Z@00Q[0108R_0@27/P00Q;4008N_0028
/040RJd408J`0P20/080O[0307j`0P22]040QK8108J^002:[`00R:l008B_0025[`40Ok04082d2@20
/PL0Pk<308Rd0@2:/`00R;D008Zf0@2<]@00R[@00080RkD002L0RKH008^g0@2;]@00QkD008Vg0029
^@40SKP908Zg202=^0L0S[@<096c2`2E]0X0S;D;08bf402I/A<0VKH<09Jh2@2B^0d0VKP>0:2g2@2E
]`/0WkL<0::k3@2I_@/0UL0;09Vk4`2I^Pl0U;T;096m302I^@h0VkL=09Jh3P2F^Q00WKHC0:2g402N
^Ph0W[PD0:6f5@2L]Q400P2M]A409`2M]1H0VkHA09Vk302G^100XKDC0:Fi3`2F^Q40V;LF09ji4P2I
]A00U[8G09Je4P2H^@`0T[DC096e4@2@_A80T;TE09bb6@2N/A<0XJdE0:NU6@2TZAP0YJ8Q09FV602A
ZB00T:lC09F`4`2XYAT0ZZ<P0:nI<02TXS@0TZTk08J]>020]CD0N<Dc07S6:`1faRD0Nl<N07_37@02
0833800W07g59@1iab80N/`Q07O>7`1hd1h0N=8K07gC6P1jda/0NLlN07[?8P1icA`0N/hI07O<6@1c
c1X0N<TJ07[97P1gbQ`0L<dO06g@8P1XcRX0K<@_06c4<`1]b2X0LLPY06fm:`1[_2h0L/4_07;8:@1`
bbP0K/`X06k;:01`cRL0Km0V06o<:@1YbBl0IlXZ06C;:@1Tb2`0IlLc0080Jl@g02L0K<Xa06[@9`1X
dRH0J]<Y06OD9P1_eQT0N=8F07c@5@2;ca80S=0I08c>7@2=c1`0SLXF093:5`2Aba`0T/DN09;2802<
aA/0SLPJ08g=6`2Bab<0TL4W0932:02>_BL0Sk8Z09ZT<02WWSH0/iHm0;Z@@P2gT4T0Z99?09JIB`2C
SU<0SH9E08j?G02DTU`0VheG09N7DP2ASDP00P28X2L09`28VA@0R8H308J50025P000Qh00089m001l
MP00Ng0007e_001jNP00P7d0089m0020O@00PWX00860001nO000OGh008210020O`00O7P007Yk001l
O`00OGd007Mi001fM`00Mg@007Mh001aMP00K7@006EZ001MF`00F5@005U=001ID`00FU@005UD001D
D@00ETd005M@000205aC000Q05aD001ID000Edh005E?001CCP00DD/005A=001FCP00DDh004i40019
@P00C4<004Y10017?`00Ac`004Hi0012>000@cP0040h000n=@00>cD003H_000`:@00<BP002hW000Y
8`0091/001dH000F4`0040`000/500050P000P0004@00000303oool000X0oooo01@0G6X005Y_001J
LP00Fg@005ae001PM@00Gg`105b40P1JS`<0EY<405ND0`1HVPH0GIP205bL1@1OWPH0HIl406>M1@1S
V`L0HYT7062H1P80GYT702L0HIP7062D201MU@/0FYH;05fE2P1OUPX0HI<906>C1@1ST080IHh006ZA
0@1_T040Ki@107:D001fU@00LIX106^J0`1ZWP@0K9l506bL0`1/XP40KJ8206RQ0P1XY@@0J:L;06NX
2`1ZZ0T0K:X706n[1P1aYP<0KZH007:W001gY@00NjP007fX001kZ000Oj@007fR001hW`000P1eYP00
901bZ000MJT007NX001kZP00O:P008F]0026ZP00QJd008>Z0021[P40Pjh108>]0022/000Q;H008Bb
0022/`40P;<4082`1P1o/0<0O[4407ba101k]0<0OKH308:c0@28/P00Qk0008V_0025[P00P;4007bb
101k/PL0O;8807bc2@1o]0P0PkD208Rd0080RKD002X0Q;H108Zd0@2:]040S;P108^i0@29]P00QkL0
08Fg0027^040T;L:08Bh202:^0X0T;D=096d202>^0T0S[P<09Ng502L]Pl0TK/908fn2P2@^100U;P;
09Nj2@2B^0`0VkP>0:>h2`2P^0/0V[/>09^h5P2G^@l0Tk`>09Bj3@2J]`l0VKH=09Vh3P2C^0l0V[TA
09Ji3`2E^@l0VKLB0:2h4`2N^Ph209Vj400W09Rf4`2I^Q00UkT;092k3P2D^Pd0WkX;09Vm3@2H^A00
Uk/?08Vm3@2:^a40T[TC09Zj3P2C^a80UKX>09Fj502A^1H0VK<G09j`502V[QD0ZjPK0::X6P2NXB80
Tj@N096X7`2I[Ah0VZlN0::T702VXAl0/9Hd0:6S>@2AYc/0Q:di07jf>01i`cD0NLPX07O89P1haah0
N/HO0080O/LP02L0NlLN07W;801jd240N]4N07WC7P1id1/0N/hJ07OB701icAl0NL`X07O>8@1gdAl0
M/hH077=6P1kbaP0NlTQ07S;801cbb40KldS06_?9@1`bR@0K/`V0777;01]b2h0Kl<Z07329@1haB80
MlPO07?;7P1bbal0LldR077?8@1bd1h0L<dR06g;8`1XcR@0H<l[063=;01SbbT00P1YbbT09`1/cR@0
JllK06[D801[eB<0KmHM07GE5@1kdaD0Pm0@08g>502>caX0TLhN08k96`2Bc1L0T/XJ0977602AaAT0
S<8M08S37028`AT0R<@N08_59@2B`bL0Sl4T092g802DZBT0XZ4^0:nI=@2hUS80_i8a0;VA@@2[TD/0
ViI;09R=E`2:QU/0UH]K09VAEP2MU4X0UiI508ZH:@0208:G4P0W08R81@24Q@00Ph@0085n0027OP00
Q7`0089j0020M`00NWD007Ue001lM000OGH007ij001oN`00Ph0007mg001lMP00OW/007ek001jN@00
MWL007Qf001lN`00MWP007Qi001eLP00MG40079_001[K@00Hf<005eK001JDP00FE<005aF001LE`00
FUL005Q?001HC@00F4`00080F4h00200Fe8005YE001GC`00F50005=C001CC@00Cd/005A;001CC@00
CdD00512001>@`00CTD004]00019?`00@SX004@g0011=`00?S@003`f000i<`00<B`002XS000Z8@00
:Al002@L000N5`005a<0014<000:20001040004004D00000303oool000X0oooo01@0GgT005el0@1L
O@40Ggl005im001NN`40HXH405b>1P1GV@D0EId505>L1@1FX0D0Fj0505nN1P1RW@H0H9`406BM1P1R
W@L0HYP7062I1`80GIH801@0H9<605jA1@1PS`D0H8h706B>1P1YT0H0Jhh606f?0`1_SP40L8h0076?
001cS`00MID007BG001dV000LI/106jL0`1_WP<0K:0206bR0@80J:@100`0I:D206NU101WZPP0I:X8
06F/1P1[[@@0L:`4072Y0P1bZ@00LZP007NY001iY`0207VV000307ZP001kX@00MZD00080LZT002L0
M:X007^Y001nZP40OjX108>/0025[P00QZd008F^0020[@00P;0107n`0`1o[`40PZh008Bc0022/000
Ojl207^^0`1k[`<0O[02082`0P23/@80P[8207jb0P1o/`00Q;8108Fa0@25[`00PJh007f^001l/`40
O[@307nd101n]@P0Pk@808Bf1027]@40R;@008Vd0027/P400P2=]0409`2<]@40RKL008Vi002:]P00
QkL008Fg0028^@T0P[P908g03P2B]Pl0T[D908k0202@]Ph0T[DA09Ff2P2>_@T0SKd:09;02`2B^0X0
S/0;09Fh3P2L]@l0X;D<09Zh302J^Ph0WkHA09Zg3@2H^A80V;T@09fg402J^0d0VKT>09Ng3`2N^140
V;T>09^i402M^1<0WkLB09Nm3`0209>o4@0W09Bj3P2E]`d0UL0;08g0302>`@h0V;/<09Ro302E_@h0
T[`?08^m3@25`140T;`D09^k4@2A^`d0T[X@09Bh4@2B^A@0UK<E09be602Q/1X0XjlN09V`7@2IYB80
V:LR09^Y8P2KYRD0V:/T09RS902KX2L0XYTf09VR>`2=Xd00P:U007fg>@1i`SL0N/T[07S:901hab<0
N<TR0080O</J02L0N]4F07O@601idQP0Mm@J07S?6@1hba/0N<LM07C:801gbRD0MLX]07C=9@1fcQh0
ML/P07388P1cab<0MLDV07C99@1bc2P0L<`U073<8`1^cAd0LllM06k<:01XbS40KLH`07;:9@1hbB80
LlTR06k89P1]bB@0KLX^06k>:`1^cR@0KL`Q06W;9P1ZbbT0H/X_06K?:P1WdB800P1/dA`0301bdAD0
L=4F06gD6P1_eQX0MM<F07_E5P22d@h0S=0<093?402AcQD0U<XM09?28080Ul<P01T0Sl8O08c17P28
`b40QkhM08Nm6`28_1h0RKdS08_08@2<]240S:LQ09RN:P2WVC80]IXa0;ZE:@2lU2D0]i<i0;6AC02V
Rdl0VHQH08^1F`2@RE/0UIQC09^KA@2<X2d0R9`F0080RHP400@0QH8008An0020NP00Og`00P20O@00
8@1oM`00OgD007Yc001fKP00M6l007Ib001gL`00NWL0081o001mO000OGH007ai001kNP00MWX007Eg
001eMP00MW@007Ii001iN@00M7@007E`001bL000KW0006QV001PGP00GUP005aH001MF000GeT005iJ
001JD@00ETh005990002051<000O05E>001DD@00E4/005A?001DD`00Ddh0059;001ABP00DDP004m5
001<?P00ASl004Xm0016?`00ASh004<h0011=P00?C8003/`000f<000<bd002hW000X8@008a`0020E
000J4`005Ph0010:00091`001`8000400016000000`0oooo000:0?ooo`0D05b00@1OQ@<0GH@20626
0@1RP@00GhD205j?1P1NT`H0FYP605bK1P1KV`H0Fil505^P1@1NW0H0GZ4605jL1P1OVP@0HiD505nD
101KTPD205b@1P0W05n=1@1RR@<0HXH206R30P1XQ@80JhX106j;0@1`R`40LH/007:>001eS@00Lhh0
07FB001fVP00Mid007>O0P1/X0@0Jil206ZN0@1/X`40JjD306NX0P1SZ@40I:P206B/0`1TZ@<0JJX2
06^Z0@1_Y`80LJ/107>Z001c[040MJT107NZ0@1eY@00MjH007RR001hY@80NJP30080Mj/101/0NJX0
07ZZ0@1oZ`80PJ/208BZ0@26Z@00QjP008>/0024[P@0PJl3086`101n[P80OK0007Zb0@1l/P40Nk40
07V`0@1h/P40O[80082a0020/000PK4008>`0020/P00Ojh107n`0@20/P000P22/@002P1o/P00P[<1
08:f0P24^0<0Q[D508Bf1025]080RK@008Za002:[P0208ba000R08^c0029]P00QkP008Vf0024]000
P[H008Fh1@24^0T0T;P@09Bg2P2H]`T0Tkh909?0402@]A80SL0908g02P2@_P/0TL0:08c02`28`0d0
U;X>09Ve3@2G^@X0U[X;09Vi3`2Q]@l0VkP:09Vl3`2J^A40VkP?09jo3@2H_0d0VKT@09g04080Uk/?
00<0UL0C08nn4@2=_@h00P2<`0d09`2=_@d0S/0=09C03@2@`A00Sl8@09Rm3P2E`0/0TL0;08nm402=
^a40RklB09:l502F]a80S[P=096j402E^A@0UKTC09Ff502K]A/0WKDL09^_8@2G[R@0VjTW09^Z:`2C
YRl0U:P[09BX;@2CXRl0U:8^092N<`2?Xcd0SYm0086R@P1j/400M<8g07S9:01gbR40Ml/U07K;9P02
07K=7@0W07O=6@1fd1X0MM0J07CA6`1cc1/0L<@O07708P1c_RH0ML4V07C4:@1bb2H0Ll/N07K8801_
`bH0K/DW06o4;@1bbRD0Kl/R07;;8P1bbb00LllH07;A6P1bc2D0K<`^06g;:P1acBH0L/`R06_;8P1Z
bR@0J//Q06g<801]d1l0JLlP06O=8`1TbbT0ILT/06C9;P1WcR@0JLlL0080K]<C00h0Lm<B07GD5@1c
dQP0MMDG07GB5@1kd1<0Q<l=08c?3P2?dAT0SlhO09;69`2?abX0T/HT09?18P80SL8U01L0RlLP08c9
7029aQT0RlHJ08c1802<_200RK8Q08NV8`2=XBP0UI`]0:2J=P2WWCH0[i`l0:nI@P2YUTT0WhYC09J2
FP25OUd0S8UF09NDBP2LV4@0Rj@J08bD2P0208R60@0@08250020OP00NW8007Yf001nN000NgP007ac
001hJ@00MFX007E]001dK000M6l007=b001gLP00NG`007ag0080NgH001D0MgT007Ii001bM000LW00
079_001fL`00N7H007Qd001fL@00MG4006m_001YJP00HVD005eO001PG000FeT005]H001MDP00FeH0
05IB001BCP000P1CC@007P1BC`00D4X00599001CB000D4X004e7001:@`00C4<004a0001:?@00Acd0
044e000o=@00@SX003df000o=000?C@003T^000b:P00<BP002/S000V8@008Qd001hH000H3`004@T0
00d7000910001@40004104L00000303oool000X0oooo01@0GH4305n51@1OQ@@0H8X10628001OR`<0
Gi0505fC101NT0L0H8l8062>201PU0H0HYH506BE101RUPD0HYH305jC0@1OT@00FYD105ZB0`80G8/3
02L0GhP206J60@1XQ000KX<006b5001/R000Jh`006V>0@1[T000KHl0072@001^T@00KiD007BJ001f
W@40Kj4506^T1P1]X@80K9d006bO0@1[X`<0J:H306VW0@1XYP00JJH006VU001[XP00L:8007BR001c
Y@00LjT107>[0P1bZ080LZT207>X0P1dZ@80N:P207Z[1@1kZ`L00P1kZP<09`1nZ@00P:L107n/0P1j
ZP80OZT1082U0023ZP00Q:T008J/2@24[PL0Pjl308:`0P1o/P40O;8007^a001j[P00O:l007n`0023
[`00Q:l008B^0023/000P;8007^_0@1i[P<0NK8207nb0023/000P[80082c0026/`00Q[L008Rf0026
]040QK<208Jb0@29]000R[4008f`000208Vb000W08Ff0026]`00R;L108Vf0@29]000Q[H608Nh2@2;
_0X0UKT>09Zh2@2I]`T0UKl:09304@2?]a00S[d;08jo302B]``0TKP:08_03@2:`100TKT@09Vk2`2C
`0/0T[/=09Jj3P2R]Pl0V[X;09fj3@2N]140Wk@>09nf3P2G^Pd0Vk/@09_0402H`0l0U/0>0970402;
_A00S[`<0080S;d:02L0R/0=08[13@2A`0/0TL0>09>m3`2E_140U[h@09O03`2@^Q80TkPE09Nk5`2I
]aP0Uk@G09>g4`2B_1<0T;/C08ji5P2A^AX0U;LM09Jh802C/bD0UjlZ09b];@2FZC@0SZ8e08bU<02>
Yc80TjPd092X<@2:Z3L0PjHm08JR@024WT<0PJhl07c2=P1nbRX0N<dU07K:9`1`c2T00P1cbB409`1g
`R40LlTO06k=7@1[cAd0K<`N06S48@1]`2@0MK`T07O09@1b`bH0L/HP07;;7@1cbad0MLTO07;98`1a
bRL0L<hS077=8`1ecB40M=0O07??701bcA`0M<`V07?;:P1dbbL0LL/S06c>901ZcQl0KldK07;:5`1c
c1D0LldE06g>6P1^c1`0JL`N06O=8P1Yc280JLhG06o?4002077B400W07CC4@1deQD0M]DG07OC5@1l
cA80NldA08G?4@2<dQD0S=0L08_>7P2=aB@0S/HW09758@2D_2<0U<0W09309`2=`2@0Rl0O08[37P2:
`B00S;/U08fc9@29ZR/0Qj4^08RM<P2;WCH0TIe009bOA@2VWDP0YIe60:JIA`2KRe00UXAF08b2F@2E
RU00TIe308RX<@2<W180S8/20080RXH002L0Ph@007mj001iL@00Mfd007Ye001lM`00OW<007Y[001e
IP00LVH007A/001cJ`00M70007Ea001gLP00N7@007M`001kMP00N7T007Qh001eMP00LG0006iZ001_
J`00MW<007Ib001eL@00LW8006eY001UJ000HF4005eM001KE`00Ee<005QF001IE`00FeT005IE001E
DP000P1GD0007@1GD`00F5@005E?001AB@00CTH004]3001;@@00BD4004Y00018>`00A3`003lg0010
=@00@3X003lc000k=@00=c80038[000b:@00;B<002HQ000S70007QP001`F000C3@002`T000H40002
0@000@0004P00000303oool000X0oooo01@0Fgh3061o0`1OO`80GWd105j60@1NQ0<0GHX305f90P1N
P`@0HH8605mn101NP@@0HH/3066;0P1TSP@0GXd305V>0P1FS`80Ei0105b<0080GXL002L0HXH006B7
001ZQP00KXL006^6001ZR000J8`1066@0P1QT`40I94106RC0P1YU@80JiD106jJ001/WP40JZ<306bR
101[X040K9/006^I0@1[W@<0KYh2072S001`W`00K9l0072O001aW`00LYl0076N001cX`00MJL007FX
0@1dY080LZH207BX0`1c[0@0MZd307R^1@1m[PL00P1o[@<04P20Z@00PJP008:V0@1mY@40OJL007jV
0021YP80PjP208BY1`22[@<0P;0207f_0@1o/040OJl007f`001o[@00PZl0082`0080QJ`00100Pj`0
082_001k/P00Lk@207>e101i]080O;@007nd0022]@00P;8108:e0@25]P40R;H008Bd0024/@00R;@0
0P29/`006029/P00Q;8008Bb001m]@00PKH108>e0`27]`<0RK<208^e2@2:^0T0TKP:09bg2`2L]`X0
U[h:09Rh3@2H]Pd0Vk<<09Vg2P2D]@`0TKH=09Je2`2@]0d0SK/B09Jk4@80VKX;0100UKX:09O03P2O
^`l0Wk/;0:6i2`2Q]A00XK<A0:6b3`2M]`h0W[T>09[03`2D`0d0T<4:09702P2?`0/0TL0;0P2?`0/0
4P28`@/0S<0<09;03@2E_Q00T[h@096k4@2E_1<0VkdF09Fi5`2D^1P0UKLJ09Ng6`2A^QP0T;lE08_1
4P29_aD0R/0G08fo7080SK/Q01<0R[/U08be:P2D^Rh0TK8e08R^=`27[S@0RZdd08na>02<[cX0R:To
086Q@`1oXSl0NjHn07nb?01n`CT0O<T^07W;901hc2@0M//T0080M/LQ02L0M/DR07C98P1ac1h0K<dK
06c=701[aQd0LLDM07K5701hbQl0LlXR07;:801`cal0M/dQ07O<7`1ec1h0LLlS06g;:@1[bBh0K/d[
07;@:P1_cR`0LL`Z07?8:@1`abT0M/TZ0738:P1]bB`0K/`V073<8P1cbR00M<LP07G<7@1bcQ/0L/dD
077=4@1bdA<0LM0D077A3`1dc`d00P1cdA009`1ee0l0LMPF07CG5`1lda40Pl`A08S94`2;b1H0SLTJ
08_97P2;bAl0RlDR08g4902C`BL0UkXY09_08`2C`280TL8O08no802?]b40Rk4S08b^9`2?[BT0RjHZ
08VU;`29X3<0S9`l08VJ@P2<VTT0TYaD09fMD02NVd`0Sh]A092?D02FUE@0VIE:08bV>@22XQT0Qi@;
08J9000208F7000A081o001mM`00NW@007Qc001jM000OGT007ai001kLP00NFl007I^001eK000LVT0
075/001eK@00MG4007Ib001hL`000P1jL`00501cNP00MGX007Id001aKP00JVL006iV001_J`00L700
071b001VK000HF<005iO001KGP00FUT005QE001JE`00F5X005iN001MFP00FeH00P1LD@002`1JEP00
FET005YB001EC@00D4T004e4001<@`00CTH004Y40018@`00ASh00080A3`000h0@3P003lg000k=000
=2l0030Y000]:0009R@002<L000P5P006Q@001PB000@30002PH0008204X00000303oool000X0oooo
01@0Fg<205ed0P1JLP40GG8105ei0`1JN@<0G7T105mm0@1NNP@0FW`705Mh201MO@P0GHT905b<2@1I
R`T0FHh605NA1@1GT0@0F983062<0@80HHP002L0HhL006F;001VR000IhD006B7001RR000HH`105fB
0P1KTP80GY<505jF1P1QV@@0IY/106NL001WW@00Iid106NN0@1YW040JiX106ZH0@1ZVP80KIP207:G
0@1gW040Mi/007FQ001bX@00LZ@007:S001bY000MJD107NU001jY000MjD107JW0@1fZ080N:T107ZX
0P1lZ@800P1nZ`409`1m[@00OjX0082W0@1oY@40NZL007FW0P1iY`H0NZD507ZX0`1l[000OZl107V]
0@1j[P00Njl007f^001o/000O[80082`0021/000Q:d008:_001k/000Mk@007Vc0@1h/`80O;81082b
001n/`00P;<007nc0023/@40Q;@008Bc0027/P00QJl008:`0024/000QKH008>d000208Bg000W07jh
0020^080PkP608Nf1P28^0@0SL0908nf3@2E^0`0VkP;09:i3@2E^0h0UkT?0:2i2`2Q/`X0W[L;09Zf
3P2J]A40X[0;09Zc302G`180V[XA09^j3@2N^``0VKP=09Zh3@2O^`l0XKP>09fj302N]`d0W;LA09fe
402L^@d0VL0=09[03`2I`0/0UL0:09302P2C_0d0U[h>0080UL0>02L0T/0;0970302D``d0T/0A092m
502>_1@0T[dF09?05`2B^aT0T[`I092l6`2A_a/0T<4K08o25`2<`aD0R<@D08O55026aaD0R/HG08k5
5`2:aAL0SL<I08g37028`R40Pl8V086l:P21^R`0QkXa08Vi=`27/Sl0PJQ2086W?P1iZ3h0N;<k07S3
>01jbb`0MlhV07S@8`1hcB800P1gbAl09`1dab40ML/T07G=7`1dcAd0L/dL06k?6P1_cQL0LllH07G?
6`1gd280M/lR06o>9P1dcb<0M=0N07G@6`1acR<0KLXZ06[8;@1`bR/0LL`]07?9;@1ebB`0N<@Y07C4
9P1ga2@0NLDQ07S78P1eba`0LLhJ06o<6P1ac1T0M=4C077D401id0h0M]4>07W@3`1dd0l0MM@>07KC
3@0207?D3`0W07;F4@1cfQH0L]LC07cD4026c180R<LL08c67P2<bal0QL`O08O;7P2;bQl0S<HU09;0
9`2A_BL0Ul<O09?37@2>aQh0T;dP09J]902DZBH0TJ8V08nP9`2@XR`0Sj<a08nS=@2>V3/0Pha9082=
CP2:V5D0T9YF09JKD02>TDh0TIM;09VLBP2>WT@0Pj8T07nH3@21S`<0Q8H00080Pgl002L0Og`007]b
001jLP00NWH007ii001oN`00Ng/007ag001iL`00N7<007I_001dI@00LVT007EZ001eKP00NW<007]f
001kNP00N7P0079k001dNP00LGD006e^001ZHP00IEd006MP001[JP00JG4006A]001QI@00G60005mM
001LFP00FeX005YM001LGP00H60005iN001KF0000P1KE`006P1KEP00EeD005I@001ECP00DTX004e4
001:@`00BT8004U50017@P00B40004Do0013>`00@3H003Xg000e;@00;RX002dV000Y8`008Qh001hI
000F40004@d000l;00081P000`<0B`00000<0?ooo`002P3oool0501II`40E64105AV001HIP00F6l2
05YZ0@1IJ`00GG0305Yd201HMPX0Egh=05Z64@1JS1@0FI<?05JA301EU0P0EI<605VA1P1HS`<0GHX1
0P1RQ`009`1QR@00Hh/00669001TQ000HhT005f:001MS@40FI4105^?0`1IT@P0FYD8066H0`1RV`40
IIP006BJ001TV@00IIP006VE0@1VV080IIL106NE0@1/U0<0Li<307ZF0@1jV000MJ0007:S001bYP00
M:@007BT0@1eYP80NJD107ZU001hY@00NJD107ZP0P1jY@80NZ@207ZZ000207V/000W07Z`0@1l[@40
O:`207VW0P1fZ@40M:P307NX201eZ0P0NJP207f[001nY`00P:T007f]0@1o[@00P:l0086b0021/@00
P;00086_0022/@00PK<007fb001k/000O;0007j_0022[P00QZl008Fd0023]000P[0008Fa0021/P00
P[0008F`0026[P00PK8008:d0021]`00P[X00080QKX001@0Q;T008Ri0@28^080R;H308Rn0P2;_@80
VKH<09jg302K]@`0U;@>09Rf4@2O/`l0X[H=09Vg302H]Ph0W;DB09n_502W[a80X;4=09jf3`80WkH@
0140X[H>09nf302P^@l0Y;DA0:Ne4@2V^0d0W[L<09^g3`2K]Q40WKH?09fj2`2H^`/0VL0<09Bl2@2A
_0`0Tk/?09Bm4@0209314@0W09;14@2D`180Sl8C08g36029`QT0Ql4H08S25P27a1H0RL<G08S45@27
aQ80QlTB08c64`2B`a40S/D@08c52`2:b0/0R/T;08g:2`2Ab@X0TLD;09362`2@aP`0SLD;08W83P26
a180QL<E08K66025a240P<0]082k=P21]3L0O;<h07Vf=@1j`S80N//[07S<901hcQh0M<`M0080L/XO
02L0L/XR07;99@1ebb80M<dQ07?>7@1`dQP0L=0G07;?601bcQ`0MlhM07C=8P1^cB/0KllS06kC801c
dad0Km0S077;9P1ZbBT0L/P/07G4;`1h`R`0M<P[07?;9`1cbAh0O<PH07g;5P1ic1P0M<hE073=501^
cQ@0L/l@07G@3`1hd@d0OM0=07_A3@1jd@`0M=@>06oG401[eQ400P1`eQ<09`1`fQL0L]XF07KF4`1n
dQ40QLlG08[;7P2;cAh0S<lL08SB6`2;dQ/0Rm0M09349`2C_2P0SklW09G46P2C`A`0S/<Q08nj902D
ZRH0Vj8X09RM:@2CVR`0T9X`096P<@2@Y3@0Ri`l08:<A@21TU00RiQD08RLE@29WDd0RYMA09NFB@2J
W3l0R:Tc08FV5@21V080P8h008>3000207mj000W07ed001hL@00NFl007Ud001mNP00O7P007ei001j
O000MgD007ei001jM@00MfX007E^001fK@00Lf/007Ia001lM`00O7/007Qj001gO@00MGX007=d001_
KP00J6@0069H001TF@00I6D006E^001RL@00Hf`005mQ001NH`00HF8005mO001NF@00G5d0061S001N
G@00GUT00080G5d001T0FEP0059D001CC@00DDd0051<001>A000C48004U1001:@@00Ad@004Lo0013
>`00?SD003Pc000g<@00;bP002LS000T80008Ad001/G000E4@003@`000X700071@000`4004`00000
303oool000X0oooo01@0FFL105AQ0@1DIP00F6H005Q_0P1JJP40FF/005e`0`1JM0P0F7H:05Mn3@1J
QQ40FX`D05VC3`1FT@`0EI@805FC1P1IT@H0F8l305f:0@80HXL002L0HHT006>;001QR@00I8@006>9
001MRP00GHd105VA0@1KS`<0FI4805ZE201QV0<0HY/106FH001TVP00I9T006FH001YU@40IYP206FG
0@1WU@40K9@307>C0`1jUP40NYP007FP001bX`00LZH007BT001dY040MJH207VU0@1jY@00N:D007VU
0@1jX080NZD207ZT0P1jZP000P1i[0009`1j/040O:d107b/0P1iY`80MZT107BX0`1gZ0P0MJP807VX
0P1mZ`00OZL0082Y001m[@40Ojd0082_0021/P00PK40082`0021[`00P[40086c001m/P00Nk0007b`
001n[`00PZh008J_0025]000Pk@008:`0025/@00PK8008:`0025/000QZh0086b0022]000PKL008:j
000208Fj000D08Bi0028^@40R;P208Rf0`28_P80Rkd209Vf302N]``0VkD<09Bd3P2H]Q40Wk<?0::f
3@2I]``0V;H>09be4P2O[a@0YjlB0:2a3@2N]Pl209nf400A0::f3P2O]P`0X;T?0:Be4@2W]A40Y[P=
09jg302K]`l0VkHA09ff3`2M^P/0V;/;09W0302D_0T0TK`<09>k3`2D_A400P2@`A409`2B`A40U<0B
08o24`2=`aP0RL8I08O16028`QH0Ql@F08W35`28a1D0QlHB08O94P2<aQ<0T/<A08k5402<a@/0R/P;
08[92`2=bP/0TLT:09752`2@aP/0T<H<08g52`29b0h0Q/@B08G35@26aQP0QL@Q0830;@20^cH0PK@g
07bc>01i]SD0N/8b07[;:`1hc2@0N<hN07C<7@0207;:7`0W07;:8P1bbBD0ML/R07C=8@1ccQd0L=8H
073@5`1bcaP0L/hL07O>7@1dcB80K/d[06o?8`1^db00Lm<M06o@8`1abbH0J/TY07;8;01ea2l0N<8/
07C8:`1cbbL0LlTN07c8601mbaH0NL`H07C>5@1`cA@0K/hD07;?401ed0l0N=4=07g@3@1kd@d0N]4<
07CD3P1_ea00JmHA0080L=HC02L0L=XG07;J5P1feQ<0O]8A08G?5`2:bah0RldN08c?7028dQ/0Rm8K
08_@7@2@a2L0Tk`X08no9`2Ea1X0Tl4L08k38@2?^R@0U:XV09^R:02HWBT0TiX/092J<02AX340T:@d
08^L?022S4D0PI9@08^HE028W5D0RIe=08ZGD@2GUTT0VY`o08RY<`25YQD0PIP2082>0023P`000P1o
NP009`1mM000N74007U_001iM000OGX007ah001mN@00NW`007Me001mN@00NWD007MZ001eKP00MVd0
07=[001fL@00O7L007ak001hNP00Mgd007Ej001cM000Kfh006QT001RF000I5T006AU001UKP00HW40
06=/001OH@00GV<0065R001OG`00GUT005aM001PH`00GUd005iI000205aM000I05UH001BE000Ddd0
055=001@C000CT@004a20019@@00BT4004M40017?`00@c/003he000h<`00=c4002lX000W8`009200
024M000K5`005A4000d<000:1`001`D000<1001<000000`0oooo000:0?ooo`0D055J001@FP00DU/0
05MJ001IH040EUl005EN001IJPP0F78;05Me2`1GQ0d0FXP@05RB4P1IU0l0EY@;05NH2@1FU0L0EHl4
05R<0`1JR04205j4000W05f6001LR000FXH005V30@1JR`40Ehh005B>001KT000G90205^B1`1IT@D0
GIL2062G001XU@00JY<006bD001[U000JID106RG0@1[U`80JiH206nD101bTP@0MiH107BJ001cX@40
LJ40076R001eYP00MZH107ZW0`1jYP<0NZH207JU0P1fZ0D0Nj<907VV201iZ0D0N:/20080Mj`102L0
MJd107V[0@1j[080NJ`107Z[001jZ040NZ/307VZ101kZ@80OJL007fZ001k[040OJl107b_0@1m/P00
O;H107nb0P1o/@80OZl007bb0022[P00PJl0082Z0022ZP00Oj/0082^0023/P00Q[@008>c0022/P00
QK4008J`0027[`00Qjh008N_0024/P00PkH008Nj0026^0000P2:]`009`2:^000S;X008bk002:]`00
QL0208Zm0P2@_0/0U[T<09Jo2`2C]0h0V;<B09na4@2Q]`l0WK/=09^e3`2L]180W;<E09nc5@2P/Ph0
WKD?09jd4P2M]180YkD?09nb3@2U/a80Y;4C0:>d3`2R]Pd0W;X<09Fk3P2E^Pl0VKLA09Rh402E^Ph0
UKd=09>k4@2A^Q00Sl0A08_3500209335@0W09?25@2A`aH0RLDF08C35@1oa1<0P<H@08G74024b0`0
RLL;08W72@2:b0T0RlP:08k52@2@a@X0TL<;09721P2>`P80SL440932102C`P<0U/8309K00`2B`P80
T<8408g22@2<_`X0Rkl;08W13027`a00Q<HD07o58`20a2/0O;/c07fn<`1k`C@0OLLZ07S;901fbad0
Ll`L0080L//N02L0LL/Q07?=8@1dbb80M</S07C:7@1_cQ80M<lB07G>4@1fcAD0L/`O07;=7P1bcR00
L/lO06_@8`1_dB80Km4S073?801]cal0K//X0737;`1bab`0L<XU07C;6P1gc1D0O</B07[=4P1gcAD0
M]0E07K@4`1ddA40L=0@07?@3`1ed@l0OLl=07[?2`1hdP`0LM<=06[H3`1XeaL00P1[fAd09`1beb40
M]LH07cF5P26dAL0P]4I08S@6@2<cad0RllK08c@702>da/0S=@L08g69P2?`2P0T<LP08o65`2=`1`0
SKhR08fh:`2AZS40V:8b09VO<@2AVBd0SiTa096N;`2=Xc40RJ@h08FJ@P23VT`0RY]B08ZKD`23Wdh0
SiY=09ZHC02IXCd0QZPK08NO4027U@40Phd008>0000207mf000607Q_001fJ`00MFh007Ya001gN000
NGP00P1kN0007`1lM`00OGl007ae001kL000NG0007M^001cJP00Lf`007Ma001gLP00MgD007ah001g
M@00M6l006m[001YIP00I5/005mE001SE@00Hf@006A]001RKP00GF<005aP001OI000Gf8005eJ001K
GP00GF0005YJ001KF`000P1LG000601FE@00DDl004e9001=AP00CDL004a40018?`00A3h004Ho0016
@000@3`003`g000g;`00=B/0038[000Z8`008Ah0020H000K5@004Q00010:000:1`001P<0008104d0
0000303oool000X0oooo01@0De/0055K001EFP00De@005AC001FF000EE/005Ue301IN`l0G80<05V6
2@1GR0T0F8P:05Z@201GU0T0F9L805V?1@1HQ`<0F88105Ql0080Fgh002L0GH4005^3001KQP40FhL2
05Z=0`1JS@40FHd005j:001RRP40GXl206>>0@1STP00IID006jA001`T@00LID006jK0@1]VP40KiX1
072L0P1`V@40LY@2076A0P1dUP40M9X007>N001aW`00LY`007BQ0@1iXP80NZ@507NU1`1hY0D0MjH3
07BW201hZ0`0N:L;07FW201dYP@00P1cZ0<09`1dZ080LjT207J[0@1hZ`00Oj/0082Z001n[P40OJh1
07b[0@20Z@40OjP007f[001n[P40O;8107^a0@1k]P<0NKD407jf0P1n]000P;<008B`0023ZP00Q:T0
08:Z001o[`40OK01082`0023/P00PK4008B_0027[`00Rjh008b`002</@00Sk@008^e0029]@00R[L0
092f0@0208ff000W08nh002?^@00TKL008jg002:^@40S;d508nm302A^0/0TK`:09:m302@^Q00U;DC
09Vi402L^0l0W[X>09Nk4@2F^QD0WKHG0:6e402P]100Wk@D09bd5P2U]Q<0X;8A09^d402I]Q00V;T?
09Jn3`2F`0h0T/0>092m3P2>^Pl0T;L@08ni502D`1H0Tl0C08o24`2=a1<0Ql<D0080SL@C00X0T<DA
08g74P28b100PlH:08772P23a`T0QLL808K62028aPL0Ql@50P2>``<06`2<a080Sl810972002D_000
TK`008g00P2=`@@0Tkd309G20@2I`@40V<8009?0002@`080S[/309:k1@2?_0T0Rl8<08c43@27aA<0
QLDL08339`1o`Bh0NL@`07K7:01ec200M/`M07C<7`02073>7P0W077<7`1_cah0L/`S07?98P1aaah0
LL`C07C<4@1fc100ML/E07;69@1_bb<0K/`P06g?801^d2H0K]0S06o?8P1beAX0L]DM077?9P1/cR`0
L/`T077=7P1gcAL0N=4D07c@5@1kd180O<lB07_>4P1kc`l0O=0>07GA4@1gd0l0M/h<07W>3@1ic``0
M]8:073C3P1^e180L=DI0080Lm@J02L0Mm<M083D6P23daT0Q]4I08GD6@29eQP0S=@H08gD6@2>daT0
Rm@G08gD6P2>aB@0TLDQ09C=602=aAL0RL0J08^l7P2;^b@0QkT^08Va<029ZS80QZ0^08RP;@2:XRd0
Pj@b08>Y=`25YD80Qim908JFD02;X5H0RJ9E09ZKC02FX4H0TJHa08>O5026T`L0QHl108B7001lP000
0P1mN`009`1iL@00MfT007EZ001cL@00M74007Id001iLP00Mg<007Ue001iM000Mg8007Q]001eK`00
LVh0071Z001`J`00LVX0075/001eK`00MG@007=c001bL000KV/006QQ001SE@00FT`005Q=001JD`00
G64005mZ001LH@00GF4005iQ001LF`00F5L005YE001HE000EU@005IE000205QH000G05MD001DC@00
CdL004Y10018A000BD8004Do0012?000@S/003hi000l<P00>34003@^000b:@00:bL002DN000M5P00
5a40018@000=2`002@T000L500020@00CP00000<0?ooo`002P3oool0501GH000E6H005EQ001EE`00
E5D005IL001HI@00Fg4205V52`1KQPP0G8L505Z10P1GQ040F8L205J<101DRPD0FhL305en0@1IO@00
Egd10P1IO0409`1KP040GH8105j50`1NR@D0GXX505f>0`1QR@40I8P006N8001/RP00KH/006RA001^
U@00LY<007FB001dU000LiP107:K0P1dW`40LYh1076L001aV000KiP0072K001bX@00LIh007:N001`
WP40Lj@307>R1@1dY@L0M:D907FR1`1eYP80LJL707FX2P1bY@P0L:<506nS1@0207:U100V076U0@1c
Y`80N:H007^W001lY@00OJH007nY0020Z`40PjP1082/0@1j[080Ojd307nZ0P1l[P40Nk8507Rc1`1h
]@@0OKH1082d0021/P00PZl008:/0022[@00PZ`107f^0P1m/040O[00082_001k/@00O[4008>a0027
/@40R[<108b`002@]000T;@108ff0P2=]@8308je0@0W08ng0@2>]`00T;H008ji002?^040T;X70930
2`2G^`d0U;P<08fi2`2?^@l0T;HB09Jk4@2K`0h0VkT@09Vi402H^140VKPB09ni4`2T]a80W[T@09fi
4P2S]AD0XKHD09Zd4@2D^0d0Uk`>09Ji402D^a00T<0@09303P2;`0h0R/0A08c04`2>`A@0S/<C0974
4`2<a1<0R/DB0080RlD=00/0S<L:08W62P25a`T0QLP908G72@2:aPL0Rl@508_3102=`P80R/8108c0
000208k0000J08o2002A`000U;`009:i002>_080SKh408nm1@2B`@@0UL@209G30@2B`@00TKh009Fm
002E_@40UKd209?2102A`@X0SL4>08W24025a1L0P<4S07S3;01gabP0ML/P07S=7P1ecAh207;>7`0W
077=801`cR40L</U06o;:01^bRH0Kl/O06k;6`1]cQL0L<lK07;;:P1^bBT0KlXU06o;9`1/d2X0Km0P
073A7@1fe1P0Mm@J07KC6`1edQh0NL`J07O>601icaP0Mm8H07c=5P1jcAT0M/lH07S@4@1kdP`0N<l=
07CD3`1gd@l0Lm0>07C>3P1kd@d0M]8=077G3`1cea@0M]HH0080NmHF02L0PmDH08OA6P2:dQl0RM4P
08WE7P28eB80SM<L08oD6P2:dQ/0RM<K08OA7P29cAl0T<`L09C=5P2>a1H0R/0H08bl702;^Qh0QkhW
08Fh9@22/bT0NZdY07fU:@1lYBT0NZLc07nW>@25YT<0Q9Y?08N@EP2<TU/0U9UK09fHB@2;Xd40PJDY
08:G3`26S@<0QXT00866001jP`000P1eO`007@1fN`00NG4007U_001fK`00MV`007M_001eL@00LVh0
07=X001cJ`00M6h007=[001aJP00KVX006eY001`JP00LFh006eX001^J`00L6T0071X001^IP00K6<0
06EM001PE000Ed`00554001BA000EUL00080Ff4000P0F5l005UJ001IE`00FUD005aC001DD000DD`0
051=0080DE4001L0Ee<005=?001?C000BD<004M10012?@00@S`0040i000k>@00>C@003@_000c;`00
<2/002XW000V7`007aL001D@000>2`002`P000L5000410000P800041001>000000`0oooo000:0?oo
o`0D05Q]001JK`00FFX005MT001GHP00Efl105Yd001LNP40HH<305j30P1KPP00FH4005N0001IP`00
Fh<105b20P1PO@00GGP005em001KO`4205an0P0W05j10`1PP0<0HXL206:8101UR@@0HXP306F90P1Y
RP40Jh`006Z7001^RP00Jhh006fD001aT@00Khl007>@001dT`40LiX2076J0@1^WP40KI`006^L001Z
W@00JIl006fN001`V`00LI`007:N0@1^X`@0L:H707BS1`1fY0L0LjD407>V0@1dY@80LJH4076Q0P1_
X040Kih20080Lj8200<0L:L207BV0P1hX@400P1kX@001@1mXP00NjH007bX0@1nZ080Nj/30080Mk45
01<0NZh407V]0`1g[`@0Mk0707Rc0`1j/P00O[80082c0021/@00O[4007ba001l[@40Ojl1086a0@24
[`00Qjh0086_0021/P00P[<10080Pk<100H0Rk4208je102?/0<0S[4908^c1`29]0@208Zd0P0W08bf
0@2>^040TKP108nh002B]`80TKX:09:h2`2I^180VKH@09Bf3`2D]Q40U;PB09^i5P2J^Q<0X;T@09Zh
3`2H`0h0U<0@09Vh4P2P]AD0WkTB09nm3`2L^a40V[/@09Rh4`2G^@h0V[T>09S04P2E`180T<4B08[1
3`26`a80Q/<A08W64P2<aQ00SLP>08o6302<aP/0RL@:0080Q/H802L0Pl4807o42023aPP0Q<L908W5
2P2>`P<0S/400931002=`@00Rl<008_4002<_`00S;d008k0002C`@00Tl0109:n0@2?_@00SKl208g0
0P2<_`40T/0109K40@2Ea000U/8009;4002D`P00T<8009;2002A`P80TL0408[03026`Ph0P/HH07W5
:`1fbBX0N</V07W<8P1fc2800P1bbb809`1`bbH0M<XV06o::P1/bRh0K</X06_<7`1XcAd0J/hK073?
6P1bc1h0L<TM07G;7@1acb80K]4W07;B6`1dd1H0MM<B07GD401ida00N=0@083=3P1ncP`0OLl@07gC
4`1jd140M/l@07G?401ed`l0Lm<<07?D301ce0l0M]0?07?>3P1ed0d0Nll@07[B3P1heQ00O=LB07_F
600208?G500W08OD6@28dQd0Qm4P08WB9@29dBL0RMDU08[E6P2=e1T0R=8K08G>7`26cB<0RM0J08cA
5@2?c1P0RlLF08W6602;`AL0S/0L08_07P29_A`0Q;/N086k8`1j]RP0N:h^07VZ>01oZ4D0RYe;08nA
E@2>S5X0TXeI09F>F02MUe00QjPd07nQ5P25U@P0QHd008B:0021Q@00OX800080OGl000P0NW`007ae
001nM@00NG@007=]001dJ@00LfP0075[0080KVH001d0KVd0075]001_J`00K6X0075X001_KP00KVX0
06iY001YJ@00IV8006QQ001WG@00HeL0065F001LD@00F4d00514001;?000CDT005AE001BF@00DeL0
05IG001HF@00FEL005IF001CC`00DTd004i:000204e<000D04i?001?C000C4X004I1000n>@00?SD0
03/c000l=000>C<003@`000`;000<2P002XT000T7P007aD001D?000?2`002@H000@30002001A0000
00`0oooo000:0?ooo`0D05Aj0@1FN`40EW8005Q[001GK@00Eg4005Ui001IO@00GH4005]m001GO000
FGh105Mn001HP`00G88105j00@1QO@40GG`005am001LO`4205n00@0W065o0P1SO@80I88106N80P1V
Q`@0JHL406^70`1VR@80J8`006V;001/SP00JHd006^A0@1/S000L8T00769001aR000LI4106n@001]
TP00JI/006FJ001UW@00J9l006fO001aVP00MY/007NL0@1dW@@0Lj<907FS1P1dY@80MJ@007BS001e
X000MZ0007:P001`XP00LJ400080Lj8102L0MJD107JR0P1fX@80MYl107RT001iXP00NZD107^V0`1i
Z@H0MJ`507>]0`1g/080NJd207J[0P1d[@<0Mjd207V]0@1g/000MK0007^b0@1l/P80M[@207Nc0@1j
[`00OK0008:^0025/P00Q;<007nd001o]@00PKL008Ng0@29]P40R[D308Rd202</@H0RZd408B^1P28
/P@00P29]0809`2=^080RkD308fg0P2<^@40S[L3096g2`2A]P/0UKDA09Vd4P2I]A80VKHB09Vi4@2I
^Q40V[/A09bk4`2H`180UL0?09C03`2D`180Ul0E09W04`2L`140Ukd@09Bl3`2F^A40VKXA09Vn4P2E
`180Sl0A08c34`29`a80RlH?08c63`29b0/0R<D:08W62027a`T0Pl@80873200208321`0W07o21`22
``L0Q<<808K51`29a0H0SKl208g00@2;`P00R/@108c2002=`000S[d008k1002=``00T<4109;00P2C
`080S/4008^o002;_P00TKd009Jo002E``00Tl8008o3002;a@00S<H008g4002>`@00Tl4009K2002D
_`D0R/4>08?84@1hcB@0M<dS07G=9@1ec1l0L//M0080L<`U02L0M<`W06o<9P1]c2T0JL`Z06[<9P1X
c1h0I/dO06K?8@1^d1T0Lm0G07K>5`1hca/0N=4M07;B801cdaT0L]8E07CA4@1bd0l0M]4A07OB4P1l
d@h0N]8<07gC3P1lda40O=<=07_B301ld@`0M]H<077G301_ePh0L]@?07K@3@1dd0d0Mm0;07S@301l
e@d0O]D>07kE4P20eQL00P26eAP09`25e1`0QMDP08K@9`27dBP0RM4X08OE8`27eAd0R=<K08OB7`28
dB@0Q<dV08GA6`29caX0R/dO08[;6@2:aAD0R/<H08[06@2:_aL0S;dF08Zl5P25_A/0Ok`V07^h>@1m
[440OJA;08NGDP2<TE`0S99O09:GE02ITU<0WY=A08^Y9`21V180QXh408V<0025R000PX@0081o0002
07el000707ej0020M`00OgX007Uf001dKP00LVT006eT000206iW0007071X001_J`00L6`0071/001_
J@00LfT0075`0002071/000E06eX001UHP00IEd005iK001KD@00F4l005M?001BB@00BD0003ld000l
<`00ACd004Y8001<B000CDh005=C001CE@00EU8005A>001?B`00BDL00080B4L001<0Ad@004U30017
@000@CX003Xc000i<P00=c0003D]000d;P00<2d002hX000Z90008R0001lG000E4@003@/000L40003
0P000P0005800000303oool000X0oooo01@0DWX305Ag0P1FKP00EfX005I/001HL000FgP005Yj0@1I
OP80EWX405Il1P1FP`L0EXH505V50`1LS@D0GHT505f8101NQ@80GH8105n10080HWd002L0IG`106Eo
0@1WP000JhL106^40P1_Q040KhD106b;0@1/S`00JXl006^D001XT000J8`006Z:001YQ@00KHL006^8
001^S000Kh/006f?001]UP00JiD006RH001WV000K9X006fJ001_U000LYP007FG0P1fW0D0M9l307FQ
0@1aX000LYh007FJ0@1fV@40MIh107>S0@1dXP400P1cY0009`1dY@00MJ<207FS0`1fXP80NZ4107bS
0@1gZ@<0MZT407>Z101cZ@<0NJ/207^[0@1mZ@40NjL107VY0@1kZ`40Njd007f]001k[000NZ`207Z_
1@1i/0@0Mk8207Va0@1j[`00PK<008:e0021]P40P[H3086f1@20^080QKL008Fe0028]@80Q[<508Ra
1@27[`<0RJl208Fa0@0208Rc0@0W08^e0@2=]080SKP2092g0`2?]`L0S;h:092e2P2B`100Ul0B09Rj
4`2K`180W<0A09Nk4@2F^AD0Uk`H09Nn5`2G_Q<0U;hA09>n4`2B`180Tl0A09C04P2@`Q40Rl0@08c0
402?`100R/4B08O24P26`a00Q/D=08S72`2=aPX0S<D;08S72@24a`L0QLT608760`21``80Pl<700<0
Q<8802H0QL<808;42@23a0@0RL<508_31P2:a@@0R/H708O81@2;a040S;l008g1002>`000S<000931
0@2D`080Tl8108o3002B``40Tl00096n002C_000U<0009K1002E`000T/<00971002@`@00S/0008k2
002Aa000TL@408o42`25b0d0N</H07?<701ccAl0MLdL07;<7080Kl`N02L0L<hN07?<7@1`bb<0JldU
06_<9P1ZcB80JldR06_?9P1^da`0LM8H07SA5@1gdQP0Mm@J07KB6`1edaX0M=@I07SD4@1gd@h0O=<?
07_E4P1leA00NmD>07[F3`1geQ00NmH>07_F3@1ke@d0M]D=073D3`1_d`l0L=<B07GF4@1gf0h0N=H<
07KD3P1iePh0NmD@083C4024e1800P27eAH09`26daX0Qm@S08S?:P29d2`0QM8Y08CH8@22eal0P]DP
08GB8P25dR@0QM4S08WC7@29dQP0RL/K08S75P28`Pl0R/0B08Nl4P28^a<0RkXD08Vl5`28_AT0QK/X
086`?025[4L0Oim@07^DF01nTU`0PYYN09BKC`2EWD/0TI]108bP6024T0T0Q8P208F;0024R`00Ph00
07ak000207ag000:07Uj001lM`00Ng`007Yh001iL@00M6d006iW001^IP00LFD007=[0080LVh001/0
Kf`0079[001_K000LFl0079`001aK@00LVh006]U001UIP00HE/005YF001DC@00CdD004M10010<P00
=bH002lP000g:000>c@0044l0016@`00AdT004]8001<BP00CT`004Y80018@`000P16@`004P13@@00
@SX003hi000m=@00>c8003Ha000c;000;bP002`T000Y8P0091d0020F000I50004Pl000/;00081@00
0`80004005<00000303oool000X0oooo01@0Cf/105A[0@1FIP00Ef8005EX001IK000FW8005Ic0@1B
M@H0D7/904ml2P1@QPd0DXL905J81P1KTPH0F9@605R?1P1KS0@0FhL206610080Hg`000@0IG`006=n
001WPP00K8@00P1/PP008@1_Q@00KhP006f<001ZS@00J90006B?001PR`00HXX006><001TS@00IHd0
06J<001]S000KXh006jD001`T000KY8006f?001`SP00LY@007:C001dV000LYH007>H0@1aUP40LI`0
06bN001^WP80Kih6076O201bW`H0LYd507>M1@0207>O100W07FP0@1dX@80MjD407NS0@1eY040N:H2
07B/1P1b[`@0Kjl207:_0`1g[P<0Njd3082Y0@21Z@00Oj`007^/001oZP00P:/008:X001oZ080OZ/5
07b^101k/`80O:l107j`0@22/`40PK@0086d0@21]@P0PKH9082g1022]@00P[@008>g0`23]040Q[42
08^`0P29/@40Qk000080PK<00140QK<008Zd0@2=]P40TkP308nh2`2<^PX0S<0;08jm2`2@_A00T;hB
09Jn4P2M`1<0V[dC09;04P2?_a@0SkhF09:k4`0209?04`0D09?14`2D`140SL4B08_44@27a100QL<>
08G53023a@`0P/<<0831201o`PP0PlH708O52@27a`P0Q<L808?81`24b0L0QLD408;40`25`@D208W1
1P0W08g31@2<``H0R<0408_30@29a0@0R/H508_51@27b0T0Q/T808[70P2;a@40QlD008S4002=`@00
T;h009:m002B`000Sl000930002@`@00Rl8008o00@2D_040VL0009C1002E`040U<4209;30@2?``00
R<H008c8002=aP<0SLH708S82`1nb1<0M/XJ07G;8`1ecAl0LLdL0080K<hK02L0KlhI07?@601`cAd0
KldL06k?7`1^d240Km0O077@801be1d0LMHK07KF4`1ida80Mm<A07KB4P1jdAD0N]@K07[E4P1kdPl0
OMDA07gF4P1mf1@0NmDC07_F401geQ00MmD?07WG3@1he`h0M]H>077D4`1_daD0L]@C07_H4P1kf140
N]P?07SH4P1le@l0O=<>08CB3P29dQ000P29e1P09`23dQd0Qm8U08[@;@26dc00Q=DZ08?H8P22eR00
PmDR08;C8@25db00Q=8P08WA6`28cQD0SLP>08[43`29_a00Qk`?08Ni3`27/Q00Q[8A08Vg6@24^al0
P[/]07f]A@20YTh0P:5G07bIF`20UEh0PimG09:KC@2<XDL0O:0_08RM4P24SP40PX/008B:0023Q000
PGX007Qd000207Ed000L07Mg001gN000NWP007Yl001fM@00Lfd0075]001^I000Kf@0071Z001dK000
LW8006i`001aKP00Lg00075_001`K`00KV/006eW001]J@00JFX006ES001MFP00EE<004U20013>000
>Bh002lQ00808aL000T0:R0003H]000l=`00@Sd0044l0011?@00@4@0040n0013?P000P11?`004@12
?@00?cT003Td000f<@00=2d002l]000_9`009b8002@M000P5P006180018=000<2`002PP000L40003
0@000@0005@00000303oool000X0oooo01@0Ce`0055L001@E`00D5@005EM001HI000F6d605I]2@1C
N0/0Cgd:04en301>P@d0DXX;05R<201GT0L0F8l505b:0`1MR`<0H8H106:10080I7l002L0IGd006Al
001WOP00K8D006R3001VO`00JXD006^5001YR@00HX/005n;001PR`00Fh`005b<001MSP40GHd005f>
001NS000IH`006J?001WT`00Ji8006R=001/R`00LHP0076@001dT@40MYH207BG0@1cVP40M9P0076G
001[X@00K:4206ZQ201[X@X0JY`806fI201aW@T00P1fW@X09`1gWPD0MId307VP0P1hW`40M:4107>W
0`1bZ0<0KZ/306f^0@1^[0<0MZd307R^0P20[`40PZh0082[0@1oZ@40PJX008FZ0027YP00PJX107j]
0P1n/@40Ok41082b0@22/`00Ok82082b0P21]0<0PkH608Je1`23]@<0P;D008>c0@24/040Qk4108^a
0`2</0@0Rk@208Nd000208Zb000W08^b002=/@00T;81096e0@2@]`/0SKT:08k02P2;`0/0Rl0>08g0
402@`140U<0C09Bo502A`100S[h?08fn3`2<_Q00T;h@09C04P2?`Q40Sl8?08c44027a`h0QLH=0875
2P21``T0P/H808?32@24``P0P/@808742021aPP0P<L907k81`21aPH0Q/@408C10`20`@D0OL840080
Pl0202L0QlD00931002C`@00TL@008_40@27a`40QLH208G71@28b@D0R/T308_90`25b@<0PLP208O4
0@2:a000SL<108o20@2<a040S/<008o5002=a@80SL<208k20P2>`040Tl4009:n0P2A`0<0SL4208_4
0@25a000P/@108?60@27a040Q<T907_;401ga200ML<Z07C8901`bb000P1_cAl09`1^cR40K/lR077?
7@1bcQT0KllH073A8@1adB40L]4L077E601ae1/0L]LF07OE501ieA40MmDF07SC6P1heAd0O=PE07gE
4P1gea<0MMHC07[G5@1jf1L0MmDC07GC4@1geA00NML@07SI401ff1<0L=TK073G6P1ceaP0N]LF07cI
5`1lfAH0N]XG083G3`22e0d0Qm8=08SC4@0208KA600W08GB6`26eR40QmLZ08GF:`24eBH0P]HR08;E
8`21e2D0PmDR08;C7P21cR40RL`J08[;502>aQ00RL<?08O04026^`h0Q[P>08Nc3@27/0l0Q;@F086j
8P1o^c40Nk5707ZWEP1mXEX0OYeM086IG028WE@0TiQ?08bQ>`1iX1/0PIH>086A0023T@00OhX00862
001hM`00MG400080M70002L0Lg40075a001cM000MGD007Ea001bK`00M6/0071W001_H`00LV/007=^
001aL@00K6h0071`001`L@00L7D007=_001/I`00JV<006ER001WI000I5l0061L001GD`00BT80044l
000i;P00:Ad001/>000?2@0050/002@F000_9`00=C<003Lf000h=@00=SL003Te000j<`000P0i=000
3`0j<`00>c<003<a000b:@00;BD002PQ000R7@007AL001T@000D3@003PX000X800081P0010@00080
001F000000`0oooo000:0?ooo`0D04aC001<E000CU<0055A001EF@40F5h305=U1@1DMPl0CWL<051i
201AN@P0DWl905692`1DR`/0EHH<05V82@1MP`D0GH4205ao0@1ONP4205mi000W061j001QNP00IH00
06F1001RO`40Gg/105j00@1NP@00FWl005^5001KQ`00Fh`005b<001KR@00Fh`005f:001PR000GH<0
06B3001WR@00IHh006J>0@1UR`00JhX1072:001bTP40Li@207:I101`VP<0L9X207>L0P1dW040L:80
06jR0@1_X@@0KYd506nG101bU@<0LiP60080MIP800h0LIT807NL101fW@40Mid1076Q0P1eZ080MJL1
07>Z0P1fZ`00M:T107N[0P1k[P40OZd1086[0080PJ/100l0PjT108FZ0024[000PK0007n_001o/@00
Ok8007fb001m]040O[H4082c1@20]@80Q;H308Bc0`25/`800P24/0401P25[`40RZh108bb1`2@/`P0
Rk@308^b0@80S;8002L0S[D008fe002>]000S[D008ne002>`0X0S<0;08O02P26_@d0Q<0=08o04P2A
_a40SKlC08bl4@2@_Pl0S<0>08W0402=`Q40T<8B08c3402;``l0RLL<08S62@28a0P0QL<808G22@28
a0T0Ql<908G22P29a@P0R<D908[32P25`PT0P/8707o21`22`PL0Q/4508?51@20a`@00P20aP809`25
``00S/8009?2002Aa@00TL<008g4002:a000RlD108g50P2>a`<0SLT308g80`28aPD0Q/L208G70@28
b080R/P608_81P2?a040S<D108_80@2:aP40R/8108W2002>`P00T[d108nm0@2=_`40R/0008W40@24
a@<0PlD308?50P22aPX0P</?07S87`1c`S80MLT]07?;;@0206k@:P0W06c@:01[dBH0K]0S07;@701c
dA/0LM4S07;B8@1bdQP0LMDG077D6`1deQH0N=@A07KF5P1bdad0L=@P073D7`1geQH0O=DE07[D4`1g
e1<0NmDD07OI5@1feA80MM@C07SF4@1ifa40N=XC07?K6@1_fb80L]XR07?I7@1kf1/0OmLL08?G6026
fAX0R=PB08OG3P27d`d0R]<A0080Q]8G02L0QM@L08OH8029f2<0QM@T08CE8`23eB40PM@V087D:@21
e2D0PM4Q08G=8P2:baD0S<dD08_:4028a140Ql<A08Nn3`27^`h0R;L=08Rd3`25^AD0P;/T07fm=@1j
]TP0M:]J07ZQFP1nWU/0RiaF09>HD@2?V4l0RZ@`07nJ4@22T0@0PY40086>0021RP00OWl007Mb001a
LP000P1aK`009`1cK000L6/006m_001^KP00LV/007=Z001dK@00L6P0075S001aIP00M6X006i[001[
J000JFh006][001`L000LFd006e[001[HP00HU/005eD001MEP00GE/005QA001@BP00ACl003H_000V
7`0050T000L000060@003PH001`C000[9@00<Rh003<a000c<`00<Rh0034U0002034X000:02h[000`
:000:RH002PO000T70007A@001D@000A3@003`H000T400801@@000<00`80004100000000EP00000<
0?ooo`002P3oool03P1:C`00Be8004]@001;D000EEH104mL1`1=H`X0CGPA04ed2`1@K0@0E7<4051i
201@Q@T0DhP>0P1CQ@l0101FO0H0FWX305]g0P1IL`8205]d000P05eg001ON`00GH4005f30@1MP080
EGX205Al0P1BO@80DGl205R30@1IQ000FHT005V6001KPP00G8L006:7001TPP00HGd006Ii001TOP00
J8<006V70`1ZQ`40KH`206n=001`U`80LIL2076C101bV0@0LI/207BN0P1eW@4207JN000507NQ001g
V`00MYD007RD001eU@400P1eVP<0201cV@D0LYh5076K0P1bW040MYh207RR0`1iX`40NjH10P1mY`00
7@1nZ000PJ`107f^0`1n[@<0OZX3082X1022Z@40PZd0086_001n]@00Pk<008:a001o/@00P;@007ne
0@22/@80P[83086f0@23]000QKH108Ba0@28[000RZ`108f[0@28[`80R[4508Zd1P2;]0D0Rk<30080
S;8102L0SK8108Zd0@2=]000S[<008ng002=`0T0R;X908C02P22_Pd0QKd>08^m4@2=_A00S[lA08g0
3`2>`@l0RL<@08O34028a100Rl@<08W32`28a0X0Q/@908S12@29`@P0Ql8908K42@2:a0T0Q/<808C1
2025`PP0Q/<808O02027`0T0Pl080832201o`@P0QL0708W5102;a@@00P29a@<09`26aP<0RlL108[8
0@2=aP40T<@108c30@29a040RLD108W80@29b@D0RLX308c70P2:b080QlX208G:0P25bP<0QLX608K6
1P24aP40QlL108W90@27a`40QLD108O30@29`P00Rl4008o0002<`000R/8208c30`29a`L0R<P808G9
2024b0T0PL`=07W;701ebc00L/l`077>;`02073@9P0W06k@9P1/d2@0K=0R06kA8@1^dR40Km<U07;E
8@1cca/0L=<G07;E6@1heAH0NM<D07SE5@1aeQ/0K]PK06gG5P1cda@0N=@E07[E5P1gdaH0N=LD07CH
5@1deAL0K]<I07;F5@1cfQ<0M=/F073I7`1^fb<0L]TO07OJ701oeAP0Qm@J08SB6@2=ea/0RmDG08OE
4@28da00RM<B0080Qm<H02L0Q=<K08KD6`26e1P0P]@K087D7`21dR80Pm@T087H9022eRD0Om@T08?A
7P29cA@0RLXF08G95@1nbQ80O/PA08354@27`100Q[d>08Jk4025_Q@0PK`Z07Zm?01h]DP0MZaE07RT
FP1lXET0Sim@09RJB@28X4H0Q:HV086J2@24T@40PXd00869001oPP00NG/007Ab001aK0000P1`J`00
9`1aJ@00L6T006eY001^K000KV@007=W001eK@00L6`0071Z001^I000Kf8006iX001]J@00IfL006MT
001XH@00JF@006UU001XHP00HET005U>001JC@00FE@0055=001=B000ACd003@`000W70004@/000<1
00010000100000d7000M4`00:R<002hZ000^:`00:bD002PR000202LO000:02<M000R7`008AT001dH
000G4P004Ph000h600081@001P8000<100800P4000<00@40000000000000EP00000<0?ooo`002P3o
ool0501:D@00C50004aA001=CP00CEH104iK101<HPH0Bg4804a^101@J@<0DFd404mc1`1@OPL0DX47
05Eo201HO`L0F7L305Qb0`1JL0@0FVd20P1HL0409`1HLP00EWD005Em001?O@80CG`504Yj1P1:N0D0
CG`7055o1`1GP0@0FWd105eh001SN`00HWP006El001VP@00J8@006El001UN@00JX8106Z40@1_Q`@0
KH`3076E0P1aU000LID107FI0@1dUP<0LY/3076K0P1cW000LiT007VG001lU`00Ni<007^D001jU@00
MiT007FH000207FJ0@0W07FJ101dV0H0M9L4076L0P1eVP<0Nj0407ZP0@1lY000NZH007jU001oZ000
OJd207V_1P1h/0L0NJh507^[0`21[@40PZh008:b0@22]@40Pk8108F_0029Z`40QZd108B[0P25[@80
QZ/108B]0024[`00QJh008NY002=Z000S:@108f[0P28Z`<0QZ`208Vb0`27]@P0RK<80080Q[8501X0
S;D408Zc0P2:^000R[L108^f0@2:^@L0R;/808Nn2P22^PT0Q/0:08o0402B`0l0T<8?08g1402@`100
S/0>08c53@29a@/0R/D908K52@25a0T0PlD908S32@28a0P0P/H908?52080Ql<500/0Q/4608G52027
aPD0R<@408S12@25`0T0OL8707_21@23a@<0S/<209730P0208k20`0W08[40`29aP<0QlP308O80P2:
aP40R/D108K60@22aP40QlX108W:1@2;bP80S/H008W80025a`40PlX308G:1@23b0<0PlH308G50`28
b0D0QLX208C80P23a`<0QLT208W80@2:b040S/D308o61@2BaPX0U<H<09C82P2>b`/0R/d:08K>3025
d0`0PM0F07W@:01dd2T0L]</0080Lm0Y0140L/hW06o>8@1ZdB80J]0S06[B8@1]db80LM8S07O>8`1f
dQh0MmHJ07KE5P1heA@0M]PE07CF7P1ce1T0LMDD07KF4P0207OG500D07KH5P1df1<0LMTD06kG5P1_
eQT0L]TF07?L501afQD0LMTE077K601kfQL0P]TB08WG502=eaP0RmHL08gH6P2<eAP0S=@C08cE4P2=
da8208WC4`0W08KE4P25eQH0P=<F083?6@1nbB00Pm0P087C8P22eb80P=PX087D9`24cR<0R<TG08K6
5`20aAP0P<LF07c;601mbQX0PlHF08G03P24`140P<8H07k0;@1k_4@0M;U;07>dDP1f[U`0NJ=H08fK
E@2GVTd0PZE208>Z7`22V0H0PX`008:8001lPP00Nh<007Uj001bM000L6X00080JVL002L0KF<0071/
001bK000KVH006aT001_I`00L6H006mX001`J`00K6D006US001ZI@00JfH006MV001VH`00I5l006EO
001UH@00IV00065L001LE@00FDh0055;001<A@00Ad0003hg000b:0008QL000h900030@0000000040
00060P003`P001XB000P6P0081`001hH000L5@000P0I3`002P0F40005a4001D@000A2`003@L000H3
00030P000P4000400002001K000000`0oooo000:0?ooo`0D04MF001<DP00Cdl004e=001=C`00D5/1
04iQ0@1=J`80Bf/404YW1@1;K0L0CG<8059h1P1EO@80FGX105Yj0P1LM@40EW0105IZ0P1BJP82059_
000S04ma001?L`00C7P004]h0P1>N`@0BWX604mj201DOPX0F88:05^0101QNP40IGP006Ue001XK`00
J7D006Qj001WO`00Jh0006Un001ZP`40KhL206nC101[V@@0KIX2072J001]V000L9X107>H0@1cVP40
LIT0072J001aVP00Mi4007VB001eS@000P1hT`00:`1fU`00LiT007FM0P1eW@80LY`407>L101fU`80
N9P107^K0P1hV`80NJ8207NU001lZ000NjT007f/001g[040MK8407Nd101g[`80N:l107j`0021[P40
PK4207nb0`1o/@80Q;0008J]0P20[0D0O:X9086[1`23Z080QJT008NX0028Z@00Qj/008V[0@2;Z`<0
SZX308VZ0P27[@40Q[0108Nb1@25]0L00P27/0L04`2:/0D0S;4208jc0@2;]080RkH108fj1P2;]`T0
Rk`908Jk2@2:`0X0Sl0;096o2`2B_`/0T<0;08no302?_@X0S<0:08S22@29`@P00P24``P04P24aPP0
Q<D808G61022a@80Q<H108C50@24`P<0Ql8308[10@29a@40Rl4108_01@28`PD0P/8208730P28a@40
S/@108k10@80R/4102L0Rl8308S71@2:b0D0R/L208_70@2=aP40QLL008?90026b040R/L108k50@2B
`P00RlD008W80`2:aPH0R/P908O92P26bPT0Rl/808W;2P25b`T0Q<`9087>2022c@P0Qlh808k>2@2B
cPX0U<h;09K<302Ec0d0U</@097;4`2?bA<0SLX@08W>2`25cQ<0P=4L07W@8P1gdB/00P1fcRH09`1d
c2D0L<lR06cA8P1/dB40JM4P06WB701^dQd0Km4L07KD6`1cf1H0MMDB07KE4P1hea<0N=@H07?F5@1_
eQH0L]@E07CF5@1gf1D0KmXF06kG5P1/e1P0KmLE06oI5P1bfQ@0M]XB07KJ401jea00PmL?08[I3P2=
fA00RmHG08WF6P2;e1/0S]@L08kB8P2>dQT0SmDE08oB300208_B2P0W08WD3@28e1D0Om<B07g@5`1m
cB00Om8O08;D8023eb00P=LX07oC:`1mcBD0O//I07k85P1maAT0Nl<L07g67`1nbal0PLXL08?45@20
aa/0N/8X07Rn>`1h_D/0M;]=07>iC`1c[eP0MZAG08BLF@2AVE<0PJXl08:W6@21VP@0P8/007j5001l
Q000NXH007Z2001iOP00M7800080KVH000h0KFD0071[001`KP00K6`006i^001]K@00KVL006]O001Z
H000JV@006YP001WG`00J6@006QP0080IfH000d0I5l0065M001PG`00H5/005eI001ID@00DT`004a7
0014?@00>CH002`U000I4@002`H000<0000000L00P0000D2000:1@003`P0010:000=20002`D00080
2PD000H02@@000P4000810001P8000810001001O000000`0oooo000:0?ooo`0D04UC001:D000BU40
04YD001<E`00D60004iV001:J0@0Bg8;04I^201=KPH0DW0505Ic0`1IM@40GGP005]f001JL`00Dg01
059_0P1AL08204ma0@0W055e0@1>M`40Cg/204if0P1AN0<0Eg`405am1@1NOPL0IH0506Im0P1[N`00
KWT0071j001]M@00K7P006al001]P`00Jh@006^5001ZR@40KX/106jD0@1_W@40KIl106jM001^V@00
L9X0076E001bV000KiL006fE001cU@00M9<007FA001bT`00MIL007JC001eUP00LIX00080Ki`102L0
KYT106nK0@1cV`00M9/007RP0@1kX`40N:H107JX001hZ`00N:h007R/001gZ`00Nk4107Za0@1j[P40
NZ`007f/0@21[040Q:/207n/0P1oZP80PjX0086/0P1l[`D0Mk4907ZZ1`1oYP80PZP008>X0023YP00
RJ/008b`0P2<[@@0SZd308R]0@2<[P40Rj`008b/0@29/@800P2:[`809`29[@80SJ/108na0@2</`80
RkD108Zh0@2<]`D0S[/908g02P2?`0X0S[l:08jo202>`0T0S/0608k02P2<`0X0Rkl;08S02029`@P0
R<4908[02@2:a0T0Rl<908W51@28aP<0R/@208K70P22a@<0Ol8208;40@21aP00R<H208g40`2:``<0
RL@308O40`27a@<0R<H208K60@0208C50@0W08K71026b@L0R<X808S:1@25b@40RLT408[81`2:b@T0
RL/908W8202=b0T0TLL:09?82P2BbP/0T<X=09373@28b0d0RLX>08k;3@2?b`d0RlX?08W<302;c@/0
S<d;08o<2`2Bc@`0VLh;09[>302Gc@`0U</>09C:3P2Eba80SlPA08g8402:bPh0Q<hF083?701kd1d0
N=0R0080MlhQ02L0MLhR07C?801cd1l0Km4Q06oB701]daP0K]@F06cE5P1]eaL0K=LG077G501_eQ@0
LmHC07CE501be1H0K=DL06oE6P1_eQT0LmLK06kH8@1_eR00KMTO06gH7@1`faL0MMX@07gF3@20e`h0
R=P=08oG2`2CeP`0TMPA08gF5@2:eQ/0SM@O08gE8`2<e2D0T=<S097F702?e@d00P2?d@/09`2?dP/0
R]0<08?D3@1oe1@0P<hN07oE8P20eR@0P=HU083F:`1md2h0O<dX07k;601lb180O<<C07Jo7@1m`B<0
P<XN08?:7P22bAh0NlLZ07G5>P1e^dP0M;E@07:gE01a]e80M;=H07BTEP1nWEH0QiaC07j`<P25Z1D0
Q9@507j5001kP000O8<007b5001kQP00O80007Ue000206i/000M06eZ001_I`00KVX006mZ001`K`00
KVh006YX001[H@00Ied006UP001WI@00Iel006EK001QE`00I68006=S001RF`00GeP005eJ001LFP00
F58005E:001=AP00B4L00490000g<P00:20001D;00070`0010000000100100000P40008100030@02
0040008000000P01001S000000`0oooo000:0?ooo`0D04UC0018DP00Ae@004EE0018G000B6H004aV
0@19JPH0Ag@=04A^2@19J`@0DFl205Ib0@1JM`00FgL005Mh0@1FM`80DWD105El0`1DO08205=j0@0O
05B00@1EP080EGd305An0`1GO080GG`206Em0@1VO@80JWl106io001_PP00L8000762001_PP00K840
06f3001^Q@00KXX006Z<0@1US080Ihl206^C0@1]V`00KIP006jH001`U@00KIH006bH001^U`00L9@0
072@000206n@000606^B0@1]V@00LiX0076B001]S`00KI@00P1YUP009`1/U`00KIH006jK001bX000
M:H007:V001fY`00M:H007JX001hY`00N:T007VY001j[040Nk0207Z`0@1kZ@40P:L107fY0`1oY040
OJH007nY0@20YP00Oj/007b]0P1m/0<0OJ`407jY0P20Z@40PJL108JW0@26ZP00QZX108Z^0P2>Z`<0
R:P208Z`0@2<[@00SJ/008bZ000208RZ000W08RV002>Z000TZ`108j`0@2</P40RKH108Vg0@2;^P40
S;d808_02P2:`0X0SL0:08c02@2:`0D0S<4708[02@28`PL0RLD408O31025``<0R<0308o11`2>`0P0
R/@808W42@29`@P0Ql4408C10`20`@80P<<108340@21a@80Q<H408_71@2:aPH0Q/P608O90`24b080
OlT40080P</602L0Pl`808?>2024c@P0P/h808C?2@26c@T0R//:08o:3P2<b`d0SlX<09C73@2GbPh0
VL/<09c:302Kb0d0TLX=08K94@26aa40R/DC08g34P2AaA<0T<L@0978402EbP`0UlT=09S9302Mb@/0
X<X<0:3;302Qb@d0VlT=09W<2`2Ic0`0T//<08_=3@21ca80N/lI07C>7P1bcB800P1acb809`1ccb40
LLdP07S>801ed1`0MM8I07CF4P1de180KmHA077F4P1_f1@0L]TD073H5P1`f1L0LMHF06oF601]eQ/0
KmPH077G601`f1d0L=TP07;G7`1dea/0NMPG07kK4024f@l0R=<:08[G2P2=eP/0SMH<08oG3P2=eQ<0
RmDK08gH7`2;eB80R=<S08[B8P2=dRD0Rm@R08gE4`0208oA2`0W08kA2@29d0/0R=0=08CB5020db40
P]@U08;F:P20eRh0PM<_07_B<`1idB`0N/dK07S85P1iaQD0M/DM07_69@1nbAh0PL/M07g=9@1k`S40
NJm407JZDP1fZUL0LZUJ072`F`1d/640Nj5L07ZLF`21W540O:lU07jP4@1mRP@0NH0007Ii001jM`00
N7l007R0001hN`00NGP00080MW@000l0M6d0075[001/IP00Kf/007=a001_K`00KVD006UP001XH@00
K6D006aW001VH`00I5`0065K001OF`000P1PFP00301OFP00GU/005YG001CC@00C4<004Y20014@000
?cP003@_000U6`0040L000H100H0000000<00040000000000000J000000<0?ooo`002P3oool0501;
BP00AdP004E80015DP00AE@004UR001=I040AVL504E_2015K0D0C6h204mc0@1DM`40EGX2055j0`1@
O0D0D7`305=m0`1FP@80EH@10P1IP`401@1KQ040F88105Ym0@1LO080GGX10080IW`00200J7l006b1
001[OP00K8@006f2001]P`00KX8006N2001YQ000JhT006b>001WS`40HY0206NC0@1XT@00K9<006nF
001`U@00LY<006fC001[VP00K9H006jD001_S`00Ki4006bA0@1/U080KiP2072F001/TP00JY4006fB
0080KYH002L0KiX006^H001^WP00Lj0007BU001cY@00N:D007FT001dZP40MZP107NW001hZ000MjP1
07J/0`1g[@@0O:X107VW0@1fY040N:4107jU001m[080O:X007b^001o[000OZd107f[0P1lZP@0OZ/3
08:/0025Y`00QZH107nZ0P1o[`<0P:`508>_1@23[`80Pjh108Z]002:Z@000P27Z@009`27[000R[40
08Va0027/P00R[H008^i002=^P00S;X008W02@26^`T0RL0908_12@2;``T0Q/8908;42@22a0D0Q<@2
08K50P26aP40Q<@008[20@2@`P<0SL<408W31`26``P0Q<@808?31P22a0<0P/<308?30P24a@80P/L2
08C51027aPD0R<P708G:1@22c0@0OLd707_@200207W@200W07_@201odPT0P/l908??2@29d@T0SLh:
08k>3@2=b1<0S/XA09774@2GaQ00WL@>09o72`2Pb0/0W<L<09?<2P25b`X0Q<X:08?92`26b@/0SlL;
08o93@2>a`l0T/H@09G83P2GbPd0VlL=0:753P2SaPl0XlL>09g73P2Jb@/0V<T:09S82`2Ab``0QldA
07g<701cbb<0K/TW0080KldT01P0LLhO07;A6`1gdAT0O=0D07_B4`1heAD0LmHD07?F4P1afA80L=LC
077I4`1]fAP0K=TF073F5@1afA@0L]DE07?G501cf140M=PC07;H4`1gePl0NmL=08KG3@2<f@`208oE
2`0=08[F2P28ePX0RMH>08SJ402;eQ<0R]@M08[F8P2:eB@0R=<S08[D9P2;db@0R=<Q08cD6002093B
3P0W097>2@2>c0H0SM4>08SA4@20dal0PM8V08?B:`22dB`0O]<_07_D;`1he2P0N=0M07O;6`1ic1h0
N//T07c::P1ncBD0O</S07_9:01j`SL0N:]807>`CP1`/UP0JjeJ06f/F`1fYf40OiIO07b@G@1nUU40
P:@G07bF101mQ`40N7l007Ij001hNP00MW`007=m001bLP00LG000080LW0001d0Lfh006m/001/I`00
JFh006ma001bL@00KVT006MQ001YHP00J6H006MQ001VH@00Heh0061H001OF`00GeX0065K001QG000
H5d005]G001BC`00CD8004Dl000l=`00=C0002hY000Q600030T00081001a000000`0oooo000:0?oo
o`0D04E50012@P00@D40049:0017B@00AT`004QM1@14G0@0A6T204E[0019L000BGL104]l0P1<O@D0
D7l704f01P1@P0<0EGl205Qo0@1IPP0205an000405eo001OO000GWL0061f0080HgH001<0J7h006Um
001ZP@00K7d006^00@1[O@00J84006N1001WP000JWl006V3001VR000H8/105j:0P1PSP40IXT006N?
0@1WU000Ji800080JY8000`0JI@006bE001bU@00Ki8006n@001_T@80Ki<406fF101/T@<0KYH106bE
001_UP0207:H000W06nM0@1_V`40LJ4307JO0`1fV@40Nih107^K001iX000MJ0107NU101iXP40N:@0
07FU0@1gZ@80MZX307NY0@1fYP00NJD007bS001nZ000O:`007^/001kZ`40O:X207fY0P20Y`80OZH2
082/0P24[@<0QJT1082W0P1j[0D0M[4807Fe2@1h]@L0M[4407je0P24/P00QJl00080Q[<002L0PkD0
08Jg0027/`00RKP008Zi0029_P00R[d008^j002:^0L0S;X608c02P29``X0R/D:08G62@20a0T0O/84
07o40@22aP40PlL108340@25a@80R/D308c60`28a@80P<@307_81@1jb@D0PlP308G41025a0D0QLD4
08C60P22a`40QlH308O72P24b@X0Q<`9083=2@20c@P00P1nc`T09`1nc`/0Q<h:08_=2P2<c@X0Slh:
09G<2P2Ib`/0UlX<09G:3P2Bb`h0SlT?09363`2?aPl0TLH?09;8302>bP/0S</:08[<2@2;c0P0Sld9
09C;2`2EbP/0UlL:09K92P2IbP`0UlP<09?72`2Ka`/0W/X=09_:3`2JaPl0ULL>09;83@2Ea0d0U/T?
09384P27baX0PLTN07k:7`0207S=700W07C>6@1ddA@0Mm8C07[A4`1kda<0MmHC07SE501eeaD0LmHD
077G5@1bfAD0K]TH06oK5`1`fAL0LmLF07KE4P1ef0l0M]L?07OG3P1fe`d0O]<<08KE2`2;e@`0RmP<
08cF3@2;e0/0R]@>08WE4@2;ea80RM/B08[H4P28f1P0Q]PP08SF8`2:eRL0RMHV08_G9@2:e2@0S=<I
0080T]4@02L0U<`=09?61@2@b`h0S<`@08G;8P1ocBP0P/h_08;B;`1oeBh0NMLb07WG:P1hdR00N<hQ
07[<8P1jbRH0NLdZ07_=:01lcbX0NLh/07G8=`1a^dL0K;i=06bkD@1]]5`0KJmR07NZI024U5l0Ni1J
07REBP1oWa@0P9400867001lO`00NgX007Mg001iN@00LgH0075[001bKP000P1`J`007@1`I`00JVX0
06]T001[K000Jfl006i/001YIP00JFD006QW001QG`00IUh006EO001PG`00Ge/005iH001NE`00GEH0
05UG001IF000EeH005=>001<@000?cT003@/000]9@009A/001XA000<20000P8007400000303oool0
00X0oooo01@0@D800410000m?P00@TD004=90015B000Ae`804EK1016G@40B6/004U_001:N000C7`2
04Z1201<QP`0BX<704io0P1DOP40Dg/005Ek0080FWX002L0GGP005ic001KKP00H6h0061_001PLP00
HW/0069j001QP040HWX1069i001SN@40Hg/006>0001TO@00Ig`006Z1001UP`00H8L005n40@1QQ@40
HhD006B5001YS000J8/006R=001TSP00KI4006n?001_TP00L94007:?001bT@80K98506RD1P1ZUPD0
KYT207:H001eU`000P1fU`009`1cWP00MId107>L1P1bV`H0MIH207ZH0`1kV040NId007NL0P1iXPL0
NZ@307ZR0P1gX@80N:@107:R0@1dY000MZ<007bR0@20X`40PZ4007bU001iY@40NZH407ZW1@1jZ@D0
O:D207^R001nZ@40O:D207n[0`1j[040Mj/407Nb201f/`P0M[@607^e0`20]040PK<008>e0002082e
000O07nh0022^@00Q[D008^f0028^@00Ql0008Rl0029^`00RK/208W00P26`P@0R<<508G41`25a0H0
Q<8608;10`21``40PLP207g80`1ib0@0P<P608;51P24a`D0PlL308781@1lb0D0N/T407k81022b0@0
Q<H407o70`0207o90@0608?80P26b`T0R<X:08K;2@28c@/0Q/d90P1nc@T09`1lc@/0P/d<08K;3@2<
b0d0S/X<09O;3@2LbP/0VL/;09K<302Bb`d0SLd>08S=3@24cPl0Q/d@08O<4@26c140Q/`?08[<3P2>
c0h0TLd>09;;302BbPd0TlP;09W92`2Oa``0W<H<09[9302Jc0/0V//;09_;2`2Ja`/0ULP:08o<2P2C
c@/0V/X=097<4@27ba<0Q<TF07k96@0207W?6@0W07g@601kdAH0N]0F07gC501kea<0NMHB07cF501l
eAL0N]DD07cE4P1hfQ40M]XF07[J501kfA@0NMTB07OG401ie@l0NmH?07cG301ne``0Q=D=08[E3@2;
e`d0R]P<08_F3@29f@d0QmH?08KH4`29fQ@0RM/D08WH5`29f1X0Q]LP08WH9@2<eBL0RmLV08WI9`2;
fB80S=HM0080Sm4F02L0UL`=09351P2?a@`0RLH?08S88@21cR/0O<db07kD<P20eRh0OMT[07_F:P1i
e2H0NM4R07g?8`1icBH0M/dY07G>;`1fdC40Lm0i06g:BP1/aUD0JlEE06k0DP1a^UX0L[QN07FaHP21
Ueh0N9Y@07RR=P20VA40OhT007b1001iN000N74007If001eM000KFh006m]001_K0000P1^IP00301_
IP00KF0006]S001ZJ000J6T006MX001ZIP00J6T006I[001SG`00Ge/005mN0080HE`000l0GU`005eF
001FD@00EU8005MB001EC`00CTT004@k000h;`00;bD0028L000J4P0040L000H200010000L@00000<
0?ooo`002P3oool0500k>@00?c`003lk0013A`00ADX004A>0017H0D0BUl204]O001>J000D6T004m^
001CM`<0Dg`505>11P1>O@<0DWP105Ad001?L`00DG000P1DL0009`1HKP00FW0005QW001EH000Ef<0
05UY001KM000Fg4005Ya001LMP80GVl105ac0@1OM000HW`0069n001QO000Ih8006F0001VPP00IGh0
069j001UP`00IhD006Z7001[Q`00KX/006^@001YRP00KH`006f?001cT000LHd007:>0@1^T@80K9D3
06bG0`1aV@40M9L007NG000207VF000W07RJ001hW@40Mi`207JL0P1gV040Mid307FN0@1fW`40MIh3
07JQ1`1jX`P0MjD507FV0P1bYP40L:0007JQ001jX000OJ<1082T0P1mX@80OYl107jS0P1lY@80NjP6
07ZW101oY@80Nj4107^R0P1oX080O:T107b[001m[0<0OJl307Vc0`1h/`<0P;8108:e0021]@00Q;L1
0080PKT002L0PkX108>i0P2;]P80S[D208Zi0026^P40Pk/107o00P23`080Q<4308K31@25``80QLD2
08C41@26a0P0QL0708?1101oaPD0O<T507[81@1lbPH0O<X808782@23b@L0P<P80837201kbPH0NLT5
07o80@22aP40P<L108;70026a`40RlP:09;:2P2AbP/0Sl/:097:2P2;b@/00P23b`X09`1ob`X0O//>
08;<3P22b100QLT@08c:4P2Bb180TLLA08k83P2<aPl0SLT?08W;4028ba00R//@08k:4029b`l0Rl/?
08o<3`2:b`d0R/d=08c<3@2=b`d0S<X;09392`2Ka@`0W<L>09G:3@2Ac0/0T<h:09?:2`2DaPd0ULT=
09G;2P2BbP/0UlP<09G93`2Ab@h0S/XB08G:5@0208G<6@0W08C>6023dAH0Om4F07kD4P1oeQ40P=H@
08?E4023e100PmD>08?D3P22ePl0PMP@08;G4P23f@l0PmP>08?F3027e@/0R=D;08WF3028f0d0R]L@
08_H3`2=e`l0SML=08[H3@29f0`0QmL?08SI5028fAH0R=XL08OK7@26eb00Q=LU08OJ9@27eR40R=TR
08GG8P29f1`0S=PN0080S]DL02D0Sm0>08_82P2<`@/0RlH=08O<5`1odbL0Nm@`07SC;P1je2T0OMLU
07OF:@1he2/0OM4[07[B:`1gd2X0L]<Y06kE;P1_dcH0K]1206c;DP1Zc640IlmO06c9F01b`5X0LKIK
07>`F`1fWEh0MjQ007RX7`1nTPd0O88007Il001hL@00M6`007=^001aL000KVT00080KFT00P1/I@00
701_I000K68006mZ001^J@00JVD006]V001XH@00J6P006QY001ZIP00Hf<0061K001QF000H64005iN
001KF@00EU4005A?001BCP00CT/004Y40011>000=Rl002hS000P6@004Pd000L20002001b000000`0
oooo000:0?ooo`0D03`e000m>@00@3d004=20015D@00AU<004]R0P1;I@40Bf0004eT001=H`00CFD2
059^1@1DLPH0DgP3051e0@1@L@00Cfd004aX001=I@02051U000N051T001@I@00DUh0051J001GGP00
Df@005E]001BJP00EFT005]`0P1KK040GW0105ma001MM000H7X005ei001SO000Hg/006F1001VN`00
IGh006R3001ZQP00KH@006j5001`RP00L8/006b:001^S`00Ki410P1bT0001`1bT@00LI@007>F0@1d
W@40MIX007NJ001hV0000P1iV`409`1hW040NiT007RL001dX@40LIl206nQ0`1]W`40L:83076O1`1a
X`X0MZD;07JT2@1iYP80N:<007NQ0@1iW@40O:0107jQ001mYP40O:<207fR0`1iX@@0OJ43086U0P1o
Y@80Q:<007fQ0@21W`40PZ8108:V0023[@00QJ`008:/0024/000Pk0008Jb0026]`00QkH008Ji0002
08:o000708>o1026_`H0Q[X808Bi1`26^@<0RKL108Ji0`020830100N08C20P22a@40Q<D308;71@24
aPT0P/D908C42P22``L0Q<D508?31024aP80PLP208780`1oa`@0PL@608C51@21a@H0N/H807W8101m
a`40PlL208O5102;a`D0S<P908c83@2Da`h0U<P?09C83P2Da`l0TLP;0P2:bPd09`28b0h0O/T?07c:
3P24bPd0QLX>08S:4@2>aa@0SL<C08_15029_Q<0R/0C08c14@2=`Q80S/8A09774P2CaA<0U/DB09K6
402Db180SlT?08_:3P2<b`d0SlX<08c:2`2FbP/0UlX<09C;302?c@`0T<l<09;=3@2AbP`0T/T<08k<
3`2;b0d0T/D=09K43`2Ea`l0TLX?08g;5P0208_=600A08g@5P27dAD0Pm<C07gG3`1of@l0PMT?08GG
4025e@h0QM<>08[D3`2=eQ00RMHA08[G4@28e@h0S=H=08WG3@29eP`00P2<e0`0502<e0h0S]@A08kE
4@2<ePl0R]L>08[I3@29f@l0S=PA08SG5@24eQT0Q=HR08GI7`22fAh0R=TS08OJ9@25fR80QMTP08?F
8P29eB00RmLR0P29eB009P29dPl0SLT;08c32029aP`0Q/`@07cC8`1gdc80M]<]07WE:P1jeRH0Nm<X
07gB;`1kdSD0N=4i07G@=@1aeBl0K]@a06gA>`1[c4L0K<]B06W;G@1Vd680J<QL06blFP1`/EX0LJmL
07:PF`1eYcH0NJ0F07b71`1iO000N7L007E`001bJ`00L740071[001^JP00JF@00`1ZHP006`1[IP00
Jf`006mb001^L@00KFd006aV001UG`00IV4006EP001XI000I64005mJ001OGP00H64005eK001IF@00
FEH005=A001@B`00B4@004@o000m>000=Rd002/Q000K4`003`L000<0001c000000`0oooo000:0?oo
o`0D03`i0011@@00A4X004M=001;F000BEH104YH0P1=HP40CEl004aP0019G000BE`304aV1`1>J@L0
CfH304mX001?IP00CVH004]S001;HP0204YR000E04UN001;F000CEH004eI001BGP00DF<0051P001E
H`00EV<005Y]0@1MKP00G6h005md001RN`00HG/006=j001VN000IWH006Il001[P000JX000080K8D0
0100KXX006n=001`SP00Jhh006R?001WT`40J90106bC0@1_U@00M9P007FK001fWP00N9l007BE001f
V000MYP10P1eV`<09`1dW@80M9d1076P0@1[YP<0JJD506NN101XW`<0Jil606fU201`YP/0LjH<07JR
2@1jX`40Nj4007fP0P1lW`<0OjD107ZV001lY@00Nj4107ZS0`1jXPD0O:0407^M0@21XP00QZ0108>Q
0020XP40QjL008J]0025[@00QZh008R_0027[P00Q[0008Nd0025]`00P[L008Fj000208Bk0@80Pl08
02D0Ol0807bo201o_PL0Q;X308:k101n`0H0Pl0608731@23a0D0Pl<608741P20a`T0P<H908;62026
a0H0PlH608K40`23a@40Q<H108?50027a`40RL8308G30`26a0D0OLD607W60P1oa@00Q/H808_62P2@
aP/0T<P;09782`2?b0d0SlH=08o83`2?aPh0SL@=0080SL@B00<0TL@B08_54029a@h00P2:bP/08P2:
b``0SlH=09763P2@aa00Sl4?08c23`2<`Q00SL@B08o14@2A`A40U<4D09S05@2G`AL0U/8G09;54`2;
a`l0R/X=08g;3P2<bPh0SlL@09?94@2Fba40UL/?09G;3P2Db@d0VLP=09S73@2Eb``0Tl`;09;92`2?
bPh0S/`=093<3`29cQ<208S?500U08[;6@27d1H0Q=@D07_H401ofPh0P]X=08;G3P24e0l0Q]P>08[G
3P2>d`h0SmD@08kE3`2;e@h0S=D>08SD3`2:eQ00R=D@08cD4@2;da00T=D?097E3P2?ePd0S=P<08_H
3@2:fA@0RmHH08WD6`27e1L0P=DJ08?G5P24f1H0Q]PE08CG6024eQ`0QMLR08GE9P0208OF:@80PmHT
02L0Q]8A08c=302=`@<0Qkl:08;<401idR80Lm@b07?D<@1beC00Mm@Z07KC;01jdbh0Mm4b07KA>P1b
e3/0L=Dk06oE>@1/e3`0Jlm:06gACP1ZcEH0I/aI06?6G01X_UP0K[=I06naFP1Y[e<0NJTV07RC201h
Q@40MgP007Ea001dL000LW4006i_001`K000KFd006YX001YH@000P1WH@006P1XH`00JFH006e^001^
K000JVT006IR001QG000HUd0065M001VI@00I5/005mM001QH000GUl005iM001IF`00F5L005A?001:
A`00A3l003dh000i<@00<BP002PK000I3`002@<0M000000<0?ooo`002P3oool05011@000AdL004Y=
001;D000BUL004MH0P16FP<0CEl104aN001=G@00BUT004MK0@1<HP<0CV8304eO0@1<G000C5/004QJ
001:H@00BV800P1<I0009`19G000BU<004UE001>F@00DV4004mS001CGP00Df0005=R001MK@00GFl0
05m`001SMP00HW/006>0001VO`00J7d006f0001[PP00KXL006f6001/RP00J8T006R:001[T@00JY@0
06VD001UTP00Hi@0062E0@1SUP00Ji`107:Q001dW`00Lil0076O001^VP00MI@007FB000207JF0@0W
072E0@1ZUP40Jil106^R0`1YY0H0KIh506jM1@1]WPH0L:0507:S2@1eY`T0NJ<507RR0@1eX080O:43
07jO0P20XP40Pih0086K001nVP00Ni`107VM0P1nW@80OYX007nO0025X@00QJH508>V0@24Z`00QZh0
08>a0@26/P80R;8208Rb0@26/P80Q;L107nh0@1m^P40OkX00080P[h301X0P[d708Bm2020`0P0OL08
08301`21`0H0P<0607c01@1m`@P0Pl8:08S01`27`0H0Pl@808C11P23`P@0P/<208O40`24``@0P/L3
08760@26``40R<<008[50028a@80Ql@308S40`80Q/@100/0Q/D008W72P28aP/0R<D=08o43P2Ba@d0
TLT<0938302<c0`0QL/=08W92`0208W83P0W08c43`29`a00R/D@08c83P2=b``0S/X=09;43P2Ha100
WL8@09[33`2A``l0T<H>09763`2A`a00U/0A09W23`2Ka0l0Ul<E09G1502Fa1@0T<LD08c;4@2=cA40
S//A093:4`2DbAD0VLPC09_;4@2Fb`l0T/T>09O83P2Ka@l0U/T<09;93`2@b@d0R<h<08W>3@2AcA40
T</@0080Rl/C02L0RL`G08KC5P23eQ<0O]TA08?H4020e`l0O=P>08;H3P25f@d0RML>08_E402<da00
S]8=08gC3@2>e0h0R]D=08GG2`21ePl0P]<>08GD3`2<d`l0Sm<=08gF302:f@d0R=P@08WE5P29daX0
R]@I08CC5P1oeQP0P=DE08?D4P21e180PMDF08CD7@20eB00O]@W087G;@24eBd00P24dbT09`24e1H0
S/T<092l0`26`0L0PLX@07[D7P1ceRl0Lm<b07?E=P1edS80M<hh07?==`1acCP0Km5006kE@P1[eT@0
JmE306gABP1[ceH0JM1D06_>EP1WcED0HlAF06BlE01Z/UP0Jk5C06Vi@P1hZa`0MH`307>0001`LP00
L6`0071W001/L000K6X006iX001/J000K6H006QT000206MU000J06QT001WI000JVL006U/001TH`00
He`006=K001QH000H64006AT001PG000HEl0065P001MGP00F5h005IK001CE@00CDl004Q50010>P00
>3P0038/000Y8@007aD0010:00050@1d000000`0oooo000:0?ooo`80AT<00180BT`004]>001;D000
BEd104IO0@1;H@40CF@004eR001<G`00BE`004iM001?GP00CUd004YK001;FP00AeX004QT0018IP02
04iT000W04]O0018E`00AeX004]M001>H`00DFH0059W001EI`00Ef/005]_001QM`00HWH006=o001P
PP00I8L006F5001ZP`00KHH006b7001]S`00Ji4006N>001RU000HY<006JG001ZU`00JIH006NG001N
VP00Fil005ZS0@1QY@80IjD206fP001^V`00KYX006RG001[U000L8l00080Khd002L0KY@006jC001^
V`40LId107:P0P1eW@80MJ8207FN0P1gWP80MIh107RP0@1eW@40MYh307>O0`1iW`<0OIP108:J0@23
VP00P9L007jI0@1iW`80Nj4007fR001iX`00OjH0086X0025[PX0PJ`108:a0020[P00O[D6082f1`22
]`L0P[D6086f0`1o]`@0NKL607^k0`20]`000P24^@409`22^P@0PKX4086k101o_`<0P[l408;00`20
`0D0O<0307o11025`0@0RKh708K12020`@L0P/0508G10P27`P40QL@108K40P21aP40Pl<108720P25
a@@0QlP208K60@23aP80Q<H108c5002;aP00S<@008W92P22bP`0O/P>08O5402=`Pd0S<P=08W:2`26
b`X0P/X:08O82P0208?62@0B08O62P2?```0U/H=09C:302Bb``0ULP=09C73P2H`Pd0ULD<09?33@2B
a0l0T/4@09G04P2?`a80SlHA09783`2Eb0d0V/@>0P2K`1@04`2H`1D0TLHG08k95P2=ba@0S//C09?5
4`2EaQ@0Ul@E09K83`2Fb@h0ULX=09K7402HaQ40TlP?09383`27b`h0R<`C08k:6`2CaA/00P2AaQd0
4P2:c1T0RM<F08GH5021e`l0PmT>07oH301hf0d0OMX=08;J3`22ea00PmDC08GC4026e0l0R=D@08[G
3`2:f0d0PmH:07kG2P80Q=H:01<0R]<;08gF2`2;f@`0R=T;08SF3@28dQ40RM8D08WD5@26eAD0OmHI
07oD601oeAD0Q=@C087D6P21db00PMDN08CF901oeR`0P]L[0080PM@X02L0Q=@H08g53@2@^P<0R/06
08K83P1meA/0MmH^07KD=01ddcH0MLLj07C0?P1baDD0LLM:073>BP1/dT/0JmA=06cCD`1Xce`0I/YL
06K=G01Wc5X0J<ID06BlD`1V]UH0JJiH06^[CP1_/CH0O:8E07J80P1eM`00L6/006aU001ZH`00Jfh0
06UV001YI000J6T006UU001XI@000P1WHP006P1YH@00IUl006QS001WH`00IV8006EL001SHP00Hf00
06ET001RI@00Ge`0061K001IE`00EeT005MJ001DE`00DED004e<0012@P00>SX003<_000Y8@007aH0
01D?000;1P000@00M000000<0?ooo`002P3oool05019B000BDT004a@001=E@00BET004eS0019H`00
BfT004]Z001<I000Bf<004]Q001>H000DF<0059U001<HP00BV8004UW001:I`00BfD00P1;I0009`1=
H@00C60004aT001=I@00DVH005E/001HL000FW8005ma001PMP00HX0006J1001TQ@00HHP00666001U
R@00Ih<006R5001UR040HXX106>B0@1QTP40GI<0066D001UV000IYH006RF001VV@00II`105nP0@1L
X`00G:H106:S0P1YV000K9@006VD001WU@00J9@006fA000206j;000W06n@0@1`SP00M9<007FB001f
V@40NId007ZN001kW`00NJ4107NL0P1hV@80MiL207RG0`1fW`80MY`107fJ001oV000PYl007fO0@1i
X@@0MZX507V/0P1h[P40NZd207b]0@1m[`00OK@607fd0@1j]000N[0007Ze201n]PL0O;P607fe1@1m
]0@0N[<607>f2P1b]PD0N[P00080OkL002L0PKP1086i0@22^@40PK`208:k1023^P40Q;P108:i0@20
^`40Q;`108>o1@1o`0T0P<4608311@25``@0R<H308O20`26``40Q<D108340P21a@D0PLD:08751022
aP40P<H208?50P28a@<0RLD208O50@27a`d0Pl/<07k;2`24b@X0R<T:08W83029bP`0R<L<08G92@20
b`T00P1lb`P09`20bPT0RLL:09K73P2Gb0d0ULT<09O82`2Fb@/0SlT;08g8302>a100T/8B09S0502M
`100Ul4=08c83@25bPl0S/L=09C43P2F`Q<0VL4C09;33`2Ca1D0T/HE08c64P2;aa80S/@B0973502H
aAL0Tl@G08o55P2>aa80SlPD08c:5P28b1@0R/HG08?76026c1T0R</K08[;7`0208[<7`0W08_?7P28
dQT0Pm@F08?D4`26eQ80Q]L?08CG3`1ofQ00P=L@07kD3`1oeQ00P]DA08GE4@26eQ00RmH@08OF3@27
eP`0PmP;08_H2`2:f`X0S=T:08oF302@e`h0RmD<08_A2`29d0`0S=8?08SC4@27dPl0PMHC08GD5`22
dQd0Om0M07oC7@20eB80PmDR08CE8P20eb80PMHU0080Q]PY02L0Q]<F08c83`2A_0<0Skd408c53P23
daX0Mm@]07[>=P1gbD40MKa407BcC`1a]ED0KKYD06c2E01Zb500J<YC06K:F`1Q`fD0HL5W063:H01S
bE`0IL5H06>jG01S/e`0J[5B07:_@@1fZQh0P9`?07N30P1dL`00LFX006QS001ZI000KF`006iY001Y
I`00JVH006MT001WHP000P1WH@006@1TH`00If<006MW001WIP00If<006MU001UI000Hf4006AR001Q
H000Ged005UG001CD@00EU80059?001?C000BDP004I40010?@00>C@002hT000M5P004``000/50005
0@00M@00000<0?ooo`002P3oool05014C`00ADl004MJ001<H000BV@004]_001:J`40BfX204a/0`1:
J@<0CVH204eU0@1?IP00D6T004e[001<J000B6/004Q_001:KP00BF/00P1;I`409`1=I`40C6<004aX
001<K@00CV/005Aa001HM@00Fg8005ie001PN@00H88105j3001NQ000GHP005b6001NRP00GhD005j6
001HRP80Dhh405FD101ES`<0Fi02062=001ST000J8h006B;001VRP00Ihd106NE0@1TU`40GiH006J?
001YQ@00JhH006b<001US`00J8`006b8000206^5000W06f?0@1aTP00MID007F@001gV@80MI`107BL
001iV@00NY/207ZM1P1gWPP0NYh:07VK201kWP@0N:<207JS001jX@00PZL007VY0@1i[0D0N;4707N`
0`1g[`<0N[@807b`101k]000O;@007^e001h/`00O;4007f^0@1l/080O[8207^^0P1n/0@0N[0407Ra
1@1j/`80O[H00080PkD002L0Pk@0082f0023]P00Q;L108>j0P24^`80QkP108Ji0@22^040PkP108Bk
0P21`0D0OlD308?10`25`@@0R<4608G01@25a040P<P207o81021aPT0P<H;08;22@20aPD0O/L50875
1@24a@D0Q/@308C40`24aP<0QLL;08K92P25b`/0RL/;09393@2Cb@h0TLP<08S82P22bPT00P1ib`T0
9`1nb@X0QlT=08k;3@2>c0/0Rlh908[=2@26c0T0PlX;08?:3`28a`h0SL@=09333P2<a``0TlL;09?5
302<aA<0SL<D08o63@2Aa`d0Tl<>09763`2BaPl0U/4?08k5502CaQ@0UlDD09W24`2O`aH0V<4H09K6
602Db1T0SLhI08K@5`26bQH0R<PI08O86P26bA/0PL/K083<6`0208?=700W08GC7@25e1L0Q=HF08CF
4`24e180Q]@@08KE4023e@d0OmH<07oE2`20e@d0P=@=08SF3`2:ePl0S]D=08[F3029e``0Q]P?08_J
3`29f0l0RmD@08oD4@2AeA<0Sm@A08gC4027d`l0R]<=08[D3`28dA40Q=<B08SC5027d1L0PM8I07kB
7@20e2H0P=@Y07gE:021daT0QM<L0080Qm<S02L0R/lD0936302C^P40TkX208o33@26dAD0N]@/07W:
>`1gaTH0MkM:07:[E`1aXUT0L:QG06fdD`1`^UH0KK]H06^gFP1W]V<0H;AW05noGP1S`UP0I;iJ062h
G@1V/U`0KkE607B]:01gV`l0N8/4079n001^LP00Kf/006UT001XJ000JVL006QY001_J000JfP006IS
001VHP000P1UHP00601VI000JVP006aZ001VJ@00J6P006EW001QHP00Hf0005iN001NFP00G5`005MD
001DCP00DD`004]8001:A@00@Cd003li000l=P00<b/002HK000D2`002@@000<007H00000303oool0
00X0oooo01@0@e<004AE0016E@00B6D004AV0015KP00AV`304EZ1@19J`H0BfT604]Y101<J`40Bf/0
04U^0018K@00BG4004Y`001;M@00BW4004Y/0@80B6@200D0Bf0204mS0@1=I`00CfX0051V000205Q[
000P05U[001LM@00FWH005Z10P1LOP00F7`005R1001EP`00EXH105F1001BOP40CHX404V<1P1;S0H0
ChP605N80`1MQ`40H8@00622001QOP00HWd006=j001SPP00GhH005f3001TO@00JGP006]l001[Q`00
IhT006N3001ZPP0206R1000C06f<001cTP00MY4007VA0@1eV@40M9h207BK001gW040O9L307ZL201h
XPX0LZL;07>V2`1fY0X0N:<307JV001iZ000NjT007Z[0@0207R^0P0607V]0@1hZ`80N:h707^[101k
[@40OJd00P1n[P002P1k[000O:/107b[001jZ@00O:d507b/2@1jZ`H0OJd1082/0021[`02082_000W
086a0020/P00PK8008B`0024_@80Q;`508Ji1027]P40QKD1086i0020^`40P;X208>o0P25`@<0QL48
08?12`22a0X0P<H707c8101ma`@0OlH907k62@1mb0T0OLD807[62@1kb0H0OlH408730`24a0@0Q<@8
08;62P1ma`T0Q<P:08_93@2Ea@h0U<H<08c72P25bPX0P</90080Nl/<02L0P<X?08O93P2>b0`0S//9
08C92@23c0T0O/d=083:3@23bPl0Q/X=08W8302;b0`0Pl`=08[93@2Fa140T/<G09?24P2Ba@d0T/H<
09772`2>bQ80SLHE08k2502A`a80T/<@09;2402I`a40Vl0C09nm5P2J`AP0UlDM09365`2;aA40RlD>
09745`2@aAd0QlXM07g>6@1jcaH00P1odQL09`23eAX0QMLE08CD4`25e1<0Q]@G08?C6023e0l0P=H<
083E2P21eP/0Pm@<08GE3`25e@h0R]L=08cF302<e`d0SMD@08WE5@2:eA@0RM8E08g>502>caD0SM<F
08gB6@28d1h0QM@F08OF4@27eA40Q]4D087A5@26dQD0Q=<E08;D5020da@0PM8K07oA8`1ndb@0O]8K
08?C5P0208WC700W08[@402Ba0`0Tk`109:j002A_P<0R//?083@8`1lcC<0NlTo07Nj@`1c[D/0MZiE
07F^EP1d/U00Lk9=07>/D`1_[E<0JZeN06:[H`1Q]5h0H[UF06BbE`1U/eD0KKQ507N^9`1iVA<0N8T4
07F2001aM000J70006QZ001WJ000J6L006IP001RH@00JF@006]V001XH@00IV400080IV8000P0If80
06QT001YIP00IVH006EV001SH000GEh005]P0080FeT000h0Fed005IH001DC`00CdL004]30013?@00
>S00038/000a9`00:24001hB000=1@000`40004007H00000303oool000X0oooo0100@50004=A0015
E@00AV4004ES0013H`00AV@204IQ101:I0@0B6T504Y[0`1<K040B6X004I/0016K@00B6h00P1:K000
:`1;K000B6D104EL0@15G040BEP104mI001=F`00D5d0055I001?FP00Deh0051O001CIP00EF/005Ea
001CLP00DW40059g001AN000DGX1055e001;LP40BG`204Qn101;P@<0DGd305=o0P1EP`40FH4205^3
0@1IN@00FGH005e_001LM000GGh1065m001YO`00Jg/106f20@1/RP40JHl006R:001YQ0400P1_R040
5`1^S000M90007F>001eU@40MiD207BK0P1eW@40MYl307^K0P1iW`<0N:8407FW2P1`YPX0M:@907ZO
0`1jXP40MZD007RY001i[000NZ`007VW001kY@40N:<00080NJL300h0OZH107jU0@1mZ0<0OJL207^U
0@1lY@40NjP007J/001j[0D0N:X807ZX101hZP00NJP007f[0080Nj`002L0P:l207bc0`1n/`40Ok40
08:i0P22^0@0PkT608:h1021]@80PKT107fk0@1j_@40Ol04082n1@20`@X0P/8;07k42`1ja0T0OLL5
07g50@1laP<0NlP708752P21a0T0OlP907g81P1oaPH0P/8508G10P23``X0P<D:07W62@22a@h0RlD?
09;2302B``X0R<P907o:2P1nc0X00P1ob`d09`26b@l0SlD>09;42`2=`PX0QlL<08K<4@22ba80RLD?
08k63P2<a`h0R/H;08S:3@2:c100SlPB09S0502H`AD0VL4A0:323@2Ka@/0TlL<08g45@2Aa1D0T/<C
09C43@2@aP`0T<@F0973502H`140VkhA09[1502E`aH0T/4E0973502B`QT0TL<N08o58P27bQl0Ol`J
07cA500208;F500W08GF6@26eA40P]@B08;E4`24eA<0QM<D083C401me0`0O=D;08GE3028f0h0R]H@
08SB5029eA40RmL>08_F302:e0`0RM8>08cC4@2;d1D0R/`K08S>7@28dad0RM<O08SD7023eAD0Q=DD
08WD5025da<0P=<C087B4@22e100Pm4A08CA4024dA40P=4C07g@5P1jdQL0OM<I0080QM4G02L0S</?
09701@2B]`00T;D009>i002?aPX0QldA07g@9`1icC00M/Hj0771@01a`4/0M;];07FnB@1f^dD0LKI5
072cC01^/Dd0IJiC06^_E@1U/e80I:i:06Zf>@1d/Ah0NYT>07N00`1eNP40L7H006e`001YJ`00Hf<0
06IV001TH@00He`005mK001QFP00IV0006MR001WH0000P1UG`005P1VGP00Hf00065M001RH@00If<0
05iQ001MH000Gf0005UJ001EF000F5T005=I001CDP00C4X004940010>000<bh002hV000U70007QH0
01@=00050P1h000000`0oooo000:0?ooo`0D03m:0011C`00@580049K0016G000AUX004IL0@17E`40
A5H104ES0P16HP40AF<004AP0015I000@f<004=R0015G000Aed004QI0016E@0204A<000W04A90019
C@00BU4004]D001?EP00CEL004eH001;E`00BUT004YM001:IP00Bf/004i/001AM000D7<004mZ001<
K`00BG0004Uh0@1<N000CGD105Eh0@1FNP40EH8205B2101GPP<0EGh005Ik001LN000GGL006B2001W
Q000JXd106N<0`1YT@@0JIH206ZC0@1]TP00K9010080L8`102L0Kh/006n<001/R@00K8l3076A0`1d
U`<0MIT407FL101dW`80NId007JJ001bW@80LYl507BK0`1gVP80MIL007VJ001iWP00NJD007^S0@1m
YP40NJ@107NT001dX`00N:8107^R001jY`80LZ/607>Y1@1cZ080NZ@007VT0@1eX`00MZL207ZS0P1j
Y040O:D007bX001lX0000P1hY`009`1j/0D0N;<907Ve101e^@40O;`107jn101j^`L0Mk/907^k1@1j
^0<0O;/307_01@1l_0<0P;d20831101o`@P0O/<907O31`1ja`@0NLL207_7001kb@@0O/H707o71P20
b0D0OlP907k72P21b@H0O/D307k82@20a``0OLX<08763022bPX0Q/H;08O32P28a@T0R<P;08K93@02
08K73@0W08S63P2=``h0Ql<<08O2302=a`d0RLH?08O24P2B`aH0Ul<@09?43028bPl0Ql`@08g8402D
aQL0Ul4I0973502F``h0Xl4=09W03P2BaA40U<4A09C1402CaPd0S/H<08o53`2=`1H0T/0E09W04P2K
`@h0V/8?09Vm4@2C_AH0U[dJ09G07`2@`2@0S<<U08;88P1oc1T0Om<C0080QmDC02L0R=<G087C5@1m
da<0Nm@D083D4`24dQ@0P=DA07[E401le@h0Q]@>08SG3P29eQ00Rm@C08[D402;d`l0RM8=08gD302<
d``0T=4@08k?5P2=cQ`0R=4L08GD6`28e1T0RM@H08SC5P26da<0Q]4E087A401odPh0Om8=087B3024
d0`0Qm8=08?>3P23c0l0Om4A07cA501ld1H00P21d1P09`2<`Pl0TKP108nb002>/@00T[@009>k0@2:
aP`0PM4B07g?601fbQl0LldW077<:P1fbS00NlTa07k6<P1jabh0N/8]07bo:@1o^b<0NKTV07Jc9@1e
[R@0M:<D07BI2P1cR0<0L7T0079`001^J`00JfT006QW001RG`00HV00069L001TFP00H5/005iI001R
G000IF4006MP0002065L000F069I001OFP00GUT0065O001QH`00GfL005mY001OI@00F5/005=E001B
E`00DU@0059A001;B@00AC/003T_000^90009Q/001TC000D3`0030L000<007P00000303oool000X0
oooo00@0>d8003i8000nB@00@Dh00P10CP003P0oD@00@dh1041C0@0oG@40@E`004=G000oF000@UH0
04AE0013DP00?T/0045;0010BP00@TL00P10A0009`0n@P00A4D004=80016D000C5L004UF0018F@00
A5L004=H0016FP00AfD004YW001=J@00D6/0059^001?JP00Cg4004me001>O@40E7X005Ef0@1JN`80
Egd405F50`1GPP<0FWh105n1001NP@00HHD006B4001YR000JXh106^B0P1YU@80Ii@306RF0@1/T`00
JY4006j?0@02072=0@0W06j9001]SP00KXd007:B0@1bT`40M9<107JJ201dV`@0MYH207ND001fV000
MID007FL0P1eUP40MiH107bD0@1kU@00NIP007VQ001gX000NZ<107RW0@1eY`00M:@107>V0P1fX@40
NZP307FX101bZ`<0LZT207NV0@1fYP80MJ<107RS001iX`00O:P007jY001mY@00NZ000080NjL002L0
NJd207Rb101e/P80MKP107Fl101f`0P0Ll09076m2@1c_@H0MKd407Fm1`1j_PX0O[d7082m0@1o`@00
N/<007K70P1ga`H0O<P507g80P1lb@80M//307K:101ka`<0P<L408362P1ma`X0NLT707S;0P1mb@/0
NlH>08;83`1nb@X0NlL807_62026aPT0S/H=08g1402B_Q800P2E`0l09`2A```0RL@<07o83@21b0`0
S/8>08_24`2;_Q40Rl4A09?0402K`@d0S<XA08W:3`2=`Q00T<8C09?04`2;`a<0S<@>09G33`2C_Q<0
SL0E09G23P2O`@`0Vl<<09;54@2C`aH0W[TE09Zl5@2I_100V;l?09No5@2M]Q/0V;HS09>h902=_RX0
SKdY08bm;@24`RT0P/`P087A5`0208CC500W08KB5025dAH0Pm0F08GA6025e1D0R=HD08CF5@22e1L0
Q=<A08KE3`28ePh0RmP?08WF4P2;da40RM4@08SB4@2<dQ00S]<>08o@4P2?caD0SldC08gB4@29dPl0
R=8@08WD3`29d`l0R=0?08CA3P25c@h0P<l>087?3@21cP`0Plh=08G?3@25c@d0QL/>08C>3P1od0h0
O/hA0080PLXC01/0R[/>08nd002>/000S:h008^]002:/000R[P308K02P1o_@h0OKTA07fk4@1k_A00
PkdC08Bi4P26]a40QK@A08:/3`24Y0`0Oih707bI1`1hT@P0MHl807J<1@1cR`40L88006id001ZJ@00
0P1WI000201XJ@00IV8005mI001PF`00HV0006IO001SH000H6000P1TH00206IS000;06AP001SG`00
H5l0065N001NG`00HF@0061Y001LG`00DeL0051C001=C@000P1:C0002016@P00?C<002lX000S7@00
7180014:000;20001`@0N@00000<0?ooo`002P3oool0400g?@00>Sl003U0000j@@00>TD003Q80@0g
C@40>D`303Q?1@0kE0<0?54103e=0010C000@4T004=<000oAP0203i2000[03]3000lA000?DP003e8
000mA@00?dP004==0014E@00AUX004IH0019H000AEd004MP001;J@00Bf/004e/001@K000DF/005I[
001CJ@00EG8005Ah001EN000F7d005Qi0@1KPPL0FhD905^9101LQ080HWh106Ao0@1TP`00HhX006R;
001]TP80K8l406Z>0`1ZR`40JhL006b7001]Q`00JXT006f9000206n;000W06f6001[RP00K94006^D
0@1/U`40KIH1076L2@1dUPD0MI8207>9001eS@00MI0007BH0`1cU@80M9D207RG0P1gU`40MI/0072Q
001`X000MZ0007JR001fY@00Lj4207:V1P1aX`H0M:D5076T0`1bZ@80L:P006nZ0`1^YPD0KZD2072R
001hX000MjL007NY001lY`00N:H00080MjT002L0Mj/007Ba001d/P40M[L307Ji201e_PT0L/0907>n
2@1f`0D0Mkd607O02P1l_PX0P<040870001i``00ML@107C60@1kb0@0OLT308;60@21a@40OLP207_7
101ma`H0P<H607o6201na0T0N/H407W:0P21b@d0Q/L>08S73@22a``0O<L:07O82P1oaPd0T/@>09Bl
4@2B_1400P2=_Ph09`2<`@`0R<H:08G72P29a@d0S<0D08^o5@27`A80QL8>08no3@2J`0h0S<T@08W7
4@2F_a40U<4@08o03@23b0l0QL@A08o05@2B_1@0SkhA08jn3`2B^a00V;hA09?16`2D_1/0Z;@F09fg
4@2D^@h0UkPB09^i5`2[/R80X[D[09Fe<P2<_2h0R[`^08S0<025bBP0Q<dT08;@800208CA7@0W08CB
6@26dAT0Q]0J08?@6P29dAL0R]@C08OC5`26eAT0Qm8D08SD402:ePh0R=P>08[E3P26e@d0RM@?08[B
4P28dQ<0R=<D08cA4P2<dQ00Sm8>08cE3@28dPd0R=8>08GB3`23d0l0Q=0>083>3P22cPh0P/lA08?<
3P22b`d0Pl`>08?;3@23c@l0PlX?08?=3P23c0h0P/X>0080Q<<?02L0RkH808^`0028ZP00Qj`008VZ
002;Y@00QjX008Jb0@23/P40QZ/108JW0P22YP40PZ<308BO0`26W@80PI/107fC0@1lR`00NHP007N3
001jQ000MX@007N4001dQP00KH8006ei001VIP00Hel0069M001VI@00HV40061K001QG@00Hf4006EV
001WJ@00Hf@006AO001VG`000P1RI@005@1UIP00HVD0069O001JG@00FEX005eO001NH000EeT005=A
001<BP00ADX004A40011?P00>SH0034/000X80006aH0010;00070`0010800081001i000000`0oooo
000:0?ooo`0D03<d000e>000=3L003<j000e@`00<dT1039=0@0dC@<0=4`403e?0P0nBP40@DP00497
0011C000@Th004=<0010A`00@4X003e>000kC00203e@000W03m@0010D`00AEL004UK001:GP00BF80
04]R001<J000CF/004ma001>M@00DG8005=c001ALP00F6l005Q^001EKP00EW8005I^001IM000GGD1
05f1101NQ0D0GH0206230P1QP080Hgl206En001WQ`00JX/006R<0P1XRPD0IhD306Z30@1XO000IgT0
06Mf001ZPP00Jh<00080JHD001@0KHT006f=001_T`00JY<106RF0P1[T@<0Ki86076B1@1_T@<0KXl4
06n?0`1bS080LY8106n>0@1cU@80LIL207>J0@1_V`00Kj00076K0080MIT00140M9/007BH0P1cW`@0
LIl507:P201_X`D0LJD1076U001`Z0<0KZD806nU101bX`00Mih007FO001dYP00L:L006n[0002076]
000W07F_001d]000MkD107Ri0`1g]P@0L[P807:l1P1e_PD0N<<407G31`1ia0X0N/8907o20P1k`@40
N<0107C30@1ea@80MlL307k30`22`@40QL4108?20P20bPP0O//;08392`22b@X0PLH608350`1oa`80
P<P308c33`29a0d0Q<H>0876301naPh0Q/<@09>n4@2G^a<0RK/>0080P/0>02L0PL@=08C62P2>a``0
Sl0>09706@2C`Q<0T/0>09:n2P2?`P/0Sl@A09K14P2K^Q@0Vk/D08jo3`21a0d0PLH?08C44P2:^A/0
UKDF09Jf3`2@^Q40U[XG09nk902C`2@0T[DL0:R_5@2J]A80T;PJ09Vc5P2S[Q/0XZhR0:2e:@2J]bl0
TkL]08fm;028bB`0QlXX08G=8`26dB800P26dAl03024e200Q]8O08KB7`25d200Q]0L08KA6@22dQX0
Q]@I08GB6027e180R]@>08[E3@80RmD<01T0Rm8=08k@402=ca80Q]8B08WB3`2:d`h0Rm@>08SD3`26
dQ<0Qm4?08G>3`21cPl0O/d>07g@3P21d@l0PM4@083>3@1ocP`0OlX@07o=3`1nb`l0P<X?08?:3`20
cPh0OlL;0080RKh602L0SZ`208bW0027Y000QZL008ZR002;X@00RJ8008JV0P23Y`80QJ@108>V0022
Y000P9`007jC0024U@00Oi8007f<001kQ@00Mh<007Io001fOP00Lg/007Ai001cO000L88006el001Z
K`00HV80065I001QGP00HU`005mO001RI000Hf8006AU001WK000JVX006MT001UH0000`1RI0004P1T
H@00H68005iN001KEP00EUH005=D001BCP00CTl004]80011@P00@Ch003Tf000`:`00:B<0024K000G
3P0020@0004107/00000303oool000X0oooo01@0;R`002hd000^>@00;3h00319000aC@00<e0003QC
0@0nD@40@Dh104AF0015D`00AeL004MI0015H@00AUl004AJ0012F`00@Uh0045L0080AEd002L0A5h0
04EP001<I@00CVH0059/001>KP00C6l0051`001?L`00CWH0051f001>M`00Dgd105Ik001KN000FW40
05M`001ILP00FVl005Yb001NMP00FgL005f00P1NO040HWh106Am0@1SO040HgP006Ai001VO@00IgX1
06Eg0@1QL040HG@005aa001PLP00H7@0069k001VP@000P1YPP009`1ZRP00Jhd006jA0@1/TP40K8h3
06J:1P1ZSPT0Ji0906JG1`1SV0X0I9H:06RD1@1[SP<0L8d0076?0@1bV@40LY/0072J001_VP00L9H0
07:B001aUP40KiL006fH001`V@40LIh2072M0P1bX@80M9h0076N001gX@40NZ0207NN0@1gW@00MYh0
07FL001cX`00LJL006n[000206n^000W07:_001d/`40N;4207Zf0`1g]`80M;P307:j1@1a_0D0L<02
07710P1e`PH0Ll8407C40P1aa080LL<307G50P1g``D0N/@507g20P20`@80P/<208;20P23b0@0OlP6
07k82020b`H0P/T508;60`23a@40Ql@208c12`21`P`0OL8<08764@28a180TL<A09G03`2?`0d0P<0@
0080PL0<02L0P<@<08?82`27aPl0Rl0B092m4@2A`@h0U<<<0972302:`@h0SLDE09jk6`2S/aX0WkLE
08g13`24aa40R/8C08^n6`2;^240UkDJ09nd4P2M/@d0W;LD09Rm:@2@`280U[TG0:Fd4@2G]QL0SKTP
09n^8@2SZ1/0VKD[09^d9@2V/Rd0XKTX0970:@27aB/0Q<dZ08CA:029dbH00P28dRH09`25cbH0Q]8R
08KA7`26da`0Q=@K08;B6@1mdAP0PLlH08G>6@23dAH0Qm<E08KB3`29dPd0Rm8<08k?3@2;cQ00RLlA
08?B4P29e100R]@@08OC4P28e180QM8C08CA4@24cA00Q<T>07o<3P1ldA40P=8A083@401nc`h0Nll<
07W<3P1jc@h0NlX:083<2`1oc0d0OL`=08;32`0208Rh0@0W08j[002<X000R9h008RP002>Y@00Rj<0
08RO0@21W@<0PJ4308:M0024WP00Q9l008JE0024T@00Pi40086B001kS`00NhL007N2001bO`00KW`0
06id001bM000LGD007Ai001dO000L7`006a`001UHP00HU`0065L001QG@00HF<005iO001PF`00Hf@0
06IU001TH@00Hf0000<0Geh00140HV40061Q001NGP00FUH005A=001>B`00Bd/004a80014A000?S/0
03/g000c;`009b8001lH000I50003PP000<1001l000000`0oooo000:0?ooo`0B02`/000]<000<4@6
031:100`FP<0<ed003UO0012H@00AEh004MQ0018IP40AfH004QX0018JP40AVd104I]0015J000@V@0
0P15HP0204UV000W04QW0018K000C7<004Ya001:L`00B7L004Mi001;NP00Bg`004Uh001=N`00CWX0
05:00P1ENP00EWD005Ue0@1IM000FGL005U_001JL@00FW0005Y/001JM@40EW4105ee001NK`00GV/0
05mX001NJ`00Gfh005iX001MI000Ff8005]Z001IIP00FFL005Y_001QL`00Hg`00080IWT002L0IWh0
06F10@1UT080Ji4206b?1@1ZSPX0JI0<06B?2@1PU0P0HIT:06>K2`1WU`L0K9D306nD0@1_U`00Ki/0
06fN001^V`00KIL006bC001ZU@00KI`206bM001_WP00LYT007>J001cV000MIT007FG001cV`00LiX0
07FJ001iV000NI`007FO0@1eX@00M:L007BX001c[@000P1e[P009`1e[`00Mjh007^`0@1k/P80NK<1
07Zg0`1e_PH0M;l906k01@1``P<0M[l007S20`1eaP@0LlH30776101ba@@0M<D707C61@1ga@<0NlL2
07k81020aPD0PL@208;6001oaP40P/P407k82@21a`H0Q/D108W20@2:_`X0PL8<08704029_Q80SkdE
09:n4`2D_@l0RKh=086o3`0208c03P0W08Fo402:_A80V;/A09Nl402H_0l0S<@=08_:3P2;c0l0RLD@
09305P2G^ad0VkXI09jj402E^`d0T[/?08c06P2=^al0T;LO09Ne5`2K]@l0W[P<09Bl602G]bD0WKPJ
0:6h402R^@d0S[`E08S07`2O/A`0XZlE09Nb602R[bX0ZZ/_0:>f;02C^S00R[/_08?<:@24dRD0Q=@[
0080Q<l]02L0Q=4Y08OB9023dad0P]DI08;D6022e1L0P]@D08GB4`25c1@0Q<dB08KA5028dQ40Rm0@
08_?402=d0h0Rm4A08SC4@23e1@0RM<F08C@6@26dQD0Q]DC08CF4@28dA<0S<dA08O;4@22ba80OLlD
07oB3`1ndA00N=0=07K?3P1icPh0N<h=07_:2`1oc@/0PLX;08;53028`0L00P2>/`002`2?Y@00SYh0
08VL002:W000SZ<008jU0027X000Q:0108>M0@23V@00PY@00080QI<000T0PHh007j90020R@00Oh/0
07f7001hOP00MX<007B0001`NP000P1bM0003`1aM@00LWT0079n001`N`00K74006IW001RG000I5h0
069O001QF`00H5`0061N001SG@00H5d005UJ000205UH000A05]L001MG@00Gf0005]M001FEP00CTd0
04Q60018A`00AdD0048n000g=P00<Rl002/[000S6@0050l0010700050P00O@00000<0?ooo`002P3o
ool0500^=`00<Cd0035I3@0cGP/0<f8703I/0`0gJP00@6`004E^0@16K`80AgH304Qc0P14M@80@WD3
03id100mL`80?Vh0041Y0015IP00AVL00P19K0009`1<K`00BW<004]h0019M000BG<004Qe0017M`00
Bg`004Yh0019N000C7X004ij001BM`40DG<005=Y001FL@D0E6/105AY0@1DIP00DUh005AQ001CFP00
DV00059M001EH`00Eeh0055L001BFP00EE/005IS001DH`00F6<105UT0@1HI@40FfT105QV001MK000
H6/006Ab000206Aa000W06Ef001TN`40HX<206FB0`1UT@H0J9D;06V@2P1VT0P0HYD906:K2`1XV@X0
K9P506jE0P1_U`40KiX006nL001^W@00JiX106bF0@1]U`40K9P006fM0P1/W`00L:<007:P0@1`W`40
LIL207FF001bT`00M9L007BK001dXP00MJ0007JP001iX`00NJT007F/001f[@00M[000080LK@002L0
K[4007:`001h/P00NK<007Nc0@1h]`40NK`407S21`1``0D0M;h207Zm0@1k_P80OL0407c20P1ja`H0
NL8607K2101aaP<0KLP407C:1@1haPL0O<D607o20`20`@00Nl@007c10`1n``D0PlD308K20027a0P0
QL@;08733@24_Q00TKdE09>n4`2I`0l0Tl8=08S13@2>_Pd00P28`1<09`2A^1D0XK8F0:Nd4@2P]Q40
U[`>09;33@2BaPh0SLXB08_35P2@^aT0TK`M09bk5@2T^0T0X[/<09Zn4@2<^al0T;`K09Rk4@2H^Pl0
UK/;08k1502=`1d0UKHU0:6b6P2M^Pl0Tkd@08[05`2:`1/0WkHE0:2c3`2K]1P0ZZdW0:j[:`2P]2d0
S[Pb08Vi<@24ab/0QllR08OB:P0208GB:00W08?A9P26e1h0Q=<K087C5`21e100Q=@@08GC3P23d`d0
PM4>08??3`25d1<0RM0D08[B5@2=e180S=8@08KC4P25eA40Q]DG08SB5P27caH0Pm4E08?D3`24ea00
RMDC08SA4`29c180Q/XA087=4`23d@l0O]4>07kB3P1oc`l0O//?07[=3P1jb`l0Ol/=08O6302<_PH0
TKD10080Tjd002L0TZL008nL002:V000RYX008bP002:XP00QJ<008>U0020W@00Oi@007jA0022T@00
PID008><001nQ000Nh0007f5001nR000N88007J1001fP000LH0006mi001^M000K780079d001dO@00
N7P007Ag001YJ`00Hf<0065P001SH`00I6D006EV001QG`00H5X005iB001HDP000P1GE000401HFP00
Fed005aK001HE`00DU@004]:0016A000AD80048o000o>P00=S<002dX000T7@005`l000/500020@1n
000000`0oooo000:0?ooo`0D0395000cC`00<fP:03A[2P0fK0P0>Vh303]^000lK@40@G@4041e1`13
O0L0@gX403me0`0lL0<0=G4603A_100gKP80=f`103eY0013J`0204=_000B04Ma0017M000AGD004Ea
0016K000B6P004UZ001:K000Cfd004Y_001>LP00CG8004a_001<IP00CEl004mU101=FP40BU000P1<
D@004`1=D`00BD/004UA0018C`00BU0004iI001<FP00E5T005=I001FI`40EVH205QT0P1GK@@0Dfh4
05U`0P1MK@40Gg00061]001UL@800P1SL@009`1PL@00HW`106F30@1VSP40II4406VE1@1YTP@0I9<5
06JE301SV@d0J9L706ZF0P1ZUP40KYT006bL0@1/V`40JId206RM0P1ZV0<0Ji@106jA001^U@40KIX1
06nP0@1aX@80KZ03076J0P1dU040Li@007>L001`X040KjP1076W001dZP00M:T107B_0P1b/P80L[<0
07:d0@0206je0@0W06Vi0@1/]P40L[D007:d0P1g]PD0MkD207bj0020^@40O;T307Zg0@1i^040M[/2
07Zm0P1l`080O;h207_2101h`080L/D207?61P1ea0T0N/8607k30`21_@80Q;d008;0001m_P00O[h1
08?10@28`@00RL@;08?53021a@h0Ql8@09?05@2I`Q00VL0<08k13P28`A40TL4B0080SL0B02L0V;XF
0:>c6@2S/QD0VKP?08o64@2F`@d0UKl?09;05`2<`1T0T;dH09Nm5P2N^Pl0X;P;09Nl4@2F^Ql0TkLM
09Bl5@2M_0l0U[/=08nn4027aAL0Sl0M09be902U/Ah0V;PD09>n8`2B_Q/0W[PN0:6f5@2B^a<0R;TS
0:2^9@2ZZR/0W[8_08fh<`27]bl0Q/X[08G>:027dBT00P27db<09`23eB40QMHJ08CD5`21e1<0PM<@
083D4@23eQ00Q]DB08CC4@28dQD0Qm<G08OB5@28dQ<0R=8B08;D4P20e1T0Pm@J083C7@24dQT0Pm0G
08;B4`1ne0l0P=@@087D4`23daP0Qm4C08_?3P2:c@d0QLl>07g@3P20cPh0P/`?087:3P1nb0d0OLD>
07o63P24_0h0S;D409:`000209>^000W092Y002;XP00RYd008RH0024V000QY/0086Q0020YP00Oi`0
07j@001lR`00OXh0086A0023T@00OhT007b4001oQP00OHD007b2001iP000M8000761001`OP00LWP0
06ia001_L`00LG<0079b001/N@00JG@006I/001TIP00HfH006AX001UJP00HV8005eK001JD`00Ddl0
0080EE8000l0FUT005YN001EF000DU<004a?0015@`00@400040n000j=`00>3@0030Y000S7@006QD0
00`600040@00O`00000<0?ooo`002P3oool0500_C`40<UH003=X1P0hJ0L0?6D603iX0P0mI`00>FP3
03Qc1`0hM@X0=gP;03Mi2@0dM0D0<Fh502i]1`0]K0D0<V`403=[0@0hJP00>VX00P0lJ`009`11KP00
@Fl0049a0012JP00@V0004=J0017F000Bed004]Q001;H`00CFD004aO0019E`00AeH004E>0017C040
?d0003/e000n?P00@D@004U90014A@00@d4004U;001:D@00CV<004]X001AK000EF/005E/0P1GMPD0
Eg@405Ia0`1GK@<0Fg4105id001UM`00I7D0061g0002065h0@0W06=h001SPP00IX@006V=0@1ZT@40
JYH106ND0@1UU`<0I9@:06:D2@1QU@<0II<106JF001WU@00IY8106:@0P1UV0<0IiP306ZF0`1YT`40
K8l006^?001[TP00K9@106jI0@1/VP<0L9/207:I0@1`W000K:8106^X0@1[[040K:/1076^0@1_[@<0
L;45072c0P1`]`40J[L20080J[T202L0Jk@106ja001^/@00KK@407>e2@1h]0<0O;D007jf0@1k]040
MkH107Jg0@1e^040N;/307Vl101j_`D0NKl807G01`1]`0@0L/8607Jo1`1k_@@0P[h1086n0@21_`00
Q;d108>m0@22_000O[d008:n0028`@h0Ql4?08S04@2A`@h0V;h>09g03`2D`@d0QLH?08K6402:aQ<0
0P2@`a809`2?a1H0SkdD08Zh4`2=_0`0Tl4<09713@2;_A@0S[XN092j6P2L^A00X[L<09nj2P2O^@d0
UkTH09Zh9@2O]1l0W[LI09ji4`2I^a40TklE0930502A_200WkLT09fd5P2Q]1H0V[@L09^g902X/B<0
Yk4E09>f5`2:^b@0XK8U0:^_:P2N]3@0SKLf08Rk<026b2h0Ql`^08C@;00208KB8@0W08CE7021eQL0
PMLF07oE5@22eAD0PM<J083D7P21eA`0PM@E08GC4P28e1<0QM8A08G@3`22d@l0Q=8A08;B4`23d1L0
Pm4N08;?6@26d1D0Pll@083@3P1nd@h0OmD?083H4`24da40Q]@@08?C3P1oe0h0O]4=083<3@1nb`h0
P<T<07g83@1maPd0O<4<08:d1`2>[P80SjL00080SJL002L0SJH008fK002:V`00RID008FB0024T`00
QYl008JP0026WP00PY0007f40021Q000Phh008BD001oT000PHT007j6001lP`00NhL007Z2001iP`00
M8@00763001aOP00KWL006ad001^JP00Jfh006Yb001XLP00J74006IY001SI`00H6L005iX001MH`00
GUl005QF001FD@000P1HE@003`1HE`00EUT0059E001>D@00B4P00451000l>`00=SD0034/000^9`00
91X001L@000>20001P800040001o000000`0oooo000:0?ooo`0D031:0@0aC@00<e4003YK0@0hF040
>U/003MM0@0`HP<0;Vd602eb200^M@/0;g<<02e^2@0[I`D0:fH502]T100`I@<0<fH103EV000gI002
03]Q000W03]O0010I000?f<0041K0011D`00?Td004990014D@00AUH004AF0016D`00@dd004540010
@@00?C`003De000a:`00;2H003P`000o?`00A4P004I80019B`40CEP104iP001?KP00CG8005Ib001G
M`00EgH305Yn1@1HNP<0FgD105Ua001ON000HGT006Aj001TO`00I8800080IHH102L0HH8006:9001U
R@40HY4406FC0`1WV`40IY/006:F0P1RU@L0H9@6062D0P1RSP00II4106J?0@1UQP80I8D106>>0`1R
T080I9H306JE0P1[T`00Jhd006N>0@1XT`40Ji/206fK0P1_XP40LZ<1072U001/Z@00JJd106^^0@1/
/@40JK@306^c101_[P@0LK0206jb0@1/]0800P1^/P409`1`[@00LjX007FX001^[`80LJd307F_0P1e
/P00MK@107Fc0@1]]040KkL1076e0P1e^@<0MKh307Nm201g`0X0Lk`906o11`1_`@P0L/0707Vn0`1m
_@40OL0007k10023``40QL4208310@1n_P40Ol8108340`2:`A<0UklC09S03P2B`0/0T<0<08k32`29
a0h0R/PC08c54P0209;14`0W08g45022`a00NLL;08712P2A`@d0T/4A09Fn7@2G^280VkHH0:2e3P2R
]`/0U;d<09ff502I/QX0WK<Q0:Bb9`2J]1H0VKHA09Zj402H`1L0T/0G09Zh7@2O/1X0W;DB09^c4P2O
/AH0W;0X0:B_9P2/ZA@0Vk8C09:i7`2O]RL0Y;4/09je<`2@^300Q[l[08?6:P27bS40Q</a0080Q]8W
02L0RM@N08KF6@1oeA@0P]DE083C5`1ldQT0Nm8I07WD5`1ke100P=H?08KE3@28e140PlhG083=4`26
cQ<0Q/hA08O>5026cah0RL/F08S=4P29cA80PLdA07k>4P1ne140PMP@08GD4@24eQ00Om<?07_B3@1o
dPd0O<l>07k;3P20a``0O/T<07c6301o_@L0Q;8108RW0@2<W`000P2;X@009`29X000RYP008ZF0029
T`00QHh008BD0025V`00RZ4008JM0021S`00PX@008230020QP00Ph/0082>0021S@00OXH007j5001l
PP00NX<007Z6001eP000LX<007:2001cOP00LW`006e`001ZL000J6l006M/001XK@00IF`0069U001N
I@00GF8005aP001JHP00Ee`005QH000205AE000>059E001CF000DEP004aB0015A000@3d003Td000_
:`009b00024I000E3`002`D000D300020020000000`0oooo000:0?ooo`0D03510@0b@@00<d@003=;
000_B`00;4`002iH0@0ZG`<09f`402I^100UKPL0:F/802MS1@0WGP@0:Uh202eH0@0aD`40=E@003QE
000hE00203Q?000H03M?000fD`00>e4003a:000j@`00>Sh003`n0011@000?d@003i1000l?P00>T00
03Pl000j?@00>3X003@_000`9`00<BP003lj0016A`00BE<004UK0@19H@<0C6P10P1AJ@003@1FJ`00
F6d005aa001MLP40GgT205ej0@1ON`00Gg`005f0001SQ@00Hgl006N60P1TR`400P1RT@809`1MS`00
G98105b<101MS`X0GY@805fF0@1PUP00H9<106:D0`1NT`<0H94106:8001PR040Gh@306:20P1NP@00
G8T105j90P1RU`L0IIX406ZG0@1VSP40Ii8206BI0`1YX@D0JjD306nZ0P1^Z040KjL006ZW001Y[040
KZ/106n/0P1Y/PD0JkD406b_0P1a[P<0Kjh406j/0`0206fZ0P0W06bX0@1dYP00LJH106j/0@1_Z`00
LZX106n[0P1X/080JK4206Rc0P1W]`40K;8107:g0P1d^080MkT407fi2@1h^PL0MKd807G02@1d`@X0
M<8807G00P1d`P00NL@107o80@22a0<0O/4307k00@1m`@40O<8608Zn4`2D_A00VKh=08c22`23a0/0
R/4<09333`2;`Q@0T;dI0080U;hI02L0Sl0@08?42`1ha`T0M/H:08?24@2?_QL0V;XM0::c902R/aD0
Xk4?0:B`2`2B]0h0WKDC09Fc7`2F/B@0XjhY09Vb4`2R]140V[/B09Rn502@`A/0UkLJ0:Jb5@2N/@h0
V[PB09Ne802L/BH0YJhU0:Z]5`2U/AL0W[8L09ng:02O^2T0V;T_08c1;@21bbT0O<hW08;;;@25cc00
0P29dBP09`2;e200QM<L07oF6@21eAD0P=DF07cC601jeAX0NMDM07OG601meQ<0PMD@08WC4P25d1`0
PLlE08O>5@27d1H0QlhF08O97@25bA<0P//C083=4P20cQ80P<TF08??4@26eA00R=@?08?@401lcPl0
Olh?07cC3P1ndPh0O/h=07o93P24a@d0P/07086f0`26Z`00QJH008JN000208VO000O08VN0029V000
QYH008ZC0028SP00QY0008ZD002:V@00QIX008B>0022RP00OH8007]l001lOP00OX4007n8001nP`00
Nh4007j3001kQ000OXT007N4001cPP00LWd0071m001cP000LWD006ia001YL000IVh0069W0002069V
000605eQ001LH000Ee`005AI001FF`00EEL00P1CD0003@1<CP00CT/004]=0019C000@D4003Tg000b
;0009b0001dD000E2`002PH000H300030P00P@00000<0?ooo`002P3oool0500_=P00;3L002`e000^
?`00:D0002A5000XD@<09UT602AM100UHP<09f0302YJ0P0YEP809e@102UC0@0_C000<D4003<m000a
?000<Sl00P0e?`00300b>@00=Ch003Lh000b<P00<CD003@f000f=000=C8003Dd000g=@00=S8003Lf
0080>3`001T0>ch003/l0010>@00@Sh004I>001=H000BfH004iZ0@1BK@40EGD105E^001EJ000F6H0
05MW001HKP00Ffd005ee001MNP00GWl005n3001JR@00Gh/00666001NR`L0Fhh30080FXl202L0G8`0
05j8001LRP<0FXh805RD1`1IT040G90005j@001OT@40GI0005j;001RQ000Hg`1065l0P1NO@40Fgh0
05n40@1OR@40I8d106RL1P1XU`40JIH106RE0P1XW@<0Jj8506jX0`1^Z`40K:T106^W001XY040IZ<2
06ZS0P1^Z@<0JJ`306Z_0`1X[`P0Jk4906^^2P1Y[@T00P1WZ`L09`1WZ@@0LJD1076S001^ZP40Jjd0
06n]0@1/Z@40IZX306>a101R/`<0K;8107:d0@1d]@40N;@207Ng0P1h]PD0MKL407Fi1@1i^0D0N[/6
07Jn1`1b_@80MKl007[0001n``40O/8307jn0`1n`080Nl0107[10`2;_a00T/0?08Zm2`27`P/0RL<;
08_23P29`A80RK`G08fj6@0209Jj5`0W092n3@29a0X0Q<D<07[4401o`A@0QklE09>n6P2R^B<0Z;DA
0:Z`3P2W[`/0V[8@09ff5`2A^280U[<R0:R_6`2V/0l0WK@>09Jk5P2B_Q/0RkXJ09Nj602S^140Y;H>
09^f3`2I]b40W;<T0:N_902W/A/0Xk4I09na8@2G]R/0U;X[08jn;P27b2d0P]0_083;:`25b2X0QLd/
0080R<l[02L0R]4W08CD9P20e1/0OMHF07[F601heQT0OmDH083D601ndaL0P=@D083C4@22eA<0P]HI
07oD6@20cQT0P]4K08K@6@25bQX0Q/TD08C;5023cQ80Q<lB08;>4P25d100RM4?08_A3`26c0l0O/hA
07kC401jd@l0N]4>07oA3@22b@h0Q/0908Vi0027/P00RJP008ZU002<X@000P2:Y0009`2;W@00QiL0
08JF0026U@00RYD008VC0027U`00QYL008>A0020RP00OhX007Z6001eOP00MgL007Ig001lO@00Ng`0
07Ui001gNP00Ngh007Z2001hQ000Mh@0071l001^O000KWX0071f001^MP00K74006Q_001VK000I6X0
06AY001QI@00FUl005EI001CE000D5<004e>000204m7000=04Q20015?`00@T40040n000k>P00=S40
02/S000M5@0040L000P500030`000P4000400021000000`0oooo000:0?ooo`0D02D]000W;`009S80
02Xe000U=P008cd002I80@0VC@<08dl202M?0@0XB@00:4H002a3000Z?P00:c/002/c000W;`00:Bh0
02TZ000/:`0202hc000702d[000]:P00:bD002XV000]<000;c<0030_0002038_000N03H_000c<`00
>CT003]2000oA000A4T0049:0017DP00BeX004aU001BK@00Dfl005A^001CK`00E74005I_001DJ`00
F6L005ES001KKP00Ffl005Ub001LO000Fgd005eo001MO@00GW/005mj001QO`<0GGl20P1JOP409`1I
Q`00FhL105V?101DR`@0EHl305B>001HSP40G8h105f=001MR`00GhP00623001OO000HgT006=j001S
OP00Hh0006F8001ZT`00Jil206NM0@1WW@00J9l106ZS0@1^X`80K:8106bR001XY@00Ij8006NP0@1U
W@80J9/206VR0`1VY@40IJ/206:]2@1S/@T0HK0:05fb2P0205n^2@0W06V[1@1^Y@40L:H006fT001X
Z`40IZl106N^0@1X/0<0Ik<606Bj101[]`<0K[L507Bf101d/`<0M[D207Ng0`1e^P@0L;P407>h101h
^`D0N;X707Jk0`1g^`40N;h007bo0P1k`0@0O;d307jn0@1l`040O<020970302=`P`0PL0;08;52`2<
a@`0Q<@B07c05`28_A<0UkLD0080WKHE02L0T[P;08g04@25`1H0N/4H07S35`1k`aP0Pl<F08[44`2Q
^Q00[;<=0:6_3@2L/QD0V[8W096g9@2J/ad0[:l>0:Zb3@2Q]@h0U;TM092f902O/ad0YKHH0:>i4P2T
^0l0W;HA09Bg6`2I/R<0X;8S0:6e802L]b@0Uk8Z08nf;`2<^S<0Q<<a087;<@21cC<0P/H_08C6;P25
cS000P22dC<09`22dc80Pm@Z07_E7`1ef1X0LmLJ07KG5`1oeAP0PMDM07cD6@1je1T0N]8P07_E7@20
eB00PMHO07k@7@20cR00PldP08G@7024dQ<0P]4C083?5@1md1H0O/lH07kA4P20dQ00P]4>08;B4@20
e180PM<?07k>3`1od0h0P<`>08?4302=_0H0S;H008^b0029[@00S:L0092Y0002092T000W08^G0027
T000RI8008NC0029V@00RIP008JI0025TP00PHT007^5001nQP00NhH007Uo001eN@00MWH007Ei001h
M`00MWL007Ed001gN000NGT007N2001gP@00Lgd0075k001cNP00Kg`006ei001[M000JG4006E[001U
KP00IV`006=]001LH@00EeD004m?001:B@00AT@00080AD4000/0@Sh003dg000g<@00=2l0034^000/
:00081T0014<000710000`8000400023000000`0oooo000:0?ooo`0D024Y000S;P0092l002Db000S
=P008SP0024l000S?@408Sd002Lk000W=`009S@002Td000W:`008bH002<T000R8@008R8002@R000V
900202/]000W02TZ000V8@00:2<002PT000]<@00<C8002//000a;`00<Bd003Db000h>@00?44003i>
0012D`00AU4004MG0017GP00D6T004e/001CKP00DV`004eW001<JP00CF`0055^001BKP00Ef`005I[
001FK000FVl005Q^001IL`00Eg<005Qc001IJ`00FF`005Y`001JK`00G7@00080GGH000P0FXD005N;
0P1HT0L0EX`705J?0`1FRP00Ehl305Z80@80FhP001d0G88005f6001MP`00HH80065o001YQ@40JhD0
06Z=001XTP00I9T006>J001SW`00HYh006NO001YVP00JYT106JH001TW000H9h1066O0P1UUP80I9`1
06:I001VWP00HJ4005jX0P1LZPD0GZh705bb2@02066a1`0W06J`101YZ`<0KJ`206fX0@1XZ`40IZl1
06N`0@1//@@0L;@506nj1@1/_0L0L;/706jg201b]P@0N;<107Zd0P1g^@<0LKT5076k1@1f^@H0M;P6
07Nk0`1f_P40M/0107c00P1o_080OkX2086o0@21`P00O/8107_31@26a0/0Pl<?08G44P24a1H0Q/0G
08Fm5P2D]Q@0U;<?0080V;@A02L0SkPD08fm6025_Qh0OkdM08>l6`28_A/0P/<F08C95@2G_@h0Y[L?
0:2c4@2N/R@0W;<Y09^g702U]a@0Z[<<0:6_3P2I]140U;LS08ng9P2J/2H0YK0N0:Fc5`2R]1<0V;@A
09Ff5`2B]R00U;DU09Zj:@2I^B`0TkPb08bi<@29^C<0R;hc0874=01maC/0OLHf07g:=01mccL00P20
dS<09`1ne3<0OMH[07[G:01ff2<0L]PN07GG601iead0OmDN07_D601fe1X0NMHQ07_E7`1nea/0PMLK
08?F6P1ocad0Q<lP083A7@20e1P0OM<I07kA6`1ldQ`0N/lM07cA6`21dQD0Om4D07_C5P1hdQh0P=0D
07o:4022b@h0PL@<08Vj202<]@@0S[8008ne002;/P00S:/009>Y0002092V000W08nM002:U000Qi40
08>D0029VP00QiT008>F0022T@00Oh/007b7001jQP00NX8007]n001dOP00LgP007Mh001kO000N7`0
07Qk001cO@00M7L007Ak001dO`00Lg`0075k001_NP00KgT006md001ZLP00IFh0065X001QJP00Hfd0
065Y001LGP00EUH0051<0018B@00@d800080?d4000X0>c/003<b000_8`009ah002@L000O6@006100
00P600010@000@00Q000000<0?ooo`002P3oool0500Q:@008bh002@_000U<P008cH0028h000Q?000
8cd1028m000W>`009cL002Hd000Y=0009b/002<V000S90008R40028R000T8P009R@00P0[;@009`0Y
:P009R4002PS000X9000;C40034b000[;000<Bl0034]000e<P00>3T003a1000nCP00@U<004IA0017
E`00Aeh0051Y001=K000Dfh0059/001=I`00C6X004e/001AKP00DVh005M/001FJ`00EV`005Y_001H
KP00FG<005Mc001HL`00FF/005U/001JL000FVl005ad000205ef000805Z5001GR`80F90705J<1`1F
S`<0EXX005N?0`1JR04205^8000M05b2001MQP00GH<00662001QO`00JHD106^5001ZS@00J98006BI
001SVP00Hil006:N001WW`00JIX006ZI0@1VV000I9`0062N0@1QW`80IIH206BL0@1RV@00IYh0066Q
001NZ080G:X505j^1`1L/PT00P1Q/@L09`1V/0@0JJ/306f/0P1]Z040J:/106J_0@1W/040K;44072d
1@1_^PD0K;`7072k1`1^]`P0L[H407Rc0@1j]080MkT3076i1@1a^`D0M[T607Bh1P1g^`<0M[h107K0
0@1l`080Ok`207nj0P21_`40PL8007k20@1k``D0Q/@;08?33`25a180Q<@F08K05`25_AH0U;HD09Bc
3`0209Rd4@0W08nh502=_AP0QKhN07nm7@23_1/0R;dK08;35P24bAD0Ukd>0:Jg3`2P/a40W[8T09bc
:@2K]a`0YKLD0:Zc302Q[`h0VK@A09Bg8`2?]bH0V[0V0:F`7P2U/aL0X[@C09Rd4@2E]QL0T[HP09Be
9@2J^RT0VKT/09>h<P2<^C40RKTc08Rn<`21a3@0OLDk07g6=P1mbS@0OLlg0080P=8c02L0O]@c07gF
:`1jebP0M]PS07;H7P1eeaP0NMLM07oE7P1ke1P0M]@J07WF8@1keAl0O]LK087G6`23eQX0OllM08C?
8020dAd0P=@H07gC6@1ndA/0O=8L07[?7@1ldA/0PM8E07oA501kdaH0N=8N083@501obQ00P/T>0874
3029^PP0S;D408jb002?]@00Rk8008b[002CZ@000P2@YP009`2?W@00RY@008NA0023U000RIX008NI
0023UP00PY4007n;001lQ`00NXH007Z2001kOP00M7h007=h001gN000Ng`007Ql001hN`00Lgd007Ag
001dN`00M7l007=l001aN`00KgX006mi001_M000JW8006E^001QJ000HFX006=]001QJ@00G5h005IF
001@C000B4T004=2000203m1000:03/k000c<P00;b<002LN000T70007aT001P@00081P000@400040
08@00000303oool000X0oooo01@07bL002<^000T<`0093L002@h000S=`008CL002@c000R<0009B/0
02L]000X;000:Rl002LW000U80008B00020K000N6@008R8002@Q00809bX002L09bd002TZ000Y:000
:BD002hc000b<P00<2d0034/000c<000=CD003/o0010AP00A4h0049?0014C@00B5<004QF001:GP00
BeX004aO001<H000B60004MU001:I`00D780055d001BL000EG4005E[001HJ@00EF<005=X001BI`00
DVX0051V001>I040EF/105IZ001IL0000P1JN0409`1KR080F8/405J?1P1DS`D0Eh/105F8001FRP40
F8L105^7001GQ`00F8D005N9001GRP00FHT005j;001RT`40I8l106V>001TSP00Hhl106F?0@1VT@00
Hhl006FB001UTP40IY4106>>001OT000FI<205VI0`1LU@40HI@005nD001SV@00H9d005nQ001NY@40
HZT206>[100206>b0`0W06>c101S]0@0Ik0506R_0@1[/080Ik8306b`0@1^[0<0LK47076j1P1[_@H0
KKd706nk1`1a^0@0M[D207Je0`1c]`<0L[@407>f2@1b]`X0KKP9072i101c_0<0ML0207C00P1i`080
O;l208300P1n`@40OL4107[32`1m```0Ll8>07k06`23^ad0R[`J09>i602H^Q@0RkT>0080TkHI02L0
TKPC08^i5`28^R@0S;PU09Fc7`2N/QL0T[/A08g85`2@a100VklA09Vj602J]bH0W[8Y0::g6P2W^Ph0
Y;D<09Vh302I^Q<0UkLQ092d9@2@/RX0WJlT0:V`7P2Q/a`0VKPI09Ve5`2<^240S[`S096g8@2G]RX0
TkTa092h<@2@^3@0S;Tf08Bn>P1j_S`0MlHl07O:?01iccd00P1kccL02P1kd3<0N=@[07OE9@1deRD0
LMHP073H701dfB00M]TP07SI601kf1H207SF6`0K07[E7@1meQh0OMPQ07SH801ke240N=4N07gA8P1l
dB@0O=8Q07cD7P1ge1d0MmHR07[G7`1he1P0M]8G07K>6P1nbA<0P<L@08>n2`25]P@0Qjh108^/0@2=
Z`00Sk40092a002?[@00Rjh00080SZL002L0Sj0008fM0027UP00QIL008NF0026T`00PI40086:0020
S000P8l007b9001jP@00N7d007Ei001fN000NG`007V0001kP@00Nh0007Ml001cNP00LgL007Ai001b
O000LGd006ee001^MP00K7@006M]001RIP00HFH005iT001OIP00GEh005EG001@DP00BDT004E4000n
?0000P0h=@00200g<@00;RP002<L000K4P005Pd000l;000:10001040QP00000<0?ooo`002P3oool0
500M:0008C8002<j000P?00093h0028i000R=P008c8002<_000U:`00:bl002Pf000/>000:38002</
000P9P007B4001`J000O7P0081l00P0S9@00700W9`00:RP002d[000[:@00;2d003@c000a<@00<S@0
038f000e>@00?4@003m70010A`00@4D003e0000o@P00?D8003a5000oA@00@DT004AF0P12FP80AV<1
04YT001@K@00DFd0055Z001EJ`02059U0009051R001CI`00CfH004aW001>JP40CFT105A`0@1DKP00
F7@00080EgP102L0EGX505>41@1ARP<0DY41056B0@1@TP00CI4005>;001GQP00F8D005>2001GQ@00
F8H005V9001KR`00G981062@0@1OR@00HH@006210@1SQ0<0H88506260`1OQP40Gh`005n70@1QQ`00
G8L005Z@0@1KUP40G9@105fG001QU`00HiX306:I0@1SV`00HZ0106>W0@1YYP400P1ZZ0409`1XZ040
Ij/206VZ0`1/Z`40KJh106j^0P1`[P40KK0306bf2@1Z^0X0J[/406ni101a^0@0L;d206bj101X^@L0
I[P506Zg1@1[^`L0J[/906jh1`1`]`D0LkL207Bl0`1__`<0KLD407?30P1h`P<0O<0207Zo001h``/0
Ml<>06bn4P1e_A/0OKTP08Bk7P2:_1H0R;`?08nn400209Nj6P0W08ji6`2?]Ah0Rk8R09J`8@2R[QX0
YJd=09Nk3P2@aa/0TLDB09W14P2M_QD0X;TP0:Nd:02Z]aL0YkP@0::i3P2J_@h0V;`@09Vf6`2E/ad0
U[<O09Rb802L/Ah0V;8N096f7`2E]b80S[XS09:k802C^Al0TkXU09Jk;P2J^c00U;Xf08^l>`23_Ch0
O;ho07O3?@1gb3/0Mlm30080N<hm02L0N/lj07K?=@1edS40M]@e073E:P1_ebL0L=HX07;G8P1dfAh0
MmLN07GG7@1eeQ/0O=@L07gF7`1jfBD0NMPX07WC:P1cd2/0N/dZ07OA:01gdR80NMPF07OG4@1eeAD0
N=HJ07SF6@1ddQL0ML/F07o64@24_0L0R;@408Fa0P28Z`40RZX008bX002=ZP00S:/108fY002;Z000
0P2<Z@009`2<XP00RZ0008NN0026W000QIH008:A001lT@00OX/0082:001oR`00OXT007V6001gP000
MG`007Il001gO000Ng`007V4001hP@00M7/0071g001`M@00LW<0075h001`M`00K7D006eh001[N@00
Ig@005mT001LG@00F5`005UL001FE`00DE8004Q>0015A000@T0003Xg0002038a000902dW000S8000
6Q<0010:000<1@001@800040000000000@0008D00000303oool000X0oooo00D06Bl001Xd000O@000
7Sl002100002024i000<02@k000W>0009SH002/m000[@`00:D8002Hj000S<0007bX001hS000L7@00
7Al00`0K70009`0Q8@009B@002P[000Y:000:bX0030b000^<000;cL0034g000a>P00=d<003I4000e
?000<cP0038e000d=@00<3@003Le000i>@00?DD0045K1P12H0D0A64204]P0019G`00C6L004YS001<
I000BUl004YT0018H`00BVL004a_001:L000CWP004id0@1AM`00D740051/0002059d0@0W04mg101B
O`@0DH<104n<001<SP00CI4004f<001@R@00DX0005V0001EN@00EGP005Mn001GP000FXX005b6001N
QP00Fh8005^0001IP@40EhD605N42`1FR@L0EXX105^@0@1LQ000H8<005io001NR@00GXh005nF001M
VP40HI`1066J0@1SW0<0IiL106FF001UX000Jil10080Jil002L0JJ4106RR0@1XX040Jj8106fR0@1a
YP00KZX106f_0P1//@T0Jk@:06be0`1a/P40MKH207:j0`1Z^PL0Hk/806:k201U^`L0I[/506^l0`1`
^0@0MKH307Bg0`1c^@40K[l406[51@1^a0D0M<8307[00P1i_P00N/<=07K13@1c`140M/0K07Zl7020
_Ad0P[lD08S13P2G`1D00P2I_aT09`2?_Ad0T;TN09bc7P2O/ad0W[@I0:6d3`2C`100S/XK08o84P2G
a1<0T/0F09Zm7P2S^RL0YK@G0:2i4`2N`1P0V<4F09S15@2J_1d0UkTN09Ji802F]Ah0U[8P09Bb8P2E
/BP0V;<X09Zj8P2O^al0WK/R09Rm902F^bH0V;X_09Fj=P2=_Sd0QkY0082k?01l_Sd0N<4k07S9@002
07K;?00W07K<?@1dcC/0M<dl073A>P1_dcD0K]Dc06oE:01af2@0L]HU07KJ901deb@0LmTQ07_F8`1o
eR@0P=@V083F9P1ldbl0M]0f077B;01/eRD0KMPP07;H6P1beQ00MM@A07KB4P1ddA@0N<dA07g93`26
_``0SK0108^/0@28[P80R:l108J/0029Z000Qj@108NY0@2:Y`40Qj<00080Qj4000<0Q9P008FE0024
V0000P22U@005@20V000P9H007nC0022S@00PHd007n@001mT`00NXL007J3001fPP00MW/007=l001e
O@00M7/0075h001aM`00K70006e_001/L000JVl006Yd000206Qb000;06=Y001MG`00FET005=E001C
EP00CDl004a<0015B000@Sl003ll000h<P000P0`:`001P0Y7@006aD0014;000910001040008008P0
0000303oool000X0oooo01@05S4001Tb000L?@006c`001`i000M=P007cT002E0000V@0009c`002a2
000[@@00:40002De000P9`006Ql001/J000I5`006aT001PG00806a@000P07A/0024P000R8000:2P0
02PY000];P00:bd002PY0080:bd001d0;SL002li000]<@00:bd002`^000`=000=3D003@j000kAP00
?Td0045P2@11HPP0@U/204AI0013EP00AE`004IL0017G`00AEd0041J0014H@00Af<004]]001:K`00
C7H004ad0019LP00Bg8004e/000204e`0@0W04aa0@1AN`80Cgd104n6001=P`00Cgh0051k001>N000
DWD005Id001EM@00DW0005=`001DL@00F7T005Ub001JN@00Egd005Ao0@1CO`40EH0305N11@1FQ0<0
EHH105N<0P1KQ`00GH4005^0001NP@00GXL005nE0@1MV040GY`3066K0`1TW080I94106FB001TUP00
J9X00080JiX002L0JIX206VK0P1/W080KIh206jM0P1bXP40Kj<106b[0P1/[PH0KJl806n_1P1bZ`<0
Lk4207R`1`1c[`T0KKH;06fj2P1^^PP0LKT4076f0P1^]`80L[@107Fc001c/P40L[T307;0101d_`@0
MK/307Rj0@1k_040O/@>07c03`1i`A00OL8K082n6`28_1X0S[`F08[03P2>`AH00P2D`aT09`2=`AL0
UKdI0::k6`2L^a/0UkdK09fk3P2A`0h0RLPH08W66P2;aQP0SL8G09G26P2L_1d0WkTK0:2l6`2K`2<0
T<<R09728P2@`2@0S;lS08jk9@2C]bD0Vk<R09Zb9@2O/RX0WKPX09Zo9`2K`bT0Ul8Y09?49`2AaBL0
U<@]08o2<`2<`C@0R<4e08:i=@1j`3L0N<Ll07O9?P0207O<?@04073@?01bdSX0LLlk06o?>P80Jlhm
0240K]0a06oE<@1aeRh0M=P[07GF:P1eebL0N=DV07_E:P20dR`0PM4U07_E9P1gebH0L=@K06OC6@1Y
e1/0KM8L07;B6@1bd1L0LLlE07O;401oa`h0RL45092j0@2?[`40SZd108j[0@2>Z`00RZX008^V0027
X`00QjL108JV0027X`000P27X0009`22V000Q9<0086?001nT000OY@0082K0022WP00P9H007jC001m
TP00OYD007fH001iS`00M8l007F=001bP@00L7T0075g001aN`00KgX0071f001]L000Ifl006QY001W
J000IVT006I[001TK000H68005iL001FFP00E5L0055D001?C@00ATT003i3000k?000=bl002hV0002
02LS000401lF000D2`002080008008X00000303oool000X0oooo01@04S8001@b000J>00073H001dc
000N<P0083D0028i000W@`00:3`002Xl000Y>0009C40020V000J6P005AD001LD000F50005Q4001D?
00805Q4001T071H001lJ000O800092L002DY000Y;0009bT002<R000S80008Qh002@R000];`00:R/0
02`^000/;`00;S4003Hl000hB000>e@003iF0010G`<0@Uh3045E0@12DP00?Tl00080@5P000`0?UD0
045I0011EP00A60004ES0019J000AV@004IR0018I`00AfT004Y`001;J`0204Y[000:04eW001?N0P0
D7P504mk0@1:MP40C6h004eZ001=H`00Cf@0051V0080D74000P0DW@005=`001EK@00DVX005A^001C
M@40CG/304ij0`80DgT10140EW`105=i001EPP80Egh005Ym001KN000GW`005eo001PRP40HXh106FD
0P1UU@80I9<1066?0@1SS`00II4006FE000206NB000W06RD0@1YT@80K9P206^L0@1_W`<0L:<307:U
0P1_[0@0K:`606V^2@1[/@X0JZd5072b1@1d/@T0Ljd6072b1`1`]`H0M;H607Nd101c]P<0KkH107:e
0@1d]P00M[0107Vc0@1i]@40N[`207Rm0P1i^040OK`208;23@1o`0l0QKlA08Bl402;^Q`0SkPG09:k
5@2<`180Ql<D0080Ql4G02L0R<8B09:n4P2F_1D0TkdL09347@2D`A@0U<<@08o4402;aQP0R/LI08_5
5@2@`aH0Tl0I09Bm6P2F^Qh0U/0U09?19P2B`RL0R/LU08S48P29`2H0S<0T09S08P2F_al0VKdN09[0
:@2H_RT0T/0Y09:o:@2?a2<0T<PS08o89P2;bbL0R<hX08;>:P1mbRP0Nl/]07K@;@1bd2d00P1ddbl0
9`1ce340M=<d07?B<`1]cSL0K<`i06_9@01^cC@0L=@e07?D=P1aeS00K]D`06oE9P1cdR80N]@T07[D
9@1jeB<0NmHN07KG7@1_daX0J=0G06G>5P1WcAL0L<hN07;:601haQ80P/0=08Zj1@2@]P40TK@0092b
002>[`00RjX008RV0027Y`00QZ8008RT0027X`00QjH008Z[000208BW000608FM0022U`00PHl007f?
001nS`00PI<00P21V`004P1mUP00Ni4007jA001lS`00NHd007ZA001iS`00MHP007>5001aN`00L7P0
079i001]M@00Jg8006M_001TJ000I6L0069T0080Gf@000/0GEh005UJ001GF000D5<0051>001:CP00
AD@003`o000i=`00<RL002<L0002020K000301D=00080`000P0008/00000303oool000X0oooo01@0
5C0001H`000J=@00734001d]000P;P008Bl0028b000W>@009c<002D]000R:P007R8001XI000D4@00
40d0018<000@3P004@h001@>00804Q0002L06QH001/M000L8@008BD0028U000S9P009BD0020O000Q
7@008Q`002@R000Z:`00:Bl0034g000a>@00=3P003M0000iA`00>e8003e@000lCP00@5@003i<0010
C@00?D/003mG0@0nEP00?5<003iH000oE000@Eh004=P0014I@00A5l0045F0014F000AU/004UR0017
HP000P18I`009`18H`00Af@004Mc2015K@40B74004MV0017H000AeX004ML0@16H040BV`104ec0@1A
M`00Dg@005=a001BJ000DV`0051]0@1<LP@0CWD404mf0@1@MP00D78004eb001>K000E78005E]001G
J`00F6X005Ud001LP000HGl006F70@1TR@40IXd406>90@1SR000IHX006RA000206R@000W06VD0P1X
U080IiX206ZI0P1/XP80KZP507:[1P1a/0T0KJ`606b_2@1/[0D0KJl406ne1@1`]@H0Kk4306na0@1e
/@80MZl207Jd0P1`]@@0KKD2076f0@1d]000NK<107Z_0@1f]080N;/207Nl0P1g_`80N/4407fm0@1k
aA00R[lE096n5P2D^Q/0V;PL09:k602<`QD0Ql<E0080QLDB02L0R<DC08k34`2>`1<0Rl0H08[26`29
a1D0R/HC08_64P27aa00RlL?0971402B`1@0T;lG08fn7@2?`240Sl@T09789@2=aRL0RLXS08O67P27
aB00QlDM08o86P2CbQT0U/PH09C6702DaB80UL8T08o18P2=a200SLXN08c?6`28dQH0RM4D08KB4`1o
cQ80OlhA07[=4`1fd1D00P1idAD06`1jda/0O=DQ07cF:@1aeS<0M=@^06k@<@1_e340K=L]073F;`1]
eRd0JM@[06[F9`1`eB00MmLL07[E6`1ldaL0NM@L07?D8@1`dAh0JM4L06c>5@1cbQ<0MlPF07_0401m
^@d0QZh508ZZ000208fV000:08nW002@Z`00RjT008RW0025XP00QJ<008BQ0025W`00QZ8008V[0080
QZ`000d0QZ4008JI0025U000PY40082A001nU000P9L0086I001lV000Ni<007f?001lS@00MhX00080
NX/001P0N8L007R6001fP@00LG/0075l001^N000JWD006Uc001WL000HfT0065S001MH`00G6@005MM
001CEP00DE4004a;0017@P00AD<0040n000i>@00=3<002TS000O600201D?000300/700030@000000
08/00000303oool000X0oooo01@05R/001L[000F:P007B/001`X000O:@0082P001lT000R:`007R80
01`O000L6`005aL0018C000B40003``000h:000<2P0030/0014:00804@h002L0514001/L000L7@00
82<0020Q000Q:00092P0024Q000R8P009BP002LZ000/=000;ST0034j000f@`00=48003=3000d@P00
<48003E3000gA000>dd003]:0010C000@4l003mC0014G000@5D0045E000mD`00>eT003aH000jF000
?EX003eA0011DP00@U8004=L0011G@400P11G`809`14H@40@V<0041[1015I`40B6T004MO0017F`00
A5`103mO0P13H@<0AVh304Ua0@1:L000CGH0051_001AKP00CFH0055[0@1?KP80DGH2055f0@1@N000
CWD004mc001?K000EW8005E]001GK@00F6h005Me001HM@00GgT005mh001QO000HW`006>70P1SQ`40
H8@106B;0@0206B>0@0W06NH0P1VU`40J9T006RF001/W`40KjD207>Y101_[PL0KJP406ZZ101YZ@80
K:h3072_0P1]]P<0K[D2076`0P1c/P40L[@107:e0P1`]`@0K[/307>k0@1a^040L[/207Fh101e^PH0
Kkd306k00P1^`@H0LL<907C0101g`0l0O[hB08[15P2=_Ah0U;TL09Jk702?`1T0T/0J0080Sl@G02L0
S/LE08c75@2=aQD0P/<K07g27@20`QX0PL<K08?45`26aaL0SLDG09G06P2D`1X0T<8G08k79@2=ab@0
R/TQ08c:902?ab80RLHN08[4702?aA`0S<PI08k95P2Ac1<0T/hG093:6`2?b1/0U//G09755`2=a1D0
SLLA08g93P29bPh0R/T=08K53@20aP`0PLD;08772@1lb0X00P1na`/09`26a0d0Q<H@08?B601keR`0
NMHT07GH8`1bf2H0KMPT06kG:@1ZebP0I=DT06SD901_dal0M]4D07S@4@1hd1<0N<lG07??801bcal0
K=4J07;;4P1kaa40Pkh>08:e2@20Z`<0P:H208:S0025W@00R9d008fT002>Y`00RjL008NT0028X@00
R:0008JO0023VP00Q9`008BT000208>S000A082N0024W@00Q9`008>E0022UP00OiH007j>001oT`00
OY@007Z@001jR000NhP007Z;001iS@00MHL007B6001fQP000P1dP`00501eO`00LGX006Ye001VL@00
IG8006EY001NH@00Gf0005]O001EF@00D5<004Y;0011A000>cX003dg000e<000<30002XU000L6000
5Pl00P091`000`050P000@400000002;000000`0oooo000:0?ooo`0:01DV000F90005R4001TP000H
7@005QX001TI000F5`006Q/001PF008051D000P04aD0014A000B3`003``000`8000;1P002PP0010:
0080514000<05aD001lR000P9P000P0Q9P006`0Q:@008bd002@/000S;P00:C4002T_000^=000;cP0
02lj000a@000;T80038n000`>000;CL003@i000e?`00=dd003Q;000kBP00?U@0041G0011G@00?eD0
041D000kC`00=d/003]B000203aC000503]:000nBP00?4/003YA000mEP800P0mF@@09`12HP80?680
041R0014GP00BFH204QP0@1<H@00Ael104IO0@18I080AFP204Q^0@17KP00CG80051/001AM@00CVd0
055`001CM000DG`004ml001BN`00DgL0055a001>LP00Dg/005Eb001HM`00FGD005Yn0@1MOP00H7X0
05ic001OM000GgL006280P1MQ@<0H8D1062;0@02066A0@0W06JI0@1UV040IiL106VF001ZW@40Kj41
072U0@1/YP40JZP206R]0P1V[@40J[0206f_101]]@D0LKD407:`0P1d/000M;41072g0P1]^`P0K[`6
07>k0@1`_P40K/4406fn1`1^_PP0Jkh306c00P1_`@D0Kl8507G00`1i`0l0NklA08715P26`1h0RL4I
09;1602D`QT0Ul8L0080U/4L02L0V<<L09G7702Ba1h0Rl0Q08;07P23`R00Pl<O08C27@27`QT0SKdN
092n7`2C`a`0T/LN09?<8`2>bB40SLLT08c48@2>`b<0SL@R08[7602@b1L0U/DD09?54@2BaA00TlH?
09743P2@``d0TK`<08ni2`2?/`T0Sk<708bi1`2;_@H0S[`608bj2@25^`X0QKd408700@24`0<00P23
_0<09`26]`80Q[T508Ro401ocAh0NM4M07KA6P1ddAd0LM@O06gF9P1WeRD0J]@M073A7P1`dAX0KlhE
073<501acAX0M<XQ07S?:P1dbQl0LLPE07[13P21^@`0Q[0208FY0027X`00QjD008FQ0029WP00Qil0
08^Q002;Y`00RZL008RN0028X000RId008BM0023W000Q9L0082I000207bJ000W07nH0020V@00Q9P0
07jH001nU000P9@007j9001nS000NXX007N<001gQ000MX8007N6001fR000LH4006j2001aP000L8@0
0723001^O@00L7/006]d001XL000IW8006E[001OH`00FeT005II001DEP00Ce0004Q:000m@000>3H0
038_000/9@009B0001dE000@3@002PL00080108000<00@00000000000000R`00000<0?ooo`002P3o
ool0500E8@005Qd001DI000E5P004Q80010@000D50004Q<0018B000G50004aD001<F000D5P004A<0
018?000@2`0030T000/7000=2P004A000P0I6P009`0L8@008B/0028b000Q<`008S8002<^000U=000
9CL002Ll000Z>@00:S<002/d000^=@00:S8002/d000Y<`009bl002d`000/=000;ch003=0000iC000
>dX003U8000lCP00?E80041A000mC@00>Dh003I=000fB`00>U@003UB000jD@00=DD003E1000jB000
=d@003a80@0203i<0P03041K0@0oG@00@V800080@Ed00280BF@104UQ001:I000Aed004QM0016G`00
Af/004I]0018K`00BVX004i`001>K`00CWL104ei001=OP00B7l0055o001BN`00DWT0055h001@O000
DGP005El001FNP00F8L205Z8001MQ@00GGL0065c001PNP00GXL205j6101SQ@40HXX00P1TT@409`1T
T`40IIL106:G0@1RW@40IZ<206^Q0P1_Y040KJD006bV001XYP40J:`106ZZ0@1Z[`<0KK@5072`101d
/080MJ/107B]0@1`]`80K;P606bi1P1d^040MKT1072l1@1]_0L0K<4706nn1@1b_080M[`407Vn1@1h
`@@0N<0307c2401k`a<0Ml4F08C05P2;a1D0R/@L08g4700208k46`0V09Jm7P2E`1l0TL8O0930902<
`240R/0N08W17P25`R00R<0O08Rl7@2<`1d0T/LH09G:7P2Aab<0RLLR08_77@28a1/0R<LH08W65P2:
b100S/4>09>i3P2C]`H0T;T208bj0@2=^@40QkP108Zg002;/`00S:X008fV002>Z`00S[4108bg0@2:
]P40R;L208Ng0@26^@0308Bk0P0O08Bc0P25]040Q[d<07o54P1jbQ@0MLdF07;<6@1acR00KM4X06S?
9`1[cb40K<hT06c;9@1/bAL0L<PF07;:7P1hab00N/<N07c03`1o_0`0P[L708>f1026/040QJ`008FS
0026XP00QJ0008VQ0027Y000RZ8008VR000208VP000608RP0026W@00Q9/008>I0023V000PY`00P1n
VP000`1kU`00OY8007jB000207^D000R07n?001kS@00O8/007b7001fQP00MXL007N2001dP@00M800
0720001_OP00Jg`006en001/OP00K7D006ee001XM000IW0006E^001RI`00FfH005EM001?EP00C580
04E70013A000?3X0038^000V8P007aT001H>000=1P001P80008100800@00SP00000<0?ooo`002P3o
ool0500?4@004QD0014@000A3`0040`000d:000A5@004A/0018L000G8P005al001PM000E6@004Q<0
010?000?30003@`0010>000A50005QP00P0M8P009`0R:`008S40024d000Q=0008c8002@a000U=@00
:3h002M0000Z?000:SH002Pc000X<0009RT002HW000X9@009RL002Xb000[>`00<DD00398000cA@00
=dP003E6000hAP00>DD003Q3000fB000=4`003=A000`D@00=UD003=A000aBP00<TD002m2000fA`00
=D@003Y5000203i:000F049H0011F`00@5`004=O0013HP00AVT104ET0017H@00AEX004=@0010D000
@Uh0041S0013I`00A6P004Qa0017L000A78004Ah0015N000AWl004Un0080C88000l0Cgl004mi001B
N000DW/005Ak001DOP00FH`005^8001QO`00I80005j50@1PS080HH/406><0P1TS`800P1UU@<09`1V
U0<0I9T306>N0`1RX`<0HZD306F/0P1ZZ`40KZL0072W001^X000K:@106jT0@1/Z@80JZH306jX101a
Z`<0LZT107BZ0@1dZ@40M:h207B`0P1gZ`40O:X107N_0P1a/`@0KK/6072l1P1d^PD0M[P207Vi101i
_@<0Nk`307g04021`1@0NkdG07k06025`aT0O/DK08756`0208O16`0W08bk7P2<_2<0RlHT08g49P2C
`RX0UkdW09Bm8P2@_200R[/M08Zj7@2<`1h0T<PJ0978702?aQh0SLXH09344@2:_@d0R;h;08Nn3@29
^P`0Rk@308b/0@2?[080RK<308Rh0P28^@40R;P108Zb002;/`00RjP008fT002>XP00SjH008Ra0026
/@00QkD008Vc0029]P00QkP00080Qk@102L0RK8108:b0@1n_0@0NKl:07W1301h`@h0MLD@07?7401d
b280LlPX07?98`1`cRD0KlLO07;0501e_@d0N/4@086l3`23^@d0Qk4508F_0025]000Pk8008Nc0@26
[@40QJH008FP0025W`00QZ0008RR0028X`00Qj@008NV0025Y`00R:P008RT0027X000QIX008:I0021
V@000P1mVP009P1lUP00NY4007R=001iS@00N8l007R>001jT000NHT007V3001iQ000Mh@007V6001c
P@00LWl0075n001^N@00K7/006]k001WM000Ifd006Ma001VM@00IG8005mX001LI000Ef4004iM001<
E`00B4d00450000m?@00=c8002XU000N5P0050d000/600040@000@00T@00000<0?ooo`002P3oool0
1`0920003@`000`:000:20003@`000d?000A7P000P0>9@002`0G:`005RL001HP000F6@004Q0000h;
000?2P003P`001HG000I7`006R@000808C4002L093D102@e000Q<P008C0002<b000U<00093@002Li
000W>0009S<002D/000S:0009BH0024Q000R8@008bD002DZ000W=@00:Sl002]6000bB@00<4D003=6
000c@`00<dH003E3000c@P00=Dd0039C000aEP00<EP003AF000aCP00<T@003M4000d@@00>4X003M;
000kD0000P0oC`009`0kD000@5X0041M0015HP00AV<004MU0014H`00AV@004AL0012D`00?4l003aE
000kF@00>E/003eW000lK@00@G@003ei000jO000?G/004Io0019O`00C8@004^3001>PP40DGh105>1
0P1BO040EWH005Id001IQP40EH`105j=0@1QRP00Ghl105Z=0`1HT`@0FY84062H1@0206>M1`0W06>M
1P1SWPH0HY`4066R101OX`D0HjT206FW001/Y`00KZ<006fP001ZX`00K:<106VW0P1ZX@<0Kj@407:T
101`Z@80LZP2072W0@1aZ`40M:T007JW0@1lZP40NZ`107Z]0P1e[`<0Lk@407>i1P1e^PL0M[T607Vi
0P1l^P<0N[l?07W14@22`1L0QL0L08G07P1o`200O<@R0080QkdV02H0RKPU08fi9@2:`2@0SL8Q08no
8@2C^b00UkXQ09>i8@2<^2D0S<0O08g45P2<`a<0SL<B08c23`2>`0d0S[T908Nf0P25^0D0Q;T<08Fe
3@23/0@0PZX208F`0`1o/@<0OK@207ji0@24^`00RKD008Vb002;[@00RZ@108VO0P2=X@40R:X008Va
0027/@00Rk@008^b0@<0Q[<102L0Q[41086_0@1o[P<0NkH507nf0`21]`40NkT307bl2@1o_A40O/<B
07k3401na@l0P<0>07jg2P22]0@0O[8608>`0`21/040PZ/0086[0025[000QJd008N^0025ZP00QJ@0
08JN0025V000QiD008VI0027WP00Q:8008>S0021Y@00PjD008FR0025X000Pil0082N001mV@000P1l
U@00201kT`00NHh007N<001iSP00Mhl007V>001fS`00MXX00P1gQ`006`1hQ000LX@0075o001_O@00
Kh0006ei001]NP00JWd006A^001OKP00H6P005iX001OK000FF@005MJ001@D`00C50004M;0013A000
>CL0034/000W8@007aL0014<0008100010400080002B000000`0oooo000:0?ooo`0D00D400092000
1`D000L5000>3@003@l000dD000?9`004B<0018O000G8P005Q/001<E000?3@002`P000`9000>3000
4Q@001XW000J;P0201df0@0D01df0P0M<@408S4001h^000L:P007b`001lX000R9`008bH001hQ000P
7P007Q/0020N000Q8P008BD002<Y000P:P00930002Lg000Z?P0202m7000A0315000aA@00;TH00319
000`BP00=5<003=F000cF`00<UX0035F000cC`00<TT003Q4000e?`00=dH003]:000jC0000P0mE000
9`0lCP00?EH003mK0011HP00@f0004IM0015HP00@VL004=S0@10F`00@UH003iH000jF`00>El003QW
000iJ`00?GH003Uk000fP@00>Wh004B10018P`00CXL004n90@1CQ`80D8<405>51@1HP0<0EgT105Ie
001HP`80EHT105VE0P1FU`80Ei/305RB0`1EV@<0DYL405VL1@0205fP1P0W062S1P1PX0@0H9T206:H
0P1TV0@0II/206FM001YY040K:@006ZS001VX`00HjP006F]0@1/Z`40L:P2076Y0`1bZ0<0KjD106bY
0P1ZZ040KJT007FZ0@1iZ040Nj`107^[0@1iZP80Lk4607:j1`1`^@/0LkL807Bf0`1g^`<0ML4>07?1
3`20_aT0Q;dM08Bl8P1o_R@0O[lW0080Q[/X01P0R[PT08Jk8P2;`2<0Sl<N08O67@28bAL0RlHG08c4
5@2:`140RKd?08Fl2`26/`T0Q[H408Ng0P2:/`40Rk0008bc0@2;/`80R;H908Fa3025/@P0PZd407jb
0P20/`4207nb000=08Fc002;]`00RKD008Na0026Z`80QZ@408JT0@27Z000QZ`008F/002:[040Qjd1
08F[0@0208J^000W08B/001lZ`40NjD107bW0@21[P00P;8008>^0@22[P40QZl408>c1025]`@0Qk@3
08Nb0P23/`40Q:`008>[001o[040NJ/107jX001oZ000PjL008>V0028Z@00QZT008FW0028W`00Pi/0
08JB0025UP00Q9T008BO0023V`00PiL0086I0022UP00Q9P008>J0023V@00P9L00080OI<00280Nhl0
07^=001kS000Mhl007R<001fSP00N90007><001fS`00Mh/007J5001cP`00KGl006mm001/OP00KG/0
06Yf001VLP00H6l005m]001KGP00F5`005MN001BF@00CeD004U;0015AP00@48003di000_:@008Ad0
01L>000=1`001`<00P01002C000000`0oooo000:0?ooo`0D00<200061P001@D000D5000<3P002`h0
00/B000@80004A`0014G000E6@004A@000l>000<2P0020H000X7000?3@004QL001LW000F;00201H]
0@0N01P[0@0H9@007B/001XY000G9P006R@001TN000J6`006AL001LD000G4`0061L001TL000M9`00
7RT0024^000O:@0072X002<_000W<P00;Cd002Tm000[@@00:dH002]9000ZC000;4/0039=000`D000
;e000P0`D`001`0dD`00=4X003M4000g@P00=dD003]:000kB`000P0oD0009`0kC000?UD003aL000n
IP00@680045Q0012I`00@6X203iY0`0mI@40?F4003aO000oHP00?FL003i^000lKP00@7@003mc0011
L`00@78004Ik001<P`00C8`004j<001BQ@40DGl305B00`1EPP80FGh005R0001GR040EHX105JG0@1C
W080EIl505JI0P1HU@40F9<205^G0`0205RL100W05NT101IXP<0FYX105b?0@1RS`40I9H106BG001R
Y040IJ<106ZQ001TX`00HZ/106B_0P1[[`40KZ`206fW0P1_Y@40LIl206jQ0P1YY@40JjL106jX0@1`
Y000M:P107RZ0@1jZ@D0Mk89076c201a/`L0MK4507N_0P1e^0<0L[D407:k3P1e^A`0N;<K07Ff7P20
_B40P;lS0080Ol0N02L0R;lK08Bl702;`Q/0SlXH08S84@26a@h0Qkd<08Nj2P26^PD0P;P307bd0@22
[040QJ`008N]0026Z@00QZP008ZY0028Z`00Q:h408Ba1P2:[`X0Rjh508Ba0P23[`40QJX008FX0028
Z`00S:l008^c002:/P00QZ/108>X0@22Y000Pj@008BT0024Y@00QjP008>Q0025XP000P24Y`005P21
ZP00OZT008>W0022X`00Q:D008:Y0025Z000QJT008^V002=Z@00RJ/008Z^002:ZP00QJX008NX0022
Z`40PJ`007R[0@1oY@00P:@008:S0024X`0208RW000508FZ0025X`00QY/008BH0023UP000P23V`00
2023VP00PIL007fC001oSP00PY8007jB001mT`00OYD00P1mUP001`1mU@00O94007Z>001iR`00MHT0
07N;001dSP000P1bS`00601`R`00LH@00765001]P000JW/006]g001ZL`00IVl0065V001OJ000GfL0
05MM001DEP00CDl004]?0018C000ADP003i0000i>000=2`002LM000J4@0030<000<109H00000303o
ool000X0oooo01@00@400000000410001@<000T<00092`002@`000lF000>4`003Q4000h?000=2`00
2PP000P500070`001P@000lA000@6`004bD001<R008051`001005AT001@G000C5P00524001<O000E
8@0051T001<C000E50005A4001DB000F5@006AX001/W000J9`007b/00P0M:0001@0S<0009Bl002Pk
000U>P00:3T00080:dH000h0;4<002Y1000[?`00;d8002m3000aA`00<dd003I?000eB000=4D003I7
000e@`00>4T003U80080?Dl002L0>Tl003aI000kH@00>VL003mY000nI@00?6H103QW100fK0H0=FP2
039Z000aI`00=VD003YZ000kMP00?G@004Aa0016JP00A6P004MW0016KP00CWT004il001BPP00D7/0
051j0@1>NP40DX4005An001DP000E8@005><001DT000E9X1056O0`1DVP40Ei@005N;001ET`<00P1B
UP80301AW`@0E9l605VM1@1IV0<0H9<0066D001PUP00H9`106>J0@1XW@00I:0006RU0@80JjL10P1X
Y0805`1ZX040J9`106bK0P1[V@40L9d2076U0P1_WP40LjD107FT0@1hY`D0N:h607F/1@1f[P@0M:T3
07NV0`1gZ`80LjX307:e301d/a80M[4A07Jf5020`1/0OlDD0080P<LA02L0QlH@08K33`28`0h0QKX=
08>i1P24^P<0Q[P208>e0@24]@40OkH1082_0@20Z000PZH0086V0023YP00Q:<008NP002;XP00RJ`1
08V`0P2</P80S[4208N/0026Z`00QJ@008JN0027X`00RZD008^Y0026[P00Q:d0086Y0021Y000P:40
086M0025W`00Qj4008FK0024V0000P27W`003@27YP00QZL008RZ0025YP00Qj@008JT0028Y@00QZ@0
08ZQ002@X@00SZD008VX0027YP000P27XP006022Z`00P:`007^Z001nY`00OJ@007bP0020X000Q:40
08NR0025Y000Q:00086M0021U@00PY4008:D0021VP00Q9T008>I001oT`00OHd007nC0020U000NY@0
07^B0080Ni@00200NiX007ZJ001eT@00MH`007N9001gS000Lhl006n;001]S000KH<0071n001[O@00
Jg`006Ye001WKP00I6/0065]001KIP00Ff0005QM001DEP00Cd`004I40017AP00@dH00454000i>@00
;bX002PM000K40003PL000D109L00000303oool000X0oooo0P00000200<2000@008100061P001`H0
00H6000;2P002@T000X700071@0010<000@100040P001@D000`C000<6P0031T0010H00803Pl002L0
3`/000l=000>50004al0018L000E7@0051L0018B000F5`004a@0010C000G60005a/001XQ000H7@00
5QX001`Q000M9P008Rl0024b000O=@009Cl002Hk000/@@00:c`002Tj000Y=P009SL002/k000/?P00
<DH00399000`C@00=4T00356000cBP00=DH003I8000iB@000P0hDP009`0gDP00=EH003QW000eJP00
?6T003aR000iG000=ET203ES0`0aI@40;VP002iY000aI@00=FL003MZ000kM000@6d004U]0017J`00
BFP004QX001=K@00CV/005Aa001CL000EWT0059i001BOP00DW/005=m001CP000E8T005J9001ETP00
D9H1056G001ATP00E8d004f6000204b>0P0W04ZH1`19W0/0CYh;05JJ1@1NU`00FiL005RD001IT000
H9<0066C001TVP00Iid006RP0@1WW@00HiP1062H0@1QT@00I9L006^H0P1ZU`<0L9/4076Q0`1`W@80
M9X007FF001fWPD0M9/107:Q0P1cY@@0LJL407>T0`1eX`40M:H207F[201iZPL0O:h707nc3`1j]P/0
Ok`<0080Ol0;02L0O;d907^m201l^@<0Nk4207fc0@21/P80P[D208:a0`23/`<0Pk02082_0P1nZP40
OZL0086T0@24Y@00PZL008JQ0029X`00R:X008Ra0@29/P00RJl008R_0026ZP40Q:00086Q0024XP00
QJ0008JR0022ZP00P;00086/0025YP00QId008:J0023W000QYd008>L0021U0000P23T`005`28X000
RJ@008ZW0027[P00RJX008NP0028W`00Pi`008NP0028X@00RZ8008RT002:X`00QJ0008NO0029XP00
RJ@008:X001oY@00O:<007fL001oVP00P9X00080PIT000X0PY`0086N0024V000P9<007bA001lUP00
OYD0082I0020U@00OI@00P20UP00901kTP00Mh`007V@001iT000NID007ZF001iU`00MY0007J;001c
R`00L8`006f=001[S`00JhH006Z1001VNP00HG<006E^001RJ000GFT005iX001GH`00EUh004iI001<
D000ADD003lm000m?@00?3T003Xk000c<P00928001LC000>20001@80004009L00000303oool000X0
oooo0P000003004000800`8000D00`4000H400040`000`8000810002004000060081000410002P/0
00/=000;300030/00P0810002`0;2P002`l000`G000C7`004Q/0010D000A4`004@l001DG000C5000
4A@000805Q/000/06R0001LJ000D5`006R0001XT000P:`007b`0020b000U?P008cT002Pl000202Dh
000=02Ll000X?@00:d8002]3000`B000;TT002a9000]B@00;DP0035:000bA000<dL00398000202m9
000W035A000^E000=F00039R000fH@00>ET003QA000dC@00<Dh002iH000_G`00=F8003QO000kG000
>5/003iW0010J000A6l004A/0014J@00@VL004QZ0@1:IP00CfL004eX001BM000Dg80055c001>L`00
DGT004mk001>P000Dgd005B5001BR@00Chd0052>001ARP00DH@00080Ch/102L0BXd704^D2`1;UPX0
EHl205b?0@1IT`00F9@005Z=001OR@00GXX0062=001OSP00HY8006:E001NT040HXd106>2001WRP00
J8h006fG0@1ZWP<0J:0306ZL0P1]U@40Ki0007BH0P1cU`40LYd107:K0P1dY0<0MJ@207:T0@1aZ@<0
L[0307B`0P1i/P80Ok0307n`0P21/`400P1n/`<09`1j]PH0M[T607Vf101l]@80OK81082b0P1o/P80
Pk@408:d1021/0D0Ok8:07b`1P1kZ@40P:@008:V0022Z@00PZL007jV0020ZP00Pk81086b0025/040
Qk<008R]0026Y`00Qj@008>N0020W@00Oid0086T0021Z@00PjH108JU0029W@00PiX008:M0024X000
PJ0008FI000208FC000S08FF0028V000SJD008V`0026Z040R:0008ZM0027V`00Pj40082R0022W@00
PI`008>O0023WP00Q9/008JH0029W000RJ0008NN0022WP00Oid007jH001mU@00Oi0007bA001oT`00
OiH008:G001nUP00NiH007NC001gUP00N9/007^G001mT`000P1oU@008`1kT@00Mh`007N=001gS@00
NY4007^C001iT`00MHh007>8001aP`00L8H00729001^R`00JXP006V6001SN`00HW4005iZ001OI`00
Ff<005YP001HGP00De/004aE0019C@00A48003hk000d<000<2/002lY000V8P006aL000d;00050`00
0P0009P00000303oool000X0oooo1@00000200410004004000020@000@00004000<0000000H00@00
008100040`0010<000@200071P0200<2000W00D4000;50002aP0014K000?50003@d0010?000>3P00
3@d0010C000>4@0051X001HH000E5P006A/001HK000L8`006RH001XW000N:P007R/0024g000P=000
838002@h000R?@009dD002Q7000/B@00;4D002e1000Z@@00:48002Y3000X@@00:T8002a0000/?`00
:d<000809DD001809TP002Q;000aF@40;UD203AH0P0cEP80<T/102m4000X@P00;T`0035@000hF000
=e@003UB000iD@00@EH0041N0011H`0203iS000C049Q0018IP40AVD004]W0017J@00Bf`004]X0@1<
I`40B6X004]a0014L@40A78104I`001<N@00Bh8004R5001;PP00D8@005:3000205:8000W04n60P1C
R0@0DXP305F7001CP`40DhH005N7001JQ000Fh800621001QPP00GWd005f2001LP@00F8<005b3001O
O@00IH4006^7001`TP00K98006RI0P1VW0<0J98106f>001[T040LYH007>L0@1eW`40MZH207NT0P1i
YP<0N:P107VW0@1g/@80O;D207f^0P20/080Ok410080Ojl202L0O[8307jh0`1n]`80OkD107nc0@22
/`40P[8108Bd0@26/PD0P;4:07bf301l]0T0Nk4207f^0@21[000Ojd007fX0@1lY`40O:X207f_0@1j
/`40PK8108J`0@2:/000RJX008RU0025X`00OY`007bP0@1kXP40OZ@1082V0@23Z000QJ@008JQ0028
Y000QZ<008JV002:W`000P28V`009`26V000RIP008bO002;Z@00RZX008FU0028X000QZ0008FN001k
V`00NiX007ZK0020V`00PI/0082H0021T`00R98008FC0024V@00PIT007bG001nT`00OI0007f>001k
SP00NhD007Z9001kU000NY/007RJ001dU000MIL007NH001iU000NY@007VA001lSP00NY0007RB0002
07N@000N07Z=001hT000MY4007F=001cRP00L88006b0001[Q@00JHD006R4001UPP00HWT0065c001N
J`00G6L005aT001GFP00DUD004eH001<DP00Add004E6000k>`00;bh002LQ000P700061@000l=0007
1P000P40V@00000<0?ooo`002P3oool800000003004000000000000000H0000000<00@0000000006
2@000P0410009`051`0031L000`G000=4P003Pd000/8000?4P003Pl000d<000?3`003Pl001<E000C
4`004Q8001LL000C7`0062X001PW000H9P007bX001XW000M<`006c8001db000S=`008CP002Dn000V
>P009SL002Lk000W=@009CH002<f000U>`009CP002@d000W=@00:38002Hk0002024n000W0290000T
@P00;D`302]<1`0YCPX0;4h<02Q81`0RA@807d0102Q7000^C000=E@003M@000jC000>4D003]<000g
DP00=e4003QH000jE`00@EH0049J0018H000B5h004ES0011HP00?fD203iS0`12J080@fP003aV0@0h
H000?fT003i_0012O000@7h004Qk001?O@00Cg/00080DH4002L0Cgh00522001@P@00E800059o001A
OP00EWT005Qd001ILP00G7D005Yk001DMP00E7X105Ik001EO`00DW`005Z0001QP`00IHT006Z@001^
T000KY@006nL0P1_U@40LYH106fG001_V`00L:01076S0@1dYP40Mj@207NU0P1jY@40N:H107J]0P1i
/@80O;4307f_0`1k[0<00P1nZ`<09020[`@0OK03082f0P1o]@40OKH007fd001n/`40O[H207jd1021
[PH0O;@707Vh1P1j]`D0M;H307Rd0@1l[P40NZh107RZ0P1g[040NJd007V^0020/000Pjl008F`0029
[`00QjP108BV0@1nY@80N:8107BR0P1hX080OJH307j_0`20[@40Qj/008NV0080Qj0002X0QZ4008NP
0027X000QIH008VC002=V`00SJ<008bY0029[000RJ<008JR0021W000O9@007fD001iU@00OI<0086G
0023U000Oi<007nA0020S@00Oh`007j@001lSP00NY0007b>001mSP00N8h007N7001cR000NIH007RP
001gX000M9/007BF001cU000MY@007JC001fSP00N8T007N=001eT`0207FB000A07F:001dR000M8P0
06n9001_Q@00KH0006]n001ZOP00J7l006Ao001RO`00Hg/0065d001KK000FVD005QR001BEP000P1;
DP002`18C`00B4h00497000h>000;BT0020J000I4@003`X000X500040P000@0009T00000303oool0
00X0oooo4@0000000`01000000000000000200D5000W00D6000;40002`l000X:00091P0020L000dA
000<3`002P/000d=000<2`002PX000d?000=40004R0000lR000?7`005BL001HR000K9P005R<001@Q
000I:0006R@001h[0@0L9P007RX001dW000I8@006bP001XV000M:@007BL001`S000P9`007R8001lV
000M:00083H000807CD002L083`002<o000S@@@08T`;021:3P0OCA@06d`<01Q;1P0IB0<09T/102U>
000`DP00=4T00350000e?P00<3L00392000aA000=Dd003A:000iC`00?E8004AE0013EP00@Ud003iJ
000jI0@0>FH4041X0P0nHP00@64003QM000nIP00?f`004Ad0013L@00B70004i^001@K@000P1=K@00
9`1>L000D7D004ie001BM`00DG8005Ig001GM000DV`005=V001GJ@00EW00059d001?O`40Dgl105F3
001FP000GXD005n5001OS@00Gi<006JB001]UP00K9T106fP0`1`X@40KZ01072L001`VP40Kil2076Q
0@1dX`40MZD107FU0@1g[@80MZd107F]0P1f[P@0Nk4407Z_0`0207ZZ0`0W07b`101o[`<0P;8207nh
0@1k]`00MkL107Rb001i/P40OK0207b/0P1n[@80P;4407be1`1k]@L0O;8407b/001o[P00Ojd207f/
0@1m[@00Oj`0086[0027Z@00Qjd008B]0@26ZP40PjL108BV0@1mY080O:<307^Q0`1kZ@D0Ojh608>a
0P28Z`00RZ<008RJ0022W@40QZ800080Qih002L0QIP008:C0028S`00RiD008^Q0028Y@00QJD008:S
0022V@00Oi<007j=001kR`00N8D007^:0020RP00O90007b:001lQ@00O8<007V3001eQ@00LhH007B7
001hR`00N8l007N6001iR@00NIP007VS001fX`00LIh0076H001cU@00Li<007B?001bS000MHT007>8
001bRP000P1cS@00201`R@00KX<006em001]PP00J7l006]n001YN000Ig/00P1UN`004P1PN@00GGT0
05]d001HI`00EF40055J001@E@00B4l004E;0012BP00?TD003Xn000c<0009b8001XC000=20001P<0
00<109/00000303oool000X0oooo500000020081000M00<100071`001`H000D300060`001@D000D6
000820001P@000T700081`0020H000`;000;2`003a/0010K000?6`005240014K000E7@004AD0010A
000C5000410001HH0@0C50004A8001@J000?5P000P0C7P00200G7@005QX001<F000E6P004aH001@L
000E7`006S400P0J=0009`0L<P007ch001e20P0NC@@06d/601m9200JB@T06DX801a61P0R?@80:D00
02/j000]>`00;ST002ll000Z>000;3`002a0000aA@00<DH003E9000eC@00>Tl003UE000jG@00>ET0
03YM0P0iGP80?V<003YK000lFP00>UD0049L0014G`00BF@004UR001;H@00BV8004aR000204YN000W
04QP001:H`00CFD004eS001>I`00DFh105A/001AJP00E6<005IT001BJ@00E74005=d001@Q@40D8T1
05F60@1NR040HH`106:<001MS`00HY0006FD001WU@40JYl206fP0P1]X`40LJ4006nJ001bW000LI/0
06fR001aYP00LJL1076_0P1e[`40MJd107B/0@1f[080M:h30080N:d302L0OZd307f`0`1o/080N;81
07Fc0@1f/P00NZ/007bY0P1mZP<0OJL407jW1@1nY0H0Oj@607bZ1`1i[@@0OZT107n[0@20Z`40PJT1
08:X0@24Z@40QZ<008VR002:Y@00QJH008:W0022Z@40QJT108FW0@20XP80OZ@207nU0P21Z@<0PjX1
08BV0029X`00Q9/0086J0023V`000P23W0009`21U`00Ohd0082:0023RP00Q9L008BP001mW`00OI/0
07fD001nT@00P8L007Z2001gPP00NHT007Z7001iR000N8<007R2001fNP00MGd00722001_QP00KX@0
07>7001fRP00NXT007^?001jUP00NYd0076Q0@1[X@00LYH007BB001eT@00Li0007B?001dSP00LXH0
06^4000206b7000K06Z9001XQ000J7/006Ql001VN000J7L006Qe001VMP00J7X006Ii001LL000FG<0
05I/001DHP00DV40051G0019D@00@dL00412000m@000=cX0034b000[:0008A`0018<00050`000P40
09`00000303oool000X0oooo600000020081000400D600051000108000@200800P0000<010<000@2
00081`000P061`00600<3P003A00014E000?40002PT000`?000920002PX000L5000510002@L000P6
000<5@002a<0014L000@6@0041@0018D000B4`0051P0014C000D5`004AH001<N008062l001@06300
01`l000K@P0064/001Y:000QA`408T8201ho0`0R?`<08cD102Ha000V;000:C@002Pb000/?`009D00
02M1000Z@`00<DH003940080=4L00140=dL003M?000dF@00=5P003MF000hE`00?Ed003YI000kF`00
=E@003UC000nDP00A5H004IH0017FP00Ae/004ML000204ED000W04=D0013F@00AE/004UJ001:H@00
CF<0051Y001=I000DF<0055U001DJ@00Eg0005Eb001CPP80ChP105:?0`1KT@D0GHd306B80`1SRP@0
HI0205j@0@1RTP40Hih206>R0`1WY@80IZ8106bO0@1]V`40KYX0072N001^Y000KZH106n]0`1`[@80
MZh107F[0@1a[040LK030080LJl202L0N:l207b]101k/PD0M[<207>c0@1j[P00OZ<007fU0P1lZP<0
O:T407bU1@1jX0D0NYh207NU0`1eY`@0MZP307ZY0@1nYP40PZ4008RR0@2:YP40RJ<008VP0027W000
QJ0008:R0021YP00PjP108R/0028Z000QJD008BS0023W`00Pih0082N0021WP00PId007fH001mU@40
0P1mTP001`1lS000OHP007f4001lQ`00Nh/007ZE001kV0000P1kTP007P1jS`00Oh/007^<001hR@00
M8h007R6001gPP00MX8007R3001gOP00MW`007F3001dR@00L8d007B>001iSP00NY4007^?001dT`00
MiT107FR0P1/W`40LI@006nC001aT`00LY80076E001cT`00Lhd006n60080K8@001/0J8T006J5001V
PP00Ig`006Ae001VM`00I78006Ea001VL`00Gg4005][001GJP00Del0055M001=FP00AeH004=?000k
@P00=S`003Dk000^;`00:RD0028O000E4@002PD000<100010000W000000<0?ooo`002P3ooolH0000
0006004000000000000000<300010@000@000P0000000`020@00000000@3000200<2000:00H30006
10002@T000P7000610001`D000@3000610000`<000<2008010@000`02Pd000X<00092`003Q8000d?
000A5P004AT0018K000@5@0030h0010A000?5P0201HW000W01LZ000J=@006C/001]6000JA@0073l0
01lm000M>04093L102<b000V;@008bd002Pe000V<`00;44002Y3000/A000;DD002e4000^B000;T80
0355000bA000=TP003=?000fD@00<e0003IC000fE000>EP003IJ000gD`00=dd003M9000iA`00@4d0
04=?0018F@00AeT00080AE4002L0@4l003mA0011D`00@UL004IP001:I000D6`004iR001AI000DFX0
059Y001CJP00D6X005Aj1`1BOP80EHh405>>1`1FT@X0G8X;05f7301PR`D0GX`206:?0@1PUP40H:<6
05jX1P1MY`@0HJH206ZP0@1]W000Jid006NM001]Y@80LJd7072]1P1f[@80MZl207B^0P1_/0800P1]
/P<0201e/0<0N;8407Fb101b]0<0LK<1076a001h[040N:d20P1h[`807@1iZ`80NJ@307FQ0P1dX@80
LZD207FW0P1jZ@80O:T0082W0024Z040PjX108JW0025XP00Q:0008FQ0021X`00NjD007jV0026Z000
RJH008ZT0027WP00PIL0082B001mTP00OiL007fM001nV000OI400080NHT002L0N8<007R0001hP000
M88007:3001bR000MX`007Z<001kR`00NXl007f=001nR@00NHd007B@001bR000LX<007In001iQP00
MhD007>1001bP000L8@0072;0@1gS@00NXh007^@001hS@00Lhd006n@0@1_UP40K9P106ZD001ZT@00
K94006f>001aT`00LY<0076@001`R@000P1]Q0006@1YP`00IXH006:8001PP000HWH0065d001RK`00
HFh0061/001KIP00FVD005MV001=F@00CeL004MF0012C@00?DL003Lk000b=000;bd002LS000N5`00
50h000X600030000WP00000<0?ooo`002P3ooolK0000000300410000000000000080000000<00@00
0000000000000`0200001@0100000000008100010@000P4000800000010010@0008200061P001@D0
00@300061P001@@000X=000;3@0041P0014I000?4`003Pl000/8000>3`0041D00P0F8`009`0G9@00
734001/b000J>0006ST001Xd000M=`006c<001hd000Q<@009Bl002<_000V>@009cL002Tk000]@`00
:d<002i3000/@@00:dP002]6000^B000;DH003=5000bAP00=DX003I:000eCP00=T/003Q>000fD@00
=dh003I<000fCP00>4T003Q6000mAP00AU<004=J000204=F000W045>0011C`00?Th003mF0012GP00
BF@004m]001BH`00DVH0055X001@I`00C6@004eT001@L`P0EWD205Mn0P1CP`<0DhP605J5201KP`T0
FhD505j<0P1PT@40HXh106BK1P1SY0@0GJD506BU0`1VX@40J9h106^L001ZWP00KYl1072O101aZ0`0
Lj`:07F/1`1fZ`@0Lk830080Kk4300P0MK4407>c0`1c]P<0Lk@7072d101//`40Kk8107>_0P80LZl1
00`0LJl1076X0@1eY@40L:D106fV0@1cZ040NJP107fZ001k[@00O:`107f]0P20Y`4207bR000?07fP
001mX@00NJ0007jR0022W000Pid008FL0022U`00OI8007^;001fQP00NXT007^>001mU@00NY800080
N8d002L0MXP007>3001bP`00LH40079l001`N`00LGh007J1001fQ000MhT007b:001kS000NY0007J?
001fRP00LXT007F4001hO`00MX8007:7001cOP00L7d006f4001aQ`00MH`007J;001aR@00L8`006^=
0@1[S`40Ji4006^C001/TP00JhH006b9001/R`00Khl0076@001_R0000P1]P000601ZOP00JGh006>2
001SO000GgL005ec001OK@00GV/005UV001DH@00DF<0055K001:D000C50004=;000n@@00=SP0030_
000Z:0008b40020J000F3P0030D000<109l00000303oool000X0oooo:P0000004`01000000000000
00051@000P4000L800051@000`<000H700051P002`l000X=00092`003Q<000/<000;2`002@T000hA
000?5`000P0F:@406@0F:0405BP001T`000G;@006bX001/W000P;@007B`001`/000O;P007b/002@c
000R=`009C/002<l000X@P009d8002Y1000X@@00:DD002Q1000/A000;4<00356000b@`000P0d@`00
300fB000=D<003I2000eA@00>4d003I<000eD@00=Dd003Y6000h@000@Dd004=B0080A5D002L0@E80
049B0011C`00@eD0041H0013H040BfX104iS001AH@00Ced0055P001?G@00CEl004eP001BK@40DWL2
04ih0@1>P@80Dh4305Yn1@1IPPD0H8d3066?0@1TR000I9<406JA0@1SV0<0Ii`306fM0P1ZW040JYP2
06fL0@1[V`80LYH206nQ2`1aY`/0KjL707JV101bZP800P1d[0409`1e[`80L[42072b0P1c/PD0L;43
06^f0`1^/P<0L:`406jZ0`1_[@40KZh106j]0@1`ZP00KZT006^]001_[@40MjX107R/0@1h[P00N:`2
07RZ0`1oYP80O:8007NQ001hV`00NI`007VN001kW000NY@007ZA001iS`00OHl007b=001jR@00MH<0
07Eo001fPP00Mhd007RC000207FA000G07F:001cPP00M88007Im001bM@00KWP006ag001cN`00MGl0
07:3001iRP00N8`007^>001iS@00Mh`0072:001bPP00Kgh007=o001aQ000Lh000760001]PP000P1/
P@001P1_Q@00KhP006b:001/R@00JhL006V;0080KXh000H0JHL006R2001ZQ000KHD006n<001/R002
06Z3000H06V1001WN`00IgH0065c001MMP00F70005a_001HJ`00Ef<0059M001=H000BeD004Q@0016
B`00?d@003Ph000a;000:BD0020N000H5`00510000`800040`000P00W`00000<0?ooo`002P3oool]
0000000@00@400010000000000@300010@001PP000H:000;3P002@X000L7000:3@0020T000`=000:
2`003Q<000hE00803aX002L03bh100l^000E=@005R`001XU000I7@007RD001/U000J90007RL001dW
000P<P0083H002<k000S?0009ch002Dl000V?@009Cl002@n000U>@00:Ch002`o000a@@00;cd002lk
000b>@00<C/003A0000b?@00=dH003I<000gCP00=d`003Q<000iBP00=d@003m3000oBP000P10D@00
9`11D@00AE8004=?0011E000?E/103UM0`0mG`80Ae/104QH001>G000DE`0059K001AG@00DEX0051W
001>K000C7H204io0`1?O`D0Dgl705J2201LR@H0GXL20665001SR`40HXH106B;0@1XT040JYL106VG
0@1YV@80JIX606VM1`1/W0H0K9h406nL0P1`WP<0M:0207>Q0@0207JV0@0W07>Z0@1e[080LJh206n]
0P1/Z`<0Jjh3072a101_Z`H0K:X306nY0@1^Z`40MJh107B_001b/@00L;4007:b0@1f[@00N:h007^_
001m[@40Mj/107^X0@1jY@00Mil007JI001eU`00NYD007ZG001lU000N90007R;001iQ`00MHP007R8
001cQ000L7`0079n001`RP00M9400080M98002L0Mhh007V8001hQ000Mh8007F1001_O`00LGP0075m
001`O`00L84007>9001fR@00Mh`007B8001hS@00MH/007B5001^P@00LX8007>4001dP`00KH0006^0
001[OP00Jh8006^4001[Q`00KHX006Z6001YO`00Ih@006^;001_SP00JX/006Z6001YP@00JH0006ao
001[OP000P1XQ0005`1TPP00H7`0065f001PL000G70005U/001HK000EfP005=O001>F000BeP004UA
0013B`00?d<003Lh000c<000:R<002<M000J500040`000P600050P000@000:000000303oool000X0
oooo;@00000040020@000000000000030@00000000H800051P0010@000H400030`001`/000L8000;
3`0020T000H6000<400200dE000W00l/0@0@:`005C@001@Y000F8@005AT001HG000J8@00628001`X
000K9@007C4001dd000Q>P008SP002Hj000U=0009C<002Dd000S=0008C40028a000W=@00:34002dd
000[<P00:c<002hk000dAP00=D<003M8000hC`00>U8003I9000gA`00=TD003I1000i?`00?TD00080
A58002L0@UL004AH000mEP00?EX103eM0@0kG@<0?5`204AJ0@15F000BEd004]M001@IP00DfH0051S
001@HP00BF<104Q`0@19M`80CGP305Im101IO`H0FXH705b00P1PQ000GH0005im001OP000H8/1066E
0P1TV0<0HIL406>M1P1VV`H0Ii/606bM0`1/W040KZ8207:M0P1hU`000P1gX@409`1gZ080M:X306jZ
0`1]Y`80JJ@206VW0P1]Z080KJX306^^101]Z`<0LJ`107>/0P1a[040LZl007R`001h[@00M[4007Z`
001m[@00OjX007bW0@1lY040NJ8007JM001eV000MID007RD001jTP00MY0007F?001gS000LXT00726
001aQ`00MH8007=n001bN`00LH<007>8000207R?000H07V?001iS000Mh`007J6001gQ`00MX40075l
001_O000KGP00760001cP`00Lh/007F<001cR`00M8X007F<001fR@00LX@007>8001dR000KXH006^0
001WO`00JH000P1]Q`003@1]QP00KHX006V8001VP@00I7h006R2001[R@00JH/006Z9001YQ@00IWd0
06Mj001XN`000P1ZO`005@1QO@00G7T005Ug001JL`00FG4005MY001EI000DEd004aF001;D`00AU80
04190010@@00>3L002l]000W9P0081`001PA000=2@0020<000<1002R000000`0oooo000:0?oooc00
000000d00@400000000000000`80004100020@000@4000L<00062@001@H000L600030`002A400080
2aL002L04BP0014T000D:`0051d0014B000C50004AD001PN000F7`006bX001XX000K<@006c0001lf
000Q=0007bl0024^000P9P008RL001h[000O;`007Rd002<`000U;000:C0002/a000^=P00<cl003Y<
0@0eB000=4L003E9000iCP00=dX003U9000fA@00>3l003Xn000oB0000P0oD`009`13G000@Ed003eP
0@0mG@40@E`1045K0@10F@40@UX004AG0015F`00B5P0051W001>J000DFD004iU001:IP00BV`104e`
0@1?M@40D7H1051n0`1DQ0<0Eh4105b4001MO`00H7T0061g001RP@00IHl1066E0P1STP@0IIT406:I
0`1XV`80JY/206^N0@1`X040Ki/107NH0@0207JN0@0G07RR0P1hZP<0MJD306jQ101/W@@0Kil206fT
0P1^Y080K:T406fY0`1a[`<0LZX2076Y0@1e[@00O:d007R^001d[P00OZT0086X0021YP00Oj@007fU
001iW`000P1fU`003P1gT@00MXl007J<001fR`00M8T007J<001bR000LH@007F6001eR000LhD007Am
001dN`00MGd00P1kQ0009`1nR`00Ohl007R<001fR@00N8H007B1001bO000Kg/006if001cN`00MH@0
07B;001eS@00LHT00724001bR`00M8L007::001gR000M8T006j9001YP`00Jgh006n1001/Q`00KhT0
06^7001ZR000JHP006F3001QO000Hgh006F0001VOP00JH8006J0001XP000J7`006Qi000206Ai000D
05if001GMP00F78005Ea001FK`00DVD0059N0019D@00@dT004E:0010A000?3d003Pm000`=0009B<0
01`F000E2`002`H000D20002002S000000`0oooo000:0?oooc<0000000X00P40000000010@000@40
00000006200010@000H500030`002A@00P096000300:6@003aT000dA000?5@003@d0018F000@5@00
51d001@N000I:0006BT001LW00806BT001T07bX001dT000N:0006b8001PU000I:0007Rl0024_000T
<P0092h002T^000Z;@00<SX003A2000hB`40=DP003E3000a@P00<TP003A>000hD`00>d/003a8000l
A@00?dX00080?dl002L0@5H0045P000lIP40>VH1041P0010E`00@EP0045E0014E000AE<004E@001:
GP40CF41055W0@1BIP00DFT004mY001?K000DW@004ee001>O040CWd105B10P1HP`40G7h0065o001Q
O@00I8<106NA0P1PT080IY0206J<0P1RT`80IIH206RD0@1[W@40K9`006jM001cX0400P1cW0404P1e
X@80MZH207>V0`1]X@H0KId607BI0P1cVP40LY`207:O0P1dYP<0LZL2072Q0P1bW`40Mj8007VU001j
X`00N9l007^N0080P9d001<0OI`0082S001nW000Ni@007Z@001hS`00MHd007F;001cQ@00MH8007F5
001eQP00LhH007B9001bS@00MH@007Ek001cN000Lg/00080MG`000L0NH@007j<001kRP00NHH007R4
001hO000LW`00080LW/001h0N88007V;001cT000LY0006n4001]P000L84007>4001eR`00M8P007::
001/R`00JHL006N1001/PP00K8P00728001ZQP00JHH006R7001XQ000I7l006=o001RO000GgT0061f
001UN000IGX006Ah001UM`0205eg000B05Qc001HK`00DVL005=Z001CJ`00DF0004aI0016CP00?D40
03dm000h>@00=3<002lb000W9`006Q@000h=00081@000P00Y@00000<0?ooo`002P3ooole00000080
0@0000H0000000@400020@001@@000@4000:400200XB000W00T@000<40002PX000`A000;3@004AH0
00lB000=3`0041`0018N000G90005B4001PP000H7@006ad001TH000J80005R<001XZ000K;P007c80
02<d000U>0009cH002D^000W;000:Bl0030h000_>000<c`0034j000]?P00;40002m=000bDP00>U80
03e>000nC000?4D00080>D0002L0?DP0041D000nH000?V80041R0010GP00@Ud0045K0014E000?dT0
049;0018F`40BUl1055[0@1CK@00Dfh005=Y001CKP00EW80051b001BMP00D7<105=h001EMP00G7d0
05j10@1PQ000IHH206N70@1RSP80Hhd106J>0@1UT080I8l106FD0P1UVP40J9/106^M0P1^XP400P1_
W0409`1_XP80L9l107BN0@1_X0<0Jid406fI0P1aV@40MIH107BE0@1dV`40LZ0207>M0P1dU`40MiL0
07JE001fT000NXd007V<001hT@00Mi4007J?001mT@00Ni4007b>001hR@00MX`007B8001bP`00LH00
07Al001eP000M7l0075o001`P@00L8T007B5001fN@00LgH0071`0002071b000W07If001fP000MhP0
07Z;001jS@00MX@0071o001cNP00LX4007B3001fS000M9<007:E001^R000LH<006f3001aO`00KhP0
07:3001aQ000JHX006J8001WP`00Jh4006j4001aRP00JHP006R2001VQ000IHD006=o001POP00HGl0
05il001NL`00Gg80065a001NL000Fg800080F7400140Eg0005AX001AH000DF00055R001?F`00@eT0
041?000m@`00=cH002hZ000W9P008B8001/D000=2`0020D000<1002V000000`0oooo000:0?ooocP0
000000D00P40000000020P000P800081000200P9000W00H8000:2@001PD000X<00092P002P/000`<
000:2@003QH000lE000D70004Q/001@K000E6@005aT001PG000H6`006B4001`W000O<@007c8002<g
000R?0009C`002Hh000X=P00:3P002hh000Z<@00;S@002hf000]?P00:d<0031>000cD`00>ED003]@
000lC000>4<00080=S/002L0=Cd003a80010D000@EP004EP0013G`00AEl004=K0015E@00@DT0049:
0012C000BV4104i_0@1>L`40D78005=Z001GK000EVX005=^001BK`00D6d105Ib001GL@40FGT105Qo
0P1MQ@40Hh<106B20@1TQP40I8X106F=0@1RT@40Hi0106>I0P1QVP40HI`206JJ0P1[T`400P1_VP40
5`1]VP80Ki81076D001XT`40J9H206ZE0P1[TP40LI81076D0P1_U`80K9@407:G0@1fU@00MhX007R9
001gQ`00MH8007V0001gQ`00LXL00762001gO`00NHH00080N8`000L0N8X007>3001]P000L7H006ee
001`MP00Kg`00080K7T000D0L7d0079o001cP000LgD006i`000206m^000W06i[001]L@00LWh007B7
001eS000NH/007B5001`P000L8<006n2001bQP00LHl007:B001aT000L8`00762001_N`00KGd006an
001[P000JX<006J5001WQP00J7h006^2001`RP00Jhd006N4001UOP00H7l0065m001ON`00GG/005mo
001QM`00GW0005aZ001JJ@00F6h00080Ef`00140EVd0051U001;FP00BeD004UB0016C@00@dX003i4
000h?@00;S0002<P000K60004a0000X800060`000P400040002V000000`0oooo000:0?oooc@00000
0P0100020000000500400000000000000040000000000P040`003@030`001PH000<200010@001PD0
00D300092@001PL000`?000:2P0041H0010I000D7P000P0D7@00600H80005a/001XR000I:P007C<0
01hc000S>@008cl002E0000V?`00:D4002]0000^@`00;C`002lj000]>000;C/002a1000bBP00<E00
03=G0@0cD`40=E8003I90080>4@002L0>Sl003m6000mB000@E<0041B0012D000@eH004AC0016DP00
ADh0049<0015CP00AV4104UW0@1;LP40Cg41051X001EIP00EVP005I/001AJP00DW<105Ec0@1FL`40
EGP105=k0P1HO`80Gh<106>1001VQ000IhH006J9001SSP00HXh006BK1P1RVP40Gid306>J1@1YUP<0
0P1ZU`409`1]U@40J8d106ZA0@1ZTP40Jh`106N<0@1YS040JXl006nG0@1YU080JY4306nA0P1_SP00
LXT007R;001hQ`00MX00079l001cP000LX4007=o001aO@00MX8007N6001eQ`00MH<006mn001_O@00
KWD006Y[001XL000Kg/006im001WN`40IWT106aj0@1_O@00LgT0079d000206i/000W06ES001XI`00
JG8006el001eQ`00N8P007>8001aQ000LX4006mo001bQP00LX/0072;001aT`00L9800769001`P000
Jgh006Ql001[O@00KGl006b1001[P`00JX4006V6001/RP00KHX006^4001VO`00Fh0005Yl001LMP00
FW8005eh001RO000GG<005IZ001DI000EF<00080Df<000l0Cf4004]M0018E@00?d`003i3000l@P00
>3X003<d000^:`00924001PF000A300020H000@200010000Z000000<0?ooo`002P3ooolc000000<0
0@001`0000030041000M000000020@000000008100010@001`X000H70009300020P000lF000?6P00
3Q/001@T000E8P006BH001DN000G8P005Bl001Xh000M=`008d4002=4000UAP009D<002M2000[?@00
<4400352000a?`000P0_?@001`0^@000;d@002e8000/DP40;U8102eH0@0cD0000P0kB@009`0mB000
@4d003m;0011C@00?4/003]8000lC000@UD004EE0016EP00AU<004I?0016G@40Aeh104QZ0@1<J@40
DVP0055N001?H@00CfL004mV001>K@40BFT104Ye0P1AOP40DG`105B00P1IP`40GHH106>2001SP`00
IhD106J80@1TR`40IY<506BA0P1UU`80J9L406RD0P0206VD0@0?06>?0@1VT@40Ihl006F>0@1WR@40
JH`106N=0@1VT@40IY8106FA0@1WS`40Ihh006N9001WP`40L8P00080LHH000H0Kh4006en001`O`00
L800071n001aP00207:1000>07=n001]N000KG@006]b001XKP00JW<006Yg001^O@00J8L106250P1Y
P040KW/0071i001dM`02075d000W06MZ001XIP00J70006ae001`N`00M7l007F1001dQ`00L8D00726
001bRP00LHH00729001_T000Li4007><001`Q@00Jh4006]o001]O`00KX4006mn001ZP000JH4006R3
001[P`00JH@006V1001VP@00Gh4005mn001LM@00FW0005Q^001IL@00Eg8005E`001CI@00DEX00080
CUH000d0B5X004=E0011DP00?dD003Pi000b<P00:BP002@O000N500050`000X600050@000@000:X0
0000303oool000X0oooo<`000000100100000@4000400001000:0000000J00400000000000000000
000510000`80008100072P0020/000hK000=70004bL001@P000H9`005Ql001LW000G;`006cX101`l
0@0PAP0084X002A6000V@0009SX002Xe000W<00202hm000902hk000]?P00;40002Lo000XA0009TP1
02Q>0@0^DP00;dX00080=dH001d0?Td0049C000lCP00?D`003U8000lAP00?dh004EQ0013HP00AV40
04EB0014CP00AU@004QF0019I@40CfT0059Y001<G`00BUd004aL001:F`00CFL004][0@16N080BGD2
04am0@1BP`80Egd205^00@0205ml000806Ao0@1SOP40IXD106240@1JR@40HI4206B:0@1UT`8206N?
0@0H06N8001USP40J8d006R7001YR`00Jhd006N?0@1XS040Ihd006N<001[S000KHP006b5001WO`00
K84006^2001^S@00K8d107290@1`Q@00L8H007:6001`P`00LH400P1`P0003@1/M000Jg8006Ud001/
M000JG8006Qa001]NP00KHP006V80@1_Q`00Kh<0079m001cN0000P1bN@009`1^NP00KWH006Yc001Y
K@00K78006if001`O@00LH@007>8001aR`00Kh/006^2001]P000L8T007>:001_S@00JhD006^3001Z
PP00KH8006j0001[N`00J7`006Qm001YP000IWh006Mn001VN`00I7X005mk001RN@00GgL005a^001F
I`00DVP0059[001AKP00DFH004eF000204Q?000;04MB0013C@00@DT003Tk000a<000:B8001/G000E
3@0030D000H100010000[000000<0?ooo`002P3ooold000000800@004000000080010000000000H8
00062P0031T000`H000B90004Q`001LW000F9000630001Hd0@0D=`406d0101]0000OA`008Cl002@j
000V=@00:C0002D[000[>000:SP002/l000]?@00;D8002Q3000VAP0094H002Y9000[A`00;T000P0`
>@000`0h@P00>dP003]6000203]6000R03Y9000oC@00AE`004ER0015I@00@eH0041<0010B000A580
04QQ0@1>J000CVX004eU0018GP00A5D004MA001>F`00CF@004]h1`18M`80B7L104]g001DN000FG/0
05il001SM`00HVh0069_001SO000GX4105b50@1JR@<0GXH305nA1`80H8`502L0I8P006V=001YSP40
J88006F7001YR000KHT006f8001XQ000IH@006V6001]RP00KX<006f0001/O`00KX@006b=001/T`40
KiD1072@0@1bRP40MXT007>7001`Q000LX@00762001`N000JW8006Ed001UL@00IFX006M[001[LP00
KgP006ml001bQ000LhL007>1001dOP000P1cO0009`1^P000LGl006ag001^M000KFl006Ua001[NP00
KX0006j7001_S`00L8/006b1001/N`00KH0006j3001[Q`00J8@006>2001VP000J7l006Mm001WNP00
IWd006Ui001XO000IGT0061n001OO000G7T005Ya001LL@00FgH005aa001FH`00Ced004aO001<I@00
Bf0004ME000204M?000904=9000k?@00>3`002h]000Z8`007QP000l900090`000P000:h00000303o
ool000X0oooo=@0000000`01000000000000000@0000000500@400061`0031H000`E000B7`000P0A
6P005`0G9@005B8001P`0@0F<@406cd101`j000Q?P0083T002<h000U<P00:2h002H/000Y<P00:3D0
02dl000]?P00;T8002]3000[A000:D8002a:000^A`00;T000080;cT000@0<Cd003<l000c?000=400
0P0g@`008@0mBP00@UD0049L0016H`00A5/0041@000oD000A540045C0018H040BV0004aQ0019G@00
AeD004E@0012D`00B5l004Uf2014L`80C70104m/001CLP00EW@005ag001SM@00H6X005iW001PK@00
GgL005em0@1FO@40G8<405bA3P0205b:2`0W06>70@1[R000Ih@006Ij001TN000IW`006N2001YQP00
J80006Mk001VP000Jh4006j1001]Q000KXP006n=001^TP00Ki8106jK0P1/U080K8l2076;0@1cP`00
L8400766001dP`00Kh0006el001ZNP00IgP0069`001RJ@00J6h006Ma001WMP00KWh00762001dP000
MGl00080LG`000@0LH@007>3001bO@00JgT00P1XLP008@1YMP00IWh006R0001_R000KhH006f1001[
P000Jg/006]m001TO`00J7l006:0001RO000HWX006=c001RL@00HWD006Md001VLP00H7D005ai001L
N`00G7P005U^001FK000Eg0005I^001BIP00Ce`004UD0019F000AeH004E@00020455000803Lj000`
;`00:bL001dK000G4@003`P000D20001002_000000`0oooo000:0?ooodP0000000/00`<000@40005
1P002a4000/@000A6P003aT001DP000E700062D001LT000201/e000A028k000Q>`0083d0024h000W
=`009c@002/e000/=@00;c`002hm000bA@00;d8002e1000Z?000;4L002e7000_AP000P0dA`000`0c
B000<Sh0038n000303Ho000Q03a9000kC000@5T004=N0015GP00@EP003m@0011C`00@58004EN0P17
F`00C5d004QI0018E000Ae40049?0012G000A6P004=d0@17K`00D6/005=_001EL@00Eg4105a_001N
I@00GfP005][001HKP00FWT005Yi0@1IP080F8460080FHH402L0HH<1069n001SNP00Gg@0061/001P
L`00HgL006=o001SQ000I80006=o001UO`00IGh006]m001/P`00Kh/006bC001_V@00L9T106nB0P1]
S080KHD106in001WP000Jh800724001aQ@00L8<006j2001]O`00J7L006=b001XK@00I6`006Af001Y
N@00L7d007B4001gP@000P1dO`009`1bQ@00Lh8007:5001/OP00J7L006Y`001UK`00Hg<006Af001U
N`00JWh006f1001/O`00Jg`006Uk001UN`00IW/006Eo001TO000GWD0065/001OK000Gg<0065`001N
J`00G6d005ac001LM`00GGH005I_001DI@00D6D0055S001?I000C5`004M>0011B000?T@003/o0002
03Dh000602`b000U800061<000`900070`000P40/@00000<0?ooo`002P3oool^0000000300400000
0000000001P0000001d00P80008100083@0020h000dG000=5@004QL0010C000G6`0051/001L^000J
<P008CP0020k000N?@008CX0024d000V>@009c<002/b000[<`00;c/002m3000`A@00;3d002Xm000X
?@00;4L002m3000203A8000W03A=000`BP00=4D003E2000d?P00=3d003]8000lBP00?U<0049H0014
F`00@UL003i>000oC000@4l004AK0`18F@00Bel004ML001<E`00Ae0004=>0011E000@F00041/0@10
I000BFT1051^0@1AK040E6l105IY0@1KI`00GV`005eY001KI`00F6L005e_001KO@40F7l10080F841
02L0Fgd005]a001LL`00Gg41065[001OK000GG8005eg001NPP00H7h005mk001NNP00GgX006Ik001Z
O000L88006b;001/TP00KY4006j@001/R040JH4006Ij001XN`00IgX006Qk001]Q000LH/007:8001`
R@40KX@106Un0@1XLP00IVh006Ma001YL@00K7@007Am001jQ`000P1eQ0009`1cP`00LX400722001/
P@00JGd006]i001YM000IG@0069b001TL@00J7/006f0001[OP00JGX006Qm001XOP00IWd006Ak001R
N@00H7T005m`001RL000GG8005]^001HJ000FVL005UZ001JL`00FG<005QY001BI000CF4004]O001:
H000AUH00419000k?@00<c<002l[000202HU000401hP000G50003PT000@20;<00000303oool000X0
ooooB@0000007@010000000000H900062P00314000/>000=3`002``001<E000B600041/001L]000I
:`0083@001dd000Q<`008c4002Hd000S;P009Rh002L^000]=P00;CX002hm000[?000;3/002]0000_
A`00<D000080=48002L0<TH00318000aA`00=4T003=6000eAP00?D`003e:000mB`00@4d0049B0010
C`00?4d003U;000oC@00?4l004AF0019G@00BUL004]H0018E000@Dd0049=0015E@00@UX0049F0017
I@00BFT2051_0`1ALP40E6h005UY001NJ`00H6L005aV001CI@00G6T005ed001GNP000P1FP`409`1G
O`00FgD005Y`001KM040H7<0061a001HLP00GGL00660001PN`00H7<005U`001HL@00H7L006Mh001X
N000KH4006n3001]QP00KHP006b;001XPP00JG`006Uh001VMP00IGH006Yo001[R000KHX0072;001_
QP00KH4006aj001ZM@00Jg4006]/001WK@00KGD007>2000207B4000W07>0001aO@00KWh006en001Z
OP00JWl006Uk001XNP00IWL006Md001WN@00JG`006Uj001XOP00Igh006Ao001TO000H7d006=i001S
M@00HGH0061b001MLP00Fg0005Q^001HJP00EVL005AX001DI@00DEl004mM0018GP00AU`004=I000n
C`00?DD003Di000X9`0081X000805A<000@040h000X9000510000@40/`00000<0?ooo`002P3ooom;
0000000K00D500051P002P/000P:00072@002`/000/<000A60003aT001<Z000E:@0072l001//000O
<0007S<0020d000P;@008RT0028V000W:`009bd002Xe000Y=`00;3T002/i000a?`00<Sh00080<d80
0180<4@00316000aB000=4T00398000fB`00>4/003a8000nA@00?D80041;000oB@00?D/003U<000j
C@00>dh003i@0013D`0204QD000C04ME0016C`00B50004QB0018E@00AUH004QO0@17J080CW03055_
0P1CJ`00EVh005]W001LI`00F6D0055X001GI`00FfT005ac000205Qk0@0F05Qk001LMP00GW8105U`
0@1KL@00GW<005ad001NNP00HW/0069g001SLP00GVX005i]001SL000IW<006Ab001YN@00J7P006Yk
001[P`00JhL006Z60080JWd000l0Jg/006Mf001WN@00Ig`006^0001_Q@00LX0006ml001^N@00KGL0
06Uc001UL`00IF/006Qa001ZN`400P1`P0001P1_OP00LH8006an001ZO000J80006Ym0080Jg`001l0
J7/006Qh001WN`00J7d006Uj001VO@00Hgh0069l001SO000IWl006=j001PM@00H7<005ma001NI`00
Ff/005I_001EJ@00DV00059M001>F@00B58004YC0014E000@E8003]:000iA`00=c/002h[000O6000
4@`0008020@000@01@<000<100020@000@00/`00000<0?ooo`002P3ooolT000000@00@0050000000
0`01000000000000000=000000800P4001P01`P000L:000;40003180010E000?5P005BD101DT000H
:`006R/0024b000P=P009CH002<_000O9P007B00020Q000Q9@009S4002Pg000[?000:3T002/m000/
?0020310000;02e2000^AP00;DP003=;000cA@00=dD003I3000hA000=3l003Y3000mB0000P11D000
300lB`00?Dd003a?000mD@00@U<004EB0014D000Ae<004YB001;F@00Be/004UK0080BeX000`0Bf81
04m_0@1DK040DfT005AY0@1AH@00Ff4005IQ001AI000DfT005U/001JL`0205Ue000W05Yd001OL`00
HW0005eb0@1NL040GG4005ec001PN@00HGL006Ae001TM000HFl0065Z001PJ000HV/006Id001XN@00
JGD006Ud001/O000K7h006]m001ZNP00Jg`006]m001VN`00IWT006If001VM@00JWX006]l001WN000
Ig`006Qg001WN@00IWL006Ea001YL000J7<00080JGd002L0JWl006j3001]PP00Jh4006R1001ZP@00
JW`006Mj001VN`00IWd006Mo001WP000JGl006Mo001UO`00I80006J1001RP000HGh005mh001PMP00
GG0005]U001HIP00D6@004mP0019G@40AeT104I@0@11A@00?3l003Xl000e>`00<SL002`[000Y8000
7QL0014:00050`000P01002g000000`0oooo000:0?ooob@000001001000D00000003004000000000
000000d000000P020@00600720001`X000/@000<4P0041D000lF000E9@405B@001P[000J:`008C80
020f000U=P008bl001lV000M80008240024U000V<@00:3L002/l000X>@00:cd002`l0080<40000/0
;D8002i6000]B000<d/003=5000gA@00=T<003Q4000d?`00>T<003e80002045@000<03a;000mC@00
?4l003eA0012D`00AE8004A@0017D`00BU8004]I001;F`00BE/00P1;FP00301;HP40Cfl105A/0@1C
J@00E6T1055Q001KH@00EV40055T001CJ@00FF`005Yc0080FGD002L0FW@005mc001RL000GG8105i`
0@1ML@00GG<0061i001QM`00I7D006Ad001QK`00HFX0061X001RJ`00IW@006Qi001YM@00JG@006al
001/OP00Jgd006Yj001[O000Jgd006Ik001VN@00IWH006Ie001ZNP00Jg`006Mh001WO000J7L006Mi
001VM`00IG4006U`001XL`000P1YO@009`1ZO`00KX<006f2001[P@00J84006Z1001ZO000IgX006Ik
001VO@00Igl006N0001YO`00Igl006Eo001TP000IX4006:0001QOP00GgP0061f001ML000FfD005QV
001@I000Cf0004UM0@17F@40AU010455000l?`00>S`003Dk000b=`00;2/002TP000N5`004@X000D3
000200400;L00000303oool000X0oooo:@0000000`01000000000000000R0000000400D500051P00
2`l000/?00803@l001805B0201<O000C8@005bP001PX000O;@008B`002@`000P9P0082<001lO000O
8P008RT002Tc000X>000:3d002Li000Y>@0202Hi000>02/k000[?000<48003I6000dB000=T@003=1
000e@000<S`003M1000jA000@5H003iF000mD00203a=000G03m@0010E@00A5P0045@0014D@00AU40
04eL001<H@00CV0004iK001=DP00Ce`005=V0@1GJ000Ef<005EK001BF@00EUl005IL001DIP00EFP0
05A_001AM@400P1BL@009`1FM000G7@005ma001PL`40GGD105ec0@1MN000GGL005mh0@1RNP40H7P0
06=i001ML`00FVT005iX001TL000J7H006]d001/M`00KG`006b0001_N@00IgP006Ii001WNP00IGT0
06Ai001VN000IgL006If001YM000IGP006Il001QO@40IWX006Uh001WLP00IV`006=[000206Ia000W
06Mi001ZP@00KXD006b5001/QP00KHL006j0001XM`00HWT006En001VPP00JH0006R2001SO`00H7l0
06An001RO000H7`0065j001NNP00GW0005Y/001HK000DV<004aH0019E`00AUL0045B0@0nA`40>Ch0
038b000Z:P00:bT002HS000K5P004P`000T500040@000P000;T00000303oool000X0ooooCP000002
00<2000F00P;00082@001`T000/>000;4`004Al000hP000D:@005RD001`W000N:@008Rd001lY000Q
:`008BD0020U000R9`009bd002L`000X=P00:CH002Tg00809CL002L0:CD002/d000_=@00<cX003I4
000f@@00<d4003A1000`?@00=48003I5000kF000>Ed003YG000hD000>4`003Q@000oE`40AEd004ED
0016D000ADd004aH001>F`00Ce/004mM001@EP00D5/005=O001II`00FVL005QO001HG@00EET005MR
001FJP00F6`005M_001@L0000P1=L0006P1FL@00Dfd005]]001PL000GGD005]h001MN000GgL105if
0@1MN040GWh105en0@1KN000Fg8005m]001TK000Ig<006Uh001^M`00Jgh006Z2001ZO`00HWT0061j
001RM000Ig<00P1UMP002`1WMP00J7<006Yf001XNP00Ig`006In001YO@00Jgd006Ig001RK`00HVP0
0080Hf`002D0IWD006Mn001YP`00K8L006j7001`Q`00LH4006]j001UM000HGH005mn001RP000IX<0
06B1001TO000HWP005mc001MM000GWD005]c001HJP00EFP0055V001@G000AeH004A@0014C`00?DX0
03Q0000a>000:2L001dO000K6@005a@000h700060P000@000;/00000303oool000X0oooo3`000000
0`01000000000000000m000000800@4000h01PH000D6000;3P0031<0018O000?7`005BP001LW000L
:`007B`001h/000N:0008R/0024Z00808R/000D092/002@Z000W<@009c<002Dc000202D_000K02Te
000[<`00;C40030c000e?P00=3h003I0000d@`00<T8002m0000cBP00=UP003EP0@0hF`80=ED203AD
0@0bE040>UT103mH0015DP00ATl004M90019D000BE4004iD001?F@00D5X00080E64000X0EV@005UU
001KJ@00F6@005IN001FH@00EV@005a[001LLP00Dg<00P1>M0009`1AM000Dg4005M]001LL@00G7@0
05Uf001JM000GG80065b001QM040G7L105Yi0@1IN@40GWL005me001RL`00Ig<006]d001]M000KGT0
06an001XO@00HX00061l001RM000HW8006Ee001VM@00Ig@006Qe001ZMP00IgP006Ee001XNP00JG`0
06Yo001YNP00I6l0069[000206E^000T06Ac001VMP00Igd006b5001^R`00LHH006n1001[P@00IG<0
05a]001LL`00GgL006:0001TN`00I7d0061e001NL000FFh005MY001IJ000F6T0059R001>F`00C5@0
04EB000mAP00>3l003Dh000]<000:2P001hJ000C3`003PT000X500050@000@00_000000<0?ooo`00
2P3oool>0000000300400000000000000400000000`01@H000H7000;3@002`h0014I000A5P005A/0
01HO000L:P006bX001l]000M:P0201lX0007028/000R:P009BX002<]000W<P009cD002Pe000202P^
000402Xd000Y<P00;S80030d0080<ch00240=D@003E2000d@`00<TH003=;000aC`00=5d203EP100e
GP<0=U`203AG0@0jF@00@EL004EC0016C000A4L004=<0012B000Adl004]H001?H000DFP005=W001C
H000E6<005QY001CHP00EUh005QT001HH`00FfT005a`001GMP000P1AN`009`1BNP00Dg<005Q`001G
JP00FVl005A_001GK@00GfX006=a001SM000GgL105mf0@1INP00GWX0065i001TMP00IWD006]c001X
KP00Jfl006Qe001WM`00IGl006=n001TN000Hg<006I`001TLP00I7<006Yd001ZN@00IW<006=f001V
M`00IWX006Mk001WO@00HWH006=^0002065/000S06=a001QK`00IGH006]n001_QP00K88006b7001Z
RP00IWd005mc001LK@00GG0005ic001KK`00GG0005ac001HJP00E6@005AN001>F@00CeL004YD0014
C@00@4X003a5000b=P00:R`002LR000Q6P006QD000h=00071@001040008100010000_@00000<0?oo
o`002P3ooolD000000800@00>`0000005@051`001PT000/=000:2`003a@000hA000>3`004QD0018K
000I9@006B@001`]000K:@006bL001XS000L9`007RL002D/000T;`00:CL002dk000202`g000W02Pa
000W;P00:BX002dc000a@040<TL103M:000f@`00=d@003I6000dAP00<4d0031K0@0`G`<0<f0203AM
0P0hF040?ED0041B0016E000B5<004I;000oA`00?DX004=<0017DP00CUh0059V001CJ000E6<005=T
001EJ@00Df0005AO001GI@00Df0005IW0@1EJ`00Eg<00080E7`002L0DgT005Ie001DL`00EV/005U_
001EJP00F6/005Q]001IK000H7@0069c001RM@00HGT0061n001RP@00IG`006Ii001WM@00J6T006I^
001ZL`00JGT006In001SP@00HWl006Ii001RM@00HGD006=f001UN`00JW/006Ei001QN000HWT006Mj
001XP000IGd0069i001SL`000P1PK`00801PKP00GVh005ma001RN@00I7d006Ao001VP`00IhH006Em
001RMP00GVd005][001IIP00Deh005EO001BH@00DEd004eE0019C@00A4L003i3000k?@00>ch003<i
000_=@00:BP001hL000F4P003`/000X600060P000P40`000000<0?ooo`002P3ooomA0000000E00@4
00051P0010<000P<00082`003A4000`>000@5@004AT001LR000G90006c0001X[000K9`006B0001XR
000K8`007bT0028/000X=000:SH00080:cT002L0:SH002Tb000V;`00:c8002db000_BP40=4/003Y9
000kC000>Dl003I7000`BP00;e@202iK0P0_G@80<Ul103YK0@0lEP00?e<004QD001:D`00ATX003m5
000nB000?TD004I@001;F000Ced0059Q001BG`00Df@0055X001EH`00EFD005AT001AH@00DfP1059/
0@1EL0000P1FM@009`1EM@00EG@0055/001FJ`00F70005IY001IK000Ef`005E[001ILP00GgT0069e
001OM@00GWd006=m001SNP00IG/006Ah001UL000IVl006Uc001YO@00JX0006F3001QP`00I7l006Ak
001RO@00HG`006=h001VN@00IGP0069i001UM`00IG/006F0001VOP00Hgd006=k0002069j000P06Ad
001PK@00GW00061d001PLP00GW<0061g001QN000HGH005id001JKP00EVT0051R001AF000BEH004IA
0018C`00A4X003m3000k?`00=3P002d`000/;P00:2T002<T000J6P004Q0000/700050`000P000000
00010030000000`0oooo000:0?oooe80000001@00P40004100072P001PT000X<00082@003a<000lF
000E8P005BL001Xa000I<0006b/001TS000L7`006ah001lU000R:0009Rh002H_0080:CD002L0:SH0
02Pi000V>@00:CH002/e000cAP40=4T003U:000jB`00>4d003=2000aA@00<dl103=D0@0dGP80;f42
03IP0P0lF@00?U<004=@0018CP00@d/003m3000mA`00?dP004ED0017E@00B5D004UB001?EP00D5d0
055S001CI@00F6/005M]001JJP00DfP005=b0@1CK0000P1EK000101GK`00EW<0055[001DJ@0205Ma
000Q05Qe001EK`00Dfh005Ee001JN000GGH0061a001QM`00HgD006=f001UO`00IX4006Eh001SM`00
HgH006Ei001XNP00IH0005f2001LP@00Gh00069n001RO@00HWT006=g001QM`00HWH0065a001SM@00
GWX0065i001SO000HWh00080Ggl001d0HGP005mb001OL`00Gg0005]]001JJ`00F6L005UY001ILP00
FFl005I/0@1?IP00Cel004]H0017C`00@DP004180011B000>Cl003<j000^<00092D001/K000G4`00
5A<000h:00081@000`8000800033000000`0oooo000:0?oooc<0000000<00@000000000000007P00
000200@4000@00H500051@0030h000dA000D7P0052@001H_000G<00062X001XU000I700071l001`Q
000R9`0092T002H`0080:3P002L0:d0002`n000Z>@00:CD002/f000aA@00<4P003A;000eB000=480
030l000_@000<4L003E@000eFP40<V8103IN0@0jE000@4l0041A0013C`00A4`0045:0010BP00@Dd0
04AC0017DP00Adl004IA0018E000CeL004mI001AG000EF@005Y^001KK@00FV`005Ig0P1CK@400P1E
J@009`1IKP00FFl0059[001FK@00DVd005=c001FN000EW@105=c001IN000Fg`005il001QNP00I7P0
06Ea001TM000J7`006Mo001TO@00Ggd005ah001OLP00I700061j001KP040EX4105Ym0@1LO000HG80
05mg001KMP00GWD005ic001LKP00G6/005]_001OM@00GWT005mm000205b0000K05ek001NMP00Fg40
05UX001JJP00EFD005=O001@G@00DFP005=Y001BJ@00CV4004QJ0014D@00@DT003i6000k@P00>3d0
034c000Z:@0081`001PB000=20002@@000L400050@000P000<D00000303oool000X0oooo<`000000
0`01000000000000000N000000800P4000/010@000D500061@0030`000`>000B7`0052@001DX000H
8`007B8001/O000201dP0003020U000Q9`00:3D000809cl002L0:TT002Y7000]?`00:CD002`e000a
@000;TH1039@000dB000<d0002hl000a>P00<d0003A7000dD`00=5/103IC000mCP00@4d0045>0013
D000AE40045?0010AP00@d/004=@0013C@00@TX004E<0016EP00B58004QE001:D@00DET005EX001H
K`00FVl005Ug0@1FK@000P1EKP409`1FK@40Efl005A_001HL`00EFh0055e001BL@00DgH105Ae001H
L`00G80005j40@1QOP00H7P005m_001QL000H70005ig001MOP00F7X005Qf001HL000G6`005Y^001F
NP40EG`005Mm001IN@00F7D005Ye001KM`00FWD005Y]001KK@00F6X005Y]001LLP00H7T0065j0002
05im000G05]j001IM000EVh005IX001EJ000EVD0055M001<FP00BUl004aP0019H`00B5T004EE0010
A`00>T8003Lj000_<@00:BL0028K000G4@003@T000L5000200000P010037000000`0oooo000:0?oo
oeD000000P0100003`051P001@L000X<000<3@004Ad0014L000F8P0061l001`R000J7P00720001`O
000N80007B4002H^000202Hi000402Q5000YB`00:DX002]10080;3`00240;d/1035=000dB`00<4@0
02m1000b?`00=44003I6000cB`00>54003U<000lCP00?dh0049?0014D@00AED004AG0012E000@Th0
03m;0010C`00@DP004540016B`00AU0004UA0015C`00BED0051U001EJ000Ef`005Ue0@1GL0000P1G
L`409`1ELP40Eg4005Me001FL`00EFd005=a001>K`00E70005I`001IL@00GWT005^40`1ON`00GgH0
05mg001KL@00F6h005Mc0@1HNP00DW/005Ed001CL@40D6h105A/001FLP00EgT005Mn001KO000G7/0
05Qj001JN@00FgH005Y_001GK000F6X005]^001LKP00HG0005ic000205ad000F05Yb001HL@00F6h0
05EV001DJ000DfT0051M0019E000B5D004EB0011D@00@4P003a2000c>000;bh002XT000O6P005100
00d800080`000P0000400<X00000303oool000X0ooooE`0000003`051P001@L000X<000;3@004AX0
010H000F8`005R4001/T000H80006ah001PK000I6P006a`0024[0@0202@`000W02Hn000RBP809Dd1
02Y5000Z@P00:D8002e<0@0_CP00<TX00314000b@000;c`0030o000b@@00<d4003M3000hA@00?4T0
03e?000mD`00?U4004AG0014G000@UX0045F000oD`00@54003m5000o@`00@dX004IC0019G000AED0
04EG001;F`00DV4005=Z001CKP00DWL00080DgX100L0EG@105Ea001FMP00E7D005I_001AK@00CV/0
0080DFl001h0EVl005eb001NK`00I7D006=e001PN000Gg@005Q`001CM000F7D0059f001CM000DG81
05=a0@1GK000FG4005ai001KOP40GWh005im001IN`00FGT005Qc001GJP00EFX005MY001GI@00FVH0
05a[001KKP0205a/000C05Y]001HK`00EFL0055R001@H@00CUl004]F0014B`00?d8003`o000g>@00
<2h002PS000R6`006AD0014;000:1@001@400080000b00000003004000000000000009P00000303o
ool000X0ooooE`0000003`051@001@H000/<000:2`003Q4000h@000C7P004a`0018L000H8@005ah0
01PL000F5`006QP001XM0002024[000W028k0@0NA`4094T102E2000X@@009d4002]9000/B@00<DH0
0391000d>`00<3P002hk000_>000<3/003<i000e>@00>TD003UA000iD`00?4h0049E0012FP00?e/0
041M0010FP00@E800418000oAP00@4/004=D0018H000AUX004MH0015EP00CET0051N001?H@00Cf/0
0080EWH002L0DgD1055a0@1BM000E7L005Mg001EK`00DFh0051`001@KP00EFh005UZ001JJ000IG80
06Ed001TNP00GGL005Ic001CMP40DW@105Af001DN@00DWD005Ia001IK000Fg0005ih001MNP00Gg`0
05eo001KP000Eg/105Ee0@1DK`00F6d005QY001EI@00E5d005EM001DG@000P1EG`004@1FH@00DV<0
04]I001:E@00Ae00049=000nAP00>Sd0034`000]:P009b<001/D000B2`003@H000X300020@000@00
0<l00000303oool000X0ooooE`0000003`061`001@H000@500082@001`H000/=000930003a@000lB
000G7P0061l001PP000F6P006Q`001TN000201dW000W01`^0@0R?P408D@002A1000R@0009T8002]6
000ZA000;TD002m0000^>P00;SP002dj000^=P00<ST0038d000^<P00;cT003I=0@0fE040>Th103mB
000oEP00?e/003eL0@11G040@E4004170010B@00?dl0041D0012EP00B60004QM0019E000BU8004]E
0016EP00BV800080C6/002L0DW80059b0@1AM@40E7L005Ug001CLP00Dfl0051b001>L040E6l0055Y
001GI000HVP0061[001LL`00FgD005=g0@1AL`00D6l005=d001DN000E7L005Yf001LKP00Ff`005Yb
0@1JM@40FWH105Ul0@1HP040E80105Ek001CN000EG0005E[001CI000Ce/004U?0018C0000P19C@00
3`1:DP00Add004=:000nBP00>T@003Ln000b>P00;C<002@R000L5`0061@000`800030P000@400040
003A000000`0oooo000:0?oooeP0000000P01@H000@300071@0010<000T>000930003aD000lB0080
51d000@05Ql101@J000J70006B800P0N9P00900M9@00938002@l000V@0008S`002@o000T>`00:440
02]0000]?@00;3H002/g000]=P00;cX003<m000`=P00;C@002/j000bB`40=4d103U=000nCP00@580
045K000mF`40@5`1041A000lB`00?D`003mA0010D`00?eP004ER0019HP00BEX004UG0080AE8002X0
B5d004eS001=H`00D6/0051_001@M@40DW@105=c001AL@00E6l0051`001BM@40DW@105=Z001GIP00
GFH005aV001HJ`00EW81055g0@1?L@40D78105Ah001FMP00EgX005If0@1IK`00F6/0059^0@1BK`40
Dg8105Ai0@1CN`80E7l105Ii001EN000EFd005=X001BI000BeH004E<0013@`02040m000<03`l000g
>@00=C/003@o000`=000;Rl002T]000R9P0061@0010>000;1P0010402@0000000`01000000000000
0038000000`0oooo000:0?oooaX000000P01000I0000000300400000000000000200000000h00P40
004100030P000P4000T;0009300041P000lJ000A900042<101<S0@0D6`406A`001XP00807RP002L0
7R<002@[000S<`0093P0028j000T?@0093T002Tm000X?000:SX002Xi000Z>000:SD002hm000/?P00
<3l002hj000/>P00<4810350000fA000>D@003eB0012F000@U`1045I0@0oDP00?U4003e?000lD000
@5D0041G0013I`40BFH004eQ001:H000AUP004AC0011D@000P18EP009`1>G000C68004mX001CL@40
D74104m_001@KP00EFl005Ie001CN040EG@005U_001JJ`00FfL005IU001EK040D7<1051[0@1BK`40
EWL005Mc001EM000EgP005Ud001FL000DfT104aX0`1=KP80Cfd004e`0@1@LP40Dg00055_001AJP00
BVD004MN0@15E000ATd003a3000203@h000<02ha000/9`00;BT002X[000R7P006aD001HD000@3`00
2PH000@200030@000@00e000000<0?ooo`002P3ooolJ00000003004000010@000@0003d0000000<0
0@00000000071`000P0820001`0=60002QX100hW0@0?8`40524101<I000H70000P0I7@00600K8P00
6R@001la000R>P008c/002Dh000S<0009C<0028d000W>000:3P002Th000Z>000;c`002e1000a@P00
<3h002Xj000^>@00;S`003=0000e@000>Td003iA0080@ET000d0@5D003eA000kC`00?U4003eF0011
F`00Af`104YX001:H`00BUl004IE0011C`00@4T00080@T/000@0A4l004QI001?G`00CVT00P1>J`00
8@1=K000E6h005A^001BM@40DWX105Uh001JK`00EVL005=R001HI`00EVT105=U0@1BJ`40EVh005EZ
001GK@00FWL005Uj001GL@00E6X104eT0P1<I@40CF<004YT001;I000C64004eO001<GP00AUl0045I
000nDP00>TD003<h000202`a000902X[000S8`007a/001/G000A3@0020D000H100030@000@000=L0
0000303oool000X0oooo6P0000020040044000000P0410001`094`0021H000dU0@0?80404Ql0018H
000F60000P0F5`009P0H70005ah001l_000P=P008cX0028d000O:`007BL002<_000W>0009cH002Xh
000Y=P00:cT002`m000bA@00<D40030n000/>P00;Ch0038o000c?P00>4H003Y90010EP00?UT003aG
000kD`00>4d003eB000mE`00?Ul0049Q0016J000B6`004EW0@15G@00@E@00`10BP009`12C@00AeD0
04mO001<J@00DFT0051X001?K000D6h004mZ001=K@00CG8005Ab001EJ`00E6H0059U001DIP00EfL0
059U001CJ@00E6T005EX001CH`00DfL005A_001GJ@00DF0004iM0@17FP00AE/004AL0017FP00AUH0
04AB0013E000@5<003]=000hB@00<CP002HZ000202@Q000601`N000F5P004`l000`800060`000@00
fP00000<0?ooo`002P3ooolR00000003004000000000000003P0000000T00`800082000830001a00
00XS000<7@004Q`0010C000A4@000P0A4P009`0E6`0051/001d[000M<P007cL001lc000N;P007R`0
02@/000T:@009c<002Hd000V<P009c4002Te000`?`00;d0002m1000^@P00<400038l000c>`00=Sd0
03E0000lD000>EP103YG0@0eD`40=Dl003Y@000iE`00>ed003mM0012JP00AWH104Ia0@16J@00AF<0
04EI000204IE000F04A@0018CP00BE4004iT001AL@00Cf`0055^001@LP00CG<004e`001<JP00DF`0
05=Z001DI`00Df<004mR001=I000CVT0051Y001BJ000DfP004aQ00<0BUl000h0BeX004UH0012E040
@E80041B0011D000?Tl003U:000hB@40=D<0038o000^=`009RX001/L00804`l000D03@`000/70007
10000`800040003K000000`0oooo000:0?oooed000000P010@001`061P001`X000/M000<5`004QP0
00h@000<30000P0=30009`0C5`004a/001T]000H=0006cT101dd0@0M;P007b`0024Z000P9P009Bl0
02La000W;`0092`002H/000X<000;3d002m3000b@`00=T00038k000f?000<CP003Dn000iB`00?5@0
03UH0@0hEP00=U4003ED000fF000?5T003]I0012I040?Vd1049c0@15N040@fd104QV0@0204eR000W
04MI0015C`00ATl004iT0@1@L@40C6h004e[0018L040C7`004ig001>J`00DVX005E]001CJ@00Cf40
04aP001?HP00BVT004eY001@K000Cf`004UT0016GP00A5P0041B0@0oD000@Th0041:000oA@00>D40
03Y3000cA@00;Sl002`m0@0W<P009BP0020R000I5P0040h0008020H000<01080008100000000g@00
000<0?ooo`002P3ooomP0000000600@400051@002``000T8000<3@002@L00P0820009`081`004AL0
014N000D<P0063d101Xe0@0N;P0072P0020V000N8P009B/002H_000W:P008BH0028S000U;000;3d0
02]0000bA@00=Cl0038j000c@000<Sh003M5000fB@00>Td003QC000gE@00=5D003AF000eEP00=E@0
03QG000lGP00>F@203ib1011MP<0@W0104Q[0@0204]Z0@0W04UQ0016EP00A4l004YL001;I`40C6d0
04]^001;K`40CW/005=k001AL000EFd005A]001CIP00Cf8004aL001AG`00C6@004]T001>J000BfL0
04IR0@14F@00@4h003m6000kAP00>3h003Dk000b=P00;Rl002h`000V;@0092H0028U000K60005Q40
014;00081@001P<000800`8000<00P00000000000000g@00000<0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{78.625, 308}, {377.25, 147.875}} -> {-153.971, 260.769, \
1.46487, 1.46487}},
  CellTags->"RenderCTData"]
}, Open  ]],

Cell[TextData[{
  "Even with the colored transfer function the image looks a bit flat on \
modern graphic cards. You can use ",
  StyleBox["MVShadeVolume", "Input"],
  " to get the effect of surfaces in the volume."
}], "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MVListDensityPlot3D[
        Evaluate@\[IndentingNewLine]ToFileName[$MathGL3dDataDirectory, \
"\<foot.v3d\>"], 
        MVNewScene \[Rule] 
          True, \[IndentingNewLine]MVTextureSize \[Rule] {256, 256, 
            256}, \[IndentingNewLine]ColorFunction \[Rule] \(({Hue[#], 
                GrayLevel[#^2]}\  &)\), \[IndentingNewLine]MVShadeVolume \
\[Rule] {0.6, 0.4, 
            0.2}, \[IndentingNewLine]ViewPoint \[Rule] {1.086, \(-2.00\), 
            1.0}, ViewCenter \[Rule] {0.42, 0.5, 0.46}];\)\)], "Input",
  CellTags->"RenderCTData"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00238095 0.0238095 0.00238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
1200 string
400 400 8 [400 0 0 400 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010000020100040200050200070200090300080300
0A03000702000802000B02000C04000C0700130800180D001A0F00180C00150C00150B00
140B00110A00100900140600120800140900150B001A0C001D0E001E10001E1100241100
2311002413002717002814002918002A19002E1B002D1D002E1F00322100342300382600
3827003425003321003021003221003323003323003622003921003A2200392300382100
3B23003B2400402A00412C00442B00452D00462E00432A00442E00472E004A2E004A3000
4A2F004B2F004C31004C3300533B00544000533C00523B00523900513800543F00574500
544800564F005557025359075065104C6F224077363778423279523586513D9B41429F2F
42A02641A1223BA62C31AA352BAB322CAB2C2DA825319F123C9708448D044A87044C8505
4983024B820246840546840546850741810A40810F3F7B103F750A447106456B04486405
4A62054A62044B61034E5C02535800514E004F4100493500432C003E2500372300331F00
321B002F1A002B1A002B17002A17002E16002D18002C19002D15002C1400281100251000
241000241200220F002110001F1000200D001E0E001F0E001E0C001D0D00190900150700
1407001404001305001005001004000E03000A0100080000040000020000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
0100000100000100000100000100000101000301000301000301000701000803000A0200
0904000A02000B02000C04000E0600110700150A00190D001A0F00180E00190B00170A00
180900150A00140900160900150900130C00190D001E0E00221200201100201300231100
2314002413002613002718002719002919002B1A002D1B002E1B00302000342400372600
382400342100311F00312100321D00321F00351F003723003720003A20003D21003E2300
3E24004026003F2B00422C00462A00472D00482F00442E00472F00492F004930004A2F00
4B2E004B2F004E32004E3600523E00554300574200523F00564000513F00554500594B00
5A52005758005461064F690F497220467534426F4D3A745B347C61348A5C3A9A4D3BA53F
37A83E33AB3B31AB422BAE452AAD3D31AB3233A6273C9C13409307448E04468C05468B05
438A05468B04438D04448D05418B093F860D3C82103E7D113F770E427009426B07456606
466205476104495E034F5B01575600574F004F42004D39004631003C2700342100331B00
301C002E1A002B15002A13002916002C1700301A002D19002B1500291300281100221000
230F002512002411002312002112001F1000201000220E00210C001F0C001A0800160600
1406001407001407001106001005000E02000A0200080000040000020000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000030100030100
0401000401000501000601000700000601000701000602000A02000A04000C06000B0700
0A05000D03000A04000B06000E0600170A00180C001910001E12002111001D0E001B0D00
190D00160B00160C00160C00180B001C0C001E0F00211200271800271700271A00251900
261800271800271900271A002918002918002919002D1D00301D00341F00352300362400
352100311F002F1D003020003020003220003620003321003420003822003822003E2400
402500402800432700412A00422B00432D00482B00452C00482C004A3000493000493000
4B32004C36004E3700533900553E005444005446005449005546005646005C4A005A5300
565B005366024F6F0A4B781A407C3140754B466A65417271328173318D6E349B5F33A655
2DAB4B2BAC482AAF4928AD462CAC3835A7283A9F1D42970E468E05458E03468D06439007
4092083F94084194084090083D8E0B3C870F3A82143E7E143D7A143D730E406C0B436507
426306456104496002515D015557005352005143004B37004232003C2900382300341E00
301C002E18002C15002B14002A17002D18002B19002B18002C16002A1300281000250D00
270E00271100251100270F00231100221000221000210F00200D001F0B001B0800180800
1609001509001508001207001005000E02000A0100080000040000030000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000020000020000020100040100050200050200
0402000603000803000704000805000A05000A04000A04000E0600120800130900120A00
1108000E07000C06000E0800120A00160B001B0E001D11002015002214001F11001F1100
1E0E001C0E001C0F001D0E001E0E001C0E001F10002614002A1A002B1B002B1C002A1C00
271C002A1B002C1B002D1D002E1E002F1D002E2000312100362000372200362300342200
362200332000321F00311F00351F00352200361F003321003622003720003A20003E2300
422400422900442D00422C00452F00452D00462E00442900452E00462F00492F004C3100
4E3500523900503A00513C00554100544400524B01534B02564B01584B015B4F005C5901
586604527409487F1642802D3F7947446E61526372496B78357F7A2D897831936B30A063
2AAA592BAD502BAD4A28AC422FA92E35A11D3B991242910B4391064294064096093E990B
3A9B10399C103A9A0E3E93103A8E123A88153C84183E80173A7B163A77143F6E1144670C
446609436305486304516201546001555801524D004B3D004234003D29003A2400331E00
301E002F19002C15002F16002D17002E17002B16002B1700291500281400281100251100
260F00270E002710002710002610002310002310002210001F0F001F0C001C09001A0A00
180B00180A00150A001309001006000D05000B0100080000060000030000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010100020000050100070200050300050200060300
0903000A04000D05000C05000E06000D07000C0900110800160C00190F001B1100190F00
160B00140B00110A00120A00140A001A0F001B10001D1300211600241400221300211100
1F11001E10001D11001D10002111001E13002013002416002B17002E19002C1B002E1C00
2B20002C1F00301F003220003120003121003222003424003724003927003A2600392200
342200352100342000362000361F00351D003820003825003B24003F23003D2400412900
442B00482F00483100483000472E00473100462F00472D00433100482E004B30004C3200
503600533C00543F00514000534300514A015150054F5407555605585501585A005B6502
5871084B8316438B2A408240436F5A46606D465D783C667C32767D2B807A2E8A742B946B
2AA4602BAB532CAC4829AB3C33A626389E173A98113C940B3E95093D9A0B3B9E0F37A115
34A21934A019379A183C9217398F1A378B1C3A871D3E82183D7B163E7415406E12426B0E
42680A4467074A6806516903546501565B00554F004F3E004434003F2A003C26003B2200
3621002F1E002E19002E19002D19002E19002C19002B1600291400271300271100240F00
260F002810002711002A1300271200251300241300221100201000200E001D0C00190A00
170B00170B00140A001208001105000D05000B0100090100060000040000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000101000501000502000602000704000604000804000A0400
0B03000D05000E0700110800110900120800130900160900190F001E13002014001E1200
1A0F00170A00160A00150B001A09001B0D001C10001F12002313002112002011001E1000
1D0E001B0D001D0E002011001F13002210002312002713002A1A002B1B002A1C002A1D00
2C1C002E1F002D2000321D00311F00332000361F003921003B26003D27003B27003B2100
372200381D003A21003622003520003820003625003D25003E26003F2600412800412A00
472E004832004D35004B35004B35004A33004832004933004932004A33004D3300503300
553600553D00584000554000544700524E034F59094D601051630A566504566B02577707
4E8315448C2B3F864442715A4A586C45517938557F305C802D6A802A757C2A7E782B8671
2898652DA2522FA8462EA83636A2253B9D173A99113C990C3D9B0A38A00E36A21631A31A
30A31F349F24359B23389324359225368E273A8922407F18427913407211416C11426B0E
426B0B416B09476F094E7005526D01576100574E004D3D00453100402A004029003B2500
352100311B00301A002E19002C18002B17002A15002A13002A1400291200271200291000
2611002613002914002B14002B1400281400271200221000200E00200E001D0D001A0B00
180900170A001309001208001006000E06000B02000A0100070000050000020000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000100000100000301000501000603000603000504000704000904000A03000D0400
0F0700120900130A00140B00130B00160A00150C00180D001A11001D11002015001C1100
1B10001A0E00170B00160C001A0D001E0F001F11002014002515002113001F10001D0E00
1A0D00170D001A0E001B0D001C0E00200E002310002615002819002B1C002B1D002E1A00
301E00301F00302300312000311F00321E00341F003821003D25003C27003D2800382400
3721003324003521003623003A24003C25003E25003E2900412C00422B00452E00462E00
472E00492E004C32004D34004D35004D35004D35004B35004C36004C34004E3500503600
523700523A00583D005440005448005154044E610E4A6C1750711153750A537A08508513
4A8E254189464A6F615152735A477850457E3C48833250832D5F7E296D7A297776297C73
298E682F9D5632A74630A73736A2273A9F1D369C17379C13389E1037A21237A31836A21E
35A022349D25339A2731952A30932D35902E3E8827467E1848740F456C0F426A0E426B0F
406B0C426E0B46710B4A75074F6F025861005A4B00503800422D003E2A003D28003B2300
371F00301E002D18002A1A002817002915002A14002A12002B12002A1300271300281300
2A14002B14002814002915002B1300271500261200231000210E001E0F001D0F001A0C00
180B00180A00130B00110B001009000F05000C03000B0200070000060000030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
0201000401000501000402000602000903000803000902000B04000C03000D0700100800
110A00160A00150A00160A00150B00150E00180C00190D001910001C11001D13001C1000
160F00180D00150D001B0C001E0F00211100241500251500281A002318001D12001E0F00
1A0F001B0D001D0E001D10001C11002011002213002615002818002D1B002C1D002D1E00
3020003220003320003320003220003521003722003825003E28003D27003C25003A2400
3722003721003624003A26003E21003C27003F2A003E2B00412D00472C00492F00492C00
4B2F004A34004B31004D33004E32004D35004E38005037005037004E37004D3700503700
533C00523D00564000584400534E00555E044F6C0D4B77184B7C154D82124C8B184D9328
4D923E557C5A5F5A705F497C5D417F543E824642843A498037587E30657B2C6E79287075
29846C2C995C31A64E2EA73F33A32E35A022339E1D339E18339F1736A21837A51B36A420
34A322319F272D9B2B2F97302E963136902F3F88264A7E164B750D476E0D426D10426D13
406C0F44700A4676084777074E7003565E015648004934003F2D003E2A003F29003B2400
351F00301C002D1B002C15002B15002B17002B16002A14002A14002913002A13002B1500
2B13002A14002815002816002714002415002611002310002011001F10001D0E001A0E00
170A00180A00130A00130A001109001006000E04000B0200060000060000030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010100020100
0501000603000705000904000A04000A04000A05000B05000E04000E0600100700120A00
160C00170C00170C00160C00180C00180E00190F00190F001B0E001B12001C12001A0E00
180C00190D00170C00180D001E1100221300261700271B002B1E00251A00221600210F00
1E12001D13001E1100211200220F002113002313002514002B14002D1B002F1E00322000
3321003423003523003621003721003524003D25003C2A003F2B003E29003F2A003E2800
3E29003E26003F29003C29003F2600412900422E00432D004730004B34004E33004D3500
5135005134004D34004F34004D3500533700563A00543A00553D005239005037004F3800
543F005541005A4700584B0057550057640452700C4E7B154C8316488F1B47972755963D
6385566C6E6874547568447D5E3B825532834E3484443F8240527E355F7E2E667C2A657B
297B702B92622DA2562DA64B32A53F36A32E2FA32330A42035A51F37A51C37A82035A724
32A3252DA12B2A9D2F2C9A3130962E3B8E2845871C4E7E104B780D47720F447114437016
41701147720A447707467807506E04585C005442004833003E29003E28003F28003D2600
3A2100361C00301A002E1A002C1B002A1B002B1A002C18002A14002915002B16002A1600
2B14002813002615002615002713002513002610002411001F12002212001E11001B0E00
1A09001A06001509001409001109001005000D03000B0200080100070000040000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000000000000000030000030100040100
0602000904000C05000C06000C08000F0800110600110700120A00140B00160B00170C00
190E001B0E001E0E001A0E001B0E001D0F001A10001B10001C0E001D0F002010001C1000
1B0D001A10001B0E001C0E00211000241700281C00291D002D1F002A1A00251500221300
2210002011002014002315002614002716002617002918002C18002D1D002E1D00301C00
301F00312000331F00321F003420003826003D2A00422B00422E003E2D00422D00432E00
422C00432A00412A00412A00422800422B00442A00462C004931004F3500503600503A00
513C00533800533900533800553800553B00533C00543E00564100533F00543D00544000
564600544B005A4C005C54005C5C0157690654760E4F8115498D1B429929439C3F5B8D53
776F687962737E517874417A66397F5A3582573C81494C80415A813763872C648126607A
246D702782632A945F2D9F572EA74F30A93E2BA8302CA72A33A72735A62232A9232FA827
2AA52E27A43428A2362C9C3535962A428D1D4A86114D800D497E0E437815437519447419
447513467609467906477606526C025958005440004832003F2D003E2A003B2600392500
3D2100381C003320002F1D002E1A002F1B002E1A002E19002B1800291500281400271600
2814002613002715002814002914002611002710002411002112002112001F11001B0E00
1A0A001A0800150A00130A001109001006000E06000B0300080000080000040000020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000FF0000000000FF0000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000010000030000040100050100080200
0902000A04000F07001007000E0900140A00120900140C00160C00140B00170B00180C00
1C10001E0F001E11001E11001E0F002110001C13001E11001F14002213002311001F1100
1F12001E11001D10001D1000231200281800271B002C1E002C1F002B1B00261800261300
2512002412002415002515002513002B1700271800291A002D1D002E1D002E1E00301F00
321E00312200341F003520003921003B26003F2A00432C00422E00422C00432E00452F00
453100462F00482F00472F00452E00452E004830004732004B3700513A00553A00533900
563C00543C00543D00543A00563D005840005A3F005944005944005A4700594700594800
5C4E005A51005C57005F5C015E660358750B4F83174A8E2042992D3D9C3F4992525C8164
6D68746B587D6F4D7D6D3F816539825B3A8058417D4D4E7F455782355F8B2B5E85255A7D
2461732570682981662994622BA25A2BA84B2BAA3C2EA9302FA72831A82630AA2929A930
26A73624A73A25A4382D9E35359625418D1847850F48810E457E12457A1946761A49771C
487815477B0E417C084478074F6B03565200523D004934004230003F2B003D26003E2500
3B2600372000342000331F00321A002F1A002E1A002A17002A1500271500271300281400
2713002913002B14002814002913002611002611002311002112001F13001D12001A0F00
1B0C00190C00150C00150B00120B001106000E06000B0300090100080000050000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000010100030100050300070300070300080100
0903000C04000F06000F0600120700120900140A00150C00170C00170C00170B00170C00
1A0E001E13002115001F13002013002114001E12001E1500231300241600201700241600
2212002013001E1400201300251400281B002A1C00301F00301F002E1D002A1A00271500
2513002311002310002714002915002A16002A1A00301800301C00342200332200352100
3825003826003925003927003D2A003D2A003F2A00412A00422A003E2C003D2B00452F00
472E004531004633004730004833004A32004D3500503700533900523E00523F00533E00
523A00553D00533D005540005A41005B44005C42005D44005E47005F48005E46005C4A00
5950005A55005B5A025A6104576D095081134692263A9F3339A0443F9357548166606E6F
645C775F4D7F6545836A3D84633A875F3F835B4580534B81474F893B538E315486294F80
2953792A5C712E6C6E2B86692B9A622DA65B2DA94B2FA93831A82E2FAB2E2CAC3426AD3B
24AE4024AB4025A4372C9F32349A25409219448B12488514458115477B154876144A7716
497B154380143E800C4078084F6702544D004E3700453200402B004028003E24003F2500
3A2400392100392100342000301A002F18002D17002A16002814002816002A15002A1200
291500261400281500281600271200250F002510002210002211002011001E0F001D0E00
1D0E001B0E00190C00170C00140B001108000E05000B0300090200080000030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000301000601000803000A0400090400090400
0A04000E0400100700100700150800130B00130C00160B00180C00190D00190D00190D00
1D11001F1300201600221500241700231800241800251700291700281800241700241800
2215002014002010001E10002314002817002D1B003020003324003222002D1E00271900
2515002012002213002514002714002914002C1900311B00321F00342000352300382500
3E27003F2A003F2D003F3100403200432D00432D00412C00432E00412A003F2B00402C00
452F00472E004731004930004C32004D3700513C00553D00563E00564200554100584100
564100564000583F005A44005B43005F46005D46005E47005B48005D48005D47005B4600
5A48005B52015B5A0656680D5177174987293F943D38994A3E8F5E52786B6D626F735475
684B795E3E7E6042845D43885D448D60438D66458A5A448B52429046418E3844892F4482
2D447E304A783455722E75682A90632AA05D2CA6512DA7412BA73F27A93F25AC4224AC45
23AC4926AA4A29A73A30A232359E273C951C428F16448818478313497C0F49780D4A7C12
4480153F85173D830F4378085060025348004C3600442D004229004128004027003F2800
3A2400362100362000352000311C002F1B002C17002D14002A1200261400281200291200
271200271300271300281100251100240F00231000220F00230E00220F001F0F001E1000
1D0F001C0F00180E00170C00130B001109000E05000B0400090200080000030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000500000600000702000904000806000A06000B0500
0E0400110400110600130900140A00160C00150B00180C00190C001B0D001D0E001D1100
2112001E1300221700221700251A00291800271B002B18002A1A00261C00281800251500
231300221400210F001F13002818002A1A002F1C00352300372800362800311F002B1900
2815002414002813002818002917002B1B002F1E003521003523003A25003926003D2600
402B00402D00422E00442F00423200413000452E00452C00442C00412C00412D00442F00
4830004A33004B36004936004A38004F3D00534400574300564600584500574400584600
5B46005D45005D49005C4800604C005E4D00604D005E4B005E4A005F47005C46005C4800
5D48005A52025A620C52771D4A852F438741438257467D624D766B65636F7B5372754975
6A48795D42805A44835548865B478867408D723E8F693B9064378F53398A443E86384081
35437C364779385174306D702888692A96672E9B602E9E572C9F51289E5128A25225A654
24A75528A8552BA54531A63837A22D3C9A2241931B438B1849840F4C7D0A497C0A46800E
4284133D86163D8410467609515D03554800503500472D004329004129004029003D2400
392400362200332100342000321E002F19002E17002B1500291400281200281200241200
261200231400241300241000220F00231000221000231000230F00210F00210D001F0E00
1C0F001C0E00190F00170B00150A001109000F06000D0500080500080100050000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000FF0000000000000000000000000000
000000000000000000FF0000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000200000300000501000902000802000B03000C04000D0600100800
140700130A00130A00150C00160B00170E00160E00160D001C0E001F10001E1300201300
2312002114002214002517002D1C002E1C002E1D002E20002E1F002A1B002B19002B1900
2816002715002716002616002B1B002E1E00312200382500392B003627003320002E1C00
2719002616002A18002A1B002E1B00311D003721003B23003B27003D28003E2A003E2D00
3F2A00412C00442F00443100432E00442F00432E00432E00423000453100483300493500
4E39004F3D00503C00513B004D3B005140005444005847005B49005A48005A48005B4B00
5B4C005B4F005B51005B51006052005E56005D56005A54005C52005E51005E4C00624E00
5A4F005B580356701645893341884F4671644C6072575F6A5E5E666E536B754B736D467B
64497F5C48835946825540825B3F896B378D79358D75318F6F2E8E5D348A4A3B833D407C
3A437B3848763553742E6873287C6F2A85712D8B6D308F683091632C91642A97612A9E60
28A05E29A45B2EA64C32A74037A6333C9F2B3D9821408F1947870F4A800B497D0B44820F
44841141871441821145730B505D035449004E39004A3000452D00432B003D27003C2300
382400372200382200392100341E00321A002F17002D15002A1400271200291200261300
271300241400231300251100241000231000231100231000220F00221000200E001E0F00
1D0E001C0E001A0F00190C00180A001408001207000F05000A0400080300060000030000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000FF0000000000000000000000000000000000000000
000000000000FF0000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000401000701000702000A02000B02000C07000F0800100900150C00
170D00180D00180F001810001A10001A11001B10001B11001D1200211200211500231400
1F10001D0F002314002618002D1F00301F003220003120003020002B1E002C1B002A1A00
2E1A002C1A002A1A002B1C00332100352500382800392D003C2E003728003022002D1C00
2917002619002818002A1A002E1B00321E00341F003A25003C2A003E2A00402B003F2D00
3C2B003F2E003F2E00402D00432E004530004730004531004835004B39004B39004E3A00
503F00504500534600514400514200514300564800554A00584B00594D005A4D00585000
5B51005A5500575500555600575900585D00595B005A5C00605900605600625600625600
625A015D6A0A597E234D874E517769595C795F4D79654E68724E567549626F457467447F
6147815E45835D3F85593682613286702B8B7D288C78238C74278D662C8A4F36843F3C7F
3F417B3D4978395279315E7A31677B316E78347477327B7832817730877230916D309967
2D9C622EA15932A64C34A94535A74036A138389B2B3C9320458A16488311468111428511
43861142861244811247730B525B045048004D38004530004228003F28003C2300392200
3B23003923003920003B2100382000361D002F1B002F16002D14002C13002A1400241600
2416002514002613002812002612002512002412002311002411001F0F002110001E0F00
1D0F001C0D001B0D001A0D00180B001509001208000F05000C05000A0400080200040000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000FF0000FF0000FF0000000000FF0000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000300000702000803000804000C04000D07000F0900120D00140E00180D00
1A0F001A10001C0F001B0F001D12001F12001D13001E1300201500211200211400231300
2012001E10002317002A1C003020003021003323003325003424003020002F1C002F1E00
2E1F002D1D002D1D002E1D003521003A27003D2C003B2E003E3100372A003323002F1C00
291B002719002917002A18002B19002C1800301C00381F003727003D29003E2B003F2B00
3C2A003E2D004132004534004836004835004A39004B39004F3F005041004E44004F4500
4F49004E4F00504E00524C004F4C00524D00554E00565000585100585100545000565400
555700505B004D5A004E5B004E60005461005463005760005D5D00615D00625C01696304
66700C5F801B5E813A656F6769617B71507C704B776649706347685F436E57437B544380
504284543F83573A855F38816D33837D2B828A278187228781258770298A543386423B80
43437F494C7F465380445881485B80445F7D42627B3C69773B7175367C7134886B309265
2F995A329F5035A54639A94534A84235A240339B3534952D3E8E1E438818428515408713
43861043840F43801348720B515C045349004E3900442C004028003E25003D2200382200
3A23003A23003B24003B25003B2000391E00341C00311B002E17002A1600291500251600
2815002713002812002812002612002513002512002413002411002210002011001F1200
1F11001E10001E0E001B0D00180B00150A001409001008000D06000A0500080300040100
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0200000400000501000902000A03000B04000F0500110800140A00160D00190D00190E00
1A10001B11001913001C11001E1400201700231700231500231600251500231400221400
2210002013002818002B1D003224003326003426003225003122002F21002F1C002C1E00
2E1D002F1E002F1C002F1D003622003927003D2B003D30004031003A2B00342500332100
2D1E002918002719002919002D18002D18002D1C003520003925003D2800412B00402E00
413000433200483800483C004B3C004E3F004D40004F42004F48004F4B004B4D004A4E00
4A53004A5700505700505B01505A02525902555901585800575900555900545700555C00
515F004C62014860004863004966014F6500536700596300606400636400696F046B7A0F
60872357853C647057785278774C8079477B7545776443795841764F40784C407E4C3E83
4D3E804E3880543580653B807D388091337B982C7493287889297F7A2C846136844D3C80
4E4281564A805C528057547F58518055567F545A794A5F7545636F406F6A377E652F895E
309154329C4936A34539A74137A64035A138379B36379635419128458B1C458818458713
46840D45820B437F0F49740A515D03524B00493800442E003F29003C27003924003A2400
3926003E25003E24003C26003B26003C1F00371E00371A00311800291700281500271400
2A13002A11002915002A14002A1300291400281200261500251500241300241300221200
2111002111002010001E11001B0E00160B00150A001209000D07000B0500080300060100
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
0500000601000A03000C04000C05000F0700110800130800150A00150C00160E00190E00
1B0D001B0F001B0F001C1200201400231600221700221500221600221600251600241400
2516002215002A1A002D1F00322500352700372700372800332500322300311E002B1D00
301E002F20002C21002F1F003323003B29003D2B00432E004130003D2D00352500322200
311E002F18002B1A002E1E00311C00321E00331F003C2300402800412D00432F00453500
4836004C3D00534200524800554A00514A00504C004E4E004D53004B55004A5701465B01
4760024663034A63044C65064C6808506607526204535E01555E01556000576200526301
4E66024A6A03496B03496D034D6C02506D02526D015A6B015F6D0163750363830C618C24
55884454735F6C5C6E7E477E723F816C3B7F65397C593A804E3B804C3B7F4D3C7F513A83
4E3A81523A7B5B377E6D377E88387B983876A336669B326C9032787F36806E3F7D5F437E
60467C6C4A7E714E7E6E4C7F6A4B8265537D625A78555D734A606D436B67397B63348659
32904E379A4639A44038A63C36A434369F3039982E3A9330448E24498B1C4B8A124A840C
4C8108488008427E0A487106505C02504800463A003F2E003B2C003A27003B24003B2400
3D22003E25004224003C24003C22003A2100361E00341C002D1B00281700281400271400
2815002C15002D14002E15002916002A1500291400271500261500271600271300261200
2312002210002111001E10001D0E00170C00170A001209000F07000C06000A0300050100
030000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010000040000
0803000A05000C06000E08000E0700100800120700140700130900150A00180C001B0E00
1D0F001C11001F1100231200231300241500241400251300251300241500251800251700
241500241700291C002D1E00312200362700362900362A003425003225003022002F1E00
301E00322000331E00331D003922003B28003D2D004232004335003E2F00372300342300
3320002F19002A1A002B1900311D00342200372300402900412F004531004836004D3D00
534100524800544B005452005554005056004A5600485900435D00436001416204406707
3F6D0842700A42700D4673104775154B710E4F6C08506404516604546803566B03546B04
4F6E064B74074A75064D73075073065472065272055C7504617E06618B0F5C911F588639
5A76565C666B70597479477B6B3B80613781563882543782523D80513F82564181603A81
59398057387C5E397C6B33797D31798D3579953B78903C7B843C7B7D3E7F74497C734E7B
7D4C7B8C4A788F477887407A793D7D73497B66517C565A78486175416D6F3E7F66378B59
37964B37A04439A53D39A23435A02C359C283C99273D9326448E2147891949860D4E7F06
4E7D06477D064579064B6C034D57014E4500473600402C003A2800392600392400392200
3E24003F26003D28003C24003B2300392000331D00321C002D1A002C16002C1600291500
2916002C16002B16002D17002B16002C17002A1500281500271500271600271500251300
2212002311002310001E0F001B0D00190C001809001309001107000E0500090300050100
030000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000020000040200070200
0B06000E0900100800100900110900110700120700110900130A00140A00160C001B0F00
1C11001E1000201200211400221400251600251700251600271800291700291800291800
291900281A002B1A002C1E002F2100342500372A00392D00382900352A00352400352300
3320003320003121003121003822003C28003E2B004130004235004134003C2C00362800
3224002D1B002A19002B1E00311E003420003B25003F2800422E00463500493A004C4300
4F4D004F51004C53014D56014A5A01485D014260013E65013C6802386C06377009367410
3877133779173C791C3F7B21447C244778184C730F4D6B0B506C09536F07547008517309
4F760B4C7B0E4F7C104F7A1155790E57790B587E0B5F860D5D91165B8F275885355E7A47
646F59656A696B60766F507B653C805C3882553989533988573F885A428D5C4383683F80
633C7F5F3D7E633D7E71317A7D2977833280873C808542817F407D7D437C7B51797F5476
8A4F7392436F923E6E914070853F737B427868447C54577E436B7B3F77714086643E9255
3D9E4B3FA3413EA4383EA12B3A9D253A98223B95223D901F408C1B4786144D800A4F7D04
4B7C054A7B044675044D67015057004E43004734003F2C003A2700372300392100382300
3822003A24003A25003A24003C2000381E00351E00331D00301C003119002E18002D1500
2C16002D16002E15002E17002B18002A18002B1700291700271700271600231600241500
2512002211002010001E1000170D00180C00170B00120A001006000D0500080200050100
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000020000030200070400080500
0C07000E09000E0900120800120900130700110800120900140900150900190C001B0F00
201100201300211300231500261500281A002A1A00291D00291F002B1C002A1C00291B00
2B1C002B1D002E1F00302200342800362B003B30003D31003D30003B30003A2A00392500
3521003320003020003320003925003E29004228004531004839004538003F33003C2F00
362B00311E002F1B00301C003420003922003E2500402D00453200453500493D014A4902
4A54024A5903465C03435E04425F034262034063043D67043B6D0538740C357916327D1D
327E1F337D24377E253D7F27437F2A467D1F4A7B174B75124C75114D78104F79114D7A15
4C7D184A7E1B4E7E1D4F7F1F57811B5B8718628E196793216491305E853B5C78445F714F
676C596D6A656D656D7159726E4B796C467E6A427E6B417F6D40836F41846B438169457C
67437C69417E7140827D397C8B327587337D8338827D3E827F437C81437A8353748C5570
8F496E933D6C8E3C708C42738345747D45756950745166774775724C766650875A4E9A4D
4DA4434AA5354DA0284C9B1D469717429216418F1B3F8D1C3F8A1E4484134B800A4E7F05
4A7E064A7A054A74034E69024F55004F4300483400422C003E29003B23003A2300372400
3925003C27003926003E27003B2300392200351F00351E00331C00311B00321700301400
2D17002C1800311900321A002F1A002F17002C18002C18002B1700291400261400241500
2514002313002211001F1000180F00180D00180B001309000F07000C0500080200040000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000301000603000907000A0700
100700120800120B00140A00150C00140A00110900140A00170900170B00170D001D1000
1E11002013002316002617002617002719002A1C002B1F002F21002F1F002B1F002D1E00
2F1F002F2300342500382A003A30003D31003E36003F3C00403A00403700403500402C00
3C2800382300341F00351F003A29003F2C00443000453500483D004640004239003F3400
3C3100362200321D00341D003924003D29004831004838004B3E01474202484B05455607
475F0845640942680A3E690B3E6B083D6B073E6B08416F093D750B3A7B18338125328730
34862E33842D3783283C8227408026417F20457E1E467A19467A19457E1949811C49821F
4982224885264D852C508A2E58912B5A992C5F982E628D38638541617D495E77505A7757
58765E5A76655B726A636C6C6D5C6F6E5373734F747947777B407C823A807741806A497B
634C7C6C497E7A487F873F7C9739768D357A80327E7536807B427B82497889536D925467
9043688F396A893972874275824B707E5367666B65517E644F865B55874C578F47589D41
57A23757A0285B981D589312538E0F4D8C0E488A124888194888214883174A820C4B8206
497E04497B044C6F024F64015052004F4100453300402C003E29003B27003A25003C2600
3C27003E29003E28003C2500392500392200362200351E00331F00331A003319002E1900
2D1C002F1D00331B00331B00301900301B002F1A002E1A002C18002A1700271800261700
2617002616002214002111001B0F001A0E00190B00150A000E07000C0400080300040000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000401000803000B07000E0600
110700120A00140B00170C00190E00180D00170C00190C00180E001C0E001B0F00201000
211100231400251C00271900251800281900291D002C2200302300321F00302100311F00
3421003527003A2C003930003B3600403C003D3F003C42003F4300424200433F00433900
3D33003B2B003727003823003E29004030004633004839004A3D00463F00453900413600
4130003C2600362300392500402700432E004D3A004F4702495103445707435D0B436711
426E124173123F76143C79153B751038760E3777103C78143D7B1838812135872D318B35
2E8C35318A3132892A3587233A861F3F851C40841C41821941831C42851D43871F448921
458D2647912D489738499C3F49A0404B9F42529542598A4459854C598051597C5758765E
58775F5978625D7765646E657361647B5769824E6C89466E8D3C7A93387E85427E6E4D7D
6051826C4F7D7A4A7B83447C8D4376853E78753B7B693B7B7444777E4A7586516D914E65
904C639048638B3F6D8A3C77814C6D77675E61805A548F4F59924158903A58943E579C38
579B315D97255B8E1C588B12568B0E51880B50870E5085174E861E4E831649840E478408
498206487A064B6E054D5D024E4D014B3D004632003C29003928003927003B26003F2500
3F26004027003E25003A2500382300342200361F00371E00311D00321A00321A002F1A00
2E1C00311C00341C00331C00311C00301D00301C002F1B00301A002C19002A1700291700
2717002414002212002111001D10001C1000190B00140A000F08000D0500080200040000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000100000501000903000E0600110800
150900140C00170D001B10001D0F001C0E001A0F001B0E001C10001B12001E0F001F1200
201500251600261A00281700271500261900281B002E1F00312200322400332700362700
372C003A2E003D34003B38003C3F013F45013E48023E4C03414E03415002414E02414801
414401403B013F2E003E2B003E2F00443600453500493800493E00473F00463900433300
4333003F2B003E28003E2800432D004938004E46014E57044763073D690B3D70113A7518
3879173A801A36811D31821C31811932811833821B36811F3785213387272D8B2F2C8E33
2B8F2F2D8F2C308D24338A1F36891D3788193C87163F86143D87163E8C1944911B46951E
479A2446A13142A4413EA54E39A0553A9958418F554B8557518157528059537E58567B5A
5B7A5D62785E6A7861657161666362665862685369704B707C47798A4577854C78764E78
674D7D6C4D79754D78744C7B794C7A6B4A7A63457B5E437A6D457177476D844C678B4A66
8E506591526A8D49718B4A737E5C6D6D775E638B4F5E9340589336549135518F3A549337
559531599227578B1B57881257860E53860B52830C5582115484145385114C870F49870B
46840A437B0A496F064B5C034B4701493C004531003E29003A2600392400362200392400
3C23003E25003A2200381F00352300331F00351E00351F00331D00311A002E18002D1900
311B00321F00301E00301F00301D00301D002F1E00311D002F1D002C1A002A1900291700
2717002614002513002012001E10001A0F00190D00160A000E08000C0400080200040000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000201000602000B05000F0700130A00
160B00170C00180E001C10001E10001D0E001B0F001C10001D14002013002212001F1400
2316002615002818002818002A18002719002D1B003021003324003929003C2F003F3100
3E35003F39003F42003C47023751033853043858063B5B083A5C073B5C07375C06375605
3952033C4B03443F014336004836004B3A004936004E3A00493C00463C00453C00463900
443900433400452E004733004C37005142004F54024C63073D6F0C347610327914307E19
30821B2F861C30881F2B891E2C891C2D89202D87262D8A292D8A2B2C8B2F298D30298F2D
2B9027308F20338D1F328D1D338B1E3789193B8A133B8C123E90183D971C3F9D1F3FA026
3EA13237A344309E532D97612A91662D8C672F8566398463418061477D5F497A59527A56
5D765967745A746E5B6E675E655E5E61546161536766506D6E4D74804E728253727A4C73
74447A734A79764D7A6F4F7C6B4F7A5F4E7D5B487C5A447968467172436C824864884568
8C506C8E51728952707F54716A6869637E596688475F894055883D4F88404A8B404E8F3B
539030528E26518A1A508615528210517F0C507E0B4F7C0B517F0A4D830946880D43870E
41850F3F7D0F476E084957044C4501483700442F004229003E27003C24003A2300392200
3A25003922003B1E00371C00351E00331E00331B00331B00341A00301900321B00311A00
341F00352000331E002F1D00301C00311C002E1D002F1D002D1C002C1A00291800281700
2718002415002314002111001D0F001B0E00190D00140C000F06000A0400060100040000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000FF0000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000300000302000903000D04000F0800120B00
160F001A0F00190F001D0E001D11001F0E001E10001F1200201500211600221400251700
2817002B18002D1C002C1E002B1E002B1C00302100352A003B30004039003E3E00414300
414300414A013F50013B5804345E0534620633660931690E33670D32670D2D640C2F5F0A
315C08385705404B034440004B3F00524100513F004F42004F45004C4100484000484200
4A43004A3B004C37004E40005046005056004C680443720C367D113082142C84142A8616
278718298A18298B1C268E1D2A8D1F2C8E252C8E292C92302A91312E8F312D912E2F9126
33921F3B8F183B8F153B8D16398D1A398D153A91143B9616389E1F36A32835A63032A23B
319E472F99532B8E5E2A87652A80692F7D6B377A6C42786B42786B45766148705857704F
666F4E6E6C547366576C615B635C5E5C5A635A5B656258696C546A7B52688052697E476C
7B3D767A43767E4B796C507B5E4F7D54517E5C4F7C5C4C7B6B44706F426B7D4364844168
8A4B6D8C4E7382546F6E5E6A646E60667B4D667446586E474E7049487B484A81424E8737
5388284F8A1F4E85175083124F7E0F537F0B507D094F7D094D800849850B418A0F3F8B12
3C841141790F466A09485403494101463400422E00412A004129003F27003A26003B2500
3C2500392100372100361F00381E00331D00321A00341B00311B00301C00321900351E00
352000372100332000322000301A00301C002E1B00301B002E1A002D1A00291900261800
2617002415002414002011001F10001C0E001B0E00130A001006000B0400060000020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000301000701000903000D04000E05000F0A00130B00
160D00170D00190E001D1200201200201400221500211200221300211400261600271B00
2C19002C1E003122003124003526003527003E2D00413700443F014549013F51013E5602
3C56023A57033B5B03385F03326205316605326A082D6C0D2E6C0C2D6B0B2C6A0B2C660A
29640B345E083E5405444C014E4D01534B00534800544D005150004F4B004A4700494C00
4850004E4B00534A00584F00595D004F6B03427708398310318918298C1D298D1A278F18
278F1729901928901A2B901C2C8F1F2B91232B91262B932D2F922F30933332942D349425
3B912141911A4192174193163F981B3D99193A9E1935A41F30AA2C2AA83C27A448289A50
299556298F5B288660277F642A796534766A3E716D49717144726F436F66446B60517054
61714E636D4E6266545C615A5B615B59625E5D635F675E606A5C6371586672516A734A6D
7741738142798A457D754A80574E814C52825B557D6055786D4B6E7145697C42667E406A
7F476D7C4B6E795167695F5E6570536F744669634C58595249665346764C4883404D8530
4F831F5085175082144F831252821055800D567E0A50820A4C850D4686114189143E8712
3E7E0E40720C4A6107484C034A3B00453300422E00412C003E2D003F2B003E29003E2800
3D26003B24003A24003822003A2100342100341E00341E00341D00321D00341C00322100
362300362400352100322000311C00311D002F1C002E19002D1800291900271A00261900
2518002516002415002212002011001D1000190E001309000F07000A0400060000020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000200000200000401000801000905000D0600110900120C00150D00160C00
180C00190B001A0E001D1200201600231500221500231400201200221600271700281B00
2D1D003020003324003729003A2A003B3100433A014648034552043F5904396305356605
356204375F043A5D03375E033860023C6305366707306B0A306B082D6B072E6807306809
2E670B35640A3A5D074259044D5702555001564E005453005157014D5702495803465B06
4764054C6202525F015766024F7304467D0939870F32901729951E25972028951F29971F
24971E279A1F28981F2A95202A95202A97242B98282C992B30982E32992E33962E35942C
37932A3D9725419B223F9D213DA32538A62632AA292CAB3126AD3B23AA4922A658239F5C
239B5C24995A239558239159258E5A31895F3E83674B806D497D6B4A77634E6D5D5A6D57
636B4E5B6B504D695647655C4D6B56576B555C6559675F5D665C61685A6466576C6E4B6F
7443767C427A80467F674F824A528247577E605B7A695F7571526C6D486B7D45677C3F6E
7A476A734C677C5A62726D5570764A8269477A58515E56544D65534B754D4B844050882E
53861E57871956861555861555881457861058830E54870F4C8611488717448416408110
4277094869074E58034C4700493800432F003F2C00402A003F2A003F2A003E2D003F2C00
3C28003D28003825003A27003A26003B2400392000382100361F00321E00352000361F00
351F00361E00341E00322000311D002F1D002C1C002C1B002A1A00281800291800271900
2619002417002413002111002010001A0F00160D001209000F06000B0300060100020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000100000200000301000502000A04000E0600130900140C001810001A12001B0F00
190E001A0E001E11001D1300231600241700251600241500241600231500271800291A00
2D1E00302300352700392D003D3500403D00454B024159063A6508366808316C072F6B08
3667063C62043E5F033C5C013B5C013A6404366607316A08306A072D6B06306B05336A06
2F6B093269093A64063D6106486005535A02565600575C014F6303476406456609436E0D
3B760B4277084A76064B7F0942890D37911430981E299E25239E29239E2B279F2826A027
24A02723A028289D27299C232B9B232C9B232D9D262F9D28309E28329E2A319D2A309D2C
2E9E2C32A32B38A72B34AA2F2FAB362AAB3A26AC4021AC4422AA4924A94F26A85824A659
25A75729A75627A65326A45428A1582D9B5E3599673D93693C8F693F846342776248725F
4E6E57496E564173593E715B477355556D545E65576658616455665F5D685C5F6F665376
70477976457F7346845D5086455283435B805E60756760736C556F6B4D6D7E46697D426E
7C476A72506878635F7475507873498B614D7A575365555454694D50784650863B548B2D
578A1E568B19578C18578F16588D15588C11558B114F8D134C8A174B8816448115467A0E
4A6E074E60045051015143004B3700442B003F2600402800402900402900402A00412900
3F28003C25003C23003E25003B27003C21003D22003E21003A2200382200382000382100
371F00351C00331E00321C00301B002F1B002D1D002A19002C1B002D19002E19002A1B00
281700281700241300221100201000190E00160C001107000E06000B0300070100020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000FF0000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000301000401000601000804000B0700110800120B00180D001B13001A13001B1100
1C11001E1100201600221700261900261B002818002719002B1A002A1D002A1B002A1C00
2F1D00332300372A003C3100423F00444B004057043A670930710E30700C30720B317008
3C6B064065033F61023F5F003E5C003C62033A65053569053168052E6E07316F07346F07
316F07346D07386A06376908406B074B6605566502546D054A750944750B457B103C8219
2E8919308A13368C123893192F9B212B9F2A24A33222A53822A63A20A53524A52F23A42B
21A52E22A33026A32D28A12A29A0272FA02732A12632A22634A32531A42831A6292BA72B
24A62D26AB2F28AE3427AC3B23AB4422AB4A23AC4923AB4C26A94D29A84E2AA94E2BAC50
2BAF4E2DAF4E2DAD492CAC4E2EA75631A35C309E65319F65309763308C5F367E603B755F
406E613D6A633B74693E766841765F516B5A5C615B69556566536E576270516774595D79
66507B684780674485534B854155813D5D805361775D6075665674694C717A476A7A446B
814D69765C67716B5F73744F766C4A73624D67604B656146597140537F3A55872F568B27
578E2054931D52921A5293165691125690105290124E90194B8E1C48881A487F154C720D
516508525804554A01543C004C3300482900422600412400432600432900422A00422B00
402B004027004325004025003E25003F24004024003D25003C2100372300362300362200
362000332000301D00311F002F1B00301B002E1C002C1C002F1C00301C002E1B002E1A00
2918002616002417002112001E1100180D00160A001108000D05000A0300060200030000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0200000402000502000903000B0500100700130800120B00180C00190E00181000190F00
1A0E001D0F00211200261800271C002B1D002C1E002E1C002E21003123003220002E2000
3422003A2B003E3200434001434E03425D0639670A3171102A7B142F790F2F780D34750A
3A70073C6A063D66043F62023C5D003B6202396104396505356806326D0932700B357009
31720833700836700836710A3D720C4473094674074C7C0947810F407F113D8418378D24
279328289522259924249F3020A43620A83E1EAB461EAD4A1EAB4A1EAA441EA9391EA835
20A63524A63427A3302AA42A29A42A2EA42830A4262EA5272DA8292BA82B29AB2D24AA2E
20AC331EAF371EB03A1FAF3D21AB4323AB4425AC4028AB402CAA4031A93D35AC3E34AD40
33B04032AE4531AA4530AB4D2FA9552FA65A309F5D2DA1612D9B642C92622F8861337E63
377366396C6A3C6F7045727041716C4C6763555B64665668695870546573456B774A5F7C
58577D604E825946844B4F813F5B7E3B667C496678576073665673675275794D6B784C6D
7F536A72636A6D6F5E77754B726A495F5F4A576641597140547E39528936578B2B548E22
52921D4E961E4E96195093155092135091114E9014478F1A438F1D48861C487C154E6F0C
526007545403564800533F004F3500492E00482800432700442900452A00452C00422E00
462D00412B004027003E26003D26003E23003E25003F26003B27003D2300372100352100
341F00352100341D00341C00311B00301B00301F002E1C002F1900301B00301C002C1B00
2A17002715002314001F12001C1000190C00150A001109000D06000B0500060200060000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0201000401000502000804000D0600110700120A00160C00190E00190F001911001A0E00
1D0D001E0F002313002719002C1B00312100312300332200342600392700372600362600
382B003E3801424503455105416109376E0E307510287A13247E152B7D0F2D7D0D317B0C
357409346E093868073C66053964063865053C63073C6408396809356C0B35700D37720C
2F770D31760D35760D3877103A7B113D7A0E3F7E0E4688143E8B1F37881F378B24329233
259737229B30209F351CA5441AA9481AAB4B1CAE521AAF541BAF5219AE4719AB3D1CA837
1FA73824A93727A73427A83025A62D2AA72C28A82926AA2B24AB2D24AC3122AC331FAB33
1CA7391CAB3B20AD3D22AD3F24AB4125A84128A93B2BA9392DAB3935AA353AA9323CAA36
3AA73637A74032A54130A74C2FA85331A75235A55135A257339E5F2F9A5E329561308A61
337A67326B6C3469733968733B6B73496668535F67665A6B6F5C715664754268793C627F
44597E494E824948863C558134697D30717B3B6A784D617461587366577270556C6E596C
785B697068636E7553737E446D71425C6441556E40547B3C51853A548F3850942E529723
4F981F4D9B244D9A1E4D97184C95164B951747931944921F428D2047851C4E7412506309
525503534B014F4200503C004B3500483000472D00442B00482C00482D00442C00432D00
432D004129003E26003C25003E23003B23003C23003D27003A27003A26003A2500392100
392000332000341F00321D00321E00321F00342000301E002F1C002F1B002F1D002D1C00
2816002317002215001F13001D0F00160C00150B001008000D07000B0700080300050000
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0101000401000702000B04000F06000F0700140900170C001C11001E0F001D11001D1100
1C0D001F1100231600291800301D003021003326003425003428003629003B2D003B3100
3E3A0144480344540742620B3970102B7C192D7B16297D14247E12297C0C2B7E0A2E7D0A
31770A31720C336D0C396C0D36690E3A6A0E39680F38660E376A0D316C0E346F0F357410
307B132E7D15307D163180183583183782153585143C8C1D398F2C33902C308F322F8F40
2294481F9D4220A3451AA95417AC5419AE5617AF5713AD5714AD5415AB4A16AB411AA83C
1DA83C22A73823A63725A93523A83126AA2E23AA2A24AF2D23AE3125AE3724AE3A23AC3D
22AA4121AA4227AD452BAB452DA5442EA2442AA3402BA6402BA94034A9393AA7353FA631
3CA43236A53A32A2402FA4502DA6522FA85034A74D35A64E33A355319F59359B60318F66
2C7E692B696B2D656E325F733064763E657245646E4D676E506771486B714169733A617A
3D587C3F4F823D4E86335C87296F8125767D2F6B78416174585B6F5C5C71655D6A666068
6F62666F71596C854969893F667A395F7237577240507E424F88414F933C4C9A32509D27
4D9D214A9E24499D22489A1C49981945971D45941F4290224289214A7D1E506C10535B06
524E01534300533A004E34004D32004A3100472D00442E00452F00452D00442E00432F00
422D00412B003E2A003C29003D26003D27003E23003F22003B24003E24003D22003C2400
3A2000362000322000311E00331F00332000311F002E1D002F1C002D1A002E1C002A1A00
2A18002318002216001E13001C0D00170B00170B00110A000E08000C0700070500050000
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
00FF0000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
0300000702000A04000D07000D0700130800180A001A0F001D11002011002014001F1100
1F13002214002616002B1D002F1F00342000312700332700352B00372F003C3701404402
435104415F0B3B6B123774163379152B8015308114307F122E7F112D7F0D2C7F0A2B7E09
2D790B2D770E30741237721535701A36711B336F18346F143370122E73122F74132F7A16
2C811C2D821C31821C2C862031891F34891A36891C3B91253A9437319536308E3D2A864D
1F8A54209B4E20A5531BA86515AE6217AE5D16AD5E16AF5C1AAF5618AD4A18AC411AAC3D
1DAA3821A83721A63320AA3621AA3023AD2C24AF2723AF2B23AE3129AD362CAA3A2BA93D
28A84227AA462AAC4C2FA84B329E4931974C2E99492B9D4A2DA14D30A24536A33D3BA438
38A63537A83D31A54331A3512EA6542FA75430A85132A74D33A551349F59399A60328F67
2C7F68296C6928646C295F74296478356773386C6E37706C37756D38786B3F736B3D6474
40557C3B4D84334A882C538B246A86247580286E7B3A657650616D55616D5C61695C6766
636A61697E54678D4561893A5E8035597A395378444D8046498C414D97384A9C314EA025
4E9E204DA025489F26479E21489D20489B2247962448902149841E4F751759660B585303
594A00543D005338004C34004B32004A2E00462F00463000472C00452C00472D00432D00
422E00433000402E00442B00432700412A003E28003B26003A27003A24003B23003C2400
3C23003922003522003223003322003522003220002F1E002E19002E1A002B1A00291A00
2717002419002215001D11001D0E00180C00160A001409001006000D0600070400040000
000000000000000000010000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000020000050000
0701000C05000D0700140900170B00180B00190D001D10002011002113001F1600231300
2212002415002B17002C1E003220003723003627003A2A003A30003B3600434704415D09
3C690E3772152F7C1C2D801B2D81182B84182F82183084192F85192D83112A830B298209
2A7D0A2C7C0C32791134781631751E3175202F771C2E771A2F78182978182A7B15297F19
26851E2C891E2D8A222B8D272E9125308E23318D2538932E36933E30953E2D8C42267E53
1E865C20995624A65C1BAA7214AD6F18AD6816AE6615AE6619AD5A19AD4E16AD4419AD3F
1DAE391DAC351EAB331EAC3220AD2E22AE2923AF2626AD292BAC2B30A82F32A72E33A62F
30A5342DA93E2EAA4630A34B32974E318C51318B513291543096572E9B502D9D472CA146
2CA6422DA6482CA64C2EA3552CA1572DA35A2EA3572FA154319E5A339A63339564338B67
2D7F6827716A24686E236176276679316D762F77712B806A2785662F8663397F64406A72
43537C3A48812F448829478B245E87246E84276F7F316A7B4369724B6B6F546A67526F68
5774625D8350648B406084365A7A38597C3D537D454B8A424A94394A9D354CA12D4DA225
4E9F1F49A02747A02D46A02D47A029489D284D97264D8D1D4E7D1756700D606006614F01
5D4300563D00523C004D37004F31004C2E004C2F00472F00472C00482E00452E00453000
442E00442C00442D00442E00482D004229004127003F27003925003923003A25003A2400
3A2400382100352000332100311F00332300321F002F1D002E1B002C1A002A1900271500
2617002116002113002010001D0F001B0D00190B001409001108000E0600090400070000
030000030000030000020100010100010000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000200000500000803000E0400
0E0600120900140B00170E00190E001D0F001F1300201300221400211600231700201700
2315002411002818002D1C00341F003826003B2E00403400413F013E48033E5C0C366F18
2D7E1F2B832524872C2889252D851C2D84192D84192C861A2B88192A871228860D2A820B
2A800A2B7C0A307B0E347A14317A203179232E7C212A7A22287E2021802024801A23841C
218923278D2328902526952E2D952E31902E308D2F3991343592442F95452D8D48268059
1E885D209D5625A85C1AAB7414AB7817AC7217AD7116AE7117AF6319AF5617AE4818AF40
1BAE351FAD331EAD331EAD3020AF2C22AE2829AD252FAB2834A7293BA42A3FA2273EA129
3AA42A35A5312FA6392CA6402D9F462E994A31994C339B53329C5A2A9C5826985825985A
289C5728A05E24A05D299C60299C602C9C5F329B5F319A633097692D976D2B95692D8C6B
2B856C27796C2371701F6975216E79297874288770248E662092642690623387653B7272
42567D3C4285323C88283B8A244E8A26648A276F88326C7E4072744977704D766A4E7766
527D5C5D8C486593386385335E75395A783D537D3E4E8A3A4A973449A02E4CA22A4C9F25
4B9F2347A02B46A13144A130469E2C459B274A942350871B55760E5967045F59015E4B00
5D4100543C005437004F35005033004D34004A3200483000462C00452E00443000462F00
443000432C00422D00442B00432A004228004027003D25003E26003D24003B24003A2500
362300312100322100332000312000322100301F00311D00321E002E1C002B1A00281A00
2817002414002114002212001D10001F0E001B0C00170A001408001007000B0500080200
060300060300050200050200050100040100030000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF0000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000200000401000903000A0700100800
120B00140900170D001810001810001C11001E1200201300221500231700271500261600
231300251700291A002D1C003624003B2B004132004644024251073A5F0F38711B2F802B
288A322A8A2F298C2E298B282B871F2A851B2D85182988172989162B87112A870F29830B
2B7E0B2E7B0B327C0D357E1530801F2F81242B82242781262483221F862321851E238923
218D2B24922A26972C239A33279B352D95352F92363394383490472D944B2B8C50267E5E
1F885E239F5626A95E1AAA7612AC7D18AE7616AC7814AC7614AE6915AE5917B04E1CAF40
1EAF3720AD3422AC3323AC3121AC2C24AD2828AD262EAC2733A8283DA52741A126439E26
459D293D9E2E31A5342CA63D2DA4412FA5482FA54C30A4512DA25E299B62229367258D6B
258D6D258C6E238F6C278E6D28916D25936E25957226967525957926957B299277288B77
268576247D752178751C75761D7D761F89742097721F9A691E99652391632B866B39717A
3E5A8539498B2E4889264A862455842B61852D6985326C813879793C826E4680634D8161
558A5163954163983561863658763F557A40518241508E3C4D9B3649A33148A12E499F2C
49A02D46A22E45A43145A52F449E2E4499274893204F7E15566C075A5E015F53005B4300
563E005238005137005137005235005034004E35004C34004B33004A2E00462F00462D00
432F00442C00442E00452C00442D00422A004026003E26003B27003C27003B26003A2600
362200352300322100322200302100341F00341D00341D00331D00301E00301C002C1A00
281900271700241300221200200E001E0F001D0E001B0C001709001408000E05000A0400
090400080400080300080300070300060200050200020100020100020000020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000401000802000C0600110800160C00
170D00170D00181000190F00190E001A0F001B0E001E0C001E1100231200261300281800
2717002618002918002E1D003426003F3000433D004854083C66143174222F7F2C268939
238F3D278F38268E38278D2F298C26298B202A8A1C2B89182A89132C8A112C8A0F2D8610
31810F307C0F337D113480162F831B2F821F28831E24861F238721208925228B24228D29
219131239532239A34209D3D239D3F24983E29963D2E973E2D944A2C964E2B8C52277B61
23866226A1572AAA5E1CA97711AB7F18AB7A15AB7C10AC7C12AB6E12AE6018AF521DAF42
21AE3A25AA3526A92F25A92C26AB2826AB242AAE262EAC2730A82937A6283AA0283E9D2A
3F9A2B3F9B2D35A03130A23A2FA6402DAA482BA94E27A85726A363239969248973247F7B
217C7D20777D207D78247F7724857A21897C1F8F7E1F937F20967F23988124937F248D7E
238A7D21817C1D807E1B807C1B8A751B94731BA0741CA26F1C9C67209367288370346D7B
3A5A8A3753912D578A255A84255C802A5F81306581316C7F317C7735876A4285614B8956
599449659C39629436607D3956703C517E39528C394F98374CA23848A43748A0364A9B37
49A03748A23445A53245A332429D2E4496244D891A55750B5A65035C55005C4B00563E00
5036004D34004D36004C34004D35004D38004A33004A31004A3000492F00472F00473000
463300463000472F00462E00452D00432B00422A004128003F2A003C28003D29003D2800
392400362500351F00351F00322000331E00341E003321003822003423003221002F1D00
2B1B002A15002715002315002211002110001F0F001D0C001A0C00140B001007000C0400
0905000A0500090400090400070300060300070200070200070100040100030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000200000601000C0500110900170B00190D00
1910001B10001D0F001F0F001D10001A0E001C0E001F13002014002013002416002A1800
2819002819002A1C00301F003729003F3600444801445F0D3673232982352887341F8D39
259038278F371F8F39208F32228F2A229029258E20298B172C89122C8A132A8C142C8A15
2F86153281153181163082152D85172E84182785162088171F8B1F218F2925922C229332
20953E22983D219C411D9C491D9D4820994722994824994626964D289851278A56237663
24856627A05928AB601BAB7812AB8018A87E16A8810CAC800EA97611AB6416AF551FB146
22AD4026AB3728A92E2AA9272AA9242CAA262DAC292EA92C2EA72E32A230339D2F359C2D
369B2C389B2D359D32359F3732A6402DAA4628A85122A45F22986A1F8C72217A7B206F81
1F67811D60801D677D216F801F78871B7F871A86861C8E831F958221998122997D24947B
23907C2089801E867F1C877D1A8F77179A761AA47919A6731E9E6A208D6B297271315F7C
3253863354872C608429647F2960812B60832D66822C70812D7D7532856840875F479153
599A4767983869863560723B5571394F81344E92314E9D364BA23A49A53C45A040439C43
489F4045A53D43A63643A236429C2F498F21507F0F5767045D5801604C00564400533B00
4E35004B30004932004C31004A32004B31004B32004B35004D3400493100473000473200
4A33004A3000473000462E00432C00412D004329003F28003C26003D27003C27003B2700
3E28003B2700392300372100341F00371F00352000361F00352300362100362200331D00
3020002E1E002D1A00271A002417002514002213002010001E1000190E00140900100600
0C05000C06000A06000A0400090400080300080300080400070400060300060100030000
020000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000100000201000502000B0400120A00150C00180D001B0D00
1B10001E11001F11001F11001F12002012001F1300211500221400231500261800291A00
2E1D002B1C002E1E003121003E2C00403E013E52033C69142C7B2923863928892E248B2B
258E2C248E321E8F391F903222902B229227278E1E2B8A152B89102C8A1429901828901A
2F8B17318516328316318214338214308315278513208914218E211E94301E96361E973C
209944209A441F9B481D9A4F1D98521D96521F9754229A51229851219751258A57267564
24876429A35A29AC5C1BAD7213AB7B16A87D11A6800FAA7E0EAC7510AF6419B0561FB24C
22AE4525AB3A27A82F2AA7272CA8282EA82A2FA92E34A53233A135319F372F9D36319D32
339F2D35A03037A03134A23632A63F2DAB4728A65421A1662095751E8A7822787E1F6B85
1D5F85185782175C801A65821B6D851B7088207887218386238D85219980229D79259F76
219E772099781E947B1E917B1B967D199D7C1BA1811B9F7C21927323816C2D66722E5A7C
2E54812B5A812A647D27687D2C67802E6A822D6F842C75812C7C7533836D378563439354
589B426697316587305C7B35567D31538C2F4F96334E9A374A9E3848A23C44A13C41A040
41A14045A43D45A34041A13848972E4E861C5670065D5C015F4E005D4500573E00533A00
5135004D31004F31004B32004C31004F31004D33004D34004B3100492E00482F00482F00
4A3200493000472E00432B00432A004129004129003F28003F2A00402900412900412A00
422C004029003D25003C22003B2100392000361F00372200372400382300382300342200
3221002E1E002C1D002A1B002817002613002214002213002011001A0E00170C000F0900
0D06000D06000D06000C06000B06000B05000B05000A06000A0600090600060500070100
060200030200030000020000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF0000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000301000400000701000B02000D0600120A00150A00170A00170D00
1A11001F11001B0F001F1100201200241600271800271A00281900281A002A1B002B1B00
2C1D002D1C00352000392600413300414603375C06366E142B7D262587332A8825268921
238B22248D271F8F2F228F2A228F24208F20278D172B89122A880D298D1228911727911B
2E8B173186163484183583183A7F193084192C8615238B182090221E96341C99401A9846
1C984C1C984D1C9A4F1B9A581D9B5C1D9A5E1D9B5E219D58229954219553228A59257865
25886329A4582AAB581CAC6D13A87A15A57D12A5810FA87E12AC7413B0631AB2531FB045
24AE3E2CAC322EAB2A32AA2535A92438A8273BA72B3DA22C3C9F2E379F2F379E30379F2C
34A12B37A12F37A33234A6372DA84028AB4D24A65B22A06B22967420897A2179811E6A88
1B5B86175083145880176380186A821D6C85207183277C8027878025947C279F7024A46C
1EA66E1EA2731C9E781E967C1E97801C98851F96861F8F80287B752C6C7038587A32567E
285C7F22687E24727926767A2D717B2E737D3074802F787E2D7C7A328173368567419554
589E3A64972D5F8D33588A38558B365590355197374D9A3A489D33459F31429F33419E35
43A13645A23444A03347992D4E8B1F5B76106263046051005F46005C4000583C00553B00
5238004E36004F37004E33004C35004C34004C33004B3300482E00472E00462E00472F00
463000473000453000432E00422B003E2C003F28004029003F2D00422D00432E00433000
432E00412D004027003F26003D24003923003C23003A2300372400382300362100342300
331F002F1E002C1900281A002917002715002415002112001D0F00180D00140C00120A00
0F09000F08000F08001008000F08000F07000D07000D07000E07000C07000A0500080400
070400070300060100040100030000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000300000302000501000901000D05000F0800140A00160B00170D00170B00
190E001C0F001C0F00210E00211300281700281800281800291800291B002B1D002C1C00
2E1F00331F00382600412D00433E004050033064083070102B7F1D2789252C881C28891A
248A1C248C1E1F8E24238E23258E1E268D192A8D132A8A0F2B8C0E2A8F102A921727921B
2F8F17308B1933891B38871D3786213389202F8B1A248E192292222095301C983C199842
1B994D1D9A4D209B511D9E5A1E9F5F1FA0641DA2631FA15C1F9C551E994E1E9057227E66
218D622BA5552EAC5720A96B15A77A13A07D14A08213A57F14A97216AD5C1BAF4720B038
29AF2E31AE2636AA2038A91F3AA91F3FA72043A62244A323429F23409F243F9E263CA028
3AA12A35A32F32A8342BA93F26AA4823A95522A66121A16A229872228B78207A7F1D6885
1E57872049871B53831A627E196C80206F7F25767D2B807C2C8A782A967229A16724A869
1EA86B1CA36F1A9C751D937E1C93821C8F8422838128767C316476385C7544587A38647D
2B707E227E7D258676258576277D782B797B31747D31737B337479337C76368668469952
5E9D38658F325C8640568942528D4051933D509B3E4D9C394B9C2E479B27479B27479B27
459F2B479E2B4998264F8B1D577A13636708665701634B006144005C3F00593C00593D00
553A005338005335005133004D33004C3100483200472F00462E00462D00452800442A00
442D00462F00463100432F00422E00412B00432900412A00422D00432E00453000443100
462F00432F00422B004029003D28003E27003B28003A27003B2500392200352300342100
341D002F1F002E1A002B1A002817002617002415002013001C0D001A0B00150A00110A00
100900110900120A00110A00110A001009001009001008000F08000F07000C07000B0600
0B05000A0500080300060300050000020000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000401000603000703000904000E0700110800130900180A00190E00190F00
1D10001C11001E0F002111002413002917002818002B1800281C00291E002B1D00302000
321F003525003E28004635004649013D5B052D6C0A2A750D2B7F142989182E8B162B8D18
268F19288D1A268C1C278C1B2A8C182B8C162E8C112F8D10308F0F2F8F0F2E93122D9216
2E901A2D8F1E2E8F20328F1F328E2033901F30921D29941F25942120962A1E99311C993C
1C9B471F9C491F9F4B1FA2571FA6611DA76A1FA76C20A462229C571D9E4E1D98561F8666
2594642FA55432AB5422A76E16A27E179C82169D8615A38017A67218AC5919AE4021B12D
2AB12335AF1D39AE1A3AAB1C3CAB1D3EA91E41A81E46A52148A021489D20439D253B9E2A
32A12E2FA5332CAA3B28AB4824AA5325A65D24A264239C6B2191701F84761F757C1F6781
2457802A487F26517D245F7C246B7E27757A2A82752E8C712E946A2C9B612BA35B27A760
23A8671E9F721A947B1A88801B84841B7C831F747C28667730597832667934757B2C8478
268F7A239878259A79269475268479287A76327075366B763867793976763E89644D9E49
6498376685375E7B41577F47528345528C4052973E4F9C384E982C4C98224895214B9621
4697244D9620528C195A8011636E08685D036451006047005D3D005B3F00583E00583C00
563A005537005435005131005133004E33004B3100482F00402B00412900462A00452C00
472E004C32004A3400483500473500452E00432E00452E00452F00472E004832004A3200
473000412D00412E00432F00432D00402D003E2B003B26003A24003B2400382200342100
341E00321C002F1A002C19002917002716002415002013001C0F00190A00160A00130A00
110A00110B00130B00130B00120B00120B00130B00120A00110A00120A001008000E0800
0B08000A06000A0400070300060200050000020000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0101000502000803000903000A05000F0600100800140A00160C001B0C001B0B001C0F00
1D12002014001E13002112002715002A1C002919002A16002C1A002E1F00312100322200
3525003C2700403000463F004652023965072A720D2B770D2C80112C8912318C142A9018
28911A2C8F18298F17298B182B8B172E8A16328B10348B0D368E0C37920E3292132E9319
2D932028942B26942B2994252995242E97212E9A22289A25279A24259A25219A2C219C37
1F9D40209D4526A14C21A6591FA8601EA8681FA66E21A4621F9F581CA44E1CA053219661
279C5D32A84E35AB5022A96917A27B189B7F15998314A07F16A27115A65B19AB421EAD30
2AAE2633AD1D39AE1C3CAD1E3CAC1F3BAB223BAD2740AA2544A62640A52738A12C30A030
28A33824A64025A74926A85226A65E28A364259969258D6D2181731F76781D6A7D20657B
2A5D7A3055763058752F5E732F6A77307A712E8D71309567319A5F309C562DA2532CA658
27A664219D6F1D907D1E83821D7D821F727D226A772B5C763258772F75772A917826A073
25A77323AB7327A7722B9B752C8A782D817435756F3B6B6D3E617140736B468F5D56A345
6898346682355B7740577B465280465289435195404F993A4D98314C95264B93224E9121
508E1D548715617C0E6773076A6202675301644A005C43005A41005941005B3D00593D00
5539005437005232005031004E34004C3600493000472F00462C00442C00482D00472D00
4D2E004D33004D37004E3700473500453100442F00432F00482E004A2F004A31004C3000
492E00492E00452E00432B00422D00402C004027003B29003A24003A22003B2300382200
341F00331C002E19002A18002A17002615002214002113001B1000180B00140A00130A00
120B00110B00130A00130A00140A00150B00150B00150B00150B00140A00110A000F0800
0D08000C08000B06000B0400080300060200050000010000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020000030100
0702000804000C05000D07000E0700110700130A00150C001A10001C0E001F0F001E1400
2017002216002516002715002819002C1C002A17002D1A002E1B00302200332600392700
3A2800402D00453800484800465C03396C0B267A142D7E133082112F8A11318E132E9019
2A90172E8D132E8D10308C12308B102F8C11348C0C388E0A368E0B378F1230921C279526
25952C2195351E98371F99311D992D259D2B2BA12B2BA02A299C26279D27229D2B209D35
21A04122A24724A54E25AA5B21A96220A86520A26A23A15F23A0561FA54920A64B27A055
2AA34F33AA4232AE471EA96015A17418967E19948214997D159A70169E5D18A44A1EA73E
27A9352EAC2E34AD2A36AD2A36AD2D33AD2E31AC3336AC3238AB3333A6372CA03C279B43
239B4520A04D20A15521A35E21A56423A166208F6C217B72216B7622667822647B286977
2E6C70316E6E33696D3566683571683180692E91692E966030985E32995530A0512FA754
29A662259F6C23927821858023808022797926776F2E716A3277672E8F6E2BA57329AC71
28B17028B16D2BAB6F309D70328D74358470387B6A3D6E68406B66457E63509A5461A53C
6B962A63862C587F3656833B4E88404E8F414C98404C9B3D4A993349962E4D8F2551891C
5881135E78076871036C62016B56006550006147005A42005842005A3F005C3E00563B00
5337004F35004D32004E33005035004D36004B31004B2D00482E00492E004731004D3600
5034004E3A004E3A004E3A004C3700473300483100442F00432E004A30004A2F004A3000
4A2E00492C00462C00452A004329004229004027004026003E26003D2700392500392200
331F00321E002D1B002A18002718002616002417001F12001C0F00180C00140C00130C00
130C00140A00150C00160C00160D00160C00160C00160C00160C00160B00140B00110A00
100A000F09000E08000D06000A0600070300070200050000020000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000FF0000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000030000050200
0904000E0600100700120700120B00140A00160B001C0E00211200221300221100241400
2615002614002316002714002619002B1C002A1A002D1C002D1F003324003723003B2800
3F2E004436004843004450003F630634751127821F2E831B3289172D8E163190172C911A
2E8E15328F10338F0C338D0B348F0B2F8F0C338F0C348E0C308F0F2B911C27952E20983C
1F98401A99431A9B441A9C411B9E401E9F3D21A23926A2352AA22D28A12E239F3222A13A
21A24320A54A22A5521FA75E20A6651EA2641F9C69229B60229E5422A84322AA412BA748
2DA74034AA3530AD3A1BAA4F17A0661C90771C8D811A907F168D73159265169C541EA34A
27A7412EAA3734AD3135AE2F34AC2E35AD2C31AC3033AD3631AC3E2EA842279F4824954E
20984F219A56229B60219C65219E6921986920876D227372206773246971296B7129766C
2D8269308969338164377C60348260338C5C2D975B2D975C30955B349757319F562EA55D
2AA56728A36A279A6F288F72298C732A88722C8C68328F5E35975D34A26534AB6D32AC71
30AE7030AE6E2FA86732986B358D6C3B836B3E7B683F736441796148905755A2446AA02E
7092226580225D83265589324F903A4D9840499A40439B4046983D47952E4B8A205A8016
6271096A6801696100675600664E00634A006044005C41005844005B44005B4100573700
5138004F32004F33005133005036004F32004C2D00492D00482B004C2F004F31004F3900
533B00513A00513B00523A004F36004C3300483000482F00472D004A2D00482E00492F00
4C3200472C00472D00452D00442B004629004027004327003D27003D25003C28003A2500
381F00331F00311A002D19002A1A002719002416002114001C1100170D00150E00160E00
160D00150E00170D00160D00170E00150D00150C00150B00150B00150C00160C00160D00
140C00110A001009001009000F06000B0500090400060100020000020000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010100040100080200
0E0500100700140800120900140A00150B001C0F00201000201500231500251800251800
271B00291A00291900281900261C00291C002B1A002E1B00321D003922003B2200402900
413200463C00494A014058023A6A0C307B172689272E8B25308E222D951F2F941C2E9118
2F8F11338F0D308E0A328F0A30900C2D910D2E900F2B91142693192596262399351F9B41
1E9B401D9B3F1A9B40199E4118A0431CA1411DA33C1FA43D24A53623A43321A43720A640
1DA6491AA64E1CA6541FA56122A3651F9E6421946A249461279A4F25A73A2BAA372EAA40
31A93434AB2A2EAC301CAA47179D5E2189721E83841A8683168478168B69189A5920A34C
27A9402BAC372FAD2F31AD2C32AC2633AA2432A92A30AB352DAD422CA94B249F52229457
21945924955C26966625966B25966A218F6C22806E237071236F7026736C257867288564
2F955F30995E33965B3592582F95562D9A552C9C522E9A502F994F319C5230A25A2EA464
2BA46B2AA36B29A3672A9C6A2C966D30926C33996132A25B35A85F34AA6633A86D33A275
32A47433A571329E6C31886A33826A3B797040776D407C6342915C4EA14965A12D779016
787C0E717411647B135B841C528F284F9738459B40469A4245963B49902B51861C5F770E
6A69056B5D006C5500674E00654C006447006143005C42005A44005B4100574000563A00
5139004C39005236005336005337004E34004B31004B2B004C2E004E3100503400523B00
563B00543C00533C00533D00543800503600493200483000472F004A2E004933004D3000
4D3200473100462D00442E00452C00432900412B00442700412A003D26003C26003A2300
372100351E00331C002F1B002B1A002718002415001E14001D1000190F00180E00180D00
180D00190E001A0E001A0E00190E00170C00170C00170C00170C00170D00170D00160B00
140C00150B001309001209000F09000D06000B0600090400060200020000010000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000100000200000401000A01000D0400
110500140A00160D00160B00160B00190A001B1000201000251400271600281600281A00
2B19002B1A00281B00261C00251900271B00261A002E1B00301E003A25003A2800403000
4336004542004750023C600536710E2C821D248E2C2A90292C942A2B97262E961C2D9216
308E11338E0F2F900C2D930C2B930E26940F26931623931C1F942420962B229A33229B39
219B36209D341E9D361E9F3A1B9F401CA14019A33B1AA63B1CA7381EA83A20A83D1EA848
1DA6551BA6581DA35D1DA364209E692195691F8770218A6526975026A5372BA92E2EAA35
2FAB2C34AC262FAD2E1EA9421B9A5824826F227B851D7E8818827D178D711B9C5D20A94C
24AC3A2AAD2E2DAE2531AE2035AA1D35AA1D34AB2231AC322CB04327AA4E239E5823935D
23925E269162278D67288C6A278B6827836A267A6F296F7428766F297F69258A6329955E
309F5733A65236A54E36A54D31A54B2DA64B2CA6472FA44430A34331A5482FA75530A166
309D712FA06D2EA6662DA567309F66329C6134A25C35A96136A76531A06B2F9A722F9574
339676359777349370348670357F6A3F776A437B6A438E6547A44E58A7307098127A7E09
796E04766B05706F09617C11568A1C528F2C4A973B4A963C4C91355087245C7A166A6B09
6E5F016B55006A4E006849006248006243006142005D43005C43005C4200594000563C00
4F3C005037005438005137005239005137005034004F3300503400523400523800523A00
513B00543E00523B00533C00533A005339004E34004B34004B30004732004B31004D3100
493100482D00442D00452E00462D00432E00422B00452A00412A003F25003D25003A2500
392300361F003320002E1A002B18002415002217002111001F10001811001910001B1000
1C10001B0F001E10001D10001D0F001C0F001B0E001B0E001B0E001B0E00190D00170C00
160E00170D00160B00140900110900100A000F07000B0600090300050100020000010000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000101000502000A03000C05000F0A00
130B00170D001711001B10001A0F001B10001D0F00211100211500231600241700281800
2A19002B19002A1900281900241900291A002B19002C1B00331E003C2600412D00453600
443C004745004557023B6707347A112A872122923229952F27983328982D2A961E2C9115
2F8D11328E0D2D920B2E930D2B930F27961325951F23942A1E9534209634229933239834
249930219D2E229D2D209E331F9F391CA2391AA1381AA2381BA73B1BAB401DA8441BA94E
1BA7581DA65A1DA35D1EA06721986C218B6F1E747620796A24915125A7372AA92D30AA2D
2FAA2835AD282FAD311FAA441D9659247C6F2274871C7C8719837B19916E1CA0591FAD47
23AF372AB02C30B12232B01F34AD1D36AC1D31AD232FAD3529AF4E23A85A22985E208B64
218C63258A6527876828836A28806726786B2A736F2C6B722D79702A886B27976728A05C
30A65433A94C35AB4636AB4132AC412FAD402FAC4030AC3C2DAA3C2EAB4530A85430A363
2B9C6B30A06B32A5672FA96532A55E32A15C36A0633A9C6A37956D358F752D8B772F8975
358C753A90743B926F378E6A3E8A65458462488F614CA35556A839659F1B718907767301
7867007561006F69026771075D80145A8B2252912F4F8E2D528827597E19676F0C6C6204
6F5801695100674B00604C006046005F41005A45005D42005E44005B41005A3E00573B00
553B00523C00533500573900583A00563D00533A00533600513600503600533900513900
513600533C00543C00563A00543A00543A004D36004E32004B31004C31004D2E004A2D00
4B3000483000473000462E00452F00452E00452D00462E00422C004429003F2800392700
372300382100301F002D1B002C19002517002213002112001E11001D12001D11001F1100
1D10001F11001D11001D0F001D0F001C10001D11001E11001E10001C0F001A0E00180D00
170C00180C00150C00150A00120A00100A001009000E07000A0600070300050000020000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000200000501000803000E0400110B00140B00
190E001D0F001D0F001E1400201300201200201300200F00211000221300261600261800
2814002A17002D1B002917002816002613002817002D1C00331F003D2B00423300453C00
483F00494B01475D0637710C318019288E2B22973B269836269835279A2E2C961F2E9218
318D13358E0E338F0A2F910E2E93122795192496272296381D96461E98401E993E1F9A3B
239A35249C30219D31219E351DA03F1DA2401CA13E1CA13D1EA4401CA8441DA94C1AA755
19A55E1DA65D1DA3611E9C691E906F2480711F647A226C6A268C5022A43A28A7332DAA2F
2EAC2835AD2B32AF331FA9441C945A247772226B881B798618867817956B1BA4581FAD44
25B03528B02D2FB02731AF2334AD2132AD222EAE2E2AAE4226AF5A22A56624936823846C
25836A27836928816B277A6E27716F256D6E296F6F2B6B732B7E6E2D906928A1652CA65C
2FA95634AA4F32AC4832AD4132AD3E31AD382EAB382FAC3C2EAB402EAB4A2DA8542FA561
30A46634A66536A76138A75D35A15B359C5C3A97663D8D6F38867538857A348777338B73
3A8E6B3E9268419A69419B674895604C98584DA35155A64063A0236C940B727E01736D00
756400716100706400696B0163770F5A801B598625568321597D1C6672106D65056C5901
6B5000654C006449006346006142005940005641005841005A3F005A42005B3F00583D00
583E00553E00543900593B005B3F00583F00583F00543D00513600513800533500513800
563800553B00583D00573D005B3D00593C005139005238004D37004E36004B31004C3000
4C33004B34004935004932004933004934004A3100482E00452D00412B003F28003B2700
392300382200341D003019002B1800291800251600231600221500221500211600231500
2316002016002013001F12001F10001D0F001D10001E12001C10001C11001B11001A0F00
1A0D001B0D001A0D00180D00150C00130A001009000F09000C0700090400070100040000
020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF0000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000030000050000070200090500110500160B00180E00
1D0F001E12001F1300201500211600221400211300201100201100221600271600271700
2816002A19002F1B002D1A002A16002714002918002F1C003723003F2E00443900484500
48490049560342690B347D182E8A27279536249A44289B39259C32249A2A2A981F2B951A
309015328E10338D0D31910F2D921329921A24962C21993D1D9B4E1C9C4A1C9E4A1D9F47
219E42219F3D219E3D1F9F411E9F4D1EA04C1D9F451FA04621A34520A64A1CA6531AA558
1AA66119A6611B9F631B926B1D8470247571255C7928676630894A28A23B28A53D2DA834
2CAD2D36AE2F31B13A1DAB4B19925D1E7276216188187783168977179C691CA6521FAD41
23AF3728AF2F2CAE2E2FAF292DAE292DAE2B27AD3726AE4D25AE6225A56B23916E257D6E
267C6D267D6E257C7026737426697625677426726E257A6B298A662F94622EA15F2CA65D
2EAA5931AB5531AC5031AD4631AD4032AB3933AA3C31AA4132AB4930AA5330A85831A560
34A7603AA75B3AA8573BA654379E5B3795613B8A693B7D713A79733B7E783B86723B8D6D
438F64459560489C674A9C624F97564F9F4F58A64061A12A6A9414708306737700736900
706100705D006E5D00666401646C095C77155D79195B76176373116C68086F5B016C5800
6B52006A4D006648006343005E3F00583C00563F005640005942005A42005D4100593E00
594000593F00573E005941005D41005B4200553E00533C00513800523700523800523700
5639005539005C3B00593D00573E00583C00553C005438005139005236004F37004E3400
4F36005336005236005134004E34004B35004A3100482E00452B004028003E2500382200
372100352000351D00301A002B18002A1800281400291500231600241800271800271800
2519002316002215001F14001E12001E12001E12001E14001C11001D11001D11001C0F00
1C0D001D0E001B0E001A0E00160D00130C001208001109000E09000B0400090100060000
060000030000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF0000FF0000FF0000000000FF0000FF0000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000401000602000A03000F0500130800190C001D0D00
2012002012002014001E15002317002616002515002213002213002815002818002C1800
2B1B002F1C00321E003321002C1F002D1C002E19003120003B2500412F00473D00484600
485000455E05407313308624299230269942229D49299D38259A292798202C971B2B9519
2F93163292142F91112E92102A94122994182498261F9C381C9F481DA0461FA1461FA244
24A140259F40279F44259D4A209A51239C4E289F472CA2432BA64226A74422A64B1CA456
19A36317A36616996518876D1B7570226A6F2956773566633D8A432FA03728A0412AA73F
2BAE3737B03732AF411DAA52188F661B717C1E5E871A7782188E741BA26620A95323AD40
27AE3527AF3229AE3128AE3129AA3229A83925A94728A9562AA967289F6E258A6E25756F
237271227273217277236E7B29677B296C76287C6B278B6629945E2E955D2A9D5B29A35C
2AAB592DAC5430AE4E2EAF4731AE4034AE4033AB4133AB4632A95133A65A33A65F32A162
32A35E38A35637A2523A9C563A91603B86683B7B6C38736E38736F3B8072408C6E479364
4C975750975954985C539557559251589A475E9D3265951A71870A767C02746F00726500
6E6000705D006D5D006B6100686504656A0A616C0B6467096A61076D5E036D55006D5100
6B5000674E00644A005D45005A3F00583C00583E005B3E005C42005E44005B41005B4100
5942005A41005742005A42005D41005C3F005A3B00553C00533A00513700503400513500
533900553B00593B00583B00593B00563A00513800513600533500533700543900523600
503700523A00533A004F37005033005031004D3000452E00442E00412C003F28003C2400
392400352000351E00331D002D1B002B1A00291700281600261800271900271A00261C00
2919002719002417002216002114002114002214002214002114002215001F12001F1100
1D0E001D0F001E0F001D0F001B0F00160D00130B00120A001009000D0700090300080100
060000030000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010100010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010100030100050200060300050300040100010000
0000000000000100000200000302000502000C0400120700190C001E0F00221000231500
2317002416002515002517002817002818002B16002915002616002C16002D1D002C1D00
2F1D00311F00301E00312100301F00311F003123003827003B2E003F33004941004D5303
4463073C761333882C239446259A4A20A04B20A34828A130289B1D2D951132930E35930E
3392103294133196162F9817299A19239C1D239D1F229F2323A126259F29269E2B29A02F
2B9E342A9D3D2A9C3E2E9D3C2D9D38319E3534A23231A7322CA73128A93420A74020A54F
1BA163169D711B8F6D1B746E2361742C6273335F75427459478C35349E33279F4829A447
28A84A37AA4832A9531BA46815907B1878861A67891B8079209B6124AE4D2BB03E2FAF30
31AE2C2BAF322BAE3B2BAA462E9B52337F603B706D446B735268794A66783A62752A5C76
2359781F5C7A1E607C217977258C722C9B6438A45639A84E33A85130A34F2AA54B2AAA4A
2BAD472FAF412FB13F32B13F34B13B34AD3A36AC4034AD4A32A95630A76131A65F34A15D
3498573890573B895B4381654275703A6C7639746F3981683D90624C9B5F56A0555C9B49
6498446B8C4C5F834F587C4E5B774362852F698E1E70890F777F09757100766800746000
6E59006C58006B5A006C5D00695D00685900625500665000694F006A4C00694B00674900
6748006448005D4300583E00583F00563B00553A00553C00553C00553C00583C00553D00
583D005A3F005A41005B44005D43005C44005B41005B3F00593D00563800533800513700
503800533900573D00573C005A3E00573F00573D00563B00543A00553900543800523A00
5037004E38005039004D37004D36004C35004D35004831004B2F00472D00432C00412B00
3D2700382500352000351F00321F002D1B00271800271600271800291A002B1B002D1C00
2D1D002B1C00281B00261B00251900251700241600221500221600221400211300201200
2012002011001F12001D1200190F00190D00170D00160B001309001208000E06000D0500
0B0400060300030000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000100000200000401000805000905000A0800080700070300030100
0200000100000100000401000402000704000F0700160C001B0F001E1100221100241400
2317002214002317002715002A18002917002918002B19002C1C002B1F002F1F00311E00
321B002F1A002F1D00341C003120003424003A26003A29003F30004538004E46014F5D09
4272133A82252E8E421F955F1F9A561FA14B1DA44323A22E269D1C2D971331950F34950D
33941135971632971C309A1D2C9D2024A024249F2323A22322A22527A12728A0292AA12F
2C9E34299C3F289E3F309F3731A03135A12B33A32B2FA8302DA83425A73C21A74520A455
1DA26218A06B218B6A286A712D58782F6476306F77417E55498D32399B332A9D4728A547
2CA74F3BA95136A65D1EA67017937D197A841C68891E8174239F592BB04230B03734B230
34AC2D2FAC352BAD412CA651308F5A35726540616D4C5F715A5A74505F6F40646C2D676A
296A69296C682773692A8C642B9F6130AA5637AC5036AD4C2EAC4E2CAB492AAD422DAD41
2EB03E34B03C32B23D33B03F33AF3D34AC3C38AC4037AE5032AF572FAC5D30AA5733A052
3693503E8557457B5E4774673E686E3965713A7E663E925E4C9D5657A0505D9B48609447
678A496D80535D77535775495A77396382246B8A1970820B787906786F00756900716100
6D59006C54006A5300675400695400665000645000655000665100684D00684C00644800
6647006348006144005D3F005A3C005A3A00553600533B00563B00573C00563B00573D00
583E00593E005A40005C42005F42005A4100594100563F00533C00523D00533900533800
543800593B005940005C40005D40005A42005941005B3F00573E00543900523B00523C00
503B005038004E37004F36004E36005237004F35004D34004A3300483000412F00402B00
3D2500382400342100361F00351F00301C002D1A00291B002A1C002A1B002E1E002C1F00
2C1C002B1C00271B00271C00281A00271800261400261500241500231600231500231400
2114002113002012002012001D10001B0F00190E00180C00160A001309000F08000F0700
0D06000B0400060200030000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000200000202000302000602000905000C08000D0B000D0B000D0A00090600060300
0401000200000101000501000804000E0600130B001A0E001E10001F1300211300211300
231500241500271600291800291800291700281A002C1B002E1D00322300382400352500
332000331F00331C00361E003722003A25003D2900402E004636004A3E00554E0253690F
428223368E3D2B93561F976D209D5C1CA24A1AA53C21A32C269E1D2A99162D9A142E9B12
309D16349D1C339E21349F262FA12828A12C25A22923A32824A32728A22929A22D2BA22F
2CA1322BA03C2EA13C32A23132A12A35A32733A52A2FA8322CA83B27A545249F5323A15C
1FA4631CA365298B6733686F385B73356C72317C7243864E518D2E3B9C352CA0422BA443
30A65040A5533AA55F1DA97218967C1D7980226184247D6F289B572EAE4733AF3E35AE38
33AA372DA8402CA64C2B9B562C8B5A2F79613572653D71684471673F796236815B2F8755
2D8C4D2D91492E974A32A14B35A74F35A94D36AA4F2FA95327A95328AA4D2BAB462FAC40
33B03C34B13D32B14131B0462FAD4732AD4734AF4D30AF5B2BB0602BAE612EA95534984C
39884D447C554C775D47756442706140795A468B554E9C545A9C4F5F97495D8B49637E4E
6876536A70585E71515D76425E7C356282206C8411727F0B767405766A00736400725C00
6F56006C5300685100675200634C00624B00614B00654D00684F00694F00694E00674A00
654900664A006447006144005F3F005B3E00573D00583800583A00533B00573D00543E00
593E00573C005A40005E43005E45005B4300574200534200523D00523A00533A00573800
553A005C3C005D3F005C3E005A41005B42005E41005C4000593D00543B00533B00523800
5138004F3A004F35004D31004D34005036005035004C34004C3200462D00452C003F2700
3B26003B2300372000362100342000321F00311B002A1B002B1D002D1B002A1B002B1F00
2A1B002A1A00271D00291C00281B00281800261600261500241500261600251600251500
2413002213001F12001F12001D10001D0E00191000170C00160B00130B000F09000F0700
0E07000D0400080300050200
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000301000602000804000A06000E0A000F0C000F0E001010000F0D000C09000A0600
0603000500000500000702000D04001609001B0F001F1400231400211300231500241700
2618002918002B19002818002716002717002819002D1D002F2000362200352A00352700
3825003520003521003822003826003B29003F2C004132004A390051430159570454751A
3E8C372E944E24985E1D9A6D1C9F5D18A24719A3371FA229249F1E299B17299E1527A018
2BA11C2FA12034A02734A22D32A12E2DA1322BA32B29A62628A5242CA3252DA1292CA12B
2FA02B2EA23331A23432A12C35A22533A42732A62D2AA83A28A447259E55249962219F65
1FA46523A4612D91613777623A6D623B7A623884624D8B40598F283D9D342DA44029A43F
2FA14D429D563AA06520A8751B977723767C2B597E2D786B31995833AC4A33AE4635AC42
32A8442EA44D2C97562C8C5D2C885E2A83612D885F2E905D31975A319C4D2FA0442EA439
2CA9312DAB302FAD3334AC3D35A545349A4C3198502C9755299A552CA0522EA74B31AB48
32AE4234B14235B14931B0502CAE552DAD5C2CAD6128AC6B26B06825AA662BA158368F50
3C835045825645885C438B59418A50488D4852944A5A98505C964D5C8A4A5A784D656951
686757676754607348627C3E617F2F63821B697F0D6F780A736C03725F007059006F5200
695100694D00685000654E00614A005F4800604C00614900664A00674D006B4B006A4C00
684E00684C006448006143005B4100574000563C00593B00583B00573E00583D005A3E00
5E3E005D41006047006048005E49005E45005B42005A4200573E00543A00553700583700
583A005B3B005D3D005B3E005E40005E44006245006242005D4200574100533C00523B00
5138004E37004D36004C34004E35005136005136005033004C3100482E00462D003D2600
3F26003B2300392300352100342100321E002C1A002A1C002919002A1C002C1C002C1E00
2C1E002C1E002D1F002D1D002A1D00271A00261700261600241700251800251700251700
2515002515002214002213001F12001C1000190F00160E00150B00140B00120A00100900
0E08000D06000A0400070200
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0200000502000905000B07000F0B00120E00141000131300151300121200120F000E0900
0C06000804000B03000F06001409001B1000201500251700241600211500241600261A00
291C002C1B002F1C002817002616002616002718002C1E00312200362400352800392700
3B27003826003827003E29003F2E00402D00443400473A014B430252500458630D4D7E2A
338D4F2793612198671A9B7118A15C17A3431BA23120A027259F1D2A9D162AA11427A419
28A41E2DA22231A12633A32D30A4302CA5342EA6292EA32030A11B31A01C329E1F359D23
369F22359E24379F26379F2435A12332A2292DA13724A048249E54249B6023976C239F69
27A4652DA75D2E9D58319154378A4E3D8C4E428B525A8C335C8F1F3DA02D31A5372AA53D
339C4D45955B3C9B691DA4741F957629757932577C347969359A5736AC4B36AB4733AC45
32A94830A34E309454318C56308C5B2E8B5C3097572FA35030AC4832AC3931AC2C30AE21
2FAF1F2AAF252BB0312CAA3E329C47308C4C2E8B4C2C8C4C2C914D2F9B4D32A24B33AA49
34AE4736B24835AF4F30AD592EAB612BA86A28AB7027AD7326AB6F27A36B2A9A5D328E56
348A52399354399E543EA24E449F4151993D5B944560924D5D8B4B5C7E4D6368536A5C57
65655463694C607940618033638023637D1266770B6C70056F64026D57006B5400684D00
684D00694E00664E00644F00654D00634B00614800624700644600664A00674C00684A00
694C00654A006248006045005B4100573C00583C00583900553A00563F005A40005C4200
604500604700624B00614A006149006249006146005D4200583B00583A00573800583A00
593900593D005B3D005C3F005E42006244006347006149006144005D41005A4000583E00
543E00523A005239005035005336005236005034004C34004B32004A2F00452B00412900
3D29003D23003A2400352300331F00321D002F1C002D1D002F1B002E1B002E1E002E2300
3121002E1F00301F002F1E002C1D002B1B00291900271800261800271700261600251700
2515002514002315002315002114001C1300191100170E00170D00170B00150B00110A00
1009000F06000C0400070300
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010000000000000000000000000000000000020000
0201000603000B07000F0B00120F001512001715001A1600181700171600161300110E00
120900100600120A00180F001813001D1700221A00251A00251800261600271800281B00
2B19002D19002E1C002819002316002613002616002C1A002E1D003321003824003C2700
3F2B003E2A003F2A003F3300443800453900453E004B440150540653630E4E751F408442
288768228E6D1E996C199E6D19A35A1AA5431CA33022A22724A22029A1172BA21729A419
26A21E299E21299A29299F2C29A32F24A7362CA42B2FA01F339E153A9C143A9B16389B17
3E9B14409C15409B193B9B20389C2C329B372B9544268B59249160249863229B6829A263
32A75D34A75734A45232A24E379E48419843498F415D8B26588C16409D2135A5282EA334
359A4C48915D3B966B20A1722396702D7A73396277397F62389C5038AD4436B04031AF40
30AE422FAB4533A74937A14B3B9C503D965037A04838AA4035B03836AF2937AF1F34AF1C
31B01E2FB0252DAF302DA73B2B9B3F2E8F42318C44318B43349245379C443AA14638A747
38AA4B37AF4E35AC5730AB5E2BA76727A26C25A56E23A67326A26C289C662C975C319256
33954F38A04B3AA94842A9434F9F3B5B903B5F8843617F495F734A676451735855765357
6A6550637348648136658426678317667E0E6979056D6F026F64006D5600675000664C00
684E00695100664E00675400695000655200654900634600614400634800684800664900
6447006343006243005F43005C41005C3E005A3F00593F005C3F005C43005D4400614600
604700624700654B00654B00654E00654B006549005E4400593F005B3D005A3F00563F00
593F005B3F005A41005E4300644600644900644D00634D00624A006146005D46005A4200
574300563D00533A005237005136005336005035004F34004C31004E2D00482D00432C00
402A003F27003B2600392400362100351D00311F003020003121003021003021002F1F00
2F22002F23003122003120002F20002C1C002A1B00291A00281A00271800281A00271A00
261A002717002614002514002215002013001C1200191000190D00190A00160B00120A00
1109000E06000B0400070300
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010000010100010000000000000000000000020000020100
0402000905000E0900120E001613001A15001B18001C1A001C1A001D18001A1500161200
140E00150B001A0D001E1400201600241A00251C00261C002718002A19002A1900281A00
2818002916002B18002718002616002515002717002C1A002C1900331D003627003F2A00
422D00413200443400453A00454100454600454C014758054B6912467A24408736358954
238673228D721F9A6A1AA16A1CA45B20A74622A73624A52C23A62626A61F26A61E28A51E
27A123259929238F32249533229E3521A43929A22C309E21319B183C9A133E9B113F9B0F
409B0F3F9A113F9C143D9C22369A362E9345288653247665268860299A5B29A65735AA52
3CAA503BA6513BA153369F563BA14A439E404F96315C8B18558A0B4399103CA01F2EA22D
389C4A49925C3C986A24A36D279C692C886B34776E398C563AA34439AF3B37B13A31B03D
2EB23E33B03D37AF3F3EAC4142A84643A5443FAA3A3EAD2F3CAE283AAE2338AE1F35AE1F
32AE2432AE2A2FAF302FAD3631A43935993C37933D3C8D413D92413B99433C9C463D9E4F
399F5535A55B33A55F30A3642A9E68269C6B239B6B249F6B289D66299D612C9B52319B4B
38A1453EA74144A7404E9F3E58953C5F8440627C4464714765694B716351835C52845E4C
7069465D7338627E2869821C6C7E0E6D7A0D6C7505716F027266006E5C00685300664F00
694C00684F006B4F006D51006B50006A4F00674C00664700614600624A00634700614700
6041006241005C42005F40005B3F005C41005D43005C40005D4300604500634700624800
624800624900644800644A00634A00654900664B006449005F43005F43005B42005C4100
5F42005D42005E44005F4700644800664700654D00665000654B00614B006148005C4500
5A4300564200563C005139005439005235005035004E32004B3100492E00442C00412A00
3F27003A28003B2600392200382200331F003220003323003223003122002F1F002E1C00
2C1E002E1D002F1E002F2000311F00301F002D1C002D1A002C18002A1A002C1C002B1C00
2A1A002918002816002815002214002012001F0F001F10001C0F00190C00170C00140B00
1209000E07000C0400080300
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010000010000010000000000000000010000020100050300
0605000A0700100C00140E001814001B18001C1B001E1B001E1B001D1900191500191000
170E00190E001A0E00201400211600241700221800281700291B002B1A002C1C002C1B00
2B18002B18002C19002A1D002A1E002D1C002A1B002D1E002E1D003321003C2900423000
463A004939004C4000484901444E01435203435B0547670D437B23388840308D532B8D63
248C752290701E996B1C9F661FA55924A84C24AB4124AA3521A92D21AA2625A92228A822
239F272194321E833C218D3C23983C209F40299F32319C24359A193D9C15409F123F9E12
409E163F9D1A3F9F1F3D9B2732953E2D8B4C2982572374672788582B9F4C2EAB453AA947
3FA94D3CA0573C935D3A90614198504CA23D52A026578F145288094A900A41961534A127
3F9F4549985A3B9C6629A66728A25E2D985C328D5C399C483CAB3C3DB2343AB13537B136
35B3373BB03240B22F44AF3248AD354AAC3045AE2842AD2340AB243EAA273FAA2A3BAA2F
3BAB3037AF3135B13535B13937AA3D3BA2403F98453F8E48418C4C3E8B503B8C55388A5B
358D623393673493683292672D906A278F6B249368239A6526A06026A45A30A54C35A542
40A53C44A140489B3F55933F5E8A3F657E44687745687246676C486C6B49796947766E41
6875375E7A2A657F1C6C800F727D0B767807757102766A01736100705B006B53006A4F00
694A006B51006E5000694F006A5000684E00674B00654800614500624200614000604200
6242005D43005E41005B43005D4100614500634A00654C00654C00684B00695001694E01
674D00664D00684C00674E006653016753006B4F00654E00654F00654B005F4500614200
614200634300604600604600624900654A00665000665400635700635200604B005E4800
5C4600564100553E00533C00533A005437005334005035004C3200493000442B00412900
3C24003A2300382200372200352000311F00302000322100312200301F002C1D002C1C00
2E1D00301D00311E00321D00311F003222003021002D1E002A1B002C1B002B1D002C1D00
2B1B002A18002917002716002314002212002112001F12001F11001C1000180D00150C00
140A001108000D07000A0400
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000020000010000000000000000000000000000010000030100060300
0907000C0900100B001410001713001B16001A18001B17001C16001D17001B17001C1200
1A11001B0D001E1100201300241500241900231600241500261900281900281B002C1B00
2E1B00301D002E1D00301E003221003123002E20003322003423003725003F2A00473200
4D3B004F4500524C014C5703465E04436709406D103E771F37823B2B8861288B6D25906F
21937621926C1E9767209E5F23A35527A94D28AB4525AA3C1FAB341EAB2D25AA2626A922
23A2292095331D8142248B4128953D299C3F2E9C30359B21379A153B9C163AA11938A21D
39A22436A02E389E2F3B99333490422D8D4B298D542489612C974E34A64137AD413CAA48
3CA6593898643A86693A7F6B4591544CA04050A22B51941A4B890F5087084B900E3BA21F
41A53E4A9C57399C6129A65D2AA74F2DA64732A1433AA73C41B03642B4323FB2323FB235
40B03245AF2C48AE294DAC2650AD2351AC1E4CAC1A47AA1D45AD2348AB2C49AC3546AB3E
43AB3C42AC3D40AE423EAC453DAA483DA34D3D94553C8E573B8E5C3989603985643A806A
3C826F3B84703E826D37826D2F816B298669268E66279D602AA4572EA95036AA443DAA40
42A440489B405092415D8B436682466E79496E734B6C73476671436673406A74386B7932
677F29657E206B7F126D7D09787804797302786C01796700746400705E006E56006B4F00
694E006B51006C50006A4B00624B00614A006545006647006543006043005D41005D4200
6044005F43006340005F4100614800684C006B53016B57016B5B016C5E026C5F046C6104
6B5C026D5C026E5E01695F01676103675F02695900685700665701665000624800614500
5F4500604400614600644800644A00635100655800625D00635F00655A00665400644D00
5E4700594600594300543D00553B00543A00533A005339004D36004E35004A3300412C00
3D28003B2400362200342100331E003320002F2300332300362300332000302000312000
311F00321D003320003723003526003524003222003021002D21002D1D002C1B002E1B00
2D1B002B1A002917002817002617002312002114002112002010001E0F001C1000170C00
150B001309001107000E0600
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000020000020100010100010000000000000000000000000000030200070400
0A07000C09000F0D00140F001814001B14001B17001C15001C16001B15001B15001A1000
1B11001F10001F1400241700271A00261B002619002816002A19002B1A002C1E002E1D00
2E20002E20002D21003323003024003223003421003621003A24003C29003E2C00483600
504300505000525B024C670842710F3F7718397F24398534308853228774248A7A219273
1A99731E97691F9761249C5728A34F29AA4C26AC4624AD3C1DAC331EAB3023AC2826A924
24A5271FA02F1C9737279B342F9C30339F2F399E233C9C183A9D1038A01831A42432A42D
31A33531A240369F3E39963E358C452F8D4C299952259E5C32A44B3CA5463CA64B39A355
389F6737926C3B8467387D5F488C504D99454E9E384C99284B8D1854850A51880742A018
42A437479C523698572AA74F30AA4033AC3937AB333DAD3043B13043AF3046AE3345AC37
47AC314AAD2B49AC2A4FAC2452AA1A54A91553AA1351AB184DAE1F50AC2A4AAC374BAB45
4AA6454AA04848A04E44A45340A35A3D9D603C94623A95643A98663992693B8B6B3D846C
428570468170437F703A807031836C2C89682794612DA35A31A94C3AA8423FAB3F42AC41
4BA24654974E5D8E4D6788486E7F4778734A7470496A7143656E3B646F3464742B6A7E24
6D801D6F82176F7B0D7577047875007A6C00796700766600776400745E007057006E5200
6B4F00694F00644D006247005E4400603F006341006644006244005E43005A4100604300
624700674300644400684500694F006C59036C6206696809696C08676E0966710E65700E
67700D676F0B626C07616E03607307617105646902636401646502675A01655100654E00
644900654A00664A00684D00695400675A006660006366005E6600636300685C00665600
634F005D4A005A4300594000553F00553900543B005337005036004F3600493200462F00
3E2B003B2700392400341F00322000322100362300362500362500372300352200352300
3624003624003624003824003826003726003625003323003022002E1F002E1E002F1E00
2E1A002D19002D19002A1A002619002515002313002314002014001E11001B1100180D00
150B001309001208000F0700
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000030100020100010000010000000000000000000000030000060300
0906000E0A00110C00150E001713001915001C13001D15001D12001B12001A1300181300
1C10002012002318002A1B002C1C002D1F002D1E002D1A002C1F002D1F002B1D002B1D00
2F1D002F1D002F2000322100311E00301F00351F003822003B24003F2A004230004C3B00
574C00565D01506A0844771139811E37862B328B3D308B4D2B8C641E897E208B7C1E9173
19966E1C9A611F9E5226A24828A54A23A94E22AB471EAC3D1AAC381AAA341EAA2C23AA24
24A82626A62727A22A2FA22835A12435A1223A9E193A9E14359F1532A21F2BA52E27A53B
2CA43F2DA24434A044389940338E472D934C2AA14D26AA5736A74F3DA05039955C399563
37936D368D6A3A855F3A8655478A4C4A8F4B4996434698334A9122538509578404519A11
4BA32F44A04A369B4E2EA74234AB393DAB313FAD2E44AB2E48AB3548A83349A33748A235
46A43845A63543AB3244AD2B46AD224AAD174CAC184EAC1D4BAE2248AF2C46AD3945AC45
47A649489A4F4696584095603D96643B94663C92683C98693C9A6C3F9A6E3F926A3F8A6C
44886C468570428B703A8F702F92672B985B2AA05231A94C3AA5403FA53742A53847A441
539B485C9152648A556D855071794E756F496D734467763A64762E67772769761A717713
777A0F7A790C7B72067A70017A6B00766700746300766000765F00715B006E58006D5600
6C4F00684E00634D006046005F42005D41005F3F005D41005E40005E3E005F3F00624200
644600684900674901695002695D05696908687711667B1666801662821662851A60831B
5F83195D83175D7F0F5C7D0C5D810D627D0B5F73045F7202606F056668026B5F00695900
6854006A52006852006C56006A5F01656301656601626B00626A00656D006A6A016D6201
665D006255005E4A005C4300573D005539005138004E38004F36004C33004A3000433000
3D2B003A2900382400362300322200352400372400392500382500372500362700372500
3626003728003928003B28003C29003C28003A2A00352900362400322200331F00301F00
2F1E002F1A002D1A002A19002619002517002414002415002012002012001C10001B0F00
180D00120B00120A000E0900
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000020100030000020000010000020000020000010000040000060300
0A07000E0A00110D00150F00180F001911001E13002015001E13001A1000180F001B0E00
1E11002015002618002B1C002E20002E1E00302100312100312000301F00281E00291D00
2E1D00311E00332300331F00321F00341F003423003A26003D2C00413200493500534400
5858034F6C0647780E3B861F328E2E338E3E2F8A4E2A885D258A6B1C8B7B1E8C72198D6A
158F67199A591EA24B24A54423A54821AB4820AE401DAD3818AB391AAA3420AB2A25AA24
2AA82031A71C37A5193CA3153EA1153A9F153DA114389E1A2F9E2233A4272DA33928A542
2EA73E31A73E36A54038A13D339B472D9D492BA74B26A95237A2533C945A348666358568
34846D3886613D825441844B4A844E4987544B8D4C46944046912A51870D5B82045C940B
56A22746A24139A04335A83B3DAA3643A93548A8364AA73949A73B4B9E3A4A973E4A9740
469C4045A23E42A93A42AD3341AF2D45AD2343AE1E43AF2242AE2640AD2C3EAE313EAC3B
40A8433FA1523B9D553A9B5C39975E3893613991633A92633F916641926C448D6C428A6D
448A6C43916D449B6940A0633EA45537A44A38A4453DA33C40A03244A02D459B3650953E
5B8F4567884F6F80517F7B5278774C6C704666733D657B31677D2869791A6B7710717409
7B71057C6F027B6A01766700766600746200745C007059006F58006B54006E56006B5400
6C5500654E00634A006147005C44005D3F005C3E005F3E005B39005A3C005F3D005E4200
6546006B4C00695302666009646D0F627A1362811D608823618B29608E2A5F90265C8F21
5B8D1E5E8B1C5C87165B89165F8B175D87115D7D085E7E065F7C07647506676D04696302
6D5A006B59006A59006B6201636802656A02646A02626A01626D006572026975036E7201
696800665B00635000604700594200543B005138005136004A3500483400463000422F00
3C29003C25003B24003421003121003923003725003B27003C27003D2A00372900372800
382B00372A00392A003B2A003C2C003A2C00372D00372C00362700342400332500322200
2F1D002D19002C1B002B1A002819002619002514002414002212002012001F10001B0F00
190E00150B00140A00100A00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000020000020000020100030000030200030200030100040200080300
0C07000F0900150C00150E00190E001A0F001B11001C14001D1200191100190D001D1000
1F1400221600251800281D002D1C00301E002F1C002E22003120003021002E1E00291C00
301C00341F00342300372200341E003620003823003B2B00422F00473A00504000565402
546C08437A123E861C33923030963F318F49297F5B247F671D856F188B79178B6E158866
158B611A97521EA34922A64423A84123AC3923AC3321AC341CAC3D1EAC3523AB2727AB1E
2FA81A3BA71340A20D42A10D44A00E419F0F40A0123CA11931A32031A4292AA33726A442
2FA73A34A83735A93637A73B2FA2482CA4492AA74729A550379B533A8E59348462358166
377F663C845943824E45854D4F7F5449805D4A855445924C4393344B8A16578409658F0A
5E9E204BA13D3EA3413DAB3A41AC3947AB3A4AAB3E48A74045A043449544478948448B4B
41934B419C4642A7423DAD3E40AE3843AF2D42AF263FAF263EAE293CAE2B3CAC2A3AAD32
3CAC403AA9503CA75239A156389A583A9459398B593E845E407A63427C6745766F477F72
45867143976C4AA16250A5564D9F474A9E3E4A9A3A499E34489F2D47992F4C8D39568A40
6583426C7E4874764D7E744F727848657D3F607A2F677E226B7F1B727C0F757608766E03
7B6D01796A007B68007767007568007562007159006F57006D52006A53006B53006C5000
6B4F006A4C006746006041005D4000583B005A3C00593A005A3D00583E005C3F00623F00
674A016B5503685C0367690B637513627E1A62852461882D608D335D9033598E275A8C1A
5A8B145E89155A86165E88185F8E17608B125C880B59890C59880E60830F647C0A686D07
6C63006E5C006A5E00666701646D02656E02616B02656801656F01657302657804697702
6A7201696800675A00614D005A4600574000533A00533A005137004B3500493200452E00
402C003D26003B23003721003322003324003A27003B29003C2C003F2D003C2F003E3000
3F30003E2E003C2E003C2D003A2C003B2D003A30003B2D003A2A00382A00352600332300
2F1D002D1C002B1A002A1A002919002616002613002612002312002212002011001C0F00
1A0D00180D00160C00130C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000000000000000000000000000000000000000000000000000000000
0000000000000000000100000301000401000502000502000702000801000803000A0300
100800110A00150D001B10001B13001C12001D12001C18001D14001A10001C10001D1000
1F1300211500251600261B00251A002A19002A1C002E1A002F1D002F2100312000312200
311D00311D003623003720003B1F003920003F2400452D004935004D43004E4E01556406
4B77143D8625368E302E983E309B482D8C561C726E1B75741A7E6E18876C1A905A179754
199A511D9E4E1FA44D24A74423A63C23AB2F29AB2B24AB2E21AD3124AB2B2AAC202FAA16
34A8113DA50C3FA30843A20944A10B44A10D42A3103EA61834A71F33A8262FA8312CA73A
30A73432AA3333AC3830A9402AA65327A54D2DA54829A14E369B4F399255378D5C388A5A
39855A4087554684524A8453517E584C7A614F7D5A4787593F8C4B468E2B528A1861910C
5E9A1B4B9C3842A04143A93E43AE4146AE4246AC4144AA4143A04842934845824F428052
3F894F3D954B3DA3463DAE463EB0403FAF373EB02F40AF2C3CAF2C3DAF2E3BAD2C3BAB30
3CAD3C3EAD4B3CAA4D3AA74F3BA251389C563893573E8955417E5C40746242646C437668
438C6B47A26254A25B599D4D56944756913C578C375B95345B93335A8D3A5E8142657D48
6B7A456A78496F754C6F764B69814061863063861F6D8016747E0C7979077E73037B6C01
7B6C00796E007B6D00786F00786B007666007460007158006E50006F53006D51006B4F00
6B4D00654B00664A005F43005941005738005D3C00593C00593D005F41005E4500624900
635305625D0A66630765670964730E5F740E5E7E155E83215F87246388205B84185D8311
5F800F5E7E0F607F0E5F8411608914608811628A105A8E13548F17598F195A881962770D
696C03696600676700666D00686F01666C01696901676600646F01647403627905657C04
677802696F006A62006555005F4C005A4100553D00523C00513A004E37004A3400472F00
422C003E28003929003825003927003A26003A28003E2B003E2E00423300423300433400
4235004435003F33003E31003E2F003D32004035003E36003E33003B3000382A00352500
3320002E1C002E19002B19002818002719002715002314002114002012002011001C0F00
1C0D00180C00170A00140B00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010000000000000000000000000000000000000000000000000000000000
0000000000000200000201000401000602000802000905000A04000904000D05000E0700
140B00190E001C10001E13002214002015001F17002019001F14002013001D11001E1100
2015002014002115002318002217002818002819002A19002C1B00302100322500342700
332000331C003422003621003923003E29004430004936004E44015053034F60074E7111
448425328E3E2F93482D984F2F96562C8C621E7C741F80701D87641A905A1A994E1D9F4E
1DA35422A15125A24D29A2402BA3332CA7262AAA2426AD2622AB2724AC232BAB1B31AA11
36A50D38A50C38A40B3DA30D3FA60F3CA6123AA71534AA1C2AAC212CAC242AAC2A29AA31
2FAB3330AC3830AD412BA84D24A25E27A3552FA5492FA44A38A04C3A9B52369759399655
3993563F905846885B4A855B537D5C4B766151775F4B7763447D5F4787494F8B2E5A9414
5C9D194C9D3346A13D45A93E46AE4348AE4447AC4643A6453F9F4F3F954B41864D438053
3C8356398F55389D5338AB4E39AF493AB0433DAD3B3CAE343CAE313AAD353DAC2E3CAD31
3EAE3841AE4440AC483EA94E3FA7503B9F563C9B583B97563B8B583D795E3D6564428060
43995D4D9E585899515A954F56934957923F5990395E893A5F7F426475496B6E4F6C6B4E
69684C656D4C63744660794062842F668A1E6A851772790C7675017A72007A6A007D6900
7C6C007A6D00796E00796D007969007666007360007059006C57006D56006F57006D5200
655000634D00644B005F47006044005D43005E3E00603F00624300604700624B00665300
665D0665670B676707676B04636D066371075E770F5E7F175F84185F84155E84135D8311
5D81105D7F115C7C0E5A80105686145986165C8D175492194E931E5095245590245C801A
647707657101677200686F006C70006C6E006D6B006A6D00647001627303627806637E06
617B04657301676A00615B00604E005B4500573F00533C004F36004D3500473300473000
442C003F29003C27003927003B2B003E2C003E2E00423200423300443500473800463B00
483C00453C004139004038003F36004035004037003E38003E3A003D38003D3500382F00
352200321E002D1C002D1B002A19002819002717002516002113001F12001D11001C0F00
1C0D001A0C00160C00130A00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000201000502000602000905000C05000E08000F0900110800120800150A00
190E001E1300201700231800221B00241B001F19002115002216002116001F1400211300
2313002214002216002317002117002418002518002819002B1C00301F00362400352500
332000331E003222003C2300412B004432004A3D014F4902525C044F690C487516418023
348C3E28905827915C269160288E622788671E80791F866B1E8D5F1B9452209C481EA14A
1CA55123A55124A44B29A43E2DA1332BA82A29AA2925AE2720AC2323AD202BAC182FAA12
30A71132A81230AA1334A71537A81632AB1A2FAD1F2BAE2825AE2E28AE2927AD2828AE29
30AE2F30AD3D2CAE4927AA5820A36825A55930A74730A9443BA54840A24F38A15639A353
37A15942965F4A8D644F8761547F5A51765E586E63526B68496C6C4E785D4D8643519821
54A0194DA2214DA52A50AA3053AA384FAB3B4CA63F46A345439A523F96513F8A52408555
3A865D398B6137956238A65B3BAD533BAC4A3DAD423CAF383DAF3240AE3040AD2E40AE2D
42AE2F42AF3843B03C42AF4840A84D40A156429D5C409A5D3E91623D83653A806243925A
4A9E5658904F5B8E4B588C4E56934757993C5795405884485D764E6669556F6658656954
626D4F6277475F7E3F6280306A841F6D8312757C0D7873057B6C00796B00786800766800
756A00756900786900766600746200755E00715F006F59007156007057007056006F5400
695300674E00664E00674F00664C00654A00614900664900634C00684E00695300675901
646003656505686905666C05656F076274095D7A0D5D80115B85125B88135B8A155D8815
598417588518528315528616538619538B1A5593205597224F992A50963B568D3E5E8527
627F11657D05687D026A78006976006C73006B7401697304687304677604677705617806
607D05647A03676E016661006252005F4400563F00563B005038004E3200483400463400
473000402E003B2B003B2C003C2D00432E004230004434004637004739004941004B4300
494700454600414100413F003F3B00403A003F3B003E3D003D3F01403F00403B003E3400
3A2B00372300322000301C002A1C00271A002617002415002013001E12001B10001B0E00
1B0E001B0B00190B00150B00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
0100000201000501000802000907000F0700120900150C00170E00150E00180D001B1100
1F1400211700221B00241E00282100241C00231A00221A00221500231500211600241200
2315002314002515002518002717002515002516002717002B1A00301E00372200352500
3120003622003926003C2B00423100493900524C01525D064C6D0D447B1D3E8330358743
2D8D55248F66238E6A1F8A7221876F238969208968248F5721944C1C9A491F9E4A1DA04F
1BA35521A35222A64C27A54128A43927A83324AA3224AD2E1DAC2420AD2126AD1A28AA15
27A91728A91D26AB242BA9212DAB2029AF2528AF2A22AE2F1FAD3424AE2B26AD262AAC25
31AC2E31AD3E2BAF5324AA5E20A46C24A65D32AB4834AD403DA7403CA34C39A65739A957
39A765449D614B8D6151865F577A5A556E5E5B686457616E50646E5269624E7C524E9731
50A6224FA71C52A71C58A82055A62C52A53053A3374C9F4045964E3F96553F8D563D8B5A
39885D388C5E36966238A45D38AC543CAC4A3EAE403FAF3542AF2C45AF2A44AE2841AE2D
3EAE2E3FAD3343AF3841AE4541AB4741A34E439B584090663C8D6C3A8F663D9A5E489F56
51994C59894D5D8E455B9245599641599C4054954756854E5A7553646A596B6759646D57
5F7150607D456286376388256F8215777C097B77047C70017E6B00796A00786500786600
766200746700736600735E00705D00705800715A00735900755A007457007456006C5300
6C4F00694F00695000665100684F006550006852006951006652006B56006A6001696601
666601686C0168700566730A62790D647D125E7F105B810E5A850E5C89135A8B155D8A16
578C19548C1A548A19518B1C4D8C21528F235797294D9B2E4E9743538B515E7F545E7A43
5F8721618E10648C07698404667E02677C036780076A830A678209648009637C08627B07
5E7E07627F06657704656901655B005E4B00574400553C00523B004A3700483700493500
4832004431003D30003C2E003C2F00403000443500463A00473C004742004A49004C4F00
485500435401414E00404900424400424601404503404804404806404902404500403B00
4032003A2900352100301D002D1A00291B002717002616002412002211001D10001B0E00
1C0F001A0E00190D00170C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020000030100
0401000703000A05000D06000F0800100B00150D001911001911001913001B15001A1500
1E16001F1A00231A00261E00252000271F00221D00221A001F1600211600211500231600
2513002614002815002919002915002A14002716002A18002E1C00332100352100382500
3622003724003C2B004132004638014C45025659074E6B12427A1E3B843432854C2E7F5D
2584661E85742083741F807A21817322896822935C24984B209C461CA1481CA2491FA148
1DA24821A44622A64426A64026A83E24AB3A21AC3820AD331DAE2D20AD2525AC1E22AB1B
23AB2123AB2B20AC3521AB3022AD2E21AD3320AD351FAD3920AF3A28AD2C29AB222FAB1E
31AE292EAE3F29B05123AD5C1FA96B28AB5A36B0463AB0403FAB403DA54C38A4563BA85A
3DA962479E5B4D8E5C5182585C77575E6B5C6062615D59675A596A5A5F615371564C933F
4AA72D4EAA1F55A91858A61A57A524539F2653992E4F99384392503D95523D91573D8F58
3A8A593A8B5C37945D3AA05A39AA5238AB483DAB413FAC3845AD2B4CAE2649AD2743AE2F
41AE2F3EAD3541AD3C3FAB4241AB3E3EA74B3D9B563E86623E8C633E9A5D46A358519C4E
52934C528950589245579B40589E3C579C3E55954655864C587854616F56646E555E7551
5C774D5E8341638C306D8B207781107D77027D71007E6E007F6D00786900786700796500
796100735F007161006D5D006D59006C57006D5B007259007459007357007156006C5200
6A4E00674D00664B00684B00684F006651006852006759006C59016D61026A6802666B02
666C02667203627808627B0D5E830F6288125E88115A86125889105A8B105A8A115A8D14
578F1A51911D51911C5093224E952B4D98304C9A364D9A404D8F52577B5D63715B5F7D4B
59912E5A981D60981760930D618C06638908648C0D658E15638D14638D135F87125F840E
5E8A0D5E880A5E8107657303646100624F005B4300563D00513A00503A004C37004B3700
4A3600463300403000403000403200453700453D00464000454701454F01485601475C01
4262023F60023E5C013F57013E540340530640550A3C560F3A580E3B55063C4E02404500
4037003B2E00362300311F002B1B002A19002A18002716002514002511002010001D0E00
1B10001A0D00180D00170B00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000030100060200
0906000C06000E08000E0900120A00130B00160C00180E001C12001E14001C13001C1300
1D1600221900241A00261A00281F002A2300292200281D002617001F1500201600241400
2415002613002716002919002A19002B17002D19002F1B00311D00362300382400372700
3828003E2700422E004B390150460455550A566B15487A2638833832864F2783652B7A6E
257C6F227C76217C751B7A7D1E8475239068219C5A249F471EA14018A64119A6431BA443
1CA5401EA54121A74121A74021A93F21AB3E1DAD391CB0391BB0361FAE2C20AC251EAC23
1DAC2D1CAD3B1DAD4A1DAB421DA9411CA8411FAB3E1FAD3D20AE392AAB2A2EAC1A33AD16
32AD262CAF3924B14A23AE541EAD612CAC533EAF4340AE3D3EA5403BA04E39A1563EA558
3FA85D479D524D8C50567D5463705766645D645C626255665F556A5F5F63597359508F48
4BA2394DA92653AA1C5FA6175BA11C549823508F2C4B93344A8F4843954E3E9358419258
3D8E5A3E8B5B3E915B4099583DA4523BAA4C3CA84840AB4141AE3645AE3145AD2C44AD33
40AD3841AC3B42AA4341A64642A94141A64E3E9A553E895C4494524AA24F52A24B549948
52904953864A58954058A13B58A138579F3A5292405482485B78535E70556171565C7350
5A784C5F843C688C277282187E770A7E6D01816C007D6E007A6D007B6D007B68007A6300
786300746200735E00735B007359007058006F55007357007558007158006D54006B4F00
6B4D00664C00644D006851006B4D006C51006D5400715E046E6609686E0A66730962730A
62750A61790D6180136085155F89125D8C145A8E13598A1258881158860D5C880C59870D
548B12528F184E941C4B9A264E9A2E4C9C3A4B9B454D8E524E7F5E546D645D6F5C588347
579A3251A42855A624579F1A5A97115C960E5D97155F961961971A61961E5E911E5E9118
5B9017598D105A830B617B06666A06665B03614F02594401563D004F3A004E3C004F3B00
4C38004A3800453700443600473C00464000474600424C013E56023E5D034064053F6A07
376D09356A09356605376306385F0736600A346210336616316110315C073456023B4B00
3E40003D33003829003121002E1C002C19002B1900291800261500251200221100201000
1C0F001C0C00180D00160B00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000200000401000804000B0500
0F0800100A00110A00110B00130A00140C00160D001910001B12001E15001F13001F1300
211400241800261A00271B002820002B23002D23002A20002419001F1200221200261200
251400261400291800291A002C19002E1D002E22003222003322003721003825003B2300
3C27004130004A370055470257590B506E1B497B2F3D7A482E765D277D6A1D7D77247874
217479216E7C206F7C1E727D2083712296641EA35820A5491CA64317A94418A84319A742
1AA6411DA7421CA9411DA9401DA93E1BAB3D1BAE391AB0371EB0361EAD2D1FAD2B1BAD2E
1AAD381AAD441AAE541AAA501AA85319A5551CA8491EAC4121B03D2BAD292EAD1B31AF19
31AE2529B03625B14224B04C20AF5934AE4B47AE3E42AA3D3EA2443D8F533994573C9E53
3CA056489C4A4A8F4C5380506371556B645B6A5B5A674D656155665E646358765A53884F
4E98434DA73354AB2460A6195DA11758992252912E538F33518843489349439A54429957
419056428B59418B5B42905A3F995A3C9F533AA44C3CAA4740AD3F42AE3C3DAE383BAD3C
39AD403DAA423FA74443A74546A84746A451439A54428A544A994852A34052A242549C46
5299445595415C9D325CA03359A030549F2F539735568745587B505E6F57606C585C7951
5C7D4966862F72811979730B7C6D047B65007969007C66007869007A6C007E6B00796A00
7C6800786200776000745B00715A007253007253007252007053006D55006D4F00674D00
6A4B006850006B52006B55006B55006C5700715F02726F0C697815647C16617F16618017
6282195E82195E891D618C1D5F8D195C9016589117578D15588D14588C13588B10588A0F
588D135190174D9821479E2A489E324A9C434C94524F825C57795E596F66577956549040
53A0344DAB3150AB2E52A52655A01B559E175C9F1B609E1E629D21639B255E9A215B951C
55931D558D175687135B8014607913656D0F61610B5C52045545015040004E3D004D3F00
4C3D004C3B004A3F004842004B47014B4D01495703466007406A0D3D710D3C7612397B1A
327B1E33791F357118366E1639681639651738671932671C2F67142F610C335A06364D01
3942003A3500392B003323002D21002D1A002D1A002918002715002615002213001F1000
1D0E001A0D00180C00160C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000100000400000602000804000B04000E0900
120A00140C00170C00160D00160C00190C001810001F0F001E1500201700231900241900
251A00261B00271A00281B00281F002A1E002C22002B1D002216001F1200201100231500
2314002314002613002A17002A1B002F2100342600362300342000302200352300382400
3F2B004833005443005B5405546D17417F313880492F716627687821727D19768321777C
20767A257576277D6F24886D23956320A15E1DA6581FA74C1EA64619A84718A84817A549
1AA84A19AA4919AE4319AD401CAA3C1EAA3A1EAC351FAD3222AC2E21AC2D1FAD301CAE39
1DAE3F1BAE4A1AAD571AAB561AA95A18A75E1BA74A1EAE4121B13F28AF2C2DB0222FB01F
2EB02828B13823B04024B24423AF4935AE4047AC3840A93B409C463D855838895B399452
399B5545A046439C454D8E4D5D7C54646D5765645A6959615F61605D6D5E567A57558650
50914851A03854AB295FA61B5CA316599E1F57982B59922F5785404F924147A04D42A250
429B54408D5545865A47835C478858478D58419B523EA34C41AB443EAE4339AF4838AE4C
36AC523CA74E3FA14B44A24847A14A459D544790534683554E954250A43C50A44650A149
52A24550A53758A32E5EA22C5CA1265B9E2557992E5A90405D804E607157606F585F7C4E
5E85417384217E770C7A67017763007561007562007360007860007A66007C67007B6900
7B6A007B6600776300755C00735B007358006E53006F50006E50006B5000694F00684E00
6B4B006C4E006C55016D5C02706104776809777311707E1C678422618924608D23598C1F
5A8D215A8A215C8B1D5B8B1C578D185A8E16588F185B8D195A8D1A538E1C528F1E538F1D
52911955941C5298244C9F2E45A137439B4C498A5F5673655C70646078635A8E5155A03A
50A7334DAC344DAD334FA92A52A91F53A61D57A61D58A6225BA5215C9F21599C1F569A1E
4F9A2254951D509221558E235689235986215A781958650F535308534D07534A07534A06
5048054E4A054F4D054E53064C5C06476607426D0E41791837832436852434892A308B31
2E88372F843A307E3332772F39712E376B2A356A2A316B262F6A1D2E6A162F5E09345002
374400393600382C003223002F1E002D1A002A1900291900291900281700251500211400
1D12001A0E00180C00170C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000301000702000903000B05000C0600100800130B00
160D001811001A10001D10001B11001D1400211300231600231700211800231900261800
261A00271B00271900281900271900291D002A1E00261C00221700221100221300231300
2613002616002715002818002B1A003122003424003825003522002F1F003524003B2A00
463100543F015A540357680F487B2832824B297A6428687A2760841F6B851D7285237C7A
2181792684722B8D68299766249D5C1EA3581AA65320A64F24A44A1FA64D1AA44F19A056
1BA55519AA511AAC441AAD3E1DAD3C21AA3A24AA3328A92D2CAA262AAC2825AD2C23AF34
21AC361FAC3F1FAD4A1EAE4E1DAC511AAB561FAD4822AD4223B1412AB1322CB02B2FB128
30B22F2BB23D27B34427B23E24B14039AE3549AB3242A83D3D974D3B7D5A3A815C398B5A
3595573FA14441A54045984C5184525877595E6E5964645C5B655E587159577B5653874C
508C434F9A3953A52B5BA81E5CA8175BA72157A02C5B933058833B528D40499F4347A546
44A14B3F9352488856517B594F7D5A4F825B4A8F5843995042A3493CA84A39AC4F37AE50
39AF4D3FAC4441AA3C41A94048A94649A7464C9E414D94404F9B3950A3374FA43B57A43B
58A53758A62F59A3245DA3215FA21C5A9F205B9A295D953B5A844E5C74575C735260813D
688A2A7C7E16806E047D6600776500736100735F00745C00745C007A62007C6200766400
7967007A6400795F00735C007257007055006C5400684D00674B006B4E00694F006A4E01
6E50047355087A5C0E826714887018877B1F7C84297883306F853366912E62972C609727
5F9427608C225F831D5B811A5883165C85155A8715598915598A17578D19518F1E51901E
4F931D4F97214D9D2C48A238459E4646905D4A836A53756C5E71656082585A9D4453A733
4FA3344BAA334DAE334DAE294EAC1F53AA1F54AA2257AA2558A8235BA22357A22254A223
50A223509E224F97254D94254C93234C902954822B5871275A64215C5F1E58591D575B19
505D154F64144C6A13497111427813397F193187222D8F2F2A943D2B933D2A943D27923F
2A8E4027874028813D29793830733530722E3171292F6E232C6B1B2C68152D6009315202
3645003A3800352E00342600301F002F1B002C1A002A1A002A1900271700231500221200
1E10001D0D001B0C00180C00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000200000401000703000B05000C07000E0700130800140B00160E00
1910001B11001C1400211400201700271600261800241900221700231900221800241900
261A00271800241700241600221800261800271D00281900231600241500251500251600
271B00291A002A1E002A1A002D1F003321003726003B25003521003520003A2800403000
4F3E005A5405566B0E4C7A24397A442E6F642C68722A5F822762852071871D7C84208375
1D8A70239368269C6325A06121A2581EA2561CA35220A44A25A54722A4481EA34E1B9F56
1DA4541FA94A1FAD3F22AE3625AB3529AB342DA52D32A72732AB212DAF222BAF2426AE27
28AD2A29AD3024AE3B23AE4221AE4A1EAF5123AD4828B04329B1422BAF3A2DAE3831B232
32B0342CB13E2AB14129B1372AB1303BAB2D46A73040A4423D9452407B5C3C7E5F3C8960
35925F3FA04641A63D439B484B894F4E7F575675565F6A58566C5752755652814F508749
518B4452973752A02F5BA8225FAB1C5FA8215BA02E5B932F57843B518A3C4C9240459945
419C4B3F9754468A58567C58557C59597B5B50865D438D553C974E38A25136AB5134AE4E
38AE443FAE3C3FAC3441AB3746AC3A4BAB3650AA2E4EA92A4EA72D50A82B50A82F55A52B
5DA32860A11F5F9F1962A11862A0175D9D25609B285F983A5A8D48567C545B7A43628629
7186167C790A806D017E69007B6600776600766600765E00755B00745C00756000726000
756100776000765F00755E00725C007059006B5400675300684D006A51006A51006B5604
6B5C11716719806E268974348A7B3A88774384764E837A4878833E718E3B6D933C67913A
6392326288275E83245A85235987225A8D215B8F225A8D26549024569522539526519526
4F99244D9F2D49A44045A24844905A4D766E4E78744F787055786555944D53A3364B9E2D
4B9C3047A53447AF3449B0294CAD2251AB2253AB2454AD2655AD2656A72653A32A4FA42A
4EA62750A324509D1E4E971C4B99224D943352873E587840566B464F66444B6442476738
436E31457931497C2D42822D37832E2B8334278A3C279243279548279445289540269540
249240258F3825883227822E2E792A30772432751F2F701A2C6E162C69123063092F5A04
374C013B4000383400372A003524003220002F1E002B1C00281B00271600251400231300
1E10001C0F001C0E001A0F00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000300000702000A05000D08000F0A00100C00170D00191000191100
1B13001F13001D1300201400261700251700241B00261700201700201600231500231800
241800241900241800241A002317002618002817002917002918002817002719002A1B00
291C002D1E002E1D002D1C003120003825003D2B00402B003F2A003D2C00423200493D00
5549015B680E497D243B7E43336D5F335B7433587F3456882F6682247B79228B71219266
1B99641D9D6320A26320A26021A055219F54219F5023A14725A34222A3401FA5451DA248
1DA6451DAA3F23AB3526AC2F2AA92E2EA92C32A72734A92032AE1D2CAE202AAE2227AE27
29AC2829AD2F26AD3F23AE4624AF4E22AF5625AD4D28AF4B2CB04730AF4032AF3C32B138
32AF372CB03B2EB23931B02F37AD2D3FA83044A4383B9F503D8F5B437463447A66408666
39946543A14A43A83F46A0454F944B4C89534F80555373564F74574D7A524D824A4F8A46
518F40519835539C325CA52860AC2261AB1E5CA323599626548E33518C384B893E468C44
41944D3E9256448B574E7F5C50825A59855A508A58448D553C9251349C5231A75131AE50
37AD463AAD3C3AAD373DAB3341AD3348AC2C4EAC284DAD284EAD2B54AC2558AA2260A51F
669D1C68991A679D1969A017689C18649B21649A275F9A3558904651854D558437648C1B
758709807902806E007B6B007A6A007969007B6600796300745D00745B00735B00725A00
755D00755F00786000796300796200765E01725D026E5904765B05745A036E560271630B
73711879792B89723A8C7348877A4B857B4C827C4C8586417E8B3A78884272804A6A8247
628C405B8A315A8E2958922954962A57992D579730569337529837539E31539F2E4D9F29
4BA32C4AA83647AB46449E564086624E696E546B6F5574725380624F99494B9437489130
49973243A63248B02F4BB12D4AAF2A4DAF274FB0254FAF2850AC2750A8244AA62C4CA62F
4BA62D51A52756A220509E1E509A28499A364B95404D87474A8151457E5441765442704D
426F484D714B537550487B543B7A522E76512C7F4F308650348A4F318A4B2A8E44289247
2899462797442791372C8930308229327B263076273074272D72252D751C2D7013306709
3858033B48003A3C003A30003627003322002F1F002E1C002A1A00261500251500231300
2212001F12001D10001C1100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
0000000000000200000401000803000B0700110B00140D00160E00190D001B1000201300
1E15001F1300201300221500221900261A00261A00211600211300221400221700231700
221A00241800251B00261A00251500251600281900261C002A1A002D1B00281C002B1C00
2B1D002F1D002E1C00311B003622003B2500402B003F2D00423200452F004C3701544602
5C5B095873233C7C4233725D315E7036507F3956823C5D83347174278666219662219D5E
1DA05F1EA25C23A05B259E56269D4F249B4E219A4D229D4722A14321A33E20A53E1FA53D
1BA83A1FA93322A92C27A92B2BA82C30A82C33AA2733AB2234AD1C2EB01E2AAE202BAE24
2BAD2B27AE3922AD5021AA5521AA5D21A86223AC5D26AF5827B25230B14732B04033B03D
32AE382EAE3831AF333AAC2E3CAA3442A439419B4836936039836B44696F447367408264
39916542A14B42A74046A5414A9C464996504A92544E894F4A8A4C4A874C4C8D464F8F43
4F9140539737569B345BA4305EAD2B60AB1F5FA71C5EA01B58972B52912F4B8E35458D3F
3E92453D9050448D524780594E8558568657518B55488B543F9056389A5433A45534A952
36AD4A39AD3E39AC333DAB2D42AD2C47AC2751AD2454AE2256AC255BAA2261A71D669D1B
6C981F6C95226D9C1C6C9F1A6E9E1C699E21659C275E9836579443528E49588F31689117
7A8A04857F00847300806D007D6F007E6B007E6A007C6700796200755C00735800705800
745700755C007B5C017E61027F650581680C7B6811856B1498671E9366118C6A077B730E
867A1D8D75388E70408B704A837D4C7B81487E8543858D3C848A4082854A737B546C824C
638E445D95315E9A2759992159961E5B942257922758912B57942F559C2D4FA02C4EA32A
4BA62E4BAB404BAF4848A55640925F448367517767547A665B85594D934548804045823B
49923646A53144B02A47B22C4AB22D48B22A47B2294CAF2A4EAA264CA52347A82B48A836
4AA6374CA8334FA72C4FA02A4B9C2F48A032489C3B48974646965046905A40805C44775A
4F715A5C6C5D636F5F5A76634B7C5D3D7F573D81544481514B7F523F7F4E2F8147278C49
26974B28984A2896402991352C8B302B842C297F2C297E2E2B7C2D287E2729791B2A6F0E
3561063B4F013D3F003C32003628003523002F1F002D1B00291900281900271800251600
2515002212001E11001C1000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000010000
0100000201000402000902000F0400120A00160E001A10001A12001911001E1200211300
211500211500221600221600231A00271B00281B00281900251600241700241800261900
241700241B00271A00261B00281800281800281C002B1C002D1D002F1D002F1B002F1A00
2B1C002D1B002A1B00321D00372300402C00442E004632004536004938005846045E560E
5B69224D73413A6C5E31676D2C5B7430587E2F657F2D738028826D2192631E9C5F1EA35D
1EA25D22A0562B995332964F2E964D26984C26984D269B4926A14522A44020A43C21A537
22AB3025AB2C2CAA2631A92735A82737AA2638AA2435AA2033AB1C2EAE1D31AE2031AC24
2DAC3227AB471CA8631DA66A1EA26E1CA0721EA86621AD5D24B15532B04936AE4236AF40
37AC3B31A73834A8333EA63640A24146984640905632866E3672743D5D76426F693B7E65
358E643A9E4F3CA84142AA404AA4444AA1494AA2494C9D49499C494B98484B98464E9745
4F973E549C38539C3359A5305EA93062AA2663A91C62A6185C9E1D4F96234B902C439136
3E923D3E8E46418B4C4381514986525386544F86564685573F8955399158339D5632A655
35AC4E39AD433FAD3644AE2A40AC2B48AE2455AE1D5BAA1D5BA81F63A61967A217699D18
68981A6A961D6D9E1B6D9F1C719E1E689D22639B2A5B923756943D53954059972B6E9415
7D8F04838301867B02877301827100836D007E6B007B6900796200775E00745900725700
745A00785B007D64047B6B0B7C71117E741D7D7A3490773EAB6A46A56826A56F127E7218
92741C9E782B917D3B877B4081824281853E8787398C85438A814F847657736B5D677556
60884A5C92385B972E5D98255A97235E96225C91235B9325579626569C2951A02B4DA42E
4EA93250AD404FB1474CAD52449F5C41966548876550875F5698524F9640467C40448240
47944045A83643B02947B22948B32B44B32B44B42F4BB2304FA82950A42649A72C48A63A
46A03E489C3F48A3344AA4314C9F2F48A02E469C354995434F9A4E5794584B865E51815F
627F5B667E55628255558957438F563892573B9157458B564A82533D80512F804C26874E
268B50268A5127894A248A4524894023863525853227842E2982292880232B791A2E6E0F
3562073C54023E42003B3500392A00362600332000301D002C1B00291900271900271700
2416002111001E10001C1000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
0401000603000A04000F0500110A00170D001B10001E14001B13001F1200201400201600
221500231700231600251800261B002B1C00281C00271A00261800231700251500241800
251700241800241A00261A00271800281700281B002D1E002D1D002F1D002E1F002F1D00
2F1E002E20002D20003624003B2A004330004532004636004F3B005347015E590D5A6726
4A6B483F6B5F36646F316275285D7C28647B257773218B6B1F94631A9A661B9E661CA362
22A05D279B53329050378E4E32934F2B984E28974A289C4526A14124A33E25A43C28A531
2AA82631A92239A6223CA8233CAB243DAC223AAC2236AA2236A91C35AB1C34AC2231AE2A
2BAA3A24A94F1BA4691BA26B1C9F6C1C9D6D20A66025AC5627B25135B0463CAE443AAE44
3AA73D369A403D9A3D429B4140994E468E513D85592D766C3167713459733A6C69397A66
328868339C5437AA483DAB4047A84447A7464DA8464BA74449A64647A24847A2474E9D46
4D9D40539D37569C345AA3315BA4315FA82A66AB2165A71B60A21859991B4D932442932E
3F913A3F8D44458C4C4681544783534E7D544A7B58467E5B41845A3B8E5A37965636A053
38AA4E3CAD4142B13245B02647AD254BAB205BAC1964A61865A31C699D19699A18689716
6B95196D951A6B9A196C9E1B6CA01D67A124639C2B5D94365B9836599D37649D24769910
7F9206828D05858908878109887D088778098270087F6C038066037C68037E65037A6406
7B670A7F6D0F7D7714807A19807B2684773889784993754C9E704E96783D917A2F747C30
7C8B2A8098327796397391387A8D3B7F8836817F357F79497C755A73695F6559625C625A
5B6B525C7E465E863C5B8F3559992F5D9B2F5B992C5A9A28589D25589E26539F2B4DA22F
4BA73550AE4050AF3E4CAD4B46A35544985F4A8E614C965D4EA34F4C9941498240488540
47944446AB3842B22A41B32843B32E45B42F4AB6364CB43353AC2950AA2C4CA73548A340
439744428C45479B3C4AA4394BA233479B304896364E934158964A5F95555491564F9154
52985052954D4F8E4A47914F3F95553B946239916A418A69437F673B7E61357E602B7B61
297563267360247060267659237B4E22804423844027873629832E2B80272C7A1E2E6F13
31640B3556043948003B3900383000362800352100301F002B1C00281600281600271400
2514001F13001E11001D0F00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000040100
0804000C05000D0600110800150B001A10001E16002015002212002013001E1500211700
251800241800251700231A00271B002A1C002B1A00281700271800261600251600241600
261800271800261800271800291B002A17002B1C00301B002F1C002D1E002F1D00322000
3722003625003928003B2C003F2F00453700493A00523E005A4D025C5C065C6C214E6E46
3E68673568743163782F647426697121716B1D856518965F1A9D5C199E631D9E631F9E5D
269A552B934F348A523589563191542897502998492A9E4028A33E23A63924A73729A62A
2DA72137A61F41A5203EA9243CAA2737AA2433A82432A82434A92034A9222FAB3028AC40
25A94A20A25A1B9B6C1B9C671D9F631BA06025A7502CAB482FAC493DAC4542AC4940AB48
43A5413E9744429544469248428C554385553A7B58296F68306A6E33637136706B30776C
2F7F6D33955E32A7523CAB4746AA4347A9404CAB404CAB3E45A74149A7454BA5454CA041
4BA13A529E37539C3556A13357A6335CA73362AA2E5FA9295DA41E5AA019529A1C499922
44963141954442954D468A56448755477C57467959467C5D45855C3F8F5B37975839A052
39A8483EAD3D43AE3049AD254CAA2153AA1D61A91B69A71D6BA21E6C9F1B699B1B6A9718
6898186B9819669A1A659F1F66A12362A3295EA22E5F9F33619E2E61A22970A11D7D9D0E
7E9C0B81970B80990F8394108390148587198282188278128675118475138574148C731A
8C781F8E80259083318E7E3690733E9A7145A36F4C94744D8A774C7F874776914072903B
719533689835649639639A3D659546668B496A794A6C6956656C5D5E675D58655D576E57
59794E5E84445C873D5E92325C992E5C99265D9A285D9B29599D24599B2057981F509B29
4FA1334DA63C4EAB404BAA4845A44F4A98574C935F4C9D5B4BA14F469B41488B41498843
49934344AC3744B42B42B32641B52A46B5304BB4344FB42D53AB264EAB2E4AA43A449C45
41934B3F8D4F439B4646A44545A240489E374A9937489D3B459E484C9D594C9856499457
499B534699523F8D533F8A59478B674B89734585774083763E7D74327E6E307F6C2A7B68
2972622A6D602C6B5D2C6D5C287455277C4C27834228853C27822F2980262C7C212F7216
2E660D3158043749003A3A00392F003628003220002F1D002A1900281500281700271500
2414002113002011001D0F00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000040000090200
0B04001005001109001609001A0E001D1300211500231700261500231600211700251700
281A00291A00291800241900271C00291A002B1B00261A00271700241800241600241400
2312002416002A16002919002918002A19002D1B002E1D002E1D002C1F002F1F00392000
3827003A2A003B2B00402E004131004738004F41005A51035F650B56741F4D7740436F63
3A6A742E6C762C6A742A726F23796C1D7F60188E55199B511BA1531CA1591F9E5B269A55
31944B318E4A2F89542E8A5B2A9159279851289947279D3D25A13A24A53424A92F28A725
2CA61F35A61D38A92036A92833A82E33A72C31A62A32A42C30A62A2DA53228A84024A950
22A7581F9F5E1E9765219C5D21A25225A74C2EA94435A84336A44A43A34C43A45241A452
429D4B3F934D448E4C4C87514B7D5F45795B37715E2C6B6A2F6E6D2F6B7131706D31706C
2F7171328B64369A5C39A64F3EA74542AA404CA93B4EA9394BA7394FA73951A53751A239
4FA234519F33529A34539F3152A73255A93756AA3C53A73754A43150A22656A01A559C18
4E9A26489D38419E473E98573F945B42835B417C5B47805C48865B40905D3B965B3A9F53
39A8473BAD3B42AD2F4BAB284EAA2459AB2162A92367A72168A31E67A21C67A11E6C9E19
6B9D18669C195F9F1F5EA2265CA02A5DA03458A4375BA6385FA62F63A92871AA1A7FA810
81A60D80A40F82A4167EA31D7EA0227F9B297E952D7C8D2A76842A76822C797E327F7A39
897C3D927940977C479C7B47997242967940947D42887F42817F42808B4083953883983A
77983868973866963C6B964675894F707C576F705A76635D726661706C5E69725D687A58
64814F6086455D8C3F5F8F305A932A5F94246196255D962A5F97255E95205C941E539624
4F9D3150A13A4EA6444CA94D44A24F459955479A5949A2524CA7494BA040489640489440
499C3E48AF3548B42C46B42844B62947B7314AB43B4AB3324BAF2F49AF3C47A44142974D
3E95563B965B3B9C543B9B4D3F9E44439D424399413F98403E94493E8F5541895747865A
4B875A49865B4078623C747144777F4875824371803D737F35777C2C7A7429816D298763
2786572A83502E814D2E7E4F2A7F5226834E278442258338277E2B25781E2A74192D6F11
2F65093156043646003738003A30003826003320002C1E00291A00271700271900261800
2516002013001F10001D0F00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010100010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010100010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000101000201000801000904000E0400
100800130900160C001A11001D1000211500251700271A00271900251700251700291B00
2921002A1D002B1D00281A00291A002B1C002C1D00291C002A1B00281900251600251100
2413002514002717002A1B002A19002A1B002B1C002E1A002F1D00301B00321E00372400
3729003D2B00412E004334004938004D4100554E015C650A5779214381463B7D66397779
3872792B757527796D2282661D89631B8E5417954B1C9B4A1FA04A23A051269C4F2D954A
388F45348D4A2D8D55298D6028935B279752299B48299E3E2B9F382AA33027A82C2CA825
34A82232A82234A72731A82E32AA3535A72F36A72D35A43230A7372EA74529A75524A764
25A465269B632691602C97552EA14D30A64737A64339A2453B9F4E459F4C479E52419B58
439252418A564986535181574C7364427263376F652B6B6A2F706C316E6C346F69316A6D
316876387D683A87663A96583FA14F41A94649A63A4EA73350A73453AA3157A92F56A930
52A92E53A62D50A33150A42C4DA62F50A93550AB3A4EA83B4DA83D4EA53355A31D5B9F13
569B184EA02646A43B3AA64F39A0563C8E594283594D845A4F865D458B603D945B3B9D55
3BAA483FAE3F42AD364EAC3157AC285EAB2665AC2664A82563A72066A61D69A81F67A71B
63A71662A3185FA52157A6285AA52E58A23758A53C5AA63C60A93265B02973AF1C7BAF10
7DAC0D80AB127CAA1C7AAE247AAF2D79AE3475A73C709B3F6E8D436B85467182477B824A
8382478A83488A864A868A427F81437C80447B813F7D803A7C803B818D37879B30869D32
7796356B8F32698C397189457A785478655C7F5F5D895A638F5860955D6092635F8E675C
816856716D4C62744461833D5B8E335F94295F98265D95265E94225F941F5F921C5C9520
589B2D53A03653A24053A2494B9C4F469B56449C514DA14E50A74C4CA3434C9C404D9B37
4CA6354EB13349B43047B42C48B72F4AB73748B5424AB23E4AB13D45AF4044A6433F9D4B
3C9A573998603A935E378C5B3A95583C995B3C94573D8A523D81523C7A553D79563D775D
3F7C6741736F415D7842547F4759814C5B7C455B763D5E763368772F6D702A796B268760
298E522B8C4A2D8B462C8B4A288D51268D4F258B4324843E267A312674212972192E6B10
305F08345102354000373600392D003828003324002F1D002C1B002A1A00291700261700
2515002013002011001D1100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000000000
010000010100010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000201000501000A02000C03000F0600100800
140A00190B001F0F002013002416002516002A1A00291A002A1B002A1900291B002A1E00
2A20002C1E002A20002A1C002E1E002D20003020002D1D002A1D00271A00281500251100
2510002415002614002D18002C17002A1A00291B002E1A00302000351E00372100392600
3A28003E2D004531004C3C005541005B52035A630958771D4B803D3A7B62367974347D7B
377B6D2C81642387631C8E6219985B1C9C4A1D9943239A42269B45289B4B2D964C30914E
368A4D328B522B8C5A258F6028945A299C522B9D462D9F3C2F9E392EA33330A63035A731
34A52F30A72E31A73330A93633AA383BA7323FA7313AA63932AA442EA8502CA45E2BA06F
2D9D682D985F2E905A33965238994C3A944F3F954E3F98513E9A54489C50459A553D945F
428859447A584D7F524D82534877674079633577642F736630756236735F377360396D68
38667439796A3C82653C8E5D3F9554409B4C469E404DA2394DA63854AB3357AF3057AE2E
52AE2A52AC284CA6294DA5294BA52C4BA5344BAA394FAB3C4DAC404CA83C52A5295BA416
5B9A15579B194EA42A41AA453EA6513D9556418A5549875B4D845F4587613E8E5E3E9B57
3EAB4E40B14342B13D4CAD3558AB2A62AC2566A92166A81E67A61A6AA61C69AC1F68AD1C
64AC1A5FAD1E59AC245AAD295AAB2F57AB395BAA3C5BAA3864AF2C6DB01F73AF1A77AE11
7CAA0C7CAC0F78AF1872B1216FB12774B23273B03876A93C72A13F70963F719442789540
7F94407F97407F95417A9541758F42718C4074923D75923A7694367E9D347FA33579A33A
74973D6E8C39708743768151796D5D81595D8957639154619755619A575E935E59886353
7E6D4D6E7845617C415F8A405F903560922A6196235E941E5C94196093175E92175F9419
5B9B255CA03257A54154A24D4E9F50499E564B9C5354A14F50A44B4A9F414C9937509833
4FA8304CB0334FB2314CB42D4CB62D4EB73249B43949B23A48B14046AE3E44A54140A14B
3C9955388D5F378366347A6A3E7D6B498072507C6B4E7266496B6344675F3C6B5E3D6A6B
3D66743D587939497F394B7D3A5A7B3A6B72377764337D643082623180632C815F268457
27844D2A83472E84402C88432A8B44288C402689392683392979342D77262A761B2D6C10
305E08344E03373F00373400382F00392C00362400311F002C1D00281A00271900261800
251500241400211400201000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
000000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000200000400000701000803000D0800110900130900140B00
1810001D0E002214002314002416002618002617002A18002A1A00291C002F1B002C1D00
2D1F002E20002F1F002D20002F21002E1F00311F002C20002B1C002A1B00281800271500
2715002A14002A1A002C1D002E1A002E19002B1800301C00341E00342300352200382500
402700422D004D3D005647005E57066169135A73264E7A3D4577543D73663578702F8170
2E846628906121955C189B5A1C9E55219D482699412E97422F97452E964C2D92512C8C55
2E86572C885A278D5B238F5C2895552D9D4B2EA04229A33C2FA33B2EA43E2DA73E2EA640
32A54332A74332A84233A94034AA403EA8393EA53B39A64232AA482DA9542F9E5F35916C
388D67398A5E36855A388B573A8D5539815C3F8359408C5A40905A479154469159428F60
488A554E7F5151834D4D8755407C663C85633781652F7C6335805B377D583A7D593C7561
3E70683C7B633E7D6440875E3F8A583F8F554295494798444B9F3E4FA83850AF3253B12E
52B12B50AB294BA92A4EAA2949A82C48A7344AAB374BAC3D4AAC4047A8404CA83354A824
5D9F185C9B1353A22446AA4043A74E419B534191554688594A855D4485613F8C5E40A057
43AE4C45B1414BB33A56B13460AF2765AB2268A92068A51E6DA51D70AB1B73AE196CAF1C
5EB01D5AAF2458B02B53AF3158B03258AE3759AD3859AD3863B1286DB11D72AF1878AE13
7AAA0E7AAB1077AF1671B21E6BB1266CB32C71B13474B03670AF3673AA3573A93375A537
759C3A759740769440769043778B47758A437A923E82933F87913A8D93398F9339878F3E
8387457F7E4988785492715E93645F9A565F9B57609B575D94595F8D565C835F55736D4C
677B495F87455B8E435A92405D92345E92285F941F5C94195F92175D94175C93185F981C
5E99245E9F3456A44151A0514E9E534B9A584D9E5251A7524FAC484EA6354F9B2B519C2A
4EA82D4EB0324DAE304FAF2A4DB0294BB32C4AB42F46B03145AE3346A83945A040439C45
3C974E3A895635776337686F485E7B665680725282744F81674E7F534F7C45557A485281
4C4B80473F803C388130417E2E59782E746C2F8A5F2C98592A9C562B985127924B278D44
2B8C402E8A402F8A3C2E8B382A8B382888332886312882332B7E332B7D282774192D680F
325906384B02383800353200392C00352700342300301D002B1B00291800281700241900
2517002514002414001F1200
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000010000030000
0201000402000804000C05000E0600110900140A00190C001D1100211100221200231800
271A002B1B002F1D002A1C002A1B002C1B00271D002B1B00331D00351F003620003A2400
382500382700372500322200342000362100322400342400322200301F002F1F002F1A00
301B00301C003720003726003724003525003A27003F2B004031004436004B4101535208
5C691659732B576A485463614C656D3D6E753C737033836E299169219A5E1E9850229848
229D482C9B4C37984F3B90503A8C54398D58378C5F358D66338E6B319172349164339358
3195502C994B2C9C48319F4833A24B30A35229A45723A5541FA3511FA44A20A94326AA41
2DA93E30A83B33AA3B35AA3C32AC4130AC4429A6482991532A73652F6871336D6F366D72
3E6D6B3F72653B70693F7169486F6B4E5E734D6C6C4571693E7068407A593D7C573E7E54
40894F3F8A573E91533C96503B91543F96463F934341944842964C41895740805B417161
44676449725A477B5846865943925844905D44815F466F65427364417D5C40875943924B
449849439D4943A24144A73E42AA3E3DA9403DA2423E9E443DA14739A24936A8483AA940
45A83651A92C58AA1F59A91556A81D55A62C4BA73B46A94447A74C4AA0524A995D4A995B
4C995751A44959AE395FAF2961AE2365A81D69AB1D6CAB1869AC1869AB1B66AE1D5CB11F
50B32F4BB43C44AF4445AD4549AD3F51AE3153B02461B42366B12B68B03769AF3C66B03B
67B1346AB42A6AB3256CB22272B1226FB12270B3266DB3306DAF346BA4366A963B6B8541
67863F698640698E3F69963B6B94376990386E8C3C6B82416C7549776F4E835F55894F61
964A649E4A5E994E599256548F62578F695C8665537D654C866C4987724874713E647236
64783263842B658328628527618926608B256092215D991D5E9C186099196099165E9C1B
5D9F2E5FA23C5DA0465F97506094515D96505C94555BA14C57AE4057B33553B33552AD36
4FAD3C4EB0444BAF444AB23C44B32F44B12B46AC2F49AC2A4DAA2653A8294EA22C4A9F37
48A33B48A04041934635844D2E79582C7069296672275E75255B77205D741F626F1F6C6A
2571642C74632F7B5C368654378E49328F463392462F894C2D8252297C5826795C267762
267E6628845F28914F289940259335258F2D248B24258B21218B262880242E6C15325207
354101373500392E003A2A003A2C003C2A003525003121002E1F002E1E002A1C00261900
2616002214002011001F1000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000020000020000040100
0601000B02000D0400130600140700150B00180F001A0F001D11001E0E001E1100231400
2816002C1C00301C002E1D002B1E002D1B002C1F00311E003321003821003922003B2600
392800362600342200372100352000342000312200342200332000301A00321B00311D00
3121003523003925003D2B003B2B003D2B003D2B004030004839004F4602565909597019
557B394F705245556E3E527A405F703A716B3B7D63308A622B965A259C4F2797462A9446
2797502B9658319458369058398F5B3D8F5E398E65388E6B318E6D30906E349062369359
36964F309A4D2E9F4C2EA24D2DA45327A75624A75C24A75723A65124A84527AA3E2DAB37
2DA9362CA63B2EA8402FAC462FAB472DAB4828A74A2990552D756331686D3C6A6B41686D
446B684171683A726C3C756A446F67485A754B6A6A4C74634A74634881553D8A513C8C50
41934D3B90553F994E3C9D4C3E9A4E409A4640954341964540924D447F5B437960427166
436A6649765A447A5942885A42915840915E438163456D6B446C69457465457E60459050
41984F419A48439C4244A04143A6413DA4453C9C413E96443A9C4B399E4E37A1473CA340
43A5334FAA2C55AE215CAA145DA61858A4284FA9324CAE3C48AE4649AA4E4A9E5A4C965A
4792564CA14A55AE3560AD2661AA1D68AB1668AB146AAB1369AC1865AE1D60B02256B22C
48B13B42B14540AF4E44AE4845AE3C4CAF265AB11E66B12068B13167AD4069AB4066AE41
67B03666B42968B1266BB0256CB12668AE2969B12B6AB2346AAF3568A53865953C668743
65883F6B8D3D6C913D6D93406A8C40638742667F46697248706651816154925559974D60
954B638F4A657F5360775F5C786C5B75745473734970753F758239748A356E892C658621
668919648715638B14648E146595136396156297165D9A16619B15619B165F9B155DA01A
5AA6315BA643599D4C5B9A4E62924D61924E60914F5A984A56A73F54B13751B23852B03E
51AF404DB0454BAC424CB13A47B2304BAF2C4AA72E4DA82851A82451A6274AA02D469D36
44A13545A03E429E403A94473189532C84662B7C6E287570256A74206572216970246A70
276A6E2A6C6C2D756A3381632F895B2C8C552C8D562A8C59268A5A24895A25895C248A5A
268F5B289351289442289339259133268F32258D2C248C232288212C7C1B34650C374E04
393F013C36003A2F003D2C003A2C00372800382700342400311F002D1D00291D00261900
2618002215002112001C0F00
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000302000502000502000504000804000A05000904000C0200
0A01000B04000C0500100600130900190C001B0C001B0D001B0C001A0C00160B00130900
130600170A001B0D002110001E13002512002013002311002113002719002B1B00291A00
281900291A002D1B003020003922003D28003C2C003D30004232004733004A3700523B00
5740005C49005B4B005E50005C52005C5901586200516C04497B0D4384163E891D3D8D22
3B902340941B43921C44901444921145921142941A3D95263896333A913D388948357F54
36745D38695E435D5D51496854415E503B6D5942726348667C42586B375E593B625B4962
67495B7344596B395E602D65682C6875306E803274813079802C827F2285781A91760F98
7D10938B11879E11789B15649A19519A1B49931E5B8B226A7D2A7C6D308D5F369D4E3C99
354591224E89245B8026677A296C762E6B76316B75346D773773743A78703A796F397A70
3977723874743C7077436A7347647348646F49706D4A756948706851686B5A5A7566477A
6B3D78702D7C7939777D4675834D717F476D75416F6A3B7460536D5763634D725E477A60
427F623D8064427A5E3E6E5B426660486860486366486A6148705B457A584082573B7F63
3577753A6A763F577D415E793D7675398978428B62468F5142954E4298563E9D5F3A9D5E
389A5134984D349B4F349F55379C574098504294574A8F3B55871F5E830E6D7D0B717108
736A04756C01796F007F72008174008275008173008073008076047F7E0B86901787922F
927D2CA567159D731BA0752C9075467C7650706F58856E569D6F56AA6944AE632BA96034
A25C419D5B4AA65F4EAA654CB5573DBB5335C14B47C04A52AF6755A5765B9379508E784E
947B43987743928044838C4E75A64B69A35269985A6A9D4A6EA040729E4070A03A6DA233
6CA43070A62770A52174A52175A62472A322719D1C72991772981B76981B79921A808A0F
828A0880910B7F990E7AA0137AA51478A41374A110729E0E6FA0106EA3156CAA196BAD1D
6BAD1F6CAF256FAE326EA8336FA33472A031759C2D78971E7E8B10818009817A027E7900
7F7B007D75007C7700797A007C7C007C7D00797A00767500757200746D00716900736A00
796B00776D00786C00766C00726800726500736700736600726600726400746000726100
725F00735F007361007861007360006F5F006A5B006C5A006B57006A5500685500655200
654E00654D00644E00655100645300614E005F47005B45005843005D4800604900634800
6348006148006049006048005D45005E44006044006243005D46005E44005D45005E4500
5B45005D46005C43005B44005B4200594000533F00533A005139005234005036004F3500
4C36004B3600493300443100432E00402C003C2900392800332400311E002E1D002B1D00
2A1D002918002513002112001E12001A0F00180E00180E00160B00150B00110B00100700
0C0600080300050100020000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0400000703000B04000D0700130A00130B00150B00140900120800150900180C001A0E00
1A11001E1100211400241500231600211600231300221200241600251800281D002A1D00
291B002A1C00291E002C1F002F20002F2300352400372200352600342500342600342500
3724003821003928003F3500463D004942004644004744004747004746004A4A004B5000
515600535B005862006269006872006A7F02618B084F94123F9A1835A01D32A61E34AA23
31AB2930AC322DA93E29A74B28A45129A35629A55A28A65B29A45929A257249F6022A066
20A06A20A4651FA2691CA17015987D14948E178F88178980167C7F1A6B8220588C304793
443A9A5530995D2998662197671C956919956B189069168B67158868148668138F6C1398
7111A0770F987B0F8E790D83760E87720D8B720D8E720C88720D806F0C7E6D0C806B0D83
67128A62189B5E1FAA542BAD4835AA3D3CA63A3FA43B41A03C429C2F4D9324568F1C5B8B
1C637F1F6A7A2671792E71772E7E6F2B8C6A2E95642F965F30995C33995A3A97593E9560
4492644187633D7867376E6E34786D3881713F7F6F4580674A846252895E50855D4A7A66
417269407B61418265498664538A5D5588605384664D7A624B6E655265635C685A646755
676E4C65724359714C56705D4F6D6A506B6F55706C5675655375655577645571705D6576
6364726D5F7178586D74586771575F7B694B7B793C7A833775862A6C831F737E10787909
757100746F007667007567007364007464007462007360006C5E007058006E5600705700
755C00745900795D007A6000775D007F68057D70108689218C8334937338A76836A85F49
9E5F4F9F535F9957629D5F60A16054A65D4AA25A519A526097495D9E4850A34545A54348
A73D4AAE3B4BB5384F98485084585D7F60519B573CB05440AA5259A05E619C6A599A665D
936261916A5B93704E947647917739927F309A8729938D1B848104857700876F00876E00
8A76008E850B90921D89991E859E1A819D1B829F207BA62C77AC2376AD2273AD1C79A812
79A8137DA5157C9E0F7B99097D9E0A74AE186CBA2B67C03969C03869C03168BF2D67BC35
62B73760A93E5DAC3F5EB14060B23A60B13C5EAA415DA14660984C63925067904C6A894E
678B50608B535F8551658A4F6F924D6C95416D973A70A23474AD316FAD326EAB3066A135
64973E639049608D4B5E904F5C975253A1504DA3524DA7554AA54C41AA463EA04B40975D
409869439F6441A7643FAF6540B76444BB6349B9554CB74751B33B56B63758B52E5EB130
65B12C65A72D68A3346DA237799D3772A0326AA12F63A52F61A63061A43D5E9F4A5A9753
579B5359944F5F934F66944B6396486296405A9F3B54A83854A73053A025569C22519D1F
559F2753A02F4E9E314E9F314EA2374C9F33479E2B489B214B96194F8E1659800A627201
696900685B00645200604A005A4400574100583C00563D00513A004C34004A3000483200
402C003A28003524003421002F1B00291800271B002718002513001E10001C1000160B00
0F07000A0500050200010000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000020000
0703000D0800130B00170D00190F001A13001913001A1000160F00180D00190D001C0E00
1C11002011002213002816002717002618002715002A1A002F1B002F2000332400331F00
2E1E002B1D002D1C003020002D21003424003727003A28003C26003A28003D28003F2A00
3C2E003E3100403900434100464A00444D01474C01474D004A4D00494F004D4F004F5500
555E005860005D6700636E00677C00648A05549511409E2132A1232EA42130A91D31AA25
2AAD3328A84027A24F239C5D239C66229C68229E6D22A07120A06F209E6B1E9A6E1D9B72
1D9B741FA2701DA36F1CA27317997F17928B168A8A1783871573871A62891F5091304199
43349E542BA15E22A0661BA06A169D6F13997111906D118D68128D670F8D690D946E0D9C
760BA47E089E83069581078D7C0A907809957608987406917304896D058468078963098E
6111965C18A25A21AD4F2CAC3D38A92B40A428449F2C459A2F439525518E1B5C8A176187
19677C1E7076237A762D7A732C846A2C91662E9B61319C5A319D57379B583C955B408E63
428A67448964417F663A7B6D3A826B3B846A3E826A4586674D8A634F8B5E50895D497D60
3F73653C7B623F82624785624F885F53886352816B4F7966506D66596B5C637056657552
66774C5F7B4657774F53735C516E63506E685A73635C7C5D567C5F5878655F6A706E5774
74596D81596A845C64785B5E72595C756F476D852F5E89246881176F760A727104756F02
716900716300706100725F00725A006E5E00725A00715C006E61007157006E5700705600
725300755700795A007B5E007C5E007E7011758827898C2E9A763BA16A3BA86933A26745
9464549058648E5E668F5F619D5E5FA75762AA51649F4C669C4D64A44960AD475BAC4651
B24441B74443BB4246AF484B9A5255935C52A05B43A95A46A0565C9C5E5F996E5C946E5C
8E6F5D8A73548F764D917D478C7D3D91862B8A91198B860B867A018978008B78038D7F0A
9A8910968E1D94912890932D89982881982A819E297BA53179AC2777B02475AD1E71AA14
6EB11C6EAC2271AA1D75A31177A10B72B1186CC03864C43F62C03E64BE3E64BB3B61B647
59A75259855C5A97565DA94E5BAB485DAC485D9E505B8D56608C57608E55658C48628A4B
6195515E91525C844F63904C6F974D6F9542739C3A759D3773A4326EA53068A62E66A332
5D9B3E5B914A5A894D54984C51A64F4AAD5144A856469F5E41A4543DAC4C36A050389A60
3F99653F9B6541A06641AC643FB76542BA6341B75B46B1534BAC514DB34951B54158B242
5EAF3F62A83E64A53E64A43B679E3A6A9C386B9C3C63A5375C9E4058925157855C567C61
51825D4E8A5D52915D58985759984E589541549D3F50A83F50A93553A52659A32356A020
57A02052A22151A3274DA4284CA5284BA62846A327469F2247971B4F901756840B5E7302
656600675700624E006049005C4300594100584000563C004F38004B3400463000433000
3F2E003C2700362500322200301A002719002317002115002112001D1100190E00150C00
0F09000B0500040200000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000010000010000020100050200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000000000000000000000000000000000000000000000000010000020100040100060300
0C0600140A00160F001811001B12001A13001C13001F14001F1400221600231800261200
221400231400271900271C002D1F003021003624003928003825003B26003A2900372500
321E002F1B002719002C1C003520003827003C2A00422E00442B00432F00453200453D00
424900415001425401415102444E01484D014B4E00514F00575800565F01546301536502
536D025971015D76016281045D8D084D9814399F2E29A24824A54627A43C2CA5362AA540
23A352219B6521926D1E8B721C8A731B90711B936F1A92721890741A8B751A8C7817907C
19917B199879199C741B9E721C98761A8F7F187D881A6C901D569B2148A12342A52E40A8
4039A45031A15C2CA167289F6F239C7721997A229675249372249173218F7C1D8C871989
9217909813939F11969E0F909A0C93940C988D0A9A870998820994710B93600D995110A2
4B20A7422EA83C3BA73542A32C499D224D971F4E8E1E50881E52871C617D1C6C781D7472
20776A1F7D652582662982682C89662E94612E9B5E30985B3697573D965B3E8F5D3D8564
3E8066438765488E6247936647945F42935F439064418F67408D6C438B6D4A8765488461
438463448657458554438859438B5A4687634F7F664F7F624F7E62577B5C607E54647E53
5C8150577E504F755F49706A486C684B656A536F6154765D526B685B64686B5B6B7F4F6C
7954677659657860547375426D813A6E83286C7F16686F096B69046C65016E5F006B5C00
6B5C006C5F006B61006E5E006A5B006858006B57006A5E006C6000715E00735D00755D00
7363007664007963007E720C7A891A948F28A37838A57334AA6A35A1654697644E8E635C
8465637C606989596698585DA45853B25850AD54519F534D9057508755548555578A564D
8C57449E5436BA4D2FBF4548B84160AE5161A76056A06551956355906B5A9076558D7657
8973588B744F8F73489080388298278990188B81058E7E018D800093880399941197961D
9F9427A7932DA2932F9C88388D8E31828D38769B38729D396FA63B71B3356BB7326AB835
6ABB4467B9486DB4426FAD3072AD176CB32269BB4166C04A64C04261C04360C14560B947
5FB44860A74C5F974C5B864E5F855267875F5D886B528F6852A75B4EB84E51B25055A458
58935B5B8E525D9544689B3D729F37789E3976993A77973B7199376F9B2E6C9E266CA22A
66A32C60A0335AA23750A43D49B24444BD4D47BC5145B9533EB3533BB64F3DB65248AB58
50A15648A0533EA7523BAF5739AE5E39A5623896663B91663D8D674090604A905F509060
54935B588C5A5C855361884F618B506889546D8A5E69866466706662646971606B82626C
836C6A7D736C64786756776556805F528F53519E4A4FA7434EAA3E4DA73C50A23B519A2F
4F992A4C9C264AA5254BA3254AA1224CA1244C9D2350991E5196154F9112508911577A07
5D6800625F006157005D4C005A4800543E004E3800473100432D00442E00412C003C2800
392200342200301D002C1D00261D002418002314001E12001A1000180F00170F00170E00
120A000A0500060100000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000000000000000000000000000000000000200000301000602000806000C0500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0000000000000000000000000000000000000200000302000603000903000D0700100A00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0000000000000000000000000000000100000301000503000904000C07000F0A00130B00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0000000000000000000000000000000501000702000A06000D0700110800120B00130C00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0000000000000001000500000601000A06000F0700140B00150E00170F00181100180F00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0100000101000201000602000B0600120A001610001B12001C14001D17001D16001B1400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0100000201000402000804000D0900140E001913001C1900221C00241C00211900211900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0201000502000605000A05000F0700150C00191100221600231A00231900241A00251900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0603000806000F0800120B00140C00180F001C1200221700241B00261B00281D00291E00
301E002E21002E22002F2100301D002E1F00362200382800392F003C2E003D2E00412E00
413200413700483A004C3B00513A00503F005446005C5200605F03606D07597A124F8827
458A3A3E8C4D3A8F52359A52349F47349F40389C2A3D9B1642980B4B94094C92094F9210
5192175694195792135192144D951B49981B46961845931F4993204A952448982C449C34
439633459237418E40378E4C2E8B512398531E9E58209C602396631D9762159266168B6B
18916C1B92711B8D721F8272207A771A7486156B93145E94124A9614469617529419628E
1B6C8A19708917728A186F9218699E1764A7185EAA1863A91969A6186CA51A63A21A59A1
214E9D24469B2A3A963332933B2C96412B9A3F2C9D3E2AA03D29A2382AA3342AA63231A8
2F42AA2F4FA92F51A7284E9E204F961D50911E588D1B5A8F16608F1974821B837D1B877A
1B8A731C8F6B1C93671F9563209E5E21A85925AB562AAA5530A75533A45732A35232A84F
30AA5034A95436AA5635AC5837A7533AA2533D99593F975B3E96593C91563B9055429152
44925445964D469A4444A43D45A63C46A63A41A23D42A24246A24248A34844A253409D52
3F9F53439F5745995E449262478D5D4C895650805A4A87554A8F5446905E4089653E8265
3C7C69407C6A437069495C6F575F6A6C6261856453746B4D656C4B666D4366792562790B
6277076674026870006D6D006E6D00716D00736900726800726A00736F00736C00756A00
756B00796F007B71007E74007B73007E74007F78047D8814749C268390407E7E54817953
826B58737F5564855F558863517D675A7968667666706F6372715B72705877745A79775A
77775F73775D6D75616C6C657166697F5C6C86516E795D5A726259855156894962815959
9E564B955553825164785C6070645D766C60866A678A7461927351887D50738D4F759C33
7B9A0C7F8D027F88008385008382008084008B8E0F87942987923A878A4480984877A645
6DA54970A34C6DAC466EB53D6EB6366BB5336EB62F6DB72E6BB72970B82673B52177B61B
76B61977B81B77B92374B82D75B93275BD3077BC296EB6246DB2246AB22A67B42B6BB631
62B73858B0434A9751459956409E5444A34A4BA1484B99474D9247508A4B4C89444D8D3D
4D992F49A02846A72449A72250A91E53AA2056AC2656AE2D5BAF2F5EB52C5DB5265EB324
5CB4275EB4275CB72957B63954B84154B34955B34B51BB4C4FB6444CB33E4AB83C43C03D
3EBC3B3FB63639B63F38B63F3AB0323DAD2C3EB1373CB5443AB45337AC5A3AA86136A169
359D6E3A9173398775398278397F7B3A7F803B81853A81883E7E8D3E7A8D407688427583
3D82793A9072379D6732A55A33AE5A32B05D37AD5336AA4834A63933A3302FA22A31A027
339F25369D243E971B478E12468A154583174382113F810F3E780A416E06495E044C4A01
483E00473C00493C00493E00493D004737004633004032003D2E003B2C00382800362800
3226003124002C22002B1E002A1E00271E002718002215001C1200170C00120B000D0600
070300030200010000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0A07000F0A00120E001810001911001E13002317002318002619002B1A002E1D00332000
3725003726003A26003626003326003622003827003E2F003E3200423100463200473600
4A3A004D42005447005A4C025A51055F5B0965680963760C60840D548E1849982D419A4D
3A9362368D6B339168329B5B319F4D37A03D3CA028419F1846990F52950A55920857910B
5A920E5A921055900F5093144399223F9E27399B3136963E3A95403E9A413D9B3B3F9F34
3E9D3542993A3E9440378F49318A4E259B4E1FA3511CA0581E99611B9963159468178E6D
1893721991771D8C751F81731F77771B6D83166192145195144097163B9716479418598E
1B668B1B6B8A186C8F1669981664A2155FA8175AAA1760A71669A4186A9F1A5F9E1E569A
1F4D9A21499B2640952C3B9234379138369435359735319C392F9F362FA1352DA53433A9
3145AA2954AA235AA1195B99135C910F5E8E15658C17678F18688D1B7B7F1B8B751D9172
20956C1E9D641FA25F23A15A25A05923A85428AB542FAC5133A95132A55432A45630A855
30AA5432A95434AC5535AE5338AA4D3BA74B3EA14F419E4E3E9D4B3E9C493F9847429944
459843449C42469E3D43A63C43AA3C47A73748A13D47A2464AA24549A34A43A152419C53
3F9C53449A5744975B3E925F438C5C4A8A594F875F469059469553408F5C3E87643F7F65
3E7A6C3F776C466E6D4D5D6D5B5E606C64557F6A487075455E764560793C627D1A5B7001
5E6F006473006A71006E6B00716900737000766D00716B006C67006E68006E6600726A00
7870007B77007E7A00817D027E8108848611868C1D7A982B72993F798B4C6F8156708253
678153609052588E62558A675182675B8162697D5E7776597977597A765A7C77597F775F
7C785F79735D7B6F5D7B66617E5A69834974863B787062646E82667C6554AD48619D5E61
9A62558D5C5679575D725E5F6F635A7369608567658C6E61917058887C4E70943977961C
7F8B067C82007C83007F81017E80018483008B910F8E903388963C7A994377A64771B045
72B1456DB34265B83F65C03D6DB6376CB52B71B6236FB82770B52670B62574B62174B41A
72B41777B71C77B82075B62173B92473C12E72B92E70AA2D6DB2266DB32B6CB32D6EB930
66C0345FB63A56A04A48A84C41AE4C40AE4947A84B4A9B51528A555B715B517A51488B41
49992C4AA42344AA2249A71C4EA5144FA61953A81F5AAC285BB22D5CBA315EBA2D58B82E
57B92F55B72E55B63855B64751B44A54AF5057AE4D55B64C51B8424DB73650B9334EBA2F
49B92E47B62D3FB43340B2333EAF2E3DAF333AB24836AF5A34A66832A174359D7B349583
308A882D808E327D90317694347293366D923A6A934166984A61994E5F9952609451628E
4971874286803B947036A46637AB5B39AC5336A84C33A84632A7412FA4382AA3342CA02E
329D283898243E901A43881345841046810F45800C3F78093E6D054364024C57004D4500
484100463D00493E004B3E004A38004637004433004131003D2B003B2E003C2900392800
3527003222002E21002F21002C2000291C00251900211600191100140B000F09000C0500
050200020100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0E09000F0D00170D00171100191100201200211500201300211300271D002E1E00372500
3D28003D28003B2A003A2D003A2A00392A003B30004032004636004837004D35004E3F00
5147005750005A5901606507647110637B1A5F881D56921E4A9A24439F303A9F4736945F
348B7133916F2E986C289C652EA25238A53B3DA52841A31F4B9E18539B1259941059940D
5A940E57960D53960D4E9711459E1C3C9F2A399B3B36944B39924F34954D349548349D39
389E37389E3C37994036914633894C29994A21A2491BA34F1C9E561B9C5C1898641A9369
1A96701A94751B8A761D7B771D707B1A6A8316608F165195164198183B9516469318568D
1D628A1E6B8B1A7090186E9717699F1563A3155EA51560A318659E19609D1C549C1E4C9C
20499C21489A22459424489126468F27468F244193293D972D399B30399E2E3AA12C3FA4
294DA5225AA21C639A19649016628A14608C156E8C17778F187E8A1B887B1D91701E976E
209D6820A36221A45B26A357279F552AA6522DAD5233B04F32AD5031A8552FA55932A857
30AB5733AB5537AD5336AC4D3AAC483FAA4742A94741A84541A74240A44140A24341A03D
43A03C43A03A44A23A42A83E41A7404AA53B4F9F424E9E4850A1454CA04A44A055409B55
3F9C55469A5942975741925C418D5C4B905C4E8E6045955A4396533F905C3D87623E7F66
437671457170486D6D5061695F635C6B6952796E47667B3D5685325583225C790E576E00
5B6E006773006B71006E6F00716C00716D00736F006E69006C67006968006C6A00756C00
7B74007C7D018188037B920777981573912E738A40738B446F8C48698B4E5E88595C9055
57915C539C5850995A508F594F8B575A835867785970745B777D577E7E5A7F7B587D7B5B
7B785C7B7260796E617B69638B5C6A974D6A973D6A7F56656E6D6086615EAE48699A6067
8F676182675C76685E74695770665E7565618C615D8F6C5A906E5A898144759B1F7A8E0E
7D7D027B75007C79007C8001807F01818A028C9719958C3C84974474A44375A94875AF47
72AE446BB7416AC04069BB3F6BB5396DB53072B52A71B52D74B52C76B42178B41B74B319
74B21776B31B77B41E76B71C78B72078C02A76BB2A73B82F6DB92D6CB6326FB2356DB932
67C03260C03856B54C4EB34647B24247B2404DAB4250974952884E577C574F824A4B8E3D
4C992A4BA42043A82043A81B43A91A4BAC1F4EAB294FAF2F51B53356B7345BB7335EB931
5CBB315AB83458B64556B24F56B34D56B34A57B44856B44554B73B50B42E50B3264EB426
48B42644B32A40B12B43AD2943AB2A42AE373EAE52399F64398A703A817A3D7E87397889
366F8E346B96386B9B38699C3C64983E6192445B945057965853915D568B5F5C87576388
4F6F89467D863D8B7637996639A3543BA3473AA04037A13734A13633A1302DA02C309F2B
349A2437992341901B428C1443860F40810C407A0A3F6F063F60024559004E4C004D4400
4D3F004C40004E40004E3F00483A00483800453600443600403200392F003A2900392700
3626002F24003020002C21002B1F00281C002418001F1400190E00140C00100800080500
040200020000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
110A00150C00180D001C10001A10001A10001C0D001A10002112002516002B1A00352100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160E001B11001B12001F14001E12001B0E001B0C001C0E002012002B16003120003B2600
3D2B003C2B003E2C00382D003A2D003E2E004732004F37005540005A47005B51015F6105
59710C52831351911D4D9B294B9E3540A24037A44330A5432DA4432F9F48358D573A7A65
347B6D2D826E29866D2889642C9F4530A92D36A82338A5203FA221449F234C9E274C9E28
49A02A4AA22649A22646A42A3CA83830A94329A74C32A04E38974C308C4E2D854E2E7D4C
31765034804B3296452EA1432D9F4128A23F20A5401CA4431DA6451DA1521E97631D9271
199079148C7D187A8019638618598C175D8D185A901853931A4A972144921A488F184B8D
17598D1A698C1C788D1D7991187696136F9A106B9D11649D12609B15559C18459D1B3F9F
1B47A01C519F1B589C185F9816629316608C16588D1B4F8F214994254D97265398225A97
1B6196186C9314788A16757F1770801B67831A80821992821A9F7E1E9C7321A16A1EA16A
1D9E661E9C63209B5C259F582A9E532EA25132A65331AC502FAC4F2FAA5231A95532AA52
36AD4C39AC453CAC3D3EAD3B3FAE3843AF3643B13543AE3743AB3844A74040A74340A53F
3FA43C44A44144A34242A44541A149479F474C9949489C4E4B9C4E4B9B4F4B984F4A9750
469C524B9A544B984C48944D45915249954A4B9948429D493F984A3F8F573F8662417B66
45696D4A646F546A6462675C6B6B546B71516F7451608334548818507B09597204616F00
6575006677006C7900707E00767B00737B0073780072790071790074830178920B6CA014
6AA41E61A8295CAA2F54AA354FA53551A03A52A43B51AC474DAF5444B25C42B26743B15D
45AD5C4BA95B4B9A5A4F8F505C844D5C79525D765E6173656E7762737D6572775F706B5D
73695D7D67627F65667B626A81596D985764A94D608B506C884B7B9B506DA94E6A8C6170
7F6F70787E6476825579785682636287665E9666528C704B75834F7D8E2D85850A7D7401
7B6D007E6E007C7400828100908C0C898F24948D2E9B8D3A829C4875A0507096586B9456
6A9B4B66B04C61B7535CB6505FB24967B04470B24270B73772B73071C02672B92374B519
77B10F7AAC0A7DAC0E7FAF167BB4187AB51877B51B74B9266DC02B6FBA2B71B23271B926
70BD2167C02761C03258C03F53BB434EC03C52B23C529848539D4955A14651A1424FA23B
50A92C4CA92446A71F47A31D43A32543A73849A04648A64E4BAB5551A85756AB575BAD56
5CB3515EB7505CB64D5BA74F5CA44B5BAE445FB03D61A82B63A01D6298125E900B58940B
4B9D1544A82944AF3A40AE3C3FAA43439A604776764C5B8062548774518A70578B6E5F8B
71638E6B5F915A5A90505E8B4A5D854F5F7858656C57686655655D5166574D6B55486E59
40755A3B805A3D8C5640994945973646952B4794264492224394223E951C389A1C39971A
3B95163E9315418F1041880D45840C497A094E6D08515F055253015147004F4400514100
4D3F004B3D00483B004839004834004436004737004334004132003F2F003B2C00392700
3428003320002D20002B1C00251A002318002115001D1100180C00110A000B0500060200
020200000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
1C12001C15001F16002117001E15002010001E0F00200F002814002E1C00372700402C00
402E00403400403A004136004635004E38005340005E4B005E5600615C006166035B770B
4C8A1C3E97283AA13237A64037A64532A7492FA7482BA74A2A9F512B8F5935835F3B7666
2F777127727329786E2E7F5D319D3D31A52635A61D3BA31940A01A439D1A4C9B194C9D1C
4D9F1E4DA11E4DA11F47A62839AA372CAB4328A95031A54D359C4A3093492C8A4D2C8051
2C74572E7A593190512EA14A2DA54228A53C20A23D1DA0421EA4431FA14F22965F20936D
1A95741792761B827B176D8416608B145F8D155C8B175D8E1A5C9223598E1F5B8A195A8A
1765891875891B80891C808E177A9611739B0E6F9D116B9B136899155B9A164C9C174A9F
1457A217649F186C9B187195167190186F881A69861C668B21658D236B8D24708B227689
1D7C8919808C14868617887E18877C1A867F19937A1B9B721CA06C21A06523A36021A262
1F9C6220956125985E279E592AA0562EA25530A55830AA552FAA5230AA5032AB4F37AD4B
3DAF463EB03C42AD3541AF3641AF3343B03241B03541AE3941AB3D44A94342A7463FA642
41A63F46A64046A63D44A63B43A13B489E3D4A9A44469B49489B4A4D994B52994D55984B
519B4C559A4D519A45499749459652479948469B4C409B52429355458A60418169447469
45626F4D5F6A566660656459696B516378505A7C4B57832B537C0F577505627201657000
6874006B7800717E00738501758A04748B06738F087690086F92086C990B66A51355AE22
51AE294DA9354AA73849A53B4AA63A47A93743AD3D41B0543AB36937B46A37B76E3FB265
3FAF5F46A85C4A985F518A5D5B7B5A5D72585E736363716B6D736A756E6C73656A70586D
6A5B6D76656A81656A755C6C6F4D767F5C71985C72815B747E4A7D8A556A9A5468886A69
7D766C7883636C88586F80577F695D83675D8E635480734B628D41788D22857A077A6F00
786E007770007F770086850198950F9C92259C8D32958F3E829F4F729B566F9257688C56
64915368AB4F65B7535DB54C60AD5068A1556E9E516CA63F6FB13670B82F6FB82775B61B
7BB5147BB00F7CAF137BB31A79B21B7BB41977B71773B81D6CC0266CC0266DBA286FB91A
6DB81668BD205FC02B5BC03F55C04756C04551B54053A24454A84455AF4652B1474FB13B
4CB03148AD274AA82048A42148A333439F4945895F4795634AA1664FA96550A96057A756
5BAD4A5FB14460AB39649E2F669924649C1E659516638C0E67840B667D086577035D8002
528E0D4AA02846AD3D41AF4042A64A429161496C705657826C4A8D7C45917B438C744E91
6A589B5E59934E6085426A764776654B7D4C567E335A78285B782059771E54771B4F7A20
48812D40883441913A409432419128448D21488A1C4A8B1B4A8E1845941C3E971E3C961B
3C9113408B0F40830B427E0A4776064C6903505701554E014F4300523F005040004C3F00
4C40004A3900483600483900483500463200453300453200423100402E003B2B00382900
3226003023002B2000281E002719002316001F13001B0F00150E00100A000A0400030200
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
1C12001C13001E11001F11002011002210002213002313002B1500301C00392300402A00
403000443400443900493B004D3C005A4300625400655F00666A01636F045E7C0A518B1C
42992D37A03631A53C2BA64129A84528A8472AA84927A456269560277E6E35786C3A6E6F
316C7A2D667E2B76742E895F2EA0402EA62D32A52536A222379F223B9E22409D1F429D1F
4BA12050A2204DA52146A82B3AAA3732AA422BA94E30A94B33A74831A3442C9E452A9646
2D904D348E4D36964734A0462EA63B2AA43521A3361F9F3F1FA5431EA44D219D5A209C64
1B9D6D199A6E1A8C7417768315648E135D8E135B8A14638C186C8F226D8D216C881B6888
1A7388168287188B8818858F157A9812729D14719D14709A146E9815629715559A13579F
1267A01176A1137D9917809218818C188086197D841E7C84207F8523848323897E1E8F7D
1B917C189082169281169579169A79179D7A199F741CA0661D9F5C21A15821A45722A159
239D5B27995C289A59299F582CA15630A35731A65A2EA85830AA5631AA5337AA4E3DAB44
3FAF3D43B13544B22F41AF2F40B12F3EB1303DB0363BAE453EAC483FA94C3EA8503DA749
42A74142A83D46A83846A73148A1324C9F374A9A40499A47499C484B9C494E9B4B539849
509B47579F4754A0424C9E42469E4A459D4745995141955A43905B438764467C6C48736D
4C676B58606560665A6E62546D6C4D5C7D4D4B82444F7D235277085C72006472006C7500
7077007080007188016F8F046A9908679C0B69A21068A71564A81265AA155CAD1F59AC28
58AB2C57AA3157AC3252AB3551AD354AAF3843B0433BB05735B2693BAF623EB06141AC5D
40A55E43A65D4CA25F579C5B5E9458608E5562825D6275686A70646D6A6A73686B735A6F
7062706F686B76636B715A6D6A4D76756274896376776575745677805D698B5D66827266
7B7B6B76886165875767825875715E7D6B5B8466577477495E972E718D197D7803787500
797200777200807801858A0495A012AB8F2B9A8C3A8C91418098507F95527E934E768E4E
6F8A5069994D689F4C649F4A669B546C945E6F92566E9B486AAC3D68B7316EC02974B826
7BB81E7EB71C78B61E75B52175B12079B31A77B61773B9196DC0276DC02B70C0266FB718
6FB5136AB91C64C02E5FC0395DC0455BC04B57BB3F54B1385AAE3A5AAC4058AF4250AB40
4AA53C479F394AA4304BAA3248A74047A251449864449C6946A1674DA96557A15C5D9E52
5FA24862A43A659D2567911469860B688205637401637100636B00626600626900607000
5F7C0854941C4BA83248AB3F469D4F4286614A666858557A6C4A887F418E833C8E784B8E
5D5A8E4F6477496E624873524A7D404D7F26537114566A08586203556302566703566F09
4D7C154A8620458B29428C2543891E4784194D83144E82134D8815498C19498E1D468B17
48840E4A810A4A7C084B7407516A05545C015850005546004F40004B3A004C3C004F3E00
493E004938004A35004A37004839004637004334004433004330003F2D003B2A00362800
3022003021002B20002A1C00251A002016001D12001A0E00140A000E0600080300030100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2012001D13002012002210002313002211002510002816002B1A00341C003824003E2800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261A002617002915002B1500291A002D1A002E1A00301E00361D00372000412400462D00
4A30004D3700533E005B47006057006761006C6C006D7603628009568D13489A263BA539
349D46308F59289B5F22A76122A96123AA5F26A55B2897632A836A2C706E31676A3B5871
454884385F852E8080269C7123A75127AB382FAB2932A92633A62632A7263AA7223DA91D
41AD1D3DAE223AAB2737A93138A73437A73D30A6462EA7482CA94827AB4B27A84827A943
2EA542349E4037994138964332A1382CA53024A333239B3F23A04621A35122A65421A759
1EA3611EA06C1C9C72188D7C177881196E831A6C861876871B7E851D80821E817D1E807D
1F8680188E80149484128F8C11879A147E9E19789D17799915789214788B13788A11798B
13818A148888158D831890821A92811B977D1E957B219578209879209B781E9E751BA370
18A46B189D6A199A6B199E6B16A56E16A66E19A26A1B98611C97581C99511E9E5221A153
25A35527A5552AA3552B9F592E9D5B30A05C2FA15E2EA45D2FA65A31A5533AA94B3DAC3D
3EB23642B33441B4363FB1383CB1393BB2403DB04A3CAE543BAE523BAD4F3DAB4A41AB42
41A93C3FA8393BA7363AA73540A53746A1424F9A494C9A4B4C9F484BA146479F47499F42
49A3434AA64A4AA64C43A64F40A45743A05343965B418C5D418B5C4780644C7669537368
5D6E6468695D696D596D6C576776475A87305483155B7A0B6276046A7401727A00778400
748C007193036D9A0765A3085DAA0B5DA9115FA81364AD1562AD1860AE1E60AA1F5EA822
5EAB255BAD2C5EB02D5CB12E52B53448C04141B55140B25E3FAC6847AF564DAF484DAE4D
46AB5845A3664A996E50916A588F63598C5F5F836562736B6770696761736962736D6174
68657461666F63626D6C5D646E566D686A6D6D69696572645C696C5A7063556D695B735F
617559697A5B6B71697069647C625775675673675D7484407496147A87047E7D007B7A00
7C7D007F7F00958C0FAD812CB07F2CAE87339787497D825378785E828457858755818252
78725B6D7161726B5E72685F7A6F5F837C5A82885573974E73A64174B53B74BA3A70C032
70B62375B82574C02878B82078B7197CB61F7AB92279B82072B92C6FBB326DB53571B62F
74B82B72B62B70B63172BD3C6BC14065C04368C04067BE3669B53269AE3065AC365DA340
5294454B944848A14543A14B429E5044A85447AD654BA96A51986255964B5F9D2B688C13
6C7F08707505706D036D6A016C6A006A6200666100626300666400686300636300616200
6168015D7706578C1451A12943A93A3FA63B409B4A3F9A553E975D3E9A6140A45D44A444
53901E5A76075B6601615E015C5C005D5C005A5A00595A005A58005F58005E5E005F6202
5A6A0754730B497D14468616498A194C8C1B4D8A194F86194A831A4C7F174E7712566C08
566501565C00565700555200544D005445004F3E004B3D004A38004C3B004A3700473700
443600433100433200432F004532004634004231003D2D003A2A00392900372700352400
3021002D1E002B1D002719002016001C0F00130F001108000C0600090200050200010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2D21002F1C00311D003420003421003721003923003D2600402900442C004431004C3600
4C3D005342005648005D5100636600677501637E065E8810518E21449B2D38A4372FA53E
2A984D25806C2192781C9F7A1CA3761CA178219A74258A722C787031686F3A6071405A76
475683386E802A8779249E6523A94A29AB3833AC2C38A92A3BA72A3EA72642A82248AA1D
40AE1D3BB02337AE2639AC263DAB253BA92A35A83435A73C32A7442CA54F28A24E28A14A
2B9E493697453B91453B8B4535983A2DA13526A335279D3B279D3F259D4C27A15424A55A
20A5651FA26D1BA372179B76168C761A827C20808023828125818020817E1C847D1D847D
1D8580168A80149283149389148F94178597187F99167B98137C9212808A108485128582
16897F178E7C1992791B93751E96771F9A711F9B701F9A701D9B72209C731E9D751EA26D
1BA0671C9C651A9A65189D67189F6A17A26B19A1681B9A601B98571D97541F9B5422A153
25A4542BA8542EA3562FA15B319D62309D642F9D6531A05F34A45535A74F39A8453DAA39
3EAE3A40B1403DB2463EB1443DB0423EB0453EAF4C3CAF533CAE503CAD473AAC473CAC40
3DAA3A39A83539A83A38A9393DA73E42A543499D46479D47469F4246A14043A34043A641
45A94044A84942A94F3FA84E3FA55542A153439857428F59428A5E4C7C61546B675B6768
64676270685A6D6D596B705D627C445D8B225B8207637A04687A036E7A01757F00768700
738F007296046AA10863A70A60A9105FAC145EAE145EAF185CB0195DB11C60AD1961AD17
5FB01958B02057B22352B5264BBD3445BA473FB4593FAF5F3DA76546B0564CB3434BB248
45B05647A7654A8F6E4D82744F7F6E52806F57777261677468706A656773636A7664667A
6465745F636C59626B5F666461616A5E75616171615B7A6056716A577766557766587758
5A7656617B5A70666F775C6A7E58577864507270587A883A7E930D7B85017A81007C7C00
838103888C0E938E1BA98423AD7C2BAB7F3E928A517D8558777A567F82517B7D5C797659
766C58726E5C756A6083635F956060A06D5F978353779A4B75A4447FA74077B53F70C03F
6DB5316EBA2E72BA2E74B92973B82579B72978B92A79C02678B82D71B33672B13174B52E
76B32E7BB12C74B32E70B7386ABA3B64C03D67C03D66BB376AB72F69B42B68AD2F5CA138
5490434C8C4B49924F449651419B5B46A45E49AB684EA862529A4F5B942E658B166D7D0A
6D76016C6E006E68006F68006B6500696300646400626400645D00645B00625A005E5A00
625E005F6A00577A0A51901E49A03149A339499D39469D3D499B3E4D9D3D509D3256911F
617C0B6368016060005B59005B56005D58005C55005A56005D56005D5A005E59005B5901
595C025B6504546F0953790B557C0C557D0D577C0C5B780B5A730C5D6E095C6806606203
5B5900575000594F005449005244004F3F00493A004934004833004A3600483600463000
4332003F33004330004131004232004333004030003D2B003C2800362900342700342300
2F1F002A1F00281A00241900201300190E00150B00100A000B0600070100020100010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
311D003520003520003A24004129004129003F2900452B004534004B3600503900503C00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381E003923003B2700402E004534004932004B30004B2F004831004A34004C36004F3700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3E28003F2C00452F004C36004F3900543B004F38004A34004930004830004834004A3400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443300473500493400523C005543005A49005646004F3A004733004731004B37004D3900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4B32004838004C3E00523F005C4B005F4C00574800503F004D30004530004433004E3A00
5347015860034D79133A822D2C87502589702482852D768E396691474F9447499A42489B
2D5D8E266887207589207787236F8228637E3762864C608C5A628E57608D4D63914D5F8C
317E802A90662B9F4932A7333AA72B3EA5263CA7223CA8213DA81E3EAA1E3DA81E3EAB1F
41A92140A82D40A53740A44439A34E36A35632A6502EA64C24A34F23995C249862269562
2F985636A34737A8403FAA3E3DA63835A4362DA43F27AC4025A94224A04427A14627A74A
27A74B279B4D27994F2A935A2B8F6929887624847C25797E2A76802E7C7E2F827A2B8678
238677228E782690732B8F732D91742C927527937123986C1F9A6624A16327A2622D9E65
309A65349B60349B5F379A60319D5F309D5C379A53359D4D349B4B30994F28985C229562
218D66218567228B6520926221995B229F5223A34D24A44D20A44C25A24E2BA6502DA74B
2FA54832A24735A14934A15135A45531A35731A25D349E6537A05D34A55A33A75B37A857
3BA9453EA93142AA2347AD1C49B01C44B02541B12A3FB02E40AF3044AF2B46B0284AAE27
4DAA2F52A93553A3404DA242459D44469F4146A23A44A53C45A74046A34146A34343A346
41A64641A84C42A8523E9D553C8E5F3C9060438F645182675A7065616B586D624F706B4D
686D535C774E648D2B6F920D718E03758E017892007792007793017199046D9F076AA507
68A90861AC0A60AD0F5EAC115AAC1356AE144FB0144EAE1947B22549B13548AF4042B146
43B34242B34046B54745B1543DB05539B05236B25135C04D36C04E39B3543DAC5E40AA5B
43A1564EA75458AA5758AD515CA94959A74558995151846E5F875E63835C5A85555C8158
568458548F5957915A58894F59884A598944538C46518C4A548A535D8651597F5F637462
6D606D745A6A88566A815D647B5E616E794668901B7585087E7E03818A0E86961E9D8C2F
B27332B17127AA603AB26640AC72469673568B745F89775692685FA0655CB06A55B86B57
BD6459B75C63B05664A5545A9B5B509D684099703C98734682864A78944B7B9D457EA043
7EA93A80AD3B81AD3985AB3683AB3182A9347CA9347CB03C7B9D4283854A8C88408C9132
7EA01E7AA21675A11871A71F70AD236FAD2669AA1966A91761A9205EB0285FB5335FB63A
5FAC4A5EA6515A9A585B934F5C9B375F931A6C7F09696C00666200646100655D006A5C00
6858006655006355006153005F4F005C51005A4F005B4E00594D00554900544300554200
5445005947005F4D005F53006153005F51005C54005C56005B5400594F005950005A5100
594F00574E005B4B005B48005A4A005A46005A47005844005645005A4900584B005A4A00
5747005546005245005744005444005043004F42004D3F00513E004E3C004D3E00503D00
4C3D004C3900493700463300443200402C003C26003A27003A2900392A003928003A2800
3925003826003726003728003929003929003828003426003428003123002E21002C1D00
291B002718002116001C1200170C001108000B0500050300020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4A34004837004C3700523C00584100574300513F004B3300452F00482F004A3400513F00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473500493400493800503900513B004D3A004B34004A31004832004D3A005444005A5201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4939004A36004D3D004C39004E38004B39004C34004C37004B3E005B480064580261690A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4534004336004937004A37004F37004C36004F33004D3A005842006252006665045D7D17
4F8A383A8F62317E7A2F7187286D961F5EA32D55A83F55A54D4F9F4E42993847972E519B
2E5F963C65903E6A87426683525C736A4E665D5577525A814060872F7080238076219969
20A95923AC4928AE3F2CAD3430AD3033AA2A34A92837A82B37A72E3AA62B3EA6263CA624
38A72337A82736AA2A36A93130A63F2AA74A27A75024AA5224AD5429AE462CA93F2AA848
29A64D29A74B2BA64B2BA93A2DAA2F2CA8332DA2402BA93D2AA6392F9A3F3297452DA147
27A44A289B5024A154269B5C2C88643473692E736B266E702165781F6C78207377287376
247D762086752087732587752E83713A7F6736885E2D8E5D23935823994F2C9A4B37974A
3793503193512E8F542E96562C9D5A28A15C2A9E5B2C9E5D2F9C622D9D68299E6D279B6D
28956D26966B259D6422A65E23A95322AB4927A9412EA93D33A93A36A53B35A73C34AA3C
2FA63D32A54035A54534A64733A64F2FA55E2D9E612F9460349B5A37A54C3DAB4045AD36
4DAE344CAC384BAB2F44AC283EAE2D3AB0393AAF3F3CB23C3DB13940AE2F44AB2648A927
47A83048A92C48A82D48A72F49A73148A9324AAA3546A83946A43F46A43D43A144449453
458A614383634382664281663F766A43686E56616E6B636C7A65647368636A66605D7E50
539D3458A71967990D7095066F9403709501749601729C016DA2066AA81167AE1B5FAE24
5AAA3059AB3355A53E51A244519F4850A3494AAB554AAB5246A9564CA652479F50419854
468E6044886F438F713E93743C9E703CA86A3EAE5B43B14D43BF4148C0394BB5344DB32E
48B12F49B13B45B14C43AF5145AD4B40AC4B4AA94A4CA4545CA4445CA33E58A13F589E44
5F92465F8D42608E3E62903861963B5C99415E9C495C8E4B55745354715B516B68666C67
795875855A70935768837160658B5073962D87900B888C157D86308982299B6840A66230
AB662BA46432A8633FA46D50A76D5F9A705D9C655AA35F56AA5D56AB5B55AB5B46AF603E
B86933BB6544BC5E47B169409E7440997740A28240A687408F864780834E878A4882974D
7DA3517AA3467A9F4180A83983AA3982AB397FA1397E943C7D99387E9D31809A1D84940F
888903867F00867A00857D018380027D82057D83057C80057E840981870A7B890B78800A
787908757405716E026D66006C60006860006460006461006D6700716E006E6C006D6C00
6B65006B62006A6300685E006052005B4C005A47005A4800554500553E00503D00504100
513E004F40005542005545005746005346005042004A4200504400544600554800564900
5444005644005345005849005648005848005345005445005245005242005040004F4100
5244005545005443005348005747005743005640005241004F3E00503A004C3900473600
4336004535004432004334004635004130003D2E003B2C003C2A00392600352300332100
301F002F1F00311E00311F003221002E1F002E22003224003022002D1F00261700211400
1C1400180F00120B000F09000C0700060300040100010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3E2E003F31004034004937004B3600513500513A00584300624D00695F006B76045E8C19
4C973C36946731867D2E7C86277493245AA03349A4444AA74F4CA14D4998364A94315091
365B91495D8A4D58854E4F80504C77574B6F4358863D5D9135658E287C7E208E721FA265
1FA75624AC4B2AAE412EAE3C31AC3731A83332A93032A83233A73535A63138A72B38A729
34A72830A92C31AA2C35A92F33A8382CA64626A84E21A95622A95A27AA4729AA4029A741
2CA64730A74431A64432A83233AB2734AC312EA7412DAC3C2DA7372F983E3196402D9F45
27A147289A4929A44828A04F2A8E57307C5D2A796127706A2168741D6A761E6877236478
246D781F727B1C757A23767B2D737B357273357D6A2B8763248E5E2396532C9A4B39974A
3996503098542A95582C985D279F6322A063249E63289D612E9E6530A0682BA26B279F6D
28987025976D239D6423A55A24A85027A9482DA83E32A73938A83839A83A38AA3C31AB3C
31A93E33AA4133A94434A94730A7532DA55A2EA35A2E9F5438A44C40A74144A93A49AA3A
4BAA3A47A93D42AA363FAB2C3BAD2F3CAF393DB0453EB1433FB03E42B03345AB2C44AB2E
45AB3448AA2F49AA3147A43849A33647A63A49A93D47A74045A044449D4644974B438B5C
42826A42816C3E806D3C816B3E756A46676D575F716D5E6E7B62646D675E5C6B5C538247
539D2661A40F6E97077392037392017295007299026FA10468AA0965AE1262B11D5DAF22
5BAC2A5BAB2D5AAA3A52A9424EA54A4FA65045A95F44A55F419A6445975F468F5C45895E
46826447816A45856F428176428C764195713EA56540B15042C04547C0354BB52E4BB42C
46B12F48B33A47B24A40B14F40AA563CA75945A7544BA7555DA7455FA53D5BA03B589B42
628A45668246638B4062903C5F98395E94455C964E5B8E52517E58527463516670686672
8861708F6069955E658477576A963E789C218A960F8E96198E842F9078268D65249B622A
A1622DAA6835A96B3EA0704D956E5A916C58A16A5BA86650A85843A85148A6523EAC5E36
B66B31BA6A3FBC6647AE64409B6C4098743F9C77409E793D8C80487F814F84834C808A54
7C93537E994C809B4884A03E84A63B83A834839F30849A297F9C23809D1883940E828E04
8A8501867C008274007C72007E77007C7B01827D008278007F7C00807A007E7900787100
757000736B006D67006B62006B6100676100625A00665E006C6500736F00717100716F00
706B006F6B006B6600685D006357005F4E005F4B005E4F005B4800574200504000533E00
513E00574100594800554800564A00574A00534700534500504800534800564600564600
5344005045005241005345005647005545005646005546005545004C3D00493B004B3900
4C3C00503F00514100534400534600554300534300523F004F3E004E39004C3A00463500
4533004330003E31004130004231004431004132003F2C003B2A00392C00382600332200
3121002F20002B22002E21002D1E002D20002B1F002F1E002C1D002A1C00281900201700
1C1300160D000F09000C0700080400040100010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3B2B004234004837005041005544005C4B005F4B00635200656000707100718905629C16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3C3300493D005246005D51005F5800625E006862006767006976006F8502719B0961A519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453B00504700584E005F5C00606A00616E00647602637F03648D076B960D68A4145AA928
3CA3512995792686892B7F85306B87304A934342984C469C4B4E933C528A365A8235667F
32747F357C8140748B4568943D63992B76941E848A1E88801D8B7D1C91771D9D6920AA5D
22AE4D26AF3D2FAE2C32AE2A37AC3033AA3734AA3936A83F37A73F38A93F35A73F35AA3F
36AC3F37AC4339AB3C3FAC2F41AC2A3AAD3633AD4030AA4F30A95A31AC5531AA5331A74C
34A54636A044379D4837A13A3AA92E3CA8323EA33B41AA353AAB3036A43733A23A34A83D
2EA8462EA5492AA64427A348299B52269254278E52258D552093571C985E1F9362278766
2D82682E816E2D8075287B7B256E7B25667E24737A24807424866E2491682898622E9B60
2E9F6327A16521A0651FA1611EA15D1DA35C1DA35E1DA36221A36420A36522A46422A260
219E5F28A1562DA24B2EA5402FA63C31A63935A33537A63239A9333BA53336A63230A635
30A93832AA3D30AB3F2DA84A2EA85833A95935AB5138AD463CAB4841AA4842AA4643AA43
3FAA453EAC463BAF463CB14B40B14148B0324AAD2647AB2649AB214BAA184BA9164CA81F
48A92B4FAB2C52AB3251AB384EA9394DA73A4DA9394CA33C48994247954547964B468F5B
417F653E736A3C66703F64754764745261755A5E7365626E686B65597C5E4B8A5855963C
679A187094067095037494007593007991007E95007F96007D9A0272A10768A80A5DAE10
5AB01A55AF2456AF3053AF3452B03E53AD4648A4584194653A82723B7574436A74486273
4E65754F6E724A776E3F78773F86773C9A743DA7623FAF5642B54848B33B4AC03250B333
49B3324FB43250B13B4AB34245B04B44AF5259AD425BA4425DA13963A23965A53569A438
6E9D3670913566923567913A6B9040688A4B5F8953588C59518B64567D65665972765273
8752748C5F688D695D8184407AA31991A719AE8B34A48423B8762AA7721CA86C24986640
A064559B69589D6D53A76B46A9673CA6663EAB5C46B65146CA5143BF5949B76357A85C50
AC5445AF6143B96746A763509961519C7237A0773EA37D499C7C4B8C80518292487D9F42
81A83680A620879D148C900E8C8E0D918A0A8F89058A8501888601858501858601828301
827C00817A008177008076007E71007B7000776B00776E007B6F007B73007B72007D7100
786E007569007264006D61006E5D006B5B006A62006A6900676900706A00707000707100
6F73007072007170007069006C62006C5A006553005F5100615300604C00604700574600
5643005742005848005B49005B4D005F4900604B005D4D00594B00594C005749005B4800
5D48005746005741005741005B48005C4C005E4E005E4E005B4D005A4700584400523F00
523E00513F00544700534500514100534200534000513F004F3D004B3C004C3700463600
4837004432004031003F3200413200443400463B00463700433600442F003D2E00372A00
3323003020002B1B002A1D00271A00241A00261B00251B00231A00221800221500191200
180C00100B000A0500060300020100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4B46005951005F5D006168005F7A0462850965930F68991370A11978A02069A02451A333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524F005C5F00626D01637F07609512619B216A992C6D94337593347097305B9E2C3DA040
299864208C80217A872E697F3751803E41874848894455893B65832C747B2B8570258B6D
1E8876247F832B778E29759123758D1E83851E8E841E93881D9C7E1BA46321AE4D29AF38
2FAE3136AC2B39AD273CAF253CAD2B38AE3038AD313AAE3239AD333CAC3440AC363CAB38
39AB3A36AC3B37A93837A93433AB322FAB3531AA3833A64138A44A3AA8453DAA453CAA40
3CA63E3AA43E3A9C483BA23D3CA6353FA93844A24043A8373DA8353DA23939A33837A73C
38A64337A44530A7432BA94D25A55621A16325996823986C20A06A1EA46A1E9D6C20906C
248C6C2B8770308772298370247D6F26766F257C6E26807023836F228D70249473269873
229D711CA3701BA66B1AA7601DA6541FA5551BA75E19A7641BA7641DA7631FA85B22A750
25A74929A73F2FA5342FA42F2FA72C2FA72E31A82F2FA9302FA93133A5302DAA322BAC39
2DAB3C2FAD3E2FAB402FA84A2EA95533AA5E3AAB5F39AA5838A7563EA55543A84741AC45
3DAE4B3BAE513AAE4D40B04B43B04247AF3848AD3447AF2E48AE214AAD184DAC174CAC1D
48AB2649AA264AAB2A49A92E4AA63447A83844A33D489D42479B46479B49469C4D438F5D
41826942776C42696E4262724960754C62735163735C646C5E70694F895A489D4C57A42E
6B9C10729B04779A017999007C97007E96007E97007B98007A9C0070A1026CA5095CAC13
5EAA1160AC0F5DAD1359B02054AF2A4FB03442AF413CAE4437A84E389E5C3B8D64428370
487D6F4677704181763C897B39987530A97135B0643CB05744B14D4DB33D50B13556B334
50B2344DB43947B04244B34D41B2613FB27054B04C5EA93E5FA5385FA83A67AA3461A638
62A03B659A44609340608C4362904C658252687754667F575C7F5D69735D855C648A5766
8854617E6659727458788C3D8791358D8923AA7F30A27525AC6D2AAC683DB36B36AA7843
967E558C78578A7057926754956451996552A86443B46135B95A29B45D2DBD6242B15D4E
B25049B05B43B76140A76841A2683B9C684E9A7855A48553A084558B8C5085A3318E9E1D
8F900F8A88058A7D018B7F008F82009185008E8300898100867F00897E00867D00837A00
807A008476008075007D73007B7100786D007A67007A65007C6B007D7100817300837400
8274008077007A75007B7900797400756D007167006F6C006A7100717700767A00767300
7672007577007477007071006D6D006E66006E63006E63006D6000645700675700645600
644F005E4E005C46005C4A005F4D00614F00625200665100645200615200614E005F4F00
5F50005E52005E50005E4C005D4D005F4C00624D00614F006350005F4B00574400554300
5744005645005545005543005846005747005548005647005645005544005340004F3E00
4A39004A37004B36004735004433004231004231003F32003E2F003E2F003B2C00392700
3425002F21002C1D00281B002419002015001C12001B11001B1000191000190F00130C00
1008000A0600050200010100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
556608577B0F598F1A5C9825619F3263913C6F884174853C748D3A6B992C51A62E33A34D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5A891A619225678E2E6C89337682407D78467E704280723A768637659E3041A53E2AA15B
209872208E7725827B2E6F7732597B2E4C7E34527E2C6180247781239175209C691C936C
197F771A76841775931A818D1A8B84189A781CA16E23A56029A95230AC4138AF2F3FAF26
44AE2245B22349AD2748AE2C41AE313BAF343BB0323CB1333FAD3442AC3742AE3E3AAB48
33AA502EA85131A74D30A74731A64132A53C35A73E39A8413BAA463BAC3F3DAD383BAC35
3AAA373EA8383EA73F40A83A42A93243AB3348A73C4AAC3348A93244A83843A63D3FAB3A
39AD3936AB3834AB382BAA4326AC4E25AD5125AA5922A56220A9651FAC6720AA691EA76B
21A26F259971268F752386751F84771F82741C87751D8A731E8B741F8B7A1E8C801D8F7F
1A967A19A2721AA7671AA75F1CA8561DA8591DA7651EA96520A95F21A65923A64C24A842
26AA3C29A8362DA73431A7312FAA3231A9362CAA352AAA3329A7332CA6342BAD382BAF40
2DAD452FAC4630AA4131A2422EA14A34A3583BA55E3CA75A38A75A3BA7543DAE4C3CAE4F
3BAD5A40AC5340AD4340AF3549B02F54B12454AF1F53AF1D53AD1853AB1153AD1455AC19
51AB1F4BAB2547A82845A82D4AA72F48A53543A13747A43B4AAA3F4BA845459E53418B64
417F6F437F6D46766E466D6C456B7045676D4D696A5A6A6864736656935551AB3C5DAB21
68A4106BA8096DA80970A70976A50979A1097A9D087A9D037D9D017BA30172A70960AB14
5DAC1A59AE2455AD2451AF1F4DAF214EB1274CB3334BB53447B83543BC393FBB5239C05D
39B05937A56234A16B31A0713BA36C3AAA6C3BAC6444B15A48B6524DB4394AB12E54AF28
52B2274EB53543B04B41AE5543AB5B48AC6259A7495B95445D9D405EA14961A2485EA350
5D984E60844C5E864A5C9350609A46648B476981536684595B7D657374629A63619A5F63
905C63796A6060845D728E3D92893392793DB26B38BB5E3AAB62398F614E8166577B6D57
836D5C8D6E5E9E6B63A96A5CA8624C966348856A57897363A271649F6949B75D34BB5549
B24B61A85D57AC6354936B4C9B6A49A16F4E9D79599B8354899F2D8D9D1993900E928704
9086009383008E84008D8100897A00867900877700847700867B00888100847F00847C00
847C008379007F6F007E6D007C6A007C68007A67007C6B007E67007D6B00806D007F6F00
7F7200847500807900807A007D73007E6F00756C00736C00746F00727400757700777D00
777800797900767700707200716F007066007163007161006F61006B5D006D5900655700
5F5100614D00644D00635000634F006553006856006A5800685900655800605100615000
5E5100604E006250005F4B005C4A005D4E00624F006252006350005D4A00594500564100
5844005746005946005A45005A4600594700594500564900564400554300554500554100
4F3D004B39004735004833004733004B3500493800473400412F003F2F003E2B00382A00
3627003223002C1F002619002216002016001E15001D12001A1300150D001109000B0600
060200030100010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
678E41737C456F72446E7548746C547E644E82693D8672337C892A609C2D3AA14A299E6B
249B7925957B27857D2A75792C66782B5C7E2C5F81286586256D84237F781F8D721C8D72
187B7B167086146D931A838F1D96821BA47620AA5F2BAB4537AE383FAE3241AF2E48AD25
49B0214AB3204DAF254EAD2A48AC2F43AD3142AC3444AC3145AB3246AC3741AB443BAA56
33A7622DA66330A75D34A75534A54B37A2463EA54541A84540AB453BAC3B3CAB3537AB36
3AAA3940AA3A43A83E41AA3845AC2F47AC304AAC394CAE2F4BAA2E4AA63645A63C42A937
3EAD3A39AC3636AA3732AB3E2DAA412FAC402CAB4728A85028AB5524AB5924AD5A24AC5D
24A96527A16727976B248E71228A71218870218F6B21926B23936B23906E239171209174
20996E21A26520A95C21AA5522AB5226A95427A95A2AA85D28A65727A55528A74A29A842
28AA3D29A93B2EA83B30A63631A93730A93B30AB392DAB342CA8342EAA352DAF3B2EB142
2BAE4B2DAD472EAA412DA3452DA44C31A55738A45B38A95738A95639AB5638B04F39AF52
3BAF5A3EAB4F40AD3942AF264AB02353B11D53AD1754AC1A54AD1954AC1A53AB1C54AC1E
52AB214DAB244BA92848AB2C49AB2C47AC3047AB3346AC3746AE4048B04C419E5C3D856D
3E7C70427A7046756F44736B437269436B68486C68546F665B776257974657AE2A5DAF1F
5FAD175CB01662B01762B11467AE1566A9156DA91171A60A71A30374A60270A80669AA0F
61AC125DAD1955AA1C52AD2150AE2253B02051B0224FB3274DB32F4CB73245BD3A3FC047
39B34D34A05E309D64329765399D5F41A85844AB5546AF504CB44C4CBD344CB82354B421
4FB5234CB53248AF4646A9504BA4534CA3525BA2445A8D485E98465BA04D5F9D4D579D53
5C99525E844D5C824E58924E62984268904361914A5A9058527D6F74716DA0656F9D5F6E
955A6F7A70686196587C95399B8527A27631B06733A8643A94624D826A59757658777254
8869559D6056A26058A86054AD5B4CA15B4A936456916665946365956355AF6047B75755
AD4E64A55F58AA66489B6D409E6D40A1724A9A7F4F8D953B8A9E1E8D8E0C908202948200
8F83009181008D83008B8100887B00877700857B008878008C7D008B7C00897E00877B00
817D00807900817600816E007D68007C6800806800816A00816D00826A00816E00826F00
8470007E71007E75007A6E007A69007869007A6800756600706B006D69006E6F00737300
767200777500767500757500747000716C007063007362006E60006D5D006B5E00685800
6454006353006253006856006955006B5800695A00685900685700665700645300635100
635000614D00614F005D5100604D00624E005E5300635300655400614F005F48005C4700
5C46005C49005E4700604A005F4B005B4C005D4B00594A00594600524100534000544200
503D004E3C004D38004A37004A3600483800473700483500453200412E003F2D00382800
3325003324002D2000261A002118001D13001C0F00181000160F001209000B0700060200
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
757E467B72407E713A776940795D468259428866388C7533788C2C559D363AA1552DA071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875D4189604182653F70634C6C5D5678594D7A6F3D7C812D66952E46A04235A2602FA27E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8A563E87564077583C6D583C735B427D653C7C762E708D2B5597383B9D5531A06F2EA07F
2FA57F2FA376319C683097662B936E288C7B277F82227587246D80288C6A289D691B9E7F
189288158586167F811A8A7E2299752A9F6E2EA85831AD3F37B0353BB1363CB13945AF36
4BAD2C4EAA214BAC214AAE2748AD3147AC3F49AB374AAA2F4CAA2C46A83340A73F3EA945
3AA84A3AAB443BA9403FA7403CA94241A64A42A74942A74942A94A42A93F45AA3744AB3F
43A94442A73E41A73F40A54441A54342A74643A44745A94045AB3E49AB434EAC434DAD38
4AAC3146AC2E44A7323DA43836A34332A8472FAC462CAB4728AC4728AD4E29AD5129AE4A
28B04728B0462AAE4829AF5029AC5427AA5A27A76228A76A29A66729A4692A9E69289766
299164289B5D29A15A29A45A27A85A27A85B2AA6592BA8552BA9532BA8522BAA4B2BA948
2DA9442FA74133A84234A84233A74033AA3F2FAD402AAF4229AE492AAC522AAC512CA457
2BA2562AA55528A4572DA2602FA16231A66635A56437A65937AC5533B05636B15737AE58
35AE563BAE483DAE363DAF293BAF2A3EB1273FB02C3BB13137B2353AAE3840AD3745AD37
44AC3745AD3C45AF3848AE2F47B02D48B23843B0443FAE5136A95C34A16A339571338875
328772388A763B89723D876B3C826840746B44776B45856449935458A3385FAB2357AC2A
55AE2D54B12859B02759AF2C59B02D55B03652B03D53AF4053B14058B33959B02B61AE18
68AD096DAD046EA9066CA90C69A81167A81062AD106AAD116EAE106AAD0F65B01159B114
56B32353B03751B03F51AA4F51A9564EA15D4DA15752AD4F4DB74650C0374FB72D54B627
51B22553B12C57B23256B03C54A73E4F9F4956A24E579456599F5053A55250A34B509C4B
549F4257A241539A43578E5358825F5783625C7C6760696F68527A775A79925E7890626F
8C5E687C7C557A9A3A908D30A47737B36047AB5D41A1554686645C76705E76755E7C7F5C
92745FA46F5FAD6852B85F44B75E4BB65A4AB75A3EBD563EC65348BC5551A7575CA65D58
AF6657AC6F53AC7555AA7D51A0834F838E478C9222898106867C01887700857900897E00
8A7D00887D008678008A77008B76008F76008E7A008D7C008C7B008D77008C78008A7900
8B77008A78008C79008773008670008974008672008275008875008974008A7400877500
8678008375007E6A007662007462007361007C6B007B69007A6D00746C00756D00717000
717300757A007778007879007777007775007773007B73007E77007B7800797600797500
746E007466006F5D006C5B006C5A006956006A5600665200664E006752006A5500675600
675A00635A00635600645500625400635300655600675900645D00645900685700625000
5D49005A4800584C005D4D005D4C00594C005A48005B4700574C00564300544500534600
5047005043005243005144004F41004A3C004737004331004030004131003D2D00372C00
3225002D1E002519002115001A1200160F000F09000D0700080300050100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7E4A557E4555764D46715344715F4F796B447B7C30668F354D94443499632D9D772CA081
2DA57E2CA7712CA9642CA65F26A3682A977528887E257F7A287C702D9D5A2EA45F1FA47C
199D8514918015887C188B7F239A722BA16C2DA85631AD4138AE3938B0363DB03246AE30
4BAC284FA8214EA7234FA82A50A7344EA53953A73157A72A55A7264FA72E45A63841A83E
41A94440A94040AA4043A63D41A34441A44A44A54645A64446A64148A7394DA7374AA63B
44A84245A93F3FA9403DA7463FA64841A54843A44A45A74249AC404BAC434BAC3F4DAD35
4FAD2E4EAB2B4BA531429F3A3B9D4535AA4733AC4732AF432CAF442CAE482EAE472FAF41
2EB13F2FB13E32B03E34B24136B14632AE4A33AB5331AC5630A75C2EA4602FA0632E995F
2B945E29975D279960279962299D6229A3602AA4602CA55B29A65628A75227A94929A844
29A84031A73E34A73E34A94137A84033AB432FAE472CB0492BAF4828AF502AA95429A45A
2A9F5928A2592BA15A309D5F2F9E6030A26133A56035A65D35A95A33AE5934AF5930AE56
2FAF5233B14538B23A37B23036B43434B43138B43433B43B32B24135AF423BAE4040AE42
41AE4242A94943AC4245AE3747B13746B04144AE4E3AA85C359E6034936B339071348A72
328F75348F76378C793E89713E8369417B6B427F68438D61459E5357A7345FA9225AAD25
56AF275AB2245DB12558AE2B58AD2C55AE2F52AF3252AF3651B33955B33755AE335BAE2A
60B02266B2156FAE0F70AB0B6CA8066AA70964A90F66AC0D67AC0D68AE0968B20863B00A
67B2145CAF255FB2325DAF4554A6554A9B614C9C5F4BA95149AF474EB1404BB23556B32E
54B12D5BB3275DB2285BB13157AF3B51AB4352AA4354A6465CA44854A351519E4E4F914E
4E914D53994E529550538458517863507C6C55767567657C7C537F7F5A788E5F768E616D
8B61697C7D527299338A9027A27A32A2653F9A62488E63587A785B7388577988527B8C51
8E83549E735AA5694DAE603EAD5B3CA25A3F9A5E3BA35E36B35536BB573DAC5B47AB674A
B26A4AAE714DA77651A47E4F9B814B7F9533878A168677028471008975008B77008C7800
8D79008A7B008D7D00907C00917D008D79008B7A00897C00867700877100867600877300
897300887500867300867000877000886D00846F00847300857A008C78008B7D00887A00
897E00887A008274007F6E007A69007668007466007867007D6C00756F00746C006D7100
6F7500737800767C00777E00767B00777D007778007A76007B77007C76007B7800797300
766D007369007364006F60006D5D006C5A006B5A006C5A00695700675500685500675A00
655900655B00685E00695C00685D00695B006A62006760016661006A5F00655E00625600
5C4F005C4B005A4B005B4E00604A005E4A005B4900574400574600564800564400544600
5046005142005044005246005245004E42004B3B004134003F32003C2E003B2D003A2800
322400281D002517001B1400181000120A000A0600080300040100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7C5052794E4A75533F6F5C386A653E6A6F4068803D588A44498E5A3594762F977C2E9D7F
2DA3782BA96829AE5B25AB5228A85A2A9E6828956E23916B2791602AA3522BA85A22A777
1BA27C149A76169376189676239F6F2AA06630A85036AD413BB0383BAF3845AD3049AB2D
51A8294FA6234FA52752A63055A53055A53156A62D5AA62959A6264CA72B47A83543AA3E
40A9423EA9423FAA4444A349459852449758449D4E46A34447A73D48A7384BA6394BA840
46A84441A8433EA6483BA64D3EA54940A54642A64849A93C4DAE3D4CAD404DAE3B4CAD37
4EA9314DA53049A33544A03F3EA0413AA84132AB4231AC402FAC3F2EAC4030AB4032AE3F
30AF3D2FAF3932AE3A34AF3F38AF4135AF4633AE4E34AD5533AA5B2FA5632D9E652B9366
268C6526876924896D238470238C71269571269E6D26A16626A65E26A95724A84B27AA41
29A93D2FA73B32AA3B34A94034A84232AB472DAF4D2FAF482EAF462DAC482BA64F2DA156
2D9F572BA0572CA05B309A5D2F9C5B2CA25D2CA55D33A55C31A95B30AD5A2FAE5B2FB054
2CAF5133B24835B24334B23D31B43D32B43736B43535B33B34B34136AF443BAE4540AE4A
41AB4D41A75241AA4C40AD4742AC463EAE4C3DAE553BAB6036A562339F63339C6931956F
309272339177368D7A3D8A723F886B3F806C3E85653E945E43A75155A93060A91E5BAD21
5BAF2358B12559AF2457B12955B12956AF2B52AF2E52B02F4FC0354FC03852C03C53B33A
55B4395EB22E64B11F68AF146AAC096DA70669A80969A8086DAB086EAB0572AC0571AD06
6FAD0B68AE1465B11F5FAD345AA74B4E9A624C99654FA25653A35055AA4256B13C5BB234
5DB23362B32361B11E5EB4275AB13454B03F56AF3C56AE3858A842559F50549851528C54
558C525593565193554F805A4D736350756E54747968627E8D518086577C8E5A738A5D73
885F72787A587290319B861DA07425945E398863537B755C76885371974A6C904A758E50
8281589568659C5E53A44F3EA54D3C964C4090614D9F674AA5582ABB552AB1573DB1613E
B56944B17248A97947977F4594824485961D84820C8878018977008A78008D7C008B7B00
8E7B00917E00917E009080008C80008E7F008B79008778008873008873008A7400897300
8973008773008673008974008B76008B72008570008573008B76008C78008C7C008A7E00
877B00887A00867300816F007D6D00776900736700766C00796B00756B00766F00737400
7076006F7600717B00757F00778100787F007A7F007C77007973007A7600797A007A7400
777000767100786C007366006E65006E62006F66007266007264006E60006C61006A6300
6B5E00685E006A60006B61006D61006C6800686B01666D02666A01656800696400656000
6259005F55005F50005E53006051005C4E005A4A00574500564500594600554800564500
5442005544005545005445005143004D42004C3C004534004030003B2F003A2900372700
302100281B001E1300190E00110C000C0700070300040200020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
8255497E57476E5E4069693D5F6B4A576F545B794E4F8155478464378A74339077319872
2EA06726A95527AF4B29AF412EA74A29A05E259C671E9C621F9F5621A64E25A75924A870
1FA76C1CA36A199D6E1D9F7523A16A2AA1612FA84F3AAC403CAC3F42AA3A48A8304EA72A
52A5294DA32949A32C54A23055A32F54A42C54A42A58A52757A52652A62A49A93346A53A
43A83C40A93C43A94149A347509C514C9D534BA34748A73549A82D4BA72E4BA83447A940
45A84943A64C40A44D41A44F44A44944A74544AB424FAB3B4EAD3B4DB03D4EAF3B4DAF3E
4CAA3F4BA9394BA438479F3A419E4039A54035A94034AC3F34AC3C34AA3E36AA3935AD3A
32AD3C31AC3A31AC3B33AE3E35AC4435AA4B34AA4F32AC5832AC5F30A66A2D9B6F2B8C6E
28836F2A806D287F71267974248374249172259D7525A26F24A56623A95C23AA5025A944
26A8402CA83C2DAB3B2EAB3F32AA4330AD4A2FB04F30B0492FAE4330AA472FA64E30A155
30A0552D9D592E9A5D32955C2E975A299E5A2CA55B2DA65E2FA85E2DAB5D2DAE5B2BB057
2DB05431B25034B24934B64536B34536B33F36B33C37B23C36B04335AE4638AE4A3EAE51
3FAC573FA75840A7553EA7533DA7543CAA553BAF5E37AC6033AB6031A95D2FA3632F9C69
309871329476338D7C378A7A3C87733E806F3C88633E9B5B47AB4958AA2B62A91E60AD24
61AE225AAF255CB02458B22955B22B50B72B4FB22F4DB1304FB93152BA3752B33A54B340
4EB24A57B1425BAE3562AF2465AE146AAC096DAB076EA70371A70372A60277A80178AA01
78AA0677AC0971AF1567AD2560A93A56A55450A06254A25855A05157AA4B57B14260B03C
60C03865C02260B31B60B3215DB33155B13B55B03555AF3856A2445692535390554F8F59
569056569654519751508C5B4D7E634E7E6C5175755D697B7A578082537B8F5175825972
765E79727956788E308F85309C763E9A684F7F7956748B567495486E99416A904A6D8E58
79825C8D6B679B6453AF5348B34D42AE4E409A6048966046A76133B95A3AB65149B15E4E
B8684FB07249A2784D8F8D418A9138858E138580048579008779008A7A008A7F008E7C00
907E009180008B82008E7F008F8100917D008F7A008D79008976008B76008A74008B7800
857B008776008977008A78009081008A7B00847500827000806C00857000877400867500
8272007E70007D6D00786C00796C00766900756B00766D00746C00726B00746C00737300
6E75006D78006D7F00738000777F00797E00797A007675007770007872007977007A7500
7A74007C7100797000776F00746A00726600726B00756D007769007363006D6100696200
655F00685D006A61006A64006C69006E70016776066375086176096575066C70026B6D01
6B6600665F006257006159006155005D52005A4F00584D00594A00594B005B4800594700
5447005444005246005346005145004D41004B40004536004030003A2C003A2700332800
2E2200261A001F1100140C000D0900080300030200010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7E5D517562486B69456370485F6F4F606E515D754C53795C44796A3A7F72368875309466
29A25523AA4523AF3B2BAC3534A83F2DA25723A1611EA45C1DA6551CAA501EA85A23A56D
20A4671DA56922A06C22A26A26A45D2EA54E37A73F3BA93840A63B46A8364CA92C53A82A
53A42C4EA22A4FA22C52A32F55A62D53A62D53A42F57A52D57A32A55A62B4CA63244A73B
3EAB3C3EA93A45A83C4EA6474FA2474CA54645AA3C40AB323FAA2F44A83444A93842AB43
40AB4B3FA8503FA75044A35046A74746AA3F48AD3B4FAB3A52AF3A4FB33C4DB23C49B13F
46AD4646AE4449A73A4A9E38479F3B43A5403CA93F3AAB3B35AC3737AA3A36AB3A34AD3B
33AD3B32AC3B32AE3B34AB3E37AA4237A94434AB4835AB4B33AC5232AB5D32A4622E9961
2D91612D935F2D94632A9167289567249C6526A16624A46523A66025A65725A84F26AA47
28A7422AAA3B2CAD3930AB3A32AB3D32AE3E32B14431B04430AD4432AB4931A550329D57
329E59329E59309A5B32955A2F955A2B9959299E5B2EA15E30A75E2DA95E2DAC5C2FB05A
31AE5731AF5532AF4F33AF4F36B24B39B34838B44738B44535B24834B1463AB04A3FAF55
3FA95C3BA3603BA05E3CA25E38A45F35A76231AC6130AB6433AD6331AA6330A463329C6C
33977035947534907A358A783A88773B84723B8A683B9F5642AD425FAC2864AA1D61AC1D
61AD1C5CAF1F5BB22258B42556B42853B22950B22A4BB82B4DB82D4BB7304EB1364CB343
4BB15654AF5458AE505FAE3963B01E6AB0146EAC0B6EA70470A40179A0007CA2007DA301
7DA40277A50678A80D6FAE1C63AE2A5BAC4B54A85B57A357599D5B57A75155B04B5DB044
5AB1425EB22C5DB11D5CB2225BB32D5AB33C57AF3C52AB41539D4E53865650845F4D8765
508D614C935C4C955E4B8F684A866F4B7C6D4D6A7359677B6F57837D527D8F4A6F81576E
685D796B7755808035A27548A56F54A069637D8564698B616A8E5B6E865A6B7D5E677868
76726A8D646AA55F54BE563BCB513BD05238B54F41A95144AB6142B26149B75655B26158
B46C53B0784BA47E4C869A3D7C9B25838B0B888201897F008D7C008F7D008D7A008C7A00
917F009281008E7E008C7C008E7C008C7D008A7B008C78008979008776008B79008B7600
8A7600887500867400887B008C8000887D008278008073007D6800826C00887000847000
7F6C00806E007E6E017A6E02797003777703767801797C017B7C01767300766E00726D00
727400717C017280017881017B84007A8100787C00747900767300766D007671007B7400
7973007D7600787400766F00746A00726C00756D00756C007469007268006E61006B5F00
6660006A60006867006E67006F71006D780467810D60830F5C83145D7E10607B08687703
666E01686500626100625C00625A005F54005F51005E4F005B4C005A4A005A4800574700
5244005245004F44004E44004F41004C4200483C00423400402F003B2A003424002E2200
2C1E00251A00181000120B000C0800070400030000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7368596D665E6B65636A686368695E6C6556626E555970614772704075743C8077309369
29A25322AB4328B0392EAF3633AB3E2EA55229A35924A35A1EA45A1AAA591DAB601CA56E
1BA56B1DA56D23A36C27A9612CAA4C31A94037AA353DA73241A63545A8324DA8314EA732
50A3324FA030539E3357A13358A63158A72F56A33257A13553A1344EA53646A7393EA840
3AA73D3EAA3847A83D4DA7434AA54345A84141AC3B3CAC353BA8333DA63D40A74040AB45
3DAB483FAA4B42A94547A74649A93F4CAC364DAE324FAB3350B0354DB3394EB23D4AB03F
47AC4249AC4049A63E49A43C48A43947A83943AB3A3EAD3739AD3635AC3A36AD3B36AE40
33AB4433AB4034AB4035AA3F39A94039A94037A74337A84636AB4D33AB5532A95D2FA361
2D9E5F2EA25D2CA3622CA2642BA35E2CA25E29A16029A36128A45B27A65528A85028A94D
29A9492BAD402CAF392FAF3B31AD3931B03A33B33E32B14231AD4831AA5032A356309A5B
309D5E2E9D5D2F9A602E935D2E8F5D2C905B2B975C309D5E2FA05E2EA45E2FAA5B2EAB5A
2EA95930AC5732AC5133AC5034AD4F35AD4F37B04D37B24735B44637B4433AB4443DB44F
3BB05838AB5D37AA5D37A95E36A95C33A95830AE572FAF5A32AD6230A76031A362329F63
369C69389971379674388F76398975368575348D653C9F4A4AAD3461AC2067A91C67AF1C
6AAF1D67AF1F66B02160B5225BB82657B52257B72353B22452B8274FB92B4AB1364BB344
45B2584FB15959AE575CAF435FB22A66B41B6AB0126CAB0876A702799F00809E007F9D00
819D027A9C0579A2086CAC126AB0215FAF395AAD4A59A64F59A35A58A85356AF4E59B147
58B1405CB52B5AB41F57B41F5AB13056B03B55AE3F4DA54D5296524C815C4C80664A826E
4B8D67479B5E4BA05C4C9B644B936F4C866F4D70785C667973587F8154778D4E7282576F
685F766B76558682399C76409573528B71617E7F5C737E5E73865E75865872845E6A7E69
7A7470956171A0645BB25735BC5A30C65A2FBB5B31B15A38AB6944AC6D4BAC654BAE674B
B57047AB81459D824A839F2E829515848606897D008F7F008E84009186008D80008F7D00
907D00948200908000917F008F7D008D7F00897800877A00877800847600857600867200
867000816E00816C00817400847A00877D00877A00857500836D00846A00876E00847300
846F01837A027D7A0675820A79880E798D0F798E0A7C8F09788E08778703767E03777701
7379006D7D026E8405728403768400768300747E00767700767100776C00776D00787100
7D78007C7400767100766E00746A00746D00746F00756D00746A00736A00726600706700
6C68006A6A006D6A006D6F006D7801697F0B638B185B921A57911C5B8E175D8A0F67820C
697C06686F03676902666601666100645C006356006050005B4D005D4B00574800564400
5041005143004D41004F41004C40004A3D00473A004434003B2F003827003421002B1D00
271800201300180D00100700090300030100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6A63807259876D537F7156736E5B64745F556868555B70604A736F417578388378319769
2AA85326AF472AB13E2EAE3D32AC4630A94D2EA5522AA55423A75B1CAC5C16AA5F18A56A
1BA46B24A46C2AA46630A95036AB393CAC2F3FAB2B40A72C48A42E4EA42D51A82D52A52C
57A6305BA42B5CA42C60A52B63A42962A32B5CA33058A3334FA33C4CA33D44A53E3BA73C
3AA83844A6324BA6374AA63B49A63A46A83644AB333BAA373AA73B3EA64643A74440AA44
43AB4440AC4143AA3E48AA404BAC384BAD314BAF2D49AE2D48AF334AAA3A48AB4345AB44
44AB4048A7404AA63F47A63C47A93843A93543AA333DAC3337AD3137AD3739AC3C38AA43
34A84534A94435AB4534AA4739A7443AA6413AA34138A34434A64B30A8562FA85F2CA666
2DA3662DA6682EA56E2DA76A2FA56131A35C33A25B30A55E2EA55C2CA55B2EA5562CA754
2DAA4D32AB4232AB3D31AC3B34AC3B33AE3B32B04130AE4A30A95232A8572F9E5F309560
3099602F9D5E329761328C612F875F2E865C2E8E5C2F94612F99612D9E5C33A25E32A15E
2F9C5E31A05932A35731A75630A6592FA45A32A75435B04C37B34936B5423AB6423BB44A
39B45532B15D30B05E33AD5F33AD5D30AA5B30AC5630AC5831AB6231A86131A65E34A160
35A067379E6A3A9B6E39916F358B7231897133935A3FA33E53AE2364AB1967AC1668B018
67B11869B01B67B01C61B61A60B51E5CBA1F5DBD1D55BD1F54B81F50B6264CB72B44B23C
43AF4B49AF5551AD5A5EAE4762B33A63B22F69B01D71AC0F79A80980A100809D01809B03
7E9B02809D037CA70872AE0E69B01C5FB12C58AF3C59AA4D54A66153A85850AC5953AE48
51B23B56B62954B32154B42157B12D53B13E4FAA4B4D9B594B8D5A48805B497D634A7D6A
4C8C62469F5548A5554C9E604B946D4A8B744C747E60637A79537988537A8F577B7F5975
635B766B705387812A946B3A846B598E6669826C637E66607B765C778956728D5C6F8663
827571A96375A86063AB5936B45E2ABC6124BF601FBB6324A7673DA2654AA16A3CA46A37
AB71359F8338908942889F1D879108878502867E008E7B008B80008E87008E80008B7400
8D7800917900907F008E81008E7F008E7D008C7800877800877700887500857800857100
856D00836D00827200827800817900877E008C7E008A7A008B75008974008C7900887F03
8582057F8C0878940C78990E789A13759B15769C1176990C71960A759505759504758C03
718A056C85066982066F8503738001738000757C007778007A7400787000776F00787200
7A77007977007875007571007672007573007771007772007571006E70006D70016D6E01
696F016972006973006A7600657D035D8A165A9726579B2E599F2C589D275898225B9418
6389125F810C607608626E056265016560006159005F4F00594900564500514500514100
5041004D40004B3D004B3E00493C004739004436004030003929003424002F1E00261800
1F1300191000140C000E0800090300040100010000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
694B6A63416A66406567425E6D495B7F5B516C6A4D5D735A4D756F46767F37877A309E67
2BAA5427B04A2AAF442FAC4530AE4934AA4831A9452CA64B23A7521CAC581AA8611AA069
20A06825A2682EA55E35A8463BAA343FA82D40A82847A7244EA42658A5245AA62258A726
5AA5265CA5285BA62959A72A5FA62A62A3285BA32754A5274EA82D4BA93147A72C41A62E
3EA83245A73545A53D47A43E44A63843A93343AB313EAA393CA8403AA5483EA8473FA843
42AB4147AA4046AB3F49AC3C48AC3545AC3244AD3245AD3343AC3743A94241A84E41A64B
43A84349AA3F4CA93F48A83B44A83B43A83842A83840AA383BAB353BA93A3EA8403FA541
3EA44338A44437A94A37AB4E3AA7483AA444389C44399E4635A34C32A75230A9552FA753
2DA5552FA55830A65D30A55B32A35237A04D3CA04C38A74E35A85234A75634A95236A94D
35AB4836AB4035AC4033AC4034AE4233AE4430AE4D31A85234A85A33A760319F66319764
329C60329E5F349760358B6133836033835E328E5D33946131966432985E33995E33985D
2D9660319A5F2FA05A30A45C2FA15A2D9E5A32A55731AC4F35B54A34B44337B34136B347
35B64F30B55931B25D30B15D31AD6030AA5E33A95D32A95E33AA6135A56037A45C3AA25C
37A16439A06A3B9B713B8E72348C703088703894554BA72F60AC1565AC1368AF1665B317
67B01865B01C64B11B5DB3195DB31B63B41D61B31C59BD1C55B81D53B6224EB7264AB12F
45AF4049AE4F4AAB5E52AC4F59B2485CB13F62B32C6CAE197CA90C829D00809B037D9B07
799B047B9D0277A4066EAC0867AD185AAE2A56AE3652AC4C50A7674EA65F4FA0624DAF4D
52B23A57B52F53B42452B62252B02E4CB0414DA455498F64468363467965477C6747836A
448F64459D57499C584E93634D8A724C847B4E717F5E617B7D5577855477895A7C7D5F77
6361736A745283883389764286745389756088735B8F6B57807A557A8850788456737A5F
837162A86060AE5B54AE5640B05D3AB4612EB96522BA6421B4623BB2654DA6703FA57639
A7793E9A874188993E8CA1188B8F018B8400887D008778008B7A008E7C00887700857200
8973008C74008C76008C7A008D77008C78008E74008A75008B79008A7D008C79008E7700
8C7700877500827800847B00857900897E008C7E008A7C00897B00867C01898604848A0D
808D0F7D990F7B9D1276A21579A61774A61A74A217719F11749E0A729A017597016F9A05
6B9E0B69920C6486076784056486056B82017182007684007A7D007C7A007977007A7700
7678007A7D00797900777500767600767800767B007779017477016F75016E74026C7804
7078036F7D036F80036C860661900E5D991D59A12C59A32F5CA5305EA42B5CA22B5A9D24
629518648D1362821064790C646E06636A02625E006053005A48005545004F42004C4000
4E3F004C3D004B3A00483B00473B00473A004334003F2E003526002F2000271A00221500
1B0E00170C00130A001107000A0400040300030100010100010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6F2E6663295B682A58732E52853A578C554C6F67485D6F5C5270724B70803C837B319E66
2EAB502CAF432FAC3E34AC3739AE3435AE3234AD322EAD3729AC4223AE4F20A75D209F67
249E6A2A9F6831A5563DAA4042AA3245A92B49A82352A51E5CA2215EA41F60A61C5FA51E
61A62161A4215BA7255BA82562A52764A5235DA42056A62053A71E51A82053A9234BA827
4AA83248A6374AA14348A34145A73744AB3044AC2E40AA363FA73F3EA64B41A84840AA41
46A83F4CAB3C4DAD394BAB374CAB2F46A92C47AB3246AC3C45AD4343AB4E40A85641A74E
44A74049AB3A4BA83C45A63A43A63D40A6403FA74140A5403DA63E3EA73F40A44341A242
40A5403BA84239AB4536AC4939A8483AA4473CA04538A04A34A45232A65331A74C30A648
31A34733A84835A94D33A94A36A64539A6433CA3433CA8473AAA4D36AA5236AA5039AB48
3CAB4639AD4038AF4035AF4335AF4931AB522EA8592DA46133A56534A66C30A26C339B65
33A06135A161359B5E348E5C36885E368C5E369460369762359667339461339A5D329E5F
2FA15F31A55D2FAA5B2FAB592EA9572DA5542EAA5031B04936B44335B54033B5402FB541
32B44732B4522FB05931AF5C33AD6033AC5E31AB5D34A95C34A75C36A25939A0573B9D56
3D9E5F3A9C663C956F3C896E378B6937906B409C5159A9296AAF1268B21368B31865B31A
67B31B67B11E61B21F5CB21C60B41C66B41F66B5205DC01D55B8204FB92051B6204BB627
49B33147B24147AD534AAF544FAD4F53AF4A5CB24265B02F73AD187AA1077F9D067E9B04
7F9902809A007E9E0378A6086DAD1263AD215CAF2F53AF4849B05947A55F4998684DAA52
54C03C56B62E52B5254EB5214EB13449B04D49995C4B806B507669496E6A467B6B408A6D
459268459264448B6553826D52797A4F79804F66805C617D715A797C5A78815A78716474
5E716E757F4E93833490684E85625E8A67698B6C658C6A638072607A7259796D5A73625F
806258A85E49BB543FC84D38BA4C42B14C40B25B2FB86222BE5E39BE5E4CB07241A27F41
9E824A8B924E7DA6368C99178D84018A7E008A7900877800877900897A00897400887200
8B72008972008C73008B71008F74008C7800907700907A008D7B008D80008F7F00947F00
937F008C80008778008777008575008B79018D7D02877E038A820683880B84910D819711
7E99137A99167BA01977A82076AB2178AF1D77AF1A75AD1B73A61575A41374A8136DB013
66B31366A70F609B106092126691116B9111708F0D74920B7C8F067F88017E84007D7E00
7B7D00787B00757800747900747B00747900737B02727C047178046F7B036E7C056E8108
7086096A880B658D0A60981458A12056A82E5AA4315DA1355F993B60983D5D993B5F9E34
619E2B64962C638E24628617647B11636E0A6262015F5A00584E005249005141004B3E00
493C00483700463900483B00463B004339004033003A2A003421002A1C00291A00231300
191100180D00130D00100A000C0900080400050200040100020100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7927616D2956732C527D30527B345079553C6862515A69675569784D6A843E7F7D359B69
31AB532EAE4234AD383BAD2C41AD273CAA2433AC252FAC2C2BAD4029AB4D27A85F259E68
279A6B2C9D653AA55643A94148A9344DA92B51A71F5AA41763A31A64A51D68A61865A41A
64A41C60A51D5EA41F60A32263A31E69A31F63A31959A21752A41652A61B4FA7264EA82E
4EA83B4AA64547A24E46A34A43A63F40AA3541AB3143A93542A6403FA65141A84B45A740
4CA3404FA63C52A83451A73150A72A49A92A45A83347AA4045AB4B43A95443A95744A64B
48A73F4BA93748A53C43A53C43A6403EA6483EA35041A04B40A2463F9E44449C4842A044
3EA6433AA93F38AB4139AA483BA44A3DA2483C9E493A9F4D369F5337A15335A14636A13F
36A43D36A74038A94135A84035A93E36A63F37A64139AA4834AA5135A95736AA5037AB47
38AC443AAE4237AE4236AF4B35AD5531AA612DA4662C966E319B7133A07434A170329D67
35A16435A362359E6035935E348D5F37925E359962369865349369338F6331995E30A25E
32A85E2FAA5D2EAB5C2FAC592DAD542CA9502EAE4E30B14633B64232B74431B5412FB23D
32B14032B14A31AE5433AD5F30AF632DAC5F31AB5D36A75B35A25B359E57389C553C9955
3A995E3895653A8D6B3C8666398C6438946646A24F64AC246DAF1166B31264B31962B11E
61B32059B52559B42758B5215FB32069B22264B1275CB52350B92347BA2048BF1F49C023
4AC0274BB53546B14C45AB55459E5B4AA75F4DB15D59B4506BAF2470A80C7AA4087E9E02
819700829800839B017F9C0378A3096DAB1560B12352B03B44B24D45A459458C6F4AA556
4FC04053C03150B52950B4294CB13B45AF544C94604D756D4E6F6C4B676E4A776E418B72
458E7343837446797750747A4F6C854C68844C5A87595A84695C7F71597C76547B686577
587C6C6F88548A884384745484725E867B60827D5F8B755F86745C7F705D7D6A607C6162
89605BA15D42B15A36C15230B84C41AA4850A45741B36036BC5A41BE5B4DB36F45A67B46
9A825285954A78A728888F0F857D018B76008873008B7800897B008E7D008C79008A7A00
8D77008D78008D75009174009076009374008F76008E7A008E7B008F7E00947E00958000
9283008C8000887E00857B0088760087790482800C8289118093147E99147D9E137D9F13
77A01676A51A73AB2272B22A6EB6286EB82271B7246EB12F6FA82B6EB32B6CB92C5FBC29
58BA1B56B41658AD1C58A31F5E9E245D99215C9721629B19689A0E7992057C88007F8000
7C7D00757800707600737600737900747B00717E036F7E0870830970890B6F8F0E6B9310
6895106498125FA01457A71D51AE2E58AD365CA1405E95485F884E5B8A4F5A924E57994A
58A1445C994062942F638E1C6383126476096369015F61005954005249004D40004A3D00
483B004639004338004436004338004233003C2C00362600302100291C00251900201700
1B13001B1100150E00140C000F07000B0400070300040100020100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
8837458738458A384791384D87344D7A54316B5B535F606B595F794F65863E79803A976A
33A7532FAA4234AB383FA8303EA52D39A32A34A72A2CA73327A84926A95428A95C2CA45E
2EA35833A25040A8464CA83753A82A51A72352A71A5BA71764A7196CA71E72A41C6FA41E
68A11F619F20649D1E6A9E1869A1166AA11968A1175AA3174FA5184FA81F50A82A4EA630
4EA8354BA73849A43F47A33944A73540A93241A93146A8334AA63546A84047A93D4FA937
52A73853A83653A8304EA82D4FA9284BA72D48A53844A94743AB4D43AA5345A95048A747
4AA63F49A53C4AA43F49A54249A74445A64A43A45245A35045A24740A14A439F4E44A44E
40A64E40AA4641AA4642A64C40A04C43A04B439C4A3E984B3D9A523B9C513E9D483C9E40
3BA13B3DA6393CA73C3CA73D3AA93D37A94037A84136A94934AC4D35AA4F36AB4A37AB47
37AB4938AE4637AD4835AB5136A65733A55E31A06631976A359B68379F6638A063389F5F
3BA15E3AA55F3AA45C379C5934985C34975D339B60339C64339965359462339E5F31A55C
32AA5B32AD5831AE5730AC5430AF502FAE5132B14D35B54A37B84136B83F34B33A34B13F
33B04034AD4735AC5232AC5F30AD652DAC6233A85E36A458389F523E9B513F99503C9653
3D915C3C8B613C8766428364418B63419A6150A94769AC1F6DAD1367B11463B21A63B01D
60B0215DB02460B12461B32266B22067B41F62B2205BB11D56B5204FB91E50B92150BE24
50BE2451B92A4DB23B48AF4646AD524FAD564DB15958B44F65B22D69B01B76A80F7D9D01
8297008494008498008398007F9C047AA10970AC155BAF2D49B03947A351488B6E4CA45A
4FB74D54BF3A51BF304FB42B4EB44046A9554B92604D786751786A526F6E507C714C8479
4982784F7A7A5170794E707D4969864861894C548B5757876E56896D5B7E6A577C5A697C
508D7362955F798D507B7A5E7E79628F7765996F6B996C6490676482686881666E89666D
9261609A5D47A55B37B55D2AB75633B5544A9B5A4FAA594BB45A4AB65B51B46B45A5744B
9279537D953B7A9C1A858708887B008A79008A7B008881008979008E7C008F7700907A00
9278008E75008D75009178009073008E7600917800937C009077008F7A00947C00958000
9383008E8400898100877C008B7D0082810A7E8C167B9619779C1A7AA01A7AA71A7AAB1C
75A91E6FAB2471B02F6CB3316EB92C6FBA296AB7316CAE3C6CA63A68B1366BBB345FBB33
59BC3057B92A59BA2D59B42E57B13053B03352A92C58A7285CA5216BA11B799E147F990F
80900B7C8707758508737F07727F077081056D860A6A94116F9717709F206CA3246BA428
64AB2861AE2C5EA93159A63759A636699D397191427289496C834D66874C5F894E589251
52974D5798445A9E315D991D638E11667F07647500606C00595B005246004F42004A3D00
453B004436003F35004136003E32003B30003B2B003325002F1F00291A00251A00201700
1E16001E14001A1300160D001109000C0700080500030100010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
93452E98463398453B9C404796374980592B71634F6265625A636C53677048816B3F9960
35A64F31AA4036AB353CA62E3AA42D36A82930A8282AA93426AA4B27AC5129AB5330AA4F
35A9443BA93946AB3251AB2659AA1E5AA91D5EA81662A8156BA61972A51B75A41971A11A
6CA01E6D9C1E6D9B1E669B1A659E1761A01762A11C5CA41E4FA41F4CA52752A8294FA829
4DA72D49A82D49A82D48A62A49A82546A9264CAB294EAA2A53A92E50AC3553AD3157AD2C
58AC2F54AB3454AB2F4FAB2D4CA82C50A62F4DA43B45A84345AA4448AB3F48AC3A4AA73A
49A33D4B9C434A9F454AA3454CA44549A74544A84A46A84846A94542A84942A5503FA752
3DA95540AC5145A95245A35248A051479F4D46984D43974C3E994D3F9D4C429F4640A13F
3E9F3D409F3940A13A40A53C3CA83D38A94137A94836AA4A35AC4A37AB4A35AB4535AA46
38A84B38AA4E38AA5235A65B37A05F349B61339865349767399763399F5D38A55738A656
3AA95538AC5638AA5536A55534A15A349F5C339F5F30A26334A36334A36331A75E33A85C
35AB5832AE5132AF4D30B14B33B14C34B14C33B44C36B74A38BC3F36BC3836B63834B73F
33B34633AF4B30AB582FAC612CAA662CA76633A46236A3583BA052409D4D41994C40974D
3D8C533D8A5940896142886547955F4AA4515DAE326BAB1C6AAE1764B21A60B11862AE15
5FAF165FAF1765AE196AAF1D67B32065B21E5EB31E59B11F5CB11A59B71A59B92458B825
58B52554B92452BA2B4CB73C45B14E4EB25251B55454B34A5BB23860B13070AA167E9A02
7F9600819400839800819C00809D027DA20779A90E65B01D50B02C4DA4464888704BA461
4BB4574DC04149C0384AB63449B14747A15E4B8A624B726651736A596F7259727D56777F
5C757F656B7A676579516A8141638846598C504F8E5D528F6E558E6A59835E577F51717B
4B9E7263A6597F8E507C7A5F7D7F5E8178607F736A816D67806B667F646982606E906969
986C5F9B65509D6445AE6639B2603AB55A40A55A4BAA5754AD5C4EB35C55B06F4AA1754D
8E7B568093347C900E858203897B008B7D008A80008C7D008A7C008A78008A78008D7500
8D76008D74008D75008D72008C77008D76009481009B8100947A00937800968000958500
9283008F86008983008D8400898A027D931174A32572AA3073A12C6FA1286EA9276DB12D
6CB2346AB63A6DB83B6AB7346BB9326BB6396CB14769A44D68A24866AB4165AF385BB53D
54B64650B34C53BD4B4FBE4B48C04B48BD494EB74050B43B50AE4356AD4059B03C5DB22F
69A8186E9A0F709411698B0F6A8A0E698F0C64991260A12461A6345EAA4262AE4062AB47
5AB24650AF45569F4C5D9751668D4A7380497B7B4D767A4D6D82496687486183495A8C4C
50914B4E96484FA33852A1245698175C87095E79015A6D00535A005048004B4100453600
4039003D30003D2D003D2E003B2C003B2C00372D003525002E22002E1F00291E00251900
2015001F14001E11001A1000130C000E0800080500030100010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
904B29994A299649339146428D41457E602E736D40646D50576860506F644B8962439D55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864A2496492295492B89443F9144478C5C3A7A713968724A5E6F575472625289604A9E54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89492D90472A904439833F468C454F8C594777713E65764C5C755C557864508662479C55
3AA54B35A54037AA383CAB2E3AAC2A35AE292EAE3025B03922AD412BAD4032AE3A3BB02B
45B01F4CAE1C50AD1D4EAD214AAC2753AC245BA9205DA61B5FA61F67A32370A12270A122
6FA01F6DA1236CA12A69A02B5FA02C5CA22760A1265CA22859A229559E24549D1F55A11A
52A41850A51D58A31D5AA51756A41451A91951AB1F56AB1C5CAA185CAB1A5BAB1C56AC1D
4CAE2549AC2D4BAB374DAD3A55AA3A56AC3453A8334EAA344CA9314CA8304AA93146A638
44A342429B4A45A2484BA7434BAB424AAB4046AB4546A94D46A94F48A95546A65846A15C
469662479265479A65479C6147995A45965A428C5D438D5D43905A429355409F5144A24D
459E4B4A97494B8F4B498C524D9651509651518D4B4D994845A04541A6423BA83B3EA939
3CA63942A8393EAA393DA83D3EA83E3AAB3D39AD3D3AAC433BAD453AB1443AB24439B142
37B04032B24432B14832AE4836AB493AA84A3AA84D3AA7573BA76339AA6234A96233A85D
35AD5439AF4A38B24036B53A38B63938B93B38B93F35B64732B65031B2552EB05E2DAE63
2EA8662FA168309B6B329C6B349E66359F5D35A35A34A65337A84C39A6463BA54539A442
3DA6423FA63F42A93948AD3559B22860B62361B21F64B21E61B11660AA0E62AB1061AB19
5FB0235EAE295AB02C54B11E53B01957B21B5EB01C68AC0F6AA90C5EAF0F5CB1175AB71C
55B52C52B42B52B02751B13149C03F4EC04151C04455B34159B44058C0465EB3345CB029
74A6167D9404848B00868A00898D008A91008698067FA30F72AB1C63AE4047B16343AD6C
439D7643AA6B45B85E43B65642AE5F47A2654C876B4B6A6A45756A3B7E693D8167408463
4783644D7E6F4E7B754B75784D6D796B5F7783567778567C69557F5E647D5F70795E9260
59AF4869AA416E954B638E59618E58649155678E596D835F74796572746B7F6A6AA2585A
A354558668528A6E49B15744AB554EA0594DA95D49B95D4CAA6E55A86E579C6E57897A54
71A03B769A1F7D8607827C00807B00817A00837A00887B008A7A008E7B00947D01988404
9B880B9F920FA09C129EA41397A71392A9158AAA1782A71E84A3258AA11B8E9C15959509
9595029597078C9E0E84A51280B2147DB6197BB61D79B52879B92A79BC287BBA2277BB24
73B52E70AC3B6DAB3F6CAC3D6CAE3F6FAD4076A24374954C6D9F4B63AB495EAE5056B559
50B35452AE5549B45843B45444B25047AE4C49B54A48C04649C0424BC43950C43351C03A
51BE4452BA4753B84A56BA4758BB4056BB3C52BA494EB75A4BA86D47AA6B48B7654EB55C
51AD464EA530539E295A994959954952953552951F56920E54901451901753931B509416
4E981A4C9A1D479E2541A22643A01A4C9312507E0D48710E435F05455500464A00464000
423C004035003C31003A3000372C00352C00332C003226002F23002D2000292000281E00
261C002318001B1600171100130D001009000D0500060300020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
8D493D894838864148853F5688445D85584D746F41647A4E5B795C537C634E846241965A
3AA55131A84836A94039AB343AAC3035AF332CAF3D22B14121B3442AB34031B2393DB125
43B01E4BAC1C51AC204EAC284BAD2F4CAC2B53A82459A71E5BA7215EA42867A4286EA227
67A22462A32860A42E5F9F31569E2F50A42751A6234EA72351A42056A01A589D19539F17
4FA2174FA11956A3195BA31857A61253A81554AB1C58AB1659AA1455AA1750AC1C4CAC1F
48AD2847AD2E4FAC3753AB3C56AB4058AB3855A73450A5334BA53347A83546A83744A63E
44A54544A34C44A74645AD4347B14148AE4145A94846A75544A65944A65C46A45F489B63
45876747856945926D45986A44976241945E3E8D5D418F5E42905C41925A3EA05340A852
44A64E489E4C4A8D5048825A4D865E50895E5682564E8B4C4A984845A14241A93840AB36
40A83642A6353FA8343FAC3741AF363DB3343BB53A39B2413DB1443BB34239B43F37B03E
36B0392FB03D32B14234AF4039B1433BAE443CAA4A3BA6523AA66338A66735A46234A55F
34A95636AF4D38B24336B53939B53638B93636B84033B54D31B45B31B1672EAD6F2DA66E
2E9B6D33906B378C6A379169349866339F5731A54E32A84B32A84633AC4436AD4235B23E
36B5373BB72E43B8254BB91E58B71A61B61B63B41D64B31F60B21B5FAF1162AB0F63AC12
63B0195EAE1A5DB01C5BB0165BB01461AF1664B01266AF0D6AAE0D63B0135FB1165AB419
58B52457B32259B21A55B32450C03754BA3956B53C59B5395AB4395BB53B5DB4315DB32D
72AC18819A05849200878B00898C008A9400899A02829B097EA61468B12B4DB44B47AE61
439E7C41A97942B36944B15D48A5594B9B5E4B9262498761418B653A916D3C8C6B408464
4D7F6659776B5B7171587273586A736E5E717E5A71725D7663617C5F71705B776B669050
6BAA4070A54166964C5F8F58608561648A586C875C73795F7A706677736B8273649C6854
A25648865F4C816A47AB5D40AB514F9D4E54A75D4FB6614AAA724EA56F53956B55867B51
6FA02B789A16828C05878100847E00837D008B7D008A79008D7800977B00998806969612
999E1B98A31D98AF1F90B6218DB31D8EB3218CB02486A92F849A37859733889A2D939F15
939F048FA70F83B0187AB21C79B71D79B52A7AB42C79B52B79BA297DBF2C7CC02C79C02F
76AE3B71914E6C8F546C97506AAC4A6CB64269AC466B9D4E699F4962AC4C5EB25C56B45E
54AE5254B15444B9543FBD533FBC5346B05746B25645B55649BA4F46C13E43C53B3EB945
41B44945BB4D47C25149C84E49C54648C24843BA543FB5603AA6743CA56F3AAC6B3FA852
44AA3C46AA3E43A82F47AD3A4EA737509F2A4B9B1A4F97155099254F97264C94294C971F
4B971F4A9521459429409E26409C18489114478114447313456007465500484A00464000
423D004038003F3400393200382F00342D00352C003528003225002E25002B2100281E00
281B00231A001B1700161300130D00110B000C0600060200020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
88444681464385435187456088485F84574A7368446772515D765F587766527C62459059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724154674B556752566F5B5774635375694A676E4A6774556373675D746C5879634B8A58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5E3A625A456264535C7062546F6F5568755765755569745E66746A6372725F7466508559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5E4B675B54626460566A6D51687751607C55617A5466796066756661756A617961518655
449C4A3CA64137AC4133AD402CAE3B28AF352BAF2E33AC2638AB2139AC1D3BAA193EAC15
49AC1C4FAC1D4FAB1D52AA1B56A41D5FA02069A31E70A41E6EA4176FA41571A31774A418
76A2157A9F1574A0176DA11764A22060A2255EA025559F29569E2759A0225EA22464A024
66A024679B276B9922699919699E1864A3165DA71858A81E53AA234FA9294EA73255A938
56AA3855AB3855A53955A339579F36559F3654A3384FA43C4CA64548A64844A94343A840
44A94044A84246AA3F48AC4346AA5144A85E41A263439D63449F5E449C60469862459662
469064438A654488644681634B7A5E54765C60715E5B755E507D5E49876049945D499A5F
4A955B478E5A488D584A8C5A469456439C5242A24E44A64644A64046A84049AC364EAF32
4CAE374EAE354CB12D4BB12D4DAE2E51AE2A4FAF294CB12B54B22757B22358AD2557AC26
58AD2251B11E48B12645B02A43B02B41B02C3FAF343AAD4334AA4D35A95337AB5636AB56
3AAD523DAE4B40B14245B4384BB32F48B32A46B5294AB2284DB12E4EB13151AF3058AE2C
5CAF295DB1235FB31D62B51864B41766B21465B41265B40F62B51064B41366B41964B41D
63B41864B71666B41965B42364B22966B02966AF225EB3275CB11F63AF116AAD0D6FA90F
6DA70D6CA50C6CAA1268AC1C6AAF1B65AF1B62AB215FAA2462A92263AA1860AE1760B110
61B00C61AE0C62AF135EB11454B11752B21853B11C51B22351B32F52B63C56B23759B336
65B02668AC237AA4148597068D97008E97008B99008C9F008DA50284AC0974B11365AF34
4C9F6549A06845A26F48AB654DB45550B6514BB65747C06048B3604BAC604DA4664E966D
53896E4D7C6F4A766F4974714E796F647A6E707F6A6B815B66864A64AA2A5DC02760B829
64B53162AF3E66A05864995C6493586C8A536F785970796178766A84696792546E9D5D61
AC5862996B5D906B6B87736B8F6E71A16A71A36268A05F5CA16451A26850828540728B36
7C8F168183028681008E83009185009584009C8A0A98961B969A279B95378DB03587B433
86AA3380AB3482B4327DB9347FB8327DB7337EC0387DC0367EC03D81B04389A04087AA35
83B41F7EB41877B12C729D4771A64A71B9436FC03B78C03A76BD4076BB407BBB4079B63E
74B04572A74B729C4A71A04870AE4370B33A72B43275AF3575A33675A23C70A2445D9F4E
5F9A635699774BA1764AB87344C86D3FC7723FBD683FAD6645B06047B3574AAD5249A655
4B9C5548874F437C49416D5946766B4F6A6E645C607862606086554B8C4E457C59439456
47A64F45AA3B45A43648A83444A927479B2D3F983840A33A3CA7383B9B3438883A3E9729
3D991D3A98173F95163A9118358D19328616318411367C084371014D5E004E4800453E00
453B004238004135003C34003B32003A2F00362B003225002D2100271900271A00271800
2215001F11001D1400191200130B000C0500060200020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6367615C6B5E5873575C7C4D5C824F59855A577F5C587E62587E67587A69588364509055
43A04834A6462DAB4F26AD5424AF4F25B2412CB03432AD2436AB1E3CA9193BAC1642AA14
4AAD184EAE1C51AD1F53AB2157A8235FA42467A32170A41B71A5136FA61472A31774A218
769E19759D1B6B9A1B639C1C5E9E215F9C1F5F9C205D9A235E9A21659D1E689C1D6C9C1C
6B982169971E63991A649F1666A11860A61A59AA1E54AA2450AD2C4FAC314DA93453A938
53A83755A93756A63856A235569E33569E33519E324EA33A4AA74246A94243AA4242AB40
44AB3E44AC4246AB4143A84A44A655449C6243956543936342986544986546966647956A
47946B468C67478565487C64507B625778646371665B7466517F674A89674B966049975E
4D8F5B4B8E554B90524993554A9650479D4E46A04B48A64546AA3F47AC3F49AF3D4AAF37
49B03950B0354FB12D4CAE2C4FAC3352AC304FAD2B4DB22C54B22A5BB22259B12359AE28
59AE2058B01C51B01C4AAE204CAC204EAF2147AE2A3FAD343CAB403FAB483FAC4A3FAE4B
44AD4348B03C4CB22E50B52355B41F56B51B55B31B57B01E5FAD2166B0226AB1216FB01F
6FB21D6EB21D68B41C66B41E65B32267B62065B51D64C01864B61566B41466B61767B81B
65B71A66B41965B31C67B22465B12764B22563B0215FAF2266B01C64AF1665AC1666A81A
64AA1A64A8186BA6176DA71871AA176DAA1868A9186EA71771A91567AB1B5EAE1F5AB216
5FB20F64B01164B11864B31656B31952B21A53B21B56B32255B22F57B23B5AB13461B630
6CB2266DAE2377A91486A0068B9A009097008D94008F9A008DA10087AA057EB10A67B32B
4FAC564BA35C4997604C9F614FA8584FAF544DAC5A4AAC5E49A8614FA45E539B615D9067
59846C54796F4E756D4775714C806956946461A75765AA3E6AB0276BB61C62C01A67B61B
69B02C65AD3864A44864A44F5EA64964A345689B476B8D4E717C5D7F7459995F588D6A62
8D5C718D6F62916E667E6E67826B709D6870A5646DA45B59A66450AC694F888B3C77982C
828E14867F01887E008B800090820094850099900C98971F98A02895A73190B22E8FA932
8DA43789AC3488B52F87B82E83B62B83B92D80BA2E81BC3385B83E8DA647889C4784A53C
84B72583B51C7CA92E799049769B4978B94472C0407BC03877B83D7DB83D7CB33C7CAD3A
77A84074A24075A03E74A53E6FAE3B76B23376B42E75B32D78AF2B72A9346CA945609C4F
5C955A539F654AAE6D48B96F43C26843C26846BA6748AB6B46A66945A55C46AC4F4CAE53
4C9A574D7A58547054546A5C547667596E6F5C6B6266665A5C7B4E4B8E49449254439D4C
47A54842AC3945A63A47A63445A828489F2E439B37409C3F3C9C4336973B358F3938992B
3A9B22399B1D3C991E3C981E389520358D1E318615377D094270034D5E014F4C004B4100
463D004338004035003B30003A2F003C2E00372D003225002D20002B1E00281A00241800
2017001E1000180F00140E000F0800080400040200020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
62775F627B5B597E525A854B588B4F598B5753875C5086604F83654F82675188604C9453
3EA0492EA54B21AB5A1EAE611FB15C24B3492EAF3636AD223BAB1C3EAB183EAB1447AC12
4CAE174DB11C4EB12253AF2756A9285BA62761A5216BA3186DA5126FA5106DA115729E17
749E1D6D99226897216099245E9D215C9D1F62971F6997206D9A1C729B1973961872931C
6F911E699615639D1660A2195EA61B57A62051A9254FAB324EAC3B4BAB394CA93A53A839
53A63854A73854A63A54A238549E3351A1314DA0334BA33B49A64046A74144A93F43AC3C
44AC3D44AE4245AB4643A651449E5E449366418E69438A6941906943926E43906B47906F
47906E4488694880664A7C67527A68587566626F6C58776C4E856C488F6C4997654C945E
4E8A594E8D554D93524C93524A984D4A9B4B489F4B4AA4444AAB3F47AF404AB03F49B13A
4CAF3B4FB0384FB02E4FAE2F4EAC3952AB3650AE2D50B02A58B22A5EB32759AF2459AE2B
5BAF285BAD1D58AE1C53AC1D57A81959A91E54A82849A92E44A93845A63F46A93C45AC42
49AF394FB5314EB62553B6205AB5185DB7185AB61D5FB01E66AD2169AD236AAF266CB126
6AB4286AB52564B62463B62861B52E62B62A61C02965BD2567BD1C69B61468B61668B61B
64B61D65AF2162B02362B42B5FB42964B42761B22060B02664B01D61B11D5EB02353AE2D
56AE2A5AA92563A81C67A8196DAA1866AA1B66A81869A8136EAB1066AF215CB22E5AB41E
5DB31365B21362B51D5FB31C54B61C52B71E53B31E57B3215AB33057B53C5AB53461B531
66B72667B42570B01584A3078799008D92008F92008F99008FA2008DA70080B5066EB727
4EB5494BA9544C8D604A89664D90624E95624E96654995684D91694E8E665D876667786B
62766F5B766F50776A4C7A684B90604DB15459C04464C02466C01767C01762C01665B317
60AD2E59AC455CAB4D5CAE5153B05953B34B53B4405E9F48687E5F7C785AA86B4C85795E
766E7982756E916F69766A697A64729E6A75AB686DA85C5AAB6550B36F4F89933D79A323
87960F8887008586008686008B8600928C00939A0D9A962496A62B92AB2A90AD2B8BAD31
88AC3C8CB4378CB83189BD2787B82683B9277FBC2C7CBC3589B2479A9C4C889A4F82A244
83B92E7EB7247CA3387F8A4C76994779B94676C14978C03E78BB3F78B8407AAD4377A444
759E42749B3F75A03E71A63F6FB43E70B73871B23872B23473AC2F67A63665A749629F50
5D94554EA65A48B86846BC6A42BD6443BC604AB76448AB6E46A07243986446AB5147B452
4A9A584E6D61596660636762676A6A6B657853736D546D5E4E724A468448449C5441A554
40A14F3DAF4144AD3F47A93743A82F43A3363F9F3E3D994B3A94543498442F983C29A032
2FA127319F2538A1223AA0243C9D2C35922230871834800D4073054C5F015052004B4B00
484300443D003B36003931003A33003A3400363100352A003125002F2000291D00241800
2017001B1300180F00130B000E0700080400050200020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5C835B5B805959804F5B82425C89405D9042579040538F44528D49538B4E53924F4E9944
3EA33E2DA53E22A74821AB4B26AC462CAD3837AB283DAA1D43AC1947A9174DA81556A912
5EAA125CAB165AAD1559AB175AAA1A5FA81F68A41C6FA31671A31370A6166EA11570A015
6F9C176B9D186A9B1C6A9A1F699B206C9A226F961E6F951C7195186F9715709816749A18
6E9816689B14629B185FA1185BA51E54A4244EA82C4DA8344AA83B4AA6394EA63851A738
54A43857A63555A43354A12E52A03254A035509F40509F404CA24349A43E47A73A48A83A
48AB3A46AE4145AD4844A455439762458D6A47866C487F6C45846D44867043886F438971
46886E458268497D635476625F72615F75625D75665480624E8C634897634A975E4C915A
4F825A4F87594D8B5B4A905C4B92514A984D4A9D4E4AA5404AAA394DAD3B4EAF3B4EAF35
50AF3451B03553B03052AE2E51AC3455AC3457AF2858AF235BB0255EAF235CAD2258AC25
5BAD295DAC1E5CAC1958AB1860A81666A3175FA21C56A4214FA52753A62D52A83051AA36
55AE305AB3285DB5265DB32161B42165B11E65B11F65B02164AE2368AF256BB02968B12A
6CB22B6AB52668B52469B5246BB52768B62768B7246BBD256DB7236FB31E6EB21B71B519
6AB41667B31967B32067B42569B4226AB21E6BB21C6BB21A6AAF1B65AD1E65AD255EAB29
5EAA2261A51F66A6186CA71770A3186EA41E6BA71C6FA7176DAA1B66AD2366AF266BAD1B
6BAF146CAD1266B01661B2165AB21859B3175CB2175AB11C59B42957B4345CB32F5EB22E
69B2216BB01B75AB1480A306879601909200938F009093008C9D028AAA0983B50C6FB528
50C04950AD514A995C4996614B9D5C4F9F5C4C9E5F4A98644C9366518E635488625B8265
578965549561549D4E56A0405EAB3564B4306ABA2772BF1B6FB5146FB5156FB7156EB11B
69AC2D64AF3A60AD3C62AD3D5CAF415AB04658B2445DA14962835B777E5AA471557D8562
6C777574756D7B70676E6F66776568986065A76160A45D54A96A51AC74548B923C7A9E20
88960F8C87008B83008A7E00947E0097890C959914989A2293A02A90A5298EA82E93A431
92A3388EA73489AB3586AF2D85B62482B92283BB2281C02F83B3428A9E4E83A04D80A346
82B33281B8227DAC31809E407BA0467AB44970BD4A77BC4077B5407EAE4680AD3A7CA939
7D9F3582A03585A23181A5317EA9307CA72D79A8287AAD2679AC277AAB3471AC3D6BA946
61AA4A55B64851C04C4FC05345C15344C24D4AC04F44BE5945B35F49AA5C4CAC4D4BAC4C
4EA14E4B905A4F835A50795B53705C5C6B654E795F4C84574D894A4B92454B9D4843A055
3FA5543AAC463DAE4640AC4441AE4043A74041A3413DA14339A24938A53D34A63533A633
33A53035A42D38A32F39A12F3F9B263C8C1B3F7E0F4172084963025055004E4C004F4600
484300463D004036003D3300382D00362B00342A003327002C23002A1E00261A00241900
2317001E1300190F00120C000E0600080400050300020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5788625A86615B82555D83475D86405F8F3F5C943A56963C4E973F4E97415199424EA03E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5B8F515A8E4F5C8E455F8D3B5E913963963B609A3A5A9A395A9A38599838599B37549F34
43A62E30A72E26A9352BAA3330AA2F38AA283BA9213DAB1A46AC194EAE1558AD125FAB14
65A81461A9115BAA105AAA0E58AA125CA71760A41764A3146BA3186BA6166CA71469A616
68A51569A41667A2196C9F18709C1B73982274981F749717719912699A16649D17659F17
65A11363A0115CA11A54A52450A83048AA3548A73848A23643A03642A43742A63447A535
4BA1304EA12D4DA32B4CA42D4CA4344EA2424EA14D4F9D4A4CA24548A53C49AA3549AC34
48AB3948AC4047AA4C429C5C428A69428171477A734F6B774A73763F767A3C7B7A3C7C79
3F7E74417C6B4F7761606F5E6A6E625A7760527A5D4A9059489957469E58469754498D57
487C5E4A806243886A448F644A9257499A5249A24F4BA73F4DAC3153AF3156B13453B333
54B13150AE3657AE3256B02B56B12F58B1305CB2235FB01C5AB0215BB0265BAF215AAD24
59A8285EA72362A81A65A9146CA212719A146D9B12669D1A67A01B69A31F66A72565A72E
62AC2665B02466B12866AF2E65AE3063AD2C67B13067B23163B22F66B22D68B12E69B130
67B22E69B62B69B72968C0236CB9216DB5246DB3236DB3266FB32C71B52C6FB7246FB718
6DB5176CB41D6EB2246CB2246BB3206EB41A71B2186CAD1769AD1E63AA2A64AF296CA829
6BAB2365A61E66AA196CAA186AA71A6CA6216BAA1E69AD1E6AAC256EAF266FB02374B219
71B0136DB10D68B30D69B20E6BB3106DB40F66B30E65B4125FB2185CB8215EB7235EB428
68B31A69B01476AE0E83A504899B01919500918B008D9100899C0381AE0A77B8136DB828
56C04052B6484BAF5147A8544AA4534CA0554C9F584A9F584FA25750A6524EA74C4BA446
52AF405EB9386CC0256FC01B6FC01872C01A75C01874C0186FC01770C0186EB41B6CAE22
6DAC2C68AB305EAC305CAD325EAF3D5FB34858B15156AD58599C5C6A965784855D728C5E
5E8966638562667F68657A6B72676D8C5B6A9A6162A3635B9F6F5B9B785F83963B7BA218
89950A8E89008E87009282009886039B9719939E2D92A32E8D9D328D9D3690A23A939F3A
8E9D3B8D9E3787A33683B72F80BA2880C02083C01E82C02183C02F7FBA3E7DBB407EB842
7DBA3880C0277BBD257DB83B7FAD4677B64672C04678C0437BBA3F80B23E83B6387DAC37
81A43785A23087A62987AC2481AB1F81AC1A7FAA1D79AE2078AD257DAD3074AB306FA733
68B13562B83761BB3759C03A4FC5414BC43A4AC33647C63D4AC53C4BC3394DBB3F51B13F
4FAC3C4FA6454C9F484898444894474B924C4A95474D9748519F484CA64749AB4943A84F
40AC543BAE5439B14F3AB1503CAD4C3BA84C3DA54A44A7433EA8423BA7453BA549369E4D
379C50359C4D389C433B983140891D48760B4F6105515501514E00504B00504C004F4A00
4F4900494300433C004036003C3200382B003327002F2400282000271900221800231800
2017001C1600170E00120B000C0700090400040200010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5D92355A94385A94355A96335D963362993E629C3C5E993662993366972F64972E5C9C29
4BA4263AA62732A62C30A82E36A92C3BA6273CA9213FAB1D41AD1848AE1350AA1359A616
5EA4155EA41361A7135FA8125EA9125FA5165FA31667A21770A0186FA21873A31574A616
72A31970A2176A9C1871991677941A779217799016759511779A1279951971971C6A971C
7098146D9E0F64A1165BA52852A72E4DA8334CA8324BA82B48A63048A4314CA1314E9F31
4EA02F4EA12F51A22F4DA52F4AA5374DA5404FA5464FA24546A44146A63947A9304AA831
49A93949AA4544A654439965448C6C458470487C704C6E6F4573724277793F7A75427A72
487E6D477E69507B6158735F5871615279604A815F459256479952499853489253488958
49805F488A5E46935C47965549994C4DA24750A8474FAB3950B02953B02657B22D58B22D
55AE2A52AE3156AE2E57B02459B1265EB02A5EB0215FAE1D5FAC205EAD2864AA2361A820
61A42962A32465A61B6EA116739D147494177398186D9D19719F20739F246EA42A6AA52C
6CA9286BAB276BAB2A69A23067A53467A8336AAB366BB1326BB22E6EB12C6DAE2E6DAE32
6BB23069B72D69B52E6AB52B69B72B68B62768B2256EB2286DB1326EAE2C70B3236EB321
6EB11F6FB01F6BB1256BB1226CB2216DB21D69AD1C6AAE1F69B02468AC2E69AD2D6AAB2B
6BA92765A72460AF2365AE2565A92966A4286BA52067A62765AC2A68AD236BAE1670AC0F
70AC0D74AE096FB00A74B10A76AD0777B2086EB40D69B51066B60F63B71165B51763B222
6BAE1670AD107AA90981AA028AA1008F9400908D008F9100899B0283AF0979B4146FB327
59B83454BA3C50B8464DB44A4EB04C4AAD5048AE534BB0534CB84950C03B51BD2D57B823
63B5216FB82473B91E72C01C71C01E70C02070C02073C01E6AC0186EB5186DB41C6AAC25
76A82C6EAA305EAC335CAB3960AE405DB24F56B05453AD5C56A55A629E5772875E668661
5F8A605E8C616089686A80717D6D768D5C729C5E6BAD6765A269678F716480923782A013
8A94078E89008E89009587019995089D9D2091993A93A03993963C91A33695AA3A91A53C
8CA24287A04085A73C81C0327FC02A7FC02682C01D88C01D85C02384C02F82C03880C039
7CC0397BC0297CC1227EBD3681B5417ABB4379C0407BC03E7CC03D7AB93D7CAE4080A93B
83A73882A43185A52A84A62385A81F82A81E7DA7217AA62675A92971AF2D6EAF3171B02F
6CB6306CB93463C13859C43250C3334AC2314BC1354BC43B4FC4344CC42F4BC2344BBC33
4EB4314FAC3A51A23D509B3E4F9C474FA64852AD404FB2474AB54F43B55542B15E3DAF5F
3AAE6A38B16C38B46337AF5B36A55539A15B3CA7573EA84B3EA7463BA5503BA15937965B
33905A33905437943A3A8D2341780D4D6201535400534A00524900534E00534F004F4B00
4C4F00474500454200423C003F3800373200332C002D25002A1F002519002217001F1800
2018001C1400161000120B000C0900090400030000000000000000000000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
61992B589B2D539C2E569B315A9A395C9D415F9E3E5E9B3664982F6C90306C9227609824
53A12240A52436A62632A82938AA2939AA273BAC243AAE1F3FAD183EAD1544AC1646A918
4EA81752A71656A81C58A81A58A81558A51659A51862A4186AA01C6EA11971A21373A416
6EA31367A111619F146E9E167799197994187393147396127A99157F951977931F719620
6D9614689B0B65A31859A72552A82D4CA9324BAA2F46AC2A44AA2F47A4314E9E31509C31
4F9C344AA13249A23246A33645A53A47A7424BA5404EA24043A54041A83A42AB3545AA3A
44A74640A64F3FA05F3F966B408F70438B6D457E6E467070467172407776417C71447E6C
4B83674F7E664F7E604F79624C7563487865438363429459459953479455478A5949855C
49855F499357449D52479F4D4AA1454EA9404FAC3F53AD3254B02255B32357B42A56B228
54B22A52B02F57B02D59AF2158B02059AE245AAC225BAC205AAB2760A92D6CA62266A122
639D2A63A02867A11D719D1977951976931C76991D719C1B749F23799E2A6EA32D6EA62B
6DA92A6CAB296AAA2B6BA2306CA4326CAA326DAD306EB32C70B4276FB3296EB02C6CB22E
6AB4316CB62E6DB62E6CB52969B5276AB3296CB22C6DB22B6DB02F6EB22A6DB32669B222
68B3216CB41C6BB4226AB5246CB22169B11E66B01C6AB11E6AB0226CAF2969B12D69B12E
6DAB2D68A82C64AF2D5DAF385DAB3664A52A64A71F64A72966AE2969B21A70AE1070AD0A
75AC0978AD0875AE0777B1067CB3057AB3076FC00D6BC00E6AC00B6BB60D68B71467B51D
6DB31370B2107CB20985B3038BA8018E98008E8E008A9200879A0187A7087FB30E7BB51E
65C02761C02F5BC03652BB3E53B84054B83E50B74651BA4853C03E59C12E5AC3215FC11D
69C01D71C01D70C01F72C01F6DC0206EC01F68C01F70C01B71BA1775B51776B32074AA25
73A62870AD2C62AE3460B13862B33C60B54658B64F56B15559A5545F9C526C865D66885C
5E8F5E60985C5D946469856E7F6E77925E72A0616CAD6A63A06C6483725E7F932F869E0C
8E9504948C00938A009D8F0C9596199B9A2A9A973D92A0398D9C3791AB3390B5388DAE3D
8BAA3F84A23D83A63481B62E84BB2784BB2288BC1989BC1587C01785C02481C02980C02E
7FC02E82C02982C01C7DC02877B73A78C03C7EC03483C13881C03481BA3381B03983AE34
83AD2C84AD2389AA2088B11D89AC1C84AF1D81AA237FA32A7AA82979A92779B0267AB524
71B7216EBC2064C0225CC22156C32653C02855BB324EC13E4FC3394FC1324FC02A4DBE25
53B32459AC265EA62A61A32D5EA5325BAC3656B2374FB3404BB74E48B15749A65D45A25E
43A0663FA16A41A5623EA45A3E9E513DA1503EA44840A24240A040429F42469D45409846
3D93423D8E334487234A7C11546906575800544A004F42004F43004F4700514700504600
484800464000443B00413A003F34003B2F003428002C1F002A1B00241B002017001F1800
1F18001A1300160E001109000A0500070200010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
64972D649C285D9F275D9E2B639D2E67A13268A02E6B9A2C6F972871932B6F9527629D22
52A32248A8223AAB2437AD2938AE2A38AF293AB0293FB12440AF1E40B01A3FB11A44AE1B
4CAB1850AA1557A9195CA7195FA7175FA61962A61865A6156CA5156DA5126DA51271A315
6FA2126F9E0F6E9F10749F12789C167C9817769412749815799B167E9A16779819749918
6D9711649D0F61A61658A92554A82852AA2A4DAA2C48AD2A49A82E4DA42F52A0304FA22F
4CA33247A23447A43346A63146A73347A83847A63C47A73E40A73C3EAB3C3CAC3F3BA946
3DA74E3CA4593B9F633E946D40906F42896C42806F43716F467671467973467D704A7E65
508162597B60567C604F7F60477E614484623F8F5C439C50439E4A489750478D59488D5C
478F5C479851459F4A47A2444BA63C4DAB3852AE3354B02756B11C59B41B57B42454B226
53B12452B32555B22659B11E5AAF1F5BAD2159AC245DAC2360AD2564AB286CA9246CA127
699E2E669D286E9D1D74961D78921B7A9322789A20789C23769C2B7A9D2E6CA42E6AAE2A
70AF2A71B02B72AE2E71AC2F6EAC2F71B12E73B52B75B42573B62474B42770B02E71AC30
70AC3070AE2C72AD2875B12774B12674B12774AF2C70AF2B6EB12A6EB52A6FB4286BB61F
6CB41C6FB51970B51C6DB5246EB2236CB1206CAE1C6BAE176FAE1272AE1670B2256BB12C
6DAE266AAD2F66AC3C5BAD425FA83069A7216BAA1B6CAE1870AE1274AF0E79AE097BAD06
7DAA057CAC047CAD027EAF047BB30677B7096CC00F67C01167C01166C01166B71663B523
6CB5156EB41377B20D82B30788AC048F9C018E94008D93008B95008A9E0089AC097EB419
71B8206BC02762BD2E62BB2E5EB62E5DB82B5FB83061C03266C02E67C02A67C02765C027
69C0256DC0226EC02173C0226CC0236DC0226EC01C70BB1573B31778AE1C7CA6237DA528
75A8286EAA2969AC2E64AF3560B0325AB23B54B34B55B05158A1515F924C68795F64845C
5C94625C9D5A619B5E6A84677A6B72955E72A6646BAA6F5B9C6F5B83715580902A869C07
8F9401958E00988F03A39711988E289991369B93428FA2398FA0378CB4358CB53688AC39
87AA4188A83686A92D83B22A87B8248BB7208DB5188EB8128CBA1389C01A87C01E82C025
7EC0277FC1267FC01E7BC02271C03577C03883C03186C12F86C02D82B82B7FB53380B42C
82B32381B12081B21E86B51C86B51E82AF217FAC297EA72B7BA82C7DAB2A7BAF2779B322
75B81C6FB91964BA175AC01B56C32254C02A58B93651C0424DC13C4BC1384AC32847BE1E
4DB41F54AC1E5AAC2157AC2955AD3251B03F49B25041B05E3EB16F3EA874408D75408772
3E87763D86783F8F6A3E945E409A523EA0513E9F41409B4141974944994547984141953C
429637418B234D7F0F5770045E5E005A50004E43004A3B004A42004B43004942004B4400
484000453C00433B003F34003C2F00392B003727002E2000281C00261B00211A00231A00
1F18001C1100150D000F0600080400050100010000000000000000000000000000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
649632679B276499236098265F9A2A609C2B61992B64942B6C902D70912C6C972A5C9B28
50A12944A42A3AA82A35AB2C36AB2F3AAA3140A72F42A82E44AD2E43AD2841AD2143AE1E
4FAC1B5CAA1C63A81A67A71967A81968A81D64A71B61A51664A60F67A70B67A60D6AA414
6CA315719F10719F10749E0F789F16769A17759714749A17739F1871A11771A018729C10
6A9810629E1461A41758A72158A62656A7284EA92A49A82D4DA3304DA2324FA2324CA433
4CA53548A0384AA2334BA62B46A92D45A83442A63940A53E3DA6403CA64138A74738A451
37A1573AA05E3D9A613E906940896D40816D447A6D47706C46757047777048786E4E7767
5874626870625E7860507E6145855F42915B429F5046A54545A14245954E488F5746905B
47915A49904F499B444CA2404DA73750AD2D52AE2654B1205AAF1A5CAF1B58AF2057AF26
56B01F55B11F59B0235EAF1F62AD1E61AB1E60AA245FAC2463AD2366AB276CA72570A329
6F9F2C6F9B2A7A9620788F207C8E238191267F972982962C7F95327B9A326DA72D6AAE28
74AE2A75AF2B74AE3074AE3173AD3073AF2B73AF2478AF2379AF2473B12B71AD2F72A42F
72A32E74A12D76A52979AC2A79AE2A77AE2D76AD3172B02F6FB12F70B32F6FB32D6FB31F
71B31C6DB22069B02267B02A65B22E6CAF2673AB1F72AB1970AC0F70B11569B22761AE32
5DAF3259AB4856A8554FA9505EA83162AA2665AE1B69B01070B10C71B40A72B1097AAE06
7EAD027EAE027EB20080B3037BB40774B70D69BC1363BC1664C0175EC01960B51D5EB428
65B21966B41476B30F7BB30A84AB0790A1028F9A008E96008A9800879B0085A5097EB211
70C0186DBE2164BF246BB62665B5296BB4286DB22C6DB6306CB93368C02F69C02C6AC02C
67C0286BC02067C01C6BC01F65C0206CC01F6DC01A70C01572B31775AC1A77AE2278AE24
74AC266EAA2764B12864B42D5CB52D4DB6384DBA4C51B353549F5155924F5B8061598760
5A94625BA155609D5B6D81638469699A636BA66767A5705C9A70527F754E7E8C27849306
8E8F009692059B9812A8991EAB90249B913B9698448AAB3F8CAA398BB23789B83884B23E
85AB4080A83686AD2D88B6258DB7218CB7208EB61D8BB7198CBA128ABD1085C01487C01F
85C02481C0267DC21F79C02277C02D7EC02D80C32980C52A80C0277FBC2081B81C84B618
84B81782B71584B91581B71B82B31F82A81E81AB1C80AB1E81AB207FAB207BB02079B41F
78B31975B3146CB41367BC1A5FC51F5DC12B5AC0365BB83F57B74253C33B4FC22952BC1A
56B41659AD1A5AA71F59AB2B54AB374CA94544AC5140AB6040A86947AA594C9B49508E3E
50873D4E8940488B3E429141439649429C4C449843439036468C314886254C871E4E841D
517E185575105969065C5C015B4F005543004A3D00493A00463A00463D00493C004B4100
4A3A004535004336003E36003C3100392E003427002F2000291C002517002118001E1600
1C1200150E000F0B000B0400050300010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
669E2869A02569A22463A22463A12662A127629D2A66982D6A962E6D943063992D559D2B
4DA03542A63139AA3233AC3134AD323BAA313CA7303EA93542AB3640AE303EAE293EAD22
4BAF1D5BAD1F60AB1D65AA1967AA1869A91F68A81B5FAB145CAA0C5BAA095EA91065A713
66A61470A2106CA10F6EA114709D1A6C9E186D9F176E9C1769A11866A41A64A21565A111
689F1366A3135FA71657AC1D59AA2057A62552A62A4CA63148A63345A53440A73541A83A
41A44042A34042A5363EA62D3BA82F36A73636A74236A84635A74B34A74F32A25532995B
3399603699653997673B8C693D836B3F7A6B41746E456C6E486F6D47737148726E536B66
65686777666763716550806244905F439D5846A74947A93D46A545429653438F5A458E5C
49905A4D894F4E994251A53B4FAA3551AD2652AF1D54B01A59AF185AAF1A57AD2253AF29
54AF1F54AF1E59B1235FAF2463AC1F64AE2060AB2861AD2668AF236AAB266DA72C70A42C
72A12C799A2881901C7B89217C892A7E8F2B7A902D7E8E2D7A9236769C366EAC2E6EB326
75AE2476B02476AD2778AF2977B12974B02776AF247AAE2379AF2377B12570B32A70AF26
72AF2376AC227AB01F7EB51F7FB41F79B42378B12E74B13272B33270B32B71B32375B31E
77B21F70B2216CAE2467AE2966B02D6DAE2474AE1F70AF1F6CB31A6EB41C6BAE2867AB2E
68A52F659F3965A23967A63066A92268AE1B6BB11771B11675B31472B41374B30F7BB10A
81B2067FB20679B50777B70579B30776B50A6BB71067B6136AB71467B9146CB4156BB01C
6BB1146BB41077B10C7DB30C84B10A95A301929C008F9A008C9A008B9A0084A0037FB00A
77B91071BE1F6BC0266FB52A6EB23079B02F7FAE3179B03172B33372B73170B9316DC02A
6CC0226EC01D69C01872C01A6EBC1C73C01E74B81A76B4167AB01775AA1974AE1E74B123
76AA246EA9265FB22558B52857B8314BC03F4FB74A54B34E549A4A57924B578C59548A5B
5A8D5B5E9B4F64995579785B925D5AA3655DAA6D5FA46B5897704F797848828C1F899206
908C0195950E979D1DA99A26AE8F2B99983F8EA04789AF408AB1388BB43886B73B84AF3F
85A23C83A33684A5318AB5248DB7248BB4278AAE228DB31C8FB5158CB81290B81389C01B
84C02182C0247BC02178C0237BC02B82C0287FC02778C62A76C12A79C01C7DB91785B916
88B91586B41184B81580B41B7FAE1D7FA71A81A9187FAB1C7DA82079A32079A82275AB1D
72AD176EB0106AB21169BE1E63C3225EC22D5AC0365FB63D5BAF4051C03D4FC32755BD16
54B61756AE1E52A82A53AA3953A9474A9D53459F6442A06F42A06C48A34C4D932B54821A
577611537C184C7F1D43892743913B41954641904841853244801F49740F4B72054C6C03
516401555B01575100554A004F47004F3E004C4000483E00453700423200463800473B00
463C00443A004235003E36003E32003A31003429002D2500291E002519002016001C1200
170D001108000B0700090400030100010000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6B9D286AA12666A52667A52167A12167A22565A02669A0286F9B2A6C9B27619D26519F27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719C2968A02964A32665A22263A2225DA1265C9F275FA02867A02664A01F59A0204BA225
47A32A46A22B3EA4273DA62341A82249AB1B4FAC164EB0164AB01C43B02141B02542AE26
4AB02A51B02B51AC2A58AC205BB01964AC1464AF0E5DAD0C55AE0D51AE0F4FAB1355A915
5BA71365A6116AA4146CA1166EA2176AA11969A51968A51A68A11C6C9C156F9F126EA214
68A61663A71559AD1A51AD254BAA2C45A83040A83538A93D33AD3D2FAA3D2DA94036A742
38A64437A54636A54135A83E34A6402EA5442FA24A2FA64C33A75032A65432A65733A356
33A45534A55439A3593B9D5D3C9261408660477F624E7C6256766257775F59775D5B735C
59705F5870654F8564479460459E5A49A3514CA84252A53E4DA04D4B965A488E61468D5B
46865C497C554A91474EA73E50AC3A55AE3156B02758B0255BAC225EAE1F5EB1235DB02F
59B12D58B02B56B3285CB1285FAF2560B0275FAD2B67AD2D67AC2C69A8316AA2336FA223
76A21D809E1A87931C828E227C89307E8932738D2E73912D69993367A62F6AAF2471B320
74B32077B22076B21E77B22073B22272B32272B42172AF2474AE2574B1266FB42471B122
76B12276B21F7AB21E7FB11F7EB02379AE2676A82D6FAC3271AD3075AE2974AE266FAE26
70B0266BB22468B0266AB02A69AF2A6BB9246CB91D6EB42466B0375EAD3965A436679838
659A36609D3862A43260AE2765B2216AB22673AF276DAE296EB02372AF1B77B2147BB615
7DB20D78B3076EB30B6FB60A6EB40870B2076FB20970B20B71B30D75B50B78B50C79B20D
79B30C75B30B7EB10980B10B8AAC0894A90296A90294A4018FA0008F9D008A9F0088A703
83B20778B70E6FBF1A6EBF2372BE257DB12E7CAC3978A93872AB3772AD3372AF3375B42F
70C02A6EC0236BC01F6FC01D72C01D73C01A75BB1776B31575B61C70B42470B7236FB520
6BB31F5EB4265AB5294FC0304FB8374EB64250B44B53B24E53B0455BAC4063A5485D9A52
5895595E9A5B648C64827062995D64A06A63A36C619F695A8A7D4B7C9C298A9D139A9A0A
9EA913A9AB17B69D1EAC9D33A298438EA64783A94083B03782B53880AB43829D48879B3E
919C3A94A03498A03094A32B91AD2992B52593B71A95B21797B51193B5118DB6118AB813
88BC1B86C02382C22483C22783C12B86BA2884C0247EC4287CC6297AC22B7DC02481C024
7FBB2181B31C84B11C82AD1A84AA1485A8117FA9137AAB167CA41C74A3216EA4246DA51D
72A7166EA91169AE1266B91A60C1245FC32F5FC22B5BBE2750BE2749BA2151B82155B017
5AAA105DA5185CA018589D1650A0254DAD4049B2524DB35358A728678B09686D00635E00
5F58005C55005459034E68154475274675254B721C4F640C525801565200544C00594600
5242004F42005042004E3E004C3F004A3800473800493600453300412F003E30003D2F00
3F32004033003C3300383000382F00372E00332700301F00271B002319001C1300170F00
130E000D0800080400040200020100010000000000000000010000020100020100020100
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
71A22968A02961A4275FA5265CA42657A32859A12C61A22C63A42763A22158A3204EA221
46A22742A22541A32242A61E47AA1A53AC1656AD1254B0114BB21646B11D44AF2441B12B
45B03243AE3140AD2D49AC2953AD2056AF1C55B01552B21551AE124AAE1347AD1747AD1C
4DAB1B59A91868A51471A21572A4176AA41765A31D62A22165A01D6EA01070A2116CA413
68A7175CAA1956AA254FAB2E46AA313BAB3333AA3D2AAB4925AE4923AE4529AC442CA845
2EA54830A54B30A54E2FA64930A5482DA5492D9F4C32A35234A75634A95835A95934A755
35A65137A75138A85639A15B3C9560408A63487F65517A695D78655F785E5D7A585B7957
54775A487965448C60439B60459E5D49A54F4CA8434EA1434D9E4E49975C48915E448E5E
44845C44795C478E4D49A8414EB03D51B03755B03058B12A5CB0285FAE1F5CB02859B031
56B03456B12E58B22A5BB2295BB2245DB0255FAD2B65AB3064AA2E60A62E62A42F6AA823
75A51D7E9D1F869320858D23828D2F7E8D33748F316E962F619F3060AB2866AF1F6CB11F
71B02274B32275B22175B12371B22571B22372B22872AF2971AE2A71B02672B32674AF26
75B02577AF1F79AD237CAE297DAC2C78AA2E75A72D72AB2C72B13174B02A73AD2B72AC2A
6DB12D66B22967C02466B42468B42B65BC2669B92365B02D649E4360A44066A839659B3F
5F9D405C9D405DAC385FB42F6BB32D6EB12F70AF2E68A8366CAC2F72AE1F76B21B77B61B
77B21074B30C6DB5106CB7126EB51271B21172B50F70C00E73B70D7AB90B7EB6077DB105
7AB10877B50E84B20883B2058AA90493A30291A50193A30190A100909D008BA2008BA400
88AF027DB70C72C01A70C01B70C01F76B82478B13077AD3475AB3779AC3076B03271B533
6BB93369C02E69C02867C02667C0216CC01F74B81977B41872B51F72B92375B82071B51E
62B32559C02D53C03453C03B4EC0404CB44C4CB1544BB1544EB44558B34062AF455AA44F
579C595B976365876A7E726B9766689A6B669E6B659560627F774E789F208C9B109AA011
B09E19B2A11CB5A024A8A1339999408B9D42829B3E7D9E407D9F457F964D8A8D498B9841
909C3A999C349AA13293AB2B93B72794B81DA0B6149FA80E9AAE0B91AE0E8AB41187BA18
86BC1F87C02A8AC02A84C02B82C02F82C02F82C02482C02080C02980C02880C02384C01F
84B51F82AC1E81AF1F84AE1E83AC1784AB1582AB1480AD157EAB2077AA2071A81D70A61D
6FA71968AA1868B11A67B82563C03262BE3764B52767AD1C66A3145E9F1258A41757A318
59A71761A41461A1155E9D17579C2157A02958A3355AA2296596156B7D03676300605300
5C4D00585200575301545A09516212526110565E0C565204534A00514500514100543F00
503E004E3E004A3700493400483600493600473500433000442F003D2C003A2B00392C00
3B2D003C2F003B2F00392C00382A003427003223002D1E00251D002218001A1200160E00
1009000C0500080400030100010000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6BA12F639D2D5B9C2D5D9E2B5BA02B5A9D2F619A33699C356F9E306E9D2A619D2A5C9F2D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64A32D5DA02D5A9F2E5C9E2F659E2C669B2D6F9730749B33749E306DA12E659D2D5F9B2F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5F9B305B9D345D99326694316A962F6E932F779331799634749E3067A12C5FA02E619E30
5D9F2D5BA22555A62251A92150AD2050AE1F4FAB1E4DAD1D4BAE1949AE1E45AE2249AC24
4BAB284CAA2C47A83246A83449AA3948AA3E47A94747A74648A73D48A9394CA73251A72E
54A82955AC2355AD1D53AA1753AD1850AB1B55AD1A57AE144EAF154AB0174AAF224BAB24
4BA82647AA2C46AA383BA9472FA65425A95D22AB6321AB5F20AA5C21A95924A65723A259
239B5C239D5E27A45B28A85628AC4A26AB4627AD492AAD4E2BAC512AAA572CA95831A955
2EA1592E9B61329268398C653F8668498365527E5A5D7D5064794C577A4E497B50487E53
4C7B5B4D7B654E77624B855A47955449A14848AA454BAD4749A84949A2504B95554D9E4A
4DAC414FB23B50B13152B42755B42158B6225EB61B5EB61A5CB31E58AF2557B02559B02C
57B2325BB22D5EB02C5FAF2B5FAD2B63AB3164A93765AB3968A83467AA2969AB2474A71F
7F9E2081962480902B7D90377B8C3B779137759830769F346FA6396CAB3469B0336CB128
72B32471B42270B42473B22877B12D78B32D78B1237AB32180B2217CAF217AAD2378AD28
75A92B77AE2B75B42973C02973BE2472BE1C72B2246CAE2B6DA9356EA33868A13768AD30
65B22D68B13169B13B69AE366AA83467AE3563B2405FB4415BB43B5FBB3859C03961B72E
5CB4255EB2265FB3255BB22860AB325CA64061AD3365B2216DB31A75B21975B41775B91A
78B5267AB02D78A5337EA432829D3386A028879F2482A5257CAA2C77AF2B75B42573B618
77C00E75B70A81B2078EAF0590A5028E9F018E9C0091A0008EA6018DA70089AC008AAF00
86B1008AB10086B2037FB70A77C01577C01A77C0207EBA257DB72777B92673BA316BB83B
66B74165B54463B64664B44A64B44B64B54A62B33F62B83865C02A65C0235FC02760C024
61C0285EC0295DC02A59C03253C04052B4504EAA604DA36453AE5156AF4B5AA54C579C59
5999605A9760648D6B7A7A748D6D77926D618F6A5281765A7E8C448BA82198951E9D8B21
AB9224A7A02E9B9C3994A03D88A83A84A5428D9C408E8F48858A568889578C884E928D45
9792439A923B989D308EAA2C95B81F91C0198EC01991C01C92B81C90BB1C8BC01E8CC021
8BC02687C02B87BB2E89B62F83BA2684C01E89BB1B86BB2285C02884C02A82C02B81C024
83BB1E83B22081B01E7FAD187CAA1A80AD197FAF1A7DAD1B74AA216BAA2468AC2A6DAB33
6AA83A66AC4260B03863A02C6E8B1C707A0F706704646100635E00635F00606701567708
5388174E9120538F115D88095D8A0B5F85046476006A6E00676700646000605B00615500
5B4A00564200503E004C3D004A3C00493900473700453400473600463500423000423100
433100413300453500473300432E003B2C003A28003C28003C2C00382C00382600362900
3427003123003223003224002E1F002C1E002B1F00261C00231C001E17001A1100130B00
0B0600050300020100010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
69972D669A2D699C2D6C992B72992A749929769928759B2A76A1296DA42864A32760A127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74912D709428719928739A26759526779928739B26729A28709E286FA22969A2265FA021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799B24779A24769B27759D26749B24749C27759C27749A2C739C2E749F2D6EA32A66A225
64A11F659F1C65A01E649E225F9B28629C2B609D2D639E2A669F2866A02760A2265DA424
62A4265FA4245CA72358A92250AC214EAB204CAB264BA92D48A93249A73448A83347A733
42A92F3DA93237AB3532AC3936AB3439AC3239B23236B03135AD3138AB313DAE333AAC38
33AA482EA95727A65F24A56524A86222A85A1FA55A22A26522A16B219D6F25937725867B
28787A287676257775217879208B6F1F9D651EA167229B6E239D68249D68269E6B289C6A
2F99672D9B65309C663596653C8B633D83653D8466398E6336955C3599573A9558438E4F
45854C45884846904C489D4C49A6484BAD454CAA4548A147459B4947A7424AAB3E49B037
49B2314EB42E52B53054B42558B41F5AB51D5DB81F63B5215FB1265DB0275FB3235FB426
62B32960B3275FB12962AE2E65AA3565A83B66AA3968AD376CB13176B02784AF1C8BA61D
8AA22388992685982984972B85962F83992E82992B82972A819B2E7C9E3279A73671B034
6DB43070B62773B62278B1257BAF2A7AAF2A79AF2A7BAC227FAA237CA92A75AC2A77AD27
7AB0227AB02479B11E77B21B77B2187AB51578B6157AB8167AB5187FB51682B31980B11D
7CB52174B91C71B91D6BBD2168BB286AB1256EAE2569B02163BC2662C02E64BD3164C033
67B13267AF3A72AC3175AD2874AF1F6FB0186DB1146DB61175B81479B31B7EA72D85A42D
889A37959B3498933993942E95912A808E2A8B883392902E99912997932D8D972D839A30
888F3F7DA5406CB22D72B2167CAB0783A404869F03809F0484A20486A10188A5018CA800
8AAF0189B0058AB0078DB20590B4038CB60388BB0A80C0127ABA1979B41F75B22375B42C
6DB53665B53A5EC03F5CC04460BB4C5EBA4E5EB84B5CB64E5DB74961BB395EC02F63C01F
68C01764C0185BB32656B43A5BB54755B157509E6151975C659D4D689D4E69A455659D5C
5F995D6C8A6173736779636F835F6B956D5FA2755C887A5E77894F96992FB19122B88F23
A0933189A03F87AB3D869E428E9141A98646978A4D9283589E7E57A57754B07458AB7551
A77B4B9F953D99A23692A6338AB8288FBB2493B42995B72F95BA3291BB2F8CBD3689BD3A
86B53D89B3418AAB3A8DA83690B5298FB61A8DB4198CB1118AB81889BD1A89C01D89C023
87C02389C02086BE2085B81C84AF1D85B3207EB52977B43A759F4D768A51718D4F6D9749
6B9D3B6A9D2C69961D70850F6F7301686600615C005E4D00594C00584F005B4F005C4700
584B005E53006359016158015F58005F5500625A00675D00635900645900604D00584800
5242005140004F3D004C38004530003E2C003D2B003F2D003F2F003F2E003F2B003D2D00
402A003B29003B28003B28003B2800382800362600332400342500352800352700302000
2B1F00271E00281B002A1900251D00291F00282000231C001B1800150D000E0500060300
030100010000000000000000000000000000000000000000000000000000000000000000
000000000000010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
73A01E729D1E719E20719E21709C226F9E23719E26749B28749A29729D2D72A12B70A225
6E9F1F6C9C1D689D1C6A9F20689D27659C27699D29689E2C659E2A63A0275FA5265DA527
5EA6245CA7205AA72255AB244FAC244CAD244EAD224BAC2548AF2C49AC2E4AAA3048AB31
42A92E3CA93339AB3837AC3C3BAA3A3EA93841AC3640AB393CAA3B3AAB3839AC3C35AC43
2DA95325A75A22A66221A76422AB6622A75D21A25A219B6720976B229473278C7C278080
2B717F286C7C276A7E1F66831F7B7B1F9174209B7421987524A06B25A46725A36A25A169
2A9F642C9E622FA06234985D37925B3D8F5A408F5E3C9459379954349A5236944D3C8D4C
3F8B4C40914C42994E43A34A45AB454AAD404BAD414CAA464AA3474AA94247AD4045AF3E
48B0374AB52F4EB72951B32457B41E59B52159B5255CB52A5CB42A5AB5255EB32463B628
60B52F61B42A62AF2C64AD3564A23C659F3D65A3386BAC316EB12E7CB22287AD1B8AA820
8CA4268A9E29889A2D879D27859B2C84992D7F952C83962A84972B7E96347C9D3A75A73C
6EB1396FB52F6FB52775B22878B22875B42D77B22B79B0247AAF217AB12D76B12A76B125
78AF207DB21E7FB41A7CB3167AB21777B71777BD1477BB147AB71481BC1383BD157FB617
7CB61A79B81A77C01871B61872AE1873AE1873AE1A70B31E68B62A67B7276AB5266AB62B
6DB42B6EB02D7AAF237AB11A77B01277AF1077B01178B6157DB31E84A9238AA5298AA62B
859D33879C3A8A973D869C36819A3281963387912E8E96299197288C9D2B8D9C328E9835
90883F898B467F95477A9F3D7DA72E82AB2781AE2087AA1A84AB1984AD1182B30E82B20F
80B61084B11083B40F87B40B8DB4068AB30287B70784B90B80B8117AC01974B92071B52D
6DB43766B8385EC03D5DC0405CC04B5DC04C5BB84F59B35156B65152B64A53C03757C01F
5EC01A5BC01B54B62558B33358B64253B75251A35B569B56649B4A679750679B575E965B
61955B6C88627576697F6B6D8B6068956861A0725F887A5A808D489CA027AF9C23B19926
97A83289B23B8EB23B909F399E903FAE8446A18053987E5395774E9F754DB2764BAE764E
A47F4D9F953E97A03B8CA93787B5328DBB3293B83291B8328FBB358DBB318FB53289B33A
89AE3C88A63B8AA0388FA4368CB0268CAE188FA60D8FA30D8FAA108DB61688BC1C8AC021
8CC0248BC02387C02186B91F84B41E81B5207DB32778B13677A14277974076982E799522
7C91187A8513737A0F7472056D6A00645F005F54005C4B005B48005A48005D4B00594100
5040005645005D4C005A49005945005A48005E4F006355006153005E4E00594500514200
4F3C004F39004E3C004A37004433003F2C003F2A003A2F003A2C003C2D003C2B003F2A00
412D003C29003B28003727003928003928003825003628003629003529003425002D2100
2B1D00281D00271A00241900271C00271B00261D00221B001A1100140B000B0700050300
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
749E1E749E1E709D226E9C26709B276E9C296F9B29729A26729A2A749A2D769E2C77A026
759B21729A1E6C981E6D9A206D9A266E9626709B266D9F2866A02A5FA32A5CA72557A924
56AA2255AB1E52A91F4BAA2548AE2941AC2A48AC2246AD2346AD2746AD2A46AC2A45A928
41A92A43A92E3FA92F3BAC343DAA3540AA3745A93944A8413CA74B37A84B32A6502CA456
24A25F1EA4611DA5631DA96220AD5C20A855209F5A1C91641E8E6A1F8A7321817927767D
296E7F296B822468831E658A1D73821B8B7C1D987A21987622A17022A36B24A16F269D6D
299B6B2A9C642B9A632F955D3395593A96563F95573B965537985335974C3794473C8C49
3E8D483D954C3EA14D40A84944AB4246AB4249AD444CAC484AA84649AA4046AA4344AE47
46AF4049B32E4FB52751B21F55B31E57B42058B52956B42C58B2295AB42557B5275CB62C
5DB4345EB33161B03361AD3661A43C64A23C64A4366BAE2870B31F7DB0198AAD188AA81D
8CA5228DA12685A126859F27839E2B859E2B8798318A952F8B933482913980944077A13D
71A93C6FB0346DB12B6FB02771B02477B12977B32774B02073B02171B12670B02774AF25
79B1217AB31C7AB41A79B31775B01870BD1B75BA1A78BD177CBD1680B41581B3187EB317
74B31A75B31779B21677B21376B11472AF1670B11A6DB22869B3326BB5256AB21F6BB31D
6EB01979AD1981AD177AAF1A7AB2137DB01180B21783B11B85A72587A72790A32886A629
7C9A3D849B408697437E9A3E7D96398F93319592239295238D932791952A9F8D33A18338
A17942937555887C5B76885A699A546EAB4D6BB2496EB5416CB8336EC0276FC0226EC022
6EC02273C01E78C0197FB80F82B80A86B70585B70487B50884B50C84B8117DB71A7FB227
79B32B73B42F6BB83962C03F5DC0475CC04F5DC04E5DB85059BB4D53C0404EC0344FC026
52C02455C02558C02358B62856C03458B93F51AC4D55A04E619A4E628C585A865C568464
5D83616E78667D6F6A876C6C91656B97666296645F847759808949A29D1BAB97259D9637
90A83A87B63D89AC3D9398439A8D48AB794BA9764BA577489C7349A27145B57840B07E46
A1814C9E8E3D959A3A87AE3986B93289BA368CBA3D8CB63C8EB93F8CB43790AD3D8DAE3E
8CA8378EA3348EA13290A52E8CB32091AC148E9B0690970390A00A8EAE128BB71B8ABA23
88BC228AC02388C02489BD2285BB2081B9227CB4297AAE3279A2357A9E2A7A95187C8108
767000726A006D69006C6600656000645A00605500584D005B4700594800584800584500
553E00523F005444005445005143005545005846005A4C005E4900574000523B004F3B00
4D3B004C35004936004A33004432004030003F2A003B2B003C2B003A2A003B26003B2600
3E28003B2B003A28003824003725003827003626003627003529003326002C27002A2100
2A1B00291900251C00241900241900231B00221A001D1700151100100A00090500040000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
739C22739E22759E24759D23709F26709F25729C27789827789D29799D2A799C2B76A025
70A0226B9E20669D1E6B9D216C9B256D9A22719B2073A1226DA32066A6205EA91F5CAA1E
57AA1E52A81E52A61F4CA52548A82743A82B4AA9294EA8244DAA234DAA254AA92747A827
48A82548A82743A9273EAD2B3EAD3242AB3A49A9403EA94C30AA6229A46A24A26F219F6F
1F9C701B9D6C19A3691AAA6120AF5921A75620985C1D87651B816B1F797422747A2B6F7C
2E68812A678725658A1D5F8F1D6D871D86801D957E2099781FA0751F9E76229B7B259577
27957325946C28966D2890632C975B309B583799573798533599513696493795423A9345
3C9548409D4740A44441AB4144AB3F48AC424AAD424CAC4048AA3E46AC3945AF384AAF39
4DB1384FB42D52B42452B32056B22157B82058B12556B12759B22858B42A59B62E5BB334
5AB23A5BB2395FAF3860AB3760A63A60A03A63A0326AAA2272B01482B01289AC198CA81F
8CA6218CA52689A026859F27829F28849F298B9A2D9095328E8F3887943B83953E7C9B40
76A23E6EAD376BAE326AAF286DAF2475B22677B22275AF2275AE266FAE2870AF2B71B02A
74B22973B42775B52770B32273BD206FB61F71B52173B61F75BE1C7ABA1B7BB41F79B31F
73AF2374AF1F78B11878B31672B21972B31C6FB1226CB2296DB42C6CB72367B4216AB11C
72B01278AE0B7CAC0B7CB10F7EB51180B41A89AE208FAB1F92A21F8DA1268AA12F80A72E
7BA03B80A83D79AE3C77AA3978A23582A03188A029859F2D8799328E94329A873C997A46
957A4C887959817F5C708E5666985667A95566B25666B64A64BA4165C03368C02E6BC02C
69C02D6FC02B74C0277BC01E7DC0167FBB1282B90E7FB80A82B60B85B60C83B41282B51F
7DB7217BB32772B53666B73E5DC04A5FC0535BBE545CBF5454BA494EC0394FC03048C02C
4DC03053C0335AC0265CC02358C02E55C0374FB44454A84F6199515C845C577C64537B66
5F77686B706C776B6C806E6C8E6D69926A629362627E755B7A8A4C9AA1329D9D35909A40
89A3418CA643919A43978647A27948B26A4DB66D48B77245AA7041A56F3EB27939B18444
AA8948A49140959C3D89AD4088B23D87B23B88B1408EB3408CB6408BB1398EAF3390B533
8FB6308DB72E8BB7258DB51C8EB31395A90B949B03949602939B048FA50A8AB01189B619
87BA1E8BC0228EBD228ABD1F86BC1E85BC2184B4277DAB267FA01D85971784880A817B02
776F00716C006D6B00686300626000635A005D54005D49005A4700574500564900584500
554000523E00543E00554000524200554300544400564A005846004F3F004A3900473900
483600473400473300443500443400402F003F2B003A29003D2900392800362700352500
3622003623003A24003321003220003527003426003625003527003125002D23002A1F00
271A00281C002818002517002517001F17001F15001B1300130D000C0500060200010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
739C1D739E1E76A01F759E21729F22749F24779E25779C25799F277B9D297B9D2776A027
739F27709F276D9F246E9C256B9E246F9E22729F1F759F1E75A21E6EA31E68A51D65A81C
5DA61F59A62053A4224FA4274DA3274EA22754A4275CA42557A82252A92151AB224EAA22
4EAA224BA81F4AA91E46AC2147AD284BAC354AA4433D9A592C9B72229C761D9E731E9F6E
1EA1661AA4671BA7621BAD5E1CAE581EA45B1D91601A7E671D756F1F6E7622697C2A6780
3163852F648A2563901E5F931B6F8A1E86801E947D1E97761F997820987F23968024947A
249676219A75269A6E2899662A9A5D2B995B2D985632965433935536974E359B4A379F48
3C9E453CA44341A83E44AA3E48AD4148AD454CAD424BAB3947AC3848AF364BB3314DB432
50B43554B93051B52754B62259B5235CB81F5BB42158AF255AB22A5BB42F5BB43059B135
5BAE405EAF405EAE3E5FAB3B61A73A63A53664A72E6DAD1E7CAF1187AE108EAC188CAC1D
8BA91F89AA2084A62384A4257FA3247FA32886A02F8E98378C933D8692408391407C933D
769F4070AD3D6AB2386CB12A6EB02576AE2377B02373AF2172AF256EAF2B6FB02871B82C
74B32972B52575B12974B12872B3226FB82071B62474B71F7BBA1877B71A78B42579AF2A
73AD3374B02678B31A78B21979B51778B01979B01B7AB31B76B41C74B61D70B22070B31A
75B40F7AB20880B4097CB40B80B51783B32190A72492AA22959F23909F29869E377CA134
769E3C74B43573BE3373B53374AB3577A5347AA13479A43A7EA13D7D9C407F8C4B7F7C56
7F74587B775B7F805174934C6999546DA25570A7536DAD486AB04069B53C6AB8386DB637
6FB6396EB53876C03A77C03277C02D7AC0257AC01D7ABA137DB40D82B40B84B70F83B91B
83B71E83B32180B22475B22C66B63663C0405FC04B5DC04C5ABA4B59C03A5AC22F5BC127
5CC02960C02566C01A64C0185FC02158C03055B73F5BAD496096515D835E597D6858776D
64776D6D766D71716F77716F836F6C8D68659562627E7563778857989B37A2993A959842
9094489C8D49A77F47AA6F40AD643EBC5E44C76044CE6340B9663DAE6A3AB27735B4833D
B38D47A899409B9F3F88AA4085AB4384A54884A3428AAF3E8BB73A8FB52F8EB22793B925
91BA218FB92290B81990B21292A80B959F059596019691009492009099018C9F0589A911
88B41A8AB81F8BB9208CB91E8BBC1B8CB71B88B21F87A71A8699108789078380017D7700
776F00736A00696100676200666100645A006050005A4A00584400554600594E005B4B00
584600563F00523F00523E005442005540005741005642005644005241004D3800453200
463200443200483400453600433400412C003D28003D2A003B2D00392A00362800352800
312200332200322000301F002F1F003120002F25003125003026002F21002F20002A1E00
261B00281800251A002217001F13001C1400171200141200100C000A0500050100010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010000010100020100020100010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6FA11971A01974A11E74A11E749E1E73A12177A32179A2217AA32278A12377A12378A11F
72A11E71A121719E23729D25749D27759D26749E24769F23759E246F9C246A9F2367A124
63A1245DA62357A52752A22A55A0275BA12864A22665A5235EA82254A9204DA91E4BA91E
4BAE1F4FAE1C4AAC1945AF1C42AC2342A732409149377F66287C7F1F8D7E1B97761A9A6B
1EA2621CA96119AB6117AB611BAB621A9D671A88691A76701C7075206A7C2865802F6183
385E8B33618F2565951D65931B7A891D8D7F1E937A218F77218D7A1F8A7F228D8124947A
229775259C76279E742B9D692D98642D965F2B945D2B8F5C2E8D5F2E93602F9E5834A44D
38A4453CA54041AB3A47AB3A4CAC3F4BAC474EAD3F4CAC374CAE384DB2344EB63152BB31
53BD3255BA2A57B9235AB91E5DBA1D60BB1C60BB1D5FB32160B52862B42D62B6345BB13B
5CAD405AA8445DAA4262AA3F64A63B65A93364AD2B6EB01D7DB2128CAC128AAB1886AB1C
83A92185A92083A52080A3237EA0267FA32A87A12D8E9A349297398C903F838C407C8F40
75964674A64371AD3C70AE3070AD2D75AB2B7BAC2C7CAA2B74AA2A6FAD2B6CAF2C6EAD2A
71AF2573B22178B22476B12776B22775B42573B82477B61B79B81876BD1874B51F77B323
79B1247BAF1974B41475B21176B11576B11775B11873B21974B31A74B21B6FB11A72B311
77B40F7CB60B7FB6127DB21B8BAC2096A91F92A62490A62291A32789A33081A23B7CA837
74AD3571BA2F70C03075B53274AE3479A8347B9E38779D40779D49719D4E6D9A576E8D5C
6F835B70885576914D70A4446CA54868A94B6EAF4A6DB2406CB63569B93364C03168C035
6AC03C6FC0406FC03C6FC03570C03374BD2E75C02779BB207DB81483B81082B50D87B510
84B61880B71F7DB61F78B2206FB62367BB3161C0405FC0465CBA4761C03D66C03764C031
63C02F65C02066C0156AB81163B9185EC0235BB73C5DAE4B6091525F81605C7C675A7C71
637E6E697C726F717671667C776877876A7194636A7D766A738C5F90A1389AA531979D3D
949845A58C47AE7B43B36C3CB65F40C66344C26549C4604BB3663EB16D37B57337B27E44
AB8D4F9B9D4091A43E89A044889C45849949839F4886AA3A86B82D8BBA2191B21493AE10
93AE0F96A50E95A60C95A20B929E04949D01969200938F00939300939500949502919B09
8EA20F8DA7138EAC128DAC118FAA0E94A60E94A30D919E0C899106888602827E01817700
7972007568006D5E006A5F00686000635C006355005E4C00594C00574C005A4E005A4D00
594C00564A005342004E3F00563F005344005341005642005847005445004C3E00483400
4532004431004534004537004135004030003C2700382400352700392500382800382800
3325003323003323002F1F002B1C002D1B002B1F002F1F003020002F22002E22002A1E00
271C002319002316001D14001A1200171100130B00100A000B0900080400030100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6BA2196E9E19759B1B7A9C1F7A9C1F789E1F77A01F7DA1217CA1207BA21D79A31E76A21D
72A31C77A11E779F237C9C257B9C2B799D2A779B2A769A27769B27719B266C9F266CA228
6AA32768A32663A22862A02962A02866A1256BA2216AA41F66A81C5EAA195CA91852AA1A
4FAC184EAD174BAD1842AC1C3AA92630A03C317960315E7B275E8A1D7D821A92781A966A
18A26219AA6115AC6315A76A18A36E1A93731D80731F6E75226B7A26667F2D6183375C85
41588A3A5E8E2C6490216C901F83871F947E1F947E21877A22827B237D82228382249279
249B7224A07428A37629A2722A9A6E299664299160278E642B90692A9B6A2CA55B2EA84C
35A94039AC3940AE3148B1304FB0344FAF3B4FAC384FAE354EB03452B33554B63255B92E
57B92A59BA245FB71D62B71963B61A64BA1C62B8215DB5205FB52760B73062B7375FAF40
5CA6455AA1485BA54A60A74462A94062AD356AB32573B51A7EB11382B01382B31581B218
82B01B83B21886AB1A83A91C83AC2082AB2489AA268CA6298B9E3187943C818943778B49
74944B709E4A6EAA406CB0376DAF2F72AE3070B02F75AF2A76AE2C71AF2B6BAD2C6BAF27
6EB12274B41D76B41E77B22573B3286FC02774C0227BBB1A7BBE1778B41876B21E7CB41B
7CB3197DB4137BB20B76B20E72B01570B21A70B01C70B11B72AF1B72AE1D74B41475B710
78B3107DB41583B22080AA2A94A32898A124949E298BA42B8BA32F83A73580A5377AB233
73B53575BE2E73BE307AB33179AB317FA5327E9B407498456F96516AA1576AA45566A856
64A85468A64E6AAA466EB43F6CB64169B7456BB8426BB5396AC0336BC02E6BC02D6DC02E
71C02E72C02C6DC02D6EC02E70C02F75C02E76C02D7BC02979C0207FB91782B41386B510
85B4137DC01A7AC01C7DB7237BB82575B72C68C03165C03E64C04568C04268C04069C03A
6DBB3069C02769C01A6AB91269B91266B91B61B8355FAF4962945563845D647C6B627C70
60806C667C6D6D6B786F657D7E647E87657790647478766B6C8E6188A0399B9D36A0993D
A19B43A58D3EAD7941B86E39C36A40CE653EBF6A47BE644EAE6E39B77133C2703EB17D4B
A08D548FA1428CA1418F94468F95458B9F4283A93D89AD2D8CB21F8FB01494A90D939C01
949900959400939500939500939500919400929400939100959100919400919000939400
9098028D9B078A9E088C9A088F9A039597009298008D9500898D00838800857F00827B00
807500776E007167006B61006C5E00665E006656005F55005B4F005B4D00594E005B4E00
564E005A4B005545005342005641005742005545005541005643005245004E3B004A3600
4A36004736004531004530004231004131003A29003A2400382300382400362800382600
3827003327002F21002B1F002C1E002B1D002C1D002D1C002D21002D1E002C1D00271A00
2318002116002115001D15001A1000160D00100A000C0600090400050200020100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
75A31B76A21A78A01C7AA11E7DA01F7AA01D7BA11D7DA01C7EA51C7AA51879A51A77A51E
77A51C79A21F7C9F1F7E9B267B9A2A799A2A799929789C28769A29759A25759E29749E29
759C2C739B2D719D2F6E992D709C2A709F27729C256E9E206DA21D69A51969A71961A719
55AC1B4EAD1F48AB2A42A93239A13E2F944F2F7E6729737623727D228D701C9C6A17A263
14A76112AC6611AA6B13A272179A761C8B741E79722769762C677A2F6483355F843E5B89
45558A3E5E8C2E688C216E8C1F85891E92871E9285208180247D80247984257D81268E75
259B6F22A07024A27427A1762B9B78299A672A945E2A955F2C9B622DA45E2AAB522DAD46
34AD3C38AE3240B0294BB02851B22C51B13350B03851AF3751B13553B13C56B23A59B433
57B9245CB71E61B41B65B41A63B81E62B82061B6265FB3285FB32C60B53461B13C5FAA40
5AA044599D475BA1475DA74162AD3B6AB12971B61C7AB61180B30F7FB5107FB7127EB813
80B31482B31287B31282B51283B51483B41787B41988B31D85B12180A62C789E3F749745
739747719C456CA44069AD3B67B0386DB03270B02C71B02773AF236DAF236BB12465B223
6BB41F6FB31D72B61E75B52276B42278C01E7AB81B7DB5167CB6137AB41875B21E78B618
7AB5127FB40F7BB30C75B01273B01C6DAF1F66B3216DB01C71AC1C77AC1A75B11778AD1D
7BAB2287AB228EA8288EA52B96A025939F27919E2A8BA22E87A23580A83382AA3576B432
76BE3176BC2C77BC3075B42F74A8317C9F3D7F98467194476D974C6AAA4E6BB04B67B34B
63B54765B74365B73F68C03769C03C62B74064B93B66C03265C02D6AC0276EC02572C025
71C1266FC2266AC02869BF2D6DC03070C03071C03473C02E77C02B7ABD1D7CB61682B312
85B30E7BB81378B9187CBA207EB6227AB12971B52A6CC03368C0416BC03F6BB84A6BBA43
6CBA3A6AC0316BC0226DB71767BA1363B91E64C03A5DB4505E955C627F626C786D6A7571
66756F69716F6B647773627E7F658281657C8061756E776F61956183A739949F33999A3E
9C9847A58B40AE8339B77734C27433C97036C46D3CC3674AB16A3FB06E36B47539AD7E44
A6884F9997489096488C924A86A34684B23984B62789B3198BAC108FA70A93A103939800
939300948E009A95009896009296009290009290008F8F008F8E008E93009291008F9100
9293018C92028D8F028F90029190019293009192008B9500868D00878400867D00837C00
8178007A7300766E006F6B00706A006D64006A6200685D006059006052005D50005B4F00
5B50005B4E005A4C00574200514400554000554100513E004E3D004E3B00503D004F3D00
4E3800493400432F004635004332004030003A2900392600332400322500332300332400
3523003125002B1F002A1F00301F002F1D002B1E002C1E002C1F002A1D00281B00271900
2518002015001C11001E1000171000100D000E0800090500050300020000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
80A11D7FA21C7DA11D7BA01F7EA020819F21809F227DA01D7AA31A78A51979A51A7AA122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73A2107EA3197FA119819F1A869E1D869A1E859E2083A01F7DA21C7CA31C7DA3207EA127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6EA50C78A3167BA21884A01A859C1D859C1D84A01D84A11C7FA21B7DA11E79A0207CA124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6CA50670A71576A5187BA1197DA11B7FA11981A41A7FA41980A41A82A21C7EA11D7CA11C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669E066BA2126FA11673A21974A41976A51678A7187BAA187FA81880A21880A4177EA018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659B05639C066AA2136EA61577A51876A81679A8157EA81683A51884A21783A21681A317
7BA41579A71676A61975A71974A31A7AA31D79A41B78A51576A51479A6157DA81584A316
87A11985A01B82A11D7CA41F78A41E73A71974AA176DAC1561AF1254B00E4FAB0B4CA90D
48AB1443AC2836A5462A965B1F8A6B1C7E7D148390128790109A8514A47F16A97A17AC7A
16AB7B18AD8015A383168B831671841174810E767F0E777C14737E186F801B6B851E648A
215194253D9D2633A12534A223489C22599A1F6A9A2471952079951C81961D88941A8B90
188F8E21918C2492862290852091801D957D1EA0771FA57320A96823AF5727B44C2BB645
33B54039B73141B82A47B62B4DBE2F52C02F55BA2B58B62859B6275BB12260B0215EAE26
5CAE2D5BAD375BAF405BB14259B24559AE4759A84B5DA34A5EA44961A64661AC4163B136
63B52366B7166AB7106AB6126FB31570B31670B11671B41871B61A70B5206FB3296FB22A
7EAE1C90AA1097A2129BA1169DA1199DA0199E9E18A39D1CA89D1DA6991FA39225A28F2D
9C99299A9C25939C2882A32873A63467A04368AB3C6FAF3371AF3073B12974B22471B223
74B1207AB11F7AB01E7AB11C6FB11974B11975AF197AAE167EAD167BB01378B11378B116
7DB01981AC1D80AC2480A9237BA82675A82372A92170A91F76A41F7BA6217BA51E7BA21F
7D9A23829527869331879C307D9E367C9D337B953874A23A72A93872B72D6DC02470C01D
72C01977C01578C01477C01874C01F75C02671C02C70C0286EC02770C0276FC02F6DC02A
6AC02A6CB8296BB42970BA2671B62D75B22871B52574B92A73C02B79C01C77C01476C014
71C31574C21572C41774C61972C12072C0206CC2216BC02967C2306AC02E69C23671C036
71C03879C0247EB61688B40D89AF0989B30A85B3157EB3217EB81E78B42373BA2571B138
69AF5066B84367BB3369C02B6DC02A6CC03567B44963A2566492616A8B6775846972796C
766971786872786E777473776C7372647D6C5F8C6767A75476B8448CA8309E932EAB8132
BC7633C07135C56B37C97439B8703FA06C49A87241B97345AB8949978E4A8A954884AA23
8FAB11989B09969403959100948B00938F00938F00938E00928F00918C00948F00959300
9395009693009690009891009892009A8F00978D00959000959100948E008D8E008C8900
878D00858F008793008592008692008A91008E8A008B8600888600868B00818B00818600
8082007B8100767D00737C00717B007278007178007474007370006F6C006C6A006A6400
6B67006D6600696300645C005F56005D54005B5100595100584D00584B00574700504300
4D3D00483C004339004637004233004230004135003D2D00392D00382700352600342500
3425002E22002D1E002A1E002B1A00281B002518001F17001F12001E13001D1300171000
120B000E0500070300020100010100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
669803699C066DA50E70A5107EA8177FA91681A71586A81788A61889A21987A21884A31A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6D97016E9A0372A10875A10975A20B7EA51480A4168BA41A8BA31A8C9F1A8C9F1A879F18
82A21681A7177EA61C7DA3207BA11E7CA01E839D1A859C158B9C178D9F18869F1B849F1F
7DA21F7BA31D76A51D79A72276A91A73A80D6FA8086AA70860A60858A70A52A4094DA60D
45AA193BA23A298E5C24796E206C7A1C73811A868B17988A12A08D139F9114A19413A296
15A38A14A08116957A17837616727C16897D1799791CA1701C9A751D92811E878C1E7491
1E54971D49992051971F609523668C236E8A26708C247D8D22898B20908D1F8A8F217F8F
207F8C24878A288D87279384239C8521A47E1FA9771FAD7024AE6727AD6029B05631B149
39B44446B43453B52458B41F57B7205AB51F5AB42059B0255DAD275FAD2F5AAD3359AE38
5BAD3D5BA9415CA5475BA3455DA34361A33F63A2376AA03867AD335CB22958B62758B622
58B61C5DB7195FB51B63B42162B32564B52365B61D65B61966B21D64B11F63B12964B234
6EB1287BAE1587AD1598A9169DA8169BA9199CA718A0A31CA29D1EA2931C9F911DA5931F
9C901D9A941E9D9A21979B1C85A2237AAB3275AF2B76AD2378AD207DAC1B76AE2071B022
72B31E71B11C6FB01774B1147CAF137FAF1581AF1384AD1287AE1280AE137FAB147EAB13
78A8147FA91A7FA92081AA1E81A9217AA82174A72077A6247BA82681A8257FA12D87A12B
8A9A2E829934749B3B709F376F98386BA03564A13769B0346CBA2A6BC0216CC41C74C018
78C0177AC01B77C02175C02175C02178C0257AC0297CC0267BB2277AC02276B72771B62B
6EBC2F74B52A76B12A72B32E72B33073B82474B92175C01A76C0147BC0127EC0137BC014
75C11475C31571C41573C31672C21872C1176FC1196DC0236CC02D71C02D6CC2336DC130
6DC0376DC02B72C0207DB81387B00A8CAF058BB40B82B71882B81C7CB5247BBA1D76B32D
6DAE3E72AA466DB14966C04065C33D6ABA4368A7576B995F708E60758D5E79925E778E5D
7B855E817E627D776B74746B6B706E647C6A5E91686CAB5387AD3EA092359A8B3E9B8544
9B8642A97936B6722AB9752DB97439B47240B27A48B48150A396498EA53E81A81C8F9F0F
919600939200988C00978D00988F00968E00948D00948C008E8C008D87008D82008C8200
8F85009087009185008F84009186009089008D88008B86008A8900848500827E00807D00
7F8300808000818500848A007D84007D84007E81008083007F83007F8500858600828600
787F007278006F72006D6F006A75006D77006D76006E71006D6D006A6B006A6B00686800
686B006869006766006A67006A6A006B66006660005F5A005F58006054005E55005E5400
5D54005C4F00574A00504400493C00463C00463900463A004434003B2F00382700352800
3526003426002E2100291D00291A002519002216001A0F00160E00150C001109000F0800
0B0400020100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
749900729901789E0677A107799E0878A50C7AA1108A9F1A8CA018909B178E9D1888A014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7594007A9700789A00789D00779C00779F09799E097C9B0B8C9D158E99178E9A17879C16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759403769701779900789D00769F00739E00749E06799D077CA10F7E9F11879F1886A118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749600749B01719C00729F0071A000729E00729E0073A00073A40A75A20A77A10A7FA413
83A41282A71283A71285A015909B198F9B188B9C1A86A31683A5157CA6117BA70D7BAA0C
76A80873A70772A30775A007759D03749E046DA2086AA50A5FA70D51A71848A52244A72B
3DA93035AB372CAC4324A64E20A4531AA25618A55317A6521AA35C189E6F19A37F17A587
16A48B16A08E189C8A1DA27E1DA6771EA9791CA9801EA8851EA089208E8F208493237E93
2479972A7096277391217E8D20848C23888E228E912190911F929222928E24938827947F
28947C27997D2B9D7B2BA47829A9732AAF622EB45631B64935B54039B43F3FB5364AB728
55B6225AB4265CB3345BB13B5EAF3862AF3661AC355FAC395EAB405DA8485BA5485DA845
61AA3B62AD3164AE2765AF2161B4175CB4175CB5175FBA1962BF1E64B82162B6265FB727
5BB42D57B43055B73156B73552BF3351B63A50B63B4EB6394FB73753B63950B53D55B342
5BB33F64AF267FAA188FA6159CA116A59F1CAC9720AF9121A89718A79B18AB921BA88E1A
A38D1BA7901CAB8D1CA3941D999A1C87A31C79AA1E75AB1E73AC1974AC167CA81984A41C
83A61C7BAB1776AC1577AD1880AC177FA90F7DA70F80AA1C80A81B79A51A7CA91A8AAA1C
7EA41F77A62776AA2579A72177A4267B9F267B94267B952C819F3383A52C87A0217CA02C
769D3573AA3372AF2E71B52970BE2572C01F72C01874C01576C0127AC00E7AC01076C011
77C01179C0107AC00F79C00F81C00D7FC00D7FC10D81C00D82BC1083BB107DBA107DB810
7CC0117DC0127DC0157AC0127DC0127FC00F80C00D85C00C80BA0C7FBA0F7CC01184B80C
82C00C7FC01274C0156BC01762C01962C02064C22A68C22668C52F67C12E63C13168C036
6BC0446CC0366EC02E74C0207CC0148EB80A93B00093B1008EB90683B9097AC01170C020
6FC0296DB6376DB44572AA506F9B5871975B7396586F9851739351758B54728058778455
798956788B5A73945A65AC4F66B6497DB137929C34A28438A87D3BAC7B389E8234A37E2F
BC7316C96922D46335B65F42AA634DA9704F9782537E9B4284AB1A8D9F079195018F9400
8E9500909600919000918E008F87008B8000887F008D82008B84008C83008C7F008B8000
8C7F008A7C00897B00877B00867800847C00897F008883008D81008B8200887D00847D00
8579008279008375007E6F00826D007C6C00756A007165006B61006B5C006B59006D5C00
6E63006C65006869006666006260005F5B005B5C005C5A005D5C005B5C005C59005D6000
6363005F6500615E005F5900625A00635E00656100636100656300646000625D005E5A00
5B55005A56005B5700545100514A004E44004A41004940004339003D3600392E00332800
2D22002B1D00261B002419001A1100130A000E07000B0500060300040200030100010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
709A006F9D016D9D006C9D0072A000749F0076A100769F0074A00077A40778A4087CA809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719900719C006D9F006E9D0075A00077A00077A50073A50076A20079A30077A10076A406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779300749500729A00719B00769F0179A30176A60175A40076A30078A20077A00071A300
70A60271A60275A50779A1077AA30778A50778A50779A7077BA40778A30876A00874A00A
719E0C6F9E0B72990C739A0B749C0C789B087A9B07799B02719E03629F0A58A1134EA325
46A5333FA53932A2442A9653268C63248269268A6B25906525926424916623956B1F986D
20976C1F976E1E98751A9B7F199B8A199B8D18998D199A90199A941A9B9A1B9C9D1B9B9B
1D9A971D9D8E1E9F87209D8421968622948A1E948E1C978C1E9D8524A07D269F702A9C66
299F6827A36B26A46A28A46628A9602CAE5B31B35237B6413BB63743B6304DB52754B02A
58AE355AAC3E5CAB3F5FAC4164AD4068AC3C63AB3867AD3366AD2E66B22565B11D64B216
65B61167BD1164B71360B51563B21B60B21E62B22661B1295DB42F57B43450B33A46B241
45B34544B34845B74148B93D49B33E4BB2414BAF474BAF4947AF4B44B24F45B35849B253
50AD4C58AC336BAF1C88A814999D109D9518A29312A8940F9F901C9E8E1DA89016A2881A
A18222A68A23A99022B5831EAC8C19989B1988A52186A7237DAB1F7AAD1F80AB2687A725
829E22819A23809D2572A02576A52781A71F85A61B839D1D81A11E85A21C80A11877A220
7CA5217DA21E7BA51E78A72277A72178A7217AA82B81A62989A52776A73267AA3662B433
65BA316EC03076C02474BF1A74BA1778BC187BC01782C0137FC0177FC0197FC01780C016
7CC0157CC01782C01983C01C81B81C81B81B83B81887C01184C00C82C00B81C00C80C00F
7EC0117FB91384B91487BA1184BC0D83BC0C81BA0D83BA0F7FC0107EBD0E7CC00D7CBB14
78C0187AC01676C01572C21C6AC32A68C12164C02165C0225FC02960C02560C02962C130
65C13769C32D6AC12972C01E75C01D82C00C8CBA0297B60396B70A94BC0A90C01485C11F
7FC12076C02E71B8396DAE426BB03F66B83863B83A6AAD4073A5457D9D447AA0446FA63D
69B1336EB72975B22C7DAE307FA23A8B9443928644AB7D31B47C2FB77827BF6C34C06041
B35747AF634AB76F4BB66B4EB36953A27E4C8F973585A11691950B8D89008883008A8000
9081008D81008C87008C86008B86008D82008C81008881008B84008C82008A83008A8400
948B00928A009189008D84008B7B00867700837300847000816F00837400857800837600
7E75007C7200796D00766C00706700746600776800766D00766D00726C00716800736900
7367007366006E60006B5700665800655A006864006967006A6A006B6A006B68006B7200
6C6E006968006463005F5F005A59005A5B005B5C005C5800585800575600515300514F00
4D4A004D4A004F48004D4B004C46004A4500454300403B003C35003A32003830002F2800
271E001B1600160D000E0900070300010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
769301759200749700739801759E03789D01799F01789E00799F0079A10076A10076A000
75A200779F007D9B007D98007D9A007EA0007EA2027BA3087AA20977A10973A009759F09
719F0A719A0A729708729D08759E0779A00877A008789E08729D0A6B9D0C609E12569F1E
4FA32B47A73638A0452E91552A856729786D267A6F267F6D27846D258870268F74229678
239A75239A7821997D1D9A81199F8719A28618A086189C8816958E179397189399189398
1A93931C939020948D21978C1F938F1E90941D91971D97961D9E8D21A38124A274299F6B
289E6827A16D27A26929A36729A85E2EAD5C34B4523DB74241B53947B33151B02B59A631
5CA43C5EA74362AB4467AC3D69A93767AC2E67B12C69B3276EB41C6CB51869B61367B611
68B71269B71767B61C63B22161AE255DAD285CAB305AAD3756B03A4CB53E46B64141B442
41B44742B74645C03E45C03B49B73D48B44348B34D44B25141B15441B45744B3594BB24B
54AE3F5BAD2F66AB2386A415999C129D90209A9011A88E10A08622A68923A99118A1871F
A87E2AA98822AB8F22B38820A28E198F981E89A22384A91D77AB1B76B01D81AD2280AA22
819F2E829E2C829F237A9D2A7E9D2A84A321849F1E859A24879A21889D1B799F1D72A527
7FA12388A01D7F9D247CA12778A21F82A32585A3238CA4208CA1227BA42D6EA93267B230
6BBA2E6EC02974C02273B91C75C01875C0177AC0197EC0167FC01A7CC01880C0147FC013
80C01181C01781C01F80C01780C0177EBA1582B51185B90F84C00C82C00D7DC0107DBB19
7EB6177FB71487B91384BC1183BD1082B80F81B90E81BE107AC01177C01174C11273C017
73C01F73C21771C21770C3206CC22F69C12263C02162C0255EC02D65C12865C12868C22D
64C3386CC02E70C02374C11874C0117EBD0A8BBE0898BB0B95C00C91C1188CC01E87C01D
83C21B7BC51D71C32A6EBA3B69C03768C03268C03069C0316CC02B71B82475B92574B727
70B22B6EAF2E71AF3379AA3280A03C8C983D978D42B27E3FB4793BB3772FB96F2DC05D39
BA5450B3595EAF6664A8695BA16C558D815389962C88920E8B89028B82008B7C008B8000
8C83008E81008B7B008A7C00897E008B7D008A7C008A7E008C7E008980008B83008A8300
8E83008E84008F84009184008D81008B7C008A7900827200816B007E6C008273007E7500
7B7000796C00786D00766E00736C00756900786C00756B00756E00746800746A00776C00
756E00766F007163006B5B00655700675400675A006760006766006969006B6D006D7400
6F71006E6E006A6C00686700616700606600626200615E00605C005A5600594F00564D00
524900504A004D49004B47004A4800494700454100423A003D3500382F00322B002B2200
211900190F001209000A0400030000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
7199036F9801709901739A02749A02759A01799A007C9B007A9B00799D00789F00789C00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749901729901729C01729C02769B02799C017797007A9A007A98007999007C9F007C9C00
7D9D007D9A0080960081970082980083A003839E0A80A00B7CA40C79A40A71A40C70A00B
749D07779E0877A00A72A40974A50771A70771A40870A60772A2086EA10867A0095FA210
57A21D4CA02C439F3B3C9F46379657318568307877316E7C306E7D2D737C297E7D228A81
1F91811F9083218E831F8F851B998519A1851CA1861B98851C89891C848C1C838F1B8290
1A808E1C7C902080931F85971F8A9D1E8C9C208C9A1E9598209C9020A28521A37D24A177
23A17125A3702AA3682DA7642FAA5C36AF5240B24748B43951B42C5FB21F63B01F68AE23
6AAC206EB01C72B01B74B11673B1126FB4116AB9136ABB1669B31765B31463B21865B31B
63B32760B22E5AB13259AA3059A83255A73452A93A52AA404DAE4043B1413EB44741B549
42B74742B94443BC4245BC4042BC3B43B83F42B74341B6533FB35D3FB35A44B2514BB33F
55B23559B12B67AF2986AA1E949E169E8B1EA08919A58718A67F239E821C928C1AA0891E
AF82209F8D199F9220AF891C998D168C8C2280981B83A5187EA12083A2207EA61C88A521
8C9C2783A1217CA7268B9E29879D208B9726909A248F9620899924939A268C9A22869A21
81A02C7EA22A7FA01C81A11C879E228DA41F8EA12188A32286A03080AB347AAF327BB52B
78C02572B92273B62373BC2278BC2376C02375C01E7CC01B7CC01C7CC21982C01580C015
81C0157CC0147EC0157FC01080BB0F7FBA1180B41481B80F80C00D7EC0137EC01986B81B
87B21C84BB1684BA1385C01682B9187EB9197ABD1A7BC01678BD1876C01B72C01E74C026
73C02E72C1226FC01C6DC01D69C01B6DC11868C11664C01F65C22669C3206CC2216EC321
69C1296EC0256DC02774C31978C41081C2108BC31490C0198DC22587C52A81C52687C528
85C82383C3207CC21F79C61E73C71E76C51B77C51A7AC21E78C32077C22478C02974B930
75AF3676A53A769F3980A2378D9A3A8D90418F8A47A7873CB6793FBA6348A17047927641
B86E42B66A52AE6264A0666495745C7B98427F98208383078676008B7400887B008A7F00
8E80008E8000887D00887700897700887A008B7C00847F00868100887F008A7F008B8000
8A83008B8300887E008882008C81008B80008778008578008375007E74007D72007B6D00
7C70007F72007F74007D7500827700827A00837D008379007B73007973007A74007A7300
736E00706A006E69006D6B006C61006759005B4E00594C00594D00625900696800716F00
6F7400727600747600717C007278006E77006D7300676F006A6800696A006A6A00646300
605A00595400545000504B004D4600474400464300423C003930002E25002218001B1100
120C000C0400070100010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6F9B006F9C00709D01729F01749F01769C00789B00779900789A00799B00789E007A9C00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699F03699E026B9F026EA1016AA0006DA200719E00739D00769E00729D00759F00789E00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63A30268A30668A1066AA0026BA1006CA3006EA40173A00075A100729F00749A0077A000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66A3036BA3066EA30772A2036FA00070A10173A10178A100789F01769F00789C0076A100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6F9E0171A10574A104749B01739C01749E0179A10179A101769F01769D01739B00719E00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739D00779F01789D02749D02759C02759C01779E007B9D017B9B017C9E00779C00769E00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6E9F0071A00170A001719F01739D01749D00779C007A9C00799B007C9E0079A20077A200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6CA0006DA1016EA20171A001759D00779D00759F00769F0078A00079A20077A20077A001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70A00070A10073A10072A001749F0176A0007AA2007AA30079A30078A10077A20178A202
7AA2017CA3007CA5007DA4007EA4047EA40979A70978A80B7AA90A7CA7097CA5097EA10B
78A20C76A20E72A20F70A30D71A40A74A70B74A60D76A50D76A60C78A40C7AA4097CA109
7BA3087AA8097CA90978AA096FAC0C60AD1355AE1A4FAF224DB12647B12F40B2403BB14E
38AC5536A25C399E613D985E3F945E3F93553C98513B9E5037A050359E5734995E339366
329166358A64328266317D69337F72348571338F63349D4940A6304CAF1A58AF0F64B308
6BB2056BB1056DB0056EB10770B01169B02162AC385DAB415AA74155AB404EAD4448AD44
45AD4142AE3C43B03445B13247B13448AF3A49AB3B4DA8374FAB3250AF3250AF3154B230
53B52D4CB62F47B43544B13C44AE473EAD513AAD5A38AD5E37AD5C37AD5636AD5538AE55
3AB0503BB24E3FAD5142A558429E60409E5E439E55449C54429955409D4C41A45045AC4F
4CB04B5FB13481AB20979E1B9D9A1EA58C22A0921C9E981CA49320A28C1D9E921FA09420
AA931FA08F219D8F22A2981EAA9F23AD952B9E9A1F9C9A279C9C249F9E239D992B9C9C25
969D20969B1F9795249A942B939C27959C2C93972B928A308C882E92862F958E299E9223
A88719A48926A97D3D9485418C82477B954875A33E75B52A76C02177C01A81C01E87B81B
84B8187EBB1878BF1979BF1D7BBF1D7DC01B82C01686C01386C0107FC20E7CC1137BC21D
7BC61B7FC7157DC61579C51C76C51971C71374C31472C01A73C01F6FC02075C01C76C01B
78C01B73C01E71C02276C02179C01C7AC2177CC0177AC01677B81979C02073C02573C022
71C01C75C01872C01877C11178C0107AC10F76C10F79C40F78C81075C81572C91675CA16
71CC1570CE1471CE1574CF157CCC1882C9177EC6147FC3167EC3187FC61B7FC51D81C519
7FC71581C61482C71584C61182C30E80C3107FC21580C61680C51581C21684C01883C024
7FC0277DC02A7DB32E87B22E8BB82E89B72A83AE368DA3449692549E8159A27B60A97659
A5735C9A7C5484933C859719858705817B00847700867D008681008981008A8000887F00
8B7F008B8000897B00877500847800807700837900827800857800877C00857D008A7C00
887D008B7F008D8A008F90008C92018A960388A70A88AE0D8BA70589AB0589AC0C89AF11
81AF1485B21185BB1080C1107DC4127DC2167BC21679C8197CC71F7AC5287AC6297CC129
7ABA2B78B72E72AE2A72A31F72950F728A047679016D6E006365005D58005B57005E5900
5B5B00605E006263006664006661006261005D5F00595C005A57005958005C54005D5600
5F54005B4E00564D00534B004E46004C46004A4200443D003F3B003D32003A3100332800
2D24002C2100271F00211900191200110900080300030100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
709E006F9F006E9F016DA0036D9E0371A30173A00076A20078A40076A200769F00769E01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6AA0006A9F006A9F0168A1036BA3036EA201709F00709F0071A000769D007A9B007A9B00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6A9E00699C00699C00699F01699D016A9C006C9A006E9B00709D00739B00799A017A9901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6C97006D97006A97006D97006D93006D94006B94006A9500719A00769700769500779601
789701749702739703729A04759D0773A00C71A50E73A20D76A10B74A2096EA20A6CA40A
6CA40A6EA00971A30870A40972A50873A30776A00877A10778A40978A50A76A30A77A30A
76A80B78A90B77AA0978AB0974AA0777AA0476AA0471AC066FAE096CAC0B6AB00D67AF14
66AF1C64AE1C63B11B60B01C59AF2258AE2458AF2259B01E56B31B52B41A54B41856B415
55B41253B4114FB4124DB6124EB61053B5115BB40C63B30869B5056DB40270B30070B301
71B3036AB5095FB61156B71D50B72A51B53751B24055AE4456AE4755AE4353B13E53B13A
52AE3A4FAD4250AD414EB0424CB24647B14E46B05645AD5644AE5244AC4C44AB4841AA48
3EA54D3FA2533FA05B3BA46438A66834A26D329A72319871349A6A35A06334A66634A668
3BA167419B643F99683D966A3D97713D946E4093653C975E3D9D5A42A75545AF4E54B241
6AAD3D90A6299E9D1DA1991C9D9C1C9CA0179F9F19A3991E9A9C1A9A9F1AA29D1D9A9E19
97A018A1A11BA7A01CA19D1DA39E15A4A210A6A01AA59A2497A11B99A41E9DA821A0A521
9BA92197A82394A52392A22793A12A90A62C90A92C92A43191A0308D99348A9C3C8C9D3F
869C407F9A427E9947799B45779F4371AA406FAC4074B33175B92B75C02874C02075C218
76C1157AC1137CC3107FC20E81C20F7CC11179C41278C01377C01175C01076C10D78C00F
80C00F89C00D88C00B80BB0E7DC01075C01877C01C79C01A7AC0197DBD1A7BC01878C014
77C01479C0177BC01B7BC01F76BC2178BA227BC01F79BF2074C12173C21F6FC31C75C712
79C70E76C71075C61574C21075C00C77C20C77C40F75C50C6FC50D71C90F74C91574CB19
6ECA1D71C61F71C3207AC0227AC02B77BF2A7AC52C7FC42A7FC62581C81F7FC91B7AC71C
79C82078C8227BC8207CC91B80CA197FCA1780C91782C61B81C7237FC5207CC52278C52C
73C53375BF3383C12584C3237DC32577BE2D76AF3D75AC467FA250908F519C8851A28350
9A8B4F8F974484A31F859A10888F058C8B008D8C008C8F008F90008E8C008E8300908801
918C048C900A85900C84960F829B0E859B078CA00490A7058BA40984A81081AF1682B11B
8AAF1E91AD1192B0058DBC0D8CC2138BC3138DC00F8BC10D8AC60F8BC6148AC71B86C925
85C72483C9267EC9267DCE257DCD1F78CC207BCF2177CF2174CE2672CC2B70CF336CD03F
6BC9436BC53C6CC8386AC43969BA3D65B83861BF3463BC2B67B21371A106738C016D7A00
67760365760861720858710B556C0C516A0F51690B566908586204565E01595B00585A00
565400534B005347005248004F49004E49004D4400483D00453900423600413400393000
362C00372A00302400281C00211600190F00170E00110C000D0A000A0500040100010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6D96007098006F96007495007293006F9000708F00719501729702739501799500789802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729A007498007497017597017395017293017392007191016D95037495017694007B9C02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729B00749B00749D01739A01759A017696017895007593017497017995017C95007A9B00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759900729900759D00739E00749E00749C00769B007599007699007899007A9800799900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709B00709B00729E0071A00073A000759C00769801749801749901779C01779D007C9A01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6C97006E9A006E9B00709C00739900769B00759702749902759702759A037A9B037B9C01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7095006F9600709B00739600789300769701769502759703759603759904789B04779C01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7197006E95006E9500729500739300759500739401749401769903749905739A03769E02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6F97006D94006D9300719600719100729000729000719400739601709602709803729D04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6C95016D91006A8E00718F006F8D006E8A006F91006F8F006E91006D8E026E8F04719206
72940876960578970776980A749F0D6CA10E69A30F68A10F65A10B659F0A619E0C659D0C
669D0A689C09699B0A6899066B98036E9704719506759408769605779807769709779608
7999057B9D067C9A077E9C037D9E017C9E037FA2057EA3077AA6087BA9097AA80979A808
7BAB057CAE037CAF047DAF0180AB0183AC0082AC017FAE027AB0057CB00379AF0279B100
7CB2007DB2007CB3007FB10184B20183B1007FB10081B2007FB20082B10084B10086B300
86B40086B50084B50083B40181B70384B50389B4018AB3008BB30185B40679B50871B40D
69B31663AE2762A838619D485B9A4F589B52519E534CA7574EB05C4DB0594BB25948AE5E
45A46543986D4098713E99723F94733A8E763A8975398A773D9474439C6F43A26146A257
47A1514CA04F4EA14957A23A65AE2B73B8217CB41A84B21A8AAD1B91AE1993AF1A91B01C
92B21C96B31C95B3208FB21D8FC01893BB1294BA1096BB0F96BB0F93BF0E91C00E90C00E
92B60D93B70E93B90E92C00A91B60892B60A94B80994B80B94B40D95B20C96B50B96B90A
94B60A94B50A97B70A97B80897B80795B60792B20696B00495B00295B20293B20293B002
8EAE0192B10096B50196B40099B50096B60096B7009AB7009AB7009AB30197B4078DB80E
82BB157DBB1B78BC1B7BC01582BC0E81C00E7FC00E82BC0E84C00D86BD0E84C00E7EC00F
7EC0107DC21780C51882C0158BBE158AC01588BB1A89B91D8AB81E8AB91E88BB1E86C01E
83C6167ECC127CCC107ACC137BCD177AC81C78C6237BC02578BC2679C02070C01F76C121
76C22376C22374C2217AC02175C0267FBD2781C12385C71D8AC8108BC70B8EC7098FC707
91C60389C80484C90A84C70C81C7187CC4217AC82777C7337AC63877C73775C9347AC236
77B93C74AE426DB6476BC0406DC9306FCB276FCC2073CC1F73CB246DCB2A6BCA306EC33A
70C24370BA4474B73F79AA497BA94978B0497BAC4A829F50899552A18A52A7864FA08A48
8FA62D86B4138EAA0A91A101919E0093A10294AD0D90B21588AD2185B51D86BE1888BE17
86BF1B83BD2087C01988C3138FB90F90BA0C92BA0F8ABB0D85B90B8BBB1189C31388C824
87C4318ABD3C88C3338AC51E86C41B88BD2F8BC03284C43085C93086CA2D83CD2985CE1C
85CF1C84CF1A7FCE207CCA2379C91F75CA1F71CB286DC93C66C43F68C1435FB9505AA662
4D9E704D91724C996A4AAC6846B1643EA3623E965B3E9E5740A75241B3563EBA673ABD72
3CC27538C76E3BCB5D41C94D45BF3F45B34341B15643AE5946A4405397196384086A7001
656900645E00605800595100564C005349005145004E3F00493B00463500413100413100
3E33003D2F00352B003328002E21002A2000251D001F1300160D00130B000B0500050200
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6A8D026C8C016E89006C8A006E8C006D89006B8B00698E006A8F00708D016D8902718C03
728F05739007719608719A0A6DA20F6AA31167A50D65A40C65A30D65A00C669D0A6C9D08
6B9B066A9B076D9C05709A05709A04729603769404769604749904729F066F9E08749C09
779A057D9E047E9F087CA00879A20778A6077AA6087BA5087CA60B78A80D79A70C7CAA0B
80AB0781AC0382AD0480AC0382AD0183AC0081AE007EAF017AB0027AB1047FB00281B101
81B00080B0007FB20081B20084AF0085B10082AE0084AF0081B00085B10087B00088B100
88B40088B60086B30085B20083B50182B40083B50085B50186B50180B40379B70773B709
71B60E6CB51567B32166AF2E5EAE3659AC3D58AE4251AB4E50AD574BAD5B4AA86044A467
43976D408972408A743F8B76408E76438A773E89743B8E7440986D41A36344AF5549B048
50B33D55B4375EB12E6AB32375B61B7AB51884B21989B41B8EB21D92B11F8EB31E91B71C
91B81893B91590C0108FC00F95BB0F94BB0E94BA0F96BA0D9BB90E9BB50E97C01099B610
96C01295B61295B71295C00F93C00E91C00F8FB7128DB5188FB1208FAF1D96AF1A98B11A
97B11999B3179CB4139FB611A0B6129FB8109FB70E9EB80F9BB60F9BB7109EB60E9CB80D
9CB50D9BB40B9BB60A9BB80A9AC00996C00994C00996BB099AB90A9BB90B9CBA0A95BA0A
8EBB0D84C0157DC0177CC0157FC00F81C00F81C00E85C00E88C00E86C11087C21287C013
88C01783C11882C11688BC1888B81A88B61E89B71C89B61B84BB1A83BD1C87C01D84C31A
7CC6147BCA0F7CCB0F7DCB137BCA1379CB1878C9217DC0247EB8257BB92176BB2375BE26
74BD2977BC287ABC297CBB2B7AB93080B62E7CB82F7AC12F7CC61F80C91486C90D8CC90B
91C70A89C80785CA0882C90981C80D80C91482C91A80C82280C62D81C62F7DCA297CCC2D
76C73072C43A6EC43E69C53E6AC7346DCA2E6ECD2571CC2671CC316CCA316CC73771C33D
72C04276B5427AAE427AA4497BA24C7CAC4C7DB14F81A153859651A08A55A888569F8B4B
8DA43484B5178CAD0E91A10392A10494A60A93B1158FB41B8BB41C86BB1786C01788BE18
87BE1A81C22083C21985C3178CBA148CC11192C2118CBB108ABD108FBC1190C3128FC415
8BC72389C52F89C2348AC4248CC31985C02585C03084BD3280BA3382C53385CA2A82CF1C
82CE1D7FD1227BD0227CC81F7CC21977C21971C6226FC92A6BCA2E69CD405EC65258B15C
4EAA614DA2674CB76648C85D45CA5446BA4D43B44440B84344B64742B9523DBB633CC06A
3DC3693DC7613EC95841C35043BA4B43B05244AD5A45A74D529D29608C0D6A7D016B6D00
666600656100655E005F5800594D005445005042004A4100493E004739003F32003E3200
3F35003B2B003927003328002F2100291C00241A001D1300160C000D0A00080600040100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6D8F016F8C006E87006A88006E88006E85006B8B00698D006A8F006F8E00718900728B01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6C8F006C8F006C8C006B8A006E89006E88006F8D00718E00708E00749001748A00728800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6B8E006D8C006D8B00698A006A8C006A8C006F8D00738E00748F00779400789100778F00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6F8F00708A00718A006C88006D8800708A00738800788E00758F00769000749200768E00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749200728E00749100718F00728C00748D00758D00778E00788F00778D01789201799301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739100758F00729400729400709300749400749000738F00768C00778B01779302789201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748B00739000719000719200729300739300739000738900748B00748C01748F01728D01
728C0672920B72960F709F0F6AA10E6CA30E6EA00B6B9E0C69970E6B940E6E980D70960B
76950878900475920272930775950873960873980A709B0C709C0B6EA10B70A40A6DA409
6EA50572A70175A60276A80379A90478A70578A70479A50274AB0571AD066FB10672AD04
76AF0377AD0675B10774AF0774B00779AD057BAE017DAE0081AD0082AE0085AF0085B100
85B20085B20085B10086B10084B20088AD008AAD008FB10090B2008DAF018AAF018AB100
88B30087B30089B30087B10188B40189B50086B60186B40183B30282B30481B30783B407
80B6067FC0077FC0077CB50878B70777C00877B70778BC0879BC087AC00A7FBF0983C00A
7FBC0B7AC00D7AC00E7BC00C80BA0B81C00883B70883B80884B80882B80782BA0785B908
8AB8088AB60787B90884B90985B80A8AB60A90B70B93B70A98B30C9AB8109FB311A0B10C
9FB20E9DB1109DB40F9DB40F9AB110A0B4119CB21296B41097B61198B51498B2119BB213
9BAD1B9FAF11A3B011A3B1199DB10E98B00E94B40F96B30E99B50C93B61199B0169CAF16
9BB2149AB61697B11194B00E96B01097B01297AE1397AF1096AC139CA813A5A412AAA515
A3A511AAA412A9A516A5A711A3AA0BA3AD0BA8AC12AAAC11ABAC0EA7AB0DAEAA0EAAA90E
A1AA0D9FA70E9CAF109EB512A3B11197B20C94B40F91B8108EB81387B71387B6128CB513
8EB80F84BC1287BB1789BA2288BD2382BB247FBC2184B92281BE227ABE1F78C0197DC315
7CC6167BC91777CB1A74CC1571CB176FCE1D72CB1F78CD1B7CCB197CC91C79C61E7BC71F
7AC6237AC5277AC5257DCC247ECC177FCA137ECA157CCB1E7ACB1C77CD277ACC2C7DCD2B
80CC287BC9277ACC2A7CCC297DCD2A7FCC2982CA2480CB2081C9168AC80D8EC8098DC60B
8AC61388C71682C01D7EC0207CC02777C03773BF3E71C04171C83773C92671C9216BCC24
69C7306BBF456DAC536E9E5A6E9E5C70A05A70A256749B5A77995A72935A718E5D6A9459
6FA54781BD2B96C024A0C0299EC12B9ABD2C92B72C8FA9328DA73291A92F8BB02B83B22A
84B82C89B9298AB42386B31C87B71A87B7178BB81889B71690B71394BA1396C21593C619
92C81B8EC91B8AC92087C82E85C03986B43D84B64083BD3882C12D81C5227EC22279BD2D
78B93577C23776C83971C42B70C02671BC2475B81A6DB1176AAD1967A31463A41464AA18
61AB1D69A21470980B729407679A0C5F9F105BA7195BAE1A5BAF1559B21356B41655B015
57B01661A30B648C026A7A00686D00666700656700676500686300696000656300636000
5A52005449004E42004F4500514100504300493F00483B00413800443600403A003D2F00
3429002D2100231A001F17001E1300191100130E000D0A00070300030100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
728D00748D00758900768A00778C00778B00778A007288006E8B026C89027084016F8800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6C84006E8300708000748100747E00737C007380006F84006B89046A8A036C81016E8200
6E82066C8E0B6F930C6D950B6A98096D93076F96076C95066D91056E91056C92046B9103
6B8E03698E056D960A6E9A0B6E9F0B6B9F0A65A00F659E1466A11666A21368A4116DA50C
70A50771A60472A80670A9086EAA086FAC0973AA0971A90670AC0472AC0473AA0675A905
76AA0777AC0874AD0873AF0578AE017BAD017DAF027FB0037BB1027CB0007DB10080B200
7CB3007FB0027EB20082B20084B2008AB0008FB1008CB1008FAF0092AB0094AB0093AE00
92B00192B1038FB20489B20288B10188B2028AB20286B10081B1017DB5037CB50382B303
83B40485B40784B70784B60484B80882BC057FB7067FB7087EB90A7FBA0981B8077CB906
7BC0067BC0067EB90683B40683B50786B20687B30587B50687B40689B4078BB4078EB707
95B40A94B50A94C00A95C00D97B50D98B71199B31199B3119BB1129EB210A0B0109FB10F
9FB10D9EAD0F9DAF13A0B2119FB110A0AF12A4AD11A1B00EA1B212A4B113A1B10EA1B013
A4AD16A6AD12A3B012A1B0159CAF149AB01397B51495B31697B51497B60E95B80F96B616
99B31399B7159CB4169DB11592B01694AA1997A91D9AAA2198AC1F98A920A2AC1CA5AA1A
A0A914A5A715A8AD17AAAE14ABAC14A6AD13ACA912ACAF12ACB10FAAAF0BABAD0DB0AA0F
AAA40FADA40FA4AF109CB41094B81191B9168DBA1C8ABE198DBE1484BB1182BA148AB613
8FB5138EB71B8DB91790B9128BBA1A83B9237CC02078C61E76CA1D79CA1A7BC81677CB13
78CC147AD01576D01577CF1A78CD1F7ED01585CF1286CD1383CB1384CC1884CC1987CA13
86C90F86CA0F88CB1089CA1185CC107FCC0E7CCC1377CF1779CD1D79CA2778CA2B78CB2B
79CB2477CA2578CA2B78C93078C9317BC8337FCB347DCC2F7FCA287DCA2485CA1787C60D
87C80C86C90E85C21885C41C84C5237BC9247ABD2F71B94571C5416ECB336AC92B68CD2E
68C3376BB34C72A4507A9E5377A24F77A24F7899517A9156798C5B7A886577886D6C9A66
70B04886BB2891BB2A92BD308CBE3090B13091A6328E9C3C8CA23A8FB2358AAC3788A53B
8CA33C90A13B9498368B9B2989A61D8FB2108DBB0F8BBC118EC41890C81D8FC81C8FC51E
8EC81F8CC9208CC82286C53183BE3E85AC4587A44886AC4083BD2A87C01B80C2147CC019
78BB2C73B62E72B52670B11C68B11864B01568B41B6BB31C68AD1765AC1563AC1666A916
62A41874900E7077016D6E006C6D006971006471025E73055D79075F810B67870B6A820A
6E7F067076036E6F016C6800646000615B005F5B00635B006159005E53005A56005B5600
5C5700564E004C44004B3D00473C00493C00473D00463C00443B003F3B003C39003C3400
352B002F20002517001C1300191200160E00120B000B0600060200010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6771006876006B78006E7C006F7B006C7D006C7F006E83006C8401698902688202678502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5E6A00667300687100687200697700677E006681006882006882006A8701648401628704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617300617800617500617600617C005F80006082005F84006086006288005E8800608600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627B006281006182005B81005C83005A84005A87005B88005C85005B8B005E8901608901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627700657900678000607E006083006085015F86015F88005F85005B83015F8502628301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657B00677800697700687700667C00668200668601678800638500627F016784046A8002
668904648907638E0A61950B63940A6793076C8E066A8B066B8D076B9107718E03728D00
758B02759104729405749A03759C04779E05769B08769B0B779E0D789D09769F0772A108
74A00676A00476A50476A90573AA0876A90774AB0774AD0576AF0176AE0179AF047AB007
7FAE0482AB0084AD007FAF007AAF0076B2007AB2017BAE017EAD0081AC0081AC027CAF05
78AE0480AD0283AE0081AE0081AC0082AC0083AA0088AB0089AE0089AD0086B00088AF01
89AE018AAD028AAC018DAF018DAF008DAE008BAF008CAF008EAE008FB10087B20083B201
82B20482B30582B40381B20285AE0288AA018CAF008DB2058EB2078BB3088CB4088BB806
8BB8038BB8028BB7028AB50385B6058DB50690B6048DB60494B60496B50197B40093B80B
95B70C97B90A97BA0C9DBA0DA0B90C9FB60BA3B60DA3B50D9FB10C9FB20E9FB20E99B30C
9CB20E9EB10B98B50B9BB50F9DB20F99B60B99B60B9DB30E99B410A0B310A6AF0AA3AF0E
9DAD12A3AE159CB21098B00EA1B011A2B10EA6B111A6AF19A3B0179EB01AA7AF1BACAB1C
A6A714A3A41CAB9B259FA319A3A31FA79D1DA79F1497AE15A1AC17B19F1CAE9E1DA4A41D
9FA11FA89D1EAC9C1DA9A019A7A41AA7A320A4A5209BA91F98AB1F9CAC1B9CAE1F9FA81E
A7A7109FAB0D95AE1493B2148CBA1394B914A4AF1996B51A92B71D9AAD21A1A729A1A32B
9CAA2E93B02D8CBB2684BB2581C2237EC32380C42482C02689BE2387BA2085BD2081C01B
80C11D7EC11F80C21D86C81987C81887C51783C31883C11B80C41985C81284CB1086CC0F
82CF1082CB1583C71986C01D85C11C84C11980C3187EC22181C21F7AC32276C62775CA26
74CE2371CF226CCE246DCE2D6ECE366ECB406DC6496DBF536DB14C72B04674B03D76BC38
77C2337CC81986C70D88C40988C60A84CA107BC91A79C4247FBC307DB8387BB03B7AAE3F
80AF407EAF4482AB4380AB437AB34476B53F74BC3E77C63482C52D84BE2F84B9378AB33A
8AA83892A3378EA2459497459B8F46A79646AB9943A99B40AC993AB39838B5963EB19141
AC953FA19A3B9DA03397A73493AE3390B6308CC22F87C92A89CC2687CC2888CB2888CC25
8AC92984C8247DC42878C5287CC52F7EBB297DB72582B31C83AB1484990E858D03848600
7F81007B8000747800706D006F6A006C6100645D006560005F5F00615F005E5B005A5A00
585B005D5F005C5500554C00574E005C57005E52005950005A54005B5000575100555000
554E00524C00534A00534800534C00534B00524E00574E00554A005145004D4100504600
4F42004A3F00483E004A3F00483E00423B003D3A003A3700383500373300322B00292500
251C00201B001B1400130B000A0300020100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
667C006477006974006874006875006B7F00698300698100688200687C006981066A8003
68860765890663910964960A6894086B8F04718B01708800708A016F8E017088016F8700
728B01758F02739403749904749D06729E0671A00971A00E71A21071A10D6FA20A70A40A
6DA60871A80771A70B73A70A72A70971AA0876AA0776AB0476AC0179AB017AAA047AAB07
80AC0482A90181AB007EAE0177AE0276AD0278AD0178AC017AAC0281AD0182AC0180AE02
80AF0284AC0186A90088AB0087AC0088AA0188A8008BAB008EAA008FAC008CAE008BAE02
87AE0784AD078AAE048DB00290B10091B1008FAD008EAA008DAC008EAF0089AF0085AF00
84B20283B30683B60682B50284B1028AAF0189B00087B10286B40583B50786B40887B405
8BB4038BB5038CB60489B60887B9068EB70391B80391B50492B40294B10096B3019BB60B
97B90A96B60C95B60B99B6099CB60D9BB40C9DB5099DB40E9CB30FA2B00DA1B10C9BB210
A1B10BA3B20A9DB40D9DB40DA0B30C99B30C9BB60A9CB30A94B3109DB010A4AF0A97B211
9BAE14A2B10F97AE1096AF14A0B20E97B30DA2AE19A5B1159CB11499B01FA1AE16A9AE10
9EAE19A1A91DABA316A1A61AA6A426A6A017A8A2139CAE16A2A817AD9F18AD9F1AA69E1C
A79823AB9C1FAE9F1AAAA319AE9F1FAB9F1CA7A21BA09E2B9DA32B9FA92DA1A920A7A717
9FAF149AB21595B11792B41391BA1091B51397AF1695AF1894AD21A1A42BA5A12EA0A430
99A9318FB22E8BB82A86BE2881C3207FC4217EC42482C12986BD2A83BB2780C02580C123
7FB9237DB9237FC02084C11B87C21688C31587C01887BC1A87BE1C89C31386CB1288CC10
82CD1082CA1481C51882C41C80C7177ECC1680C9187DC5207CC62177C72174CA206FCB20
6DCD246ACF2567CF286BCE2C6CCE3969C84A6AC05169B5566DAB536DAA4D72AC4974B53B
74B9357CC62483C80F8CC0078AC00884C90E7DCE157BC9227AC0297BBF317BB93575B937
7AB73E7AB64179B14077B14177B93E7AC0317CC52B83C42985BE2C86BD3386B33B8EAC3A
8CA0378DA334869D41979945AF9148B59543B79542B29545BD973AC09331BE933FB69446
9C9442949F3D8CAC3C89AF3D8CB63D8DBD3B8CC23A88C23886C73685CD3183CB2883C623
85C61D87C31884C11480BA157EB6157FAF127EAB1180A40F7F9B0A828E048183017F8000
7B7D007977007370007068006C61006759006057005D54005A53006059005E5A005B5C00
5F5D00616000625A00594E00584D005C54005853005C5400595000565000565000554F00
524C00554900544B005248005246004D47005248005249004F43005140004A3F004B4500
4E45004F43004A4200483E00443E00413E003E3900393300383200332E002F2700281F00
2318001B18001611000C0900060200010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
627700647600657400687800677C006A8200697D006A7B00697B00687900688305677F04
678308648E076690066596066996066B92066F9104708F04738E03718F026D8D016E8C00
6E8E016E94026B99066E9F076EA00768A10668A2086CA00A6E9D0B6F9F0A6DA1086DA609
6CA7096FAA0C70A90F71A70C72A60A74A50876A90876A90976AE0678A90279A9037BA904
80A80380AA0281AB007CAC0276AC0476AE0576AC0477A90479A80380AA0283AA0086A900
87AB008AAA008CAA0089A80089A9008CA9018BAB008EAA018CAB018EAD008BAE008CAE02
89AC0789AA078BAD0490AE028EAF008FAD008DAE008EAD008EB0008FB10087B20086B400
85B50186B70285B70384B80282B9068AB80888B50685B40581B40480B50480B60384B802
88B40189B70288B60289B70588B8048DB9028FBA038FB9048FB80391B30396B40599B60C
96B50D98B30F99B30997B30994B30E98B5089CB80898B60D9FB211A3B108A4B10DA3AF11
A4AF0C9BB30C9BB10DA1B00C9FB20A99B312A0B50B9BB40A93B0119DAF0F9EB30C92B212
9AB212A1B30A9AB11297B31599B80A97B60C9BB11495B51096B61399AE209AB1129EB212
9FAC1FA4A616A8A70DA4A31FA39E24A5A415AAA914A9A520A7A21BA5A518A8A118A99E1A
AC9B1DA59D16A59E1EAA9E20A99F1CA6A51AA39F20989A299B9F2D9FA82DA1A6239FA621
9FAE23A1AF1C9FB11396B4169AB51C93B614A2AF10A0B019A1AD209CA42D98A8318BB033
89B63085BC3084C03082C22980C0217FC12182C32581C1267EC32678C7247AC8247CC520
7EC12283BF2682BF2384C51C83C61B8AC51789C51687C51686C31787C5168AC8118AC611
83C51083C3137FC51782C31E7EC71E7FCA1D7FCB1D7EC6247AC72176C91E72CD1A6ECB1E
6DCD256CCD2869CD296ACC2C6BCD3D69C84D69B9546CB0586FAD5470A95172A94870B03E
74B33A7AC5248AC61192BE088FBC038AC30A80CD137BCA1C7DBF287EC02C7ABD3277BD32
7BBD3579BE3777C03777C0337EC13082C32483BC2B85BC2F83BC3383B9358BB33792A836
92A4398DA83C8C9C429C9943AC9447B39442AE9843A99746AC9642AC9839A59B419BA344
94A83E8AAF3A8BB7388AB63989B7408CBA408CBB3D88C13A83C33880C8347EC32F80C11E
83BB1788B60E88B10689AA0685A103859E03849702829503818B017C85007E7E00807B00
7A7B007477006E6F006D6900695F006156005F5200584E00554B00574E005D5400605800
605C00635B006359005F54005B51005C53005952005750005350005750005A5100555000
534A00514B00544D00514A004E42004F44005145004D48004D44004A41004B4000494000
4E45005248004E4800494100423F003E39003D37003A3200342D002F26002A2200232000
2118001A1100130E000B0800060100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
6170005D75005D7700607D00668000697E006B7D00697A00687D00687E006A7E00698706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5F71005F7700617900637D00657E00667D006A7E006D7D006D82006D84006B85006A8B06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5F6F00607800647900677A00697B016A7E016D82016D8300688600688A01668A01669103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6073005F7800647C00657A00687F01668502678B01668800648700608D02608E035E9403
609203609406639A08639C08609E0860A109629F09629F09619C09619808639208649309
64980A68980A6B93076F8D03708D016E90036F90036F9501739700789A01779B03749905
70A00471A4036DA8046BA9036FA90371AA0272AB006FAB016EA9026FA60271A30071AA02
73AC0376AF0676AE077CAE067AAC0379AD017CAF017CB00178B00179B2037AB1037BB202
79B00577AE077AAE0581AC0181AE007EAC007EAA0080AC0084AC0181AC007EAF017DB001
7AB0027DB0027FB30282B00187B00089B0018BB2018AB2008DB1008AB30088B30088B200
8AB2018EB2028DB4048CB7048AB7048CB60189B4008BB2008AB20087B40288AF048BAF02
8AB00686B2028AB3018DB3018CB2018EAE018DAE018CAE0088B1028CB3038EB20296B40A
9CB50A96B60D9AB60E9FB20999B5099CB60F9EB313A3B50B99B60A8FB50F98B70B97C00A
90BF0C8BBB0A8FBB098BC0088FBF0993B5098CB80C8DB71099B30A92B60B98B60B9CB20E
9AB2109EB711A2B510A6B30EA0B40FA2B115A5AD1497B5139FB518AAAF18A3AD12A4AD16
ABA917A8AA12A0A615A3A81CA2AA1899AA16A59F1EB39C1BA8A50FA3AA12A9A817A9A712
93B0129AAE19A7A61D9AAA14A2A418A6A119A2A713A4A622A3AB19A2AF169AA91C9AA81F
9FA321A3A124A79E24A0A526A2A72399A72B91A82E8CAD2D88B12F83B6347EC0277CBE24
7BC12281C82381C62A7FC32F81C12F86BD2D84C22584C51982C91684C91083CA107FCB16
76C9227BCA247ECC237FCC1B7ECD167ECD157ECD197DCB1C7CC92080C7247DC72682CA24
84CD1F84CC2180CA247FC3237BC12675C72972CB246DCD2270C9246EC7296CC9286ECB26
6DCA2A68CA3469CC3469CD366CCF3D68CD4B69C25168B75768B8546AB55070AF4973B940
76C8357CCC2085C7138EC4108FC51490C41B94C71C92C81D8BCB1A89CA1988C91887C81B
8AC51C8BC82086C82383C72585C62380C32A85B62F8BAA3599A338A59B3C999743928F4D
93894EA28554BC8151B58553A98454988C4D919D478DAA4392AE3F95AD4095A243949F4B
909A4C92A04B93A94088AC2890A913929A089191018C9301899201868A00848400808400
8082008087008184008184008385008185007F82007F7C007B79007A7300767400777500
777200717100706800645E006054005D5100595000594D00594E005A4F005C5000595400
5B52005C55005B53005A50005C4E005A4F00595600585100544D00544A00544C00554D00
524A005145004E45004C45005044004F3F00483E004941004B43004A4200473E00484000
453E004136003931003934003A3200352B002C2600252000241A001F16001B1300151100
0E0700040300000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
607001607601637600677B006681016182016387015C88006086006087006188025D8B02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5D6F005F76016177006378006180006080005B7F005C80005D79005C7D005F7E025E8405
608E075C90065D9806609906619506608F056089025E8901608D03628C03668D03678D04
6C92036D92046D92056D95046F9606719A08709906719806709C06709D096EA20B6EA10F
6EA70D6FA9096BA9096AA90A6BA7096FA80970A80470A9006FA60070A50070A50171A602
75AD0473B00377B20278B10077B20077B30075B60178B3017BB0007FB0007DAC007AAD00
79AE0177AD0278AA017AA9007BAA007EAB0083AC0083AC0084AE0084B10084AE0182B001
80B1017DB1027FAF0481AD0284AE018AAD008CAB008BAD008AAF018DAE0088AE0085AC00
88B30187B2018AB10288B60287BA0586B7028DB70090B60091B2018BB40288B20289B100
8CB20093B20094B00093B30094B6008FB5008EB40092B30091B1018DB1018FB00991B109
93B30B98B80A9BB40B9AB80B93BC0C92BA0B96B90B8CB80A90B30E97B60991B70993C00B
9DB7129FB80A9CB80997B70E98B80C95B8098BBB0C90BB0F99B90B90B70E9AB614A6AF0F
9EAF0F9BB313A7B112A5B30F9FB412A1B513A7B310A1B110A3AE15A9AD159FB311A0B412
A1B3189EB11595B3199FB11BA5AB1DA1AC169DAD18ABA81FA9AD14A2AF12A5A6179EA515
96AE1B99B31B9EB1148FB21498AD1490B21096B414A6AB2393B2159BAA17A5A816A6A316
9F9A2DA59F2AA99E27A0A22F99A23092A2338DA53385B03185C02A85C82483C72483C627
84C42386C91E83C91D82CA1C7ECB227FC9297DC92780C9207ECA197CCB137CCB117BCD12
7CCE157ECE137CCE157ACE167AD11977CF1976CE1D7DD2197ED01A83CC1D81CD1A7DCE1B
76CF1B7BCD187ACC1D73CA2272CF2175D12178D01C74CF1A74CE1C78C82479C91C77CA18
74CD1F6BCE2969CE2D65CE2F67D13069D13D67CD4D66CA576AC94F6AC74872C14474C631
79CF2184D01290CB0F97CA1694C61E93CA2292C81A94C51892C81791C71790C21991C01C
8DBD1F8BC4228AC02786BE2686B82787B02C88AB338FAA3595A33E9C9944A6924AB28450
B47C51B58351B4894EA688539C8A52928F4E8F9B4992A147989E45939E45909B4A8AA43A
88A7208D9D138E90068987008A88008A8800858800888B00898A00878600878700848700
8182007F83007F8000817E008380008284008584008583008080007B77007A7600797800
736F00706A006A6500665A005C4F005A50005A51005B4F00594F005552005953005D5500
5E56005A5200565000584F00554C00564800554A00544A004F48005047004D4500504900
4E49004B4100493E00463B00493D00494000494000463A00473B00464000473E00453D00
3F39003A3200363000332A002E27003128002C2500221A00191300110C000E0800070400
040200000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
596B00576D005A74005875005C7C005B7B005C78005873005B6F00576F005B7604598008
5A8B085893075796065D9706629402659001608C016089005D8E025E8F03628E03678F01
6A8D016C8F02669004649307659A0B679C106A9E0D6C9E0B69A10B679F0C69A10C6EA20C
6EA40A6DA3096CA4096AA80B6DA60A6FA80770A90371A80072A70070A70072A80073AC02
76B10774B10677B10577B0017AB0007BAC007CAE007DAE007DAD0080AA007FAC007BAC00
7DAD007EAB007CA9007EA80080AA0084AC0183AA0181AD027FAE0281AE0186AF0184B100
86B10086B00186AF0386AE0286AE0188AA008CA9008CAD0188B00286AF018AAD0088AD00
89AD008BAF008BB3028AB40187B50286B4018AB4008BB3008FB3018BB30189B2018CB300
91B10197AF0197AB0096B10095B40091B3008EB3008DB5008BB4008AB2018DB6088EB50B
8CB60996B60995B60A94BB0B90BA0C8EB8098BB80A8EB50D90B4098EB40890B70A99B70D
A0B4149FB50C9EB80B9BB4149AB50D96B8098EBA0B92BB0E9ABA0991B90DA0B114A9B00E
A5B00E9DB213A2B2159FB70FA1B811A2B713A3B3119DB3109DB311A6B115A6AF10A1B60F
9DB3189FB61799B9179FB019A6AC1A9FB1149CB114A3AE19A4B2149FB2109AAA1E9CA81B
96AE179AB11E9CB11D90B51892AE1895B00E99B013A2AB2697AE1898A7189EA814A0A919
A9A02CAB9C23A398219B9F2A94AA2E88AE3182B3317FC12A82C52483CB1F82CC1C83C81F
85CA2182C92480C8217DC6207CC9217EC5277EC82980C9247DCA1C7ACD177ACC1479CE15
78D11580CD137FCF127AD01477CF1779CE1C76CC217BD21E7CD21C7FCD1C7DCD1C79CD1E
75CA1E76CB2077C82775CA2A72CC2275D01F76CF1A77CD1A76CB2074CA2D75C72971C722
70CC1E6CD1236ED0226CD1266CCF2F69D03A67CF4764CE4C66CD456BCA3F72C63E73CB31
7ED02389CC1897C8159BCB1996CB1997CC1C95CC1795CC1593CB1793CB1695CA1791CA15
8DCB1790CA1D90C5238CC12488B82586B1298AB22A8DAB36919F4293914AAB8F4DB78852
BC7E4FBA8252B38555A488559989549496518F974B90944A97944B96954A8F98427FA11F
869412858704868200848000868100868400848300848400838200848200838800858A00
8287007F83007A80007D7C00807E00847D00847E007E79007D78007A75007B7800787700
7876007572006B6900625C005A52005A5000595300555200534E004F4B005651005A5400
5E55005B54005954005A4C00564D00544C005149005048004F47004E46004C46004E4400
4B47004C42004B4000443B00483A00483C00473D00453B00453900453C00454100433E00
3D3500342D003128002D23002B24002D25002823001E18001410000D0700060300030100
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5C67005A69005C6F005C6F005C6F005C74005D71005C71005C6F015C72025E79035D7D07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5B5E005C63005A6801576A005A6B005D70005F74005F7C005B7D02607E035F84045D8506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5D61005C63005D6D025A6D005D6C005F72006075005C7D005A8702598A045B92065D8F05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5C6A005A6F005A72005B74005C75006075005F7C015C84025A8F03569304579403589A06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5F79005D7C015C7D015F7F005E7D005E7B016286045C8E06579905559D05539C0556A005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5C80015F85035D84026086016281005F85025E8F065E93065A98065C9B065B9B065B9F05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5D81035F85055F8504608A016088005F8B035F90055D93045E9007608F08608E08609406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5B7E03607F035F7F025E7D015E86015E84035D8A035D89025E83046182065F7E045E8104
618B03618B02648E045E8D03598E02568F025790015C8C005E87006286006487006A8600
6E87006B86006A8800688C016190026193016491016893026995026B95016E9A006C9E01
6AA3036CA2046BA0016C9B006B99016B9D036E9E0270A300709F006C9F00709F00719F00
729F00719E0073A30075A70075A80174A40272A60274A80373AC0476AD0378AE057DAE07
7FAD0380A90081A80082A6017DA5017DA7007EA60081A60283A80284A90782AD0380B002
7DAF017FB0017DAF007DB0007FAD0082AF0080B00085AC0085AC0083AC0080AF007BB200
73B40273B50479B4027CB4007FB40082B50080B20182B50185B60188B60084B40084B100
88B40089B30089B30089B20084B2007DB50081B60183B50387B70389B3028BB5098AB809
91B80A9CB70B9CB70A96BE0A98B80D98B60D9BB30C99B70A94B50C91B60D96B50B90B40D
8DBB1296BB1199BA0B99BA0B95BA0A97C00E9FBB0F9FBB0BA1B90BA1B510A1B311A1B20F
9DB70E9EB90E9AC00F94C00D90C10A91C00A8FC00B91C00B8FC00B88C10B8CC00C92C00D
95BE1092BE1091BB1195BC139BBD1695B91794B81895B71A97B71B91BA1890BF158BC112
89BF158AC0178DBF1C8DBB218DBB218ABB258CB52A94BA2E91B23588AE3787AE348AAD34
8FB1388CAF3A88A93F81A1437FA23F7BA63E7FB23C7EC1397CC92E79CB2478CC2476CB24
76C72176C52274C92271CC1E6CCD1B6CCD1C6BC61D71C51D76C51C78CA1F73CA2272CA20
70CF1F76CD2177CC1F75CC1E71CF236DCB296BC92E6ECD2B72D02A6FCE2C71CC2A73C829
70C72976C92A70C82A6DC92C6ECC2670CC2273CA2074C72075CC1D72CE1B72CD1471CD11
72D11371D01471D10F74CF0D73D11075D40F71D81674D7177CD31183CC1188C9138BC816
8DC91A8BC91E8BC91F8BC5228DC42493C12797BA299BC02393C02291C21F8FBF208FB721
8BB1238CAE278FAD298BA62A89A52F89A0338C9C3C899A428C9A49929C549D9D509E9B4C
8F8B51908F5096955499954A8CA63982A21987940B868900858700807F007D77007A7400
7873007A74007D79007C79007B7200796F00766E00756C00726900716C00756D00757100
7672007873007A73007A7300737A00757A00767400716E006A67006E66006F6B00707000
707200666C006163005E5F005B5E005A59005855005A5700585A005E5E005D5A005B5600
5C51005A56005959005A5200554D005049004D44004C43004E46004A4400484300463E00
443C00443C004038003F37003B3400342F003029002D2800262400231C002016001A1400
181200100C000A0600020200000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
5B73025D74025A72015D72015D79035A79035C79015F7D015E7A045A7C075778085D7D08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596701546101546600586600586F025A6A01596B005D70035A740858760A577E0D5A8611
5A8C1459930F56910C559408559306599106588F035D8A01628700618900638B00618900
6484006389005D8A005D8D015991015B8F035991085A9508619803629B01659800649A00
6499006598006995016698026597016795016C94037393037A96017A980075A00072A300
72A60074A40074A40175A60279A5017AA50078A50079A5017AA0027AA5027AA4027AAA00
79AC007AB0017CAD017CAC0279A70276A90174A80377A80875A80879A8027DAB007EA700
80A9007DAD017FAD0080AF0081B20081B10080B00081AF0082B10081B3007DB2007BB000
7CB0007EAF0082AE0086AF0085B40083B40082B00085B10081B20082B00085B00086AE00
81B20082B40081B70082BA0085BA0084B90088B90188B80288B60388BE028BBD0299B60C
9EB70C9BB50C94B40E98B6119FB30FA2B60D99B70C98B60E9CB5129FAF14A7AF12A0B10D
9EB60F9FB6109FB610A2B60E9FB60CA0B90FA4B511A7B511A6B80D9EB70C9BB70F9BB611
9DB60F9DBA0B98BB0B99C00C94BC0991BC0C93BB0F94BD1190C11192C11194C0128FC213
8DC31889C21987C11888C21687C41689C31788C41587C61287C9128CC61392C3118EC510
8CC50B8AC80B8AC90B8DCA0B91C90A91C50B90C60B90C60C8DC50B89C80E86C41285C315
86C61885C42180C02D80BB3681B4377CB33879B6357AC2327ACB2B78CC2478CE1E74CC1D
72CA1F72CA2272C92575CB2274CD2173CE1D70D21870D01772CF1872CE1C77CE1D74CD22
6ECD2B6FCF236ED32073D31D6FD02371CB266AC92972C82C75C42F78C22C74C82B73CB27
73C91E7CC8187DCB1679CC1874CE1570CD146ECE1472CF1075D00F78D10D7DD00D7BD10D
7AD10C74D40E6FD7106BD61170D61370DA1772DA1676D6137ED21185CF178ACB1E8BCD1E
8CCF1C88D21B8BD21B8BD01D90C42793BC288FBF2795C41A93C11C8EC3218FBA2494AA26
9BA228989D29939A2C909A3091A03190A4348B9C3C828C458192508B9854889C55899D4D
8A97519796499A9C3F88A93385A615819802808E008383007F7A007D7400787100796F00
7974007D7A007C78007D79007A7C007775007D79007A7500776A00756E00766D00736B00
7671007C77007C7B00787A00777D00757A007374006F6E00686400625800645900646500
656E00627100636C005F61005E63006162005F5F005E59005C5D006063005E5D005E5900
5C5D00595800525400534D00514D00504C004E44004C42004941004A4100474400473F00
433B003E35003833003731002F2800272300242000211D001B17001511000D0C000A0700
070500030100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
515A00505A00525B00575A00596001565F00555E00596A0858720B57750B57840D5A8810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535B00515B00555A00535400545300565800555B0059750C597B0F5C800C598609578809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576000546600556100555700545500565C005865005B710259850B5B86085C87055A8102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586D005A6F00596A00576400576200576F015A74005C7A016183035E83025B8200598100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547A01567B01567200586B00576D00577100597900597D005D81005B7D00577C00597E01
577E005883005C82015E8001617D015D7C005C7D005C7F015F8001617F02637D02648201
6788026687046987046B8703668902688C00698B006C8E00698D006B91016C8C00708900
7189007188007191016F90006D9200699B00659A00659D00689F006D9F00719A00769B00
779C01749D0473A30975A30674A50275A40074A30075A00076A00072A00070A20071A100
73A20175A50176A20276A102769F0178A40079A2007AA5017BA60379A90675AC0573AD03
77B00279AD0276AB0274AD0377AD0279AD0177B00075B0007BB2017CB20276B40277B301
7AAF007DB00082AE0085B20084B3007FB4007FB50081B70087B70189B6018AB50388B408
8CB1068AAD0484AE0688B20489B4028DB8028BB5038DB7028CB9018EB70391B70B91B60B
95B51199B41299B51299B61299B91199BA119ABB119CBB1398C01295C00F94C00F94C012
97C01599C0139CC01197BD1094BC0F96B91199BA1199BE1295C0128FC0118CC31389C312
8BC60F8CC60F89C80B88C50A89C60887C70983C40881C30880C2077FC20782C30784C308
86C50789C4068DBF028DC0018BC2008AC4018CC2008DC0008EBD008EC1008DC30090C101
92C00293C0028EC1008BBF008BBE0091BD0096BF0095C30093C2008FC3008BC5008CC600
8DC4008EC10093C10096C20094BF058AC10E83C81178CD2474CD2375CD2575CC1F72CB1D
70CC2574CC276FCC266DCC2969CC2A6ACC2668CC1E66CD1F66CF216ED01973D01776CE17
78CF1B78D11D72D22073D31972D21574D11172D00F76D11177D2127CD10E7AD20C7DD30E
7CD3117CD30D7BD20C7CD10C76D60C71D70C6FD60E72D40F76D00D74D00D77D00B78D00C
7CD50D7ED50E7ED51280D61786D51885D41C85D52086D02787D12889D12887D52387D51D
88D31B87D21F88D12484CD2685D11B89CF1A8ACD1F8ACB198AC5158AC3188AC0198ABF17
8CBD168ABC1685BD1B7FBC267BB8397DAC417DA44B8797528C915C8C925F929754999253
9E93518BA927819812868E04898C00858800828400807F007D7C007D7A008077007F7A00
797600746E007269006D64006E67006E67007068006F6B00706C00706C006F6900736900
717000706C00706C006D6800656200655D005E5B005B5100584F00574F00524900494000
3F34003C3300453D004A48004C48004D4E00535300535500565200544E004F4B00494700
484700474400494300474000413A003A3300393200373000352D00342E00302D002E2800
2A24002220001F17001511000D0B00070400030200020000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
527A03547702566E00576A00566C005870005B78005A7A01597E02567A04567C06568307
5686055985035C8D055D89055D88045E85025D82015F8100627D00657C01657F01678000
6B87016B84026F84016F85016C8B016C8F006A8F006B9400689000688C006A8A00698500
6D87006B88006E8C006F8B006D8F006D96006B95006898006798006C9A006D9A006F9400
729800759702769C05749F0375A10171A000729E00759A01769901759E0173A30174A201
73A40074A50075A30275A30376A2027AA1017CA30177A90376A90473AA0473A90379AB02
7BAB017DA9017BA70179A9017BAB017BAD007DAD007BAC007AAC027AAF0579B00477B202
79B1017AAF0081B30082B50081B60182B60381B60580B80285B70085B50088B50286B305
88B10587AF0389AF0285B10188B3018BB5018DB4028DB80290B7038FB7078CBE0A90B50A
92C01097C01298BA139BC0129CC01197BB1196B91597BC1897BE1797BE1394BE1193BE13
92C01293C01194C01290C2118BC0108CC0108FC0108AC11287C21286C31086C50D88C70B
8DC60A8CC50B88C70984C70785C90681C60381C30283C30784C20884C20885C30882C409
83C40489C3058BC3068AC5048AC60787C8058BC4018CBF008DC1008EC0008CC00090C101
94C00293C2018FC30092C30193C00091BE0093BC0094C00096C10095C00092C30091C100
90C1008EC0008EC20091C40091C4048FC40B85C80D78CB1873CC1C73CD1F75CD1C72CC1C
6FCC1E70CE1E73CC1D70CB236BCD256BCC266ACD226BCD226BCF266ED31C71D21878D115
77D21877D41A76D21B75D31A74D41978D41177D10E7CD30F7BD5127CD5107BD50E7AD60F
77D6107BD60E7BD60D7BD50D76D50D70D40F6FD30F70D31275D61177D80E78D60C76D40E
79D60E7BD51080D31084D41287D51686D31A87D42388CF2A89D02C85D22984D82182D71F
82D52085D22285D22485D12389D31D89D21889CB1B88C71688C20F8AC01287BC1288BB13
8BBA1489BC1788BD1985BB2881B03C85AC477F9F507B94587E925C829A5E949B4F959D4B
919B418CA018849009848802858B00848B008380007C7B007C7700797A007C77007B7C00
7A7800797100746D006E67006E6600716500736B00726E00726E006F6C00726B006F6C00
716F00727000716D00726E006B6500656600615B005A5600544D004F4500474100403200
3726002F20003728003B3400413C004643004749004B48004C4A004E4C004A4800484300
464300434100423A003E39003D35003B3200363100332C002F28002C2400292200241D00
201600191400120F000B0B00080500030200010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4F6B01546B01566600576200556800596C005A7200567301527506507B094F7C0A50860D
5287095688065B9206589406588F065B8C045B8702618100637C00657C00637E00678200
6C84006C82006C82006F85006F88006D8C006A8D00689000648F00608B00628A00638C00
648D00658D00668C006D8C006E8E006E94007090006E92006D8F00708E00729400729300
749800729600739801719601719C006C9E006E9E026F9E06719F08729F06729D05739D05
739F0475A00174A10277A50477A30175A40178A60274AC0672AF046FAF0272AF0377AE03
7BAD0380A90181A9007FAC007BAC007FAA0080AB0082A8007FA8027EAB057CAE047BB302
7CAF017EB00182B30181B40081B40181B50881B60980B70482B50082B40083B70383B401
86B1028BB00289B10187B00081B30085B3008AB4018DB60193B8038FB80B8CBA0A8CC00B
8EBD0B90BD1090BE1296BE129DC0139ABD1392C0128FBF148FBE1692BB1393C01393C013
93C11394C0118DC1128BC41187C41085C30E85C50C83C50C82C30C80C1087FC20883C607
87C50987C70884C70883C80784C80785C50482C40385C10589C1068DC3058CC30688C004
8BC30189C4048AC6058BC50587C80986C9088AC7028BC50187C50088C4008DC10090BE00
92BD0092C0008FC00090C00090C1008BC2008FC00194BC0199C00094C10095C00194C102
92C3018FC30088C6008CC8008DC6038DC60788C80B7EC81376CA1A75CB2375CD1F71CD1C
6CCE1B6FCE1973D01870CD1D6FCD1C6ECF1F6ED0216FD01F71D02072D41D71D61B76D613
79D31277D31176D2127AD1157AD41B7AD5127BD20F7DD5117DD6127DD8147BD5137BD610
77D61077D50F79D70D78D70E76D60E71D4136FD31572D4137BD8127BD8117AD80F78D812
7CD50F7CD30E84D20E89D21089D41883D21D87D2258AD02D86D33084D52A83D82282D620
83D52282D32185D32084D22089D11B88CE158DC80E8AC40F89BF1087BC0F87B90F87B210
86B21189B71984BB1F82BB2D7DAD4580A64E80A1577C995B80955E839F57929B4D8CA147
7CA02F889D12848E01828B00848A00838400817A007874007574007777007778007A7800
7A7C00767500736D00716D006E64006F6400706A00746C007272006E7000716E00737000
716F00706F006E6B006D67006D6900696A006563005D5A00555300494200433800392E00
2F21002317002317002A2000362D003C3700423D00413C00413D00404400403E00433E00
413F00423D003F3900393400363100342D002F2D002F2700272200241D00201600181200
120D000C0B000A0800070400030100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4F5C00515C00505700505400555D00586400586D06566D0953780B4F7D0A4D7E0C4E810D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4C53004C54004E5300515100555901585E0353650554760F4E770C507908517908527F09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4A4F004B52004B50004B50005556014F5C074D630A4D78114D740B506C04547304507908
50850953880E53850F53850F567C065A7A035B77025973025B74005D77005F7B005D8100
5D83015D8002557A02547C02527D02517F025883015984005989005986005B82005C8700
628700648200617D00667900647E006883006987036A87016D8C026F8D00709702719702
719304729804719B02749E02759D01769E00769E0077A100779B00769500789400759501
759A03739905729E05719B02729C01769E0278A20379A3017BA6017DA7007DA7007EA800
81AC017DAE037EAD037EAA0380A80482A90182AD0081AF007EB50083B30082B1007FB100
80B4007FB50182B10282B20381B60183B40085B60184B10188AC008AAC018DAB0188AF02
8AB1058AB4068BB4058BB3038CB2018DB2018AB4018DB4008EB3008FB7008DC00988BA09
84C00A82BE0D85BD0E8BBD118DBD108EBF118DC00F8EC10F89C31087C31088C4108BC40C
89C30B88C40A86C40988C10989C10887C20986C4098AC40986C30884C10885C20886C308
87C00887C00983C00880C2087FC10885C00789C5048BC50489C50386C6038BC7018AC801
8DC60190C4018CC30189C40189C50189C80189C90589CA038CC7028AC80287CA0285CA02
85CA0385CA0686C60684C60187C70189C90187C70185C50187C30189C2008BC1008FC000
8CC0008AC2028CC30389C70788C80885C90884C80981CC0D79CB1C75CB3072CF3071CE2F
70D0266ED0266CD0246CD0226ED1216ED2216FD32572D52173CF1B70D31772D51978D516
79D31478D51571D61B6ED81B6DD71673D31478D4157AD51677D31678D71474D81574D517
6ED31972D61573DA1374DB1670D91F6EDB2372D91F77DA1C7FD51887D41A88D2198DD71B
8BD51787D51188D31089D31287D31884D31B86D41B86D41882D41B81D41F81D22283D424
81D82482D6257FD42483D11E89CD1489CA1685C9157ECA127EC81180C51187C01086BD0E
86BB1085BE1481BC2A7ABD3C78B54876AC5578A45A7CA1598F9F50989A4988A04684A626
819A09849101828D008189007F8200797B00747200716C00706B007169007069006D6900
6E6C006E6400736700756D00706C00706A006E64006F62006E68006D6900676700676400
686100696400696500686200615900594E005A4D00595400514D004D4800453D00343000
271C00110B000301000100000400000D07001D13002A23002E2A002E2B002B2500282200
271F00231D00221F002119001D1800171200120E000E0600080500060200030100020100
020100010100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4A51004C50004C51004D4E004D56014E5B044C62064B71084C6E04506903516D044F7307
507E07528107557F08587F075877035872035A70045A6D02587001587200567500557D00
4F7D024D7C054A7A064A78054D7C07517F075780045A7D015D7800637B00627800657C00
668100688400657C006579006A82016A84016F87046D8C03719502719400719501759901
749603729B03719B02739C007399007997007C97007B93007B94007A9500779900759800
759A01759A04749806749704719C02759A037BA0047AA0017CA4007AA6007EA5007FA800
7DAD0279AF0678B00779AE057BAB0381AD0182AE0082B20182B50183B20185AF0089AB01
86AD0184AB0285AD0286AB0184AD0084AF0085AE0087A9008DA8008CA4018DAB0288AB03
86AC0289B20387B50889B30886B2058CB5048AB3028AB8008AB7018BB6018AB90788BB08
87BE0A82BA0986C00A8FC01092C00F90C20F8DC11090C0108EC00E8CC50D89C50B8AC509
86C50985C40983C50988C30988C40882C60983C50887C30587C30586C10685C50887C605
88C40488C10985C0097DC2077BC20583C5038EC30291C3028EC2038AC40389C60387C803
87C8028AC6018AC50186C60182C60187CA0189CA058BCA028EC60089C80085C70183CA03
85CA0583C80383C60385C50388C80585CA0284C80283C70385C90289C8018AC8018EC503
8FC60592C60A94C60C94C80A8ECB0B8ACD0A86CE0C85D00C81D01679D02874D02972D32C
73D02972CE276FCE216AD1226AD0236AD2216DD32271D22377CE2376D21E77D61A76D516
78D51476D81574D61E73D41971D51476D61277D71477D71476D81674D81371D9146ED716
6FD61972D91673DC1471DA1571D91571DB187BDA1782D91289D7148DD7188BD61C8DD81A
8CD5188CD4138CD5128DD31289D31386D51285D61680D31680CF197EC92083D02081D322
82D72280D82881D42784CE2388C91786C61780C51880C7167CCB187DCA1A83C61685C00E
84C01180C2187EC02D7BBC4474B94B73B45276AE5C79A3588D9B55979A4D82A54283AA1F
829806828C008288007C82007B8300797A00727400706A006A67006D6300706C00726C00
6E66006C64006F67007066006F6800706B006C65006963006A65006B6600676600666300
645F00655F00656100666000615C005C5500594E00514B004C45004740003E3700322800
2217000E09000301000000000100000602000F08001A1200201A00201C001E18001C1500
190F00161000171100151000110B000D0700060300030200020100010000020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4756004C52004F4F004D4D004D4F00505B014E61014D6B024B6B044A67054B6C074D7308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4953004A50004A51004A54004C57005060004E66004A68044B720B466E084D6E06527005
5673035975015D78005B76005A7300537001526F025170024F71015175014E77014F7B02
4E7602517803577C045C7D055E7E07658005667D026B7B006E7900707A006D75006C7800
6C7C006D83006B84006B85006A89016E8B016E94016F9D016D9F016E9D006E9900709A00
7195007298006F97006D9500739500749300759100729300759700769300759600719A00
6F9C016E99016F9B01739B00749B0078A0017BA30178A60176A80078AB0078AE0078AC00
77AB007BB1017AB1017AAE017AAC007DAC0181AC0184AB027FAC027FAA0283AA0081AC02
7CAF0577B1097AAA077FA60282A80083A80083A60089AB008CB0028CAD048EAD0388AD01
8CAE018BAC008CAC0189B1028AAF0289AD028DAB018FB1018CB3028BB5018AB8018CB705
8EBB098DC00A8FC00A8EBF0A8EBF088EC0098EC0068EC00A8CC00A8BBF0B88C00889C108
88C1098AC0098AC4098BC30989C50588C6038AC40286C70282C5037FC20282C40181C600
88C6028DC4038AC30389C40387C40387C50388C60286C60184C50186C70486C90788CA08
88CA0585C90189C9048AC8078AC90989CB0989C8088DC80991C70A93C80A92CA0B90CA0D
90C70D88C80D89CA0E8ECB0D8FCB0D8BCA0F89CC0C8BCD0B8CCD0B8FCC0B92CD0C99CE0B
9ACE0C97CD0C94CB0E94CA0E95CB128FC8118DC8108ACA0E84CE1680CF1C7BD01D78D022
77CE2175CE2274CF2073D01F6FD1216FD21C6DD3186ED4166CD5166DD7176CD71771D714
6FD61473D61374D51472D4166CD51C6FD51A6FD61973D71B6ED8216FD6206DD91F6DD81D
70DB1775DA107DD60D80D70E88D80D8FD70B93D60C91D8118DD6158AD61B8DD41F8DD523
8CD42590D32391D61C8FD50D8FD10B8FD20B8AD00C83D40D7FD41480CE1E7FD52280D624
80D62580D62B7DD02E7CCD287ECB187CC8127CC31376BF1D7DC12380CA1E83CA1E82C91E
7BC72A75C53A75BB4874B55072B75471B75274B35874A4567E9D56879C537EB03285A815
8494057E85007B80007C83007C85007B86007C80007975006E6C006D6A006F67006E6A00
6F6A00706F006E6E006A68006B6100675D00696000676500675F00655B00615700646200
636300625B005F58005D5A005C5A00585200554A004D4600484700424000373200282000
150B00070300000000000000000000000000010000020100020100030100010000010000
000000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
495300485200475400455500485C004866004C6601496A0647740D446E09496B04516F02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4B4A004748004548004552004554004962004D6401466705456F08456C054C6E024F7301
547701557A02517A03507C05507C03537D035681025584015983015B84015882015A7D01
5C7C025D7A01667C00667C00687F006C81006B7E006C84006D82006D83006E8200678200
6984006B89006C8E00678F016290026793016891006C93006F96007095007293006D9300
6B9A006C96006E94006F8F006F91006C91016C94026F98027096006C92006A91006D9200
6E96006F9A006B98006E9E0073A00074A50073A50078A50075A40074AA0176A80177A700
78A80077A80176AC0377AD047CAA0179A70176A40178A1017EA5007DAC027CAA007CAE00
7FAC007EAD017DAB027CAA047EAB0382AC0085A70086A6017FAA027FAF0380AC0583AF05
83AF0283AE018AAD008AA90087A90087AC008AB10089B10087B2008AB6008BB9008DBA00
8CBA0089C00986BB0989C0098BC1098BC30986C20982C40982C40584C40286C50286C601
84C4008AC20190C2038DC30489C30786C30884C40883C30682C40382C30383C30284C502
82C70284C50487C60588C80785CA0582CC047DCD077BD00879D0087BD0087FD20982CF09
83CF0989D1098DCE0A8ECE0D8DC8138ECA1191C71197C6109DC40E9FC70BA0C80B9CC70C
93CC0A85CB0A84CA0A83C90B86C90B8FC70B8FC90D8EC70F92C61095C80E97CA0D9BC70D
A1C50EA3C60FA3C70E9DC70E9AC90B98C90A98C80B91CB0C87CD117DCC1C73CB236EC927
6FCD2471CE1F72D11B77D1197CD0147BD21378D51573D61473D61271D91270D71371D913
6DD9186CD91670D61571D91472D51573D71473D81174D81372D81377D60F7BD70D86D70D
8CD90C8FD50B8FD50B8AD60A88D60A89D60E88DA108BD6138AD41D8AD6228AD52488D323
8AD4268BD32488D3218CD41890D20E91CE098ECC068DD10E88D11180D31F81D22683D22B
82D12C7ED32F7BD42F78D42878D01D77CB1B79CC1E7ACB247CCA2A7ECD257CCB237BC928
7AC23778AB4873B04E70B2586BAD5A6DAC5B76A7617F965F7C905D7E965180A4177C9604
7D8701787F00767A00787A00767C00737D00727200717000727000736E006F6C006C6700
696E006F71007271006E6900676100696200686600676100666100635E006058005F5B00
5F5A00615B00615C00605D005B5700524F004D4200453C003C37003530002E2900211800
0C0900020100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
454500424200414100424A00474900464C00485D05445C04446902456B00497000497701
4B7C024C7D05507F074D8006508003557F02587F015982005C7E005D7F005F7C005E7700
607600637600637600687E00697D006A81006C7D006B80016B7D00688100678100678000
6A7F00698300668800608B015E8A02608E01668900678F016794006B92006A92006A9200
6994006C95007295006F92006F90006F91026F93046D96046C91036E96016C95006F9600
7298006F9D016F9B0171A103769F037699017B9E017B9B0079A00075A00177A50479A201
78A40075A50177A90276AA0377A90176A60079A5007CA3007EA8007CAC007BAC007BAB01
7CAA027DA90280A7027EA60280AC0284AD0385A90180A7027AAC0576B10875B50978B507
76B1047EB50284B20085AF0086B30083B50086B70087B30089B8008AB90089BE008ABD00
8BBA008AB8078CBA068CC00A89C30A8AC50A85C60980C4097EC2047FC40182C60183C701
80C40185C5028AC5038CC60388C50280C4037BC8057AC90583C80385C40485C40585C504
84C60282C70187C60387C70A84C90A84CC0980CD0980CD087ECF097ECF0B84CE0A8BCD0A
8CCD0A8FCE0A95CC0A99CB0B97CA0C95CA0E92CB0E8FC90F90C60F8FC60F91C60F92C80C
8ECA0B8CCB0A8ACC098BCC088FCD0994CB0B95CA0B97C70A96C90A99CA0C97C80C93C70B
9BC70B9ECA0D9BCA0F9AC60F95C70E92C80D95C40D96C90F90C81287CB1A81C91E7ECA1F
78CD1C74CE1974D11477D2137AD1137BD31377D61378D51475D71573D61471D71572D915
6ED9186FDB1770D91773D71676D51275D80F76D70F77D70E76D70D7ED30C86D50B8BD50C
8BD80C8CD60D8BD40B8AD40E89D5118BD71289DB128AD81288D81886D82088D6238AD627
89D6268BD7258AD4248CD31992D11094CC0D93C60590CB0E8CCC1085CB227FCD2882CE2F
82D22F7FD52E79D73279D72A78D22078CE217ACC227ACA2679CD2A7BCD287CCF2A79CE2C
75C83771BB476CBE4D6CBB516DB45C6DAF6277AA6484945F7B905A78954A7F9F14809100
8187007C7F007B7A00777700797900737600716B00726E00706B007067006A6A006B6400
6B6C006B6F006E6C00696600696500686700615F00665E00655F00605F005F5B005E5800
5E57005D5600595700595800575600534E004C40003F3900342C002D2500251B001A1100
0C0800020200000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
4142004040003D3E00424500434900454800475C08455B04465D01486B00496F004A7800
4C7C024A81084C860C4A83074E7F02547E01537B00557B005A7A005D78005E73005B6E00
606E00606F00607200627B00627A00618001627A01627900637901637B00638000647D00
677C006A81006583006087005F8401618501638500648500698C00688B00688D00648E00
6D91006F8F006F9200709100728F007291026C92056894066A96056E9902729800759700
769700739E00759D01739C06729B067596027A98037B9801799D00779C0279A2077AA403
7AA20277A10278A40172A20174A40076A3007CA20180A30182A1007CA50079A5017AA604
7AA7057AA9057CA5027BA2007EA9017CA5027FAB037AAC0177AB0477B20876B30876B406
7BB50380B40181B30083B50080B5007FB80082B90086B5008BB60088B90087C00088BC00
89BB0089BB0289C00286C20488C30585C40785C40684C20682C10381C30181C8027DC803
79C80480C80682C50684C70583C70381C8057CC8057AC9047EC80482C80484C6047FC703
7FC9017FC90183C80286CB0988CA0A86CB0988CD0B86CD097ECD097CCD0B82CD0C86CB0D
8CC80D8ECA0C97CB0D9CCA0B99CB0B96CC0C92CB0D8DCD0E88CD0D84CE0F86CD1087CC11
86CC1186CC0F8ACC0E8ECC0E91CD0E92CB0C92CA0D93C80B99C90B9FC70C9CC60C9AC90C
9ACC0B9ACB0B9BCB0B9AC70B95C80A8FCC0A93CD0B9ACA0D91CC1187CB1384C9167EC919
79CF197DD0187BD1167AD0167DD3147BD71379D6127CD6147CD5177AD5147CD51278DA11
76DA167ADA147BD91479D91277D71079D50F7BD60F7CD70C7ED70C84D50D8AD50D8BD70D
8AD80C8BD60D89D90D87D60F86D81389DA1489DB1489D81789D81A86D72089D8258CD527
8BD72689D9278BD9228CD61D8FD11695CC0D90C5068FC50C89C60F88C82181CE2B7CCD32
7ED43280D62E7DD92B7BD62A79D42679D1227DCF2379CD2676CD2975CE2F76D13173D039
6DCA4A6CC6556BC5556EC05271BA5A72B85E75B16281975E789A5078A2368099117F8900
7C81007978007871007676007574006D6E006F6D006F6C006E66006F66006D60006B6300
6A68006869006768006A6600686900666B00635F005F5B005F5E00615C00615C005E5C00
5D5600565100565200575200554F004E4900443B00382F002F2500221C001A1200100700
060200010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3B39003F3C003F3B00434700454A00444E004760054A5F024B5F004E68005069004F6E00
537703537C055381064E7D035278015474004F7300517000547000586E005A7000586700
5560005763005969005B74005B71005A71005C76025E6F015C73015F7400627C00627E00
617C00678200658000668200657E00627A006583006785006A87006B87006E8B006B9000
698A006D8C006D8F00739000718D00728E016E91026C95036C9703719901749700779700
799600789A00789D01779C02769C02779801779D03759E01769F01759E0376A1077AA308
77A50575A60272A60170A00076A1007AA0007DA30180A4027DA1027E9F017EA3027CA502
7BA8067AA7047FA5027BA1017BA2027FA0027CA9017CAB007DAC037DAF0379B30378B303
80B20182B50081B50084B70181B90083BA0183B9028BB6028EB5028AB90086BA0183BB01
7FC00283C00284C10386C30585C30285C50284C40586C40885C00783C1047FC6057CC905
7AC8057CCA067CCA0881C80983C90780C80880C7087BCA0679C9057FC80182C60180C701
82C70086C7018BC80A92CA0A91CA0B8FCB0A91CA0A8BC90B83CB0A7FCB0A7ECB0E82CC0E
82C81085C9108CCA1292C81291C7118EC80E8CC60F8DC90F89CB1088CB108ACB108ECA10
89CB0F8BCB0F8FCC0F8ACB0D8ACD0D8CCC0D8DCB0D8CCA0B90C90B9BC50C9CC70E95CA0D
91CC0B90CE0A93CA0B94C60D95C90D95CB0A92CA0B97C80C95C90F91C90E8ECA1285CA15
85CC1984CE1883D1167FD1167ED4127FD61180D61083D51083D41083D50E83D40E82D60F
81D81082D71283D90F83D80E83D60C87D50B88D50B89D60C88D80D8AD7108BD80F8DD70F
8DD70D8AD80D89D80C87D70F88D91488D91688DA1C87DB1D86D72084D72587DA2587D621
88D92285D72289D81C8CD81E8ED51C8FD00E8BC80A8CC10B8BC60D87CC177FD3277BD430
78D32E7AD4297DD72577D62978D42B7DD12B7AD22B77D02A72D3296ED52E6FD3366ED042
6CCB526ACC6167CF5F6CC95872C05A71B65B73B05B769D5E77A84078A81F7E920D7C8200
767C00787100746C00736E007170006E69006D69006D69006C65006F64006C62006F6A00
6E69006A65006B66006861006868006869006A6600636300605B006158006061005E5E00
5B5900565100544F00524E004E4B004A4400413800362F002E2300201900120D00070200
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3C35003D3900403D004342004551004653004B62024B65014B60004D64004D63004D6502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3C3900414100444A00474D004B58004956014A58024D62014D5F004C6000495C00495C03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4140004747004A4D004B50004A5700475802465A034D5F014C5E004D5D004A5900475B01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4643004643004A4C004B4E004B5000495D01465F014B61014D64004D62004C5F00495C00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4948004949004C50004D55004959004D63004963004B69004B6A004C64004B63004B6100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444F00454F00475A004C60004A64004B6F004A6B014B6A024C6C034A69034E66024D6501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435300445500465500486500446600456E00466C03456A05496B064B69064B69044C6B01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4050004351004555004661004563004363004664024661044A64044869054A6B034C6C01
486A00466C00466D00486E004A6C004A6C004B6C00486501455C014958014F59004D5B00
505D005159004F5A00535E00505F00536600556B00557100537200527100527700517800
517A015175004B7201497C02487E044B8103517D03537F025583015981025B8301597900
5976005D6F005C74005D7E01617D00697F006B7B016D82016C8A01698F00688A00698401
6F88016E8C00749000758E00759501779502749B02759D01769F037B9B02799F0378A204
75A70A70A60A74A4097A9F037AA20176A50078A90079AC007AAC0079A7007BA50178A300
79A70379A7037EA6017EA5017DA8037DA7027BA5017CA5017BA80076AC007AAC0578AA08
7AA80478AA0079A8007DAB007BAC0080AF027CB3037EB3017FB10082B90282B80483B906
82B80481B50281B9017DBB017ABD017FC00480BE0580C10A82C20B7EC40B7AC4097DC705
7DC5017CC6037BC80781C50A81C4097FC8097DC8067FC60682C20585C10283C30A80C50A
79C60982C50E8BC50F92C20C92C30A88C8097FCA0A7ECC0A7FCB0D86C90F8FC50E92C40B
8DC20A87C70C86CC1182CB1289C50F8EC60E8CC70E8AC60B88CA0D8ACC108FC81298C014
98C11599C111A0C20D9BC50B93C70C8DC41591C41592C31394C40D90C60C90C41691C314
98C0119BBE119AC11495C31692C11591C31492C21991C31E8FC52287CA1F7FCC1A7CD114
82D61485D61986D51182D41282D51384D51385D31480D3107DD40C7CD50B85D50C88D80E
8AD61088D21489D5118BD70E8BD60C8AD40C89D20E8CD3118BD0158ACC1B88CE1D88D31D
89D31F88D41C83D51584D51489D41485D31380D31381D21182D41083D11184D11084D111
80D1137DD0167AD2177DD31985D1178CCB0F91C00592B70090B50093B9008FC60A87CD11
7DD02779CD3076C63A71C14071C04B74BB4B75BE4976BB4571B64570B34C6EB14D65AE53
6BAF5565B35264AE4A6AB63974B11E7A990E778003757A017076006D7000696B00636300
666600646100635C005F5B00615A00666000676200676000655F00665E00636000615D00
6261006763005E61005D60005F6000595A005558005859005359005352004C4A00424400
403800332E002E2600251C001E1600140D00050200000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3F4A00414F00405200425B00465C00465A00465C01475701445601456302466201456300
446000456400436300436200455C00475D00485900465500444C00444900494D004A5100
4B54004F56004D57004D58004B57004A59004A5D004A66004B6B004E6C00517400507300
4F6A004C6F004970004978014C78004D7501557801567A01558202548204578203557E00
567B005C78005D77006482006784006A8D01678C036991046996026A93016D92006C9001
708C016F8B006F8C006C89006C8F03719103749703759904759C04749F02799D00769A00
729D02729F05749B03779A02759700799A00799E0079A5007BA3017DA60179A40177A400
74A30078A2017BA2007AA70272AB0673A90573A8027AA40079A40175A30076A7027AA302
7AA4017CA5007CA8007CA00078A7007AB00578B30979B50475B9017CBC017EBE047ABB07
77BB097BBB057AB8037CBB037BC0057CBC0380BD0280C1047FC1087EC30977C3077AC704
79C7027BC7007BC9047EC6077FC70680C8057FC8097EC70A81C9067EC5037EC80980C70C
7DCA0C81C60C82CA0A86C60B87C30A88C50988C80B86C90D86C70D88C60E8DC30E87C30C
87C20C8DC70D89C60F87C21292C31697C31093C40C88CA0F87CC108DC81094C61797C119
91C31496C30EA3C10D99C00E92C51194C11194C11093C60D8EC60C8FC50F8DC01692C015
99C0129BC10E9AC20F99BD1193BD1696BD1A95C01F90C0248CC32582C8227FCC197FD313
87D51388D31781D3157DD3137BD41480D41384D21480D5117AD5107CD50E86D40E88D70E
89D6108BD4138AD4108BD30F89D20D8DD40C8CD30C90D1108ECF168DCE1C88D11C85D41B
88D41989D41888D31686D31386D11581D1107FD20E7FD20D81D20C84D00C87D20D83CE0E
83CC0F7FD1117CD1147CD01681D0188CC20F91B8018FB2008EB10092B40093BB018AC60C
81D1127DCF1876CA1F73CD2771CC2A76CA307BC9317EC6327AC72E7AC22D7CBF297FBB23
79B92676B32575AE2474A31474990A7388037079007270006E6B006B6900686700625F00
626000625C00645A00605B005E5900625C00656100676000615C006259005F5A005E5900
615F006163005F67005F69005F6500585B005355005257005254005251004B4900453B00
392F002E2400261B00191300140F000C0700030000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3B42003E48003E4900414E00404E00404E003F5100434E014053013F5D01415C00435700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373D003A3F003940003A41003A4500384801374D01394C03384F053B54033C51013D4D00
404C00404900434C003F46003E42003E42003B43003C44003D48003D45003F4800434D00
445500465A00465800496000455D004760004B69004B6B004D6C00506C00516B00566B00
536900557200547800557800587D005879015B82075B85095B89045C8402627E01647F01
648300638A00688B006D92026C8F046A8E036A8B016B87006C87006D87006A89006D8900
6F8B006D86006B8A006C91006B94016C97016D9601719C09749605759202738900758D00
759000749803739502749502789702779701759B0070A10070A00076A00076A20076A500
73A10272A60671A30674A50571A40372A90270A8006FAA036EA6056EA50270A20078A000
77A70077A9007CA70078A60077A90077AB0074B10074B20176B70376B90875BE0972C009
73BE0976C00577BD0677C00A7CBE0A80C00481C00079C30075C40174C6017BC8047DC903
82C60181C5017DC8027BC7047DC70680C6067FC6087EC4097AC60479CA0281C90D86C70E
88C70D82C70C7CC70A77C80A7FC60D92C40E94BC1192BC118DBE0E8CC10C88C60A85C70A
89C50D8CC0148BBF1587C11285C20E8FBF0D9AC00E8CC91089C71196BF1194C1108FC00D
83C80F85C4118FC01592BC148FBE118EBE0F92BB1098BE1193C11B94BC1BA8B4169DB711
94B90E97B8129BB917ABB222A2B52B95B5328CBC2E8ABC2E88C03085C92884CD2482D020
84D11D84D21986D11986D01A83D01A89D1178AD41387D31786D51987D21488D4108AD60E
88D80E8AD50E86D50D89D40F8AD21288D21388D3148CD1128CD2108FD20E8CD50D88D20D
88D20E85D20F83D00F84D00E80CE0E82CE0E82CF1183CC0E82CB0D83CC0E83CB0D83CD0F
83CA0F83CD0E83CC0E82CA0E84C30F8BB6088BB00088AA0087AC0089AA008BA50087AA00
86B20183B20186AB0186A70282A60182A303849F03869D02819B017D93017C8B00798800
7783007A84007684007784007486006D82006D7900666600635F00625D00666500626100
605B00615D00636100656600676900636400645F00665F00626500656600626500625F00
5A5D00595A005D5F005E60005759005351004C4A00454A00444400413E003A3600312C00
2820001B1600100B00070300040200020100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
333400353800343700333A00354300334901324D01344D03344C043D4F023E4A01414800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2E2C002E34002E39002C3E00304900314D003350003853013E5101414E01445600455300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2C2C002D3000304406304A04305A03335D00395F00426100455E00476100486601476600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2E3700313D0031590D335E0B336207366C03376A00406C00456E01466F02477603487302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324500334F0033680A346B0A366C083A6E033B6E003C6D01417404407507437C07437A04
3F75033C7003357106346F04376E02376C013D6900436B00436F00477100477400457500
457100466C00486800496A004A6C004F6D004A6F004E72004D72004C6F004C66004D5F00
4F65044D5A014A50004C51004C51004D5300494B00495100484F004A50004E59004C5A00
545900535900566701566602586402576D04536E045970025D6D015F7000606D00657102
637100607100627C01658301668E0165910469950569920464930566950C63990D689707
6A96026A96016E99006C9C016C9B01699D02689D026A98036B94016E91006E95016D9A01
6FA00171A1026EA003719A02749401739400739C0070A0016FA80171A70074AA0074A901
74AF0272B20272B30072B4016EB50169B9016CB60172B50072B40277B60577B5027CBA00
80B9017CB9037AB70179B80176BB027ABD027CC0027CBE027BC20478C00272C50273C606
75C4097AC2067EC30381BD0284BD0082C0007DBE007EBE0183C10188C10089C40B83C50C
81C50E87C21093C01599C21099C00C8EC10E88C11191C1128DC01298BA16A3B319A3B215
99B80F8FC61196C10D95BF0F92C0178CC01990BD1897BD169EBA0FA0B80B97BC1196BA1F
93B71D94BC159DBC0F96BB0D8FBE1087C5178FC01D9CB524A5B11E98B81493BE2392BE1B
9EB81EA1B61592BB1388B923A0AE25AAAA2B9EB22F8DB83387B72F86CA2B85CE2887D129
87D32383D52185D61A84D41781D41381D31080D41183D61086D51284D31188D21587D317
87D21588D21388D21282D41280D41983D41A80D31D84D21983D01782D2137ED40F80D410
81D41383D31887D1138BCF0E8ACD0D85CF0E7DD00E80CE0E82CC0F81CA0E7EC80D7DC50E
7FC60E84BC0E8CB50492B00093AE0090A9008BA2008A9D00889800849800869B0081A100
80A6007F9C007E90007C8B007E8E008191008391007F89007C84007F86007D85007C8200
798000748000718100707E007278006E71006F73007173007272006C7900697400666C00
646600636600646800656A006262005D5B005A5300534F005552005A59005A5E00555800
5253004C4F00454300404000403E003A3700383400302900231D001A15000C0600040100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2F4F013256003368063868073C65063E68023D670039680338730738750A37780B377909
347405316E052E6D072D6C05326C04336B01386A003A6A003C6B00416E00416F00427100
426A00426000435A004758004B5D004B61004B63004D65004C5F00495700475600454E00
474C013F40003B35003E3E00414400494900444500434100494B004A51004E63004B6800
516C00556B00556C02577605577404567103576D035B71015E7400657700647500607700
617801637800638200668400698D016A91016A960167940165970364940A629409619503
6593016696006795006692016290026598036798036A96036993016C8F006B8F006B9200
6C94016E99016C9A03709B02729901709C006CA2016BA8016BAC016CAB0171AE016FAD03
70B10570B30270B7016AB7026AB9026BB4016EB1006EB1006DB40473B50978B4037CB500
7EB6017BB40177B60176B70175B80178BB0379BC047ABF0579BF0875C0076DC00472C206
76BF077BBD0482BE0181BE0181BF0084BD0183BD0182BC007EBD0082BE0088C10E87C10F
88C01191C10E98BE0E9DC00F94C10D85C60F86C6108AC61390C3128FC4168FBD148AB813
8DBC0C93C10C91C10D8BBD148EBA1E90BA1A9CB910A2B70C9FBA0A9FB90D97B9189AB825
9FB41F9EB7199EB91399BB1193BF1590C01491BC209FB7249DB416A1B4169AB41C9BB724
A8B123A7B11593B6178ABB24A1B225ABAF2A9EB4348DB73688BB3086C82E87CC2E84D02C
86D22184D51C81D61781D7167FD51582D51581D31A80D41E81D51C81D41585D31288D413
85D21185D00F82D10F84D21182D21383D01783D11E82CF1986D01583CF1080D00E7ED10E
7FD50F80D81384D31186D41083D30E7FD40E7ED10D80CC0D7ECB0E80C90C7DC80D7DC60D
7CC10C82B4078EAE028FA7008DA7008DA6008D9B008A9B00899500859200849300869F00
86A000869E008290007D8400818400838E008494007F90008189007E86007C83007B8700
7A8200798300748400718300717E006E77006C74006E6A006B6E006A7200687200687100
6669006367006067005E68005D63005E5F00585600565100585500585700565900525500
4E51004848004141003C3B00363500312C002E2700241A001710000E0800060200010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
304A01314D003351003A5B013858013A5B00375D013062032E6D062D72082E750B2F730C
2D6E092B67052B66052B64043065033366013566003764003B61003B5F004064003F6300
405B004153003E4D00424900445100465600445600465300434D004144004041003D3C00
353500312B002C26003830003F3F00444800464800494B014D58014E60004F6E004D7200
5672005777005776035A7E05587A035B75015971005F7800617900647A00647F00648200
658601618200628900658901629104659303679B01669B00629602629507609406609402
628E00659101668F01658602648501638E036290026496036695026B93006B8D00678E01
6893016B9B026D9B026FA20172A30170A5006CA90069AD016BAE016CB10169B4036BB304
6FAE0471B0026EB2016CB4026EB20170AD0073AA0075A8006EAF0271AD0375AF0275B200
75B40175B3016DB4016FB70171B50275B90375BE0377BD0877C00A73BC096FC1076FC108
72C00779BE037DBD017DC0007EC10083C30185C10280C1017EBE017FC20180C4038AC113
97BF1398C00E92C00B90C00C8EC30B89C40E8AC8138CC51292C1138DC41482C31079C70B
81C10A91C10D92C11195BE1D97B8229BB618A0B50EA2B70B94BD0C9DB61499B21A9DB321
A4B2279AB41699B6119ABA1098C01792C0179AB81D9FB01A9CB5129BB3129FB1169CB028
A4AF26ACA9149BB21392B91F9FB627A4B12C9EB53390B83086BF2B83C62A87CA3184CB31
86D22789D41E86D6197FD51482D51580D3177CD2197BD21979D4177BD41080D60F86D50D
88D41183CE1780CD1386CE1386CE1187CE1486CF1E89CB1688CD1289CD1281CD117ECE12
7ED41181D81085D41184D6107FD30F7BD20D7FD20D7CCF0E7ECB0E80C70C7EC90C7CC60C
7FBD0784B20188A7018C9F008BA10089A0008A98008A9600899300858E00849400859B00
8AA100869D00818F00828400808300808600838B00808E00818D007E86007E85007C8200
7A83007A8600758000728300728200737E00727C006D70006A7000686F00676C00686D00
656C006265005E65005D62005C60005A6200575C00585800545500525500535800515800
4C5200454400403D003934002F2B00272000211900150F000B0500050300020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
314101324100334400334B002F4B002C4C002E58012A5F03276C04266E04256E07296B08
276305275E042A5E022D5801315301355400385500385400384F00374F003653003B5100
3C4A003A43003A3E003C3E004140003F44003E41003C3E003A4000383C003A3D00383A00
342F003027003128003F3A00464700495300495B014961034C6801516900516900566B00
586D005C71005D72015F79025D7A015F7B005F7C005D8000638500637F00678602648B01
6291025D8F005C92015C8C045D8F0A5E94085D96016096006093016294035E9303609101
6288006088015F84036282025E81005C89015E8902629707659A046A9701668E01679202
64990369A1056BA5036FAA026EA8016FA7006AA70069AC016EAB016FAC0269B2056BB504
6CAF0271AE036FAE046EAC036DAA026CA80174A60071A6016EAC016FAB0072AA016FAB02
68B00269B10268B30267B7016CB20172B70274B80277B9047DB90978BA0775BD0875C009
74C10A74C20875C00274C20079C4017FC80182C4037EC1037EC0017DC1017CC2068ABE13
94BD1099BE0D8CC20B83C40B8AC10C90C30F8BC21490BD1994BE198FC01083C40B78C709
76C60A83C2118FBE1798BA1DA2B324A2B315A3B10FA4B00B92B40E9DB51395B31F96B124
A3AE2999B213A2B4119ABB1298BE1490C11B97B71AA6B2159EB10E9AB81297B5209CB126
A5AE25AAAD17A5B1179EB21C9FB7289FB82998B92F8CC12D81CB297CCE2782CB2D85CF30
89D1288BD42085D31C7FD61981D51580D5167CD3187AD51A79D51D77D7187DD61381D510
89D31285D01C81CF1587CE1587D01687CE1687C91D85C91382CB1380CD1280CE1280C916
83CF1186D51088D40F83D0107CCE0F7FCE0F7CD30E7ED20E7ECE0D7FC90E84C50D82C007
81B60386AB0085A600869E00899F00899E008998008696008A9300888E008690008A9400
8A9900859A00848E00828A007D82007B7C007C7E007E81007F88007E83007B81007E8300
7B84007E8900778400738200727D00707D007380007275006E7100697000666E00626700
6266006266005D61005C6000575C00545900565B005557005350004C4E004E4B004B4D00
494C00414100393700322C002720001D1400150B000A0600060300030200000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2F36002C37002C35002E3F00294000244500285103265906245D042562032760032A5A02
2956022754012953012F4C00314100333D00313C00323F00353F00323900353E00373800
323200313500343600363400353200353400373500363200373600383C00383C003B3E00
3B3C00403900423E00464E004D60004B66004E6A01526D01557501556E00556800586600
576700586E005B6D005D75005D7A005E7F005F83005A89005F8B006186005E8B075B8E03
5A8F025C8C005E88005C8A035A8E085894075990015C90005E90005F91015D90005E8B00
628400637C01617C025E7D015B7E005F84015F8901648D01689C06689701699601689502
689D036BA2056EA8036EAB016CA9016BA70068A40166A3026AA3026EA90369AC036AAF03
68AF086BB1096BAE0A69AD0967AB0767A90471A50171A3006EAA016BAD006FAD016CA901
66AA0363B10462B3036CB20172B40174B50178B40277B70278B60575B70475B90579B805
7ABB0676BE0772BD0275BF007AC0007EC3017EC2037EBE037EC0027BC0017AC1038BBF10
92C00F8ABD0B87C20B89C30B8BC20E89C11289BC178DBA1996BA1790BE0D89C40A84C50C
7AC4107FC11487BF1593BE1AA2B923A8B511AAB00EA7AF0B9AB2109DB61791B82296B322
A8AF1BA6B00F9DB40E96BB1692BE1B8BBA1A97BA18A3B811A4B60E9BB60F99B7219CB324
A7AF24A7B11BA3B1199FB12197B62B94BA2B8EBE2E87C82D82D02F80CB2B85C82A85CD2C
88CF2B8AD12784D42680D41B7DD6167AD61878D6197FD51880D4187ED31780D41480D311
82D51382D6197FD41980CE1982D11B86D01985CA1A86C91484CB1483CE1284CF1282CE12
85D01089D10F8BD10F86CC0F7ECE117ED3107AD10F7AD10E7FD10D82C90E86C00989B900
87B20089A8008AA5008CA1008AA4008B9D008797008696008695008A9500899300879700
869700839100808A007F8A007A8600757E007777007677007C7D007B7C00797900777A00
7B7E007A8200788400778400707C006E7C006E7A007076006E76006C7100686F00666C00
646A006469006165005A5F005559005354005053004D4E004F4700484200453F00424100
403E003B3A003631002B23001D1500100700080500030300020100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
252D00272F002632002A3500253600233D00264801264D03234F02274F01284900284600
2C43002A3E002B3B002B3300272F00292E00292A002C2B002E33002D2B002D2A002B2500
2A26002D30002F3300302F00322F00322F00362F003333003939003B42003F4400444900
424A004752004B5A004C6500526D00536F00546E00536F00547100566F00546B00586700
5563005B6E005B6F005972005C7C005B7D005D7F005D7D005E7B005F7A00617F035D7F02
5A7E015987005B8701598F04548B04558F03548E00588E015C8E015D8D005D8B005F8800
6083005F7C00637900637A00637E006380006588006A93006B9F02679D01679D00689F01
6AA3016EA3026CA2016CA20068A50067A20067A001659D02689B0269A20366A50165AB02
62AD0963B10961B00A5DB20A5FAE0969AB056EA50170A6006DA40068AB0166AF0167AE01
68B00367B30664BA046BB7036EB70574B60474B30376B50277B70375BA0470B80473B804
78BB0578BA0776BB0377BB0178BE007CBF027BC0047CBD037EBE017CC0017CC00291C00C
8DC20C81C00B82C50B8CC50C84C4127CC01788BD1397B7149DB61592B80B8DC01185C016
7AC11878C3177BC31883C3168AC413A1BA10ACB30DA1AF0D9CB2159AB22791B7259AB31D
ACAF0EAAB20DA1B50E94B91D90B6249FB31DA5B618A3B912A4B80F9CB61194B71B99B223
A0B223A1B5209CB72497B22A8FB62F8CBA3384C33181CB3181CD3382C62F84C62E85CE30
82D13382D33283D42A7BD51F75D81A73D71A76D7177FD51881D51D7CD4197AD4197AD220
7BD51D80D52081D61F7ED01D80CE2083CD2085D01C84D21382D11380CF157DD0167ECF18
7ED11280D21082D10E82D21180D41281D30F7ECE0F7FD00E80CC0E83C40C8DBC068CB600
8BB20089AD008CA70090A90090A4008B9700879000899200879300899900899800869900
8592008189007B85007E86007B8600797F00757900767600757900787700767700757400
777800797900778200778100737D00717B00737A006F7C006D79006B7400697100656B00
656E00666C00636D005C61005755004F4F004A4900464400454100423E003D3700373100
342F00312E002C2800201900110C00070400030200010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
212900232E00242F00253200233600223800213C00233D01223D00273B00273700263400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1F2700232E00243300243700243800233700213700243300223000252B00272D00282C00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1D2800213200233A00203C00243E00223900223600233200232F00252B002B2F00283600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192F001A34001F40001E3F00204000213900213900243B002738002636002B3D002B4300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1631001932001C3D001B3C001C39001D36001F3900254000264000273C002C42002B4100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1232001432001A38001C36001D33001E3200203500223900274300283C002A3C00293800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1530001630001A35001C31001D2D00202E00212F00223200273900273300252D00222A00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162B00172B00162A001D2B001C28001F29002028001F2400222B001E22001C1F001C1B00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152600162400162100192000181D00161A001919001617001A1B00181600141500141500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152100161D00151900151600121200101000141400121300121200171400131500131600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0F1100121500111000110F00100C000D0A00111500111B00121C00172200171F00181D00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0908000D0C000C0A000A08000D0C000D0F00111E000E25000E2500172B00162700162000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0504000908000705000705000E0D000D0F000D14000F2700112300121F00172200161B00
1315000F0D000B08000C09000E0C001214001A27001A2E001D36011D36021D3101223100
1E2E001C2A001F2C001F28002227002326001E2100201E001E1B00201E00212200212500
232900202A002430002737002A3E002F47002F47003045003145002E4600304900304A00
345300335600335B00325A00315600334F00324900384400353F003746003B4A003A4C00
3D54003C4E003D56003F5B00416200436000465D00456200426700436301405B00425600
3E58003A5B00395F00386700396B003D7600397B003681003A7E004481004883004E8700
4F8901538702508304538505588003577901567500588302558901599502569702579B03
589203559903529704599C055DA00660A30660A004609902629802649804659B02659D00
69A4016CA4006AA30066A30063A80065AD016CAB0170A80271A90372A8036FA5016CA902
6AA8016DA90075AA0179A8017BAC017BAB0179AA0273B10672BA0770B90B73B70874B603
77BB0375C10E73C10F80BF1984BD1D84BC227FBE247EBF2786BB288AB82486BB228BC023
8FC31E87C61D88C9178BC6178CC4158AC01189BD0F85BC0B86B30986B60487B7028AB301
8BB0008CB3018BB30288B60985B10C85B10882AD047EB20280B3017FB2007FB20085B300
8BB70089B50087B10086AB0286A40486A40187A80086AC0085AC008AAC0187AD0185AB01
86AE0084AC007CAB017BA5017CA70181AE0080B20083AE0182AE0186AF0483B30485B704
87B40387B20283B30184AC0083AB007FAC0179AB017EA8007FA80083A70083A60088A900
86A90085A700889F00839B00869200859600849900849F00839B00839700819900829600
849800839A008399008097007D93007B8F007B8D007B8C00778F00788C00768E00789000
738C00768F00778B007685007383006D7F006F7D006C7E006D7B006A7600667200606F00
5F6D005B5E00585C00575E005259004F5500494B004546004042003D39002F2900211D00
170E000D0700070300010000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0302000606000505000505000C0E000B0E000B1200102000111C00111700151900111400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010100000000040400050300090C00090B00090C000F16000E13000E11000E0F000D0B00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0000000000000302000302000201000606000706000606000B0A000909000A0700070500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000000000000010000010000010000030200030200030100060400040300030200020100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000000000000000000000000000000010100010100010000020100010000010000000000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000000000000000000000000000000000000000000000000010000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000030300040400
0506000B11000B1000111A000F1900152000151C001825001724001B35001B3500223B00
213B00203D002138002737002734002B35002C35002F3C002E3D003245002F42002D4100
2A3C002C47002D47002F4600344700334800323E00323E00363F00363F00363F003C4900
3B4C00405900435E00455E004158003F5000414F00405200455E02475B004C5D00485900
485400475100424F00425C00446800437401476F00506B00536F005571005771015C6F00
5E65005F68005B6B00586E005A79005A7901598002588106598604618301627E00637A00
5F7400606C00607300637700637F00638400648000637F00657F00657E006B7D006C8300
6F8B006C93006F99007099016F92026D8C026D85016E7E006780006B8200708400718500
7083006E82006D7F00687700637200686D00646C00647600697900707D00748400778100
747F007285007382007285006C7E006877006A7000656F00637300647600657B006A7E00
6D81006C7F006B7C00697B00657B00667B00657F00647C005E7500616C005F6C005F7300
6170005E6B005C6D005C73005C77005D7600566F005465005065005163004F64004C5C00
474E004148003E44003B3F003538002C32002520001813000C0900070300020100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000020100010100070A00060900
0A0C000809000F13000F16001522001527001A31001930001B2B001923001C1F001B1E00
1F2500222800262E00262F002935002A36002839002639002936002B3500334601344900
394A003A4B00384D00334200314500334F01335401345E022F61023660023C59003E5300
435000484E00434B003F43003D47003F48004554004755004855004952004F5600505D00
516300536500586B00576D005A6A00536800537201536C00556C00576F00567300516B00
546900577100577100587500556F00536E005575005A78005D7600607100617700637500
637600657F00668100657800637700637600657900687A006580005D82005C81005F8000
627E00627D006279006377006177006276006171006375005E7A00617900637C00627E00
5F7F006178005F72005F73005F70005B6D005A6B00586700596900597200596F00566C01
4F66004F5F004B5800474F00414800404800414800393F00333A002E30002425001B1B00
1713001513000E0A00080500030200020000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010100010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000100000000000707000808000808000D18000A1A010E2701
0F2301142101131900181C00191D001B22001A24001F3100223A00233B00253800233000
2533002234002738002838002938002A38002F3C002D4100314200303E002A3A002E3900
2E3C003340003540003A4D003E51004159004159004055003D51003B4F003E51003D5600
415B00476C014A68004A63004A5F00465500414F00404900424B00444F004859004F5F00
4E69004E6B004E6B004D6C00546E00546E00527501527A015978005A6F00566700536200
586700566901536501526B01566E00556A00576D005A7700597A00577100546A014D6402
4C65014D63004A64004B64004C61004D5F004C5E00465F004159003E52003A4500333800
2C31002A2B002323001F1B001B1700110D00080500060100030100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000404000404000913000816000D2501
0F2001121F00121800161800161700181C00171E001F2F00203600233A002234001F2B00
1D2700232F002738002736002A38002936002B39002C3D00324500314100303E002C3A00
2D3E00323F00333E003846003A49004056003E59003C57003B5300384D003D52003D5700
3E5F00426100466800486C00456701455D00415400404A00404A00424D004755004F5F00
4C69005169005068004F6C00506E004F6A004D6D004D7200547200556B00546600526500
546600576700526500536900546900556800536300536700546F005769005160004E5D01
475A00455B00445C00475A004656004452004354004053003B4D00384900313800262A00
2421001C1E00161600130F000C0800060300010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010100010100060600070A000B1D00
0C17001218000E10000C0C000D0C00131700131B00192D001834001B39011D34011D2E00
1F2C00212A00202600252F00273100272F00242C00262C002830002C3D002F4300324300
364000323B00363C00313800353E00394B003C5400395801385600365100355400365800
3C59003B59004264013E6D01427301457801436D014866014D6200475900454F00464F00
4E64015071014C6E004D6B004870014C7C004E77004E6B00526A00556D005369004F6100
4C60004F62004A69004D6900506C004F6C00496400465E004458004052013F5000424E00
404A003F45003941003A43003345002E3F002C3D01273200252800202200191600100E00
080600040200020100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000040400050500
0B0C000908000C0D00090700080800080700111700111E00143200183D011A35011E2E00
1C28002026001E2200252B00262F00272A00212600222300252C002C3D002B4000324500
353F00323A00334000323E003745003649003A4D00385300375500345500345600355600
3554003857003C5E003964023E7204417603427001486B014B6A01496100465600444F00
4A5C004B67014C6D004B6E004B6F014E7B00537B00517000556D00546D005366004F6200
4C5C00515F004C64004B64004E68004B6700466201445900404E003F46003B4600383E00
353B003236002E2F002E3000262D002426002225001B1800161100110B00080500060300
030200020000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`002P3ooooE000000800@0000X00P4000@200050P001`8000T300080`00
2P<000L200080P002`800P0<1000900<1`004`P001P=000J3`0060`001D<000E2`0050/0014:000@
2@0050H00188000D2@005@/001X<000M3P007Q0001hA000T4@008a4002@C000W5`00:1@002TH000Z
6@00;Q/002dM000^7`00<R4003@S000h9P00>2L003@U000c8@00<240038Q0080<b<002X0=R8003TQ
000i8@00>R8003TS000h8@00>b<003/T0010:P00@B`004@[0015;@00ARh004<Z0014;P00Abh004X^
001:<000BRl004/_001<<@00C3<005<k001D@000Dc`0058k001B>@00DCP005@o001GA@00E4P005I?
001EE`80DeT7051U401<Kb80@7Lf03Mh@P0bNE80=HIA03fK@@12Wbl204:P9P0=046Q8P0kYR`0<JXe
02^[<P0/Zb`0;JPU036O4P0lU`P0A8d404Z7101<Q@D0BH<204^20P0204J41@0H04J51`11P@X0@84?
03mk400oM@X0A74604E[1018I0D0BV8504YR101;H@<0CU`205=H001ACP00Cd4004Te0013;000?RD0
03LS000c7`00<Q/002lJ000[6P00:aL00P0Z5`007@0^5P00;AP002`I000]5@00;1@002PA000U4000
910002@B000R3`008A0001l@000P3@007Ph001l>000N30007@d001T9000E1`0050L001@4000C1@00
40D00104000>0`002P4000P0000400000P0001l00000303oool000X0ooooc`0000070040000;0041
00030@000`4000<100070@0020<000X2000910002P8000/2000<10000P0>1P009`0A1`005@X001T=
000J3`0060h001T;000G2P0060T001D:000D2@005PT001D9000C30006@d001h>000R4P008140020C
000S4@008a@002@C000V4`009aP002LI000Y6@00:aX002dK000^6`00<20003@T000g9P00>2@003@Q
000a7`00<B40038M000b7`00=Al003LS000203LP000W03XP000m8@00?R<003hT00109P00?b/0048/
0016:P00Abd004P_0014;P00Abl004T_0019<000BRl004/^001;;`00CS8004hf001B?P00ED<005M2
001B?`00ET00054o001EA@00FD/005YB001GF000E64604mY3`19LR00AWDd049_C@0jM5/0=7aQ03B:
G00jVTd0>jDo0080=jPn02L0<j/k036[@P0[[TD0:Zdm036[<P0cYRL0?9`C042C1`14SP@0AX`504J;
1@13RPD0AX/404>=1014S@D0@H/903n63@0lPQ00?WdA03mg3P12L0T0@V/704EV1P16HPD0Af4404UN
0`1?F`40EeH005M?001?@P00CCT004Ha000l9`00=24003<K000`7000;QX002/E000Z4`000P0Y5P00
500/5`00<1X002dI000[5@00:A<002PA000R40008`l002DB000T4@008a80024B000O40008100028>
000Q30007``001X8000F1P0050H00P0D1`001`0A1P0040D000h2000:0P00200000@0000200007`00
000<0?ooo`002P3oooo>00000003004000030@000`400080104000h01@4000H1000700001P4000L1
00060P002P8000X4000<1P002`L000X5000=0`002P@000/600803PH000T05`X001P<000I40007Q80
024A000M3P006`d001T=000F2`000P0F3000300H2`0070`001h?000Q4P009aP002LG000W6P009AT0
02HH000W60009aT002LJ0080:AP000T0:AT002dM000`7@00=1l003DS000f9000=B40034O000_7@00
0P0`80000`0b8000=R0003<Q000203@P0080>28000/0?R@0040U0010:000@bL0044Z0012:`00@bd0
04P[0015;000B2`004X`000204T`000H04/b001<=P00CSL005<i001E?P00E4@005A6001DB@00EDH0
05I6001LBP00FU<005IK001CIP80Cfl:04]h6P10O340@7E;04IZI@11LW40<X5c036=KP0dVel0<jIE
0P0]Zd/09`0[[4P0:Zm902R]AP0/[3P0=JLX03ZO7@12U`h0AXh504F>0`16S@H0@i07042B200oU0P0
@I@8042@200mSP/0?8L?03Z2500nOQ@0?GXD03ec3P10K0/0@fD7049S1P15H@@0BF02055M0@1EE`00
De800553001;=`00@S8003`Y000h8`00=1h0030L000^6000;1D002/D000202XG000<02dH000[6@00
:aP002`F000Z4`00:10002D=000W3P009a4002DA000W3`008a400P0R40003`0Q3`0080d001l;000K
200060P001H9000E2@005@P00187000@1@003P8000X100080000100000<0000O000000`0oooo000:
0?ooolX0000000D00@000080000200000P4000@1000200D2000600@200060`0020<000L400081@00
2PD00P0:1000200>1P004PP001<9000B2P004@P000h7000<1P003PP00P0B2P001@0F2`006`h001dA
000P5@008Q@000807a4002007Ph001`>000L3`007@h001h>000L3P007a0002HD000Z6P00:a/002/L
000Z70009a`002XK000/6`00;Ad002hN000_7@00;R00034Q000f8000=b8003HS000d8P00=R8003<P
000b7`00<Al003DO000e8P00=Ql003<Q0080=R8002L0=b0003XP000n8`00@R@0048Y0014;@00@R`0
04D_0015;@00ARh004@Y0015;P00ARl004T_001<<@00CSD0058i001@>P00DC`005E1001DA000DT/1
05=;0P1FB`40F4/105]?001LF@40F6H4059d2@18OaH0@X0]03miA`14KV40DV=b04U[N00eOgX0;HUh
036CJ`0`X6<00P0ZZUT09`0[[E00:je:02R/@P0_ZBh0=J4M03^I4P12T@/0@i4604:D1P10UPT0?YT;
03ZK400iW100>YX>03jC400jSQ80>XPE03b4600nP1L0>W/F03Yg500oKQ40A6L<04AV2@13H`D0B6<4
055R0@1DH040EEP1059=001;?@00@S@003dY000j9000<ah0030N000_6@00;1D002lF000202dG0009
02hG000[5P00:aL002TE000X5000:14002DA000V3`009`h000809a0001<09Q0002<@000S40008Q00
01l?000O300070T001X:000H2`0060X001D:000C2@0040H000d5000;0@00200000H0000300000@00
01h00000303oool000X0oooob@000000600100000@40008000050@001`8000D300050P001P<000T3
000:10003@D000`5000>1P003@L000`9000A20005P`001T?000K4@006@l001H;000D2`004@X0018:
008050X002L06Pl001/@000M4`008AH002@D000R4`008A4001lA000N40007A4001d@000Q4@007Q<0
020C000T5P00:aL002hI000/6`00;Q`002/P000/7`00<1l0038P000a8000<B40038R000d9000=b@0
03TW000j9P00>B8003@R000e8@00=20003HP000f7`00=Ad003PP000h9@000P0k90009`0o8`00?B@0
044Y0014:`00B2l004Pa0018<000Abh004La0016;`00Abd004<a0018;P00Bc0004`b001@=P00Dc`0
05@o001A@000Dd<0055:0@1AD0D0Ce@705EF1@1HE@40F5X005]U0P1HL@P0Bh<F04>;:P10PT00@fmJ
04IPK@16GGP0?6Il039fO@0[P7X0;XYd02^DJ`0202ZTH00U02^[D`0/[4P0:J/l03>V9P0hWQL0>YPA
03bD2`0nU@T0?IX;03^N3`0gXAD0=:8I03BP6@0gVQP0?98G03V?6P0gRa`0>XLM03j2600mNaH0?W@E
041^4P12J`h0@VP:04AW1`1:J0H0DFT305AU0@1FF`00EDl004ln0014=000?bX003`V000k8P00=R40
02lN000202hI0080;AT001<0;QT002`I000[5P00:A@002LC000W4@0090l002H?000X40009a4002XC
000W4P009A<002@C000R4@008100020>000M30006@X000805`/000P050X00188000A1@003@D000/1
00090@001P0000@000800@007@00000<0?ooo`002P3oooo80000000I004000010@001@4000D20006
0P001`@000H4000810002P@000/3000=1@003PL00148000A2@004PP001<9000F2@006@l001hC000P
50007Q8001X?000G2P005PX001D;000201X9000W01/=000L40007a8002<C000Q4P00814001h@000M
3P006`d001d>000P4@007a<0028@000S4P009a<002XJ000[6`00:Q`002XM000/7000;Ql002dP000b
7@00<Al003<P000f7`00>B4003/V000m9`00>bL003/Q000g8P00>1d003XQ000f8P00=B0003PP000f
9@00?BD00080?RH000H0?bH0044X0011:P00Abh004Pb001==@0204/e000O04Xc0018<P00BC<004Tb
001:<`00CC<0050c001E=P00ECd005Q0001E@000E4L0059>0`1?F@T0CF0@055S2P1FI@@0EV/205Mg
1`1>PaD0A8`[03n6A012LEX0BUQ/04EAN@0hEGl0<5b002eZP00ZMG`0:Wih02^6L@0202RHI@0W02fR
DP0_Z4H0;ZPf03JR9@0kWAL0>YTA03bI300mV`X0>:0>03JR5P0aXaX0<:<O03BO900eVb<0>9<T03FB
9@0fSRL0>XTR041o6012NA<0@78A045/4@12J`h0@V/;045[2@17K`T0CW05059]0@1GH@00Edh004dm
0015<@00@2X0040Y000k9@00=B40034K000`6P00;QT00080;1P000X0:aL002XE000Z4`00:Q@002TB
000W4P00:A0002HA000V4`00:A@00P0[50000`0X50009a80028@0002020>000>01d=000J2`0060T0
01L:000C2@004PP00106000>1P002`8000X1000700001@0000800001000M000000`0oooo000:0?oo
olD000000`0100006@030@001@4000H300060`001@@000L4000910002P<000d4000?1`004PT001<:
000D2`004`/001H:000E300060d001XA000M4@0081D001`A000K40006Ph001L;000F30000P0J3@00
9`0N3`007a40020D000U5@008A<001l@000M3P006Pd001L=000J3P006`d001`>000P3P008a0002HE
000X6@00:a`002/M000^6P00<1h0030O000`8`00<B00034O000b7P00=1l003PQ000m9@00?2L003dX
000h9000=b4003<T000e8@00=R<003XT000l9@00?RD003hY0002044/0007048[0015;P00ARh004L^
0019;P00C38004dd000304de000M04/e001<=P00C3@004he001@=P00DSL0058j001H?@00E40005A8
001AE0@0CV4>04Y/5`1@LA40DgD:05=j201@QA<0BXhU0469AP1:Kf40DE9c05Y7N01@AGh0?4R3039@
P`0]Ggh0:Fej02UgMP0YO7<00P0YSVP09`0_WEH0<ZM6032W=`0fXRL0>YlM03JL5`0gW1<0>9h@03NR
4P0gXaP0=Z8N03FP8P0dWBD0<iXW036E:P0`Tbd0=I0^03j89`16OQP0B7@?04E/3`12JPh0@V/?041[
3012KP/0AW4;04Ye1`1?K`80F64005Y;001@>000@Rd003hZ000m:000>b<003LO000`7P00;AP002XJ
000202PG000O02TE000Z5000:Q8002/B000Z4`009a<002PC000Z5000:a@002PD000Y5@00:a<002LE
000V4P008a00024>000N3`007@l001X<000H2`0060X001<;000A2`0040T000l5000<0`002`8000L0
000600000`000040000M000000`0oooo000:0?oool<000000P01000070020@00104000D100040P00
1P8000T300080`002@8000/4000<0`003@L00108000A2P005PX001D:000F2P005@/001D>000H3000
6@d001T@000L4@007A<001`@000F3`0060d001D=000K300201h?000E024A000T5@009AD002PJ000S
60007A8001h?000J3`006`d001d>000M40007140020A000R4`009QD002PH000]6`00;1d002dN000`
8000<R000080<b000100<R0003DQ000g8P00>2D003hX000m9`00?2D003XT000g8P00=b4003HT000j
9P00?R4003`W000o:P00?R/00P11;@002P17;000BBl004T/001;;`00BS@004/a001=<`00CS8004de
001>>002050g000K04hg001==`00D3L005<l001B?@00ET0005Q4001CCP00EEh404m/3@1;MaP0Bg`E
04f24P1<RaP0CI<X04fB?P1EO5X0GeY`05m9O01M@Gl0E3j204I2Q00jBH00=eQn031UN`0/KWT0:71e
0080:HA/02L0;9UL036VCP0^Ycl0<j<^03FP8P0cWQd0<ihH03>O5`0fXQP0=jDK03JT800dXb80<IlW
02fK:`0_Uc00;YHa03J@;`0oR2H0BWhF04]e3@17KPd0@Vd@049]4`10K0l0A70:04If2017M`L0CW03
05IN0@1FB000BC@003l]000n:P00?bT003/T000e7`00<1`002dK000/5@000P0[5@005@0[5`00:aH0
02XD000Z5000:A<002XC000[5@00:a<002XD000X5@00:1H002LD000T5@009Q4002<@000P4@007a00
01d>000J3P005`X001P:000201<:00040149000@1P003P@000/200801P0000<00`00004000000000
7000000<0?ooo`002P3oooo300000006004100020@001@4000H300071@002@@00P0:10001`0:1@00
2`D000h4000>1P0040L0018:000F30000P0G30000`0F300060`001P>000201T?000801/>000K4P00
718001X>000H30006@d001L<000H3@0201hA000W028C000V5`009a/002/N000U6P008QH0024?000N
4P007A<001hA000Q4P008Pl0024C000S4`009A@002/D000]6`00;ah0038P000c8@00=2<003DS000f
8@00=b4003DT000m9@00?2X003l[000n:@00?bX003hX000n:@00?RH003lY000l:@00?bH0044Y0012
;P00@bd00080Ac0002L0Bc@004hc001==@00DCD0054d001==000Cc@004de001C=`00ESX005@j001E
?@00DST0050g001?>000E3l005E1001JA`00F4/005ME001GI0@0DW0<04ik5@1<PaH0B8lK04NG9`1E
USd0HhEF06a^J01dE7D0J4Am05hkPP1E<X<0CSB404@oPP10DWh0=Emn02iVO00ZIG/00P0YNg009`0[
TV80;J9F02fVB`0bYCl0=Z<^02nS8`0`Y200=JDO03NU700gZ200=JLT03:S9@0]XB/0:Yd_02bJ<@0`
URh0>hhX04F7701>OQ00BgP=04Mb3`14LA@0@g0F045`4@17LPX0A7L704Ih1`1@KP@0F5`005A20018
<`00?RT003hX000o:000?BH003XQ000f7000<1X002hJ000202`K000902XK000[6P00;1P002XD000Y
5@00:aH002XF000[5000:1<000809QD001@09a<002DC000V4000914001lB000R4P007Q4001/>000J
2@006PH001D9000D2@004@T00105000=0`002`8000P1000700001000004001d00000303oool000X0
oooo_`0000008P01000000000000000300000`4000@100060P002@@000`5000<1P0030P000l8000A
1P004@L0018:000D2`005P/001L<000I3P006`h001h>000J3P006`h001d?000J40006a0001`>000M
3`00810001`@000K3@006Q0001/>000L3P02024@000Q02@G000X7000:Ad002dO000Z6P009AD0028C
000R40008140020D000S5@009Q@002LF000V5`00:AP002`H000]7@00;Qd0030L000`7`00<B0003<O
000b7`00=20003PV000m:P00@R/0048^000n;@00@Rd004<^0012;000@bX00080@BX000@0@RP0048[
0014:P00AR`00P19<@009`1?=@00D3H0050j001A?000DcP005<i001C>000ECP005Dk001C?000E3h0
05I1001C?`00E3d005A0001FAP00E4/005Y<001LE000G5`105MY1P1DMPh0Ch4E04V=6`12VBT0@i`o
05^=D`1gKfP0NF9c07iAN01d@GX0ISUo05XePP1G?840BDb0045JP@0gHhL0;6B102IPNP0202A]L00W
02N2H`0ZU5l0;ImG02jWC`0`ZCh0:jP`02bW:P0cYbL0=JHR03:Y8`0_Z2L0:ZD^02NT=00XXSH0;9`e
03FF:P12SAd0BXHA04f03@19OPh0@gPE04=e6@14M1T0A7DC04If2@16N@H0AgH6059/0P1IF000E400
04Pb000o;@00?RX003/V000i9@00?B4003PL000c8000;ad00080;QX000l0;a/002hJ000^6@00:aP0
02TE000X50009aH002PD000V4`009aD002PD000Y50009Q4002L@000T4@000P0Q4P002P0O4@006`h0
01X:000J20005@X001<:000A2@0040H000h6000;0`0200P0000300@000020000000001`00000303o
ool000X0oooo<P0000030?l000040000003o0000o`000?l008H000000P0100004P030000104000D1
00080P002@8000X4000?1`0040L000h9000D2P004PT001@<000F300050/001L;000H3000710001h?
00807Q4000X07Pl0024@000L4`007Q4001lD000R4`008a4001lA000O4P007Q400P0M400202<B000S
02PH000W6`00;1h002`O000[6`009QP002HC000U4P00918002@E000U5@009A<002/G000W6000:AX0
02dM000^7@00;Qh0030O000b7P00<B8003@O000e8000>B4003/V000o:P00@b`0048^0012;000@bh0
04D_0015<@00ARl004P_0017;`000P15;P003P18<000Ac8004/g001;=`00DCX005Dj001C>@00ES`0
05@l001D?@00E3X005Hm001H@000FSl00P1IA0006`1JA`00FDL005U8001LCP00FU4005aG001OG040
GVH305Qe2`1?PaL0BXhP04:I;@0mW3l0BI9B05b1I01]J7@0JeQm06m=O@1]?h40ICV205/jP01H@Gd0
CDio04EGPP0eGh/0:ej502EJO@0202AQL`0W02E`J00YPFH0:IAR02^RFP0[Z4/0:jXl02jY<00_YbP0
<JPV032Z:@0YZC009ZLf02BW>P0UY3P0;Ihe03FF9@11SAP0AhD?04R13P15OQ80AGXI04If6P19Ma`0
B7PE04Mk3P11O0P0A7P704m[0`1FDP00DSd004Td0012<000?b/003dV000n9@00>bH003LP000d8000
<al00080<QX000`0;aX002hJ000Z5`00:QD002LE000W4`00:1@002LC000Y4`00:a@002PD000Y4`02
02HA000A02<A000Q4P007a<001dB000J3`006``001T<000E30005@/0018;000A1P003PH000/30009
0@00200000D0000100007@00000<0?ooo`002P3ooolc000000050?l00000000000000000003o0000
QP000000100100000@4000<100050`0200L3000300P100090`0030@000803`H000@04PL00189000D
2P005@`00P0G30004P0G2`005``001X>000N4`008AD001lC000P4`008A@001hB000N5@008a<002@F
000P5`0091H0028B000P4`007Q@0020C00809A@001L0:1/002XL000`7`00<1l002hM000Z6P009aD0
02DC000S4@008a0002LD000Y5@00:QH002XJ000`6000<1`003@R000c8P00=B4003PU000h9P00>BD0
03TW000203dZ000>03lZ0011:P00@RX003h/000m:`00ABl004L^0015<@00AS<004L`0018<`00BS80
04de001@=`0205<i000W058n001B?`00Dch0058j001E?@00Dcd005E0001J@@00Fd@005a2001MA000
GTL005m8001NAP00G4X005U@001JE@00FeX205YQ101GK@T0D84C04JB9P0jWc<0>J1403nCE`1DPFH0
H6i_06ALM`1OCGl0IDF306XmQ01S>XL0Gcn305]5P01CBh40Adn903]CSP0aE8H0:Dn00080:E=i02@0
:Uaa02i/KP0[QVT0:iYR02fVF`0]ZD/0;jTh036X;P0_Zbh0;:`d02J]>`0T[T009:]002FT=`0/Wc80
=9XU042B6@14Ra80B8DD04F15@17NaD0B7HD04Yg5P19NaD0@h0D03j03010N0P0CfL205A=001>=`00
AC80040[0010:000?R@003lU000j900203TQ000E03@P000`6P00<1X002lH000]5`00:QH002PD000X
5P00:QD002XB000Y5@009Q@002PE000X5P009a8002D?000U40008Q00028A000P4@007Pl000807@h0
00/06`h001T<000G300050/00148000>1@002`<000T2000800000`000040000M000000`0oooo000:
0?oooc@0000000<0o`000000003o0000Q`0000001@0100000`4000H100080`002P@000802@@000T0
2P@000h4000@1`0040L001D8000C2`004``001H;000H30000`0I3@00400M4@007a<0020F000R5@00
91L002<H000T60009AL002TG000X600091L002@H000R5@0081@0020@000N400202<D000H02PG000]
6`00<20003<T000b8P00;Ah002LI000U5@008180028C000U50009a@002TD000/6@00<A/0038O000d
8000=B<003PU000n9`00?bX003l]000o<@00@3800P13;@003@11;000@bh0044Z000o:`00@2`004D_
0017;P00Ac4004T`001<<P00CCL0054l001E?@000P1F?P009`1F@P00ED4005Q1001F@@00ET0005Po
001JA000Fd<005m6001MAP00GTL005]8001MB000GDL005]6001JB000Fe8105]J1P1FJ0d0DGLG04V7
:@0oU3d0>9U:03j?GP1BN6/0KF9_07=DM@1XBgT0GSin0612Q01M@hP0GDB=0613S@1VAHX0FTB;0592
T016@Hh0>4B902m4PP0202e4OP0W031:N00dEG80;WEX02Z@H`0ZX5d0;:IA02fW@@0[Ycl09jTo02F/
@P0T[4D08ja902JZBP0YYcX0<:8b03FN9`0lUA`0@XlF04B86017Pa<0BG`?04Uh3@1:O180A80E03n5
5`0mP`l0@gP8051P0P1CB000C3H004@]0012:@00@BP0040W000o:000>R@003HQ000f8000=B000080
<A`000P0;a/002`G000]5000:Q8002HD000X4P00:A8002LB00809a<001D0:14002DA000T3`008a00
028?000S3P008Pl001l?000N40007@l001`?000H3P005``001<;000A2@003PD000/400090P002000
00<0000100007@00000<0?ooo`002P3oool]000000030?l000000000000000D0000000<0o`000000
00000000Q00000005`0100000P0000D0000600001`8000T400081P002PH000/5000>10004@@00146
000C2@0050X001H<000E2`0060`001T<000K3@007@h001dA000Q4P007Q<000808QL000`09AX002TH
000W6`00:aP002XJ000V7000:1P002DE000S4`008Q@0024?000O4`0202PH000W02XJ000_7000=B<0
03LX000f:000<Al002/I000X5@0091@002PC000X6000:AL002/K000_7P00=B4003DS000j9@00>BH0
03dV0010:`00@2d0048^0014;`00@S80044`0015;P00AB`004@/0011;000@Bd004@_0018<000BS<0
04/f0019=P00BSP004lm001CA000Ed<00080ETH002L0F4D005M4001HAP00FdH005e5001MB@00G4P0
061<001NC@00H4d005i;001NBP00GdL005a6001LB000GDP005YB0P1JHP`0DWLM04Z5;`13Qd40@h9G
04ImHP1=MV/0IF=_07]CLP1eBGD0JTQi05e2P01JA8<0EDR605]7R01W@8d0LSj?06TkT01T=hl0DcV:
04@nQP0h@8400P0e@g`09`0fAgT0>55d031]L00XR6T0:YIW02jKH00^WUL0;9mA02RND@0XXU809JID
02BWE@0XZ5D0:jE5036V>00gXRd0?9XR046C6`13RaP0BH@?04am2P19O0X0AX0>04:44`0mQQH0?H@@
04If2@1AG@<0EDP0050e0017;@00@bT0044Y0010:@00?B@003TT000f8P00<b4003@P0002038N0004
02lI000^5`00:aD002TD0080:18001T0918002HB000S500091<002@@000R3`008a00028@000S4000
8`l0024?000Q3@007`h001`?000L3P006@l001L;000E2P004@T000l6000=1@0020D000P100050000
0@0001d00000303oool000X0oooo:`0000020?l000L0000000<0o`000000003o0000Q00000002`01
00000P0000<000050@002@8000P2000;0`0030@000d6000@200050L000804`X001<05@`001H;000G
3P005Ph001H=000L3P007a0001hC000P4`008a80024D000R50009AL002dL000^7000;Qd002hP000^
7`00:Q/00080:aT000@0:1H002LE000W5P009QH00P0[6`006@0^7P00<B8003PU000i:`00=RL003<P
000^70009aT002HF000Z6000:Q/002hK000a7@00=b4003/S000k9`00?BP003hZ000n;@00?bX0044/
0014;`00A34004<^0014;`000P13;P003012<000AC4004Pc0019=@00CST004lm001@?000DC/004dk
001A@000E4@005Q70080FdT00P1JB0000`1KB`00Fd`005]?000205]A000P061B001NEP00GEH005YD
001LDP00GU4005i<001RCP00FTl005]H0`1FL1H0AHTc0468C`16LF@0C61b05MOJP1NGVH0KU=[07E;
L`1]AW/0I4Uo05a8P`1IAX80ED2205/oR@1[=hd0NCF=07DaS`1_;Xh0GCB:04XkP`0m@7`203Y3N`0W
03Q8MP0eDg@0;VQc02QlK`0ZQG40;H]]032?J00`TF<0;95T02ZGH@0ZWV00::1N02VTF`0^YT`0<ZM0
03NV<`0lWb/0?IPQ042?6@17Q`l0BX0;04Um2`14PPl0A8@A04675011PQ40AG<;051M0`1DB@00CST0
04X`0015;@00@b/003dW000l8`00>2@003LR000h8P00>B400080=1h001l0<QX002lG000]5@00:Q@0
02LB000Y4P009Q<002LC000T50008a<002DA000T40008a0002<A000S40008Pl0028@000P3P007Pl0
01d>000L3P006Pl001T<000H2P0050P00187000?1@002P@000P3000600000`0001d00000303oool0
00X0oooo:@0000020?l000P0000000D0o`0000000000000000000?l000230000000V004000040@00
1`4000L2000:0P002`8000`7000?200040T001D<000G3@0060d001P?000H40006Q0001XA000K4000
6a4001dB000Q4P008AD002<D000O40007@l002<D000V6000;Al0030O000b8000<B00030P000[7P00
;1/002XJ000^6P00;1X002XJ000[700203<Q000D03DU000h:000>Bd003`^000g:000<28002dL000Y
5`009QT002PH000Z6P00;Q/0038N000d7`00>RD003`Z000n:P00@2/003l]000l:`0203l^0006040]
0013;P00AC0004L`0015<@00B3D00P1;>@002@1>>P00D3l00515001CAP00DD@00552001A@`00ETP0
05E:000205Q;000=05U=001JC@00F50005]A001JE@00EeD005EF001GF@00F5d005UK001JG000H5T0
061F0002069F000H069J0@1MJPX0FGhS04f7CP1AMfT0FEai05m=N@1UCVP0LTiF07E9HP1_AG@0IdAo
0657P@1NAH<0GCn505TfPP1Q<XH0L2^;07dXS01h8h`0M2N=06H/RP1?=X@0?cao0P0o@G/09`0mBGP0
>E9i035NNP0aIg/0<Fih03AdM`0bNgP0<X5g0327LP0`TFd0<9UW02fLHP0^XET0<ZI<03BYA@0eYd00
=Z4h03RK:`0lTb00AHXF04R34@16PA40@XDA04>64@12QQ80A84B04Mc2`1BF`@0D4P004dh0015<000
@RP003lX000l8`00>B8003/S000i8`00>B0003/Q000203PP000603HM000_6`00;aH002dD000/4`00
:Q@00P0T5P00600U50009Q<002PB000V4P009A8002@B000S4@00914001l?000Q40007Pl001d?000L
3@006`d001X=000H2`005@T00188000?1@0030D000X400080P001000004001`00000303oool000X0
oooo:00000000`3o0000000000000007000000<0o`0000@000000?l0003o0000o`00P@0000009001
00000`0000L200080`0020@000`4000=1`003`T0018=000D3P0060d001X?000J400070l001/?000M
4P007a8001dC000N4`0081D0024B000Q50008a<0020B000N40008aL002XL000`8000<24003<S000c
9@00=2@0030P000_7000;ah002hO0080;Ad002X0;Qd003DQ000e8@00>RL003d/000k;P00?S4003LZ
000c8`00;a`002TK000W6@00:AL002XH000[6@00;1P0030L000h7`00=bL003dY000n:`00?b/003`Z
000n;@00@C8004Dd0018=P00B3D004Xi001;>@00Ccl00511001>A000CdD004m9001>C`00D4h0059<
001?C000DTd005E>001FD00305QA000V05A@001FE000EEL0051K001=FP00CU/004iP001DH@00E6<0
05MP001MG@00HEd0069L0@1YH`@0IW0<05n06`1NPCX0IFmW06UQN`1aD7`0L4]g06I9L01SAfP0Gd=^
05M3N`1D@h00D4:405@oP`1G>XD0GcR106dcP`1m:h80RRN108LRQ`219HL0L2V:05@cQP12>h0204=3
O`0S04U<O`16Dh00A5R104QKP014Ggd0@V9k03aYM`0kLGD0=Waa03B8J`0`TVD0;iUJ03:OD00eYDH0
>JU503BX@P0eXT00<i/e03BE;@0nSQh0@hPH04:55@10Qa<0@hH@04>43`13P1<0B78;055L101CB@00
CST004@/0010:000?RD003dR000h8P000P0j8`003@0k9000>bD003/P000k8000>Ah003@L000a6`00
;QL002XF000Y5@009AH002PE000W4`000P0X4P005@0V4P009A<002DB000T4`009140028@000P4@00
7a8001lA000N40007Ph001/=000H2`005@X001@9000@20003@H000X500080`0010400080000L0000
00`0oooo000:0?ooobH000000P3o002@000000800P0002L0100000D100090P002P<000/4000?1@00
4@P001@:000F3@006@d001T>000J40006a4001TC000L4@007Q@0020G000S5`008aD002<F000U5@00
8a@0028D000R400081<002PH000[7@00<R@003<V000d9P00<RD0034R000_8@00;a`002`N000^7@00
;ah002lL000_7@000P0f8P002`0i9`00?B/003d`0010<@00>R/003@U000c8@00;Ah002TH000W6@00
:AT00080;AP001X0;A`003DP000i9@00?BP0044[0010;P00@C0004<b0018>000B3`004/l001>?`00
CD0004m2001?B000Cd/004]=001:CP00BU<004YG001@E`00D5/1051J0P1BF@80EET105QH0080EeT0
02L0EET005AG001EG000DEl004aR0@18H000B6<004UV0@1?I@00DfL005US001PI000Hf@006U_101[
NPl0H8LS05N5?01TL5L0N59h07M<P01iAg/0MDEg06A3N@1H@GH0Cd1h04a0OP1<?X<0CCj004hhP01D
=H00IC^007dhP02A<g/0V2ad09<XN029:Gl0NRb4064fQ01=?8000P1>@X409`1FBX00G5:005MDO`1H
DH00EEIo05AJN@1:GgD0AF=_041_JP0gOVD0;hUN032AE00bW4T0=Z=503VW@@0gYT00=J4h03NK=P0g
USD0@I4X04F;7015R1P0AHLC04J43@15PP/0@gl?04Ud2P1AG@<0DT/004Th0014;P00?bT003`W000i
9000>R@003TV000n9@00?R@003`V000203/V000@03`O000g7P00=aX0034H000Y5`00:1D002LD000Z
4`00:Q4002TE000Z5000:Q<002TD000X4P009QD002DE008091<000h08Q80024A000Q4@00810001hA
000K3P005P/001D:000B2@003@L000/500080`001P40008001`00000303oool000X0oooo90000002
0?l00940000000l00@0000D0000500001P4000X3000<100030D000l7000A20004`P001D:000E3000
5Ph001T>000K3@000P0K3`001@0L4P0081@002<F000R5`008QD000808QH001809AH002@D000U5P00
8QD002XJ000]7`00<RD003DW000g9`00=bP003<U000b8`00<Ah002/M000`7P00;b0002`Q000_7`02
03<S000W03/Y000m:`00@bh0044`000m;@00=BD0038R000a7P00;aP002/J000^7P00<A`0038N000c
7`00?2<0040X0011;@00@bl004De0018=P00C3d005=2001BB000EDX0055:001@C000CTh004eC001;
E@00BUL104IK0@17H080AV<304YS101<I@H0C6P8051V1`1BHP@0Deh10080EEh102L0EF0005MR001B
H`40CVH204YZ0`19J`<0BFd304e/0P1@K@80DVd105Y[0@1OK@40HgD306>3301QS2@0EHQ405AcG`1/
G6h0OTMn078oP@1/>gl0ICUl05TjP01>>h00C3]o04dlO`1A>X<0CSZ1058jN`1K=gh0KCMn08PhN`2H
>7H0XcIV09/bK02@<WP0OcJ006hoO@1O@gh00P1PAW`08@1/BWh0LDin06i<O`1ZBh80IE=m069JN01E
GG<0BV1]04=[I`0iNf<0=8II03:@CP0gVTH0>JA003RV?00fY3@0=Yl`03VH;P0jTc00A8hT04V;701;
RQ80BX@<04b12018P0P0@Wh:04Qa1P1@G080D4P004Hj000o;P00>b`003XW000203/T000403dR000n
9@00@R@003`T0080?2800200>R4003HN000d7000;A/002PG000X50009a@002PE000/5@00;A@002hE
000Y5P00:QD002TD000W5@009QD002LF000W4`009Q8002<B000R40008A4001h@000M3P005``001L:
000B2@003`L000`6000:0`001@4000<001`00000303oool000X0oooo8`0000000`3o000000000000
002?000000800@0001D0100000P300080`002PD000`6000>20003PL00108000B1`0050L001<9000E
2P0060`001/>000M3`00714001lA000S4P008a<002@E000T50000P0U4`004`0T5@009AP002DG000T
5@0091L002TL000]7P00<B8003HW000f:@00=RX003@U000b9@00<28002lN000`7P00<R0003<N000c
7@000P0i8P009`0k:000?Bd0048b0013=@00?Rl003LS000d8`00<b0002lI000Z6P00:aT0034M000d
8P00=b<0040Y0011;`00AC4004Pf001=?@00Dd400598001DB`00E58005ED001@EP00BUH004QI0013
G@00@f01045R1010I`L0?fd8049`2P12L0d0AW<@04Me5@1;L@h0Cf`8051T1002055V100W05AX0`1F
J`<0E6/404m^1P1;M0L0BWD604ec1`1@L`H0E786059b1@1LM@@0HGh6066;3`1LTAl0F8Hi05YfEP1L
IV/0L5Ud07U7N`1[>h00HCN105HhPP1D=h80DSf0054oPP1F@H40H3Z105TiP01G>7`0GSUl06/cN@1m
<GT0SCEi09DkN02@?7/0Q3ak07dnO`1dBG`0Ldik0080ODak02L0S4Yh08m7N027@7X0NCem07=9N`1V
DG`0EUYh04QQM@11KFl0?WmV03N;F@0gUT/0=j1403VU?@0iXS@0=J0/03FL:00lVBL0?I<V04B>8@17
RAT0BHH=04io1P1>O@H0Agd604Ei1P1;K0<0CEL104i50017=P00@2`003XX000i9P00>B@003TR000n
9000?bH003dX000l90000P0k8`00100i8000<ad0038L000]6P0202`F000J02TE000Y5P00;1H002/F
000]5`00:aH002`G000Z5@00:1D002LE000W5P009aD002DC000R4P008a4002<@000N3`006`d001T<
000H2@004`T00147000>1@002@<000D10003000L000000`0oooo000:0?ooob<0000000<0o`000000
00000000S`0000020040000E00@000080`0020<000X5000<1P003PP000h7000@20004PL001@7000C
2@005@X001P<000K3P007@l001`A000O4@008a8002<C000T5@0091@000809A<001<091D002DH000U
5`0091D002@G000Y7000;Ah0034R000f9`00=RT003HZ000d9@00<RD0030R000_7P00<1h0038P000c
7P00<ad00080>B8002L0>bP003d]0012<P00@cD003h_000g8`00=2<003<P000_6@00:QX002/I000a
7@00=28003LS0010:@00@Bl004Da0018=P00CCd005=1001BB000E4/005AB001EE000D5H004YF0018
F@00@ed004=P0@11HP@0@6L703m]2012L0X0@W0=04Ic4017MAD0Bg4>04m/201@I0@00P1AIP@09`1D
J0<0EV/305A[101?KPH0Bg@704Ye1P1=L`L0D7<605Ab1P1BLPD0G7D4065n1P1QR`l0G94O05R6>@1J
MUH0G6I[071IM01iAg/0Jc^0064gP@1F>880E3N2058mP01A?h80ET61060jP@1I>H00EcQl05hiO01[
<gT0OC5i08deN@2E>gP0T3ak08@lN`1m?Wl0M4Ul07=>N`0207e<N`0W08a:N02?AgP0Qd1j07TmO@1c
BG/0IU5l05IJN018HGD0@Fe_03ioIP0gReT0=iI;03NPA00iYCd0>J8d03FP;00eW2P0?9TW03fC9P14
SR40AhTI04V63@1>O`H0CWd604Mm1P15N@H0Bf`304eG0@1>A@00AcH0040/000j:000>BH003TT000i
8P00?R@003lV000m:000?2@00080>b<000@0>B0003<M000b7000;AX00P0/5P006P0Y5@00:AH002`F
000[5P00;AL002/F000/5`00:QD002PE000W5@009aH002LE000U4`008Q8002<A000S40007Pl001/=
000I300060T001<9000A1`003PD000T300050@000`007000000<0?ooo`002P3ooolQ00000080o`00
T@000000100100000P0000@200070P0200/6000E00h9000@200040T00149000A1`004PL00149000C
2P0050X001H<000K3`00714001h@000P4P008A@0028D000U5P009AL002DF000W6000:AL00080:AP0
00`0:AT002PJ000[6P00;1h002lQ000d9@00=bX003T]000h:@00=BX003DT000e8`0203<P0080<B40
0P0h8P009`0l:000?R/0044`0012=@00@C@003`/000f:000<R@002dK000Z6@00:ah0034N000d8000
>bD003lX0012;P00ASD004Tj001<@`00Cdd004mA001<D`40CEH104YJ0@18G@40@V0103iU0@0lJ080
>6`603M`2@0fM100>7LC03Mi5`0lNA`0?g/Q04Al9017N1P0C7<?04e[2`02051/2@0W05=_1`1DL0P0
DG<904mf2`1<N`h0Cg`@04mj4@1EN@h0EgT;05Qn2`1OQPd0GI4F05^?9`1HQCD0GWY706A_F@1UJVT0
Jf1f06m@N`1U?800G3R205DiR@1C>HP0Ecn805Y2S@1L@h<0J3n006<lO`1O?Gh0Hcen074aNP1m:GL0
Pc:008LlP025@X40Od1m07e3O01kDGT0OeAf0080RTmc02L0TT=_098nKP2A@700QCmc07]2N01XA7`0
E5Mn04=[N`0oMg40@8IT03jBE@0mWT/0?j=103jT>00nXB/0>YdU03ZH8P0kUB80?I0O042<6`17QQ@0
CH0:04mm101;O0D0BW/404Ie101=I`40D5L004i30017=000?b`003XW000g8`00>B4003PS000h8P00
>R@003XU000j90000P0l8000800h7P00=Ah003<M000`7000<AT002hH000]5@00;1H002dF000^5@00
;QL002/H000Z6000:aL002TG000W5`009aH002<F000T5@009A80028A000P40007Q0001L=000H3000
5`/0018:000@1P003@D000P200050@000@007000000<0?ooo`002P3ooolO00000080o`00T`000000
100200000`8000L400081@0200`700803PT002D04PP00189000C1`004@P00189000D2@005@T001T<
000K3`008140020C000Q4`008aD002HE000X6P00:QX002TM000Y7`00:a`002XL000Y6`00:a`002/M
000^7`00<28003@X000f:`00>c0003da000m<000>c0003XZ000i9@00=B4003<P000`8000<b000080
>BD002L0?RT0048X0015<@00B3T004Dh000o<`00?2l003H[000a7P00;a/0030L000d8000>B8003hU
0010;@00AC8004De0019?@40BTT204YD0P1:F@<0AU`304=N1012G`<0@V83041S100mI`@0>fd503Qd
300eNAH0<WdM039n7`0cOB@0=ghU03eo9`13ObX0AWdO04Yk5`1;MA800P1<MA409`1=N100CgTA04ej
5@1<OAP0BWhK04in7@1?Oal0Eh4K05^7601RSQT0Ii<Q06BA<01NQC/0G7Q405maC`1WK5T0KFYU06eU
K@1aFG80KT]i06a6OP1Z@Wh0Jd5o06e0P`1_@H@0Jd>106U5O01W@g`0JD5n0750PP1m>G`0Rc9e08Lc
O@23>880OCj207m3O021@gX0Pe=d08aEL00208m9KP0W09<mK02>?700S49c08=5M01mAGD0JE1d055V
M`17MG80C7IV0527FP1>VTd0CJA304ZU=@1=X2P0C9/M04JG5`12TQH0@HlK03n=700oRQh0A8@C04^0
2P1>O`D0BWh604Yj1@1:M0<0CVT204mE001?@`00B3@0048/000n:@00>b<003XS000g9000>BD003`W
000i9P00?RL00080>b<000d0>B8003DO000e7P00<a`0034K000b5`00<1@002dG000/6000<AT0038J
000_6P00;aL00080;1P00140:aL002TD000V500091D002DD000S4`008Q4001l@000H3`0060d001P;
000C2@003`L000`500080P0010000040000L000000`0oooo000:0?oooad000000P3o002E00000004
00<100060`002@L000X7008040L000h04PP0018;000D2P005@`001@:000A2@0050X001L9000G2`00
5`d001d@000N4@0081<002<F00809QL001L09aT002XL000[7`00;b4002lO000[7`00;Ah002lO000_
8`00=2D003PZ000j<000?C4003hf000o?000@3X0040g0010=@00@2`003`X000h8`00=1l003DO0002
03XY000V03l/0014<000ACD004Pm0016@000@ST003ld000l<@00=R80038M000d7@00>B@003dY0018
<@00B3P004/n0@17@P80B4/504EF1`17G`P0AF@9049X2P0nJ@/0?V/803e[1`0nJ`P0@Fl903ee2`0j
NaP0<h4U03:7<00dQRh0<h@]03N3:00lPRL0@80V045o8015OQh304Ij6@0W04En6@19PA`0BH8O04V2
8P18QBH0CHD/052:;P1HTB/0FYT/05nH;P1RSCP0HhE1065mB@1NMe00FWMG05QfGP1JMVD0Fg9Z06=/
K01]G6l0KU=c07=?M01iAgL0Nd1l088jP01g@H00JTUk06=<O01/BGh0NTQo08LoO02G>GH0SCEj080b
OP1e=X00Nd9k0899N029Dfd0TUAW0080T4=X02L0ScUZ08TiLP27@WD0PT]`07iCI`1VJfD0DGiT04n6
F`1EQd`0Ehm705RM@@1GXSL0Ej0X05^H7@1HTa80Dhh?04f<3P18RQ80B8PI04R88@18PaL0BX8<04^2
1P19OP@0BG/404a_0P1?I040D58004m10015<`00@2`003hY000k9`00>RD003`V000l9`00?RT003hX
000l9@000P0i9@002@0i8P00=R8003DN000c7`00<aX003<I000^6@00;A`002lM000203<K0007030I
000`6`00;aX002hJ000/6000:QL002LH000202HG000<02HF000R50008A4001/?000J3P006@/001D:
000>1`0030@000P3000400000@007000000<0?ooo`002P3ooolL000000030?l000000000000009D0
000000@0104000P3000;1`003PH00P0A1`009`0B2P0050/001L<000I3P0060d001L<000I300060h0
01`>000K3`008100024A000S50009A`002LI000U6000:1T002TM000/8P00<2<0038O000`8@00<Al0
03@Q000e9`00>R`003T`000k=P00@3`003do000l@P00?d<004920013?`00@cT003dc000k:`00=bL0
03PS000203hY000W040`0016<`00B3T004Xm0016?`00ACT0044f0011<000?2H003HS000i9@00@2L0
04<^001=>P00CdL204UA0`14E`L0@ed;04=W4@12KQ80@G<B03mf500lNAD0>gD@03Qf3P0gMa00?7PD
03ek600hPB40=HL]036;=@0^S3D0<HXa03:9:P0eQb<0>XHO03n57010Q1`0@H8I0080@H<L02L0@XDM
04>77`14RB40AHdV04NA;@18UcP0BI`o04VP@01;Wd80DYE205V:A01IQD`0FH1A05UlE`1HMUh0F7MO
05UhHP1MMfD0I6iU07=QI01kEfT0PTi/08U6KP2=?7X0TcQn08E2OP1^CGd0H56206a?O@1jBW/0PdAl
08e3MP25?WP0MC]k06TkN`1dA7L0OTYe08IAK@2ACVD00P2@C6<09`2@B6<0Rcm]08XlM`21C6d0MfMN
0660FP1DSdl0FI9105R@>P1HU3h0Ei`h05NK<@1MUbD0FhhL05R;4P1FR`h0DHP;05273P1@QAL0CXHN
04j35P19Q0h0Ah@804V21P18NPH0Bfh504eM0P1>C@40Bcd004Hb000l:@00>BP003TW000k9P00?bD0
03lV00109`00?RD003XU000203PS000403@R000f7`00=ah0034M0080<QX001T0;aX002hL000a7000
=1`003<L000a7000<1d0030L000_6`00<1X002`I000Z5`00:AL002LG000T50008Q80024A000M4000
710001T;000D2P003`P000d500080P00100001d00000303oool000X0oooo6P0000020?l009H00000
0P01000010050@002@<000h6000A200201D9000W01@<000G3@006a0001d?000L3P006Pl001/>000L
40006a8001h?000O4P0081D002DF000V6P00:1L002LE000V6@00:1/002hO000a8P00<R@003<W000f
9`00=b`003X^000m=000>cP003`o0@0oA@40?TP203i<0`11CP<0@E02045>0P11B040@D@1040k0@0o
;P00?R/00080?Rl000H0A3H004De0019>000BCh004Lo0016>@0204<c000O03l[000n:000?RP004<]
0019>000CTH104iG1017H`L0?FT;03e`4@0jMAP0>7TG03Z06P0fPAd0<H8L03616@0bPAP0<h8K03J1
7`0gQB40<hLW02f;;`0/SS<0:hl_02f?;00`SB@0<hXO03J97@0gR1T0?8LF03n6500203f75P0W03j<
6@14TA/0AYDN04NJ9016XC40@ZA103jUCP0iX5D0>YUH046?E@1;QEL0DH5G05:0F@1COUP0EW]J05]j
G@1RN5h0JWQQ06EaH@1VHf80IUQR06QCJ@1`Bg00O4Mi08Y5M`25C7P0MTih06M=O@1/CGT0MDeh07A<
N`1iC7X0JdYj06=5N`1N@gX0KDEa07M7K@24C6L0RdYV0080SU1U02L0TE9Z08e9L@2;BW<0OUa]06eg
GP1SRdl0GY=005RC=P1DTCD0DHlj05BC=`1EUC40FI8W05N;6`1GR180EhH>05>62`1BP``0EH8A05B4
501CQA40C8L?04V72`16Q0X0@g/:04U_1P1;G0<0BdL104Tl0015<@00?RT003XV000i9000=R8003TT
000l8`00?RD003XR000h7`000P0e8`002`0c7`00=Ah003DO000c7@00<AX002hH000]6@00<A/0038O
000`7P00<1l00080<1d00180;ah0034M000_7@00;1X002XI000Y5`009aL002HD000U4`00818001h@
000J3`006@d001H:000>200030@000P20004000M000000`0oooo000:0?oooaT0000000<0003o003o
00000000UP0000001P0100000P4000H2000;1@003`L001<:00805P/000d05``001P>000L40007Q00
01d>000K3`00710001dD000P4`008Q8001lD000S5P009QD00080:1P001P0:QP002LI000]6`00<240
03<T000i:@00?2l003la000n=@00?cT003m2000lA`80=e4303QC100hF0H0>e/803YL1`0kG0L0=e`6
03MF1@0iDP<0?4/304@o0@13=P0204Pf000W04/j0019=P00CSX004Tl0016?000AC`004Hi0014>@00
@c@004D^0017<`00C3L00552001?E080C6<703e_300dMQ00<WTD031n6@0`PQ/0;hHL03287`0[RAh0
;8TL02f9800]QbH0;HXY02f::`0/Rbl0:Hd`02V?;@0[T2L0<8lP03>=7`0bSAd0<h/N03N96@0kRQ<0
>h`B0080?Y0H02L0?ILL03nM7`0oX2H0?Z4b03NSA00`WU<0;IMQ02ZAIP0]S6L0;hEV03V4H`11P640
AgeO04UjF@1BNUH0GGII06MdFP1dKU/0KVMN06ENGP1QE640HE=W06I@K@1^CG@0P4ib089CLP1jC7<0
M4Aj07=:N@1fCGX0Kdml06]?NP1OCWd0FdQl05Y4N@1XAW40LT=/0898I028AFP00P2<D6`09`2>DG80
RE9`07mDL@1ZJ6T0HgiI06J8A`1ORD00EHPm04n8@01:Rd00CXlk05>@<01BSRH0DHXJ05265@1BPQ00
DGl<051n2`1?O0/0DGl:04f32@16R0d0@hL>04653`0oO@l0Afh804UG101<A@40B3L004@_0012:@00
?RL003`T000j8`00>B8003XU000i8P00>ah003LL000203DN000O03<N000c6`00<a/003@J000`6@00
<Q/0034J000d7`00=B0003<N000_7@00<1`0034L000^7@00;ad002dL000/6P00:AP002PG000W6000
91D002<D000Q4@007@l001/>000I3@0050`000l6000:10001P4000@0000M000000`0oooo000:0?oo
oaT0000000@0003o00000000o`000?l0U00000001`0100000`0000<200090`003@@000l8000B2`00
0P0F3`005P0J3`006@l001d>000M4@007`h001h@000O4P0081D0024F000R50009AL002PG000[6000
;A`002`N000[7P00:a`0030Q000e:P00>c00040i000n?P020453000?045:0@0oD040>eP403AN1@0d
HPH0<fH9035Y3P0cI`d0<VL=02eT300_G`X0<E`803QG1@10B`<0A4000080Bcl002L0DT40054o001?
@P00CdD004a10018@000B48004Y3001:>`00C3L004i0001@AP00D5H004aX1013LP`0=WdA0322500/
Q1@0:XHF02N7600YRQP0:H/L02J>7@0ZSAl0;8hU02b>:@0/TS00:Y4a02j?<@0]TBh0;i4V03>B7`0k
SaP0>hlE03^=5P0iSAX0>HdE03ZA500kUQH00P0hWQl02P0fXbP0=JH`03:R>`0aWTL0;iUC02^>GP0Z
QfD0:X1Y02mmJ`0gNV`2049hJ`0K04EfH@18L5P0Eg1?06I_CP1^K5@0LfIG06aQF`1SG5h0G5YS05YK
I@1RF6T0K5AZ07]BJ020DVT0OTM/07/mMP1j@gH0OT]i06a@N`1NCgd0E55n05a?O01LC7/0JdA`06m2
J`1m@f@0Q45X0080RT]]02L0S4ic089DK`1^GVX0I6iP06IkC@1VM4H0F6i704i`B@18NdP0BX5204j7
=`1CR2P0ChXO04j55`1@Pa80Cgh?05=o2`1@O@T0Cgd904f02019Q@/0@HX?03n;4P0lQ140@GT?04IZ
2@18E0<0BD4104Hd0012;P00@BX0044Y000o9`00>RH003/U000l9@00>B4003LQ000f7`000P0h7P00
7`0c7@00<QX003@K000a6`00<1`0038I000e7P00=B0003LQ000c8000<R00030J000`7000;Q/0030K
000^6P00;AX002TI000V60009QL002@E000T5000814001l@000L3P006`h001<:000@1P002`@000H0
000200007@00000<0?ooo`002P3ooolI000000050000o`000000000000000000o`00T@0000002@01
00000P0000<100070@002@<000d4000>1@003`X001<;000201H=000W01L=000I3P007A80020B000P
50008QD0024B000R4`008A@002HF000W6`00;1T002`N000a8P00<B@003DV000e9`00?Rd0044g0014
?`40ADT103mA0@0nEP80?5H203YG0`0kF`<0>5l3039R1@0aIPD0<VX802e/3@0^K0`0;F/;02aZ2`0/
IPX0:F@;03AN200nE0D0A4`10080CTd102L0Dd/005=8001DC@00DE0004m;001:A`00BD`004Q@001>
B`00DdX005Q?001IG@00Cf/3049g200iPa00<HTH02V<7@0YSAX09hlH02N?5`0YT1T0:90J02^@700/
Sal0:i4S02^A9P0[Tbd0;i8_032C<`0bU2d0=9@U03^A8@11TAX0@I8G046C5P0oV1/0?ITI03ZN6@0e
Y1l00P0`ZR`09`0ZZ3`09jA802RJD00YUEH0:HmK02R6H00WOf@0:WUU03AfJP0nLFd0BG5a04AbK`13
KfH0A6]P055`E01QLDh0Hfe>069VE01LHEX0Ff5K05URGP1MHel0IeiP06YLH`1aF6H0LU5Z07=:K@1g
@G<0PD9i08Y5O@1eBX00Edj104aBPP1KEGd0H5Eh06e;KP1aAFT0O49V07i0JP0207m7K@0W07a;KP1i
DFL0JEmN06E`D`1_M4H0JF=<05QIDP19IU<0AWI<04R3@01=QC00Ch<O05255`1@PQ@0Ch<B05:2401E
P0d0EWh:05222P1<Q@d0AXHA0469500nQa80?Wh>041b301:H@L0B4`304Xk0015<`00@Rh0044/000n
;@00?b/003hY000n:000?BH003/T000j9000>2800080>R4001l0=24003@N000d7P00=1d0038M000d
7000<R4003HS000f9000=B40038P000a7000<Ad002lL000^6@00;AP002TI000W6P009QT002DH000U
5P0091D0028B000P4@007A0001T>000C2@003`L000X4000600000P0001d00000303oool000X0oooo
6@0000000`000?l000000000000200000003003o00000000000008d000000P02000020040@002040
00T5000=1P004@T0018<000E3@005P`00P0H30009`0I2`006Ph001dB000P5P008aD0028E000S5000
8180028F000W5`00:1/002dM000`8000<b@003LY000j:P00>c4004<j0@16B0<0AE8403mI100iH`D0
=FH503ER100gG`@0>Ud303MN0`0hH080?6<503IW1`0`J`X0<6/802e[1`0^J0L0<6P902iW2`0eI0X0
>Ud7049I100204eG0P0F05E@0@1FCP00E5<0055G0@1=E`80BEP304IK1P17I0D0C682059O0@1GIP80
Cg<404Im2@0iQ`l0<Y0G02VE7P0UUb00:9DO02VG7`0TUah09iXO02RH7`80:YDP00l0:YLT02^H:00/
VB/0<9P^03:I;P0cURh0=I@/03NC:P0mUbD0@I/R03nM8@0mXbD0>:HV03:Z:@0/Zc400P0V[C/09`0S
ZTT08ZIH02>OG00SVe`099UJ02>EF00STET09HiJ0369G`0nPfL0Bh1]04UmJ`1:Mf<0CVeM05Y]E`1S
Jdh0Ff]@04eYEP17IE`0CF]F05M[E@1LIET0IemM06ILH@1XFV@0IUM/06i;K`1d@gH0O49j0816O`1W
Ch80BU:204MGOP1PFgX0JEme075BK01]B6/0ODEW07`oKP0207Y7JP0O07=<I`1lFV80LVeE071fBP22
JDL0NUQA05iFE01=IE<0BgE=04^4@01@R2h0DhHN05N76@1FQQD0EHHE05F8501GQQ00F8<>05B73`1<
QQ40B8LG04B45P10PA00@WL904QY1`1>F0<0C4L004Th0013;`00?b`0040Z000203lZ000603h]000o
;000?2P003dX000h9@00>RL00P0j9P007`0k9000>B0003PQ000f7`00<Qh003DP000f7`00=Al003HN
000d7P00<R00034M000_7@00;1`002`K000Z6P00:1P002TH000W6@009QT002@G000T4`008A40020@
000J3`005Pd00189000?1P002`<000H1000200007@00000<0?ooo`002P3ooolI000000030000o`00
0000000000<0000000<00?l0000000000000RP0000020040000:008000030@001@8000X4000>1P00
4`T001@<000H40006Q8001/?00806@h002L06Ph001hA000M4`008aH002@G000U5P0091D002@F000S
5@009aP002TJ000]7P00<2<003DW000i;@00?CD0040m0015B`80@ET603YU200fJ0P0<F`702m[200f
I`H0?68403iO0`0lG040>e`103YT100fIPL0<FX8031Z1`0]J`H0<6/503=Z1P0_J`T0<VT903YT1P0m
H@H00P18H0D09`1CFP80EUH005ML0@1?H`<0Af@604EV2@13KPd0>gH;049g201:MPH0Bgl904:93@0g
TA@0<9PN02VN9@0SWRT08ih[02NO:00VX2L09:0W02>P:00XWBL0:I`S02^K8`0/Vb<0;IdV02nM:00`
WRP0<YhZ036M:P0`WB`0;Yh/03:S:`0hYb/0=:X_02n[=P0ZZcX09Za0026/A00202:ZB@0W02BYC`0V
Z5P09:II02FWE`0YYeH09jIC02JTE00XXEP0;I]N03FII`0mTfT0?8mY03n4H`12Mf80B79O04i^E`19
KUH0@G=I03iaF`17LeD0EFeD05iUE`1VF640I5EV05mMJ01LGfl0IU=f0717N@1fAGl0LdJ405e@QP15
DX<0@e^005iPM@1WH7<0K5E_06]=K@1nAVT0OD9^0080O4MZ01l0LU1X07QSG`1dME00N7=908]QC@1j
Ee<0IEED05AYC@1@N4H0D8Hk05B;;@1GRQh0EX/I05N<601GSaH0F8dE05R<4@1ERa40ChdC04b:5`1;
R1H0A84E04Ij3P1:KPL0CV04051A0@1A@`00BcL004@[000o9P00@2P00080@2T000H0@2X0044Y000o
:000?2D003`S000n9@0203/W000C03`Q000m8P00?R4003XR000h8P00>20003PQ000g7`00=A`003<N
000b7000<1/002lK000]7@00:QT002`K000]6@00;QT002XK000202PG000:02@C000R4@00810001T>
000F30004@L000h6000;0`001`40008001d00000303oool000X0oooo600000000`000?l000000000
0005000000800?l0RP000000300100000`4000@100060@0020@000/7000A20004P/001P=000K4`00
6Q<001/A0080714002L07Q40020F000R5`009QT002HK000X60009aT002/J000Z7@00:Q/002XL000_
7@00<b<003LZ000l<@00@Sl004A;0010E`@0>VL9031a3P0`L0`0<78;035`200lJ`H0@6D303mQ0P0o
G`00?U`003aR0`0jI@D0=FT5035X1@0^KPL0<Fl703A_1`0aK`L0=6d703QZ1P0gJ@P00P10J`L09`1;
IPD0EVD205A]1@1:M@T0A7D;04Ek400lPQT0;XTI032:4`0fS180>9<I02nK8@0[WbX09:<b02:U>00R
YSX08:De02BU;`0SY2/08JD^02:S<00VXbd0::4Z02VP9`0_X2L0<Z4V03:R9P0dXbD0<J@X036V:@0[
Yb/09:H]02J[;`0X[S@09j`k02>[A00RZdX08ja902>[C00202JYC@0W02VXCP0ZZDh0:ja@02^_CP0]
[dh0;Je902b/CP0^YeH0<J=L032NI@0aWfD0<9MS032<G`0fOV00>gEO041^H@0mJV<0>gAY03ifJ011
MUl0DF]J05aQF`1YEFD0IU=^05MRL01AIg@0FEei06I@N`1XAh00IdB505=;Q@11EH40?Ef005=QM`1M
H7D0IUId06U<L@1jAfX0NTA[0080PDeY02L0MUaW075[G`1cM4l0MVa:07=RC@1WH4/0IF5605Ua@01C
OcX0EHL_05J;9`1GSR00E9<M05:B6P1BTaH0EY4B05J@401BT180CY0I04^>7018R1X0B7lE04ab3@1A
I@P0DUP405E:0@1D?000C3<004PY00129P00@B@004<V0013:@00@RX0048[0010:`00@2L004<U0010
9@000P0n9@00800o9000@2@003dU000l8@00=b<003HS000f8P00=R0003<P000`7@00<Al002lK000`
6`00;Q`002`L000_7000<1`002hK000^6P00:AP002HF000T5`008A8001hA000H3@005PX00148000=
1@002P<000H2000300000@007000000<0?ooo`002P3ooolH000000030000o`000000000000L00000
00<00?l0000000000000Q`00000030020000108000D200090`002`D00107000C20004P/001P<000I
3P00610001T?00806Ph002L07@l0024B000V60009a`002/M000/7P00;Q`002hQ000a8`00<R0002hP
000d8P00>R/003hb0013@040@dh3049M1P0iI`X0<G4@02Yk500_N@l0;gP=03Ae2P0jL0L0?6X603eV
100oHP80?5d003]R0P0iH@@0>FD503EX1P0bK@T0<W0;03E`2@0aLPP0<g0803I`200fL@X00P0mLP`0
9`14L`T0AW@704al2@17P@l0@7lA03f4600gSB@09i<X02RE8P0UVB@099l`022T=P0PZ3h07Z]601j]
BP0NZdX07ZY401jY>@0NZ3D08:He02BV=00WXc00:Z@Z02VT:P0^Y2P0<:@V02jU9`0]Z2T0:jP[02V[
;@0TZRh08:`c01j_=`0N/3X07jlm026[@`0SZd@09Ja002R[@00202bZ@00W036Y?@0e[3h0=:e003>`
@00b[TD0<JY5032[C@0_ZED0;jIJ032OG@0]XF40;I]T02bBHP0_R640<giS03McIP0iK6X0?6m`04Eb
L011LF`0C6MS05EKI01VEVP0JEQ`05AUL`15JgL0BUml05QGO@1PCX80FDJ404]?P@0oFgh0>fIl04UV
N01GH7<0IUIc06MBM@1iCF/0N4a]0080Oe=Z02L0LV=Z06e_GP1gMD/0LVY905mOBP1GIT40FG5005An
>@1BRCH0Eh/[05B>8P1BTQd0CYHN04jF6@1@TaD0D98C052A4@1>T1@0AhlJ04>?7@18QQ`0B7`E04i_
301BH0L0E5@305I8001C?`00CcD004T^0018:000@bL004@Y0015:P00AB`0048^0016;@00@B/0040W
000n9P000P0m9P00800n8`00?RD003lV000k9`00?B<003LQ000e8@00=1l003DQ000d7@00=1`0034K
000`6`00<1l002hL000_6@00<1/0030L000/6`00:QL002LE000S50007a8001`@000I30005@X00149
000=1P002`D000H2000600000@007000000<0?ooo`002P3ooolH000000030000o`000000000000P0
000000<00?l0000000000000QP00000030020@00104000D2000810003@H00147000B2P005P`001T>
000I3`006A4001X>00807@d002L07Pl002<C000W6@00;1/0034Q000a8`00<b8003@V000i9`00=bH0
03HV000h:`00?SP104950`15D@D0@F4903M^3P0`MA00:7XC02An5@0[O@l0;Gd=035k300eM0T0=6h9
03QX1`0lIPD0>F@603QU1@0lH`L0?6@803UX2@0eK0/0=G0=03Mb300_M`d0<GH=03Ef3@0hMa000P0j
Na409`0mNPh0?gh>04J8500nRal0=hPO03N;900bTS<09ILg02:K<00PWcD07:E401ZYB00JZd/07:iB
01Z_E00K[e806Ji701V[?@0LZ3L07jLh02BY=`0WYc@09jP`02FV;@0ZYb`0::PY02JZ:`0TZbd09:`a
02:/<`0OZc<07:Li01b[>`0P[Cd08Zdo02B[@@0UZ440::Tk02^Y>@0202f[>@0W03FZ=@0jZC80?:Xf
03ZW=P0gYd00<ZE1032WC00_Z5<0<JMB03FUD@0eXUL0<iiO02nJGP0bUF40<8YQ03=jI`0bJf`0=6Uc
03UXL`0kJg<0BFIX05=OI`1VFV/0Keaa05ITM@12J7T0?69o04AIOP19CX80BDR603aEP@0dJGd0<75k
03]ZN01=HG@0HEQc06IGLP1`EF`0KUU/0080N5]Y0280L6QS06ieD`1cOT@0KG5205aT@@1EKT00E7/l
0565>P1DScP0D9@^05:G8`1?V1l0CI/T04fJ7P1=UaP0C9DF04^E5`17TaT0A98O04:=8017QA`0CW@B
051S2@1BE@<0Dd/104m2001@?000BcD004P`0017;@00A2/004P/0018;@00A2`00P13;@000`11:@00
?RH003`U000203hS000P03/S000l8`00?BL003XW000j9P00>RD003TQ000i8000<b0003@O000b7@00
<Qh0038O000d8000<1h002lL000_6`00;ad002dL000X5P008aL0028E000O4`007@l001H<000E2`00
40P000d7000;1`0020<000D00002000L000000`0oooo000:0?oooaP0000000<0003o000000000000
2@0000000`00o`000000000000250000000:004100040@001`8000/4000?1P003`L001@9000G3000
714001h?00807A400P0L3@009`0O4@008aH002TH000`7@00<24003<V000d9@00=2P003HY000k;@00
>c4003hj0@14B0<0A5@7049R2`0iL100:g`I02ek5P0YOA@097hB02Ul300[OPX0;Wd:035g2P0aLP`0
<fd<03U/3@0fJ@h0>VX>03UX3`0hIPh0=fX=035/3P0dK`l0=G@@031k4`0^OAD0<7dF0360600203F3
600W03N25@0eQA@0?8`M03V?;00cT2`0<8lb02n?@00RU4P07ie2022SA@0JZE@05jaD01V^EP0G[eL0
4jeG01B]E00EZdX05Z]101ZX?00MZ3`08ZLh02>V=`0UZCD08jPa02JZ;P0SZRX09:l]02>^<@0U[SL0
9:hj02>/?@0RZT408JY202N]A@0[ZdD0;JE402jRA00ZXd00:jI00080:jU002L0=:Ti03ZW=@0oYS40
?:@b03JU>P0bXT00;jA@02fVDP0_Z500=:M=03FVCP0cXeD0<ImI03FKH00aSfH0;7iY02]YJ`0]IFh0
<Umc031TMP0nIG80AFA^04eWKP1@Ig40B6]a045YL`0jHGX0?EQl03m?PP0mCXH0<eb702U_P@0UMWd0
;f]h045QM01HFfl0G5aa06EMJP1VH6P00P1_HVH09`1_LET0K8E906V9?`1VNST0Gg8g05Mb@01@OT80
ChQ104nC?01<VS80D9dW04fM8@1:WR@0BIdR04RJ7019V1T0AILM04FD7`12T280@XTQ04Ym7P1@K100
De/6059>0@1C@`00DcX004hd001=<P00BS4004L]0014;P00ABl004D]0014;P00@bl0048]0011:`00
?RX003`Y000203dV000H03dW000n8`00?b8003/T000n9000?B8003`T000j8000=R00038P000a7P00
<al003<P000a7`00;Qd002lL000]6P00;Q`002XJ000Z60008aP0028F000N4`0070d00P0G2`001P0A
2P003PP000`700071@001@00008001`00000303oool000X0oooo600000000`000?l000000000000:
000000800?l0Q0000000100100000`0000L2000:100200d7000701<8000H2P006Pl001dA000P4@00
81@001lA000201lC000W028D000V5P00:ad002lO000d8000<BL003<W000e:`00=bl003`g0@10A080
@e44045O2`0kJa80=g@F03=i5@0[P1D0<84D031o4P0^Oa40;Gl=02ao2P0[OPT0;GT;02eg3P0`M180
=g8E03E`6P0fLA/0<flH03A_500cL180;W<B02md4`0_NQH0;84L02f2700aPQ`0;8HP0080<HTO02L0
=8TJ03J9700kTBD0>Y@g036E=P0`SSd0:XI=01n:E00PVdh08:EC01^XI@0E[V805jiM01J]GP0F[e`0
6ZmF01R]BP0H[4406Z`m01fZ>00QZ3L08JHc022Z=P0QZS008jd/02B_9`0S[b/08jha02V]=P0/ZSX0
:jTm02RX@P0WZTH0:Za<02nXB`0bWTT0<IM<02jIB@0[WDX00P0]XDd09`0`XTD0=Z<m03^T>00hYSD0
=jPm036U@`0aXe40;ZID02nWE00`Z540<ZM=03>UD@0dWeT0>IYP03:?I`0/OfP0:FaY02QTK00YGg@0
:FAh03EWL`0hK6h0=g1/03MeK@0hN6/0?g=[03eTM010EG`0>df403=:R00/Dh/096Z602AeP00XKW/0
>VEf051QK@1EHFd0G65Y05aWIP0206=ZH@0W06UnE01WSDD0HHTj05j0=@1INST0DgQ404f0AP19S440
CILh04ZL<@1>X2D0CYhP04fP9@18WbH0AihQ04RM8018Vb80AiHT04R@8@19Q1h0CgDG05UV2`1HD`<0
FDX005@m001C>000C3@004/b001:;P00ARl004H`0017;000AB`004L]0013;@00@Rh004<`0010;P00
A2/00080@bL001l0@BX003hX000k9P00>RL003XT000k8`00?2@003`S000i8P00=B80038S000c8P00
=B80038P000_7P00;QT002hJ000[6P00:AX002LG000T6@008QD001dA000M3P0060`001H:000D2@00
40H000d600071000100000<000000P01000H000000`0oooo000:0?oooaL0000000<0003o00000000
00003@0000000`00o`0000000000001o0000000?0040000200001@0000L1000<1@003@L001@9000G
2`0060/001T=000M40008140024C000O5P008a<000808Q8002L091D002/G000/7P00<R0003LS000f
9`00>RX003X`000k=P00@dL4045M2@0lJ@h0=g8E02ml700]P1/0;H4H02^4600_PQP0<8@I02n56@0]
Pa40:X<;02V22@0ZO@X0;7`<039i4@0dN1H0<GDN035e800_Ma`0;WLJ02mh600YN1P0:W/E02Uo6@0V
QAh0;8TN02f:8P0[SBL00P0^TBD09`0`SR<0<HdU03RC;P0fTch0<9Dn02f<@P0VOU<07XIL022IEP0T
YU`06jYb01B]K`0H[FP05ZiV01F^IP0I[EX06Je>01J]A00I[Cl07Jhi01f/=@0NZc<07Z`b022];P0R
[RT08jlV02J]:@0[[2/0<:P_03:W;P0cYRl0<:Dd02fY?P0^ZTH0<:=;03:GCP0aS540<H]A03:AE002
032FE`0W02jKD00]WDL0;:5602bV@P0]YTP0;:I<02jSE@0/XEL0;J=J02jSE`0_XE@0<IiJ03>JH`0c
UF@0<h]W02eoJ00WLFX096Q^02=QMP0WIWT0<Fef02mgL@0[P6X09hEV02n6H`0iOf@0@6Yb04=CO00j
B840;dB802U7R`0TGXL096j402M_O`0aJW/0@fUb04][K`1DJVL0DVmX0080EgAR02L0GH=@06B;@01P
Q3H0FWXh05Ul?@1CODD0BhY204ZD>@1:WCD0C:4]04fR9@1>Wal0BJ0W04NP;@16X2d0Aj0Y04RM:01=
UbH0CHdM04im5`1FL0d0H606065?0@1M@`00ESd0058l001==`00Cc4004`^001<;`00Abl004L/0018
;P00ABh004D`0014;P00A2`004@]0014;P000P18;@001P12:@00@BL003lW000i9@00>B<003XU0080
>R@001L0>24003DP000c8@00<Al003<S000b7`00;ad002hK000/6P00:QT002LE000V5`008AH0024C
000P40007@l001/=000I2`0050T00148000>1P002@@000L0000300<00004008100010@000@000040
01H00000303oool000X0oooo5`0000000`000?l000000000000>00000003003o00000000000007d0
000001000P0000D000080`003P@000h6000B2@0050/001L>000I3P007@l001lC000P4`008Q@0024F
000S5`0081L00P0S5@00400T4@00:1P002dL000d7`00>2H003/^0010=000@Cl103i80`0nG0`0=VlH
02en7`0[PbD098L/02R99@0]QA`202f46@0E02b66P0[R1T0:XLB02R63@0ZPP/0:X0:02]l2P0`N`h0
=7XD035j800aNB<0;W`Q02Yj8P0XOR008H0P02B06P0SQ1`08HTS02N=8`0XT2D09YD^0080;ID^02L0
<I0^032=;`0iTC@0=I9402nEA@0]SDP09X1I01j8G@0PWEH09JQL01Z[M00DZgP05jab01N]L@0F[W40
5jmS01V_EP0G[TP06:m001^^=@0O[C<07Zdc01j]<00P[b`08ZhX02V]9@0_ZbP0=:LY03^T:P0oXRL0
?Z4Y03ZT:P0eYC40;jHi02bV@00]WdH0;YU:036IC00cVe<00P0bW5X01P0ZW5P09YQH02FHFP0XW5L0
::1N02BPG@80:IaP01l0;9aO03:KG`0aVV<0<9MY02fGK@0[UFT0;Ha[02^5K00WNF`08g5`01mYM@0Q
KWT0:GQd02R7L00TSVH0899T02J@HP0cQfD0>g9b049FO@0l@XD0<Sb802PkRP0TCXX09VB:02M_R00b
K7h0@79d04UgL01=MVX0CWMV0080DWeL02L0GHa806FC>01SQC<0GWDi05Yh?@1COCh0CXXj04ZG=019
X2h0C:8Z04bO9@1;Wb<0Aj0[04JQ<@14XC00AYh/04FK9`1:U2<0D8LK05Ef3P1II`@0GeT105i;001M
@@00E3`005@g001?=@00D3<004dd001:<P00B30004H/0015;P00A30004H_0014<000@b`0048]0014
:`000P13:P007`12:000@2L003dU000n9P00?B@003/T000j9@00=R<0034Q000b8@00<b00034P000b
8@00<1l0034M000b7P00;Q`002/J000X6P00:1L002@D000Q50008Q8001d@000O3P006``001L:000D
200040L000/500080P000P060`0200D2000400D100040@000`00004001D00000303oool000X0oooo
5`0000000`000?l000000000000?000000800?l0O000000020020000104000T3000:1`0040P0018;
000D2@005`d00P0H40001`0L4@007Q80020C000R5@008aL002LE000V5P000P0S4`009`0U5`00:AX0
02dL000f9000>b/0044b0016A080@U4703YO3`0hLA/0;h0[02R:<P0ZRRl0:H`^02V;:00[Qal0:XDK
02f5600YR1L0:HTF02^74@0ZQ`l0:H<;02]n2`0^N`/0<W`=03En5@0`P1l0;h4T02^2900WPBH098<R
01n68`0QQAh08hTS026=:`0TTRX09YL/02>J<`0202NK=@0W02fE=@0_TSH0<i@h03B@A`0]U4/0:ha@
02InGP0OR5h08imF02JYGP0JZWH04Zam01R^MP0F[7P05:af01B^J@0E[UT05k1>01b_@00N[cL08:dd
02:/<`0S[3408J`/02B]:00X[BH0;Z`W03>X:00mYBL0@J4V04>N9P15WBT0?Ih^036U=00/YSd0;JA1
02nUB00_YD`0<:AA0080;J9N02L0:I]R02:CI`0USF/09He]02F<KP0SSf`09hi]02RAK@0UTfh09IEb
02JFM@0UUGT09YEk02VBM`0XRgL09XEf02AmM@0QN7D077Ef01emMP0ORG@089Mb01nJJ@0NVFD08i5S
02^6J`0iLGX0?UZ503U9R`0^B8T09TZ602AEQ00[HHD0;FV5039/P@0hNGT0?89^04J0H`1=PF400P1E
RU406@1SUD40HiPe0666=P1HMSl0EGY00562@@1@SS`0CI/f04VS<@18XBh0BIl/04VP;@16XRh0AJ@a
04FU;`14WRh0A9TW04RC801?OQD0EV`705YN0@1OD`00Fd<005Hn001B>0000P1A=`00301B=@00D3@0
04he001<=000Bc<004X^0016;`00ARd004<_0014;000A2h004D/0080A2d000d0@RX0040V000n9P00
>bL003`W000k9P00>RH003HR000e8`00<R40038R000`8@00=1l00080=1d00180<ad0030N000`7000
;1X002PI000W5`0091<0028B000P3P007Pl001d>000K30005`T001@8000>1@002P@000T400081002
00P3000300L300060P001@8000<00P400P02000A000000`0oooo000:0?oooaL0000000<0003o0000
000000004@0000000`00o`0000000000001h00000006004000040@00208000`6000A20005P`00P0G
3@002P0H40006@l001T>000J3`006`h001h<000N4@008a8002HC000X600202LG000W02HH000Y6000
;Qd003@V000o<000@cd004QD200lIQ@0<G@R02mo;00VRCT08hlm02N?>00VSSP09hd_02V<9P0YRb00
:XXL02^9600ZRA<0;8XA02b:3`0]QQ00<H4?031l3`0cOA40=80F02n36`0_PQl0:8<N02B67`0SQb40
88TU02:;900RSBT08I4a02>E<P0SVS@089dm00808ido02L099Pn02VF?@0^Uch0;IA:02bFCP0[S580
9g]Q02>6HP0VXEL0:ZYN01bYM`0AZgl06:]j01F[O00@[7`04Z]^01:^H00H[e807Jm2026^>P0UZSD0
9ZT_02FY;00VZbP09Z/T02Z^9P0^[2L0<:PY03NV:00jX2P0?YdZ03nJ:`0oVbd0=J0a032R>P0_YT00
;JY802^YCP0WZ5L00P0VXf<09`0SVFT098Uc02AoN`0QO7d087Mm021mN00TOgL098Ej0269O00OSgh0
7i=o022FO`0SV84099=o02B=OP0SRWd08H5l01f0OP0KP7`06hYe01^DL`0KX7@07:9_01bLI`0PTfL0
:8=`03A]N`0jFXX0=e>A02eGRP0UFX@09Eb002YOP@0`IH40<Fao035lM`0eQfX0@XEQ04^9EP0205VD
B@0W06FL>@1RU3H0H7di05I`?01AOST0DX`i04nH=`1<XSP0B:@g04RP=P1:VcL0BJ0g04RR=015YC80
AJ<b04:M;P14UR@0CHTJ05Ee2`1JI@<0G5D005a;001F?P00D3H004dd001==P00C3@004de001=>000
BS<004Xa001:<000BBl004L_0017<000AS<004H`0017;`00ARh00080ABd000T0@b/0048Z0011:000
?bX003`X000m:@00?BP003TT000f9@000P0e7`005P0b8000<ah003@N000c8@00>28003@S000b8@00
;ad002/K000Z5@009aD002<E000R4@008A0001l?000M30006P`001@;000@1`0030@000T5000:1@02
00T4000400L300060`001`8000L200801`4000<0104000<0000100004000000<0?ooo`002P3ooolG
000000030000o`00000000000180000000<00?l0000000000000MP0000004`0100000P0000H1000<
1@004@T001L;000I3@006A0001/@000M3`007`l001d@000J3P0070h001lC000P500081<002@F000Z
60000`0X6@009P0Z7000<1l003LY000o=P00A4P104AO3@0fLb<0:H8e02R7=00OSCT09I0h02N?=`0O
ScT088lb02:?:P0RT2T09HhP02V;5`0/RA80;8XC02Z<500/RQD0;hHE03:15@0aPAH0<88E02f55`0^
Q1P09hDF02285`0ORal08HlY02FB;00RTc8089Dn02:H?@0QW4407Ia90P0MWDP09`0PVDL08YU802BI
AP0VUTd0:9QA02N:EP0SMV<098EV02NPF@0XZf006j]h01:[P00HZ7h05ZR100b/P00>ZGH04J]T01J_
E@0O/DH08Ze002J[=`0XZBh0:ZTW02ZY900/ZRH0;J`Y02jY;00^Ybh0<Z8`03>M;`0eW2d0=Y//03RK
;@0eWC80=Ilg03:V@00]ZTH0::QA02:TG`0202:HJP0W01n<LP0QNW/086n101mWP@0MH8007FMm025_
P00ON8L06gn701Z6QP0LSX<07iF2026IP@0RVGd099Ak02>@O00PRH007XIo01b7O@0JSgL05iYf01ZT
N@0IYW<07YiZ022=J`0YLW40<Eml039CQP0cE8L0;62402UTO`0YH840:f2302eVPP0/L840;Gee03:5
J010Qel0Ai5C0080FIY702L0IiPh06V6=@1PLS/0EG4i04n1=01>TS40CYdf04^R>P19YC`0AJ1004>L
@`18Wd00AJDm04>V=P13XSH0@Y`_04V?8@1@O`l0EfL405eH0@1PC000ET@005<k001>=@00Bc0004Tb
001<<@00BS8004/a001;<P00BcD004dd0019<@00Ac0004Lb001:<`00BS0004L`0016;P000P13;000
9011;@00@bT003lX000l9P00?BL003`W000k9`00?RP003/W000i8`00=b4003@O000g7`00=B0003HO
000e8`00=R4003HR000c7@00<20002hN000]6P009aX002@G000U50008Q<0020@000N40006@h001@9
000@1P0030D000`6000:1P002P@000T4008020<000L020@000L4000710001P<000H1000300000P00
00800@003@00000<0?ooo`002P3ooolF000000030000o`000000000001@0000000<00?l000000000
0000M00000002P0100000P4000D2000;10004PX001D<000H3@006`d001/@000N4@0201lA000801lB
000P4P007a<0024E000R50008aD002HH000Y6P0202hM000W02/L000^7P00<B4003h/0010?P40?U83
03aY500/NbT08hHi02R9;P0TRb/09Hh/02B><P0NScT07i0b02:@:`0RTRL09hhN02^:5@0[RA00;8XD
02V@600XT1X0;h/G03655P0bPaH0<H8D03>2500`PaD09hDC0229500QSR407Y@`01jF=P0NUc`089U4
022JA00OVdP07IY?00807IQB02L07IIB01nGE00RVU408YQA026GD@0URUL09WET02B7I00YXeX0:JaL
01^]LP0CZg/05ZQm016VP00?ZWh03Zae012_I00I/5H07k9<02:^A@0UZcX09jP_02ZW9`0/Z2P0;ZPZ
02nY;P0dYC80<j4e036O=`0_WCH0<Idb03>O;@0eX300=j0a03BR=P0bYSl0;J]702RVE00QXFH00P0P
UGD09`0NRWP08WQn01m[Q@0MGhD065N201MLP00JIH806ff501]`R00PN8L08H>602>=Q@0QVH008Yei
02FOMP0QWWL089Uh01jDN`0NTG/06iIm01VMO00KXH406iml026BL`0SPF`0;FIb02iJO00^E840:eZ1
02YTO@0WJ7d0;6N002iZPP0]Kh@0;7F102alM@0cPfd0=hES04>CE00205RK@P0Q06JG<@1UQc00G7/e
05Im<@1CS2l0CiHc04jJ=`1:WSP0B:8l04BQ?011X400@J5004FT?@15Xd00@J4h04RG;P1>QQ`0EW06
05eL0@1OCP00GDD005Ln001C>P00DCD004da001?<@00Bc8004`a001?<@00CC<004dd001;<@00BBh0
0080B2l000@0BS8004T`0017;P00@b/00P13:P02044Y000>03lX000o:P00@2T0044Y0011:P00@R`0
040Y000m9@00?28003/Q000i8000=Ql003LR000g900203PS000=03@R000b8@00;Qh002`M000Z6`00
:1L002HC000R50008Q<0020A000J3P005``000l9000300d6000400`6000;1P002`D000/500<02PH0
00L02@H000H500070@001P8000<2000300000P0000`00000303oool000X0oooo5P0000000`000?l0
00000000000E000000800?l0LP0000005P0100000`4000@000070@002`8000d6000B2P005@X001L:
000G3@006Q4001lA000K3`007a40020B000T5P009aP002LJ000X6@00:1X002XK000[6`0202`M000W
02dL000e8000>BH0044c0011AP<0=e`603I^500[OBH09HLc02Z89@0VRB408h/R02B=9`0OSbl08XlZ
02:?900PSb009hdG02^94P0ZR0d0:HdB02RA5`0WTA/0;X/G03665P0dQ1P0=H<H03Yo6@0`Q1T0;8HE
02>;600PT2807YHd01bI@00JV4H079Q<01bHC@0LVTl06iYH00807I]L02L07IYN01fKGP0QWEP08YUD
026ED`0RRUT09GQU02F8H`0YY5P0:Z]H01b/K@0CZ7X05JEm01:UP@0?Z7h04Zad01>`H`0J/U<07k15
02B^?P0/[380;Z/Z03:Z9@0eZB@0>:PW03^W:`0mXR`0?9l^03NO;`0gWS00=il/03BQ:`0gXBl0=j<b
03BV=`0]Z400::]=02BVF`0RX6/00P0RUW@09`0PRGX08GV101iZR00KFhH05e2301AHP00GHh0066Z2
01e/Q@0PLH<09gb002N7P00UU7`09im`02BTK00NYVh07Z9c01bNN00NUW`07YN001bHQ@0OUXH07hn0
02QkM@0/K700>5Qj039FOP0XG7l08VQn02AbN@0VMWX0;G5k02icO@0`M800;gQn02elNP0bPG<0=XEW
046EE00205RN>P0W06BG;@1OSC<0F8Xh05F;=P1ET3D0DILg04fJ>P18WC<0AIla04:O<`11WSD0@j4f
04FR=014X3<0AiT]04j;7`1KMQ00HV<4061A001OAP00G40005Pl001E>`00DSP004hf001?=`00CS<0
04`e001<=000C3<004/c0018;P00Abh004H^0017;`00AS0004L`0015<000@bh00080@R/00200?R`0
03lX0010:@00?bd0048]0013;P00@c0004<^0011;@00@2L003lV000m9000>B<003`S000j8`00=b@0
03PS000f8@00=2<003<O000_7P00;1T002PJ000Y5`009aD002@E000Q4P007@l001P=000D30004PX0
00l900803`P000<040P000l8000?1`000P0=1`0200h7000800`7000:1@0020@000L400070`001P40
00@10003000;000000`0oooo000:0?oooaH0000000<0003o000000000000A`0000000`0100000000
0000000n0000000<0040000300000`8000D100090@003@D000l8000D2P005P/001L=000G2`006@h0
0P0L3`000`0Q3P008A<002PG000202PH000402TH000Y6`00:ad002`L0080;Ql002L0<al003PV0011
;@00@ch0041@0`0`I0P0<70@02]o7@0WRBD0;8PL02R96P0TRQ`098`N01n>900SSR<09HhN02J=6@0Z
SA<0:XX?02^<3P0ZSa00:Y8G02NB6`0_SaL0<8/I03>96`0hQad0=hHQ03>9800_RaX098hI02:B8P0P
UC0079Pl01VH@P0KVDd07IY=022KD@0MWUX00P0NWel09`0OX6@07J9S01nQG00OW5D07YU>01j@E`0R
OVH08HeR02^UE@0^[5L08:U[01FWNP0CX7d05:2201>UO`0DZG805ZeL01^_A`0P/3P0:Jl^036^9P0f
ZR00>:TO03ZY7`0oYb00@jHR04BS8`12Wb<0@9lT03nN9P0lX2P0>Z4Z03FS;`0bZ3@0:jTo02JZB00S
ZED08ZIQ026QJP0202:HLP0W02:;N00PNWl07FR501iGQ`0PBHL06e>301YROP0IK80086mo02EfO@0[
P7`0;8Yh02ZFLP0YXFL09:QY01jXJ`0LXfl06Yae01fCOP0LTh8078n402:3P@0XMW`0<FAf03QLM@14
F7X0>6Am02]`OP0ROWd09HIf02F5MP0WOGP0:gUk035dO@0aLg/0<gAi03=lMP0fQVP0AYUB0080GYdh
00P0IHlb05b6@01FRD80DXe0056C?@1@Vch0CI`i04^L;P<0Ai/W01`0AIl[04NN:`19V2H0Ch/M05Mj
4`1SI`P0IUL106=;001QA000G3l005Tl001I?@00ECX005<h001C=@00DC<004dc001<<@00B38004L_
0016;P00ARd004DX0014:P00A2d004H_0016<@00@bl00P12;P008P11:`00@bT0044Z0012;@00@bh0
04D`0014<@00ARl004<_0012:`00@2T003dX000n9`00>bP003XW000k9@00>B8003DS000d8@00=1d0
02lO000^6P00:aX002PG000V5`0091D0020C000L3@006P/001D:000A2P0040T00149000B2P02014:
008040T000`040P000l8000?20003`L000`7000;1P002`D000X500080`001P<000D00002000:0000
00`0oooo000:0?oooaH0000000<0003o000000000000AP0000000`01000000000000000o0000000G
004000040@001P<000L3000910003PL00148000C2@0060X001T>000I3`007A0001`A000N3`008A40
02@C000Y5`00:1P002/H000X7000:Ah002/M000`80000P0b7`009`0e9@00?RP004He0016B@40?E/5
02e/2P0ZM@d0:glD02V9600^RaH0:hdH02J?6@0XSAX09X`L02N<6`0ZS1P0:h`F02j<4@0_SA00<8l?
02n?3`0^Ta80;I8F02j@6P0]Sah0;XlP03:?7`0bSR00<i0O032B7@0YU1l09I@Q022F:P0NVC4079Tl
01bKA`0OW4T07im;01nRE`0201nVH@0W01fWJP0OYf`08:AR02:LE`0MWTh07IQF01n6IP0UU6@0;jED
03:[E00RYfh05Z9n01NLPP0FWHH05J>001NVLP0H[5T06Ji0026a;@0Z/B<0=JlM03V^6P0jZa`0?:/M
03jY7P11Z1h0AZDQ04RP8@18WB00@idU03^N:P0bXBh0;jDc02bZ>`0XZdP09:YC02FVG@0TXV@08ia[
00808I5`02L07hAf01meO00OIh4095N002Y8O`0VDGd095ml02A[OP0WMGX0:X9e02j<L@0^U6X0;9]Q
02^SF`0WYf008jQW01jOLP0JU7/06XR001^4Q00KO8<07gAl02QVM`0`FGP0<VIi03AeN`0/Q7P09Xmj
02>HN00UVWT09YAe02J4N@0XNWH0<W1e03I[MP0hIgT0>GIf03j9I01=WTT00P1TV3L09`1VQCL0GW]1
05MoA`1BPdD0DXa005:G?P1?W3P0CYP/04bH8P18UB40BiHQ04JG901=UR00DX`I05Z04@1SKPP0J5d3
06AA001PA`00GCd005/o001H?P00F3`005Hj001E=`00E3D0054a001A<`00CS<004/a0018;`00@2/0
044Y0016:P00AB`004L^001<<P00BS@004Pe000204Le000Q04D^0013;P00ABh004D_0017;P00B380
04Xb0017<000@Bd0044^0013;`00@bd0040]000n:`00>bH003XT000k9000>28003@Q000d7P00<Q`0
02lJ000/6@00:AL002LF000T5@0081<001`?000I2P005PX001<:000A2P004@/000804`/00P0B2`00
3P0C2`004PX0014:000A2P004PX00108000>20002`P000X6000:10001`<000H2000500000P002@00
000<0?ooo`002P3ooolF000000030000o`000000000008L0000001P00@4000D200080`002@<000X5
000?1P0040P001@:000F30006``001/;000L3`007A80020D000N4`008A8002LE000Z7000:AT002XF
000/6P00;Ql0034Q000b8P0203DU000W03`W0010<000ASl004IB0P0iI@L0:W8=02]g3@0/P140;8TB
036<500ZT1P0:94J02b?600YSaL0:H/H02^;5`0^RQH0<X/@03B;3@0fSP`0=i8>03:B4`0^TaT0;I<P
02RD:`0VU2/0:I@U02VE900^Ub40;YXR02RJ9@0WVR@09IXU026J;00QW3L07ie0022MA@0VXD`08JII
00807jQP02L07ZQX01nVKP0QY6807imH01bTCP0LX5<08IIQ02NLG@0bZ4h0=J]@02:YJ@0GXW/069]o
01FIP`0DX7l05Z9a01FVF`0IZd807Zd`02Z^9P0c[Ad0>JhL03b]7P0l[1l0>j/R03^]9`10ZRD0A:HV
042U9`0hXB`0<:0`02RS>00TYT009JM902JXDP0VYUh0::=T02FIJ@0USFd00P0QPG<09`0OMWP07FYm
021UN`0ZGGX0<5Ef031HM@0_GW<0;fYg031jL@0^SG40<9EW036JG`0`W5H0;J9C02bVF00WYV@08Ie_
01f@O@0NPh807Gf201mbO@0RJWL0:eaf039HM`0_MGL0:Y5h02JPL`0UYg<08j]c02NWLP0[VgD0;8Yh
02f1M00eMFl0>f]]03iQL@10Lf/0AXmM05JSA@0206RH=00W06J2=@1KMd00Eg]605:0AP1BRD<0DIE0
04nI>P1=V340C9DV04^C8P1>TB40D8hM05B75@1QO0h0Ig<706YR0P1WD`40I4X005a3001J@@00FD40
05/m001I?@00ECT005@g001B<P00D34004hd001<=P00BC0004L_0016;000A2`004P]0017;@00CBh0
04dc001==`00CSL00080AcD000L0AC4004@_0013;`00B2h004X_001:<@00C3000080BBh001P0ABh0
04<[0012;@00@2`0040W000k:@00>R@003XR000k8`00>28003@O000c7000;QT002XH000Z5`009QD0
028D000Q4`006a0001P;000D2P004`X0018;000A2`0201<:000301@:000E2`005@/000<05@/000/0
50X0014:000?20003@P000`8000;1P002`@000P300060P001@0000400008000000`0oooo000:0?oo
oa@000000P000?n80000000J008000030@001`8000P4000<1@003@L000h7000A1`004`X001D<000J
400070h001l?000N500081L0028F000U5P009aD002PI000/7000:QL002dJ000^6`00<28003<V000i
9`0203XX000W040]0015>000B4P004IL0`0iK0/09WXD02en4`0`PQ40;hXA036>4`0^T1T0:Y0G02j=
4`0^SA00<8`B032;400_S140=8`<03R>2P0fSP/0=hlB032B700WUBH09ID/026E=@0NV3L07iTa01fI
;@0UWB/0:j4[02^P:P0YW2H09idW02:M:`0PWCD08J1102:RA`0TYDh09JYK00808JUR02L08:QU022R
JP0SXEl08j1F01nUB@0PYT/09j1E02ZSC`0cZT80<Zi701jYH00EXG@069In01VDPP0DVGd05IY`01JN
G@0HY4X07ZLn02NY=@0^[2h0=:dZ03J]:P0f[Bd0<jd^036/<`0f[380>:/c03>V=`0/X3`09i]302>K
A@0PX4d08:5E026SGP0QYF@08j5V022?K00QNg800P0QJgH09`0RIWP08VAk02QYM`0^K700<Fi^03=Y
K@0eIVP0=G5X0360J@0^TFT0;YIP032HGP0bVED0<:1A02nWE00YYV809Im/02>BN00QQH008h20029i
N@0VMfl0;W5Z039gI`0^Sfh0:jEc02V/L@0X/G00:;5]02^[K`0`WG00<Xed03F4L00hNfX0?FiX041[
IP15OV<0D9YD066U?00206^F:P0T06>6;01HOcH0EX<k04j8@01>Sd40C9Q004bK?@1:VC<0BIH^04f?
9@1ARA`0F84C05ih1`1XL@<0K68106]F001UD000HDL005Y2001H@P00FSl005`n001F>`00DcL004le
001=<P00CS<0050e001==P00Bc4004/]0018;P00BBh004La001==P00D3@00`1>>P0204`g000N04Lc
0018<@00A2l004<^001:<000BRl004X`001:;P00BB`004H/0015:P00@bT0048Y00109`00@2H003hV
000m9`00>BD003TR000c7`00<Qh002dK000Z60009aP002HF000T5`007a8001`?000H300050`00P0C
3000100D2P005@`001H<000F3@0501H<000<01H;000D2`004@X0010:000?2@003PP000d6000:1P00
1`<000L2000500000P001`00000<0?ooo`002P3ooolD00000080003o8@000003003o06<0000001/0
0@0000<000050P002@@000h6000@1`004PL0018;000D2P005P/001`>000Q4P008Q<0028A000T5000
9QD002HD000S5P009a@002HI000[7000:QX002dL000]7`00<b@003LS000k:0000P0o;P009`14=P00
B4<004A@000oH`H0=7DA02N27`0^Pa/0<XTG02f>5P0aT1L0;94J02j>5@0bSa00<hl<03>=2`0dS`/0
;hl<03>?300dSP`0<8l?02^A700WUBh089Pl01nH@00JVD<06Y]401ZL@@0KWT007Ylm026R>@0VXSD0
:Z8]02RQ;P0SWc808Z4j026R@`0PYDX08ZEB01nWGP02022VI@0W01jRI00OW6T08Y]P02:NE00RZ4<0
8ZY102^WB00]Yd00=:Xe032]>P0KZTl05j1V01b@M`0LSH406Y1o01J=L`0ETVD05YaD01jSBP0WYd40
;ZXg03B]<@0e[Rl0=:`^03F];00a[300<jdf036/?P0^Z4809im802BECP0PV4l08IYF02:KH00QW6D0
8IiY026HJ@0PQfd08W=b008086Mc02L096Ua02U[L@0YMV`0;H9Y0329J@0cPF@0=gaP03B2H00cS5`0
;IMK02fGG00`UE/0=9MG036OEP0^YEd0:ZEW02RSJP0WVVl0:8mb02V<L`0ZR780;8aX03:?GP0eUed0
=:9U03B[K@0b[740<:i`032^KP0_Z6L0<YQ[03F=K00kPf/0?W]X03mcI011NF40B91G05FRA01ZX2h0
0P1`TR809`1UP280GH<V05F9<P1?T3X0CIQ004VJ@013Vd00AYPm04NE;P1;RR00FX0F069a2@1ZJ040
JF4006MF001VCP00HdX00614001L@@00F4@005]4001K@@00EcL0054h001?<P00Cc<0054c001@=P00
Cc8004`]0019;@00B2/004`_001?<@00CcT005<k001A>P00DC/0058j000204lf000V04`c0018<000
B2l004L]001:;@00B2h004T_001<<P00Ab`004L]0015;@00A2/004HY00109`00@bL003dW000m9@00
?2P003XU000h7`00<al0034J000]6@00:QX002LI000T5P008A@001`A000G3@005@h001H>000F3@00
5@h001L=000F3@005`h001D=000E300301D;000501D<000F30005Pd001@<000A2P000P0@2@00100?
1P002`D000T400060@02008000H00000303oool000X0oooo>00000000`00o`0000000000001Q0000
000>004000010@00104000P2000>1@0040L001@8000B2@0050X001D;000L3`008100020E000S5@02
02DH000<02LK000Y6P00:AT002PI000V7000:A`002/J000^6`00<Qd003TR000k8P00@2T00P11<P00
9`16?000BDX1041H0P0jJP`0<7/G02J99`0^RbD0<8hR02fE7`0_U1`0;Y4H02n?4@0cS`d0<8h:03:?
2P0`T0`0;I4=02j@3`0[TA@09Y<I02FF9P0SVCD07i]101jK@00MVcl06Y]001VN@@0HX4<07:5101fS
?00OY3d09:Df02>T<`0QY3L08:I001fVB@0JYTh07:ID01nUH@0202:SI@0W01nNI00QU6X099AQ02NJ
C`0UYcX0:jXg02jZ@00aZC@0=:/Z02j/<00LZTL05ieN0269LP0NPh@06XJ301J4N00FRfT069YI022S
C00WZD00:j`g02n];`0a[B`0<Z`V03>Z900bZBX0<:/e02f]@P0/ZD/099mB02:DE`0QU5T099EL02JF
IP0UUV/09IIZ026?K00RP6h08g1a00808fm`02L09W=/02EhI`0XQF@0;iEO032IGP0cUU/0=I9H02nE
EP0]VUD0;9aB02jJD00_VDl0<IaB032RFP0^Y6@0:jA[02ZSJ`0YXfL0:YaZ02bFK@0`TV`0<iUQ03:R
F`0eZ5l0=:YV03>XK@0cXWD0<ZAd03>UL@0bWV`0<HQZ03>2JP0kNG00@7M]041lH`12TE`0CZ5906FQ
;@1gT1H00P1hO0h09`1aM140I7/C05^4701BSbP0CiLh04FK@016VT80AIHk04V@:`1AQQ`0GgL>06YY
1@1[G@00K5D006M>001UC000I4L00653001L@P00FT@005]1001G@000ESX0054i001<>@00DSH005<f
001C=`00CS@004/a001;:`00C2h004ha001@=000DS/005Hk001D?000Dc`005<m000205@h000N050f
0019<P00B30004L_001:;P00BC<004d`001=<P00Ac4004H]0014;P00AB`004<Y0011:`00A2L0044Z
000m9P00?2H003XS000g8@00=Ah003<L000_6`00:aX002LH000T5@007Q@001d@000I3`0060h00P0H
3@00100I3P006Ph001X>000I3P0501L<00805`d000`05P/001@<000E2`004`T00189000?2@003@H0
00/6000910001P80008000010005000000`0oooo000:0?ooocP0000000<00?l0000000000000H000
0000200100000P0000@1000:0@003@@00145000D2P005Pd00P0F2`004`0I2P006a00020@000U5000
9aH002PF000X6P00:aT002/J000X6`009Q`002DI000W6`009QX002hK000`7P00>RD003XX0010<000
0P13=P009`15@P00Ae0203aP1@0fL@h0;88M02B>;00ZT2T0;9@Z02^G9P0^UQ`0;I8F032>4@0cSPl0
;i0<02fC300[T`h09Y@?02JC5P0STa`07i@T022F:`0RVS<08Y/i026K=P0PWC@07Ydf01jO>P0KWd00
7:5001VS>`0JYS/07:Lh01jX>P0PZ3d07ZQ801fVE@0KYUP07J=M01fSI002022NJ@0G026EJ@0OQg00
8HYU02JGD00VYCL0:jT^02jZ=@0_Zb`0=:`V02n];P0NZD806iYH02B2K`0RNhD07Gj801R2O@0GSG40
6iaM022YC00T[3X0:Zd^02f^9@0a[R000P0eZQd03P0dZb80<J`b02b`@`0WZTh08iiH02>CG@0STUh0
9Y5R02N=I`0XS6X09h]X02N3JP0VNVl0:Fmd0P0XMVl09`0YOfT09HYS02VEGP0`WeL0<jIB03JUCP0f
YDd0<JE;02fVB`0/YTL0;jA4032S@`0aYDP0;jME032QIP0`WG40;j1]02jVIP0]YFL0<9mV03:LH@0d
XU`0=JUQ03JWI@0aX6/0;iYb02nEM00cUWH0=IMg03BCL00dQW00=GmZ03mgJP13NfX0@hiU04NTCP1H
Yc00L9PB07Yn2@0207U^100W07I[1@1`K`T0HG`A05J:701BSb`0BYLk04ZF?01<TCD0D8LT05aj5P1Z
J`T0KUl106]E001ZCP00J4T00698001R@`00HD8005e3001L@`00G48005U0001F?000Cc`0050g001D
>000DCL0058i001A=`00D3@004lc001@=000DS@0058h001B>P00DC/005@n001B>`00Dc`00080DcX0
02D0DcT004hd001;=000Bc0004Lb001;<@00CC4004Ta0018;@00A2d004D^0016;@00@bh0048[0015
:P00@BX003lU000m9@00>RD003TS000f7`00<b0002hJ000[600091D0028G000Q4@007a0001PA000I
40006a0001`@000K3`007Q0001d@000M3`0070l000D06`h000h06@d001L<000F3P005`d001H;000D
2@004@T0010:000?1`002`H000T300050@000P00004000@00000303oool000X0oooo=`0000000`00
o`000000003o001P0000000N004000010@001@8000X3000<1@003`X001<;000G3@005a4001/@000J
3`006a0001d?000Q4@008AD002<F000T5`00:1P002XI000[6@00:QT002PI000T6@00:AX002/I000/
6`00<ah003`V0011;@00ACH00P14?0009`17A@00AEL203]W1`0dNQ40:XLQ02:B<P0YUBl09iPc02RH
;@0ZUQh0;94E02n=4@0bSPd0;I8;02jC3@0[T`l09iHC02FE7`0SU2X07YDd022F=00RVC<08iPd02BI
<00QWBh08Yd]022N<`0OWcT07:8i01ZQ>00JXSP06jLk01^[@00MZ4@06jU>01^WF00MYUX07J=M01jP
I`02026HK00W026;K`0NM7H087UZ02BAD@0UYcL0:ZT]032Z;@0_ZRP0=JdX02n]<@0OZT@07III02Al
K`0RM8L077b701V3N`0ITFh07:1I01n]A`0S[cL0:[0/032a8P0b/1l0=:dM03J/7@0a[B<0;jde02V_
CP0SZ5X08YQN022;I00QS6<09HYU02N7J00XPfX0:81W02IhJ`0ZLfl0;6]b0080;GU`02L0:XQ[02NG
I`0XX5`0<:ID03>YC00eZdH0=Z]103:/@@0_[D00;ja0032/?00]ZS`0;Z]5032XE00`Xf<0:ia[032P
J`0bYFL0;jUU03:UGP0bXE`0=Z1S03ZLJP0gUFd0=Hme02f;M`0_RGD0=Hae03Z@M00kTVl0=hiZ03j:
I@15Q680B8mQ04bSE@1FZ3T0IIlK07691`1fL`400P1hI`009`1eH@00KfT206Ma1`1MP1@0FX/R05:A
;`1?SRd0DXPW05Un6@1WK``0K68406mH0@1YD@00Id/0061<001PAP00Gd4005Y5001M@P00GT@005]1
001J?P00Ec/005Dk001B?000DcD005Li001H>P00ESd005<j001C=P00DCH0050f001C>@00DCT0054f
001C?000E3`005Hj000305@j000Q04df001><P00Bc4004`a001=;P00BRd004/`0018<000Ac0004H^
0015;`00ABh004D]0016;P00@R`004@Y000o:000>BL003LS000h8@00<1l002dK000/6@009AL0028C
000Q4P007Q4001dB000M4@007a4001d@000O4@007A4000807@l000<0710001dA000N4@000P0N4000
3`0L3`006Ph001P=000G300060`001D<000E2P004PX0010:000@2@003PL000X600070`001@000080
0004000000`0oooo000:0?ooocL0000000<00?l000000000o`00G`000000200100000P0000D10008
0`003P@0014;000D2`006@h00P0M3`005@0N500081<0020B000P4`0080l0024@000R4`009QH002HH
000X5000:QL002dK000Y5`00:1H002HC000X5`00;A`003<O000m:`00@S<004Dl000204Po000W04U;
0@17G@H0=g4<03606@0XSR/08YLk02JH=P0VV3D09iX^02bF7`0^TQP0<HdC03F>3P0cS`X0;i4>02jC
4P0WUAT099HW02:F>00MUTH07YQ001jI?P0OVS/08iXe02BL<00QWC408Ihe01fP?`0MXT007:4n01bQ
?@0NY4007:Q401fYC00JYeD06JEN01fVG@0MXf407YaY00807Y1_02L0981a01mTNP0RK6X09Xa@02:T
>P0XYc<0;JX_02j/:00e[B/0<Zlc01nYA00LU5X097Mb029[R00KNHH068Ih01NEJ`0KY5P07je402F`
=@0X/2d0;k0W036_8`0d[B40<ZdR02j^;P0Z[T809ZmJ02:UIP0TTfP08hA/02F3JP0WPfT0:85[02Mj
KP0WLFl09Fe^02U_K`0[Jg<00P0[OVh09`0]T6T0::5U02bVG00_ZEH0=:Y?03:/B00b[D40<Zdn036]
>00^ZcP0;j`l02j[@00^ZdX0;JQD02nUH@0`Y6H0=:IU03JWH@0hYed0=J5K03FLG00jUfH0?He_03R6
M@0hQGX0=8Mg03>;L`0jSV/0?Y9X046JJ@11VfL0B9EP04bHF01=Xe40EJI006>P8`1/U0/0LWh107=]
000207ET000L075Q001`I000JF/106=g3`1JP1/0FHHU05J38@1IOA`0IW8@06eU1@1/F@40Je0006E<
001TB@00HdH00652001I@000ET4005Q1001J?`00FT8005/o001H?@00F3h005Dn001D>@00FC/005/o
0080F3l000T0E3d0054f001A>000DcD0054h001F>000EC/005Pm001G?@000P1K?@006`1I?000DCT0
058h001==`00CSH004/a001<<000C3<004/d0019=@00BC8004Tc0019=000BS4004P^0015;@00@B/0
03lX000k9`00>B<003PR000d7@00<1T002/H000Y60009AH002<F0002028E000:024F000S5@008aH0
020F000P4`007a8001l@000M3`007A0001hB008071000100714001/A000J3`006Pd001/=000J3@00
60d001D<000C2P0040T000l9000<1`002@@000L1000400000P000`00000<0?ooo`002P3ooolf0000
0005003o00000000000000000000o`00GP0000003P0300001@0000L200091@004@D001H;000H3P00
7@l001hB000O4`0081D0024F000R50008A<00P0P4@003`0R5P009aH002LG000X5P00:QT002lK000]
6P00:QH002LD000Y6000;a`003LS000o;P00A3T004Q5000204Q9000W04UF0`12J@/0=7dH02j:9`0W
UCH099Y402RK>@0UW38099XZ02ZH7`0[UAX0<90E03:>400cS@d0<I4?02fB4`0YTQX099H/026I?@0M
Vdh079a:01bNBP0MWdL08Ii2026O?@0QWSd07im101jOC@0NX4`07Im501nPAP0QXdD08:I:01bVD`0J
YEP06ZIQ01VVH@0KWf<06i9[00807HA`02L097Ea02ELN@0XIfH0<8U:02RR>`0XYCd0;JPd02b];@0f
[Rl0<K4j01f[B`0ITUd07W9f025QR00HMh<05XUg01NLJ@0LYU807je102>_=`0X[bl0;:h^02n_:@0]
[RT0;Jh[02N]=`0V[Td09JiR02FUJ`0STFh09Ge^02IlK@0VOFh09Ga`02IcM00VJGH09FMd02IbKP0U
NV/00P0YRVH09`0_U680;Z5O02bVG@0^ZUT0<J]E036/D00a[DH0<Je003:[>@0cZS`0<JY103:[B@0`
ZU<0<:QH036UH00dYf00>ZMK03ZXE`0kYU@0=iiK03NEH@0kRVT0>gea03YiL`0kOWP0>hIb03^=K@13
Sf@0AIEP04RLI`1:W680CiMF04nOC`1HYT00HJ4Z06ZD501`P`H0LgL007=Y0002071Q000W071M001^
G@00IV@106A/2@1LMaD0GGTI05]f5`1SLa40K6P806mK0@1/F000Je8006Y=001VB000Hd<005ho001H
?000ESl005I0001I@P00FT8005e1001I?P00FD0005To001G?P00FD4005e1001K@P00ECh005<l001A
>000DSL0058h001B=`00EST005Di001L>`00FCd00080Ech001d0F3`005Dl001D>000DCT0058f001?
=`00CS@004lf001C=P00DSH0054d001>=000BcD004Xa0018;P00AB/0040X000n9@00>28003LQ000e
8000=Ad0030J000[6000:QP002PD000Y5@008aH002@H000202LH000402DI000S5P008QD001lD00<0
7Q8000<07Q@001`A000L4@000P0M4@00300L3`0070d001d>000K3P006Ph001H=000C30004PP00149
000>2@002`@000T100801P0000<00`00004000000000303oool000X0oooo4`0000060000oa`00000
0`00o`00100000000?l0003o0000o`1K00000009004000020000104000H2000:0`003`D001<8000I
30007@d00080818000D081@001hE000S5`009QH002DE0002028C000?02PE000X6000;1P002/K000_
7000<Qh003<Q000/7`00;A`002hI000a8000>bD0044_0017?@00B4H00080B50002L0AEh5041c4`0`
QR@0:I8`02JI@P0RWDT0:Idh02FJ:@0WV200;9LK02^E6@0_TaH0<Y8D02nA4@0^TQ00:Y@B02VD600T
V2H07i`h01bOB00MX4H07j5601nRA00TXD009Im002NOA00UWDX089YA02>LCP0XWdL0;:9302^V@P0V
Yd@08ZI;01bTEP0IXf<05j=V01JII@0HQfd00P0KMG009`0RJVl0:EIg03EVH`0mRT<0;j0g02RP@@0Z
Ycl0:jhg03N`=`0b[d407JYB01R?IP0KLG`07Uj701YgPP0HSW@06j9V022YD`0S[D009jhe02N_<P0Y
[S40::ha02VZ<P0YZ3T09JU702RYEP0ZZFL0:9m^02F:KP0UMFl08g9a029bL`0QLWL08fik02UWN`0Y
K7H0:7a[02N;IP0202VDGP0W02jEG@0ZWE/0:J=L02Z[F@0][5@0<:i>02j_A`0a[T00=:i003>[@@0c
ZdH0<ZUA03>VFP0cYUl0<Z5R03:SGP0hXeH0=j9B03ZLEP0jTF00>hIX03]kK00hLfh0>7=_03^0LP10
S6h0Ai=T04bGE`1@UeT0E9QL05>EE`1ETU40F9Y705jM<P1UUAX0LHL:07Il0P1dK`00LVD00080KV00
01D0L5d006eM001[H@00J6D406EZ2P1QK0/0I6L906YQ1`1]GP<0KED006eA001[D000Idh006A:001M
A@00FSl005Pl001H?P00Fch005a2001NA0000P1K@@00401I@P00FT4005M2001J@P00GD4005`o001J
>`00EC`005<j001A=`00D3@0054e001C>@00EC/005Tk001H>`0205Tk000S05Hj001A>000DCH005<e
001C=`00E3T0058f001@=`00DSX005<j001?=`00D3<0050a001=<000ABh004@^0011;000?bP003`T
000i9000=B0003DN000c7@00;A/002/J000Y5`00:1H002HH000W6@009aX002HL000Y6@009aT002@G
000R5P000P0Q5002028D00808A@001<08QD001lB000O4@007@h001d?000N3`007@l001/?000F3@00
4`/0018:000@2@003@L000T300080@001P0000<000010000000000`0oooo000:0?oooa<0000000<0
003o0000000000000P0000000`000?l000000000000Y0000000300400000000000000240000000<0
0@000000000000008@00000200400005008100030@000`40008100010000100000008@0200000`00
00@100080`003@@001H;000K30007Ph0024B000S5@008QD0024B000Q50009AL002DI000W5`008QH0
02<G000X5`00;AP002XH000/7@00<1h003<O000c8@00<Ql0030O000_8@00<R<003/Z000o=000ASl0
04Y<0@0204AH0@0E041[2@0kOQ/0:8lb02FG?00RW4L08j5:02ZO<P0WVR40:YDF02fD4`0^TQ<0<I0C
032A500^U1@0:iDC02^F5P0XV1P099/R022N;@0MXCP08Z4f00809:4e0100:Z0g02ZO?P0]WD40:I]6
02ZHB@0/Vd80;j0m03:T>P0aYSP0;JLi02BX@`0MYE006J1T01>MK@0ETfT05ge]0P0LJG009`0UHfl0
<5Qd03m[G@14RcX0<J0c02NOAP0/Yd@0::e303F]@00`ZTP06ZML01J?L@0ILX006f6;01YkP00JUVh0
8JUM02R]BP0Z[3P0;:l_02V`<P0Y[CH0:Zdl02ZUA00/V4l0:XmO032AJ00gTW80=HUc02ekL@0UJW40
86Ae01aRN00MIG/08Vmk02YaO@0[Og@0<8eS03:KFP0202fKE`0802nGE@0XWUL09jAF02VZE00[[4`0
<;5703>a@@0e[d0203B/@00M03BZBP0dZUH0<ZEP03:TH`0bXF@0=9mL03FJE`0gV5H0?I1M0424I`0l
N700>WAa03IeK@0eOVT0?h]Z04bHIP1CV5@0FIQ906:DB`1MSU<0F8M@05Z0CP1MRD00HY<V06Z?501c
P@T0MWD107A/001bGP000P1aF`002P1^FP00KUl006MP001[H@00If<106=N0@1ZF`40KUH106eE001[
D`0206Q=000E06A@001RA`00GT4005Tl001G>P00EC/005@l001H@000FT8005Y1001H?000Ed0005Y2
001K@`00FT8005a5001LA000G3l005Y0001G?@00E3T00080DCD000@0DcL005@h001F>`00F3X00P1H
>`00201A>`00DcT004lf001B=`00DS@005Dg001@=P00DCH00P1@>0006`1>=P00BSD004/`001<;`00
B2h004T/0017;000@b`0040X000l9`00>28003PQ000d7P00;a`002`I000V5P009Q@002HG000X6P00
9aT002PK000Y6`00:a/002LJ000T60008aD0028D0002028B00808A@001<08QD0028B000N4P007Pl0
01d?000O40007A0001/?000H3P0050`001<;000C2P003PL000/5000:0P00208000<0000100000000
00`0oooo000:0?oooa@000000P000?m@000000800@0000<00@400040000000008@0000000`010@00
0`4000D2000200H3000300D300040@000@000080000002800@00008000030P001@8000`4000B1`00
6@`001h?000R40008aD002<G000T5P009AD002DG000X5`00:1P002/F000Y5@009QH002`F000]7@00
;1d002lM000a7`00<1h0034Q000`7`00<Al0034S000h9`00>bh003lc0019@@00CE<30P14H`L09`0l
MQ<0<hP/02>DAP0UVTX08:1;022SB00XXC00:9/M02fE4@0bT`h0=I<>03>B400bU1<0<IHF02nH5`0Y
VQT08i`M02>M7`0RWb<08j4V02FO:@0VWR/0:J0_02^N=00ZWCd0:Y`n02jM?00]WCP0<Ihe03BR<P0a
Yc80;:La02RY=00PYd008:E?01^QH`0FWG406hm]01]dKP0202=QM00W02aRL`0cGgD0@WAI04N<=@0d
WS<09im802VTA`0XZ4X0=jY803:YD`0KY6P05I1k01QhQP0JIhT06h1i022KH@0T[Td0:k0n02n_<00a
[R`0:jlb02^^>`0[ZTH0;Y]B03=oH00kL6d0A6]c059XN@1:IWP0>V9e02YLMP0SFGP07eaj01iPO00Q
NGL09Hab02bKI00hY5H0>JQ>0080<jQA02L0<:=?02ZUB`0ZZTX0:je702n_@@0_/Cl0<[4o03Ba>`0d
[CX0=Za003B]BP0bZEH0<:MQ036VG`0dXEd0=9QG03R@E`0kRE/0@h5U049eL00jK7H0>GA_03V1J00m
T680C9]O05JPE@1LVdT0I9Q406^<C01OPdl0F7a>05]g@`1RQBl0JHhN07293`1gO`T0MG4007IX001d
H0000P1^F@004P1/F000JeX006aM001YG@00J5T0069E001VD000JDl006Y<001YB`00IdT006M8001T
B000GD<005Pn001H?`00ES/005Dj00<0EC`00180F3`005Dm001H?@00FSl005Y1001KA000GD<005a4
001K@@00Fcl005Tm001F>000DcP0054g001@>000DcT005Lm001G?00205Xn000W05Lo001G?@00ES/0
05@j001E>@00E3P0058j001@=`00CSP0050i001==`00CCH004`e001==@00B34004/_0017;@00@b`0
044[000m9`00>2D003DP000e7`00<Ql002dK000W60009aH002LH000Y6P00:a/002dL000]7@00:a`0
02PK000V6`009AT002DG000T5P008QD000808QH001<08Q@0024C000P4P008180020A000O4P007A80
01T?000I3@005`d001H;000C2@004PP000h6000=1@002`@000H300030000000000`0oooo000:0?oo
oaH0000000<0003o000000000000C`0000000`01000000000000000N000000800@0000@00P0000@1
00081@002@D00P0:200010081`001`<000<1000200020040000Q00@100040P001`@000l7000F3000
6`l001hA000R4@0091@002<G000R50008aL002LE000Z6000:AL002TH000[6@00;1`002/O000_7`00
<Ah0038K000_6P00;ad003@L000a8000=2@003XV000j:@00?c0004Dh001>AP40Ced90080@W8C02L0
>X8U02j>@P0OUEl07iYF01nQB`0MY4<08j8^02JM700]Ua<0<ID?03BE3@0cU140=ILF03:G700`VQd0
;9dP02BP900TWb<08j8S02:R9@0WXBL0::0Y02ZQ;`0/WS@0:I`o02RN?`0`WcL0<J0a03FQ:`0cXb/0
;jP`02fX=00UYc`08JM5022TE@0MXV806:1[026;JP0XJW400P0]F7P09`0_I7H0<6mg045nE@19SC80
>I/c02ZMA`0XYDL0;:M?03^YD@0fYUd07ZI`01NCO@0INX@076R901j1M00SWeT0:k12032`=`0d/S00
=:`]02n/=@0[[D40;:IA032?FP0eLVD0@65]04aOL@1JFW@0D5m_041TK00]IfX0:FYY02U/J00WLfT0
:XaT02^OH@0`ZUH0=ja@03J]C00202j/CP0W02b[B@0Z[D80;Je102j`?P0d/3`0<[8m03>`?`0c[cd0
=:`l03R/@00g[U00<ZmG02n/G@0`ZUL0<j1B03JCD00nQEL0AG]N04MdI`0nJ6h0>FEa03YnIP0nTUh0
C9eF05NPD01MVdP0H9A706N:B@1]P5<0GGMC05MeB@1JMcT0Hh8T06^:6@1`PP/0N7T607Q_001eJ@00
LF400080KET002L0K5@006YC001WE000JE@006I@001TD000IE0006IA001XC@00J4`006A8001VA`00
HdP00654001M?`00FS`005Xj001E=P00Dc/005Hk001G?000ES/005Lm001H?P00FCh005Y0001L@P00
Gd8005Y1001I@@00ESl005<l001B?@00DcT005<h001D>000FC/005U0001L@0000P1M@0009`1J@P00
FD4005/o001G?P00E3T0058k001B?000D3/0050h001>=`00CcH004hf001B=`00CcD004dd001:<`00
B300044_0010:`00?BD003PT000d8@00=Ql003DO000`7000;AX002TK000Z7000:Q/002hN000/7`00
;1`002/L000W6`009a`002PJ000W60009Q@002HE000202@E000502<F000S5@008a@0024D000Q4`00
0P0P4P00300M40006`l001T>000H30005PX001<9000?20003`L000d6000;10001P8000<000`0oooo
000:0?oooaL0000000<0003o000000000000CP0000000`01000000000000000M0000000600800002
0P000`8000H200091@0030P00`0=2`003@0=2P002@H000H300040@000P00004100050@0020@000h6
000C2`006Ph001h@000O4`000P0Q4`000`0S5@0091D002LF000202TH000C02TG000X6P00;1/002hM
000b8`00>2@003DU000c8000<al003<L000f7P00=b8003XU000m:@00@2h004Hf001:?P00EDh205=Y
3`0204:28`0W03J>?@0[TeH07iM]022MG00LXTX06ZDl026S;00VWQd0:YTF02fJ500^Va80<9dF03BM
700cWR40=9lV02nQ:00XXB`09J8Y02>S:00TXbL0::8Y02VR;@0[XRl0;:4b02^P?00^XC`0<Z8a03:Q
:P0eXbL0<jDZ02nX<P0/Z3/09jE502BOD`0SXE`07jAS01bSI@0YRfL0<fQ_0080>5]c02L0=Fab035l
LP13QTh0DHd^03^L=@0/X480:jA3032VD010YE<0>ZEO01fYLP0HUW`07GV0029QQ00TOFl0:9]G02j^
A`0c[ch0=Jhh03>Z=`0]Z400;:I<02^KEP0/ReX0;gUQ03EbI@0mLFP0A75W03miHP0fPE/0;hME02f<
C@0]TDT0;YM:03:QB`0eYdl0=JU=03JZC`0_ZE<00P0WZE<09`0XZTd0:j]602n/@00c/3`0=;4m03:a
@@0a/4H0;je703:]A`0d[dd0<:mK02^`H00[[V40;ZUE03BHC00iR4d0A7aE04agG@17MF@0@W1Q041i
FP16ReD0CYaD05ZLC`1OUdT0GH]906=nCP1XMU<0JW1H05iaD@1MMT80GW`e06:2801/Q140LWl;07Id
1@1fJP00Lf@0079L000206mF000W06aC001XD@00Ie8006=<001RB`00HD/006E=001XC`00JDl006U>
001WBP00IDT006I:001TA`00HD@005lo001K?P00Ecd005Ph001H>P00Dc/005Lm001D?P00FCh005Ll
001J@000GT<005i5001K@`00Ed8005=2001B?@00DSX005<j001G>000ECX005`l001M?`00G3h00080
FT4002L0Fd8005i1001L@000FCd005@k001C>`00DSP0054h001?>P00CcD004da001==000D3H0050e
001<=000C38004H]0015;000?bL003/V000k8`00=b0003HQ000d8000<Ql0034K000Z6`00:ad002dK
000Z6`00:al002XK000Z6P009ad002TL000X6`00:1P002HF000V5@000P0T5@001@0V5P009AH002DE
000T4`008Q<000807a8000`07A0001d>000I40005``001H;000C2`003`T000l7000>1`003@@000P3
00050P0<0?ooo`002P3ooolC000000030000o`00000000000080000000<0003o000000000000K000
0000200100000`4000H2000810002PH000h:000?30003`h00P0@4000100?3@0030T000X600060`02
00D0000Q00L2000=10005PT001/?000O50008a@0024C000S5@0091L002HH000Y6000:aT002PH000W
5P009aL002PI000]7@00;b0003HR000e:P00=BL003PU000e8000=B4003PR000h9P00>bT003l/0011
<P00BST005530@1IE`@0E7DJ0080?X`g02L0;YA>02BHGP0MVVd079mM01RRA`0IXcL07j8Y02BO7P0Y
VaL0:IhE02NP600[XA`0;j4P03BP9`0dXRd0<Z4^02fQ<P0[Xb/0:JHV02RU900/XbD0;J4Y02bQ:`0_
X2/0;Z8c036R=00bXB`0=J8U03>T9`0bYRd0:ZPj02RTA`0UWUD099UR026OI@0OY6D08jAQ02fAH@0g
Mf800P0jKF809`0kNV80>8AR04f;@01ISbP0?Idd02fT@00YY3l0;j5=04:MEP0jX6D08:Qe01^GM`0S
MW`0:eUn02ehJ`0aVEP0<ja:03>^AP0e[480<ZQ402jTC@0/UeH0;8aM02b8GP0ZPf40;HQO02j@G@0a
UeX0<Ia=02nPA00^Y3T0;:Ta02f[<00_[C<0=:`m03FUA@0dVT`0<IQ@02bGE@0202VJE@0W02bPDP0^
Yd/0<J]803:^@P0d/D80=K59036`D00/[UD0;JeL02b]H@0X[6/09[1X02FZIP0[XEP0=Xm@03b3D015
PUH0AHQL04>;F@11RU00B8e805:DBP1JV500G9I=05b:BP1JN4d0IFUA06QWE`1WIe@0H7=8069l?P1Q
Obl0Hh8K06Uo3@1_N0X0Lf`3079O001`F@00Ke800080JE4002L0JDd006Q@001UCP00HDX005m8001P
C000HDT006I:001WC@00Jd/006Y<001XCP00J4`006A8001Q@`00Fd4005M0001F?000FC/005Pk001G
?P00F3d005Xn001N?P00GD400617001PB000GTT005i5001K@P00FT8005Ln001D>P00ECL005Pg001H
>P00Fc/005dm001K?P000P1N@000301NA000HTD00692001M@P00Ed4005<l001B>`00DCP004hg001=
=P00C3@004he0080DCH00100D3<004`a0018;P00ARd003dV000o9P00>b<003TS000e8@00=240038N
000/6P00:Q`002TI000Z7000;1`00`0/7P001P0]7`00;Ad002XM000W6P009QL002HF008091L000<0
9AP002DG000U5`000P0U5@003P0R50008Q<001lB000L40006@l001H>000E2`0050/0018:000@2@00
3PP000d6000:10001`80303oool000X0oooo4`0000060000ofh0000000P00P0000D200091@002`L0
00l;000B3P00510001<C00805A<001<04Q80018?000>2@0030H000P4000;0`003`H001@9000K4000
81D002DG000T5P008AD002@F000V6P00:A`002`K000_7000:1L000809QH001809aP002`N000a8P00
=R@003DX000i9`00>bL003PV000h9`00?RT003l^0010;@00A3@004Lj0@1;@`80DU0405QS3@1=ORX2
03>=C`0W02NCH@0QV6L06Y]a01RQG00GXd<06j8a022P9`0UWad0:YdF02ZQ500WY1T0::@N02fR8P0a
XBH0<j<]032T<00/YC@0;ZHY02jS800`XA/0<J0L03:N7`0eWB<0=YlR03FN900gWbH0=ilT03FQ8`0b
XRT0;J4g02BPB00TWU@099]P02>GK00SWfT09jAU02fWG@0^WEP0<I5D0080=hY>02L0?Ha>04:;DP1J
S3<0G8lO03fP;@0aYCL0:ZDm03>LC@15UE/0?9]Y01fTM00OUGH0:GEi039GO00dNFT0=IYG03J/B`0f
ZdL0<ja503:YB00`Xdh0<9AD036<EP0`S5/0;X]L032GE`0_Xe00<:a803:/>@0a[2`0<:hQ02n_7`0Z
[bD0:k0a02bZ?P0bW4L0<8a<02j;C00/S4`00P0/TDd09P0_Vdd0<Z9;03>ZB@0d[TL0=[9803F_C`0`
[ET0;Z]Q02^XJP0XZg009jec02J[K`0WXf/0:YYM03:>EP0dRU80>I=D03VNE00nXTh0A9m1056I?@1K
U4D0H99=05f;B`1LOTd0HfQC06YLE`1UIE@0HfU<061i@01QP3<0Hh0S06=m4P1VM`/0K70506mT0P1]
E`00Je@00`1XC@009`1YCP00ITh006A?001UC@00Hd/00658001RA`00I4H006I:001WC000J4X006U<
001UBP00HTP00615001K@@00Ec`005Pl001H>@00ECX005Ho001J@000G4800615001PA`00HT/0065:
001QB@00HTT00656001M@P00F3/005Pj001G>000F3X005Ti001I?@00Fcd005`o000205i2000W0694
001SA`00HDT00654001M@@00FT0005Pn001D?P00DSX0058i001@=@00DcH0058f001@=000C3@004/b
001:;`00AB/0044Y000m:@00?B<003XT000e8`00<al0038M000_7000;Ad002lK000^6`00;Qh002hS
000a8@00;Ql0030O000_7P00;1d002/K000Y6@009aP000809QP000D09aL002HF000U5`009AD002DD
000202<E000<024D000L4`006A4001L>000G3@005`/001D;000A2P0040T000l6000<10001`<0303o
ool000X0ooooO`000002004000D0000000T00P00008100060`002`L000l;000B3`005A8001LE000J
5P000P0H5`009`0G5P005Q<0014>000B2@0040H0018:000H3`0061<001dG000R6P009AX002DH000V
5P009aP002PK000[6@00;AT002hL000X6@008aH002HC000V5P00;1X002hM000c8@00>2@003`W000o
:`00?RX003lZ000o<`00A3P004Di0015?P00Bd@1051D1P1CH`h0CWDO0424@P0202R7J00W02:>K@0N
VF`06Ii]01VSFP0JYD<07:<`02:R9`0TXR00:J4G02^R5`0YY1T09Z8N02VN8@0YVRT0:Il/02VS;`0T
YcH0;:@[02nP7`0cWQD0>Y`D03ZK5P0hVaL0?Y/D042L5@10VaT0>i/P03RL;00bVcL0:iE402J;F@0T
TF0099QS02:KJ00YXV<0<ZMM03BWE`0dY580<Z9>0080=ii802L0@IQ304V?@@1MRbH0F8`F042M8@0e
YBP0;Z<d03FJC018TEd0>iI[022QLP0SUW00;GYc03URM`0iOf80>9a@03R]A00f/400<Jm0032^@P0_
ZdD0<jM903NQB`0kW500?II@03NPB00hZT00=K0h03J_:@0g[al0=:lL036`7P0_/2D0;Jl`02fW>`0[
Vcl0;Xm2036<A00aRd<00P0dTTD09`0gW4@0>Z5603RWA`0hZT/0=jm>03F/E`0`Zeh0:jMW02NRK00U
YFh08jIc02JRK00XW6H0;9ML036BEP0cUDl0>:1;03ZYB012ZD<0Cilk05^@>`1OR4<0HGm905mcBP1W
I540LeQE07ICE`1ZIE00Hg=806B1=P1UQ2H0Ih<G06In3P1YN@D0KFl206mT001]EP00Ie0006I<0002
06Q>000I06UA001VCP00Ie@006U@001UDP00IDT006=6001QA000HdP006Q8001VB@00I4L006=3001R
@`00Gd<005a1001L?P00FSl005To001L?`00G4<005e4001QAP00H4L00697000206E;000<06E>001U
B`00IDT005i4001I?`00Fcd005Xo001F?`00FCl005/o001J@@00GT<00P1TAP00701TB@00I4d006==
001RBP00HDH005e6001J@P00Ed<005Hm001C>P00DSL0054f001C=P00D3D004ld001<<@00CRd004P]
0013;000@2X003lW000k9P00>B@003HQ000e7@00<Al0030P000a8@02030Q000902lO000_8P00;b<0
034R000a8000;b0002`L000Z6`00:AX00080:1X001<09aP002PJ000W6P009QX002LG000V50009A@0
028E000P4`00718001T@000I3@006@X001H;000B2P004@T000h6000;10001`<000`0oooo000:0?oo
ogl000000P01000500000009008000020@001P<000/7000?2`004Pl001DB000G5@006QH0008061L0
02L05aH001HC000A3P004PT00106000B2P0060l001PC000M5`008QX002DJ000U60009QH002LH000X
6`00:aT002dI000^7000:1T002<F000V4`009QH002`J000^7@00<b4003PT000l9`00?b/003hZ000o
:P00?c<004@h0015>@00ACh004]40@1@E0H0Df<>04ie7`10Q4800P0XQfP09`0RSVd07YU/01VNK@0I
XeX06ZE301bS<00RXRL09:8P02VQ5`0[XQL0:J@I02JR7P0YWR40:IXY02VO;00YXbl09:Lf02bT:`0_
X1l0<ihE03ZL500jVaH0>9/G03jK5010W1D0@9/I03^K800hW2`0<Y/g02^EA00VReT0995P02BHH`0R
VfP0:J9S03:WG@0dYeL0=:AB03:RCP0203NNB00W046H@`19Sd40GH/V05R<5P10WB40=JDX02jS=00e
VT`0B95M03^FJ`0PXG808iI`02ejL`0iHWL0>GmR03RLD00h[D@0=[10036_@00`[T80;j]503>WB@0g
XD/0>ia@03fFD00gX4P0>:Y003F`>00f[bT0=jlO03B_700a/1h0;k0U02f_<00]Yc/0:i/o02j?@P0a
S4@0<H]30080=99502L0=ia403ZQAP0hYdL0>:Y;03N_CP0e[5L0<:]N02^WI`0WXV`09JE^02>VL`0V
XV`0:9aV02bGG00aTUH0<iE?03RPB`0jZDP0@ZU304nO>`1KT3/0GhQ3065oB@1OLdX0IfAA07=HE@1f
DeL0JVE@06=cB01TPCH0IH@V06N35`1VOPh0JGT506e_0P1_I000KEH006M@001VC0000P1XCP006@1Y
D@00ITh006MD001YD000IE8006E9001SAP00HD@006=8001XB000ITT006A7001S@`00HT<005m3001L
@@00G3h005Xo001I?`00G3l005a3001MA000HDH00617001RA`000P1UB`00301UCP00ID/006E9001N
A000FCl005/m001J?`00ESl005To001K?`00FT4005i30080I4H001`0I4T006A=001SC@00HTX00656
001MAP00FT8005M3001F?@00DcX0058g001A=P00DcH0050e001?=000C34004h]0018;@00@b`0040Z
000o9`00>bH003TT000f8@00=Ad0034O000`8000<B400P0`8@002@0_7`00;b8002lS000a8P00<B00
02lP000/7000:Q/002TJ000202PJ000C02LH000X6P009aX002HJ000W5`009Q@002DD000R5@0081<0
01`B000I40006@d001T:000F2`004PX00149000>1P002`@000L3000<0?ooo`002P3ooomn00000080
0@0000<00@400040000000000P0000002@0200000P4000@200091@003PT0018>000F4`006QD001/H
000301`J000<01dH000J5@005Q8001@>000E2`006Pd001hD000P5P0091X002DL000V70009aP00P0Z
6@006@0X6P00:1P002TF000[60009aP002HF000U5@009aL002`J000/6@00<ad003HW000o:P00@Rd0
044b0014=000ACX004E10015AP00AD`104MH1@1;JA80AWXT0427=P0eRE@00P0SQW<09`0RSG807iYZ
01ZQJP0LY5/08:M602:W=P0TYB`08jHV02JV7`0VYQh0::DN02NQ8`0UVBT08hlb02BE<`0RWSD08J@i
02VR;00`WR40<I/H03bJ4`0nVa40?i/?042K3`0oVQ40?i`D03fL8P0fVSH0;Y=502R6D`0TMVD09XQP
02VJF`0YYUL0=JYB03bZD00kYU40>j5C03JOEP0203^QBP0W04>N@01?US40G8/H05F:2`13VA00?:0O
02jR;@0hW4X0BI9L03bHJP0TXfd09iaY02b8J`0dMfh0>HaF03ZSA00i[c/0=k4j036`?@0^/Sh0<k0m
03N_?`0n[440@ZQ604>UA00oZSX0?Zd_03b^:00j[R<0>:hO03F^7`0b[R@0<ZhZ02n_<00_[CH0<J@i
03FI?00gTcd0?8e10080?I9102L0>iU303bLAP0mWTl0>ImE03FUF`0cYEl0<:=T02ZNJ00VW6/08i][
02BOJ`0XWFH0:IeQ02bKDP0aVd/0>:5503jW@@14Yd00CYln05RE?01OQ400HWa406AaA`1UJD/0LF=A
08=LDP24GT`0L6U605ec>01RORP0JH8L06an3P1]NPd0K7D5075_0P1bIP00KU`006QC001VC`000P1Y
C0005P1XC`00Jdl006eA001[D000JTl006M<001VA`00HDH0069:001SA`00HDL00611001R@@00G480
05m0001K?`00G44005e3001L@000GD<00615001SA`02069800070699001TB000I4X006=:001UB@00
IT/006A9000205m3000605]2001L@@00Gd8005e2001NA000GdL00P1TB0009`1VA`00IDd006I@001U
B`00HD/00658001LA@00FT<005I2001F?000DCT005@i001B=@00D3D004hb001;<@00BBh004@/0011
:P00?bL003XX000k9P00>B8003PR000c7`00<R0003<S000b8`00<B8002lO000^7000;1h002hM000_
7P00;b00034O000`7`00;A`002dJ000202`H000C02XJ000/7000:a`002XJ000Y6000:1H002PE000R
5000818001l?000O400070l001T<000G300050/00189000>1`0030@000P3000<0?ooo`002P3ooomn
000000@00@000P0000002P0100000P4000D300061@002PL0010<000D3P0061@001/H000L6`0301hK
000?01dI000I5@006A0001L>000I3P006Ph0020D000Q5P0091L0028H000X5`00:A/002/J000/7000
;1/00080:aP001H0;1T002XM000Z7P00;A`002XK000]7P00;Qd003<Q000l:@00@S0004Hj0019>@00
C40004Q90@14CP40@e8304=K1@17I`d0@g/S03R8@00`SE<0:heS0P0TS7D09`0RT7007YU[01bOIP0O
YET09:Q<02B[@@0TZSD08JT]026Z9P0UZB80::PR02>O9`0QU3807X<l026=?00SV3`089m002VO<P0a
W2@0=IXI03fL5@10Wa80?ihB042N5P0oWAX0?ilO03fK9`0bUCh0;H]<02V2E`0SM6L09hQH02^OC00^
ZdD0>ZU703nYC@0lX5L0?9=M03Z@H@02046HD00W04bR?@1BX2H0EhlD05:82@1:T0X0@IHE03BQ9`0o
WdD0BIQJ03^LIP0YYVL0::9N02fHG00bSE`0>Ia803b[?00m/S@0>[4e03Na=P0e/cL0>k0b042b;`14
[c80B:de04Z/<015[RP0@ZdS042[900nZRL0?jXZ03^Z;`0kZc00=jla03Fa=@0e/CT0=jXm03^R@00o
V4D0?hi80080@Ha<02L0?X]@03^<E@0hRU/0=HeR03>CI`0dTfP0<Y9W02f@JP0WSf/099=X02>JI@0V
X6009ZAJ032UC00eYD80@:Dl04BQ@018Vcl0EI<o05j:?`1UOT@0J7M506QbAP1WK4P0K6]907UYA`1f
KT40J7Dg05ij:P1UOa`0K80?079m2`1fN0L0MG4207IZ0@1cH@00L5/006]C001ZC`000P1YBP004P1[
D@00KU0006U?001ZD000J4h006M;001UB000HDD00692001Q@000H4800692001M@`00GT4005]3001M
@@00HDD006=:0080ID`000h0J4/006U@0@1YCP40Idd006I=001XC000Idh006IC0@1WD`00Jdl006E>
001UC`00ID/005m50080HD8000<0Hd<00616001PAP000P1RB@009`1UBP00IU0006ID001SE`00He80
061;001NB000G4H005I1001E?P00Dc`005<j001D=`00Dc@0050e001<<P00BC0004@[0011:@00?2@0
03XS000h8P00=b8003DP000a7`00<200038Q000a8P00<1l002`M000/7000;Qd0030M000a7P00<Qd0
034O000b8P00<24002dN000202XK000C02`K000[7@00;1d002/K000Z6000:AL002LF000S50008Q80
024B000O4P007a4001`@000H3@005@`001@:000A20003@L000X4000<0?ooo`002P3ooomn00000003
008000010000000000<0000000/00@0000<100060`002@L000`9000@2`00510001LC000K5P006QP0
01/G000201`F000W01dG000K5`00718001XA000K3@007Q40020C000T5@0091T002<F000T5@009QT0
02PI000X6`00;1/002hK000`7@00;Qd0030N000b8@00<B<002hP000c8P00=2<003LU000o:P00Ac80
04dk001?A@00DT`104aG0`16GP@0@fL9041]400nMal0=h8k02^8H@0XRfd09I1_00808I=f02L08I9/
01jGI`0PWUl08j=E02NYC@0XZdD09JXl01n[=00NZbd09JXV02JY8P0SXRT089Dc01f1@P0TRd40:9Dm
02VL?`0^W300=I/Q03NJ5@0kW1H0>Z4I03RR7@0iXR@0=Z0^03RN;`0kVC<0=91202f=B`0YSE@098UQ
02bGCP0dYT40=je103bZB00lYUT0>9QT03Z6J@0jOf/00P15TE@09`1<X400D:8[056D6P1;R@l0D8L8
04^@3P0kXQl0@JDn04ZLE`0iW640:JIM02ZWC`0]YTL0<Z5303ZW?011/3H0@[@b03nb<P0o/SD0@;0b
04F_;018[RT0CJ`V052]8`1A[1h0C:`J04NZ7@15[B<0B://04V/=@16Zch0@j/l04:/?@10[T80?Za5
03fZB00mXdd0?IAE03b>E`0203^>G00W03V9H00iQF@0>X1Z03b2K`0kQ700?X9]03N2K@0_PF/0:HIY
02J>IP0WWF00:ZAG02jYD00fZT@0?JY004:T@018Vd00D99105f;@`1VPTH0KWU906icB`1/LdL0IW53
06Ic@01ZM3P0JgTb06Mo:@1UOR00JglB06em2@1hN0@0NG<207Q/0@1iI`00M6@0071N001^EP00Jdl0
0080JDh002L0Je4006a@001ZB`00HT/0065:001UA@00ITL006E3001P@`00GD4005e2001PA000Gd<0
06=0001O@@00HDP006Q<001[D`40JeL106]K0@1/GP80K5l406aQ101[G080KE`206iN0@1YG`40If43
06MO0P1YF@00J5L006IG0@1VD000HTP00655001OA@00H4@00656001TB0000P1TBP009`1SD@00IEP0
069M001SG`00IEX006ID001TC@00GTL005U6001I@`00E3d005Dk001D>P00DcX005<i001==P00CSD0
04Xc0011;000?BP003/T000f8P00=24003<N000c8000;b<003<S000f8`00<b00030P000a8000<Al0
038M000c8000=b<003DV000e9000<R80030Q000202dQ000C02dM000/6`00;Q/002dK000[6P00:AL0
02PG000V5`008a80024D000Q4P00810001h?000L40005``001D;000C2@004@L000h6000<0?ooo`00
2P3ooomm00000004008000020@000@40004000@0000000X00`8000L4000:1`0030T000l=000D3`00
61@001/D000K5`0071D00P0L5P0201/E000=01X@000K4@007a0001lD000T5`009aX002HK000V6@00
:1H002XI000[6P00;1h002hM000202hP000F02dQ000c8`00<2@0038S000d8@00=R4003XT000l:@00
?R`004Pf001@@`00D500059K0P1<I`P0@W4?03mg600iOb@0>HDd0328D`0RQg@098Yj026BL`806YUc
02L07YMY01nGH@0TW5L0::=?02VZC00V[4H09:dl01f/<`0NZc008j`X02JY900TYBL07j0_01bG=`0W
Vc@0;i``03>O;`0iWR<0?9`H03ZM400hX1P0<J@T03:T;@0aXcD0<J9003JO?P0iUSh0=Ha502n=C00Y
VE809IiL03:TB`0lYDH0?:I;03VSE@0hWfL0=i9/03^4I`0hOEl00P18S5009`1=VDD0CYhh04bI:01;
SAP0E8D:05681`12X1P0@Z@g04NLDP0fV5L0:ZM?032Z@00c[3T0=j/c03f]<013/C00@jl`04J^<`15
[3L0Aj`a04Z]:`19[2X0Cj`T05:Z6P1DZAD0DjXC056[601=[Ql0D:`Z04Z/=`1;ZdD0BZI504ZPB018
X4h0A:AC042SFP0mWF00?9AR03ZEI00203ZHIP0W03VBJ@0kRf/0?HA/04:5L016PG00@gm`03Z0L00a
Pf`0;8UX02NDH@0]XeX0<JU<03ZX@P0oZcl0@Za104^RAP1DUdh0GHi=06N8B01^OdL0N7=:07A`B@1Z
LD<0IFhk06A_=01TM2/0JWhT06f07@1_PQL0Kg/=07Eg101hM@00NV`007UW001fIP00Mf@007AN001`
E`00KU800080Jdl002L0JDl006A=001RA`00GT@0060o001S@@00IT@00694001N@`00FT400613001R
A`00Id<006A4001XA@00JDl006aI0`1/HPH0JFP906U/201WKPT0IW4>06E`3P1WL0d0Ifl;069/1`1Q
KP<0H7<7065a1@1TJ@80Hf@106AU0P1WFP40IE4006E>001TB@00IDX006I:001XC@000P1YE0006P1W
FP00IV0006=V001NIP00Hf<006QL001VEP00Hdl005e:001J@`00FD0005Do001E>@00E3/005<g001@
=P00CcH004Tb0016;`00?R/003/W000i9000=1l0038P000b8@00=R<00P0f9@000`0g8`00=B8003DS
000303HT000503PT000h9P00=bH003HU000c8`000P0`8P00100^7`00;Qh002lN000^6P0202dI000=
02XJ000V6@009AD002<C000S500081@001hA000K4@0060d001D;000C2@004PP000l7000<0?ooo`00
2P3ooomm00000003004000030@000P4000800@000`0000002P0300001P<000T6000>2P004@`001D>
000G4`006AD001`C000M5@0201dB000=01/B000J4`0061<001`@000P4P008aP002XK000/7000;Al0
02dN000]6P00;1l002dO000202/M0080;ad001H0;b00038Q000a7P00<1l003DO000h8P00>b@003lZ
0012<000C3/005M<001FG@40D6X804Ag4@0iPAh0=hH[03:;?@0`Rdd0:haT01j9OP0PRg`07Y5c0P0I
UVh09`0LVV407iiB02JRB00XYDX08jU>02:[A`0N[3d06Z`h01ZZ=00NZR`08jXT02BX9P0VYRL09j8Z
02nR:00eXB@0=J4R03ZN6@0jWQ@0=IlE03:R7`0[YBh09jDk02bT?`0]XT@0=:1403RI@00cSTL0;I=<
02ZQC@0VZUL0=ZM?03fPD00iUE`0>IES03NCK@0fSFX0>XEO03Z6E@0204N:C00W04Z?B`19UT<0AYPc
04ZA8P1CQ@T0Eh@4056J4@1;Xbl0A:1:03JKCP0^Yd80=:/i03f[<@0o[Bh0A:/^04R[=@18Z3<0BJ<g
04RR=@16Y3P0AJHe04>[<P14[B/0AZdR04Z]5`1<[1P0CZ`M04^^8P18[b`0AZdi04F/A@17YTT0B9Y?
04JFF010UF00?IIT03^DIP0lTVP0?9QY0080?9Y/02L0?iY^03nBJP0oRV`0A8Q/04J5L012Rg00>Xm`
02nBI`0[V5/0:Z1B036YC00jYD00?jDg04:U>017Y440Di]805bADP1TRUD0KHE@075iCP1eKdT0KG=4
06Mf>P1TMRh0IgLW06Uf6P1aMa<0MgX?07Yi301kLPH0NW0107Y[001fI`00M6<007IP001fG`00LE/0
06iH001]EP000P1/C`009`1XCP00Hdd00616001O@P00GD4005lo001M@@00GT0005hn001O?`00HT80
06A6001XB@00IdT106U@0P1YG@D0JFT806Qg4@1VNaH0IX0F06:25P1RQAX0H8<K05n36@1MPaL0GGl?
05am301MP@d0HWd;05mc101OLP80H6l506IX0P1[G`00JET006QD001ZDP00J58006aF000206YO0@0W
06ES0@1UIP40HV/0069Z001UK@00JVX106eR0@1VG@00HUD005i:001L@`00Ecd005Di001A>000CSP0
04lf001<<`00BS0004<`000m:`00>RT003PT000f8`00<R8003DT000g9000>BD003PU000g9@00=RL0
03LU000f9P00=bP003TX000k:000?2T003`X000j:P00=BT00080=R@000/0<R8003<O000`7`00;ah0
02lJ000]6P00:QT002HI000U5`0091@002@E0002020B000601`@000K3`0060d0018;000B2P003PT0
303oool000X0ooooO@0000001@0100000P4000<0000200000@0000800P0000/00@0000@000060`00
2PL000h:000A3@005@l001P?000I4@007Q<0020E000201hC000W01X@000H3`006`h001hA000P5@00
9QP002/L000^8000;Qh0030Q000a8@00<B00030O000X7P00:Ad002hM000a7P00<b<003<O000b7`00
=1l003@S000j9P00?B`0044b0019=@00Dd@005QH0`1?K0H0AgP>03^67`0bSRh0<hhn02n:CP0ZR5d0
9HY[01b;N`0NS7806HeZ00805HmW02L06IYI01jRB`0TYD@08jE8026[B00P[T007Jdh01R[>@0JZS@0
8:/Z02FZ900ZZ200<JLL03NU6@0lXaD0?Z4E03ZO5@0mXA@0>9hJ02nN8P0cY2L0;J<i02RU@P0^Ych0
<JLn03JU@00hXCd0<i]702fMB@0[Yd/09ZUB03NRD`0lU5X0=8IV03F5J00dQ6d0>8IQ03f2E011Q4/0
0P1:Q4h09`19Qe@0Bhe<04JD@016TBX0DHL=05^2101LU0/0EZ8W04JR@@0iX4<0=JPk03fZ=P13ZCD0
B:Pf04ZW>@19Yc/0Bihj04ZG?P1:Ud00AYa004FR?P12ZCX0@Zdc046_;@15[B<0@jhN04>_8P12[RH0
@:d/03j^<@0n[3/0@:Q303nQDP0kWED0>Y]L03VGGP0hTf40>I5S03ZBH`0203nAIP0W046BK014SF`0
@XY]04B:K013TFd0A9]Y042PH`0nY5D0=jA:03RTA@0mXc`0@:0b04BP;@15VcH0D9Dn05^?A@1WR4l0
Kh1A07mkDP1hMd`0K71606Ic?@1UNc40IgdX06Ui6P1[Ma00LG@907]a1@1lK`80NfX107IW001fIP00
M68007AL001`F@00KeP006]D001^EP00Je@00080K5D002L0IDh006=:001QA`00G4@005do001L?P00
Gch005/i001J?000Gcd005i2001UAP00Jd`006UC0P1VH0T0I6d?069j4`1RPAd0H8PS066;:@1PSRX0
Gi0V05b?8@1KSAh0GX/L05b75P1KRAH0Gh/G05f74@1MO@P0GWh605ml1`1TM@H0Ifd406US0P1]FP00
JeT006YI001[HP400P1SJ0809`1UJP80I6X2069Z0@1RK@00IG8206Ue0`1^LP40JFP006IK001SD000
H4L005U2001D>`00DCP0054f001:=@00B3@004H`0012;`00?2T003`U000k9000=240034Q000i8`00
=bD003/W000l9`00?BX003LY000g:000>2/003LZ000i:P00>bX003`/000j;000=bd003L/000203HW
000C03@T000c9@00<R8002lM000]6@00;1/002/J000X6@009QT002DD000T50008Q80020B000O4000
6`l001T>000E2`0050X0010:000<0?ooo`002P3ooolm000000800@00?`0000020080000?00810003
00000`8000<200030@00108000P3000<1`003`T001D<000E3P006@h001X?000K4@0071@000807A80
02L06A4001T=000M40007a@0028F000U6000:1d002dL000`7P00;a`002hR000a8000<24002hN000Y
7000<1`003@O000d8`00=b8003@N000f8000>2<003/[0012;`00AcX00510001FE080E6`804=j4P0n
QQ`0<i8`032F?`0aSdT0:GmK02AoI`0MQFl068]i01N;KP0ER6H00P0ERf409`0JUe807Z=902:VA00S
Z4408j`i02>/<`0Q[3@07:`m01j/=@0SZbL09j/N02nX6P0kYa<0@:8=04:Q3@14X0h0@Il?042P4P0l
XAT0<J<P036T:@0ZXcL09ZA202nW>P0dZ3L0=JTf03NW>`0_XTP0;:A902ZWA`0YYE00=i]C03Z>F@0d
Q680=H5V03MoIP0lQ5T0@h9>04F5C@0204moE00W04V0G@1:QE@0AI9<04>C=01;RQH0Eh@906F?2P1N
WR00Bj4m03jS@@0mZcX0@J`i04N[>P1:Zch0B:M004FP@`14UD@0AhU804B;B`11Td/0@Ia604:W@P0m
[Ch0@:hh04>_;@12[bH0?jlV03j^:@0l[R/0?:`Z03Z]<P0l[400>ZU@03bWDP0iXEH0>9YH03ZDF@0i
ReT0?XAN0080@7YS02L0@WaW04EfK`17Og80AHIa04>GK01:XF80D:EF04fOA`1:WSh0BYXj04VN=018
Wbd0AiT_04b=>@1FRT00IH=206anB01dMTd0OWA?079hB01UOCl0H7X_06Mn8P1[Oa/0LW`?07Ef201f
KP<0Nfd107UZ001kJ000MfL007EX001eHP00LET006mG001]DP00JU<006]C001/D0000P1[C`009`1Z
C000IdH00611001M@000F3/005Xl001I>P00FSd005Pn001L?`00HSl006M:0@1[E@<0J5`306MY2`1S
MA<0HWhJ06:5901QR2d0H8dc05f@<`1ISRL0FX`J05Z;501NRAD0FXHF05j8601OSQL0H8/B05b82`1I
R@`0FHP>06233`1TO0X0J6d706aS001^G000JUh006IW0@0206A]0P0=06E^0P1QJ`80IFP106E_0@1U
L`80IGP406Ug0P1ZLP40JFP006MJ001QC@00FTH005M0000205<j000H054g001;=@00BC8004D^0010
;000?BH003/S000g8@00<b8003<T000j9`00>bT003`/000o;@00?2l003h`000o<000?Rh003`^000l
;@00>R`003/]000j<000>bd00P0j:P004`0h:P00=BH003<S000_7@00;A`002/J000Z6P00:AT002HF
000V4`009Q8002<B000R4P00814001`?000J3@0060d001H<000C3000303oool000X0ooooL@000000
0`01000000000000000:00000003004000030@00104000801@8000`01`8000P100080`002P<00108
000A2P005@d001/@000K4`00718001dB000L600201dD000?01X@000L40007A0001lC000Q5@009AH0
02HK000U6P00:QT002XL000^6P00;ad002lQ000a8000<B800080<Ad001H0=R<003LP000k7`00>B00
03lT0015;@00BCD004e3001>CP40EF@604]g500mQRD0=Xh`02jH?P0`VdP0;HaF01abKP0KMG@06Wi^
01R7K00JT5X05iMD0P0IVU409`0MWTh07jA=02BWA00SYS`08j/_02V[:`0TZbh08Jda02B[:`0Z[200
;jXF03BX4@0mY@`0?j<804>R2@14X@/0A:4=04:S400nYQP0=:LO03>X9P0_Z340;:Lj032W=00bZS<0
<j`h032Y@00ZYU<09jE=02fUB00YXDh0=Y]?03VBE@0gSE`0>8YJ03V5FP10QeD0AXAB04Z4D`02055n
F00W04ajH@1?OEX0AhMI03n<B`16SR/0DXXH066A301NVQ/0Bi`h04:P@@13ZCh0@ji104J^@P16[440
A:Y104>PB012TdP0AH9?04:0DP0oRDl0?IE;03fSAP0m[TH0?[1003n_=`0n/2l0@:l/03b_;00m[bh0
>jd/03^[<00l[C`0?Ze;03bZC@0jYdl0>j9A03RLEP0hTeL0?XUE0080@GiL02L0@7AR049TK013MVP0
@ha[04NRHP1DXU/0FIe=05JDA`1FTC`0Eh`g05^E=01KTc<0FXdj05j1@P1UODP0JgY506YhB@1_MD`0
KgI;06V1@01QQS00HhHO06f05P1dOP`0NGT707ic0`1kK040Nf`007U^001kK@00N6l007Q[001fIP00
M600075H001^D000Ke<006eA001[C`000P1[C@009`1UB`00ITX005m3001I@@00EcP005dl001I?000
FCd005m1001NA@00HTT006=C1@1RG@X0IV<706EW2@1TL`h0Gg@>05in5@1NPb40GhLT06>8801KQ1P0
GH<A05n03`1NOPl0H7l>05n44@1PRA@0H8PA06::401JSQ<0E8lG05V?6@1JR1T0HWL=06U/0`1YIP00
IfL006I]000206Q_0@0L06I/0@1YJ@40IfH006A_0@1TM0<0HWT506El101WN080JFl006YR001UE@00
Gd`005Y1001E?@00DS`0054j001>=`00BS@004L_0012;000?RP003TY000h9@00>BL003XV000j:000
?R/003h^0080@S<000T0@c@0048e0014=@00?c<003ha000n;`00?C80040e000n=P000P0n<`004`0k
<000>2X003DU000c8000;Q`002hI000[6@00:1P002LI000W5@008a@0024D000P4P00814001`?000L
3@0060`001L:000D2`00303oool000X0ooooL0000002004000/0000001800P00008100040@001P80
00P200091@002P@000T4000=1@003PL001@;000I3P00710001hC000R500081D001lG000P6@0201lD
000W020C000M4@007Q40020E000P50008AD002<H000R5`00:1P002PI000Z6@00;1/0030Q000b9@00
=2L003<P000c7000=28003HQ000i8`00?RT004@`0019=P00CT@1051C0`1?H0L0CW4A04B49@0bSSh0
;i=802fHC`0_UUH0;8aR01ilM00OP7007HMT01Z@FP0JVDh07Im>00807J=D02L08Z5A02FRC@0YXT00
:j<c02bW9P0ZZR@09ZdV02:[9`0T[2<0:j/K036Z4@0fY@d0>:D<03RT2`0mX`d0?jH?03bV4P0jYaD0
=:XL02Z/8@0/[2@0:Z`Z02VZ<@0_Zc<0<:`h032]@@0[Z4d09:9N02NSE@0_YDT0;jA:03RPC00jVe80
=YMI03VFE@0iTeH0?i1H04J8F`1:QE/00P1COE`09`1;MV40DGMO04]gH`14OEl0AhM904n;;P1JU1@0
G9dI04bM<`16XCd0AJTn04J^@`18[T@0Aja604>VA@0oWdl0?iE;0466C@13P5<0?8=F03V?E@0hWE<0
>:]>03V_B@0j/4<0?Jdk03b^=00l[S40>Zde03f/;P0l[C40?Zhh046^A010[4P0?ZU>03nWD00kWeH0
?9]H03^GEP0203^;F00W03eiGP0mIF@0@X1P04>IG@1=WUP0F9UA05ZEC`1FTdT0Ei8o05V@>@1NRCX0
Ggm206AeB@1[KTl0K6]>06UXC01UKD`0HgA6061i@01RQ2l0IXXN06Z55`1bN@`0MWD107Yb001jJP00
OFT007a/001jK@00NFh007U]001iJ@00MVH007=P001`F@00K5L006eF001_E`00KE800080IE0002L0
Hdd006A;001OA`00H4@005e3001N?P00H3l00693001PA`00HT/006IC001VG@H0IFL;06MW1`1WJ`@0
Hfd606=a1`1NM`l0GWlG05n4601OQ1D0GX@C05f34@1MPA00GGlA05al3P1JP100EXHD05V65P1LSAL0
E98I04jC7P1@UB@0EI0T05b06P1TM`L0IG4106Mb001XK`000P1/L0009`1/KP00KF/006Y]001TL040
HW<3069h1P1SOPH0HG/406Ec0@1WJP00HE/0061>001KA@00Ecl005<l001?=P00CCD004Lc0017<000
A2`003lY000l9`00>BL003/[000n;000?Rh0048b0012<`00A3D004Lh0016>`00B3`004Dl0011>@00
@3P003lf0010=@00@3L003hh000203hj000C03dh000m=@00>2l003DR000b7P00;A`002dK000Z6@00
:1T002LG000U5P008A<001lB000M4@0070l001`=000J30005P`001<:000<0?ooo`002P3oooml0000
000C004000020@001@8000H200091@0030D000h8000?2@004@P00188000E2P006@h001hC000P5`00
8aP0028K000T6`007aT0024E0002028F000W024F000O50008A<002<C000R50008QH002<G000Q5`00
91P002DH000X6@00:a`0030O000f9000=BD003<P000c7P00<R8003`S0011:`00A38004Xm0@1?B@80
DU`404mY3018MAH0@H0S03B<?P0XT5P09i5L02JAH00XSV809hQW01j0N@0OQV/07XeO01^DDP0PW4P0
7Z5:00807:EA02L08jEA02BTB`0YY3h0;J4c02^X:P0YZRT09JhW022/8`0S[B00:j`H02nZ4P0`Ya40
<ZPB032Z4`0dYaD0=jPF03:[6P0_[Al0:jhX02F^;P0X[RT09jdX02R^:@0`[Rl0<:dm02b^B@0WZUP0
8:=X02FUF@0`YdL0<:U403^UB010XTl0>:5F03VSD`0gXET0@YIO04Z=I01?Qf400P1DOeX09`1AMUh0
F6iS059[J019K6`0CWQM04f6@`1AV240E:0I04fR8@1=YBX0D:X`05>Z>01?Zc/0C:Ho04JSA@13VU80
?iIA03n:DP10QED0>XIM03V;H@0gUF80>:IK03^]D`0k[4X0?Je203b_>00m[c80@:h`042];P10[Rd0
@Zh_04:_>013/3`0@Zm8042XC@10XEH0@YeL042JG@0203jAHP0W03f3I@0jP680@i9J04ZNEP1HT4l0
Fhi;05R<CP1FTdL0EiTl05NE@01HQ4P0GGI>06IYE@1_IUP0IFUD069]C`1RMdL0Ggho06:0<01ZQ1l0
KH<B07El3@1hL`D0Nf`007U[001hJ000MVP007EZ001eJ@00N6T007IV001dHP00MEh0075O001_F@00
LEH0071G001`EP00Ke@00080JE<002L0Idh006I>001WC`00IT`006E:001QB@00ITT006=<001XCP00
JE<006MI0@1TH0<0IFD506QY1@1VK0D0IFl7069d2@1MNPd0GH0A05^54P1KR1<0FhXE05f85@1IQ1L0
F8DH05:35@1BQQH0DhHI05>;6P1ETb00EILR04nI:P1@US/0EXdn05j59`1ROa40IGd506Qm0P1ZN000
0P1YMP009`1/L`00Jg@106Uc101XL`@0IgH406Mg1@1QN0H0H7d506Aj0`1WKP40IV40069B001OA000
ESl005Hk001@>000CS8004Pd0016=000Ac00040^000k:`00>b`003`]0013;P00@S0004@d0016=`00
AcT004U1001;@`00BDL004E60011@@00@Cl003lk0010>P00?c/003hm000203do0@0>040o0010>`00
?S@003X[000g8`00<R00030L000Z70009aX002HG000T5@0081<001hB000K400201/>000301/;000I
2`005@/000`0oooo000:0?ooogX000000P0100004`020@001@4000P200091`003`L00189000E3000
5`h001D>000H3@006a4001lD000Q5`008Q/002@N000X8@0091`002<J000R6P000P0R5@009`0S5@00
8AH002@B000S5@008a@002DE000U60009aL002DE000U5P009aL002/J000`7P00=b8003DU000a8000
=R8003TV000l:`00@S4004Ti001BC040DUd604a]3@14Nad0?X<`03F7@`0]SED098mV02>>JP0ORW80
8HM_02>9J@0PRFP098mG026DC00LVTT07ii:01fPC`0201^SE@0W026SDP0RYT`09jE102RT>@0WZ3<0
9:Xb02B];P0M[2@08:dQ02J]6P0XZQD09jTG02RY7@0VZb@0:jTQ02f[800Y[bD0::lZ02:^;`0O[C@0
9:h[02J]9P0Z[2D0<J`^036]?P0[[e<09:YN022TK00TYUd0<Z]803B]@00mYd00?:=<03VVE`0iZEL0
>JMU04BMH@1;SF40DHIO0080EgYJ02L0EFiN05]XI01GHFh0D6A^059YHP1>O580CYLa052V8P1?Ya`0
DZLL05RX801EYR`0DZD`05>S=`1<Wd00AII>03nFE@0oSEH0?H]J03V8G@0hS5h0=YIR03RTG@0h[5@0
?:a:03j^@00o[cD0@Zl/04F_:P14[RP0@Jh]03j^;P0o[C<0@jlh046^A@11ZdL0@J=>04>KF010T6H0
0P0lSF`09`0jSfH0?IYN04ROEP1AVD`0FHU=05f>A@1KTTD0FII105VL@01DUDL0EXE>05YeD`1TJUT0
JfMI06A]E`1OLE00H7e506:6=`1SR2D0Kh8E07Ml2@1kM`@0O70107i[001iJP00N6D007QV001fHP00
M6L007=V001cGP00L5d0071H001aFP00LeT007EJ001dE`00M5H006aC000206a?000W06U?001YD000
IU4006Q?001UD000J58006UA001VDP00JeH006YP0@1YIP40IVH106Q/0@1XL0D0IW<:069i3@1TOA80
GWl@05^13P1JQ@h0G8TC05Z;5@1MRQH0Eh`I05B<6P1DRQT0DH/L04f<8@1BSb<0EiLY04fK;P1>Ud<0
Dh]A05ioE01NNT<0GhLQ066>401TS0L0JH@40080IWh202L0Ig`306N01`1ZP`X0Ih8906B02@1SO0P0
HW/705in1`1RO`H0IGL406EY0@1UF`00GT/005M4001E?000DS/004Xg0018=`00BCD004Pb0014<@00
?C0003`^000l;`00@30004@e0016>P00Ac`004M2001:B@00C4l004QE0013E040@Dh004190012A000
@TH104150`10B0@00P10B0H04`10B@80@4D0040k0010<P00>RT003DQ000`7@00;AX002TK000W5`00
9QH002@B000R4@007A0001/>000L3`006Ph001T=000G3000303oool000X0oooo;`0000000`010000
00000000000800000003004000000000000003`0000000T00P0000<100040@001`<000X5000=1P00
3`P0010;000E3@000P0I4@002`0I4`006aD001XE000N5P007aX002<J000V7P009B0002LO000R7@00
8QX000807aH002L08AH0024E000S5P009A<002HD000X5@00:AT002TE000Z50009aH002XH000^7000
<b4003DQ000h9@00=R8003LT000l:`00@C8004Hh0@1<A@80EUT704i[4P12NQh0>h@d03:5C00^Oed0
9HAV01j5M00PPg@07h1j0261L`0RRFP08Y=L02BHB`0PW4H07:5801bRB@0OXDP00P0MXTP09`0QY4H0
8ZI402JV@00VZ3h09:/j026/>00P[C<07Jh]022]9@0U[1h08Z/K02>[8@0SZb/08:`e026[<00R[Bh0
8Jdc022]=@0O[CT08:lj02R];00YZb80;j/N036^:@0^[Sl0:K1A02>]G00OZF/0::]J03J`AP0j/400
?j]003fUC00hY5H0>jQJ03fYHP17WU/0CHiL0562F00205agE`0W05i[G01PHV40GEUW05YIJP1JGf40
Dg5F04bC?`1:Ybd0CZXO05FY601HYQX0EjDT05>O9P1CVBh0CiTh04>BD00mUE80?I5G03f?F00jRUT0
>X]L03NDG@0jX5X0>JYB03R[B00mZd40?j`h04F]:`1<[RH0BJdW04>^;`11[Rl0?Zde046]?00oZd80
@J/n03jWB`0mVeH0?XIR0080?XaS02L0?YYM04JSF01AW4h0DY=<05:9D01HTTD0Ei]005RN?01GW3h0
EIE605F6C01HN5@0HFmF06A^E@1NME40G7M=05j3@@1SS300KH/P07N1401mM`80OG4007i^001oK@00
N6T007QW001iI@00NF4007=O001aH@00KEd006eI001/E`00KE/0079I001dF@00LeL0075F001/DP00
0P1ZCP009`1WC@00IT/006Q;001XC`00IU4006QB001WF@00K5T106eQ0P1ZJ080IV/206I/0P1VLP<0
HWP8069k3@1NP`l0HXPB05j84@1JQQ80F8T@05Z;401JRQ40FXdD05N?6P1ATAd0DI4L052C8P1>UB/0
CIP`04bJ=P1=VT00CHmB05MkG@1SLE/0Gge;05VA;P1JV1d0H9PG062C3@02066<1P0E06>9201TS0d0
IHhE06>=501SSA<0GhLB05n43P1NRPd0GXP:05j11`1UL`<0I640069?001K@`00ESd0054j001@>P00
C3L004/g001:=P00AS<00080@3000100@38004Dg0015?@00AT0004E70@15C`40B5H104ML0@12HP80
?f0203iL0@0oE`40?U@3041C1P10E@X0?5H?0P0jF0h04`0kE@H0?4h204150010=`00>bh003HS000a
7`00:a/002XI000Z60009aH002DD000U4@00810001d>000K40006Pd001P=000G2`00303oool000X0
ooooCP0000000`01000000000000000W0000000=004000030@001P8000T6000<1P003PP000h9000B
2P004`/001H<000H3P00718001hD000201`C000801dF000R6@0091X002HJ000X7`00:R<002TR000X
7@0202HG000W01lE000P5P0091@002@E000V4`009aH002TI000Z6@00:aL002dI000_6`00<Ad003HS
000h9000=bL003PX000n9`00@Rh004/i0@1@AP@0EED:05I[5@18NRH0>8<h03:6C`0WPfD0:gY^02El
K`0RO7H08Gae01]jO@0NQ7D08i1X026LFP0TWdL07Z5001RV@@0IYT<06jA300807:E002L07ZE1026W
@@0QYd008JTo026[?P0M[CT07;0i01^`=P0O[R`08:`U01j/8`0M[2d07:dk01f]BP0MZd807JU101bX
@@0OZch07jdm022^>@0ZZbX0;Z`J03>]5P0b[BH0;:li02BaBP0S[U@07ZeQ02b/D`0n[d<0@:hm03jU
@00kX4h0>J5F03jUF00oZ5d0AieB04f<D01FOE@00P1SL5L09`1VI5d0I5aR069EIP1OEFX0GemS05Uc
F@1@SdP0Bj8i04fY9P1CZQ`0GjHG05^Q701DV2<0D8l/04^C=01:SdP0@iE>03jCF011TUP0?HiJ03j;
F`0nTE/0@9UH03fTDP0kZT`0?:Q8042[@@11[SH0AJha04F];014[C<0@:dh046/>`12ZT<0@JI604:Y
@@11YTh0?YYE03j9G00204BDDP0W04ZRC`1BXT/0E9U805:@B@1CQTX0F9E005RQ>`1HXCP0Eilj05:B
@01DPTP0FgQC05i`E@1QLEH0G7=@05YhC01OQ3`0J8`W07:2601nM`X0OVd1085/001mKP00NVd007]]
001kJ000NV<007QS001dHP00Leh007=K001cF@00L5P006mE001cE`00MEP0075H001]E000Jdl00080
Jdd002L0IT`006A=001XD@00Jdd006aA001]E000LEh406iV2@1XKPX0IW<9069c2P1RM@X0HGT=0660
4`1PQAD0GhTB05f<501JSQ<0FHXB05R84@1HQPd0G8P<05V73@1DRa80DXlH04jD701;VRH0CYX^04bL
>P1;VdD0CHiB04ioGP1DKF@0GFmL05R3A`1GVS80DJ@X05FV901GWaX00P1JUa409`1LUPh0GILE05nF
6@1QUaX0HIHN05jA7P1NTAP0Fi0G05V=401JP`/0HG/606IZ1P1VF`<0HDl205U40@1F?@00CcX004hl
001?>`00C3P004Xh0015=`00A3H004Ll0016@000AdH0049<0@0nEP80?Ud3041T1@0oJPL0=fd903EZ
2@0eIPD0=f<603QO1`0fH0X0=68@03=V5P02035Q400C035L1`0dEP80>d/003i0000m<`00>2T0034Q
000^7000;1T002/I000Y60009QD002DB000R4@00810001`?000L300060d001H;000<0?ooo`002P3o
oomg0000000>008000040@0020@000/5000?200040X0014:000A2`004`X001@<000F3@006A0001/B
000N5@0201lC0008024D000T60009QX002LK000X8000:b<002dS000Z800202@I000W01lB000R4P00
9Q8002DD000V5000:AP002TJ000/6@00;Qd002hR000b8P00<b8003LQ000h9@00>b<003`W0011<000
BSL005E70P1GF@/0D6hK04Uk;`0mNTP0;WIM02MmJP0MOGL097Qd025dN@0QKW`086ml01ibO@0PPg40
8YIT01jSF00PYDT07:I301NYA00HZ4<06JM200806ZI102L07JM201bY@@0MZD007JTn01^[?@0K[ST0
6[0g01j`=P0N[Bd07jd[01^];P0J[CP06Ze401Z^E00JZU006ZQC01VUE@0LZ4T07Za1026`?@0[[BT0
;ZdK036_6@0a[RD0:K0f02Fa@P0T/4`08:mI03B^B`17[Sh0@ZXm03jRA00mSe<0>IAG03bND`0lX5H0
B9a:04Z?C01CP5000P1SLED09`1[I5/0JU]J06M=I@1QEFH0GVAS05QfFP1CR4l0CYQ304fW<`1DZb@0
H:HI05fQ5`1HVB80DY4^05>?<`1AR4<0B9=904>JE012VEL0@I1F04:;F@11Re/0@Y1J03nIFP0lWe<0
>ZA<03bZA`10[Cl0@Zhl03f^>00k[C`0>Je003fZ@P0oYd@0@jM504JXA`16Y540@iYD04::E00204ZI
B00P05:S@01BXT80E9a605:IA01EUD40G9db05bP<`1IX300E9l_05>G=@1FQdD0F7]@05i_E`1PK5P0
G7UA05amB@1VQRl0LX4I07Uc2`1lK@@0NfD007UY001lIP00N6T007Y/001nJ`00NFX007aX001hHP00
Mf0007AK001aFP02079C0005079B001`D`00KED006e?001WC@000P1ZB`009`1XD000Je8006]E001[
E@00K5L0075O0P1bK``0JGPE06Al5P1QOaH0HH0G06:26@1NPQT0GXTM066<7@1OSAT0G90F05RA5`1G
SAD0F8dD05R<4`1HRa00F8X?05R=4`1AT1L0CIPQ04NN:P18WS80BYa304bDDP1?PU`0EgUN05U_IP1G
NEH0E91005>P=01=Zc40D:/^05:U9P0205FP6`0W05FN5`1LWa/0H9hN06:M8@1SVbD0GYXQ05^E701E
Tad0EHdG05J74`1KP1@0H7TC06E]3`1QH@/0G58405E50@1@@000CSd004do001<?@00C3/004Xo0018
@P00BdL104]=0@19E`<0AV07041Z3@0mL@d0?7HB03Uk6P0bNah0<gTO03Ea600fKQH0>FPF03UU5`0h
IaT0<VLL0080;fLD00P0;f4<03=J1P0fC@40>D8003Xe000i:`00<b<002dQ0080;AX000T0:AP002LE
000V5@008Q<001l@000M3P006Pd001P<000F3000303oool000X0ooooM00000020040000I00@00006
0P0020@000/4000>2@004PX001@<000G30005Pd001H<000I3000610001l?000N5@0081L002<I000T
6@009AX002HK000W6P00:1/002PO000Z7P00;28002/M0002028F000301lB000P4@008aD000808a@0
02809Q<002XG000Z6`00;b4003@V000f8`00=200030R000e8`00>2@003l[0018<`00E4<005]D1@1D
KAL0@Gla03R0B@0_LFH09fQh025bO@0IMX<08GMl021fNP0UMGH09ge_02B8K@0SUF<08:5N01fVF00O
Yd`07ZI601VXA`0HZ4P05jE90P0JZ4X09`0IZTT06Ji301V]@00LZS`07ZXj01j/=@0O[C808Z`^026/
;@0O[C007:hi01f^?`0K[TX06ZeG01Z[EP0JZEX06:MN01^WBP0N[T408K4o02R_;00]/280;k0O02j`
:00X/CP08k1002BbA00S[dT0=Ji004N/>010ZC/0@9a603f5F00hRE/0>IAB03VKE@15X4H0@ia504f>
C@0205elE00W06A]E`1UI5X0JEUQ05mQH01MKEh0EWYG05F6D01@TDP0DJ0h05B[:@1OYQ/0G:<F05VN
7`1GV2/0FI8_05N5@01?TT40Aj1=04:RD012Ve@0@8eE04F6FP17Pe`0AhQH04N=F011Ve80?Z=<046[
A00n[T<0>Jm803R^C00f[580?:M>03nQB`14XTP0Aj5:04FME017T5<0AX=E0080CYE202L0D:@l052T
AP1@XDT0DZ95052U=`1HXbh0GZ8/05bQ9P1KWRD0EiT^05Z@@01MP4h0H75G061_F01OO4h0GXE107>4
8@1nM``0NVL107MS001eH@00MF8007=P001hH000NVH007aW001kJ@00NfX007]V001gH`00ME`007=K
001cF000KU<006m@001^D000Je0006U?001XCP000P1[B`009`1/CP00K5D106eL0P1`H@@0MfP907Mc
4@1`OQ`0Ih@R0669901PSB<0FH`O05Z=8@1JRR40G8/M05^;701GSAP0FXhF05R?601KSAT0FXdJ05>>
701BSah0DhlM05:A6@1EU1`0DYPT04bO;P15XCL0@i]<04V:G`1FLfD0G71T061hH`1JSU40EJ0j052W
<`1=[3@0CJdc04nY:P0205:Y7`0W05>V7@1GYQd0F:HR05^U8@1LWb40FI`O05JJ7P1?VR80E9DM052B
8@1ESR<0EXTS05V68@1JN1T0F6D?05=C201CC@L0DdX705=:1P1@B0D0CTX504m=1@1>D`H0C5`604MV
1`12K@h0@GTH03N3900fQB@0=8TZ032;<@0^R3L0;h@j031n<`0bMbl0>G4^03M[:P0eJRX0<F/V0080
;fXM00X0;VXF02mN2@0dD080=d@003Tf000h;000<R<002lN000]6P00:QT00P0Y6@001`0X5`009AD0
024D000M4P006Ph001P<000G3000303oool000X0ooooC@0000000`01000000000000000R0000000M
0040000200000`4000L200090`002`D000`6000@20004`/001H=000H4@006Q0001d@000K4@007A@0
024C000S5P008aL0024H000S6@009QP002HJ000W6`009aT002PI000W6@00:Ad002XN000V70000P0R
5`009`0R4@008Q<002<C000V4`009QH002LE000X6000:aX0034R000d9000>2D003DR000_7`00=B@0
03/Z0016<@00E3l105YD0`1GJ0l0B7/X03:2B`0YNV@0:6Qj02MPQ00OJhD07G:502=lNP0QPGT09XAb
02^=J00YUfH099eL01jSF00JYU<08:I?02BTBP0OYTd06ZA?01VPEP0201^UE@0W01VZD@0J[4@06Zdn
01f]?00QZSX09:Xc02RY;@0/ZRH0:Z`X02F];00S[c@08J`f01n/?`0O[DX07Zi>01f/D@0JZeH07je8
02:]@P0S/D40:[4b02b`:`0_/BP0<;8_02^b?@0W/d@09k8n02Ba@00i[SD0BJ/b04:X?@0mUdd0>geJ
03Z1G00iReX0=IEG03nQA011YD00AIQ<0080DHAB02L0F7MI05i^F@1TI5`0FfEN05QaF@1GNeH0DhM<
052<@`1?VST0DjD[05^X7P1LZ1L0FjLQ05NP;01KTc00F8<k05:=@019Wd<0AjE604BQB`0oTe80B8QF
055kF@1?OEX0Ch9K04Z?F013VE00@Z=903bXBP0i[4l0=ji@03V_C@0o[4@0@JXl046Y@018ZDH0BJM6
04bN@@1=U4000P1?VcT05P1@XcL0Cj@k05NT>`1HYCL0F:H_05VS901MXb40Gj8L05ZO801KVRT0GIDk
05Z4CP1LM5L0G7=B0621?@1XRRX0O7hF081^101mIP00MfD007=Q001cG`0207AL000?07YR001lHP00
MV@007UW001jI000NEl007=L001bE`00L5D006aD001XC@00Id/006]>001YC`00JTh10080KU0402L0
LeD807YL3P22Ia@0R70H08Mk7`1lQ2T0N8<`06n5<`1VTBh0HYL/062G9`1OU2L0H8`R05n37@1KPAX0
F8<F05b55@1JQaD0FHTE05V:5`1GSAT0DHlN056@7P1?Tad0CiLQ04fM;018XSP0AIi604J@G@1:PfX0
DgE/05iaI@1PPUP0FYe405>W<`1?Xc@0BjXc04f^<`1=[RT00P1>[1l09`1CZQl0E:XR05NZ9@1HZ2<0
Fj8S05NR8P1DXR<0D:8S052N8P1?UbD0CI@U04bC8`1<T2T0E88[05Qa9`1JI240G5lN05QI7@1GFaT0
D5dE04mT501<JQ<0BG4A049h4`0iOaT0<HLR02f?;`0ZU3d0:i<m02ZD?@0WTSl0:Xi002N7@00XPCd0
:GTh031c=@0`LRh0<G4Y02m^8`0202a[6`0C02aX5@0]H0T0<E8203I5000j>000=Bh003@V000`7`00
;a/002`J000Z6P00:QT002LG000S5@008Q8001h@000M3@006``001P<000<0?ooo`002P3ooomb0000
000M008000040@001`<000/5000<1`003PL001<8000D2`005Ph001T@000K4@0071@0024D000P5`00
9aH002HH000T6@008QL002<I000R600091T002HJ000W600091L002@F000R60009QP002LM000X6@00
0P0S5P009`0T5@009AD002DF000W6`00:AX002XN000Z6P00;Al003<Q000g9P00>bD003DQ000e8000
>RP0040`001??P00FU@505I[3P1<NR@0>GY402i_I00/J780:Un202MRQ@0PLHL07Gb40223M@0MRW00
8i=X02JLH`0UX6408J9H01jREP0LXe808:A:02FUA`0RY4P07Z=>01^OEP0201fTE00W01nYBP0O[Cl0
8Zhf02F[=@0YZc@0;JD]03:W9`0bZb40;JlR02^_900V[RL0::dZ02V]<00T[S/08ji2026^BP0N[e40
8je802R`@`0Y/D80:jlj02f^>00a/S80<[0d02ba?P0Z/D40:K4g02Za<00kZbd0AZL`042T@P0mU580
@7]L03anG`0lRF00=I9O03nPAP11YSd0@i]80080BhU?02L0CWmG05IeEP1OJUP0EVaG059eEP1BPDl0
D8M9056;A01BUcL0DZ0_05^X8P1OZa`0GjPQ05^P;P1KTbl0Eh@k056:?01<TT00AIU5046LB`0oUe@0
AXYH05IlF01EO5T0FG]K0526G@13SED0?9M>03RRD@0fZe40=:i>03R^A00o[S`0?j`d046[=`16[3X0
Bj/f052Z;P1>ZBX00P1>Ybd0901@Z2/0D:P_05FU:`1MXbP0H:4O05nO6@1RXAP0HZ0G05fM9@1PVbP0
GiPj05Z=B01FO5@0FgY306:6:@1aQQH0O7T:081]0@1nJ@00NfH007MV001fIP00MUh007EK001dG000
MF00079P001eH@00Mf0007IO001eGP00LU`0071I001[E000Ie<006Q=0080JU4002X0JeH406]L4@1[
G140LFLI081^9P29M3@0RW/j08Qg@`24MTh0PgY807R3?P1aSS/0KI<l06NA>P1STS80HXPW05j3901J
QB<0FHLR05Z=8@1KSb80FXdV05B@901FUB80DiDV056E9P1?VB@0CIl]04VT@015XTP0A91J04efKP1>
N7@0CgQ`05EhI@1EU4d0Dj<f04^N;@1;W300AjDd04N_=019/2T204b]8P0W056[8P1CZb@0E:dV05F]
9P1FYbH0Dj<Z04nT:P1>YRL0D:<T052M7P1>Ua`0BiTR04fD<`1BQch0F7Q005I[AP1?IT@0BfA204MW
>013KS40AGTa04Ul;@12PRd0=h<^02^3=00WRS`09i9302NEB00WU4D0:9E002JE@00TTT009Hlh02F8
<P0WPRh0;WTZ031g900bMAl0;g0J0080;6hF01<0;6TB031S2@0_FP@0=d`103]0000h=000=bX003DT
000b8000;ah002/L000X6`009aH002DD000S4`007Q0001`?000L3P006Pl000`0oooo000:0?ooog80
000001d00`0000L2000:1@003@P000l:000@30005`d001T@000I4@006a<001lC000M4`0081@002HG
000U5`0091/002HG000P5`0081H002<E000S600091P002@I000T600091X002<G000V6000:1L002TG
000202TH000W02PG000W6@00:Q/002TL000]7P00;Qd002dL000a8000>2D003d[0010:`00?bX003d/
0012<P00BCd005E90@1KJ0h0BGdT03]n@`0cKEl0<e]d03=HO`0dEXP0;fJ202AkN@0RRg408I9V01^I
I00MWF<08:9S022RH00QX5D08ImD026OD00SXDL09J=202:S@00OYDD07J9800807JI502L07JXo02>[
=@0V[2l0:ZT^02jY;00bYbL0=:TP03:^7@0/[R00:ZhR02N^9`0Y[2P0:Jd_02J]?`0S[TH09:m>02:_
EP0U[Dd0::m;02b`A`0`[d00<Zll03:a>00b[cL0;;0k02jb>@0a/2l0=jd]03nX<014Y3P0>im@03f?
F`13M6<0A7YV0426IP0iU6D0@j5:04>X?`16X4D00P1?U4/09`1<RE<0Ch1E05=cEP1?M5L0CGYB04f2
BP1?RTH0DHm0056H=@1CW380G:DX062/8P1QZah0G:<S05VF9P1DSS<0DH`h04^9?P16S4@0@IA=03jB
EP14ReL0CWmL0522FP1IQEX0D8YH04B=E@0lTU40=9aB036WD@0a[U00=je603Z]?00j[CL0?J/c046]
<`18[2`0CZ`X04f]:00204j]:`0W05B/9@1HZR80H:DO06JM701XVAX0IidI06VP5`1XW1P0I9/Q06BJ
9`1OVSD0F9160565C@1EQ3L0I8`K07F72@20N@80P6h007][001jJP00NFT007]V001iH`00M5d007AK
001cF`00LUX007EM001eG`00N60007US001iHP00MUh1079M0P1^F@@0MU/507AJ0`1^EP80LF<;0080
Lg4H02L0NGT[08Ub>P2<LdP0QgY;08EkC022O4`0QHI107j;>P1hR480LX1:06Z2A`1RS400FhXa05Z>
:@1HTRT0E9HZ05NI;@1GUc00EY<g05:H=`1CWS40Dil^04fO:@1;Xb`0BZPf04N[AP14WUH0@8IR04iY
KP1DJfl0EGAb05>0HP1?VDT0Bi@g04RA<019Uc80@jHb04R`;`1;/Bd00P1:[bX09`1=[bL0Ck0U04n_
:01@[2L0D:PT04ZV;01<YRl0BjH]056U9`1FXR00D9hN052J:019VSH0BiE004f7A`1:PE40AGiD045f
E012L4d0@Vm804eaB`1CME00B7]D03]jDP0^MU40;7m?0326D00dRTl0<HY;02Z>A00XTTL0:9U602NG
A00WTCL0;8T`0322:@0bNbH0<7HW031d9`0202eb9@0C02ee700]L1<0<6L903QH0`0kB000>S`003X`
000f9`00<b8002lO000^7000:QX002HE000U5@008a<0028B000O4P007A0001`A000<0?ooo`002P3o
oomR00000003004000000000000000`0000000l00P0000@100080`002`L0014;000D3@005Ph001T=
000K400081<001hE000O4`0081<0028E000R6@000P0V6P003@0Q5P008A<0028D000R5`008aL0028J
000T60009A/002HJ000U5@009AH002PI000V70000P0Z6P009`0]6`00:1`002/L000[7@00;ad002hL
000a6`00=R8003/U0010:`00?bd0048b0015;`00C3L105A60P1LF`T0F7<S03al@P0cLUd0<Ei`03I@
O`0iEX80?5f303AaM00WQVH08IIR026MGP0MX5l07Z9L02>PF`0UWUH09Ye?02BKCP0QVTd08Ye702:Q
@`0QXch08:Dn01nU?@0201^X>P0W01nY<`0RZB`09jT[02^X;00`Z2`0<jXW03>[8P0d[A`0;[0N02Z^
800[[R@0:jd[02N^>@0R[E008JYE026ZG@0QZ6808jaM02J_F00W/U80<;5703:`@00c/3d0<Zhh02j^
>00a[c<0>Z`^03bZ=012Y3T0@I]803JCH00iPf/0A6U_04AcI`10PV@0>I5U04:QB`12Yd00AZE10080
BYa602L0BII@04ZBE01>RDl0BXY<04Z7C01<SDH0Chm304nA@01CUcL0EY/d05^T<01N[B/0H:/O05nW
701NX1/0F9L[05:A;`1;SSD0AHdo03jBA@0mT500A8eB04N0F@1>QEP0EXIG056;E@18Re@0?i1F03RJ
E00cY5D0=:UB03J]BP0i[Ch0>J`c03f[;@12[B`0Aj`W056]901D[R800P1F[2D09`1KZR80HJLM06JM
6`1/V1l0K9DR06fL701/WaX0KYhL06VN8@1UW2L0GYPf05ND@`1BSTT0F8la06RA5`1jRP@0QGl008Ac
0020K@00OFl007i[001nJP00O6L007UR001eG000LeP0071H001dE`00ME`007]L0@1nH@80OfD5085X
301kJ140QF/D09QW7P2CIQ40S6X707]c3P0208Ij7@0W08ee>02>L400Rg1:08=mC01kPDP0OXE308F=
?024RT00PXE:07=kE01/PT`0Hhi405fE<@1NVRL0FITQ05VF7P1KU280Ei8W05RA:`1GU2l0EI`]04nP
;01>XbX0BjH^04^[@01;[dP0B:EF042BG`14PfL0DGMW05AjIP1KQET0CI=504R0@015PS/0BI8f04JU
<@14/2X0Ak8/0080B[8]02L0B;8Z04Nb:@1<[bX0CZXV04bU8`17Z2/0B:Pf04ZV=`1<Z3<0CjL/04nP
:P1;W2l0B:0b04RL>`18UdH0AYI@04J@FP10P5`0A7MJ04maFP1LK5d0HfmO05YfH`1;O5d0?GmG03f1
E014PE40BgmB03moCP0_PDL09ha902JGB`0XV4X0:9I002VA=@0/Rc00:h@/02Uo;00YORh00P0[O2d0
4`0XORL0:GTK02Y_3P0eH@H0>dl103do000l<P00=RP003DS000_7`00;A/002TI000X6@009aP002DF
000U5@008Q8001hA000L4000303oool000X0ooooHP0000000`010000000000000009000000800@00
00/00P4000@200090P003`@0018:000F3P006Q0001XB000I4@007Q80024C0002024E00808QH000`0
8aX002LK000X6`00:1T002DF000T5`0091P002HI000T5`0091/002LJ000V6`0202PH000[02PL000[
7000;Ad002dM000_7@00;a/002lJ000[7000;A/002XK000b7@00=b<0040/0014;P00AS8004Df0019
>000F4H405iF3P1KJB80CG=103Y/GP0aIfd0;5]d031HOP0_IGl0;G>002R2K@0QTV<07YaO01jSG@0N
XUd08Z1F02^ID`0bUTl0;YI=02JHC00VV4d09Y]902JQA@0RY4008:@l026U=`0202:[<00W02F[;00/
ZRH0<JTW03FX9`0gZRH0>:XT03FZ800cZa`0;ZhM036^800a[2@0;J`b02N[A`0LZ6<07JIZ01jRKP0L
X7807ZQV026]G@0T/ED0<[1903J^@P0f[d00=j`k036W>00dZ3<0?ZHf042R@@16V4H0@91F03:6KP0f
LW@0?Eef049_J@0kOVD0=HiT03ZNC`0lZ440@ZY00080BZA402L0BZ5904ZRB@1<WDT0BIa904^HB01;
V4H0CYM504nG?P1DW3P0Di`c05VU<01NZC00HZXV06>Y701RYQP0G9hM04nF8`1;T2`0@i4f03jB?@0n
STH0@H]<04>1D@19QU80DhID04n6EP16QEL0?hUE03VAF00cWEH0<ZIE03F/CP0i[D<0?jdf04B^:P10
[2/0B:hT05F^7@1KZQd00P1KZ1l09`1SYQT0Ij8G06VM601XV1X0JYHM06fN6`1]Wa`0LIhN06RM8P1S
VbX0Fi8g05JD?@1CUD00FIL[06jD5@1mS`@0Ph<108Ik0P27L`40PW4008=]001nJ`00NfT007UR001g
GP00M5T0079G001dFP00N5/007eT101kJ`/0O74A07id7@1mNS@0T7Ln0:]ZAP2UJ2H0YFlB07ib6002
099d700W09ih:`2AOC/0Qg]00862@P21QCh0QhLi08b5@`2:PDl0Q7IG07=[G@1WMEH0H8Q:05bB>01K
Ubh0GIPU05ZG8`1NUR80G94S05^C9@1GURH0EY`Y056P:`1=Y2h0CZTb052]@01?/DL0C:eB04BOG011
UVD0B8MU0527G`1FV580CiI004Il@014PT00AiA004FX=P13/2T0Ak8Y0080B;<[02L0A;<[04Bd;`1;
/S00CjPY052T9P19Yb`0B:Hj04JP?P18W3l0B:<d04ZT<@1<Wbl0B:0^04JL=@19UD<0CiY>05NDF01;
QUh0DH5O069oF`1VOUD0HX9E05F9E`13SeH0>99G03^AE`15ReH0BX9C03f0D@0_P4`09XM>02J;D00V
RU409hU:02B:A@0TRD008hHe02F5<P0WQ2h00P0YPRT04`0XP2<0:gTJ02i^3`0eHPL0?5@203i2000k
=@00>BX003HV000c8000<1d002`K000Y6@009aT002LG000T5P008A4001h@000L4000303oool000X0
ooooKP0000008@010000104000H3000:10003`D0014:000G3@006a0001hD000K4`007a80020D000P
5P008QD002<G000S5P009AP002HK000[7000:1`002LJ000V60008aL002DE000T60009AL002@H000T
6P009QX002LH000X5`00:1/002dN000202dM000W02lM000^7`00;ad002lN000^8000;B0003HT000k
:P00@c0004Db0016=P00Cc/005=70@1NF@d0FVLV04Y[B00oJel0=VA_035RM@0XGG`0:6Ak02EgL`0Q
Rf/07iAS01ZJIP0KWVH07:=R02:PG@0WVe<0<Y1@03N>CP0bTdl0:iQ>02RGBP0XW4D09Z5102BS?P0U
Y3`0::Da0080:ZPV02L0<JTR03VV8P0lZ2<0?:/T03f/8P0j[280=ZXR03JY700eZa`0=:`R036^:P0[
ZSX09:U?01^TJ@0KXV/079m/01bMK@0PYV009JaF02NbD@0e/4H0?:i403Z^A00jYcd0=YY003fJ?@12
Vd40@9U>04J>D@0mQET0;GI/035WL@0dFG<0>VaY03UjIP0bR6P0<iaD03NZB00mZd000P17Z4@09`17
YdH0CJQ604^WA019YTH0Aj9804NRA`1>WDH0CIe005>M=`1FW3@0FZ<a05^T<@1OZ2X0IZ/Q06FW6`1P
XQP0FITK04fC9012Tbh0?i4j03n=A015S4`0AX5D04N3D`1>OE@0BW]H04InF`11Q5X0>hiJ03NFEP0f
X5<0>:Y>03b]@@12/C80AK0V04N]9@1;Zb00Fj`I06BV600206FS700W06VM6@1YVQP0J9LF06^E6@1]
UAX0JiXI06bN6`1/X1d0Ij4T06>L:`1MU3H0FiPf05VM=`1TWB@0MYT@07nB1P22S@D0QHT808N12@28
O@P0QgP9089`201oK0<0P6H307aX0`1nI@<0NV@607]W2P1oK@l0OGLD081j6@20NbH0Q7Lh08UhB@2C
MD`0WW1>09Ih?@2ANRl0M7``0080O8/Z02L0P9Pb07NF>@1cTCP0NXdk07n8=P21OcD0OgU907aeFP1c
JEl0IEUR05aRFP1KJe80G7i605j6?01KScD0FIT_05fK;`1KVB`0FYXX05RM9@1HWRH0Dil[04fR;`1;
YcD0D:i0052_?P1<[D/0AZ=E04BHG`1:SV40C9IM04jSC`1<VD40BH9004R5@017U4@0AZ/h04:b:P11
/bP00P13/bh09`15]2l0B[Hf04bd<`1C[2T0D:X/04bW=@18Xd00@iM404:<A@17Vc`0BZ@i04^R<`17
Vc00B9Hf04jC@@1HUTX0GiEE05BAEP1?TE@0DYQ@05:EC@1?STX0Ai5?03nEE@0kU680>I5Z046:J@13
OfL0>giQ03EnH00[Nf40:GES02IcH00TL6009WII02=kCP0RP4@08hA002N7=P0202V3;P0<02^09`0/
NQh0;VlC035T2`0eEP@0>DP003/i000h<000=RP003DQ000`7`00:a`00P0X5P001@0W50009A@001lC
000N4@007@l000`0oooo000:0?ooofd0000002800@0000@10008100030D000d6000A20005@/001X@
000N5P0081D0028B000P4`007QD0024G000U600091P002DG000S6P009a/002XL000[6P00:1L002LH
000V5P009AH002@F000V60009aP002HH000W6000:A/002XG000[7000<1/00P0_70009`0]7P00;ad0
038P000g8P00=RD003TX000k;000?bl004Dg0019>P00DSh005Y=0P1LG0H0G6`Q04i^AP0nJ6L0=FQd
035SN00_I7@09VUa025aJ`0MQFD069IO01ZMG00IWV<07IiS01nNG@0VVUD0:i=?03B:DP0eREH0<I5D
02RGD00YV4T0:Yi002RS?P0SYST09:Lg02VV:P0202fW8@0W03NV7`11YB00?ZTT03bZ9`0gZR@0<jPT
03:X900dZB00=:TR02n[<00X[4009JU:022RFP0KVf`06iaW01fOH`0KX6009JM@02b[B00_[4T0?Ja5
04:/B@10ZdP0@jE103jGA012UD@0AY9804:<E@13QED0>W]H02U_J00`JVh0<f=a03I`J`0`Mf`0;gm]
03>EGP0bYe80?:]70080AZY302L0AjU004b[@01<Zch0AJM104VWA@1;YDD0C:1104^Q>P1BWSL0Di`e
05JQ<`1GYS<0G:Lc06:Z;P1OZBT0GJ@N05ZP6@1BVQ`0BITR04BF<@11UD@0@YE=04J:EP14QeD0AgaG
04IiF@16O5d0AHEL03n?F`0gUeP0>J1B03VXB00n[Cd0@jh`04V]9@1<ZR40DjXM066Y6`1YYad00P1[
XQh09`1/Wa/0JI/K06ZG601XV1P0JiPI06JJ6P1UWal0IZ4S06:S:@1NXRh0Gilc066N;P1QXRT0L:4M
07fM3P1nW0/0PIL;082I3`23U100Pi0D08F76@22PQP0PWPB08Ie4@24MA<0QG@D08ac6P2<N1l0SX0U
0923<@2>OSH0T7<n09YaA@2SKd`0U7A=08YgC01oQdL0MY5007:@>`02076E<`0W06RH=@1TUST0HiXm
06FEAP1VRdT0JWU:06aYEP1UK5d0GVMM05QUG@1GKUL0FGU>05j4A01LQcd0GY8b05bI;P1LVBH0GIXX
05fK:@1IWB@0FI/P05NH7`1@VbT0Cj4c04fV?01>Zd00BjY804FTC`1:V5L0C9=O04bMF`1;XDl0AY]1
04R;@@19R4<0BI=304B/=`14]2/0@[<V0080@KDZ02L0A[D`04^d=01?]2d0Dj/V04j[;P1:Y3X0A9a5
046CB`0oSDl0@i]604JTA@15XT00B9hg04ZI=`18WC/0AIi804bMF@1<V5H0BIAG04VKD`16VE80?heC
03n:F@17RfL0BhUc04F5M`10PgH0?Wed039nKP0`Of`0:W]X02UbHP0ZKF00;6]M02a]G00XM5D09ga<
02N3@P0XQC`00P0WPRl04`0YP2H0;7`Q02mb5P0^IPd0<EP403M9000j>P00>Bl003HX000b8000;ad0
02XI000X5@00:1L002LE000T50008A<0020A000M3`00303oool000X0ooooA`0000000`0100000000
0000000Q000000800@000240100000T2000;100040D00149000F2@006Ph001dC000Q5@008aL002HE
000S5P008AL002DG000X6P00:AX002TH000T6@009a`002TJ000[6`009QX002LG000T600091H002@D
000S4P0091H002XF000Y6@00:AP002XI000]6`000`0^7@009`0/7`00;al003TP000h9`00>RX003/[
0010;P00@C4004Lh001?@@00FU4305mU2`1FM1l0CGM004=_H`0jJW@0;Vaf02aZM00ZLVl08gU/01eo
H00HSUD06I]A01^QD`0LXET07iiK02JJE@0aU4/0<Hi:02n9E00^RU/0:Y5I02NHD@0XVDL09idm02FQ
>P0TYC@09:T_02RW9@0202bV7`0W03FV7@0hZB00=ZTX03>X;P0cYb`0<JHZ03:T;00`YRX0;JDb02RX
@00TZE008ZMH01nOGP0NUfD08IaM026RDP0UYd`0;ZU403FX@`0fY4X0@j=<04>TDP11Y580@Ye;03nC
C@14ST`0C8MA04]mG`15NE/0=g5N02a[JP0_KVd0;f]a035`K@0aL6`0;g5a03:;I00fVU`0>JI?0080
?ZM502L0@ZY004bY>`1>ZCT0BjLi04nW>@1AYCL0DJ8i04nR=01AWc<0DYXd05>O<@1BYc80EJTg05JZ
?01CYcL0E:@a052R9P1FX1X0EI`H04jJ9P18WCP0@Ii703jHE`0oU5/0@X=K045lF`17P5`0B8IK042@
G@0kUU/0>YmC03VXA`0k[C/0@Zd_04^[:01>ZR@0FJ/Q06:Y8`1WYb400P1XXah09`1WXQ`0Ij4N06bN
6@1[WAP0IY`I05nO7`1NXRH0G:0Z05fP=01HY3L0FjHh05nV;`1SZBP0LJXJ07nX4021YPd0P:@?08:T
5P1nXad0OZ0R07nK:@1nUBd0O8dZ07J4:P1fPR`0NGhb07mj>@29O3d0TWU009MlA`2LNdL0VG9209Ii
@02DOD80R7m2085o@P20Rd00PiDh08>H>P0207NH>00W06RG>01VUS`0JiI607F9C`1`O5L0Kg1J07IS
G@1bIV40L6aN06UbG@1XNUP0I85?0626A@1MS3l0Ghl`05ZC:P1OU2@0HIHU05fF:P1OUbD0GYDP05bD
7P1CUR@0Cida052Q>P1>YT@0C:U=04BRC`15VED0AiYI04VRDP1<YdT0Bj1004RF@018U400BI`n04R_
=@18]2`0A[@X0080A;HY02L0AkLa04Zd>`1:/c80Bjl_04V_?017Y440@YM=03jEEP0kUU/0>iaD03^K
C@0oWT@0@ie204>I@@0oV400?YA903j?E@11REL0AhIJ04^7FP19QU/0@7QR03adL@14Mgl0B7F204=a
P00mLgl0=GMl02ajM00YPFd0:HMS02N6E`0ZPe00;X5=02inC`0ZOe809X=>02N4@P0UPcP00P0WOR/0
4`0UN1h0:W@I02e_4@0_I@T0<EH403I6000g>000>S0003PV000c8000;1h002TJ000W5`009aT002HH
000U5P0081<001l@000M3`00303oool000X0oooo<@0000000`0100000@400040000C000000030041
0001000000000200000000h00@40008100080@002@@000h4000@20004`T001H<000J4@007A00024E
000U5`009aX002LI00809AL001D0:A/002TQ000Z7@00:ad002PJ000Y6P00:a`002`M000Y7000:Q/0
02PI000U5P009A4002@C000U50009aL002XK000Z6@00:Q/002/L000^6P000P0_7@009`0`6`00<Qh0
03LT000g:@00?B/0044^0013=000BCP004e1001ECP40G6D:05Mi8@13PDH0>geV03UgN@0hLWT0:gEe
02MiK@0RPVH07HUS01^>E00GUD/079]:01nPBP0SX5409Ya?02fEBP0hSdD0=8e:02f=E@0YSF00:9=K
02NGDP0YVdP0:Ihn02^O>00ZXc009jP/02bX9@0203BX8P0W03:X8P0dYbL0<JP^03:Z=@0eYbl0=ZL]
03FT<P0`YcL0;ZM502VWE@0TYf@09JAU02JKH`0VTF00;9ME02jQC@0`YTL0=jI303VRA@0kWdh0AIm<
04NNDP11VeP0@i9B046:EP19QU<0DH5G04acI012LV<0=fmU02][JP0_L6`0<Fi/03A_J@0aJVd0<FQf
03QmJ00jQfH0>YIH0080?j5?02L0@JU604VV>P1>Yc<0D:Ld05>Z<@1GZBl0EZT`05:Y;P1CYRd0D:<a
052T;01=YRl0D:Te052[>P1>Z3/0CJPm04jU<`1EXad0FilC05JK601>X2H0AZ@k03ZVC`0iX5H0?8iI
04:3F@1=Q5X0ChIM04F;H00mU5/0>ieE03^ZB00o[Sl0@Zdf04j/<@1G[2P0GZ/V06F/9P1TZ2D00P1S
Yb009`1VYQd0JJPO06NW6`1SYaH0HZ<H05nU8@1GYRP0FZD^05RR=`1HYC`0FZHl062Y<P1U/2T0LjlL
07^_401m[0d0P:/B07bZ701j[R@0NZl]07V^=01eYc`0L9/o06j=@`1[QDH0LH9707^2BP23PTL0RX=8
08Z6BP26RT80Oh5307b0A01kPCl0OH0j07b0>`21SCL0Qi/`08JM<P0207NF=@0W06^?<P1YS3T0LHU5
07YhE01hIE`0OemM08UJH`2?F600UEeP099SG`2>Ie`0PFQF075]C01RM4@0HH<m05^><`1OU2T0GiPV
05fE9P1NU280Gi@O05nB701LUB00F9/]05>P=P1CXT00Dj9904^LC`16VeH0A9aA04fQCP1@Yd`0C:=3
04bL@01=VcL0C:He04ja<`19]300Ak@/0080B;L_02L0B[Lg04Re@P1:/Sh0B[4m04F_@014YT<0?ie;
03bJE`0iV600>Y=N03N<F`0jUEP0?9UK03bDE`0mRU80?H5B03ajE@0mNEH0?GMM03mlI`11Lfl0@Eeh
049DO`17FH40C5]l04EKMP0mGWH0<fQg02m]L00ZNF/09XMP02V>DP0[S4X0;H]602b;BP0XSE409Xe?
02F;@`0TQ3h00P0VNS404`0VM240:G8I02i[400`G`P0=54203E0000g=P00>Bd003PX000c9000;ad0
02`K000Z6P00:AL002HG000U5@0081<0020A000M4@00303oool000X0oooo;`0000001@0100000000
004000010@000@0001<0000000<00@000000000000007P0000009`0100000P4000D1000:0P0030<0
00l6000@200050X001T;000O3`0081<002@F000U5P00:QX002TJ000Z6`00:QT002TK000Z7P00:R00
02`N000Z8000:Q`002hN000]8000<20002dM000Z7@009aX002PE000U4@009A0002@E000V5000;AP0
02`G000Z6P00:A/002hJ0002030P000W03DN000g8@00>BH003XX000n;@00AC4004`l001E@@00Fe83
05YS2@1HMad0Bh0m03YkHP0fNG@0=7ek03MkK@0/PF@08hMS01b>HP0IV5/079a:01fI@`0SVT809Y]5
02RKB`0]UT`0<95>03J:C@0bRe80:haJ02F?H00XU5X0:IaB02^MAP0]Wc`0;ihi02jS<`0`YS00=JLa
0080=:D_02L0<:L^036W<`0`ZCH0<jXh03^W<P0oYc40>ZHi03:ZA00^Z500;:AN02^PK`0]WFP0;IQO
02j@FP0cUU80>9U<03ZDC`0oUDh0?iQA03jJE018W500AIYE03fDG`12R5T0A7YH04eoDP1=PU<0B7MW
041iH`0eMf@0;g=V031eHP0fLel0=g=P03U]J00hIW@0>GUZ03b2I@0lSUd00P0oUE@09`10Vd`0AYi0
04fR>@1=YSP0E:/c05N_<01G[Rh0DZhZ05:/:01<YRT0CJDY04^U;01;YC@0BjXi04n[?01=[400C:Pl
05:U:@1KY1H0FiXE05NK6@1>Y2X0@JY503jVD@0mUEH0@HYE04V7F`1=Q5l0AHMQ03j>GP0nVeL0?Z]>
042a@`12/Cd0C:de05R[:P1R[2D0IZTQ06JX7P0206NV6P0W06ZV701Y[1l0J:dL06B/6P1O[Ah0FJ`T
05Z]:@1JZbl0Ej/i05^Z?01KZSP0I:l/06f`7`1c[aX0MjhA07bZ301l[0l0N:lH07:a8@1_/BL0M;8b
07>`>01fZC`0LZ4o072F?`1aU480N9E007nD@01oUd00OiE107ZE@@1eSd80LHa007BB?@1eTSX0MY@f
07jM=01oXcD0NJ<j0080M9Lm02L0KX`i0727@`1fPE40NFeM085IG@29Ef<0TEAQ09MEH@2JEeh0TeiI
08QSD`1nKDd0KWQ5065l@@1ORT00Gi0e062B:P1QUR<0GY@N05bD6@1PTaL0GY8G05nD6@1KVbD0G:0b
05NU@@1DXTd0CYm@04VNEP1;W5<0E:5?052TB`1:Wd40C9Tg052H<`1?Z300C;0c04nb<@1<]2d00P1<
]Rd09`1>]c80BK@i04Vb>P18/D00AZhn04BU@@10XD/0?9UE03R=G`0gPfH0=7YZ03imJ`19P780D7a[
04ibIP19Jf<0A6MO03a[GP0mJV/0?FId03eHN@0iBGl0>D]m03YJN`0jJg80=gMT03=mI00`PV80<H1S
02b1G`0VQ5L09hA=02Z3A`0^Q400;8Q302Z;A00XS4009XTi02J3>@0202Ui=00C02eg9P0ZMQ/0;F`@
031N200dCP<0=cl003Ld000h;`00>B`003HT000a7`00;1d002PJ000W6@009QP002DE000T50008A@0
020@000<0?ooo`002P3oool_000000800@0000<00000004000010000<@0000008@0100000P000080
000400001`4000P3000=20004@T001<9000D2`00610001d>000R50008a@002@F000V60009QL002XH
000Z6P00:A`002lK000/7@00;Al002hP000_7`00;B0002lQ000^7`00<Al002`P000[7000:Q/002PH
000202LE000702XD000Z6P00;1d002hJ000^6@00:aP0030L000203@N000W03@S000e8P00>2D0040W
0012;@00CCd005I7001NE`H0HFTC05Yc9P1>NSd0AGMD03ecIP0eN700;h5`02j4IP0XT6408IEL01RK
FP0LWUD08Ie802JI@@0^Ud80;iM502jFC00]TU40;8aE02j6E`0/R5X09heK02>?G00XUED0;Ie;02jP
@P0YXc`0;j<k02jT?P0]Ych0;ZI00080<ZE302L0<ZM303:X@P0cZD00=:Y003jX>@0nYC/0>JI203:Z
B00]ZE@0;iiO03FAK00hSFL0>HYN03J5FP0hReL0>XeE03V1G00oPeT0@8aJ042@FP17TE@0AY5I04:?
H018RUD0CWmA0563C@1=QeD0@7aV03b5H`0gPFD0;gaS03F0F`0gOEP0>WeI03aeH@0nL6P0?7]S03im
I010Qeh00P0oRUP09`0oSeD0@YE904NHA01;Wch0CjPh052_<P1C/Bh0D[4[052[:@1;ZBX0CZXY04VX
;018Yc@0BZ/g04^/?@1:[400AjQ004bX<`1DZ2@0GIlH05bK4`1CXR@0AZY004>WCP11Ve<0@I5E04J8
F@1:QEd0A8EQ03n<GP10X5L0@ji<04Fa@@1;/cX0E[4d062_9`1UZb80J:TP06RU7P0206fU7@09072[
6`1c[QT0K:lL05j`7@1J[b@0F;0[05>_<@1H/380F:hg0080FJdh01`0Hk4X06fa7@1b[aP0N:hC07ZZ
3P1jZa00MjlF076b7P1[/BH0K;</076a=01d/3H0L:lf07>Z=@1cZC<0MJDg07FL>P1eUd00MYA007J@
@`1gRdL0MHY307ZB?P22Tcl0Qi4j08fC>@2?TcT0Qhln0P23QdD09`1oOTT0R7QD099aGP2CI5l0VUIO
09]GH02KEed0U5UO08eFG023GeD0Lfe<06MkB@1OQdD0Fhi305ZB@01MTS@0GY8X05nD7`1LU1T0Gi8G
05fD5`1LTaP0GiPL05jI901NWc@0EZA1056PD@1>WU<0BiYH04fNDP1AYe80Cja804jV=@1?Vb/0DI`Z
04jX;@1>/380CJh`04n_:P0204f`:@0W04^c;01:]2l0A[0a04F^<`16Z3T0AJ1004>LA@0lUdh0>XUF
03EgH`0gJ6l0B5ik06IFP01bDX80M4n106M>O`1CCg`0AEEj04QBP@1<Bh00Acn003`hP@0`@Gh0;UUh
02idK00_RUl0;9QI02ZLEP0[V5409i9;02N=A00[S400;XY002n:?00^RcP0:X/h02R8<`0XQS40:88c
0080:ghc01<0:gdX02Md6@0]J0l0<UT603Q;0P0h>000=C8003T/000e9`00=2<0030M000[6`00:AP0
02PG000T6@009AL002DD000T50007a8000`0oooo000:0?ooobh0000000@00@00008000010@000@00
<P00000200800080108002L0208000P6000>1`004P/001L:000H300070`001hA000S4P009Q@002@B
000U5P009QL002LH000]5`00;1/002dP000_7@00;Q`002lM000_8@00;b<0030P000d9000<280038Q
000^8@00;Qd002/M000[7000;1L002PG000W6@00:a`002`K000]6`00;Q/002dK000b7@000P0c8000
8P0e8`00>B8003/V000n:`00B3D005E80P1NG@P0G7<G05Ej=015MU40@G5L03mcG@15LeX0=g]V02b4
I`0USV4099IF02>LCP0MWDd089]=02JJB00^UdH0=9M803>EB`0bTe40<I1G02j<G@0/RF00;8YN02Z?
F`0ZTeL0;iM>03>LB@0_XD4202ZV@@0302RVB00XYTd0:jEB0080;jIC02L0<:I=032XB@0bZdD0=ZY2
03NX@00dZ4@0<:M:02fYD00YY5T0<Y=S049jJP18LVP0@G5T03U_H`0jO5/0>hAJ03QmIP0nOf00?WiO
03anI012Peh0B8AU04R4H`1:RE@0B8=C04V<C016S540>X=Q03V8G@0eQF80<X1P03J6EP0gQeH0>hME
03anFP0kMV80?GiK03j2GP11R5P00P13RUP09`0nS5T0@8eC04F=D`18UTX0B:0n04RW>01?[3D0D;4b
04n];`1:[Bd0BJ//04>Z;P0oZC@0@jdh04R/>`17[3d0AZQ104NY?@1<ZS<0FJHO05nN4@1HX1X0CJXb
04ZU@P15VTl0A9AD04B@F@17RF00A8aR03nCGP10YUL0AK1=04Rd@01B]SH0H;<[06F^801Z[240JJPR
06bS8`0206bR8P0W076/6P1b/1D0JK4J05j`8@1F[b/0D:hc04ja=01E/c@0F;0c05^`<@1L/S00IK<V
06V`8P1^[al0LjhL07N]6P1d[AT0Lk0L076a801`/RH0K;4^06b_=@1`[CH0LJPj07FQ>`1dVcH0M9Lf
076C?01aTD00Li1207B?A@1dRDD0LXE207F<?01mTSP0P98b07f@;P1oSCL0PXXm0080OWm902L0Pg1E
09MVF@2]FU/0/5YP0;AEH02VF5l0Te]N08IOG@1kHEh0M6AG06]/D@1SMDX0Gh5805f=@@1MTCX0GY4/
062?8`1PT1/0Gi0G05j?601NTAT0HYDN06FG801RVR40HJ4^05JO?01DV4H0DIM=052ED`1BWeD0Dk1D
05:cB01D[380DZDX05:T:@1>Z2h0CZhf04b]=`1<ZBl00P16Zbh09`16[Bd0B:d^04RZ;018ZRT0C:H[
04fN;P17WCL0AY]103f@AP0fOe40=VIV045DM`1LA8<0LCn707XnR`1^@8X0Fd>60597QP1KBHP0GTN2
0594P014@W/0=Dab02aNJ00]MEh0<8]F032KD00/XT/0;:1702VH?`0ZU3/0:YDn02fC@@0]Td00;I8k
02ZA>@0WRc@09hXc02F:=P0202R9>@0=02F5<`0TN280:fTC03AF200i@P80>SD003T`000g;000=bT0
03@S000a8000;Ad002/J000202HG000402@F000R50008a<0020A00`0oooo000:0?ooobh0000000<0
0@00008000010@00<`00000020030000108000L200070P0030@00147000G2P006a400P0M4@008@0P
4`008aH002HH000W5`009QP002LF000X5`00:1P002`I000/7@00;R40030N000a8@00<Ql003<S000d
9000<2<003<U000d8000<b<003<Q000c8`00<R<0030M000[6`00:AT002`K000[7@00;Ah002hN000_
7P00<1h003DS000203DT000W03LU000l9P00?RX004@b001@AP40G5l6065e5`1@PSD0?h5K03QfK`0j
Mfh0>GeX03Z2G@0bR600:HiK022GEP0VW4`0;9e602VJB@0XU500;9=?02nBC00eSe80=91D03>AFP0d
TEX0<HiL02n?FP0^TED0;YA=032EB00cV4H0=Ye403BRA00YYDD09Z=:02:TD@0RYE@09Z=H0080:ZII
02L0;ZQB03BYC00iZDL0=jU403FZAP0]ZTX0:JA?02FKG@0UTV@0;XMV03]fJP13KFL0@FaO03iYGP0n
LEh0@7aS03ihLP12NfL0?7UV039aJ`0oM6@0BG5U04ecH@1:Q5<0@XEB04:?C`10T5<0=XQM03R>E`0g
S5P0=XIH03R<E@0fSe<0>8aC03aoG010Lf80@7aI0420FP13REL00P15SUD09`11SET0AHUH04F3F013
Qe00@Y1604>I@@1;Xcd0CJTi04bZ=`19[C80B:`a04J[<@0oZST0@:/n04BZ?P14ZSd0@JU2042[@014
Zcl0DJTZ05nS5@1KXQL0CjTT04jU<`15WDT0@IMA046BD`15ReX0A9=K04JIGP11YeH0B:i>04ba@01J
]380I[4T06F_8@1W[2@0IjPR06^Y8@0206j/700W06n/5`1^[aD0Hk4J05bb8@1E/Bh0D:li04nb>@1B
/c/0Ek<b05^a9`1M]2@0I;8W06Ra9P1Z[R/0LZdW07B_:01b/2P0Jk4T072`8`1//BL0K[0[076`<`1a
[3T0Li]007FC@01dSC/0Lh/i06b<>@1XS3`0IXhn06R@?@1XSS`0IXdl06N>>`1YT3L0J8`g06Z7>@1]
P3l0M7e60080PFm?02L0SF=G0:=KEP2eEEH0]U5P0;9AI02GFF@0OUiN07AWG@1`KE`0K6]A06MWB@1R
Ld@0H7e405n6?01ORc80GXTV05n:7@1PSAP0GhdG05f<5P1NSaH0IIDN06>I9@1PW2P0Gilb05bK>`1J
TT<0F99905>IDP1GWED0E:aC05BbAP1E[ST0DZ/^056Y;@1?ZCD0CJdn04j`?`18[3P00P16ZS<09`15
[2h0AZ/^04^X8`1=Z1l0DZ<O05:O7`1=WRT0B:0c04BH@00kQdX0=FeK03AKKP0iCGX0ATB104i1QP1;
@hL0@4F403]8P@10EGl0AEmi049PLP0iI6P0=feM03=jD@0_QTL0=91603BEB00bUd/0;YE702f?A00X
SDD09i1;02N>B`0VTdH09iA002VA=`0XSC009H`^02J=<@0202F==`0C02J:@00WO2T0;fDE03M>1`0i
?P40>38003X^000h;@00=R`003HW000_8`00;Qd002XK000X6@009aP002HG000Q50008A8001hB000<
0?ooo`002P3oool]000000040040000200000P4000410340000000@00@00008000050P0020<00P0=
1@009`0=1`004PT001X=000O40008a@002DD000T5`009AT002XH000/6000:A/002TI000X6000:1X0
02PM000^7000<1h003DP000h8000=R@003DV000e9`00<BH003<S000c9@00<RH003<U000c9P00<b40
030Q000Z7000;AX002hK000_7P00<Qd002hS000e7P00=24003LT000203/X000W03h/0011<000AcX1
05990`1KGP/0I70N05ih>@1<N5L0>GI`03EbMP0cO6d0;HUX02^AHP0WTe`099MC02BLC00[WTH0=Ya4
03NEA`0cSU00=8eE03>=F@0cSEh0<hmP036AI`0cTEh0<I9I032DE00_UDh0;iM903>JA@0gWTL0=Im9
03:RC00YYD`08Z1>01nQC00QY4X09JM:0080;:M902L0<ZU403NY@@0iZD00=jY203B[A@0ZZDX0:IUF
02Z1I`0XNFd0;WU[03MbKP0nKfP0@FmP03i[H@12LF40A7IW04][L`18LfT0@7QZ03EbKP11N600AG=L
04EdF`14P540@8AF03n?E00kTE@0=XaK03fBCP0lSd`0>he=03bAC`0iSED0?HQD049gG`12JV80AGMH
04ElEP16RED00P14TE<09`13T5L0AHAH049gG`11O5/0@HM@04:>C@17UdH0BIe404VU@@16ZC`0Aj/g
04:Z=010ZCd0?ZQ0042W@@0oYd<0?ZQ703Z[A@0mZT00C:Xc05NW801JZ1H0EjPG05>W9@1=XSX0A9m5
04:LC011VU@0AiUH04NJG@16XET0B:M>05>^@`1M/S<0Hk8V06J]8@1VZBD0J:PT06Z[7@0206^]6P0W
06bZ601Z[QL0H:lL05Rb9@1>/S<0Bk9004Z`@@1=/3h0DJh`05R`9P1M/RD0H[8X06Ra;@1[[c80Kjl_
06ja:P1^/RL0K[DS06fc9@1[/BD0L;8W076c:`1`/C<0LJ`g076R=`1bUcH0KXlh06N<>@1XRcX0II4j
06VG=P1XUSL0II@e06R@>P1XQSl0JgY;06icD@1`H5H0PeQK0080WE1Q02L0]DmN0;m>CP31BdP0_4aH
0;A:I`2?E680MeQP07QUGP1kJUP0JfM?06IWA01TL440HWa005n2=@1OQ2h0GX8Y05n6901OSA`0G98H
05fD5`1PUAT0GiTT05fL:P1KVc80GiXi05fE@@1MSTX0Fi9@05JKE01EVE@0EJQ=05Fc@01F/cH0Dk4d
056^<`1?[3d0C[1304fa@`1;[d000P15/3<09`15[Rd0AjX/04JZ9@19Z1l0DZDO052P8@1;X2/0Aj<f
04FK@@0lRTX0=7AE031THP0YE6d0:TYf02m5N@0]B7h0:T]k02A@N@0WI7<0;Vm/03=aI00eMe/0=h9?
03R:AP0eSD80=iA103B>A`0cR4`0;H5?02YkDP0VMeP097eL02B0E`0VST/09iI002JB<`0VSBT09X`U
02F>:@0202J?<@0C02V8<`0/Mb<0<Ud>03M7100h>@40>Bl003`/000k;000>B`003DV000^8P00;Ah0
02XJ000X6`009aT002HF000S4`0081<001l@000<0?ooo`002P3oool]000000<00@00;P0000030040
000500<000020@00108000P4000<1@000P0>1P009`0A2@0050X001T<000M4@008A40028B000S6000
9aX002/K000_7@00:Q`002XK000/6`009ad002/K000c7@00=Al003HP000j9000>2D003PW000g9@00
<R8003@P000f8@00<R@003@T000b8P00<1l002lO000_6P00<1/0030L000g8000=bH003LT000e9@00
>RL003l[0002040a000W04@f001;@@40De8805aY5P1ILb/0EfY805ASH@1<IFd0?Fie03acL00cPfh0
:I5Y026JGP0NV5008YQ802:MB00/Vd`0=iQ?03^@D00jS5@0>HeH03N<G`0eSFH0<hi[036ALP0dTF@0
<i=H036ED00/VD/0;9a8036OB00cXT/0<:=B02VTE`0SYE@07j=A01nTBP0PZD<09ZY10080;JTn02L0
<:Pk03>Z>`0eZS`0<Za1032/A00YYTP0:I5C02YcI@0_J740<fe_03I]LP0nKF/0?g9U03]`J@0oLFT0
B6m[04iNL`1=K6`0AG5Y03i`J010NUT0?GaG03inE010RDl0?hYG03jAD`0lUU00>i5D03nFAP0oTd<0
@IA804:FC011REL0@81K045aH@14If@0BG9J04MkF016QUT00P13TUP09`14T5d0A85O04I_I@12Lf@0
@GeL0427F@13TT/0A9Q904>MB@13XT40A:Ln04:Z?P0mZD00?J9203jNA00mXDL0>J9903JXB00jZD00
AJPf056Y;01HZQl0FJTE05JX7@1EYR`0BjLk04JYA017Yd`0BZ1B04ZIG@1:VE/0C9UG056TB@1I[ST0
GjlY066^8`1UZ1d0JJ/M06b[600206V/600W06V[6`1V[Qd0G;4O052c;`1;]3`0A:m404F]A@19[Cl0
DJha05>`901Q]2<0I[4[06R`=`1Y[c`0I[0k06Na=01Z]2X0J[<U06bb8P1b/B80Kk4R072c9P1]/c00
KJld06^T=P1ZUS/0JhE106N6?`1YQT00JHho06VF>`1[U3L0JI0h06j<?01[PT40K7E907M_CP23GeD0
RDmQ0080UTYT02L0WTYN09U>F@2BEU@0Sf9G08mYG026IE<0OFE<08I/B@27LTP0M74n06Ab=P1TN380
Hh@[06F3:01RQBL0HHTV062;9@1PTR40GITM05jL601PVAT0H9TF05jL6`1MWbh0Gj8l05fPAP1OUe00
H9AA05fFD01LU5D0Fj5<05N^@01G/cD0Dk<e05:]=P1?[C`0C[1404^_A01:/S`00P14/bl09`14/B/0
AZ`_04V/:P1=ZRH0DjPY04jR;01:WcL0B:<k04RP@011TdH0=HA=02iiF00/L6T0:FIb02MNM@0UFgL0
85ed01mRK`0OK6X09G5T02adH`0_Ne`0=XID03N>B@0bSdH0<i9602n9C00]PU80:GaH02IiG00VMf80
9WiV02R4G`0XTDl0:9U002FC=@0USbd098/T02F;8@02026;9P0C02R0900^K1D0<U8703E10@0g=@00
>Bh003XZ000j;000?2X003DU000a8@00;Ql002hN000Z70009QT002HF000R5000814001l@000<0?oo
o`002P3oool]000000800@005@0000000`01000000000000000G000000080040000200000P0000@1
00060@002`8000d4000C1P0201@7000T01D;000H3`006Pl001dA000N3P007Q4002<D000X5P00;1`0
030L000^7@00:ah002dK000/7`00<Ah003<Q000h8@00>B8003/V000i:000=RH003@R000g8@00=B00
03@P000a8P00=28003<P000`6P00<Q/0034M000a8@00=B<003TU000m:`00>b/00P0m:`00:P10<000
B3T004Pi001?AP80EUT905U`6@1ENcT0Cg1B04EEKP0nDWX0@5m`03YaJ`0kOF<0<8YR02^FFP0UW4l0
9iM602ZDAP0WUe00:iIH036DF00fT5P0>HmK03f?GP0iSVD0>8i[036>K@0`T6h0=91R03JCF@0fUTl0
<9Y=02jOC00^XTd0;JAC02NWEP0TYe`09:MG02>VD@0TZ4D09jXn02f[=`80;JTf02L0;:Hk02jX@00_
[4H0;j]702f[B00XYdX0:I1E02eeH`0aJ6d0?6Y[045XK@14JfP0@G5X03YbK00lMFX0A6mW04QJM@1;
JVX0C7AS04YdH`18PED0?HYA03b<D011Tdd0>i1E03nICP0lWD`0?YY>042JAP10UD<0@II5042BC@14
Oe/0@gUP049aIP13JVH0BGIJ04AjF@12R5X00P12TEP09`10TEh0@h5S04E]J`14K6T0AGAU04EnH015
T500@IQ?046JB013W480A:1104>V@@0mY4D0?9a103jFA00jW4/0>Ii>03NQA`0lXd00@jDc04nZ;01E
[R40G:XD05fV601HY2P0CjTb04b^?018[TH0BJY>04ZNFP1<UUX0Ai9F04bQBP1E[SD0H:dV066Z7@1X
ZaH0J:/D06Z[4`0206V/600W06F^7@1P/280E[8/04Ra>`12/DD0@:m>04B^B015[S`0C:lV05Za7P1V
/B00J;4a06N]@01YZd00IZi106N`=P1V]2T0J;4V06^`9@1//BH0J:hY06Va:`1Z/S@0JZle06RU>01U
UC`0IXM306F8?`1[SCd0K94m06fC@01ZS400HhM206IoAP1YLTP0L6IA085QE02BEET0UdeP0080UD]S
02L0SdYU07mCH01gGe`0N6aK07EdE01cLdT0L7Do07F2>@1dRSD0KXT/06F68@1VRAT0I8LE06>;501T
SQ@0IIDC06>F5@1RUaH0GIXF066K5@1QVaH0Gi/E05fP6P1JYS40FjI305VMC01KVTh0HY9=066BCP1P
TDl0FYQ:05JW?`1D/CL0DK8h05:`?P1A[d00CK1504^/@P1</CX00P17/S009`1;[b`0BZL^04fX:01A
Z2@0DJHW04ZP;@16WCH0A:4e04FP?P12WT00>YA70369D`0/Q6H0:ga^02QeL00UJW@086Eb025YL00T
JW009fY^02Y/K00]MFX0<h5S02n9F`0/S5D0;8eF02Z<F@0VRUX098UJ02F9G00TRUX09XmK02RCD@0X
U480:9<i02FA<`0VSc809Hd/02B<8`0202:88@0C02al6`0dI@`0=dh403To0@0l=P00>Rl003d/000j
;000=bP003PW000d9000<Al002dM000Y7@009QT002HH000R5@008A8001`?000<0?ooo`002P3ooomK
000000800@000P0300001`040@00204000`2000?0P004PD00188000E2@000P0G2@009`0I3P007Q40
024B000O4`007A0001lC000U5@00:aT002dO000b7@00;b0002hN000^8@00<1h003@Q000f8P00>RP0
03`S000n:000?2T003TT000e9000>R40038R000d7`00<Ql003<M000d7@00<Ql0030Q000c9@00=RT0
03XY0012;P00@c40048c0012<P00@c<004/j000205=70P0W05]M301GLR00CgHo04QZH014EV`0>T]h
03=EN00eKFH0<X5L02j>F00WVE/0;9]C02jJA`0aTd40<Y5802fCEP0[TUh0;XmN03B>F`0jSUh0?HeO
03V<IP0hRfX0<h]Y032;JP0cRV@0=XmK03FCDP0`W4d0:j1>02RTD00TYU808JQF022YE`0SZUD0::a<
02jY@`0_ZSX0<JTh0080;jHi02L0;ZPn02nYA@0`Zdd0<:Q=032TD`0YW5T0;8eO02aiI`0cKfl0>g9Z
03mdJ011MfD0@GUS03afIP0oLFH0@fU[04EEMP1>JfH0CGMM04YjGP17R5@0@I1B046ECP12V4`0>YIC
03nLB@11XT/0@:1>03nPAP0nVTL0?IU<03jDD00oOEl0?gQQ03ieI`0nMVD0AX9J04:6F`12SUd00P11
UEh09`0nTF00@HQT04AdKP13KVl0@g5Y04=hHP12RU00@9M=04>MAP15W4<0A9m4046TA00lXd<0?9Y0
03jC@P0jUT/0>YE;03ZKAP0nWCd0@j4e04bX;P1?[R<0G:XH062V5@1MZ2<0E:Xb05:]=@1<[Ch0C:a:
04NSF@1:Teh0B8iM04ZQB01B[C<0H:dQ06F[5@1ZZPl0JJX=06B/400206:]5P0W05Z`8@1D/B/0CK4k
04:aBP10[e<0?JiE042^B`17[S/0EZ`S06N^5P1^[Q/0Jjl`06JY@01WYT00IJY006J_>`1Q/2l0JK<[
06Na:P1Y/RT0IK8W06>a:@1R/S00I:lb06JQ>@1YTD00IHU106R8@`1YT440K99006f?@`1YQTP0IWU?
06Y[FP1bFU/0P51O091=HP2TCF<0X4mV0080T5AT02L0Q5]R07QOG@1gI5T0PFYH07eZE`1hJ4l0KWA8
06^1@01/RC@0JHX_06N?7@1WTA<0Ihd=06F?2`1WT@/0Ii8<06ND3P1RUPh0HiP?06NJ4@1TVQD0GYdD
05jR7P1JZCP0Ej1705^=C`1NT4/0HY1?06>?C@1TS4X0FYE;05VT@`1G[cl0E[4o05:^@@1A/4D0C;54
04b^@01=/3<00P1<[b/09`1=[R/0CJPY04fW:01?YbP0BZ0[04FL<P14VCd0@9Xm04BO?P15XT@0?Y]9
03^=C`0dQEX0<GmO02iiHP0XK6L0:5m^02ULK`0/Ffl0;EU`02aILP0/Hfl0;75Z02akIP0YPF@0:8ET
02N:HP0USUh09I5K02JDEP0XUU80:9I@02RD@`0ZT3X0;Hdc02Z<=@0ZSSX09hdd02B;:00202B67P06
035h500kH0P0?D`203hn000o=`00?C400P0k;@002`0g:P00=RD003DS000a7`00;Q`002TK000T5P00
8aH001hC000N3`00714000`0oooo000:0?ooob/0000000<00@00000000000000100000000`010000
00000000000T000000030040000300000P4000801@4000H01`<000T3000>10004P@001H6000G3002
01P<008070d001X07Q40024C000T4P008a@0028D000V5000;1P002hN000a8000<b0002lO000b7@00
<Ql003DR000g9@00>B@003LV000l9`00?R`0040Y000n9000>B4003PS000i8P00=B0003DN0080=al0
00/0=b8003LU000j:000>b/0040^0016=P00BSd004hm001=?`00D44105I<100205]S3`0W05Qh:01=
M4X0B61V04A:N011A7<0<TQd02mLL00^N680;HmG02^ID@0VWED0:9UA02^FB00^T4X0<I5D03:@H00_
SfH0<8aU03R<G@0nSEl0@HUR03^8J00jQFH0=HET03:5I`0cPfT0=8]P03BBF00_Ve809j5D01nSE`0O
YE@08:AA02:WC@0U[4`0:je703:[@00bZCh0<jDn0080<:Hn02L0<:M103>XA00cZD`0=Z=A03JGG@0b
RfL0<gmY035bKP0dKfl0>GIY03^2J`0nQFL0?h1R03mhI@14K6H0BFIZ04eGLP1AK6<0CgUO04UnGP16
RUL0@XiF046AE012UT`0?9I?046NA`14XDT0@Z5?04:PB00mW4d0>iY@03^DDP0jOel0>7aP03YmI`0m
P680@i=F04FKF@12WEX00P11WEX09`0mVEd0?XeV03mmK`11MW40@W5Z04=fI012R5<0@YA<04:LA@19
Wd<0AIa604:QA@0lWdL0>YY0042?@@0mTD/0>YA903^K@`0oWC`0@ilk04JV=P19Zc40Ej`R05n[6P1P
[B@0Fj`b05J]=`1A[d00CJm704JWD`18UUh0BI9G04bV@@1C[bX0HZhJ06Z[4@1^ZP/0JZ/9066]3@02
05V_5@0W05:a801;/Rd0A;5003j_D`0m[Uh0?:aS03f]B01=[C80Gj/L072X401c[AP0Jjd/06NX?`1V
Zch0Ik0k06>a=01S/C40IK8a06Bb=01T/S<0H[4^05n`;P1O/380H:`j06BH@01[PdP0IhA;0666BP1W
QdL0J8Y406f6B01^Nd/0LVUB07MPG029DV40VTER0:95J02QB6L0SU9T0080Mf5M02L0KFiK06MhDP1`
MDh0Ng1:085]BP23K4`0Og5407Qj>P1cPS<0KXL[06b=6P1^T100L8d906j>1P1[SPH0KY0806fD301[
U`h0JIX@06RN4@1TWa<0H:<G05jU8@1NZS@0GJ=105jAB01PTd`0HYAA06>@CP1TS4`0GII:05bRAP1J
[3l0Ejdm05B[A01A[DD0CKA404V`@01</3@00P1=[bd09`1=[R`0D:/[04bY;P18Yc<0AY/g04Z>?@17
ST<0AY5304BG@013WC`0@Idk03nC@00jRdH0=XI>02j1D`0/NEX0:VmR02YYI`0[IF/0;61]02eOK00Z
If`0:7EY02V0IP0XRFD098iU02>CH@0UUE@09iI@02RGBP0/UTT0:Y=:02j@>`0]RS<0;XLa02j8<`0Y
RCL0:8/^02J:8@0202R35@0A03Ab3@0nF`D0@DP1040k000n=@00>S4003P]000g:P00<RD003<S000d
8@00;ah002TL000W700091H0028F000O40000P0M3`0<0?ooo`002P3ooola00000003004000030@00
0P4002@0000000h00P0000@000040@00208000L200090P002`4000l6000B20005`X001T<000K4P00
7100024A00809A8002L07aH002@E000U5`009AH002HI000^6P00<ad0034U000f8@00=2@0038V000a
8P00=Qh003DP000h8P00>BH003XW000k:P00?bT003lX000k9P00>RD003PU000e9000=RD003PU000i
9@00>2D003PT000i9`00?B`003l/0012=000BS/00557001ABP00DU0105MH1P1JIa<00P1ILc409`1G
M5<0EF1Y04a6O00h>XP0=4Ih02UGLP0VKVT09hQL02jDDP0bV4`0;IIB02N@E00VSe80:HmH02Z>H00[
SVL0;HiZ02n;I@0iReX0@8YJ04F9G`0oRF@0@HIQ0425H@0mPFH0?81V03Z6GP0eSU@0;iQ?02RPDP0Q
XeH08ZEB026SBP0TYT<0::a702Z^A`0_ZdH0<jM703JQB00203>RB00W036QB@0cXDT0=Im=03FHE@0d
RF40=GY_03QbL00hJG00?VQ^03ifJP0kPVl0>h=Z045mI@18JFP0CV1/051MK@1>F780DfMT04ebH@14
NEl0@hIG04:5FP11R5@0@I1=042?C`16VDX0AYm904>OC@12XTX0?JE?03bRC`0kUU80>7mM03V1H00k
QV80?8aO04JPE018Ze@0A:YC0080@JIH02L0?ImM03ZGI@0jRfl0>X9c03ijK`10NFX0@HEH046<D016
V4H0B9e004RMA@11XdH0?:9703^LA00oSd@0?91;03ZDB@0jVT<0>Ylk03fQ@010XSd0@ZI004nY;01G
[2@0GJhX06:^<P1L[SP0Ejlm052`A@18[4`0C9iD04nOD01CZc@0F[0T066_6@1X[Q80K:d>06^]3@1R
[Q400P1G/1/09`1=/B@0B;<b046cA@0h/5P0>JiV03b[I@19[TL0E:dY06RX6@1dYQ40M:dL076];01V
[3h0J;0m06Ja=@1R/C00H[@_066c=@1O/C/0G;5005b_?01J[SL0GZXi05nP@01TUT@0IXM<06:5BP1O
PTX0Gh5806UjB01bNDl0N75@081ZE`2;GU`0WUEP0:e<GP2UCFH0VTe]07eJI00206=WH00W06EgF@1d
P540MWU:07QaBP1cLdL0LGQ506mn>01]Qbh0L8`V072>7P1_SQH0Khd@076>3@1`T0T0KY8506jF2P1/
U`d0K9XB06VP501WXQH0HZLJ05jY7`1OZBX0GJhi05VW@01JU4L0GIQ805bJCP1OTTd0Ghe;066CB01O
WT@0G:Po05NY?`1EXTH0DjQ904n`B01:/T<0B[4h0080CK0a02L0DJl_05:/:P1:ZB/0B:H`04NL;P19
Tbd0BI@^04RE<@11Uc80@I/]046M;`0lVS00>9Hh03FBA@0`SE00;8EJ02Z0I@0[N6T0;W=[031/K00b
J6d0;FmY02akI@0/R6D0:YEV02RII@0XW640:9iC02RMC00XVDP0:iM402ZC@`0/SS/0;HTe02b5=@0Z
QcD09hTc02R::P0XQa/00P0/O0l04`0eJ0H0@E<204=4000o>@00?C4003T^000g:@00=2D0038S000a
8000<24002lQ000[70009QP002<F000T50007a0001d@000L4000303oool000X0oooo;`0000001@01
00000000004000030P000P4002<0000000l00@0000<000070P002P<000/5000:10002P<000d5000B
20004`X001T>000K400081<0028D000W5`000P0Y60009`0Z5P00:1L002PI000Y6@00;Q`0034R000d
9000>2D003PT000g9P00=BD003@Q000c7P00<Q`003PP000k9@00>2T003PU000j9`00?BH003lV000j
9P00>2@003PR000j:000>bX003h/000n:`00?RP0040[000n;000ABl004Xi001?@`00EDh005YG0`1I
IPP0EVlJ04m`>00205=YF@0W05iLL`1VBW`0FD2004DoPP0fFG809WE[0228H`0RU5X0;IMB03JCD00b
SED0:hMH02J5G00WQF809hIY02R;JP0[RfT0;XET03MnG@10OUl0A8AR0428IP11QV<0A8=O049oG00o
OV80>X=I03B:E00bU4h0;9m@02RSE@0VY4`0::A102^V>`0X[3l0:Za602bYD@0cXEH0=iaI0080<ImN
02L0;iaJ02nGE`0`SUL0<XEN03=lJ`0eLG@0>Fa`03mXK`13Ifh0Ag5Z04AjJ@17NFT0CfiX05]JJ`1K
EVd0DeY^04=ILP16JfD0A7YN0425G@18R5H0AhAM04B6F@12RE40?8AG04>@DP13W500@Ii>046SB`0m
YU00>Z5C03VCE`0fOf40>HEO03f=G00kV5L0@jI?04>`CP12[5000P10Ye@09`0mXUl0=iiW03NCK00i
Rg80>h5c03enKP11Q640@hEI04N@BP19V4@0BIa604NRB@11XD`0@iU?04R=CP13Sdl0?i5:03^GA00k
VSh0>Ya203^M@`0mX4D0BJDh04n/;`1L[Bh0Hjd_05j/>`1JZd00E:i:04b]C@1;Ye80CJM805Z^;@1O
/280Hk0K06N`601X/1D0I[0F05f^6@0205>b8P0W04Vc;P15/c`0?K5>03R`G00k[f@0A:]I05R]?@1R
[Qd0LZHB07JS501bZa/0K:d[06R]?P1V[Sd0I;0d06B`;`1S/R`0HK8/05nc<P1Q/3P0GZ`f05f[>01M
WT40GI17066BC@1PS5<0H8a<05b4BP1HN4d0HfeD06a/F@1jJF00P6QL08YTFP2<H5X0QU]M081UGP1k
LV<0JgAH0080IW1A02L0OG5>08YdC`27Kdd0Nfe706]j@`1RPT40Ih/g06V=<@1[RRl0KHlW06jC7@1^
UAL0LiDC07JF4P1cUPl0L9P?06nL401/WQ@0JZ8F06JT6@1RYQl0H:HW05nZ;`1N/3X0GZa005bRA01K
XDL0FYa905fBB`1MSdP0Gi1406:O@01OYcl0Fj=005ZOB01GXdP0DZ]905:`@`1C[cL00P1D/C009`1B
[b/0CjPT04fT9019XRD0Ci`R04bE7`1;UQl0B9LR04>H8P11VR<0@idZ03nP;@0nWS@0>Ia303JAD@0d
QEh0<WmW039eJ`0gKFd0?FI^03aWK00cLFL0:g]X02b;JP0ZVFP0:imX02RTHP0XY5L0::1A02VMC00Y
VTD0:IQ302^A?00]SCH0;hPa02j5;P0^QBX0:XHR02R15`0202ac300C03QO0P11B`00@Sl003lg000l
<000>2h003LZ000b9P00<R80034Q000b7`00;ad002dL000W5`009A@0024F000R4P007a0001/@000<
0?ooo`002P3oool_000000030041000100000@0000800@00800000020040000@0080000400001`40
00`4000<1P003@@00105000@1P004@T001@<000I2`00618001`>000Q4@008QP002LJ0080;1d002L0
:Ah002TK000Y6@00:A`0034Q000c9P00=2P003DV000h9@00=RH003DU000c8000<Ah003<N000f8@00
>bD003LZ000m:000?RT003`[000n;@00?BX003XW000h9P00>RP003d/0010<000@bh0040^0011;P00
@S<004@i001:@000E4d105YK1@1MJPh0F7TP051f?@19HUP00P1DDVX09`1PCGP0ITQf0599N@10DWd0
;G1d01n9K@0KUF0079UJ02FGF@0_Se/0;hEP02mnH00]N6<0:gUX02V1J`0[R6T0;hIW031lI00eL6<0
?VmU04AlIP11QFX0?hAZ03inI@0nNf@0>gQT03MmF`0bP5L0<X]@02jIC`0^XU<0:jA<02ZT@`0/Y3/0
:ZTo02NZBP0YYe/0;:9P032PI@0202bPJP0W02VIJ@0ZRf`0:g]_02ahL00_KGL0=V=k03iSL`18HW00
D61^051XJ01<KFP0CfUZ061OJP1bDg00K51_05AFK`0gF780>ViU03^3F`0nSE/0BHiG04^<GP14S5`0
@hiE03j<GP10UE@0?iaA042MC`0nXdd0>jAB03^LE`0hSUX0>GeU03^9G`0lV5X0?j=E046ZD`10[UD0
?JaF0080=jUG02L0>JQQ03FUJ00dWG40<i1b03V6L`0lPFl0@8ET04F3G@1;SE<0Bi=904fIB`1:WTd0
A9eD04VEF@1AReX0BHaH04B;C@0kS4D0=i1003J?A`0lUTH0?YM504JI?`1>XST0FJPc062]<01K[SX0
Eja505J^DP1B[500DJQC05F/B01L[bd0I;0O06:a7P1R/Qd0H[4K06>a6P1K/2000P1>/RX09`17/cH0
@[5<03bYFP0mY6H0@JUM04nXC01VZRh0Lj`J07NR3@1`XA80LJ`M06b_;01U/3h0H[4m06J`=`1U/c00
I;8[06Bb9`1S[bL0H:`[06:Z;@1MZ3L0GIm005nEB01OTdT0Ghi=062;B`1NQ4/0FWID05iTG@1[Hf80
OF=V08ETHP2<HU/0Nf5L06YQF`1UO5d0HY5G06>BAP0206J<?00W072;>@1hQS/0LX8f06j3<`1[S3H0
Jhhj06n>=P1]SCH0JY0c06^B;@1/Ub<0Ji`P06nL7`1bVa`0LYTE06nJ501ZVa@0JYhG06JQ5P1UXAH0
Ij4H06:S7P1RYb@0GJ`]05^`>01JZT80Fj=805fIAP1OT4P0Ghe905nB@P1NWD00GjLo05fV@01JXT@0
EZ5804nSB@1BZd00Dk0g0080EK<f02L0CZhX04nX8@1>Xb40BJ0M04fK6P1@UAP0CiDK04ZI7012VAh0
?Y/P03jN:@0kXc40>j@n03ZMB00iU580>8]I03N7F`0fPE`0=WaO03]kH@0fP600;XUL02V@G@0YVV40
9j1L02JQF00VXU409j5:02RNB00VWTH09Ia602JLAP0VUT00:Y0d02b9:`0_Q280;H4L02]n5@0[N0`0
0P0fIPH04`10DP40@d<0044k000o=P00?C4003X]000f:P00=B<0038R000c8000<1h002lL000Z6P00
9QH002DD000P50008A<001lB000L3`00303oool000X0oooo;@000002004000800P4000<00@000000
000000007P00000050030000100000@000040@001@0000L000090P002`D000h5000A1P005@X001L<
000I3P006Q0001/?000L40007`l0020C000T5`00:a`00P0a7000400]7000;1d002`N000/7`00<240
038Y000f:000=bH003DX000g9`00=B8003@S000b8P00=Qh003`T000m:P02044/000E044_0016;P00
@2l0048[000m;@00?b/003h]0011<@00AS<004Pc0017=`00ASP004Dk0019?`00E4X105aN1P1OLQ@0
GGda05UgB01MI540GeAA0080GdmU02L0DTmj04aENP10G7T0=VMj02J4L`0RUF/07iMQ01^HH00MTfD0
8XU^02IlL@0/LFh0;FQb02e[M@0bNg00=hIV03^4H`0hLfL0>5Y_03YOK`0oMFh0?H=`03b2K@0lOfL0
?7eU03QiIP0gN640<g9R03F0F00dUE00<9mA02VRB`0VXDX08im902BRC00TXUL09:=T02JNI@0XVVH0
0P0YVf/09`0XTV`0;89`02e_M00_KW@0=FMe03aKM`15GG80Ce]b05IJK`1GI6P0DfIY05INK01UFW00
N5Ec06iGK01CGF/0=fA^03agH010R5`0@I=L04bDE`18TUd0A9AL042EF00jTUh0?IUE03nND00mX4`0
?j5=03VKEP0gTUd0>8MM03UoH`0iT5X0?YmG03nWE010[5H0?JeL03JZF`0303>YGP0V03:XJ00bXW00
=99a03^3L00lOfl0AX9S04]oH`1=QeL0CHiA052@D01@TU80BI1F04b:E`1AQE`0C8QM04F3D@0jQ4X0
=hM403>5BP0hTDP0?99704R?@01=TCh0FIlg062];@1I[ST0F:a;05R]EP1DZeH0DjQB05>]A01I[bX0
G;4Q06:a701P/1X0H[4G06:`601J[ad205>b9P0W04Za=016[DX0@iaN04:KH`1:Ydh0FjDm07:X;01m
YaT0OI`>076N4P1YYa`0Hjl/066a>01S/400Hk4j06Bc=01X]2`0Ik8X06N^901SZRL0I:@/06BV=01S
Y440HI]705jEBP1LRe40HHM<069jD@1RL5P0HfMO06MXH`1^KEd0KfmN07MbF@1^KUD0IGM>06F6C`1U
UDX0HYPn0080IIXg02L0J9@b06J==@1YQC@0JX@d06^8=P1^RcH0KhTg06f>=@1[TB/0JYDV06FM8@1X
X1d0Jj8M06jP601]WQT0JYdI06ZN601WXAT0IJ<F06FQ4`1YX1D0Ij4H06>X6P1LZR40G:l`05j]@01M
XTD0G9170629A`1RSDH0HHm1062F@01PX3H0FZLj05BR@01BXDH0D:5805:]@01A/3@00P1>/3D09`1;
ZRL0C:HP04jQ7`18W1`0B9XM04fH7`1=UQd0BITK03nH600jVAT0>I`S03NQ=@0hXTH0>9]>03F@D@0e
SED0<haD03:<D`0bReD0<heG02jDEP0XW5409j1B02JSE`0WXU40:J1:02VNA00VWD00:9Y002NK@@0X
WDL099e:02RJA00ZU3d0;8db02^6:00YPA/0:7XA031^1P0203iJ000C04=90014?@00@3P003lc000k
;P00>bX003PU000c9000<R8002lO000a7P00;AX002XG000V5`009AH002<E000T4`008a0001h@000<
0?ooo`002P3oool^00000003004000020@000@4001l0000000<00@0000<000060P000P070P004@07
0`00208000T2000:0P002`H00188000F30007A0001lC000P5P007A<001hC000O4P009A<002LE000W
5`00;AX00080<A`002L0<1d0034J000_7000<1l003<S000e9P00>2P003LW000d9000=BH0034Q000c
8P00=B8003DU000m:@00?2d004@^0014<P00AC8004P^0015;000@Bl0044^0014<@00A3@004Xd001:
=`00C3d004i2001AA@00DTD005Y@0P1PG@L0HW@F05ml=01QLUL0HVAO06UGDP1_BTP00P1MC6<09`19
CGL0>eii02QbN@0PPWT07Y5g02:FK`0UUFH08Y=W026;KP0OP7D08gIe02]cM@0_LGX0<G=o039hNP0h
OVl0?Gi[03YgJ`0fKFh0=fi_03akK00nPF/0?89Z03b1J@0kPFX0?Ga_03YcK00fJ6l0>7QP03Z?D00d
WD/0:Im<02FND`0SUel08iQN02:HI@0SVg409YI/02JAJ`0202N>K`0W02b<J`0]Q6d0<7Yb039dK@0i
JFd0@5E_04iCKP1JCg<0IU5c069HK@1LEfh0GEIa06UIM01gFGP0KEi`055TJ`0jKFP0@W]K04F7E`12
S5H0BY9F04BBF`12UUh0@9UL03VHH00mVU@0?Ym>03fQD@10WE<0?95L03R8H`0iRUl0>8eR03bIFP0n
XUL0?JQH03fZF@0lZF40=jQQ0080=:UP02L0=JYP03FZG`0cYV/0=YU_03J;K@0nQf/0B8ET04miI01<
OV40CX=L04j5G01@Q5L0C85F04j0E`1<OEP0B81H04R0DP13PTh0>XQ:03N9C@0mSTl0@8i>04V;AP1?
QD<0DiLi05b[;01K/3P0Fk1405R_CP1DZ5<0D:IC05>]@P1F[Rl0F;4R05b_701N[QT0GjhF06B]6@1L
/1d00P1E[bP09`1?[SH0AZ]604BOEP1<YE<0G:Q206RP?`1eYC<0OJHN082K3P1fV@l0JZDJ06J]:P1S
/CD0H[0k06>b>P1W/CX0K;8f06Za;@1X[bL0J:/X06RY:P1UZC@0HJI005fPA01LV4H0GHe>0664D@1Y
LUL0If]K06MYGP1RMU`0H81D0665EP1TS4l0IXU306F<?`1WSSl0Ji0i06RA=@0206V?=00W06Z8=P1X
Q400JWXi06Um=`1ZPcP0JhDi06N7=P1XSc40JI4Y06RG801TW1d0J:8N06NT7P1UXQX0IJ<N06NT801X
Y200IjLP06NW6@1XY1@0JZ<A06JT5@1RYaT0H:`P05n[:01QZcD0Gj<l05fC@@1PRD80HXY106:<@01O
Sd00H9Pe05bS=P1IWd80Ej5805NVA@1D[CL0CjX/0080BjHT02L0C:8P04bN801<W280BIXR04^H901<
V2L0BiDO04RE5P12U1<0?Y<B03ZH700gW3<0=Ie@03FCD`0gQED0=hMG03R9E@0fReH0=HiO03>BH@0/
Uf80:YeP02JOGP0RXe`09J=E02>SD00TXDP08ii402NL@00ZVD40:iQ702^GA`0bU440<Hm003:;>@0a
QS80;g`Q031b400kH`D00P13D0004`15@`00@ST003ld000n;`00?Rd003TX000f9@00=B<0030O000]
7@00;Q/002`K000W60009AL002@F000R5@008Q80024@000K4000303oool000X0oooo;@0000001001
00000P00008100010@0600000003004000000000000001D0000001L00@0000<000030P002@<000`5
000?10003@@000d3000?100040@00187000E2P006a00020E000S60008QL002<C000S4P009a<002HD
000V5`009QT002/K000202lL000W02lK000d7000<b40038R000c9000=RP003LZ000h:000=2@003<M
000c8@00=24003PW000l:P00?Rh0048^0013;P00A30004<`0017;`00A300048_0017<P00BST004dk
001@?@00Dcd005I5001GC@00Fe0005aH101RI@`0HgHM05Ym=`1OLU80JUe]079CI`1^DUd0J4aL0080
CE1^02L0=eAm02A^P00GQ8005Xmm01^>N@0QT7009Y5Y02R?K`0XPW@09WMj02M_NP0/Lg`0;GN002mh
Q00^MXD0=7Qn03MjN@0fNW/0<WEj02m`N@0eMGD0>GUb03QlL00gO6`0>7]`03aiL@0nMg40>gM_03j0
H@0mSdl0=I]:02bLD00VW5T09IAT02JGI00WUVT09iEb02V?L@0[RVl00P0/Q7409`0aR6X0<8EZ03=m
L@0iMFX0@6I/04ADK@1BE700HTme06e>M`1[DG<0Ie9d06Q@M@1`E7H0N51j06]JMP1DIfd0@fi]04Ye
GP1<OUP0Ah5I04R:E@14ReX0?heO03bDH00iTfP0?9MK03nJE@0mWUP0@9EH04>2GP10P640>hiM03VN
HP0jXeT0?:=H03^TFP0lYEX0?J9O03NSH@0203RVH@0W03N[G`0fZed0=:]V03FPJP0iUfX0?9AZ04N;
I01=N6L0BWQX04YgJ01<MfH0DGQT04ieHP1>MEP0BgIG04eiF@1ANUP0CgiF04N9D`10RUL0BHmD04Z:
DP1>QTd0Ch1=056@@P1HZcH0F[0g05^`>`1I[TH0DjAB04fLE01B[4H0Ek0e05Zb901L/Ql0Gk0I066]
6`1Q[R80F:d^0080DjDm02L0C9]804bVB@18[DT0G:e006fX?@1^WD<0M:4h07VW9`22XA80MIXA06VR
6@1QZbL0Fjl`05f_=P1Q/CX0IK9006Ra?01X/C80J:l]06B_:P1U[Bd0HZ`d05b[@01NZ4<0GJ9405bN
C@1JVE40GhiE06IoD@1TPD/0I8U;06R>BP1WTTL0II=006F=>`1USCT0J8`g06V;<P1YSC400P1YRc00
9`1]RRh0J8Xa06V:<01[SBh0Jhh`06R<<01RT2d0I94X06ND9@1XUR00IYXQ06BO8P1TYB40J9lI06JQ
6P1ZY1d0IjHQ06JX7`1WZ1P0I:@C06JR4P1VXA<0IZ@I066Z8@1Q[2H0H:P_05nT>P1NVc/0HHll06:@
?01STCl0II@h062I;P1JVBh0FI=005JL@P1GYD40EZLe052S8`02056N6`0W04nK701AV2<0D9HT04nD
901?TBH0BY0R04Z>6`16T1P0@i8I03jG7@0iV2P0=9Q0036CEP0`SUL0<X]J03J<F`0cS5`0<XmU032>
J`0/T6h0:Hib02^;N00WTWL08ia/022QH00QXeH08:I:02BRA00VWD00:9Hm02b?>00_RS<0<hHa03F2
;00eORT0=7TO03M/4@0mG`L0@U020080@d8001<0@c/003hb000k<000?Bd003`/000j:@00=bH003@R
000a7P00;a/002`J000Z6@009QP002DH000R5@008aD0024B000M400070l000`0oooo000:0?ooob`0
00000P0100000`0000000@00004000060000000500400000000000000000000100001P0000000`01
0000000000000005000000800@000`0200005`0300000`4000L2000:1@003PH00108000A20004@L0
01@8000F20005`/001X>000P4P0091L002<L000T6@009AD002@C000U4`008AD002LH000X6@00:QP0
0080;1`000H0<1d003@T000f9P00=BD0034W000d9`0203LU000O03@T000a9000=R4003/T000m:`00
@S8004<f0011=000@bl0044]000o;`00@Bl0044b0013<P00B3P004lj001@@000ED8005E7001FC000
GeT006=S0`1RL0l0GGdW05Yk@@1NKUP0Jf1R075IJP1cE6d0JEAb05]@MP0203eEO@0W02eGQ00JN8H0
58>901B7QP0GOh007HIh022<N@0TSX809h:202IdP00YKgl0;7Mm031nP00aOXD0<7F803=^R00cLXD0
<7V102akP`0[M880<WAi03QfMP0fMg<0=GAa03EaL@0kLW40?7Ua03f2KP0kRF00>Y=A036GD`0YU5`0
9YMN02VEH`0[UV@0;IAZ02fAMP0`T7<0=Y1/0080>HeZ02L0>XUW03Z2K00iKG@0@VM`04eLJP1HCfX0
HDe_06Q>N01_CWX0Ke5f06mBN01_DgT0KeUf06mGM`1XGg<0G69^05AVK01GK5h0DW5K04IcG`13PEL0
@81K03f4I@0kSVL0=91^03VAI00jTEd0?9AN046AFP13Oeh0A81L04:DG@0nXel0?jEJ03nOF`0lWE`0
?YaN03^DHP0hUf800P0hX5l09`0fZV00=ZaM03N[HP0eYV<0>IeW03^IJP15T6P0AgU[04YbJ`1?Jg40
D6aa055`K01@KV`0CfmT04a/H@1?L600DgIP05MmGP1AQ5`0BHMN04V<FP1>QUL0BhAD04Z0E01@T4/0
F:Tm05Vb=`1O/SH0FZi005>MB`1ATEL0DjA<05Zb@01K/c40G[<R05nb701I[bD0F:lc05:[@@0204bH
B`0S04^<CP1DXSl0FZlf06V]<01cYCH0KY]006nO?@1dZ340MjLJ06jV5P1ZYad0Gj/Y05n^;01P[S40
I;0d06Bb?P1T/d00Ik4i06R`<P1U/2h0Hk0a066`?01Q/T<0H:e8062VB`1JYE00GZAA066TB01QWD00
J9`f072D?01dV3l0LYE006j=?P1YQD400P1XQ400:`1WQcT0IX/b06NB;01WTR`0IiDV06JF:@1VV2X0
J9LY06VF;01WUR/0IILX06BD9P1TSRL0HHXY05n<;01TSb/0HYHZ06>I8P1TWB<0JJ8W06ZU9@1UZB00
Ij@H06JO401XW@l0IiT=06RL4P1SY1X0HJPU06FW<01QXcL0I9hm06FF>`1VUS/0IYHl06NH<01WV1d0
HIDI05NA8P1CV2d0Cj0h05BR=P1FWbL00P1FVAT09`1JV1T0F9<N05:A7`1DSR40E8`S04f=7`18SQh0
A9LQ03fL:P0gXCH0=Im802fFF@0YQVD0:H=Y02^:KP0]RV`0;X9/02j3LP0]PWH0;8Qd02V9MP0ZQG/0
:8mi02BLK`0VXV<09J=F02JRB@0[WT00:iU002^A<`0^R2h0<8<Y03=o:@0fNB<0<G<K03=Y4@0iF`H0
?d`20411000203lf000C03``000h:`00>bX003`Z000k:P00>2X003HV000e8`00<al002lM000/6`00
:AT002LH000U5`008Q@0020A000N4P007Pl001d?000<0?ooo`002P3oool/000000800@0000<00000
0040000100001P0000001@01000000000000000000000@0000H0000000<00@000000000000001@00
0002004000<00P0001L00`0000<100070P002PD000h6000@20004@P00147000D20005PP001L;000J
3P00818002@G000S700091T002DE000T4`009A<0024E000W6000:1T002XH000202`L0006030M000d
9000=RH003DU000a9`00=2L00P0g9@007`0d9000<B@003HQ000k9000?B/0048b0013=P00@C@004<_
0011;@00?bl0044_0011<P00@c8004Ph001?>P00D40005E2001EA`00ET`005mI001SH`<0HW0?05em
9`1JNd40GViH06]PHP1aFFX0LeA]06UDLP1KD7H00P0mEGd09`0]Eh@06WR601B3R@0DQhH05gn001f6
N00PS7T098j202N2PP0VM800:Fmo02agO@0`OX00<Gj5031eR00cKXP0<g:5031iP@0/Nh<0:gB2039d
N@0hMWH0=WMc03EdL@0eLG40>g9a03aiL@0mPVh0>hUP03ZCD@0aUe<0:IAL02JGGP0YUF<0:iIT02fD
JP0]TGH0<91c03J@K00203V=JP0W03Z9I`0jPV`0>Fed049WL01=G6X0F4mZ065=K`1XCWP0Kdij06mA
MP1_DWP0Ke=i06mIMP1_EgL0J5mc05aRKP1DIV`0EfaN059aF`16Lel0@h5G0420F`0mQ6D0>hiW03B@
KP0iTF@0>Y5M03bDGP11TEX0@gmN04B0G012U5d0?Z=O03nUFP0oWe/0?9eL03jLGP0kU680>9MR0080
>:1O02L0=ZYP03J/G@0gZf80=JIS03VMI`0kVFX0AI1X04MiJ`1:LV/0Cf]a051/L@1AL6`0D6i/04m_
I01<K640Cg1P05=fH01GOEh0DHAL04V7GP19S5X0CXIG04^4E01:P5@0D91;05RY?@1I/SL0Gk8f05Z^
@01CWD/0DI5G05>TC01J/T00Fk<a05jc8P1O/Q`0FJlU05R_<`1BZd400P1<V4/08`1;S4h0E:8o05Z_
=P1Y[C00LjDf06jK@01_Wcd0M:Pa07NW6P1^YQH0JZLM05n[:@1O[R`0H:ha06B`=01T/Sh0I;=006Na
>@1X/380IK0^06>`<@1Q/3`0HK93062]B01PYT/0FZE@05jTD@1QY4P0HIe006RL=P1`U3`0M9Po07:E
@01^SCh0JHE10080J8A002/0IhLi06J;<P1WTR`0Ii8/06NE9P1VURT0IYPZ06RG:@1YUR`0IiH[06FG
:01TU2H0I8hW066::@1OS2`0I8l[06:F:P1SVB80I9dS06VR9`1ZYBD0IJTP06NT601VWa00J9d?06NI
3@1XW180Hj@J066X9@1UYc00HJ<g06BN?@1UUS/0IYHk06JF?01WV300IiPM066E6@1GTB80DiP]04nP
>01DXSH0EYlW0080EYTI02L0FYPI05RC7P1BTAl0E8hQ05B<8`1=SAl0B8hN04BG8@0mW2X0=j4f03FO
B00]UUT0:HIU02V3J@0[RVh0;HY/02j2K00^Pg80;H9f02b8M00YRGH0:XEk02R?N@0TW6l09Z9S02FS
EP0VXTT0:ii002^I@00[TC<0;XP^0323:@0cObT0=WTS035c6`0cJA40>E/603m<0P10@@000P0o=P00
4`0l<000>2/003/Z000l:P00>bX003PZ000f9P00=B<003<O000_7@00;1/002TI000W60009AL0028D
000P4@007Q8001h?000M3`00303oool000X0oooo;0000002004001<0000000<00@00008100010000
1@000002008000800P4001T0108000D200050@00204000P3000>1P003`P001<9000A2P004`X001D9
000G2P006@d001`?000M4`008QH002<H000Q60008a@0028B000V4@009QD002XH000Z6@00:aT00080
;aX002L0<B8003PX000j:`00=bT003@T000d9P00=BL003DX000f:000>2H003dX0011;000Ac<004Pi
0019>@00BS<004Dc0012;P00@2l0040^0010;000AC8004di001A@P00DTL005U7001KD000G5`1069Z
1`1RM1@0GGd[05UhB01TIUd0JeaX07=HI`1kDV<0MDmc06i<OP1FCX800P0aGHL09`0OIH`05GND01=g
V00EMY8056R;01QhQ@0IRHT06Y6B01j:S@0OPHX08WR502EgQ00WNHD0:gV602afQ`0^M8L0;GV702em
P`0]NhH0;gN803AiOP0gNg/0>7Ug03EcL`0cKG40>79`03UoK`0iS700>I1W03JCG`0]TF809h]Z02J<
JP0XRVX0:h]/02j<K`0`S7T0<hmb03^AJ`02046BI`0W0469I011N6T0AU]d059EKP1UDfP0O4eR07M?
IP1dCG80M4ei07=FM@1bFGH0Ke]f06YOL@1SGGD0HF1]05eUJ@1GI6d0F6]P051`GP13LV40@GaL03]f
HP0iNFX0=hUY032>LP0hRVP0>X]Q03^?H`0nSe/0?hEH0468E`11UeL0@J1M04>PF012WE`0?iQQ03fC
GP0mQf80>XaO0080>9YP02L0=jQS03N]F`0h[5d0>JIQ03RMK00kVFd0A95X04QnJ`1>L6X0FVI/05QQ
L01IJFl0E6ic04iZJ@16IFL0BFUY04ibJP1?NfX0DH9T04b1H`16Q5d0AWiM04AlF`18OEX0DXaC05^W
?`1M/CD0H[8_05j_=01DWTL0DHmJ056ME@1F[Dd0F;1005Zc<P1F/Rl0Dk0i04fYB@17XDh00P18WD/0
9`1@WCP0H:TX06f]9P1i[bT0M:Xh06jQA01`Y440KJXe06n]801]ZQ`0IjTO06F/:01S[RP0IK4V06Ja
:`1U/340IZhm06J^=P1R[C40G[0]05nb<01L/cP0Gk=606:[B@1OWTX0GIY=06:KCP1YXCl0J:@b06nP
;01bVRh0LIXg07FC>01dRc@0L8@f06^7>P1[S380JXd[06JC:@0206JF900W06RJ801XW2@0IidX06BM
:`1UW2h0Hi/_06FL;@1WTB/0HXH/0660<P1QQ3H0GXTd05b?<@1NURd0HILX06>R:P1WYBL0JJ@Q06FR
601UW1@0IYPC06NE4@1ZUa40J9/G06ZO701ZWAd0II`W06VL;01^UR`0KY<Z06nD:01^UAh0K94C066:
3P1JRA80EhhK05BH9P1FVBD0FIPI0080GY4E02L0GXlF05R;6@1CSAd0EI8V05:?:@1=TB<0BYHU04BP
;@0iYSh0<ZUA032SJ00WUFl09X9c02QkM`0YNg@0:WEb02maLP0]LG40;7=a02Z2L00ZQVl0:HAb02N=
K`0XVfP0:J9O02VSC`0[X4@0;YXl02jE<P0`S2`0<hHV03>09@0dNB80<g<H03EZ3`0lG@P0?Td20490
0011=P000P0n<@004`0k;@00>RT003XY000j:P00=bX003XY000f9000<b40030O000]7P00;A/002TG
000W5`009AD002@A000P4@007`l001`>000I3`00303oool000X0oooo;00000000`020@000@400000
000A000000800@0000<00@400040000100000`0000007P0100000P00008100030P00108000L40008
100020<000X5000=10003@P00148000D2@0050X001@;000E2P005`d001`?000O4P008A<002<E000V
5@008aD002@B000V5000:1H002XJ000/7P00<20002lN0080;R4002L0=B<003XZ000h;000>2P0038V
000f8P00>RH003`/000o;@00@2d0048^0015<P00B3X004ho001A@000Ccd004Tf0017<P00AC8004Hd
0018=000C3h00591001FAP00F4P005aA0@1OH@@0HG8<05il7`1INcH0FFe>065QF@1^EVL0NTa^07]?
J`1lCFP0LDac06I:P017EH@00P0YIH/09`0JJ9005fVI01ISW00GHiD05Ef=01QbR`0GQY<05i:J01N@
V00IRYD06h2C01]eT`0NKY408F^>02=`SP0TLH`09W6;02]cQ`0_M8H0<GF903AiQ00gO7`0=Weg03Uk
L00hNVP0?7eU03j5I`0jSFh0>91^03N@KP0_RW80:X=e02YmL`0]MW40:gQ`02n1M00aQgL0=8]_03Z<
JP0203j:JP0W0463IP16LFT0CeEd05a@L01]D6P0PDYN07aCHP1iE6L0MeM]07QKK01hFfd0Kei_06AW
K01LI6l0GfAW05eZH@1AJfP0Cg9N04QhG`0nP6D0?8EP03EhJ00gNF`0=HUW03:8J`0fQFD0>hMS03b=
H`0jTUL0>XmF03f@D`11VU40@9iH042QEP10Wed0?iYQ03nAH@0kR5l0>I=N0080=ImO02L0=ZYK03ZZ
F00lZUX0>jAP03fJI`0nU6X0A91U04V9I`1DNFH0IVMU06ASI`1NJF/0E6ib04YZKP11I6/0@VIc04Ac
M@15Ng@0C7eX04amI018Of80A7IQ049fGP11OEX0ChaC05^W>@1N/bh0H[8U066`9P1FXS`0DYUH05BM
E`1CWeD0E:E=05:ZBP1@ZdT0BZ1A04F@FP18UU400P1=Y3@09`1L[b@0LZdM07R_7P1j[bP0Lk4d076Z
?P1_Ycd0L:Xc07:_901a[Ql0KJPK06VZ8@1U[B40IJlO06Fa801Q/Bh0H:dd05j/=@1O[S80H;4^05jc
=@1P/c`0GK9405f]?P1NXcX0IYU106nC@P1_V3/0LIPb07>J<01aVcL0LYhl07BJ?@1`UcD0KY8c06ZB
=@1XTc80IY@Z06FE9@02066H7P0W06>I701XVah0IIhT06>O:P1OVR`0HI//06NJ:P1TTRT0HXhZ066B
;`1QTc@0HYPe05nG<`1NV2h0I9/Z06NM:P1WXbH0JJ0Q06NN7P1TW1l0HIHO06BE7`1RUQX0IiLF06fE
5P1]Sa00IHhA06V<4P1]RA<0KhTD07:44`1dP`h0LX0:06Ul2P1RO0h0G7lC05R85@1GRa@0FHX@0080
GXXB02L0GXdG05N>6P1@T240D9@]04jA;P17U2L0A9`[03jS=`0fZ4`0;:QT02JLM@0URWd09Weg02Ui
K00[N5l0;GQD031gC`0`MU40;gYB02f3D`0ZRUP0:XaN02JBF`0WW5H0:Z1?02bQA`0/X400;Ydo02jE
<`0_SBT0<8@R03=l700hLaH0?6L<03mL1@14C`80@T40048f0011<P000P0m;`00100k;000>B`003PZ
000j9P0203PT000=03DT000d8@00;al002lM000/6P009aL002DE000S50008a<0020C000N4@0070l0
01T=000<0?ooo`002P3oool[00000003004000020@000P4000L000000`010008000000800@001@00
00007`0100000`0000<100050@001`8000L4000910002`H000X5000>10003`P00188000C1`0050P0
01D9000E30006Pl001l?000N4`009AD002@I000P5`008a@0028F000T5`009QT002TH000Z7`00;Ql0
03@Q000c80000P0d8@002@0f8@00=2L003HX000e9P00>2L003XW000l:000@2d0044]0002040_000L
04Da0018>@00CT400512001A?`00CS`004dh001:=`00BC/004do001AA000E4X005YB001OF000HfP6
05mk4`1JPBX0DWM5059OF`1NBF@0IDYM06UAH`1eCVL0N4iY07A>J`1WC780HD>003eEQ`807f>B02L0
56:F01MIV`0JEI`06eNC01MES@0KJh`06h2C01^>V`0LSiX07H^I01b4VP0IM9`06V>L01iIV00MHID0
7FVA029[S00ZK8H0<6j403=bQ@0hMH80>7Mo03YmN@0iOfh0?H9U0462H`0nQFH0>hQb03N;N00eRG@0
=8=c03=oL`0bOFh0=7M^03AjJ@0ePFT0>8AY03Z6J@0mPV/00P0oN7809`11L6/0BfM^05]AN`1WCGP0
K4]]07E7I@1cDF80KUUT06aLIP1[HFD0JVAX06ETJ@1OIfH0FVAV05]VH`1GKF40BWAR04QjF`11PUh0
=hQZ03::HP0aOVH0<WmV03R;GP0fQV@0>8MR03b9H00oSf40@9AG03b@EP0mTUD0@IYB03nJEP0mXE@0
?YmJ03ZJH@0kU5d0>HiP03JHG@0203FSFP0W03NZF00mYeL0?Z9L03jMG@10V6<0@I=T04N?HP1>R6D0
FgMT06YWI@1RIfX0EFi]04i_L@19KFd0@6e_041/M00oMgT0@Gal04IkL@19N6`0BGQV04YZJ015K6D0
AGMQ04b:D@1LYc80H;<P06Fa6`1T[Ql0FZLe05FOC01BVE40D8mD05:DE@1?WEH0C9mH04ZCF01:QeD0
E9M00080H:XT02L0Jk0G07J]501g[a`0L[4W076_<`1`[3<0Lj/c076];01a/280J[4O06V_6`1Y[1X0
J:`K06J/701Y/1/0Hk4U05fb;P1K/340G[4k062b>@1S/400I;1206F]A01T[cP0IZh`06fW=01bYBl0
L:8]07>Q:`1aVbh0KYd`06fR;P1bXS40MJ0^06jN<01_WC80JY/^06VJ:`1TVBL00P1VUb809`1TUQl0
I9PQ066I9`1PVBd0HID]06:E:@1SUBX0IIHV06RL9P1TXRl0IZ8f06BO>01TUSX0I8do06J<?P1VUS`0
I9hf06FN;@1TXBP0IYdW06JH8P1VUR40Ii8K06b>4P1^R0d0KWl606ik0`1_NP@0KWD3071g0`1aM@80
Lg02071Y0P1YI`D0JVd906Ed2P1SOPX0FhH:05^8300205f:4@0W05Z94`1FR180DXhJ04jC:018UBT0
@iD]03bI?@0hVTh0<iYP036HK@0/TG40:He`02b<H`0aR4T0=h4d03im:@0oO280?gXP041m8`0jPbX0
=h`g036B@@0^V4H0<9]2032M?`0_WS/0<9`h02nJ=00`Tc40<H/W03>26`0fMa80?FX904AJ1014C040
A440048j0010=000@2l00080?R`000<0>B`003PX000h:0000P0j9@003P0f9@00=B<003HS000b8000
;a`002XI000W60009A@0020C000R50008A<001/B000J40006@d0303oool000X0oooo;00000000`01
0@000@000000000500000004004000010@000@40004000L0000000@00@000000000000000@000`00
00005`0100000P00008100020P001@8000L5000:1P0030H000l6000?1@0040L0014;000E30004`T0
01D8000G2`005Pd001/>000N4P009A@002PG000W60009aD0008091D000L091T002PJ000/7000;1h0
02lO000e8@00=R<000<0=R0002H0=R<003DT000h9P00>BP003XX0010;P00A380048e0013<@00AC00
04Dd0019>`00C4000553001??@00Cch0054n001@@000CT<0051=001EE040EUd405aX1`1OL`h0G80N
05B0=P1DJ540FUED05i5I01O>V`0Hd5L06m:D@1bCUX0LE1U079<J`1SBg@0E4V1039JR`806V2F02L0
55bF01];V@0MAYL06T^A01I?S@0IIHl06GVC01b6U`0OQYH088JJ01n4W`0MMJ407EnQ01m9WP0RDIP0
8eVC02EPS`0/IHL0=6R103I^O00iLW`0>GIm03alN@0nP740@X=[04:1J@0nOVd0>7Yi039iO`0dN7P0
=WEd03IhL00eNVX0>7eX03J2H`0gRU`0>hmH03n<G013PVD00P15K7009`18J740F5ic07A>N`1gB7P0
LTAd074lL01]C6T0IUEW05iGJP1NGVT0GV9[05]TJP1LHfD0G5iU05aUH`1BKf00AWMP04=oF`0oQVD0
<Xa_03:>H`0aPVD0=89M03^;EP0kQ5`0?hIN046=GP13TV40@iAI03j?FP0nTeP0?IYG03^MFP0iXEL0
>YeJ03RHG`0iUEd0=IMP03BOG@0203JXG00W03RXG00oWU`0?iEN042CF`11TE`0AH]I0565G01HOEl0
HfmT071TJ@1OJFl0D71]04UdK`16Lg00@GE`03mgM00nOGX0?7mk0421MP16OW80AWaZ04IcJ`11Lf/0
AGEV04^;CP1QYRX0J[0N072`6`1a[Ah0IjdW05fY<01JY3H0EY`m056Q?`1BZ4<0Dj]605NT?01NWS40
K:DS0080LjdG02L0NJ`@07Z^4`1c[AP0LJhQ07B_;P1b/300Lk4[07>b9`1_/b@0J;8T06Rc7`1//Q/0
JZhG06RZ6@1YZAT0J:lO062`:@1N[c80Hk0i066a>@1R/C`0IZlm06N_?P1_[CH0KZhf06j^=01][S80
KJP_06bS;01^Xb/0KJ<V07>T8@1fY2@0MZHZ072Q;01^XBh0JZ4Y06VP8P1WWR400P1WWB@07@1QW2D0
GiLX05nE;@1PTRl0II8]06BD:`1UVBX0HY`U06FR901WXb/0J:4b06FI=P1TTCl0IX]206Z:@P1YU400
J9`f06VO;@1^WRL0KY`W072B6`1bSQD0M8PA07N2301hO@D0LWP0071c001dK`00LfX00080M6`000P0
LFL006YO001/F`40K64206eW0P1[M`<0IH0406241`80H8H;02L0FhP:05J;301CTQL0BY/Y042L<`0k
VT80=hiH03>2IP0gPFd0=h1[03N0H`0mR5<0@h]504N2;@1>NQH0DW4<05Eb201FL0P0DG<904]g3P16
PAT0?H`Y03JB;@0dU2`0<iHY03>F:00dU2L0>8lT03b88@0mP1`0?gPC049Z2@15G0<0BDh104U50016
?P00A3D0048b000n:P000P0m:@004`0j9P00?2H003TU000h9000>B@003DQ000c8000<Qh0034N000]
7000:aX002TG000U4`008a<0028C000Q4P0070l001T>000I3000303oool000X0oooo;00000020040
0080000000D00@000000000100000@0000800002004000d000000P01000080020@00100000D10006
0P002@<000`5000@1`0050T001<7000A1P004@L001<<000G3@0060`001`9000J2P006`h0020@000T
4`00:aP002dG000Y5P009aD002<F000R4`009QH002LI000W7@009aT002dK000b8000=RH00P0g9@00
9`0g9000=B@003XW000j:000?BX0044]0013<P00AS@004@f0014=000ASP004Pj001<@000DTD00516
001?B000CdL005E9001EC@40EeD205IR101GK@X0EgPD05J17@1CQBh0CX15059ZF01LA6H0KCEF06/b
F`1X<V80Ic]H07=7CP1/D5/0JU5U06E>K`1CBGd0AT:;02]?TP0201]AV`0W01e@U`0WAiL09DNE01Y<
TP0BD9404Un@01=^U00GMiH067JH01agV@0OMY/07VbN029KV@0UB9P0:DbG02YETP0YGi80;FN903E]
O`0jMG@0?GYb03enL@11PG40@X5b04AoL`11NWP0?7=l03EYP00_HH00<V=i039TM@0eJ780=W9]03Ah
JP0dO6D0=XIL03V;F@0oReh0@gmW0080@fid02L0BV=g065GMP1nAWL0PD1e07Y1L`1i@6l0LDU[065<
JP1FDFl0EUi[05ESKP1FI6d0FUiX05eGJP1HHFP0CFaW041aIP12N6D0?H9]03B;L`0eQfH0=giT03b1
G00nR5L0?h=N042:G`11Te`0AYQL04FFE`11T5T0@9=J03fKF@0mWf40>j=J03VNF`0eVeh0=Y]M03JM
H@0eXUX00P0hYeP09`0kYeX0@:5F042LE@12Te80AhaB04b7D01FP580GWiC06IdH01^JfH0FgE/04f0
J@14PVP0A85/0425KP0mRG40>H]c03V;NP0nQWD0?h9h03n5K`0kQFl0?89]0461J01:Rdl0IZH^076]
9`1i[200N:`P07B`7@1W/Ah0HjlQ06>^9`1R[b`0HK0a05n_=@1X[RL0M:XM07^Y5@0207f[4@0W07V]
4@1c[1D0L:hE07B]5`1d/1l0L[<Q07Nd9@1b]2L0KKDW06Jd9@1Z/b@0Ik@R06bc6P1//1L0KJ`H06b_
701W/R<0I[4]06Bb<`1W/Bl0Hk<a06Jc<@1X/S40KK4e076_>@1`[CT0Jj`j06ZY=`1ZZ2`0K:HW06jY
901`YR80Lj@X076V:`1]Y2`0JZH^06RT9P1WYB80I:DT0080HjLZ0200H:0^062H<@1OTC<0H8dd06>:
=@1UU2d0I9`[06:P9`1PXRT0Hj8_066L=`1PU3d0HXi506B;@@1XSc/0JY@e06^F:01^Ual0L9<F07><
501jQ0h0Ng/807Qj1P1fN@D0N7/107ah001nM000Nfh007UY001fH`00LF0006eJ0080JUP000D0KET0
06mS001]KP00JW/206>00P0205j71@0W05R91@1FS`/0CiTH04:P:00kXST0<iYA0323JP0cLFX0=G5R
03ifD016NcX0Cg`Z05Yf7P1MJA00GF@605mQ0`1RH`80I6H105eW0P1HK0@0DW8804Im3`0nPaD0=h`K
03F=7P0cSah0=XdM03b65`14OA80BG<?04UV201:E@<0Bd/004Q40017?P00ACP004@d0010;`00?R/0
0080?2P000h0>RH003TU000g9@00=RD003@Q000c7`00;ad002hL000_7P00;A`002hK000U5`008aH0
028E0080818000<06`h001P<000G2`00303oool000X0oooo;00000001P010@000P40004000010000
0@40000000<00P4000<00@000000000000002@0000007P0100000P00004000010@000P4000@10005
0000208000T3000>1@004PP001H9000E3@0060P001<9000F2@005`h001/?000P2`008@d0020=000P
40008Pl002HE000/6@00:aP002PI000W5P008a@002DD00809aP000D09aX002XI000_7000=RD003XX
000203`Y0080>BT000/0>R/003l[0011;`00A38004Lf001;>000AS/004E10014@P00AdD004a50002
059?000H059E001AF@00E5h305QV101HL@/0EG`D05>68`1=RcD0AHE504EfE01<GfD0FDQZ06`hH`1f
;5X0HRIR06L^D@1Y@UL0J5=S05eHJ@1YBG40H4Ii04a3Q@10?I<0:T:I0P0R@Id09`0XA9P0<T2E02a5
T`0NC9804E:B011MU00AJIL0572H01I[V@0GIid06F6N01eMV`0REiH09djC02eAT@0]FY80;FBA02m/
S@0fL840>WEf03aiKP0mNV/0@gQb04AiL`12NGX0?GEo03Q_P00aIGl0;EYm039IN00dGG<0<f5`03=Y
J`0cK6`0<g1Z03EgIP0hNfH0?WU^049`M`0204=WPP0W04aIPP1PCGl0MCen07XoN@1h@W80NDA]06a8
KP1OC6l0EE1_05ALJP1DHf`0Dem^05INJP1JFVd0F65^04aXK011HVl0@Fe_03ehM00jOWP0>gaV03Yh
H@0lO5l0@H=N0421H010Reh0@IAI04:JF011VE40?IA@03nED`11W5T0?:1T03VSG@0iWeh0>IiO03ZP
G`0hXV<0>ZAO0080>ZMK02L0>Z=H03nOE@12W4l0A9E>04F@C@17SDl0Ch]?05B8DP1IPeT0GWeT05>2
I@1;RV00A95R04BEH`11Vf40?IaR03^LI00kVFT0?I9/03f?L@13UVT0@IYX042EJ013RfD0Ci1C06VT
=P1eZ3@0NJ//07f/8@1h[aP0Kk4F072`601e[ah0MZlR07R`9@1i[RD0O:/S07^/7@1nZQ/00P1lZaH0
3P1i[AT0LJ`F07>Z4`1fZ140MJXF07J_6@1f/bH0LkDZ06je:`1[/RT0Jk4Y06fb9`1/]Al0JK8M0P1Z
/R005`1X/Ah0I[8T06Vb;`1Z[c00JK0_06Zd<01/]300K;<c06b_<P1[[3P0J:Xe06NW;@1XYBL0KJTS
06fZ:@1_Z2H0LJDV072T9`1]Y2D0JZDP06RR7P1TY200HZPX0080H:Lb01H0Gj@g05jL=P1LUCP0G9@g
066G<`1UWB/0Hj4X066U:P1PYC@0Gim405f@C01PQDd0HX1;065mA01XR3d0Jhhc06j?7`1_Ra40MHH>
07Yn2@1lMP<0Ng800P1iL@003`1kL`00P7@0081^001jJ@00MV<0075M001^FP00JUD006mE001_E000
LUT006mQ001^JP00JgD006Mm0@0205n30`0W05R91P1BT0/0BiPC046M800kX3P0<iiA02n@GP0bQED0
=h1104Ek901DLA40FVX:069R1P1REP<0HUD1069E001UF000I5`0065N001LH`00FFT104ma0P16N@D0
?gh:03n03`11O`l0@W`=04Ab2019JPH0DF45051E0`1CB`00D4<004ho0017>P00B3D004@d0012;`00
@B`00080?2/001<0>2D003DU000f8`00=280030N000/7000;QX002/K000/7000:Q/002/I000X5P00
91D0024E000Q4`007Q8001X>000F300050`000`0oooo000:0?ooob`0000000@00@40008100010000
00000P01000200410003008000000000000000H000000P01000200<0000>008000020@00108000D2
00070`002`8000h3000:0`003`D00107000B2@005@`001T8000F2@0201D:000;01/=000M3@008A40
02<B000T4@008Q80028A000U6000:aX002TK000X6`000P0X6000200Y6000:AX002/N000/7000<1h0
03@T000i;000?Rl00P10<0009`12;P00@Bd0048`0015<000AcL004I00017AP40BDD104U50018B@00
B4d104U=0019D`00CeX0051Q0P1>IP<0C6l7051e301BOA@0CXXQ04b=<`17QTP0@GUF03aYHP18DG00
Ed1`060dK01Y;W00KRYR064RH01`<TP0K4MM06AELP1@EgX0CT^004A8Q@0i@Hh0=C^H02XeWP0202Xa
X00W03HgVP10>Y80>4>B02A<T00EEI004ejB019WU`0GKYT05fNL01YIV`0LC9X084bG029?TP0ZDXd0
;EZ<02mOSP0bIhh0<fj803MbP@0lLgH0@75^045XK012HG@0@fUg03i^OP0eKH80=G5o03=]O00dJgX0
=V]c03E[KP0cJfX0=71T03E[IP0gHfd0>fAa03mMN`17Egl0CEB50080E56802L0FTV606A0P`1]=HH0
Lcak07A5M01cAG80I4Qb05I;LP1>D700C5Y/04mNK01@GVd0DV5]05=UL@1DIFl0BfE^03aMM@0nHg<0
@6Y_04AYL012Kf@0?W9S03igH`13Of<0?h1Y03n:HP0kUe`0>imG03fMC`0hVdh0>J1@03bSE00mYEd0
?:IJ03fTF@0oX5d0?j9Q03jRJ00mXf400P0mX6009`10W5h0@iQE04BDCP14Td/0@i9=046CC@15TDd0
Ai5=04b=E@1?RUl0BhiN04VDG017WU/0A:MH04B/E@13[5H0@ZIH04:SFP12W5d0@YUR04:UG`14Z6<0
@JES04NOG`1EWdl0KZHk07>T?@1iY3@0OZLZ07^]7P1a[aT0N:hM07V/9`20[2L0PZ@Y086R9`1nXBH0
OjLO07^[6`0207Z[6`0W07JX801gYaX0NZ8@07^P3`1lYQ80N:lJ07>b:01a/bd0L[4_076`;P1^[bd0
Jk<[06Bd901O]B@0I;D/06Fb9@1S/b40Hk0U06V_;P1_[380Kj/`06n^<P1_/C00K;4d06VX>P1VWd00
IIdf06BN<01XYRh0JZT]06fY;@1[YbX0K:@W06^T8`1/YQh0K:@G06JU6@1SY1h0HJLZ0080GZ@e01L0
Gilm062L?01MW3h0FYm005VT>`1LXc80GZ4_05fV>01KXD80FY5>05^7D`1OPdX0I89006b0<`1cPBX0
MhHP07J04`1cOP`0NG`507ad0@20L000OV/007Y[000207a[000>07][001lI`00MfL007ER001dG@00
Ke/0075H001^F@00LUH0071H001bG`00LVL006eb001WN`0205in0P0W05b41@1IQ`P0Bi4@046F8P0n
Vcl0?IaA03jIC`11SSX0AglP05I]2@1MH@40HeT0065E001VD000He8006AE001UE@00IU`006=Q001Q
HP00GF@005UV001EJ@40DV/304m/1P1?JPH0CfD404mL0@1DE@40Ddl005A9001EA@00Dd4004i0001;
>P00BCL004@e0012;`00?2X00080>2L001<0=280030O000b7000<Qd0034L000[6`00;A`002/K000Z
6@00:AX002XH000Y5`0091H0028A000O3`007@h001T<000G3@004PX000`0oooo000:0?ooob/00000
00@00P0000<100020@000@000P010@000`0100000@4000410009000000800P000P040@000`050@00
1`8000T5000200`5000>00h5000A1@0040D00188000C2@0060X001P9000H2P005PP001X:000I3000
7`d001lC000S500202@E000@02LE000V5`00:QH002dM000Y7000;A/002lO000Z7@00;Ah002lO000b
7P00=24003TR000i:000?Bd0040a0080@cD002L0ACH004Dg0016>000C3/004m5001@C@80BU@304YE
0P1=E@80C5T504]Q2@19IPX0BF/;04Yc3P1:N100B80C04J67018SBH0BHhc04F<A014Pe80AFmP049I
J`18D6L0GT5^06LgKP1U=F<0KS1X06lbG`1W=5h0J41Q069@K@1CEgP0AU:804A2TP11?iD0?SFL03df
W00f<Yl00P0g;Y`09`0i=YL0>SbA03A3T00VBY006U:?01QJS`0GHYL06FVO01iQW@0OEI/084FG02E7
U00VDhl0:Uf<02aVS00^KH/0<G>803AhOP0kNW@0@7A]04A[K@13GW40A5Ie04=OMP0oI7X0>F1o03Y_
O@0iMW/0>GUj03]iL@0jN6d0>7=Y03QcH`0lJFT0@5Qg04YAO@1@Ah@0FD280611Q`0206I0QP0W06hl
Q01`?XD0Lc^707=1O@1]AW@0I4Id05Y;L`1ACW40BTmb04eIJ`1;F6X0CEU_04aQK`1=I780CVI`04=V
L00dI7T0=fm/03]dI012Mel0AGYJ04AjF`14O5h0AH9O04:4I`0lT5d0>IUJ03JOF@0iX580=J=B03VW
D00kYE@0>j1K042RE@0oXUL0?:=M03bUH`0nY6P0?Z5U0080@9iY02L0@iaP04BGD`17UDP0AIQ404JF
AP13UdH0AII304NDAP1:Sd/0BHe@04R?D@18UTl0BIm:04ZZBP18/D/0AZe704RYBP17Z4L0AjQ604VX
B01;[4X0C:eI04j/FP1AZe<0GJM<07:V@01hXT00Nj@h07jY<@1i[BT0LjlW07V];01gYcT0Oj4l08JF
@021U3T0O9<f07VY901f/1h00P1i[b409`1hZb80NJHI07^R4`1lXQ00OJTB07V_6@1a/BD0LK4Z07B^
;@1`/2d0KK0^06Fc;`1R`2d0H/0W06Zc8P1^/B00K;0O06J`9P1V[bX0J:l]06j^;@1_[300Kjlc06^`
=P1YXCP0J9@l06VG<`1YVC00Jj<^06fX;`1^ZBh0KJ</06^L:P1XXb@0IZTR06NY7@1UYA/0HjDP06>V
;@02062U>`0W066R>P1RXCP0Gj8l05ZYA01LYdD0FYi505VKA@1KWd`0FXmD05imD`1PQ500I8A306Z3
:P1_P1T0LWLB07Qd3@1fL0P0MFh407e`0P1oK`00Pg8007m`001mJP00OFP007QV001iI@00Nf<007YW
001fH`00Lf80071O001cG000KUX006mH001/F000KU`006iP001/J000Ifh00080HW0102L0GWX205an
101ARPh0BY<R04VD<P1=TcP0Dhda05Ik7`1JJ0T0H5d1069F001SD`00He4006I=001SCP00HUD006=G
001XF`00IUd006=O001QG@00GeX0061J001OE@00G5<105eE0@1MDP00FT`005Q:001DA000DD00058o
001@@000CC/004/i0019=@00@c8003l/000j9P000P0e8`004`0c7@00<A/002hH000Z6@00:aT002lJ
000]7@00;1/002/K000W6P00:1L002LH000T5P008Q<001l@000M3P006@`001P;000C2P00303oool0
00X0oooo:`000000100100000P40008100010002004100<00@0000<000000040000200000`010000
0`0000000@000040000200D1000H00D200080P002P@000X6000>20003@X00108000B1`0050H001@:
000C1P005@X001L:000H3P005`l001/=000L40008A8002DC000R5`009QL002@F000W6000:QX00P0]
6P000`0_7@00;B4002lO0002034Q000803<S000d9000=B<003PU000h:@00>B`003d/0011=00204Dl
000W04]0001:?P00BD4104e40@1>C`<0BeL704]O2@1;H`T0BfP=04a]4`1:MQP0BG/K04N18014QBD0
A8/[04B?=017TT00Bh];0561D01BNUT0D6mQ04mMIP1DCFL0IdAR07hmH01f=F00K2iS06laH01[@5l0
J4eM061BL@1VCX00GDR604i2S`1=>ID0Bc^H04TfX015>9l0?C6O0080>2bK02L0=SRD0350T00/AXl0
9DZA021>T00ODi<085VJ02IMWP0SEj0094fJ02I3U00[BXh0;5N;02aVS@0]Khh0;gB;035iQ`0hNgP0
?Ga[049hI`19LVL0Afa[04MUKP16Ifl0@fUb041UN012Lg@0AGea04J1LP16P6d0@WY]041_K`11K6T0
BUib05U:O01QB7l0ID6506`kQ`1]?8D00P1c>X@09`1e?X@0M46107A4P@1_AWX0Hdad05Q>LP1CE700
CeA/04iBJP1=EVX0BeM[04UFK01:GV/0BEi`04IRL@0mJW@0;Vmj035jJ00hP5/0?X5J04B4E@18PeH0
B8EH04N9F@13Seh0?YMH03RKEP0cX5@0>:9B03VUE@0jZ580?:5F03^DG@0nUeP0?IaJ03VMH00mWV80
?J1U04:MH`0204BIJ00W04>LF`13WTX0AIe004VO?@18WC/0BI`f04^L=01;VSP0BYLj04ZE?P18V3`0
B9dl04bT>`1?[Cl0DJi204n[A01@ZTH0CZe104j/=`1?ZcH0Dje005>_D@1F/4h0Fji806NVAP1fWch0
NiE307^P=P23Yc<0OjT^07VY<P20Y3P0NiM6086EB02?RTT0PY5307JF?`1g[B/0Mk<V0080M[8V02L0
MZlV07R[7`1iZ1H0NJHB07N[4`1h/a`0M[4W07N`<`1f/3L0MK4b06nb<P1[/S00K;@^06bd9`1^]1h0
L;<L06n]6P1`/Al0JK8U06Vb:@1[/Rh0Ijda06Za=P1Y/S`0K:Hh06^M<P1^XBh0KZH[06jY9`1_ZRT0
KZT]06fT:P1_XRH0JjDR06RY7`1VYad0IZHN06BU901QYBh00P1PY3H08@1NX3D0G:4`05ZT=P1IZ3h0
EjE005ZRA01IX4P0FiQ?05f2D`1PKe00JGE806el=P1_O1/0LW4:075Y0`1cI000LV<007IX001iJ000
OFX007mZ0020JP00OFH007]T001eH000Mf4007UQ001hH`00M680079O001aG@00KEL006UD000206UB
000406MD001XEP00JEd006UQ0080IV<00140IFT006Ea0@1ONPD0G7l<05Yo501LO1D0H74B069U201R
E`40H54006E?001RCP00Hdh0065@001RC`00HU8006ID000206IG000406AG001SE@00He8005i@0080
GDX000h0GDH005a8001LB000F4@004ln001>?000CCd004`k001<>000BSP004Xe0016=000?Rl003`]
0080>B@001<0=1l002lM000_7000:QP002XJ000Z6@00;1T002/G000[6000:1P002LE000V5`008aH0
028C000N4P007@h001/=000E2P004@T000`0oooo000:0?ooobT0000000H00@000081000100000@40
008100010002000000800@0000L00000004000020@000`40008200020@000@4000800P0001L00`40
00@200040P001P@000X6000=20003`L000h:000A2@004`L001D:000D2@005``001T>000L3P006a00
01hB000P5@008QD002<B000R50008aD002DF000202DH000A02TH000Z6`00;a`0034N000d7`00<b80
038T000f9`00>2H003TX000j:@00>BX003PZ000j;`00?300044c0016?P000P18B0009`19CP40Ae02
04]@0`1<D`<0B5/804QU4019KAD0Bg8F04ai7@18PBD0AXP^04>;<@10T3d0?Y1503f@B`16ReP0D8=R
05YhH@1OKUl0GfMV06=NJ@1WCfT0KTaP07Q6FP2@=5/0PC5D07@WF`1]:eP0IC]K06M7F01JDGP0HTV=
0611T@1N=I40H36A05XfW01E=ZH0C3NS044^XP0203PXV`0W02lfU@0X@hl09DV?02E9T00RBY<09TZE
02e:VP0cAih0<DFL02m3V00]@9D0<4b@02iNT00]Khh0;WR?031lR00bNX40?7a`041jJ015NVL0AG]V
04AiJ`11MG00A7E_04EdL@13Lg80BG]W04b0HP1<PV<0DH1R04]fJ@17IG00B61e05eCN020@gX0PT9i
08=0O`22?H40NSio0080NSn202L0NdB007U8OP1eBg`0JTih05i@LP1;E7<0BeU/04iLJ01?EVT0CeMY
04UKK@16G6l0Bf9/04AQK010IVd0>W1^031hL00bPFD0>8YN03f:G@11REL0AhEI04R8F@14TEP0@I]N
03jLEP0hWE80=iiA03bPC@0kY580>:IB03VJEP0jQV40?hUO03b;H`0lT6<0?IMT03fKH`14Uf<00P15
U6<09`17Ve@0Aj9304VO?P1;XSd0C9li056Q<@1>Wbh0CI``04^H=@1<UcD0CYTb052P<P1@ZC40E:dc
05Z/?P1IZS`0FJU005R[>`1H[Bl0FZda05^/=01L[4<0IJi506R[@`1_Y4<0NI=107Z0A@1kTSh0O:8i
07VP?P1jVT00Pi1308MoC02@Qd/0UXY:08:HB@1bYd<0MK0j07N`<`0207>_;P0W07:a9`1e[1d0NjPG
07FX501bZaD0Mk8P07Bb9`1d/bh0L[8g07Fb=@1f/C<0L[0`07Fc:`1^/bP0KK<V06fb8`1][a`0K[8K
06Ra8@1U]R@0J[D/06R`;`1W/C40Ik4e06b/=@1ZYc<0Jjd^06Z];@1[ZRd0Jj`_06^Z;`1]ZB`0KZPU
06fY8P1[Zb40JjPO06RY8P1UYbL0I:<b0080HJ8i02L0GIdg05bK=P1IVc/0FYm005VP@@1GX4L0EiM9
05V9CP1MQ4P0IX0l06mn9`1fM1T0Mf/=07=S0`1dG`40L5`0079M001eH`00N6H007YW001mIP00MfH0
07QR001bH000MEh007MM001cF@00M5T0079H001]E`00KeT006aB001YCP00Idd0065=001UD000He<0
06EG001VF@000P1VG0007P1XG000Iel006IX001SJ040HFD1065R0@1UF040I5@006=>001RB`00HT`0
06A>001RC`00Hdl006I@001UD@00IUD006M@001VCP00He00065?001PC@00G4/005]4001I@P00FT00
05Y3001HA000E400054o0080D3/000L0BST004Pi001:>000BCH0048d0010<`00?Rd00080>RH000L0
=240030N000_7P00;1/002TJ000Y6000:AT00080:AL00P0W5`00200T5P008aH0020A000N3`0070d0
01L=000E2@0040P0303oool000X0oooo:@0000000`020@00108000410002004000@000000`010000
0`030P000P8000@1000200800003004000040@000`<000801P<000`02`@000d8000@2`0040/001<9
000C20005@X001D<000G2P005`l001dC000R5002024E000302PG000V6P008aL0008091@001@09AD0
02HG000V5`00:AP002XK000_8000<b8003HR000f8`00=bD003/X000i;@00?Bd0044^000o<P00@S@0
044g0011>@00B3l004a;0P80BUH502L0BEh804MT2@17H0P0Af@904MZ3`19LAP0AgXN04R08@18QBT0
@hT`042A>`0nUcl0>9Y503RBC@0iQe/0Ag]W05IWM01SH6X0IF5R06EMK@1^DW00LdeZ07i6F@21B4`0
QcU<07HcD@1X;eL0GCQH04a6IP1:C7D0Cdj=06TjX01^<IT0Lb>@07@US01Z;I/0HRnW05@^Y@16:Yh0
0P0m:IP09`0i=I<0=46@0398T@0`BI<0;4ZH02i9V00aAiX0=4>K0391UP0`@Y<0:d>C02eCT00]JHl0
;gN=02ekR00cNGh0>GEf03ejJ@0oNfL0@WaZ04>0J@0nPV`0?Wia03inL`0oP7<0?gmc04AoI@16PEd0
Bh=K04ioGP1:MFL0AF=g04mJO01`CWT0Ucib09LnM02??W/0QT2208=6N`020857N00W08A;M`21CWH0
NTai06Q>M@1GDg<0A5Eb04EMK@18Ff/0BE=]04aJKP1;GG80BV9_04MVK012JF`0?Fi[03MdJ@0aNFT0
=X9S03Z7G@0oREd0@hQH04B9F@15SeP0B9IL04BNHP11WV00?IiJ03bOD`0nWdh0>ImD03RNE@0jVUX0
>99P042BG@13TF40@99R04>AH@15TV00AYEK0080AIUG02L0Bia804jQ@01BWcd0Dj4g05>R=@1DX2h0
E9P_05:D<`1?ScP0DHdk05BB=01NWC00Hj@d06BX=P1/YcH0IZDe06>T>01QXSL0HjHc06RT=01WYSL0
JZU006nVAP1bXd@0NIQ707Z8B01gNDX0NHM307^@@P1gTd40P8]908J0B`2GK4h0VWY;09j4B`20WTH0
K:]5076/?@1cZD000P1/ZST09`1X[RX0LJdR07JX6`1bYa/0LZPK07>/7P1`/BD0LK8/06ja<01g/S@0
MZla07:_<01]/R/0JK</06Jb;@1P[2`0I[0R06Ra801U]200J[@R06^d9`1X[RX0IK4/06>`<@1X[S40
K:`a06f[<@1YYc80JZX_06^[;P1Y[2h0Jj/X06b[8P1Z[280J:/T06VX9P1XZb`0IjP`06VW>00206BS
>00W066O<P1QVc00HYhf05nO>`1PW3h0GiI705^3C01PM4`0I8<n06N79`1dOA80Lfd607MS0P1cG000
L5`007=I001eG@00N68007UV001iI`00N6@007ET001hI@00MV4007IN001dG@00MEP0071G001_FP00
L5P006aJ001YEP00K5@006U?001WC000Jdl006EE001UFP00J5H00080J5L000@0J5H006IG001XEP00
I5T00P1SD`001@1YD000IDl006A>001SC`00HTl00080He000P1UDP00601UE000J54006MB001TD000
HTh0069?001RC@00GT/005i7001LA@00G3l005U1001G@000FCd005I0001C@000Dd4004Xl0017=`00
B3P004Hb000o<P00?Rl003dZ0080>2L001<0=B4003@O000a7000;AT002`H000X5P00:1P002PG000W
5P009QH002DF000S5@008a<0020B000L4@006Ph001@=000C2@003`H000`0oooo000:0?ooobT00000
00<00@400081000100001P000003004000800`8000H00`4000<0000200000P4000@10005100200/4
000W00h6000B2@005@`001D=000D3@0050/001H9000F20005@X001`=000S5@009aL002@I000W6`00
9a`002TM000Y6`009AP002DJ000W6`009aX002HH000T5@00:QH002`N000d9@00=R<003DT000i9@00
>bT003h^0011<@00ACH004@i0017?000AT4004E60@15C@80AUT60080AfD=02L0AF/D04=^4`1;K140
Ag0B04Qb6P1:NB40AglU04J;;P0oSc`0>Ha903R<D@0eTDh0<hm@03R2E@0lMF00A6YZ04iLK@1IDVX0
ITa[06Y8KP1`AVP0JdmO079@D`1nBDL0Oci706XhC`1M<ED0E3mF04A?K@14CX00E46;07<[UP1h:Xl0
ORF607XYQ`1^:9P0Ib>U05XTX`1?9I`00P17:IH09`15<i@0ACbB04=3TP0mAYH0>DZI03U9V00hAiL0
=d>E03=3TP0_Ahd0:Dj=02aOS00]K8/0;WJ9031dP00bM7D0=Vi^03afJP0nOF`0@HE`0465K@10R6X0
?hE^0464L012PW40A7aa04EmI@17Of80BH9R04QoHP19LFh0C5Yl05]@N@1gAG80VC][090lK026>gT0
Od:407e>N@0207UDL00W07]FL01jEg<0MEUh06QKL`1IG6`0B5]Y04YKJP1=F6l0Ce5d059FLP1DFg40
Df5_04YYKP0nKG40>g9`03EeJ00_LV`0=WiW03^4HP0mPf<0@hYM04>AG`15UeX0AiYJ04JNH@16WEd0
@9]J042KD`10V4l0?HmF03^DG@0jV5l0?9IT04JCH@16Tf<0?iEX042>I`10SV@0@YYB0080A:9302L0
CZ8k05JO=`1KW3H0GYd`06:L;@1NVRh0GI0g05b:>@1IP3/0Fh8i066:<`1/TS80MiHb07VI<P1oWBl0
OYdc07BM<`1bVC/0NILi07JE=`1bVcL0L9hm07RN@`1jW4@0P99807^8B@1jOD/0OH1807j5B020QdP0
Sh1?091gBP2EJ580U7E<0926BP1kWT40KZ@m07BV>01bYSd00P1][3d09`1[[bl0K:lW06f/8P1_[B80
L:dS076]8@1^/2H0JK8/06b`;P1b/Bl0M[4^07>b;01//b/0Ik4/06V_;P1^[R/0KK4O072`7P1^/A`0
L;8N06n_8`1[[BH0Ik8X06Bc:@1W/RL0JjlX06^[;P1]Z2d0JjX^06V[;@1XZbh0JZXU06RZ8P1X[BT0
IjT_06RU<`1UZCP0IZa006BZ@00206>Z@00W06:W=P1QYC40G:8f05jM>`1NV3`0GY8l066;>01UORd0
LH0P07Qo501hM@P0MfT107IP001cG@00KUX0071I001fG@00NF<007QV001gIP00MfP007IV001fI@00
MFH007=P001`G000LEL006mF001`EP00KEX006aL001/F`00K5@006QA001TC@00HTl006A?001TD`00
He800080Hdl00P1PC@009@1PC`00H4h0065=001TCP00Hd/006=<001OC000HD`006=>001QCP00HT`0
06I@001WDP00He<006Q@001VD000IDh0065>001RCP00HDh0061=001PBP00GTL005Y2001I@@00F400
05I2001G?`00E3h0054o001<>`00Bc@004Dc0012<@00?S0003hY000l:0000P0h9P004`0f8@00<Ql0
030K000/6`00:AP002LF000W50009Q@002HE000V4`009AD002<B000Q4@007Q4001/?000G300050/0
0149000=1@00303oool000X0oooo:000000200400003004100000000000000D0000000D00@000000
000300000`4000@1000200D2000400L100060@001`<000X400802`H001/03`T0018:000E3@006Pl0
01X@000I3@005`/001H:000I2`0070l0028D000V6P00:A`002`M000^7000:Qd002XN000[7P00:A/0
02PL000V7@008aX0028G000V5P00;A`0038Q000e9`000P0j9P002P0l:P00A30004Tf001;?`00CD80
04U5001;C040AeT404EP2013KA0203ec6`0W03ai8`11N200AWLJ04Ii7018O200A80Y04>7<@0oTSl0
?9=903V=D00iQU40?7]=045bD@12JUP0A6IN04IMHP1@DV80Ed]P05m1I`1X?VD0JT9S07=;E@1jBdh0
PTE<07lhD01Z=eL0GCIM05A3HP1<CW80E4Ii068bP`1g98@0O2R2084ZOP1j:hD0L1nD06dBX@1R6Il0
F22J0080DBRF02L0E32D05PgU@1E?YH0Cd:H04]6V@17B9@0@DJB03U4T@0bAhl0;4j<02MIR00/JHD0
;g2702ibR`0^Kh00;f]f03=VL@0hM780?85d03n<L`13RV`0@hQV0425IP16QVL0Bh=W04YjJ@1=NV@0
DGiS04f2IP1:PFX0DFa^06E=L`1c@fd0QSY/0:8cJP27>V/0MSYk07E0R@1_CWX00P1YEg809`1YFW80
J5ee06ILO01OH7<0EV1Z04]NJ@1:GFd0C5Ue04e>OP1?E7D0CUIc04eNL014JG00>g1d03EbMP0cM6d0
<75^03MkI`0oNfD0@WMU04>5H013U5l0@YUL04>JE`14WE/0A9UH042JEP0oVU80@iMA03j@G00mTEd0
@IAR042CJ@15Tf<0A9=W03bGJ`0lUV/0>IaP042RB`0204JU>P0W056Q<P1KVS00H9La06:I;@1SURX0
Hi8Z06B<;P1ZRbh0K8P_072><01dSR`0OH/T086:8P27S1l0SI<[08VA>@1iV3P0M8m207V<@01kS400
NI1007RE?P21Td@0OI94082>B01iQ4X0NGa<07mnC020Me80S7e<0:1lBP2FLDh0UfMA08ihC022QDT0
MIA006fC?`1]WSP0L:Hl0080KZdo02L0Kk4`06fb8P1/[ah0LZlP072_8@1a[b80KK4T06j`9`1_/BT0
LjlZ07F_:@1c/RX0Kk<Z06Zd:P1_/RP0L:lU076[7P1eZ1d0LjlP07>_8@1a[b@0KZhS06f_8`1[[b80
JJ`Q06j/901`[2P0Kj`W076X901_Z2T0JjX_06bX9P1ZZB40JZXY06Z/<P1VZcP0IJ`o06:_B01Q[TT0
0P1PZdP09`1PYd<0Hj50066K@@1STT00GX/k06>;<P1WRb@0Kh0C07=`301iJPD0M6H107=S001_G@00
KUP006aF001]EP00LET0075L001cG000MEd007MP001dG`00Mf4007MP001dG`00LUT0071I001^D@00
JeH006]G001YF000JE8006Q?001RBP00HDP005e5001PAP00GdP0065:000205e7000605i8001PAP00
GTP005i9001OBP00H4X00P1PB`007`1PBP00HD/0065<001OB`00HDH006==001SC`00I4l006E@001V
D@00I54006E?001SDP00HE4006=@001QCP00GdL005i3001J@000E3l005<m001B?@00CcT0058k001;
=P00Ac4004@a0010;000?Rd003d]000l:`000P0l:0002P0h8`00=2<002lL000/6000:QP002HG000U
50008a<0028B000R4@02028B000701hA000L3`0060d001D<000D2P0040L000d5000<0?ooo`002P3o
oolX000000030041000100000@0000<0000000D00P000040000000000000004000020080000800@0
00050P001`8000H40008100020D000`4000?0`02014500040189000C2P0050`001P>00807Pl00240
5`l001T=000K3@007A00020E000U5`00;1`002`M000[7`00;b4002dP000_7`00;1l002TQ000X7`00
9ad002LH000]6`00=20003/V000j:`00?B/003h/0012<000B3H004hn001@AP00DDP004m>0P1;G0H0
@fL>03ib600mMb000P0kNRL09`0nO2L0AG/R04Yj701<OAd0BX4N04J7:00oScL0>iA603RCD@0fR5X0
>G]J049XF@19H5`0BF5I04USE`1;GEP0E55N06E4GP1^?V00MC]J06Y2H01`AE`0Od1K08TnF01i>U`0
H3MW05LgK@1K?g<0K3if070gLP1f8WP0Oaad084VN@23:gX0P2R407`MTP1l4Y`0LARJ06LOUP02068U
U00W05l]U01N<iD0EcNG04`mV@14@YH0@4RB03Q>T@0`D8h0;EN>02eTQ`0[KhD0<7J2039fQ00bK8L0
=FR003IVN`0fIWT0>GUg03^9M`0mTGP0@8Y]0463I`0oOFL0AgeW04aiI01:LVH0DGAS051nHP1>QFL0
CGe/05eSI`1g?eh0OCaL08=0G@2K@5d0ODAO06e0K`1a@800J55f0080FeY`02L0F5eb05QNM01IGGd0
EUec05=TJ@1<Hf/0CFA^04]MMP1<Cgh0CE5f04UFLP15GW40?FYc039^N`0`L7T0;gQd02ioL@0iPVH0
A85Q04UnI@1<RUh0BiEP04JIFP16VUH0@YQJ04:GE@11V5D0@IUC04BGEP10UUh0@iEN04FCHP10T6X0
A99V04>HJ@11WFD0@jAR04:TF01:XT800P1?VcD09`1FUS40G98`05n?<01PSc00HXd/06><9`1ZQRP0
LH/T07JB8@20URD0S8Pc08^58P2=S1X0S8`N09:9<`27QdD0NX]40768B@1cQdH0N8M407J5@@1iRSh0
OY1307n=A`21Qdd0OH5>07]eC027L500SVQH09UgD02VMTh0WGA>09EbDP2;Nd/0O7e<07R6A`1aQD/0
L9A206ZRB00206ZXA`0:06^_>P1[/2/0K;0Y06ja:P1`/BL0L[0X07>a9@1c/B@0LK0V076`:@80Lk4Y
01/0MK0]06n`;P1c/BT0L[0R07:W8@1eXb80L:dU076a901`/280KZlM06f^6@1][AD0L:LB06fU5P1_
YQX0LJLM07BV8@1cXbH0KZ8Z06^S901/Y200JjDT06ZU:01WZ2`0IJXa06J]?P1UZD@00P1WYDD0401]
WD00LYTg07:D=@1`Qbd0KgdZ06]n7`1_OA<0LgH907E[0P1cI000M6<007EN001cF`00KeH006UB001^
E@0206eF000E079I001bF000M5X007MK001gH@00MV0007IO001eGP00Le`006aG001/E000JeD006YB
001VD@00HDd0065<001NAP00FdH005]7001QB@00GD/00080FTP00100GDL005i6001KAP00GDL005i:
001PB`00HDX00698001NB`00H4/00619001PB000Gd<006=9001TC@00I5400P1TD0003`1TCP00IE40
06=A001QDP00H500069=001NB@00FdD005M2001C?000CS/004di001<>000CcT004`d000204P`0004
04D_000n;@00>bd003XZ0080>RT001<0>BD003HR000_7@00:aP002XH000U5P008a@0024B000O4P00
7a0001lB000M4`007A4001T>000G3@004`X00189000>1`002P@000`0oooo000:0?ooobP0000000X0
0P4000410001000000000040000200000P400080000100000@400P0300002@040@000`8000D20008
0`002@D000X5000<1`003@D000d600030148000H01@9000F300060`001`@000N400070l001d@000P
40007a80028B000X5P00;Q/002hM000a8`00<R@0038P000_7`00;24002dR000]8@00:b4002`Q000d
9000?B/00P16=P003017=P00AC@004Pd001=?@00ED8005U;001FD@40DEd504Q/3P12NQ`0>H0/03R2
<@80>h8i02L0@8<b04>5:@13QRP0B8LX04B9;P0nScH0?IDo03VHAP0gUTP0=HY@03EnFP0oK600AEY/
04aEI`1IDF80HE1T06E>IP1_AFL0MS]^06llI`1V>VT0KcMV08HbJP2K;fH0Q3AS06/dJ@1X=fd0KcQg
084bN021;780PB9`088QK@1o9W/0OB>6080QS@216i@0QQJI07/KUP1a8I800P1[9i409`1X;Y@0Hc>H
05TfV01=>IH0A3bC03]8SP0bE8/0:Eb902QVRP0/KhL0;WV5031jQ00dMh80=W2403a`O@0nMGL0?Gaf
03j8MP0mSWH0>heg03n1LP10MVh0@F]`04Q]J`18KFL0AVMX04e[H`1>MFD0C7Q]05A[L01VCf@0NcEG
07hiF01kA5/0PdYM0797GP1W@f`0HDAf05eEL00205AQK00W055VJ`1?HFd0D5Ua059IK01AI6D0BViS
04eYIP1=Gg00Cdam04]BM@0oF7D0>69e039]M`0/JWd0;6in02amN00[RG@0>hUV04J7H`1;Pf<0DX]I
052@E@1=U540CY=B04^AEP18Te<0A9AH04FFFP15Ved0?ieT04BLG`14TEl0>hYV04BAHP12Vf40Aj9E
04^SA`1?Wd00FYHh0080G8hc02L0HH/_06>::`1TR2T0I8LX06R58P1[PAd0LH0L07Z:7`1kU280Qi4X
09an:P2EP1X0VH<N08n6<028QCh0OW]<07N5B`1jPd/0NWm707amA@21ODL0O89707j7B021PD`0Ph1@
08AfC`26IeL0T6AG09YQGP2NLU80[7E;09MjC`2?MeH0QWa?07]kD01hR4`0LYA;07:QB01/Xd`00P1W
X4l09`1XZd80K:di06na>01a/SX0MK4e07Fb;P1g/RP0L[0V072]9`1^/2X0LJl/076`;@1d[300M:@b
07:/9@1^[1h0L:TK076W7P1bZbD0MK0T07Fa801d[QD0LJdA07BX3`1aXPd0KYl@072Q4`1aXad0KJ<W
06nM:`1ZX2l0Ij4[06bX:01[YRT0JZHX06FS;@1RXC40I:8i06NO?00206ZN<@0W07>G7`1hTQX0NXdE
07N34@1gO@l0MGD;07A]1P1eK080MF`007AV001gI@00Mf8007=Q001aG000L5/0071H001`E`00KeH0
06iF001`E000L5L007IK001fGP00N5l007IO001bGP00M5l0075L001_F000KUH006aF001XDP00ITl0
06A>001RB`00H4X006=;001TD000H4h00080G4/001L0FT<005I2001F@`00FD@005i6001MAP00H4X0
05m8001NA`00GTP005e;001LA000Gd@006A7001RBP00I4/0069>001UCP00IDd006I?001RCP00H4h0
05m:000205e6000>05]5001F@000Dc/0050i001@>000DS/0054h001;=`00BCD004Pb0013<000?c00
03`/000j:00203TV000C03HU000c8P00;Q`002/H000X5P009Q@002<E000O4`007a4001hA000P4000
7Q0001/@000I30005P/001<;000?20003PH000P3000<0?ooo`002P3ooolX000000800P4000D00@40
000000010@000P80008100030080000:00<000030@001@8000P3000:1@003@@000l5000>1P0040L0
00l700<040L002L04`P001<9000E300060`001/=000L4P0080l0024D000R5@008Q8002@D000V5`00
;1`002dP000b8`00=28003DT000`8P00<R80034S000a9@00<bL003PW0011:`00BSH004Xn001<?@00
CC/004Xi001??000ED<005a:001KEP40F5l504m]2P14NQ@0?H4M03V59@0kRBD00P0lRBL09`12RR80
AXdR04J?8@15TbL0?iH/03ZH=@0iVST0=iU003>DA`0aR5H0;GMW03Y]KP14FWL0ADao05Y8N`1XCG/0
MDA`07<lJ`1c=6H0L3QT06dgI01h>5h0PCMR08LgI01a?6T0Hcea06XlM@1l=GT0SRYj08dXL`299F/0
PBE_07/NP`1k49P0Q1BI08hGU`2F69H0RajB088RSP0207TWS`0W078^U@1Z=9X0GCFH04deU@12>8l0
>4J:031FQP0VHX<09VZ402efPP0_OH@0<g^003EeP00iKh00@7Ij049lM00nPWD0?hMb03j5LP0lP7D0
?W=e049[LP13IW80BFE]04MVJ`16H6X0B61X04eSJ01HGG00IDi_06lmI01k;5@0OCMK07a1IP1mBW00
K4=]05i3L@1?AGD0CeMa0080C6E/02L0AVe[04EVK015FVh0BUaX04aYG@1:L5X0Bf]S04aUJP1:FgH0
@f9`03i[K@0fMG40;gEf02MZO00XKW`0:geg02n9L`0kSFT0AXmS052:HP1ESUH0Di5D052@E01>T5@0
BHeE04R>E@13T5@0@IEE04BIFP12WV00AiaH04J>G@12Q600B8iD04ZKC@1BW3X0FYTW062D6@1YSQT0
0P1^R1T09`1`PaH0KGlG06mk5P1aN1<0LgT?07Ek301iO@d0PhXG07n?;P2<Qbd0ZgHG0:9l5@2KObH0
Th<k08F8?P1iOTd0OX1?08UlD02=ODh0R7U?08UjE01mNe80P7UB07iiDP20N5<0Sf]C09aPEP2IGeL0
UV9K09Q`C@2JNDh0SXAC08eoF@2:OU80PWa@07ZBB`1bXDD0KjY006ZZA00206bTBP0W06nW?@1_Z3H0
L[0c07Ba=P1g/C00Mk0/07Na:P1a[bD0KZX[06b[<01^[Bl0K:T]07>T<01hWS00LjLQ072/6`1bZQP0
L:`J076X9P1`[2D0Lj`S07B_5@1cZPl0LJT<07:S2`1_X0/0LYl?072R6P1^Y2T0JZ8_06RQ<P1WY340
JJXf06N/=@1XXcH0J9Lm06ND?P1ZUSl0KYTd0080LiTL02L0N94>07F<2@1gQ`D0NGl207Mf0@1dK`00
N6/007AZ001`I000Lf40079P001eHP00M6D007MV001gI000LF8007=N001_F`00KE@006eC001bFP00
N5d007IM001dGP00LUX0075H001bG`00Leh007EL001cG000Ke`006eK001ZF@00IED006E<001RC@00
H50006=@001OD0000P1QB`009`1LA`00FTD005]7001NBP00HD`0061;001OB`00H4H005e8001QA`00
G4D005a6001MA000GTX00658001RBP00I4d006A<001PB`00HD/005i:001OB000GDD005]5001G@`00
FTD005Dn001E?000E3/005Dl001G?000DSL004he001:<`00AC8004D/0010:`00?RT003/W000203HV
000C03DV000a8000;1d002`G000W5P0091H0024D000N4`007a8001d@000L400070h001T>000E3P00
4P/00107000?1P002`@000H2000<0?ooo`002P3ooolY00000006008100010@000@0000<100030P00
0`400P02000030030@001`4000L100080`0030H00107000@2@004`T00189000B2P003PP001870080
4@T002L04`X001D=000H30006@d001/>000K4000818002DF000W6P00:1L002DF000W6000;1T002hN
000`8@00<bD0038S000c8@00<240038U000f:@00>2X003l^0018<`00C3T00510001??000D3d00591
001DA@00FU0105eK0P1II`H0DW<<04Yl5012QAP0?hTJ03b:700nSAl00P0mSah09`12T1/0@I8K04:D
8@10VBT0>i`[03NL<P0fVcL0=9E1036:CP0bOel0=GA[039XN@13DGl0Ed5i06A3L`1ZD6h0Ld1_06/f
K`1W>FD0JCiP06a1F@1c?5l0LS=W07@bK@1/>Vh0Kcm^07XjM02=:X00WAeo09HRM@2<9FT0Q2Aa080J
Q@2239H0Ra2@098FQ`2J6X<0T1b308PQQ00207`XR@0W078]TP1X<i/0FcBH04PhT`0k>Xl0=TN802mL
P00ZIg`0:fih039aMP0bMGT0=g=h03UcM`0jLWX0?gUe03enL`0jOGH0>Wad03ehLP0mKGH0?fQe04A/
M014KW80AVi[04E_J@15IVd0B5Y`05EDK@1Y@W<0NCa_07hjH@23>580QcmH08Y1KP2>@840MT5l05Y0
MP15A780AeY`0080A6]_02L0@7A]03mZJ`0lG6`0@5aU04ETH016J640AfEV04IWJ`13IG80?G5[03Uk
J`0dPG00;Wea02UcM`0YLgP0<H5b03F:LP10SVL0BI5N04j@FP1AUE80BiQB04JJD`13UU00>YE@03^H
DP0hVUH0>IeK03nLD`11X5l0AYQF04J4E@18NED0D8U805RF>01PTB40Ih/?06f71@1dQ`P00P1jPPT0
9`1iOPP0MgP707Yb1@1kK0<0Ng8107ij1`22P0l0R8lO08Z9=@2FMbh0YG4R09mb9P2@N3@0PH<n07b;
@@1fP4d0QGU?09]eD02PMe<0UW=G091_F`27LE`0QG1J07a^EP1oK5@0W5iD0;EFD`2XG5@0VFEC099`
B`2;MDh0SH9?09>1E02>P580QXM?07bM@P1aZ440KZdn072^@`02072Y@@0W07FT>P1cXcP0MZLc07R]
<@1f[Bl0N[8Y07Rb9@1c/2L0M:d/076Z:@1[Yb`0KjD`07>Q;@1fXR/0Nj8K07NT4P1hXQ<0LjHH06jT
901_YRL0LJLV076Z5`1^YPh0LZ4:07FP201fWPT0M:4<072T4`1]Z200K:LU06^R;01]Y2h0J:Ph06JW
?01ZX3H0JYHc076D;01fTb<0OI4I0080PH`<02L0OHL607b60`1mP`40N7l007Uh001hM000MVd007=X
001aHP00LEl0075N001aG`00MV4007MT001fI000L60006eK001[E`00Je<006eE001bF000ME`0075M
001_G000KET006eK001^G000LEl0079J001^F@00JUL006QI001[E`00Ie40069=001RC000HTd006E=
001SCP000P1QC0009`1NC@00HDd005i>001OBP00I4h006I>001RB@00HDP00617001PA@00G4L005a4
001KA000GTP005i7001TBP00ID/006=:001SB@00HTX00619001PAP00G4P005Y1001IAP00FTD005M2
001I?@00F3h005Ll001B?`00CSL004lg001;<@00ABl004D]000o:P00?BX003XX000203DS000C03<T
000a8000;Ql002/I000X6@0091D002<A000P4P007Q0001`?000L3P006``001L<000D30004@/000l7
000=1@001`<000<1000<0?ooo`002P3ooolY0000000900@1000400000`8000@200050P001`@000L1
00050@001`800080208000D02`D00149000B3P0060/001L<000201H;000[01<:000B20004PX0018:
000F30006@d001d?000O40008Q00020C000Q4P009AL002HK000/7P00:Qd002`H000[5P00;Ad0034O
000d9000=B@003HT000g9@00>2T0040Z0013<@00BSD0050i001D@@00ED@005I2001FA@00F4T005YC
001KGP40E6/704Ql3P13Q1H0?hXQ03^>800nSQP0@XlG04:=5@0204:@4`0W04>A4`13TQL0@YDN042K
9P0jVb/0>9Hf03BA@@0`Q5@0;WMJ03YYI014GVX0?U=_04=2N@1B?gX0GDE[071;G`1Y?fh0J3=m06lg
L`1f?eX0NT5607HiE01/;6@0KRa/070fKP1l>V`0PcEa08`[N`2@8gd0Qb=n07lQO`1m7X<0P1N808/>
R@2@57d0TaQ_09TJJ02A7W40RR9h0080O2V202L0KbnA06<eWP1D>9T0?SnC02i4R`0]DH@0:f9l02U[
M`0^K7@0<Vid03IaM@0kMG@0?7I`03eiKP0nNVh0?GQ_03YbL`0jJg@0?VEd049IN015G7H0AFUb04Ic
L@15MF`0Ag1Y04YUL01CEWD0GTUb06hhM`1i=g<0P49[08A5H@25AF80PT5/07hmN01/Ag@0Fe1]04]K
JP17IfX00P14M6X09`0nNfT0?gAV03eUIP0oGV<0A5iQ04MJJ@18GfT0A6U/045aK@0jNfH0=h9Z03>0
M@0aNg<0<Fee039]M`0gOfl0>h]c04R=H`1@SU@0DI1?04nEC`1:VeX0@I]J03bKDP0cVDl0=ieA03:P
F`0fXEl0?9eD03fJF`13UT`0BH/l04n5;P1QQb80JX8I06el3`1bNPH0MWT107]m0@0207eh0P0W07ii
0P1nM@40OFh107]a001nL040P8DA07j=802<Sbd0ZGDX0:a_9P2]Kbd0WW8j08Eg@@1iOdL0OGm:08Uk
D02DLdP0Y6]10:EXAP2LJTl0UFEH09EVF`2EIUP0T69=09INB02^D4h0_T]C0:]SDP2IL5@0T7I<08Ue
C02CNdL0WWU809YnB@2<S4`0N:M306f[AP1]ZD`0JZQ40080KJLo02L0Lj4m072T>P1cY3H0LjLb076Y
;@1f[2@0MZhR07N^901fZR80MZHQ07:Q8@1bWRH0MilV07VM901jVQP0O9L?07VL401hX1D0Mj@J07JU
701dYAX0Kj@C07>O3`1eW@d0M9d=07:Q3P1bY@l0KjLF06b[8@1`[2X0L:Pc06fT>P1[YSd0JZDl06ZP
;P1`V200O8`E08653023P0D00P21O@809`1nN@40OGd007Yl001iO@00Ngd007Ii001gL`00Lfh007AZ
001dI@00MFH007AP001gIP00M6H007QU001bG`00Kel006mL001_F`00L5T0075L001eG@00Le`0079P
001dG@00LEh007=N001_G000K5/006YJ001ZD`00JUH006ME001TDP00HT/006=:001SC000ITl006M@
000206E@000W069=001RB000HDH00696001SB000IDP00699001RBP00GT`005m8001OAP00G48005]5
001NA`00GDL005m:001OB000Gd/005m6001PB000H4D005i3001OA`00GT8005U3001J@`00ECh005Hi
001E>000E3P004hg001>=P00C3L004Tc0013<000@Bh0040Z000l:@00>2D00080<B8001<0<2<0034Q
000_7P00;1`002TI000U4`008A4001hA000K40006@l001L=000E30005P`001@<000@2P003`L000T5
00050`000`0000`0oooo000:0?ooobP0000001D00@0000<200050P001@8000D4000810002PD000T4
000<0P002P4000/4000<1@0040H001<9000I30006``001/=000K30006P`001H;000C2@000P0C1P00
9`0G2P006`d0024@000N4`009A80020C000S4@008A<002LI000[6`00:AX002PI000Y6P00;A/0030P
000i8P00?BP003`/000m<000@S8004Lc001:=`00DS/005M0001LB@00Fd/005i@001LDP00G5T105QR
001AK0@0BG/=04>45P0nRAd0?HdR03^@8`10U1/0@i8L04B@500204BB4@0W04FB4@12U1X0?IDV03RF
<`0jTCd0>8U803EoE00fM5d0>6UN04=MG@1ABFP0E45N050kK@1I@W80HdQV07a2F01[=eh0FC]R05]9
HP1WBE/0LdAI06/iGP1P;FD0J2aX07D`KP20<W@0PC1i080/PP1o8XD0N1ZA07H?V01m49<0Ra6709hA
N02K5F@0VQUA09XKB@2C7U/0Rb9Z0080OBYl02L0KC2=05lfW@1>?9T0=DFA029>R@0TFh009VMj02U/
MP0^JgH0<F]e03A]M`0gLg@0>WQ`03YiK`0iNW00>GMb03QdM00lL7L0@fYc04MTL`18I6l0BG1]04Ye
J@18L6P0DFQ[05YJM@1VAgX0Jceh070]O01i>GL0ODIe08==L@1oAfd0MD5_06XkM01PDfd0Ef=S04eb
GP17NV000P12Of809`0mP6@0@WYN03i^F`12IV00B6QP04QSIP18JV40B71K04EjF010PUL0>gmS03Eg
M@0jJWH0?eMm045NN@0mMWD0>HUh04:;HP16Se40@YE>04:HEP0nWEl0>YeN03RJD@0dV4d0=9]?03BO
E@0gW5L0@9Q@04:DE`1:Sc/0EHLO05j33P1]O@/0LG4807=Z101eK040NFl007mb0002085d000W089e
0021L`00P7<0081f101oOP/0QY0G08NB;`2BOB`0YFLE09ec6`2PMB`0T7E607afD01`KeP0QFiF09e_
EP2ZJD@0[V<[0:UP=02RG440WE]:0:IOCP2ZID`0]ELm0;]C=@31BdL0`4YB0:mWE@2UMU/0TgU@08ih
CP2DNd<0V7M309:0A023S4h0MJI;06VSDP1YV5X0JYe:0080KZ1002L0LYi0072P>P1]XS<0K:@`072V
9`1`YB40M:DQ07FV901bXb80LIdL07:I5`1bV1/0MYPK07VB6P20RPl0PXX8082A2`1oV@h0NZ0C07ZU
501hY1<0M:4@07:N3P1_X100KZ<E06bZ6@1[[Ad0JjdO06b_9@1_[S80KZPc06nS=01bX340MI`]07RG
7P1nRa00PH09085j0P1nN@000P1oN`009`1mM@00O7L007Uj001lO000O7d007Uj001fM@00MG8007A]
001aJ@00LfX007U[001gK@00N6`007I/001bJ000LVD007=W001cIP00LVH0079T001dH000LV40079O
001cG`00Lf4007QQ001cH000Kel006YK001/FP00JeL006YE001XE@00IE8006E>001UC@00I4h006EA
000206AC0006065>001OA`00FdD005Q3001MB000H4T00P1SB0007`1QB000H4T00618001MA@00GT@0
0614001R@`00GDH005i4001MA@00GTD005]5001MAP00G4<005]4001K@P00FD0005<o001C>P00DCT0
058d001@=P00CcD004`f001;=P00BC<004@a0013;P00@2`003`Y000i:0000P0c90002@0a7P00;Qd0
02/M000Z7@00:AP002DC000Q4P007Q8001X?000201P>000801H;000E2`004@/00107000<1P0020<0
00D10002000<0?ooo`002P3ooolU000000800@0001D00`0000@100060P0020<000L300080`002PD0
00h6000>1`0040H000d5000@1@003PD00186000E20006@X001`=000L300070d001/<000H2P000`0F
20009`0K2`007100028D000S50009A@0028C000S40008Q8002@D000W6000:AT002/I000]6P00:a`0
034R000l:000@2h004@b0016=P00C3L0058j001C?@00FD@005e<001PD`00IeP006EL001MH@40F6P1
059^0P1:N@D0AH@>04:;5`0mSQ`0?HhK03fA7@12UA`0A9LK04FE6@0204>G6@0W04>I7@0nV2P0=i@h
03:;B`0dP5P0=WES03AWJ`0eGFl0?eA]051=J01O@FX0HSMR05`cJ@1R?VP0JdMS0790H01N=6T0DCA[
05dlG@1a>E@0O3IA06l_E@1T8f00Kb9W084QM02>8Wd0QBAn07`SQ01k7XP0NAFH07`:X0243I@0T162
0:0DKP2L5f00VAYC09HMC`2<8680PREb0080Kben02L0GCF:04dkU@11A9<0;U6<01mJQ@0RHg`09VMe
02]ZMP0/JgT0<Fej039]O@0eL7L0=gEc03QeM00iLgH0>7Ig03QcN@0mKGX0@fee04QZLP1;KFh0D7AV
04e`IP1<HfT0F5Y]06M=N01fAg`0MD5f07DkMP1k?W@0OTIe0857N@1hAGH0ITAb05A3L@1DGF<0E7IH
05J5DP19REL00P13QUh09`11P6@0A7]N049/GP14J680B6]S04Q[HP15LEX0AGeA04>8C010QU00>h1R
03QdMP0oJGP0A5Yl04MMMP12MW<0@8E`04::HP10S5h0>HaT03R@I`0fUF/0=iIU03NFG00cU5L0>9IF
03JKE00lUe80BHi605:8@01KQ2<0Hgh=06]f0@1`K@40LV@007=T001cIP00NFL007m/000207m_000W
085/0021L000P7D107n13@1lRaH0SY4U09im<P2DK280UFTC095a6@2DKS@0R75A07ebEP1mJe`0T6UH
0:ESC@2XGT40ZEXf0:IG?`2RETH0XEM=0:YRC`2aHTd0_EI20<9=@02iD4P0[e=@0:QUE@2WJeT0Y7E@
09ieB@2KLd00TWE108MlA`1kQE80Li=>06jGC`1]VE40JYe90080JJ5102L0K:0i06^P<@1]XRX0L:8T
07FO7`1cWQ`0L9lM07:N8@1bVad0L9PH07>B4@1cTPl0MXh>07b93@27Q0L0QX<208>91022T0D0PIP8
07fL2`1lWP`0Mi`<076K301]XA40JjHF06N[6@1X[Ah0IZ`N06^Z801_Z2@0LJ<O076J6@1fU1@0Oi0C
08:93024PPH0QW/307mm0021P0000P1mOP009`1nO000NGh007Un001iOP00Mgl007Mk001hM000MW00
07I]001gJ`00NFd007E/001iK000MfX007EV001bI000LF80079U001bJ000LfP0071U001bH@00LV00
071M001aG`00M60007AT001eH`00LF4006iL001/F@00IeL006MC001WEP00JEH006IE001WD@00JE80
06QC000206IA000=069@001RC@00GdX005m:001QBP00IE4006I?001VD@00Idl006E<001PB@00GDH0
05a3000205e3000H05i0001L@`00HD@00614001NA@00GTL005e7001KA000FT4005U1001C?`00Dc/0
054j001C=`00DCX0050h001?=`00CCL004Td0016<000A300048_000n;000>RX00P0g90004`0c8@00
;a`002/K000X6`009AL0028C000N4@0070h001T?000I30005`/001D9000A2`004@L000l7000<1@00
20<000@000000000303oool000X0oooo8`0000020040000H004100030@0010<000P300090P002P<0
00T3000:1@002PL000d:000B2@004`H00145000B1@0040L001<9000G2`006Pl001d<000O3P007A00
01`?000G3P006@`00P0H3P009`0N3P008A<002DF000U6@009aP002HH000R6P0091L002DI000W6P00
;AX0030O000c7`00=b8003PX0011;000BSL004`k001@@000E4<005I4001K@`00FTP005eB001PF`00
I6D006AY001RL000Fg@105Ih0@1AP0H0BXT=04B@4P12TA80?i@C042D6@0mVR40>YhY03ZM:`0203VN
<`0W03VN=`0fUT<0=8eB03=oH@0cKfL0=F=[031HM@0`DG`0@Dei05Y<M`1U@gL0GSEe05PZMP1S=6P0
MceI07LkEP1Q=FP0FS9^05ThF@1R=4X0Kbm@06hZE01`8ed0NBAS080UK0268g80Ob5f07PIO`1n5XD0
Pa:@08d>UP2A4XX0U1Ei09/HJP2F6fP0TaiT08lPI`209GD0LRZ00080GSB702L0AT2;03I9S@0]EXX0
9VF5029^P00VLGL0:6ic02e`L`0^M7P0<WMf039gN00gN780>WYa03YfL`0jMg<0>gMf03YcN`0mIW`0
A6Uf04YZM01<Kfh0D71V04eXIP1<E6l0EU1c05e8NP1WAWh0JDMf06]5M01_@W80MD5a07I1M`1/A7L0
GTU`051AJP1BJ5T0Dge:05F:@`1?R4T00P1=PUT09`17MVL0Ag1S04EVIP16I6/0AVQX04EZH`11Le`0
@81D03^9DP0jPe`0>WQ^03]/OP11I7/0@Ual049QMP11Mf`0?hQU046<H00nS640=hMY03R8JP0jRW00
>X]^03V;J@0gQVH0>8eE03^BA`16T3d0FXLX06Qm701^N@l0Kfh4075V001eI@00M680075T001eJ000
Mf/007a/0002081]000W07i^001lK`00P7P208>:5@23URT0U8LU0:I]902CJb80W6/N091a:P2<KdL0
OfmJ08=XGP2CIF@0W6=D0:=M@`2SDCl0YTY10:I1BP2NADl0WdaC0:UOD@2eHdh0`UU;0;mDD`2XGED0
WF1L09=TF@2FI5@0XW9;0:MfA@2TMT40VG=408QoB`1kPE00N8Q:07:?BP1aWDL0JZA80080J:M102L0
Jj@d06bW9`1`Yb@0MjHS07ZU701iX1X0MYdL07RJ6`1gUAT0NI@A07NA2`1jT`T0OHd808:81P29Q`80
QX0008=o0023Q000PHP2086D101mT`L0NiD907JH2`1hW@d0N:<D07BU5P1`Z1T0LZHK07FS5P1hW1<0
N9D=07^@1P1kR`<0PHP108:60026O`80QH8408B31@26QPH00P22R0@09022QP<0P8@107f2001jOP00
NGh007Ui001jLP00N6l007Y^001gJ`00NV`007Y[001fJ`00M6P007=V001dH`00Lf@0075R001_I000
LV8006mP001`G000KUl006mN001_F`00L5d007AP001bG`00KEl0075M001/F@00JE8006QA001VD`00
JET006QI0080JEP000/0JEL006QD001XE000Ie0006M>001RC`00I4l0069A001VE000J5@006UD0002
06QB000M06A?001PB`00G4P005Y4001N@000Fd8005m3001QAP00HdH00659001RBP00GdL00616001P
A@00GT8005U1001G?P00E3`005@j001C>@00D3/0054h001?=`00BcH004Lc0013<@00@c00048/000k
9`000P0i90004`0d8000;20002TM000W6P008QL0020A000M4000710001T=000E3P0050X001<8000@
1P003@D000/500090`001@80008000000000303oool000X0oooo80000002004000<00P4000@00`40
00H200080`002P800P0;1P004P0;1@0030H00148000E2P0050X001@8000B200050T001H;000G3@00
60l001`?000L40007a<0020C000Q40007A4001`@00808A0002L0918002HI000Z6P00:AX002HK000V
5P009a/002DK000V6`00:A`003@O000i9`00?2/003h[0010<000AcT004i1001AA000DdX005Q@001M
DP00Ge0005eD001OG000I6P006Q`001TL@00H7H005ik001HO`00DHP604b@3017U140A9LD03jH5@0n
V1h0>Ih/03JQ>@0bWd400P0aWTP09`0bVTh0<i1H03J4I@0fL6d0<Eeb02m>M`0[Agh0;4B903m5R`1G
AHP0ISj106HdO01Y<G80LSUT07e3E`1j@5@0KC]L06<eF`1?>e@0@cYD05<dH@1V;680NbAW080VIP20
9fT0P2=Y07XJLP1h37`0PP^108l@R`2R58`0WAMo09PKLP2G7FP0TQm]08dQM02697/0MBZ506@aR`02
04dlS`0W03E:S00QF8P086N302=fP00UOG`0:G]e02aeLP0^LWD0<GEf039mL@0ePFl0>h9/03j3JP0o
Pf`0@Gm]049lKP11L740@69c04IUL@1<JG00C6e_04aXKP1@Ffd0E4Af05A6N01CAh00E4am05Y>M`1Q
B7L0ID5i06HlN01W=gT0Gd=j055AL`1:GF`0CW5F05>1AP1CRch0EHA80080EGQE02L0CFeW04][I@1:
IFP0BFMZ04]]I`15L6D0@GIQ03emH@0fOF/0>gIc041[NP14Gh40@eml041HO`12H7H0?7YY03B9I@0h
RF<0>HMV03F5K`0iQVl0>XIa03V3K`0nP6T0?WYQ04:4C@17Rc`0E8PW06Qk4`1aL0H0LFT207EP001h
GP00MV40079S001eJ000N6X007]`0020K`000P1kK`009`1mL040Ng@407b02P2ATAh0WHDm09Uc8@2T
JR<0T74]09eZ=`2HId<0SVQA08UZGP2>IeT0WF9M0:9LCP2YEd@0ZU190;15BP2^?Tl0Z3YC0:A4DP2Y
GD`0]FI80<1OC02iGED0WVeL095aH@2;J5l0TFAB0:9]B02^MDD0ZGI609UdC@22NT`0MHA?07NBB@1b
UTT0L9a806^R@`0206fZ>00W06jX:@1`Z1h0LJXP07>[901gYah0NJ0K07fE6P1nSA@0P8T>08671`21
Q`<0Q8X108B50@27Q000R88008Ik0025O@00Pgl008:30`1hR`D0M8`607J>201hTP/0N9L=07RJ3`1i
VPh0NY/>07bJ3@1oU0X0Phl808F<1@23Q`40PXH008290@22R@80PX`808>B3@22TPh0PY8?0080PI0>
02L0OI<907b;1P1mQ`40Oh@00865001nOP00NgX007]h001lL`00O7D007Yb001jL@00Mg4007Ib001f
K`00MW4007M^001eJP00LF0006iN001^F@00KUd006eO001bH000LV<0075S001`H000LF4006mN001a
H`00Keh006iG001[E@00J58006QD001[E`00K5X006mI001YE`000P1YD@009`1UD`00Ie8006EB001T
D@00IU@006QD001WEP00IeD006UB001WDP00I4h0065=001PB000FdH005U0001H@@00G4<005i7001Q
A@00GTX00698001OB@00I4X005i7001LA@00FD@005M0001I>`00Dc`0050j001@>000CCP004hf0018
=000BC<004Da0013<@00@B/003`W000203PT000C034S000]7P00:1/002DJ000Q4`008A8001d@000J
3P005A4001H<000C2P004`H000`5000;0P002@4000H100020@000@000000000<0?ooo`002P3ooolN
0000000?00400003000010<000L3000810001`<000P300090P002P<000`4000<1@0030P000l5000>
1`0040X000805P/000T05`X001D9000H2`006P`001`>000O40008Q40024A000Q5@000P0T5P000`0O
5@007Q40020A000202@C000W02@I000Y6`00;1`002XH000Y5`0091L002PI000X6`00:A`002`N000f
8`00>R`003hb0013=000ACX004Y0001?A`00Ed`005MC001LF000H5L0061K001TG`00JFL006Y^0@1/
M`40JWX206Ek0P1PP0<0FXH505B=2@1ATQ00B9HG04>G7`0lUbT0=iHe03:E@@0aV540:iMG0080:YIN
02L0:i1Q0326IP0aN700;V]f02UKNP0WCGl094N402I9SP0`C9L0?TVG054lTP1O:h`0KbMi08@/F`2C
<d00QcM107DgC@1T<e<0@cQN03XeKP1><WD0K2Q]08`SK02:9FD0Q2MQ07lPF`1m5VH0O@M`08X;N@2I
4X40Z1R009hMO@2E8gH0SbAd08HWN`1m:X<0Lbb805lbSP1@>I000P0kBHl09`0WFhX05ff301]kO00S
PgL0:HAh02b1MP0^O7@0<GEh03=fMP0fOfd0>HIW046:IP13SF40A8aT04B4JP14NV/0@fe[04ASKP1<
IF`0CFQ]04aYKP1:GWD0D55g0552OP1?Bgh0Bdj004]?OP1AD7P0E4Ui05A4N`1E@7d0ECmn0599N@1>
F780BF=]04edF@1?PD`0D8E905=nD00205A_G00W04eNK`1:I6`0B65/04]UK01;KfP0@g=V045gI`0k
OV<0=gab03ifLP15K7D0CEeh04iOM01@G740CF1_04AfK00aOg<0=81_03=mL`0]MW`0<GIf02meM`0d
MF/0>GME04Ag@01@NRl0G7/N06Ye4P1_KPL0KVH006mR001_FP00LUd007IQ001jI`00O6L007m^001o
L`00O7H00080NW8002L0OG4107]m301kSQ@0WHDU0:M]=P2RIbP0YVdX09Ua?02FJTH0RFI>08YZE`2<
KEl0U6MC09eHCP2SE4d0/51A0;]>DP33A4h0`SeB0;8jD02XA4l0ZeY20;AR@030GT<0^f5D0:1aF@2G
Lel0TFmG09EYC`2PK480YW100:EaB02GLU<0OWY>06f5D@1]Tdl0KHeB06j:C`1[VTD00P1^ZSH09`1a
ZB<0Lj<H07BR7@1fXAl0MYhO07BC6`1dR1<0MWd>07ah1@1mM040P7H0089h0021M@00P7P007mg0023
M`00PWh008>30@21QP<0NXX707B8201dR0T0N8`907R>2P1lT0X0OI0908>>1P22R`<0QhH108R40029
QP00QhL108R<0`25T`P0PiP;08FK3P20X140O9hB07bK4`0207^J4@0E07^L3@1jV0T0Oi83082?0@1m
RP40OXD007b1001oO`00P7T007ig001nN@00O7T107Qg001hN000O7/007ej001kM`00MVh0079V001/
H@00KV000080LfH00100MV`007QZ001eIP00LF80075O001bG`00Lf<007AS001bH000L5`006UH001W
D`00KEL006eH001/E`00KE800P1XE0007`1XF000J5L006YF001ZF000KEX006mI001[F@00JUH006YD
001WE000I58006A>001SCP00GdP005a0001K@@00FT0005e2001PA@00GdH00695001QB000HT/005e8
001L@`00FT<005Ln001F?P00E3l005<h001@=P000P1==@001P1:<@00BCD004Dd0013=000@Rl0040/
0080>bL00140<b8002`L000W6@009QH002<E000R4`00714001T>000F3P005@d001<8000@1@0030<0
00P100060@000@4000400002000000`0oooo000:0?oooad0000000X00@0000@100060`002@H000`6
000>2@0030L000/7000>1P0040L00P0A1`00500?20004PT001<7000C2P005@`001L=000I3@0060l0
01P=000L3P0070l001lC000S5@009QP002PJ000Z6`00:A/002HI000Q4P007A@00P0P5P009`0T6@00
;1`002hM000]7@00:AT002DH000V6P00;1d0030P000a8`00<bX003`^0012=000BCX004/m001BA000
ET/005QC001IF`00GU`0065Q001QIP00IF`006Qg0@1WO`<0I84606:0201QQ0P0GHL905B<3P1:TaH0
AYDR03nE;P0iU3T0<he20366C@0_PE@0;8AG02b8G@0202V:GP0W02b9GP0YPf<09WY]02=`N00OGgl0
7U:50254RP0YAi80<TRJ0493V01F=hl0JBN507dWKP2=:580Vb/l08l`@021<dT0LRi304PgCP0_AU@0
>T9K05X/G@2086L0Pb1X08DPJP2576T0QaEa08X<LP2B47L0V1Ii09hKN`2C8gl0RBZ3084/QP1c<H/0
IcF@05TiS`16?Y00=T>?0080:5B;02L07FV:01QjQ00KPWX09HUb02^:L`0_QWH0<X5c03AlL@0gNFd0
?8=W042;H`18SUh0BY5J04Z<H@15PF/0AGEZ049[K015H780Bei_04iNL@1?EW@0DTmk0559OP1?Ah80
CE2004aDOP1<D7`0CTih05A:N01DAW`0Bdem04YDO01?Gg00DVYT055cG@1CO5<0E81E05=mF`1CMeh0
0P1BIFP09`1>E7<0BUYa04IJLP17HG40A6]c03U`L`0iLVh0>7M/039fM`0oM7H0Bfee05EUM@1CJfd0
CW1X04ecI@1:MVH0?GA_03]^L`0gI7/0<eJ103EMNP0]HWD0=VaH04Ef=01?MAH0Gf`A06MV2P1^HPH0
Kf4106iL001]G000L5/0071L001dH000MfP007]`001lMP00OW@007eh000207Ye0@0W07]k1P24QaP0
Rh<^09]m:02TH3<0Y5hf0:]T<`2OJD40R69D07aOE@25IeL0T6QN09UQD02QD4H0ZDe70;I<B030BTD0
cD=40<PoB02d=dd0[4960:iK@02gHcX0_Um50;YRE@2TM5P0Vg=I09M]D`2FJdd0VVa009e^?P2OLD<0
TgQA07^7D01`Se00Kha@06b3D`1_OU80LIA80080LZ<j02L0M9lV07FL6P1eVaX0N9TJ07>B6@1aR1D0
Lg`=07Eb1@1jJP40OVL0081[001lK@00Nfl007U^001jLP00OgT008:00022P`00PH@208260`1kP`<0
N7l407b01@1oO`<0PX02085m0@20N`40PG/008Al0028PP40QhH208R>1@27U@T0PYl>07bX501m[1T0
O:hF07VZ5`1gYaD00P1oY1<09`1mYA00NZ8<07ZL201lV@H0Ni4407f:0@1oR000PhH008B0001nN`00
O7d107Mk0P1fNP40Mg/007ak001iN000OGD007U`001eJ@00LV<007=S001cI`00LVP007IZ001eK@00
MFH0079R001dH@00Lf0007AT001bI000LfH007=K001]E@00JE8006YA001WEP00J5L006UH000206YG
000B06YH001YF000JeL006eJ001_GP00KU`006iM001]FP00K5/006MG001YEP00IU4006AF001TCP00
HDL005m4001P@@00GT800P1NAP004`1QAP00Gd/00618001NAP00G4@005Xo001G@@00Ecd005Hm001A
>`00CCT004hd001<=`00C3P004/f0018=@00AS<004<`000l:`000P0i90003`0a8@00;Ad002HH000U
50008aH001lB000L3`0060h001<9000A2@0040H000h3000;0P001`8000<10002004000800000303o
ool000X0oooo700000001@0100000`0000@3000910003PL000803`P001X03PX000l8000A2P004P`0
01@:000B20004PX001D:000E1`0050P001<:000G2`006@d001`>000I3@0070d001dC000T5P009QP0
02PG000/6P00;1h002XN000Y6P008a<0024B00808aD002L09AP002`J000[7000;ah002dN000]6`00
;Ad0034R000h:000>RX003h^000n=@00BSL004e1001DA`00FDh005YF001GH000Ff<005mU001RI`00
HG41065k0@1NP`@0GhX:05V=401DSa80DhdC056>5@1:TQl0@9D/03fA?@0jSdL0=hY@0362E`0`N5d0
;g9Q02aeH@0ZNF400P0]Nf809`0/Mf@0;71Y02eTM00^GGX0;e=o039?P00gBh00?Tmo04IAOP1?C7X0
Fcif06HbLP1f<6H0Q2eI08d/D`2:;5@0QRiH07H[@@1E>D40>d]703/mE@1C85l0Ma=/080CK`2<4g@0
TQAa09HDLP2L4VX0VaM[09LLL02C8WL0R2V407haTP1e=9X0HcVI05E0VP17AI40=DR:02E<R00201YN
Q`0W01QdP`0HP800785i02B6L@0]RG40<HQb03F6L00iQf/0?8QY03n;I013Seh0C91F04b@E@18QU/0
@gMU04EYJ`17HG40BeUj051>N@1CB7T0FCil05E0PP1=@hH0B4^304]DO@1<EWT0CU5g04e:N@1=AgT0
C4Uk04MHN`11IGX0BViV055eFP1DNU40EWa@05=lE01ANV40DG=R0080CfAY01l0CDec04]EKP1:G6d0
Af9`04EULP0mGW/0>eim03UXM00cIWX0@FQj051WNP1OI7X0DgA^04UiI`17MFH0BgIS049dK011KG40
?Em`03eCL`10EFL0@UQM04]U@01HLAP0GVD306AM0@1/E@00K5H006eJ001_FP00KUX00080LUX000H0
MEl007UU001kK000O6h007e]001kLP0207Uj0`0W07V:3P2EQBX0Wg1309mc;P2]I3P0XfY109EYAP23
IUH0M6IK075XE`1nIeX0REmN09mEE`2dBDT0^TTn0;e::`31BbX0bT<a0<93?02b>DP0[4A<0:mKA@2c
Hd80]e]90:aOEP2LL5L0Vg5F09i`CP2QKTH0X6hl09a`?02JLdD0T7Y@08N>C021STd0M8U=06Z7DP1_
RTh0LYPj0080MIX^02L0Mi@T07RE7@1iV1h0O9@E07Z93`1kQ0`0NWT407]`001lJ000OV`008E`0022
L@00P7@007mc001oM000OGT007eo001lP@00Oh<008B1001nM`00OgD107mc0@21M040QW<0089d0023
M@00Q7H108R00`29Q`D0Qh`808BF2P1oXPh0Nj`C07J_7@1d/200Mk4M07J/6@1fZAP00P1gZAH09`1g
ZA80MJP<07JT2P1hX0L0NIP707jA1P1kTPP0Q90:08F<2P1oQ`@0Kh@206j20P1dP`40NH8007V40@1h
QP80N8D307Aj0`1cK`40LFP006eQ001aH000LfD0075W001cI000MV@007AT001cHP00L600079P001f
H@00Kf40071K001]F@00JE<006YF001YE`00JUP006]I000206YJ000Q06YI001_F@00KeT006mM001]
H000Kf@006YT001XI000Hf8006IL001XE`00JE/006QI001YE@00Ie4006=:001NAP00Gd<005i4001O
A000GdH00616001L@`00Fd0005Tn001G?000F3`005Lo001C>`00D3T004hg001?=`00CSP00080BcL0
00@0AcL0044c0010;000?BP00P0f8`00400d8@00;Ql002`I000S5@008A4001d>000E3P005@`00188
000@1@003@<000T300080P000`80008000010003000000`0oooo000:0?oooa/0000002800P0000<1
00050P001P<000X4000<1`003`P00109000A2P004P`001<=000D3P005@`0018;000D2@004`/001D8
000A20004@T001L;000I3@0070X001X=000L2`007a40028B000Y5P00:AP002PJ000Y7P00;A`002XJ
000X5`008Q@00P0R5P009`0W6000;1P002dM000d8P00<b40030Q000`8000=2H003/_0011=@00AS/0
04/l001:?P00E4P005UC001NF`00F6D105E]0@1IKP40G7<105ad0@1IO@<0E8D605::2P1AT140CI4G
04ZC7P18U280Ai<U04BF;012U3D0?he203b5B@0jPd/0=Gm<03EkD`0cN5P0<GQM031fGP0202ecI00W
02UZJP0_GgH0>5600499PP1;AH@0DDB105a1O@1U@6h0JT9O06Q2G01T>VH0IBm^06lZM01l87T0QQee
08hLJ@2E7V80NRE306LeA01S@EL0DBmN05TEI@1h2fd0Q0]b09D=M`2K47D0WaEd0:DIJ@2N7W00Tb9f
08/WO@21:h/0Mc6I06hcWP1K>9`0CT2D03m<R`0/EXD075b200805f]n02L067Yl01]mO@0OMW`09Gif
02f5M00^QWD0=8Ea03V8K00lRfH0?haT04B:H@19SEl0BXQL04IoG@11KVH0AfI/04QOLP1:EWT0DT]i
05Y<O01QBGh0GDQj05E>NP1?DW@0DUEa05=CL01ABW80Cd]c04m9N@1?Cg`0Af1h049ZM@17L6L0CWIG
04miD@1?Me00CgMI04eaJ`1>IfT00P1;F6`09`1;BW40BeU[04MSJ@16K6/0A6e_049VN@10I7/0?VEh
03aMN@19GWH0G5ie06mQLP1PL6X0C7=X04UZIP1;L680@G5_045`J`11JFH0@6QO04i/A`1JKC<0HVTL
06QW301SF`00I5D006UB001[EP00JeX0075I001/E`00LE`0075N001fH`00N6H007YW001kJ`00Mfd1
07Qd1P0207f35`0W082::02JNc<0WF@d0:UV>02XK4L0RG5C07]UFP1`Ff40L6AR07EVG023GUd0Te5J
0:m>C@35CSd0`DhY0;AB6P2dCQT0`T`P0<97=02d@DT0[dU>0:mQB@2_I4P0[65?0:=QDP2HL580Ug5F
09idC`2PL4`0XFa209]aA@2CLU00S7MA08n4B@21RTX0Lh]<06f?B`1WUD40KiX[0080MIHL02L0N9@C
07jD4@1mTPh0Ohl=08242@21NPD0PgL2085b0020L000QG4008=e0023NP00PGP007mf001kL`00NWD0
07Uh001kN`00OWh0081j001oL`00Ofd007eY001nIP00Ofh0085a0022N000Pg`408B93025T`d0PY`=
07^U3`1kZQH0MjdM07F^7`1f[RD0MZ`H07VX3`1iY`h00P1fZ0d0901hY``0MJL<07BS2@1cW@H0N9X7
07^J2`1iWQ00O:4A082S4@1kW@/0Li@706nA101_SP40LX`2076A101`U`L0LIL<07>?3@1bP0L0LW42
071]0@1`IP00LVL0071Y001bI@00MFD007UV001fI000MF80071Q001`H000Ked006iM001_G000JU/0
06aH0080KET001/0KU/006iM001^G@00L5/006mK001^GP00K6@106e[0`1[L0H0J7<=06Yd3P1UL`l0
JG0?06]]3@1/JPP0LFL506mT0P1[G000JU@006A=001TB@00GDD005a5001MAP00GT@005U1001K@`00
0P1H?0003@1G?@00E3d0050l001@>`00C3D004/f001:<@00B3@004Lg0016<`00A2l003lZ000l:@00
0P0f:0001P0c8`00;al002TI000T5`00714001L>008050`000L04@L000d3000;0P00208000D20003
0@000@0000@00000303oool000X0oooo6P0000008`0200000`4000P2000910002@D000X6000;2@00
3`H0014:000D30005@d001P?000I40006@h001D<000E2P0050X001H:000F20005PT001X;000I3@00
70h001T=000L400081<002@C000W5@009aL002PH000[6P00:ad002`P000Z6`009AL00080:1X002L0
9aT0030L000g8`00>BX003`X000g9000<R4003@S000l:`00A3P004Y3001?A`00DdX005IE001CH@00
E6/2051`0`1<NPH0D7l605B21P1DQ0P0CHP;04^=4019TaP0AI@R04:F:@0mUC<0>IDl03RB?P0gTd00
>8e703QoC`0eL5H0<G1G02aaF00]Kel0;faX039/L@0dI7@00P0^H7L09`0ZEgh0<Tb5044oRP1C>8L0
GcZ206/kOP1d?740NCeO07/mD@1j=U@0MS9F078]E01^;5X0JRUO06/WHP1e8Ed0Q21L070VDP1];Uh0
O35b06XTL01_4f`0R0e/08l@MP2H4g`0VAMn09PLO02H8GD0T2J008LZRP21;I<0NBnI074bX01Z<j00
EcJJ04/lU00jBh/0:Uj401]/P00201UiN`0W01f0M@0KP7@087Ig02=gM`0XNW@0;G]f035jL00gPFd0
>HA/03b4IP0oQ6H0A8=W04F1I014N6<0AFUV04IOKP1:H6l0BEUb04mHL`1FGG@0FfEf05YOK`1BG6`0
CEIZ04eDK01>Cfd0D4M_051?L`1?DgP0CEYj04YVL@1;K6`0CFmR051bE@1AL5L0CG9L04e`I01BGgD0
DEAc0080Bd]d02L0AdQh04]MI`15JV<0?faX04=^K@11K7H0?fYh049/L@10HWD0BVEa05MZJ`1SL6D0
Gg9P05MZHP1EGVD0EEmX04iOMP18J6h0@WAO04ImB01MN2P0K6lA06]V1`1]G0<0IU@006EH001VEP00
KE/006iJ001^G@00LF40079T001iI@00NFL007YW001lK000Mf`107Ua101iOa000P2=PRl09`2GKTL0
WV`j0:AI>02PHdD0TFi@07YgF@1_KF80LFUR07iWG@2>HET0VUaB0:9FAP2fESX0^UX/0:QO;02@HcH0
WEP`0;I>8`34AC80_DA60;A=C`2]IDP0ZFQ=0:5UC02HITh0UFi@09M^E@2SM4P0X7150:5^@P2MJTX0
R6eG089cE@23O4h0NHQ7072BA01aV3X0LIh/07BI7P0207ZE500W07fB4P1nT0h0P8d;08671P24P080
Qg/008Qa0025KP00Pf/007mZ0020JP00Ofd007m^0020KP00OfX007i^001mLP00OgH0089h0021N000
OG4007i^001mJ000O6H007e[0022M040PGh508692`1lTa40OYXA07jS4P1fYa<0M:PI07J[601eZAP0
M:`J07N/5P1iZ@l0NJP=0080MJd=01T0Mj/<07JZ301bZ0X0L:<807:O2P1bY0l0MZLC07JY6`1f[Q/0
NZd@07>W3@1`W`X0KIT806jB1@1_U0H0LY/;07BS3`1cWQ80M94=079l101eK@40M6/007E]001fJ`00
MFL00080N6X000`0NVT007MT001aIP00L6@0075U001bHP00LUl006iI001ZEP00KEL006eF001^F@02
071O000D071M001bH`00KfP006Y_0`1SM@X0HGhA05n46`1OQ1l0Gh0T05j19@1QOb40I7`H06Uj3`1/
L@L0K6T106aP001WE@00I4`005i4001K@`0205U2000A05Q0001J@`00Fd0005Y0001G@`00E3h0054l
001?>P00CSD004Xf001:<`00BCD004Td0016=P00ARl0044/000n:@000P0h9P003@0d8000;1`002PF
000P50006`l001P<000E2`004PT000l7000;1@002`8000@2000300001P00000<0?ooo`002P3ooolI
0000000C008000050@002@<000`7000=20003@D000h5000>1`0040H00189000F3@006Q0001d@000K
40006@l001H<000D30005PT001X9000201P<000?01`>000L3@007@h0024?000P4P0091H002@G000X
6000:AP002TI000]6P00;R00038S000^8@00;2400080:a/002L0;aX0038Q000k:000?Rl0044^000l
;000=RH003PU000o<000B3d0051<001BD`00EEP0055Q0P1:K0<0B78504Ii3013Q180@XXD04B<6016
SQT0@i<O042E900lURX0?YP]03bH;P0iUc40>9Dg03ND>@0iT3`0>Xa003V2AP0bNU80;gYH02miG@0_
N640<GMV035fK00aL6d00P0^JVl09`0[HW@0<EIo03]6P@1B@880Icj007djNP22>Fl0OcaR07PmG01[
?680ICiY064lJ@1H>Vd0DSU^04d`K01J8F@0LQMR06/JJP1a87`0PbF9080LO@2>4W40WQ1[09dCM@2J
67h0UAj108lTP@2;:H<0Pbf@07/bWP1g=:P0LCBW06/eY01V=9/0EcFF04TjT@0gBH/09VJ401akP002
01^6N00W01b8L@0MR6h08Gmb02AlL`0XOG80:gea02mkKP0dOF`0=GmZ03YoJ@0nOF/0@G]]04AiJP16
M6T0BVYY04aRK01:HF/0BEm/04iWI`1@KfP0DGeY05IeI01?Iel0AUMV041BJ@16BG40BDAe04]BM`18
FGd0BUai04e[K`1@LfL0E7QN05EjE@1ANeH0CGQL04m[I@1AEg@0DTmf0080De=c0200DEI_059UHP1;
JV00A6QW04I^J`15K7D0B6Ue04MZL@13HG@0BVE_04]_JP1BLfL0GFmP05mVH@1OFVL0IEIV065BI01G
HUP0EG=205Ef:P1VKAD0Jf8306MD001YEP00JUD006aG001]FP00Kel0075M001/GP00MF@007UW0080
OFP000D0OfX007i`001nM`D0OX4E08F48P0209Yg<P0W0:=O@@2IHd00VEY708EWD`1cKe`0IgAQ07Ab
H@22KF<0UfAN0:YKFP2cFT80^5Da0;MN9@2aHbD0Sf<j08AVDP2@G4/0ZddZ0<M9;`36BdH0_EM?0:mZ
B`2UJdl0VVI>09MVC`2FJdl0V6e;0:1f?@2OLcX0X74l09Y/A@23LDl0OWIA07agCP1gR4<0LI8j07FH
901lUa<0Q90>0080R8/<02L0R8T908J42026Q0<0QX4208Un0029N@00RgH0085[0020H`00O5l007US
001fI`00NVT007]Y001mJP00PFX008Aa0023N@00QGP008Ej0023NP00PWL108Ab1027M`/0Qgl?08V3
4@28SAL0OiHG07NK5`1jXQL0N:@F07J]501dZAD0MZXD07J/5@1g[AL0NJhF07R_5P1i[A000P1g/0l0
8P1f/Pd0LZl<06nY2`1^YP`0KJP=06j^4`1a/200L:lU072`9@1a/aX0K:hD06RY4@1VX0h0J9d:06ZM
301]YPh0LZ`C07BX4P1gWA40NX`?07Yo301iMPL0NW8207U/001iJP00MfP007MY001hIP00N6D007AT
001cJ000M6H0079V001^H00206aL000306YI001ZFP00L5h00080KF8001<0KVH0071/001_K@40J7H:
05ao5P1HQQ`0EhXV05R::`1HQc80FhLh05b8<`1MQR<0HH@L06En5@1YL`L0JVP006YL001VC`00GdL0
0080Fd@00180FT8005]5001MA000G4@005a2001IA@00ET8005Dn001C>P00C3P004/h001:=P00BCD0
04Tf0015<`00@Rd003hZ000j9`0203DQ000<02lJ000Y6P009QH001hB000H30004`X00107000>1`00
2PD000/400070P000P001`00000<0?ooo`002P3ooolF0000000?004000010@000@4000L100080P00
2P@00107000B20004@P00187000?2@0040T001H;000M30007`h000807a4000@06a8001D=000G2P00
5`d00P0K3000400K3@006P`001X;000O30008a4002@E000T6@009QP002XF000[5`00:a/002dS000_
8`00=2@0038W000e8P02030O000W03@M000g8`00@2h004<g0015>000@3D0040a0011<000BSL004a9
001AEP00DF81055W0P1;L0@0AGH504Eh2@15Oa40@HTK03n>9@0jSbh0?I0c03RD=`0fVC`0=Ia103FK
?P0fVCP0=YPe03BF=`0hT3T0>H/m03V2A@0gNDl0<WAO02ieJ00/MV`0;WA_02abK`0/LW<0:W9d0080
9W1e02L08VAi02ECPP0]@8T0CCF@07HYTP2M8Xl0WB>009LULP22;VX0HSe/05M;P01DChX0CdZ904Y7
R@10=g/0CB1[06`@HP1_4W40NaJ208hNR`2?6g`0WQQ]0:PGI`2O77@0UB1o08hUQ`26:HT0PBb;07X`
U`1d<j<0L3FZ06TdZ01S=J40GcJH04llT@10@8h0<4n702E^O`0NPg/00P0OSWL09`0PTG00891_02B8
LP0UPW00:X=/02n3K00dP6X0>7mX03IoJP0hO6h0?7U_03mfL@13MFd0AW9[04aWK01?HFh0DFIZ04]X
JP1<KFP0BWUQ04f4HP1AOe`0B6iN03]LIP0hEVT0@51`04Q6N@18CW/0B5El04YGN`1<JW00CgYW05>0
G`1DOeT0BgYN04=bI@1<Hfh0C5=j05AEN00205IRKP0I05A/I@1FMUH0D7IH04QcHP1=LVD0DVIZ05QL
L01CGfh0CeIe04mMLP1?JFd0E6U^05m[I01KJ6H0FUmV05aODP1GH3l0FFL]05iZ7P1QHa@0IU`906UJ
0P1YEP00JeD006eF0002079N000<075S001cH@00KV00075T001hH`00O68007iW0023KP00OW810821
3`2;Q2@0U7di0P2OLC009`2LH3l0TfM309AYB`1lMeD0Ih1M06J2F`1mMEh0T6=N09UTF@2VIe<0[68n
0:aI=02GFSH0S5e308INB`1oFDh0REM30:U>;`2nBSL0^T]?0;5FF@2XJ5D0W6iE09I_D@2FKdd0UFm6
09Ic?P2KMSL0WG@c0:5c?@2HN4<0PH1608B5@@1oQcP0Oh`a086>901oT100PHX708V80`0208R0000W
08Qn0026O000Q7d008Il0025O`00Qg/008Uf0023K@00Of<007IQ001jH@00OV/007m^001oL@00PG@0
085e0023MP00OGX007al0020O`00Pgl008>31022Q`d0Oh`H07^?;01lRS40OhLn07FJ=01dXC40LjPZ
07FZ8`1a[200LZdP07>]8@1a[al0Lk0M07:_601e[aD0MK4B0080M;4B01X0Lk8?07:a3P1][Ph0K:lF
06fa8`1]/RH0Jk8^06V`<`1X/bd0I[XX06Jf:P1V[b80Ij/J06F^5P1W[Q@0JjlF06^b6@1a/1H0MjhJ
07RW6P1hVQH0Nhh@07j41P1lMP40MVh007IU0080M68000/0LfD0075V001aIP00L6D006iS0@1]H040
Ke`006eM001`G`00KV<0071U000206m/0@0W06ma0@1^L`40JWL606N65P1OSB`0FH/b05V;>@1NR3d0
I8Q106>4A01MQT00G8hg05V?<P1JQRX0GG`?06=/001YH000J5@006==001NB000FTD005Y1001H@P00
FT8005Y0001I@@00FT<005Y4001E@`00ESh0050k001@=P00BC0004@b0012;P00@2`003lY000i9`00
=B400080<al000H0;Q/002XG000R50006a4001H9000?1`0200/6000300X400070P001@4000P00000
303oool000X0oooo500000020040000Q008100040P001P8000P3000<1@003`H00149000B2`004PX0
01@;000C200050P001D;000L3P007`h001lA000O50007A8001X@000J30006@`001`=000O3P0080h0
01d?000L3`007@d0020B000T5`009QD002XG000W5`00;A/00080<20000@0<Ql003@R000h8@00=al0
0P0f80009`0c9P00>2X003d_0011=`00A3P004Tg0018=P00BCh005=6001EF000E6D0059a0P1<N@D0
BW`704Qn2@18P@l0B8@I04B::00mSC<0=i1003B=B00cTTT0<YI;03>IB`0cVDL0<YY103:J?P0eUSl0
=Y9003N<A`0hPdd0=gQI03AfH`0bMf`0<7A_031`L00]K780;6ef02]_MP0202]`M`0W02iWNP0eFH00
?dR505PmQP1g<H<0Sbaj084`KP1c<fH0ISU]05]6NP1GDhX0E5><04m:Q@1?@7d0DCAc05TTJ`1W6VL0
MAY]084ML`278gD0SB=_09HSJP2J8Fd0TR=h08XVP`25:HT0Ob^=07X]SP1d<9P0Kc:R06/cZ01P=:D0
ESJL050iT`11@H`0<d^902QIP`0ULWL08hMb0080991a02L0999c02J@L`0WRWD0:X9_02j4JP0bRFX0
=hIV03V2J@0fOG80>GQa03ecL@10KG<0AV]c04QZL@1;H7<0Cema04mYK`1=LFd0C7=V04agH019OV00
CGYL04IdG00kJV<0=fIU03eLJ012Cg40B5Mb04mKL`1AFgH0E6e/05=kJ01DPF80CgiQ04AaJ@0mI740
@5Yg04U@P@1BFg/00P1AK6l09`1<NFP0D7iM051lG@1>L6P0E6aX05ENK@1JE780FEQ_05AKKP1EGFd0
GEi]06]IL01]HFP0HF=V05ETG01FJ3L0D6LL05]U4@1QFPP0He@206MF0@1XG000KU/0075K001cH000
M60007EV001eI000M5h0071K001dG`00MEd007IN001mI`00PG43081m4@1oPAd0SgP_09i]?00209Y[
=00W09EO?P2;Jd@0Og]=06j<D`1ZS5X0KhAJ08Q/FP2LE640WV=L0:9ZC`2QGT80WTm008==C`26DUT0
Q4mC08M6BP2JBC`0[E8a0;E=@02^DEL0Z5QT09m[G`2GLU`0TWIF09AeC02DMDP0TgM009Ul>02JP3T0
WH5109:5@@1oRcl0P9@^082D6`26RA80S88>08J01`24NP80QWX00080QWP002L0QGD008If0026M@00
PgH008Aj0026O@00RG/008Yh0021L000Nfd007a_0021LP00OWD107ai0@1oN`<0P84607n62`20Q`X0
OhP:08292P25S@/0P8l@07nD5@1lUb00NITX07NH;@1gW3<0L:La06f^;@1][bT0K:`V06jZ9`1_ZbT0
K:/Y06n^8@1^/ad0L:lG072^5P1_[aD00P1`/AH09`1/]AL0J[8I06^b7P1Y]2d0I[<o06Va?@1VZCl0
HZXm066g<`1K^Rl0Gk8h06:_<`1S[c<0Hk8_06Bg:P1W^RL0IkXS06bh7P1/^1l0L;@Q07:]801dXaT0
O9<A07j93P1oO0d0O7H;07Uc201hK`P0N6h807I^1@1dKP80L6l306e/1`1_K@T0K6`606e]0P1^K040
Jfl106]d0P0206]k1@0W06b01`1RP`X0G8/C05fD:@1IUSd0F8m505b:B01UPTX0J81706]iA`1OP3l0
F8dj05V?=01IRbH0FGlC05mb201VI`@0Jf0106YF001VC000GDP005a5001I@P00Ech005Xo001H?000
FCh005M3001E@@00E3d0050i001<<`00B2l0048]000n:P00>bP003TW000i9000=B800080;Qh000/0
:aX002@E000P4P0060l001@:000>20002`L000P400070P001@4000800008000000`0oooo000:0?oo
oa<0000001400@0000<0000300001@4000P3000;0`0030@000d7000@1`0050T001@:000G3@005@d0
01@<000E300060d001dA000401hB000E01/D000I40006@d001d=000S4@008Q@0024C000P4@008A<0
02@G000X5`009QX002`E000Z6`00:a`002TO000a7000<AX0034L000b7@00<ah00080>2D002L0>RP0
03`_0010<P00A3D004Dh0019>`00Cd0005E4001GE080F6@3055e1019P0H0B8D:04Z53P1;QQ00BhDH
04^39P15Qc80?XXf03Z<?`0fRDL0=h]603V<A00iSd00=YA103BGA00bVDH0<iU703>IBP0cUE00<Y9A
03:?D`0`S5X0<HYR02j3J00/Nfh0:GAd02U_N`0]KWh00P0bKWl09`0iIX<0@ef7051?R`1OAH@0L3Uj
07TdLP1S>W40HCIf05lkP01R@HP0IdZ?06I8R@1Y>h00LRmd07@ZJ`1c9fD0Mb=R080QH@278V40RBIS
08TZJ02;;6h0RbYg08DYP020:X`0O2^B07L/U01f;Y<0KbnI06/aX01T<Z@0FCBP04leV014>i40=dR:
02]BQ@0TGH009W9`02B2K@0202B;LP0W02N=M@0YRWL0:X=f02amKP0_PfL0<hIW03N7I`0jPV`0>7Yc
03]aLP11KW00AFUa04ETL`18HVl0AUa`04QMM01:Jg@0Bg=b04YeK@1;MF@0Ag5T04]cHP14MF40?W=V
03YZH`0lGVP0?e5_04ILK`1;HVl0DFMa05MbJP1GNVH0DGeT04IgI@10K700?5ik045KMP1@FgD0E6Ac
0080D7=[02L0C7a[04ikIP1CLVT0F65e05aML01KD7@0GTIl05UCM@1CFWL0F5Yc069KK`1/Ef`0KEmP
05iVC@1CIcX0FfTL05YO2P1PF0@0IE<1065@001YEP00JUl0075T001gI000MV<007MR001gI@00MVP0
07IS001eGP00NF4007aR001lI000NFX1085j3`24P2L0OWHa08ia<P2RGT/00P2QH3h09`2GH3`0PG94
0763D@1/Sdl0LHIB07YhD`2BIE`0ZEUP0:UNF`2YIU00ZEi50:E=>@2MAT80WTI>09Y6D02J@T/0Y4U8
0:eE@02_Dd/0Y5QJ0:9OI@2JJV40UW5O09YcF@2PL5D0Ug5B09=fB@2COT80U8I308n:B028TC`0OIDZ
07nF5`24S@X0QgT408Id0025L@00QgL008=k000208Am000W08Qh0023N000PW0007ic0021M@00QgP0
08Ul002<P000RGT0089g0021M@00PWX107en101hPPL0NXH<07bA4@1mUaL0OYTL08:J8`22X2<0QJ4S
086R9`1oYb`0P:/]07fW:P1gYbL0M:`Y06j^:P1Y/2d0IJ`_06ZT<01/YS00KZD_06fZ;P1/[RL0JKDQ
06Ze7@1/]AP0J[HO0080JK<S02L0Ik<Y06Fb;`1U/SP0I:e4066VC`1UXdL0I:5406:V@01L]S80F[D]
05bX>01PZcL0Gj`j05n`>@1Q/CL0H;0f06Fa<`1U]R`0J;HY06nd:01b[b/0LJL`07JI;P1jTBP0Nh`P
07N;6`1fQ1H0MX0D07F05@1cO`h0Kgh706]o1`1XOPh0Ih4C06R53P1VQ0P0J84606621`1RQ0`00P1U
SQ809`1RUQP0GiTO05bJ:P1OVCP0HYY206FCAP1STDH0Hhi5066=@01LR3T0F8Pb05N?;P1GTR/0EX`R
05R05`1OMQ80HV`806US0@1XF@00Ie<006I>001RB@00GDL005a5001LAP00Ed0005Q0001H?`00ET00
058n001<>P00C3@004Da0014;@00?bT003`Y000i:P00>2<003DR000202hM000;02PG000P4`006`d0
01H:000A1P003@<000X300080P0010800080000100002000000<0?ooo`002P3ooolC0000000Z0081
00090@002@4000X3000<1`003`L00106000?1`0050T001@=000E2`005@X001P;000G3P0060l001X>
000O4000814001dC000O4P008AH0028E000R40007Q80028A000U5@0091D002DF000V5@009QH002LH
000[7000:aX002TL000]6P00;ad002/L000`7@00;Q/002lL000c7P00>B800P0j:`009`11<000@SD0
048f0018=@00ACP004dl001CA@00GEH105eX101CMPL0BH8:04>83014S@l0AI4D04N?7@14RRT0@88k
03^3@P0jQT40=hM503B5C00gPdX0=X5503R7@00fSd@0<9I<02nHE@0^W5H0;IiJ02bKH@0]V680;IIN
02^BH@0[SVL0:8A^02AjM`0TKH00:FB803=PR@0203eMR`0W04UIS@1EEHl0I4f@06Y4P`1_>WD0KSA]
05djN01Y<HL0L3F=07LiS@1m?8T0OCN3088[N@2F7g00TB5V08TWGP2::UX0RBMG08`UE@2?9E/0RbUV
08L]L@24;7/0P2^507d[S`1j;I@0MBjH078`VP1Y<Id0HS>O05ddX@1A>I/0ASbC03e2SP0bChH0:ER0
02ENO00UKg009ga^00809X=b02L09hAg02Z2MP0/PGD0;Wi/0361J@0cPFP0=X5/03UmK@0jLg40?FY_
04=]K017KFl0B6U_04Q/J@16KVL0BVi^04QaM@1:NG80Cg]/055fH`1:Jf@0BFaT04]]I019JVX0@f1[
03iEKP0lBg@0@Ua`04UXK@1CKfX0EW=V05=bI`18Kfl0B6]]04IUM@15GWL0BVI`04Y_J`1>N6H00P1;
OF809`17O6X0D7Y/05i[K@1_DWL0KTmf06Y8N@1^AWX0IU9i05MFO@1KEGH0GUY]05aHK01OHdd0GFd]
05e]601WJ@h0IUh406MI0@1WE000JE@006UF001^H000MEl007UR001dH@00MEh007MO001cI000MFD0
07AR001jH`00NVP0081]0P1mN0P0OhTG08]o<`2;LCP0R78a08]W@00208=Y@`0W07IaD01[Q5@0I8YH
06R8DP1aLED0PF=K09YJH@2`EV40]EAM0;UFF@2lDT00aDHQ0<M1:@35?Cd0]ci90:hmE@2YAU@0ZEM<
0:EJB`2LFU`0V5mW09eWHP2OK680W71L09m]F02ML5L0VGA@09UjB`2CQDP0RH]808FG;027V180R8d9
08Mm0`26M@40Qg8008Qg0027O000R7d00080RGh002L0Rgh008Mj0026M000Pg@0085e0027N@00Rgh0
08b00027O@00QWh008Im001mP`80N8`807R?2`1hU@l0MJ0E07FW8P1dZBT0M:`[07B`;`1f/C<0N;4c
07V`<@1h/3@0MZ/d07BW<P1a[2X0KK0/06J]<@1XWCD0K9Lm06jF>P1^Uc/0LIdk06nV<`1^/bX0JkHT
06Vd8@1Y^2P00P1T]S809`1R/3T0H:dm05nYA01MYT/0GJ9C06BKC`1TWTd0Gje005Vh<01H/b`0EjPb
05Z^<P1J[CL0F:dn05^T@@1KWT80H:9106FX?`1Y/CP0K[<a06n]>01^YSh0K9]206jE@@1`UC80LI@Y
076B901dSQd0MXhI07b>5`1nSAH0OXhF07j>6`1gS1l0L8lL06RB6`1VU1`0HI8Q06:@900206:I;@0W
06:P>@1SXd<0HiU906F?B`1aS4l0MX]A07J;DP1]SDX0FXY005J9>01DSc<0E9H]05JH:@1ITb40F8PJ
05ag3`1PK0L0If<106YN001WF000Idl006I;001PA`00GdH005U5001H@`00F3l005I0001C?`00DSd0
04hg0018<000@Bl0040/000m:P00?2P003XT000g8P00<1h00080:aL000X09AD001lB000H3@0050T0
00l7000:0`001@8000H200030P000P402@00000<0?ooo`002P3ooolA00000003008000060@002@<0
00803@<001403PD000h8000A1`004PP001<8000E2`005`h001@@000F3@0060`001T>000J3P006Q00
020?000O4`008a8002<E000202DG000D020G000Q5000:1@002XF000W6P00:QP002/I000X5`00:1`0
02TI000]6@00;a/003DH000c7000=20003LS000g9@00=bT003XZ000i;`0203lc000W04@g0017>P00
B3`004/m001=?P00DCl005aA001RJP80FWd804V:4@10SQ@0?i4C04:C5`18U1`0AI<S042C;@0jSCX0
=Xhn03B<@00fST00=ha803N9A@0hRDD0=Hm4036GB@0^W580:Y]L02^GH00YV6<0:iMV02^FJ00[TF@0
:h]U02f5JP0aOG40=WAi03MYO`0nHH<0AUV60080CU:902L0EE>;05e@R`1WC8X0J4F106TnN@1a=g<0
KCId07DaN`1f=7X0NcEg07heL020<Vl0Q2][094RJ02=9V00QR]J08<]F023:EH0QBIE08LVH023:W00
ORf007`]R@1j;I00NRjG07H`W01_<J00J3>Q05/dX@1C=j80C3ZN0455U00iCHh0<eB802mPO00XJ7<0
9V]b02MfK@0VOVX00P0XPV`09`0ZPFd0;7m_02n1K@0bP6H0=81W03AjJP0hN6h0>7E/03M[K`0nHfh0
@F][04E]KP16KVl0B7MW04MnI@19O6T0BGMa04]lL01@P6P0EGaP04ifHP1;Leh0AgIN04A_I`10JG00
@65]04AAK@1?FFP0E6EV05M]H`1DJfD0D6AY04]GL`1;GG80Bemh051OM@1=Kfh0A7Y[04AkI@0204Ij
I00W04QcK`1DKW00HVMa075EN`1hCgL0O4ih089?M`1mDg80Le5h06]HL@1OG6H0DEQO05Q]=@1NMQ80
IFl406eW0@1[G@00K5T006]G001[E@00K5T0075O001bGP00Lel0071K001bG@00Leh007=Q001eGP00
NF8007]T001kJ@00PGX<07f27@1lPBH0SW/a09Me?P2AK400WV5H0080NW=E02L0I7YR06>6F`1WQUP0
LGeH085XG02<GV<0WUeL0;1FEP2eDdl0^5990:mA=02ZC2@0/DXS0<M4:P35@Ch0]CaF0:a9FP2XG4d0
XUe@099IH02AFVH0X6=T0:IUI02KKeh0V75F09efC`2JMe40TGYA08^:@@21U2X0QY<D08V80`26OP00
PGH0081a0024LP00Qg8008Mg002:N@400P2:O`@09`2=P`L0Qh8708J31`29OP80QWP008Ej002:P000
Rh<008R0002:QP00Q8l107nG201mW0h0Mih@072Q4@1aYaP0LJdT07:`:P1e]B`0MK@^07Fd=@1d/c80
LK<_076_<`1c[3@0LJTc06b];`1[Z2l0JJ4a06fJ<P1_UCH0KHlg06j??`1^TT80K9Tn06^T>01VZBl0
I[0[06Jc=@0206FX?P0W06:GB01NVT`0Fi];05^QB`1IY4l0GJA?05nXB01K[S/0DZha052`;P1B[S80
Djhg056a?`1E/DL0FJ]905jZA@1NZd00Hk<j06Ne<01^]bP0KKH^06fc>@1Z[C/0K:@j06jM=@1^VC<0
M9De07jA<`27RC<0S8Lg09:9>`2:Rc`0R8`j07n9>01]T3L0HYHn05ZM@`1CWDT0E9aB0080FIaG02L0
GIaF06FMC@1ZUDL0Jhi507N<AP1kRT`0Lhe:06R@@01MT3H0F8h]056C:@1?WBT0D9lW05>J9@1@TA`0
FWd>061b0P1TJ000If4006MH001UD`00HDX005i7001KAP00G4@005i3001K@P00FSl005@n001=>P00
BS<004<`00109`00@RT003hY000k9`00>2<0038N000_6P000P0W5P002P0R4P0070d001H<000A3000
3PD000T300060@001040004100010009000000`0oooo000:0?ooo`l000000P0200000`050@001`@0
00d500020147000W0188000B2P0050/001@<000G2`006`d001`A000L4`006`l001`@000M4@006`l0
01X?000O3`007Q<002<C000R50008a@0024F000S50009AP002XG000[6P00;1X002`K000/7000:QT0
02TH000Z5`00;AT002lM000c7`00>B8003/W000n;`00?S<0040a000o<`00?cL00080?S/002L0AT00
04a5001BA`00EdT005U7001ND000HF@105il1@1BS0h0?iDJ03^I700nV1d0@YLN04>I8`10VBH0>YX]
03RE<`0dUCH0>9@d03VE=@0iTcl0>9=603JEBP0bV4d0;IiB02RMG00TV6X09I=^02:DK`0STW809Hm`
02R7K@0YOVh0<7Ac03][M`16H7l0D5N105Y?P`1TAXH00P1X@HT09`1X@hX0JdB;06i2Q@1`?X00LCYd
07TeM01k<G@0ORmi07haLP20<Vd0P31V07l^IP20:FT0QRMW08HZI024;F00P2eM07lYFP1n9UP0ORIU
07XYO01d;900LRnI07<aV`1f<I`0LC:R06PfY@1P>:P0CcVT04<mX`0i@9d0<djD02eGS`0[GXL0:VQh
02IdK`0TO6h0985Y02N6I`0202R8I`0W02^4I`0]QF@0<hMU03J9H@0gQF80=WeW03MiJ00fMFT0=F]_
03YPL@13J6h0AVQ^04MYK`18NFX0B8MX04^6IP1>PF/0BhA[04j9I`1DQEl0C7mP04UnG@13OUd0?GEX
03i_L011I6X0BEUY05MMI@1LIeh0Eg1J05Y_GP1CJVT0D5ia05=QK`1FHfl0F6A]05E`IP17N6H0@gQY
0080Ag=[02L0BVEe05QRMP1WGW@0O4ml089ALP27DW<0SU=h089JL@1[Gfl0HfAR065[B01KJC<0IG<I
06mc2@1^KP00K6D006eJ001]F000Je8006UF001/F@00LU/0071N001aG@00LUX007=K001cGP00Mf<0
07aQ001iHP00NVD007Y^0@1mPQT0OGhf07mh=`2NLSD0VfY308eVC027HEh00P1cLe/09`1XMV<0JWQN
07M^H@26JF00Tf9X09YRI02RGEP0[eI;0;AE?02eD2/0UU@^08MB>P2GDRT0]d`Q0<=5;`2nA4h0]4eF
0:YMC@2PGU80TUYQ095EI`2JFFD0WEiN09QZDP2GKDP0X7A809aeC026N5<0PI4]08>I4@29R`H0RX40
08]j0027N000Q7H008Qi0P23NP<0QW`508Qm200208V63`0W08N@4@24T0h0Pi8<08R61P25N000Pg80
08Mg002;Q`00S94308NG1`21Y``0Oj/>086^4@1j/1P0M[8N072c9P1/]bd0KKTb072g=01b^C@0Lk@k
06j^>`1_[CP0KjHi06jU>01[Y3`0IZE106NHA@1WU4D0JIDm06^A@@1[Rd40JhU806Z:B`1XS4h0Ii=9
06JO?P1S[3d0I;120080Gj5702L0GXUB05b;DP1JSU<0FiE@05RPD@1FYeD0FJa;05N[@01=X3X0BJ`e
04Z]?01:[D@0Bk1904ndC@1H/U@0F;9?05Vd?`1J]SD0HkHX06Bc8@1X]bL0J[Xc06Re=P1[Zc<0LJ4g
07:F>P1cUC/0P9Lm08nC@02BST40SI1108>GA01kWD@0L9a106FQ@P1KYd`0DJQE052VFP1CYEh00P1I
YEh09`1NYE80HZ96062O@01LUSd0H8dj06V<?01^SSh0HI<e05VE<P1GUR/0DYTZ052R:`1@Xb`0DZ4Z
04jG8P1GRa<0Fgh7061a0P1XJ@00JE/006EB001SC000H4T005i7001KAP00FTH005Q4001D?`00D3`0
04/h0016<P00@Bh003hZ000l9P00>bL003TP000d8000;aX002/I000202DE000801lA000K3@005`T0
00l:000=10001P8000<10002000;000000`0oooo000:0?ooo`h0000000H00@0000<200060P001@@0
00T3000=0`020147000W01<8000F2`005`/001T>000L3@007180024C000Q500081D0020D000O4P00
718001`?000P40008A80024@000Q4@007a8001lC000S4`009aT002dJ000^7P00:Q`002`M000_7000
;QT002XF000[4`00:AP002hO000g9@00?bh004<a0012=P00@3D0048f0013=P00A3X00080ACd002L0
B4@0055;001HDP00GEH006MJ001XI`40I7L305N82@16U1L0>9`S03JP9P0gWRL0>ilX03ZQ;P0gXC80
=:8d03:N>00cWSP0=Ide03RM=00hW400=Ie<036NE@0/X5T0:J9L02JNIP0SUg408Hmh01j>NP0OS7/0
8hUh02EmM@0YKgL0<F5j045FP01EBH80Id:1074mPP1k=8800P1l;X@09`1j;hH0NS2607d^P020;GP0
PR][08</L@23:gH0Q2]l08D/L@23;FX0PR]P080WI01n8fL0ObEW080VIP20:F@0OBIS07/TH@1i8E`0
Mb9[074VQ01[;9`0IS:R06TdX`1/=:40JCFT05hjYP1F?:L0A3nQ03E3W@0ZAYL09EF@02ELR@0WGXD0
:FMj02QeL@0VPg409XaX02N=I@0202Z<I`0W02n<I00bSV80=8mQ03VAH@0iRV80>81U03=gI`0dM6X0
=g9_03a^LP15LF/0B75X04YbJ01?NfH0Ch9X04n1I01BP6@0ChMR052;HP1CRU/0CH=M04b1G`12OV<0
>GIa03]]MP13I6/0D5IY05]LHP1JIUH0E6]L05A^I01?Jf`0CFMc05=YK01DKFX0EfmT05IhGP1;O680
AX1]0080BgA_02L0DUme06IGM@1cEFd0Qe1W08MHGP2<G6H0U5]^081ZI@1TLf80GGQ906Ak:01aM0l0
M7@907Mb0`1eKP00Lf<007=K001^E000JU4006IC001YE000KUd0079L001cH@00Lf8007EO001jHP00
OF@007iY001kI`00OW0607Qn601iR2L0T7Lo09U]A@2PICX0UD]=08AIF@1eHVP00P1bLV409`1cLUP0
NVYK08YMH`2CFFH0WU]U0:=MH@2UEe@0ZeA30:eD=P2_CRH0Q5Hg07QJD@21ES/0ZdhQ0;m8<02nATX0
]e1@0:]QB@2MGdl0TeYP099HJ02@GET0T61D099XB02CJd40WGA109Uk>`24R2h0PhhH08B41027OP00
QgX008Uk0026O@00QWl208B42025R@P0Q8T<08N>4@0208FH4@0W07jM501mWa00PI`>08JF302:R@X0
PGX208=k0026SPD0Pj4?07j[4P1l/QD0N[LP07Vg8P1e]bT0L;L_06S0;`1T`3<0I<0i06Fn=`1Z^CH0
J[Dl06V_?@1/[3/0KZHh06bS=`1YXCl0Hi]506JAAP1XSTD0J91406RG@`1YWD<0Ij4m06JT>@1VY3/0
IjHn06V[>P1X[CX0Gj/m0080G9m302L0FiQ8066CBP1SV4/0FiiB05FSD`1AXe<0Ej]@05NYA`19X480
AJU004NZB`18Z5D0AjaD04R^E@1>/E/0E;1E05>aA`1D]S/0FKL/05jh:01P]bP0I[XW06:g;@1V[bh0
IZLb06VO<01[XC80KZ@o06nU@@1aXCl0M9hn072T?`1X[DD0Gjm805n[D@1NZU/0GZEJ05fLF`1TW5h0
0P1]WEX09`1aWU@0M9Y<06^HA`1QTd00FhXj0664?01]Qcl0HX`i05NA=01EVBh0DIl[056S;01@Y2/0
DIhW04bE6P1BRa40FH0>05ef1@1SL000If@006MI001WD`00HU0005m9001KA000FD0005Po001G?000
CcP004hh001:<P00@bl003hX000k9@00=R80038N000]6`00;1X002XH000202DD0008020A000O3000
50/00108000:1@001P4000800001000;000000`0oooo000:0?ooo`d0000000H00@0000<100081000
2PD000d5000<1P0300l8000W014:000G30006@d001/@000P4@008A4002<A000P500091H001lB000N
3`007A8001lA000T4P0091@002<D000T600091H002PI000Y6`00;Qd002lO000b7P00;Ah0034O000b
7`00<1h003@J000b6P00<al003LW000m<000@cP004Hi0017?000ASh004Lo001:@P00BdH00080C4L0
0140Be0005=G001QG@00J6@006Q_001XN`80GXL604ZC400jVad0<j8W03FV9`0fYbL0=jPZ03FV<@0b
YCP0<:Hm036T?`0203:T@P0D03:S@@0cX4<0;YiB02VPF@0UX5`09JAN02FQI00SWVh07IAi01^BP00L
SWl07X]i01moN00QL7/0:V2003UBQP1=AXT0GCf:06HiR01_<XD2074]R00W06l/R01`:XP0LBV3078W
OP1e9GL0MBEo07HTQP1i8hh0OB:407hSO@1l87<0NQef07LKNP1g77`0N1ig07POL`1g7740M1Ya078I
LP1`7G`0JR2?06<XXP1M<:P0F3FX05@iY@1A>j<0CCfS04PoX00jAYT0;DjD029BT00QGHH08f6202IS
P00^IgT0;GIc02Z7K00/T6P0;I=U0080;99T02L0<99Q03BEG`0kUf80?IEQ03j;H@0kOV<0=75Z03=e
K@0gOG40?W]a04AlJ`18O6D0D7]R059nH`1?OVL0BGYU04MlG`16Q640C8MR05B8G01ER5d0DHEQ04Ym
HP12KfX0@f9]04iLIP1LEf80HEmH05eXD@1CJUP0CfYV04YZLP18IgP0D6i]055cJP1>LFL0EWYO04em
JP1=NG800P1ALW809`1NHWH0KEU^07AHJP1mDel0QF1?08YZB@2BKE00P7Q:06F1@@1TPBL0Kg`?07Ac
001dK`00N70007UZ001gI000L5h006eJ001/D`00Ie8006Q@001ZE`00L5/007AS001cI000Mf@007aU
001jI`00O6P007aU0023Na<0N8/[08B:>P2WJCX0[ei30:9P@02KDU80SEeL08IVH`0208]ZFP0W08]U
DP2<GU@0SUUP099AH@2HDUH0W4i=0:5;BP2VATL0ZDE40:]1?`25CDX0NEaL07iKB02PDRl0^D/j0;M=
D`2/E5`0XfID09]RF@2AGf<0TV5S095VDP2AK4`0U6hk091a>P2INc`0U8PW082>4023PPP0PgD008=`
0023M000R7`30927302<RPh0R8h?08F>3`21UaD0NYdO0080O:0K02L0NZHI07ZT4`1nYA40PZ<A08JM
4@25S`L0P8d1082G2P1kZaD0LK<Q07>i9P1b_2h0K/0U06o09@1Z`2/0Ikd]06>m;P1O^c80H;/c06Bl
;`1R^3H0H[8k06B`>01UYCd0IiY206VHA01/TTH0JHe:06J7C01RQ4l0Ih]@06bIC01XWT@0IYlj06VX
=`1Z/3T0Jjll06VY>`1PX4400P1OT4T09`1RQE80JH1H06N8F01LUeL0DimB05:RE@1E[ED0E:=;04BP
A012YTP0A9mI04FMI015YF00@j]M04B[H016/Ed0BKUF04ZiBP1@^CH0EkL]05Zg:01J]R@0H[LV06Bc
:01TZ2`0I:4a06ZP<P1hWcX0K:4h06BN>01WWSL0Kj0g06nW?01VZdH0Hj]B06JWD`1]Wd`0M9Q907JH
C@0207JKB@0W07>KB@1`WD80J9lj06JK<@1OUb`0GY8]05bE;P1HUC00E9H`052I;@1?W3<0Cile052O
<01?VBH0DIDI05>@501DR180G7X706Ad001ZJP00K5`006QE001RCP00GTT005Q2001G@@00ESl005Hl
001A=`00CC@004/d0014<@00?2T003XR000b7@00;Q`002PM000Y60009aL000808aH000H0818001`>
000G3@004@T000T500050P0=000000`0oooo000:0?ooo``0000000P0100000L3000;10003@L001<:
000C2`005@/001@900804PP002L05@T001P<000J3P006Q4001hA000Q500091D002<F000Q5P008a<0
028B000T5P009AP002PM000Z7@00:A/002XL000Y7P00;1l002lP000_8`00=B@003LR000e9P00=2D0
03@V000d9@00=b@003PQ000i:000?cD004Hm0019@P00AT@004M40017A`00AdH004Y:001;D0000P1A
EP009`1CF`00F680069Y001XLP00JWl2066;201?U180?iXH03FP7@0bYQh0=:XS036[:@0`[380;JTn
02VWB`0XY540:J=F02VUFP0XYU/0:JAI02VRE`0TWf008Z1V022PJP0PY6D07j9Y01bQL00EV7d059B>
01N?R00GRH005Wao01Y[PP0PF8`0<4NC04@jVP1E<9T0GBVH06HQU`0206LLU@0W06TIU@1[6900JAJ;
06LER01X58H0J1>?06`CV01a4J00M`nH07/?SP1i3H<0MPj7078=R`1b3Hh0LPb8078=P01_37h0K@b0
06/=P`1W4XX0HQRK05hOZP1D:jd0B3FZ03dlYP0j?j@0>d6P03a2W00_CI<095J?01aKR`0LHgl07fYj
02IaN@0^LGL0;Wi_02^<JP0^UF@0;iIO0080<9UL02L0<iUJ03ZGF@0nUF00A99T0467H`0mN6L0=fi^
03AhK@0hPG40?gm_04F0I`1:Q680DXUN0525G@1:NVH0@G9Y041kH@11PVD0BHIT05>:G@1ER600DhAV
04ejHP1;KVD0DVES05aXFP1TIeD0Ifi<06Eb@`1ILD`0EW1M04m]JP1@Jfl0EG1/05IeI@1CMFD0EGMT
05EaL01MIGH00P1SI7809`1]Gg40N5Q]07AHI`1aEel0NfU;07]i?01jPcL0MHHZ06b37`1cOQ00N7T9
07Ea001dK`00MVL007EW001cI000M6@007AR001cH000K5h0071H001^EP00L5L007EL001dF@00NEd0
07YP001gG@00OfP507e`4026RB40S8<d09=c>02WJ3H0Z5m909iOC`2ODel0VEMR09eOH0020:5PE00W
0:IMBP2RFU40VU9P09M9G@2NB500XdE50:E3B02W?DX0[S];0;DhC`2HB500Q5QM07mPD@2KEc`0/5A0
0:YBF@2PGV40W6YI09YVG@2CHV40TFYK09=`CP2DMTL0TGLi099o<02JQbT0ThdK08B11025M`00Qfl0
08M^002:MP00SXD;092B7@29VAh0QIhJ086M6`22Wb00NjH/0080Mj`S02L0MZdR07>]701iZ180NJPC
07fU5@1lWPl0NiT907fN2P1d[QP0K;X[06O0>@1Y`3P0JL0a06Ro;@1W_3D0H[Lg062Y?P1M[3l0G[50
062b>P1P/C`0GZY105fQAP1PV4`0Hi9@06N@C01ZRDh0Ih]@062;D`1OQE40IHY?06nBC@1/UD40KILj
072R=01d[C40Kjdb06j[<01VXCD00P1TUch09`1ST4T0H8e;05j@C`1LUe80Dj5@04fSDP1=YeD0BZE<
046ZAP0nX4/0@9MM042HJ@13Wf@0@JMT03n_I@10]f@0A;]S04ViE@1<]dL0DK<k05Jf=`1H]Bh0G[4`
06Fa;01UYbd0J:<d06fR=`1iWCL0LZ0b06ZQ;`1SYBl0HJH`066T?@1NWdX0FYMC05NKD`1IU4l0Gi=?
06JDB`0206>FB00W06:F@01JWc/0E:Ph05BW<01CX2D0EY`R056M7`1EWbL0Dj0_04jN<@1>Wc40CZ8g
04bO<`17WR/0B9/Q04^F6@1?SQH0FH0:069b0@1YJ@00J5/006AB001PBP00FT@005M1001H?000ESd0
054j001<=000BS0004Pb0010;000>RP003DT000d8@00;a/002TH000W6`009aP000809A<000L07Q00
01`@000F2`003`L000X500050P000@0000`00000303oool000X0oooo2`0000002@0200001`<000d8
000C2`005`d001T?000J4`006A<001X@000201H?000W01P=000I3@0070h001`A000P4@008Q<002PF
000W5`009QP002LE000Z6P00;a/002lP000c9000<al002hN000[7@00;A`0030P000]8@00=2@003LW
000j:000?2H003XX000m:000?bX003`^000n<@00@3T004=10016BP00A4d104M<0@17C@00BTd004U?
001=C`00CeD00080EEh002L0F60005eW001SKP00Ig`006B:1@1DUA40@9hQ03:Q8`0^Y240<:TM036Z
9@0Z[C<0::Q002NRC`0SW5d08iaV02:LJ00RWVd08Z1a022PK`0PWV/07YY^01fKLP0MVg@07j9`01fS
K`0LXW<05iUo01NBR`0FRXX05h>701EcQ`0JHXT07e2A0311V@13=9h0E2^Q05hRX01V6j000P1Z5Yd0
9`1_4iT0LA6@06dAS@1X4Xd0I`n=06T=U01^3I`0MP^T07h8WP231YD0P@N=07`:T01h2ID0MPRH07@6
T@1c18T0K@F406P7R@1S2Hh0HA6F05`HXP1J8Jd0Cbb/03dhZ@0[@:@0:4BO02a5VP0_@iD09E6>01]L
RP0GHHL06FMl01i`MP0SNWH0;GYc02b4JP0/TFH0;Y]Q036LFP02036ME`0W03NKF00lUE/0@8iS04::
I`14RF@0@GmV03YkK@0jPV/0>hAZ03j2JP15QVL0CHYS04n;GP1@REd0BGeP03mcI@0lNf80?h9R04N5
HP1?R5l0DhQS05:1J`1?NFH0D6eV05U[G01SL5H0IGEB06IgC01ONdH0EgM?05=cG01AKV<0D6iX05Yc
H`1LO5d0EWaO05QhI@1OJW00KUMd0080M5U]02L0PEUZ08ALI01hFeh0LUUL07E_A`1]QBl0GXTT06R1
5`1_MPX0LW4407E_0P1aJ@00LF<0071Q001bG`00LUX006iN001bFP00LE`006iQ001aE`00KUL0071F
001bD`00MEL007UJ001kGP00O5h007i`4@1eR2L0RH`^09Yf>`2QJS/0Z6Tc0:9WA@2DI5@0T5QT08iN
IP2?Gf400P2MGUl09`2WEf80ZU5T09m<IP2LCF@0Y4UP0:e7F`2/AU40/TA10;M4@`2k@TH0[dQ;09YB
E@2CG580X5]30:UJAP2PEU`0W5iO09U^G02DKU`0SVmM08YcE02?MTd0TGe708am?@2AQR/0RY4I08^6
2`26NP40RGP008]h0`2=O`X0VXT@09J>7@2DTBP0T9<]08VH:021V2X0PIhY07^U<@0207V/9`0W07N`
901e[Ah0LJXD06ja701^[280LJXM07FS4@1gX@/0L[4H06c0>01Ta3l0H/0n06Bn?P1T^c/0HKI705VW
DP1IQE`0FYMF05fYCP1KZdP0GJa805fND01KSEH0H8aG062>E@1US4P0HXY;066ED@1NTE80G8A?06>@
C01_Udd0KiE207>L>P1eWCL0Lj@b06jU<01XYRh0IZ<b0080GI/n02L0Fi5:05Z9C@1DV4`0DJI?04Z]
D@14Z5H0AYmN046TE00m[4`0=Z1@03RJH00oVFD0?i]U046PIP11[6@0?kMU04:jH`11]e/0A[5C04^/
D@1=/dT0DKE105Rb@P1N[cl0HZPn06BU?P1TY3/0Iihj06ZL>01[W3`0HjDg05bN@01HTU40EhEL05Il
H@1APUd0CXYM05:AG@1HV5L00P1IV4h09`1HUD40E9do052X?`1@ZCD0DjDV05VS8`1FX200Ej0P05:R
8@1AXbL0CJ@X04bU:01;YRP0AZ<W04JO8P17Ua/0Ci0G05J42`1NL`80IFH006MG001RCP00H4T005a3
001I@@00F40005Hl001?>000Bc@004H`0013<000?bh003`W000f9@00<R80030J000W6@008aL0024E
0002024B000601dA000I3P005@`000l9000;1@0010803@00000<0?ooo`002P3oool8000000800@00
00X00P4000D2000;10004P/001L>000G4P006Q<001dC000N50007A400P0P4@009`0L4@007a0001l@
000O4P008Q4002@C000Z5P00:aX002dL000_7@00;b4003@R000a8`00=2L0034S000/7@00;1`002PI
000Z6`00:Qh003@T000k:@00@2/004<[0010;@00@Rh0044d0014>000?d0004A40014B@00@dh104=B
0P17C`40BU4004iD001AE@00E5D005EJ0@0205ER0@0W05]X0@1RK@00I7X106B60`1HTP`0AI`R03>T
>@0[YSD0;:H[036Y9@0_ZS009j]002:SD`0QUeh0899Y01nBK@0NUFl07YA_01jGL00NUW407IE_01ZD
L`0LUGL079Qf01fLM00KXG<06Z9c01RKNP0HTH<05h>901MiR`0HIXl07UJB0299V00b@Id0ACNN05H^
WP1M9Ih0IR6N0080KAbL02L0LQVJ07<JU@1]6i<0J1^A06LIT01]5I80Ma:E08<@V`2:3Y/0T@^G08l9
S`292i80Q0ZF0848V01m1iD0NPJ?0707S01T2I80FPbG05HHWP1@8jH0BbbZ048eZ@0d?JD09DBN02=:
U@0WBhl0:4b:025JP`0KIGl066Ql01]/M00PMVh09Ge_02YnK00[QVP0;99R02fLG@0_W5P00P0dW5H0
9`0jVUL0?I9M03j:H`0oQ6D0A8IT04>8I@10RFP0?XYU03n<HP10RFD0@haT04J:IP1<Rf80C8MO04V0
H010O6<0?X=H03n5E010QeL0AhQJ04Z6H@1@OfP0CW]T051fI@1HMEd0H7]D06EkE@1POE<0FWe<055h
F01=LV80BFiU04QZJ01EM640FGiK05=jI01ILVP0Hf9]07=AM00207MGK@0W081JH`22HUH0N6Y=07A]
B@1eOC/0JhHU065j4`1ZL@X0JfP206iV001^H`00K60006]P001[G`00K5l006eH001/E`00KUH006aJ
001ZG`00KUX006mJ001`E`00L5X007=L001jHP00OFT207I]1`25R200SX/f09Qm;P2UJc80YV8i0:=U
@P2SHE<0T61N089GJ`24E6l0TDmZ0080XTmY02L0^D]X0;Y7J@2TBFL0WDiR0:M=HP2]CF40[d]<0;I=
;032B340dDHe0<U1B@2l?e/0[U1K0:UMD@2TFdd0VUUJ09UTG`2ELed0TWEL08UfF024NE<0SGU;095k
@02AQ3L0S94Q08B72P27O@80Q7/008Yl0@2=R0T0U9PD09^C8`2HSRd0UX/`0967=028TB`0QY8d07jP
<@1fXc@00P1bZS409`1d/2X0LK0X06nc8`1Y]C00JkDc06^`;P1`Zah0LJLA06nf7P1Z`D40I/9406K1
@@1T`4<0HKa605bfB@1F[E80EiEK05fFE`1KVDl0GI]@06:NE01NU5d0EHmP05RNE`1IYE80Fj1=05^L
C@1LUeT0F8iI05b7E01[RED0N8YC07V:C`1iSTX0MXi6076A@01]UcT0JiTd06RK>00206>D@@0W05n>
B01IQd/0D9U:04Z[C@14]Dd0@;Q<04:^D`0m[5<0=k5>03J]E@0lWf<0AIQW042HI`0nX680?jUO03f`
H`0n[FH0?ZYT03jRH@10VfD0A:AO04f^F01E[E`0F:]E05^SD01OWTT0Gj=505jR@`1RWTD0IiY?05nL
DP1LReP0F7YO061bI01SJfH0HWUR05f5H`1GRV80EXeP0080EY1E02H0EYA:056MA@1BYT80D:Lf05BS
:`1EX2d0EITT056J8@1?WQl0CJ@R04jW901:YR80BjLT04VU9`1:XB@0B9LJ04bC4P1BR0d0FG@4069V
001VE`00He0005Y9001M@`00ECh0054j001==P00Bc<004H]0016;P00@2d003hY000j9P00<R4002hN
000[6@009AL0024E00<07A8000H07@l001T>000E300040T000/500060P0=000000`0oooo000:0?oo
o`P0000000/00@00008100040@001P<000`6000D2P005Pl001PA000K4P006Q<001`C000301lD000W
028F000S60009Q80028D000S50009aT002LL000]7`00<24003HT000i:000>2D003/V000j:@00=bD0
038N000_6`009aT002`L000e8000>2L003`Z0012;P00A2/004<_0015<P00ACd004990011D040@U@1
045A0P14CP40B4d104]>001AC`00EeP005IO0@1DH`40DfD20080Dfd202L0FG4105ef0@1RP@@0GHd8
04fH500iWbh0:J9802BUAP0WY3`0;:Df02ZU@00SXe808I]U026BK@0NRg8078Yc01^@L@0KTfl06Y9b
01R@M00JRgD06Xah01N@O00ITG/06IQi01VLM00KWW8079Qf01Z?O`0HOHP06Vb@01eFV`0QB:408d:U
02i0Z010>J@0D36Q05`/X@1W:9l00P1_8i`09`1g8IT0NR:F07DTT`1b9940Lb6?07`MS0276HT0TQN@
09PCT`2O4IH0WPn@09X<T`2D39P0S@ZJ08L9V0222I@0L@^C060=V@1A4:80Bb2W048^Z00l>jL0=D:S
02a9W@0RCIL07dj>01i@R00NDXL0765m01a/N00MM78087MZ01mmI@0UPVH0:H9X02b9IP0^U640;Y]N
032HF`0203JGE`0W03fFF`0nSed0?HET03j0IP13QfD0B8iR04NCIP17U5l0@Y=O04>@I011SfL0@8e/
04>;K@1:QfD0B8AQ04>4H`14QUL0AHED04>8F@13ReX0AXMS04moIP1?Of80CgiR05MkG01POU@0I7iC
05b1D01GOU00CgEO04U`JP18K6P0BfEZ05=_H@1DMUd0DV]X05]TJ01[Ff/0Odm/0080NEAW00X0MUUU
07QPE01cMD80KH4j06j3:01/OaH0J6l906]Y101/I@40KUl00P1[G0006`1/G`00Jf4006iN001ZF`00
J5P006]G001ZGP00K600075N001cG@00MEd007=S001fI000NF<007ib301jRAX0U8lX0:=h>02ULc@0
ZVXe0:5UAP2GI4h0SV=L08AUH`1lH6T0REUV09QHG@020:AHD`0W0;9HD02]E540We==091GD027EE@0
QEEG08YFC@2<Ed@0WU@f0;Y=;`2oADP0^45P0:iAH@2WH5H0X6EA09ESE@2@JeX0T7IE08efE`29LeP0
RgA?08mcB02@P3P0PYPW08V@602;P@D0SWh108f0002CR0<0VI@A09NF7@2OU2L0Yi<]0::C;`2LR3P0
SHha08:=>01fVcP0LYdi0080KjHk02L0LK<e06^g<P1Z^3D0J[]406NiB01]]480Kjd`07:]5`1//b80
JK]106K0BP1T`480HL130631A@1P^DL0GkA8062WC01OUd`0FhI>05n5DP1WQel0GHQ[05:?J01BYe/0
C[Q>056bD01EY5P0F9=K05^>DP1MUD@0J9/m07:O=`1hWST0MYTj07NG>`1aVCL0Ki/^06bN9P1/XRX0
0P1VXb`09`1PX3<0FZ8g052T?@19/T@0A;e=04NlD@15^E<0?[=C03^fC`0m]U80B:]H052QEP18X5<0
?ZMB03^_E`0i[Uh0>JER03RFIP0kTFH0?HeW042@H01:T5l0D91P05BCF`1HS5X0G8EC0668C`1QRe00
J8UD06f:GP1YQV@0IW1V069TJ@1aH6/0PV9/08=/JP1mLf`0I7QW05IgI@0205J0G`0W05:?D`1AWTX0
CjM304jZ?P1=Yc`0D:8k056J;`1?VBX0C9`V04ZU9@1;XbD0BZ4R04bQ901<WB<0D9TN056F5@1?TA80
D8TA05Mj1`1MJ000HUl0065G001MC000FTP005@n001>>000Ac4004<]0014;P00@B`003`X000i8P00
=280030M000/7@009Qd002@H000S50007Q8000806Q0000H060l001L?000G3P004PX000X500060@0=
000000`0oooo000:0?ooo`P0000000/00@00008100040@001P<000`6000D2P005Pl001PA000K4P00
6Q<001`C000301lD000W028F000S60009Q80028D000S50009aT002LL000]7`00<24003HT000i:000
>2D003/V000j:@00=bD0038N000_6`009aT002`L000e8000>2L003`Z0012;P00A2/004<_0015<P00
ACd004990011D040@U@1045A0P14CP40B4d104]>001AC`00EeP005IO0@1DH`40DfD20080Dfd202L0
FG4105ef0@1RP@@0GHd804fH500iWbh0:J9802BUAP0WY3`0;:Df02ZU@00SXe808I]U026BK@0NRg80
78Yc01^@L@0KTfl06Y9b01R@M00JRgD06Xah01N@O00ITG/06IQi01VLM00KWW8079Qf01Z?O`0HOHP0
6Vb@01eFV`0QB:408d:U02i0Z010>J@0D36Q05`/X@1W:9l00P1_8i`09`1g8IT0NR:F07DTT`1b9940
Lb6?07`MS0276HT0TQN@09PCT`2O4IH0WPn@09X<T`2D39P0S@ZJ08L9V0222I@0L@^C060=V@1A4:80
Bb2W048^Z00l>jL0=D:S02a9W@0RCIL07dj>01i@R00NDXL0765m01a/N00MM78087MZ01mmI@0UPVH0
:H9X02b9IP0^U640;Y]N032HF`0203JGE`0W03fFF`0nSed0?HET03j0IP13QfD0B8iR04NCIP17U5l0
@Y=O04>@I011SfL0@8e/04>;K@1:QfD0B8AQ04>4H`14QUL0AHED04>8F@13ReX0AXMS04moIP1?Of80
CgiR05MkG01POU@0I7iC05b1D01GOU00CgEO04U`JP18K6P0BfEZ05=_H@1DMUd0DV]X05]TJ01[Ff/0
Odm/0080NEAW00X0MUUU07QPE01cMD80KH4j06j3:01/OaH0J6l906]Y101/I@40KUl00P1[G0006`1/
G`00Jf4006iN001ZF`00J5P006]G001ZGP00K600075N001cG@00MEd007=S001fI000NF<007ib301j
RAX0U8lX0:=h>02ULc@0ZVXe0:5UAP2GI4h0SV=L08AUH`1lH6T0REUV09QHG@020:AHD`0W0;9HD02]
E540We==091GD027EE@0QEEG08YFC@2<Ed@0WU@f0;Y=;`2oADP0^45P0:iAH@2WH5H0X6EA09ESE@2@
JeX0T7IE08efE`29LeP0RgA?08mcB02@P3P0PYPW08V@602;P@D0SWh108f0002CR0<0VI@A09NF7@2O
U2L0Yi<]0::C;`2LR3P0SHha08:=>01fVcP0LYdi0080KjHk02L0LK<e06^g<P1Z^3D0J[]406NiB01]
]480Kjd`07:]5`1//b80JK]106K0BP1T`480HL130631A@1P^DL0GkA8062WC01OUd`0FhI>05n5DP1W
Qel0GHQ[05:?J01BYe/0C[Q>056bD01EY5P0F9=K05^>DP1MUD@0J9/m07:O=`1hWST0MYTj07NG>`1a
VCL0Ki/^06bN9P1/XRX00P1VXb`09`1PX3<0FZ8g052T?@19/T@0A;e=04NlD@15^E<0?[=C03^fC`0m
]U80B:]H052QEP18X5<0?ZMB03^_E`0i[Uh0>JER03RFIP0kTFH0?HeW042@H01:T5l0D91P05BCF`1H
S5X0G8EC0668C`1QRe00J8UD06f:GP1YQV@0IW1V069TJ@1aH6/0PV9/08=/JP1mLf`0I7QW05IgI@02
05J0G`0W05:?D`1AWTX0CjM304jZ?P1=Yc`0D:8k056J;`1?VBX0C9`V04ZU9@1;XbD0BZ4R04bQ901<
WB<0D9TN056F5@1?TA80D8TA05Mj1`1MJ000HUl0065G001MC000FTP005@n001>>000Ac4004<]0014
;P00@B`003`X000i8P00=280030M000/7@009Qd002@H000S50007Q8000806Q0000H060l001L?000G
3P004PX000X500060@0=000000`0oooo000:0?ooo`L0000000d00P0000<100060P0020H000`5000?
2@004Pd001T?000K4`007AD0020D000O4P0081@000<091D002H09QX002LG000V6@00:aX002/K000X
7000;Ah003DS000h:000?B`003l[000n<000?R`003LW000f8`00<b00034P000f8000>BL003`/0010
<000AS4004Dd0018=P00B3/004U50018DP00A5d104IM0`1:F`<0Ce81059A001GD@00FEL005YO001H
J@40Ef`205A^0P80DWD302L0DWT305Io1`1MR`/0DYHA03fL8`0[Wd0089iK022QFP0SXE009Z1;02BM
D`0PVF<07i5e01n;M`0LQWL06XQf01R?LP0HTfh06I9_01^=M00JR7H06XUh01V<NP0JTgP069Mj01bI
MP0MVGD06i5i01Z4P00ILhH076>@01i?V@0U@Z009c^U034jZ@0o=ZH0Cc:U05X_XP1S;:000P1Z:Yd0
9`1a:IX0MBZH07D[UP1f:i80N2Z=07lVRP298hL0UQj;09`KT@2S5i<0YQ:?0:<@T@2O3i<0U0fF08T<
UP1o39L0KPfI05XBXP176JX0@2ZZ03PjZ@0_B:40:E2I02IDTP0PE8/07EB401UFP@0EFH<066El01Uc
L`0MNVh08WiW02F2HP0UQVD0:XQT02j?H@0^V5h0<9aL03BGF`0203VCFP0W03f=G`0mRF<0>hAV03b3
J@13RF80Ai1O04RCG`17Uel0@YMM042BI@11TF40?haW046;J@14RF@0B8QQ04>3I018QU`0BHQL04Z5
H@1:RV<0C8QT0567H01AQUd0E8AM05^0FP1RPTl0HXA<05R2DP1COEP0BWEP04M]I`19LVD0BW=Z055h
H`1CMel0EfAZ05iKJ@1_EVL0PeEM0080NUaJ02L0MEeE07MTB@1/OcT0HXLX06An601XKPX0J60106aP
001ZG`00J5d006MH001/G000Jel006US001^HP00L60006iP001`H000LV8007AU001hI@00NFL007YT
001hI@00NfT107][1@25QaX0PIL[0:24;02YKc<0WFU209]WA`2CGe<0Q5mN07MRIP1mJV@0QVAW08mK
HP2KFE400P2XFT/09`2/G440[5dn0:EJ>`2DG3h0M5YH071@K`1dEFX0LeYT08=LA02YERT0]4ho0;=<
H02[Ef<0YFMK09Q]E@2>J5T0QVmF08MbE02<Le<0SW=C095iB`2COd00Ri</082G602;RPX0SX<108n6
002BR000UYH80:2I702LSb`0Yi@^0:jB>02XUc80YHdd09N=;`2?RST0P94n07JF>`0207:Q>@0W06n_
=P1X]CL0JK]306VhD01X]U80KK1<06b[>01[/200Ik4U06:j?`1P`4X0HL1405g1@`1L`4D0G/1505^c
B@1LVT`0I8a=07AgCP1_O580Jh9P05V9I@1>TfD0CjQK052iB`1C]4l0D:IK05JCG01HT540GIE406>H
?`1WUc`0JYTj06nB?@1dRd00Jhm006>D>01SUc<0Hihd0080GZTb02L0Fjhe05R]>@1>Zd00AkE704O0
D@16^eD0@[EG03VdDP0m/Tl0?:iB04bZDP1FYDh0E:=<04N]B`0l/UD0?:eJ03VPGP0fRFH0=hMV03V2
I`0kN6@0?g5W04Y`K01>LfH0FF][06MQJ`1WHFL0J6MS07=XI`1iJf/0Mfm_07MXK`1ZHFh0Mee/08QM
IP2=IF80QVYO06U_G@1JL5`00P1EOU`09`1AT5T0CJ=?04RaAP1:/T@0Bj]404^W@01;XSD0Bih^04ZN
:01:WB<0Bi`R04fI7`1?V240CY<L04f@501DSa80D8X?05253`1DN`H0EF/105aP001NE000GT/005a5
001??@00BSP004Db0013<000@B/003hW000h8`00=20002lO000]7000:a/002TL000V5P008A<001hA
000201/>000601P>000G40005@l001<900091P000`803@00000<0?ooo`002P3oool60000000>0080
00030P001P<000T3000=1`0040X0018<000F3P007140024F000S5`008aP0020F000N5@0202@E000W
02PJ000]6P00:Ah002TM000/7@00:b4002hO000c8P00=bD003X/000m<@00@C40044e000l;P00=B/0
03PV000i9P00>bP0040Y0013<@00A3D004Th0018>@00B3/0054n001=AP00BDh004QH0017H`40B6L3
04eQ0`1FFP40FUX005iL001PHP00HV`005e]0@1LL040EFd10080E7P202L0EGd605B64@1CSaX0AITT
036L=`0SVE4089MU02JKH00/W5H0;9mA02FLF00PU6L088ae01n9N@0KR7T05hUi01F>N@0FSgT05X]i
01R6O00HPWd068Ij01R<N00HUgH06IMh01ZFN`0ITGl05XR001AkQ00FK8T06En?01a?V00N@Yh08CbT
02TjY`0d>JP0@CNW04ddYP1F<:D00P1H;j809`1L<Il0H3>M06DbV@1]<9L0L2nE078]U@1g:YD0PbNE
08`QU02F7I<0VaR@09/GT@2K59@0RA:H07P@V`1Y49`0FQJO04@PY00d;JP0;SjW02Y:X`0VE9X095b?
029PR00MGh406V=i01QVM00EJGL066ie01]fK`0OOVX0989T02R6G`0YRV00;HaN036DF`0cVe`0=YiL
03^HG00203Z@H00W03^5H`0lP6D0>h9U03f7JP12SF80@iAL04BEG016UF00@iET046BI`11T640@8iS
03f?HP10SeX0@HaK03n5H016R5X0BXYH04j9G@1@R600DhYM05J:F@1ER5H0FX=H05n1EP1TQD/0GX9>
059nG@1;NF<0AFeW04IZJ@17M6L0AGM_04YfK01CLFH0GV9[06ALI@1YFel0MEaK0080LfU>02L0L715
07Ae?@1]Pb/0J7`I06U^2`1ZH`@0I5`006=K001SG000IEd006IN001/H@00K6@006iT001^H`00Kf@0
07AW001fI000MVD007MZ001kI`00OV`007iY001oJ@00QGL<07^6602CTBL0WX100:Ue<@2UKCd0TVI<
08mRDP2;GeP0N6IL06UXGP1dKE/0PFaO08USG`2BG5`00P2GGeP09`2HJUP0UFiC09AWD@2BHe80SUYF
08]=GP29DEl0REYT08ATB02QHR`0[UPi0;1EF02UHf40WG9M09AbF@28Jed0Q6YH08E^DP2=L5@0Sg=?
08j3AP22US`0Q9XT08>93@2;Q0D0SXT0092<002HTPT0V9`A0:2I7`2OTBX0XI8`0:V=?@2RUCL0ZXPm
0:N6?@2IPT00Q8A007RB>`02072U=00W06nb<P1_^c`0KKY406fiC@1]/Dd0Jj]706j]?@1/]2D0Jk<Q
06Nf<`1S_S`0I<A006;4@`1K`T<0Fl1805NXC01HQE40N75D0:MRD02>K5H0MGUQ05b:I@1<UVD0Cj]J
04nlCP1@]UH0CjaI05RQC@1RWT00JY/j06NJ?P1XVT00JI`i06jH=`1cUSP0J9<f05jC<`1NVBd0H:@/
0080HJl^02L0Gk@`05^_<`1?/CL0AKM104RlD018^eL0@K]H03^fEP0k[Tl0>j]>04N_AP1;[d80C:Q7
04>_BP0i]5@0=;1F03FWG@0eUf/0=95[03:8K@0hKfd0@5ma04eOM01NHG00K5ee07iDLP1nEW<0Nea[
08AQJ@2>HVh0Rf]Z08A/J`1cK6`0K6E[079JJ01_I5/0KfQI05m/EP1FKeP00P1?O5`09`1<RU/0BZ9F
04JaC`18/d`0BK1704N/@P18Z3`0Bj<h04RO;011Vb80AILK04VG7P18Ub@0B8dI052:401FRPh0EXD:
05:02`1FN@P0FFl305QO001KDP00Fd/005M5001@?`00C3T004Pf0017<000?R/003LY000g8P00<B40
02lP000/7@00:Ad002LL000T600081L001dC000201d@000601X?000F40004`d000l900090`001@40
3@00000<0?ooo`002P3oool50000000?004000030@001@<000T4000<1`003`X001<;000E3P005Pl0
01XA000N4P008AP0028H000O5P007a@000808AH000@0:AX002dN000]8@00<B400P0_80008@0_8P00
<b4003LT000n;000@bl004@e0014=P00?Bd003TX000j:@00?Bh0048b0017=000BCd104Q40P17A040
BdP1055;0@1AD`40D5T104]K0@1<F`00DEh1059S0@1FH@40FU/005iL001RH`00HF`005Ud0@1EM`00
EG@205Md0`0205Mm100W05F23@1@SAl0Ai0a03VF?`0WUU80899U02BAKP0_T6T0=YEN02jKE`0WVEd0
8XmZ0229M@0MR7H06HMg01N7N@0ER7l05XV101R5P`0GPXH05h2501J7O`0DSGX05iQh01RGN`0MSh00
5hJ4015nR00?L8/04FB>01AITP0GCYL06TBM01dlXP0S>ZL0;3VX03PhZP13=J`0BS6^0080BC6]02L0
BCFX04lhYP1I=J<0I3:P06HcX@1U<jH0IS>W074_X01m:YX0RBBC094OS`2E78h0V1N>084FUP1X5IX0
DQBQ04DNY00c;ZH08d:U01eCX`0PFY`08EnC025UQ`0NJGl06Fek01YbLP0FNfX05H1[01R0K`0MPFT0
8XES02R7H00]ReX0;91F03:FE@0gW5D0>YmD03jPE`11UeX00P0nS5l09`0mPFL0?WmY03n3J@11RVT0
@8mQ046BG00oTEd0@Y9P04:AJ011S6d0@HmU042@HP0oTf80?I=G03^=F@0kQF40@H]J04b@E`1DSE`0
GHQK05Z7F@1JR5@0GHY>06F5C01VPDd0IHI805j4C01>P640B7MV04E]J013KFT0A7AY04IaKP19JVl0
E6AZ06QKK@1/G600IUmO06ePE`0206a_AP0W06An?01WQS40KX8M075c2`1/I`@0J5l106AJ001TF@00
If0006US001]I@00KVD006eY001`K000LFT007AV001hIP00NV@007UT001fI000O6L007i[0020J000
Ofh108R95P1lUbh0VXDc0:E]>@2OLc`0VFe608aWD01lJUL0M6iK06mbE01WJUD0LVIH08QQF`2MFEd0
YEAQ0080ZEQN02L0Z61N0:ITHP2UH5l0Y5eJ0:YFE`2`AeL0Z4]J0:5@I@29H5H0Wehe0:YN>`2[FEH0
WVMR09AeG`2?M5h0QVIP08IPF`27Ie80Rfe@091kBP27S400LZ0_07^B6025P0D0Rh0008Z5002>RP00
UYHA09:D902STR<0Z8`^09n?=`2VQC/0WH/i0:Z7?`2OS440Ri9107bL?@1fZ3H00P1d/2l09`1^]b`0
KkPb072h?01a]4T0L[A806jaAP1_/T00L[Hb076c8`1Y/Rd0Hk/f06?1>`1O`3`0Fl0m05g0A01H]Dd0
EieC06N=E@22PUP0MhEH06^9GP1KUEh0DImI056aDP1?^eD0CkAM05:bE`1KZTD0IIld06>I;`1OWSX0
H9Y006R?>P1aTC/0L8he06:D<01IV300FJ0_05Z]:P0205fe<`0W05bh>P1H/CP0Cjlk04J]@@17ZTP0
B;I?046iDP11/UD0@;5@03^^BP0n]400@[8j04>V?P10ZTP0=k5C02n`F`0^[6P0<j1e02nBMP0^QWH0
>6Uh04IBNP1HDG`0K4el08E;P02MB800V4ek09IEL`2PF6`0Z5][0:9NJ02KI6L0OV]V06iUH`1TGUh0
G6AN05Y^HP1ALF80CgAM0080C7QH02L0D8AJ04^MF@16ZeD0AZa>04J/@`15ZCd0AJDf04RN=P13WB/0
@Y`T04FG7018V1`0AYLN04V=5@1@R0d0EH<;05J02P1FOPT0E7L805Q]101HH@40FUH005];001CA000
CS`004Pg0016<@00@bX003dY000h9P00<b<003<O000^8000;1l002`K000W6@009AP002<E000Q4P00
0P0M4@001P0I3`00610001D>000>1`001`@000@200d00000303oool000X0oooo1@0000003`050@00
1`8000X6000=1`004@P0018;000C300050d001T<000J3`006Q4001hC000N6@008aT002DH000202XJ
000502dM000`8000;b@003<T000c8@000P0e8P00800f9000>bP0040]0011<@00AS@0044f0011<@00
?b`0048]0015<@00A3H004Po001:B@80Ae@504UG101<G@<0DF8405A[101@K@<0DFh4055X101EJ0D0
EfH405ES0P1JGP40GV0006EU001PLP40Dg/104em0P1:OPP0CX4>0P1?Pa809`1@R1d0B8X[04::=P0h
Sd@0:Y5K026@KP0RTGD0:Xm]03BBG`0_Ue/09iAT02F:K@0RQWH078Ef01Z5M@0HPWP05X>001J5Q@0F
PHT05gn;01ImQ`0CPX404hQm01JDN@0ITg`06Xj001J2Q@0CNXX0472=015STP0DFIL05TnJ01Q6W00L
@J008CfQ02PlX`0b>JH0?3BZ044][002048][00W03laZ014=:H0CC>V05L_Y01I;ZD0ES2Z05DdZ`1P
=:L0KS6P07/[U`239i40R2:@08`MSP1c6iL0EaZO040JY@0e9jD093fR01EEW`0DIYP05fZA01UWS@0I
Jh@06G1k01QeN00GOfd068eV01RAJ@0MRfd08XQT02F;G00[S5/0<91D03BHC`0gWdh0>Z9>03fSC`0o
We@0@IYH0080@I9N00H0@8]S03n:I011SV00@I1N042BF`11TU/2042BGP0O046BGP12Sf<0AY9L04JF
F@11VE/0>iQG03N@F@0hQV00@8aI04ZAEP1FSe/0GHQN05V6E`1GPe80FXM>05b4D@1OQ5D0G8MC05J1
F@16MfH0A7MT049gI011N6P0@W]V04A^K@19H7<0FemW079JH`1cH5T0IF5C075RD00206]e@@0W05b6
=@1LPb80K7/?06iV0@1XH000IEX006=J001WH000K6@006mZ001aK`00LVl0071/001`K@00LFT007ET
001gH000MV0007MQ001hHP00NVL007e^0022M0L0OX@B09:@8P2COd@0XWPc09e_?P2@M4/0TV]?08MX
E@1fLUP0MgEE07MdBP1`LTL0Lg9:07mYC@2;HTh0TeiE0080TemH02L0TV=I08mTF02?H5/0TEaN0:MD
E@2aD4/0[dY<0:]7EP2GE5@0VeU30:5O@P2LGED0TFaL08QjGP26Mel0Q6MQ08EQG024HED0QFa@08Ig
B`20SSL0MiDH08663024OP80RH0008b60@2AR`H0V9LH09R;;@2RSbd0ZX`e0:J>=02VRC<0UXXl0::;
@02>Ud@0NZA007>]>01d]2h00P1b]BT09`1e]BT0L;H]06nd>@1^/DP0J[=906ZcB01Z/d@0JKPa06^d
:@1X/c00H[Tg05nl>P1M_3h0G<0o05S0B01F^dX0D[UD05>]F01HWV40HY5N06N>HP1GVf40CZIH04b`
E`1;]V<0CJiP05:/C@1OZ3T0HIh]05jK<01NWST0Hhi206V3A`1fPdX0LXU406:@@01NVc/0GZTi05jb
=@0205Vj<`0W05Ni<@1G]2h0DZlg04b_>`1:/400B[M604JfC@15]U<0?kU?03RgBP0k]ch0?[8k04>V
?P16Z4D0@:i803baC@0j/UP0>:UQ03BOHP0]Uf40;hUT03R4K@13MGD0CV5g069GN`1hCH00R4Yn09a:
N`2YCWH0/4ma09eBJ@2?GFD0O6=M07AYE@1^KU80I7=H05YmH01DPf<0DH1S0080DXMI02L0Ci5G04^O
E@18YU80AJE604FU>@14Xc00A9`Y04ND:P17TbT0BIHY04VC8018V1d0AI@K04N:5019Q`d0Bh4<0560
401COA40CgD;05=]1@1GH@00F5H005U;001C@`00CS/004Pe0010<@00?2d003XZ000h9P00=2H003@T
000a8`00;1h002TK000U5P008Q@002<E000O4`000P0L4@001P0I400060d001@:000<1`001`@000<1
00d00000303oool000X0oooo0P0000004P000@001@0000H1000:1P003`L001@;000E3P005`l001PA
000H3`005`h001/A000M4`007A40020E000R6000:1X002XM0080;b0000<0=Al003PT000e90000P0f
9`008P0h9`00>bT003TV00109`00@R`004D^0016=P00AcD004@d0015=000ACT004`o001?A@@0CeD8
04]N2`13KPh0@W4;04Md2@19N0L0B7h704ao1P1?O@H0E7/805=h2@1DL`X0F6/605mT0`1TJ@<0IVd3
05mj0`1EO040AX0404>64@10RQl2046=:00W042=;P0kRCT0?HDn03R9B@0bRf009Xi^02:?L`0XSf`0
;I5P02NAGP0QTFH08hm]02:>M@0MRW@06H=d01N1N@0FQ8405HJ:01J2S`0ENi004WN?011lRP0@P8P0
58V501V:P`0JR8805h:501IkQ`0GLHX05VJA01QMU`0JDid074ZN01m5WP0R@9d0:3bO030gW`0g;Z80
>bRV0080>bRY02L0?2^W040]YP14:jP0BBVY04L]ZP14<Z/0@3NZ04XhY`1J=j@0Jc>M07<^U`1b:9H0
LbBE05dSV@169Il0<B^Q02XjW`0PC9/06UfE01Q/SP0IKhP06Vb501Q_O00HN7<05hA_01Z?I`0NV6D0
89UX026@J@0YRV40;8]J036=E@0fTe00=Yi<03NUBP0kYTh0?JE@03^QE00nVUX00P0oUE`09`0nTf<0
?Y5O04:EG00oUUT0@Y=L046DG@0nU5h0?YIL03nGFP0mUeP0@iMA04BKC012WT`0?Ye=03^HD00lT580
A8mE04fBE`1ESUl0GXQO05^2EP1IPd/0EXU;05N9DP1FR5l0DHQN04YlI@0oJV`0@7AV041jIP0mOf/0
A81/04Y_K`1@GW<0GUaW079JH01cHE@0HVM<06MWCP0206Qj?00W05n2901SNa<0JW4806]U0@1XH000
JUl006UO001[I`00L6/0075^001dL000LG40075/001_J`00MFL007EU001hH@00Mf<007QS001fI@00
NVL007]^0P1mPQ@0MY4R09Z4<@2PJDT0WFli09U`A`2=LU@0Pg9I07=eG@1aMEL0MfEG07aWD@1jJDh0
MVI@071QDP1fH5P0MeaN0080M5US02L0LUYX07=IJ01jCfd0ODa[08aEG02ZE400[d/k0;M3?@2OBDd0
VU5C09MLD`2:IE/0Q7IM08=mHP25M5h0RFQO08=RE`22JED0PW1E07enB`1nR2X0PHH;08=k0@24N000
QWd008Z:1@29UPd0UY/L09f7<P2MSc<0[8Tk0:2>>02ETCH0SI<n08jFA020WTH0M:I107BY>@1g]C40
0`1e]RD09P1g]SD0LkLm07:dBP1]/4`0J;5?06NeD@1T]CP0IK0[06N^<P1Q^3/0H;Ln05^fA01F_TL0
D/1504g1A@1@`4`0CZm@05JIE`1SSEH0IhUI05N?GP1=Veh0BJQT04NTK@17XfT0DZ]905ZR<P1FUS00
E94j05V?@01JTD40G9A105nM?P1QZ3X0G:Xh05ja=01N]S80GKP/0P1K^BT09`1I^BT0FKD]056g>P1<
^Cd0C;M604b_C01:]T`0AK]@03g1D00f_T`0=;Q303Nc@00mZTH0@Jm8046cA010]d<0>kID03V^F00f
XeH0<jIA036XD00d[U`0=i]X03YgL@16IgD0F5Al07a9PP2N?hH0ZCf00;0nO02?AWH0Me1_07AKJ@1f
HF40NfEQ07e]I@1RPF@0C8YS04^@H@0204RNF`0W04ZVF015Z4l0AJ]404BV=P15Y2H0AYhO04VH7@1:
Tb00CI4R04nA9`1?SR40C90K04V@6018RQD0AHH>04B03P18OQH0BWXH04Y^4@1?I@H0CeT105EB001A
B@00DT@004`n0014=`00@C4003h^000j;@00>BP003<W000d9000;b@002lO000Y700091L0028C000T
50008A<00080714000H06A0001H<000A2@003@L000L40002000=000000`0oooo000:0?ooo`0D0040
00010@000P4000H2000;1P004PX001H@000K4P0071@001dG000M5P006a@001lD000Q5`008aD002HH
000S6`00:1`002`Q000b900203LW000W03/[000l:`00?2T003TX000h9`00?B/003l^000n<@00@2h0
040_0012<@00@cD004@h001:>`00BCh004U70@1>D@@0Cf4=04eb6`17Nad0?X8I04254`13R0`0@h@7
04V41P1AP0D0EGl605Eo201FOPl0EGX<05Md1`1NKP@0I74706=i2P1PP0D0E8D204V7200oRaP0>I8]
0080=i<e02L0>Hhm03R8@`0eQTD0>8M=03>8H00WSFh08Hib02B=K00VSf008HaP01n8J00QT6T08Y9^
01^=KP0HQ7405h9i01F9Q00ERHh04h2C015cU00BKY403g>>00iiS@0AP8/05HB901V5Q`0JQ8D077f4
01ecR@0JJ9807F6H025GW00RCYh08dVM02E4V@0X>iX0;3:H03@VW00g8J800P0g8:D09`0g8JD0>R6V
03/OZ@0m8J/0>BRZ03@_ZP0_=jT0=cbZ04PmZ@1K>JH0Gc>O05``VP1J;9T0BBbJ03HdVP0S?YT07djH
01iIU00JI9405fn901QbP@0HKgh067=g01V1K00IU6L07IeT02:RHP0TW6<09YAU02b=G00aTU<0=Y9=
03VJB`0lXdX0>JQ;03fXCP0mYU40>Z5B03fMF@0203fKG@0W042HH@10VEd0@I]J04:HFP14Tel0@iER
03jFHP0oV5L0?IYA03fJD`12VTT0@9e103jO@`0lWdP0?Ie>042KD018UE40Ci9F05J>H01IREd0FXM@
05R5@P1ER4L0EH]@04n?G@1:S5X0@X1N03i^I@0nMV00?WmR0422K@19Ofl0DfU^05mIK`1UGFD0MeUR
07EUE@1ML4/0EVmB0080Ggdf02@0IWlF06Yd1`1[K@80JF@006YT001YI@00JfX006m]001`K`00Lfd0
079`001`K@00L6X006mX001`H`00LF@007MT001iJP00NVX007M_001kL@@0PWd<08F?8@25Qd00WWLf
09E]A`2?MDP0Tg1E08QaGP1jMed0KgQQ06mdFP1dHeH0NfIA07i[DP1iJE8207=XF@0I071RH01]H6H0
KF1V071MIP1hDf`0NdQb07]1L01oCUl0Re970:=>>02k@S00Yd=>09I3H`2:EV00OF]M07MnG`20OF40
Qg1O08UVEP24IU<0QVeC08IkB@1kU340QI4G08B31@02085g000?08Am0027Q`L0QiL?08jP7@2NSBh0
U8he09n:@02?ST80R8i6086EBP1iWD`0MZE;07J[@P1eYT00N;@e0080LKDY02L0L;DV07:i=@1c^ch0
KkM106j[A`1/Z4h0Jk5A06V`@P1X/b/0IkHY062e<01O]CL0F[4o05NiA01B`4L0D/1404nlB01=[dX0
CJ1;056EA01>TTD0CY9A04^HE@12WEl0@YYQ04>OD`1?XT00EY<m04j3@P1@NTP0EWi605N@>P1HWS00
EZXZ05Jb;P1K/c<0FkDa05Vj:01F]bL00P1G]bD09`1K]RX0Fk<b05Fb?`1B]440D;=6052YB01B]d<0
Bl17042mB@0g_4D0=KY003NdA00g[4P0?[1<03n^BP12/T40?KQ;03ZbD@0gZUH0>:QD03NXC@0g[e<0
>:IQ03V@I`0mPV/0AWId05A^N`1UJGl0KFAo075SO01UHWH0G6Q]05adIP1QOF<0I85R06YnH@1FREd0
BI5J04JJEP02046VE00W046[D010ZTT0@JTl042U<013XB40A9`G04RK5@18V1`0CIHO04fE9@1?TR80
BXlL04Z<6@16QAH0@h4@04Ak3014NA00B70@04YU2@1>EP80DTh00559001>A000D3l004dk0016>000
@C<0040a000m;@00>2/003LV000e8`00;b4002`M000X600091L0028E000Q50007a800080714000H0
5`h0014=000A20002PD000H30001000=000000`0oooo000:0?ooo`0:004000020@00108000P4000=
2@0050h001TC000L6@008Q`002@L00808AT000P08aP002DK000Y7@00;Ah002`O000[8@00;R@003LX
0080>RT002L0?c0003lc000n;000>B/003/V0010;P00@S@004Df0015<P00@cD004Df0019?000CD40
0515001@BP00D5P304iZ2P19O1d0@hLb03f=<@0jTRT0?I@N03jB4P10S@P0AXX50566101IPPD0Gh08
069o2@1PN`P0HGD506Eg1P1NNPT0G84805R:201CS0D0C8`<04NB7`0mUSD00P0gTSP09`0kScX0>Xm1
03:@A`0_Sdl0:IAL02>FJ@0QUFl08i=X022BH@0JS6<06XMV01fBIP0PU6/07Ha[01R3M00HPGX058R6
01>6U00@NIP04FNI019RUP0DJ9<04G6@01=gSP0DO8d05h6901^2Q`0MNXX07W:?01aWUP0OHid08e^P
02IFX00UD9l09dRK02TnV@0/=9T0<BNK03@QW@0203PMXP0W03TNX`0k7jD0>ajX03XQZP0d:ZT0;C2X
02LiZ00[@:X0?4:Y050nY`1@=j80B3BN04LbV@0j=ID0:D6C01Q@T@0HHHl06FN?01M/S00IL8H06G9m
01Q_OP0IMG@06H]X01^PHP0QZUl08ZUN02BQG`0YVF40<IIE03JLC00hWdP0>J=<03^WC`0jZ540?ZUA
03nUDP0mWUH0?9eJ0080?YaJ02L0?YMM03nGFP10V5L0@iMH04NDFP17VUL0@ia@046MB@0nWDP0?9a:
042NA00nX400?:5503bPC@0mWe40?j5E04VME`1<V5`0BXiS056:G@1CR5<0EH1<0564C@1ARU40C99I
04B@F011QET0?G]L03moFP11Q600@X9[051kK01PJfT0LeaS07APEP20Gdh0NfM805iaBP18M4/00P1J
NbT09`1XN`/0JG0006Y^001YJP00JVH006eS001]JP00Kfh0079a001dL@00L6/006mX001aJ@00LfP0
07AV001eJ000MV/007Q]001jLP00O7X207Z23@1iT1T0T8`a09EeBP2EN400RGA907]jDP1eMEh0L7=P
071dH01bKF<0KV]O06eTFP1cIeL0MVaE07=`F01XKU`0IVmS06aZJ@0207AWJ@0W07iPIP2AEfL0VDY^
09PlL@1nA6T0JdiN07iAAP2[ACP0WcmB08e0I`22E6P0LfQR07=gH@20MV<0Qg5M08a]D@26L4l0RGAB
08J;@@1kXAd0Pi8;08J60@26OP00Q7X008N0002;R0P0PidD08bP:02MRSH0SHY008b:AP21ST/0O8m<
07VHB`1fY4<0Lk1007Fe?`1f]Ch0L[M00080K;Lf02L0Jk@d06^c>01/^CH0J[Pd076a>@1`/3d0LJi8
07:[@01b]Bd0K[TQ06Ni9`1U^3<0H[Hl05Vn@@1J`400EL1404jeCP1:We@0AHaK04AlF`14OUd0B8=P
04>6I@0nS6X0A9MH04NN?`1@VcH0E98h04n;@@1>RTD0Di0o05JN<P1IZ2L0EZlT05N_:P1G[2d0F[0V
05Vf801I]Qd00P1I]2009`1L]R<0FkHU05Rd<01G]SX0D[Lo052hA01B`DD0C/1704FjA`10^D40>;/o
03Rd>P0jZd40>Zi803b`A`12/SX0?;Dh03ZgB00i]EP0>:YE03VND@0dVe<0=IIR03F=JP0lPfd0?Wed
03miM`15MWd0B7B204UcQ019Kgl0B79c04iiL@1@PG00D8=^04n4K019R6H0@I9O046KE`0203fTE@0W
03j[C`10[400?jLc03fT;@0lX2<0A9/N04>K6P12WA`0@Y`O04JG8@17U240AhhP04R86@17PAL0@h4B
041l2P11M@/0A6`<04iM1@1;CP40CTP004i7001=A000CD4004hl0018=@00@S8003`/000h:000>2H0
03HV000c8P00;R4002/N000Y6P009AP002DE000T50007a@00080714000D05`h001<<000>20002P@0
00H3000>000000`0oooo000:0?ooo`0D008100050P001PD000X5000?1`005@`001TA000R5P008aX0
02<I000T6P009AT002LK000/6`00;Qh002hP000_6`00<1l003<R000f:00203P[000W03l]0010<@00
?2h0040/000m;@00AC4004De0016=@00B3H004Pi001B@@00ETT005]A0@1LF@<0F6D<051a5`18P2H0
?h/g03^DA00iVD00>I`f03ZJ9@0iVa@0@IH804N?1P1?S0H0EhL805f92@1NQ`X0GXH905j32@1JQP`0
EHX>05:;2`1?S@X0D8l904f?4@19UBD0@9Hl0080?Hlm02L0?Xdm03j;A00bSU00:heF026GF@0NVf80
7iQZ02BCIP0PTf405XiU01R8J00LTFH0799]01f=K`0LQ7406Wmi01MoQ`0CNY@046ZG015HV00CDYL0
5U^C01EXT00EKh`05WF;01MiRP0INXd07G:C01aZV`0JHj406fBS01]UX`0MHj407U^O01mBW00SAiX0
9cfI02`aU`0b:YT00P0f9Y`09`0j9Yh0?2BQ03dSY@0m9:H0=bVW030_Y`0]=JP0;T:Z03I9ZP0mAjD0
>D6P03=0VP0_@I<0:dN@02=?SP0HF8`06Fb701QfQP0IO8806gil01YoMP0KOW407H=Z01nGI@0OYel0
8JeM02J[G00ZY5`0;9iM032ODP0cY4`0<jM903JYC`0jZU<0>J]F03ZXE00kXE80>i]H03jKF`0203jI
F00W03jFF@0nUEL0@iIE04FEE016V5D0Ai]=046Q@P14Y400@j8m042Q@@0nXd40@j9004:RAP0oXU00
?Z1B03jQDP18X5T0BI]O04JBI@1;S5h0CHAF051hEP1<O5D0CX]E04NCG@13SEd0@HAL03imHP13PEd0
@giR04IdK@1DKf/0IfIV07aNG@1cITl0L6Y;06e[A@1RMCP0EWTW0080HgXC02L0I7H606M_001XK@00
K6X006mW001^I@00LF<007=/001eL`00Mfl007MY001eJ000MFL007QV001jK000Nf`007U]001kKP40
OGT907^74P1oU280PY8c0922@@2BK540PgIA07MkG01QPF40G75U069ZI@1aJVH0MFUV071ZG@1_J5L0
MF]H07EaF01_Leh0IWEQ06=dJ01ZKFX00P1dJFX05`27H6L0V5YR09a?H02J@6<0S49V07M9J@1_E4h0
WTTj09a3E029@V`0OUEZ079XHP1eM600QGAU08adF`2<NE00Q7e@07b5D`1iV3P0N9hA07f@1@22R040
Ph800080Q80000h0S8d<08FL7`28VC00THPo08F<B`1nVDL0MIY>07>BC@1cUDT0M:Dn072_>@1_]cX0
L;Ln072e=P80KK@c02L0KKHa06fb;`1_]RH0L;LR076e8P1a]bh0M;<i07Nf>01e^C40Lk`Q06^k8`1/
]R`0IkLg06>i>01O`3H0F<0l056fAP1;Xe00AiE?04Z8D01?SDh0DhmA0568E@1<Re<0BiQ<04fH@@1B
TSP0D9Dg04^H>P1;WcX0CJ<e04n/;@1E[BP0E[4]05J]<`1FY3D0FJ`/05Rb9P1I/b800P1N]B@09`1M
]B80F;PV05Ni<01F^Ch0DkU2056kB01@_D/0CkQ804f_A@14^4D0?<1003Fg>`0h/400>[=803ZeA@0n
[cL0?[4_03be?@0l^T/0?[1B03bPD@0kV5L0>I1R03b:J011PVX0@W]a045fL`14MWP0B7Mo04MgQ@15
MH00A7N104MfP017MGh0AGIi04:0M00jRFh0>iAR03JNF`0203ZVFP0W03Z^E00m[DH0@:Lh03nR;@0j
X280>IhM03^L700fWQh0>Z0Q042K7@16TaP0AX`G04V35`19Oa<0@gh@045i3010LP`0BVT<04UC101:
A`00CT4004`o001?AP00CD<004Tn0015>@00@c@003/Z000e:P00>2P003HU000c9@00;b8002/S000[
6`00:1T002DH000V5P008a<00080714000D06Ph001<<000?1P002@@000<2000>000000`0oooo000:
0?ooo`0D00H300081P003`P0018;000D300060l001`B000R5`0091/002HK000X7@00:Ah0030N000^
8@00;R8002lQ000`7@00;Ql003HR000h:00203T_000W03`^000m;P00@Bh0044b0011=`00B3X004`k
001A>P00D3l005A6001LDP00H5l3061]1`1INQ80ChPW04F:>P0nS4d0>XmB03FJDP0dWdL0=9m003RL
:P0mVaH0@YP;04^D2@1<TPT0Ci8@056B5`1FU1T0Ei8C056B501=UA/0BIPK04JF6015Tal0BI<P04ZE
9018V2`0A9`d0080@iHc02L0AI8g046>@00gST`0;X]A02>HD`0NWUP089aP02>FH`0MUf805I9V01J;
J`0HTF`06i9a01^=LP0OPW8087Yg01YdQP0EJi<055jD019:UP0DAYH05e:D01URSP0KK8X06G2901Mb
RP0HKi8066VN01MTY`0HGZX066>Y01UYYP0HK:D06V>R01YIX@0QCYd094JK02XjUP0c<Y<00P0k;9H0
9`11:iX0?bbM03hZX00m:J80>2ZS03@ZYP0b<JP0;d:Z02m?Z@0_DJL0:4jN021?UP0MD9407UR=01]J
S`0FH8l06GB201^3O@0KQgX06hYc01b?J`0LTfL07iES022NGP0QZ5T09J]F02ZZE@0`YeD0<jAG03:S
DP0bZ4l0<:Y@03BYE00fZUH0=JaH03NWD`0jXU<0?IUI03nGF`0203jFF@0W03bAEP0kT5D0@Y5B04BB
E015UTd0AYY404BT?@15YS`0AZHj046R?@12XT80AZ9204RSB014XU<0@9eB03nOD`13WeL0AIUN04BB
HP17SEd0C8UF0520FP1:QeD0BXmD04J@GP10RFD0?X9U03alJ@10O6X0@g1Y04ULK`1GGfX0K69Q08ET
D`1dJdd0IFa;06I]@`1VNBD0HWT;0080HWL702L0IW@206Q`001]K@00KVd0075]001cJ@00LVP0079Z
001cK`00Lf`007EZ001eJ`00NFl007]a001nM000Ng<007id001oN0@0OHPD07BL9P23T400OWiD085i
D`22JeP0LgmE06B5G`1ER6<0DGeW05YiJ01VMVH0L6mS079aF`1bL5P0MgAJ07UgFP1gMel0LgMM06ee
H@1/K6D00P1aIVT09`1oG6`0QU5^07UMFP1bHUT0QE5F08U9HP21FET0WUI;09EED`22DF@0N5aP071T
G@1fK600QVYW08YdH@2BLe40R7e@07>=C`1eW3<0NiX<07n=0P1oR000PhD008>20020Q000Rhh?08ND
:@27TSX0QhY4082HB01gYTD0KJE9072SC01][4H0K[Dm06jf=P1[]C<0K[H_06fg;P0206^g:@0W072h
9P1c]B40MkHK07Jf6@1g^1/0MkTS07Bh;@1e^C80MKd`07Nl:@1^]R@0KK8T06Zb:P1W]2/0JkHa06:g
>01H/4<0BYMA04FIEP10WU@0A:=:04^QB01;VDL0CI97052:B`1<RD@0CHdm04fI;`19X2P0AZLT04VW
8P1@ZAh0DjXP05J/9P1F[Rd0Fjl_05je;01M]BH0G[<T0080G;@W02L0G[@W05bg:@1G]ST0E;Q105Bc
B@1E/d/0DK]<04nfA01</ch0B[Pl04?0?@0n_3/0?kHf03Vf?`0h]Sl0>[0b03f];00n/CL0?;E403Zd
D`0g[5X0>ZQQ03JQJ@0eWFh0>Y5c03V7M@0iPWP0>Gmk03YoP00kPHD0>X6803inS@0nNXd0@7J8049e
P`0mPWT0>Y1b03NMI`0bYEX00P0c[UX09`0b/5d0=jeC03JZB00dYST0<j<`02nR:P0aX2L0<ilU03JM
900nUa/0AhhB04J:5@15PaL0@h8A03n13`0nN0X0@Fh604UN101<BP40B3h004Ll0019?000BCh004Tm
0017=`00AS<0040b000m;P00>b`003PX000f:000<RH0034T000/8P00:ah002XN000W7P009aP0028E
000201`B000601L<000B2`003@H000L300030P000@003@00000<0?ooo`002P3oool0500:1`003`X0
018>000H40006A4001hC000S5`008aP002HI000[6P00;Qd003<P000g9@00=bH003XV000f9P00<bH0
03HR000h9`00?Rl00P0n<P009`12<@00AS8004Lf001:>P00CD8005A7001JC080FU4505mK2@1UJ0T0
HgH<06243@1DSQP0BIP]046JC@0jTf80=Xe[03>AJ00bVe/0<Im=03NP?@0lX2P0@IlH04JI3`1BU@X0
EI8805NA2`1JTPh0FY8@05F@3`1@Ta@0@iTR03nN9`0iVc40=YHn03ZE@00nVT40?I/k03nO=00203jM
=@0W04:I>P0nU400=hm9036:CP0UVdh07j=A01bPF00NVF406iUS01FDJ00GSVd069=b01VAM`0MS7D0
7h5c01mgM`0KKH<05V6B01AAU@0D@9L05S^G01I7U00HFHh06fJ;01][RP0HK8l05VVH01ITXP0EGjP0
5eZZ01MPY`0FJJ@066ZO01YOWP0NEYX07dfJ0259V`0V@9D0;3^B0080=3NA02L0>3JD03DeU`0e<I`0
>BnO03H_X@0e;JD0=3>Y0355ZP0YE:X08eZQ01UKV@0CG9403ej>01EUS00GIhl066R=01]kO`0KRgD0
7I5b022EK00NWF@07j9O02>QFP0UX5T08jQD02R[E00_[540<jUA03:UE00bY5H0<:QE032ZE00bZE@0
=:aE03F^D`0hZTd0>jM;03jQC`11WTh00P0nWD/09`0nW4T0?iQ704:IA015V4<0A9a204JN?@13YS`0
@jXl04NW=`18XCd0Aj9604ZRA@19XdX0@j5B046LD`0oW5<0A9YG04BGF`0nTUl0@haL04Z:F@1?Qel0
AY1I04JED`10Se`0?XMT03moI@0nNV`0?gM/04I^K@1=GFd0FeiP06aTE@1oJTP0L7E505ifA@1PNC`0
HWdJ05]`0@0205i_000W06Ac001ZL@00KV/0075Y001cL000MVd0075[001/I`00KVP006iV001bJP00
N70007]g001nNP00PGd207j12024QQ40QX`M07ZH:`1bVCl0NH]<06n1EP1`PU<0Ih5C062@DP1HSV80
EHYW0562I`1KPF80JGeN07MfF@1iMeT0NWIJ07agF@1oMel0O7QO07UcG@1kKed0NfIQ0080OUYY02L0
PdUd08HkN01`HV@0KX9V07aUE02]B640WEiQ09YRE@2=G5H0NEMM079NG`1_HeX0LfUP08EWI@2<KV40
TG1H08QlCP1`U3T0MiHL07n;1P1lPP00O8<007n10@1nP040Q8<008^A3`2>T3<0R9Hl07ZI@`1gYTL0
LK1507:aA@1]/d80IKPo06G0?@1]]SL0K;D[076f8`1_^2L00P1`]BH09`1`]RD0M;HQ07Bd6P1b]1L0
MkLL07Nh801e]R40LkTT07?1;P1b^Bh0L:X]06fb9P1]/b/0K;<]06ji<01V`3@0GkHj05JPBP18Z4`0
@Ji<042^B@17Z4/0BY]A05::E@1KLE/0DGYA04R;@@19VB`0BZ@S04BZ8P19Ya`0CZDD04nV6@1CZ1l0
FZ`X05^b;@1L^S40G[X]05Rh;P0205Ni;`0W05Fg;P1E]SP0EKI7056dBP1D[e00Eji=05FfC01A^480
CKLf052i<`1>^Rl0BKT^04Nf;@0o]3<0@;8c03j_;P0m[c<0>[9803J_FP0dYVP0<Z5d03FMN`0dUH<0
<8Z802f0SP0bOI00<GJD03AbT`0fKI80>VZC045VV01:HIT0CUnI059PU01AHXh0BG6704:6P00kU700
=ZAV0080=j]K02L0>JaC03JXC00cZ4H0<ZM102nT>00ZXc@0;:0^03:M:00hV2@0?Y0J04>84`15Q100
AX4?04F0300oN0T0?Vd504=T0P1<E`00CDD004Q10016?@00BCh004/n001:>000ASL004@c0011<@00
?B/003/^000l:@00>BP003DW000b8P00;R4002lQ000/8000:A`002DI000Q5P000P0I4@001@0D2`00
3`T000`500050P000P4000h00000303oool000X0oooo00`03PT000l=000G3@005a4001TA000P4P00
8AD0020C000Q4`009ad002hN000g9@0203dX000603/Z000j;@00>RX003TZ000k<000@3800P16=P00
9`18=`00CCD004ho001AA`00Ee0005YI0@1PI@L0I74@06=k6P1OR1d0EY8N04ZJ9013Wc00>Ym703JD
G`0dRg40<i5_02jHK00XW6D0;Z9B03RU>`0mYBP0@J<O04^N601CVa80FI@@05VD3@1JU0h0EiH=05>F
3@1>Ua40AIhL03bO:P0iVc/0=YA;03VBC`0dUDd0=9E803BM>@0203RN=`0W03RN?00gVD00=Y5603>9
C00YVDX08J9901^SC`0LWUH06iaL01RHI00JTfT06YI`01ZDM@0KRWH07G]g01e`N`0JJX<05V2?01IA
U@0F@IP063^E01I6T`0HEXd07F::01i[R`0JL90066jG01MYW`0EHj<05EjU01EPX`0HIIh06F2M01aD
W00NC9`084VL0258VP0RAI@094RA00809TJ?02L09dJ?02A1T`0Y?IL0;CVK030iWP0^>Z40;3nT02U=
Y@0RFZ8076>J01UTT00FHXX0562<01E^S00GMhl067j:01^8N`0MTG007YM^022MJ00PXf808JAK02JS
E`0WWeD0:ZIB02f]DP0c/4l0<Ze@036XE@0_YET0<ZQG032[E`0cZeD0=jeC03J/C@0j[4P0?jY704:Y
A`11Z4D00P11Yd809`10Y440@:93046P?@13X3`0@j0j04BR>P12Z3h0@JM004ZU>`1?Wd80CYi8052Q
A@1<X4X0A:1E042KE@0oW5D0AYYI04:GE`11TU`0@HeL04^@G01>SV00AIEJ04>FD`0oT5`0?HMR03io
IP13MW40AG5`04Q]K@1@HFT0Gf=L06]YDP1iKTL0IW/m05J5<P1EPb80G7T>05M^000205]^000W06Mc
001[L@00KVl0075/001aK@00Lfl006iY001/I`00JFP006aZ001eK000Ng@007am0@21R0<0Ni8707NH
5@1cTBh0LhY007>;A01_S4P0JH]>05j8F@1LT5D0Ei5L05>LF01@VEX0D8mI04n;E`1JPeP0IgQI071d
F`1gOEL0OWiJ07mkF01mNe/0NgQL07]bH01iKV40NfUS0080ReaZ02L0UdeZ09LmJP1oEVD0KVeP08IQ
GP2^B6T0VV1W08mWH@22Ie`0MVQN07AYE`1`IUh0MFEQ08aQG@2?K5X0T6iJ08V1A01eVal0NXh>07em
0P1kM@00O7T007b00@20O`40PHX208bG6@2ES3`0Q9M407BT@`1eZDP0MJm707:^A01[]d40J/1006Vk
?`1[]CT0KKD`07:e:P1a]Bd00P1d]B`09`1f]240N;@K07Bc6@1d/QL0M[<K07Nd7P1f]a`0N;LP07S0
:P1f^bX0LkP_06fi;@1/]S80Kk8e06fi<P1W`380H<0h05JeC01>/dH0Ak9204Nb@01=Zd80D9M905:8
CP1GO5L0Ch9:04^>?@1<VBX0Bj@P04>X8013Z1/0@jTJ04^/7`1>ZbT0Cjl_056e<`1F]c@0FkLc05ji
<@0205bk<@0W05Zh=01H]TD0E[9?05JcC@1F/dX0EkA805JdA@1D]c/0D;@^052c9P1>]2H0B;@V04Bc
:P10/B/0@jdY04>[:P12[SL0?ZiB03VOI00iRW00>X5j03enQ`0iN8T0=Vn>03A[UP0hJi/0>6VL03aT
V00nHI80A5^D051GUP1HDi40GEJ;05mLQ`1GHhP0Cfn904ImQP0mRgH0=iUV0080>J=D02L0>j=703ZP
@00gXCL0=:4f03>Q<00]X2`0<9l[03BJ900gVB<0@I0K04:<5013QPl0@84<041j2P0oK`H0?f0204EI
001>C000CD@004do001<@000CT0004ho0018>P00B3P004Df0014=P00@38003T_000j:@00>BL003HV
000_9000<20002`Q000[7`00:1`002@H000O50000P0I3P001@0D300040P000P500040P000P0000h0
0000303oool000X0oooo00@04@X001D<000H3@0071000P0J40002@0L3@006Q00024B000U5P00:aX0
03DQ000i9000>bH003TZ000203XZ000303/Z000o;P00A3000080B3H002L0D3T005@n001FA`40FUH3
05QW1P1NM@/0GX0C05j<8@1CUBh0Bi`a04>Q<`0fXcH0<ZA202nIE@0_OfX0:WYi02^?L`0XUVl09IIZ
02bRDP0eZ3T0=ZT^03ZW:@12XbH0AihU04jL8@1@W1l0CYlN04bO6P1>WQL0CIhK04BR900lY340>J52
03RJB@0jU4T0=I1:032=B00bST000P0gSSl09`0fU3d0=i`m03>K@00_UDD0:Yi3026S@`0KY4L07J9;
01^PD`0LVF406iEZ01VFL@0GTGH0689m01U`OP0IJ84066J601MOT00GDIH0646I01XlU@0GAI00652;
01UNS00KJX`06gB@01]cT`0HLIT056ZN015SX00BGJ0055fL01MFV`0LBI/073nO01i2WP0OB9h07d^J
01iAUP0201aEU00W01YDS@0ICHh07TJB02M1U`0ZA9T09dJM02M=W`0SEi`06V>K01I/T@0GK8L05fR3
01IRQ`0HMXH06HF601ZAQ00OTgL08IQ/022LK00NWVT07ImT01jOG00TXEL09iiC02fSD00_ZE40<Ji=
032^CP0^ZU40<:QH036ZE@0aZeD0=JeB03V^BP0kZdL0?Za2042]?`14[Cl0A:`h0080A:Tg02L0A:Dn
046W@`10YS/0@ZDi04FR>P14Xch0@:I204:TAP19XD80DIY804nMBP1?WTP0CIe<04NKD`15VU80@Y]C
04JJEP17Ue40AI9C04F?D`1;TU40C9AA04>KCP11VT`0?Y9F03j:H@10P6H0AVm`04M[L`1?K6T0GFEQ
06MUF01_Je00N6m<06>2>@1DS240DH8B05Yf1P1LK0000P1SL@009`1VM000K7D006mc001bK`00L780
06e`001_KP00Kf/0075`001hN@<0OX@8086=301lUA00N:8C06^V5`1UY2D0IY@k06V=AP1_UD<0JZ14
062UC01CYU<0CZUE04^UH@1>XEl0CiMG056BE01CQe00FGaF06=aG01XJ6@0Lg5R07eiH01mME/0OG1K
07i/F`21HVD0OV5Z07mRM@0209=LL00W0:Y@F`2_@ED0SDiX08=ALP2KDFP0/DM]09IMKP23Jfh0O7IU
07]gF@1lM5@0Nf=Q085RG@2@HU@0T6iA08MjE022RcX0O8lD081n101kK`40NfX007aa001lO000QXH7
08^@402:UR<0Uhdo07nMA01cYTP0LZ1@07:LBP1_Y4L0KKA506JiB01Q^4P0I;Q006jd?P1`]SD0LkPc
0080MKT]02L0MkXR07Ji701f]QT0LK0C07F]4@1i/AL0O;@H07bf6P1i^1h0M[TU07?0;`1[^c80L;Db
07:_=@1a^300KL0Z06C0=@1K^TL0Dk=604^_A@1;^Cl0Cjm1052>C01BRDl0CHU=04n8?`1@ScX0Di/W
04^S7P13Z240@ZPM04B[8015[2X0C:hd04ba?01@/4<0EJi205Z_@01N]D000P1L^3l09`1J^T@0FKQ?
05Z^D@1H[TX0F;I705^g@P1J]C/0Fjl^05F[8@1AYaP0CZTI04Z[8P18[RH0A:`[04:Z:P12Ybl0@J=7
042DH00oPFd0BG1i05AXQ01AKH/0C6j804a]R`1;Ji@0A6NH041WU@10HY80@ef@04ULT01=Fhd0BeN:
04iLP@1;GW`0B6]l041dO`0mOX00>8Md03^BH@0203fJB`0W042K>@0nW340?YTZ03fL:`0iVB40=iPP
03RL800mVAd0?9HM03jB600oSaL0@8XE04243`0nO0h0@6h804MO0P1:D`00D4T004m0001>?@00Ccl0
04lm001:>`00BCP004Lh0017=@00ACD0040c000m;`00>b`003PX000c9`00<24002dQ000/7`00:1h0
02HL000U5P007a4000806@l000D04PX000d6000710000P400040000>000000`0oooo000:0?ooo`0D
01H>000K4@006a8001lD000N4P006`h001/<000L3P00818002/F000a8000>bH003d[000l:`00?R`0
03P]000j;@00?Rh004Lb001?=`0205E0000W05Y7001KD@40Gf4505Ua301BPa<0DI4M04fK:@1;WSD0
@:9003NT@`0`YD<0;JA302nOB00eSEL0>WYU03AkK@0]PVh0:HI]02R9I00/WdD0<:T]03JX8`0hYB00
?j8Q04BO8`1<WRL0C9hX04VP:P1:XRH0BJ8V04JT:P0lZ3P0<:U302VWC00bX4h0>9M<032<CP0]QDh0
;We<0080<GI@02L0=81;03:FA@0^XD<0;Im102RR?`0PYD007:A301fVA@0MXE807YMS01fBL@0IT7T0
58am01QjP00IHhH065V<01MMS@0HFY0065>C01Y:U`0QA9806TR?01Q;S@0GFHd06VV<01ahS@0MNI40
67JF01=_VP0@Jid04FBM019PV`0EEI`064FM01/oW`0KAj00756O01]HW00HGiP00P0FHY<09`0FH8`0
5UR=01]?S`0QBI@09DfG02ICV00RFYL06f6F01Q/T`0DN8X05WEo01M`P00KIh<06X2201VBPP0JWgh0
7Yac026QJP0NXFX07IiV01jLH`0PVe`09ImH02ZND`0^XU40<ZIC036/D00_[4l0;jYB036YE@0bZU80
=Ze<03V/A@0l[3d0?Zdk03n^>013[cH0@k4e04>^=`0204>[>00W04BW@010Yd<0@:Do03nT?014Y440
A:=204:TA@11XDT0Aim704bIB@18W4h0Bia>04^KC`1;V4l0BYM@04JLDP1;VU@0BiQ<04RDC@15TE80
BIE:04^IB012WDT0?iQ:03n?E`0oQV80@G]V04EYK@1:I6l0E6YT069WG01[Je@0Jg5A06mdD@1PPc@0
E8PH051k2@1ILP@0HFl00080IGD002L0IWL006ai001`OP00MW/007=k001cN000LWT0075i001dP`40
N98;06bP501ZY1h0HJPY05bZ;`1DZSD0CjDe056P>P1BY3/0DJa704f_E014/U`0@[9W04>aG@15[E`0
BjUK04^JFP1?Se00G8A=05aiDP1MMUh0HG=U06igHP1cOFD0LWMO071[G@1cJEd0OFMR07mUIP1kHVX0
0P21FFd09`2HEf@0ZDeP08]@K028Bg/0Ve1]0:U>JP2<HG00Ofm`07QnI01fPUD0NGQF089SHP27IUh0
UVIB08a`B`1ePdl0OHh]08F52P1mM040Nfd007i^001lM000PX40092<3029Sb@0U8d^09^=>P22W4P0
MJ1@072FF01[U5H0JY];06J`C01Q]e<0G;I@05nbB@1W/4@0L;92072g=`0207:g<00W07709P1b^B<0
M;DI07Na3`1j[0X0OJ`>07n_5P1k]1P0N[DH07Ne6`1d^BH0KL0[06nj:`1a/S80LKTV072m8@1W`2L0
HL0b05S0?`1C^d<0C/0l05:b?01BV4P0Die905FQAP1AXD80Cj8k052Y;01<ZB@0AZLO04NS7@13XbD0
@jLh04VPAP18YTh0Bj]E056XE`1FZeL0FjeF0080G;=A02L0G[M@05bfC@1KYdl0G:A;05^^A01O/3d0
HJP[06>P7@1RV180GY0;05RD2`1;WAD0A:PY04B_>P10[S`0?jY304>JH017MWH0C5^0069DQ`1dDHX0
L5N;06iOR`1aHhh0JenA05YJT01@GX/0BUf504mON01HIF`0EfQV05EUG@1AIUL0CF]E04Q^F@10MEX0
>h1J03f<EP10VDT00P15UcH09`16UB/0Ai@V04BB8P13U280?YDL03RJ700iUaX0>iDF03jC5@11Sa00
@HP=04F43019NPT0CVd8055O1@1BD`40DDL004m4001A@@00CCl004/m0018>`00B3T004Pd0014=P00
AcL004<d0011<P00?bl003//000i9`00=2P003<P000]8000:a`002DJ000S60008AD001dA000201P<
0004014:000;1@001P80008200l00000303oool000X0oooo01@0718001`E000O5P008AL001hE000P
40007Pl0020?000X5000;Q`003LW0010;000@2h0040d0010>P00@CH004He001>>000Dd0005i;0080
GUH002L0HE`0065V0`1KM`/0C8XL03jG:00jXC80=jI003NVA@0bYdT0;jM802^WBP0ZWe40:hmI03F3
G`0kMVH0;gMa02MbL`0YN6h0;WmM036M?@0aYBH0=JHM03^S6@10X1X0@idJ04bK6@1<WA`0CIlN04fQ
7P1=XAl0AjHX03VZ=`0/Zd<0::U@036UC@0eW4X0<9=902b:C@0/P5400P0/M5L09`0^NUT0<I1A02jQ
BP0]YD80::Dl022R?@0MX4807ZA301nQC`0RUUl089=]01ZEM00GTWH06h9k01M]Q00FH8/055n=01EL
R`0GGHh06UbB02=ISP0OFhX06EZ:01MUR@0HMHT06h2901b0SP0GNYH04G>K00i_W@0AJi/04fRI01EK
VP0FC9`05dZO01AGXP0GI9l066bK01QaU@0201IaT00W01Q_R00JJHH076J;025US@0SJhd0972;029f
R@0MO8T06H2<01B6QP0GR7h068Ml01Z6O`0ITgX06i]b01bPK00QX6D08j=P026RHP0OW68089EQ02FH
GP0WWUT0:Z1F02jRE@0`YEP0<:YE02nZDP0`ZU00<Z]?03N]B`0m[dH0?[0l04:]=@11[cH0@Jlc04>`
<P11/3D0@Jhi0080@J/m02L0A:U304:WAP0oYT80@JHo04JV@016YSd0A:Hk04>Q>`18WSd0BYY404JK
B@18VdX0CIU;05:IC@1EV4/0DI]<05FJC@1AVTD0BIM904FFDP17VDP0AY]<042KDP12TeD0AHYP0461
J@14M6T0AF9_04eOJP1FIV00IFAI06U[D@1SN500FWa;05N3:`1CO0l0EgD5069b0@1UL0000P1XM000
9`1[N000LGh007>50@1eRP@0M8/607>?201fT0P0Ki8806bI2`1VYA<0EJhR056^:@1=ZCD0BZLh04VU
>`1:YSX0AjTg04>]?@11/5@0>[=Y03NdJP0g]fh0?k9U03n_G`16Z5`0BYQO056:G@1KNeX0GG9H05ic
H`1SLF/0KG=Z07E^K01cIFX0L5Q]06YKK@1fIFX0PFEZ07ELK00206m=MP0W07mLL@2HG780PE]d07i:
O@2:EFX0VUAX08QZJ@1mMV`0N8=S06b8F01_P5L0OfUM08=WG@2>He@0P7=;06:=@@1hSB80QGX707Y_
001hKP00Mg0007mg0026Q@40V9D?09bB9@2LSC80UHln08:OC`1bVeH0Ki9G06R<EP1TTE<0J:]?06Fg
D`1M]D`0H:e@06RQE@1^WU40K:Ho0080Kk4f00/0L;P_06nh9`1e]Q/0NkDD07^`3`1l[a<0Nk<J07Vb
6`1k]1T0MkLG07>h7@0206c09P0J06fj:01_^AX0KKPF06Rm801O`2/0Fl0o05G0A`1F`4D0DKE005>R
A01DZ4@0EJm605:aA`1?/C/0C;0a04R]9`1:Z200B:@Q04RS<`13WdT0AHUO04NEH`1:XFH0CjUU052Y
H01GYeH205^]BP0W05naA01PZcT0I9h_06JI901TW1h0IIDF06><3P1WQ0/0IWd806Eg0`1MP080DXh=
04ZP:016[Cd0@Jm004:VBP12TF40BFa`05IGPP1/BXd0O4FA07]3S01dCY40JURK05iIT`1>H8D0@VYf
04MfI@1;OD`0EWhc05Yh:01KN200FGLN05Ag6`1?NR00B84]0428=011TCX0@9@b0080@I4X02L0A8dQ
04R:701:Ra/0BXhH04FD700nUah0?9HK03bA4`10R`l0@8<;049n2P17MPH0C6T3051G0@1ECP40Cd<0
058o001@@000C3l004a0001:>@00B3H004Pi0018=@00AS8004Dc0015<P00@S40040^000k:`00>2T0
038V000`8`00:b0002PN000W6@008aH001lC000K3`000P0E3P00100@2P002P@000<20002000?0000
00`0oooo000:0?ooo`0D01`B000L4`007Q4001lA000P4@008Q00028C000S4`00:aD0030L000i8`00
@2X0040`0014=000A3T004Tk001=?000FT<0069D001UG`0206IZ0@0W06=_101NO0X0DH/L04:I;@0g
X3H0<JDl02^V@@0YZ4D0::Q702ZXB@0WY5H09YEP02MnKP0eN6`0>Vi_035/NP0]IWh0:gId02j9G`0^
X400;ZH]03:U9@0fXR80=ilR03^N8P10WAl0@YdO04^Q801@XR00CJDQ04JX:`0jZSL0<ZY202^YCP0`
ZD/0<jM8036SA00/WTD0:YI60080;I1=02L0=8i=03JFA`0dX4H0;ZHk02ZT=@0QXcH07ilo01nU@`0N
Y4d08IeJ022LI00KWFd06IY^01Z<M00GMX<05FB>01=MSP0CFhX056><01Q/S`0RKHd08Fb801]XR00J
LhP05X:701R;R00HQHl05GZH019bW@0DLId0572J01A^V00EHYL05EFJ01=GW`0BIj004GJQ01=mV@0G
P9800P0HPH`09`0HP8H06Gf401ilQ00POhD08hB302>9OP0NSgd06i5l01R@PP0FTX405YEi01JJN@0G
WGX06Imd01bPIP0MWe`08J5H026TE`0RXET08ieK02NIG00XVUT0:ImH02bQEP0`XeL0<JIJ02jXF00`
ZUH0<JYC03NZCP0mZd@0?jlm04>a=@14/Rl0@Jl_042a;`0n/C00?K0f03^^A@0203j/B00W03nYC00n
Z500?JM904:W@@12Z3d0AZPh04JW<@18XC80C9lg04ZJ@019VTL0BIa804^LB@1>Vd/0DiQ9052KA`1G
WdL0E:1204bN@P16WTX0AIe704FID@11UEX0@i1K04>7I016O6`0B7=]04aWJ`1HH6D0H6IJ06iRE01]
K4d0G7e=04^2A01?OB<0DWL805ab001TLP00K7D00080L7L002L0L80007680@1_S`@0JYT806NL2`1Y
XQ00J:LE06BX4P1UZQD0G:dO05V/:01HZb`0EjXa05N/<P1BZcD0DJde04Z_>013/4<0>k1G03FbJ@0k
[f80?[1Q046/G@10YEh0@jIM04bRG`1GW5/0GYAH062>E@1RPUd0HWEX06Y`I01]JVX0LfQ[07=JK`1`
HW00KfQ[07ISJ`1aFVd00P1ZCGH09`1eHW@0RF=f07MUM@1dEWL0P5eY08]MIP22LVH0Ng][07J8H@1U
QeL0Ih9H07EaGP1mJe/0Q6IG07AgB@1NUbh0LHdI07eh0`1hM@00NG8007Mb0020N040QHX409FP4P2[
Sb/0VX`j08bA@@20V500OiEB07jCCP1fSTh0KhY@06VIC@1XWd`0I9m:06JKE01/U5h0Ki9F06jKB002
06Z/?@0W06Rg<@1^`2T0M;PV07^h7P1n]a`0N;HN07Fe8@1e/B00NK<J07Nf5`1c^AT0KL0W06g0:`1`
`2H0KkLH06ne4`1Z^A`0I<0^05o0>@1M`4D0Fl1;05Nk?`1D/CP0FZhj05Z/@01H[d80D:]004ZU?017
WcT0BZ@`04^Z<P18Yd00Aj9A04BHI014W6T0AZ5W04fYI@1GXE`0GIiB0080Gj9802L0HZ@j06FM9@1W
TA@0JHH;06R21@1SM040Hg4006=[001RIP00HVT0061`001OO0P0E9@L04^X<P18Zcl0AYe?04:6H@1:
IVP0F5Ej06a:R01o@Hh0Pcb>07Q;SP1MFXh0CfAg04U^HP18Le80BWe004eo9P1CLA@0EVX805QR0`1E
H`80EVL305I_2@1=O1D0BXHP04F;:@12S2D00P13RAh09`17Q1T0CH<D04j24`1=R1D0BH`I04V>7@16
RaL0B8@>04Z12P1:O0P0Bg@7055Z1@1DG040F50005E6001?@000BcX004`l001??P00BCh004Th001:
=@00BSL004Pi0016=`00@c@004@c0013<000?bd003/Z000f:000<280030Q000[8000:Q`002DJ000P
5P007A8001X>000201@:000300h600080`000`4001000000303oool000X0oooo01@0818001dC000P
4P008Q0002<C000R4@009A0002PF000[6P00=1`003PT000n:000Ab`004P_001>=P00Dch005a5001S
D@00K5h006i]0@80JG4302L0GH0805J>5`16WS00>Ym003:MAP0[XTT09jI=02FWB@0YYdL0:jI602nO
DP0_Se`0;7]Y03=eJP0gJ700=ej003=QP@0]NgX09iA^02JUD00ZZ3T0;JL/02jS:`0aWbd0;Z4_03FR
;P0mY2P0@JLW04FY9@12ZB/0>jLc03JW@00aYTT0:jEF02^XDP0[ZTd0:Za<02NZ@`0XYT400P0/XDD0
9`0eWT@0=Ya103JN@P0`YSL0:JL`02>T=@0RW3l08J=501nTC`0PY5H07j=N01fSI@0KWf/079Ac01Io
Q@0DJ94055^>019GS@0CIH`05gJ<029jR00SNX808WR301moQ@0JS8804i:501B:S`0COiX05GNN01Id
W`0GMI/05g>E01E]T@0DIY804VVE019gV00CQ9L058^C01F<SP0201R=RP0W01R>Q00LSH40891o022B
OP0OUg/07i]j01ZPM@0GXG@069ai01NJNP0GWWL05JEg01JXM@0HYVd079mS01bMEP0PWe<08:9@026P
DP0SXED09j1G02ROE@0YX5H0;J1G02nSF@0^Xe`0<:IJ032XF00bZ540>:Y;03j]@010/SL0@k@`04Bd
<011/S40?K<c03^c=`0m/Ch0?Ji<0080>je=02L0>j]=03fYCP10ZDH0@jQ0046Z?013Z3D0@:P^04>T
<`19WSh0BiU504ZHB`19WD/0BIm:04ZMB`1>W4P0CYm705:QB01?XTD0BJ5704>RCP16Wd`0@iQD04:B
FP10SU/0A8MU04UkJP1<MV`0Dfi[061UHP1SJUX0KfMC06YcCP1IPD00Bh@]055k5@1JM0H0I7<006eg
001aN`000P1dP@009`1dR@40L94406ZJ1P1UX@P0HJD?05jX5@1OZQP0H:/L05j]8P1K[RT0F:Tc05^/
<`1I[3<0Gjlb05Za<01F/c80BKLj04:eAP0j/UT0>jmW04>^F`15[5H0AjMK046OI014X6H0Aj=Z052R
HP1KWUX0GiYH05n;H01OMVX0HVYY06ELK`1/Gfd0Lf1_06]WL@1VK740JfA/06mMJ@0206iDM00W06iU
K`1jIfd0Jf]Z06QRL@1[JFH0LFIY071cI@1^NEh0KH9K06J0H01[NEd0NFaN07]YF01iIe`0LH1606>I
7@1aR0X0MgX107Yj001hNP00NgP008R2202ETAL0X98O0:Z<;`2DS440QXa;07Z8E`26SU40RHi=08F;
C`1iOEL0LWeG071kF01ZNET0JWiL07>5G01gSUD0LIA=0080Jj8o02L0JkLf07;0<01c`2h0N;PR07^j
7`1h^R40MkHN07Zf6@1k]QT0O;LK07>j7@1/^bH0JL0e06Zk<@1Z^2<0KkPK06fi8P1W^C40Ik/k06C0
A@1S`4/0H/1105nk=`1Q[CD0HJPf05fZ@01GY4L0CI5?04V:D`19Wd/0Aja:04FXB@14[540B:mS04FY
I`18Y680E:QD05jV@P1ZWS800P1`UbH09`1bT1/0LXLB06j02P1^M`<0Ifh106AY001UIP00If4006MU
001UI@00I6P0065b0`1KR100DYlU04jZ>@16YTD0@iI;04N3F01@Mf@0FgE^069cM01RNGT0GH9b0565
D`1CP380FW`T05md7P1OLQH0Ff`=05aW201HGP<0F5h105iO0@1MH@40GV/605Ec301@OAL0AhDM04B9
7P0204J87@0W04R96P1:QaD0BX@F04N76016R1`0@h<I04Um4@1?M@H0DVl405=Y0P1DH@80FEX105YA
001DB000E4<004dm001=>P00BcP004Xj0017=@00A38004Da0015=000AcP004Ti0016=000@Rl003l_
000k:`00>BP003HU000`8`00;Ql002XN000X70008aL001lD000H400050/000804PP000<03@H000L3
000300004000000<0?ooo`002P3oool0500V6P009QL002TE000[5@00:AX002dJ000^6P00<1h003HM
000g8000@B@004H]001:<000CCL005<n001KA`00H5L006MQ001/K000KGH30P1RP0T09`1FSA<0B9XV
03^U>@0dWDH0<8mI02RKG`0RYf408ZUQ02>ZG`0VYE/0:9MS02Z3JP0/L6h0<FMZ03]HL@15B8@0>5n5
02j0P00VW7408jMA02N[>00_ZbT0<ZTV03>V9P0bYbH0>ZLR03fY7@11[Ad0?JhR03Z[9`0gZC40>:Ld
03NW?@0`YTH0;ZM802bYB00WZd/09jQ802NY@`0202jU@P0W03BN@00gVD40>9I303:Q>00/YC009:<c
02>K?`0SX4H08J=A02:VE00QYeT07Z=Q01jPK00LW78068el01MhP@0IKX<06Vb601QfQ`0KOXD07H22
01j1O@0NP7d07hJ001R>P00DU8@04Xn<0167VP0DOYh06GRM01MiV@0EN98057R;01=hRP0ANH/04h6:
01B8R00ESH<0692200806Y:102L06iMm01jEN`0QUGP089Qi022KN00NWWD06j=`01RTJ`0HWFX06IY[
01VNJ`0FYFh05ZI^01VRJP0KV64079MH01bID@0NWU808J5C02FSE@0WYED0:Z=E02^OF@0^WE/0<:1L
02nQGP0^Y5d0;jIJ036UD`0jZD/0?J`m03jb=P12/c@0@K@f03na>00l/CT0>k9003f`BP0l[U@00P0k
[U809`0k[Dl0?J]:046[@P11ZC`0?jPi03^W=P0jYcD0@:Dg04JQ@P1?VTT0C9Y;04bOB01;XDH0Aim7
04VO@P19Xd<0BZI:04ZVC013YTl0@:AG04>PD`13UU/0@HaM046;G017P6@0C7IY05=cJ01MKV@0J6UM
06U]F@1]K5L0IgI705Z7<01DPaD0FgX;069f101ZM040LWX007N4000207B<000W076C0`1]VPL0IJ<8
05fZ2`1MZA40GjPC06B]5@1R[AP0H:hN062Z7`1NZ280GZ/U05^];01N/2d0G;4^05:e=018`440@KEA
042bGP0o[6P0AjmF04f_B01=[Td0AZ]H04FSIP1:VFh0D95Z05R?H`1IS5l0Gh=U069cJ`1WL6T0If5c
06URL`1]HG@0J6Ed065VK`1SHVd0K5eT0080KUI]02L0J6Y]06eYJ@1ULV@0G6U/05Y`H`1EKFT0Fg=O
065eF@1YNU/0Jg5Y071YI01lHUL0MFMF07=WG@1dQ400M9HD07Z7101nO@00NgX007am001oO`00UH`?
0:f1;02`Ob`0[XLc09N7B@1mPU<0N7QN08:4E`25QeD0PH9B07QbF`1]LF40LV]N079XG`1jKel0PgaJ
08:8E@1cUdh00P1cYT409`1d]C/0M;Xj0730<P1`]R<0MKPU07C0:01h^200N;LI07bf7`1j^B80NKPP
07:i;01_^c80KKDe076f;`1d^2/0L[H[072f<@1b_C`0Jl5006G0@`1X`400Ikhf06Ve<P1Y[S00IJ`f
05fS@01BU4D0BiA804RQA@13XD/0@Yi@04BXE017[FD0BjUZ056HHP1EUT/0Gid[06R<4`0206ao200W
071e1@1`K@<0KFX106aZ001ZHP00IV40069S001VI000J6<006=S001QHP00HFP105eg1P1GS1@0DJ4Y
04>Y>P0oYS/0@9]:03nJE@0nUed0?YYQ042TG@14Y4@0Di0N05Yf1`1KIP40HEh105aL001MG000FUX0
05UJ001JF000GeP005iN001OHP80FVX705Ac2`19OA@0AXHF0080BHXI02L0C8`K04f:6@1?QQT0BX<J
04ao5`1>Ma80EV`805IU0@1FG000EUL005EB001DC@00E4D004ln001;?@00BSP004`k001:=`00AcL0
04@f0013<@00@c8004<_0015<P00AS@0048a000m;@00>RX003TY000g9`00=B@0030Q000]7P00:ad0
02LI000P5P0070l001<?000A20000P0<1P000`090P001@800040000@000000`0oooo000:0?ooo`0D
02dQ000_7000<Ad003@P000d8@00=b4003TS000m9P00@2T004@/0014<@00C3H004`m001C@P00ETP0
05eA001SIP00IgD106=n1P1NR102056>8@0W04BK;@0hY3L0;jDn02ZHC@0UP6`08I9h01bONP0LXgH0
7:5h026JM00URW80;7Q`035XK`0jH740@5Yf04MFP`0hKX00:XMi02BNI@0SZDX0:J/h03>/;00hZBX0
>jLZ03jW9P12Z280B:XM042^7@0k/2<0=jhV03V/9P0mZbD0>jTZ03FX=00eYc`0<ZM402bUC`0XXTh0
::5:0080:ii902L0=YM503^AA@0kRdD0=IPj02fQ=@0VXcD09idk02NM?`0UWD`09j5D02BUFP0PYFD0
7j9]01^SLP0GVgH05Xaf01Z2O00PP8008h:102F1P00PPGh078Am01f4O@0MQH005XZ001BBP`0DThT0
58nD01N5U`0HOiT05W^H01=lTP0BP8X048B501:5PP0FRGl05hil01VBN@0KTgD00P0NUWL09`0OVW40
7i]`01nJL00MVg8089ac01jMM@0NXVd06j1W01bLI@0JVVD069eW01ROJP0GXV/06J5X01^JH00KV5L0
7IMD01nKE00RXE<09JAD02^XE00^XeH0;j5K036MHP0`WF@0;ieU036PG`0dY5D0=JM?03VXA@0mZST0
?Zhj042a@00m/TH0?[5403f`@P0n/4D0?Zm<03b_D`0203b^D00W03b]A`0j[4L0?:a003fZ>P0iZ3D0
>JPj03RY>@0mYch0@ZE304VMAP17WDL0AYm204JQ@013Xd00@jI104FY@014Z4T0@ZU?03nXCP0oYED0
@Z5C04>HE`12SeT0@XYN04alH@1DJfL0FfMX06AWHP1`J5X0KFeI06]`G@1RO4@0GH/R05^21`1SNP@0
J7X306ij0@1eO`00MXL00080Lhl002L0LYH406ZQ201SY`X0H:T@05n/501N[Q@0GZlH05b`6@1M/A`0
H:dI066]5`1O/1T0F;0P05Nb8`1B]BH0Bkdd04FjA`0o]5T0?jmO03fWI@16/5H0C;=304^bB015/5H0
AjMU04Z?KP1=PW@0Cgm^05:0K`1GMg80HFMd06Q`JP1UIg<0HfYf06AVNP1TIG@0Gf=/05URJ`1OIV@0
0P1QHFX09`1NMF40HG5Q05]jH01FLFX0EgMV05EgIP1HMeP0FWIF065kFP1`IVl0MeaZ07iHE`1hI500
LW1H07Z8>P1nT`d0NhD107Z1001lO000Ph4308R<3P2CSQ/0ZH@S0:el:`2[Och0TXYA07f5F01gNUH0
Oh9A07]mG01iMUT0MVaH079^G01eJV00Pf=O09EPH02PKEl0Uh=C07NJB`0207FTA00W07nW@01g]Cl0
L<0o06fe<@1^^Rh0L[X^07Bi:@1c^2D0NKLY07Ri:P1i`2H0N;P]076c=P1b/C40M;D^07Jc;P1k/B`0
M;<^072g>01Z^S/0I<0m06O0?@1V^cL0J[L_06Vd:`1X[Bl0G:4h05B@@`1<S4/0BI9?04BFD@11Ve/0
AZAN04V[J01>Z680DYY?05^D;P1URaH0KGd:0080KGH102L0K6h006iX001_J000JfD006US001TI000
HV@006AM001TF`00HUX005iJ001RGP00GfX005Mj2P1AT1h0BJ0a04VS>@19WCT0AYdm04VK?P1=WCd0
D9db05JA7`1QO0/0HfP1061P001KF@00FeH005eH001LE@00FUH005eF001MFP00GUT005]I0@1IG080
FfD405A_2@1CN@/00P1EO0`09`1EO@d0Eg`<05]h2`1JL``0GFh905aX1P1PHP<0FeT005M@001IC`00
E4T00594001??`00BCX004Td0018<`00BSH004Pf0016<000@c8003lc0013<000@C40048b0013<`00
@30003d[000l:000=RT003@W000d8`00;al002XO000X6P0091T0020C000I3P005@/0010:000200/6
000300L100020@000@0001000000303oool000X0oooo00@0<Ad003DP000e8000>R@00P11:@003P0o
:@00AB/004Dd001;=P00D3T0050l001?@000DTH005Q@001LFP00Gfl205f3201BTA<0A9TY0P0hVDD0
9`0`X5809j5E02>KE@0WREd0:7Ie02:9O00OU7h079:001b:O`0QQW`09Weg031/L@0fH7H0?EQm03mN
P`0oH8`0:gN402>:M@0PWel08:M<02RW?`0`YCP0?9hh04>L>@16VcP0C9/c04RM:`15XbL0@JPY03^Y
:P0kZRP0?JHS03^V9P0gYS00=J<l03JRC00`X5T0:9]K02>GGP0202RAG@0W036<C`0kPd`0@7e<03b=
@@0bVc`0:9ll02JO>00YW3T0:YQ602^JDP0VYE`08ZQT026VK00MZ7405jIa01NML00MTg@09Hmi02j:
O@0cPG`0:7en01n0P00KP8007Gj001J0PP0HS8@05i>801VBS00JRXl07X:>01]oS`0IOX`068B801R:
P@0HSGd07Hig01bBL`0NTg408IE]00808YIZ02L08iQW02BKJ00RVV/089]_02>KK`0SW7008IiY01jL
H`0LVf806iUS01ZHIP0GV6X05j1X01VRI00KWU`07YUH01jHD`0PVE<08j1D02JUE00]YU<0<JEH03>R
G`0fWfL0=9eU03:LI00dVV00>:=B03RVB@0kZDD0?JQ103jX@@0nZdH0?Je203n_?014/3D0A:lb04B_
=`14/3h00P13[d<09`10[cl0?Ji003f`?`0m[3X0>J/j03JX>`0hZ3l0?JQ2046UA015Wd@0@im604FO
@@16XD00@JQ003nZ@00o[4<0@:U>03nYD00mYe40?Z9H04>OD`13UUD0@Y1J04B9G`1@NV00GVQU06EX
HP1^If80MfUL06ieE`1PPE80G8/h06B=6@1VQ0D0Jgl307200@1aPP00MXH007^9000207R?0P0W07>I
1P1]Y@L0J:H906B[3P1UZa<0G:dF05^]6P1K/Qd0F[8P05^`7`1I/1h0FK8O05Fd9@1F/bT0CkT[04Zi
=P16`4T0@kIF04:cE@12[E80B;5A04JaC`17/U80AjmI04fXH@1:UF/0D8Y/0568J@1AQFl0EWUd069P
MP1RIg40JVMc06aZM01[J7@0IVA[061TI01BIVP0E6YS0080DVIX02L0DgaF055hEP1AOUl0DGM[05Ik
H`1LP680GWaD05IgE@1MNEl0LFIc07eIK`23F5l0M6YB06R2C`1gUBl0OI4807F6001fPP00NGh008V:
2@2<S1l0UX<W0:]o8`2XMC80Y7U508f3F020QE80Oh=A08B3D@24NET0R75I08E[F01oK5/0OVYM08mX
H02QIV<0ZVYM09amD01lSTT00P20Td409`2=U4H0NK=60770A01_]d40LKDk07>f=@1e]C40MKLb07Bi
;P1e^2h0N;PX07Vg;@1gZcD0Lj/b07Rb;01j]Bl0NZl/07F]<01b[3P0KK9006Vh?@1W^S/0I[/e06Jh
:@1W]B80IK0R066Y9`1JW3D0D9M504bHC01;WUD0B:1S04ZUI@1:YF/0Cj5E05NN<`1RSQ@0Jgh706ae
0@0206i_000W06][001/I000Jf<006YU001VG`00HU`005]I001NE000GUL006=H001UF@00Heh005mR
001IJP@0E7`?04f:7P1<Tb80C9PV04VG9019Ub80DY4M05Z8401RN`H0HfL1061L001NF@00Fe8005]@
001MD000FU40061C001PE@00Fe8005]C001JD`00Ee8005]F001JGP00F6X10080Eg0102L0EG0205Y_
0@1LK040H6H006AO001PFP00Ge@005e=001GBP00EdD0058n001>?000BS`004Lh0018=000A3<004Hg
0010<P00@30003l^0010:P00@2h003l^000m<@00@34003d^000l:P00>bT003LY000g9`00=2<002lP
000Z70009QX002<F000N4@006@h001H:000@2@000P0<10000`050@000@000000000@000000`0oooo
000:0?ooo`0D03PN000i8`00>bL0040^0015=000BC8004/`001;;`00B34004Xd001<=P00CcL004ll
001B@`00FU4005iS0@1ONPX0DhdK04:K<P0cW4h202fGI`0W02^EL@0RTWL088Qi02EgNP0ZK8808gn7
0227R`0OP8H07726021_P@0[KG/0=f5e03eBP015DXT0@5f@03]US`0ZOH408i1/022TD`0SZ440:JHd
03:S<@0lX300AYlc04bL<`1?VBl0Cid/04fP9P18YBP0?ZH]03fT<00jXS00>:4d03NP>@0dWT40<ia@
02VHGP0PUF80891U00809XeQ02L0<Y5A03R>B`0oPd`0?Xe403BJ@00XWSh09ili02ZL=P0]Td<0;9E@
02RSFP0UZF809JIV02:XJ`0KZ6X07J1Y022HJ@0UTG<0;H]g03J3MP0aP7P09X1l025nOP0NNH006gZ0
01f8P@0OTGh089=m026=O@0SRgd08HUm01n9OP0PSWh0899l022CN`0SU7D08iQb02JHK`0VUfX00P0X
UVH09`0ZUVD0;IIS02JGH00TVF80:9MT02NIIP0TVF408iQO02BHH00PV6<07IAW01bBJ00NWVD07Z=O
022RFP0QVeH099IE02FEEP0VWED0:jAF032WEP0cY5/0=JAR03FRI00cXF<0=9]Q03RGH00lWdh0>ZM3
03ZXA00mZ4P0?ZQ:03j[B@0o[Cd0@Zhc04F^9`15[b@0B;0X04Z_<00204N_=@0W04F_=@0n[SP0?K0h
03b]>00kZSL0?JLl03bX@@0oZCh0AJM304>Q@@14X440AJ1004BR?`0nYd80?ZQ403fZAP0jYe40?:UC
03jTD`0mWET0@9UF046DE@11T5/0AXIQ05EfG`1VJ640KfEP079ZG@1kKEl0JH9A05VD@@1KTbL0IX`@
06b61@1aQP80MHD107V;001hT000NI<10080NIH402L0LIl606RX201WZ`X0J:T>06B[501K[aT0G[0N
05fb7P1I/R80EZhQ05J^7`1E/RD0D[8^04bg;@13^3<0B;Tn04JkD@13/eL0AkA904JeA`13/dl0@;=L
04JbG@1:[FD0Bj]V04RQK01<Vf/0CiIZ04VBN@1?P7H0EfEj05m]L`1aK700Lg9/06U^JP1VL6<0HWIM
05UjH01DNe`00P1?N5X09`1>QDl0C81E05:4F01GPEd0Fh=J0625H@1UPUD0FgUJ061eHP1iHg80PUU`
08AEI`1cL5@0Gi=407NF9022Q`H0OH0107^20`21Q@L0SILC09VB902RPB<0YWlX09mi<`2FNTX0QWUI
08>2E027RE@0Sh=D099]F@2LJ5X0YFIN08mXG025J5`0V6YS0:EXI02VJeh0UWM=08F1B`0208^8B@0W
08V>BP1eZ4L0L;9707>cA@1c]440MK0g07N`<01h/SL0MK@c07Re;P1g^B`0NkHd07b/?@1oZ3H0Ojh]
07jg8@1k/Ad0MJhQ06n/=@1Z/c`0JkDk06Rj<`1W]b`0J;DQ06Bf701U/A/0H[8N05^_:01A[CP0CZa8
04jYEP1=X640Bj=Q04RRE@1AW3X0Gi0L06]o2P1[L@80JVP00080JVL002L0If<006MK001UG@00I5X0
061E001JD@00Fe4005]D001OFP00HEX005mH001RFP00Ged005eR001FJ`80CWT=04n66@1<Sb00Bi8T
04n@7P1BR1L0FWP905eY0@1QGP00G5@005iF001LD`00Fe4005YD001LD@00HE<005mF001LD`00G540
05]D001LDP00GED0065H001OG0000P1PH0009`1NH000GUl0061K001QFP00HE8005i>001HAP00Ed@0
0592001B?P00CC/004Pf0018=000AS@004Hb0013;`00@Bd003l[000o;`00?bh003l]000n<000?bh0
03d^000m;`00?R`003`Y000i:@00>2P003@T000c9@00;b4002TM000U6@0081<001d@000G3@004PX0
00l7000200P4000300@100020000000001000000303oool000X0oooo01@0?RP003l/0015;`00C3H0
04li001D>`00CcP004Xd0019<000B30004Pd001:=000Ccd005E;001HG@40G7D805B97@13Tc/0<IMJ
02RHM08099:602L0:hR;02YnSP0ULY409fV;02QUS00SN9007WjA01acSP0OIHX09fF603ITP017H7h0
DER6059LR@19HHd0=g6902b3N@0VUf40::E602fX>00aYBd0=ZLV03nW9P14YRT0C:<Z04bS:@1=Y2@0
AZTR046Z:@0mZC80?JLm03RT@00fWdD0=Ii302nOA00WVdl08I9P01f@I`0NS6P00P0WSEl09`0`VdX0
=9e403jGA`0oVCl0=9ll02ZQ?`0YY3P09j8h02ZI@@0/Vdd09jEC02JXF00XY5/09jEN026SH@0PW6D0
899[02>=L`0ZQWH0=H1e03>0M@0ZPWP08gek029iO`0QOgl08HMm02F>NP0UTGX09I5f02>?M@0RTW<0
8Y9b02BGL`0UVWH09YUf02RJL`0XW700:ia^02^KJ`0202VKJ00W02^KIP0_V600;9YJ02VIE@0/V5H0
:YQK02VIF00VUed08IIO02>GG`0QUF408IER026OG00RYED08ZAE02>OE00SVe@0:9]E02VODP0/YE<0
<jAC03FSG00eXf40=ZAN03FTG00gWed0>YYN03fQC`0jYDD0>ZM<03VTE@0mYe40>j]503n]=P11[b<0
@JhM04>^7P15/280AJdX0080@:`a02L0?Zd_03n`<P10/C80@jha04:Y<P13Yc`0@:I004:TA016Xd40
Aj4o04JQ?@16Y3d0AJ=004:T@`0nYTH0?JQ403ZXBP0lZE00@:AA03jIE@0oUE@0?iAE042<G017O680
Eg=M06YXF@1dJET0N6eN07YbG@1SRTX0FI`Z06:C5P1^RPT0LX/407J=0P1iSP00NY0007JD001gUP40
0P1aV`@09`1/Y0L0HjX:066Z301O[140H:dG05Za7P1J/B00FK@Q05Fa:P1D[R/0Dk0]04na;P1<`3D0
BL0f04;0?013^D<0?[YA04:bDP14^4H0@kQ204BaCP0o[Eh0A:eK04V[H01@ZF00D:EY04jTK01@XFX0
Bia_0526L01FKWP0Ifm_07E^L@1dLFX0IV]]05m]I@1MNV00F8EP05J5FP0205:2EP0W056<C`1ERU80
EHM?05N4E@1MOeX0HgQQ06MjGP1OKf@0J6]V07eQKP21GFT0OeAV06ibDP1LVCL0LI<L08661`20P040
OhH608:?3P27Y200XhXX0:Ye;`2/NC40WGA708mbC`22K5/0QX1D08UnF@2EMeP0WFMM0:URGP2gH5l0
X5]T08iLI@2NHfD0XFMU09YZE`2ELe00UWA:0080T7]<02L0PHEC07JIB01bYTP0LkA<07Ba@`1g[C`0
O[4k07f_=`1j/3d0Mjhd07Fd=P1i/3X0NYm008:L>`2:XBh0P;@N07fa5P1e[AT0KZl]06Jb=P1Z]SP0
JkD[06Jc7P1U/1X0HK4M05n`701Q/b40FkD[05:d@@1@[E@0DZ9N04fHH@1;W5T0D9i205FC8`1RO@d0
J6X106QR001ZHP000P1YH@008P1VG`00Ie`006EH001QE@00Fe<005m?001MD000GU4005i@001MBP00
G4/0061D001QF@00H5X005aN001JJ0D0F6l<05]h3`1KOA00Gg`=065c2@1PI`@0GU`005]A001KC@00
Ge8005eC001KC@00FU0005UA001LD000Ge0005eA001KD@0205iB0003061C001OD000Ge000080GDh0
02L0GDl005m>001KB`00G4T005U6001EA000E400058n001??@00BcT004/h0017<`00AS<0048`0010
;@00@B`003hZ000k:P00?BX003`[000l;000?BX003l[000o:P00?B/003`Z000k:P00=BL0034W000_
9000<B8002`O000Z6`0091P001lD000K40005`d0014:000<1P000P050`000`02000000000000000@
000000`0oooo000:0?ooo`0D04@c0017=@00BC@0058l001E@`00FTT005I6001?>P00Ac<004La001;
=`00CCT00511001JE@40EG0504f5500lScL0<XiJ02^7N`0YQHT202imSP0W03M]T@0kI9D0=5jG02eT
R00WIhL08GJ;01mkS00QLHL096B2031RP`0oHXT0DV6805YOS01FHXl0E5n?03IbR00[QWD0:IQM03:S
@P0fYC@0>Z8[03bT9@10YB@0@JDU042S9`11YBD0@ZTR03nY8P0oZBd0?jLk03jTB`0hY580<YmF03:P
C@0/WTX08IMC0225IP0NQF/0889/00809hYL02L0<Im403JU?P0kYSh0?:Dj03>T>00WY3l09Z/m02FW
>`0XWd80;9i802ZXC@0XZE<0::1B02JPE00VVeh099IX02:?L@0NR7H09Gek031kO00bOWX0;81i02Im
O00SNX008H9m02B8N`0XRgP09hmf02RAM@0RTgD089Ma022IK`0TX6l08Z5`02BNM@0[W7D0:iia02jN
KP0]W6h00P0YWVT09`0YW6L0<YYL032KDP0`VD`0;iI>02VGD`0TV5P08Y9N022>H@0PTEl08YAR02>G
H00RWeL08Z=@02>TC`0QXTl09J1A02RPD`0[XU00:jA=036SCP0dXe<0=J9F03JTE`0eXeH0=:9K03ZO
G`0lX5D0=ZE@03JXD`0hYUP0?:M:03f[>`11[2`0AZdO04F_6`15/Ah0@jlU042`:`0203n^<P0W042_
;`11[c00@Zl`04R/;P1;ZC40Bj<n04JPA@14WDP0AYi604JR?P13Y3X0A:Ln04BRA010XdH0?j=903fW
A@0kZDP0?JU@046ODP0nTUD0?99E042AFP17RF00D7US05YbE`1XIe@0L6YD06i^FP1YM5L0IHTi06NF
6P1/S@X0L8/607F>0P1iT040NHd007ZB001fU@00LIX10080Kil302L0JZ8806BZ2`1SZPd0HJ/A05^[
4P1F[aD0E[4K04n`8`1=/Bl0C;0i04Ra@018]3`0A/0j04Nn?P14`4T0@L1>03JfD00d/dl0>KQ803bh
A`0n/U<0?JmU046[G@14YEX0CjEI05:XH01CZF40FJEK05JQE@1ESUl0EGYb06AnJP1[N6H0IgMP05eb
I01IM680FX=M05>=G@1CRe000P1DRdd09`1CS4X0E8a:05B9C01EQED0GWeE05m`H`1ULEl0IF9V071Q
J022FV`0OUaT07eFH`1]LT`0Gi<Y072<4P21PP@0QH0708J;3`2;U1H0UXhR0:B1:02ZLBl0[G0g0:Ia
A02CM4l0R7=H08V1E@2ALE/0UfaL0:MWFP2bHed0_5iK0;1JJ02YEFX0YEYX09iOG02JJDh0UG9509Ic
B00208anC00W07Z9DP1iUDP0N:1907b/A@1l[Sh0NZdj08:c>@1o/CH0Ojdk07fX?01jZC`0NJ9007ZC
A024TCh0SYHc07jW8P1jZQD0N:PI06n/8`1//B/0Ik@Z06Vb8P1V[Q/0HJhL05ba7`1N/bH0GKD]05^c
=`1F[TH0DZ9E05BLD`1EWDP0E9/d05jA7@1VO`l0IF`506EO001RG@00IV000080J5l000<0JU`006QJ
001WE@000P1QEP008P1PE000GE4005]?001GB@00E4@005I6001KB`00GTl005iD001ME@00GUH005eI
0@1NG`40Gf<105mP0@1OG000GEP005mC001KC`00F4l005e?001KB`00FTH005Y8001JBP00FDH005I8
001IC@00FU4005Y>001JDP00F4`005]8001KB`0205U7000>05Y5001E@`00E44005=1001B?`00DT80
0551001=?P00Ccd004dh001<>000ASH004Hb0010;@0203dY000903/Y000l:@00?2/003`X000l:@00
>BL003T/000j;000?BT00080>BL000`0=R@003@S000c8@00;b0002TM000V6P008aP001dB000I4000
50d000h700071@0200H001<00000303oool000X0oooo01@0Bc8004Ph001<?P00DSl005a;001OC000
EdP0050o001=<000AC0004@c001>>P00DdL105QP0`1=NA<0>X8]02b7D00URG0098:502efSP80>FJA
02L0AdnD04M9VP12B9/0;Ef>02IXQ`0PMHT087N702=_PP0XHgh0=f:604aPS01JHXh0Ef2=04eST@1=
Gh`0<Gj002Z@IP0[WdT0<ZLc03ZW:`0nYBH0?:LR03bX8@0mZ1h0?ZXN03fX7P0nZal0@JTQ042X;@10
YCL0@:A403VSCP0fXeH0<ZI@02jVC00TXdl08iUL02BHHP0VUF800P0_V5H09`0fXdL0=jQ003nZ?P0m
YSP0=J@f02fT?`0W[4009JU202BPA00WXDH09jM:02NWB`0WVdd09iU?02ZCFP0[SfT0:HQf02B4O00U
NGh0:WJ002ilOP0_PWX0:hIh02>6M`0RSWP09Y1c02^?L`0]TG@0;99e02NCL@0SV6`07iYV02BQH`0W
XV80;IiU032JI@0dVf00=9]O03NJH002036MG`0W032MG00gVU<0=Ie=03BKB`0`VDl0:9QL02:EHP0Q
SFH08HEW02:;I@0PTV808IUK02:ODP0SXdd09:A=022TC00UXTh0:jI@02fWB`0_YDP0<Z9703FQB@0d
XE40=JAE036SE`0aXUd0=9iU03NPG@0dYEX0<jMK03NXE`0kZDD0?ZTa04:Z8`17[A`0BK0L04B`9@11
/BX0?k0^0080@:l`02L0A:l[04J`:01:[RL0CJX_05:Y=@1CXd00CJ9204FMA016Wd40AZ8j04BU?015
Yd00AZ=104JS@`13XdH0@JI6046XC012Z580?YeE03b>G`0lT600@hmT0562I`1JL6D0HF]H06eRC`1`
Jdd0J6eC05agCP1TSB/0Ki8=076>0`1eSP40N98007NB001gT`40LIT406fO1`1ZY@L00P1XZ@P09`1Q
[0X0H:d?05j/4@1J[1<0EZhD04n`501>[QT0Ak8U04Va=@18[d00@[5604>c@P12/d00A[E704FaE00m
/5D0>K1B03JbD@0e`4d0=/1>03VcE00m[5h0@:YK04>QEP1>Ye@0F:YG05R]D@1LZDT0FJM505RID@1A
Q6h0GhMN06>3G01JQED0G85H05J4F01DSeT0Ei5J05R9C`0205V8BP0W05V9A01CS4H0DHa:05B:D`1M
QU40FGmO06=dHP1]H6d0M5YZ08QFJP21GF@0NeiQ06iiAP1XT1/0MHD807in0`21RPh0QYHN09f<;`2b
Lc80/G4W0:YP>P2bIT00[79609IcEP2;M5l0RGMF099XG`2PIE`0/6YE0;Q[E`2mI5T0]eaS0;1FI02U
E5X0Ve]@09eX@02IL3`0V7=60080PXI:02L0N9A;07^MA@1nX4<0OZTj082]>`21[CT0QJ/f08>[<@22
ZC@0O:Td07b`?01kWD80PhE:08b8@02<TC80OZ0N07ZR5P1eXAP0LJLO072]8`1_[BH0JJXI06JY5`1Q
ZB00G[0X05ne<`1O]SX0Gja:05jVD@1JVUP0Fi=?05bK=`1OTaX0K7l906U/001VHP00I64006EM001Z
G0000P1XF0009`1VE@00HeD0065C001OC`00G54005Y?001KCP00FDd005E9001D@`00ED8005A5001I
A`00Gdd005mC001QD`00Ge4005aD001LEP00Fe@005U?001ID000FU4005U?001GCP00Fd/005]8001J
BP00FTH005Y7001HA000ETD005Y9001HB`00FTX005M7001EAP00DTD005M4000205A4000G0513001?
@P00CCl0054n001>?000CCh0050m001<?@00C3T004Tg0016<`00A380040/000l9P00>RL003XY000i
:P00>BP003XX000i9@00>2H003LV000g:0000P0i:@003P0h:000=2H003@X000a8`00;R4002`M000Y
6`009aP0024F000L4P005``00148000;1@001@<00P02000C000000`0oooo000:0?ooo`0D04Xd0018
=`00C3L0058l001H@@00Ed<0054o001;<`00ABl004P_001:=000DCl005M>0@1CK`X0@GlW02eeCP0U
MVT07Gj202AfT@0eIID204EAU@0W050mU`16@I`0@TJL02eNT@0XJ8T0:7B602UgQ00aK7h0A5Qf05=I
NP1LFX80DU^604MJR@0iGXh0<Vb802R=LP0WWeD0:JPi032Y:@0fZb@0=jXR03Z[7`0iZa`0>jXL03^Y
6P0mZA`0?jXQ03nY9@10ZBh0?ZTi03^W@`0gYdX0;Z]F02Z[E00T[U<08JaD02:XF@0UYU/0:ZAK0080
;Z=D02L0<ZI;03JYB@0gZd<0>JPk03BR>@0^WD00:ZQ202RU@`0YWdH0:J1802JWA`0VYDT0:9I>02FC
E00[SEl0<8IW03=nLP0ZPWH09G]l02IgOP0ZOG`0;hAh02n:L`0VTG408IQa02>GL00[UFl0;iA`02nC
J`0ZUfT08i]T026KG`0UWeP0:Z1E036KF@0cUET0=9IF03FFE00gVEH00P0aWEL09`0`WE<0=Ie?032O
B`0^X4d0:ImE02:MHP0NUfT088mY022;J@0PTFD07iMQ01jNF00LXU808:=>026VB`0RY4T09jE:02^U
BP0_YdP0<:=303>R@@0dX4<0<j1<03>QDP0`XeH0<Z5O03:KJ00dVfP0<j=R03FYH@0jZU@0?jQ0046Z
;P17ZR@0Aj/N04V_8@15/2h0@:la04:`;`0204B`;00W04Ra9P19/B<0BjhU04fZ;`1?ZCD0CZQ004VY
>P16Z3X0AJPn04JX>`14Z3l0A:U004VW>`18Y3/0AJ9004NUA017YTX0AJ1@03jHF@0jSfD0>hiY04J9
K01FNVl0IFYX06UYF01bJ4l0K71:05mhB`1APD@0HHlO06fD201^TP40M9<107BE001bU@00LiH206fO
201WYQ40HZ`G0080H;0L02L0FK4P05ba801I/R80Dk0V052^8`19/R80B:hW04Ja;P15/CP0Ak5404F`
BP17ZdD0A:M=04NXE@11Z680@:aL03b`E@0i^e80=KmC03BoD@0i]4L0>[=504:]A@18ZDD0D:]605^]
BP1J[Td0GJY205VW@@1HW4/0D8aS05b>E@1HRe@0FHm>05J@C`1ETE00EiE@05^BD`1NRDX00P1PSDD0
9`1PT440FiI005FF@`1ETd/0GI9@05^:G@1XNf80NV1[089FJP2<E6P0PV1R06m]H01aQT00N8dB07n0
101oP@<0Qi8H08b=<02>OBL0T78W0:A]:02cIc80[VY00:A[C029L5H0Q6eR08Q[H02CHEd0XfEF0;EZ
EP2kIUH0`6AK0;MIH@2dD680Z55J09]HC@2KIcd0W6m009ic@P0208F2AP0W07bDB01nWd40P:<m08>[
?@26[CT0RJXe096S<`2?WcD0Pilg07VQ>P1fYd@0OIM7089oB`2<Pcl0RXl`07VN7@1jUa<0MI@>07VG
4@1fWaT0LZDL076U5P1ZYaD0IJLM05n[9P1P/c40HK@k066[A@1UYd00K9/e06jD:01^S1L0KH<<06mj
0P1^LP00K6T006YY001YI@00K6@00080JEl002L0Ied006ML001SEP00G50005Y:001KC000Fdh005]:
001FA@00DD000591001A@@00FT@005m<001MD@00H4h0061:001IB`00FDL005U;001ICP00F4l005Q>
001IC000F4`005Q;001LB000GD/005a9001HB000F4H005E6001HA`00EdP005I4001DAP00DD@005=2
001EA@000P1B@`009`1B@000DCl004i1001B?`00CSl004ll001=?@00C3`004Xj0018=P00AS<003l^
000m;@00?BP003X[000k9`00>RL003TU000g9@00=b8003DT000c9P00=R@003HS000h9P00=bL003DX
000f9P00=2D0034P000[7@00:1/002<J000O5`006A80018<000<200020@000<1000E000000`0oooo
000:0?ooo`0D04Le0019=000BCP0050i001A>`00CCX004/d001:<@00B38004dj001DA000FU8105]U
201@O1T0>84n02Y^J@0TL7l07GBB02M/VP0iHId204MAU`0W04hoUP0n@Yh0=TVP02YPU00YJXd0:GJ6
02ijPP0nKW`0HUE]06a?L`1]D7T0DDn103Q?Q@0ZEhT09WJ002:GJ@0VYTL0:jTb032Y:00dZBD0=J/R
03NZ800gYah0>:TO03^V7P16Y1d0AJLQ042V9`0oZRl0?:Xf03^X@00bZTX09ZYE02B_EP0N/E@06JiE
02>`D`0W[E<0:J]D0080::UB02L0:jUB02bYEP0`[4/0;ZLn02jO>P0^V440;JE002bV@P0]Vd@0;Ye7
02ZVB00WYT/09iMC02>FFP0XSFD0;h9[03IfL`0[NW@08gQi021eO`0RO7l0:8Ak02f9M`0VU70089ea
026ML@0VV780;YI`02fBK00XUVT089aO01jLF@0SWU@0:IiA032JD`0bTUD0<XmC03:AD00eUE800P0`
W5809`0^WU80;ia?02fMD@0[WEP09IiS022NJ`0KV6X07i5X01n?JP0OVF<07iiM01nRE@0NY4l08JA7
02BVB00TYTL0::A602bUA00aYT@0<:9003>O@P0cWd00<im903BPD00cXUL0<ImN03>FI00dVV40=JAL
03RZE@0n[DH0B:/g04ZZ;01:ZRD0BJ/R04B^9`13/3D0@Zle04F^;`0204Ja:`0W04V`9P1;[B80BjXY
04bW<P1:Z3P0BJTl04V[>017ZcH0@j`m04FZ@014ZT00@ZQ104JU>@17Y3P0A:1404NOC017V500@i9H
042<H@0mQf`0?X5]04UmK@1MLf/0K6]S075ZG@1gJe<0JgE=05V5B01?US@0GiTJ06VE1`1/U@<0L981
07:C0@1bUP40KiP406JS3@1NZaT0F:lT0080F;0^02L0Ejla05J]=@1?/3L0BK0i04V`=P17/3P0BJhf
04Ja=`17/480A[5>04FYD@15Wdl0?YEL046JI00nWVl0>j]T03bdE`0k`540?;eF03ZjEP0o]3d0@;<b
04Na=P18[CL0DZdo05B]B`1?/4`0Cji304n]?@1BYTL0DIAH05RFC@1GUT`0F9Q705RHC@1GUT`0FYI7
05bEAP1OSD800P1RTSX09`1NUSX0GYlm05fK?@1NTDP0HXiC05j7H@1[MfD0QEea08]ELP2@DF/0Of9S
06MiF`1aRST0OXP;089l001oQ0@0TH/U09Yc@`1nMb/0PVPa0:9Z9`2eL2<0[fho0:=OD@2=KUT0RF9O
08mQG02JHeP0YF=B0;EVE@2jI5D0_EmE0;MKG@2dD5d0[UI<09mNB02KJT00WgDm0:Ai?@0208Z5A00S
07jCAP1nWch0QjLn08Z`?02<[C@0RZT`08bY<027YSH0OZ<l07ZM@P1fTdD0OXY:089nC@22RCh0PILU
07jL4@1mT@L0NhX707R@2@1gUPh0Lj0D07:U5P1/Y1P0JZDS06FZ;01P[SD0Gjdn05n^>@1YY2`0L98C
0763201^L`<0Jfd106a[001/JP000P1/IP00:P1/I@00K6X006aY001/J@00Jf<006IP001SE`00GU40
05e@001IC@00F4d005I6001A@`00DT0005A0001FA000EdT005e8001KB`00G4d005Y;001CC000F4/0
05M?001DCP00EU0005M>001IC@00FT/005U<001NB`00GD`005Q7001C@P00E4D00550001CA@00E480
0550001B?`00D440051200<0Dd<002L0DT80058o001??`00D40005<n001A>`00CC`004dn001:>P00
B3P004Hb0010<P00?Rh003/[000j;@00?2X003TX000g8P00<RD003DT000f9000=RD003@U000d9000
=RH003HW000d9`00=B@003<S000]80009a`002@I000R5`007aD001X?000D2`002`H000L400030000
5@00000<0?ooo`002P3oool05019>@00BSH004dm001<>@00CSP004/i001<=000C3L004/n001KB000
I5P2065Y2P1JNah0AhPh03EoF`0/LGT0:7::01iYX00YHJH0?UfT0P1;D9`09`1@?Y<0>dBI031>W`0X
HIH0;Ff?02YfR00aNX80C6ad07E?H01bD6d0JDmi04]?PP0cG8<09FZ002>9LP0RXUh09J]702^Z=P0]
ZBh0<:/X03BZ900iZb<0>jPS03VV9@0mYB80A:DQ03nV8@0mYR@0?:XX03VZ;`0gZSL0;JQ202JXD00S
Ze<08JaA01n_D`0W/4`0;:e902JXC00202JWC`0W02RYCP0WZ580::Y502ZX>P0/XCT0;YY002fW@00[
Yc/0;i]003:IA00`Y4P09J9:02JJDP0SWUd08YEW02f3K@0cLG@0;G9e02A_N00OJW`07G=n02EmOP0Z
PGT098ae022EM00PUg8099Ac02f?L@0bS6H0;i5N02NGF@0RV5@08Y]<02^JB@0eUDh0=I5A03:?D00a
S4l0=9=A0080;IeE02L0:ImD02bMEP0ZW5L0:Y]P02RJJP0SW6d08YQ[02FBJ@0SU6T08YeS02>SGP0Q
YU@08JI>02:VB00XYdT0:ZM402jV@P0`YT00<jI0036T?`0bX400<Ym103JPB00fXTh0<j9J032LHP0b
TfD0<iQR03FUE@0i[DX0@jhl04f]<P1=[Bh0Bj`Y04J[9011[BX0?k0d03n_>013[c@00P11/C409`18
[bT0B:hV04R[:P19Z300B:Lb04VY<@18ZRh0B:Xa04N[>017ZcT0AZXl04JY?`16YSX0A:@o04>IC014
TeL0AXUM04>2GP12PF@0?WY]041aK`1AK6d0IVU]07QYI01fJel0Mf]L06MlD`1FUD00DZ@W066L4`1Z
V0P0JiH506nE0`1_U040KiD006fK101YY0h0Hj/H05f^900205Z_;00W05R[<@1AZS/0Cja004Z[@01;
[Cl0Aji504N^@`15/4H0Aji904b[C`14Xdl0AiMH04>>I@12UF/0?YUd03bUJ00j[Ul0?k5D03njD@10
_d`0@klm04Ve<`1:/S40Bk0b04n^?@1<[4P0Aji=04J]A`17[T00CZU5052ICP1EWDP0EJ17056NA@1B
WdX0EiM605^F?P1MTSh0HXdj0080Hi8e02L0GITn05fO@01PUD80G7m?05emF@1HMVP0I6e[07mGN02:
CgD0TE9^085XH`1SPUH0LY0b08>92`25Q@X0Oh/I08V5:02=MSH0TVh^09iV:P2PKBH0Xg4b0:A`B@2Y
K5T0UW9N09ATG02KH5l0Z69M0:YRE@2`Hdl0]f5<0;aPAP2jFdl0^EAB0:mS@P2OKcl0VgHo0:>0?@2X
QCL00P2@R4409`20SDH0QI]408ZS@`2;[d80Qjhf086V;P20[2h0Q:Tf08BV?`1lVD<0NX]80826B`20
QdX0OI4c086F6@23TPP0QHL208:50`20R0@0OX/907bC3P1hT`l0NiHC07NH6`1fVQh0KYhV06fJ9P1^
V1l0M8lF079o2P1^L@40Jf@006UR001ZI@00J6P006YU001[I`00JVP006]Y000206]W000W06QT001Y
GP00HUT0061E001LCP00EdX005E8001E@P00DT0005<o001C@`00ESl00590001EA000ET@005M8001F
B@00D4H00555001@A@00Dd/005=:001HB`00EDH005I7001MB@00G4`005Y=001EA`00ED<00551001C
@@00DT800590001A@000DT800553001B@000DD800080E4<002L0E4800551001@?`00DSh004hk001=
>P00BcL004Tj0018>000ACD004Dd0012<`00@Bd003h/000l;000>RT003PW000f9P00>24003@R000e
8000=B<003<U000b8P00<B<0038R000c:000<b<002hO000Z6P009AP001hF000M40006Ph001H<000A
2@002`D000D100010@005@00000<0?ooo`002P3oool05015=000@cH004Tg001:=`00CcL004`f001?
<`00CCX005Q2001RDP00IVD405em5`1?RSP0>XmR035nNP0_LHL0:6fF01mNX`0]EJP0?eFU0P1=Cil0
9`1>@YT0>4NG02iAV`0^GiH0?6F@03iZQ`12IX<0DUac06Y>IP1MEGL0DUZ1041PQ`0_L8008h1f026I
J@0PZET08ja902R^?`0/[C@0<:d`03>Z:P0dZBP0=jP[03NW;P0jYR/0?ZHV03bV900hYb<0=jPW03JZ
:P0fZC40<:Ho02ZWBP0WYe009:YB02B]E00Y[TH0;:To02ZXB00202VVC@0W02VWB`0[YT/0:jTj02fZ
;`0/Z3<0;J9002^Y?@0ZYST0;iXo03:GA@0]XDL09jA:02RKD00TXE@09Y]L02b8I00dLfT0;W=[02I^
L00QIGP07fah021cM`0XLgH097ef0226M@0PQg<09HMe02j3L@0jOfL0=XQN02f>G@0STeP08iU?02bJ
B`0gUdX0=i=@036CD@0^Se@0;YIF0080;9eJ02L0::5L02ZNF`0/WUd0;iaR02fMJ00YWVd09i]]02RE
K@0VUV/09IeT02:VGP0SZE<08Z]902NY@@0^ZCd0<jTj03JU>`0eYc`0=:Xl02nV?@0bYD00=JE503BV
A`0cYTl0;jEN02fNH@0_U600=9]J03NUC00mZd00AJdf04f^=01<[3P0Bj/_04B/:00n[Rd0>[0i03Z_
?`0l/S`00P0m/CT09`10[Rl0A:/V04RY9`17Z300B:T/04RX;@18Ybl0BJLa04RY<P1:ZSD0AZPi04JT
?`16Y3d0@j5404BDD`15RV40@h=S04>2IP12PFH0?gIZ04=XKP1FHFh0Jf=/07YUI01cJ6<0JVIP05en
D01CWC@0F:LI06NI3@1`U@H0Ki@3072E0@1dUP40LY`106fR1P1ZZ140IjhK05n^900205ZZ<00W05V[
<`1EYCh0DJ94056OB01@XdT0BZ]E04Z[DP16ZEH0C:IB04NOD011V5@0AXiP04B8K`13Sg40?Y=d03bN
L00lZ6X0?ZiK04>aC@13_d40B<0i04^e=01=/bh0B;4_04Va>`15/D`0@jmA04F]B`10[4/0BZU:04bT
E01LY4@0G:<n05RQ?`1HWT@0Gi9605n=@P1PSSh0HY0h0080HIHk02L0G9U105jLB@1LST/0EGAC05Aa
F`1AJfP0IVaW07UHM@25FW00TeMX08=aH01URe00LiH]08N@2`28S1D0OHH`08V2:@2KJ400YV8`0:]V
:`2TI380Z6<o0:A]D02WKEl0VW1M09aUFP2SGeH0ZUeF0:]KE@2[FdH0[f0n0;QY<`2kID@0_5i70;5Y
@02NM400VGM00::2@02VQd000P2?QTL09`20Pdh0QhY808:GC@1mXe40NZ=607ZO@@20Z3T0PjXi08:[
>@1oXCT0OY@l07fI>01nWC40P9XM08BD3`28R@<0QWl008Ij0025O@40Ph0207f21@1mP`D0O80507j4
2@21Q`X0NhT;07R02P1hN@P0MG@5075^0P1]IP00K60006QP001TH000I64006eW001aKP00KV`006e/
000206]U000W06]R001ZH`00J5h0061B001KC000FTL005Y8001EA@00ECh0050m001@@@00DCh004m0
001E@P00EDD005M6001CAP00D48004Y2001@A000E4H005E8001FB@00E4@005I4001CA@00F4T005I8
001HB000DdD005A5001BA@00DT800510001?@@00DT@005E5001D@`00DdP00080EdL002L0Ed<005I0
001B@@00Cch0050j001<>@00AcH004<f0015=@00A38004<d0016=@00@C0003d^000k;000?2X003TV
000e8`00<b40030O000_7`00<Ah0034O000b8@00;Ql002hR000b9000<28002dO000V5`008A@001`D
000H3`004P/000l9000<1`001P<000@1000100005@00000<0?ooo`002P3oool0500n;P00?c40040d
0019=`00BcH0054e001A>P00F4<0069=001YG`00JgH405j<6@1<Uc`0=YAW0366O@0^O8H09gBC02AJ
X00cBJ@0A4ZW0P1?C:409`1=BIP0=TZD035@T@0fFi40BEf:04eHQ@1>Ch00D4ag05M;K`13F8H0?EfA
03EUSP0XO7h088ib01nRI@0OYeH09:a;02Z^@@0^[S`0<J`g036X<`0bZC00<ZPb03>W=@0eYS40>:L[
03RW:@0dYbP0<:T/036Z;00eZBl0<jPh02bVAP0VZ4h08JUF02:YFP0WZTL0:JY002VW@@0202bVA`0W
032WA00aYT@0<ZPb03>[9`0d[340;ZM102f/?00]YcL0;iPn036F@00]WdD09j5702RJB@0YY4P0::1?
02Z>E`0`O5d0:WUQ02M`JP0QJ7@07FYf01iXM`0SI7P096eh01mbN`0LMGX08gIk02ecN`0eLW<0=GeZ
02^7H`0TSUh08iIC02bJB`0iUdX0>II@032HE00ZUEP0;9QM00809imS02L08Z1S02BNH`0XWF40;YiU
032PJ00[XV/09im]02RHL00UUfd08ieT02>UFP0TZ5009jU802fX?P0bYcT0>:Ph03VX>P0hZS`0<J/l
036Y?P0cZT40<jU403BYA`0`Ye<0;JEJ02jSFP0^We@0>:A<042W@@14ZCX0BJXj04^Z>P17ZCd0@ZXf
03n[;00k[Bl0?:li03f`A@0n/D<00P0o/3h09`12/3<0AJ//04B[;P15Zc@0B:X_04VZ<@17Y3P0BJ<f
04NV>P19ZCd0AjM004FPA014WDH0A9M;04>;G012PVX0@X5/03j0K@0lPF/0?WEZ04IWK@1GGg40KEi^
07]RI01]Ieh0G6]L05>2A`1CWBH0HJ@?06jG1`1cTP<0Li8107:E001bV@80Kj4406RZ2@1U[Q80H[4M
05f_8P0205^/:P0W05^[;@1JZSX0DZU204jUBP1?YU00AJUO04BUG`11VV@0AIMO04J?G015REh0AX9T
04N1JP15QFl0@X5f04:<MP11UG40?ZEU042aD012`4D0Al0e04^e;P1;]2`0A[4_04Rc>P17/TX0@;5?
042ZEP0lYeT0AJMD04^WE@1MYdD0GjDm05^P>`1HVd80HXY506J2AP1SRd00HY0l0080GiPi02L0GYA5
05bFCP1KSU80DGiH059dH`1AIW00J6Ib08QQL02?H6T0UEiU08AgE`1ZUSh0N9`Q08ZF3`2>UQT0SX@_
091h9P2=IB@0Vf8Z0:5R;@2ZJ3D0ZF/n0:1`C@2EKUX0TFaH0:5ZF`2XIU00Z5Q30:QAB02VDSh0[5hf
0;I[<@2jJSl0_6I70:iT@02KK400V7@o09ag@02NNCd00P2<P4P09`1oPDl0Q8=<082:E01lTe<0OYU<
082KB024X3h0Q:Hk08>X=023Wc00Q9XY07nL8`20WAP0Pi@>08:>102:Q@40QW`0089d001lLP00OWL0
07ak0@22O@00PWP007ml0020NP00OWT007Qa001eL000Lf/006eW001[HP00Jf4006MQ001RFP00IUh0
06aU001cK`00LG40075_0002071[000E06m[001[IP00J5d006=G001OCP00Gd/005i?001KB000Ed80
0510001C?P00DCh005M1001IB000EDP005I:001GBP00DdL005=5001@B000DdP00080ETH00100Dd@0
0515001B@@00DdD005I7001EA@00ETH005E6001EA@00C3d004Tk001;>@00C3`0050o001A@@00Dd@0
0P1CAP009P1E@`00Dd<0058o001??P00CST004`j0016=@00AC<004<`000n<@00@C00048a0014<@00
@C8003l/000k:P00>B`003PV000c8P00<B4002lP000[8P00;R4002dN000]8000:al002lN000/7@00
:Q`002PI000P5`0071<001H=000?2@0030L000P400040@000@005P00000<0?ooo`002P3oool0500k
:`00@S@004Pg001@@@00ED@005a;001OB`00He8006EP001`L@00LHT506:L5P1<X3X0=IYU02j@NP0]
SH<0:gf=02IHVP0i@:00AcnV0P1?C:L09`1;C9T0=TVA03=@R`0nG8X0E5^305MDP`1HBX00CT^004]C
N`0hIHL0<Fb=02]cQ`0TQgT089I^026VH`0SZU809je702f]?P0aZc`0=:/j03BZ>00cZCH0=JPj03N[
>`0fZCH0=jLc03NV<`0fZ380;jPe03>]=@0h[340>ZXa02nY>P0TZ4/08ZUI02BZGP0T[U809ja802ZZ
A`0202jUA@0W03>T@P0dXT@0=ZHd03J[9`0gZbl0=JLn03:[=`0`Z3@0;i`j03>J?`0]X4409j9302NN
A00VY4009j9602RFC@0XQe@09XAF029hH`0MKG<076Yf01]RN00VEWX095]i029OO@0QHGd08f=o02US
P`0aH800;71h02YoK`0VRfL09IAK02ZIDP0eVE40=9]G02fMF@0WVU`0:9]U008099eY02L089e/02>M
I`0WWFH0:imV02jRJP0XYF`0::5^02JIM`0TUfl099eO02>VD`0WZDP0;:U5036W?00gZ3/0>JPi03^W
>`0hZC`0=:Ph03>Y?00eZSh0=:]403BXB`0_Y5D0;:=K02bUDP0^Yd/0>jM604BX?P19ZSh0BJY104J[
@`11ZT<0?J/m03Z_>00n[S@0@Zld046`=`14/3H00P17[S<09`17[2H0B:XT04NY9`17ZRh0CJ`Y04fZ
;P1;Y3H0Bj@i04^W?018ZSl0AjQ204NOAP18Vd@0AYM904B4F`12NfT0?GY_03]mLP0jNW40@75_04YR
L@1LFg@0Kea_07URI@1VIeh0DFeK04b5@@1IWB00Iil9072E101fT000MY<007>C001aV040JZ4406NY
2P1P/AL0F[0P05N`9@0205^_;P0W05N]=P1K[T80EJe904j]B`1A[UP0AZ]V04BLI`0nRW40@8E[04Ej
J017LVH0BWMY04]hJ`19Mfh0AFMi04EaN`15O7D0AIEY04B`FP14`4l0B<0m04S0;`1:/Rd0A[4`04Bb
<P19/Sl0A[55046[C`10ZU@0CZY804jX@P1OYc/0HJDh062O>`1SVT80IXlo06^9?`1YSSh0IiDj0080
HiHc02L0Gi9005bBDP1IReL0DH]Q05ElJ01CHWD0Kf1d09=PL@2GHV@0UF1Q08=jE@1_W3<0OZ0N08FR
5P2MVAT0^WPi09ac8@2XGb`0Z5d^0;ES9@2^JRh0ZFa209M_D028J580SV]?0:E]E@2ZJdT0/5i00:IC
@02PET00YUhi0;5U<@2gKSP0_FU30:eP@02LH400W74h09a`>P2JJS@00P2=NSl09`27OE00R8==08J;
C02<R4`0QIa8082Y@025ZB`0Q:TR08VT7P29WaL0RiPD08RD3`27T@`0Qhd808J60@28PP00QW/0081b
001kJ`00O70007ig001kN@00OW4007ib001kL`00O78007U_001hK000MV/0071T001YG@00JEX006AK
001TE`00I5X006US001`J`00Kg0006e_0002071_000W079Z001/H`00JEh006IJ001VEP00GU0005];
001IB@00EDT005E1001E?P00Dd8005I3001JB000G4T0061<001MCP00FDh005M:001CB000DDD00519
001DAP00DD<004i0001=?`00Cd000511001CA`00EdT005M6001B@`00Cc/004Xj0017>000BCH004dn
001=@@00DT400080Dd8001T0Dd@00553001?@@00CS/004lm0019?@00BSP004Lh0015<P00@S8004<b
0016<`00ASD004Df0011<000?Rd003h[000g:000=BD0030T000_8P00<2<002hS000]8000;Ql00080
:1/000/09A`002PI000T5`0081H001XB000E300040T000L500040@000@400040000F000000`0oooo
000:0?ooo`0D03`c0019?@00DTH005eA001OF000HUh006QR001WI`00JGH006n50P1aV`T0HJDI04VW
?`0fW6X0;I=o02bBP@0[OHP0:EJE03]2VP1;A9d204i>V@0W04=?S`0gDhX0=5b403UYPP14KGl0C6J3
04iJQP12FHl0=6N>02MfS@0UNhD08H6001n<MP0OVFd08ZQP02R^D@0Y[d40;:he036/<P0fZ3@0<jTj
03:Z@00fZT40=JU303NY?`0eYcl0>:Ho03NZ?`0cZD80=jXl03n[<@0n[2X0=J/d02b[@`0]ZU809j]O
02R_EP0WZU00;ZM;0080<JA602L0=:9203VOA@0hY3H0>ZX[03^Y;@0kY3X0>jPc03JX<P0cX3L0=9dj
036S?P0[Y480:j1502RU@00WXT@0:9Q:02V=D00WRDl09H9E01b0GP0IQFD07WmY02UbJ`0^Lf`0;W=a
02adN00VL7X0:6Ym02USOP0XLg`09gma02N9J`0VTV40:IUI032KEP0^WEX09j5M026NG@0RWUl00P0Q
Wf409`0OWf8089mP02:OH`0UX6@0:J9V02FUI@0UXfH09iaW02NKHP0ZWe80:JE802bW@`0`Z400=jLk
03JV=`0kZ3L0?:Lj03NX=P0bYcD0<jPk03NZ?00eZd<0<JQ=02nUF00_YUX0<:Q?03>/AP0iZdH0@ZY6
04B/A012ZDX0?jY903Z]A00j[d40>K15042`?@12/340AZhZ04V^;00204ZZ9@0W04^Y7P1:ZQd0C:/R
04VZ9P1?ZRL0CjX^052W=`1<YcT0C:Tk04ZY>P1;Yc`0BJ1104ZL@P17Ud/0AXUL045mJ@0mN6h0>W9c
03U`M013JW<0CF1f05eMM01/HFd0LFQV05abGP1<NUP0DXdo066K7@1/W0L0KY@407:C001cU000N980
07RF001iV@80MIl906fZ301R/180FK0F0080FK0Q02L0FJlc05N_>`1H/3h0E;5505>`D01:[600A9M/
03]mM@10M7D0AFQa04UVL@1=Jg40CW9]04]bJ`15G7/0A6]n04IhN@18TVX0AJeO04G0DP18`400AkHe
04S0<@17/S40Ak4^04j`=P1=/T00AZe904J]D01HYd00EjA005^O?01QX3P0Hidj06FL?P1_TcT0LhTh
06V>>P1UTcP00P1UU3P09`1PSD<0G8UE05R4G@1CR6<0FWeW05eNMP1bF7@0SEU`095QI02?Hf<0Oh1=
07JR9@27ZAT0V:<Q0::B7`2bPB<0XW@I0:iZ6P2OJ2/0YfHl09mYC02IKE80VW1:09U/@`2OJd<0YfQ7
0;1PA`2lED00/UQ50:5PC`2QH4L0[Ulk0;=Y@@2mIdH0Z5e809eRA`2OKSP0X7Dk0:9e?@0209Um@P0W
08mmC025RTT0Phi:08fE@P22YSX0PZP[08FU7`28W1L0RYPD08fC3@2<S@<0RHH308J70`25Q`80QXH0
081o0023NP00PG@007ea001nL`00NW0007Uc001hL000NfP007U/001gJP00N6d007M]001aI`00KF00
06QK001YD`00IeH006EH001VG`00JF@006e[001^K@00K7400080KW0001@0K6h006aU001ZHP00J5l0
06EJ001PDP00GD/005a9001PB000FdT005Q3001G@`00EdH005]:001NC@00GU00061;001KB@00FdD0
05I80080E4H000L0Ed@005=2001A@P00Cc`0058n001C@000F4P00080FTX000P0EdH005M3001A?`00
DC/004/j001>@000DT8005140080Dd<002D0E4400550001??`00CCX004dl001=>@00BCH004Td0012
<@00@380048`0013=000ACH004Pg0015<@00@bl003h^000j:`00<b/0030T000^7`00:ad002`O000Y
6`00:1`002LM000W6P009Q`002DJ000R5P0071<001T@000D2`0030L000L300010@000@0001L00000
303oool000X0oooo01@0AC/00517001HCP00Ge`0061Z001QKP00I7H206=o0`1TS@L0JiH=06RT501J
ZBP0?:=A02VEN@0VQXT0:gn5031[Q`0`BY<0@d:H04a6W080BdjC02L0?5::03IJPP0eIWl0<WAo03El
P@10M8/0AFRD03eSV@0[MY@07XB:01j8P00MRgd0795g01fMJ@0PZUd08Zi=02J_?@0_[R`0<ZhZ03N/
<00cZSL0=:Xi03JX?`0gYcl0>:To03FW?`0eZSl0=Z`o03N/@`0iZc`0?j`_046/:P0j[CH0<je0032Z
C`0`ZEX0<JaE036ZD`0aYd`00P0dYDH09`0fX4@0=ie803NQ>P0jZBh0?:Pb03jS>`11ZSD0>Z/`03JT
=`0cXSX0=:Pm02jXAP0^YDT0:ZI402NSB00YVe809Y9D02N>DP0USED089=G01bHGP0OTf809hMV02f2
J00^PFh0;H1e02QkN`0UKW/09FIn02AcNP0TP7@098I^02BAJ00XV680;Y]P02jOH`0WXFD08J1U01nQ
H@0201jQG@0W01fSG00MXeh07J=R026SI00PXfD08ZAT02:RH00QWUl0::5F02fRB`0^YD00;jHl036V
>@0eXcD0=jHb03VY<`0kYC<0=ZHb032V=@0`ZCP0<ZXm032[?`0]Z4X0;ZQH03>YF@0eZe40>:e603b[
B011ZTP0@ZY604>Z@`0oZTD0?Za603^_AP0l/D/0@;5104R`<P1:[BH0Aj/V0080BJ/Q02L0BjXH04^Y
5P1<Z1l0B:T[04n[;01BZc80DJ/h04jY>@1=YcX0CJTi04bS?018VD80AiE504NFB`16Se/0@GmU03ic
JP0lIW00?fAe04MTM01BHGD0FUic06ERKP1XJfD0FGaN04^:F01EUS`0IiXH072D1P1`U@<0M9@007FC
001iT@00OYD007nF001mVP80LZ4706RX2P1M[Q000P1J/1X09`1E[b@0EZl`05>_=01B/3h0Dje604RT
F011U6D0>X9b03]eM013JW@0B69c04iUM@1?KW80BWM^03mhM`0oQWL0?9Yd03fWHP0o[eH0@[E804Rc
>`1:`380D;<c04Vc<P1?]380D;4k04Zc@P15/4/0A:mB05V]@P1KY480GJ4i06>R>@1UYCD0JJ@h06jM
=P1`TCD0IY8e06NA>P0206^@@00W06R:B`1ORE<0F8aI056;I01FOFD0IUUb07IBL`27DW@0S5mX08eY
G@21Q400NZ<I096W6@2^Rc@0Y8@S0;Qf:P2WLQ`0Z6`T09QV@02PI5D0VfUH09e]D`2WJdH0ZFLl0:IV
?P2[G4H0]U560<YA@`2oFDT0]f=G0:QLD02/E4D0[f530;UWAP2WHe00VF5A09ab=`2PMch0Xge90080
W7a;02L0S81A08:BB01mWd80PJPf082V8027WA@0S90>08b>3@2ARPX0ShT508Z50@28QP40QHD108F6
0@22P`40PW`0085j0021M`00P7H007ia001kL000Mf/007M^001kK`00Ng<007]b001mL@00N6h007EY
001bI000KF4006iM001[F`00JV8006YY001WJ@00L6X0071`001`L@000P1_L`006@1`LP00LG00071Y
001/HP00K5X006EC001OD@00HE<0061<001PA`00EdH005I3001G@P00F4P005]9001KC@00GdT0061;
001MC@00FD/005U<001GB@00FdP005e8001GAP000P1G@@00301KB000G4`005i>001NCP00Fdd005Y7
001HA000DSl0058n001A?`00E4L005=50080DD4002@0Dd8005=0001A?`00Ccd004/l001<=`00ASH0
04Pg0014<P00@34003lb0011<P00A3@004Hk0016=`00@cH004@_000m;P00=bX003<S000`8000:a/0
02XM000W6P0091X002HK000U6`008aX0028H000R5@006A8001P<000@2`002PD000H300020@0H0000
00`0oooo000:0?ooo`0D04]6001ID@00Ged0065X001ONP@0HXD906FC3`1XVA<0L:4I07RP801YX2@0
DJ<c03:MF`0RSh0087f:02YZPP0dEH80?D6>04m4T@1ABi8204MDRP0W03QIP@0bJ7/0<WEj02aoO@0[
P8@0>GJ<03U_TP0aKI@08Wn>01n;Q00NSh007YEm01ZMK`0OYUX09:a702Z^?00_[c80=JdZ03J]:00h
[B`0=Jha03RZ<P0hZcH0=jTh03N/>`0eZS/0=:`j03J]?00f[D00=j/k03Z[<`0h[Bd0=Z/f03F[?00c
YTL0<jE@03FZBP0iZd/0>Z]70080>jI402L0>JA303RLB00hXT00?JLf03jX=P12XD00@jPg03jY<`0i
YCL0=:Dl03>U@00`YdT0;Z==02ZUBP0WYE409J5K02>FH`0RS6@088mT01fIHP0KX6D06i]W01n>J`0R
Rfh0:8Qf02V6N`0UP7h08G5n029VO@0SLW/08gYg02:0L`0SRW<099E_02RKKP0WWW008:=b01nQK00M
Y6@00P0NXeX09`0MY5L06ZQM01ZYI@0KYFH07JEU01jVHP0OYEP08:EE02RUB@0^Y3d0<:@g036T<P0a
Xc40=J@b03FY<00gYbh0=J@_03:W<00[ZCL0;jXh02jZ>`0]Zcl0;JU;02jZF00eZe/0>ZeE03b/C@0l
Zd`0@JU?04JYAP16[D40@Je303j]B00n/DL0?k=804>`@018[cL0BJ`a04F]:`0204R/8`0W04V/601;
ZQH0BJ/M04Z[9`1>ZRL0Cj`]04j[=01<Z3P0C:Pi04VY>`18X440AYI404JEB014UTd0A8eM0460I`0o
LF/0?Ui_041LM018GWH0DF5f05MQM01MHf`0GFiU0526FP17VE80Ej0e06ZK501aV0D0MYH207NE001m
U000OY@008:F0020U@00O9/107>P0P1[XPT0GZX?0080GZ/?02L0G:dD05b^7P1H/RL0E[0`05:_>013
ZdX0?j9G03^@J@0jOg00?fma04EQMP1>HWH0CfAe04=eM00iP7`0=IAk03>YLP0h[fH0?:mF042bB@18
/cd0CKDf05:e=01:/SD0C;@l04^b@016/TT0@K5D03jdH`1C/4L0F:Y105jV=`1RZ3H0I:/^06FY<`1Y
Y3H0Jihj06>F>01RS3`00P1ZS4@09`1]Pe40IHAC05n;F@1FQV<0H7IS07EHKP1lDVd0QDm[08EQHP23
LE/0PhTi086S6`2?UaX0X8DX0:=n802QN1d0WW8W0:=Z;@2RKd80VWQ>09=jE02=Me40Tfa<09M/C02L
Ie00/5e=0;]GA039DcH0`EHj0;]SC02[G4h0[U930:mO@P2jId@0YVY509]TA`2LJd<0WgU60::6BP02
09^3D@0W08b2D`1oUD@0PJ<d08>U8P21V140QHH408Uo002=PP00SX8009230029P@00QWl008N00025
O@00Ph01085k0022MP00OgT007if001mL`00NVh007UZ001mJ000Nfl007ie0022M@00PWH007ic001i
KP00M70007I`001bJP00KVD0071T001ZK000Jg0006md001bNP00LG@00080Kg000140MGP0079e001b
K@00KfH006eP001UG`00JE/006MF001SD000HU0005m@001OCP00FTP005Y7001HC000G4/005e@0002
065A000;05e>001JCP00GDl005]=001NC000GDh005a;001KB000G4`005m=001PCP000P1QC@001`1M
BP00FD@005I2001D@`00ED<005M4001F@`000P1GAP003@1DAP00E4<005A2001A?`00D3d004hl0018
>`00BCH004Hc0015<`00@cD004<`0011<@000P14=0005@14<`00?c4003d^000i;000=B@002lS000[
7@00:1`002@I000P5`007aD0020D000N4@007Q<001`B000I3@0050/000l80008100010800040000H
000000`0oooo000:0?ooo`0D059?001LG`00HVd106=o1`1PUA80HI/Q06ZI;01]U3<0MI<d072G<01K
WR`0?J1002VHI00PS8008GZ702iYO`0gDH00?T6704Q8R@14EHT203]UP`0W02adN`0[QG009H]]01j8
MP0TOh<0:gN>02UeT@0SMHd07X>501j>Q00NThP07Ian01^TH`0Q[Td0:Jlh02n^<@0f[2/0>JdW03b_
9@0l[B/0>:h`03R]<@0j[S80>Jdc03b/=010[3H0?:/h03V[>P0f[3/0=jTh03NY=00cZc80;j/e036Z
>00cYT40>:A:03ZXA@0mZTD0?:Y00080?:Hn02L0>Z@n03ZLB00kXSd0?:He03nY>014XT00@jPg03fX
=@0mXST0>J<h03NW?00hYT<0=jA5032W@`0[ZDd09JEF026QH`0UVFP08iQ/022PJP0NY6X07Ye/022@
K00TS6`0:hM`0327LP0YPg0097e_02IfK`0UO6h09X1`02>3K`0RSG0099Ac02JHL`0RWG407:=`01^V
J`0JYf000P0MYU@09`0OYED06jMN01VWI00KYf@07JMS01nXF`0RYe009JM902VW?`0_YC@0;j@_02nW
;00_Ybh0<JP_02nY<00_ZC40<jD`02fZ<P0[[3T0;J/l02n]?P0_Zd00;jQ:02jYE@0cZUh0>Z]O03VZ
F00hYeH0?ZEE04>XA`11[4D0?Ji;03^^D@0j[Td0@;1;04>`@P17[cP0B:dd04N_;P0204R^8@0W04Z]
601=[1L0C:`M04R[9P19ZRH0BZ/Z04VY;P1:YS@0AjPh04BS?@18WD80Ai]604NKB@16W4d0@hmM0462
J@12Mf`0@VU^049RLP19H7D0C69c055SL`1LI6`0GW1Y04n9FP18WD`0Ej@^06^L401bV`@0MiX107VI
001lU`00OYH007jG001kV000NY`0072Q0P1/Y@T0G:`C0080GZXA02L0H:`?05f]4`1I/200E:lZ04n`
=012[d40?:i403NXCP0hWU`0>heT04:3L018OFl0AWM`0461MP0lRG/0>IQe032YL@0e/6@0?;1G04Ba
C@1=/cd0D;4e05Jc=01@/S@0CK@i04N`@P14/dd0@K9Q03nbL01D/4`0GZTn05nU>01OZ3X0IjXd066V
>01RX3/0IIY4062C@01PS4<00P1RT4`09`1UPU80J7MD06IoE`1LOed0JG=M08ELI02:EfH0R5AQ07iV
F@1bM5P0N8`m08NA=@2=RB<0ZWl`0:9e9@2/KBX0[6Pm0;=[=P2ZN4<0UWiE08ahE`2:L5L0TVMD09ET
D@2IIE80Z6A30;AQ=@2iFRT0]5d]0;eR@P2aGDh0/U190;1K@`2gHD00YfQ10:9X>`2LJ4h0VWQE0:B5
D`020:24E@0W08^<D025Xc40SYhM08n@3`2:R0D0RWd108]o002?PP00THD008j30029P@00QWl008Un
0026O@00PgX0081j0024MP00P7D007ec001kL@00N6d007YW001jI@00O6/007ea0021L`00Pg@0089d
0020M`00NWD007]i001iM000MFd0075W001_K000JW40075g001fNP00MW<00080MW8000D0MGL007Ag
001`L@00KFd006iV000206iS000P06eP001TE`00IeL006AF001TC`00GTh005a6001LBP00Gdd0065?
001RDP00IU4006AB001QDP00HDh005m?001OD000GU8005i@001NC000GDd005m<001RC@00HDl006=@
001OB`00Ed@005E3001GA000ETD005E5001E@`0205Q6000<05M7001EB000ETL005I5001EA000Dd00
04ln001:>@00BSL004/f0017=@00A3<00P12<@005@0o<P00?Rl003h_000k;000>BL003@U000_8@00
;1d002PK000T6@0081D001`B000K4@006a0001T@000I3`004``00108000:1P001@800041000I0000
00`0oooo000:0?ooo`0D05EV201GN`l0FHlJ05bH9@1QWc80Hi4l06n8@@1dQC`0M8dj06^I;01AYRh0
<j==02>IJP0QSG`09Wj002e^O@0eDgd0>4J103m;P@0gFh0202edO`0W02N;N@0QVFd06YA[01N1M`0L
N8D087N@01ejS`0JOHT06HJ201^CP`0KVH807J=f022YE`0X[c`0<ZlX03^`9`0o/2@0A:hT04F`:00o
[Bh0>Jhc03R`<P0h/3<0=jle03j^=`10[c/0>Ze003F]@@0a[D80=:Y003>[>P0]ZcH0;JXh02nY=`0b
ZCh0=ZI503Z[@@0j[3h0?Zdj0080?JXh02L0?JHg03^P@P0lYCd0?jTi04:Z>016Yd80AZTj04>Y=`12
YS`0@ZHk03bX?00iZD00>:E003>X>`0Z[4D09ja>02>XF00TXf408j1W02>UIP0PYf/08JAY02:HJ@0W
UVP0:i5Y02j:KP0YR6d09hI[02B2J@0TQF`08XI^02>8KP0RSG808I9f02:DN00NVW@06J9_01RXJ00I
ZEh00P0LYeH09`0OYUP07:MQ01ZXI00KZf006jQL01jWD`0RYTP09JQ002VW>00/YS40;:L^02^Z;P0]
Zbl0:Z/`02^[;`0/Yc00;Z<`02^/<P0][SX0;Zi002n]@@0b[480<:=6036TCP0bYU/0>JQO03^XG00h
YUX0?JEC042[B00n[TX0?:mE03j]D`0n[D/0@Jm504J`@01>/CD0Cjlb04^^:P0204^]700W052]501C
[1<0D:dH04^^8@1;[2H0B:XY04JW;P1:YC80A:4g046M?@14W400BJ1304VSA`15WDl0AHiO0462J`11
OVh0@7=_04EYLP16I7D0Af9b04eVK`1JJFX0GW5V056?F@19YTD0EjLT06RN3P1^WP80LYl107NL001m
VP00OIP007nG001lUP00O9T007JP001_XPL0GZTC0080G:`E02L0G:dG05Z]5`1F[Q`0CZlW04b_<P13
/D00@[4j042c>00m/T@0?:aH03^YJ`0nXVH0?IAV03RBL@0kTgL0>ii`03FWK@0f[FL0?K1L04VcEP1=
/cd0C[4a05:a;`1B/R`0D;8e04FcAP13/E40@K1L04B`J01I[DT0Gj4o06>S?`1QYT00HZPo066T@`1Q
WDP0HXi:062<A@1PTdP00P1QV4`09`1QQ4l0J75E06UkF@1NNUh0L7AM09ERH`2DFf80S5UI07YVFP1R
M5L0KhU008F<:@2ANbP0Vg@U0:I`9P2[Jc<0W6Y309E/B`2<M500RGME08edF`2EL5/0WVaH0:1ZCP2F
Id@0QVa7095_A@2PJd40X6Ha0;EP>02gEDd0/TUK0:eKD`2_HD`0WVE60:5W?P2PJ540WgMG0:23F002
09R?B00G08nI=P2=W1/0Shh>08j50@2>P000S7l008in002@PP00SX0008ao0026OP00R84008R30028
O@00Q7X008=h0022N000Og@007i`0020KP00NfX007UY001kI@000P1kK0003P1mL@00OVl0081b0023
MP00Q7X007mk001mM@00Nfh007M[001cJP00LVl007Ih001gNP00NGP00P1lMP007@1gNP00MG<007=a
001bK000LFP006iT001_H`00KV4006UI001WE`00IEH006M?001QC@00Fd`0065:001OCP00HU0006MD
001TE`00IEH006MF001TDP00HE8005m@001QD000H58005i<001QBP00H4l00080HE4000P0GU4005e;
001I@`00ETD005M3001H@000Ed<005I30080EdH002<0G4@005U4001HB@00E4D005U3001D@`00Dd40
050m001=>@00BcH004Tg0018=000A3@004@c0014<P00?bh003h_000k;000>2/003<U000a8@00:R40
02PI000Q5`007aH001hE000M4P006a8001P@000E3P0040P000/600070`0010400041000I000000`0
oooo000:0?ooo`0D05Z96P1QTRD0Ihh^06b9<`1fPT00OGQ607i`@P20LSX0MXHg06FN<011YCh0:Z5K
022HLP0PSWL09H9k02i_M`0bFG/0;Tan03ABOP0/HH0202AgP@0W02>AM@0PW6T079=/01UoM`0JMX@0
5gFC01Z1S@0JRh@069Yh01bQKP0SYF00:JUB032/@@0h[bl0?jlV04B^8P15/R<0BJdW04R^;011[S40
>jld03^`<P0l/C<0?jdd04:/=`12[Sh0>Z]803>ZD00^Z540<JM=032WA`0aYT40<ZDl03FW?P0iZ440
>jY603^/?`0m[CP0>j`e0080>ZXg02L0?ZPh03jW?`10Z3X0@ZTb04>[<`18Yc`0BZ`c04RY<P14Z3P0
@jHm03n[>P0i[CT0=Z/h03B[>00[ZT<09Za>02F]D@0UZUT08ZER022YI@0O[6L08:YY01jWJ`0QXVl0
9IUa02J?M@0SQWD07hAg01n2M00LQgD07HYc01j;M00ORgX07Xb001f?O`0JUWX06J9b01ZWI`0JYel0
0P0LZ5H09`0MZ5T07JMU01jYI@0PZEl08JII02>VC00TZ4809ZXl02VX=P0]Yc@0<JLa02nZ<P0aZCH0
;:Xe02ZZ<`0YYc<0;:Hd02^]>00[[d00;Je502n/AP0`ZT40<J9202jQBP0dXeP0>jEN03bWFP0hYeX0
>jMD03f^C00l[Tl0>jeJ042/D`10[D<0@:le04V`;`1D/B@0E:lO05>_7@0205>]600W05>[4@1C[A@0
EJ`I056[7`1;ZbD0AjPX04FX;@1:Ybl0B:De04>Q=`17Y3/0BZXo04^XA@15WU<0@H]T045oK`13Ofd0
AWI^04I]K015Jg00AFM]04eYJP1JJVP0I7=V05JCE@1AZc`0GJ/Q06RT401[Z0T0KJP9072W2@1fY@T0
NJ4907ZM201jW@<0OId107^S0@1bY`T0H:/D0080GJ`J02L0FJhT05F]901A[al0CJlQ04ja9`1</c<0
BkDd04Nh=@13_3T0?k]B03W0G@0i/5T0=jER03BQJ`0aX740>j=/03ZZK00k[6@0A;5J04RfDP1=]3T0
B[4^05B_:01B/RL0C[De04>`B`11[UD0@j]K04R/HP1IYdT0FiE405fM@01NXDT0HJ9805jSD01MV4h0
H8A<05j6BP1LTe000P1PVTH09`1TRdL0JH5C06J4F@1KOFD0LgAR09YSH@2JGf<0T5aS07UZH01PQ5d0
LXhm09:9<`2BNCd0/V/h0;]N>P2[HST0Sf5>085VE`1kKEL0PfeL08e^GP2NJf<0ZFYL0:QRC02FHdP0
QFYG08UcH`2RLF@0WfU90;MM=02kEDT0/T]Q0:QME`2/He@0Tf]<09]ZB@2QKdh0WGUI09^3E00208VO
;@0>08fM6@2CT0h0TXL40926002CP`00SX@008f10029NP00QWT008Mg0024M`00QW/008R10024O`02
08Al000G08=i001oK`00OVd007aZ001lJ000NVL007a[001nI`00OF/0081]001oK`00Og8008Ae0020
N@00P7X007ec001nK`00MF`007=/001dK`00LW@007Eg001gO@000P1gN0009`1iN@00MWL0071b001a
K`00L6H0075S001aH@00Kf4006]M001]F@00IEL005mA001QC@00I4d006=@001SC`00IE<006QF001Z
F000J5T006EH001PD@00HE0005iA001PCP00HU0005m;001LBP00GDh0069?001RDP00He0005e:001I
A@00ET4005Q4001GAP00FDH005Y5000205Y6000R05U7001IA@00ETT005I4001E@`00EDD005E1001?
?@00BcT004Le0018<`00Ac<004/e0019>000Ac@0044_000o;`00?R/003PZ000f9`00<R<002`O000V
6@008QH0020F000N5@007A8001XC000E3@004@T000/600060P000`40004001X00000303oool000X0
oooo01@0Ihi107=lA@1_LT@0KWE807A/E01nI4h0PVTm08Ib<`1lRBX0H9`]03ZQBP0YWV/099]i02FE
N`0WQGd0:WEi02aVN00[G7h0;5n102QUQP809Ff402L08gmh01n=LP0LSG8067]k01I`QP0DKI<06X>?
01fFPP0KY7H08:YO02^[A@0g[SP0?jhb046_;P18[BD0BK0Q04Zc801=[bD0CZdZ04R/;`13[C40@Z`d
04B/<@15Zc80AZ`g046[A00kZUH0<jMR02fVH`0`Yed0=:ME03BUB`0gXTH0?ZE5046XA@10ZdD0>j`k
03b[=@0gZcH00P0jZST09`10ZSX0@jPn046Z>015[2l0Aj``04Z/>@1<[Rl0BjX^04ZV=P15YS`0@ZTg
03j]>P0i[3H0=ZXg03:[?P0]ZT40;ja002b[A`0XZ500::]E02B[F@0T[EX09:aM02BYI@0WXFL09iM[
02B>L@0RRW408HQ`026?J`0QTV/08i=[02>@KP0STG40895d022IKP0QXVD08:UL026ZE@0202:[DP0W
02JYE00WZEX0:ZQM02RVE`0WYED0::M:02VX@P0XZSd0:JTk02jX>`0`YSH0<JTg032Y>`0`ZcT0;J/d
02bX=00^ZSD0;Jlk02ja@P0[[T/0;Je702jZ@@0]XdD0;JA<036UE`0hY5/0>:UG03RYEP0iZeH0>;1?
03V_DP0k[eX0?Z]?042]>@12[bH0B[0S05>a7@1C[AL0E:`J0080E:dI02L0E:`J05>[701D[1h0DZ/Q
04f[901;ZBP0B://04V[;017[300Aj/c04J/=`16[T00B;1<046NG00mQFd0?Wa`049jL016MFl0A7=[
04=bJ@13JfP0B6aX05A_IP1KMf80EiM605N^:P1M[al0GjdG05b`5P1R/1L0H[4D06N^5@1VZAD0KJTA
076V2P1aX`<0M:H2072X1P1YZPl00P1Q[1809`1M[AT0EJXL05:]8@1@[R80Dk0P056`8P1?/bL0CK<_
04bg<P15_CX0?l1703VcC@0dX5h0<9eT03:GI@0iWEl0@JQH04B[E@16[e00C;A<04bm=01<^2<0E;@Q
04ne8`1<]C80B:m604JYD01;Y5<0C:=B05^RA01JSDP0GYQ605^PC@1OWDd0EieC05bIDP1NQ4d0G89>
05RBCP0206:H@P0W06R@@`1QTDX0FY1H059mK`1dLFd0X6E_09eOKP2EFVl0NW1X066FF01lUCT0VhDW
0:9f<@2`Ic<0Z6@j09ARC@22JUT0MGIH07MbE028JED0WF1F0:9PF02XH5@0[E]<0:5KBP2CI5H0TFIU
09ASI@2EHeD0[f170;MGE@2]CV@0YEmH0:YVB02KKD00WVe00:5bBP2JOdl0SIDk0080RYhN02L0SHh<
09220P2DPP00Sh<00961002=P`00Rh4008Qk0027M`00QG/008Qh002<O@00Rg`008Un0027N`00PGd0
081i0021MP00PFh007eX001lJ000P6P0085Z0021K@00PVX0085^0022K`00Q70007ia001nM@00NVh0
07YY001hJ@00NVP007EV001`J`00KFT006i_001cL`000P1fLP009`1gM@00MWD007Ee001dL000LF`0
071S001cHP00KV0006eM001[GP00J5P006AD001SD`00HU<006QF001YE@00JeP006UJ001XF@00J5L0
06IG001TD`00He4006=@001QC@00HDl005eA001PC@00HTh005iC001SD`00IE@0065?001OB000G4L0
05a6001LB@00GTL0061:000205m;000P05]<001MB`00FDX005U6001B@@00Dd0005A2001@?@00CS`0
04dh001:=`00BSH004Ph0017=`00B3D004Db0011;P00?bd003PX000c9@00<b@002dP000V6P008AP0
01dC000L3`00610001H?000B2@002`L000H20002000L000000`0oooo000:0?ooo`0D07EnAP1kLT00
OW4j07MY@01iGDH0PUU208QV>02<MC<0N8`/05FM=P0jXED0;J1a02JOO`0WVX00:XQl02ajN00[LWL0
9Veo02QZR@0UI9D202=ISP0W01mYP`0IOGX05hAm01MfQP0CJX`05VRD01b6S00MVX007ZE]02N/E00d
[cL0?;0/03nb;P14/340Ak<[04bc8P1=/Qd0C;4O04b_9P16[b/0A:lb04>[=@14[3D0AJ`d04:[>P10
Z4L0>JUG036WH`0]Z600;jQG03FWC@0gYDX0?:=804>SA011YTH0?ZY803^[>P0j[CD0?:/i0080@J/o
02L0@j/l04>[?P14[3T0AJXf04NZ<P17Zc/0CJ`_04fZ<019YSX0B:Q104R[>P14[ST0?k0c03n]<@0h
ZSL0=JPj03B]=`0c[3X0<JY502j/BP0[[Dd0:JmB02R^E00WZe<0::IE02RTG00VWV409I]V02FFJ00R
W6P09:5V02>QH@0VWFH09YUU02FFIP0UVV809:EH02BYD00SZU000P0U[Dh09`0Y[Dl0:jaC02ZZD`0/
ZU00:jQ@02^WB00[ZT40;:Xo02jZ?`0aZCl0<:Pk02nX?@0bZC/0<:/j02n]=`0][SP0;j/j02n`?@0^
/D<0;:a802V/A00[ZT<0;:I:02fWD00_YeL0=JQJ03B/E00e[540=k1B03R`D00h[e@0>jaL03jXC`0o
[SD0@[4P04Na801:/AT0C[4H04f^700204n]7`0W04f/9@1=Zbd0CZ`W052/8`1>[RL0CZlZ04b^:P1;
[R`0AZh`04Na=016/cd0@[E;03jaF`0kWFL0>85e03UfM`0nMW80@g9_04=hJ@0mNFL0@FaZ04=[J@1@
LVD0EWiK05RI?`1M[ad0GjlN05f]6`1J/aT0F[4I05Z_601L/A/0GjlM066`6`1V[AL0Jjd@07:Z3@1b
[0X0Jj/90080IZ/702L0Hj/;05^[501C[B00E:dZ05F/8@1@[aX0D[0N05Fb8`1F]280CK@X04;0<00j
]T00=ZYB03FTF`0hWUh0?YmI04BWD@19ZDh0CZe904nc@P1>_2l0CK/O056f7@1@/RD0CK4a04fa@P1:
ZTL0Bj1;04jKCP1NWDT0GXEB05jKC01IXU80FIiA05bND@1MWTP0G8i505b=A`1LTU000P1PU4/09`1R
Rd/0GhaB05V6GP1JKW<0MFMg09]NN02IGG@0SUM^07AfHP1/VU00Ri0c0:]n902gIRl0[6H/09AV@027
He`0Nfa[071bIP1eJUd0TEUG0:UAD`2WCe@0Z51@0;1?D02ZE580X5UK09UMGP2;EF00REYI0:MLE02a
FU/0Ze=O0:eXC`2cJT40YW8l0:Ab>P2RMT`0U8Xl08FQ800208jA3P0<09640P2?O`00SGl008an002;
P000S84008V10027Q000RWd008Qn002:O000Rgl00P2:OP006@29N`00QGP0089g0028M`00Pg<008=/
0024J`00QV/008=_0022LP00Pg8008Ec0023M@00PW@007a`001kJ`00MV80075P001bHP00NF<007IT
001dI@00KfH006aY001bL0000P1bMP002P1eL`00M7<007Eb001fL@00LV/0075X001`I@00LVL006eS
001^HP0206]O000706aK001VE@00J5@006iD001[E@00J5L006YA000206UE000B06ME001WDP00IDl0
06A?001RD@00H4d0065?001OC@00I540069G001VF@00IUD0061@001NC@00FTX005Y4001LBP00H4h0
0P1OD00205e;000N05e<001IB@00ED00050o001BA000CT<004ho001=?P00Bc`004Tg0017>@00ACX0
04Hh0018>000A3<0040b000i;000<bL0034S000[7`009a/0024G000M4@006@h001<>000A2`0030L0
00H300030@000@007000000<0?ooo`002P3oool05027GD40RF11089U?`1`Hd`0K5eF07QIC@1jKcd0
O84]06JE;P16X480=J9P02nROP0]Y8<0;In002n=N@0_Pg00;7ic02QkO00ULhT08fZ@0P0SGH/09`0P
MWX07Xab01RCO@0GQHH05gZ801MfR@0KRH<08IYh02BTK@0ZZUD0<[0l03Nb=@0g/SP0>k0l042b=@18
/BT0B[0O04b`8@19[b<0B:hZ04R^=P17ZSL0B:/c04N[<015ZcH0@jY503j[D@0fZUL0<ZY@03BZA`0i
YT@0>jM403nUA`14YDH0@jM6042YA`10Zc`0@:`g046Z?@0203nY@00W04:Z@013ZD40@jQ104:W@011
Ych0@jM204VY=P18ZST0B:U504ZYA01<Zcd0AZhi04:^<P10[2l0?JHh03JV?@0bZcl0;jdn02j[@`0Z
[4L0:Je=02V]D00X[Th09Zi:02R/C@0VZe409ZUH02JUG`0SXF@08J=Y02:TJ`0TYVH08jAV02JMIP0T
VFH099ES02BOF`0UYE<09:QA00809JaB02L09jaB02NYDP0ZZ5@0:jUB02fXDP0/ZT`0;Z]702f[A00_
ZT@0<JY103>Y@00bZCl0<JTl02j]?00Z[S`0:Jlo02Z/@`0[[dL0:Z]=02ZVBP0ZZDX0:ZQ<02bVD@0^
YED0<:MK03FWG@0fZED0<j]A03NaD@0i/U80>:mD03R[F00nZd/0@K4c046`8P12/BD0@jlO04F_7P13
[b@00P15[bT09`14[2h0AJd`04R];P19[Rh0C:lb04Z_<01:/2`0B:lZ04fa<019/3X0A;5503b_EP0l
[6D0=YU`03J3N00cNgH0>7mf041mL@0nOVT0?7aX045/J`14LF/0BW]V04^8F@1GWcL0GZlL05V_8@1G
/B00EK@M05Jb7`1G/R80Ek4T05Rb:`1I/Rh0F[0^05nb;P1V/B00JK0L06J^3@0206J/100W06NY1@1P
ZPd0G:dL05b[8`1K[A`0DK0H05b^6@1P[aX0H;0J05Fa6P1:]2<0Ak@c046_B013ZTl0AJIF04VVE`15
Ye80BJI>04V^B@1</d80Ck/^04fk8P1A^b40DK4X04nb<@1@/S/0DJm1052QA`1>UTd0G9I@06IkH@1O
UeD0FJ5C05JPB`1BXDX0F:E305^N?P1NVd80Fi=@0080FhmF02L0FHYI05Z3F`1GMVD0GUUf07IMNP2C
GGP0UEab08YJI`1hNUT0Kia008bA:P2YNB80XVh[0:1^=P2EJD80Q6aI07MaH`1gLe`0NW=K091YH02V
HE/0ZEeG0:iFC@2bDdl0/eI;0:eFAP2[EdL0Y5E?0:5DE@2WG5`0Z5]K0:mLG02^JDh0[g1<0:]jA@2U
O4D0V817092F;`25T1000P28PPD09`2:O@00QgT008Mj002:OP00R7`008Um0029O000Rg/008ej002:
O@00SW`008mo002:O000Rgh008Uo0029N@00RWP008]l0025M@00Q70008=c0024L@00QW4008Ub0026
M@00QGD008Me0025M@00P74007]X001dH000LEh007=P001iK000OFh007IY001cI@00L6/006ma0002
075d000707Id001dL@00Lg8007Ia001gK`00MFX007E]000207Q[000N07I^001dK@00M6L0071S001[
F000JUD006mE001[EP00IU<006MB001TE000Ie8006UG001YF000J5T006AF001TD@00HE00065F001P
D`00HE8006AG001VF@00IEH006EE001PCP00GTD005U8001JBP00G4h00P1OD@007`1LC`00GD`005Y<
001GBP00ED@005A2001@A000DD<0054m001>@000C44004Lo0019=@00A3D004<b0012<`00?c8003l`
000i:@00;b<002hO000W70008aX001lE000J40004@/00109000=1P002@<000@2000100007@00000<
0?ooo`002P3oool0502:ESh0QeI007MH?01]F3`0Le]207eU?01lMRh0L8d[05FG>00kWED0<J1_02jP
O`0_YGl0;j=f036LJ00`UfH0:i=^02R<N`0WOh808WF70P0TKH008@0XS6X0:9eY01^NO`0HTXP05HF6
01IoP@0JRWh08YUe02ZOKP0^Z5P0<Jdo03N`=@0k/CH0?;4i04F_=P1;[B`0CZXQ04^/8@1:[RL0B:da
04N/?`19ZcL0BZX_04bZ;016Z3<0@:Lo03jYA@0jZ4X0>Z]403^Y@00oYd00?:U2046VBP0204:WB@04
04:YBP12ZCl0AJXg04B[?`80@jU402L0@ZLn046W?`10YD@0@JE304:WAP13Y4L0AJU004F[?P19Zd<0
CZa304f]>01:[340AZ`^04BW<P0mY3P0=Z=303:XA`0_[4H0;:]702R/A`0X[Dh0:JeA02V^BP0X/4L0
:;1602Z^B00Y[e00:JaD02NZFP0WYf80::MZ02VVI`0YY6T0:YiY02RGIP0YTF@0:9]M02VQFP0YY5X0
0P0WZ5X09`0WZ5/0:ZII02^XE@0[ZE<0:jQB02^ZB`0[ZDP0;JU402nW@@0cZ480=:Q203>W@00cZSl0
;je002Z_@P0Y[TT0:ZaB02Z/D@0/Y5L0:j9F02ZUE@0XY5L0;J9P02nQHP0aYVH0=JET03NVF@0g[5D0
<k1F03JaE`0g[UP0=JiF03^^B00m[SH0?JlY03^_:P0n/BL0?k0/03^a<@0203Nb=@0W03Z^>010[CL0
AJdg04B/=`15[C`0AJlh04R^;`17/2d0B;8h04>`A00o[U40=ZUL03BQJP0cUG40<hQe03:7LP0hRWH0
>hUb03f7J`0lPVP0@7A[04AgJ`15QF@0BI=D05RS>01OZb<0Ej`Z05F^;@1D/BP0FK0W05V_;01I/2d0
EK0f05:`?@1C[d00Dk5005Rc>@1I/2/0HJhH0080J:d902L0KJd406jY1P1/Z@`0JJPA06NX401R[A00
JZdA06j^401Z[@l0IK0A05Va501F/b<0Dk0g056`?`1AZTl0DJUF04jQG@1=XEL0DZe?04fgAP1@`3L0
CkL]05Bf9`1A/RD0Dk4/05Nb<P1F/3`0E:Ln04nOB@1FXTh0EiAF05VOD01CYE80D:=;052LB`1DWd80
Ej9105>J@`1GSU<00P1HPUl09`1GPf80G7aW061YK`1XDWX0MeYi099NN02@HVl0S5iX07alE@1jVSX0
T8d`0:Ag=`2cH4L0Zee10:5EAP26I5`0MW1N07IeGP1lOe`0TWAO0:A_G`2]J580^5m40;MNB`2fFTX0
]eXn0;eF?P36DdP0_5EA0:MGG02VGEP0[fIG0:a_D`2/MED0ZWeA0:23C`23STL0S98R08V11P0208Il
0@0W08Qg0025N@00RGh008Ym0028O@00QWP008Yg002;MP00SgH008ij002=O000S7/008eg002<N000
RWT008]g002:N000S7T008Mc0026L000RG@008Ib0022M@00R7D008Ud002:M000QgD008Ih0023M@00
OVX007IR001dHP00Lf4007a[001kJ@00NVd007A/001eK@00LG000080LG<002L0MGX007Mh001hN@00
MgL007Me001gL`00Ng<007ig001kN000NGH007Ue001dKP00M6H006mM001/F`00K5X006UF001ZEP00
IU8006I>001WDP00JUD006MF001WFP00HeX006=F001TE@00HU@006=C001UEP00IeT006AM001TF@00
J5L0069@001MB@00FTP005Q<001MC@000P1MC0007@1IC000FTP005]7001GC000ET<005A5001CAP00
D4L00513001B@`00DD@004m1001:?000AcL004<a0010<000@C4003d]000g;000<RD002dN000U6@00
8AD001XB000F3`003`T000d700080`001@4001l00000303oool000X0oooo01@0OTYE07i5E@1fCDH0
LE=4075OC`1iJd@0Ng``06J?=@1=U4@0=9US02fMM`0/X840;JEn02bWL@0/ZF@0;:IO02JSJ00ZUgD0
:8Qn02EoNP80:7a`02L0;IeJ02jTG`0OY7`06If501BAP00ER7`068]o02>JLP0[XF`0;JQF036]@@0h
[ST0>;0f03f`<P16[S00Bj`X04nX8@1>Yb<0CjPZ052W=01>YCT0DjLa05NW:P1EYbH0CjL^04FV>011
Z3h0@JU4042Y@010ZT00@jHm046SA011Y4X0A:E604FVA016YT40B:Li04fW=`1:YS/00P14Z4809`15
ZCl0?jU003fWAP0oYTP0@JE804>TBP15Yd80BJa004^/@`1;[3l0CJde04n];P1>Zb/0BjDa04:O>P0k
WDD0=JY703>/A`0b[d<0;:m402b^B00^[TL0;jm102ja?`0_/Ch0<[0n03Bb@@0f/DH0<Zi:03>[D`0a
[5H0<:ML02jTH00_X6<0;YUO02^DGP0YUed09iUP02NIHP0202VMHP0W02VSH00ZY600;:EK02VVEP0X
Ye809jU902VXA00YZ400<JLn03BW?P0dZD40=jQ003>[@`0_[TL0;;1902^_B00X[e00:ZUD02VTFP0Z
WeT0::9I02^QFP0`WEl0;iiP032RH@0cYF00=JIM03FYFP0c[UT0=:mI032^EP0_[e80<k5503Rb>P0g
/S00=[@d03Bd<@0h]3@0<k@k0080<[9102L0=Jm203^^@010[T80@Ji204:YB@13[480AJhg04Na=`16
/440A:i>03ZXG00eWV00=9=[03>@L@0dRW80<Xme03B?MP0gS7T0?XUa03j3J@11Nf/0@WmX04>=H@15
WU<0EjLd05nY8P1J[BD0EZlW05Zb901M/BD0F:h[05R];01E[Rl0DZlb05:_=P1A/cT0EK<g05F^<`1K
[RX00P1P/2809`1V/QD0Kjh?072[2`1/Z0H0JZL906BY3`1V[0d0Ij`=06R^2@1X/PP0Hk0:06Nb501L
[bD0Gk8b05f_A@1DYUD0BY]Q04bLG`1;ZE40BJm704ja@01;/SD0E[<^05Ba;@1K/bL0GK8X05^a<@1G
[c/0DJ]305:Z@`1DYTH0G:A805BSD@1AWTh0Ci5>04jAC@1CVDh0DYE@05>4F002055hH`0W051lK01E
MWD0IfEl07aCO`1oFWP0SUmf08iQK@2;HFT0O7eB07:I<`2:T2L0XWXb0:9U?`2JHTP0SV=H07YhF`1c
R5L0NHQB07^<D@2>Pe@0WW=J0:EYC@2^H3h0[E/l0:9J?`2JGS/0Xehf0;=E=P2kEcd0[5]70:]WBP2b
JTX0[W5=0:MfD@2TOTl0Vh5;07nE<`27RQH0QWL20080Q74002L0RGD008]g002<N000SGT008Yk002=
O@00T7`0095m002=N@00RgX008Ul0026M`00Qg4008If0027L`00RG<008Qe0026L`00QW0008M`0028
K@00Q6l008Ac0025NP00S7P008]m0028NP00RGh008Qj0022M000Ofh007YY001fJ000M6H007QW001m
K000MFl007A/001]L@000P1_M@009`1cN000MW`007Mn001fN`00Mgd007Mh001jMP00NgL007af001k
N000NG<007I]001cJ@00Lf@006mP001]G@00K5X006]J001/FP00JEL006ME001XE@00IeX006EI001U
F`00J5h006UL001XG@00JE/006YR001WH040IV4006YO001UGP00HUH005a?001LB`00FT/005]>0002
061:000L05i:001KB@00Ed@005M6001FB000ET@005A6001@AP00DD800514001BAP00DTD004i2001;
>`00@C@003lb000l;P00>bd003XX000b9000:1d002DG000K50006100018:000:1P0020<000@10200
0000303oool000X0oooo01@0OTYE07i5E@1fCDH0LE=4075OC`1iJd@0Ng``06J?=@1=U4@0=9US02fM
M`0/X840;JEn02bWL@0/ZF@0;:IO02JSJ00ZUgD0:8Qn02EoNP80:7a`02L0;IeJ02jTG`0OY7`06If5
01BAP00ER7`068]o02>JLP0[XF`0;JQF036]@@0h[ST0>;0f03f`<P16[S00Bj`X04nX8@1>Yb<0CjPZ
052W=01>YCT0DjLa05NW:P1EYbH0CjL^04FV>011Z3h0@JU4042Y@010ZT00@jHm046SA011Y4X0A:E6
04FVA016YT40B:Li04fW=`1:YS/00P14Z4809`15ZCl0?jU003fWAP0oYTP0@JE804>TBP15Yd80BJa0
04^/@`1;[3l0CJde04n];P1>Zb/0BjDa04:O>P0kWDD0=JY703>/A`0b[d<0;:m402b^B00^[TL0;jm1
02ja?`0_/Ch0<[0n03Bb@@0f/DH0<Zi:03>[D`0a[5H0<:ML02jTH00_X6<0;YUO02^DGP0YUed09iUP
02NIHP0202VMHP0W02VSH00ZY600;:EK02VVEP0XYe809jU902VXA00YZ400<JLn03BW?P0dZD40=jQ0
03>[@`0_[TL0;;1902^_B00X[e00:ZUD02VTFP0ZWeT0::9I02^QFP0`WEl0;iiP032RH@0cYF00=JIM
03FYFP0c[UT0=:mI032^EP0_[e80<k5503Rb>P0g/S00=[@d03Bd<@0h]3@0<k@k0080<[9102L0=Jm2
03^^@010[T80@Ji204:YB@13[480AJhg04Na=`16/440A:i>03ZXG00eWV00=9=[03>@L@0dRW80<Xme
03B?MP0gS7T0?XUa03j3J@11Nf/0@WmX04>=H@15WU<0EjLd05nY8P1J[BD0EZlW05Zb901M/BD0F:h[
05R];01E[Rl0DZlb05:_=P1A/cT0EK<g05F^<`1K[RX00P1P/2809`1V/QD0Kjh?072[2`1/Z0H0JZL9
06BY3`1V[0d0Ij`=06R^2@1X/PP0Hk0:06Nb501L[bD0Gk8b05f_A@1DYUD0BY]Q04bLG`1;ZE40BJm7
04ja@01;/SD0E[<^05Ba;@1K/bL0GK8X05^a<@1G[c/0DJ]305:Z@`1DYTH0G:A805BSD@1AWTh0Ci5>
04jAC@1CVDh0DYE@05>4F002055hH`0W051lK01EMWD0IfEl07aCO`1oFWP0SUmf08iQK@2;HFT0O7eB
07:I<`2:T2L0XWXb0:9U?`2JHTP0SV=H07YhF`1cR5L0NHQB07^<D@2>Pe@0WW=J0:EYC@2^H3h0[E/l
0:9J?`2JGS/0Xehf0;=E=P2kEcd0[5]70:]WBP2bJTX0[W5=0:MfD@2TOTl0Vh5;07nE<`27RQH0QWL2
0080Q74002L0RGD008]g002<N000SGT008Yk002=O@00T7`0095m002=N@00RgX008Ul0026M`00Qg40
08If0027L`00RG<008Qe0026L`00QW0008M`0028K@00Q6l008Ac0025NP00S7P008]m0028NP00RGh0
08Qj0022M000Ofh007YY001fJ000M6H007QW001mK000MFl007A/001]L@000P1_M@009`1cN000MW`0
07Mn001fN`00Mgd007Mh001jMP00NgL007af001kN000NG<007I]001cJ@00Lf@006mP001]G@00K5X0
06]J001/FP00JEL006ME001XE@00IeX006EI001UF`00J5h006UL001XG@00JE/006YR001WH040IV40
06YO001UGP00HUH005a?001LB`00FT/005]>0002061:000L05i:001KB@00Ed@005M6001FB000ET@0
05A6001@AP00DD800514001BAP00DTD004i2001;>`00@C@003lb000l;P00>bd003XX000b9000:1d0
02DG000K50006100018:000:1P0020<000@102000000303oool000X0oooo01@0O51B07U>BP1eDcl0
Ke`h06YU?P1ZKd00J80m05R:A019SUX0=IAf02nGO00^WGl0;J=h02^YJ00Y[U/09J]B02RXFP0ZWVP0
:9E^02>AJ`809i5P02L0:Z=B02^XFP0RYgL06j9l01BJMP0FTgH069If02>OK`0ZX6H0<:Q@03J]@@0k
/3P0>jlh04F]<019Zbd0DJPY04nV8`1?YBL0DZH`05FU<01EYC40EZH]05ZV:@1IYRH0C:L[04NX=@13
ZSh0@:U203jY@P0oZT@0A:=904FHDP14UeP0A9e>04JSA017Ycd0B:Lh04^V>@1;Z4000P16Z4@09`11
Z4<0?ZI803^VC@0nYDT0@:E604:VB019ZC`0CJhm04b]@01=[S/0C:dg04jY<@1=YC00BJ<e04BP?`0n
X440>ZQ103:[@P0a[400;j`o02j/@00`Zd00<Zho032_?@0_[cT0<Zhj03B_?`0h[d40=Jm603>^CP0d
[ED0<jYK02nUH`0]WVD0:i=V02J<I@0VQfT098U]02>4L00202><L@0W02JEL@0VWVd09Z5V02JVGP0V
ZEL09:Q;02NZ@@0YZCd0;jLk03:Z>`0dZD00=:Q203:[A`0][dd0;jm802j_AP0][4P0:jI?02fQEP0]
WeL0:j1G02bPF`0`VUd0;iaK02bRG@0/YEd0<jEL036YF`0`[EX0;jiK02n`E00/[e40<k9803Fb@`0d
/Sd0<K@m03:d=`0f]3D0=K<k0080=;=102L0=Zm403^^A@10[TX0@J]=046WDP11ZT`0@:e704:/AP0n
[T`0?JiE03^[H00fYF80<imS03>LJ@0aUFl0<99b03>AM`0fSGX0?HYb03n8J`0oP6`0?XEU03jDGP13
Ye40EJT`062Y7P1K[B40FjlS05Ra9@1I[b@0Ek4Y05Fa:@1F[b/0DZl^05:`;`1?`3D0Cl0h05;0?01C
/cX00P1E]3T09`1N/Rh0I;4O06R_501Z[0T0KJL606VX2@1YZ0P0KJ/806j[1@1b[0D0LJd606n]2`1X
[Q@0IK4O05n]=01JYd/0CYYR04bII@1?XUH0Dj=@05FZ@P1F/C`0Fk8d05fb<`1R/b<0HK4N05jd9`1J
/C@0E;0o05J_?01F[SP0F:Q205FOD01DV540DXaD05F<DP1ETeH0DI=E04n0FP0204ecH`0W051eKP1D
M7T0J69n08eAP026Eg`0SUYc08YML`28Gg80N7YH07:@<@2KQQd0X7@U09AN>@28He<0NgEL07J8D`1a
UdX0K91:07F>D022PEP0UFQU09aND`2TCch0YDdl09I<@02@HDd0WfM:0:EH:P2kEBX0/ELm0;5Q?P2e
JD@0/G980:UiA`2GOdD0U89408FF7@24PP`0R7P10080RGL000@0RWP008el002;N`00SW/00P2AOP00
1@2@P000S80008io002;N@00QgP00080R7<001X0RW@008Uc0029L`00Qg<008Ic0029M000RgH008]b
0025L000QG<008]f002<N000S7`008Yn0027N`00R7X008Ic0021K`00OFd007MY001cI`00MV`007U[
001eJ`00MVl007=d0080L7H002L0KgH0075k001eO`00Mh4007Qo001jO`00O7L007Uc001jMP00NGX0
07Yd001gL000MW4007Q/001cIP00KVD006iR001_IP00LVH0079T001^H000K64006YS001[GP00J5h0
06YP001[H@00KF4006aX001XJ`40IVd206IZ0@1UJ000JF@006EP001RF@00GeD005m@001ND`000P1P
D@00701LCP00FTX005M5001FA@00FDH005E8001FA@00E48005E4001EA@00E4D00553001=@P00C3`0
04Dd0010<000>bl003XY000g9`00<24002PK000N4`006@h0014<000<1`001`<000@20002000P0000
00`0oooo000:0?ooo`0D089EB@1nEdL0KUi006UY?@1OJdX0EfmD05]iCP1?PED0AhAT03N:M00cT7L0
<IQb02jPI`0VZED09jm;02V_@@0^YdX0:J1N02FLI`0NW68201nOEP0W026VCP0UYeT09:Q`01nWK00L
XfX06Ie^01fOM@0SXFX0:Z5Q02nXC`0j[400?:`o04:Z>P18Z300CZLZ05:U:@1=XbT0BJ</05BR<01E
Xbl0E:@/05BT:P1HYBL0EjDV05:V:P19ZC<0AZDj04>X?010ZC`0@jU104VSA`1@W540C9eC04^SA`18
YcD0BJP]04^W;P1;Z3@0AjU00080AJQ902L0@jI<042TC@11Y4l0A:A904BWA@14Zd80Cj/k04j]>`1=
/3d0CZlk04f_?P1<ZSl0BjTi04^T>017WcX0@Ii003VU@00eZD00=:`o03B/?00dZSh0=ZXi03F]>P0b
[C`0<J`j036/>`0c[Sh0=Ja403FZB`0dZTl0<ZaH03:/G`0`YVX0;I]_02^<KP0XPfl0:X1]02QoL@0V
NG@00P0TPg@09`0TTG809Iee02FRK`0TYFH08jUL02>ZD00UZD@09ZQ002bX?00]Zc/0;Z/o03:Z@`0`
[DX0;k1?032`B@0_[T<0<:Y702nVCP0`XED0<:1E02fMF@0^VUd0<YEL02jGFP0YWUX0;:EK02fVGP0_
Z5h0;J]M02f^F`0[/5L0;K1D036bD00d/TT0=;I503JcA@0f/cl0=[<l03Nb?00203J`@`0W03F^AP0h
[TX0?ZiA03n/E`0oYeP0@:ME03jWD`0mYe@0?:YE03^_GP0g[600<j]P036YG@0_Xf<0;iaY032HL@0b
U7H0<hel03N:NP0lQg<0?X1_03b8H`0nVe/0Aj]905RZ:`1RZAh0H:dT066^8P1J[bD0G;0T05Rb:@1E
/R/0D;L[04nb;`1=/C00CkTa05:j=`1B/cX0E;=00080C[9:02L0Ek5205^^=@1R[b@0IJhD06Z/2@1]
Z`L0KZL3076W0`1bYP80MjP107RZ0@1hZPH0Mj`9076_5@1W[BD0H:Tj05JUE01@X680E:9H05FPD@1G
ZT/0Ek52062`?01P`3P0IL0R062c6`1P/b40GK<a05Fa>`1E/3D0EJlh05JRA01FTU<0Di1E04n?F@1F
T5H0EYID056GD@1@S5/00P1=OV<09`1>OV`0DGEe05eYN`1jEh00PU=k08mAM@22FG80MUii079iEP1h
SS00ShD`09af?P2JJ4l0OgUF07B;EP1dUDP0KYU106Z@BP1]SUP0NH9L08e[I`2KI5<0[e=80;==@P2^
CT00VV1809IPAP2WHC<0^EXj0;IAB@2aGTh0^6Q?0;1bB@2RN4d0She108ZA>025SQ<0QH0408Ei0002
08Mi000W08Yj002:O`00SW`0091n002AP000Rh8008io002?P@00TGd008mj002=N@00RGH008]f002:
M000RgP008Ek0027MP00RGL008Yh002@P@00RW/008Ae0022L000P6`008E`0027M000QWD0089b001n
L000OFd007Q/001iK000MVT007E[001fK@00M6`0079[001dK000Lg<00080KWD002L0KGP006eo001c
P000Mgl007Un001iNP00MWD007M`001hLP00NGL007Ye001jM000O74007U`001gK`00M6X0079V001b
J`00MFd007MY001cH`00KF4006UR001UG`00J5d006YQ001ZI000K6T006i`0@1WMPH0HgD8065f2@1U
M@H0K70206]]0@1[IP00IUl0069G001QF@000P1QE@006`1MDP00FTl005Q=001IBP00FD/005]8001I
A`00E4L005A4001BAP00DdH00555001=@@00Bd0004Df0010<000>R`003XW000c:000;R8002HJ000O
4@0050`000d900080`000`800040000Q000000`0oooo000:0?ooo`0D07iMD@1eHTP0JfU506=`B01O
Kdl0H6iA05eeC01CNE`0A7UZ03YoLP0fR7D0<9AV02VRE@0SZTD08jlk02^/=@0dZ3l0;J9G02>QH@0N
Y5`201fVE@0W01bZD00NZ5X08jE]022TI`0MYFT08Z1/02:RJP0VY5d0;ZE>03NW?`0kZCP0@:Hk04JX
=P1<ZB`0DjPZ05>T;01>XRX0Cj8/05:S;`1EYRd0DjH]05>T;`1GYBd0Ej<Z05FV:`1<YS80A:Lk03j[
?00nZCX0AJPl04jVA`1?XTL0C:E604FZ?010Zc80?jX_04BX=014ZCP0@Z]30080@:];02L0?jQ@03nW
D014Xe00AZM704JZ?`18[C/0Cj/j05:_>P1?/c`0CK8l04Va?`16[DH0AZi404VW>P1:WSP0Ailk04>U
@00lZCl0>Z/k03F/=`0gZSX0=Z/j03B]>`0c[C/0<Z`k03:^>`0dZch0=jY203NYA00dZdP0=J];03>/
DP0bZed0<ZAR02jIH@0]TF40;I=O02fDH`0ZTFL00P0XUFL04`0TW6D09Z5V02BTI@0SYV009JIG02FX
C`0VZTL0::M202ZZ>`0/[CT0<:/j03:[?@0b[Sh0<[54036`A00`[D@0<Z]9036UD00bWEL00P0bWUT0
4P0`VU/0<YEJ02nEFP0[VET0:IiK02jQGP0`Yeh0;JUN02f/G00_/5X0<JiG036_E@0b[dl0<jm?03Jb
B`0i/dP0>;A703RdA@80=K9802L0=;5603Z`BP0o[eD0?jUL03^SH00kX5h0?:9N03RTG`0eYf80<JaQ
032[I00c[F<0<JYS032TH`0bW6`0<iM`03FDM@0dT7X0=HYh03Z8M`0kQ780>hYX03^OEP12[D80Gj`X
06BZ7@1Q[1d0HJdL05b_7`1K/R80F;@U05Jd:01C/RT0D;8Z04^h:`1=^2d0BkL`04ja=P1</d<00P1;
/EH09`1D[e@0F:i@05n^>@1S/1h0J[0D06j/2`1^Y`@0L:@107VP001lXP00OJ<107fT0P1gY@H0N:P=
06n^701S[RX0Fja;05BXF`1GXeL0FIeK05NWD@1E/4/0GK1405Za@P1N/R`0GK4M05bb8P1K/bd0F[<l
05N_?01BZd40Die>05>6EP1@Q5l0CHMU052=H@1<Te`0C9EN04^?J00204Z6K`0W04]lK@1=JW<0FFMk
06mGP`1mDWd0SdY_085GKP1XGGT0JgME0820=@2RMDP0YFmD0:1YH`1mQF@0JH]Q06Z>F`1^QUX0JgeN
06MhJ01fLVX0SFAZ0:EOE02nES/0be4k0=1B>02eCd40ZE540:]Q@P2bHDT0]eIE0;9QF02dK5<0/7Q;
0:AnC026VSd0O9/U08>;2`28PP40RGl00080SG`002L0Sgd008ej002<NP00TGl009:1002>OP00S7`0
08il002<O@00RW/008ah0029N@00QgH008]i002;MP00RWH008Qe0026M000R7/008b00028O@00PWP0
081c001mJ000PV`008Q`0024L000Of`0081^001nKP40NVh207U`0`1gM`<0MWP107Ul0@1kO040MW<0
07I^001bK@000P1bM0009`1aO040LX0107R10@1kQ000NX4007Ql001dN@00MW<007I]001fL@00Ng@0
07Uc001mMP00N7@007I_001dJP00LV`007E]001eK000M6T0079X001^H@00Jel006IP001ZH000J6L0
06iW001_L@00KGP406N13@1PP`l0G8<D05en401PN`P0J7L306I^0@1XI@00HV40069L0002069J000J
05mD001OD@00GTl005]<001JBP00FTP005M7001BA000DTD004m4001>A000Cd4004a20018?000@S@0
040_000k:P00=2@002hR000/7P009AX001P@000B2`0030P000L40003000R000000`0oooo000:0?oo
o`0D07=XF@1]IUh0JfES06YXH`1XJEh0K6EF069^E@1IL640Ag9`041eM00lP7L0<9=Y02VRD`0RZd<0
:;0i02j_=P0cZch0;ZEB02VSF@0TXeX201jTFP0W01ZZF@0MZf007:E^01^UJ`0MYFd08j=/02NYH@0/
ZT`0<JU003NZ=@0mYc80@JHe04FX<P1=Z340CZLb052S<P1?X300Dihc05NQ<`1HYS40F:L_05JS<P1G
XCD0Dj4d04jU=P16YcT0?ZQ003ZW?@0nZSP0AjPm04fW@`1:YD<0AJQ1046/>`0l[3D0>jPc03fV?@10
Yd00@:]50080?J]801/0?jY;04:YA@17YdH0BJTo04b/=P1=[S80Cj/c052`=@1=/cT0C[8m04Z`?`17
[480BJa004VV?P19Y3`0B:@i04NX>@13ZcX0?Zdg03V]=P0e[3X0=Zdk03J^@00cZd@0<j]003B[@00e
ZSl00P0iZD002P0gYd<0=jQ603J[C@0cZeD0<ZUM02nSH@0]WUl0;Z9M02bSHP0/XV@202^SGP0W02bR
GP0YXF00:J=Q02RTF`0WYUD0::Q@02RYC@0YZDT0:je002b_>@0_[c/0<Jdi036`>P0c/ch0<[52036]
B00aZU00<Z=F032JF`0`WEh0;YeM02nJH00^Ted0;XmM02b@F`0[Ue`0<9eN02nPGP0^Y5h0;jYK02j[
FP0^ZET0<:aG03:/D@0c[500=:e?03F]C`0g/4d0=k970080=KA602L0=kA303ZdA00m]4l0>k1H03R[
G@0gZUd0=jUN03JYG00cZEP0<:iG02n_FP0b[F80<:MP036SHP0bWf<0=YaY03RIL@0gUW@0>8mf03V9
M@0fQGD0=8eU03bOBP1:[C@0HJ`P06NY701W[a`0JZlM06N_7`1V/240H;DR05^h9P1G]B80EkLS05>b
901B^2L0CkT[04Za=P1;/d@00P15/UP09`1?/ET0FJiG05b_@`1O/RX0I[@K06Z`4P1/Z`P0MZL207VO
0020WP00Oid0086M0P1jW0D0NJ8806b/4P1Z/240Gjli05Z]BP1IYTl0FJ=J05RXD`1F[dh0FK5705Ra
@01L]B/0F[@O05Nd7`1J/C00E[0k05F^?`1=YDd0DYIB04b1G01<P6H0BX9^04^=I`17Veh0Bj1L04bK
I00204^CK`0W04b6K`1=L7P0G6Ii07=HO`21E7L0SDib089GK`1XGgH0JgIE08J2>@2LMT00UG=B08]a
H@1nOe`0LgiN07>6GP1eQUP0LXAN06YnJ@1jM700UF5a0:1TF`2bEcD0_5X`0<IJ;`2kFc40/EXh0:]Y
A02/KD/0[6E;0:iWB`2eL4L0Zh5509f2BP23Wbh0PYDE08B61P29O@00Sgl00080SX@002L0THH008f0
002?O@00T7d009B2002@P000TGl008mm002=O`00RGP008Mj0027N000Q7H008Ef0026LP00QW00085^
0021K000PG@008Aj0027O@00QgX008Ee0023K@00Q6X008M^0024L`00Q6l108=j0P1mNPH0MH8:07V8
3P1iS@l0NHh:07b?2@1hSPP0MhL307In0`1gM`400P1cN@009`1]O@80KX@507:40`1fQ000MX<007An
001fM`00MW4007M/001gK@00N74007eh001lM000MW4007I^001dJP00M6d007A_001eK@00M6X007=Z
001bIP00L6L006aX001ZJP00KFX006e_001]N040JGl;06>;601KTQX0Ei4L05^>5`1MRPl0Ih8<06Ul
1P1XK`<0IfT206IV0@0206IQ000I06AL001SEP00H50005]=001MB`00EdP005I4001@@@00DD<004e1
001?@@00C40004Xm0017>P00A3@003/_000h9`00=24002/M000W600081<001P=000@1`002@<000<1
000S000000`0oooo000:0?ooo`0D06YSP01bFHL0KE=o075FL`1^Ff@0M5mE06QXE@1KL600BW=_045e
N00hPgP0<IMY02ZXD`0V[dL0:[4n02j^?@0b[4H0<:U=02jUDP0ZYE@202>WF`0W01b/G00FZUl06:EZ
01^TJ`0TY6`0:ZAV032YD00fZcT0?:`_03n[:`10Yb`0B:@^04jT;@1AZ2d0DZD/05NV<01KY2/0G:@/
062U:`1SY2T0HZ<[05bS<01HXc<0Cj<l04bS?@14YCh0>jLl03ZX>014YS80BjHg04ZV>`19YSX0AZPf
04B[<`0kZSL0>ZLk03jVAP13Yd@0@:Y40080@j]402L0@:a104>Z?P18ZT00Bj`h04^]<@1;[bd0BJh]
04R_<`1:ZSX0B:]304F[A014Zd00B:M004ZV?`17YS`0AjTh04>Y=@13ZS<0?J`c03N]<@0g[CL0>J`l
03RZ@`0dZ4D0=:U403F[A@0dZTL0>JM403ZV@@0jXd40>:=403BVB`0`Z5H0;jQO02bVIP0]XfH0;JIX
02jUKP0]YfX00P0_YF409`0aXe`0<j9K032UGP0^YE`0;:EK02jUEP0/Ye@0;JY=03:[@P0bZcd0<J`k
03B/>`0c[S/0<[11032^BP0`ZE80<ZQG02nNG`0`UF00<9UP02nMGP0bUf40<XaQ02n7G`0^QU`0;XiL
02nDH@0_VF40;IiL03>RGP0bXEh0;iaN036PF@0bXeL0<JMF032VF@0_Y5X0<ZMD03F`C00203NcB@0W
03Je@P0j]T80>kA:03VdE@0b/Ed0<;1N03>]G`0c[Ed0<:YK032/EP0`[5P0<J]R036XH@0aYUh0=:5P
03FPI`0gWVX0>Y]^03VAK`0eRg80<HUa03>CFP0oXch0DjhS06B[6@1W[1H0J;0H06Na601Y/1/0Ik0L
066f6P1P]Ah0G;XO05fm7@1E_Al0E;PO052f9P1<]b/0A;8l0080@jm;02L0BJmE056]FP1N[TL0H[<j
06>b;`1Y/1d0LJ`?07VX2@20X@00P9d1082K0`1nV`80P9d307bW201b[Ph0JK0L05na;01H[c`0FJY=
05BVH@1CZ5P0D:aI05>^B01A/S/0E[HY05Bc8@1D]240Ek4]05>a?P1?ZT/0CI]I04^=FP18P5/0BGeS
04YmJP1<S680AYmE04RUE@1<WV000P1;U6d09`1:Rg@0C7An061SNP1iDgT0R5=j08mGN`1oFGD0He]f
06]`D`27PBX0U6/j08A[F@2>IVT0PVaS07iVH01kMU`0MhUF07:=G01_QV<0PWEa0:USM@2XH6<0ZeTf
0;AN:P2lHB@0_f0O0;]S902WIcd0XVE:0:5Z?02TJSL0Zg4e09n3>02@RD80R9lM08NA2027Q@80QWh0
08ik000208^0000W08j7002>P000Rg@008eh002AN@00T7l008j1002>O`00SWd008ah0027N000QgL0
08Qe0025N000QG4008E]0023K@00PW80089h0021N@00Qgh008an002:NP00RgD008Ud002<N@00R7l3
08F21@1oS0P0N9@<07RI3P1hVQ<0MI/E07JL4@1fV@`0LIH:07FE1@1eU@@0MH`30080LHX502L0K8D6
06V21P1_Q@<0Lh0107>0001eO000MgP007Yd001hL000Mfl007Qb001jM`00NGL007Qe001eL@00MW80
07Ec001gL@00Mg8007Ea001^L000KG0106e^0@1YK`40JG8006Uc001ZMP00IGd305f:5P1JUbH0Ei/^
05VO;01HWBL0F9PR05^D601SRA80Gh4<061f201RKPD00P1RI@406@1UH000HET005m?001IB@00ETD0
0555001A@@00D44004e0001;?@00Bch004Tl0017>@00A3H0040`000i:@00=2@002lN000V60007a<0
01T@000D30003PP000T300040@000P01000Q000000`0oooo000:0?ooo`0D06U;JP1S@FX0IT1U06M2
GP1]BE/0Oe]A06aZC@1MLeX0CGE_04IfO`0gQgX0<9iW02^ZE00W/4X0:Zm402n/A@0`[TT0=:Y8036Y
A@0/YT/202>WDP0W01b/F00JZ6406Z1Y022PJ00UXVP0;ZEN03FXAP0kZS@0?jP]042X:017Yb@0CZ@V
05RU901JYR80F:LV05ZU9P1LYBP0FjHY05VW:P1OYRX0HZ<X05^S9`1DYBL0CZP]04^Y<@17Yb`0@JH^
03jX<P15YcD0AJDm04NT?P14YSP0@jTc04>[<@0nZST0?:Q003ZUB00nZ4L0?jQ30080@Z]102L0AjY0
04J[?`19[3`0B:`e04F/<P14[C80AJdc04>/=`13ZD80@JQ>046VB`13Z4<0BJXo04bY?`18Z3/0A:Pk
04>X>012Z3P0@:Xh03^[=@0kZCX0?ZQ003nU@@0nY4<0>:A403NYBP0gZdh0>ZM803ZTA00hW4@0>Ii6
03FSC00bYe80<:UE02nWD`0]YED0;jEH032VG@0`YE/00P0bXe809`0gX4d0?:1<03RWCP0eZ580=:MF
03BYDP0fZDd0=J]803J[@00e[400<ja003B^@P0c[T@0<:i=036XDP0dZ5X0<jMP036OIP0aUf@0<YaP
03:NG`0dUf00=H]Q03>3H00cPeh0<XiM03>DH@0aUV@0<YQN03>IGP0cV5d0;IIP036JG`0_X5X0<:AL
02nQFP0]WUX0<ZEG036/C`0203FeBP0W03Bd@`0g/d40=[=703FfC`0`]ET0<K9M032aG@0a[F00<:YN
03>YG@0bZEh0<jYQ03FUH00gY5`0>Z9L03NQI00iX6X0>i]a03^>LP0dS700<8Q`03RDE@1;Ybl0H:`E
06F/4`1X[aH0IK<G06N`601U/1`0I;4K05fc6@1M/a/0Hk@M066c701I_A`0EKPM05>f8P1>]bH0B[4_
0080AJm002L0BJi?04Z[GP1B[4l0FK9805ba?`1R/b`0K:hI07bY3022W@00P9/307fK1`1iV`@0Nid2
07NT1P1^[0P0IjdH05Z^:P1F[SH0DZa<052WI`1>YUl0Cj1R04f_C@1B/SX0EkD_05>d901B]R80D[0^
04b`@@1=Y5D0BHmT04J3H`16NFD0AgaW04N3JP14Sf@0AIeG04VLF01>Tf<00P1=RW809`1<Q7/0CW5o
05iQN`1mEGL0QEAg08UJO01mGgL0Hf5c06YdDP23R3<0RGI208IdD`29MF00R7=K08m[E`20NUD0NXQ@
07R4EP1cNUl0Pg5R0:QPH02^Fe@0[UI00;1M>P2dHBh0^FDR0;YT8@2dHS/0/VE=0:I`?`2UMST0YgTn
09Z7@@28VCh0S:4H08^?0@2;Q000R7d008Mh000208]j000W08il0028M`00QG8008Uc002<M000S7H0
08aj002=M`00S7P008id002:M@00RgT008Ym002<N@00SWL008ag0027M@00PWP008Ak0025N@00RGh0
08an002:O000RG/008Il0@29QP@0Q8X=082=3`1mV@l0NidB07JR5@1iYQL0M:HJ07BR5`1aWa40M9h:
07:J0@1eU`40KiX50080Jih;02L0JI8<06B61`1WQ0D0I8H506^20@1aPP00MX@007Ym001lNP00NGL0
07Yg001fN000NWd007Ui001gM@00MWH007Ih001fN`00MgT107Ag0@1_M@40KW@206ah101`N0<0Kgd3
06n00`1/QPH0HI0>05fI7@1IXB`0FJ<_05bU<01NY2/0G:8[05ZM901RUAP0I8dC06:2401TN@`00P1T
KPH0701SJP80HUh0061C001JB000EDD004m2001<@000CSl004`m001;>P00B3/004Lk0017>P00@c@0
03l^000e9P00;b0002LJ000R5@006`h001L<000C2P004@L000X400040`000`4000410001000P0000
00`0oooo000:0?ooo`0D06l^IP1S:E/0J2YH07<^DP25>UL0S5E<06mWB01MKe`0DW1b04]`P00lPg/0
<IiV02j[D00/[d<0;j`n03B/=`0i[S@0=Jhb03B]<P0^[CL202V/@P0W02>^C`0PYed089mW02BNJP0Z
WfP0<JEF03fZ@012ZS80AJT[04VX8`1BYAh0G:8Q05jT7`1PYQ`0GjDN066V8@1QY240FjLU05^X9@1R
YBL0I:DS05fT801FYR00DjLN056X801CZB<0BjPW04ZX<P18YSL0BZ5304RS@@15YcL0A:/`04B/;P10
ZSH0?jLo03jVB`11Z4P0@:Y10080AZPo02L0C:/l04f]>@1;ZcL0C:/_04JY;017Zc80AZ`l04F]@`13
Zdh0@:QF046WCP14Yd00BJ/j04^X?015YSX0@jHm042V@00oYd40@:E003fV?P0nYcl0@:A3046R@P10
YD00>jQ203V[A@0f[4T0>JQ803ZTA`0lX4D0>:1:03BTDP0bYU<0<JM<032VB00aXdL0<jQ803FYC@0c
ZDX00P0fYTD09`0iYT<0?:=303bXA`0jZTd0=ZYB03JZD00iZdP0?:]603V]@00h[d00=Jm303F_B@0a
Ze80;ZQI02fTH@0cYFD0=:I/032RK00cVfD0<j1Q03FQH@0eVeh0=8iL03J8GP0fS5h0=YAP03JGHP0e
UVL0<iAQ03>JG@0bWUl0;j5O036UG@0_ZU/0;j]I02jYE`0]YE@0;ZY@036`B@0203Jd@`0W03Fe@00c
]D00;kE103:dA`0b]580;k1I036_G00c[F00<jaN036[G@0dZE`0=:ML03JRF@0iX5L0>ieF03fNG`0j
W6H0?9E_03b9KP0gRfT0=i1[042LD@1IZBT0JZlB06Rb4`1X/aP0IK<J06Nc6`1W/Ah0HK8O05bb701P
]1`0I[@O06Je801M`1d0EKPP04ni801A]R00BkHW0080BK<a02L0Ak9104N]D`1:[e@0Cje?05>_BP1L
/T80IK0_07>]601jX@L0Oid607jK101oV@80P9X007jN0`1hYPP0KJdB06>]8@1L[bl0Djm804V`F@17
YEl0BIQX04fZDP1D`3`0E[H^05:e9@1>]B40C[4d04V`C@19VE`0Bh1[051fJ@19KVX0AW][042:K@15
TVP0AI9T04B;I@1CPVd00P1BNGX09`1?NH00CfJ005aQO@1aFWT0O5Yh085JN01aI7@0GW5^07EoCP2C
Pc@0T6Q>08ERGP2:IfT0RfaU08aZH`20LV00NW9I07U]FP1cHUl0P69H0:QNB@2kE3l0b4dh0;Y<@P2a
C400/U/_0;QR8P2nGST0_Ui<0;1b@@2ROd40WX9:08^BCP1mYSH0S9TG08f40@2:OP00RWT008Mh0002
08Mi000W08Uj0029M000R78008]b0029LP00S7<008]a002?M000S7P0091g002@NP00SG/008f0002?
O`00U7l009=o002<P000QgP008Mg0025M@00RgT108em0P27OP<0RX8608>82`24T@d0PILA07jI4`1j
VAH0Nj0I07NX801fZb40N:lM07N_6P1e[A/0LjHE07FT4`1dZ1<0KK0C0080I[<C02L0IZL?062K401P
TQ80IY4A06^A4@1`S`d0M98;07b?1P1oR040OX@007en001kO@00N7/007Eh001dN@00M7/007Ai001c
N`80LW`4075h101_N`<0KW`506j1201`QPT0JXP;06F=2P1PV1@0F:4P05JX;P1JY340GJ4e05nI>`1P
V3d0GITk05nN=01QWR/0I9H/06>>901RQQL00P1TNa40701SKPX0HV8105mJ001HCP00DTT00551001;
?P00BC`004Pg0016>@00B3/004Hk0013>@00@3<003XZ000d8@00:Q`002TJ000S4`006A4001P=000C
3@0040X000`9000810001@8000@100020@0P000000`0oooo000:0?ooo`0D07TWH@1]:EH0LbaB07d`
DP1k=500NEDl06QRD@1JJFL0EFUh04eZQ00nOgd0=I]Y036[D`0^[T80=:dh03^];011[BL0?:XT03>/
9@0_[2`202^]@00W02V[C@0WZ5l09IiX02NJJ`0/WFD0>ZEF04>Y@@18ZC@0CJT[056W7`1JY1L0Hj<J
06BU7@1XYQP0IJ@J06BT701PYAd0GZ@O062S8P1SXah0JJ<O06>S6@1IXQL0DZ@F05:V6`1?YbH0CZP^
04jX>`1:YTD0Aj9>04JSBP13YSl0@:Xe046[<@13ZCD0@ZI003nVD@11Z4/0AJM00080C:=002L0CjHl
05:X=01AYc40D:LZ04VY:P15Z3<0AjY004F[B`13ZE@0@jUG04BVB`18Ycl0BjTg04RU?013YC`0@jI0
03jVB00nXe00@J1;042RAP0oWT@0A9a804:PA00nYT<0>ZTo03R[@@0iZTP0>jA:03fRB00lWTT0>Ym=
03JOD`0gXE<0=J5603JQ?`0fY3d0=ZM003RY@@0eZ4000P0eZCh09`0fYSl0=jI103VZB00dZU40=JUG
03JZD00gZdL0>:a403Z^@P0g[T80=Zm;03F]E@0aZV40;JAV02bFKP0aVg40<j1d03BQL00bWFL0=J5T
03FSHP0eWV00=I=N03B=G`0gTUh0=IUR03JHI@0dTfT0<hmS036IGP0`XUh0<ZQN02nZG@0^Ze`0;jaI
02f]E00/ZE00;Zi>032aAP0203>f@P0W03:gA00a]D40;k8m03:a@00b/DX0<JiD03>]G`0`[f<0;JaO
036[G@0fYe/0=J9K03FNE`0hW5D0?9UE03ZIGP0hUFD0>Xe[03b6IP0iS6@0>9AV04JRC`1T[2@0KJlA
06Jc4P1T/aT0H[4N066c801I]BD0FK@W05Re8@1O/b00JK8R06Ba9`1L]B<0D;TS04Nj8018_al0BL0S
0080B/0W02L0BkDe04JaC015ZeD0AIiK04ZWG`1=/Ed0FKA@06^_901`Z0`0NZ@807jN0P21U`00PYP0
08>K0@1oW0<0N:<906f[5@1P/B<0D[0k04BbC@15Y5T0AHa_04ZUEP1?`400Dl0a052e:@1@]2T0C;4k
04F_E01<U600CGE]04i_K01;Ifh0BWM^046;LP15SW<0@h=d04IiM`1@M7X00P1?K8D09`1<J8@0C5Z7
05UJQ01YG7l0LEUl07IDN`1XIGL0F7a/06n8E02:R4<0Q7AD08AbGP26Nf00PWeO08]eG`26M5`0Og1M
07eZH01lHF80RF1K0:5M@P2aFSH0`E8`0;Q<@@2ZB500Y5M10;=P=P2lFT40_U]=0;=_A@2VNdH0VX9B
08FEBP1hYbP0R8l?08Em0@2;MP00R7<008]h000208Uk000W08im002<N@00RWX008eg002=N000SGD0
095d002@MP00Tg@008mf002>NP00SW/008mn002DOP00UH0009:3002<P000R7h008Ek0028MP00QgT4
08:03022RA40P9<D07jI501mWQ<0OIlC07NP5P1fYAX0Lj/R07:b:P1^]RP0K[PR076g901^/Bl0KjP[
06jc:`1/^B`0Gk`Y0080F;XK02L0E[@F05R]701HXal0GYhT05fI8@1LUb40HY/I06RJ3P1iTPD0O8P0
07n0001lO@00MGP0071f001cMP00LgT007Ak001aOP<0Kgh807232@1`R@/0Khl>06^C401XUA00I9PB
05nP501GYad0DJh^05R]=P1LXD00GYE805n8CP1KRTl0FY9>05NIBP1HXD@0G9U006:D;`1SSQ`00P1S
Pa80701TMPT0HfT105mQ001IE000DTT004e0001:?@00B3/004Hi0013>000A3H004<h0012<`00?2`0
03HV000`8@00:A`002DI000P5`006a<001/A000E3P0050`000l7000;10001`<000@100020@0P0000
00`0oooo000:0?ooo`0D08PgA@27>4D0RSQ7094hC@27=4d0NU@a06]KD`1OH6/0FEmi04mUQP0nNH00
>YMZ03>WD`0_ZT80=:/h03nX<00nYBd0>J<Z03BW:P0/Yc<202NXB@0W02JYE00XZE`0;:AN02jSF00c
XU00@:Q604bX=`1CZ2X0DJLS05:W6P1KYaL0I:LI06bW7P1bY1`0Kj@N06RQ7`1QWb00I9dN06ZN601Y
XAH0JZ4I06RQ5`1JXaL0CjDH04nX7`1@Z2X0CZH`04jX=@1;YcP0BJ@o04NS>@14YcD0@:Tb046Y<@16
Z3<0BZHe04JX@017ZCd0CjTg0080DZLh02L0DjPf05>X<01>Z2d0CjTX04^W;@18YCP0A:U704>[C@13
ZU<0AJU@04RWA`1:YSl0BJDl04ZT?`19YD80BJM404FVBP13Y580AJ=@04FRA`10XDX0@im>04BTCP10
YTh0@:Y6046ZAP12YT`0@:1<04>PB`13W4X0?YQ;03fJDP0kW540?Ye803bN@00kXC/0?JHi03bW?00l
Ycd00P0jZCd09`0gZD00=jQ103JYB@0d[4d0=JY?03J[BP0gZdL0=j]903R^AP0g[DP0=J]A03JVE`0c
YEh0<J1V036GJP0eVfP0=imV03RPH`0hWel0>j5N03ZUG`0jY5`0=iaI03BHG00dUed0<i]P03>LI00c
VFD0=IAR03>NG`0aYE`0<ZYK03:]F00a[UL0<:aD032_D00_[U40<[5=03FeBP0203Nh@@0V03Jh?`0d
/cX0=;4o03>`@00d[DL0=JaB03:/G`0`[FD0;JaR03>XGP0fY5P0>9mB03jKD@0oVE00?9IC03fAG00l
Rf40?8MV04:3I011Rf<0@IYQ052YA`1Y[1l0KJdC06Na501S/QX0Hk0M062`8@1M/2@0H;4T066c8P1V
/R00Ik@O06:b801K/Ad0E[DP04ni7P1@^B43052n900W056i:P1=/S/0B:m604J]DP1?[EH0CK5I05Rd
C`1U/Rd0JK0K07JX3`1mW@40PYL008BD0024V000PiP007nL101jX@T0L:`E05^_;@19/3T0Aj=A04R;
KP1<Y5X0CkM=05Bo>P1A_c00Ck@[04jd@016ZED0Bi9P04ehI`1AN6X0DVm^051lL@1<Q7T0BH9h04mj
NP1AL7T0CW1m0080BFV602L0B66904aDR`1GEhL0KUJ906eKOP1ZEg`0FVUl052=L`1RUEl0NHe@07]j
GP1nNF80SgMU09U_J`2IK6@0T6MT089XJ021IVh0RFI]099QH02JGDL0YE/g0;EM:P2gES<0]EA:09]J
C`2ZFD/0]5Y:0;IKD@2dJdD0YGA;099iD`1mUC/0NY`J08F72028N`00RWT008Yk0028P@000P29N@00
9`2>O000SgL0091j002BN000SWD008ee002AN000T7<008if002AN000Tg`0091g002?NP00U7`009F0
002CP`00SX@008V10027O000Rgd008:12P1nS1H0NiHI07NL6P1jX1X0NZLJ07Z[701eZAh0Kj/T076`
;`1//c40K[T/06nj:@1Z]c40K:hl06bV>P1X/CH0Jk/d05nk<`0205Vl<00W05Ni:P1I^Rd0FK@^05Na
<01C/3<0DZT/05RW:01LYB40Jj4K07VN501oV@l0P90;07b71`1eQ@P0Lgl7079o1`1`P@D0KHH:06ZD
4@1_UaL0L9lP06bS901[Y2P0I:/X066^;01NZC40FJHg05VV=P1YWCT0LI5207:9B@1/Pdd0IXM<05n9
CP1HTU40DYM=05NHA01JWS40GITM0080HhhA01`0IWl706Ae001PK000FE/00596001?@P00BSd004Dk
0014=P00?cD0044f000n<P00>c0003/[000c9@00;al002TJ000U6P0081L001hF000N50006Q<001H=
000A2@0030L000P500030@000@008000000<0?ooo`002P3oool0502CABh0V4Hc09Q5>`2L@4L0USM9
081I:`1aHdl0HVER05YSK01CIg00B85[03nIH00eYTl0<JY003J[=@0lYRh0>Z@]03JX:@0`Z2P0:ZTd
0P0VZT/0700W[540:J]C032ZC`0eZD@0>jTi04J[<P1AZbH0FJXN05ZY7@1NZ1H0HZPE06^V6@1bYA/0
MJ@I076Q6P1/X1h0KI`N06fK7P1VVaX0IIhG066P5`1RXA`0G:@N04nT7`1<YBL0DZPY04nX:@1=Ybd2
04VX;@0904RV:P19Z2D0AZTV04b[:@1>ZRX0DjT^052/=@1C[C40Ejd/0080F:`_02L0E:/d05B[;`1?
Zbd0C:P/052V;`1=Y3/0AJQ304FZA018Zcl0B:`j04ZW>P19Xcd0Bia304ZOA@1:XdD0C:A504VWA@14
Z4X0AZQ804JYA@12Z4T0@ZE@03nWDP0mZED0@:aA04FYDP15Xe80B:1A04NOC@16V4d0@iM<03jIC@0o
WD`0@Ym6042Q?`0nWcd0@9li042Q>P10YC`00P0lZ3d06`0hZD40=jU803JZBP0e[4X0=j]:03F[A@0e
ZTH0>:Q;03RZCP0hZU80=JIK03NPG`0dVf40<iQU03BGI`0iUf<0>ImM03RUE`0hYUH0>ZUE03R/EP0h
ZUD0=ZEE03BQFP0dWe`0<imO032RH`0203BSH`0:036WGP0cZ5`0=J]H03:^D@0b[dd0<;5;03>aC00d
/D`0<kA<03JgBP80>;`o02L0=[`h03Jf>00d]cl0<k=603>_B`0`ZeP0;jaQ02bZIP0/YfH0<jAR03JS
F00kX580@9e=046IC010Udd0?HaC03f:F@10RF40@XQU04NEG`1:Y540GJhb06^[701Z[QL0I;8J062a
601R[QD0GjlF05n_5`1U[QT0JZlM06Nc801U/Qh0G[<N05Va7`1L/AX0FKLJ05Vi901H^2D00P1H]BD0
9`1D^B@0D[X[04bg?015/Dh0C[9B056eE01D/dX0Fk8h062a<01`ZQH0OYX207nF0021U000PiP0086L
0020W@80OJ8707VY3P1U/1d0D;0/04fTAP18R700BjAQ04^dE`1=`440BL0h04Zf=019/DL0Aj5N04^:
HP1;LVH0DG=Z05U_LP1ILWd0EWMo05aeO`1UJgX0IfEi055ZP@02045SR00W04IIS01@Chh0GE:?06iE
SP1ZFH<0GUMo055aN`1;WW80HjII07n>D01lNUl0OGmN085hH01oLfX0PFeW081[IP1oI6T0PV1^091Y
J@2HK5l0VfE@09eTA@2^IST0/V0j0;EJ@02UFT/0ZUMD0:eLCP2cG5D0/6m:0:5eC@2>NeH0P9<d07b@
3P25PP<0RG/008]m002:P000S7d00080RW`00P2:N0009@2=M@00SGH008ed002=M@00SG8008ag002=
MP00U84009^1002DNP00TgP009J0002EQ@00TX<008n60029P`00SH@008V:0P1mTa40M:<U07:Z<01c
XB`0Kj4X06jY9`1]/Bd0K;8d06Zf>P1]^3/0J[Ld06^i<P1[]ST0K;5706VTC@1XXTP0IZ]106F_>01K
]Cd00P1D]TH09`1@/d`0Dke;04nnB`18`4/0B;e904jg@01@]3/0D:i305J]@01I/3`0GK8_06VX601^
VPl0L9@A06V;3`1ZRPh0JHl<06BI4P1PXB@0HJHd05jZ@P1R[T00HZ]705ZbAP1@[dD0EYm<05fGD@1V
SDX0Lh1907]kC@1fNTd0KH9906J7B01QPdT0FXa<052AB`1>UTP0Cj<h05:Q900205JH5`0;05b72@1N
N@40FVd005=J001@B000Bd4004Df0010>@00?C0003d]000m;P000P0k;0003`0g;@00=BD002hR000^
7`00:Ah002DI000P5@007a@001hA000J40004``000h800081@000`400040000P000000`0oooo000:
0?ooo`0D091;:@2IBRT0UTTc0956@P2=@DD0OV0^07=]@01TKE00EfQP051_I01;RF80@ieE03ZXB@0e
ZC/0=ZXa03ZX:`0eZ2X0<jPY02f[:00UZSD202:YCP0W02>ZDP0WZe80;:Y:03JZ=@10[2T0AJdU052/
7@1EZaT0G:TJ066W5`1XYAL0JZ@L06jS6P1_XaT0J9lN06RN801_W200LYdS06JN8P1OX1h0GZ4Q066S
:`1NX2d0DZ8/04jO<@1@X2`0C:DU04RW9@14ZbD0AZPT04JX7P1:Z1`0BZPM04nX9`1@ZBX0E:P[05FY
:P1HZbL0Fj/W0080EZ//02L0DJTc04^Y>01;ZSL0BjLb04fW<01;Y3P0B:Q304RY>`1:Z3<0B:T_04JV
<P15WSl0B8e;04VDC@1:W4/0Bj9704RW@P15ZD@0Aja404FYA@13ZD/0@JQA03jXEP0nZEX0@JQM046T
G014X5`0AiUF04FED@14Se80@I5B03jEDP0oVTh0@Z1904>O@`10VT40@9Ho046F@00oWD400P0mYSl0
9`0hYT<0>:9;03JXCP0d[4/0<jY703BXA00cYdT0=Z5?03NTE00iY5l0=iUT03F@I`0fRfH0=H]W03J>
J00kTF80>I]K03NXEP0h/580>K5A03JaD@0f/500=JaF036TG@0bWel0<J1Q02nSH00aYVD0<ZMT03:X
HP0bZEd0<jYG03B]C@0e/DD0=K=203NcB00i]4`0=KA=03FfBP0203Fh@P0W03Jf?P0c]400<[=9032b
D@0b[UP0<:]S02jYJ@0^Y6l0<9ma032PKP0fWf@0?9eH042KC@13UTX0?hm803f7C`0mQED0?8YR03n@
J@17WeT0DJm306>_9`1W[Ad0Hk0N05jb7`1M/1T0GJlB06>]3`1VZQ40J:/C06B]6@1U[ah0GjlQ062`
8@1K/Q`0H;8D05nd5P1O]B00G;PO0080F[LQ02L0E[@Q05709@1>`3D0B[E505:eB`1B]4`0E[=:05Rb
@01I/c`0J:`S07JK2`1hU`@0O9<0082E0022W000Qil008FO0022Y`P0LZhG05bd8`1FZD<0AiI^04^Y
IP17/600BKQ>04Fk@015^S/0AK5804NTF@1;REl0Bg1R04i`I@1?Kfh0D7=f04iiM`1BNgT0GWEj05ad
NP1<MWd00P12Kh<09`1=HHT0Ge:806IDQ`1ZEhL0I5j105iTOP1CPWD0DZET06bOE028QE80O7]U06mm
H`1/Mf00IG1U06U]K@1eJFd0OeiX08UFJ@2HEVH0XF5P0:M/E@2]HU80/UQ;0:]MB@2`HDP0]UUB0;Q?
E`2]H5T0[FAM0:EeCP2FOTh0PGmF07fB<@1oR@X0Pg`108Im0026O000RX0008Yl000208Uj000W08]g
002:N@00S74008e_002BM@00UWP009Ij002GO`40VH<209V:102JS@H0VHH909J6102GP@40UX@00964
002?QP00T8<008Z70P27U@T0N:4C07Z/8P1h/bd0M:`Z07F^9`1a/RD0KkDX06jh;P1^^Bh0KKP_06^g
<`1^/S@0Kjdn06nTA@1bV500Jii=06RXAP1TZd80FkI90080FKA=02L0F;9D05>eEP1:]e@0A[Q@04Fj
BP18^d80CKe004nm@`1?^d40Dk/l05Vk>P1N]c<0JJXY076O:@1cWbP0LIlU06bV901Y[2l0H[=206F^
E01R[640H[MM06BcH01K/Th0DjXk05bE>`1[SD<0LXTo06j3>P1[RRd0JI0M06NA6@1STa/0GILO05RM
8`1@WBP0Cj</04fU9P1<YRD00P1@X1`07@1HS`l0F7`2055Z0@1>F040B4`004M10014>P00?cH003Xb
000h;`00>2`003LZ000g;@00=bT0038V000`8P00;20002PM000W6`0091L0024E000M4`00614001D<
000>200020@000@100010@000@0001l00000303oool000X0oooo01@0QTXT09I98P2EBB/0RD@o0954
A`2<G3X0NW4i06QbBP1NKeL0E79R05:9H01:WU@0?j=803^R@00nY3P0?JH]03VY:00dZRH0;J`Z02FZ
=0809:Y302L0:JY602j[@`0gZcT0@:X[04N]8P1=Zb40BZ/M04jY7P1CZah0G:PJ05nV6@1UXQh0JZ<O
06fR7@1^X1d0KIlN06nP801_XRD0J:0V062S9`1LXRP0GJ<]05bR;`1CWS80Cid`04nP:`1;Y2<0AZHR
04RW8`1>YR40CZLM04^U6@1>YaT0D:XS05B/8@1HZB80FJTR05^Y8@1JZb400P1BZbT09`1=[C00CJTh
04ZX?@1@ZSL0DJLd04nV=`1;Z3/0AZTd04^Y;`18ZBh0AJDe04BM@014T4/0AYa>04ZRB01:YT<0BJU1
04JZA014[4L0AZU804NWD014YU@0A:MH04BQG012WV80AIiQ04JJGP17UET0AY=E04F;F014ReT0@95F
046EDP14WT/0A:1804NGAP17TDH0B91:04VCA`0204NQA@0W04NRA@17VTP0@j9903nVB@0jYT@0>JQ0
03RV@00kXd<0?:E203bVB@0kXDl0>Ia?03NLC00eW4l0=iiA03ZOD@0kYdd0>:e;03^aB@0j/TX0=[9:
03FaC@0eZdl0=:QB03FSD`0gXUL0=j=M03NTH`0eZ680=:]P03JZGP0fZUH0=Jm803Jc@00i]3`0=kA2
03NfA00h]TH0=[M90080=KE702L0<[A503:aC@0a/UP0;jmM036YH`0bYFT0<:=^03:PK@0bW6/0=9eT
03ZNGP0mX5H0?ia<04>GB011U4H0@H];042=D@0nUeD0@iaD04f[@@1I/Rh0Hk8P06J`701T/AX0IJlE
06J_4P1U[A80HjhF06N^701U[Qh0H;0H05b`6`1M[AX0Hk4L06V]5@1Z[@d0HZlB062d5`1N^AT00P1J
]ah09`1E]280C;DS04k0<01;_400Cl1404g0B01F]4<0F;E105JdA01S[Rd0K:PH07BN3@1kU080Ohd0
08FC002;U@00R9P008BO201g[1@0Jk4Q05b^@@17[F`0A:]Z04JXK014/e`0@/1<04:jB017/e00B:MN
04^:H01@JV@0BVmV04AdI`16NV/0A81X04V4K@1?Og@0Cgaj04IlO00204QcOP0W05eTOP1hEgl0LUF0
06YDP@1QHH40Ffen05F=J@1F[5H0L:A7086DB01_RUT0K8YE06J8EP1TPE/0JWaS07EcJ@20JF@0RUaY
09iDI02PEf@0TfQJ0:1TDP2eEU00[5UC0:YRD02cFe80_E5I0:YWF02YJed0VgEH08mmE01dSTh0NI8X
08:62021O000QGh008Im0028O000Rg/00080RG/002L0Rgl008ai002=M`00TGD009J00@2JQP40VhT5
09V@3@2JT`/0UIL@08fI4P2@VAT0Si@@09B;0`2DQ`40ThP0096:002>S@00Qi<607fQ4P1c[1D0N[DK
07Rd;@1f]c00MKX]07Bg9P1c]RD0L;PX07:k;01_^C<0KK@i06b/@@1^X440NIE707j:C@1/VdX0HZM9
06:YB@1J]5L00P1E]5D09`1@/5H0Bk1M04N[E`10ZU80@:e=04JiA018aSl0A/=204S1@P1?`3/0Dl14
05JiE`1IYU00FYeB05bQD`1MYDL0Fj]405b]D@1JZf40FjIb05RVN01F/gD0G;5f05B/FP1<Y3/0Ehdc
06QgE@1UOU80FW`m05N98@1KS@T0G8X505J;201FS`d0EIPB056L6@1<XAd0AJ@R04BV:@0204FT9@0M
04fF5@1DO0D0C6X404MM0P15DP00ADP004=10010>P00?C@003X`000h;`00=b`003L]000g:@00<bL0
02hT000[7`00:b0002HL000U6`0091T001`E000G3`004``000h9000;10001@800041000100007`00
000<0?ooo`002P3oool05029BBd0T4LZ0914>@23?dH0S4E?08aIA`1gLCh0IGI<05aeG01EN6@0D8IR
04NLE@0jYD/0=JE003NZ>00lZbh0>Z`Z03F^:@0^[S009K0i0P0R[D403@0[[D00<Zhj03^`:`15/1l0
C:hL052]7@1>[B40BZ`W05>/901KZB00GJHK05nV7`1WXb<00P1`XB80601_X1l0KJ4S06bQ:P1YX2/0
Gj0/05bR9`1PXBH0G:8X05VR:@1EWR@0E9dO05FQ6P1BY1P0D:DM05RS7@1JYAL0EZ@D056Y6@1AZal0
EZ/L05bZ601LZaX0Fj/L05J/7@80C:hU02L0BJ`]04^[=`1=[CX0EJXj05J/=01CZ3<0CZXd04bY<@1<
Z300BZTa04JV>014Xd80@Y]:04FRB01;Yd<0Bj]204Z[@016ZdD0AZU=04JYC`18ZED0AZIH04JQG016
UV80Ai9U04NJI@17W640AiUJ04FFFP12S5d0@heM04>@FP12TeD0@9mA04BRC@15WT/0BYM904^?B`19
S5800P1=UU409`1@UU40DHe;04fIB015X4D0@JI203^X>`0nZCT0?:Hi04:X>@0nZST0?JPm03jX?P0j
Zcd0>Jdm03Z/@`0k[DD0>[5403ZbA00i/D80=k1003:bA00b/DP0<Zi803J[B@0jZ4X0>ZQ=03ZWE`0k
Yf<0>JYR03BYHP0cZ5d0=JeD03V_BP0h/T00=[Dj03Rf>@0h^C/0>;To03FfA`0203:fD00W036bE@0^
/5h0;JiS02jXIP0_XFP0<9][03:LJ`0dWVH0=ImM03FSFP0dYU<0=jQ<03VVAP0kYDD0>JA203fV@P0o
YSl0@ZTi04R]=@1I/RP0H;HS066b7`1T/Qh0HK4F062Z3P1RZa00HJ/I05n`8`1N[RT0F[0/05Ba7P1C
/1T0Ek8K05j`701X[0l0JZT<05j_3`1L/AL0F[LL0080EKD/02L0D[@[05:`9`1A/C40BL0o04k0@@1A
`4@0EK=105Vd@01H`4H0G[<d05b`:@1dYQH0OI@408B;0026RP00RHd008ZA0026V0H0Oj<?07:[701S
[T00Ak5S04>]K013WGH0@jY[04FhGP13]UH0@ZiO04NRI@1<Qf/0BfYZ04EeJP0kOVT0?H5W0424H`17
Pf@0CGi_04ikM@1;MGP00P1=KGT09`1[GgL0PeIg07QFO01YEGl0GVAm05m`N@1NTV00FJm806VZ@@1^
UD/0HhiI066>F01TTED0IhiI06f3G`1dNFD0LWA[07mZJP2RF5X0XeAE08IXDP2:KTT0/EM40:]ECP2P
FDd0ZEe90;UMC02ZKUD0Z6iG09a^E`29NU@0LJ0k07JJ7`1mQPL0PW`0081k0021NP00PgX008Qk0002
08Yj000W08ik002DO@40V8@409^82`2OTPl0X9`B09jT4`2GYa<0TZTE08ZZ5`22Yah0Q:<U08ZQ6`2>
W1D0UID909FE0P2EU`L0S9h>08BU4P20/Q@0OKHI07^f7@1i]BP0NKTZ07Vl:01k^R80Mk/T07>e;P1`
[3/0KJ/o06b/?@1/[Sl0Kje007JR@`1dUD`0KIm;06>[B@1N[U00E[EI0080D;=D02L0DZiE04VdF013
]5@0A;9@04N^C019]DX0B<1604W0@P1;a3T0D<@c0570>P1A_T@0D[Y705>hBP1F^TL0F;]005Jk?01B
^TT0C[MJ04^XK@17ZV/0B;MU04jeG01A[DH0CZD`05>N:@1JVDT0FIE905:E=@1BUAl0EY8>05B@501A
T1L0Di<K052D5P1>V1X0C9XM04NN9@11XRH00P13X1X0701<Ta80D7h=04Qa3P13G`D0AED004I:0016
@000@S`0040e000l<@00>S0003L/000e;000<b`0038V000_8`00;B0002TP000X7P009Q`002<H000K
5P005a4001<=000@2@003@D000H30002000P000000`0oooo000:0?ooo`0D08e9?@29B3P0QT5808Do
EP28A5d0QEQ=07A_@@1TNTh0FgUL05=lH`1>Q680@IIJ03ZUD@0aZ4P0=ZU003V[=00j[300=Jlc02b_
?@0R/D42026cA00W02Zc@00a/ST0?K4U04>`7P1;[1`0DJ`P04j/:01;[Bl0C:`[05>X901IYah0FjLQ
05jT:01WY2P0KZ8W06NR901RXbP0H:@^05nO<@1FWRl0D:@W056V8`1>Yb<0DJ@P05JP6P1HWAT0DilG
04nR5`1?XAT0EZ<I05^S601GYQ80DjPE05B[701HZaH0FJXD05FZ5`1@[1`0C:`O0080B:dX02L0Ajd^
04n/=`1CZc`0EZ]005R[>01EYc@0D:Dc04^U<`17Z3D0AZPg04BV?P14YDD0A:=<04BWAP15[D<0Ak51
04R^@@15ZDP0AZME04BVF@14YU`0AZAO04RKH`15QfL0AhEY04FBK@15V6X0A9MR046DGP0nSEd0@HmN
04:@G011TUX0?Z1C042XDP14YTh0B9i<04Z=D018PUX00P1=QUh09`1@REh0EX9F04j;C01:V4P0AJ52
046Y>010ZcH0@:Pf04:V=@0oZ3@0?j`g046_=P0m/c@0>kDj03Vb@@0m/D@0>k=203Vd?`0g/3h0=[0i
02n`?@0b/D80=:m003Va@`0k[T@0?:Y:03^VDP0jYV<0>:IW03FTHP0dYEl0=:UF03J_C@0h/T<0=[Di
03Ve=P0h^CH0=[Q003>eC@02036dF`0W036aI`0^[Fl0;JI^02jKK@0cT6/0=haZ03NAJ@0dV6H0<imG
036UCP0bZ4/0<ZQ603>/A00f[D80=K8n03Je=`0k]bh0@kPU04^i7P1H]aX0HKHK06>d7@1T/al0H;8K
05n_4@1RZ`l0Hj`B06>`6@1N[QX0GK0L05^`5P1K/1@0HJlF06B`4P1V[`d0JZh=06>`4`1O/AH0F[@I
0080F;DT02L0Ek<R05Vb6P1E/b@0D<0g05Bj>@1F]C`0FKDi05Zd>@1K]C/0GK@a05fc;@1b[1P0PIX5
08BB0027R`00RH`008ZD0029VP80PY/907jV501X/B/0CKA;04N^H@13WW`0@JUi04:cJ@14/Ed0B:EI
04^KGP1;TV80BHMQ046;I@0jTFd0?8a[0424I01=OfH0FGM[05]aL@1HLW<00P1HJW<09`1^GW40OUYa
079MMP1SHG`0Gg5`05]gJ`1VT500JjY0072U@@1VUT`0GhmH0625H@1TRUP0K8ML07=iG`1jL6H0Mg=[
089cI02LJ5@0XUI808IOC021JTL0Zee00:]AC`2MCU@0Yee?0;IQBP2ZLTh0YFmC09E[E@26Ne40Kj0[
07RJ5P22S0D0Qh4008An0023O@00Rgd008Yi000208eh000W09Mk002IR0H0UYHB09VN6`2HXad0V:lO
092f8@2=/ad0S[<Q08b`9026ZBl0Q9Xg08FG<`28VRd0TilE09>O102?Y`l0Pk0H07Zb701i]ad0NKDZ
07Zd;01i]B/0NKXY07fo;01l`2`0NL0_07J^>`1aTDh0K8mD06bGD01Z[4X0K;I206V/AP1[WDh0JIm9
06:/C01N/U`0E[AN0080E:iB02L0E;5D04BiE00o_E<0?kaC04J`E`16/UH0AKEF04VjC`16`Ch0@lDk
03jiA@11]4T0AK]=04O2D@19b4h0BLE604S2B013^U@0?kEP03ZVM00lYFl0>Za[03nXDP14ZS`0AZXn
04>X;`17[CX0CZLg052O:P1;VaX0CiLE052I9@1?UbH0C9@Y04bG7`1;Ual0BYDQ04FD:@10WRH00P10
W1P07018TA@0Ah4D04Ac4`15H0L0AUD004Q:0016@000@Sd0040h000o=000>C8003P_000d;@00=B`0
03DX000b9@00;RD002/Q000X7P00:1/002<J000K5`005Q<001<=000A2`0030H000H20002000P0000
00`0oooo000:0?ooo`0D08Q4AP21AT<0QD=A08M5H028B5l0Q5M:07=XA01WLU40GGIO05QgIP1BO680
AI1I03bQC`0iYDD0?JTm03j[=00iZc40<Z`d02b_>00U/CP202Rb>@0W02nd=00d/Rh0?K0T04>^7P1;
[1`0DJ`O05>Y8@1=[2L0EJ/U062W7@1UYQ`0IZ@N06JS8`1^Xb@0Kj4Q06fQ8@1]Xb40K:@V06ZQ;01O
Wb/0FJ4V05VT901AYB80Dj@S05NR701KX1P0Dj0I05:O7@1CWAh0FYhN05nO6`1LY1@0G:TG05fZ701M
ZQ<0FZXD05FZ6@1?ZQl0DZXT0080D:hZ02L0CjX_04n[=`1CZcX0EJ`m05BV=`1EYcP0DJ<h04bS>`18
Yc`0AZLn046V?P13Y4@0A:9904JY@`19[c`0A[8n04N`@`16ZDh0AjMH04FUF`14Xel0AZ9P04NHH017
QfD0AXAX04F=J@16TVL0AhiO04J;FP17QEX0B8IJ04F:FP14SEL0@YeE04BUE015XU00Aia=04R<D`18
Q5/00P1:RF409`1>S5`0ChUF04^@C@18VTL0B:1004RY=P19[340B:Pf04ZU=016Z380AZ/b04J`;`16
/bd0@[@`04:a=014/3P0A;8c04B_<P10[340@:d[03b`<P0h[c`0>;8m03Vc?`0j/Sl0?:m403ZYD00d
Y5d0=JES03FTHP0dYUh0=JQI03F^E00i/D/0>;A003Vd?00e]CT0=[Q003>fA`02032cE00W032cGP0^
[F40<:MO03BNF@0hUE@0?YAD03nGE@0oWTd0@:E504>Z?@15ZcL0AZhf04B_=018/S@0BKD/04^g:01=
]b80D[HN05Vf6`1P]Q/0I;<R06F_901R[bH0GK<O05^^4`1M[A40Gk0A05n`5@1I[a80F:h@05b^3@1R
[0d0IJ`>06F_3`1R[a<0GjlI05j^6@1O[QX0H:lL0080F[4Q02L0FK<H05bc401J/a/0DkH_05Bd<@1F
/S`0F;8g05Nc=01F/Cd0Ek4b05Fd<@1^/1`0O:07086E0026TP00RI4008ZG002:W000Ri`208FS301`
/240C[@f04Z^D`10W8<0?jMo042ZNP16XVP0C9MG04bCEP17TeT0AYAG042HI@0fW6d0>Xe^04=kJP1B
K6`0IfQ]06mVK@1UJfh00P1OJfl09`1/HFh0NE]a06aPM`1NHWX0FW=]04mfJ01[SdH0LZ`n06RZA@1U
ZE40HI=K06=fH`1UOE/0IW]J07QaH`25IF`0S6aY099aI02@Je/0TUmQ081PG024HE<0YVA:0:EJF02K
Ef<0XeaJ0;=[DP2SLdh0VG1?08QhDP1jR4T0M:8M086L2`25S`<0SHH008R2002:QP00T8D009600002
09N1100W09^9402OVa<0W:HK09RZ902C[2L0S[D/08fh;@2<^2T0R[P[08bg9`29]2/0RjX`08VQ>P2;
VcD0S:HK096U402;[A40P;HN07Rh9@1g^bL0NKXY07Bj8`1i^bD0M/0T07O3:P1h`380Mk`f07Fa?P1b
Td`0LXe@07>BC01/XDH0J:Tn06NZ?@1ZXd<0KYi206fVA`1_[El0HjaL0080IZME02L0HZaE05f`E@16
_5L0>[]K03jhEP14^d`0AkY404Ri?@16_c40@<0]042l;`17_S00CL4a04c2>@1<`C/0C;lj04nk?@1:
]D40B:i?04FVG00oYe/0@JMR042YDP14[Sl0?jhm042Y:`14Zb/0BJ@X04NK9`15V2@0AYdP04RO:01:
UbX0B98`04ZB9`18VBL0AILY04:G;`0lWRh00P0mVad07012SaL0AX8H04Ec4018H@@0BU<004]60015
?P00@SX0044h000o<000>2h003H/000e:P00=BT003<U000b9P00;B8002`N000Y70009AP0028G000N
5@00614001<:000<2@002`D000@20001000P000000`0oooo000:0?ooo`0D0791E01WBeD0Ie9F06mK
E`1dHe<0MFU:06M^BP1WM5D0Hg=W05edK01HNF<0BhYH03nPC00nYd<0?j`h03^^<P0h[Bl0<:d/02Z_
;`0Z/30202na;P0W03>a9`0h/B00>ZlL04B^7@1:Za`0BZ/O04f[7P1=ZR40F:TN066X6`1XYaP0JZDH
06VU6`1^Y1`0LJ0J07FP6@1fXaX0MJ@O06fS901UX2@0H:8W05^S9`1BYBL0DZDV05NU8P1HXal0Ej<R
05VP9`1FWR`0Fi`T05nL6`1OXAD0GZLE05nY5`1LZ1H0Fj/F05B[701=ZbH0DZT]0080E:/^02L0DZTb
056X>01BZSX0E:Po05FX>@1?Yc/0CZHn04RVA@15YT<0@ZM304>X@P16YT@0AZE604RZ?P17[SX0A[8o
04B_BP16ZUH0AJQL04BVFP16XeX0@j1N04BGH014RV<0AXUV04>?IP15RVD0AHMM04^4E`1AP5D0CX5C
04R5E019R5L0AIUG04FPF014WeD0AYIH04F=FP16R5d00P14Sed09`19UU/0AIMB04FMC016XT<0B:8o
04fZ=01>/340C:/f04fZ=019[340Ajl`04b`;@1?/RH0BK8W04Na:P1<[b/0CJlX04V`:P17[R`0BJhV
04>c:@0m/cH0>[8l03^d?00k/cd0>k1003R/C00bZET0<ZUO03:YH@0`ZF<0<jaP03>_F`0g/E<0=kI8
03Zf@P0g]Ch0=kDm03Be?`0203:dB@0W02jdC`0_/U00<Ja;03NY@`0kZCl0A:Th04^/<01C[2X0EZ`V
05b^9P1J/R80FK@O05Rf7`1M]b40G[HN05bh6`1L]aP0G[DJ06>e6`1U]200JK<V06N`9@1S/2H0Fk4M
066a4P1U/0d0JK0>06F_3P1PZQ00HZX>05n[4@1UZa40J:dA06B^5@1P/1/0H:hM06:_6P1Q[aH0G;0F
0080G:lG0100HK8B06>c3@1O]AL0F;DO05Jc8`1G]2H0F;<Z05Fb<@1D/CT0E;4d05Je=@1Z[R40N:8>
08>I1`29T@40Ri000P2=V0005@2?VP00S:8607Z_5P1R/RH0EJe604NKN@15Y7`0@jag04BYIP1>YU@0
CZEC04fYE`19[5d0AZYP046XIP15VVP0BhQW05=oIP1NO680GgYV05InK00205ImK00W06AcKP1_KVd0
J6i/069/K01KPE@0EiQ406fS>01Z[SD0Ije006F/C01SUEL0IGEP06IkF@1YNEH0M6aU08UML@2BH6d0
Vf=^099RIP2=EVh0PVES08ePH@2OK5@0Wf9L09eLJ@2RGf40ZVEH09i^DP2EKE00PGU?07N7@@1iVAD0
OXl408F:0P2<Q000RhL008j8002BRP00UX400080WXH@02L0UH`S0:N?;02QTcD0SiTe08NM@028ZCd0
QZdh08:g;`24^BX0Q;PV08Fj8@27]RD0QZhe08NH>`2:YBP0QjXH08>_501l]240M[Hf07C0<01d^bX0
M;DQ07:e9@1d_2T0ML4e07G1>`1f`440Mk=407RGC@1iT4d0OHY=06f@A@1VV3T0JITg06fG?`1bUSl0
NiY507fSG@1aYE`00P1cX5`09`1bXf40Mj9P056dI@0f_6@0=/5L03c4BP15_ch0AkPj04:l;00l_2P0
?KTZ046j<@11^bl0?;da03^m=P16]d00CK1:04ZR@P1:V4h0B9aB04>LB013WEX0@JIC04B]A`10[c`0
?ZXX046Y9@13YAl0AIXU042F;@10XBl0@:D`042J<012SSD0AI@/046M;P0kVc00>YPb03RM<`0203FI
9@0;03^<7@0nPa`0AW@B04US101>EP40BDH0048n0014?000@SH003dd000g<@000P0d;P003P0b:@00
<2H0030S000[7`00:1`002HH000U60008aT0020G000J4P004PX000d6000:0`000`408@00000<0?oo
o`002P3oool0501N>V80FTER06ACG01`HU@0KfmE06QeE`1UMED0JGAN06IdJP1SLW80GgAV0525F@14
Vdh0?ZI103^^?@0i/CP0;k0d02R_;`0Y[b`0;;0[0P0a[bH09`0d[1h0>:lK03V_6010[al0AZ`P04V/
7`19ZQX0BZPM05^V7@1QYA`0I:DM06FU5`1VYQ@0JJHG06bR5`1^Y1@0LZDD07>U6P1[YAd0H:<S05fS
:`1GY300CJ<`04jS;01BYRD0F:DW05ZT:@1OX2h0GJ0b06>L:P1SVQh0HYhH062U5@1NYaL0FJXJ05B[
7@1?[2H0CZ/_05BY=P0205BZ=`0W05:X>01@XS`0D:Pn05:W?01?YCd0C:M104ZWAP1:Z4h0AjM>04FW
BP11Y480AJI404JUB017ZSh0AJln04>aBP10ZeX0@jUR046XH015Xe`0@j1I04>JG`12UV00@HiQ04><
I012RV80@H5U04EjG01?NEL0FWMG05IgE@1>OE@0Ah1J04VAGP17Vf80AiYN04N?G@12Red0@XYR0080
@i9I02L0A9]I042TD011YTX0A:M104RQ?P1<ZS@0C;0`04b]=P1:[C@0Ak4^04Na<019/bd0CK<W04Vc
9`1</b/0DK0X05F_9P1A[R<0DZhV05:b8018/R@0?k<b03^c>P0k]CP0>K@k03N`@@0aZTh0<JUH02nZ
GP0aZf00<JaT036]H`0b/640=K9J03RfE@0k]dX0=[A003Je>00d]3T00P0b]4009`0`]4@0;k53036]
?P0i/3L0@;@_04Zf8`1F^1P0GkDB06>e401T]@l0H;L=062f3`1P]a<0I;PI06Ne6P1T]QH0HkHE06Be
5`1S]200IK@W06Nd:P1X/BH0GK4U05jc7P1T/Q00J[0;06n]301aZP/0K:T906N[401W[1T0I[0K06Fa
6P1M[al0FZhT05b]901R[QH0Gk0D06:c4@0206>a3`0W066`3@1S/A40GK<D05>e601B]1T0D[@L05Jd
901@/bd0D[Dh05>d=`1J/cD0JJlV072Z701jW@l0R9<408f@002>U`00SIL008nJ002>Y0<0P;4?06^d
6@1R[Cd0Ai]_04>UMP15Zg@0@ji[04fcFP1>/U40CKIG04VgGP16]6D0AjaQ04VRIP1<U6P0CXU/05>1
I01?OVP0C81]0080CX1^02L0HgU_075eL@1YKV`0HVeV06:G?01I]RX0H[DZ06Fg;`1U/SX0IZQ<06>N
E`1ZS5D0LHY?06]iE@1aMf80O6e]08QVKP2DGg40WV1U0:1EIP2@JEl0RfmU08ieH02IK6<0XfQ[0:AT
H@2VHUP0W6UB09AXC@21OdP0MX/n07VG5`26R@<0RXD008n7002BQ@00THH009N80P2KS0`00P2MT1/0
9`2MUbP0W9la096Y<`27Yc<0Q:Hm086_>P1m/cP0OK@a07nf<01o^2h0PKXZ082l;`24/3/0RIhm08JY
<@24]1d0P;4F07b`:01a[Sh0LKHn07Bj=`1b`2T0Lk`^07Nk<`1h`3`0Nl0j07Vi>P1g[d40LYm607JH
B@1gV4@0L:0m06nV<`1aYBd0M:8c07ZG=P1lW400N:=;06NRD`0206FJH@0W06BLJ01RX6L0CK=Y0431
IP0m`f@0?/9C04FiC@17]TD0A[Pl04Nd>P15[cd0Aj/k04NU=P14WS@0@iQ504JHD`1?SUX0FGm>05mn
E01BTU00Bi=704B:E@15Ve80AZY804:[>016YRh0AZL/04RT8018VBL0A9D`04BO<@12YS<0@ITa0467
<`17TbH0@IPQ03fG7`0oUR40>i<R0080=i0M01/0>XLH04225P18M`/0BfP204iG001;A`00ACd004<i
0011=`00@C8003/_000i<000>Bd003DX000a8P00;Qd002TL000V6P0091T0028E000M5P007Q@001P@
000@2`0030H000L2000200008@00000<0?ooo`002P3oool0501NBfL0FeAR06APEP1ZKE40J7MA061l
E@1QNU@0IWUP06IeIP1QMFX0HGUQ0566E@14W4X0?:I103N/@@0c[D00;:hk02R_=@0[[bh0<j`V0P0h
Zb409`0i[1d0>jXI03j/5@19[1`0Cj`M04n[7@1BZQ/0EZ@M05nP801YXah0L:@N06jT5`1_Y1D0LJ<G
07BT601fXQD0NYlE07BP5`1]XAL0I:8P062R9@1NX2D0EIlY05JN9`1IX280GZ8T06BP901VX2@0Ii/W
06^I8P1YVAT0JIhH06BS5P1MYaP0F:PN05>Z8`1?ZBT0CZLb05FY>00205JZ>00W05F[>01EYCT0EJ<i
05NO=P1EWcH0E:<h04nT?01<YTD0B:I804BY@`13Z400A:U004BX@P16ZSl0B:a304JZD@14Z5h0@J9S
04>MH`14Weh0A9aP04JHHP15UV80AY1T04>:I@14R6@0AX5S04]jGP1DMU`0H75N05]eGP1@OEh0BHMP
04VDG@19VUl0BYEK04N>FP18SEP0BXaJ0080AYAF02L0@iaB04:RCP14YTH0A:I004JX@019[3H0CZlb
04b^=`1>[SD0C;4]04^a;@1=[Rh0DJhZ04n_:@1</B/0E;8W05Nb8`1H[BD0Ej`V05R]8P1A/Ah0B;4V
04F`:P13/2/0@K0/03n_=00j[D<0=:Y=03FYD`0gZeH0=Z]F03Z]DP0m[T/0@;5204Fd>01;/bl0B;<Z
04Je:@1:/RP00P1=/Bh09`1>/C40DJl`05R^;01L[bT0GK4S05nc7@1R]AP0I;@G06Jb501U]180IK@?
06:e401T]1<0I[@I06Bd7@1S]1P0I;LF06Jd6@1U]2<0I;8Y06J`:@1V[b80G[<W05ba7`1S[a40JZd=
06nY3`1]Y`d0K:D<06bZ4P1X[1`0JZlK06F_6`1RZb40GjXT06:Y8P1SZQP0H:hG062a4002066`300W
066^301R[a<0G[4D05Ba5`1B/QP0Dk4L056b8`1A/bl0D[Hl05Jb=`1I/cH0IK0V06R/8`1jY1@0QIL6
08fG002>U`00RiT008bO002=Y@80Q:`907Ba4`1U[c@0C9mU04VPJ015XVl0B:]U04fdE@1@]U40BkIG
04O0H018/f00BjaP04fTIP1>UVd0DhU^04elK`1:MVl0BGAa0080CWU_02L0I7Y^071oJP1[PE/0IXI:
06BZ:P1M`2L0H;PY06Be<@1R[ch0IZ1H06BIG01TTeP0K8YC06mhF@1`NF40N7IZ08AYI`2BE6h0WEeQ
0:aHHP2IJed0T6][08McJ`2?KW40XFYa0:=RJ02PGe`0XFAA0:9XD022QD00LX/f07b?5P21P`80QX40
08j3002AQ@00UH@009b:2P2HUQ/00P2FVRL09`2KUCL0SK0e08Nd<`26ZS<0P:/d08:d<P1m^C@0OkPb
07fg<`1n`3P0OL0f07k0?@21/4<0RJ1008NZ=@23]1l0O[@H07Na;01bWDL0LJI:076i@`1_`3/0N<0j
07Jm@01f^d00Nk]007Vf?P1d/4D0LZM;07:LBP1aX4P0L:i3072c>P1b]380MJle07FS=P1eXS`0L:94
05fOCP0205nJH`0W05JIM`1;XGH0B[Qc04C8K@0oag80?keX03n]IP15/600Ak=G04Z]DP19YUD0BiaE
04R7C`13O4T0@FeI04IfJ`1?JVh0I5aP07QRH01PQUD0Bha>04ElF@13U5H0AjI?04FZ>`15Y3H0B:Pd
04BY9`17Vbd0?iPh042S>P0lYcP0>i/d03R8>P0nUbT0?ITM03ZH5`0oUAH0>Y4H0080=HdI01/0<XHF
03644@0fO0P0@g4104eN001>B000ACh004Dk0012>000@CD003`d000k<P00>Rl003H[000b9@00;B40
02LI000W6P009aP0028E000O4@007A@001TB000C2`0030D000H2000200008@00000<0?ooo`002P3o
ool0501SIf40G6]N05QcE`1LO4d0G89?05V5FP1GOe`0F7iR05QnI`1HNVT0F8=T052@E@13X4P0=:I6
02f[C`0V[E@09:m?02Fb@@0//3@0<ZdT0P0fZah09`0lZAT0>j`F04:Z501:[AP0CZhL056]7`1CZb40
EjPS05nT901WXb40L:@K076U4`1_YQ@0LZ<G07BR601fWQT0MIdK06^J6`1SW1`0GYhQ05nL7`1OW200
GIXS05jJ8@1UWAh0J9`M06bL701[V240JILN06>I6P1TWaH0IZ4H062V6P1IZQh0E:XT052];01?[340
CJTd05>Y>00205>X=`0305FY=`1FYSP0EZ8e0080EYhc0280DIhb04jS>P1:Yd80AZU204>Z@P12Zd00
A:/n04B/@P16Zd40@jQ:04BVE@14W680@iEU04>CH`12V6D0A9QU04JFIP17UFX0AiA[04J<I`17QFD0
B7aT051kHP1GN6@0Hg5V05]dIP1AOfL0BXUW04^FH019Ueh0CHmK04^>E@1;T580BI=E0P1:UU009`17
WDh0AZ1;04RVA@16ZSl0Aj`o04V_?@1:[cL0BK0i052`=@1?/Bd0C:h/04n/<`1B[300Cjd[04fb;01D
/RX0Fk8R05Va8`1I[RP0FJhP05R`701A/1`0BZhP04b/801>[b40AjhZ03n]=00lZd00?j]803n/BP0o
[T/0A:e304R`?01</Rh0D;DS05Fd7`1F]A/0EK<K05N`7P0205n]8@0W06J`8P1Z/B40Kk0O06nb7@1^
/Qd0J;@L06Jd7P1U/b80IkHP06Fe7@1T`1P0I;HE06Jd501V]QL0IkPK06Fg6P1V]1T0IK<L06Nb901U
/BL0I;8U06>`8@1O[b80I[0L06B_5P1U[1H0IZPJ06BZ6P1TZ1P0JjHG06fW601aZQL0KJXH06RY601^
YaL0LJTE06N[6`1N[Ql0F[8F0080Gk8?02L0I;0A06Ba601T/aH0E[<I05:b6P1C/Q/0E[<R05Fb;`1G
/S/0F[4d066f<01//RH0KJhS07NY5026X0H0RiX0092G002=U000SiX008fQ0027ZPD0O[4:06Nc:`1?
[5H0Bj=L04VGH01<Wf40CjQH04n_E01=[5X0BZaN04VXH@1?Y5h0Di]Q05f@I`1IQ6`0E7U_04ieK@17
MG400P1<P6T09`1FU6@0HJMG06FZ?P1Z/2L0JkHL06;06P1W]Q/0JK0/06F]>01TY4P0I:A?05jVB@1T
XdD0J9]706^=CP1aO5d0OgAI09UOF02=JV80SEaa08e_HP2AKVH0OViW089[L02MJ700YFA]0:AKF@2V
I500[6U?08R;?01gV2`0PXhD08Io0@28OP00Rh000922002DQ@00VI0<09RG7`0209RP:00W09FW<@2@
/Rh0SjTb08fT=`29[3@0R;D_08Nh;P23]R/0PkT]082j;P21_3<0QKPn08fVA`28W4L0Q:Dl08Bg9@23
]A`0O:T^07V@B@1fVdT0N;U407;0@01k`3P0MkPm07fh?@1l/c`0O:dj07NX@01dXT00MJ0n07BU?P1_
[S/0M[8c07Jd;P1e/bd0N:l[07:Y=01/ZDD0H9a?0080G9EJ00<0DimU04Z^K@18^Fl00P13`VP08P16
^VL0B:][04JVJ@15YE`0AZa?04b^D`1<VUL0CGYH05A`E01DJU`0E7IW05U^K`1LJf80IVIJ05akCP1;
STT0A99D04>MC017YDP0@Z`i04FV>P17YS@0AJPX04RO;P13VcL0@9`o03bL@`0fUc/0=Hli03RI:`0j
Vb80>I/M03bI7P0lV1h203RE800K03F=7P0aQQD0=gd9049`0`1=GP40Cd`004]10016?@00@cP0040e
000k<000>Rl003`^000g;@00<RD002dP000[7P00:1X002@H000P5`007Q0001P?000D3P003`P000P4
00040P000P0002400000303oool000X0oooo01@0HWMO069kF`1IOU80FXE;05R;C`1IReL0DhML0526
H01?PfD0Ch9W0568H01<U5<0?Z1902jUB`0QZeX07ZiQ01naG00T/dT0;Zlf03J]8P80>j/L02L0?Z/H
03j[5017[180C:hG04fa701>/B80DjlW05JY:01KYRL0HJDQ06^S601]YA80KjD@06fQ5@1bWQL0M9hM
06fI8P1XUb40H9TT05jM8@1LWAl0HYLO06VG801]VQ`0LY/I07>F601bTa`0Ki4N06VF5@1SWAH0H:8I
05jV6`1GYR00DJTU04n[<P1>[3/0Bj/i04bY>P1CZ3T00P1CYSP09`1DYcP0E:Hj05BR>01DWS<0DJ4a
04fP<`1;Xc/0BJI004JW@@14ZCl0@j`l04B/?@14[T80AJ]604>VD@14WUh0A9=V046>J@13RVT0@I1Y
04>BKP13T6/0Ai1_04N@KP14R6T0B81V04YlI`1BNVP0F7EV069_K01HMf`0CXE/04R?K019UfD0C9AN
04j:F@1>SED0CI=B04bCDP0204ZHC@0W04ZKB`18Wd/0BZA404Z[?`17[d00B[0o04Va>P1<[c/0Ck0h
04n`;P1?[Rl0CZ`i05:[=P1@[Rd0D;0Z05Rb:P1N/bL0FJlT05V^:`1K[bP0FjdM05R^701C[1d0EjPI
05VY7P1DZ2P0BJT^04BY>015YSl0AZTl04F/@P19[cT0CkDa04jf9@1C]R00F[DH05fg601J]Qd0Gk0N
0080IZdQ02L0JJdS06Z_9P1//BH0J[@X06Ze9@1T]R@0HkHX066e;P1R]RX0HL0Y06Fm9@1W_A`0JKHD
06Rf5P1X]Q/0I;HM06F_8@1R/2<0H[@[05nd:@1T]2L0HK8P062`9P1T/1d0HK4M05j`8`1C[Rd0EZhZ
05ZY9@1SZ1`0IjPI06fZ601VZQ/0IZPH06VX4`1^Za00IZlQ05bb;P1J]1h00P1M/a<09`1U/Q<0H[DM
05nc701D]Q`0D[LN05>c7P1G/b40F[<`05Ne?01J]C@0HKDa06Jg9P1W]2D0L;0E08BS1`27V@00SI80
08nB002?V@00Sj8008fW0020]@H0K[LW04jeB@1;ZE@0C8eP04Z9IP1=T680CYER04jFI@19UFP0CI5Y
04j>IP1MQfH0IgQ[069fK`1KMVl0D7MZ04ajJ00204^@H00W04faE01I`4@0I<0T06K05`1W`1L0H/0F
06Fc5`1P[Bh0FJa505b[C@1L[U40Dk1I05>cB`1C]400GYm806QnG`1lN5X0Z6]<08EiGP1fKWT0PWE^
095_J@1fJVT0NVAb09iZM@2[J6d0Z5aJ0:]UD02cKdl0RI<m07VS8`27UPl0R8L008F60026QP00RhH0
09:<002CVPd0VYHT0080UZH[02L0TZ/Z092]:`2;[C40R:`l08bd=`2<^340RKdW08Nh9P23^BL0Ok`/
07bl=@29/TL0VYa<08RJC`22XT@0PkT^07jg901lXcP0OhY<07JIA`1i^DH0M/5907S0?P1h^cl0N;Q0
07Z]@`1gY4@0MIi207BK?`1eX3h0LJHo06nd?P1`]cP0LK8h07:b=01c[2l0IjHf06FWB@1RWe000P1M
U5D09`1>YUX0B;QX04JlJP12_F@0@kaP04ZgI018Zfh0AZ1b04>HI016Ze40AkAB04ZJF01>KF40FFIP
06=WHP1WJVX0JfEh05=cK@1DKEh0CW9:04J4B014W5@0@JED042QC`0m[d40A:do04NY=`13Z2l0@j<f
03nO?P0mVD/0>YAD03BHA00_V3`0:J0b02nQ9`0aWbD0>:4R03ZP900203bM;00K03FB8P0`QaP0=80=
041c1@1<G`40D58004];0018@`00A3d003/f000i<@00>S<003Xd000f<@00=BX0034U000_8000:Ad0
02@H000P5`006a<001P?000C2`003PL000P400050P000P0002400000303oool000X0oooo01@0G8=K
05^0F@1IP4l0Fh9205b9@01MT480Ei1005>?A01BSDT0Dh]>05>BC`1>VD@0?Z<n02fU?P0RYdP08J];
02J/AP0/[CP0=j/X03fZ7@80@j`I02L0AjTG04fX5@1FZA80GZXB05b[5P1J[AD0FJ/G05ZZ6P1OZ1l0
J:@L06nS5P1aXa<0L:HF06jQ5@1`X1D0Ki`G06^M601ZVa`0JYXO06VK801/VR80KiHN06nE701aUAP0
KiLE072H5P1dVQP0KYPF06RK501RVaP0Gj4H05^U7P1DY2@0CZP/04fX=01:Z3/0BZHi04jV>01AYcP0
0P1DY3P01@1GYSD0EJ@c05BQ;P1BX380E:0e0080D9m00200C:9304VT?P17YcX0B:Pj04R[>P16[T40
AJe804BTE@13Uf80AHeZ04N6K018Of`0AHA]04B6L013R6l0@hUa04J8KP15PVP0BGeS05AfHP1OLV40
GgER05eeIP1DP680CXaS04RGH`1:Ueh0C95J04n2FP1?QeT0CH]K04Z@G080Bi9A02L0BYQ=04ZMCP1:
YD00BZXi04f]>`1>[c/0CZle052_=01A/3D0Dk0`05:^;P1A[3@0EJ`d05N_:01H[b<0Fk0U05j_8`1L
[B80F:`U05^]:@1M[1h0G:`I05R[601PZ1H0IZ<G05nR701FY240CjDW05>V;@1BZ300DJXf05F^<01J
/bP0GKDV05fc8@1Q]240IK4N06Fa7`1U/2400P1T[R<09`1X[bD0Jk0Y06Ra:P1//R/0J[DV06Re901Y
]B@0JkDW06Rf9`1X]b@0JkdU06fg8`1_/ah0K[8K076e6@1Z]1H0Ik<I06Nc801W]2D0JK@R06Zb7P1[
/Q`0Jk8J06Z_6`1U[Ah0IJdU05j[:@1NZR80HJDO06JV601/YaL0L:<H06jT7P1[Ya`0KjLG06fZ6`1V
[B<0IZlV06^]6`0206^_500W06b]4P1V/1H0HK8F05Zb601I/aL0G;8G05Za701I]2T0Ek@d05bc;`1N
/Rh0JK8Q06^`6`1eZa@0P:<608NF0@2@TP00Thl0092C002<W@80RZX908>e301_]BP0D<19052]D@1:
VE`0BIIQ04^MG01?We`0C9iO04ZHI01<TfH0DHiS05B8HP1KPVD0EhUU05BEH@1DWDh0EZ100080GZ/e
02L0I;@`06Zj9`1b_a/0KkDD06ne5@1_]aD0K[4K06V/;@1T[cX0H:dl06:]?@1L[d40F[1605RbA01M
XDT0HX=K07MnFP2TLED0OHER06agM@1dMFd0Ng1W06i_IP1gIFP0V61U0:MQH02TGE@0ZFYA0:adE02;
TS`0NYhP08RF3`2<Q`00Rh<008Yn002DOP00UhT<09FI502HVR800P2CX2X09`2@YBT0SZP^09>T<@2B
XcP0SZLd08V[=@26[bd0QKHT08:i8P23^b80PL0_08>c@P2:WTh0Pj1=082SAP22/c80PKPR07f/<@20
WT00Nj1607ZdB@1`_DX0Mka007Ne@01n[TH0P:dj07bY>@1mWcD0PZ0e08FR<@21YC40OZT`07bW;@1i
Z2P0NZdV07V/9`1jZc@0LJ`m06^YAP02066ZBP0W05FfB01A`4`0Cl1C04G1D`14`Td0B/1?04BnF@15
/el0BJYL04b/C@1;[4`0CZ5>04^@FP1?PeX0D7UK05=`G01LJfD0CWUO04b4E`1=RDX0Bi9504^MB013
X5D0?jED03Z/AP0m[TH0@:a4046^@013Yd00@J=103fQ@`0iXTT0>:Dm03BV=@0cYS<0<jD`03FT;@0h
Xbl0>J4_0080?i/V01/0?8`K03mn3`11LPP0BF<2051E001>C000CdH004Q30016?@00@3H003dc000h
;@00=R/003@Z000c9`00;2<002XN000V6P0091T002<G000N4`006@l0018<000>1P0020@000D30002
00008@00000<0?ooo`002P3oool0501GR680FXIQ05^2E@1MPdL0GHI005n??`1LU3X0EYHl04jG?`1>
Ud40DIU204jP?P0mYcP0:ZTi02:Y?P0SZCX0:jXf03BY:P0kZB<0@J/J0P16[1X09`1=[AL0Ej/C05bZ
4`1SZQD0HZTD05^Z3P1IZA40F:`E05fZ6P1TYaP0JZHD06bW5@1]YAP0KJDF06VR6`1WXAH0KZ0F06VS
7`1]X1`0LIdO07>N:@1cVR80MILK06jF5`1VVa@0II`I06NP601VX1<0HihD05jL7P1JXB00DjPZ04fX
<01;YSD0B:<g04>P?013Y3P0AZLg04ZV>@0204fR=@0W056Q<01?Wc00C:0]04^P=01=WD00DIa8052K
B01=WTL0Bj=004ZW>P19ZCL0B:/h04N[@016ZdP0AImJ04:>I`13Q700BGed04mdL`18Mg@0@gYf03mo
MP0nOgH0@H5c04AmJP1>Mf<0GG9P06Y^HP1MLf00EWIN04j9G01:Tf00BI]P04VJE`19SeL0Bg]N04ao
HP18PfH0BH]T0080BI5G02L0BYUA04ZND@19XT<0CZ/i052`=`1C/CX0D;0d05:^<P1C[SH0E:lb05J_
<01E[c@0FK0f05bb9@1M/1h0FK0R05b_9@1J[R<0EjdU05ZZ;01LZB@0GZ/K05n[5P1XYa@0KihI06VK
6`1HVQh0FYlQ05jU8@1JYbH0F:P]05b_:`1P/RH0HKDZ06Jc:01U[bP0IK0X06Fa:@1R[bh00P1S/300
9`1T/Bd0IK4_06F`;`1Y[c40Jk@/06Ze9@1Z]R40K[LP06bf8P1/]2@0JkDV06fc:P1_]BT0LkDU06nf
6@1[/aD0J;8I06Nb8@1X]BP0I[@Q06Zc701//aT0Jk0H06N_7@1K[B/0FZh[05b]<01QZBH0GJ<T062Z
6P1U[1P0JJTL06R/901Y[RH0H[4S066`:01S/Bd0IZl[06ba800206fa600W06f`4P1S/Q40G;<D05^e
601M]1H0Fk@C05bc5`1E]B@0F;Ta05Zh;@1H/S40Hk4O06Na5`1`[A40Nj@608BJ0P2@TP40SI0008^D
0025X0@0PZ`<07Ng4`1[^Bh0D<1=04ZaDP15X600A9]V04NJGP1;VEh0BIQN04^GHP1@T6D0CXeX04^>
I@19SFL0Aj1P04bbD`1E]SH0Hl0Q0080JL0K02L0K/0H07705`1c`1P0JkHH06jh501_]QT0K;4P06B]
;`1J[CD0FZlb05N`=01H/T00Ek1:052_E01CZ5T0EX]R06j7G@2MO5l0NhiS06>2L@1/NFd0KW1[061f
I`1/JFL0Sf1I09UQD`2LHe40XWAD0:MlE02:VT00Nj8P08NJ3P2?S000SXP008^1002?O@40UY0E08jP
7P29XBD00P2:X2h09`27Ybl0S:@i09:S=P2@X3P0S:0b08RT<`22ZRh0PKDV08707`21`R40O/0^07^j
?@1kYTT0Mja?07^/B01k/3T0O/0S07fi:P1n]Ch0O:a307>gC01/_4h0LL1707JiBP1lYdT0N[Hm07Zf
=@1mWcH0Q9Pc08NJ;@26WC40Oi`[07jK:01lWBX0MJDV07RS:`21WcT0NZM006fTA`02066]AP0W05Vk
@@1B^Sl0BKe904?7E00nadH0?LM103[:BP0ka4h0A;YE04faD@1<YU00BJM904FTE@10VF00?XQJ041l
E@16LET0?gMF0421F014REP0BIIE04BOD@0mTe`0=IeT03>RG`0_ZeX0=;1N03BcF`0e[E@0>:M;03RW
A`0f[4/0=:Y002nZ@P0_Yd/0<ZY>03:ZD@0eZ500=jE60080?9`Y00D0@8PJ04=f3017H`@0BUD004e=
000204e9000D04i5001;@P00@S`003df000j;P00=RP003<W000`9`00;28002LM000R6`008a`002@J
000P50006A8001H=000?20002PH000H40002000Q000000`0oooo000:0?ooo`0D05^?D@1JSTl0G8i5
05n=>`1NTCT0HiHk062J>P1JVST0FYXh05VH>01IVcL0E9ld04>V;P0`Ybh09ZTe02^Z<`0`ZRl0>:XX
03^Y8@0mZaX204J/6@0W04j^5@1H[A80Gj/D06FX501QZA40FjX@05ZZ3P1HZQ80G:LG062T5`1TXa@0
Jj<H06^V5P1/Ya@0JJHF06RU5@1YY1H0Ij8I06bO601`W1/0LiPR07BH7`1dUaL0LITB06VJ5P1TWAL0
IIlG06FQ4`1SX140G:4J05BU901@Z300B:Xe04RW>018XSH0@j0f04:T=`12YS@0AjDe0080Bj4`02L0
CZ4]04fS:`1<Y2d0C:@d04jR@P1>XDd0Cie:04bRA@18YC`0BJXe04V/=018ZcT0B:a004NZC012W5`0
@XYY04:1L@17NW<0Cf]g04YcMP0oMWX0?7]j03alN@0oOW@0@Ga[04mgH@1PKeh0JViR05YgH01BNUd0
BY1I04RIE`16WUP0AYMD04V=E`18O5h0BX1R04>8JP14Sf@00P1:TUL09`19VU80BJ9?04^W?`1=[340
Djla05Ja=01C/c<0E;4a052^=P1G[S80E[0[05Ja;`1H/C00G;8S05n`701J/240Fk0V05^_8@1J[B@0
FJPX05jW8`1RZ1X0IJTD06bR4P1aVQ@0KI/B06JM6P1WX1/0JJ<O06JW9@1UYbh0HZ`V06F`901V/BP0
IZl^06F^<01S[B`0Ik4`06Nb<@0206>b;`0W06Jb;@1X/Bh0JK4`06Nb;P1Y]R/0JKLY06S08`1/^B40
KKDT06fc8`1]/bH0Kk</076e;01_]b@0KkLH06fe5`1/]1d0K[8T06bb901[/b00K[@J076b601/[AL0
JJdN06>Z:P1T[bT0K:PY06^[8`1UYQh0IZXI06bZ601ZYaX0K:HQ06^Z7P1Y[Ah0JZ`U06j_9P1_/2<0
M;8I0080LK0C02L0KK4=06Rc3@1Y/Ph0Jk<@06fd3`1V/`h0IK@B05nb601L^240G[LS05jd:01X/aX0
JK0D07J^3P23Y@@0RI/1096E002AR`00SI4008VL0`21[PX0MkPC06fh:01F`400D[I804^_D@17Z5@0
BZAC04bPE@1<WeP0BYmH04nRE`1@YU80CZM<04^TAP1B[d00G[Th06c09@1_`1/00P1_`1P09`1b`1X0
ML0H07C0601_`1L0L<0H06jd6`1/[R80KJ`/06R[<01N[300G:db05j_?@1O/dP0F;5A05J]F01IW5`0
JYIG08B5G@1bS5h0GXUV06>5HP1VOfP0IGY[079WK@2<FfX0VV5R0:=SF`2OKe/0VgQO08>F>`1kXQP0
RID:08j9002>Q`00TX8009R60`2KUaT0Tih]09:S;P0208fM<P0W08fM=P2@XSX0Tilj08jM>`2=WSL0
Qj<f08>g;`20^RP0P<0P08?07P22`240Pl0_07nj?P1m^d00O[Q207fj>020`2L0NkdU07fh>`1o[DH0
MkI607;0AP1h`4<0NkXo082b?P23]SP0OJ`g086T=`25XS00QjHY08N/9021Zal0PJ`J07nZ7@1i[R00
N:dU07f]<01dZc00KjLc0080J;4e02L0H[Pg066k=`1I`3X0ClE104_4>P1:`cH0AlHm04[5?01;`cT0
CK/o056a?`1?[3`0CjI504bOB018V4@0B9A704^BC01:UDL0CIM8056OB01<YTL0BJ]904>XC`10[5@0
>jiD03VaC`0j/E00?:e<03^XC00mYDX0A:M303jX@P0kYdD0>jE903JNC@0gW500=Ia=03RL@`0kV340
0P10RAd06`18MP/0Cf45055E0@1ACP00D4/0051<001?BP00CdT004U30013?000@3H003`b000h:`00
<bL002lT000X80009aT0028H000S600081L001`F000G3P004P/000`70009100010800040000Q0000
00`0oooo000:0?ooo`0D05fB=@1JU3P0FY@e05ZF<`1MUS<0HYTn06:L?01NVCH0HYTc06JG;`1TUbh0
G9`Y04^T9P0jYRL0<ZH/032X;P0fZB`0>jHW03bY8@0oZad2046]600W04R^4`1@ZQ<0FJHF05jT5@1N
Y1<0HJLC05nX4P1NZA80GjDF05nS5P1WXQL0L:0H06nR601cXaD0M:HF07:S6@1`XQL0JY`H076I5P1g
U1X0Mi8G07V@5P1eUA40MiXB07VE6@1aUa`0JYLL072H501]WPl0I:4F05^U:01BYbh0CJPc04bX<P1;
Z2/0B:H`04RT<@1<XC40CYla0080CZ0_02L0CZ4_056R;`1=YBl0BZDg04fU@01?YDH0Cj9504JT@@16
YST0AjT`04ZX<@19ZCT0BJY504BVE013VFD0A8a/04F4L018O700C6i_04EcLP12MgT0?gYe049jLP18
OVd0AgiY051kH@1HLel0F75Q059iH01:PEl0AI9F04NIDP19V5<0B99C04R9F019P5l0B8YN04JCG017
UUD00P19VD`09`1=XTL0D:Q704n[>@1@/2T0Dk0V05Nb;@1H/Rd0EJhZ05:^<@1F[Rh0Ek0T05Va9P1N
/2X0G[0Q05n^7@1O[200GZdX06BZ8`1QZ200HJ@Y06:S901UYQ/0KZ4F07>M501dU1L0LiPH06fM6@1a
Wb00LilT06jT:P1ZYB`0K:TX06^[9`1[ZbX0JJ8`06NU=01WZ3<0JZ/f06^a<P0206^b;P0W06ja;01]
[Rh0KJhb06^b<01Y]bd0JKD^06Ze:`1Y]b/0J;HW06Rb9@1^/RP0KK4b06j^;01`/b<0K[<Q06ja7`1_
/1l0Jk4U06^a8P1//R40KK8M06V]701Z[Ql0JK0T06R/;P1Y[Bd0JZ/[06^Y9`1UYb@0H:lS06F^9@1U
ZBT0IZ@X06^U801WYRL0IJ`Z06R]8`1[[QH0L:`?0080L:`=02L0M:h906n`2P1d/@X0MZd707Nb201^
]0d0JKD@06Jf3`1S]a40IKDG06>b8P1[[QH0L:d@07ZY2@21ZP80RZ4008nD002@S@00Si4008VK0P23
[`T0NK@D06nc9`1I^3@0E;Xl052hAP1=]4X0C[1<04Z]D018[U<0Bk1C04bhB@1@`3/0DKd]05Nh8`1S
]B40KkPT07>i7P1b`1`00P1a`1h20730800N07?07P1Z`1P0K[DH06fd701Z[2D0MZP/06jZ<01N[3<0
G:/i062^@01M/Tl0E[1D05>]G01FYEX0HYiG07:7GP1VQV40GhYP05j<H@1PRFP0JX1a07e]MP2=G780
W5i[0:eWI@2RJFL0Sg5T082B=`22X1<0RY@70P2>R@001@2EQ`40VID809fM802AVCX0Tj0i0080TiHl
02L0TJ<f09FZ>P2AYC`0S:9208NP@025Yc`0PL0b07o0:P1o`2H0P/0M08S07@25`2<0Q<0_08;0>020
`3T0O<0i07_0:@1l`B80O[df086e@@1j^d<0NL1007_0?P1l`3d0N[Tm07b^@020ZC/0PjLh08:T<@25
YBX0Q:HS08FX7`22Z1h0OJLQ07ZV9P1eZBT0LJl]06j_<@1a/2l00P1/]S009`1/^C@0Hl4h05W4<P1@
`c<0B/8a04_1=@1;a3/0Cl@d04c4;`1;`S@0Bk`c04jd<@1?[3X0DJ8m052K?P1?W4L0CjI805:]@01?
/TL0B[E?04>eE@12/Eh0?JmO03Z^JP0h/F`0>;AS03N_F`0fYED0>J5K03bWE`0nZ4/0?ZM603^UD00k
XET0=iIK03>@FP0cT5@0=i@j03Z=8`02045h3@0J04eR0@1CE000DdX00599001CCP00Ddl004m;001<
C`00AdD004E20012?000?cP003Lb000c;000;BD002XO000U6@008QL001lH000P600071@001H@000B
2`0030T000T400030003000000800@007@00000<0?ooo`002P3oool0501QVB/0F9/]05>L;P1FVc40
FYXi05bM@@1OWSh0GY/f06BH;`1/T300K98W062H901CXB80@:DT03JV9P0bZ2T0>:XY03VZ9`0k[2@0
>ZhO0P0o[AP09`0n[AD0A:`F04JY601>Z1L0DZLF05JX701HZ1X0F:PE05RU5P1IYAP0HZ@H06ZP701^
XAT0LJ8C07>T5P1^Xa<0Ij4A066O501^WQH0MiTI07VD601cTa@0LiHB07ZI5@1oUAT0Mi<O076F801]
UQ@0J9/;06FS601IYbD0DZP]04bY<P1;ZRl0AZ`Z04BZ;`17Y340CYha052L<@0204nL=00W04ZQ<P19
XS80AZ<f04FU>P17Yd80BjE004jR@013YD00@JPj04:[=@15ZSX0A:M6042VC`0oX5l0?iI[042?L013
Rfd0AGi^04I`L016LG80@7Mf045lL@14OV`0Bh=W04mnIP1?OV00CgUR04aeH`18N6D0@h=S04:DF@15
VE<0AiAE04N:F@19QE`0BHEO04VCE`14WE80Aim=0080BZ5502L0CZU004n/?`1C[C80E;0R05Fc8`1G
]2X0E[8X05Bb:P1B/2l0Ek0]05V_8@1H/200FJhT05Z/8P1K[200FZ/W062Y;@1/YR80IZ4R06>M:P1S
X2P0Ij4M076M6@1gUAT0MY<L07JI7@1aW1/0M9lS07VN:P1^Xbd0KZH[06fY:P1/ZbT0JZX[06^R<01/
Y380K:Xb06f]<01^/b`00P1`]2L09`1_/bT0K[0/06bb;P1Z]340K;H^06ff;P1/]BT0JKDW06Zc:@1/
/R`0KK8[06f`;`1^/RX0KK<V06Vb8P1X/b40K;@L06^d8P1Z]B@0K;8Q06Va7P1V/1`0J[4N06Z`8P1/
[bT0JK4]06Va;P1]Zbd0J:P/06B_;@1M[cP0GJ/f06BU:P1TYal0I:LY06J^:@1Y/QX0L:h@072]2P02
07F/2@0W07R]201e[PL0Mk4607bc1@1j/`L0Kl0=06_03P1Z`0/0JkH=06Rg501W]Ad0KK<C072b401l
/PT0QK<308^X0@2>V000SXh008ZB0027VP40QjL807nc3P1k]Ah0IL0W0670;`1K`3H0D[/n05>h@01D
^3h0D;M6056jB01C`3h0FL4^05[38@1O`Ad0JL0M07707@1``1l0L/0O0080KL0P02L0K/0O06S07`1`
`1/0LKXG07Fe5`1f/b00M:XU07>V:01`[B`0HZhd062a>01R/c`0H;E605RfC`1F/ED0FJED05nLDP1/
QUd0IXQL05j?GP1PV5`0GIAT06V5KP1oKWL0TUib0:1QK02]JV<0X6aT08=bGP1oTbl0QYh<08jE102D
S000ThX009f?302EUQT0ViXZ09ZG?@2BX3T00P2=W3L09`2AZc<0T;Dh08f^?@2;ZSl0Q:8m08>V=021
]Rh0Q;/W08Bk8P28_1T0RK`E08O05`25`2@0PL0Y0830;P1o`2h0P/0Y08;0701m`2P0MkLj07S0?01n
`3@0Pl4h0870=021^S<0PK0i08>^=023[B`0Q:dS08VZ8028/Ad0RJ`L08B_7@21ZR<0Oj<Z07ZX:@1i
ZBL0NK0V07Ze9002076g8@0W06jl801T`280G<8Q05K39P1C`2P0EK/b04k1?P1?`cT0Cl4b04o0:P1=
_RD0Dk<T05V/9P1NYRX0HJ<]05jU<P1K[3H0E[8g04nc@01;]dh0B;5G04VVG@15XUh0@j1V03nQJP11
YF80?ZAJ03jND@0mXE00?ZA8042R@P10X400@Ym204JMA@10V4H0?I=203f><`14Qb<0BW`A0080E6T6
0180EeP005A:001?@P00Cd<004m7001AA`00D4H004Q80016@000A3/0044j000o=000>bl003@X000/
7`00:Q/002@K000P5`0201lH000601XC000F3P004@T000X500070P000@008P00000<0?ooo`002P3o
ool0501TUbd0I9`X05fO9`1MWR/0Hid^06NQ<P1XX2h0JiX/06nG:01aTb/0KiDW06:M8P1BXb80B:PR
03Z[900g[BT0>:hZ03R_:@0j/2T0?k4T0P10[ah03010/1X0?k4J04B^6`1<ZaP0D:XE05NY6@1LYaT0
GjLG05nV6@1RYQP0IJHE06bU5@80KJDB01T0LJ<E06nR4P1_WPl0KYl@07BO4P1hW1H0O9PG07JD4P1d
V1D0NI/F07jJ5P1gV1T0M9TH06fG4@1TW@l0HJHF05RY9@1DZ2P0DZXZ04fZ;018[BX0BJP^04fT;`1B
X300Cj8_0080C:<b02L0Aj8d04NT<`16YS40AZLc04NX>017YS`0AjLn042W?00nZc`0?:`o03^YAP0m
Ydh0?:AI03^OH`0nU6d0@91_04:9K012P6l0@g5_04IfL@16NG<0AWe`04YnI@1@PF80FG]P05IlH01?
Of00AgiQ04B4HP0oSe`0@ia@04>NBP18Ue00AheI04R=G017Se`0AiQA04FOBP17XT@00P1;YS`09`1=
ZcP0DZhc05B`9`1F/A`0FK@K05Nd901D/RH0Dk4T05:c9@1E/RH0FK4N05Z_7`1K[B40FJ`T05f/8`1P
[BD0I:/X06bY901/XBL0JIh^06JM:01^WAd0M9HM07RB6`1jTb80N9XP07RL8`1fW2/0NYd^06bT;P1Z
[RX0L:lZ076`:`1b[Rh0LJ`_06j/;`1a/Bh0LkD[07Fd9@0207>f900W07Bd9`1`/2h0LJ``072/<01`
[R`0LZdX07Fa9`1d/BH0M;4W07B_;01`[b/0K[4Z06je:P1_]2P0JkHO06bd701_]AT0L;DL06fe901^
/R<0K;4P06b^701[[QL0KjhB07:^5P1`/RD0Jk4/06f^9P1Z[Bl0IZ`l05^]@P1OZ300JJLQ06^Z6`1/
[QP0L:hB07B_3P1i[PT0Njd60080OJX500H0O:`407b]0P1n[`@0Nk<607Ng2@1/`0l206O04@0O06K0
4@1V]aH0HkDS06be5@1^]1<0Mk8=08:c1`28[0@0Si`108jD002=T`00RiD008ZN0029[0T0O[@I076h
801[`2L0H[d^06:k;P1N]Rh0GKP[05nh<01Q`380I/0^06O0:P1W`2L0IL0W06W09@1]`280K/0Q07?0
8P0206c08`0W06g08P1^`1`0L;/E07>c5`1h[Q`0O:HS07fU:01eZ2P0KZXY06V/;P1T[cD0H;0b05Zb
>`1D/d/0EK1A05RQD@1OTT`0J7UO06B4G01LU680G9eJ066KGP1ZQ6L0NV]b09ENLP2VI6/0ZVmK09a_
F`23LED0P90Z08JL1`2?U040UHh009R?0`2SUa40V8hX09VA=P2KTd80Sj8i0080Sj0g02L0S;@e08be
=P28[3T0QjY108RX=P26ZBd0Pk8Z08Nh902;]b00SKDH08jh4P2<^Q<0RL0J08O07P22`2D0O/0W07o1
9P1o`1h0Nl0R0770=@1g`3P0Pl0a08K1;`26`2d0P[P[07ne<`20]2`0P[<S086a8021/Qh0Q[DL08Je
7P22[b40Oj`Y07jW:`1kZ2`0OJ/Z07^_9`1i/b800P1e^1`09`1_^AT0I;XG05[06`1F`b80E<0Z05Ri
=P1A`480CL4l04_1>01:`bP0AkhN04fd7`1D[1h0FZ`Q05N/:@1E[C80DK0o04VbD011/5h0?[5_03jX
M010SGD0@8Mb03j7MP0mQWP0?hmZ03jDGP10VU80?Z1A03jO@@10Vd40@IM904BIA@17V440@IDl04:F
=`11Rb<0CGl?05M`100205iN000J05Y@001>@`00BS/004Y2001;@`00BD8004]40018@000AC`004<k
000o=000?2l003T[000g9`00;R0002PL000V6`008AX002<J000O6000714001D=000?1P0020@000D1
00010004000000800@007000000<0?ooo`002P3oool0501TUS80Ii/W06BI8`1PV2H0GiXZ062L:`1Q
VB/0I9@[06b@;@1`TB`0K9LZ05bK:01@XBT0A:@Z03ZX:P0eZb`0=Z/_03ZZ<@10Ybl0@ZP^0P14[Bh0
4013[BP0@JdQ04>^7P1?[1/0G:XL06>X6P1WYaT0IjPI06RX7@1TYa/0HJDF06BV3`1WY`/0IjH=06ZT
501/XaD2076O400E07BN3`1hWaH0MYXG07FG501dVQL0LilH076Q5`1aX1P0LY`@06ZH401RWQ@0HJ@G
05RW8@1HYRH0EZLX04jY:P19Z2d0CJ<`04fR<P1?XS80C:@c0080C:De02L0B:0h04ZR<`1;YR/0AZT]
04FX=012YST0@:Dn03fV@00lYT40>:M703RTD@0gXEL0>Z1N03fJH@0nT6T0@8U]0421K@14NVd0Ag1/
04IeL017Mg00B7Q^04igI`1HM680J71R05ihH01@OV40AHEO04:AF`12We00AZE504FQ@P15UDh0B8mG
04J@F`17TEX0BI1?04VKA01<XT000P1=YcL09`1@[Bd0DZhV05Ba801J[aX0G:lK05R_801G[bH0E[0O
05Fa7`1I/2<0GZlO06:]7P1QZah0H:XT05n/901S[B<0IZ/W06bW9@1`XbT0Kil/06nK:P1jUR00N8lP
07b>8`21TBH0OiLY08:F;01oUC80NiXb06fW;@1Z[RP0M:hZ07F_:`1d[S00M:ha07>]<01c[b/0LjlT
07R_8`0207V_900W07>a:`1a[Bl0LZ@_07:S;P1dXBd0MZDY07V/:P1i[RX0Mjh]07J]<@1b/2l0Kk4_
072c;`1_/bd0Kk<O076c701]/R00JK0R06N`:P1U/Rh0K:lV07>[7`1bZaT0L:`?072a5@1Y/RL0HJhb
05f_<P1IZdP0EZQE04nYD01NZ340HZXV06F^6`1Y/100L;4<076d2P1b/@T0NZh60080OZd202L0OZh2
07jb0020/`<0Nk@707Bg3@1Y_1<0Hk`F06C05`1N`1T0H;DM05jd:01U/QT0I[@D07Jc3`1k/`X0Q:/7
092Q0P2?VP00SYH008ZH0027V`00QJD907jb4@1``1P0KKhQ06Bo901[]RH0IKDY06^d:01]/R`0KKH`
06bi<`1X`2l0JL0/06[0;01W`2P0Jl0P06O0701[`1l00P1U`2009`1/`1l0KL0J07305@1b/aL0MJ`J
07N^8P1h[R@0M:`V06jZ9`1T/BP0I;@]05be;@1=]SP0CKY<056cD`1DWe40EI9?05^0H@1IQf00FYAR
05^QE@1PWE/0KH5S08AYJ@2JHf/0YVMW0:E`G02JL580OgE>07j<9`24T`H0SXl009JB1@2KV180Z9TN
0:^@902KTC/0UYQ408Z[?`0208bZ>@0W08^b=`29^3P0Q;8n08F[@020Z3H0QZd]08Rf9@2=]b40S;LP
08jf7@2;]aT0S;XB08Zm4025`1@0Ql0O08G09021`2H0OL8O07W08P1g`2d0O/0]0833:@20aBX0P<0W
07nl8021^1`0Q;HH08Bh5`22]aD0Q;TE086g6`22/al0PZPN086[7020Zah0PJ/P07n[801k/200NK@O
0080N;<I02L0MK<D06bd4`1W_1X0GlDO05g1:`1J`3H0FkPo05Ng@P1C`c/0Cl8Y05:l6P1F]1H0FJdJ
05ZW7`1IZb/0E:/g04bYA@14[540@:]P042XJ@17ZUT0C9]9052>?P1@Qcd0CXU004R;?P12TD40@iI9
04:LC014V4<0@i0f04J<<@18QRD0C8LN04j47@1AOQP0EGD@05UY1P1LG0400P1KC`006@1E@`00BSd0
04Tj0016>P00ASd004Tl001;@@00BSX004De0013=P00?SH003`a000i;P00=2L002lP000Y70009AL0
024H000N5P00718001D>000?2`002`@000D3000100008`00000<0?ooo`002P3oool0501VWRP0JJ0U
06VR901SXR@0Hj4V06:Q9`1RWBX0IYP]06ZF;P1]U300HiT]05FM:`1=X3D0@ZHa03VZ<P0c[340=:db
03^Z<@0lYc00?ZTe0P12ZcH09`10[S00?ZhY03j]8P1;[ad0FjdO062[7@1UZQT0IjXH06VY7`1XZ1/0
Gj/D05bZ301KZPT0GZT@06FW4`1VYQ@0L:8@06bQ3`1^XA@0L9dJ06bN601]WaL0KY`G06VQ601VY1X0
I:8E06FQ4@1XWa<0IZ<C05nW5P1G[1d0FJXP05NV9@1BYRX0C:Ha04RV<`15YC@0@:Le046X>P02046T
@00W04:S@012YCH0?ZH]03^X;`0fYcH0=ZM203JXAP0eYd/0=:M?03:RE@0bVE/0<iUP03JII@0iUfL0
>haY03f3J`0oNV/0@GA^04E/KP18Kfd0Ag=a04QbKP1CJfH0IFQW07MVI`1SLFD0D81R04B@G`13WEP0
AZM904NY?@16YDD0@YIC04>?FP15SU`0BI1J04f9C`1>VD80DJDk0080CjXe02L0DJdV05:_7@1D/1X0
FJlH05Z_6P1G[B80DjlY05B_7`1D[ah0FK4S05n_901S[1l0I:hP062[:01Q[BH0J:lS06Z[9P1]Yb`0
L:@/07:Q;01iVRP0PI0L07^98@1lRBX0OXl[07Z@;@1nSRd0NY8f07JL=P1^[2h0K[<V07F^901f/2@0
MZdW07R_:@1g/BT0M;0W07J_901j[R<00P1i[b<09`1g/BD0L;<Z072_9P1b[b<0MZ`R07Z`7`1n]Al0
Ok@O07Vd8`1h/Bh0M;4b07:c<P1`/b/0LK<S07Fc7P1g/Ql0L;8Q06b^901W[RT0I[0]06f^901d[Ql0
L:lO06bc6P1^]1`0JjhX06N[;P1XYBl0IIli06FR>@1WYS00IZTR06R^6`1[/AL0LK4F07Fc501b]1<0
M;<?07^a2P02086b1P0W07nb1P1i]@L0MkL507Vc1`1f]@X0JkL@06Nf4`1Z]a@0IkTD06bd5@1[/1`0
Jk4D06^d401g/@`0OK<<08Ba2P2EX`40TY`008nJ002<VP00RiX008BP0`1o/0X0MkT@076n7`1[`2H0
KkDZ06jb<01i/2l0Ojha07V`<@1b/c<0L[La072i<@1]`2X0K<0R06k07@1Y`1P0L/0J0080K[`L02L0
Ll0N07Bh6P1f]1H0N[0G07FZ6@1d[Qh0M;4S07JZ901^ZBH0Gk8U05Re:01G^340Bl0o04ngBP1D/dh0
E9Y:05NBB`1GS5T0E8YK05Z=F`1NVdl0I9UE07UhF`2BGEX0XfEM0:Y]G`2TJeP0Ug1?07UhB022S1l0
RI86092<0@2EU@h0UidM0:VJ9P2^Sb/0VIPo08jPA`29[d000P2:/CP09`2;]3P0Q[Lk08B_?`25XS`0
Pj<f08BU<@2:]B@0SKLT08^d9`2:[R80SK<L08ne5@2<^180T;PC08W06`24`240P/0T07_08@1h`2<0
Nl0[08;0:01o`2L0N<HZ07K1:P1i`1`0OKTG08Fi5P28^AD0Q[@A08Bh5@20]1/0OjhM07nW6P21ZAP0
Oj/L07fX801iXb00NJPR07F[7@0207:]5`0W06j`401Z/Q40JKhN06?38P1N`Rd0F/0f05nf?@1K[d00
DL0m04o39`1E_AH0E;HG05J^7P1BZ2X0DjXi05>YA`1:WE<0AImT04:PK`12X6`0B:=<04fC:`1DPQX0
EgHA05=l601<Oad0@hTW04>A>`11UDH0@I180465<P14P1l0BG@?04]b1@1<K0<0DF@105EK0@1GD@00
EDX00080CdL001T0Cch004a00018?P00ACL0048b0016>000Ac/004Hl0014>P00@SD003hf000n<P00
>S4003@Y000]9@00:Ah002DI000P5P00718001L=000A20002`L000T400030@000@0000<0000000<0
0@000000000000007@00000<0?ooo`002P3oool0501[WBP0JZ4V06JU9P1WYB40Ij4Q06NR9@1UX2H0
JJ0X06nK:P1/VbL0HIdV056O9`19Xbl0AZH^03fZ;00g[R/0?Zl[04F^9@19[b80B:hT0P15[bP09`15
[RL0?k0U046`8P1;/B40FJdT062[8`1T[1`0IZdI06f[6P1[ZQ<0Hj/?05V]2P1IZ`d0Fj/@06>Y4`1Z
YQ80LZ8@06fO4`1^X1X0KihK06^Q6P1_XaT0LZ4G06jP6@1^WQX0K9lF06^Q501[XaH0JJHC05n[5P1G
[B40E:/T05:W:P1>Ybl0C:Ta046/<P0kZS@0>:Xf03R[?`0203fY@`0W03fW@P0lZSX0>J/e03FY>P0a
Z400;ZM802nZC00]ZU40;jMD032TF@0bWUh0<imO03>PG`0jWV00?9IV03Z:I00oP6@0A7YW04UeHP1<
LfH0D7IU051cI@1FKf<0GV]Y06QXJ`1GNFL0B8aR04BJG@16XU40BJU504^Y?01<YTP0B9IG04F@G`15
Sed0B8aK04b3D@1>UT40DJTj0080DJhe02L0DZlW05Bb7`1H/Ah0G[4L05fa701K/280F[8Z05Jc8P1J
/b00F;@T05Za9P1P/200HK4S05j]:P1U[BL0K:dW06n[;01aY2l0Lj4W07^Q8@22VR40RY8E08F88P1k
Q2h0NXT_07F>:`1jS2T0LI8d06nR<`1[/bd0KKLU07Je7`1g/ad0MZlR07Nc901f]B@0Lk@T07:h7`1g
/al00P1f/B809`1b/bD0JKLT06^e7`1_/al0MK@N07fb701m]QT0O[PM07Vc901g[Rh0Kjhe06fb<01_
/bL0K[<R076c8P1b/B<0Kk0T06V[:P1T[c00IZd^06V_9`1//R40JK8R06Jd;P1P/C<0GZPf05nN?@1P
USL0HI4i06JL<P1QYRX0HjhP06Ba6`1[/al0JkDU06jc8@1_/Q`0MK@E07Zc400207Vc3@0W07Je201`
]`T0LKD907:c1`1`/PL0KkH<06je4P1^]@l0L[<>07Ja4@1e[a80MK0?06jb301o/@X0Ok<>08N`302F
Z0<0UZ<109>P002?X000RY/008JO0P23Z`P0N[D=07?06P1^`2@0KkD[07Fb<021[c<0NjXe07JZ<`1`
[SP0L;0d06ne<`1``2d0K/0R06[0701Z`1T0Ll0H0080M<0J02L0M<0M07Fg6@1c/aL0Lk4I06j_7P1/
]200M;<R076`8@1W/2<0G;DT05:f9`1@`3@0C[M105>fB01B/dT0EIm905ZLB@1KVE00FI1B05N;E`1M
WU<0IYMI085aF02EEeP0Y6AL0:M/G02QKE@0U7I=07f;>`26UAT0TiH509BG2@2QXa@0[YPO0:jF;P2Y
UCd0Tj=708JZB@24/S`00P26^SP09`22]cd0Q:Y108JS?02;WCd0SZ0d08nS;`2@YBP0Sj`Z08fb;P2?
]1h0T[HG09:e4`2A]a<0SKXA08fk4`28`1`0Ql0R08708P1n`2@0P<0Z08Jl9P22`2D0O/D[07_2;@1j
`2H0OL0M08;07@21^ad0PKHG07nc5@20[aL0PjdE08>U5@23ZAD0PZdI07jS7P1lXB80Mj8T07FW6`02
07FX500W07>Y3@1`/100J[`K06G07`1O`bd0G/4]05fm<01I`2d0D<<[05;07@1H]QD0FZ`B05bV6@1I
Y1d0FZ<R05RU;P1BYT40CZYC04f/F`1@YTD0GiTR06R24`1UK`/0H6P605eY2P1GK0d0C7XN04R3;P18
Q3@0BX4_04ag7@1BK@h0Df@605EM0@1FF@40Ee<005I:001CB000D4800080DD0000H0CC/004Xi0017
>`00AC80044`0012<P02040f000A044d000n<P00?2l003`_000k;000<BP0030Q000X6`008aT001lE
000K4P005Ph000l80007100010<000<1000100000P0000001@0100000P40008100020@000@0001`0
0000303oool000X0oooo01@0LI`Y06RP:@1TXbH0IJ8R06>R8P1MXBH0G9lW05nP:01WX2H0I:0O05VP
801;XRD0Aj<Z04JR:`0nY2L0?JHS046X8P19Za/0Cj`F04j`5P80B[0L02L0@k0Q046`9@12[RH0B[0Z
056`:`1A[2X0F:`P05^`6@1T[1@0I:l>05f]301E[Pd0DJh?04n[4`1EZAD0FjLC06FV4@1ZY1@0K:4F
06jR5`1ZXAT0JJDI06RU6P1XXA`0K9`E06nO4P1^XQ@0J:HF06>W5@1I[AX0DJdU04^Z;015Z300@:Pe
03RY?@0c[Cd0;jXm02fY@00fYd800P0hYT@09`0gYDH0=ZE103FX?P0dYT00;ZE402nRBP0_YT`0<jM@
03:VE00bYUL0<j=F03>TE@0dYE@0>J=I03^MG@0lTV40@8IP04MoHP1>O680EWIR05MgG`1IMed0Fg=L
05U`G`1HL6D0ChET04NDH015WUX0BJ=A04bX@P1BYCh0CJ1=04^FFP18SV40AXeK04J6G019O5D0BY57
04jW?P02052/>P0W05F^<@1F/2L0F;0U05^/8P1N[Ql0G[4S05f`;`1I/Bd0F;0[05Jc:01L/BP0GjlU
062`9`1O[B/0Ijd]06N/;01YZ340JZ8c06nR8`1fXQd0P9hJ08NC7022SR80O8T`07j9<P1cSBh0Li4]
06VI<`1WYRl0JZlT076c801d/b00Mk8P07Jb7P1g/R00Lk8R07:c8P1b]240LZlT0080M:hU02L0M;4V
06nd901a/B80M[4R07Jb7`1j/Qh0Ok4O07j`8`1i[RH0MZP]06n/<P1a[C00MJhY07B^9P1_[RH0L;0V
06^b901X/2H0J[0Z06V_:P1[^B@0K;TM06jd901V/3L0GZdi06FT=P1WV3P0IIXf062M>01RY380H:hW
06Fb8@1Z/RH0LjlW06f^:@1^/2<0LZlK07Nb501k]QD00P1m/Pd09`1h/`L0K[<;06nf2P1^]0P0L;87
06nb2@1`/P/0LK<=07Fe2`1h]@`0NK8=07Vc301e/`/0O[49082a2`2:[0P0U:T209JY0P2DY040Sj00
08nM002:W`00R:L308>b1`1h]`h0KklJ06jo8`1b_RD0OK4^07b/>@1hZCP0LZ/g07:]<`1b[c<0MK@_
0730:P1^`2<0Jl0O06o07@0207;07@0W07?06P1e^aL0M[<E07Ff701`]2@0L;LS06ne801[/al0G[@V
05Ze:@1?`300CkPg04jf@P1@]4/0Dk9>05>`A@1K[400HjE805fJDP1HUET0GYYK06B<I022L680VEeT
0:1ZH`2SK640WfUJ08YmB`1lW2T0RYdC09ZJ2P2NZA<0ZJ/G0;JM7P2/WC<0XYQ308jVA`23ZD00Pk0g
0080P[Dh02L0P:]308:MB027Vch0TI`j09BP=02HX300U:<[096]:@2B]BD0TkLJ09Fb5`2G]A40TkDA
08ff4@2:^1<0R;`K08K08`22`R@0Pl8W08?1:`26^RP0Q<0T07k4:01laRT0N/8[07g09021`2@0Ok/Q
086c7024/A`0PZdJ08BZ5025Z140OjTC07Z[5P1lY1`0M:<Q06jT901]YAd00P1bYaH09`1^ZA40JJhB
06Ji6P1P`B@0Gl<_05o2:`1K_RL0D;hW04Vj8@1A^240EK0G05ZZ401MYAP0G:0H05RM5P1@X2D0CJe0
04VbDP1=/e<0F:LX06N;2@1XK@00Heh005mH001LE@00E5T304iX5@14MBL0AWDU04]b701?I0`0DUP1
05IB001DC000FDH00592001?@P00D48004hn000204`o000I04Xh0017>000BCH004Dc0011;`00?S00
03d_000o<P00@3<003`c000h<000>2l003L^000c9`00<1l002LK000S6@0071<001L?000C3P003@P0
00P400040P000P400040000200000005004000020@000P400081000100007000000<0?ooo`002P3o
ool0501aXRT0J:0Y066T9`1OYBH0G:@V05NS:01IXB`0HJ8/06>T9`1SXR40F:<P04jR8@16XRL0@Z8U
046S8P12YQh0AjXJ05>/5P1F[A80E;0A0P1;/QH09`16/Ad0A:lT046a:`15/380@jha042];@19[2T0
DjdP05J_701E/1D0D[8E056^4P1:[Q<0AjdG04N]701=Za/0FJTH06RU501aXQD0LZ@G06ZT5`1UXad0
HZ8Q06FP7@1^X100L:8A06bT4`1XYaL0G:XI05JZ9@1?Zbh0AZXa03^[<`0cZSd0:Z]902F^B@0S[TD0
:Ja402bXA@0202jUB00W032UB`0`YDh0;jI9032UB00]YDT0;Im<03:SDP0dYeH0=:UH03FYF@0dYeD0
=JIA03NWD@0hZ5H0>J5K03bEH010RV<0B7mU055jJ@1MN6D0GgQN05ejF01KNEL0E7MJ04QiI@14S600
@i]P04FNG@19YDl0C:Q304jQ@`1=WTh0BIML04RAGP14SUh0A8AL04AiG017STd0BJQ10080C[0m02L0
DK0g05F`<01H/BX0G;0X05n^7`1L/2P0FK0a05J`=01F/Bh0F;8Z05^b:@1K/R@0GK0U05n]:`1UZc00
I:X^062V;P1RY2l0JZPS07FU7@1nWAl0QY<P08F=8`22SBl0OXdc07B?<@1^URl0HIl`062[:01V[al0
K;4O076`8P1d/b80MK8Q07Fa8`1a/RD0LK8S07:b:01b[bT00P1a[RX09`1a/2H0L[<V07B_9P1e/2D0
MjlO07V]8`1l[RT0OJ`/07RZ;P1eYbd0LZ//07:a<@1d/2X0Ljd[07:/:P1]/Bd0I[8Y06O0901V]2@0
J;@[06Fl9P1Y^B<0IK0]06BN@`1PY400IZPi06FK?`1OWD00G9e005f/>01O]2l0Jk<]06ja;`1`[bh0
J:Pf06b/;`1b[Ql0M[8K07Nf6`0207Nb400W07Bc301]]A00K;LB06je4P1a/Q40L[D?07303P1c]`d0
N[T;07jf1`1m/@D0N[4807Ne3P24/PP0Pk8508ZY102CX`80TJD109>S0@2@X@00T9d008^R002;Y000
R:l207fg301b`1X0L<0K07307`1f^2@0N;4`07N]=01eZcL0NJ``07J`<P1a]C<0JkTc06W0;P1Y`2P0
Il0V0080Il0Q02L0K<0O07Bh6@1g]1P0L[DO07:i8`1e^200LKDN06:c9@1I`2d0Dl0d05?0>`1>`400
C;A<04baE01;/E@0C[A505Rc@01R[dD0FZA?05NLF@1KUf<0IHMZ07ibJ`2GIVP0VV]V09i[I@2EH680
OgM>07RO802<Va00VZ0A0;2N6@2bXA`0]J0T0:RQ<`2IVD00Rie208:K?P1mWT000P1mWdD04`1oUTd0
RXe908^H@@2@W3X0VI`d09ZQ<P2CZb/0TkLW09Bh7@2P]Q@0WjP>09Z^2`2A[Ph0R[@A08Nj6026_1l0
Ql0Z08[0:P24`2/00P22`2l04P22`2@0P/0P0830:@20`2P0P<0S08C07`24]Al0PZ`N086_7`24[Qh0
Pj`G08B[5@22Za@0P:dE07j[801gZR00LJPM072V7@80KjLI02L0J:XH06Ra6P1W^2D0Hl0b06:n=`1T
]BL0IjdL06JS501NWa80F:@G05NS601IYaL0HJ@D066Q5@1NWAL0Ei`Q05NP:@1HXcD0FZ8Y06FF5@1[
O@<0If<0061C001LC@00F58005MC0@1DFPT0DF8B059Q401FGP`0EU8405=:001AA@00DD4005@o001@
?P00CSh004Xg0019=0000P18=P005`19=P00AcD004<`0014;`00?B`003X[000i;000>bd003`_000k
;`00>B`003PZ000d9`00<R<002dN000U7@008QP001XB000F3P0040T000`5000810000`4000800@00
8`00000<0?ooo`002P3oool0501[XBl0Hid]05^L;@1MWR/0Fj0[05ZM;`1QVS<0JI`e06nN<01^WBX0
HIdZ05bO;@1CWR`0D:8W04jU8`1;ZAl0CjhH05R]4`1H[Q40FK8@0P1D/AH09`1</Al0AK4X04B^;`15
Zc<0A:/e04:[=015Zc80B:`_04f^;P1?[b/0DJhV056^7`1B[A`0DjlI05:^601C[Q`0FZ/J06RW501_
YQ80J:HA06JW5P1UYAP0IZHL06FV501YY`l0IJL=06>X401O[1H0EZlM05B]:01@Z3<0@jXg03N[>`0Y
[4D08:aA01n^CP0Q[DH08Zi602BZA@0202NZB@0W02VXC@0YYU00;:Y<02^YA00[ZD40;jM303:XBP0f
ZTh0=jaA03J/C`0gZdd0=jI;03NVC@0lXU80>YeE03n@FP16Pf40DWYN05]iG`1UMeX0GWUE05MkE01C
O5D0DWiJ04UoH`18RV40AY=O04RKF01:XTl0BjU304jY@P1<Ydh0B9mI04RFG018UE/0A9EE04FDD@15
XT<0B:df0080C;8e02L0D[<f05>d:`1G]R<0F[HN05ne7@1J/R<0F;8`05>c>01G]2d0FK@Y05bd9`1M
/b80H;0T06:/:P1UZBl0I:H`05nV;01TYBX0LJHS07RS7`1mVB80P9LT08B?:`20Tc00O9Hc07FG<@1_
W2l0JZ<f06V_:`1Y/R00L;@M07:d8@1c]2<0Lk@R07Fc901f]2H0Mk8T07>b901d/BH00P1g/BX09`1h
/RH0NK8T07Za901i/B<0Nk4P07Ja8`1h/2L0NK4]07B`:01fZRL0MK4X07Bc;P1e/2h0L:L^072^;@1]
/c00IkD/06C0:01S`2/0IKD^06Rf:`1U/b`0HJ/h066@B@1LWdH0FZm405BYBP1AYdD0EJDo05^`=`1R
_3<0J[4]072Y<@1][C00Hj`h06^a;P1b[al0M[0H07Fd6002072d500W06jc6@1X/280J:lT06nX9P1d
ZR@0MjXQ07:e701c`1X0N;PA07^e1@1n/@40Nk<707Nc3@20/PL0QK4108^X0@2@X@00Rj<008ZU0@2:
YP40SJ8008bV002;YP00Qjh108:c201h]P/0Ll0C06g06`1c_B00MKhV07Re;01e/c80MKH`07Bg=P1d
]cT0JKU106Rg?@1W]cL0Il0g0080I<0_02L0Il0Y06^j9@1a]B<0LKHV06jg8`1]^1h0J;DP05o09`1F
^Bh0E<0`0530<P1<`3l0B[Q>04N`F017[5T0C;A:05>b@01M[TL0EjY@05FSGP1HVV40I8e/07YiL02C
K700VfUY09aYI02:HfD0NW]807ZM5`2CVPl0YiPG0;2F8@2[WR<0Zj@Y09fU=P2@X3d0QjA208:M@@1n
TTP00P1kSE009`26Qe80RHQ=08fF@02?WcT0Uj0g09bS<P2@[c00T[LR09S05`2L^A80V[DB09^d4P2D
]a<0S[LD08Rj7@25`240Ql0Z08Bj;@26_Bd0PL0/08?0:P25`200QL0O08309`20`2T0Q<0S08S07`25
]B00PZTO08>[7@24/1/0OjTH08J[5@21ZQD0P:`F07fZ7@1kZAh0Lj/L076X6`0206nT700W06^/801W
/2<0Hk@[06Vb<01Z[2l0KZ4L06bD4`1ZQPT0Hh@705JA4019W1l0Aj0T04fQ6P1EWQP0EihN05NE7`1C
UR40EIDO05b<3P1VP@40JVh006EL001PC`00G4X005Y<001EC000Dd`0059@0@1DB`40E4P10593001A
?@00BcX004Xe001>>000D3`004/i0017=@00@c400080A3<000@0@S40044c000o<`00>R`00P0j:000
4@0i9P00>2D003TZ000k;000>R`003@Z000`9P00;2@002PO000T6P007aT001XC000D3P003PT000T5
00060`000`0002D00000303oool000X0oooo01@0I:<]05fP;@1JWbh0G9h_06FN;01VVbd0KiL`07BK
<`1dWS00KJ4^06FM;@1OVbl0GId[05NQ9`1CYR00DJXO052^6P1E[QP0Ej`E05F_5@80C[0I02L0B[0R
04Ba;010[3<0AZTg04>V?010Z3`0@j/l04B[@017[400B:]404Z[?@1;ZS00DJ/U05F/7`1E[QX0F:XN
05^Z6`1SZAD0I:LC05nW5P1HZ1`0FZTO05fX6P1JZaD0FjTB05Z/4P1H[1T0DjdI04n_8P1=[Rh0AjXg
03^[@00^[4T09JaA022/E@0R[4l08jY9026ZAP0RZ4d00P0RYU<0100XYED0:ZIC02ZYC`0XZdH202^]
@P0Q02f]A@0b[DX0<Zi?03B]C`0cZdh0=:E?03BRDP0hVUH0>iAL04:8GP1<Oeh0EG]L069iE@1[ME40
G7M?051iD`1<NeH0CgaN04UlIP1;Nf<0BHUP04JDF@1:WTd0BjQ304^/A01;ZTT0BImG04RCF01;UU@0
BJ9:04ZYA`1;[ST0CK0]0080D;8Z02L0E;@]05Nf8@1H]Ad0FK@O05^d801I/B<0E[4_05Rc?01K/Rh0
Gk0Y05n`:P1O[RP0I:d/06RZ<`1XYS@0Ij<c06JU:`1YYR/0M:LR07ZN8023V280PY<Y07j>=01hT3D0
N9Dc07JH<01cWc<0KJHc06Z];`1Y/BP0KK8Q07Bc8@1f/B40MK0T07Fa9`1f/RX0M[8V07Va8P1k/2<0
0P20/B@09`1n[BD0O[0S07b^901jZBH0Nj/Y07J_:`1j/RX0Mk4V07J`901d[RH0LjhZ06n_<`1bZC<0
KJ4b06nZ;`1[[R/0J;8^06Fb<@1V/C00Jjh/06^a;@1Y/SD0I:lj066[>P1Q[cH0G;Dj05fc=@1L/RX0
HJlS05fd8`1Q^RT0JJ``06^G?01WYSX0H[4_06bc9@1d[al0NK8I07>e6P0206no800W06ne9@1^Zbl0
M:Hc07NT<P1kXR`0OilV07Jc9P1^`2L0M;hJ07Jg3@1l]P/0OKD907Ne2P22/@H0SJd2092V0@2@X@00
SJ00092T002?Y`00T:L008fZ002<ZP00RK4008Na0@1o]PL0Ml0=06o06`1]`2H0Kl0^07K0<@1a`3@0
L/0c0730@01^]dD0JKM806Jd@`1U/T00HkM50080G/1602L0H/0k06Bg<@1Z]Rl0J;TW06O08@1R`200
GKPR05bi9P1I`340D/0b05;0=01;`440BkQ@04bZG01;YUd0CK5>04n`@P1GZ4D0EJQD05JUF@1IWUh0
IXmX07UmM`2<Kg`0UVa[09Q]GP24K5d0Mh94082Q6@2@VAT0XhT]0;>;9@2]VBP0Xi/`09^N>`2;XD<0
Qj=308RM?`24S4T00P25R5809`26REH0RXY=08jH@02@X3h0VY`e09VO<P2AZB`0T[HN09Ni5P2B^a@0
T/0K09Bi6`2B`1`0S/0I08Zj8026_B80QkPZ08F`;@25/B/0PL0T08?08P24`1l0PkdQ08;0;024`300
P/0Z08;09`24]b80P:`S08:Y7P27ZQP0PZdG08BY6@23[1H0PJTF07b[6`1aZ1l0KZXQ076V8`02072S
:P0K06VW=P1T[3H0IYlf06bL:01_SQh0MGh=06ee101/LP80J70105ei1`1DQa<0B9<N04fG6`1HUa40
GYH@05nA4P1NS140Gh<=06Il1@1[LP00JFH006=J001QE@00Fd`005Q7001EA@00DTD00080D4@000X0
D3d004Xm0019?000B3H004H`0018<@00BCD004Pd0018=@00A3<00P10<0005`0o:`00?B`003`^000m
:`00>BX003TV000d:000=BH003@W000e9P00<bL003<V000]8@00:b<002TN000U6`008AD001XB000B
30003@D000H200030P000@0002D00000303oool000X0oooo01@0Gi/`05^M=01MVC80IY@a06ZF;`1^
Tbl0Mi<a07VF=01dWS00Ij4/05nP;P1QWS00GIl]05^R9@1EYR80DJTQ052]801@[Ql0Cj/N04f]7@80
BjhI02L0BJhN04F^8P19[2@0Bj/X04bZ;017Z380AZPd04VZ>@18ZSh0AjU704NWAP18Ycd0B:Ti04bW
<P1AYbh0E:PY05F/8`1E[Ad0DjXG05>]601@Za/0EJdJ05N^501>[aD0B[0G04Z_8P1;Zb@0BjPV04NZ
;016ZSP0>jU702nVE00UZEd08Z]S026[G`0PZU`08JUI02BVE`0SXUT00P0SVe`09`0SWEh09jAK02RX
EP0X[4X09Z]602N]B@0Z[Dh0:jaA02ZZE`0/ZEP0<JUE02jQF@0^Vf40<Y9X03V<I@0oQVP0BH=U059n
FP1MOE00I7U<05MjCP19Ne00B7iC04akF`1=NfD0CWMR04^5FP17UE@0BJ5804RZA@1;[DL0BJQ904VR
D01;UED0CIi:04f/@@1?/S/0D;4a05:d9`0205Fd8@0W05Rf8P1N]Q/0G[HJ05bc7P1H[bD0Ek0U05V`
;01G/S80Fk8]05j`;01O[b/0Gjd[06>[<@1TZCL0IJ/i06RX=01WZRT0JJ/T07BW7`1oWR00PIHT082@
:`1mT3L0Nh`k07NA=`1eV300MYld06nV>@1/Zc@0JK0c06ba:01b/b@0LK@R072d901c/RP0Mk4]07Rc
;@1h/B<0N[<Q0080P;8Q02L0O:lQ07Z]8`1h[BP0MJT[07N^:`1e]2T0Ll0Y07>n901b_Q`0L[8T06b^
:`1]ZCD0KZ<h06RQ=`1X[C00IK8]06Ra<@1Y/C/0JJhf06ZX=01W[SD0Hk9005nd@@1K]3/0Gk/h05W0
>@1Q]bh0G;@U05jb9P1O/bD0Fk8X062[<P1LYT00HJdc06Fb8@1]/aX0MK8I07Fd5`1e^AX00P1h]BH0
9`1j/2d0N:Dc07jT<P22WC<0QZ0X08NO9022YBD0O:X/07N_:`1e]2D0LkHH07O03P1e]`X0PK8708j_
1@2@Y@80SYl108jL002AX000SZH108fW0029[000RZl008Ja002:/@00Q[8307ng2P1g`1D0Ml0J07O0
801n^RD0OKLW07Ni9P1c^S40JkPk06Jg@@1U]D@0HkI606BdBP0206BdB`0W06BeBP1R/cl0H[Ph06G0
:P1U`2<0Gl0W0630901Q`2P0G/0Y05g0:P1I`380Dl1005:dD01>ZV00CJ=T05>^D@1F[d/0FZE<05NL
F@1IVF00FYMP06B=J`1jNW@0SFeg099]H@2?JU80PGIJ07j<A02;Z240V9DN09f;8@2[TR@0Yj0^09^L
>@2DX3d0R:Pj08BU@P2=W400SXm80080QHYF02L0R8UG08b8CP2BSDD0Ui9309ZB>`2HWC00SZX/09Fh
7`2A`1T0S/0I0970702B^1`0T;/L08_07P2<`240Rl0V08O0:`27^bh0RKH_08>j9P24`1h0RK/K08Jk
8P25`2P0Q<0Z08;0:`21`2@0Pk/N08>b8021/1h0OjdH07bZ6P20[AT0OjlJ07f]6`1dZR40JjXT06R/
:P1]Zc<00P1ZZ3X09`1V[480H;0h06>P;01^Ra`0L7X?071W101TH@00Heh006=O001PI`40EWL805>8
5`1>TB00DhlA05f82@1MRP/0GhD406Af001ZKP00IfL006AP001PF`00HED005]:001F@P00D3h004`m
001:?000BCT004Lg0015=000AcH004He0012<000@S4004<a0011<`00ACD004Lc000204<^000G03//
000j:000?2P003`/000h;000>2H003HY000d9`00<B<0038S000b9000;Ql002`N000[7`009Q`002<L
000N5`006Q4001<;000;1P001@<00081000100009@00000<0?ooo`002P3oool0501YUbd0IYX]06VL
;@1/VB/0LYTZ07BI:@1fVBP0MI/Z07JQ:@1]Y2P0I:<W062Q9`1MXR@0G:@O05NX7P1EZ200E:XR05BY
8`1EZb40D:/O0P1BZa`09`1DZad0DjXN05BZ7P1BZQl0E:XT052Z9`1;ZRh0BjLb04RW>@16YT@0B:=9
04JTA`17Y480BZ90052O@01@YCP0CjT^04b[9`1:[2@0BJlP04N_7`1;/A/0Ak8H04Fa7014/R40A;4Y
04ZX<P1<Y3@0A:@i03bX@`0bZE00:JQK022XGP0OZEl07jUR022XHP0PZ6D08ImS02:HIP0202:=J@0W
02BAJ00WW6@0:ZAR02RYD@0WZdd08je?02F[E`0WZEP0::IK02VWGP0/Xeh0;9aO02bIHP0^U6H0=95Q
03^;H@14QEl0BHEK04j7E@1=R540AHU@04:9D019RTh0BhAA04f3EP1=PeD0C8eD04VKD@18Z4P0C:]5
04ZZAP1:Y4T0B:5904bRB@1?Ych0D:lg052f=01E]340EkDS0080F[DJ02L0G[HJ06:f5`1V]AL0H[@O
05^a:@1I[bP0F;0Y05Va;01M/B/0Gk0]05j_;@1P[Bh0H:dg06B^>`1U[Sd0IZdf06N`:@1]/200MZXN
08:O7@21URD0OXl/086@<P23T3D0OID_07^J;@1iVS00MJ@b07>Z=01a/C@0L;@^07>d:@1c]BD0M[HV
07Jb;01l/300O;4]07^`9`1o/A`00P25[a/09`24Zah0P:TR07^]9P1hZb`0MZlZ07Bd:P1a^2@0M;<O
07Jb6P1f/Qh0LZhR07:[;01`ZbL0LJhU06nc9P1_]BT0K[8V06Vb<01V/R/0JZd_06Nb<`1S]cT0HK4g
062a=01R^Rl0G;X`05nj:@1M/b/0HJ/d06FZ>01TXS`0Hj/i062a=01W/b80J[HD076f4@1g^1<0N;LF
07^c7@0207j^:@0W082[:`22YBl0QIda08FA>@2>Tc00UY<W08bD<025TcT0Ni`h07BY<@1/]b80M<0H
07W04@24/PX0R:/808JS0P2;WP40RiX008VN0@2;YP80RZL108N[0028[P00Rk4008f`002</P40QkD7
07^g3@1j`140N/0G07Rj7P1k^2<0N[LS076h:`1X^3D0I;I406:dBP1S/T/0I[950080I[1:02L0H[5>
062_C01O/dH0HL0h06G0;P1R_c40H;P[06C08`1Z`2<0I[TT05k0<@1G`400D[AE04^WI@1>WVX0EjAE
05bWE01NXET0FhmU05j4HP1QQ680JgU[07U`L@2:Ig80RVYF08IXCP1lNE/0N95=09RG<P2LSah0Ui0M
0:NB:`2aT3<0U9E008FVA@1o[Cd0PZHm08^Q@@2CVDd00P2:SUD09`28QED0V8=@0:>9B02VQD<0WXHo
09RG<`2=Y2`0TKLR08k07`2;`1/0SKTO09:f7`2;]b40Rk`U08_19`2;`2l0Q/4e08S0=@2<^3@0R;LY
08bk6@2=^AT0R[TQ08Rk9@29^2T0Q[TX08C08@28^ad0Q[XP08>h8P20/a`0OZ`K07fb7@1e]B80MK4Y
072^;`1`/Rh0Jk0i06ZWB00206>XC`0W066^BP1U[cH0JilQ07=m401/I040IE/0061E001ODP00Fe@0
05iO001MJ0<0G78905an3`1GPPd0GX48065o101TO040J78006]]001YH`00IUd0065G001ND000G4/0
05Do001A>P00BCL004Le0018<`00AS<004<d0013<@00@380044a0010;000?b/003dZ0014<`00@SH0
0080@30001H0?2T003TT000h9`00>RP003PZ000f9`00=BH003<T000a7`00<R00030N000[7`009R00
02LN000T70008AP001/B000D3P0040X000P500030@000@009P00000<0?ooo`002P3oool0501dTBd0
L9@X076I:01cVRH0MIDV07NI:01cVbH0LYXX072N:01_XRT0JJ8V05nP8@1OX1l0Gj<M05fU7@1LXal0
FJ@R05ZT:01MYRL0FZPS0P1NYb009`1OYR40G:@N05VV7P1JZAl0FJPR05RY8`1CZB@0C:XV04RY:`18
YSP0B:4o04BU@P16YD<0B:E304^P@019YCP0@JXb03jZ<00j[Bh0?Jd/042_:00o/2T0?JlY03V`:00l
/2X0@Jl_04BZ<P0nYc`0>JM503BYD00/ZU@0::UI02B[EP0OZEL08ZMR02:VI00RXfT08iY/02B?K@02
02>4K00W02J4K00WRV/09i5/02FNGP0SYUX08ZMJ02:SH@0TXed09Z5Q02RQH`0/WF80;YQR02jHH`0^
UfL0=99R03Z<GP10Q640@XAR046;G@0nSUP0>Y5D03fAE@15SE00B8E;04^5C@19RDh0C9A=04fQC@1<
ZTP0C:]704ZTB@16VT`0AZ=704bZ@P1=[cH0C[<`05:e;`1E]S40F;HS0080Fk@I02L0GkTH06Je6P1V
/Q/0H[4Q05^_;01K/BL0F[8V05Zb:P1M/Rd0G[8/066_:P1S[2l0I:/f06N_>`1W/3h0Ijlf076`9`1j
[b00R:TN08RO7`25UBP0PY4Z08>>;`26TS40Pi@^07nH:@1mUR`0OYd]07^Q<`1f[3<0L;<`06je;P1a
]2@0L[<N07Va9P1j[bd0Mjl^07F^:01m[Qd00P20[1/09`1oZR@0Mj`Y07J^9@1d/B<0M;8U07>k9`1b
_B40MK<I07Ve5P1h]QH0N;4G07J_7`1i[1X0OJhL07Z`8`1l/2@0MK<R06fc9@1Z^BD0Ik0^06Jc;P1W
[bh0IZlX066_9`1S^Bd0H;X^066l:P1R]Bh0I:dm06N[?P1[YCd0Jjld06Ba:@1W]1/0J;HB06ng401b
^QD0Mk0O07n/9P0208FV:@0W08^Q;02BWBl0TIHZ08n@;`2:T2T0T9@S092G9P2BVBH0RYdW07jW9P1a
[b40OjhT08>e801n]A@0PJh>082U0@28X@00S:0008NN0`28YPD0QjL208NZ0@2;ZP00Rk0008f`0P2C
/0<0SK8508Rf2P26^`/0Pl0>07o0601j^1d0N[HQ07Be9@1_]Rh0IkHm06Ff@01S^4@0I[I00080H[U:
02L0HkE=05jaB@1M/TT0H[Q106K0=@1S`300H/0[06Vh7P1Z`1X0H[HS05^e=P1N]dH0D[1E04ZQIP1;
V6P0FYiE062QE`1SXe`0GYAR05n?GP1XR5l0LgQU07M[L@24IVd0SFmL08i`E`1nO5l0NHi>08bK9P2U
UQ`0XY@V0:J?<@2QTCX0RJ=1082[AP20Z400R9M008jEB02FT5<00P2DQUD09`2ENUD0Z7]D0:^0C@2Y
PdT0WXa009ZI=P2AY2h0SkPS09308P2A^240UK/W09Jf;02@^R/0Rk/^08W1;P29`3H0R;dk08Zg=`2:
]3@0RKTT08fj6@2>]aH0SkHI08^k7P28_Al0Q<0N08O07`29`1d0R<0O08Jk8023]aX0Pk0J07f`701f
]240M;@/07B/>@1fZcX0KZM006ZUA`0206>UA@0W06>T>P1/Y2`0L94F079f201WI000HeX005e@001I
C@00F4`005YF001KE@00GE`005eV0P1OJPP0GVh7061^0@1TK@00IV<006IQ001VG`00IU/0061D001L
C@00FDL00590001=?000BSL0044a0013<@00@2h0048`0012<P00@Rl0048^000o;000?2T003TY000n
;@00?bh00080?b/001D0>bP003DV000f9P00=BD003HW000g9`00<b@002hQ000[8000:Qd002XL000Y
7000:2<002HQ000T70007aP001L@000B2@0030H000H300010@009`00000<0?ooo`002P3oool0501i
Vb@0MiXT07JK9`1eWBH0M9/T07BL9`1eW2L0M9X/07>L;P1dWbd0KZ<Z06JR9@1TXAl0IIlL06FP7P1T
WR80Gi/X06:L:`1PWBd0HihZ0P1VWbP09`1VX2L0H:8V05fT901RY2H0Gj@T05bW8`1HZB80D:`Q04j[
801<ZbH0BjT]04RY<P19Yc@0B:Pc04NW<`12ZBl0?JTb03N[=@0b[3T0=Z/d03V/<P0i/S80=[0a03F]
<@0hZc40?Jhc03Z/>00cZTP0;ZUG02NVG`0TYFD09:QR02:XFP0OYEX08Z9U02:QJ`0QWFl09I=g02F6
N`0202QhNP0W02QfMP0UMgD08GQi022;K`0OWFD07Z5W02:KKP0SWFP099eX02JNJ`0XW6X0;iUW02fK
I@0`W6H0=IIU03b;H`0mPfD0?HAV03V>H`0fUE`0=IUG03ZEF013STl0AHE<04F8B016T4`0B9e<04VV
B01;[DD0C:Y504RQA`15VdT0AjM204Z[?P19/3L0BK8a04jd;P1B]C00E;@U0080F;@O02L0F[DM05fh
7`1S]B40Gk4V05f`9`1O/b<0Gk@V06:c:@1P/bL0Gk4Y06:^;P1UZSD0IJPk06JZ>@1X[CL0K;4a07J`
9`24[a`0RjHM08ZR8`28VBH0QIPY08BG:`25URl0PiT^08:I:`22UbX0PI/^07bN<P1iYcH0LK0d06fd
<01`]RL0LkHR07Ra9@1k[bX0NZlZ07V_:P1k[2800P1oZR<09`1lZBX0MJ`Z07N]9`1j/280N[0T07Va
7P1g/Q/0Mk8H07Ze5@1h]QD0N[PF07Ze601o]AH0P[<I082a7@1l]B40M;TL076i7@1[_B40J;/X06Za
9@1^[RD0JK0Q06>l9P1R`2h0I;da06C0<`1W/C80Ijlj07:/<@1e[BP0M:lO06n`601]/A@0KKHA07Fh
501i/a/0OZL]08FT;@0208RJ=`0W09FK=02HTcT0Ti@^09FA:P20SRX0RhPc09:@;P2ITBT0Ui<]08fG
;@23VS00R8lo07fU@01//Rd0L[8F07b[1`23Y0@0QYl3082O1024XP@0QZ4108RU0@2<Z000RZl108V`
1@2:/0L0SK85092d0`2<]P<0R;/:08304P1j^QT0NK@O07Fb8`1e]2`0KKDf06Fe>P1N`3l0G<140080
H;]<02L0G[Y>05jhB`1L]Th0GKM9066k>@1N`2l0Hl0O06S05`1T`1P0Fk<V05Jd>P1K]DL0EK5G052N
H@1AUe`0IIe=06RMCP1YY5D0IIeL05nIG@1/RV40Lg=W07USK`23Gf/0UFeO0:9eG028NUh0MhU?09JI
;`2aTB80^8lS0:2C<@29X3l0Qj/m08JN@P2>TD40ZHI609N:C@2BPeP00P2NOUL09`2UMe@0/7AH0:]e
D@2WNd/0WiDm09VR=P2BYS<0R[PX08nk902C]2T0UKL_09Fj<P2A^bl0S;df08Vm>P26]Cd0RK=108Z[
>P2=Z3H0T;DY08nf6P2=]1T0S;4A08Zh6029_AX0RL0M08W08`27`2<0RL0P08Jn8025^1`0Q:lM08Fc
801n]BT0Mk@j07FOC@1fRU40LHe?06fGB@0206^M>`0U06ZM;01YUQd0L8D?06mc0@1XIP00HE`005i=
001IC000F4l005]?001LA`00F4/005iC001SF@40HEP105mH001OE@00HUX006MM001SF@00I5T0061=
001HB000DT800550001??@00C3P004D`000n;000?B/003l]000o;`00?bh003l[000m;@00@2X003/Y
000403/X000E03PX000f9P00<b@003@U000e:000=BL0030P000[7`009ah002PK000Z6@009Ad002TO
000X80008a`001/H000E3@003PD000H300030@000@0000`000000P01000I000000`0oooo000:0?oo
o`0D07>P7P1bWAh0LIhP076N8@1`W280KihS076N9P1dVbP0M9XY07:M;@1bXB/0L:8U06jO7`1/W1d0
J9dL06ZO801XWBL0II`W06VM:@1XWR`206FN:P0W06>P9`1OYBH0GJDW05jV901LYb00FZLR05F[901?
[2@0C:dT04j]8P1;[2D0B:l/04V/;P1:ZS00B:/a04:Y;P0lZC<0>J/h03N/?00kZSX0?ZTh046/=P10
ZcT0?:Xk03Z[>00i[3`0=Ja302fYD`0UYeX08ZIR026WI00RZfH08ZMM026RFP0QVfL089M[02:DL`0W
S7`09h200080:g5o02L0:6al02MZOP0OIX<07g]k01nAM00PVg@08IQe02BPJ`0UY6L09J=Z02FQJ@0Z
Wf@0;9iR02nPHP0dV5d0=i9K03f?FP10Seh0?9AI03NIE00dVU80=YA=03b=C00oRd`0@95<04:ICP13
XdX0AJ]504Z]@01;[D40C:Y604ZSA`1:ZD80Aje004F_?P18/3L0B[D_04jg:@1A/b@00P1G]1h09`1I
]B40FKDU05be:P1L]2X0F[DU05jc901S]RP0H;D_066d:P1R[b`0I:de06BR?01UWcd0IJ<h06^/<@1^
/Bh0O;8R08N]6`2:Z200S:@V08ZN:@28VRd0QidW08FK;024VBd0OiD/08>F:P24Ub/0OYHd07bM>P1e
Yc`0K[4i06ne;`1_]BL0MK8X07Rb:01e]2d0Mk8[07V`900207Z_8@0W07Za;@1f/BX0M[4U07R_801m
/Qh0Ok@J07bc5P1j/QL0MkLG07Nm501g^a@0N[LD086l4`23_AD0OkHG07bf6P1i^1X0Ml0H076f601b
[QP0LjhH07>^6P1`/ah0J;HZ06Ng9`1Z]BH0J[H[06fd:`1^/2d0NZlS07Za6P1g/180Mjl@07N`4@1h
]QD0OK<N08BY8`2:YBT0RZH[0080QIdc02L0Qi`j08ZG?@26W3H0PIXb086F<`27TBh0SYHY096G:02<
WB/0SI`b08jH=@2@R3l0RH]607nEA`1jWcd0OJL^08:[9`21[R00QjXJ08B[6@24[A40P[<>08:b3`20
]Q00Q;4@08>d3`27]0/0SK@608Zc0P27]`L0Q;T;082h4@1j`1T0M;TP076e;@1]]3L0I[Ph05k0?@1M
`4000P1L`4/09`1M`4`0FkQ?05VcD@1F]U40D[I:05?0=`1G`1l0G/0J05_06`1D]RD0F;<c05Rf@P1C
]e80DJ=K05JKEP1TVdX0IiM@06NKE`1NUU/0HIEK06b8HP1eMVT0Of]]08]PJ02EJ640X79O08QjFP20
SDP0W:0W0:nL8`2aVBH0UjPb08Vb>`2>/S/0T9li09j@?`2^Q4H0XH1C09QnD`0209EgCP0W09meC@2b
MT/0[WI>0:AoC@2OUCh0Uj0k08bY=`27]C80SK/b09>h<P2A^380Sk/e08fk<@2?]C80RK<j08V^?028
YS/0RZ0h08nT=P2</2H0S:hH08nV3@2?X`d0SjX@08ff5P28_1`0R/0Q08c0902;`2<0Ql0Q08Ji7`24
]1h0PKDP07fc9`1h/CH0Mj5207NG@01fV2h0NIDR0080O94H02L0NXDC07=j3`1dLPD0KFX006AO001O
E000G4/005]8001JB000GD/005U1001@@000ETD005e<001JB@00FDD005Y8001NC`00HeD0065C001N
CP00FDD00552001??000CcT004hl001:=`00A3<003l/000o:P00>Rl003X/000l;@00?2/003lZ0011
;@00?2T003/X000g9`000`0i:0004`0h9@00=RP003HY000e:@00=2D002dQ000[7@00:1d002LJ000T
6@009a`002LK000V7@008Q/001XA000D2`002`L000D300010000:000000<0?ooo`002P3oool207BN
7P0B072M8P1^W2H0L9/W06jL:@1_VbT0LYXV07:J:P1dVRd0MYh/07NP9P1eVb40LYXN06bH7P1]VR00
KIXV06jF9P1`VbH0KIlX0P1VX2X09`1OXbX0G:LU05NY901FZR80EJ/N05:Y7`1;ZRD0B:hY046/:P18
[280AZdS04J]9`16[BX0AZ`Z04FY:011ZBX0@jT^03nY;`0k[3@0?JXe042Z=`15ZCT0A:Q103bWB`0g
Z4/0<ZI@02bTEP0TXUl07ZAQ01fUH`0MZF808:eL022XE@0PWeX0795T01j>JP0ORW<08H5i02MfO@02
02U^O`0W02U[PP0TJ8<07VF:01ecPP0KRg`07IQj026HMP0RXG008Z=[02BQK`0VWFd0:I][02ZLI00[
VV<0;iEM03>EF@0jUUH0?iEG03^FE@0gV5<0=IM<03NDA`0lS4T0?Xe803fEC00nXDd0@:Q904B[@P16
Zd80BJe404b/B01:Z4H0BJY004JZ@`14[TL0AZm004Vc;P1?]BL0DK8O0080EK<N02L0Ek@P05Re:@1F
]2`0F;8Y05Zd9@1G]BL0G;H/05fd=01N/c40HK0c066]=P1QY3`0I:8l06BT=P1[[RP0L;<O07f`6@2:
[AP0RZPM08bU8P2=XBH0QJ4V08FO9`23WR/0QIh[08NH<@2:UBl0Ri<d08:A>@20U400Mj4m076Y?01_
/3@0KK4[06n`9`1a/2@0Mk4Y07Nc9`1d/2000P1c/2409`1a/BH0L;0W07B_9@1i/B40N[<L07Zd6P1i
/aL0MK0H072m6`1e^QX0N;dG07bm5P20]1D0PK<H07jc5`1d/aX0MK<G07Vb5P1g/Q<0M[4D07:_5P1`
/AX0KK8X06Vc<P1[]BD0J[8O06^c7@1^/1T0NJdI086]5`1j[aX0N[8C07f`4@20/QL0Pk4K08FW9@27
YbL0T:<X08JV:@0207bJ?@0F08BK@026Ud<0OYXn07fF>@2?Tc40UI8S09:E8`2=TbL0TIDZ09n=<`2Q
PcP0XGU209=eE@28O5/0MXQJ06VJE01^Zdd0Jk9906je@@1/^3<0K/0W06o08P80K/0R00l0Ll0N07S0
6@1o^0l0P[P:08Jg1@25]`@0QkD808Be3024^140OKLJ07nb9`1i/b/0Lk@_06^h>@1R`3l00P1M`4L0
9`1L`4l0GL1>05fhD01I^dd0Dl1004k0=01?`2H0D/0T05G09@1H`2<0F;HX05K0=01H^Cl0DJa=05FP
CP1QVTh0HXaH05Z6G01FQ6@0GH=Q06ihIP1mKfX0Qfa/095UJ`2GIV80UVAO08AgF@20RDT0XYdK0:^G
9@2MUSL0T:Pj08Nf?@29[3d0TiQ309Z=B02[ND/0ZGI;0:EgB00209acB@0W0:9aA@2eN400/7i60:61
C02NSSd0UIXj08N^>@26^C80RKXf08bj?@2<]S`0S[To08bd=`2@[Cd0SJhn08bX=`2>Xc@0SZ4b092U
;P2</b00TJ`D08jK1P2@U`<0T:0:08j^4P2;]a/0R[XS08Rl8P2:`2<0R<0T08Vm8P25^b00PKTR07bd
:@1j[S80NJ8e07ZN:P1jUAP0O8480080MW000240LVX006eY001/IP00IF0006AJ001PE@00F4d005]7
001IB000F4P005Q5001E?P00DSl005A4001DA@00DD<005E5001HAP00FT`005i9001G@000DS/004lk
001=>`00C3D004Tf001:<`00A380040`000o:P00>b/003`[000j:P000P0k9P00100n:000>b/003XX
000h900203LU000:03PW000f9P00=RL003DY000c9P00;2L002XQ000Z6`00:AT002DL008091T000L0
8a/0028J000M5`005A40010:00091@00100002T00000303oool000X0oooo01@0Li`R07>N8P1eWR@0
MIdS072O9P1`WbD0LY`W07RH9`1hWBT0NIdZ07VL:`1fX2D0L:0R06^N801VWAh0JidQ06bK9@1]VR80
LI/P07>Q8P80KJ<P02L0IZHP05jY7`1LZQh0EjXN05:X7P1BYQl0C:DU04RX9`13Z2/0BZTY04jX901=
ZR<0CJXU04ZY9`17Z2L0B:PU04RX9`13ZBL0?Zd[03j]<P12ZcX0BJU003jYC00`ZV80:JAZ02BRK`0Q
Wfl07ia`01^MK00IXfT06ZYQ022_F@0QYeH089QL01f7I@0KPF/07gUd029dNP0[Kg`00P0^J8409`0Z
IhL09FF:01eOS`0MKHL07HJ001fEOP0PVGP07j1e01nNMP0RVg/09IEg02NEL`0UU6`0:9I]02R@H`0/
Ue/0<9]H03NIE`0gV5<0=IUA03JFB@0gUD80>Y=503bEB010WDL0@:A4046[@@14Zcl0B:a204Z]@P1<
[400B:Xn04J/>@15[cP0BZli04fa>01?]2d0D[@T05:c800205Jb8@0W05Nh801H/BD0E[4W05Vb:01H
]2X0FKH^05^c=01J/SX0Fk8i05n_>01PZcL0H:Hj062P>P1SX380JZXR07:`5022/180RJ`I08bX7`2<
YR40S:DV08VP9P25WbL0PYlX08BO:@2;VRd0T9Db08j?>027U3/0PiDn07bK@01fXSh0KZdg06^^<P1Z
[bP0KJlT07Fb9P1g/R80MJlR0080MJhV02L0KjhX072_:`1a/2X0M;8Y07>d9`1e]BL0L;<R07>m801_
]Ql0LKDQ07>f7`1e_Q`0N[XK07^d7`1i/al0LjlS07B_7`1h/AP0N;<F07:b6@1b/a`0Kk4R06bb:@1]
]2`0K;LS06Nd8@1Z/A`0L[0B07R^2`1l[0/0O;4?07je4@20]1X0RJhP08n[7`2BXQl0SJ4V08ZQ;`20
Ybh00P1kX3/09`20Z3d0NJhl07NZ>@1hXSD0PZ0a08RP:@25Wbd0QiTb08jD<P2JQc`0VGY609EjC028
NET0PGmL072>EP1VV5H0IjUE06JbEP1V]TX0I;Y106G0<`1X`2h0Jl0/06W0;@1_`2/0M<0W07_07P1m
`1H0Ok/B08:i3P1o^0X0P[H;08Ff3023]180P[DO07fg8@1k/bL0L[Df06Jg?P0205g0BP0W05o0D`1K
_U@0G;mD05BjB@1>`3T0Cl0`04S0;01=`300Dl0c05[09P1L`2<0F<0^05G0=`1?]4@0E:Q?066ID@1L
Q5`0EgaT05=kIP1OMfP0Jg1/07M[K020KV`0SVeY099ZHP2CHV80OWEK07Z:C02JXC80WIde092J@029
Xd40S:I3096J@`2GQTL0XWU80;9ZC@2fKDP0]g950080ZW1102L0YFln0;9i>@2aQ4@0ZXU80:BA@02E
W3d0RJe008Rb?@27/S/0R;5008jc@02<]T00Rk4i08j_<`2@]C<0SkH`08fg;P2;]bD0SKDL08jc4`2E
Z@/0U9/309BF0P2CV`@0SjD:08Z`4@29]QT0QkXN08_08P2>_B80R[dO08Jl7P25_240Q;@W07f[9P1o
X1d0QILG08B82P21N`800P1gK`009`1aK000KF/006QS001RH000HeX005eD001MB@00FTL005M5001F
B@00F4D005E0001B?P00E3h005E0001B@P00ED<005A4001FBP00F4H004lo001:>@00AcT004Pf0017
=000Ac<004@e0014=000@2l003l[000j:@00?BT003TX000f9`00=BD003HR000f8`00>R@003<Q0002
038P000:03DW000d9P00=RD003DW000a9@00;B<002XO000W6P00:1`002PH00809AL000L07aL001lE
000K4`004`d000`500060P000@0000l0000000<00@000041000100005`00000<0?ooo`002P3oool0
501cW280LihR07FN901eWB<0L9lV072O9@1bW2L0N9PW07RM:@1iWBX0NI`[07JP9@1`X280JihP06JM
7P1[WB40K9/U06fJ8P1aVb00Lj4R0P1]Xb009`1VYR00GZTO05bZ7P1GZQh0DZPN05:V7`1<YBD0B:PW
04>X:`1:ZBT0CZPT04fZ8`1=ZRD0BZTW04NX9`18Z2D0B:PW04>Y9`0n[B/0?Zdb04:[>P19ZD00?ZU<
032ZHP0YY6X09:9_026OK`0OW7006ie/01VSJ@0JZV408:mI026WEP0PV5`07HMU01^1J`0ONG@08WAj
02]_O00202iXP@0W02YWQ`0UIHX07En?01e]Q`0MQX007IEn022IN00OX7D07iif02:KN`0UUGL09iEc
02FDK00XUVd0:91S02bGF`0`VeP0=iUG03NHD`0eVE40=YI903NE@P0jTdD0?9E8042MA`10Y4@0@J]1
04B[?`18[480BZe204b/@018ZSh0AZ`i04F_>01:[cT0CK4h04nd;@1B]2@0D[<P0080E[8Q02L0EkPP
05Ra9@1F/BL0FK8X05Rd:P1I]Rh0Fk<d05Zb>P1K/ST0Gjlh062[=`1PYSX0H:0j06>P<P1ZZR80L[0D
08:`4P29[1T0S:PO08bV8@2<YBH0RJ0V08FO9`22WbP0Q9lY08^J;@2@UC80SXlh08ND>`23UCh0O9]0
07JR?P1^[CL0Jjhb06Z_:01][b@0MK8V07Nb8P1e[b800P1e[RH09`1_[RP0L:l[076`:P1d/RT0Lk@W
07Fe9`1`/b80LkdP06nf7`1a]B40LkHO07Fn701j^Q/0Nk@O07Vc7`1c[b<0M:lO07Ra601h/aH0L[8I
07:c701_/B80K;8Y06fd;01/]b<0Ik@Q06Za701b/180N:h;07b/2`1l/@l0O[DA082d6P29[R00Sj/O
09:R7`2=XBH0RZ4_082W;P0207^P>`0W082X?@1i[S`0MjXi07RR=@22X340R:0Y08FO;@27VC80SY@b
09Z7?02INTH0UGY<08QiF@21Oe`0L8iF06JHEP1WZED0I[9F06JfBP1T^T40IL0c06S0;P1[`2`0JL0]
06o0:`1d`2L0Nl0N07g05P1o^a80P[T>07nh2P22]P/0QKH<08>d4P22]Al0OKLQ07^c9`1b]CH0I[Ln
0080GL1:02L0Gl1C05^nE01L_e@0E;Y904k0>@1?`300B<0/04g0<01C`3<0F/0V05c08`1H`2h0EL0g
04ndA01DZ4l0HIUA05b4G01GO6@0Dg]V05mgJ01[L6`0Mf]/081^K02>KFT0TVYR09=RHP1nME/0NXY<
09ZQ<P2MWCD0T9Y008VS@@2<YT<0TIY309N6A`2RNDP0/VY=0;I]B02gLTD00P2ZL4409`2UKch0/WTi
0;64A02ZRDP0Y95009FL?@29[D00R;8m08Nb>`28/D00S[=008bf@02;/CT0SZlc092e<`2?]S00SKL^
08^g9@2=]A`0S[<C09FY2`2DV`<0U9H209>K102?Y@X0R[0A08Vf6@27^Qh0Rl0R08jm8P2:_Al0Q[`N
08Fl8@24]2L0OJ/V07nP7@25UaL0Q8P:085k0P0207M_000W075/001]J`00J6<0069P001SFP00GE@0
05e9001JA`00EdD005I9001HA@00ED00058n001D?P00ED000592001E@`00E4@005I:001HAP00Ccl0
04Xi0017>@00B3H004Ld0017<`00A3D004@d0010;`00?b/003XY000m:@00>BP003HW000e9@00=R80
03HS000j9000<b400080<R0000X0=BL003@V000f9@00=BL0034U000]8`00:Ql002LJ000X7000:1P0
0P0U5`001`0O5`007aD001/C000C3@0030D000H2000100003`0000000`0100000@400040000G0000
00`0oooo000:0?ooo`0D07>L7@1cWQh0MZ0O07FN8@1bWb80M9lT07NN9@1gW2D0NIlW07^M:@1kWBL0
MZ0W07>O9`1`WbL0KIlT06jL9@1[WR@0KihR07:O7`1eWah207FR7P0>06jS7P1XYAd0IJPL05fV7`1I
YR00Dj@R04nT9`1=XbL0CZ8W05BT9`1LY2D0EjPR05:Y8@1AZb8204jZ8P0G04^X7`1:ZAh0AZ`Q04N]
:01;[3D0BZA303fJF@0/Vg808Yaf01fNL`0NWfh07Z5V01ZTI`0KYf806jeN01b^F00NY5/07I5P01Yn
I`0MMFl07fif029YO00ZIh000P0aHhD09`0_I8X09F>@01iOT`0KKhX07XJ001jDO@0NUgH07iUh022H
O`0SUX0099Aj02BFMP0QVWD09YY^02RIIP0ZVUd0:iUK02fHEP0bUU@0<i=E03JGCP0eVdX0=im803bN
A@0lY4<0@JPn04BZ?P18[D40B:e504b]@P1;ZcT0Aj`h04R_=P1;/c40CK@b052d=@1D^C00DKDW05Bf
8P0205Ve8`0W05bh7`1K]240F:lU05Zb:P1K]2l0Fk@`05Va=@1K[T00GZm005j^?P1OZc/0HJLj06>U
=P1TYbh0KJdN07b_4@27[Q00SZ`H08b/7@2;ZAl0RJXP08BV8`24Y2D0Oj<T07nS:026X2l0SYPg08bC
?@26TT00Pi5007bC?@1fWd00L:dm06Zb>01//BX0K[0U07J^8`1g/2<0LjlQ0080LZlU02L0KZl[06n`
:01a^2`0M;<Y07:e9@1e/BT0M;4X07:c8P1_^200LKHT07Bg7`1k^QP0MkLJ07Rd9@1i[bX0Ljdc07B`
9P1h/aX0N;8I07Ve5`1h/1T0NK0K07Zc6`1f]1`0M;HM072b801`/aX0MK@?07Zb2020]0T0O;@;082e
5`23/b40T:LT09:Z8P2EWb<0T9lY08JN=`1lXC@00P1fWS`09`1d]3D0Lkhc07>e<`1dZcD0MjDd07ZQ
=01iY3X0OZ4m07fL@01oS4/0OgaF07mdF01kMe/0Oh1A07BCC01YVE@0KJ9E072WD`1][DP0J[1006Ve
?01Z^3P0KKHg06nf>@1^]CP0M/0j07O0<P1g`2d0N/0U07[07@1j^Q<0OK@=08:d2`24]`l0PkTK08>g
7P23/b40P;8T07Fb;00206Jf=P0W06?0@01O`4/0GL1<05ZjB`1I`3X0F/8_05_19`1L`2T0H<0U06K0
6P1T`1P0Gl0Q05S0<01E]cl0Fje9062FD@1MPeh0FGeX05QgK@1TMfd0KGI]075aK`1gLFl0Pfm/08eX
I@2EHV80OWES07N8E`2HVcL0XYTj09FH@P2@U4P0W8e90:MoA`2ZKd00[F@n0;aNA037H4@0cV=00080
^FHm02L0[VXj0;9g=@2dPcd0/he70:RI@02KWcl0R:Y008F[@`24YDP0Q:=208Z_?P2;]cX0SkD_08jb
9`2C^BD0TKXQ08ni8P2@^1T0T;8B09:X2`2EW`D0UIH109JA002DTP00T9T108bO1@29ZA40R;@J08Zh
7`2;^B00S;TN08^l6`2<]a/0R;8O08NW6P26VA00QhT708>00@1mM`000P1gK`009`1cJP00JF4006MR
001VH@00I5X0061@001JBP00F4@005E6001ICP00Fd/005Q6001F?`00DSl0058n001D@P00ED0005M1
001F@P00ET@00591001=>000AC8004Hb0014<P00B3@004Df0013=000@B`003dX000m:P00>bd003TZ
000f:000=BP0034R000c8P00<R00030O000202lO000C034P000_9@00<BD0030V000_8@00;b0002XN
000V6`00:1P002DJ000R5`007a<001`D000G4P005180010<000:1@001@400040000=000000800@00
00@00@40008100020@000@005P00000<0?ooo`002P3oool0501_XAT0LJ0I07BQ7P1dXAh0M9hN07>Q
8@1gXb40NJ8Q07ZS8P1hXB<0Mj4S07RQ7`1bXAh0LJ4Q076N8`1bWBD0M9dW07FM9P1dWR@0MYlS0P1e
WR@09`1_W2@0JYlS06NQ901SXB@0GJHS05NU9`1BXRX0EJ0W05^Q:01TXRH0IJDS05jX8P1DZB00CJTN
04^Y7P1;[Ql0CjhL04Z/6@15[a`0@Z`S04:W<P10TDT0=gmV02QlO`0OSGh06iMf01ZJJ`0NXV807:UQ
01V[H@0GZf406j]R01ZMI`0JR6T06WI`01a`M@0PJW`0:6F002mQP`0203QNR`0W03=QS`0UIID07FFC
01]jR@0MSGl07Y=j026?M`0QSGX07hYo02:=P@0TU7X08YMe02FLMP0WWW@0:ieY02fHI00]UUl0:iAM
02^?G00^SEl0;Y=P02nNF00dY4d0>:A503bU@011ZcX0Aj/j04b/?`1;[4L0CZdo04b/=`1<[SP0CK8d
04jf<@1B^c40Dkdb05Fj:P1G^B<0F[TN0080GKXM02L0H;/L062k7@1O/b40H;DX06:d;@1R]S@0Fk4k
05b]@01JZ4@0GJY206:Z?`1TYS/0IJTc06B]:`1^/1d0OK8B08b/4P2:ZaP0QZ/L08>Y8@25ZB00PjDP
082S8`1nX2H0Oj<Z08NQ;@2>VS@0TYLi08b@?`23S400O8m007FFAP1dYT<0LJdl072^<01`[Bd0MJ/[
07^/;01lZR/00P1dZRX09`1_[B/0K:l/06j]:P1a[bD0Lk8Q07Rb901f/BL0M[8W07Fd9@1c^2@0MkHK
07Vh601f_AP0M;DO07Nc8`1i/B@0NjlI07Bd501e/Q40M[4E07Ja5`1e/AP0Lk8I07Bc6P1d/Q/0Kk4J
07:c4@1g]0l0O;H;07nf4P1m/Q/0Rj`P09JY7`2BYR@0T:HR096S9`29Xc00PJ8k07bX=`0207B]=@0W
076j;`1``300MKDb07B^=01iZ3@0Nihh07NM@01gWDT0LIe>06fJE`1^SE`0Kh=K0728E@1fTDd0L:A4
06bUB01XZD/0KZm:06fb@01/]SD0JKTc06C0<@1X`3D0J/0l06o0@01_`3`0Kl0e0730<`1d_Bh0ML0W
07Vk801m^1@0PkP@08:e3@27]A00Q;HH082g7`1m]Ql0N;8P0080KkHS02L0Ik/a0670@01O`4H0G;Y7
0670?@1V`3L0I<0a06?0;`1U`200I/0E06Zh4@1S^AP0G/0S05^g?01M[T/0H95B05n1H01LO6L0FWaa
06=nKP1YO780Kg5f075VO01gJ7L0QfYa09ASJP1mMVX0LhaO092Q>02JYC40Uidm09BHA@2US4L0[W]3
0;=/?02fGd00aV=40<9UB@34H4/00P2cISh09`2aKCL0]G<g0;9nA02[SDl0Vie0096T?P29X4@0R9a5
08BIB@23WdP0QZXj08Jh;@2;^R40TK8D09>^402C[Pl0UZD>09FV302EXP/0TYh409BM0@2FTP00Thl0
09>C002CU@00U9D2096K2@2>XPl0SJLC08j/4P2=[140SjX>09BV3P2DX`d0TIh<08VA1P28QP80PWh1
085g000207Ub000Q07EX001]GP00JUl006QP001SG000HeD005i<001IC000Ed`005Y>001JC@00FD`0
05I:001C@P00CSl005Ho001CA000Dd4005I2001HA`00E4D004`n0018=000AC8004@a0015=000ACL0
044e0010<000?2L003PT000e9`00>BD00080>2P000@0<bD003<S000c8`00;al00P0[70004P0]6`00
:al002lO000`8000;b8002hR000Z7P009a`002<I000S5P007A@001XB000G4@004`/0010:000;2@00
20@000<10140000000<00@000000000000005P00000<0?ooo`002P3oool00`1[XQT0KYhI07FK6`02
07ZL7`0?07RN7`1gX1l0OJ4Q07bQ801kXQd0NJ<N07JR7@1bXa`0Mj4N07NO8`1lW2D0Ni`[07VM:P1g
VbX0MYXW0080MY/W02L0LI/V06bO9P1/XRP0JZ<W06RS9P1SXRP0HZ0Y06:P:01VXBD0Jj8Q06ZT7`1V
Z1`0GZXI05bY601BZQX0Cj`H04j]5`1;[AP0@Z`L03ZY9P0`X3`0<GUP035NN`0WGXX07Gf201ZBN00J
UVX06:9R01VZH@0E[6<05JMZ01RSKP0JTg<07H1c01m^M@0RJgX09VIo02eQP`0gG8D00P11F8X0100j
GXh0;6B@025/T00OPhL201nDOP0Q0267NP0RPW/08gf202:3PP0TTWT099]b02BPM00XXgH0:J9b02ZJ
KP0YUV@0:I5P02N>I00[T6T0:Y]Z02bUF`0^Z4`0=JU003V/>@10[S40B;4`04n`=01?[c/0Cj`h04n^
=@1>/3@0D[<e05Bf<P1E^Bh0EkTZ05Vj901O]ad0H[LI0080HkHJ02L0I;XL06:h8@1M]B00GkDW062g
<01R]cL0Gjm005bVA@1JXDP0FjE:062WA01RZD00HZde06Zc9@1c]AX0O[4C08:`4`22/aD0PK8H08:`
6`23/QP0QZ/J08>Y7023[200PZ/T08VZ9P2<YRT0Riha08ND?021RD<0Mh]907BDB`1`WTX0KZY006b`
=`1][bl0LZh`072`;`1e[bX00P1f[R`09`1a[b/0Jjd/06^_9`1^/B80M;@M07Jd7P1g/RD0Lk<X06o0
9`1d`280Nk/J07^n5`1h]1P0M[8N07bd6`1l/aT0OK@C07^b2`1f/Ph0L[0E072b6P1`/1`0L;4K07:_
6`1b[Qd0M;@D07Fg401h/a00OK@E08>b8020ZRX0U:<X09RQ902DWRT0Rj@[08^S;`23YcD0P:Dg07Zb
<`0207>e=@0W07Fn;P1c_S00N[<a07V[<@1oYC80OY]007BHA@1_UU40JZ5G06ZTE@1VZ5H0I:QD06RV
CP1ZZTH0K[@o06bf@@1Y]dD0JkQ206^e>@1Z`3<0Jl0^06_0;@1]`2h0LL0^07;0;01]`2d0K/0^0730
;`1e`2h0M/0]07_0:@1i`200OkTG08:d4`26]A00QK@C07g06P1j`1`0OKLS0080NkPU02L0MKL/06S0
<@1U`3h0I<1506S0@P1X`400JL0j06fk<01Y`2L0JL0J06Zi4P1Y^A80I[TK066h=@1O[dT0HYAE06>4
G@1TO6/0HWa`0620K01VO6d0KF]h06mUO@1nI7h0QfEg091TM01hMV/0K8iQ08RP>@2KWCH0X9Tm0:6K
@`2USCh0[GU10;Q^>@33JT00cVDn0;mZA`2nI4h00P2^KST04@2gLC<0`W0n0;5mB`2PSE@0Sj5208bQ
@@2?U4H0SiE508^O@P23ZCd0RJd]08bb7`2?/1@0U:T=09>L0@2DV@00UI@000<0TiD001<0TI@009:D
002CT@00UI40096D002AT000Ti@0092H0P2=V`L0RYh808bJ202?VP<0UIL009:H002=U@00RHd008>8
0025O`00PW/00080P7D001H0Mfh0075W001[H@00K5h006IN001VEP00GeD005]?001KC@00FDh005]>
001FCP00FT/005E5001C@P00ET4005M2001EA@00ED4005I3001BA@00CS/00P1:=P003`17=P00AC40
04D`0012<@00@C4003XY000j9000>2<003PT000f:000>2H003PW000c9`00;b4002/O000202`N000B
02/M000/7@00;A`002dQ000]7P00;1d002LJ000S60008AH0024E000M5@006Q0001H=000@2P0030H0
00T400050P000P40:P00000<0?ooo`002P3oool0501eXa/0MZ8J07RP701jXAh0OJ0O07ZP7@1kXAd0
OJ0L07jU701jYAP0NJDJ07NU7P1gYA`0NJ8O07bO7`1nVbH0NiXZ07VJ:P1iVBT0N9`X0P1fVRT09`1e
VRD0MIhY07BN:@1eW2`0Li/]076M;`1^VBd0L9`Z072O9`1bW2D0KYhP06fR7@1YYAT0JJLI066W6@1E
[1/0CZdO04R[:P12ZC80>J4n02nDC`0_OVL0:G=f02=bO@0RSG0079aZ01NRH`0DYf404ZaV016ZJ`0C
XW805iYf01b;M00NNG809fUf02aWNP0_I8<0=En403iKR@0204EERP0W03iNS00^J8`08Fj<01n5R@0N
TXL07Y:50221P00TOH0097V402EmP@0VSWD09I]_02:PL00TXW@09j5f02^KN00YVVL0:YAN02ZEG`0/
Vf80;JAN02Z[DP0][DH0=:dl03R^<P10/2T0Bk0X056b;01A/C<0D;0h056_=`1A/CD0Dk4l05Jb>P1I
]3<0EkTT05bg7P1Q]1/0IK@J0080HkPN02L0H[PP066f9P1O/bP0Gk</062e=01Q/C`0GjY005ZPA01I
WDL0Fj5705fW@@1R[C/0J[4Y076f701j]Q40P;<?07ne401o]a80O[PC082c5022/a80Qk<B08:e4P23
]A@0Pk@G08Nd6@28/ad0QK4Q082V;01hWSl0M9M507>GA`1aW4D0K:A006V]>`1W/3P0KK0b072`;01a
/2L00P1c[b<09`1][b<0Jk4T06Fb8`1[]1l0Kk<M07:f7P1e]B80M[@R07S07P1j^1/0OKDF07bf4`1j
]1P0MK8N07Rf601j]A80Ok@?07^c301e/180Lk0L06f_7`1V/b40KK0L076/701g[1X0MK4G07R]7@1k
Zb80Qj/R08jX:02>YB/0UZ0U09>O9`2AWRX0Rj8^08NR=@20Z3<0PZXe07Jd<P0207Jn<@0W07Jl;01g
_300MK@_07BX<@1lWcd0OiQ6076DA`1]Ud`0JZY>06^`B`1W/d/0HkE706Fg@`1U]cl0J<0g06W0?01R
]d00I;Tk06K0<P1U`2d0J/0W06k09@1b`2D0LL4V06o29P1Z`2P0JKl]06g0<01``300LL0d07?0;P1g
`2/0N[dM07bf5P22/a80QK<>07^h4`1h^AP0O;XP0080O[HR02L0N[4Y076e:P1/`3<0J<1106_0?`1[
^4X0JkY306bj>P1Z`340Jl0R06fg5`1W^Q<0HkTN06C0>P1M]500GYEL069oHP1/N6d0JWEa06IeK`1Y
LFl0JfAg07=ROP1oIH80PFEl081QM@1^Mfl0HIEQ08>W>@2DWc<0VIXn09bHA`2URd00[X<i0;Mg=032
M3<0bG0f0<A]?033IdX00P2aJSl0502`KSH0]7Di0:enA02VR4l0VIM8092FB02<TTX0QZ=608Bb>@24
]RL0RK<I08^/402?Y`X0Tj4309>H002CT`00U8h009ZE002HUP00TYH00P2BT0004@2?S`00Shh008jC
002BT@00Si4009:C0@2<TP80SHl208n@0P2AT040TY<0096B002;U@00QXd008N40026O@00Pg`00080
PGP002L0NW<007I^001_J`00L6X006eT001ZHP00J5d0061I001PDP00GE0005]?001KD000Fdh005Y<
001G@P00DD@005E0001E@@00DCh004hm001>>`00D3d004lm001>>000BC@004<_0016=@00@c80040`
000j:@00>BH003<T000b9@00<b<003<T000e8`00<BD002/O000Z7`000P0`7`004@0_7@00:ah002`N
000/7`00:Qd002PK000W6@009AP0020E000L4@007Q0001L@000@3@003PP000T500050`000P0002/0
0000303oool000X0oooo01@0P:4M07nR701mXAd0Nj0O07jP8021Wb40P9lR07fP7@1jXaX0N:DI07VU
6P1jXB80Mj4U07bN9@1nV2H0OID[082A:020UBH0OiPY07RK:080MITU02L0MITV07NM9P1gWBP0MIdY
076P:@1bWB/0LY`Z07BM:@1eWbD0M:4Q072P701[X1T0Jj8I06VV6@1MYQ`0BZXT04:Z<`0kYD<0>9U=
03F=F`0aPV/0:h5c02N7LP0SR74089QU01ZNIP0FYFH04ZUZ012[K@0AZG805Z5e01RJM@0NS6l09G]`
02aYM`0dJ7h0>f2403mKR@10F8X00P13FX/09`0kGX`0<FF:029[S`0OPhh07hn>01f;S@0PNhP08gb6
02AjR00YOhH0:8Qi02BAL`0SUg@09Y]j02RKO00WVGX0:9QY02VEHP0ZVF@0;:1T02bYF`0Y[U00;;14
02n_>P0g/2d0?k0V04Za9P1@/RT0DK@`056a=P1@/SD0C;0d04j_?01C[cd0Ek<f05Zf8`1N/a`0IK0L
06Fa8P0206Bg900W06Ff9`1P[b`0Gjhf05n`>@1L[c`0GZQ405bNA01IVD@0EYQ405^L@P1QZCL0H[4b
06^e7`1g^140P[@:08:d2021]PP0Q;H808Fc2P2:/0`0Sk0:08fa2`2=/`d0S;@=08jc3P2</Q40Rk4E
08Na6022/1d0MZ`[07BV=P1bWCl0L9M406fIA01VY440Ij`o06Z`>@1`/B`0Kk0S0080LJlP02L0Kk0M
06Z`7@1Z/B00J[4P06f`801a]1h0M;<N07Fd7P1i]AX0NK@G07nc4`1n]1<0O;DI07Ng701e`1L0O;PA
07bd4@1k/a80NZlJ07NW9P1`[2P0K:`X07Ba801j/QX0N[@J07^b801lY2/0PYl^08jM<02@Vc40U9X]
08bL:`2;Vb`0T94/08nE<P2AU3`0QJ4e07b^<`1d]Rh00P1a_Bd09`1d_BH0L[dZ06c0:P1^]C80M:@n
07RGA01bVT80K:=0072c>01c]cT0Jk`l06[0?01V`3`0I/0o06G0>01V`3P0I;He06Jg<01[`2`0KL0V
0770801a`1l0Ll0P07;28@1aa2D0K<0_06[1;P1[`2l0K<8`06k0<@1``S@0M<0c07K0;`1h^B80P;@C
08Be2021]`T0P;P@07fk7@0207ni7`0W082c9P1f/b@0LKHW06[0;P1Y^CX0J[U=06fiBP1Z`4<0J<0j
06W0;01^^Qh0KKPJ06Nh901U^3L0GZmC05^?H01OOV<0J7YZ06MjK01SPVd0IGi^06Y^L01[J7H0LFUi
06i/M@1aJ6d0IgmZ06FMH021Zd00TIXh09N?A`2QST/0]8/n0;^7;02jPB<0_GdT0<1i:037M3D0dFQ2
0080/f=002L0YVhj0:Eg>@2WQST0/8a909nFA@2EUDL0SII308V^>026]RL0R;8H08fV3@2>W`T0T9h1
09>G002DT000U8h009RB002KU`00V9T009NJ002BT`00T8h008j?002@T@00T8h009:;002?S000S8h0
08Z=002=S@00SX`0096>002BSP00SY<008b@002=R`00Qh4008Uo0022N`000P1oNP009`1mM`00Lg<0
071a001bK@00MFd0079]001`I`00J60006AE001MCP00GE0005m@001MCP00FU0005Q9001CA000Cd80
054l001>>@00C3H004dh001<?000C3d004Xi001;=`00BC<004Tg0011=P00?c@003d_000f9`00=B@0
03HW000c9P00<B80030Q000_8P00:ah002XO000202dN000A02dP000Y7`00:a`002LL000T70009AX0
02@I000Q500070h001P>000G30004`/000h:000:1`001P<000<100010000:`00000<0?ooo`002P3o
ool0501cXQ00OZ<I07nQ6@21WaX0QYhM08JJ7P25WR00Pj0O07fR701lXa`0OJ<P07jQ9`1kWRP0NY/V
07bF:`20TRh0Phd[08N?:`28TBX0PY@/0P1kTRh09`1jTbX0NY/U07^M8`1hX240MJ8U07BQ:@1fX2X0
N9`X07^M9@1nWRL0MIhT06bQ8`1UXB00Gj@P05BV8012ZRh0<j]002nWE00^UV@0<H=c02elP@0QRH00
7iMh01fGKP0MVfH05i]/01JUL`0AZWD04j]d01>XL00GXW405Yic026@L@0WNg00<VMh03iRP017FhD0
C5B:04IFS@0203iHS@0W03AJSP0/Fi00862F01ejU`0JQY/06X:J01icT`0PN9008gZ>02QmRP0YPH00
8h]j02>AN@0UUGh09IQo02>JP@0SVfl08YmV026QI`0VYVT0::eM02JaD@0Y/4T0;jlj03>a:`0j/2H0
Ak4X052c:`1@/bX0CK8/04fb;`1</S00C;4g05:b>01F]340FkPS05ne6`1R/200H[<V0080H;LZ02L0
G[8]05j[=`1MZD80FJa605V[A@1KY4L0GI]405RJ@01GW3/0GJ8f066]:`1Q]Ah0J[LD07Jg2`21/`L0
P[@208:c0`28]0<0S[43092/102B[`H0TZh909>_202E[`L0UK4809N^2P2E[`X0Sjl=08^`4023[aD0
OJhI07Z/7P1bXbd0LJDi06J/@01R/4<0I[4k072`9`1b/Ah00P1c`1X00`1]]1H0J;DG06Re7@0206Zg
7`0R072d6P1e]AT0M;@I07:g6P1c]Q40N[8=07bd3`1h]AT0M[HI07>h501j]@h0N[8A07^b5P1n[280
P9Da07>P;P1ZYRl0Lj/Y07^]8`22[B<0RZHS08nN8@2DVbH0UIdY092L;`29WR/0P9d]08>K;02>SC<0
S9<d08fD>`21YCT0NK8h07Jh;P80K/0U02L0LL0R06^l9`1/`2X0KKDa07BS?@1eTd00LYU006jY?P1b
]c00M<0^0730<@1_`3D0J<0h06S0@01U`3l0I/0i06K0;@1U`2X0LL0Q07C06P1c`1T0L<4F06k26`1_
`Ad0L/4X06g0=`1]`300Jl0c06[2;01Y`2l0K<0f06g0?P1a`3L0LL0Z07ff5P23]@/0QKD708Re2P29
]`h00P26]a@09`20^Qh0NkXN07Jf8P1_^ad0J[Ld06FiC@1X]dl0I[Q@06Nh@@1V`3<0K;/R06nk8@1[
^2d0JK<k06:UCP1NS680GX5S06EiI@1ROV`0H8=c0620MP1TLVl0I6U`06MWM`1VJG@0K6Q`06F1J01V
XV00OZ/m092J>@2MT3P0Y8Xk09b8>`2SQCL0]7`/0;Il9P2jMBT0`G<c0<]Y@@020;=[@@0W0:Ae@@2P
PCh0Vi1009VA@02ETT00SY=208bP=@2:/Ah0RJTC092N202>U`<0SiD208jC002CT`00U94009JD002E
V@00UIX009BI002DVP00TYD0096@002?T`00TI80096>002DS@00TX`008j<002>R`00S8X008f;002C
SP00TY80096?002?S000SH/008^80028Q000QG`00080PgT002L0P7P007Qe001cL`00Mg@007Me001f
M000Lf`006]R001RF000He<006=?001ND000H58005a@001HC`00FDT005I5001@?@00BSP004Tj0017
>@00C3P004`i001=>000B3P004Dh0016>@00AS@0048a000k;P00=R@003LX000e8`00=2D002hQ000^
7P00;Ad002TP000[7`000P0]7@00400/7P00:ad002PK000W6`008aT0028F000N50007Q<001/A000G
3P004P/000l:000:200020@000<20001000/000000`0oooo000:0?ooo`0406jU301hXaH0Nj8H08BP
6P80QI`M00h0Q:0M08BQ701oXQ/0OJ4N07VP801lXB@0NidU07^N9@1nWBL0Pi`W08ZE9@28UbD0R9LT
08RH9P80PYDY02L0P9PU07bP7P1iXQ`0NZ<K07fV6P1oYA`0PZ8L08:Q7@24XAd0Oj8N07>R7@1XXQ/0
GZLK05JZ601?[1`0@JlX03J`>00a[4H0;J9E02VCK00TRWd07Y9j01RKM`0IVfl06ImX01JSL@0CYgL0
4j]i01>[LP0GYg005JA]01VQL00PTFl0:7]d03=WNP0oH800BeV4051ERP13E8d00P0jEI007P0`EI<0
:4nF01mBWP0KJil06WVP01QgWP0KJYP07gFC025jTP0UOhl08XJ201j>O00PTWh099B202:FQP0MVX40
7Yma01bSI@0QY6P09JYW02F_G00T/E00:K5602n`>P0f/Rh0?;4Y04Fb;01;/bX0C;@Y04Vd;080B[H_
00L0C;Da05>d<@1L]RX0GkPR06:e7`1P/RD0H;D[0080G[D`00h0Fk0j05ZZ@01MZDL0G:Q905fYA`1P
YdH0G9m105JQ?@1KYcD0H:/`06>d7`1W_A@0JkT?07Fh3P80O;L>01L0OkH?08Fe3P2>/@`0TK4;09B`
202H/0L0U[8709Ra0`2I/040V:l209>_0P2A/P80S[4208Z_1`28[`L0Q;0?07f`5`1d/2T0Jjli06>e
AP1U/ch0Kk8_07:a7`0207>e600W06jc5P1/`1D0Jl0I06bk6P1Z^ad0Kl0K07707@1/]1d0IkHL06^e
4`1e`0l0MKl?076o501__QD0Lk/D07Re4P1n/QD0Q;8K086b8@1k[BH0KjlT06Va9P1^[BH0NZHV07jR
:`27WRL0SI8[09>?:02BV2T0SiXb08jJ;@2:UBX0RiD]09:?<P25US@0PIXg07^]<`1g]c<0ML0X0080
L<0M02L0Kl0J06c07@1c`2@0M<0/07Fd=@1a[CP0JK8e06Ze=P1_`2h0L/0]07C0;P1e`2l0L/0`06_0
=P1V`380J<0`06c0;@1Z`2d0L<0S07;07P1b`1T0LL0J06o0701V`A/0K/8R06k2:`1_`2h0L<0a06_0
:@1Y`2T0JL4a06[0=`1_`300Kl0/07W07020^A80Rk@9096c0`2=/`L00P2:]Ph09`22^aP0Ol0L07^d
7`1g^A/0L[L`06JjA`1Y]500JJmE06NhA@1U`2l0IkdR06^h901Z^Rd0JkPk06JZBP1STeX0GHQQ05f5
I01KP6X0HGed065hN@1TK780JF]^06a[L`1]KG<0JFaa06N:IP1]ZET0SJH`0:>D;@2_QRX0Zh<X08n6
?P2BN4L0Zfli0;I/=@2gN2d0_7L`0<=b?P020;9i@@0W0::5@`2LS4@0UY=1096E?@2>USL0Rid`08jR
802>YA@0RiP708n;0@2=RP00ThT009><002DT000UIH009JK002HV`00V9`009>J002DU`00TI@009:@
002@S`00UY0009FA002FSP00UH/00968002AS000ShX008Z:002BS@00T8h009:=002AS000T8/008n;
0028R@00Q7h00080PG/002L0OWX007Uj001iOP00NWd007Yh001hM000Lfd006aT001VG`00J5/006MG
001QE000G4l005U<001GB@00F4`005E5001>@000CSd004lm001>>`00CSX004hi001<>`00BCT004Dj
0016>000A3<004@`000n<000>b`003HY000`9000<b<002lP000/7P00;1l002/P000Z7`000P0Y7@00
3`0/7`00:1`002PJ000W6P009AL001lE000M400060l001L?000C2P003PX000/600080`001@800081
000]000000`0oooo000:0?ooo`0D06bU1P1`YaD0MZDH07^Q6@1mXA/0Oj4I086T6P1oY1T0P:@J08:R
701nXAd0O:4L07^P7P1kWQ`0O:4O08:O8022WAl0RI/O08JH7P24VB0208:H8`0W082G8`1oWAd0O:4J
07nR6P20XaX0PJ@K08>O7022WAh0P9hS07bL9P1_Wb80HZDQ05V/7@1A[QP0BZhL046^:00i/3H0<:i5
02RTE`0SUF`07HYm01R>P00DTGl05Iic01BSK00FZ7@05jYk01F/N@0E[gL05JMg01VPMP0ITgT078Ig
01mgNP0XJ7`0<6An03QOPP0lFHP0=5R=0080<5>D02L0:T^J02I3W@0P@J<07UNT01YXY00GKJ8076ZK
021dU@0OOID07h>A01n;Q`0LTX407iF402BDP`0RTHD07I=o01fJL`0OYFT07ZUW026[IP0R/UX08[5<
02Vc@`0^[cT0=K0^03^`:P13/R/0BKD/04Zf:`1:]b/0BkD[04fg:`1C]bP0F;LS062e8@1R/b00Hk8V
062b:@1L]C000P1I/cT09`1I[DL0FJY;05ZWC01LYd/0GZY:05nZAP1OXT00G:Hi05n_;01Q/B@0HkLH
06Rl401]^Pl0L[XA07Bi6P1d_1/0ML0O07^j8020]Ad0SK4D09N`4@2K/180WK4@0:6a402Q[@l0Xjl@
0:Ba3`2R/Pl0V;<>09Na3`2D[a40SjlA08^_4P24/Qd0M;PY06Jc@01X^c`0JKd[06ff7P0206jd6@0W
07705@1c]1D0LKLH076e6@1`]Qh0LL0N06g07`1Z`1l0IL0N06W05`1^`180LKlC072o5@1]^AX0LKHK
07Jb7`1o/BD0R:`Y08>[:P1m[2P0MjlS076_7`1j[1d0O:DM086Q7P25Wad0S9dO08ZM902>W2<0Rj4_
08jK;P2;TS@0RYH_08fE=025W380Mj0g07Fa=01g]S00Ml0P0080LL0I02L0Kl0H06k06`1c`280Ll0Z
0730=`1/]3P0J[Df06Ne=`1^_2l0M<0_07G0;`1_`S<0K<0c06K0<P1W`2P0J/0R06o0:@1]]c40L;DZ
06fh8P1_`1d0K/4P06o06P1a`1T0L<0K06o0801_`2<0L<0W06g09P1W`2`0JL0]06S0<01/`3<0K<0f
07O0901l`1D0RkX>09:e202A/@D00P2>/P/09`25]a00P;HJ07Vb801g]Ad0MKP_06Vl?P1V/4/0IJUJ
06Fg@P1W`2`0J<0Q06g0801^`340L[U006b^B`1QVUT0GIAP05VBI01HQV/0I7Ie06QYN01VIg<0JfIh
075YM`1^LG@0I7Y[06BGHP1^]T`0T:d^0:JH<02bQS40]80^0:Yo=`2XLS`0/fa00;5]@02WN3X0Yg`e
0;]j?0020:^3@P0E0:N;B@2PT4T0TIU508BS?@26[2X0SZTI09>P3P2CTPH0TX`20927002BQ`00Thd0
09F;002HS`00V98009JD002IU@00V9X009JI002FU@00Ui400080Thl00100Ti@009BE002DT@00U8h0
09:;002?S`00SXh008^<002?S@00THh0092:002AR000Sh/008f;0028R@00Q8@00P24P0009`1nO`00
Ngh007b1001lO@00NG/007Ib001aJ@00KfH006aS001/H@00Jel006ML001QF000GTl005Q?001FC@00
ETH005=3001A@@00DD0004hn001A?@00CC`004`j0019?@00A3T0048h0013<@00?C0003l/000l:`00
=R@002lR000b9000;R80030Q000`7`00;20002/O000202XQ000>02hM000X7@00:AT002HJ000P6P00
7QH001X?000F3P0050`00109000:10001@<000@10001000^000000`0oooo000:0?ooo`0D06JN1P1[
XQ80Kj4F07>R6@1dY1T0MZDF07RW601kZQP0OjPH082R6020Y1L0OZ0H07ZQ5`1jY1L0N:@E07NX5`1j
YaL0OJDG07bU5`1kYQH207ZU5`0W07bV6@1nZ1H0P:DF08:T5`22XaP0OjHI07fS6`1oXa/0Nj@K07NU
701^YaT0H:`F05J^4`1?[Q00BJdA04B]7011/2`0=:a302VOH00MSGD07Gj001N3R@0BPh/04I]k01BW
L`0E[7H05jaj01V^NP0G[gh06ZN001RFP00FPWl05Gam01MdOP0JK7d07fQk02ISP00XH8D0:5f;0080
9e6E02L0:D6M02PcXP0U<JL08dBT01iEY00MIJ408FVJ021aU`0LNIL07X>A01^?RP0JUHT07YF:02:A
R00QRXH07HR101j<N`0OVWH07ZAa02>YI`0T[eP09k=:02jd@00b/SL0>;8_03fe:P13]R/0B[P^04nj
<01?^bh0C[L]04ng:P1D]BL0GK4O062a801N[RH0Fjla05Za<@1I/SD00P1J/d002P1K[T`0FjU=05bT
B`1OYT`0H:U:06:[@`1RZcd0HK0_06Je7`1X_1L206Nn4P0K06Vh4P1^_Q@0K;/P06W0901V`2h0JKTa
06nc<`21[b80T:DN09RN8@2KXR00X:8Q0:BP802VX1`0ZJDG0:ZU602WXQL0Yj0H0:VK7P2TWQh0XJDO
09BV7P25[B@0LZlc06b/?01[[S<0L;4T0080Lk<Q02L0L/0M07>g6`1g]a/0N;HK07^g701h]Ad0L/0N
06[0701U`1/0K;HJ06jf5@1b]a@0M;PG076h601a^1/0M;8P07Z]:01oZC<0NZH_07NW<@1aZbT0LjdW
07bW9@1jY240PZ0R07jQ8029VbH0QiPP08^C8@2?UB/0SYD`08JF=`22W340QILb07jN=P1gXcH0MK<_
07O0:P1g`1h00P1d`AP09`1f`1P0NL0I07[0701g`2D0M<0^0730<01/`2l0JkL^0770;P1d`380Kl0a
06O0=@1Y^cD0JKXb06S09@1^^280LkPT06jh;@1a`2P0KL0T07;06`1d`QL0M<<E07745P1b`aD0LL<E
07716@1^`1l0Kl0U06c0:`1W`2X0HL4/06C0;@1W`3P0Ll0]07K09@23`1D0RKLA092a2@0208fb2@0W
08Vd3023]A<0O:`R07bd7P1g]RX0K;Pb06Vb@`1U[5D0I;Y006O0;01W`280K<0R06k0<`1[]d@0IZU?
06>FG@1OU6@0Gi1U05mnK`1/Jg80L6Ag071WN01_KGL0Lg=d06YjL01SPFP0JJ1J07FeA`2>Z340[I4e
0;ao>032LSd0bG4k0<YY?036KdD0/g190:IaC`2HMch0_GHm0080[HQ302L0Z8m@09fHC@2<Y3d0R:`Y
096_602DX@d0U98109J?002CSP00THT009><002ESP00UHd009J@002FT`00UYH009FE002IU@00V9L0
09RF002HT000UY00092@002CUP00UI<009B<002AR000S8X008^@0029T`00S9H008VB002AS`00SH/0
08^8002:R@00R8d008B<0023QP000P20QP009`1lO`00Mg/007Ul001gN`00MGH0075c001aKP00L6T0
06eX001]I@00Jf@006UR001XH@00I5d0065E001LD000F4/005E9001IB@00E4<00591001A@@00Cch0
04Th0016=`00@CD0044a0011;P00?bl003l^000m;@00>BX003@V000b9`00<2D0030T000_8`00;200
02XP000202TO000>02PN000W700091L0024F000O6@007QD001T>000E2`0040P000X7000510000`80
00810001000^000000`0oooo000:0?ooo`0D06FK1@1SW0H0JZ8C06jV5@1gYAP0MZPF07VX5@1nZ1H0
PjDH08BR5`23XQH0PJ<G07^T5@1iYaH0MZHI07FW6@1dXaX0NZ<M07VT6`1hYAD207JU500W07VV5@1m
Z1D0Q:<F08NQ6@25X1/0PZ4M07bT7`1hY1h0LjLI07BZ5`1][1D0HJlB05B`3P1?Z`/0C:T=04R[5013
[2P0=ZE602ZFF`0ORV/077im01B3T00BQi0049Z501BTO`0FZGX05jaj01J[N`0H[H005J>301J;P`0F
LH@04GB100ifO`0>Mg`057=n01Q_P00KJhD07VB:00808E6D02L09CfM02HcX@0U=:808dRL029IVP0O
JYX0976E021iU@0LPIH07HRD01Z;T00HShh08I6<02BBQP0RT8D0896001fEO@0NX7L07jEc022YJ00S
[eL09kA<02^fA@0c]D00>KLa046h:P17]R/0CKh_05;0;`1E^R/0F;HX05Vf9`1K/B80H;0Q05j^9P1L
[Rd0Fjdg05^_@01K/D800P1I/TD09`1I[TL0FJQ;05fSBP1NY4T0HJI6066/@@1S/CH0HkDS06Jg5P1Z
]a00J[HB06nc5@1`/aH0L;4F076d601a]QX0L;DP06nc:@1_/RX0OZhL092Z402GXQ80Vj4F09fQ6@2M
X1T0WYhH0:>M702XWAd0YYTO0:>B9@2RSbd0W9TY09ZL9@2CW2P0PZ<X07>V=01WX4<0J:/l06n_<`02
076_<00W07>a:@1d/R@0LK8S07Ba801j/Al0N[0N07Za701_/AT0M;4I07F_6@1j[QH0OZdF07^`4`1h
/A<0N;4F07f`6@21[1d0P:`T082Y8`1kZ2H0MJPS07:Y8@1`ZAl0MZ@O07^V8@1kYAh0Nj8O07fJ8`22
UBL0QY<a08NL<01mWSH0O9dc07^E>01dXSX0LZTh07:g;@1]`2@0L<0M0080L/0I02L0Ml0E07S0501g
`1P0M<0O07G09P1a`2`0L<0X06k09`1``2L0Kl0_06g0:P1Z`2X0K;PY06^d:@1`^RH0LKH]07Fb:01a
]BD0M;TZ07?0:`1i`1`0Ml0D07K0501a`aD0M<8E07;45`1daQT0L/4P07;0801/`R40Jl0Y06O2<01Z
`2h0JL8f0770=P1a`3P0NL0T07jf5P28]0d00P29[`T09`29/`X0QK<E07jc8@1n^1h0N;@S07>j9@1a
/CP0JJm@06Jh@`1W^c<0JL0[06g0:P1/`3D0IkA906>REP1TTV40JX]W07F4J@1bNF`0MVUa07QXLP1h
KWL0M7=g06acLP1TOF`0GhaW06NWE01f^4@0S:P`09jC;P2[PC80_7Hc0<1a=@35JcL0bG@i0;Q`?`2P
K4T0Z7910;UcA@020:^9B@0809N>BP2:UDP0Q:XS08n[4@2HV`T0UY@309FA002DR`0209>?000M09>>
002BS`00TH`009B?002ET`00TiD009JC002FT000V94009RB002JS`00Uhd009F@002ET@00U8h008f>
002<R@00Qhd008F?0027T`00QI8008JB002:T@00SXX008^60028QP00QX/0086;0021QP000P20PP00
8P1kP@00MWd007=l001aN`00LWP0075h001dM000Lg0006m/001/JP00JV@006]W001]IP00JF<006AL
001OEP00GE@005]A001ID@00F4d005Q;001GA`00D4<004dm0018?000@cT004Hg0012<`00@S00044e
000m;@00>Bd003PW000e9P0203@U000302hR000]7P00:Qh00080:aX000d0:1/002DH000O5`007a80
01hC000M4`005a00018;000>1@001`<0008100010@000@0002l00000303oool000X0oooo01@0IYP3
06VL1P1]Y@h0L:D@07jX5`1oZAH0PJLE08JX5`28YQP0RJ8I08NR6024XaX0OjDE07bV5P1jZA/0MZDN
07FS7P1kXAl0Oj<I086S5P80OZHD02L0OJLB082V5020XaL0P:4J07jS6@1nXAL0NJDK07B[6@1_[Q40
KJh;06V]2@1P[PT0EZd<056W2`1=YPT0BZTB04:V;@0cVTd0:HQP025lK00MNG`05hB=01>BSP0CWhT0
4Z2801FVQ`0FZHD05jZ101JYO@0HW7/05XMl01AaP@0AOWl04XQm01B>N00EQgd06X2101akR00NKHl0
0P0ODiH09`0QA9/08TBL029?V`0SFY@09FN>02=]S`0UN8d088:A01b9TP0NRI4078F?01^5S`0QRh/0
98n802>@Q@0PUh807Iio01fUN`0PYgL08jY^02R[G@0[/540<;E903JcAP11/cH0B[DX052e9@1B]RL0
EkLT05Zf8P1J/b<0F[0U05j_901O[bH0F:l[05Z_<P1G[Cl0FZ]805R^C`0205V^B@0W05^ZA@1NXd00
HJ1106:W@P1Q[CX0G;8a05^d:@1L]a`0G[HF06>e5P1W/aH0JK@O06Ra7@1_/aL0Kk8F072a601_[ad0
JK0X06Z`;P1i[b80R:`A09NZ4@2PYPl0XZ<A09fX3`2QYQ40YJ@E0:VQ5@2WVQD0YYHF0:VH5`2MWQL0
WJ0F09bP5`2?YAL0O:HR06j[>01/[c80Mk4X0080M[0V02L0M;0Q072_801_/B00K[4N076b7P1`/QX0
MK4F07J`5`1k/1P0OZdJ07n[6021Z1P0O:`G07b^6@1jZQd0O:/M07jX8@1lZ2L0PjLW07^U9`1nY2/0
M:LU076W8P1hYAd0Q:<Q082S9`28X2<0QY`X08:E;P1oUSH0NZ0b07ZO<`1fX3<0KYlh06n]=@1_]S80
Kl0U06o0801`_AT00P1a_A@09`1i_1D0N/0H07W06P1h`1/0ML0T07C09P1g`2@0Ll0S07K0901b`2L0
KL0V07309P1b`240Mk@T07Bf:@1b/S00K[HT06bh8P1d`240Ll0P07c0501h`180ML0B06o24`1aaA@0
LLDE07;55P1d`QX0L/0H06c07P1X`2L0J/0e06k0<P1/`SL0L<<g06[0?`1_`2`0M[PN07jf4P0208Rb
2P0W08Vb1`25]A80P[HQ082f7P1j/RL0M;TQ07:d<@1Z/4H0K;9506Ze@01Y`3L0JL8c06Vk>`1T[dd0
HieK06J@IP1bRVP0NhEZ07aoIP1nMVP0O7=/07Q`L@1^LWH0JW9`05j2K@1ITFX0IZUD07jc?02DWR/0
QI@o0967>@2iNb80^W/T0;Ye:@31LbH0_74b0;1d?P2dMdD0_7UA0080Z8]=02L0S9E;082M>028YAT0
T9d409NF002FTP00U8h009J@002DTP00Ti8009>A002CSP00Sh`008b9002?R000T8h009F=002CR@00
THP009::002@S@00T8T008n<002=S`00QhT008N30024Q@00Q8P008>80024R000PXX007n90021R000
Ph<008B50023QP00PhT008F;0021QP000P1kPP009`1dO000LW`006ei001aN`00Lg`0079j001cNP00
LGD0071`001/J`00JF<006YW001YI000IF@006=P001UHP00IU`0061E001JD@00Fdl005m>001JCP00
FE0005I<001CA@00Cd0004hm0014>000@CD0048e0015=000?Rl003X[000f9`00<RL003DX000c9@00
;Al002PM000202TM000;02PI000X5@007Q4001/=000J3P00610001D;000?2@002@<000<000010000
<@00000<0?ooo`002P3oool02@1]U`40KYX307:Q201eX@T0MJ8;07jU5020Y1H0Rj@J08^S6P0208bO
6P0908NO6022XQH0PJLG07jV701mXb00Nj4N07bP7P23WAX0QI`E0080Ri`G02L0SIlH08JO6`24Wal0
OJ8O07^S7@1fYAd0NJLR07JY6P1cZ0d0KjP806ZW201PYPP0F:L:05:T2@1=YPd0AJXI03^R>P0YSU`0
97U^021/NP0LLh406XJ;01NHRP0BX8d04inA01BQU00CXYH05J>:01BPP@0FUGX05h=f01IbO00FRGd0
5iUi01bQL00LVWD07I:101j7S00NM9400P0NE9L09`0MBIT0856G01mPU@0SIX`08fj:02I`S00TOHd0
8XV;022@S@0ORXl08Gn?021oS00TQhX0:8f702NCQ00SW8D08JAn01nYM`0O[G009:iW02N]H00Y/5H0
<K5903VdA016]3@0DkDT05Rd7`1G]b00F[DO05Zd801I/2D0GJdW05n];`1J[C<0FJhh05^]?@1KZD40
G:E705^SA@0205fS@`0W066S?`1SXSL0JZ0h06N]<`1L/RT0F;HW05Rf8P1H]Q`0GKLI05ne6`1S]240
H[<U06Be8`1U]Qd0IKHI06Jb7@1T/Al0Hk4Y06Bb=01^/BP0NjhE08N]5@2HZAH0WJPF09^Y6@2LYaP0
X:<L0::M7P2RTa`0Wi4M0:FC7`2LT1d0VY@N09fJ8@2GVa`0QJ8S07Z[<P1e[b/0MZdS0080N:dP02L0
OJ`K07J^801a/280L[<N076a701_/1L0M;4D07b_4`1o[aD0PJlC08B]4P27[Q80P:hC07n[501nZa<0
N:PD07nY6P1oZB00PJXN086Y8@1jZ240M:LP07NV901kZ2H0PJPU07nQ;@27XB/0RYX^08:I=01dVc/0
L9lg06nH>01[X3D0I:4g06V`=01/^RX0Jl0Q06c4701d`1P00P1h`1L09`1j`1/0Ml0Q07G08@1e`240
N<0U07[0:@1l`2H0Nk8W07[08P1f]bL0LKH[06jl;`1d]BX0M[4Z07:c;P1b/c00LkPT07Bi8@1e`1X0
M/0D07_04P1n`1<0Nl0D07G1501e`aD0LL@E07?35P1b`QP0L/4G06o16@1]`2<0K<0]0770;@1/`S<0
KL4`06g0=`1]`2/0L/0P07fh4`0208N`2P0W08b_1@2;]0/0P[LH08:h701l]B@0NkXM07Jc;@1][Sh0
LZY606faB@1V`400IL<m06Zj@`1XYeL0JiUO072>H01eSEh0NI9N07N>G@1kQEh0PGiR07egJ`1dM6/0
Jg1^06AlJP1NTFP0K:]C08N]?P2PTSD0VX/n09^5A02KQT80ZGTf0;Ib:P2iMBd0^G@i0;Ab@02bNTP0
]85@0080XiI901l0SZDn086X702?W`l0TIH009>B002HS000Uhd009R?002FSP00U8d009B<002>S000
SHL008f2002<PP00ShD00927002AQ@00Sh@00966002@R@00SHP008^6002:R@00Q8D0089n0020O@00
Oh<008200021Q@00Q8X00080OH@000H0OX400823001oP`00OhD008F60022QP0207Qo0008079h001_
LP00KFl006Ye001]M`00KGH006ia001]K@0206Y[000M06QX001XJ`00J6T006MV001ZI`00JVX006]V
001VH000GeX005mH001PE000GUD005iD001ME000G4l005M:001@A000BC`004Hl0016>@00ASX004@d
000k;`00>2L003DX000e9P00=2H002hQ000Y7@000P0Y6P002@0U6@008QH001X?000F3P005@`00149
000?20002`@00081000G00000003004000000000000001T00000303oool000X0oooo01@0M9T007:I
0@1hWPH0Mj4707VN201hY@`0NZ4@08ZO6P2<X1P0T9/G08jM6028X1@0Pj@D08>T5`23XaX0Q:<K08BQ
6`23W1P0PiXJ08RI5`80Ri`K02L0SIhJ08JO6P21X1/0N:DM07NU8`1eZAh0MZHD07JT3@1cX0X0LYh9
06VP2@1NX@/0Ej0A04jP5P1;XQL0@ZLP03JV>@0WW5407heT01n3KP0KRW806IAg01FQN`0CXHD04Z2B
01:RV`0CXi/04YnC01:GRP0DS80068Ak01QkO@0HTG/06j9f01jVL@0PXGH089Z2022=S00MNI@00P0N
FYP09`0LDIX07UNF01mXTP0QKh`09GR902MnR`0UR8/098n:02BERP0VT8`0:8N:02J5R@0WS8P0:Y27
02VHQ00VXH009:Qf026/KP0R/FD0:JmP02b^F00][T/0<k8l03bd<`1<]2D0G;HM05fg701L]1l0GK<R
05Z_9@1I[RT0G:h_05^]=`1I[400EZe705^ZA`1KXD`0G9Y;05bJA00205nL?P0W06:N<P1XX2l0KYl`
06Ra9`1P]ah0G[`M05bh7@1K]R<0GkDW05jd;01L/S@0FkDh05fg<@1K]BX0G;DW05^c;@1J]300G;<e
066c>P1W/2`0MjhI08B]5@2D[180Uj/C09ZY602NYQT0WZPI09nP5P2TWAD0WY/J09VG6@2MSaT0VIPK
09ZN7`2IV1/0RZ0N07b/:P1h[RL0LjdS0080MjhM02L0N:dH07R]7@1g/240Mk0J07J`6P1c[QP0MZdE
07j^501o[A<0PJTD086Z5P28ZQL0QJTG08:R6@26X1d0OJHH07fS8P25YbD0RjLL08>U7P22Xb00OZ4S
07fP9P1lYC00PZ@[086O:@27WbT0PiX_07nT<01gYC<0K:L`06FS<@1X[Rh0I;HZ06Jj9@1Z`1l0K<<H
06k35P1f`1P00P1i`1L09`1h`1L0M<0L07C07P1d`1h0N<0P07c09@22`240P[TN07c07P1e`2H0L/0Z
076h:@1f^R@0N;PT07^i8P1h^1d0N[TH07S05@1g`180NL0B08304P20`140PL0D07g0501l`1@0LL0D
07?05P1c`1P0K<8I06[0701/`2@0Kl0a07;09`1^`Rd0K/</06c2<@1^a2H0LL0L07fk4P0208Ve2P0W
08j_0`2=]0P0PkT>08Fj5`22^B00Pl0I07ji:@1c]c@0LZm006bcC01W`4@0JL1306fbCP1]Vel0KI1T
07>5H@1bRU`0L91J07B@E@1kR5/0Ph5S08=lH`1gN6H0LGIT06F3I01UUEd0MjU709^M>@2gP400`G=4
0;IbA`2aN500Y6a:0;1R=02dL3T0^G=50;M/B@2cMTd0ZXU@0080W:5200P0TZlZ08nT502BW@L0U9L0
09F=002DQP00TH/0096900<0Th`001`0THT008b50029OP00Q7/008Mi0028OP00RH8008Z4002?PP00
S8<008V00026P000QHP008240020O@00OG`007aj001nO@00QHD00825001oQ@00Oh4007io001oO`00
O7l007in0020O`00OWh00P1dN`003P1_M000J6T006ER001QHP00HfL006IY001YJP00J6/006M[001X
J`00JF/006E^001UK@00If`00P1/J0001P1]I`00J68006AM001UF`00H5L0061F0080GeH000l0GEL0
05QA001DA`00DD8004a1001:?@00Ac`004@f000n<`00>BT003@U000`8`00;b<002/M000X70000P0T
6@002@0P4`007A<001X?000D3`004@X000/600090`0010800080000H000000030041000000000000
01P00000303oool000X0oooo00h0MI@007ZG001hVP00N9d007NL001gW`T0NIh907bK2`2<WAD0SYTG
08jJ5`27W1H0QIdG08ZO6080RihI00@0S9XI08ZF5`2;UaP0SITK0P2?W1l09`2@Wah0Q9lI07jT601g
Z1P0NJXG07NZ3P1iXP`0NIX:07BF2P1`U`/0HI`;05FO4P1:WR40AY`Z04>R9`0nYbX0=JLg02bVA@0S
XU@07iiM01bPG`0KXf<05j=X01:QMP0CX8H04Z>B01:WU`0BXi@04Yb>01JHP`0HU7`079Ag01fNN@0L
Y7X07jIh026NO@0RU8T08XN?01ihUP0201mRVP0W025GV`0PG9T08FVB029dS@0TP8`098NA02B>T@0T
TY40:9>@02FCT@0[S8X0:HN602^=QP0/U8H0:ib602RTP@0WZW009k1Q02ZcF00]/5L0<JiD03:/B00i
/C40@KHS04jg6P1L]aT0H;DO062d9@1O/2P0Fjl/05f^<01K[cT0Ejm005J/B01GZTd0G:a:05fTB01M
X440H:4h0080HjL]02L0HJdU066`901Q/R<0HKDH05ji5`1M^aP0G;TN05fh;01P]C40F[<c05Rd?P1F
]d40EKPh05Bd<P1C]S@0E;@l05Be?@1D]Sd0Fk<n05j_<`1][B00O:`H09>Z5@2OYAL0Y9TI0:BJ702U
X200XZ0G0:JO6@2VVa`0X9PJ09fC6`2OUa`0XI/M09VB602CWA/0QJ`R07f_801e[Al00P1f[A/09`1h
[QL0MjlH07^_601l[QP0NJlI07J`6@1g[QD0O:h@07f]3P28ZPd0Pjd=086^3`1mZA40P:DE08VS6020
YAL0OjHN07j/8@1o[A`0OJTM07VU8P1kWBL0OI`/07ZP<`21X2l0Qid]08JM;01nWC<0OJ8b07NQ=01]
ZC00IZd^06_0:01Z`Ah0Il8J06k05@1c`A00M/0A07_0500207W05P0W07Rk4@1b_0l0Ll0D07?06@1i
`1X0OL0M08C0601o`1X0O<0L07Bi7`1i]Ah0N[HT08>h701o^AP0O/0E07c04`1n`100OL0A08;04@23
_140QkX?082j3`24`140P<0C07g04P1d`1@0L/4C07325@1]`Q`0I<8R06W2;01/`380Kl8X06_4:@1`
aBL0KLH[06o59`1aa280N/4D0080Pk/=02L0SKL6092f1@2<^@P0RkP@08Jj6P24`1L0O;XR076j;@1a
/cX0K[A906ZjB01Z[T/0Lj5@07ZBE`1cRE`0K85O06R1G@1YQ5X0LH9H0821F@28PU`0QH=O07j2H01a
P640JhQL06nEDP28Y3/0YYD^0;J0:@2nMC<0_W@d0;Q^=@2eHS`0]e/m0;=Y>02aL3l0[Ve70:QfC@2L
Sdh00P2:/3809`2?[QX0Ti`909NG0@2DUP00TI<0092<002>R000S8T009:;002CR`00THd008n6002=
O`00RGd008Ef0024MP00QGT008Ak002;OP00RX8008R00024P`00Ph8008J50024P@00OW/007ag001i
N@00Ng/007Z0001nO`00P7d007eg001mM@00O78007Qa001hK`00Mfh007EZ000206i_000W06a[001W
I@00HUl005YJ001OG000H6L0069X001PJ@00I6T006=Y001RI`00HVX0069V001SI@00If8006YT001[
H`00JV8006EP001VGP00HU`0065J001MEP00FUH005aH001IE@00Edh005A7001=A000BT<004Ll0012
>000@3D003P^000c9@00;R@002/R000[7P0091T0008081H000P07A8001T@000E3@004P`000d70008
10001040008001T0000000<00@000000000000006000000<0?ooo`002P3oool0501eU0<0MYL107NI
001hW@00MYl007>N001dWPH0NId707bQ3`1nWa40QilH08JQ602;WQL0RilF08ZR602>WAX0Si/F092F
5@2:UaH0S9lG0P2;Y1L09`27Xa@0OjDE07jZ4P1jZ`d0MjT907>T2@1eW@T0NIP707VF1P1_V@T0I:4;
05NT4`1:YB40@j8[04:U;P0nZc00=J`h02b^@P0T[Th08:]A01b[D`0JZU@05ZUI01FSJ@0FXG`05:J;
01B[S`0EYi805:2D01NLRP0IX7l07j=j01fUNP0MZW`08:Mo02>PQ00QTH`07hBB025hU`0202EZV@0W
02QKVP0VH9P086fD021kS`0RQ8l098fB02>BTP0STiL09IBG02FDU@0WTXh0:Hn602ZBQ@0[UhL0:in2
02VXO`0Y[VT0:k9I02jdC`0a/dd0=[1<03V`@@0o]BT0B[DM05Jd701O/b@0Gk8[066`;P1R[Rl0HJ`a
062Z=01O[Sl0G:a205NYB@1JZ4P0GJM105jT>`1OY3D0IZP^0080Ik0R02L0Gk<M05^f7P1N^A/0Gl0H
066k5`1T^A`0GkTS05bh;@1O]C00FkHc05Rg>@1C]S`0DKDi056d=`1@/cT0C;Dl05:c>`1B]S/0F;<o
05f`>01X[R<0NZ`H08nW5P2NY1L0YYdI0:NH7@2WW240XidL0:JM6P2TVQd0XIDK09f@7P2QUQ/0XiLM
09fA702CVaX0QJPM07Z]8@1d[Al00P1a[A/09`1fZQ`0NjTM08BT7@24Yal0OjhL07R`6@1g[AP0P:PI
07fX3`27Ya80QjXG08BX5P1oYQL0P:DK08jW7025XaX0P:8U07bY9P1nZQl0N:PS07>Z9@1lW2@0PI`Z
07bU=021YB`0Pj8W082R:01fYC40MJX_07:^;`1`/R/0L;<W07307@1]`1P0K/0D07?04@1j`0l0Nl0A
07W0500207_04P80M<0=02D0ML0>07[03P1k`0d0Nl0>08?03`1j`1<0O;TD07Vh4P1j]a@0Ol0I0870
501n^QH0O/0E07g04`20`0l0O/0>08;03`23`0l0Q<0?08>j4025`140PL0A07g04`1e`1L0L/0D06O2
5P1S`240H/@/06O6;@1ZaC40K/H/06_5:P1``Rh0L<0c07;2;`1b`2T0M<0H0080Nl0A02L0R[H:092c
0@2>]P@0SkP:08Rh4@1n`1D0N;/R076m:@1`]CP0K;E4072_B`1`Ve80N9ED082?EP1^ReP0JH1M06Qk
GP1UMEl0KWYN081nF01nQUd0OXYQ072@F`1[U5P0LYM=086I@02HTST0YXDa0;5i7`2gO1X0_GLJ0<UY
5@3BHbP0eUXn0;MP?@2ZHSh0YVe;09ilCP2=STL00P25/2L01`2=Ya40TYD309JA002FT`00UI@009:=
002=Q`000P2@Q@007P2?QP00T8P008j8002>PP00Rh8008En0025NP00Q7T008=h0024O000Pg`008An
0028O`00QX8008Z3002:P@00QWh008Mk0022OP00Ogl007ml001oN000P7<007]b001hK`00LFT006aO
001^GP00KUl006QP00<0JVL002H0IVD006EQ001PGP00FUX005]M001MG@00G5l0061R001QHP00HfH0
06=W001SI@00HF4006AN001XH`00JVH006YY001XI@00I6D006ER001QH000GET005aG001MF000FUP0
05QC001AB`00CdL004]60019?P00@cT003ld000f;P00<RD002hR000/7`009ah002DH008071@000P0
6Pd0018<000?2`003@P000T6000710000`40004003@00000303oool000X0oooo00D0M9H007BK0@1a
W000LYl0076P000207:N000=07>P001cY0X0MJ8:07NQ2P1oY1<0Pj@B08:W4P23Ya80QJ0E092K6@2?
VaP0Ri`J08JS5P0208>U5@0W07bV4@1kY`d0NjX<07JX201cY`L0LZ<707FP1`1eW@<0M9h406fR201Z
Y@X0GjL=056W6018YB80A:L[03fY<00eZcL0;:a302BVCP0PY5<06Z9F01RUD`0GYU806Z=L01RNK`0I
Xgl05jF701JTR`0FX8h069b:01fROP0MYWL07ZUi01bYP00NZ8D07Z29022>S`0PQ9<08gjC008097VG
02L0:W2F02McT@0QOXd088B<02>8SP0RSY408I2A01nBTP0RTXh099>802NDO`0XU7`09iUm02^MN`0[
Y7P0:JUc02Z_HP0^]5H0<KI903Fe@00i]3l0?kDf04Zg:01E]R80F[@V05bc=01K/C/0GZlh06:_=P1Q
[3D0Gj`i05j[@01MZ4P0FjE805fXA@1QZS/0HZda06B^9`1U[b400P1Q]1L09`1L]1L0G;DG05nj6@1R
_ah0I;PQ06:f9P1O]bL0Fk@]05Nd<01E]c40E[Le05:o<`1A]SX0D;Hk04jf>@1?]cL0DkHi052e?@1E
/d80Fk<o06B_9P1oZQP0SjHE09bQ5P2UWa`0[9LP0:nA8@2XUaP0Yi/H0:^B6`2XSQX0XhdK0:N@702[
SA`0Xi@M09VJ7027Xa`0NJXN07F[7P0207>/6@0W07B/5P1lZ1T0Q:@L08>V701kZaL0MZ`E07N]6020
[1L0OjT?07fW3`20ZQ`0P:PK07VU6P1lZAX0RZXL07jT7`1gYRL0MZXU07VW8@1gY2H0NilV07^D9P1k
UB`0PIlc08>U;027X240O:0/07JM=@1cZS<0LZl^076e:@1`_RD0L/0O07;0601d`1D0M/0B07[03P1j
`100M/0A0080Ml0A02L0NL0@07[03`1i`0l0PL0=07o03@1o`@d0PL0=08:l4023^a00OKX@07fh401l
`140OL0B07g05@1j`180OL0B07o03`20`0d0QL0<082j301o^Pl0O<0A08Bh3022`0`0Ol0B07C05@1[
`1L0H/0I06;0801T`RX0J<8V06S5;`1W`Bh0Hl4a06S0=P1[`4@0K<0f06k0;P1d`2000P1l`1@09`2>
^0X0Tk0009>a002>^@H0PkT907[04@1``200Kl0Y06ff=`1]]4D0LZY@06nKF01aUe/0LiIH06nHD@1c
Te40MH]D07:0F01gQ5D0NHUF07R;FP1cU5X0IJa?06JfB@1m/CL0TY`d0::4>02XOC/0[7/h09j2=02S
ORl0_7<F0<UY8P3DHcD0]Um20:YSC@2YL4l0Uh9C07jK@P0208B[6P0W08fO1`2AU@40Si@008jE002@
UP00TI00096>002?Q`00Rh0008Qo002=PP00Rh@008b3002<O`00Rh0008ao002:O000RG/008Mk0026
N000Q7`008Uo0028P`00SH4008^20028O@00Q7d008Ei0022N@00PgD007i_0022K@00O6`007EZ001a
I@00Jf4006]L001[F@00KE`00080KV<002L0K6D006QY001VIP00HV0005mK001KG000G5X005eL001K
G000G5T005eP001SH`00GfD0065N001OF@00HUX006=N001UH@00Hf4006ES001TH000HUd005iJ001K
E@00FUH005]G001DD@00DDX004i4001:@@00BD0004<i000m=P00>Bh003<X000]8P00:ad002HK000T
6@000P0J4@001`0C2P003PL000/500060`00108000<100010000=@00000<0?ooo`002P3oool0501`
VP00Kid106fM001/W@00LZ0007BO001fX@00MYl007BP001gY0L0N:@807bX2@1jZ0T0N:T:07fV2P1o
Y0X0RJ<E08JT5@26YA@0Oj/D0P1nZa409`1jZ@d0NZP:07VU201gYPP0LjH907JS2P1eX`X0LYl8072P
201bX@P0LJD806NW2P1HZA00CJXK04:X:P0nYcH0>:Lk032TA00VWdl08iYI026FG`0PXU/07jEF02:R
E00OWF8079m_01bPMP0JWG/06IYm01VHP00JW7l06imo01bPPP0GXh`06:F@022OT00OU9@08Y6B02><
T`0202B;TP0W02N:S@0SSHT08Hn602:>Q`0UShX07hj;022@R@0MTXL08I>402>BN`0UTgD0:IYc02VO
L`0YXgH0:JI_02VZJ@0/[el0;[9E03:eAP0f^C`0?;Xe04Ji<01?^2/0F;DV05bb;@1G/ST0E[4n05j^
?P1T[Cd0HZ/l062X?01OYSl0GZHn05bT@01RYcP0I:h[06>c8`1M]Qh0E[LH0080EL0F02L0EkXF05Zi
5@1Q_QL0IKTS06Bh:01R]R/0F[H^05Re<P1@/c@0D;He05:g<P1B]C@0D;Dm05:g?@1@]ST0DKDf04jc
>@1>/d<0D;A605Ja@`1Q[BT0MJlD08nZ4P2LXa<0XJ4E0:RI702cSa/0ZY<J0:JC702[SQX0ZX/I0:>3
7@2YQb00[8/P0:FD8P2JV1d0Si/Q086R8P1iYQh00P1dZAl09`1mZ1h0OZPK08:U702:X200OZ@D07:U
701iYad0PjPI086W3P22ZQ40Q:TJ086W6@1jYQ/0PjTH08^Y6@1mXa/0MJXW07:Y8`1gY2<0Mj<O07RM
8@1iVBT0OIl_08:Q=022Y2l0NZD]076Y;P1^Zc40L;8`072f;@1/`2H0KL0R06k0801d`1/0N<0E07[0
4@1j`1<0M/0D07C04P0207^i4@0@07^f4P20`1<0Ol0C08;04P24`0`0Pl0=08;03@21`0l0Pl0@08Bj
4023]`l0OkP@07Zi4@1k`140O<0?08Bk3P80Q<0=01D0P/0;07k02`1l^Pd0O/0=086i2P21`0`0O<0D
07?06`1/`1h0GL0R06?08P1Y`BL0J<4R06G39P1Q`RX0H<0a06?0>01V_4<0J<0f06[0=P1b`2<00P1m
`1D09`2B^P`0Uk0009:a002<]080P[L607g03@1d`1X0L/0T06jg=P1_/T80LjM806fME@1_VeD0Li]D
07NGE@22Ue@0QhmD08>9E@1iRe00NY1<07^FB01^Z4H0K;`k07K0=P24YcL0TIDk0:j0>@2hN400^g93
09imC02AOdh0[7TX0;ae7`39JbD0/f=30:]RF02aLe@0VhM>082V=P0208BU4`0:08^I0@2<U`00RYD0
092D002?TP00TY0009>?002?R000S8D008Yo0080Rgh001/0RH0008Z0002;O@00Rh4008]n002:N`00
Qgd008Ii0028OP00RGh008Z3002>PP00SGl008Um0022M@00O70007i[001lJP00NFL007MU001cIP00
LV40071V001]I@00Jf0006aP001ZG0000P1_GP00501]H@00JF@006EQ001UF`00HV8006AT001SI@00
Hf00065N001RGP00H5h0061M001MG000FUD005UF001HF000F5T005UI001NF`00G5X00P1KF@004@1L
F000F5@005AF001DD@00EDl0055;001?BP00BdD004]20017@000?cT003d`000d:@00;B4002DJ000R
5@006a80008050`000@03@L000P300070P000`800P01000f000000`0oooo000:0?ooo`0D076I001a
W000KIl006jM001eX000Mj0007NU001cY@00MZ8007VS001gX@00MZ@607>T101cY@<0MjD807VR201n
Y@h0O:@=07bV3P1kZ0l207VV2P0W07ZY2@1kYPP0Mj@:076U3@1cX`d0Lj8<07BP3@1cWP/0LZ0:07NO
2@1eX`L0KJ<805fV301>YaL0AZHX046U=00jYS/0<:A602NID00SU5d08hmW02BII`0TW6808i]L02:I
G@0PVVL07YU^01jCK@0MTg006YEg01^HO00GVXH05iV801RKSP0HWY4079fE01jJV@0NVIP08IRD0080
8YVD00`08Yf9026OP`0QW8008I>2026AR00OT8X07Y2601fDP00TV7`09YQa02VHJ`0WWV`202NTKP0I
02RVIP0XZV80:k9H02jcDP0e]T80=kPd042i;P19^2L0E;DY05Zc;P1J/SL0F:m005^^A01P[TD0IJ`o
06J/?`1SZC/0HJDk062V=`1TYS<0I:`U06N`6`1X_AT0HKdE05fm4`020630500W062h4`1Q^aH0H[XN
06>g:01O]Rh0F[Hb05>e=P1<]S`0AkDm04Ne?01:]CP0Ck@h05:d?P1B/d00CK8n04^`?P16/D@0B;=@
04^bC`1A[4T0Fj`/06n_5P2<ZPl0W:8@0:6M4P2VVAH0/9<E0:FB702NTAh0ZhdG0:J:6P2SPb80YXPR
0:Z>7`2XTb80Xi<L09>K7@22Xal0MjLS0080Mj/T02H0NZdQ07ZY8P23Yb<0RJ8N07fO6`1eXR40M:@P
07JX701e[1H0PZPG08:V7@1lYQ`0Nj@L08BS6P2;X1H0N:@N076Z:01aZB<0NZXU07ZP;01lWBL0Lj@a
07NW=@29WS<0O:<c072T=P1Z[C00K;<`06fi;P1``2L0K<0N06jo6P1]_aT0MklJ07fo501l_a@0N/0F
07_060@0Ml0H02H0Ol0G08C06026`1L0P[XE08;04`22`0l0Ol0>08303@26`0d0Q<0=07k03`1m^Q80
OKTA08Fi3P24^Pd0Q;h<08703@21_Pd0P;`>082j3@1o^P`0P[T>07g04`1i`1@0Ll0F06c06`1V`280
J<0R06O08P1V`Al0Gl0T0630901P`2d0Gl0b0630?@1T`C80Il4_07708P80Nl0G02L0S[/:09Fe002G
/@00Tk80092g1@2;`0h0PL4K07g09@1e_3D0L[I307BWA01`ZD80JZa506Z[B01`WTh0NIQ@082BDP1l
Te80KYQ:06fQ@01[/SD0LKT_07Rk;P1m]3<0RI`l08n=@@2/PC<0^7Xf0<1c>@2aL4@0YVm40:ae>@2g
Kc<0_78_0;QZA@2_JU40[7A;09>FA@25ZR400P2=W1405@2:S`00RXT008j:002<R000ShX008j;002<
S`00T8`008b5002:O`00RH0008f2002;O@00RWl008^1002@P`00T88008ao0027O000Q7D008Af0002
08Mi000@08Mk002:OP00Qh<008Eg0020K`00OVh007a]001eI`00L6D007=T001dIP00LF`0071[001`
I`00KfD006]Q0080KUh002L0KF0006]L001YG000IUP006EK001TIP00JFL006QY001YI000Jf<006QT
001YI000HUd005iH001KE`00FEP005QI001GF@00EEH005QE001GD@00Ee@005MC001BD`00DDl0051?
001?C`00Cd/004e8001=A000B3l004<m0011>@00?CD003@/000[7`008QP001`B000E3@000P0<1`00
10060P000`4000800002000h000000`0oooo000:0?ooo`0A07NC001dU@00LYX0076K001fW`40NJ<1
07JV0@1eY000MZ<007RR001gX000LJ<0072V0P1aYP80MJD707VQ1`1jX`L00P1hY@L0:P1iY`L0Nj@7
07^T1`1hX`P0MZ0807BP2P1aWP`0Kih;07:I301cVP/0M9`<07RK201jV`L0NI/2076N0`1RW`X0F:4C
04jS9@16YC<0?jDi03:RA00ZUU<09XaS02B2J@0VRV/09I1U02FBI00TTFH08iE[01nHK@0PUf`07iM^
01jHM@0JVgl06I^:01VKS@0HVHd06IZ@01VJU00JViX06ibM01^KV`807IZG02L07If>01jOQ`0PWH@0
8IJ602:DRP0NU8h079N<01jMQ@0TX7d09Ym`02ZLIP0YWfP09j=[02JTJP0XY6H0::UP02b^F`0a/e80
=kI103^f=`13]S00CKDW05B`:P1H[SD0FZ`n05b[?`1O[440I:e006R/?01SZcP0Ijdc06J];P1V/RD0
IK4M06Bb5P1U]Q40IkdA06Bg4`1P]AD00P1S/Q/09`1P/Qh0H[8V066a:@1M]2l0Ek@d052c>P16/T40
AK=504BcB015]d40B;Tm04Vc?P1;/T40Bjm704^_B@17[d/0A;9?04FcF019/U<0D:e<05R/<`1[[a`0
R:PD09VM402MUAP0XY<B0:RD3`2OT1`0WXhM0:R@5P2RR1X0XH8R0:J:8`2YT280]H<N0:b<6@2HVaT0
R:DQ08JW8`0207f[7`0W07Z]7`20ZbH0QjLU08:N8P21VR<0P9dU07:P9@1fYBL0PJLO08FV6`23WAd0
PJ4N08FR7020XAP0Mj8P07bU8@1mXQh0NjDN07RW8P1gYb40N:LQ07ZX:`21YRT0RJDW07JW<P1WZSH0
H[@c06Fj<@1^`300M/0T07Bo6P1d^QL0N;`H07_05`22`1<0Ol0G07o06@1o`1L0P<0F0080O<0E02L0
O<0G08;06@23`1`0PKPL086h6`23^1P0Ql0A08C03022`0/0PL0<08303`1n`140OkTC08Bi5027^Q40
Q;`=08>l3021^Pd0PkX?07o0401n_@h0O<0=07bk501h`1P0N/0F07K05@1b`Q`0J/<Z06S18@1T`240
IL0R05o0:@1P`2D0H<0Y06;1<01U`CL0JL<]06[1:@1b`1h00P1e`1d09`22`0`0S;X209Nf0`2F]`X0
U;`:09305025`Al0Ol4P07K0;P1a^3T0KJi206^`?`1V^3P0HkPj06Z]@01cYDD0OIe407ZPA01_YSd0
JK4c06jg:@1e/R`0OJh`07nR>P2;U4<0TXI40:]m<@2dO2l0]gPW0;m/=030H440/eM70:mSBP2gKd/0
]V]>0;=YD`2ROT`0SiLe08FQ5P02096E2`0R08f90028P`00RX000921002=P@00S8L008b6002;QP00
SH8008b10028P@00Rh@008b2002:P`00RX@009B;002BRP00THT008f4002;N`00QWL008=c0024L000
PFl008=d0025N000PgH007ie001lLP00NFd007I/001`I`00M6H007MX0080MVd000<0LV`0075X001c
J@000P1cI`005`1cIP00KV0006]G001VF000IEX006QT001YI`00JVX006]Z001[J000Jg8006a^001Y
J000I6<005mO001JF@00FU/005]L001LF000F5P005MF001AD`00DDl00080CDX000h0CdP004e;001<
AP00BTD004E30010>`00?3D003Xb000h<000;bP002LN000K5P005Pd000h900801`<000<00@000000
00000000>@00000<0?ooo`002P3oool0501fT`40MI8007BG001cV040MIh307RM0@1iW`40N9h007VO
001iX@00MZ4007JP001eXP00Mil007fK001mV000OIX007jP001nXP80Nj<80P1jXPT09`1gX@T0Lj09
07FO2@1aW`X0LIX:07:G201bW@P0MIh707VP201gX0P0N9h807:M2P1[W@`0H9hB05JO7P1?Xb/0AjLf
03RPA@0^TED0:XEW02UhK@0VNVl09Wm]02N4K@0UR7009Xmd02:FN00SVWD08iYh026IO@0MVX406In7
01VRQP0HX8H069b801JESP0GTiL069>I01RCV00201ZCT`0W01bCT00PU8d08IN<01nCS`0NT9@07I6G
01fGUP0MWXd08J>102BRM00YWf/0:9iX02NQK@0WXVT0:J=W02VXGP0^[E`0=;AB03fg@P11]CT0Ak<a
056`:`1IYS40G:@l05jW@`1RZd@0Ij`m06VY=`1W[2h0Ik4/06Vc9`1^]1`0K;DH06Vf4`1W]Q40J;LB
06Vg5`1W]Q`0Hk8Q0080HJhU02L0GJdX05b[<01J[CL0E[0j04be?P16]T40@KA2046dA`12]dH0AL0n
04G0>`19]cd0B;A304RcC@14/U40@K5D046dE`14/eT0Bk9;05B^?`1K[Bl0IZ/S08JT5@2IW180WI0P
09Z@4@2XSQ00X8HR0:J98`2YTAP0XHLO0:Qn:P2YR280ZhlR0;>8802RSQT0SiPN08VR8`24ZAd00P1g
Za/09`1f/1d0PJdR082Z8P21Wbh0PYh/08:O8`1jWBX0OYdZ08BS8@24Wah0QIXT08NJ8@28WA/0NIlM
07:U9`1oXB<0R:0M07nM901lXBL0N:8O08:S9@25Xb<0S:@P08bQ8P1kY2d0KZTb06Nb<01[^Rh0K/0Y
07C08P1c^A`0ML0H07G05`1j`1T0O/0F07o06P1l`1P0P<0D07o04`0208304@0P08705`21`1l0P<0G
08305`1n^QD0P[DA08Fi3`24`0`0P/0=07g0401m^aT0O[HG07ng5027^A<0Q;`A08>m4022^0l0PKT>
086n401j`140Ml0A07C14P1c`1L0Ll0O07?25`1a`QL0L<<P06c2;`1Y`B80Hl0Q06;09@1N`2d206G1
:00506S2;@1T`cP0K<0^07308`1d`AP00P1d`1409`1n_@X0Rkh809Rk2`2E`0`0TL4H08c07P27`1d0
Pl8K07_57@1a`bX0K[Xk06W0=`1X`380J<0`06W0<@1/`2/0LKPT07Fi9@1d]bL0L;8[06j_;P1a[c<0
NJXb082P?02<V3d0Uhe20;9n?`2dNC/0/gL_0;U_;@30GCT0^UA@0;=IGP2_IV@0Z6UK0:5/E@2=PE<0
RIH/08RB3P0208^90P0W08^2002;O000Rh0008b3002>P@00Rg/008Yl0029OP00Rgd008Yl002:OP00
S7h008V0002;P`00RX<008j3002>Q000Sh@00964002=P@00Rg`008Yi0022LP00PF/007i/0022L`00
OWD007]`001iK000N6d007I^001cK000MFT007Q/001eJ`00MFh007AX001dJP00Mf`00080MFh002L0
MVl0075S001[F`00IEL006MD001WFP00If0006MV001YJ@00Jfd006ed001_L@00KVh006Y/001XI`00
HFL0061V001RHP00HEh0061L001JEP00FDl005I=001BB@00D4X004e9001;A`00BTP004U70015@@00
@SX003de000h;`00<R/002/R000Q6@006@l00189000:10000P03000l000000`0oooo000:0?ooo`0D
076I0`1_V040L9T107>J0P1dVP80MIX107VJ001lV`00NY/007VM001hW`00N9`007ZK001lW000PYX0
08:I0022U`00Q9h1086P1P1oY0/207bS300W07RQ301bXPX0Li`907>L2@1dV@L0M9X607BM101dXPL0
MJ@807BU1`1bY0P0LZ0906nP2`1WX0d0GZ8G05JT8P1;Xbd0@:4m03BHC`0aRV80:ga_02EeM@0WMG@0
:7Ye02R2N00VRWd08YB001jIP00PVh007iR601bFRP0HW8/06JB901RRQ`0IUhP06HR:01R4T@0IPiD0
6H>C0080686C02L06gjC0261T@0QR9L07hbI022;V`0KSJ007IBJ01fLT`0OXHT08j=m02JQL`0WWW80
9:5d02NRJP0ZY6L0:jUQ02n]GP0k]500@KE304Nc=P1?/Rd0F:l[05jX<@1PYSH0IJXe06Z^=@1]/2d0
KJlQ06^a6@1/]QP0K[DH072e4P1]/`l0JkD=06Rh4P1X]aX0IKLV06:c:`1K[S800P1MYSD09`1KXcD0
Ej@l05J[@01@/440AkA2042cA`11]DL0@KI804:j@`15`3h0A/0j04Ri>P17]T40A;E8042dC`12/EX0
@;9I04RbDP1=]480F;0e05f`:@1X[RD0QJPH09FM5@2NRQl0VXXD0::<5@2PPRH0YX@S09f=602QQb40
[W`Y0:N86`2VSR40/hTU09^:602>SbX0RI`T08BV6@0207RZ6`0W07fZ8025ZQ/0QJHP08jN;`27WRX0
PZ8U08BM;P25X2L0PJ0R08RN8@2=Ual0Q9dM08NN7`1oX280NZ0T07fP9@1lY2@0OJ4R07^R7@1gWb80
Oj@S08bS8@2>XR80RYTZ086S=01gZcL0M[@/07O09`1e^B80M[HP076i7P1f`1d0Ml0J07[06@1m`1L0
Ol0I07g15020`100P/0B0080Pl0B02L0Ol0G07g07`1m`1H0O;TF07Rd7P1j[al0OKPC08?03P1m`140
OK/I08Ja8P29[2<0PkHE08>i4P23_A40P[PE08:g601o]aX0OK/G07S06@1g`1P0L<0I07?07`1c`BT0
LL4P06[06P1Z`1l0JL4V06S17`1R`Ah0H/0V0630;@1V`RD0I/8W06[2:01W`3<0KKhZ06k08P1d`Q<0
0P1f`0`09`1n`0X0RL0<09Bm302@`AT0RL8S08S28P2:`B80Pl@L07g96P1gaQd0LL<U06_19@1_`b@0
L<DR07C38@1c`ah0M<4M07S07@1f_2D0M:l]07FV=01cYcP0OZLg08JP?02<UCl0V8Y60;Eo@@2hM4<0
]VLn0;Ea;P2kIbX0aU]80;YNFP2/H6X0WFEV09I/G021SDl0PYTW08J7200208In000W08Mk0028NP00
Rgl008^2002=P`00RX0008]i0026M`00QGH008Af0025M`00R7X008Qm002=OP00S80008Z20029Q000
Sh0008n2002>P@00SWh008Ie0022L@00PG80085c0020L`00OVl007U]001hK@00Ng8007]c001iLP00
NW8007]`001kK@00N6d007E[001fJ000Mf`00080LVd000/0LF/0079W001/H`00J5`0065@001NC`00
G4d0061D001VH000Jfh006]a0002075b000J075e001`LP00KgD006aa001ZK000IfL006IQ001TI000
HUl005aI001ID`00EDl0059<001>C000BDH004Q60018A000@C`003Xb000b:000:b00028J000N4@00
4PT000/60006000n000000`0oooo000:0?ooo`0D07BI0@1bV@40LY`107:L0P1fV`80NI`107NG001j
VP00NYP007VI001lW`00O9`007fM001mVP00P9H0086G0022V000Pj0308>N2P20X0/207bT300W07VT
2P1aY0`0L:0;07BM1`1gWPP0Mj0:07:T2@1dY@L0LJL7076T201`YPL0LZ8806jQ201WX0T0Gj8@05NR
7@1<X2`0@ilk03bOAP0gUUL0<HEX031hM`0aKW`0<6im02ecO00YOWd08XZ101nAP@0OT8<08Hj301n?
Q@0KVHD06J6501bQQP0KV8D078V901b4S00LPhl06h:@00806X2>02L077b@0220T`0OQIL07hZM01j<
W00PS9X07YFH022LT00PXXD08J=m02BQM`0SXG409J=`02ZSJ00]Yf@0;jYL03J_DP10/TL0B;@i056d
;01O/Ql0Hk0O06R^8`1Z[200K[0L07:`6`1d/AH0Lk4B06nd4@1Z^A<0J[/F06Vc5`1U/a@0Hk8H06Fc
6`1S/bL0H;8^05Za<P1IZS000P1IZ3809`1EYc@0DZTj05:Z@01=[T00@k5103jdA`11]DT0@[M704:i
A013_480AKa004:l>`13^3l0@[M3046fD`0o/ed0?k=J04BbD@1;/cl0EK8e05Va:`1W[bT0QZXN09BN
5P2NRah0X8TI0:F7602VOb<0WX8L09:<6P2PRAh0[h8P09n=6@2OTR00[hTL09V=5P2<S280P9PK08>U
600207jQ800W08>R801nYQ`0R:DQ08bL9`23XB40O:LV08^N:@27WB00RiLV092J902?UR00RITT09>J
9P2<VR80QYXQ086P;01nXRX0Oj0L086Q7027WR80SJ@O08jQ8@28Xb80QZ0`082[=01j[c80NkD[07S0
9@1b^B80LkHS07>l8P1h_2<0M/0S07G07P1l`1/0O<0L07c26@22`1D0P<0E0080PL0E02L0O<0D07k0
5@1o`100P;/?07nj4@20]1@0PKP?08303@1n`1<0O/0I08Jh6`27/Q`0Q;/F08Bj4`25`1H0P[TH07ji
6@1j_AX0Nl0F07Rm601f`1/0L/0N07C09P1c`2h0L/4R06o0701]`1d0JL0K06g1601X`AH0I<0O06G2
9P1Y`b00K<8Q06k38@1Y`BT0K/0U06g09`1d`aT00P1ha1009`21`Q00Rl<D09306@2=`RD0QlDZ0875
9P27aBP0QLPS08?3801l`Ql0NLHN07?77P1faA/0MlDJ07[27P1h`b00Ml8T07S0:@1d^C00MJlf07JU
>P1fWcT0P:8g08fJ>P2=T440ShY70:N7?02fNCl0^V=80:5`A`2BMT40^6i20;IZDP2^HV@0X6IT09Ed
G01kV480OiPP08>31`0208If000308]d0028N`00RWl00080SX000280R7d008Qg0029M`00R7X008]l
0024O`00QX4008Qo002:O`00Rh0008Z3002;P`00R7h008R2002<P@00Rh0008Mh0025N000PgD007id
001mLP00Nfd007a`001oLP00Og@007ee0022M`00PWX008=m0023N@00Ng<007Uc001jM000NW<00P1c
KP009`1`JP00KVT006e[001/H@00IeT005]>001IC000FDd0069I001YJ000LFl006md001bMP00M7H0
075l001bN000KWL006ec001WK`00JVP006UZ001ZJP00I6<0061J001IE000E500051;001=AP00Ad@0
04I30012?000>C0002hU000R60006a40018<000<10001`400040000n000000`0oooo000:0?ooo`0D
06nK001_W000L9d107:O0@1dW`40MY`007RK001gV@00N9X007VK001hWP00NY`007ZK001mV@00P9P0
08:K001nW@80OZ8707nP2@1nX0X207^W3@0W07RU2P1gX0T0MYh:07JP2@1iX`X0NJ4;07JR2P1fX@T0
Lj8907JQ2P1eX0P0L9d706bK1`1ZW`P0HZ4<05NS6@1:Wbd0A:0k046TA@0lXDl0=i=R03AlN@0iIhH0
=Ej503=SO@0ZLGh08gj302:3P@0SPGl09Gen02B4O`0QTH407J23022TQ00SWH809IN402>?R@0RR8d0
88N@00808hZ<02L08hZ;02:8T00PQiH07hRI022:U`0PS9808I>@02>JRP0TWh@09j1n02VPM`0XWFl0
;Ym]032RJ`0aZ680=ZYG03^^@`1;/S<0E[8Y062c701`/AD0LjhD07B^5@1f/@l0O;4?07j_3`1h/@l0
L[<@06^e501W]Q`0IKDT06>b9@1O/RD0Gk8Y05bb;@1L/S00F:lc05J[=@1DZ3800P1EYS<09`1?ZCL0
C:do04fZ@`1<[400AJm004:e@P12^4<0A;Q304>g@010]D@0@;I2042l@@0l^3l0?<1803^eD`0o]Ed0
>[AH03ncBP14]3l0B[8h05:_=P1S/300PJPS09:M602LSah0Y8XM0:J7602PPB80W84O09R96P2RQah0
[X@P09V<6@2KSad0[8/B09N;5@2@RAh0Q9TF08jP5P0208jK8P0W08bI6P20XbD0Q:8P08bO6`1nZ1`0
OJP/08VS8`2;WQh0T9HV09:H802;V200QIdP08NQ7`1kXR40P:0V07jO:@1nXR80NZ0P07bP8P26X2@0
R:0O08VK9`1oYRT0OZDa07^_<`1g]RP0MkTW07Rh9`1d^BD0MKLW07C0901i_B80NKhS07[08@1i`2<0
Ml0Q07W07`1l_1/0PL0G0080P/0I00T0Ol0D07o04@1o`0`0Pl0:086n3021_A00O[/B07^l4`1l`1D0
0P1k`1L0701m^AT0P<0K08707`21^R40P;TQ07fl5`1l`1D0P;`D07o05@1l`1P0M<0M07O08@1c`2T0
Ll0T06k07P1``1T0K/0E07705@1/`AD0Il8H06O3701Y`aT0KL0K06c17P1[`240K/0P06o09P1_a1d2
07C35P0W07g6601o`a`0R<0X08C3<022ac00O/LZ08C79@25bB<0Q<DR08318`1oaA`0OLTK07k6601o
`aP0O<<I07_16`1l`200NL0W07Jl;P1d/3<0N:Te07nS>P28WS/0RI=0096A@P2IRT<0X88l0:ih=@30
K3P0WFm908QiF02PN4/0]71>0:]XHP2PLF@0U7eI082J=P21TQP0Q7h60080PG@000P0Q7@008Qj002<
O`00SH8008V1002:N`00Q7P008Uj0080Rgh001d0S80008Z1002<P000Rgh008j3002?P`00SGl008el
0027N000QGd008Ak0022NP00PX00085n0021NP00PW@0085`0023M000PgX0085e0021N@00Pg/008Im
0025O`00Pgh007]l001kO@00NW`007Ye000207M`000W075/001]J`00K6L006]R001XH000He`005UI
001GD`00G5D006=O001/I`00K6l006ad001]MP00K7P006ih001]N000KgL006ic001ZK000Jf/006]]
001XJ@00HV0005aK001JE000E4d004a60019@P00A48004<m000h<`00<2P002@K000H4P004`X000/7
00060`000P4000800@400P01000j000000`0oooo000:0?ooo`0D06VO0`1YWP80Jil206jQ0@1ZX000
KJ80076N001cW@00MYh007:M001eW`00N9h007ZO001kWP00NYh007RO0@1gX0@0N9h707RP201lXPT2
07^W2P0W07^V201kY0L0Nil607VO1P1hXPX0N:8;07RQ2`1fX0/0Lid;07>L2P1dV0P0LIT606jJ1`1X
WPX0GJ@>05BT6019Y2X0@ZDj03nY@`0lYTT0=YiJ03>8L00cKX<0=Uf303=NO@0`Ig`0;GF202UjP@0W
M7h0:G5l02YlN`0VRGd089N102>NQ00VWXH09iZ602NBQ@0WRHP09XR;00809Xb>02L098j=02::S`0O
R9D07hNI022:T`0OSXd08I>802:IR00XVX80:Y]n02jJM`0aVVl0=9a/03FPJ`0fYUh0=jY804>_=01F
/R80Ik8H07Fb4@1i/@`0NZl:07Fa2`1d/PX0Mk<>07Nc401^/a40IKDJ05fg8P1J]B/0Ek<b05Va>01K
/3d0Fk4n05R`?01F/SH0EJdh05FY>`1AZcT00P1?ZST0201;[c/0A[5104R/@P19[ch0Ak4i04Fd>P14
]c`0@[Hm0P0o]3d07@0m]3h0?KI103ZfA@0g]Tl0>KIG03VeG`0i]ET0?;U8046f@018[d<0BZlo05n]
?020Z2l0V9lG0:2H7P2RT1T0YXLF09N58P2HRRP0XhXH0:N;802[R2D0V8PU09N68`2aQQ00WGlF08f1
9`2<U1L0SIhB0080T9TN02L0QYPF07VP8P21XQL0S:@@086V6`22YRH0R:<S08^N902DUR40TITJ08ZG
8024WQ`0OjHK07RV9@24X2`0QY/X08NK9@24W2L0QYhX08NL:P25WBL0Pi`_07nX:P1k/b`0N[XZ07Bn
901a`280M/0T07K0:01g`2L0Ml0T07S08`1l`280O/0U07W1901g`240N<0M07[06P1o`1X00P24`1X0
9`21`1T0P<0B08703023`0/0Pl0=086m4@1n_A40OkdB07_04`1f`1L0NL0K07S07`1o`2@0NL0Y07O0
:01f`2<0Ml0K07G3601k`AT0O/0H07_06@1i`1d0NL0T07C0;P1i`2@0N<0N07C16P1``AT0L<<H06c2
6`1[`QX0Jl4H06c0601]`1/0Kl4H06_16@1]`a/0KL<W06c5800206_47`0W07S7701iaAh0PL8S07g2
<P21`b/0OLDU07k67`22b280PlPS08?58P26aaP0Q<TE08O54P21`a80PL8D08;05P21^Qd0PL0S07c0
;@1k/c<0O:`g08:U?P2<UT00SX=709^;@P2[Q440Z7]80:]e?@2hM2d0[Vm109]^E@2WME<0/G5C0:iV
FP2PM5X0SH1B08>D9@21RA80PWH50080PG0002L0Pg8008Qf0029M@00R7`008Yo002:NP00RGP008Ii
0028N`00RG/008]j002;N`00Rgd008mo002?P`00SH4008io002;N000PgL0081d001oM@00OWP00863
0024P@00QX4008Ek0024N@00Q7P008Ig0023MP00Pgd008J20025P`00Ph<00864001oPP00OWl007]i
001jL`000P1fL0009`1dK000L6T006]Z001[H@00IV8006=S001NH000FUX005UH001NG000Hf4006IU
001XJ@00JV/006Y`001^M@00KGL006mb001`L`00KVd006Y/001XIP00IV80065N001NG@00FeH0055>
001:@000ASl003lk000j=000=S0002`V000Q70005a<0014?000=2@0020D000@2000200<100800P40
00<00@00000000000000=`00000<0?ooo`002P3oool0501SX`80J:<606RQ1P1ZX080Jj4006bS001^
Y040Lj0007FQ001bW`00M9X007NP001eX@00N:@007JQ001fX`40N:0507FP1`1gY0X0O:8;0P1lY@/0
9`1mXPT0OY`507fL0P1mW0L0NY`;07ZP301cXP`0M:4<07>M3@1`V`d0KiP:072J1`1`W0L0JJ4:05^U
3P1BYaH0C:TT04BY>011[4@0?JY603JVCP0cV5h0;gmd03=^M`0lJG@0@F]g045dNP0kNWP0=gQd03Ae
M@0dN7H0<H1h02f8O00ZTGd0;9Il02RGO00WSWX0:HN002V6PP0302^5PP0V02R3Q`0VQHl08hNC02::
S`0RS8P08hj302JAP@0YTWh0;Y=i03BEL`0jTV`0?YA[03jGH`0jWeL0?Z@n04^_:01N/QT0LK4>07ba
2P1m/@@0M[4706ne2P1]]100L;LF06bf7`1U]B@0F[LZ05>c;`1B/3D0Djlf05N]=`1G[3T0FZ`n05V[
?@1I[CH0EZTj05BY?P1>Zcl204V]@00W04R`?`17[Sl0@Zm004>a?016/CT0@K@k03je?P0o]d40?K@o
03fa?P0l/3`0>k1003VcB00f]ED0>;MO03NcH`0e]5X0?KI804Fd@016[Cl0Bjho062`=P20ZRT0W9hJ
09bJ6P2PU1X0XX/J09^<7`2MRQl0[X`H0:V;7`2]Qbd0XghV09em9@2cOA00[7`H09mn9`2IS1/0Sid@
0080TI`A02L0QY`?082O6@27X0d0RZH;08bW6@2<Y1h0Q9hR08BO8`2DVQX0Ri/I08NH8@28WA/0QilK
07jN8P1nWR/0QYDZ08^E:@25V2P0PI`^08BF=022US<0PILg07Z_;01k`2P0ML4X06o0901]`280L/0S
07K09P1k`2@0M/0S07O08P1m`240Ol0S07c0901k`240O<0K07c06P21`1X00P20`1X0101n`1X0O/0E
08323022`0`208703`0Q08;03@20`0d0N[dB07Vl6@1m_Q`0O<0T07Vh;@1h]S00ML0Y07O0901e`1d0
M/0N07K0801h`R80N<0N07O08@1h`2P0Ll0`07G0801f`A/0Ml8J07C36@1``QL0K<4K06W26P1[`1P0
K<4G06S06@1/`1P0K<<G0732601^`b<0K<LP0080JlPS02L0MlDN07g38P22`R80P<4V08G38P23`ad0
P<DN08?79P23a2@0PlDR08S46029aA@0R<D?08723`21`A40Ol0D07c0601o_Al0Ol0Y082b;`1nZS@0
PZ8i08nE>`2UQ3<0WhHm0:n0?@2`NDP0/gY60;Mn:@2iM4@0_6MS0;AaGP2`KeT0/6MF09mkF02;QDT0
QXlL08F42`26N0<00`27M@009P28L`00Pg8008Eb0027L`00RGH008Ib0025LP00Q7D008Ic0025M`00
RGX008ao002:O`00RgX008Uf0028M`00QW<0081_0023K000P7@007ij0021O@00PH@008:20026Q@00
R84008]n0028OP00RGl008V50027RP80RHh208^>0028R`00Q8L007n1001nN@00NGD00P1eLP009`1e
K@00LFT006e/001[JP00J6H006IS001RH@00GUh005eK001MG@00HUd0065Q001TJ000IfP006Q/001[
KP00Jg4006Y/001WJP00J6L006QV001UH@00HET005]H001LEP00DTh004a20016?000@3/003Xg000g
<000<Bh002`V000P7`006aL0018>000?200020L000D3000200<3000300<200020@000@0003T00000
303oool000X0oooo01@0IZ<306^S1P1^X`L0LZ8306nP001`X@40Lj4107RQ001hW`40MYl007RL001f
X@00M:4007NR0@1jWP00NY`007^N1P1iW0P0Nil>07ZP3`80N9l>02L0N9h<07VJ2`1jVPP0NIT807VM
2P1dW`d0Lj8=072P3@1aWPh0LYh=07BI3@1dW@X0M9l906nQ2@1WX``0FjD@056X701;Zb/0@j/f046^
=`0m[C`0=:==02f?HP0aNFd0AVa/05IUN01HJ7X0Dg1l04i`MP15LGD0@g1f045bM@0lMgH0>H1c03F6
KP0^S6h0:XI_02j0L`0aOW@00P0bNWL09`0cMWX0<7N002]nRP0XQ8`09XF>02R6RP0YRHL0:hb202^?
O`0_T7X0<iAc03VGK@0mWF<0?j5A042U?P1<YbX0GZlH06bb3`1f/@P0Nk4607Nb1@1/]@L0IKD@06>g
6P1U]R`0HK8g05Jb>P1B/3h0CK0k04f`?01=[CL0D:Tc05:T>01GYSX0FZXj05NZ>P1DZ3/0DJU004f^
@00204Vb?P0304N`>`16/C`0A;4o0080@k500280?[E203^eB00i]D/0?KE;03fcA@0k/D00?:i103Zb
A`0e]UL0<;IO03:cH00c]5L0>kI=04FaAP18Zd00DJ`g06J_;023ZBT0X9TN0:JG602QUAl0YhhT0::<
7`2TSAX0[H`C0:^;7P2ZPRX0YHDR0::8902dPAd0YH@M09N89@2HUAh0U9/B0P2CWA<09`2<Wa80PYlL
08:T4@2<Z0`0TZ@J09:O6P22Wb80QihT09VL3`2>WAD0Vi8V096D802ATQ/0OYHQ07bN:02ATbD0TI@T
08ZI;P29Uc40Si8e08VI=`26XC@0OKHZ07c0901c`2@0L/0N07306P1i`280NL0U07[08`1h`2<0N<0R
07_08P1l`280OL0P07o07P1l`1T0OL0F082k4`0207o0400W07nn4@22`180PL8?08C03023`0/0Q<0:
08;0301n`A00N[XH07Rf8@1i_Al0N[/R07Rf;01f/c<0LkTZ07C08`1e`240M/0R07W1901g`RH0N<0W
07C09P1a`2T0K/0Z07C08`1g`200Ml8M07G27P1``1T0J/0M06S05P1]`A40JL4A06_0501Y`AH0Kl0H
07726@1``b00LLPP0080KLP[02L0MlHS07S39@23`B<0Nl8R08716`1n`A/0PL<Q08?5:`22`B<0Ol8N
08G46027`aL0Rl8?08W23P25`140O/4C07g06024`1h0PK`V08:c;@20Y3@0P9Tj08fD>@2[RBl0W8Po
0:1n@`2_PDT0/8=;0;23>02fMd/0^VMV0:I^J02MLF<0YfiK0963E@1oTd00PhlF08Mo1026NP400P25
N0009`24N@00QgX008Ei0025M@00Q70008Qc0024L@00Q6l008Ed0026L@00RGP008Z2002<P`00RGh0
08Ie0024L000QW@008=e0021L`00P7<008Af0022O@00P80008660024S000Si4008jB002=U000R980
08VA002:U080R9`808RN1`2=W040SYP008bA0025R000PX8007in000207Ui000W07Ef001cM@00Lg<0
06m]001WI@00IEh0069P001OG000FE`005aJ001OG@00Gf00069Y001SJ000HV<006EX001SI000HV40
069O001QH000I640069Q001KF@00F58005E=001?A`00BT@004<o000n?@00>SL003@b000a;000;2T0
02LU000S7`0061@0010<000:1P001P<0008010<000<00`80008100010000>@00000<0?ooo`002P3o
ool01P1_WP40LJ4507BQ101dV`40Li`107BN0@80NJ4100`0MYl107JM0@1cV`00LIh007:Q0@1dX080
Ni/307^I0`1lV`P0O9h:07bT3@1kY14207JR400W07NQ301eX0X0MYh;07FO2`1fX@d0MJ4=07BT3P1c
XP`0Lj<<07JS301iX0`0NJ4;07ZR2`1fX@T0LJ<806JU2`1NZA80EJXJ04f/8@19[2<0@ZdX03ZY<`0f
X480>I9:04B;D01;PUh0CWiZ04ilL@1:N7<0A7Q`03maLP0nL700?75_03YgJ@0dP6L0<HIT0324IP0b
P6/0=W]_0080>GEb02L0=g9g03EeN`0dNX@0<7j9031oS00aOX`0;h270362P@0`RG/0;i1d03:GKP0i
Wf00A:Q;04V[<P1C[R40GjhC06^`301b/@P0LK87076b1P1]/P/0HK<B05bd701I]2X0FK<g05>b@P1=
/T@0Bjm204V^?P18/C/0B:dg04f[<P1@ZCL0EJTl05NY?01GZcX0EjXj05>]?P1=/Cl00P1=/S`09`17
/cX0A[<l04Fc@013/dL0?k=<03^bB`0i/Td0?;9A03baC@0j/4d0>k5:042]B00o[dP0>kAF03>aH00d
/F40>:iJ042_D013/4H0BZdn05F/=@1[[BD0PjLW09nJ7`2/UAD0Xi8O0:J;8`2US200YHdM0:j:602Y
RQT0XhTW0:J<8@2YTQh0/HTS0:F<5@2OUQ`0V9/O09bN6@0209RL6@0W092Q4P27Yad0QJXJ08^X3P2B
XQd0Tj4K08NQ7P2=X200WiXC09VI5`2OSRH0UXlR096<8`20U2@0OYdT08jE6@2BTbD0WX`i09^:>@2P
Pcd0UIPn09:V=P24^BP0N/0Q07K07@1i`1`0Nl0M07g08`1j`2@0NL0P07W07P1f`280NL0O07c07@1l
`1h0O<0L07[05`1m`100Q<0<0080Q[d<0100Q[`<08;04026`140R<0A08?23P24`@d0PL8>08;24`20
`1`0O[/R07Rh8@1f^200M[LT07Fg9`1b^RL0M<0V0P1e`2805@1g`BH0MLDW0773:@1]`B/0Jl0W06fk
9@1d`1h0N<0M07C07@1]`280Kl0L06k07`1]`1<0K<8=06o13@1``A00L<<C0774601aa1/0LLLQ07;9
8@0206k5:@0W07S3801i`Q`0Ol8K07W16`1k`QD0N/8F07c17`1kaBd0O<<O07o36@23`AP0Q/<K08c3
502<`180R<0D08705P1k`1/0Nl4M07k18@1n^RH0Nk<Y07V/<P21YSL0TIPk09>@@P2EPd`0ZHI80:aj
DP2WMe80ZGIC0;9_H@2KK680SfmQ09MeF02:Sd`0OJ0c08>A5026P`00RWd00080R7d002L0QWh008Ym
002=O@00RGL008I`0026M000Q70008=c0029MP00RGP008Yo002<Q000RX<008Qn0021M`00P7<0089f
0022N`00QG`0089h0020N@00PH0008F70P2;S@D0Ri<7096K1P2@X0@0RYl208bQ0P2>WP<0SJ0408nS
1P2;Z0H0R:H308jV0P2>X@40RYH1086<0@1mQ@000P1jP000501kO`00MW/007Aa001`JP00J68006=O
001QH000G5/005QH001KEP00FeP0061O001SI000I6<0069O001QGP00GUX005YH001JGP00G6000P1O
HP000`1JGP00EE@0051:000204i9000<04Q40018?`00@3P003Td000e<000;bP002`X000W8`008AX0
01PC000C2`002PH00P050P000`020@000P000040000i000000`0oooo000:0?ooo`0D07>M001gW`40
N9d207BM0P1eW080MI`107NN001kW@40Ni/107bN001gW000MYh007NO0@1hX080NIl607^L1`1lX`X0
NJD:07RV301jZ0h207RX2`0W07VW2@1gYPT0MJL;07RW301iY`d0NjD>07RU3P1jY0/0N:D;07ZU2P1i
Y`X0NJP;07RX2`1hY0`0MZ@:072R2@1^Y@`0HjP>05Z[4@1AZa<0CJ`F04JZ7013YbL0@jD^04JR<`18
X440B9QC04N=H@12PfH0?GeX03eeJ@0mKfT0>G1Z03QcI@0hNF80>7iR03R1I@0jOfP0?7a^0080?GA`
01/0?W5b03]bM@0nMGP0>WIl03]cO`0hLH40=g2003MdNP0hOW<0=Xa/03NKI00nYE00Bj`b05Nb5P1T
]0`0Lk8607R_101e/@L0L;4806fa301V[a/0GK0W05Ja<01B[cL0C[0n04R`?`13[Sd00P15[C/02P15
[c`0AZlf04N^=@1<[ST0DJ/m05>Z>P1C[CT0DZhg04n`>01=/CL204Vd>P0W04Ba?011/3h0@;9603fa
C00j[e<0>;1>03^bC00k/E00>k5B03f_C`0m[d`0@Je@03f]E@0i/5X0=k5R03B]HP0fZEP0?jeA046^
A@19Zch0EZTf07BX9P20YB<0VY/R0:j@5@2/SA/0[8@S0:^:7`2ST240[XHU0:B=7@2EU2`0X98N0:6@
5P2NS2D0WXhJ09VI6`2HWAh0VYXL0080UIPN02L0TI`I08ZV6P2AZa/0V:@K09RM8@2RWAl0X9hK09BN
802UUAH0Yi@G0:Z9902JR2L0ThLa08^>8`2<T1T0SI0C08VH7`2LR2/0UHXd0::2?P2AUc/0RZTc07c0
9P1e`1/0N<0J07bj7`1o`240PL0R07fk901j`200NL0O07_0701j`1d0Nl0K07k16P1n`1H0OL0@0870
3025`0/00P27`0X09`24`0`0P<0A07k16`22`AP0P/@B08;04@1n`Q40P<0E07g08P1k^bT0M[DU07Jc
901g^Al0NK/M07O07`1d`1l0Ml0L07O08P1j`b80NL<T07C0801Z`2D0K/0V07:i9`1f`1X0NL0D0771
501]`QX0L<4H07725`1``a<0LL@@07S4401ba1<0LlDC07;55P1`aQT0L<HO07G7800207;39`0W07g2
7020a1H0P/4E07k04`1ia100M/<D07S3701laB80Ol@H08335@25`aH0R<4F08c04`2<`1@0R;hD08C0
5@1n`1`0Ml8R07g08P22`240O[PX07be<023ZSL0RZ<l08jC?@2?Qd@0Wha80:InE@2MKUh0WgQJ0:Qi
G`2LME/0SWEL08YoD@27U380Pi/E08J>3026P`00RXD00080S84002L0Rgd008j1002<PP00RWd008Ih
0024LP00QWL008Ad0025M`00R7l008^1002>Q@00Rh4008Ul0022N`00OgL0081g0025O@00QH4008=n
0021OP00R8@008bC1P2<W0h0Rj<@08bX3P2;ZP/0RZT808ZV1P2<YPP0RZH708j]1@2;/PT0RK@:08Ff
2@25/@T0R:T<08BO3@1oUPh00P1nS`h0501iR@/0N7l607=f0P1bK000JVL006EN001NF`00G5H005QH
001KF@00FUP005mJ001RG`00HV0005mL001JEP00FeD005UF001NFP00GEd00P1NG@004@1JG000EU@0
055:001BBP00D4X004e70019A000@c`003`h000j<P00=R/002dV000/9P00:B4001hK000H40004@X0
00802PH000<01@40004000000000>@00000<0?ooo`002P3oool0501^W`00LJ01072P0@1aW`40Lid1
07BM001gW000NY`007VK001lWP00NJ8007NR001iY000NZ8107ZS201nX@P0O:4:07VV301gZ@d0NJ/=
0P1f[0X09`1hZPT0NJ/:07VY2P1iZ0X0MjT<07JU301gXPX0NJ4:07fS2P1iY@X0N:H:07FX2`1hY@d0
Mj@>07VR301gXPX0MJH906nY2`1XZ@`0Gj/>05F[4@1=Za@0BjdH04^_7P19[bL0B:hb046ZB00mW5H0
>heT03QnH`0hLfP0=V]Y03M^JP0fL6P0>7IS03UmHP0kPF<0>h9X03enKP0203mfK`0W03mbL011LFd0
@G9`041_L`13JgH0?6Ik03YXL`0kL6L0@GmI03jED`16YTH0DJXd05V_7P1U/@d0Lk4607^a0`20/`<0
NK8806n`3@1V/A/0GZl^05F^@01B[T@0CZe404R]A012[cd0@Jdg04F]=`17[SX0BJlj04N^=P17[cL0
Bk0h04n]>@1C[3P0Djle052a<`1:/cL0B[8h0080A;<o02L0@Jm503j^B`0j[E40>:aB03RZD`0h/580
?;==03bdC00k/Th0>k1:03f]D@0nYeD0?ZaI03b_FP0i[5l0=ZYM03ZXDP11ZT/0AJa504ZY@`1FZ3`0
Lj<Z08BT8P2IX2H0ZY8J0:J=6`2RR2<0[8TO0:F<7`2XQRP0XXXN09JF9`2LV1h0WI4D09B>8`2NTR40
[9TB0:JI702RUA`00P2CTB809`2?VB<0UJ<H09RX702MWA`0UJ0P09ZM8P2NVAh0UI`N0:6G802MU1d0
WhTV09:7:02EPc@0UhLV09f25@2QQPl0RiHI0:636`2GQRl0XgXi096H?025[c@0NKPT07?06@1f_QX0
O[hR08?07P27`1l0Q[XP07bk801i`1d0N/4K07_1601o`1<0P/4A08713`1o`0h0P/0=08Fo300208K0
3@0W08G13P25`A80P<4F08734`24`Pl0PL8A07W24P1i`1H0NkXN07bj8`1f]b<0M;LU07Fj7P1e`1/0
NL0I07O0601e`1X0ML0N07W17`1f`200LL0N06S0901^`2P0L/0^07C08@1_`1X0Ll4H07306P1b`1X0
Kl0K07K35@1ga1<0O<@C07W4501iaa<0M<LC07775@1abAP0M/PH0080M/XQ02L0Q<TI08;75P20`a<0
O<<?07g33`1iaaT0O/DK07W76`1oaQH0O/PG08;44`1o`aD0QL<E08;24P23`Q@0QL4F07c37`1g`BP0
NL8R08;08023^BL0PJl/08FX<@2;WCP0RIdd08ND?@2CV480W8m@09UgH02HN6D0WGUW09MfGP2;NEP0
RhM908VG8@25T`D0QXL008:20028P0000P2:P0009`2:O000RX4008]n002<O`00RGX008Qe0027LP00
PG8008Aa0026N`00RX4008b4002;PP00Qh00085k001lM@00P7@008Ek0024P@00PhH008V:0@2>UP<0
TJ48092U302<Z0d0SJX;092[2@2AZPT0RjP:08R/1`27/@D0QKD808Fl3@24_140P;h?07nl4P21^1H0
OK4N07V[8@0207JX900J07>K601cS0l0Lh8607Ah0@1aJ`00If<0069J001NF000GEH005YF001LF000
GU/006EQ001SH@00HEh005mI001PFP00GU/0061M001OGP00G5P005aE001KEP00F50005A;001AA`02
04m;000;04i70019@P00@c`003de000g;`00<bT002dU000X9@008al001/F000G40000P0?2`000`08
10000P000000000i000000`0oooo000:0?ooo`0D06bP001]X@40KZ81076P0@1eW@00Mid007FO001f
W`00N:0007VR001gXP00Mj0107ZT0@1jYP00OJL607fU1P1lY0P0NjH:07JX301h[Pd207R/2P0W07^Z
201l[@T0OJL907RV2`1dZ@d0MZD<07FT2`1eX`X0MZD907FW2`1fZ@X0MZT;07RW301hY@`0NZ<;07ZS
2@1iZ0X0MjL907:Z2P1Y[@d0Fj`B05:/5P1;[a/0Bk4R04Z_;014[cT0?Zi903bVEP0hV5`0>I5M03f8
G@0mPEh0>hAK03V8F00hSET0=i5I03NAG`0fSf@0=XY]0080=hE]02L0>H1/03UkJ00iN6/0>7M`03]d
L`0eNVh0=X5N03^<B@12VCL0BJPY05F^801Q[QP0IK0>06^`1`1b/@D0Nk0807Za401b/1X0IjhR05n]
:`1G[3L0DZe204b/AP17[4L0A:i104:`>@12/2l0AZhb04Z_>P1:[3d0C:dj04b_=@1=/SD0D;4e05Fa
<`1D/S40DK@_04Zd=@17/c/00P14/D<09`10[Td0?:eD03R[F@0gYeX0=ZMG03R_E@0j]540>[A@03fb
C`0n[dh0?jUF046SGP12YEd0?ZQJ03jTG00iY5X0?ZAC046YB`14[4L0BJa205R]>@1jYB@0T:4J09^P
902[Sah0YY<J0:BE8`2VTAl0YX`I0::;8`2QRb80X8dL09j>7`2KTA`0VYDK09fI8`2YUB80WIPT09fG
8@0209ND8P0W096K8`2KX1l0VJ8O09jL7`2BWQT0V9PP09bE802CVa/0WiHY09FD9@2HRR/0RXPY09B4
<P2ERBL0X8LL09j04`2HRQh0Y7`Z09J4>@2JOD00Q9Y107Z/>`1d`2L0ML0M07K0701n_1d0Q;TI08Jl
6021`1/0Nl0J07O07P1k`Ad0Ol0G08?04P23`0l0QL0>07o13@21`140P<<I0080P/@G02L0Q<HD08C5
4`20aAH0OLHE07_34@1k`140ML0F07C06P1g]Qd0N[DN07Rh8@1e`240LL0P07;08P1j`1h0OL0H07g0
5P1k`1P0OL0G07S0601d`1d0JL0U07708`1c`2L0M<0T06_09P1a`AX0Ll4H07?25@1b`Q@0NLDA07_9
401jaa80M/PB07K:4@1aba@0LL`D07;>5@1gcaP00P1icR009`25bAL0QLTF08345`20`a80P<DA07g6
601naAL0OlHE07o74`22aQ@0Q<@A08744P1n`a<0Nl<E07k35022`Q<0P<8H07k1801m_b80P;XS08>h
:021[Bd0QjL_08^R=027YS<0PJ8h08nO@`2FUE00WWaJ09afJ02SMVL0WW9P09=hF028ST<0RIPK08R=
1@25O`00Q7`008Mm000208Mj000W08Qm002:O`00Rgh008al002;N`00RGH008=_0022K`00PW<0089g
0025N000RGh008N00027N`00QGP007mh0023NP00Qgd008J30026R@00Ri0108RP2@2;Y`T0S:L808b/
2@2>ZPX0S:`>08Z]3`27[0h0QK8:08:i2@1n`0h0PL0B07k05@1i`A@0Nl@E07c26P1i_R40N;HW0080
NK0Y0180MjXS07BM6@1hUA40N8T9075k0@1_J`00IF40065P001NF`00FEL005]J001PG@00Hf8006AX
001SI@00IV40065N001JH00205aM000C05]H001LE000FUD005aA001GC000E4T00559001BB`00CDP0
04]50016@@00@CT003`b000g;P00;bL002`U000X8`008Ad001dE000201D>000300`700060P000000
03T00000303oool000X0oooo01@0L:00072Q001cX@00LZ0107BO0@1fX000NZ8007ZS001iX`00N:40
07NR0@1hXP80NZ8107bS001lY@00OJ@007jT101nY0T0NJL907RX2`80NZT:02L0O:L907bU2@1nX@/0
N:8<07JR3P1bXPl0L:<=076T2P1dY`/0M:H=07JU3@1fYP`0N:@<07ZT2@1lX@T0Nj<807ZX2@1lZ@T0
N:X906n/301P[A<0EJhJ04n_8P1=/BH0Ak4_042b@00k/Dh0>:aE03JRG00iWV40?IQN03nDGP0oTeD0
?9QA03^ND00gX500=IiG03BIGP0cTfH00P0bTFH09`0eRV@0<X9V035mJ@0cOg80=8Ea03>?H`0dWDT0
@:H`04b_6P1H[`l0I;<806^b1@1[/@D0KK0506ja1`1`/140JK0Q06:/>01MZd40FZM105F[@01>[D@0
B:e404F]@@12[S`0@k0d04Fa<P17/C@0B:lj04V[>`1=Z3L0Cj/b052_<P1@[c40E;8`05>e;@1<]Rl0
Ak@e04Ba?00204B^A`0W03j]D@0j[EX0>:eN03N]G00g[EH0=ZeE03R^E@0j/500>k9>03n]D@12YEP0
@YiP042NGP13WUD0A9aD04:IE@10WD`0@JA@04F/C`1</4/0Gk4d086[802GWQ/0WIXN0:F<8P2PTQ`0
WYPL0:BC802RS1d0WY8O0:2D802ZTal0X8lQ09f?8P2RV1h0ZYlS0:fE:`2NVQl0W9XW0080W9`T02L0
WihS09fI:`2LW2D0UYdP09JK7`2GUB@0VY@[09>L9`2EW2`0TiL[09::<02<R2h0TXH_09F>:@2NTR<0
Z8LI0:B99P2YOCd0U8E108b2A`1kUDP0MJ<n07Fe:P1f`240Ml0J08707P27^1/0Q;PH07jk601h_aT0
NKlM07^o7@1m`1/0P/0F08K04`26`100Ol8>07c14`1k`Qd00P1kaQ/09`1oaaD0OLHE07W5701faAT0
LLLC07C3501b`1X0Ll0O06o0801e`1`0M/0K07S06`1c`1h0LL0R07K08@1i`1`0N/8G07c05`1j`1H0
MkPI07W0801c`2D0Ll0R0770701e`1P0L/0H07O14@1h`100N/4?07K13`1ia0l0N<P@07G85@1bbAH0
MLXF077<5@1`cQ@0LLhE07C?5@0207c<600W08;95`1naQ@0Ol<F07k3601oaQ/0OlDM08756@1oaaD0
PLHD08;75@24aQ40P/<>0833401o`QD0P<HF08355@21`QH0Q<0H08?0901o`2L0OL0Z07fc;P27/Rh0
RkP^08Vg:P23[SH0SJ=409JBE02NPET0XW]P0:UfF@2ULe`0VWaD08BC?025UaT0QHL5085k0024M`00
QWd00080QX4002L0RH4008Z00028O`00Rgl008^00029N`00QgD008Ah0020M`00PgT0089h0025N000
Qg`008Em002:O000R7d008]o002=RP00Si0008bB0@2:UP<0R:L:08R^3@2;Y`D0RJ/508V/3029[a40
PJlD08Fb4@25^a00P<4@07g44P1m`QH0Nl8F07W86@1laal0N/DX07[6:@1l`BT00P1j^R/09`1h]bh0
LZhZ07:S7`1bU@l0LXX407Ii0@1]KP00HfD005eH001KE`00GUT005]K001PGP00HV<006IT001VH@00
HV4005eO001IG000FUL005UH001LE000GEH005mD001KCP00ETd005=;001>AP00C4H004Y20014?@00
?c/003db000j<@00<bP002dT000/8@009al0024I000201TB0003014900080`000`4003T00000303o
ool000X0oooo01@0L9h006nO001^W`40KJ0306fN0`1aX`40Lj0007JR001hY000MZ8007JO001fWP40
NIl107^O001iX040O9l307^M101kXPX0Mj@:07RS2`80N:H;02L0N:L<07JV2`1eX0d0Lj4=076S301^
Y100KJ@A076T3`1bX`h0LZ4>07:Q3@1hX``0Nj8:07fS1P1kY0H0N:D707NY201iZ@P0Mj/8076/2P1V
[Pl0G:lA05J_601B/Ad0Bk<T04:e=00l]480>:m=03ZYEP0nYeX0?J=N03jMH00mWET0?J5D03bYB`0j
ZdP0=ZQ<03FSD00bXEP00P0bWeP09`0bVeX0<IEJ032@G`0aU6D0=9UL03VUB@10/Bl0CK8J05Vb3@1T
/@H0JK<106^e001^]0@0J[<606Zc3@1T]1T0G;0_05F^AP1E[D`0Cj]>04n]BP1;/4X0A[1404Fa?`17
/ST0BK<`04Vd;`1;/cH0B[0m04b]?01<[3X0Cj`b052`<@1@/c<0C[@a052d<017/CD0A;0k046`@@02
03j^B@0W03n_DP0k[e/0>:iN03V^G@0g[5P0>:EM03NPFP0kZ5@0@:YA04>WD`12X5T0?YiS042JI014
W5`0@iYE042IDP0oXTl0>jUE04:/E`1<[U@0IJdd08NT8@2MVaL0XILK09ZF902QVal0XYhG0:2F7P2S
Uad0WI`I0:BP702TVRL0Vi`S09^G9P2WURL0[9XX0:>G9`2KWa`0Uj<M0080W:8T02L0WZ<R09RN:P2N
W2T0WihN09^K9P2MUB/0VYHd08nK;P29X300TITb092C=02FTCH0UI4g09BC>P2ITCD0UhT_09J;<`2F
RT40Qi=108:AB01bV4L0L9e607Bf:`1k`1`0N<0G07_05@21_Q@0O[dE07jl6@1j`1d0N[lL07_06P1m
`QH0P/4D08G25@24`140P<0=07c13@1m`a000P1ka1002`1o`a40Ol@?07W24`1i`a@0ML@E07726@1e
`1/0M<0O07;0801c`1d0ML0J00<0M<0J01T0N<0H07[15`1j`aD0Ml8F07C06@1b^240M[PV07Fk;@1_
`2D0K/0L07C05P1d`180NL0C07_03`1m`0h0N<4=07[33P1faQ40M/PF07;86P1cbA/0M<TL07C;601b
baT0O<LJ0080OlHK02L0P/DI08;65P1laaD0P<PM08366`21a1T0Q<@G08355`22aQ@0PlPF08?:4@23
aPl0Pl4D08;35@21a1T0Pl<K08Jo6@25_AX0P/0O07c09`1l_b`0PKL^08>d<027`BX0QK`Y08:_=`25
YTP0SYAD09b3FP2LOE/0VX1I09ElG@2@R500PIhg08>L6026R0H0QWh008N00026Q0000P28Q0002P29
PP00RX8008b10029P000Sh4008j2002;PP00R88008J20026OP0208ao000K08Z6002:R@40S8T108f6
002BSP00T9T009FL002CXP80S:H:08V`4@2<]A00SK0908Vb3`28]Q<0QKTK08>g7@25^1h0Q<0L08;9
6@1oaaH0OLPJ07[;7@1hcB<0N<`Y07O<<01hcCD0N<Pa0080Nl<`02L0M[l/072f:P1`Z2<0KZ8M076L
5P1aTQ00M80606e^001SG`00H5l006=P001RH@00Gel0061N001UH000HEh0069M001QG000FeT005]F
001LE`00GED005]B001HC`00Fe0005U=001BA`00BSl004Q00018?`00ASd0044i000m<`00?3<003T^
000d9@00:b4002@N000R60000P0J4000100B2`0030L000L300030@0h000000`0oooo000:0?ooo`06
06ZP001ZW`00JYl106RQ0`1[X`<0KZ810P1`W`00301aX000MYd007ZK001jV`00NYT007^I0@1hW0<0
Mil707ZK1@1iV@L0M:0:076S2@80LZ@:02L0Kj<;06bT301^X`d0KjD;07>U2`1_X@d0L:8?07:U4P1c
X@d0LZ0=076O3@1eX@/0N:4607VT101gX`D0MZP807FZ2@1e[0P0M:`806n^201X/0P0H[0;05f`3@1J
/Q<0Dk4H04ja9@17/cH0@k16046_C013[4d0@j]B042TF00lX5L0>j1D03fXC00l[4D0>je303V[A00i
[4@00P0hZd409`0iZSl0=ZLm03FU?`0jYd80?jXj04Na:`1=/Q/0Ek8@06>a1`1Y/P<0Jk8106Ve0P1[
]PH0IK@<066h5`1J]R80E[@b05:_@01@[DH0CZm:04j`B01:/4T0AZm204^a>`1</ST0CK4a04Rb;@18
/c<0B;1004F_A018[Cl0B:di04Z^>01:[cT0BJlh04R_>@11ZSd0?jU503n[B@0203Z/D00W03^]E`0h
Zf40=jYS03N[G`0eZ600=:1S03NKHP0kWel0@iiI04JMFP12W640@I]V03nJIP12Vf80@I]H046LE@10
YU00@:iI046aE@1>/E40LJlb08^R702JWQT0W:0K09VT7P2MXah0WZ8I09NR6P2QX1P0WZ<E09jX602P
Xb00VJDN09RS8P2RVbL0Z9PV09fF9P2MWQh0XJ8G0080VJ<P02L0Vj@U09ZU8P2PXB@0Y9`S09jM9P2H
VBP0TI/`08fO;@2:Xb`0S9d^09FJ<@2HVcL0VILm09BG?`2CT3l0SXQ108b8@028SdX0OYQ307BN@`1]
X4<0LIm207Nd;P1i`1l0ML0J07Jl5`1l_1D0OKdG07^m6@1j`1X0Ml4K07c25P1laAH0O/DD07k15`1k
`1D0NL0>07K13P1ia0h00P1j`Q407@1n`a00PLD>07o53`1k`A40M/8H06o38@1c`R00LL8S07;2:01b
`2H0LL0O07>l7@1c^R00Ml0O07_07@1k`200NKXR07Nj8@1g`280Ll0R07?08@1c`R<0M<8J07O44`1k
aA80N<@B07g1401m`@l0O<4>0080Nl0=00P0Ll@@06k8501^bR00L/TO07K86`1eb1/0Ll@L07k38P80
Pl8P02L0Q/@L0836701mb1X0O<TL08796021b1L0QLLI08376P1nbAL0P<TF08784P23aA80Pl4F08?0
6@28`200R[lR08^m7@22`AX0O/4N07W0:01l`2l0PKd]08Bj;P26`b/0O/0X07f]=P1lYDL0RYQ?09Z8
E@2GPEP0RX1G08R5E`23TT/0NjDb082R5`26S`P0QhL008J6002;R@000P29R0009`28QP00RhH008^5
002=O`00T88008j6002:Q`40RhL108V8002;R@00SHT008b@002:T`80RiT7092G1P2BT080TiL009BT
002FZP00U:l608ja3P2@^@l0S[`>08jj3P29_A@0Q/8L08?08@26_R@0Q;D]08C1;021cBL0OlhL07_>
7`1jdR@0M=<S077?9P1ac300ML`k07?:>`0207C6=`0W07K1<@1c_C00KkD^06bb<@1Y[bX0J:@G07>D
3P1dO`80KF`006MX001VJ000I6H0061R001PH000Ged005aJ001MG@00HEd005iM001QG000G5P005]C
001FC@00E4T005A:001FC000DDL004m6001:@P00AT0004U00015?000@C<003``000j<000=BH002hR
000Y70008aT000806Q<000D05@h0014:000<1`001`<00080000g000000`0oooo000:0?ooo`0D06ZN
001YW000JI`006VO0@1YW@40JY`006bJ001^V`00L9d007>K001iVP40NYT107VF001gUP40MiL307FJ
1P1eV@H0LiT707BO3@1bX0X207BO2@0W06nO2P1/XP/0Jj8<06nT2P1_XPT0KJ8:06nR2P1bXP/0MJ4;
07>N2`1dW0/0N:0907ZQ1@1iX`@0MZ8607>V2P1eZ@d0Lj`:07:]2@1b[@P0LZh606b/1`1S[`P0H:h:
05Z`401E/AP0D[8V056c=P1@]3T0D;8e04n_=P19Zd40AZQ704JVA@19[3h0A:lf04B`<`14/Bl0A;4Y
0080Ak4U02L0A;4V04Bb8`13/b80@k8P04bb7@1A/aH0F[<<05nc1`1W/P<0K;<106jd0@1X/`<0J;D8
06:f4P1K^280DkL]05:c>01B[Sl0Dji505:`AP1C/D00D;4n056_>@1A/3/0DZll04n_=@1;/S40B;@i
04N_A@15[Th0@ji:04>]A`13[4D0?j]0042Y@00oYTH0?ZA903bTDP0iYUL00P0i[5d09`0gZfH0=:E/
03BTJ`0bZ6@0=:ES03BUI@0eXVP0>YiV046HH@13UF80@9QT046IJ@0oVFT0?iUT03fJG@0nWUT0@JUE
04B_EP18/Th0Fk5<07n]<@2GWa`0WYdM09fQ7`2MYAT0WZ8L0:FK6P2EWaT0WZ4I0:6Q602MXQL0VihI
09fT5`2LYA/0XYlQ0::M7P2NWQX0W9hL0::N7P0209FT7@0W09bS8P2MYR40XJDS0:>S8`2MX2D0TiX[
09>K;P2DWR/0TZ8[09>T;P2HWRl0UYlb09BK<`2?VS`0SYPl08VD@025Td<0QI9:07ZO@`1]YD40K:Y0
06n[@01d/C40M[TT07;07`1b`AP0Ll4F07K4501i`aD0OL0C07g1501l`Q@0O<4D07[04P1k`1@0ML4C
07?04@1c``l0N<8B0080Ol0@02L0Q<0>08S03@23`0l0O<0@07C1701c`R80L/0M07?27P1d`1d0ML0N
07C06`1d`1H0M/0L07[07`1f`280L[L[07Zb;P1h]2`0M[PX07;09`1e`R00M<@M07G5501haa40N/DA
07O55@1i`@l0Ml0>07[13P1o`0d0NL8<06o73P1^ba<0LL/O07C87P1baaX0LLLK07?47020_b000P20
_B<09`23`RH0OlLR07k87`1nb1d0PLLJ08;:5@21b1D0O<TJ07c:6`1lb1P0O/PF08785021aQL0Q<@H
08_1802:`2H0RKhN07c06`1ia280N<0Z07fh<P21_BP0Q<0Y07k1:01j^bd0MjXh07FWA01oW4d0Ti1B
09Z8D`2FPUH0T8QA08RFBP1oYBP0Q9hD08N@1`29R`00Rh/008j<000208j;000=08^4002=Q@00SX<0
08n1002>R@00RH/208ZA3027T@X0RY8408bD0P2AV@40SIX208fM2P0208NU4`0H09BP4P2DWPX0TJL1
096d1P2@]`d0Sk`?092n302>`0`0Rl<?08[35P25`ad0P/DP08C58P23`b<0P/HW07o89@1lcQh0NM0R
07KB9@1bdbL0L=4T06o>;`1^cCd0K/a20P1^b3d09`1^a340Kl@/07C1:P1^]bh0JkHV06Vc6`1aZQ@0
MiX<07J30@1]LP00J6`006MZ001RI`00H68005iM001HF@00FU/005UN001MG`00G5h005QJ001HD@00
Edh005=;001CB000E4T005A<001DC@00CdL004a10019@000ACh0044f000l<P00>BX003LY000b9@00
;B0002LK000201hF000601LA000F2`003PX000X8000510000P00=P00000<0?ooo`002P3oool0501/
U`00KIL006ZG001]U`00KI<006fD001[U000JYD0076J001fU`00MYD007NF0@1hU`40M9L207>G0`1b
VP@0MId707>P301aY@h0Lj8=0P1fX@/09`1dXPT0KZ8:06bT2P1/Y0X0KZ09076S201`Y0T0LZD807>S
1`1fX0P0Mj4707RT2@1hY@X0MZ<:07NS2P1fZ0/0N:T;07NZ2@1hZ`T0M:X707NZ101fZP@0LJ`606n^
2@1/[0/0J[0=06N_501V[a`0I:hL06>a6`1P/1`0FJlR05R^901H[b80FK0N05Jc6`1B]1X0E;@H05Jd
5@0205Fd4P0W05>d4@1?]180CKHB04jf401C]A40Fk@<06>c201Y]@D0KK@2072c001`/`40LK<306Ze
2@1O]Q40E[LM052g:P1A]CL0DK9005F^A01F[TL0EJi305>a?P1C/CX0DZhj04n]@P1@[D40C[1204bb
AP17/Dh0A[1F04F]EP14[U80A:a<04B[B011ZTP0?ZE=03nRD`0oX5/0>jAT0080>:IX02L0=:9]03:J
LP0aV740=9YZ03FPH`0dYVH0=:IX03^QI`11Vf@0?iUX03fFJP0mUg40?IA^042CI@0lUeh0?IeJ04:W
E@15[dh0E;9106Z]?@2@YRT0WYdM0:6I702MW1`0W:0G09nO6@2SVAh0VY`J09ZO6P2RWAd0VYhI09NP
602QXA/0Yj0L0:6M7@2SWQD0Y:8@0:JP6P2UVR@00P2GXA/09`2IY1h0WJPQ0:2U8@2KZB40UjPS09BU
8`2BXRL0Tj4Z092V;02@ZB`0TZ@a096P<02=VC@0RY`l08bM?`26W400OiY207jIA`1iVdD0Mim3076Z
@01_[400M;<a07Fi:`1e`2P0M<0P07G2601f`AD0N/4C07c3401o`Ph0PL8?07c14@1ia180N<0C07O0
4@1e`100M/4=07S03`0208303`0W08W03@28`0/0P;/>07g0401e`1P0Ml0L07W06P1j`1T0OKdJ07_0
601h`1@0Ml0D07W05`1k`1/0Nl0O07Jl8@1h^R80Nl0O07Vo801d`B40Ll8O06o3701eaa80NLL>07K7
401eaQD0M<8@07G0301g`P`0Ml@?07G5301_a@d0LLT?07C95@1dbaT0K/XM07767`1a`b00N/0R0080
N/0[02L0MklZ07[5;01oa2X0OlHU08787`1obA/0N/LL07W8801hb280NlPP07c96`20bQT0OlXG0839
5`22aQ/0PLLS07o5801laB80N<D/07?5<`1e_c<0Pl4U08C38`1m`bD0Mkh]07J_?@1e[4H0Oj9@092?
D@2LR540XX=@09Z;C`2?Ud@0Q:<O08FJ4028S`D0S8/008f<002<S`000P2?T0009`2>S000SX<00928
0@2AS0@0S90:08F@3024UPl0PY/>08FK1`2<X0@0T:L508^T2@24Z100PJlF08:a6`2:[ah0TJdA09:`
1@2=_0d0S<8C08_34`2=`0l0Rl4=08[63`2;aQ@0R/LK08K99@25ab@0PlTV07k99P1mcRD0OLdO07S<
801kcb40MllQ07C>9P1bc2/0L<lc06c@?`0206_9@`0W06_5?01/b3P0J/@i06Vj?@1U^3P0HKld06>l
:`1W/Q<0LJ4607><0@1]NP00IgH306Ef201QLPP0F74;05E/301AJPl0DFT;05IY201HHP@0EUh105UK
001HFP00EU@005=;001CA`00DTP004m9001>B@00CD@004Pm0015>@00@SH0044d000i<000=R`003LZ
000`9000:1`000808AH000L06@l001L>000A30003@X000X500040@000@0003D00000303oool000X0
oooo01@0KIH0072H001_UP00M9D007:C001_T000L8l0076E0@1bU`80LiD107VE001hV080MYT307BI
101dW0@0MIX407BO1P1cXP`0LZD>076V3@80MJ8=02L0N:4<07FQ2`1aX0`0LJ0=076P301bXPX0M:@9
07>V2@1eX`X0N:<907NS2P1gXP`0MJH<07NT3@1gYP`0NJH<07bU2`1mY@X0O:H907^Y1P1jZ`H0NJX6
07N/1P1eZ@P0MjP807J/2`1e[@/0MJh;07>]2`1a[`/0KJh<06J`3P1V/Ph0I[@<06Fe2P1U]PP0HK@8
06:e2P1P]P`00P1M]0`09`1L]0`0GKD:05Re2`1J]PT0FkH906Jf2@1^]0L0L[@307Jd0@1e]000MkH0
07Jf0@1b]@L0Ik@<05Ze5P1B]RD0D;@a05>d@01D[d@0Ejm705>]B@1B[d<0DZdn05BZ@01@YT`0CJU?
04^[F01;[U/0B:iN04>`H014[VL0BJiK04V`DP17[dd0AJY<04:VCP10Y5L0?J5N03jPI`0203jQJP0W
03RRJ`0dWVl0<i]a03>KK00cWfT0=:=X03BSJ@0lXF/0?Z1Y03fNK`0lVW@0>iAi03fCL00lSf80>iAN
03bMF014Y500CJ]505n^<`1cZ2X0TYlQ0:2J702NUad0VYPO09nK6`2NW1H0W9HR09nI7`2PW1X0WYTS
09bK7`2IYQT0XZ@J0:NL802RWQh0X:0H0::Q5@2OWaT0WIhP0080VJ8L02L0UjPN09FZ8@2HZRD0UZhQ
09>_8P2EZBD0TjHZ09:W;`2<YC<0SZXb08nX=@2<YCL0RJ8i07nR@020XSl0NZ4n07NS?`1eXD80MZ=0
07NN@P1dZD<0LZe107:`?01g]3D0M[/g07O0;P1g`R@0N/0O07S06P1k`1H0Nl0E07_1501j`AH0Ml@F
08335@1l`a@0NL8F07?05@1c`1800P1l`1009`1o`0h0Ol0=07c0401i`1@0NL4F07[05@1k`1D0Ol0H
07k05P1m`1D0M<8F07C05`1f`1h0N<0P07K08P1b`2D0Ll0O07716`1b`1`0LL0Q07Bn8P1e^a`0Ml4A
07S33@1ga@l0M<@G07C23`1f`0X0N<8:07_3301ga0T0L<D;07;73P1bb1<0LL`I06c9801_bR40L/DV
07G39P0207C1:P0W07G0:P1k`2P0Ol0W08749@1nbB80O<XN07W:7@1fbb00NLPT07[:901mb2@0O<XQ
087<6P20bQL0P<PI07[88@1gb2T0MlH`07G5?01aaD00LLHf07c78`24aB@0Ol0Z07Zi<`1g[480MZa8
086PDP2CSU40W8MB09f4C`2BU4P0Ri`m08RU6029UP`0Rhh308b;002?S000SY400080Si<002L0T8l0
08b@002CU@H0TIl=08nS502;XQD0RYXA08NM4025V``0R:<?08nY3`2=Z`d0Rj`<08Na4028]a@0S;XL
08bf502;^100S;dC08[36@28b1H0S<T@08[83`28aa<0R<XG08_<6`25cB40Ol`[07k<<`1kcC00O</V
07_:8P1jbRD0N<hU07W?9@1gdB@0MM0U07GA:@1cd3800P1Zc3h09`1VbSl0I<Q205o6B@1J`4L0G/17
05c6>01MaBd0H<0R06Jj6@1_/140K:8906JD3P1OV1@0FY<G056?701=RR80AXDZ04En801?MQP0EV`<
05QY0P1KI@40GEh005aG001FD000DTD004m6001?A000CT8004a3001;?@00B3h0044f000l<000?2l0
03T_000g;000<RL002/M000202DI000701d@000G3`0050`000l<000<2P0020<00081000e000000`0
oooo000:0?ooo`0D07:J001dV000M9L107FG0@1cU@40LY<107>B001aT@40KID307BE0@1fU000Ni`2
07VL0P1iV`80Ni`307VL101jX0L0MZ4:07>S301bY``207JV3@0W07VW2`1hXP/0M:4<07BR3`1bXQ80
M:@>076V2P1aYP`0MJ<>07JR301hX``0NJD<07JT301eY0/0MjD;07^U2`1lX`X0NjD807nV201lYPP0
NjH907ZW201jZ@T0NjH907bV2P1jZ@X0NJ/907V_1`1h[PH0MJh7076_1`1Z/@L0J;<606Nd1@1Z/`<0
J;<106Nc0P1V/`H0IK<70080H[D900P0HK8806:d201Q]PP0I;P706Jg1P1^]PD0LK@307Nd0@80NK@3
01d0NkD107bf001f]PD0K[H906Be4@1K]Ah0E;<Y05Bb>@1G/480EK1205F_?@1F[ch0F:]005NW@01E
YDL0DJI;04fZE`19Zel0AjeP04R/H`17[VH0BjeM04f_E01=[D`0BjQ;04BUD@0oXUT0?YmR03nPIP02
042PI00W03fSI@0kY6X0>:A]03FRK@0eY6/0=ZI[03NUJP0iY6h0?J9b03fNM`0fUW/0=hek03RAK@0l
Sf40@XmN042CF01:Wdl0EZI206f[:P1nYQ`0TilO0:2I6@2OVA/0VYPN09fH702LVaT0V9TM09fM802Q
Val0Ui/R09bM8@2GY1`0UZ8O0::E9@2RWR40X:@N0:>M8P2RVB80Wj0Q0080WZDQ02D0Vj8S09JV8P2D
ZBD0TZ/S08f^8`2<ZRL0TZP[09:V<`2?ZC`0RjXg08^Z>P2<ZCP0RZXh08BW>01nZ3h0MjE007JRA01e
Xd<0MZHn07bO?@1eYSl0L:]106n/@01b/3`0Ll0l07C0;`1b`2@0NL0P07c06P1k`1T0Nl0G07c04P1i
`a40O/8@08?34020a180O<4G0080M/0E0P1j`1409`1i`100NL0?07Zm4P1i_1@0NKhC07g05@1m`1@0
Pl0A08Jl3P20_@l0N<4?07_34P1la1H0O<0J07O06P1a`1d0Kl8L06o17@1c`200M;HY07Fa9P1h]280
Nl4F07[54@1maA80N<<F07O43`1fa@T0N<D907O6301gaPT0M/H:07?8301dbA00M<XC06k:601fbAd0
N<PS07O9900207?7:00W07Jn;01l^R/0P[l^08769`1jbB@0N//O07_97@1fb1d0NlXS07c8901lab@0
O/PQ083;6`21bQT0OlTL07W6901haRl0N<De07W5@01bb4@0L<Lf07K79@1ka2L0N[`Z07^h<P1k/C/0
Mj]8086KC`2KRe@0VHAD09=nDP29TTP0Qihe08bO4`29T@@0S8/108n9002=S@00THl00080TI4001D0
TYD109FL1@2BY@/0TZd<096]402;/140R:/@08RX4P25XQ@0QJ<L08Z/4`2=[`l0S[8508^g2028_a40
R<8P08O28P25_1l0Ql0S08O2:P29aQl00P29bQ004026bAL0PlTK08K<8024c200O/`S07o><01ncRh0
OLdR07_<801icR<0N<l[07GB;P1fd2L0M=4S07W?8P1gcRH2077@<00W06gA;P1Uc3T0HLM805jlC01L
]4l0F/1405[5@@1Ia400ElTl05W9;`1La1l0G[hU05Nh=01B[S80CJ4a04VG=P16US<0A8hY04R67`1>
PAD0FG/<05]a1@1KIP80Fe`105U<001EB000E4L004m5001;@`00CD0004a00015>P00?c8003X_000m
;P00?2l003X^000d9`00;Ql000809aX000P07QD001XB000F3P004`l0014<000=1`001@80004003@0
0000303oool000X0oooo01@0LY/007BK001dW@40LiX107FJ0@1fUP40N9D007FC0@1dU`40NID107bE
001jV`00NId007bN0@1mW`80Oil407jP201kX@X0N:H;07J[2`80MjX<02L0N:T;07FY2`1bZ0`0LjH@
07BX4@1eYPd0MZ@<07FQ3`1gX180MJ4B07NS3`1hY0/0MjD:07NV2P1hY@P0NZ8707fT1`1kY`L0O:P9
07bZ2@1lZ@T0NjT:07^Z2P1lY`/0NjH<07fZ2`1n[@T0Njl507R]1P1g[PL0M;4706^`1`1V/@H0I[43
06Zb0@1[/P00JK<106Nc101W]0H00P1V/PP09`1Y/`L0J;@606Vg1@1[]P@0L[H307>f0`1f]@40NKD3
07fd1`1n]@P0P;@207ne001i]P<0LkD706fc2P1T/QD0G;0R05Ra;P1H/3L0Ek8i05Jb>01G/3/0EZa0
05JVAP1IY4P0E:A=04fVE`19ZEd0BJUR04^[H`18[6D0CJYO04jXD`1CYTh0D:9>04ZND`12XEX0?J=O
03nUGP02046VG00W04>YH@10ZfL0@:UZ03^XJ@0jZG00=JMe03JVMP0hX7P0>IYk03RGO00eTGX0=Hei
03RCK`0oTVH0@HYV04J<IP1CWU@0HJ/o07R[9@28YQL0TJ@I09nN602LVaX0V9/N09^M802OXQh0Wj4J
09nO7@2TVal0U9XQ09bL7P2LWR00WIXQ09fD8P2RWB40Wj<N09RQ802IX240Vj0R0080Vj4U01`0V:<X
092X:02=Z2H0T:LW092Z902=YRL0UJ@V09VU:P2BYS80SZ@c08jV<P2CYbh0TJD_08^X<024ZcL0O:Pi
07^W>P1iYc`0MZXg07JX=P1b[SL0KZXm06fT@01cYDH0L[To07O0<`1e`2P0N<0R0P1k`1h02@1k`1T0
Nl0E07_14@1n`0l0OL8?07_1401l`140OL0B07[0500207c04P0W07c0501j`1<0NL0E07c04@1l`1<0
O/0C08304P21_100Q[T>08:l3`1n`0`0N/8=07[35@1k`1T0N<0J07G06@1c`Qh0Ml0Q07Zk8@1h_RH0
Nk`Z07_08P1naA<0OLD@08353`1na0l0N/D<07W7201gb@P0NLP;07O72@1eb0X0MLL;077:3P1ebA00
M/XH07W96`1ic1h0MlXQ0080MLXP02D0N<DT07Zo;01l`bd0NlD[07W5;01haR`0N<LZ07W8:020b2X0
P<@X07o79@20ab00OlLO07c97@1hab40M<H[07?2=01daCP0MLA00775B01^acT0MlLY07c4:@1l^Bh0
N[Xb07Jg?P1lYd`0QYI?0:29D02QPE80W7]B08R?A`23W340Ri/C08ZE0P2:TP00S9400080S8d00P2B
TP009`2EV0D0TJH>09>/402A/Q00Sk0@08bb4@2</A00RZdB08^/502;[1D0T:lA08fc3@2:]PP0RkX=
08S45021`bP0O/4a07k0:`20`2/0QL4/08O69P2:b1T0Ql/G08C97@23bB@0Q</V08;;8P22cB00P<l/
07g>;@1mcRD0Mm0Q07?=9@1cdB/0L=4`06k>;@1bcbL0M]0V07KB9@02073@:`0W06_@;01Sd340GlXk
05[4AP1C_E00C/I@04S7C016aD`0A<Q;04?5BP10`T/0?l9F03jnF@14^E<0AJY:04BNB014XT40@9lh
03nE;013TR<0Bh`M051m401EK`L0Eeh205Q?001HC000Ed/00556001@A@00Cd@004a10013?000@3<0
03hd000o;`00?bh003P/000f:@00;R0000809a`000T091T001lE000H4@005Q0001<=000?200020<0
00<100010000<`00000<0?ooo`002P3oool0501eV@00LYT007FM001cWP00M9h007BL001fV`00MIT0
07JI001hV@00NYP007VI001jVP00NIX007ZO101kWPL0Nj<:07ZV2`1fZP`0MZ/=0P1hZ`d04P1fZ`d0
LJTA072X501`Ya80LJH?07:T2`1cXP`0M:<=07>T3`1bYa00MZD>07NS2`1jX`P0NjD607jS101lY0H0
NZH907RY2@80Nj/901<0NZT907R/2P1iZ`T0NJX;07jZ2P1oZ`/0PJd807f`101f/@D0MJl6076`1P1Z
/0D0I[0306Jd0@1//`40K;8006^b001Y/P40J[@30080J[<602L0J;D606Nd0`1Z^0<0K;H607Fe1@1j
]0@0NkD307nd1022/@L0Q;8608Fc0@20]000O[D107Zb0`1c[`T0K;8;06Fc4@1P]1X0GKLV05Zf:01I
/bX0E[<f05J^@01IYdD0Ej5:05:PC`1<XUL0B:EN04RWG01:ZV80BjUP04^WG@1?XEH0DiYE052GD`1;
UUT0@iaK03jTFP12ZUd00P16Zel09`13ZFH0@JI]03jVKP0lZ740>JId03JRO00bWWX0=9el03JEO00d
T7`0=Xee03Z@LP0nV6T0AY1W0523J01CPf`0G9mF06N^?024[R40SZXB09JX602OXa`0VJ<G09BV7@2K
YAl0WJDH09^W5`2IYA/0WIlP09VJ7P2HW200VY/U09^K8`2MVR80WilP0:2S802GXad0Uj@O09BS7`02
09JS9P0W09FV:P2?ZBT0TZL[09:Z:P2AZRT0TjD[09BV:@2DZ2T0RjhY08^`;027/BT0RK<X08^`8P2;
/R40P[<S07Zc9P1k[bH0N;<Y07Jc:`1f/bX0Mk<a07:^?@1cYd<0Lj=407Bb?01h`3<0N<0]07[0901l
`240N/0M07_07@1j`1P0O<0E07c04P1o`140PL0?07g03P1m`100O/0C0080P<0A02L0O/0?07c0401i
`140OL0C07k04P20`1<0Pl0B07nn5P20_AD0OK`D07W04P1f_QH0K/8L07?0901g_al0N;dP07K09@1e
`2X0NL0[07_0:P1l`2X0O<<Q07_54`1jaPl0OlD<07o52`1maPT0NLX907W;201lb0T0OLD:07c62P1k
b0X0L/L<07W73P1haa80MlTD07[95P1ibQX00P1hbAh09@1jab80O/D/07c3=01k`S40Ml0d07K0=`1d
`3P0L/4d07c4;`1m`bX0O/@V08;77P1nb1h0O<PN07[69@1b`Rh0L/<e06o4>`1]`480Jl=406g6?P1e
acD0O<<^07k0;01j`300NKPm08:PC@2ASTl0Z8U80:b7C`2XPE@0SY=5086M=029WA<0RiH108^B002=
U0000P2=S`02096E000W09BL202>Z1<0SZlA08fc4`2>/a80S;8E08Nb4P2:/Q@0SK8B08jd4P2:/Pl0
R[<;08Ff3026_100R<DJ08C3=@1n^d00P/4h08?5:`24`300Q[l_08G7:021bad0P/`K08387023b200
Q/TQ08C=7P1ocb<0O//Y07W?;01dcbL0L/dY07;A;P1ccc00LL`_07;?:`1dd2`0L]4[0080L=4[02L0
J<l]063;<01Od300D]@i04cCA014dTT0?Le=03k8E@0kbeP0>;mQ03VYJ`0hYW00>ZI/03^cI`10/Eh0
A:QE04NZB`15Yd@0?id_03jJ9`16TR80C8@H055f3`1HH`<0FE4005A=001EBP00E4d005A7001?@P00
C3l004Po0015>@00@c@003hd000l;`00>2d003@W000/8P000P0W6P002@0T6@007A@001L?000A2P00
3`T000h9000:10001@800040000c000000`0oooo000:0?ooo`80L9/00180LYh0076P001cX000MI`0
07JH0@1dV040M9T107NL0@1gW@00O9X107^M0@1iV@00NZ4607VR201gX`X0N:L<07F/3`1gZ`d207FY
3P0W07JW301cYPd0Kj@>07:Q3`1`X@`0Kj0<076P301`X@X0LZ0:072O2`1dX0X0MYh807^O1P1mXPP0
Nj8807VW2P1hZ`X0NJd907R^2P1j[@X0N:/:07N/2@1e[PT0Mjl907^]2P1nZ@T0P:/607f]0`1j[`80
N:h407Ja101_/P@0KK8206jc0@1`]000L;<0072d001a/`00L[<10080K[8302L0J[<206Ve0@1Z]@H0
K[@707Jd1`1j]0H0O;4607jb1@21/@@0Pk4308Bc0@23/`00PK8007bb0@1i/0@0Lk4706nb2@1Z]@h0
I[HF06>e6@1O/al0F[4a05V^@01MZDD0GJ9:05RODP1BWeT0D:5K04fUFP1;YEX0BJIL04ZTGP17W5`0
C9IM04bFH019TV00A9YM04FTF`14ZE/00P13Zf009`11Z6H0?jIb03bTM00hYGP0=j5h03JHO`0eU7l0
=IMl03RDO@0fSWL0>he^046AJ@18UF<0CI5P05>>G@1HUUT0I:U8076b<028/1h0T:hD09F/502NYQ`0
UJPD09:Y5P2E[1d0WZDI09bQ6@2NX1P0WY`N09fM902LW2@0U9PO09NN8@2KXRL0Vj<V09ZV802F[280
TJhN08n]800208n_8`0W08bb9P2:]1l0SK<P08nb7`2C/2<0TJdT096]8`2>[b80Rk<Q08Nd7P23]Ah0
PkDM08Bg3P21^@d0PL0>07nj3`1k^0l0OKPE07ff5P1l^1T0O;HO07Re;01e[c40Mjdh07Nd=P1j^CD0
N/0^07W09`1h`1l0Ml0J07Rm5@1m_Q80O/0@08304023`0l0Q/0>08G03022`0d0PL0?0080P<0@02L0
PL0<07o03@1o_140P<0B08304`21_100Q[`>08>m3P21`1D0P<0E07Zn601j`1`0ML0R07;08`1h_R00
Nk/R07Zm9P1f_2H0NK`U07^n9P20_R<0P<0P07k06@1kaA@0P<H<08362P23a`T0P/T907o92@1jbPX0
N<L907c62@22a`T0O/L;07k63@1laA@0MlHI07O87@1fab000P1ka2D09`1k`b/0Nl4f07O2>@1ea3X0
ML1207Bb@`1c/d<0L[8o07Re=`1e_300NLDV07o:6P1mbQT0O<HN07[59@1ea300K/De06[3>@1Z`cd0
Jl@i06_3>01bach0N/4e07g0<01j_cH0OKA408fGC`2JRDd0YXY:0:^:CP2YSE<0Si]8082U<027Wa00
SIH1092B002AU`00TY<009:A000209:I0P0W08nP3@2?ZQD0RjdC08bc4P2<]Q80RkDD08Rb4P27/Q80
Rk<A08^i4@28^Q00QK`?082j4024`AP0Q/HS08Jn?023]4D0Q/0i08S6:`26`Bh0Okh`0873:`21bb<0
PLdR08G<6P27bAT0RLLT08_:8P23c2D0OL`^07G==`1`d2d0K<X^06g:<`1accH0L]4a07?B:`1ce2d0
KM4_0080Jldc02L0H/dd05[;?@1@cd40Bli<04O>E`0mbeX0>lQT03[9J00jafP0>;]a03J`M@0f[WP0
=:ie03>fKP0i^F<0@KIJ04NgD`18/TP0@jXf042Q:P13UbD0AXdQ05=m5P1MI`@0GET005A?001ABP00
E4`004m6001<@`00C48004`m0016>000?S<003``000k<P00>2d003<W000^8@000P0Y6`002@0R6000
71D001P@000B2@0030/000h7000:1P0010800040000c000000`0oooo000:0?ooo`80L9/00180LYh0
076P001cX000MI`007JH0@1dV040M9T107NL0@1gW@00O9X107^M0@1iV@00NZ4607VR201gX`X0N:L<
07F/3`1gZ`d207FY3P0W07JW301cYPd0Kj@>07:Q3`1`X@`0Kj0<076P301`X@X0LZ0:072O2`1dX0X0
MYh807^O1P1mXPP0Nj8807VW2P1hZ`X0NJd907R^2P1j[@X0N:/:07N/2@1e[PT0Mjl907^]2P1nZ@T0
P:/607f]0`1j[`80N:h407Ja101_/P@0KK8206jc0@1`]000L;<0072d001a/`00L[<10080K[8302L0
J[<206Ve0@1Z]@H0K[@707Jd1`1j]0H0O;4607jb1@21/@@0Pk4308Bc0@23/`00PK8007bb0@1i/0@0
Lk4706nb2@1Z]@h0I[HF06>e6@1O/al0F[4a05V^@01MZDD0GJ9:05RODP1BWeT0D:5K04fUFP1;YEX0
BJIL04ZTGP17W5`0C9IM04bFH019TV00A9YM04FTF`14ZE/00P13Zf009`11Z6H0?jIb03bTM00hYGP0
=j5h03JHO`0eU7l0=IMl03RDO@0fSWL0>he^046AJ@18UF<0CI5P05>>G@1HUUT0I:U8076b<028/1h0
T:hD09F/502NYQ`0UJPD09:Y5P2E[1d0WZDI09bQ6@2NX1P0WY`N09fM902LW2@0U9PO09NN8@2KXRL0
Vj<V09ZV802F[280TJhN08n]800208n_8`0W08bb9P2:]1l0SK<P08nb7`2C/2<0TJdT096]8`2>[b80
Rk<Q08Nd7P23]Ah0PkDM08Bg3P21^@d0PL0>07nj3`1k^0l0OKPE07ff5P1l^1T0O;HO07Re;01e[c40
Mjdh07Nd=P1j^CD0N/0^07W09`1h`1l0Ml0J07Rm5@1m_Q80O/0@08304023`0l0Q/0>08G03022`0d0
PL0?0080P<0@02L0PL0<07o03@1o_140P<0B08304`21_100Q[`>08>m3P21`1D0P<0E07Zn601j`1`0
ML0R07;08`1h_R00Nk/R07Zm9P1f_2H0NK`U07^n9P20_R<0P<0P07k06@1kaA@0P<H<08362P23a`T0
P/T907o92@1jbPX0N<L907c62@22a`T0O/L;07k63@1laA@0MlHI07O87@1fab000P1ka2D09`1k`b/0
Nl4f07O2>@1ea3X0ML1207Bb@`1c/d<0L[8o07Re=`1e_300NLDV07o:6P1mbQT0O<HN07[59@1ea300
K/De06[3>@1Z`cd0Jl@i06_3>01bach0N/4e07g0<01j_cH0OKA408fGC`2JRDd0YXY:0:^:CP2YSE<0
Si]8082U<027Wa00SIH1092B002AU`00TY<009:A000209:I0P0W08nP3@2?ZQD0RjdC08bc4P2<]Q80
RkDD08Rb4P27/Q80Rk<A08^i4@28^Q00QK`?082j4024`AP0Q/HS08Jn?023]4D0Q/0i08S6:`26`Bh0
Okh`0873:`21bb<0PLdR08G<6P27bAT0RLLT08_:8P23c2D0OL`^07G==`1`d2d0K<X^06g:<`1accH0
L]4a07?B:`1ce2d0KM4_0080Jldc02L0H/dd05[;?@1@cd40Bli<04O>E`0mbeX0>lQT03[9J00jafP0
>;]a03J`M@0f[WP0=:ie03>fKP0i^F<0@KIJ04NgD`18/TP0@jXf042Q:P13UbD0AXdQ05=m5P1MI`@0
GET005A?001ABP00E4`004m6001<@`00C48004`m0016>000?S<003``000k<P00>2d003<W000^8@00
0P0Y6`002@0R600071D001P@000B2@0030/000h7000:1P0010800040000c000000`0oooo000:0?oo
o`0D06bG001^VP00KY/0072L001cV@00MY/007FG0P1dV@80MIL207FJ0`1jV`<0Ni`107VN0P1iX@80
N:8207JS1`1dYPT0M:L<07BX301cYPd207BV2P0E07>Q2P1cWPX0Kid;072K2@1^W@P0KIh906bP2P1_
X0T0Kj0706fN1`1aW0H0M9/707JM1`1hWPX0N:8;07NX2`1hZ@T0Mjd907N`2@1h[@T0MZl80080M:l9
00T0Mk0907^`2@1k[@P0Nk0607V^0P1k[`00Mk0007Jc0@1b]0800P1`]@4207Fb0@0307Ra0@1f]080
Mk<20080MK<102L0Kk<106bd1@1]/`L0K[@707Jd1P1j/`@0N[4407^a0`1n/P80O[<1082d001n/P80
Ok8407nd0`1l/P@0N[@407Ne1P1g]PX0M;H<07:d3P1[/A40HjhT05^_=`1OZT@0II]=05bHD`1EVUT0
DiaJ056QF01=XUP0BJ9L04RMH@14Vf00A9IN04JFG`14Ue`0@imM04BUG014Z5h00P12ZV@09`0nYW00
>J5m03VPP00hXG/0=j1k03NIOP0hVGH0>YUe03ZHL`0jTf`0@8mR04Z;G@1=SUL0CY9A05ZOB01/ZcH0
N[4V08>c7P2=[QX0UK0D09Z]602OY1d0V9lH09>Q5P2GX1X0VZ0O0:2M8@2OVR40WYdR09jR9P2IXRT0
T9lW08jT:02C[RP0UJdR09FZ7`2A[R40TK0O08Zd7`0208Re7P0W08Nh7027`1<0RkL?092f3`2<]Pd0
QkH=08Zd302=/P/0RK@;08Vf2`28/`d0S;<=08Zc2P2:]@T0R;D:08Ne2024]@L0QKL:08Bf2P1n]`d0
OKL?07bj501o^Qd0N[@S07Ze:@1i^C<0Ml0c07G0<P1d`2T0M/0Q07Fk6@1j`1@0Ol0B08;04020`100
P/0A08C03@23`@d0OL4B0080N/0C02L0O/0A07jl401m^a40P<0A07fl4@22^A40Q[X=08G03`1m`QH0
PL0M07bn8@1i`2P0M<0T07Fl801g_B<0N;`U07fm9`1k^2X0O[XS07nk8@25^Ql0QKPO08:j7`1l`Ad0
N/DF07o63@22aPT0PLP:07o92P1ja`X0O<P907_:2025aPL0R<D;08O43021`a80NlHH07[66`1iab00
0P1kaR@09`1h`bX0N/<`07K3=@1_`ST0L/1407>^B01fYDP0NZ5707ZW@01b^3H0M<0Y07S:701eaAT0
M/DM0777901_b2l0K<Pb06_7=01WbcD0J/Pc06c1=P1c`cT0OL@c07c0;`1g_Sh0NJY:092BDP2OPe00
YXE=0:R5C`2^RTl0U9m407jY;02:X@h0SY`1092J0@2@V000TiH009JI0@0209FR1P0W096V3P2@[100
S[4A08bh4`27^A80R[HB08Zb402:/100R;0@08Ng4@25]Q<0Q[XC08>l5@24_aX0QlH^08Jm@025[D00
Rl4c08[:7`27a2@0P;`/07jn<020bBX0PlhX087=8@20cAh0QL/U08S88P27b1h0O/`R07G?<@1`dBX0
J/Tc06c<>01]cCh0Kllh077?<01_dbl0L<l[0080JllY02L0HLh/05G>>@15c4T0?lmI03[?GP0jcV40
>]1Q03W@IP0jc680=<AQ03S5J00i`W80<l=b03?5I`0i`e`0@/AE04K2C`18^cd0@KPc03n`=@12Wc00
AXlY05J15@1QJ@80GE`005YC001HB`00DdL00515001B@P00CDH004Xl0011=000?B`003X/000k:@00
=bL0034S000a8P000P0[7000200S60007QD001PB000D30003`T000d7000:1`0010<0=000000<0?oo
o`002P3oool0501`U@00KiH0072K001cUP00N9<007JG0@1fU@80MIL307FF0`1eV@@0N9/407NL0@1e
W`80M:@507FS0`1cYPL0LZ@8072V2`1`XPh0LIl:0P1bW`T09`1_W@L0Ki/406fH0`1ZU`80JiP206jK
1P1`WPL0L:0706fQ1P1]W`H0Kid807:M201bVPX0M9h=07JQ3@1gYP`0MjL907RY201gZPP0Mjd807N[
1`1g[`P0N:h807N/2@1j[@P0N:/707N]101h[P<0N:l207Fb0@1a/P00L;@306je0P1_]@40Lk8107R`
0@1h/@80Mk8407Vc100207Rd0P0W07Fd0@1d]0D0LKD6076e101i]P40N[D007Rb0@1h/`00MK@007Bf
001h]P40OKL507jf1P20]PD0PKH4086h1021^0<0P[L508Bg1`21]0L0N[4<06j^5@1X[bT0IJXj06VM
A@1PV4`0FYEE05RHF01FVUh0CI]N04ZHH`14UfH0@9AU04>DGP11UUd0?iaN04:PG@12YF40@JMW0080
?jUX02L0>JI/03>SM00dXgX0=j5h03ZPM`0iX7<0?:5/03bNI`0jV6D0>iAP04J=F01>RE@0D8Y?05NH
AP1TZC@0Mk0U08ba602@[Q40TjlC09R^502H[AT0Vj@O09fJ7`2NW1X0V9`M09bM8`2JWRT0Vi`]09^O
9`2HY2T0U:D/092W:`2;[RP0T;DL09:e5P2A]180SK8A08nc402?]Ph00P2=^@h09`2;^0h0SKH=096f
2P2E]0X0T[H608Zg1@2;]@<0SK@108bc002>]080SK4608j_1`2@/@<0TK<208nc0@2>]080S;<308be
1029]@L0QkD808Fg2@2:^@`0RkP=08Zg4@23]Qd0O[PZ07Rj<P1g_c00Lk`Y07S0801g`1P0O<0C07g0
5@20`1<0Ol0E08;05022`0h0PL0>07c03P0207Zn400W07g0401o`140OK`@0870401o`140P/0B08W0
4028`1@0P/8L08Jl8@22^BL0O[XZ07_08P1g`240ML4R07O2901j`2P0N[/^07Vl9P1j_B@0PkXR08:k
8P22^240OL0P07W36P1iaQ<0NlX?07_82`1hb0/0MLD;07[62@23a0<0S/0108k2102:`PP0PL<<07k4
401mbQ@0O/LK0080O<HR02L0Ml@Z07W5=P1ha3X0M<8j0770@`1cZ4`0MiQ@07jIB@1oWD80MZli06o1
<01eab40LlPK07;77@1ab2L0L<X`06_8<@1Xac80Jl8f06S1=`1Z`cP0ML<c0832;`1l`3<0MKY007NQ
CP29SU<0V8E@0:1lA`2SPDd0ZXM=09:P>@20ZAh0S:8=08fO0@2=V`40TI/009FJ002HXP@00P2GZ`h0
9`2D/0l0T[<?08fd4@2<^A80RK`B08Rj4P2:^Q00R[D=08Zd3@27]0d0R;@=08fe3P29^A00Q<0E08G6
:027`3`0R:m00931<P2?b1X0Rl@K08Fk:`1n_2X0OlH_087<:P20bb00P=4M08C<8028a1h0Ql<L08?:
7P1icB/0M=0/06_@>01]cS/0Jla206K;@@1[cd00K=0k06_:;@0206;><`0W05_<@@1=`U80@KUN03W8
H@0gd5l0>M1>03gC@P0idd@0>]8o03CC@00`e4l0<m1P03;BK@0gdUh0?l]>04;7AP13_D<0@k/g046k
=@13]S/0A:Hj04NC<P1LOQ<0HVD005iI001JD000Edd005A8001B@`00DTD00513001;?P00AcD0044a
000n:`00>b`003PY000d9`00<RD00080:ah000P091`001lH000K4P005`d0018;000>20002@@000<0
03@00000303oool000X0oooo01@0LIL006jE001^U@00LYD007>C001eU@00Li@107BD0@1fV@<0M9T5
07>J0`1fWP80MIh207NO101fW080M:8707:Q1`1]XP`0Jj<@06fM2P80KiX90100K9P806VG201YUPP0
J9P706^I1P1^V0D0Kih4072M0`1]WP<0KIl7072M2P1dW0X0MIT907VK2`1eW`/0MZ0;0P1gX`X02@1f
Y0T0Mj@707^W1@1nYP80OJL707fY2@1kZ`P0OJd507Z^0`0207V^1@0:07F_0`1b/@40L[@207Bb0`1f
/@40N[0207Z^0P1i/0<0M[4407Nc0P80N;@102L0MkD207Je0`1d]0@0M[D307Ze0P1j]000M[<007>a
001c]000M;H007Ne0@1l]0<0Ok85082c0`25/P<0PKD508Bf102:]@80SkH108Zc0@21[`L0Mjh=06b_
6`1YZbT0I:@j05jJB@1KU5H0FIEP05JFIP1>UVL0B9QY04FJI`14W640@i]J04FNFP14Y5h0A:UV046Y
KP12YW000P0oYFX09`0iXV/0=Yib03NKN00iVGP0?YYh03nOK`14XVT0@9YQ046AGP14S5X0B8]B04nA
A`1IWS/0JJP`07>]8@25/QX0U;0E09V_4P2I/100V:XF09fY602MXb40W9dU09^J9P2PWB@0XIlV09ZU
;P2CZ2d0T;4U096e7`2=/aP0Sk@F096f502A^140TkL>09Bc2`2B/`T0Tk8409Bb1@02096c1@0W08n`
102=/080T[0309Fb0`2A]@40R[<108fb0@2@/P00Tk<009Ba002C[P40U:l309Na0P2B]040U;@0092e
002B]`40TK@209:d0P2@]080TkD509>c1`2G]@X0Uk4=09Bb402</a@0P;TW07Rk;01e_2d0N/0L07k0
5@1n_180O<0A07jn5P20`1H0Pl0D08Jk3`25`0d0O[`>0080Nk`=02L0OL0@07g04P1m`180P<0?0872
4@28`1<0S;TJ08^j7@29^ah0R;PS086k9P1o^2L0OL4P07[47P1haQd0O<LM07o48`1n`2T0OL0W07o0
9@20_280P;XO086k7P1k`1h0N<@M07G8601fba80L/T?06k74P1_aaL0O<D=08S5102B`@80S/0108K3
1@26a`X0P/L@08785P1ob2800P1kabP09`1daC00MLXd07W8<P1haS<0M<Dj076f@@1cZU40NZ1;07jN
A@1g[D00Kl0i077::P1bbQ`0L<XP077:801bbRH0K<T[06_7<01Z`3P0K<0k06c1?01ea3@0NKhe07Vh
?01e[T<0NYm;08:?DP2@S4l0W8=40:23A@2RRDL0SJ@a07nY502@XP/0TI`1092L0@2@W`00U9l309NR
300209N[4@0W096b4@2>^140S[PE08bl5@2=^Q40R[XA08Vl402>^Pl0RkP>08bc1`27]PP0RkL608Rh
2@25_aD0Q<HU08Jm?@27[T<0SL4c08g96028`Qh0QKP^086i<P21`380Pl/`08?=9026d1l0Q<`L08W7
6`2;b1/0R<dM07c>8P1dd2P0K]<k06g??P1/bTD0JLY506K8A01SaT40Hl<m0080FLM402L0CLQE04Nn
IP11]6L0>kaT03S7G@0lc4D0@Lde047>;P13d2/0>]8d03;CA@0de5/0==EK03[CD012cDH0@l8n046f
@`12]cl0@KLo04F`@P19Xc80Di8O05mm2P1SH@00H5@005U;001GB`00CdT00555001BAP00C48004/k
0015?000A3H003he000l<000>Rd003HW000c9P000P0/8@00200Y700091X001dF000G3`004P`000`7
00070P000P40=000000<0?ooo`002P3oool01@1_U`00KI@006fC001aUP00LI400080LY0000d0LI@0
07>F0@1`UP80L9P307:M101dW0H0Mi`407RI0`1gV`L0Lj0906^P301YYQ00KZ0<0080K9l901/0J9d9
06BJ301TWP/0Iid<06RL2P1ZUPT0JYP606ZL0`1ZW0@0K9/706jK2`1eVPP0MiL607VG201jUPP0N9d6
07VN201hX0X0Nj4707bQ101nX`@0Oj8207jU1P1kY`P0NZ/707Z[1P1k[@D00P1j/0D02P1i/0<0Njl1
07f_0@1n[040OZh207b]0P1k/0@0N;4307J`0P1f/@4207Fd000W07Vd0@1i]@40OK<107fc0@1n/P00
O;8007Vb001h/`00NK@007fc0021]000P[4108Bb0@23/P00PK<3086f1P22]0D0R[D208fe002;/`40
Pk<707^b301a/Q@0J:lQ05jY=01PWT@0Gi=B05b?G@1HSf00CIES04NMI@17YV40B:YM04R]F@17[5T0
AZMS046TKP10Y7D0?Z=e0080>im`02L0>YY]03RHL`0gUGL0>iEh046FL`15VF/0B9MV04RBG@18S5l0
AHaI04V<DP1GX3`0Ik4/07Fc801n/QT0Rk4D09B_4`2F[Q<0UJdG09JZ5`2I[QT0VZhP09ZZ8`2HZ280
VZ`O09j/7`2K[B<0T[0R09:o6P2B_a40RkPA08nf402A^A00T/0>096e302D]0D0TkD4092c102B/`@0
0P2E/@809`2D/@40TK4109:e002E]@00Tk<009Bc002F/P00Uk4009Rb002G/000UZd009F_002C/@40
T[0109:c002<]P00T;H109Bf0P2F]P40UKL009Bd002H/`00V[<009fc0@2I/@H0T;8=08Fg6@1j^B40
Nl0W07W08P1g`1T0Nl0B07g03`1n_A<0OL0D08;04P26^a00QK`>07o03P0207c03P0W07k04P20`Q<0
P/@B08S34P23`Q<0QL4H08Rk802<]R00SKLO08Ji8@23`240Ol8N07_56P1jbQD0NLTF07g;6P1laAh0
Nl0U07Zk:@1j^RT0NKTS07Jk8@1g`280Ll<O07357P1_bAh0M<TJ06k56@1`aad0L/TN08784@2=a0X0
Tl<909;3102<a0@0R/D908S52`24b0l0P/HJ0080O/<T02L0N<0]07S6;P1jb340NLPc07G7<P1ca3`0
M;U907VUB`1iWd/0M:];06nl?`1_bC00LL/W073<7`1ec1/0M</M06o;9`1^b2d0K/4h06c0?P1]`480
M/4i07Nd@@1k[4D0MZQ507ZQB`20Ue80QiEA09f8C02SQDD0Wh]308jV;`27[Q80TZL909BS002@W`00
TZ8109FW2P2E[@l00P2@[QH09`2;/aD0R[`D08^l5P29_AL0RkdH08Zl4`2<_a40SKd=096h302>^0/0
QK/;08Fg2@25^Pd0R/4D08O9:@27_S`0RK9008_1=02:aaX0Q[lK08Rj;`25_c80Q<Hb08G:<026cBX0
QM<Q08G>6@28c1P0RLXI083>701kcB00MlhT077A<`1^cCT0J/9706NiB01W[dL0H:a?05fWE`02056/
H@0W04fVIP19ZFP0AJeX042bHP0k/5P0@;5?03nh@011^cX0?l8g03W8A@0fc5<0=/mR03GBG`0id580
@<]7046l>P12/Cd0?kE:03jbD`13YdX0Bi`W05^>4@1VM@@0IFL005mI001JDP00ET/005A8001AA`00
DTH004/n0015?@00A3L003ld0010<@00>c4003`/000d9`00<bP00080;B<000P0:ah002DH000P4`00
6A0001@<000=20001080008103@00000303oool000X0oooo01@0K9D106fA001ZSP00LHl006n=001^
RP00Ki4006n?001^T@00KHh206j?101aTPH0LY@807JF1@1hU`L0MYP:07BO3@1/X@h0JJ<?06RQ3`80
IJ4;02L0IIl:066N301UW@`0IYd:06RL2@1YV`X0J9T606^H0`1^U`@0LID607FD201fUPD0MiP707JG
2@1gUPP0NIT507^M1P1lVPL0OY`307fN0@1lWP<0Oj8507jS1`1jYPP0NjT907ZX2@1iZ0P0Nj/507b^
0`1l[`@0OJl1082[0@23[000PZ`107n^0P1j/0D0O;0307V_0P1i/@000P1l/P009`1m/P00O;<007na
0@24/P40Pk4007na0021/P00Ok8008:a0024/@00Q[<008Jd0026]@00Q;D008>d0@21]`<0Q;D308Vd
0@2:/`00Rk<108Fd1P1i]@P0LK@=06Vc5P1S[RL0HZPh066MB01KVTl0F9]B056ND`1<YeL0C[1L04f`
F@1;/UT0B:iN04FTI@13V6d0@9Qa03jILP0203nDL`0J03Z>MP0jRGD0>HYg03fDM013W6l0@j9Q04JR
E`17XE40C:1?04jQB@1GXSX0IJh[07>h8@1l]1X0Q;8J08Z]6`2A[QT0TjlJ096`702B/Q`0U[<L09Fc
802?/Qd0Sl0H09>k4P2D^Q0209Jk3`0;09>o3P2A`0h0T<0>09:f3@2C]`h0TkT>09;02P2A]PP0T[H:
09Bh2@2D^0/00P2D]0d05P2E/P`0U[D;09Ji2P2D]PX0U;D:09Ng2P2G^0P0UkP709Ff1`2B/PH0U[04
09F`0P2E/P80Tk8209>`0P2>[P40T[4009Je0@2F]000VKD009Jf002F]`0209Zg000?09Zc0@2G]0L0
SKP>08:k5@1m^a/0N;`K07_05@22_0h0PL0>07o03P22_0h0Q<0=08Jm3P24`0h0O/0?0080O/0@01L0
OL8G08356022`1D0RkhE08[05@28^aX0RKTM08Zh7P2:^Ah0R;/N08K07P23aQH0O/`B07c<401jc1<0
NldG07[8701haR<0Nl0U07Rl9P1i`200L<0O07K18@0207K28`0>07C28@1j`240ML0V07nm9`21`B<0
QLLM08[8402;a`/0S/L908o71`2AaP<0RLP408C92P24a``20877600W07c48@1jb2L0MlLc07[6>01g
acL0MLTd07[2=P1g^C`0M:i206ffA`1[`400KLT`06o;9`1_c200Ll`O07?;901]bbX0JlX`06k3>P1`
`T<0L;Y407Bg?`1iZTT0NjU907R`B@1k[4X0PYm@08VEDP2QRU80YhI?0:2:B02?YRd0Q[@C08jZ2P2A
X@40TIh009>Q0P2D[@d0T;8E0080R:dQ02L0QKDM08Jn6028_QL0Q[lK08>m8027`1T0R<<C08ni3`2@
^P`0T[X?08Zk3@25^@/0Rk/A08W34`28b2@0Ql@a08Zm?028`c<0R/DN08K46`28_Bl0Rl0b08C4<025
bC00Q/X]08?=:@25cQ`0QLlL08C?6P1ocR00O<XS07W97`1ebQl0LL/X06g9?01Va3l0J<5305niD01J
YV800P1=WW008@1=TG80C9UZ04Z/J016/F@0?Z=R03jFF`0nWUL0@:MB046cEP0n^VL0>[eb03c2M@0h
afh0>l]M0479C@15_cl0AK=3046aEP13[UT0AZA005>G6@1SQ0P0JW0106EY001TGP00H5P005UA001F
C000DdT00555001>?`00BC/004He0002044a000403hc000m;`00=B/003<X0080;R4000P0:R0002DM
000O4`005Pd001<;000;1@001@80004003@00000303oool000X0oooo01@0JXd206b<0@1^R@00K8X0
06j<001]R@00Jh/006V>001ZS`00L8d106f90P1aS0<0LXl507>@1`1aUPP0LIX:06fR3`1ZXa40IjD=
06FT3080IJ<=02L0IJ0<06JM2P1/W@P0Ji/606ZK1`1]W0D0L9X5072J101bUP<0MY@407JF101dV@@0
LYl606nN201dW0T0MiX507fN101nW`P0O:0807VR1`1hYPL0NZH807^U201lYP/0N:P=07VW301lZP/0
P:/7086/0`22[@@0P:`308:]0@23[000PJh007j_0@1j/080N[4407n`0P21/@400P21/0009`20/000
Ok80086b0024[`00QK4008:^0024[`00PK0008Fa0027/000R;4008Rd0028]P00Q[<008Fb0023]@40
P[@008>e0025]@40Q[D1082d0`1i]`L0LkL9076f3P1/]AD0Ik<Q06J_;P1N[SH0FJ`m05R^@P1AZdh0
D:eG04^]F`1:Z600A:AW04>GK@10RG80@8Yd03n;MP02042>MP0W04>:M`0nRG@0>hid042HK@11Xf<0
A:mE04V`B01@/cd0EK@g05ja;P1Z/b<0MKHK07Ze6024/QT0RK@K08jb7@2B/Al0S[<N096g702A^1P0
TkTE0930402?`0l0UK/?09Bk3P2D^Pl0U[X=09^i3P2K]@h0Ul0@09Vf402F`180UKHB09Fg4P2E`0l0
Tl0>09703`2?]a80SKDH0080Sk4P02L0SjlM09J_6P2H/AX0Uk4I09Vc5`2L]1<0WkHA0:2f4P2O^100
WkL>09jh3`2K]Pl0VkL@09jf3P2L^0d0W;D=09^d2`2K]PX0VkP:09[02@2F`0T0U<0909Jk2@2J^@X0
VkT;09bj2P2E^PX0S[/=08C05@1m`1L0O<0E07o03`21`0l0PL0>08G03P28`0h0Q/4@08O24P27`1<0
0P28`1L09`23`AP0P/4F08Rl6028^1X0R;HN08Vg7029]Q/0Q;/J08>m7027`1d0Q<<J07c6501kbPl0
O</?07g;4`1kbQ<0NL/H07S98@1m`2@0O[PU07^i8@1f^b<0MKhV07Bm:@1g_2P0N[`Y07bk:`1j^C00
P;H^07bh;`1j`Bl0O<HO08395026b@d0S<T;09772P29b0L0QLX808;92@0208783@0W08395022bAX0
P<PR0836;@21aRl0OLXY07c<;@1fac00L/@j06k4?P1YaCh0J/Ld06g:;P1^cBD0LL`V077<<@1/bS40
K<Lg0773?@1b`480M[E207Z^@P1jY4T0Nj9<07b/C01m/Dl0PJ5C08FFD@2PRUD0Z8QF09n;B`2=Y3@0
Q;DG08b]3P2AX@<0TZ4409BV2P2C/AD0Sk@K0080Rk@L02L0Q[/G08K05`28_QP0QkhJ08728023`QT0
QL<G08bj502<`A40T/8A08bk402:_A00Sk`A09334P2?a1D0RlLS08W5;`29`S@0R/@T08c36@25`2D0
QL0`08Bm<P20^S<0P/Dc08G::P22ca`0P/hM07oA8P1kd280O<PO07c26@1g`QT0LLHR06o9:P1[bRh0
JLe005k6DP1H/E`00P1>ZV409`1=XVL0C;MV04S8G@15bU@0A[Y=04>dA010^4<0A;I704:iDP0m^f<0
?<1Z03g3J@0maf40?/UH0473D013^T/0@k1B04B]FP15Ydd0DYdY062<3@1ZO@40Jfd006IV001UH@00
IEh005mH001IC@00E4D00512001:@@00BCh004Li000o<P00?S8003le000k:`00>BL003<X000202lQ
000702TL000T6P007A<001H<000=2P0020H000@1000e000000`0oooo000:0?ooo`0D06f?0@1_S000
KXL006Z8001^R000KXD006^;001YS@00JXl006n>001aR@00LX/107:>1`1cT@X0M9@906nG1`1]XP`0
K:8A06VQ201XY0P206JS2P0W06RQ201/W0L0KiX2072J0@1/VP80KiT306nK1P1`V`L0LY`8076N1`1`
X@H0Jj<606VU1`1[Y@P0KZ@807FS1@1iX`P0NZH;07^W301iZP/0NJP;07VW2`1iYPT0NjH907RU2P1k
Y`T0OJL807f[1@20ZPD0PZ/608:^1@21[P40PZ`008:^001n/000Nk4007fa0`1n/0@0P[430080P;41
0100OJl007jc0020/P00Q;8008Fa0026/000QJl008B`0026/P00R;8008Rc0027]P00QK@008>c0021
]040Ok@10P1m]0405@1o]@80P;L2086h001l^@D0MkT407Ri201h^0/0LkXB06g06@1W_2<0H;P`05^c
=`1F[D80DjY>04nPF@19UVD0@Y5W046:I`11PVh0@89]04:4K00204F5J`0O04R7K@17RV/0@XmW04BL
I@16[U`0BkA904jh>P1J^R/0IKPS072h6`1e^1P0N;TH07jh6@25]aT0QkLI08g06@2?^QL0T;XF09;0
5@2D^Q<0Uk/A09Fl3`2B^Pl0UKX@09>j4@2F_a<0TkXG09jd502N/A@0W[8D0:6`60020:N^5P060:Na
4@2Y/A00YK4?09ja4@2E/a80TkDH0P2@/Q`07@2@[Q/0S[0K08n]7P2A[B<0UZ/U09b]8`2Q[Al0Xj/P
0::Y702Q[1X0XJ`H0:>]602XZQP0Z:/A0:V/4`2/[A40ZZlA0:Ra4@2U]0h0Xk@=0::g2`2N^`h0Vk/?
09S03P2I`0l0X;/@0:704@2I`140R/4D0080Ol0K00P0Pl0D08324021`0l0P/4@08C04`1o`AP0Pl0N
08Zj7`80S;PO02L0S;dI08fj4`2;_1@0RkDF08Zb7P27]Al0P[PO08707`20`280P<0L07[46@1gaaP0
NL/A07c<401nbA@0NlXF07W;701gab80O<0Q07Zh8P1i^R@0M[/V07>k9`1a`B/0M<0]07C1<P1n^B`0
PkDZ08Bd;P1m]300MKD_07Vi;@1i`bD0PLPR08O<6@26c0d0QLX:08C92@22bPT00P25bPT09`24b@X0
R<T<08W84026aQP0QLPS08?98@1mbB@0N</W07;::@1abR/0KlLc06[6<`1]aRd0LlXV07?<:01bcB/0
L<XX06k6;01]aCL0L<0k07Ni@01f/d00N:i307V`B01i/D`0NK9=07nSE026TU@0VHU@0:B7CP2PQTD0
RJ0e07je8@27[A80T:87092V302A[a80T[0R092h8`0208o06P0W08g25@2<`1@0RL0I08O16P24`1h0
QL0H08C05`26_1@0R[dB092m402>^Q00SkhA08fn402?_Q80S<<B08W76P26a2@0R/@[08_58P2=aaT0
R<DK08S0;`27^3@0PkPe08>o<023abT0QLhN08C>7P20dR00P</Q08346`1o^aX0O[TJ07Vl6P1g`1X0
J/DI06C89P1Lac00F<<h0080C/A302L0C<1<04[;C017eT80BMHl04c;=@1<`cD0Al0h04K3@P0k_580
>;mO03[3G@12a5H0@/YC04?5A`14]DP0AZY:04FXB@1;XdD0DZ0_05nD5@1ZP`@0KG4006YX001VH`00
IUd0069K001ND`00ETT00512001;?P00BCd004Xo0018>`00@cH003h`000h<000>2/003LZ000d9`00
0P0_8`001`0V6P008AL001/D000D3`003`X000T500040P00=@00000<0?ooo`002P3oool206b?000B
06b<001[RP00KXT006j8001_S@00LHh0072>001dT040M8X007:8001aSPT0MI4:072F2@1`U`@0KYX4
072S201]X@P0KJ450P1[WP@09`1/W@D0KY/5072J0`1bVP40KY`306jP1`1_WPP0Kj8906nU201`YPT0
KjH906nT2@1_X`T0L:D9076T201bY@H0M:@807>Y2P1dZ`/0M:`;07R[2`1fZ@/0N:P807Z[1@1gZ`H0
N:T407N/1@1k[080O:/307f]1P1m/0D0O:l1082`001n/040O;D007Vf001m]P40OK@207jd0P0207^d
0@0W07Vd001g]000NK<107jb0@21/`00Pk8008Jc0024/P00P[8108Bb0@22]000PkH1086f0@1n]P40
N[H207Ze0P1k]040O;@107fe0@20]@40PkH008:i001l^@80O;T707Vi201c_0X0Kl0A06g06@1Y_b00
H;DZ05^]<`1IYc`0EYe:04fDF018TEd0AHeN04:7H@13Q600AH]L0080BHmI02L0C95H04jIEP1;WU80
CJY;05>dA01K^C<0H;XU06Zg7P1f]A/0O[@I07fe6P20^aP0Ok/H08;05027`140R/0?08k03P2>`180
TkTD09Bd5@2L/Q@0Wk<@09nb3@2M/Pl0Wk@?09^b3`2J/a40WK@@09jc402J/aD0V[0I09NY6`2NYah0
XjHJ0:^V502]XA<0[jDB0:fX4P2U[a000P2O[@d09`2L[0`0VK8=09Vc3P2F/100V[0F09b_702OZaT0
XZTG0:2W5@2MZAP0WZ`H09V]7`2OZQl0Yj<K0:RW5P2XYQ@0[:HG0:nW5P2]YA40ZjPC0:j[4P2^[A00
[K4B0:Z_4`2Y[QH0[[0H0:fb5@2X]QH0U;TG08Zi6@26`1`0Q/0D08?03`26`100RKd?08Zl4023`1D0
Q[/G08ff500208bf600W08^i602?]Q/0S;PK08jd6P2</b40R;DU08Jh:023^bP0P/0N07[46P1caa`0
M/`J07K<501gba80M//C07O85@1haaX0Ml<O07K07P1f^Q`0N[`P07bm8P1n_2<0N<0T07c0;01k_C`0
R;8c096Y<02@ZCD0RjXc08ZX<`22/340O[Ta0837;@21bbD0P/hL087;5022c0`0P//:0080Q<`902L0
R//908[92P29b`X0R<P>08O:5@24bAH0Ol/E07W?601cc1`0L/XT0739:`1_a2l0Kl0[06k6:P1dbbd0
M<`U07?98@1eab80L<L/06c3>@1c_D<0M[Y507JiB@1e^dT0MKM807J]BP1lWU80Pi1E09>:DP2OPd`0
VH=808NJ@01l]2H0R;4B092Y2P2C[Q80UK0L09Fc9`2B`2L00P2Aab409`2@aa`0S/HJ08W27`29_Ah0
Q[`M08>g6P27]AD0Q[P@08bh3@2?]`d0TkD<092k3@2D^`h0UKh@09314P2<`aL0R<DM08_19@2=ab<0
SlLM08c8602;aBT0Ql4b08O3<P25aRd0QLXW08?:8@23bAh0QLhN08798P1o`a/0O[`N08:e7P1m]ad0
N;LG07>k4@1Z`180GLLG05S;7@02057>:@0W04[B=`18eCH0BmP/04gF8`1@cQX0D/LN04c2;017`SX0
B<E804G9B`13c4P0A/Q704K8@`13`cL0BkPg056Y<`1CYB/0G9LS062<5@1WO`H0J74006aX001YI@00
I5h005mI001ME@00GE0005A7001<@`00BC`004Hl0018?000AS/0048d000m;`00>2`003DZ000d;000
=2/00080<2H000P091X0020C000H40004Ph0014<00081P000`40004003@00000303oool000X0oooo
00@0Jhh006f<001]R`00JHX00P1ZS0003P1_S@00Lhh007B?001gU000N94007N?001dU0D0M9H707>M
1`1bV@D0LIT5072Q201aW`L0MIl50P1eV`<09`1aV@H0L9P706jH1P1_W0L0KI`7072O201_X0P0KJ48
072T2@1aYPP0LJD907>Q2@1cX0`0M:4;07BT2@1fYPL0MZD707NX1`1fZ@T0MZX907JZ2P1iZ`T0NZX7
07Z/0P1hZ`<0Ljh307>^101h[P<0NZl307Z_101j/P@0Nk8107^d0@1h]040Mk@107Bf001g]040NK<1
07fd0@0207bc0080N;<002D0N[@107ba0P1o/P40PK8007nb001o/@00Ok8008:c0@22]000P[P107jg
0P1m]@80NKH307Ne1@1j]0<0O;D1086a0022/`00QKD008Be0@22]@00OkL107Ri1P1b_0P0L;d:07;0
301/`180I<0N05bc:@1Q/RX0H;0`05b[=@1GZT00DZTm056V?@1?YSP0D:Ld0080E:P`02L0F:Xa05^^
;`1O/BX0I;HU06Nn8P1^_AX0LKTE07Zj5@22]AP0PkHE08Fi4@24_A00QK`?08^m3@2>`0`0UKT:09?0
302B`0l0T;HA09:b4`2F/1D0Wk8F0:6c5P2O/A@0Xk0C0:2c3`2J/`l0WK@?09nc402N/Pl0YJhA09n[
4P2O[100WJ/D0:2Y502WXQP0Zj4M0:ZS7`2XYAX00P2TZPh09`2O[0h0W[0?09ja3P2Q[`d0YJl@0:Z/
402]ZPl0[J`=0:b[2`2WZ`h0Xj`?0:BY3`2O[A40YZ`C0:BZ3`2PZA40XZ`E0:JY5@2[Y1<0Z:HC0:bW
5P2[ZQT0Z:hJ0:FW7P2YYR80[JPU0:fX8P2WZah0WJhO08nc7@29]QX0SKLG08fg502?]Q@0T;LB09:f
4`2A]a40U;H?08ji3@02092k3P0W08jh4@2D]a80T;LG08bj6@2;^b00R[XR08Ng9`23^R80P;hK07W5
6@1fb1H0MldH07[<4`1gb100LlP?07K6401gaQL0M<HM07746P1_`aX0LL8M06k37`1_a1h0M<DS07_3
:@21_S80QK@f08Z]>`2=[3h0RJLm08ZZ?`1jZcd0Ljhk07O3<01lcBH0OLdR07g=7@21baL0Q<`D0080
RL/;02L0R/X;08S;2@2>a`P0R/L:08K93024aa00O/XB07_;501ibAP0N<TP07O::@1caBh0L;`_06k2
;P1abB`0M//N07S65`1gaQX0L/PW06g6>01]`TH0LKY<07>gD01e^DP0L[E<076XB@1hWE00QY9E09J:
E`2OQe@0V8QB08jL@`20]B80SK0B09:]4@2I/AP0Uk8X08nj:`2BaBH00P2>aR809`2=aB<0S/DS08W1
9P29`200Q;`O08Ng6024]Q<0PkL?08Vg3P2@]@h0TK@@09Be4@2E^a80Ukd@09;04@2Aa1L0SL8L08c1
8`2;aB80R/PQ08c<7@26bbP0Q/P_08G9<@25bRT0P/PW07k69020b2D0Pl/R07o1901j`Al0O;/Q07^c
8`23/R40OK4I07V`4P1c/a00JKXE06335`0205S97@0H053B9`1;eBX0CM8Q04g?6P1@ba@0DLDI04g0
8`18`3<0B<@m04S7=017bS00ClDj04[3=P1<_BD0DkDT05^V6P1SV140JhL:06Yh101UK@40HfD0069P
001TG000HE/00P1MD`003@1JC@00E4d004m3001;?000B3/004Pn0015>P00@3@003d`000g:P00<RP0
03@[000b:P000P0]8`001`0U6`007a@001L@000A2@0040L000L300010@00=@00000<0?ooo`002P3o
ool0501_S`00L8X0076:001/R000KHP0072:001cR000N8h007F?001fT000M98007J>001fUP40MIP1
07FI001cW0D0LY/807:Q2@1bX0X0LZ090P1fWPT09`1bV@X0KiT:06nI2P1aW@T0LZ4;076M2P1`W`L0
LIl707BQ2@1eX0P0Lj08072O201`X0T0MJ4907>R2@1cY0H0MJD207JW0@1jZP<0N:X807F/2@1f[@L0
MJd207R]0`1i[P@0MZd507>_1P1f[P@0Mk8307Ra0P1f/`@0MK@407Jd0`1c]0<0Lk@107>c001h]000
N[<007Vc000207Zb000W07^a001k/@40OK0207j`0`1o/@40Ok40082a0023/P00Pk4008Bc0@23]@00
Q[L108Fe0@22]080OKD307jd1@20]@80P[<008N^0026[`00QZl108Bb0P25]0@0OkH407Nj1P1c^PL0
LL070770201]`0`0JL0H06;07P1W^aX0J;TI06Jf7@1S/b40H[DO06Jf7@1W]aP0IKPG0080IKLH02L0
I[LH06^g6@1b^AH0M/0D07Vl501l_140PK/=08Bl2P27]`/0R[L=08Nh2`2:`0X0R[T<096h3`2D]0h0
V[4<09ba3P2I]@`0UKL>09Re3P2K]0d0X[0?0:2_3`2N/0l0W[8?09^d4@2G/A<0VZlH0::`502S[Q<0
Z:`E0:NZ4P2VYQ00YJ`A0:>[4@2UZa00YjL?0:VY3`2Y[0h00P2U[@h09`2P/0d0X;4?09jb3`2N/100
Y:lD0:Z/602/YA/0ZZLH0:^Z502ZZaD0Y:PA0:NR4P2WYAH0[:/B0:BZ402U[0l0Y;0?0:N_402YZ`h0
Yjl=0:B^3@2YZPl0ZjL?0:ZV3P2[ZQ80ZZlI0:V[4`2X[1<0XJTF09fa4P2B]Q40U;HB092e502<]Q<0
R[DD092e602@]1@0TK<E096e500209:d5@0W09Bc5P2K]A@0UkHC09Bi4`2A^aD0S;/L08Ji7@1o`AT0
O<8G07S7501gb1D0N<dC07W;4@1hc0h0L/T=07773@1daa<0M<HI07386@1/bAd0K<LO06W38P1a`b<0
Ml<S08309`21_B`0OK/e07jm>@1k`CH0Nl0`07c4<P1j`3L0LkPg07K6;P1hc2D0NldV07k=9@21cR@0
Q<`M0080PLdF02L0Pl`?08G9302;b@T0Q/T808K:2@26b0d0QLTB08775@20bAL0OLPP07K79@1aab/0
Kl4g06S3<P1ZaR`0L/PN07S7401haQ@0MlPQ06o6=P1[_dP0K;E@06b[DP1a[U40L:U@076WE01kVED0
RhmE09:5F`2GQEl0U8IS08ZKD@1m^BP0R[PH09F_6P2H/b80U[H^092m:`2>`2D00P2;`2809`2>_B`0
SKd/08Zl<028`2@0R<DM08Jo4P28_A00QkT=08Jj3P26^140T;DD09:h5@2D`1D0Tl0B09;54`2B`Q/0
T<4T08fo:P26`BL0Rl@R08[:8`28c2@0Q<X^08K5<P24bBT0QLDU08;0:P22`S80PLXZ07c48`1j_al0
N;HR07Z_8@1o[AL0OZ`F07Z[701gZA@0LZ`A072b4@0206Jl5@0P05k<7`1EdbH0Dm4P05;?701<bA`0
ClHL04g27`19`2D0Bl<_04g2901<`Qd0D/8V05Fi801J[a00HJ4?06ZB2`1]P0@0K7@106Yb001TJ`00
HV8005mL001QEP00HE<005aB001JD000ETl005E:001AAP00BSh004Pm0016>P02048g000503`a000g
:000=2P0038[000b:0000P0[8P001`0T6P007AD001D=000?2P0020D000<100010000=@00000<0?oo
o`002P3oool0501dTP00LXh007BA001aS`00LX`007B=001eS@00Mhh007R?001gS@40N98107VC0@1h
V@H0MYT107NH101gW0L0LYd907>R3`1cY140Lil@0P1aX1409`1_WPl0KY/<06jJ2`1`W0/0LJ0:07BO
2@1bW@D0MY`507NM1P1fW0@0Mih107JM0`1bW@<0LYl7072O201eX0H0Mid107^R001nYP40OZH407^Z
1@1hZ`<0Mj`107J/101e[`L0LZh7076_1`1e/P@0MK8707>c101c]@D0LKD707:d1P1d/`<0M[8107Vc
001k/`00O[8007jd000207Za000A07j`0022/040Pk0208:a0`22/@40PK8008:`0023/000Pk4008:c
0@23]000Q[D008Jd0@24]P40P;D208Fd0P2:/`400P2:[`005027/000Q[4008Ja1`24]`L0O[L607Vg
1P1b^PH0L[T7072j201^_0`0JK`?06Vl501/^Q80L;PA07704P1b_180M;`C07Rm4@1i`0h0Ml0?0P1f
`1009`1a`100L/0A07Vn3`20_Ph0Pl0;08?02@24^PT0Q;X808Bf2027]`P0R;L908Ze2P2>]`/0T;T:
09Jf2P2K/`/0W[@=09nd402J]180Vk<D09^c4@2P[`l0YJh?0::a3P2Q/`d0X;@>0:2a3`2V/100XK4B
0::`4P2U/1L0XZ/B09n[5@2O[1H0WjhC09f_4@2NZa00X:`A0:B_3@0209f^300W09n`3`2P]@h0Wk@>
0::a3`2V/Q00YjlA0:NY3P2RZ`h0ZZX>0:^Y3`2YY@h0XiX=0:NT5@2ZYQX0YZ<C0:BV4P2YZQ<0YjXD
0:NX502V[a40WZl>09nV4@2/YP/0[j<;0:NS3`2ZYa<0Zj/@0:JY302XZ0h0YZd?0:2f3`2O^Ph0U[P=
08Vg3@29^@h0TkH=09Bc302E/`d0S[L@0080S;PA00T0T;<@09:e4@2@]Q80SK/B08^j5P27`1`0QkdM
07bo6P1m_Qd00P1jaQL0701iaAD0N/LB07G<401`c180LLTC07395@1aaQ`0L<LN06g;8P1_ab40LLDS
07[08P21_bD0P[/Y07jk;@20`C@0O<@_07[69P1laRH0NlT^07k2;`1j^cH0O<8a07S9;@1kbRd0O/``
083=;P24d2X208C<8@0W08?;6P25b180R<X=08W92@2<b@X0SLT<08_84@27a1H0P/LI0835801haB<0
LlD[06nn>@1YaST0JLD`06g;7P1bbQ80MlPE07C=8@1_bC@0KKi806ZaD@1[YEH0KZAG072TFP1cXeT0
N9]H07nBF@1oRU/0OHMQ07b8H01jWE80O[`^08jo7P2O]2@0V[XY09No;@2D`2T0SKTX0080S;@Y02L0
T;@_08Vh;`28^RP0Ql0N08[05@2<_Q00S;`A08Nl4@26_1<0R;<H08nd602D]QL0T<0E08nl502C`A@0
T<@I08o58P28`R/0R;h[08Zl:02;a2H0QlXX08G<<025ac40P/TU08G59024`2/0QK/c0837<P1gb380
M/8U07Rh8P1i/R80NJhF07R^5P1hZQh0MZ<E072R4@1/Y`l00P1Z]1H0801T`ah0HlXR0636701G`Qd0
D<HQ04k07P1@_a/0CkdI04bo901;`2@0Ck`S05Bm9P1L/aT0Hih506^;0P1[O040KFl006UY001/K000
Jf/006MW001QG@00GUL005iC001HDP00FT`005M=001GB@00DdL004Xm0015>000@cL00P11>@001@0j
<@00<RH0034V000^:@00;B<00080:1h000H08aP001P@000C20003@H000H400020@0f000000`0oooo
000:0?ooo`0D07>A001eS`00LY@007:D001`T`00M9@007B@001cS`00MX`007N;0@1gT`80N98107VA
0P1gU0H0M9L807>O301aX@h0KJ<>072T3P1`X@l206fP4P0W06nM4P1aV0h0L9L<07FG2P1fV@P0MYL5
07JI1@1eV0H0MYX507NI101gVP@0MYd307FL0`1fW0H0Lid707>M1@1hX@00OIl0086T001oX`40OJP2
07^V0@1iZ080Mj`507:_1`1^/@L0L;4607>a101f/@L0MK8507F`1`1e/PP0MK4707Ra0P1j[`00OZh0
086_0024/@00Q;000080P[400280Pk8008Fb0024/@40Q;8108B`0@27/@00R[8008^a0029/@40R;41
08Fb0024/`00Q;@008Fd0025/P40Qk8108Rc0@26/`00R;8008>b0022/@40QK@708Bg1P1n^@H0O;T6
07Rf1P1f]PL0L[X706nl2@1b_0`0KkT<06jj2`1b^P`0N<0=0P1j`0d00`1k`0d0O<0<07c0300207_0
3P0W07c03@1m`0d0O[h;082i2@23^@P0P/0808Jn2@2:^@P0Q[P708Bd1`25^0T0R[L:08fg3P2B]``0
UKH;09fd2`2Q]`/0Wl0=0:2f3`2N/`d0V[4?09^a3P2L/0l0Vk<A09j`5@2Q/AD0Wk4B0:F_5`2S[Q<0
X[0B0:6b502Q/Q00X:h>0:2_3P2O/`h0WK8>09b`302H/``0V[<=0080U;<>02L0U;@A09Za5P2Q/1P0
YjhF0:Ba4@2M[Q40WZ`?09^`302T/0d0YZ`@0:JX2`2YYP/0Z:@@0:^S4`2YYQ40YZH@0:^V3P2[Z@d0
Xj`>0:B[302R[Pd0Y:/A0:N]3@2Y[0d0Y:L@0:VS4P2TZ@l0WJ/>09JX5P2P[1L0Wk8E0:6d4P2B]0l0
R[DC08fe502H/aH0SKDA08^f4`2=_1800P2=^Ph09`2;^`d0S;P?08Zj4`26_QD0Pl4K08726P22`A`0
OL0N07^j801k_1/0NL0J07_16P1maaH0NlXF07G=4`1cd180L/TI07387P1abR40L<XU07;67P1ga1`0
OL<N07o39@1k_bX0MlD/07_:;01mbal0OlXE07o9701kabD0NL@X07S0;`1iaBh0NL/^07_=:P1ncB/0
PLhX08;>:`02087::@0W08;;9022bad0QL/B08S82`2<bPT0TLX:08k73@2:`a@0Q<HF08367P1iab40
NL0/07Bn?P1ba3l0Kl<i07;;:P1abah0L<XL06g<9@1ZbS<0K;e606^bD`1ZXEP0KIeM06jQG@1cWUX0
M9UJ07NEF@1cT5T0KX]L072;G01eXTX0O[/a09>l9`2V]BL0Wkl[09_3;02J^bP0TJl^0080SZP_02L0
SjXb08Za;`25]2L0QK/P08Vl6`2;]aD0R;XF08Zm5`2;_1L0Qk<I08fa6@2B]aP0SkhE09:m5@2A`aP0
S/LK08g67P2;aBD0R[d_08Ne<@27]S<0Q<4c08C7;`25b2d0P/DU08739`1n`Bh0PKTc07c2=01dbcL0
LLH]06nn9@1d^RP0L[DI07B`5P1_Zah0K:DF06VR4P1XZA800P1T[Qd09`1T/R00J[<H06V^4@1M/AH0
D[PK056j7`1F^Q/0E[/H05:l7@1A^b00DKLQ05>g8@1L[140IiD306^2001/L@00K6`006MX001ZIP00
JfP006UZ001RHP00GUL005UB001GBP00EDX005=9001EB000DTL004/n0016=`00A3D0040f0014>000
>C00038X000^8@00:R0002DI0002028E000601lD000D3@003`P000d400040P000P00=P00000<0?oo
o`002P3oool0501dR`00Li00076@001aTP00LY<007>C001cT000LhT007B;001dS040M8l107:=0@1b
S0H0LY8;07:F3`1`W`l0JZ4>06bS3P1^X0/0Jih<0P1YU`h09`1[U0h0KYP=072F2`1fU@P0N90407FB
0P1bT`L0MID807>F201cV0X0L9/<072L2`1^X@/0L:@:06fT2@1^Y@D0LZL107FV0P1fZ0<0NJT407RW
1@1hY`@0NJD207B[1@1a[@H0Kk4607:]101f[`<0Mjd607Fa1`1d[`L0M;0707V]1@1k[P40OJh0086]
0022[P00QJl008Fa000308Fb000G08Fa0026/@00Q;8008R]002:[@00Sk40092b002=[`40RZl108Za
0028/`00Qk<008Vc0027/@40R;@108Ve0026]P40Q[@108>c0P22/`@0PK<708>d1`20]PH00P1o`0L0
3@1l]@P0N;L707O0201g]`L0N;`807Vl201j`0X0Okl908?02P1o_0/0N/0=07[03P1k`0`00P20^P/0
5@21`0P0PkL808>h2024^0P0P[P708:j1`25^@P0R[P808Zf1`27^@P0Q;T908Fh2P2:]PX0T;L;09>g
2P2H/``0V[P@09nc4@2P/@`0Wk8>09fa400209fd3`0@09Za402P]140W;8B09Jd402G]Q40V;DD09Rb
4@2K/Q<0VjdK09n_4@2S/140Xk4I09fa3P2H/0h0U;@?09Jc3P80VKD<02L0TkHA09V`5P2L[aH0Vk8D
09Zf5P2G/A40U;0>09J`402G/180UjhC09N_402F[1<0W:PC0:FT4P2ZYAD0XjDA0:ZT4P2YYAH0YJLA
0:>Z2`2S[@/0Z:`B0:Z/4@2[[0h0Yj/=0:jZ3P2ZZ@h0XJX=09nW3P2L[a00W[DB0:>a4@2G/P`0U;@?
096h402>^1<0QkLC08Nf4P2<]A<00P2>^0l09`24_180Qk/G08Vj8P28_B<0P[/T07nl8@24^B80PKhR
07Zn7`1h`1T0OL<E07c65P1kbAL0Ml/J07C<5@1abaL0KlhM07;;7`1hcA/0O</I07c9701iaQh0NlLO
07[68`1jaBL0N/DU07g<901nc1L0OlXC07k:5@1lbah0N//L07O=9`1jc2`0OLd[083<:01kbBL0N/`Z
07c<:@0207g=:P0W07o<:@22bR@0P</P08795P2:b0d0S/P908g62`2:aQ<0R<LF08;07@1n`200O<0W
07O0=`1c_ch0LL110778=`1cbBH0LLTQ06_<901Yac00Jkm506f/D`1^WUX0KYiL072PFP1`XUH0M9]J
07NIFP1bTeX0LHiM06ZDF@1_YDL0PKd[09K0902P`2T0W/4[09Zm;02B]b`0SjTb0080SJLb02L0TJT_
08^`:`23/RX0Q;P/08Vi:@2:]2<0Q[<L08Ng6P27]aL0RkPH08Vg5P2@]a<0U;XC09K25@2CaQT0T/PK
08k96`2:bB00QlP^08G0>@26]3d0Q;I008>m>022`Bd0PLDR07k28P1i_Bd0N;Te07O2=`1fb3T0LL@[
07309P1a_2@0MKPJ06fa5`1Z[AT0Ij<D06>T501TZQP00P1QZad09`1YXQ@0L9P;07:D1`1WVP`0Gil@
05^W6@1K[QX0FjlE05Vb4`1F]1H0EK0E05N`5P1QX`/0I8`206Yj001XK@00IVL006EW001WI@00J6<0
06UP001UH`00Hf0005YB001DB@00CT8004m5001A@@00D4<004To0018>`00@CP004@f0010>P00?Bl0
03@Y000]8@008aX001lG000201hC000501TA000C3P003@X000L300030@00=`00000<0?ooo`002P3o
ool0501bS@00M8d007F9001fRP00Mh`007N;001gRP00LXP006j;0P1/R@80L8@106n8001bR@H0Khd;
06jD3@1`V100KiT>06jI301aVPT0KYL70P1]TPP09`1^S`H0K9L706jE1P1bSP@0M8`307>?1@1`T`T0
LIP:072H2P1^V`d0J9dD06VN501YXA40JZ8A06bT301_YPH0L:P306nY1P1aZPP0L:/:072/2@1eZ@H0
MjT407:Z1@1^[PD0KZh307:Z0`1f[0D0Mjl807>`201d/@H0M[0307Z^0@1m[040Ojh1082]0@20[P00
Ojd008:a000208:c000W086d0@21/`00Q;4008F`0@2:[`40S:d008n`002@[`00Sjl108j`0@2</000
S;8008ja0P2=/080R[8208Vc0@26]040Q;@208>c0@22/@40O[45082c1P1o/`@0Pk@6082d1`23]`L0
PKD707jk1`1l^PP0OKX707jj1`20^0T0OkX9086i2024^PP0O<0707[0201k`0T0P;T80080P[D602L0
P[<708Bc2026]@L0QKL708>f1`26^0L0QkP6092e202?/`D0T[P;09:g3@2A^0/0U;L<09Be2P2G]@/0
UK@=09Rb3@2K/`h0V[4=09Z_3P2N/100Vk8E09jb5@2O/1@0Xj`F0:6^4`2L/`h0W[L>09nd402J]100
WK4B0:2_5P2RZa80XZlB0::b602L/1@0U[4D09Ja4P2D]A800P2E]@l09`2I]Q80V;DC09Fa602G/1P0
Wk@G09je5@2H/1<0UJhB09R]502I[QL0V[0E09Z`502J[Q<0XjdA0:>_3P2SZ@l0YJT>0:F/402YZPl0
ZJ`>0:FZ3`2XY100Zj/A0:Ra3P2R[`l0ZJDG0;>S5`2TY180Xj8C0::Z5P2S/A40Wk8=09Rf402D^QT0
TKlF08bn4@25_A00R[X@08^h3P0209Fg3@0W09>f3`2?^a@0S[dI08Zi8@24^2D0P[XU086m8`1n`280
Nl4M07c06`1na1P0O//H07_=5@1ec1H0L<hF07?>5`1hcaH0N/lD08?>5026cQ@0Pl/G083:6022bAL0
PLXC08G85@25bQ<0Q/TH083:4`1kbQ40OLXD07S=5P1fbR40MLP`07O8=01jbC@0O<T/07S7;@1ebRh0
MlX]0080N/`^02L0OLd_083;;`1nbb`0PL/U08G<5@28bPd0S<P:08k73P2:aa00Q<0K07o1801n`BD0
Ml@[07Fm=01_^T80KlHk06o;;01]bR@0J</V06O5<@1Z]dP0KZUA072ND@1^XEH0L:=C07BPD01cUeP0
MiAJ07B>GP1iRV@0KY5R06jTB`23^RT0TL0U09[0:P2H_2`0U;X_08fa<02<YCL00P2=XcP09`2=Zbd0
RJh^08J_<@29/S<0S:d^08fX;@28YbD0QZ/M08^f4`2<]a<0RkPC08fn5@2C`1H0ULDH09;56P2Bb1`0
SL`M08c;8028bC00PL=3086aA026ZdP0P[Pn08?3:`1oa1`0O<<K07Zn:01h_C@0L[`i07:o=@1c_BD0
K[LO06bd6P1_]aX0L;<G06^]5P1XYa<0HZTE062[600206BW6P0W06nG401cP`40KgX006eo0P1XQP@0
HH`:05bA4@1LUQ80G:8E05^V5`1KY1L0GZ<@06RE2@1ZPP80JW<006MS001UGP00IF00065O001TG@00
He`0065M001PG@00G5D00599001<@000Bcl004Y0001;@@00BT8004Tn0013>@00?cX0044h000l<P00
=bT002hT000U700081T000806a@000D06A@001@?000>2P001`800081000g000000`0oooo000:0?oo
o`0D06b4001^P`00L80007B1001dOP00Lg`007>0001_Q000JhT406Z:0`1/P@40KX8006j21P1/SP/0
Ki<<06fE2`1ZV0T0KI<706nF1`1/U@H206fA1@0W06jA1@1/TP@0Ji4306^>0`1YSPD0KIH:06jJ2`1^
W`/0Jil:06FP3`1UWQ@0IZ4F06JR4`1XY140KJD<072U1`1aYP@0LZP6072Y201^ZPP0Kj`907>Z2@1a
Z@H0L:`407:/101cZPH0MJT507JZ1`1g[0P0M:d807>_1@1h[P40Njd107f_0P1o/0<0Nk4207b`001m
/@00P;800080O;<002<0Ok0207jb0022/P00Q;8008Z`002?/@00S;4008n_002BZ`00U:/009>^002B
/040T[4308nb1029/P80R;4108Rb0P2:/P80Q[40086a0@1m]@<0O;D308:c0`23]0@0QK@708Bg1`24
]P@0Q;P808:l1@1o]`H0OkL807ji2P1o^PT0PKP707bi1P0207_01P0A07ji1P23]0H0PkD708>e1`26
/PH0Qk<508Ne1P27]0H0RK@708^d1`2>]`L0UK@:09Be2P2D`0X0UL0=09Ne3@2H]a400P2I/a40602K
/A80W[8@0:2`402O/@l0Wk4=09j]3`2M[a<0X;8A09na402P[a80Y:dA0:6`3P2Q/Q80Y;4C0:6a3P2Q
/1<0Y:dF0:J]4P2S/180XK0E09b_502J/1<0UkDD09Fc5P80UkDD02L0UkH>09Fh3`2F]QH0VK<C09Vg
5@2L]1H0WK4E09:`5P2DZQT0UjTM09ZZ8@2H[1l0V:TP0::/702UZQX0X:TD0:FW5@2X[AL0ZZhD0:^/
502V[A<0[:TB0:b_4P2//@l0ZZl;0:^]3@2`ZPl0ZZ@?0:fT3`2T[a00W;@@09Bh4@2A^AH0SKXL08Zn
6@2=_Q@0Q;/A08:j502:]Q<00P2?]A<09`2>]a/0SKTG092i4P2;^QX0PkTS07c0801haQh0M/XM07W:
6P1kb1H0Ml/C07S<501jd1D0M]0E07O?6P1hcAl0O]0E08G?4P26cA<0Pl/C08C<6024c1T0QlXC08K9
3`26bPl0R</@08W:4@25c100Ol`>07c<4`1gcaL0NLdM07W:9`1hbR/0N</[07W;901gbRD0N<X[07S9
<00207S9<@0G07_8<`1obc@0OL`_07o::01mbR@0QLXG08O63@27b0`0Q/T>08G26025a1`0Q<DS07_9
901j_Bl0LKU50775@@1^bc<0J/T[06S=;P1X`cL0Jk=<07:TD01jWU<00P1gXTl03P1hVE40NY5F07V<
F`1jR6D0MhQ]06bJIP1`/4P0Q[/X096k:P2B_C00S;h`092a<02AYS80SY`l0P2<XSX09`2?/SD0RZ`g
08RU>`2<Xc`0T:4k09BH=P2;VbT0RJHM08nb402=^`l0Rk`A08k4602@b1d0SlPL08o57P2>b1l0S<TP
08c88P26aC40Pkhn08F/A@27Y4P0QZa008>m:P27`1/0P<8D07c06@1h^b`0LkH^07:e9P1`/A`0J;4H
06B`5@1X]1/0Jk<L06R]5`1U[1D0Hj`F06JY5P0206:T600W07B@3P1`M`40KFh006a]001YL@00I742
05ic1@1MN@L0Gh4;06N72`1ZPPX0KWl6071f0`1^K`40K6P006AP001QF`00Ge/006=K001QF@00GU<0
05YF001KEP00G5L005I>001<A000Bcd004Ll0019?000Acd004Hl0014>`00?c/003`i000l=000=B/0
02lP000U5`0071<000806A8000D05Ph0018;000;1P001P800040000g000000`0oooo000:0?ooo`0D
06Ma001XMP00JgP006il001_N`00K7d006ao001^P`00K8@106V90P1XPP80IhD206F10`1ZRPP0JYH:
06ZG201WW0L0IY/706>E201TU0X206JB2@0W06NC2@1VUPX0IYL:06JG201XU@T0JY/:06ZP301_XP`0
Kil:06fN3`1`W180Ki`B076O4@1`X`h0L:D907>S101dX`80N:T107F]101a[PL0L:`9076Z2@1dZ0P0
LZd307>/0`1b[@L0Ljh6072[1P1e[@L0N:/507V[0P1mZ`00OJd1082_0@1o/P80O;4107ba0021/000
Q;400080Pk0002L0Q;01086b0022/@00QK0008^`002:/@40R[<208^^0P2CZ`40UJ`009>_002C/@00
TK4208na0P29/P80RkD108^a0@2=/040RK4008>b001m]`80OKD1082d0@23/`40QK8508Nc1P28/`@0
R[@408Vf0`23^0H0O[D807Zh2`1k_0X0Mk`807Nj1P1k^@H0Ok@508Fd1P2:/@H00P29/PH09`2=]0@0
RkH708Zg1P2<]@<0S[43092c102E]@T0UKL909fe3`2J]Pl0V;L>09jh402O^100W;H?09Ze3`2L]A<0
WK8@09nd3P2M/Q80VZh?09f_3`2M[a@0Vk4A09j_3P2Q[a40Y;0>0::b3P2R/A00Wk4@09^d402L/@l0
X[8?09ne402Q]100WK4?09ba4@2L/180Uk8F09>a6@0209R_5`0W09^`4@2N/@l0Vk0C09^b5`2T/1L0
Xj`G0:2/6P2Q[Q`0UJ`H09:]6@2KYah0WJHL09RX7P2MZ200Y:LN09nU7@2OZ1`0X:dL0::_6P2SZaP0
WZ/L0:F[702[[AP0ZZdD0:J]4P2X[Q@0[j`B0:B_3P2T]140X[LF09jg5@2M]A00VKL?096m4`2;`1<0
RL0?08Vi3`2;]Q00RKT@0080SkP@02L0R[TD08bk4`2<^A40QK/M082m901ka1l0M/LN07K;701ecAT0
M/`D07;;4@1bc180N/`E07g=601ncQP0PLhJ08S=4`25bQ00PlX>087<3`26cAH0Q/XH08W95`29bA@0
RLLD08W;5028cA80Pld@087=4@1lcQH0N<`K07g<6`1jbb00N/TT07S9:@1fbB@0LLXW0779<P1gb3X0
0P1fb3/09`1ibCP0N/Tc07c<<01kbc80OLX_07_=9@20bQ00R<X;08c83026bQ<0Q/LJ08K67P1nab80
P<0/07Nk@`1c`T<0K/Tk06O==P1WcCT0JKi006jSB@1kWTh0PY]A086JD`22Ue00PYIB08:?E027RUh0
P8AX07V7K@1_Z6<0N[m2096l:02?^2h0Q[X_08Nh<P2=[2l0TJ0a096M>@0208jR>P0W08jZ=P2;[CH0
RjHf09>O>P2HVcT0WiTc08jM:02;Z240TKDF092k502=`A@0Sl<F08o6702=c1l0Rl/M08k;7029bAh0
R<PT08C6;`24_3d0QZ]008NRAP21X4@0Q;8`08>g701o_Q<0OkdC07Vj701c^Ad0L;4K06b^6P1/[aP0
IJlH06Nf9@1W/RH0HJdO06:Y6`1WZQL0JZ0B0080JI<?01d0LHD706mb0@1ZJ@00J68006MT001UH`00
H68005iO001OG040H6<106AQ001QGP00Heh006EP001QGP00Ge`0065I001NE`00GeL0065D001ID000
E4X005E=001ED000Ed`00593001:?@00B3X004Hi0002048i0008044k000n>000>S@003`b000g;P00
;b<002@H000J4@0201D@0004018=000?2@002@H000@103P00000303oool000X0oooo00L0GVX006Ic
001XL@00J78006Ug001WOP00IX400080J88000/0JXL106B40@1RQ`@0IHT106:=1P1SVPT0IY`806:Q
201TXPP0I9d;06BI300206FI2P0W05nG3@1OW100Gi/?066N3@1RW0P0Ij0;06bS301_X@d0L:0=06nM
3P1bW@h0MI/>07VM301eXPX0MZ<607JU0P1gX`40NZT007J]0@1b[PD0LZ`707:/201eZ@H0MJX107B/
0`1dZ`H0L:`606nZ1P1f[0H0NZP207fY001mZP40OJl107f`0P1l/@80O;4107n_0022[P00Q;000080
Pjd002L0PJ`007j`001o/@00Pk4008J`0025[`80Q;4608J^1@2>[P40TK41096a0P2B/P40TK80092b
002?/@00S;8008b`002;/@00RK@008Jd0@24]P@0Pk@208Ja0@25/P40Q;D608Nd1`29]PD0R[<208Jf
0@23^0@0OKH707bf2@1j]`P0NKP607^k1P1l^PH0P[@608Bc0`26]0800P28]0402@2?/`40TK@208fd
0P2A/P40S[0008fc002B]@d0V;D=09bf3P0209jh3`0L09fg3P2Q]Q80WkP@09Ze3`2L/a00Wk4@0:6a
402O[a80Vk0A09V^3P2H/Pl0W;4@09fb3`2N]A40Wk8@09fb402M/`l0W;8?09Nc4@2J/@`0Vk<?09fc
4P2L/0h0WK0A09ja4`2L/A40VK8C09>e5080V;0A02L0V[4A09ba3@2O/@d0W[4F0:F^6`2S[AP0XJdL
0:F]7`2D[QT0TJ`M0:6U8P2PX1/0U:<N09fV802YWb40Z9/Q0:>N802LYb00XjTK0:JY602JZaT0Vk4L
0:2_5`2V[A@0Y:`D0:R]4P2N/Q00VkDA09fa4`2K/a@0V[4C09j`4@2I/Q40U[8G09Ff5P2@]a@0R;DG
08Vb6@2?]@l00P2C]@h09`2C]1X0SK<K08bf7@29^b80RL4R08K48021aQd0O<PK07S76`1gbaL0M/XE
07W:5P1laaP0OLHI07g96@1obQP0Pl`B08?:3`22b`d0Pld?08C;5`25bQX0R<XF08[95029`aL0R/DE
08G95`24baL0P</G07c=5`1ic1P0O//I07_<701fbb80MlXZ07K:;@1`bb`0K//f077:>`0207G8>00W
07K8=`1ecC80N<he07_;>P1hcC<0N/dX087:5P29b@h0S<H<08K74`23aaL0P<HM07_48@20`B/0Mk`n
07Nk@`1c_480LLDl07G0@01h/4@0NYU908>PC024XE80QI]I08RFEP25UEL0PY=F07jBG@1iTV@0M9iT
07JiB@25_S40U;LX08ff<P28]SH0RZhh092U=@2AXCD0U:0l0080TjLm00d0UJPi09:Y>02BZ3D0Wilh
0:^G=@2[U3<0U9TX08ZU9P2:/R00RkXL08g56@2<aaD0R/LH0080S<XN01P0RLLO08[87`25abH0Q/Db
08>k@`28[4L0R:=9082JA@23YC00Pk<P08Bk4`20]@l0N[TB07Bf6@1a^1l0KK8P06Zb8P1W/RH0I;La
062e>@1K/CH0HjLX06RS701aU`h207660`0W075i0@1ZJ`00JfH006MR001SG`00HUl0065M001NF`00
GED005YG001KE@00FU@005QE001KE@00FeL005iH001MF@00FeD005eA001ME000G4`005I<001BC000
DDT00558001@B000BDD004Do0013>P00@SD004<h0011?000?3T003`c000k=000=bl0030U000R6@00
7A@0008050l000@03`d000d900071@000`00>000000<0?ooo`002P3oool0501QL`00HGP0065e001Q
MP00HG`005n0001PPP00Gh@00626001RR000GXP00626001NS`40H946062J2@1PW0T0HZ8>06BT401S
X@l0Hid=0P1PV``09`1LVPd0HI`A06:K4@1WV`d0I9T906jM2P1bW``0LYh>072O3@1_WP`0LI`907NL
201gW@H0N9l707FR101eXP40Mj4007NU001bZ@80MJd407B]1`1dZPH0MJP307F/001hZ`40N:/307JZ
0`1hZPH0NZX707R[0P1iZ`00OJh107j_0`1n/P<0Ok8407na101o[`40P:h0082]0@0207f]0@0W07b^
001l/000N[4007j`001n[`00P;42082a1P20/@D0RK0108j`0P2=/0H0S[8308nb002>/P00SK0008j^
002:[P00S:l008Za0029/`00Rk<508^c0@2<]040R;<308Fc1`29]0P0R[D508Ne0024]`80P[L0082g
1`1o]PL0OkL707ji1P1o^@H0Q[T608Rh1@28]040R;800080Q[<002L0RK@008fe002?^000SkH108^d
0@2=/`40Tk@909Zg402P^@h0X;P>09bh3P2K]`l0WKD?09Zg402G]`h0V[8@09jc3P2O/Pl0VZh@09b/
402M]0h0V[0B09n`4P2O/`h0Vk@B09^c4`2J]A40V;@B09Vc402J/@l0WK@>09fc3@2J/`d0V;4B09^b
5@2I]@h0VK8>09Ja4`2C/a000P2G/a409`2Q/1L0WJl>0::`3P2R/AL0YJlD0:>^402M/AL0Y:hJ09R]
702LZA/0WJDM0:6R7@2NWah0WJ8K0:JO702SVR<0Y9HW0:FP;02TXb80Yj8M09fU8P2OZR@0YjTM0:RZ
5`2XZQ@0WJlC09Nc6`2L]AH0Y:hA09Jb5@2F/Q<0XZhA0:6]402I[a<0VK4D09b`4@2@]1D0SKLF092h
500209>d5P0W08Z`7@29/B80RK<X08nn:02@`BP0RL@W08G38P21`b00Nl@P07g76P1nb1H0Q<@G0875
6P1oaQ`0OLTI07k85P1nba<0O/X>07o;401mcA@0P/dG08G:6P26ba<0R/XD08W26P2:`QX0Q<<J0877
6@1ob1`0Ol/G07g;601nbA`0O<TS07O79`1faS00M/T]07C8;P1bbc40LLXh0080M<Th02L0LLXi07?<
=`1dbcl0N<A307S8>P1ic2h0N/XN08C84028a@/0Q<P=08;84P1laAd0NL@U07g0;P1f`400NKE207ZY
A@23[d00TK4n08fX?@26X480QZI808RSDP28WET0RIaI08JKF`21XEP0NJAJ076/F`1b^D`0O/<b08Zo
:P2C]c80T[8e092Z>@2CWd00X9ln0::R?02OXCd00P2JZCT09`2GZSP0U:Hf09NT<`2TVSD0ZiHg0:^D
=02HWR`0Rj@Z08N_9P29_2<0QlPO08K<8@2:cR@0R=4[08C=;@26c2T0QlP[08C4;`22`3T0OK]908>/
CP22ZTT0PZU2086a<P21]R40PkLD08R]3P1k/Q80Mk<G07>_701]ZR00Jj/K06jW6P1^Yal0Jj<O06NH
7@1VSAL0JhD@07:11002071h000W06a^001VI000IfD006MQ001TF`00HUL005iI001LG000FEL005MB
001ECP00F5<005MB001HE`00Fe@005YH001HE`00FU@005]B001KD@00F5<005MA001CBP00CT@004Y5
001>B000Bd<004Ln0013>P00@3D0048m0014?000?CL003/b000g=000=RP002/R000T6@006aD00080
4``000@02`L000X600060P000@00>000000<0?ooo`002P3oool0501RN`00HX400662001KP@00G8<0
05Z4001JQ`00FhP005b5001KR`00GXT106290@1QS@80GXh705jH2P1JV0/0GYlA062U4`1RXQ40IJ4<
0P1QV@`0601OUP/0IiT;06^H2P1_V0P0L9H7072I201_VPT0LIh:07>P2P1dW@P0MY/307RK001gU`40
MY/207JL101fX080N9l107NR001fY`80MZX407N/1@1f[0@0M:d207N/0080NJd000@0N:h007bZ0`1l
Z`D0NZh20P1i[`001`1i/080OK8407nb101o/`@0OK0107f^0@1g[@400P1g[`403@1f/P40O;4007Va
001j/000OJd0086_0@24[P80RK4208b^002>[@40Rk0308nb0`2?/P000P2@/000102?[`00RJh008N`
002;[`0208f`000B08^d0@2;/P80R;4708Ja1`27/@L0PkD208Bg0024]`40QK@008Jd1026/`D0Qk@5
08Ni1P28^`L0RkP608fg0P2<]@40R;@00P24]0402@27]P80R[D108jf0@2@]0<0SKH208ne102B]`T0
VKT?09jj300309fg3`0K09nf4@2P^140WKP=09jc2`2I]@/0V;@<09fb302O/0l0X:`=09f]2P2K/0`0
WK@=09fa4`2G/100U[@@09Jd4`2G/a40W;0A0:2d3`2L/`d0V;8@09^a4P2K]@h0UKD?09fa4`2R/1<0
V[@C0080W;4H02L0YZTG0:>/4P2U[AH0Xj/I0:JY4P2SXQD0Xj@M0:bT5`2VXQT0XJ8K0:FP802XX1l0
Yj0L09nT702VXal0Y:8N0:ZM8P2XWB<0XJ<S0:FV802UZ280XZdN09^_6P2L[1P0WJhE09R_4`2C]1H0
Vk@D0:Ba5P2F[1P0WjPG0:NY4`2L[AH0VJlK09Bc4P2K[Q/0WjhQ0:2`7P2O/A/00P2K[ah09`2C/240
Sk0W08Z_:P2<]b`0R[ha08W1:P29_bH0Pl0P08317@1oa1d0PL<J08Nn6`2;`1d0Rl0P08S38023`Ah0
Q<8I08;35@22bAD0PL/D08G;5@24cQH0QLd@08O;4@28bA`0QLTJ08;66`1oaaX0NlHJ083:5`1nbaT0
O//L07c7901gaRP0MLP[07O6:@1gb2h0Lld^073><`02073<=P0W06o>=P1`cC`0LLY207VfB01h_d80
MlTk07G7;P1ib1/0P<L=08G72P24bPd0O/XE07S67`1k_B`0O<0f07bf?01k[440Oji008Rb?@28[C/0
PZY008B[@`24YTT0PJM?07nVCP20YE40Nja@07FdD@1b_D40O<D^08[5;02:^380T[0h092S?P2AVd<0
V8m70:RG@02[XCl0Yj0n0080WYhm02L0Vidg09VP=02NVc@0ZYPe0:ZL<P2WWC80VZH]08jX:`2>[b/0
Qk/W08G;8P26cBD0RM0V08W><P24c380QLXf08?:>P1obC/0P<0m07fjAP1m/4P0P;5107nc>@20]2d0
PK@M08NX4P27W@X0PIh807bN301eW@h0MYP?07>C301dS`P0MHh707261@1/N@@0Ifh106=T0@1THP00
0P1VH@009`1PG`00GE<006=H001SG@00HEP005aC001JD000FU8005]C001FD`00EU4005U<001GC`00
EU<005ME001IE@00F4l005M>001JD000F4l005I>001GC000EDX004e40018@@00BD8004Y10019@000
@c/0044f0013>@00?SX003/h000h=000=2h002dU000W80008AX001`B00020109000400L500040`00
0P40004003P00000303oool000X0oooo01@0HWL006Ei001WP000H7h00623001PQ@40GhH105n8001O
Q@00Fh<105n50P1RP`40HXT305b=201MT0/0GIH=05fG3@1QW0`0HiX<06JH3080I9X<02L0JY8;06jD
1@1fT@<0M98307:E1`1cU`P0LI`507>M1P1fW`H0Mi/507NI101mV0@0NiT207NK0`1gW@H0N9l407^P
0@1iX@00N:H107JW101gZ@D0MJT607B/0`1e[@40MZh007N_0@1h[P<0OZ/308:Z0P21[`40OZl007^_
001j/P00O;8107n`0@1o/@40P:l1082]0@1j[0<00P1d[@<09`1h[P40OK0007ba001k/000OJ/008:_
0027[P00RK0008Z`0027/000Qjl008b`0@2<[000T:`0092]002@[P00Sjd008^`002;[`00S;4008^`
0025]000P[8208Be1`21/`@0PK4107nd0023]040Q[@108^c002;/P<0Rk<408ba1`2=]PL0R[L808Zg
1@2?]`80SK@108Re000208:f0`0W08Vf1`2;]0<0RkL208bf1P2A]0<0T[@209>i2P2J^0d0V;/<09^k
3@2M^0d0X;T<09nk302Q^@h0XKP=0:6c2`2I/P`0W:l?09na3@2N[A80VZ`;0:2`202I/Ph0W[<@09^c
3`2H/`d0Uk4?09Rb3`2L]0l0X;0B0:6a3@2M/Pd0W[0D09fc4P2M]@d0Vk4C0:2c502V/@h0W[0G0080
XjlK02L0Z:/G0:RZ6P2]Yb80[J<E0:RP502[VR40YI`H0:NO4P2UWQP0Xj0F0:>T602UXaP0[J0K0:BT
7`2SYAd0Y:@K0:VK7@2YUal0ZIhQ0:jU702ZYa/0XZ/M0:>b7P2R[aX0XjlB09^`4P2F]1X0X;4@0::^
3P2O[0h0VjdA09B]5P2E/Q<0Uk8>09Be5P2>[R00TjdS09V/8`2SY2`00P2LZ2d09`2A/2/0RkDY08Be
:@22_b/0Pl0Z08C29`27`B40Ql8L08;06P21`A`0P/8K08:m6@24`Ah0R/8R08[38P29`ah0Ql4P08?2
7P22aa`0P/`J08?<5@24c180QL`@08K=4023baT0PlTK08S28025`1h0Pk`K08;46P21aQl0PL8L07g1
8`1ia2H0M/LT07W<8P1fbb@0L/dU073?;@0206o?<@0W06g>=01]bD40K<E=072gC@1d^D80MK`l07K3
=`1ea2T0OLLA08;42P27b0X0PL/?07k95@1n`b40O[h^082h=@1i/S`0Nja107f]?`21[Sh0Oj`m08:Y
@P20ZDH0NZa507B_AP1e/D/0M;]807K3?`1ma2`0QL4X08S0<@2:ZcD0Tj<k09BNB02ATdP0UHY709nC
@`2TW3l0Xidk0080Xi/j02L0YiTi0:NG=P2YTcT0/iLj0:jM=P2UWS40WJH_09F[;P2:[b/0R;hV08C;
8`2:cbD0RM0U08SA:`26cBh0PlLc08?8=@1maSH0Ol<e07o0>P21_3P0P;Xe086k;01m]R00OJPC08>H
2027S@40P8P007f:001hQ`00MWl007Ai001fL`00LWD006i^001[J@00HV80061K001IEP000P1NF000
5@1KF000Fdl005QB001LD`00H5L005eC001ICP00Fe0005QB001GD000FE4005Q>001FCP00ET`005I=
001GD000ETd005E?001HD000F4h005I<000205E:000@04i40019?P00BSh004U00018@000A3X0040g
000o=@00?3X003/i000g<`00<BT002TR000T70007aL001PA00803`D000<01@80004100010000>@00
000<0?ooo`002P3oool0501UN`00IgP006Ug001XM`00IW`006J2001VQP40IhP006>5001RO`40Ih@4
06Z00P1VR@@0I8T706>>2P1QU@/0Hi@:06NC1`1/SPH0JX/60P1[S@L09`1[T@L0LHh307:=001eR`80
MI4407:D1@1dVP<0MI`407NN1@1fV`P0MY/;07NN3@1hW@T0MYl707:Q201dX0H0MZ0407JU101fZ@D0
LjX807JY1`1dZ`L0M:d507J_0@1f[P40NJl407Z`1`1o[P@0PZ/008B]001o[`00NZl007Jb001j/P40
Njh107j]0021[000PJ`207b_1@0207R^100W082]0P23[P00PJh0086/0022[000PjX008R[0029[P00
RJd008J`0028[`40RJh108Z]0P2:[040SJl108f_002=[P00Rjl008b_002>[P00Sk4008Nb0023/P40
P[8408:c1@22]0<0PK8208F^0P28ZP40S:l008fb1@2>/PL0Rk<808bd202;^0H0RkP308^h0P2;]`80
R[D30080QKH50100SKD6092f102=]P@0U;H409Je0@2G]000TkP;09Fg302G^@X0UkX<09fj3@2P^@`0
WkH;0:>f3@2S]@d0Wk4<0P2O/Ph01P2I/``0W;8>09ja2`2H]@/0VkD?09fb3`80VKH;00d0WK<>09Vd
402P/a00YZl:0:>_3P2M[A80XjhE09bb402H/0h0XK0A0::a3P2V/A40YZlI0080Xk0G02L0W[0J0:N_
6`2/Za`0YZLD0:>T702[VbD0Wj<I0:>S7`2WWAd0YilD09N^5@2Q[1L0/IlL0:jN7@2TY1d0Wj4O0:RM
7P2/W1d0ZJ0I0:NT6P2WXb00Y:DP09^Y7`2HZal0W:`K09b^7`2OZ1h0YjL@09n[3@2E[Q@0Tk8D08bj
4`2D^A@0Y:lI09Je6P2B]ad0VZdQ0:6W:@2QXb/00P2LZRh09`2C/2d0S;/V08Bk9@21`R<0O/<S0834
9022`2H0RKhS08Nj8025_B00PL0K08317@1n`Al0P<8M08K86@27b1P0QlDG08?36023`A/0P<@I08G8
4P24ba00Q/`?08;?4022baD0PlLI08K07@25`A`0Q<4I0833601n`R40PL8O07[38P1faRL0MLXV07C>
8`1acb80K<hT06g>;@0206k>=P0W06k;@01]aTT0KKmC06faC01b/4H0M;0m07Jl>01g`S<0O<PI08K7
3@28a0T0R<H:08C:401kbAX0NL@T07nl<01m^3P0Nk0k07Z^?`20[d00OZm408:[@`20Zd<0N[=407Je
?`1d_3h0MlHd08;5;@24_Rl0Q;Tg08Zc>P2:Z3P0TZ<g08jRA@2DUdD0Vhm60:NFAP2[VD<0ZI]00080
[9Tj02L0/iPh0;FF?P2aTD40[9Do0:6J>`2MX3<0UjLd09>^<`2@]S00S<8_08O9:P29c2H0Ql`X08S;
:028c2D0R/TY08C8901ma2P0N<DX07c5;`1n^bT0OKLU08:c7023Za@0Q9T>08F=0`24QP00Oh4007^0
001dN000L6d006mZ001/H@00I5d006EP001OG`00HEl005iK001JFP000P1HF`009`1MG`00G5D005E<
001GCP00G5L005iB001ID000FU@005]@001GD@00EE0005E>001BC000DdX005=8001CC000Dd/0059>
001GCP00EDX00555001=@@00D4H004m2001:?`00B3h004Xo0018?P00@S/003dj000j=`00>3D003Lc
000b:`00:BD002DL000P6`006a@001<;000200X30003008100000000000003T00000303oool000X0
oooo01@0IW`006Ag001YM000J7@006Qe001[O`00JH<006V1001XPP00J7`006V11P1ZP0<0J8H706F9
1P1ST@T0I9H:06RD201[S`@0LH/107280080L8X102L0Khh107280@1_Q`00LX/107F?0P1cU0<0M9T4
07BM1P1bWPH0LJ09076P3P1aXQ00LJ4=06nR2P1`Y0X0KJH8076X1`1aY`/0LjL:07:W2@1aZPP0MZX7
07J[101f[040NJ/107ZZ101jZ`L0P:`408:Y0@21Z`00OZh107N^0P1f[@80N:d107R/0@1j[080PJd1
08:/0@20[P800P20[`809`24[040QZT008R[0027[000R:X108RX002;Z`00SZX008n/002<[P00Rjh2
08N^1`24[@L0RZh408f`0P2@/@00TK4008n]002>ZP00SJ`008j_0029[`00QJl008Bb0P23/`H0PkH6
08:e0P24/@80RZl108V`0027/@80Q[@508>e1`26]0P0Qk@508^d0`2;]@<0S;H408Vf200208Ni1P0E
08jg0`2A^0<0TKD409:d0P2D/@00U[<109^f2`2G^@X0U[H<09Ff2`2I]PT0W;H=09^d302M]@T0WK@>
09bc3`2R/0d0XK4<09^b402Q/@/0Xk8:0080WK@=0100X;<<09Vc302K]PX0W;<:09Bc402M/100Y:l:
09Nb4@2K[Q@0X[4?09N^402F[a@0X;8>09Nc3@2R[QT0YK4E0P2L/A@09`2I/1l0XJhF0:V^402N[QT0
XJTM0:^S5P2QYQX0YZ@V0:JP5`2XXQ<0W:hF0::X5`2]WaP0[IlJ0:JN702WV2<0Zi`O0:jO6P2ZXaT0
[YlO0:^O702WXQ/0X9h[09fS:`2OZBd0XJTP0:NW5`2O[a@0V[8E09Fa5`2B]1<0TKX@096e4`2G[aH0
UJlH09B]8@2QY2/0YJ4^0:2T<00209VY<@0W08nb;P2;^2X0Q[hX0873801oa240O/@T08;1:@26_BX0
Pk/W08309@20`B<0OkTS07fi8`1o`200Q<4K08O25P28`aD0Ql0H08Nl6P27_Q`0RL<C08K;4P28c100
P/d@08;:5021aAP0P/@L08375`1nc1H0P<TH07g5801laR40MlLQ07C:801_bb00KLdT06[?9@1WcbP0
Jlh/0080K<hi02L0JLQ:06[0D@1Y]EH0KJ]C06fZC@1b[4T0M;Dk07Bi=@1laR@0PlP?08c01`2:`0P0
Q<T>07g>5@1kbB80N/0Y07^o<@1k^CD0MKTg07Zg?P1j]T40NK5007Na@@1g^Ch0N/0a07c5:`23a2T0
QKh/08Jm<`26/c/0SZ`j08bP=`2=Xc@0QYe109NIA@2_TDP0]IE30;NE@P2bUDD00P2mUcX09`30Tc40
_Y<o0;JDAP2LU480U9lm08b/?029[cd0S;Hm08fm>`2<`SX0R<8h08K7=P25cC40Pl/X08?68`25aQd0
Ql<H08C15020^QD0O[HE07n_4P1nZa40P:@?07nK2P22SP@0PH<107n0001kO@00NGL007=`001`J000
K64006MI001PE`00GE@005YC001PF@00GUX005]L000205mM0008065P001RFP00FDh005Q=001LE000
F5<005aD001ID00205I@000M05E?001BC000EDT005A;001BB000DTH004e7001BB000DTT004m3001A
@000BSl004]5001>A@00Cd<004Y20018?P00A3h0044n000n>@00>C<003Pb000c;P00;bL002PO000S
60006aP001HA000<2@000P060P000`01000000000000000i000000`0oooo000:0?ooo`0D069g001T
MP00IG@006Qh001WO000JX8006Um001ZN`00JG/006Qi001XP`D0Igl406N3201TSPL0IY0606FF1P1Y
UPH0Ji8606nA101`S`@207>>0`0W076?0P1]S@40KX`006j>0@1^U080JiT606jO1`1^X0L0J:4606RR
201/X0X0KYd;06nO2P1]X@P0KJH906bW2@1_ZP`0L:T?076W301bYPX0M:D807JY201fZ@T0MZh607RY
0P1iZ@<0NjT4082X0`20ZP80PJ/007b/0P1f[0@0MZh507J/101gZ@@0NJP3082Z0P23ZP00QZT00080
Qj/002L0RZX008bZ0029Z000RJT008bY0@2;Z`00SZX108b[0@2>[@00Rjh008b^0P29[0L0RJX708^]
102@[P80SZl008n]002=[P00SZd008j`002?/@00Qk8008Jd0025]@40Q[L208Fg0`24^080P[T608Zh
2028]@H0QK@5086d1020]@@0P;H308Bh0P28]040RKL208Rf0P29]`D00P28^0@09`2=^@80SkX308ni
102?^0<0TK<309Jd1@2I]P`0U[D=09Rc3`2I/`T0Uk<909Bc3P2H]@P0W;P809Rf3@2O/Q40Xk480:Ba
3@2S[a40Y:l<09^c302K/@d0XK0<09nb2P2I/a80X;D;09^d2P2C/140WJl?09jc302B/Q80V[8B0:6c
2P2J/A80Uk<E09Vh2P2G]P`0Vk4D09Fe400209Jf4`0W09V^802J/A80W[8B09n/7`2TYQH0Z:L=0:BS
7`2SWR@0YJ@E0:ZY502YYB00Yj8K0:FU602XXAP0ZIhJ0:bK7@2UWAH0YIhN0:ZN802YWa`0YZDJ0:>O
802HVRT0Vil]09nX;@2QYR<0WjHQ09n^8`2Q[a`0Wk4C09Jd5P2J]A`0TkHD0::_402P/1T0XJdP09bT
;@2HZ340Rk0c0080RKH`02L0QK``08C0<022`RT0P<0Q07o18@22`bD0PL4V07k39P1hab@0N/PT07c5
801n`B80PklV08:o8`24aA`0PlHK08[55`29aAH0QlDF08K35`27aAH0R/PA08[64@23aA00Pl<C07o5
5`22`ah0O/LN07o:7@1obad0O/HT07[78@1fbAh0L/dJ06k;7P1]cBD0K<dX06W=:@1Zc2`00P1[cCd0
9`1Yb4d0JKUD06b`F01_[E@0L:UA07:YB01`/3h0M;<j07[5902:aQ40T[h808nl0`2:``X0P<dC07_:
701m_bP0O/0/07Zm<P1g_C80Nkde07Vn=`1g`3L0Ml0c07k1<022`b@0Pk`[08Fl;`23_3<0PkTe08^c
=`2BZ3H0TZ@i08fX?02<W480W9U30:bDA`2cU480[YQ30:VGAP020:bF@P0W0:bH>@2UVd40Vj=409BX
?P2:[cX0RkLh08Zf>@29]d00S;Y008bk?@28`CX0Pl<h0838=01n`bl0P<4N08>k5`28]Ph0R;4608VZ
1P25X@<0QIh308BG0P22U@<0PH/107b5001nOP00P7/007Yk001dM`00KVl006eY001YG`00HEH005mB
001HCP00ED/005M>001ME000H5P00080H5`002L0He/006=I001OE000Fe4005aC001IDP00Ee0005=@
001GD000FU4005E@001CBP00DD/005A=001ABP00CT8004m4001AA@00CDP004e4001:@@00Bd0004U0
001>A@00DTP004i80019@@00@Sl003hi000m=`00>S8003@]000_9P00:R8002<P000Q60006Q4001<>
000;20000P060@0l000000`0oooo000:0?ooo`0D065`001MM@00GGL0061m001VP000JGh006]m001Y
NP00J7d006Qn001ZOP00JHL606N<1`1VTPL0J98706VD1`1VV`T0JI/806ZL201^VPT206jH2@0W06^H
1@1ZT`<0JID406FG1@1QV@H0H9d;06>P4@1VX`h0IZ<706RS1`1]XPH0Kj8406fS101YY@<0JZH606bU
2@1_Y`X0LZ@=07BO2@1gX@H0LZ8807:U2`1dZ@l0MZd907NY101fZ0<0NJP307ZV1P1oYP<0OZH307bX
0`1fZ`D0MZ`607RZ101lZ@<0O:@1086V0@24Y`00QjX00080Q:d00P28Z`009@28ZP00RjT008fZ002;
Z@40RJ/208RZ0P28[P40Qjl008R`0@25[P80RJ/208Z[0@2:[000R:`008R^0029[`00RZl008ba002<
/P40QkL208Fi0P26]`40RkH308Vf1@29]`D0Q[L708^g202:]0P0Pk<707ne1@1o]`80PKP108:g0@27
^080Q[L408Fh1029^0@00P28]`<09`2:^080R[H408Zg2027]`P0SK<8092c2P2A]@X0U[D>09Zi2P2F
^0X0T[D908^f202A]`L0T;P809Bf302N]0/0W[D:0:>e302S/`l0X;8;09Re2P2H]Q00WKH:09Vf2@2O
/1<0XK4;09fb2`2I]1D0V[<<09Jg3@2@/a<0Uk8=09be2P2J/a40U;P=092m2P2A_0`0U[LC09:h3P02
09Ff4`0W09fY7@2H/Q<0X;8J0:JW6@2RY140X:XG0:2R802SWAL0WJPB0::_5P2XXRD0WJPD09f/402S
X1P0YZ4I0:RR502NYAD0Z9XW0:VM702WXa@0Xj<Q0:NP902VV200XYhR09jV:02KYAX0WjPH09N_7P2C
/Qh0U[@H096d6P2J]1h0UKHL09f]8P2L[b40VJlS09JZ;@2>[S00Q[Da0080Q;TZ02L0P[lW08;0:023
_BP0P[/U08Bl9`22aBX0OlH[07_38`1j`R40Nl<Q07c68022aQl0QLDQ08G28@25a1l0Q/LK08S86`23
bAT0Q/XG08K:6P29bAT0QlDH08?05`1o`1L0P<8G07o65`21`R00Ol@S07o78`1naR80N/DT07S6801a
aal0K/XP06k9901/bBL0KLX^06_;;01Yac000P1Xbch09`1XbD/0JkUA06b[F01`Z5<0LZI>07:[BP1`
/480KkHh07S39027`Q<0T;X7096l002?`@X0Rl`<083<5`1l`2D0PL8Y08;1;`1o`Bd0Ol@[07[9:01i
b2D0P<HV08;39P1o_R/0OK/`07jk<`1o]cD0QJhe08fY<@2@YC80Tj@n092XAP2JU4L0WIM40:FBAP2a
Td/0[9E709jFC00209bAB`0W09NDB@2<W4H0S:]408Zc@`2=]Sd0TKPk08ne>`2?[T40RZY408B^?`22
]S@0P<4]086l8P22]al0Pk0E08JX3P29Y0H0Rj<008fP0025W000QYD008J@0023R@00OhD007]l001k
NP00NWP007Qj001eN@00LG8006]Z001WH`00H5@005M@001ECP00EDd00598001FC000GE<00080FeD0
00L0G5H005iC001NF`00GeL005]E001KD000ET/00080Edl000l0Edh005MB001GCP00DTT005=:001@
@`00CD0004dn001<@@00BD0004Y1001=A`00CD4004Y2001:@0000P1=AP003@19@000@cP003db000k
<@00<bd0038X000[8P009Ad0020J000M5P005@h000`9000910000P03000l000000`0oooo000:0?oo
o`0D05ma001OM`00HGT006=m001UOP00IWd006Yn001]O@00KH8006f4001[Q@00JX/606VA1`1WV@L0
IY/906NN2@1ZX0/0JYl906^O201XX0T206NN2P0V06BL2@1TU`T0I9P805bM1`1KW0P0HYd:06BJ3@1/
V`X0KY`806nN1@1]X080LJ4007>R001bX`00LZ<207:U1@1bY@H0M:<807BQ1@1eX@@0LZ0507>T1`1e
Z@`0MJ/707RY0`1eY`80MJL607FW201jZ@P0O:H607bV1@1iZ0D0NJL407jV0P1nZ080OjH008:W0@24
Z00308FZ000E08>[0@27Z`00QjX008^T002;Y@00RjT108F[0P27ZP80Q:d108>_0025/000Q:l008:]
0025[@40Pj`107n^0@21/@80Pk8108Ra002:]000R;H20080Q;P400@0R[L208bf0`2<]PH0S[@60P2>
]@P02P2</`L0QK@3086f0`22]P80Q[L108Ff0P25]`H0P[@708Jg2029^0P208^e0`0W08Vd0`28/PH0
Qk<708Rd1P2?]0H0T;@:09Fe302K]@`0V;L:09Bf302B]@/0TK<709>c202>/`h0Uk8909je2P2L^0X0
X;@=09ff2`2I`0X0T[P<092h302<^PP0TKP;09^c3`2M/P/0Vk8<0:2a602J]0h0TkPA09^d5@2N/0/0
W;T;09bf3@2C]P/0Rl0<096j3`2I/a80SK/@0080Tk/B02L0XZ/I0:2_502T[aP0ZZDG0:6W4@2NZaP0
XjHE0:NR3@2H[A00XK@H0:ZS9P2TZ1@0YJL>0:NU6P2XY1X0YZD?09fU4`2VWRT0XJ4F0:BQ5@2WVbL0
[9/T0:JM8@2SWRH0Y:DW09FW602RYal0Wj`X09Z]902K[1d0VjlM0:2`802P/1h0WJlP09F]9`2?/2/0
Qk8b08Fg<01i_2`00P1m`B@09`20aB@0P/0X08:j:P25^B/0Q[L_0834<@1o`b`0OL0Z07Jj:01g^2T0
N/8V08388`23bah0QL/L087<6020bQP0PlXH08?87027bQ/0R<`L08S86025aQD0Ql0C08C13`21bPh0
Ol/H07k:8P1nbRD0O<@T07K69P1c`RP0M<@W06o79@1_b2@0LLHW0736:`1/aC80K/<e06S4?00206O:
@`0W06O:D01[^EL0K:YL06jTF@1`Xe80LZi:076`@01a^S/0O<<W08O0502?^0D0T[h708o52P2<b``0
Ql/C08K<7P28ab00QlHQ08C:7P25bAh0Q</L083:7P22a280P/8W0831<01o_3L0O;Hk07n`>@27YcH0
TJ<f09NS=P2DWD<0VYI>0:V=C`2ZTDd0[8]>0:^>D02NVdL0TJ970080SjI:02L0SZM508nRB@2=YdX0
RZi508Z_@P29[T<0RZe108nX@02=Xd00Qj8k08V_:@25]Qd0RJPA08VN302:V0P0Qi4308BB0@28U000
RI4008NB0026T@00Phd007n6001mQ000NWT007Yg001fL@00MW@007Ae001_L000Jf<006IK001NE@00
F4h005UB001MDP00ETd005A;001HC@000P1FC@002P1JC`00GED0065G001PE`00G5H005U?001DC000
EdX00598001ABP0205A9000K059;001?B000BD<004`n0019?@00BCX004Pn001:@000CD<004a4001;
@000BCd004Hn0018@P00AT40040f000k<000=R/003<[000]9P00:1l0020K000M5P006Q8000l=0009
1@00108000800@00?000000<0?ooo`002P3oool0501OK`00H7P006Ai001WNP00JG/106Yn0@1]PP40
KH<006R6001XRP40IXX106JA0`1VTPH0I98706BL2@1VW`X0JJ8;06ZQ2@1XW`P0HYl:0P1SW@X09`1P
VPP0GIP805fG2@1MV`X0G9`906FI2@1YU@P0KHh706nA1P1`U@@0LYX107>M001fWP00MI`007FM0@1d
XP40M:<207FU0`1eY0<0MZL207NV0P1dZ@@0LjX507B[101gZ@80MJD207FX101cZ`H0MZd707RZ201j
[@L0N:T507bW0P1mZ000OZ/007b/0@1m[080P:l2086`0@0207n^0P0W07j^0`22[P80QJP108RX0023
Y`00PjP008>X0@22[@40Ojh0086a0020[`00O[00082_0020[`40P:d108:`0@20/@<0Q[@208Na0@29
/`00R;<108Bf0P26]P80R[D108je0@2?]0D0SKH508fc102?]0<0S;@008Rc0025/P40Pk<408Jd0P29
]040Q;D708>c1P27]0L0S;@60080Rk8302L0S;4308N`0`28/P<0Q[8408fb102C/`h0VK@=09jf2`2H
]Pd0U;P=09Zd302J/`P0VkD909Jc502M]0/0VK@909>g302H^0h0VK/:09;02`2=`0d0S<0908Fk202=
`0/0V[<:09>e2P2C]a80Wk<=09Jf302H]@`0V[<@09Ve3P2G]`h0XKH>09ff302C^0h0Vk<B0:6`3@2C
^Pl00P2G]a@09`2V[1/0Yj`D0:N/5P2ZYaP0YjPB09fZ502TYQD0Z:HB09^^4`2R[1/0Zj8P0:JY4`2R
Za80YjLM0:NV602TZ@h0WJPG0:RQ:02KYaH0XZ8J0:fL8@2[WAT0XJ0Q0:>T802QZ1T0U:TH09VU902L
Z2P0WZHY09bQ902KY2L0YZLW0:6V8@2GZ2<0UJ`Z08fa:`23]300O[XW07O0900207[5800W07k;801o
abD0Ol0/08:j;@24]2l0P;d[08329@21aa/0OLLG07g55`1nb1`0Ol/R083>7@20cA`0Ol`G07g;5`22
bQP0PLTK08G;6P25c1/0QlHN08K86`29aaH0RLPD08S;4`23c1H0O//O07c:8`1gabH0M<PV073::P1a
bRT0L<TZ07389@1`bR@0L<P[06g8<01/acH0JL@n0080J<e402L0J<]B06ZmEP1Y[e`0K:aI06j]D`1b
[4P0M;E007C3>P1kb2L0Ql<D08nk2P2@``X0S/TA09C95`2CaAP0SLPH08c:6`26ba/0QLXG08K85`29
bA/0PlLQ08?78P22bRL0Ol@/082l<`22[cH0QJXf092Q=P2KWSh0UYi309R@B`2VQ4l0_H5@0;Z6D02g
QE80X8]=08nNB028ZDD00P2;[4@0402B[DL0UJA;09BOCP2@X4P0Sj5708ZWB026[C/0S;0T09BY6P2F
XA<0Tj4@08bO3`29U@D0R8h008J<0023RP0208>9000E08J40023QP00QHX00826001nP@00OGl007Qi
001fM@00Mg4007Md001aL@00KfX006]P001UEP00G58005]A001ND@00G50005YC001HC`00ETh00080
Edh000T0FE@005aG001NEP00G5T005]E001ID000ETd00597001@A`000P1BBP002@1ABP00DdX00596
001=A000Cd<004`n0018>`00BT0004e4000204U0000A04Xo0018?P00@cL0040d0011>P00>c@003H/
000a9P00;R@002PR000U70007QL001TB000B3@002PD000D100020000?P00000<0?ooo`002P3oool0
4P1PL`00GgP006Al001UNP00J7l106J50P1WR`40IXP006B7001PS@80H8h305jD0`1PTP<0H9@606>J
201SW0P0H9h8062Q2@80HYl90P1QW0T09`1QV0P0Hi8806BC2@1TV0X0J9P:06^C1`1_S@<0L8d106j@
0`1_T0<0KiD107>G001hVP40Mi/307BI1@1`X0@0LJ@306fX101[Z@<0KjT3076Z0P1bZ`00Kj/106jY
0P1_YP80LJ<0076Z0P1c[0<0MZl607J^1`1l[PH0NZ`307V]0@1l[`40O;0107R`0@1i/P<0N[4307^b
0P0207V`1@0W07N^1`1j[PD0PJ`1086^001n[000OZX0082/0024[040PJ`007j_0@1m/040N[0207f`
0P1o/`80P[0108N`0029/040Rk8108Zb002=/@00R[<008Rc0028/P00R[8108jb0P2=]0@0S;L408Zg
102<]P40RK@008^b002:/P00Qk@208R_102;[`80R[0608Jb0P2:/`40SK<10080S;8102L0SZh108f^
0@2<[P00R;4208bc0`2>/P80U[@:09be2P2F]Pd0V[H>09nb2@2I]@T0W;H?09jc4`2S]@/0VKH:08ne
3`2H]`/0Ul0:092o302;^`X0Sk/908_0202?_`T0TkD908bh302=]a00VK<:09:f2`2H]P/0W;8>09Zb
402N]a40X[D@0:Jc3P2P]0l0X[4E0:F]502G]A<00P2O]AP09`2Z[aP0XjdB0:B]5P2[ZAL0Z:XB0:2V
5@2SZ1`0XZXH09VZ5P2UWah0/i`K0:RU3`2SZQ80ZJPG0:VW4P2C/180VZhI0:NV7@2JZQ@0XZ@H0:JQ
6@2RYa<0Y:HR0:>[6@2R[aH0VZTL09ZX7`2OXb40Xj4T0:NN902PYBH0XZLS09VW:`2AZ2h0S:d]08Ra
;`23]S@0O/0W07bn900207_18P0W08788`21aRX0Ol<_0871;`26_Bd0Q<8U08C56@22bAH0Q<T@08?:
401obaH0M/TR07_:901nc2<0Ol`K07k=5P1ncAD0O/dI07g;701lbB00P<LT07g79P22bR@0Q<dO08C<
8@20bR@0Ol<S07_19P1eabT0L//T06g=8P1`bB@0K/LY06c9:01^bbH0KLXZ06S:=01Yc3@0JLdf0080
K<lm02L0J<e;06W2D@1X]eL0J;QD06ZeD01`[dT0LkU007K8=@1lc200QLLC08k4402?aA@0T<@K09C7
702Bb1d0Rl/J08W:6@28bAP0QlPK08[5702;b200Q/PS08?79@25aR<0P<<Z08Ff;`2;ZSD0VJ<h0:FK
?02IUd<0TXm=09>9CP2RQE@0_85A0;F5D`2YQ5@0V8a=096MA`2=ZT<00P2B[Sl04@2E[D00UJ9309BO
B`2@VT`0TZ1;09>Y@028[2P0T:TC09:J202AT@40S9<108VB0@26RP00Q8@008240020PP00P8L00080
PH@001@0PhD00865001oPP00Og`007]i001jL`00MW@007Me001gLP00LG40071X001TGP00H5@005eA
001ID000FDd005U>001JC`00G50005UD0080Fe8002D0G5D005]C001JD000G4h005Y?001IEP00F540
05A=001DBP00E4`005E=001BBP00DDD004i5001<A@00D4@004lo0018?P00BD4004]3001:@P00Ach0
04Q00015?P00@CH003Ta000i=000>S8003D[000/9P009B0002@J000O5P006a<001DA000>1`0010<0
04000000303oool000X0oooo01@0H701061f0@1SMP00Ig/006J10@1QPP40HhL105b8001PQP00H8L0
06680P1MR`80G9<405ZA1@1LV`L0GYX705^L201OU`X0Gi<7066F1`80H9H802<0I98506JB101XT@T0
J9@806^F1P1/T`H0L943072?0@1_T080Ki41076D0@1bU`40LYT3072K2@1_W@/0KJ<:06jY201[Z`L0
J:/706^Z1`1_ZPH0LZ`206n/0@1/ZP40KZH106nR0@1aZ080MJX107N]0P1j[PD0NK0207R_001g/P00
M[H107Nc0@0207Zc0@0[07jb0P1k/P40N;<307Rc0`1g/@D0NZh307^]0@1k[000OJ`007n]0020[P00
Pj`007n_0@1n/040N[4207Na0`1j/`@0O[4408F_0`29[P40RZd008b^002=[P00SZl008^a0027[`00
Qjd008R_0@2<[`80S[4308^d0`2:]`@0R[H208ne002>/`00T;8008bc0`2:/0<0R;0108^`0@2</`40
Sk@0096e000208nd000G096e002?/`00Sk4008jc0@2;/@80S[43096b2@2C/`X0V[D?09je3@2Q]@/0
VKX<09Vf402N]0d0UKH;092f3P2B/Pl0T[L:09Bo2P2D]`d0UKX:09C02@2@^@T00P2B^@X03P2;_@`0
SkP>09^h302@^0d0TkXC09j`302N/Ph0W;<A0:Ra402X[Q00Wk0C0::_4`2W[a80W;4C0P2T/AP09`2Z
[aL0WK8B0:>_5P2Z[AH0Xj/C0:2/6P2T[1h0YJ/L09^[5`2SY1`0[j0M0:>W4`2S[a40ZjHE0:NV3`2B
]1X0V[@I0:F^3`2F[A80X:PB09:]5@2J/aL0YjTS09Ra5P2L/1H0XJ`M09fU602GWB40XIlU0:ZP;P2T
XbT0Wj0W09ZR<@2@XS@0RJTa08Ne<027_Rd0QL4Y07o0:@0208C0:`0W08O09`24`BD0P<DU07o79P22
b2P0Q/TS08G<6`21bQL0PLTD083:4`1kc1D0M/`N07W=8@1lbbH0N/dK07_@601kcQL0NLdI07g=6P1n
ba/0P<PO08398020bQd0P<dK083=7`1nb200MlPP07?:901ec2X0LlhQ077@6`1`cah0LlPT07?<801c
cQd0KllV06_<<P1ZccH0JL`e0080J]0e02L0JLm406O:C@1Ua5P0Il1I06VmD01_^DL0M<0i07G;:P1l
c1L0R/X>0975602A`240T/8S09777P2Aaa/0SL/G08g;5@2<aQL0S<DK08W27`28ab<0Q/HU08O29@26
_BP0QKDZ08F`;`2=YcD0VJ4h0:BL@02JTTX0VH=A09b3E02YQ5<0_8A>0:Z5D02KR5@0U8e@096GC@2B
Y4X00P2GZ480402CZCh0TJ=309JNA@2;ZC`0S:d[09>V5`2>VA40SIL608f>0@26S`00RY4008R@0026
QP00QHD008220020O@020823000E08>50024Q000QHL008B60021PP00OgL007Ua001fM000NGL007Ia
001`K000KVD006QH001LD`00FU4005Y?001HD000Ee0005Q>001JDP00GED00080GUH002D0G4l005E@
001ICP00EdT005A:001JDP00EDl005==001@C000DdT0055<001@B@00C40004/m001<?P00C4<004]4
001:@000B3h004Hn001=?`00ASl004Ll0014>000?S@003/`000f;@00<B/003<Z000Z9@008Q`001dF
000I4@005@/00109000:1@000P0004000000303oool000X0oooo01@0GFl005mf0@1QM`00HgP00660
001PP000Fgl005b0001MN@00G7d005mn0P1NQ0D0H8h705b@1P1MV0H0H9T6066E1P1PS`D0H8T205j9
0@80H8d302L0HX`306J=0`1WS@@0K98306fB101]TPD0KID406nF1P1aVPP0L9T6076H1P1`W0H0L9d9
06jR2`1^X@l0KZL=06nY2@1[Z@T0JZT:06^W2@1_Z0T0L:P4072Y001_YP00L:D0072U0@1aYP80MJd4
07>`0`1g/P80N;4007Nb001g/`00MKH107Rc0@1k/000Ok0007f/001j[@000P1i[P401@1g[@80N:X1
07ZY001kZP00OZ/00080Pj`00200Q:h008Ba0024[P40P[01082a0@1m/@80Ojl4086]0P24[P40RZd0
08b[002;[@00RZl108f^0028[P00QJ`008Rc0@27/P40R[4208Rf0P27^PD0Q[L208fg002@]P00TK81
08^d0P28/P80RK4008bb002C/P00U;0009>c0080U;H002L0SkD008jd002B/`00TK4108fa0@2?/0T0
TK4909>c2`2H^0X0Vk@;09Zh2`2C_0`0T[X;09Ji2`2<^0X0T;<>09Nf2@2A]`T0Tl0;09fg4P2O^0X0
W;P909Ng3P2H^0`0UKP908^k302@^`l0VKT;092g3P2J]Q@0YZl?09j_3`2K/a<0Yk4B0:Fc3`2O]180
XKDC0:Nc402Q/A000P2S[QD09`2Y[AD0Wk<A0:2d4P2Q/aP0W[4E09Fc6@2O/A/0YJ/M0:6/5P2M[AP0
ZjPO0:V]502R[a80YJHG09jU5@2F[Q/0VK<K09ja502?/Q@0V:dD092b402F]1@0YZ/S09>b5@2KZQL0
YJPF0:JS5P2OVRd0YIlZ0:VN9`2PXRl0VJ8`09:R<`2=YC<0QK0a08G0:P25b2@0PlLT08?69`0208C4
8`0W08K97P23bAd0P/XL07k;8P1obBT0OLTW0839801nbQT0O</C07c;4@1kcA80O<hE07k>4`1lcQD0
N/hF07[A6@1gcaT0M/hM07gB6@1nd1X0Pl`M087=6P1mcQ/0M/lK07_=601jc1d0LlXR07;?8@1edB40
N=0L07C?6P1dcQ`0N<PT07W9701gbQP0M<dO06_>:@1YcRd0ILh_0080Im4`02L0JM4m06O=C@1VbUL0
J/U?06[7B01b`D@0M<Ha07W?8@24d180T</?09O:5P2DaQh0TlXR09;86P2DaAP0T/PG09775`2@`QT0
TL0L08fm7`2;a280R/0W08Jn9P26^2L0Qk0/08R[<`2?ZSD0UJ<n09bIA02VTTX0/XA@0;AlD@2ePe40
]8U>0:J8D`2LRU80TXm>08nKB@2BXDL00P2HWTD01`2CWTD0T9]:08ZT>P28Yb00SIdC08j@1P29Q`00
0P2:R0007P25R000R8/008V:0027QP00QhL008B70021PP00Oh<007n00021OP00Ph0008:40025Q000
QH<00820001kM`00NWH007Uh001cK`00L6X006YU001VFP00G4l005Y@001JD@00Fdl005U?001EDP00
FE<005eE0080GUH00100FU8005I@001HC`00ED`005I8001EBP00E4X004m8001@A`00CDD00519001>
B@00Bd4004Tn0016>`00BCd00P19@0004P16>P00Ac/004I00017?P00ACd003li000j<P00=S0003<Z
000^9`00<BP002`U000R6P006A<0014<000>20001`@000@204400000303oool000X0oooo01@0FF/0
05M]001JM000F7D005al001KN`00G7P005Qc001KK`00Efl005]f101IP0P0FX/805RC1`1GUPH0GIL6
06:D0P1UT040H8`106290080GHh202L0GXl306:>0`1WS`40JXd106b?0P1VT0@0I9<706FJ2`1WW100
JYh=06bN2`1YX@/0Iil<06VQ301^XP`0KZ@:06fS2@1/Y0T0JZP;06fV2P1_Z0L0L:T3076X001bY`00
L:L007:X001c[080M[4707Ba1P1g/@D0Mk0107Z`001k[000O:h007f^001m[@00P:X007n/001k[000
0P1m[@009`1nZ`00O:T007jX0020ZP00Q:`108>Z0@21[@80Ojh2086^0@26[`40Q;4008Ja0026/040
QZl308J^0P26[P40R:X008bY002<[@40R;0208J_0@2:[@00R:d008V]002;[`00Rk<208Zd0@27]@80
Q[@108Zd002;/`00Sk<108^c0@29/P40S;<0096a0@2G[`40Uj/009Ja000209Fd000W096c002>/`00
SKD008^d002:/P40SKH808je2`2<]PT0U[H909Ff2P2D^`/0T;X<08jh2@2;^0X0S[D=092d2@2>]0P0
T;L:09Vg3@2P]1@0WkD<09jh2`2K]1@0V[D=09Jh2@2>^P/0T[/>09Zj2@2A^@d0X;4D0:V`3P2U/0h0
WK8C0::b5@2O]`l0XKPA0::g4`2S/a40WK<@0080WK<A02L0Y[4E0:J_402Q]Pl0WK<H09nf5`2I^AL0
Wk0I0:J/6P2O/A@0W;4D0:>^6@2T/Q@0Wk8@09ZZ7P2LZ1/0UZhG09Za7P2L/Ad0T;DH09:^602E/0h0
VK0C0::[9P2G[QP0V:LH09jX502PZAT0ZJ0/0:^L8`2SV240VilZ09BZ;P28[S40P[<a07o1:P22aB@0
Pl/O08;<7023b1l00P25bR409`22bB@0P<PQ07g6801lbB40O/DW07k8:@20bB@0OLXL07[=5`1jc1@0
NLhE07SA5@20cA<0OllB07[@501gcaL0NLhL07K<8@1kdQh0O=8L07o=701mcA`0NLdN07G:7P1fbb00
MlPW07G::P1bc280MM0O07K?6P1gcAX0M//P07C:;@1eabT0LLLR073<7P1/dB<0K]0R06cA9P0206c?
;`0W06W@>P1WcdL0I<i<06K=A@1[bSl0L/Hn07?;<@1nd2<0RL`H09O85@2KbaT0U//I09O<702Ec1L0
UL`E09?;5`2CbaH0ULXG097:5@2=baL0T<XM09358`2<`B@0R;PU08Ja:@2:/RX0SJ/f096O@P2CTDX0
Zhm=0;N8DP2lOTl0^X9B0;>5E@2TR5D0VHUD09BFD@2?Ud/0T9A:0080UiA;02L0UYE:08nH@P1oXAl0
QY@B08F71026PP00Q80008J10026Q000Q8<008B40023PP00Q88008>80025RP00PXL007n3001jP000
OG`0081n0024O@00Q7h007ii001mN000NWD007]h001hM`00N7H007Eb001[J@00HU`005YB001JD000
FE<005EB001CCP00Cd/005IA001JE0000P1NE@00901KE000FE@005Y<001FC@00E4`00559001@B000
CdL004i6001<AP00CT@004]7001<@P00Bd0004@k0018>P00B3`004Lm0015>`00ACT004Dl0015@@00
@ch003de000d;@00<BP002dS000[9000;BD002PS000N6000510000d700060`000`40004004400000
303oool000X0oooo00<0G6L005YY001LK`000P1LK`003`1LM000GG4005aa001LK`40G78205ii0`1M
O@L0FhX805J>1P1IT`H0GIP5062G101OU0<0HI41066@0@02062D0@0W062E0P1PU080Hi<306BD1@1S
U@@0H8h305nB1`1MV0d0HIdC066O4P1RXA00HJ0?05jO301UWP`0Jil806fL1P1]X`H0JZ@706NV2P1Z
Z0T0KJT6076Y1@1bZ`80KZX0076X001eZP00MJ`107>`201d[PL0MZl507V/0@1iZ`00O:X007jY001n
Z`00Oj/007j/001nZ`00OZ`00080Oj/002L0OZT008BT0025YP00QjP008FZ0P21[0@0Pjh507n/1@21
[`@0QZl208N_0029[P40RZh108F/0P27[P40Rj`008^Z002<ZP00Rjl108N^0@26Z`40RZX008b/002:
[P00SJh008Rb0029]@00Q[<008Jd0029/`00S;<008Zb0028/`00SK<008ba002=[`40T:l109:_0@2D
/`000P2B/P009`2C]000Sk8008na002>]000Rk@008Zh2@2:]PT0RkL8096g2@2>^PT0TL0:09>h3@2;
]@`0Q[d:08bb3`2>/PP0RkH9096f2P2M]@l0Y[@?09^f302F_`d0W[HB09Rh302E_`T0UKT=09Bg3P2J
]`T0S[h<09^d4P2V/`l0XK<=09^g4@2O]a<0Vk/@09bn4@2N^aH0WKLE09Jk4P0209Ri4`0W0:Fd5P2V
/a<0X[@A09na5`2R]1T0Y;TF0::c5@2V[AP0Wk4C0:2c4@2T[aH0X;<B09Ve3`2G/Q`0V:hJ09:a502H
/aT0X:lN09:b5P2E[QT0XZ/E09b^5P2TZB@0XJ`J09^X4P2KZaD0U;8H0:JT902[X2@0Y9PY09^S;@2@
/2`0P;@c07jj<01maRl0OlPW083;8022c1`0PLPO0080PL/Q02L0P<`T07c:8`1hbAd0M/XL07W:801l
bQh0O/hN07c;701mbaP0NLdG07cA5`1icaP0OM0G07kB5`1id1D0N/hA07[>5`1ecR00N=8P07K@8`1h
c200NlXN07S;7@1iba`0N<TP07S79@1eabH0M</N07?=6`1dba/0M/PK07?;801ac2@0KL/T06W;8P1/
d1l0Jm0R06oC7`1`dBH00P1]bRl09`1XbC<0J<hl06SA@`1Vcd40J/`l06g=<P1ecRP0N]<U08W@6@2B
c1P0T/PP09?88@2Cb1l0TlTL09;:6`2?baX0T</J09C;5P2?cA<0TM4D093<5`2>aB40SKdT08^k902:
^2P0S:/]09>O>`2OUDD0[XM<0;B9CP2hRE<0^hID0;R3E`2fQ5X0W8AH09>:EP2GU5P0UI=D08b:E`02
09B>E`0W08jG@@28WBL0P98C08F71023P@40Pg`007il001mNP00O7X007il001oO000Ogd007j10021
PP00Q88008F70020QP00Oh8007Ul001oNP00Oh00081l001iNP00NG4007I_001jMP00NGL007Mm001`
N@00KFl006ER001NFP00G5@005aE001FD`00EE4005=?001FC`00FDl00080FE0002<0FU0005UD001G
D`00F54005A;001CA`00D4X00515001>B000Bd@004U2001;?P00BSl004Ln0012>000@cP004Hi0016
>`00A3h004<j0012>@00@SX003dg000j<@00<BL002TR000W8P008ad0028K000O6P0061<0010=0007
1000104000410012000000`0oooo000:0?ooo`0D05]N001LH`00FVP105MZ001JJ`00GG0005md001O
O000Fgd2061n0`1OQ0@0GHD605b81`1JT@H0EIH905^M2@1JW@@0GYH205fC0@1STP4206:G0P0W062H
0P1NU0@0GYT605^I2@1KV0P0GI8505fB1P1MU0T0H9P;066J3@1RWP`0HZ0;06:N2`1WW0P0JiT506jJ
0P1_X0<0K:D706^V2@1/Y`L0K:D606jX1P1_YP@0L:D1076T0P1dY`80LjH207FT0`1eZ0H0MZL207JW
001fZ@00N:T007^Y001mZ@00OJ/007n[001nZP00NjT00080OZH001T0PJH0086Q0022X`00OjL008:Z
0023[@@0Pjd508:/1P22Z@D0Q:/208B/0026/080QJd208F^0@26[P00R:/008Z[102;ZP40Rjl008J`
0@26[`40QZh108Z^002;[P00S;000080S:h000`0Pjh008Bc0@25/P80RK8308Nc0P27]040S;@008bc
002;/`40RK@108jc0@2?]P0208fe000W08ne002=]@00S;@008Ve002<^000QkT908Vg1P2;]PL0TkT8
08fi2@2?]``0V;8<08ng2`27`0d0Sk4B096d2`2@]PX0UKL>09Ve4P2T]@`0VKP;09Ro3@2P]a40Uk/;
09>o2P2K^0d0WKT>09Zf2P2?`0`0UkTB09nh3P2J]`d0U;dB09fh4`2N^100VL0?09o05@2R^AD0UKXB
0080VKXC02L0X;8E0::g4P2N^@l0W[HD0:>e6@2V]aP0VkLG09fc6P2P]A80WK@@09ba602M]1@0V[L?
09Ne5P2G]1L0T;L@09:h5@2O/Ad0VjlE09b[5@2UYaT0XZXH0:FV8@2HZAT0TZPJ09B^4@2C/a<0Z:4L
0:VR7P2[VR`0WJT_092`<`20/S40O;P`07[7<`1lbRP0O<XT07o9701kaa`00P1oab409`1oab80N//P
07O=7`1fcA/0N/hM07[@701odQT0N=4N07S?7@1icQX0NllG07c>6@1gcQ/0N<dK07W;6@1ibAH0MldH
07CA6`1ad2@0LLlZ07;7:P1baRT0MLLW07K88`1f`2X0Ml0/07K7:P1gbB<0MLXX07;8:@1^bB/0L/`U
07;>8`1^cb<0J<dS06W?8P1VcR<0KLhT06o<;@0206g7=`0W06g9=01Zcc80I/le06G?>01WcS<0LM4X
07CD7P1hdQT0Qm0C08k<4`2>bQd0RlTL08k:502?baD0T<`J09;:6P2@bA`0TL/H093<4`2@c1L0T/LJ
09728@2@`BH0S[hV08fg:@2@[B/0WJ4g0:nC@02kRDT0]hY>0;>=D`2/Se80Yh]I0::0E`2BQe`0ShmJ
09^AE`2JReH0UHQI0080Ti1A02L0Qj0X07nB4@23Q@D0QX4108N10020N`00NWH007I`001iL`00OGL0
085l0021O`00P80007em001mO000OX0008290021QP00OGl007mn0020O000Ogh007Ql001hM@00MW<0
07Me001iNP00Lg/006mk001XKP00Hf8005iI001GDP00F5@005U@001EE000Edl005UA001KD`000P1L
CP008`1IC`00F54005U=001GC`00EDd005I9001GC@00E4d0051:001:AP00BD<004M00018?P00B3d0
04Hi0014=P00ACP004Pk0015>@00@3T003hh000k=@00=S4003H_000_:@00:R<002LO000Q6`007AD0
01PD000C3P0030H000<200010@000@0004800000303oool000X0oooo01@0GF4005aS001MK@80FVd0
05e/001OLP00H7D005am001JQ`80FHX405^B1P1MS`D0G90405jI1P1LW0L0GYd606>L101QVP<0H9L5
05jG0`80H9T401H0HYX406>G101LV@L0F9T:05NF2P1LV0L0FI<605jD101NT`<0HYH406>I1@1WV0D0
JYX506ZG0`1]UP40KYT106ZO0`1XX`D0JZD806ZR1P1/XPH0JJ@50P1/X@<03`1/X`L0KJ@807>V1`1b
Y`H0LjH507FU0P1gX`00M:H007BX001lZP00OZX007b[0020Z@00OZH007VT000207RT000W07JT001h
Y`00N:D007^Y001lZ@00Pj/108B[0P24ZP80QJT208B[0@24Z@00Q[0108R_0@27/P00Q;4008N_0028
/040RJd408J`0P20/080O[0307j`0P22]040QK8108J^002:[`00R:l008B_0025[`40Ok04082d2@20
/PL0Pk<308Rd0@2:/`00R;D008Zf0@2<]@00R[@00080RkD002L0RKH008^g0@2;]@00QkD008Vg0029
^@40SKP908Zg202=^0L0S[@<096c2`2E]0X0S;D;08bf402I/A<0VKH<09Jh2@2B^0d0VKP>0:2g2@2E
]`/0WkL<0::k3@2I_@/0UL0;09Vk4`2I^Pl0U;T;096m302I^@h0VkL=09Jh3P2F^Q00WKHC0:2g402N
^Ph0W[PD0:6f5@2L]Q400P2M]A409`2M]1H0VkHA09Vk302G^100XKDC0:Fi3`2F^Q40V;LF09ji4P2I
]A00U[8G09Je4P2H^@`0T[DC096e4@2@_A80T;TE09bb6@2N/A<0XJdE0:NU6@2TZAP0YJ8Q09FV602A
ZB00T:lC09F`4`2XYAT0ZZ<P0:nI<02TXS@0TZTk08J]>020]CD0N<Dc07S6:`1faRD0Nl<N07_37@02
0833800W07g59@1iab80N/`Q07O>7`1hd1h0N=8K07gC6P1jda/0NLlN07[?8P1icA`0N/hI07O<6@1c
c1X0N<TJ07[97P1gbQ`0L<dO06g@8P1XcRX0K<@_06c4<`1]b2X0LLPY06fm:`1[_2h0L/4_07;8:@1`
bbP0K/`X06k;:01`cRL0Km0V06o<:@1YbBl0IlXZ06C;:@1Tb2`0IlLc0080Jl@g02L0K<Xa06[@9`1X
dRH0J]<Y06OD9P1_eQT0N=8F07c@5@2;ca80S=0I08c>7@2=c1`0SLXF093:5`2Aba`0T/DN09;2802<
aA/0SLPJ08g=6`2Bab<0TL4W0932:02>_BL0Sk8Z09ZT<02WWSH0/iHm0;Z@@P2gT4T0Z99?09JIB`2C
SU<0SH9E08j?G02DTU`0VheG09N7DP2ASDP00P28X2L09`28VA@0R8H308J50025P000Qh00089m001l
MP00Ng0007e_001jNP00P7d0089m0020O@00PWX00860001nO000OGh008210020O`00O7P007Yk001l
O`00OGd007Mi001fM`00Mg@007Mh001aMP00K7@006EZ001MF`00F5@005U=001ID`00FU@005UD001D
D@00ETd005M@000205aC000Q05aD001ID000Edh005E?001CCP00DD/005A=001FCP00DDh004i40019
@P00C4<004Y10017?`00Ac`004Hi0012>000@cP0040h000n=@00>cD003H_000`:@00<BP002hW000Y
8`0091/001dH000F4`0040`000/500050P000P0004@00000303oool000X0oooo01@0G6X005Y_001J
LP00Fg@005ae001PM@00Gg`105b40P1JS`<0EY<405ND0`1HVPH0GIP205bL1@1OWPH0HIl406>M1@1S
V`L0HYT7062H1P80GYT702L0HIP7062D201MU@/0FYH;05fE2P1OUPX0HI<906>C1@1ST080IHh006ZA
0@1_T040Ki@107:D001fU@00LIX106^J0`1ZWP@0K9l506bL0`1/XP40KJ8206RQ0P1XY@@0J:L;06NX
2`1ZZ0T0K:X706n[1P1aYP<0KZH007:W001gY@00NjP007fX001kZ000Oj@007fR001hW`000P1eYP00
901bZ000MJT007NX001kZP00O:P008F]0026ZP00QJd008>Z0021[P40Pjh108>]0022/000Q;H008Bb
0022/`40P;<4082`1P1o/0<0O[4407ba101k]0<0OKH308:c0@28/P00Qk0008V_0025[P00P;4007bb
101k/PL0O;8807bc2@1o]0P0PkD208Rd0080RKD002X0Q;H108Zd0@2:]040S;P108^i0@29]P00QkL0
08Fg0027^040T;L:08Bh202:^0X0T;D=096d202>^0T0S[P<09Ng502L]Pl0TK/908fn2P2@^100U;P;
09Nj2@2B^0`0VkP>0:>h2`2P^0/0V[/>09^h5P2G^@l0Tk`>09Bj3@2J]`l0VKH=09Vh3P2C^0l0V[TA
09Ji3`2E^@l0VKLB0:2h4`2N^Ph209Vj400W09Rf4`2I^Q00UkT;092k3P2D^Pd0WkX;09Vm3@2H^A00
Uk/?08Vm3@2:^a40T[TC09Zj3P2C^a80UKX>09Fj502A^1H0VK<G09j`502V[QD0ZjPK0::X6P2NXB80
Tj@N096X7`2I[Ah0VZlN0::T702VXAl0/9Hd0:6S>@2AYc/0Q:di07jf>01i`cD0NLPX07O89P1haah0
N/HO0080O/LP02L0NlLN07W;801jd240N]4N07WC7P1id1/0N/hJ07OB701icAl0NL`X07O>8@1gdAl0
M/hH077=6P1kbaP0NlTQ07S;801cbb40KldS06_?9@1`bR@0K/`V0777;01]b2h0Kl<Z07329@1haB80
MlPO07?;7P1bbal0LldR077?8@1bd1h0L<dR06g;8`1XcR@0H<l[063=;01SbbT00P1YbbT09`1/cR@0
JllK06[D801[eB<0KmHM07GE5@1kdaD0Pm0@08g>502>caX0TLhN08k96`2Bc1L0T/XJ0977602AaAT0
S<8M08S37028`AT0R<@N08_59@2B`bL0Sl4T092g802DZBT0XZ4^0:nI=@2hUS80_i8a0;VA@@2[TD/0
ViI;09R=E`2:QU/0UH]K09VAEP2MU4X0UiI508ZH:@0208:G4P0W08R81@24Q@00Ph@0085n0027OP00
Q7`0089j0020M`00NWD007Ue001lM000OGH007ij001oN`00Ph0007mg001lMP00OW/007ek001jN@00
MWL007Qf001lN`00MWP007Qi001eLP00MG40079_001[K@00Hf<005eK001JDP00FE<005aF001LE`00
FUL005Q?001HC@00F4`00080F4h00200Fe8005YE001GC`00F50005=C001CC@00Cd/005A;001CC@00
CdD00512001>@`00CTD004]00019?`00@SX004@g0011=`00?S@003`f000i<`00<B`002XS000Z8@00
:Al002@L000N5`005a<0014<000:20001040004004D00000303oool000X0oooo01@0GgT005el0@1L
O@40Ggl005im001NN`40HXH405b>1P1GV@D0EId505>L1@1FX0D0Fj0505nN1P1RW@H0H9`406BM1P1R
W@L0HYP7062I1`80GIH801@0H9<605jA1@1PS`D0H8h706B>1P1YT0H0Jhh606f?0`1_SP40L8h0076?
001cS`00MID007BG001dV000LI/106jL0`1_WP<0K:0206bR0@80J:@100`0I:D206NU101WZPP0I:X8
06F/1P1[[@@0L:`4072Y0P1bZ@00LZP007NY001iY`0207VV000307ZP001kX@00MZD00080LZT002L0
M:X007^Y001nZP40OjX108>/0025[P00QZd008F^0020[@00P;0107n`0`1o[`40PZh008Bc0022/000
Ojl207^^0`1k[`<0O[02082`0P23/@80P[8207jb0P1o/`00Q;8108Fa0@25[`00PJh007f^001l/`40
O[@307nd101n]@P0Pk@808Bf1027]@40R;@008Vd0027/P400P2=]0409`2<]@40RKL008Vi002:]P00
QkL008Fg0028^@T0P[P908g03P2B]Pl0T[D908k0202@]Ph0T[DA09Ff2P2>_@T0SKd:09;02`2B^0X0
S/0;09Fh3P2L]@l0X;D<09Zh302J^Ph0WkHA09Zg3@2H^A80V;T@09fg402J^0d0VKT>09Ng3`2N^140
V;T>09^i402M^1<0WkLB09Nm3`0209>o4@0W09Bj3P2E]`d0UL0;08g0302>`@h0V;/<09Ro302E_@h0
T[`?08^m3@25`140T;`D09^k4@2A^`d0T[X@09Bh4@2B^A@0UK<E09be602Q/1X0XjlN09V`7@2IYB80
V:LR09^Y8P2KYRD0V:/T09RS902KX2L0XYTf09VR>`2=Xd00P:U007fg>@1i`SL0N/T[07S:901hab<0
N<TR0080O</J02L0N]4F07O@601idQP0Mm@J07S?6@1hba/0N<LM07C:801gbRD0MLX]07C=9@1fcQh0
ML/P07388P1cab<0MLDV07C99@1bc2P0L<`U073<8`1^cAd0LllM06k<:01XbS40KLH`07;:9@1hbB80
LlTR06k89P1]bB@0KLX^06k>:`1^cR@0KL`Q06W;9P1ZbbT0H/X_06K?:P1WdB800P1/dA`0301bdAD0
L=4F06gD6P1_eQX0MM<F07_E5P22d@h0S=0<093?402AcQD0U<XM09?28080Ul<P01T0Sl8O08c17P28
`b40QkhM08Nm6`28_1h0RKdS08_08@2<]240S:LQ09RN:P2WVC80]IXa0;ZE:@2lU2D0]i<i0;6AC02V
Rdl0VHQH08^1F`2@RE/0UIQC09^KA@2<X2d0R9`F0080RHP400@0QH8008An0020NP00Og`00P20O@00
8@1oM`00OgD007Yc001fKP00M6l007Ib001gL`00NWL0081o001mO000OGH007ai001kNP00MWX007Eg
001eMP00MW@007Ii001iN@00M7@007E`001bL000KW0006QV001PGP00GUP005aH001MF000GeT005iJ
001JD@00ETh005990002051<000O05E>001DD@00E4/005A?001DD`00Ddh0059;001ABP00DDP004m5
001<?P00ASl004Xm0016?`00ASh004<h0011=P00?C8003/`000f<000<bd002hW000X8@008a`0020E
000J4`005Ph0010:00091`001`8000400016000000`0oooo000:0?ooo`0D05b00@1OQ@<0GH@20626
0@1RP@00GhD205j?1P1NT`H0FYP605bK1P1KV`H0Fil505^P1@1NW0H0GZ4605jL1P1OVP@0HiD505nD
101KTPD205b@1P0W05n=1@1RR@<0HXH206R30P1XQ@80JhX106j;0@1`R`40LH/007:>001eS@00Lhh0
07FB001fVP00Mid007>O0P1/X0@0Jil206ZN0@1/X`40JjD306NX0P1SZ@40I:P206B/0`1TZ@<0JJX2
06^Z0@1_Y`80LJ/107>Z001c[040MJT107NZ0@1eY@00MjH007RR001hY@80NJP30080Mj/101/0NJX0
07ZZ0@1oZ`80PJ/208BZ0@26Z@00QjP008>/0024[P@0PJl3086`101n[P80OK0007Zb0@1l/P40Nk40
07V`0@1h/P40O[80082a0020/000PK4008>`0020/P00Ojh107n`0@20/P000P22/@002P1o/P00P[<1
08:f0P24^0<0Q[D508Bf1025]080RK@008Za002:[P0208ba000R08^c0029]P00QkP008Vf0024]000
P[H008Fh1@24^0T0T;P@09Bg2P2H]`T0Tkh909?0402@]A80SL0908g02P2@_P/0TL0:08c02`28`0d0
U;X>09Ve3@2G^@X0U[X;09Vi3`2Q]@l0VkP:09Vl3`2J^A40VkP?09jo3@2H_0d0VKT@09g04080Uk/?
00<0UL0C08nn4@2=_@h00P2<`0d09`2=_@d0S/0=09C03@2@`A00Sl8@09Rm3P2E`0/0TL0;08nm402=
^a40RklB09:l502F]a80S[P=096j402E^A@0UKTC09Ff502K]A/0WKDL09^_8@2G[R@0VjTW09^Z:`2C
YRl0U:P[09BX;@2CXRl0U:8^092N<`2?Xcd0SYm0086R@P1j/400M<8g07S9:01gbR40Ml/U07K;9P02
07K=7@0W07O=6@1fd1X0MM0J07CA6`1cc1/0L<@O07708P1c_RH0ML4V07C4:@1bb2H0Ll/N07K8801_
`bH0K/DW06o4;@1bbRD0Kl/R07;;8P1bbb00LllH07;A6P1bc2D0K<`^06g;:P1acBH0L/`R06_;8P1Z
bR@0J//Q06g<801]d1l0JLlP06O=8`1TbbT0ILT/06C9;P1WcR@0JLlL0080K]<C00h0Lm<B07GD5@1c
dQP0MMDG07GB5@1kd1<0Q<l=08c?3P2?dAT0SlhO09;69`2?abX0T/HT09?18P80SL8U01L0RlLP08c9
7029aQT0RlHJ08c1802<_200RK8Q08NV8`2=XBP0UI`]0:2J=P2WWCH0[i`l0:nI@P2YUTT0WhYC09J2
FP25OUd0S8UF09NDBP2LV4@0Rj@J08bD2P0208R60@0@08250020OP00NW8007Yf001nN000NgP007ac
001hJ@00MFX007E]001dK000M6l007=b001gLP00NG`007ag0080NgH001D0MgT007Ii001bM000LW00
079_001fL`00N7H007Qd001fL@00MG4006m_001YJP00HVD005eO001PG000FeT005]H001MDP00FeH0
05IB001BCP000P1CC@007P1BC`00D4X00599001CB000D4X004e7001:@`00C4<004a0001:?@00Acd0
044e000o=@00@SX003df000o=000?C@003T^000b:P00<BP002/S000V8@008Qd001hH000H3`004@T0
00d7000910001@40004104L00000303oool000X0oooo01@0GH4305n51@1OQ@@0H8X10628001OR`<0
Gi0505fC101NT0L0H8l8062>201PU0H0HYH506BE101RUPD0HYH305jC0@1OT@00FYD105ZB0`80G8/3
02L0GhP206J60@1XQ000KX<006b5001/R000Jh`006V>0@1[T000KHl0072@001^T@00KiD007BJ001f
W@40Kj4506^T1P1]X@80K9d006bO0@1[X`<0J:H306VW0@1XYP00JJH006VU001[XP00L:8007BR001c
Y@00LjT107>[0P1bZ080LZT207>X0P1dZ@80N:P207Z[1@1kZ`L00P1kZP<09`1nZ@00P:L107n/0P1j
ZP80OZT1082U0023ZP00Q:T008J/2@24[PL0Pjl308:`0P1o/P40O;8007^a001j[P00O:l007n`0023
[`00Q:l008B^0023/000P;8007^_0@1i[P<0NK8207nb0023/000P[80082c0026/`00Q[L008Rf0026
]040QK<208Jb0@29]000R[4008f`000208Vb000W08Ff0026]`00R;L108Vf0@29]000Q[H608Nh2@2;
_0X0UKT>09Zh2@2I]`T0UKl:09304@2?]a00S[d;08jo302B]``0TKP:08_03@2:`100TKT@09Vk2`2C
`0/0T[/=09Jj3P2R]Pl0V[X;09fj3@2N]140Wk@>09nf3P2G^Pd0Vk/@09_0402H`0l0U/0>0970402;
_A00S[`<0080S;d:02L0R/0=08[13@2A`0/0TL0>09>m3`2E_140U[h@09O03`2@^Q80TkPE09Nk5`2I
]aP0Uk@G09>g4`2B_1<0T;/C08ji5P2A^AX0U;LM09Jh802C/bD0UjlZ09b];@2FZC@0SZ8e08bU<02>
Yc80TjPd092X<@2:Z3L0PjHm08JR@024WT<0PJhl07c2=P1nbRX0N<dU07K:9`1`c2T00P1cbB409`1g
`R40LlTO06k=7@1[cAd0K<`N06S48@1]`2@0MK`T07O09@1b`bH0L/HP07;;7@1cbad0MLTO07;98`1a
bRL0L<hS077=8`1ecB40M=0O07??701bcA`0M<`V07?;:P1dbbL0LL/S06c>901ZcQl0KldK07;:5`1c
c1D0LldE06g>6P1^c1`0JL`N06O=8P1Yc280JLhG06o?4002077B400W07CC4@1deQD0M]DG07OC5@1l
cA80NldA08G?4@2<dQD0S=0L08_>7P2=aB@0S/HW09758@2D_2<0U<0W09309`2=`2@0Rl0O08[37P2:
`B00S;/U08fc9@29ZR/0Qj4^08RM<P2;WCH0TIe009bOA@2VWDP0YIe60:JIA`2KRe00UXAF08b2F@2E
RU00TIe308RX<@2<W180S8/20080RXH002L0Ph@007mj001iL@00Mfd007Ye001lM`00OW<007Y[001e
IP00LVH007A/001cJ`00M70007Ea001gLP00N7@007M`001kMP00N7T007Qh001eMP00LG0006iZ001_
J`00MW<007Ib001eL@00LW8006eY001UJ000HF4005eM001KE`00Ee<005QF001IE`00FeT005IE001E
DP000P1GD0007@1GD`00F5@005E?001AB@00CTH004]3001;@@00BD4004Y00018>`00A3`003lg0010
=@00@3X003lc000k=@00=c80038[000b:@00;B<002HQ000S70007QP001`F000C3@002`T000H40002
0@000@0004P00000303oool000X0oooo01@0Fgh3061o0`1OO`80GWd105j60@1NQ0<0GHX305f90P1N
P`@0HH8605mn101NP@@0HH/3066;0P1TSP@0GXd305V>0P1FS`80Ei0105b<0080GXL002L0HXH006B7
001ZQP00KXL006^6001ZR000J8`1066@0P1QT`40I94106RC0P1YU@80JiD106jJ001/WP40JZ<306bR
101[X040K9/006^I0@1[W@<0KYh2072S001`W`00K9l0072O001aW`00LYl0076N001cX`00MJL007FX
0@1dY080LZH207BX0`1c[0@0MZd307R^1@1m[PL00P1o[@<04P20Z@00PJP008:V0@1mY@40OJL007jV
0021YP80PjP208BY1`22[@<0P;0207f_0@1o/040OJl007f`001o[@00PZl0082`0080QJ`00100Pj`0
082_001k/P00Lk@207>e101i]080O;@007nd0022]@00P;8108:e0@25]P40R;H008Bd0024/@00R;@0
0P29/`006029/P00Q;8008Bb001m]@00PKH108>e0`27]`<0RK<208^e2@2:^0T0TKP:09bg2`2L]`X0
U[h:09Rh3@2H]Pd0Vk<<09Vg2P2D]@`0TKH=09Je2`2@]0d0SK/B09Jk4@80VKX;0100UKX:09O03P2O
^`l0Wk/;0:6i2`2Q]A00XK<A0:6b3`2M]`h0W[T>09[03`2D`0d0T<4:09702P2?`0/0TL0;0P2?`0/0
4P28`@/0S<0<09;03@2E_Q00T[h@096k4@2E_1<0VkdF09Fi5`2D^1P0UKLJ09Ng6`2A^QP0T;lE08_1
4P29_aD0R/0G08fo7080SK/Q01<0R[/U08be:P2D^Rh0TK8e08R^=`27[S@0RZdd08na>02<[cX0R:To
086Q@`1oXSl0NjHn07nb?01n`CT0O<T^07W;901hc2@0M//T0080M/LQ02L0M/DR07C98P1ac1h0K<dK
06c=701[aQd0LLDM07K5701hbQl0LlXR07;:801`cal0M/dQ07O<7`1ec1h0LLlS06g;:@1[bBh0K/d[
07;@:P1_cR`0LL`Z07?8:@1`abT0M/TZ0738:P1]bB`0K/`V073<8P1cbR00M<LP07G<7@1bcQ/0L/dD
077=4@1bdA<0LM0D077A3`1dc`d00P1cdA009`1ee0l0LMPF07CG5`1lda40Pl`A08S94`2;b1H0SLTJ
08_97P2;bAl0RlDR08g4902C`BL0UkXY09_08`2C`280TL8O08no802?]b40Rk4S08b^9`2?[BT0RjHZ
08VU;`29X3<0S9`l08VJ@P2<VTT0TYaD09fMD02NVd`0Sh]A092?D02FUE@0VIE:08bV>@22XQT0Qi@;
08J9000208F7000A081o001mM`00NW@007Qc001jM000OGT007ai001kLP00NFl007I^001eK000LVT0
075/001eK@00MG4007Ib001hL`000P1jL`00501cNP00MGX007Id001aKP00JVL006iV001_J`00L700
071b001VK000HF<005iO001KGP00FUT005QE001JE`00F5X005iN001MFP00FeH00P1LD@002`1JEP00
FET005YB001EC@00D4T004e4001<@`00CTH004Y40018@`00ASh00080A3`000h0@3P003lg000k=000
=2l0030Y000]:0009R@002<L000P5P006Q@001PB000@30002PH0008204X00000303oool000X0oooo
01@0Fg<205ed0P1JLP40GG8105ei0`1JN@<0G7T105mm0@1NNP@0FW`705Mh201MO@P0GHT905b<2@1I
R`T0FHh605NA1@1GT0@0F983062<0@80HHP002L0HhL006F;001VR000IhD006B7001RR000HH`105fB
0P1KTP80GY<505jF1P1QV@@0IY/106NL001WW@00Iid106NN0@1YW040JiX106ZH0@1ZVP80KIP207:G
0@1gW040Mi/007FQ001bX@00LZ@007:S001bY000MJD107NU001jY000MjD107JW0@1fZ080N:T107ZX
0P1lZ@800P1nZ`409`1m[@00OjX0082W0@1oY@40NZL007FW0P1iY`H0NZD507ZX0`1l[000OZl107V]
0@1j[P00Njl007f^001o/000O[80082`0021/000Q:d008:_001k/000Mk@007Vc0@1h/`80O;81082b
001n/`00P;<007nc0023/@40Q;@008Bc0027/P00QJl008:`0024/000QKH008>d000208Bg000W07jh
0020^080PkP608Nf1P28^0@0SL0908nf3@2E^0`0VkP;09:i3@2E^0h0UkT?0:2i2`2Q/`X0W[L;09Zf
3P2J]A40X[0;09Zc302G`180V[XA09^j3@2N^``0VKP=09Zh3@2O^`l0XKP>09fj302N]`d0W;LA09fe
402L^@d0VL0=09[03`2I`0/0UL0:09302P2C_0d0U[h>0080UL0>02L0T/0;0970302D``d0T/0A092m
502>_1@0T[dF09?05`2B^aT0T[`I092l6`2A_a/0T<4K08o25`2<`aD0R<@D08O55026aaD0R/HG08k5
5`2:aAL0SL<I08g37028`R40Pl8V086l:P21^R`0QkXa08Vi=`27/Sl0PJQ2086W?P1iZ3h0N;<k07S3
>01jbb`0MlhV07S@8`1hcB800P1gbAl09`1dab40ML/T07G=7`1dcAd0L/dL06k?6P1_cQL0LllH07G?
6`1gd280M/lR06o>9P1dcb<0M=0N07G@6`1acR<0KLXZ06[8;@1`bR/0LL`]07?9;@1ebB`0N<@Y07C4
9P1ga2@0NLDQ07S78P1eba`0LLhJ06o<6P1ac1T0M=4C077D401id0h0M]4>07W@3`1dd0l0MM@>07KC
3@0207?D3`0W07;F4@1cfQH0L]LC07cD4026c180R<LL08c67P2<bal0QL`O08O;7P2;bQl0S<HU09;0
9`2A_BL0Ul<O09?37@2>aQh0T;dP09J]902DZBH0TJ8V08nP9`2@XR`0Sj<a08nS=@2>V3/0Pha9082=
CP2:V5D0T9YF09JKD02>TDh0TIM;09VLBP2>WT@0Pj8T07nH3@21S`<0Q8H00080Pgl002L0Og`007]b
001jLP00NWH007ii001oN`00Ng/007ag001iL`00N7<007I_001dI@00LVT007EZ001eKP00NW<007]f
001kNP00N7P0079k001dNP00LGD006e^001ZHP00IEd006MP001[JP00JG4006A]001QI@00G60005mM
001LFP00FeX005YM001LGP00H60005iN001KF0000P1KE`006P1KEP00EeD005I@001ECP00DTX004e4
001:@`00BT8004U50017@P00B40004Do0013>`00@3H003Xg000e;@00;RX002dV000Y8`008Qh001hI
000F40004@d000l;00081P000`<0B`00000<0?ooo`002P3oool0501II`40E64105AV001HIP00F6l2
05YZ0@1IJ`00GG0305Yd201HMPX0Egh=05Z64@1JS1@0FI<?05JA301EU0P0EI<605VA1P1HS`<0GHX1
0P1RQ`009`1QR@00Hh/00669001TQ000HhT005f:001MS@40FI4105^?0`1IT@P0FYD8066H0`1RV`40
IIP006BJ001TV@00IIP006VE0@1VV080IIL106NE0@1/U0<0Li<307ZF0@1jV000MJ0007:S001bYP00
M:@007BT0@1eYP80NJD107ZU001hY@00NJD107ZP0P1jY@80NZ@207ZZ000207V/000W07Z`0@1l[@40
O:`207VW0P1fZ@40M:P307NX201eZ0P0NJP207f[001nY`00P:T007f]0@1o[@00P:l0086b0021/@00
P;00086_0022/@00PK<007fb001k/000O;0007j_0022[P00QZl008Fd0023]000P[0008Fa0021/P00
P[0008F`0026[P00PK8008:d0021]`00P[X00080QKX001@0Q;T008Ri0@28^080R;H308Rn0P2;_@80
VKH<09jg302K]@`0U;@>09Rf4@2O/`l0X[H=09Vg302H]Ph0W;DB09n_502W[a80X;4=09jf3`80WkH@
0140X[H>09nf302P^@l0Y;DA0:Ne4@2V^0d0W[L<09^g3`2K]Q40WKH?09fj2`2H^`/0VL0<09Bl2@2A
_0`0Tk/?09Bm4@0209314@0W09;14@2D`180Sl8C08g36029`QT0Ql4H08S25P27a1H0RL<G08S45@27
aQ80QlTB08c64`2B`a40S/D@08c52`2:b0/0R/T;08g:2`2Ab@X0TLD;09362`2@aP`0SLD;08W83P26
a180QL<E08K66025a240P<0]082k=P21]3L0O;<h07Vf=@1j`S80N//[07S<901hcQh0M<`M0080L/XO
02L0L/XR07;99@1ebb80M<dQ07?>7@1`dQP0L=0G07;?601bcQ`0MlhM07C=8P1^cB/0KllS06kC801c
dad0Km0S077;9P1ZbBT0L/P/07G4;`1h`R`0M<P[07?;9`1cbAh0O<PH07g;5P1ic1P0M<hE073=501^
cQ@0L/l@07G@3`1hd@d0OM0=07_A3@1jd@`0M=@>06oG401[eQ400P1`eQ<09`1`fQL0L]XF07KF4`1n
dQ40QLlG08[;7P2;cAh0S<lL08SB6`2;dQ/0Rm0M09349`2C_2P0SklW09G46P2C`A`0S/<Q08nj902D
ZRH0Vj8X09RM:@2CVR`0T9X`096P<@2@Y3@0Ri`l08:<A@21TU00RiQD08RLE@29WDd0RYMA09NFB@2J
W3l0R:Tc08FV5@21V080P8h008>3000207mj000W07ed001hL@00NFl007Ud001mNP00O7P007ei001j
O000MgD007ei001jM@00MfX007E^001fK@00Lf/007Ia001lM`00O7/007Qj001gO@00MGX007=d001_
KP00J6@0069H001TF@00I6D006E^001RL@00Hf`005mQ001NH`00HF8005mO001NF@00G5d0061S001N
G@00GUT00080G5d001T0FEP0059D001CC@00DDd0051<001>A000C48004U1001:@@00Ad@004Lo0013
>`00?SD003Pc000g<@00;bP002LS000T80008Ad001/G000E4@003@`000X700071@000`4004`00000
303oool000X0oooo01@0FFL105AQ0@1DIP00F6H005Q_0P1JJP40FF/005e`0`1JM0P0F7H:05Mn3@1J
QQ40FX`D05VC3`1FT@`0EI@805FC1P1IT@H0F8l305f:0@80HXL002L0HHT006>;001QR@00I8@006>9
001MRP00GHd105VA0@1KS`<0FI4805ZE201QV0<0HY/106FH001TVP00I9T006FH001YU@40IYP206FG
0@1WU@40K9@307>C0`1jUP40NYP007FP001bX`00LZH007BT001dY040MJH207VU0@1jY@00N:D007VU
0@1jX080NZD207ZT0P1jZP000P1i[0009`1j/040O:d107b/0P1iY`80MZT107BX0`1gZ0P0MJP807VX
0P1mZ`00OZL0082Y001m[@40Ojd0082_0021/P00PK40082`0021[`00P[40086c001m/P00Nk0007b`
001n[`00PZh008J_0025]000Pk@008:`0025/@00PK8008:`0025/000QZh0086b0022]000PKL008:j
000208Fj000D08Bi0028^@40R;P208Rf0`28_P80Rkd209Vf302N]``0VkD<09Bd3P2H]Q40Wk<?0::f
3@2I]``0V;H>09be4P2O[a@0YjlB0:2a3@2N]Pl209nf400A0::f3P2O]P`0X;T?0:Be4@2W]A40Y[P=
09jg302K]`l0VkHA09ff3`2M^P/0V;/;09W0302D_0T0TK`<09>k3`2D_A400P2@`A409`2B`A40U<0B
08o24`2=`aP0RL8I08O16028`QH0Ql@F08W35`28a1D0QlHB08O94P2<aQ<0T/<A08k5402<a@/0R/P;
08[92`2=bP/0TLT:09752`2@aP/0T<H<08g52`29b0h0Q/@B08G35@26aQP0QL@Q0830;@20^cH0PK@g
07bc>01i]SD0N/8b07[;:`1hc2@0N<hN07C<7@0207;:7`0W07;:8P1bbBD0ML/R07C=8@1ccQd0L=8H
073@5`1bcaP0L/hL07O>7@1dcB80K/d[06o?8`1^db00Lm<M06o@8`1abbH0J/TY07;8;01ea2l0N<8/
07C8:`1cbbL0LlTN07c8601mbaH0NL`H07C>5@1`cA@0K/hD07;?401ed0l0N=4=07g@3@1kd@d0N]4<
07CD3P1_ea00JmHA0080L=HC02L0L=XG07;J5P1feQ<0O]8A08G?5`2:bah0RldN08c?7028dQ/0Rm8K
08_@7@2@a2L0Tk`X08no9`2Ea1X0Tl4L08k38@2?^R@0U:XV09^R:02HWBT0TiX/092J<02AX340T:@d
08^L?022S4D0PI9@08^HE028W5D0RIe=08ZGD@2GUTT0VY`o08RY<`25YQD0PIP2082>0023P`000P1o
NP009`1mM000N74007U_001iM000OGX007ah001mN@00NW`007Me001mN@00NWD007MZ001eKP00MVd0
07=[001fL@00O7L007ak001hNP00Mgd007Ej001cM000Kfh006QT001RF000I5T006AU001UKP00HW40
06=/001OH@00GV<0065R001OG`00GUT005aM001PH`00GUd005iI000205aM000I05UH001BE000Ddd0
055=001@C000CT@004a20019@@00BT4004M40017?`00@c/003he000h<`00=c4002lX000W8`009200
024M000K5`005A4000d<000:1`001`D000<1001<000000`0oooo000:0?ooo`0D055J001@FP00DU/0
05MJ001IH040EUl005EN001IJPP0F78;05Me2`1GQ0d0FXP@05RB4P1IU0l0EY@;05NH2@1FU0L0EHl4
05R<0`1JR04205j4000W05f6001LR000FXH005V30@1JR`40Ehh005B>001KT000G90205^B1`1IT@D0
GIL2062G001XU@00JY<006bD001[U000JID106RG0@1[U`80JiH206nD101bTP@0MiH107BJ001cX@40
LJ40076R001eYP00MZH107ZW0`1jYP<0NZH207JU0P1fZ0D0Nj<907VV201iZ0D0N:/20080Mj`102L0
MJd107V[0@1j[080NJ`107Z[001jZ040NZ/307VZ101kZ@80OJL007fZ001k[040OJl107b_0@1m/P00
O;H107nb0P1o/@80OZl007bb0022[P00PJl0082Z0022ZP00Oj/0082^0023/P00Q[@008>c0022/P00
QK4008J`0027[`00Qjh008N_0024/P00PkH008Nj0026^0000P2:]`009`2:^000S;X008bk002:]`00
QL0208Zm0P2@_0/0U[T<09Jo2`2C]0h0V;<B09na4@2Q]`l0WK/=09^e3`2L]180W;<E09nc5@2P/Ph0
WKD?09jd4P2M]180YkD?09nb3@2U/a80Y;4C0:>d3`2R]Pd0W;X<09Fk3P2E^Pl0VKLA09Rh402E^Ph0
UKd=09>k4@2A^Q00Sl0A08_3500209335@0W09?25@2A`aH0RLDF08C35@1oa1<0P<H@08G74024b0`0
RLL;08W72@2:b0T0RlP:08k52@2@a@X0TL<;09721P2>`P80SL440932102C`P<0U/8309K00`2B`P80
T<8408g22@2<_`X0Rkl;08W13027`a00Q<HD07o58`20a2/0O;/c07fn<`1k`C@0OLLZ07S;901fbad0
Ll`L0080L//N02L0LL/Q07?=8@1dbb80M</S07C:7@1_cQ80M<lB07G>4@1fcAD0L/`O07;=7P1bcR00
L/lO06_@8`1_dB80Km4S073?801]cal0K//X0737;`1bab`0L<XU07C;6P1gc1D0O</B07[=4P1gcAD0
M]0E07K@4`1ddA40L=0@07?@3`1ed@l0OLl=07[?2`1hdP`0LM<=06[H3`1XeaL00P1[fAd09`1beb40
M]LH07cF5P26dAL0P]4I08S@6@2<cad0RllK08c@702>da/0S=@L08g69P2?`2P0T<LP08o65`2=`1`0
SKhR08fh:`2AZS40V:8b09VO<@2AVBd0SiTa096N;`2=Xc40RJ@h08FJ@P23VT`0RY]B08ZKD`23Wdh0
SiY=09ZHC02IXCd0QZPK08NO4027U@40Phd008>0000207mf000607Q_001fJ`00MFh007Ya001gN000
NGP00P1kN0007`1lM`00OGl007ae001kL000NG0007M^001cJP00Lf`007Ma001gLP00MgD007ah001g
M@00M6l006m[001YIP00I5/005mE001SE@00Hf@006A]001RKP00GF<005aP001OI000Gf8005eJ001K
GP00GF0005YJ001KF`000P1LG000601FE@00DDl004e9001=AP00CDL004a40018?`00A3h004Ho0016
@000@3`003`g000g;`00=B/0038[000Z8`008Ah0020H000K5@004Q00010:000:1`001P<0008104d0
0000303oool000X0oooo01@0De/0055K001EFP00De@005AC001FF000EE/005Ue301IN`l0G80<05V6
2@1GR0T0F8P:05Z@201GU0T0F9L805V?1@1HQ`<0F88105Ql0080Fgh002L0GH4005^3001KQP40FhL2
05Z=0`1JS@40FHd005j:001RRP40GXl206>>0@1STP00IID006jA001`T@00LID006jK0@1]VP40KiX1
072L0P1`V@40LY@2076A0P1dUP40M9X007>N001aW`00LY`007BQ0@1iXP80NZ@507NU1`1hY0D0MjH3
07BW201hZ0`0N:L;07FW201dYP@00P1cZ0<09`1dZ080LjT207J[0@1hZ`00Oj/0082Z001n[P40OJh1
07b[0@20Z@40OjP007f[001n[P40O;8107^a0@1k]P<0NKD407jf0P1n]000P;<008B`0023ZP00Q:T0
08:Z001o[`40OK01082`0023/P00PK4008B_0027[`00Rjh008b`002</@00Sk@008^e0029]@00R[L0
092f0@0208ff000W08nh002?^@00TKL008jg002:^@40S;d508nm302A^0/0TK`:09:m302@^Q00U;DC
09Vi402L^0l0W[X>09Nk4@2F^QD0WKHG0:6e402P]100Wk@D09bd5P2U]Q<0X;8A09^d402I]Q00V;T?
09Jn3`2F`0h0T/0>092m3P2>^Pl0T;L@08ni502D`1H0Tl0C08o24`2=a1<0Ql<D0080SL@C00X0T<DA
08g74P28b100PlH:08772P23a`T0QLL808K62028aPL0Ql@50P2>``<06`2<a080Sl810972002D_000
TK`008g00P2=`@@0Tkd309G20@2I`@40V<8009?0002@`080S[/309:k1@2?_0T0Rl8<08c43@27aA<0
QLDL08339`1o`Bh0NL@`07K7:01ec200M/`M07C<7`02073>7P0W077<7`1_cah0L/`S07?98P1aaah0
LL`C07C<4@1fc100ML/E07;69@1_bb<0K/`P06g?801^d2H0K]0S06o?8P1beAX0L]DM077?9P1/cR`0
L/`T077=7P1gcAL0N=4D07c@5@1kd180O<lB07_>4P1kc`l0O=0>07GA4@1gd0l0M/h<07W>3@1ic``0
M]8:073C3P1^e180L=DI0080Lm@J02L0Mm<M083D6P23daT0Q]4I08GD6@29eQP0S=@H08gD6@2>daT0
Rm@G08gD6P2>aB@0TLDQ09C=602=aAL0RL0J08^l7P2;^b@0QkT^08Va<029ZS80QZ0^08RP;@2:XRd0
Pj@b08>Y=`25YD80Qim908JFD02;X5H0RJ9E09ZKC02FX4H0TJHa08>O5026T`L0QHl108B7001lP000
0P1mN`009`1iL@00MfT007EZ001cL@00M74007Id001iLP00Mg<007Ue001iM000Mg8007Q]001eK`00
LVh0071Z001`J`00LVX0075/001eK`00MG@007=c001bL000KV/006QQ001SE@00FT`005Q=001JD`00
G64005mZ001LH@00GF4005iQ001LF`00F5L005YE001HE000EU@005IE000205QH000G05MD001DC@00
CdL004Y10018A000BD8004Do0012?000@S/003hi000l<P00>34003@^000b:@00:bL002DN000M5P00
5a40018@000=2`002@T000L500020@00CP00000<0?ooo`002P3oool0501GH000E6H005EQ001EE`00
E5D005IL001HI@00Fg4205V52`1KQPP0G8L505Z10P1GQ040F8L205J<101DRPD0FhL305en0@1IO@00
Egd10P1IO0409`1KP040GH8105j50`1NR@D0GXX505f>0`1QR@40I8P006N8001/RP00KH/006RA001^
U@00LY<007FB001dU000LiP107:K0P1dW`40LYh1076L001aV000KiP0072K001bX@00LIh007:N001`
WP40Lj@307>R1@1dY@L0M:D907FR1`1eYP80LJL707FX2P1bY@P0L:<506nS1@0207:U100V076U0@1c
Y`80N:H007^W001lY@00OJH007nY0020Z`40PjP1082/0@1j[080Ojd307nZ0P1l[P40Nk8507Rc1`1h
]@@0OKH1082d0021/P00PZl008:/0022[@00PZ`107f^0P1m/040O[00082_001k/@00O[4008>a0027
/@40R[<108b`002@]000T;@108ff0P2=]@8308je0@0W08ng0@2>]`00T;H008ji002?^040T;X70930
2`2G^`d0U;P<08fi2`2?^@l0T;HB09Jk4@2K`0h0VkT@09Vi402H^140VKPB09ni4`2T]a80W[T@09fi
4P2S]AD0XKHD09Zd4@2D^0d0Uk`>09Ji402D^a00T<0@09303P2;`0h0R/0A08c04`2>`A@0S/<C0974
4`2<a1<0R/DB0080RlD=00/0S<L:08W62P25a`T0QLP908G72@2:aPL0Rl@508_3102=`P80R/8108c0
000208k0000J08o2002A`000U;`009:i002>_080SKh408nm1@2B`@@0UL@209G30@2B`@00TKh009Fm
002E_@40UKd209?2102A`@X0SL4>08W24025a1L0P<4S07S3;01gabP0ML/P07S=7P1ecAh207;>7`0W
077=801`cR40L</U06o;:01^bRH0Kl/O06k;6`1]cQL0L<lK07;;:P1^bBT0KlXU06o;9`1/d2X0Km0P
073A7@1fe1P0Mm@J07KC6`1edQh0NL`J07O>601icaP0Mm8H07c=5P1jcAT0M/lH07S@4@1kdP`0N<l=
07CD3`1gd@l0Lm0>07C>3P1kd@d0M]8=077G3`1cea@0M]HH0080NmHF02L0PmDH08OA6P2:dQl0RM4P
08WE7P28eB80SM<L08oD6P2:dQ/0RM<K08OA7P29cAl0T<`L09C=5P2>a1H0R/0H08bl702;^Qh0QkhW
08Fh9@22/bT0NZdY07fU:@1lYBT0NZLc07nW>@25YT<0Q9Y?08N@EP2<TU/0U9UK09fHB@2;Xd40PJDY
08:G3`26S@<0QXT00866001jP`000P1eO`007@1fN`00NG4007U_001fK`00MV`007M_001eL@00LVh0
07=X001cJ`00M6h007=[001aJP00KVX006eY001`JP00LFh006eX001^J`00L6T0071X001^IP00K6<0
06EM001PE000Ed`00554001BA000EUL00080Ff4000P0F5l005UJ001IE`00FUD005aC001DD000DD`0
051=0080DE4001L0Ee<005=?001?C000BD<004M10012?@00@S`0040i000k>@00>C@003@_000c;`00
<2/002XW000V7`007aL001D@000>2`002`P000L5000410000P800041001>000000`0oooo000:0?oo
o`0D05Q]001JK`00FFX005MT001GHP00Efl105Yd001LNP40HH<305j30P1KPP00FH4005N0001IP`00
Fh<105b20P1PO@00GGP005em001KO`4205an0P0W05j10`1PP0<0HXL206:8101UR@@0HXP306F90P1Y
RP40Jh`006Z7001^RP00Jhh006fD001aT@00Khl007>@001dT`40LiX2076J0@1^WP40KI`006^L001Z
W@00JIl006fN001`V`00LI`007:N0@1^X`@0L:H707BS1`1fY0L0LjD407>V0@1dY@80LJH4076Q0P1_
X040Kih20080Lj8200<0L:L207BV0P1hX@400P1kX@001@1mXP00NjH007bX0@1nZ080Nj/30080Mk45
01<0NZh407V]0`1g[`@0Mk0707Rc0`1j/P00O[80082c0021/@00O[4007ba001l[@40Ojl1086a0@24
[`00Qjh0086_0021/P00P[<10080Pk<100H0Rk4208je102?/0<0S[4908^c1`29]0@208Zd0P0W08bf
0@2>^040TKP108nh002B]`80TKX:09:h2`2I^180VKH@09Bf3`2D]Q40U;PB09^i5P2J^Q<0X;T@09Zh
3`2H`0h0U<0@09Vh4P2P]AD0WkTB09nm3`2L^a40V[/@09Rh4`2G^@h0V[T>09S04P2E`180T<4B08[1
3`26`a80Q/<A08W64P2<aQ00SLP>08o6302<aP/0RL@:0080Q/H802L0Pl4807o42023aPP0Q<L908W5
2P2>`P<0S/400931002=`@00Rl<008_4002<_`00S;d008k0002C`@00Tl0109:n0@2?_@00SKl208g0
0P2<_`40T/0109K40@2Ea000U/8009;4002D`P00T<8009;2002A`P80TL0408[03026`Ph0P/HH07W5
:`1fbBX0N</V07W<8P1fc2800P1bbb809`1`bbH0M<XV06o::P1/bRh0K</X06_<7`1XcAd0J/hK073?
6P1bc1h0L<TM07G;7@1acb80K]4W07;B6`1dd1H0MM<B07GD401ida00N=0@083=3P1ncP`0OLl@07gC
4`1jd140M/l@07G?401ed`l0Lm<<07?D301ce0l0M]0?07?>3P1ed0d0Nll@07[B3P1heQ00O=LB07_F
600208?G500W08OD6@28dQd0Qm4P08WB9@29dBL0RMDU08[E6P2=e1T0R=8K08G>7`26cB<0RM0J08cA
5@2?c1P0RlLF08W6602;`AL0S/0L08_07P29_A`0Q;/N086k8`1j]RP0N:h^07VZ>01oZ4D0RYe;08nA
E@2>S5X0TXeI09F>F02MUe00QjPd07nQ5P25U@P0QHd008B:0021Q@00OX800080OGl000P0NW`007ae
001nM@00NG@007=]001dJ@00LfP0075[0080KVH001d0KVd0075]001_J`00K6X0075X001_KP00KVX0
06iY001YJ@00IV8006QQ001WG@00HeL0065F001LD@00F4d00514001;?000CDT005AE001BF@00DeL0
05IG001HF@00FEL005IF001CC`00DTd004i:000204e<000D04i?001?C000C4X004I1000n>@00?SD0
03/c000l=000>C<003@`000`;000<2P002XT000T7P007aD001D?000?2`002@H000@30002001A0000
00`0oooo000:0?ooo`0D05Aj0@1FN`40EW8005Q[001GK@00Eg4005Ui001IO@00GH4005]m001GO000
FGh105Mn001HP`00G88105j00@1QO@40GG`005am001LO`4205n00@0W065o0P1SO@80I88106N80P1V
Q`@0JHL406^70`1VR@80J8`006V;001/SP00JHd006^A0@1/S000L8T00769001aR000LI4106n@001]
TP00JI/006FJ001UW@00J9l006fO001aVP00MY/007NL0@1dW@@0Lj<907FS1P1dY@80MJ@007BS001e
X000MZ0007:P001`XP00LJ400080Lj8102L0MJD107JR0P1fX@80MYl107RT001iXP00NZD107^V0`1i
Z@H0MJ`507>]0`1g/080NJd207J[0P1d[@<0Mjd207V]0@1g/000MK0007^b0@1l/P80M[@207Nc0@1j
[`00OK0008:^0025/P00Q;<007nd001o]@00PKL008Ng0@29]P40R[D308Rd202</@H0RZd408B^1P28
/P@00P29]0809`2=^080RkD308fg0P2<^@40S[L3096g2`2A]P/0UKDA09Vd4P2I]A80VKHB09Vi4@2I
^Q40V[/A09bk4`2H`180UL0?09C03`2D`180Ul0E09W04`2L`140Ukd@09Bl3`2F^A40VKXA09Vn4P2E
`180Sl0A08c34`29`a80RlH?08c63`29b0/0R<D:08W62027a`T0Pl@80873200208321`0W07o21`22
``L0Q<<808K51`29a0H0SKl208g00@2;`P00R/@108c2002=`000S[d008k1002=``00T<4109;00P2C
`080S/4008^o002;_P00TKd009Jo002E``00Tl8008o3002;a@00S<H008g4002>`@00Tl4009K2002D
_`D0R/4>08?84@1hcB@0M<dS07G=9@1ec1l0L//M0080L<`U02L0M<`W06o<9P1]c2T0JL`Z06[<9P1X
c1h0I/dO06K?8@1^d1T0Lm0G07K>5`1hca/0N=4M07;B801cdaT0L]8E07CA4@1bd0l0M]4A07OB4P1l
d@h0N]8<07gC3P1lda40O=<=07_B301ld@`0M]H<077G301_ePh0L]@?07K@3@1dd0d0Mm0;07S@301l
e@d0O]D>07kE4P20eQL00P26eAP09`25e1`0QMDP08K@9`27dBP0RM4X08OE8`27eAd0R=<K08OB7`28
dB@0Q<dV08GA6`29caX0R/dO08[;6@2:aAD0R/<H08[06@2:_aL0S;dF08Zl5P25_A/0Ok`V07^h>@1m
[440OJA;08NGDP2<TE`0S99O09:GE02ITU<0WY=A08^Y9`21V180QXh408V<0025R000PX@0081o0002
07el000707ej0020M`00OgX007Uf001dKP00LVT006eT000206iW0007071X001_J`00L6`0071/001_
J@00LfT0075`0002071/000E06eX001UHP00IEd005iK001KD@00F4l005M?001BB@00BD0003ld000l
<`00ACd004Y8001<B000CDh005=C001CE@00EU8005A>001?B`00BDL00080B4L001<0Ad@004U30017
@000@CX003Xc000i<P00=c0003D]000d;P00<2d002hX000Z90008R0001lG000E4@003@/000L40003
0P000P0005800000303oool000X0oooo01@0DWX305Ag0P1FKP00EfX005I/001HL000FgP005Yj0@1I
OP80EWX405Il1P1FP`L0EXH505V50`1LS@D0GHT505f8101NQ@80GH8105n10080HWd002L0IG`106Eo
0@1WP000JhL106^40P1_Q040KhD106b;0@1/S`00JXl006^D001XT000J8`006Z:001YQ@00KHL006^8
001^S000Kh/006f?001]UP00JiD006RH001WV000K9X006fJ001_U000LYP007FG0P1fW0D0M9l307FQ
0@1aX000LYh007FJ0@1fV@40MIh107>S0@1dXP400P1cY0009`1dY@00MJ<207FS0`1fXP80NZ4107bS
0@1gZ@<0MZT407>Z101cZ@<0NJ/207^[0@1mZ@40NjL107VY0@1kZ`40Njd007f]001k[000NZ`207Z_
1@1i/0@0Mk8207Va0@1j[`00PK<008:e0021]P40P[H3086f1@20^080QKL008Fe0028]@80Q[<508Ra
1@27[`<0RJl208Fa0@0208Rc0@0W08^e0@2=]080SKP2092g0`2?]`L0S;h:092e2P2B`100Ul0B09Rj
4`2K`180W<0A09Nk4@2F^AD0Uk`H09Nn5`2G_Q<0U;hA09>n4`2B`180Tl0A09C04P2@`Q40Rl0@08c0
402?`100R/4B08O24P26`a00Q/D=08S72`2=aPX0S<D;08S72@24a`L0QLT608760`21``80Pl<700<0
Q<8802H0QL<808;42@23a0@0RL<508_31P2:a@@0R/H708O81@2;a040S;l008g1002>`000S<000931
0@2D`080Tl8108o3002B``40Tl00096n002C_000U<0009K1002E`000T/<00971002@`@00S/0008k2
002Aa000TL@408o42`25b0d0N</H07?<701ccAl0MLdL07;<7080Kl`N02L0L<hN07?<7@1`bb<0JldU
06_<9P1ZcB80JldR06_?9P1^da`0LM8H07SA5@1gdQP0Mm@J07KB6`1edaX0M=@I07SD4@1gd@h0O=<?
07_E4P1leA00NmD>07[F3`1geQ00NmH>07_F3@1ke@d0M]D=073D3`1_d`l0L=<B07GF4@1gf0h0N=H<
07KD3P1iePh0NmD@083C4024e1800P27eAH09`26daX0Qm@S08S?:P29d2`0QM8Y08CH8@22eal0P]DP
08GB8P25dR@0QM4S08WC7@29dQP0RL/K08S75P28`Pl0R/0B08Nl4P28^a<0RkXD08Vl5`28_AT0QK/X
086`?025[4L0Oim@07^DF01nTU`0PYYN09BKC`2EWD/0TI]108bP6024T0T0Q8P208F;0024R`00Ph00
07ak000207ag000:07Uj001lM`00Ng`007Yh001iL@00M6d006iW001^IP00LFD007=[0080LVh001/0
Kf`0079[001_K000LFl0079`001aK@00LVh006]U001UIP00HE/005YF001DC@00CdD004M10010<P00
=bH002lP000g:000>c@0044l0016@`00AdT004]8001<BP00CT`004Y80018@`000P16@`004P13@@00
@SX003hi000m=@00>c8003Ha000c;000;bP002`T000Y8P0091d0020F000I50004Pl000/;00081@00
0`80004005<00000303oool000X0oooo01@0Cf/105A[0@1FIP00Ef8005EX001IK000FW8005Ic0@1B
M@H0D7/904ml2P1@QPd0DXL905J81P1KTPH0F9@605R?1P1KS0@0FhL206610080Hg`000@0IG`006=n
001WPP00K8@00P1/PP008@1_Q@00KhP006f<001ZS@00J90006B?001PR`00HXX006><001TS@00IHd0
06J<001]S000KXh006jD001`T000KY8006f?001`SP00LY@007:C001dV000LYH007>H0@1aUP40LI`0
06bN001^WP80Kih6076O201bW`H0LYd507>M1@0207>O100W07FP0@1dX@80MjD407NS0@1eY040N:H2
07B/1P1b[`@0Kjl207:_0`1g[P<0Njd3082Y0@21Z@00Oj`007^/001oZP00P:/008:X001oZ080OZ/5
07b^101k/`80O:l107j`0@22/`40PK@0086d0@21]@P0PKH9082g1022]@00P[@008>g0`23]040Q[42
08^`0P29/@40Qk000080PK<00140QK<008Zd0@2=]P40TkP308nh2`2<^PX0S<0;08jm2`2@_A00T;hB
09Jn4P2M`1<0V[dC09;04P2?_a@0SkhF09:k4`0209?04`0D09?14`2D`140SL4B08_44@27a100QL<>
08G53023a@`0P/<<0831201o`PP0PlH708O52@27a`P0Q<L808?81`24b0L0QLD408;40`25`@D208W1
1P0W08g31@2<``H0R<0408_30@29a0@0R/H508_51@27b0T0Q/T808[70P2;a@40QlD008S4002=`@00
T;h009:m002B`000Sl000930002@`@00Rl8008o00@2D_040VL0009C1002E`040U<4209;30@2?``00
R<H008c8002=aP<0SLH708S82`1nb1<0M/XJ07G;8`1ecAl0LLdL0080K<hK02L0KlhI07?@601`cAd0
KldL06k?7`1^d240Km0O077@801be1d0LMHK07KF4`1ida80Mm<A07KB4P1jdAD0N]@K07[E4P1kdPl0
OMDA07gF4P1mf1@0NmDC07_F401geQ00MmD?07WG3@1he`h0M]H>077D4`1_daD0L]@C07_H4P1kf140
N]P?07SH4P1le@l0O=<>08CB3P29dQ000P29e1P09`23dQd0Qm8U08[@;@26dc00Q=DZ08?H8P22eR00
PmDR08;C8@25db00Q=8P08WA6`28cQD0SLP>08[43`29_a00Qk`?08Ni3`27/Q00Q[8A08Vg6@24^al0
P[/]07f]A@20YTh0P:5G07bIF`20UEh0PimG09:KC@2<XDL0O:0_08RM4P24SP40PX/008B:0023Q000
PGX007Qd000207Ed000L07Mg001gN000NWP007Yl001fM@00Lfd0075]001^I000Kf@0071Z001dK000
LW8006i`001aKP00Lg00075_001`K`00KV/006eW001]J@00JFX006ES001MFP00EE<004U20013>000
>Bh002lQ00808aL000T0:R0003H]000l=`00@Sd0044l0011?@00@4@0040n0013?P000P11?`004@12
?@00?cT003Td000f<@00=2d002l]000_9`009b8002@M000P5P006180018=000<2`002PP000L40003
0@000@0005@00000303oool000X0oooo01@0Ce`0055L001@E`00D5@005EM001HI000F6d605I]2@1C
N0/0Cgd:04en301>P@d0DXX;05R<201GT0L0F8l505b:0`1MR`<0H8H106:10080I7l002L0IGd006Al
001WOP00K8D006R3001VO`00JXD006^5001YR@00HX/005n;001PR`00Fh`005b<001MSP40GHd005f>
001NS000IH`006J?001WT`00Ji8006R=001/R`00LHP0076@001dT@40MYH207BG0@1cVP40M9P0076G
001[X@00K:4206ZQ201[X@X0JY`806fI201aW@T00P1fW@X09`1gWPD0MId307VP0P1hW`40M:4107>W
0`1bZ0<0KZ/306f^0@1^[0<0MZd307R^0P20[`40PZh0082[0@1oZ@40PJX008FZ0027YP00PJX107j]
0P1n/@40Ok41082b0@22/`00Ok82082b0P21]0<0PkH608Je1`23]@<0P;D008>c0@24/040Qk4108^a
0`2</0@0Rk@208Nd000208Zb000W08^b002=/@00T;81096e0@2@]`/0SKT:08k02P2;`0/0Rl0>08g0
402@`140U<0C09Bo502A`100S[h?08fn3`2<_Q00T;h@09C04P2?`Q40Sl8?08c44027a`h0QLH=0875
2P21``T0P/H808?32@24``P0P/@808742021aPP0P<L907k81`21aPH0Q/@408C10`20`@D0OL840080
Pl0202L0QlD00931002C`@00TL@008_40@27a`40QLH208G71@28b@D0R/T308_90`25b@<0PLP208O4
0@2:a000SL<108o20@2<a040S/<008o5002=a@80SL<208k20P2>`040Tl4009:n0P2A`0<0SL4208_4
0@25a000P/@108?60@27a040Q<T907_;401ga200ML<Z07C8901`bb000P1_cAl09`1^cR40K/lR077?
7@1bcQT0KllH073A8@1adB40L]4L077E601ae1/0L]LF07OE501ieA40MmDF07SC6P1heAd0O=PE07gE
4P1gea<0MMHC07[G5@1jf1L0MmDC07GC4@1geA00NML@07SI401ff1<0L=TK073G6P1ceaP0N]LF07cI
5`1lfAH0N]XG083G3`22e0d0Qm8=08SC4@0208KA600W08GB6`26eR40QmLZ08GF:`24eBH0P]HR08;E
8`21e2D0PmDR08;C7P21cR40RL`J08[;502>aQ00RL<?08O04026^`h0Q[P>08Nc3@27/0l0Q;@F086j
8P1o^c40Nk5707ZWEP1mXEX0OYeM086IG028WE@0TiQ?08bQ>`1iX1/0PIH>086A0023T@00OhX00862
001hM`00MG400080M70002L0Lg40075a001cM000MGD007Ea001bK`00M6/0071W001_H`00LV/007=^
001aL@00K6h0071`001`L@00L7D007=_001/I`00JV<006ER001WI000I5l0061L001GD`00BT80044l
000i;P00:Ad001/>000?2@0050/002@F000_9`00=C<003Lf000h=@00=SL003Te000j<`000P0i=000
3`0j<`00>c<003<a000b:@00;BD002PQ000R7@007AL001T@000D3@003PX000X800081P0010@00080
001F000000`0oooo000:0?ooo`0D04aC001<E000CU<0055A001EF@40F5h305=U1@1DMPl0CWL<051i
201AN@P0DWl905692`1DR`/0EHH<05V82@1MP`D0GH4205ao0@1ONP4205mi000W061j001QNP00IH00
06F1001RO`40Gg/105j00@1NP@00FWl005^5001KQ`00Fh`005b<001KR@00Fh`005f:001PR000GH<0
06B3001WR@00IHh006J>0@1UR`00JhX1072:001bTP40Li@207:I101`VP<0L9X207>L0P1dW040L:80
06jR0@1_X@@0KYd506nG101bU@<0LiP60080MIP800h0LIT807NL101fW@40Mid1076Q0P1eZ080MJL1
07>Z0P1fZ`00M:T107N[0P1k[P40OZd1086[0080PJ/100l0PjT108FZ0024[000PK0007n_001o/@00
Ok8007fb001m]040O[H4082c1@20]@80Q;H308Bc0`25/`800P24/0401P25[`40RZh108bb1`2@/`P0
Rk@308^b0@80S;8002L0S[D008fe002>]000S[D008ne002>`0X0S<0;08O02P26_@d0Q<0=08o04P2A
_a40SKlC08bl4@2@_Pl0S<0>08W0402=`Q40T<8B08c3402;``l0RLL<08S62@28a0P0QL<808G22@28
a0T0Ql<908G22P29a@P0R<D908[32P25`PT0P/8707o21`22`PL0Q/4508?51@20a`@00P20aP809`25
``00S/8009?2002Aa@00TL<008g4002:a000RlD108g50P2>a`<0SLT308g80`28aPD0Q/L208G70@28
b080R/P608_81P2?a040S<D108_80@2:aP40R/8108W2002>`P00T[d108nm0@2=_`40R/0008W40@24
a@<0PlD308?50P22aPX0P</?07S87`1c`S80MLT]07?;;@0206k@:P0W06c@:01[dBH0K]0S07;@701c
dA/0LM4S07;B8@1bdQP0LMDG077D6`1deQH0N=@A07KF5P1bdad0L=@P073D7`1geQH0O=DE07[D4`1g
e1<0NmDD07OI5@1feA80MM@C07SF4@1ifa40N=XC07?K6@1_fb80L]XR07?I7@1kf1/0OmLL08?G6026
fAX0R=PB08OG3P27d`d0R]<A0080Q]8G02L0QM@L08OH8029f2<0QM@T08CE8`23eB40PM@V087D:@21
e2D0PM4Q08G=8P2:baD0S<dD08_:4028a140Ql<A08Nn3`27^`h0R;L=08Rd3`25^AD0P;/T07fm=@1j
]TP0M:]J07ZQFP1nWU/0RiaF09>HD@2?V4l0RZ@`07nJ4@22T0@0PY40086>0021RP00OWl007Mb001a
LP000P1aK`009`1cK000L6/006m_001^KP00LV/007=Z001dK@00L6P0075S001aIP00M6X006i[001[
J000JFh006][001`L000LFd006e[001[HP00HU/005eD001MEP00GE/005QA001@BP00ACl003H_000V
7`0050T000L000060@003PH001`C000[9@00<Rh003<a000c<`00<Rh0034U0002034X000:02h[000`
:000:RH002PO000T70007A@001D@000A3@003`H000T400801@@000<00`80004100000000EP00000<
0?ooo`002P3oool03P1:C`00Be8004]@001;D000EEH104mL1`1=H`X0CGPA04ed2`1@K0@0E7<4051i
201@Q@T0DhP>0P1CQ@l0101FO0H0FWX305]g0P1IL`8205]d000P05eg001ON`00GH4005f30@1MP080
EGX205Al0P1BO@80DGl205R30@1IQ000FHT005V6001KPP00G8L006:7001TPP00HGd006Ii001TOP00
J8<006V70`1ZQ`40KH`206n=001`U`80LIL2076C101bV0@0LI/207BN0P1eW@4207JN000507NQ001g
V`00MYD007RD001eU@400P1eVP<0201cV@D0LYh5076K0P1bW040MYh207RR0`1iX`40NjH10P1mY`00
7@1nZ000PJ`107f^0`1n[@<0OZX3082X1022Z@40PZd0086_001n]@00Pk<008:a001o/@00P;@007ne
0@22/@80P[83086f0@23]000QKH108Ba0@28[000RZ`108f[0@28[`80R[4508Zd1P2;]0D0Rk<30080
S;8102L0SK8108Zd0@2=]000S[<008ng002=`0T0R;X908C02P22_Pd0QKd>08^m4@2=_A00S[lA08g0
3`2>`@l0RL<@08O34028a100Rl@<08W32`28a0X0Q/@908S12@29`@P0Ql8908K42@2:a0T0Q/<808C1
2025`PP0Q/<808O02027`0T0Pl080832201o`@P0QL0708W5102;a@@00P29a@<09`26aP<0RlL108[8
0@2=aP40T<@108c30@29a040RLD108W80@29b@D0RLX308c70P2:b080QlX208G:0P25bP<0QLX608K6
1P24aP40QlL108W90@27a`40QLD108O30@29`P00Rl4008o0002<`000R/8208c30`29a`L0R<P808G9
2024b0T0PL`=07W;701ebc00L/l`077>;`02073@9P0W06k@9P1/d2@0K=0R06kA8@1^dR40Km<U07;E
8@1cca/0L=<G07;E6@1heAH0NM<D07SE5@1aeQ/0K]PK06gG5P1cda@0N=@E07[E5P1gdaH0N=LD07CH
5@1deAL0K]<I07;F5@1cfQ<0M=/F073I7`1^fb<0L]TO07OJ701oeAP0Qm@J08SB6@2=ea/0RmDG08OE
4@28da00RM<B0080Qm<H02L0Q=<K08KD6`26e1P0P]@K087D7`21dR80Pm@T087H9022eRD0Om@T08?A
7P29cA@0RLXF08G95@1nbQ80O/PA08354@27`100Q[d>08Jk4025_Q@0PK`Z07Zm?01h]DP0MZaE07RT
FP1lXET0Sim@09RJB@28X4H0Q:HV086J2@24T@40PXd00869001oPP00NG/007Ab001aK0000P1`J`00
9`1aJ@00L6T006eY001^K000KV@007=W001eK@00L6`0071Z001^I000Kf8006iX001]J@00IfL006MT
001XH@00JF@006UU001XHP00HET005U>001JC@00FE@0055=001=B000ACd003@`000W70004@/000<1
00010000100000d7000M4`00:R<002hZ000^:`00:bD002PR000202LO000:02<M000R7`008AT001dH
000G4P004Ph000h600081@001P8000<100800P4000<00@40000000000000EP00000<0?ooo`002P3o
ool0501:D@00C50004aA001=CP00CEH104iK101<HPH0Bg4804a^101@J@<0DFd404mc1`1@OPL0DX47
05Eo201HO`L0F7L305Qb0`1JL0@0FVd20P1HL0409`1HLP00EWD005Em001?O@80CG`504Yj1P1:N0D0
CG`7055o1`1GP0@0FWd105eh001SN`00HWP006El001VP@00J8@006El001UN@00JX8106Z40@1_Q`@0
KH`3076E0P1aU000LID107FI0@1dUP<0LY/3076K0P1cW000LiT007VG001lU`00Ni<007^D001jU@00
MiT007FH000207FJ0@0W07FJ101dV0H0M9L4076L0P1eVP<0Nj0407ZP0@1lY000NZH007jU001oZ000
OJd207V_1P1h/0L0NJh507^[0`21[@40PZh008:b0@22]@40Pk8108F_0029Z`40QZd108B[0P25[@80
QZ/108B]0024[`00QJh008NY002=Z000S:@108f[0P28Z`<0QZ`208Vb0`27]@P0RK<80080Q[8501X0
S;D408Zc0P2:^000R[L108^f0@2:^@L0R;/808Nn2P22^PT0Q/0:08o0402B`0l0T<8?08g1402@`100
S/0>08c53@29a@/0R/D908K52@25a0T0PlD908S32@28a0P0P/H908?52080Ql<500/0Q/4608G52027
aPD0R<@408S12@25`0T0OL8707_21@23a@<0S/<209730P0208k20`0W08[40`29aP<0QlP308O80P2:
aP40R/D108K60@22aP40QlX108W:1@2;bP80S/H008W80025a`40PlX308G:1@23b0<0PlH308G50`28
b0D0QLX208C80P23a`<0QLT208W80@2:b040S/D308o61@2BaPX0U<H<09C82P2>b`/0R/d:08K>3025
d0`0PM0F07W@:01dd2T0L]</0080Lm0Y0140L/hW06o>8@1ZdB80J]0S06[B8@1]db80LM8S07O>8`1f
dQh0MmHJ07KE5P1heA@0M]PE07CF7P1ce1T0LMDD07KF4P0207OG500D07KH5P1df1<0LMTD06kG5P1_
eQT0L]TF07?L501afQD0LMTE077K601kfQL0P]TB08WG502=eaP0RmHL08gH6P2<eAP0S=@C08cE4P2=
da8208WC4`0W08KE4P25eQH0P=<F083?6@1nbB00Pm0P087C8P22eb80P=PX087D9`24cR<0R<TG08K6
5`20aAP0P<LF07c;601mbQX0PlHF08G03P24`140P<8H07k0;@1k_4@0M;U;07>dDP1f[U`0NJ=H08fK
E@2GVTd0PZE208>Z7`22V0H0PX`008:8001lPP00Nh<007Uj001bM000L6X00080JVL002L0KF<0071/
001bK000KVH006aT001_I`00L6H006mX001`J`00K6D006US001ZI@00JfH006MV001VH`00I5l006EO
001UH@00IV00065L001LE@00FDh0055;001<A@00Ad0003hg000b:0008QL000h900030@0000000040
00060P003`P001XB000P6P0081`001hH000L5@000P0I3`002P0F40005a4001D@000A2`003@L000H3
00030P000P4000400002001K000000`0oooo000:0?ooo`0D04MF001<DP00Cdl004e=001=C`00D5/1
04iQ0@1=J`80Bf/404YW1@1;K0L0CG<8059h1P1EO@80FGX105Yj0P1LM@40EW0105IZ0P1BJP82059_
000S04ma001?L`00C7P004]h0P1>N`@0BWX604mj201DOPX0F88:05^0101QNP40IGP006Ue001XK`00
J7D006Qj001WO`00Jh0006Un001ZP`40KhL206nC101[V@@0KIX2072J001]V000L9X107>H0@1cVP40
LIT0072J001aVP00Mi4007VB001eS@000P1hT`00:`1fU`00LiT007FM0P1eW@80LY`407>L101fU`80
N9P107^K0P1hV`80NJ8207NU001lZ000NjT007f/001g[040MK8407Nd101g[`80N:l107j`0021[P40
PK4207nb0`1o/@80Q;0008J]0P20[0D0O:X9086[1`23Z080QJT008NX0028Z@00Qj/008V[0@2;Z`<0
SZX308VZ0P27[@40Q[0108Nb1@25]0L00P27/0L04`2:/0D0S;4208jc0@2;]080RkH108fj1P2;]`T0
Rk`908Jk2@2:`0X0Sl0;096o2`2B_`/0T<0;08no302?_@X0S<0:08S22@29`@P00P24``P04P24aPP0
Q<D808G61022a@80Q<H108C50@24`P<0Ql8308[10@29a@40Rl4108_01@28`PD0P/8208730P28a@40
S/@108k10@80R/4102L0Rl8308S71@2:b0D0R/L208_70@2=aP40QLL008?90026b040R/L108k50@2B
`P00RlD008W80`2:aPH0R/P908O92P26bPT0Rl/808W;2P25b`T0Q<`9087>2022c@P0Qlh808k>2@2B
cPX0U<h;09K<302Ec0d0U</@097;4`2?bA<0SLX@08W>2`25cQ<0P=4L07W@8P1gdB/00P1fcRH09`1d
c2D0L<lR06cA8P1/dB40JM4P06WB701^dQd0Km4L07KD6`1cf1H0MMDB07KE4P1hea<0N=@H07?F5@1_
eQH0L]@E07CF5@1gf1D0KmXF06kG5P1/e1P0KmLE06oI5P1bfQ@0M]XB07KJ401jea00PmL?08[I3P2=
fA00RmHG08WF6P2;e1/0S]@L08kB8P2>dQT0SmDE08oB300208_B2P0W08WD3@28e1D0Om<B07g@5`1m
cB00Om8O08;D8023eb00P=LX07oC:`1mcBD0O//I07k85P1maAT0Nl<L07g67`1nbal0PLXL08?45@20
aa/0N/8X07Rn>`1h_D/0M;]=07>iC`1c[eP0MZAG08BLF@2AVE<0PJXl08:W6@21VP@0P8/007j5001l
Q000NXH007Z2001iOP00M7800080KVH000h0KFD0071[001`KP00K6`006i^001]K@00KVL006]O001Z
H000JV@006YP001WG`00J6@006QP0080IfH000d0I5l0065M001PG`00H5/005eI001ID@00DT`004a7
0014?@00>CH002`U000I4@002`H000<0000000L00P0000D2000:1@003`P0010:000=20002`D00080
2PD000H02@@000P4000810001P8000810001001O000000`0oooo000:0?ooo`0D04UC001:D000BU40
04YD001<E`00D60004iV001:J0@0Bg8;04I^201=KPH0DW0505Ic0`1IM@40GGP005]f001JL`00Dg01
059_0P1AL08204ma0@0W055e0@1>M`40Cg/204if0P1AN0<0Eg`405am1@1NOPL0IH0506Im0P1[N`00
KWT0071j001]M@00K7P006al001]P`00Jh@006^5001ZR@40KX/106jD0@1_W@40KIl106jM001^V@00
L9X0076E001bV000KiL006fE001cU@00M9<007FA001bT`00MIL007JC001eUP00LIX00080Ki`102L0
KYT106nK0@1cV`00M9/007RP0@1kX`40N:H107JX001hZ`00N:h007R/001gZ`00Nk4107Za0@1j[P40
NZ`007f/0@21[040Q:/207n/0P1oZP80PjX0086/0P1l[`D0Mk4907ZZ1`1oYP80PZP008>X0023YP00
RJ/008b`0P2<[@@0SZd308R]0@2<[P40Rj`008b/0@29/@800P2:[`809`29[@80SJ/108na0@2</`80
RkD108Zh0@2<]`D0S[/908g02P2?`0X0S[l:08jo202>`0T0S/0608k02P2<`0X0Rkl;08S02029`@P0
R<4908[02@2:a0T0Rl<908W51@28aP<0R/@208K70P22a@<0Ol8208;40@21aP00R<H208g40`2:``<0
RL@308O40`27a@<0R<H208K60@0208C50@0W08K71026b@L0R<X808S:1@25b@40RLT408[81`2:b@T0
RL/908W8202=b0T0TLL:09?82P2BbP/0T<X=09373@28b0d0RLX>08k;3@2?b`d0RlX?08W<302;c@/0
S<d;08o<2`2Bc@`0VLh;09[>302Gc@`0U</>09C:3P2Eba80SlPA08g8402:bPh0Q<hF083?701kd1d0
N=0R0080MlhQ02L0MLhR07C?801cd1l0Km4Q06oB701]daP0K]@F06cE5P1]eaL0K=LG077G501_eQ@0
LmHC07CE501be1H0K=DL06oE6P1_eQT0LmLK06kH8@1_eR00KMTO06gH7@1`faL0MMX@07gF3@20e`h0
R=P=08oG2`2CeP`0TMPA08gF5@2:eQ/0SM@O08gE8`2<e2D0T=<S097F702?e@d00P2?d@/09`2?dP/0
R]0<08?D3@1oe1@0P<hN07oE8P20eR@0P=HU083F:`1md2h0O<dX07k;601lb180O<<C07Jo7@1m`B<0
P<XN08?:7P22bAh0NlLZ07G5>P1e^dP0M;E@07:gE01a]e80M;=H07BTEP1nWEH0QiaC07j`<P25Z1D0
Q9@507j5001kP000O8<007b5001kQP00O80007Ue000206i/000M06eZ001_I`00KVX006mZ001`K`00
KVh006YX001[H@00Ied006UP001WI@00Iel006EK001QE`00I68006=S001RF`00GeP005eJ001LFP00
F58005E:001=AP00B4L00490000g<P00:20001D;00070`0010000000100100000P40008100030@02
0040008000000P01001S000000`0oooo000:0?ooo`0D04UC0018DP00Ae@004EE0018G000B6H004aV
0@19JPH0Ag@=04A^2@19J`@0DFl205Ib0@1JM`00FgL005Mh0@1FM`80DWD105El0`1DO08205=j0@0O
05B00@1EP080EGd305An0`1GO080GG`206Em0@1VO@80JWl106io001_PP00L8000762001_PP00K840
06f3001^Q@00KXX006Z<0@1US080Ihl206^C0@1]V`00KIP006jH001`U@00KIH006bH001^U`00L9@0
072@000206n@000606^B0@1]V@00LiX0076B001]S`00KI@00P1YUP009`1/U`00KIH006jK001bX000
M:H007:V001fY`00M:H007JX001hY`00N:T007VY001j[040Nk0207Z`0@1kZ@40P:L107fY0`1oY040
OJH007nY0@20YP00Oj/007b]0P1m/0<0OJ`407jY0P20Z@40PJL108JW0@26ZP00QZX108Z^0P2>Z`<0
R:P208Z`0@2<[@00SJ/008bZ000208RZ000W08RV002>Z000TZ`108j`0@2</P40RKH108Vg0@2;^P40
S;d808_02P2:`0X0SL0:08c02@2:`0D0S<4708[02@28`PL0RLD408O31025``<0R<0308o11`2>`0P0
R/@808W42@29`@P0Ql4408C10`20`@80P<<108340@21a@80Q<H408_71@2:aPH0Q/P608O90`24b080
OlT40080P</602L0Pl`808?>2024c@P0P/h808C?2@26c@T0R//:08o:3P2<b`d0SlX<09C73@2GbPh0
VL/<09c:302Kb0d0TLX=08K94@26aa40R/DC08g34P2AaA<0T<L@0978402EbP`0UlT=09S9302Mb@/0
X<X<0:3;302Qb@d0VlT=09W<2`2Ic0`0T//<08_=3@21ca80N/lI07C>7P1bcB800P1acb809`1ccb40
LLdP07S>801ed1`0MM8I07CF4P1de180KmHA077F4P1_f1@0L]TD073H5P1`f1L0LMHF06oF601]eQ/0
KmPH077G601`f1d0L=TP07;G7`1dea/0NMPG07kK4024f@l0R=<:08[G2P2=eP/0SMH<08oG3P2=eQ<0
RmDK08gH7`2;eB80R=<S08[B8P2=dRD0Rm@R08gE4`0208oA2`0W08kA2@29d0/0R=0=08CB5020db40
P]@U08;F:P20eRh0PM<_07_B<`1idB`0N/dK07S85P1iaQD0M/DM07_69@1nbAh0PL/M07g=9@1k`S40
NJm407JZDP1fZUL0LZUJ072`F`1d/640Nj5L07ZLF`21W540O:lU07jP4@1mRP@0NH0007Ii001jM`00
N7l007R0001hN`00NGP00080MW@000l0M6d0075[001/IP00Kf/007=a001_K`00KVD006UP001XH@00
K6D006aW001VH`00I5`0065K001OF`000P1PFP00301OFP00GU/005YG001CC@00C4<004Y20014@000
?cP003@_000U6`0040L000H100H0000000<00040000000000000J000000<0?ooo`002P3oool0501;
BP00AdP004E80015DP00AE@004UR001=I040AVL504E_2015K0D0C6h204mc0@1DM`40EGX2055j0`1@
O0D0D7`305=m0`1FP@80EH@10P1IP`401@1KQ040F88105Ym0@1LO080GGX10080IW`00200J7l006b1
001[OP00K8@006f2001]P`00KX8006N2001YQ000JhT006b>001WS`40HY0206NC0@1XT@00K9<006nF
001`U@00LY<006fC001[VP00K9H006jD001_S`00Ki4006bA0@1/U080KiP2072F001/TP00JY4006fB
0080KYH002L0KiX006^H001^WP00Lj0007BU001cY@00N:D007FT001dZP40MZP107NW001hZ000MjP1
07J/0`1g[@@0O:X107VW0@1fY040N:4107jU001m[080O:X007b^001o[000OZd107f[0P1lZP@0OZ/3
08:/0025Y`00QZH107nZ0P1o[`<0P:`508>_1@23[`80Pjh108Z]002:Z@000P27Z@009`27[000R[40
08Va0027/P00R[H008^i002=^P00S;X008W02@26^`T0RL0908_12@2;``T0Q/8908;42@22a0D0Q<@2
08K50P26aP40Q<@008[20@2@`P<0SL<408W31`26``P0Q<@808?31P22a0<0P/<308?30P24a@80P/L2
08C51027aPD0R<P708G:1@22c0@0OLd707_@200207W@200W07_@201odPT0P/l908??2@29d@T0SLh:
08k>3@2=b1<0S/XA09774@2GaQ00WL@>09o72`2Pb0/0W<L<09?<2P25b`X0Q<X:08?92`26b@/0SlL;
08o93@2>a`l0T/H@09G83P2GbPd0VlL=0:753P2SaPl0XlL>09g73P2Jb@/0V<T:09S82`2Ab``0QldA
07g<701cbb<0K/TW0080KldT01P0LLhO07;A6`1gdAT0O=0D07_B4`1heAD0LmHD07?F4P1afA80L=LC
077I4`1]fAP0K=TF073F5@1afA@0L]DE07?G501cf140M=PC07;H4`1gePl0NmL=08KG3@2<f@`208oE
2`0=08[F2P28ePX0RMH>08SJ402;eQ<0R]@M08[F8P2:eB@0R=<S08[D9P2;db@0R=<Q08cD6002093B
3P0W097>2@2>c0H0SM4>08SA4@20dal0PM8V08?B:`22dB`0O]<_07_D;`1he2P0N=0M07O;6`1ic1h0
N//T07c::P1ncBD0O</S07_9:01j`SL0N:]807>`CP1`/UP0JjeJ06f/F`1fYf40OiIO07b@G@1nUU40
P:@G07bF101mQ`40N7l007Ij001hNP00MW`007=m001bLP00LG000080LW0001d0Lfh006m/001/I`00
JFh006ma001bL@00KVT006MQ001YHP00J6H006MQ001VH@00Heh0061H001OF`00GeX0065K001QG000
H5d005]G001BC`00CD8004Dl000l=`00=C0002hY000Q600030T00081001a000000`0oooo000:0?oo
o`0D04E50012@P00@D40049:0017B@00AT`004QM1@14G0@0A6T204E[0019L000BGL104]l0P1<O@D0
D7l704f01P1@P0<0EGl205Qo0@1IPP0205an000405eo001OO000GWL0061f0080HgH001<0J7h006Um
001ZP@00K7d006^00@1[O@00J84006N1001WP000JWl006V3001VR000H8/105j:0P1PSP40IXT006N?
0@1WU000Ji800080JY8000`0JI@006bE001bU@00Ki8006n@001_T@80Ki<406fF101/T@<0KYH106bE
001_UP0207:H000W06nM0@1_V`40LJ4307JO0`1fV@40Nih107^K001iX000MJ0107NU101iXP40N:@0
07FU0@1gZ@80MZX307NY0@1fYP00NJD007bS001nZ000O:`007^/001kZ`40O:X207fY0P20Y`80OZH2
082/0P24[@<0QJT1082W0P1j[0D0M[4807Fe2@1h]@L0M[4407je0P24/P00QJl00080Q[<002L0PkD0
08Jg0027/`00RKP008Zi0029_P00R[d008^j002:^0L0S;X608c02P29``X0R/D:08G62@20a0T0O/84
07o40@22aP40PlL108340@25a@80R/D308c60`28a@80P<@307_81@1jb@D0PlP308G41025a0D0QLD4
08C60P22a`40QlH308O72P24b@X0Q<`9083=2@20c@P00P1nc`T09`1nc`/0Q<h:08_=2P2<c@X0Slh:
09G<2P2Ib`/0UlX<09G:3P2Bb`h0SlT?09363`2?aPl0TLH?09;8302>bP/0S</:08[<2@2;c0P0Sld9
09C;2`2EbP/0UlL:09K92P2IbP`0UlP<09?72`2Ka`/0W/X=09_:3`2JaPl0ULL>09;83@2Ea0d0U/T?
09384P27baX0PLTN07k:7`0207S=700W07C>6@1ddA@0Mm8C07[A4`1kda<0MmHC07SE501eeaD0LmHD
077G5@1bfAD0K]TH06oK5`1`fAL0LmLF07KE4P1ef0l0M]L?07OG3P1fe`d0O]<<08KE2`2;e@`0RmP<
08cF3@2;e0/0R]@>08WE4@2;ea80RM/B08[H4P28f1P0Q]PP08SF8`2:eRL0RMHV08_G9@2:e2@0S=<I
0080T]4@02L0U<`=09?61@2@b`h0S<`@08G;8P1ocBP0P/h_08;B;`1oeBh0NMLb07WG:P1hdR00N<hQ
07[<8P1jbRH0NLdZ07_=:01lcbX0NLh/07G8=`1a^dL0K;i=06bkD@1]]5`0KJmR07NZI024U5l0Ni1J
07REBP1oWa@0P9400867001lO`00NgX007Mg001iN@00LgH0075[001bKP000P1`J`007@1`I`00JVX0
06]T001[K000Jfl006i/001YIP00JFD006QW001QG`00IUh006EO001PG`00Ge/005iH001NE`00GEH0
05UG001IF000EeH005=>001<@000?cT003@/000]9@009A/001XA000<20000P8007400000303oool0
00X0oooo01@0@D800410000m?P00@TD004=90015B000Ae`804EK1016G@40B6/004U_001:N000C7`2
04Z1201<QP`0BX<704io0P1DOP40Dg/005Ek0080FWX002L0GGP005ic001KKP00H6h0061_001PLP00
HW/0069j001QP040HWX1069i001SN@40Hg/006>0001TO@00Ig`006Z1001UP`00H8L005n40@1QQ@40
HhD006B5001YS000J8/006R=001TSP00KI4006n?001_TP00L94007:?001bT@80K98506RD1P1ZUPD0
KYT207:H001eU`000P1fU`009`1cWP00MId107>L1P1bV`H0MIH207ZH0`1kV040NId007NL0P1iXPL0
NZ@307ZR0P1gX@80N:@107:R0@1dY000MZ<007bR0@20X`40PZ4007bU001iY@40NZH407ZW1@1jZ@D0
O:D207^R001nZ@40O:D207n[0`1j[040Mj/407Nb201f/`P0M[@607^e0`20]040PK<008>e0002082e
000O07nh0022^@00Q[D008^f0028^@00Ql0008Rl0029^`00RK/208W00P26`P@0R<<508G41`25a0H0
Q<8608;10`21``40PLP207g80`1ib0@0P<P608;51P24a`D0PlL308781@1lb0D0N/T407k81022b0@0
Q<H407o70`0207o90@0608?80P26b`T0R<X:08K;2@28c@/0Q/d90P1nc@T09`1lc@/0P/d<08K;3@2<
b0d0S/X<09O;3@2LbP/0VL/;09K<302Bb`d0SLd>08S=3@24cPl0Q/d@08O<4@26c140Q/`?08[<3P2>
c0h0TLd>09;;302BbPd0TlP;09W92`2Oa``0W<H<09[9302Jc0/0V//;09_;2`2Ja`/0ULP:08o<2P2C
c@/0V/X=097<4@27ba<0Q<TF07k96@0207W?6@0W07g@601kdAH0N]0F07gC501kea<0NMHB07cF501l
eAL0N]DD07cE4P1hfQ40M]XF07[J501kfA@0NMTB07OG401ie@l0NmH?07cG301ne``0Q=D=08[E3@2;
e`d0R]P<08_F3@29f@d0QmH?08KH4`29fQ@0RM/D08WH5`29f1X0Q]LP08WH9@2<eBL0RmLV08WI9`2;
fB80S=HM0080Sm4F02L0UL`=09351P2?a@`0RLH?08S88@21cR/0O<db07kD<P20eRh0OMT[07_F:P1i
e2H0NM4R07g?8`1icBH0M/dY07G>;`1fdC40Lm0i06g:BP1/aUD0JlEE06k0DP1a^UX0L[QN07FaHP21
Ueh0N9Y@07RR=P20VA40OhT007b1001iN000N74007If001eM000KFh006m]001_K0000P1^IP00301_
IP00KF0006]S001ZJ000J6T006MX001ZIP00J6T006I[001SG`00Ge/005mN0080HE`000l0GU`005eF
001FD@00EU8005MB001EC`00CTT004@k000h;`00;bD0028L000J4P0040L000H200010000L@00000<
0?ooo`002P3oool0500k>@00?c`003lk0013A`00ADX004A>0017H0D0BUl204]O001>J000D6T004m^
001CM`<0Dg`505>11P1>O@<0DWP105Ad001?L`00DG000P1DL0009`1HKP00FW0005QW001EH000Ef<0
05UY001KM000Fg4005Ya001LMP80GVl105ac0@1OM000HW`0069n001QO000Ih8006F0001VPP00IGh0
069j001UP`00IhD006Z7001[Q`00KX/006^@001YRP00KH`006f?001cT000LHd007:>0@1^T@80K9D3
06bG0`1aV@40M9L007NG000207VF000W07RJ001hW@40Mi`207JL0P1gV040Mid307FN0@1fW`40MIh3
07JQ1`1jX`P0MjD507FV0P1bYP40L:0007JQ001jX000OJ<1082T0P1mX@80OYl107jS0P1lY@80NjP6
07ZW101oY@80Nj4107^R0P1oX080O:T107b[001m[0<0OJl307Vc0`1h/`<0P;8108:e0021]@00Q;L1
0080PKT002L0PkX108>i0P2;]P80S[D208Zi0026^P40Pk/107o00P23`080Q<4308K31@25``80QLD2
08C41@26a0P0QL0708?1101oaPD0O<T507[81@1lbPH0O<X808782@23b@L0P<P80837201kbPH0NLT5
07o80@22aP40P<L108;70026a`40RlP:09;:2P2AbP/0Sl/:097:2P2;b@/00P23b`X09`1ob`X0O//>
08;<3P22b100QLT@08c:4P2Bb180TLLA08k83P2<aPl0SLT?08W;4028ba00R//@08k:4029b`l0Rl/?
08o<3`2:b`d0R/d=08c<3@2=b`d0S<X;09392`2Ka@`0W<L>09G:3@2Ac0/0T<h:09?:2`2DaPd0ULT=
09G;2P2BbP/0UlP<09G93`2Ab@h0S/XB08G:5@0208G<6@0W08C>6023dAH0Om4F07kD4P1oeQ40P=H@
08?E4023e100PmD>08?D3P22ePl0PMP@08;G4P23f@l0PmP>08?F3027e@/0R=D;08WF3028f0d0R]L@
08_H3`2=e`l0SML=08[H3@29f0`0QmL?08SI5028fAH0R=XL08OK7@26eb00Q=LU08OJ9@27eR40R=TR
08GG8P29f1`0S=PN0080S]DL02D0Sm0>08_82P2<`@/0RlH=08O<5`1odbL0Nm@`07SC;P1je2T0OMLU
07OF:@1he2/0OM4[07[B:`1gd2X0L]<Y06kE;P1_dcH0K]1206c;DP1Zc640IlmO06c9F01b`5X0LKIK
07>`F`1fWEh0MjQ007RX7`1nTPd0O88007Il001hL@00M6`007=^001aL000KVT00080KFT00P1/I@00
701_I000K68006mZ001^J@00JVD006]V001XH@00J6P006QY001ZIP00Hf<0061K001QF000H64005iN
001KF@00EU4005A?001BCP00CT/004Y40011>000=Rl002hS000P6@004Pd000L20002001b000000`0
oooo000:0?ooo`0D03`e000m>@00@3d004=20015D@00AU<004]R0P1;I@40Bf0004eT001=H`00CFD2
059^1@1DLPH0DgP3051e0@1@L@00Cfd004aX001=I@02051U000N051T001@I@00DUh0051J001GGP00
Df@005E]001BJP00EFT005]`0P1KK040GW0105ma001MM000H7X005ei001SO000Hg/006F1001VN`00
IGh006R3001ZQP00KH@006j5001`RP00L8/006b:001^S`00Ki410P1bT0001`1bT@00LI@007>F0@1d
W@40MIX007NJ001hV0000P1iV`409`1hW040NiT007RL001dX@40LIl206nQ0`1]W`40L:83076O1`1a
X`X0MZD;07JT2@1iYP80N:<007NQ0@1iW@40O:0107jQ001mYP40O:<207fR0`1iX@@0OJ43086U0P1o
Y@80Q:<007fQ0@21W`40PZ8108:V0023[@00QJ`008:/0024/000Pk0008Jb0026]`00QkH008Ji0002
08:o000708>o1026_`H0Q[X808Bi1`26^@<0RKL108Ji0`020830100N08C20P22a@40Q<D308;71@24
aPT0P/D908C42P22``L0Q<D508?31024aP80PLP208780`1oa`@0PL@608C51@21a@H0N/H807W8101m
a`40PlL208O5102;a`D0S<P908c83@2Da`h0U<P?09C83P2Da`l0TLP;0P2:bPd09`28b0h0O/T?07c:
3P24bPd0QLX>08S:4@2>aa@0SL<C08_15029_Q<0R/0C08c14@2=`Q80S/8A09774P2CaA<0U/DB09K6
402Db180SlT?08_:3P2<b`d0SlX<08c:2`2FbP/0UlX<09C;302?c@`0T<l<09;=3@2AbP`0T/T<08k<
3`2;b0d0T/D=09K43`2Ea`l0TLX?08g;5P0208_=600A08g@5P27dAD0Pm<C07gG3`1of@l0PMT?08GG
4025e@h0QM<>08[D3`2=eQ00RMHA08[G4@28e@h0S=H=08WG3@29eP`00P2<e0`0502<e0h0S]@A08kE
4@2<ePl0R]L>08[I3@29f@l0S=PA08SG5@24eQT0Q=HR08GI7`22fAh0R=TS08OJ9@25fR80QMTP08?F
8P29eB00RmLR0P29eB009P29dPl0SLT;08c32029aP`0Q/`@07cC8`1gdc80M]<]07WE:P1jeRH0Nm<X
07gB;`1kdSD0N=4i07G@=@1aeBl0K]@a06gA>`1[c4L0K<]B06W;G@1Vd680J<QL06blFP1`/EX0LJmL
07:PF`1eYcH0NJ0F07b71`1iO000N7L007E`001bJ`00L740071[001^JP00JF@00`1ZHP006`1[IP00
Jf`006mb001^L@00KFd006aV001UG`00IV4006EP001XI000I64005mJ001OGP00H64005eK001IF@00
FEH005=A001@B`00B4@004@o000m>000=Rd002/Q000K4`003`L000<0001c000000`0oooo000:0?oo
o`0D03`i0011@@00A4X004M=001;F000BEH104YH0P1=HP40CEl004aP0019G000BE`304aV1`1>J@L0
CfH304mX001?IP00CVH004]S001;HP0204YR000E04UN001;F000CEH004eI001BGP00DF<0051P001E
H`00EV<005Y]0@1MKP00G6h005md001RN`00HG/006=j001VN000IWH006Il001[P000JX000080K8D0
0100KXX006n=001`SP00Jhh006R?001WT`40J90106bC0@1_U@00M9P007FK001fWP00N9l007BE001f
V000MYP10P1eV`<09`1dW@80M9d1076P0@1[YP<0JJD506NN101XW`<0Jil606fU201`YP/0LjH<07JR
2@1jX`40Nj4007fP0P1lW`<0OjD107ZV001lY@00Nj4107ZS0`1jXPD0O:0407^M0@21XP00QZ0108>Q
0020XP40QjL008J]0025[@00QZh008R_0027[P00Q[0008Nd0025]`00P[L008Fj000208Bk0@80Pl08
02D0Ol0807bo201o_PL0Q;X308:k101n`0H0Pl0608731@23a0D0Pl<608741P20a`T0P<H908;62026
a0H0PlH608K40`23a@40Q<H108?50027a`40RL8308G30`26a0D0OLD607W60P1oa@00Q/H808_62P2@
aP/0T<P;09782`2?b0d0SlH=08o83`2?aPh0SL@=0080SL@B00<0TL@B08_54029a@h00P2:bP/08P2:
b``0SlH=09763P2@aa00Sl4?08c23`2<`Q00SL@B08o14@2A`A40U<4D09S05@2G`AL0U/8G09;54`2;
a`l0R/X=08g;3P2<bPh0SlL@09?94@2Fba40UL/?09G;3P2Db@d0VLP=09S73@2Eb``0Tl`;09;92`2?
bPh0S/`=093<3`29cQ<208S?500U08[;6@27d1H0Q=@D07_H401ofPh0P]X=08;G3P24e0l0Q]P>08[G
3P2>d`h0SmD@08kE3`2;e@h0S=D>08SD3`2:eQ00R=D@08cD4@2;da00T=D?097E3P2?ePd0S=P<08_H
3@2:fA@0RmHH08WD6`27e1L0P=DJ08?G5P24f1H0Q]PE08CG6024eQ`0QMLR08GE9P0208OF:@80PmHT
02L0Q]8A08c=302=`@<0Qkl:08;<401idR80Lm@b07?D<@1beC00Mm@Z07KC;01jdbh0Mm4b07KA>P1b
e3/0L=Dk06oE>@1/e3`0Jlm:06gACP1ZcEH0I/aI06?6G01X_UP0K[=I06naFP1Y[e<0NJTV07RC201h
Q@40MgP007Ea001dL000LW4006i_001`K000KFd006YX001YH@000P1WH@006P1XH`00JFH006e^001^
K000JVT006IR001QG000HUd0065M001VI@00I5/005mM001QH000GUl005iM001IF`00F5L005A?001:
A`00A3l003dh000i<@00<BP002PK000I3`002@<0M000000<0?ooo`002P3oool05011@000AdL004Y=
001;D000BUL004MH0P16FP<0CEl104aN001=G@00BUT004MK0@1<HP<0CV8304eO0@1<G000C5/004QJ
001:H@00BV800P1<I0009`19G000BU<004UE001>F@00DV4004mS001CGP00Df0005=R001MK@00GFl0
05m`001SMP00HW/006>0001VO`00J7d006f0001[PP00KXL006f6001/RP00J8T006R:001[T@00JY@0
06VD001UTP00Hi@0062E0@1SUP00Ji`107:Q001dW`00Lil0076O001^VP00MI@007FB000207JF0@0W
072E0@1ZUP40Jil106^R0`1YY0H0KIh506jM1@1]WPH0L:0507:S2@1eY`T0NJ<507RR0@1eX080O:43
07jO0P20XP40Pih0086K001nVP00Ni`107VM0P1nW@80OYX007nO0025X@00QJH508>V0@24Z`00QZh0
08>a0@26/P80R;8208Rb0@26/P80Q;L107nh0@1m^P40OkX00080P[h301X0P[d708Bm2020`0P0OL08
08301`21`0H0P<0607c01@1m`@P0Pl8:08S01`27`0H0Pl@808C11P23`P@0P/<208O40`24``@0P/L3
08760@26``40R<<008[50028a@80Ql@308S40`80Q/@100/0Q/D008W72P28aP/0R<D=08o43P2Ba@d0
TLT<0938302<c0`0QL/=08W92`0208W83P0W08c43`29`a00R/D@08c83P2=b``0S/X=09;43P2Ha100
WL8@09[33`2A``l0T<H>09763`2A`a00U/0A09W23`2Ka0l0Ul<E09G1502Fa1@0T<LD08c;4@2=cA40
S//A093:4`2DbAD0VLPC09_;4@2Fb`l0T/T>09O83P2Ka@l0U/T<09;93`2@b@d0R<h<08W>3@2AcA40
T</@0080Rl/C02L0RL`G08KC5P23eQ<0O]TA08?H4020e`l0O=P>08;H3P25f@d0RML>08_E402<da00
S]8=08gC3@2>e0h0R]D=08GG2`21ePl0P]<>08GD3`2<d`l0Sm<=08gF302:f@d0R=P@08WE5P29daX0
R]@I08CC5P1oeQP0P=DE08?D4P21e180PMDF08CD7@20eB00O]@W087G;@24eBd00P24dbT09`24e1H0
S/T<092l0`26`0L0PLX@07[D7P1ceRl0Lm<b07?E=P1edS80M<hh07?==`1acCP0Km5006kE@P1[eT@0
JmE306gABP1[ceH0JM1D06_>EP1WcED0HlAF06BlE01Z/UP0Jk5C06Vi@P1hZa`0MH`307>0001`LP00
L6`0071W001/L000K6X006iX001/J000K6H006QT000206MU000J06QT001WI000JVL006U/001TH`00
He`006=K001QH000H64006AT001PG000HEl0065P001MGP00F5h005IK001CE@00CDl004Q50010>P00
>3P0038/000Y8@007aD0010:00050@1d000000`0oooo000:0?ooo`80AT<00180BT`004]>001;D000
BEd104IO0@1;H@40CF@004eR001<G`00BE`004iM001?GP00CUd004YK001;FP00AeX004QT0018IP02
04iT000W04]O0018E`00AeX004]M001>H`00DFH0059W001EI`00Ef/005]_001QM`00HWH006=o001P
PP00I8L006F5001ZP`00KHH006b7001]S`00Ji4006N>001RU000HY<006JG001ZU`00JIH006NG001N
VP00Fil005ZS0@1QY@80IjD206fP001^V`00KYX006RG001[U000L8l00080Khd002L0KY@006jC001^
V`40LId107:P0P1eW@80MJ8207FN0P1gWP80MIh107RP0@1eW@40MYh307>O0`1iW`<0OIP108:J0@23
VP00P9L007jI0@1iW`80Nj4007fR001iX`00OjH0086X0025[PX0PJ`108:a0020[P00O[D6082f1`22
]`L0P[D6086f0`1o]`@0NKL607^k0`20]`000P24^@409`22^P@0PKX4086k101o_`<0P[l408;00`20
`0D0O<0307o11025`0@0RKh708K12020`@L0P/0508G10P27`P40QL@108K40P21aP40Pl<108720P25
a@@0QlP208K60@23aP80Q<H108c5002;aP00S<@008W92P22bP`0O/P>08O5402=`Pd0S<P=08W:2`26
b`X0P/X:08O82P0208?62@0B08O62P2?```0U/H=09C:302Bb``0ULP=09C73P2H`Pd0ULD<09?33@2B
a0l0T/4@09G04P2?`a80SlHA09783`2Eb0d0V/@>0P2K`1@04`2H`1D0TLHG08k95P2=ba@0S//C09?5
4`2EaQ@0Ul@E09K83`2Fb@h0ULX=09K7402HaQ40TlP?09383`27b`h0R<`C08k:6`2CaA/00P2AaQd0
4P2:c1T0RM<F08GH5021e`l0PmT>07oH301hf0d0OMX=08;J3`22ea00PmDC08GC4026e0l0R=D@08[G
3`2:f0d0PmH:07kG2P80Q=H:01<0R]<;08gF2`2;f@`0R=T;08SF3@28dQ40RM8D08WD5@26eAD0OmHI
07oD601oeAD0Q=@C087D6P21db00PMDN08CF901oeR`0P]L[0080PM@X02L0Q=@H08g53@2@^P<0R/06
08K83P1meA/0MmH^07KD=01ddcH0MLLj07C0?P1baDD0LLM:073>BP1/dT/0JmA=06cCD`1Xce`0I/YL
06K=G01Wc5X0J<ID06BlD`1V]UH0JJiH06^[CP1_/CH0O:8E07J80P1eM`00L6/006aU001ZH`00Jfh0
06UV001YI000J6T006UU001XI@000P1WHP006P1YH@00IUl006QS001WH`00IV8006EL001SHP00Hf00
06ET001RI@00Ge`0061K001IE`00EeT005MJ001DE`00DED004e<0012@P00>SX003<_000Y8@007aH0
01D?000;1P000@00M000000<0?ooo`002P3oool05019B000BDT004a@001=E@00BET004eS0019H`00
BfT004]Z001<I000Bf<004]Q001>H000DF<0059U001<HP00BV8004UW001:I`00BfD00P1;I0009`1=
H@00C60004aT001=I@00DVH005E/001HL000FW8005ma001PMP00HX0006J1001TQ@00HHP00666001U
R@00Ih<006R5001UR040HXX106>B0@1QTP40GI<0066D001UV000IYH006RF001VV@00II`105nP0@1L
X`00G:H106:S0P1YV000K9@006VD001WU@00J9@006fA000206j;000W06n@0@1`SP00M9<007FB001f
V@40NId007ZN001kW`00NJ4107NL0P1hV@80MiL207RG0`1fW`80MY`107fJ001oV000PYl007fO0@1i
X@@0MZX507V/0P1h[P40NZd207b]0@1m[`00OK@607fd0@1j]000N[0007Ze201n]PL0O;P607fe1@1m
]0@0N[<607>f2P1b]PD0N[P00080OkL002L0PKP1086i0@22^@40PK`208:k1023^P40Q;P108:i0@20
^`40Q;`108>o1@1o`0T0P<4608311@25``@0R<H308O20`26``40Q<D108340P21a@D0PLD:08751022
aP40P<H208?50P28a@<0RLD208O50@27a`d0Pl/<07k;2`24b@X0R<T:08W83029bP`0R<L<08G92@20
b`T00P1lb`P09`20bPT0RLL:09K73P2Gb0d0ULT<09O82`2Fb@/0SlT;08g8302>a100T/8B09S0502M
`100Ul4=08c83@25bPl0S/L=09C43P2F`Q<0VL4C09;33`2Ca1D0T/HE08c64P2;aa80S/@B0973502H
aAL0Tl@G08o55P2>aa80SlPD08c:5P28b1@0R/HG08?76026c1T0R</K08[;7`0208[<7`0W08_?7P28
dQT0Pm@F08?D4`26eQ80Q]L?08CG3`1ofQ00P=L@07kD3`1oeQ00P]DA08GE4@26eQ00RmH@08OF3@27
eP`0PmP;08_H2`2:f`X0S=T:08oF302@e`h0RmD<08_A2`29d0`0S=8?08SC4@27dPl0PMHC08GD5`22
dQd0Om0M07oC7@20eB80PmDR08CE8P20eb80PMHU0080Q]PY02L0Q]<F08c83`2A_0<0Skd408c53P23
daX0Mm@]07[>=P1gbD40MKa407BcC`1a]ED0KKYD06c2E01Zb500J<YC06K:F`1Q`fD0HL5W063:H01S
bE`0IL5H06>jG01S/e`0J[5B07:_@@1fZQh0P9`?07N30P1dL`00LFX006QS001ZI000KF`006iY001Y
I`00JVH006MT001WHP000P1WH@006@1TH`00If<006MW001WIP00If<006MU001UI000Hf4006AR001Q
H000Ged005UG001CD@00EU80059?001?C000BDP004I40010?@00>C@002hT000M5P004``000/50005
0@00M@00000<0?ooo`002P3oool05014C`00ADl004MJ001<H000BV@004]_001:J`40BfX204a/0`1:
J@<0CVH204eU0@1?IP00D6T004e[001<J000B6/004Q_001:KP00BF/00P1;I`409`1=I`40C6<004aX
001<K@00CV/005Aa001HM@00Fg8005ie001PN@00H88105j3001NQ000GHP005b6001NRP00GhD005j6
001HRP80Dhh405FD101ES`<0Fi02062=001ST000J8h006B;001VRP00Ihd106NE0@1TU`40GiH006J?
001YQ@00JhH006b<001US`00J8`006b8000206^5000W06f?0@1aTP00MID007F@001gV@80MI`107BL
001iV@00NY/207ZM1P1gWPP0NYh:07VK201kWP@0N:<207JS001jX@00PZL007VY0@1i[0D0N;4707N`
0`1g[`<0N[@807b`101k]000O;@007^e001h/`00O;4007f^0@1l/080O[8207^^0P1n/0@0N[0407Ra
1@1j/`80O[H00080PkD002L0Pk@0082f0023]P00Q;L108>j0P24^`80QkP108Ji0@22^040PkP108Bk
0P21`0D0OlD308?10`25`@@0R<4608G01@25a040P<P207o81021aPT0P<H;08;22@20aPD0O/L50875
1@24a@D0Q/@308C40`24aP<0QLL;08K92P25b`/0RL/;09393@2Cb@h0TLP<08S82P22bPT00P1ib`T0
9`1nb@X0QlT=08k;3@2>c0/0Rlh908[=2@26c0T0PlX;08?:3`28a`h0SL@=09333P2<a``0TlL;09?5
302<aA<0SL<D08o63@2Aa`d0Tl<>09763`2BaPl0U/4?08k5502CaQ@0UlDD09W24`2O`aH0V<4H09K6
602Db1T0SLhI08K@5`26bQH0R<PI08O86P26bA/0PL/K083<6`0208?=700W08GC7@25e1L0Q=HF08CF
4`24e180Q]@@08KE4023e@d0OmH<07oE2`20e@d0P=@=08SF3`2:ePl0S]D=08[F3029e``0Q]P?08_J
3`29f0l0RmD@08oD4@2AeA<0Sm@A08gC4027d`l0R]<=08[D3`28dA40Q=<B08SC5027d1L0PM8I07kB
7@20e2H0P=@Y07gE:021daT0QM<L0080Qm<S02L0R/lD0936302C^P40TkX208o33@26dAD0N]@/07W:
>`1gaTH0MkM:07:[E`1aXUT0L:QG06fdD`1`^UH0KK]H06^gFP1W]V<0H;AW05noGP1S`UP0I;iJ062h
G@1V/U`0KkE607B]:01gV`l0N8/4079n001^LP00Kf/006UT001XJ000JVL006QY001_J000JfP006IS
001VHP000P1UHP00601VI000JVP006aZ001VJ@00J6P006EW001QHP00Hf0005iN001NFP00G5`005MD
001DCP00DD`004]8001:A@00@Cd003li000l=P00<b/002HK000D2`002@@000<007H00000303oool0
00X0oooo01@0@e<004AE0016E@00B6D004AV0015KP00AV`304EZ1@19J`H0BfT604]Y101<J`40Bf/0
04U^0018K@00BG4004Y`001;M@00BW4004Y/0@80B6@200D0Bf0204mS0@1=I`00CfX0051V000205Q[
000P05U[001LM@00FWH005Z10P1LOP00F7`005R1001EP`00EXH105F1001BOP40CHX404V<1P1;S0H0
ChP605N80`1MQ`40H8@00622001QOP00HWd006=j001SPP00GhH005f3001TO@00JGP006]l001[Q`00
IhT006N3001ZPP0206R1000C06f<001cTP00MY4007VA0@1eV@40M9h207BK001gW040O9L307ZL201h
XPX0LZL;07>V2`1fY0X0N:<307JV001iZ000NjT007Z[0@0207R^0P0607V]0@1hZ`80N:h707^[101k
[@40OJd00P1n[P002P1k[000O:/107b[001jZ@00O:d507b/2@1jZ`H0OJd1082/0021[`02082_000W
086a0020/P00PK8008B`0024_@80Q;`508Ji1027]P40QKD1086i0020^`40P;X208>o0P25`@<0QL48
08?12`22a0X0P<H707c8101ma`@0OlH907k62@1mb0T0OLD807[62@1kb0H0OlH408730`24a0@0Q<@8
08;62P1ma`T0Q<P:08_93@2Ea@h0U<H<08c72P25bPX0P</90080Nl/<02L0P<X?08O93P2>b0`0S//9
08C92@23c0T0O/d=083:3@23bPl0Q/X=08W8302;b0`0Pl`=08[93@2Fa140T/<G09?24P2Ba@d0T/H<
09772`2>bQ80SLHE08k2502A`a80T/<@09;2402I`a40Vl0C09nm5P2J`AP0UlDM09365`2;aA40RlD>
09745`2@aAd0QlXM07g>6@1jcaH00P1odQL09`23eAX0QMLE08CD4`25e1<0Q]@G08?C6023e0l0P=H<
083E2P21eP/0Pm@<08GE3`25e@h0R]L=08cF302<e`d0SMD@08WE5@2:eA@0RM8E08g>502>caD0SM<F
08gB6@28d1h0QM@F08OF4@27eA40Q]4D087A5@26dQD0Q=<E08;D5020da@0PM8K07oA8`1ndb@0O]8K
08?C5P0208WC700W08[@402Ba0`0Tk`109:j002A_P<0R//?083@8`1lcC<0NlTo07Nj@`1c[D/0MZiE
07F^EP1d/U00Lk9=07>/D`1_[E<0JZeN06:[H`1Q]5h0H[UF06BbE`1U/eD0KKQ507N^9`1iVA<0N8T4
07F2001aM000J70006QZ001WJ000J6L006IP001RH@00JF@006]V001XH@00IV400080IV8000P0If80
06QT001YIP00IVH006EV001SH000GEh005]P0080FeT000h0Fed005IH001DC`00CdL004]30013?@00
>S00038/000a9`00:24001hB000=1@000`40004007H00000303oool000X0oooo0100@50004=A0015
E@00AV4004ES0013H`00AV@204IQ101:I0@0B6T504Y[0`1<K040B6X004I/0016K@00B6h00P1:K000
:`1;K000B6D104EL0@15G040BEP104mI001=F`00D5d0055I001?FP00Deh0051O001CIP00EF/005Ea
001CLP00DW40059g001AN000DGX1055e001;LP40BG`204Qn101;P@<0DGd305=o0P1EP`40FH4205^3
0@1IN@00FGH005e_001LM000GGh1065m001YO`00Jg/106f20@1/RP40JHl006R:001YQ0400P1_R040
5`1^S000M90007F>001eU@40MiD207BK0P1eW@40MYl307^K0P1iW`<0N:8407FW2P1`YPX0M:@907ZO
0`1jXP40MZD007RY001i[000NZ`007VW001kY@40N:<00080NJL300h0OZH107jU0@1mZ0<0OJL207^U
0@1lY@40NjP007J/001j[0D0N:X807ZX101hZP00NJP007f[0080Nj`002L0P:l207bc0`1n/`40Ok40
08:i0P22^0@0PkT608:h1021]@80PKT107fk0@1j_@40Ol04082n1@20`@X0P/8;07k42`1ja0T0OLL5
07g50@1laP<0NlP708752P21a0T0OlP907g81P1oaPH0P/8508G10P23``X0P<D:07W62@22a@h0RlD?
09;2302B``X0R<P907o:2P1nc0X00P1ob`d09`26b@l0SlD>09;42`2=`PX0QlL<08K<4@22ba80RLD?
08k63P2<a`h0R/H;08S:3@2:c100SlPB09S0502H`AD0VL4A0:323@2Ka@/0TlL<08g45@2Aa1D0T/<C
09C43@2@aP`0T<@F0973502H`140VkhA09[1502E`aH0T/4E0973502B`QT0TL<N08o58P27bQl0Ol`J
07cA500208;F500W08GF6@26eA40P]@B08;E4`24eA<0QM<D083C401me0`0O=D;08GE3028f0h0R]H@
08SB5029eA40RmL>08_F302:e0`0RM8>08cC4@2;d1D0R/`K08S>7@28dad0RM<O08SD7023eAD0Q=DD
08WD5025da<0P=<C087B4@22e100Pm4A08CA4024dA40P=4C07g@5P1jdQL0OM<I0080QM4G02L0S</?
09701@2B]`00T;D009>i002?aPX0QldA07g@9`1icC00M/Hj0771@01a`4/0M;];07FnB@1f^dD0LKI5
072cC01^/Dd0IJiC06^_E@1U/e80I:i:06Zf>@1d/Ah0NYT>07N00`1eNP40L7H006e`001YJ`00Hf<0
06IV001TH@00He`005mK001QFP00IV0006MR001WH0000P1UG`005P1VGP00Hf00065M001RH@00If<0
05iQ001MH000Gf0005UJ001EF000F5T005=I001CDP00C4X004940010>000<bh002hV000U70007QH0
01@=00050P1h000000`0oooo000:0?ooo`0D03m:0011C`00@580049K0016G000AUX004IL0@17E`40
A5H104ES0P16HP40AF<004AP0015I000@f<004=R0015G000Aed004QI0016E@0204A<000W04A90019
C@00BU4004]D001?EP00CEL004eH001;E`00BUT004YM001:IP00Bf/004i/001AM000D7<004mZ001<
K`00BG0004Uh0@1<N000CGD105Eh0@1FNP40EH8205B2101GPP<0EGh005Ik001LN000GGL006B2001W
Q000JXd106N<0`1YT@@0JIH206ZC0@1]TP00K9010080L8`102L0Kh/006n<001/R@00K8l3076A0`1d
U`<0MIT407FL101dW`80NId007JJ001bW@80LYl507BK0`1gVP80MIL007VJ001iWP00NJD007^S0@1m
YP40NJ@107NT001dX`00N:8107^R001jY`80LZ/607>Y1@1cZ080NZ@007VT0@1eX`00MZL207ZS0P1j
Y040O:D007bX001lX0000P1hY`009`1j/0D0N;<907Ve101e^@40O;`107jn101j^`L0Mk/907^k1@1j
^0<0O;/307_01@1l_0<0P;d20831101o`@P0O/<907O31`1ja`@0NLL207_7001kb@@0O/H707o71P20
b0D0OlP907k72P21b@H0O/D307k82@20a``0OLX<08763022bPX0Q/H;08O32P28a@T0R<P;08K93@02
08K73@0W08S63P2=``h0Ql<<08O2302=a`d0RLH?08O24P2B`aH0Ul<@09?43028bPl0Ql`@08g8402D
aQL0Ul4I0973502F``h0Xl4=09W03P2BaA40U<4A09C1402CaPd0S/H<08o53`2=`1H0T/0E09W04P2K
`@h0V/8?09Vm4@2C_AH0U[dJ09G07`2@`2@0S<<U08;88P1oc1T0Om<C0080QmDC02L0R=<G087C5@1m
da<0Nm@D083D4`24dQ@0P=DA07[E401le@h0Q]@>08SG3P29eQ00Rm@C08[D402;d`l0RM8=08gD302<
d``0T=4@08k?5P2=cQ`0R=4L08GD6`28e1T0RM@H08SC5P26da<0Q]4E087A401odPh0Om8=087B3024
d0`0Qm8=08?>3P23c0l0Om4A07cA501ld1H00P21d1P09`2<`Pl0TKP108nb002>/@00T[@009>k0@2:
aP`0PM4B07g?601fbQl0LldW077<:P1fbS00NlTa07k6<P1jabh0N/8]07bo:@1o^b<0NKTV07Jc9@1e
[R@0M:<D07BI2P1cR0<0L7T0079`001^J`00JfT006QW001RG`00HV00069L001TFP00H5/005iI001R
G000IF4006MP0002065L000F069I001OFP00GUT0065O001QH`00GfL005mY001OI@00F5/005=E001B
E`00DU@0059A001;B@00AC/003T_000^90009Q/001TC000D3`0030L000<007P00000303oool000X0
oooo00@0>d8003i8000nB@00@Dh00P10CP003P0oD@00@dh1041C0@0oG@40@E`004=G000oF000@UH0
04AE0013DP00?T/0045;0010BP00@TL00P10A0009`0n@P00A4D004=80016D000C5L004UF0018F@00
A5L004=H0016FP00AfD004YW001=J@00D6/0059^001?JP00Cg4004me001>O@40E7X005Ef0@1JN`80
Egd405F50`1GPP<0FWh105n1001NP@00HHD006B4001YR000JXh106^B0P1YU@80Ii@306RF0@1/T`00
JY4006j?0@02072=0@0W06j9001]SP00KXd007:B0@1bT`40M9<107JJ201dV`@0MYH207ND001fV000
MID007FL0P1eUP40MiH107bD0@1kU@00NIP007VQ001gX000NZ<107RW0@1eY`00M:@107>V0P1fX@40
NZP307FX101bZ`<0LZT207NV0@1fYP80MJ<107RS001iX`00O:P007jY001mY@00NZ000080NjL002L0
NJd207Rb101e/P80MKP107Fl101f`0P0Ll09076m2@1c_@H0MKd407Fm1`1j_PX0O[d7082m0@1o`@00
N/<007K70P1ga`H0O<P507g80P1lb@80M//307K:101ka`<0P<L408362P1ma`X0NLT707S;0P1mb@/0
NlH>08;83`1nb@X0NlL807_62026aPT0S/H=08g1402B_Q800P2E`0l09`2A```0RL@<07o83@21b0`0
S/8>08_24`2;_Q40Rl4A09?0402K`@d0S<XA08W:3`2=`Q00T<8C09?04`2;`a<0S<@>09G33`2C_Q<0
SL0E09G23P2O`@`0Vl<<09;54@2C`aH0W[TE09Zl5@2I_100V;l?09No5@2M]Q/0V;HS09>h902=_RX0
SKdY08bm;@24`RT0P/`P087A5`0208CC500W08KB5025dAH0Pm0F08GA6025e1D0R=HD08CF5@22e1L0
Q=<A08KE3`28ePh0RmP?08WF4P2;da40RM4@08SB4@2<dQ00S]<>08o@4P2?caD0SldC08gB4@29dPl0
R=8@08WD3`29d`l0R=0?08CA3P25c@h0P<l>087?3@21cP`0Plh=08G?3@25c@d0QL/>08C>3P1od0h0
O/hA0080PLXC01/0R[/>08nd002>/000S:h008^]002:/000R[P308K02P1o_@h0OKTA07fk4@1k_A00
PkdC08Bi4P26]a40QK@A08:/3`24Y0`0Oih707bI1`1hT@P0MHl807J<1@1cR`40L88006id001ZJ@00
0P1WI000201XJ@00IV8005mI001PF`00HV0006IO001SH000H6000P1TH00206IS000;06AP001SG`00
H5l0065N001NG`00HF@0061Y001LG`00DeL0051C001=C@000P1:C0002016@P00?C<002lX000S7@00
7180014:000;20001`@0N@00000<0?ooo`002P3oool0400g?@00>Sl003U0000j@@00>TD003Q80@0g
C@40>D`303Q?1@0kE0<0?54103e=0010C000@4T004=<000oAP0203i2000[03]3000lA000?DP003e8
000mA@00?dP004==0014E@00AUX004IH0019H000AEd004MP001;J@00Bf/004e/001@K000DF/005I[
001CJ@00EG8005Ah001EN000F7d005Qi0@1KPPL0FhD905^9101LQ080HWh106Ao0@1TP`00HhX006R;
001]TP80K8l406Z>0`1ZR`40JhL006b7001]Q`00JXT006f9000206n;000W06f6001[RP00K94006^D
0@1/U`40KIH1076L2@1dUPD0MI8207>9001eS@00MI0007BH0`1cU@80M9D207RG0P1gU`40MI/0072Q
001`X000MZ0007JR001fY@00Lj4207:V1P1aX`H0M:D5076T0`1bZ@80L:P006nZ0`1^YPD0KZD2072R
001hX000MjL007NY001lY`00N:H00080MjT002L0Mj/007Ba001d/P40M[L307Ji201e_PT0L/0907>n
2@1f`0D0Mkd607O02P1l_PX0P<040870001i``00ML@107C60@1kb0@0OLT308;60@21a@40OLP207_7
101ma`H0P<H607o6201na0T0N/H407W:0P21b@d0Q/L>08S73@22a``0O<L:07O82P1oaPd0T/@>09Bl
4@2B_1400P2=_Ph09`2<`@`0R<H:08G72P29a@d0S<0D08^o5@27`A80QL8>08no3@2J`0h0S<T@08W7
4@2F_a40U<4@08o03@23b0l0QL@A08o05@2B_1@0SkhA08jn3`2B^a00V;hA09?16`2D_1/0Z;@F09fg
4@2D^@h0UkPB09^i5`2[/R80X[D[09Fe<P2<_2h0R[`^08S0<025bBP0Q<dT08;@800208CA7@0W08CB
6@26dAT0Q]0J08?@6P29dAL0R]@C08OC5`26eAT0Qm8D08SD402:ePh0R=P>08[E3P26e@d0RM@?08[B
4P28dQ<0R=<D08cA4P2<dQ00Sm8>08cE3@28dPd0R=8>08GB3`23d0l0Q=0>083>3P22cPh0P/lA08?<
3P22b`d0Pl`>08?;3@23c@l0PlX?08?=3P23c0h0P/X>0080Q<<?02L0RkH808^`0028ZP00Qj`008VZ
002;Y@00QjX008Jb0@23/P40QZ/108JW0P22YP40PZ<308BO0`26W@80PI/107fC0@1lR`00NHP007N3
001jQ000MX@007N4001dQP00KH8006ei001VIP00Hel0069M001VI@00HV40061K001QG@00Hf4006EV
001WJ@00Hf@006AO001VG`000P1RI@005@1UIP00HVD0069O001JG@00FEX005eO001NH000EeT005=A
001<BP00ADX004A40011?P00>SH0034/000X80006aH0010;00070`0010800081001i000000`0oooo
000:0?ooo`0D03<d000e>000=3L003<j000e@`00<dT1039=0@0dC@<0=4`403e?0P0nBP40@DP00497
0011C000@Th004=<0010A`00@4X003e>000kC00203e@000W03m@0010D`00AEL004UK001:GP00BF80
04]R001<J000CF/004ma001>M@00DG8005=c001ALP00F6l005Q^001EKP00EW8005I^001IM000GGD1
05f1101NQ0D0GH0206230P1QP080Hgl206En001WQ`00JX/006R<0P1XRPD0IhD306Z30@1XO000IgT0
06Mf001ZPP00Jh<00080JHD001@0KHT006f=001_T`00JY<106RF0P1[T@<0Ki86076B1@1_T@<0KXl4
06n?0`1bS080LY8106n>0@1cU@80LIL207>J0@1_V`00Kj00076K0080MIT00140M9/007BH0P1cW`@0
LIl507:P201_X`D0LJD1076U001`Z0<0KZD806nU101bX`00Mih007FO001dYP00L:L006n[0002076]
000W07F_001d]000MkD107Ri0`1g]P@0L[P807:l1P1e_PD0N<<407G31`1ia0X0N/8907o20P1k`@40
N<0107C30@1ea@80MlL307k30`22`@40QL4108?20P20bPP0O//;08392`22b@X0PLH608350`1oa`80
P<P308c33`29a0d0Q<H>0876301naPh0Q/<@09>n4@2G^a<0RK/>0080P/0>02L0PL@=08C62P2>a``0
Sl0>09706@2C`Q<0T/0>09:n2P2?`P/0Sl@A09K14P2K^Q@0Vk/D08jo3`21a0d0PLH?08C44P2:^A/0
UKDF09Jf3`2@^Q40U[XG09nk902C`2@0T[DL0:R_5@2J]A80T;PJ09Vc5P2S[Q/0XZhR0:2e:@2J]bl0
TkL]08fm;028bB`0QlXX08G=8`26dB800P26dAl03024e200Q]8O08KB7`25d200Q]0L08KA6@22dQX0
Q]@I08GB6027e180R]@>08[E3@80RmD<01T0Rm8=08k@402=ca80Q]8B08WB3`2:d`h0Rm@>08SD3`26
dQ<0Qm4?08G>3`21cPl0O/d>07g@3P21d@l0PM4@083>3@1ocP`0OlX@07o=3`1nb`l0P<X?08?:3`20
cPh0OlL;0080RKh602L0SZ`208bW0027Y000QZL008ZR002;X@00RJ8008JV0P23Y`80QJ@108>V0022
Y000P9`007jC0024U@00Oi8007f<001kQ@00Mh<007Io001fOP00Lg/007Ai001cO000L88006el001Z
K`00HV80065I001QGP00HU`005mO001RI000Hf8006AU001WK000JVX006MT001UH0000`1RI0004P1T
H@00H68005iN001KEP00EUH005=D001BCP00CTl004]80011@P00@Ch003Tf000`:`00:B<0024K000G
3P0020@0004107/00000303oool000X0oooo01@0;R`002hd000^>@00;3h00319000aC@00<e0003QC
0@0nD@40@Dh104AF0015D`00AeL004MI0015H@00AUl004AJ0012F`00@Uh0045L0080AEd002L0A5h0
04EP001<I@00CVH0059/001>KP00C6l0051`001?L`00CWH0051f001>M`00Dgd105Ik001KN000FW40
05M`001ILP00FVl005Yb001NMP00FgL005f00P1NO040HWh106Am0@1SO040HgP006Ai001VO@00IgX1
06Eg0@1QL040HG@005aa001PLP00H7@0069k001VP@000P1YPP009`1ZRP00Jhd006jA0@1/TP40K8h3
06J:1P1ZSPT0Ji0906JG1`1SV0X0I9H:06RD1@1[SP<0L8d0076?0@1bV@40LY/0072J001_VP00L9H0
07:B001aUP40KiL006fH001`V@40LIh2072M0P1bX@80M9h0076N001gX@40NZ0207NN0@1gW@00MYh0
07FL001cX`00LJL006n[000206n^000W07:_001d/`40N;4207Zf0`1g]`80M;P307:j1@1a_0D0L<02
07710P1e`PH0Ll8407C40P1aa080LL<307G50P1g``D0N/@507g20P20`@80P/<208;20P23b0@0OlP6
07k82020b`H0P/T508;60`23a@40Ql@208c12`21`P`0OL8<08764@28a180TL<A09G03`2?`0d0P<0@
0080PL0<02L0P<@<08?82`27aPl0Rl0B092m4@2A`@h0U<<<0972302:`@h0SLDE09jk6`2S/aX0WkLE
08g13`24aa40R/8C08^n6`2;^240UkDJ09nd4P2M/@d0W;LD09Rm:@2@`280U[TG0:Fd4@2G]QL0SKTP
09n^8@2SZ1/0VKD[09^d9@2V/Rd0XKTX0970:@27aB/0Q<dZ08CA:029dbH00P28dRH09`25cbH0Q]8R
08KA7`26da`0Q=@K08;B6@1mdAP0PLlH08G>6@23dAH0Qm<E08KB3`29dPd0Rm8<08k?3@2;cQ00RLlA
08?B4P29e100R]@@08OC4P28e180QM8C08CA4@24cA00Q<T>07o<3P1ldA40P=8A083@401nc`h0Nll<
07W<3P1jc@h0NlX:083<2`1oc0d0OL`=08;32`0208Rh0@0W08j[002<X000R9h008RP002>Y@00Rj<0
08RO0@21W@<0PJ4308:M0024WP00Q9l008JE0024T@00Pi40086B001kS`00NhL007N2001bO`00KW`0
06id001bM000LGD007Ai001dO000L7`006a`001UHP00HU`0065L001QG@00HF<005iO001PF`00Hf@0
06IU001TH@00Hf0000<0Geh00140HV40061Q001NGP00FUH005A=001>B`00Bd/004a80014A000?S/0
03/g000c;`009b8001lH000I50003PP000<1001l000000`0oooo000:0?ooo`0B02`/000]<000<4@6
031:100`FP<0<ed003UO0012H@00AEh004MQ0018IP40AfH004QX0018JP40AVd104I]0015J000@V@0
0P15HP0204UV000W04QW0018K000C7<004Ya001:L`00B7L004Mi001;NP00Bg`004Uh001=N`00CWX0
05:00P1ENP00EWD005Ue0@1IM000FGL005U_001JL@00FW0005Y/001JM@40EW4105ee001NK`00GV/0
05mX001NJ`00Gfh005iX001MI000Ff8005]Z001IIP00FFL005Y_001QL`00Hg`00080IWT002L0IWh0
06F10@1UT080Ji4206b?1@1ZSPX0JI0<06B?2@1PU0P0HIT:06>K2`1WU`L0K9D306nD0@1_U`00Ki/0
06fN001^V`00KIL006bC001ZU@00KI`206bM001_WP00LYT007>J001cV000MIT007FG001cV`00LiX0
07FJ001iV000NI`007FO0@1eX@00M:L007BX001c[@000P1e[P009`1e[`00Mjh007^`0@1k/P80NK<1
07Zg0`1e_PH0M;l906k01@1``P<0M[l007S20`1eaP@0LlH30776101ba@@0M<D707C61@1ga@<0NlL2
07k81020aPD0PL@208;6001oaP40P/P407k82@21a`H0Q/D108W20@2:_`X0PL8<08704029_Q80SkdE
09:n4`2D_@l0RKh=086o3`0208c03P0W08Fo402:_A80V;/A09Nl402H_0l0S<@=08_:3P2;c0l0RLD@
09305P2G^ad0VkXI09jj402E^`d0T[/?08c06P2=^al0T;LO09Ne5`2K]@l0W[P<09Bl602G]bD0WKPJ
0:6h402R^@d0S[`E08S07`2O/A`0XZlE09Nb602R[bX0ZZ/_0:>f;02C^S00R[/_08?<:@24dRD0Q=@[
0080Q<l]02L0Q=4Y08OB9023dad0P]DI08;D6022e1L0P]@D08GB4`25c1@0Q<dB08KA5028dQ40Rm0@
08_?402=d0h0Rm4A08SC4@23e1@0RM<F08C@6@26dQD0Q]DC08CF4@28dA<0S<dA08O;4@22ba80OLlD
07oB3`1ndA00N=0=07K?3P1icPh0N<h=07_:2`1oc@/0PLX;08;53028`0L00P2>/`002`2?Y@00SYh0
08VL002:W000SZ<008jU0027X000Q:0108>M0@23V@00PY@00080QI<000T0PHh007j90020R@00Oh/0
07f7001hOP00MX<007B0001`NP000P1bM0003`1aM@00LWT0079n001`N`00K74006IW001RG000I5h0
069O001QF`00H5`0061N001SG@00H5d005UJ000205UH000A05]L001MG@00Gf0005]M001FEP00CTd0
04Q60018A`00AdD0048n000g=P00<Rl002/[000S6@0050l0010700050P00O@00000<0?ooo`002P3o
ool0500^=`00<Cd0035I3@0cGP/0<f8703I/0`0gJP00@6`004E^0@16K`80AgH304Qc0P14M@80@WD3
03id100mL`80?Vh0041Y0015IP00AVL00P19K0009`1<K`00BW<004]h0019M000BG<004Qe0017M`00
Bg`004Yh0019N000C7X004ij001BM`40DG<005=Y001FL@D0E6/105AY0@1DIP00DUh005AQ001CFP00
DV00059M001EH`00Eeh0055L001BFP00EE/005IS001DH`00F6<105UT0@1HI@40FfT105QV001MK000
H6/006Ab000206Aa000W06Ef001TN`40HX<206FB0`1UT@H0J9D;06V@2P1VT0P0HYD906:K2`1XV@X0
K9P506jE0P1_U`40KiX006nL001^W@00JiX106bF0@1]U`40K9P006fM0P1/W`00L:<007:P0@1`W`40
LIL207FF001bT`00M9L007BK001dXP00MJ0007JP001iX`00NJT007F/001f[@00M[000080LK@002L0
K[4007:`001h/P00NK<007Nc0@1h]`40NK`407S21`1``0D0M;h207Zm0@1k_P80OL0407c20P1ja`H0
NL8607K2101aaP<0KLP407C:1@1haPL0O<D607o20`20`@00Nl@007c10`1n``D0PlD308K20027a0P0
QL@;08733@24_Q00TKdE09>n4`2I`0l0Tl8=08S13@2>_Pd00P28`1<09`2A^1D0XK8F0:Nd4@2P]Q40
U[`>09;33@2BaPh0SLXB08_35P2@^aT0TK`M09bk5@2T^0T0X[/<09Zn4@2<^al0T;`K09Rk4@2H^Pl0
UK/;08k1502=`1d0UKHU0:6b6P2M^Pl0Tkd@08[05`2:`1/0WkHE0:2c3`2K]1P0ZZdW0:j[:`2P]2d0
S[Pb08Vi<@24ab/0QllR08OB:P0208GB:00W08?A9P26e1h0Q=<K087C5`21e100Q=@@08GC3P23d`d0
PM4>08??3`25d1<0RM0D08[B5@2=e180S=8@08KC4P25eA40Q]DG08SB5P27caH0Pm4E08?D3`24ea00
RMDC08SA4`29c180Q/XA087=4`23d@l0O]4>07kB3P1oc`l0O//?07[=3P1jb`l0Ol/=08O6302<_PH0
TKD10080Tjd002L0TZL008nL002:V000RYX008bP002:XP00QJ<008>U0020W@00Oi@007jA0022T@00
PID008><001nQ000Nh0007f5001nR000N88007J1001fP000LH0006mi001^M000K780079d001dO@00
N7P007Ag001YJ`00Hf<0065P001SH`00I6D006EV001QG`00H5X005iB001HDP000P1GE000401HFP00
Fed005aK001HE`00DU@004]:0016A000AD80048o000o>P00=S<002dX000T7@005`l000/500020@1n
000000`0oooo000:0?ooo`0D0395000cC`00<fP:03A[2P0fK0P0>Vh303]^000lK@40@G@4041e1`13
O0L0@gX403me0`0lL0<0=G4603A_100gKP80=f`103eY0013J`0204=_000B04Ma0017M000AGD004Ea
0016K000B6P004UZ001:K000Cfd004Y_001>LP00CG8004a_001<IP00CEl004mU101=FP40BU000P1<
D@004`1=D`00BD/004UA0018C`00BU0004iI001<FP00E5T005=I001FI`40EVH205QT0P1GK@@0Dfh4
05U`0P1MK@40Gg00061]001UL@800P1SL@009`1PL@00HW`106F30@1VSP40II4406VE1@1YTP@0I9<5
06JE301SV@d0J9L706ZF0P1ZUP40KYT006bL0@1/V`40JId206RM0P1ZV0<0Ji@106jA001^U@40KIX1
06nP0@1aX@80KZ03076J0P1dU040Li@007>L001`X040KjP1076W001dZP00M:T107B_0P1b/P80L[<0
07:d0@0206je0@0W06Vi0@1/]P40L[D007:d0P1g]PD0MkD207bj0020^@40O;T307Zg0@1i^040M[/2
07Zm0P1l`080O;h207_2101h`080L/D207?61P1ea0T0N/8607k30`21_@80Q;d008;0001m_P00O[h1
08?10@28`@00RL@;08?53021a@h0Ql8@09?05@2I`Q00VL0<08k13P28`A40TL4B0080SL0B02L0V;XF
0:>c6@2S/QD0VKP?08o64@2F`@d0UKl?09;05`2<`1T0T;dH09Nm5P2N^Pl0X;P;09Nl4@2F^Ql0TkLM
09Bl5@2M_0l0U[/=08nn4027aAL0Sl0M09be902U/Ah0V;PD09>n8`2B_Q/0W[PN0:6f5@2B^a<0R;TS
0:2^9@2ZZR/0W[8_08fh<`27]bl0Q/X[08G>:027dBT00P27db<09`23eB40QMHJ08CD5`21e1<0PM<@
083D4@23eQ00Q]DB08CC4@28dQD0Qm<G08OB5@28dQ<0R=8B08;D4P20e1T0Pm@J083C7@24dQT0Pm0G
08;B4`1ne0l0P=@@087D4`23daP0Qm4C08_?3P2:c@d0QLl>07g@3P20cPh0P/`?087:3P1nb0d0OLD>
07o63P24_0h0S;D409:`000209>^000W092Y002;XP00RYd008RH0024V000QY/0086Q0020YP00Oi`0
07j@001lR`00OXh0086A0023T@00OhT007b4001oQP00OHD007b2001iP000M8000761001`OP00LWP0
06ia001_L`00LG<0079b001/N@00JG@006I/001TIP00HfH006AX001UJP00HV8005eK001JD`00Ddl0
0080EE8000l0FUT005YN001EF000DU<004a?0015@`00@400040n000j=`00>3@0030Y000S7@006QD0
00`600040@00O`00000<0?ooo`002P3oool0500_C`40<UH003=X1P0hJ0L0?6D603iX0P0mI`00>FP3
03Qc1`0hM@X0=gP;03Mi2@0dM0D0<Fh502i]1`0]K0D0<V`403=[0@0hJP00>VX00P0lJ`009`11KP00
@Fl0049a0012JP00@V0004=J0017F000Bed004]Q001;H`00CFD004aO0019E`00AeH004E>0017C040
?d0003/e000n?P00@D@004U90014A@00@d4004U;001:D@00CV<004]X001AK000EF/005E/0P1GMPD0
Eg@405Ia0`1GK@<0Fg4105id001UM`00I7D0061g0002065h0@0W06=h001SPP00IX@006V=0@1ZT@40
JYH106ND0@1UU`<0I9@:06:D2@1QU@<0II<106JF001WU@00IY8106:@0P1UV0<0IiP306ZF0`1YT`40
K8l006^?001[TP00K9@106jI0@1/VP<0L9/207:I0@1`W000K:8106^X0@1[[040K:/1076^0@1_[@<0
L;45072c0P1`]`40J[L20080J[T202L0Jk@106ja001^/@00KK@407>e2@1h]0<0O;D007jf0@1k]040
MkH107Jg0@1e^040N;/307Vl101j_`D0NKl807G01`1]`0@0L/8607Jo1`1k_@@0P[h1086n0@21_`00
Q;d108>m0@22_000O[d008:n0028`@h0Ql4?08S04@2A`@h0V;h>09g03`2D`@d0QLH?08K6402:aQ<0
0P2@`a809`2?a1H0SkdD08Zh4`2=_0`0Tl4<09713@2;_A@0S[XN092j6P2L^A00X[L<09nj2P2O^@d0
UkTH09Zh9@2O]1l0W[LI09ji4`2I^a40TklE0930502A_200WkLT09fd5P2Q]1H0V[@L09^g902X/B<0
Yk4E09>f5`2:^b@0XK8U0:^_:P2N]3@0SKLf08Rk<026b2h0Ql`^08C@;00208KB8@0W08CE7021eQL0
PMLF07oE5@22eAD0PM<J083D7P21eA`0PM@E08GC4P28e1<0QM8A08G@3`22d@l0Q=8A08;B4`23d1L0
Pm4N08;?6@26d1D0Pll@083@3P1nd@h0OmD?083H4`24da40Q]@@08?C3P1oe0h0O]4=083<3@1nb`h0
P<T<07g83@1maPd0O<4<08:d1`2>[P80SjL00080SJL002L0SJH008fK002:V`00RID008FB0024T`00
QYl008JP0026WP00PY0007f40021Q000Phh008BD001oT000PHT007j6001lP`00NhL007Z2001iP`00
M8@00763001aOP00KWL006ad001^JP00Jfh006Yb001XLP00J74006IY001SI`00H6L005iX001MH`00
GUl005QF001FD@000P1HE@003`1HE`00EUT0059E001>D@00B4P00451000l>`00=SD0034/000^9`00
91X001L@000>20001P800040001o000000`0oooo000:0?ooo`0D031:0@0aC@00<e4003YK0@0hF040
>U/003MM0@0`HP<0;Vd602eb200^M@/0;g<<02e^2@0[I`D0:fH502]T100`I@<0<fH103EV000gI002
03]Q000W03]O0010I000?f<0041K0011D`00?Td004990014D@00AUH004AF0016D`00@dd004540010
@@00?C`003De000a:`00;2H003P`000o?`00A4P004I80019B`40CEP104iP001?KP00CG8005Ib001G
M`00EgH305Yn1@1HNP<0FgD105Ua001ON000HGT006Aj001TO`00I8800080IHH102L0HH8006:9001U
R@40HY4406FC0`1WV`40IY/006:F0P1RU@L0H9@6062D0P1RSP00II4106J?0@1UQP80I8D106>>0`1R
T080I9H306JE0P1[T`00Jhd006N>0@1XT`40Ji/206fK0P1_XP40LZ<1072U001/Z@00JJd106^^0@1/
/@40JK@306^c101_[P@0LK0206jb0@1/]0800P1^/P409`1`[@00LjX007FX001^[`80LJd307F_0P1e
/P00MK@107Fc0@1]]040KkL1076e0P1e^@<0MKh307Nm201g`0X0Lk`906o11`1_`@P0L/0707Vn0`1m
_@40OL0007k10023``40QL4208310@1n_P40Ol8108340`2:`A<0UklC09S03P2B`0/0T<0<08k32`29
a0h0R/PC08c54P0209;14`0W08g45022`a00NLL;08712P2A`@d0T/4A09Fn7@2G^280VkHH0:2e3P2R
]`/0U;d<09ff502I/QX0WK<Q0:Bb9`2J]1H0VKHA09Zj402H`1L0T/0G09Zh7@2O/1X0W;DB09^c4P2O
/AH0W;0X0:B_9P2/ZA@0Vk8C09:i7`2O]RL0Y;4/09je<`2@^300Q[l[08?6:P27bS40Q</a0080Q]8W
02L0RM@N08KF6@1oeA@0P]DE083C5`1ldQT0Nm8I07WD5`1ke100P=H?08KE3@28e140PlhG083=4`26
cQ<0Q/hA08O>5026cah0RL/F08S=4P29cA80PLdA07k>4P1ne140PMP@08GD4@24eQ00Om<?07_B3@1o
dPd0O<l>07k;3P20a``0O/T<07c6301o_@L0Q;8108RW0@2<W`000P2;X@009`29X000RYP008ZF0029
T`00QHh008BD0025V`00RZ4008JM0021S`00PX@008230020QP00Ph/0082>0021S@00OXH007j5001l
PP00NX<007Z6001eP000LX<007:2001cOP00LW`006e`001ZL000J6l006M/001XK@00IF`0069U001N
I@00GF8005aP001JHP00Ee`005QH000205AE000>059E001CF000DEP004aB0015A000@3d003Td000_
:`009b00024I000E3`002`D000D300020020000000`0oooo000:0?ooo`0D03510@0b@@00<d@003=;
000_B`00;4`002iH0@0ZG`<09f`402I^100UKPL0:F/802MS1@0WGP@0:Uh202eH0@0aD`40=E@003QE
000hE00203Q?000H03M?000fD`00>e4003a:000j@`00>Sh003`n0011@000?d@003i1000l?P00>T00
03Pl000j?@00>3X003@_000`9`00<BP003lj0016A`00BE<004UK0@19H@<0C6P10P1AJ@003@1FJ`00
F6d005aa001MLP40GgT205ej0@1ON`00Gg`005f0001SQ@00Hgl006N60P1TR`400P1RT@809`1MS`00
G98105b<101MS`X0GY@805fF0@1PUP00H9<106:D0`1NT`<0H94106:8001PR040Gh@306:20P1NP@00
G8T105j90P1RU`L0IIX406ZG0@1VSP40Ii8206BI0`1YX@D0JjD306nZ0P1^Z040KjL006ZW001Y[040
KZ/106n/0P1Y/PD0JkD406b_0P1a[P<0Kjh406j/0`0206fZ0P0W06bX0@1dYP00LJH106j/0@1_Z`00
LZX106n[0P1X/080JK4206Rc0P1W]`40K;8107:g0P1d^080MkT407fi2@1h^PL0MKd807G02@1d`@X0
M<8807G00P1d`P00NL@107o80@22a0<0O/4307k00@1m`@40O<8608Zn4`2D_A00VKh=08c22`23a0/0
R/4<09333`2;`Q@0T;dI0080U;hI02L0Sl0@08?42`1ha`T0M/H:08?24@2?_QL0V;XM0::c902R/aD0
Xk4?0:B`2`2B]0h0WKDC09Fc7`2F/B@0XjhY09Vb4`2R]140V[/B09Rn502@`A/0UkLJ0:Jb5@2N/@h0
V[PB09Ne802L/BH0YJhU0:Z]5`2U/AL0W[8L09ng:02O^2T0V;T_08c1;@21bbT0O<hW08;;;@25cc00
0P29dBP09`2;e200QM<L07oF6@21eAD0P=DF07cC601jeAX0NMDM07OG601meQ<0PMD@08WC4P25d1`0
PLlE08O>5@27d1H0QlhF08O97@25bA<0P//C083=4P20cQ80P<TF08??4@26eA00R=@?08?@401lcPl0
Olh?07cC3P1ndPh0O/h=07o93P24a@d0P/07086f0`26Z`00QJH008JN000208VO000O08VN0029V000
QYH008ZC0028SP00QY0008ZD002:V@00QIX008B>0022RP00OH8007]l001lOP00OX4007n8001nP`00
Nh4007j3001kQ000OXT007N4001cPP00LWd0071m001cP000LWD006ia001YL000IVh0069W0002069V
000605eQ001LH000Ee`005AI001FF`00EEL00P1CD0003@1<CP00CT/004]=0019C000@D4003Tg000b
;0009b0001dD000E2`002PH000H300030P00P@00000<0?ooo`002P3oool0500_=P00;3L002`e000^
?`00:D0002A5000XD@<09UT602AM100UHP<09f0302YJ0P0YEP809e@102UC0@0_C000<D4003<m000a
?000<Sl00P0e?`00300b>@00=Ch003Lh000b<P00<CD003@f000f=000=C8003Dd000g=@00=S8003Lf
0080>3`001T0>ch003/l0010>@00@Sh004I>001=H000BfH004iZ0@1BK@40EGD105E^001EJ000F6H0
05MW001HKP00Ffd005ee001MNP00GWl005n3001JR@00Gh/00666001NR`L0Fhh30080FXl202L0G8`0
05j8001LRP<0FXh805RD1`1IT040G90005j@001OT@40GI0005j;001RQ000Hg`1065l0P1NO@40Fgh0
05n40@1OR@40I8d106RL1P1XU`40JIH106RE0P1XW@<0Jj8506jX0`1^Z`40K:T106^W001XY040IZ<2
06ZS0P1^Z@<0JJ`306Z_0`1X[`P0Jk4906^^2P1Y[@T00P1WZ`L09`1WZ@@0LJD1076S001^ZP40Jjd0
06n]0@1/Z@40IZX306>a101R/`<0K;8107:d0@1d]@40N;@207Ng0P1h]PD0MKL407Fi1@1i^0D0N[/6
07Jn1`1b_@80MKl007[0001n``40O/8307jn0`1n`080Nl0107[10`2;_a00T/0?08Zm2`27`P/0RL<;
08_23P29`A80RK`G08fj6@0209Jj5`0W092n3@29a0X0Q<D<07[4401o`A@0QklE09>n6P2R^B<0Z;DA
0:Z`3P2W[`/0V[8@09ff5`2A^280U[<R0:R_6`2V/0l0WK@>09Jk5P2B_Q/0RkXJ09Nj602S^140Y;H>
09^f3`2I]b40W;<T0:N_902W/A/0Xk4I09na8@2G]R/0U;X[08jn;P27b2d0P]0_083;:`25b2X0QLd/
0080R<l[02L0R]4W08CD9P20e1/0OMHF07[F601heQT0OmDH083D601ndaL0P=@D083C4@22eA<0P]HI
07oD6@20cQT0P]4K08K@6@25bQX0Q/TD08C;5023cQ80Q<lB08;>4P25d100RM4?08_A3`26c0l0O/hA
07kC401jd@l0N]4>07oA3@22b@h0Q/0908Vi0027/P00RJP008ZU002<X@000P2:Y0009`2;W@00QiL0
08JF0026U@00RYD008VC0027U`00QYL008>A0020RP00OhX007Z6001eOP00MgL007Ig001lO@00Ng`0
07Ui001gNP00Ngh007Z2001hQ000Mh@0071l001^O000KWX0071f001^MP00K74006Q_001VK000I6X0
06AY001QI@00FUl005EI001CE000D5<004e>000204m7000=04Q20015?`00@T40040n000k>P00=S40
02/S000M5@0040L000P500030`000P4000400021000000`0oooo000:0?ooo`0D02D]000W;`009S80
02Xe000U=P008cd002I80@0VC@<08dl202M?0@0XB@00:4H002a3000Z?P00:c/002/c000W;`00:Bh0
02TZ000/:`0202hc000702d[000]:P00:bD002XV000]<000;c<0030_0002038_000N03H_000c<`00
>CT003]2000oA000A4T0049:0017DP00BeX004aU001BK@00Dfl005A^001CK`00E74005I_001DJ`00
F6L005ES001KKP00Ffl005Ub001LO000Fgd005eo001MO@00GW/005mj001QO`<0GGl20P1JOP409`1I
Q`00FhL105V?101DR`@0EHl305B>001HSP40G8h105f=001MR`00GhP00623001OO000HgT006=j001S
OP00Hh0006F8001ZT`00Jil206NM0@1WW@00J9l106ZS0@1^X`80K:8106bR001XY@00Ij8006NP0@1U
W@80J9/206VR0`1VY@40IJ/206:]2@1S/@T0HK0:05fb2P0205n^2@0W06V[1@1^Y@40L:H006fT001X
Z`40IZl106N^0@1X/0<0Ik<606Bj101[]`<0K[L507Bf101d/`<0M[D207Ng0`1e^P@0L;P407>h101h
^`D0N;X707Jk0`1g^`40N;h007bo0P1k`0@0O;d307jn0@1l`040O<020970302=`P`0PL0;08;52`2<
a@`0Q<@B07c05`28_A<0UkLD0080WKHE02L0T[P;08g04@25`1H0N/4H07S35`1k`aP0Pl<F08[44`2Q
^Q00[;<=0:6_3@2L/QD0V[8W096g9@2J/ad0[:l>0:Zb3@2Q]@h0U;TM092f902O/ad0YKHH0:>i4P2T
^0l0W;HA09Bg6`2I/R<0X;8S0:6e802L]b@0Uk8Z08nf;`2<^S<0Q<<a087;<@21cC<0P/H_08C6;P25
cS000P22dC<09`22dc80Pm@Z07_E7`1ef1X0LmLJ07KG5`1oeAP0PMDM07cD6@1je1T0N]8P07_E7@20
eB00PMHO07k@7@20cR00PldP08G@7024dQ<0P]4C083?5@1md1H0O/lH07kA4P20dQ00P]4>08;B4@20
e180PM<?07k>3`1od0h0P<`>08?4302=_0H0S;H008^b0029[@00S:L0092Y0002092T000W08^G0027
T000RI8008NC0029V@00RIP008JI0025TP00PHT007^5001nQP00NhH007Uo001eN@00MWH007Ei001h
M`00MWL007Ed001gN000NGT007N2001gP@00Lgd0075k001cNP00Kg`006ei001[M000JG4006E[001U
KP00IV`006=]001LH@00EeD004m?001:B@00AT@00080AD4000/0@Sh003dg000g<@00=2l0034^000/
:00081T0014<000710000`8000400023000000`0oooo000:0?ooo`0D024Y000S;P0092l002Db000S
=P008SP0024l000S?@408Sd002Lk000W=`009S@002Td000W:`008bH002<T000R8@008R8002@R000V
900202/]000W02TZ000V8@00:2<002PT000]<@00<C8002//000a;`00<Bd003Db000h>@00?44003i>
0012D`00AU4004MG0017GP00D6T004e/001CKP00DV`004eW001<JP00CF`0055^001BKP00Ef`005I[
001FK000FVl005Q^001IL`00Eg<005Qc001IJ`00FF`005Y`001JK`00G7@00080GGH000P0FXD005N;
0P1HT0L0EX`705J?0`1FRP00Ehl305Z80@80FhP001d0G88005f6001MP`00HH80065o001YQ@40JhD0
06Z=001XTP00I9T006>J001SW`00HYh006NO001YVP00JYT106JH001TW000H9h1066O0P1UUP80I9`1
06:I001VWP00HJ4005jX0P1LZPD0GZh705bb2@02066a1`0W06J`101YZ`<0KJ`206fX0@1XZ`40IZl1
06N`0@1//@@0L;@506nj1@1/_0L0L;/706jg201b]P@0N;<107Zd0P1g^@<0LKT5076k1@1f^@H0M;P6
07Nk0`1f_P40M/0107c00P1o_080OkX2086o0@21`P00O/8107_31@26a0/0Pl<?08G44P24a1H0Q/0G
08Fm5P2D]Q@0U;<?0080V;@A02L0SkPD08fm6025_Qh0OkdM08>l6`28_A/0P/<F08C95@2G_@h0Y[L?
0:2c4@2N/R@0W;<Y09^g702U]a@0Z[<<0:6_3P2I]140U;LS08ng9P2J/2H0YK0N0:Fc5`2R]1<0V;@A
09Ff5`2B]R00U;DU09Zj:@2I^B`0TkPb08bi<@29^C<0R;hc0874=01maC/0OLHf07g:=01mccL00P20
dS<09`1ne3<0OMH[07[G:01ff2<0L]PN07GG601iead0OmDN07_D601fe1X0NMHQ07_E7`1nea/0PMLK
08?F6P1ocad0Q<lP083A7@20e1P0OM<I07kA6`1ldQ`0N/lM07cA6`21dQD0Om4D07_C5P1hdQh0P=0D
07o:4022b@h0PL@<08Vj202<]@@0S[8008ne002;/P00S:/009>Y0002092V000W08nM002:U000Qi40
08>D0029VP00QiT008>F0022T@00Oh/007b7001jQP00NX8007]n001dOP00LgP007Mh001kO000N7`0
07Qk001cO@00M7L007Ak001dO`00Lg`0075k001_NP00KgT006md001ZLP00IFh0065X001QJP00Hfd0
065Y001LGP00EUH0051<0018B@00@d800080?d4000X0>c/003<b000_8`009ah002@L000O6@006100
00P600010@000@00Q000000<0?ooo`002P3oool0500Q:@008bh002@_000U<P008cH0028h000Q?000
8cd1028m000W>`009cL002Hd000Y=0009b/002<V000S90008R40028R000T8P009R@00P0[;@009`0Y
:P009R4002PS000X9000;C40034b000[;000<Bl0034]000e<P00>3T003a1000nCP00@U<004IA0017
E`00Aeh0051Y001=K000Dfh0059/001=I`00C6X004e/001AKP00DVh005M/001FJ`00EV`005Y_001H
KP00FG<005Mc001HL`00FF/005U/001JL000FVl005ad000205ef000805Z5001GR`80F90705J<1`1F
S`<0EXX005N?0`1JR04205^8000M05b2001MQP00GH<00662001QO`00JHD106^5001ZS@00J98006BI
001SVP00Hil006:N001WW`00JIX006ZI0@1VV000I9`0062N0@1QW`80IIH206BL0@1RV@00IYh0066Q
001NZ080G:X505j^1`1L/PT00P1Q/@L09`1V/0@0JJ/306f/0P1]Z040J:/106J_0@1W/040K;44072d
1@1_^PD0K;`7072k1`1^]`P0L[H407Rc0@1j]080MkT3076i1@1a^`D0M[T607Bh1P1g^`<0M[h107K0
0@1l`080Ok`207nj0P21_`40PL8007k20@1k``D0Q/@;08?33`25a180Q<@F08K05`25_AH0U;HD09Bc
3`0209Rd4@0W08nh502=_AP0QKhN07nm7@23_1/0R;dK08;35P24bAD0Ukd>0:Jg3`2P/a40W[8T09bc
:@2K]a`0YKLD0:Zc302Q[`h0VK@A09Bg8`2?]bH0V[0V0:F`7P2U/aL0X[@C09Rd4@2E]QL0T[HP09Be
9@2J^RT0VKT/09>h<P2<^C40RKTc08Rn<`21a3@0OLDk07g6=P1mbS@0OLlg0080P=8c02L0O]@c07gF
:`1jebP0M]PS07;H7P1eeaP0NMLM07oE7P1ke1P0M]@J07WF8@1keAl0O]LK087G6`23eQX0OllM08C?
8020dAd0P=@H07gC6@1ndA/0O=8L07[?7@1ldA/0PM8E07oA501kdaH0N=8N083@501obQ00P/T>0874
3029^PP0S;D408jb002?]@00Rk8008b[002CZ@000P2@YP009`2?W@00RY@008NA0023U000RIX008NI
0023UP00PY4007n;001lQ`00NXH007Z2001kOP00M7h007=h001gN000Ng`007Ql001hN`00Lgd007Ag
001dN`00M7l007=l001aN`00KgX006mi001_M000JW8006E^001QJ000HFX006=]001QJ@00G5h005IF
001@C000B4T004=2000203m1000:03/k000c<P00;b<002LN000T70007aT001P@00081P000@400040
08@00000303oool000X0oooo01@07bL002<^000T<`0093L002@h000S=`008CL002@c000R<0009B/0
02L]000X;000:Rl002LW000U80008B00020K000N6@008R8002@Q00809bX002L09bd002TZ000Y:000
:BD002hc000b<P00<2d0034/000c<000=CD003/o0010AP00A4h0049?0014C@00B5<004QF001:GP00
BeX004aO001<H000B60004MU001:I`00D780055d001BL000EG4005E[001HJ@00EF<005=X001BI`00
DVX0051V001>I040EF/105IZ001IL0000P1JN0409`1KR080F8/405J?1P1DS`D0Eh/105F8001FRP40
F8L105^7001GQ`00F8D005N9001GRP00FHT005j;001RT`40I8l106V>001TSP00Hhl106F?0@1VT@00
Hhl006FB001UTP40IY4106>>001OT000FI<205VI0`1LU@40HI@005nD001SV@00H9d005nQ001NY@40
HZT206>[100206>b0`0W06>c101S]0@0Ik0506R_0@1[/080Ik8306b`0@1^[0<0LK47076j1P1[_@H0
KKd706nk1`1a^0@0M[D207Je0`1c]`<0L[@407>f2@1b]`X0KKP9072i101c_0<0ML0207C00P1i`080
O;l208300P1n`@40OL4107[32`1m```0Ll8>07k06`23^ad0R[`J09>i602H^Q@0RkT>0080TkHI02L0
TKPC08^i5`28^R@0S;PU09Fc7`2N/QL0T[/A08g85`2@a100VklA09Vj602J]bH0W[8Y0::g6P2W^Ph0
Y;D<09Vh302I^Q<0UkLQ092d9@2@/RX0WJlT0:V`7P2Q/a`0VKPI09Ve5`2<^240S[`S096g8@2G]RX0
TkTa092h<@2@^3@0S;Tf08Bn>P1j_S`0MlHl07O:?01iccd00P1kccL02P1kd3<0N=@[07OE9@1deRD0
LMHP073H701dfB00M]TP07SI601kf1H207SF6`0K07[E7@1meQh0OMPQ07SH801ke240N=4N07gA8P1l
dB@0O=8Q07cD7P1ge1d0MmHR07[G7`1he1P0M]8G07K>6P1nbA<0P<L@08>n2`25]P@0Qjh108^/0@2=
Z`00Sk40092a002?[@00Rjh00080SZL002L0Sj0008fM0027UP00QIL008NF0026T`00PI40086:0020
S000P8l007b9001jP@00N7d007Ei001fN000NG`007V0001kP@00Nh0007Ml001cNP00LgL007Ai001b
O000LGd006ee001^MP00K7@006M]001RIP00HFH005iT001OIP00GEh005EG001@DP00BDT004E4000n
?0000P0h=@00200g<@00;RP002<L000K4P005Pd000l;000:10001040QP00000<0?ooo`002P3oool0
500M:0008C8002<j000P?00093h0028i000R=P008c8002<_000U:`00:bl002Pf000/>000:38002</
000P9P007B4001`J000O7P0081l00P0S9@00700W9`00:RP002d[000[:@00;2d003@c000a<@00<S@0
038f000e>@00?4@003m70010A`00@4D003e0000o@P00?D8003a5000oA@00@DT004AF0P12FP80AV<1
04YT001@K@00DFd0055Z001EJ`02059U0009051R001CI`00CfH004aW001>JP40CFT105A`0@1DKP00
F7@00080EgP102L0EGX505>41@1ARP<0DY41056B0@1@TP00CI4005>;001GQP00F8D005>2001GQ@00
F8H005V9001KR`00G981062@0@1OR@00HH@006210@1SQ0<0H88506260`1OQP40Gh`005n70@1QQ`00
G8L005Z@0@1KUP40G9@105fG001QU`00HiX306:I0@1SV`00HZ0106>W0@1YYP400P1ZZ0409`1XZ040
Ij/206VZ0`1/Z`40KJh106j^0P1`[P40KK0306bf2@1Z^0X0J[/406ni101a^0@0L;d206bj101X^@L0
I[P506Zg1@1[^`L0J[/906jh1`1`]`D0LkL207Bl0`1__`<0KLD407?30P1h`P<0O<0207Zo001h``/0
Ml<>06bn4P1e_A/0OKTP08Bk7P2:_1H0R;`?08nn400209Nj6P0W08ji6`2?]Ah0Rk8R09J`8@2R[QX0
YJd=09Nk3P2@aa/0TLDB09W14P2M_QD0X;TP0:Nd:02Z]aL0YkP@0::i3P2J_@h0V;`@09Vf6`2E/ad0
U[<O09Rb802L/Ah0V;8N096f7`2E]b80S[XS09:k802C^Al0TkXU09Jk;P2J^c00U;Xf08^l>`23_Ch0
O;ho07O3?@1gb3/0Mlm30080N<hm02L0N/lj07K?=@1edS40M]@e073E:P1_ebL0L=HX07;G8P1dfAh0
MmLN07GG7@1eeQ/0O=@L07gF7`1jfBD0NMPX07WC:P1cd2/0N/dZ07OA:01gdR80NMPF07OG4@1eeAD0
N=HJ07SF6@1ddQL0ML/F07o64@24_0L0R;@408Fa0P28Z`40RZX008bX002=ZP00S:/108fY002;Z000
0P2<Z@009`2<XP00RZ0008NN0026W000QIH008:A001lT@00OX/0082:001oR`00OXT007V6001gP000
MG`007Il001gO000Ng`007V4001hP@00M7/0071g001`M@00LW<0075h001`M`00K7D006eh001[N@00
Ig@005mT001LG@00F5`005UL001FE`00DE8004Q>0015A000@T0003Xg0002038a000902dW000S8000
6Q<0010:000<1@001@800040000000000@0008D00000303oool000X0oooo00D06Bl001Xd000O@000
7Sl002100002024i000<02@k000W>0009SH002/m000[@`00:D8002Hj000S<0007bX001hS000L7@00
7Al00`0K70009`0Q8@009B@002P[000Y:000:bX0030b000^<000;cL0034g000a>P00=d<003I4000e
?000<cP0038e000d=@00<3@003Le000i>@00?DD0045K1P12H0D0A64204]P0019G`00C6L004YS001<
I000BUl004YT0018H`00BVL004a_001:L000CWP004id0@1AM`00D740051/0002059d0@0W04mg101B
O`@0DH<104n<001<SP00CI4004f<001@R@00DX0005V0001EN@00EGP005Mn001GP000FXX005b6001N
QP00Fh8005^0001IP@40EhD605N42`1FR@L0EXX105^@0@1LQ000H8<005io001NR@00GXh005nF001M
VP40HI`1066J0@1SW0<0IiL106FF001UX000Jil10080Jil002L0JJ4106RR0@1XX040Jj8106fR0@1a
YP00KZX106f_0P1//@T0Jk@:06be0`1a/P40MKH207:j0`1Z^PL0Hk/806:k201U^`L0I[/506^l0`1`
^0@0MKH307Bg0`1c^@40K[l406[51@1^a0D0M<8307[00P1i_P00N/<=07K13@1c`140M/0K07Zl7020
_Ad0P[lD08S13P2G`1D00P2I_aT09`2?_Ad0T;TN09bc7P2O/ad0W[@I0:6d3`2C`100S/XK08o84P2G
a1<0T/0F09Zm7P2S^RL0YK@G0:2i4`2N`1P0V<4F09S15@2J_1d0UkTN09Ji802F]Ah0U[8P09Bb8P2E
/BP0V;<X09Zj8P2O^al0WK/R09Rm902F^bH0V;X_09Fj=P2=_Sd0QkY0082k?01l_Sd0N<4k07S9@002
07K;?00W07K<?@1dcC/0M<dl073A>P1_dcD0K]Dc06oE:01af2@0L]HU07KJ901deb@0LmTQ07_F8`1o
eR@0P=@V083F9P1ldbl0M]0f077B;01/eRD0KMPP07;H6P1beQ00MM@A07KB4P1ddA@0N<dA07g93`26
_``0SK0108^/0@28[P80R:l108J/0029Z000Qj@108NY0@2:Y`40Qj<00080Qj4000<0Q9P008FE0024
V0000P22U@005@20V000P9H007nC0022S@00PHd007n@001mT`00NXL007J3001fPP00MW/007=l001e
O@00M7/0075h001aM`00K70006e_001/L000JVl006Yd000206Qb000;06=Y001MG`00FET005=E001C
EP00CDl004a<0015B000@Sl003ll000h<P000P0`:`001P0Y7@006aD0014;000910001040008008P0
0000303oool000X0oooo01@05S4001Tb000L?@006c`001`i000M=P007cT002E0000V@0009c`002a2
000[@@00:40002De000P9`006Ql001/J000I5`006aT001PG00806a@000P07A/0024P000R8000:2P0
02PY000];P00:bd002PY0080:bd001d0;SL002li000]<@00:bd002`^000`=000=3D003@j000kAP00
?Td0045P2@11HPP0@U/204AI0013EP00AE`004IL0017G`00AEd0041J0014H@00Af<004]]001:K`00
C7H004ad0019LP00Bg8004e/000204e`0@0W04aa0@1AN`80Cgd104n6001=P`00Cgh0051k001>N000
DWD005Id001EM@00DW0005=`001DL@00F7T005Ub001JN@00Egd005Ao0@1CO`40EH0305N11@1FQ0<0
EHH105N<0P1KQ`00GH4005^0001NP@00GXL005nE0@1MV040GY`3066K0`1TW080I94106FB001TUP00
J9X00080JiX002L0JIX206VK0P1/W080KIh206jM0P1bXP40Kj<106b[0P1/[PH0KJl806n_1P1bZ`<0
Lk4207R`1`1c[`T0KKH;06fj2P1^^PP0LKT4076f0P1^]`80L[@107Fc001c/P40L[T307;0101d_`@0
MK/307Rj0@1k_040O/@>07c03`1i`A00OL8K082n6`28_1X0S[`F08[03P2>`AH00P2D`aT09`2=`AL0
UKdI0::k6`2L^a/0UkdK09fk3P2A`0h0RLPH08W66P2;aQP0SL8G09G26P2L_1d0WkTK0:2l6`2K`2<0
T<<R09728P2@`2@0S;lS08jk9@2C]bD0Vk<R09Zb9@2O/RX0WKPX09Zo9`2K`bT0Ul8Y09?49`2AaBL0
U<@]08o2<`2<`C@0R<4e08:i=@1j`3L0N<Ll07O9?P0207O<?@04073@?01bdSX0LLlk06o?>P80Jlhm
0240K]0a06oE<@1aeRh0M=P[07GF:P1eebL0N=DV07_E:P20dR`0PM4U07_E9P1gebH0L=@K06OC6@1Y
e1/0KM8L07;B6@1bd1L0LLlE07O;401oa`h0RL45092j0@2?[`40SZd108j[0@2>Z`00RZX008^V0027
X`00QjL108JV0027X`000P27X0009`22V000Q9<0086?001nT000OY@0082K0022WP00P9H007jC001m
TP00OYD007fH001iS`00M8l007F=001bP@00L7T0075g001aN`00KgX0071f001]L000Ifl006QY001W
J000IVT006I[001TK000H68005iL001FFP00E5L0055D001?C@00ATT003i3000k?000=bl002hV0002
02LS000401lF000D2`002080008008X00000303oool000X0oooo01@04S8001@b000J>00073H001dc
000N<P0083D0028i000W@`00:3`002Xl000Y>0009C40020V000J6P005AD001LD000F50005Q4001D?
00805Q4001T071H001lJ000O800092L002DY000Y;0009bT002<R000S80008Qh002@R000];`00:R/0
02`^000/;`00;S4003Hl000hB000>e@003iF0010G`<0@Uh3045E0@12DP00?Tl00080@5P000`0?UD0
045I0011EP00A60004ES0019J000AV@004IR0018I`00AfT004Y`001;J`0204Y[000:04eW001?N0P0
D7P504mk0@1:MP40C6h004eZ001=H`00Cf@0051V0080D74000P0DW@005=`001EK@00DVX005A^001C
M@40CG/304ij0`80DgT10140EW`105=i001EPP80Egh005Ym001KN000GW`005eo001PRP40HXh106FD
0P1UU@80I9<1066?0@1SS`00II4006FE000206NB000W06RD0@1YT@80K9P206^L0@1_W`<0L:<307:U
0P1_[0@0K:`606V^2@1[/@X0JZd5072b1@1d/@T0Ljd6072b1`1`]`H0M;H607Nd101c]P<0KkH107:e
0@1d]P00M[0107Vc0@1i]@40N[`207Rm0P1i^040OK`208;23@1o`0l0QKlA08Bl402;^Q`0SkPG09:k
5@2<`180Ql<D0080Ql4G02L0R<8B09:n4P2F_1D0TkdL09347@2D`A@0U<<@08o4402;aQP0R/LI08_5
5@2@`aH0Tl0I09Bm6P2F^Qh0U/0U09?19P2B`RL0R/LU08S48P29`2H0S<0T09S08P2F_al0VKdN09[0
:@2H_RT0T/0Y09:o:@2?a2<0T<PS08o89P2;bbL0R<hX08;>:P1mbRP0Nl/]07K@;@1bd2d00P1ddbl0
9`1ce340M=<d07?B<`1]cSL0K<`i06_9@01^cC@0L=@e07?D=P1aeS00K]D`06oE9P1cdR80N]@T07[D
9@1jeB<0NmHN07KG7@1_daX0J=0G06G>5P1WcAL0L<hN07;:601haQ80P/0=08Zj1@2@]P40TK@0092b
002>[`00RjX008RV0027Y`00QZ8008RT0027X`00QjH008Z[000208BW000608FM0022U`00PHl007f?
001nS`00PI<00P21V`004P1mUP00Ni4007jA001lS`00NHd007ZA001iS`00MHP007>5001aN`00L7P0
079i001]M@00Jg8006M_001TJ000I6L0069T0080Gf@000/0GEh005UJ001GF000D5<0051>001:CP00
AD@003`o000i=`00<RL002<L0002020K000301D=00080`000P0008/00000303oool000X0oooo01@0
5C0001H`000J=@00734001d]000P;P008Bl0028b000W>@009c<002D]000R:P007R8001XI000D4@00
40d0018<000@3P004@h001@>00804Q0002L06QH001/M000L8@008BD0028U000S9P009BD0020O000Q
7@008Q`002@R000Z:`00:Bl0034g000a>@00=3P003M0000iA`00>e8003e@000lCP00@5@003i<0010
C@00?D/003mG0@0nEP00?5<003iH000oE000@Eh004=P0014I@00A5l0045F0014F000AU/004UR0017
HP000P18I`009`18H`00Af@004Mc2015K@40B74004MV0017H000AeX004ML0@16H040BV`104ec0@1A
M`00Dg@005=a001BJ000DV`0051]0@1<LP@0CWD404mf0@1@MP00D78004eb001>K000E78005E]001G
J`00F6X005Ud001LP000HGl006F70@1TR@40IXd406>90@1SR000IHX006RA000206R@000W06VD0P1X
U080IiX206ZI0P1/XP80KZP507:[1P1a/0T0KJ`606b_2@1/[0D0KJl406ne1@1`]@H0Kk4306na0@1e
/@80MZl207Jd0P1`]@@0KKD2076f0@1d]000NK<107Z_0@1f]080N;/207Nl0P1g_`80N/4407fm0@1k
aA00R[lE096n5P2D^Q/0V;PL09:k602<`QD0Ql<E0080QLDB02L0R<DC08k34`2>`1<0Rl0H08[26`29
a1D0R/HC08_64P27aa00RlL?0971402B`1@0T;lG08fn7@2?`240Sl@T09789@2=aRL0RLXS08O67P27
aB00QlDM08o86P2CbQT0U/PH09C6702DaB80UL8T08o18P2=a200SLXN08c?6`28dQH0RM4D08KB4`1o
cQ80OlhA07[=4`1fd1D00P1idAD06`1jda/0O=DQ07cF:@1aeS<0M=@^06k@<@1_e340K=L]073F;`1]
eRd0JM@[06[F9`1`eB00MmLL07[E6`1ldaL0NM@L07?D8@1`dAh0JM4L06c>5@1cbQ<0MlPF07_0401m
^@d0QZh508ZZ000208fV000:08nW002@Z`00RjT008RW0025XP00QJ<008BQ0025W`00QZ8008V[0080
QZ`000d0QZ4008JI0025U000PY40082A001nU000P9L0086I001lV000Ni<007f?001lS@00MhX00080
NX/001P0N8L007R6001fP@00LG/0075l001^N000JWD006Uc001WL000HfT0065S001MH`00G6@005MM
001CEP00DE4004a;0017@P00AD<0040n000i>@00=3<002TS000O600201D?000300/700030@000000
08/00000303oool000X0oooo01@05R/001L[000F:P007B/001`X000O:@0082P001lT000R:`007R80
01`O000L6`005aL0018C000B40003``000h:000<2P0030/0014:00804@h002L0514001/L000L7@00
82<0020Q000Q:00092P0024Q000R8P009BP002LZ000/=000;ST0034j000f@`00=48003=3000d@P00
<48003E3000gA000>dd003]:0010C000@4l003mC0014G000@5D0045E000mD`00>eT003aH000jF000
?EX003eA0011DP00@U8004=L0011G@400P11G`809`14H@40@V<0041[1015I`40B6T004MO0017F`00
A5`103mO0P13H@<0AVh304Ua0@1:L000CGH0051_001AKP00CFH0055[0@1?KP80DGH2055f0@1@N000
CWD004mc001?K000EW8005E]001GK@00F6h005Me001HM@00GgT005mh001QO000HW`006>70P1SQ`40
H8@106B;0@0206B>0@0W06NH0P1VU`40J9T006RF001/W`40KjD207>Y101_[PL0KJP406ZZ101YZ@80
K:h3072_0P1]]P<0K[D2076`0P1c/P40L[@107:e0P1`]`@0K[/307>k0@1a^040L[/207Fh101e^PH0
Kkd306k00P1^`@H0LL<907C0101g`0l0O[hB08[15P2=_Ah0U;TL09Jk702?`1T0T/0J0080Sl@G02L0
S/LE08c75@2=aQD0P/<K07g27@20`QX0PL<K08?45`26aaL0SLDG09G06P2D`1X0T<8G08k79@2=ab@0
R/TQ08c:902?ab80RLHN08[4702?aA`0S<PI08k95P2Ac1<0T/hG093:6`2?b1/0U//G09755`2=a1D0
SLLA08g93P29bPh0R/T=08K53@20aP`0PLD;08772@1lb0X00P1na`/09`26a0d0Q<H@08?B601keR`0
NMHT07GH8`1bf2H0KMPT06kG:@1ZebP0I=DT06SD901_dal0M]4D07S@4@1hd1<0N<lG07??801bcal0
K=4J07;;4P1kaa40Pkh>08:e2@20Z`<0P:H208:S0025W@00R9d008fT002>Y`00RjL008NT0028X@00
R:0008JO0023VP00Q9`008BT000208>S000A082N0024W@00Q9`008>E0022UP00OiH007j>001oT`00
OY@007Z@001jR000NhP007Z;001iS@00MHL007B6001fQP000P1dP`00501eO`00LGX006Ye001VL@00
IG8006EY001NH@00Gf0005]O001EF@00D5<004Y;0011A000>cX003dg000e<000<30002XU000L6000
5Pl00P091`000`050P000@400000002;000000`0oooo000:0?ooo`0:01DV000F90005R4001TP000H
7@005QX001TI000F5`006Q/001PF008051D000P04aD0014A000B3`003``000`8000;1P002PP0010:
0080514000<05aD001lR000P9P000P0Q9P006`0Q:@008bd002@/000S;P00:C4002T_000^=000;cP0
02lj000a@000;T80038n000`>000;CL003@i000e?`00=dd003Q;000kBP00?U@0041G0011G@00?eD0
041D000kC`00=d/003]B000203aC000503]:000nBP00?4/003YA000mEP800P0mF@@09`12HP80?680
041R0014GP00BFH204QP0@1<H@00Ael104IO0@18I080AFP204Q^0@17KP00CG80051/001AM@00CVd0
055`001CM000DG`004ml001BN`00DgL0055a001>LP00Dg/005Eb001HM`00FGD005Yn0@1MOP00H7X0
05ic001OM000GgL006280P1MQ@<0H8D1062;0@02066A0@0W06JI0@1UV040IiL106VF001ZW@40Kj41
072U0@1/YP40JZP206R]0P1V[@40J[0206f_101]]@D0LKD407:`0P1d/000M;41072g0P1]^`P0K[`6
07>k0@1`_P40K/4406fn1`1^_PP0Jkh306c00P1_`@D0Kl8507G00`1i`0l0NklA08715P26`1h0RL4I
09;1602D`QT0Ul8L0080U/4L02L0V<<L09G7702Ba1h0Rl0Q08;07P23`R00Pl<O08C27@27`QT0SKdN
092n7`2C`a`0T/LN09?<8`2>bB40SLLT08c48@2>`b<0SL@R08[7602@b1L0U/DD09?54@2BaA00TlH?
09743P2@``d0TK`<08ni2`2?/`T0Sk<708bi1`2;_@H0S[`608bj2@25^`X0QKd408700@24`0<00P23
_0<09`26]`80Q[T508Ro401ocAh0NM4M07KA6P1ddAd0LM@O06gF9P1WeRD0J]@M073A7P1`dAX0KlhE
073<501acAX0M<XQ07S?:P1dbQl0LLPE07[13P21^@`0Q[0208FY0027X`00QjD008FQ0029WP00Qil0
08^Q002;Y`00RZL008RN0028X000RId008BM0023W000Q9L0082I000207bJ000W07nH0020V@00Q9P0
07jH001nU000P9@007j9001nS000NXX007N<001gQ000MX8007N6001fR000LH4006j2001aP000L8@0
0723001^O@00L7/006]d001XL000IW8006E[001OH`00FeT005II001DEP00Ce0004Q:000m@000>3H0
038_000/9@009B0001dE000@3@002PL00080108000<00@00000000000000R`00000<0?ooo`002P3o
ool0500E8@005Qd001DI000E5P004Q80010@000D50004Q<0018B000G50004aD001<F000D5P004A<0
018?000@2`0030T000/7000=2P004A000P0I6P009`0L8@008B/0028b000Q<`008S8002<^000U=000
9CL002Ll000Z>@00:S<002/d000^=@00:S8002/d000Y<`009bl002d`000/=000;ch003=0000iC000
>dX003U8000lCP00?E80041A000mC@00>Dh003I=000fB`00>U@003UB000jD@00=DD003E1000jB000
=d@003a80@0203i<0P03041K0@0oG@00@V800080@Ed00280BF@104UQ001:I000Aed004QM0016G`00
Af/004I]0018K`00BVX004i`001>K`00CWL104ei001=OP00B7l0055o001BN`00DWT0055h001@O000
DGP005El001FNP00F8L205Z8001MQ@00GGL0065c001PNP00GXL205j6101SQ@40HXX00P1TT@409`1T
T`40IIL106:G0@1RW@40IZ<206^Q0P1_Y040KJD006bV001XYP40J:`106ZZ0@1Z[`<0KK@5072`101d
/080MJ/107B]0@1`]`80K;P606bi1P1d^040MKT1072l1@1]_0L0K<4706nn1@1b_080M[`407Vn1@1h
`@@0N<0307c2401k`a<0Ml4F08C05P2;a1D0R/@L08g4700208k46`0V09Jm7P2E`1l0TL8O0930902<
`240R/0N08W17P25`R00R<0O08Rl7@2<`1d0T/LH09G:7P2Aab<0RLLR08_77@28a1/0R<LH08W65P2:
b100S/4>09>i3P2C]`H0T;T208bj0@2=^@40QkP108Zg002;/`00S:X008fV002>Z`00S[4108bg0@2:
]P40R;L208Ng0@26^@0308Bk0P0O08Bc0P25]040Q[d<07o54P1jbQ@0MLdF07;<6@1acR00KM4X06S?
9`1[cb40K<hT06c;9@1/bAL0L<PF07;:7P1hab00N/<N07c03`1o_0`0P[L708>f1026/040QJ`008FS
0026XP00QJ0008VQ0027Y000RZ8008VR000208VP000608RP0026W@00Q9/008>I0023V000PY`00P1n
VP000`1kU`00OY8007jB000207^D000R07n?001kS@00O8/007b7001fQP00MXL007N2001dP@00M800
0720001_OP00Jg`006en001/OP00K7D006ee001XM000IW0006E^001RI`00FfH005EM001?EP00C580
04E70013A000?3X0038^000V8P007aT001H>000=1P001P80008100800@00SP00000<0?ooo`002P3o
ool0500?4@004QD0014@000A3`0040`000d:000A5@004A/0018L000G8P005al001PM000E6@004Q<0
010?000?30003@`0010>000A50005QP00P0M8P009`0R:`008S40024d000Q=0008c8002@a000U=@00
:3h002M0000Z?000:SH002Pc000X<0009RT002HW000X9@009RL002Xb000[>`00<DD00398000cA@00
=dP003E6000hAP00>DD003Q3000fB000=4`003=A000`D@00=UD003=A000aBP00<TD002m2000fA`00
=D@003Y5000203i:000F049H0011F`00@5`004=O0013HP00AVT104ET0017H@00AEX004=@0010D000
@Uh0041S0013I`00A6P004Qa0017L000A78004Ah0015N000AWl004Un0080C88000l0Cgl004mi001B
N000DW/005Ak001DOP00FH`005^8001QO`00I80005j50@1PS080HH/406><0P1TS`800P1UU@<09`1V
U0<0I9T306>N0`1RX`<0HZD306F/0P1ZZ`40KZL0072W001^X000K:@106jT0@1/Z@80JZH306jX101a
Z`<0LZT107BZ0@1dZ@40M:h207B`0P1gZ`40O:X107N_0P1a/`@0KK/6072l1P1d^PD0M[P207Vi101i
_@<0Nk`307g04021`1@0NkdG07k06025`aT0O/DK08756`0208O16`0W08bk7P2<_2<0RlHT08g49P2C
`RX0UkdW09Bm8P2@_200R[/M08Zj7@2<`1h0T<PJ0978702?aQh0SLXH09344@2:_@d0R;h;08Nn3@29
^P`0Rk@308b/0@2?[080RK<308Rh0P28^@40R;P108Zb002;/`00RjP008fT002>XP00SjH008Ra0026
/@00QkD008Vc0029]P00QkP00080Qk@102L0RK8108:b0@1n_0@0NKl:07W1301h`@h0MLD@07?7401d
b280LlPX07?98`1`cRD0KlLO07;0501e_@d0N/4@086l3`23^@d0Qk4508F_0025]000Pk8008Nc0@26
[@40QJH008FP0025W`00QZ0008RR0028X`00Qj@008NV0025Y`00R:P008RT0027X000QIX008:I0021
V@000P1mVP009P1lUP00NY4007R=001iS@00N8l007R>001jT000NHT007V3001iQ000Mh@007V6001c
P@00LWl0075n001^N@00K7/006]k001WM000Ifd006Ma001VM@00IG8005mX001LI000Ef4004iM001<
E`00B4d00450000m?@00=c8002XU000N5P0050d000/600040@000@00T@00000<0?ooo`002P3oool0
1`0920003@`000`:000:20003@`000d?000A7P000P0>9@002`0G:`005RL001HP000F6@004Q0000h;
000?2P003P`001HG000I7`006R@000808C4002L093D102@e000Q<P008C0002<b000U<00093@002Li
000W>0009S<002D/000S:0009BH0024Q000R8@008bD002DZ000W=@00:Sl002]6000bB@00<4D003=6
000c@`00<dH003E3000c@P00=Dd0039C000aEP00<EP003AF000aCP00<T@003M4000d@@00>4X003M;
000kD0000P0oC`009`0kD000@5X0041M0015HP00AV<004MU0014H`00AV@004AL0012D`00?4l003aE
000kF@00>E/003eW000lK@00@G@003ei000jO000?G/004Io0019O`00C8@004^3001>PP40DGh105>1
0P1BO040EWH005Id001IQP40EH`105j=0@1QRP00Ghl105Z=0`1HT`@0FY84062H1@0206>M1`0W06>M
1P1SWPH0HY`4066R101OX`D0HjT206FW001/Y`00KZ<006fP001ZX`00K:<106VW0P1ZX@<0Kj@407:T
101`Z@80LZP2072W0@1aZ`40M:T007JW0@1lZP40NZ`107Z]0P1e[`<0Lk@407>i1P1e^PL0M[T607Vi
0P1l^P<0N[l?07W14@22`1L0QL0L08G07P1o`200O<@R0080QkdV02H0RKPU08fi9@2:`2@0SL8Q08no
8@2C^b00UkXQ09>i8@2<^2D0S<0O08g45P2<`a<0SL<B08c23`2>`0d0S[T908Nf0P25^0D0Q;T<08Fe
3@23/0@0PZX208F`0`1o/@<0OK@207ji0@24^`00RKD008Vb002;[@00RZ@108VO0P2=X@40R:X008Va
0027/@00Rk@008^b0@<0Q[<102L0Q[41086_0@1o[P<0NkH507nf0`21]`40NkT307bl2@1o_A40O/<B
07k3401na@l0P<0>07jg2P22]0@0O[8608>`0`21/040PZ/0086[0025[000QJd008N^0025ZP00QJ@0
08JN0025V000QiD008VI0027WP00Q:8008>S0021Y@00PjD008FR0025X000Pil0082N001mV@000P1l
U@00201kT`00NHh007N<001iSP00Mhl007V>001fS`00MXX00P1gQ`006`1hQ000LX@0075o001_O@00
Kh0006ei001]NP00JWd006A^001OKP00H6P005iX001OK000FF@005MJ001@D`00C50004M;0013A000
>CL0034/000W8@007aL0014<0008100010400080002B000000`0oooo000:0?ooo`0D00D400092000
1`D000L5000>3@003@l000dD000?9`004B<0018O000G8P005Q/001<E000?3@002`P000`9000>3000
4Q@001XW000J;P0201df0@0D01df0P0M<@408S4001h^000L:P007b`001lX000R9`008bH001hQ000P
7P007Q/0020N000Q8P008BD002<Y000P:P00930002Lg000Z?P0202m7000A0315000aA@00;TH00319
000`BP00=5<003=F000cF`00<UX0035F000cC`00<TT003Q4000e?`00=dH003]:000jC0000P0mE000
9`0lCP00?EH003mK0011HP00@f0004IM0015HP00@VL004=S0@10F`00@UH003iH000jF`00>El003QW
000iJ`00?GH003Uk000fP@00>Wh004B10018P`00CXL004n90@1CQ`80D8<405>51@1HP0<0EgT105Ie
001HP`80EHT105VE0P1FU`80Ei/305RB0`1EV@<0DYL405VL1@0205fP1P0W062S1P1PX0@0H9T206:H
0P1TV0@0II/206FM001YY040K:@006ZS001VX`00HjP006F]0@1/Z`40L:P2076Y0`1bZ0<0KjD106bY
0P1ZZ040KJT007FZ0@1iZ040Nj`107^[0@1iZP80Lk4607:j1`1`^@/0LkL807Bf0`1g^`<0ML4>07?1
3`20_aT0Q;dM08Bl8P1o_R@0O[lW0080Q[/X01P0R[PT08Jk8P2;`2<0Sl<N08O67@28bAL0RlHG08c4
5@2:`140RKd?08Fl2`26/`T0Q[H408Ng0P2:/`40Rk0008bc0@2;/`80R;H908Fa3025/@P0PZd407jb
0P20/`4207nb000=08Fc002;]`00RKD008Na0026Z`80QZ@408JT0@27Z000QZ`008F/002:[040Qjd1
08F[0@0208J^000W08B/001lZ`40NjD107bW0@21[P00P;8008>^0@22[P40QZl408>c1025]`@0Qk@3
08Nb0P23/`40Q:`008>[001o[040NJ/107jX001oZ000PjL008>V0028Z@00QZT008FW0028W`00Pi/0
08JB0025UP00Q9T008BO0023V`00PiL0086I0022UP00Q9P008>J0023V@00P9L00080OI<00280Nhl0
07^=001kS000Mhl007R<001fSP00N90007><001fS`00Mh/007J5001cP`00KGl006mm001/OP00KG/0
06Yf001VLP00H6l005m]001KGP00F5`005MN001BF@00CeD004U;0015AP00@48003di000_:@008Ad0
01L>000=1`001`<00P01002C000000`0oooo000:0?ooo`0D00<200061P001@D000D5000<3P002`h0
00/B000@80004A`0014G000E6@004A@000l>000<2P0020H000X7000?3@004QL001LW000F;00201H]
0@0N01P[0@0H9@007B/001XY000G9P006R@001TN000J6`006AL001LD000G4`0061L001TL000M9`00
7RT0024^000O:@0072X002<_000W<P00;Cd002Tm000[@@00:dH002]9000ZC000;4/0039=000`D000
;e000P0`D`001`0dD`00=4X003M4000g@P00=dD003]:000kB`000P0oD0009`0kC000?UD003aL000n
IP00@680045Q0012I`00@6X203iY0`0mI@40?F4003aO000oHP00?FL003i^000lKP00@7@003mc0011
L`00@78004Ik001<P`00C8`004j<001BQ@40DGl305B00`1EPP80FGh005R0001GR040EHX105JG0@1C
W080EIl505JI0P1HU@40F9<205^G0`0205RL100W05NT101IXP<0FYX105b?0@1RS`40I9H106BG001R
Y040IJ<106ZQ001TX`00HZ/106B_0P1[[`40KZ`206fW0P1_Y@40LIl206jQ0P1YY@40JjL106jX0@1`
Y000M:P107RZ0@1jZ@D0Mk89076c201a/`L0MK4507N_0P1e^0<0L[D407:k3P1e^A`0N;<K07Ff7P20
_B40P;lS0080Ol0N02L0R;lK08Bl702;`Q/0SlXH08S84@26a@h0Qkd<08Nj2P26^PD0P;P307bd0@22
[040QJ`008N]0026Z@00QZP008ZY0028Z`00Q:h408Ba1P2:[`X0Rjh508Ba0P23[`40QJX008FX0028
Z`00S:l008^c002:/P00QZ/108>X0@22Y000Pj@008BT0024Y@00QjP008>Q0025XP000P24Y`005P21
ZP00OZT008>W0022X`00Q:D008:Y0025Z000QJT008^V002=Z@00RJ/008Z^002:ZP00QJX008NX0022
Z`40PJ`007R[0@1oY@00P:@008:S0024X`0208RW000508FZ0025X`00QY/008BH0023UP000P23V`00
2023VP00PIL007fC001oSP00PY8007jB001mT`00OYD00P1mUP001`1mU@00O94007Z>001iR`00MHT0
07N;001dSP000P1bS`00601`R`00LH@00765001]P000JW/006]g001ZL`00IVl0065V001OJ000GfL0
05MM001DEP00CDl004]?0018C000ADP003i0000i>000=2`002LM000J4@0030<000<109H00000303o
ool000X0oooo01@00@400000000410001@<000T<00092`002@`000lF000>4`003Q4000h?000=2`00
2PP000P500070`001P@000lA000@6`004bD001<R008051`001005AT001@G000C5P00524001<O000E
8@0051T001<C000E50005A4001DB000F5@006AX001/W000J9`007b/00P0M:0001@0S<0009Bl002Pk
000U>P00:3T00080:dH000h0;4<002Y1000[?`00;d8002m3000aA`00<dd003I?000eB000=4D003I7
000e@`00>4T003U80080?Dl002L0>Tl003aI000kH@00>VL003mY000nI@00?6H103QW100fK0H0=FP2
039Z000aI`00=VD003YZ000kMP00?G@004Aa0016JP00A6P004MW0016KP00CWT004il001BPP00D7/0
051j0@1>NP40DX4005An001DP000E8@005><001DT000E9X1056O0`1DVP40Ei@005N;001ET`<00P1B
UP80301AW`@0E9l605VM1@1IV0<0H9<0066D001PUP00H9`106>J0@1XW@00I:0006RU0@80JjL10P1X
Y0805`1ZX040J9`106bK0P1[V@40L9d2076U0P1_WP40LjD107FT0@1hY`D0N:h607F/1@1f[P@0M:T3
07NV0`1gZ`80LjX307:e301d/a80M[4A07Jf5020`1/0OlDD0080P<LA02L0QlH@08K33`28`0h0QKX=
08>i1P24^P<0Q[P208>e0@24]@40OkH1082_0@20Z000PZH0086V0023YP00Q:<008NP002;XP00RJ`1
08V`0P2</P80S[4208N/0026Z`00QJ@008JN0027X`00RZD008^Y0026[P00Q:d0086Y0021Y000P:40
086M0025W`00Qj4008FK0024V0000P27W`003@27YP00QZL008RZ0025YP00Qj@008JT0028Y@00QZ@0
08ZQ002@X@00SZD008VX0027YP000P27XP006022Z`00P:`007^Z001nY`00OJ@007bP0020X000Q:40
08NR0025Y000Q:00086M0021U@00PY4008:D0021VP00Q9T008>I001oT`00OHd007nC0020U000NY@0
07^B0080Ni@00200NiX007ZJ001eT@00MH`007N9001gS000Lhl006n;001]S000KH<0071n001[O@00
Jg`006Ye001WKP00I6/0065]001KIP00Ff0005QM001DEP00Cd`004I40017AP00@dH00454000i>@00
;bX002PM000K40003PL000D109L00000303oool000X0oooo0P00000200<2000@008100061P001`H0
00H6000;2P002@T000X700071@0010<000@100040P001@D000`C000<6P0031T0010H00803Pl002L0
3`/000l=000>50004al0018L000E7@0051L0018B000F5`004a@0010C000G60005a/001XQ000H7@00
5QX001`Q000M9P008Rl0024b000O=@009Cl002Hk000/@@00:c`002Tj000Y=P009SL002/k000/?P00
<DH00399000`C@00=4T00356000cBP00=DH003I8000iB@000P0hDP009`0gDP00=EH003QW000eJP00
?6T003aR000iG000=ET203ES0`0aI@40;VP002iY000aI@00=FL003MZ000kM000@6d004U]0017J`00
BFP004QX001=K@00CV/005Aa001CL000EWT0059i001BOP00DW/005=m001CP000E8T005J9001ETP00
D9H1056G001ATP00E8d004f6000204b>0P0W04ZH1`19W0/0CYh;05JJ1@1NU`00FiL005RD001IT000
H9<0066C001TVP00Iid006RP0@1WW@00HiP1062H0@1QT@00I9L006^H0P1ZU`<0L9/4076Q0`1`W@80
M9X007FF001fWPD0M9/107:Q0P1cY@@0LJL407>T0`1eX`40M:H207F[201iZPL0O:h707nc3`1j]P/0
Ok`<0080Ol0;02L0O;d907^m201l^@<0Nk4207fc0@21/P80P[D208:a0`23/`<0Pk02082_0P1nZP40
OZL0086T0@24Y@00PZL008JQ0029X`00R:X008Ra0@29/P00RJl008R_0026ZP40Q:00086Q0024XP00
QJ0008JR0022ZP00P;00086/0025YP00QId008:J0023W000QYd008>L0021U0000P23T`005`28X000
RJ@008ZW0027[P00RJX008NP0028W`00Pi`008NP0028X@00RZ8008RT002:X`00QJ0008NO0029XP00
RJ@008:X001oY@00O:<007fL001oVP00P9X00080PIT000X0PY`0086N0024V000P9<007bA001lUP00
OYD0082I0020U@00OI@00P20UP00901kTP00Mh`007V@001iT000NID007ZF001iU`00MY0007J;001c
R`00L8`006f=001[S`00JhH006Z1001VNP00HG<006E^001RJ000GFT005iX001GH`00EUh004iI001<
D000ADD003lm000m?@00?3T003Xk000c<P00928001LC000>20001@80004009L00000303oool000X0
oooo0P000003004000800`8000D00`4000H400040`000`8000810002004000060081000410002P/0
00/=000;300030/00P0810002`0;2P002`l000`G000C7`004Q/0010D000A4`004@l001DG000C5000
4A@000805Q/000/06R0001LJ000D5`006R0001XT000P:`007b`0020b000U?P008cT002Pl000202Dh
000=02Ll000X?@00:d8002]3000`B000;TT002a9000]B@00;DP0035:000bA000<dL00398000202m9
000W035A000^E000=F00039R000fH@00>ET003QA000dC@00<Dh002iH000_G`00=F8003QO000kG000
>5/003iW0010J000A6l004A/0014J@00@VL004QZ0@1:IP00CfL004eX001BM000Dg80055c001>L`00
DGT004mk001>P000Dgd005B5001BR@00Chd0052>001ARP00DH@00080Ch/102L0BXd704^D2`1;UPX0
EHl205b?0@1IT`00F9@005Z=001OR@00GXX0062=001OSP00HY8006:E001NT040HXd106>2001WRP00
J8h006fG0@1ZWP<0J:0306ZL0P1]U@40Ki0007BH0P1cU`40LYd107:K0P1dY0<0MJ@207:T0@1aZ@<0
L[0307B`0P1i/P80Ok0307n`0P21/`400P1n/`<09`1j]PH0M[T607Vf101l]@80OK81082b0P1o/P80
Pk@408:d1021/0D0Ok8:07b`1P1kZ@40P:@008:V0022Z@00PZL007jV0020ZP00Pk81086b0025/040
Qk<008R]0026Y`00Qj@008>N0020W@00Oid0086T0021Z@00PjH108JU0029W@00PiX008:M0024X000
PJ0008FI000208FC000S08FF0028V000SJD008V`0026Z040R:0008ZM0027V`00Pj40082R0022W@00
PI`008>O0023WP00Q9/008JH0029W000RJ0008NN0022WP00Oid007jH001mU@00Oi0007bA001oT`00
OiH008:G001nUP00NiH007NC001gUP00N9/007^G001mT`000P1oU@008`1kT@00Mh`007N=001gS@00
NY4007^C001iT`00MHh007>8001aP`00L8H00729001^R`00JXP006V6001SN`00HW4005iZ001OI`00
Ff<005YP001HGP00De/004aE0019C@00A48003hk000d<000<2/002lY000V8P006aL000d;00050`00
0P0009P00000303oool000X0oooo1@00000200410004004000020@000@00004000<0000000H00@00
008100040`0010<000@200071P0200<2000W00D4000;50002aP0014K000?50003@d0010?000>3P00
3@d0010C000>4@0051X001HH000E5P006A/001HK000L8`006RH001XW000N:P007R/0024g000P=000
838002@h000R?@009dD002Q7000/B@00;4D002e1000Z@@00:48002Y3000X@@00:T8002a0000/?`00
:d<000809DD001809TP002Q;000aF@40;UD203AH0P0cEP80<T/102m4000X@P00;T`0035@000hF000
=e@003UB000iD@00@EH0041N0011H`0203iS000C049Q0018IP40AVD004]W0017J@00Bf`004]X0@1<
I`40B6X004]a0014L@40A78104I`001<N@00Bh8004R5001;PP00D8@005:3000205:8000W04n60P1C
R0@0DXP305F7001CP`40DhH005N7001JQ000Fh800621001QPP00GWd005f2001LP@00F8<005b3001O
O@00IH4006^7001`TP00K98006RI0P1VW0<0J98106f>001[T040LYH007>L0@1eW`40MZH207NT0P1i
YP<0N:P107VW0@1g/@80O;D207f^0P20/080Ok410080Ojl202L0O[8307jh0`1n]`80OkD107nc0@22
/`40P[8108Bd0@26/PD0P;4:07bf301l]0T0Nk4207f^0@21[000Ojd007fX0@1lY`40O:X207f_0@1j
/`40PK8108J`0@2:/000RJX008RU0025X`00OY`007bP0@1kXP40OZ@1082V0@23Z000QJ@008JQ0028
Y000QZ<008JV002:W`000P28V`009`26V000RIP008bO002;Z@00RZX008FU0028X000QZ0008FN001k
V`00NiX007ZK0020V`00PI/0082H0021T`00R98008FC0024V@00PIT007bG001nT`00OI0007f>001k
SP00NhD007Z9001kU000NY/007RJ001dU000MIL007NH001iU000NY@007VA001lSP00NY0007RB0002
07N@000N07Z=001hT000MY4007F=001cRP00L88006b0001[Q@00JHD006R4001UPP00HWT0065c001N
J`00G6L005aT001GFP00DUD004eH001<DP00Add004E6000k>`00;bh002LQ000P700061@000l=0007
1P000P40V@00000<0?ooo`002P3oool800000003004000000000000000H0000000<00@0000000006
2@000P0410009`051`0031L000`G000=4P003Pd000/8000?4P003Pl000d<000?3`003Pl001<E000C
4`004Q8001LL000C7`0062X001PW000H9P007bX001XW000M<`006c8001db000S=`008CP002Dn000V
>P009SL002Lk000W=@009CH002<f000U>`009CP002@d000W=@00:38002Hk0002024n000W0290000T
@P00;D`302]<1`0YCPX0;4h<02Q81`0RA@807d0102Q7000^C000=E@003M@000jC000>4D003]<000g
DP00=e4003QH000jE`00@EH0049J0018H000B5h004ES0011HP00?fD203iS0`12J080@fP003aV0@0h
H000?fT003i_0012O000@7h004Qk001?O@00Cg/00080DH4002L0Cgh00522001@P@00E800059o001A
OP00EWT005Qd001ILP00G7D005Yk001DMP00E7X105Ik001EO`00DW`005Z0001QP`00IHT006Z@001^
T000KY@006nL0P1_U@40LYH106fG001_V`00L:01076S0@1dYP40Mj@207NU0P1jY@40N:H107J]0P1i
/@80O;4307f_0`1k[0<00P1nZ`<09020[`@0OK03082f0P1o]@40OKH007fd001n/`40O[H207jd1021
[PH0O;@707Vh1P1j]`D0M;H307Rd0@1l[P40NZh107RZ0P1g[040NJd007V^0020/000Pjl008F`0029
[`00QjP108BV0@1nY@80N:8107BR0P1hX080OJH307j_0`20[@40Qj/008NV0080Qj0002X0QZ4008NP
0027X000QIH008VC002=V`00SJ<008bY0029[000RJ<008JR0021W000O9@007fD001iU@00OI<0086G
0023U000Oi<007nA0020S@00Oh`007j@001lSP00NY0007b>001mSP00N8h007N7001cR000NIH007RP
001gX000M9/007BF001cU000MY@007JC001fSP00N8T007N=001eT`0207FB000A07F:001dR000M8P0
06n9001_Q@00KH0006]n001ZOP00J7l006Ao001RO`00Hg/0065d001KK000FVD005QR001BEP000P1;
DP002`18C`00B4h00497000h>000;BT0020J000I4@003`X000X500040P000@0009T00000303oool0
00X0oooo4@0000000`01000000000000000200D5000W00D6000;40002`l000X:00091P0020L000dA
000<3`002P/000d=000<2`002PX000d?000=40004R0000lR000?7`005BL001HR000K9P005R<001@Q
000I:0006R@001h[0@0L9P007RX001dW000I8@006bP001XV000M:@007BL001`S000P9`007R8001lV
000M:00083H000807CD002L083`002<o000S@@@08T`;021:3P0OCA@06d`<01Q;1P0IB0<09T/102U>
000`DP00=4T00350000e?P00<3L00392000aA000=Dd003A:000iC`00?E8004AE0013EP00@Ud003iJ
000jI0@0>FH4041X0P0nHP00@64003QM000nIP00?f`004Ad0013L@00B70004i^001@K@000P1=K@00
9`1>L000D7D004ie001BM`00DG8005Ig001GM000DV`005=V001GJ@00EW00059d001?O`40Dgl105F3
001FP000GXD005n5001OS@00Gi<006JB001]UP00K9T106fP0`1`X@40KZ01072L001`VP40Kil2076Q
0@1dX`40MZD107FU0@1g[@80MZd107F]0P1f[P@0Nk4407Z_0`0207ZZ0`0W07b`101o[`<0P;8207nh
0@1k]`00MkL107Rb001i/P40OK0207b/0P1n[@80P;4407be1`1k]@L0O;8407b/001o[P00Ojd207f/
0@1m[@00Oj`0086[0027Z@00Qjd008B]0@26ZP40PjL108BV0@1mY080O:<307^Q0`1kZ@D0Ojh608>a
0P28Z`00RZ<008RJ0022W@40QZ800080Qih002L0QIP008:C0028S`00RiD008^Q0028Y@00QJD008:S
0022V@00Oi<007j=001kR`00N8D007^:0020RP00O90007b:001lQ@00O8<007V3001eQ@00LhH007B7
001hR`00N8l007N6001iR@00NIP007VS001fX`00LIh0076H001cU@00Li<007B?001bS000MHT007>8
001bRP000P1cS@00201`R@00KX<006em001]PP00J7l006]n001YN000Ig/00P1UN`004P1PN@00GGT0
05]d001HI`00EF40055J001@E@00B4l004E;0012BP00?TD003Xn000c<0009b8001XC000=20001P<0
00<109/00000303oool000X0oooo500000020081000M00<100071`001`H000D300060`001@D000D6
000820001P@000T700081`0020H000`;000;2`003a/0010K000?6`005240014K000E7@004AD0010A
000C5000410001HH0@0C50004A8001@J000?5P000P0C7P00200G7@005QX001<F000E6P004aH001@L
000E7`006S400P0J=0009`0L<P007ch001e20P0NC@@06d/601m9200JB@T06DX801a61P0R?@80:D00
02/j000]>`00;ST002ll000Z>000;3`002a0000aA@00<DH003E9000eC@00>Tl003UE000jG@00>ET0
03YM0P0iGP80?V<003YK000lFP00>UD0049L0014G`00BF@004UR001;H@00BV8004aR000204YN000W
04QP001:H`00CFD004eS001>I`00DFh105A/001AJP00E6<005IT001BJ@00E74005=d001@Q@40D8T1
05F60@1NR040HH`106:<001MS`00HY0006FD001WU@40JYl206fP0P1]X`40LJ4006nJ001bW000LI/0
06fR001aYP00LJL1076_0P1e[`40MJd107B/0@1f[080M:h30080N:d302L0OZd307f`0`1o/080N;81
07Fc0@1f/P00NZ/007bY0P1mZP<0OJL407jW1@1nY0H0Oj@607bZ1`1i[@@0OZT107n[0@20Z`40PJT1
08:X0@24Z@40QZ<008VR002:Y@00QJH008:W0022Z@40QJT108FW0@20XP80OZ@207nU0P21Z@<0PjX1
08BV0029X`00Q9/0086J0023V`000P23W0009`21U`00Ohd0082:0023RP00Q9L008BP001mW`00OI/0
07fD001nT@00P8L007Z2001gPP00NHT007Z7001iR000N8<007R2001fNP00MGd00722001_QP00KX@0
07>7001fRP00NXT007^?001jUP00NYd0076Q0@1[X@00LYH007BB001eT@00Li0007B?001dSP00LXH0
06^4000206b7000K06Z9001XQ000J7/006Ql001VN000J7L006Qe001VMP00J7X006Ii001LL000FG<0
05I/001DHP00DV40051G0019D@00@dL00412000m@000=cX0034b000[:0008A`0018<00050`000P40
09`00000303oool000X0oooo600000020081000400D600051000108000@200800P0000<010<000@2
00081`000P061`00600<3P003A00014E000?40002PT000`?000920002PX000L5000510002@L000P6
000<5@002a<0014L000@6@0041@0018D000B4`0051P0014C000D5`004AH001<N008062l001@06300
01`l000K@P0064/001Y:000QA`408T8201ho0`0R?`<08cD102Ha000V;000:C@002Pb000/?`009D00
02M1000Z@`00<DH003940080=4L00140=dL003M?000dF@00=5P003MF000hE`00?Ed003YI000kF`00
=E@003UC000nDP00A5H004IH0017FP00Ae/004ML000204ED000W04=D0013F@00AE/004UJ001:H@00
CF<0051Y001=I000DF<0055U001DJ@00Eg0005Eb001CPP80ChP105:?0`1KT@D0GHd306B80`1SRP@0
HI0205j@0@1RTP40Hih206>R0`1WY@80IZ8106bO0@1]V`40KYX0072N001^Y000KZH106n]0`1`[@80
MZh107F[0@1a[040LK030080LJl202L0N:l207b]101k/PD0M[<207>c0@1j[P00OZ<007fU0P1lZP<0
O:T407bU1@1jX0D0NYh207NU0`1eY`@0MZP307ZY0@1nYP40PZ4008RR0@2:YP40RJ<008VP0027W000
QJ0008:R0021YP00PjP108R/0028Z000QJD008BS0023W`00Pih0082N0021WP00PId007fH001mU@40
0P1mTP001`1lS000OHP007f4001lQ`00Nh/007ZE001kV0000P1kTP007P1jS`00Oh/007^<001hR@00
M8h007R6001gPP00MX8007R3001gOP00MW`007F3001dR@00L8d007B>001iSP00NY4007^?001dT`00
MiT107FR0P1/W`40LI@006nC001aT`00LY80076E001cT`00Lhd006n60080K8@001/0J8T006J5001V
PP00Ig`006Ae001VM`00I78006Ea001VL`00Gg4005][001GJP00Del0055M001=FP00AeH004=?000k
@P00=S`003Dk000^;`00:RD0028O000E4@002PD000<100010000W000000<0?ooo`002P3ooolH0000
0006004000000000000000<300010@000@000P0000000`020@00000000@3000200<2000:00H30006
10002@T000P7000610001`D000@3000610000`<000<2008010@000`02Pd000X<00092`003Q8000d?
000A5P004AT0018K000@5@0030h0010A000?5P0201HW000W01LZ000J=@006C/001]6000JA@0073l0
01lm000M>04093L102<b000V;@008bd002Pe000V<`00;44002Y3000/A000;DD002e4000^B000;T80
0355000bA000=TP003=?000fD@00<e0003IC000fE000>EP003IJ000gD`00=dd003M9000iA`00@4d0
04=?0018F@00AeT00080AE4002L0@4l003mA0011D`00@UL004IP001:I000D6`004iR001AI000DFX0
059Y001CJP00D6X005Aj1`1BOP80EHh405>>1`1FT@X0G8X;05f7301PR`D0GX`206:?0@1PUP40H:<6
05jX1P1MY`@0HJH206ZP0@1]W000Jid006NM001]Y@80LJd7072]1P1f[@80MZl207B^0P1_/0800P1]
/P<0201e/0<0N;8407Fb101b]0<0LK<1076a001h[040N:d20P1h[`807@1iZ`80NJ@307FQ0P1dX@80
LZD207FW0P1jZ@80O:T0082W0024Z040PjX108JW0025XP00Q:0008FQ0021X`00NjD007jV0026Z000
RJH008ZT0027WP00PIL0082B001mTP00OiL007fM001nV000OI400080NHT002L0N8<007R0001hP000
M88007:3001bR000MX`007Z<001kR`00NXl007f=001nR@00NHd007B@001bR000LX<007In001iQP00
MhD007>1001bP000L8@0072;0@1gS@00NXh007^@001hS@00Lhd006n@0@1_UP40K9P106ZD001ZT@00
K94006f>001aT`00LY<0076@001`R@000P1]Q0006@1YP`00IXH006:8001PP000HWH0065d001RK`00
HFh0061/001KIP00FVD005MV001=F@00CeL004MF0012C@00?DL003Lk000b=000;bd002LS000N5`00
50h000X600030000WP00000<0?ooo`002P3ooolK0000000300410000000000000080000000<00@00
0000000000000`0200001@0100000000008100010@000P4000800000010010@0008200061P001@D0
00@300061P001@@000X=000;3@0041P0014I000?4`003Pl000/8000>3`0041D00P0F8`009`0G9@00
734001/b000J>0006ST001Xd000M=`006c<001hd000Q<@009Bl002<_000V>@009cL002Tk000]@`00
:d<002i3000/@@00:dP002]6000^B000;DH003=5000bAP00=DX003I:000eCP00=T/003Q>000fD@00
=dh003I<000fCP00>4T003Q6000mAP00AU<004=J000204=F000W045>0011C`00?Th003mF0012GP00
BF@004m]001BH`00DVH0055X001@I`00C6@004eT001@L`P0EWD205Mn0P1CP`<0DhP605J5201KP`T0
FhD505j<0P1PT@40HXh106BK1P1SY0@0GJD506BU0`1VX@40J9h106^L001ZWP00KYl1072O101aZ0`0
Lj`:07F/1`1fZ`@0Lk830080Kk4300P0MK4407>c0`1c]P<0Lk@7072d101//`40Kk8107>_0P80LZl1
00`0LJl1076X0@1eY@40L:D106fV0@1cZ040NJP107fZ001k[@00O:`107f]0P20Y`4207bR000?07fP
001mX@00NJ0007jR0022W000Pid008FL0022U`00OI8007^;001fQP00NXT007^>001mU@00NY800080
N8d002L0MXP007>3001bP`00LH40079l001`N`00LGh007J1001fQ000MhT007b:001kS000NY0007J?
001fRP00LXT007F4001hO`00MX8007:7001cOP00L7d006f4001aQ`00MH`007J;001aR@00L8`006^=
0@1[S`40Ji4006^C001/TP00JhH006b9001/R`00Khl0076@001_R0000P1]P000601ZOP00JGh006>2
001SO000GgL005ec001OK@00GV/005UV001DH@00DF<0055K001:D000C50004=;000n@@00=SP0030_
000Z:0008b40020J000F3P0030D000<109l00000303oool000X0oooo:P0000004`01000000000000
00051@000P4000L800051@000`<000H700051P002`l000X=00092`003Q<000/<000;2`002@T000hA
000?5`000P0F:@406@0F:0405BP001T`000G;@006bX001/W000P;@007B`001`/000O;P007b/002@c
000R=`009C/002<l000X@P009d8002Y1000X@@00:DD002Q1000/A000;4<00356000b@`000P0d@`00
300fB000=D<003I2000eA@00>4d003I<000eD@00=Dd003Y6000h@000@Dd004=B0080A5D002L0@E80
049B0011C`00@eD0041H0013H040BfX104iS001AH@00Ced0055P001?G@00CEl004eP001BK@40DWL2
04ih0@1>P@80Dh4305Yn1@1IPPD0H8d3066?0@1TR000I9<406JA0@1SV0<0Ii`306fM0P1ZW040JYP2
06fL0@1[V`80LYH206nQ2`1aY`/0KjL707JV101bZP800P1d[0409`1e[`80L[42072b0P1c/PD0L;43
06^f0`1^/P<0L:`406jZ0`1_[@40KZh106j]0@1`ZP00KZT006^]001_[@40MjX107R/0@1h[P00N:`2
07RZ0`1oYP80O:8007NQ001hV`00NI`007VN001kW000NY@007ZA001iS`00OHl007b=001jR@00MH<0
07Eo001fPP00Mhd007RC000207FA000G07F:001cPP00M88007Im001bM@00KWP006ag001cN`00MGl0
07:3001iRP00N8`007^>001iS@00Mh`0072:001bPP00Kgh007=o001aQ000Lh000760001]PP000P1/
P@001P1_Q@00KhP006b:001/R@00JhL006V;0080KXh000H0JHL006R2001ZQ000KHD006n<001/R002
06Z3000H06V1001WN`00IgH0065c001MMP00F70005a_001HJ`00Ef<0059M001=H000BeD004Q@0016
B`00?d@003Ph000a;000:BD0020N000H5`00510000`800040`000P00W`00000<0?ooo`002P3oool]
0000000@00@400010000000000@300010@001PP000H:000;3P002@X000L7000:3@0020T000`=000:
2`003Q<000hE00803aX002L03bh100l^000E=@005R`001XU000I7@007RD001/U000J90007RL001dW
000P<P0083H002<k000S?0009ch002Dl000V?@009Cl002@n000U>@00:Ch002`o000a@@00;cd002lk
000b>@00<C/003A0000b?@00=dH003I<000gCP00=d`003Q<000iBP00=d@003m3000oBP000P10D@00
9`11D@00AE8004=?0011E000?E/103UM0`0mG`80Ae/104QH001>G000DE`0059K001AG@00DEX0051W
001>K000C7H204io0`1?O`D0Dgl705J2201LR@H0GXL20665001SR`40HXH106B;0@1XT040JYL106VG
0@1YV@80JIX606VM1`1/W0H0K9h406nL0P1`WP<0M:0207>Q0@0207JV0@0W07>Z0@1e[080LJh206n]
0P1/Z`<0Jjh3072a101_Z`H0K:X306nY0@1^Z`40MJh107B_001b/@00L;4007:b0@1f[@00N:h007^_
001m[@40Mj/107^X0@1jY@00Mil007JI001eU`00NYD007ZG001lU000N90007R;001iQ`00MHP007R8
001cQ000L7`0079n001`RP00M9400080M98002L0Mhh007V8001hQ000Mh8007F1001_O`00LGP0075m
001`O`00L84007>9001fR@00Mh`007B8001hS@00MH/007B5001^P@00LX8007>4001dP`00KH0006^0
001[OP00Jh8006^4001[Q`00KHX006Z6001YO`00Ih@006^;001_SP00JX/006Z6001YP@00JH0006ao
001[OP000P1XQ0005`1TPP00H7`0065f001PL000G70005U/001HK000EfP005=O001>F000BeP004UA
0013B`00?d<003Lh000c<000:R<002<M000J500040`000P600050P000@000:000000303oool000X0
oooo;@00000040020@000000000000030@00000000H800051P0010@000H400030`001`/000L8000;
3`0020T000H6000<400200dE000W00l/0@0@:`005C@001@Y000F8@005AT001HG000J8@00628001`X
000K9@007C4001dd000Q>P008SP002Hj000U=0009C<002Dd000S=0008C40028a000W=@00:34002dd
000[<P00:c<002hk000dAP00=D<003M8000hC`00>U8003I9000gA`00=TD003I1000i?`00?TD00080
A58002L0@UL004AH000mEP00?EX103eM0@0kG@<0?5`204AJ0@15F000BEd004]M001@IP00DfH0051S
001@HP00BF<104Q`0@19M`80CGP305Im101IO`H0FXH705b00P1PQ000GH0005im001OP000H8/1066E
0P1TV0<0HIL406>M1P1VV`H0Ii/606bM0`1/W040KZ8207:M0P1hU`000P1gX@409`1gZ080M:X306jZ
0`1]Y`80JJ@206VW0P1]Z080KJX306^^101]Z`<0LJ`107>/0P1a[040LZl007R`001h[@00M[4007Z`
001m[@00OjX007bW0@1lY040NJ8007JM001eV000MID007RD001jTP00MY0007F?001gS000LXT00726
001aQ`00MH8007=n001bN`00LH<007>8000207R?000H07V?001iS000Mh`007J6001gQ`00MX40075l
001_O000KGP00760001cP`00Lh/007F<001cR`00M8X007F<001fR@00LX@007>8001dR000KXH006^0
001WO`00JH000P1]Q`003@1]QP00KHX006V8001VP@00I7h006R2001[R@00JH/006Z9001YQ@00IWd0
06Mj001XN`000P1ZO`005@1QO@00G7T005Ug001JL`00FG4005MY001EI000DEd004aF001;D`00AU80
04190010@@00>3L002l]000W9P0081`001PA000=2@0020<000<1002R000000`0oooo000:0?oooc00
000000d00@400000000000000`80004100020@000@4000L<00062@001@H000L600030`002A400080
2aL002L04BP0014T000D:`0051d0014B000C50004AD001PN000F7`006bX001XX000K<@006c0001lf
000Q=0007bl0024^000P9P008RL001h[000O;`007Rd002<`000U;000:C0002/a000^=P00<cl003Y<
0@0eB000=4L003E9000iCP00=dX003U9000fA@00>3l003Xn000oB0000P0oD`009`13G000@Ed003eP
0@0mG@40@E`1045K0@10F@40@UX004AG0015F`00B5P0051W001>J000DFD004iU001:IP00BV`104e`
0@1?M@40D7H1051n0`1DQ0<0Eh4105b4001MO`00H7T0061g001RP@00IHl1066E0P1STP@0IIT406:I
0`1XV`80JY/206^N0@1`X040Ki/107NH0@0207JN0@0G07RR0P1hZP<0MJD306jQ101/W@@0Kil206fT
0P1^Y080K:T406fY0`1a[`<0LZX2076Y0@1e[@00O:d007R^001d[P00OZT0086X0021YP00Oj@007fU
001iW`000P1fU`003P1gT@00MXl007J<001fR`00M8T007J<001bR000LH@007F6001eR000LhD007Am
001dN`00MGd00P1kQ0009`1nR`00Ohl007R<001fR@00N8H007B1001bO000Kg/006if001cN`00MH@0
07B;001eS@00LHT00724001bR`00M8L007::001gR000M8T006j9001YP`00Jgh006n1001/Q`00KhT0
06^7001ZR000JHP006F3001QO000Hgh006F0001VOP00JH8006J0001XP000J7`006Qi000206Ai000D
05if001GMP00F78005Ea001FK`00DVD0059N0019D@00@dT004E:0010A000?3d003Pm000`=0009B<0
01`F000E2`002`H000D20002002S000000`0oooo000:0?oooc<0000000X00P40000000010@000@40
00000006200010@000H500030`002A@00P096000300:6@003aT000dA000?5@003@d0018F000@5@00
51d001@N000I:0006BT001LW00806BT001T07bX001dT000N:0006b8001PU000I:0007Rl0024_000T
<P0092h002T^000Z;@00<SX003A2000hB`40=DP003E3000a@P00<TP003A>000hD`00>d/003a8000l
A@00?dX00080?dl002L0@5H0045P000lIP40>VH1041P0010E`00@EP0045E0014E000AE<004E@001:
GP40CF41055W0@1BIP00DFT004mY001?K000DW@004ee001>O040CWd105B10P1HP`40G7h0065o001Q
O@00I8<106NA0P1PT080IY0206J<0P1RT`80IIH206RD0@1[W@40K9`006jM001cX0400P1cW0404P1e
X@80MZH207>V0`1]X@H0KId607BI0P1cVP40LY`207:O0P1dYP<0LZL2072Q0P1bW`40Mj8007VU001j
X`00N9l007^N0080P9d001<0OI`0082S001nW000Ni@007Z@001hS`00MHd007F;001cQ@00MH8007F5
001eQP00LhH007B9001bS@00MH@007Ek001cN000Lg/00080MG`000L0NH@007j<001kRP00NHH007R4
001hO000LW`00080LW/001h0N88007V;001cT000LY0006n4001]P000L84007>4001eR`00M8P007::
001/R`00JHL006N1001/PP00K8P00728001ZQP00JHH006R7001XQ000I7l006=o001RO000GgT0061f
001UN000IGX006Ah001UM`0205eg000B05Qc001HK`00DVL005=Z001CJ`00DF0004aI0016CP00?D40
03dm000h>@00=3<002lb000W9`006Q@000h=00081@000P00Y@00000<0?ooo`002P3ooole00000080
0@0000H0000000@400020@001@@000@4000:400200XB000W00T@000<40002PX000`A000;3@004AH0
00lB000=3`0041`0018N000G90005B4001PP000H7@006ad001TH000J80005R<001XZ000K;P007c80
02<d000U>0009cH002D^000W;000:Bl0030h000_>000<c`0034j000]?P00;40002m=000bDP00>U80
03e>000nC000?4D00080>D0002L0?DP0041D000nH000?V80041R0010GP00@Ud0045K0014E000?dT0
049;0018F`40BUl1055[0@1CK@00Dfh005=Y001CKP00EW80051b001BMP00D7<105=h001EMP00G7d0
05j10@1PQ000IHH206N70@1RSP80Hhd106J>0@1UT080I8l106FD0P1UVP40J9/106^M0P1^XP400P1_
W0409`1_XP80L9l107BN0@1_X0<0Jid406fI0P1aV@40MIH107BE0@1dV`40LZ0207>M0P1dU`40MiL0
07JE001fT000NXd007V<001hT@00Mi4007J?001mT@00Ni4007b>001hR@00MX`007B8001bP`00LH00
07Al001eP000M7l0075o001`P@00L8T007B5001fN@00LgH0071`0002071b000W07If001fP000MhP0
07Z;001jS@00MX@0071o001cNP00LX4007B3001fS000M9<007:E001^R000LH<006f3001aO`00KhP0
07:3001aQ000JHX006J8001WP`00Jh4006j4001aRP00JHP006R2001VQ000IHD006=o001POP00HGl0
05il001NL`00Gg80065a001NL000Fg800080F7400140Eg0005AX001AH000DF00055R001?F`00@eT0
041?000m@`00=cH002hZ000W9P008B8001/D000=2`0020D000<1002V000000`0oooo000:0?ooocP0
000000D00P40000000020P000P800081000200P9000W00H8000:2@001PD000X<00092P002P/000`<
000:2@003QH000lE000D70004Q/001@K000E6@005aT001PG000H6`006B4001`W000O<@007c8002<g
000R?0009C`002Hh000X=P00:3P002hh000Z<@00;S@002hf000]?P00:d<0031>000cD`00>ED003]@
000lC000>4<00080=S/002L0=Cd003a80010D000@EP004EP0013G`00AEl004=K0015E@00@DT0049:
0012C000BV4104i_0@1>L`40D78005=Z001GK000EVX005=^001BK`00D6d105Ib001GL@40FGT105Qo
0P1MQ@40Hh<106B20@1TQP40I8X106F=0@1RT@40Hi0106>I0P1QVP40HI`206JJ0P1[T`400P1_VP40
5`1]VP80Ki81076D001XT`40J9H206ZE0P1[TP40LI81076D0P1_U`80K9@407:G0@1fU@00MhX007R9
001gQ`00MH8007V0001gQ`00LXL00762001gO`00NHH00080N8`000L0N8X007>3001]P000L7H006ee
001`MP00Kg`00080K7T000D0L7d0079o001cP000LgD006i`000206m^000W06i[001]L@00LWh007B7
001eS000NH/007B5001`P000L8<006n2001bQP00LHl007:B001aT000L8`00762001_N`00KGd006an
001[P000JX<006J5001WQP00J7h006^2001`RP00Jhd006N4001UOP00H7l0065m001ON`00GG/005mo
001QM`00GW0005aZ001JJ@00F6h00080Ef`00140EVd0051U001;FP00BeD004UB0016C@00@dX003i4
000h?@00;S0002<P000K60004a0000X800060`000P400040002V000000`0oooo000:0?oooc@00000
0P0100020000000500400000000000000040000000000P040`003@030`001PH000<200010@001PD0
00D300092@001PL000`?000:2P0041H0010I000D7P000P0D7@00600H80005a/001XR000I:P007C<0
01hc000S>@008cl002E0000V?`00:D4002]0000^@`00;C`002lj000]>000;C/002a1000bBP00<E00
03=G0@0cD`40=E8003I90080>4@002L0>Sl003m6000mB000@E<0041B0012D000@eH004AC0016DP00
ADh0049<0015CP00AV4104UW0@1;LP40Cg41051X001EIP00EVP005I/001AJP00DW<105Ec0@1FL`40
EGP105=k0P1HO`80Gh<106>1001VQ000IhH006J9001SSP00HXh006BK1P1RVP40Gid306>J1@1YUP<0
0P1ZU`409`1]U@40J8d106ZA0@1ZTP40Jh`106N<0@1YS040JXl006nG0@1YU080JY4306nA0P1_SP00
LXT007R;001hQ`00MX00079l001cP000LX4007=o001aO@00MX8007N6001eQ`00MH<006mn001_O@00
KWD006Y[001XL000Kg/006im001WN`40IWT106aj0@1_O@00LgT0079d000206i/000W06ES001XI`00
JG8006el001eQ`00N8P007>8001aQ000LX4006mo001bQP00LX/0072;001aT`00L9800769001`P000
Jgh006Ql001[O@00KGl006b1001[P`00JX4006V6001/RP00KHX006^4001VO`00Fh0005Yl001LMP00
FW8005eh001RO000GG<005IZ001DI000EF<00080Df<000l0Cf4004]M0018E@00?d`003i3000l@P00
>3X003<d000^:`00924001PF000A300020H000@200010000Z000000<0?ooo`002P3ooolc000000<0
0@001`0000030041000M000000020@000000008100010@001`X000H70009300020P000lF000?6P00
3Q/001@T000E8P006BH001DN000G8P005Bl001Xh000M=`008d4002=4000UAP009D<002M2000[?@00
<4400352000a?`000P0_?@001`0^@000;d@002e8000/DP40;U8102eH0@0cD0000P0kB@009`0mB000
@4d003m;0011C@00?4/003]8000lC000@UD004EE0016EP00AU<004I?0016G@40Aeh104QZ0@1<J@40
DVP0055N001?H@00CfL004mV001>K@40BFT104Ye0P1AOP40DG`105B00P1IP`40GHH106>2001SP`00
IhD106J80@1TR`40IY<506BA0P1UU`80J9L406RD0P0206VD0@0?06>?0@1VT@40Ihl006F>0@1WR@40
JH`106N=0@1VT@40IY8106FA0@1WS`40Ihh006N9001WP`40L8P00080LHH000H0Kh4006en001`O`00
L800071n001aP00207:1000>07=n001]N000KG@006]b001XKP00JW<006Yg001^O@00J8L106250P1Y
P040KW/0071i001dM`02075d000W06MZ001XIP00J70006ae001`N`00M7l007F1001dQ`00L8D00726
001bRP00LHH00729001_T000Li4007><001`Q@00Jh4006]o001]O`00KX4006mn001ZP000JH4006R3
001[P`00JH@006V1001VP@00Gh4005mn001LM@00FW0005Q^001IL@00Eg8005E`001CI@00DEX00080
CUH000d0B5X004=E0011DP00?dD003Pi000b<P00:BP002@O000N500050`000X600050@000@000:X0
0000303oool000X0oooo<`000000100100000@4000400001000:0000000J00400000000000000000
000510000`80008100072P0020/000hK000=70004bL001@P000H9`005Ql001LW000G;`006cX101`l
0@0PAP0084X002A6000V@0009SX002Xe000W<00202hm000902hk000]?P00;40002Lo000XA0009TP1
02Q>0@0^DP00;dX00080=dH001d0?Td0049C000lCP00?D`003U8000lAP00?dh004EQ0013HP00AV40
04EB0014CP00AU@004QF0019I@40CfT0059Y001<G`00BUd004aL001:F`00CFL004][0@16N080BGD2
04am0@1BP`80Egd205^00@0205ml000806Ao0@1SOP40IXD106240@1JR@40HI4206B:0@1UT`8206N?
0@0H06N8001USP40J8d006R7001YR`00Jhd006N?0@1XS040Ihd006N<001[S000KHP006b5001WO`00
K84006^2001^S@00K8d107290@1`Q@00L8H007:6001`P`00LH400P1`P0003@1/M000Jg8006Ud001/
M000JG8006Qa001]NP00KHP006V80@1_Q`00Kh<0079m001cN0000P1bN@009`1^NP00KWH006Yc001Y
K@00K78006if001`O@00LH@007>8001aR`00Kh/006^2001]P000L8T007>:001_S@00JhD006^3001Z
PP00KH8006j0001[N`00J7`006Qm001YP000IWh006Mn001VN`00I7X005mk001RN@00GgL005a^001F
I`00DVP0059[001AKP00DFH004eF000204Q?000;04MB0013C@00@DT003Tk000a<000:B8001/G000E
3@0030D000H100010000[000000<0?ooo`002P3ooold000000800@004000000080010000000000H8
00062P0031T000`H000B90004Q`001LW000F9000630001Hd0@0D=`406d0101]0000OA`008Cl002@j
000V=@00:C0002D[000[>000:SP002/l000]?@00;D8002Q3000VAP0094H002Y9000[A`00;T000P0`
>@000`0h@P00>dP003]6000203]6000R03Y9000oC@00AE`004ER0015I@00@eH0041<0010B000A580
04QQ0@1>J000CVX004eU0018GP00A5D004MA001>F`00CF@004]h1`18M`80B7L104]g001DN000FG/0
05il001SM`00HVh0069_001SO000GX4105b50@1JR@<0GXH305nA1`80H8`502L0I8P006V=001YSP40
J88006F7001YR000KHT006f8001XQ000IH@006V6001]RP00KX<006f0001/O`00KX@006b=001/T`40
KiD1072@0@1bRP40MXT007>7001`Q000LX@00762001`N000JW8006Ed001UL@00IFX006M[001[LP00
KgP006ml001bQ000LhL007>1001dOP000P1cO0009`1^P000LGl006ag001^M000KFl006Ua001[NP00
KX0006j7001_S`00L8/006b1001/N`00KH0006j3001[Q`00J8@006>2001VP000J7l006Mm001WNP00
IWd006Ui001XO000IGT0061n001OO000G7T005Ya001LL@00FgH005aa001FH`00Ced004aO001<I@00
Bf0004ME000204M?000904=9000k?@00>3`002h]000Z8`007QP000l900090`000P000:h00000303o
ool000X0oooo=@0000000`01000000000000000@0000000500@400061`0031H000`E000B7`000P0A
6P005`0G9@005B8001P`0@0F<@406cd101`j000Q?P0083T002<h000U<P00:2h002H/000Y<P00:3D0
02dl000]?P00;T8002]3000[A000:D8002a:000^A`00;T000080;cT000@0<Cd003<l000c?000=400
0P0g@`008@0mBP00@UD0049L0016H`00A5/0041@000oD000A540045C0018H040BV0004aQ0019G@00
AeD004E@0012D`00B5l004Uf2014L`80C70104m/001CLP00EW@005ag001SM@00H6X005iW001PK@00
GgL005em0@1FO@40G8<405bA3P0205b:2`0W06>70@1[R000Ih@006Ij001TN000IW`006N2001YQP00
J80006Mk001VP000Jh4006j1001]Q000KXP006n=001^TP00Ki8106jK0P1/U080K8l2076;0@1cP`00
L8400766001dP`00Kh0006el001ZNP00IgP0069`001RJ@00J6h006Ma001WMP00KWh00762001dP000
MGl00080LG`000@0LH@007>3001bO@00JgT00P1XLP008@1YMP00IWh006R0001_R000KhH006f1001[
P000Jg/006]m001TO`00J7l006:0001RO000HWX006=c001RL@00HWD006Md001VLP00H7D005ai001L
N`00G7P005U^001FK000Eg0005I^001BIP00Ce`004UD0019F000AeH004E@00020455000803Lj000`
;`00:bL001dK000G4@003`P000D20001002_000000`0oooo000:0?ooodP0000000/00`<000@40005
1P002a4000/@000A6P003aT001DP000E700062D001LT000201/e000A028k000Q>`0083d0024h000W
=`009c@002/e000/=@00;c`002hm000bA@00;d8002e1000Z?000;4L002e7000_AP000P0dA`000`0c
B000<Sh0038n000303Ho000Q03a9000kC000@5T004=N0015GP00@EP003m@0011C`00@58004EN0P17
F`00C5d004QI0018E000Ae40049?0012G000A6P004=d0@17K`00D6/005=_001EL@00Eg4105a_001N
I@00GfP005][001HKP00FWT005Yi0@1IP080F8460080FHH402L0HH<1069n001SNP00Gg@0061/001P
L`00HgL006=o001SQ000I80006=o001UO`00IGh006]m001/P`00Kh/006bC001_V@00L9T106nB0P1]
S080KHD106in001WP000Jh800724001aQ@00L8<006j2001]O`00J7L006=b001XK@00I6`006Af001Y
N@00L7d007B4001gP@000P1dO`009`1bQ@00Lh8007:5001/OP00J7L006Y`001UK`00Hg<006Af001U
N`00JWh006f1001/O`00Jg`006Uk001UN`00IW/006Eo001TO000GWD0065/001OK000Gg<0065`001N
J`00G6d005ac001LM`00GGH005I_001DI@00D6D0055S001?I000C5`004M>0011B000?T@003/o0002
03Dh000602`b000U800061<000`900070`000P40/@00000<0?ooo`002P3oool^0000000300400000
0000000001P0000001d00P80008100083@0020h000dG000=5@004QL0010C000G6`0051/001L^000J
<P008CP0020k000N?@008CX0024d000V>@009c<002/b000[<`00;c/002m3000`A@00;3d002Xm000X
?@00;4L002m3000203A8000W03A=000`BP00=4D003E2000d?P00=3d003]8000lBP00?U<0049H0014
F`00@UL003i>000oC000@4l004AK0`18F@00Bel004ML001<E`00Ae0004=>0011E000@F00041/0@10
I000BFT1051^0@1AK040E6l105IY0@1KI`00GV`005eY001KI`00F6L005e_001KO@40F7l10080F841
02L0Fgd005]a001LL`00Gg41065[001OK000GG8005eg001NPP00H7h005mk001NNP00GgX006Ik001Z
O000L88006b;001/TP00KY4006j@001/R040JH4006Ij001XN`00IgX006Qk001]Q000LH/007:8001`
R@40KX@106Un0@1XLP00IVh006Ma001YL@00K7@007Am001jQ`000P1eQ0009`1cP`00LX400722001/
P@00JGd006]i001YM000IG@0069b001TL@00J7/006f0001[OP00JGX006Qm001XOP00IWd006Ak001R
N@00H7T005m`001RL000GG8005]^001HJ000FVL005UZ001JL`00FG<005QY001BI000CF4004]O001:
H000AUH00419000k?@00<c<002l[000202HU000401hP000G50003PT000@20;<00000303oool000X0
ooooB@0000007@010000000000H900062P00314000/>000=3`002``001<E000B600041/001L]000I
:`0083@001dd000Q<`008c4002Hd000S;P009Rh002L^000]=P00;CX002hm000[?000;3/002]0000_
A`00<D000080=48002L0<TH00318000aA`00=4T003=6000eAP00?D`003e:000mB`00@4d0049B0010
C`00?4d003U;000oC@00?4l004AF0019G@00BUL004]H0018E000@Dd0049=0015E@00@UX0049F0017
I@00BFT2051_0`1ALP40E6h005UY001NJ`00H6L005aV001CI@00G6T005ed001GNP000P1FP`409`1G
O`00FgD005Y`001KM040H7<0061a001HLP00GGL00660001PN`00H7<005U`001HL@00H7L006Mh001X
N000KH4006n3001]QP00KHP006b;001XPP00JG`006Uh001VMP00IGH006Yo001[R000KHX0072;001_
QP00KH4006aj001ZM@00Jg4006]/001WK@00KGD007>2000207B4000W07>0001aO@00KWh006en001Z
OP00JWl006Uk001XNP00IWL006Md001WN@00JG`006Uj001XOP00Igh006Ao001TO000H7d006=i001S
M@00HGH0061b001MLP00Fg0005Q^001HJP00EVL005AX001DI@00DEl004mM0018GP00AU`004=I000n
C`00?DD003Di000X9`0081X000805A<000@040h000X9000510000@40/`00000<0?ooo`002P3ooom;
0000000K00D500051P002P/000P:00072@002`/000/<000A60003aT001<Z000E:@0072l001//000O
<0007S<0020d000P;@008RT0028V000W:`009bd002Xe000Y=`00;3T002/i000a?`00<Sh00080<d80
0180<4@00316000aB000=4T00398000fB`00>4/003a8000nA@00?D80041;000oB@00?D/003U<000j
C@00>dh003i@0013D`0204QD000C04ME0016C`00B50004QB0018E@00AUH004QO0@17J080CW03055_
0P1CJ`00EVh005]W001LI`00F6D0055X001GI`00FfT005ac000205Qk0@0F05Qk001LMP00GW8105U`
0@1KL@00GW<005ad001NNP00HW/0069g001SLP00GVX005i]001SL000IW<006Ab001YN@00J7P006Yk
001[P`00JhL006Z60080JWd000l0Jg/006Mf001WN@00Ig`006^0001_Q@00LX0006ml001^N@00KGL0
06Uc001UL`00IF/006Qa001ZN`400P1`P0001P1_OP00LH8006an001ZO000J80006Ym0080Jg`001l0
J7/006Qh001WN`00J7d006Uj001VO@00Hgh0069l001SO000IWl006=j001PM@00H7<005ma001NI`00
Ff/005I_001EJ@00DV00059M001>F@00B58004YC0014E000@E8003]:000iA`00=c/002h[000O6000
4@`0008020@000@01@<000<100020@000@00/`00000<0?ooo`002P3ooolT000000@00@0050000000
0`01000000000000000=000000800P4001P01`P000L:000;40003180010E000?5P005BD101DT000H
:`006R/0024b000P=P009CH002<_000O9P007B00020Q000Q9@009S4002Pg000[?000:3T002/m000/
?0020310000;02e2000^AP00;DP003=;000cA@00=dD003I3000hA000=3l003Y3000mB0000P11D000
300lB`00?Dd003a?000mD@00@U<004EB0014D000Ae<004YB001;F@00Be/004UK0080BeX000`0Bf81
04m_0@1DK040DfT005AY0@1AH@00Ff4005IQ001AI000DfT005U/001JL`0205Ue000W05Yd001OL`00
HW0005eb0@1NL040GG4005ec001PN@00HGL006Ae001TM000HFl0065Z001PJ000HV/006Id001XN@00
JGD006Ud001/O000K7h006]m001ZNP00Jg`006]m001VN`00IWT006If001VM@00JWX006]l001WN000
Ig`006Qg001WN@00IWL006Ea001YL000J7<00080JGd002L0JWl006j3001]PP00Jh4006R1001ZP@00
JW`006Mj001VN`00IWd006Mo001WP000JGl006Mo001UO`00I80006J1001RP000HGh005mh001PMP00
GG0005]U001HIP00D6@004mP0019G@40AeT104I@0@11A@00?3l003Xl000e>`00<SL002`[000Y8000
7QL0014:00050`000P01002g000000`0oooo000:0?ooob@000001001000D00000003004000000000
000000d000000P020@00600720001`X000/@000<4P0041D000lF000E9@405B@001P[000J:`008C80
020f000U=P008bl001lV000M80008240024U000V<@00:3L002/l000X>@00:cd002`l0080<40000/0
;D8002i6000]B000<d/003=5000gA@00=T<003Q4000d?`00>T<003e80002045@000<03a;000mC@00
?4l003eA0012D`00AE8004A@0017D`00BU8004]I001;F`00BE/00P1;FP00301;HP40Cfl105A/0@1C
J@00E6T1055Q001KH@00EV40055T001CJ@00FF`005Yc0080FGD002L0FW@005mc001RL000GG8105i`
0@1ML@00GG<0061i001QM`00I7D006Ad001QK`00HFX0061X001RJ`00IW@006Qi001YM@00JG@006al
001/OP00Jgd006Yj001[O000Jgd006Ik001VN@00IWH006Ie001ZNP00Jg`006Mh001WO000J7L006Mi
001VM`00IG4006U`001XL`000P1YO@009`1ZO`00KX<006f2001[P@00J84006Z1001ZO000IgX006Ik
001VO@00Igl006N0001YO`00Igl006Eo001TP000IX4006:0001QOP00GgP0061f001ML000FfD005QV
001@I000Cf0004UM0@17F@40AU010455000l?`00>S`003Dk000b=`00;2/002TP000N5`004@X000D3
000200400;L00000303oool000X0oooo:@0000000`01000000000000000R0000000400D500051P00
2`l000/?00803@l001805B0201<O000C8@005bP001PX000O;@008B`002@`000P9P0082<001lO000O
8P008RT002Tc000X>000:3d002Li000Y>@0202Hi000>02/k000[?000<48003I6000dB000=T@003=1
000e@000<S`003M1000jA000@5H003iF000mD00203a=000G03m@0010E@00A5P0045@0014D@00AU40
04eL001<H@00CV0004iK001=DP00Ce`005=V0@1GJ000Ef<005EK001BF@00EUl005IL001DIP00EFP0
05A_001AM@400P1BL@009`1FM000G7@005ma001PL`40GGD105ec0@1MN000GGL005mh0@1RNP40H7P0
06=i001ML`00FVT005iX001TL000J7H006]d001/M`00KG`006b0001_N@00IgP006Ii001WNP00IGT0
06Ai001VN000IgL006If001YM000IGP006Il001QO@40IWX006Uh001WLP00IV`006=[000206Ia000W
06Mi001ZP@00KXD006b5001/QP00KHL006j0001XM`00HWT006En001VPP00JH0006R2001SO`00H7l0
06An001RO000H7`0065j001NNP00GW0005Y/001HK000DV<004aH0019E`00AUL0045B0@0nA`40>Ch0
038b000Z:P00:bT002HS000K5P004P`000T500040@000P000;T00000303oool000X0ooooCP000002
00<2000F00P;00082@001`T000/>000;4`004Al000hP000D:@005RD001`W000N:@008Rd001lY000Q
:`008BD0020U000R9`009bd002L`000X=P00:CH002Tg00809CL002L0:CD002/d000_=@00<cX003I4
000f@@00<d4003A1000`?@00=48003I5000kF000>Ed003YG000hD000>4`003Q@000oE`40AEd004ED
0016D000ADd004aH001>F`00Ce/004mM001@EP00D5/005=O001II`00FVL005QO001HG@00EET005MR
001FJP00F6`005M_001@L0000P1=L0006P1FL@00Dfd005]]001PL000GGD005]h001MN000GgL105if
0@1MN040GWh105en0@1KN000Fg8005m]001TK000Ig<006Uh001^M`00Jgh006Z2001ZO`00HWT0061j
001RM000Ig<00P1UMP002`1WMP00J7<006Yf001XNP00Ig`006In001YO@00Jgd006Ig001RK`00HVP0
0080Hf`002D0IWD006Mn001YP`00K8L006j7001`Q`00LH4006]j001UM000HGH005mn001RP000IX<0
06B1001TO000HWP005mc001MM000GWD005]c001HJP00EFP0055V001@G000AeH004A@0014C`00?DX0
03Q0000a>000:2L001dO000K6@005a@000h700060P000@000;/00000303oool000X0oooo3`000000
0`01000000000000000m000000800@4000h01PH000D6000;3P0031<0018O000?7`005BP001LW000L
:`007B`001h/000N:0008R/0024Z00808R/000D092/002@Z000W<@009c<002Dc000202D_000K02Te
000[<`00;C40030c000e?P00=3h003I0000d@`00<T8002m0000cBP00=UP003EP0@0hF`80=ED203AD
0@0bE040>UT103mH0015DP00ATl004M90019D000BE4004iD001?F@00D5X00080E64000X0EV@005UU
001KJ@00F6@005IN001FH@00EV@005a[001LLP00Dg<00P1>M0009`1AM000Dg4005M]001LL@00G7@0
05Uf001JM000GG80065b001QM040G7L105Yi0@1IN@40GWL005me001RL`00Ig<006]d001]M000KGT0
06an001XO@00HX00061l001RM000HW8006Ee001VM@00Ig@006Qe001ZMP00IgP006Ee001XNP00JG`0
06Yo001YNP00I6l0069[000206E^000T06Ac001VMP00Igd006b5001^R`00LHH006n1001[P@00IG<0
05a]001LL`00GgL006:0001TN`00I7d0061e001NL000FFh005MY001IJ000F6T0059R001>F`00C5@0
04EB000mAP00>3l003Dh000]<000:2P001hJ000C3`003PT000X500050@000@00_000000<0?ooo`00
2P3oool>0000000300400000000000000400000000`01@H000H7000;3@002`h0014I000A5P005A/0
01HO000L:P006bX001l]000M:P0201lX0007028/000R:P009BX002<]000W<P009cD002Pe000202P^
000402Xd000Y<P00;S80030d0080<ch00240=D@003E2000d@`00<TH003=;000aC`00=5d203EP100e
GP<0=U`203AG0@0jF@00@EL004EC0016C000A4L004=<0012B000Adl004]H001?H000DFP005=W001C
H000E6<005QY001CHP00EUh005QT001HH`00FfT005a`001GMP000P1AN`009`1BNP00Dg<005Q`001G
JP00FVl005A_001GK@00GfX006=a001SM000GgL105mf0@1INP00GWX0065i001TMP00IWD006]c001X
KP00Jfl006Qe001WM`00IGl006=n001TN000Hg<006I`001TLP00I7<006Yd001ZN@00IW<006=f001V
M`00IWX006Mk001WO@00HWH006=^0002065/000S06=a001QK`00IGH006]n001_QP00K88006b7001Z
RP00IWd005mc001LK@00GG0005ic001KK`00GG0005ac001HJP00E6@005AN001>F@00CeL004YD0014
C@00@4X003a5000b=P00:R`002LR000Q6P006QD000h=00071@001040008100010000_@00000<0?oo
o`002P3ooolD000000800@00>`0000005@051`001PT000/=000:2`003a@000hA000>3`004QD0018K
000I9@006B@001`]000K:@006bL001XS000L9`007RL002D/000T;`00:CL002dk000202`g000W02Pa
000W;P00:BX002dc000a@040<TL103M:000f@`00=d@003I6000dAP00<4d0031K0@0`G`<0<f0203AM
0P0hF040?ED0041B0016E000B5<004I;000oA`00?DX004=<0017DP00CUh0059V001CJ000E6<005=T
001EJ@00Df0005AO001GI@00Df0005IW0@1EJ`00Eg<00080E7`002L0DgT005Ie001DL`00EV/005U_
001EJP00F6/005Q]001IK000H7@0069c001RM@00HGT0061n001RP@00IG`006Ii001WM@00J6T006I^
001ZL`00JGT006In001SP@00HWl006Ii001RM@00HGD006=f001UN`00JW/006Ei001QN000HWT006Mj
001XP000IGd0069i001SL`000P1PK`00801PKP00GVh005ma001RN@00I7d006Ao001VP`00IhH006Em
001RMP00GVd005][001IIP00Deh005EO001BH@00DEd004eE0019C@00A4L003i3000k?@00>ch003<i
000_=@00:BP001hL000F4P003`/000X600060P000P40`000000<0?ooo`002P3ooomA0000000E00@4
00051P0010<000P<00082`003A4000`>000@5@004AT001LR000G90006c0001X[000K9`006B0001XR
000K8`007bT0028/000X=000:SH00080:cT002L0:SH002Tb000V;`00:c8002db000_BP40=4/003Y9
000kC000>Dl003I7000`BP00;e@202iK0P0_G@80<Ul103YK0@0lEP00?e<004QD001:D`00ATX003m5
000nB000?TD004I@001;F000Ced0059Q001BG`00Df@0055X001EH`00EFD005AT001AH@00DfP1059/
0@1EL0000P1FM@009`1EM@00EG@0055/001FJ`00F70005IY001IK000Ef`005E[001ILP00GgT0069e
001OM@00GWd006=m001SNP00IG/006Ah001UL000IVl006Uc001YO@00JX0006F3001QP`00I7l006Ak
001RO@00HG`006=h001VN@00IGP0069i001UM`00IG/006F0001VOP00Hgd006=k0002069j000P06Ad
001PK@00GW00061d001PLP00GW<0061g001QN000HGH005id001JKP00EVT0051R001AF000BEH004IA
0018C`00A4X003m3000k?`00=3P002d`000/;P00:2T002<T000J6P004Q0000/700050`000P000000
00010030000000`0oooo000:0?oooe80000001@00P40004100072P001PT000X<00082@003a<000lF
000E8P005BL001Xa000I<0006b/001TS000L7`006ah001lU000R:0009Rh002H_0080:CD002L0:SH0
02Pi000V>@00:CH002/e000cAP40=4T003U:000jB`00>4d003=2000aA@00<dl103=D0@0dGP80;f42
03IP0P0lF@00?U<004=@0018CP00@d/003m3000mA`00?dP004ED0017E@00B5D004UB001?EP00D5d0
055S001CI@00F6/005M]001JJP00DfP005=b0@1CK0000P1EK000101GK`00EW<0055[001DJ@0205Ma
000Q05Qe001EK`00Dfh005Ee001JN000GGH0061a001QM`00HgD006=f001UO`00IX4006Eh001SM`00
HgH006Ei001XNP00IH0005f2001LP@00Gh00069n001RO@00HWT006=g001QM`00HWH0065a001SM@00
GWX0065i001SO000HWh00080Ggl001d0HGP005mb001OL`00Gg0005]]001JJ`00F6L005UY001ILP00
FFl005I/0@1?IP00Cel004]H0017C`00@DP004180011B000>Cl003<j000^<00092D001/K000G4`00
5A<000h:00081@000`8000800033000000`0oooo000:0?oooc<0000000<00@000000000000007P00
000200@4000@00H500051@0030h000dA000D7P0052@001H_000G<00062X001XU000I700071l001`Q
000R9`0092T002H`0080:3P002L0:d0002`n000Z>@00:CD002/f000aA@00<4P003A;000eB000=480
030l000_@000<4L003E@000eFP40<V8103IN0@0jE000@4l0041A0013C`00A4`0045:0010BP00@Dd0
04AC0017DP00Adl004IA0018E000CeL004mI001AG000EF@005Y^001KK@00FV`005Ig0P1CK@400P1E
J@009`1IKP00FFl0059[001FK@00DVd005=c001FN000EW@105=c001IN000Fg`005il001QNP00I7P0
06Ea001TM000J7`006Mo001TO@00Ggd005ah001OLP00I700061j001KP040EX4105Ym0@1LO000HG80
05mg001KMP00GWD005ic001LKP00G6/005]_001OM@00GWT005mm000205b0000K05ek001NMP00Fg40
05UX001JJP00EFD005=O001@G@00DFP005=Y001BJ@00CV4004QJ0014D@00@DT003i6000k@P00>3d0
034c000Z:@0081`001PB000=20002@@000L400050@000P000<D00000303oool000X0oooo<`000000
0`01000000000000000N000000800P4000/010@000D500061@0030`000`>000B7`0052@001DX000H
8`007B8001/O000201dP0003020U000Q9`00:3D000809cl002L0:TT002Y7000]?`00:CD002`e000a
@000;TH1039@000dB000<d0002hl000a>P00<d0003A7000dD`00=5/103IC000mCP00@4d0045>0013
D000AE40045?0010AP00@d/004=@0013C@00@TX004E<0016EP00B58004QE001:D@00DET005EX001H
K`00FVl005Ug0@1FK@000P1EKP409`1FK@40Efl005A_001HL`00EFh0055e001BL@00DgH105Ae001H
L`00G80005j40@1QOP00H7P005m_001QL000H70005ig001MOP00F7X005Qf001HL000G6`005Y^001F
NP40EG`005Mm001IN@00F7D005Ye001KM`00FWD005Y]001KK@00F6X005Y]001LLP00H7T0065j0002
05im000G05]j001IM000EVh005IX001EJ000EVD0055M001<FP00BUl004aP0019H`00B5T004EE0010
A`00>T8003Lj000_<@00:BL0028K000G4@003@T000L5000200000P010037000000`0oooo000:0?oo
oeD000000P0100003`051P001@L000X<000<3@004Ad0014L000F8P0061l001`R000J7P00720001`O
000N80007B4002H^000202Hi000402Q5000YB`00:DX002]10080;3`00240;d/1035=000dB`00<4@0
02m1000b?`00=44003I6000cB`00>54003U<000lCP00?dh0049?0014D@00AED004AG0012E000@Th0
03m;0010C`00@DP004540016B`00AU0004UA0015C`00BED0051U001EJ000Ef`005Ue0@1GL0000P1G
L`409`1ELP40Eg4005Me001FL`00EFd005=a001>K`00E70005I`001IL@00GWT005^40`1ON`00GgH0
05mg001KL@00F6h005Mc0@1HNP00DW/005Ed001CL@40D6h105A/001FLP00EgT005Mn001KO000G7/0
05Qj001JN@00FgH005Y_001GK000F6X005]^001LKP00HG0005ic000205ad000F05Yb001HL@00F6h0
05EV001DJ000DfT0051M0019E000B5D004EB0011D@00@4P003a2000c>000;bh002XT000O6P005100
00d800080`000P0000400<X00000303oool000X0ooooE`0000003`051P001@L000X<000;3@004AX0
010H000F8`005R4001/T000H80006ah001PK000I6P006a`0024[0@0202@`000W02Hn000RBP809Dd1
02Y5000Z@P00:D8002e<0@0_CP00<TX00314000b@000;c`0030o000b@@00<d4003M3000hA@00?4T0
03e?000mD`00?U4004AG0014G000@UX0045F000oD`00@54003m5000o@`00@dX004IC0019G000AED0
04EG001;F`00DV4005=Z001CKP00DWL00080DgX100L0EG@105Ea001FMP00E7D005I_001AK@00CV/0
0080DFl001h0EVl005eb001NK`00I7D006=e001PN000Gg@005Q`001CM000F7D0059f001CM000DG81
05=a0@1GK000FG4005ai001KOP40GWh005im001IN`00FGT005Qc001GJP00EFX005MY001GI@00FVH0
05a[001KKP0205a/000C05Y]001HK`00EFL0055R001@H@00CUl004]F0014B`00?d8003`o000g>@00
<2h002PS000R6`006AD0014;000:1@001@400080000b00000003004000000000000009P00000303o
ool000X0ooooE`0000003`051@001@H000/<000:2`003Q4000h@000C7P004a`0018L000H8@005ah0
01PL000F5`006QP001XM0002024[000W028k0@0NA`4094T102E2000X@@009d4002]9000/B@00<DH0
0391000d>`00<3P002hk000_>000<3/003<i000e>@00>TD003UA000iD`00?4h0049E0012FP00?e/0
041M0010FP00@E800418000oAP00@4/004=D0018H000AUX004MH0015EP00CET0051N001?H@00Cf/0
0080EWH002L0DgD1055a0@1BM000E7L005Mg001EK`00DFh0051`001@KP00EFh005UZ001JJ000IG80
06Ed001TNP00GGL005Ic001CMP40DW@105Af001DN@00DWD005Ia001IK000Fg0005ih001MNP00Gg`0
05eo001KP000Eg/105Ee0@1DK`00F6d005QY001EI@00E5d005EM001DG@000P1EG`004@1FH@00DV<0
04]I001:E@00Ae00049=000nAP00>Sd0034`000]:P009b<001/D000B2`003@H000X300020@000@00
0<l00000303oool000X0ooooE`0000003`061`001@H000@500082@001`H000/=000930003a@000lB
000G7P0061l001PP000F6P006Q`001TN000201dW000W01`^0@0R?P408D@002A1000R@0009T8002]6
000ZA000;TD002m0000^>P00;SP002dj000^=P00<ST0038d000^<P00;cT003I=0@0fE040>Th103mB
000oEP00?e/003eL0@11G040@E4004170010B@00?dl0041D0012EP00B60004QM0019E000BU8004]E
0016EP00BV800080C6/002L0DW80059b0@1AM@40E7L005Ug001CLP00Dfl0051b001>L040E6l0055Y
001GI000HVP0061[001LL`00FgD005=g0@1AL`00D6l005=d001DN000E7L005Yf001LKP00Ff`005Yb
0@1JM@40FWH105Ul0@1HP040E80105Ek001CN000EG0005E[001CI000Ce/004U?0018C0000P19C@00
3`1:DP00Add004=:000nBP00>T@003Ln000b>P00;C<002@R000L5`0061@000`800030P000@400040
003A000000`0oooo000:0?oooeP0000000P01@H000@300071@0010<000T>000930003aD000lB0080
51d000@05Ql101@J000J70006B800P0N9P00900M9@00938002@l000V@0008S`002@o000T>`00:440
02]0000]?@00;3H002/g000]=P00;cX003<m000`=P00;C@002/j000bB`40=4d103U=000nCP00@580
045K000mF`40@5`1041A000lB`00?D`003mA0010D`00?eP004ER0019HP00BEX004UG0080AE8002X0
B5d004eS001=H`00D6/0051_001@M@40DW@105=c001AL@00E6l0051`001BM@40DW@105=Z001GIP00
GFH005aV001HJ`00EW81055g0@1?L@40D78105Ah001FMP00EgX005If0@1IK`00F6/0059^0@1BK`40
Dg8105Ai0@1CN`80E7l105Ii001EN000EFd005=X001BI000BeH004E<0013@`02040m000<03`l000g
>@00=C/003@o000`=000;Rl002T]000R9P0061@0010>000;1P0010402@0000000`01000000000000
0038000000`0oooo000:0?oooaX000000P01000I0000000300400000000000000200000000h00P40
004100030P000P4000T;0009300041P000lJ000A900042<101<S0@0D6`406A`001XP00807RP002L0
7R<002@[000S<`0093P0028j000T?@0093T002Tm000X?000:SX002Xi000Z>000:SD002hm000/?P00
<3l002hj000/>P00<4810350000fA000>D@003eB0012F000@U`1045I0@0oDP00?U4003e?000lD000
@5D0041G0013I`40BFH004eQ001:H000AUP004AC0011D@000P18EP009`1>G000C68004mX001CL@40
D74104m_001@KP00EFl005Ie001CN040EG@005U_001JJ`00FfL005IU001EK040D7<1051[0@1BK`40
EWL005Mc001EM000EgP005Ud001FL000DfT104aX0`1=KP80Cfd004e`0@1@LP40Dg00055_001AJP00
BVD004MN0@15E000ATd003a3000203@h000<02ha000/9`00;BT002X[000R7P006aD001HD000@3`00
2PH000@200030@000@00e000000<0?ooo`002P3ooolJ00000003004000010@000@0003d0000000<0
0@00000000071`000P0820001`0=60002QX100hW0@0?8`40524101<I000H70000P0I7@00600K8P00
6R@001la000R>P008c/002Dh000S<0009C<0028d000W>000:3P002Th000Z>000;c`002e1000a@P00
<3h002Xj000^>@00;S`003=0000e@000>Td003iA0080@ET000d0@5D003eA000kC`00?U4003eF0011
F`00Af`104YX001:H`00BUl004IE0011C`00@4T00080@T/000@0A4l004QI001?G`00CVT00P1>J`00
8@1=K000E6h005A^001BM@40DWX105Uh001JK`00EVL005=R001HI`00EVT105=U0@1BJ`40EVh005EZ
001GK@00FWL005Uj001GL@00E6X104eT0P1<I@40CF<004YT001;I000C64004eO001<GP00AUl0045I
000nDP00>TD003<h000202`a000902X[000S8`007a/001/G000A3@0020D000H100030@000@000=L0
0000303oool000X0oooo6P0000020040044000000P0410001`094`0021H000dU0@0?80404Ql0018H
000F60000P0F5`009P0H70005ah001l_000P=P008cX0028d000O:`007BL002<_000W>0009cH002Xh
000Y=P00:cT002`m000bA@00<D40030n000/>P00;Ch0038o000c?P00>4H003Y90010EP00?UT003aG
000kD`00>4d003eB000mE`00?Ul0049Q0016J000B6`004EW0@15G@00@E@00`10BP009`12C@00AeD0
04mO001<J@00DFT0051X001?K000D6h004mZ001=K@00CG8005Ab001EJ`00E6H0059U001DIP00EfL0
059U001CJ@00E6T005EX001CH`00DfL005A_001GJ@00DF0004iM0@17FP00AE/004AL0017FP00AUH0
04AB0013E000@5<003]=000hB@00<CP002HZ000202@Q000601`N000F5P004`l000`800060`000@00
fP00000<0?ooo`002P3ooolR00000003004000000000000003P0000000T00`800082000830001a00
00XS000<7@004Q`0010C000A4@000P0A4P009`0E6`0051/001d[000M<P007cL001lc000N;P007R`0
02@/000T:@009c<002Hd000V<P009c4002Te000`?`00;d0002m1000^@P00<400038l000c>`00=Sd0
03E0000lD000>EP103YG0@0eD`40=Dl003Y@000iE`00>ed003mM0012JP00AWH104Ia0@16J@00AF<0
04EI000204IE000F04A@0018CP00BE4004iT001AL@00Cf`0055^001@LP00CG<004e`001<JP00DF`0
05=Z001DI`00Df<004mR001=I000CVT0051Y001BJ000DfP004aQ00<0BUl000h0BeX004UH0012E040
@E80041B0011D000?Tl003U:000hB@40=D<0038o000^=`009RX001/L00804`l000D03@`000/70007
10000`800040003K000000`0oooo000:0?oooed000000P010@001`061P001`X000/M000<5`004QP0
00h@000<30000P0=30009`0C5`004a/001T]000H=0006cT101dd0@0M;P007b`0024Z000P9P009Bl0
02La000W;`0092`002H/000X<000;3d002m3000b@`00=T00038k000f?000<CP003Dn000iB`00?5@0
03UH0@0hEP00=U4003ED000fF000?5T003]I0012I040?Vd1049c0@15N040@fd104QV0@0204eR000W
04MI0015C`00ATl004iT0@1@L@40C6h004e[0018L040C7`004ig001>J`00DVX005E]001CJ@00Cf40
04aP001?HP00BVT004eY001@K000Cf`004UT0016GP00A5P0041B0@0oD000@Th0041:000oA@00>D40
03Y3000cA@00;Sl002`m0@0W<P009BP0020R000I5P0040h0008020H000<01080008100000000g@00
000<0?ooo`002P3ooomP0000000600@400051@002``000T8000<3@002@L00P0820009`081`004AL0
014N000D<P0063d101Xe0@0N;P0072P0020V000N8P009B/002H_000W:P008BH0028S000U;000;3d0
02]0000bA@00=Cl0038j000c@000<Sh003M5000fB@00>Td003QC000gE@00=5D003AF000eEP00=E@0
03QG000lGP00>F@203ib1011MP<0@W0104Q[0@0204]Z0@0W04UQ0016EP00A4l004YL001;I`40C6d0
04]^001;K`40CW/005=k001AL000EFd005A]001CIP00Cf8004aL001AG`00C6@004]T001>J000BfL0
04IR0@14F@00@4h003m6000kAP00>3h003Dk000b=P00;Rl002h`000V;@0092H0028U000K60005Q40
014;00081@001P<000800`8000<00P00000000000000g@00000<0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{78.625, 308}, {377.25, 147.875}} -> {-153.971, 260.769, \
1.46487, 1.46487}},
  CellTags->"RenderCTData"]
}, Open  ]],

Cell[TextData[{
  "Without the color, you can obtain almost the same effect as from ",
  StyleBox["MVContourPlot3D[]", "Input"],
  "."
}], "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MVListDensityPlot3D[
        Evaluate@\[IndentingNewLine]ToFileName[$MathGL3dDataDirectory, \
"\<foot.v3d\>"], 
        MVNewScene \[Rule] 
          True, \[IndentingNewLine]MVTextureSize \[Rule] {256, 256, 
            256}, \[IndentingNewLine]ColorFunction \[Rule] \((If[# < 0.37, 
                GrayLevel[0], 
                GrayLevel[
                  1]]\  &)\), \[IndentingNewLine]MVShadeVolume \[Rule] {0.6, 
            0.4, 0.2}, \[IndentingNewLine]ViewPoint \[Rule] {1.086, \
\(-2.00\), 1.0}, ViewCenter \[Rule] {0.42, 0.5, 0.46}];\)\)], "Input",
  CellTags->"RenderCTData"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00238095 0.0238095 0.00238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
1200 string
400 400 8 [400 0 0 400 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000807075046419C8A80CAB3A6D4BCAFDAC1B4DAC1B3D9C0B3D9C0B3D9C1B2D8C1B2
D8C0B1D8C0B1D8C0B1D8C1B1D8C1B1D9C1B1D9C1B1C6B1A3332E2A1A1715564C468B7B72
6B5E5788796FCBB3A5A18F83A39185C6B1A2D9C1B1DAC2B1CCB7A6B29E9187796E463F39
080706000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000211E1C887971CBB4A8DAC1B4DAC1B4D9C1B4D9C1B3D9C0B3D9C0B2D8C0B1D8C0B1
D8C1B1D8C1B1D8C0B1D8C0B1D8C0B0D8C1B0D8C1B0C7B2A336312C2A25228B7A71DDC3B4
A692879D8C80A99688A29084C5B0A1DAC3B2DAC3B2DBC3B2DBC3B2DBC3B2B8A49560554E
0A0908000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000006050515131226221F201D1B100E0D010101040403
0A09084A413EB5A095D8C0B3D9C1B4D9C1B3D9C1B3D9C0B3D9C0B2D9C0B2D8C0B2D8C0B1
D8C1B1D8C1B1D8C0B1D8C0B1D8C1B1D8C1B1D8C0B0B6A29548403B5D534CA49186DBC3B3
C6B1A2C8B3A3C3AE9EBFAB9CD1BBAADAC3B1DAC3B1DAC3B2DBC3B1DAC3B2B9A69660554E
0A0908000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000161412443C396F635C5E534D2F29260201011E1A19
534944A49288D4BCAFDAC0B4D9C1B4D9C1B4D9C0B3D9C0B3D9C0B2D9C0B2D8C0B2D8C1B1
D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1D0BAAA9B8A7F766A61B19F91CBB5A6D9C2B1
D7C0AFD7C0AFD7C0AFD7C0AFD8C2B0D9C3B1D9C2B1DAC2B1DAC2B1DBC3B1BFAA9B85776C
4039331A1715000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000036302C84766EBAA69AA29086534A450D0B0B4C4440
A18E86D2BAADD9C0B3D9C0B3D9C0B3D8C0B3D9C0B3D9C0B3D9C0B3D9C0B3D8C0B2D8C1B1
D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1C3AEA096867AAD9B8DD7C1B0D7C1B0D8C1B0
D8C1B0D8C1B0D8C1B0D9C2B0D9C2B0D9C2B0D9C2B0D9C3B1DAC3B2DAC3B2C5B0A0AB998B
7E7066584E474C443E2D28250F0E0C000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000004D4440A59389CDB7AABEAA9E80726A544B45908078
CDB6A9D9C1B4D9C0B3D8C0B3D8C0B3D9C0B3D9C0B2D9C0B2D8C0B2D8C0B2D8C1B1D8C1B1
D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1CAB5A5A09083B19E91D8C1B1D8C1B0D8C2B1
D8C2B0D8C2B0D9C2B0D9C2B0D9C2B0D9C2B1D9C3B1D9C2B1DAC3B1DAC3B2C9B4A4CCB6A6
AC9A8C8B7C709F8E815F544C201D1A000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000005A504AB5A197D3BCAFCCB7AAB19E93AB988DC6B1A5
D7BFB3D8C0B3D8C0B3D8C0B3D8C0B3D9C0B3D9C0B3D9C0B3D8C0B2D8C1B2D8C1B2D8C1B1
D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1D6C0AFC9B3A4C2AD9FD4BDAED8C1B1D8C2B1
D8C2B1D8C2B1D8C2B0D9C2B0D9C2B0D9C3B1D9C3B1D9C3B1DAC3B2DAC3B2C9B3A3CBB6A6
AE9C8E9D8C80CCB6A5796C62292521000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000101015C524CB6A297D3BDB0D4BDB0D3BCAFD3BDAFD5BEB1
D7C0B2D8C0B3D8C0B3D8C0B3D9C0B3D9C0B3D9C0B3D8C0B3D8C1B2D7C1B1D7C1B1D7C1B1
D7C1B1D7C1B1D8C1B1D8C1B1D8C1B1D8C1B1D8C2B1D6C0B0D4BEADD6BFB0D8C2B1D8C2B1
D8C2B1D8C2B1D8C2B1D8C2B1D9C2B1D9C2B1D8C1B0CCB7A6C7B2A2D1BBABC8B4A3CCB6A6
AA988A7C6E64796C6248403A191614000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000D0C0B6E625CBBA79BD4BEB0D3BDB0D4BEB0D5BFB1D5BFB1
D7C0B2D7C0B2D7C0B2D7C0B2D7C0B2D8C0B3D8C0B3D8C0B3D8C0B2D7C1B1D7C1B1D7C1B1
D7C1B1D7C1B1D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1D8C1B1D9C2B2D8C2B1D8C2B1D8C2B1
D8C2B1D8C2B1D8C2B1D8C3B1D8C2B1D9C2B1CCB7A69C8C809D8C80C4B0A1CAB5A5CEB9A8
A694875C524A292522191614080707000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000002E28268F8078C4AFA3D1BBAED4BEB0D5BFB2D5BFB1D6C0B2
D7C0B2D7C0B2D7C0B2D7C0B2D7C0B2D8C0B2D9C0B3D8C1B3D8C1B2D7C1B2D7C1B2D7C1B2
D8C1B2D8C2B2D8C1B1D8C1B1D8C1B1D8C2B1D8C2B1D8C2B1D8C2B1D7C2B1D7C2B1D7C2B1
D8C2B1D8C2B1D8C2B1D9C2B1D9C3B1D9C3B2B9A5966F645C94857AC8B3A3D1BCABD3BEAC
A79688564D460B0A09040403000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000FF0000000000FF0000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000807070F0E0D59504AB29F95D2BDAFD5BFB2D5BFB2D5C0B2D6C0B2D6C0B2
D6C0B2D6C0B2D6C0B2D7C0B2D7C0B2D7C0B2D8C0B3D7C0B2D7C1B2D7C1B2D7C1B2D7C1B2
D7C1B2D7C1B1D7C1B1D7C1B1D8C1B1D8C1B1D8C2B1D8C2B1D8C2B1D8C2B1D8C2B1D8C2B1
D8C2B1D8C2B1D8C2B1D8C2B1D9C3B1D9C3B1C1AD9EA39285C2AE9ED5BFAED7C1B0D9C3B1
BCA8998B7C713E3732181513000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000003020226222049413D98887FCCB7ABD6BFB2D6BFB2D6C0B2D6C0B2D7C0B2D6C0B2
D6C0B2D6C0B2D6C0B2D7C0B2D7C0B2D7C0B2D7C0B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2
D7C1B2D7C1B2D8C1B2D8C1B2D8C2B2D8C2B2D8C2B1D8C2B1D8C2B1D8C2B1D8C2B1D8C2B1
D8C2B1D8C2B1D9C3B1D9C3B1D9C3B1D9C2B1D2BDACCAB5A6D2BDACD4BFADD3BDACD3BEAD
CEB9A8C7B3A197877B675C542A26220B0A09000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000001613126358529F8F85C8B3A7D4BEB1D6BFB2D6C0B2D6C0B2D7C0B2D7C0B2D6C0B2
D7C0B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C2B2
D7C2B2D7C2B2D8C2B2D8C1B2D8C2B2D8C2B2D8C2B2D8C2B2D8C2B1D8C2B1D8C2B1D8C2B1
D8C2B1D8C3B1D8C3B1D8C3B1D9C3B1D9C3B2DAC3B3D9C3B2D3BEADD2BCABD8C1B0DCC5B3
DCC5B3DDC5B3CDB8A7B19F905E534C171412000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000028242292827ACBB6A9D5BFB2D5BFB2D5C0B2D5BFB2D6BFB2D6BFB2D6C0B2D6C0B2
D6C0B2D6C0B2D6C0B2D6C1B2D6C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2
D7C1B2D7C2B2D7C2B2D7C2B2D7C2B2D7C2B1D8C2B1D8C2B1D8C2B1D8C2B1D8C2B1D7C2B1
D7C2B1D8C2B1D8C2B1D8C3B1D8C3B1D9C3B2DAC3B2D9C3B2BDAA9BAD9B8DCAB5A4DDC5B3
DDC5B3DDC5B3DDC5B4D6C0AF83756B1F1C19000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000FF0000000000000000000000000000
000000000000000000FF0000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010101050404
0908073F3834B29F94D5BFB2D5BFB2D5C0B2D5C0B2D5BFB2D6C0B2D6C0B2D6C0B2D6C0B2
D6C0B2D6C0B2D6C0B2D6C1B2D6C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2D7C1B2
D7C2B2D7C2B2D7C2B2D7C2B2D7C2B2D7C2B2D7C2B1D8C2B1D8C2B1D8C2B1D8C2B1D8C2B1
D8C2B1D8C2B1D8C3B1D8C3B1D9C3B2D9C3B2DAC4B3DAC4B3C5B1A2B8A596CBB6A6DCC5B3
DCC5B3DCC5B3DCC5B3D8C1B08A7C701F1C19000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000FF0000000000000000000000000000000000000000
000000000000FF0000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000807072B2624
51484485766EC9B4A9D5BFB2D5C0B2D5C0B2D5C0B2D5C0B2D5C0B2D5C0B2D5C0B2D6C0B2
D6C0B2D6C0B2D7C0B2D7C1B2D7C1B3D7C1B2D7C1B2D7C1B2D7C2B2D7C2B2D7C2B2D7C2B2
D7C2B2D7C2B2D7C2B2D7C2B2D8C2B2D8C2B2D8C2B2D8C2B2D8C3B2D8C3B2D8C3B2D8C3B2
D8C3B2D8C3B2D8C3B2D8C3B2D8C3B2D9C3B2DAC3B3D9C4B3D7C2B1D5C0AFD8C2B0DBC4B3
DCC5B3DCC5B4DCC5B4D8C1B18A7C701F1C19000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000FF0000FF0000FF0000000000FF0000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010101030303050505050404030202000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000211E1B726660
B39F95CBB6AAD5BFB2D5BFB3D5C0B3D5BFB3D5BFB3D5C0B3D5C0B3D6C0B3D6C0B3D6C1B3
D6C0B2D6C0B3D6C0B2D7C1B2D7C1B2D6C1B2D6C1B2D7C1B2D7C1B2D7C1B2D7C2B2D7C2B2
D7C2B2D7C2B2D7C2B2D7C2B2D7C2B2D7C2B2D8C2B2D8C2B2D8C2B2D8C2B2D8C2B2D8C3B2
D8C3B2D8C3B2D8C3B2D8C3B2D9C3B2DAC3B2DAC3B3DAC4B3DAC5B3DAC4B3DAC3B2D7C1B0
D1BBAAD3BDACDCC6B4CAB5A5796C62191714000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000B0A0A25211F3F39363A3431201D1B060505000000000000000000000000
00000000000000000000000000000000000000000000000008070714131159504BB5A198
D3BDB1D5BFB3D5BFB3D4BFB3D4BFB2D4BFB2D4BFB2D4BFB2D5C0B3D6C0B3D6C1B3D6C1B3
D6C0B2D6C0B2D6C0B2D6C0B2D7C1B2D6C1B2D6C1B2D7C1B2D7C1B2D7C2B2D7C2B2D7C2B2
D7C2B2D7C2B2D7C2B2D7C2B2D7C2B2D7C2B2D8C2B2D8C2B2D8C3B3D9C3B3D9C3B3D9C3B3
D9C3B3D9C3B3D9C3B3D9C3B2D9C3B3DAC3B3D9C4B3DAC4B3DAC4B3DBC5B3DBC5B3C8B4A3
A39285A69487CDB8A8A08F825149420D0C0B000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000808071B18172F2A2836312E
36312E36312E46403C6A5F5A8F8179877A73645A543B35321F1C1B0C0B0A0706061A1816
2E2A2737312E37312E37322E37322E37322E37322E25211F403A37736660B7A39AD2BCB1
D5BFB3D5BFB3D5C0B3D4BFB3D4BFB3D4BFB3D4BFB2D4BFB2D4C0B2D5C0B3D6C1B3D6C1B3
D6C1B3D6C0B2D6C0B2D6C1B2D6C1B2D7C1B2D7C1B3D7C1B3D7C2B3D7C2B3D7C2B3D7C2B2
D7C2B2D7C2B2D7C2B2D7C2B2D7C2B2D7C2B2D8C2B2D9C2B3D9C2B3D9C3B3D9C3B3D9C3B3
D9C3B3D9C3B3D9C3B3D9C3B3D9C3B3DAC4B3DAC4B3DAC4B3DAC5B3D8C2B1C0AD9D887B70
595149524942776B614E47401E1B19020202000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000001311103E38356A5F5A80736D
857871897C7593857EAA9A91C2AFA5BDABA0A6968D887B745E5550393431302B29544C47
786D66887C74887C74887C74897C74897C749082797E726AA4938AC8B4A8D4BEB3D5BFB3
D5BFB3D4BFB3D4BFB3D4BFB3D4BFB3D4BFB3D4BFB3D4C0B3D4C0B2D5C0B2D5C0B3D5C1B3
D5C1B2D6C1B3D7C1B3D7C1B3D7C1B3D7C1B3D7C1B3D7C1B2D7C1B2D7C1B2D7C2B2D7C2B2
D7C2B2D7C2B2D8C2B3D8C2B3D8C2B2D8C2B2D8C2B3D9C3B3D9C3B4D9C3B4D9C3B4D9C3B3
D9C3B3D9C3B3DAC3B3D9C3B3D9C4B3D9C4B3DAC4B4DAC5B4DAC5B4D5C0AFA0908349423C
221E1B1513101F1C1913110F060605000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000001F1C1A6D625DAD9C94C3B1A7
C6B3A9C8B4AAC8B5AAC9B5ABCAB6ACC9B6ABC8B5AAC2AFA5A2938983776F7C70689A8B82
B9A79DC6B4A8C6B4A8C6B4A8C7B4A8C8B6A9CBB8ABC5B3A7CFBBAFD5BFB3D5BFB3D4BFB3
D4BFB3D4BFB3D4BFB2D4C0B2D4C0B2D4C0B2D4C0B2D5C0B2D5C0B3D5C0B3D5C0B3D5C1B3
D5C1B3D5C1B3D6C1B3D6C1B3D7C1B3D7C1B3D7C1B3D7C1B3D7C1B3D7C2B3D7C2B2D7C2B2
D7C2B2D7C2B3D8C2B3D8C2B3D8C2B3D9C2B3D9C2B3D9C3B3D9C3B4D9C4B4D9C4B4D9C3B4
D9C3B3D9C3B3D9C3B3D9C3B3D9C4B4D9C4B4DAC5B4DAC5B4DAC5B4D4BFAE86796E1B1916
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000C0B0A1E1B1A312C2A
342F2D3833313D37343D3735393331352F2D332E2C332E2C4E464294867FC1AEA5CCB9AE
CCB9AECCB9AECDB9AECDB9AECDBAAFCBB8ADCAB7ACC7B5AAC2B0A5BDABA0BCAA9FC1AFA3
C6B4A8C9B6AAC9B6ABC9B7ABCAB8ACCCBAADCEBBAED0BCB0D2BEB2D4BFB3D4BFB3D3BFB2
D3BFB2D4BFB2D4BFB2D4BFB2D4BFB2D4BFB2D4C0B2D4C0B2D4C0B2D5C0B3D5C0B3D5C1B3
D5C1B3D5C1B3D5C1B3D6C1B3D6C1B3D6C1B3D6C1B3D7C1B2D7C1B2D7C1B2D7C1B2D7C2B3
D7C2B3D8C2B3D8C2B3D8C2B3D8C2B3D8C2B3D8C3B4D8C3B4D9C3B4D9C3B4D9C4B4D9C4B4
D9C4B4D9C4B4D9C4B4D9C4B4D9C4B4D9C5B4DAC5B4DAC5B4DAC5B4D5C0AF877A6F1D1917
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000090807151312221E1D3A35325D545080736E
877B7591837D9B8D869C8E8696878192847D94867F90827B968880B7A59CCAB6ACCCB9AE
CCB9AECCB9AECDB9AECDBAAFCDBAAFCBB8ADCBB7ACC9B6ABC9B6ABC8B5AAC8B5AAC9B7AB
CBB8ACCCB9ADCDBAAECEBBAFCEBBAECEBBAFCFBCAFD0BDB0D2BEB2D3BEB2D3BEB2D3BEB1
D3BEB1D3BEB1D3BEB1D3BFB1D4BFB2D4BFB2D4BFB2D4BFB2D4C0B2D5C0B2D5C0B3D5C0B3
D5C1B3D5C1B3D6C1B3D6C1B3D6C1B3D6C1B3D6C1B3D7C1B3D7C1B3D7C1B2D7C2B2D7C2B3
D7C2B3D7C2B3D8C2B4D8C2B4D8C3B4D9C3B4D9C4B4D9C4B4D9C4B4DAC4B5DAC5B5DAC5B5
DAC5B5DBC5B5DAC5B5DAC5B5D9C4B3D2BEADD0BDACD9C4B3DAC5B3CFBBAB97887C3B3530
090807000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000001917163E383663595580726EA5948DC1AEA7
C5B2A9C7B4ACC9B6ADC9B6ACC7B4ABC6B4ABC7B5ABC7B4ABC7B4ABCAB6ADCCB8AECCB9AE
CCB9AECCB9AECCB9AECDB9AECDBAAFC8B6ABCEBBB0CFBBB0CFBBB0CFBBB0CFBCB0CFBCB0
CFBCB0CFBBAFCFBCAFCFBCAFCFBCAFCFBCAFD0BDB0D1BDB1D2BEB1D2BEB1D2BEB1D2BEB1
D2BEB1D3BEB1D3BEB1D3BEB1D3BFB2D3BFB2D4BFB2D4BFB2D4BFB2D4C0B2D4C0B2D5C0B3
D5C1B3D5C1B3D6C1B3D6C1B3D6C1B3D6C1B3D6C1B3D6C2B3D6C2B3D7C2B3D6C2B3D7C2B3
D7C2B3D7C2B3D8C2B4D8C2B4D8C3B4D9C3B4DAC4B5DAC4B5DAC5B5DBC5B6DBC5B6DBC5B6
DCC5B6DCC5B6DCC5B6DBC5B5D9C4B4C3B0A1C1AE9FD8C2B2DAC4B3CFBBABAE9D90665C54
3E3833342F2B1A1816010101000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000C0A0A1B1818282423252120282422322D2B332E2D342F2E322D2C1F1C1B
0C0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000002B27256A605CA6958EB4A29CC2AFA7CBB7AE
CCB8AFCBB8AFCBB8AFCBB8AFCBB8AFCAB8AEC9B8AECAB8AECBB9AFCDB9AFCCB9AFCCB9AF
CCB9AFCCB9AFCCB9AECDB9AECDBAAEC7B5AACEBBAFCFBBB0CFBBB0CFBBB0D0BBB0D0BCB0
D0BCB0CFBCB0CFBBAFCEBCAFCFBCAFCFBCB0D0BCB0D0BDB0D1BDB0D1BEB1D1BEB1D1BEB1
D1BEB1D2BEB1D3BEB1D3BFB1D3BFB1D3BFB2D4BFB2D4BFB2D4BFB2D4C0B2D4C0B2D4C0B2
D5C1B3D5C1B3D5C1B3D6C1B3D6C1B3D6C2B3D6C2B3D6C2B3D6C2B3D7C2B3D7C2B3D7C2B3
D7C2B3D8C2B4D8C3B4D8C3B4D8C3B5D9C4B5D9C4B5DAC4B5DBC5B6DBC5B6DBC5B6DBC5B6
DCC5B6DCC5B6DCC5B6DCC6B6DBC5B5CAB6A7C4B1A2D0BBABD3BEAECBB7A7B8A697877A70
8E807798897E645A52191714000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000001F1C1B4942406D625F584F4E59504E7569668275728D7F7B8B7D7A645A57
3933321D1A19110F0F040404000000000000000000000000000000000000000000000000
0000000000000000000000000000000605054B43419A8C85C8B5ADCBB8AFCBB8AFCBB8AF
CBB8AFCBB8AFCBB8AFCBB8AFCBB8AECAB8AEC9B7ADCAB8AECBB8AFCBB9AFCCB9AECCB9AE
CCB9AECCB9AECCB9AECCB9AECCB9AECAB8ADCDBAAFCFBBB0CFBBB0CFBBB0D0BCB0D0BCB0
D0BCB0CFBCB0CFBCAFCEBCAFCFBCAFCFBCB0D0BCB0D0BCB0D0BDB0D1BDB1D1BEB1D1BEB1
D1BEB1D1BEB1D2BFB1D3BFB1D3BFB1D3BFB1D3BFB1D3BFB1D3C0B1D4C0B2D4C0B2D4C0B2
D4C1B3D5C1B3D5C1B3D5C1B3D5C1B3D6C2B3D6C2B3D6C2B3D6C2B3D6C2B3D7C2B3D7C2B3
D7C2B4D8C2B4D8C2B4D8C3B4D8C3B5D9C4B5DAC4B5DBC5B6DBC5B6DBC5B6DCC5B6DCC5B6
DCC6B6DCC6B6DCC6B6DCC6B6DCC6B6D8C2B2D4BFAFBFAC9EA392868A7D728F8276A7968A
CBB6A7D4BFAEAD9C8E46403B000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000FF0000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000101010807070F0D0D100F0E
090808020202332E2D786C69B19F9A857774847774B5A39EBCA9A5C1AEA9BFABA79B8B87
796D695E55523731300D0C0C000000000000000000000000000000000000000000000000
000000000000000000000000000000131211756965BAA8A0CAB7AFCBB8AFCBB8AFCBB8AF
CBB8AFCBB8AFCAB8AFCAB8AECAB8AECAB8AEC9B7AECAB8AECAB8AECBB8AFCBB9AECCB9AF
CCB9AFCCB9AECBB8AECBB9AECDBAAFCCB9AECDBAAFCFBBB0CFBBB0CFBCB0CFBBB0CEBCB0
CEBCAFCEBCAFCFBCB0CFBCB0CFBCB0CFBCB0CFBDB0CFBDB0D0BDB0D0BDB0D1BEB1D1BEB1
D1BEB1D1BEB1D1BEB1D2BFB1D2BFB1D2BFB1D3BFB1D3BFB1D3BFB1D3C0B1D4C0B2D4C0B2
D4C0B2D4C1B2D5C1B3D5C1B3D5C1B3D5C2B3D6C2B3D6C2B3D6C2B3D6C2B3D7C2B3D7C2B4
D8C2B4D8C2B4D8C2B4D8C3B4D8C3B5D9C4B5DAC5B6DCC5B7DCC6B7DCC6B7DCC6B7DCC6B7
DCC6B6DCC6B6DCC6B6DCC6B6DAC5B5C0AC9D95867B877A7084776D9D8D81B5A495CDB9A9
D4BFAFDBC5B4C6B3A3695E56000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000012111026212135302F3E38374C44434C4543
2C28270B0A0A2C2727675C5A998A86847774867976A69692B5A29EC1AEAAC2AFAAAE9D99
AB9995A4938F7368643D3735262322151313050504030202050504060605060605060605
0504040404040605050B0A0A0D0C0C383230A5958FC9B6AECBB7AFCAB7AFCBB7AFCBB8B0
CCB8B0CBB8B0CAB8AFC9B7AEC9B7AEC9B7AEC9B8AEC9B8AECAB8AECAB8AECBB8AECBB9AF
CCB9AFCCB9AFCCB9AFCCBAAFCCBAAECDBAAFCEBAAFCFBCB1CFBCB1CEBBB0CDBBAFCEBBAF
CDBBAFCDBBAECEBCAFCEBCAFCEBCAFCFBCAFCFBCB0CFBCB0CFBCAFD0BDAFD0BDB0D1BEB1
D1BEB1D1BEB1D2BEB1D2BFB2D2BFB2D2BFB2D2BFB2D2BFB1D3C0B1D3C0B1D4C0B2D4C0B2
D4C0B2D4C0B2D4C1B2D5C1B3D5C1B3D5C1B3D5C2B3D6C2B3D6C2B3D6C2B3D7C2B4D8C2B4
D8C3B4D8C3B4D8C3B4D8C3B5D9C4B5DAC5B6DCC6B7DCC6B7DCC6B7DCC6B7DCC6B7DCC6B7
DCC6B7DCC6B6DCC6B6DCC6B6DAC5B5BAA89A84776D86796FB3A194D3BEAED4BFAFD1BDAD
C9B5A5CCB8A8AB9A8C554D46000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000100F0F5A5050928482
B2A09EBDABA9C4B2AFC5B2AFC5B3B0C7B4B1C7B4B1C6B3B0C3B1AEAF9E9B958684928481
A1918EBBA8A5B5A39FB6A4A0C2B0ABC8B5B0C8B5B0C8B5B0C8B5B0C8B6B0C8B6B0C9B6B0
C9B6B0C9B6B0C9B6B0C9B6B0C9B6B0C9B6B0C9B7B0CAB7B0CBB8B2CCB8B2CBB9B2CAB8B1
CAB8B1CBB8B1C9B7B0C8B7B0C8B7AFC8B7AFC7B7AEC7B6AEC7B7AEC7B7AEC7B7AEC7B7AE
C8B7AEC8B7AEC8B8AEC8B8AEC8B8AEC9B8AEC9B8AEC9B8AEC9B8AEC9B8AECAB9AFCAB9AF
CAB9AECAB9AEC9B9AEC9B9AECAB9AECAB9AECAB9AECABAAECABAAECBBAAECBBAAFCCBBAF
CCBBAFCCBBAFCDBBAFCDBBAFCDBCAFCDBCAFCEBCAFCEBDB0CEBDB0CEBDB0CEBDB0CFBEB0
CFBEB0CFBEB0CFBEB0D0BEB0D0BEB0CFBEB0D0BEB0D0BFB0D0BFB0D1BFB1D2C0B2D3C1B2
D3C1B2D3C1B2D3C1B2D4C1B3D4C1B2D4C1B2D4C2B3D5C2B3D6C3B4D6C3B4D6C3B4D7C3B5
D8C3B5D8C4B6D8C4B6DAC6B8DCC7B8DCC7B8DCC7B8DCC7B8DCC7B8DCC7B8DCC7B8DCC7B8
DCC7B8DCC7B8DCC7B8DCC7B8DDC8B8DEC8B8DEC8B8DDC8B8D8C4B3B4A395695F57191715
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000404040908082D2929938583C0AEAC
C9B6B4C8B6B3C8B6B2C8B5B2C7B4B1C7B4B1C7B4B1C7B4B1C7B4B0BEABA8BBA9A6BEACA8
B19F9DB8A7A4A69693A49490BCAAA6C8B5B1C8B6B1C8B6B1C9B6B1C9B6B1C9B6B1C9B6B0
C9B6B0C9B6B0C9B6B0C8B6B0C9B6B0C9B7B0C9B7B0CAB8B1CBB8B2CCB9B3CBB9B2CBB8B1
CAB8B1CAB8B1C8B7B0C8B7AFC8B7AFC7B7AFC7B6AEC7B7AEC7B7AEC7B7AEC7B7AEC7B7AE
C8B7AEC8B7AEC8B8AEC8B8AEC8B8AEC9B8AEC9B8AEC9B8AEC9B8AEC9B9AECAB9AFCBBAB0
CCBAB0CAB9AFCAB9AEC9B9AEC9B9AECAB9AECABAAECABAAECABAAECBBAAFCBBAAFCBBAAF
CCBAAFCCBBAFCCBBAFCDBCAFCDBCAFCDBCAFCDBCAFCEBDAFCEBDAFCEBDAFCEBDAFCEBDAF
CEBDAFCEBEAFCFBEB0CFBEB0CFBEB0CFBEB0CFBEB0D0BEB0D0BFB0D0C0B0D1C0B1D3C0B2
D3C1B2D3C1B2D3C1B2D4C1B3D4C1B3D4C1B3D4C1B3D4C2B3D5C3B4D5C3B4D6C3B4D7C3B5
D7C3B5D7C4B6D8C5B6DBC7B8DCC7B9DCC7B9DCC7B9DCC7B9DCC7B8DCC7B8DCC7B8DCC7B8
DCC7B8DCC7B8DCC7B8DDC8B8DDC8B9DEC8B9DEC8B8DCC7B7B3A294584E4923201D020201
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF0000FF0000FF0000000000FF0000FF0000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000006A6160BCABAAC7B6B4C6B5B3C6B5B3C6B4B3C5B4B3C5B4B3C5B4B2C4B3B1C4B3B1
C3B3B0C0B0ADB9AAA7AFA19EBBABA8C5B5B2C5B5B2C4B4B1C4B4B1C4B4B1C4B5B1C4B5B1
C4B5B1C4B5B1C4B5B1C4B5B1C5B5B1C5B5B1C5B6B1C7B7B2C7B7B2C6B7B1C6B6B1C6B7B1
C6B7B1C7B7B2C7B7B2C8B7B2C8B8B2C8B8B2C8B8B2C8B8B2C9B9B2CAB9B3CBBAB3CCBBB5
CDBBB5CABAB3C8B9B1C7B8B0C7B8B0C7B8B0C7B8B0C7B8B0C7B9B0C8B9B0C8B9B0C9BAB1
CABAB1CABAB1CABAB1CABAB1CABAB1CABAB1CABAB1CABAB1CABAB1CABBB1CABBB1CABBB1
CABBB1CABBB1CABBB1CABBB1CBBCB1CBBCB1CBBCB1CBBCB1CBBCB1CCBDB1CDBDB2CDBDB2
CDBEB2CEBEB2CEBEB2CEBEB2CEBFB2D0BFB4D0BFB4D0C0B4D0C0B4D0C0B4D0C0B4D0C0B4
D0C0B4D1C1B4D1C2B5D3C2B5D3C2B5D3C2B5D4C3B6D4C3B6D4C3B6D4C3B6D4C3B6D5C3B6
D5C4B6D6C4B8D6C5B8D7C5B8D7C5B9D8C6B9D9C6B9D9C6B9BCABA036322E000000000000
0000000000000000001B19176E655EB1A196B6A79BB6A79BA1938761585212100F000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000E0D0D383333
5E5656AB9D9BC5B4B2C6B5B3C6B4B3C5B4B3C5B4B3C5B4B3C5B4B2B4A5A3AA9C9AB5A6A4
B7A7A5B6A7A5C2B3B0B9AAA7BCADAAC2B3B0C4B4B1C4B4B1C4B5B1C4B5B1C4B5B1C4B5B1
C4B5B1C4B5B1C5B5B1C5B5B1C5B6B1C5B6B1C6B7B2C8B7B3C7B7B2C6B7B2C6B7B1C6B7B1
C7B7B2C7B7B2C7B7B2C8B8B2C8B8B2C8B8B2C9B9B2C9B9B2C9B9B3CCBCB5CCBBB5CCBBB5
CCBBB5CABAB3C8B9B2C7B8B1C7B9B0C7B8B0C7B9B0C7B9B0C8B9B0C8B9B0C8B9B1C9BAB1
CABAB1C9BAB1C9BAB1C9BAB1C9BAB1CABAB1CABAB1CABAB1CABBB1CABBB1CABBB1CBBBB1
CBBBB1CBBCB1CABBB1CBBCB1CBBCB1CBBCB1CBBCB1CCBDB1CCBDB2CCBDB2CDBDB2CDBEB2
CDBEB2CEBEB2CEBFB3CFBFB3CFBFB3CFBFB4D0C0B4D0C0B4D0C0B4D0C0B4D0C0B4D1C1B4
D1C2B4D2C2B5D3C2B6D3C2B6D4C2B6D4C2B6D4C3B6D4C3B6D4C3B6D5C3B6D5C4B6D6C5B8
D8C5B9D8C5B9D8C5BAD9C6BAD9C7BADAC7BADAC7BACDBBAF8F827A201D1B000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000001312123C3737625A5A9C8F8FC3B3B2
C5B4B4C5B4B3C4B4B3C4B4B3C4B4B3C4B4B3C4B4B3C4B4B3C4B4B3C3B3B1C2B3B1C3B4B2
C3B4B1C3B4B1C3B4B1C3B4B1C4B5B1C4B5B1C4B5B1C4B5B1C4B5B1C4B5B1C4B5B1C4B5B1
C5B6B1C5B6B2C6B6B2C6B6B2C6B7B2C6B7B2C6B7B2C7B7B2C7B7B2C7B7B2C7B7B2C7B7B2
C7B8B2C7B8B2C8B8B2C8B9B2C8B9B2C9B9B3C9B9B3C5B6ADC4B6AACEBDB7CFBDB8CEBDB8
CDBDB6CABBB3C8B9B2C8B9B2C8B9B2C7B9B1C7B9B1C7B9B1C8BAB1C9BAB2C9BAB2C9BAB1
C9BAB1C9BAB1C9BAB1C9BBB1CABBB1CABBB1CABBB1CABBB1CABBB1CABBB1CBBCB2CDBEB4
CDBEB4CDBEB3CDBDB3CDBEB3CDBEB3CEBEB4CDBEB4CDBEB4CDBEB3CDBEB3CEBFB3CEBFB3
CFC0B4CFC0B4CFC0B4CFC0B4CFC0B4CFC0B4CFC0B4CFC0B4D0C0B4D0C0B4D0C1B4D1C1B5
D2C2B5D3C3B6D4C3B6D4C3B6D4C3B6D5C4B8D6C5B9D6C5B9D7C5BAD8C5BAD8C5BAD9C6BA
D9C6BAD9C7BBD9C7BBDAC7BBDAC7BBBDADA27B7169504944282522000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000002A28287C7272AE9F9FC1B1B0C5B4B3
C5B4B3C4B4B3C4B4B3C4B4B3C4B4B3C4B4B3C4B4B3C4B4B3C4B4B3C4B4B3C4B4B2C3B4B2
C3B4B2C3B5B2C4B5B2C4B5B2C4B5B2C4B5B2C4B5B2C4B5B2C4B5B2C4B5B2C4B6B2C4B5B1
C2B3AFC3B4B0C6B6B2C6B6B2C6B6B2C6B6B2C6B7B2C7B7B2C7B8B3C7B8B3C7B8B2C7B8B2
C7B8B2C8B8B2C8B8B2C8B8B2C8B9B2C9B9B3CABAB4C0ADA8C1ACA7D0BEB9CFBEB8CFBEB8
CDBDB6CABBB3C8B9B2C8B9B2C8B9B2C7B9B1C7B9B1C7B9B1C8BAB1C9BAB2C9BAB2C9BAB2
C9BBB2CABBB2CABBB2CABBB2CABBB2CABBB2CABBB2CABCB1CABCB2CBBCB2CCBDB3CDBFB5
CEBFB5CEBFB5CEBEB4CEBEB4CEBEB4CFBFB5CFC0B5CEC0B5CEC0B4CEBFB4CEBFB4CFC0B4
CFC0B5CFC0B4D0C0B4D0C0B4D0C1B4D0C1B4D0C1B4D0C1B4D0C1B4D0C1B4D0C1B4D1C2B5
D2C2B5D2C3B6D3C3B6D3C3B6D3C3B6D5C4B9D7C6BAD8C6BBD8C6BBD8C6BBD9C6BBD9C7BA
D9C7BBD9C7BBD9C7BBD9C7BBDAC7BBA99B913A35320E0D0C070606000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000302020E0D0D191717575050AEA09FC4B3B3C5B5B4C4B4B3
C4B4B3C4B4B3C4B4B3C4B4B3C4B4B3C3B4B2C3B4B2C3B4B2C3B4B2C4B4B2C3B4B2C3B4B1
C3B4B2C3B4B2C3B5B2C3B5B2C3B5B2C3B4B1C3B5B1C3B5B1C3B5B1C4B5B1C4B5B1C1B3AF
C0B1AEC5B6B2C6B6B3C6B7B3C6B7B3C6B7B2C7B7B2C7B7B2C7B7B2C7B7B2C7B8B2C7B8B2
C8B8B3C8B9B3C8B9B3C8B9B3C9B9B3CABAB4CABAB4B9A39FAF9B97D0BFBACFBEB9CFBEB8
CDBDB6CABBB3C9BAB2C8B9B2C8B9B2C8BAB2C7BAB1C8BAB1C8BAB2C9BAB2C9BAB2C9BAB2
C9BAB2CABBB2CABBB2CABCB2CBBCB2CBBCB2CBBCB2CBBCB2CBBCB2CCBDB3CEBFB5CEBFB5
CEBEB4CEBEB4CEBEB4CEBEB4CFBFB5D0C0B5D0C0B5D0C0B5D0C0B5CFC0B5D0C1B5D0C0B5
D0C0B5D0C0B5D0C0B5D0C1B5D0C1B4D0C1B4D0C1B4D1C1B4D1C1B4D1C1B4D1C1B5D2C2B5
D2C2B5D2C3B6D3C3B6D3C3B6D3C3B6D4C4B7D7C5BAD9C7BBD9C7BBD9C7BBD9C7BBD9C7BB
D9C7BBD9C7BBD9C7BBD9C7BBCBBBAF8C80781F1C1B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000A09091513132623234841416B62629D9090C1B1B0C4B4B3C5B4B3C4B4B3
C4B4B3C4B4B3C4B4B3C4B4B3C3B4B2C3B4B2C3B4B2C3B4B2C3B4B2C3B4B2C3B4B2C3B4B2
C3B4B2C3B5B2C3B5B2C3B5B2C3B5B2C3B5B1C3B5B2C3B5B2C4B5B2C4B5B1C4B6B1C3B4B0
C4B5B1C6B7B3C6B7B3C6B7B3C6B7B3C6B7B3C7B7B3C7B8B3C7B8B3C7B8B3C7B8B3C8B8B3
C9B9B4C9B9B4CABAB4CABAB4CABAB4CABBB5CAB8B3BEA8A3A69490C2B2ADCEBDB7CEBDB7
CDBDB6CABBB3C9BAB2C9BAB2C8BAB2C9BAB2C9BAB2C9BAB2C9BAB2C9BAB2C9BBB2C9BBB2
C9BBB2CABBB2CBBCB3CBBCB3CBBCB3CBBCB3CCBDB3CCBDB3CCBEB4CDBEB4CEBFB5CEBEB5
CDBEB4CDBEB4CEBEB4CFBFB5D0C0B6D0C0B6D0C0B6D1C1B6D0C1B6D0C0B6D0C1B6D0C1B5
D0C0B5D0C0B5D0C1B5D0C1B5D0C1B5D0C1B5D0C1B5D1C1B4D1C1B4D1C1B4D1C2B5D2C2B6
D2C2B6D2C3B6D2C3B6D3C3B6D3C3B6D4C4B8D8C6BBD9C7BCD9C7BCD9C7BBD9C7BBD9C7BB
D9C7BBDAC8BCC5B5AAB1A29892867E564F4A0E0D0C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000161413312C292824220D0C0B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000002623234F4949786E6E9A8D8DB5A7A7C1B2B2C5B5B4C4B4B4C4B4B4C4B4B3
C3B4B3C4B4B3C4B4B3C4B4B3C3B4B2C3B4B2C3B4B2C3B4B2C3B4B2C3B4B2C3B4B2C3B4B2
C3B4B2C3B5B2C3B5B2C3B5B2C3B4B1C2B4B1C3B5B1C2B4B0BEB0ACC2B4B0C4B6B2C4B6B2
C4B6B2C5B6B2C5B6B2C6B7B3C6B7B3C6B7B2C7B7B3C7B7B3C7B8B3C7B8B3C8B9B3C9B9B4
C9BAB5CABAB5CABAB5CABAB4CABBB4CBBBB5CCBBB6CAB7B2C2B0ABBAABA6CABAB5CEBDB7
CDBDB6CABBB3C8BAB2C8BAB2C8BAB2C9BAB2C9BAB2C9BAB2C9BAB2C9BBB2C9BBB2C9BBB2
CABBB2CBBCB3CDBEB5CCBEB4CCBDB4CDBDB5CEBEB5CFC0B5CEBFB6CEBFB5CEBFB5CEBEB5
CDBEB4CEBEB4CEBFB5CFC0B5D0C0B6D0C0B6D0C1B7D1C1B7D1C1B6D0C1B6D0C1B6D0C1B6
D0C1B5D0C0B5D0C1B5D0C1B5D0C1B5D1C1B5D1C1B5D1C1B5D1C1B5D1C1B5D1C2B5D1C2B5
D1C2B6D2C3B6D3C3B7D3C3B7D3C4B7D5C4B8D7C7BAD9C7BCD9C7BCD9C7BCD9C7BBD9C7BB
D9C7BCDAC8BC9A8E855B534E302C29171514000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000100E0D302C293F39361E1C1A02020223201E433E39
48413D48413D332E2B4A433E83786F6A615A24211F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003D3838
897E7EB6A8A8C2B3B3C4B5B5C4B4B4C4B4B4C4B4B4C4B4B4C3B4B4C3B4B4C3B4B4C3B4B4
C3B4B3C2B4B3C2B4B3C2B4B2C2B4B2C2B4B2C2B4B2C2B4B2C2B4B1C2B4B1C3B4B2C3B5B2
C3B5B2C3B5B2C3B5B2BDAFACBFB1AEC2B4B1C3B4B1C5B6B3C5B6B3C4B6B3C4B6B2C4B6B2
C4B6B2C4B7B2C4B7B2C5B7B2C6B8B3C7B8B3C7B8B3C8B9B3C8B9B4C9BAB5CABAB5CABAB5
CABBB5CBBBB6CCBCB7CDBDB8CDBDB8CEBEB9CFBEB9D0BEBAD0BEBBCBBAB5A59692B9A9A6
CDBDB7CCBDB5CBBCB5CABCB4CBBDB5CDBEB6CFBFB8CFBFB9D0BFB9CFBFB8CFBFB8CFBFB8
CFBFB8CFC0B8D0C0B8D1C0B9D2C1BAD2C1BAD2C1B9D1C0B9D1C1B9D1C1B9D1C1B9D1C1B8
D1C1B8D1C1B8D1C1B8D1C1B8D1C1B8D1C1B8D1C1B8D2C1B8D2C1B8D2C1B8D2C2B8D2C2B8
D2C2B8D2C2B7D2C2B7D2C2B7D2C2B7D3C2B7D3C3B8D3C3B8D4C4B9D4C4B9D3C4B9D2C3B7
D3C4B7D4C4B8D5C5B9D7C6BAD7C6BAD8C6BBD7C6BBCBBAB0B2A49BAB9E94AA9C93877D75
45403C000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000040403
2C2926534C47796F68BFAFA4DECBBFE6D2C5E5D2C4E5D1C3E5D1C3E5D1C3E5D1C3E5D1C3
E2CFC0E1CEBFE3CFC0E3D0C1E4D1C2D9C7B8B1A296CDBBADE6D3C3E6D3C3E6D3C3B6A69A
46403B040404000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000050505100F0F1B19196C6464
B3A5A5C5B5B5C4B5B5C4B4B5C4B4B4C3B4B4C3B4B4C3B4B4C3B4B4C3B4B4C3B4B4C2B4B3
C2B4B3C2B4B3C2B4B2C2B4B3C2B4B2C2B4B2C2B4B2C2B4B2C2B4B2C2B4B2C2B5B2C3B5B2
C3B5B2C3B5B2C3B5B2B6A9A6BBAEAAC0B3AFC2B4B0C5B6B3C5B6B3C4B6B3C4B6B2C4B6B2
C4B6B2C4B6B2C4B7B2C5B7B2C6B8B3C6B8B3C7B8B3C8B9B4C9BAB5CABAB6CABAB6CABBB6
CBBBB7CBBCB7CCBCB7CCBCB7CDBDB8CEBEB9CFBEBAD0BEBBD1BFBBD1C0BCCBBAB6BDADA8
CCBCB6CDBDB7CCBDB5CCBCB5CCBDB5CDBEB7CEBEB7CFBFB8CFBFB8D0BFB9D0C0B9D1C0B9
D1C0B9D1C0B9D1C0B9D1C0B9D1C0B9D1C0B9D1C0B9D1C0B9D1C1B9D2C1B9D2C1B9D2C1B9
D1C1B8D1C1B8D1C1B8D1C1B8D1C1B8D1C1B8D2C2B8D2C2B8D2C2B8D2C2B8D2C2B8D2C2B8
D2C2B8D2C2B8D3C3B8D3C3B9D3C3B9D4C4B9D4C4BAD6C5BBD7C5BCD7C6BBD5C5BAD3C4B9
D5C5B9D6C6BBD7C7BCD8C7BCD9C7BCD9C8BDCDBDB29C8F875C555058514C58514C46413D
24211F000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000090807
5E5651B1A2988A7F77A4958CD4C2B5BAA99FB2A298D3C1B5E5D1C3E5D1C3D9C6B9CBBAAD
D5C3B4D5C3B5B7A89BC6B5A8DECBBDDBC8BAD5C3B5E2CEBFE5D2C2E6D2C2E5D2C2D3C1B2
6E645C0A090900000000000000000000000000000000000000000000000015131237332E
433D381F1C1A000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000302034944448A8080B8A9AAC0B1B2C4B5B5C4B5B5
C4B4B5C3B4B5C3B4B4C3B4B4C3B4B4C3B4B4C3B4B4C3B4B4C3B4B4C2B4B4C2B4B3C1B3B3
C1B3B3C1B3B2C1B3B1C1B3B2C1B4B2C3B5B3C3B5B3C3B5B3C3B5B3C3B5B3C3B5B3C2B4B2
C2B5B2C2B4B1C2B5B1C2B5B2C2B5B2C3B6B2C3B6B2C3B6B2C3B6B2C3B6B2C3B6B2C3B6B2
C4B6B2C4B7B2C4B7B2C4B7B2C5B7B2C5B8B3C6B8B3C9BAB6CABAB6CABBB7CBBCB7CBBCB7
CCBCB7CCBCB8CDBDB8CEBEB9CEBEBACFBEBACFBEBAD0BFBBD0BFBCD0BFBCD1C0BCD1C0BC
CFBFB9CBBCB5CCBCB6CDBEB7CEBFB8CEC0B8CFC0B9CFC0B9D0C0B9D0C0BAD0C0BAD1C0BA
D1C0BAD1C0BAD1C1B9D1C1B9D1C1B9D1C1B9D1C1B9D1C1B9D1C1B9D1C1B9D1C1B9D1C1B9
D1C1B8D1C1B8D1C1B9D1C2B9D2C2B9D2C2B9D2C2B9D2C2B9D2C2B9D2C3B9D3C3BAD3C3BA
D4C4BBD5C5BBD6C5BCD6C5BCD7C5BCD7C6BDD7C6BDD8C7BDD9C7BED9C7BDD9C7BDD9C8BD
D9C8BDD9C8BDD9C8BDD9C8BDB7A99F5F5853322F2C1A1816010101000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000001816157E746CE1CEC1E2CFC2E2CFC2E3D0C2E3D0C2E4D1C3E4D1C3E4D1C2E4D1C2
E2D0C1DDCABCE0CDBFE5D1C2E5D1C2E5D1C2E5D1C2E5D2C2E5D2C2E5D2C1E5D2C1E5D2C1
E4D2C2E4D1C1C2B2A4716860403B36655D55A39589BFAFA1B6A699B3A49692867A7E7369
887D72968A7E92867B4A433E080807000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000E0D0C211E1B2B28233E3933645C52756C5F38342E050504000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000A09091715152B29297D7474B4A6A7C5B6B7C5B6B7C4B5B6C4B5B5
C4B4B5C3B4B5C3B4B4C3B4B4C3B4B4C3B4B4C3B4B4C2B4B4C2B4B3C1B4B3C2B4B3C1B4B3
C1B4B3C1B3B2C1B3B2C1B4B2C1B4B2C1B4B2C1B4B2C1B4B2C1B4B2C2B5B2C2B5B3C2B5B3
C2B5B2C2B5B2C1B5B1C2B5B2C2B5B2C2B5B2C3B5B2C3B6B2C3B6B2C3B6B2C4B7B3C4B7B3
C4B7B3C4B7B3C4B7B2C4B7B2C4B7B2C5B7B2C5B8B3C9BAB5CABBB7CABCB7CBBCB7CBBCB7
CCBCB7CCBDB8CEBEB9CEBEBACEBEBACFBEBACFBEBAD0BFBBD0C0BCD0C0BCCFC0BBD0BFBB
CFBFB9CCBDB6CABBB4CEBEB7CFBFB9CFC0B9CFC0B9D0C0BAD0C0BAD1C0BBD1C0BAD1C0BA
D1C0BAD1C0BAD1C0BAD2C0BAD2C1BAD2C1BAD2C2BBD2C2BBD2C2BBD2C2BBD2C2BAD1C2B9
D1C1B9D1C1B9D1C2B9D1C2B9D1C2B9D2C2B9D3C2BAD3C2BAD3C3BAD3C3BBD3C3BBD4C4BB
D5C4BCD6C5BCD6C5BCD7C5BCD7C6BCD7C6BDD7C6BDD8C7BDD9C7BED9C7BED9C8BDD9C8BD
D9C8BDD9C8BDD9C8BDD6C5BBA79A912B2825000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000101011615132C29262F2B282F2B282F2B28
2F2B28423D39958880E3D0C3DAC7BBD9C7BAD9C7B9DFCCBEDDCBBCCCBCAFCFBEB1DFCCBE
E1CFC0E3D0C1E5D1C2E5D1C2E5D1C2E5D1C2E5D2C2E5D2C2E5D2C2E5D2C1E5D2C1E5D2C1
E5D2C1E5D2C1E2D0BFD2C0B1BAAB9CC5B6A6DFCDBBE6D3C1E5D3C1E5D3C1D8C6B5C7B8A7
C6B6A6D3C1B1E0CDBC7D72690E0D0C000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000C0B0A201D1A
2925221413110000002D2925686056887E70998E7EB9AB98CABBA6675F540A0908000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000211F1F4F49497E7475ADA0A1C2B4B4C5B6B7C4B5B6C4B5B5C3B4B5
C3B4B5C3B4B5C3B4B4C2B4B4C2B4B4C2B4B4C2B4B4C2B4B4C2B4B3C1B4B3C1B4B3C1B4B3
C1B4B3C2B4B3C1B3B2C1B4B2C1B4B2C1B4B2C1B4B2C1B4B2C1B5B2C1B4B2C2B5B2C3B5B3
C2B5B2C1B5B2C1B5B2C2B5B2C2B5B1C2B5B1C2B5B1C2B5B1C2B6B2C3B6B2C4B7B3C6B8B5
C5B7B3C4B7B3C4B7B2C4B7B3C4B7B3C5B8B3C5B8B3C9BBB6CABBB7CABBB7CABCB7CBBCB8
CCBDB8CDBDB9CEBEBACEBEBACEBEBACFBFBACFBFBBD0BFBCD0BFBCCFBFBBCEBFB9CEBEB8
CDBEB8CDBEB7CCBDB6CEBFB7CFBFB9CFC0B9CFC0B9CFC0B9D0C0BAD1C0BBD1C0BBD1C0BB
D2C1BBD2C1BBD2C1BBD2C1BBD2C1BBD2C1BBD3C2BBD3C2BBD3C2BBD3C2BBD2C3BBD2C2BA
D1C2B9D1C2B9D1C2B9D1C2B9D2C2B9D3C2BAD3C2BAD2C3BAD3C3BBD3C3BBD3C4BBD4C4BC
D6C5BCD6C5BCD6C5BDD7C6BDD7C6BDD7C6BDD7C6BDD8C7BED8C7BED9C8BED9C8BED9C8BE
D9C8BDD9C8BDD8C7BCC8B9AF887B75191716000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000001715146E655FA99B92AE9F96AE9F96AE9F96
AE9F96B4A49BCCBBB0E3D0C3D8C7BBD8C6B9E4D1C3E4D1C3E4D2C2C8B8ABA89A8FB8A99E
DBC9BBE4D0C2E4D1C2E4D1C2E4D1C2E5D1C2E5D1C2E5D1C2E5D1C2E5D2C1E5D2C1E5D3C1
E5D2C1E5D2C1E5D2C1E5D3C1E5D3C1E5D3C1E5D3C1E5D3C1E5D3C1E5D3C1E4D2C0E4D2BF
E4D2BFE5D3C0E4D1BFB3A496796F6550494325231F090908000000000000000000000000
000000000000000000000000000000000000010101030202030303161412514B438B8073
9D9081736A5F4A443D7D7467BBAD9AE5D4BDE5D4BDDAC9B3BAAB98544D45090908000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000464040928889BDAFB0C3B4B5C4B6B6C4B5B6C4B5B5C3B4B5C3B4B5
C3B4B5C2B4B5C1B3B4C1B4B4C1B4B4C2B4B4C2B4B4C1B4B3C1B3B3C1B3B3C1B4B3C1B4B3
C1B4B3C1B4B2C1B4B2C0B4B2C0B4B2C0B4B2C0B4B2C1B4B2C1B4B2C1B5B2C2B5B2C2B5B2
C1B5B2C1B5B2C1B5B2C1B5B2C2B5B2C2B6B2C3B6B2C3B6B2C3B6B2C4B6B3C6B8B5C7B9B6
C5B8B3C4B7B3C4B7B3C4B8B3C5B8B3C5B8B3C6B8B4CABBB7CABBB7CABCB7CBBCB8CBBDB8
CCBDB8CCBDB9CEBEBACEBEBACFBEBACFBFBBD0BFBCD0C0BDD0C0BDCEBFBBCDBEB8CDBEB7
CDBEB7CDBEB7CDBEB7CEBFB8CFC0B9CFC0B9CFC0B9CFC0B9D0C0BAD1C0BBD1C0BBD1C0BB
D1C0BBD1C1BBD1C1BBD1C1BBD2C1BBD2C1BBD2C2BCD2C2BBD2C2BBD1C2BAD1C2BAD1C2BA
D1C2B9D1C2B9D1C2B9D2C2B9D2C2BAD2C2BAD3C2BAD3C3BBD3C3BBD3C4BBD4C5BCD5C5BC
D6C5BCD6C6BDD7C6BDD7C6BDD7C6BDD7C6BDD7C6BDD8C7BED8C8BED8C8BED9C8BED9C8BE
D9C8BED8C7BDCEBEB4988B844B423F070706000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000101010807073F3A37BAAAA0E3D0C4E6D2C6E6D2C6E5D1C5
E3D0C3E3D0C3E3D0C3E3D1C4E3D0C3E2D0C2E4D1C3E4D2C3E4D2C3DCCABBBAAB9EB1A297
D8C6B8E4D2C2E4D2C2E4D1C2E4D1C2E4D1C2E4D1C2E5D1C2E5D2C2E5D2C2E5D3C1E5D3C1
E5D2C1E5D2C1E5D2C1E5D2C1E5D3C1E5D3C1E5D3C1E5D3C1E5D3C1E4D2C0E3D1BFE3D1BF
E3D2BFE4D2BFE5D2C0E0CEBCDAC8B6C0B1A0847A6F2A2723000000000000000000000000
030302100E0D1C1A171D1A181D1A181D1A18413C36766D6392877A978B7DBDAE9CDAC9B5
E1CFBAD2C2AEC5B5A2CFBFABD7C7B2E5D4BDE5D4BDDBCBB5B1A492766D613B37310F0E0C
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010101645D5EB5A7A8C5B6B7C4B6B7C4B5B7C4B5B6C3B4B5C3B4B5C2B4B5
C2B4B5C2B4B4C1B3B4C1B3B3C1B3B3C1B3B3C1B4B3C1B4B3C1B3B3C1B4B2C1B4B2C1B4B2
C1B4B2C0B4B2C0B4B2C0B4B2C0B4B2C0B4B2C0B4B2C1B4B2C1B4B2C1B5B2C1B5B2C1B5B2
C1B5B2C1B5B2C1B5B2C1B5B2C1B5B2C2B6B2C2B6B2C3B6B2C3B6B2C3B6B3C4B8B3C5B8B4
C5B8B3C4B7B3C4B7B3C5B8B3C6B8B4C6B8B4C6B9B4CABBB7CABCB7CBBCB8CBBDB8CCBDB8
CCBDB9CCBDB9CEBEBACEBEBACFBFBBD0BFBCD0BFBCD0BFBCD0C0BCCEBFBACDBEB8CDBEB7
CDBEB7CDBEB7CDBEB8CEBFB8CFC0BACFC0BACFC0BAD0C0BAD1C0BBD1C0BBD1C1BBD1C1BB
D1C1BBD2C1BBD2C1BBD2C1BBD2C2BBD2C2BBD2C2BBD2C2BBD2C2BAD1C2BAD1C2B9D1C2B9
D1C2B9D1C2B9D1C2BAD2C2BAD2C2BAD2C3BBD2C3BBD2C3BBD3C3BBD4C4BCD6C5BDD6C5BD
D6C6BDD6C6BDD7C6BDD7C6BDD7C6BDD7C7BED8C7BED8C8BED8C8BED8C8BED8C8BED9C8BE
D9C8BDD0C0B6998D863E3835151211000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000014131229262437332F625A54A5978EDCC9BEE5D2C6E5D2C6E6D2C6E6D2C6
E5D2C5E4D2C5E4D2C5E4D1C4E4D2C4E3D0C2E4D1C2E4D1C2E4D1C2E3D1C2E2CFC0E1CFC0
E3D0C1E4D2C2E4D2C2E4D2C2E5D2C2E5D2C2E4D2C2E4D2C2E5D2C2E5D2C2E5D2C1E4D2C1
E5D2C2E4D2C1E4D1C1E4D1C0E4D2C0E5D3C1E5D3C1E5D3C1E4D2C0E3D1BFE2D0BEE2D1BE
E2D1BEE3D1BFE4D2C0E5D3C0E5D3C0E5D2BFD2C1B0766C633935303A35303A35303A3530
443E386C6359968A7D9B8F81978B7E908577B5A797D8C7B3DFCFBADECDB8E1D0BBE5D3BD
E5D3BDE4D2BCE3D1BCE4D2BCE4D2BCE5D4BDE5D4BDE2D1BBD0C1ACBFB19E71685D1D1B18
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0303031413132926268C8283C0B3B3C5B6B7C4B5B7C3B5B6C3B5B5C3B4B5C2B4B5C2B4B5
C2B3B5C1B3B4C1B3B4C1B3B3C1B3B3C1B4B3C1B4B3C1B4B3C1B3B2C1B3B2C1B3B2C1B4B2
C1B4B2C0B4B2C0B4B2C0B4B2C0B4B2C0B4B2C0B4B2C0B4B2C1B5B2C1B5B2C1B5B2C1B5B2
C1B5B2C1B5B2C1B5B2C1B5B2C1B6B2C2B6B2C2B6B2C3B6B2C3B6B2C3B6B2C4B7B3C3B7B3
C4B7B3C4B7B3C4B7B3C5B8B3C6B8B4C6B8B4C7B9B5CABCB8CABCB8CCBCB8CCBDB8CCBDB8
CCBDB9CCBDB9CEBEBACFBFBBCFBFBBD0BFBCD0C0BCD0C0BDD0C0BDCEBFBBCDBEB9CDBEB7
CDBEB8CEBFB9CEBFB9CFC0B9CFC0BACFC0BACFC0BAD0C0BAD1C0BBD1C0BBD1C1BCD1C1BC
D1C1BCD1C2BBD1C1BBD1C2BBD2C3BCD2C3BCD2C3BCD2C3BCD1C2BAD1C2BAD1C2B9D1C2B9
D1C2B9D1C2B9D2C2BAD2C2BAD2C3BAD2C3BBD2C3BBD3C3BBD4C4BCD5C5BDD5C5BDD6C5BD
D6C5BDD6C6BDD6C6BDD7C6BDD7C6BDD7C6BDD8C8BED8C8BED8C8BED8C8BED8C8BED8C8BE
D6C6BBB3A59D46403E030202000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000120C0B
382F2C4F4844786E68A3958DB2A39ACCBBB0E2CFC3E4D1C5E5D2C6E5D2C6E5D2C6E5D2C6
E4D1C5E3D1C4E3D1C4E3D1C4E4D1C4E4D1C4E4D1C3E4D1C3E4D1C3E4D2C3E4D2C2E4D2C2
E4D2C2E4D2C2E4D2C2E4D2C2E4D2C3E5D2C2E5D2C2E5D2C2E4D2C2E4D2C2E4D1C1E4D1C1
E4D1C1E4D1C0E4D1C0E4D1C0E4D2C0E5D2C0E5D3C1E5D3C1E4D2C0E3D1BFE2D1BEE2D1BE
E2D1BEE3D1BFE4D2C0E4D2C0E5D2BFE5D2BFE3D1BECDBDACB9AA9BB8A99AB6A898AB9E8F
AD9E90C8B9A7E1CFBBE4D2BDE3D1BDE2D0BCE3D2BDE4D3BEE3D2BDE4D3BDE4D3BDE4D3BD
E4D4BDE5D4BEE5D4BEE5D3BDE4D3BCE3D1BCDECDB7C8B9A4B0A391B0A2916860561B1916
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
1210104C4747817779B6A9AAC4B6B6C4B6B7C3B5B6C3B4B6C3B4B5C2B4B5C2B4B5C1B3B5
C1B4B4C1B3B4C1B3B4C1B3B4C1B3B4C1B4B4C1B4B3C1B3B3C0B3B2C1B3B2C1B4B2C1B4B2
C1B4B2C1B4B2C0B4B2C0B4B2C0B4B2C1B5B2C1B5B2C1B5B2C1B5B2C2B5B2C2B5B3C2B6B3
C1B5B2C1B5B2C1B5B2C1B6B2C2B6B2C2B6B2C2B6B2C3B6B2C3B6B2C3B7B2C3B7B3C3B7B3
C4B7B3C4B8B3C4B8B3C4B8B3C6B8B4C7B9B5C8BBB6CABCB8CABCB8CBBDB8CCBDB8CCBDB9
CCBDB9CCBEB9CEBFBACEBFBBCEBFBBCFBFBBCFBFBBCFC0BCD0C0BDCFC0BBCDBFB9CDBEB7
CEBFB9D0C0BBD1C0BCD1C1BCD0C1BBCFC0BACFC0BAD0C0BAD1C0BBD1C0BBD1C1BCD1C1BC
D1C1BCD0C1BBD0C1BAD1C1BBD2C2BBD3C3BCD3C3BCD3C3BCD2C2BBD1C1BAD1C2BAD1C2BA
D1C2BAD2C2BAD2C2BAD2C2BAD2C3BBD2C3BBD3C3BBD4C4BCD5C5BCD5C5BDD6C5BDD6C5BD
D6C6BDD7C6BDD7C7BED7C7BED5C5BCD7C6BDD8C8BED8C8BED8C8BED8C8BED8C8BED7C7BD
C4B5AC776E68151313000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000101010807073C3331
8B7D75B6A79ECDBBB1E1CFC3E6D3C7E5D2C6E5D2C6E4D2C6E5D2C6E5D1C5E5D2C5E5D2C5
E4D2C5E4D1C5E4D1C4E4D1C4E4D2C4E4D2C4E4D2C4E4D2C4E4D2C4E4D2C3E4D2C3E4D2C2
E4D2C2E4D2C2E4D2C2E4D1C2E4D1C2E4D2C2E4D2C2E5D2C2E4D3C2E5D2C2E4D1C1E4D1C1
E4D2C1E4D1C0E4D1C0E3D1C0E4D1C0E4D2C0E4D2C0E3D2C0E3D2C0E3D1BFE2D0BEE2D0BE
E2D0BEE2D1BEE2D0BDE0CFBCE4D2BFE5D2BFE5D3C0E5D3C0E6D3C0E6D3C0E6D3C0E6D3C0
E5D3C0E5D3BFE5D3BFE5D3BFE5D3BFE5D3BEE5D3BEE4D3BEE3D3BDE3D2BCE3D2BCE3D2BC
E3D3BCE4D3BDE4D3BDE4D3BDE5D4BEE6D4BEDFCEB8C2B29FA29686A09484867D6E504B43
211F1C060505000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000020202
332E2E93888ABCAEB0C4B6B7C3B5B7C3B5B6C3B5B6C3B4B5C3B4B5C2B4B5C2B4B5C1B4B4
C1B3B4C1B3B4C0B3B4C0B3B4C1B3B4C0B3B3C0B3B3C0B3B2C0B3B2C0B3B2C0B3B2C0B4B2
C1B4B2C1B4B2C1B4B2C1B4B3C2B5B3C2B5B4C2B6B4C2B6B4C3B6B3C2B6B3C2B6B3C2B6B3
C2B6B3C2B5B2C2B5B2C2B5B2C2B6B2C3B6B2C2B6B2C2B6B2C2B6B2C3B6B2C3B7B3C3B7B3
C4B8B3C4B8B3C4B8B3C5B8B3C6BAB5C8BAB6C9BBB7CABCB8CABCB8CBBDB8CBBDB8CCBDB9
CCBEB9CDBEB9CEBFBACEBFBBCEBFBBCDBFBACDBEBACEBFBBD0C0BDCFC0BCCEBFBBCEBFBA
CFC0BBD0C1BCD2C1BED2C1BED1C1BDD0C0BBCFC0BACFBFBAD1C1BBD1C1BBD1C1BCD1C1BC
D1C2BCD0C1BBD0C1BAD1C1BBD2C2BBD2C3BCD2C3BCD3C3BCD2C2BBD2C2BBD2C2BBD2C2BB
D2C2BBD2C2BBD2C2BBD2C3BBD3C3BBD3C3BBD3C4BCD4C4BCD5C5BCD5C5BDD6C5BDD6C6BD
D6C6BDD7C7BED7C7BED7C7BED5C5BCD8C7BED8C8BED8C8BED8C8BED8C8BED8C7BEC9BAB1
8379742F2B29010101000000000000000000000000000000000000000000000000000000
000000000000000000000000020202120D0C1A0A092318162C2825262320443F3B8C817B
C5B5ABE5D2C7E5D2C7E5D2C7E5D2C6E5D2C6E5D2C6E5D2C6E5D2C6E5D2C6E5D2C6E5D2C6
E4D1C5E3D1C4E3D1C4E3D1C4E3D1C4E3D1C4E3D1C4E4D2C4E4D2C4E4D2C3E4D2C3E4D2C2
E4D2C2E4D2C2E4D2C2E4D2C2E4D2C2E4D2C2E4D2C2E4D2C2E4D2C2E4D2C2E4D2C1E4D2C1
E4D2C1E5D2C1E4D2C1E4D2C0E4D1C0E3D2C0E2D1BFE2D1BFE3D2C0E3D2BFE2D1BEE2D1BE
E2D1BEE2D1BEE2D2BEE1D0BDE3D1BEE4D3C0E4D3C0E5D3C0E5D3C0E5D3C0E5D3C0E5D3BF
E5D3BFE5D3BFE5D3BFE5D3BFE5D3BFE5D3BFE5D3BEE5D3BEE4D3BEE3D2BDE3D2BCE3D2BC
E3D3BCE3D3BDE3D3BDE3D3BDE5D4BDE6D4BEE5D4BDE1D0BADDCCB6DBCBB5D5C5AFB4A694
756C6126231F000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000001110102E2B2B
7C7374BBADAFC3B5B6C3B5B6C3B5B6C3B4B6C2B4B5C2B4B5C1B3B4C1B3B4C0B3B4C0B3B4
C0B3B4C0B3B4C0B3B4C0B3B3C0B3B3C0B3B2C0B3B2C0B3B2C0B3B2C0B3B2C0B4B2C0B4B2
C1B4B2C1B4B2C1B4B2C2B5B3C3B6B4C5B6B6C5B7B6C6B7B6C5B7B5C4B7B4C3B6B4C2B6B3
C2B5B2C2B5B2C2B5B2C2B6B2C2B6B2C2B6B2C2B6B2C2B6B2C2B6B2C3B6B2C3B7B3C4B7B3
C4B7B3C4B8B3C4B8B3C5B8B4C8BAB6CABCB8CABCB8CABCB8CABCB8CBBDB8CBBDB8CCBDB9
CCBEB9CCBEB9CDBFBACEBFBACDBEBACCBEB9CBBDB8CDBFBACFC0BCD0C0BCD0C0BCD0C0BB
D0C0BCD1C1BDD2C1BED2C1BED2C2BDD1C1BCCFC0BACDBEB9D0C0BBD1C0BBD1C1BCD1C1BC
D1C2BCD1C2BBD0C1BBD1C2BBD1C2BCD1C2BCD1C2BCD2C2BCD2C2BBD2C2BBD2C2BBD2C2BA
D2C2BAD2C2BAD2C2BAD2C2BBD3C3BBD3C4BBD4C4BCD4C4BCD5C5BCD5C5BDD6C6BDD6C6BE
D7C7BED7C7BED7C7BED7C7BED5C5BCD8C7BED8C8BED8C8BED8C8BED8C8BED7C7BDBCADA5
57514D0D0B0B000000000000000000000000000000000000000000000000000000000000
0000000000001B1917413D395C555081726B96766FA38A83B0A097847972A1938BD8C7BC
DFCDC2E5D2C7E5D2C7E5D2C6E5D2C6E5D2C6E5D2C6E4D1C6E5D1C6E5D2C6E5D2C6E5D2C6
E4D2C5E4D2C5E4D2C5E4D2C5E4D2C5E4D2C4E4D2C4E4D2C4E4D2C4E4D2C4E4D2C4E4D2C3
E4D2C3E4D2C2E4D2C2E4D2C2E4D2C2E4D3C2E4D3C2E4D2C3E4D2C2E5D2C2E4D2C1E4D2C1
E4D2C2E5D2C2E5D2C1E4D2C1E4D2C0E3D2C0E2D1BFE1D1BFE2D1BFE3D2C0E2D1BFE2D1BF
E2D1BFE2D2BFE2D2BFE3D2BFE4D2C0E4D3C0E4D3C0E4D3C0E5D3C0E5D3C0E5D3BFE5D3BF
E4D3BFE5D3BFE5D3BFE4D3BFE4D3BFE4D3BFE4D3BEE4D4BEE3D3BDE3D2BDE3D2BDE3D3BC
E3D3BCE3D3BDE3D3BDE3D3BDE4D4BDE5D4BEE5D4BEE5D4BEE5D5BEE5D4BDE4D3BCDECDB6
B2A492454039000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000606063F3A3B7F7577
B6A9ABC2B4B6C3B5B6C3B4B6C3B4B6C3B4B6C2B4B6C1B4B5C0B3B4C0B3B4C0B3B4C0B3B4
C0B3B4C0B3B4C0B3B4C0B3B4C0B3B3C0B3B3C0B3B2C0B3B2C0B3B2C0B4B2C1B4B3C1B4B3
C1B4B3C1B4B3C1B4B3C3B6B4C5B7B7C8BAB9C8B9B9C8BAB8C8BAB9C5B8B6C3B6B4C2B5B2
C2B5B2C2B5B2C2B5B2C2B6B2C2B6B2C2B6B2C2B6B2C2B6B2C2B6B2C3B7B2C4B8B3C4B8B4
C4B8B4C4B8B4C5B8B4C6B9B4CABBB8CABCB8CABCB8CABCB8CBBCB8CBBDB8CBBDB8CCBEB9
CCBEB9CCBEB9CDBFBBCEBFBACDBFBACDBFBACDBEBACEBFBBCFC0BCD1C1BDD1C1BDD1C1BD
D1C1BDD1C2BDD2C2BED2C2BED3C3BFD2C2BDD2C2BDD1C1BCD0C0BBD0C0BBD1C1BCD1C2BC
D1C2BCD2C2BCD2C2BCD2C2BCD1C2BCD1C2BCD1C2BCD2C2BCD2C2BBD3C3BBD3C3BBD3C3BB
D3C3BBD3C3BBD3C3BBD3C3BBD3C4BCD3C4BCD4C4BCD5C5BCD5C5BDD5C4BCD5C5BDD7C7BE
D7C7BECEBFB6CABBB3D7C7BED8C8BED8C8BED8C8BED8C8BED8C8BED9C8BED8C8BECDBCB3
675E5A0B0A0A09080811100F12100F12100F0B0A0A0302020000000000000404040C0C0B
12100F12100F49433F978C85C5B7ADDAC9BFE4D1C6E4D2C7E5D2C7C0B0A7D0BFB4E5D3C7
E5D3C7E5D2C7E4D2C6E4D2C6E5D2C6E4D2C6E4D2C6E4D2C6E5D2C6E5D2C6E5D2C6E5D2C6
E5D2C6E5D2C6E4D1C4E3D1C4E4D2C5E4D2C4E4D2C4E4D2C4E4D2C4E4D2C4E4D2C4E4D2C4
E4D2C3E4D2C3E4D2C2E4D2C2E4D2C2E4D3C2E4D2C2E4D2C2E4D2C2E4D2C2E4D2C2E4D2C2
E4D2C2E4D2C2E4D2C1E4D2C1E4D2C0E3D2C0E2D1BFE1D1BFE2D1BFE2D1BFE2D1BFE2D1BF
E2D2BFE2D2BFE2D2BFE3D2C0E4D2C0E4D2C0E4D3C0E4D3C0E4D3BFE4D3BFE4D3BFE4D3BF
E4D3BFE4D3BFE4D3BFE3D3BEE3D3BEE3D3BEE3D3BEE3D3BEE3D3BDE3D3BDE3D3BDE3D3BD
E3D3BDE3D3BDE3D3BDE3D4BDE4D4BDE5D4BEE5D4BEE5D5BEE5D5BEE5D5BEE6D5BEE7D5BF
BAAD9A4C463E000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000101011D1A1A807779B8ABAD
C2B5B6C2B4B6C2B4B6C2B4B6C2B4B5C2B4B5C2B4B5C1B3B5C0B3B4C0B3B4C0B3B4C0B3B4
C0B3B4C0B3B4C0B4B4C0B4B4C0B4B4C1B4B3C0B4B3C1B4B3C1B4B3C1B4B3C1B4B3C2B5B4
C3B6B4C4B6B5C4B7B6C6B9B7C8BAB9CABCBBCABBBBCABBBACBBBBBC7B8B7C4B6B5C2B6B3
C2B6B3C2B6B3C2B6B3C2B6B3C2B6B3C2B6B3C3B7B3C3B7B3C3B7B3C4B8B3C4B8B4C6B9B5
C6B9B5C7B9B5C7B9B5C8BAB6CABBB8C9BBB8CABCB8CABCB8CBBDB8CBBDB8CCBDB8CCBEB9
CCBEB9CCBEB9CDBFBACDBFBACDC0BACEBFBBCEBFBBCEC0BCD0C0BDD0C1BDD1C1BDD1C1BD
D1C1BDD1C1BDD2C2BED2C2BED3C3BFD2C3BED3C2BED2C2BDD1C2BCCFC0BBD0C0BBD1C1BB
D1C1BBD1C1BBD1C2BCD1C2BCD1C2BCD1C2BCD1C2BCD1C2BBD2C2BBD3C3BCD3C3BCD3C3BC
D3C3BCD3C3BCD3C4BCD3C4BCD3C4BCD3C4BCD4C5BCD5C5BDD5C5BDD4C3BCD4C5BCD7C7BE
D7C7BEC7B8B0C2B4ABD8C8BFD8C8BFD8C8BED8C8BED8C8BED9C8BED9C8BED5C5BCBBADA5
81777146423E625B578B817B8C817B8C817B6B635E423D3B35312F35312F494441726964
8C817B8C817BA99C94D3C2B8E4D2C8E4D2C7E4D2C7E4D2C7E5D2C7DECDC1DFCDC2E5D3C7
E5D3C7E5D2C7E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E5D2C6E5D2C6
E5D2C6E5D2C6E5D2C5E5D2C5E4D2C5E3D2C4E4D2C4E3D1C4E3D1C4E3D2C4E3D2C4E3D2C4
E4D2C3E4D2C3E4D2C3E4D2C2E4D2C2E4D2C2E4D2C3E4D2C2E4D2C2E3D1C1E4D2C2E4D2C2
E4D2C2E4D2C2E4D3C1E4D2C1E4D2C0E3D2C0E2D1BFE2D1BFE1D1BFE1D1BFE1D1BFE1D2BF
E2D2BFE2D2BFE2D2BFE3D2C0E4D2BFE4D2BFE4D2C0E4D3BFE4D3BFE4D3BFE4D3BFE4D3BF
E4D3BFE4D3BFE3D3BFE3D3BEE2D3BEE2D3BEE2D3BEE3D3BEE3D3BEE3D3BDE3D3BDE3D3BD
E3D3BDE3D3BDE3D4BDE3D4BDE4D4BEE5D4BEE5D5BEE5D5BEE5D5BEE5D5BEE6D5BEE6D5BE
B9AC994B463F000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000E0D0D2723246A6364B3A6A8C3B5B7
C2B5B7C2B4B6C2B4B6C2B4B6C2B4B6C2B4B6C1B3B5C0B3B5C0B3B4C0B3B4C0B3B4C0B3B4
C0B3B4C0B4B4C0B4B4C0B4B4C0B4B4C1B4B4C1B4B4C1B4B4C1B4B4C1B4B4C2B5B4C3B6B5
C5B7B6C5B9B7C6B9B7C7BAB9C8BAB8C9BBBAC9BBBAC8BAB9C8BAB8C6B8B6C3B7B4C3B6B4
C3B7B4C3B7B4C2B6B4C2B7B4C3B7B4C3B7B3C3B7B3C3B7B4C3B8B4C4B8B4C5B9B5C6B9B5
C7BAB6C9BBB7C9BBB8C9BBB8C9BBB8CABCB8CBBCB8CBBDB8CBBDB9CCBEB9CCBEB9CCBEBA
CCBEBACDBEBACDBFBACDBFBACEBFBBCFBFBBCFC0BCD0C0BDD0C1BDD1C1BDD1C1BDD1C1BD
D1C2BED2C2BED2C2BED2C2BED3C2BED2C2BDD1C1BCD1C2BCD1C1BBD0C1BAD0C0BBD1C1BB
D1C1BBD1C1BBD1C1BBD1C2BCD1C2BCD1C2BCD1C2BBD1C2BBD1C2BBD2C3BCD3C3BCD4C4BC
D4C4BDD4C4BDD4C4BDD4C5BDD3C4BCD4C5BDD5C5BDD5C5BDD5C5BED6C6BED7C7BED7C7BE
D7C7BEC9BBB2CBBCB4D8C8BFD8C8BFD8C8BFD8C8BFD8C8BFD8C8BED9C8BED3C3BAC1B2AA
CCBDB4C0B1AAD3C3BAE1CFC5E1D0C6E1D0C6D6C5BCC7B8AFC2B4ABC2B4ABC9BBB1D8C7BE
E2D0C6E2D0C6E2D0C6E3D2C7E4D2C7E4D2C7E4D2C7E4D2C7E5D2C7E5D2C7E5D2C7E4D2C7
E3D2C6E3D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E5D2C6E5D2C6E5D2C6E5D2C6
E5D2C6E5D2C6E5D2C6E5D2C6E5D2C6E4D3C5E4D2C5E4D3C5E4D3C5E4D3C5E4D2C4E4D2C4
E4D2C4E4D2C4E4D2C4E4D2C3E4D2C3E4D2C3E4D2C3E4D2C3E4D2C2E4D2C2E4D2C2E4D2C2
E4D3C2E4D3C2E5D3C2E4D3C1E4D2C1E4D2C1E3D2C0E2D2C0E2D1BFE1D1BFE1D2BFE1D2BF
E1D2BFE2D2BFE2D2BFE3D2C0E4D2BFE4D2BFE4D2BFE4D2BFE4D2BFE4D3BFE4D3BFE4D3BF
E4D3BFE4D3BFE3D3BFE3D3BEE2D3BEE2D3BEE2D3BEE2D3BEE3D3BEE3D3BEE3D3BEE3D3BD
E4D4BEE4D4BEE4D4BEE4D4BEE4D4BEE5D5BEE5D5BEE5D5BEE3D3BCE1D0BAE4D3BCD8C8B3
A59988403B35000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000302020A0A0A393436746B6DAFA3A5C1B4B5C2B5B6
C2B4B6C2B4B6C2B4B6C2B4B6C2B4B6C1B4B5C1B3B5C0B3B5C0B3B4C0B3B4C0B3B4C0B3B4
C0B4B4C0B4B4C0B4B4C0B4B4C0B4B4C1B4B4C1B4B4C1B4B4C1B4B4C1B5B4C2B5B4C4B7B6
C6B8B7C6B9B8C6B8B7C6B8B7C5B8B7C5B8B7C5B8B7C4B7B5C3B7B4C3B7B4C2B6B4C2B6B4
C2B6B4C2B7B4C2B7B4C2B7B4C3B7B4C3B7B4C3B7B4C4B8B4C5B8B5C5B8B5C6B9B6C7BAB6
C7BAB7C9BBB8C9BBB8C9BCB8CABCB8CABCB8CBBDB8CBBDB8CBBDB9CCBEBACCBEBACCBEBA
CDBEBBCDBFBBCDBFBBCDBFBACEBFBBCEBFBBCFBFBBCEC0BCCEC0BCCFC0BCD1C1BDD1C1BD
D2C2BDD2C2BED2C2BFD2C2BFD2C2BED1C1BCCFC0BACFC0BACFC0BACFC0BAD0C1BAD1C2BC
D1C2BCD1C2BCD1C2BCD1C2BCD1C2BCD1C2BCD1C2BCD1C2BBD1C3BCD1C3BCD2C3BCD3C4BC
D4C4BDD4C4BDD4C4BDD4C5BDD4C5BDD4C5BDD5C5BDD5C5BDD5C6BED6C6BED6C6BED6C7BE
D6C7BED3C3BBD6C6BDD7C8BED7C8BED8C8BED8C8BED8C8BED8C8BED8C8BED7C7BDD5C5BC
E1CFC6E1D0C6E2D0C7E3D1C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E4D2C8
E4D2C8E4D2C8E4D2C8E4D2C8E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7
E4D2C7E4D2C7E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6
E4D2C6E5D2C6E5D2C6E5D2C6E5D2C5E5D2C5E5D2C5E5D2C5E5D3C5E5D3C5E5D3C5E4D2C4
E3D2C4E3D2C4E3D2C3E4D2C3E4D2C3E4D3C3E4D2C3E4D2C3E4D2C3E4D2C3E4D2C3E4D3C2
E4D3C2E4D3C2E4D3C2E4D3C1E4D2C1E4D2C1E3D2C0E3D2C0E2D1BFE1D1BFE1D1BFE1D1BF
E1D1BFE1D2BFE2D2BFE3D2BFE4D2C0E4D2BFE4D2BFE4D2BFE4D3BFE4D3BFE4D3BFE4D3BF
E4D3BFE4D3BFE3D3BFE2D3BEE2D3BEE2D3BEE2D3BEE2D3BEE2D3BDE2D3BDE2D3BDE3D3BD
E4D4BEE5D4BEE5D4BEE5D4BEE5D5BEE5D5BEE5D5BEE5D5BEDACAB4D1C2ADE2D2BBB9AC99
726A5F272420000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000019171748424393888BB8AAADC2B5B7C2B5B7C2B4B6
C2B4B6C2B4B6C2B4B6C2B4B6C1B4B6C1B4B5C0B3B5C0B3B5C0B3B4C0B3B4C0B3B4C0B3B4
C0B3B4C0B3B4C0B4B4C0B4B4C0B4B4C0B4B4C0B4B4C1B4B4C1B5B4C1B5B5C3B6B6C5B8B7
C6B9B8C6B8B8C4B7B6C3B6B5C3B6B5C3B6B5C3B6B5C2B6B4C3B6B4C2B6B4C2B7B4C3B7B4
C3B7B4C2B6B4C2B6B3C2B6B3C2B7B3C3B7B3C4B8B4C5B8B5C6B9B6C6B9B6C7BAB6C8BAB7
C8BBB7C9BBB8C9BBB8C9BCB8CABCB8CBBDB9CBBDB9CBBDB9CCBEB9CCBEBACCBEBACDBEBB
CDBFBBCDBFBBCDBFBBCDBFBBCEBFBBCEBFBBCEC0BBCEC0BBCEC0BBCFC0BCCFC1BDD1C2BE
D2C2BDD2C2BED2C2BFD2C2BFD2C2BED1C1BCCFC0BACFC1BAD0C1BACFC1BAD0C1BBCFC1BB
D0C1BCD1C3BDD1C2BCD1C2BBD1C2BBD1C2BBD1C3BCD2C3BDD2C3BDD2C3BDD3C4BDD4C4BC
D4C4BDD3C4BDD3C4BDD4C4BDD4C5BED5C5BED5C5BED5C6BED5C6BED6C6BED6C7BED6C7BE
D6C7BED6C7BED7C7BFD8C8BFD8C8BFD8C8BFD8C8BFD8C8BED8C8BED8C8BFD9C9C0DCCBC1
DFCEC5E1D0C7E2D1C8E2D2C8E2D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8
E3D2C8E3D2C8E4D2C8E4D2C8E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7
E4D2C7E4D3C7E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6
E4D2C6E4D2C6E4D2C6E5D2C6E5D2C6E5D2C5E4D2C5E4D2C5E2D0C3D9C8BBD8C7BBE4D2C4
E4D3C4E4D3C4E4D3C4E4D3C4E4D3C3E4D3C3E4D3C3E4D2C3E4D2C3E4D2C2E4D2C2E4D3C2
E4D3C2E4D3C2E4D3C2E3D2C1E3D2C1E3D2C1E3D2C0E3D2C0E3D2C0E2D1BFE1D1BFE1D1BF
E1D2BFE1D2BFE1D2BFE2D2BFE3D3C0E3D3C0E3D3C0E3D3C0E3D3BFE3D3BFE3D3BFE3D3BF
E4D3BFE4D3BFE3D3BFE3D3BEE3D3BEE3D3BEE3D3BEE3D3BEE3D3BEE3D3BEE3D3BDE4D4BE
E4D4BEE5D4BEE5D4BEE5D4BEE5D4BEE5D4BEE5D4BEE5D5BEDFCFB9DBCCB5E4D4BCBAAD9A
6E665A201E1B000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000030303111011544F509F9396C0B2B5C2B5B7C2B5B7C2B4B6C2B4B6
C2B4B6C2B4B6C2B4B6C1B3B6C0B3B5C0B4B5C0B3B5C0B3B4C0B3B4C0B3B4C0B3B4C0B3B4
C0B3B4C0B4B4C0B4B4C0B4B4C0B4B4C0B4B4C1B4B4C2B5B5C3B6B6C3B7B6C4B7B7C6B9B9
C7B9B9C5B8B7C3B6B5C2B6B4C2B6B4C2B6B4C2B6B4C2B6B4C2B6B4C2B7B4C3B7B4C3B7B4
C3B7B4C3B7B4C2B7B4C2B7B4C3B7B4C4B8B4C5B8B4C5B9B6C6B9B6C6BAB6C8BAB7C8BAB7
C9BBB8C9BBB8C9BCB9CABCB8CABDB8CBBDB9CBBDB9CBBEBACCBEBACCBEBACCBEBACCBEBB
CCBEBBCDBFBBCDBFBBCDBFBBCEBFBBCEBFBBCEC0BBCEBFBBCDBFBACEC0BBCFC1BCD0C1BD
D1C2BED1C2BED2C2BED1C2BDD1C2BDD0C1BCCFC1BBCFC1BACFC1BACFC1BAD0C1BBD1C2BC
CEC0B9D1C3BDD1C3BDD1C2BCD1C2BCD1C2BCD2C3BCD2C3BCD2C3BDD3C4BDD3C4BDD3C4BD
D4C4BDD2C4BDD2C4BCD3C4BDD4C5BDD5C6BED5C6BED5C6BED5C5BDD5C5BED8C8C0D7C7BF
D6C7BFD7C7BFD7C8BFD7C8BFD8C7BFD8C8BFD8C8BFD8C8BFD8C8BFDACAC1DDCCC3DFCEC5
E1D0C7E1CFC6E2D0C7E2D1C7E2D1C7E2D1C7E3D1C8E3D1C8E3D1C8E3D1C8E3D2C8E3D2C8
E3D2C8E4D2C8E4D2C8E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E3D2C7E3D2C7
E4D2C7E4D2C7E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6
E4D2C6E5D2C6E5D3C6E5D3C6E5D3C5E5D3C5E5D3C5E5D3C5E5D3C5C7B8ACC0B1A6E0CFC1
E5D3C5E5D3C5E5D3C5E5D3C4E4D3C3E4D3C3E4D3C3E4D2C2E4D2C2E4D2C2E4D3C2E4D2C2
E4D3C2E4D3C3E3D2C2E3D2C1E3D2C1E3D2C1E4D2C1E4D2C1E3D2C0E2D2C0E2D2BFE1D2BF
E1D2BFE1D2BFE1D2BFE1D2BFE2D2BFE2D2BFE2D2BFE2D2BFE2D2BEE2D2BEE2D2BEE2D2BE
E3D3BFE4D3BFE4D4BFE4D4BFE3D4BFE3D4BFE4D4BFE4D4BFE4D4BFE4D4BFE3D4BEE4D4BE
E4D4BEE4D4BEE5D4BEE5D4BEE5D4BEE5D4BEE5D4BEE5D5BEE5D4BDE4D4BCE2D3BBDDCEB7
A2968538342E000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000302021A1919514B4CA19597C0B3B5C2B5B7C2B5B7C2B4B7C2B4B6C1B4B6
C0B3B5C0B3B5C0B3B5C0B3B5C0B3B5C0B3B5C0B3B4C0B3B5C0B3B5C0B3B4C0B4B4C0B4B4
C0B4B4C0B4B4C0B4B4C0B4B4C0B4B4C0B4B4C1B5B5C2B5B5C3B6B6C3B7B6C4B7B7C4B7B7
C3B7B6C3B7B5C2B6B4C2B6B4C2B6B4C2B6B4C2B6B4C2B6B4C3B7B4C3B7B4C3B7B4C3B7B4
C3B7B4C3B7B4C3B7B4C3B8B5C4B9B5C5B9B5C5B9B6C6B9B6C6BAB7C7BAB7C8BBB8C8BBB8
C9BBB8C9BCB9C9BCB9CABCB9CABDB9CBBDB9CBBEBACBBEBACCBEBACCBEBBCCBEBBCDBFBB
CDBFBBCDBFBBCDBFBBCDBFBBCEBFBBCEBFBBCEC0BBCDBFBBCDBFBACEC0BBCFC1BCD0C1BD
D1C2BED1C2BED1C2BDD0C1BDCFC1BCCFC0BBCEC0BACEC0BACFC1BACFC1BACFC1BAD0C2BB
CFC1BBD1C3BCD2C3BDD1C3BDD1C2BCD1C3BCD2C3BDD2C3BDD3C4BED3C4BED3C4BDD3C4BD
D3C4BCD3C4BCD2C3BCD3C4BDD3C5BDD5C6BED5C6BED6C6BFD5C6BED8C8C0DACAC2D7C8BF
D7C8BFD7C8BFD7C8BFD7C8BFD8C8BFD8C8BFD8C8BFD8C8BFD9C9C0DDCDC3E0CFC6E1D0C7
E1D0C7DFCEC6E1D0C7E1D0C7E2D0C7E2D0C7E2D1C7E3D1C7E3D1C7E3D1C7E3D1C7E3D1C7
E3D1C7E3D2C7E3D2C7E3D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E3D2C7E3D2C7E3D2C6
E3D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6
E4D2C6E4D2C5E4D2C5E4D2C5E4D2C5E4D3C5E4D3C5E4D3C5E5D3C5D2C1B5CEBEB2E2D1C3
E5D3C5E5D3C5E5D3C5E5D3C5E4D3C3E4D3C3E4D3C3E4D3C3E4D3C3E4D3C2E3D2C2E3D2C1
E3D2C2E4D3C2E4D3C2E3D2C1E4D2C1E4D3C2E4D3C2E4D2C1E3D2C0E3D2C0E2D2C0E2D2BF
E1D2BFE1D2BFE1D2BFE1D2BFE1D2BFE1D2BFE1D2BFE1D2BEE1D2BEE1D2BEE1D2BEE1D3BE
E3D3BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE5D4BFE5D4BFE4D4BEE4D4BE
E4D4BEE4D4BEE4D4BEE4D4BEE5D4BEE5D5BEE5D5BEE5D5BEE5D5BEE5D5BDE5D5BEE5D5BE
B1A4933D3932000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000090909262324686262A5999CC0B3B5C2B5B7C1B4B7C1B4B6C1B4B6C1B3B6C0B3B5
C0B3B5BFB3B5C0B3B5C0B3B5C0B3B5C0B3B5BFB3B5C0B3B5C0B3B5C0B4B5C0B4B5C0B4B5
C0B4B5C0B4B4C0B4B4C0B4B4C0B4B4C0B4B4C1B5B4C1B5B5C2B6B5C2B6B5C2B6B5C2B6B5
C2B6B5C2B6B4C1B6B4C1B6B4C2B6B4C2B6B4C2B6B4C2B6B4C3B7B5C4B7B5C4B7B5C4B7B5
C4B8B5C4B8B5C4B8B5C5B8B5C6B9B6C6B9B6C6B9B6C7BAB7C7BBB7C8BBB8C8BBB8C8BBB8
C9BCB8C9BCB9C9BCB9CABDB9CABDB9CBBDB9CBBEBACBBEBACCBEBACCBEBBCCBEBBCDBFBB
CDBFBBCDBFBBCDC0BBCDBFBBCEBFBBCEBFBBCEC0BBCDC0BBCDBFBACEC0BBCFC0BCD0C1BD
D0C1BCCFC1BCCFC1BCCFC1BCCEC0BACEC0BACEC0BACEC0BACEC1BACFC1BBCFC2BBCFC2BB
D0C2BBCBBDB7D0C2BCD2C3BDD1C3BDD2C3BDD2C3BDD2C4BDD3C4BED3C4BED3C4BDD3C4BD
D3C4BDD3C4BCD3C4BDD3C5BDD5C6BED5C6BED6C6BED6C6BFD7C8C0DCCCC4DCCCC4D8C8C0
D7C8BFD7C8BFD7C8BFD7C8BFD8C8BFD8C8BFD8C8BFD8C8BFDACAC1DFCEC5E1D0C7E1D0C7
E1D0C7E1D0C7E2D0C7E2D0C7E2D0C7E2D0C7E2D1C7E2D1C8E2D1C8E2D1C8E2D1C7E2D1C7
E2D2C7E2D2C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7E4D2C7
E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6
E4D3C6E4D3C6E4D3C6E4D3C6E4D3C6E4D3C6DBCABDD6C5B9E0CFC1E5D3C5E5D3C5E5D3C5
E5D3C5E5D3C5E5D3C5E5D3C5E4D3C4E3D3C3E4D3C2E4D3C2E4D3C3E4D3C2E4D3C2E3D2C2
E3D2C2E3D3C2E3D2C1E3D2C1E3D2C1E4D4C2E4D4C2E3D2C1E3D2C0E3D2C0E3D2C0E2D2C0
E3D2C0E3D2C0E2D2BFE2D2BFE1D2BFE1D2BFE1D2BFE1D2BFE1D2BEE1D2BEE1D2BEE1D3BE
E3D3BFE4D4BFE4D4BFE4D3BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BEE4D4BE
E4D4BEE4D4BEE4D4BEE4D4BEE5D5BEE5D5BEE5D5BEE5D5BEE5D5BEE5D5BEE5D5BEE5D5BE
BBAE9B3D3932000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010101
040303242020686161B0A5A7C1B4B6C2B5B8C2B5B7C2B4B7C1B4B7C1B3B6C0B3B6C0B3B5
BFB3B5BFB3B5BFB3B5C0B3B5C0B3B5BFB3B5BFB3B4BFB3B4BFB3B4BFB3B4C0B4B4C0B4B4
C0B4B4C0B4B5C1B5B5C1B6B5C1B5B5C1B5B5C0B5B4C1B5B5C1B5B5C1B5B5C1B6B5C1B6B5
C1B6B5C2B6B5C2B6B4C2B6B4C2B6B4C2B6B4C2B6B4C3B7B5C3B7B5C3B7B5C4B7B5C4B8B6
C4B8B6C5B8B5C5B9B5C5B9B6C6B9B6C6B9B6C6B9B7C7BAB7C8BAB8C8BBB8C8BBB8C9BCB8
C9BCB9C9BCB9C9BCB9CABDB9CABDB9CBBDB9CBBEBACBBEBACCBEBBCCBEBBCCBEBBCDBFBB
CDBFBBCDBFBBCDBFBBCDBFBBCEBFBBCEC0BBCEC0BBCDC0BBCDC0BACEC0BBCFC0BDCFC1BD
CFC1BCCFC0BBCFC1BBCFC1BBCDC0BACEC0BACEC0BACEC1BACFC1BBCFC1BBCFC2BBCFC2BB
D0C2BBCEC0BACEC0BAD2C3BED2C4BDD2C4BDD3C4BDD3C4BDD3C4BED3C4BDD3C4BDD3C4BD
D3C4BDD3C4BDD4C5BDD5C6BED6C6BFD6C6BFD6C7BFD8C9C1DACBC3DDCEC6DCCCC4D8C8C0
D7C8BFD7C8BFD7C8BFD7C8BFD8C8BFD8C8BFD8C8BFD8C9C0DBCBC2E0CFC6E1D0C8E1D0C8
E2D0C8E2D0C8E2D1C8E2D1C8E1D0C7E2D0C7E2D0C7E2D1C7E2D1C7E2D1C7E2D1C7E2D1C7
E2D1C7E2D1C7E3D1C7E3D2C8E3D2C8E3D2C8E3D1C7E3D1C7E3D2C7E3D1C7E3D1C7E3D2C7
E3D2C7E3D2C7E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D3C6
E4D3C6E4D3C6E4D3C6E4D3C6E4D3C6E4D3C6CFC0B4C9BAAEDCCBBEE4D3C5E4D3C5E5D3C5
E5D3C5E5D3C5E5D3C5E5D3C5E4D3C4E4D3C3E4D3C3E3D3C3E4D3C3E4D3C3E4D3C2E4D3C3
E3D2C2E3D2C1E3D2C1E3D2C1E3D2C1E3D3C1E4D3C2E4D3C2E4D3C1E3D2C1E3D2C0E3D3C0
E3D3C0E3D3C0E3D3C0E2D3BFE1D2BFE1D2BFE1D3BFE1D3BFE1D3BFE2D3BFE2D3BFE2D3BF
E3D3BFE4D4BFE4D4BFE4D4BFE4D3BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BE
E4D4BEE4D4BEE4D4BEE4D4BEE4D5BEE4D5BEE4D5BEE5D5BEE5D5BEE5D5BEE5D5BEE0D1BA
AB9F8D33302A000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000080707201E1F
4841427F7172AE9FA2C1B5B8C2B5B7C1B4B7C1B4B7C1B4B6C1B4B6C0B3B6C0B3B5C0B3B5
BFB3B5BFB3B5BFB3B5C0B3B5C0B4B5BFB3B5BFB3B5BFB3B5BFB3B5BFB3B4BFB4B4C0B4B4
C0B4B4C0B4B4C1B5B5C1B5B6C1B5B5C1B5B5C1B5B5C1B5B5C1B5B5C1B6B5C2B6B5C2B6B5
C2B6B5C2B6B5C2B6B5C2B6B5C2B7B5C2B7B5C2B7B5C3B7B6C3B7B5C4B7B5C4B8B5C4B8B5
C4B8B5C5B8B6C6B9B6C6B9B7C6B9B7C6BAB7C7BAB7C8BAB8C8BBB8C8BBB8C8BCB9C8BCB9
C9BCB9C9BCB9C9BDB9CABDB9CABDB9CBBDB9CBBEBACBBEBACCBEBBCCBEBBCCBFBBCDBFBB
CDBFBBCDBFBBCDBFBBCDBFBBCEC0BBCEC0BBCEC0BCCEC0BCCDC0BBCEC0BCCFC0BCD0C1BC
CFC1BCCFC0BBCFC1BCCEC1BBCDC0BACEC0BACEC1BACEC1BACFC1BBCFC2BBCFC2BBCFC2BB
D0C2BBD1C3BCD0C1BCD2C3BDD3C3BED3C4BDD3C4BDD3C4BDD3C4BDD3C4BDD3C4BDD3C4BD
D3C4BDD4C5BDD4C5BFD5C6BFD5C6BFD6C6BFD8C8C0DBCCC4DECFC7DFD0C8DCCCC4D8C9C0
D7C8BFD7C8BFD7C8BFD7C8BFD8C8BFD8C8BFD8C9C0D8C9C0DBCBC3DFCFC6E0D0C7E0D0C7
E1D0C7E1D0C7E1D0C8E2D0C8E2D0C7E2D1C7E2D1C7E2D1C7E2D1C7E2D1C7E2D1C7E2D1C7
E2D1C7E3D1C7E3D1C7E3D2C8E3D2C8E3D2C7E3D1C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7
E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C7E4D2C6E4D2C6E4D2C6E4D2C6E4D3C6E4D3C7
E4D3C7E4D4C7E4D4C7E4D4C7E4D4C7E5D4C7DACABEDDCDC0E3D2C4E5D3C5E5D3C5E5D3C5
E5D3C5E5D3C5E5D4C5E5D4C5E4D4C4E4D3C4E3D3C4E4D3C4E4D3C3E4D3C3E4D3C3E4D3C2
E4D3C2E3D3C2E3D2C2E3D3C2E3D3C1E3D3C2E4D3C1E4D3C2E3D3C1E3D2C0E3D2C0E3D2C0
E3D3C0E3D3C0E3D3C0E2D3C0E2D3BFE2D3BFE2D3BFE2D3BFE2D3BFE2D3BFE2D3BFE2D3BF
E3D4C0E4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BF
E4D4BEE4D4BEE4D4BEE4D4BEE4D5BEE4D5BEE4D5BEE4D5BEE4D5BEE5D5BEE5D5BECEC0AB
756D611A1916000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000070606302C2D71696C
A4979AB8A7AABFB0B3C2B5B8C1B4B7C1B4B7C1B4B7C1B3B7C0B3B6C0B3B6BFB3B5BFB3B5
BFB3B5BFB3B5BFB3B5BFB3B5BFB3B5BFB3B5BFB3B5BFB3B5BFB3B5BFB4B5BFB4B5C0B4B5
C0B4B5C0B4B5C0B5B5C1B5B5C1B5B5C1B5B5C1B5B5C1B5B5C1B5B5C1B5B5C2B6B5C2B6B5
C2B6B6C3B6B6C3B6B6C3B6B6C3B7B6C3B7B6C4B7B6C4B7B6C4B8B6C4B8B6C4B8B6C4B8B6
C4B8B6C5B9B6C5B9B7C5B9B7C6B9B7C7BAB7C7BAB7C8BBB8C8BBB8C8BBB8C8BCB9C8BCB9
C9BCB9C9BDB9CABDB9CABDB9CABDB9CBBEBACBBEBACBBEBACCBFBBCCBFBBCCBFBBCDBFBB
CDBFBBCDBFBBCDBFBBCEBFBBCEBFBBCEBFBBCEC0BBCEC0BCCEC0BCCFC1BCCFC1BDCFC1BD
CEC1BBCEC0BBCEC1BBCEC1BBCEC1BBCEC1BBCEC1BACEC1BACFC2BBCFC2BBCFC2BBCFC2BB
D0C2BBD1C2BCD1C2BDD2C3BED3C4BED3C4BED3C4BDD3C4BDD3C4BDD3C4BDD3C4BDD3C4BD
D4C5BDD5C6BFD6C7C0D6C7BFD6C7C0D6C8C0DACBC3DECEC6DFCFC7DECEC6DACBC3D7C8C0
D7C8BFD7C8BFD7C8BFD7C8BFD7C9C0D8C8C0D8C9C0D9C9C1DBCCC3E0D0C7E0D0C7E0D0C7
E0D0C7E0D0C7E1D0C7E2D1C8E2D1C8E2D1C8E2D1C8E2D1C8E2D1C8E2D1C8E2D1C7E2D1C7
E2D1C7E2D1C7E2D1C7E3D1C7E3D2C8E3D1C7E3D1C7E3D1C7E3D1C7E3D1C7E3D2C7E3D2C7
E3D2C7E3D2C7E3D2C7E3D2C7E3D2C6E4D2C6E4D2C6E4D2C6E4D2C6E4D3C6E4D3C7E4D3C7
E3D2C6DBCBBFD5C6BAD1C1B6D4C5B9DFCFC2E0D0C3E2D1C4E4D3C5E5D3C5E4D3C5E2D0C3
E4D3C5E4D3C5E5D3C5E4D3C4E3D3C4E3D3C4E3D3C4E3D3C4E3D3C3E3D3C2E3D3C2E4D3C3
E4D3C3E4D3C3E3D3C2E3D3C2E3D3C2E3D3C2E3D2C1E3D3C1E3D3C1E3D2C1E3D2C0E3D2C0
E3D2C0E3D2C0E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D4C0E3D4C0
E4D4C0E4D4C0E4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BF
E4D4BFE4D4BEE4D4BEE4D5BEE4D5BEE4D5BEE4D5BEE4D5BEE4D5BEE4D5BEE5D5BEB1A592
3B3731010101000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000100F103A35368A7F81B7A9AC
C2B5B8C2B6B9C2B5B9C1B4B8C1B4B7C0B3B7C0B3B7C0B3B6BFB3B6BFB3B6BFB3B5BFB3B5
BFB3B5BFB3B5BFB4B5BFB4B5C0B4B5BFB4B5BFB4B5BFB4B5BFB4B5C0B4B5C0B4B5C0B4B5
C0B5B5C0B5B5C0B5B5C1B5B5C1B5B5C1B5B5C1B5B5C1B5B5C1B6B5C1B6B5C2B6B5C2B6B6
C2B6B6C3B6B6C3B6B6C3B7B6C3B7B6C3B7B6C3B7B6C4B7B6C4B8B6C4B8B6C4B8B6C4B8B6
C5B9B6C5B9B7C6B9B7C6B9B7C6BAB7C7BAB7C7BBB7C8BBB8C8BBB9C8BCB9C8BCB9C9BCB9
C9BDB9CABDB9CABDB9CBBDBACBBEBACBBEBBCBBEBBCCBFBBCCBFBBCCBFBBCCBFBBCDC0BC
CDBFBCCDBFBBCEBFBBCEBFBBCEBFBBCEC0BBCEC0BCCEC0BBCEC0BBCEC0BCCEC1BCCFC1BC
CFC1BCCEC1BBCEC1BBCEC1BBCEC1BBCEC1BBCEC1BBCEC2BBCFC2BBCFC2BBCFC2BBCFC2BB
D0C2BCD1C3BDD2C3BDCDBFB9CBBDB8D3C4BED3C4BED3C4BDD3C4BDD3C4BDD3C4BDD3C4BD
D4C5BED5C7C0D6C7C0D6C7C0D9CAC2DBCCC4DCCEC6DFCFC7DDCDC5D9CAC3D8C9C1D7C8C0
D7C8C0D7C8BFD7C8BFD7C8BFD7C9C0D7C8C0D8C8C0DACAC2DDCDC4E0D0C7E0D0C7E0D0C7
E0D0C7E0D0C7E0D0C7E0D0C7E1D0C7E1D0C7E1D1C7E1D1C7E1D1C8E1D1C8E2D1C7E2D1C7
E2D1C7E2D1C7E2D1C7E2D1C7E2D1C7E3D1C7E3D1C7E3D1C7E3D1C7E3D2C7E3D2C7E3D2C7
E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C6E4D2C7E4D3C8E4D3C7E4D3C7E4D3C7E4D3C7
E2D1C5D4C5B9CCBDB2CCBDB2D4C5B9DFCFC3DFCFC2DCCCBFE1D1C4E5D4C6E5D4C6E5D4C6
E4D3C5E4D3C5E4D3C5E3D3C4E3D3C4E3D3C4E3D3C4E3D3C4E3D3C4E3D3C3E4D4C3E4D4C3
E4D3C3E4D3C3E4D3C3E3D2C2E3D2C1E3D3C1E3D3C1E2D3C1E3D3C1E3D3C1E3D3C1E3D3C1
E3D3C1E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E4D3C0E4D3C0E4D3C0E4D4C0E4D4C0E4D4C0
E4D4C0E4D4C0E4D4C0E4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BF
E4D4BFE4D4BFE4D4BEE4D5BEE4D5BEE4D5BEE4D5BEE4D5BEE4D4BEE4D5BEDACBB5988D7E
312E29000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000006060613131144423E897F80B6A5A9BEAEB1
C2B6B9C1B5B8C2B5B9C1B4B8C0B4B7C0B4B7C0B3B7C0B3B6BFB3B6BFB3B6BFB3B5BFB3B5
BFB3B5BFB4B5BFB4B5BFB4B5C0B4B5BFB4B5BFB4B5BFB4B5C0B4B5C0B4B5C0B5B5C0B5B5
C0B5B5C0B5B5C0B5B5C1B5B5C1B5B5C1B5B5C1B5B5C1B6B5C1B6B5C1B6B5C2B6B6C3B6B6
C3B7B6C3B7B6C3B7B6C3B7B6C3B7B6C4B8B6C4B8B6C4B8B6C4B8B6C4B8B6C4B9B6C5B9B6
C5B9B7C5B9B7C6B9B7C6BAB7C6BAB7C6BAB7C7BAB7C8BBB8C8BBB9C8BCB9C8BCB9C9BCB9
C9BDB9CABDB9CABDBACBBEBACBBEBACBBEBBCCBFBBCCBFBCCCBFBCCCBFBBCCBFBBCDC0BC
CDC0BCCDBFBCCEC0BCCEC0BCCEC0BCCEC0BCCEC0BCCEC1BCCEC0BCCEC1BCCEC1BCCEC1BC
CFC1BCCEC1BCCEC1BBCEC1BBCEC1BBCEC1BBCFC2BBCFC2BCD0C2BCD0C2BDD0C2BDD0C2BC
D0C3BCD2C4BDD3C4BED1C2BDCFC0BCD5C6C0D4C5BFD3C5BFD3C5BFD4C5BFD4C5BFD4C5BF
D5C7C0D5C7C0D6C7C0D7C8C1DCCCC5DECFC7E0D0C8DFCFC7DBCCC4D7C8C1D7C8C1D7C8C0
D7C8C0D7C8C0D7C8C0D7C8BFD8C9C0D8C9C0D9CAC2DDCDC5E0D0C7E0D0C7E0D0C7E0D0C7
E0D0C7E0D0C6E0D0C6E0D0C6E0D0C6E1D0C6E1D0C7E1D0C7E1D0C7E1D1C7E1D1C7E2D1C8
E2D1C8E2D1C8E3D1C8E3D1C8E3D2C8E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7
E3D2C7E3D2C7E3D2C7E4D2C7E4D2C7E4D2C7E4D3C7E4D3C8E4D3C8E4D3C7E4D4C7E4D4C7
E6D4C8E7D6C9CBBCB1AEA198CDBFB4E3D3C6E5D5C7E6D5C8E6D5C8E5D4C7E4D4C6E4D4C6
E5D4C6E5D4C5E5D4C5E4D4C5E3D3C4E3D3C4E3D3C4E3D3C4E3D3C4E3D3C3E3D3C2E3D3C2
E3D3C2E3D3C3E4D3C3E4D3C2E3D3C2E3D3C2E3D3C1E3D3C1E2D3C1E3D3C1E3D3C1E3D3C1
E3D3C1E3D3C1E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0
E3D3C0E3D3C0E4D4C0E4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BFE4D4BF
E4D4BFE4D4BFE4D5BFE4D5BEE4D5BEE4D5BEE4D5BEE4D5BEE3D4BDE4D4BEB4A89660594F
1A1815000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000F0E0E3431326964609D9690BAAEAFBEADB1BEAFB3
C2B5B9C1B5B8C1B5B8C1B4B7C0B4B7C0B3B6BFB3B6BFB3B6BFB3B6BFB3B5BFB3B5BFB3B5
BEB3B5BFB3B5BFB3B5BFB4B5BFB4B5BFB4B5BFB4B5BFB4B5C0B4B5C0B4B5C0B4B5C0B5B5
C0B5B5C0B5B5C0B5B5C0B5B5C0B5B5C0B5B5C1B5B5C1B5B5C1B6B5C2B6B6C2B6B6C3B7B7
C3B7B6C3B7B6C3B7B6C3B7B6C3B7B6C3B7B6C3B7B6C3B8B6C4B8B6C4B8B6C4B9B6C5B9B7
C5B9B7C5B9B7C6BAB7C6BAB7C7BAB7C7BBB7C7BBB8C9BBB9C8BCB9C8BCB9C8BCB9C8BCB9
C9BDBACABDBACBBEBACBBEBBCBBEBBCBBEBBCCBFBCCCBFBCCCBFBCCCBFBCCCBFBCCDC0BC
CDC0BCCDC0BCCEC0BCCEC0BCCEC0BCCEC0BCCEC0BCCEC1BCCEC1BCCEC1BCCEC1BCCEC1BC
CFC2BDCFC2BDCEC1BCCEC1BBCEC1BBCEC2BBCFC2BCD0C2BDD0C2BED0C3BDD0C3BCCFC2BB
CFC2BBD1C3BDD2C4BED4C5BFD5C6C0D7C7C1D6C7C1D5C6C0D5C6C0D5C6C0D5C6C0D5C7C0
D5C7C0D6C7C0D7C7C0D8C8C1D8C9C3DBCCC5E0D0C9DECEC7DACBC4D7C8C1D7C8C1D7C8C0
D7C8C0D7C8C0D7C8C0D7C8C0D8C8C0D8C9C0DACBC2E0D0C7E0D0C8E0D0C8E0D0C7E0D0C7
E0D0C7E0D0C6E0D0C6E0D0C6E0D0C6E0D0C6E0D0C6E0D0C7E1D0C7E1D0C7E1D0C7E1D1C7
E2D1C8E2D1C8E2D1C8E2D1C8E2D1C8E3D1C7E3D1C7E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7
E3D2C7E3D2C7E3D2C7E3D2C7E3D2C7E4D3C8E4D3C8E4D3C8E4D3C8E4D3C7E4D3C7E4D4C8
E6D5C9E7D6CA9D91895B5450A59990DDCDC0E6D5C8E6D6C8E5D5C8E5D4C7E4D4C7E4D4C6
E4D4C6E4D4C6E4D4C6E4D4C5E3D4C4E3D3C4E3D3C4E3D3C4E3D3C4E3D3C3E3D3C3E3D3C2
E3D4C2E3D4C2E4D4C3E4D4C3E4D4C3E3D3C2E3D3C1E3D3C1E3D3C1E2D3C1E3D3C1E3D3C1
E3D3C1E3D3C0E3D3C1E3D3C1E3D3C0E3D3C0E3D3C0E3D3C0E3D3C0E3D4C0E3D4C0E4D4C0
E4D4C0E4D4C0E4D4C0E4D4C0E4D4C0E4D4C0E4D4C0E4D4BFE4D4BFE4D4BFE4D5BFE4D5BF
E4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE4D5BEE0D1BBCBBDA9756D6122201D
020202000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000303030807083632347A7375B0A6A6BEB3B1C1B6B8C2B6B9C1B5B9
C1B5B9C2B5B9C2B5B8C1B4B8C0B4B7BFB3B6BFB3B6BEB3B5BFB3B5BFB3B5BFB3B5BFB3B5
BEB3B5BFB3B5BFB4B5BFB4B5BFB4B5BFB4B5BFB4B5BFB4B5C0B4B5C0B4B5C0B5B5C0B5B5
C0B5B5C0B5B5C0B5B5C0B5B5C0B5B5C0B5B5C1B5B5C1B6B6C2B6B6C2B6B6C2B6B6C3B7B6
C3B7B7C3B7B6C3B7B6C3B7B6C3B8B6C4B8B6C4B8B6C4B8B6C4B8B6C5B9B6C5B9B7C5B9B7
C5B9B7C6BAB7C6BAB7C6BAB7C7BBB8C8BBB8C8BBB9C8BCB9C8BCBAC8BCBAC8BCBAC9BDBA
C9BDBACBBEBBCBBEBBCBBEBBCBBEBBCBBEBBCCBFBCCCBFBCCCBFBCCCBFBCCCBFBCCCC0BC
CDBFBCCDC0BCCDBFBCCEC0BCCEC0BCCDC0BCCDC0BCCDC1BCCEC1BCCEC1BCCEC1BCCEC1BC
CFC2BDCFC2BECFC1BCCEC1BBCEC1BBCEC2BBD0C1BCD0C2BDD0C2BDD0C2BDCFC2BCCEC2BB
CFC2BBCFC2BBD0C2BCD2C4BED5C5C0D6C7C1D7C7C2D7C7C2D6C7C1D6C7C1D6C7C1D5C7C0
D5C7C0D5C7C0D7C7C0D7C8C1D8C9C2D8C9C2DBCBC4D9CBC3D7C9C1D7C8C0D7C9C0D7C8C0
D7C8C0D7C8C0D7C8C0D7C8C0D7C8C0D8C9C0DCCDC4E0D1C8E1D1C8E1D1C9E1D1C8E1D1C8
E1D1C8E0D0C7E0D0C7E1D0C7E1D0C7E0D0C7E1D0C7E1D1C7E1D1C7E1D1C7E1D1C7E1D1C8
E2D1C8E3D1C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C7E3D2C7
E3D2C7E3D2C7E3D2C7E3D2C7E4D3C8E4D3C8E4D3C8E4D3C8E4D3C8E5D4C8E5D4C8E6D5C9
E7D6CAE7D6CAAB9E956B635EAFA299DFCFC2E6D5C8E5D4C7E5D4C7E5D4C7E5D4C7E5D4C7
E4D5C6E5D5C6E5D5C6E5D5C6E4D4C5E4D4C5E4D4C5E4D4C4E3D4C4E3D4C4E3D4C4E3D4C3
E3D4C3E3D4C3E4D4C3E4D5C3E4D5C4E4D3C2E3D3C2E3D3C2E3D3C2E3D3C1E3D3C1E3D3C1
E3D3C1E3D3C1E3D4C1E3D4C1E3D3C1E3D3C1E3D3C0E3D3C0E3D4C0E3D4C0E3D4C0E3D4C0
E4D4C0E4D4C0E4D4C0E4D4C0E4D4C0E4D4C0E4D4C0E4D4BFE4D4BFE4D5BFE4D5BFE4D5BF
E4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE4D5BFCFC1AD7D756834312B0D0C0B
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000001A1719413D3E888183B4A9ACC2B6BAC2B6BAC2B5B9C1B5B9C1B5B9
C1B5B9C1B5B8C1B4B8C0B4B7BFB3B6BFB3B6BFB3B6BFB3B6BFB3B6BFB3B6BFB3B6BFB4B6
BFB4B6BFB4B6BFB4B6BFB4B6BFB4B6C0B4B6C0B4B6C0B5B6C0B5B6C0B5B6C0B5B6C1B5B6
C1B5B6C1B5B6C1B6B6C1B6B6C1B6B6C1B6B6C2B7B7C2B7B6C2B7B7C2B6B6C3B7B6C3B7B6
C3B7B6C3B7B6C3B7B6C3B8B6C4B8B6C4B8B6C4B8B6C4B8B6C5B9B6C5B9B7C5B9B7C5B9B7
C5BAB7C6BAB7C6BAB7C6BAB7C7BBB8C7BBB8C8BBB8C8BCB9C8BCBAC9BCBAC9BCBAC9BDBA
CABDBACABEBBCABEBBCABEBBCBBEBBCBBEBBCBBFBCCCBFBCCCBFBCCCBFBCCCC0BCCCC0BC
CCBFBCCDC0BCCDC0BCCDC0BCCDC0BCCDC0BCCEC0BCCEC1BCCEC1BCCEC1BCCEC1BCCEC1BC
CFC2BDCFC2BECFC2BCCEC1BBCEC1BBCFC2BCD0C2BDD0C2BDD0C2BDD0C2BDD0C2BCCFC2BB
CFC2BBCFC2BBD0C2BCD1C4BDD5C5C0D6C7C1D7C7C2D6C7C2D6C7C1D6C7C1D6C7C1D5C7C0
D5C7C0D5C7C0D6C8C1D7C8C1D7C8C1D7C8C1D7C8C1D7C8C1D6C8C0D6C8C0D7C8C0D7C8C0
D7C8C0D7C8C0D7C8C0D8C9C0DACAC2DBCCC3DFCFC7E2D1C9E2D2C9E2D2CAE2D2C9E2D2C9
E2D2C9E1D1C8E0D0C7E0D0C7E0D0C6E0D0C6E0D0C6E0D0C7E0D0C7E1D0C7E1D1C7E1D1C8
E2D1C8E2D1C8E2D1C8E2D1C8E3D1C8E2D1C8E3D2C8E3D2C8E3D2C7E3D2C7E3D2C7E3D2C7
E3D2C7E3D3C8E3D3C7E4D3C8E4D3C8E4D3C8E4D3C8E4D3C8E4D3C8E5D4C8E6D5C9E6D5C9
E6D6CAE7D6CADECEC2C9BBB0DCCCC0E6D5C9E5D4C7E5D4C7E5D4C7E5D4C7E5D4C7E5D4C7
E4D4C6E4D5C6E5D5C6E5D5C6E5D5C6E5D4C5E4D4C5E4D4C5E3D4C4E3D3C4E3D4C4E3D4C3
E3D4C3E3D4C2E3D4C3E4D4C3E4D4C3E4D4C3E4D4C3E3D3C2E3D3C2E3D3C2E3D3C1E3D3C1
E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D3C1E3D3C1E3D4C0E3D4C0E3D4C0E3D4C0E3D4C0
E3D4C0E3D4C0E3D4C0E3D4C0E4D4C0E4D4C0E4D4C0E4D4C0E4D5BFE4D5BFE4D5BFE4D5BF
E4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE4D5BEBDB19F312E2A000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000B0B0B2825276861649D9296BDB1B5C1B5B9C2B6BAC1B5B9C1B5B9C1B5B9C1B5B9
C0B4B8C0B4B7C0B3B7BFB3B6BFB3B6BFB3B6BFB3B6BFB3B6BFB3B6BFB3B6BFB4B6BFB4B6
BFB4B6BFB4B6BFB4B6BFB4B6BFB4B6C0B4B6C0B4B6C0B5B6C0B5B6C0B5B6C1B5B7C1B6B7
C1B5B6C1B5B6C1B6B6C1B6B6C1B6B6C2B7B6C2B7B6C3B7B7C2B6B6C2B7B6C3B7B6C3B7B6
C3B7B6C3B7B6C3B7B6C3B7B6C4B8B6C4B8B6C4B8B6C5B9B7C5B9B8C5B9B7C5BAB8C6BAB8
C6BAB8C6BAB8C6BBB8C7BBB8C7BBB8C7BBB8C8BBB9C8BCBAC8BCBAC9BDBAC9BDBACABDBA
CABEBACABEBBCABEBBCABEBBCABEBBCBBFBBCBBFBCCBBFBCCCC0BCCCC0BCCDC0BCCDC0BC
CDC0BCCDC0BCCEC0BCCDC0BCCDC0BCCDC1BCCEC1BCCEC1BCCEC1BCCEC1BCCEC1BCCEC1BC
CFC2BECFC2BECFC2BDCFC2BCCFC2BCD0C2BDD0C2BDD0C2BDD0C2BDD0C2BDD0C3BDD0C3BC
D0C3BCD0C3BCD0C3BDD1C4BFD5C6C0D6C7C1D6C7C2D6C7C2D6C7C1D6C7C1D6C7C1D5C7C1
D5C7C0D5C7C0D7C8C2D7C9C2D6C8C1D6C8C0D6C8C0D6C8C0D6C8C0D6C8C0D6C8C0D7C8C0
D7C8C0D7C8C0D7C8C0D8C9C0DBCCC4DDCDC5DFD0C8E0D0C8E1D1C8E1D1C9E1D1C8E1D1C8
E1D2C9E1D2C9E1D1C8E0D1C8E0D0C8E0D1C8E0D1C7E1D1C8E1D1C8E1D1C8E1D1C8E1D1C8
E2D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8E3D2C8
E4D3C8E4D3C8E4D3C8E4D3C8E4D3C8E4D3C8E4D3C8E4D3C8E4D3C8E5D4C8E5D4C8E6D5C9
E6D6CAE7D6CAE7D6CAE7D6C9E6D5C9E6D5C8E6D5C8E5D4C7E5D5C7E5D4C7E5D4C7E5D4C7
E5D4C7E4D4C6E4D4C6E4D4C6E5D5C6E5D4C6E4D4C5E5D4C5E4D4C5E4D4C4E4D4C4E4D4C4
E4D4C4E3D4C4E4D4C3E4D4C3E3D4C3E3D4C3E3D4C3E3D4C2E3D3C2E3D3C2E2D2C1E3D4C1
E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C0E3D4C0
E3D4C0E3D4C0E3D4C0E3D4C0E4D4C0E4D4C0E4D4C0E4D4C0E4D5C0E4D5BFE4D5BFE4D5BF
E4D5BFE4D5BFE4D5BFE4D5BFE4D5BFE1D3BDDFD1BBD0C2AE8880721C1A18000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
030303242223726C6EB2A7ABC1B5B9C2B7BAC2B6BAC2B6BAC1B5B9C1B5B9C0B4B8C0B4B8
C0B3B8BFB3B7BFB3B7BEB3B6BEB3B6BEB3B6BEB3B6BEB3B6BEB3B6BFB3B6BFB3B6BFB4B6
BFB4B6BFB4B6BFB4B6BFB4B6BFB4B6BFB4B5BFB4B5C0B4B6C0B5B6C1B5B7C1B5B7C1B6B7
C1B5B6C1B6B6C1B6B6C1B6B6C2B6B6C2B6B6C2B6B6C2B6B7C3B7B7C3B7B7C3B7B6C3B8B6
C3B8B6C4B8B6C4B8B6C4B8B6C4B8B6C4B8B6C4B9B6C4B9B7C5B9B7C5B9B7C5BAB8C6BAB8
C6BAB8C6BBB8C7BBB9C7BBB9C8BBB9C8BBB9C8BCBAC8BCBAC8BCBAC9BDBACABDBACABDBA
CABEBACABEBBCABEBBCBBEBBCBBFBBCBBFBCCBBFBCCBBFBCCCC0BCCCC0BCCCC0BCCDC0BC
CDC0BCCDC0BCCEC0BCCDC0BCCDC0BCCDC1BCCDC1BCCDC1BCCDC1BCCEC1BCCEC1BDCFC1BD
CFC2BECFC2BED0C2BECFC2BDCFC2BDD0C2BDD0C2BDD0C2BDD0C2BDD0C2BDD0C3BED0C3BE
D0C3BDCFC3BDD0C3BCD1C4BED3C6C0D5C6C0D5C6C0D5C7C1D6C7C1D6C7C1D6C7C1D6C7C1
D6C7C1D6C8C1D6C8C2D7C8C2D7C9C1D7C8C1D7C8C1D7C8C1D7C8C0D7C8C0D7C8C0D7C8C0
D7C8C0D7C8C0D7C8C0D8CAC1DDCDC5DDCDC5E0D0C8E0D0C8E0D0C8E0D0C8E0D0C8E0D0C8
E0D0C8E0D1C8E0D0C8DFD0C7E0D1C8E0D1C8E0D1C8E1D1C8E1D1C8E1D1C8E1D1C8E1D1C8
E2D1C8E2D1C8E2D1C8E2D1C8E2D2C8E2D2C8E2D2C8E2D2C8E3D2C8E3D2C8E3D2C8E3D3C8
E4D3C8E4D3C8E4D3C8E4D3C9E5D4C9E5D4C9E5D4C8E5D4C8E5D4C8E5D4C8E5D4C8E5D4C8
E5D5C8E6D5C8E6D5C8E6D5C8E5D5C8E5D5C8E5D5C8E5D5C7E5D4C7E5D4C7E5D4C7E5D4C7
E5D4C7E5D4C7E4D5C6E5D5C6E5D5C6E5D5C6E5D5C6E5D5C6E5D5C5E4D4C5E4D4C4E4D4C5
E3D4C4E3D4C4E3D4C4E3D4C3E3D4C3E4D4C3E4D4C3E4D4C3E4D4C2E3D3C2E0D1BFE3D3C1
E3D3C1E3D3C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C0
E3D4C0E3D4C0E3D5C0E3D4C0E3D4C0E3D4C0E4D4C0E4D5C0E4D5C0E4D5C0E4D5BFE4D5BF
E4D5BFE4D5BFE4D5BFE4D5BFE4D5BFDED0BAC7BAA7877E71322F2A070606000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000A0A0A171617
312E2F686063B1A6AAC3B6BBC3B7BBC2B6BAC1B6B9C1B5B9C1B5B9C0B4B9C0B4B8C0B3B7
C0B3B7BFB3B7BFB3B7BFB3B6BEB3B6BEB3B6BEB3B6BFB3B6BFB4B6BFB4B6BFB4B6BFB4B6
BFB4B6BFB4B6BFB4B6BFB4B6BFB4B6C0B5B6C0B5B6C0B5B6C1B5B7C1B5B7C1B6B7C1B6B7
C1B6B7C2B6B7C2B6B7C2B6B7C2B6B7C2B6B7C2B6B7C2B7B7C2B7B7C2B7B7C2B7B7C3B8B7
C4B8B7C4B8B7C4B8B7C4B8B7C4B8B7C4B9B7C5B9B8C5B9B8C5BAB8C5BAB8C5BAB8C6BAB8
C6BAB8C6BBB8C7BBB9C7BBB9C8BCB9C8BCBAC8BCBAC8BCBAC8BDBAC9BDBACABDBACABDBA
CABEBACABEBBCABEBBCBBFBCCBBFBCCBBFBCCBBFBCCBBFBCCCC0BCCCC0BCCCC0BCCDC0BC
CDC0BCCDC0BCCDC0BCCDC0BCCDC1BCCDC1BCCDC1BCCEC1BCCEC1BDCEC1BDCFC1BDCFC2BE
CFC2BECFC2BED0C3BED0C3BED1C3BFD1C3BFD0C3BED0C3BED0C3BED0C3BED0C3BED0C3BE
D0C3BDCFC3BCCFC3BBD0C3BDD2C5BED2C5BFD3C5BFD4C6C0D5C6C0D6C7C1D6C7C1D6C7C1
D6C7C1D6C8C1D7C8C2D7C9C2D8C9C2D8C9C2D7C8C1D7C8C1D6C8C0D7C8C0D7C8C0D7C8C0
D7C8C0D7C8C0D7C9C1DBCCC4DECEC6CDBFB7D7C8C0DFD0C8DFD0C8DFD0C8DFD0C8E0D0C8
E0D0C8E0D0C8E0D0C8E0D0C8E0D0C8E0D0C8E0D0C8E0D1C8E0D1C8E0D1C8E0D1C8E1D1C8
E2D2C8E2D2C8E2D2C8E2D2C8E2D2C8E3D2C8E3D2C8E3D2C8E3D3C9E3D3C9E3D3C9E4D3C9
E4D3C9E4D3C9E4D3C9E4D4C9E4D4C9E5D4C9E5D4C9E5D4C8E5D4C8E5D4C8E5D4C8E5D4C8
E5D4C8E5D5C8E5D5C8E5D5C8E5D5C8E5D5C8E5D5C8E5D5C8E5D5C7E5D5C7E5D5C8E5D5C7
E5D5C7E5D5C7E5D5C7E5D5C7E5D5C7E5D5C7E5D5C6E5D5C5E4D4C5E4D4C5E5D5C5E5D5C5
E4D5C4E4D4C4E3D4C4E3D4C3E3D4C3E3D4C3E3D3C2E3D4C3E1D2C1DFD0BEE1D1C0E3D3C1
E3D3C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C0
E3D4C0E3D4C0E3D4C0E3D5C0E3D5C0E3D4C0E3D5C0E3D5C0E4D5C0E4D5C0E4D5C0E4D5C0
E4D5C0E4D5BFE4D5BFE4D5BFE4D5BFE3D5BFD4C7B1696258030303000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000002220215B5557
92888CB0A5A9C1B5BAC2B7BBC2B6BAC1B6BAC1B5B9C1B5B9C1B5B9C0B4B8C0B3B8BFB3B8
BFB3B7BFB3B7BFB3B7BEB3B6BEB3B6BEB3B6BEB3B6BFB4B6BFB4B6BFB4B6BFB4B6BFB4B6
BFB4B6BFB4B6BFB4B6BFB4B6BFB5B6C0B5B6C0B5B7C1B5B7C1B5B7C1B5B7C1B5B7C1B5B7
C1B6B7C1B6B7C1B6B7C2B6B7C2B6B7C2B6B7C2B7B7C2B7B7C3B7B7C3B7B7C3B8B7C3B8B7
C3B8B7C3B8B7C4B8B6C4B8B6C4B8B7C5BAB8C5BAB8C5BAB8C6BAB8C6BAB8C6BAB8C6BAB8
C6BBB8C7BBB9C7BBB9C7BBB9C8BCBAC8BCBAC8BCBAC8BDBAC9BDBACABDBACABDBACABDBA
CABEBBCABEBBCABEBBCBBFBCCBBFBCCBBFBCCBBFBCCBBFBCCCC0BCCCC0BCCCC0BCCDC0BC
CDC0BCCDC0BCCDC0BCCDC0BCCDC1BDCDC1BCCEC1BCCEC1BCCEC1BDCFC1BDCFC1BDCFC1BD
CFC2BECFC2BED0C3BED0C3BED0C3BED1C4BED1C3BFD0C3BED0C3BED0C3BED0C3BED0C3BE
D0C3BDCFC3BDCFC3BCD0C4BDD1C4BED1C4BED1C4BED2C5BFD4C6C0D6C7C1D6C7C1D6C7C1
D6C7C1D6C8C1D6C8C2D7C9C2D7C9C2D8C9C2D7C8C1D6C8C0D6C8C0D6C8C0D7C8C0D7C8C0
D7C8C0D8C9C1DBCCC5DECFC7E1D2CAD4C5BED2C3BCDFD0C8E0D0C8E0D0C8E0D0C8E0D0C8
E0D0C8E0D0C8E0D1C8E0D1C8E0D1C8E0D1C8E0D1C8E0D1C8E0D1C8E1D1C8E1D1C8E1D1C8
E2D1C8E2D1C8E2D2C8E2D2C8E2D2C8E2D2C8E3D2C8E3D3C9E4D3C9E4D4C9E4D4C9E4D4C9
E4D4C9E4D4C9E5D4C9E5D4C9E4D4C9E5D4C9E5D4C9E5D4C9E5D4C9E5D4C9E5D4C8E5D4C8
E5D5C9E5D5C9E4D5C9E5D5C9E6D5C9E5D5C8E5D5C8E5D5C8E2D2C5E3D3C5E4D5C8E5D5C7
E5D5C7E5D5C7E5D5C7E5D5C7E5D5C7E5D5C7E5D5C6E5D5C6E5D5C5E4D5C5E4D5C5E4D4C5
E4D5C5E4D5C5E3D5C4E3D4C4E2D3C2E0D1C0E0D1C0E3D4C2E2D3C2E2D2C1E3D4C2E3D4C2
E3D4C2E3D4C2E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E4D4C1E4D4C1E4D5C1
E4D5C1E3D5C1E3D4C0E3D4C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E4D5C0
E4D5C0E4D6C0E4D6C0E5D6C0E0D2BCC3B7A4877F713C3832020201000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000001F1D1D696265ABA0A5
C1B5BAC2B6BBC2B7BBC2B6BAC1B6BAC1B5BAC1B5B9C0B4B9C0B4B8C0B4B8BFB3B8BFB3B8
BFB3B8BFB3B8BFB3B7BEB3B7BEB3B6BEB3B6BEB3B6BEB3B6BEB3B6BEB4B6BFB4B6BFB4B6
BFB4B6BFB4B6BFB4B6BFB4B6BFB4B6C0B5B6C1B5B7C1B5B7C1B5B7C1B6B7C1B6B7C1B6B7
C1B6B7C1B6B7C2B6B7C2B6B7C2B7B7C2B7B7C2B7B7C2B7B7C2B7B7C3B8B7C3B8B7C3B8B7
C4B8B7C4B8B7C4B8B7C4B8B7C4B9B7C5B9B8C5BAB8C5BAB8C5BAB8C5BAB8C6BAB8C6BBB9
C7BBB9C7BBB9C7BBB9C8BCBAC8BCBAC8BCBAC8BCBAC9BDBAC9BDBAC9BDBACABDBACABEBA
CABEBBCABEBBCABEBBCBBFBCCBBFBCCBBFBCCBC0BCCCC0BCCCC0BCCCC0BCCCC0BCCDC0BD
CDC0BDCDC0BCCDC0BCCDC0BCCDC1BCCDC1BCCEC1BDCEC1BDCFC1BECFC1BECFC1BECFC2BE
CFC2BECFC2BED0C3BFD0C3BFD1C4BFD1C4BFD2C4BFD1C3BFD0C3BED0C3BED0C3BED0C3BE
D0C3BED0C3BDD0C3BDD0C3BED0C4BDD0C4BED1C4BED2C5BFD4C6C0D6C7C1D6C7C1D6C7C1
D6C7C1D6C8C1D6C8C2D7C8C2D7C8C2D7C8C2D6C8C1D6C8C0D6C8C1D6C8C1D7C8C0D7C8C0
D7C9C1DBCCC4DFD0C9E1D2CAE1D2CADDCEC6D6C8C0DFD0C8DFD0C8E0D0C8E0D0C8E0D0C8
E0D0C8E0D0C8E0D0C8E0D0C8E0D0C8E0D1C8E0D1C8E0D1C8E0D1C8E0D1C8E0D1C8E1D1C8
E2D2C9E2D2C8E3D3C9E3D3C9E3D3C9E3D3C9E3D3C9E3D3C9E4D3C9E4D4C9E4D4C9E4D4C9
E4D4C9E4D4C9E4D4C9E5D4C9E4D4C9E4D4C9E5D4C9E5D4C9E5D4C9E5D4C9E5D4C9E5D4C8
E5D4C8E5D5C8E3D3C7E3D3C7E5D5C8E5D5C8E5D5C8E4D4C6D1C3B7DACCBFCEC1B5D9CABE
E5D5C7E5D5C7E5D5C7E5D5C7E5D5C7E6D6C7E6D6C7E5D5C6E5D5C6E3D3C4E3D3C4E5D5C6
E4D5C5E4D5C5E4D5C4E3D4C4E2D3C3E2D4C2E1D2C1E3D5C3E3D4C3E1D2C0E3D4C3E3D4C2
E3D4C2E3D4C2E3D4C2E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E4D5C1E4D5C1
E4D5C1E4D5C1E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E4D5C0
E4D5C0E4D6C0E4D6C0E5D6C0CFC2AD716A5E22201D11100E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000A0A0A1F1C1E6C6568AEA2A8BFB0B6
C0B2B7C2B7BBC1B6BAC1B6BAC1B5BAC1B5BAC0B5B9C0B4B8BFB3B8BFB3B8BFB3B8BFB3B8
BFB3B8BFB3B8BFB4B7BEB3B7BEB3B6BEB3B6BEB3B6BEB3B6BEB4B6BEB4B6BEB4B6BFB4B6
BFB4B6BFB4B6BFB4B6BFB4B6C0B5B6C0B5B7C1B5B7C1B5B7C1B6B7C1B6B7C1B6B7C1B6B7
C1B6B7C1B6B7C2B7B7C2B7B7C2B7B7C2B7B7C2B7B7C2B7B7C3B8B7C3B8B7C3B8B7C3B8B7
C4B9B7C4B9B7C4B9B7C4B9B7C5B9B8C5BAB8C5BAB8C5BAB8C5BAB8C6BAB8C6BBB8C7BBB9
C7BBB9C7BBB9C8BBBAC7BCBAC7BCBAC7BCBAC8BDBAC9BDBAC9BDBAC9BDBACABEBACABEBB
CABEBBCABEBBCABEBCCBBFBCCBBFBCCBC0BCCCC0BCCCC0BCCCC0BCCCC0BCCCC0BCCDC0BD
CDC0BDCDC0BDCDC0BDCDC1BDCDC1BDCDC1BDCEC1BDCFC1BECFC1BECFC1BECFC2BECFC2BE
CFC2BFCFC2BFD0C3BED0C3BFD1C4BFD2C4BFD1C4BFD1C4C0D0C4BFD0C4BFD1C4BFD1C4BF
D0C4BED0C3BDD0C3BDD0C4BED0C4BED1C4BFD3C5BFD3C6C0D5C7C0D6C8C2D6C7C1D6C7C1
D6C7C1D6C8C2D6C8C2D6C8C2D7C8C2D6C8C2D6C8C1D6C8C0D7C8C1D7C9C1D7C9C2D8CAC2
DACBC4DDCFC8E1D2CBE1D2CBE1D2CBE0D2CADDCEC7DFD0C8E0D1C9E0D1C9E0D1C9E0D1C9
E0D1C9E0D1C9E0D1C9E0D1C9E0D1C9E0D1C9E0D1C9E1D1C9E1D1C9E1D1C9E1D1C9E1D1C9
E2D2C9E2D2C9E3D3CAE3D3CAE3D3CAE3D3CAE3D3CAE4D3CAE4D4CAE4D4CAE4D4CAE4D4CA
E3D3C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9
E4D5C8E5D5C8E5D5C8E5D5C8E4D5C8E5D5C8E5D5C8E4D5C7E2D3C6E4D5C8D4C6BADDCDC1
E5D5C7E5D5C7E5D6C7E5D5C7E5D5C7E5D6C7E5D6C7E5D6C7E5D5C6D6C8BADECFC0E5D5C6
E4D5C5E4D5C5E3D4C4DACCBCDBCCBDE1D3C2E1D3C1E3D5C2E3D5C2E2D4C2E3D4C2E3D4C3
E3D4C2E3D4C2E3D4C2E3D4C2E3D4C1E3D4C1E3D4C1E3D4C1E3D4C1E3D5C1E3D5C1E3D5C1
E3D5C1E3D5C1E3D5C1E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E4D5C0
E4D6C0E2D4BED4C7B3C1B6A39A91813E3A34000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000001110102F2D2E635D61898185B7ACB1C1B5BBBCABB0
BDACB1C2B6BAC1B5BAC1B5BAC1B5BAC0B5B9C0B4B8BFB4B8BFB3B8BFB3B8BFB3B8BFB3B8
BFB3B8BFB3B7BFB3B7BEB3B6BEB3B6BEB4B6BEB4B6BEB4B6BFB4B6BFB4B6BFB4B6BFB4B6
BFB4B6BFB5B6BFB5B6C0B5B7C0B5B7C0B5B7C1B5B7C1B5B7C1B5B7C1B6B7C1B6B7C1B6B7
C1B6B7C2B6B7C2B7B7C2B7B7C2B7B7C2B7B7C2B7B7C3B8B7C3B8B7C3B8B7C3B8B7C4B8B8
C4B9B8C4B9B8C4B9B8C5BAB8C5BAB8C5BAB8C5BAB8C5BAB8C6BAB9C6BBB9C7BBB9C7BBB9
C7BBBAC7BBBAC8BBBAC7BCBAC8BCBBC8BDBBC8BDBBC9BDBAC9BDBAC9BDBAC9BEBACABEBB
CABEBBCABEBBCABEBCCBBFBCCBBFBDCCC0BDCCC0BDCCC0BDCCC0BDCCC0BDCCC0BDCDC0BC
CDC0BCCDC0BCCDC1BDCDC1BDCDC1BDCDC1BDCEC1BECFC1BECEC1BECFC1BECFC1BECFC2BE
CFC2BECFC2BED0C3BFD1C4BFD1C4BFD1C4BFD1C4BFD1C4C0D1C4C0D1C4C0D1C4BFD2C4C0
D1C3BED0C3BDD0C3BDD0C4BED0C4BED2C5BFD4C6C0D5C7C2D6C8C2D7C9C3D6C8C2D6C7C1
D6C7C1D6C8C2D6C8C2D6C8C2D6C8C2D6C8C2D6C8C1D6C8C1D7C9C1D8C9C2DACCC5DCCEC7
DDCFC8E0D1CAE1D2CBE1D2CBE1D3CBE1D2CBE1D1CAE0D1C9E0D1CAE1D1CAE1D2CAE1D1CA
E1D1CAE1D1CAE1D1CAE1D1CAE1D1CAE1D1C9E1D1C9E1D2C9E1D2C9E1D2C9E2D2C9E2D2C9
E2D2C9E3D3CAE3D3CAE3D3CAE3D3CAE3D3CAE3D4CAE3D4CAE3D4CAE4D4CAE1D1C8DBCCC2
E0D1C7E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D4C9E4D5C9
E4D5C9E4D5C8E5D5C8E5D5C8E5D5C8E5D5C8E5D6C9E5D6C9E5D6C9E5D6C9E4D5C8E3D4C7
E5D5C7E2D3C5D0C3B7BDB1A5BBAEA3BAADA2BAADA2BAADA2B7AB9FACA196D3C5B7DFD0C1
E2D3C3E0D1C1E1D2C2C4B7AACFC1B3E0D2C1E2D4C3E2D4C2E3D4C2E3D5C2E3D4C3E3D5C3
E3D5C3E3D4C2E2D4C2E3D4C1E3D4C1E3D4C1E3D4C1E3D5C2E4D5C2E4D5C2E4D5C2E4D5C2
E3D5C1E3D5C1E3D5C1E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E4D5C0E4D6C1
E4D6C1D2C5B29087794D48413D39331B1916000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000606063834358A8285B8ADB2C1B5BABDB2B7B7ABB0B4A6AA
BCAEB2C1B6BAC1B5BAC0B5BAC0B4B9C0B4B9BFB4B8BFB3B8BFB3B8BFB3B8BFB3B8BFB3B8
BFB4B8BFB4B8BFB4B7BEB3B7BEB4B7BEB4B7BEB4B7BEB4B6BEB4B6BFB4B6BFB4B6BFB4B6
BFB4B6BFB5B7C0B5B7C0B5B7C1B5B7C1B5B7C1B6B7C1B6B7C1B6B7C1B6B7C1B6B7C1B6B7
C1B6B7C2B7B7C2B7B7C2B7B7C2B7B7C2B7B7C2B7B7C3B8B7C3B8B7C3B8B7C3B8B7C4B9B8
C4B9B8C4B9B8C5B9B8C5B9B8C5BAB8C5BAB8C5BAB8C5BAB8C6BBB9C6BBB9C6BBB9C7BBB9
C7BCBAC8BCBAC8BCBAC8BCBAC8BDBBC8BDBBC8BDBAC9BDBAC9BDBAC9BEBACABEBBCABEBB
CABEBBCABEBBCABEBCCBBFBCCBBFBDCBBFBDCCC0BDCCC0BDCCC0BDCCC0BDCCC0BDCDC0BD
CDC0BDCDC1BDCDC1BDCDC1BDCEC1BDCFC1BECFC1BECFC1BECFC1BECFC2BECFC2BECFC2BF
CFC3BFCFC3BFD1C4BFD1C4BFD1C4BFD1C4BFD1C4BFD1C4C0D2C4C0D2C4C0D2C4C0D2C5C0
D1C4BFD1C4BED1C4BED1C4BFD1C5BFD2C6C0D4C7C1D7C9C3D9CBC6D9CBC5D6C8C3D6C8C2
D6C8C1D6C8C2D6C8C2D6C8C2D6C8C2D6C9C2D6C9C1D6C9C1D7C9C2D8C9C2DDCEC7E0D2CB
E0D2CBE1D2CBE1D2CBE1D2CBE2D3CCE1D3CBE0D1CAE0D1CAE0D1CAE0D1CAE0D1CAE0D1C9
E1D1C9E1D1C9E1D1C9E1D1C9E1D1C9E1D1C9E1D1C9E1D1C9E1D2C9E1D2CAE2D2CAE2D2CA
E3D3CAE3D3CAE3D3CAE3D3CAE3D3CAE3D4CAE3D4CAE3D4CAE3D4CAE4D4CAE4D4CAE4D4CA
E4D4CAE4D4CAE4D4CAE4D4CAE4D4C9E4D4C9E4D4C9E4D5C9E4D5C9E4D5C9E4D5C9E5D5C9
E4D5C9E5D5C9E5D5C9E5D5C9E5D5C9E5D6C9E5D6C9E5D6C9E5D6C9E5D6C8E5D5C8E5D5C8
E4D4C7BEB1A6615B552C29262B28262B28262B28262B28262B292648433E887F76B3A79B
C4B7AAC7BAACE3D4C4DDCFBFDED0C0D7C9BACABEAED7CABAE3D5C3E3D5C3E3D5C3E3D4C3
E3D4C3E3D4C3E3D4C2E2D4C1E2D4C1E3D4C1E3D4C1E3D5C2E3D5C2E3D5C2E3D5C2E4D5C2
E4D5C2E3D5C1E3D5C1E3D5C1E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E3D5C0E4D6C1DDD0BC
B2A8987C746938342F000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000C0B0B2C292B4C484A645D60968D92BFB3B9C3B7BEC3B7BDB8ACB1B9AEB3BDB2B7
B8ADB2B6ABAFBDB1B6C0B5B9C0B4B9BFB4B8BFB3B8BFB3B8BFB3B8BFB3B8BFB3B8BFB4B8
BFB4B8BFB4B7BEB3B7BEB3B7BEB3B6BEB4B6BEB4B6BEB4B6BEB4B6BEB4B6BEB4B6BFB4B6
BFB4B6BFB5B7C0B5B7C0B5B8C1B5B8C1B6B8C1B6B8C1B6B7C1B6B7C1B6B7C1B6B7C2B7B8
C2B7B8C2B7B8C2B7B8C2B7B7C2B7B7C2B8B7C3B8B7C3B8B7C3B8B8C3B8B8C3B9B8C4B9B8
C4B9B8C4B9B8C5B9B8C5BAB8C5BAB8C5BAB8C5BAB8C5BAB9C6BBBAC7BBBAC7BBBAC7BCBA
C8BCBAC8BCBAC8BCBAC8BCBAC7BDBBC8BDBBC8BDBAC9BDBAC9BDBAC9BEBBCABEBBCABEBB
CABEBBCABEBBCABEBCCBBFBCCBBFBDCBC0BDCBC0BDCCC0BDCCC0BDCCC0BDCCC0BDCDC0BD
CDC0BDCDC1BDCDC1BDCDC1BDCEC1BECEC1BECEC1BECEC1BECEC1BECEC2BECFC2BFCFC3BF
CFC3BFD0C4BFD1C4BFD1C4BFD1C4BFD1C4BFD1C4C0D1C4C0D1C4C0D2C4C0D2C4C0D2C5C0
D2C5C0D1C5C0D2C5BFD2C5BFD2C5BFD3C6C0D5C8C2DBCDC7DED0CBDACCC7D7C9C4D6C8C2
D6C8C2D6C8C2D6C8C2D6C8C2D6C9C2D6C9C2D7C9C2D8CAC3D9CBC5DCCEC7DFD1CAE0D2CB
E0D2CBE1D2CBE1D2CBE2D3CCE2D4CCE1D3CBE1D2CBE0D1CAE1D2CAE1D2CAE1D2CAE1D2CA
E0D1C9E0D1C9E0D1C9E1D1C9E1D1C9E1D1C9E1D1C9E1D2C9E1D2CAE1D2CAE2D2CAE2D2CA
E3D3CAE3D4CAE3D4CAE3D4CAE3D4CAE3D4CAE3D4CAE4D4CAE4D4CAE4D4CAE4D4CAE4D4CA
E4D4CAE4D4CAE4D4CAE4D4CAE4D4CAE4D4C9E4D5C9E4D5C9E4D5C9E4D5C9E4D5C9E4D5C9
E4D5C9E4D5C9E5D5C9E5D5C9E5D6C9E5D6CAE5D6C9E5D6C9E5D6C9E3D4C7D8CABDCDC0B4
B6AA9F665F590D0C0C00000000000000000000000000000000000008080723211E423E3A
57514C716A62938A7F988E83AA9F939B90859F958AD3C6B6E3D5C3E3D5C3E3D5C2E3D5C2
E3D4C3E3D5C2E3D5C2E3D4C2E3D4C2E3D4C2DFD2C0CABDADB4A99AB2A798B2A798B2A798
B5AA9ACCBFAEDFD1BEE3D5C1E3D5C1E3D5C1E3D5C1E3D5C1E3D5C0E4D6C1E4D6C1CFC2B0
68635923211D0F0E0D000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000030202060606
1D1C1C484447878084ADA3A9B9AEB4C1B5BBC3B7BDC1B5BBBFB3B9B6ABB0BEB3B8B7ACB1
B4A9AEB6ACB0BCB1B5C0B4B9BFB4B9BFB3B8BFB3B8BEB3B8BFB3B8BFB3B8BFB3B8BFB3B8
BEB3B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B6BEB4B6BEB4B6BFB4B7
BFB5B7C0B5B7C0B5B7C0B5B7C0B5B7C0B5B7C0B5B7C1B6B8C1B6B8C1B6B7C1B6B7C1B6B7
C1B7B7C1B7B7C2B7B7C2B7B7C2B7B7C3B8B7C3B8B7C3B8B7C3B8B8C3B9B8C3B9B8C4B9B9
C4BAB9C5BAB9C5BAB9C5BAB9C5BAB9C5BAB9C5BBB9C6BBBAC6BBBAC7BBBAC7BCBAC7BCBA
C7BCBAC7BCBAC7BCBAC8BCBAC7BDBBC8BDBBC8BDBBC9BDBAC9BDBAC9BEBBCABEBCCABEBC
CABEBBCABEBBCABFBCCBBFBCCBBFBDCBBFBCCBBFBCCBC0BCCCC0BDCCC0BDCCC0BDCDC0BD
CDC0BDCDC1BDCDC1BDCDC1BDCEC1BECEC1BECEC1BECEC2BECEC2BECEC2BFCFC2BFD0C3BF
D1C3C0D1C3C0D1C3C0D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D2C5C0
D2C5C0D2C5C0D3C6C0D3C6C0D3C6C0D3C6C0D5C8C2DBCEC9DFD1CCDDCFCAD8CBC5D6C9C3
D6C9C3D6C9C3D6C9C2D6C9C2D6C9C2D7C9C3D8CBC4DCCEC7DDCFC8DED0C9E0D1CBE1D2CB
E1D2CBE1D2CBE1D3CCE1D4CCE2D3CCE1D2CBE0D1CAE0D1CAE0D1CAE0D1CAE0D1CAE0D1C9
E0D1C9E1D2CAE1D2CAE1D2CAE1D2CAE1D2CAE1D2CAE2D2CAE2D3CAE2D3CAE2D3CAE3D3CB
E3D3CAE3D4CAE3D4CAE3D4CAE3D4CAE3D4CAE3D4CAE3D4CAE4D4CAE4D4CAE4D4CAE4D4CA
E4D4CAE4D4CAE4D4CAE4D4CAE4D4CAE4D5CAE4D5C9E4D5C9E4D5C9E4D5C9E4D5C9E4D6CA
E4D6CAE4D6CAE4D6CAE4D6C9E5D6CAE5D6CAE5D6CAE2D3C7DACBC0B7AAA07B736C59534E
47423E1F1E1B020202000000000000000000000000000000000000000000000000000000
080807201E1B322F2B322F2B322F2B2E2B28999084E3D5C4E3D5C3E3D5C3E3D5C3E3D5C2
E3D5C2E3D5C2E2D5C2DCCFBDD5C8B7CCC0B0A89E8F645E5647423D47423D47423D47433D
49443E6C655CA2988AC6BBA9DDCFBCE3D6C1E3D5C1E3D5C1E3D5C1E3D6C1DACDBAA89E8F
35332D000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000201021110112423244C494B6D676B
958C92B0A5ABC0B6BBC4B9BFC1B6BCBCB0B7B4AAAFB3A9AEB5ABB0BCB2B6C0B5BAB3A9AE
BCB1B6C0B5BAC0B4B9BFB4B9BFB3B9BEB3B8BFB3B8BFB3B8BFB3B8BFB3B8BFB4B8BFB4B8
BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BFB5B7BFB5B7
C0B5B8C0B5B8C0B5B8C0B5B8C0B6B8C1B6B8C1B6B8C1B6B8C1B7B8C1B7B8C1B7B8C2B7B8
C2B7B8C2B7B8C2B7B8C2B8B8C2B8B8C3B8B8C3B8B8C3B8B8C3B9B8C4B9B9C4B9B9C4B9B9
C4B9B9C5BAB9C5BAB9C6BABAC6BABAC6BABAC6BBBAC6BBBAC6BBBAC7BBBAC7BBBAC7BCBA
C7BCBAC7BCBAC7BCBAC7BCBBC7BDBBC7BDBBC8BDBBC9BDBBC9BEBBC9BEBBCABEBCCABEBC
CABEBCCABFBCCABFBCCBBFBCCBBFBDCBBFBDCBC0BDCCC0BDCCC0BDCCC0BDCCC0BDCCC0BD
CCC0BDCCC1BDCCC1BDCDC1BDCEC2BECEC2BFCEC2BFCEC2BFCFC2BFCFC2BFCFC3BFD0C3C0
D1C4C1D1C4C1D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D2C5C0D2C5C0
D2C5C0D2C5C0D3C6C0D3C6C1D3C6C1D3C6C0D5C8C2DBCEC9DED1CCDDD0CBDBCEC8D9CCC6
D9CBC6D9CBC5D9CBC5D9CBC5D9CCC5DBCDC6DECFC9DFD1CAE0D2CBE0D2CBE0D2CBE1D3CC
E1D3CCE1D3CCE1D4CCE1D4CCE2D3CCE1D2CBE0D1CAE0D1CAE0D1CAE0D1CAE0D1CAE0D1C9
E0D1C9E0D2CAE2D3CBE3D4CCE2D3CBE1D2CAE1D2CAE2D3CAE2D3CAE2D3CAE2D3CAE2D3CA
E3D3CAE3D3CAE3D3CAE3D3CAE3D3CAE3D4CBE3D4CBE3D4CBE3D4CBE4D4CAE3D4CAE3D4CA
E4D4CAE4D4CAE4D4CAE4D4CAE4D4C9E4D4C9E4D4C9E4D5C9E4D5C9E4D5C9E4D5CAE4D5CA
E4D6CAE4D6CAE4D6CAE4D6CAE5D6CAE5D6CAE5D6CACABDB2877E773935320E0C0C000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000001514129D9387E4D6C5E3D6C4E3D5C4E3D5C3E3D5C3
E3D5C3E3D6C3D3C6B6888075615B5356514A312F2A090908000000000000000000000000
0000000A0909262421514B45888074A89F90A69C8EA3998BA3998BA3998B8E8579545048
151412000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000505050D0C0C131212131212131212191818242123565153857E83ACA3A8BCB2B8
C3B9BFC4B9C0C4B8BFC3B8BEBBB0B5B6ABB1AEA3A9B1A7ACBEB4B9C0B6BAC0B5BAB8ADB2
BEB3B7BFB4B9BFB3B9BFB3B8BEB3B8BEB3B8BEB3B8BEB3B8BEB3B8BFB3B8BFB3B8BEB4B8
BEB3B7BDB3B7BEB3B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BFB5B7BFB5B7
C0B5B8C0B5B8C0B5B8C0B5B8C0B5B8C1B6B8C1B6B8C1B6B8C1B6B8C1B6B8C1B7B8C1B7B8
C2B7B8C2B7B7C2B7B7C2B8B7C2B8B7C2B8B8C3B8B8C3B9B8C3B9B9C4B9B9C4B9B9C4B9B9
C4BAB9C5BAB9C5BAB9C6BABAC6BABAC6BBBAC6BBBAC6BBBAC7BBBAC7BBBAC7BCBAC7BCBA
C7BCBAC7BCBBC7BCBBC7BDBBC8BDBBC8BDBBC8BDBBC9BDBBC9BEBBC9BEBBCABEBCCABEBC
CABFBCCABFBCCABFBCCBBFBDCBBFBDCBC0BDCBC0BDCCC0BDCCC0BDCCC0BDCCC0BDCCC0BD
CCC1BDCCC1BDCDC1BDCDC1BDCEC2BECEC2BFCEC2BFCEC2BFCEC2BFCEC2BFCFC2BFD0C3C0
D1C4C1D1C4C1D1C4C1D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D1C4C0D1C5C0D2C5C0
D2C5C0D2C5C0D2C6C0D2C6C0D3C6C1D3C6C1D5C8C2DBCEC9DED1CCDED1CCDDD0CADDCFC9
DDCFC9DDCFC9DDCFC9DED0C9DED0CADFD1CAE0D2CCE0D3CCE0D2CCE0D2CBE1D3CCE1D3CC
DFD1CAE1D3CCE1D3CCE1D3CCE2D3CCE1D3CCE1D3CBE0D2CBE0D2CAE1D2CAE1D2CAE1D2CA
E0D1CAE0D1C9E2D3CBE2D4CBE2D3CBE2D3CAE2D3CAE2D3CAE2D2CAE2D3CAE2D3CBE2D3CA
E3D3CAE3D3CAE3D3CAE3D3CAE3D4CAE3D4CBE3D5CBE3D5CBE3D5CBE4D4CBE3D4CAE3D4CA
E3D4CAE4D4CAE4D4CAE4D4CAE4D4C9E4D4C9E4D5C9E4D5C9E4D5C9E4D6CAE4D6CAE4D6CA
E4D6CAE5D6CAE5D5CAE2D4C8DBCDC1BBAFA59F958C7A726C302D2A000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000001514128C8379E4D5C5E4D6C5E3D5C4E2D5C3E2D5C3
E2D5C2D7CAB990877C1E1D1A000000000000000000000000000000000000000000000000
00000000000000000002020211100F201E1B201E1B201E1B201E1B201E1B181714090908
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010101090809111011161415
161415333132625C5F827C80847D81847D81847C818C8389AEA5AAC0B5BBC5BAC0C4BAC0
C4B8BFC4B8BFC2B7BEC2B7BDB8ADB2BDB2B8B7ACB1B9AEB3C1B6BBC0B5BBC0B5BABEB3B8
BFB4B9BFB4B9BFB3B9BEB3B9BEB3B8BEB3B8BEB3B8BEB3B8BEB3B8BEB3B8BFB4B8BEB4B8
BEB3B7BDB3B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BFB5B7BFB5B7C0B5B8
C0B5B8C0B5B8C0B5B8C0B5B8C0B6B8C1B6B8C1B6B8C1B7B8C1B7B8C1B7B8C1B7B8C2B7B8
C2B8B8C2B8B8C2B8B8C3B8B8C3B8B8C3B8B8C4B9B9C4B9B9C4B9B9C4BAB9C4BAB9C5BAB9
C5BAB9C5BABAC6BBBAC6BBBAC6BBBAC6BBBAC6BBBAC7BBBAC7BBBBC7BCBBC7BCBAC7BCBA
C7BCBAC7BCBBC7BDBBC7BDBBC8BDBBC9BDBBC9BDBBC9BEBBC9BEBBC9BEBCC9BEBCCABFBC
CABFBCCABFBCCABFBCCBBFBDCBC0BDCBC0BDCCC0BDCCC0BDCCC0BDCDC0BDCCC1BDCCC1BD
CCC1BDCDC1BECDC1BECEC2BECEC2BFCEC2BFCEC2BFCEC2BFCEC3BFCFC3BFCFC3BFD0C3C0
D1C4C1D1C4C1D1C4C1D1C4C1D1C4C1D1C4C0D1C4C0D1C4C0D1C4C0D1C5C0D1C5C0D2C5C0
D2C5C0D2C6C0D2C5C0D2C5C0D3C6C1D3C7C1D5C8C2DBCEC9DED1CCDFD1CCDFD1CBDFD1CB
DFD1CBDFD1CBDFD1CBE0D2CCDFD2CBE0D2CBE0D2CCE1D3CDE1D3CDE1D3CDE1D3CCE1D3CC
D5C8C1D8CCC4E1D3CCE2D4CDE2D4CDE2D4CDE2D4CDE1D3CBE0D2CBE0D2CBE0D2CBE0D2CB
E0D2CAE0D2CAE1D3CBE2D4CCE3D5CDE3D5CCE2D3CBE2D3CBE2D3CBE2D4CBE2D3CBE2D3CB
E2D3CBE3D3CBE2D3CBE3D4CBE3D4CBE3D4CBE3D5CBE3D5CBE3D5CBE3D5CBE3D4CAE3D4CA
E3D4CAE3D4CAE3D4CAE3D4CAE3D4CAE4D5C9E4D5C9E4D5C9E4D5CAE4D6CAE4D6CAE4D6CA
E5D6CAE5D6CADDCFC3ADA2997F767057514C36322F2A272511100F000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000F0E0D5F5952BFB3A5D8CBBAE1D3C2E1D4C2DDD0BF
C9BDAD8B8378383530080807000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000303032624254A46495D585B
5F5A5D817B7FACA2A9C0B6BCC0B6BDC0B6BEBFB5BCC1B7BDC4BAC0C4BAC0C4B9C0C3B8C0
C3B8BEC2B8BEC2B7BDC1B7BDBDB3B8C0B5BBBEB3B9BFB5BAC0B5BABEB3B9BEB3B8BFB4B9
BEB3B9BEB3B9BEB3B9BEB3B9BEB3B9BEB3B9BEB3B9BFB4B9BFB4B8BFB4B8BFB4B8BEB4B8
BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BEB4B7BFB5B7C0B5B8C0B5B8C0B5B8
C0B5B8C0B6B8C0B6B8C0B6B8C1B6B8C1B6B8C1B6B8C1B6B8C1B7B8C1B7B8C2B7B8C2B7B8
C2B7B8C2B8B8C2B8B8C2B8B8C3B8B8C3B9B8C4B9B9C4B9B9C4B9B9C4B9B9C4BAB9C5BAB9
C5BABAC6BBBAC6BBBAC6BBBAC6BBBAC6BBBAC7BCBBC7BCBBC7BCBBC7BCBBC7BCBBC7BCBB
C7BCBBC7BDBBC7BDBBC7BDBBC8BDBBC9BDBBC9BEBBC9BEBCC9BEBCC9BEBCC9BEBCCABFBC
CABFBCCABFBCCABFBCCBC0BDCBC0BDCCC0BDCCC0BDCCC0BDCCC0BDCCC0BDCCC1BDCCC1BD
CCC1BECDC1BECEC1BECEC2BFCEC2C0CEC2C0CEC2C0CFC3C0CFC3C0D0C3C0D0C4C0D1C4C1
D2C5C2D2C5C1D2C5C1D2C5C1D2C5C1D2C5C1D1C5C1D1C5C0D2C5C0D2C5C0D2C5C0D2C6C1
D3C6C1D3C6C1D3C6C1D3C6C1D3C6C0D4C7C1D6C9C3DCCFCADED1CCDFD1CBDFD1CBDFD1CB
DFD1CBDFD1CBDFD1CBE0D2CCDFD2CCE0D2CCE0D2CCE1D3CDE1D4CDE1D4CDE1D4CDE1D4CD
D9CCC5DBCDC7E1D4CCE2D4CDE2D4CDE2D4CDE2D4CDE1D3CBE0D2CBE0D2CBE0D2CBE1D2CB
E1D3CBDFD1C9E1D3CBE2D4CCE3D5CDE2D4CCE2D3CBE2D4CBE2D4CBE2D3CBE2D3CBE2D3CB
E2D3CBE2D4CBE2D4CBE3D4CBE3D4CBE3D5CBE3D5CBE3D5CBE3D5CBE3D5CBE3D4CAE3D4CA
E3D4CAE3D4CAE3D4CAE3D4CAE3D5CAE3D5CAE4D5CAE4D5CAE4D6CAE4D5CAE4D6CAE4D6CB
E5D6CAE5D6CBC9BCB258534E000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000060605252320625C558980779A91849D94878E857B
5E58511E1D1A040403000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000C0B0C1A191A3A373A524D51645E635E595D555154504C4F756F73A39CA1BCB2B9
C2B8BFC4BAC0C4BAC1C5BAC1C5BAC1C5BAC1C4B9C0C3B9C0C3B8BFC3B8BFC2B8BEC2B7BE
C1B7BDC1B7BCC1B6BCC1B6BCC1B6BCC0B6BCC0B6BBBAB0B5B3A9AEBAB0B5BDB2B8BEB3B9
BEB3B9BEB4B9BEB4B9BEB3B9BEB3B9BEB3B8BEB3B8BEB3B8BEB4B8BEB4B8BEB4B8BEB4B8
BEB4B7BDB4B7BDB4B7BEB4B7BEB4B7BEB4B7BEB5B7BEB5B7BFB5B8BFB5B8C0B5B8C0B5B8
C0B5B8C0B5B8C0B6B8C1B6B8C1B7B8C1B7B8C1B7B8C1B7B8C1B7B8C2B7B8C2B7B8C2B8B8
C2B8B9C2B8B9C3B8B9C3B9B9C4B9B9C4B9B9C4B9B9C4BAB9C4BAB9C4BABAC5BABAC5BABA
C5BABAC5BABAC5BBBAC6BBBAC6BBBAC6BBBBC6BBBBC6BCBBC7BCBBC7BCBBC7BCBBC7BDBC
C7BDBBC7BDBBC8BDBBC8BDBBC8BEBBC8BEBBC9BEBBC9BEBCC9BEBCC9BFBCCABFBCCABFBC
CABFBCCABFBCCAC0BDCBC0BDCBC0BDCBC0BDCCC0BDCCC0BDCCC1BECCC1BECCC1BECDC1BE
CDC2BECEC2BFCEC2BFCFC2C0CFC3C0CFC3C0D0C4C0D1C5C2D1C5C2D2C5C2D2C5C2D3C6C3
D3C6C3D2C5C2D2C5C1D2C5C1D2C5C1D2C5C1D2C6C1D2C5C1D2C6C1D2C6C1D2C6C1D3C7C2
D4C7C2D3C7C2D3C6C1D4C7C2D7CAC5DBCEC9DDD0CBDED1CCDED1CCDFD1CCDFD1CCDFD2CC
DFD2CCDFD2CCDFD2CCDFD2CCDFD2CCDFD2CCE0D3CCE1D3CDE1D3CDE1D3CDE1D3CDE1D4CD
E1D3CDE1D4CDE1D4CDE1D4CDE1D4CDE2D5CDE2D5CDE2D5CDE1D4CCE1D2CBE1D2CBE1D2CB
E1D2CBE1D2CBE1D2CBE2D3CBE3D5CDE3D5CDE3D4CCE2D4CCE2D4CBE2D4CBE2D4CBE2D4CB
E2D4CCE2D4CCE2D4CCE2D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CBE3D5CBE3D5CB
E3D5CBE3D5CBE3D5CBE3D5CBE3D5CBE3D5CBE3D5CBE3D5CAE3D6CAE4D6CBE3D4C9B3A89F
4A44401E1D1B1817150B0A09000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000002321234C484B827C819B939AAEA5ACA9A0A79E969C958D939F969DB3A9B0C1B7BE
C5BBC2C4BBC2C4BBC2C4BBC1C4BBC1C4BAC1C3B9C0C3B8BFC2B8BEC2B7BEC2B7BEC1B7BD
C1B7BDC0B6BCC0B6BCC0B6BCC0B6BBC0B6BBBFB5BBB8AEB3B5ACB0BEB3B9BEB3B9BEB3B9
BEB3B9BEB3B9BEB3B9BEB3B9BEB3B9BEB4B9BEB4B9BEB4B9BFB4B9BFB4B9BFB4B9BEB4B8
BEB4B8BDB4B7BDB4B7BEB4B7BEB4B7BEB5B8BFB5B8BFB5B8C0B5B8C0B5B8C0B6B8C0B6B8
C0B6B8C0B6B8C0B6B8C0B6B8C0B6B8C1B6B8C1B7B8C1B7B8C2B8B8C2B8B8C2B8B8C2B8B9
C2B8B9C2B8B9C3B9B9C3B9B9C3B9B9C4B9B9C4B9B9C4B9B9C4BABAC5BABAC5BBBBC5BBBB
C6BBBBC6BBBBC6BBBBC6BBBBC6BBBBC6BBBBC6BCBBC6BCBBC6BCBBC7BCBBC7BDBBC7BDBB
C7BDBBC8BDBBC8BDBBC8BEBBC8BEBBC8BEBBC9BEBBC9BEBCC9BFBCC9BFBDCAC0BDCAC0BE
CAC0BECBC0BDCBC0BDCBC0BDCBC0BECCC0BECCC0BECCC1BECCC1BECCC1BECCC1BECDC2C0
CEC2C0CEC3C0CEC3C0CFC3C0CFC3C0CFC3C0D0C4C1D2C5C3D2C5C3D2C6C3D3C6C3D3C7C3
D3C7C3D3C6C3D3C6C2D3C6C2D3C6C2D3C6C2D3C6C2D3C6C2D3C7C2D3C7C2D3C7C2D5C8C3
D6CAC5D5C9C4D5C9C3D7CAC5DACDC8DED1CCDED1CCDED1CCDED1CCDFD1CCDFD2CCDFD2CC
DFD2CCDFD2CCDFD2CCDFD2CCDFD2CCE0D3CCE1D3CDE1D3CDE1D3CDE1D3CDE1D3CDE1D3CD
E1D4CDE1D4CDE1D4CDE1D4CDE2D4CDE2D5CDE2D5CDE2D5CDE2D4CDE1D3CCE1D3CBE1D3CB
E1D3CBDFD1CAE1D3CBE2D4CCE3D5CDE3D6CDE3D4CCE2D4CCE2D4CBE2D4CBE2D4CBE2D4CC
E2D4CCE2D4CCE2D5CCE2D5CCE2D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CBE3D5CB
E3D5CBE3D5CBE3D5CBE3D5CBE4D5CBE4D5CBE4D5CBE4D6CBE3D5CAE1D3C8C5B9AF5B5551
090808000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000080708131213
2B292B686367989197BDB3BBC1B7BFC6BBC4C6BBC3C6BBC3C2B8C0BEB4BBBFB5BDC3B9C1
C4BBC2C4BAC2C4BAC2C4BAC2C4B9C1C3B9C0C2B8BFC2B7BFC2B7BEC2B7BEC1B7BDC1B7BD
C0B6BCC0B6BCC0B6BBC0B6BBC0B6BBC0B5BBBFB5BABDB2B8BCB1B7BEB3B9BEB3B9BEB4B9
BEB4B9BEB3B9BEB3B9BEB3B9BEB3B9BEB3B9BEB4B9BEB4B9BEB4B9BEB4B9BEB4B9BEB4B8
BEB4B8BEB4B8BEB4B7BEB4B7BEB5B7BEB5B8BFB5B8BFB5B8BFB5B8BFB5B8BFB5B8C0B5B8
C0B6B8C0B6B8C0B6B8C1B7B9C1B7B8C1B7B8C1B7B8C1B7B8C2B7B8C2B8B9C2B8B9C2B8B9
C3B9BAC3B9BAC3B9BAC4B9BAC4B9BAC4BABAC4BABAC4BABAC5BABAC5BABBC5BBBBC6BBBB
C6BBBBC6BBBBC6BBBBC6BBBBC6BBBBC6BCBBC6BCBCC6BDBCC6BDBCC7BDBCC7BDBCC7BDBC
C8BEBCC8BEBCC8BEBCC8BEBCC9BEBCC9BEBCC9BFBCC9BFBDC9BFBDCAC0BDCAC0BECAC0BE
CBC0BECBC0BECBC0BECCC0BECCC0BECCC0BECCC1BECCC1BECCC1BECCC1BECCC2BFCDC2C0
CDC2C0CEC3C0CFC3C0CFC3C0CFC3C0D0C4C1D1C5C2D3C6C4D3C6C3D3C6C3D3C7C3D3C7C3
D3C7C3D3C7C3D2C6C2D3C6C2D0C4C0D0C3BFD6C9C5D6CAC5D6CAC5D6CAC5D7CBC6DACDC8
DACEC9DACEC9D9CDC8DBCECADDD0CBDED2CDDED1CCDFD1CCDFD1CCDFD1CCDFD2CCDFD2CC
DFD2CCDFD2CDDFD2CDDFD2CDE0D3CDE0D3CDE1D3CDE1D3CDE1D3CDE1D3CDE1D4CDE1D4CD
E1D4CDE1D4CDE1D4CDE2D4CDE2D5CDE2D5CDE2D5CDE2D5CDE2D5CDE2D5CDE2D4CDE2D4CD
E2D4CDDCCEC7E2D5CDE3D5CDE3D5CDE3D5CCE2D4CCE2D4CCE2D4CCE2D4CBE2D4CCE2D4CC
E2D4CCE2D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CCE3D5CC
E3D5CCE3D5CCE3D5CCE4D5CCE4D5CCE4D5CBE4D6CBE5D6CCC9BCB29C918A58524E141312
010101000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000001D1B1D8C848CBEB5BEC1B9C1BDB4BDBAB1BA
BCB2BBBEB5BEC0B6BFC0B7BFBFB6BFBFB6BEBFB6BEBFB6BEBFB6BEBFB6BEBFB6BEBFB6BD
BFB5BDBEB5BDBEB5BCBEB5BCBEB5BCBEB4BBBDB4BBBDB4BBBDB4BBBDB4BBBBB2B8B2A9AF
AAA2A8B2A9AFBAB0B7BDB3BABDB3BABDB3BABDB3BABDB3BABDB3BABDB3BABDB3BABDB4BA
BDB4B9BDB4B9BDB4B9BEB4B9BEB4B9BEB4B9BEB4B9BEB4B9BEB5B9BEB5B9BEB5B9BEB5B9
BEB5B9BEB5B9BEB5B9BFB5B9BFB6B9BFB6B9BFB6B9BFB6B9BFB6B9C0B7B9C0B7B9C0B7B9
C1B7B9C1B7B9C1B8B9C1B8BAC1B8BAC1B8BAC2B9BAC2B9BAC2B9BAC3B9BBC4BABBC4BABB
C4BABBC4BABBC4BABBC4BBBCC5BBBCC5BBBCC5BBBCC5BBBCC5BBBCC5BBBCC5BCBCC6BCBC
C6BCBCC6BCBCC6BDBDC7BDBDC7BDBDC7BEBDC7BEBDC7BEBDC8BEBDC8BEBEC8BFBEC9BFBE
C9BFBFC9BFBFC9BFBFC9C0BFCAC0BFCAC0BFCBC0BFCBC0BFCBC0BFCBC0BFCBC0BFCBC1BF
CBC1BFCBC1BFCCC1BFCDC1C0CCC1C0C9BEBCB0A7A67F77773A3737000000000000000000
0000000000000000000000000000000202020D0C0C2A2727BAB0AEDDD1CEB9B3A8B6AFA6
C5BBB8D8CCC9DDD0CDDDD1CDDCD1CDDCD1CEDCD1CEDCD1CEDDD1CEDDD1CEDDD1CEDDD1CD
DDD1CDDDD1CDDDD2CDDDD1CDDED1CDDED1CDDED2CDDED2CDDED2CDDED2CDDFD2CDDFD2CD
DFD3CDDFD3CDE0D3CEE0D4CEE0D4CEE0D4CEE1D4CEE0D4CEE1D5CEE1D5CFE1D5CFE1D5CF
E1D5CFE1D5CFE2D6CFE2D6CFE1D5CEDDD1CAC0B5AFACA39DAAA19B857E7A6A64613C3836
0808070000000A0A091E1C1B3E3A386A6460ADA49DE3D6CEE3D6CEE3D6CEE3D6CEE3D6CE
E3D5CDE0D3CBDFD2CABFB4AD5C56521B19181211110807071D1514484441484441484441
48444145413E201E1D000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000605061F1E1F817B81B5ACB5C0B8C0C0B7C0C0B7C0
BEB4BEBFB5BFBFB6BFBFB6BEBFB6BEBFB6BEBFB6BEBFB6BEBFB6BEBFB6BEBFB6BDBEB5BD
BEB5BDBEB5BCBEB5BCBEB5BCBEB5BCBEB5BBBDB4BBBDB4BBBEB4BBBDB4BBBAB1B8B0A7AE
AAA2A8B3AAB0BAB0B7BDB3BABDB3BABDB3BABDB3BABDB3BABDB3BABDB3BABDB4BABDB4BA
BDB4BABDB4BABDB4BABDB4BABEB4B9BEB4B9BEB4B9BEB5B9BEB5B9BEB5B9BEB5B9BEB5B9
BEB5B9BEB5B9BEB5B9BFB6BABFB6BABFB6BABFB6BAC0B7BAC0B7B9C0B7B9C1B7B9C1B7B9
C1B8BAC1B8BAC1B8BAC1B8BBC2B8BBC2B9BBC3B9BBC3B9BBC3B9BBC3BABBC4BABCC4BABC
C4BABBC4BABBC4BABBC5BBBCC5BBBCC5BBBCC5BBBCC5BBBCC5BBBCC5BCBDC5BCBDC6BCBD
C6BDBDC6BDBDC7BDBDC7BDBDC7BEBDC7BEBDC8BEBDC8BEBDC8BEBEC8BFBEC9BFBEC9BFBF
C9BFBFC9BFBFC9C0BFC9C0BFCAC0BFCBC0BFCAC0BFCAC0BFCAC1BFCBC1BFCBC1BFCBC1BF
CBC1BFCBC1BFCCC1C0CCC1C0CBC0BEB1A7A6524D4C2624230E0E0D000000000000000000
0000000000000000000000000000000F0E0E474443898180D3C8C5DCD1CEB0A7A5CFC4C1
DDD1CEDCD0CDDDD1CDDDD1CDDCD1CEDCD1CEDCD1CEDCD1CEDDD1CEDDD1CEDDD1CEDDD1CE
DDD1CEDDD2CEDDD2CEDDD1CDDED1CDDED2CDDED2CDDED2CDDED2CDDED2CDDFD2CDDFD3CE
DFD3CEDFD3CEE0D3CEE0D4CFE0D4CFE0D4CFE1D4CFE0D4CFE1D5CFE0D5CFE1D5CFE1D5CF
E1D5CEE1D5CFE2D6CFE2D6CFDCD0C99D948F585350363332272524121111030303020202
0000000000000000000000001E1C1B655F5CAAA19BCDC0BACEC2BBD5CAC2D9CEC6DCCFC7
C8BDB69C938D8B837E5B5653141312000000000000000000544B48B8AEA7B8AEA7B8AEA7
B8AEA7B5ABA46A635F111010000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000151415635F649D969FAFA8B1ABA4AEA59EA7A59DA7B2AAB4
B9B1BBBBB2BDBBB3BCBBB3BCBAB2BCBAB2BBBAB1BBBAB2BCBBB3BCBCB3BDBCB3BCBCB3BC
BCB3BCBCB3BCBCB3BCBCB3BCBCB3BCBCB3BCBCB3BCBCB3BCBCB3BCBCB3BCBCB3BCBCB3BC
BCB3BCB5ADB5AFA7AEB4ABB3B4ABB3B4ABB3B4ABB3B3AAB2B5ACB4BBB2B9B8AFB7BBB2B9
BCB3BBBCB3BBBCB3BBBCB4BBBDB4BBBDB4BBBCB4BABCB4B9BCB4B9BCB4B9BCB4B9BCB4B9
BCB4B9BCB4B9BCB4B9BDB5BABEB5BABEB5BABEB5BABEB5BABEB5BABEB6BABEB6BABEB6BA
BFB6BABFB6BAC0B7BAC0B7BAC0B7BAC0B8BAC0B8BBC0B8BBC1B8BBC1B9BBC2B9BBC2B9BB
C2B9BBC2B9BBC2B9BBC2BABCC3BABDC3BABCC4BABDC4BBBDC4BBBDC4BBBDC4BBBDC4BBBD
C4BBBDC4BBBDC4BBBDC4BCBDC5BCBEC5BCBDC5BDBDC5BDBDC6BDBDC6BDBEC6BDBEC7BEBE
C7BEBFC7BEBFC7BEBEC7BEBEC8BFBFC8BFBFC8BFBFC8BFC0C9C0C0C9C0BFC9C0C0CAC0C0
CAC0C0CAC0C0CAC1C0CBC1C1CBC1C1CBC1C1CBC1C1CAC0C1C6BCBDA19999454141090909
040404000000000000000000000000000000000000000000000000000000000000000000
0000002725257B7473B8AFADC9BEBBC7B8B6D0C1BFD9CDCBDCD1CEDCD0CEDCD0CEDCD0CD
DCD0CDDCD1CEDCD1CFDCD2CFDCD2CFDBD0CDDBD0CDDDD1CDDDD1CDD4C8C5C1B7B4DDD2CE
DDD2CEDDD2CEDDD2CEDDD2CEDED2CEDED2CEDED2CEDED2CEDED3CEDED2CEDACECADFD4CF
DFD4CFE0D4CFE0D4CFE0D5CFE0D5CFE0D5CFDACFC9C7BEB8968E8A716B684D4947181716
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000038353378726E8C8580968F89AEA69FD7CCC4
E3D8CFE6DAD1E5D9D0E6DBD1E6DBD1E6DBD2E7DAD2E7DAD2E7DAD1E7DAD1E7DBD1E3D7CE
E2D6CDE7DAD1E7DAD1D1C6BDCEC3BBE4D8CEE8DBD1E8DBD1E8DBD2E8DBD1E8DBD1E8DBD1
E5D9CFCDC2B9837C769A928AE3D6CCE9DCD0E8DCD1D9CDC2ACA29AA69D95928A825F5955
1E1D1B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000101011A1917978E85E9DCCCE8DCCCE8DCCB
E8DCCBE8DDCBE8DDCBE8DDCBE8DDCBE8DDCBB9B0A14A4640000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000606064C4A50A7A4B3
BFBBCABEBACABEBACABEBACABEBACABEBACABEBACABEBACABEBACABEBAC9BEB9C9BDB9C8
BDB9C8BCB9C8BCB9C8BDB9C8BDB9C8BDB9C8C0BBC9C0BDCBC1BDCBC1BDCAC3BECCC4BFCD
C5C0CEC5C0CEC1BDCBBDB9C6BDB8C6BDB8C6BDB8C6BDB8C6BDB8C6BEB9C6BEB9C6BEB9C6
BEB9C6BEB9C6BEB9C6BEB9C6BCB7C4BAB5C1B8B3BFB8B2BFB7B2BEB7B2BDB7B2BDB7B2BD
B7B2BDB7B1BDB7B2BDB7B2BDB7B2BDB7B1BCB7B1BCB7B1BCB7B1BCB6B1BCB6B1BCB6B1BC
B6B0BBB6B0BBB6B0BBB6B0BAB6B0BAB6B1BAB6B1BAB7B1BAB7B1BAB7B1BAB7B1BAB7B1BA
B7B1BAB7B1BAB7B2BAB7B2BAB7B2BAB7B2BBB8B3BBB8B3BCB8B3BCB8B3BCB8B3BCB9B3BC
B9B4BCB9B4BCB9B4BCB9B4BCB9B4BCB9B4BCB9B4BCBAB4BCBAB5BCBAB5BCBBB5BDBBB6BD
BBB6BDBCB6BDBCB6BDBCB6BDBCB7BDBDB7BDBDB7BDBDB7BDBDB8BDBDB8BEBEB8BEBEB8BE
BEB8BEBEB8BEBEB9BEBFB9BEBFB9BEC0BABEC0BABFC0BABFC0BABFC1BABFC1BABFC1BBC0
C1BBC0C1BBC0C1BBC0C2BBC0C2BCC0C2BCC0C2BCC0C2BDC0C3BDC0C3BDC1C3BDC1C4BEC1
C4BEC2C4BEC2C5BEC2C5BFC3C5BFC2C5BFC3C6C0C3C6BFC3C6BFC3C7BFC3C6BFC3C7C0C3
C7C0C3C7C0C3C7C1C3C7C0C3C7C1C3C8C1C4C8C1C4C2B9BD8F8587413F40222122020202
000000000000000000151414373536615D5E8A86879C9697898485969091D4CCCED6CECF
D6CECFD6CDCFD6CDCFD5CDCFD5CDCFD6CDCFD6CDCFD5CDCED6CDCED6CDCED6CDCED6CDCE
D6CDCFD6CECFD6CECFD6CECFD6CECFD6CECFD7CECFD7CECFD7CECFD7CECFD7CFCFD8CFCF
D8CFCFD8CFCFD8CFCFD8D0CFD8D0CFD9D0CFD9D0CFD9D1CFD9D1D0D9D1D0DAD1D0DAD1D0
DAD1D0DAD1D0DAD1D1DAD1D1DAD2D1DBD2D0DCD2D1DBD3D1DCD3D1D7CECD6C6868000000
000000000000000000000000A19B99E1D9D6E2DAD7E2DAD7E1DAD6E1DAD6E2DAD6E2DBD6
E2DBD6E2DAD6E2DAD6E2DAD6E2DAD6E2DAD6E2DAD6E2DBD6E3DBD6E3DBD6E3DBD6E4DBD6
DFD6D2BAB3AFBBB5B0E5DCD7E4DCD6E4DCD6E4DCD6E4DCD6E3DBD5E3DBD5E4DBD5E4DCD5
E5DCD6E4DCD6E4DCD6E4DCD6E4DCD6E4DCD6E4DCD6E4DCD6E5DCD6E5DCD6E5DCD6E5DCD6
E5DCD5E5DCD5E5DCD5E5DCD5E6DDD5E6DDD5E6DED5E6DED5E6DED5E6DED6E6DED6E7DED6
E8DED6E8DED6E8DED6E8DFD6E7DDD5E3D9D1D4CCC5BAB3ACB3ACA687817C2A28272C2B29
C3BBB2E7DED3E7DED3E7DED3E7DDD3E7DED3E7DED3E7DED3E7DED2E7DED2E7DED2E7DED2
E6DED2E7DED2E7DED1E7DED1E7DED1E7DED2D9D1C5C4BDB2BEB6ACB6AFA5A29C92BFB8AD
E7DFD1E7DFD1E7DFD0E7DFD0E7DFD0E7DFCFE7DFCFE7DFCFE5DDCDE5DECDE7DFCFE6DECE
DDD5C5C8C1B378746C1D1C1A0E0E0D11111021201E29272411100F000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000001010112121446454B93909CBBB7C8
BEBACBBEB9CABEBACABEBACABEBACABEBACABEBACABEBACABEBACABEB9C9BDB9C8BDB9C8
BDB9C8BCB9C8BCB9C8BCB9C7BDB9C7BDB9C7BEBAC9C0BCCAC0BCCABEBAC8C0BCCAC3BECC
C5C0CEC5C1CEC1BDCABDB9C7BCB8C6BDB8C6BDB8C5BDB8C5BDB8C5BDB8C6BEB9C6BEB9C6
BEB9C6BEB9C6BEB9C6BEB9C6BCB7C4BAB5C1B9B3C0B8B3BFB8B3BFB7B2BEB7B2BEB7B2BD
B7B2BDB7B2BDB7B2BDB7B2BDB8B2BDB8B2BDB7B1BCB7B1BCB6B0BCB6B1BCB6B1BCB6B1BC
B6B0BBB6B0BBB6B0BBB6B0BBB6B1BBB6B1BBB6B1BBB7B1BBB7B1BAB7B1BAB7B1BAB7B1BA
B7B1BAB7B2BAB7B2BAB7B2BAB7B2BAB7B2BBB8B3BBB8B3BCB8B3BCB8B3BCB8B3BCB9B3BC
B9B4BCB9B4BCB9B4BCB9B4BCB9B4BCB9B4BCBAB5BCBAB5BCBAB5BDBBB5BDBBB5BDBBB6BD
BCB6BDBCB6BDBCB6BDBCB7BDBDB7BDBDB7BDBDB7BDBDB7BDBDB8BEBDB8BEBEB8BEBEB8BE
BEB8BEBEB9BEBFB9BEBFB9BEBFB9BEC0BABFC0BABFC0BABFC0BABFC0BABFC0BABFC1BBC0
C2BBC0C1BBC0C1BCC0C2BCC0C3BDC1C3BDC1C3BDC1C3BDC1C3BDC1C4BEC1C4BEC2C4BEC2
C4BEC2C5BEC2C5BEC3C5BFC3C5BFC3C5BFC3C5BFC3C6BFC3C6BFC3C7BFC3C6BFC3C6C0C3
C6C0C3C6C0C3C6C0C3C7C0C3C7C1C4C8C1C5C8C1C5B8ADB05C4D4D070707040404000000
0000000000000000002E2C2D7B7778BCB5B7D1CACCD5CED0D3CCCED3CCCED5CED0D5CED0
D5CDCFD5CCCFD5CDCFD5CDCFD6CDCFD5CDCFD5CDCED5CDCED5CDCED5CDCED5CDCED6CDCE
D6CDCED6CDCED6CDCED6CECED6CECFD6CECFD7CECFD7CECFD7CECFD7CECFD7CECFD7CFCF
D8CFCFD8CFCFD8CFCFD8D0CFD8D0CFD8D0CFD9D0CFD9D0CFD9D1D0D9D1D0DAD1D1DAD1D1
DAD1D1DAD1D0DAD1D0DAD2D0DBD2D1DBD2D1DBD2D1DBD2D1DCD3D1C1B9B842403F000000
000000000000020202060505BCB6B3E2DAD7E2DAD7E1DAD6E2DBD6E2DBD6E2DAD6E2DBD6
E2DBD6E2DAD6E2DAD6E2DAD6E2DAD6E2DAD6E2DBD6E3DBD6E3DBD6E3DBD6E3DBD7E4DBD7
E4DCD7E4DCD7E4DCD6E4DDD7E4DDD7E5DDD7E4DCD7E4DCD7E4DCD6E4DCD6E4DCD6E4DCD7
E5DCD7E5DCD7E4DCD6E5DCD6E4DCD6E5DCD6E5DCD6E5DCD6E5DCD6E5DCD6E5DCD6E5DDD6
E5DDD6E6DDD6E6DDD6E6DDD6E6DED6E6DED6E6DED6E6DED6E7DED6E7DED6E7DED6E8DED6
E8DED6E8DED6E8DFD7E8DFD7CEC5BE706B67252323050505000000000000000000141312
99938CE6DDD2E7DED3E7DED3E7DED3E7DED3E7DED3E7DED3E7DED3E7DED2E7DED2E7DED2
E6DED2E6DED2E7DED2E6DED1E5DCD0DDD5C9928C842A2926070706060605020202746F68
E7DFD1E7DFD1E7DFD1E7DFD0E7DFD0E4DDCDC8C1B4B5B0A3CDC7B9E6DECEE7DFCFE3DBCB
D3CCBDCDC6B88B867D1E1D1B000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
0101011111125F5E67B3AFC0BEBBCCBEBBCCBEBBCBBDBBCBBDBBCBBDBACABDBACBBDBACA
BDBACABDB9CABDB9CABDBACABDBACABDBACABCB9C9BCB9C9BBB8C8BBB8C8BBB8C7BBB7C7
BBB7C7BBB7C7BBB7C7BBB7C6BBB7C6BBB7C6BCB7C6BCB8C6BCB8C6BCB8C6BEBAC9C1BDCB
C3BECDC0BCCABCB8C6BBB7C5BCB7C5BCB7C5BCB7C5BCB8C6BCB8C6BDB8C6BDB8C6BDB8C6
BDB8C6BDB8C6BDB9C6BDB9C6BEB9C6BEB9C6BEB9C6BBB7C4BAB4C1B9B3C0B9B3C0B9B3C0
B9B3C0B9B3C0B8B3C0B8B3BFB7B3BEB7B3BEB7B3BEB7B3BEB7B2BEB6B2BDB6B2BDB7B2BD
B7B2BDB6B2BDB6B2BDB6B2BDB6B2BDB6B2BDB7B2BDB7B2BCB7B2BCB7B2BCB7B2BCB7B3BC
B7B3BCB7B3BCB7B3BCB7B3BCB7B3BCB8B3BCB8B4BDB9B5BDBAB5BEBAB5BEBAB5BEBAB5BE
BAB5BEBAB5BEBBB6BEBBB6BEBBB6BEBBB6BEBBB6BEBBB6BEBCB7BEBCB7BEBCB7BEBCB7BE
BCB7BEBCB7BDBCB7BDBCB7BDBCB8BDBDB8BEBDB8BEBDB8BFBDB8BFBDB9BFBEB9BFBEB9BF
BFB9C0C0BAC0C1BCC2C2BDC4C2BEC4C0BCC2C1BCC2C1BCC2C1BCC2C1BCC2C1BCC1C1BCC1
C2BDC2C2BDC2C3BDC2C3BDC2C3BEC3C3BEC3C4BEC3C4BFC4C4BFC4C4BFC4C4BFC4C4BFC4
C5BFC4C6BFC4C5BFC4C5C0C4C5C0C4C5C0C4C6C0C4C6C0C4C6C0C4C6C0C4C6C1C4C6C1C4
C7C1C5C7C1C5C7C1C5C0BBBFA6A1A48580835350522F2D2E0B0B0B000000000000191819
3837388F8B8ED0CACDD6D0D3D6D0D3D6CFD2D5CED1D3CDCFD3CCCED3CCCED3CCCED3CBCE
D3CCCED3CCCED3CCCED3CCCED3CCCED3CCCED3CCCED3CCCED3CCCED4CCCED4CCCED4CDCE
D4CDCFD4CDCFD4CDCED4CDCED5CDCED5CDCED5CDCFD6CECFD6CECFD6CECFD6CECFD7CFCF
D7CFCFD8D0D0D8D0D0D8D0D0D8D1D0D8D1D0D8D1D1D8D1D1D8D1D1D9D1D1DAD2D1DAD2D1
DAD2D1DAD2D1DAD2D1DAD2D1DAD3D2DAD3D2DBD3D2B7B0AF514F4E6E6B6AAFAAA8B4AEAD
C2BCBBDED7D5E1DAD8E1DAD8E1DBD8E1DBD8E1DAD7E1DAD7E1DAD7E1DAD7E1DAD7E1DAD7
E1DAD7E1DAD7E1DAD7E1DBD7E2DBD7E2DBD7E2DBD7E2DCD8E3DCD8E3DCD8E3DCD8E4DCD8
E4DDD8E4DDD8E4DDD8E5DDD8E4DDD8E4DDD8E5DDD8E5DDD8E5DDD8E5DDD8E5DDD8E5DED8
E5DED8E1DAD4E4DDD7E4DDD7E4DDD7E4DDD7E4DDD7E5DDD7E5DDD7E5DDD7E5DDD7E5DDD7
E5DED7E5DED7E5DED7E6DED7E6DED7E6DED7E1D9D2C8C1BA5E5B57020201000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000050504242322413E3C403C3A302F2C141312020201000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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0000000000000000000000000000000000000000000000000000000000000A090A1F1E21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00000000000000000000000000000000000000000000000000000000000023232665646D
A5A3B2BCBACBBEBBCDBEBBCDBDBBCCBDBACBBDBBCBBDBBCBBDBBCBBDBACBBDBACBBDBACA
BCBACABCBACABDBACABCB9C9BCB9C9BCB9C9BCB9C9BBB8C8BAB8C7BAB7C7BBB7C7BBB7C7
BBB7C7BBB7C7BAB6C6BAB6C6BAB6C6BBB7C6BDB9C8BEBAC9BEBAC9BEBAC9BEBAC9BEB9C8
BDB8C7BCB7C6BBB6C6BBB7C6BBB7C6BBB7C6BCB7C5BCB7C5BCB7C5BCB8C6BCB8C6BCB8C6
BCB8C6BDB8C6BDB8C6BDB9C6BDB9C7BCB8C5BAB6C2B8B4C1BAB6C3BBB7C4BCB7C4BCB7C4
BBB6C3BAB5C2B9B4C1B8B3C0B8B3C0B8B3C0B7B3BFB7B2BFB7B2BFB7B2BFB7B2BFB7B2BF
B8B3BFB8B3BFB7B3BEB7B3BEB7B3BEB7B3BEB7B3BEB7B3BEB7B3BEB8B3BEB8B3BEB8B4BE
B8B4BDB8B4BDB8B4BDB8B4BDB8B4BEB9B4BEB9B5BEB9B5BEB9B5BEB9B5BEB9B5BEBAB5BE
BAB5BEBAB5BEBAB5BEBAB6BEBAB6BEBBB6BEBBB7BEBBB7BEBBB7BEBBB7BEBBB7BEBCB7BE
BCB7BEBCB8BEBCB8BEBDB9C0BEB9C0BEB9C0BEB9C0BEB9C0BEBAC0BEBABFBEBABFBFBAC0
C0BBC2C1BCC3C1BDC4C1BDC3C1BCC2C1BCC2C1BDC2C2BDC2C2BDC2C2BDC2C2BDC3C2BDC3
C2BDC3C2BEC3C3BEC3C3BEC3C3BEC4C3BFC4C4BFC4C4BFC4C4BFC4C5BFC4C5BFC4C5BFC4
C5C0C5C5C0C5C5C0C5C5C0C5C5C1C5C6C1C5C6C1C5C6C1C5C6C1C5C7C1C6C7C1C6C7C1C6
C7C1C6C7C1C6B4AEB2464243000000000000000000000000333133B8B3B6D4CED2D4CDD1
D4CDD2D5CFD2D5CED1D3CCD0D2CBCFD2CCCFD2CCCFD2CBCED2CBCED2CBCED2CBCED2CBCE
D3CBCFD3CBCFD3CCCFD3CCCFD3CCCFD3CCCFD3CCCFD4CCCFD3CCCED4CCCFD4CDCFD5CDCF
D4CDCFD4CDCFD4CDCFD4CDCFD4CDCFD4CDCFD5CDCFD6CECFD6CECFD6CFD0D6CFD0D7CFD0
D7CFD0D8D0D1D8D1D1D8D1D1D8D1D1D8D1D1D8D1D1D8D1D1D9D2D2DAD2D2DAD2D2DAD2D2
DAD2D2DAD2D2D9D2D2DAD2D2DAD3D2D5CECD6D6968797674C5C0BFD2CDCBDED9D7E0DAD9
DFD9D7D3CECCDFDAD7E1DBD8E0DAD8E1DAD8E1DAD8E1DBD8E1DBD8E1DAD7E1DBD7E1DBD7
E1DBD7E1DBD8E1DBD8E2DBD8E2DBD8E2DCD8E2DCD8E2DCD8E2DCD8E3DCD8E4DDD8E4DDD8
E4DDD8E4DDD9E4DDD9E4DDD9E4DDD9E4DDD8E4DDD8E5DED8E5DED8E5DED8E5DED8D9D3CD
46444200000042403F96918EA19C98BCB5B1DAD2CDE2DAD4E2DBD5E4DCD7E5DDD7E4DCD6
E2DAD4CFC8C25B5855000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000000000000000000000000000000000000000000000000000003D3C429896A4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0000000000000000000000000000000000000000000000000000000202024F4E55AAA8B7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0000000000000000000000000000000000000000000000000000000606066C6C75B8B6C6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00000000000000000000000000000000000000000003030319191A4D4D53A8A7B6C0BECF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00000000000000000000000008080924242740404652535A868693BCBACCC2C1D3BFBECF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00000000000000000010101253535AA3A3B2C0C0D2C2C3D5C4C4D6C4C3D5C0BFD1BFBDCF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0000000000001D1D1F73737EB9BACAC4C4D6C4C5D6C5C4D6C5C3D5C4C2D4C0BED0BFBDCF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7A7B869B9CAAB6B6C6C3C3D5C5C5D6C4C5D7C4C3D5C2C1D3C3C1D3C2C0D2C0BECFBFBDCF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C1C1D4C4C5D7C4C5D7C4C3D5C3C3D5C4C4D5C1C1D3C1C0D2C3C2D4C0BED0C0BECFBFBECF
BEBDCEBEBCCEBDBBCEBEBBCDBDBBCDBCBBCCBCBACCBCBACCBCBACBBBBACBBAB9C9BAB8C9
BAB8C9BAB9C9BAB8C9BAB8C8BAB7C8B9B7C7B9B7C7B9B7C7B9B6C7BAB6C7BAB6C7BAB6C7
BAB6C7BAB6C7BAB6C7BAB6C7BAB6C7BAB6C6BAB6C6BAB6C6BAB6C6BAB6C6BAB6C6BBB6C6
BBB6C6BBB6C6BBB6C6BBB7C6BBB7C6BBB7C6BBB7C6BBB7C6BBB7C6BCB8C6BCB9C7BCB8C7
BCB9C7BCB9C7BCB9C7BCB9C7BDBAC8BDBAC8BDBAC8BDBAC8BEBBC8BEBBC8BEBBC9BDBAC8
BCB8C6BAB6C2B9B5C2B8B5C1B8B5C0B8B5C0B8B5C0B8B5C0B9B5C0B9B5C0B9B5C0B9B5C0
B9B5C0B9B5C0B9B5C0B9B5C0B9B5C0B9B5C0B9B5C0B8B5C0B9B5C0B9B5C0B9B5C0B9B5C0
B9B5C0B9B6C0B9B6C0B9B6C0B9B6C0B9B6C0B9B5BFB9B6BFBAB6C0BAB6C0BAB7BFBAB7C0
BBB8C1BBB8C0BBB8C0BEBAC2BFBAC3BDB9C1BCB8C0BBB8BFBCB8BFBCB8BFBCB8BFBCB8BF
BCB9BFBCB9BFBDBAC1BEBAC1BFBBC2BFBBC2BFBBC2BFBBC3BFBCC3BFBCC3BFBCC3C0BCC3
C0BCC3C0BDC3C1BDC3C1BEC3C1BEC4C1BEC4C2BEC4C3BFC5C2BEC5C2BEC5C3C0C6C4C0C6
C4BFC6C4C0C6C4C0C6C4C0C6C4C0C6C4C0C6C4C0C6C4C0C6C4C1C6C4C1C6C5C1C6C5C1C6
C5C1C6C5C1C6C5C1C6C5C1C6C6C1C7C6C1C7C7C2C7C7C2C7C7C2C7C7C2C7C7C2C7C6C1C5
B6AAADA9A2A7BBB6BBC5C1C5C4C0C4C0BCC0AFABAF6967690404041614169B979AD1CBD0
D2CCD0D0CACED1CBCFD2CCD0D3CDD1D2CDD1D2CCD0D2CCD0D2CCD0D2CCD0D2CCCFD2CCCF
D2CCCFD2CCCFD2CCCFD2CCCFD2CCCFD2CCCFD2CCCFD3CCCFD3CDD0D5CFD1D7D2D4D5CFD2
D3CDD0D3CDD0D3CDD0D3CDCFD4CED0D5CED0D6CFD1D6CFD1D6D0D1D6D0D1D6D0D1D7D0D1
D7D0D1D7D1D1D7D1D1D7D1D1D7D1D1D7D1D2D7D1D2D7D1D2D8D1D2D8D2D2D8D2D2D8D2D2
D9D2D3D9D2D3D9D2D3D8D2D2D8D1D1DFDAD9DFDAD9DFDAD9DFDAD9DFDAD9DFDBD9E0DBD9
E0DBD9E0DBD9E0DBD9E0DBD9E0DBD9E0DBD9E0DBD9E1DBD9E1DBD9D8D3D1CFC9C8E1DBD9
E1DCD9E1DCD9E1DCD9E1DCD9E1DCD9E2DCD9E2DDD9E2DDDAE2DDDADED8D4B0ACA9565452
060606000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
C4C5D7C4C5D7C4C4D6C5C4D6C3C3D5C1C0D2BCBDCABDBCCDBDBBCDC0BECFC0BED0BEBDCF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BDBDCFBEBED0C0C0D2BEBDCFBEBDCFC0C0D1C1C1D1C1C0D2C0C0D2BFBDCFBFBDCFBDBCCE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BFBED0C3C3D5C3C3D5C2C2D4C1C0D3C2C0D3C2C1D4BFBDCFC0BED0BEBDCFBEBCCFBDBBCE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B9BACBB6B5C7B5B4C5B8B7C8BEBDD0C2C1D3C2C1D4C0BFD1C0BED1BEBDCFBEBCCFBDBCCE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BBBCCDBFBFD1BCBBCEBFBED0C2C1D4C2C1D4C2C1D4C1C0D2BFBED0BEBDCFBDBCCEBDBBCE
BDBBCEBDBBCEBDBBCDBCBBCDBCBBCCBCBACCBBBACCBBBACBBBBACBBBBACBBAB9CABAB8C9
B9B8C9B9B8C9BAB8C9B9B7C8B9B7C8B9B7C8B9B7C8B9B7C8B9B6C7B9B6C7B9B6C7BAB7C8
BBB8C9BCB9CABCB9CABCB9C9BBB7C8BAB6C7BAB6C7BAB6C7BAB6C7BAB6C7BAB6C6BAB6C6
BAB6C6BAB7C6BAB7C7BBB7C7BBB8C7BBB8C7BBB8C7BBB8C6BBB8C6BBB8C7BCB9C8BCB9C8
BCB9C8BCB9C7BCB9C7BCB9C7BDBAC8BDBAC8BDBAC8BDBAC8BDBBC9BDBBC9BDBBC9BDBBC9
BDBBC9BDBAC8BDBAC7BCB9C5BBB8C4BAB7C3BAB6C3B9B6C2B9B6C2B9B6C2B9B6C2BAB6C2
BAB6C2BAB6C2BAB6C2BAB6C2BAB6C2BAB7C2BAB7C2BAB7C2BAB7C2BAB7C2BAB7C1BAB6C1
BAB7C1BAB7C1BAB7C1BAB7C1BAB7C1BAB7C1BBB7C1BBB8C0BBB7C0BBB8C0BBB8C0BBB8C0
BBB8C0BBB8C1BBB8C0BCB9C1BCB9C1BCB9C1BCB9C1BDBAC2BDBAC2BDBAC2BEBBC3BEBBC3
BFBBC3BFBBC3BEBBC3BFBBC3BFBBC3BFBBC3BFBCC3BFBCC3BFBCC3BFBCC3C0BDC3C0BDC4
C0BDC4C1BEC4C2BFC5C2BFC6C2BFC6C2BFC6C2BFC6C2BFC5C1BEC5C2BFC5C2BFC5C4BFC6
C4C0C6C4C0C6C3C0C6C4C0C6C4C0C6C4C0C6C4C0C6C4C1C6C4C1C6C4C1C6C4C1C6C4C1C6
C4C1C6C4C1C6C4C1C6C4C1C6C5C1C6C5C2C6C5C2C6C6C2C7C6C2C7C7C3C8CBC7CCD3CFD5
D4D0D5D4D0D5D4D0D5D4D0D4D4D0D4D4D0D4D4CFD4D4D0D4D4D0D4D4CFD4D4CFD4D4CFD4
D3CFD3CCC8CCBBB7BA9C999D6261627C787BC1BDC0CBC6CAD1CBCFBEB9BD989597B6B2B4
D1CDD0D5CFD2D5D0D3D5D0D3D6D0D3D6D0D3D5D0D3D6D0D3D6D1D3D5D0D2D4CED1D4CED1
D4CED1D5CED1D5CFD1D5CFD1D5CFD1D5CFD1D5CFD1D5CFD1D5D0D1D6D0D1D6D0D1D7D1D2
D7D1D2D7D1D2D7D1D2D7D1D2D7D1D2D7D2D2D8D2D2D7D2D2D7D2D2D7D2D2D7D2D2D7D2D2
D8D2D2D8D2D2D9D3D3D9D3D3DCD6D6DFDAD9DFDAD9DFDAD9DFDAD9DFDAD9DFDAD9DFDAD9
DFDAD9DFDAD9DFDAD9DFDAD9E0DAD9E0DAD9E0DAD9DCD7D6CECAC8E1DBD9E1DCD9E1DCD9
E1DCD9E1DCD9E1DCD9E1DCDAE1DCDAE1DDDAC8C3C12D2C2C000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
B8B7C9BEBDD0B9B8C9BEBECFC1C0D3C2C1D4C2C0D3C1C0D2BFBED0BEBDCFBDBCCFBDBBCE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BFBED1BDBCCFBEBECFC1C0D3C2C1D4C2C1D4C1C0D2C0C0D1BFBED0BFBED0BEBDCFBEBCCF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C0C0D2BDBDCFC1C0D3C2C1D4C1C0D3C1C0D3C0C0D2C0BFD1BFBED1BFBED1BFBED0BEBDD0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C0C0D4C1C1D4C1C1D4C2C1D4C1C1D3C0C0D3C0C0D2C0BFD1BFBED1BFBED1BFBED1BFBED1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C1C1D4C0C0D4C0BFD3C0BFD2C1C1D3C0C0D3C0C0D2C0BFD1BFBED1BFBED1BFBED1BFBED0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BEBED1BCBCCFBCBBCDBCBBCDC1C0D3C0C0D2BFBFD2BFBED1BFBED1BFBED1BFBED1BEBED0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BBBBCDB8B8CAB7B6C8B8B7C9C1C0D3C0C0D2BFBFD1BFBED1BFBED1BFBED2BFBED1BEBED0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B9BACCB9B8CBB6B5C8B9B8CAB9B8CBBFBFD1BFBFD1BFBFD1BFBED1BFBED2BFBFD2BFBFD1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BBBBCEBEBDD1B8B7CABEBDCFB9B9CBBFBFD1BEBFD1BFBFD1BFBED1BFBED2BFBFD2BFBFD2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BEBED2C0C1D4BABACCC0BFD2BAB9CCBFBFD1BDBED0BFBFD2BFBFD1BFBFD1BFBED2BFBFD2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C0C0D5BFBFD3BCBBCEBCBBCEB8B8CBBFBFD1BDBED0C0C0D2BFC0D2BFBFD1BFBED1BFBFD2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C1C1D5C0C0D4C0BFD3BBBACDBFBFD2C0C0D3BFC0D3C0C0D2BFC0D2BFBFD2BFBFD1BFBFD2
BFBFD2BEBED1BEBDD0BEBDD0BDBDCFBABACDBABACCB9B9CBB9B9CBB9B8CAB9B8CAB9B8CA
B9B8CAB9B8CAB8B7C9BAB8CABBB9CBBBBACCBEBCCEC0C1D2C2C1D2C2C2D3C3C3D3C0C0D1
BDBCCDBCBBCCBCBACBBCBACBBDBCCDBFBDCEBFBECFBFBDCEBFBDCEBFBDCEBEBDCDBCBACB
BAB9C9BAB9C9BBB9C9BDBBCBBEBDCDBEBDCCBBBAC9BBBAC9BBBAC9BCBAC9BCBBCABDBCCB
BDBCCBBDBBCABDBBCABDBCCBBEBCCBBFBECCBDBCCBBDBBCABDBCCABDBCCABDBCCABEBCCA
BEBCCABEBCCABEBCCABEBCCABEBCCABEBCCABFBCCABEBCCABFBDCABFBDCABFBDCABFBDCA
BFBDCABFBDCABFBDCABFBDCABFBDCAC0BECAC0BECBBFBDC9BEBBC8BEBCC8BFBCC9BFBCC9
BEBBC8BFBDC9C0BDC9BFBDC9BFBCC8BEBCC7BEBBC6BEBBC6BEBCC6BEBCC6BEBCC6BEBCC6
BEBCC6BDBCC5BDBCC5BDBCC5BDBCC5BDBCC5BDBCC5BEBCC5BEBDC5BFBDC5BFBDC5BFBDC5
BFBDC5BFBEC5BFBEC6C0BEC6C0BEC6C0BEC6C0BEC7C1BFC7C1BFC7C1BFC7C1BFC7C1BFC7
C1BFC7C1BFC7C2C0C7C2C0C7C2C0C7C2C0C7C2C0C7C2C0C7C3C0C7C3C0C7C3C0C7C3C0C7
C3C1C7C4C1C7C4C1C7C3C1C7C3C1C7C3C1C7C4C1C7C4C2C7C4C2C7C4C2C7C4C2C7C5C2C7
C5C2C8C6C3C9C5C3C9C5C3C9C5C3C9C6C4C9C7C5CACDCAD0D3D1D7D1CED4D2CFD5CAC8CD
C7C4C9CDCBD0D2CED4D3D0D6D4D2D7D5D1D7D5D1D7D5D2D7D4D1D6D2CFD4D3D0D5D4D1D6
D4D0D6D4D1D6D4D0D5D4D0D4D3CFD4D4D0D4D4D0D4D4D0D4D5D1D6D5D1D6D5D2D6D4D1D4
BEBBBE414041000000000000000000000000605D60CBC8CBD7D3D7D5D1D4D5D1D4D5D1D4
D5D1D4D5D1D4D6D1D4D6D1D4D6D1D3D6D1D3D6D1D3D6D1D3D5D1D2D5D0D2D5D0D2D5D1D2
D6D2D3D6D2D3D6D2D3D6D2D3D6D2D3D6D2D3D6D2D2D6D2D2D7D2D2D7D3D2D7D3D2D7D3D2
D7D3D3D8D4D4DAD6D6DDDADADDDADADDDADADDDADADDDADADDDADADEDADADEDBDADEDBDA
DEDBDADFDBDAD7D4D3D7D3D2DFDBDADFDBDADFDBDAE0DBDAE0DBDBE0DBDBE0DCDBE0DCDB
E0DCDAD9D5D4474645000000000000000000000000000000000000000000000000000000
000000000000000000535250AEACA7BEBDB6DBDAD1E4E3D9E5E4DAB2B1A90F0F0E000000
000000000000000000595854DAD9CFE4E3D8E1DFD6E6E2DDE6E2DDE7E2DDE7E2DDE7E2DD
E7E3DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DCE7E2DCE7E2DBE6E2DB
E7E2DBE7E3DCE7E2DBE7E3DBE7E3DCE8E3DDE8E3DCE8E3DBE8E3DBE8E3DAE8E3DAE8E4DA
E8E4DAE8E4DAE8E4DAE8E4DAE8E4DAE8E4D9E6E3D9E6E3D8E6E4D8E6E4D8E6E4D8E6E4D8
E6E4D8E6E4D7E3E0D4E7E4D8E7E4D8E7E5D8C9C7BC52514C42413EA2A197E7E5D7E7E5D6
E8E5D7E8E5D7E8E5D7E8E6D7E8E6D7B0AEA33A3A362B2B28141413000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
C1C1D5BFBFD3BEBDD0BABACCBFBFD2C0C0D3BFC0D2BFC0D2BFC0D2BFBFD2BFBFD1BFBFD2
BFBFD2BEBED1BEBED0BEBDD0BCBBCEBABACDB9B9CCB9B9CBB9B9CBB9B8CAB8B8CAB9B8CA
BAB9CABAB9CBB8B7C9B9B7C9B8B7C9B9B7C9BAB8CABDBCCDBFBFD0C1C1D3C1C1D2C0C0D2
BFBED0BEBDCEBDBCCDBDBCCDBEBDCEBFBECFBFBECFBEBDCEBFBDCEBFBFCFC0BFCFBDBCCC
BDBCCCBDBCCCBEBECDC0C0CFC0C0CFBEBDCDBBBAC9BCBACABDBBCABEBCCBBDBCCBBEBCCB
BDBBCABDBBCABDBBCABDBCCBBEBCCBBEBDCCBDBCCABDBCCABDBCCABDBCCABEBCCABEBCCA
BEBCCABEBCCABEBCCABEBCCABEBCCABEBCCABEBCCABEBCCABFBDCABFBDCABFBDCABFBDCA
BFBDCABFBDCABFBDCABFBDCABFBDCAC0BDCAC0BECAC0BDCAC0BDCAC0BDCAC0BDCAC0BDCA
C0BDCAC0BECAC1BFCBC0BECABFBDC9BFBDC8BEBDC8BFBDC9C0BDC9C0BDC9BFBDC8BFBCC7
BEBCC6BEBCC6BEBDC6BEBDC6BEBDC6BEBDC6BFBDC6BEBDC6BFBDC6BFBDC6BFBDC6BFBDC5
BFBDC5BFBDC5BFBEC5C0BEC6C0BEC6C0BEC6C0BEC7C1BFC7C1BFC7C1BFC7C1C0C8C2C0C7
C2C0C7C2C0C7C2C0C7C2C0C7C2C0C7C2C0C7C3C0C8C3C0C8C3C0C7C3C0C7C3C0C7C3C1C7
C3C1C7C4C1C7C4C1C7C3C1C7C3C1C7C4C2C8C4C2C8C4C2C8C4C2C8C5C3C8C5C3C8C5C2C8
C5C3C9C5C3C9C6C4C9C6C4C9C6C4C9C7C5CACAC8CDCFCDD2D2D0D6AEACB1C3C1C7CCC9CF
D4D1D7D4D1D7D4D1D7D4D2D7D5D2D8D4D1D6D4D1D6D5D2D7D4D1D6D1CDD2D3D0D4D4D1D6
D4D0D5D4D0D5D4D0D5D4D0D4D3D0D4D4D0D4D4D0D4D4D0D4D5D1D5D5D1D5D5D1D6D6D2D6
D3D0D36563660000000000000000000000004A494ABFBCBFD7D3D7D5D1D4D5D1D4D5D1D4
D5D1D4D5D1D4D5D1D4D5D1D4D6D1D3D6D1D3D6D1D3D6D1D3D5D1D3D5D0D2D5D1D2D6D2D3
D6D2D3D6D2D3D6D2D3D6D2D3D6D2D3D6D2D2D6D2D2D6D2D2D6D2D2D6D2D2D6D2D2D7D3D2
D8D3D3D8D4D5DAD7D8DCD9DADDD9DADDDADADDDADADDDADADDDADADDDADADDDADADEDBDB
DEDBDBDFDBDBD4D0D0CBC8C8DFDBDADFDBDADFDBDADFDBDADFDBDAE0DBDBE0DCDBE0DCDB
E0DCDBD7D3D147464500000000000000000000000000000000000010101054535174726F
888782979691AFAEA8D5D3CBE8E6DEE8E6DDE8E6DCE8E7DDE8E7DDE4E2D8BEBDB570706B
21211F80807BBEBDB4D2D1C7E6E5DAE5E3DBE5E1DBE6E2DDE6E2DDE6E2DDE7E2DDE7E2DD
E7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DCE7E2DBE6E2DBE6E2DB
E6E3DBE6E2DBE6E3DBE6E3DBE7E3DBE7E3DBE8E3DBE8E4DBE8E4DBE8E4DBE8E4DBE8E4DA
E8E4DAE8E4DAE7E4DAE7E4DAE7E4D9E7E4D9E6E3D9E6E3D9E6E4D9E6E4D9E6E4D8E6E4D8
E7E4D8E6E4D7D7D4C9E6E4D7E6E4D7E7E4D8CECCC099978EC8C6BADAD8CBE7E5D7E8E6D7
E5E3D5E8E6D8E8E6D8E8E6D8E8E6D7CFCEC0A1A0959B9A90494843000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
BFC0D4BBBBCFB8B8CBBEBDD0BEBED0C0C0D3BFC0D2C0C0D2BFC0D2BFBFD2BFBFD2BFBFD2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BDBED2B9BACDB8B8CAC1C1D5BEBED1BFC0D3BEC0D2C0C0D3BFC0D3BFBFD2BFBFD2BFBFD2
BFBFD2BEBED1BDBDD0BBBCCEBABACDB9BACCB9B9CCB9B9CBB8B8CBB8B8CAB8B8CAB9B8CB
BABACCB9B9CBB8B7C9B8B7C9B9B7CABAB8CABBB9CBBDBCCEC0BFD0C1C1D2C0C1D2C0C0D2
BFBFD0BEBDCFBEBDCFBFBECFBFBECFBFBECFBEBDCEBEBDCDBDBCCDBEBCCCBDBDCDBCBBCB
BCBCCBC0BFCEC2C2D1BEBDCDC1C0D0BFBECDBDBBCBBEBDCDBFBECEBEBDCCBCBBCBBDBCCB
BDBCCBBCBBCABCBBCABCBBCABCBBCABCBCCABDBCCABDBCCABDBCCABEBCCABEBCCABEBCCA
BEBCCABEBCCABEBCCABEBCCABEBCCABEBCCABEBCCABEBDCABEBDCABEBDCABFBDCABFBDCA
BFBDCABFBDCABFBDCABFBDCABFBDCABFBDCBC0BDCBC0BECBC0BECBC1BECBC1BECBC1BECB
C1BECBC1BFCBC1BFCBC1BFCBC1BFCBC1BFCBC1C0CBC2C0CCC2C0CCC3C0CCC2C0CBC0BEC9
BFBDC8BFBDC7BFBDC7BFBDC7C0BEC7C0BEC8C0BEC8C0BEC7BFBEC7BFBEC7C0BEC7C0BEC7
BFBEC6BFBDC6C0BEC6C0BEC7C0BEC6C0BFC7C1BFC7C1BFC7C1BFC7C1BFC7C1C0C7C1BFC7
C1C0C7C1C0C7C2C0C8C2C0C7C2C0C7C2C0C8C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7C3C0C7
C3C1C7C3C1C7C3C1C7C3C1C7C3C1C8C4C2C9C5C2C9C5C3C9C6C3CAC6C4CAC6C4CAC5C3CA
C5C3C9C6C4CAC7C5CAC8C5CBCBC9CFD0CED4D3D0D7D3D0D7D3D1D7D3D1D7D1CFD5D2D0D6
D3D1D8D0CED5B2B1B6A6A4A8CDCAD0B8B6BBC2C0C5CCCACFD2CFD5D2CFD4D2CFD4D3D0D6
D4D0D6D0CDD2D0CDD1D3D0D4D3CFD4D3D0D4D3D0D4D4D0D4D4D1D5D4D1D5D5D1D6D5D1D6
D4D1D57A787A0000000000000000000000000B0B0B282728969496D5D1D4D5D1D4D5D1D4
D5D1D4D6D1D4D6D1D4D6D2D4D5D1D3D5D1D3D5D1D3D5D1D3D5D1D3D5D1D3D5D1D3D5D2D3
D6D2D3D6D2D3D6D2D3D6D2D3D6D2D3D6D2D3D6D3D3D6D3D3D6D3D3D6D3D3D6D3D3D7D3D4
D9D6D7DCD9DADCD9DADDD9DADDDADADDDADADDDADADDDADADDDADADDDADADDDADADDDADA
DEDADADEDBDBD7D4D3D6D3D2DFDBDADFDBDADFDBDADFDBDADFDBDAE0DCDBE0DCDBE0DCDB
C9C5C47574721A1A1A000000000000000000000000040403504F4D9E9C97E1DFD8E8E6DF
E8E7DEE8E7DEE7E7DDE7E6DDE8E6DDE7E6DCE7E6DCE8E6DCE8E6DCE8E6DCE8E7DCE3E2D8
C0BFB6E1E0D6E8E7DCE7E7DCE7E5DCE6E3DDE6E2DEE6E2DDE7E2DDE7E3DDE7E2DDE6E2DD
E7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DDE7E2DCE6E2DBE6E2DB
E6E3DBE6E3DBE6E3DBE6E3DBE6E3DBE6E3DAE7E3DBE7E3DBE7E4DBE7E4DBE7E4DBE7E4DA
E7E4DAE7E4DAE7E4DAE6E4D9E6E4D9E7E4D9E7E4D9E6E4D9E6E4D9E6E4D9E6E4D9E6E4D9
E6E4D8E6E4D8E7E5D8E7E5D8E7E5D9E7E5D9D5D3C7D2D0C3E6E4D6E7E5D6E7E5D6E7E5D7
E5E3D5E7E5D7E7E5D7E7E5D7E8E6D7D4D2C5B3B2A68E8C84353531000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
BEBFD3BBBCCFBBBBCEC1C1D5BFBFD2C0C0D4BFC0D3C0C0D3BFC0D3BFBFD2BFBFD2BFBFD2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C0C1D5C0C0D4C0C0D4C1C1D5C0C1D4C0C1D4BFC0D3BFC0D3BFC0D3BFBFD2BFBFD2BEBFD2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C1C2D6C1C2D7C1C2D6C1C1D5C1C1D5C0C1D5C0C1D4BFC0D3BFC0D3BFC0D3BFBFD2BEBED1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C1C2D6C1C2D7C1C1D6C0C1D5C0C1D5C0C1D5C0C1D4C0C0D3BFC0D3C0C0D3BEC0D2BDBED0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C1C2D6C1C2D7C1C2D6C0C1D5C0C1D5C0C1D5C0C1D4C0C1D3BFC0D3BFC0D3BEBFD2BCBDD0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C1C2D6C1C2D7C1C2D7C0C2D6C0C1D5C0C1D5C0C1D5C0C1D4C0C1D4C0C1D3C0C0D2BDBED1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C1C2D7C1C2D7C1C2D7C1C3D7C1C3D7C1C2D6C0C1D5C0C1D4C0C1D4C0C1D3BFC0D3BEC0D2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C1C3D7C0C2D7C1C2D7C1C2D6C1C3D6C1C2D6C0C1D5C0C1D5C0C1D4C0C1D4C0C0D3BFC0D3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C1C3D8C1C3D8C1C2D7C0C2D6C0C1D5C0C1D5BFC1D5C0C1D5C0C2D5C0C2D5C0C1D4C0C1D4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C1C3D8C1C3D7C0C2D6C0C1D5C0C1D5C0C1D5BFC1D4BFC1D5C0C2D5C1C3D7C1C3D7C0C1D5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C1C2D8C2C3D8C1C3D7C0C2D6C0C2D6C0C1D5BFC1D5BFC1D5C1C3D6C1C3D7C1C3D7BEC0D4
BDBED2BABCD0BABBCFB9BACEB8BACDB9BACCB8B9CCB8B9CCBABBCEBBBCCFBCBDCFBABBCD
BCBDCFBEBFD0BDBED0BBBCCFBDBFD2BDBFD1BDBED0BFBFD1BFC0D1BFC0D2BDBECFC0C2D2
C1C3D4BFC0D1C0C1D3C1C2D4C3C5D6C2C5D6BBBCCCC6C8D9C6C8D9C4C5D6C3C5D6C1C2D4
B1B1C0B3B4C3BBBCCCBBBBCCBBBBCCBBBBCCBBBBCCBBBBCBBBBBCBBBBCCCBCBBCBBCBBCB
BBBBCABABAC9BAB9C8BAB9C8BAB9C8BAB9C8BABAC8BBBAC8BABAC8BABAC8BBBAC8BCBBC9
BCBCCABDBDCBBEBDCCBEBDCCBEBDCCBEBDCCBEBDCCBEBDCCBEBDCCBEBDCCBEBDCBBEBECB
BEBECCBFBECCBFBECDC0BFCDC0BFCDC0BFCDC0BFCDC0BFCDC0BFCCC0BFCCC0C0CDC0C0CD
C0C0CDC0C0CDC0C0CDC0C0CDC1C0CDC1C0CDC2C0CDC2C1CDC3C1CEC3C2CEC3C2CEC3C2CE
C3C2CEC3C2CEC4C3CFC5C4D0C6C5D0C6C5D0C6C4D0C6C5D0C7C5D1C7C6D1C8C6D1C8C7D2
C8C7D2C8C7D2CAC9D4CFCFD9D0D0DAD0CFD9CFCFD9CFCFD9CFCFD9CFCFD9CFCFD8CFCFD9
CFD0D9D0D0D9D0D0D9D0D0D9D0D0D9D0D0D9D0CFD9D0D0D9D1D0D9D1D0D9D1D0D9D1D0D8
D1D0D8D1D0D8D1D0D8D1D0D8D1D0D8D1D0D8D1D1D8D1D0D9D1D0D8D1D0D8D1D0D8D1D0D8
D1D0D9D2D0D9D2D0D8D3D1D8D2D0D8D2D1D8D1CFD7C5C4CBC0BEC5CDCBD2D2D0D7D1D0D7
D1D0D6D0CFD6D1CFD6D2D0D7D2D0D6CCCAD0BDBBC1B7B6BBC0BEC3A9A7AC7E7D81646266
5E5D604544464645485D5C5F747275AFADB2CFCCD2D0CED3C7C4C9C3C0C6C8C6CBD3D1D7
D4D2D7D4D2D7B7B5BA454445000000000000000000000000050505161616848386D7D6DA
D9D8DBD8D6DAD7D5D9D7D5D9D7D5D8D7D5D8D7D5D8D7D4D7D7D5D8D7D5D8D8D5D8D9D7D9
DAD8DADBD9DCDBD9DCDCDADCDCDADCDDDBDDDDDCDEDDDCDEDEDCDEDEDDDEDEDDDEDEDDDE
DDDCDDDCDBDCDBD9DADBD9DADBD9DADBD9DADBD9DADBD9DADCDADADDDADBDDDBDBDDDBDB
DDDBDBDDDBDBDDDBDBDDDBDBDDDBDBDEDBDBDEDBDBDFDCDCDFDCDCDFDCDCCECBCB424141
1010100A07072A2C25C6CABBE6E6DFE6E7DFE6E7DFE6E7DFE6E7DEE6E7DEE6E6DEE6E6DF
E6E6DEE6E7DEE6E7DEE6E7DEE6E7DEE6E7DEE6E7DEE7E7DEE7E7DEE8E7DEE8E8DEE8E8DE
E8E8DEE8E8DEE8E7DEE6E3DFE6E3DFE6E3DFE6E3DFE6E3DFE6E3DFE6E4DFE7E6DEE8E9DD
E8E8DDE8E8DDE8E9DDE8E9DDE8E9DDE8E9DDE8E9DDE8E9DDE9E9DDE9E9DDE9E9DDE9E9DC
E8E8DBE2E1D7E7E5DDE8E5DEE8E5DEE8E5DEE8E5DEE8E5DDE8E5DEE8E6DEE8E6DEE9E8DD
E6E6DAE6E5DBE6E5DBE7E5DBE7E6DBE7E6DBE7E6DBE7E6DBE7E6DBE7E6DBE7E6DBE7E6DB
E7E6DAE7E6DAE7E6DAE7E6D9E7E6D9E7E7D9E7E7D9E7E7D9E7E7D9E7E7D9E7E7D9E7E7D9
E7E7D9E7E8D9E7E8D99C9C9122221F000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
C1C2D7C1C3D8C2C3D8C2C4D8C1C3D8C1C3D7C1C3D7C1C4D7C2C4D8C1C3D7C0C1D5BDBED2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C1C2D8C1C3D8C2C4D9C2C5D9C2C4D9C2C4D8C2C4D8C2C4D8C2C4D8C1C3D7BFC0D5BBBDD0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C1C3D9C2C4D9C2C4D9C2C5D9C2C5D9C2C5D9C2C4D9C2C4D8C2C4D8C2C4D8BFC1D5BABCD0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C2C5DAC2C5DAC2C5D9C2C5D9C2C5D9C2C5D9C2C4D9C2C4D8C2C4D8C2C4D8BFC1D5BABCD0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C2C6DAC3C6DAC3C6DAC2C5DAC2C5DAC2C5DAC2C5DAC2C5D9C2C4D9C2C4D9BFC1D5BBBDD0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C2C6DAC3C6DAC3C6DAC3C6DAC2C5DAC2C5DAC2C5DAC2C5DAC2C5D9C1C3D8BEC0D5BBBDD2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C3C6DBC2C5DAC3C5DAC3C6DAC2C6DAC2C5DAC2C5DAC2C5DAC2C5D9C0C3D7BEC0D3BBBDD0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C2C5DAC2C4DAC2C4DAC2C5DAC3C6DAC3C7DAC3C7DAC3C6DAC2C5DABFC2D7BCBED2BABCCF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C2C5DBC1C3D9C1C3D9C2C5DAC3C6DBC3C6DBC3C7DAC3C7DAC3C6DAC0C4D8BEC1D6BDBFD4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C2C6DBC1C5DBC2C5DBC2C6DBC3C7DBC3C6DBC3C6DBC3C7DBC3C7DBC2C5DAC1C4D8C1C3D7
C2C4D8C3C6DAC1C5D9C2C5D9C3C6DAC2C5D8C1C3D7C0C2D6C1C3D7C1C4D7C2C4D8C0C1D5
BDBFD2BDBED2BDBFD2BEBFD2BDBFD2BDBFD2BEBFD2BEC0D2BEC0D2BFC0D3BFC1D3C0C1D3
C0C1D3BFC0D1BDBED0BCBDCFBCBDCFBCBDCFBCBDCFBCBDCFBCBDCEBBBCCEBBBCCDBABBCC
B9BACBB8B9CAB8B8C9B7B8C8B7B7C7B7B7C7B6B7C6B6B6C6B6B6C6B6B6C6B6B6C6B6B6C6
B6B6C6B7B7C5B7B7C5B7B7C5B7B7C6B7B7C6B7B8C6B8B8C7B8B8C7B9B9C8B9B9C8B9B9C8
B9B9C8B9B9C8B9BAC8B9BAC8BABBC9BBBCCABBBBCABBBBCABCBCCABCBCCBBCBDCBBDBDCB
BEBECDBFBFCEBFBFCEBFC0CEBFC0CEBFC0CEBFC0CEBFC0CEBFC0CEBFC0CEC0C0CEC0C0CE
C1C1CFC1C1CEC1C1CEC2C1CFC2C2CFC2C2CFC2C2CFC4C3D1C5C5D2C4C4D1C4C4D1C5C5D1
C5C5D1C5C5D1C6C6D2C7C7D3C7C7D3C7C7D3C7C7D3C7C7D3C7C7D3C8C7D3C8C8D4C9C9D5
CBCCD8CED0DBCFD1DCCFD1DCCFD1DCCFD0DBD0D0DBCFD0DBCFD0DBCFD0DACFD0DACFD0DA
CFD0DACFD0DAD0D0DAD0D0DACFD0DACFD0DAD0D0DAD0D0DAD0D1DAD0D1DAD0D1DAD0D1DA
D0D1DAD0D1DAD0D1DAD0D1DAD0D1DAD1D1DBD1D1DBD0D1D9D1D1DAD0D0D8D0D0D9D1D0D9
D1D0D9D0D0D8D0D0D8D0D0D8D0D0D8D1D0D8D1D0D8D1D0D7D0D0D7D1D0D7D1D0D7D1D0D8
D1D0D8D2D1D9D2D2D9D2D2D9D2D1D9D1D1D8D1D1D8D2D1D8D1D1D8D2D2D8D3D4DAD6D6DC
D7D8DFD7D7DED5D5DCD1D2D8D1D2D8B9BABFBCBCC2C5C5CBD8D9DED8D9DED8D9DED8D9DE
D9D9DED9D9DED7D7DCB0B0B4000000000000000000000000000000000000000000000000
0F0F0F43434560606169696BA09FA2BCBBBFD4D4D7D9D9DDDBDADEDAD9DDD9D8DCD9D8DC
D9D8DCD9D8DCD9D8DCD9D8DCD9D8DBD9D8DBD9D8DBD9D8DBD9D8DBD9D8DBD9D8DAD9D8DA
DBDADCDBDBDDDBDADCDAD9DBDAD9DBDAD9DBDAD9DADAD9DADBDADADCDADBDCDBDCDCDBDC
DCDBDCDCDBDCDCDBDCDDDCDCDDDCDCDDDCDCDDDCDCDDDCDCDDDCDCD7D6D5D2D2CFE1E3DE
E5E7E0E5E7E0E5E6E0E5E6E0E5E6E0E5E6E0E5E6E0E5E7DFE5E7DFE5E7DFE5E7DFE5E7E0
E6E7E0E6E7E0E6E8DFE6E8E0E7E8E0E7E8E0E7E8E0E7E9E0E7E9E0E7E9E0E8E9E0E7E9E0
E8E9E0E8E9E0E8E9E0E8E9E0E9E9E0E8E9E0E5E6DCE8E9DFE8EAE0E8E9DFE8E8DFE8E9DF
E8E9DFE8E9DFE8E9DEE9E9DEE9E9DEE9E9DEE9E9DEE9EADEE9EADEE9EADEEAEADEEAEADE
EAEBDEEAEBDEEAEBDFD1D1C76D6D68080807000000000000000000000000000000000000
00000029292790908A81817C1A1A19000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
C3C7DCC3C6DCC3C6DCC3C7DCC3C7DCC3C7DBC3C7DBC3C7DBC3C7DBC3C7DBC3C7DBC3C7DB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C3C7DCC3C7DCC3C7DCC3C7DCC3C7DCC3C7DCC2C7DBC2C7DBC3C7DBC3C7DBC3C7DBC3C7DB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C3C7DCC3C7DCC3C7DCC3C7DCC3C7DCC3C7DCC3C7DCC3C7DCC3C7DCC3C7DCC3C7DBC3C7DB
C3C7DBC3C7DBC3C7DBC3C7DAC3C6DAC3C6DAC3C6DAC0C3D7BDBFD3BCBED1BCBED1BCBED1
BEBFD3BFC2D5BDBFD2BBBDD1BABCCFBABCCFBBBDCFBBBDD0BDBED1BDBFD2BEC0D2BFC1D3
BFC1D3BFC1D3BEC0D2BFC0D2BFC0D2BFC0D2BCBED0BABBCDB8B9CBB8B8CAB7B8C9B7B8C9
B7B8C8B7B7C8B7B7C7B6B7C7B6B6C6B6B6C6B6B6C6B6B6C6B6B6C6B6B6C6B6B7C6B6B7C6
B6B7C6B6B7C6B7B7C6B7B7C6B7B7C6B7B7C6B7B7C6B7B8C6B8B8C7B8B9C7B8B9C8B9B9C8
B9B9C8B9B9C8B9BAC8B9BAC9B9BAC9B9BBC9BABBC9BBBCCABCBDCCBCBDCCBDBECCBEBFCD
BFC0CEBFC0CEBFC0CEBFC0CEC0C0CEC0C0CEC0C0CEC0C0CEC0C0CEC0C0CEC0C0CEC0C0CE
C1C1CFC1C2CFC1C2CFC2C2CFC3C3D1C3C4D1C3C3D1C4C4D1C5C5D2C5C5D2C5C5D2C5C6D2
C6C6D3C6C7D3C7C7D3C7C7D3C7C7D3C7C7D3C7C7D3C7C7D4C8C8D4C9CBD6CDCEDACFD1DD
CFD2DDCFD2DDCFD2DDCFD1DDCFD1DDCFD1DCCFD0DCD0D1DCD0D1DCCFD0DBCFD0DBCFD0DB
CFD0DACECFDACECFDACECFDACFD0DACFD1DBD0D1DBD0D1DBD0D1DBD0D1DAD0D1DAD1D1DA
D1D1DAD1D1DBD1D1DBD1D2DBD1D2DBD0D1DAD0D1DAD0D0D9D1D1DAD0D1DAD1D2DAD1D2DA
D1D2DAD1D2DACFD0D8D0D0D9D1D1D9D0D0D8D0D0D8D0D0D8D0D0D8D0CFD7D0CFD7D1D0D8
D1D1D9D1D1D8D1D1D8CFCFD6BFBFC5D7D9DFD8DAE0D7D9DFD4D4DBD2D2D9D3D3DAD6D6DD
D7D8DFD7D8DED7D8DED5D5DBD3D2D7D4D4D9D6D7DDD7D8DED7D8DED7D8DED7D8DED8D8DE
D8D9DED8D9DED8D9DED8D9DED8D9DED8D9DDD8D8DDD9D8DDD9D9DDD9D9DDD9D9DDD9D9DD
D9D9DDD9D9DED9D9DDD4D4D8ACACAF4343443C3D3D969799CCCDD0DADADED9DADDDAD9DC
D9D8DCD9D9DCD9D9DCD9D8DCD9D8DBD9D8DCD9D8DBD9D8DBD9D8DBD9D8DBD9D9DBD9D9DB
DAD9DBDADADBDADADBDADADBDADADBDADADBDADADBDADADBDBDBDCDCDBDCDCDBDDDCDBDC
DCDBDCDCDCDCDCDCDCDCDCDCDCDCDCDDDCDCDDDCDCDDDCDCDDDCDCDFDEDDE4E7E0E5E6E0
E5E6E0E4E6E0E4E6E0E4E6E0E4E6E0E4E7E0E4E7E0E5E7E0E5E7E0E4E6DFE2E4DDE5E7E0
E6E7E0E6E8E0E6E8E0E7E8E0E6E8E0E6E8E0E7E9E0E7E9E0E7E9E0E7E9E1E8E9E1E7E9E0
E7E9E0E8EAE1E8EAE1E8EAE0E8EAE0CDCEC62222212E2E2DBEC0B7E7E9DFE8E9DFE8EADF
E8EADFE8EADFE8EADFE9EADFE9EADFE9EADFE9EADFE9EADFE9EADFEAEBDFE5E6DB70716C
030303000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
C2C7DDC3C8DDC3C8DDC3C7DCC3C7DCC3C8DCC3C8DDC3C7DCC2C7DCC3C7DBC3C7DBC3C7DB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C2C6DCC3C8DDC3C8DDC3C8DDC3C7DCC3C7DCC3C7DCC3C8DCC3C7DCC3C7DCC3C7DCC3C7DC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C1C5DBC2C7DCC3C8DDC3C8DDC3C8DDC3C7DCC3C8DCC3C8DCC3C8DCC3C7DCC3C7DCC3C7DC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C0C4DAC2C7DCC3C8DDC3C8DDC3C8DDC3C8DDC3C8DDC4C8DDC4C8DDC3C8DDC3C8DDC3C8DD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C1C6DBC2C7DCC3C8DDC3C8DDC3C8DDC3C8DDC3C8DDC3C8DDC3C8DDC3C8DDC3C8DDC3C8DD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C3C8DDC3C8DDC3C9DDC3C9DDC3C8DDC3C8DEC3C9DEC3C9DEC3C9DEC3C9DEC4C8DDC4C8DD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C3C9DEC3C9DEC3C9DEC4C9DEC3C8DEC3C8DDC3C8DEC3C8DEC3C8DDC3C8DDC3C8DDC4C8DD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C3C9DEC4C9DEC4C9DEC4C9DEC4C9DEC4C9DEC4C9DEC4C9DDC3C8DDC3C8DDC3C8DDC3C8DD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B9BED2C3C9DEC3C9DEC4C9DEC4C9DEC4C9DEC4C9DEC4C9DEC4C9DEC3C9DDC3C9DDC3C9DD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818694C3C9DEC3C9DEC3C9DEC4C9DEC4C9DEC4C9DEC4C9DEC4CADEC4C9DEC4C9DEC4CADE
C4CADEC4CADEC4CADEC4CADDC4CADDC4CADDC4C9DDC4C9DDC4C9DDC4C9DDC5C9DDC5C9DD
C5C9DDC5C9DDC5C9DDC5C9DDC5C9DDC5CADDC5CADDC5CADDC3C8DBC0C4D7BEC1D4BCBFD1
B9BBCEB7BACCB6B9CBB6B8CAB6B8CAB5B7C9B5B7C9B5B7C9B5B7C9B5B7C8B5B7C7B5B7C7
B5B7C7B5B7C7B5B7C7B6B7C7B6B7C7B6B7C7B6B7C7B6B7C7B6B7C7B6B8C7B6B8C7B6B8C7
B6B8C7B6B8C7B6B8C7B6B8C7B7B8C7B7B8C7B7B9C7B7B9C7B7B9C8B7B9C8B7B9C8B7B9C8
B8B9C8B8BAC8B8BAC8B9BAC8B9BAC8B9BBC9B9BBC9B9BBCAB9BCCAB9BCC9B9BCC9B9BCC9
BABCCABBBDCABDBFCDC0C1D0C0C2D1C0C2D1C1C2D1C2C3D2C2C3D2C2C3D2C3C4D2C5C6D4
C5C7D5C5C7D5C5C7D5C5C7D5C5C7D4C5C7D5C5C7D5C5C7D5C6C7D5C6C7D4C6C7D4C6C7D5
C7C8D6C7C9D6C7C9D6C7C8D5C7C9D6C6C7D4C5C6D4C5C6D3C5C6D2C5C6D2C5C6D2C5C6D2
C6C7D4CED1DDD6DAE7D6DAE6D6DAE6D6DAE6D6DAE6D6DAE6D5DAE6D5DAE5D5DAE5D5DAE5
D5D9E3D3D5E0D0D2DDCFD1DCCED0DBCFD0DBCFD1DBCED0DBCED0DACFD0DBD0D2DCCFD2DB
D0D1DCCFD1DCD0D1DCD0D1DCD0D1DCD0D1DBD0D1DCD1D2DBD0D2DBD0D1DACFD0D9CFD0D9
CFD0D9D0D1DAD0D1DAD0D1DAD0D1DAD0D0D9CFD0D9CFD0D9D0D0D9D1D2DACFD2D9D3D5DD
D6D8E0D6D8E0D6D7DFD6D8E0D7D9E1D7D8E0D6D9E0D6D8E0D6D8E0D6D8DFD6D8DFD6D8DF
D6D8DFD6D8DFD6D8DFD6D8DFD6D8DFD7D8DFD7D8DFD7D9DFD7D9DFD7D8DFD7D9DFD8D9DF
D8D9DFD8D9DFD7D8DED8D9DED8D9DFD8D9DED8D9DED8D9DED8D9DED9D9DED8DADFD9DADF
D9DADFDADBDFDADADFD9DADED9DADED8D9DED8D9DDD8D9DDD8D9DDD9D9DDD9DADEDADADE
DADBDFDADBDFCACBCE707173717173DCDDE1DCDDE1DCDDE0DCDDE0DCDCDFDBDCDFDBDBDE
DBDBDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDDDBDBDDDBDBDDDBDCDDDBDCDDDCDCDD
DCDCDCDCDCDCDCDCDCDCDCDCDCDCDDDCDDDDDCDDDDDCDDDDDCDDDDDDDDDDE1E2E2E3E4E2
E3E6E1E4E7E1E4E7E1E4E7E1E4E7E1E4E7E1E4E7E1E4E7E1E4E7E1E4E7E1E4E7E1E4E8E1
E5E8E1E3E6DFA4A6A1030303000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
323439797D8AC3C9DFC3C9DFC3C9DFC3C9DEC3C9DEC4C9DEC4CADEC4C9DEC4C9DDC4C9DD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15151833343AC3C9DFC3C9DFC3C9DFC3C9DFC4C9DEC4C9DFC4CADFC4CADFC4CADEC4CADE
C4CADEC4CADEC4CADEC4CADEC4CADDC3C9DDC3C8DDC3C8DDC3C9DDC4C9DDC4CADEC5CBDE
C5CBDEC3C9DCC2C7DAC2C7DAC4C8DBC3C8DBC2C7DAC3C8DBB5B9CBB5B7CAB4B7C9B0B3C5
B3B6C8B6B8CAB6B8CAB6B8CAB5B8CAB5B8C9B5B8C9B5B7C8B5B7C8B5B7C8B5B7C7B5B7C7
B5B7C7B5B7C7B5B7C7B5B7C7B5B7C7B5B7C7B5B7C7B6B7C7B6B7C7B6B8C7B6B8C7B6B8C7
B6B8C7B6B8C7B6B8C7B6B8C7B6B8C7B6B8C7B7B9C7B7B9C7B7B9C8B7BAC8B8BAC8B8BAC8
B8BAC8B8BAC8B8BAC8B9BAC8B9BBC8B8BBC9B8BBCAB8BBC9B8BBC9B9BCC9B9BCC9BABCC9
BABCC9BBBDCABDBFCDC0C1D0C0C2D1C1C2D1C2C4D3C2C4D3C2C4D3C3C5D3C5C7D5C5C7D5
C5C7D5C5C7D5C5C7D5C5C7D5C5C7D5C5C7D5C6C8D6C6C8D6C6C8D6C6C8D5C6C7D5C5C7D4
C5C6D3C5C6D3C6C7D3C6C7D3C6C7D3C6C7D4C6C7D4C5C6D3C5C6D3C5C6D3C5C6D2C5C6D2
C6C7D3CCCFDBD1D5E1CBD0DBC6CBD6CCD0DCD2D6E2CDD1DCCFD3DED4D9E4C5CAD4C7CCD6
D5D9E4CCD0DAC3C6D0C9CDD7CED1DBCFD0DBCFD0DBCED0DBCED0DACFD1DBCFD2DCCFD1DB
CFD1DBCFD2DBD0D2DCD1D3DDD1D3DDD1D2DCD1D2DCD0D2DCCECFD9CFD0D9D0D2DBCFD1DB
D0D1DBD0D2DBCFD1DACFD1DAD0D1DACFD0D9CFD0D9CFD0D9CFD0D9D0D1D9D0D1D9D0D1DA
D3D5DED6D9E1D6D9E1D6D8E1D6D9E0D6D8E0D6D8E0D6D8E0D6D8E0D6D8E0D6D8E0D6D9E0
D6D9E0D7D9E0D7D9E0D6D9E0D7D9DFD7D9DFD7D8DFD7D8DFD7D9DFD7D9DFD7D9DFD7D9DF
D7D8DFD8D9DFD8D9DFD8D9DFD8D9DFD7D8DED7D8DED8D9DFD8DAE0D8D9DED8D8DED8D9DE
D8D9DED9D9DED9DADFD8D9DED7D8DDD8D9DED8D9DDD8D9DDD8D9DDD8D9DDD8D9DDD8D9DD
DADADFDADBDFDADBDFD7D8DCA1A2A5444446CFD1D3DCDDE0DCDDE1DCDCE0DCDCE0DBDCDF
DBDBDEDBDBDEDBDBDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDDDBDCDDDBDCDDDBDCDD
DBDCDDDBDCDDDBDCDDDBDCDDDCDCDDDCDDDDDCDDDDDCDDDDDCDDDDDDDEDEE1E2E3E0E1E2
E2E3E3E2E3E3E3E3E3E3E5E2E4E7E1E4E7E1E4E7E1E4E8E1E4E8E1E4E7E1E5E7E2DFE2DC
7C7E79000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000A3A9BAB4BACEBDC3D8C3C9DEC3C9DFC3C9DFC3C9DFC3C9DFC3CADFC4CADF
C4CADFC4CADEC4CADEC4CADEC4CADEC4CADEC4C9DEC4C9DEC4C9DEC4CADFC4CBDFC4CBDF
C5CBDFC5CBDFC5CBDFC5CADEC4CADDC2C7DAACB0C2ADB1C38184918D909D9D9FB0A8ABBC
B4B6C8B6B8CAB5B8CAB5B7C9B5B7C9B5B7C9B5B7C9B5B7C8B5B7C8B5B7C8B5B7C8B5B7C8
B5B7C8B5B7C7B5B7C7B5B7C7B5B7C7B6B7C7B6B8C7B6B8C7B6B8C7B6B8C7B6B8C7B6B8C7
B6B8C7B6B8C7B6B8C7B6B9C7B6B9C7B7B9C8B7B9C8B7B9C8B7B9C8B7B9C8B7BAC8B7BAC8
B7BAC8B8BAC8B8BAC8B9BBC9B9BBC9B9BBC9B8BBCAB8BBCAB9BCC9B9BCC9BABCC9BABCC9
BABDCABBBDCABDC0CDC0C1D0C1C3D2C3C5D4C4C6D4C3C5D4C4C5D4C4C6D4C5C7D5C5C7D5
C5C7D5C5C7D5C5C7D5C5C7D5C5C7D5C5C8D5C6C8D6C6C8D6C6C8D6C6C7D5C6C7D5C5C6D4
C4C6D3C5C6D3C6C7D3C6C7D3C6C7D3C6C7D4C6C7D4C5C6D3C5C6D3C5C6D3C5C6D3C5C6D3
C6C7D3CACCD9D1D5E1D3D7E3D4D9E5D5D9E5D5D9E5D5D9E4D5D9E5D5D9E4D4D9E4D5D9E4
D5D9E4D4D9E4D5D8E3D1D5DFCFD1DCCED0DBCED0DBCFD0DBCFD0DBCFD0DBCFD1DBCFD2DC
CFD2DCD0D2DCD0D2DCD1D3DDD1D3DDD1D3DDD1D3DDD0D1DBCDCED7CFD1DACED1DAC7C9D2
C7C8D1C8CAD3CDCFD8D0D2DBD0D1DACFD0D9CFD0D9CFD0D9CFD0D9D0D1DAD0D1D9D1D1DA
D4D5DDD6D9E1D6D8E1D6D9E0D6D8E0D6D8E0D5D8E0D6D8E0D6D8E0D6D8E0D6D8E0D6D8E0
D6D9E0D6D9E0D6D9E0D6D8DFD6D9DFD6D9DFD7D9DFD7D9DFD7D9E0D7D9DFD7D9DFD7D9DF
D7D9DFD8D9DFD8D9DFD8D9DFD8D9DFD7D9DED7D9DFD8DADFD8D9DFD7D8DDD8D9DED8DADF
D9DADFD9DADFD9DADFD8D9DED8D9DED8D9DED8D9DDD8D9DDD8D9DDD8D9DDD8D9DDD9D9DE
DADADEDADADFDADBDFDBDCE0C1C2C6404041B5B6B8DCDDE0DCDDE0DCDCE0DCDCE0DBDCDF
DBDCDFDBDCDFDBDCDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDDDBDCDDDBDCDD
DBDCDEDCDCDDDCDDDDDCDDDDDCDDDDDCDDDDDCDDDDDCDDDDDCDDDEDEDFDFE2E3E4E2E3E4
E2E3E4E2E3E4E2E3E4E3E4E3E3E5E2E4E6E1E4E7E1E4E7E1E4E8E1E4E8E2E5E8E2ACAEA9
1A1A1A000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000053555F6C707C797D8AB5BBCFC3CADFC3CADFC3CADFC3CADFC3CADFC4CADF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020202000000000000000000000000777B889FA4B59FA4B5C3CADFC3CADFC3CADFC3CADF
C3C9DEC3C9DEC3C9DEC4CADFC4CBDFC4CBDFC4CBDFC4CBDFC4CBDFC4CADFC3CADEC3CADE
C4CBDEC4CBDFC4CBDEC1C7DBB8BED0AEB4C5AEB2C4A8ABBDA9ABBDAFB2C4B5B7CAB7B9CB
B6B8CBB6B8CAB5B8CAB5B8CAB5B8CAB5B8CAB5B8C9B5B7C8B5B7C8B5B7C8B5B7C7B5B7C7
B5B7C7B5B7C7B5B7C7B5B7C7B5B7C7B5B7C7B5B7C7B5B8C7B5B8C7B6B8C7B6B8C7B6B8C7
B6B8C7B6B8C7B6B8C7B6B8C7B6B9C8B7B9C8B7BAC9B7BAC9B7BAC9B7BAC8B7BAC8B7BAC8
B8BAC8B8BAC8B8BBC9B9BBC9B9BBC9B8BBC9B8BCCAB9BCCAB9BCCAB9BCCABABDCABBBECA
BBBECCBCBECDBEC0CFC1C3D2C3C5D5C4C6D5C3C6D5C4C6D4C4C7D5C4C7D5C4C7D5C4C7D5
C4C7D5C5C7D6C5C7D6C5C7D6C6C8D6C6C8D7C5C7D5C4C6D4C5C7D4C6C7D5C6C7D5C4C6D4
C4C6D3C4C6D3C4C6D3C4C6D3C4C6D3C4C5D2C4C6D3C5C6D3C5C6D3C5C6D3C5C6D3C5C6D3
C6C7D3C6C7D4C8CAD7CFD2DFD5D9E5D5D9E5D4D9E5D4D9E4D3D8E4D4D9E4D4D9E4D2D6E2
D5D9E4D5D9E4D4D8E3CCCFDACFD1DCCED0DBCED0DBCED0DACED0DACED0DACFD0DBCFD1DB
CFD1DCCFD1DCCFD2DCCFD1DCD0D2DDC6C9D2C0C3CCBDC0C9C3C5CFC8CAD3CBCDD6CFD0D9
CFD1DAD0D1DBCFD1DAD0D2DBCCCDD6CECFD8CFD0DAD0D1DBD0D1D9D0D1D9D0D1DAD1D3DB
D3D6DED5D8E0D5D8E0D6D8E0D6D9E1D5D8E0D5D8E0D5D8E0D5D8E0D6D9E1D7D9E1D7D9E1
D7DAE1D8DAE1D7DAE1D7D9E0D6D9E0D7D9E1D8DAE1D8DAE1D7DAE0D7DAE0D8DAE0D7DAE0
D8DAE0D7DAE0D7DAE0D8DAE0D8D9DFD8DAE0D8DADFD6D8DED6D8DDD2D4D9D7D9DFD8DADF
D9DAE0D9DADFD9DADFD9DADFD9DADFD8D9DED7D8DDD7D8DDD7D9DDD7D9DDD8D9DDD8D9DD
D9DADEDADADEDADADFDADBE0D6D7DC8586884D4E4F9E9FA1D1D2D5DCDEE1DDDEE1DCDDE0
DBDCDFDBDCDFDBDCDFDBDCDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDEDBDCDEDBDDDE
DBDDDEDBDDDEDBDDDDDBDDDDDBDDDDDBDDDDDCDEDDDDDEDEE1E2E2E2E3E3E2E3E4E2E3E4
E2E3E4E2E3E4E2E3E4E2E3E4E3E3E3E3E5E3E3E6E2E4E7E1E4E8E2E3E7E18F918D222222
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
3A3C420F1011000000000000000000000000494C54494C54C4CAE0C4CBE0C4CBE0C1C7DC
BAC0D4B7BED1BCC3D7C3CADFBFC6DAC0C7DBC4CCE0C4CCE0C4CBDFC1C7DBBEC4D7BEC4D7
C0C7DAAFB4C69CA1B1979DAB7C808D797D889396A6A6A9BBACAFC0B4B7CAB6B9CCB6B9CB
B6B8CBB6B8CAB5B8CAB5B8CAB5B8CAB6B8CAB6B9CBB6B8CAB5B8C9B5B7C8B5B7C8B5B7C8
B5B7C8B5B7C8B5B7C8B5B7C8B5B8C8B5B8C8B6B8C8B6B8C8B6B8C8B6B8C8B6B8C8B6B8C7
B6B8C7B6B9C7B6B9C7B6B9C7B6B9C8B7B9C8B7BAC9B7BAC9B7BAC9B7BAC9B7BAC9B7BAC9
B8BAC8B8BAC8B8BBC9B9BBC9B9BBC9B8BBC9B8BCCAB8BCCAB9BCCAB9BCCABABDCABBBECC
BCBFCDBDC0CFC0C3D1C3C6D5C4C6D6C4C6D5C4C6D5C4C6D5C5C7D5C5C7D6C5C7D6C5C7D6
C5C7D6C6C8D6C6C8D6C6C8D6C7C9D7C6C9D7C5C7D5C4C6D4C5C7D4C6C7D5C6C7D5C5C6D4
C5C6D4C4C5D3C3C5D2C4C5D2C4C5D2C4C5D2C4C6D3C5C6D3C5C6D3C5C6D3C5C6D3C5C6D3
C6C7D3C6C7D4CACDDAD1D5E1D5D9E5D4D9E5D4D9E5D4D9E5D4D9E5D4D9E5D4D9E5D5D9E5
D5D9E5D5D9E5D5D9E5D2D6E2CED1DCCFD1DCCED0DBCED0DCCED1DBCFD1DBCFD1DCCFD1DC
CFD1DCCFD1DCCFD1DCCFD1DCCFD2DCC5C7D1D3D7E1D3D8E2CED1DBC9CDD6CED0D9CFD1DA
CFD1DACFD1DACFD1DBD0D1DACBCDD6CDCFD8D0D2DBD1D2DCD0D1DAD0D2DAD2D3DCD3D6DE
D5D7DFD5D8E1D5D8E1D6D9E1D6D9E1D5D8E0D5D8E0D5D8E0D6D8E0D6D9E1D7DAE1D7DAE1
D7DAE2D8DBE2D7DAE1D7DAE1D6D9E0D7D9E1D8DAE2D8DBE1D4D5DBD0CED4D7DAE0D3D6DC
D4D7DDD6D8DED6D9DFD8D9E0D8D9DFD7D8DED7D8DED4D6DCD5D7DDD1D2D7D5D7DCD7D8DE
D8DADFD9DADFD9DADFD9DADFD9DADFD9DADFD8D9DED7D9DED7D9DDD7D9DDD8D9DDD8DADE
D8DADED9DADEDADBDFDADBDFDADBDFAAABAE232424393A3BB1B2B4DCDEE1DDDEE1DCDDE0
DBDCDFDBDCDFDBDCDFDBDDDFDBDCDEDBDCDEDBDCDEDBDDDEDBDCDEDBDDDEDBDDDEDBDDDE
DBDDDEDBDDDEDBDDDEDCDDDDDCDDDDDCDEDEDCDEDEDEE0DFE2E3E4E2E3E4E2E3E4E2E3E4
E2E3E4E2E3E4E2E3E4E2E3E4E2E3E3E2E3E3E3E4E3E4E7E2E4E7E1DBDED8565754000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000001E1F22000000000000000000000000000000000000A5ABBDA5ABBDA5ABBDBFC6DA
BDC3D7BEC4D8BEC4D8BCC2D6BFC6DAC4CCE0C4CCE0C4CCE0C4CCE0C0C8DBBCC3D5C0C7DA
AEB4C5727581838795979CAB44464C2224267A7D8AB5BACCB4B8CAB5B9CBB7BACDB7BACC
B7B9CBB6B8CBB5B8CAB5B7C9B5B8CAB5B8CAB6B8CAB5B8CAB5B8C9B5B7C8B5B7C8B5B7C8
B5B7C8B5B7C8B5B7C8B5B7C8B5B7C8B5B8C7B5B8C7B5B8C7B5B8C7B5B8C7B6B8C7B6B8C7
B6B8C7B6B8C7B6B9C7B6B9C7B6B9C8B7B9C8B7B9C8B7BAC8B7BAC8B7BAC8B7BAC8B7BAC8
B7BAC8B8BAC9B8BBC9B9BBC9B9BBC9B8BBC9B8BCCAB8BCCAB9BCCABABDCABABDCABBBECC
BDC0CEC0C2D1C2C4D3C4C6D5C4C7D6C4C7D6C4C7D6C5C7D6C5C7D6C5C7D6C5C8D7C5C8D7
C6C8D7C6C9D7C6C9D7C7C9D8C7C9D8C7C9D8C5C7D5C5C6D4C5C7D5C5C7D5C5C7D5C5C7D5
C5C6D4C3C5D3C4C5D3C4C6D3C4C6D3C4C6D3C4C6D3C4C6D3C5C6D3C5C6D3C5C6D3C5C6D3
C5C7D3C6C8D5CCCFDBD3D7E3D4D9E5D4D9E5D4D9E5D4D9E5D4D9E5D4D9E5D4D9E5D4D9E5
D5D9E5D5D9E5D5D9E5D3D7E2CFD2DDCED1DCCED0DBCFD1DCCFD2DDCFD2DDD0D2DDD0D3DE
D0D3DEC7C9D4C9CBD6CED1DCCFD2DCB8BCC4BCC0C9D2D7E0C1C5CFA4A7AFC8CBD5CFD2DB
CFD1DBCFD1DBCED0DACDCFD8CCCED6C9CCD4CCCED7D0D2DAD0D1DAD1D2DBD4D6DFD5D8E1
D5D8E1D5D9E1D5D8E1D5D8E1D5D8E0D5D8E0D5D8E0D5D8E0D6D9E0D7DAE2D6D9E1D6D9E1
D7DAE1D7DAE1D7DAE1D7D9E1D6D9E1D7D9E1D7DAE1D8DBE1D5D6DDCFCDD4D6D9DFD4D6DC
D6D7DED5D7DED6D8DFD7D9E0D8D9DFD7D9DFD7D9DFD7D9DFD9DBE1D7D9DED6D8DED8D9DF
D0D1D7D4D6DBD9DBE0D9DADFD9DADFD8D9DED7D9DDD8D9DDD7D9DDD7D9DDD8D9DDD8DADD
D8DADED8DADEDADBDFDADBDFD9DADFA6A7AB050505000000868789D3D5D8D8D9DDDCDDE1
DCDDE0DBDCDFDBDCDFDBDCDFDBDCDFDBDDDFDBDDDFDBDDDEDBDDDEDBDDDEDBDDDEDCDDDE
DCDDDEDCDDDEDBDDDEDBDDDEDCDEDEDDDEDEDEDFE0E0E1E2E2E3E4E2E3E4E2E3E4DDDEDE
DBDCDDE2E3E4E2E3E4E2E3E4E2E3E3E3E4E3E3E6E3E4E7E2D9DCD7828380242624000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000016171A0000000000000000000000000000000000000000004F525B50525B8E94A3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00000007080800000000000000000000000000000000000000000000000000000037393F
000000000000969CAC969CACB7BED1B7BED1C1C9DCBEC5D9B1B8CAACB3C49EA4B4C1C8DB
C5CBDFC5CBE0C4CBDFBFC5D9B1B7C9AAB0C1989DAC6F727C7476829DA0B0B3B7CAB8BBCE
B8BBCEB7BACDB7BACCB6B9CBB6B8CBB5B8CAB5B8CAB5B8CAB6B8CAB6B9CAB5B8CAB5B8C9
B5B8C9B5B8C9B6B8C8B5B8C8B5B8C8B5B8C8B5B8C8B6B8C8B6B8C8B6B8C8B6B9C8B6B9C8
B6B9C8B6B9C8B6B9C8B6B9C8B6B9C8B7BAC9B7BAC9B7BAC9B7BAC9B7BAC9B7BAC9B8BBC9
B9BBCAB8BBC9B9BBC9B9BBC9B9BBC9B8BCC9B8BCCAB9BDCAB9BDCABABDCABABECBBCBFCD
C0C2D2C3C5D5C4C6D6C4C6D6C4C7D6C5C8D7C5C8D7C5C8D7C6C8D7C6C9D7C6C9D8C7C9D8
C7C9D8C6C8D7C5C8D7C5C8D6C5C7D5C5C7D5C5C7D6C5C7D5C5C7D5C5C7D5C5C7D4C4C7D4
C4C5D3C3C5D3C3C5D3C4C5D3C4C6D3C4C6D3C3C5D2C3C5D2C4C6D2C5C7D3C5C7D3C5C6D3
C5C7D4C6C7D4C8CAD6CED1DDBFC3CED4DAE5D4DAE5D4DAE5D2D7E2CCCFDAD4D9E5D4D9E5
D4D9E5D4D9E5D4D9E5D4D9E5D4D8E3D0D3DFCED0DCCED1DCCED0DBCED0DACED0DBCFD1DC
D2D5E0C8CDD6CED2DDCED0DBD1D5E0D3D8E2CACFD8D2D7E0D4D9E2D4D9E2CDD0DAD0D3DC
CFD1DBCFD1DBCFD1DACFD1DACFD1DACFD1DACFD1DAD0D2DAD1D2DBD3D5DED5D8E1D5D8E1
D5D8E1D5D8E1D5D8E1D5D8E1D5D8E0D5D8E0D5D8E0D6D9E1D6D9E1D6D9E1D6D9E1D6D9E1
D5D9E0D5D7DFD6D8E0D6D9E0D6D9E0D6D9E1D6D9E1D7DAE1D7DAE1CCCFD5CFD1D8D0D2D9
D4D6DCD0D2D9D7D9E0D9DAE1D8DBE1D9DBE1D5D8DED0D2D8D3D5DBC4C5CAC4C6CBBEC0C4
CFD1D6D7D9DED9DAE0D7D9DED7D9DED7D9DED7D8DDD7D9DDD8DADED8DADED7D9DDD7D9DD
D8DADED8DADEDADBDFDADBDFD9DBDFA5A7AA000000000000000000474848DADCDFDCDDE1
DCDDE1DCDDE0DCDDE0DCDDE0DCDDE0DBDDDFDBDDDFDBDDDFDBDDDFDBDDDFDBDDDFDBDDDF
DCDDDFDCDDDFDCDEDFDCDEDFDFE0E1E0E2E3E1E3E4E1E3E4E1E3E4E2E3E4E2E3E4E2E3E4
E2E3E4E2E3E4E2E3E4E2E3E4E2E3E4E3E5E3E3E6E3E3E7E29EA19C030303000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0303040000000000000000000F1011000000000000000000000000000000000000000000
0000000000003E40463E40465F636D5F636D5F636D6B707A5559615C606A5A5D66A9AFC0
C0C7DBC1C8DBB7BED0A5AABB9196A5898E9C777C8742454C595A649B9EAFB2B6C9B8BBCE
B8BBCEB7BACDB7BACCB6B9CBB6B8CBB5B8CAB5B8CAB5B8CAB6B8CAB6B8CAB6B8CAB5B8CA
B5B8CAB5B8CAB6B8C9B5B8C8B5B8C8B5B8C8B5B8C8B5B8C8B5B8C8B5B8C8B5B8C8B6B8C8
B6B9C8B6B9C8B6B9C8B6B9C7B6B9C8B7BAC8B7BAC9B7BAC9B7BAC9B7BAC9B7BAC9B8BBC9
B8BBCAB8BBC9B8BBC9B8BBC9B8BBC9B8BCCAB8BCCAB9BDCABABDCBBABDCBBBBECCBEC1D0
C2C5D4C4C7D6C4C7D6C4C7D6C5C7D7C5C7D7C5C8D7C5C8D7C5C8D7C6C9D7C6C9D8C8C9D9
C7CAD9C6C8D7C5C7D6C5C7D5C5C7D5C5C7D5C5C7D6C5C8D6C5C7D5C4C7D5C4C6D4C3C5D3
C3C5D3C3C5D3C3C5D3C4C6D3C4C6D3C3C5D2C3C5D2C3C6D2C4C6D2C5C7D3C5C7D3C4C6D3
C5C7D4C5C7D4C6C7D4CACCD9B9BDC7CCD1DDA9ADB7BCC1CBCED3DED4DAE5D4D9E5D5D9E5
D4D9E5D4D9E5D4D9E5D4D9E5D0D4E0D0D3DFCED1DCCED1DCCED1DCCED0DBCED0DBCFD1DC
D0D3DED1D5DFCFD2DDCFD2DCD2D6E0D4D8E3CBCFD8D3D8E1D5D9E3D5D9E3CDD1DAD2D5DF
D1D4DEC9CCD5C3C5CEC9CBD4CACCD5CDCFD8CFD1DAD0D2DAD0D2DBD2D4DDD4D8E0D4D8E1
D3D6DFD3D5DED4D7E0D5D8E0D5D8E0D5D8E0D5D8E0D6D9E1D6D9E1D6D8E0D6D9E1D6DAE1
D6D9E0D5D8E0D6D8E0D6D9E1D6D9E1D6D9E0D5D8DFD5D8DFD4D6DDC3C5CCBCBEC4CCCED4
C2C3C9C8CAD0D6D8DFD7D9DFD7D9DFD4D7DDD4D6DDD4D6DDD4D6DCCDCFD4D6D7DDD8D9DF
D7D9DFD9DAE0D8DADFD7D9DFD7D9DED7D9DED7D8DDD7D9DDD7D9DED7D9DED7D9DDD7D9DD
D8DADED8DADED9DADED9DBDEDADBDFC2C3C7535555686A697E8080B7BBBADEE0E3DEDFE2
DDDEE2DCDDE1DCDDE0DCDDE0DCDDE0DBDDE0DBDDDFDBDDDFDBDDDFDBDDDFDBDDDFDBDDDF
DBDDDFDCDEE0DEDFE1E0E1E3E1E2E4E1E2E4E1E2E4E1E3E4E1E3E4E1E3E4E2E3E4E2E3E4
E2E4E4E2E3E4E2E4E4E2E4E4E2E4E4E2E4E4E3E4E4D8DBD86D6F6C000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0F101200000000000000000025272B000000000000000000000000000000000000000000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1B1C1F000000000000000000000000000000000000000000000000000000000000000000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121214000000000000000000000000000000000000000000000000000000000000000000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101112000000000000000000000000000000000000000000000000000000000000000000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51545D464850292A2F1C1D20000000000000000000000000000000000000000000000000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3C3E45979DAE6A6E7A3F4148000000000000000000000000000000000000000000000000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464851ADB3C7888E9D43454D000000000000000000000000000000000000000000000000
000000000000000000090A0B969CACC5CCE1C5CCE1C4CCE1C3CBE0C0C7DCAFB5C7767A87
5F636CA7AEBFBFC5DAC3CADFC4CBE0C0C7DBC0C6DAC3C9DDC2C9DDB4BACCB9BED2B7BCD0
B8BDD0B9BDD1B8BCCFB7BCCEB7BBCEB7BBCEB7BBCDB7BBCDB7BACCB7BACCB7BACCB6BACC
B7BACCB7BACCB6BACCB6BACBB6BACBB6BACBB6BACAB6BACAB6BACAB6BACAB6BACAB6BACA
B7BACAB7BACAB7BACAB7BACAB7BBCAB7BBCAB7BBCAB7BBCAB7BBCAB7BBCAB7BCCAB7BCCB
B7BCCBB8BCCBB8BDCBB9BDCBB9BDCBB8BCCBB7BBCAABAFBD7C808B4C4E55A4A6B4C2C5D5
C3C6D6C2C6D6C2C6D6C3C6D5C3C6D5C3C6D5C3C6D5C3C6D5C3C6D6C3C7D6C4C7D6C4C7D6
C4C7D7C4C7D7C4C7D6C3C6D5C2C5D4C2C6D4C3C6D4C3C6D4C3C6D4C3C6D4C2C5D4C2C5D3
C2C5D3C2C5D3C2C5D3C2C5D3C3C5D3C3C5D3C3C6D3C3C6D3C3C6D3C3C6D3C4C7D3C4C7D4
C5C7D4C5C7D4C5C8D5C6C9D5CBCEDBD3D8E4D4DAE6CFD6E2D0D6E2D4DAE6D4DAE6D4DAE6
D4DAE6D4DAE6D4DAE6D4DAE6BEC3CED3D8E4D1D6E2C5C9D5CACFDAB4B9C2CBD0DAC6C9D4
CACDD8CCCFDAC4C8D2CDD1DCD0D4DFD0D5DFC1C4CED4D9E3D4D9E3BEC2CCC8CCD6D2D6E0
D2D5E0CED2DCD4D8E2D4D9E2D4D9E2D4D9E2D4D8E2D4D8E2D4D8E2D4D8E1D4D8E1D4D8E2
D4D8E2D4D9E2D4D9E2D5D9E1D5D9E1D5D9E2D5D9E2D5D9E2D5D9E2D5D9E2D5D9E2D6DAE2
D6DAE2D6DAE2D6DAE2D7DBE2D2D5DDC4C7CEB5B8BECDD0D7D6D9E0D6D9E1D7DAE1D7D9E1
D7DAE1D7DAE1D7DAE1D7DAE1D7DAE1D6D9E0D6D9E0D6D9E0D7D9E0D6D8DFD6D8DED6D8DE
D6D8DED6D9DFD7DADFD6D9DED6D8DDD6D9DED7DADED3D6DBC8CBCFCED1D5D6D9DDD7D9DD
D8DBDED8DBDFD8DBDFD9DBDFD9DCE0DADCE0DADDE1DBDEE2DEE1E4DEE1E5DEE1E4DEE1E4
DEE1E4DEE1E4DEE1E4DEE1E4DFE2E4E0E5E5E1E6E5DFE2E4DEE1E4DFE1E4DFE1E4DFE1E4
DFE2E4E0E2E4E0E2E4E0E2E4E0E3E4E0E3E4E0E3E5E1E3E5E1E3E5E1E3E5E1E3E5E1E4E5
E1E4E5E1E4E5E2E4E5E2E4E5E2E4E5C6C8C85051511C1C1C000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000161615898B8790918D1C1C1C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2223276A6E7A4B4E57161719000000000000000000000000000000000000000000000000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030304070809060707020202000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000666A76ADB5C9BCC4D9C4CDE3C3CDE2C3CDE2C3CBE0C2CBE0C1C9DEC0C8DE
C3CBE0C3CBE0C3CBE0C2CADFC0C8DDC4CBE1C4CBE1BCC4D8999FAF5B5E684B4E565C6069
8D93A2B8BED1BDC4D8C2C9DDB4BACDC3CADFC3CADEC1C8DDC1C7DBC3CADEC3CADE989EAD
42444B20212552555C60636D55575F2325280000000000000000000000000000002D2F33
696E784A4D541213155D626AB9C2D37176810C0D0E00000009090A181A1C17181A070708
000000000000000000141517686B74ADB2C1C1C6D7C1C6D7C1C6D7C1C5D7C1C5D6C1C6D6
C1C6D6C1C6D6C1C6D6C1C6D6C1C6D6C1C6D6C1C6D6C1C5D5C1C5D5C1C5D5C1C6D5C1C6D5
C1C5D5C1C5D5C1C5D5C1C6D5C1C6D5C1C6D5C1C6D5C2C6D5C2C6D5C2C7D5C3C7D5C3C7D6
C3C7D6C3C7D6C3C8D5C3C7D5C3C7D5C4C8D6C4C8D6C4C8D6C4C9D6C5C9D6C5C9D7C9CFDC
D1D9E6D3DBE8D4DBE9C2C8D5D3DAE8D3DAE8D3DAE8D3DBE8D3DBE8D3DBE8D3DBE7D4DCE8
D4DCE8D4DBE8D4DBE8D4DCE8D1D8E4D2D8E5D4DBE7D4DBE7D4DBE7D4DBE7D4DBE7D4DBE7
D4DBE7D3DAE6D3DBE7D3DAE6D3DAE6D4DBE6D4DBE6D4DBE6D4DBE6D4DBE6D4DBE6D4DBE6
CFD5E0C8CED8D1D7E1D4D9E4D4DAE4D4D9E4D4DAE4D4DAE4D4DAE4D4D9E3D4D9E3D3D8E3
D4D9E3D4D9E3D4D9E3D4D9E3D4D9E3D4D9E2D4D9E3D4D9E3D3D8E2CDD2DACED2DBD4D8E1
D4D8E1D1D6DED1D5DED4D8E1D4D9E1D4D9E1CFD3DCC4C8D0CED2DAD3D7DFD5D9E1D7DBE3
D7DBE3D7DBE3D7DBE3D8DCE4D8DCE3D6DBE2D7DBE2D7DBE2D7DBE2D7DBE2D8DCE2D8DCE3
D8DCE3D7DBE2D5D9E0CFD3DAC7CAD1CBCFD5D6DAE0D1D5DAC9CDD2BBBFC3D1D6DBDADFE4
DCE1E6DCE1E6DCE1E6DCE1E6DCE0E6DCE0E6DCE0E6DCE0E6DCE1E5DCE1E5DCE1E5DCE1E4
DCE1E4DCE1E4DCE1E4DCE1E4DCE1E4DCE2E4DCE1E4DCE1E4DCE1E4DCE1E4DDE2E4DDE2E4
DDE2E4DDE2E4DDE2E5DEE3E5DFE3E5DFE4E5DFE4E5E0E4E6E0E4E7E0E5E7E0E5E7E0E5E7
E0E5E7E1E5E79B9D9E0000000000000000000000000606061516159B9E9EE6EAE8E5EAE8
E6EAE8E5EAE8E5EAE8E3E7E5CDD1CFE6EAE7E6EAE7DBDEDCE6EBE8E6EBE8E6EBE7E7EBE7
E7ECE7E7ECE7E7ECE7E7EBE6E7EBE6E7ECE6E7ECE6E7ECE6E6ECE5E7EDE5E7EDE5E7ECE6
E7EBE5E7EBE4E7EBE4E6ECE4E6ECE4E6ECE3E6ECE3E6ECE3E7ECE4E8ECE4E7EDE4E7EDE4
E7EDE3E7EDE3E6EDE3E5ECE3E4ECE3E4ECE2E4ECE2E4ECE2E4ECE2E4ECE2E4ECE1E4ECE1
E3ECE1E3ECE0E4ECE0E4EDE1E5EDE1E5EDE1E5EEE1E5EEE1E5EDE1E5EDE0E5EDE0D5DDD1
474A46000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000131416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000000000000000000000000000000000000000000000000000000000000000000383B41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00000000000000000000000000000000000000000000000000000000000000000051555E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000000000000000000000000000000000000000000000000000000000000000000303238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000000000000000000000000000000000000000000000000000000000000000000121215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000000000000000000000000000000000000000000000000000000000000000000000000
5E636E9FA8BA7278861D1F220F1012757B884A4D5420222526282C33363C3B3D432D2E34
28292D292A2F5659639DA4B5AFB8CBBAC2D6BDC5D9BEC6DBB3BACDA5ACBE979EAE868B99
7075825C606A797E8BA3A9BABCC4D8C1C8DDBEC5D97277842F31363233383234392F3035
18191C060607000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000026272B0B0C0D000000
000000000000000000000000000000000000000000000000000000000000000000232528
D0D9EBBAC2D2CAD1E3C5CBDDC4C9DBC3C8D9C3C7D8C2C7D8C2C7D8C2C7D8C2C7D8C2C7D8
C2C7D8C2C7D8C2C8D7C2C8D8C2C8D7C3C8D7C3C8D7C3C8D7C3C8D8C3C8D7C4C8D7C4C8D7
C5C9D8C6CBDAC8CEDEC9CFDEC9CFDEC9CFDECED5E4D3DBEBD4DCECD3DCEBD4DCEBD4DCEB
D4DBEAD3DBE8CACDDBC7C5D2CAC6D2C4C8D3C0C7D3CDD5E3D4DCEAD7DFECCDD4E0CBCDD9
D0D2DEDAE2EEDAE2EED3DEE0D5D7E3D2D7E2D7DFEBD7DEEBC0C6D1A4AAB4BDC4CEC0C8D2
A2A8B1CBD2DDD1D8E3BAC1CBBDC4CDBDC3CDBFC6CFC8D0DAD5DEE7D6DFE9D5DDE8D8E0EA
DAE3ECDAE3EBD4D7DFC2B2B8D0CFD6D4D8E0D5DBE2DAE3EBDAE3EBDAE3EBDAE3EBDBE3EA
D8E0E9D6DCE6D5DAE5D4D9E4D4DAE4D4DAE4D4DAE4D6DCE6D6DCE5D5DAE4D5DBE4CCD2DA
C6CDD4D3D9E2D5DBE4D5DAE3D6DBE4D8DEE7D8DEE7D6DCE4D5DBE3D4DAE2D5DBE3D6DCE4
D6DBE2D6DBE3D6DCE4D8DEE6D9DEE6D7DCE4D6DCE3D9DEE6DBE1E8D8DEE5D7DDE4D7DDE3
D7DCE3D7DCE2D6DCE2D7DDE3DBE1E7DBE1E7DBE1E7DBE1E7DBE1E7DCE1E7DCE1E7DCE2E7
DCE2E7DCE2E7DBE0E6D3D8DECED2D8CDD1D7C1C6CBCBCFD4DBE0E5DCE1E7DDE1E7DDE2E7
DDE2E7DDE2E7DDE2E6DCE2E5DDE3E6DDE3E7DDE2E6DDE2E6DDE2E6DDE3E6DDE3E6DDE3E6
DEE4E6DEE4E6DEE4E6DEE4E6DEE4E6DEE4E6DFE5E6DFE5E6DFE5E6DFE5E6DFE5E6DFE6E6
E0E6E6E0E6E6D4DADAB1B6B4C5CBC9E4EAE9E4EBE9E5EBE9E5EBE9E5EBE9E5EBE9E5EBE9
E5EBE9E5EBE9E5EBE9E5EBE9E5ECE9AFB4B2BEC2C0A0A3A1999C9A868988D2D8D5E5EBE7
E6EBE8E6ECE8E6ECE8E6ECE8E6ECE8E7ECE8E6ECE8E7EDE8E7EDE7E7ECE8E7EDE8E7EDE8
E7ECE7E7EDE7E7EDE7E7ECE6E7EDE7E7EDE7E7EDE7E8EDE7E8EDE7E8EDE6E7EDE5E6EEE6
E5EDE4E4EDE5E4EDE5E4EDE5E5EDE4E3EBE2E0E9E0E4EDE4E4EEE4E4EEE4E4EEE4E5EEE4
E5EEE4E4EEE3E4EEE3E4EDE3E1EBDFD3DCD1CAD3C8A6ADA44C4F4B000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000010101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000000000000000000000000000000000000000000000000000000000000000000050506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00000000000000000000000000000000000000000000000001010100000000000009090A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00000000000000000000000000000000000000000000000021232700000000000009090A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00000000000000000000000000000000000000000000000041444C0000000000000E0E10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000000000000000000000000000000000000000000000000000000000000000000303238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00000000000000000000000000000000000000000000000000000000000000000051555F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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000060708000000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0000000000000000000000000000000000000000000000000000000000002E3036212226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0000000000000000000000000000000000000000000000000000000000005559644C515A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0000000000000000000000000000000000000000000000000000000000003B3E44646976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00000000000000000000000000000000000000000000000000000000000009090B646A76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00000000000000000000000000000000000000000000000000000000000008090A5D636E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03030400000000000000000000000000000000000000000000000000000004050532353B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0F0F110000000000000000000000000000000000000000000000000000000000001F2125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191B1E0000000000000000000000000000000C0D0F00000000000002020213141624262A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1112140000000000000000000000000000000000000000000000000506073D4048747A89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05060600000000000000000000000000000000000000000000000009090A606571B6C1D8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000000000000020202000000000000000000000000000000000000050505383B42838C9C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0000000000001415170000000000000000000000000000000000000101012325296A717F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00000000000026282D000000000000000000000000000000000000000000696F7D606672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0000000000000000000000000000000A0A0C282A2F3A3E451D1E220000000000005E636F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10111323252A2123280E0F1000000017181B5C626D8991A2575D683C404724272B3C4047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2B2E346167745B616D26282D000000181A1D626874929BAD747B8A8992A45358631E2024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40444D8D96AA858EA0383B420000000C0C0E2D3036484B5562697697A1B55C626E141518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24262B5055604B505A1F21260303030000000000000405052B2D3350546034373E2A2C31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0708091011141213150708091B1C2000000000000007070832353B5A606C5B606C838B9C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00000000000000000000000034373E0000000000002A2C326F7584B2BCD3B5BFD7BAC5DD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00000000000000000000000026292E0000000000007B829397A1B4AAB4CBB2BDD4ADB8CE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000000000000000000000000000000000000000000BFCBE4BECAE3BECAE3BFCBE48A92A4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0000000000000000000000000000000000000000004F545FB0BBD2A0ABC08891A33D4048
0D0E102022264D525C575D68282A2F000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000191B1E000000000000000000000000000000000000000000
000000010101030303545A63B5C1D571798511121451565F9CA6B879818E202226000000
000000000000000000000000000000000000000000000000000000000000191B1D565B64
696F7A2F32360202034C51599099A7464A51000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
10111336393E212326020202000000000000000000000000000000000000A0A9B6D5E2F3
D6E2F3D6E2F3D6E2F3D5E2F3D5E2F3D5E2F3D5E2F3D5E2F3D5E2F3D6E2F2D6E2F2D6E2F2
D6E2F2D6E2F2D6E2F2D6E2F2D6E2F2D6E2F2D6E2F2D6E3F2D6E3F2D6E3F2D6E3F1D6E4F1
D6E4F1D6E3F1D6E3F1D6E3F1D6E3F1D6E3F1D6E3F1D6E3F1D7E3F1D7E3F1D7E3F0D7E3F0
D6E2F0D4E0ED7C838A555A5F62686E252729000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000303336798086BBC4CED4DEEAD6E1ECD6E0EDD7E1EDD6E1ECD6E1ECD6E0ECD7E0EC
D7E0ECD7E0ECD7E1ECD7E1ECD7E1EBD7E1EBD7E1EBD7E1EBD7E0EAD6E0EAD6DFE9D6E0EA
D6E0EAD6E0EAD6E0EAD7E1EBD8E1EBD8E2ECD8E2EBD7E1EBD7E1EAD8E2EBD9E2ECD8E2EB
D8E2EBD7E2EAD7E2E9D7E2E9D7E2E8D6E1E7D7E2E8D9E3EAD2DBE2D8E3E9D6E0E6D9E3EA
DAE4EADBE6EBDAE5EADAE4EADBE5EBDCE7ECDEE9EDDFEAEEDFEAEEE0EAEEE0EAEEE0EAEE
E0EAEEE0EBEEE0EBEEE0EAEEE0EBEEE0EBEEE1EBEEE1EBEEE1EBEEE1EBEEE1EBEEE1EBEE
E1EBEEE1EBEEE1EBEEE1ECEEE1ECEEE2ECEEE2ECEDE2ECEDE2ECEDE2ECEDE2ECEDE2ECED
E2EDEEE2ECEEE1EBECACB3B4494C4D070707000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000000000000000000000000000000000002D3036676E7C565C672F32380D0E10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0000000000000000000000000000000000000000000C0D0F1C1D211A1C200F101209090B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00000000000000000000000000000000000000000007070832353B5A606C5A606C5A606C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0000000000000000000000000000000000000000000E0E105F6672AFBAD1AFBAD1AFBAD1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0000000000000000000000000303040C0C0E34383E494D58636A77818A9B8992A4929DB0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0000000000000000000000001314174347515B616D97A1B65B616D2D3036555B668891A3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000000000000000000000000222529788090A2AEC4A4AFC5474B550000004449529BA6BB
B6C3DBABB8CEA6B2C8A9B5CC505560000000000000000000000000000000000000000000
00000000000002020223252A3639404D515C3133390D0E10000000000000000000000000
0000000000000000000000000000000000002D3035000000000000000000000000000000
0000000000000000000000000000000000000101010405050505060202020404051E2023
32363B191A1D0000000000000000000000000707080000000C0D0E000000000000000000
282A2E5F666F454A510C0D0E0000000000000E0E10020202000000000000000000000000
0101011C1E21646A746C737E2326290000000000000000000000000000000000001A1C1E
6168717178825960673D4146161719050506000000000000000000000000CEDBEDD4E2F4
D4E2F4D4E2F4D4E2F4D4E2F4D5E2F4D5E2F4D5E2F3D5E2F3D5E2F3D5E2F3D5E3F3D5E3F3
D5E3F3D5E3F3D6E3F38089936B727ACBD8E6D6E3F3D5E2F1CEDAE9B5BFCCABB6C1B5C1CE
89929B7D848D848B94A0A9B5B7C2CFB7C2CF595E641B1D1E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000005C61667F868D1E1F21000000000000000000000000000000000000000000000000
000000010101565A5FB0B9C49BA3AC51565B99A0AAD6E1EDD6E1EDD5E1EED6E1EDD6E1ED
D5E0ECD5E0ECD5E1ECD6E1ECD6E1EBD6E1EBD6E2EBD6E2EBD6E2ECD6E1EBD6E1EBD6E2EB
D8E2EDD7E3EDD7E2EDD7E3ECD7E3ECD8E3EDD9E3EDD8E3ECD8E4ECD9E4EDD9E5EDD8E4EB
D7E3EAD9E5ECD9E5ECD8E4EBD8E4EBD8E4EBD8E4EBD8E4EBD9E5ECDAE5ECDBE6EDDDE9EE
DEEAEFDEEAEFDEE9EEDFEAEFDFEAEFDFEAEFDFEAEFDFEAEFDFEAEFDFEAEFDFEAEFDFEAEE
DFEAEEDFEAEEE0EBEFE0EBEFE0EBEFDDE8EBE1EBEFE1EBEFE1EBEFE1EBEFD9E3E6CFDADC
DAE4E7E1ECEFE1ECEFE1ECEEE1ECEEE1ECEEE1ECEEE1EDEEE1EDEEE1EDEEE1EDEED8E2E4
303232000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000016181B4E545F6B7281676E7C2224290000004549539BA6BB
A1ADC2798191777F8F8088993A3E46000000000000000000000000000000000000000000
000000000000080809393D44838C9D9CA7BB676E7B1C1E21000000000000000000000000
0000000000000000000000000000000000002D3035000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000C0D0E000000000000000000000000000000
464B53A9B5C57B83901517190000000000000000000A0A0B000000000000000000000000
1A1C1E50555D5A606A33363B0A0B0C000000000000000000000000000000000000000000
0C0D0E4A4F56B1BDCD9AA4B2656B7518191B0000000000000000000000006D747EA7B2C0
D4E2F4B9C5D4D5E2F4D5E2F4D6E2F5D6E2F4D5E2F4D5E2F3D5E2F3D6E3F4D6E3F4D6E3F4
D6E3F3D6E2F3D6E3F3808892272A2C696F77727981727981727981808891B1BCC8727981
373B3F787F88838B954F5359494E53494E53232628050505000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000001D1E202E30323335384E52562A2C2E1516171516171516171516172D31335A5F63
5E6469686D73BDC8D2D5E2EDD5E2EDD5E2ECD5E2ECD6E2EDD5E1EED5E1EDD5E1ECD6E1ED
D6E1EDD5E1ECD5E1ECD6E1ECD6E1EBD6E2EBD6E2ECD7E2ECD7E2EDD6E2ECD6E2EBD7E2EB
D7E2EDD7E2EDD7E2EDD7E3ECD7E3ECD7E3ECD8E3ECD8E3EDD8E3ECD9E4ECD9E4ECD8E4EC
D8E4ECD9E4ECD9E5ECD8E4ECD8E4EBD8E4EBD9E5ECDAE6EDDCE8EEDDE8EEDEE9EFDFEAF0
DFEBF0DFEBF0DFEAEFDEE9EFDEE9EEDFEAEFDFEAEFDFEAEFDFEAEFE0EBEFDFEAEFDFEAEF
DFEAEFE0EAEFE0EBEFE0EBEFE0EBEFE0EBEFE0EBEFE1EBEFE1EBEFE1EBEFE1EBEEE0EAEE
E1EBEEE1ECEFE1ECEFE1ECEFE1ECEFE1ECEEE1ECEEE1EDEEE1EDEEE1EDEFE1EDEED5E0E1
303232000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000191B1F26282E2F333A3538401D1E22474C5699A4B8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0000000000000000000000000000000000000A0B0C464A548F98AC4A4F5932353C575E69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0000000000000000000000000000000000000D0E105A606DB1BED66066731C1D2016171A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0000000000000000000000000000000A0A0C13151834383F78809032363D0A0A0C000000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000000000000000000000000000000000000555B672E31371E1F23050506010101000000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000000000000000000000000000000000000A0ACC24E545F000000000000000000000000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0000000000000000000000000000000000006D7584363A410000000000000000000E0F11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00000000000000000000000000000000000025282D12141600000000000000000026292E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00000000000000000000000000000000000000000000000000000000000000000034383F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0000000000000000000000000000000000000000000000000000000000000000001C1E22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000000000000000000000000000000000000000000000000000000000000000000040505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000000000000000000000000000000000000000000000000040405080809060607020202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000000000000000000000000000000000000000000000000272A2F4E545F3C4049131518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000000000000000000000000000000000000000000000000484E58919CB170788824272C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0000000000000000000000000000000000000000000000003A3F47747E8E59606D1D1F23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000000000000000000000000000000000000000000000000181A1E31353C26292E0C0D0F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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000202327000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000001E202442474F2E32370A0B0C000000000000000000000000000000
0000000000000000000000000000000505062123272F32381415185B636DBAC9DD86909F
2224280000000000000000000000000000000000000000000000000000000A0B0C000000
0F101225282C3A3E44555C653B3F450D0E100000001F22254B51592B2E32000000000000
000000000000000000000000000000000000000000000000000000020202060607060707
0607070203031D2022464B52222428000000000000000000000000000000000000000000
0101011213141B1D1F474D526E767F6E767F4A4F550A0B0C0000000000000000008F9AA4
929DA8C5D3E2D7E8F7D8E9F7D8E9F7C9D9E6919CA69DAAB5ACB9C59CA9B37D858DCFDEEB
D9E9F7D2E2EFB6C4D0B0BEC9AAB7C1B7C4D0D3E3EFD8E8F5D9E9F6D2E2EE87919ABCCAD6
D6E6F3D8E8F5D9E9F5D9E9F5C0CED8AEBAC4CCDAE5DAE8F5DAE8F5DAE8F5DAE8F5C8D6E2
DAE9F5DAE9F5B8C4CED8E7F3D5E4EFDAE9F4DAE9F4DAE9F4DAE9F4DAE9F4DBE9F4DBE9F4
DBE9F4DBE9F4DAE9F3DAE9F3DAE9F3DBEAF3DBEAF3DBE9F3DBE9F3DBEAF3DBEAF3DCEAF3
DCEAF3DCEAF3DCEAF3DCEAF3DCEAF3DCEAF3DCEAF3DBE9F2DCEAF3DCEBF3DDEBF3DDEBF3
DDEBF3DDEAF2DDEAF2DDEBF3DDEBF3DDEBF3DDEAF2A2ABB1636A6CB8C3C9BECACF6F7679
828B8F96A0A4C6D3D8848C90050505000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000000000004F5561454A5425292D060607000000000000010102030303050505000000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000000000000A1AEC593A0B56F798825282D0202021011143C40495D6573464B56191B1F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00000000000099A6BCA2B0C89EABC2444A5408090A373C448C97ACAFBDD696A1B8555D68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000000000000565D6A757E90757F9032363D0E1012626A78B9C7E2BDCCE7BBCAE598A3B9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0000000000000C0D0E212429282B31121417090A0B3E424B7D879A94A0B6A4B2C9A1AEC5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00000000000000000000000000000000000003030313141723262B414750727C8C818B9E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0000000000000000000000000000000000000000000000000000001113152D3138383D45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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000017191B2124273D4248A0ADBB646C75000000
000000D7EAFAD7EAFAD7EAFAD7EAFAD7E9F9D7E9F9D7E9F9D8EAF9D8EAF9D8EAF9D8EAF9
D8EAF9D8EAF9D8EBF9D8EBF9D8EAF8D3E4F2BBCBD7A1AFB95F676E474D5133373A080809
00000000000003030335393C5F676D7C868D4C5357000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000A0B0C26292B303336303336
3033362A2E300E0F10000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000020202030304010202000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000005B626A828C98363A3F3D424726292D000000
00000024272AD7E9FAD7E9FAD8EAFAD8EAFAD7EAFAD7EAF9D8EAF9D6E8F7D5E7F5D4E7F6
D8EBF9D3E4F3C4D5E28F9BA6636C72575F642226280A0B0C020202000000000000000000
000000000000000000000000282B2E97A4AD6A7379000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000001020233373C6169732E3237000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000727B857F899424272A000000000000000000
00000050575ED6E7F9CFE0F094A1ACBECFDCD5E8F7D6E9F8D6E9F8C7D9E6ABBAC78E9AA4
8A969F4D54591D20220B0C0D000000000000000000000000000000000000000000000000
0000000000000000000000000D0E0F32373A232628000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000034383E8D99A8C1D0E55B626C000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000006067701E212309090A000000000000000000
00000024272A8994A0636C74181A1C929EA96C777D747E86A1AFBA40454A393E42000000
0000000000000000000000000000000000000D0E0F2F3437212426000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000006D7682B8C7DC919DAD373C42000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000383D42000000000000000000000000000000
000000000000000000000000000000111213070808000000000000000000000000000000
00000000000000000000000000000016181A4D5458A2B0BA768188030404000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000D0F101D20231F22261F2226111315010102000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003E434A6B7380393D430A0B0C000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000535B60AAB8C4BDCEDA929FA80D0E0E000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000002B2F35000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000004F5660A9B9CEB5C5DBB9C9E09CABBE6B75821F2226000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000E0F101B1D1F1B1D1F121415020202000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000212428000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000262A2E525963575F6A727C8B929FB176809023272B000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000090A0A000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000141619373C4231353C0F1012000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000001416180506060000001C1F22494F564F565D
4B52591F2224000000000000000000000000000000000000000000000000000000000000
0000000B0C0D292C301E2023000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000006A737E1C1E21000000444B51B0C0D1BFD0E2
B6C6D74A5158000000000000000000000000000000000000000000000000000000000000
00000025292B93A0AC79838D25282B151718000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000828F9C2326290000002B2F34707A857A8490
747E892F3438000000000000000000000000000000000000000000000000000000000000
0000001F2124727D85B4C4D2A0AEBA596167000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000C0D0E000000030404090A0B1C1F21
40474D2C30340202020000000000000000000000000000000000000000000000000B0C0D
282B2E2226291214159EADB8A7B6C3575F65030303000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000050606000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000033373C
99A7B68895A3555D651A1C1F00000000000000000000000000000000000000000024282B
84909B68717A080809222527222527131516232628000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000050506000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000090A0B000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000024272B
717B869EACBBAFBFD0383D42000000000000000000000000000000000000000000202326
747F895B646B0707080000000000000000002F3437000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000090A0B000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000016181A000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000050606
151719464D54545C641B1E20000000000000000000000000000000000000000000060708
181A1C131416010101000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000050606000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000101214000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000001E2023000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000636D75000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
050606000000000000535B62000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000D0F10040405000000000000000000000000000000000000
090A0B000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000006E7882212427000000000000000000000000000000000000
0000000000000000000000000000000000001315174D555B3B4145010202000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000B0C0D000000000000000000
00000000000000000000000094A2B02D3135000000000000000000000000000000000000
0000000000000000000000000000000000002B3033AABBC9828F99030304000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000003C4248000000000000000000
000000000000000000000000000000101214000000000000000000000000000000000000
0000000000000000000000000000000000001315164A5258393F43010101000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000004C535B000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000101214000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000353B41000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000181A1C000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000474E54000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`002P3ooooo000002T0000000L020L70516@@2LRX00b[>V0=Bl[`3J`K@0
f/6c0080fL2c00<0fL6b0=S1/P3H`;400`3H`;420=S1/@80fL6a0180a[6S03<^:P0J5aD0ETa608]k
LP1[GUL0R7U_0<^cY@2QSh<0Xi650<JaXP3I`K40f/:a0<bgYP2bWY40QgU^04Ho>@081`I=000000`0
oooo000:0?ooool00000:@0000000`0Q7Q`0R7Ua0<^dZ0020=[1]0040=W1]03I`K<0fL2c0=W0/P80
f<2a0`3H`K420=S0/@0=0=S0/03H`K00f<6`0<NbX`0f<B`0:RDR08]jL@3M`k@0YY:709f<P02YUXP0
XY240<F`X@020=[3/P<0fl>b00<0^:BE061ECP0:2@P0C@00000<0?ooo`002P3ooooo000002400000
00`01PD501DC4P0V8Ql081dK010>3@010@4010@300X9201:@Ch0]J2E0=S0/`3I`K@20=W1/`050=W0
/`3I`;80fL2b0=S0/P3H`;400`3H`K420=S0/@80f<6a00/0f<2`0;JRU@18@3/0GE=<0:BAQP3K`k<0
a[6R0<RcX`33[Yh0_j^L0=6kZP020=[3/@060=[3/P3K`k40f/>b0;VVUP1PEDh02PT8C@00000<0?oo
o`002P3ooooo00000240000000/05Q@B04@l>@1_He`0GU==02lY9P020@407QXI05=9A02TTXP0e;b_
0=[0]0020=W1]080fL2c0P3I`;800`3H`;80f<6a0=S1/@060=S1/@060=2jZP2KRWl0MVYQ0;6OT@3;
]JH0fL:a103G`:l00`3H`[00fL>a0=W2/@020=[2/@050=_3/@2oZY/0QGM/040i<`0J5aD0C000000<
0?ooo`002P3ooooo00000240000000T0=S0/08AfKP2jYYX0XY2605=:A@0=2`/0C4A00:6>QP3B^Zd0
0`3I`;<00`3H`;<0fL2c0=W0/`020=W0/`030=S0/P3H`K40f<6a00H0f<6a00<0`jjP09J6NP2]Vhd0
0P3G`K040=S1/0@0fL:`00X0fL>a0=[3/P3J`k80aK2P0:^IR`1nL6H0F4i704a4?P0]:2D03`h<B@00
000<0?ooo`002P3ooooo00000240000000X0CDA00:FCR@3=]jX0_ZZN081bJP1DBdD0T81h0<ffZ@3I
`K@0fL2c0P3H`;<00`3I`;<0fL2b0=W0/P020=S0/PT0f<6a00H0b[FU0:2@P`2aWY40f<6a0=S1/03H
`[420=S2/0<0fL:`00`0fL:a0=W3/@3I`[40f/>a0=[3/P39]:@0c;JV0:bJS02;O700Whj105mDC00P
7AY9000000`0oooo000:0?ooool000008@000000201JD4X0]J6G0=>l[`3<]jX0/IjC0:^HS@36/JD0
eknc103H`;<30=W0/`030=S0/P3H`K80f<6b00P0f<6a00D0e/2_0<VcY032[Il0e;f^0=S1/@030=S2
/@030=S2/03I`[00fL:`00<0fL>a0P3J`k801`39/j<0bkJV0:jLSP2MS800c;JU07U/HP0Y9B40B@00
000<0?ooo`002P3ooooo00000200000000T00@4105aBC02fXYL0dkf`0=Bm/03C_:l0dkf_0=Fn/@3G
`;800`3H`;<30=W0/`030=S0/`3H`K80el6a00D0el6a103H`K40103H`[40e/2`0=Bn[@3F_k060=S2
/@80fL:a00/0f<6`0<bgYP37/Z80dK^[0<RdX`3<]ZH0ZYR:07a^I01iK680B40j01TF5019000000`0
oooo000:0?ooool00000800000001P0=30/0KV9L0;^WV`3D_[00dkf`0=Bn/080eKna1@3G`;830=S0
/`030=S0/P3G`K40el6a00@0el6a1P3H`K400`3I`[80f<:a0=S2/@040=S2/@0>0=S3/@3H`[40fL:a
0<bgYP2LS800WHb00<B`X@3:]JD0c[VX0:JDQ`1LDTX0:BDR01TF50081`M9000000`0oooo000:0?oo
ool0000080000000200^:2H0Sh1h0<B_X`3A^jh0e;j`0=Fo/P3E_k40e/2b1@3G`;80103H`;80fL2c
0=S1/`3H`K830=O1/P80f<6b00@0f<:b0=S1/@3H`K40f<6a103H`[430=O2/@<0f<:a00d0fL:a0=W3
/@3I`k80^JFF06mTG02DQGX0b;>S0=6lZ`3C_Z`0YiJ805I=AP0;2PT010@304X00000303oool000X0
oooo<P0000030?l000040000003o0000o`000?l00>@0000000D020L700l>3@1ID4X0/YnE0=:m[`02
0=Fo/P030=G0/P3F`;80e/2b00<0e/2b0`3G`;800`3H`;<0el2b0=O1/P050=O1/P<0el6a0P3H`K4:
0=S2/@80fL>a00X0`JfN0:>BQ@32[Yh0eKn^0=O1/03I`k40_:RI08]lL@0n=c8061DCBP00000<0?oo
o`002P3ooolc000000050?l00000000000000000003o0000i00000001@030P809R8P04U1?@2HR7l0
c;N[0080e[nb0P3F`;800`3G`;80e/2b0=K0/P020=K0/P@0el2b203G`K820=S1/P80f<:b203H`[43
0=W3/@0=0=W2/@3B_J`0b[FV0=:m[03D_jd0dkf/0=>n[@3>^JP0ak>Q09N7N`1WG5@0:RHR00/:2@18
000000`0oooo000:0?oooc@0000000<0o`000000003o0000i@0000001P0F4a80HeQB09n?Q@38/jL0
e;ja0=Jo/P80e/2b0P3G`;800`3F`;80el2b0=O1/P090=O1/P@0el:b00<0f<:b0=S1/P3H`[800`3H
`[850=S2/@<0f<>a00L0fL>a0=W3/P3J`k<0fL>b0=>n[@3B_:/0f<6`0080g<Fc00D0gLFc0<fhY`2a
Wi00GU=<01LD4P18000000`0oooo000:0?ooobd0000000<0o`000000000000001@0000000`3o0000
00000000003T0000000302PT8P2BPWX0bkJY0080eKnb00@0eL2b0=Fo/P3F_k80e[nb1@3F`;820=K1
/PT0el6b103G`[800`3G`[40f<:a0=S2/@030=S2/@80el:a0P3H`[420=S3/@060=W3/P3J`k80fL>b
0;fZV`2]Vhd0b[FT0`3MaK<0103MaK@0e/2_08=eJ`0O71U8000000`0oooo000:0?ooob/000000P3o
0007000000030?l000000000o`000>80000000D00@4100D4100920L0?cPd0;:OU0020=Fo/P80eL2b
00<0eKnb0=K0/P3F`;801@3F`;820=K1/PL0el6b1`3G`[800`3G`[40f<:a0=S2/@050=S2/@80f<>a
0P3I`k820=[4/`030<FaXP2hYIH0bkJV00@0g<Fc00<0f<6`08YlL00O71T0B000000<0?ooo`002P3o
oolY00000080o`00200000001@3o00000000000000000000o`000>40000000H020L702/V901AB4@0
QGI^0<VdZ@3E_k870=G0/P<0e/2b00<0el2b0=O1/P3G`K<00`3G`K890=O2/P@0f<:b2@3H`k80203I
`k80f/>c0=W4/`3G`[40eL2_0=S2/03Ka;<0g<Fc0P3LaK@00`3H`K40RWa`01lL6@18000000`0oooo
000:0?ooobP0000000<0o`000000000000001`0000030?l000040000003o0000o`000?l00</00000
00D00@4100<30`051@D01@@400<20P0@00000007024N6`1bIV00/inE0<^fZP3E_k80eKnc0=G0/`02
0=Fo/`80eL2c0P3F`;<0103F`K<0e/2b0=K0/`3F`;820=O1/P80e/6b0`3G`K890=O2/PD0f<:b1@3H
`k803P3I`k80f/>b0=[3/`3Ja;<0f/Fc0=[4/`3J`k80el6`0=6kZP3C_J`0g<Jd0<ZeY@1iK6806ALD
B000000<0?ooo`002P3ooolV00000080o`00g00000001P0;2PX09B4O03li=P0j=34081dK00H51@d0
000000D020L701@C4@1ID4/0]J6H0=>m/@020=Fo/`030=Bo/`3D_k80e;nb0080e;nb00@0eL2c0=K0
/`3F`K<0e/6c103F`;800`3G`K80e/6b0=K1/P020=O1/PX0el:b0P3H`[800`3H`k<0fL>c0=W3/`04
0=W3/`040=W3/P3I`k<0f/>c0=W4/`80f/Bc0P3KaK<01`38]:<0Xi:50:JDQ`3=^:P0X8n20559@P0=
30/0B000000<0?ooo`002P3ooolT00000080o`00f00000000`0820L06aPG02lZ:00303Ha;P0604I0
?01ZGeX0Sh5i08MjL`1TFU@0>cDb0P0O71/0100<2`X01`H601XH5P0^:RL203La;P@0=c8^00D09B4O
040j=`1cIV00]j>J0=:l/@020=Fo/`040=G0/`3D_k<0e;nc0=Bo/`80e;nb00<0e<2b0=G0/`3F`K<0
0P3F`K<20=K0/P80e/6b00<0el6b0=O1/`3G`K<00`3G`[<80=O2/P030=S2/P3I`[<0fL:c00P0fL>c
0`3Ja;<02P3JaK<0f<:a0<2]W@28Ng00FE590599@P1gJf40CTM001hK6@020P98000000`0oooo000:
0?ooob<0000000<0o`00000000000000f0000000300C4A00?SPe06YOFP20Lfd0QGQa08UlM@2CQGh0
ZYZA0<:_Y@2mZj00YYJ=08QkM080GUE@00@0>C@a030[:@1DC4L0N6eV0`28O7@208UlM0050922N@1n
LVX0Y9>:0<RdZ03D_[<00P3E_k<60=Bo/`070=C0/`3D`;80eL2b0=G0/`3E`K<0eL6b0=K1/`050=O1
/`<0el6b1@3G`[820=S2/`80f<:b00<0f<:c0=W3/`3I`k@00P3I`k@30=W3/`050=[3/`3I`k<0fLBc
0=W4/`3Ja;@00P3JaK@0203E`:l0X92304U2?00R7Q/05A<@01lL6@0C4@l01PH5B@00000<0?ooo`00
2P3ooolS000000030?l00000000000000=P0000000`04a4@03hh=@1ZGeX0P7=]08EhL@29O7D0ThEn
0:ZJT@32[jD0_J^P0:JFS@28Ng@205iED00403Td<@0`:bT0E4a707Q]IP<0R7ad0P29O7@01@2@PWT0
OW9Z0:BCRP38]:P0e;jc0080eKnc1P3D_k<01`3D`;<0e<2b0=G0/P3E`;<0eL6c0=G1/P3F`K<01@3G
`K<30=O1/PD0el:b0P3H`[<20=S2/P030=S2/`3I`k<0fL>d0080fL>d0`3I`k<01@3J`k<0fL>c0=W4
/`3Ia;<0f/Bd0080f/Fd00P0eL2_0:2@P`19@S`08QhK01DC400O71T04a4?00H61DT00000303oool0
00X0oooo8@0000020?l00=/0000000`07a`J06eRG@2]W9@0`k6W0<JcZ@38]:X0b;FZ0<VeZ`3:]Z`0
bKJ[0<ReZP32[jD20::CR@0408=gK`1lL6P0VX^20;VWW@<0a[BX00D0akBX0<RfZ@3;^:/0aK>W0<nk
[`020=Fo/`<0e;nc00<0e;nb0=C0/P3D`;800P3D`;80103E`;80eL2c0=G0/`3E`;<30=G1/`80e/6c
1@3G`K<00`3G`[<0el:b0=O2/P020=O2/P040=O2/`3H`[<0f<:c0=S2/`80fL:c00D0fL>c0=W3]03I
a;@0fLBd0=W3]0040=W3/`80fLBd0`3JaK@00`3D_jh0QWU^01/I5P1>000000`0oooo000:0?oooal0
00000P3o003B0000000900`;2P0N6aX0<B`Z03@_;@0h<c40?CLd03dg=@0i<c40=Bl]0080<bh/00<0
CTI209B6O`31[ZD00`3<^Jh20<fi[P040<fj[`3;^:d0b[N/0<NeZP80`[2U00`0_J^P0;bZW`31[j<0
a[BX0<VfZP39]Z/0bKN[0<Zh[03<^Zd0c[^^0=2l/03B_[820=Bo/`80dknb1@3D_k830=C0/P80eL2c
103E`K<40=K1/`@0el6b0`3G`[<50=S2/`80f<>d0P3I`k@70=W4]0070=W5]03JaK@0f/Fd0=[5]03E
`:l0QgY_01dI5`1>000000`0oooo000:0?oooad000000P3o003A0000000A00T81`0E4a808QhM03Xe
<P1ME500P7=^08MkM@2APgd0Vhf609b>QP2FQh40TXAm09B6O`2@PW/0UXR00;NUW03:]Z`00`3<^Jh0
1@3=^Jh0cKZ_0<fj[`3;^:d0bkN/00<0bKJ[0P38]JX02P39]j/0bkR/0<bi[@3=^Zh0c[^_0<jk[P3>
^jl0ckb_0=2m/03B_[820=>n/P@0dkja00<0dkna0=Bo/P3D_k800P3D_k80103D`;80eL2b0=G0/`3E
`;<20=G1/`D0e/6c0P3G`K<00`3G`K80el:b0=O2/`030=O2/`80f<:d00<0f<>d0=W3]03Ia;@00P3I
a;@01@3Ja;D0f/Fe0=[5]@3JaKD0flFe0080f/Fe00T0fLBc0=:n[@3@_J`0fLBc0=[5/`3?^j/0UhQl
03/e<00920L0C@00000<0?ooo`002P3ooolL000000030?l00000000000000=40000000d06ALF03hh
=P1SFED0P79^0:FDS@31[ZL0aK:Y0<Nd[039]Zd0bKJ/0<NdZ`36]:/0akF[0080akB[00<0b[J]0<bh
[P3<^Jh00`3<^Jh0103=^Jh0cKZ_0<RfZ`3>^k040<nk/0<0ckb`00<0ck^_0<nl[`3?_:l00P3?_:l0
0`3@_K00dKfa0=:n/@040=:n/@<0dkja0P3C_k830=Bo/P80e<2b00<0eL2c0=G1/`3E`K<01@3F`K<2
0=K2/`030=O2/`3F`[<0el:c00<0el:c0P3H`[@01@3H`k@0fL>d0=[4]@3Ja;D0f/Fe00<0flFf0`3L
aKH03@3KaKD0fLBd0<>`X@31[Yl0f<:b0=[4/`3?^j/0[Yf@06ILE00n>3<0=2l[01XH5P010@40BP00
000<0?ooo`002P3ooolJ00000080o`00]`0000002`0<2PX06aPH02PT8`0U8B00:2@R038]:`0c;Rd0
=2l^038];00O71/030X:0180000000L0:bLU06YPG02VUHh0]::L0<:_Y`3;]jh0c;R_00@0bkR_00D0
b[R^0<Vh[P3:^:h0bkV_0<fi[`040<bi[`050<bi[P3=^Jh0cKZ^0<NeZP3>^jl0103?^k002`3@^k00
d;b`0=2l/03?_;00ck^_0<jl[`3?_:l0ckb`0=2l/03@_K00dKf`00@0dKja00D0d[ja0=>n/@3C_k40
dkna0=>o/P030=Bo/P<0e<2b0`3E`K<20=K1/`@0e/:c1@3G`[<0103H`[@0f<>d0=S3]03H`kD20=W4
]@030=[4]@3KaKH0flFf0080flFf0`3LaKH03@3La[H0flFe0<ZfY`34/J80d;^[0=>n[P3;]jL0^:JG
08MjL02>P7L0V8Un06AJDP0I5a@0BP00000<0?ooo`002P3ooolI000000030000o`00o`0000000;L0
000000h07a`K04U2@01]HUl0F4m>05U@CP1eJFH0PWEb08eoN`2;OGX0I5YG03Tc<P0M6QT04@l?00@4
10h0000000@01PD504]3@@2JS8D0b;F]1`3;^:l01P3;^:h0b[R^0<Vg[@3:^:h0bkR_0<^i[`L0c;V^
00<0b[R]0<fj[`3?^k000`3?^k030=2l/0050<nl/03?_:l0c[b_0<nl[`3?_;000P3@_;000`3@_K00
dKfa0=6n/@030=6n/@030=:o/@3C_k40dkna00<0dkna00D0dl2a0=C0/P3D`;80e<2b0=C1/`040=G1
/`D0e/:c0P3G`[<20=O2]080f<:d00@0f<>d0=S3]@3Ia;D0f/Be0`3KaKH20=c5]PD0g<Jf00/0f<:b
0=Bo[`2o[9h0Xi:608YmLP2?PWH0YiJ:0<^fY`3D_jh0[Ib>04I0>`1:000000`0oooo000:0?oooaT0
000000@0003o00000000o`000?l0/000000050010@4020L700l=3@0@3`h02@P800820P0c;Rd0N6aY
0;6OVP25Mg@0Q7Md0;FSWP2lZJD0`JjY0;n[Y`2KRhL0NFeY05iEDP0g<C003@`<3P000000100C4Q40
MFUU0;ZXX03:]jl50<^h[`050<Zh[`3:^:h0b[R^0<Zh[P39]jh00P3:^:h02P3;^:l0bkV^0<bi[`3<
^Jl0c;V^0<^h[P3;^Jh0cKZ_0<bi[P3=^Zl30<nk/0030<nl/03?^k00c[b`0080c[b_103?_;020<nm
/080d;f`1@3A_[430=:o/@<0dkna00D0dl2a0=C0/P3D`;80e<2b0=C1/P030=G1/`030=G2/`3F`[<0
e/:c0080e/:c00<0el:c0=O2]03H`[@00`3H`[@01@3H`k@0f<>e0=W4]@3JaKH0g<Fg00@0g<Jg103L
a[H0303JaKD0`:bM09F6N`27NW00Q7M]09f=P@2eY9D0cKVY0=Bo[`3KaK@0a[>S06UNETX00000303o
ool000X0oooo6@0000001@000?l000000000000000000?l00:d0000001H04Q4@02HQ8@0e<2l0?SPg
04a4@`1<AD<0;2PW00/:2P0/9bL0IeaJ09V:QP24Mg@0QWUf0:JFTP2eXYh0`JjZ0<:_ZP2^WIT0ZiVE
0:BCS`1cJ6@0?CLe0P0V8b80100E4a<01@D400<20P051@@300H61@0?00D4100410@01PD500/:2P0=
30`0>38`0:FES`39]Zh0bkN_0<Zg[`3;]jl0bkR`0<bh/03;^;00b[R_00<0bKN^0P39^:h20<Zh[P03
0<^h[P3;^Jl0c;V_0080c;V_00@0c;Z_0<bj[P3=^Zl0c[Z_0`3?_;401@3>^k00cK^_0<jk[`3=^jl0
cK^^00<0c[b_00H0ckb_0<nl/03?_;00ckb_0=2m[`3@_K030=6n/@030=:n/@3B_k80d[nb0080d[nb
00<0d[na0=?0/@3C`;40103D`;801@3D`K80eL6c0=G1/`3E`K<0eL:c00<0e/:c00<0el:d0=S2]03H
`k@00`3H`k@00`3H`kD0fLBe0=[5]P070=c6]`<0g<Jf00`0f/Fe0;ZXVP24Mfd0QWU_0;>QU03C_Zh0
e;n_0=6m[@39]JD0c;RX0:^JS01ECDI:000000`0oooo000:0?oooaT0000000<0003o000000000000
0P0000000`00o`0000000000002Z0000000F03`f=@1`IF80SX1n085dLP27NWL0QGQf04e6A00C4A40
6ALF03/e=01KDDl0L6AQ08MiMP2KRhP0YiJB0;:PW02`WYX0ZIRD0;JTW`2dXYd0Sh5m06mTH@80G5=A
00l0=2l]018@3`0R7Qd0?CLf04i6A01ECDX0GE=A0518A@0k=S<0<2`Z05I>B`1/HEd0V8V40<FaZP3;
]k000`3:]jl0103;^;00bkV`0<^h[`3:^:l20<Vg[PD0bKR^00<0b[R^0<^i[`3;^Jl00P3<^Jl01@3;
^Jl0c;Z_0<fj[`3=^Zl0cKZ`00L0cK^_00<0c[^_0<jl[`3>_:l00P3>_:l20<nl[`080<nm[`3?_K00
d;f`0=2m/03A_K00dKj`0=6n/@3A_k430=:o/@80dkna00D0dl2a0=C0/P3D`;80e<2b0=C1/P030=G1
/`050=G2/`3F`[<0e/:c0=K2/`3G`[@0103H`[@0103H`k@0fL>e0=W4]P3KaKL80=c6]`0>0=c7]`3L
a[H0f/Bd0=2l[02nZid0_J^L0=6m[@3Ja;@0flJe0<:`X@27NVl0Mf]R05YBB`0Y9B9:000000`0oooo
000:0?oooaT0000000<0003o0000000000000`0000000`00o`0000000000002Y0000000F06EKF@2Y
V9D0`Zn[0:^JU`2VUY80XI6>06ILFP0Z9RH0518B01<A4@0H5QD0Edm=09J7P`2kZ:@0_Z^W0<6_Z@2a
Wi/0Z9JC0;ZXX`2eXil0VHZ609j?RP80UHJ200l0Dd]801hK6`0o>CL0LfMT09:3P02NSXT0ZIVC09f=
R024Mg<0S7mj0;NUW`32[jP0b;F^0<Zg[`3:]k000P3:]jl20<Zh[`040<Zg[`3:^:l0b[R_0<^h[`<0
bkV_00@0bkR_0<Zh[P3:^:h0b[R_1@3;^Jl40<bj[`80cKZ_00<0c;Z_0<bj[P3=^jl00P3=^jh00`3=
^jl0c[b_0<jl/0020<jl[`030<jm/03?_K00ckf`00<0d;f`1@3@_[000`3A_k40d[na0=;0/P030=?0
/P80e<2b00<0e<6b0=C1/`3E`K<00P3E`K<01@3E`[<0e/:c0=K2/`3G`k@0f<>e0080f<>d00D0f<>e
0=S4]@3Ia;D0fLBf0=_5]`040=c6]`030=_5]P3JaKD0f/Fe00<0g<Jf00`0flFe0=S3/`3C_jl0eL2`
0=[5]03La[D0gLNg0<2]W`1]HUT0;2PT00/;2P030`=:000000`0oooo000:0?oooaP0000000<0003o
0000000000001@000002003o0:H0000001T00P8200H51@0920P0Nfm/0;RVX`38]K40]ZFQ0:>CT02C
QH80OW9_06MNG012?3/07Q/K00D4100l=SD0MVYW0:6@S02hYZ40b;B_0;ZXXP2VUI40]J>N0:bJUP2B
Q800ZYZE0080Y9B?00/0Fe9@02`X9P1ZGe`0[I^G0<fh/`3<^K80c;Ra0<Nd[@2lZJ<0`JnX0<Vf[`05
0<Zg[`80bKN_0P39^:l20<Zh[`070<^i[`3;^K00cKZa0<jj/@3=^[00c;Z`0<^i/0070<^i[`P0c;Z^
103=^jl30<jl[`070<jl/03?_Jl0ckf`0<nm/03A_[40d;ja0=2m/0020<nm/080d;j`00@0dKja0=:o
/@3B`;40d/2b0P3C`;820=C0/P030=C1/P3E`[<0eL:c00<0eL:c00@0e/:c0=K3]03G`[@0el:d0`3H
`kD01@3Ha;D0fLBf0=W5]P3KaKL0flJg00<0g<Jg00<0g<Ng0=c6]`3La[L00P3La[H0303LakH0f/Fe
0=O2/P3D_jl0flFe0=g7]`3Mb;L0g/Vh0=2l[02OSh<0Bd@n00X924/00000303oool000X0oooo6000
00000`000?l000000000000700000003003o0000000000000:<0000001T04a4A030[:P1;@d80UXR5
0;j/Z@38]K40]jFR0:^JU`2^WIX0ZiZG0:RHU@1cJ6H0=2l^00@4100_:RT0ETe<07EYI`2UUI00aK6/
0<Jc[P2bXI`0^JNR0;6PW02JRhL0[YfG0080Z9RC00H0L6ER05E=B`2@PGh0_Z^V0<fi/`3<^K820<^h
/@030<Vf[`39]jl0b[N_0080b[N_0`39]jl00`38]jl0b;N^0<Rg[P020<Rg[P070<Vh[`3:^:l0b[V`
0<bi/@3=^[80c;^b0<bi/@020<^i[`030<^j[`3;^Jl0bkV_00H0bkV_0P3;^Zl00`3<^Zl0c;^_0<fk
[`050<fk[`030<fl[`3>_;00c[f`0080ckf`00@0d;j`0=6n/@3@_[00d;j`0P3?_[020=2n/0090=2o
/03A_k40dKna0=:o/@3B`;80dl2b0=C0/P3D`K80e<6c00@0eL:c00D0eL:d0=K3]03F`k@0el>d0=S3
]0020=S3]@80f<Be00D0fLFf0=[5]`3Ka[L0flJg0=c6^0030=c7^0080=c7]`3La[L0g<Jg0=c7]`3L
akH0f<>c0=G0/03Ka[H20=k8^0060=k9^03Nb;L0fLBc0;RVV01NEDh030/:B`00000<0?ooo`002P3o
oolH000000030000o`000000000000P0000000<00?l0000000000000W`000000600920P08QlN03Xd
=01KDU40P7=a0:>CT@2gYJ80aK:_0<Re/@2`Wi`0XiBA0:jNV`2bX9d0]::O08j0OP1OEU@0?3Le05eD
DP1lKf`0Rgei0:RGT`34/J`0b;F`0;f[YP80_jfX00h0/j:M0;VXXP2hYZ40^:JQ0:BDS`2RThl0_jbW
0<bh/P3=^K<0bkRb0<Zh/@3:]k40b[Ra0<Zg/080bKN_00<0bKN`0<Rg[`38]jl00P38]jl50<Rg[P03
0<Rh[P39^:l0bKR_0080bkV`00<0b[V`0<Vh[`3:^Jl00P3;^Jl40<Zi[P<0b[Z^0`3;^Zh00`3<^Zl0
cK^_0<fk[`020<fk[`80cKb_0P3>_:l0103>_K00ckf`0<nm/03?_K040<nn/0<0d;j`0`3A_k400`3B
_k40d/2b0=?0/P020=C1/P<0e<6c0P3E`[<01@3E`[@0e/>d0=K3/`3G`k@0f<>e0080el>e00H0f<>e
0=S4]P3JaKH0flFg0=c6]`3La[P40=c7^0030=g7^03LakL0g<Ng00<0g<Ng0`3Nb;P20=k9^0050=W5
]02`Wi80KfEL03Lb;P071`H0B`00000<0?ooo`002P3ooolH000000030000o`000000000000T00000
00<00?l0000000000000V`00000020010@4010@400P71`0K6AT0C4A407]^K@2OSX`0]ZBR0`36/k00
5031[j/0X96>07]^K@1`IF<0R7ai09j>R`2IRXL0R7]i07eaKP2HRHH0/Z6L0;RVXP2eY9l0`:fX0<Re
[`33/:/0aK>]0<Re/032/:/0a;:/0P35/Z`01`34/J`0b;F_0<^g/@3<^;80cKVc0<^i/P3:^;400P3;
^;420<Zg/0040<Vg/039]jl0b;N_0<Rg[`P0b;N^00P0b;R^0<Vh[`39^:l0b[V_0<Vi[`39^:h0bKV^
0<Zi[`H0b[V^103:^Zh00`3;^Zh0bkZ_0<bk[`040<fk[`80cKb_0P3>_K050<nm/080ckj`0P3@_[00
203A_[40dKna0=6o/P3A_k40d[na0=;0/P3C`;80dl6b0`3D`K801@3D`K<0eL:c0=G2]03E`[<0e/:d
0080e/>d0`3H`kD20=S4]P80f/Fg00<0g<Jh0=c7^03LakP01P3LakP20=g7^0030=g8^03Nb;P0g/Rh
00<0g/Vh00D0bKJW06ILE@0N6aT040l=00820P1;000000`0oooo000:0?oooaP0000000<0003o0000
000000002P000002003o09/0000001`01PH502<P8010>SX0IeiL09Z;R@2o[JX0b[Jc0<Vf/`39]K<0
`k6^0;j/Z@2fYJ80VX^8071UI01XGU`0TH>00;FTX030[ZX0_ZbW0;bZYP31[jX0a[>^0<Nd[`36/jh0
akB_0<Vf/038]Jl0bKJ`0P38]Jl40<Vf/0060<Zg/03:]k40bkRb0<bi/P3;^;80bkRa0P3:^;420<Vg
/0050<Vg[`38]jl0b;N_0<Ng[`37]Zh00`37]jh30<Rg[P80b;R^1@39^:h30<Vi[PD0b[V^1@3:^Zh0
103;^Zl0c;Z_0<bk[`3=^jl30<fl[`030<jl[`3>_;00c[b`0080c[f`1@3?_[001P3@_[00d;n`0=2n
/03@_[00d;na0=6o/P80d/2b00<0dl2b0=?1/P3C`K800P3D`K820=C1/`80eL:d0P3F`k@0203G`k@0
el>e0=O3]@3G`kD0elBf0=S4]P3JaKP0flJh2P3LakP00`3MakP0gLRh0=k8^0030=k8^0030=W4]02T
UHP0<RdY04h00000303oool000X0oooo5`0000000`000?l000000000000=00000003003o00000000
000009P0000000P040l?05Y@D02BQ880/Z2N0;f[Z@34/Zl0aK:_0<Fc/080akBa00X0a[>`0<>a[P2_
WY/0UHJ409:4P@2QTHh0^jRU0;FSW`2fY:00`[2[1038]K020<Rf/0P0bKJ`00D0bKN`0<Zg/03;^;80
c;Rb0<^i/P020<Zh/@030<^h/@39]k00b;N`0080b;N_00<0akN^0<Nf[P37]jh00`37]jh20<Rg[P<0
b;R^1@39^:h20<Zi[`80b[V^0P39^Jh30<Zi[P<0b[Z^00<0bkZ^0<^j[`3<^jl00P3<^jl20<fk[`80
cKb_00<0c[b_0<jm/03>_K000P3>_K040<nn/080d;j`00H0ckj`0=2n/03@_k00d;n`0=6o/@3B`;84
0=?1/P050=C1/`3D`K80e<6b0=C2/`3E`[<00`3F`k@00`3G`kD0f<>e0=S3]@020=S4]P030=[6^03L
akP0g<Nh00X0g<Nh00P0gLRh0=k8^03Nb;P0gLRh0=S4/`2dXiD0JEmG01TG5Dh00000303oool000X0
oooo5`0000000`000?l000000000000>00000003003o00000000000009D0000000T010@400T8200]
:BT0ThF30<2^[039][@0b;Jc0<Rf/P38]K801037];402P37];00_Z^X0;^YYP2n[:P0/InM0;RWY02V
UY<0Y9B@0;bZYP38]K420<Rf/@<0bKJa1039][000`38][00bKJ`0<Vf/0020<Vg/0050<Zh/@3;^;80
c;Vc0<^i/P3;^;400P3:^;401@38]k00b;N_0<Rg[`37]jl0akJ^00D0akN^0P38]jh30<Rh[P@0bKR^
00H0bKV^0<Zi[`3;^[00c;Z`0<Zi[`3:^Jh20<Vi[P030<Zi[P3:^Zh0b[Z^0080b[Z^0`3;^Zl00`3<
^Zl0c;^_0<bk[`040<fl[`H0c[f_00<0c[j_0<nn/03?_[000`3?_[001@3@_[00d;n`0=30/03A`;40
dl2b00<0dl6b103D`K<0103D`[<0eL>d0=G3]03F`k@30=O3]@030=O4]P3HaKH0flNh00@0g<Ni1`3L
akP02@3Mb;P0gLRi0=k8^@3Nb;P0g<Ng0;>RU01HCTT08b0M00820@1>000000`0oooo000:0?oooaL0
000000<0003o0000000000003`000002003o09@0000000L00P8202TU9@1>ATH0P7Ac0;VXY@37]K<0
b;Jc00<0b;Fb00d0akBb0<Nd/@36/k00a[>`0<Nd/033/:d0`[2]0<:_[02iZ:D0/J2N0:BDT@2SU900
^jZV0080b;F`1@38][030<Vf/0@0b;J`00P0bKN`0<Zg/@3;^;80cKVd0<bi/P3;^K80bkRb0<Zh/@@0
b;N_0`37]jl50<Ng[P040<Rh[P39^:l0bKR_0<Vh[`@0bKV_00D0bkZ`0<jl/P3>_;<0c;^`0<Zi[`04
0<Zj[P040<Zj[`3;^Zl0bkZ_0<^j[`H0c;^_00<0c;b_0<fl[`3=_:l00`3=_:l20<fm[`80c[f_00D0
c[j`0<nn/03@_[00d;j`0<no/0020=2o/0030=2o/@3A`;40d/2a00<0dl6b0`3D`K<20=C2/`040=C2
]03E`k@0e/>d0=O3]080elBe00@0elBf0=W5]P3KakP0g<Ni0`3Mb;T00`3LakT0g<Nh0=c7^0030=c7
^0090=c8^03Mb;P0gLRi0=k8^@3Mb;P0b[NX06QNEP0@3`d00P8204l00000303oool000X0oooo5`00
00000`000?l000000000000A00000003003o0000000000000940000000D01PH506EKFP2RTi40_ZfZ
0<Jc/@020<Ne/`080<Ne/P38]K80b;Fb0<Nd/P37];40akB`0<Jc/037]K420<Nd/@060<Jd/035/jl0
a;:^0;n]Z@2kZJD0`[2/1038][440<Vf/@80bKNa0`38][020<Vg/0030<Vg/@3:^;40bkRb00<0bkVb
00<0bkVa0<Rg/038]jl00P38]jl30<Ng[`D0akN^00@0b;R^0<Vh[`39^:l0bKR_1039^Jl0103;^[00
cKbb0<jl/`3<^k430<Zj[`<0b[Z^0P3;^Zl00`3;^jl0c;^_0<bk[`040<bk[`@0cKb_00<0cKf_0<jm
[`3>_Jl00`3>_Jl01@3>_[00ckj`0=2o/03@_k40dKna0080d;na00<0dKna0=70/@3B`;800`3C`K82
0=C1/`80e<:c0P3D`[@00`3E`k@0e/>d0=O3]0020=O3]@030=O4]P3IaKL0g<Ni00D0gLRi00<0g<Ni
0=c8^@3Lb;T00`3Lb;P01`3Mb;P0gLRi0=k9^@3D`;00UXMm038/:@0510@0D000000<0?ooo`002P3o
oolG000000030000o`00000000000180000000<00?l0000000000000T0000000100;2PX0Sh:00<2^
[038]K<40<Ne/P80akBa0P36];430<Nd/@<0b;Fb00H0akFa0<Nd/036];00a[B`0<Nd/037]K450<Rf
/@80b;J`00<0bKJ`0<Vg/038][001038][002038]k00bKNa0<Zh/@3:^;40bkRa0<^i/@3:^K40b;N_
1P37]jl50<Ng[P050<Rh[P38^:l0b;R_0<Rh[`39^:l00`39^Jl0103:^Jl0b[Z`0<^j/03:^Zl20<Vi
[P80bKZ^1@3:^Zh30<^k[`80c;^_0`3<_:l30<fl[`80cKf_00<0c[f_0<jm/03>_[000P3>_[000`3?
_k40d;na0=6o/@020=6o/@80dL2a00D0d/2b0=?1/P3C`K80dl6b0=C1/`020=C2/`80e<:d0P3E`k@0
1P3F`k@0el>e0=S4]P3Ha;H0fLFg0=[6^080g<Ni1@3Mb;T40=c8^@070=c8^03Mb;P0gLVi0=_6]`2]
WI00AClj00X9201A000000`0oooo000:0?oooaH0000000<0003o000000000000500000000`00o`00
00000000002=0000000500820P051@D05aDD0:2AT035];400P38][<20<Ne/`060<Nd/P37];40akBa
0<Nd/@36];40akFa0P36];400`38]K80b;Jb0<Re/P060<Ne/@@0b;Ja00<0bKJa0<Vg/@39]k400`39
]k420<Rg/@@0bKNa00H0bKRa0<Zh/@3:^K40bkVb0<^i/@38]k0:0<Ng[`030<Nh[`38^:l0b;R_0080
b;R_00<0b;V_0<Vi[`39^Jl01@39^Jl01039^Jh0bKZ^0<Vj[P39^Zh40<Zj[P030<Zj[`3:^jl0c;^_
0080c;^_0P3<_:l40<fl[`80cKf_00H0c[f_0<jn/03?_[40ckj`0<no/03?_k430=2o/@040=6o/@3A
`;40dL2b0=;1/P@0dl6b00@0dl:c0=C2/`3D`[@0e<:d0P3E`k@20=K3]0080=O3]@3Ha;H0f<Bf0=W5
]`3LakX0gLNj0=g8^P3Lb;T50=g8^@@0g<Ri00D0gLRi0=g9^@3F`K<0NViV014?3P1B000000`0oooo
000:0?oooaH0000000<0003o0000000000005@000002003o08d0000000H04A0?02hY:@1EC4/0ZIVG
0<Fc/038][<30<Ne/`090<Nd/P37];40a[Ba0<Jd/@37];40aK>`0;j]Z@2gYj<0aK>_0080akFa0P36
];040<Ne/@L0b;Ja00<0b;Na0<Vg/@39]k400P39]k403@38]k40b;N`0<Rg/039]k00bKNa0<Vh/@3:
^K40bkVb0<Zi/@38^;00b;N_0<Ng[`38]jl01P37]jl20<Nh[`030<Rh[`39^Jl0bKV_00<0bKV_0P3:
^Jl01039^Zl0b[Z_0<Zj[`3:^Zl30<Vj[`<0b[Z_0`3:^jl00`3;^k00c;^_0<bk[`050<bl[`060<fl
[`3=_Jl0cKf_0<fm[`3=_K00c[j`0P3?_[400`3?_k40d;na0=6o/@020=6o/@030=70/@3A`;80dL2b
0080d/6b0`3C`K800`3D`[<0e<>d0=C3]0030=G3]0<0e/>d0P3Ha;H00`3Ia[P0gLNi0=g7^@020=g7
^@030=c8^@3Mb;T0gLRi0080gLRi103Lb;T0103Mb;T0gLVi0<^iZP1OETmC000000`0oooo000:0?oo
oaH0000000<0003o000000000000Y00000001P0P7Ad0ETe=0963PP2_Wid0`k:_0<Rf/`@0akFc1037
]K801032/:`0^:NS0;NWY032/:d20<Ne/@030<Je/@37]K40akFa0080akFa00<0akJa0<Rf/@38][40
0`39]k880<Vg/@050<Rg/@38]k00bKNa0<Zh/@3:^;800P3;^K800`3:^K80b;N`0<Rg[`050<Ng[`<0
akR_0P38^:l00`39^:l0b[Va0<Zj/0020<^j/@80c;Za00@0bkZa0<Zj/03:^[00b[Z_1P39^Zl00`3:
^Zl0b[^_0<Zk[`030<^k[`030<bk[`3<_:l0c;b_00<0c;b_0`3=_K001@3>_K00c[j`0<jn/03?_[40
ckna00<0d;nb00<0dKnb0=70/P3A`;800P3A`;820=;1/P80dl6b00<0dl:c0=C3]03D`k@0103E`k@2
0=K3]0050=K4]@3Ha;H0f<Bf0=[6^03MakX00P3MakT00`3Mb;T0g<Ri0=c8^@030=g8^@@0g<Ri00@0
gLVi0=W5]P2bX9D0CdQ2D`00000<0?ooo`002P3ooolF000000030000o`00000000000:@0000000P0
;2PX07EZJ@31[Zd0/9nN0;b[Z@35];40`k:_0<Fc/@D0akFc00/0b;Fc0;ZYY@2kZZL0`k:^0;n]ZP34
/Zl0aKB`0<Fc/036];00a[Fa0<Ne/@020<Nf/@80b;Ja00@0bKNa0<Vg/P39]k80bKNa0P38]k450<Vg
/@030<Rg/@39]k40bKRa0080b[Rb0P3;^K800`3:^K80b;N`0<Ng[`040<Ng[`@0akR_00l0b;R_0<Vi
/03:^[00b[Za0<^j/P3;^k80cK^b0<fl/`3>_;<0cKbc0<^j/@3:^[00bkZ`0<Zj/03:^Zl01039^Zl0
0`3:^jl0bk^`0<^k/0030<^k/0D0c;b`00<0cKf`0<jm/@3>_[400P3>_[420<nn/@030<no/@3@_k40
d;na00<0d;na00T0dL2b0=70/`3A`K<0dL6c0=;1/`3B`K80dl6c0=?2/`3D`[@00P3D`k@30=G3]004
0=K3]@3F`k@0e/>e0=O4]@80f<Ff00D0f/Jh0=g7^P3MakX0gLRj0=g8^@030=c8^@80gLRi0`3Lb;T0
1@3Mb;T0fLFf0;2OT`1ZHET0:bLT05<00000303oool000X0oooo5P0000000`000?l000000000002T
0000000903@_;P1nLg80`[2_0:jNW02dY:40aK>a0;j]Z`33/Jl0a[Bb00D0akFc00L0ZYZH0:RHUP2d
Xil0]JBQ0;n^Z`35/k00aKBa0080aKB`00@0aKF`0<Je/@37][40akJa0P38][430<Vg/PT0b;Na00<0
bKNa0<Zh/P3:^;800P3;^K800`3:^K80b;R`0<Rg/0020<Nh/0<0akN_0P37^:l01@38^:l0b;R`0<Vi
/039^K40b[Va00<0bKV`00@0bkZa0<bk/P3<^k80bkZ`0P3:^[020<Zj[`80bKZ_00<0b[Z_0<Zk[`3:
^k001@3;^k030<bl/0<0cKf`0P3=_K420<jn/@030<nn/@3?_k40ckna00@0d;nb00@0dL2b0=70/`3A
`;<0dL6c0`3B`K<0103C`[<0dl:d0=C2]03D`k@20=G3]080eL>e00@0e/>e0=K4]@3Fa;D0elBf0P3H
aKL00`3LakT0g<Nj0=g8^P020=g8^P0=0=c8^@3Lb;X0g<Ri0=c8^@3Mb;T0g<Ri0=_7^03F`[@0b;JW
0:jNTP1TFe@08AhL00T8201C000000`0oooo000:0?oooa@000000P000?nW0000000;05A;B`2QTY40
a[Bb0;b[Z@2eY:<0^jVW0;n]Z`34/[00`[2^0;bZZ02`Wid00`2]WI/01`2BQH<0RWik0963P@2/WYX0
_jj[0<Fd/@35];000P34];001`35];00a[F`0<Je/036][40akJa0<Rf/P38]k800P39]k880<Rg/@08
0<Vg/@39^;40b[Vb0<Zi/P3;^[<0c;Zc0<Zi/P38^;030<Nh/080akN_0`37^:l01P38^:l0bKV`0<Zi
/@39^K00b;V_0<Rh[`<0b;V_00@0b[V`0<^j/03:^[00b[Z`1039^Zl00`3:^Zl0b[^_0<^k/0060<^k
/0<0c;b`0P3=_K000`3=_K40cKja0<jn/@020<jn/@030<no/@3@_k80d;nb0080d;nb00D0d<2b0=70
/P3A`;<0dL2c0=71/`030=;1/`040=?1/`3C`[@0dl:d0=C2]0@0eL>e00<0eL>d0=K3]@3F`kD00P3G
a;H20=W6]`030=_7^P3Mb;X0g<Rj0080gLRj0P3Lb;X02P3LbKX0g<Ri0=g8^@3Ja[L0aK>U08aoM@1T
FeD0DDU402/W90081`ID000000`0oooo000:0?oooa@000000P000?lQ000000<00?l0P00000005P02
0P802@P8014?3`1mLg80^ZVW0<Ne/`35];80`k6`0<>b/034/[00aK>a0<>b/02jZJH0ZY^I0:>DTP2P
THl0W8j<0964PP27NgX0S81m0;NWY033/jl20<Fd/0030<Bd/035];00aKB`0080aKF`00L0a[F`0<Jf
/@36][40b;Na0<Vg/`38]k80b;Ja00P0b;Na00P0bKRa0<Zh/P3:^K80bkZc0<fj]03;^[80b;R`0<Ng
/080akR_0P37]jl30<Nh[`040<Rh[`39^K00bKV`0<Vi/080b;V_00@0b;V`0<Ri[`39^Jl0bKZ`0P3:
^[050<Vj[`030<Zk[`3;^k00bk^`00@0bk^`0P3<_;000`3<_K00cKf`0<fm/0030<fm/@<0c[ja00<0
ckna0<no/P3@_k800`3@_k800`3@`;80dL2c0=70/`020=71/`@0dl:d0P3D`[@00`3D`kD0eL>e0=G3
]@030=G3]@040=K3]@3Ga;H0elBf0=O4]P80f/Ji00H0g<Rk0=c8^P3Lb;X0g<Rj0=g8^P3Lb;X20=c9
^P050=c8^@3Mb;T0e<6b08=gKP0C4Q00F000000<0?ooo`002P3ooolh00000003003o000000000000
07l0000000H02PT902TU9@1:@T80XiFD0<>b/037]K@30<Ne/`030<Jd/P35];80a;:`0080_Zf[00L0
_:^Y0;VXYP2fYZ<0]jJS0;NWY@2jZZL0`k:_00D0a;B`1035]K020<Je/0030<Nf/@38]k80b;Nb00P0
b;Na00T0b;Ra0<Vh/@3:^K80b[Vb0<^j/`3=^k@0bkZb0<Rh/037]k001`37^;020<Rh/0<0bKV`00<0
bKZ`0<Zj/03:^[000`3:^[060<Vj[`030<Zk/03;^k00bk^`00@0bk^`103<_;000`3=_K00cKfa0<fn
/@040<jn/@030<no/P3@_k80d;nb0080d;nb00H0d<2b0=30/`3A`;<0dL2c0=71/`3B`[@20=?2]0@0
e<>e103E`kD20=K4]@80elBf00L0e/Bf0<FdY`2MShD0WHn509:4O031[j<0flNi00D0g<Rj00@0g<Vj
0=g8^P3@_Jl0K69KF@00000<0?ooo`002P3ooolh00000003003o00000000000007l0000000D05a@D
05=<B`2;OWh0^:RV0<Fd/P020<Ne]0070<Ne/`36];80`k:`0<>b/034/k40`k:_0<Fc/@040<Fd/P<0
aKBa1034];000`34]K00aKF`0<Fe/0040<Fe/0030<Jf/@37][40akNa00T0b;Na00L0b;Ra0<Vi/P3:
^K80bkZc0<bk]@3:^[<0b;R`00T0akR`00P0akV`0<Ri/039^K00bKZa0<bk/P3=_K<0cK^c0<^j/@@0
bKZ`0P39^Zl00`39^[00b[^`0<Zk/0050<^k/0030<^l/03<_;00c;f`00@0cKfa00L0cKja0<jn/@3>
_[40ckja0<no/P3@_k<0d;nb00<0d<2b0P3@`;<00`3A`;<0dL6c0=;2]0020=?2]0H0e<>e103E`kD0
1@3Fa;H0elBf0=O4]P38]ZX0L6EO0080>cHc00<0AT0k09b>Q03F`[D01@3Lb;X0103MbKX0gLRi0<Jd
YP1RFE=I000000`0oooo000:0?ooocL0000000<00?l000000000o`00P0000000100[9bL0NW1^0:nP
W`31/:l30<Je/`80a[Bb00D0a;:a0<>b/033/[00`[6_0<Fd/@020<Fd/P030<Jd/P35]K40aKFa0080
a;Ba1@34];030<Be/080aKF`00<0aKFa0<Jf/@37]k800P37]k800`38]k80b;Na0<Rg/@020<Rg/@<0
b;Ra00L0bKRb0<Vi/P3:^K80bkZc0<bk]@3;^[<0bKRa00T0akR`00P0b;R`0<Ri/038^K00bKZ`0<Zk
/@3;^k80c;^b0<Zj/@D0bKZ`00<0bK^`0<Zk/@3;^k000`3;^k030<^l/0<0c;b`0`3=_K401@3=_[40
c[jb0<jn/@3>_[40cknb00@0d;nc103@`;<00`3A`K<0d/:d0=?2]0020=?2]@D0e<>e00@0eL>e0=G4
]@3Ea;D0e/Bf0P3Fa;L0103GaKL0d/2c08MmL`0F51820000000400h<301FCdT0YiR=0=?0/P<0g<Rj
00D0gLVj0=[6^03A_k40W8j3048l=`1I000000`0oooo000:0?ooocL0000000<00?l000000000o`00
P00000001011>SX0ThJ60;^ZZ035];820<Je]0030<Je/`36];<0a[Bb0080a;>a00<0`k:a0<>b/035
/k400`35];800`35];40a;Ba0<Bd/@050<Bd/0@0a;F`00<0aKF`0<Je/036][401037][450<Ng/@04
0<Rg/@38^;40b;Ra0<Vh/P80b[Vc00@0bkZd0<fk]@3;^[<0b;R`1`37^;002`37^K00b;V`0<Vi/039
^[00bKZa0<Vj/039^[40b[Za0<^k/@3:^k40bKZ`00@0bKZ_00@0bK^`0<Zk/03:^k00bk^a0P3;_;40
2@3;_;00c;b`0<bl/03<_;40c;fa0<fm/@3=_K80cKfa0<fn/@020<jn/@030<jn/P3>_k80cknc00<0
d;nc0`3@`;<0103A`;<0dL6c0=;1]03C`[@20=?2]@D0e<>e00D0eL>e0=G3]P3Ea;H0eLBf0=K5]`02
0=O5^0040=K3]P2YVY00<Bh[00410@80000000@00`<301TF5P1>Ad<0]:BH0P3Lb;X01P3LbKX0gLVj
0<BcYP2:OWD0BD<n01TF5ET00000303oool000X0oooo=P0000001@00o`0000000000000000000?l0
07l0000000L0FU=A0;2QW`36]K<0akJd0<Je/`36];<0aKBc0080aKBb00T0a;Bb0<Bd/@33/[00_jn]
0;NXY@2jZZP0`K6^0<Fd/P34]K801034];450<Be/@80aKFa00<0aKJa0<Jf/@37][400`36][460<Ng
/@<0b;Ra00L0b;Rb0<Vi/P3:^K<0c;Zd0<fl]P3:^[<0b;R`00H0akR`0P38^K001P39^[40b[Za0<Zj
/@39^[40b[Z`0<Vk/@@0b[Za0`39^[001@39^k00b[^`0<Zk/03:^k00bk^`00D0bkb`00D0c;b`0<bm
/@3<_K40cKfa0<fn/P020<fn/@040<jn/P3>_k80d;nc0=2o/`<0d<2c0P3@`;@0103@`K@0dL6d0=;2
]03B`[D20=?2]@<0e<>f00@0e<>e0=C3]P3E`kH0eL>f0`3Fa;H30=S5^0030<bj[P1MEE001`H600D0
000000<09R8P09b=P`3LbK/00P3LbKX01@3C`;80VXb203D`;@0;2PX00`<205T00000303oool000X0
oooo4`0000060000oa`000000`00o`00100000000?l0003o0000o`1n0000000306YQH02lZjX0akJd
0080a[Fc00@0a[Bc0<Fd/`35];<0aKBb0P34/k401@33/k00`;2]0;VZY`2_XIh0^j^X0080aKFb0`34
];460<Be/@80aKFa00D0aKJa0<Ng/P37]k80a[Na0<Jf/@020<Jg/@80akNb00<0b;Nb0<Rh/P38^;80
0`38^;801`39^K80b[Vc0<^j/`3<^kD0cK^e0<Zj/`38^K401@37^;001037^K00b;V`0<Ri/039^[49
0<Zj/@L0b[^a1P3;_;40103<_K40cKfb0<fm/P3=_[830<jn/P030<jo/P3@_k@0d;nd00H0d<2d00<0
dL6d0=72]@3C`[D00P3C`[D50=C3]P070=G3]P3Ea;H0e/Bh0=K5^03GaKP0elFi0=S6^@020=W6^@03
0;b[X00f<Rh0000000D0000000<06aTG06iUGP2aXIH00P2fYi/00`2QThL0HEQB018@3`1K000000`0
oooo000:0?oooa<0000000<0003o0000000000000P0000000`000?l000000000002K0000000900@3
0`0?3Ph06QPH01XH6025NGT0`K6_0<Ne]036]K<0aKBc0080aKBb00`0a;Bb0;n_[@2n[Z`0`K6_0<2a
[P2o[j`0`k>`0:jOW@2fYj@0aKFb0<Be/@34];460<Be/@<0aKFa00D0aKJa0<Jf/@37]k80akNb0<Jg
/@020<Jf/@040<Jg/@37]k40akNa0<Rg/PD0b;Rb00L0bKVb0<^k]03<^kD0c;^e0<fk]@3:^[<0akVa
00@0akR`0P37^K020<Ri/0030<Vj/@3:^[40b[Za00D0bKZa0`3:^[460<Zk/@@0bkba0P3<_K420<bm
/P070<fm/P3=_[80c[jb0<jn/P3>_k80cknc0=2o]0060=30]0050=31]03A`K@0d/:f0=?2]P3C`kH0
0P3D`[H40=C3]P030=G3]P3FaKL0elFh0080elFi0P3Ia[X0103IakX0fLJi0;:RU`0e<2d600000003
00d<2`0]:BH0BdE00080C4E000<0>cHb01`J60000000F`00000<0?ooo`002P3ooolD00000080003o
X0000000200>3@d0>3<c05iFEP1NEUH0ZifK0<Fd/P36]K<0a[Bc0`35];<02P35];80]:FS0:ZLVP2e
YZ@0]jNU0;JWY@32/k00^JZW0;b]ZP32/k020<Bd/@H0a;Fa0P35]K420<Ff/@040<Jg/P38]k<0akNb
0<Jg/P80a[Na0`37]k840<Rh/P80bKVb00<0bKVc0<bl]@3<^kD00P3<^kD01@3:^[<0b;Vb0<Nh/@37
^K00akR`0080akV`0P38^K000`38^K40bKZa0<Zj/@040<Vj/@<0b[Za0`3:^k420<^k/@030<^l/@3:
^k40bkba00<0bkba00D0c;fa0<bm/P3<_K80c;fb0<fm/P020<fn/P050<jn/P3>_k<0cknc0<no/`3?
_k@01@3@`;@00`3A`K@0dL:d0=;2]@020=?2]P80e<:f0`3D`kH00`3E`kH0eLBf0=K5^0020=S5^@03
0=S5^P3Ia[X0fLNj0080f/Nj00<0cK^_08n2NP0P7A/0J@00000<0?ooo`002P3ooolF000000030000
o`000000000009d0000000H081dM07I/K02[WI`0ZifL0<>b/@36]K@60<Fd/`050;FUY02RU9<0Wi:A
0:fOW@2k[:T00`33];400`34]K80a;Fa0<Be/@040<Be/@070<Fe/@35][40aKJa0<Jf/@36][80akJb
0<Ng/`070<Ng/P030<Nh/P38^;80b;Rb00<0b;Rb00@0b;Vb0<Vi/`3<^kH0c;^f0P3<^kD0103:^[<0
b;Vb0<Ri/@38^K820<Ni/@030<Ri/038^K40bKVa00L0bKZa2@3:^k440<^l/@040<^m/@3<_K80c;fb
0<bm/P<0cKjb00@0c[jb0<jo/P3?_k<0cknc0P3?_k@30<o0]080d<2d00D0dL6d0=;2]@3B`[H0dl:f
0=?3]P050=C3]P050=G4]`3FaKT0elFj0=S5^P3Ha[X00P3Ia[X01P3JakX0f/Nk0=[7^`2jZil0KF=M
00d<2fT00000303oool000X0oooo5`0000000`000?l000000000002L0000000503Xe=@2VUiL0a;Bb
0<Bd/P36]K@00P35];<30<Bd/`80a;Bb00H0_jj]0;ZZZ02kZjT0`;2^0<>c/@34];490<Be/@<0aKJa
00D0aKJb0<Jf/P36][80a[Jb0<Ng/P020<Jg/PD0akNb00<0b;Rb0<Ri/P38^K800P39^K800`36^:l0
akR]0<^k]@020<fl]`030<bl]@3:^k<0b;Vb00<0b;Va0P37^K400`38^K40bKVa0<Vi/@060<Vj/@H0
b[^a1@3;_;400`3;_K40c;fa0<bm/P030<bm/P80cKjb00<0cKjc0<jn/`3>_k<00P3?_k<00`3@`;@0
cl2d0<o0]0030<o0]0050=30]03A`K@0d/:e0=?2]P3C`kH01@3D`kH0103E`kL0e/Bg0=O6^P3Ha[X3
0=W6^P060=W7^P3Jak/0f/Nk0=[8^`2aXYP0F55<JP00000<0?ooo`002P3ooolC000000030000o`00
000000000080000000<0003o000000000000V00000001@051@D040l?01/I6@1UG5`0_:b[0080aKFd
00<0aKBd0<Fd/`34];<01034];<01035];<0`k>b0<:b/033/k440<>d/@030<Bd/@34]K40a;Fa00H0
a;Fa00@0aKJa0<Ff/P36][80a[Jb0P36]k870<Ng/P090<Nh/P38^;80b;Rb0<Rh/P38^K80bKVb0<Fh
[034^:T0bkfd0080c[fh00<0cKbf0<Zj/`38^K800P38^K830<Ni/@030<Rj/@39^[80bKZb00<0bKZb
0P39^[420<Zk/P@0b[^a103;_;801P3<_;80c;fb0<bm/P3<_K80cKfc0<bm/P80cKjc00<0cKjb0<fn
/`3>_k<00P3?_k@00`3?_k<0cl2d0<o0]0050<o0]0030=30]03A`K@0d/:e0080dl>f0P3D`kH30=G4
^0040=K4^03HaKX0f<Jj0=S6^P80fLJj00L0fLNj0=[7^`3Jak/0d;nc0;b/X@2BQWh0BD<o06X00000
303oool000X0oooo4`0000060000oiX0000000D04a8B03`g=`1RFUX0W8n?0<>c/P020<Fd]0030<Fd
/`34];<0a;Bc00D0a;Bc00<0`k>a0<:c/@33];801033];480<Be/@040<Ff/@35][80a[Jb0<Jf/P<0
a[Nb1@37]k820<Nh/P040<Rh/P38^K80b;Vb0<Ri/P80bKVc00L0aKJ]0<BfZP3>_KL0ckfh0<jm^03=
_KH0b[^c00<0b;Vb0`37^K400`38^[40bKZb0<Vj/P040<Vj/@030<Vk/@3:^k40b[^a00@0b[^a00D0
bkbb0<fn]03=_[@0cKjc0<fm/`020<fn/`030<jn]03=_[@0cKjd00<0cKjc0P3>_k<80<o0]080d<2d
00@0d<6d0=71]@3B`[D0dl>f0`3D`kH0103Ea;P0e/Fi0=K5^@3GaKX20=S5^P80fLJj0P3Iak/20=[7
^`040;f]XP1kLFT0D4U402PU8VX00000303oool000X0oooo/`000000100Z:2P0O79b0:jOW`31/K03
0<Fd/`T0a;Bc00@0a;Bb0<>d/P33];80`kFb2034]K801034][80a;Fa0<:c[`33];040<Jf/P040<Jg
/P37]k80akRc0<Nh/`<0akRb0`38^;820<Ri/P050<Vi/`3:^[@0`:fX0<6/Y`3@_[T00P3?_[P00`3=
_KH0b[^c0<Ri/P020<Ri/P<0akVa00D0b;Za0<Vj/P39^[80bKZb0<Vk/P060<Zk/P050<Zl/@3:_;80
bkbb0<bm/`3=_kD00P3>_kD30<jn]0030<no]@3?`;D0c/2e0080c/2d0P3>_k@00`3?`;@0cl2e0<o0
]0020=30]0L0d<6d00<0dL:e0=;2]@3B`kH00`3C`kH00`3Ea;T0elJj0=S6^`020=S6^`030=W6^`3I
akX0fLNk00<0fLNk00D0f/Nk0:VKT@0j=C803Pd<00L61P1Z000000`0oooo000:0?oook<0000000@0
:RPX07abLP2^Wil0`K6`0`35];<90<Bd/`040<Bd/P33];80`kBb0<>e/PP0a;Fb00@0a;Jb0<Be/@32
/jl0`kB`1036][801036]k80akNb0<Nh/`37^;<30<Nh/P<0b;Rb0P38^K801@39^K<0b[Zd0<2]Z031
[:L0d;ji0080ckjh00<0cKff0<Zk/`38^K800P38^K830<Ni/@050<Rj/@39^[80bKZb0<Vj/P39^k80
1P3:^k801@3:_;40b[bb0<^l/P3<_K<0cKne0080c[ne0`3>_[@00`3?_kD0cl2e0<k0]@020<k0]080
c[nd00<0cl2d0<o0]@3?`;@00P3@`;@70=31]0030=72]@3B`[D0d/>f00<0dl>f00<0eLBi0=O6^P3H
a[/00P3Ha[/00`3Ia[/0fLNj0=W7^`030=W7^`050=[7^`2YVi40>SDb00h=30071PH0JP00000<0?oo
o`002P3ooon`0000000700<20P0>3@d06ALG05M@D02^X9l0a;>c0<Fe]0070<Bd/`@0`kBb00<0a;Bb
0<>d/P33];400P33];830<>e/P040<>d/@33]K40`kFa0<>e/@80a;Fa00@0`K>_0<2a[P35][80a[Jc
0P36]k<00`36]k80akNb0<Ng/P020<Ng/P80akRb00@0b;Rc0<Ri/`38^K<0b;Vc0P39^K<20<Zj]008
0;VSW`2_ViL0d;nj0<nn^@3?_[P0cKff0<Zk/`39^[820<Ri/P040<Rj/P37^[40b;Za0<Rj/P@0bKZb
0P3:^k800`3:_;80bkbb0<^l/P030<^l/P030<bm/`3>_kD0c[ne00@0c[jd00<0ckne0=30]@3@`;D0
0`3@`;D00`3?`;D0d<6e0=30]@030=30]@040=31]@3@`K@0d<6d0=31]0<0dL6d00@0dL6e0=;2]@3B
`[D0d/>f0`3C`kH00`3Da;L0elFj0=W7^`080=W7^`030<^k[`2<P7P07a`K06`00000303oool000X0
oooo[P0000002@0:2@T05A<C02HS8`18@D40Jf9R09f@T031/K00a;Bc0<Fd/`060<Bd/`T0`kBb1033
]K802033]K40`kFb0<>e/P34]K80a;Fa0<Bf/@33];00a;Fa1@36]k<00`37]k<0akRc0<Nh/`020<Nh
/`030<Rh/`39^K@0bKVd00@0b[Zd00D0b[^e0<Zh/`2nZ:<0YYB@0<:b[@020<jm]`050<fm]P3:^k<0
bKZb0<Vj/P38^[801@39^[830<Vk/P030<Zk/P3;_;<0bkbc0080bkbc0P3<_K<0103<_[@0cKjd0<jo
]@3>_[D20<fn]0030<jn]03?_kD0d<2f0080d<2f00H0dL6f0=31]P3@`KH0d<2f0=31]P3@`KD20=30
]@D0d<6e0`3A`K@00`3A`[D0d/:f0=;2]P020=;3]P80dl>f00@0e<Bh0=S6^`3Iak`0fLNl103Iak/0
1P3Jb;`0aKFZ0;6RV02BQWh0ETm:00h=3240000000@05Q@C034/:@0X92803@`;A`00000<0?ooo`00
2P3ooon^0000000702HS8`1?BDT0N6i^09Z=S@2eYjL0`K:b0<Fe]0020<Bd]0030<Bd/`33];<0`kBc
00<0a;Bc2@33];830<>e/P060<>d/@32];40`kFa0<:d/02n/:`0`[B`0`34][820<Ff/P80a[Nc00<0
a[Nb0<Ng/`37]k<00P37^;<00`38^K<0bKVd0<Vj]@020<Zj]@0<0<Zj]03:^k@0b[^d0<^k]@3<^kH0
b[Nb0<:`Z`2jZjH0b[Ze0<jm]`3=_KH0b[^c0`38^[840<Vj/P<0bK^b00T0b[^b0<^l/`3=_[D0c;jd
0<bm]03=_KD0c[je0<o0]@3>_kH00P3>_kD01@3>_[D0cKjd0<jn]03>_kD0cl2e0080d<2f00@0d<6g
0=71]`3A`KH0dL6f0`3@`KH00`3@`KD0d<2e0=31]@020=31]@D0dL6e0P3A`[D01`3A`[H0d/>f0=?3
]`3C`kL0dlBg0=G4^03GakX00`3Iak`20=W7^`060=W7_03Jb;`0VXj505]CCP0`;2T05aDD60000000
1`0@3Pd0<2`Y03li=P0N71X00P8202<P7P13?ST00P18@Cd01@0c;R/0BT<n08=hK`1ZHEX0924O04L0
0000303oool000X0oooo[@0000001@010@40D4Y:09>7QP2jZj/0`K6a00T0a;Bd0P33];<20<:d/P03
0<:c/P32];80`[Bb00<0`[Bb0`33];802@33]K40`[Ba0<:d/@32];00_:jZ0;6SX033];40a;Jb0<>e
/P020<Bf/@040<Bf/P35][80a[Nc0<Jg/`@0akRc00<0bKZd0<Zj]@3:^[D00P3;^[D0103;^kD0c;^f
0<bk]P3=_KL20<nn^@070<fl^02dYJ40^Z^U0<fm]`3<_KL0b[^c0<Vj/`020<Vj/P<0bK^c0P3:^k<2
0<Zk/P0:0<^l]03<_K@0cl2f0<no]`3?_kH0dL2h0=70^@3@`;L0cl2f0<no]P80cl2f0P3>_kD0103?
`;H0d<2f0=30]P3@`;H40=71]`@0d<6f00D0d<6e0=71]@3A`KD0dL6e0=71]P020=72]P80dL:e0P3A
`[H01`3B`[H0d/>g0=?3]`3Ca;L0e<Bg0=K5^@3Hak/00P3Iak`20=W8_0050=O6^P3B`KD0b;N/07E/
I@0U8R005`0000004P0920P04a8@01XI5P1KE4d0YIJ=0;VXW02;P7L0IUiG09>6O@30[j<0a[BX0<:a
Y02=PGP0OG9Z0<bi[02kZYh0Fe==00P71dH00000303oool000X0ooooZ`0000001`081`L04a4A020M
7@23NGT0^Z^[0<Fe]P35]K@01034];@00`33];@0`kBc0<>d/`020<>d/`040<>d/P32];80`[Bb0<:c
/PL0`[Bb0P33];802@33]K40`[Ba0<:d/@32];00`;6^0<6b[P34][80`kFb0<>f/P040<Bf/P80a[Nc
00@0a[Rc0<Nh/`37^;<0b;Vd103:^[D20<^k]P80c;bg01H0cKjh0<nn^@3@_[X0ckji0:bNVP2>PGh0
c;bf0<fm]`3:^k@0bKZc0<Vj/P39^[<0b[^c0<^m]@3<_KD0bkfe0<^m]03;_;@0c;fd0<bm]@3=_[H0
ckng0P3A`;T20=;1^P030=31^03@`;L0d<2g00@0d<2g0`3@`KL80=71]`@0dL:f0`3B`[L00`3B`kL0
d/>f0=;2]P020=;3]P80d/>g00H0dl>g0=?4]`3Da;P0e/Fi0=S7^`3Iak`30=[8_0050<Vi[P2UUhh0
NFiX04Do>`0F51<05`0000004P0b;B/0KfEO08QlM@2kZYl0gl^o0>C?`P3Kb;/0e<6e0=g:_03Ud<80
iM730>??`@3;^Zd0^j^N0=c9^P3LbKT0S81f02HR80<0924N00<05Q@C00H61@000000@000000<0?oo
o`002P3ooon[0000000601`J6P16@D40KfIV0:jPX@33];@0aKFe0`34];@00`33];@0`k>d0<>d]003
0<>d/`80`[Bc00<0`[Bb0<:c/P32];800P32];800`32];40`[Bb0<:d/P020<:d/P090<>d/P33]K80
`[Ba0<:d/@33]K40`kFb0<Bf/`36]k@0a;Jb0080`kJb0`34][801035]k80a[Nc0<Jg/`36^;<20<Nh
/`070<Ri]03:^[D0b[Ze0<Zj]@3:^kD0bk^f0<bm]`020<fm^00A0<jn^@3?_[T0d;jj0=2n^`2dYJ80
LfYW0<2`Z`3=_KL0b[bd0<Vk/`38^[<0bK^c0<^l]03>_[L0ckjh0<jn]`3=_KH00P3<_KD02@3=_kH0
ckng0<o0^03A`;T0d/6j0=?2^`3A`KX0dL6i0=30^00:0=71^0@0dL6g0P3A`[L80=;2]`030=;3]`3C
`kP0d/>g00<0d/>g00@0dlBh0=C5^03EaKT0elJj0P3Iak`30=[8_0050;FVW01/I5h08QlM01@B4@06
1PD05`0000002@1QF5<0cK^_0>7>`@3Td<<0i<o20>C@``3Scl80h/k10>?@`P020>GA``070>C@`@3Q
cKl0h<fn0>CA`@3QcKh0XYB907M]I@0209j@Q@0309N:P01MEDl05aDC04400000303oool000X0oooo
Z`0000001@0m>3P0RGin0;JXZ032/k<0a;Fe00@0a;Bd1033];@20<>d/`80`[Bc1@32];820<:d/@03
0<>d/P33]K80`kFb0080`kFb00@0_Jn/0;na[P32];40`kBa0P35][<01034][<0a;Jb0<Bf/P34][82
0<Bg/P070<Fg/P36^;<0akRc0<Nh/`38^K<0b;Vd0<Vj]@020<Zj]@030<Zk]@3;^kH0c;bg00<0cKfh
0100c[ji0<nn^@3@_[X0d;jk0<^j]@2UUY80^JVV0<fm]`3<_KD0bkbe0<Zl]03;_KD0cKjf0<no^03?
_kT0d;ni103?_kP00`3?`;P0d<2h0=70^@020=;1^P030=;1^@3A`;T0dL6i0080dL6i203A`KP40=;1
^0<0d/:h103B`[L00`3C`[L0dl>h0=?3^0020=C4^@050=?4^@3B`kL0dlBg0=C4^03EaKT00P3Ga[X0
203Ha[/0elJk0<^j/02bY9/0ZijD0:ZLT`27OGD0AD0l5`000000200410<0;2TV05=<A`1iKfP0_jnT
0=k;_`3Vd/D0iM;41@3UdL<0203Rcl00hLjo0>??`03Sd<40i=720=W7^02aXYH0cK^]0`3Vdl<00`2f
YYX0AT0k00@41010000000`0oooo000:0?ooojP0000000T01@D5010?3`0K6AT0K6AT0;>UY@35]KD0
a;Fe0<Bd]@34];@01P33];@40<:d/`030<:d/P32];<0`[Bb00D0`[Bb00<0`[Fb0<>e/P33]K800P33
]K80102fZJH0^jjZ0<2c[`32];020<Ff/`030<Bf/`34][80a;Jb0080a;Jb00L0a;Nb0<Fg/P36^;<0
a[Rc0<Nh/`38^K@0bKZe0080b[Zf00<0b[^f0<^k]`3;_;L00P3<_;L20<fm^00>0<jn^@3?_[X0d;jk
0=6o^`3A`;`0bkZf0;f]Z03<_;H0cKfg0<bm]@3<_;D0c;fe0<fn]`3>_[L20<no^0030=2o^@3@`;T0
dL2i00P0dL2i00@0dL6i0=;1^@3B`KT0d/6i1P3A`KP90=;2^00C0=?3^03C`kT0dl>i0=C4^@3Da;X0
e/Fk0=O5_03Ga[/0eLFj0=?4^@3EaKT0e/Jk0=O7_03Hak`0fLNl0=W8_@3=_K80W8n705aED00205QA
C00304I1?@0T8Al0000001H0000000T02@P705iFD@2aXYP0RWmg0:BES03D`[D0^ZVO0;:RV03C`KD0
0P3UdL<0403Ia[T0bkZ]0=G3]03E`kD0]jRK0<JeZ03Nbkd0flRj0=G3]@3Rc[l0iM;20>KB`P3Ud/80
dl6b06iTG00:2@T90000000401DC4P0g<bh0@cdh01lL6S<00000303oool000X0ooooYP000000200=
30`06QPH038^;P1>B4P0JV9R0::EU@31/[80a;Ff0`34];@50<>d]00?0<>d/`32];<0`[Bc0<:d/`31
/k80`KBb0<:d/P32];<0`kFc0<Be]033]K<0a;Fc0<>e/`32]K80`[Bb0080`[Fb00D0`kFb0;nb[P30
/k00`[Fa0<:e/P020<Bf/`<0`kJb00L0a;Jb0<Bg/P34]k80aKNb0<Jg/`36^;<0akRd0080bKZe0P3:
^[H00`3:^kH0bkbg0<bl]`020<bl]`80cKfh0P3?_[X20=2n^`80dL2l00<0b;Rc0<Zk]@3=_KL00P3=
_KH01@3=_[H0cKjg0<jn]`3>_[L0cknh00H0d<2i103A`;T40=71^@H0dL6h0P3B`[P30=72^080d/:h
0P3C`[T20=?3^@80e<Bj00D0eLBk0=O5_03Ha[d0f<Nm0=O7_0020=K6^`090=O6_03Hakd0f<Nm0=S7
_@3Iakd0fLRm0;b]X`1WGeT02PT900801`H600<01@D500<20P0000005P0000002@0820L0G5E?0:nP
UP1iKfP0JEmJ08=hL@1UFeH0Ng5Z0<FeZ@020>CA``070=?1]02n[J40c[f_0<nn[`2]WY80b[R[0>7>
_`030>GA`P080>GA`@3Ud/40iM;20>?@`02FRGl0;2TV01@B4@051@@70000000402l[9`1lLFP0U8Ql
04@o>S<00000303oool000X0ooooYP0000002@0S8200Ad9207E/K02GRX/0/Z>T0<6b/P34]KH0a;Fe
0<Bd]@060<>d]0030<:d/`32];@0`KBc0080`K>c00D0`K>b0<6c/@31/k40`[Bb0<Be/`020<Ff]@05
0<Fg]P34]k@0`kFc0<:d/P32]K800`32]K420<:e/P030<>f/P33][<0a;Jb00<0`kJb00L0a;Jb0<Bg
/P34]k80aKNb0<Fh/`36^;<0akRd00<0b[Zf00<0b[^f0<^l]`3<_;L00P3<_;L00`3=_KP0cKji0<fn
^@020<nn^P80d;nk0P3A`;`01@3A`;/0c;fg0<bl]P3=_KH0cKjg0080c[jg00<0c[jh0<no^03?`;P0
2@3@`;T30=31^@<0dL6i1@3A`KP50=72^0060=;3^@3C`kT0dl>j0=?3^P3Da;/0eLFl0`3FaK`00`3H
a[d0f<Nm0=W7_@030=W7_@@0fLRm00D0cKjc0:NJT@1fKFL0?3Pd00820P0K0000000900@30`0X9B<0
EDi:06MOF@2>PWX0V8^209N:PP2ZVi40dL2d0080i=7300H0h<jo0=o=_P3Qckl0h/jo0=_8^P3Rc[l4
0>GA`P080>GA`@3Ud/40iM;10>CB`@37]jT0VHb105UBC00D4Q420000000300H51@0Q7a`0?CPd0080
?CPd00L0D4U308YoM02VV8/0HUYB02HR800D4Q000P8201T0000000H010@400h=2`0D4Q00518@00X:
20010@4A000000`0oooo000:0?ooojD0000000D00`8304U4A02:P800^:VZ0<2a/P020<Be]@030<Bd
]@33];D0`kBd00H0`kBd00<0`[Bd0<:d/`31/k<00P31/k<01031/k80`K>a0<6c/P31];860<>e/`04
0<:d/P32]K80`[Ba0<:e/@80`[Fb1`33][802P34][80a;Nb0<Bg/P34]k80aKNb0<Fh/`36^;<0bKZf
0<Zj]P3:^kL20<^l]`040<bl]`3<_;P0cKfh0<jn^@80c[jj0P3?_[X00`3@_k/0d;nl0=2o_0020=70
_0060<no^@3;_;D0c;bf0<fn]`3>_kP0c/2h0P3?`;T00`3@`;T0d<2j0=30^P030=70^PX0dL6i0P3A
`KP00`3A`KT0dL:i0=;2^@050=;2^@050=;3^@3C`kX0dl>j0=C4^`3EaK/00P3FaK`01@3GaK`0elJm
0=O6_@3Hakd0fLNn0080fLNm1@3Ib;d01@2gZIl0GeQC038_;00J61H00@4101d0000000<061HE07id
K03Qc/400P3Rcl820>?@`P80i=730P3TdL800`3Rd<40gLZl0>3=_`040>GA`P80iM;20`3Ud/40103T
d/80i=710<:bY01aJ602040k=P0<06EME@2SUHT0_jnQ0;JVV@2cY9H0TXIj07icJ@28OG80UXYn09:6
N`1:@ch020P75P0000001@0>3@`08AhK02/X8`0n>C<0I5aB0080MFaO00<0>3@^00D5100000004000
000<0?ooo`002P3ooonS0000000500X92@0G5AD0:bTY07edM02dYZL00P35][L01034]KH0a;Fe0<Bd
]@33];D50<>d]0040<:d]032];<0`KBc0<:d/`<0`KBc0P31/k860<6d/P030<:e/P32]K<0`[Fc0080
`[Fb00D0`KFa0<:e/P32]K80`[Fb0<>e/P030<>f/P@0a;Nc0`34]k801@35]k80aKRc0<Vj]@3:^kL0
b[bg0080bkbg00<0c;bg0<bm^03>_[T00`3>_[X20<nn^P0:0=2o^`3@`;`0d<2l0<o0^`3@_k/0ckni
0<bm]P3:^k@0c[jg0<no^@80cl2i0P3@`;X00`3A`;/0dL2j0=70^P030=70^P030=;0^P3B`KX0d/6j
00@0d/:k00@0d/:j0=72^@3A`KT0dL6i0`3A`[T00`3B`[T0dl:j0=?2^P020=?3^P80dl>k00H0e<Bk
0=G4_03FaK`0e/Fl0=O5_03Ga[`20=O6_@030=S7_@3Iakh0fLNn00D0fLRm00<0e/Fk0:NJT@0[:2D0
6@0000000`010@405QDC02`Y9P0402l[:00=048m>@2ER800hm330=[7^`3IakX0fLNi0=o<_P3Mbk`0
c;b_0<nn/@3Oc;h0hLo00>?@`@040>GA`P<0iM;21@3Ud/401`3Rd;l0d/2a0;Z[W02jZi`0aKJV0=o=
^`3Vdl400P3Udl401`3Ha[D0akRW0<JfYP3C`K40h<fl07ebJ@0>3@`04@0000002P0<2`X081dJ02TU
8P0D4a40000002dY9@1XH5H0R7i`09V>OP2iZiP20<ZkYP0306MOE00:2@P0000001000000303oool0
00X0ooooX`000000200Q7al0CdU907idM@2]X:40`[Bd0<Ff]`34]KH0a;Fe0`33];D00`33];@0`[Bd
0<:d]0030<:d]0030<:d/`31];<0`KBc00<0`KBc00<0`[Bc0<6c/P31];801031];801@31]K80`KBb
0<:e/P33]K<0`[Fb0080`KFb00<0`[Fb0<:e/@32]K400P32]K401`32][80`kJb0<Bg/`36^;D0aKNc
0<Bg/`34]k800P34]k<20<Fh/`070<Vk]P3:^kL0b[^g0<Zl]`3;_;P0c;fh0<fm^@040<jn^P0<0<no
^P3?_k/0d;nl0=2o_03?_k/0c[ni0<jn^03=_[P0cKjg0<bm]P3>_kL0ckni0`3?`;T0103@`;X0dL2k
0=70^`3A`;/60=;1^`@0dl:k00<0d/>k0=;2^P3A`[T00`3A`[T0103B`[T0dl:j0=?2^P3B`kX30=?3
^`050=?4^`3Da;`0e/Fl0=K5_03FaKd0103Ga[d20=S7_P<0fLRn0P3Ib;d0103Hak`0b;V_08QkM@0I
5aHI0000000301LE501^IEl0ZI^B00@0[YnF00D0]:BK0<bk/03Sd<<0f<Nk0=S6^@020>CA``060>CB
`P38^:/0Z9Z?0;RYWP3KbK/0i=320`3TdL840>GA`P80iM;100@0iM?10>GB`@3Ud/40iM;1203Udl40
2P3Td/00i=:o0>CB_`3Udl00i=6o0;>TUP1iKfD0D4U302DS7`092@P:0000000;00410@030P800`<3
01HD4P1ABd<0Rh1c09f@P@1cJUl0BT@m07edI`2k[IX00P3Ue;d01@3JbK<0^Z^H0;Z[V01DCDD02@T8
01400000303oool000X0ooooX`0000001`16@400TXR90;f_/033];D0a;Jf0<Be]P34]KD00`33];D0
1032];D0`K>d0<6d]031];@20<:d]0030<6d/`31/k<0`K>c00@0`KBc0P31];840<2d/P80`KBb00<0
`KFb0<:e/P32]K801031]K800`32]K80`[Jb0<>f/P020<>f/P040<Bf/`36^;D0akVf0<Fh/`80a;Nc
00@0a;Rc0<Fh/`35^;<0a[Rd0P3:^kL01@3:_;L0bkbh0<^m^03<_KP0c;fi0080c[jj0P3?_[X01P3?
_k/0d;nl0=30_@3@`;d0c[nk0<fn^0@0cKjg00<0c[nh0<o0^@3?`;T00P3?`;T00`3@`;X0dL2k0=70
^`020=70^`<0dL6k0P3B`K/00`3B`[`0d/:k0=;2^`030=72^P<0dL:i00@0d/:i0=;2^P3B`[X0dl:j
0`3C`k/01@3Ca;/0e<Fl0=G5_03FaK`0e/Jm00D0elJm00<0f<Nn0=S8_P3Hb;h00`3Ib;h01@3Hakd0
c[jd09R;Q01;@Sl01`L601L0000000D00@4100P71`0o>SL0^ZZP0>?@a0020>KBaP080>GAa@3Sd<<0
hm330>?@``3SdL@0hm330>;@`P3TdL<20>CB``040=c:^`2jZih0/J:G0=S6^080i=;2103TdL800`3U
dL80iM;20>GB`P020>GC`@@0iM;11P3Udl402`3Td/00hm6o0>?A_`3Sd[l0i=:o0>GB`03Pc[`0f/Rf
0<2aX024NVl0:RLS00@0000000<00`<2010>3@0L6QL00`0M6QP02`11?3H0MVeS09:7NP2GRgd0_JjL
0=[9]@3QckX0d/:^0<FeXP3?_j/0elNb0080iMBm00H0fl^e0;6TTP2aY980MVeQ03/g<@0?3P`@0000
00`0oooo000:0?oooj80000000L00@4106AMGP2eYjP0aKJg0<Bf]`34]KL0a;Ff0080`kBe0P32];D0
0`32];@0`K>d0<6c/`020<6c/`80`KBc00<0`K>c0<6d/P31];800`31];860<2d/P80`KBb2031]K82
0<:f/P80`kJb00@0`kJc0<Bh/`35^;@0aKRc0P34]k<02@35^;<0a[Rd0<Jh]036^K@0b[^g0<Zl]`3;
_;P0bkfh0<bm^0020<bm^@80c[jj0P3?_k/30=2o_0030=30_03>_kX0cKjh00<0cKjg00<0cKjh0<jo
^03?`;X00P3?`;X00`3@`;X0dL2k0=70^`030=71^`<0d/6k103B`[/00`3B`[X0dL:j0=72^@030=72
^@030=72^P3B`[X0d/:j00<0d/>k0P3C`k/00`3Da;`0e/Fm0=K5_@020=K6_@<0elJm00<0elNn0=S7
_P3Hb;h00`3Hb;h01P3Ib;h0fLRm0=30]P2ISHH0?SPe01DB4AH0000000H051<B02TV900g<bl0HUYD
0:FGSP3LbKh20>GBaP80i];600H0iM;50>CBa@3Td/D0i=740>CBa03Sd<830>CA`P040>?A`P3Rcl00
hLo00>?@`@<0i=;20P3Ud/820>CB`P80iM;200H0iM;10>CB`@3Ud/80i=;10>CA`@3TdL020>CB`0<0
iM?100<0i=;00>?A_`3Rd;h00P3RdKh0203SdKl0i=;00>GC`03Udl00iM:o0=;1/01fK6<0>CD`0`0j
=C002`14?SP0K6=I09J:O@2KSh40Uh]n0925M`2eYiL0f<Nc0=o?^P3NcKP0hM2k0080iM>m00@0i=:l
0>?A_03Td[`0i=:l0P3Ue;d01P3RdK/0d<6/0=31[02o/Ih0LFQM01dK61000000303oool000X0oooo
X00000002P030`<051<C02TV9P2<PX<0`;>c0<Ff]`34]KL0`kFf0<>e]@33];D20<:d]@030<:c]@31
/k@0`K>d0080`K>c0`31];<30<6c/P<0`KBb1`30];880<6e/P030<6f/P32][80`[Jb00<0`kJb00<0
a;Nc0<>g/`34]k<00P34]k<01035^;<0a[Rd0<Jh]037^KD20<Zl^0030<bl^03<_KP0c;fh0080c;fi
00H0c[jj0<no^`3?_k/0cknk0=2o_03@`;`20=30_@040<jo^`3=_[T0cKjg0<fn^080c[ni00D0cl2i
0<o0^P3?`;X0cl2j0=30^P020=70^`<0dL6l00<0dL:k0=71^`3A`[/0103B`k`20=72^P@0dL:i0P3B
`[X0103B`kX0d/>k0=;3^`3C`k/20=C4_080eLFm0P3FaKd20=K6_@<0elJm1P3Hb;h0103Fa[/0/jFM
04I0?P030P8C0000000:018<2`0h;b`0>2l/04m8A01hKVP0XiF=0;:SVP3<^k00h/o30>CAa@@0iM;6
00@0i=750>?Aa03SdL@0hm740P3TdL@30>CA``030>CB``3Td/80i=;200@0i=;200@0i=;30>GB`P3U
d/80iM;20P3Td/830>CA`@<0i=700P3Td/001@3Ud/00iM?10>GC`@3Td/00hm6o00<0h]6n00<0hm6o
0>CB`03Td/000P3Ud[l03`3SdKh0cKf/0;VZV`2hZIX0]ZRH0:^NS`2]WY00b;VW0>7?^`3Td[d0hm6m
0>;@_03Sd[d0i=>n0>?B_@030>CC_@080>CD_@3Ue;h0iMBn0>GC_@3Tdk`0hm6l0=k=]`38^J@20;2S
T@030;2RT@1XH5H06aTF01000000303oool000X0ooooX00000002@0B4100C4M7085gN@2fZJX0a;Jf
0<Bf]`33]KH0`kBf0<>d]@020<:d]@030<6c]@31];@0`K>d00<0`K>d00D0`KBd0<6d/`31/k<0`;>b
0<6c/P050<6d/P<0`;Bb1031]K800`32]K80`[Fc0<:f/`030<6e/P040<6f/P32][80`[Jb0<:f/P80
`kJb00@0`kNb0<>g/`33]k<0a;Nc0`34^;<00`36^;@0akVe0<Rk]P020<Zl^0060<^m^03<_KP0c;fi
0<bm^@3<_[T0c[nj0`3>_k/20<no^`0:0<o0_03@`;d0cl2k0<fo^@3=_[L0c[ni0=30^`3A`;`0dL6l
0=31^`80cl2j00<0d<2j0=70^`3A`;/00`3A`K`0103@`K/0d<6j0=71^`3B`[/30=?3_0030=;2^`3A
`KX0dL:j0080dL:j0`3B`[X20=;3^`050=?3^`3Da;`0eLFl0=G5_03EaKd00P3FaKd01P3Fa[d0elJm
0=O7_P3Gakh0eLFl0=O6_@D0f<Rn00@0elNm0<Be[01gKVP05A<C4P0000000`010@4020L703`c<@02
08]mM@040;JWWP3=^k40hLo30>KCa`80iM;600<0i=;60>GBaP3UdLD00P3Ud/D0103Td/D0i=750>CA
a03TdL@50>CBa080i=;3103Td/820>CA`P80i=;200<0iM;20>CC`P3Ud/800P3TdL40103Td/40i=70
0>CA`03SdL020>CA`080i=;00P3Sd/002@3SdKl0h]2n0>;@_P3Rd;h0h]6n0>;@_@3Pck`0i=:o0>GB
_`020>GC`0@0i]?000<0iM?00>GC_`3Udkl00P3Udkl20>GC_P030>CC_P3Sdkd0hm:l0080hm:l00P0
hm>l0>CC_@3Tdkd0i=>m0>GD_P3Ve;h0gljh0<:bW`80XYJ600D0X9B408ImKP1@Bd<08AlL00H51@0>
000000`0oooo000:0?oooil0000000H00P8203<^;P2CR8X0_:j`0<Bf]`33]KL20<>e]P80`kBe0P32
];D00`31];@0`K>d0<6c]0020<2c]0030<6c]030/k<0`;>c00@0`;>b00<0`;Bb0<6d/P31];800P31
];800`31];<0`[Fc0<:e]0020<:f]0030<>f/`32][<0`[Jc0080`[Jc0`32]K800`32][80`kJb0<:f
/P020<:f/P030<>f/P33]k<0`kNc00<0a;Rc00@0aKRc0<Jj]@38^[H0bK^g0P3:_;P20<^m^0040<bm
^@3<_[T0cKji0<jo^P<0c[nk00T0cKnj0<fn^P3>_k/0d<2m0<o0_03>_k/0c[nj0<o0^`3@`K`00P3B
`Kh0103A`Kd0d<2k0<o0^P3?_kX20=71^`80dL6l00D0dL:l0=31^`3@`KX0dL6k0=;2^`020=;3_003
0=?3_03B`[/0d/:k00D0d/:k00D0d/>k0=?3^`3C`k/0dlBl0=C4_0020=G5_0040=G5_@3FaKd0e/Jm
0=K6_@<0elNn00<0eLFl0=S7_P3Hb;h00`3Hb;h01@3Hakh0bKZa08=iM00_:bT00@4100d0000000P0
0P82018=300J2PT08aPF02`X9@0V8b00A3lk08b1N`80aKF[0`3Ud/L80>GBaP030>CAa@3SdL@0hm74
00@0hm740P3Td/@20>CB``/0i=;20`3Td/400`3Ud/40i=;10>CB`0020>CA`0050>?B`03RdKl0h]6o
0>?B`03Sd[l0103RdKh00`3Rd[h0hM2m0>?A_P020>CC`0@0iM?01`3Udkl20>GC_P050>CC_P3Sd[d0
hm:l0>?B_03Sdk`00`3Sdkd0103Ue;d0i]Bn0>GD_@3Qd;X20=g<]P050=_;]@3EaJl0]:JD07E/H@0V
8al03P00000<0?ooo`002P3ooonN00000004014@400^:b/0O7=d0;^][`<0`kFf00<0`kBf0<:d]@32
];D00P31/k@50<2c]080`;>c1@30/k820<2d/P@0`KBb00T0`[Fc0<>f]035][H0aKNf0<Jg]P35]kD0
a;Nd0<>f]032][<00`32]K860<:f/P040<>f/P33]k<0a;Nc0<Bg/`80a;Rc00<0aKRd0<Rj]P3:_;P0
0`3:_;P20<^m^0050<bm^@3<_[T0c;ji0<fo^P3>_kX00P3=_[X0103<_[T0bkfh0<fo^P3?`;`20=30
_0030=30^`3@`;`0dL6m0080d/6n00H0d/:m0=71_03?`;X0cKji0=30^`3A`;/20=71_0040=72_03A
`[/0d<6k0=72^`<0dL:l00@0d/:l0=;2^`3B`[/0d/:k103B`[X00`3B`[/0dl>k0=?4^`020=C4_080
eLFl00<0eLFm0=K6_@3Fa[h0103Gakh00`3EaK`0f<Nn0=S8_P030=S8_P040=O7_@2l[JD0Ee5=00d;
2``0000000X06aTG044m>@1LEE00PG9[09IfK`2SRX<0/:2G08AiLP2QTh/0f<Nl0P3OcL820>GBa`@0
iM;600<0i=760>GAaP3Ud/H00P3Ud/H50>CBa@H0i=;40P3Td/<40>CB`P80i=?200<0i=;30>CB`P3U
d/800P3Td/40103Td/80iM;20>GB`@3Td/420>CB`0050>?B`03RdKl0hM6o0>;A_`3Sd/000`3RdKl2
0>;B_`030>?B_`3Td/00i=?00080i=?00P3Udl020>GC_`030>CC_`3Udkl0iM>o00<0i=>o00<0i=>n
0>CD_P3Sdkd00P3Sd[d20>?C_0<0hm>m00@0i=Bm0>GD_P3Ue;h0iMBn0P3UeKh01@3Ue;d0i=>l0=k=
]P2bY980AD0i00h00000303oool000X0ooooW@0000001P061PH0?cXk07meM`2fZJ/0`[Bf0<>e]P<0
`kBf00<0`[Bf0<6d]@30/k@01`30/k@20<2c/`<0`;>b00<0`;Bb0<6d/`31];<01031];<02033][@0
aKNg0<Rj^@38^KT0b;Zh0<Rj^@35^;H0`kJd1032]K860<:f/P030<>g/P34^;<0a;Rd0080a;Rd00<0
aKRd0<Ji]03:^kP00`3:_;P00`3;_;P0bkfh0<^m^0030<bn^@030<fo^`3>_kX0cKnj0080cKnj00<0
cKjj0<jo^`3?`;`0103A`Kd0103A`[d0d/:n0=;2_P3C`kl20=;2_@040=71_03@`;/0d<2k0=71_080
dL:l0`3B`[`30=72_0030=;2_03B`[/0dl>k00H0dl>k0P3Ca;`01P3Da;`0eLFl0=G5_@3EaKd0eLBl
0=G5_@80elNn00<0c[nf0<Zk/`3Gakh01@3Hb;h01`3Ib;h0f<Rn0<fl/`1WGUX02`X:00T8200A40l0
0P0B40l01P0;2PX00`8200000000000010@400`<2`804Q0?00T0BD<o09N<Q@35]jd0f/Vo0>CAaP3T
d/L0iM;70<2`Y`3@_k@00`3UdlL0103Ud/L0i=;60>CBaP3Ud/H30>CBaPH0iM;600<0i=740>?Aa03T
d/D01`3Td/@20>CB``<0i=;200<0i=?20>CB`P3Td/801P3Td/820>CB`@80i=;000<0hm;00>;A_`3Q
dKl0103RdKl30>;B_`030>?B`03Td/00i=;00080i=?01`3Tdkl50>?C_PL0hm>m00@0hmBm0>CD_@3U
e;h0iMBn103UeKh0103VeKh0imFo0;Z]VP1<ASh>000000`0oooo000:0?oooi`0000000D00@4101dJ
6P20MgT0^:^]0<:e]P030<:d]P<0`[Be00<0`K>e0<2c]030/k@01030/k@30<2d]0030<6d/`30];<0
`KBc00<0`KBc00d0`[Fd0<>f]033][@0a;Je0<Bg]P36^KL0b;Zi0<Zl^`3:^k/0b[^j0<^k^`37^;L0
a;Je00L0`[Jc0`33]k<01034^;<0a;Rd0<Ji]@36^KD20<Ni]@030<Rj]P3:^kP0bK^h0080b[bh0P3;
_KP0103<_KP0c;ji0<bn^@3<_[T20<fo^P80cL2j0P3>_k/00`3>`;`0d<2m0=31_@040=71_@80d/:n
00L0dl>o0=;3_P3C`[h0d/:m0=72_03?`;/0d<2k00<0dL6k1@3A`[`00`3A`[/0d/:k0=?3_0040=?3
_0@0dlBl00H0e<Fl0=G5_@3EaKd0eLFm0=C3_03DaK`20=O7_P040<Nh/032]:/0f<Ro0=S8_`<0f<Rn
0P3Ib;h01P3EaK`0^jfU085gL@16@Sh0HU]G08^1N`80S85k00H0Jf=N048m>`0e<Bl0=C4_04U4@@1b
JF@208b1N`030:VLU03C`[P0i=;800<0i=;700<0iM;70=k=`@3OcL800`3UdlL00`3Ud/L0i=;60>CB
aP060>CBaP@0iM;60P3Ud/D00`3Td/D0hm;40>CBa0020>?Aa0<0hm;40`3Td/<30>CB`P040>CB``3T
d/80i=;20>?A`@@0i=;200D0i=?10>CB`@3Td/00i=;00>?B`0020>;A_`<0hM6o00D0hM:o0>;B_`3R
d[l0h]:o0>?B`0020>CB_`030>CB`03Tdkl0i=>o00D0i=>o00<0hm>o0>?C_P3Rdkh00P3Rdkh20>?C
_PD0hm>m0P3Se;d00`3Te;h0iMBn0>GE_P040>GE_P80i]Fn00<0^JbI04]6?`0000003@00000<0?oo
o`002P3ooonK0000000600h=3@0W8b@0JV=T0;>VZ033]KL0`[Fg1@32];H00`31/kD0`;>e0<2c]004
0<2c]0@0`;Bd1@31];@02032]K@0`kJe0<Fg]P35]kH0aKVg0<Ji]`37^[T0b;Zh0P39^kX01@38^[T0
b;Zh0<Jh]P33]k@0`kJd0080`kNd00<0`[Jd0<:g]033]k@00P33]k<01`33]k@0`kRd0<Bh]035^KD0
a[Ve0<Nj]P39^kL00`39^kP0103:_;P0bkbh0<^m^03;_KT20<bn^@80c;jj00<0cKjj0<fo^P3=_kX0
0P3>_k/0103?_k/0cl2l0=30_@3@`Kd30=71_@0;0=72_P3B`[h0d/:n0=;2_P3C`[h0d/:m0=71_03A
`[`0dL6k0=31^P3@`;/0103A`K/30=72_0<0dL:k00<0d/>l0=?3_03Da;`00`3Da;d00`3DaKd0dlBl
0=C5_@020=G5_@80eLFn00H0e/Jn0=O7_P3Gakh0elNn0<Vk/P3;_;@50=S8_`080=S8_P3Ib;h0dl>j
0<6bZP3<_K@0`;6Z0=?3^P3QclD20>7@aP060=K5_037^:l0`[B[0<:dZ`39^k40f<Nn0`3Rd<H00`3S
d/L0i=;70>CBa`020>CBa`<0iM;700@0i=;70>?BaP3Sd/H0hm;61P3Td/H90>GBaP030>CCa@3Td/D0
i=?50080i=?51@3Td/@50>CB``@0i=;20P3Tdl800`3Udl80i=?10>CB`@020>CB`@040>?B`03Rd/00
h]6o0>7A_`<0hM:o0P3Rd[l00`3Sd/00i=:o0>CB_`030>CB_`D0i=>o00<0hm>o0>?C_P3Rdkh00`3R
dkh30>?C_P030>?C_@3Te;h0i=Bn00<0i=Bn0`3UeKh20>?C_0050>7@^P3Tdk`0f<Rc0:FIR010>cD0
3P00000<0?ooo`002P3ooonI0000000700<20P0:2PX0>C@f07A[K@2_XjD0`KBe0<:e]P050<:d]P03
0<6d]@31/kD0`;>e00@0`;>d1@30];@40<6d]0030<6e]032]K@0a;Nf0080a[Rg00<0a[Vh0<Jh]`36
^;L00`35^;L00`34]kD0`kNd0<>g]0030<:f]0<0`[Nd0`33]k@01P34^;@0aKRe0<Fh]@36^KH0akZf
0<Nj]`80bK^h00<0bKbh0<Zl^03:_;P00P3;_KP01@3;_KT0c;jj0<bn^P3<_[X0cKjk0080cKnk00D0
cKnj0<jo^`3>_k/0c[nk0<no^`020<k0_0050<o0_03A`Kd0dL6m0=;2_@3B`[h00P3B`[l00`3B`[h0
dL6l0<o0^P030<o0^P030=31^P3A`[`0dL:l00H0dL:l00D0dL:k0=73_03A`k`0d/>l0=?4_0030=C4
_@<0e<Fm0P3EaKd20=G6_P80e/Jn0P3Fakh0103C`k/0e/Jm0=O8_P3Gb;h50=S8_P060=O7_@3EaK`0
hLo60>7@aP3Rd<L0hm781`3Sd/P50>CBb0/0i=;72`3Td/H30>GBaP@0iM;50`3UdlD0103Td/@0hm;4
0>?Ba03Sd/<20>CB``030>CC``3Td/<0i=;300<0i=;3103Tdl80103Tdl40i=;10>CB`@3Td/420>?B
`0030>;A_`3QdKl0hM6o0080hM6o00@0hM:o0>;B_`3Sd[l0i=;00`3Td[l60>CC_`030>?C_`3Rdkh0
h]>n00<0h]>n0`3Rdkd00`3Sdkd0i=Bn0>GD_P020>GD_P@0iMFn0P3Jb[@01@3A`Zd0h]:k0;V/V@1b
JUl09b@P00h00000303oool000X0ooooV@000000100I5aL0B49309>8R`2hZZd20<:e]`D0`[Bf00@0
`KBf0<6d]@30/kD0`;>e1P30/k@50<2d]0050<6d]031]K@0`KFe0<>f]P35^;L00P36^KP00`36^;P0
a;Nf0<>f]@030<>f]@040<:f]033][@0`[Jd0<:g]080`kNd00L0`[Jd0<:f/`32][<0`[Nc0<>g/`34
^;@0aKRe0080a[Vf00<0akZf0<Rj]`38^kL00P39^kP00`39_;P0b[bh0<^m^@020<^m^@040<bn^@3<
_[X0c;jj0<fn^`@0cKnk0`3>_k/30<k0^`050<o0_03?`Kd0dL:n0=;2_@3B`[h00P3B`[l02`3B`[h0
dL6l0<o0^P3?`KX0d<6j0<o1^P3@`K/0cl6k0=31_03A`kd0dL:l00<0dL:k00L0dL>l0=;3_@3B`kd0
d/>m0=?4_@3Da;`0e<Bm0080dlBm00@0e<Bm0=C5_P3EaKh0eLFn0`3Ea[h00`3Fa[h0e/Nn0=K7_P02
0=K7_P030=O7_`3Hb;l0f<Ro0080f<Ro0P3Hb;h01P3Hb;l0fLW00=c;`@3Oc/D0hM370>;Ab080h];8
2@3Sd/P20>CBb0X0i=;700<0i=?70>CBaP3Td/H02`3Td/H20>GBaP070>GBa@3Td/D0i=;50>;@``3I
b;/0f<Nk0>CBa0040>CCa0<0i=?30P3Td/<20>CB`P@0i=?2103Sd/430>?B`0030>;A_`3QdKl0hM6o
00<0hM:o00<0h]:o0>?C`03Sdl000P3Sdl040>?C_`80i=>o00<0hm>o0>?C_P3Sdkh01@3Sdkh00`3S
dkd0i=Bn0>CD_P060>GD_P080>GE_P3OckT0glni0=_<]@3Te;`0^ZfJ06iVFP0P7Q/>000000`0oooo
000:0?oooiL0000000D00`<3014@4@1DCe00Wi>F0<2b]@020<:e]`D0`[Bf00@0`K>f0<2c]@30];D0
`;>e1P30/k@50<2d]0060<6d]032]KD0`kJf0<>g]P34]kL0a[Vi0P37^KT00`35^;L0`kJe0<:f]005
0<:f]0030<:g]033]k@0`kNd0080`kNd0P32]k@01P33]k@0a;Rd0<Fh]035^KH0a[Vf0<Jj]P80b;Zg
0P39^kP00`39_;T0b[bh0<Zm^0020<^m^@040<^n^P3<_[X0c;jj0<bn^P80c;jk0`3=_k/30<jo^`06
0<k0^`3>_k/0cKnj0<k0^`3?`K`0d<6m0P3A`[h01@3B`[h0dL:m0=72_@3@`K`0cl6k00<0cl6j00<0
d<6k0=72_03>`;T00P3A`kd30=72_080d/>l00T0d/>m0=?4_@3Ca;d0dlBm0=C4_@3Ba;d0d/Bl0=?4
_@3DaKd00`3Ea[h20=G5_@050=G5_P3Hb<00elNo0=K7_`3Gakl00P3Gb;l00`3Hakl0f<Ro0=S8_`02
0=S8_`060=[:`@3Mc<<0glk50>7@a`3QclH0h]370`3RdLL40>?Ab0<0hm;80P3Td/P70>CBa`80hm;7
0`3Td/L;0>CBaP030>GBaP3UdlH0iM?600D0iM?500<0akR/0<2aYP3Pcl400`3UdlD0103Udl@0i=?3
0>CC``3Tdl<30>CB`P050>CC`P3Td/80i=?20>CC``3Sd/80103Sd/420>CB`@030>?B`03Rd/00h]:o
00D0hM:o103Rd[l40>;B_P040>?C_`3Tdkl0i=Bo0>CD_`80hmBo103Te;l0103Se;h0i=Bn0>CD_P3T
e;h50>GD_P080>GE_P3Ue;d0iMBm0>CD_03Rdk/0gLjg0::FQ@0h=2h>000000`0oooo000:0?oooiH0
000000D00`8201XI6@1ABd`0XIFG0<2c]@020<:e]`030<:d]`32];H0`KBf00H0`;>e00@0`;>d0<2c
]@30/kD0`;>d2030];@01031]KD0`[Fe0<>f]P33]kH20<Bg]`80`kNf00<0`kNe0<:f]032][@01032
][@70<>g]0070<>h]@34^KD0aKVe0<Fi]P36^KH0a[Zg0<Nj]`020<Rk^0060<Vk^039_;T0bKbi0<Zl
^@3:_KT0bkfi0P3;_[X00`3<_[X0c;jk0<bn^`050<fo^`<0c[nk00H0c/2k0<fo^`3=_kX0c/2k0<o1
_03@`Kd20=72_P040=72_@3@`Kd0cl6l0<o0^`80c/2j0`3?`KX01`3@`[/0cl6k0=73_03B`kd0dL>m
0=72_03A`k`00P3B`kd20=?4_P80dlBm0P3Ca;`00`3B`k`0dlBm0=?5_@020=G6_P050=K6_`3Ea[h0
eLJn0=S8`03Jb/801@3Gb;l40=S8_`030=W9`03McL<0h<o60080hM3700<0glk60>7@a`3Qd<L00P3R
d<L00`3RdLL0hm770>?Aa`040>?Aa`<0hm;71@3Td/L20>?Ba`<0hm;6303Td/H40>CBa@<0i=?500@0
iM?50=;1]@3>_[80h]73103UdlD50>CC``040>CC`P3Sd/80hm;10>?B`P80i=?200<0hm;10>CB`@3T
d/400P3Tdl801@3Td/40hm;00>?B`03Rd/00h]:o00L0hM:o103Qd[h00`3Qdkh0hm>o0>CD_`060>CD
_`80iMBo1P3Te;h00`3Ue;h0iMFn0>GE_P030>GE_P050>GE_@3UeKh0iMFn0;6TT`0m>C803P00000<
0?ooo`002P3ooonE0000000700T92@0V8b@0J69R0:FIW030/kD0`[Fg0<6d]`020<6d]P040<6c]P30
/kD0`;>e0;nc]@@0`;>e00<0_k>e0<2c]@30/kD01030];D50<2d]0030<6e]031]KD0`[Je00D0`[Je
00<0`[Jd0<6f]031][@01032][@01033]kD0a;Ne0<Bg]@34]kD30<Bh]@060<Fh]@36^KH0a[Vf0<Ji
]P37^[L0ak^g0`38^kP00`39_;P0bKbi0<Vl^@020<Zm^@040<^m^@3;_[X0bkjj0<bn^P80c;jk0`3=
_k/00`3=`;/0cKnk0<jo^`020<jo^`070<k0^`3=`;/0cKnj0<k0^`3?`;`0d<6m0=31_0030<o1_0@0
c/2j00T0c/6j0<o1^`3?`[/0cl:k0=32^`3;_KL0d<:l0=;3_@3A`kd00P3B`kd00`3Ba;d0dlBn0=?4
_P030=?4_@030=?4_03Ca;d0dlFm0080eLJn00@0e/Jn0=K6_`3Gb<00elS00P3Lc<@00`3Hb<00elRo
0=O8_`020=O8_`@0f<Ro00<0f/[10=o>a@3Qd<L00`3Qd<L40>;@a`040>;Aa`3RdLP0h]780>;Ab080
h]770P3Rd/L90>?Ba`L0i=;71`3Td/H60>CCaP030=_:_@3FaKT0h<o100L0iM?500D0i=?40>?C``3T
dl80i=?20>CC``020>CC`P80hm;200<0hm?20>?B`@3Sd/400P3Sd/420>CD`P050>?B`@3Sd/00hm;0
0>?B`03Rd/000P3Sd/020>;B_`@0hM:o0`3Qd[h01@3Qdkh0hm>o0>CD_`3Te;l0i=>o00H0i=Bo1P3T
e;h90>GE_P030;^^V`0m>C80000000d00000303oool000X0ooooT`0000003@010@4010<302@P801X
HF40/:FW0<6d]P32]KP0`[Fg0<:d]`31];L0`K>f0<2c]P30/kD00`2o/kD20<2c]@030;nc]@2o/k@0
_k>d0080_k>d0`30];@00`30];D0`KFe0<6f]@020<6e]@040<2e]031]KD0`KFe0<6e]@@0`KJe00<0
`[Je0<:f]032][@00`32][@30<>g]@060<Bg]@34^;H0a;Rf0<Fh]@35^KD0aKVf0P36^KH00`36^KL0
akZg0<Rj^0020<Rk^0040<Vl^039_;T0bKbi0<Vl^@80b[fi00<0bkfi0<^n^P3;_[X00`3<_[/50<fo
^`80c[nk0P3>`;/01`3=`;/0cL2j0<k0^`3?`;d0cl6m0<o1_03?`;/00P3?`K/0103=`;X0c/2j0<k0
^P3>`KX20<o1^`80cl:k00@0d<:k0<k0^P3>`;X0d/>n0P3Ba;d20=?4_@030=?4_P3Ca;d0dlBm00<0
dlBm00H0e<Fm0=G6_P3Fa[l0e/Jo0=K7_`3HbL420=[;``030=g>aP3Lc<@0f<S000@0elRo0`3Hb;l0
0`3HbL00fl_20>3?aP020>7@b080h]380P3RdLP00`3Qd<L0h]370>;@a`070>;Aa`040>?Aa`3Sd/P0
hm;80>?Bb080hm7700<0hm;70>?Aa`3SdLL0103Sd/L90>CBaPL0i=?600<0cl2d0<Vj[P3Lbkh00P3T
dlD50>GCa@040>CCa03Tdl<0i=?30>?C``80i=?300<0i=?20>CC``3Sd/801@3Sd/401P3Sdl40i=?2
0>CC`P3Tdl40hm;10>?B`0@0hm?000<0h]>o0>7B_`3Qd[l00`3Qdkl30>;C_`050>?C_`3Te;l0i=Bo
0>CD_`3Tdkl01P3Te;l50>CD_P<0i=Fn1@3UeKh00`3PdKX0Zin=03<`:P0>000000`0oooo000:0?oo
oi80000000L020L7020N7`18@D80Og5b0:jOXP31]KP0`[Fg0080`KBg0P31];H00`30/kH0`;>e0<2c
]@030;nc]@030<2c]@30];D0_k>e00<0_k>e00<0_k>d0;nd]030];@00P30];@00`31]KD0`KFf0<6e
]@040<6e]@030<6f]@32][D0`[Je00D0`[Je0`32]kD00`33]kH0`kNe0<Bg]@030<Bh]@070<Fh]P36
^KH0a[Vg0<Ji]`36^[L0akZg0<Rj^0020<Rk^080b;bi0P39_;T01039_KT0b[fi0<Zm^@3;_KT20<^n
^P80c;jk00<0c;nk0<fo^`3=_k/00`3=_k/30<k0^`80c/2l00X0cL2k0<k0_03?`;`0d<6l0<o1_03?
`;/0cl6l0<k1^`3=`;X0c/2j0P3>`KX02@3?`K/0cl:k0<o2^`3?`[/0d<:k0=73_03@`K`0d/>m0=?3
_P080=?4_@070=C5_@3DaKl0eLJo0=G6_`3Fa[l0f<S00=_<a0020=k?a`030=o@b03Lc<@0f<W000@0
elRo0P3Hb;l20=S9`0040=_;``3OclH0h=370>3@a`80hM3700<0hM380>;@b03Rd<L0203RdLL20>?A
a`80hm;800<0hm;70>?Aa`3Sd/L0103Sd/L70>CBa`@0i=;600<0i=?60>CCa`3TdlL0103Te<L0103U
e<L0f/Zn0=g=`03Sd/@50>GCa@80iMC500@0i=C40>CCa03Sdl@0i=?40`3Tdl<20>CC`P030>?C`P3S
d/80hm?20080hm?100@0hm?20>CC`@3Tdl80hm?10`3Sd/030>?C`0030>;C`03Rdkl0h]>o00H0h]>o
00<0hmC00>CD_`3Te;l02@3Te;l40>CD_PH0i=Fn0P3UeKh00`3>`:/0MFeQ01XI5P0>000000`0oooo
000:0?oooi40000000L01`H6030/;@1aJF`0Y9NJ0;RWZP2o/;<0`[Fh00<0`KBg00<0`K>g0<2c]P30
/kH02`2o/kD20;nd]@<0`;Be00<0`;Fe0<6e]@31]KD01@31]KD20<:f]@80`[Jf0`33][H20<>g]P80
a;Nf1@34^;H01035^KH0aKVg0<Fi]`36^KL20<Nj]`<0b;^h0P38_;T00`39_;T0bKfi0<Zm^@020<Zm
^@<0bkjj0`3<_k/40<fo^`@0c[nk00@0c/2k0<k0_03>`;`0cl6l0P3?`Kd00`3>`K/0c/2k0<k1^`03
0<k1^`80c/6j103?`[/0103@`[/0dL:l0=72_@3B`kh20=?4_PH0dlBm00P0e<Fm0=G6_`3Fal00e/No
0=K7`03Fb<00f/_30=k>aP80glo700<0g/k60=[;``3Gb<00103Gb;l01@3GbL00f<S00=S9`03IbL40
flc300D0h=3700<0hM370>;Ab03RdLP01@3RdLP50>;Aa`030>?Aa`3Sd/P0hm7700@0hm771`3Sd/L0
0`3Sd/H0i=;60>CBaP020>CBaP0?0>CCaP3TdlL0i=?70>?BaP3Kbkl0eLJj0=71]P3DaKT0glo20>3@
``3RdL@0i=?50>GCa@3TdlD0h]330080i=?500<0iM?50>CCa03Sdl@00`3Sdl@00`3Sdl<0hm?20>?C
`P030>CC``D0hm?200@0hm;10>?C`@3Sdl40hm;1103Sd/080>?C`080hmC00P3Te<0;0>CD_`80i=Bn
203TeKh0103UeKh0/JFB03/g<@010@4>000000`0oooo000:0?ooohl000000P0@3a00200j=CH0RWn1
0;NY[032]KP0`[Ji0<:e^@31];P0`KBg0P30/kL00`30/kH0_k>f0;nc]P040;nc]@80_kBe00<0`;Be
0;nd]@2o];D00P2o];D30<2d]@<0`;Fe1@31]KD20<6f]@040<:f]@32][H0`[Jf0<:f]P80`kJf1033
]kH00`34]kH0a;Rf0<Bh]P020<Bh]P090<Fi]P35^KL0a[Vg0<Ji]`36^[L0akZg0<Nk]`38^kP0b;^i
0080b;bi00H0bKbi0<Vm^@3:_KT0b[fi0<^m^P3;_[X20<^n^`@0c;nk00<0cL2l0<fo_03=_k/0103>
_k/01P3>`;/0c/2l0<k0^`3>`;/0c/2l0<k1_080cl6l1P3>`K/00`3>`[/0cl:k0<o2^`020<o2^`05
0=32_03A`kd0d/>m0<fo^@3;_KP00P3Ca;h50=?4_@080=C5_P3Eal00e/O00=K7`03Ib/80flc40=c>
aP3OclL20=g=a@040=W:``3HbL40elS00=O8`0<0elRo00D0elW00=O8`03Hb<00f/[20=g=a0070>3@
a`80hM370P3QdLL20>7Ab0L0h]77103SdLL90>?Ba`030>?BaP3Td/L0i=?800@0i=?700T0h]750=C5
^@3<_K80c;fb0=C5^@3Ocl<0glo20=c<_`3QdL@00`3Ue<H30>CCa@H0hm?400<0hm?30>CD``3Te<<0
0`3Tdl<00`3Sd/80hm;10>?B`@020>?C`@030>;C`@3Sdl40hm?100<0hm?11@3Sdl030>CC`0H0i=C0
2`3Te;l00`3Te;h0i=Fn0>CE_P030>CE_P80i=Bn00@0i=Fn0=[;]@2HSGh0<BhY3`00000<0?ooo`00
2P3ooon=0000000;00H61P0C4a40A48n04A2?P29Oh00]ZFY0;j^/@32][T0`KFh0<:e^@31];P00P30
];L01030/kL0`;>f0;nc]P2o/kH30;nc]@<0_kBe00@0`;Be0;nd]@2o];D0_kBe0P30];D50<2e]@@0
`KFe0`31][D00`32][H0`kJf0<>g]P050<>g]PD0a;Rf00D0a;Vf0<Fi]P35^KL0aKVg0<Ji]`030<Jj
]`030<Nj]`38^kP0b;^i0080b;bi00@0bKbi0<Vm^@3:_KT0b[fj0P3;_[X0103;_[/0c;nk0<bo_03<
_k`20<bo^`80cL2l00<0cKnl0<k0_03>`;`0103>`;`00`3>`K`0c/2l0<k1_0020<k1_0030<o1_03>
`K`0c/6k00<0c/6k00<0cl:k0<o2_03@`[`00P3@`[d0203@`[`0d<>l0=;4_@3Ca;h0dL:m0<o0_03E
a/00e<Fo0P3CaKl30=C5_`80eLO000H0e/O00=O8`@3Lc<D0g/o70>3@b03OclL20=_<a080elS1103G
b<001@3Gb;l0f<W00=S9`03Ib/80gLg500D0h=37103Pd<H0103Qd<H0hM370>7@a`3Qd<L20>7Aa`<0
h]780P3SdLP00`3Sd/P0hm;70>?Ba`090>?Ba`<0i=;700@0i=?70>CCb03TdlP0i=?70P3Te<L01`3V
e<P0imK90<^l/@2^XIP0cKnd0>?CaP3UeLL00P3VeLP0103Ue<L0i=C60>CDaP3Ue<H20>GDa@030>CD
a@3Sdl@0hm?400<0hm?400L0hm?30>?C`P3Sdl80hm?20>?C``3Tdl<0i=?200<0hm?20P3Sdl400`3R
dl40hm?10>?C`@030>?C`@`0hm?000<0i=C00>CD_`3Te;l02@3Te;l00`3TeKl0i=Fn0>CE_P030>CE
_P80hmBm00@0i=Bn0;BXUP1PFDl06QPE3`00000<0?ooo`002P3ooon<0000000300l>3P0d<C80JFAP
0080WIJ@00@0^Zj_0;j]/@2n[k<0`[Fi0P31]KP00`31];L0`;Bg0<2c]P030;nc]P<0_k>e00<0_[>e
0;nc]@2o/kD01@2o];D30<2d]@L0`;Fe0P31]KD01031][D0`[Jf0<:f]P33]kL80<>g]P040<>h]P34
^;H0a;Rf0<Bi]P<0aKVg0P36^[L01037^[L0ak^g0<Nk^039^kT40<Rl^@030<Vm^P3:_KX0bkjj00<0
bkjk1@3<_k`30<g0_0H0c/2l1@3>`K`20<o2_@090<k1_03>`K/0c/6k0<k2^`3?`[`0d<:m0=32_P3@
`kd0d<>l0080cl:k00H0dL>m0=;4_P3DaKl0eLK00=O7`@3Fal440=G6`080eLO000L0e/O00=O7`03H
b<40f<W30=_<a@3Pd<T0g/k70080f/_40P3Gb<450=O8`0040=S8`03HbL00f/_20>3@a`80h=380`3P
d<L60>3@aP050>3@a`3Qd<L0hM370>7@a`3QdLL01@3RdLP20>?Aa`/0hm;7103TdlP20>CCa`0<0>CD
b03VeLT0imK:09fAR@1KE500YIV@0=g=`03VeLP0i]K80>GEb03Ue<L0i=C7103Te<H00`3Te<D0hmC4
0>?Ca0030>?Ca080hm?300<0hm?20>?D`P3Se<80103Te<<01@3Sdl80hm?10>?C`@3Sdl40h]?100<0
hm?100<0hm?00>?C`@3Sdl401@3Sdl020>?D`0P0i=C00`3Te;l90>CE_`070>CE_P3PdK/0h=6k0<^m
Z@1eKF408R0M00820P0?000000`0oooo000:0?ooohX0000000D00`<300P7200f<S@0NW=e0;2VYP02
0;jc/@080<6f^032][T0`KFi0<6e^@32]KT0`[Fh0<6d^030];L20;nc]P030;jc]@2o/kD0_k>e0080
_k>e00<0_[>e0;nc]@2o];D01@2o];D20<2d]@P0`;Fe00<0`KFe0<6f]P32][H00P32][H00`33]kH0
`kNg0<>g]`030<>g]P030<>h]P34^;H0a;Rf0080a;Rf00@0aKVf0<Fi]`35^KL0aKVg0`36^[L01037
^kP0b;^h0<Rk^@38_;T30<Rl^P80bKfj1@3;_[/50<bo_0040<c0_03=_k`0cL2l0<fo_0<0c/2l0P3=
`;`00`3=`K`0c/6l0<k1_0020<k1_0030<o2_@3?`[h0cl6l0080c/6k00<0c/:k0=31_03@`[d00P3@
`[d0203?`[`0c/:k0<o2^`3?`[/0d<:l0=;4_P3EaL00e/O10P3Gal830=K7`@<0eLO000H0elO00=O8
`@3HbL80f<W20=_;a03Ibl<20=O9`@030=O8`03GbL00elS000D0elS000D0f<W00=c=a03PdLP0hM78
0>7Ab@030>7Ab080h=370P3Qd<L00`3Pd<L0hM370>7Aa`030>7Aa`030>7Ab03RdLP0hm7800P0hm;8
1`3Sd/L50>CCb080iMC800P0i]G90>OFbP3We/X0ZijE06]SGP2_XYT0glo20>KEb0D0iMC700@0i=G6
0>GEaP3UeLH0iMG60`3Te<D0103Te<@0hmC40>?Da03Se<@30>?D``050>CD``3TeL<0i=G40>CEa03T
dl800`3Sdl850>?C`@80hmC10P3Sdl420>?C`0@0hmC01`3Te<020>CD_`/0i=Fo0P3?`Jd00`1mMFP0
=34[00d<2`0@000000`0oooo000:0?ooohX0000000@06QLI044m?P28PH<0]:V/0`32][X01`32]KT0
`KFi0<6e^@31]KT0`KFh0<6d^030];L01`2o/kH60;nd]P80`;Bf1030]KH30<6e]P@0`KJf00@0`[Ng
0<:g]P32]kL0`[Jf1P33]kH00`33^;H0a;Rf0<Bh]P020<Bh]P050<Fi]P35^KL0aKVg0<Fi]`35^[L0
0`36^[L20<Nk^0030<Rk^038_;T0b;bj0080bKbj00<0bKfj0<Zm^P3:_[/00P3:_[/20<^n^`040<^o
_03<_k`0c;nl0<bo_080c<2l00<0c;nl0<g0_03=`;`0103=`;`00`3>`;`0c/6l0<k1_0030<k1_003
0<o2_@3?`[h0cl:l0080c/6k00<0cl:l0=32_@3@`[d00P3@`[d02P3@`[`0cl:k0<o2^`3?`[/0d<:l
0=74_@3EaL00e/O10=O7`P3Fal830=K7`@<0eLO000<0e/S10=O8`@3Gb<400`3Gb<430=K8`0D0elS0
00L0f<W00=[:`P3Kc<<0glo70>;Ab@3Rd/T0h];:00<0h];900<0hM780>3@a`3Pd<L00`3Pd<H20>3@
a`030>7@a`3QdLL0hM7800@0h]7800@0hm780>;Ab03Sd/P0hm;81P3Sd/L00`3SdlP0hm?70>CCb005
0>CCb0090>GDb03VeLT0i]G90>KFbP3We/X0g/k20<Vk/03Lc<00i]G900H0iMC700<0i=C60>CEaP3U
eLH00P3UeLH01P3Ue<D0i=C50>CDa@3Se<@0hm?40>?Da080hmC300<0hmC20>?D``3Te<<0103Te<<3
0>?C`P80hm?11@3Se<420>?C`@T0hmC0103Te<0;0>CE_`040>CE_P2m/Il0_K6O034^:Q800000303o
ool000X0ooooR00000001`0;2`/0:2DW06QQI02MTYH0_K6e0<6e^@32][X01@31]KT00`30];P0`;Bg
0<2c]`070;nc]PL0_kBf0P30];H30<2e]P040<6e]`31][L0`KFf0<6e]P<0`KJf0P32]kH00`33]kL0
`[Jf0<:g]P070<>g]P<0a;Rf00@0aKVg0<Fi^035^KL0aKZh0`36^[P01@36^kP0ak^h0<Nk^037^kP0
b;^i0080b;bj0P39_KX00`3:_KX0b[jj0<Zn^`030<Zn^`030<^o^`3;_k`0bknl0080c<2l103=`;`0
1@3>`;`0cL2l0<g0_03=`;`0cL6l00H0c/6l0P3?`[h00`3?`[d0cl:l0<o2_0050=32_@080=33_@3@
`k`0d<>l0=33_03@`kd0dLBo0=G6`03Fal420=K7`P<0e/O100H0eLO10=G7`03Eal00elS20=O9`P3F
b<470=K8`0@0elS000L0f<W00=_<a03McLD0gm380>3@b03QdLP0hM790080hM780P3Qd/T01@3QdLP0
h=780>3@b03PdLP0h=7700D0hM7800<0h];80>?Bb03Sd/P02@3Sd/P:0>CCb080iMC800H0i]G90>KF
bP3We/X0imK:0>OFb@3VeLT20>KEb0030>GDa`3UeLL0iMC700<0iMC70`3Te<H01@3UeLH0iMC60>CD
a@3Ue<D0i=C500@0i=C400<0hmC40>CD``3Te<<0103Se<<0103Se<80hm?20>?C`P3Rd/4;0>?D`@H0
hmC0103Te<000`3TeL00i=Fo0>CE_`060>CE_`030>7C_@3OdK/0d<:^0080R81b00<071XH00000000
00004000000<0?ooo`002P3ooon70000000600<30`0T8R<0LVa^0;:WZ`31]KT0`[Nj0P32][X30<6e
^@80`;Bh00<0`;>h0;nc]`2o/kL01P2n/kH20;nc]PH0_kBf0P2o];D01P30];H0`;Ff0<6e]`31]KL0
`KJg0<6e]P<0`KJf0`32][H01032][L0`kNg0<>g]`33]kH30<>h]PD0a;Rf00D0a;Vf0<Bi]`35^KL0
aKVg0<Fj^0020<Jj^0030<Jk^037^kT0ak^i0080b;^i0`38_;X01039_KX0b[fj0<Zm^P3:_[X20<Zn
^`030<^n^`3;_k/0bknl0080bknl0`3<`;`30<g0_0040<k0_03=`;`0cL2l0<g0_0@0cL6l00<0c/6l
0<k1_@3?`Kd00P3?`[h00`3@`[h0cl:m0<o2_@050=32_@80d<>n00D0d<>m0<o3_@3@`k`0dLBn0=?6
`0020=G6`0030=G7`@3Fal40e/O100<0e/O100@0e/S10=K8`P3Gb<80elW10`3Gb<480=O8`0030=S:
`@3McLD0gLg500L0h=3800<0h=780>3@b03Od<L00`3PdLP50>7Ab0@0h]78103Rd/P30>?Bb0030>?C
b03TdlP0i=?80080i=?800<0i=?90>GDb@3Ue<T01P3Ue<P0103UeLP0i]G80>KEb03VeLP30>GEb003
0>GEa`3Ue<L0iMC700@0iMC700<0i=G60>GEaP3UeLH00`3UeLH0103UeLD0i=C50>CDa03Te<D30>?D
a0<0hmC30`3Te<<00`3Te<80hm?20>3A_`030>?C`@T0hmC10`3Se<001@3SeL00hmC00>?D`03Se<00
i=C000<0i=G01`3TeKl00`3Nd;X0akZW08MnL@02038_:P0300L61P000000000001000000303oool0
00X0ooooQ@0000002@0:2PX05aHG034^;`1XH6<0/JJZ0<>f^`33]k/0`[Jj0<6f^@030<6e^@040<2d
^@30];P0`;>g0<2c]`80_k>g00D0_k>f0;jc]P2n/kH0_[>f0;nc]P090;nd]P<0`;Ff0P31]KL30<6f
]`H0`[Jg1032]kL00`33^;L0a;Rg0<Bh]`040<Bh]`030<Bi]`35^KP0aKVh00<0aKZh0P36^[P01036
^kP0ak^i0<Nk^@38_;T30<Rl^P050<Rm^P39_KX0b[fj0<Zm^P3:_[X00P3:_[/50<^o_0<0c<2l1@3=
`;`40<g1_0040<k1_03>`Kd0c/6m0<o1_@<0cl:n0P3@`kh20=73_`H0d<>n00T0d<>m0<o3_03?`k/0
d<>m0=;5_P3BaKl0dlFo0=C6`03Ea/00103Fal400`3Fb<40elS20=O9`P020=S9`P80elS10P3Fb<05
0=O8`0050=O9`@3Kc<@0g/k60<fo]`3Gb<00103Od<P80>3@b0@0h=7800<0hM780>;Bb03Rd/P00`3R
d/P30>?Bb0<0hm?91@3TdlT20>CDb@80iMC91P3Ue<P70>GEb080iMG700<0iMG80>GEa`3UeLL01@3U
eLL0103UeLH0iMG50>CDa@3Te<D20>GEa@030>CEa03Te<@0hmC400@0hmC300D0hm?20>?D``3Qd/40
gm2n0>7A`0020>?C`@X0hmC1103Se<020>?E`0030>?D`03SeL00hmG000D0i=G0103TeKl00`3SeKl0
e<Na06URF00200<30a<00000303oool000X0ooooQ@000000200R8240FeEG09:8S02`YJT0`KFj0<:g
^`32][X0`KJj1031]KT00`30];P0`;>h0;nc^0030;nc]`@0_[>f2@2o];H00`2o]KH0`;Ff0<2e]`05
0<6e]`<0`KJg0`32][L20<:g]`80`kNg1@33^;L20<Bh]P040<Bh]`35^[P0aKZh0<Fj^0@0a[Zh00@0
a[^h0<Nk^@37^kT0ak^i0`38_;X00`38_KX0bKfj0<Zm^P020<Zm^P<0b[jk1@3;_k`30<c0_0D0cL2l
0P3=`Kd0103=`K`0c/6l0<k1_03>`Kd30<o1_@80cl:n0`3@`kh00`3Aa;h0dL>o0=33_P040=33_P04
0=33_@3?`kd0cl>l0=34_@<0dLBn00<0d/Fo0=C6`03Fal400`3Fal401P3Fb<40e/S20=O9`P3GbL80
f<W20=O8`@@0e/S00`3Gb<001`3HbL40flc50=k?a`3Qd/X0e<Fn0=;3_03Od<P01P3Pd<P70>3Ab0<0
hM780P3RdLP40>;Bb0030>?Bb03SdlT0i=?900H0i=C90P3Ue<T00`3Te<T0iMC90>GDb@030>GDb@80
iMC80P3UeLT00`3TeLT0iMG90>KEb@030>GEb0030>;Ba@3SdlD0i=G800L0iMG70P3UeLH0103UeLD0
i=G50>CEa@3Te<D20>CEa@040>?Ea03Se<@0h]?20>;C`P80h=7000<0hmC20>;C`P3Rd/40103Se<87
0>?D`@80i=C10P3TeL400`3SeL40hmC00>?D`0070>?E`080i=G00P3Te/001@3Ue/00h=:l0<>gY027
Og40?3Pb00800P814`00000<0?ooo`002P3ooon40000000;01lM7@1YHVD0Zj2U0<6e^P32][/0`[Nk
0<:f^P31][X0`KFj0<6e^@30];T00`30];P40;nc^0030;nc]`2n/kL0_[>f00@0_[>f00<0_[Bf0;nd
]P2o];H01@2o];H01030]KH0`KFg0<6e]`31]KL50<6f]`80`[Jg1@32]kL30<>h]`D0a;Rg00<0a;Vg
0<Fi^035^[P00`35^[P00`36^[P0a[^i0<Nk^@020<Nk^@@0b;bj0`39_KX00`3:_KX0b[jj0<Zn^`02
0<Zn^`<0bknl00<0bl2l0<c0_03<`;`00P3<`;`20<g0_@<0cL2l0`3=`K`20<k1_@<0cl6n0`3?`[h2
0=33_`80dLBo00<0d/Bo0=73_`3@`kh0103@`kh20=33_@060=33_P3@a;d0d<Bn0=74_P3BaKl0e<K0
103Fal400`3Fb<40e/S20=O8`P020=O8`P030=K8`@3Fb<00e/S10080e/S10P3Gb<000`3GbL40flc4
0=o@b@020>7BbP040=g>aP3Fb<00gm380=o@b0P0h=381P3PdLP00`3QdLP0h];90>;Bb0060>?Cb@03
0>CCb@3Te<T0i=C900D0i=C900<0iMC90>CDb@3Te<T01@3Ue<T20>GDb0030>GEb03SdlL0hm?700<0
iMG800D0i=C60=73]`3Jc;l0c/6e0=W:_P050>GEa`80i]K70P3UeLH20>?Ca0050>GEaP3TeLD0i=G5
0>CEa03Se<@00P3Rdl<01P3Re<80hM;10>?E``3Se<<0hM;00>?D``@0hmC21`3Se<440>CE`@T0hmG0
0P3TeL020>CF`0050>GF`03?`Zd0LFYN028P7@0A40h05@00000<0?ooo`002P3ooon40000000;01lM
7@1YHVD0Zj2U0<6e^P32][/0`[Nk0<:f^P31][X0`KFj0<6e^@30];T00`30];P40;nc^0030;nc]`2n
/kL0_[>f00@0_[>f00<0_[Bf0;nd]P2o];H01@2o];H01030]KH0`KFg0<6e]`31]KL50<6f]`80`[Jg
1@32]kL30<>h]`D0a;Rg00<0a;Vg0<Fi^035^[P00`35^[P00`36^[P0a[^i0<Nk^@020<Nk^@@0b;bj
0`39_KX00`3:_KX0b[jj0<Zn^`020<Zn^`<0bknl00<0bl2l0<c0_03<`;`00P3<`;`20<g0_@<0cL2l
0`3=`K`20<k1_@<0cl6n0`3?`[h20=33_`80dLBo00<0d/Bo0=73_`3@`kh0103@`kh20=33_@060=33
_P3@a;d0d<Bn0=74_P3BaKl0e<K0103Fal400`3Fb<40e/S20=O8`P020=O8`P030=K8`@3Fb<00e/S1
0080e/S10P3Gb<000`3GbL40flc40=o@b@020>7BbP040=g>aP3Fb<00gm380=o@b0P0h=381P3PdLP0
0`3QdLP0h];90>;Bb0060>?Cb@030>CCb@3Te<T0i=C900D0i=C900<0iMC90>CDb@3Te<T01@3Ue<T2
0>GDb0030>GEb03SdlL0hm?700<0iMG800D0i=C60=73]`3Jc;l0c/6e0=W:_P050>GEa`80i]K70P3U
eLH20>?Ca0050>GEaP3TeLD0i=G50>CEa03Se<@00P3Rdl<01P3Re<80hM;10>?E``3Se<<0hM;00>?D
``@0hmC21`3Se<440>CE`@T0hmG00P3TeL020>CF`0050>GF`03?`Zd0LFYN028P7@0A40h05@00000<
0?ooo`002P3ooon20000000700X:2P0O71h0K6EX0:jRZ02o/;H0`;:g0<:g^`020<6f^P80`KFj00<0
`;Fi0<2d^02o/kP01P2o/kP00`2o];L0_[>g0;jc]P030;jc]P<0_[Bf1@2o];H01030]KH0`;Fg0<6e
]`31]KL60<6f]`H0`[Ng1033^;L50<Bi]`030<Fi^035^[P0aKZh0080aKZh00<0a[Zh0<Jk^037^kT0
0P37^kT01@38^kX0akbj0<Nl^P37_;X0b;fj00<0bKfj00D0b[jj0<Zn^`3:_[/0b[jk0<Zn_0020<^o
_0030<_0_03<`;`0c<2l00<0c<2l103=`;d40<g1_@040<k1_@3?`Kh0cl6n0<o1_P80cl:n0P3?`[l0
1P3@`kh0d<>o0=74_`3Ba;l0dLBo0=74`080d<Bo0P3Aa;l00`3@a;h0d<>m0=33_@020=34_P050=74
_`3CaKl0dlK00=G7`03Fb<800`3Fal430=K8`P040=O8`P3Fb<80e/S10=K8`080elS100D0elW10=O9
`P3Hb/80f/_40=g?b0030>7Bb`030>3BbP3Mc/L0gm3800/0h=791@3QdLT20>;Bb@D0hm?:00<0i=?:
0>CDbP3Te<X00P3Te<X20>?Cb@/0i=C900D0i=G80>GEb03UeLP0iMG80>CEb0020>GEb0050>CEa`3R
dlH0i=G80=C6^P3McL400P3UeLL00`3Ue/L0iMG70>GEa`030>GFa`040>GEaP3Fb;X0g/o00>GEaP80
i=G500H0hmC40=[<_03Kc;d0flbm0>7C`P3Qdl420>?E`P030>;D`P3Se<80hmC300@0hmC21@3Se<46
0>?E`@P0hmG000L0i=G00>CF`03Re;h0e<Nc0<6fX`2JTH40?SXd01L00000303oool000X0ooooP000
00002@0A4100;bd^06=MH@29PHD0]jba0<6e^`2lZk00_Jba0<:f^P030<6e^P030<2e^@30];P0_kBh
00H0_k>h0P2o/kL20;jc]P<0_[Bf1@2o];H20;ne]P<0`;Fg0`31]KL40<6f]`030<:f]`32]kL0`[Ng
00<0`[Ng1033^;L00`34^;P0a;Vh0<Bi^0020<Bi^0D0aKZh00@0a[Zi0<Jk^@37^kT0ak^i0P37^kX0
0`38^kX0akbj0<Rl^`020<Rm^`<0bKfj00L0bKjj0<Zn^`3:_[/0b[jk0<Zn_03;_k`0bknm00H0c<2m
0`3=`;`50<g1_@030<k1_P3?`Kh0c/6n0080cl6n0`3?`[h00`3@`kl0dLBo0=74_`020=74_`<0dLC0
00<0dLBo0=;4`03A`kh00P3@`kd20=34_P060=;5_`3Da/00eLO20=K8`P3GbL<0e/S20P3Fal450=K8
`P80e/S10P3GbL401@3HbL80f/c50=c>a`3MclP0h=7:0080hM;;00L0hM?;0>7Bb`3QdLX0h=790>3A
bP3QdLX0hM;:00H0hM7:0P3QdLT30>7Bb@<0h];91@3SdlX30>?DbP030>CDbP3QdLP0flc20080h=77
2P3Te<T20>CEb@030>CEb03UeLP0iMG80080iMG8103Ue/T01`3TeLP0hmC70>GEa`3RdlD0d<>g0;fa
Y@2k[Z<00`2j[J80202gZil0[:6F0=?5]`3Od<40h]?30>3A`@3Qd/80a;NZ0P3?`K<01P3Pd/40h]C3
0>;D`P3Se<80hmG20>?D``80hmG300<0hmC20>;D`P3Se<400`3Se<400`3SeL80i=G20>CE`P020>CE
`P<0hmG11`3SeL00203TeL00i=K10>CF`@3BaK80T8Mi04e8@@0m>C<06aTF5`00000<0?ooo`002P3o
oomo0000000<00H61P0h=3D0RX:50;R]/P31]KX0_K:g0;N[/02dYZX0_:jb0<6f^P31]KX0`;Fj0P30
];T00`2o];P0_k>h0;nc^0040;nc^080_kBh00<0_kBg0;jc]`2n];L00P2n];L20;jd]P@0_kBf00<0
_kFg0<2e]`30]KL00P31]KL70<6f]`H0`[Ng1033^;L40<Bi^080aKVh1035^[P30<Jk^@030<Nk^@37
_;X0b;bj0080b;bj0P38_K/01038_KX0bKfj0<Vm^P39_[X40<Zn^`040<Zn_03;_k`0bknm0<^o_@D0
c<2m0P3=`;d30<g1_@80c/6m103?`Kh20<o2_P030<o2_`3?`kl0cl>o00D0dLBo00H0dLC00=;4`03B
a<00d/C00=;5`03Aa;l20=74_P0:0=74_`3AaKl0d/K00=C7`@3GbL<0fL_60=W;a@3Fb<<0e/S20=K8
`@@0e/S200<0e/W20=K9`@3FbL400P3GbL80103HbL80gLk70>3Bb`3Pd//30>7Bb`030>;Cc03Qdl/0
h=7:00@0h=7:00<0h=790>7Ab@3QdLT01P3QdLT0103Qd/T0hM;:0>;BbP3Rd/X50>?CbP@0hmC:203T
e<X30>CDb@@0i=G900<0iMG90>CEb@3UeLT00`3UeLT40>GFb@070>GFb03UeLP0iMG80>CDa`2n/JH0
HE]E02`Y9P0402/X9P0802/Y9P18@ch0R7mf0;>WV`34]jX0akZ/0>?Da03Mckl20=k@`0030=O9^P3:
_Zh0elZj00<0hmG30`3Se<<00`3Se<80h]C10>;D`@020>?D`@@0hmG20P3TeL830>?E`@H0hmG000D0
i=K10=g@_02bZ9P0O7AY03Pd;`0J000000`0oooo000:0?ooog`00000014030/;02`Y:`1<B4X0I5eP
09J=TP2o/kT0`kNn0<>g_@2h[;40^Jjc0;fb]`2h[K80]Z^_0;fa]P30]KT0`;Bi0;nd^0060;nc^080
_kBh00@0_kBg0;jc]`2n/kL0_[>f1P2n];H20;nd]P040;ne]`30]KL0`;Fh0<6e^080`KJh1031][L4
0<:g^080`[Ng00<0`[Rg0<>h]`33^;L00P33^;P00`33^KP0a;Vh0<Bi^0020<Bi^0030<Fi^035^[P0
aKZh0080aKZh00D0aKZi0<Jk^P37^kX0ak^j0<Nl^P040<Rl^P030<Nm^`38_K/0b;fj0080bKfj00<0
bKjk0<Zn^`3:_[/00P3:_[/00`3:_[`0bknl0<^o_@020<_0_@@0c<2m0P3=`;d30<g1_@H0c/6n00D0
c/:n0<o2_`3?`kl0cl>o0=34_`040=74_`<0dLC00P3Ba<020=;5`00:0=75`03BaKl0d/Fo0=;5_`3C
a/00eLS20=_=a`3Nd</0f/c70=O9a0D0e/S20P3FbL801P3GbL80f<[30=W;a@3IblD0g<k70=oAbP80
h=;;0P3Qd//01@3Rdl`0h]C<0>7Cb`3Qd//0h=7:00@0hM;:0`3PdLT40>7Ab@030>7Bb@3Qd/X0hM;:
0080h];:00<0hm?:0>?DbP3Se<X0103Se<X;0>CDbP030>CDb@3TeLT0i=G900H0i=G90P3UeLT00`3U
e/T0iMK:0>GFb@020>GFb@060>?Da`3Hb[d0cL2d0;JZW`1VGeT03@`<1P0000001`0820L08b4N048n
>P1GDD`0LFYR09>:O`2HSX<00P2ZWi<00`2KT8D0WiF:0=?6]P020>?E``80hmG200<0hmC30>?E`P3S
eL800`3Se<800`3Od/00b[f]0;BYVP030;:WV0030;FZVP3<_jh0gm6n00D0hmG100L0hmG00>CF`@3T
e/40cl:`06QSF@0S8Ad03`h=01X00000303oool000X0ooooN@0000004`030P801PH601dL7018A4L0
Qh240:fSZ@2i[[@0`KFk0<>g_@31]K/0_k>i0;J[/02n/kP0]jba0;BY[P2f[;00_;6e0<2d^@2o];T0
0P2o/kP00`2n/kP0_k>h0;nc^0030;nc^0030;jc]`2n];L0_[Bg00D0_[Bg0`2n];H00`2o];L0_kFg
0<2e]`050<2e]`80`KJh0`31][L20<6g]`<0`[Ng0`33^;L01033^;P0`kVh0<>i^034^KT20<Bj^@D0
aKZi00@0aK^i0<Jk^P36^kX0ak^j1@37_;X01038_;X0akfk0<Rm^`38_K/20<Vm^P030<Vn^`3:_[`0
b[jl0080b[jk00<0b[nl0<^o_03;_kd00P3;_k`0103;`;`0c<2m0<c0_@3<`;d20<g0_@<0cL6m103>
`Kh20<k2_P030<k2_`3?`[l0d<>o00<0dL?0203Aa<030=;5`0@0dlK000D0eLS20=_>b@3OdL`0gLo:
0=S;a@030=K9``<0e/W200<0elW30=S;a03Lc/L00P3MclP00`3Nd<T0h=7;0>7Bb`020>7Bb`040>7C
c03Qe<`0h]?<0>7Bb`D0h=7:0P3PdLT60>7BbP060>;BbP3RdlX0h]?:0>;CbP3Sdl/0hm?:1`3Se<X:
0>CDbP030>CEbP3TeLT0i=G900<0i=G9103Te/X0303Te/T0iMK:0>GFbP3Ue/X0h]?70=[;`02gZZ00
Ng=/05UCCP17@Sh07ahK00820PT0000000<020P7020N6`0b;b/00`0b;b/00`0^:bP0VI240>?Ea003
0>?E``<0hmG200H0h]G20=c?_@3Eb;L0c<2`0:RNS`1TGUH304M2?@0704M3?@19A3h0K6EL0::HRP36
^jT0gLnl0>?F`@030>?E`@040>?F`@3JcKX0Z9j?03Dc;A`00000303oool000X0ooooMP0000005`02
0@804A0A02@S901<BD/0KFM[09F<TP2`YJ/0`;Jk0<Bi_`31][`0_;2g0;BZ[`2cZJh0]J^`0;bb]P30
]KX0/jV^0;ba]P30]KX0`;Bi0;nd^@2o/kT0_[>h00D0_k>h0P2o];P:0;jd]`80_kFg1030]KP01030
][P0`KJh0<6f^031][P30<6g^0@0`[Nh0P32^;P30<>h^0030<>i^034^KT0a;Vi00<0a;Vi0P35^[T3
0<Jj^P<0a[^j0P37^kX40<Nl^P050<Nl^`37_K/0akfk0<Rm^`39_K/00P39_[/30<Zn_080b[nl00@0
bknl0<^o_@3;_kd0bl2m1P3<`;d20<c1_@030<g1_@3>`[h0c/:n00<0c/:o0P3?`[l0103?`kl0d<?0
0=74`@3Aa<480=74`0@0d/G000/0dlK00=?6`@3Ca/40dlK00=G8`P3Kc/T0g]7<0=g@b`3Kc/P0fLc6
0=W;aP030=W;a@040=W<a@3KcLH0g/o90=oAbP@0h=;;0`3Qdl`20>7Dc0030>;Cc03Qd//0h=7:00@0
h=7:0P3PdLT0103Pd/X0h]?;0>?Dc03Rdl/20>7BbPD0h]?:1@3SdlX40>?Db`030>CDbP3Se<X0hmC:
00D0i=C:0`3Te<T30>CEb@80i=G:103Te/X30>GFbP040<Zm/P27OWL0>CDb00h<31<0000000D05A@B
09fCQ`3Te/D0hmK40>?Ea0030>?E``070>?F``3Ca[H0R81e065KD`1FDDX0<BlZ00T9200500000006
00X92@0V9240DD]508R0M02XWi00YYb>0`2SVH/00`2>QGT0E51801DD4P0L000000`0oooo000:0?oo
og00000000<01@D500d<300C4Q800P0C4Q805P0I61P0924S05IAD`25OX<0[:>X0;bb^033^Kl0a;W0
0<Bh_`33^;h0^k2e0;J[/@2^XjT0/JN/0;jd^@30][X0`;Fj0;R]/P2n/kL0_kBi0;nc^@2o/kP60;jc
^080_k>h00@0_[Bh0;jc]`2m/kL0_[>g1`2n];L20;ne]`D0`;Fh1@31][P20<6g^0030<:g^032]kL0
`[Ng0080`[Rg00@0`[Rh0<>h^033^KP0`kVi0`34^KT20<Bj^@80aKZi0P36^[X30<Jk^P80ak^j0`37
_;X20<Nl^`050<Nm^`38_K/0b;fk0<Rm^`39_K/00P39_[/20<Zn_0<0b[nl0P3;_kd20<_0_@D0c<2m
0P3<`Kd20<g1_@80c/:n1@3>`[l00`3?`[l0d<?00=74`@020=74`@L0dLC000@0dLG00=;5`03BaL00
d/G00P3Ba/020=?6`@050=G8`P3Kc/T0g]7<0=kAc03Md<X0103MclT01@3Nd<T0g]3:0=oAbP3Pd/`0
h=?<0080h=;<00@0h=;;0>7Cc03Qdl`0gm7:0`3Qdl`01@3Rdl`0hM?<0>7Cb`3Pd//0h=;:00<0hM;:
00D0h=7:0>3Ab@3Rdl/0h]C;0>;Cb`030>;CbP040>;BbP3RdlX0h]?;0>;CbP@0hm?:00<0hmC:0>?D
b`3SeL/00P3SeL/00`3Te</0hmC:0>?DbP020>?DbP<0i=C:0P3Te<T30>CEb@@0i=K:00P0iMK:0>GE
bP3Re<P0flg10;^_Y@2OUH`0NW9/030]:QD0000000D05A@B08b3N@3TeLD0i=K50>?Ea0020>;E``04
0>;E`P3Gb[T0T8Ml01hM6P/0000000<00P82014@3`0P7Q/0100P7Q/00`0H5a@02@T80000000L0000
00`0oooo000:0?ooof/0000000<00@4100T82@0A41400P0F51D00`0c<C80HUaO089lP00208AmP@06
08AlP@2<PhT0[ZFZ0<2e^`35^/00a;[00P34^;l02P32]kh0`[Nm0;R]/P2m/[P0]jba0;V^/`31][/0
`;Fk0<2e^P2n/kP20;nd^@030;nc^@2n/kT0_[>h00H0_[>h00@0_kBh0;jd^02n/kL0_K>g1`2n];L2
0;ne]`D0`;Fh00<0`;Jh0<6f^031][P01031]kP01032]kP0`[Rh0<:h^032^;P30<>h^0<0a;Vi0P34
^[T30<Fj^@030<Fj^P36^kX0a[^j00<0a[^j00<0ak^j0<Nk^`37_;/00`37_;X01037_;/0akfk0<Nm
^`38_K/20<Vm^`80bKjk0P39_[`40<Zo_0030<^o_@3;`;d0bl2m00<0c<2m00@0cL2m0<c1_@3<`Kd0
c<6m0P3=`Kh00`3>`[h0c/:o0<k2_`030<k2_`040<k3_`3?`kl0cl>o0=33`0D0dLC1103Aa<020=75
`080d/G000T0d/K00=;5`03BaL00dlK10=?7`@3Eb<80flk90=kAc03OdL`01@3OdL/0103Pd/`0gm;;
0>3Bb`3Pd/`40>7Cc@80hM?<00<0eLS10=S<a03Qdl`0103Re<d00`3Qdl/0h=;;0>3Bb`020>3Bb`80
h=;:00@0hM?;0>;Dc03SeLd0hmG<0`3Rdl/01P3Re</0h]?;0>;Cb`3Rdl/0hm?;0>;Cb`<0hmC;103S
eL/80>?DbP<0i=G900@0i=G:0>CFbP3Te/X0i=K:0P3Ue/X01`3Mcl<0[J:I07mfL01GDD`0=S8_02XW
9@0A40l05@0000002`0?3Pd0GeUB0;ncY@3HbkX0hM?20>7D`P3Md;l0bKf]08^3N00h=C0020P70340
0000303oool000X0ooooJ`00000030030`<09R@U04Y6B@1MF5/0GeYM085kO`2/XZT0`;Jl0<2f_@30
][h0_kFl0<6g_@80a;[000h0a;W00<>h`033^;h0`[Rn0<:g_@31]kd0_K>h0<2e^`2n/kT0_kFj0<2e
^P2n/kT0_[>h0;nd^@L0_[>i00<0_kBi0;nd^02o];P00P2o];P00`2n];P0_[Bg0;jd]`060;jd]`03
0;ne]`30]KP0`;Fh0080`;Fh0`30][P40<6f^080`KNh0`32]kP30<:h^0030<>h^033^KP0a;Vi00<0
a;Vi00@0a;Zi0<Fj^@35^[X0aKZj1@36^kX70<Nl^`<0akfk00<0b;fk0<Vm^`39_[/01039_[`40<Zo
_080bl2m1@3<`;d20<c1_@040<c1_P3=`Kh0c/6n0<k2_`@0c/;00P3?`l00103@`l00d<C00=74`@3B
aL850=;5`@030=75`@3AaL00d/G00080d/G000<0d/K10=?6`@3Ca/400P3Ca/401@3Ca/00e<O10=K9
``3LclX0g]7<00H0gm7;00D0h=;<0=oBc03Pd/`0h=;<0>7Cc@050>7Dc@030=W<a@3KcLL0hMC<00@0
h]C=00`0hM?;0>3Bb`3Pd//0h=;;0>7Bb`3Qdl/0gm790>7Cb`3Re<`0hmG=0>;Dc03Rdl/20>;Db`@0
h]?;0P3Re</20>?Db`D0hmG;1`3Se<X20>?EbP80i=G:00P0i=K:0>CEbP3Te/X0i=K;0>GFbP3Ue//0
bKbb05QCCQX0000000X01PH502DS801RG5D0RH1g09ZAQ02MU8L0SXEk05iHD@0N7AX010@3<P00000<
0?ooo`002P3ooomU0000000300820P0410@010@400<01PH600P02`/;04I3A@29PhP0[JBZ0;BZ/@2m
/kX0a;[00<Fk`P80a[_200<0aK_10<Bj`034^L000P34^L020<:g_P80`KNm00T0`KNl0<6f_031][`0
`;Jk0;jd^@2f[;40/jR^0;R]/P2m/[P0102n/kT40;jc^0<0_[Bh00<0_kBh0;jd^02n];L01P2n];L0
0`2n]KL0_kFh0;ne^0040<2e^080`;Jh0`31][P30<6g^0<0`[Rh00@0`kRi0<>h^033^KP0`kVi1@34
^KT00`34^[T0aKZi0<Fj^P020<Fj^P040<Fk^P36^kX0a[^j0<Jl^`D0akbk1037_K/20<Rm^`030<Rn
^`39_[/0bKjl0080bKjl0P39_k`30<Zo_0<0bl2m0`3<`;d20<c1_@030<c1_P3=`Kh0cL6n0080c/:o
103?`l020=34`@050=75`@3AaL80dlK20=?5`P3BaL801@3BaL420=75`@80d/G000<0d/K10=G8``3C
al400P3Ca/40103Dal80e/W40=W<a`3NdL/40=oAc0<0gm;<00@0h=;<0=oBc03Pd/`0h=;<0`3Qdld3
0>7Dc@030>3Cc03Pd/`0hMC=00<0h]C=00<0h]G=0>7Dc03Qdl/00`3Qd//01P3Qdl/0gm790>7Cb`3R
e<`0hmG=0>;Dc080h]C;00<0h]?;0>;Db`3Re</00P3Re</30>;Dc0@0hmG<0P3SeL/00`3Se</0hmC:
0>?EbP040>?EbP80hmG;0P3Se/X20>CFbP060>CFb`3Pd/H0`kN]09R?Q`1cK6D0<2d[700000001P08
1`L04Q4?01DD4P0E51804A0?00L71S@00000303oool000X0ooooH`0000000`0<2``06QTJ03Xg>P02
059=D@0:06ANH`1NFEd0EE5D051<C`1eKg<0XibQ0;bb^@32^;l0a;[00<Bj`@<0aK[100P0a;W00<>i
`033^;l0`kRo0<:h_P32]kh0`KNm0<6g_0<0`KJl00H0`;Jl0<2f^`2j/;D0/jV^0;Z`]@2m/[P20;jc
^@80_[Bi0P2n/kT30;jc^0D0_[Bh00<0_[Bg0;fd]`2m];L00`2n];L20;je]`80_kFh1030]KP00`30
][P0`KJh0<6g^0040<6g^080`[Nh00D0`[Rh0<:h^@32^;T0`kRi0<>i^@030<Bi^@80a;Zi00<0a;Zj
0<Fj^P35^[X00`35^[X00`35^kX0a[^j0<Jk^P020<Jk^`050<Jl^`37_;/0akbk0<Nl^`37_K`00P37
_K/20<Rm^`80b;jk00@0bKjk0<Vn_039_[`0bKnl103:_k`0103:`;d0bl2m0<_0_@3;`;d20<c0_@<0
c<6n00D0cL6n0<g2_P3>`[l0c/:o0<o2`0030<o3`0030=34`03AaL80dLG20080d/G20P3Ca/<00`3B
aL80d/G10=;5`@020=;5`@030=;6`@3BaL40d/K10080d/K100P0dlO20=C7`P3Cal80dlK10=C7`P3G
b/D0flk90=g@b`80g]7<0P3OdL`70=oBc0030>3Cc03Qdld0hM?=00<0hM?=00<0hMC=0>7Cc@3Qe<d0
0`3Qe<d30>;Ec@030>7Dc03Qd//0hM;;00@0hM;;00D0h]?;0>?Ec@3SeLd0hmC<0>;Dc0040>;Db`<0
h]C<00<0h]G<0>?Ec03SeL`00`3SeL`;0>?Eb`090>?EbP3Se/X0i=K;0>?Db@2cZ9l0BTA001hM6`0H
5aD02`X905H00000303oool000X0ooooH`0000000`0S8B<0C4Q;089lP@0209^CVP080:jU[02YX:L0
WYJL09F=T`2OUYd0/jV`0<6g_P35^l820<Bk`P80a;_100@0a;[10<>i`033^;l0`[Rn0P32]kh20<6g
_@<0`;Jl0P30][/00`2o]K/0^:jc0;F//0080;jc^@<0_[Bi102o];T20;jd^080_KBg0P2n];L00`2n
]KP0_kFh0;ne^0020<2e^0L0`;Jh00<0`KJh0<6g^031]kP00`32^;P30<:h^@<0`kVi0`34^KT01034
^[X0aKZj0<Fk^`35^k/70<Jk^`<0a[bk00@0akbk0<Nm^`37_K/0akfk0P38_K/30<Rn^`050<Vn^`39
_[`0bKnl0<Vo_@3:`;d00P3:`;h30<_0_@030<_0_P3<`;h0c<2n00@0c<6n00@0cL;00<k2`03>`l00
c/?0103?`l001@3@a<40d/G30=;5``3Ba/<0dlK30080dlO300<0dlK30=?6`P3Ca/80103Ca/830=?7
`P060=G8``3Fb/D0eLW40=G9``3Gb/D0f/g8103NdL`00`3OdL`0gm;<0=oBc0050=oBc0030>3Cc03Q
dld0hM?=00D0hM?=103Qe<d01P3Re<d0h]G=0>;Ec@3ReLd0h]C=0>7Cc0<0hM?;00L0gm7:0>7Cb`3R
e<`0hmG=0>?Fc@3Se<`0h]C<00<0h]C;0`3Re<`30>;Ec0D0hmG<1`3SeL/30>CEb`060>CFb`3SeLX0
hM?80<Fi[`1KEE402@P8F@00000<0?ooo`002P3ooomP0000000600P7200C4Q<0:bT[06QSI`2HTIL0
_K>k0P31]kl02036^l@0a[_30<Jk``32^<00_[Bk0;ne_@33^L40a;_20`34^/801034^L40`kW00<:h
_`32]kl20<:g_P80`KNm0P30][`30<2f^`040<2e^`2o]KX0_K:h0;ba]`80_[>i0P2n];T50;jc^@H0
_[Bi0`2n];P20;jd]`030;je]`2n]KP0_kFh00@0_kFh00D0`;Fh0<2f^030][P0`;Jh0<6g^@040<6g
^0040<:g^032^;T0`[Ri0<:h^@<0`kVj0P34^KX30<Bj^P030<Fj^P35^[/0aK^k00L0a[^k00@0a[bk
0<Jl_036_K`0a[fl0`37_K`40<Rn_080bKjl00@0bKnl0<Vo_@39_kd0b/2m0P3:`;h30<_0_P<0c<2n
103<`Kh0103<`[l0cL;00<g2`03>`l040<o3`0030=34`@3AaL80dlK40080dlK3103Cal<01@3Ba/80
dlK20=34`03@`kl0e/W500<0e/[500T0el_60=[=b03Jc/T0f/k90=W=b03Kc/X0gM3;0=kBc@3NdL`0
0`3OdL`30=oBc0<0gm;=0P3Pdld50>7Cc@D0hMC=00<0h]C=0>;Ec@3ReLd0103ReLd30>;Dc@050=c>
a`3ReLd0hmG=0>?Ec@3SeL`00`3Re<`01@3Re</0h]C<0>;Dc03Re<`0h]G<00h0hmG<0P3TeL`0203T
eL/0i=K;0>GFc039_;80W96:05QBCP0D4a800@41F@00000<0?ooo`002P3ooomO0000000700<30`0U
92D0CT]>07UcN@2PUih0/jZb0;ne_@020<:h`0<0aK_300@0_KBk0;N]]@2l/[T0`[S00P34^/801P34
^/40a;W00<>h`032^;l0`KNn0<6g_@80`;Jm0P30][`00`30]K`0_kFk0;ne^`020;ne^`030;ne^P2o
];X0_[Bi00L0_[>i1`2n];T30;jd^0030;fd^02m];L0_[Bh0080_[Fh00@0_kFh0;ne^@2o]KT0_kFi
1030][T30<2f^0050<2g^031]kT0`[Ni0<:h^@32^;P00`32^;T30<>i^P030<Bi^P34^[X0a;Zj0080
a;Zj00@0`KJg0;jd]035^k/0a[^k0`36^k`30<Jl^`@0a[bl00<0a[fl0<Nm_037_[`01038_[`02039
_[`0bKnl0<Vo_@39_kd0b[nm0<Zo_P3:_kd0b/2n0`3;`;h20<c0_P@0c<6n00<0cL700<g2`03=`/00
0`3>`l001@3?`l00d<C10=34`@3@a<40d/G300<0dlK4103Cal<0103Dal<0cl?00;V^Z`3=`Kh30=c?
b`040=c@b`3Md</0g]7<0=gAc@<0g]7=0P3Nd/d20=kAc0@0gm7<00L0gm;<0=oBc@3Od/d0gm;<0>3C
c@3Pdlh0hM?>00<0hMC>0`3Qe<d20>7DcP030>7EcP3ReLh0h]G>00@0h]G>103ReLd00`3Qdl/0hmG=
0>?Ec@020>;Dc0040>;Db`3Rdl/0h]C<0>?Dc0<0h]G<0P3Se<`80>?Ec0@0i=G<0`3Te/`01@3Re<X0
f<[10<Fi/020N780:BHT05`00000303oool000X0ooooG`0000001@061PH0A45408R1Q`2aZ:l0_kFn
00@0a;[200D0a;_30<Bj`P34^/80a;[20<>j`P030<>j`@070<>i`@33^<00`[S00<:g_`31]kh0`KNm
0<2f_@020<2f_0030;nf_030][`0_kFl00<0_kFk00<0_kFj0;nd^P2n];X00P2n/kT00`2n/kX0_[Bj
0;jc^@020;jc^@P0_[Bi00<0_[Bh0;fd^02m];L00P2m];L00`2n];P0_[Fh0;ne^@030;ne^@030;nf
^@30][T0`;Ji0080`;Ji0`30]kT30<6g^0050<6g^@32^;T0`[Rj0<:h^P32^KX00`33^KX02034^[X0
a;Zk0<Fj^`35^[/0a;Vj0;^a/@2h[Zl0a[^k0`36^k`70<Jl_080a[fl00<0akfl0<Rn_038_[`00`38
_[`01@39_k`0bKnm0<Vo_@3:_kd0b[nn0080b/2n1P3;`;h20<_1_P040<c1_`3<`[l0cL;00<g2`080
c/?100<0cl?00<o3`@3?a<400P3@a<403@3Aa<40dLG20=;6``3Ba/<0b;fj0;J[Z@2VW9T0aKZg0=G8
a@3=`[h0^[2]0:JLV@3Ba/800P3NdLd20=gAc0030=kAc03NdLd0gM7=0080g]7=0`3Nd/d30=kAc0<0
gm7<00@0gm;<0=oCc@3Od/d0gm;<0P3Pdld50>7DcP80hMG>0P3Qe<h40>7Ec@030>;Ec@3ReLh0h]G>
0080h]G>0P3ReLd00`3Qe<`0hmG=0>?Ec@040>;Dc0060>;Ec03Se/d0hmG=0>;Ec03SeL`0hmC<203S
eL`40>CEc0090>CFc@3CaKd0]:VQ0;6VWP2WW9@0Pgaf065JE@0k=cD04a4A05`00000303oool000X0
ooooG`000000100K6Q/0KfU_0:nV[P32^<420<:i`@050<2g_`30]l00`;O00<:i`@33^L800P33^/80
2P33^/40`[W10<>i`033^<00`[O00<:g_`31]kl0`KJn0<2g_P30][d20;nf_0050;V_]P2dZk00]Zbb
0;bb^02n]KX00P2o]KX00`2o];X0_[>j0;jc^P040;jc^@80_K>i0P2n/kT70;jd^@@0_KBh00<0_[Bh
0;je^02o]KT01@2o]KT20;nf^@<0`;Ji0P30]kT01031]kT0`KRi0<:h^@32^;T30<:h^P<0`kVj00<0
a;Zj0<Fj^`35^[/00P35^[/00`34^KX0^k2a0;bb/P020<Jk_0<0a[^k1@36_;`01036_K`0akfl0<Nm
_037_[`40<Rn_0040<Vn_039_kd0bKnm0<Vo_@80b[nn00<0b/2n0<_0_`3<`;h00P3<`;h01P3;`;h0
bl6n0<_1_P3<`Kh0c<6o0<c2_`80cL;00P3>`l00103=`/00b;fj0;nd/P2m/[020;^a[P0=0;>YYP2Y
Wi`0XYRF0::HUP2?QX@0Lfe[06]UH`39_[/0fLg:0<>h]@34^KH0`KJc0=W=b@020=kAc@<0gM7<1@3M
dLd20=kAc@<0g]7<0P3OdL`00`3Od/d0gm?=0=oCc@020=oBc@040>3Cc@3Pe<h0hMC>0>7DcP80h=C>
00<0hMC>0>7EcP3QeLh00P3Qe<h20>7EcP030>;EcP3QeLh0h]G>00<0h]G>00D0h]K>0>;Ec@3Re<d0
hMC<0>;Ec@030>?Ec@070>3Cb`3Kc/H0c<2i0;fbZ`3Gbl<0g]790>7Cb`060>?Ec@@0hmG<00T0i=G<
0>CFc03Te/`0hM?:09ZARP0W9R@071/I01PG5@0:2@T0G`00000<0?ooo`002P3ooomM000000050082
0P0R8280H5aP0::JX@2n]Kh00P32^L420;je_@80`;O00P32^L430<>i`@0?0<:i`031^<00`[No0<6g
_P30][h0`;Jm0;bc^@2g[K@0]:^a0;bc^@2n]K`0]jfd0;:Y[`2g[[@0_;>i00@0_[Bj0`2n/kX20;jd
^P030;fc^@2n/kT0_[Bi00T0_[Bi0P2m];P20;jd^0030;je^02n]KT0_kFi0080_kFi0P2o][T50<2f
^@80`;Ni0`31]kT01032^;T0`[Rj0<:h^P32^KX30<>i^P030<Bj^P34^[/0aKZk0080aKZk0P35^k/0
0`35^k`0a[^l0<Jk_0040<Jk_0@0a[bl0P36_K`00`37_K`0b;jl0<Rn_0030<Rn_0@0bKnm0P3:_kh0
103:`;h0b/2o0<_0_`3;`;h20<c0_P050<_0_P3;`Kl0bl6o0<c1_`3<`L000P3=`/001@3=`/40c/?1
0<k3`@2n];80QGil00@0?CTi00d0>SHf03Hc<`0c<300<c0`02`Z:@1VH5l0YIbJ0=G:aP3Ld<`0dlO4
0<k3`03Cb<@0g=3<00<0g]7=1`3MdLd00`3NdLd0g];=0=kBc@040=oBc@<0gm?=0P3Od/d0103Pdld0
h=?>0>3CcP3Pe<h20>7DcP030>7EcP3ReLh0hMG>00D0hMG>00<0h]G>0>7EcP3ReLh00`3ReLh00`3R
e/h0gm;;0=W=a@030>;Ec@<0hmK>00D0`kVb08Z2OP32^:l0dLFm0=c>aP060>?Ec@80i=K=00<0h]C;
0>3Bb@3Da[h00P35^[400`2_Xi`0FE=?00L61P1R000000`0oooo000:0?oooe`0000000D00P82010?
401KEU/0WiRP0;fd_@020<>j`P030<6h`@2n]Kd0^K2h0080_KBl00<0`;Jo0<6h`031]l000P31]l00
1031]kl0`KNn0<6g_`30][h20;nf_@050;^b^@2i/;H0^k:h0;jd^`2n]K`00P2o]K`00`2n]K/0_[Bk
0;jd^P030;jd^P80_[>j00D0_[Bj0;jc^P2m/kX0_K>j0;jd^P080;jd^@80_[Fi0`2m];P00`2n]KP0
_kFi0;ne^@020;ne^@80_kJi0`30][T40<2g^@040<6g^@31^;T0`KRi0<:h^@80`[Rj00<0`[Vj0<>i
^P33^KX00P33^KX50<Bj^`030<Fk^`35^k`0aK^l00D0a[^l0P36_;`40<Jm_0030<Nm_038_[`0b;jl
00<0b;jl0`39_kd30<Vo_P<0b/2n103;`;h20<_1_P0:0<_1_`3<`[l0cL;10<g2`@3=`/00bKjm0<2e
]02aZ:D0QWmn044m?0P0000000L04Q8B0:fTXP3Kcl`0f<c90<k3`03?`l00fLg90080gM7=00<0g]7=
0=gAc@3MdLd00`3MdLd20=gBc@D0g];=203Od/d00`3Odld0h=?=0>3CcP020>3DcP80hMC>00<0hMG?
0>7EcP3QeLh00`3QeLh60>;EcP80h]K>00<0hmK>0=O;a03>`[`00`3ReLd30>?FcP050=S<a034^K80
el_30=[>aP3OdLX01@3SeLd30>CFc@030<Bg/02BRX@0GUUE0080?CXg00<0<Bh/01<B4P000000HP00
000<0?ooo`002P3ooomL0000000:00h=3P10?T00W9BL0;fd_@32^L80`[W30<:j``31^<00`[W10;bc
^`80`;Jo00D0`;Jn0<6f_`30]l00`;Jo0<2g_`020<2f_`80`;Jn00/0_kFm0;ne_02o][`0_kFl0;je
^`2n];/0^K2f0:jUZ`2WWZ@0/ZV_0;^b^0020;jd^PD0_K>j1@2m/kT00`2m];T0_[Bi0;jd^@060;jd
^@80_KBh00<0_KFh0;je^@2n]KT0102o]KT30;nf^@030<2f^@30]kT0`KNi00@0`KNi0P31^;T20<:h
^P040<:i^P33^KX0`kVj0<>i^`@0a;Zk00<0aKZk0<Fk^`35^k`00`36^k`60<Jl_0<0a[fl00@0akfl
0<Nn_038_[`0b;jm0P38_[`01038_[d0b;nm0<Vo_@39_kh30<[0_P80b/2o00@0bl2o0<_0_P3;`;h0
bl2o103;`Kl02@3<`/00cL;10<_0_`2i[jh0RX:1079/J`1KEUD0?c/k01/J6P060000000900H51@0o
?3/0OWQe0<k4`@3Ld<d0_;:_0;V_[03>`l00f/k:00D0gM7=0P3MdLh00`3Md/h0gM;=0=gBc@060=kB
c@H0gm;=00<0gm?=0>3CcP3Pe<h01@3Pe<h00`3QeLl0hMG>0>7EcP050>7EcP040>;EcP3Re/h0h]G>
0>7EcP80h]K>00H0_;:[09J=R02WWIP0cL6k0>7Dc03ReLd50>;FcP80hmK>00<0hmK=0>?Ec@3SeLd0
0`3SeLd01@3Qdl/0elW00<2e[@1gL6/07adL06P00000303oool000X0ooooG00000001P0J6AX0Mg5g
0;R_^02o]/00`;O10;nf_`80`;O000D0`;Jo0;jd_030]l00`;O00;ne_P020<2f_`<0`;No0P30][h4
0;je_@090;je_02n];/0_[Bk0;^b^02f[K<0]:^`0;R^]02l/kT0_[Bj00@0_K>j00@0_KBj0;fc^P2m
/kX0_K>j0P2m];X70;jd^P@0_[Fi00<0_KFh0;je^@2o]KT00`2o]KT20;nf^@<0`;Ji00<0`;Ni0<6g
^@31]kT00P31]kT20<6h^@80`[Rj0P32^K/01033^KX0`kVk0<>j^`34^[/30<Bj_0070<Bj^`35^k/0
aK^l0<Fk_036^k`0aK^l0<Fl_0050<Jl_0070<Jm_@37_Kd0akfm0<Nm_037_[`0akjm0<Rn_@020<Rn
_P@0bKnn0P39`;h0103:`;h0b/2o0<[0_`3:`;l30<_0_`80bl6o00T0c<6o0<c1`03=`L00cL;10<g2
`02l/k40NW9a01XH600=30`02@000000200@4100SHJ40=76a03Dc<<0eL_40;:YYP3:_k`0gM7>2`3M
dLd30=gBc@<0g];=1@3Od/d00`3Odld0h=?>0>3DcP020>3DcP050>7DcP3Pe<h0h=C>0>3DcP3QeLl0
0`3QeLh04P3QeLl0hMG>0>7EcP3QeLh0h]G>0>?Fc`3Re/h0h=?<0=[?a`3EbL80QGii03Xf=019AD<0
NG9^0:JLU`2k/:X0c<6j0=S<a0<0hmK>0P3Se/d02`3SeLd0hmK=0>?Fc@3Re<`0cL6i0;6VW`2RVI80
P7Ud05]FDP0f<S003Pd<06P00000303oool000X0ooooG00000002P0M6ad0S8B<0;je_P31^L40_KBm
0;Za^P2l/[/0_[Fn0<2f_`30]kl20;nf_`H0_kJn00<0_kJm0;ne_@2n]Kd00`2n]K`00`2n];/0_KBk
0;fd^`020;fd^`050;^b^02bZJl0ZZ:X0;:Y[`2j/;L0202m/kX0102m];X0_KBi0;fd^@2m];T50;jd
^@P0_[Fi00<0_kFi0;nf^@2o][T00`2o][T30<2g^@80`KNi00@0`KRi0<6h^P31^;X0`KRj0`32^KX0
0`33^K/0a;Zk0<Bj^`030<Bj^`030<Bk_035^k`0aK^l00@0aK^l00<0aKbl0<Jl_036_;`00P36_;`0
0`36_Kd0akfm0<Nm_@030<Nn_@040<Rn_@38_[h0b;nn0<Vo_P<0bKno00<0bL2o0<[0_`3:`;l01@3;
`;l30<_1_`070<c1_`3=`L00c<700<Vn_02`YjH0OgMg03Xg=`090000000<00820P0=30`0:RLW0;Z`
[P3MdLh0^K>X0;J_YP35^kP0f<c90=g@c@3MdLd0g=7=0`3LdLh30=gAcP<0gM7=00@0gM;=0=gAc@3N
dLd0g]7=103Nd/d20=oBc@80gm?=00H0h=?>0>3DcP3Pe<h0h=C>0>7DcP3Pe<h20>7EcPD0hMG?0P3R
e/l03`3QeLh0gM7:0<2e[`2/Xid0ZZ6K08EnNP1ZI640?3Pf00P81`0000002PX901hL6`0n>SP0JVAP
0:fTW@050>?FcP090>?Ec@3Pdl/0gm;:0;nd[@1LEU806aTH018A4@081`L07ADD00D0B4A100<0AD4n
020N7@000000HP00000<0?ooo`002P3ooomK0000000500H51P0O7Ql0PG^10;F/]@30^<000P30]l00
0`2n];h0_kFo0;nf_`080;nf_P030;nf_@2n]Kd0_[Fm00@0_[Fl00X0_[Fk0;fd^`2m];/0_[Bk0;fd
^`2j/KP0/:N^0:ZRZ02cZ[00^[2g1`2m/kX60;fd^P<0_[Bi2@2n]KT40;nf^P030<2g^P30]kT0`;Ni
0080`KNi0`31^;X00`31^;/0`[Rk0<:i^`030<>i^`030<>j^`34^[`0a;Zl00<0a;Zk1P35^k`20<Fl
_@040<Jl_@36_Kd0a[fm0<Jm_@80akfm0P37_[d20<Rn_@030<Rn_P38_kh0bKnn00<0bKno0P39`;l0
1@3:`;l0bl2o0<[0_`3:`;l0b/6o00D0bl6o0P3<`L001@3;`;h0/JNV059=C00V92<03Ph=00T00000
00T03`h>04M4@`29PH00dlS50=cAcP2`YjD0clC10=gAcP3Ld<d00P3MdLd40=cAcPD0gM7>0P3Md/h0
0`3MdLd0g]7=0=kBc@040=kBc@050=oBc@3Odlh0gm?>0=oCcP3Pdlh00`3Pe<l01@3Qe<l0h=C?0>7E
c`3QeLl0h=G?0080hMG?00`0hMG>0>7Ec`3Re/l0h]K?0=c@b@2MU8l0F5=@03Hc<P0W9B@04Q4A00<3
0`020P840000000=01hL6`1UGe`0ZZ6K0<g0^P3>`[/0eL[20=W>aP3LclL0b;ff09bCS@2;Pgh0FeIC
01@C4P030000000305A;B02h[ZL0^:jW00<0^:jW00<0]J^T06YSG`0A4100HP00000<0?ooo`002P3o
oomF0000000300X92P0M71d0<Blb0080=C<f00H0AD9506=OI02ESYD0ZZ>Z0;V`^@2m];d30;nf_`03
0;jf_P2o][h0_kJn00<0_kJn00<0_[Fn0;je_@2n]Kd00P2n]Kd20;fd_0H0_KBk0P2m/k/01@2l/[X0
^[6h0;Z`^02j/KP0^k:i00@0_K>j102m];X50;fd^@030;fe^@2n]KX0_[Fj00L0_[Fj0P2o][X50;nf
^@060;ng^@30]kT0`;Ni0<2g^@31^;T0`KRj1032^K/30<>j^`@0a;Zl0P34^k`50<Fk_0030<Fl_035
_;d0aKbm00<0a[fm0`37_Kd20<Nn_@80b;jn0P38_kh00`39_kl0bL2o0<Vo_`020<W0_`@0b/2o00@0
b/6o0<_1_`3;`L00c<700P3<`L401P39_kh0a;Zj0;jd/P2ZXZ40LVa[010@40/0000000P07adM09R@
SP3Jcl`0f/o<0=c@c@3;`;h0f<g:0=c@c@80g=7=00@0gM7=0=cAcP3LdLh0gM7>203Md/h00`3Nd/h0
g];=0=kBc@030=kBc@030=kCcP3Odlh0gm?>0080gm?>00<0h=?>0>3Dc`3Pe<l00`3Pe<l20>3Ec`@0
hMG?00D0hMK?0>7EcP3Odl`0_;:/04Q4@P0:0000000A03Ld<P2QV980b;ff0<Nl]P2YX9X0PG]e07A^
JP1eKf/0BdM401<B4@071`H010<302dZ:01bK6L0T8R209>;Q@2l/JT01@3Wfm401P3Pe</0^JnW051;
B@0F51@03@d<00820Ul00000303oool000X0ooooEP0000000`0F5AH0@Ci106eYKP0207MbM`0508Eo
QP2OV:00^;2h0;J^]`2k/k/0202n]Kh20;jf_P050;fe_@2m];d0_KBm0;fd_@2m]Kd00P2m];`60;fd
^`80_K>k00L0[jJ]0:FLX`2QVIl0Z:2W0;6X[`2m/kX0_;>j00@0_K>j00<0_KBj0;bd^@2l];T0102l
];T20;fd^@H0_[Fj0P2n]KT70;nf^P80`;Nj0`31^;X30<:i^`030<>i^`33^[`0a;Zl00D0a;Zl0`34
^k`00`35^k`0aK^m0<Fk_@050<Fl_@<0a[fm1037_Kd01037_[d0b;jn0<Ro_P38_kh20<Vo_`<0bL2o
0`3:`;l00`3:`<00bl700<_1`0020<_1`080c<7000L0a[bk09><R`1mMWD0IF1P04a8B00Z:2P010@4
00/0000000L0<S4`0<2f]03Kcld0e/S50=_>b`3Kd<d0g=7>00@0gM7>0P3LdLh:0=gBcP@0g];=0`3N
dlh30=oCcP030>3CcP3Pe<l0h=C?0080h=C?0`3PeLl00`3QeLl0h]K?0>7Ec`020>7Ec`040=gBb`2l
/Z`0IV5N024O7PX0000000H08AlN05iIE@2>QX40Z9nI06mYI@0K6AT50000000600/;2P1dKVT0dlS0
0>CHcP3UfLl0i][@0P3Wfm402@3Wfm80j=_B0>SKdP3Uf<l0g];90:VPV@22O7H0DDe:00h=3@1O0000
00`0oooo000:0?oooe@0000000D00`<401/J701?Be00R8:80:nX/@020;R`^@030;Va^P2k/k`0_KFn
0080_KFn00<0_KFm0;bd_@2l];d00P2m];d;0;fd_0H0_KBk0`2m/k/20:ZRZ0030;2W[P2aZ:l0]Zfd
0080_;>j0`2m/kX00`2m];X0_;Bi0;bc^@060;bd^@030;fd^@2m]KT0_[Fj00D0_[Fj00@0_[Jj0;nf
^P2o][X0_kJj1@30]kX20<2h^P030<6h^P32^K/0`[Vk0080`[Vk00<0`kVl0<>j_033^[`00`33^[`4
0<Bj_080a;^l00<0aK^m0<Fl_@35_;d00P35_;d00`35_Kd0a[fm0<Jm_@020<Jm_@040<Nm_@37_[d0
akjm0<Nn_@80b;jn00@0b;nn0<Ro_`38_kl0bKno0P39`;l20<[0`0030<[0_`3:`<00bl7000<0bl70
0P3<`L401@3:`;l0Zj:R01lM7@0B4A401@D500/0000000P01@D501hM7@0N7Ad0N79a0=S=b`3LdLh0
fLS50=[<bP/0g=7>00<0gM7>0=gBcP3Md/h0103Md/h40=kBcP<0g]?>0`3Odlh20>3Dc`@0h=G?0P3Q
eLl20>;Fc`060>7Fc`3Kd<X0e/_40<:h/P1YHf000P822`0000001P081`L05aHE03<`;P15@T00;B/Y
00/:2P80000000H04a8A02h[:P13?ch0RX9m0<c1^P3Selh30>OJd@80im[@00h0i]W@0>GIc`3UfLl0
iMW?0>?Gc@3QeL`0i][@09N?R01FD4d0LfiY07YdKP1dKVT0@Shk00L71P<0000000D061HE05A?B`1e
KVT0H5]G02@Q801B000000`0oooo000:0?ooodl0000000X01`L800l>3`0C4Q<02`/<00@410071`L0
>cPk07ehOP2SW:D0/:Ra0P2bZ[<01@2cZk@0]Zff0;Zb^`2l];d0_KBn00D0_;Bm1P2l];`70;fd_0L0
_;>k00<0[:>Z0;F/]02l/kX00P2l/kX20;fc^P<0_KBj0P2l];T00`2l/kT0_;Bi0;bd^@030;bd^@03
0;fd^@2m]KT0_[Fj00D0_[Fj00<0_[Jj0;nf^P2o][X00P2o][X30<2g^P80`;Rk0P31^;/00`31^K/0
`[Vk0<:i^`020<:i^`D0`kZl1034^[`20<Bk_0030<Fk_@35_;d0aKbm00<0aKbm0`36_Kd20<Nn_@@0
akjn00@0b;jn0<Ro_`38_kl0b;no0P39`<020<W0_`80b/2o00<0b/300<_0`03<`L400`3<`L40103;
`L40b;jn0;F][01hLg8>0000000502/Y:@2DSH`0U8f<0<k4`@3Kd<d00P3LdLh20=_AcPP0g=7>00@0
e<W60<_0_P3<`Kh0e<W61@3Md/h40=kBcP80g]?>0`3Odlh30>3Dc`<0h=G?00X0hMG?0=gBb`3Md//0
b;jh0;J]Z02aZ:<0Uhn;07UcL01QG5T0:bPX500000001P0m>SL0UHf80;nf[P3Odl/0i]WA0>KJd@<0
im[A00<0i]W@0>3Db`3Bakh00P32^K00502l/ZX0/:NO0:fTW@3Gc<<0`[R`0<>h[`3MdLL0h=C:0=gA
a`2YX9P0JF=N038_;@051@@0000003hk>02eZj80el_10=;7_@1eKVT010@35`0000001P030`<0>3Da
06UTG01YI5`0Mg1X08R1M`80SHIl00D0PG]a071ZH@1ZI5`0?CXe00X92@0]000000`0oooo000:0?oo
odh0000000T01PH602`Y;01FDeP0KfY`06IRI`1FDUH0EU9G08R2RP2`Z;800P2k/kd40;bc_@@0_;Bm
3P2l];`0102m];/0^[6h0;>Z/P2/Y:/30:NOYP050:ZRZ@2aZ;00^k6i0;:Y/02h[kL01P2l/kX00`2l
];X0_;Bi0;bd^@060;bd^@030;be^@2m]KX0_KFj00D0_[Fj00D0_[Jj0;nf^P2o][X0_kJj0;ng^P04
0<2g^P<0`KRk00<0`KVk0<:i^`32^K/00`32^K/30<>j_0030<Bj_@34^kd0a;^m00<0a;^m00<0aK^m
0<Bk_@34^kd01035_;d01035_Kd0a[fm0<Jm_@37_Kd60<Nn_P<0b;no0`39`;l00`39`<00b/300<[0
_`020<[0`0030<_1`03;`L40bl710080bl7100@0`kZi09fDU01VHF40=C8b300000000`030`<030`<
06MQH0020<Ji]`050;:MV`31/:h0e/W70=cAcP3Kd<h00P3Ld<d40=cAcP80g=;?00D0g=7>0=G9aP3A
a/80bKnk0<Rm^P050=gBcP@0g];>0P3Ndlh0103Nd/d0gm?>0=oDc`3Oe<l20>3Dc`<0h=G?00P0hMK@
0=_@bP3Kd<X0eL[509fET@12?Sd03Pd=00820Q@0000000D061LE04m;B02ITX/0f/o70>?GcP020>OK
d@070>KJd@3Wf]80im[B0>OJd@3UfM00h=C;0=O<``020=W>a0040=cAa`3Gbl80/jZR0=76_@80j=cB
0140j=cA0>SKd@3Xg=40h=C90=kBb02l/ZX0IV1K01PG5@1CCd/0c/:h0>KIcP3UfLh0/:FM01<B4@07
1`H01@D400410@0D0000000600H61P1aJf<0e<Vj0=C9^P3Jc[l0hMG40P3SelH01@3Odl<0elbl0=G9
^@20NW406QTF02d00000303oool000X0ooooCP0000002P0E51D0HemT09fFW`2_Z;40ZjB^0:FNY`2U
WJL0/ZZd0;Va^`2k/[d20;^c_0060;Zb_02j/[/0^[6k0;Zb_02k/k`0_;>m402l/k`00`2e[KD0[jN^
0;B[/`030;B[/`050;>Z/P2e[;@0^k:i0;R_]`2k/[T00`2l/k/0102l];/0_KBk0;fd^`2l];X80;bd
^@030;fe^P2n]KX0_[Fj00@0_[Fj0`2n][X20;nf^P<0`;Nj00D0`;Rj0<2h^`30^;/0`KRk0<6i^`05
0<:i^`040<:j_033^[d0`kZl0<Bj_@P0a;^m00<0a;bm0<Fl_P35_;d00P35_Kd01036_Kd0a[fn0<Jm
_P37_[h30<Nn_`80akjn0`38_kl01038_l00bL300<W0_`39`<030<[0`0030<[1`03;`L40bl710080
bl7100H0b/310<Jl_@2QVIT0AD5100T92@0410@<0000000302LU9@1kM7<0^:n]0080bKjk00@0akRf
0=31_`3IcL/0g=7>0P3Ld<h20=c@c@040=cAcP3LdLl0g=;?0=cBc`80fm3=0P3MdLd00`3Db<D0`KNd
0=gBcP040=gBcP@0g];>00<0g]?>0=kBcP3Jc/X00P3Oe<l20>3Dc`<0h=G?00L0f/o90<Nn^02FSXX0
UXj:075[J01=BDL061LF0180000000T0>3Dc07QbKP2<QH00UXn90:jVW`3Gc<@0hmS?0>KJd@3UfM00
0P3Vfm400`3Vfm80im[B0>OJdP020>OJd@040>OKd@3Selh0h]K=0>;Fc@80im[A00<0dLJm0<k3^`3T
f<h00P3Xfm404@3Xfm80j=_A0>SKd@3Xfm40iMW?0<g2^@23O7H0VY::0>?Fc03Yg=00j=cA0=W=`P2/
XYX0YYfE09::PP1OFED07QdK0180000000D00@4101XI5`2GSXD0jMc<0>SLc0020>SLb`D0j=g;00<0
^K2Q04Y6@0000000;000000<0?ooo`002P3ooom>0000000502<Q8`24OXD0/jbf0;Vb_02j/[`00P2j
/[d20;^b_@<0^k>m00H0^k:m0;^b_02k/[`0^k:l0;^c_02k/kd@0;bc_0040;6Y/02`Yjl0^k:k0;bb
^`H0_;>k0`2l/kX50;bd^P040;^c^@2k];T0^kBi0;^d^@@0_;Bi00<0_KFi0;je^P2n]KX00P2n]KX3
0;jf^P80_kJj0`2o]kX01@30]kX0`;Rj0<2h^`30^;/0`KRk00@0`KVk0`32^K/30<>j_0030<>j_@34
^kd0a;^m00@0a;^m00L0a;bm0<Fl_@34_;h0a;bn0<Fl_@35_Kd0a[fm0080a[fn0P37_[h40<Nn_`04
0<No_`38_l00b;o00<Vo`0@0bL300`3:`<030<_1`@060<c2`P35^k/0/ZVY09F=S@1TGUh081hM3P00
00000`1WHf40clG30=36a0020=;8a@030=_@cP3Ld<h0g=7>0080g=3>1`3LdLh01P3DbLH0fLg:0=gA
cP3MdLh0dlS50<_1_P@0gM;?00<0gM;>0=kBcP3Nd/h00P3Nd/h20=kCcP030=_Ac03Oe<l0h=C@00<0
h=C?00@0g]C>0=O<a`2[Xil0H5]H0P0N7A`00`0920P01@D400410@0B0000000507A^JP3Qe/h0hmS@
0>CId@3Uf]400`3Vf]840>KJd@030>OJd@3Vf]40i][A00L0im[A00<0iMW?0>KJd03Wfm401@3Xfm42
0>OJd0030>KIc`3Teld0iMS=0080j=_@00L0jM_@0>SKd03Xg=00j=c@0>?Fb`34^Jl0C4Q400H00000
00<03Ph=01dK6P0M6aX00`0M6aX00`0?3Pd0000000d<2`0201`K6@0501DD4P0Q7ad0OGM^0=?9^`3X
gL`00P3Xg<`00`3XgL`0j=g;0>SMb`030>SMb`030>?HaP1iLfT0000002`00000303oool000X0oooo
B00000002@030`<02`X;01/I700_;C00@3e104M4B@1SGV@0WiVR0;Zb_0020;Zb_@X0^[:l00<0^[>l
0;Zc^`2j/k/03@2k/k/01@2i/;T0/:R`0:VQZ@2/Y:/0]:bd00@0^k:k00<0^k>k0;bc^`2l/k/01P2k
/kX0102k];X0^kBi0;^d^@2k];T60;bd^@030;be^@2m]KX0_KFj0080_KFj1P2n][X0202o]kX0`;Nj
0<2g^P30]k/0`;Rk0<2h_030^;/0`KRk1031^K/00`32^K`0`[Zl0<>j_@030<>j_@@0a;^m1`34_;h2
0<Fm_@030<Jm_@36_Kh0a[jn0080akjo0`37_[h01037_kl0b<300<W0`039`<020<Vo`0<0bL300P3:
`<000`3:`L00bl720<_1`@020<c2`P050:NOW`1VHF408R4Q01@C4`051@D0300000001@0R81l0GeYI
0:bTX`39_kh0dlS60080fLk<00@0fm3>0=_AcP3Kd<h0g=3>203LdLh40=gAcP030=[?b`3Ic/X0gM;>
00@0gM;>103Nd/h00`3Ndlh0g]??0=oDc`020=oDc`070=oDd03LdL`0bL2k0:NOVP1lMW<0BdM501`K
6P0>0000000500820P0V92<0B4E206aWH`2?RH<00P2DSHP0202DSXP0UHj80<Bk/`3Uf]80h]O?0>?H
d03Qe/h0iM[A0P3Vf]870>KJd@030>OJd@3Vf]40i][A00<0im[A1@3Wfm440>SKd@80im[@00<0im_A
0>SKd@3Xfm400`3Xfm440>WLd0090>GHc02f[:<0SXIo08V1NP23OGD0LVaV06IQF`14@Cd0DDa800D0
RX=k00<0Ad@o00820P0l>CH00P2:PgX00`2>Qgd0XYZ?0=W?`0030>SLc0<0j=g<0`3XgL/01P3Xg</0
imc:0;ZaX`1gLFL0=c@`00410BX00000303oool000X0ooooAP0000002`0410@061LI03@b=@1<BDh0
HEaR07MbN@2:Q8`0U8fF09fFW`2_Yk80^[:m0080^k:m0P2j/[`20;Vb_0@0^[:l1`2j/[/40;Zc^`D0
^k>k0P2k/[/01@2i/KT0/j^c0;6Y/@2e[KD0^K6i0080^k>k1@2l/k/60;^c^P@0^kBj00<0^kBi0;bd
^@2l];T00P2l];T00`2l]KT0_;Fj0;fe^P020;je^`H0_[Jk102o]kX01030]kX0`;Rk0<2h^`30^;/3
0<6i_080`[Vl00<0`[Zl0<>j_@33^[d00`33^[d01033^kd0a;^n0<Bk_@34^kd60<Bl_P80aKfn0P36
_Kh00`36_[h0akjo0<Nn_`040<Nn_`030<Ro_`38`<00bL300080bKo00`39`<000`39`<40b/710<[1
`@020<_1`P050<[0`@31^;T0[:BT07E_K`0d<C403`000000101YIF@0akjm0<Fl^`3=`l030=_@cP04
0=_AcP3Kd<h0fm3>0=_@cP<0g=3>203LdLh0103MdLh0g=7>0=cAcP3Md/h20=gBc`80gM;>103Nd/h2
0=kCc`80gmC?00H0gM;=0=77``2[Xil0FUID014A400410<?0000000800<30`0C4Q80L6]X0;nf/03F
blD0h]O@0>?Hd@3SfM420>CIdP80iM[B00<0i][C0>KJdP3Uf]800P3Vf]8:0>KJd@030>KKd@3Wf]40
im[A00H0im_A103Xfm420>OKd@@0j=_A00<0im_@0>SLd@3Xg=400`3Yg=002@3Xg=00im_?0>GHc03R
e/X0gm?70=K;_`3@aKX0THV108b5O@020>SLc`060>SMc`3YgLl0jMg?09VBR@19AT40WIJ;0P3PeLH0
103Pe/L0iM[:0>OLc03Xg<`60>WMc0080>WNc@3Yg/`0imc:0>SMb`3TfLP0e/bk075/H`030`<Z0000
00`0oooo000:0?ooodH0000000L02`/;03`i?@1_K780RHB=09RAVP2XXZ`0/Z^f0080^;2k00D0^K6l
0;Zb_@2k/[d0^[:l0;Vb_00;0;Vb^`h0^[:k1@2k/[/60;^c^`80^k>j00<0^[>j0;^c^@2k/kT0102k
/kT60;^d^@80_;Bi00@0_;Fi0;be^P2m]K/0_[Fk1P2n][/30;ng^`030<2g^P30]k/0`;Rk0080`;Rl
1031^K`00`32^K`0`[Zl0<>j_@040<>j_@040<>k_@34^kd0a;^m0<Bk_PD0a;bn00@0a;fn0<Jm_P36
_Kh0a[fn0P36_[l00`37_[l0ako00<Ro`0020<Ro`0030<S0`038_l00b<3000@0bL300P39`<402P3:
`<40b/720<_1`P39`<40`;Jg0:VQXP2<QXH0IV5Q044n?P0M6a/=0000000601PG5`0n>c/0ZJ6P0<_2
`03;`Kl0d<K50`3KdLl40=_@cP80g=3>2P3LdLh30=gAcP@0gM;?0P3Nd/h40=kCc`060=oDd03KdLd0
Zj>O06mYJ017A4807ahM1`0000000`0820P04Q4@00P820070000000502h]:`1mMg<0]JfW0=77`03Q
em000`3Uf]<30>GJdP030>GKdP3Uf]80iM[B0080iM[B2`3Vf]400`3Vfm40im_A0>OKd@060>OKd@X0
j=_A00@0im_@0>OLd03Xg=00j=_@0P3Xg=040>WLd0<0jMg@00X0e/_00=36^`3Xg<l0j=c?0>SMc`3X
gLh0imc>0>?IbP3Oe<D0hmS90P3Vfl`20>KLc080imc<0`3WgL`02`3XgL`0jMg<0>SMc03XgLd0j=g<
0>OKbP3XgL/0img;0<o5]@1QGED00P8202X00000303oool000X0ooooA@0000001P010@407Q`N06i[
L@2WXJ/0/J^e0;>]]`80^K6l2@2i/[`20;Va^`@0^K:k1@2j/[/30;Zc^`@0^[:k0`2j/[X30;Vb^PL0
^[:j0`2j/kX0102k/kX0^[>j0;Zc^P2j/kX40;^c^PL0^kBi00D0_;Bi0;be^@2l]KX0_;Fj0;fe^P03
0;jf^`D0_[Jj0`2o]kX01030^;/0`;Rl0<2h_030^;/40<6i_0<0`[Zm0`33^[d01@34^kd0`k^m0<Bk
_@33^kh0`kbn00D0a;bn0P35_Kh01036_Kh0a[jn0<Jn_`36_[l20<No`0D0b;o000<0b<300<W0`@39
`<400P39`<400`39`L40b/710<[1`@020<_1`P070<2g^028PX<0?3Ti02XX:00H5QH03@d=00H61P0=
0000000406MRH@2l];<0_kNf0<g3`PD0fm7?00@0fm3>0=_AcP3LdLh0fm7>1P3LdLh0103>a<40aK^i
0<Bj]`3Aa/<40=gAcP050=gBcP3Md/l0gM;?0=gCc`3Md/l00P3Nd/l40=kCc`040=gBcP2cZZH0:bPX
00@30`<0000000<01PH6018A400V92<00P1VHEl01026P7`0W9FA0:jVXP1GDe430000000600410@06
1PH02PX:01hM702:Q800fM38103Tf]<00`3Uf]<0iM[B0>GJdP070>GJdPD0i][B1@3Vf]420>KKd@T0
im_A00<0j=_A0>OKd@3Wfm401@3Wfm470>OKd0030>SLd03Yg=00jMc@00<0jMg@00@0j=g@0>SLc`3X
g<l0j=c?0P3XgLl00`3Wg<h0i]c<0>KLc0070>KLc080imc<00<0img;0>OMc03Xg/d00`3Yg/d01`3X
gL`0j=g;0>OMb`3WgL/0_kNW03<a;0010@40:P00000<0?ooo`002P3ooom30000000800410@0D4a@0
:RT[05YGG02CSYL0/Z^f0;J_^P2g/K/20;Ra_0030;Vb_@2i/[`0^K:l00D0^K:l202i/K/30;Za^`03
0;Zb^`2j/k/0^[>k00<0^[>k0P2j/[/20;Zb^P@0^K:j1P2j/[X50;Zc^P@0^k>j202k];X50;be^P03
0;fe^P2n][/0_[Jk00@0_[Jk00D0_[Nk0;ng^`2o]k/0_kNk0<2g^`020<2h^`80`;Rl00D0`;Vl0<6i
_031^K`0`KVl0<:j_@050<>j_@<0a;^n0`33_;h40<Bl_P030<Fm_P36_Kh0a[jn00@0a[jo0P37_l05
0<Ro`080bKo01039`<401P3:`<40b/720<Vo`02o][H0V96A04Q5AA00000000H02`X:01/I6@2`YjD0
f/o>0=37aP3GcL`20=_Ac`030=_@cP3Kd<l0fm3?0080fm3>203KdLh0103HcLX0f<k;0<[0_P37_K/3
0=gAcP80gM;>103Md/l00`3Nd/l0g]??0=kCc`020=kCc`040=cAc@2]YJ80BTI400<30`80000000D0
828H05YGDP1GDe40LFaY09^ET0020=;9``0=0>7Gd@3Rem40hm[D09^DT00:2PT010@400410@0g=3@0
ShV50:nWXP30][40g=;;0>CIdP020>CJdP030>CIdP3Tf]80i=[B00H0iM[B00<0iM[C0>KJdP3Vf]80
1P3Vf]800`3Vfm80im_B0>OKdP020>OKdP<0i]_A1@3Wfm430>SKdP030>OJd@3Vf]00i][@00<0i][@
0`3Vfm001@3Wfm00imc@0>SLd03Xg=00imc@00D0j=c@00<0j=g@0>SLc`3Xg<l00P3Xg<l00`3XgLl0
j=g>0>OLc@0:0>KLc0030>OLc03Vg</0img<0080j=k=0P3Yg/d20>SMc0050>SMb`3Vg<T0_KFV06=N
EP0V9240:P00000<0?ooo`002P3ooom30000000700820P0/:Rd0FUMM08b7T02WXJX0]Znj0;Va_@08
0;Rb_080^K:l102i/K/70;Va^P030;Va^`2i/KX0^[:k00@0^[:k0P2j/[X60;Vb^PD0^[:j1`2j/kX2
0;^c^PT0^kBj1@2l]KX00`2m][/0_[Jk0;jf^`050;jf^`<0_kNk00D0`;Rk0<2h_030^;`0`;Rl0<2i
_0030<6i_0030<:j_032^[d0`[Zm00<0`kZm00D0`k^m0<>k_P34^kh0`kbn0<>l_`020<Bl_`80a;bn
00@0a;fn0<Fm_P35_Kh0a[fn0`36_[l01037_/00ako00<No`037_l030<Ro`080b;o100<0bKo10<W0
`@39`<400P39`L401`3:`L40bl720<[1`P2j/[<0M6i_04]8B00N7Ad0400000000`1JEeH0Yj2O0=;8
a`020=[@cP030=[@c`3JdM00f]3?00H0fm3>2@3KdLh00`3CbLH0c<;00=cAcP020=cAcP030=gAcP3L
dLh0gM;?00@0gM;?00l0gM;>0=kCc`3Ndll0g=7=0;N_Z`0e<c400@41000000020@402`T9065MF@3;
`kd0[JJQ0<Nn^@3Mdlh00P3Rf=<02@3Sf]@0hmWC0>CJe03BbL<0YIjI04Q6@`0;2`X0VI:>0>3Gd002
0>CJd`<0i=[B103Tf]<00`3Tf]80iM[C0>GJd`040>GJd`L0i][B0`3Vfm840>OKdP80i]_B1`3Wfm80
0`3Wfm40i]_A0>KJd0030>KJd0D0i]_@00<0imc@0>SLd03Xg=401P3Xg=000`3Wg<l0j=g?0>SMc`02
0>SMc`030>OLcP3Wg<d0i]c=0080i]c<103Wg<d30>OLc0050>OMc@3WgL`0img<0>OMc03Xg/d00`3Y
g/d01`3Xg/d0j=k<0>SNc03Ldl40^k:T0;B]WP1ACDL0:P00000<0?ooo`002P3ooom30000000700T9
2@1;BDd0ShVB0;2Z]02`Z[D0]k6k0;Vb_@060;Ra_0030;Ra^`2i/K/0^K6k00@0^K6k00<0^;6j0;R`
^P2h/;X01@2h/;X00`2i/KX0^K:k0;Zb^`040;Zb^`H0^K6j1P2i/[X20;Zb^PT0^[>j202k];X40;be
^P030;bf^P2n][/0_[Jk0080_[Jk0`2n]k/30;ng^`050;nh^`30^;`0`;Rl0<2h_030^K`00`31^K`5
0<:j_@060<>j_@33^kh0`k^n0<>k_P33_;h0`kbo0P34_;l01034_;h0a;fn0<Bm_P34_Kh20<Fm_P<0
a[jo00@0a[k00<No`037_l00ako10P38`<420<Ro`@@0bL310P39`L402039`L80b/720<[1`P36_Kh0
UXn?00`;2`020P800@413P0000002`020P801PD50:ZRXP3Ic/d0eL_:0<Ro_P36_[`0e/g;0=[Ac`3K
d<l0fm7?0080f]7?2`3KdLl0103Ld/l0fLo<0=K<b@3LdLl90=gBc`80gM??00@0fm7=0::KV01;B4H0
20H60P0000001`0Y81l0Qg]g0<Fm]`3Qf=80g=?=0=[@b`3Qem400P3Rf=<40>?Je0040>;Id`2TWYT0
:BLV0<>l]P@0i=[C1@3TfM<20>CIdP030>CJdP3Uf]<0iM[C00<0iM[B1P3Vf]840>KKdP/0im_B00D0
imcB0>OKdP3Wfm80im_A0>KKd@060>KKd0@0im_@0P3Wg=000`3Wg<l0j=c@0>SLd0060>SMd0040>SL
c`3Wg<h0imc=0>OLc@80i]c=103Wg<d50>OMc@80img<00@0j=k=0>SMc@3XgL`0j=k<0`3XgL`0103R
f<L0clJf0=K=_01QGEDZ000000`0oooo000:0?oood<0000000L07ahO06YVK@2SWZP0]Zjj0;6Z]@2f
/;X0^K:m00P0^;6l1@2i/K/00`2h/KX0^;2j0;R`^P030;R`^P80^;6j0P2i/KX00`2j/[/0^K:k0;Vb
^`090;Vb^`80^K:j0P2j/[X90;Zc^PT0^kBj00<0^kFj0;be^P2m]K/00P2m]K/40;ff^`80_[Jk0`2n
]k/20;ng^`050;nh^`30^;/0`;Rl0<2h_030^K`00`31^K`60<:j_@@0`k^n0P33_;l00`34_;l0a;fo
0<Fm_`020<Fm_`<0a[jo0`36_/030<No`080b;o100<0b<310<W0`@39`<400P39`<420<S0`@080<W0
`@39`L40b/320<Fl_P2k/[<0WiRI06EPH@051@D@0000000904Q5A029Ph80c<C30=W?cP38_kh0bL2o
0=O>c@3Id<h0fm3?00L0f]7?103KdLl80=_AcP030=cBc`3Md/l0gM;?00D0gM;?00D0gM??0=_AcP3K
dLh0bL2m03Hc<P020000000500810@092@T0JfIS0=W@b`3Tf]D0103Tf]@40>?Je080i=[D00D0hm[D
0=W@bP1lMW<0]JfW0>?Jd`020>CJd`H0i=WC0P3TfM800`3Tf]80iM[C0>GJd`030>GJdPD0i][C1P3V
fm<20>OKd`D0im_B0P3Wg=<0103Wg=80im_B0>OKdP3Vfm4<0>KKd0060>OKc`3Wg<l0imc?0>OLd03X
gM00j=c@0`3XgM00103XgLl0j=c?0>OLcP3Vg<d30>OLc@030>KLc@3Vg<`0i]c=00<0imc=103Vg<`0
103VgL/0img<0>OMc03Wg<`40>OLb`050>OMb`3Yg/`0gmK40=S?_P1QGED0:P00000<0?ooo`002P3o
oom30000000603@b=@26PHT0/JZf0;Ra_@2f[kX0]k6l1@2h/K`90;Ra^`D0^;2j1@2h/KX30;Va^`/0
^K:k0P2j/[/80;Zc^P80^[Bj1`2k];X20;^e^P050;be^`2m]K/0_KFk0;fe^`2m][/00`2n][/30;jg
^`H0_kRl00<0`;Rl0<2i_030^K`00P31^Kd00`31^[d0`[Zm0<:j_P030<:j_P@0`k^n0P33_;l00`34
_;l0a;fo0<Fm_`020<Fm_`030<Fm`036_/00a[k00080ako000@0akk00<No`@37_l40ako11P38_l42
0<S0`@0:0<W0`@39`L80bL720<[1``34^kd0X9JG06aWI`0o?3h08R4Q00820Q00000000H0UHn?0=C:
bP3EblX0clK50<k4``3Ec</30=[@c`D0f]7?203KdLl30=_Bc`<0g=;?0P3LdLl20=cBc`@0gM;?00`0
gM?@0=_Ac@3Ld/h0Yj2M020N7P0B4A40AT=207EaKP2UWYX0c/G10>?Je03TfmD30>CJe@T0hm[D00D0
b;nj0:^TW`3Sf]<0i=WC0>?Id`030>CId`@0i=WB103Tf]830>GJdP040>GJd`3Vf]<0i][C0>KJd`T0
i]_C1P3Wfm<40>OKdPD0i]_A1P3Vfm020>OKd0D0imc@103Wg<l30>OLcPD0imc=00<0i]c=0>KMc@3W
gLd00P3WgLd50>KMc0040>OMc03XgL`0img<0>OMc0<0img;00H0j=k<0>SOc03PelD0f=2o06EQF@04
0`<Y000000`0oooo000:0?oooc80000000@01PH600`<300<30d01PH62P0000001P0:2@X0:bX/05QF
F`2:Q8h0[ZVc0;Vb_P<0^;:m1`2h/K`20;Ra^`040;R`^`2h/K/0^;6k0;Ra^PH0^;2j1@2h/KX40;Ra
^`@0^K6k00<0^K:k0;Vb^P2i/[X01P2i/[X00`2i/kX0^[>j0;Zc^P060;Zc^P<0^[Bj102k];X20;^e
^P80_;Fk00@0_KFk0;ff^`2m][`0_KJl0P2n][/20;jg^`040;nh_02o^;d0_kRm0;nh_@80_kRl00<0
`;Rl0<2i_@31^Kd00P31^Kd00`32^[d0`[Zn0<:j_P030<:j_P<0`k^n00<0`k^o0<>l_`33_;l00P33
_;l01@34_Kl0aKfo0<Fm_`35_Kl0aKk00080a[k01`37_l430<Ro`@<0b<3100P0b<320<W0`P39`<80
b/320<6g^@2FSXl0GEMH01hL7A40000000P0=SDd06MSHP3;`/40f]7@0<W0`03AalL0fLo>0=[@c`P0
f]7?0P3KdLl00`3Icld0e<_90=37a@020=37a@030=G;b@3Id<d0fm;?0080fm;?0P3Ld/l00`3LdLl0
g=;?0=cBc`020=cBc`<0gM??00T0g]?@0=cBc`33^kP0KFQV01HE5@0X9RD0VI>@0=O>b@3Qf=<00P3T
f]D00`3Sf]D0i=[E0>?Je@020>?Je0D0hmWD0`3Sf]@0103Pem40_[Nb0>?Id`3SfM<30>CId`80hmWC
0P3TfM<40>CJd`030>CJdP3Uf]80iM[B0080iM[B00<0iM[C0>KJd`3Vf]<02@3Vfm<60>OKd`040>OL
dP3Wfm80im_B0>OKdPH0i]_A2@3Vfm020>KLc`@0imc?1P3Wg<h00`3Vg<d0imc=0>OLc@050>OLc@H0
i]g<0`3WgL`50>ONc0050>?Jb03Ldl40XI^>03`i=0051@D0:000000<0?ooo`002P3ooola00000006
00410@0R8B@0@d5604E2A`0T8bD00P832@0000001@0C4a@0Ee=I09bGX@2c[;P0^;6m00@0^;:m00<0
^;:l0;Ra_02h/K`01@2h/K`00`2h/;/0]k2j0;N`^P040;N`^PH0^;2j0P2h/KX80;Ra^`H0^K:k0`2i
/[X20;Vc^PL0^[>j102j];X30;^d^P050;^e^`2l]K/0_KFl0;fe_02m]K/01@2m][/20;jg^`030;ng
^`2o^;`0_kRl00@0_kRl00D0`;Rm0<2i_@31^Kd0`KVm0<6j_@060<:j_P<0`k^o1@33_;l01034_Kl0
aKfo0<Fm_`35_L020<Fn`0030<Jn`037_l40ako100D0ako100<0b<310<W0`@38`<400`38`<402038
`<80bL720<[1``36_Kl0YYbM051<C@0`;Rh03Ph>4@0000001P2>R8P0cLG40=S?cP3Ec</0c<?20=S?
cP80f]3?00<0fM3?0=[@c`3Jd<l01`3Jd<l00`3EblX0bL2o0<Jm^`020<Jm^`040<[1`03GcL/0fm7?
0=_Ac`<0fm;?0P3Ld/l00`3Md/l0g=;?0=cCc`030=gCc`070=kCd03Aal@0MFm/02l];00:2@T0<c0_
0;^c[`020>CJe@040>?Je@3Tf]D0i=[E0>?Je@/0hm[D00@0i=_D0=K>a`3RfM<0hmWC0P3TfM<30>?I
d`030>CId`3Tf]<0i=[C00<0i=[C1P3Uf]<00`3Vfm<0iM_C0>KKd`020>KKd`@0i]cC2@3Wg=<40>OK
dP<0i]cA00<0i]_A0>KKd03Vfm001`3Vfm020>KLd080i]c?0P3Wg<l50>OLcP040>SLcP3WgLh0imc>
0>OLc@H0img=00<0i]c<0>KMc03VgL`01@3VgL`60>KMb`050>GLbP3IdKl0g=?207=^I@0:2PT0:000
000<0?ooo`002P3ooola0000000600410@0R8B@0@d5604E2A`0T8bD00P832@0000001@0C4a@0Ee=I
09bGX@2c[;P0^;6m00@0^;:m00<0^;:l0;Ra_02h/K`01@2h/K`00`2h/;/0]k2j0;N`^P040;N`^PH0
^;2j0P2h/KX80;Ra^`H0^K:k0`2i/[X20;Vc^PL0^[>j102j];X30;^d^P050;^e^`2l]K/0_KFl0;fe
_02m]K/01@2m][/20;jg^`030;ng^`2o^;`0_kRl00@0_kRl00D0`;Rm0<2i_@31^Kd0`KVm0<6j_@06
0<:j_P<0`k^o1@33_;l01034_Kl0aKfo0<Fm_`35_L020<Fn`0030<Jn`037_l40ako100D0ako100<0
b<310<W0`@38`<400`38`<402038`<80bL720<[1``36_Kl0YYbM051<C@0`;Rh03Ph>4@0000001P2>
R8P0cLG40=S?cP3Ec</0c<?20=S?cP80f]3?00<0fM3?0=[@c`3Jd<l01`3Jd<l00`3EblX0bL2o0<Jm
^`020<Jm^`040<[1`03GcL/0fm7?0=_Ac`<0fm;?0P3Ld/l00`3Md/l0g=;?0=cCc`030=gCc`070=kC
d03Aal@0MFm/02l];00:2@T0<c0_0;^c[`020>CJe@040>?Je@3Tf]D0i=[E0>?Je@/0hm[D00@0i=_D
0=K>a`3RfM<0hmWC0P3TfM<30>?Id`030>CId`3Tf]<0i=[C00<0i=[C1P3Uf]<00`3Vfm<0iM_C0>KK
d`020>KKd`@0i]cC2@3Wg=<40>OKdP<0i]cA00<0i]_A0>KKd03Vfm001`3Vfm020>KLd080i]c?0P3W
g<l50>OLcP040>SLcP3WgLh0imc>0>OLc@H0img=00<0i]c<0>KMc03VgL`01@3VgL`60>KMb`050>GL
bP3IdKl0g=?207=^I@0:2PT0:000000<0?ooo`002P3ooola0000000600820P0o?D40NgMo07eiPP11
?d<01@D51P00000200D51@07028P8`1GE5/0VIBM0;be`P2k]<40^;:n0;Rb_@020;Nb_@80^;:l1P2h
/K`20;N`^`L0]k2j1@2h/;X20;N`^P040;R`^`2h/K/0^;6k0;Ra^`80^;6j102i/[/0102h/KX0^;:j
0;Vb^P2i/[/20;Vc^`L0^[>k1@2j];/20;^d^`80^kBj00<0^kFj0;^e^`2l]K/0102l]K/30;ff_005
0;fg^`2n]k/0_[Nk0;jg^`2o^;`00`2o^;d00`30^;d0`;Vm0<2i_@030<2i_@030<6i_@32^[h0`[Zn
0080`[Zn00@0`[^n0<>k_`33^kl0`k^o1P33_;l00`34_Kl0aKfo0<Fm_`030<Fn`0070<Jn`037_l40
ako10<No`@37`<40ako10<Ro`P060<S0`P090<S1`P39`L80bL730<[1``2l];@0NW=b00`;2`071`L0
0P8200h0000000/00@4101hM7@0k>3P0akno0=[Ad03>a/D0d<O60=O>c@3Id<l0f]3?0=W@c`050=W?
c`80fM3?2P3Jd<l0103KdLl0fm;?0=_Bc`3Kd/l50=cBc`0;0=gBc`3Mdm00gM?@0=gCd03Kd/h0[JFR
02`Y:@00000010@403ll>P3@b<@00P3Tf]H:0>?Je@D0hm[D00@0i=[D0>?Id`3Tf]@0hm[D0P3TfM<3
0>?Id`H0i=[C1P3Uf]<20>GKd`80i]_C0`3Vg=<80>OLd`80imgC00@0imcC0>OLdP3Xg=<0j=cC0P3W
g=800`3Vfm80imcB0>OLd@030>KLd@80i]_A1@3Vg=050>OLd0030>OLc`3Wg<h0imc>0080imc>103W
gLh00`3WgLd0imc=0>OLc@040>OMc@030>KMc@3VgL`0i]g<00H0i]g<0P3Vg/`0203Wg/`0hm[80=oF
a@3<`k@0iMc:09B>P@0a;b/02PT89`00000<0?ooo`002P3ooolX0000000500410@030`<01@D600@4
10020P80100000001P020P<0@T15089nQ`24P8T0AD=700D51@H000000P0:2P/01@15@TL0Sh^D0;B^
^P2l]/80^K>o00D0^;:m00<0^;6l0;Na_02h/K`00`2h/K`60;N`^`040;N`^P2h/;X0^;2j0;R`^P80
^;6j00<0^;2j0;N`^P2g/;X00P2g/;/00`2h/;/0^;6k0;Ra^`050;Ra^`040;Rb^`2h/KX0^;:j0;Rb
^P80^K:j0`2i/[/00`2i/k/0^[>k0;Zc^`020;Zc^`H0^[Bk0`2k];/30;^e^`80_;Fk0P2k]KX01@2l
]K/0_KJl0;ff_02m][`0_KNl0080_[Nl00<0_kNl0;nh_02o^;d00`2o^;d30<2i_@80`KVm00P0`KZm
0<:j_P32^[h0`[Zn0<:k_P33^kl0`[^n0<:k_`80`[bo1033_;l01034_;l0a;fo0<Fm_`35_[l30<Fn
`080a[o100@0ako10<O0`P37`<80al310P38_l400`38`<40b<320<S0`P030<S0`P050<W0``37_l40
^K:b08f7R018ATH04@0000001`081`L0PWal0<6i^@3Icll0f]3@0<c2`P3Gclh0203Id<l;0=[@c`03
0=_@c`3KdLl0fm7?00@0fm;?103Ld/l30=gCd0080=[@c@2^YZ@0Ge]J01DC4`0=30`0JVIT0;F^ZP3Q
f=<20>?Ie@<0h][E00@0hm[E0>?Je03Sf]@0h]WD0P3SfM@60>?Je0030>CKe03Sf]@0i=[D0080i=[D
00@0i=WC0>?Id`3SfM<0hm[C203Tf]<40>GJd`80iM_C00<0i]_D0>KLe03Vg=@00P3Vg=@40>OLe0H0
imgD0P3Wg=<01P3Xg=<0imcB0>OLdP3Wg=80i]_B0>OLdP<0i]cA00<0i]_A0>KKd03Vfm000P3Vfm06
0>KLd080i]c?0P3Wg<l20>OLcP<0img>0`3XgLh00`3WgLh0img=0>OMc@030>OMc@030>KMc@3VgL`0
i]g<00H0i]g<0`3VgL/01`3OelD0gMC20=W@_`3Wg//0_kJW07A^I@0J6AL09`00000<0?ooo`002P3o
oolX0000000600T92P0W9RP0A49703Dc=`0T8bH08B0S0`0`;c801P0U8bH0<c4e04Y8C@1<BDl09bHY
00<30`<0000000<02`/;01/J700Y:2X00P0f=CT01@1fLgX0]:nj0;fha02j]L00^;:n00D0]k:m00<0
^;6m0;Na_02h/K`00P2h/K`00`2g/K/0]k2k0;N`^`060;N`^`040;R`^`2h/KX0^;6j0;Ra^P80^;6k
0`2g/;/90;Ra^`@0^;:k00<0^K:k0;Vb^P2i/[X00P2i/[X20;Vc^`<0^[>k102j];/40;Zd^P0<0;^d
^P2k]KX0^kFk0;be_02l]K/0^kFk0;^e^P2l]K/0_;Jk0;fg_02n]k`0_[Nk0P2n]k`20;nh_0<0_kRm
1@30^Kd01@31^Kd0`KZm0<6j_P31^[h0`[Zn0080`k^o00D0`[^o0<>l`033_<00`kbo0<>m_`040<Bm
_`030<Fm_`35_/00aKk00080aKk000L0a[k00<Jo`@36_l40a[o10<No`P37`<80ako20080b;o20`38
`<820<W1`P060<[1``39`L<0_kNi08=oO@18ADD08b4Q3`0000002P010@402`/;028P8032^k/0f]7A
0<g5a@3:`/40eLc<0=W?c`3Hcll60=W?c`D0fM3?2@3Jd<l00`3JdLl0fm;?0=_Bc`020=_Bc`80g=;?
00<0g=;@0=cCd03Mdm000P3Mdm001P38_k`0AdA400H51@020@407ahN0;be/@@0hm[F00<0h][F0>?J
eP3Sf]H02@3Sf]D0103Sf]@0hm[E0>?Je@3Tf]@30>?Je080i=[D103Sf]<70>CJd`<0iM[C0P3Ufm<0
0`3Ufm@0i]cD0>KLe0030>KLe0<0imcD1`3WgM@20>OLd`030>SLd`3Wg=<0imcC0080i]cB00<0imcB
0>KLd@3Vg=400P3Vg=490>KLd0@0imc@00<0img@0>OLc`3Wg<h01`3WgLh00`3WgLd0i]g=0>KMc@03
0>OMc@80i]g=1@3VgL`02`3Sf/T0gmK50>KMc03Ne/@0elnn0<W0/@2_Z9X0`;VY0<:jZ`22OG807QdJ
02L00000303oool000X0oooo9`0000001`010@8071`M05UGG@2>RID0Kf]d04a9CP1ACU@00P1fLW/0
1@1hMGh0JfQ_061MI@10?T809RDX00803`h?00H03`l@00P820000000820R05MEF`21OHH208n;U@04
0:JQ[02k]L40_KO30;Vd_`H0]k:m00<0]k6m0;Ra_02h/K`00P2h/K`00`2g/K/0]k2k0;N`^`040;N`
^`@0]k2j0P2h/;/30;Na^`030;Ra^`2h/KX0^;6j00@0^;6k1@2h/[/50;Vb^`@0^K>k00<0^[>k0;Zd
^`2j];/02@2j];/00`2j]KX0^kFk0;^e^`020;be_080^kFk00<0_;Jk0;ff_02m]k`00`2n]k`00`2o
^;`0_kRm0;nh_@080<2i_@050<6j_@31^[h0`KZn0<6j_P32^kh00`32^kl01032_;l0`kbo0<>l_`34
_;l40<Bm_`050<Fm_`35_/00aKk00<Fn`036_/400P36_l420<No`P030<No`@37_l80b<3200D0b<32
0P39`<<01039`L<0bL330:jWZ00k=cHA0000000801<B4P1cKVl0/JZZ0=O?c`3Id=00b;no0=O>cP3I
d=030=W?d0D0fM3@0P3Id<l90=[@c`80f]7?0`3KdLl01@3Kd]00fm;?0=_Bc`3Ld]00g=;?0080g=?@
00/0gM?@0=cBc`3=`l00R8:1024O7`000000;c8W07agM@3=aL40hm_F0>?JeP020>?Je@@0h][E0`3S
f]D20>;Je0@0hm[D0`3Sf]D30>?Je080i=[D00@0i=_D0>?Jd`3Sf]<0hm[C1`3Tf]<40>GJd`030>KK
d`3Vg=@0i]cD00L0i]cD0P3Wg=@50>OMe0070>OLe03WgM<0imcC0>SLd`3XgM<0i]cB0>KKdP030>OL
dP030>OMdP3Wg=40i]cA00`0i]c@0P3Vg<l50>OMc`80img>0P3XgLh20>OMcP@0img=00@0imk=0>ON
cP3Wg/h0j=k=0`3Wg/d02P3Xg/d0imk<0>7Ha`3:`[<0U8j20:BMT02e[Il0W9F9051=AP0=3@`W0000
00`0oooo000:0?ooobH0000000P04a8D03Xi?01hMGl0XYjZ0;Ja_`2TX:d0R8B=08f:U080_[S600d0
_[W709nJYP2ETI`0IF9Y02d/;P0P7b40AD=804i;D@0X9bX00`<303Pg?02:QY00]K2m0080^[C100@0
_;K30;fga02l]l80^K>o102g/[d20;Rb_@D0^;6l00<0]k6k0;N`^`2g/;/00`2g/;/00`2f/;X0]Znj
0;J_^P030;J_^PL0]k2j00@0]k6j0;Ra^`2h/K/0^;6k1P2h/[/30;Vb^`D0^K>k00<0^[>k0;Zd^`2j
];/01P2j];/00`2j]K/0^kFk0;^e^`020;^e^`030;be_02l][`0_;Jl0080_;Jk00<0_;Jl0;fg_02n
]k`00`2n]k`00`2n^;d0_kRm0;nh_@070<2i_@<0`KZn0P32^[h20<:k_`030<:l`032_;l0`kbo0080
`kbo1@34_Kl20<Fn`080aKk10P36_l401036_l80ako20<No`P37_l850<S0`P080<S1``39`<<0bL73
0<W1``37_l40^[:e08R3Q00W9RHA0000000702/Z:P30]kP0fM7A0=WAd@3Id=00e<_;0=S?c`020=S?
d0T0fM3?1@3Jd<l00`3JdLl0f]3?0=[@c`040=[@c`80f]7?00<0fm7?0=_Bc`3Kd/l00P3Ld/l20=cC
d0090=gCd03Hcl`0LFe[01DC4`010@40000005MT>`3SfmL0hm_F00@0hm[F00<0h][F0>;Je@3Sf]D0
1P3Rf]D60>?Je@<0i=_E00D0hm[D0>?Ie03Tf]@0i=_E0>CJe0020>?Jd`L0i=[C0`3Uf]<00`3Ufm@0
i]cD0>KLe0090>KLe0<0imcD0P3WgM@30>OLe0040>OLd`3XgM<0j=gC0>OLd`80imcB00@0imgB0>OL
dP3Wg=80i]cB103Vg=4:0>KLd080i]g?103WgLl40>OMcP<0img=00P0i]g=0>OMc@3WgLd0img=0>ON
c@3VgLd0j=k>0>ONc@@0imk<00L0i=_:09RBQ`1aK6<0bL2a0<g5]@2[YIL0=cDa02P00000303oool0
00X0oooo9P0000005P0d<SH0QX>=0;F`_@2l]lH0_KS70;Rd`@2VXJd0QhB=08R4SP20O8H0Q82:08Z6
T02SWZX0NWMo03He>00i=c/0O7V108b8T@18AT/01@D504i<D@2VXJd30;jiaP040;fha@2l]l@0^[C0
0;Rc_P@0]k:m00<0]k6m0;Na_02g/K`00P2g/K`20;Ra_0030;Na^`2g/;/0]k2k0080]k2k00<0]k2j
0;J_^P2f[kX00`2f[kX00`2f/;X0]k2j0;N`^P060;N`^P040;Ra^P2h/K/0^;6k0;Ra^`P0^;:k0P2i
/[/50;Vc^`P0^[Bk00@0^[Fk0;^e^`2k]K/0_;Fl0P2l][`01@2m][`0_KNl0;fg_02m]k`0_[Nl00<0
_[Rl0`2o^;d70<2i_@@0`KZn00<0`[Zn0<:k_P32^kl00`32_<000`33_;l0a;bo0<Bm_`020<Bm_`80
a;g000@0aKk00<Fn`@35_/40aKk11@36_l830<No`P<0al3200<0b<330<W1``39`L<00P37_l80102a
ZJ`0Mg=c04Y8B00D4a<?0000000701<B4P1ACTl0UY2@0=G=cP3JdM40f]3@0=W@d0020=S?d080f<o?
0P3Hd<l;0=W@c`@0f]3?00<0dl[90=O=c03Jd<l00`3JdLl01@3KdLl0fm;?0=_Bc`3Ld/l0g=;@0080
g=?@00<0gM?A0<[2`012@3h00`0000000`1mOf`0hm[F0>?JeP020>?JeP80h][F1P3Rf]D90>?Je@80
hm_E00<0i=_E0>CJe@3Tf]@00`3Tf]@00`3Sf]<0i=[D0>CJe0050>CJe0050>CKe03Uf]<0iM[C0>GK
e03Vg=@01@3Vg=D30>KLe0<0imgD0`3WgMD40>OMe0040>OLe03WgM@0j=gD0>SMe080j=gC103Vg=84
0>KLd@L0i]c@0P3VgM070>OMd0040>OMc`3Wg/l0imk?0>ONc`<0imk>00<0j=k>0>ONcP3WgLd00P3W
gLd00`3NeLD0i=_:0>ONc@040>ONc@080>ONc03TflT0ZZ>E07]fK@2ESh<0XYb?07UdJ`0R8AhX0000
00`0oooo000:0?ooob@0000001P01`L701DC5@1YIVl0]K2n0;njb02o^/T0_[[80;jja`2l]l@0WIVU
07IbN`1VHVX0IVA/079_N01oO8D0JfQ_04m=DP1KFEl0PGj7089oR013@DH01@@505iKH@2a[;P30;ji
a`040;fga@2k]L80^K>o0;Rb_P@0]k:m0`2g/Kd20;Ra_@80^;6l00<0]k6l0;N`^`2g/;/00`2g/;/3
0;J`^P030;J_^P2f/;X0][2j00L0]k2j0P2g/KX00`2h/KX0^;6k0;Rb^`080;Rb^`030;Vb^`2i/k/0
^K>k00@0^K>k202j];/00`2j]K/0^kFk0;be_0020;be_0060;bf_02m]k`0_KNl0;fg_02n]k`0_[Nm
102n^;d00`2o^;d0_kVm0;ni_@050<2i_@030<2j_@31^[h0`KZn00<0`KZn00<0`[^n0<:k_`32_<00
0P32_<000`33_<00a;fo0<Bm_`020<Bm_`050<Bm`035_/00aKk10<Fn`@36_/400`36_l850<No`P80
al320P38`<<00`37`<80a;bo0<S0`P020;jf^00407UcM@061PH00`<300410@d0000000D010@400h=
3@0n?Cd0ZjBT0=C<c0030=WAd@80f<o@103Hcll50=S@c`L0fM3?00H0f]7?0=[Ad03JdM00f]7?0<S0
_P3?a/D20=[Ad0030=_Ad03KdLl0fm7?0080fm;@0P3Ld]001@3Ldm40g=?@0=gDd@2XXIl0;2TY00<0
000000<0WIND0>?JeP3Sf]H00P3Sf]H00`3Rf]H0h][E0>;Je@050>;Je@030>?Je@3Rf]D0h][E00H0
hm[E0P3TfmD20>?Ke@050>CKe@3Tf]@0hm[D0>CJe03Sf]@01P3Tf]@20>CKe080iM_D00<0iMcD0>KL
e@3Vg=D0103Vg=D00`3Ufm<0i]cD0>KMe0040>OMe080imgE0P3WgM@20>OMe@80imgD00H0imgC0>SM
d`3XgM<0imgC0>OLd`3Wg=820>KLdP030>OLdP3WgM80i]cB00<0i]cA1`3Vg=040>KMd080i]g?1@3W
gLl00`3Wg/l0imk>0>ONcP040>ONc@030>OMc@3Ufl/0i]g<00D0imk=00P0i]g<0=kEa03JdL00VI>7
08J1M`2HTXH0CDY400P81bP00000303oool000X0oooo8P0000006P0@4180<S4e06QUKP27Phh0[JVg
0;jib02o^/P0_[[80;jib02n^LL0^KG20:VU/P25PX`0SHVC09ZFX02NVJ@0XIbW09nKYP2SWZT0YJ2/
0:6MY`2CSiT0P7f506QUK02=RI80^KC00`2n^LL0102l]lD0^[G20;Rb_`2h/[h40;Nb_@<0]k6m0`2h
/Kd00`2h/K`0]k6l0;N`^`030;N`^`80]k6k00<0]k2k0;J`^P2f/;X01P2g/;X50;Na^P030;Ra^P2h
/[/0^;:k00P0^;:k1`2i/k/50;Zd^`050;Ze^`2k]K/0^kFk0;^e^`2k]K`00`2l][`20;fg_0030;jg
_02n]kd0_[Rm0080_[Rn0P2n^;d00`2o^;d0`;Vn0<2i_P050<2i_P040<2j_P31^[h0`KZn0<6j_`<0
`[^o00<0`[_00<:l`032_<000P32_<000`33_L00a;g00<Bm`0020<Bm`0040<Bn`035_/40aKk10<Fn
`@<0a[o200D0a/320<Jo`P37_l80b;o20<O0`P030<O0``80b<7300<0a;bo0;jf^@2j/kH00P2FT980
0`1?C4d000000000000>0000000403@c<`2>RHT0`;Ri0=G>cP80fM7A00<0f=3@0=S?d03Hcm00203H
cll50=S@c`<0fM3?00L0f=3>0=?:b@36_[d0b/700=O>c@39`;l0bl;100D0f]7?0P3Kd]020=cBd005
0=cCd03Kd]00]:b[05IBD@0H5aL00`0000000`2OTi00h][F0>?JeP050>;JeP030>;KeP3SfmD0hm_E
00L0h][E103Sf]D00`3SfmH0i=_F0>CKe@020>?Ke@030>CKe@3Tf]@0i=[D00D0i=[D0P3Tfm@40>GK
e0<0iMcE0P3Ufm@00`3Vg=@0i]cE0>KLe@020>OMe@<0imkE00@0i]gD0>OMe03WgM@0imkE103WgMD0
103WgM@0j=gD0>SMd`3Xg]<30>OMd`80i]cB00@0imgB0>SMd`3WgM80i]gB0`3VgM420>KLd0L0i]g@
0`3WgM030>ONd0<0imk?0`3Wg/h01P3Xg/h0imk>0>ONcP3Wg/d0img=0>ONcPD0imk=00L0i=_:0=38
^03NeL@0ViF908b6O02LUhX0@Clj02T00000303oool000X0oooo6`0000000`051@H03@`=018B4`02
018B4`0801XJ6`0e=CP0LFih09fIYP2g/l40_;S60;jjb@2o^/T20;jib0<0_[W700@0^[G309nLY`2i
]L80`[g;0`33_//01`32_L/0`;_80;jiaP2m^<D0_;O40;Ze`@2k]/<0102n^LH0102l]l@0^[C10;Rb
_P2g/[h30;Nb_@<0]k6m1P2g/K`60;N`^`030;Na^`2g/;/0][2j00D0]k2j1P2g/KX20;Ra^PH0^;:k
00<0^;>k0;Vc^`2i/k/01P2i/k/00`2i];/0^[Bk0;Zd^`020;Zd^`80^[Fk0P2k]K`00`2l]K`0_;Jl
0;bf_0020;bf_0050;ff_02m]k`0_KNl0;fg_@2n^;d0102n^;h00`2o^;h0`;Vn0<2i_P040<2i_P04
0<2j_P31^[l0`KZo0<6j_`<0`[^o00<0`[_00<:l`032_<000`32_<000`33_L00a;g00<Bn`0020<Bn
`0030<Bn`@35_/40aKo100D0a[o200`0a/320<No``37`<<0al320<O0``37`<80al330<S0``39`<@0
`k^n0;6Z[01aJfd204E4A003024O7`000000000000`0000000@010@400`<301eL700d<S80P3Id=42
0=S@d@80f=3@00<0f<o?0=O?c`3Gcll00`3Hcll60=S?cP@0f=3?00P0fM3?0=S@c`3AbLP0aknn0;N_
[P3@alD0d/W80=G<b`<0f]7@00@0fm7@0=_Bd03Kd]00fm;@0P3Ld]001@3Ldm00f]7?08EoOP0G5QD0
1PH600<0000000<0X8n=0>;JeP3Rf]H00P3Rf]H60>;Je@<0h][F103Sf]H00`3Sf]D0hm_F0>?KeP03
0>CKeP070>?Ke@3TfmD0i=_E0>?Je@3TfmD0i=cF0>CKe@040>CJe080i=_D00<0iM_D0>GLe@3Tfm@0
0P3Ug=D20>KLe@80hmWB00<0h]WA0>KMe@3VgMD00`3VgMD20>OMe@P0imkE00@0j=kE0>SNe03Xg]@0
j=kD103WgM<0103VgM80imgC0>OMdP3WgM820>KMdP030>KMd@3VgM00i]g@00P0i]g@00@0i]k@0>ON
d03Wg]00imk@1@3Wg/l40>ONcP<0imk=00<0imk>0>OOc`3Xglh00`3Xg/d0203Wg/`0i=[90=kEa03U
g<X0Thf204i;A@15@Sd071/I:@00000<0?ooo`002P3ooolK0000000:01/J701<BU00N7Eo08^7TP2A
S9P0UY:M0:RT/02j]/@0_k[90;nkb@80_k[900<0_[[80;fib02m^LL00P2m^LL02P2n^LL0^kK40:>O
Z`2XY;00]:nl0;^e``30^lT0`Kc:0;nia`2o^/L90;jiaP030;bga02j]<40^;:o00<0]k:n0P2g/[d4
0;Na_@@0]k6l202g/;/00`2f/;X0]k2j0;N`^P020;N`^PP0]k6j00<0^;6j0;Rb^`2h/[/00`2h/[/2
0;Rc^`L0^K>k102i];/30;Zd^`80^[Fk0`2k]K`30;bf_@80_KNm00<0_KNl0;jg_@2n^;d01@2n^;d3
0;ni_P<0`;Vn00@0`;Zn0<6j_`31^[l0`KZo0`32^l000`31_<00`[c00<:l`0030<:l`0030<>m`034
_/40a;k100<0a;k10P35_l850<Jo`P80ako20`37`<<20<S1``80bL7400<0a[k109ZEU`0F4a@03`00
00001@0L6Q/0@d5107=_K`2OVYX0b/?40080f=3A00<0f<oA0=O?d03Gcm000P3Hcm080=S?c`80f=3?
2P3Id<l01031^KP0bl?10=[@c`3JdLl30=[Ad0@0fm;@0P3Ld]000`3Ldm00dl[805YFE@0400000003
00D5102dZ:D0h][F00@0h][F0`3RfmH00`3Rf]H0h][E0>;Je@060>;Je@D0hm_F00D0i=cF0>?Ke@3S
fmD0i=_E0>?Ke@070>CKe@T0iMcE0P3Ug=@0103JdLT0j=oF0>ONeP3VgMD;0>ONe@80j=kE0`3Xg]@2
0>SMd`<0imgC0`3Vg=830>KMd@T0i]g@0`3Vg]030>ONd0H0imk?1P3Wg/h02`3Wglh0imk>0>SOc@3X
gld0i=_:0=cC``39`K80ZZBG09^ER@1MFE804a8A02/00000303oool000X0oooo6P0000001@071PL0
@3m409BAW@2j]/D0_[W90080_k[:00L0`;_;0<2kbP2o^lT0_k[90;jjb@2n^LP0_KW800H0_KW700T0
^kK40;Nb_`2c[[X0^KC00;niaP2n^<H0^[G20;fiaP2m^<H00P2m^LH30;jiaP<0_[W500<0_KO40;Zd
`@2h//001@2g/[h20;Nb_@80]k6m0`2h/Kd00`2g/K`0]k2k0;J`^`050;N`^`030;J`^`2f/;X0][2j
00<0]k2j202g/KX20;Rb^PD0^;:k1@2h/k/30;Vc^`@0^KBk0P2j];/20;Ze_0030;^e_02l]Kd0_;Jm
00@0_;Jl0`2m]k`00`2n]kd0_[Rm0;jh_P030;jh_P040;ji_P2o^Kh0`;Vn0<2i_P80`;Zn00<0`;Zo
0<6j_`31^[l00P31^[l00`31^l00`[_00<:k`0040<:l`0030<:m`033_L00a;g000@0a;k100<0aKk1
0<Fo`P35_l801036_l820<No``030<O0`P37`<<0al330080b<730P38`L@01038`LD0^k>f081lOP0?
3`l;0000000900L71`0=30d03@d=00d=3@1KFET0ZjBU0<g6a`3Fc/l0f=7B0080f=3A00<0eloA0=O?
d03Gcm001@3Gc/l00`3Gcll0f<o?0=S?c`030=S?c`050=S@c`3Id<l0fM3?0=S@c`3Id<l00`3Hd<l3
0=W@c`030<No_P3Ab<L0f]7@00@0f]7@103Kd]020=cBd@030=cCd@2i/[00>SLg00<0000000D01@D5
01XI603<a<00h][F0>;Je`0=0>;JeP030>?JeP3SfmH0hm_F00<0hm_F00<0i=cF0>GLe`3TfmH00P3T
g=D00`3Sf]D0i=[E0>CKe@040>CKe@@0i=cE1P3Ug=D01@3Tfm@0hmWB0>CLd`3Wg]D0i]kE00<0i]gE
2P3Wg]D01@3Xg]D0j=oE0>SNe@3Xg]D0j=kD00D0imgC0P3Vg=830>KMdPD0i]gA00<0i]g@0>KNd03V
g]000`3Wg]440>ONd0<0imo@00<0imk@0>ONc`3Wg/l0103Wg/l0103Wgll0j=o>0>ONcP3Wg/h20>OO
cP070=;:^`2i/Z@0ZJ>G0:2KS`2>R7d0@Clj00D51@0[000000`0oooo000:0?oooaL0000000T03@d>
02l/<@1EDeX0K6Yc09REXP2k]lH0`;_;0;nkb`2o^/X00P2o^lX0102n^lT0_[[90;jjb@2n^LT40;fi
b00;0;jib02n^/P0_[[80;jjb030^lT0`[g;0<>nb`33_l`0`kk<0<6lb@2m^<D0102m^<H00`2m^LH0
_[W60;jiaP030;jiaP030;fha@2k]/<0^[G00080^;>o0P2g/[h40;Nb_@80]k6m0P2h/Kd20;Na_0@0
]k6k0`2f/;/50;J`^P030;N`^P2g/KX0]k6j00H0]k6j0`2g/[X00`2h/[X0^;:k0;Rb^`050;Rc^`80
^K>k00@0^KBk0;Vd_02j];`0^[Bl102j]K`30;^e_@<0_;Jm00@0_;Nm0;fg_@2m]kd0_KNm0P2n^;d5
0;jh_P040;ji_P2o^Kh0_kVn0<2i_P80`;Zn0P30^[l30<6j_`030<6k`032^l00`[_000<0`[c000@0
`[g00<>m`033_L00a;g00P34_/401034_/80aKk20<Fo`P35_l<20<Jo``80a[o200<0a[o30<O0``37
`<<01037`<<01`38`<@0b<740<W1a039`/D0Z::U069NH00:2@T02P000000200>3@d0MG9b0;2YZ`2h
/K<0_;Fg0<k6b03Ec/l0elk@0P3Gcm00103Fc/l0e/g>0=K>cP3Fc/h90=O>c`030=O?c`3Hcll0f<o?
00D0f=3?0`3Id<l30=W@d0030=;:b@3Gc/d0f]7@00@0f]7@00<0fm;A0=_Bd03Kd]000P3Ld]00103K
d]00a[jl07=]K00S8R430000000604=5?02PW9P0g]KC0>;Je`3Qf]H0h][F0`3RfmH30>;JeP030>;J
e@3Rf]H0h][F00<0h][F0`3SfmH00`3Ne]40e/k:0=oHdP020>GLe`030>GLeP3Tg=H0i=cF00H0i=_E
103Tg=D00`3Ug=D0iMcF0>GLeP030>GLeP040>KLeP3RfM80hm[C0>KMeP<0i]kE0P3Wg]D00`3VgMD0
imkF0>ONeP060>ONeP090>ONe@3Xg]D0j=kE0>SNe@3XgmH0hMS>0>OMd`3Wg]@0j=kC00<0imgC0P3W
gM830>KMdP030>KMd@3Vg]40i]kA00<0i]g@00<0i]k@0>ONd@3Wg]40103Wg]440>ONd0030>OOc`3W
g/l0imk?00@0imk?00<0imo?0>SOcP3Wg/h00P3Wg/d01`3Pf<P0cLJg0>CLb`3Tg</0dLZk0<k7]`1I
ETl0;000000<0?ooo`002P3ooolG0000000502PV:P1fM7d0[JVg0;Rd``2m^LT0102o^//20;njbP80
_[[900@0_K[90;fib02m^LP0_;W80`2m^LP01@2n^/T0_k_90<2kb@32_L/0`l3<0080a<3=00<0a;o=
0<6lbP2n^LL0102m^<H00`2m^LH0_[W60;jiaP040;jiaP80_;O400@0^[G20;Vd`@2g/[h0^;:n0`2g
/[h00`2g/[d0]k6m0;Na_@020;Na_@P0]k6l00<0][2k0;J`^P2f/;X00`2f/;X90;Na^P<0]k:j00<0
]k:k0;Rc^`2h/k`00P2h/k`30;Vc_0H0^KBl0P2i];/01@2j]K`0^kFl0;^e_@2k]Kd0^kJm00<0_;Jm
00@0_;Nm0;fg_@2m]kd0_[Rm1P2n^;h40;ni_P030<2j_P31^[l0`KZo00<0`KZo00D0`K^o0<6k`031
^l00`K_00<:k`0030<:l`00;0<:m`033_L00`kg00<Bm`@34_/80a;k10<Bn`P35_/80aKo20<Fo``36
`<<00P36_l<00`37_l<0al330<O0``030<O0``80al730P38`L@01@37`<<0]k2c07YfN011?d001@D5
00H0000000P00@4100D41@051@D00P8202DS9031^[`0e/k?0=K>d080e/g?00@0eLg?0=K=c`3Fc]00
elk@1@3FcLh20=K=c`@0e/k>103Gc/l40=S?c`030=S@c`3Id<l0fM3?0080fM3?00@0f=3?0=W@d03I
d=00fM7@1P3JdM040=_Bd@050=cBd@3Kd]00X9VH02l];@0?3Ph00`0000000`24P7d0g]OC0>;Ke`02
0>;Je`040>;JeP3RfmH0h]_F0>;KePL0h][F1@3SfmH0103Nem80Thj;0:BNV@3UgML30>CLeP030>CK
e@3SfmD0i=_E0080i=_E00<0iMcF0>CLeP3Tg=H00P3Tg=H20>CLe@H0iMcE00@0i=_D0>7IdP3Ug=@0
i]gE0P3Vg]D20>ONe@/0imkF0P3Wg]D01@3NeLd0WIJ@0;:ZX`3Qf<h0imkD00@0imgC00@0imgB0>ON
dP3VgM80i]gB0P3Vg]80103Wg]80i]kA0>KNd@3Vg]450>ONd@030>KNd03Ug<l0i]k?00@0imo@1@3W
gll03@3Sfl/0h=S90>OOc`3Wgll0iMg<0>3Hb02c[J00PGac07mkL@1mNFl0TXf209J@Q@0m>cL0;000
000<0?ooo`002P3ooolF0000000400H61P1<BU00YjBc0;nkbPP0_[[:00@0_[[90;jib@2m^LP0_KW8
0P2l^LP30;fib0060<2kb@30_L/0`Kg;0<6mbP33_/`0a;o=0P35`<h00`31_L/0_KW60;fhaP040;fh
aPP0_[W600D0_;O40;Ze`@2h/kl0^;:o0;Nb_P040;Nb_@040;Na_@2g/[d0]k:m0;Nb_@@0]k6l0`2f
/K`30;J`^`80][2j0P2f/KX70;Na^P@0]k:j00<0]k:k0;Rc^`2h/k`00`2h/k`00`2i/k`0^KBl0;Vd
_0050;Vd_0040;Zd_02j]K`0^[Fl0;^e_@80^kJm0`2l][d01P2l]kd0_KNm0;fg_@2m]kd0_KRm0;fh
_P@0_[Rn00@0_[Vn0;ni_P2o^Kh0`;Zn1030^[l20<6j_`@0`K_000H0`[_00<:l`032_<00`[c00<:m
`033_L020<>m`@080<Bn`@34_/80a;k20<Fn`P35_l<0aKo20<Fo``36`<<20<Jo``030<No``36_l<0
al330080al3300<0al730<O0``37`L<00P38`L@01@32^Kd0ShF7044o@00R8B800P8200@0000000P0
5A@D03Le=P1QGEh0RXJ709bFU`29Q8D0UY2A0=C<cP80e/k?0P3FcLl20=G=c`80e/g?00<0eLg>0=K=
cP3FcLh00P3FcLh00`3FcLl0e/k?0=K>c`030=K>c`@0elk?00<0elo?0=S?c`3Hcll00P3Hcll30=S@
c`80fM3?00<0fM7?0=WAd03IdM00103JdM020=[Ad@070=[Bd@3Kd]00g=;A0=_Cd@3Ldm40elk=06aX
J005000000040:6KV@3QfMH0h][G0>;Je`80hM[F00<0h][F0>;KeP3RfmH01P3Rf]H00`3RfmH0hm_F
0>?KeP020>?KeP050>CKeP3Oe]80^[>_0;^e/03Ug=L0103Tg=H20>?Ke@030>CKe@3Tg=D0iMcF00L0
i=cF103Ug=H40>GLe@80i]gE0`3Vg]D20>KNeP030>ONeP3Xg]H0j=kF0080j=kF00X0j=oF0>OMe@3S
fM40e<c50;Zc[02c[:H0Qh5l02XX9`0/:bT0`k^b0`3Wg]<0103WgM<0imkC0>ONd`3Wg]<40>ONdP03
0>KNdP3Wg]80imkA0080imkA00L0imkB0=WAa@34_K80_[J/0;J_Y@2RW980_kR]0080imoA103Wgm03
0>OOc`0=0>GMc@3Ug/d0imo?0>KNcP3MeLD0b<6c07QdK00M71X03Ph=014A400Q81h0:BLT014@3`0/
000000`0oooo000:0?oooa<0000000P00@41018B500B4Q@0ATE;09>@W02k]lP0_[[;0;jibPL0_[[:
00@0_[W90;fib02m^LP0_KW80P2l^LP0102l^LL0_KW70;fia`2n^/T20<2lbP090;jjb030_<X0`kk<
0<G0cP35`Lh0`Kg:0;fia`2l^<H0_KS600<0_KS500<0_KS60;jiaP2n^LH01@2n^LH00`2l]l@0^[G1
0;Vc`0020;Rc_`80]k:n1@2g/[d20;Rb_@80]k6l00@0][2l0;Ja_02f/K`0][6l102f/;/30;Ja^`03
0;Na^`2g/KX0]k6j00<0]k6j1@2g/[X00`2g/[/0^;>k0;Rc_0030;Rc_0030;Vc_02i];`0^KBl00@0
^KBl0P2j]K`0102j]Kd0^kFm0;^e_@2k][d30;bf_@030;bg_@2m]kd0_KNm0080_KNm0P2m^;h30;jh
_P040;ji_P2o^Kh0_kVn0;ni_PL0`;Zo00D0`K_00<:k`031^l00`Kc00<:l`0050<>m`@060<Bn`@34
_/80a;k20<Bn`P35_/80aKk31035_l<20<Jo``030<No``36_l<0a/3300<0a/3300P0al330<O1a038
`LD0b<750;R]/01LCDd01`L700@410D0000000D0;R`]07]gN02l]KL0dL[<0=G>d0020=?<cP80eLk@
00H0eLg?0=G<c`3EcLl0eLg?0=K=c`3EcLl50=G=cP@0e/g>00<0e/k>0=K>c`3Fc/l01@3Gc/l0103G
cll0f<o?0=S?c`3Hcll40=S@c`80fM3?0P3IdM030=[Ad@80f]7@00<0f];@0=_Bd@3Kd]400P3Kd]40
0`3Ldm40`KVh0490?`030000000300820P061@D0_;Jc0080h][G00@0hM[F0>;KeP3RfmH0h][F0P3R
fmH50>;JeP030>;KeP3SfmH0hm_F0080hm_F00D0hm_G0>CKe`3Tg=L0i=cG0>CLeP020>CMe`030>GM
e`3Tg=L0i=cG00<0i=cF00H0i=cG0>GLe`3Ug=L0i=cF0>GLeP3Tg=H60>GLeP80iMgF0`3VgMH40>KN
eP<0imkF103Xg]H20>SOe`040<k5_P1`JfL09B<S00D51@<0000000<051<B09VCS03VgM801`3Wg]<3
0>ONdP80i]kB00X0imkB0>KNd@3Ug=00gMG909:<Q00Z:BH01`L600H61@020P80M6mX0`3Wgm430>OO
d00;0>CMc@38`K@0]K2S0<g7^@3Vg/h0imo?0>?Kb`3Cc;d0cLJh08^6O@0N7A/0<@00000<0?ooo`00
2P3ooolC0000000700<3100b<CH0<S4f08f:UP2j]/H0`;_<0;jjb`020;fibP@0_KW90P2n^/T01@2m
^/T0_[[90;fjb@2l^LP0_;S800@0_;S700H0_KW70;njb02n^LP0_;O60;njb032_L/20<G1cP040<6m
bP2m^LH0_;S60;bhaP<0_KS600<0_KS50;fhaP2n^LH01@2n^LH01P2l]l@0^[C10;Rb`02h/[l0^;>o
0;Rc_P@0]k>n0P2g/[d30;Na_@050;Na_02f/;`0][2l0;J`_02f/K`0102f/K/60;Na^`H0]k:k0P2h
/[/00`2h/k/0^;>l0;Rc_0050;Rc_0030;Rd_02i];`0^KBl0080^KBl00@0^KFl0;Ze_@2k]Kd0^kFm
102k][d00`2l]kd0_KNm0;fg_@030;fg_@@0_[Rn00D0_[Vn0;ni_P2o^Kh0_kVo0<2j_`050<2j`003
0<2k`031^l00`K_00080`K_000<0`Kc10<:m`@33_L401033_L430<Bn`P030<Bn``35_/<0aKo300@0
aKo300@0a[o30<K0``37`<<0al330`36`<<01`37`<@0al740<S1a038`LD0b<740:RNX016?3d01@00
00002P0@3`l08b8R05iKG02_Z:X0dl_=0=G=c`3Fc]00eloA0=K?d@3Ec]020=G=c`80eLg>00@0eLg?
0=G=cP3EcLh0e<g>1@3EcLh40=K=cP80e/k?1`3Gc/l20=S?c`030=S@c`3Id<l0fM3?0080fM3?00<0
f=3?0=S@d03IdM000`3JdM400`3JdM00f]7A0=[Bd@020=[Bd@80fm;A00<0g=?B09:=R`0P7Qh00`00
0000100l>SX0SXV70<o9aP3Qf]L80>7JePD0h][F0`3RfmH20>?Ke`030>CKe`3Tg=L0i=cG00<0i=cG
00H0i=gG0>GMe`3UgML0i=cF0>?KeP3Tg=H30>GLe`H0i=cF1P3Ug=H20>GMePD0i]kF0`3Wg]H20>?J
dP050=cCb`30]k00TH^6079^J@0Y9bH01P0000000`1TGe/0f];80>OMd`070>ONd`80imkB00P0i]kA
0=O@a034_K80_KJ/0:JPU`1oNg<0ATA0018A40<0000000<0LfmX0>OOd@3Wgm40103Wgm402`3Wgm00
h]_<0=oGb03PfLX0iMk>0>OOc`31^Zd0N7E/07A`J015@Sh03`h=03400000303oool000X0oooo4@00
00000`051@D051@F03`l@00208B1S@050;ZgaP30^l`0_k_<0;jjb`2n^/X01P2m^LT20;fjb@040;jj
b@2m^LP0_;W80;bhb0@0_;S700X0_;O60;fha`2n^/P0_k_90<6mb`33_ld0aL7>0<G0cP32_//0_[[8
202m^<H50;jiaP030;bga02j]L80^K?00080^K?00P2h/kl30;Nb_P80]k:m102g/Kd0102f/K`0][2l
0;Ja_02f/K`50;Ja^`@0]k6k1P2g/[/30;Rc^`L0^;>l0`2h];`30;Vd_0030;Ze_02j]Kd0^kJm0080
^kJm00<0_;Jm0;bf_P2l]kd0102m]kd20;fh_@<0_KRn00@0_[Vn0;ni_`2o^Kl0_kVo1@30^/020<2k
`0@0`K_00P31_<400`32_L40`kg10<>m`@020<>m`@050<>n`@34_/80a;k20<Bn`P34_/<01P35_l<2
0<K0``80al3300@0a/340<K1a037`<@0al740`38`LD00`36_l80THZ=03Pd=00500000007030_;`1]
JF/0Z::U0<k6b@3Cc<h0eLg@0=K>d@020=O@dP070=K?d@3Fc]00e/k@0=G>d03FcM00e/g?0=G=c`04
0=C<cP030=G=c`3EcLh0eLg>00D0e/g>0`3Fc/h00`3Gc/l0elo?0=O?c`020=O?c`80f<o?1@3Hd<l0
0`3Id<l0fM7@0=WAd@060=[Ad@80f];A00`0fm?A0=[Bd@2e[jh0CDY:018A4@0000000@4100820P1f
LW40f]?@0>;Ke`3Qf]L20>7Ke`80h]_G0P3Qf]L40>;Je`<0h]_G00P0hm_G0>?KeP3SfmH0hm_G0>?L
e`3Tg=L0iMgH0>GMe`80i=cG00D0i=gG0>GMe`3UgML0iMgG0>GLe`020>CLe`80iMcG00@0iMgG0>CM
e`3Tg=H0i=cF1P3UgMH50>KMeP@0i]kF00@0i]kG0>ONeP3WgmH0eLg60P1bKVX01@13@3l0=38`01hM
700E51<020L700H0000000<0;RdZ08B0NP3Ec<800P3Wg]<00`3Wgm<0imkC0>ONd`020>ONd`80imoC
00D0f];705UED00G5aD04a8A00P71`060000000506MSG@3=a[X0d<Vl0=kGb@3Vg]000P3Wgm420>OO
d0060>OPd03Ug/h0i=c=0=oHb021OG@00`<3=000000<0?ooo`002P3oool@00000004014A4P0l>Sl0
M75k0:JS/@80^[O60P2o^l`00`2n^/`0_[[;0;fjbP090;fib@050;fib02l^LP0_;S70;^ga`2l]lL0
0P2l]lH0302k]lH0_KS70;nkb@32_/`0`ko=0<C0cP35`Lh0a<3>0<>oc@31_L/0_k_90;jia`P0_KS6
0`2n^LH0202m^<D0_;O30;Zf`P2i]<40^K?00;Rc`02h/kl0^;>n1@2g/[h40;Nb_@040;Na_@2f/Kd0
][6m0;Ja_0@0][6k0`2g/K/50;Nb^`T0^;>l0`2h];`40;Vd_0<0^KFl00<0^[Fm0;^e_@2k]Kd00`2k
][d30;bg_@@0_KNm0P2n^;h20;ji_P80_kVn00<0_kVo0<2j`030^/000P30^/000`30^[l0`;_00<2k
`0030<6k`0<0`Kc100<0`[g10<>m`P33_/800`33_/801@34_/80a;o30<Fo``35_l<0aKo40080aKo3
0`36_l<40<K0``80a/3400P0al740<S1a@38`LD0b<750<O1a02o^K`0NGEg02TX:0D0000000L0B4I7
0:>NX03>alT0eLk@0=K?dP3Fcm40eloB0080em3B00P0eloB0=K@d@3Fcm40e/oA0=G=d03EcLl0e<c?
0=C<cP80dlc>0P3Dc<h20=G=c`80e/g?0`3FcLh40=K>cP050=O>c`3Gcll0elo?0=O?c`3Hd=001`3H
d<l00`3HdM00fM7@0=[Ad@020=[Ad@<0f];A0`3Kdm402P3Jd]00TXf<01<B4P0410@00000034`;`22
OW`0^kFb0=_Dd@3Rf]P20>7Je`<0hM_G0P3Qf]L30>;Je`@0h]_G0`3RfmH01`3SfmL0i=_G0>CLe`3T
g=P0i=gG0>CLe`3TgML00P3UgML20>GMf0<0iMgG103Ug=L00`3Tg=L0iMgF0>GMeP070>GMeP030>KM
eP3Vg]H0i]kF00@0i]kF00@0i]kG0>GLe@3<a;h0OWUe0P0F5A@<0000000400410@1nNG80i=cA0>ON
e080imoC0P3Wg]<01@3Wgm<0imkB0>GLd02WXIP05aHE00T0000000D0<Bl/065NF01WI5h0ShZ20;F_
Y0020;fgZ`<0_KNZ00D0[jZO09jJS`25PGP0?3Xf00410@0d000000`0oooo000:0?ooo`l0000000D0
1@D503Lg?025PXh0];300;nkb`030;jkb`040;jjb`2m^//0_KW:0;fibP@0_KW9102m^/T0102l^LT0
_;W80;bha`2k]lL50;^gaP030;bha`30_<X0a<3>0080aL7?00L0a/7?0<G1cP35`<h0`l3=0<:nc031
_<X0_KW700L0_KS600P0_KW60;jiaP2n^LH0_[W50;fia@2l^<@0^kK20;Vd`@80^K?000<0^;?00;Rc
_`2g/kh00`2g/kh50;Nb_@80][6m00<0][6l0;Ja^`2f/K/00P2f/K/20;Na^`D0]k:k00<0]k>l0;Rc
_02h/k`01P2h/k`40;Rd_0<0^KBl0`2i]K`0102j]Kd0^[Jm0;^f_P2k][d20;^f_P80_;Nm0`2m]kd3
0;fh_@030;fh_P2n^;l0_[Vo0080_[Vo00<0_kVo0;nj_`30^/000`30^/000`30^l00`K_00<6k`002
0<6k`0<0`Kc100<0`Kg10<:m`P33_/801033_/820<Bo``040<Fo``35_l@0aL340<Foa080a[o400<0
a[o30<K0a036`<@01036`<@02@37`L@0al750<S1a@38`LD0al740<2j_02LV9T0IV=U028P80020000
000901lN7`16A4D0ATA507A`L`2KUYP0]k6d0<g6b@3Fcm80eLoA00<0e/oB0P3Gd=801@3Fc]40e<g?
0=C<cP3Cc<h0e<c>00<0dlc>1@3Dc<h30=G=cP040=K=cP3Fc/h0e/k>0=K>cP<0e/k?0P3Gcll50=S@
d080fM3@00<0f=7@0=WAd@3IdM401P3JdM401@3Jdm40f];A0=_Bd@3Gclh0M75_00<0000000<0HUmM
0=;<b@3Pf]H00P3Rf]P0103Qf]L0hM_G0>7Ke`3RfmL60>7Je`80h][G0P3RfmL40>?Le`@0i=cG0P3T
gML60>GMf0D0iMgG00<0i=cG0>GMe`3UgML00`3UgML20>GNe`030>KNe`3Vg]H0i]kF00D0i]kF00D0
i]kG0>ONe`3GclP0DTm<00l?3P0?0000000303`h=P2c[:@0hMW>0080imoD00L0j=oD0>CLd@3Vg]80
bL:g09:<Q@11?c`00P8200`0000000<01@@400`<2`0>3Pd0100>3Pd00`092@P00P820000000f0000
00`0oooo000:0?ooo`d0000000D00`<301<B500k>Cl0RXRD0;ReaP020;jkc080_[_;0`2m^//20;fj
bP030;fibP2m^LT0_KW900@0_K[900@0_KW90;bib02l^<P0^kS71P2k]lH03@2l^<H0_k[90<2mb`32
_/`0aL7?0<K2d034`<h0`Kg;0;njb@2n^LP0_[W70;fhaP2l^<H01P2m^<H00`2m^LH0_[W60;jiaP03
0;jiaP070;bfa02j]<40^;?00;Rc`02i/l00^;>o0;Nb_`040;Nb_P040;Nb_@2g/Kd0]k6m0;Na_@80
][6m1P2f/K`00`2g/K`0]k:l0;Nb_0020;Nb_0030;Nb^`2g/k`0^;>l00H0^;>l00<0^;Bl0;Vd_@2i
];d00P2i];d30;Vd_080^KFm0P2j]Kd00`2j][d0^kJm0;^f_@020;^g_@030;^f_@2l]kd0_;Nm0080
_;Nm00D0_KNm0;fh_@2m^;h0_[Vn0;ji_`030;ni_`050;nj_`2o^/00`;_00<6k`@30^l400P30_<46
0<6l`@030<6m`P32_L80`kk20080`kk20P33_/<01034_/<0a;o30<Bo``34_l<30<Foa0030<Joa036
`<@0a/3400<0a/340P36`L@00`37`L@0b<750<S1a@030<S1a@040<>l`02TWj80IfAV01dL7@800000
00X0@T1109FAT`2ETI<0^KBg0<K1``3:a<L0d<[=0=K>d@3DcM00e/kA103Fcm80103DcLl0dl_>0=?;
cP3Cblh50=?<cPL0e<c>00@0eLg>0=K=c`3Fc/h0e/k>0`3Fc/l20=O?c`030=S?d03Hcll0f=3@00<0
f=3?0`3HdM000`3IdM40f]7A0=[Ad@040=[Bd@0=0=[CdP3Kdm40fm?A0=?;bP1RGeh00000010@4019
ATD0ZjJU0=oHeP3Dc//0g]OD0>7Je`030>7Ke`D0hM[G1P3RfmL0103RfmP0hm_G0>?Ke`3SfmL20>CL
f0<0i=gH1`3UgMP20>GNf0030>GMf03TgML0iMgG00D0iMgG103Ug]L80>KNe`030=kFcP2EShX07ahL
0100000000@00@4101LF5@2ET8T0i]kC0P3Wgm@00`3Wgm<0h=S=06IRG@1?000000`0oooo000:0?oo
o`d0000000L020P903Lf>`24PXh0];710;jjb`2n^l`0_K[;00<0_K[:00D0_KW:0;fib`2m^LX0_KW:
0;bibP050;fib@030;bib@2l^LP0_;S700@0^kO71@2k]lH01`2l^<L0_KW70<2kbP33_ld0a<3>0<6m
b`2n^LP00`2l^<H00`2l]lD0_;S60;fhaP050;fhaP80_KW6102n^LH00`2l]l@0^[G20;Vc`0020;Vc
`0030;Rc`02h/kl0^;>o00@0]k:n00<0]k:m0;Na_@2f/Kd00P2f/Kd00`2f/[d0][6m0;Ja_@020;Jb
_0L0]k:l1P2g/k`20;Rc_0030;Rd_@2i];d0^KFm00P0^KFm00@0^[Jm0;^f_P2k][h0^kJn0P2l]kh0
0`2k]kh0_;Nn0;fg_P050;fh_PD0_[Vo00@0_kZo0<2j`031_<80`[c30`30_<840<6l`P030<6l`@31
_<80`kg20080`kk30P33_/800`33_/<0a;o30<Boa0020<Boa0030<Bo``35_l@0aKo40080a[o41`36
`<@00`37`L@0b<750<S1a@020<S1a@050<Fo``2i/kH0TXj@05AADP0D51@00P000000200l>c`0QhB6
08N4QP2j]KP0dlg@0=K@d`3Gd=<0e/kA1P3DcM000`3Cc<h0dl_>0=?;cP020=?;cP030=?<cP3Dc<h0
e<c>00<0e<c>1@3DcLh20=G=c`D0e/k?0P3Gcll00`3Hcm00f=3@0=S@d0020=S@d0070=SAd03HdM40
f=7A0=SAd@3IdM40f]7A0=WAd@020=[Ad@80f];A00`0f]?B0=_CdP3Kdm80bl?205YGEP061@D0:bXY
09VET`3Of=D0hM[H0>;Jf03Qf]P30>7Ke`D0hM[G00<0hM_G0>;Ke`3RfmL00`3RfmL00`3Rg=L0h]cH
0>?Kf0020>?Kf0030>CLf03TgMP0i=gH00@0i=gH1`3UgMP00`3Ug]P0i=cF0>GMe`030>CMe`D0iMgG
00<0iMkG0>GNeP3Ug]H01@3Vg]H0103VgMH0ZjBO01TI60020P4B0000000704Q5@P2k]J`0fmC90=[C
b03:a;T0UY2803<a;P1?000000`0oooo000:0?ooo``0000000@00@41014A4P1OGVL0/jo00P2n^l`0
1P2n^l/0_K_;0;fkb`2m^l/0_K[:0;fjb`80_K[:0P2m^LX30;fjbP80_;W90P2k^<P00`2k^<L0^kO7
0;^ga`020;^ga`<0^kO600X0_;O60;bhaP2l^<H0_;S60;jjb@31_L/0`kk=0<2lbP2l^<H0^kO50`2l
]lD20;bhaPH0_KS60P2m^LH30;jiaP030;^ga02j]<40^K?000@0^K?000<0^;?00;Rc_`2g/kh00`2g
/kh00`2g/[h0][:m0;Jb_@020;Nb_@D0][:m00<0]k:m0;Nb_02g/[`00P2g/[`70;Nc_0030;Rc_02h
];d0^KFm00H0^[Fn1P2k][h50;bg_P<0_;Nm00<0_;Rm0;fh_P2m^;h00P2m^;l02@2m^Kl0_[Vo0;ji
_`2o^L00`;[00<6l`P32_L@0`[k40<2l`P050<6l`P80`Kc10P32_L820<>m`P80`kk300<0a;k30<Bo
a034_l@00`34_l@00`35_l@0a[o40<Foa0030<G0a0@0a/340P36`L@30<O1a@060<2k_`2VXJ@0QH23
05=@DP0_;Bh02`/;0P0000001@0I61T0>3Lh03Pg>02?Rhh0d<[=0080e]3C00<0e/oB0=G>d@3CcLl0
0`3Cc<h00`3Cblh0dlc>0=?<cP070=?<cP80e<c>00<0e<g>0=C=c`3DcLl00P3DcLh20=G=cP030=G=
c`3Fc/l0e/k?0080e/k?0P3Gcll30=S@d0<0f=7@0`3HdM400`3IdM40f];A0=[Bd@040=[Bd@80f]?B
00P0fm?B0;N`[`1ACdh0KV]Z0:nZZ02d[Zd0`[bk0=kGe@80hM[H0P3QfmP90>7Je`050>7Ke`3RfmL0
h]_G0>;Ke`3Rg=P0103Sg=P01@3Tg=P0i=gH0>CMf03TgMP0iMgH0080i=gH1@3UgMP20>GNf0030>7J
e03TgML0i=gG00<0i=gG1@3UgML30>GNe`<0i]kG00@0hMWB0<S1^P1NFeL00P814`0000001`051@@0
92<R044n?010?3X0<2l/01@C4P020P40C`00000<0?ooo`002P3oool<0000000501<C5@1<Be40WIZY
0;fib`2n^l`00P2m^//40;fjbP040;fjb`2m^/X0_;W:0;fibP@0_K[:00@0_;W90;^ib@2k^<P0^kS7
1@2k]lL20;^gaP030;bib02n^/T0_[_90080_[[900H0_k_90;nkbP2o_<X0_[[80;bhaP2k]lD40;bg
a@80_;S61@2m^<H20;fiaP80_[W600<0_KW60;^f``2i]<401P2h/l000`2g/kl0]k:o0;Nb_P030;Nb
_P80][:m0P2g/[d00`2g/[h0]k:m0;Nb_@040;Nb_@H0]k>m102h/kd20;Rd_@030;Ve_P2j]Kh0^[Fn
00@0^[Fn0`2j][h30;^f_P030;^g_P2l]kh0_;Nn0080_;Nn0P2l^;h30;fh_PD0_KVo00L0_[Zo0;nj
`031_<80`kk40<BnaP32_L@0`;_200H0`Kc200@0`Kg20<:m`P32_L<0`[g20`33_/<20<Bna0040<Bo
a034_l<0a;o30<Boa080aKo400@0aL340<K0a036`<@0a/341@36`L@03@37`LD0b<750<O1a@34_l<0
V9>F04]8BP0`;Rh04a8B00X92@0;2`/0?C/l06UWJ01nNgd00P2CSY001`2[YZT0d/c?0=K?d`3Ecm<0
eLoB0=G@dP3CcM000P3Bblh00`3Cblh0dlc>0=?<cP090=?<cP030=C<cP3DcLl0e<g?00@0e<g?00<0
e<g>0=G=c`3Fc/l00`3Fc/l20=O?d0D0f=3@00<0f=7@0=SAd@3HdM400P3HdM40103IdM40f]7A0=[A
d@3Jd]420=[BdP0:0=[CdP3Jd]40a;fl081kN`12@400^K>b0>7Jf03NemD0gMKD0>3Ie`80hM_H00<0
hM_G0>7Je`3Qf]L00`3Qf]P40>7Kf080h]_H0`3RfmL00`3Rg=P0hmcH0>?Lf0020>?Lf0030>CLf03T
gMP0i=gH00<0i=gH1@3UgMP30>GNf0040=WBc03TgMP0i=gH0>CMf080iMgH0P3Ug]P00`3UgMP0iMgG
0>GNe`020>GNe`<0i]kG00@0h][C085lN00P7ah01PH6JP00000<0?ooo`002P3oool<0000000502/[
;`24Phh0^kS80;nlc@2m^l`00P2m^//30;fkb`80_K[;102l^LX30;bib@030;bjb@2l^<P0^kS800<0
^kO70P2k^<L20;^ga`040;^gaP2m^/T0`;g;0<6nc080`Kg<00D0`;c;0;nkb@2m^<L0_;S60;^gaP02
0;^ga@@0_;O50P2l^<H30;fhaP@0_KW600<0_KW50;bha02j]/<0102j]L820;Vd`@80^;?000<0]k>o
0;Rc_`2g/[l01P2g/[h50;Nb_@P0]k>m00<0^;>m0;Rd_@2h];d00P2h];d20;Vd_P80^KFn1@2j]Kh0
102j][h0^kJn0;^f_P2k][h20;^g_PD0_;Nn0P2l^;h0102m^;h0_KRo0;fh_`2m^;l30;fi_`070;ji
`030^l00`kk40<K1b034_lH0`[g40<2l`P020<6l`P@0`[g20`32_L<00`32_/<0`kk30<>n``020<Bn
a0030<Boa035_l@0aKo400<0aKo41P35`<@01036`<@0a/740<K1a036`L@30<O1a@030<2j_P1UHVD0
000000<0000000@06APH09JAU03;a/T0d/_?0P3Dc]800`3Dc]40eLkB0=C>d@020=?=d0030=C=d@3C
c<l0d/_>00@0d/_>1`3Cblh20=?<cPP0e<g?00<0eLg?0=K>c`3Fc/l00P3Fcm020=O?d0030=O@d03H
d=00f=3@0080f=3@00D0f=7@0=SAd@3HdM40f=7A0=WAd@030=[BdP<0f];A00`0f]?B0=SAd02EShl0
?3Xj03/h>03;a/@0gMKE0<>n_02i];<0fM?A0>3Jf03QfmP50>7Jf0050>7Kf03QfmL0hM_G0>7Ke`3Q
fmP0103RfmP40>;Lf080hmcH1`3TgMP20>GMf0@0iMkH00D0i=gF0;fg/P2o^K@0hmcF0>GNf0030>GM
f0D0iMkH00H0i]kG0>GMe`3Pf=80f=7:0;6ZY@0n?3Y/000000`0oooo000:0?ooo`X0000000T02PT:
01lN8@1UHfh0[jfn0;nlc@2n^ld0_[_<0;fkb`2l^//01@2m^//01@2m^/X0_;[:0;bjbP2m^/X0_;[:
00<0_;W900<0^kS80;Zhb02j]lL00P2k]lL30;^ha`0;0;^ga`2k]lH0_K[80<2mc032_/d0`Kk<0<6m
c030_</0_[[90;bga`2l]lH00P2k]lH00`2k]lD0_;O50;bga@020;bga@<0_;S6102m^<H01`2m^LH0
_[W70;fiaP2k]l@0^[K30;Ze`P2j]/800P2k]/<00`2j]L80^KC10;Rc`0030;Rc`0<0]k>o102h/kl0
102g/kh0]k:n0;Nb_@2g/[d90;Nc_@@0^;Bm0`2i]Kh60;Ze_P@0^[Jn0`2k][h20;^g_P030;bg_P2l
^;h0_;Rn0080_KRo0P2m^Kl50;ji_`080;nj`030^l40`[g40<C0aP34_/D0`Kg30<2l`P31_<840<:m
`P@0`[g300@0`[k30<>n``33_/@0a;k40`34_l@01@35_lD0a[o50<Foa@35`<@0aL3500D0aL3400@0
aL740<K1a@36`LD0al750`37`LH00`2i/kL0DTe?000000030000000302TX:@2n^[d0e<oB00<0e<kB
00<0eLoC0=C>d@3Cc=000`3Bc<l00`3Bbll0d/_>0=;;cP020=;;cP<0dl_?0`3Cc<l20=C<c`060=?<
cP3Dc<l0eLk@0=G>d03Fc]00eLk?103DcLl00`3EcLl0e/k?0=K>c`020=K?d080elo@00<0f=3@0=SA
d03HdM401P3HdM420=WAdPD0f];B00`0f]?B0=K?cP1ZIfL01@D504E4@`3Hd]40h=[H0>3Kf@3Pf]P0
fmKD0>3Je`3QfmP30>3Jf0<0hM[H00<0hM[G0>7Ke`3QfmL0103QfmP00`3RfmP0h]cG0>;Lf0020>;L
f0030>?Lf03SgMP0hmgH00H0i=gH0P3UgMP30>GNf0080>;Ke@2c[JT0FUME06]WI@3Le<l0iMkH0>GM
f03UgML20>GMf0030>KMf03Vg]P0i]kH0080i]kG00D0/J^V04i;B@0i=SD09bDU00/;2P1/000000`0
oooo000:0?ooo`X0000000@08b<V06ETK@2UXk80_;[;0P2n^ld00`2m^l`0_K[;0;fkb`030;fkb`80
_K[;00@0_K[:0;bjbP2l^/X0_K[:102l^LT00`2k^<P0^[S70;Zga`040;^ga`<0^[K600<0^kO60;fi
b02n^/T00`2n^/T0102n^LP0_KS70;bgaP2k]/H30;^gaP<0_;O51@2l^<H20;fhaP070;fiaP2m^LL0
_;S50;Zf`P2h]<40^[K30;^ga0020;bga0030;^f``2j]L80^KC100<0^;?000<0]k>o0;Nb_`2g/[l0
0`2g/[l20;Rc_`L0]k>n0P2h/kh00`2h];h0^;Bm0;Rd_@020;Rd_@80^;Bn00<0^KBn0;Ve_P2i]Kh0
0`2i]Kh40;Ze_P80^[Jn00<0^kJn0;^g_P2k]kh00`2k]kh20;bg_P80_;Rn00<0_KW00;ji`02n^L00
0P2n^L00202n^/00_[Zo0;jj_`2o^/00`;_20<6l``31_L@0`Kg30P31_<800`31_L80`[g20<:m`P02
0<:m`P<0`[g300D0`[k30<>n``33_/<0`kk40<>oa0030<Boa0<0aKo41035`<D00`35`LD0a/750<K1
a@020<K1a@D0al7600<0]:jb04I2@`0000000`000000100c<C<0^;>f0=C>dP3DcM420=C=dP040=G?
dP3Ec]40dlc@0=;;c`80d/c?1@3Bblh20=?;c`D0dlc?00D0e<c?0=?<cP3Dc<l0e<g?0=G=c`060=C=
c`030=G=c`3Fc/l0e/k?0080e/o@0P3Gcm000`3Hd=40f=7A0=SAd@050=SAd@030=WBdP3Jd]80f];B
00<0f];B00l0fM;B0=[BdP3Jdm80eLk=06eYJ01iMW@0aL2o0=;=b`3NfML0h=[I0=oIe`3Cc/`0gm[G
0>7Kf03Pf]P00P3Qf]P20>7Kf0040>7Je`3QfmL0hM_G0>7Ke`80hM_H0P3RfmP50>;Lf0040>?Lf03T
gMP0i=gH0>CMf0@0i=gI0P3TgMP40>GNf00@0=WCc@16A48000000490?`2FTHh0XIbH0;be/@3Jd/d0
h][D0>;Ke@3Tg=L0iMgG0>CLeP3Rf]@0clS205]HEG000000303oool000X0oooo2P0000000`0m?480
V9JT0;bib`020;jkc@80_[_<00<0_K_;0;bjb`2l^//0102m^//0102l^/X0_;W:0;bibP2l^LX20;bj
bP030;^ibP2k^LT0^kS80080^[O70`2j]lH00`2j]/L0^[K60;ZfaP020;ZfaP050;^faP2k]lH0_;O7
0;^ga`2l]lL00P2l]lH00`2k]lH0^kO50;^gaP030;^gaP030;bgaP2l]lD0_;S600D0_;S600L0_KS6
0;fiaP2m^LL0_;W50;^ga02j]/<0^kO40080_;O50P2k]l@0102k]/<0^[G20;Vd`@2h]<020;Rc`080
]k>o0P2h/kl0102g/kl0^;>o0;Rc_`2h/kl30;Nc_PX0^;Bn0P2i];h60;Ve_P<0^[Fn0`2j][h20;^f
_P040;^g_`2k]kh0^kNn0;^g_P80_;Ro00<0_;Rn0;fh_`2m^Kl01P2n^Kl0102n^/00_k_10;nk`@30
^l830<2l`P80`Kc21031_L820<:m``80`[k30`34_l@20<Boa@<0aKo50P35_l@60<G0a@<0a/751037
`LH00`35`<@0XYjQ03Dd=@040000000405QEF033_/80eLoC0=C>dP80eLkB00<0eLoC0=C?dP3Bc=00
0P3Bc<l00`3Bbll0d/c?0=;<c`030=;<c`D0dl_?103Cc<l20=?<cP@0e<g?00L0e<g>0=C=c`3DcLl0
eLg?0=K>c`3Fc]00e/o@0080elo@00@0em3@0=SAd@3HdM40f=7A1@3HdM80103IdM80fM;B0=WBdP3I
d]840=[BdP090=[CdP3Cc</0LFi^0;nj^@3Of]P0g=OE0=OBd@3Ke]@0h=[G00<0hM_H0`3Pf]P20>7J
f0P0hM_H0P3Rg=P0103Rg=T0hmcI0>?Lf@3Sg=P30>?Mf0060>CMf03TgMT0i=gI0>CMf@3TgMP0i=kH
0`3Ug]P04@3Ug]T0b/Bo0450?P0000004Q4A02TX9`0[:RT0>3He05QED`1]JFL0L6aY08F2O@2ET8`0
Og]g06i[J01@CD`05QDD07000000303oool000X0oooo2@00000010020P80CdiE0:ZX]`2n_<h30;jk
c@80_K_<00<0_K_;0;fjb`2m^//00`2m^//01`2l^//0_;W:0;bibP2l^LX0_;[:0;bibP2k^LT00P2k
^<P20;Zga`@0^[O61P2j]/H70;^faPD0^kO600<0_;O60;bga@2l^<H0102l^<H0102l^LH0_KW60;fi
a`2m^LH20;bha@80_KW500<0_;S50;bga@2l]l@00P2k]/<0102j]L<0^KC20;Rc`02h/l040;Rd`003
0;Rc`02h/kl0^;>o00<0^;>o0`2h];l20;Vd_`040;Ve`02i]Kl0^KBo0;Vd_`P0^KFo0P2j]Kl00`2j
][l0^[Jn0;Zf_P030;Zf_P030;^g_P2k]kl0_;Ro00<0_;Ro0`2m^;l30;fi`0030;ji`02n^/00_[[0
0080_[[000@0_k[00;nk`@30_<80`;c30P30_<820<6l`P@0`Kg200P0`[g20<:m``32_/<0`[k40<>o
a034_lD0a;o40<Boa@D0aKo51`35`<D00`35`LD0a/750<O1aP040<O1aP040<O2aP2m^;`0QH63028Q
8P@0000000@0O7Yk0<g7bP3Dcm80e<oB0P3Ecm800`3Dc]80dlgA0=;<d0080=;<c`@0dl_?1P3Cc<l8
0=C=c`030=G=c`3Fc]00e/o@0080elo@0P3Gd=070=SAd@030=SAdP3Id]80fM;B00@0f];B00/0fM;B
0=[BdP3Jd]80e/k>0;jh]`39a<<0gMSF0<S3`@2f/K00cLS60=kIe`060>3Jf0030>7Jf03QfmP0hM_H
00L0hM_H1@3Rg=P00`3Sg=P0hmgH0>?Mf0050>CMf@080>CNf@3TgMP0h]cG0=kGdP3Le]40clW409ZE
T@0c<S1n000000`0oooo000:0?ooo`T0000000D01PH606a/M@2h]/H0_kc>0;jlcP020;jkc@030;fk
c@2m^l/0_;_;00<0_;[;0P2m^//00`2l^//0_;[:0;bib@030;^ib@030;^hb@2k^<P0^[S80080^[O7
0`2j]/H00`2j]lH0^kK70;ZgaP040;ZfaPL0^kK60`2k]lH30;^ga@030;^gaP2l^<H0_;S60080_;S6
0`2l^LH00`2m^LL0_K[70;jja`020;jja`080;jia`2m^/H0_KW60;bha@2k]l@0_;O40;^fa02j]L87
0;Rd`0L0^;>o0P2h];l20;Ve_`D0^KBo0`2i]Kl60;Ve_P030;Ze_P2j][h0^[Jn0080^[Jn00<0^kNo
0;bh`02l^<000P2l^<00102l^;l0_KW00;jj`@2n^/420;fi`0030;fi_`2m^L00_[[000<0_[[000D0
`;_10<2k`P30^l80`;c30<2l`P020<6l`P030<6m``31_L80`Kg20080`[g300@0`[k30<:na032_/@0
`kk40`34_lD50<Foa@@0aL3500H0aL750<G0a@35`LD0aL750<K1a@36`LH60<O1aP030:fXZ`1OGEh0
3@d=00@0000000@0U92C0=?=d03Dc]80e<oB0P3Cc]420=?=d@80d/c@1`3Bc<l:0=?<c`030=C=d03D
cLl0dlg?0080e<g?00@0eLg?0=C=c`3DcLl0eLg?0`3Fcm00103Gcm00em3A0=O@d@3Hd=420=SAd@D0
f=7B1@3Id]840=[BdP080=WBd@3KeM@0c<O50>3Kf03Ed<h0c/W80=KAc`3Of]P30>3Jf@040>3Kf03Q
fmP0h=[H0>3Kf0L0hM_H0P3RfmP20>;Lf0050>;Lf@3Sg=T0hmcI0>?Lf@3SgMT0103TgMT20>CNf@08
0>GNf@3Me]40Y9nK089nO01hMG80IF5O03lm?00E51An000000`0oooo000:0?ooo`L0000000d00`<3
01TI6P1=CE<0Z:Nf0<2nc`2o_<h0_[_>0;fkc@2n^ld0_K_=0;fkc02l^l/0_K[;00@0_K[<00<0_;[;
0;bibP2k^LT00`2k^<T01@2j^<P0^[O80;Zgb02j]lP0^[O70080^[K60P2j]lH00`2j]lL0^kS70;Zg
a`040;ZfaPD0^kK61@2k]lH40;^ga@030;^gaP2l^<H0_;S600<0_;W600<0_KW70;fja`2m^/L00`2m
^/L00`2n^/L0_;W60;bga0030;^f``030;Ze`P2i]L40^KC10080^;C00P2h/l050;Rc_`030;Rd_`2h
/kl0^;Bo00<0^;Bo00<0^KBo0;Rd_`2h];l00P2i];l70;Ve_`<0^KFn102j][h0102j]kh0^kNo0;bh
`02m^<030;fi`@030;jj`@2n^/00_KW000@0_KW000@0_[W00;jj`02n^/00_k[00P30^l820<2l`P80
`Kc20P31_L<01032_L<0`[k40<:na032_/@20<>na@040<>oa@34_lD0a;o50<Boa@L0aKo51@35`<D0
0`35`LD0a/750<K1a@040<O1aP<0al;600<0Z:>W05MEEP092@T0100000000`1iMWP0blG90=?=d@03
0=?=d@@0d/c@00@0d/c?0=;;c`3Bbll0d/_?103Bc<l<0=?<c`060=C=c`3Ec]00e/k@0=G=c`3DcLl0
eLg?103Fcm020=O@d@030=OAd@3HdM40f=7A0080em7B103HdM820=WBdP@0f];B00X0fM;B0=WAd@3H
d]40gMOF0=7<bP3LemD0/Zj]0<6l^`3<alD0g]WG1P3Pf]P00`3PfmP0hM_H0>7Kf0070>7Kf080h]cH
0`3Rg=T00`3Sg=T0hmgI0>?Mf@050>CMf@030>?Le`2b[JT04a<C08<00000303oool000X0oooo1000
0000400820T092@W0410AP1BDeX0QXJC0;bjc032`M<0_kk?0;jlcP2n^lh0_K_=0;jkc@2m^ld0_K_<
0;bkb`2l^//30;bjc0040;fjc02l^//0^kW90;Zib@80^[S800<0^kS80;Zhb02j]lP00P2j]lP00`2j
]lL0^[K70;Zga`030;Zga`030;^ga`2j]/H0^[K600H0^[K60`2k]/H60;^gaP<0^kO50P2l^<H0102l
^LL0_;W60;biaP2m^LL50;fja`050;jja`2l^<H0^kO30;Zf`P2j]L800P2j]/80102i]L40^KC10;Vd
`02i]<090;Rd`0@0^;Bo0P2i];l:0;Ve_`030;Vf_`2j][l0^[Jo0080^[Jo00L0^[No0;^g_`2k]kl0
_;No0;bh`02m^L40_[W20080_[[200<0_KW00;bi`02m^L000`2l^Kl01@2m^L00_[[00;jj`02n^l00
`;_10080`;_20P30_<820<6l`P<0`Kg300@0`[k40<>na@33_/D0`kk50P33_lD40<Boa@D0aKo500<0
aL350<C0a@35`<D00P35`<D00`35`LD0a/760<K1aP040<O1aP@0al;600<0Yj>W05MEE`092@T01000
0000101GEEH0]k:e0=?>d@3Dc]420=?>d@050=?=d@3BcM40d/c@0=;<d03Bc<l00P3Bbll80=;<c`L0
dlc?0`3DcLl20=G>d080e<g?00<0eLk?0=K?d03Fcm000P3Fcm020=O@d@80f=7A1P3HdM820=SBdPH0
fM;B00L0e/o?0=cFe@3Of=P0fmKD0=C?cP2`[:/0f]GD0080gm[I0P3Pf]T20>3Jf0030>3Kf03QfmP0
hM_H00T0hM_H0P3Rg=P0103Rg=T0hmcI0>?Lf@3Sg=T20>?Mf@080>CMf@3KeM40_KRd0;2[Y`2ZYZ80
XijJ05eJF@071`N3000000`0oooo000:0?ooo`<0000000T0410B05=CFP2SXk80`<3B0<;3e@34a=H0
a<?E0<2od@2o_Ll00P2n_<h01P2n^lh0_[_=0;fkc@2m^l`0_;_;0;bjc0<0_K[<00@0_;W:0;^ibP2k
^LT0^[S91@2j^<P40;Zga`80^[K700<0^[O70;^ga`2k]lL02@2j]/H20;^faPL0^kO600@0^kO50;^h
a@2l^<H0_;S60`2l^LL00`2m^LL0_K[70;fja`030;fja`030;fia`2k^<D0^KG200P0^;C000@0^KC0
0;Rd`02h/l00^;C0302h];l00`2h]Kl0^KFo0;Ve_`070;Ve_`<0^KJo00H0^[Jo0;Zg_`2k]kl0^kNo
0;bh`02m^L420;jj``80_k[200<0_;W00;bh_`2l^;h00P2l^;h01@2l^;l0_KVo0;jj`02o^l40`;_2
0080_k_200H0_kc30;nl`P30_<80`Kc20<6m`P31_L<20<6ma0040<:na033_/D0`kk50<>na@80`[k4
1034_lD00`34`<D0aL350<G0a@040<G0a@@0aL7500@0aL760<K1aP36`LH0a/761037`LH01@37`/H0
aL3409RDU`1=Bdd020P800@0000000@0;2//06eZK02^Z:`0b/C80`3=al/01@3Abll0d/c@0=;<d03B
c<l0d/_?00T0d/c?1`3Cc<l20=C>d0030=G>d03DcM00e<g@0080e<g?00<0eLk@0=K?d03Fcm000P3F
cm020=O@d@80em7A00<0f=7A0=SAdP3HdM800P3HdM830=SBdP030=WBd`3Jd]<0f];C0080f];C00T0
f];B0=WCd`36`/40e]7@0<c8aP2i]K@0aL2o0=_Fe03Of]P0103Pf]P40>3Kf0P0hM_H0`3Rg=P30>;L
f@050>?Lf@3SgMT0hmgI0>3IeP1mNWP0R@00000<0?ooo`002P3oool20000000B01dM7`1cLgh0^K[:
0<C4eP34aMH0aLCF0<G3e@34`]@0`;k@0;nmc`2n_Lh0_[c>0;jkcP2n^ld0_K_=0;fkc02l^l`0_;[<
0P2m^/`00`2l^//0^kW:0;Zhb@030;Zhb@<0^[S800<0^[O80;Vga`2i]lL00`2j]lL>0;ZfaP030;^f
aP2k]lH0^kO600D0^kO60P2k^<H20;bhaP<0_;W71`2m^/L0102l^LD0^[K30;Ve`P2i]L420;Rd`003
0;Re`02i]L00^KG00080^KG01`2h]<000`2h];l0^;Fo0;Rd_`040;Ve`0P0^KFo0P2i][l40;Zf_`06
0;Zg_`2k]kl0_;S00;bh`02m^L00_;S10P2m^L420;fi`0030;bh`02l^;l0_;Ro00<0_;Vo00<0_KW0
0;jj`02o^l800P2o^l820;nl``050;nl`P30_<80`Kg20<6m`P31_L<00P31_L@01032_/@0`[k50<:n
a@33_/D20<>oa@<0a;o60`34`<H60<C0a@050<G0a@35`LD0aL750<G1aP36`LL00`37`LL40<O2aP04
0;Ze^@1THF<0;Rd^00D51@@0000000@03Pd=02h/;@2NVYd0dL_?0P3:a<P00`2m^;/0cLO:0=3;c`02
0=;<d0T0d/c?1@3Cc<l01P3CcLl0e<g@0=C>d@3Ecm40eLk@0=C>d0<0e<g@00<0e<k?0=G>d03Fcm40
0P3Fcm400`3Fd=40em3A0=O@d@050=OAd@050=OAdP3HdM80f=7B0=SAdP3Hd]800P3Id]<40=WBdP03
0=_Ee@2f/K40f]GD00<0gm[I0P3Of]P30>3Jf080h=_H00H0f]CB0<o9a`3;aL@0blG40<c7a@3Ke]<6
0>7Kf0030>;Lf03Rg=T0h]gJ0080h]cJ0P3SgMT00`3Pf]H0XijK03Dd<P29000000`0oooo000:0?oo
o`0D07YkQP2KW:X0][K60<?3e@35aMH0a<GG0<C3e@32`M<0`l7C0<;0dP30_/l0_kg?0;jmcP2n_<h0
_K_=0;jkc@2m^ld0_K_<0;bkc02l^/`30;bjb`030;Zib@2j^<T0^[S90080^[S90`2j^<P30;Vga`<0
^[O700<0^KK60;ZfaP2j]/H0302j]/H60;^gaP80^kS60`2l^<H30;bia`H0_K[700D0_[_80;fjaP2k
]l@0^KK30;Ve`@090;Rd`080^;Bo00@0^KBo0;Ve_`2i]Kl0^KFo102h]Kl60;Ve_`80^KJo00<0^KFo
0;Vf_`2i][l00P2i][l20;Zf_`070;Zg`02k]l00^kS00;fh`@2m^<80_KW10;bh`0040;bi`0<0_;Ro
00@0_;Vo0;fi`02m^L00_K[00`2o^l801@2o_<80_kc30;nl``30_<<0`;g300<0`Kg300<0`Kg40<6n
a032_/@00`32_/D01033_lD0a;o60<Boa@34_lD60<C0aP@0a<350`35`LD00`35`LH0a/760<K1aP03
0<K1aP80al;600d0a/750:RPY00]:b`07A`M01TI6@0G5aL05A@E00d=3@0410@0000001<C4`2ETI<0
d<[>0080b/C800D0_[Rl0<G0``3?bLd0dlcA0=;<d@070=;<d0<0d/c?0P3Cc<l20=?=c`050=?=d03D
c]40e]7C0=G?d@3Dc]000`3DcM020=C>d0030=K?d03Fcm40e/oA0080e]3A0P3Gd=450=SAd@030=SA
dP3Hd]80f=;B0080f=;B0P3Id]<01`3Jd]<0fM;C0=WBd`3Id]80d<_;0<K2`@3AcL`0103Of]T20>3K
f@@0h=[H00H0e]7?0<k9a`3?b/P0cl[80<2k^P3=alD20>7Kf@80hMcI0P3QfmT30>;Lf@80h]gI00@0
hmgI0>;Lf02g/Zl05ADDRP00000<0?ooo`002P3oool04P31`M@0a<GG0<C5e`34`mD0`l?E0<C4e@31
`M<0`L3B0<?2e030_]00`;k?0;nnc`2n_Lh0_[c>0;fkcP2n^ld0_K_=0;bkc080_;[<0P2l^//0202k
^//0^[W90;Zhb@2j^<T0^[W90;Zhb@2j^<P0^[O80`2i]lL00`2i]/L0^[K70;Zfa`060;Zfa`H0^[K6
102k]/H60;^gaP030;bhaP2l^LL0_;S700D0_;W7102m^/P20;jkb0060;jkb@2m^/P0_;S60;Zf`P2i
]L80^;G1102h]L0;0;Ve`0030;Re`02i]L00^KG000<0^KG01P2i]/001`2i]Kl0^KJo0;Zf`02j]/00
^[No0;Zg`02k^<400P2k^<001@2n^/80_k[30;fi`@2l^<00^kRo00@0_;Ro0P2l^Kl00`2m^/40_[[1
0;nk`P020;nk`P040;nk``2o_<<0_kc30;nl``80`;c300<0`;g30<6m``31_/<00P31_/@00`32_/@0
`ko50<:na@020<:na@030<?0aP34`<H0a;o600L0a<360P34`LH60<G1aP80a/771@37`/L03@36`LD0
]ZZ]0:VRY`2k][/0aL750<C0a030_<00[j^_06UWJ@0410@05Q@F09^GVP3Abm000P3Bc=001@3@b/h0
dL_?0=;<d03CcM40d/gA00@0d/c@2@3Bc<l01@3Cc<l0dlg@0=G?d@3Gd]@0eLoB00<0dlg@00<0dlg?
0=C>d03Ec]000P3Fcm430=K@d@80em3A1@3GdM430=OAdP040=SAdP3Hd]80f=;B0=SBdP<0fM;C00<0
f=;B0=SAd@3Of]T0103Of]T00`3OfmT0h=_I0>3Kf@060>3Kf@80hM_I00<0f=?A0<o9b03QfmT01@3Q
g=T00`3Rg=T0h]gI0>;MfP020>;MfP040=kHe02`[:T0EUAB00H61XX00000303oool000X0oooo0P34
aML02P34a=H0aLCF0<?3e@31`=80_;g:0;flc@2m^ld0`;k?0<2nd02n_Ll20;jlcP040;fkcP2m^ld0
_;_<0;bjc080_;[;0P2k^//00`2j^L/0^[W90;Zhb@020;Zib@040;Zhb@2j]lP0^KO80;Vfa`80^KO7
0`2i]/L90;Zfa`D0^[K600<0^kK60;ZfaP2k]lH0102k]lH00`2k^<H0^kS70;bia`060;bia`@0_K[8
00L0_[_80;jkb@2n^lT0_K[80;bhaP2j]l@0^;G20080^;G100<0^;G00;Rd`02h]<00102h]<000`2i
]<00^KG00;Ve`0090;Ve`0H0^KK00`2i][l0102j][l0^[No0;Zg`02j]l030;^h`080_KW200@0_;W0
0;^h`02k^;l0^kRo0`2l^<00102l^Kl0_;W00;jj`@2o^l820;nk``060;nk`P2o_<<0_kc30;nl``30
_<<0`;g30P31_L<01P31_/@0`[k50<:na@33_/H0`l360<BoaP80`kk600<0a;k60<BoaP33_lH02P34
`<H20<C1aP80a<7500<0aL750<G1aP36`LL00P36`/L02037`/L0a/;70<K2a`37`lL0a[o30<:e^@3@
b/l0dlkD0`3Dcm@01P3Cc]<0/Jfa00/:2`0?3Pl0MW=e0;Nb]P80^[Fh00L0_kZn0<g7b`3Bc=00dlgA
0=;=d03Bc=40dLc@00@0d/c@00@0d/g@0=?=d03Bc=00d/c@0P3BcM001P3CcM00dlk@0=G?d@3Fd=<0
em7D0=G?d@@0e<k@0P3Ecm450=K?d@80em3A1@3GdM40103Hd]80f=;C0=SBd`3Hd]<30=SBdP80fM;C
0P3Idm<00`3Ecll0gm[I0=oJf@050=oJf@030=oKf@3PfmT0h=_I00@0h=_I0P3QfmT00`3MemD0fM?A
0>7Kf@020>7Kf@<0hMcI00<0h]cI0>;Mf@3Rg=X00P3Nf=D00`2VXj009bHV0000002;000000`0oooo
000:0?ooo`030;fmc`2n_]00`<3B0080_[g?00@0`<3A0<71d@31`=80`<3B0P2o_Ll01@2m_<h0_K_>
0;fkcP2m^ld0_;_<0080_;[<0P2k^//20;^ib`030;ZibP2j^LT0^[W90080^[W900@0^[S90;Zgb02i
]lP0^KK70P2i]lL30;Vfa`/0^[K71@2j]/H0102j]lH0^kO60;^gaP2k]lH30;^haPL0_;W70`2m^/P0
0`2m^lP0_[_90;jkb@020;jkb@060;fja`2l^<D0^[O40;Zf``2i]/80^KG21@2i]L440;Ve`080^KK0
0P2j]/080;Vf`0030;Zf`02j]l00^[O00080^[O00P2j]kl20;Zg`0@0^kS000D0_;W10;fi`P2m^L40
_;W00;bi`@050;fi`@030;jj`@2n^l80_k_300<0_k_30`2o_<<01@30_<<0`;g30<6m``31_L<0`Kk5
0080`[k600<0`ko60<Boa`34_lH01034_lH20<?0aPP0a<361@34`LH00`35`LD0aL760<K1a`020<K1
a`80a/;700H0al;70<W5bP3;aLX0bl760=;=d@3Ccm<30=C?d`060=C?e03BcM40]K6e0:6LX02OVih0
TXjA0P29QHP0202WXZH0_[Vm0<c7b`3Bc=00d<[>0=;<d03?bLd0dL_?0`3Bc=000`3BcM00dlgA0=;=
d0030=;=d0030=?>d@3Ecm80e]3C0080e]7D00<0eM3B0=G?d@3Ecm401P3Ecm420=K?d@030=K@d@3G
dM80em7B0080em7B00<0f=7B0=OAdP3GdM800P3GdM830=OBdP80f=;B0P3Id]<0103Idm<0f]?C0=gF
eP3Of]X80=oJf@030>3Jf@3PfmT0h=_I00D0h=_I0`3QfmT40>7Lf@80h]cI00D0hM_H0:fXYP2]Z:H0
@D0n00`<302<000000`0oooo000:0?ooo`0;0;nnd033`mD0`l?E0<;2e031`=<0`/3C0<;1e02o_Ll0
`;k@0;jmc`2n_<l00`2m^lh01@2m^ld0_;_<0;bjc02l^/`0^k[<00<0^k[;00<0^kW;0;ZibP2j^<T0
0`2j^<T00`2j]lP0^KO80;Vga`020;Vga`@0^KK7302j]/L20;ZfaP80^[O60P2k]lH30;^haP030;^h
a`2l^LL0_;W700D0_;W70`2m^/P00`2m^lP0_K_90;fkb@020;fkb@050;fjb02l^LH0_;S50;^ga02j
]l@00P2i]/800`2i]L80^KG10;Ve`@060;Ve`@@0^KK100<0^[K10;Zf`02j]/000P2i]/000`2j]l00
^[O10;Zg`@030;Zg`@80^[O01@2j]kl20;^g_`030;^h`02l^L40_;W10080_KW100D0_K[20;jj`P2n
^/80_[[30;nj``020;nk``<0_k_200@0_k_30;nl``2o_<<0_kc30P30_L<20<6m``030<6na@32_lH0
`[o60080`ko600H0`ko50<:oa@32_lD0`[o50<>oa@34_lH60<C0aPH0a<761035`LH00`35`/H0a/;7
0<K2a`020<K2a`030<O3b03;a/`0dlkD00D0dlkC0`3Ccm<0103Dcm<0dloD0=?>d`2k]k/206UWJ00:
09FAU033_/80blG90<k8c03:aLP0dL_?0<o:cP3Ac=00blK:0=7;c`80d/gA0P3CcM430=?=d0060=C>
d@3Ecm40e]3B0=OAd`3GdM@0eLoB203Ecm400`3Fcm40e]3A0=K@d@050=OAdP@0em7A103Gd]800`3H
d]80fM?C0=WCd`020=WCd`030=;<c03Ac<`0fmOF00P0gm[I103Pf]T30>3Kf@<0hM_I0P3Qg=T20>7L
fP030>;MfP3Qg=T0b<C10080GEYISP00000<0?ooo`002P3oool0302i^//0][G70;Fda@2h]lP0_[g@
0<;1d`32`M@0`;oA0<2nd@2n_Ll0_[c?0;flcP80_K_>00@0_;_=0;bkc02l^/`0_;[<1@2k^//00`2j
^LX0^[S90;Vhb@020;Zhb@030;Zgb02i]lP0^KO70080^KO7202i]/L40;Zfa`H0^[K600<0^[O60;^g
a`2k^<L0102k^<H00`2k^<L0_;W80;bia`050;bia`<0_K[800<0_K_80;fkb@2m^lT00`2m^lT01P2m
^/P0_;W60;^ha02j]/<0^[K20;Vf`P80^KG2102i]/80102i]/40^KK20;Zf`P2j]/850;Zf`@030;Zg
`02j]/00^[O000H0^[O10P2k]l020;Zg`080^kO00`2k^<001`2l^L00_;W10;bi`@2l^L40_K[10;fj
`P2n^/800P2n^/<00`2n^l<0_k_30;nk``040;nk``040;nl``2o_<@0_kc30;nm``80`;g300<0`Kg4
0<6na@32_lH00P32_lH02@33_lH0`[o50<6na@31_/D0`[k50<:oa@34_lH0a<360<?0aP030<C0aPL0
a<761@35`LH01P35`/H0a/;70<K2a`36`/L0al?70<_7c0@0dloD00<0e<oD0=C?d`3Ccm<01@3Dcm@0
3`3Bc]80VYJI09ZFV@1dLG@0O7Qk08Z6R@2GTiH0Z:>W0;Vc]`32_L40clW=0<2k_P33_l40d/g@0=C>
dP050=C?d@030=G?d@3Fd=80e]3C0080e]3B00@0eLoA0=C>d@3Ec]40eLkA1@3Ecm40103Fcm40e]3A
0=K@d@3Gd=860=OAdP80em7A00<0em7B0=SBdP3Hd]<00`3Hd]<0103Id]<0fM?C0=[De03MemL;0=oJ
f@<0h=[I00<0gm[H0=kIe`3PfmT0103QfmT01P3Qg=T0hMcJ0>7Lf@3Rg=T0gMSE07IcLP807ahNSP00
000<0?ooo`002P3oool0102k_<d0_koA0;bkcP2o_]030<;1e0040<70dP2o_]00_[g?0;flcP<0_K_>
00D0_K_=0;bkc@2l^l`0_;[<0;^jc0040;^jb`050;ZibP2j^<T0^KS90;Vhb@2j^<T01@2i]lP30;Vf
a`060;Zgb02k^<T0_;W:0;bibP2l^LT0^kO81@2j]/L30;ZfaP030;ZgaP2j]lL0^kO700<0^kS70P2k
^<H00`2k^<L0_;W80;bib0020;bib0<0_;W7102m^/P50;fkb@060;fjb02m^/L0_;W50;^ha02j]l<0
^[K3102i]/860;Zf`PD0^[O200<0^[O10;Zf`@2j]l401P2j]l400`2k]l40^kS00;^g`0040;^h`003
0;^h`@2k^<00_;W100<0_;W10`2m^/820;jk``80_k_300@0_[_30;nk``2o^l<0_k_3102o_<<01@30
_L<0`;g40<2ma031_/@0`[o500@0`[o600<0`[o50<6na@31_/D00P32_lD01034_lH0a<360<C0aP33
`<H40<C0aPT0a<7600<0aL760<G2aP35`/H00P36`/L00`37`lP0blO<0=??e@030=C@e@<0e=3D00<0
e<oD0=C@e03Dd=@00`3Dcm@20=??d`0=0<c8c02k]kX0W9VM069QHP1lN7/0`Kg00<_6bP3Abll0_[Vm
09REU`2f/[@0dLg@0=G?dP020=G@d`80e]3C00@0eM3C0=K@d`3FdM<0eM3B0`3Dc]400`3Ec]40eLoA
0=G?d@040=G?d@030=G@d@3Fd=40e]3A00L0em7B00<0em;B0=SBdP3Gd]80103Gd]820=SBdP80fM?C
00<0g=KF0=oJf@3Of]T02@3Of]T30>3Jf@030=cGeP3>b/P0hM_I00D0hMcI0P3Qg=X00`3QgMX0b<?1
02d/;02@000000`0oooo000:0?ooo`040;^lc@2o_m40_;_>0;nnd0<0`/7D00@0`L3B0;nnd02n_Ll0
_Kc>0`2m^lh01@2m^ld0_;_=0;bkc02l^/`0^k[<00@0^k[;00D0^[W:0;Zhb@2i^<T0^KS90;Zhb@05
0;Vgb0<0^KK700H0^[O80;^hb@2l^LX0_;W:0;bib@2k]lP50;Zfa`<0^[K600<0^[O60;Zga`2k]lL0
0`2k^<L20;^haP030;^ha`2l^LP0_;W80080_;W80`2l^LL40;fjb0D0_K_900H0_K[80;fja`2l^LD0
^kS40;Zg``2j]/<40;Vf`PH0^[K21@2j]l800`2j]l40^[K10;Zg`@060;Zg`@030;^g`@2k^<00^kO0
00@0^kS000<0^kS10;^h`02l^L400`2l^L430;fj`P80_[_30P2o^l<0102n^l<0_k_30;nk``2o^l<4
0;nl``050<2m``30_L@0`;g40<6na032_lD01032_lH00`32_lD0`Kk50<6na@020<:oa@040<BoaP34
`<H0a<360<?0aP@0a<362@34`LH00`35`LH0aL;60<G2aP020<K2a`030<O3b03;al`0dloE00<0e=3E
0`3Dd=@00`3Dcm@0e=3D0=C@e0030=C?e080dloC00d0c<S<0;^g^P2LVId0HV5R07ahN`31_L00blK:
0=7;c`2n^Kd0V9FG0;Jb]03AcM00eLoB0080eM3C0P3Fd=<0103Ed=<0e]3C0=KAd`3Ed=830=C>d@03
0=G>d@3Ecm40eLoA00@0eLoA00<0eM3A0=K@d@3Fd=401`3GdM800`3Gd]80f=;B0=OBdP040=OBdP80
f=;B0P3Idm<00`3Le]H0gm[I0=oJf@090=oJf@<0h=[I00<0g=OF0<k:b03QfmT01@3Qg=T20>7LfP03
0>7MfP38`l40;B`/09000000303oool000X0oooo00/0^;O90;jmd02i^<T0_[k?0<70d`32`M@0`/3C
0<70dP2o_]00_[g?0;flc`040;fkcP030;bkc@2l^/`0_;[<00@0^k[<00D0^k[;0;ZibP2j^<T0^KS9
0;Vgb@060;Vgb080^KK700P0^[O80;bjbP2o_<d0`;k>0<2mc@2o_L`0_K[:0;Zgb0H0^[K700<0^[O6
0;Zga`2j]lL01`2k^<L60;bib0030;bia`2m^/P0_K[80080_K[80`2m^lT30;jkb@040;fjb02n^/P0
_;W60;^ha080^[O31`2j]l820;^g`PD0^[O200<0^kO20;^g`@2k]l40202j]l420;Zh`@<0^kS100<0
_;W20;fj``2m^L800`2l^L401`2m^/40_[[30;jka02n^l@0_[_30;nk``2n^l<00P2n^l800`2o^l<0
_kc30<2ma0040<2ma0030<6ma031_/@0`[k500<0`[o61P32_lD00`33_lH0a<360<C0aP020<C0aP03
0<C0a`34`LL0a<7600P0a<761@35`/H20<K2a`040<O3b038`lL0e=3E0=C@e@@0e=7F0P3Ed=D20=C?
e0D0e=3D00h0eM3E0=G@e03=b<`0Ph2304]9BP29QXP0XIfP0;F`/`2ETI<0EE9D05MFE`2i]KP0e<oB
0=G@d`@0eM3B0P3FdM<00`3Ed=<0eLoB0=G?dP020=G?dP80eLoA0`3Ecm801@3Ed=40e]3A0=K@d@3F
d=40e]3B00P0em7B0P3Gd]400`3Gd]80em;C0=SBd`020=SBd`030=SCd`3Idm<0g=KF00D0gm[J1@3O
f]T01P3Of]X0h=_I0>3Kf@3PfmT0g]WG0<O2`@D0hMcI0`3Qg=X00`3RgM/0WIVH01LF5P2@000000`0
oooo000:0?ooo`040;nnd@2m_<l0_[k?0<70d`80`/7D00d0`L3B0<30d@2o_]00_kk@0;jmc`2n_<l0
_Kc?0;flcP2m_<d0_;_=0;bkc02l^/`0^k[<00<0^k[;00@0^[W;0;ZibP2j^<T0^KS9202i]lP00`2i
]/L0_;W:0<2ncP020<?2dP040<?2d@31`<l0_[_<0;Zgb0D0^[K70P2j]lL30;Zha`H0^kS71`2l^LP0
102l^/P0_K[80;fjb02m^/P40;fkb@<0_[_900D0_k_90;jjb02k^LD0^[O30;Zf``0:0;Zf`P@0^[O2
102k]l840;Zg`@80^[S11@2k^<40202l^L80_;[30;fj``2m^/<0_;[20;bi`@2l^L80_K[20`2n^l@0
0`2n^l<0_k_30;jk``020;jk`P030;nl``30_L@0`;g400@0`;g400<0`Kk50<6naP32_/H00P32_/H0
1032_lH0`Ko50<6na@32_lD20<?0aP030<>oaP34_lH0a;o600D0a<360P34`LL01034`LH0a<360<C0
aP34`<H20<C1aP030<C2aP35`/H0aL;600<0aL;60P36`/L01037`/L0a<710=C@eP3Dd=H40=CAeP06
0=C@e@3Ed=D0e=3E0=C@e@3Dd=@0e<oD0`3Dd=@03@3Dd=D0eM3E0=G@e034`<<0U9:D06e/K@18ATL0
F5IG0491@P0J6AX0410@07mmO`35`<<00`3Ed=<01P3Fd=<0eM3C0=G@d`3EdM<0e]7D0=G@d`80e]3C
00<0e]3B0=G@dP3Ecm800P3Ecm820=G@dP050=G@d@3Fd=40e]3A0=K@d@3Fd=800`3GdM870=OBdP03
0=OBd`3Gd]80em;B0080f=;B00@0fmGE0=cHe`3Nf]T0g][I2@3Of]T30>3KfP050=kIf03Hdm80h=_I
0>3Kf@3QfmT00P3Qg=T01P3Qg=X0gMWF0>3Lf@30_;X0GUaK00`<34L0000000P09RDS06QVH01oOGH0
Ogef06MUGP1@CTT0?Sdj01DE54400000303oool000X0oooo00@0`<3B0;fmc`31`=<0`/7D0P31`=<0
3P30`=80`;oA0;nnd@2o_]40_kk@0;jmd02n_Ll0_Kc?0;flcP2l_<d0_;_=0;bjc02k^/`0^k[;0P2j
^//0102j^L/0^[W:0;ZhbP2i^<T70;Vgb0050;Zgb02i]/L0_;W:0;nncP32`M400P33`M400`31`=00
_[c<0;^hb0030;Zfa`@0^[O7102j^<L20;^ha`<0^kW71P2l^LP30;bjb0030;fjb02m^lT0_K_900@0
_K_900L0_[_90;jlb@2o_<T0_[_80;bjaP2j]l@0^[O300P0^[O20`2k]l<20;^g`PH0^kS200@0^[O1
0;Zh`@2j^<40^[S11@2k^<401@2l^L80_;W30;fj``2m^/@0_K[300<0_K[200L0_K_30;fka02m^l@0
_[_40;jla02o^l<0_[_30080_[_200<0_kc30<2ma030_L@01030_L@01P31_/D0`Kk60<6naP32_/H0
`[o60<:oa@80`Ko500@0`[o50<?0aP33`<H0`ko60P34_lH40<C0aP040<?0aP34`LH0a<760<C1aP80
a<361034`LH30<C2aP80aL;60P36`/L00`37a<P0b/O:0=C@eP040=CAeP050=C@e@3Dcm@0e=3E0=C@
e@3Dd=@00P3Dcm@40=C@e0050=C@e@3Ed=D0eM3D0=3<d02IUIP01@0000000`13@D<0Shb?0<c8bP04
0=G@d`040=GAe03FdM@0e]7D0=KAe080em7D00@0e]3C0=G?dP3Ecm80eLoB103Ed=820=G@d@80e]3A
00<0e]7B0=OAdP3GdM800`3GdM840=OBdP<0em;C00<0f=?C0=[De@3Mf=P00`3Nf]X0103NfMT0g][I
0=oJf@3Of]T20=kJf@<0gm[I00<0h=[I0>3KfP3PfmX00P3PfmX20>3Kf@<0hMcI00H0hMcJ0=oJf03I
eM80MWAb01dM700410@O0000000801HF500/:bT0;2/Y034`;P0];BX09B@R024Q7`0<30`400000003
024P7`1@CT`0;Rd/01T0000000P0G5YE0<c9_P3Og<l0gmc?0<o<`030_K40UY>:03<b;d400000303o
ool000X0oooo00P0`<3D0<71e031`M@0`/7D0<71d`30`=<0`<3B0<2od@@0_kkA00H0_[g@0;flc`2m
_<h0_;_=0;^jc02l^/d20;^jc080^[W<00@0^[W;0;ZibP2j^<X0^KS91@2i]lP01P2i]/P0^KO80;Zg
b02i]/P0_;[;0;nnc`80`/7A00@0`l7@0<;0c`2n_</0^kS80P2j]/L50;Zga`@0^[S700D0^kS70;^i
a`2k^LP0^kW70;^ib0050;bib0<0_;[800<0_K[90;fkb@2m^lT01@2m^lT0202n^lT0_[c90;nlb@2o
_<T0_[_80;bia@2j]l@0^KK21@2j]/801@2j]l80^[O30;^ha02l^<D0_;S300H0^kS31P2k^<830;bi
``030;fi``2m^/<0_K[300<0_K[40P2n^l@20;jk``<0_[_40P2n_<@01@2o_<@0_[_30;fk`P2n^l<0
_kc30080`;g400D0`;k40<2ma030_L@0`;g40<6na@020<:oaP040<6oaP31_lD0`Ko50<:oa@80`[o6
1P33`<H01034`<L0a<360<C0aP34`<H20<C1a`80a<760P35`LH20<C1aP<0a<;60P35`/H01@35`/L0
a/;70<K3b039a//0dLkC00H0e=7F103Dd=D70=C@e080eM3E00`0e]7E0<[6bP1cL780?cho0000000<
30`06ATI051>C`2ZZ:X0e=3D0=KAe@3FdM@20=G@d`80eM7C0P3FdM<00`3FdM@0em7D0=KAd`070=G@
dP@0e]3B0P3FdM840=OAdPH0em;B00<0em?C0=SCd`3JeMD00`3Nf]X0103NfMT0g][I0=kJf@3Of]T3
0=kJf@@0gm[I00<0h=[I0>3Kf@3PfmT00P3PfmX20>3Lf@80hMcI00@0hMcJ0=kJe`2]ZJL0>CPg8@00
0000201BDDd0Y::I0:BRV@2SXIP0YjFL09fKTP2>SH@0=SDb100000000`1=BdT0_kVd06i[J00H0000
000300`<2`25Pg`0i>7D00@0j>CF00D0emC70:2NU01LFeD0B4M303<b;`0200d=33`00000303oool0
00X0oooo00P0`L7D0<30e030_m<0`;oB0<71d`30`=<0`<3B0<2od@<0_kkA00L0_kk@0;jlc`2m_<l0
_Kc>0;blc@2l^ld0_;[<0080^k[<0P2j^L/0102i^L/0^[W:0;ZhbP2i^<T40;Vgb0D0^KK800T0_;[:
0;nncP32`M40`/3A0<70d030_ll0_K_;0;^hb02j]/L01P2j]lL50;Zha`030;^ia`2k^LP0^kW80080
^kW80`2l^LP0102l^/P0_;[90;fjb@2m^/T90;fkb@<0_[c900D0_kc90;fja`2k^<@0^KO30;Vf`P04
0;Zf`P060;Zf``2k]l<0_;W50;jka`2l^LD0^kS41P2k^<<40;^h`P050;bi`P2l^L<0_;W30;bi``2m
^L@01@2m^/@01P2n^l@0_kc40;nla02n^l@0_K_40;jka0<0_[c400H0_kc40;jk``2n^l<0_[_30;nl
``30_L@20<2na@<0`;g400H0`Kk50<:oa`32_lH0`Ko50<6na@31_lD30<:oaP@0`/360`33`<H20<C0
a`80a<3600D0a<770<C1aP34`LH0a<760<G1aP020<C1aP<0a<;600P0aL;60<G2a`35`lL0al?90<S5
b@3=b/l0d/oD0=CAeP80e=7G0P3DdMH00`3Dd=H0e=3E0=C@e@020=C@eP80e=3E1P3Dd=@03P3Ed=D0
eM7E0=GAe@3AcM40YZ:V00<30`0i=cP0LFma069PHP1^K6h0[:V/0=7=d03Gd]D0e]7D103EdM<01P3F
dM<0eM7C0=KAe03FdM<0eM3C0=G@dP<0eLoB0P3Ed=850=K@dP040=KAd@3GdM80em7B0=OAdPL0em;B
0P3Gd]<0103JeMD0g][J0=kJfP3NfMT80=kJf@@0gm[I0P3Pf]T00`3PfmT0h=_J0>3KfP040>7LfP03
0<o;b01<BTX04Q8A01d0000000h03`h>04M7@`1SHUd0L7=T0;Zi[P3Xi]P0g=[=0=OEb03Xi]P0gmc?
0<2n/`17AT80000001hN6`80GUaH00D0PWml09F@S@1eLVh0?cdk00l>3P0F0000000302DT8P2b[ZH0
i^?F00<0inCF00H0j>CF0>OTeP3Sgm80b<Jj0;VfZP22P7P202<R83`00000303oool000X0oooo00L0
_[kA0;blc`2l^ld0_;_=0<70d`30`=80_koB00@0_kkA00T0_[k@0;flc`2l^lh0_;_>0;bkc@2k^ld0
^k[=0;^jc02j^/`00P2j^//01P2i^L/0^KW:0;VhbP2i]lT0^;O90;Rgb0@0^KO80140^kS:0;bjb`2m
^//0_[g>0<2od032`=40`L3@0<70c`30_/h0_[c<0;fkb`2l^/X0_;W:0;^ib@2k^<T0^kS80;Zhb007
0;Zha`D0^kW80P2l^LP00`2l^/P0_;[90;bjb@020;fkb@@0_K_:0`2m^lT50;jlb@030;jkb02l^LH0
^kS400<0^kS40P2k^<<01`2j]l@0^kS40;fia@2o^lP0_K[70;biaP2k^L@00P2l^<@30;bia0@0_;W3
0`2l^L@50;fja0070;fka02m^lD0_K_50;jla@2n_<@0_[_40;fka0020;jla@80_[c40P2o_<@20;jl
``030<2ma030_/D0`;k50080`;k50P30_/@00`31_/D0`Ko60<6oaP020<6oa@040<6oaP32_lH0`[o6
0<:oaP80`l371@33`<H50<C0aPH0a<761034`/H01035`/L0aL?70<S5bP3=bLl30=CAe`<0e=7F1@3D
d=D0103EdMD0e=3E0=C@e@3Dd=D50=C@e00?0=G@e@3EdMD0eM7E0=KBe@3;al/01PH606=QHP36`/D0
PGn002l_;`1hMWP0blO;0=OCeP3Fd]@0e]7D00D0e]7C0P3FdM@0103EdM<0eM3B0=G@dP3Ecm860=G@
dP<0eM3A103FdM820=OAdP@0em;B00<0em?C0=SCd`3Je]H01P3Nf]X50=kJf@<0gm[I0P3Pf]T0103P
fmT0h=_J0>3KfP3PfmX30>7LfP030>7MfP33`;d04A4A01h0000000h0<2l]0;Rf[@3Lf/h0g=g:0>OV
f@3XimX0inKH0>SWf@3Yj=X0j>KH0<[8_00b<Rh00000065PF`80b<>m00D0cLS206i[J02IUY40U96<
02@S8P0<0000000<01TI600k>SL092@R00<30`0N7Q`0@3ll0450?@1=C4P0Cde905iME`2RWiH0g=W<
1@3Xi=L01@3XiMH0inCF0=[GbP3Og<h0`l2d0080OG]c00<0>SXf00X:2@000000>@00000<0?ooo`00
2P3oool01`2k^ld0^;S:0;Nfb02h]lT0`L3C0<30dP2o_m400P2o_]40102o_]80_kkA0;jnd02n_<l2
0;flc`050;blcP2l_<d0_;_>0;bkc@2j^//00P2j^L/20;VhbP<0^;O900/0^;O80;Vgb02i]lP0^KO8
0;ZibP2n_<d0`;k?0<2od031`]<0`/;B0<;0d@020<70d0090<70c`30_lh0_kg=0;nmc@2n_<`0_K_;
0;bjb`2k^LP0^[S800L0^[S71@2k^LP20;bib080_;[900@0_;_90;fkbP2m^lX0_Kc:1@2m^lX00`2n
_<X0_[c90;jlb@030;nlb@0?0;nlb02n^lP0_K_70;fka`2m^/L0_;W60;^ha@2k^<@0_;W40;bha@2m
^/H0_kc80<2mb@2m^/H0_;[500@0_;W40P2m^L@00`2l^L@0_K[40;fja0020;fka@<0_K[51P2m^lD0
1P2n^lD0_K_50;fka@2m^l@0_Kc50;jla@80_[c40`2o_L@20<2ma@030<2naP30_/D0`;k500<0`;k5
0P31_/H20<6oaP@0`[o600<0`/360<;0a`32`<L00P33`<L20<?0aP030<?0a`34`<H0a<360080a<36
1@34`LH01@34`LL0a<;70<C1aP34`/H0a<;70080aL;700<0a/?80<O4bP3;a/`00P3CdML00`3Cd=H0
e=7F0=CAeP020=CAeP040=C@eP3Cd=D0e=3E0=C@e@80eM7E103Dd=D40=C@e00>0=C@e@3EdMD0eM7E
0=;>dP1PGV00JVQZ07YgNP1:B4T03`l?04]9B`2VXjH0dLc?0=KBe@3FdMD20=G@d`<0eM7C00@0eM7D
0=KAe03FdM@0eM3C2@3Ed=820=G@d@D0e]7B00<0e];B0=OBdP3Gd]800P3Gd]801@3Gd]<0em?C0=[E
e@3NfMX0g][J00T0g][I00H0gm[I0=oJfP3Of]X0h=[J0>3KfP3PfmT40>3KfP<0hMcJ00<0`[nm014A
4@000000600000002@0M71/0?Sdj055@C01gMW00RXV10:FSVP3Ng=40jNOJ0>SWfP020>SUf`080>ST
f`3Xi=`0j>?K0>STf`3Pg=<0]k>/0;ji/`3Bc/L20>?Nf0090>COf@30_;L0_[Vd0<W4_P36`K/0]k>]
0:ZWX@1bKf`061PG00P0000000`0ADA00:2MU@1SHUd020P8059AC@2^Zj80/:jU0;Zh[P2f]:X0d<g2
0>GRe@3Wi=L60>STe`040>OTe`3Uh]@0h]oA0>?QdP80e]C600<0THn601`K6@000000>@00000<0?oo
o`002P3oool01@2i^/`0^KS;0;Jeb02i^<X0^KS;00<0_koA00D0_kkA0;nndP2o_m80_koA0;nnd002
0;jmd0050;fmd02n_Ll0_[g?0;flcP2j^/`00P2i^LX0102i^<X0^KO90;Rgb@2h]lT30;Rgb0040;Vg
b02i]lT0_Kc=0<;1dP80`l?D00D0a<GF0<G5e@33`]80`/;B0<;1d@030<70d0060<30c`2o_/h0_Kc<
0;bkbP2k^LT0^[S81`2j^<L70;^ib0060;bjb@2l^lT0_;_90;flbP2n_<X0_Kc:102m^lX40;jlbP03
0;jlb@2o_<T0_kc90080_kc90P2o_LX00`2n_<T0_K[70;bia@030;^ha@060;fjaP30_LT0`;g:0;jk
a`2l^LD0_;S41P2l^L@20;bja@030;fja@2m^lD0_K[500<0_;[500<0_;_50;fka@2m^lD01P2m^lD0
102m^l@0_Kc40;fla02n_<@20;nla0030;nma@30_LD0`;k600<0`;k61@30_/D00`31_/H0`Ko60<:o
a`020<:oaP80`/360P32`<L20<?0a`040<?1a`33`<L0`l370<C0a`L0a<7700<0a<;70<G2b035`/L0
0P34`/H01P35`/L0aL;80<K3b036`lP0b<C:0<[4bP80dm7G0`3Dd=H20=CAeP040=C@eP3Cd=H0e=3F
0=CAeP<0eM7F0`3Dd=H30=C@e0030=C@e@3DdMD0eM7E0080eM7E00/0^[Nj071^L00X9bP04Q8B00@4
100M7Ad0BDQ:09VGVP3Ac]40em;E0=GAe0030=GAd`80e]7D00D0e];D0=OBe@3GdM@0eM3B0=C@dP08
0=G@dP030=GAd@3FdM80em;B00P0em;B0P3Gdm<00`3Je]H0g][J0=kJfP0:0=kJfP80gm[J00<0gm_J
0>3KfP3PfmX0103PfmX01@3Pg=X0hMcJ0>3LfP2_ZjT030`<01T0000000`0EEA@0;JdZ`35`kX0gmgB
0>GTf03WiMT0j>KJ0>WWfP3Yi]X0j>CL0>OSg03Xh]`30>ORg080in;K00d0j>;L0>ORg03Wh]`0in;L
0>SRg03WhM`0in7K0>ORf`3Xhm/0in;K0>OQf`3:aKl0=S@c00H0000000h00P8200/;2`1bL6/0e]?9
0:n]Y01cLV/0YjFL0>GReP3Wi=L0iN;E0>7NdP3Uh]H0inCH0>OTe`80j>CH00<0j>GH0>SUe`3XiML0
103XiML01@3XiMH0h=k?0>3Nc`2PWi@07QdL03X00000303oool000X0oooo00X0^k_>0;jmd@2h]lX0
_[g?0;Vib`2o_m40_[oA0;nod@2o_]40_kkB0P2o_m80202o_]40_kk@0;jnd02o_]00_koA0<2od@2m
_<h0^[[<0P2i^LX20;VhbPD0^;O900T0^KS90;^jb`2o_m00`/CD0<C4e@33`m@0a<GF0<?4e@31`M80
0P31`M402@2m_/d0`<3@0<30c`30_/l0_kk>0;jlc02m^l/0^kW90;Zhb0060;Zha`030;^ia`2k^LP0
^kW800<0^kW80P2l^/P01@2l^/T0_K_:0;fkbP2n_</0_[c:00@0_K_:00<0_K_90;flb@2n_<T01`2n
_<T20;nmbP030;nlb@2n^lP0_K[700<0_K[700@0_[_80;nmbP30_LX0_[_70`2l^LD20;fja@030;bi
a@2m^L@0_;[50080_K[53`2m^lD01`2m_<@0_[c40;jla02n_<@0_kc50;nma@30_LD02P30_/H00`31
_lH0`[o70<:oa`020<;0a`040<;0aP32`<L0`/370<;0a`80`/360P33`<H00`33`<L0a<770<C1a`06
0<C1a`030<C2a`35`/P0aL;700<0a<;70P35`/P00`36`lP0alG:0<k:d@020=?Ae`030=?AeP3Dd=H0
e=7F0080e=7G00@0eM7G0=C@eP3Dd=H0e=7F0`3EdMH30=C@eP030=C@e@3Dd=@0e=3D0080e=3D00H0
e=3E0=G@e@3EdMH0eM7F0;6^/@0M71d40000000504M6A`2`[K00eM7D0=KBe03EdM@00P3EdM<20=GA
e0040=KAe03Fd]@0e]7D0=G@d`D0eM3B0`3EdM820=KAdP@0e];B1@3Gd]830=OCdP030=WEe03Mf]X0
gM[J00X0g][J00<0gm[J0=oKfP3OfmX0103PfmX30>3LfP040>7LfP3MfMP0Ogil00@411P0000000L0
4Q8A096@R03Xi]X0hN3E0>OVfP3Xim/0j>GK00<0j>CL00<0j>?M0>SRg@3Wh]`00`3Wh]`0103Xh]`0
j>?L0>SSg03Xh]d50>SRg00F0>SSg03Xhm/0j>?K0>SSg03Wh]X0h]gE0=oJd`3Fd/X0^[N`08b:Q01d
LVh0O7Yf09fJU02:R880]kB[0>CPe@3Sh=D0h]oC0>CQeP3Wi=L0inCH0>OTe`80inCH00<0j>CH0>SU
f03XiML02@3XiML20>7Od00309VGSP0E51@0000003T00000303oool000X0oooo00P0_[kB0<31e02j
^/`0`;oB0;Zic02o_m40_Kk@0;nodP80_koA00@0_kkB0;nodP2o_m80_[kA0P2n_]00102o_M00_Kc>
0;^kc@2j^L/20;VibP<0^KS:0P2h]lT01`2h]lP0^KS90;^jb`2m_Lh0`<3B0<?5eP34a=@00P33`m@0
3@30`=80_Kc=0;fkc02l^l`0^[W:0;Rgb02m^l`0`;k?0;nncP2n_Ld0_Kc<0;bkbP2j^LP0102j^<L2
0;^ib080^kW90`2k^LP30;bjb@060;bkb@2m_<X0_[c;0;nlb`2o_L`0_Kc:102m^lX00`2m_<X0_[c:
0;jlb@060;jlb@<0_kg:1@2n_<T01P2o_<T0`Kk;0<2mbP2o^lP0_KW50;bia@D0_K[600<0_K_60;jk
aP2n^lH03P2m^lD01`2m_<D0_Kc40;jla02o_<@0_kc50;nma@30_LD01@30_/H00`30_lH0`Ko60<6o
aP030<6oaP030<6oa`31`<L0`/3700H0`/371`33`<L20<?1a`<0a<7700@0a<;70<C1a`34`LL0aL;8
0P35`/L02`36`lP0a/?90<K3b@36a<T0b<G;0=3=d`3Cd=H0dm3E0=3=d`3;b<h0dLkC00<0e=7G00H0
e=;G0=CAe`3DdMH0e=7F0=GAeP3DdMH30=C@eP070=??e03Ccm<0dloC0=??d`3Dcm@0e=3D0=CAe@02
0=GAeP030=3<d00d<c@0000000<0000000L08R4R069PHP2k^;`0em?F0=KBe@3EdM@0eM7C0080eM7D
0P3FdM@00`3EdM<0eM3C0=G@dP030=G@dP@0eM7B0`3FdM870=KBdP@0em;B00<0fMGD0=gJfP3Mf]X0
103Nf]X40=kKfP030=kJfP3NfmX0gm_J0080gm_J0`3PfmX20>3Lf`050>3LfP3Qg=X0gm_I0;Rd/P1;
BTT06@0000002@0h=cD0bLRn0>SWf`3XimX0j>OK0>SWfP3Whm/0in;L0>OSg0060>ORg@<0j>;L00<0
j>?L0>SRg@3Xh]d00`3Xh]d20>SSg080j>?K0P3Xhm`30>STg080j>CK00D0jNCK0>WUf`3Xi=X0eM;8
0=WFc0030>KSf0060>KTf03Wi=L0inCG0>OTe`3Wi=P0j>CH103XiMP20>SUe`040>SVf03XiML0j>GH
0>SUe`80j>KH0P3Xi]L00`2VYI/04Q8A0000000i000000`0oooo000:0?ooo`0;0<30e@2o_m<0_;_>
0;bkcP2h^</0_koA0;fnd030`=80_l3B0;nod@2o_]400P2o_m801P2n_]40_[g@0;fmc`2m_Ll0_;_=
0;Zjc0<0^KW;102i^<X01`2h]lT0^;O80;Zib`2n_Lh0`<3A0<;2e034aMH00P33`m@00`32`]80_[g>
0;Vgb@020;Vgb0040;Zhb@2l^/X0_kk?0;nnc`<0_kg>00<0_K_<0;Zib@2j^<L00P2j^<L0102k^LP0
_Kc;0;flc02k^/T30;^ib@0;0;^jb@2l^/T0_;[90;bjb@2l^lX0_K_:0;flb`2n_L/0`;k=0;jlb`2l
^lX00`2m^lX00`2m_<X0_[c:0;jlbP040;jlbP80_kc:202o_LX01030_LX0`;k;0<2nbP2n_<P20;fj
aP80_[_700@0_;[60;jlb02o_LT0_kc80P2n^lL0102m^lH0_K_50;fka@2m^lD30;jka@L0_K_50P2m
_<D01@2n_<D0_kc40;nma@2o_LD0_kk600@0`;k600<0`;o70<6oa`31_lL01@31_lL80<;0a`H0`l37
0P33`LL20<?2a`<0a<;70P34`LL00`35`/P0aL?80<G3b@030<G3b@090<K4b@39al`0d/oE0=?@eP3D
dML0dLoE0<_8cP32_l@0dm3F00@0e=7G0P3DdMH20=C@e@040=CAeP3Dd=H0e=3F0=C@e0<0dloD00T0
e<oD0=CAe@3DdMD0eM7E0=GAeP3DdMD0WI^M05QGF00C4a<0100000000`1dLG@0dm3C0=ODe`040=GA
e0030=KAe03EdM@0eM7C00@0eM7C103EdM830=KAdPL0e];B00<0em;B0=OCdP3Gdm800P3Gdm800`3I
eMD0gM[J0=gJfP040=gJfPD0g]_J1@3OfmX30>3KfP80h=cK00@0hMcK0=cHeP1`KVd071/K30000000
200I6AP0=SHd04Q8A@1eMG00RHR208^:Q@1?CT/01@D510000000100U9B@0UIF>0>3Oe03WiM/20>OU
g0030>OTg03Whm`0in;L00P0in;M0P3Xh]`00`3Whm`0in;L0>SRg0020>SRg080in?K00<0j>?L0>SS
f`3Xhm/00`3Xhm/20>STf`D0j>CJ00<0inCI0>KSf03VhmP01P3Wi=P0303WiMP0inCH0>OTf03XiMT0
g]_?0;nm/P2d/JL0dLo30>OUe`3WiMH0j>KG0>SVf080jNKH0P3Yi]L00`2SXYL04Q8A0000000i0000
00`0oooo000:0?ooo`0;0<71e@30`=@0`;oC0;^jc@2o_m80`<3C0;o0d`30`=80_l3B0;nodP2o_m40
0P2o_m801P2n_]40_[g@0;jmd02m_Ll0^[[=0;Zjc0<0^KW;1@2i^<X0302h]lT0^[S:0;^ib`2k^/`0
_[c>0<31dP32`M80`/;C0<?3d`30`=40_Kc=0;bkc080_;[;00<0_Kc=0;nmcP2o_/l00`2o_Lh0202n
_Ld0_;[;0;Zib@2j^LT0^kW90;fkb`2n_Ld0_[g<0`2k^/T00`2l^/T0_;_:0;flb`020;flb`80_K_:
00D0_Kc;0;jlb`2o_/`0_Kc;0;fkbP030;flbPL0_[c:00<0_kc:0;jlbP2o_LX0202o_LX01@30_/X0
`;k;0;nmb@2n^lP0_[c80080_kc900@0_[_80;nmb@30_LT0_kg90P2o_<P00`2n_<L0_[_60;jkaP05
0;jlaPH0_Kc500<0_[c50;jma@2o_LD00`2o_LD00`2o_/D0_kk60<2naP020<2naP030<2na`31_lL0
`Ko700D0`Ko71P32`<L50<?0a`030<?1a`34`LL0a<7700<0`l7700<0a<770<C2a`34`/L00P34`/L0
0`35`/L0aL;80<K3b@030<G3b@0<0<K4b@37aLX0cL[@0=?Ae`3Ac]@0d/oE0<[8c@37a<T0cL_@0=;>
e03Cd=H0e=;G0P3EdML01@3Ed]L0e=7F0=;?e03Cd=D0e=7F0080e=3F00@0e=7F0=C@e@3Dd=@0dloD
0`3Dd=@20=GAeP040=GBeP3DdM@0_[^n0450@@@0000000<0H5eP0<_8b`3GdmL01@3EdM@20=KAe0@0
e]7C00@0eM7B0=G@dP3Ed=80eM7B1`3Fd]<20=KBdP070=OBdP3Gdm80em?B0=OCdP3Gdm<0f=CD0=[F
eP060=gJfP070=kJfP3NfmX0g]_J0=kKfP3OfmX0emCC0=OCdP030=oKfP030>3KfP3Pfm/0h=_K0080
h=cK00<0h=cJ0=WEe017ATD03@000000201CDU00[ZbW0;jm]P3Kf]40i>?I0>GTfP2b/JT03`l>1000
0000101IF5@0f]W?0>CSf03QgmH20>KRg@<0in;M00<0in?M0>ORg@3Wh]d01@3Wh]d20>ORg00:0>OR
f`3Vh]/0in;K0>ORf`3Whm`0in;K0>OSf`3Whm`0j>?M0>SSg080j>?K0P3XhmX60>STfP030>STf@3V
hmT0i^?H00D0i^CH00/0i^CG0>?Pe03Wi=P0inCH0>OUf039ak`0DU5<0491?P2RXIL0inGG0>OUeP03
0>SUe`<0j>KG00@0/:jS03Xj=P0[:bP051@C>000000<0?ooo`002P3oool01P31`MD0_koC0;jmd02j
^/`0_koB0<30d`<0_l3B00X0_koB0;nod@2o_m80_koB0;jnd@2n_]00_[g@0;bkcP2j^/d0^KW<0`2i
^L/04@2i^<X0^;S:0;VhbP2j^LX0^[W;0;Rgb@2i]lT0^;O90;Vgb@2j^<X0_Kc=0;nod031`M<0`L7B
0<30dP2o_]00_[g>0080_Kc=00L0_[g>0;nnc`2o_/l0_[g>0;nmcP2o_ll0`;o?00<0_Kc<00X0_[k=
0<30c`30`<l0_[g=0;^jb@2l^/X0_K_:0;jlb`2m_</0_[c;102m^lX00`2m_</0_[c;0;jmc0040;fl
bPX0_[c:2@2o_LX00`30_LX0`;k:0<2mbP050<2mbP030<2nbP31_l/0`;k:0080_kg900<0_kg80;jm
b02o_LT00P30_LT0102o_LP0_kc70;jlaP2n_<H40;jmaP030;nmaP2n_LH0_kg60080_kg60`2o_LD0
1@2o_/D0`;k60<2naP30_/H0`;k700<0`Ko700<0`L380<;0a`32`<L01@32`<L20<?0b0@0`l370P33
`LL20<C1a`80`l771034`/P20<G3b0030<G2b035`lT0aL?900<0a/C900L0alG:0<[8c@3?cM80d]3F
0:j//@33`LL0c<W?00<0e=7G00T0e=;G0=GBf03DdMH0e=7F0=GBe`3DdMH0dLgB0=?@e03DdMH0103D
d=D00`3Dd=@0dm3D0=C@e0020=C@e080eM7E00@0eM7F0=KBeP3Cd=<0IF=V100000000`1:BDX0_kbo
0=OCe`070=GAe0@0e]7C00<0eM7C0=G@dP3EdM801`3Fd]<60=KBdP060=OCdP3Hdm<0f=CE0=[Gf03L
fMX0gMWJ1P3Mf]X20=kKf`030=oKf`3Dd=00blS800D0gm_J00H0h=_K0>3Lf`3Pg=/0h=cK0=OCd@17
ATD70000000:010@401DDe40M79_08R7PP2GUY40[jjX0=GCb`3Xi]h0j>KM0>SVg080j>OM00X0i>;H
0;jm]@1`L6/08B4O0820N`2n_K@0d]770>KUfP3Uhm/0iN7K0`3Vh]d:0>ORg@040>ORg03Wh]/0i^;K
0>KRf`80i^?K00<0i^;K0>KSf`3Vhm/00P3Whm/00`3Xhm/0j>CK0>STf`020>STf`<0j>CJ0P3Wi=X2
0>OTf@80i^?I0P3Vi=T20>KTf0030>OTf03Vi=L0emC90080i^CG00P0inCH0<k<`02IUhh0b<Jj0=[H
b`3WiML0j>KG0>GSe@<0j>KH0P3Xi]L0103?c/00XJ2E09^JT019B4<h000000`0oooo000:0?ooo`09
0;o0e02k^ll0^;S;0;jmd02n_]00`<3C0;o0dP30`=80_l3B00@0_koB0`2n_]400`2k_<h0^[[=0;Vj
c0030;Vib`80^;S:00@0^KW;0;^kc@2j^/`0^;O90`2h]/T00`2i]lT0^kW;0;jmc`030;nod0030;jn
c`2n_Ll0_[g?00<0_[g?0P2n_Lh03P2n_/h0`L3A0<30d02n_Ld0_[g>0<71d@35a]D0`/?A0<70d02n
_Ld0^k[90;flb`30_lh0_kk=0P2m_</20;fkbPD0_;_:102m_<X:0;jlbP/0_kg:1030_//20<6nb`D0
`Ko;0P31`</30<;0b`030<6obP2o_LP0_[c70080_[g70P2o_LL20;nmb0050;nma`2o_LH0_kg60;nm
aP2o_/H00`2o_LD00`2o_/H0`;k60<2naP020<2oa`050<6oa`31`<P0`L380<70b032`<P01@32`<L8
0<?0a`@0`l7700@0a<;80<C2b@34`/T0aL?90P36`lX20<G3b@0G0<G4b@36a<T0a/C90<S6c03=bm40
dLkE0=?Ae`3BcmH0alG:0<?1aP3<b]00dm7G0<k;d@37aL/0cL[@0=CAe`3@c]<0a<760;Zh_@36`lP0
d<gB0=7>d`3Cd=D00`3Dd=H0103DdMH0dm3D0=??e03Ccm@20=C@e080e=7E00@0eM7F0=GBeP3Dd=@0
Kfi_10000000100];2d0QH>50<c8c03FdMD20=GAe0<0e]7D00<0eM7D0=GAd`3EdM<0103EdM<20=KA
d`@0e];C0`3Fd]802P3Fd]<0em?C0=OCd`3Fdm80e]?C0=OCd`3He=D0f]KG0=cHf03LfMX80=gJfP04
0=kKf`3Ofm/0dm3@0<_8b0D0gm_J00H0h=_K0>3Lf`3Pg=/0gmcJ0<O3`P0l>cX70000000802d];02o
_KL0h=kH0>CRfP3WiMd0inKM0>SVg@3Ximd20>OVg0@0j>KL00H0bLS004m>BP3Ge/d0inKK0>OWg03X
iM`50>KRg@X0in;M00<0in;L0>ORf`3Vh]/01`3Vhm/00`3WhmX0j>?K0>SSf`030>STf`80j>CJ00<0
inCJ0>OUfP3Wi=T00P3Wi=T01@3WhmT0i^CI0>KTf@3Wi=T0inCH00<0i^CH0P3WiMP02@3Wi=P0inGH
0=7?a02n_;40i^CF0>OTeP3WiMH0inGG0>;Qd`030>SVf080j>KG00@0gM_=0<_9_036a;P0GEaG>000
000<0?ooo`002P3oool02@2m_]80^K[=0;RhbP31`MD0_[kA0;o0d`2n`=80`<3C0;o0d`040;nodP07
0;jnd@2m_M00^kc>0;Zjc@2i^/`0^KW<0;Vib`020;Rhb`80^;S:00<0^KS;0;Zjc02i^L/00P2h]lT0
2@2i]lX0^[S:0;^ib`2m_<h0`;o@0<71dP30`M80`<3B0;nod0020;jmc`<0_kk?0140_[g>0;jmc@2m
_<d0_[c<0;fmc@2l^l/0_;c;0<2ocP32`]40_[g=0<70d02o_/d0_K_;0;jmc@2o_/h0_[g<0;bkb`03
0;flb`@0_;_:00@0_;c:0;flbP2m_<X0_Kc:2P2n_<X30;jmbPL0_kg:00@0_kg;0<2mb`30_//0`;k;
1031_//60<6ob`070<70b`32`<`0`/3<0<?0c032`</0`;k90;nmb0030;nma`040<2na`30_/P0`;k8
0<2na`80_kk70P30_/L01P2o_/H0_kg60<2naP30_/L0`;k60<2oa`@0`Ko700D0`L370<6oa`31`<L0
`L370<;0b0020<;0a`030<;0b033`<L0`l3700D0`l371033`LL01@33`LP0a<;90<G2b@35`lT0a/?:
0080a/C:00L0aL?:0<G3b@36a<X0alG:0<S5b`3;bLl0d<kD0080dm3G0P3CdML02`3AcmD0d]3F0=?A
f03@c]D0/[6f0:JTZ03=b]00^;Jk0<;0a@3<b/l0d/oE0080d/oD00L0dm3F0=C@eP3Dd=H0d<gB0=3=
d@3Cd=@0dloD0080dm3D00<0e=3D0=CAe@3DdMD00P3EdMH00`3DdMD0NWQj000000030000000300/;
2`0X9bP0UYBF00@0eM7D0P3FdM@00`3Fd]@0eM7C0=GAd`050=GAd`030=GBd`3Fd]<0e];C00D0e];C
1@3Fdm<01@3Gdm@0fMKG0=cIfP3LfMX0gMWJ00P0gM[J00@0g][J0=kKf`3Ge=<0e]?B1@3OfmX30>3L
f`030<W5a01eM7806QXJ00@0000000H010@3051?C@1@Cdd0WYbG0>7Of03Xi]l20>SWgP030>OWg@3W
i]d0j>KM0080inKL0`3Xi]`03P3Xim`0hn;H0<2o]P3Qh=H0j>OL0>OWg03WiM`0i^?M0>KRgP3Vh]d0
in;M0>OSg@3Wh]d0i^;M2@3Wh]d00`3Wh]`0i^;K0>KRf`060>KSf`030>KSfP3Whm/0in?K00<0inCK
103Wi=X20>KTf@80inCI1@3Vi=T20>KTf080inGH0P3WiMT00`3EdlL0d]330>KTeP020>OUeP030>OU
e`3UhmD0inGG0080inGG0P3Xi]L0103Dd/D0/k:V08j<Q00e=C4h000000`0oooo000:0?ooo`090;jo
d`2k_<l0^k_>0<71e@2o_m80`<3D0;o0d`30`=<0_l3C00@0_koB00@0_[kA0;bmc`2j^/d0^K[<0P2i
^L`00`2i^</0^;S:0;RhbP030;RhbP0=0;VhbP2h^<X0^;O90;Zib`2l^ld0_[k?0;nnd030`=40`/;D
0<?4e@34aMD0`/?D0<30d@020;jnc`060;nod030_m00`;k?0;jmcP2m_<d0^k_;0`2k^/X01`2l^l/0
_Kg<0;fmc02k^lX0_[k>0;noc`2o_/h00P2n_L`00`2m_<`0_;c;0;blb`020;blb`D0_;_:00<0_;c:
0;flb`2n_<X02@2n_<X20;jmb`D0_kg;0`2o_LX00`2o_L/0`;k;0<2nc0020<2nc080`Kk<00@0`Kk;
0<6ob`31_l`0`Ko<1@31`<`20<;0c0040<?0c033`L`0`/3<0<2obP80`;k:00<0`Kk90<2ob@31_lX0
0P31_lT01@30_lT0`[o:0<:obP32`<X0`;o700<0`;k700<0`;o80<6ob031_lP00P31_lP20<70b003
0<70a`31`<P0`/3800<0`/380`33`<P50<?1b0050<?2b034`/T0a<;80<C2b035`lT00P35`lX03036
a<X0alC<0<S6c038a/`0alG;0<S6c038a/d0b/S>0<_9c`3>c=80d/oF0=?@e`80dm7G00l0d]3F0<o=
d`3@cM@0clkD0;fk`029R8/0X9jS0<k<d@33`LH0d<oD0=3=d`3Ac]@0clcA0=;?e03@c=800P3>b]00
1P39a//0d/oD0=CAe@3Cd=@0dm3E0=C@e@<0e=7E0P3EdMH0103EdMD0ZZJZ059@DP0J6QX400000003
06ITI`3Bc]40e];E00P0eM7D00<0eM;C0=KBd`3Fd]<02`3Fd]<01@3Fdm<0em?C0=OCe03He=D0fmOH
0080gMWJ2@3Mf]X0103Nf]X0g]_K0=kKf`3Nfm/50=oKfP80h=cK00<0gm_J08n=S00000001@000000
1`092@T0ZZVT0:ZYY03Uhmd0inKO0>OVgP3Ximh0103Wi]d40>SWg@0:0>SVg@3Ximd0j>OL0>SWg03X
i]`0inOL0>OWf`3Wi]`0i^?N0>KRgPD0i^;M2@3Wh]d00`3Wh]`0i^;K0>KSf`060>KSf`030>KSfP3V
hm/0i^CK0080inCK1P3Wi=X20>OTf@030>OSf@3Wi=T0inCI0080i^CI0P3WiMT00`3Vi=P0inGH0>OU
f0030>SVf@060>OUf03WiML0inGG0>OUe`3Wi]P0inKG0`3WiML20>SVe`040>;QdP3Uhm@0Ti:801TI
5cP00000303oool000X0oooo00@0`<7E0<30e030`=@0`L7E0P30`M@30;o0d`80_koB00T0_[oB0;no
dP2m_M00^k_>0;Vic02h^L`0^KW<0;Ric02h^</00`2h^<X04@2h]lX0^;S:0;Rgb@2h^<T0^;S:0;fl
cP33`mD0a/WJ0<G6f033`mD0a<GF0<K8f@36bMT0a<KF0<30dP2n_/l0_kk?0080_[g?00D0_[k?0;jm
cP2m_<d0^k[:0;Vhb@020;Zib@@0^k[:00@0_Kg<0<30d030`<l0_Kc;102l^lX20;bkb`040;blb`2l
^l/0_;_;0;blb`L0_Kc:1P2n_<X20;jmb`P0_kg;00<0`;k;0<2nc030_//01P30_//30<6oc0<0`Ko;
00D0`L3;0<;0c032`<`0`/3<0<?1c0050<?1c@030<C2c@35`lh0a/??0080a/C?00@0alC?0<O5d036
a<l0`/3;0P30_lP20<6ob0L0`L381P32`<P00`33`<P0`l780<?1b0040<?1b0040<C1b@34`/T0a<;:
0<O5c@<0dLoF00<0d]3H0=;Af03Bd=P0103BdMP00`3CdML0dm3G0=?@e`030=?@e`0@0=?Ae`3=bm40
^kVn0<2na02/Zk00L6mb06ASIP2m_<40d]3F0=7?e@3Cd=L0d/oF0<o<dP3>bm40dm3F0<:oa@80/k6e
00<0c/_@0=?@e@3Cd=D00P3Bcm@20=CAeP80e=7E00H0e=7F0=GAeP3Ed]H0clc?0:2MX00k>S/40000
000504M7A`34`L@0em?G0=KBe@3EdM@00P3Ed]@00`3Fd]@0eM7D0=GAe0020=GBe0<0e];D1@3Fd]<5
0=KCd`80em?D00<0f=GF0=[Fe`3LfMX00`3LfMX20=gIfPH0gM[J00<0gM[K0=kKf`3Nfm/00P3Nfm/4
0=oKf`80h=cK00<0h=_K0:BRX@020P80100000001@0`<2h0RXV40=WHd@3If=40inKO0080inKN0P3W
imh50>OVg@0;0>OVg03Wi]d0inKM0>SVg03Xim`0j>OM0>;Qe`3Wi]/0inCM0>KSg@3Vh]h01`3Vh]d3
0>ORg@030>OSg@3Whmh0j>?N00<0j>?M00<0i^?L0>KSf`3Vhm/01@3Vhm/40>KSfP<0i^CJ103Wi=X2
0>OTf@030>OUf@3Wi=T0inCI00@0i^CI00L0i^CH0>OUf03WiMT0inGI0>SVf@3Wi]P0inGH0080inGG
103Wi]P0203ViML0j>KH0>SWf03XimP0eMC60=gLc@2NWI806ATG>000000<0?ooo`002P3oool00`31
`]H0`L;G0<72eP020<71e@030<31e@30`M@0_l3C0080_l3C00D0_koB0;jnd@2k_<l0^[[>0;Vjc@02
0;Vic@030;Vjc02i^L`0^;S;0080^;S:00<0^;S;0;RhbP2i^L/00`2j^/`07`2l_<h0`;oB0<?5e`34
aML0a<GF0<G6e`36b=P0a/OH0<?5e@30`=80_ko@0;fmcP2l^ld0_Kg>0;nod02o_ll0_Kc=0;bkc02l
^l/0_Kc<0;noc`30`=00_[k>0;fmc@2m_<d0_[g>0;o0c`30`<l0_[k>0;jmc@2m_L`00P2l_</20;fm
c0030;jnc@2o_/d0_[g<0080_Kc;1P2m_<X50;jlbPH0_[g;0P2n_LX0102o_LX0_kg;0;nmb`30_//5
0<2nc0030<2oc031_l`0`Ko<00L0`L3<0`32`<`00`33`<d0`l7<0<?1c@030<?1c@030<C2c@35`lh0
a/C?0080a/C?00H0alC?0<O5d036a<l0a<;<0<70b@30_lP20<6ob080`L380`31_lP00`31`<P0`/38
0<;0b0040<;0b0030<?0b033`LP0`l780080`l7900<0`l;90<?1b@33`/T00P35`/X00`36`l/0b/O?
0=;?e`020=;@f0030=?Af03Cd]T0d]7H00@0d]7H00<0d]3G0=?@e`3Cd=L00`3Cd=L02@3CdML0dm;H
0;jl`@3<bLl0ZZR/06MVJ@1mO7l0alC:0=?Ae`020=;@eP050=;?e@3CdML0clcB0=?@eP30_L800P2d
/[L01@3@cM80dm7F0=?@e@3Ccm@0dm3F00D0e=7F00D0eM7F0=GBeP3Fd]H0`l3405ACE00400000004
02d/;@2QWj40d/oB0=KBe@@0eM;D0P3EdM@20=GAd`L0e];D1P3Fdm<00`3GdmD0f=GF0=cIfP020=cI
fP030=gIfP3LfMX0g=WJ0080g=WJ103Mf]X20=gKfP040=kKfP3Nfm/0g]_K0=kKf`@0gm_K00H0gmcK
0>3Lf`3Pg=/0h=cK0;6^[@030`<40000000306ASH@3Ng]H0inKN00@0inKN00<0inON0>OVg@3Wi]d0
1@3Wi]d0203Vi]`0inKL0>OVg@3Ximd0j>OL0>7QeP3Wi]`0i^?M203Vh]h20>ORgPD0in?N0`3Xhmd0
0`3Vhm`0i^?K0>KSf`080>KSf`H0i^CJ00H0inCJ0>KTfP3Vi=T0i^CI0>KUf@3WiMT20>OTf@80i^GI
1@3WiMT00`3Wi]T0inKH0>OUf0030>OVf0040>OUf03Wi]P0j>OI0>OVf0<0j>OH00D0fm_=0>3Od02W
Yi/08B4O00<30`0g000000`0oooo000:0?ooo`030<72eP31`]L0`L7F00<0`<7E00P0`<7D0<30d`2o
`=<0`<3C0;k0dP2m_]00^[[>0;Vjc@80^KW=0P2i^L`20;Vib`80^;S;00@0^KW;0;RhbP2j^/`0^kc>
0P2k^ld06P2l_<h0_[g?0<31d`33a]L0a/WJ0<K8fP37bMX0a/SI0<?5e@30`=80_kk@0;bkc02k^//0
^k_<0;jod02o`=40_Kg>0;blc@2o_ll0`L7A0<C5e@35a]D0_Kg=0;jncP2l_<`0_;g=0P2n_/d20;fm
c@030;flc02l_<`0_;c;0080_kk=00@0`L3@0<71d030`<l0_kg=102m_</50;jlb`030;jlbP2n_L/0
_[g;00D0_[g;102o_L/00`2o_//0`;k<0<2nc0060<2nc080`;k;00<0`;o<0<6oc031_l`00`31_l`0
1@31`<`0`/3<0<;0c032`<`0`l7<00<0`l7=0P34`/d00`34`/h0aL?>0<K4c`020<K4c`<0alG@00<0
a/C?0<?2c032`<T00P32`<X00`32`<T0`[o90<:ob@070<;0b0050<?1b@34`LX0aL?<0<G3b`35`//0
0P35`/X20<G3b`050<K4c037aLd0alG=0<W7d03>c=@0103Bd=P00`3BdMP0d]3H0=?Af0030=;Af080
dm3G0P3CdML40=?Af00>0=3>e03Bd=L0c/cA0;bj`02h]kd0blW?0=?Ae`3Bd=H0d/oE0<k;d@3Cd=H0
blS>0=?@e@3;bLh20<G3b0040<g:d03Cd=D0d]3E0=?@e@80e=7F00<0dm7F0=CAe@3DdMD00`3DdMH0
0`3Ed]H0c<W>06MUI`040000000501HE5P1IEeT0Z:FX0=KCeP3Fd]D0103Ed]D90=GBe0050=KCe03F
d]<0e];C0=KBd`3Fdm<00P3Fdm@0103HeMH0fMGG0=cJf`3Mf]/50=cIfP030=gIfP3Mf]X0gM[J00@0
gM[J00@0gM_J0=gJf`3Mfm/0g]_K1P3Og=/0103Pg=/0g][I09JDU0010@440000000506a[J03Shm/0
inOO0>OWg`3Wimh00P3Wi]h30>OVg@80inOM0`3Wi]d30>OWg@80j>OM00D0i>CI0>OWg03Wi=d0i^?M
0>KSgP050>KRgPP0in?N103Whmd00`3Vhm`0i^?K0>KSf`060>KSf`<0i^CK1P3Vi=X30>OUfP80inGI
0P3Wi=T20>KTf@@0i^GI00<0inGI0>OVf@3Wi]P0103Wi]P00`3Xi]P0j>OI0>CSe@030>SWf0050>KU
eP3Shm@0`;nc06QXH00N7A/0=`00000<0?ooo`002P3oool00`31`]H0`L;G0<72eP030<31e@070<31
e030`M<0_l3C0;o0d`2n_m80_;g@0;VjcP020;Ric@030;Vic@2i^L`0^KW<0080^KW;0P2i^L`0102i
^/`0^KW;0;^kcP2l_<l20;blcP0@0;bmc`2m_/l0_koB0<?4e`36bM/0a/WJ0<O:fP36amL0`/?D0;no
d@2o_]00_Kg>0;^kb`2k^//0_/3@0<31dP80_Kg>00H0`/?C0<G7e`36amL0aLOF0;blc02m_Ld80;^k
b`070;blb`2o_lh0_ko>0<;2d@33`m80`/;A0<2ocP050;flb`D0_[c;202n_L/30;nmb`L0`;k<1030
_l`70<70c0<0`/3<0`33`Ld01@33`/d0a<;>0<C2c@34`/h0aL?>0080aL??00/0a/C?0<O5d037aM00
alG@0<S6d036a<l0aL?=0<C2c@35`l`0`/3:0<:ob@030<;0b@@0`/3800<0`/790<G4c03<b]800P3A
d=P30=7?f0<0dM3H0P3Ad=T00`3Ad=P0dLoG0=7@e`030=;@f0040=7@e`3BdMP0dm7I0=?Af080d]7H
00P0d]3G0=?@e`3Cd=L0d]3G0=;Af03CdMP0d]7G0=?@e`80dm7G00L0d]7G0=;@eP3@cmD0dLoF0=;@
eP3Cd=H0dm3G0080d/oE00<0c/_A0=?@eP3Bd=H00P3Bd=H20=?@e@030=CAeP3DdML0e=7G0080e=7F
0P3DdMD20=CAeP80eM;G00<0dLkC07=cM00000000`00000010030`<03@`=06]YK03Ed]H20=KBeP03
0=GBeP3Ed]D0eM;E00@0eM;E00<0eM?E0=KCe@3FdmD00`3FdmD00`3Fdm@0e]?C0=KCd`020=KCe007
0=ODe@3LfM/0g=[L0=gJg03Mfm`0g=WJ0=cHf@040=cIf@030=gIfP3Mf]X0gM[J00<0gM[J00@0gM_J
0=gKf`3Mfm/0g]_K1P3Og=/00`3Pg=/0fmSG07ekN`040000000300@4101cLfh0i>CM00@0inKN00<0
inKM0>KVg@3Wi]d0103Wi]d30>KVg0050>KWg@3Wi]d0j>KM0>SWg@3Vi]/00P3Wim`00`3Wi]`0i^?M
0>KRgP040>KRgP80i^?N2@3Whmh20>OSg@80i^?L0P3Vhm/90>KTf`80inCK00<0inGK0>KUfP3ViMX0
103WiMX30>OUf@<0i^GI00<0inGI0>OVf@3Wi]T0103Wi]T20>OVf0040>KUeP3Sh]D0hN7B0>SWf080
inOG0P3XimP00`3Ti=D0ZZZO03Dd<@0g000000`0oooo000:0?ooo`040<72eP31`]L0`L;G0<32eP<0
`<7E0P30`M@01@30`M<0`<3B0;fnd@2j_<h0^K[=00<0^;W=00<0^K[<0;Vic02j^ld00`2j^ld05`2k
^ld0_[k@0;jnd02m_Ll0_;g?0;fmd02n_m00`<3C0<;3e@32a=H0a<KH0<G8f034a]H0`<7C0;fnc`30
`=40_ko?0;blcP2l_Ld0_ko@0;k0d030`M40_Kk>0080`L;C00@0_l3A0;o0d02l_<`0^kc;202k^l/0
1`2l^l/0_Kg<0;fmc02o_/d0`;o>0;nncP2n_L`01`2m_</20;flbP030;jlb`2n_L/0_[g;00P0_[g;
00<0_kg;0<2nb`30_/`01030_/`80<2oc0@0`L3<0P32`<`01P32`Ld0`l7=0<?1c@33`Ld0`l;>0<C2
cP80a<?>0P35`ll01036a<l0a/C@0<O5d038aM020<S6d0050<O6d036a<l0a/C>0<O5c`33`L/00P31
_lP30<;0b@090<;0b033`LT0`l;:0<G4c038am00cLcD0=3@f@3Ad=T0dLoH00D0dM3H0P3Ad=T30=7@
f080d]3H0`3Ad=P0103BdMP0d]3H0=;@f03Ad=P30=;@e`0C0=;@f03BdMP0dm7H0=7?eP3Bd=L0dLoE
0=;@e`3>c=80`;k40;Vg_@2j^Kl0a<;80=3>e03?cM<0blW?0<k<dP3AcmD0d]3E0=7?e0020=;@eP09
0<k;d@3>c=40d/oD0=?Ae`3DdML0dm7G0=CAe`3CdMD0e=7E0080e=7F00@0e=;G0=GBe`3<bLh0J6MY
10000000100];2h0ViZM0<c:c@3Fe=L20=KCe`80eM;F0P3EdmH00`3Ed]H0eM?E0=GCe@030=GCe@<0
e]?E0`3Fdm@20=KCe@050=ODeP3Lf]`0gM_L0=gKg03Mf]`00P3KfMX60=cIfP030=gJf`3Mf]X0gM[J
00@0gM_K00<0g]_K0=oLf`3Og=/0103Og=/0103Pg=/0fmOG08V7QP020P820000000301LD4`27Q800
cLc600<0i^KN00@0inON0>KVgP3Vi]d0i^KM1P3Wi]d0103Wimd0i^OM0>OWg@3Wimd20>SWg@80inOL
00<0inKM0>KTg@3Vh]h0103Vh]h01@3Vhmh0in?N0>OSgP3Whmh0inGM00<0j>KM00<0j>GM0>STgP3W
hmh00`3Xi=h20>OTg@030>KTg03Vhm`0i^?L00T0i^CK0`3WiM/20>KUfP<0i^GI103WiMT50>KUf@04
0>KVf@3Wi]T0inKI0>OVf@80inKH00<0i^GF0>CSe@3Ui=H01@3XimP00`2a/JD0F5QC01XJ600g0000
00`0oooo000:0?ooo`<0`L;G0P31`mL03`31`]H0`<7E0<31e030`M@0`<7C0;o0d`2n`=80_[oA0;^l
c`2j^lh0^K[=0;Ric@2i^/d0^k_>0;bmd0020;fmd00A0;bmc`2m_m00_l3B0<30d`2o`=80_/3A0;no
d@2n_m40`<3C0<31e02o`=40`/?E0<C5e`32a=D0_l3A0;fmcP2o_m400P2n_/l01`2m_Lh0_[o?0;k0
c`30`]<0_;c=0<71dP2n_/l00P2m_Ld00`2l_<`0^k_;0;^kb`080;^kb`80_;c;0`2m_<`:0;flb`03
0;jlb`2n_L/0_[g;00P0_[g;00<0_kg;0;nnc030_/`01P30_/`00`30_l`0`<3<0<30c0050<70c080
`/3=00@0`/3<0<?1c@33`Ld0`l7=0P33`/h00`33`/d0a<;>0<G3cP020<G3c`0J0<K4c`36a=00a/G@
0<O5d038a]00bLK@0<S6d038a]40b<G@0<S6d039a]00bLSA0<O5c`36a<h0alK?0<O5cP35`l`0`/39
0<C3b`38am00bl_C0<g=e@3?c]P0d<oI0=3@f@3AcmP20=3@f0030=3@f@3Ad=P0dM3H0080dM3I0P3A
d=P30=;@f0060=7Af03Ad=P0dM7H0=;Af03Ad=P0dLoH0`3Ad=P20=;@e`0>0=;Af03CdMP0d]7G0=?A
e`3AcmH0d]3G0<c:d@35`lX0Z:J[0<2n``39ald0d/oF0<o=d`3AcmD30=;@eP<0dm3F00L0cL_A0<k<
dP3Bd=H0dm7G0=CAe`3CdMH0e=7F0080dm3E0P3CdMH0103Dd]L0eM;G0<[8c@1PGV0400000004055A
DP3Ad=<0fmWM0=KDf080e]?G0P3FdmH00`3FdmL0e]?F0=KCeP040=KCeP<0em?F00H0em?E0=SEe`3I
eMH0fMGF0=[Gf@3Kf=X20=cJg0050=gKg@3Ng=h0g=[K0=_HfP3Kf=T00P3LfMX40=_IfP030=cIfP3M
f]X0gM[J00<0gM_K00@0g]_K0=kLg03Og=`0gmcL103Og=/0103Pg=`0gm_K09fJVP030`<200000004
03@d<P3Cd/`0inOO0>OWg`80i^OO00@0inON0>KVgP3Wi]h0inON0`3Wi]h0103Wi]d0i^KM0>KVg@3V
i]d20>KWg@030>OVg@3Ximd0inOM0080inOL00<0i^GM0>KSg`3Vhmh00`3Vh]h40>KSgP030>OTgP3X
im`0j>SL00<0j>SL00<0j>GM0>OSgP3Xhmh0103Wi=h0103Wi=d0i^?L0>OTg03Vi=`90>KTf`80i^GK
0P3ViMX40>OUfP060>OVfP3WiMX0inGJ0>OUfP3ViMX0i^KI1P3Wi]T40>OVf0030>OWf@3XimT0j>OH
0080j>OH00<0j>SH07moMP071`L0>000000<0?ooo`002P3oool01P31`mL0`<;G0<72e`31`]H0`L?F
0<72eP80`<7E0P30`M@02P30`=<0_l3C0;o0d`2m_]40^kc@0;ZkcP2h^/d0^K[=0;^lc`2l_M020;fn
d0060;jod@2n`=40_l3B0;o0dP30`M<0`<3B0P2n_m401`30`=<0`<7C0;nod@31`]@0`/CE0;k0d02l
_Lh00P2n_]003P2m_/l0_[k?0;fnc`2k_<`0^K[:0;:c`P2j_</0`<7A0;fncP2m_Ld0_;c<0;Zjb@2j
^//0^k_;0`2k^l`20;^kb`80_;c<0`2l_</;0;flb`80_[c;2`2n_L/00`2o_//0`;k<0<2nc0020<2n
c0P0`;o<0P30`<`20<70c080`/3<00@0`/3=0<;1c@32`Ld0`l7=0`33`/h01@34`/h0aL??0<G3c`35
a<l0a/C@0080a/G@00<0alG@0<O6d038a]000P38a]401@39am40bLOB0<S6d@3=c=H0d=3I0080d<oI
00D0c/cF0<W8d035`l`0b<O?0<g<e@040=3@f@040=3@f03AcmP0dLoH0=7?f0H0dM3I00@0dM3H0=;@
f03Bd=P0d]3H1@3Ad=P01`3AcmP0dLoG0=7?e`3AcmL0dM3G0=;@e`3AcmH00P3Ad=L03`3Bd=L0d<kE
0=7?e`38ald0^;Jm0;:a]P2f]K/0]K>i0;jl`@36a<X0cL_A0=7?e@3Bd=D0dm3F0=;?e@020<k<d@09
0<;0a@2o_L<0`l360<K4bP37a<X0a/?80<k;d@3Cd=D0dm7F0080e=7F0P3Dd]L00`2k^;d0BTY;0000
00030000000504U8BP36a/T0fm[M0=ODf03Fe=L00`3FdmL:0=KCeP030=KDe@3IemP0g=[L00@0g=[L
00@0gM_L0=gLg@3Ng=h0g]_M0P3KfMX20=cIfP070=_IfP3Kf=X0fmWJ0=_IfP3LfMX0gM[K0=gJfP03
0=gKf`030=kKf`3Nfm`0gmcL00D0gmcL0P3Pg=`0202:R8P00`<3000000000000=3@b0=_Je03Vi]l0
i^OO0P3Wiml30>KVgP@0inKN0P3Wimh01`3Vimh0i^OM0>KWg@3Vimd0inOM0>SWg@3Wimd00P3Wj=d0
0`3ViMh0i^;N0>KSgP040>KSgP070>KSg`3Vhmh0inGN0>SVg@3Xj=`0j>WL0>SYg@020>SYg0050>SW
g@3Xi]d0j>KM0>SVg@3XiMh00P3Xi=h0103Wi=d0inCL0>OTg03Vi=`20>OUg0030>KTg03Vi=/0i^CK
0080i^CK0P3ViM/30>OUf`070>OUfP3ViMX0inGJ0>OUfP3Wi]X0i^GI0>OVf@020>OUf@030>OVf@3V
iMT0inGI00H0inKI0P3Wi]P20>OWf@070>SWf@3@cl80d<o20;2_X`2AT8H0@D4m00@40`0h000000`0
oooo000:0?ooo`80`L?H00H0`L;G0<32eP30`MD0`<7E0;o1e@30`MD20<32e@80`<7D00@0_koB0;bm
d@2k_=00^[_>0P2i^/d0202j^/d0^k_>0;bmc`2l_Ll0_Kg@0;jnd@2m_/l0_[o@0P2n_m402`2m_]00
_/3A0;o0dP2o_m40_l3B0<30dP30`M<0_Ko@0<32d`31`]<0`<7C0080_[o@00/0_l3A0;RjbP2e]/H0
^[c<0<?4e@30`M80_l3@0;nod02i^/X0];K40;^lc0060;^kc0030;blc02m_<`0_;c<00<0_;_:202l
^lT00`2l^lX0_;c:0;fmb`020;fmb`/0_[g;0`2o_/`50<2nc0040<2oc030`<d0`<3=0<30c080`L3<
0P31`<d20<;0c@<0`/7=00P0`l7=0<?1cP33`/h0a<;>0<C3cP35`ll0aLC?0<K4d080a/G@0P37aM00
2@37a]40b<KA0<S7d@38am80bLSB0<_9e03:bM<0c/kG0=3@f@020=3?f@050<k=e`3;bm@0bLSA0<_:
e03>c]L0103@d=T20=3?f0@0dLoH2`3Ad=P00`3AcmP0dM3H0=7@f0020=7@f080dM3G00<0d]3G0=;A
f03BdMP00P3Bd=P02`3Ad=L0d]3G0<k<d`35a<X0a/G<0<K5b`37a/`0a/C:0<S6c03<bm00dLoE0080
d]3F0180alG;0<2n``30_/<0Z:J[0:VX[02SXZH0Q8B708j<S`2i]k`0blW>0<2m`P2n_<40clgC0=?A
eP3Dd]L0eM;G09ZIW@0`;c44000000070410@034`lH0fm[N0=SFfP3Ge=P0e]CH0=KCe`030=KDe`80
e]?F0P3Fe=L20=KCeP80emCF00<0emGC0=cJg03Lf]`00`3Lf]`20=cKg0050=kLg@3Ng=h0g]cM0=cJ
f`3Kf=X0103Kf=T20=_IfP80g=WJ00<0gM[J0=gKf`3Mfm/00`3Mfm/00`3Nfm/0gmcL0=oLg0030=oL
g080h=cL00H0MgEe00<30`010@409BHT06e]JP3QhMX40>KVg`80i^KN103Wi]h40>OWgP<0i^OM00<0
inOM0>SWg@3Wimd00P3Wimd00`3ViMh0i^?O0>KSg`050>KSg`050>OTgP3Ximd0j>SL0>SXg03XjMd0
1`3XjM`02@3Ximd0j>GN0>SUgP3XiMh0inCN0>OTg@3WiMh0j>GN0>OUg@020>SUg@030>OUg03ViM/0
i^GK00<0i^GK0`3WiM/30>OVf`80inKJ203Wi]T50>SVf@@0j>OI0P27QWh00`0:2PT01PH600820P0i
000000`0oooo000:0?ooo`030<73f031`mL0`<;F00<0`<7E00<0_l7D0;o1e@30`]D00P31`mL01@30
`MD0_[oB0;bmd@2k_M00^[_?0080^K[=0P2i^L`20;ZkcP0N0;bmd02m_Ll0^[_=0;^mc`2m_m00_;g?
0;^lcP2n`=80_[oB0;fnd02n_m40_l3@0;jod02l_Lh0_l7B0<72e02n_m00_koA0<31dP32a=D0_l;B
0;Jha`37bMX0b<[K0<;4e033a=@0`L;C0;>e``2][[d0^kc<1@2k^l`0102k_<`0_;c<0;blc02l_<`2
0;^kbP80^[[91`2k^/P00`2k^lT0_;c:0;jmc0060;jmc0D0_[g;00D0_[k;0;jnc030_/`0`;k=0<2o
c@080<2oc0<0`<3<0P31`<d20<;0c@050<;1c@32`Lh0`/7>0<;1cP33`Lh00P33`/h00`34`lh0aLC@
0<K5d0020<K5d080a/GA00<0alG@0<O6d@38a]800P38am80103:bM@0c/oH0<o@f@3?d=T20=3?f@06
0<o?f@3?cmP0c/kG0<g=eP3>c]L0cloH103@d=T20=3?f0@0dLoH203Ad=P00`3AdMP0dM3H0=3@f002
0=7?f0@0dM3H01@0d]3G0=;Af03Bd]P0dM3G0=3?e`3AcmL0d]3H0=;@e`3AcmH0cLcC0<g<dP3Bd=L0
dM3F0<k<dP38a/`0c<_@0=7>e03?c=80a<;70:RV[080];:h00/0PGn308n>TP20OX40@d9307AbMP33
`/L0blW>09bJWP1iNG`0a/C90=?Be`020=CBe`0309FDU`0];2d0000000<0000000L09BDU08J5R03=
c<l0f=OK0=OEf@3Ge=P0e]CH00<0e]CG00P0e]?G0=KCeP3Fe=L0e]CG0=ODe`3GeML0fMKI0=_If`D0
g=[L00@0gM_M0=gKg03Lfm`0gMcM0P3Ng=h0103Mf]/0fmWJ0=_HfP3Kf=X40=_IfP030=cIfP3Lf]X0
gM_K00H0gM_K00<0g]_L0=oLg03Og=`00P3Og=`0203Ie]D0V9JE04I5A@020P801@H309FIR`3Ng]L0
i^KO0P3Viml30>KWgP@0i^KN1P3Vimh20>OWgP80j>ON00@0j>SN0>OWgP3Wi]d0i^CN1P3Vhml00`3W
iMh0inKN0>SXg@070>SYg@80jNWM00D0jNWL0>WXg03Ximd0j>OM0>SVg@020>OUg@<0j>KM0`3XiMd2
0>OVg0050>OVf`3ViM/0i^GK0>KUf`3WiM/01@3Wi]/50>OVfP030>OWfP3Wi]T0inKI0080inKI0P3W
imT50>SWf@030<S8^`1CDdd0De==03`00000303oool000X0oooo00<0`L;H0<;3f031`mL00P30`]H0
1030`MD0_l7E0;o1e@31`mH20<73e`070;k0e02m_]80^[c@0;Zkc`2i^/h0^;[=0;Vjc0020;Ric080
^[_>01H0^kc?0;bmc`2j^ld0_;g?0;jod02m_]00^kc?0;fodP2m_m40_Kk@0;nod@2o`=40_l3B0;fn
c`30`]80`L?D0;o0d@30`M<0`L;D0<?5eP32aMH0^kc<0P36b=T01P34aMH0`lGF0<72e02a/L00/kC3
0;^lc0@0^k_<0P2k^l/00`2k_<`0_;_;0;bkb`020;^kbP030;Zjb@2j^LP0^[W80080^[W800P0^[[8
0;^jb02j^/P0^[[80;^jb02l^lT0_;c:0;fmb`P0_[g<00D0_[g;0;jnb`2n_/`0_kk<0;nnc@050<2o
c@80`;o<1P30`<d30<70c@030<;0c@32`Ld0`l7>00D0`l;>00T0a<??0<G4d036aM00a/G@0<K4d036
aM00alGA0<O6d@38a]400`38am80103:bM@0cloI0=3@fP3@cmT40<o?f@030<o?f03?cmT0cm3I00D0
d=3I00<0d<oI0=3@f@3Ad=T00`3Ad=T70=7@f0030=7Af03Ad=T0dM3H00<0dM3H01P0dM3I0=;@f@3B
d=P0dm7H0=;@f03BdMP0dLoG0<G4b`30_/D0cL_B0=;@e`3Ad=L0dM3F0=3?eP3AcmH0d]3G0=;@eP3<
b]00_K_10;Nf^`30_/<0ZJN/07imP@1THVH205iMH00;04E4AP16ADP0GEaO07AbM@2_[K80clcB0=3>
d`37a<T0`l360<S6b`3CdML00P3Dd]L00`2g]KX0ADA5000000030000000600D51@0F5QH0Q8>60=OF
fP3If=/0f=KJ0P3GeMT30=OEf0060=ODe`3GeMP0emGH0=SEf03IemT0f]SJ0P3KfM`30=cJg0040=gK
g@3Mg=h0gMcN0=kLgP<0g]gN00<0gMcM0=cKg03KfMX01@3KfMX00`3Lf]X0gM[K0=gKf`060=gKf`80
g]_K0`3Og=`01`3>bl/0@T51010@400:1`L0:R`U0<K:^`3Vi]l00`3Viml30>KWgP030>KVgP3Vi]l0
i^KN00H0i^ON0P3Wimh00`3Ximh0j>SN0>SXgP020>SXgP030>SWgP3Vhml0i^?O00@0i^?O00<0i^CO
0>OVgP3XjMd00P3Xj=d60>SYg@<0jNWM00D0jNWL0>SXf`3Xj=/0h^7G0>OUg@040>SUgP060>SUg@3X
iMh0j>KN0>SVgP3Yj=d0i^KJ0P3ViM/00`3WiM/0inKK0>OVf`060>OVf`<0inKJ0P3Wi]T80>OWf@80
inSI00<0W9bA028R7`0R8Ql0?000000<0?ooo`002P3oool01@31`]L0`L?H0<;3f032a=P0`L?H0080
`L?G00H0`LCG0<;4f031`mL0`<7E0;fndP2j^ll20;VjcP050;Rjc@2h^Ld0^;[=0;Ric02i^/`00P2j
^lh02P2k_<h0_;g?0;bmc`2m_]00_[kA0;o0dP2m_]40_l3B0;jod@2m_]020;k0d@0C0;^mcP2o`=80
`<?D0<?6eP35a]P0a<GG0<?5e`2o`=80_Kk?0;joc`33a=D0`lGE0<32dP2n_m00_;c=0;Nha`2l_Ld0
_[k?0;^kc0020;bmc@060;blc02k_<`0^k_;0;Zib@2i^LP0^KS8102i^LP00`2i^LL0^KS70;Vha`02
0;Zib0040;Zia`2j^LP0^[[80;^jb080^k_900@0_;c:0;fmb`2m_L`0_Kg;1@2n_L/00`2n_L`0_[k<
0;nnc0020;nnc@<0_kk<00<0`;o<0<2oc@30`<d01030`<d20<70c@80`/3=00D0`/7=0<;1cP32`Lh0
`/7>0<?1cP020<?2cP090<?2c`34`ll0a<?@0<G4d036aM00a/C@0<K5d036aM40alKA0080b<KA0`38
am800`39b=<0c/oI0<o?f@070<o?f@80cm3I00<0d<oI0=3?f03@cmP01P3@cmP20=3@f0070=7@f03@
d=P0dM3I0=7@f@3Ad=P0dM7I0=7@f0040=3?f0030=7@f@3BdMP0d]7H00<0d]7H00D0d]7I0=7@f03;
b]40bLO?0=;Af0050=7@e`090=;@e`3Bd=H0d]3F0<S6c@2h][`0c<_A09bLX@1OGV40D51B0080BTY;
00D0BDU;02XY:`1JFE`0][Bi0=?Be`040=?AeP080<_9cP3CdMH0dm7F0=CBe`39a//0G5]M00L71`03
0P<40000000405eMGP3Ad=@0fm[N0=_Ig@<0f]WL00D0f]SK0=WHf`3If=/0f]SK0=[Ig0050=_Jg005
0=cJg@3Lfmd0g=_M0=gKg@3Mfmh00P3Mg=h30=kMgP80gMcM00<0g=[K0=_IfP3KfMX00`3KfMX00`3L
f]/0gM[K0=gKf`020=gKf`80gM_L103Nfm`30=oLg0070<[7a`0Y:2P0000003<^;@2GUY40gMkF0>KW
g`050>KVgP030>KVg`3Vi]h0iNKN0080iNKN103Vimh30>OWgP<0j>SO0P3Xj=h00`3Ximh0i^CO0>KS
g`020>KTgP080>KSg`3Vi=l0inKN0>OWg@3Wj=d0hnCI0>GVfP3Xj=h60>WYg@80j>WM00H0jNWM0>KV
f@3Vi]T0d];80=_Id@3XiMh20>SUg`0;0>SVgP3Wi]d0inKM0>OVg@3Ximd0j>OL0>3Oe@3NgM<0i^GK
0>KVf`3Wi]/00P3Vi]/50>OVf`040>OWf`3WimX0inOJ0>OWfPD0inOI00L0gMg?0<o?``3?cl<0`<2d
09BDR`1oOgL0De==0080410??000000<0?ooo`002P3oool01@31`]P0`L?H0<;4f@32aMT0`/CI00@0
`/CH00D0`L?G0;o0e@2k_M00^K[>0;Rjc@020;Ric@040;Rjc@2h^/`0^;W<0;Rjc080^K[<00H0^[_>
0;bmd02n_m80_l3B0;o0d`30`=<20<31e00M0;o0dP2n_m40_[oA0;jod@2o`M80`<;D0<?5eP34b=P0
`lOG0<K8fP33aML0_Kk?0;fmc`30`=80`<;C0<31dP2l_Lh0^kc<0;^kc02m_Lh0_l3A0;joc`2k^l`0
_[o@0;noc`2m_Lh0_;c<0;^kb`2h^<P0102h^<L20;Vha`030;Rha`2h^<H0^;S700<0^KS700<0^KW7
0;Zib02j^/P00P2k^/P00`2l^lT0_;c;0;fmc0020;fmc0050;jmc02n_L/0_[g;0;jmb`2n_/`00P2o
_/d30;noc@D0`;o=1030`<d40<70c@@0`/7>0`33`/h30<C3c`050<G4d036aM40a/G@0<K5d036aM40
0`38a]430<S7dP050<G4c`3>cmT0cloI0<o?f@3?cmX01@3?cmT20=3@fP030=3@f@3@cmT0d<oI0080
d<oI103@d=T0103Ad=T0dM3H0=7@f03@d=P20=7@f@030=7Af@3Ad=T0d=3I00@0d<oH00<0dLoH0=;A
f03BdMP00`3BdMP30=7@f0030=;@f03Ad=P0dM3G0080dM3G00H0d]3G0=;Ae`3Bd=L0dM3G0=7?eP3@
cmD20=;@e`030<c;d@2j^Kl0_Kg20080][Fj0140_ko409fMX@1XIfX0LW1d0;Bc^03Acm@0dM3E0<c:
c`36a<T0`l;70<o=d`31_l@0d/oE0;Jd^01jNG/0BTU;01/K700400000004055ADP3;blh0fm_N0=[I
g@80f]WL0P3JfMd0103JfM`0f]SK0=WHf`3JfM`30=_Jg@80g=[M00H0g=_M0=cKgP3Lfmh0g=[M0=cK
g@3Lg=h30=gMgP040=gLg@3Lfm`0gM_M0=cJf`80g=WK00H0fmWK0=_IfP3KfMX0g=[J0=gJf`3Mfm/4
0=gKg0040=kKg03Ng=`0g]_L0=kKg0<0gmcL00H0b/S802l_;00U9b40QHF10=kNf03Vin020>KVg`80
i^OO0`3Vi]l00`3Ui]h0iNON0>GWgP020>KVgP80inKN0`3Wimh00`3Wj=l0j>SO0>SXg`030>SXg`08
0>SWgP3Vi=l0i^GO0>OWgP3Vi]h0i^CO0>KVgP3Wj=d20>SYg@030>;Sf03RhmL0jNSM00<0jNSM1P3Y
jMd20>WXg0030=KFbP3>cL@0j>GN0080j>KN0P3WiMd20>OVg00:0>SWg03Wi]/0i^KL0>KVg03Vi]/0
inKK0>OWf`3Wi]/0i^KK0>OVf`H0inOK103WimX20>OWf@080>SWfP2;Rh<061PG01PH5`0F5QD04A4?
00h>3@092@T200820C`00000303oool000X0oooo00<0`L?I0<;4f@32a=T00`32aMT01P32a=T0`/CH
0<;4f032a=P0_l7E0;Zld0<0^;[>00D0^;[=0;Vjc@2i^/d0^K_=0;ZkcP020;Zkc@0Q0;^lc`2l_]00
_[oB0;fnd@2n_m40_l3C0<32e031`]D0`<3C0;o0d`30`M<0`L?E0<72e02o`M<0`<7C0<73e032a=D0
a/SJ0<C4eP30`M<0_[o@0;nod@2o`=40`<3A0;jod02k_<d0_[o@0;o0d@31`]80_l3@0;fncP2n_/h0
_Kc=0080^k_;00<0^[[:0;Rhb02h]lL00`2h^<L00`2i^<L0^;S70;Rha`020;Rha`<0^KS700L0^KW7
0;Zjb02j^/P0^[[80;^jb02k^lT0_;c;00@0_[g<0`2n_/`00`2o_/`0_kk=0;nnc@040;nnc@030;no
c@30_ld0`<3=00D0`<3=0P31`<d20<71c@@0`/7>0`33`/l01034`ll0a<?@0<G4d035a=030<K5d@09
0<O6d@38a]40alKA0<O7dP38am80b<OC0<[:e030`L/0cm3J0080cloI0P3?cmX0103?cmT0clkI0<k>
f@3?cmT40=3@fP<0cm3I00@0d=3I0=3Af@3@dMT0d=7J0`3Ad=T80=3@f@040=7@f@3@cmP0d<oG0=3@
f0<0dM7I0`3Ad=P01`3BdMP0dM3G0=7@e`3Ad=L0dM3H0=;Af03Bd]P00P3Cd]P00`3Bd]P0dm;H0=?B
f@020=?Af0030=CCf@3CdmT0eMGK0080dm?H0140e=?I0<W7c@2AT9D0JFQ/09>CU`3;b/l0dM3E0<S7
c02o_L80alK;0<_9cP2WYJT0c<[?0::PY02WY:T0RhZ=03<c=00400000005034a<`2GUiX0dM3C0=[I
g@3JfM`0103JfMd00`3If=`0fMSK0=[Ig0030=_Jg@80g=[M1@3Lfmd01`3Lfmh0gMcN0=kMgP3NgMh0
gMcM0=cKg03Mf]`00P3Lf]/20=cIf`050=_If`3KfMX0g=[K0=gKg03Mfm/0103Mfm`20=kLg080g]_L
00P0g]cL0=oLg03Og=`0a/?304=4?`22QG`0dmC>0>GVg`<0i^KO0P3Viml20>KVg`@0iNKN00<0i^ON
0>OWg`3Wiml00P3Wimh40>OXg`050>SXg`3XjMl0j>WO0>SYg`3Xj=h00P3Wimh0103Xj=h0j>ON0>OV
gP3Wimh20>OXg@030>OYg@3Wj=d0i^OL00@0jNWN0`3ZjMh20>WYg@0:0>[Yg@3Xim/0j>OK0=SHc03O
gM<0jNSN0>SXgP3Yj=h0j>ON0>SVg@80inKM00@0j>OM0=gLd`3@d<H0hN3F0P3Wi]`20>OWg00:0>OV
f`3Wim`0inOL0=SHc@2b/ZP0Y:BL08V:P@2HV8l0]kN]0=[Jc`<0inOJ00<0g]kA0;6aYP1:BTD0A000
000<0?ooo`002P3oool20<;5fP@0`/GI00H0`/CI0<;4f032a=P0`/CH0;o1e@2j_=030;RjcP050;Vk
cP2j_<l0^kc?0;^md02m_]400P2l_]420;fnd@<0_;k@00D0_/3B0<31e031`mD0`L?F0<31e0020<73
e@0F0;k0dP2m_]00_Ko@0<30d`33a=H0a<KG0<?4e@31`]@0_l3A0;jod02n_]00_Kg?0;Vkb`2o`=40
`<;C0<72d`32`m@0`L;C0;jnc`2k_</0^[[:0;Vhb@80^KS800<0^;S70;Nga`2g]lL00P2g]lH50;Rg
aP80^KS700L0^KW70;Zib02j^/P0^[[80;Zjb@2k^lT0_;c:00D0_;c;00@0_Kg;0;jnc02o_/d0_kk=
1P2o_ld00`30_ld0_ko=0<30c@050<30c@@0`L3=1032`Lh20<?2cP030<?2c`34`ll0aLC@0080aLC@
0`36aM402@36a]40alKA0<O7dP37am80b<OC0<_;eP3?d=X0`<7:0<o@fP040<o?fP040<o?f@3>c]T0
c/kI0<o?fP<0cm3J00<0d=3J0=3@f@3@d=T00P3@d=T20=3@fP030=3AfP3@d=T0dM3I0080dM3I00<0
d=7I0=7Af@3Ad=T00P3@d=T20=3?f@040=3@f@3@cmP0d<oG0=7@f080d]7I1`3Ad=P00`3@cmH0d]3G
0=?Af0020=?Af0090=?Bf@3BdMT0d]7H0=;Af@3CdMT0dm;H0=CCf@3Ad=H0eMCJ0080aLG;0140^;Jl
0<S7c@2d/kP0^KRn09VIW02a/;@0_[c10;:a]@2XYj/0Xj:V09ZIW@2AT9@0b/S=09:AU@20Oh40IFAV
02DU9P040000000700X:2`0X:2P0S8b?0=KEf@3Jf=`0fMSL0=[Ig0030=[Ig@040=WHg03JfM`0fm[M
0=_Jg@80f]WL0P3Jf=/20=[Ig0030=_Ig03Lf]d0gMgO00<0gMcN00<0gM_M0=_If`3JfMX00P3KfM/3
0=_IfP030=[IfP3Kf]X0gM[K0080gM_L0P3Mg=`00`3Ng=`0gM_L0=gKg0020=kKg0080=kLg03Og=`0
gmcL0<G2`P26Qh40bLg00>KWh03Viml30>GVg`80i^KO0P3Ui]l20>GWg`030>GVg`3Uiml0i^KO0080
i^KO0P3Vimh0103Wj=l0gMkE0;bl]@3:b/840>SYg`H0j>SN00<0inSN0>OYg@3Wj=h00P3XjMh30>WX
gP030>WYgP3YjMd0jNWM0080jNWM0`3ZjMd20>SXg0030>[ZgP3[j]h0jN[M00<0jN[M00L0j>ON0>OV
gP3Wi]h0inKM0=OGcP2e]:d0i^GK0080inKL103Wim`00`3Wim/0YjNN018A4@020000000300@4100W
9b@0][N]00<0inOJ00<0WinF01TI5P061PH0A000000<0?ooo`002P3oool00`32a]X0`lKJ0<?6fP04
0<;5fP090<;5f@32a=T0`/CI0;o1e@2k_M00^K[>0;RjcP2i^lh0_;kB00<0_/3C00H0`<7C0;k0d`2n
`=<0_l3D0;fodP2k_M020;^mc`030;fod@30`=<0`<;D00<0`L;D0100`<7C0;fod02k_Ll0_;g?0;k0
d@31`]@0a<GF0<?4eP32a=D0_l3B0;fnd02m_/l0_Kk@0<31dP34aMH0a<KF0P34aMH00`31`]<0_Kk>
0;ZjbP040;Rhb0030;Rha`2g]lL0]kO60080]kK60`2g]/D0102g]lD0^;S60;Vha`2i^LP40;Zjb003
0;^kb@2k_<X0_;c:00D0_;c:00<0_;c;0;jmc02o_/d0202o_ld00`30_ld0`<3=0<30c@040<30c@04
0<71cP31`Ld0`L7=0<71c@<0`/7>00D0`/;>0<?2c`33`/h0`l;?0<C3c`020<G4d0050<G4d@36aM40
a/KB0<K5d@37a]800P37am801P38am80b<SC0<_<e`3?d=/0blcF0<o@fP@0cloJ0P3?cmT30=3@fP04
0<o@fP3?d=T0d<oI0<o@f@T0d=3I00<0d=7J0=7AfP3AdMX00P3AdMX0103Ad=X0d=3I0=3@f@3@d=T2
0=7@f080dM3I0P3Ad=P00`3@d=P0dM3H0=7@e`030=7@e`080=3?eP3Bd=L0dM3G0=7@e`3AdML0d]3H
0=;Af03BdMT30=?Bf@030=GDfP3EeM/0eMGK0080c<cB0140`L760=7?eP3BdML0e=?J0<o>e03;bm00
b/W?0<K6bP2a/;D0J6MY04U8BP1kNWh0b/S>08F4Q`11@44092<T00d=3@060000000304i>C`3@cm80
fMSL0080f]WL103JfMd20=_Jg@040=[Ig03If=/0fMSK0=WHf`<0fMOJ00<0f]SK0=cJg@3Mg=l00`3M
g=h0103Lfm`0f]WJ0=[HfP3Jf=X30=[Hf@<0f]WJ00<0g=[K0=gKf`3Mfm`01P3Mfm`01`3Nfm`0g]cL
0=oLg03Jf=L0`l700=7Bb`3Pi=L00P3Vin020>GVg`<0i^KO103Ui]l00`3Ui]h0i^OO0>KWg`020>OW
g`060>KWg`3Wj=l0inSP0:FUW`0j>SP0TY>=1@3XjMl40>SXgP040>SXg`3Wj=h0inSM0>OXg@80j>SN
0P3Yj=h50>WYgP030>WYg@3ZjMd0j^WM00@0j^WM1@3Zj]d0203YjMd0inKL0>7Qf03ThmX0hN3H0=oO
eP3Kf]40g]kC0`3Wim`01@3Xim`0i>?H0<30]`1JFUD020P800<0000000L04A4@06m`J@2`/:H0^;R^
0:VZX01HF5<00P8204D00000303oool000X0oooo00@0`/KJ0<?6fP33a]X0`lKJ1032aMX01032aMT0
`L?H0;k0e@2k_M820;Vkc`060;Zld02m_m80`<7E0<32e@2o`=@0_/3C0P2n_m<00`2n`=80_KoA0;bo
d@020;bnd0030;jodP2o`=<0_l3C0080_l3C00`0`<7C0<30dP2n`=40_Kk@0;bnd02o`=80`<7C0<;3
e031`m@0`<7B0;jod02n_]020;jod0080;k0d02l_/h0`<;B0<32dP30`M80_Kk>0;^kb`2i^LT40;Rh
b0030;Rha`2g^<L0]kO600D0]kO500@0]kO60;RhaP2i^<L0^KW80`2j^/P0102k^/T0^k_:0;^kbP2k
^lX50;blbP030;blb`2m_L`0_kk=00@0_kk=1@2o_ld20;o0c@@0`<3=00D0`L3=0<71cP32`Lh0`/7>
0<;1c`020<;2c`040<?2c`33`ll0`l?@0<?3c`80a<C@00<0aLC@0<G4d@36aM400P37a]801P37am80
alOC0<S7d`38am<0b<SC0<_<e`80cm3K0P3?d=X01`3?cmX0cm3J0<o?f@3>cmT0cloI0=3@fP3@dMX0
0P3@d=X20=3@f@80cm3I0P3@d=X40=3@f@030=7@f@3AdMX0dM7J00@0dM7J00<0dM3J0=3@f@3@d=T0
103@d=T00`3Ad=T0dM3H0=7@f0020=7@f0X0dM3G00<0d]7H0=;Af@3Cd]T00P3Cd]T00`3De=X0dM7H
0=GEf`030=GEf`0>0=CCfP3Dd]T0e=;I0=GDfP3Gemd0emKL0=GCf@3?cM<0C4]=00T92@1NGF00];:g
071_LP0J6Q/800000004028R8`2CTYD0d]7D0=WIg0L0f]WL0P3If=/00`3Iem/0fMOJ0=WGfP020=WG
fP050=WHfP3JfM/0g=[M0=cJg@3Lf]`00P3Kf]`20=[HfP040=[Hf@3Jf=X0f]SI0=[Hf@80f]WJ00@0
fm[K0=cJf`3Lfm`0g=_L103Mfm`0303Mg=`0g]cL0=kLg03Ng=`0g]_L0<G4``2`/:d0`/:n0=gOf@3U
in00iNKP0>GWg`@0i^KO0P3Ui]l30>GWg`@0i^OO00L0inOO0>OXh03Wj>00h>7I0<o?b@3HfM80inWP
0080j>WP0`3XjMl20>SYgP050>SXgP3XjMl0inWN0>OYgP3XjMh02@3YjMh40>[YgP<0j^[N103Zj]d0
2@3Xj=/0hn?F0<2o]P2][:H0g]gE0>OVg@3Wimd0iNGL0>?Sf0030>OWg0030>KVf`2i^K008b<Q00D0
000000H00@4100d=3@0J6QP071`J01TI5`0<30]6000000`0oooo000:0?ooo`050<?6f`32aMX0`lGJ
0<?6fP32a]X00`32aMX01032aMT0`<?G0;k0d`2k_M020;^md@060;^nd@2m_m<0`<;F0<73eP2n`=@0
^kg@0P2l_]401@2m_m80_/3B0;g0dP2m_m80_/3B00D0_l3C00<0_l7C0<31d`2n`=800P2n`=402P30
`=<0`<;C0<72e030`]<0_l3B0;jod@2o_m40_l3A0<30dP2o`=430;fnc`070;fmc@2j^l/0^;S90;Rh
b@2h^<P0^;S70;Nga`040;NgaP@0]kK500D0]kO50;NgaP2h^<H0^;S70;Vha`040;Vib080^[W800T0
^[[80;Zjb@2k^lT0^k_:0;^lbP2l_<X0_;c;0;fmc02n_ld01`2o_ld00`2o`<h0`<3>0<30cP020<30
c@050<30cP31`Lh0`L7>0<71cP32`Lh00`32`Ll01032`/l0a<?@0<C3d034`m030<C4d0050<G4d@35
aM40aLGA0<K6dP37a]800P37am<01@37am80b<OB0<S7dP38b=<0bl_G00<0cm3K00@0d=3K0<o@fP3?
d=X0cm3J0`3?cmX50=3@fP040<o@fP3@d=X0cloJ0<o?fP<0d=3J00<0dM7J0=3AfP3@dMX01P3AdMX4
0=3@f@<0dM3I0`3Ad=P60=7@e`070=7?e`3Ad=L0dM3G0=;@e`3BdMP0dm;I0=?BfP030=?Bf@030=?C
f@3Cd]T0e=CJ0080eMGK00D0eMCJ0=CCfP3Ee=/0e]GL0=OFg0020=SGg@080=OEf`3FeMX0`/;70:j^
/`2WYj/0T92C03/k?00>3Ph80000000400410@0820P0Ng]l0=GEf080fMSL00L0f]SL0=[Ig03JfM`0
fMSL0=WHf`3Hem/0fMOK00H0fMOJ00@0fMSK0=[Hf`3Jf=/0f]SK1@3Jf=X40=[IfP040=_If@3Kf]X0
g=[K0=cKf`80gM_L103Mg=`40=kLg0030=CBd@2n_[/0hnGN00X0iNKO0P3Uiml00`3Ui]l0i^KO0>KV
g`020>KWg`030>OXg`3Wj>00inSP0080inSP0P3Wj=l00`3WjMl0j>WO0>SYg`020>SYh0040>SXg`3X
jMl0j>WO0>SYgP80inWN00@0j>WN0>SXgP3Xj=h0j>WN1P3YjMh00`3Yj]h0j^[N0>[ZgP060>[ZgP80
jn_N00l0^[V`06e]I`1;BTL0Bd]809FES`3Qh=P0i^KM0>;Qf02e]Jh0_knf0>KVg031`KT0WIfE06IV
H@0A4A00D@00000<0?ooo`002P3oool01@32aMX0`/CJ0<;4fP32aMX0`lKJ0080`lOJ00T0`lKJ0<;5
fP2o`]L0_;kB0;Zlc`2m_m<0_l7E0;fod`2m`=<00P30`]H01@2l_]80^;[>0;^md02k_M00_KoB00<0
_/3C1`2o`=<0102o`M<0_l3B0;o0dP2o`M<20<32e0090<72e030`M<0_l3B0;jod@2o`=40`<7B0<72
d`2o_m40_;g>0080^kc=00@0^[[;0;Rib@2h^<P0^;S80P2g]lL0102f]lH0][K60;JfaP2f]/H50;Nf
a@040;Nga@2g]lH0^;O60;Rga`80^;S700<0^KW80;Vha`2i^<L00`2i^LL0202i^/P0^[[80;^kb@2k
^lT0^k_:0;blbP2m_L/0_[k<0`2o_/d40;noc@@0_l3=00D0`<3=0<30cP31`<h0`L3>0<71cP040<;1
c`040<;2c`34a=00a<C@0<C3d0<0a<C@0P35aM420<K6dP<0alOC0`38am<00`38b=<0bl_G0<k?fP03
0<o@f`80cm3J00D0cloJ0<k?f@3>c]T0c/kI0<o?fP040=3@fP030<o@fP3?cmX0cloI00@0cloI00@0
d=3J0=3@f@3@d=T0d=3I0P3@dMT00`3@dMX0dM7J0=7Af@060=3@f@D0d=3H103Ad=L0203@cmL0dM3G
0=7@e`3Ad=L0d];I0=CDf`3DdmX0dm;I0`3BdMP00`3@d=H0d]7H0=CDfP020=KFg0040=GDfP3Cd]P0
eMCK0=OGg@<0f=SN00P0f=OM0=SHg@3IfMh0fMSN0=SHgP2i^[h01PH600410@X0000000<0=CDe0;:a
]03Jf=`00P3JfM`0103JfMd0fm[M0=[Ig03If=/20=SGf`<0fMOK0P3IemX90=WHfP@0f]WJ0`3KfMX0
0`3Lf]/0gM_L0=gKg0020=gKg0<0gMcL00P0g]cL0=kLg@3Ng=`0g]cL0=gLg03<c<T0d];>0>;Tg@80
iNKO00@0iNKP0>KVh03Vi^00iNKP1P3Uiml40>KWg`030>OXg`3Wj>00inSP00@0inSP00<0inWP0>SY
g`3XjMl00P3XjN001@3Yj>00j>WO0>SYg`3XjMh0inWN00<0j>WN0`3YjMl50>WYgP@0jN[N0P3Zj]h0
1P3Zj]d0j^[N0>[[g`3Rh]H0]kR^05YJE@<0000000P0?3`j0<71^P3Ti=/0h^;I09:AS01]KFT0d];9
06ATGe@00000303oool000X0oooo00@0`/GK0<73f@31`mT0`/GJ0P33a]/20<?7fP080<?6fP30a=P0
_/7F0;foe02o`]H0`<;F0;o2eP30`]H20<73e`070;k0e02k_M40_/3C0;k0d`2o`=<0_l3D0;o0d`02
0;jodP030;k0d`2n`=80_[oB0080_/3B0P2o`=<03P2o`M<0`<7C0<31d`30`M<0_l3B0;o0d@2n`=40
_KoA0;jnd02m_]00_/3@0;fnd02l_Ll0_;g>0P2k_<d01P2i^/X0^;S90;Rhb02h^<P0]kO70;JgaP/0
]kO600H0^;O60;Rha`2h^<L0^;S70;Vib02i^<L40;Via`030;Vjb02j^lT0^k_:0080^k_:00D0_;c:
0;blb`2m_L`0_[k=0;noc@030;nocPD0_l3>0`30`<h20<71cP80`L7?0P32`Ll01032`/l0`l?@0<C4
d@34a=420<C4d0050<G4d@35aM40aLGA0<G5d@36a]801@37am<02@38am<0b<SD0<S8e03;bmL0c]3K
0=3Ag03?dM`0cm3K0=3@f`020<o@f`050<o@fP3>cmX0c/oJ0<o?fP3?d=X00`3@d=X20<o@fP@0cloJ
00<0cm3J0=3AfP3@dMX00P3@dMX30=3Af@80dM7J00@0dM3J0=3@f@3Ad=X0dM7I0P3Ad=T30=3@f0D0
dM3H103Ad=L0103BdMP0dm;I0=CDf`3CdmX30=;Bf@040=3@eP3@cmD0dm;I0=GFg080emON00L0e]GL
0=GDf`3DdmT0e]OL0=3@eP3<c=80dm?H00<0f=WN0P3IfMh00`3De=T0Kfib03Tj>P08000000040041
0@0410@051@D07alOP<0fMSL00<0f]WL0=[Ig@3If=`0303If=/03@3If=X0f]SJ0=[HfP3JfM/0f][K
0=_Jg03JfM/0f][K0=_Jf`3Kf]X0fmWJ0=_JfP3Lf]/01@3Lfm`60=gLg0040=kMg@3Ee=<0f][F0>?T
gP80iNOP103Ui^000`3Ti]l0iNOO0>GWg`030>GWg`80i^OO00<0i^SO0>OXh03Wj>001@3Wj>030>OY
h0<0j>WP00<0jNSP0>SYg`3XjMl0103XjMl0103Xj=h0j>WN0>SYgP3XjMh50>WYgP80jN[N1@3Zj]h0
1@3Zjmh0j^_O0;bl/P0R8Ql02@T900<0000000P061PH05iNFP2DU8h0W9^E09ZJU022PW`0KFeX02h^
;5@00000303oool000X0oooo00D0`/KK0<75f`32aM/0`/KK0<?7f`020<?6f`80`lOK00/0`/GJ0<74
f031`mL0`/CH0<?6fP31aMT0`/GI0<?6fP32aMP0`L?G0<32eP020<73e`070<74e`32a=P0`<7E0;fo
dP2m_]80_KoB0;jodP020;fodP050;jodP2n`=80_/3B0;o0d`2o`M<00P30`M<00`2o`=40_Kk@0;bm
c`040;bmc`080;bmcP2k_<h0^kc=0;Zkc02i^//0^;W:0;Rhb@2g^<P20;Nga`030;JgaP2f]/H0][K6
00D0][K60`2g]lD20;NgaP030;NhaP2h^<L0^;S700D0^KW80P2i^/P02@2j^lT0^kc:0;^kbP2k^lX0
_;c:0;blb`2l_L/0_Kg;0;jnc@020;nocPL0_l3>0P30`<h01031`Ll0`L7>0<71cP32`Ll40<;2c`04
0<C3d@35aM80a<CA0<C4d@<0aLGA00<0a/KB0<O7d`37am<01037am<01@38am<0b<SD0<W9e@3;c=P0
c]3K00<0cm7L00@0cm3K0=3@f`3?d=/0cm3K1@3?d=X20=3@fP80cm3J0P3@d=X:0=3AfP80dM7K00@0
d=7I0=7AfP3@d=P0d=3I0P3Ad=T40=3@f080dM3H00@0dM3G0=3@e`3Ad=L0dM3G0P3Ad=P0103BdMT0
d];I0=;Bf@3BdMT20=7Af0050=;Af03AdMP0d];H0=?DfP3Fe]`00P3Gf=l01`3Gemh0eMGL0=7Bf03A
d]P0^KZo0;bl`P35aL/0103HfMh20=WIgP030=OGg02`/;@0000000L0000000X03`l?04=3A@1PH640
JFU[0:2OXP2l^kl0e=CG0=WIg@3Kf]h0f]WM1P3If=`70=WHf`80fMSJ00<0fm[L0=_Kg@3Kf]`00`3J
fM/20=[IfP030=_JfP3Lf]/0g=_L00@0g=_L1P3Mg=`00`3Ge]D0d];?0>7SgP020>GWh0D0iNKP1@3U
iml01@3Uin00i^OP0>KWh03Vj=l0i^SP00<0inSP0`3WjN000`3XjN00inWP0>SYh0030>SYh0070>WY
h03XjN00iNKL0>SYg`3Xj^00j>WO0>SXg`030>SYg`030>SYgP3YjMh0jNWN0080jNWN0`3Yj]h20>[Z
gP<0j^_N00@0j^_O0=7Aa`1]KFP020P71`000000100Y:BL0T92:0861O00J6QUE000000`0oooo000:
0?ooo`030<?7g033a]`0`lKL0080`lOL2033am/20<;6fP050<;5f@32a]T0`/KI0<?5f@32aMP00P31
`mL01`30`]H0`<7E0;o0e02n`=<0_KoC0;k0d`2m_m800P2l_]401@2m_m40_L3B0;g0dP2n`=80_l7C
0080`<7C00@0_[oA0;bmc`2j_<h0^[c>0P2k_<h02@2k_Lh0^kc>0;^lcP2j^ld0^K[;0;RibP2h^<T0
]kS80;Nga`020;JgaPH0][K60P2f]lH60;NgaP030;RhaP2h^<L0^KW800<0^KW80P2i^/T01P2j^/T0
^k_:0;^lbP2k^lX0^kc:0;blbP80_;c;00<0_;g;0;jnc02o`<h0202o`<h20<30cP@0`L7?0P32`m02
0<?3d0030<C4d@34aM80a<CA0080aLGA0P35aM800`36a]<0alOC0<O7d`030<O7d`050<S7d`38b=@0
b/[F0<_=f@3=cmX0103?dM`00`3?d=/0d=3K0=3@f`020<o@f`030<k@fP3?d=X0cm3J00D0cm3J00<0
d=7K0=3AfP3@dM/0103@dM/00`3AdMX0dM7K0=7Bf`020=3AfP050=7Af`3@dMX0d=3H0=7AfP3@dMT0
0P3Ad=T00`3AdMT0d=7I0=3@f@040=3@f0@0d=3G00<0dM3H0=;Af@3BdMT00P3Bd]T0203@cmL0d=3G
0<o?eP3@cmH0d];H0=?Bf@3DdmT0e]OM0P3Hf=l0203Hf=h0emSN0=SHgP3Fe]`0dmCJ0=OGg@3Ee]`0
f=WN0P3Gf=h40=SIgP070=CDf@1SHfH0ATI702XZ:`0O7b005ADE00`<3@0200L71`0<028R8`26QXP0
/k>g05eMGP0d=3D0BDU;09jNX@3DeMP0g=_N0=[Ig@3If=`0fMSK0P3Hf=/:0=WHf`030=[If`3Kf]`0
fm[L00<0f][K0`3JfMX01@3Kf]X0g=[L0=cKg03Lfmd0g=cL00P0gMcL00@0gn3M0>;SgP3Ui^00iNOP
1@3Ui^060>GWh080i^OP0P3Viml00`3Vj>00inSP0>OXh0030>OYh0040>SYh@3XjN00inWP0>OYh080
j>WP0P3Xj^00103YjN00inON0>SZh03Xj]l40>SYg`040>WYg`3XjMh0j>[N0>SZgPH0jN[N00<0j^[N
0>[[g`3Zjml00P3Zjml00`24Q7d00000000000070000000400l?3P0d=C80;bl]00X:2ED00000303o
ool000X0oooo1P33am`20<;7f`@0`lOK0P33amX01P33a]X0`/KJ0<;6fP33a]X0`/KI0<74e`80_l7E
00L0_KoC0;bndP2m_m80_[oC0;k0e02m_m80_;kA0080^kg@00T0_;g@0;bod@2l_]40_KoB0;k0dP2n
`=<0_l7C0;k0dP2m_m400`2m_]002P2l_Ll0^kc>0;Vkc02i^/`0^K[;0;RibP2h^LT0^;S90;Ngb02g
]lL70;JgaPP0]kO60P2g^<H00`2h^<L0^KW80;Vib0020;Vib080^K[900<0^K_90;Zkb@2k_<T00P2k
_<X30;bmb`030;fmc02n_/d0_l3>00<0_l3>1@30`<h00`30`Lh0`L7>0<71c`030<71c`<0`l?@00<0
`l?A0<C4d@34a=400P35aM401035aM80aLKC0<O7e037am@50<O7d`040<S7d`38b=@0blgH0<kAg0@0
cm7L00D0cm7M0<o@g03@d=`0d=3L0=3@f`030<o@f`80cm3J00@0c/oJ0<o@fP3?d=X0cm3J103@dM/3
0=3@fP060=7AfP3AdM/0dM;K0=;Bg03Ad]/0dM7K0P3AdMX00`3@d=T0dM7J0=7AfP030=7AfP<0dM7I
00L0d=3H0=3@e`3@d=L0d=3G0=3@f03@d=L0dM3H00<0dM7I00T0cloG0<30aP2n_lD0aLG;0=;CfP3C
dmX0dm;I0=CDfP3Ee]d00P3Gf=l20=OHgP060=KFg03Ee=X0eMKL0=OHg@3HfMh0f=SN0P3Gf=h05`3H
f=h0f=WN0=SIgP3HfMh0fMWN0=SIg@3Gf=d0emOL0=GEfP3De=T0dM7F0<o?d`3=cM40bl_?0<k>dP3>
cm<0VYZM05EEEP0P8200FU]L0<G6b03Lg>00f][M0080fMSL00<0f=SL0=SHf`3Hf=/01`3If=/00`3I
f=X0fMSK0=WIf`040=[If`050=[Jf`3Jf]X0f][J0=[JfP3Kf]/01@3Lfm`20=cLg0@0gMcL00@0gMcM
0>3OgP3Uin40iNOQ103Ui^020>CVh0@0i>OP00<0hN?L0>3QfP3Vin000P3Vin020>KXh080inSP0`3W
jN020>SYh@80inWP00P0j>WP0>SZh03Xj^00j>[P0>;RfP2a/J/0[ZnW0>;SfPD0j>WO0`3Yj]l00`3Y
j]h0jN[O0>WZg`030>WZg`060>;Sf037b;h0alRn0:j_Y@2PX9P0ATI2HP00000<0?ooo`002P3oool:
0<?7g0D0`lOK00D0`lOJ0<?6fP33a]X0`lKJ0<33e`020;fod`<0_;kA00@0_[oC0;o2e@2m_m80^kgA
0P2j_<l01@2k_Ll0^kg@0;fnd@2m_m80_/3B00<0_l7C00P0_/3B0;o0dP2o`=80_l3B0;bnd02j^ld0
^;W;0;RhbP80]kS900@0]kS80;Ngb02g]lL0][O71P2f]/H50;JgaPD0]kO600@0]kS60;Rha`2h^LL0
^;W80`2i^LP01P2i^/P0^K[90;Vjb@2i^lT0^[_90;^lbP80_;g<00<0_Kk<0;joc@2o`<h00`2o`<h8
0<30cP040<71c`31`/l0`L;?0<;2c`80`l?A00<0`lCA0<?3d@34a=400`35aM800`35a]80a/KC0<K7
d`050<O7d`050<O7e038b=@0bL_F0<g>fP3?dMd00`3?d]d20<oAg@040<oAg03?d=`0d=7L0=3Ag0<0
cm3K00H0cm3J0<k?fP3>cmX0c/oJ0<o@fP3?dM/40=3Af`80d=7J0P3AdMX20=7Af`80dM;K0P3@dMX0
0`3@d=T0dM7J0=3AfP040=7BfP030<o@f03@d=T0dM7I00@0d=3H0P3@cmL03@3Ad=P0dM7I0=7Af03A
dMP0cloF0;noa@3GfMl0f=[P0=OIg`3De=/0d];I0=?CfP3Fe]d00P3Gf=l20=OHgP040=GEf`3Cd]L0
e=CI0=KGg@@0emSN00<0f=SN0=SIgP3HfMh00`3HfMh00`3HfMd0f=SM0=WHg@050=WIg@0<0=WIgP3I
fMd0e=CH0:b/[`13@d@0?3dm09JGV@3<cM00f][N0=WJg@3JfM`0fMSL0P3IfM`0103If=`0fMSK0=WH
f`3If=`40=WHf`80fMWK00<0f]WK0=[Jf`3Jf]/01@3Jf]/00`3Kfm`0g=_L0=cKg@020=cKg0@0g=cL
103Mg=`0103Og]d0i>OP0>GVh03Ui^040>CVh080i>OP0`3Uin00103Ti]l0h^CM0>GWh03Vin020>KX
h0030>OXh03Vj>00i^SP00<0inWP00@0inWQ0>SYh@3WjN00inWP0P3Xj^420>SZh0060<g>aP0R8R40
;Rh]0;k0]`3WjMl0j>WO103Xj]l60>WZg`030>[[g`3Ui]/0L75/00800`<3I@00000<0?ooo`002P3o
ool00`32amd0`lSM0<?8g@020<?7g0040<?8g033b=d0`lOL0<;7g0T0`lOK00l0`lOJ0<74f02o`MH0
_l7F0;fod`2m_m80_KoC0;o1e@30`]H0_L3C0;bnd@2k_M00^[c?0;^md02l_]400P2m_m800`2n`=80
`<7C0;o1e0020<31e0060;o1d`30`M<0_/3A0;^lcP2h^L/0]kS:0`2g^<T00`2f]lP0][O70;Jga`02
0;JfaP/0][O6102g]lH0102g^<H0^;S70;Ria`2h^LL30;Vib0090;Vjb02i^/T0^K[90;Vjb@2j^lT0
^kc:0;bmc02m_/`0_Kk=00<0_/3>0P2o`<h00`30`<l0`<7?0<31c`040<31c`030<71c`31`]00`L;@
0080`/;@0P33`m420<C4dP040<C5dP35aM80aLGB0<G6d`<0a/OD00P0a/OC0<O7e037am<0alOC0<O7
e038b=D0b/gI0<g?fP@0cm7M0P3?d]d30<oAg@040<oAg03@dM`0cm7K0<oAf`80cm3K00@0cloK0<k?
fP3?cmX0cm3J0P3?dM/30=3Af`D0d=7J0P3@dM/02@3AdM/0d=7K0=3AfP3@d=T0d=7J0=7BfP3AdMX0
dM;J0=7AfP040=7Af@040=7@f03@d=P0d=3H0=7@f080d=3H00H0clkF0<_;d`2n_/D0VYZO08J6R`30
`LL20=SJh0050=OIh03Ee]h0e=CK0=GEg03Femh00`3Gf=l01@3Gf=h0e]GK0=CCf@3De=X0e]KL00D0
emSN00<0f=SN0=SIgP3HfMh00P3HfMh00`3HfMd0fMWM0=WIg@050=WIg@80fM[N00T0f][N0=SIg03=
cM40];Bg09NGV@2FUiT0/[:e0=SIg03Kfmh00P3IfM`20=WHf`<0fMSL0`3IfM`30=WIf`80f]WK1P3J
f]/0103Kfm`0g=_L0=cKg03Lfmd20=cKg0030=cLg@3Lg=`0gMcL00@0gMcL00@0g]kL0>CVh03Ti^40
i>KQ0`3Ti^060>CWh0040>;Tg@3Ph]/0iNOP0>KWh080i^SP00<0inSP0>KXh03Vj>000`3WjN000`3W
jN40j>WQ0>SZh@030>SZh@090>OYh03<cLH0MGEa00l?3P0E5A@0GUiJ0:JWX03?dLP0i^OM00@0j>[O
1@3Yj]l00`3Vim`0YJJN02h^;01W000000`0oooo000:0?ooo`030<;7g@33b=d0`lSM0080`lOL00@0
`lSL0<?8g@33am`0`/OL2@33am/03`33amX0`LCH0;o1eP2o`MH0_KoC0;fodP2m_m<0_l7E0<32eP2m
`=<0_;kA0;^md02j_<l0^kg@0;bnd@020;fodP030;k0dP30`M<0_l7D0080`<7D00H0_l7C0<31d`2n
`=40^kc>0;Rib`2g^<X30;Nhb@030;Jgb02f]lL0][O70080][K62`2f]lH40;NgaP040;NhaP2h^<L0
^;W70;Ria`<0^KW800T0^K[80;Vjb@2i^/T0^K[90;Zkb@2k_<X0_;g<0;fnc02m_/d00`2n`<h20;o0
cP030<30c`30`Ll0`<7?00@0`<7?00<0`L7?0<72d031`]000P32`]020<?3d@80a<CB00@0a<GB0<G5
dP35aM80aLKC0`36am@02036am<0alOD0<O7d`37am<0alOD0<S8e@3:cMT0cLoJ103?dMd20<oBg@<0
cm7M00@0cm7L0=3Ag03?dM/0cm7K0P3?d=/0103?cm/0c/oJ0<o?fP3?d=X20<oAf`<0d=7K1@3@dMX2
0=3Af`090=7Af`3@dM/0d=7J0=3@f@3@dMX0dM;J0=7AfP3Ad]X0dM7J00@0dM7I00@0dM3H0=3@f03@
d=P0dM3H0P3@d=P01P3?c]H0bl_C0;jna@2JVYl0QXJ;0<31a`80f=[P00D0emWP0=GFgP3De=/0eMGL
0=KGgP030=OHg`050=OHgP3FeM/0e=?I0=CDfP3Fe]`01@3Gf=h00`3Hf=h0f=WN0=SIgP020=SIgP03
0=SIg@3IfMd0fMWM00D0fMWM0P3If]h02@3Jf]h0f=WL0<g=d@2d];L0UiNI09JGV@2b/[D0f=WL0=_K
gP020=WIg080fMSK0`3If=`30=WIg0<0fMWK0P3JfM/60=[Jf`040=_Kg03Lfm`0g=_L0=cKg@80g=_L
00<0g=cM0=cLg03Mg=`0103Mg=`0103Ng]`0i>KP0>CVh@3Ti^430>CVh0H0i>OP00@0h^CM0>3Rf`3U
in00i^OP0P3Vj>000`3Wj>00i^SP0>KXh0030>OYh0030>OYh@3XjN40j>[Q00<0j>[Q00T0inWP0<c=
aP1eMG403`l>01DE501NGUX0YZNP0<oAb03Vimd0103Xj]l50>WZg`030>KWg02UYYh0;Rh/06L00000
303oool000X0oooo00@0`/KL0<?8g@33b=d0`lSM0`33am`00`33b=`0`lOL0<?7g0030<?7g0030<C7
g034b=`0`lSK00<0`lOK00d0`/KJ0<;4f032a=P0`<CG0<33eP30a=L0`LGH0<74e`2n`M@0_;kA0;^m
d@2l_]40_/3C0080`<;E00X0`<7D0<33e@31`mH0`L?E0<32e02o`M<0_Kk@0;ZlcP2i^l`0^;[;0P2g
^<X20;Nhb@030;Nhb02f]lL0][O700<0][O71`2f]lH50;NgaP@0]kS60P2h^<L00`2h^LL0^;W80;Vi
b0030;Vjb080^K[900<0^K_90;^lbP2l_L/00P2l_L/01@2m_/`0_[o=0;o0cP2o`<h0_l3?00<0`<3>
00<0`<7?0<71c`31`Ll00`31`Ll00`31`]00`/;@0<;2d0020<?3d0050<C4dP34aM80a<GB0<C5dP35
a]<01@36am@30<O7d`050<O7e038b=D0c<gI0<k@g@3?d]h01`3?d]d00`3?dMd0cm7L0=3Ag0020=3A
g0050=3@f`3?d=X0c/oJ0<k?fP3>d=X00P3?d=X0103?dM/0d=7K0=3Af`3@dM/20=3@fP@0d=7J103A
dMX01P3@d=X0dM7J0=3AfP3Ad]X0d=7J0=3@f@80d=3H00<0d=3I0=7Af@3AdMT00`3AdMT20=3@f006
0<W9d@2d]K/0VIVN08n@U@2XZK00dmGK0P3GfN00103Hf^00emSO0=OFgP3Femh40=OHg`050=OHgP3G
emd0eMCK0=GEf`3Femd01@3Gf=h00`3GfMh0f=WN0=SIgP030=SIgPD0fMWM00D0fMWN0=WIg@3IfMd0
fMWM0=WIgP020=[JgP080=WIg@3:blh0UiNJ04E5AP2k_;h0f]_O0=[JgP3Kf]h20=[Ig0<0fMWL1@3I
fM/00`3JfM/0f][K0=[Jf`020=[Jg0<0f][K00<0fm[L0=cKg03Lfm`00P3Lfm`00`3Lfmd0g=_L0=cK
g0040=cLg0040=gLg03MgM`0g]kM0>?Vh@<0i>KP1@3Tin030>GWh0030>?Vg`3TiMh0i^OP0080i^OP
103Vj>000`3VjN00inWP0>OYh0050>OYh@030>OYh03KgMD0BT]800D0000000<06a/J0<C6_@3XjMl0
0`3Xj^001`3Yj]l0j>[O0>SZg`3XjMh0inSN0=?Eb`17Ad@0J000000<0?ooo`002P3oool00`31aM/0
`/OL0<?8g@020<?8g@040<?7g033b=`0`lSL0<?8g0@0`lOL0P33am/00`34am/0`lOK0<?7f`040<?7
f`0:0<C7f`33am/0`lOJ0<?7fP32a]T0`<?F0;fodP2n`=<0`<;E0<;5f080a<KI00T0`lGH0<;4e`32
a=L0`/CG0<73eP2n`=80^[c>0;Rjc02h^LX00`2g^<X0102g^<P0][O80;Jgb02f]lL20;JfaPh0][O6
00P0]kO60;NhaP2g^<H0]kS60;Nha`2h^<L0^;W70;Rib0D0^K[800<0^K[90;Vkb@2k_<T00P2k_<X0
1P2k_LX0_;g;0;fnc02n_ld0_/3>0;o0c`D0`<7?00L0`L7?0<71d031`]00`L;@0<;2d032`m00`/?A
0080`l?A00D0a<GB0<G5d`35aM80a<GB0<G6d`040<K7e0@0alOC00D0alOD0<S8e@39b]L0c/oK0=3B
gP040<oBgP@0cm;M00@0cm7L0=3Ag03@dM`0d=7L103?d=/20<o@fP030=3@f`3@dM/0d=7K0080d=7K
00<0d=3J0=3AfP3@dMX0103@dMX30=7AfP80d=7J00P0d=;J0=7AfP3@dMX0d=7I0<o?f033`l/0`<38
0<o?f0@0dM7I00T0c/gF0<k>eP2m_L@0Z:R^0<O9d03Ce=`0e=GM0=CDg03Femh00`3GfN050=OHg`07
0=KHg`3Ff=h0e]SN0=KGg@3Fe]d0emOM0=OHgP020=OIgP<0f=WN103Hf=d00`3HfMd0f=SM0=SHg@09
0=WIg@80fM[N00D0f][N0=KFfP30`<<0`lC80=WIg@020=cLh0060=cLg`3Kfmh0f]WL0=[Ig03IfM`0
f]WL0P3JfM/00`3JfM`0f][L0=_Kg@030=_Kg@030=KFf03Cdm@0fm[L0080fm[L103Lfm`00`3Lg=`0
g=cM0=cLg0050=cLg0030=gMg@3Ng]d0hnKQ0080hnKP00<0i>KP0>CWh03Tin001`3Tin000`3Uin40
i^OQ0>KWh@020>KXh0030>KXh@3Vj>00i^SP00@0inWQ00L0fM[C0;Be[`2c/jh0[JjX0:RYX`1mOWT0
7alM00D0000000@02PX:06a]J035akl0hN;I0P3Yjn001`3@d/T0/[B/0:b]Y@2OX9P0T96:07=dK`0O
81h0J000000<0?ooo`002P3oool00`30a=X0`/OL0<?8g@040<?8g@80a<SM1033b=d01033b=`0a<SL
0<C8g034b=`80<?8f`060<C8f`34am/0`LCG0;o2e@30`mH0`/GH1@34a]T01P33aMP0`L?F0;o1e02l
_]00^K_=0;Nib`@0]kS:00<0][O80;Jga`2f]lL00P2e]/L00`2f]lL0][O60;JgaP020;JgaP030;Jg
a`2f]lH0][O600@0][O600<0]kO60;NhaP2g^<H00`2g^<H01@2g^<L0^;W80;Rib02h^LL0^;[800H0
^K[800<0^K_90;Zlb@2k_<X00P2k_<X0102l_L/0_Kk<0;jocP2o`<l20<30c`030<31c`31`Ll0`L7@
0080`L7@0P31`]001032`]00`/?A0<?3d@34a=820<C5dPD0aLKC00@0a/KC0<K7e036am@0a/OD1@37
am@01P38bMD0b/_G0<k?g03@dmh0cm;N0=3BgP80cm;N103?d]d0103@dM`0cm7L0<oAg03@dM`20<o@
f`050<oAg03?dM/0cm3K0<k@f`3?d=/00P3@dM`50=3Af`040<o@f`3?d=X0cm3J0<o@fP80d=7K0P3@
dMX0203@d]X0d=7J0=3AfP3@d=X0d=7J0<k?e`2k^l<0`<39103@d=P02P3@d=T0c<cD0<k>e`39b]80
cLkE0=?Df`3Ce=`0d]?J0=?Df`3Ee]h20=OHh0H0emSO00@0e]SO0=KHgP3Ff=h0e]SN0`3Gf=h30=OI
gP030=SIgP3Hf=h0f=WN00@0f=WN1P3IfMh40=WIg@80fMWN00X0fM[N0=[JgP3Jf]h0f][N0=WIg@3H
fMd0fMWM0=cLg`3Lfml0fm_N0P3Jf]d00`3JfM`0fMWL0=WIg0020=[Ig080fm_M00H0fm_N0=cKgP3L
fmh0f][L0=CCe@3Jf]/20=_Kg0D0g=_L1P3Lg=`20=gMg0030=gMg@3SiN00i>KQ00H0i>OQ0P3Tin04
0>GWh080i^OP0P3Vj>000`3Vj>40i^WQ0>OYh@030>OYh@030>?TgP29RHD0000000`0000000D0<c<a
09nQVP31`[X0`L:j05YKE`1^000000`0oooo000:0?ooo`030<76f`32am`0`lSM00X0`lSM00<0`lSL
0<?7g033b=`01`33b=`20<C8g080a<SK00D0`lOJ0<75f032aMP0`/KI0<?7fP020<C7fP080<C8fP34
amX0`/GG0;g0dP2j_Ll0^K_=0;Rjc02g^L/40;NhbP030;Jgb02e]lL0][O700`0][O70P2f]lH60;Nh
aP030;Nha`2h^LP0^;W80080^;W800<0^KW80;Vjb02i^/P00`2i^/P00`2i^lT0^[_90;ZlbP020;Zl
bP030;^mbP2l_L/0_ko=00D0`<7?0P30`M020<71d0050<72d033`m80`l?B0<C5d`35am@00P36amD0
0`35a]@0aLKC0<G6d`020<G6d`040<K7d`36am@0a/OD0<K7e0@0alOD00@0alSE0<W9eP3;cMX0cm7N
0P3@dml20=3CgP030=3BgP3?d]h0cm;N00<0cm;M00H0d=7M0<oAg03@dM`0cm7L0<oAf`3?dM`20<o@
f`040<k?f`3>d=/0cm7L0<oAg0D0d=7K00D0cm3K0<o@fP3?d=X0cm3J0=3Af`030=3Bf`030=7Bf`3@
dM/0d=7J00@0d=7J00<0dM7J0=3@f@3?cmP00P3?cmP03@3@d=P0cm3H0=7BfP3Ad]X0dM;I0=;Bf@3B
d]X0dM;I0=?Dg03Ff=l0emWP0=KGg`3Geml00`3Gf=l20=OIg`@0e]SO1@3Gf=h00`3GfMh0emSN0=SI
gP060=SIgP80f=SM0P3IfMh01P3If]l0fM[N0=SHg@3Hf=d0f=WM0=WIgPD0f][N00@0fM[N0<W9c@32
`/H0g=cP0P3Lg=l20=_KgP050=_Jg@3Jf]d0f][M0=[Jg03Kf]d00`3Kfmh30=cKgP030=[Jg03Kf]`0
fm[L00<0fm_L103Lfm`00`3Lg=`0g=cM0=cLg0040=cLg0050=gMg03Si>00hnKQ0>?Vh@3Sin402@3T
in000`3Uin40i^OQ0>KWh0020>KXh0080>KXh@3VjN40inWQ0>OYh@3WjN80b/_50861OP0^;Rd=0000
0005018B4P0i>CL0ADE204E5@P0P81l0KP00000<0?ooo`002P3oool20<?8g@80`lWM00<0`lSM0<?8
gP33bMh00`33bMh30<C8g@060<?8g@33bMd0`lSM0<?8g@34b=d0`lSL2034b=`00`34b=/0`lOK0<C8
f`020<C8f`090<74e`30a=L0`lOI0<?7f@30`mD0^[c?0;Rjc@2h^/`0^;[;0080]kS;0P2g^<X00`2g
^<T0][O80;Ffa`020;Ffa`<0]KO70P2f]lL90;JgaP<0][S60P2g^<H00`2g^<L0]kW70;Nia`020;Ri
a`030;Rib02i^/P0^K[800<0^K[80P2i^lT0202j^lT0^[c90;Zlb@2j_<X0^kg:0;fnb`2o`<h0`<7?
1@30`M001`31`M00`L;@0<;3d@33`m80`lCB0<G6e035a]D00P35a]@01035a]D0aLKD0<G6e035a]@3
0<K7e0<0alOD0P37b=D02`38bMD0bLWF0<S9eP36bMD0`lKB0;g0b`2l_lX0^K_60:b^^030a<h0c]7M
00<0cM3K00<0c]3L0<oAg03?dM`00P3@dM`20<oAg080cm3K00@0c]3K0<o@f`3?dM`0cm7L0P3?dM/2
0=3Af`80cm3J00T0cm3K0<oAf`3@dM`0dM7K0=3AfP3@dM/0d=7J0<o@f@3@d=X00`3@dMX30=7AfP08
0=3Af@3?d=P0cm3H0=3@f03@d=T0dM;K0=?Eg@3Cdm/20=7BfP080=;Cf`3Ce=`0e]ON0=OIh03Ff=l0
e=KM0=GFg@3Femh20=OHg`@0e]SO0P3Gf=l80=OHgP060=SHgP3HfMh0f=WN0=SIg`3Hf]l0fMWN0P3H
fMh20=WIg`80fM[O00@0f=WM0=SHg@3HfMd0fMWN0P3JfMh40=[JgP040;o0a01aLW@0`/?60=OHf`<0
g=gP00D0g=cO0=_KgP3Kfmh0fm[M0=_Kg@030=_KgP80g=_N00D0f][M0=KFf03IfM/0fm_M0=_Kg005
0=cKg0L0g=cL00D0g=gL0=gMg03Ri>00hnKQ0>CWh@050>CWh0@0i>OQ00@0iNOQ0>KWh@3Vin40i^OQ
0P3Vj>001`3Vj>40i^WQ0>KYh@3SiMh0_Kji06e^J`0?40l0P@00000<0?ooo`002P3oool30<?9gP03
0<C9gP33b=h0`lSM0080`lSN0`33b=d30<C8g@<0`lSM1@33bMd01034bM`0`lSL0<?8g033b=`40<C8
g00:0<C9g035bM`0aLWL0<G9g034bM/0`LKH0;g0d`2i^lh0^;[<0;Rjb`80]kW;00H0]kS;0;NhbP2g
^<X0]kS:0;Jgb02e]/L20;Fga`X0][O7102f^<L40;Nha`030;NhaP2g^LL0]kW80080]kW80P2h^LL0
1@2h^/P0^K[80;Vjb02i^/P0^K_800D0^K_900@0^Kc90;Zlb@2l_L/0_l3>1030`M020<72d0070<72
d@31`m40`/?A0<?4dP34aM<0aLKD0<C6e0020<G6e0040<G7e@36amD0aLOD0<G7e0<0a/OD01X0alOD
0<O7e@37b=D0alSF0<O8e@35aM80[Jfh05eNH`0T92L09RLY02DU:00];Bl0<S<f030b=01MGV<0T9:I
08nAV@2:S9@0TYBM09nQZ@2/[kT0_l7<0<W;eP3<c]P0c]3K0<oAg080cm3K00<0c/oK0<k@f`3@dM`0
0`3@d]`03@3@dM/0cm3J0<k?f@3>cmX0cm3J0<oAf`3Ad]`0d=7K0=3@fP3?d=T0`/?<0;o0b03>c]P0
1P3@dMX0303AdMX0d=7I0=3@f@3AdMT0dM7J0=;Cg03Eeml0eMKN0=;Cf`3Ad]X0dm?K0=KGgP80emWP
00D0eMKN0=;CfP3Ce=/0eMKM0=OIg`040=KHg`80emSO0`3GfMl30=OHgP030=OIgP3HfMh0f=WN00<0
f=WN00L0f=SN0=SIgP3HfMh0f=WN0=WJg`3If^00fM_P0080fM[O00@0f=WM0=SHg@3Hf=d0f=WM0P3I
fMd02@3If]h0f][N0=[JgP3Jf]h0emSL0:>SYP1iNW`0VY^N0<W:c@020=_KgP040=cMh03Lg=l0g=cO
0=cLgP@0fm_N00<0g=cN0=_KgP3Kfmd00P3Kfmd60=_Kg080g=_L1P3Lg=`00`3LgM`0gMgL0>;Tg`02
0>?Vh0030>CVh03Tin00i>OP00<0i>OP00D0i>OQ0>CWh03Tin00i>OP0>GWh@020>GWh080i^SQ0P3V
jN401@3Ph]/0QXN303lo?P0L7A`010@408400000303oool000X0oooo00<0`lWN0<C9gP34bMh01034
bMh00`34bMd0`lSM0<?8g@020<?8g@030<?9g@33bMh0a<WN00<0a<WN2@34bMd50<C9g0<0aLWL00<0
`lGI0;fodP2i^lh00P2h^/`20;Nib`@0]kS:00<0][O90;Fga`2e]lL00P2e]lL80;Jga`H0][S7102g
^<L00`2g^LL0^;W80;Rib0020;Rib080^;[80`2i^/P50;Vkb@80^Kc900<0^[c90;bmb`2n`<h01@30
`M001`31`]40`L?A0<73d@32`m40`lCB0<G6e036amD00`35a]@01035amD0aLOD0<G7e035am@30<K7
e00A0<K7e@37b=D0alSF0<O8eP35a]@0_Kk:0;>c_P2b/kh0];G00;Fe`@2^[kX0XZ:/0820R@1FEEX0
<S<g028S9@0@4A800`071`L0300<30`06QXL02h_<@13@dL0RHZA0<c>f03?dM/0cm3K0<k@f`3?d=/0
cm7L0=3Bg080cm7K00H0d=;L0<oAfP3>cmT0c]3J0<o@fP3?dM/40=3Af`80cm3J103@dMX50=7AfP07
0=7Af@3Ad]X0dM;K0<oAf@3De]h0eMSP0=CEg@020=?Dg0040=GGgP3FfN00e]WP0=KGgP80e=GM00<0
eMON0=KHg`3Ff=l00`3Ff=l00`3Gf=l0emWO0=OIg`020=OIg`80emSN0P3GfMh40=SIgP@0f=SN00<0
f=WN0=WJg`3Ifn000`3If]l01P3HfMh0f=SM0=SHg@3HfMd0fMWM0=WIgP@0f][N00D0f]_O0=SIg@2I
VYd02@T901DE5@020<30a0@0g=gP00<0fmcO0=_KgP3Kfmh00P3Kfmh0103Kg=h0fm_N0=_KgP3Kfmh3
0=_Kg@80g=_M103Lg=`40=cLg@80g=gM00<0gMkL0>;Uh03Sin40203Tin420>CXh@0:0>CWh@3Vin40
iNSQ0>GXh@3Vj>80i^SQ0>GXh@3RiMh0^;Zd01/L6h@00000303oool000X0oooo00<0^KkB0<?9gP33
bMh01P34bMh30<?9g@L0a<WN1`34bMd80<G9g@070<G:g@32a]T0_;oB0;VkcP2h^L`0]kW;0;Jhb`02
0;JhbP<0][S900<0]KO80;Fga`2e]lL01P2e]lL60;Jga`D0][S70P2f^<H00`2g^<H0]kW70;Nib003
0;Nib080^;W800D0^;[80;Vjb02i^lP0^K_90;VkbP020;Vkb@<0^Kc900@0^[c90;bnbP2m`<d0`<7?
0`30`M001P30`]00`L?A0<73d@31`m40`/?A0<C5d`D0a/OE0P35amD20<K7e@80a/OD00<0alOE0<O8
eP37b=H00P37b=H01@34a]<0a/OD0<K7d`36a]<0aLKC0080aLKB00H0a/KC0<S:eP3?d]h0e=WT0=?H
h`3AeN020<kBgP030<kCgP3?e=l0bloI0080b<cE00<0a/WC0<g>f@3?dM/00`3>d=/0203?dM/0c]3K
0<k@fP3>d=X0d=;L0=3Ag03>d=X0cm3J1@3?d=/02@3@dM/0d=7J0=3AfP3@dMX0d=3I0<o@f@3@d=T0
d=7J0<oAfP020=3AfP0@0=3Af@3@d=T0d=7I0<k>e`39bm80_l780<74b`3Be=`0e=KN0=CEg@3Eemh0
emWP0=OHh03Gf=l0eMOO0=GGgPP0e]SO00<0e]SN0=OHgP3Gf=h0203Gf=h20=SHgP060=OHgP3Hf=h0
f=WN0=SIgP3If]l0f=[O0P3IfMh01@3If]l0fM[N0=WIgP3IfMh0f=WN0080f=WM00P0fMWM0=WJgP3I
fMd0f][N0=[Kg`3;c<l0DE5B01dM7P80W9fO00@0g=gQ0=cMh03LgN00g=gP2@3Kfmh20=_Kg@D0fm_L
00@0fmcL0=cLg03Lg=`0g=cM0`3Lg=`01@3LgM`0gMgM0>;Th@3SiN40hnOQ00<0i>OQ103Tin030>CW
h@090>GWh@3Uj>40i^SQ0>KXhP3Ig=D0UINB07anN@15AD<02@T908@00000303oool000X0oooo00@0
PHJD0<?9gP33bMh0`lWN1034bMh00`34b]h0a<WN0<C9gP040<C:gP<0a<[M1@34bMd70<G9g@<0aL[M
00L0`lSK0<34e`2n`M@0_;oA0;VkcP2g^/`0][W;0080][S:102e]lT00`2e]lP0]KO70;Fga`030;Fg
a`H0][O7202f^<L20;Nha`80]kW7102g^LP00`2h^LP0^;[80;Rjb0020;Vjb080^K_900<0^K_:0;Vl
bP2i_<T00P2i_<T0102j_<X0^kg:0;foc@30`M020<32d@060<72d@32`m80`/?B0<;3dP33a=80aLKD
1035amD20<G7e0<0aLOE00D0a/OE0<K7e036am@0a/OE0<O8eP020<O9eP050<O8e@37bMH0a/OD0<G6
e035a]<01035a]800`36am@0c]7M0=KJi`050=KJiP0<0=GJiP3Ef^D0eM[U0=GJi@3EfN<0dmGP0=3B
g@3?dM`0c]3K0<o@f`3?dM/0c]3K0P3>d=X01@3?d=/0d=;L0<oBf`3@dM`0cm7L00<0d=7L00D0d=7K
0=3Ag03Ad]/0d=;K0=3AfP030<o@f@@0d=7J00L0d=3I0<o@f@3?d=T0d=3I0=7BfP3?d]T0dmGM0080
e]SP00D0e]OO0=KHh03GfN40emSP0=KIh0020=KHh0T0e]SO0P3Gf=l20=OIg`030=OHg`3GfMl0f=WO
0080f=WO00<0emSN0=SIgP3HfMl0103HfMh01P3IfMh0f=[O0=WJg`3If]l0f]_O0=[Jg`80fM[N00L0
f=WN0=SIg@3HfMd0f=WM0=WIg@3If]h0f][N0080f]_O00@0b/_>071aL`1aLG<0LG5c0P3LgN420=cM
h0040=cLg`3Kg=l0fm_N0=_KgPD0fmcN00<0fmcM0=_Kg@3Kfmd00P3Kg=d00`3Lg=d0g=cL0=cLg002
0=cLg0030=cLg@3LgMd0g=gM0080g=gM00@0gMgM0>7RhP3Si>80hnKQ2`3Tin401@3Tj>40iNSQ0>?V
g`2TYZ400`<308L00000303oool000X0oooo00<0<S@i07UmRP33bMl00P33bMl20<?9gP030<C9gP34
b]h0a<WN00<0a<WM1034b]d00`34bMd0`lWM0<?9g@020<?9g@80a<WM0180aL[M0<G;g@35b]d0aL[M
0<G9g@34bM`0aLWL0<G;g@34b]`0`LGH0;bodP2h^ld0][W;0;Rkc@2g^L/0][S;0;JhbP2e^<T40;Fg
b@030;Fgb02e]lL0]KO700@0]KO7102f]lL90;Jha`040;Nha`2g^LL0]kW70;Nia`80]kW81@2h^/P2
0;Vjb0<0^;_90P2i^lT20;Vlb@040;Zlb@2k_LX0_Ko=0<31d080`<;A00D0`L?B0<;3dP32`m80`/CC
0<?5e0090<G7e@040<K8e@36amD0a/OE0<K7e080a/OE00<0a/OD0<K6d`37am@00`36am@00`35a]<0
aLKB0<G6dP020<G6dP0=0<C5d@2n_l/0][[50;Bg`P2d^<<0_/7<0=;FhP3=dM`0b<gH0=;GhP3@eMl0
cm?N0=?GhP020=3DgP80cm7L00<0cm7K0<k@f`3>d=/00P3>d=X01P3?d=/0d=;L0<oBg03@d]`0d=;K
0=3Bg080d=;M0`3Ad]`01P3@dM/0d=7J0<oAfP3?d=T0c/oI0=3Bf`<0d=7J00T0d=3I0<o@f@3?d=T0
cm3I0=3AfP3?d=P0c<gE0=;Eg@3GfN400P3FfN401@3Gf>40e]WP0=KHh03Ff>00eMSO0080e]SO0`3F
fMl20=OIh080e]SO203Gf=l40=SIg`030=SHgP3Gf=h0f=WO00D0f=WN0`3If]l20=SIgP@0f=WM0P3I
f]h0103Jf]h0f]_O0=[Kg`2i^[h206e^K`0408^<SP3Gf=`0g=gP0=cMh080g=cO00@0fmcO0=_LgP3K
g=h0fm_N103Kg=h0103Kg=d0fm_M0=_Kg@3Kfmd20=_Lg080fmcM0`3Lg=d30=cMg@040=gMg@3QhN80
f]_K0>7Th@80hnGR00<0i>KQ0>CWh@3Tin400P3Tin430>CXh@060>GXhP3Uj>40e=K?07anN@0i>cP0
0@41Q`00000<0?ooo`002P3oool00`0E5AP0<c@j0<?9g`030<?9g`040<C9gP34bMl0a<[O0<C:g`H0
a<[N00@0a<[M0<?9g@33b=d0`lSM0P33bMd01@34bMd0a<[N0<G;gP35bmh0`lWL0080`/OJ00T0a<SK
0<?8f`32amX0`lSK0;Fib`2e]lX0];O90;2ca@2c]/P00`2f^<X00`2e^<X0]KS90;Fhb@030;Fgb0T0
]KO70P2f]lL:0;Jha`80]kW700<0]kW80;Njb02h^/P0102h^/P0102i^/P0^K_80;Rkb@2h^lX20;Rk
b@80^Kc90P2j_<T01@2k_LX0_Ko=0<31d030`]40`L;A00<0`/CC00<0`lGC0<G7e@35amD01`35amD3
0<K8eP030<K8e@36amD0aLOD0080aLKC0`36am<20<K7e0<0aLKC0P35a]804@36am<0c<oK0=7Eh@3;
d=/0a/_F0<c@g03Be^80cM7L0<oCgP3DfN@0aL[D0<O<eP3EfN@0c=3J0<?6d039cML0c]7K0080cm3K
00D0c]3K0<k@fP3>d=X0cm7K0<oBg0020<oAf`040<oBf`3@d]`0dM?M0=7Cg@80dM;L00L0d=;L0<k?
f@3?d=T0d=;K0<oAf`3@dM/0d=;K0080cm7J00<0d=7J0<o@f@3?d=T00P3?d=T20=3Af@060=3AfP3C
eMh0e]WQ0=KIh@3Ff>40e]WP1P3Ff>030=KIh080emWP00<0e]WP0=OIg`3GfMl00P3Gf=l40=OIg`03
0=OHg`3HfMl0f=WO0080f=WO0P3Gf=h0103HfMl0f=[P0=SIgP3Hf=h20=SIgP050=WIgP3If]l0f=WN
0=OHg@3HfMh01P3HfMd0103Jf]l0f]_O0=[Kg`3Gf=`20:6RY@0404A4AP3?dM<0g=gP0=cMh@80g=cP
00@0fmcO0=_KgP3Kfmh0fm_N1@3Kg=h80=_Lg@030=cLg@3LgMd0g=gM0080g=gM00<0gMkN0>7Rh`3P
hN800P3Rhn<00`3Shn<0hnGR0>CWh@020>CWh@<0i>SQ00@0i>OQ0>GWhP3Oh]`0O7iiRP00000<0?oo
o`002P3oool2000000040:>Y^P2d^/h0_L?H0<?9gP@0`lWO00<0`l[O0<C:g`34b]l01@34b]h40<C9
gP030<C:g`34bml0a<_O00<0aL_O00`0aL[N0<C:g@32amX0[;320:fa``21Q940SI2M09fO/02XZk`0
];K80;JhbP2e^<X40;Fgb@H0]KO8102e]lL00`2f]lL0][S70;Jha`080;Jha`80][W71@2g^LP30;Nj
b080^;[80`2i^lT20;RkbP80^Kc90P2j_<T02P2j_LX0^kg:0;g0c@30`M00`L?B0<?5e034a]@0`lGD
0<C5e034a]@80<G7e@040<G8e@36b=H0a/SF0<K8eP80a/OE00<0aLKD0<C6d`35a]<00`36am<20<K7
e0D0aLKC00D0a/OC0<[<f@3AeN40dmOS0=CIi@020=GIi@040=GIi03EfND0eMWT0=CIi080eMWT00@0
e=WT0=GHh`3AeMl0cm7L0P3>d=/40<o@f`030<oAf`3?d]`0cm;L0080d=;L103Admd02P3@dM/0cLkG
0<oAfP3>dMX0alWB0<O8d@38b]<0cLoH0=3Bf`3@dMX40<o@f@070=3AfP3@dMT0dM7J0=CEg@3FfN40
e]SQ0=KIh0020=KHh0030=GHh03Ff>00e]SP00<0e]SP103FfN000`3Ff=l0e]WO0=KIg`020=OIg`03
0=OIh03GfMl0emWO0080emWO103HfMl01`3GfMh0emWO0=SJg`3HfMl0emSM0=SIgP3Hf]l00`3If]l3
0=SIgPD0f=WM00D0fMWN0=[JgP3Jf]l0f]_O0=_Lh0020<72aP040410@@2e][P0g=gP0=cMh080g=cP
0`3Kg=l70=_LgP<0fmcM00<0fmcN0=cLg@3LgMd01@3LgMd00`3LgMh0g]oO0>;Si0040>;Si0030>?T
h`3SiN80i>KQ0080i>OQ0P3Tj>40103Tj>80iNSR0:b^Z@0J6QZ:000000`0oooo000:0?ooo`800000
00@0DeEO06a`O01iOHX0]K_?1@33b]l40<C:g`030<C;g`34bmh0a<_N00P0a<_O0`35bml02`35bmh0
^/3B0:N[^`2FVZT0Q8JD09:EY02TYkP0/KC60;FhbP2f^<X0]KO:00@0]KO92@2e]lP00`2e]lL0][S7
0;Jha`090;Jha`80][W7102g^LP40;Njb0030;Rjb02h^lP0^K_90080^K_900l0^;_:0;RlbP2i_<T0
^Kc90;ZlbP2j_LX0^kg:0;^nb`2n`<h0`<;A0<;4d`34aM@0a<KD0<C5e034a]@01034amD30<G7e@80
a/OF00P0a/SG0<G7e@35amD0aLSE0<K8e@36amD0aLKD0<C6d`80aLKC0P34a]<70<G6d`040<K7d`37
bMH0c<oL0=7Eh@@0eMWU00@0cM;L0=CIi03DfN@0bm3J0P3EfN@01@3Df><0al_E0<g@f`3?d=`0cm3K
00@0c]3J00X0c]3K0<oAf`3?d]`0cm;L0=3Bg03Admd0d]GO0=;DgP3Be=l0d=?M0P3@d]/20<oAfP05
0<o@fP3@dM/0dM;K0=7Bg03?dMX00`3?d=T30=3AfP040=7Bf`3Ce]h0e]SQ0=KIh@80e]SP0P3Ef>03
0=KHh0030=KIh03FfN40e]WQ0080e]WQ103FfN020=OIh0@0emWO00D0f=WP0=SIg`3HfMl0f=WO0=SI
h0020=SJh0050=SJg`3HfMl0eMOL0=GGg03Hf]l0103If]l00`3Hf]l0f=WN0=OIg@020=OIg@040=SI
g@3HfMh0fM[N0=[Jg`80f]_O00L0fmcP0<g>dP3=c]80EUMI07enP03HfM`0g=kQ0080g=gP00<0g=cP
0=_Lg`3Kg=l02P3Kg=h30=_Lg@@0g=gM00@0g=kM0=gNgP3PhN80h^?T1P3Rhn<00`3Si^80i>SQ0>CX
h@020>CXhP030>CWh@3HfmD0K6i[08/00000303oool000X0oooo00<00P820000000000000P000000
0`1gNhP0WjBe09nT]@040<?:g`<0`lWN00<0a<[O0<C;g`34bml01034bml04@34b]l0`l[N0<?:gP34
bmh0a<_O0<C;gP31am/0^;k@0:jda@2^//@0Z:^m0:V[_@2_//@0]KO:0;Nib`2f^</0][S:00@0]KS:
00@0]KS90;Fgb02e]lP0]KO82@2e]lL20;Fha`P0][S700<0][W80;Nib02g^/T00P2g^/T30;Njb080
^;[800D0^;_90;Vkb@2i^lT0^;_90;RlbP030;VlbP0:0;ZmbP2k_/X0^kk<0;bnc@2n`<l0`L?B0<?5
e@34a]D0`lKE0<C6e0D0a<OE0`35amH20<K8eP040<K8e`35amD0a<KD0<G7e080a/OE00<0a<KD0<C6
d`34a]<00`34a]<00`34aM80a<KC0<G6d`040<G6d`040<K7d`36am@0b<[G0<oBg`80eMWU00<0e=WU
0=CIi03Cf>@00P3DfN@01P3Be^80eMWT0=GIi03Df><0c<oJ0<oAg080c]3K103>d=X05P3?d=/0cm7K
0<oAg03?dM`0cm;L0<oAg03@d]d0a/WB0<33c02m`<T0`lG?0<S:d`3;cMH0cm3I0<oAfP3@dM/0cm7J
0=3Bf`3<cMH0c/oH0<o@fP3@dM/20=3Af@030=3AfP3Adm/0dmKN0080eMSP00<0e]SP0=KIh@3Ef>00
0`3Ef>000`3FfN40emWQ0=OIh@020=OJh@050=SJh@3Gf^40emWP0=KIh03GfN400P3Hf^420=OJh003
0=SJh03Gf^00f=[P0080em[P00X0f=[P0=SIg`3Hf^00f=[O0=KHgP3Ff=d0d]CI0=OIg`3Hf]l0fM[P
103If]l00`3HfMh0emSM0=OHg@020=OIg@80f=WM00@0fM[N0=[JgP3Jf]l0f]_P0P3Fem`01`25QXP0
CDi?09jOX@3Ad]D0g=kQ0=gNh@3LgN000`3Kg=l80=_LgP<0fmgN103KgMd0103Lg]d0gMkN0>7RhP3R
hn<60>;Si0040>?Sh`3SiN<0hnKR0>CWh@80i>SR00<0hnOQ08nAS@0R8R80R`00000<0?ooo`002P3o
ool00`0j?4803a0A0000000300000080BDaD00X0a<[P0<C;h034bn00`LOL0;[0e02g_]40_<?G0<?:
g`2oa]X0`<OK0P34c>020<C;g`0A0<77f`2na=L0_/CG0<37fP2_]<H0W:6a09NMZ`1lP8d0NGf809>F
YP2VZK/0[:o00;BgbP2f^L`0][W;0;Jhb`2f^<X00`2e^<X0102f^<X0][W;0;JhbP2e^<T70;Fgb080
]KS81@2f^<P30;Jha`<0][W700<0][W80;Nib02g^/T01@2g^/T20;Rjb0040;Rkb@2i^lT0^K_90;Rk
b@80^;c:0P2i_<X01`2j_LX0^kk<0;boc@2m`<l0`<?A0<?6e@34a]H00`34a]D00`35amD0aLOF0<G7
eP020<G7eP<0a/SF0P37bML01036bML0aLOE0<C6e035am@20<K7e@80aLKD00<0a<GC0<?5dP34aM80
0P34aM800`34a]<0aLKC0<G6d`030<G6d`050<K7d`36am@0b/gJ0=7Eh@3EfND01P3DfND40=GIi@05
0=;FhP3>dM`0cm7L0<k@f`3>d=`00P3>dM/00`3?dM/0cm7L0<oAg0040<oAg0070<oBg035am40dmOQ
0=?HhP3>dM/0bLgF0<k@f@030<oAfP0;0<oAf`3@dMX0blgF0<g?f03@d]/0dM;L0=3AfP3@d]X0d]?L
0=?FgP3Eeml00P3Ef>420=KIh@<0eMSP00@0e]SP0=KIh@3Gf^40em[Q0P3Gf^80403Hfn80em[Q0=OJ
h@3FfN00emWQ0=SJhP3Hfn40e=GK0=3>e03Gf^00dmKL0=CGg@3Ff=h0e]WO0=SIh03HfMl20=OHgP06
0=CFg03Eemd0dM;G0=GGg03Gf=h0f=[O1@3If]l01@3HfMh0emWN0=OIg@3GfMd0f=WM0080f=[N00<0
fM[N0=[Kg`3Jfml00P3Jfml01`2ZZjh08b@T03Tj>`2a/[@0g=kQ0=gNh@3LgN000`3Kg=l01P3KgMl0
fmcN0=_LgP3Kg=h0fmgN0=_LgPH0fmgN0P3LgMd20=cNgP030=kPg`3Rhn@0h^?T00H0h^?T0P3Rhn<0
1P3Si><0i>OR0>CWh@3Tin40fmkH05IGE8`00000303oool000X0oooo00<0000001hO8P0000001@00
00030:F[_@060;o6fP2m`mL0_/CH0;k4f02l`]H0_lKJ1@34c>004`30b=/0_<?E0<37fP2^]<D0LWF1
08>7U@2GW:/0A4I<028T9P1jOHX0]K[<0;BhbP2e^L/0]k[=0;Njc02g^L/0][S;0;FhbP2e]lT00P2e
^<X00`2f^<X0]KS:0;Fhb@080;Fgb0D0]KS71@2f^<L20;Jia`030;Jib02g^LP0]kW800H0]k[800D0
^;[90;Rkb@2i^lT0^K_90;Rkb@020;RlbP080;VlbP2j_LX0^[g:0;^nc02m`<h0`<;A0<;4d`34a]D3
0<C7eP<0aLOF0P35b=L00`36b=L0a/WG0<K9e`040<O9f0030<G7e@35a]@0aLOE00<0aLOE00<0aLKD
0<?5d`34aM<01@34a]<40<G6d`040<G7d`36b=D0c<oK0=?Gh`P0e=WU0`3EfND01@3Cen80cm;M0<kA
g03>d=/0cm7L00<0cm;M00h0d=;M0=3CgP3@dmh0alWD0<W;eP3>dM`0cm;L0;Rla02l`<T0d]OP0<75
c`2TYjl0b<_E0<oBf`80cm7K00T0c]3J0<g?f03<c]H0bLcD0<c>e`3@d]X0d=7J0=7Bf`3De]l00P3E
f>400`3EfN40eMSQ0=GHh@040=GHh0040=KIh03Gf^80e]WQ0=KIh@@0em[Q00h0emWQ0=KIh@3GfN40
em[Q0=SKh@3Ee]d0clgD0=KIg`3De]`0e]ON0=GGgP3Ff=l0emWP0=SIg`<0emWO00L0fM_Q0=OIgP3F
f=h0f=WO0=3Ae`3De]/0fM_P0080fM[O00<0f=WN0=OIg@3HfMd00P3GfMd0103HfMd0f=[M0=SJgP3H
f]h20=[Kg`80fM[O00P0YZN[00D51@000000QXN90=?Ef03HfMd0g=gQ0=cMh0@0fmcO0P3KgMl40=_M
gP<0g=gN0P3KgMh0103Lg]h0gMkN0=kOh03PhN830>;Si0030=gNgP3Kg=d0h^?T0080h^?T00@0h^?S
0>?Th`3Si^<0i>OR0P3Ig=L00`22Ph0092HT0000002;000000`0oooo000:0?ooo`030000000F5aX0
000000H0000000@0Ce9K051BF`2>U:<0M7V40P2UZk`00`2X[/00_LCG0<G=h0020<G=h080a<cO00d0
`/WM0;Rnd@2`]/P0/KS90;>ib`2b^<X0Z:fo07YnRP1LGfP0NGf:09nS/`2X[;h0/[G80080^;_=00<0
^;[=0;Nic02e^</01P2e^<X00`2e^<T0]KO80;Fgb0040;Fgb0@0]KS80P2e^<L40;Jha`<0][W700<0
][W80;Nib02g^/T00P2g^/T20;Njb080]k[900L0^;_90;Vkb@2i^lT0^K_90;Rlb@2h_<X0^Kc:0080
^[g:00D0^[g;0;^nc02o`M00`lGD0<C6e@030<C7eP<0aLOF0P35b=L00`36b=L0a/WG0<K9e`020<K8
e`80a/SF0P35b=H40<G7e@060<G8e@34a]@0`lGC0<C5d`34a]<0aLKD0P34a]<20<C6dP080<G6d`35
am<0aLKC0<G7d`36b=D0c<kJ0=7FhP37c=L30=CJi@030=?Gh`3>dM`0e=WU0080e=WU0P3EfND01@3D
fND0dmOS0=3BgP3>dM`0cm7L0080c]7L00l0c]7K0<kAg03@dmh0dMKQ0;g0b@3>d=/0cm7L0<oBg@3:
c]T0c]?L0=CHhP34b=40^Kg50<kAfP3@d]`00P3?dM/02`3=cmP0b/cE0<c=eP37bM80alWA0<k@f03@
d]/0dM?L0=CGh03Ef>40eMWQ0080eMSQ1P3Ef>000`3Gf^80emWQ0=OIh@040=KIh0090=OIh03FfN00
e]WQ0=OIh@3Gf^40f=_R0=3Bf@3Eemd0eMKM0080eMOM0180emWO0=SJh03Hf^00f=[P0=OIg`3BeMX0
eMSN0<;4b@2^/;@0XZ>W0:b^/P3Ce=T0fM[O0=SJg`3GfMh0emWM0=OHg@3GfMd20=SIgP80f=[M0P3H
f]h01@3Jf]l0f]_O0=WJg`3If]l0VY^M0080000000<0?cm008F6Q`3;c<h00P3LgN400`3KgMl0fmcO
0=_Lg`050=_Mg`<0fmgN0P3LgMh20=_MgP040=gNg`3Oh>40hN;T0>7Ri0<0h^?T00<0hN;S0=oQh@3R
hn@00P3Rhn@0103Ri>@0hnKS0>CXhP3Tj>820;k0_00300H71P000000000008/00000303oool000X0
oooo00<0000000L820000000200000000`0g>Cl000000000000209JL[080]kkA0180`LWL0;k5f@2a
^<X0/KS:0:bca02NY;@0`LSK0<G;g`35bn00a<_O0;o5f@2a]lT0Z[3109RM[01_LW`0M7J209fP/02c
]lX20;RkcP040;Njc@2g^/`0][W;0;Jhb`<0]KS:00<0][S:0;JibP2e^<X00`2e^<T00`2f^<P0]KS8
0;Fhb0020;Fhb0<0][S8202f^LP60;Njb@030;Rkb@2i^lX0^;_900<0^K_900T0^;c90;RlbP2i_LX0
^Kg:0;ZmbP2j_//0_;o=0<32dP33aMD00P34a]H01`34amH0aLSG0<G8e`35b=L0a/SG0<K9e`36bMP0
0P37bMP00`36b=L0aLSG0<G8eP030<G7e@070<G7eP35amD0aLOE0<G7e@35am@0a<OD0<C5d`020<?5
d`030<C5d`34a]<0a<KC0080`lGB00T0a<KB0<G7d`35am<0aLKC0<G7e036am@0b<[F0<kAg@2o`lh0
0`3Df^D00`3Ben80c<oJ0=CIi@050=CIi@040=CHh`3@dml0c]3L0<kAg080c]3K00/0c]3J0<k@f`3?
dM`0d]GP0<S=eP3>d]d0c]3K0=7Eh03Cf>80b/oH0=;Gh0020=CIhP040<g@fP3@dm`0cm7K0<oAf`D0
cm7J00<0d=;J0=7Bf`3CeMh01P3Ef>430=GHh0D0e]WQ0P3EfN00103Eeml0e]SP0=KIh03FfN020=KI
h@80em[Q0180c<oE0<oAf03@d]T0e=KL0=3Bf@3GfN00fM[Q0=SKh@3Ifn40eMSN0=3Bf03CeM/0a<G:
0<C6b`2n`<@0cm7F0=OIgP3If^030=OIgP040=OHg@3GfMd0f=[N0=SJgP80emWM0P3Hf]h20=[Kg`80
fM_O00H0YJNZ000000000000000004M8B03Jg=l20=cMh@@0g=gP1`3KgMl20=cMg`80g=kO00<0gn3Q
0>3Rh`3Qhn@00P3Qhn@80>;Si0030>?Uh`3Si^<0hnOR0080WZ6L00<00`<3000000000000R`00000<
0?ooo`002P3oool01@030`@000000000000000003a0A00T000000P0n@4H305mSK@0A06]`NP1EFF40
EEUQ05aPJP1JGFH0ZJo00<37f`31b=/0]kk@0:FZ^`2AUZD0RHjL07MlQ`12AD`0FEYT09^N[`2b]/T0
0P2h^lh0102g^/d0]k[<0;Jib`2f^</30;FhbP<0][S:0`2e^<X00`2f^<T0]KS80;Fhb0060;Fhb003
0;Jhb02f^LP0][W80080][W800<0][W70;Jib02g^/P01@2g^/T00`2h^lT0^;_:0;Rkb@030;Rkb@80
^;c:00H0^Kg:0;Zmb`2j_L/0^kk<0;k1d032aM@30<C7eP80aLOG0`35b=L01P36bML0a/WH0<S9f@37
b]T0a/SG0<G7eP@0aLOE00D0aLOF0<G8eP35amD0a<OE0<C6e0040<?5d`80a<KC0P33aM801@33a]80
a<KB0<G7d`35am<0a<KC0080aLOD00X0a/OD0<[<f@2i_LL0c=7M0:V]]`2l`L/0c]?N0=CJi@3DfND0
eMWU103DfND00`3@e>00d=?O0<kAg0030<kAg080c]3K00T0cm7L0=3CgP3AeMl0cm;M0<oBg03Be^00
e=SS0<_?f03Cf>400P3EfN<04@3=dMX0d]GO0=7DgP39c=D0`lG>0<W;e03:c=D0cLoH0<oAfP3@d]X0
d=;K0=;Dg@3Df>00e=SQ0=?Fg`3CeMh0e=OP00@0eMSP0P3FfN400`3Ff>00e]WQ0=KJh@020=KIh005
0=GHh03Ff>00e]WQ0=KIh@3FfN000P3Ef=l01`3De]d0`lG<0;bna03<c]@0`/?90<S:d03Ff=l00P3G
fMl02`3Demd0e=KM0=CFg@3De]`0cLoD0=KGg@3HfMl0emWO0=WJh03Hf]l0emWO0080emWN00@0emSM
0=OIg@3GfMh0emWN0P3GfMd20=SJgP0=0=WJgP3Ifmh0f]_O0=[Kg`32`lL0DeEE06QZJ@1nP800]k^j
0=kPh`3Ngn80gMkR0=cMh@030=cMh0030=_Mh03KgMl0fmgO00D0fmgO00<0g=kP0=kOh@3PhN<00`3Q
h^@30>7Si080h^?T00<0h^CT0>;Si03Ri>@00`3Ri>@0103Si>@0f=_H06e_K01]Kfb>000000`0oooo
000:0?ooo`0500l@4P00000000000000000U9b/0300000000`030`<05AHH05aPJP0206U^N@0J07b0
S@1VJG@0N7b:0:nea`2NY;D0HfMa04A6C@1GFF80Oh>@08fAW`24R9D0Qh^H0:JZ^`2a]LP0^;c?0;Rk
cP2g^ld0]k[<0;Jic02f^L/0]KW;0;FhbP2f^L/0][W:0;JhbP2e^<X50;Fhb@L0]KS81P2f^LP00`2f
^/P0][[90;Njb@040;Njb@050;Nkb@2h^lX0^;_90;Rkb@2h^lX00`2h_<X01@2j_L/0^[k;0;boc@2o
`]00`lGE00@0a<OG00<0aLSG0<K9f@36bMT00P36bMT20<O:f@030<O9f036bML0aLOE0080a<OE1@35
amD00`34amD0a<KD0<?6d`020<?5d`030<?5dP33aM<0`lGC00<0`lGB00D0`lKB0<C6d`35am<0aLOC
0<C6d`020<G7e00<0<K7e039bmP0^[g90<?8d`2`]L00d=KQ0=;Gh`3Df^D0e=WU0=GIi@3Ef^D0e=WU
0P3Df^D00`31aLl0d=?O0<k@g0030<k@g0090<k@f`3>dM/0c]7L0<oAg03?d]d0cm?M0=3CgP3<d=X0
d=GO0080e=WS00<0c];L0=GIh`3Df>800P3Cen401P3Be^00dMGO0;g0b@3:cMH0d=;K0=3AfP80dM?L
00L0d]?L0=?Fg`3Den00d]GN0=7Cg03CeMh0eMSQ0080eMSP0`3FfN400`3Ff>00e]WQ0=OJh@020=OJ
h@@0e]WQ00D0e][Q0=CGgP3<cmD0`LC:0<O9d0020<k@e`0>0<W;d@3BeM/0emWO0=CGg@3Ce]`0b<_@
0<C6c03AdmT0eMOM0=KHg@3Hf^00emWO0=KIg`3GfMl20=SJg`030=OJg`3GfMh0emWN00D0emWM0P3H
f]d02@3If]h0f=[N0=WKg`3Ifml0aLO;0;Bf^@3DemL0gN7R0>3Ri0020=oRi@030=gOh`3LgN40g=gQ
0080g=gP00D0g=kP0=cMh03LgN00g=gP0=cNh0020=gNh0040=gOh@3Nh>40gn7S0>3Ri0<0hN;T103Q
hn@60>;Si0030>;Ti03Qh^80TiJC0080:BTXSP00000<0?ooo`002P3oool00`0K71l000000000000>
0000000300h?401BEUh0^/7D0080_/GI01<0_L?G0;_1e02RZ;P0SY>R07AiQ01;CUD0;Rle05mRK02c
^<X0_lGH0;g3eP2g_<h0][[=0:faa02h_<l0^;_?0;NkcP2g^/d0]k[<0080][W<0P2e^L`0102e^L/0
][S;0;FhbP2e^<X40;Fhb@<0][W:00<0][W90;Jib02f^LP00P2f^LP40;Jjb@L0]k[900@0]k_90;Rk
b@2h^lT0^;_9102h_<X01`2h_</0^[k;0;Znc02l_lh0`<;C0<?6e`34b=P00`35b=P20<K8f080aLOG
00@0aLWH0<O9f@37b]T0aLOF0P34a]D20<G7e@80aLOF0`35amD00`34amD0`lKD0<?5d`050<?5d`80
`lGB0P33a]820<C6d`030<C7d`35am<0aLOD0080a/SD00@0b<_G0;^obP39cmX0a<WD0P3DfND01@39
c]T0e=WU0=CIi@3?e=l0d=GQ0080e=WU00@0^;c60=3Cg`3>dMd0c]3L0P3>dM`00`3?dMd0cm;M0<kA
g0030<oBg@030<oCg@34am40cM7K0080e=WS00`0bm3J0=CHh`3Den40dmOQ0=CGh@3Df>80e=WR0<K9
dP3@d]`0dM?M0=3Cg03Be=d20=7Dg@050=?Fg`3Den00dmKO0=?EgP3De]l00P3Ef>440=KIh@80e][Q
1@3FfN420=KIh0070=CGgP3Ce]d0dMGK0=3CfP3Eemh0eMSN0=CFg@030=OIh0030=KIg`3CeM`0dM?J
00<0emWO00D0f=WP0=SJh03GfMl0emWO0=OJg`040=SJg`040=OIgP3GfMd0emWM0=OIg@80emWN0P3H
f]d02@3Ifmh0e]SL0=WKg`3Ifml0blg@0=?Ee`3Ohn<0h>?U0=oQi@020=oQi0040=kOh`3Lg^80g=kQ
0=cMh@D0g=kP00@0g]oQ0>3Rh`3Ph^<0h>;S0`3Ph^@0103Qh^D0hN;T0>7Ri03Qh^@40>7Si080h^?T
0P3Ri>@20>;Ti@030=oPh01JFeX0000008l00000303oool000X0oooo00<04Q8D0000000000003000
000010010@4010@402`^<P2>U:830<G=h@0?0<?;g`34b]l0_LCH08V>W01kOh/0WjBe09:HY`28S9X0
Z:jn0;g3eP32bM`0/KO909fQ/@2MXK80^;c@0080^;c?00<0]k_>0;Nkc@2f^/`0102f^L`20;Jib`<0
]KS:0P2e^LX40;JibP040;Jib@2e^LP0]KW80;Jib0D0][[91@2g^/T20;Nkb@<0^;_:0P2h_<X20;Rm
b`060;Vmb`2j_/`0^kk=0;c0c`31aM@0a<SH0`35bMP02033amH0aLSH0<C7e`33a]H0`lKE0<C7eP36
b=L0aLSG1035amD01035amH0aLSF0<G8eP35b=H20<G7e@030<?6e033aM<0`lGC00H0`lGC1033a]82
0<C6d`0;0<C7d`35b=@0a/SE0<K8e@38b]H0`/GA0=7Gh`3?eN40e=WU0=CJi@2k_lX00P3Df^H02033
am<0c=7L0=CIi@3DfND0_<3:0<[>f@3<cmX0c]3L0P3>dM`02@3;c]T0dMKP0=7Eh03>dM`0c]3K0<oB
g@3?dmd0^[k70<kCg@020=CIh`0C0=?HhP3Df><0dmKQ0=7Dg`3Be]l0e=OQ0=CHhP3Den40dmOQ0=?E
g`3BeMl0d]KO0=7Cg@3Ae=d0dmKP0=CHhP3Den40e=OP0=GGh0020=GIh@<0e]WQ00@0e]WR0=KJhP3F
fN40eMSP103FfN401`3@dmX0][W00<O:d@3=cmH0/[Fj0:nb]`3BeM/00`3Gf^002@3Ff=l0f=[Q0=SJ
h@3Ff=l0e]SN0=OJg`3GfMl0emWP0=SIh0040=SJh080f=[O103GfMh20=OIg@060=OIgP3Gf]d0f=[M
0=SJg@3Ifmh0emWM0P3Jg>001@3KgN40g=oS0=kQi03Oh^D0gn7T0080g^3T0P3Nh><00`3Ngn<0gMoR
0=gOhP040=gOh@80gn7S00@0h>7S0>3Rh`3Ph^@0h>;U0P3Qh^D60>7Si@030>3Rh`3If]/0h^CU00@0
h^CU00<0g^3O05YKFP000000S`00000<0?ooo`002P3oool00`0@4A8000000000000<0000000500l?
4@0m@4H0SI>R0;Nnd@33bml00P32b]h03P2f_]40_/CI0;6hbP1eNH@0SiBS0;k4f02m`mH0][_>0;Jl
cP2na=L0_/GG09FJZ01gNhH0Vin`0`2h_=000`2h_<l0]k_>0;Nkc@040;Njc0040;Jjc02f^L/0]KW:
0;FibP80][W:00@0]KW:0;JibP2e^LX0]KW90P2f^LT20;Jib0<0][W91P2f^/T20;Njb@80]k_90P2h
^lX30;RlbP030;Rmb`2i_//0^[k=0080^kk=00T0_L3?0<;5e@34a]L0^Kg;0<O<g038c=`0`<CC0<G8
e`34amH00`33a]D90<C7eP<0a<OE00<0`lKD0<;5d`33aM<01@33aM<00`32aM80`lGC0<?6d`030<?6
dP0<0<?6d`34am<0aLOD0<K8e036b=D0alWF0;o2cP3CfND0e=[V0=;Hh`3Bf>@0^ko:0P3Df^H01`2n
`ld0b/oK0=CJi@3Df^D0^[k90<G9e03<cm/00`3?d]d00`36b]D0dmSS0=?HhP020<g@f`040<kBg03?
d]d0b<cF0=;Gh080e=WS0P3Df><0103AeMl0cm7K0=3Cg@3Den430=GHhP030=GGh@3Df>40dmKP0080
d]CN00@0dmOP0=CHhP3Ef>80eMWR103Ef>430=GIh@80e]WR0`3FfN402@3FfN80e]WQ0;g0aP21PhL0
`<?:0<oBf@30`/P0a/W@0=KHh0050=OIh0030=OJh03FfN00emWP00T0f=[P00<0emWN0=GHg03De]/0
0P3FfMh0203FfMd0emWM0=OIgP3GfMd0f=[M0=KIg03Ifmh0f=[N0P3Ifn00103Jg>00fmgQ0=gOh`3O
hN@20=kPi0<0g^7T0P3Nh>@0103Nh><0gn7S0=oQh`3NhN<30=oQh`030>3Qh`3Ph^<0h>;S0080h>;T
1`3QhnD00`3Qhn@0gMoQ0>;Si@040>;Ti0030=[Kg01FEeL0000008l00000303oool000X0oooo00@0
DEAM04I8D00Y:Rl071dP2`0000000`0M7R40MW^70;[2e@020<G=hP80`LSM00L0TiVX075fPP1OHVd0
D5=K092DY02d^/`0^l7E0080aL_P00D0aLcP0:bb``1dN8@0Oh:@0;:gb@030;Rld0030;Rlc`2g^lh0
]k_>00D0]k[<102f^/`00`2f^L/0][W:0;FibP030;FibP@0][W92@2f^/T00`2g^lT0^;_:0;RkbP04
0;RkbP0>0;RlbP2i_L/0^[k<0;^nc@2j_/d0][W80:Z]_02X[;T0[;2n0:b__@34bMP0a/[J0<G8e`34
a]H20<C6e@030<?6e@34amD0a<OE00D0a<OF00@0`lKE0<?6e033a]@0`lKD0P33a]D20<?6e080`lGC
0P33a]<40<?5d`D0`lKC00/0a<OC0<G7e035am@0aLSD0<K8e@34am@0dmST0=CJiP36c=P0c=;N0<[?
f`020=CIiP080<W>fP3<d]d0e=[U0=CJi@31aM40al_G0<[=f@3=d=`20=3Dg`040;o3c@3@eN00]k_4
0<O:e@80c]7L00@0c];L0=3DgP3AeN00dMKP0`3DfN<0103BeN00d=?M0=7DgP3Ce^030=CHhP070=CI
hP3EfN80e=OQ0=?Fh03Ce]l0e=OQ0=CHhP030=GIhP<0eMSQ0`3EfN400`3EfN80e]WR0=KIhP020=KI
hP090=KJhP3FfN80cm;J0;>e^`33a/d0cM3G0<S:d@3BeM`0e]WP00<0em[Q00@0emWP0=OJh03Gf^00
em[P103GfN002@3GfMl0e]WO0=OHg`3Gf=h0f=[P0=SJg`3Ff=h0e]SM0=OIgP050=KIgP050=OIgP3H
f]h0emWL0=WKgP3Ifml00P3Ig>000`3Jg>00fmgQ0=gOh`020=kPi0@0g^7T0P3Nh>@00`3Nh><0gn;T
0=oSi0030=oQh`030=oQi03PhN@0h>7T00<0h>;T0`3PhnD70>7Si@@0h^CU00<0blc=04];B`000000
S`00000<0?ooo`002P3oool0100l?TD0Uif^06Y^NP0o@DP;00000005024R9@24RYP0aLgQ0<G=h@34
c>400P33bn003`2W[/00DUIN01hP8`0m?dD0XJNh0;Nmd02naMP0aL_P0<G<h035bn00Z:jo08^?W@2O
XkD0][_>0;Nld0030;Rlc`80]k_>00<0]k_=0;Nkc02g^/`00P2g^/`40;Jjc0030;Jjb`2f^L/0][W:
00@0][W:2@2f^/X00`2g^/X0]k_:0;NkbP030;NkbP<0^;_:00h0^;c:0;Rmb`2i_L`0^ko=0;^ncP2l
`<l0Zjjm04iAF@1^L7T0/[G30<74e033amL0a<OF0<C6ePD0a<KE0P34amH01@34amL0a<SG0<C8e`34
b=H0`lOE0080`/GD00<0`lGD0<?6e033a]@00P33a]@01033aM@0`/GC0<;5d`32aM<50<?5d`@0`lKC
00`0a<OC0<C7e034am@0aLOD0<K8e@35b=D0dmST0=CJiP31am80bm7L0=CJiP3DfNH20=CJiP<0e=[U
00@0d]OS0=7Dh03=dMd0al_G0P3>dml01P2e^/@0b/kI0;6d_P38bmH0cM3K0<c@f`80c]7L00`0cm;M
0<G9d`3DfN<0e=WS0<W>f03<d=X0dMCM0=3Cg@3>dM/0dmSQ0=CHhP3DfN820=GIhP80e=SR00<0e=SQ
0=CHhP3Df>800P3Df>80103DfN80eMWQ0=GIh@3EfN460=GIhP80e]WR00`0e]WQ0=KJh@3EfN00cm?J
0<_?e@35b<l0_;k50<kAf03Ef=l0emWQ0=OJh@3GfN440=OIh0@0em[P00H0emWO0=KHgP3Ff=h0e]SN
0=KIgP3Hf^040=KIgP030=OIgP3FfMh0e]WN00@0em[N0P3Ifml40=[Lh0030=cNhP3Nh>@0g^7T00<0
g^7T0`3Nh>@0103NhN@0h>CT0>3Ui@3Oh^@30=oQi0030>3Qi03Ph^@0h>;T0080h>;T00<0h>?T0>3S
i@3PhnD01`3QhnD30>;Ti@030=kPh@2`/K80?Slo0200000000@020P803@e<`0g=cH02`/;K000000<
0?ooo`002P3oool01016B540[K?708R>W@13ADd;0000000500T:2`2FW:`0aLcQ0<G<h@34c>400P33
bn004`30am`0[kG707IjQ`1OHf`0Yjjo0;o5fP33b]l0a<_P0<37f`30a]X0`lWM0<;9g@2d^/`0^KkB
0;Nld02h_M00^KgA0;Rlc`2g_<h00P2g^lh20;Nkc@<0]k[<00@0][[<0;Njc02g^/`0][[<0`2f^//6
0;JjbPD0]k[:1P2g^lX01@2g_<X0]kc;0;Nlb`2h_</0^;g;0080^Kg;00P0^;c;0;NkbP2[[kd0O82;
04a>E@2TY[@0`/GE0<?6eP80`/KF1@33a]D01033a]H0`lOF0<C7eP34amH20<C7e`050<C7eP33a]D0
`/GD0<;5e032a]@01033a]@00`32aM@0`/GC0<;5d`030<;5d`80`lGC1033a]<02`34am<0a<OD0<G7
e035am@0aLSE0<K9e@3;c]/0dmST0=CJiP3?e^80d=KR00L0e=[V00@0_/?>0=?Hi03Ae^80aLWE0P3:
cmX02P2d^L80bm3J0<K9e03:cMP0c<oJ0<C8dP3=dM`0d=CO0=3Eg`31a<h20=CIh`060;k2c038c=H0
d]KP0=;Eh03>d]`0e=SR0`3DfN830=CHhP80e=SQ0P3Df>820=CIhP80eMWQ1P3EfN850=KJhP090=OK
hP3BeMd0a<O>0;Fh_P3=d=L0e]WP0=KIh@3Gf^40emWQ00D0em[Q0`3FfN000`3GfN00e]SO0=KHgP02
0=KHgP0<0=KIg`3Gf]l0e]WN0=KHg@3FfMh0em[N0=?Ff`38bll0c]7E0=KIg@3GfMd0f=_N0P3Hfml0
203Ifml0fMcP0=WLh03Jg>00f]gQ0=_NhP3NhN@0g^7U1P3NhN@01@3Oh^@0h>GU0>7Vi@3Oh^@0g^7T
00<0gn7T00@0gn;T0>3Ri03Ph^@0h>;T0P3Phn@00`3PhnD0hN?U0>7Si@020>7Si@<0hNCU0`3Ri>D0
0`36b<P0D55A01`L700P0000000401HF5@29RhL0T96=01`L76`00000303oool000X0oooo00@08R<W
06Y^NP1;CUL05QLI2P0000000`0U9RX0<C<h0;:jc0060<C<h@0C0<37f`2b^</0[[C60;g3e`34bml0
a<_P0<C:g`2na=P0_/GH0;Nnd02Y[l00/kW;0;g3e`2a]/T0]K[<0;_0d`2i_M00^;c?0;Nlc`030;Nk
cP030;Nkc02g^/`0]k[<0080]k[<0P2g^l`30;Jjc0030;Nkc02g^l/0]k[;00<0]k[;0P2g^l/50;Nk
bP80^;_:00l0]k_:0;NlbP2g_</0]kc;0;Rlb`2h_L`0^;g;0;Jjb02WZkP0X:Ba0:FY]`2MX:d0TYBR
0:nb`032aMD00P33a]H03`32a]H0`/GE0<;5e@33a]H0`/KE0<;5e032aMD0`lKF0<?7eP34amL0a<SG
0<C7e`34b=L0a<OF0<?6e@020<;5e0030<74d`32aM<0`lKD00<0`lKD0`32aM<00`33a]<0`lGC0<?5
d`030<?6d`80a<OC00<0a<OD0<G8e035b=D00P35b=D01036bMH0cM7N0=?Hi03=dml40=CJiP090=?I
i@3Df^H0e=[V0=?Ji@3Df^D0^ko:0=CIiP3DfND0dMKR0080dMOS00L0][[40<oCgP3>d]d0c=3K0<cA
g035b]D0cM?M0080dmSR00L0_/?<0<kCg@37bmD0_<390<O;e@3<d=/0dmKP00<0e=WR00<0e=WS0=CH
h@3Df>400P3Df>430=CHhP<0e=WR103EfN820=GIh@80eMWR00`0a/[B0;Fh_@2e^;d0`lK=0=;Fg@3E
fN00dmKM0<oCfP3Demh0eMWP0=KIh@3FfN040=OJh@030=OIh@3Gf^40em[Q00@0e]WP00@0e]WO0=KH
gP3Ff=l0e]SN0P3Gf]l0203FfMh0e]SN0=GGg03FfMh0cM3D0;Fg^`2l_/80e]SM0P3Gf]h00`3Hfml0
fM_O0=WKg`020=WLh0050=[Lh03KgN80gMoT0=kQi03NhnD00P3NhN@00`3Nh>@0g^7T0=gQi0020=kQ
i0030>3Ti03Qi^D0gn;T00<0g^7S00@0gn7T0=oRi03Ph^@0h>;T0`3Phn@00`3PhnD0hN?U0>7Si@02
0>7Si@<0hNCU0`3Ri>D00`2[[Jd000000000000H0000000302/[:P1NGed0GUmM0080GUmM00@0?Cdl
01XK6P1LGEX0FEUG0P1SI6800`0C51<000000000001Z000000`0oooo000:0?ooo`0400<3100720T0
1PL700820PX0000000<0OH>@08:9UP31bMh01P34c>400`30am`0`/WM0<C;h0030<C;h00@0<C:g`34
bml0`/WN0;Nmd02l`mH0`LSL0<37f`2e_<h0^l3C0;o4f02j`=80^KgA0;Vnd@2f^/d0]kc>0;NkcP80
]k_=1@2g^l`00`2f^l`0][[<0;Jkc0020;Nkc0040;Nkb`2g^//0]k[;0;Njb`D0]k_;102g^lX20;Nl
b`0=0;Rlc02h_</0^;g<0;Vnc@2b]L@0S8nJ055CF@1KGVD0RH^G0:2T/@2i_L`0`lKG0<?6eP020<;6
eP<0`/GE00H0`/KF0<;5e@31aM@0`/GD0<?6e@33amH20<C7e`80a<SG00@0a<OF0<?6e@31aM<0`LGC
0P31a=<20<;5e080`/KD00H0`lKD0<?6d`33a]@0a<KD0<C7e033a]@20<C6e0@0a<OD00P0aLSD0<G8
e@35b=D0aLSE0<K9eP3=dMh0dmSU0=;Hi0@0e=[V00H0bLkJ0=CJiP3Df^H0bLoJ0=7Gh`2oa=020=CI
iP090<O<e`3;dM`0bm7L0;NlaP3Ben80d=GP0=3Fh@3Ben80e=[T00<0e=WT00P0dMKQ0<W>f033b=80
bloJ0<gAg02k_lT0d]OQ0=CIh`<0e=WR0`3Df>400`3Df>80e=WR0=CIhP030=CIhP<0eMWR00L0eMSQ
0=GIh@3Ef>40eMWQ0=KJhP3EfN40_/;90080][W000<0cM3H0=KJh@3FfN400P3FfN420=GHh0030=GI
h03FfN40e][Q00H0em[Q203Gf^020=OJg`80e]WN00H0eMSM0=OJgP3Ef=d0e]WM0=;Df03Gf]h20=OK
g`030=WLh03Ifn00fMcP00<0fMcP00D0fmkR0=gPi03OhnH0gnCU0=oRi0020=kPi080gN7T0P3NhN@0
103Oh^@0gn?U0=oSi@3OhN@20=kQi0030=oQi03Oh^@0gn;T0080h>;T0P3Phn@0103PhnD0hN?V0>7S
iP3QhnH40>7Si@040>7Ti@3Mh>40/kBe05mPH1X0000000<0HVAQ0=[Le`3JgMP00P3KgMP02@2AThl0
?Cdl0:Z/Z02@TXh0:2XX0411?`12A440D59?07IhM00208:4P0<0PhB000<0LgA_04Q9AP0B4a80HP00
000<0?ooo`002P3oool>000000030;Bld02e_M40_/KJ0080a<cQ00D0a<gQ0<G=h@35cN40a<cR0<C<
h0040<C;h0050<;9gP33b]l0aL_P0<G;h031b=`00P34bn030<C;g`060<76f`2n`mL0_L;E0;_0e02d
^L`0]kc?102g^lh40;Nkc@030;Nlc@2g^l`0]k_<00@0]k_<0P2g^l/60;Jkb`0A0;Nkb`2g_</0]kc;
0;Rlb`2h_L`0^;g=0;Vmc@2h_<`0[;2o09VMZP0l?D804a<E03dn@`1fN8<0[k;10<;5eP33a]H00`32
a]H01032aMD0`/KF0<;5eP32aMH30<;5e@030<?6eP33amH0a<OF0080a<OG00<0a<OF0<?6e@32a]@0
1031a=<00`31aM<0`/KD0<?6e0040<?6e0040<?6e@34amD0a<OE0<?6e0D0a<OD00<0aLOD0<G8e@36
bMH00P36bMH00`3=dMh0dmSU0<C:eP020=CJiP030<gCg`3CfND0`LKB0080e=[V00<0^Kk90<oEh@3D
f^H00P3Df^H01030aM00b<kI0<S>f@39cmX20=CJi@0=0<_@f`38c]T0e=[U0=CJi037c=H0dMOQ0<35
cP34b=80_/?<0=CIi03Df>@0^ko90=;Gh@040=CIh`@0e=SR0P3DfN880=GIhP050=GHh@3EfN40em[S
0=;FgP39cMD00P3>d]T02P3Ef>00e][Q0=KIh@3FfN40eMWQ0=GIh03Ef>00e]WQ0=GHg`3Ff^460=OJ
h@040=OIh03Gf^40em[Q0=OJh@80em[P00@0em[O0=KIg`3GfMl0em[O0P3FfMh01P3Gf]h0e][N0=OJ
gP3Gf]h0e][N0=OKg`80f=_O00<0f=cP0=WKh03Ig>000P3Ig>00203JgN40gN3T0=kRi@3Oi>H0gn?U
0=kQi03Nh>@0gN7T0`3NhN@0103Nh>@0g^7T0=kPi03NhN@20=oQi0030=kQi03OhN@0gn;T0080gn;T
00<0h>;T0>3Si03Phn@00`3PhnD30>7SiP050>7Si@3Qi>D0hNCU0=OJf`0i>c/06@000000400820P0
>S/j06QZI`2?THh0/KB_0;bn^P2m_k/0[Jn[08V:Q`1ZK6T0@D5004A5@P2WZZ@0_/6j0<K:`P3MhMP5
0>GYh0040=oTfP2Y[JD0;Rl]00410F400000303oool000X0oooo3P0000000`1LH6X0HFE`08B:V003
0<C=hP80`l_P00<0][kA0<38g032b]h00P34c>001P34bml0_lKI0<37f`34bn00a<cP0<?:g`80a<_O
00/0`/WN0;W0dP31bM`0`<OK0<36fP2k`=@0_<7D0;_0e02h_=00]kc?0;NlcP040;NkcP<0]kc>00<0
]kc=0;Nkc02g^l`00P2g^l`30;Nlc080]k_<00<0][_<0;Jlc02g_<`0102g_<`03@2i_L`0]kc;0;>g
aP2]//00X:>a07UlQP1ADeT0:b`_05UJHP2GVZL0][[:0<75e@33a]H00P32a]H80<75e@80`lKF00L0
`lOF0<C7eP34b=L0a<OF0<?6eP33a]D0`/GD0080`LCC0P30a=800`31a=<0`LGC0<;5e0040<?6e003
0<C7e@34amH0a<OE0080`lOD1@34am@01`35b=@0a/WF0<K9eP37bmP0d=GR0=?JiP30aM400P3Df^L0
0`33bM@0d]WT0<[@g0020=CJi`060<O<f03@en80e=[V0=CIiP3>dml0`LKA0P39cmX30=CJi@090<C:
e030aLl0dmWU0=?Ii@2g_<H0cmGO0;Jka035b]@0^l3:0080e=WT00<0aLWC0=;Gh@3DfN<00`3DfN<0
103Df>80e=WR0=CHh@3Df>820=CIh`040=GIh`3Ef^<0eMWS0=GIhPD0eMWQ00<0e][S0=KJhP3EfN40
1P3EfN400`3FfN40eMSP0=GHh0030=KIh@040=KJh@3Gf^40em[Q0=OJh@80e]WP00<0e][Q0=OJh@3G
fn400P3Gf^420=KJh0030=OJh03Gf]l0em[O0080em[O00<0e]WN0=KJgP3FfMh00P3Gf]h0103Hfml0
f]gR0=WMh@3Hg>050=WLh0040=[NhP3NhND0g^;U0=kRi@<0g^7U00`0gN7T0=kQi03Oh^D0gn;U0=oQ
i03NhN@0gN7T0=kQi03Nh^@0gn7T0=kPi03NhN@40=oRi0030>3Si03PhnD0h>?V0080h>?V103QhnH2
0>7TiP030=SKg00n@400000001P0000000d051@C08f?S02MX9`0D55?0:RZYP3>d/`0gN3J0=oSg03F
f]<0[k:]09VKU`2i_KH0h>GL00<0j>cS1P3XkN<0103QiM/0_/:j06IWH`061`IP000000`0oooo000:
0?ooo`l0000000<01@D5028T9`33c>400P34cN820<?;h@040<79gP32b^00_lKJ0<;:g`80a<cP00<0
a<_P0<79gP32b]l01034bn002`2l`]H0TiVX0;Rod`2k`M@0_/GH0;[0d`2m`]H0^KkA0;Rmd02h_<l0
]kc>00<0]k_>00H0]kc>0;Rlc`2h_<l0^;c?0;Rlc@2g^ld30;Nlc@80^;c<1P2g_<`03`2g_</0]kc<
0;Nlc02h_L`0^;g=0:V]_01dMX00DUAK03/m@@0I6A/010@503do@`2JWJX0_l;C0<;6e`040<;6eP80
`LGE00<0`LCD0<74e@31a=D00P31a=@01031aMD0`/GE0<?6eP33a]H20<?7eP040<C7eP33a]D0`lKE
0<;5e080`LCC00D0`<CC0<34dP30a=80`LCC0<;5e0020<?6e@80`lKD00<0`lOE0<C7e@34amD00`33
am@40<C7e0070<G8e@36bMH0al_H0<[?g@3BfNH0e=_X0<36dP020=CJi`030;Jla`3@e^<0e=[W00<0
e=[W0P3Df^H00`3DfnH0aL[F0=3Eh@020=3FhP050=?Ji@3Df^D0e=[U0<gCgP39cmT00P3Df^D01@33
b=<0dMOR0<C9d`39cmT0`LK@0080e=WT1P3DfN<00`3Df>80e=WR0=CHhP030=CIhP030=CIh`3EfN<0
e=WS0080e=WR1@3EfN800`3Ff^<0e]WR0=GIh@040=GIh@040=GHh@3EfN40eMSP0=GIh@<0e]WQ00D0
e][Q0=GIh03Gf^40em[Q0=KJh@020=KIh@030=OJhP3Gfn80em[Q0080e][P00<0e][O0=OJh03Hfn40
0P3Hfn400`3Hfn00em[P0=OKh0020=OKh0080=OJgP3Ig>40gN3U0=cOh`3Ig>00fMgQ0=[Mh@3Ig>42
0=WMh@040=_Nh`3MhND0g^7V0=kPi@80g^7U00/0g^;U0=gQi@3NhND0g^7U0>3Si@3Qi^H0gn;U0=gP
i03Mh><0gN7S0=kRi0020=kQi0060=kRi03Oh^@0gn;T0=oRi03Ohn@0h>?U0`3PhnH50>7SiP030>7T
iP3Ff=X0?T1001P0000000/061PG05=DDP2d]k<0`<>n051BD01;C4/0UYRE0>?Wh03Wk>@0j>gT0>S/
i0020>O/i0040>O/h`3Wk>@0j>cS0>S/h`P0j>gS00D0]k^c01lO7`0B4Q8030`<00410@1M000000`0
oooo000:0?ooo`d0000000L01`L802@V:P1@E5d0:bdb0;o7g032bn00_LCH0080`/[O0P34c>400`33
bml0a<_P0<C<h0020<C<h00:0<C;h031bMd0a<_P0<C;h031b=`0]K_>08N<V@1WJgD0X:Ng0;[0d`80
`/WM00P0`<KJ0;g2e@2j_m80^;g@0;Rld02g_<h0]k_>0;NlcPP0^;c?00@0^;c>0;Rlc@2h_<d0^;c=
102h_Ld04@2h_<`0^;c;0;Rlc02h_L`0^;g=0;Bib@25RI@0:2T]000000020P803Q0@03@f>P2=TId0
_/;B0<;7e`32aMH0`LGF00<0`LGE00<0`LCE0<34e@31a=D00P31aMD30<74e@80`/GE00@0`/KE0<?6
eP33a]H0`lKF0`32aMD20<74d`80`<CC00@0`LCC0<75d`31aM<0`/KD0`33a]@00`33a]D0`lOE0<?7
e0020<?7e0030<C7e@34b=D0a<OE0080a<OD00@0a<SE0<K9eP39cM/0d]WV0P3DfnP01@3Af>D0e=_W
0=CKi`2j`</0d=KR00D0e=[W0P3DfnL00`38c]T0e=[V0=CJiP020=CJiP<0e=[U00P0dm[U0=CJi@3C
f^@0dMOQ0=?Ii03Cf><0d]SS0=3Fh@<0e=WT1@3DfN<01@3Cf>80e=WR0=CHhP3DfN80e=SR00<0e=WS
0`3DfN850=GIhP030=KIhP3EfN80eMWQ0080eMWQ00H0e]WQ0=CHh03Ef>40eMWQ0=GHh03EfN440=KI
h@080=CHg`3FfN40e]WQ0=KIh@3FfN00e][Q0=OJh@3Gfn820=OJh0040=KJh03Ff]l0em_P0=SKhP@0
f=_Q0P3Hg>402@3Hfn00em_O0=WLh@3Kgn<0fmoT0=_Oh`3Jgn<0g=oS0=[NhP020=[Mh@040=_Oi03N
hND0gN7U0=gPi@D0g^7U00@0g^3U0=oRi@3Pi>D0g^;T0P3MhN@00`3MhN<0g^7T0=oRi@030=kRi080
gn;T00<0gn?U0>3Si@3PhnH00P3PhnH50>7SiP030>7TiP3@dm@0?T100140000000@00@41030a<010
@D004A4A0`000000200n?ch0][Vd0=cPf`3MhM`0N7Ug092BS`3@e<h0iN[R0P3WkN@20>S/i0030>O/
i03Wk><0incS0080j>cS1`3XkN<01P3XkN@0i>SO0<W=a02UYj40GEiK00/;2ed00000303oool000X0
oooo3@0000001`0@4A80Ee]U09fS]@1>DU/0LgR50<39gP2d_<l00P2h`MD01P31bMh0`l_P0<C<h033
bn00`l[O0<?;gP80`l_P01<0`l_O0<C<h@34c>40Zk;306Y^N@15Adh0M7N40:F[_02naMP0`LSL0<?:
gP2i`=80/[S:0:neaP2f_<d0^/3B0;Rmd02g_<l0]kc>00L0^;c?00@0^;g?0;RlcP2h_<h0^;c>1@2h
_Lh03@2h_Ld0^;c<0;Rmc02h_Ld0/;C409FIYP1EEel05aPJ0000000>3Pl0BT]B09ZNZ`2n`]800P32
a]L40<75eP@0`<CE00<0`LGE0<75eP31aMD01031a=D01`31aMD0`/KE0<?6eP32a]D0`/GE0<75e032
aM@00P31aM<20<34d`030<75d`31aM@0`/KD00<0`/KD00T0`lKD0<?7e@33am@0`lOD0<;6d`33am@0
a<SE0<G8eP34b=D00P34am@01034b=D0a/WF0<W=f`3BfNH30=CKj0080=CKi`3<dml0`<KC0=3Fh`3D
fnL0e=[W0=?IiP3DfnL30=CJiP030=?Ii@3Cf^H0dm[V0080dm[V0P3Df^D30=?Ji@040=?Ji03Df^@0
e=WT0=?Ii0D0e=WT1@3DfN<01P3Cf>80e=WR0=CHhP3Df>80dmSR0=CHhP80e=WS3@3EfN80103FfN80
e][R0=GIh@3EfN430=KIh@050=KJh@3EfN40eMWP0=CHg`3Deml00P3EfN420=KIh0<0e][P00L0e]WP
0=KJh03Ff^00em_Q0=SKhP3Gfn00e][P0080em[P00@0d=?I0<O:d03Ce]X0f=cP0P3Ig>401@3Jg^80
g>3U0=gQi@3MhND0g>3T0080fmoT00<0g>3U0=gQiP3MhND00P3MhND50=gPi@030=gQi@3MhN@0gN7T
00<0gN7S00<0gN7T0=kQi03Nh^@00P3Nh^@20=oRi0<0h>?U0`3PhnH30>7SiP80hNCV00<0blk?03ho
?`0000002@0000000`071`L061TH010@40040000000500h>3P2:S8X0[k:_0411@0071`L00P000000
201cMG40fmkI0=;Ed02a]:l0RH^80=SKeP3XjnD0j>cU0P3WkN@20>S]i0050>O/i03Vk><0incS0>O/
h`3XkN@0203XkN<01P3YkN<0jNkT0>W]i02VZ:80<S<a014A45`00000303oool000X0oooo3@000000
1`0A4Q@0G61[09nW^01VJWH0QXbL0<7:g`34cN800P2e_M406P2f_]80`LWM0<?;h032bMl0^/7E0;2h
bP33bn00^/7E0::Y^`2=TZ40QhfL071eP@0f>Cl0CE5I0:F[_031b=`0a<[O0<?9g@30a]X0Ri2N05]N
I`1YKGL0W:6`0;[0dP2a]LL0]KW<102h_M001`2h_Ll0^;c?0;Rlc`2h_Ll0^Kg?0;RmcP2g_<h00P2h
_Lh30;Vnc`0=0;Vmc`2h_Ld0^;g=0;Rmc@2g_<d0TiNT051CF@0L7Al020P90000000I6Q`0Ngj80;g2
d`020<76e`D0`LGF00@0`<GE0<34e@30a=D0`<CE0`31aMD30<34e080`LCD00@0`LGE0<;6eP32aMD0
`LCD1031aM@20<34d`<0`LGD1032a]@01@33amD0`/OD0<;6e032a]@0`lOD0080aLSF00L0aLSE0<C8
e@34b=D0aLSE0<K9eP39c]`0d]WV00@0e=[X00<0c]GR0=7Gi03CfNH00P3DfnL0103?eN40e=_W0=CK
i`3=dml30=?JiP80d]SU0P3Df^H40=?JiP<0e=[U00<0dmWU0=CIi@3DfND00P3DfND00`3DfN@0e=WS
0=CIh`050=CIh`@0e=WR0P3DfN<00`3EfN<0eM[S0=GJh`030=GJhP040=GIhP3Ef^80eMWR0=KJh`<0
e][R00@0eM[S0=?Hh03Ceml0eMWQ0P3FfN420=KJhP@0eMWQ00@0e]WQ0=KJh@3Ff^40e][Q0P3Ff^03
0=GIh00?0=KJh03Gf^40f=_R0=OJh03FfMl0e][O0=GHg@3Cem`0eMSN0<kBe`3Hg>40f]gR0=SLh@3I
g^40g>3U00H0gN7V103MhND50=gPi@030=gQi@3MhN@0gN7T00<0gN7T00<0g^;T0=oRi@3Oh^D00`3O
h^D40>3Si@040>3Ti@3Pi>H0h>CV0>3TiP<0hNCV00<0hNGV0;^n_`0g>3P02P0000005`0];Rd0YZVW
096DTP0D51@01@H5030a<018BDP0OX1n0<kAcP3Gf]L0c]7=07ioOP0J6QX0SY6=0=?FdP3Vj^@0^knj
07eoO034al<0i^[T0>O[i@3Xk>D0incU0080ingU00<0j>gT0>O/i03Vk><00P3Wk><00`3WkN@0j>gS
0>S]h`050>S]h`070>S]i03YkN<0jNkS0>W^i03Uj]l0c=7806AUHP020000000300L81`0>3`h03Pl>
00803Pl>00<02`/;00<30`000000DP00000<0?ooo`002P3oool=0000000700P82@0Z:c00BTiF06ic
O`2^]/T0`l_Q0<C<hP020;2hb`0?0:fda`2j`]H0`LWN0<37g02RZ;X0SiFS0<;:gP2<TJ00KW9n07b1
SP1jOh`0PhNF08R=W02MXk@0^l;F0080a<_O00h0`LSL0;c2eP1OHV`01PH702//<@22QY<0/kW<0::V
]`2^/lD0]K[<0;JkcP2f^ld0];W<0;Jjc@80^;c?00H0]k_=0;BhbP2d^L/0]kc=0;BibP2b]/L20;Bh
b@080;Nlc@2f^//0][_<0;Nkc02g_<`0ZZjm079fP00S92L30000000401hO8P2>TId0`LGG0<76e`L0
`LGF00<0`<GE0<34e@30a=D00P30aMD00`31aMD0`LCE0<74e@020<74e@040<75e031aMD0`/KE0<75
e@D0`LGD00@0`<CC0<75d`31aM@0`/GD1@32a]@01P32am@0`/KD0<;6e033am@0`lOE0<C8eP@0aLSF
00L0aLWF0<K:f03=d]l0dmWW0=?IiP3BfNH0dmWV00@0dm[W00T0dm[V0=CKi`3Df^L0e=[W0=CKi`2n
`ll0dm[V0=CKi`3Af>@00P3@e^800`3Df^H0dm[V0=?Ji@050=?Ji@030=CJi@3CfND0dmWU0080e=WU
00<0e=[U0=CIi03CfN<00`3DfN<0103Df^@0e=WS0=CIh`3DfN<20=CIhP<0e=WS00<0e=WR0=GJh`3E
fn@00`3Ef^<01@3EfN80eMWS0=GIhP3Ef^<0eMWR0080e=WQ00@0alcD0:fa^035bM40e=SP0P3EfN43
0=KJhP<0eMWQ00<0e][Q0=OKhP3Ff^400`3Ff^404`3Ff^00e][Q0=KJh03Ff^00em_Q0=KJh@3Df=h0
e][O0=;Ff`3?dmT0e]WO0=SKh@3@dmT0em_Q0=WMhP3Jgn@0f]oS0=cOi03Lh>D0103MhNH00`3Mh>D0
gN7U0=gQi@050=gPi@030=cPi@3Mh>@0gN3T00D0gN7T00H0gN7S0=gQi03MhN@0gN7S0=kQi03Nh^@5
0>3Si@030>3SiP3Pi>H0h>CV00<0hNCV00<0hNGV0:b_/00a<S801P0000004P020`<0=3@d05EFE@1^
L6h0UYRF0=GIeP33a/@0824Q00l@3`25QhD0a/W60=?Ge03Ohml0i^[V0>K[iP3=dLd0L75_0=gQg080
in_V00@0h^KQ0<O:a@3Lh=/0in_U0P3WjnH00`3WjnD0incT0>K/i0020>K/i0030>K/h`3Wk><0incS
0080j>gS2@3Xk><03`3XkN<0jNkS0>K[h@2CUi005QHE00h?3P16B4@0P8En08jDS02V[:<0[K:Y09bP
V@1eNG<0HfIP02d_;01A000000`0oooo000:0?ooo`l0000000D03a0B07=hQ034cN<0`lcR0<C<hP02
0<?;h@80_/KK02D0`/WO0<?:h02e_=00[KC60:2V]`28SI/0UYb]0;NodP2f_M00^/7E0;o6f`31bMd0
`l[O0<?;h034bn00_L?G0;g4e`1mP8h0I6Ma07AiQ023QYD0TIJU0:bb``2l`MD0_L;F0;Fjc02X[Kh0
Uib[0:ba`P2k_m80^[oB0;Bib`2CUjD0PhND09:GY@1oPhl0L7=n0080QXZG00P0Zjo00:fa`@2a]/H0
Zk2o09nS/P1kOXT0BD]B01@E5`<0000000D07QlR08V=V@31aMH0`LKG0<35eP070<75eP@0`<GE2@31
aMD80<75e0P0`/KD0P32am@00`33amD0aLSF0<G8eP020<G9eP080<K9eP36bmP0bm3N0=7Gi03DfnP0
dm[X0=CJj039cm`40=?Ji`030=;IiP3CfnL0e=_W0080e=_W00<0a/gH0=?JiP3DfnL00`3BfND00`3D
f^L0e=[V0=?Ji@040=?Ji@H0dmWU0P3DfN@00`3CfN@0e=WT0=CIi0020=CIi0@0e=WS00P0e=WR0=CI
h`3DfN<0e=WS0=CIhP3Ef^<0e]_U0=GKi0@0eM[S0`3EfN820=GJhP030=;Gg`3>dm/0eMWR00<0e][R
103Ffn<20=KJh@030=OKhP3Ff^80eMWQ0080eMWP00<0eMWO0=KJh@3Gfn400P3Gfn404@3Gfn80eMWO
0=CHgP3EfMl0bm3E0:FX[@2j_L80e][O0;Nk_`3Cem`0fmoT0=cQi@3Jgn<0fMgR0=_Oi03MhNH0gN;V
0080gN7V00<0gN7U0=cQi@3MhND0103Mh>D20=gQi@H0gN7T103Mh^@00`3Mh^<0g^;T0=oRi@050>3S
i@<0h>CV00H0hNCW0>7TiP3Qi>H0`/G705iOH00K6a/60000000B00H61P22Q8<0d]GC0>3Th@3Tj>H0
hnOT0<K9a`1kO7/0J6YY0;Zm^P3?dll0Y:NT09bOW03Oi>00i^_W0>KZiP3Pi=l0i^[U0P3WjnH00`3W
jnD0hNGO0>GZh`020>O/i@80in_V103Vk>@01`3Wk>@0ingT0>O]h`3WkN<0incS0>S/h`3Xk>@01P3X
k><20>S]h`080>S^h`3XkN<0g^;H0=GIc`2i_kD0/KJ^0>G/h@3UkN420>G/h@060>;ZgP3Mi=P0e]gA
06U]I`092@P00@41C`00000<0?ooo`002P3oool?0000000400l@4P1_M800a<gR0<?<hP@0a<cR00<0
a<cQ0<?;h@33bn400P33bn00202l`mP0^l;G0;g5f@33c>40a<cQ0<?:g`2na]X0^<3C0P2e_<l05`2_
]/P0ZJo00;Fkc@2KXK00[[C50;2gb02TZ[X0UY^Z0:F[^`2j`=80/KO807]oS01TJ780PhND0:V__`2n
`mH0/;K608nDX@1>D5L092HY02d^<`0L7Al05AHH0080Ce9I0140VYj/0:N[^`2^/l<0UYZY06Y]M`0a
<SH06AXL01hP8P17BU40@DA:01@E5`0N7b80PXJA0<35eP31a]L0`LGF0<35eP060<75eP030<76eP31
aMD0`LGE00l0`LGE0P31aM@50<;6e0D0`/OD00<0`lOD0<C8e@34b=D00P34b=D01035bMH0a/[H0<_A
gP3Cf^P20=CKj080dm_X00H0bLoK0=?Ji`3Df^P0e=[W0=?Ji`3Af>D70=CKi`030=?JiP3BfND0d]WU
0080dm[V103Cf^D70=?Ii@030=?Ii03DfN@0e=WT00H0e=WT00D0dmWS0=CIh`3DfN<0e=WS0=CHhP02
0=CIh`030=GIh`3Ef^@0eM_T00@0eM[S00<0eMWR0=CIhP3DfN400P3Df>400`3Cf>00cmCL0=?Gh003
0=GIhP030=CHh03Ceml0dmSO0080eMWQ00D0e]_R0=OKhP3Gfn80e][Q0=GJh@020=GIh0050=KJh@3G
fn<0em_S0=OKhP3Gfn400P3Ff^001`3Ef]l0e][P0:ja]`2@TYH0e=SN07j0P`2c]k`00P3LhNH00`3K
gn@0f]kS0=_Pi@020=gRiP80gN7V00<0gN7U0=cPi@3Lh>D00`3Mh>D20=cPi@030=gQi@3MhN@0gN7T
00<0gN7T1`3Mh^@0103Mh^D0gn?U0>3Si@3PhnD20>3Ti@@0h>CV0P3Qi>H00`2PXj@020P800820P05
0000000503lo?`2?TI00b<c90=[Mg03HgMX00P3UjNH02@3Ri^<0g>3M0=WMfP3Ri^80/;Ba03@d=00f
=cH0h>CP0>O[iP020>O[i`@0in_V00L0i^[T0>O/i@3WkND0ingU0>O/iP3WjnD0i^_T0080i^cS00H0
i^cT0>O/i03WkN<0ingS0>O/h`3Wk>@60>S/i0030>S/h`3XkN<0j>gS00<0j>gS00@0ingS0>K/hP3U
k>80h^[O0P3UkN420>G/h@080>C/h03Uk>00i>cO0<G;`@2=TX/0IVUT055DD00N7ae=000000`0oooo
000:0?ooo`l0000000<03a0B07MmR@34cN<00P33c>830<C<hP<0a<cQ0`33c>400`34bn00`lcQ0<?;
h@020<?;h0080;c3e`2<T:00I6Qb06mcOP1hOHT0Oh>@09>HY`2Z/<820<?:gP0>0;k5f02g_M00`<KJ
0<;9g02MX[80BD]C05=FGP2X[;d0[[?40;6gb01hO8L0?Cm401dN8@0310@20000000C02PZ;P1]LG`0
KG5l08:6T`26RYL0TIFS079eP00i>T000@410000000d=c/0TINT08F;U`0X:Rh04a<E05=EG02IWJ/0
][[;0<34e@020<35ePD0`LGF1@31a]H;0<75e@80`LKE0`32a]D30<;6e0030<;7e@33amD0`lOE00D0
`lOE0P33b=D01@34b=D0aLWF0<O;f@3=e>80dm[X0080dm_X00P0e=_X0=?Kj03DfnP0e=_X0=?Kj03A
f>@0c]GR0=7Hi@D0e=_X1@3DfnL40=?JiP040=?Ji@3Df^D0e=[U0=CJi@80dmWU00@0dm[U0=CJi@3D
f^D0e=WU1`3DfN@00`3Df^@0dmWT0=CIi0060=CIh`<0eMWS0`3Ef^<00`3EfN<0e=WR0=CHh@020=?H
h0030=?Hh@3Df>40e=SQ0080e=WQ00H0eMWQ0=CHh@3Be]h0c=7I0<cAf03EfN450=OKh`80e][Q103G
fn802P3Ff^40eMWO0=CIg`3Ef]l0a<O=09:EVP2AU9P0eMWO09NJW@2RYJT20=[Oi0050=_Oi03Kh>D0
g>7V0=gRiP3MhNH00P3LhNH0103MhNH0g>3V0=cPiP3Lh>D20=cPi0D0g>7T0P3MhN@30=cQi0030=gQ
i03Mh^@0gN;T0080gN;T00<0gN;U0=kSi@3PhnD00`3Pi>D40>3TiP80hNCV00<0VijO000000000000
1@0000002024QXH0i^[X0>KZj03Sj>D0`lO40=kSh03CemD0hNGR0`3Vj^L01038c<T0Si6?0;Zn^`3V
jnH30>O[i`@0in_V00H0incV0>O/i@3Wk>D0ingU0>O/iP3WjnD40>K/i0<0i^cS00<0incS0>O/i03W
k>@01P3Xk><01`3VkN<0i^cS0>K/hP3UkN80iNgS0>G/h`3Tk>800`3Tk>430>G]h@<0iNcP00D0iNgP
0=oVfP3EgM40];Z`0494@01=000000`0oooo000:0?ooo`h0000000H0<cDk05iRK@2GWJh0a<gS0<?<
hP33cN820<?<hP<0a<cQ00D0`l_Q0<C;h@33c>40`/_P0<79gP020<?;h@0:0<?;h02oam/0VZ6a03m1
B00:2P/0@TA<07f1S`23R9H0UYb/0:fca080`l[N00/0_lKJ0;g3eP33b]h0`l[N09VN[@15Adh0AdU@
09VN[@2PYKD0UIZX0453BP050000000F04U<D`2X[kl0Z:no08N=V@1EEel0KW5l07j3S`1>DEP01PL7
0000000S9BP0HVI_05YNI`0K7Al01`P801lP9019BU40NG^70:V]_@2m`M<0`LGG0<76e`@0`LGF1@31
a]H00`31aMH0`LGE0<75e@030<75e@040<76e@31aMD0`LGE0<75e@@0`LKE0`32a]D01032a]@0`/OE
0<?7eP33amH50<?7e@<0a<SE00P0a<WF0<G9eP37c=X0d=OT0=;Kj03CfnT0bM3L0=?Kj0<0dm[X00<0
dm[W0=;Ji`3@en@0103DfnP00`3DfnL0e=[W0=CKi`040=CKi`@0dm[V00@0dm[U0=CJiP3DfnH0e=_V
0P3Cf^D20=CJi@80e=_U0`3Df^D01@3DfND0e=WT0=CIi03DfN@0e=[T0080e=WT0P3DfN<00`3Cf><0
e=WS0=CIh`020=CIh`070=GIh`3DfN<0e=WS0=CIh`3EfN<0eM[R0=GIhP030=GJhP030=GIhP3DfN80
e=WR00@0eMWR00@0e][S0=GJh@3Ff^80e]_S1@3Gfn<00`3Ff^80e][Q0=OKhP030=OKhP0@0=OKh@3F
f^00cmCJ0<_@e@35b/l0_/760;Vm`P3Gfn40cm;H0<[>d`3AeM/0em_P0=[Oi03LhNH0g>7U0=cQiP<0
g>7U00@0g>3U0=cPiP3Lh>H0g>3U103LhND40=gQi0030=gRi03LhN@0g>7T0080g>7T1@3Mh^@00`3N
hnD0gn?U0>3Ti@020>3Ti@@0h>CV00<0h>GW0>7Ui`2KWIh01`0000003`2<SXd0i^[X0>GZj03UjNL0
e]_I0>CYiP3Uj^L0i>SU0>GYiP3Uj^H0iNWV0>K[j03VjnL0in_W0>K[i`030>O[i`<0in_V0P3Wk>H0
1P3Wk>D0ingU0>O]i@3Wk>H0in_U0>K[i080i^cT0`3Vk><0103Wk><0incT0>S/i03WkN@30>O/i004
0>O/h`3WkN<0ingS0>G/h`H0i>cR00D0i>cQ0>?/h03Tk>40i>gQ0>G]hP040>G]h@<0iNgP00<0bm?7
04M:AP000000C000000<0?ooo`002P3oool>0000000406IZMP2]]LT0_<CI0<C=h`80`lgR0P33bn00
0`32bn00`LWN0<38gP030<?;h00B0<;:g`30b=d0a<_Q0<C;h@2la=P0VIn_05]NJ01;CUH0G61Y08fC
XP2h_]40_LCH0<;9g@2d^/d0`l[O0<?:gP31b=d0`LOK0P33b]h01`2HWZd0@TA;020Q9@1BEE`0H6=]
05EGG`0S9BP01@0000003P0];c<0JFih06U^N01:CE@04Q<E05eRJP2i`]<0LGJ100`=3P0000002@T:
01PJ700G61X01`L80`0000000`0D5AL0J6]d0:fb`@030<76e`030<75e`31aMH0`LKF00L0`LKF0`31
aMD20<76e@<0`LGE1@31a]D20<;6e@030<;7e@33amD0`lOF0080`lOF00<0`lSE0<?7e@33amD00`34
b=H02034bMH0aLWF0<G9e`39cm`0dMWV0=?Kj03DfnT0`/SE0`3Cf^P30=?Kj0030=?Ki`3Dg>P0e=cX
0080e=_X00<0e=cX0=7Hi03Bf>D0203DfnL0103Cf^H0dm_W0=?JiP3Cf^H70=CKiP060<oEh038c]P0
dMOQ0=CIi03Df^@0e=WT0`3Df^@20=CIh`030=?Hh`3DfN<0e=WS00<0e=WS00H0e=WR0=CIh`3DfN<0
dmSR0<gBfP3>d]/30=CHh@030=7FgP3AeMh0e=SQ0080e=WQ00D0cm?L0<C8d03>d]X0dmOO0=GIh@04
0=OKh`030=SLi03Hg><0e]_R00@0em_R00h0f=cR0=SLh`3Hg><0em_R0=GIh03?dmX0al[A0<_?e@3F
f^00dMGJ0<W=dP2k_l<0dMKK0=[Oi0@0g>7V1@3Lh>H30=cQi@H0g>7T00<0g>;T0=cQi03LhN@00P3L
hN@40=gRi0030=gRi@3NhnD0gn?U0080gnCU00<0h>CV0>3Ti`3PiNL00`3PiNL00`3QiNL0VifN0000
00030000000700H61P0E5QD05AHE09^NWP3Vj^P0iN[X0>KZj0020>GZj0050>?Wi@3=dLl0i^[W0>KZ
i`3Kg]`00P3VjnP00`3VjnL0in_W0>O/i`020>O/i`80in_V0`3Wk>H01@3Vk>D0ingU0>O]i@3Wk>H0
in_U0080in_T0P3Vk>@30>K/h`040>O/i03Xk>@0ingT0>O]i0<0ingS00<0i^gS0>G/h`3Tk><01@3T
k>820>C/h@040>?/h@3Sk>00i>cP0>C]h@80iNgQ0P3Uk^401@3UkN40iNgP0>G]h03EgM40AdY604d0
0000303oool000X0oooo3P000000101VJWH0[KG90;c4f@34cN<20<?=hP80`l_P00<0`/_P0<79gP30
b=h00`33bn004P32b]l0`<SM0<C;h@34bn40_<CH09VO[`1KGVP0BdiF05aPJ@2=Tj80^;kA0;g4f032
bMd0];[=0<?:g`33b]h0`LSM0<77f`80`l[N00L0V9j]0494B`0P8BD0DUEL061SK@1EEel08bDX00D0
000000h0;Blc06U^N01YKWP0BTeD018C5@1MHVX0^L;C075fP@0<3@h0000000T92P0H6Q`05aPJ00L7
20<0000000<051DG06Q[M02]//400`31a]L00`31aML0`LGF0<76eP070<76eP<0`LGE0P31a]D30<75
e@D0`LKE0P32a]D00`32amD0`lOE0<?7eP020<?7eP030<?8e@33amD0`lOE00<0a<SF00P0a<WF0<G9
eP35bML0bLoL0=7IiP3CfnP0e=_Y0<;8e@<0dm[X0`3CfnP00`3CfnL0e=cX0=CLj0020=CKj0030=CL
j03Af>@0d]SU00P0e=_W00@0dm[V0=?Ki`3Cf^H0dm[V1`3DfnH01P3?eN00b<kH0=7Gh@3DfN@0e=[T
0=CIi0<0e=[T0P3DfN<00`3Cf><0e=WS0=CIh`030=CIh`060=CIhP3DfN<0e=WS0=?HhP3=d]X0c];K
0`3Df>400`3Ae]h0dMGN0=CHh@020=CIh@050<oCg034b=00c];J0=?Gg`3EfN40103Gfn<00`3Hg>@0
f=cS0=KKhP040=OKhP0>0=SLhP3Hg><0f=cS0=OKhP3EfN00cm?J0<O:d@3;cmD0e][P0=7EfP39cM80
^ko30=7Ff`3Jgn@40=cQiPD0g>3V0`3LhND60=cQi0030=cRi03LhN@0g>7T0080g>7T103Mh^@00`3M
h^D0g^?U0=oSi@020=oTi@030>3TiP3Pi>L0h>GW00<0h>GW00<0hNGW09^MWP0000000`0000001`06
1PH05AHE01DF5@2KWYh0i^[X0>GZj03Vj^P00P3Uj^P01@3SinD0cM7?0>KZi`3Vj^L0fmkL0080i^_X
00<0i^_W0>O[i`3Wk>L00P3Wk>L20>O[iP<0incV00D0i^cU0>O]i@3WkND0incV0>O[i@020>O[i080
i^cT0`3Vk><0103Wk>@0j>cT0>O]i03WkN@30>O]h`030>K]h`3Uk><0i>cS00D0i>cR0P3Tk>40103S
k>40hncP0>C/h03TkN420>G]h@80iNkQ00D0iNgQ0>G]h03UkN00eMgA04M:AP1=000000`0oooo000:
0?ooo`l000000P34cN<20<?<hP0T0<;;h@30b=d0`<SM0:bda`26SI/0QhjM09RO/02TZ[d0][gA0;[1
e@2`]lX0Y:Zm0:6W^@2;T9l0@dM=03@f?@20QY<0Z[310;Nnd@2f_M00]Kc>0;g4f02X[[l0Yjfn0;Fl
cP2k`MD0`<OK0;Jmc`2TZ[/0NGj:03<e>P00000010D500/;3@0<3@h01PH61@0000002@092P/05QLI
01HG6@0?41400P82030b=`1WK7D0?T5600L720050000000:02X/<01FFF409RP[00820P0m?d@0P8>?
0:fa`@2m`]<0_lCE0<35eP80`LKG1@31a]H20<;6eP030<76eP31aMD0`LKE00X0`LKE00<0`/KE0<;7
e@33amH00`33amH20<?8eP030<?7e@33b=H0a<WG0080aLWF00D0aLWG0<K:f038cM/0cM?P0=;Jj002
0=?Kj@040<oFh`3Dg>T0e=_Y0=?Kj0<0e=_X00@0dm_X0=CKj03Dg>P0e=cX0`3DfnP00`3CfnL0e=_W
0=CKi`060=CKi`0A0<37d@2MXj/0R8fD08nEW02UZk@0_L?=0<kEh03BfN@0^l;<0:R_]`2h_/L0SI6I
05MJG`2SZ;00d]SS0=?Ii03Aen40103Df^@60=CIh`080=GJh`3Df^<0e=[S0=?HhP3Ben00dMGO0=;G
h@3Cen430=?Hh@0:0=CHhP3DfN80e=WR0=CHh@3Ceml0/;Bk0=7FgP3Df>00eMWQ0=KKh`80em_S01L0
emcT0=WNiP3Ig^H0em_R0=KJhP3Gfn80emcS0=SMi@3JgnH0f=gT0=SLh`3Hg>80emcR0<;6c02`];X0
`<C:0=CHg`2n`/L0Ui^N06i`L`2^/[H0eM[O0=_Pi@020=cQiPH0g>3V00<0g>3U0=cQi@3LhND0103L
hND20=gRi@030=gRi03LhN@0g>7T0080g>7T0`3Mh^@20=gRi@050=kSi@3OhnD0gn?U0=oTi@3Oi>H0
1P3PiNL00`2HVi`00000000000020000000502HW9`22Q8@0PXB40<?7a@3Vj^P00P3Uj^P0103Vj^P0
i>WV0=oTh@2j_[`20>K[j0030>GYiP3Uj^H0i^[W00D0i^_W103Wk>L01P3Wk>H0i^gV0>O]i@3WkND0
incV0>O[iP80incU1@3Vk>@0103WkN@0i^gT0>K]i03VkN@20>O]h`030>K]h`3Tk><0i>cS0080i>cS
103Tk>820>C/h@80hncQ00<0i>cQ0>C]h@3UkN800`3Uk^401@3UkN40iNgP0>G]h02f_[<0:B/X04d0
0000303oool000X0oooo3`0000020<C=h`80`/_Q0180][kC0;c5fP2laMX0Ri>R034c>00A4Q@05aPK
030b>01FF680IFUd05ePJ`1CEUl0H6A^06a`O00l?TD0AdYB0:BZ_030b=`20<;:gP0>0<?;h02k`]D0
Uif/06U/N01VJG@0SiBS0;Nnd@2KXK40I6Qb03Tk@@0`<CH0=cTn02d_<`0A4A<<0000000400L7200?
3a402@T:00410@D0000000X0G61X0;c3e01DF5l07QlQ04e@E`1MGfL0LGAo08B7U02DV:D0/KG51031
a]L70<76eP/0`LKE00@0`/OE0<;7eP33amH0`/OF1033amH00`33b=H0a<SF0<G9e`020<G9e`040<K:
f03;d=l0dMOV0=7Ii`<0dm_Y0P3Dg>T00`3DfnT0dm_X0=CKj0030=CKj0H0e=cX00<0bM3L0<?9e@33
bMD00P33bMD05`32bM@0`<OB0;k4c`2W[KH0L7Aj02HW:P0000000`<300/<300[;C00SiBM0;JlaP1E
FEh08B8T03Li?00T9BL05aLH04U;CP1bMW/0MGUo0;6f_`3Cf><0e=WT00<0e=[T103DfN<50=GJi003
0=GKi03Ef^@0e=WS00<0dmOQ01T0d]OP0=GIhP3EfN80e=WR0=GIh@3Df>40cm?L0=KKh`3Ef^80e][R
0=OKi03Gfn<0f=cT0=WMi@3JgnP0f]oW0=OLh`3Gfn80emcS0=WNi@3Jh>L0fmoV0=SMh`3Gg>80f=cR
0080f=gS00X0d]KL0<oCf@3Cf=d0XJFY02h_<00K6ad0ATQ908J9S03Be]/0g>7V1@3Lh>H20=cQiPH0
g>7U00<0g>7T0=cRi03Lh^@00P3Lh^@50=gRi0080=kRi@3Mh^D0gN?U0=kTi@3OhnD0gnCU0=oTiP3O
iNH60>3Ui`0607n2PP000000000000<30`0Q8B40Gf5P0P3:cL`20>KZj@0<0>KZj03Uj^P0iN[X0>CY
iP3MhMl0TYFB09>FU@23QH@0T9>A0:NZZ03>dm00iN[W0`3VjnL00`3Vk>L0incW0>O/i`040>O/i`06
0>O/iP3WkND0incV0>O/iP3Xk>H0incU1@3Vk>@0103Vk><0iNcT0>G/i03WkN<20>G/h`030>C/i03T
jn<0i>cS00@0i>cS00<0i>gS0>C]hP3TkN800P3TkN801@3Tk>80i>cQ0>C/h@3TkN40iNgR0080iNkQ
00D0iNgQ0>C]h@3Uk^40UYfC00D61@1=000000`0oooo000:0?ooo`/0000000T04a@F02LY;@0J71l0
1PL80<39g`2]]/T0/kcA0<;;h@2h`=D00P2namd07`2=Tj@0G65Z05mSK@1[KgX0Nh6>06]`N`0Y:Rl0
1@D600h?401AEEh0UI^/059EGP1<D5L0X:Jh0;2gbP2PY[L0Z:k00<?<h02OYKH0I6Qb01lP8`000000
EEUR0:R_`01oPi40:B/_0000000l?d@0Ngn<06EXLP0V9b/05@0000002`0j?440MW^503Lj?P10@DL0
Ngn906=VKP0b<cP05aLI03Lh?@2>TYh0`/OH0080`/SI00<0`LOH0<76e`31a]H02@31a]H60<76e@80
`/OE0P33amH20<;7eP040<?8eP34b=L0a<SG0<C9e`80a<WH0P35bML01`39c]`0d=OV0=CKj`3Dg>/0
e=cZ0=;Jj03CfnT00P3Dg>T50=CKj@030=CKj03Dg>P0e=cX0080e=cX00<0c]GQ0;:h`P1QI6X01`0T
9BL00`0R92H06Q/M00T92P030000000400L8200k?D00E5ML02<T9P<0000000X00@8200H71`0:2P/0
2PX;055BF02DUil0[;6i0<35c`39c]P0d]SR1@3DfN<00`3Ef^@0eM_T0=GJi0020=GJh`030=KKi@3F
f^@0e=WR00D0eM[S00<0e=SQ0=GIhP3Ef^<00P3Gg>D07@3Gfn<0emcT0=OLi03Gfn@0fMgV0=[Oj03K
h>P0f^3W0=WNi@3HgN@0fMoU0=[PiP3KhNP0fn7W0=SMi03Gg>80f=gS0=SNi03HgN@0fMkT0=OLhP3G
g>40cM;F03lo@@0H61T01@D503<d=P3:cm@0g>7V00@0g>3V00@0fn3V0=cPiP3Lh>H0g>7V103LhND4
0=cRi@030=gRi@3Lh^D0g>;U00<0gN;U0P3Nh^D00`3NhnD0gN?U0=kTi@020=oTi@80gnCV00<0gnGV
0>3Ui`3PiNL00`3PiNL01P1UJ6P000000000000;2`/0LgIe0;g0`080gN7P0P3Vj^T03P3VjnT0iN_X
0>K[j03Uj^P0g^?P0;>g]@2i_KX0RH^:08jAS`1iNgX0dmSE0>?Xi@3VjnL0i^cW203Wk>L01`3Wk>H0
ingV0>O[iP3Wk>H0j>cV0>O/i@3Vk>D00P3Vk>@30>K]i0030>G/i03Tk>@0iNcT00@0i>cT103Tk><2
0>C]h`D0i>gR00@0i>cQ0>C]h@3TkN40iNkR1@3Uk^400`2AUhh000000000001<000000`0oooo000:
0?ooo`/0000000P0>3]107=hQP1?Ded0=SPn05EJH`2PZ;X0/;S<0<?<hP<0a<gS01l0V9n`08fCXP2d
_M00^L;F0;g5fP2c^ll0G61Z00`<3P0?3a40EeYT09jU]`1GFV@0CE1H09fS]02FW:`0E5MP07AiQ@33
bn00OX>@034c>00;30d0000003Li?`1bMh80LgJ205IIHP0b<cT0EeYS096GY@1dN8<0;2db01D00000
00h020P9010@4P0<30h0CU5H09RLZP1jOXP0=3Dj0000000N7b80QHVD0<;7f033b=T0`/SI0<;7f080
`LKG1@31a]H01@32a]H0`LKF0<76eP31a]H0`/KF0080`/OF0P32a]H70<;7eP040<?8e`34b=L0a<SG
0<C9e`80a<WH00@0aL_I0<W>g@3?e^@0dm[Y1@3Dg>/00`3Dg>X0e=cY0=CKj@040=CKj@030=?Kj03D
g>P0e=cX0080e=cX00D0XJN`04A6BP0k?400>ce005ULH@0202l`<`0300@410000000000001800000
00H00P<301<D5@0[;2l0ADM;09>HW`3Aen420=CJi080e=WS00<0eM[T0=GKi@3Efn@00P3Ef^@20=GK
i0<0eM[T01L0e][T0=GJh`3Ef^<0e]_S0=KJh`3Ffn<0f=cU0=OLi03Gfn<0emcT0=SMi@3HgNH0f]oX
0=_Pj@3KhNP0fn7W0=[OiP3Jg^H0f]oV0=_Pi`3KhNL0fn3V0=SMi0020=KLhP030=KLh@3Gg>80em_Q
0080emcQ00P0emcR0<W>e@2EVId0:2TZ01`M7`2HVj00alcA0=CIg`D0g>3V0`3LhNH20=cQi@D0g>;U
00<0gN;U0=gRiP3Mh^H01@3Mh^D02@3MhnD0g^?U0=kTiP3Ni>D0gnCV0=oTi@3Oi>H0gnGV0>3UiP04
0>3Ui`0607EhN0020P80000000h>3P2FVIT0iN[Y0`3Vj^T50>GZj0090>?Xi@3;d<d0Y:RV0<_?c@3M
hn00_<2n0<oCd03Uj^L0i^_X00@0i^cW0`3Wk>L0103WjnH0incW0>O[iP3WjnH30>O/iP030>O]iP3W
k>D0i^cU00@0i^cT00<0iNcU0>C/i03Tk>@0103Tk>@30>C/h`H0i>gS0`3TkN820>C]h@070>C^h@3U
k^40iNkQ0>C^h@3SkN00h>WM08F;P`1>000000`0oooo000:0?ooo`/0000000P0DEEN0:F]`01cNHH0
HVMb0:ZbaP2ma]/0`<WO0<?<h`<0a<gS01@0[;G808nEY@29Sih0WjJh0;k7g02f_]80H6E_00`<3P07
1`P0:B/`04a?F00Y:c00B4YB09bR/`2BV:P0@dE<04U<E026S9X0BDaD00`=3P80000000T092HY06ib
O@2LX[<0X:Jg08F:U`1SIg40FEaU03`nA00G5aX05`0000003P030`<0;2hb05EHH014Add07AhP0000
000H6A/0Jfig0:b``02e^/X0^;g<0<35eP32amP0`LOG0P32amL00`31a]L0`LKF0<76eP050<76ePT0
`/OF00<0`lSF0<?8e`33b=L00P33b=L01`34bML0a<[H0<G:f038c]`0c]KT0=;Kj@3Dg>X01@3Dg>/0
103Dg>X0e=cY0=?Kj033bmL20;_1c@0;0;o6dP3;dn00c]KS0<kFh`3AfNH0e=_X0:2U[P1nPhT0a<cF
0<_Bg@3Fg^T00P38cmT00`2VZk@0Ri2G08^@U`0208^@U`0506ibN01AE5P0DEAH03`n@@0M7Ql01@0K
71h00`0;30`00000000000070000000403Dg>P2`]Kh0dMOR0=?Ih`80dmWR00@0a/_D0<?9d@3Efn@0
e=[T0`3Ef^<30=GJi0060=KJi03Ffn@0emgU0=SOiP3HgND0emcU0P3Ig^L0403HgNH0fMkV0=WOi`3J
h>P0f^7Y0=_Qj03Jh>L0f]oV0=SMi@3GgN@0f]oV0=_Pi`3Jh>H0f=kU0=KLhP3Efn420=KKh@0=0=KL
h@3Gg>40emcR0=SMhP3Ig^@0g>;W0=[Oi@2WZjl0BT]>01dM7P0h>CX0TiJJ0=cPi`030=cPiP040=_P
iP3LhNH0g>7V0=cQiP@0g>7U203Lh^D20=gRi@040=kRi@3NhnD0g^?U0=kTiP80g^CU0P3Oi>H50=oU
iP070>3UiP2KWYl020P80000000?3`l0V9bK0>GZj@030>KZj@030>GZj03UjnP0iN_X0080iN_X00L0
iN[X0<oEdP2n`/00hnWV0=kSh02l`;h0g>7N0080i^_X0P3Vk>L00`3Wk>L0i^_X0>K[i`030>O/i`03
0>O]i`3WjnL0incW00<0incW0P3WkNH00`3XkNH0ingU0>K]i0020>K]i0030>G/i@3Tk>D0i>cT00H0
i>cT0`3TkN@50>C]h`<0i>gR0`3Tk^820>C^h@030=cVfP2W[JD0?d8n04h00000303oool000X0oooo
2`0000001P0`<SP0JFik06=XM01ZL7`0YJg00<7:h@80`/_Q0`33c>802@31bMl0WjJh05EIHP1@De`0
OhFD07MmR@15B50092HY018B500200H61`0D00<31013ATd0W::c09>IZ00n@4H0>3Y006Q/M`1TJ7<0
GV5/069WL@1CEUl0A4I=096FY@31b=/0`LSL0;o6f@1`M7l0824T00@41@020P8G0000000>00410@0:
2P/04a<E00l?4@061`L0000000`=3P0h>Ch0OH2;07AhP@2NX[40/kW80<?8fP32b=P20<?7f0030<;6
e`31a]L0`LKF00H0`LKF1`32amH00`32b=H0`lSG0<?8e`030<?8e`070<C9f035b]T0aL[I0<W@g`3@
f>H0dm_Y0=?LjP030=CLj`0:0=?Lj`3Dg>/0dm_Y0=?Kj@3Bf^P0cmGQ0=?Ji`3@en@0alkK0=;JiP80
f>3]0P3IhNd01@3:d]h0dMST0=[RkP3JhNd0f=o/0080f>3/1@3Jh^d0103IhN/0f=oZ0=SOjP3Bf^@2
0<[Af`0;0<cCg03;d]/0b]7J0<[AfP2f_<D0VYjV07YoQ028SY<0Z:ff08R>T`1bMW/00`1cMW/00`1l
Oh@0T9JL0<35c`020=?Ih`040=CIh`3=d]`0algF0=GKi@L0eM[T00H0eM_T0=KLi@3Ih>H0fMoV0=KK
i03Gg>D20=[Pj080f=kV00H0f^3X0=[Qj@3JhNP0f^3W0=WNiP3Hg^D20=SMi@040=[Oi`3Jh>L0f=gT
0=KKhP80eM_Q00l0e]_Q0=OLhP3Gg>80emcR0=SNh`3Jh>H0fn7W0=cQi`3MhNL0gN;X0=;Hg@2c^;d0
PHF7071bMP34ald00P3IgN<0103MhNL0g>7W0=cQi`3LhNL20=cQiP<0g>;V0P3Lh^D30=cRiP<0gN;V
00<0gN?V0=gSi@3NhnD00P3NhnD0103Ni>H0g^CU0=kTi@3Oi>H40=oUiP080>3UiP3OiNH0gnGV0;Fj
^P0I6QX0<C8b08>5Q@3CemH50>GZj@D0iN_X00L0iN[X0>GZi`3Qj>D0^Kfk0<K;b03Ae]<0hnSU00@0
i^_X00<0i^cX0>K[i`3Vk>L0203Wk>L01`3WkNL0ingV0>O]i`3WkNL0i^cU0>K/i03VkN@00`3Tk>D2
0>C]i@L0i>gT1P3TkN<60>C^hP030=WRe`2RZJ40@D=004l00000303oool000X0oooo2`0000002@0B
4QD0E5QR08N>WP1QIW40F5aV0<;<h`30b^00ZK740::Y^`020:>Z_@0M09:HZ@1VJWH08bDY00L8200>
3a40:R`a069VL@1lP8h0NX2>07MmRP1hOHX0H6=_06EYM023RIL0M7V503`nA@14B4l0QH^I0::Y^`2/
/lD0/;O90:F[_@1RIW40J6af09:HY`2FW:/0QhbJ04I9D00A4Q<08000000020020P80S96N02d^<P3>
enP0c=CV0<G;g@32b=T0`/SH0P32amP40<76e`80`LOG00<0`/OG0<;7eP32amL01032amL20<;7eP@0
`lSG00P0`lWG0<C9f034b]T0a/cJ0<G;fP3<dn80d]_Z0=?LjPH0e=c[00X0d][X0=CMjP3Hh>h0e][X
0=OOk03Hh>d0d=GQ0=3Dh02j];l0a<7<0P3Jh^l01@3FgnX0f>3/0<G=f02l`/h0e=_X0080dm[W00@0
cMGP0=CLi`3Hh>/0f>3[0`3IhN`50=[Rk0030=WQj`3Hh>X0fN7[0080f^;/00<0emcU0<o<d`3FfN80
103Jh^/20=[RjP060=WRjP3EfnD0e=[T0=CIi03DfN<0e=[T0P3EfnD01@3FgNH0emcV0=GKi@3Efn@0
e]_U0080e]cU00D0emcU0=OMi@3GgND0emgV0=SNi`020=WOi`080=OMiP3Efn<0e]cT0=SNi`3Hg^H0
f=gU0=SNiP3Ig^H20=SNi@040=SMi@3Jh>L0f]oW0=OLi0<0e]_R00D0e]cR0=OLhP3Gg>80f=gS0=WO
i@020=_Qi`030=cQi`3LhNP0g>;X0080g>;W00<0f]oU09VMX029Rhl00P2i_<40103Lh>L0g>7V0=_Q
iP3KhNH30=cQiP80g>;V0P3Lh^D40=cRiP030=cRi@3LhnD0g>?U0080gN?U00D0g^?V0=kTiP3Ni>H0
g^CV0=kTi@050=oUiP070>3UiP3Oi^H0gnKV0=;Hf01DEUH0QHR80>?Xi`020>CZj@80iN[Y00@0iN_Y
0>CZj03UjnP0iN_Y103UjnP01P3Rin@0gnCQ0<75``3TjNH0cmCA0>3UhP80i^_X103Vk>P00`3Vk>L0
incW0>O/i`060>O/i`030>O]i`3Wk>H0ingW0080ingW0P3WkND00`3VkND0iNgU0>C]i@050>C]i@03
0>C]i03UkN@0i>gT00<0i>gT00<0i>kT0>G^i03Uk^@00P3Uk^<20>C^h`80i>kR00@0iNoS0:>ZXP0]
;R`03@d=C`00000<0?ooo`002P3oool<0000000805iSKP2OZ;X0LWR601dO8P0?4180MG^804Y=E00P
8RD202HX;00M03<f?00k?D<0;Bhd02PY;@0Y:Rl0EUUS09fT]@2_^</0^/;F0;g5f@2na]/0/k[=0:F/
_P2GWZh0QX^I071ePP1LH6X0NGj;0:>Y^P2la=P0`LSM0;k5f@1bMh@0;c4f038c>00b=3T0;c0e01PI
70061PL0500000000`0V9b/02``=0000000;0000000802<U:03@fN/0^/;B0<[Ah`35bmd0a<WK0<?8
f@33amP70<;7f0040<;8e`32b=P0`/SG0<;8e`<0`lSG00L0`lSH0<?8e`34b=L0a<SG0<G9f036bmX0
b<kN00<0bLoN00@0c]GT0=?Kj`3Dg>`0dmc[0P3Dg>/03@3DfnX0dm_X0<[=f`37aM80b/KB0<C8d`30
am<0cMGS0=CLjP3Ggn`0cMCP0<_=f@3@d]h00P3Jh^h01@3Cg^00eMOS0=;GhP3Ggn/0emk[0080`<KA
01H0Y:Zd0;g4cP30b=80XZRa0<_Bg@3Af><0^/7;0;g4c@2m`ld0_lK?0<S@fP3Eg^L0e]oY0=GMj03H
h>X0f^?/0=[Sj`3Deml0`[:h0=3?eP3Df>00eM_R103Jhn/01@3KhnX0f>3Y0=KLiP3Ef^D0e=WT00<0
e=[T00D0e]cV0=KLi@3Ef^@0eM_T0<cBfP020<K=e0040=?IhP3Efn@0eM[S0=KKi080f=kW01D0e]cT
0=GKh`3Df^80eM_S0=KLi03Ffn80e]_S0=KLi03Hg^H0fMkV0=OLi03Fg><0fMkV0=_Qj03Hg^D0emgT
0=OMh`3Gg><0emcR0=KLhP3GgN<01@3KhNL20=cQi`<0g>;W00X0fn3V0=?HgP3>d]P0c];H0<gAe`31
a//0bloD0=_Pi@3LhNL0gN7W0`3Mh^L0103Mh^H0g>;U0=gSiP3MhnL30=gRiP<0gN?V1P3Ni>H50=oU
iP080=oViP3Pi^H0h>KV0=CJfP2a][@0aL_90>CZj@3TjnT:0>G[j@090>G/j@2_];80_/;00:2SX@2I
W9X0QXV80=;He@3UjnL0i^_X00@0i^cX00D0incX0>K/j03WkNP0ingW0>O/j0020>O]j0040>O/i`3W
kNL0ingW0>O/iP<0ingW0P3XkNL00`3XkNH0ingU0>K^iP020>G]i0<0i>gU00@0iNgT0>?[hP3PjN00
i>gT0`3Tk^@20>G^i080i>kS00H0i>gS0>7[g`3Cg=40b]?80:J]Y01<Cd]A000000`0oooo000:0?oo
o``0000000P0;Bld04]?F02DW:d0BDeE04mDG02=UJD0LWN404a@F@80>ce400@0E5MQ07b1T021QiH0
UYb^0P2PZ;X04P2FWJh0X:Rj0<38gP2na]/0_LCI0;k6f`2la=T0`L[O0<79gP2e_M00KgB003Pj@01/
L7/0[;?50;W1e@2NYKH0@dI=00/;31X0000000<08bDY0000000000000P0000000`0D5AL000000000
00050000000900P82@0:2`/0Jg1j0;_2dP39dN80b];R0<K<g033b=P0`lOH00D0`/OH1@32b=P20<?8
f080`lWI02<0a<[I0<K<f`38c]d0b]7P0<gDh`3?enH0cmKU0<gEi@3>eN@0d=SX0=CLj`3Eg^d0d=WX
0<_Ch@3AfNP0cmSV0=CLj`3@e>80al7>0;jd_`31]/40cmCQ0=?Kj03Dg>X0eMgZ0<?:eP2^]<00ZJni
0:fd_P3=e>40d][V0<O>f@3Dg>P0fN7]0=WRk@020;Rob00B0<oFh@3EgNT0e=gX0=7GhP33][l0aKk7
0=3Ih`36c]L0`LWB0;c4c@2oa]00[[Bm0<C;e@3CfnH0_/G>0:jd_@3>e]l0dMWQ0P2k`lX01@37c]H0
eMkV0=KOi`3FgnL0fN;Y0080f^;Z00`0fN7Y0=SPj@3Gg^L0eM_U0=?Ii03CfN<0e=[T0=GLiP3FgNH0
e=_T0=KLi@3=dm`20<oFgP0:0=GJh`3Ef^@0eM[T0=KLi@3IgnP0emgV0=GJh`3Df^<0eM_S0=KLi080
eM_R00X0e]cS0=OLi@3IgnL0f^3W0=OLi03Ffn<0emgT0=SNi@3Gg^D0emgT0`3Gg><00`3GgN<0f=kU
0=_Qj0030=_Qj080g>7X0P3LhNL20=cRi`090=cRj03Mh^P0gN;X0=gRj03Cf=d0SY6F07YmO`33bLd0
gN?W0080g^CW0P3Mh^L0103Lh^H0fn;U0=cSiP3NhnL20=gSi`030=kSiP3Ni>H0g^CV00H0g^CV00<0
g^GV0=oUiP3OiNH0103OiNH01@3Oi^H0h>KV0=OMg@3Sj^T0i>[Z00<0i>[Y2@3UjnT02@3Uk>T0];Rg
0<C8aP2b][<0a<W60=GJe`37c<X0gN?O0>K[j0060>K/j080ingX0`3Wk>P70>O]i`050>K/iP3Nhmd0
fMoH0>7Xh03VkN@00P3Vk^@30>G]i@030>G]i03Jh=P0iNgT0080i>kT103Uk^@0203Tk^<0hngR0>;/
h@3>e/`0J6eX04Y>BP0^<2h03Ph>D@00000<0?ooo`002P3oool<0000000800830`0000000`<406I[
M`2PYkX0`L_Q0;_4f`2b^m020:B[_`0H0:>[_@33bn80`<WO0<39g`31b^00`<WO09bS]@2@UjL0^<7E
09JM[P24R9L0X:Ni0:Za``2[//D0]koC0:>Z_01BEEh0000003Hh?@2:T9l0XJRi065UK`0?41400P82
0P000000200^<3D05QLI03<f>`0S92P071dP02la=P0R8bH02``=400000000`0U9bX0000000000009
0000000901LH6P0^<3@0<cHj059FG@0e=S/0^/;B0=;Kk@39d>40`lWI00@0`lSH1033b=T30<?9f@0M
0<C:fP37cml0bm?R0<cCh`3=eN@0cmOV0=7Ij03AfNT0dmc[0=CMk03Dg>`0dm_Z0=KOk@3Gh>l0eM[Y
0=;Ii`3>e>80cmCS0=;Kj@3<eN80a/kL0;[1cP2//kh0a<_H0=7Ji`36cMX0d]_X0=CLjP3Ggn`00P3F
gn/0203=eN40d=WT0=CLj03=eN00`<OC0:bc_@2V[;D0/;O00P2V[;H0102oa]00f>7/0<G=e`37cmT2
0=OQj`0Q0=GOj@3HhN/0fN;/0=WRk03Bfn@0dm_U0=?Li@3DfnH0`l_D0<[Bf`3DgNH0b=7I0<C=d`2h
b[P0[/2]0;2i_02X/[40[[Fl0;k5c03?f>00^<360;Fk`P3?eml0c=?K0<K=e@3;d]/0cmKO0=7Gh@3B
f>40d]WQ0=CKi03Fg>H0eM_U0080eM_T0`3Ef^@02P3Fg>D0fN3Y0=ONi`3Efn@0e]cU0=SNi`3GgND0
e]cT0=KLh`3GgND20=SNiP030=OMi@3GgN@0e]cS0080e]cS0P3Fg>80103Fg><0e]cR0=SNi03Jh>L4
0=_Qj0<0fn7W0P3LhNL00`3LhNP0g>;X0=cRi`030=cRi`0<0=gRj03Fg>40Yj^`08J9R`2V[:h0g>CU
0=kVi`3Mi>L0gN?W0=cRiP3Lh^D0gN?V0P3MhnL01@3Mi>L0g^CV0=kTi`3Ni>L0gN?V0080gNCV0P3N
i>H50=kUiP80gnGV0`3Oi^H00`3NiND0hn[Y0>C[j@020>C[jP030>C[j@3UjnT0iN_Y00L0iN_Y00<0
iNcY0=7Fe03VjnT00P3Vk>T00`3VjnT0i^cY0>K/j@030>K/j@D0i^cX00@0i^gW0>O/j03Wk>P0ingX
1`3WkNL01@3Ujn@0dmWC0<kBc03JgmT0ingV00<0ingU0P3VkND00`3WkND0inkU0>G^i@030>G^i@08
0>K^i03Tk>80i>kT0>7Zh02c^[80ZK6Y07n5O`0H6AQD000000`0oooo000:0?ooo`/0000000T00@41
03<f?00N82@0A4M?09FL[@2maM/0`/cR0<?<h`32c><00P32bn808P31b^00`lcR0;S0e@2e_M80];cA
09fU]P1ZKgX0LWN409FL[@1<D5P05AHH03/m@`1OHfd0SiFU0:V``P23RIL0;Blc0000000L7B00B4]C
05=FG`0W:Bd0000000`=3P0h>d40BTeE06idO`0l?dD0Ri>Q05aQJ`15B4l0N7f905IIHP0L7B0@0000
000300d=3`000000000000T0000000T0CE1G09ZQ[`2U[;/0Z:no07AiP`2Y/L00dM_/0<_Ci@36bm`0
0`34bMX01P35b]/0a/cM0<K<g@36cMd0alkN0<S@h080bM3P00@0b];R0<kGiP3Bg>`0dmc[0P3DgN`0
603@fNT0c=GU0<_Dh`38dMl0aLgL0<S?g03Fg^d0/k:n0;:d`02k`m00e]k]0=OPkP3DgN/0e]k]0=CM
j`3=eN<0c]KU0=KNk03@f>H0b=3M0<O?g03;dn00eMk[0=SQkP80f>;^00L0en3/0=SPk@3Hh>`0d][V
0=?Ki`3Eg^T0bM7K0080_<?>00P0e=kY0=OQj`3:d]d0cmSR0=SQj`32bm@0]kk70:fe_P80/KW101d0
XJN^09:IX032b]<0c]SP0;2g`033bm<0cmSP0<gFgP3@f^40dMkK0<cHeP3Af^40^<;20=CMi@38cmL0
d][R0<_Cf`2^]K/0b];J0=7Ih@3;dm/0c]GM0<G;e02QYZd0XjV_0;g2c035bmD0c=?L0<O=eP020<O<
e@040<W>f03:d=T0c=7K0=7Gh080fMoX00@0emkW0=SOi`3JhNT0f=oW0P3Fg>@20=WOi`040=GLh`3E
fn<0e]cS0=KKh`80e]cS0P3Fg>820=OMh`030=SNi@3KhNP0fn7X00D0fn7X0P3Kh>L30=_Qi`80g>7W
0`3Lh^P01@3MhnP0g^CY0:R]/@1aM7H0fN3Q0080gnOX00<0g^CW0=gRi`3MhnL00`3MhnL0103Mi>L0
gNCV0=kTi`3Ni>L30=gTiP030=kTiP3NiNH0g^GV00D0g^GV103Oi^H00`3PinH0hnWY0>CZj@050>C[
j@@0iN_Y00D0i>WW0>3Vi03Tj^P0i>_X0>7Wi@040>G[j0030=gSh03Vk>T0i^cY0080i^cY1@3Vk>P0
103VkNP0ingX0>O]j03WkNP70>O]i`050=oTg`3XkNL0j>gW0=oTgP3XkNL00`3Xk^L0403Xk^H0inkU
0>O^i@3WkND0i^kU0>G^i@3Tk><0iNkT0>K^i03Uk^@0iNoT0=[Sf@0i>cT0410@00l@3`0410AD0000
00`0oooo000:0?ooo`/0000000T01@D603XmA021QiL0Yk340<3:h031b^40`/_R0<7:h@32b^400P32
bn804`32c>80`lcR0;c5f`2?UZL0IF]f04]?E`1;D5P0Jg1l06AYM00m@4L0<SDj02d_=00g>T00QhfL
0;Jod`1]LWh05aLJ00d=3`0D51L00P0K71l03@0=3@l04Q<E04M;DP2@UjL0XJVi03m2B@0n@DL0SYJT
06E[M@1SIg80YZbn07EjQP0W:Bd0700000002@1?DUT0WZBc0:jea@30bMX0W:>`0;>kbP37d>40a<cM
0<O>gP030<[AhP030<cCi03>e^L0c]KW0080cmOX0`3@f>T06`3@fNX0dM[Z0=7Kj`3Bg>/0e=g]0<WB
h@36c]h0c=GU0<oHi`2]]L80a<gK0=?Kj03Fg>/0cL_J0=3Fi03Fgnh0f>7`0=SPk`34cMX0/kc70=3H
iP30am@0_<?@0=OOk@3Hh>h0f>7^0=OPk@050=SQkP070=;Ki`3IhNh0fN7^0;S0bP2e_LL0eMkY0=3I
i0020;>i``030=GMj03Hh^d0f>;]0080f>7/00<0eMkX0<?<e@2k`ld00P3Eg^P07@34cML0b]?M0<O@
f@3=eMh0`<S@0:fd_02f_LD0/KW10:^b^P2^];`0][g40=GMi@31bM00dMWQ0;>i`@2`][d0XZR_0::Y
[`30b<l0dMSQ0=GLiP3Gg^P0eMcV0=3Gh@3Df^@0f=kY0<gDg@3?eMh0c=?M0080^l390180/[S00<S>
eP3@e]l0e=[S0=OMiP3Gg^L0fN3Y0=[Pj@3Jh>P0fN3W0=ONi@3Gg^H0fMoW0=SNiP3Fg><0eM_S0=KK
h`3Fg><20=KLi0050=OMh`3Hg^D0f=oV0=WPi`3Jh>L01`3KhNP30=_Pi`80fn7W00<0fn;X0=cRj03L
h^L00P3Lh^L02P3Lh^P0gN?X0<gBe`29SY00_L?50=_Si03OinP0g^KW0=kSj03Ni>P70=gTi`80gNCV
00@0g^CV0=gTiP3Mi>H0g^CV0`3NiNH30=kViP@0gnKV00<0h^WX0>C[jP3TjnX00P3TjnT:0>G[j@03
0>G/j@3Vk>T0i^cY00D0i^cY103Vk>P30>K]j0050>O/j03VkNP0ingX0>K]j03VkNL01P3WkNL01@3L
h]`0j>gX0>S^j03KhM/0i>[T0080inkW00<0j>kX0>K]iP3Oi]h0103Wk^D00`3Uk><0iNgT0>G^i@02
0>G_i@030<37`00H61P0000005H00000303oool000X0oooo2000000030010@400000000000092@X0
I6Ue0<7:h@33c><0`lgS0<?<h`32c>80[KK;0:2W^`80/k_@0180_LOM0;6jcP25Ri/0>3]200@51@0L
7B00IFUe09FK[01QIW40MG^80:2X^P2NYKL0U9^[0:^ba@2h`=@0Ifag02ha=P1<CeP205]NJ00>04iA
F@0V:2`09BHZ079gP`2RZKX0RHnM02`^<P0T9BX0G61Z06eaO@1RIW40IVYe04A6C@0G5aXL0000000=
01PJ700a<cP0BDeD06U^M`27S9P0bmCV0:bd``1kPH`0_<CD0=;Kk@3BgNh0d]g]0=?NkP030=?MkP@0
dmg]01X0e=g]0=?Lk03@f^T0b]?S0<G>g02LXjl0XJNc0:nga@2U[[X0YZfi09fS[P2d_<T0aLkL0<_D
hP3BfnX0e]o^0=SQl03Hh_00dM[X0=OOk@3HhNl0c=CR0<_DhP3Gh>h0f>7_0=SRk`L0f>7^0P3IhNh0
103Af^D0e=gY0=OQk03Dg^T20<oHh`030=OPj`3Hh^d0fN;]0080f>;/0280fN;]0<O@f@3Cg>H0f>7/
0=SQj`3Af^<0e^3Y0=?LiP3:dm`0`L[B0;Fla03GgnP0e]kW0;6h`032b]80c=CL0=KOi`3Eg^H0d=WQ
0;W0a`39dMP0aLgD0:BY/02X[[H0`LSA0=?Ji03=dmd0`lWB0<K=eP3?eMl0e]gW0<?9dP2b]kl0`lWB
0P2l`l/00`2h_/L0dMSR0=GKi@020=GKi00;0=OMiP3Ih>T0f^3Y0=[Qj@3JhNP0fN3W0=WOi`3Ih>L0
emgV0=KLi03Ffn<00P3Fg><00`3GgN@0emkU0=SOiP040=[Qj0H0fn7X00<0fn3X0=_Qj03KhNP00P3K
hNP00`3KhNL0fn7X0=_Rj0020=_Rj00<0=cRj03Lh^L0g>?X0=gRj03Ffn00_<750;Ro`03OinP0h>OX
0=oUj@3Oi>T0g^CY0`3Mi>L80=gTiP040=gUiP3NiNH0g^GV0=kUiP@0g^KV0P3Oi^H00`3Pi^H0h^WY
0>C[jP050>C[jP030>G[jP3UjnT0iN_Y00@0iN_Y0`3Uk>T:0>K/j@D0i^gX0P3WkNP30>O]i`<0ingX
00H0ingW0>CZi03WkNP0ingW0>G/iP3VkNL20>O^i`0>0>7Xh@2EVYD0TYF@0<?:`P3Dfm<0i>_S0>O]
i@3Vk><0i>cS0>G]h`3Oj=l0dm_B08fBS00G61MG000000`0oooo000:0?ooo`P0000000`08B<W0000
000000002@T:06AYM@31b^40`lgT0<?=h`2nb=h0WJBg05mTKP0h>d4205=GH@0R06idP01DF6809BH[
00T92`0F5aT0DUIO09>JZ`2f_m@0PhVH0:bdb031bMl0`<WO0;o8g@30bMl0_LKJ08B:V01GFfD0SYBT
0:V```2Z/<<0UYb]065TK`16BE00MWZ708jDXP1IGFH04A4C01lP8`1XJgL0XjVk06=WLP0T9BT0410B
00D51PL0000000<07QlR0000000000004P0000003`0M7b40000001dN8@1@E5/0KW=m08nFXP1RIfl0
>3]00:fea03@fN/0cmWZ0=7Lk@3BgNh0dmg^0=;Lk@020=?MkP0A0=CMkP3=e^L0cMKW0:R`_@2BVJ@0
IFYa05=GG@1]LWX0OH:<08nFX@2OYk80BdeC0=OPl03Fg^h0dmc/0=;KjP3DgN`00`3HhO000`3DgN/0
d]_Y0=7Jj0020=SPk`D0f>7_203HhNh60=SRk@030=SQk@3Hh^d0f>;]00<0f>;/00@0e^3Z0=SQj`3H
hN`0f>7/0`3HhN/06P3<eMh0_lO@0;6h`02//[X0`l_C0<;9dP3Eg^L0^/;90;>j`@3@fN40e=gU0<K=
e@3:d]T0e]oW0:fd_03HgnX0dm_U0=3Gh@3Aen40dmWT0=?Ji03Df^D0eM_U0<gCg@3:dMX0bM3I0P3>
eMl01@33b=80cmGO0=GKi03EfnD0eMcU0080emkV00L0f=oW0=[Pj@3Jh>T0f^3Y0=SPj03GgNH0e]gU
0080e]cT00@0emkU0=SOiP3IgnL0fN3W0P3JhNP01P3KhNT0fn;Y0=_Rj@3Kh^P0fn7X0=[Qi`80fn7X
0P3Kh>P30=[Qj0@0fn7X0P3Kh^P02`3Kh^L0g>;X0=cSj03LhnP0gN?X0=_Pi@2TZJ/0f>3P0=oWj03O
iNT0gnCZ0080g^CY103Mi>L20=gTiP80gNCW00<0g^GW0=kUiP3NiNH00`3NiNH60=kViP040=oViP3Q
j>P0i>_Z0>C[jPH0i>_Y1`3UjnT00`3Oi^<0f=oL0=kUhP020>G/j@<0i^cY00@0i^cX0>K/j@3VkNT0
i^cX0`3VkNP01@3VkNT0i^gX0>K]j03VkNP0ingX0080ingW0`3WkNP01@3WkNL0ingX0>O]j03WkNL0
inkX0080inkW00P0dMOA02h_;P0B4Q80;Rl^03i0?@2LXI`0fn;I0>O]i@80i^gT00@0hn[Q0>;Yh02c
^;40<C<aE`00000<0?ooo`002P3oool8000000060454C0000000000000h>401TJGD0`<[Q0P33cN@0
102V[/40I6Ye05eQJ`1GG6H203XnA00P02DV:P0W:2d061TL00D51@0[;S<0Q8ZI0:nhc02laM/0Zk?6
0;g6f`32bn40`/_P0<7:h031b]l0_LGJ09BK[01GFfD0MGZ708^@X02BV:T0W::c09NM[P1lPHl0G5mY
05iRK01]LGd0EEQQ055CG01ZKWX0QHZH04Q;DP0;2``90000000304=6C@000000000001@000000100
@4980;:jbP1fNhD02@X;00<30`0G61X0Z[;00<[Bi038cn00c]KW0=;Kk03?fNX0d=[[0=;Lk@3BgNd0
bM;R0P2Z/[l02P0`<cH0BDaA05=GG@0G61X0GV9Z0;c4e029SiX0U9ZT08Z?V`3=eN@30=KOk`070=OQ
l03HhO40f>7`0=SQl03Eg^d0emo^0<kFi0020=SQl0040<kGi03HhNl0f>7_0<kGi080f>;_00@0d]cX
0=OPk@3Gh>d0en3^0P3HhNh30=SRkPL0f>;]0`3Gh^`30=SQk0D0f>7[00X0f>7Z0=;Ki03Eg^P0e]kY
0=OOjP3Hh>/0bm;M0=7Ii03Fg^P0cMCN0P2d^/<03@3?en00Z[2i0;2f_`2`][h0aL_E0=;Ih`3Bf><0
d]WS0=CJi03Df^D0dm[T0<oFh03Fg^P00P3Eg>H0103Ef^@0e=[T0=CJi03Efn@20=GLi@0;0=GKi03E
g>@0f=oW0=[Pj@3JhNT0f=oW0=ONiP3GgND0emgV0=ONiP3Ih>P01@3JhNP20=_RjP050=_Rj@3Ih>L0
f^7X0=[Qi`3Kh^P00P3KhNP60=[Qj080fn7X0P3Kh^P0103Kh^L0g>;X0=cRj03LhnP20=gSj0050:Z_
/`2l`l<0gnOX0=oUj@3Oi>X00P3Ni>T00`3Ni>P0gNCW0=gTi`020=gTi`@0gNGW0P3NiNL00`3MiNH0
g^GV0=kUiP060=kViP030=oWiP3QjNP0i>_Z00H0i>_Z103UjnX00`3Uk>T0iN_Y0>G[j@040>G/j@T0
i^cY103VkNT00`3Vk>L0ingX0>O]j0030>O]j0040>K/i`3Wk^P0ingX0>O]i`80inkX00H0inoX0>?Z
i03Tjn@0i>_T0:nd/00@410300000009020Q801RIF40P8Ao0:^aZP2a]jl0Q8R307AhL`1KGEX06AXI
05L00000303oool000X0oooo2`0000002@0`<SP0ATYB09FM[`2e_]@0YJk107AiQ`1cN8H0Y:c00:jg
b`0209jV^00908jDYP2JX[@0T9NX06M]N@1GG6H0PhZI0;6ic@30b]l0`<WO00<0`/_Q01@0_/OL0;o8
g02PYkT0HVI`030b=`0c=C/0?3m6061TK`2PYkT0][gA09jU]P15Adl0DeMP0:F[_@2FWJd0QH^I05UL
IP0j?4807b0T00D51@T0000000<0<38g0000000000000P000000100?4140:B``02HX;00B51H;0000
000C01@E5`061PH000000000001UJG<0Ce=J00h>3`00000030`=06aaN@2U[;/0`<KG0<S@h@3?f>X0
[KK409bT/02X/;d0/K[70868TP02051DFP09024S9@29T9X0Y:^h02h`<`0k?T80MW^50;_3dP35cM`0
en3`00<0f>7a0`3HhO020=SQl@<0f>7`00<0e]o]0=OPkP3Fgnd00P3Hh^l01P3BfnP0f>;_0=SQk`3@
f>H0en7^0<K?f`80f>7^00<0c=KR0=SRkP3HhNd00`3HhNd20=OQk@80en7/00<0en;/0=SRk03Hh^`0
1`3HhN`01@3Hh^`0f>7[0=SRj`3Hh^/0f>7[00<0f>3/0`3Hh>/02`3GgnX0e]kY0=KNj@3Gg^X0/;Jo
0=;Ih`3Bf^@0d]WS0=KMj03:dM/0d=KQ0080e=[U00<0dMSR0<_Af`3Dg>H00P3:dM/00`32b=80cmKO
0=GKi@020=GLi@040=CKi03Dfn<0eM_T0=KMiP<0fN3Y0P3HgnL00`3Hh>L0fN3X0=[Qj@040=[Qj@04
0=_Qj@3Kh^X0fn;Y0=_Qj0@0fn;X00<0fn7X0=[Qj03JhNP0103JhNP30=_Qj0<0fn7W00<0g>;X0=cS
j03LhnP00P3LhnL0103FgN80];Zm0<S?d03NiNT20=kTjP030=kTj@3Ni>P0gNCW0080gNCW1P3MiNL0
0`3NiNL0gNGV0=gViP050=kViP040=oVi`3Pj>L0h^[Y0>?Zj@L0i>_Z0P3TjnT20>G[j@L0iNcZ0`3U
k>T30>K/j@L0i^gY00<0iNcW0>O]j03WkNP00`3WkNP01@3Vk>L0i^gW0>O]j03WkNP0inkX0080inoX
00@0`/S20:BZY02TZZ@0G5mL1P000000100410@061TH01/L6`071`MJ000000`0oooo000:0?ooo`/0
000000L0DEEO01lQ9029T:40`<[P09JN[`1bNHH0[;C90080`/cS0P31bn804@30b^40`<[P0;o8gP2c
_=40R92O06I[M`2SZkd0`L[Q0<7;h@30bMl0_<GJ0;Fod`2_]lX0_<GJ079gQ00T9RX02@T:00800000
00X0;2hc07b1SP2EW:`0L7B102X[<017BU80Uif]0:2W^02IWk00A4M?10000000100;2``09BL[02X/
<00?41490000000402T[;`1aMh80J6eg020Q90/0000000L0J6eg01dO8@000000000003/n@P26S9P0
?D150080000000X0JVmh096FX`2g_/h0]kk>0:B/^P26S9P0c=KW06U^M`0d=c/04a<E0P0000001`07
20P0?d9704]?E@0E5QP01PH700d=3P3HhO80103HhO400`3Bg>/0f>;a0=SQl@040=SQl@80f>7`00P0
cmSV0=SRk`3Hh^l0cmSV0=CNj`3Hh^l0e=k[0=;Kj@80f>7^00D0`L[F0=SQkP3Hh^h0d=WU0=SRkP06
0=SQk@060=SRk@36d=X0en;/0=ORk03BfnD0en3/1P3HhN`30=SQj`P0f>3/00/0f>3[0=WPk02naLl0
ZJnh0<C<e@3<e=l0Zk:k0;Rob@3Fg^T0cMGO0<_Ag0020=CJi@030=GKiP3FgNL0f=oY0080d=SQ00H0
e=cU0=KMiP3FgNH0emgW0=ONi`3FgNH20=GLi@030=SOj03Ih>T0fN3Y00<0fN3Y0P3JhNT0103Jh^X0
fn;Z0=[Rj@3Jh^T20=[Qj@@0fn;Y00@0fn7X0=_Rj@3KhNP0fn7X203JhNP00`3Jh^P0fn;X0=_Rj002
0=_Rj0090=_Sj03LhnL0g>?X0=cSj03MhnP0eMcP0:R]/03Ni>P0gnGZ0080g^CZ00<0g^CX0=gTi`3M
i>L00P3MiNL00`3Mi>L0gNGW0=gUi`020=gUi`80gNGV00<0g^KW0=kViP3Ni^H00`3Ni^H00`3Oi^L0
h^WY0>C[j`090>C[jP030>G[jP3Uk>X0iN_Z0080iN_Z00<0iNcZ0>G/j@3Uk>T00P3Uk>T20>K/j@03
0>G/j@3UkNT0i^gY00<0i^cY1@3VkNT00`3VkNP0h^ST0>K]j0060>O]j0@0inkX00@0_lG002HW9P0V
9bH010@4I000000<0?ooo`002P3oool<0000000800T92`2>UZL0`/cS0:J_``2GWk40_LOM0<?<h`32
c><20<7;h`0@0<3:h@2ob=l0`L[Q0;k7gP2EWJh0BdiG08Z@X@32bn40`L_Q0<39g`2QZ;X0Mgb:07Ml
R@1nPi40>ci400L820<0000000X051DG03Li?`14ATh0:R``00d=3P0P8BD0DEAM06=WLP1JGFP09bT]
10000000100N7b<0Ifeh07=iQ@0Y;3090000000402h`=@1oQY<0MGb702@V:@/0000000L0RY2M02LX
;00;2``07AhQ06M/M@2a^LT0D5AK0080000000P020P90<?;g035c]l0QH^G08R>VP2@UZ<0L7En02T[
;`X0000000<0E5QN0=SQlP3HhO800P3HhO800`3=enH0f>7a0=SQl@030=SQl@040<kFi@3HhO00f>7_
0=OQkP80f>;_00D0e=g[0=OQkP3HhNl0dmgZ0=CMj`020=SQkP090<oIiP3<e^80en;^0=SRkP3?fND0
e=gZ0=SQkP3Fh>/0e=kZ00<0f>;]00D0]l3:0=ORk03Gh^`0a<gG0=KPj`040=SQk0@0f>;/00<0f>7[
0=OPk03Hh>`0203Hh>`03P3<dmh0d][T0=CLi`3>e^40^Ko90<S@fP3GgnX0`<OA0;g3c@36c=L0aL_E
0;[0b@2naLh0e=cV0P3HhNX0103Hh>T0fN3Y0=SOj03HgnP20=WPj@80f=oX00@0fN3Y0=[Pj@3JhNT0
fN3Y0P3Jh>T00`3JhNX0f^;Z0=[RjP030=[RjP80f^7Y1@3Kh^T00`3Kh^P0fn7Y0=_Qj@050=[Qj004
0=[Rj03Jh^L0f^;W0=_Ri`<0fn;X00T0g>;X0=_Ri`3KhnL0fn?W0=cSj03MhnP0g>?W0;Nl_`3GgN40
0P3Ni>X0103NiNX0g^CX0=kTj03Mi>L80=gUi`80g^KW103Ni^H00`3NinH0gnOW0>;Yj@0:0>C[jP80
i>cZ203Uk>X60>G/j@030>K/j@3VkNT0i^gY00D0i^gY00<0dMOC0>K]j03VkNP00P3VkNP0203UjnH0
hnWT0>?Yi03Sj^@0h^WT0=CKe@2c^K@0IVUV0P0@411U000000`0oooo000:0?ooo``0000000P02@T;
08jFY`32c><0[[S=0:bebP30bN40`lcS0<;<h`80`L_S0100_LON0::Z_@2OZ;X0W:Bf07f3T@1MHVd0
JVml09RP/@2b^m00X:Nj05IJI00C4aH05ALI02<T:00B4aD00P822@00000010082@T04Q<E018C5P08
2@T400000004020R9@1`MX80OH>A02d_=0T0000000@04a@F03Hi?P0a=3T03a0A300000001P0?4140
;S0d07f3SP1iOhT0ADQ>01lQ8`<0000000H0EUYQ05QLH`1YKWL0am3Q0;o9f@0f>Cd300000080:B/^
00<0CU5G028T9`0000000P0000000`0X:Rd0LgR10=SQlP020=SQlP040=OQl@3Hh_40en3`0=OPl0<0
f>7a00T0dM[Y0=SQl03GhNl0/;S309^R[P3=e^<0e^3^0=GOkP3<e^<00P3HhNl0103@fNH0e^3]0=OQ
kP3@f^H20=ORkP050<K@g03AfnL0f>;^0=?Mj@3=e^800`3Hh^h02@30bM<0en;/0=ORk030bM<0en3/
0=3Ii03Af^@0e^3[0=OQk0020=SQk080f>7[00<0f>7/0=SPk03Hh>d01`3Hh>`01`3HhN`0][c60:Za
^@3?en80d][U0;o5d033b]@00P3EgNP01P3CfnH0/[S10=GMj03Fg^T0eMgW0=OOj@80f>3Z00D0f>3Y
0=WPj@3Ih>T0f>3Y0=WQj@040=WPj@050=[Qj@3JhNX0f^7[0=[Qj`3Jh^X01`3Jh^T30=_Rj@<0fn7Y
0P3Kh^T00`3Kh^P0f^7X0=[Qi`020=[Qi`030=[Qj03JhNL0f^7W00@0f^;W00@0f^;X0=_Rj03Kh^P0
fn;X0`3LhnP0103MhnP0e]gR0<76bP3Hgn820=kUjP80g^GX00<0g^CX0=gUi`3MiNL01@3MiNL20=gV
i`@0g^KW00@0g^OV0=kWi`3OinL0hNWY0P3Sjn/;0>C[jP<0i>cZ1@3Uk>X01@3UkNX0iNgY0>G]j@3U
kNT0i^gY0080i^gZ103VkNT01@3VkNP0emkJ09RMVP27RhP0X:FQ0080XJJR00L0PXJ205aOG01LGe`0
G5mL05]NF`0f=cH0414@06P00000303oool000X0oooo2P0000002P061`P0000000L72020QiL0_lWP
0;Bmd`2PZ;/0X:Rl0:^eb@2e_m@20<7;h`0=0;[4fP1^M880<C<i04Y=EP1kPHl0QXbK05AIH`18C5@0
LWR407^0S`1RIg80>Se401HH6P0200H61`0700@410010@401@D600h?400C51H02@X;00410@020000
000400<30`0c=S`0GF=/02/^<`D0000000@03@h?02ha=P0d=S`04Q<E6P0000000`0h>d00Uin/061T
K@0600000005018C5@1/LG/0SiJS08B;U@0M7R400`00000205eQJ@030;6ja`1>DUP0000000<00000
00<0^l?A0=SRlP3Hh_800`3Hh_403P3Af^X0eMk^0=SQl@3Af^X0dmc[0=SQl03Eg^d0d]cZ09NNZ@37
d=d0bmCR0=CNk@3CgN/0b]CQ0P3HhNl00`3;e>40en7_0=OQkP030=ORkP050<K?f`3Bg>P0dM_V0=KP
k03FhN`00P3Hh^h0303Gh^d0d]cW0=ORk@3GhNd0cMKQ0=OQk02Y/;X0_<G?0=?Li`2laLh0Xj^c0<WB
g080f>;/00@0dM[U0=CLj03Hh>d0f>3]1P3Hh>`03@3HhN`0_LC>0<[BgP3CfnH0b]7L0;Fka@2TZ[<0
SY:K09JLY02RZ;40Z[6k0;Rob03;dmd0103Hh>X00`3Hh>T0fN3Y0=SPj@040=SPj@050=WPj@3JhNT0
f^7Y0=[QjP3IhNX00P3IhNT00`3JhNT0f^;Y0=[Rj@030=[Rj@80fn;Y0P3JhNT00`3KhNT0fn;Y0=_R
j@030=_Rj@80f^;X00L0fn;X0=_Rj@3Kh^T0fn;Y0=_Rj03Jh^P0f^;W00<0fn;W0`3Kh^P02`3Lh^P0
g>?X0=cSj03Li>P0gNCX0<S>dP2`][T0g^CY0=kUjP3NiNT0gNGX00@0g^GX00<0g^GW0=gUi`3MiNL0
1P3Ni^L01@3Oi^L0hNSY0>;ZjP3Rj^X0hn[Z00H0i>_[0P3TjnX60>C/jPH0iNcZ0`3Uk>T20>G]j@03
0>K]j@3UkNT0i^gY00@0i^gY00<0i>_W08:6Q00K71/0L`00000<0?ooo`002P3oool:0000000:02h`
=P0Q8RH0@DA;06ecP02Y//H0/kgC09FL[`1:CUL0=cY1069WLP80TiZ/00d0P8NF03Li?`061`L09bP]
06mePP20QYD0>Se30000000l?dH0SiJW09VP/P2=U:D0LgV60080EeaV00d0?3i501/L7`0V9b/0B4]C
05UMI`0];c@00`<300X;300000001PH706E[M@2h`]H0EU]T01L0000000@02`/=024S9P0L7R001PH7
200000001@0D5AL0A4Q>06EZL`1=DEP04Q<E00@0000000@06AXM07^2S029T9`09bT/0P0000001P0T
9BP0Ce9I06Q]MP1XKGH0NGn903Hh?@<0000000d00@410=SQlP3HhO80en7b0<cFi@32c=/0e=g]0=OP
l03GhO40f>7a0=CMk03Fh>l0f>7`0080e=k/00L0^L;?0;O0c03?fNL0eMo]0=?Mk03>enD0d=WW0080
en7_00<0e^3^0=KQkP3Gh^h00P3Gh^h00`3AfnL0e^7]0<7:eP020=ORkP80bM?N0P3Gh^d02P3@f^D0
d]cW0=OQk@3GhN`0]ko80=GOjP3Fh>/0/[[30<C=eP3=en020=SQk0060<gEh@3CfnP0en3/0=SPk03<
e=l0f>3/0`3Gh>`30=SPk00;0=CLi`3AfND0e]kY0=KNj@2NY:d0[[Bn0;Fla@3;dmd0^l;<0<S@f@3C
f^@0203Hh>X30=SPj@@0fN7Z103IhNT60=[Rj@030=_Rj@3JhNP0f^7X00`0fn;Y00<0fn;X0=[Rj03J
hNL0103Jh^L01@3Jh^P0fn;X0=_Rj03KhnP0g>?X0080g>CX00H0d]SM08N=S`3AfM`0g^KY0=kUjP3N
iNT40=kUj080gNGW00<0gNKW0=kVi`3Ni^L00`3Ni^L00`3Oi^L0hNSY0>?[j`020>?[j`040>C[j`3S
jn/0hn_[0>?[j`<0i>_[1@3TjnX70>C/jP80iNcZ0P3Uk>T60>G]j@060>K]j@3Uk>T0h^[V0=kUh@3@
em<0EEQGM000000<0?ooo`002P3oool:0000000:05EII01<DEX0TYZ/06I[N01oQYD0]KoD08V@X@0Y
:c401@D501DF6@8092H/01`051DH00@4100000004Q<E03@g?@0o@TT08RDX00T92P0m@4L0SYFT0:Ra
``2a^/l0/;W=0:J^`@2W[l<0NX6>05MKI@1bN8D0R8nN09fT]P1@E5d03a0B018C5@0:2P`01PH603e1
A`1_MX80=3Lm0`000000100J6ah0=SPn03<e>`0G61X@0000000402HX;01cNH@0HFI_01@E5`T00000
00`08b@X09FLZP2AVJH08b@X00830`061PL01PL700H61`0<3Pl0=3Hk03Xl@@0@4A<200000006055E
G02d_L/0J6ef06Q]MP0F5aT02PX;0`0000002P071`P0f>;b0=ORlP3Gh_80^/?A0<C=g03Bfn/0_<CB
0:fe`P3>f>L20=SQl@040=OQl03Gh_00f>;`0=7Kj@80e^3^00@0e^7_0=KPkP3Fh>h0`L[G0P3GhNl0
1@39d]l0d=[W0=ORkP3Dgn`0cmWU0080en;^00<0^lC?0=ORkP3Gh^d00P3@fnD03P3Gh^d0en7]0=3J
iP3Eg^X0en7]0=SQk@3;e=l0a<gG0:F[]@2nam00en3[0;S0b@2f_/L0e=cY0P3Gh>d0103Fg^/0emo[
0=GMj@3Hh>`40=OPk080f>3/0P3Bf^D20=SPk0050:R^^02`]/40[K>m0:N]]P2oa]00103Hh>X20=OP
jPD0f>3Z0`3HhNX20=WQjP@0fN7Y00<0fN7Z0=[QjP3Jh^X00`3JhNX0103Jh^X0fn;Y0=[Rj@3Jh^T3
0=_Rj@<0f^;Y1P3Kh^T00`3Jh^T0f^;X0=[Ri`030=[Ri`80fn?W0`3KhnP02P3LhnP0g>CX0=cTj03J
hND0Qh^>09^QXP3Ggn<0gnKZ0=kVjP3NiNT20=kUj080g^KX00<0gNKW0=kVi`3Ni^L00P3Ni^L0103N
inL0gnOY0>7YjP3Sjn/90>C[j`X0i>c[0P3Uk>X20>G]jP80iNcZ0`3UkNX02P3SjnP0g^GR0>?Zj03P
j>@0c=;?09jSX01`M780FEaJ051CDP0L7Aed000000`0oooo000:0?ooo`X0000000X0>ci406AYMP2o
bN00JW1m0454C01fO8X0K7:005eRK@1FFfH0G65/0P1;CeP08`0I6ah020P900L820071`P01@H602X]
<@1CF640FUmZ06M/N01iOhd0P8NE08R?W`2IX;80TIRX09bS]@2DVj`0Ri6Q0:feb02:TJ00Nh6>04E8
D00k?D<0Gf=^03Hi?`0=3@l03Ph?020Q9P0O82@03a0A00D51@000000=cY007=hQ01]LGd0<C<h0100
000000@0:bhb08:9UP1^M7l05aPJ2@0000002@0@4A80ADU?04A7CP0H6Q/0NX2;09jU]02:TIh0KgAn
02ha=@050000000403Pj?`1kPH/0@4980412B080000000D02@T:03Hh?@12AD/0BTiD0<G>g@020=OR
lP060<?<g03Egnl0cMOV0;g5e03Fh>l0eMo_0P3HhO420=OQl00?0=KQk`37dMh0e^7_0=ORl03;eN80
en7`0=SQk`2h`Ld0en7_0<[Ch02h`Ld0cm[W0=ORk`3Eh>`0e=kZ0080en;^00<0c=KR0<[Cg`3@fnH0
0P3Gh^d01@3Eh>/0c=KR0=OQk@3GhNd0d=[U0080e^3[00L0]ko80;k6d03DgNP0eMoY0:6Y/P2Z/[`0
c=GQ0080en3]00D0`LWE0=SPk@3Hh>d0c=GP0=7Ii@020=SPk0040<oHh`3Ggn/0en3/0=OPk080en3[
00H0f>3[0=;KiP3FgnX0^L7:0<WAf`3CfnD30=SPjP030=OPjP3Hh>X0f>3Z00@0f>3Z103HhNX70=WQ
jPD0f^7Z0P3Jh^X40=_RjP<0f^;Y1P3Kh^T30=[Rj0D0f^;W0P3JhnL00`3JhnP0fn?X0=_Sj0020=cT
j0040=_Ti`20QHL0=CLg0;>i_080g^GZ00<0g^KZ0=kVj@3Ni^T00P3Ni^T20=kVj0@0g^OX00@0h>WY
0>?[k03Sjn`0hn_[0P3Tjn/50>?[j`D0i>_[0`3Tk>/30>C/jP040>C/j`3Uk>/0iNcZ0>G]jP80iNg[
0P3UkNX01`3TjnT0/[Rg04]=C01/L6l0Bdi=01hN7P0410@0N000000<0?ooo`002P3oool:0000000:
00T92`1TJWH0_l[Q07=iQ`12ATd0HVMc09BM[`2]]l`0Z[C80:Naa@80VZ:e00L0DeQR04a@F01VJgL0
EeaV02/]<P1HG6H0WJFh0080ZK;501X0PhVH04Q<E00b=C/0@dI>04U>E@1nQ980/;S=092GZ02@UjH0
Gf=]03Pk@@0]<3D0IV]f0:bda`1RIg805QLI00P82@0d=S`0GF5/03i1B00D5AL000000494C029Sih0
PHJE0453BQ00000000@04A8D03<f>`0[;S802@T:300000001P0F5aT0VJ6_0<oJk@3=enX0_lSJ055E
G0@0000000<030d>04U<D`1KGfL00P0Q8bD20000000;01@E5`1jP8X0Uij[0;Bmb`35cmh0en;b0=OQ
lP3>f>P0`/_J07n4T035c]d00`3GhO40403HhO40en7`0<cFi031b]T0c=OU0=GOkP3GhO00d]cZ0=OQ
l03HhO00_/OD0=CNk02b^lL0^lGA0=;MjP37d]h20=ORkP050<gGh`3Gh^h0en;^0;k7dP3?f^D00P3G
h^d03P3BgNP0`lcG0=OQk@3GhNd0`L[E0=OQk@3GhN`0]ko90=3Ji03Hh^`0e=kY09NNYP2KXZ/0b];N
0P3Gh>d02`2f_/P0en3/0=SPk03?f>@0eMkY0=OPk03HhN`0bm?O0<_CgP38d=/0en3[00D0en3Z0P3H
h>X40=OPjPH0f>3Z0`3HhNX90=WQjP@0f^7Z0P3Jh^X01`3Jh^T0f^7Y0=_RjP3JhNX0fN7Z0=WQj@3J
h^X00`3Kh^X00`3Kh^T0f^;Y0=[Rj@020=[Rj@80f^;X0`3Ih^L01@3Jh^L0f^?W0=[Si`3JhnL0fn?W
0080fn?X0P3Li>P0203Ki>P0Mg]m00000026RX`0f^7U0=kUjP3Ni^X0gnKZ1@3Ni^X01@3NinX0gnOY
0=oWjP3Oj>X0hNWZ00L0hn_[0P3Tjn/?0>C/j`80iNcZ00H0h^[X0>?[j@3Sj^P0cMCC05EHEP030`=l
000000`0oooo000:0?ooo`X0000000X020T:05eSKP2c_M<0O8>B07ImS02?UjT0/;[@0;>mdP2h`]T0
^lKM0P30b^802`20QiH0T9VZ0;2icP2X/LD0Nh2@07n5U02>UZH0RI2P08N?WP1TJG@0:2X_00800000
01H03PlA04Q<E023RIP0HfMb04I9D@0N82<010D501<C5P1=D5T0PhRH04]>E`0@4A<03Ph@05]OJP2W
[/40M7V602/]<P051PH09BL[04a?E`17BU80<38g0`0000001P010@8030`=00`<3@0F5aT0414B00H6
1aL0000000H0414B06ebO02ja=@0U9^X05]PJ00U9bX30000000400P82@0J6ad0RY6M0:6Y]`80<3<g
0P0000001P0>3Q00DeMN06M]M@3FhO40en;b0<SAh@80en7b01H0[[K408J=V@3Bg>/0f>7a0=KOl03E
g^l0e=k^0=GOkP30bML0am7P0=3KjP3<e^D0eMo]0=OQl03=e^@0[KG00;[3d03DgN`0a<oK0=CPk@3F
hNl0`/cH0P3Gh^l01@2nam<0en;^0=ORkP2mam40dMcW0080en;]00D0dmkY0<G?fP3GhNh0en7]0;_4
cP020=OQk@070;W1b`3@f^@0en7/0=KQj`34c=P0am3L0=;Kj0020=OPk@030<G>f@3AfND0b];N0080
en3/00D0c]OS0=OOk03Ggn`0`LWE0<?;eP060=OPj`80f>3Z0`3Gh>X0103Hh>X0en3Z0=SPjP3Hh>X5
0=SQjP@0fN7Z1P3Ih>X00`3IhNX0f^7Z0=[QjP030=[RjP040=WQj@3BfN40c=?K0=KNiP80fN7Y00<0
f^;Y0=[RjP3Kh^X0103Jh^T0103Jh^P0f^;W0=WRi`3Jh^L30=[Rj0050=[Ri`3JhnL0f^?W0=_Si`3J
hnL00P3KhnP30=cTj00607MlO@1?De<0/kZk0=;Ig@3Mi>T0gnK[0P3Oi^X01@3OinX0g^KZ0=kWjP3N
i^X0h>SZ00<0h^[[103Sjn`90>?[j`T0i>c[00<0iNc[0>G]j`3UkN/00P3Uk>/01@2Z[jh0Q8V807Um
O@10@T804A4A07d00000303oool000X0oooo00<00`<40000000000001`0000002P041@D0<SDk05mU
L@1ZL7d0Y:k20;[5g@2lamh0^<;H0;[5f`2mamh20;o:h@0;08F=W@2V[l80_LKM0;k8g`2g`=H0/;W=
07QmR`11AD`0>Ca302X/<@0A4Q@00P0000001@061PL07AlR03@g?@0P8RD020T:0080000000l020P9
01lQ900f>3h07R0S00L7200:2``0A4M?07f2T01dNHD0JFmj03/nA00A4A8030d>00/<3@051@H00`00
00001P061PL0<38g030b=`1JGFL0@TE<01XK7QL0000000D00`<4014B500[;S805AHH00410@040000
000402HX:`0=3Pl0B4aB05AHH0806A/M0P0000000`030`<04A8C01DF60020=ORl`0I0<?<g03GhO80
en7b0;W1d02namH0d]c/0=OQlP3DgNh0d=[Z0=7Kk03Bg>`0_/OE0=?Nk@3@fn/0b=;P0=CNk@3GhO00
a]3M0;FmbP3@fNL0e=k/0<C>fP2e_l/0UIfW0;_5d@020=ORk`050;c6dP3Gh^l0en;_0;o8d`3@g>L0
0P3Gh^h01@3FhN`0d]cX0=OQk@3GhNd0b=;M0080en7]00D0]l390<oIi03Hh^d0e^3[0<cEh@020=OP
k@050=?Lj03Eg^X0dmcY0<S@g032b]H00P3Gh>`01P30b=<0en3/0=OPk036c]X0bmCP0=OPk0@0en3[
00<0f>3[0=OPj`3Gh>/00P3Gh>/30=OPjP@0f>7Z00<0f>3Z0=SQjP3HhNX00P3HhNX50=WQjP050=SP
j@3HgnP0f=oX0=SPj@3IhNT0103Jh^X0103Ih^T0emkV0=GMi03Hh>P50=[RjP080=[Rj03Jh^T0f^;Y
0=[Rj03Ih^L0fN7W0=WRi`3Jh^L40=[Rj0@0f^?W0P3KhnP20=_Tj0060=cTj02FW9l0]Kbn0>7[k@3Q
jn`0h>W[0P3Ni^/20=oVjP040=oWjP3Pj>/0h>SZ0>7Zj`80h^_/203Sjn`00`3Sjn/0hnc[0>?/j`0=
0>C/j`050=kVi03DfmX0b]7@0:R][@14ATH0P@00000<0?ooo`002P3oool00`0?3a40000000000008
0000000901lQ9@0H6Qd0C55K0:>]`@2U[/80WJFh0:nhcP2]]//0/kgC0080_l[R00P0NX2?08B<W02d
_M<0];gB09BK[@1nQ9<0@dI>00P82@@0000000X0414B02`^<`14Adl0BTeF04A8D00U9bX03@h@00l?
4@0B4aD02@T:0`0000001`0410D071dP03<e>`1[L7`0[;K806ieP00D5AP01P0000001P0;2``0E5QQ
05AHH@2NYKH0MGZ702h`=@@0000000<03@h?0000000000006@000000100];c<0000000820P020`<2
00410@D0000000<030d>08N=V02namH00P3GhO805P33cM`0e^3`0=OQl@3Fh?40e=o^0=7Kj`3CgNd0
e=k^0;o8e`3?f^P0`L[I0<;<fP3Egnh0en;`0<C>f`3<e^@0en7`0=?Nk033cMX0UIfW09^S[P2kaM42
0=ORk`050=3Ji`3Gh^l0en;_0;o9e03?f^D00P3Gh^h0303Egn`0b]?O0=OQk@3GhNd0cMOS0=OQk@3G
h^d0_<C?0=3Ji@3Gh^d0eMoZ0<K?f`80en3]00P0_lOC0=OPk@3Gh>d0aLkI0<;:eP3:dml0/k[40;:i
a080en3]00<0dmcX0=CNjP3Gh>`0103Gh>/00`3Hh>/0en3[0=OPj`020=OPj`<0en3Z0`3HhN/:0=SQ
jP80f>3Y0`3HgnP00`3Hh>T0fN7Z0=WRjP020=[RjP030=[QjP3Jh^X0f^;Z00@0f^;Z0P3Jh^T20=WQ
j080fN;X00<0f^;W0=WRi`3Ih^L01@3Ih^L30=[Sj0040=[Si`3KhnP0fn?X0=cTj080g>GY00`0f^?U
0>3Yj`3Qjnd0hN_]0>3Zk@3QjN`0h>S[0=oWj`3Pj>/0h>W[0>7Zk03Rjn`70>?[k0P0hn_[103Sk>/6
0>C/j`060>C[j`3:d]00PHJ502/^;@0O820020P8PP00000<0?ooo`002P3oool00`0I6ah000000000
00030000000>00`=3`000000000000820P0C51H092HZ055EG`1PIW40Yk35092IZ`20QiL0X:Vm0827
U`1lPY8208R@X@0904M;E01=DEX0SYJX08nFY`1CEf80;c4g01TJ7@0820T0414C00<061TL00X0;c8h
06Q]N@2JXK@0YZg109bS]P1OI6l0>Ca204a@F@1FFV@0:R`a1P000000100e>3d0KgF104M;D`0=3Pl6
0000000600P92P11A4/0@DA;07Z0S@1KGVP092DY:`0000006`0[;C00UIbY0;[3d@3GhO<0en7b0<C=
g@3Fh?00en7b0<[Dh`3CgNd0e^7`0<cGi@2V[[X0^L?@0<cFi02GWj/0`<WG0=GOkP3Gh_00aLkL0<cF
i03GhO00e=k/0<?>fP2e_l/0RY6K0;c5d@020=ORk`050<WCh03Gh^l0en;_0<7;eP3?f^D00P3Fh^h0
1@3AgNP0`/cG0=OQkP3GhNh0c=KQ0080en7]00D0b=7L0=7KiP3Hh^d0e=oZ0<;:eP020=OPk@0:0;Bl
a`3GhNd0en7]0<G>f@32b]H0/k_609^R[02c^/D0dmcY0<?<e`80en3]00<0b];N0=?Li`3Gh>/01`3G
h>/30=OPjP80en7Z1P3HhN/40=SQjP030=SPj@3HgnT0fN3Y0080f=oY00D0f>3Y0=WQjP3IhNX0f^7Z
0=[RjP020=[QjP0:0=WPj@3Hh>P0f>3X0=SPj03Ih>P0fN7X0=[Rj@3Jh^X0fN;Y0=WRj080f^;X1@3I
h^L20=[Ri`030=[Sj03JhnL0f^?W0080f^?W00H0f^?X0=_Sj03Li>P0g>GY0=gUj@3OjN/30>;Zk@<0
h^_]00<0h^[]0>?[k@3Rjn`01P3Rjn`60>?[k0D0hnc/0P3Tk>/20>?/j`D0i>c[00D0c]GD08Z?SP1@
De807b0P00410@24000000`0oooo000:0?ooo`03014B50000000000000H0000000/01@H703e0B01d
NXT0VZ>f08N?W`25S9d0HFMd04M:D`1;CeP0:2/_01LH6`0202T/<@0901PI700P8RD0@DA<03e0B00G
61/0000000h?4@0n@DP0MW^:00<0SYFV00X0QHbL09JN[`2f_]@0_/OM0;Noe@29T:00OH>B08jDY@2J
XK<0BdiG100000001P0N82<0EeaU055FGP0_<cL04Q<E00<310H0000000H010@401dN8@0M7R40=STo
02PZ;`0@4A8F0000000300820P00000000000180000001P0IFYc0<39f@2U[K/0TYVU0;O0cP2ob=P0
e^3`0<K?g`2i`]00dmg/0=ORl@35c]d0]l3=0=3Kj@3CgN`0_<GB0<K@gP3Fh>l0en;`0<?=f`3<e^D0
en7`0=?Mk033cMX20=ORl0040;g6d`3Gh^l0en;_0;o9e@80en;_00H0dMcX0=COj`3Gh^h0en;^0=CO
j`3:e>020=OQkP030=KPk@3Gh^h0en;^00<0en;]00D0en7/0<oIi@3Gh>h0en3^0;Fmb0020=OQkP0;
0<K>f`32bmH0[;Bo08V?V02e_LP0dM[V0;c4c`3Gh>d0en3/0<gFh@3EgnT02P3Gh>/00`3GhN/0f>7[
0=SQj`060=SQj`80f>3Z0P3HhNX20=SPj@040=WPj@3Ih>X0fN3Z0=WPjP@0fN7Z0P3IhNT00`3Hh>P0
f>3W0=SPi`020=SPi`040=SQj03Ih^T0f^;Z0=[RjP80f^;Y00H0f^?Y0=[Sj03Ih^P0fN;W0=WSi`3J
hnL20=WSj0040=WRj03Ih^L0fN?W0=[Tj080f^?X00D0f^CX0=cTj@3LiNT0g^O[0>7Yk0060>;Zk@80
hn_]203Rjn`60>?[k080hn_[0`3Sk>/00`3Tk>`0i>c[0>C/j`030>C/j`040>?[jP3=e=<0G61P00<3
0hL00000303oool000X0oooo00<01@H60000000000001P00000020092@X0H6Ea0;K1f02laml0^LGM
07b4T`0_<CL01`L81P000000200410@04A8D01lQ900A4Q@00`<301lQ9@1gOH`0];gB0P2obN002`30
bN00][oD09^S]@2=U:D0W:Bg08nFYP2=Tj@0Z;3408N=WP1dNXH0=cU000@0000000@0?4160;6lc`2L
YKH0>3]14@00000010061PL08B<V03@g?00I6ad?00000003020R9@0000000000018000000100_/OF
0=;Lk@1IGFH0^<7@0;o8e`3@f^X0e^3a0::Z]`2]]/<0dmk]0::Z]P2PZ;D0cMSW0=ORl@3Dgnh0d=_Z
0P3GhO002@3Dgnd0`lcJ0<cFi@3GhO00dmk/0<?>fP3Fh_00en?`0<SBg`020=ORk`030;Job`3Gh^l0
e^;^0080e^;^0P3Gh^h01@3GhNh0e^7^0=OQkP3Gh^h0dMcX0080en7]103Gh^d30=OQkP0<0;W1c03G
h>d0en3]0<K?f`32bmH0aloL0;c4d039dMd0e=cY0<?<f03;eN00cmSS0P3GhN/30=OPj`070=KPj`3G
h>/0en3[0=OPj`3Ggn/0emoZ0=OPj`040=OQj`D0f>7[0P3IhN/00`3IhNX0f>7Z0=WQjP020=SPjP<0
fN3Z00D0fN3Y0=SPj@3Hh>T0f>3Y0=SQj@020=SQj0030=SPj03HhNP0f>3Y0080fN7Y1`3Jh^T00`3J
h^P0fN?W0=[Si`030=[Sj0050=WRj03IhnP0fN?X0=[Sj03JhnL00P3KhnP00`3LiNT0gNKZ0>7Zk@09
0>;Zk@D0h^_]103Rjn`60>?[k080hnc/0`3Sk>/30>C/k0050>C/j`36cL`0V9jM04Q;B`0:2`/0R000
000<0?ooo`002P3oool20000000300820P000000000000@0000000P01@D503Pk@P23S9`0Y[3509>L
[P1^M880>3Y100H71`H0000000P03@h@03m3BP1hOhh0IF]g03Dh?P0`<SP0O8:B0;O1e`<0`<WP00X0
^lCK09:J[01;CeL0?D170413B`1OHfl0P8JE05UNJ00d=cd05aPK10000000100Y:c00`LgR0::/_P0j
?T@A00000004010A4P1GG6@0QhnL0496C@H0000000<00P8300410@0000002P00000010030`@020P9
00H71`020P8=000000050:nhaP1QIFh0?3m509NNZ`38d^800P3GhO802@2RZkP0bMCS0=?Nk@28SYX0
[[O50<oJj@3Gh_40dMcZ0<SBh0020=OQl00=09ZQ[@2QZ[H0cMOU0=ORl03Dg^d0`lkJ0=KRl03Gho00
dMgZ0=KRk`3Gh^l0^<;=0=ORk`050=KRkP80en7^1P3Gh^h30=ORk@040=OQkP3Gh>h0en3^0<SAg@80
en7^00<0cMOS0<G>fP3GhNh00`3Gh>d00`3Fh>`0`L[F0<kGhP020=OQk080en3/00<0en3[0=KPj`3G
h>/00P3Gh>/20=OOj`030=OPj`3GhN/0en7[00<0en7[0P3HhN/20=SPj`050=SQj`3Gh>X0f>7[0=SQ
j`3HhNX00P3Hh>X30=WQjP060=SPj@3HgnP0f=oX0=SPj03Hh>T0f>7Y0`3IhNT00`3JhNX0f^;Z0=[R
jP020=[RjP<0f^;Y0P3Jh^P0103Jh^T0fN?W0=[Sj03JhnT20=_Sj@090=[Sj@3JhnP0f^?X0=[Tj03J
hnP0fn?X0=_Tj@3KiNT0gNOZ00H0hN[]203Rjnd20>;[k0040>;[k@3Rjn`0h^_/0>?[k0`0hnc/00<0
i>c/0=cTi01VJVX0R`00000<0?ooo`002P3oool20000000301@E5`000000000000@0000000/00@41
02<U:@1ZLGl0[[S>08nGZP2AVJ`0KgF301<D5`0720T02``=00H61`020000000E00T92P0]<3D0OXFD
0;g7gP2Y//L0NH2?04Y>E`1CF680QXfM0:6Y_@2T[<00YJg008nGZ01IGVP061TL0000000<3@l09BL/
03Dg?P0L7B000`@40080000000P010D501lQ900e=cd0@4A;04Y=EP1]Lh00;S4f00820Q00000000@0
4Q<E069XL@2IXK00BdmF1P0000000`1@E5d05QLI0000000:0000000402<U:01>DEP0@TE;01HG6@80
000000<00P82000000000000200000001@1oQI402`/=02ha=P34cMd0aLoO0080en;b00T0][o>0<kH
i`3Dgnl0/kk:0;_5d`3Ag>/0e^;a0<gHi`35cmd00P3GhO001P27SYP0Z;2m0<kIi`3Gh_00e=o]0<;=
fP80e^;`00H0bmKS0=ORl03Gh_00`L_G0=OSl03Fh^h20=KSkP@0e^;^103GhNh20=ORkP<0en;]0`3G
hNh01P3@f^H0en7^0=OQkP3Egn`0e=k[0=OQkP80en3]00@0dmgY0<G>fP2oam80bmCO0`3GhN`00`3G
h>`0en3[0=OQj`040=OPj`030=OOj`3Gh>/0en7[00@0en7[00P0f>7[0=SPj`3Hh>/0f>7[0=OPjP3G
gnT0en3Z0=SQj`80f>3Z103Ih^/0103HhNX0f>3X0=OOj03GgnP20=SPj@030=WPj@3IhNT0fN;Z00H0
fN;Z00<0f^;Y0=WRj03Ih^P00P3Ih^P30=[Sj@<0f^CY103Ji>P0103Ki>T0fnGY0=cUj@3MinX70>7Z
k@<0hN_]0`3Rjnd70>;[k0<0hn_/2P3Sk>`00`33c</0?Clo0000002:000000`0oooo000:0?ooo`80
000000<09RP]0000000000001@0000002P1YKgd0H6Ib06E[M`1gOH`0UYja05EJI@0o@DT0FUmZ06A[
M`0a=3X200T92`0:028T:01IGfX0T9VZ0:jgc02c_=80WjRk08::VP1=DE`0<38i038e>`80=CLn00<0
:2X_018C5@020P8020000000200R8bL0J6ii08V@X02;TJ40PHNF075fP`0k?D@010@5400000001008
20T0;2lc04E9D00R92L70000000302T/<0000000000000T0000000L0A4M=09JMZ`20QY40=SPm01<D
5P061PL00`<300/0000001L0A4Q>05=HH02SZkT0c=KW0;S1d02Z/l40a]7P0=KRlP3Fh_40e=o^0=?N
kP3Eh>l0e^;a0<oJj@34c]`0en7a0=ORl@2e_l`0^lCA0=;Lj`2`^LD0ZK:n0<C?f`020=KRl0080=KQ
k`3Gh_00en;`0=GQkP3Gho00en?_0=;NjP3Dh>`20=KSkP030=OSkP3Gh^h0en;^00<0en;^00<0e^7]
0=ORkP3Gh^h00P3Gh^h0103FhNh0en3^0=OQkP32bmL50=OQkP060=OPkP3Gh>d0d=WV0<7:eP3@f^H0
dM_V0`3GhN`02@3Gh>`0en3[0=OQj`3GhN/0en3[0=KPj`3Fgn/0emo[0=OPj`030=OQj`D0f>7[00l0
en3Z0=SQjP3Gh>X0en3Z0=SQj`3Gh>X0emoY0=SPjP3IhN/0fN;[0=WQj`3Ih^/0f>7Z0=OPj03GgnP0
0`3Gh>P00`3HhNP0fN7Y0=WRjP020=WRj@<0fN;Z00<0fN?Y0=WRj03Ih^P00P3Ih^L00`3IhnP0fN?Y
0=WSj@020=[Sj@80f^?X00L0f^CX0=[Sj03Ji>T0fnGY0=cUj@3Li^X0gnS[0080hN[]1@3Qjnd;0>;[
k@<0h^c]2`3Sk>`00`3Cfm/0HVIV01DF5P2;000000`0oooo000:0?ooo`D0000000@02PX<02PZ;`0j
?TD07AhR0P0000002@1NHfl0:2X_05eRKP1]Lh80D5EO06abO`2QZkl0[KS=06YaOP02055EG`0905eR
K@29TJ80^lKL0;c7g@2mb=h0_<KM0;_5g01eNhT08bDY00h0000000P0?d9909^S]02a^/h0]l3E0;Bm
d@2NYKL0DUEO00D61Q/0000000<051DG0000000000002@0000001`0b=CT0L7Eo06=WL01UJG<0KG=m
02<U:0010@402`0000001`3Afn`0VJ2]0<gGj03Ego00WJFc09FMZ@31bmX00P3Fh_803P3<enH0eN3`
0=KRl@2d_L/0/[c90<OBh03Fh_40en;a0=3KjP3Dgnh0e^7`09^S[P37d^00b=?P0P3Fh_020=ORl006
0=OSl037d]l0e^;_0=ORk`3>fND0d]kZ0`3Fhnh00`3Fh^h0en7^0=ORkP020=ORkP090=COj`3Gh^h0
en;^0<WDgP3Gh^d0en7^0=;MjP3Dg^/0`<WE0080en7^0P3FhNh30=OQkP030=?MjP34cMX0en7]00@0
en7/00<0en3/0=OQk03GhN`00P3GhN/00`3Fh>/0en3[0=OPj`020=OPj`80en7[00<0f>7[0=OQj`3G
hN/00P3Hh>/02@3GhN/0en3[0=OPjP3Gh>/0f>3[0=OOjP3GgnT0f>3Z0=WQjP030=WRj`030=SPjP3G
h>T0en3X00<0f>3X00H0f>7X0=WQj@3Ih^X0fN;Z0=WSjP3JhnX30=WSjP040=WSj@3IhnP0fN?X0=[S
j@80fN?X00<0f^CZ0=[Tj@3Ji>T00P3Ji>T01`3Ji>P0f^CY0=_Tj@3KiNT0g>KZ0=oYk03PjNd01@3Q
j^d60>7[k@L0h^_]0`3Rjn`00`3Rk>`0hnc/0>?/k0040>?/k0060>?/k@3Rjn/0en3O0=OPg`1kP800
2@T9S000000<0?ooo`002P3oool0500@4A<08bDZ024S:00>3a00000001LH6`1LHVd0RI6R05MMJ00l
@4L092L[03a0A`0k?dH0RI6S08fEY`1cNXP0PhZK0:jhcP2HX;@0LGN50P2FWk800`1nQID0HFMc06ac
P00406acP00304A8D00D5AP0000000@0000000@010D500d=3`0?41801`L81@000000200i?480QhjM
09BL[@20QY@0JFij05aPJ`0_<SL00`<49`0000001P0A4Q@09bP/02X]<01fO8H0UIf[030b=``00000
01L0BTiE09:IY@3GhO<0en7c0::[^@29T9`0`lgL0<cGi`33c]d0`lgL0=GQl03Cgnh0]Kg;0<_Ei03A
g>`0e^;a0=ORl@38d^00e^;a0=ORl@2DWJP0b]KS0<gHiP040=KRl0060=KRk`3<en@0e^;_0=KRk`3?
f^L0d]o[0P3Fhnl00`3Fh^l0e^7^0=ORkP060=ORkP040;k8dP3Gh^h0en?^0<SBgP80c=GR1P3GhNh0
103Fh>d0en7^0=OQkP3GhNd30=OQk080en3/00<0e^3/0=OQk03GhN`00`3Gh>`00`3Fgn/0e^3[0=KP
j`030=OQk080en7[00D0en3[0=SPj`3HhN/0f>7[0=OPj`030=SPj`050=SPjP3GgnX0en3Y0=SPjP3H
hNT00P3Gh>T0103Hh>T0f>7Y0=SQj@3IhNT20=SQj@060=SRj@3Ih^T0f^?Z0=WSjP3Ih^X0fN;Y0P3I
hnT00`3Ih^T0fN?Y0=WSj0030=WSj0@0f^CY00P0f^CZ0=[Tj@3Ji>T0fnCY0=_Uj@3Gh>@0gnW/0>7Z
kP80hN[]1P3Qjnd80>;[k@D0h^c]1@3Sk>d0103Sk>`0hnc]0>C/k@3EgMd206EYJ@03020Q8@000000
000008/00000303oool000X0oooo01@0:bhd065WM01KHFd09RP]0000000H6Qd0HVQd09:K[@1dNhX0
RI:T05=HH`0N82@0?T5909RQ]02]^<h0WJNl06E[N01VK7T0CU=M04U>E`80Mgj<00<0GVA_02d`=@0K
7B00100K7B000`0A4Q@01@D6000000040000000401TJ7@16BU80E5US02LY;PD0000000P071dQ04=6
CP18C5@0<cDk01hO8`0J6al03Ph@00410@D0000000<02PX;02T[<00f>Cl00P0F61X80000000305IK
I01BEf0092LZ01@0000000@010D502d`=00l?d@04a@F300000005`0E5QP0SIBO0=ORl`3Gh_<0cm[[
0<kIj@3Ag>d0]l7@0:nga@30bmT0dmo_0<oJjP37d^40eN7`0=KRl@32cM/0/[_80<;<f`3Fh_40en;a
0;:lb03=fNL0dmo]00@0e^;`00H0e^;_0=GRkP3Fh^l0e^;_0=CPk@3=fND20=;Nj`030=KSk`3Gh^l0
en;_00<0en;_0`3Gh^h01@3@fnH0en;^0=ORkP39dml0b]CQ00L0en7^00@0dM[W0=OQkP3GhNh0en7]
103GhN`20=KPk0040=KQk03Fh>`0en3/0=OPk080e^3/0P3Fh>/20=OQk080en7[00<0en3Z0=OOjP3G
h>/00`3HhN/0203Hh>/0f>7[0=SQj`3HhN/0en3Y0=OOj@3Gh>T0en7Y0P3Gh>T0103Hh>T0fN;Z0=WR
j`3Ih^/40=SQj@80fN;Z0P3IhnX20=WSj@030=SRj@3IhnT0fN?Y00<0fN?X0`3Ji>X30=[Tj@80fnGY
00<0fnGZ0=kXk03Pj^h0203Qj^d50>7[k@H0h^_]0P3Rjn`60>;/k080hnc/00@0hnc]0<G<c@0T9BD0
92DUSP00000<0?ooo`002P3oool05010A4d0SIJZ08F>X00h>d80000000`<3P0]<3H0B4]E069YMP2G
XKD0G69^01@E600L7R40EUaW07AlRP1RJ7@0:2X_00/<3@051PH05aPK0P0_<SP00`0T9b/030`>0000
000;0000000402h`=P20QiH0VZ:e04M;Da80000000<061TL06A[M@23RiT00P0g>T08000000030;c8
g02d_m40CeAL01l0000001L010@500d>3`0?41401PH702`^<P1TJG80[;G30=KQl`3GhO<0bmKV0=?O
l03@fn`0_LOG09jV]@31c=X0dmk^0<oJjP3>fNT0eN3`0=ORl@2c_<X0]/7=0<;<f`020=KRl@040<KB
g`3Fh_40e^?a0=KRl@80e^;`0P3Fho001@3Fh_00e^?`0=KRk`3Bg^/0a<oK0080`LcG0`3Fh^l30=OR
k`@0en;^0P3Ghnh00`3FhNd0eMo]0=OQk`040=OQkP030=;MjP3Dgn/0en7^00<0en7^0P3GhNd00`3G
hN`0e^3/0=KPk0020=KPk0070=KQk03GhN`0en3/0=KPk03Fgn`0e^3/0=KPj`030=OQk0040=OPj`3G
gnX0e]oZ0=OPjP80f>7/00L0f>3/0=SPj`3Hh>X0f>3[0=OQjP3HhNX0en3Z00<0f>7Z00<0f>3Y0=SQ
jP3Hh^X00P3Ih^X00`3GhNT0en3X0=OPj0020=OQj0030=SQj03Ih^X0f^?[0080f^?Z00H0fN?Z0=WS
j@3IhnT0fN?Y0=WSj03Ji>P30=[TjP070=[UjP3Ji>T0f^CY0=_UjP3Ki^X0g^O/0=oYk0020>3Zk@03
0>7[k@3Qj^d0hN[]00D0hN[]103Qjnd70>;[k@80h^c]00<0h^c/0>;/k@3Sk>d00`3Sk>d00`3Sk>`0
`/[:06AXJ@02014A4Hh00000303oool000X0oooo00D092H[051EH01;D5X07b4V00<30`020000000:
00@51@0[;C<0D5AP03@g?P0Z;340>cm604I;E01>E5h0?D5801HH6`d0000000@05ALI02lb>00]<3H0
51HH0P000000100O8B@0EeaW06U_O00a<cTB0000000301PI701TJgD0Ph^I0080=cY01@0000001P05
1PH03PlA00h?401lPhl0M7^703<f?1l0000001L061TL04iBF@1HGFD08bDX06=XL03=enT0dmg_0=KQ
l`3Fh_<0d=c/0=CPl03AgNh0bMGU0<7<f`3>f^X0eN3`0=?NkP3>fNP0eN7a0=KRlP31c=X0]l7?0<C>
g@020=KRl@050=;Ok@3Fho40e^?a0=KSl@3Fh_400P3Fho440=KSl080en?`0P34cm/00`3Fhnl0e^;_
0=ORk`060=ORk`80en?^00@0en;^0=OSkP3Gh^h0e^7^0`3GhNl50=OQkP80e^7^00@0e^7]0=OQk@3G
h>`0e^3/1@3FhN`50=KPk080en7/00@0e^3[0=KOj`3Fh>/0e^3[0P3Gh>X01P3GhN/0f>7[0=OQjP3G
h>X0en7Z0=OPjP80f>7Z00<0f>7[0=SQjP3GhNT0103GhNT00`3HhNT0f>;Y0=SQj@020=SQj@80en7Y
1@3IhnX01@3IhnT0f>?Y0=WSj@3Ii>T0f^CY00<0f^CZ0P3Ji>T0103JiNT0g>K[0=kXk03OjNd60>3Z
k@80hN[]0`3Qjnh00`3Qjnd0h^_]0>;[k@030>;[k@/0h^c]00@0hnc]0>;/k03Gh>00HfQXT@00000<
0?ooo`002P3oool01@0720T0414D018C5@0720T06a`P0080000000X01`L8038e>`1JH6`0Ff1/08>;
W02W/<H0[;O=0:J`aP1lPi@0;30e3@000000100a=3X0KGB106U_O00_<SL20000000400X;300N7b<0
92HZ014B4`D0000000<00`<30000000000002P0000000`0:2P/0:B``03Hi?`0201HH6PD0000000H0
828V05EJH`1@EEd0;2hc018C5@082@TO0000000802`_<`2?Uj@0XZ^j0413B@2OYkD0e^;d0=ORm034
cmh30=KRl`030=GQl@3=fNP0e^;b00<0e^;b00H0`LcK0=KRlP3Fh_80dMg/0=3KjP3@g>/20=KRl@03
0=7Nk03Fho40e^?a0080e^?a00<0eN;`0=KSl03Fho000`3Fho001@3Gho00e^?`0=GRkP3Eh^h0e^?_
00<0e^;_0P3Gh^l0103Fh^l0en;_0=ORk`3Gh^l40=OSkP030=ORkP3GhNh0en7_00@0en7_0P3GhNh2
0=KQkP040=KQk@3GhNd0en3/0=KPk0D0e^7/1@3Fh>`20=KPj`040=OPj`3Fh>/0e^3[0=KPj`80en3Z
00<0en3[0=SQk03GhN/00P3Gh>X01P3Fh>T0en3Z0=SQj`3HhN/0fN7[0=SRjP<0en7Y00<0f>7Y0=SR
jP3IhnX00P3Ihn/00`3Jhn/0fN?Z0=WSjP020=WSjP090=WSj@3IhnX0fNCZ0=WSj@3Hh^P0cMKL0=CN
i03Hh^P0f>?X0080f^CY00@0f^GZ0=_UjP3KiNX0g^W]103Pj^h00`3Pjnd0hN_]0>3Zk@020>3[k@03
0>7[kP3Qj^d0hN_]00H0hN_]103Rjnd70>;/k@050>;]k@3SkNd0en3P06IZJP0P8B40T@00000<0?oo
o`002P3oool40000000=03@g?P000000000002X/<P1_MH@0/[cC0;Foe`2jaMd0`<_T0<3<i@2nbN80
Z;;804iDGP0=0000000403a0A`25SId0P8NG03Tm@`H0000000<061XL00T92P0000000P0000000`0;
30d00000000000080000000400D51P0D5QP06Q`O00/;30P0000000@0>Si409VR/`2@VJP0<C@i8@00
0000200H6A`0CU9I05QMI@0S9BP000000=KRm03Fh_<0cMWZ0`3Fh_<0103Eh_<0c=SW0=GRlP3Eh_82
0=KRlP040;g7eP3Fh_80e^;b0=KRlP@0e^;a1@3Fho40203DhNl0e^?`0=GSl03DhNh0cmcY0=?Pk03G
ho00e^?`1@3Fhnl20=KRk`@0en;_103Ghnl20=OSkP0=0=CNj`37dMd0aLoK0<G?f`36d=`0b=;O0<WC
g`3:e>00e=k[0=KQkP3Fh>d0e^7/0=KPk@020=OQk@050=KQk@3FhN`0en7/0=OQk03FhN`00P3Fh>`0
0`3GhN`0e^7/0=KPj`040=KPj`040=OQk03GhN/0en3[0=SQj`80f>;/00L0en7[0=OPjP3Gh>X0en7Z
0=OQj`3HhN/0f>7Z0080f>;[103Ih^/03P3Hh^X0fN?Z0=WRj`3HhNX0fN;Z0=SRjP3Hh^T0f>?Z0=SS
j@3GhNP0c]SN0<C=d`3Bg>80c]WM0`3IhnT20=[Tj@040=[TjP3KiNX0g>K[0=oYkPL0h>[]00<0hN_^
0>7[k@3Qjnd0103Qjnh00`3Qjnd0h^_]0>;[k@0=0>;/k@030>?]k@37d=004Q8B09800000303oool0
00X0oooo100000003@0d=ch000000000000Z;380KgF40;:ld`2e_mL0^/GM0<3;i030c>D0_/WR0:Rb
b01>E5h03@000000100l@4L0QHfM0827U`0i?D<60000000301PJ70092@X000000080000000<02``=
0000000000002000000010051@H051HH01XL7`0;2``80000000403XnA02IX[<0T9VX034d>B400000
00P061TL04iBF@1HGFD08bDX0000003Fh_@0e^;c0<gIjP<0e^;c00@0eN;c0<cHi`3Eh_80eN;b0P3F
h_80102mamH0e^;b0=KRlP3Fh_840=KRl@D0e^?a00P0e>7_0=KSl03Eho00e>7^0<oLj@3Ch>`0en?`
0=KSl0D0e^?_0P3Fh^l40=ORk`@0en?_0P3Ghnh03@3Dg^/0am7M0<G?f`35cm/0a]3L0<SBg`39dml0
b]CP0=CNj`3FhNh0e^3]0=KQk03Fh>d00P3GhNd01@3FhNd0e^7/0=OQk03GhN`0e^7/0080e^3/00<0
en7/0=KQk03Fh>/0103Fh>/0103GhN`0en7[0=OPj`3HhN/20=SRk0070=OQj`3Gh>X0en3Z0=OQjP3G
hN/0f>7[0=SQjP020=SRj`@0fN;[00h0f>;Z0=WSjP3Ih^/0f>7Z0=WRjP3Hh^X0f>;Y0=SSjP3HhnT0
en7X0<kHgP34cM<0d]cR0<kIg@<0fN?Y0P3Ji>T0103Ji>X0fnGZ0=cVj`3OjNh70>3Zk@030>7[kP3Q
jnd0hN_]00@0hN_^00<0hN_]0>;[k@3Rjnd03@3Rk>d00`3SkNd0am3@018B4P2B000000`0oooo000:
0?ooo`@0000000d09RT^000000000000Nh:C09NQ]02Z]</0/[gD0:fhcP2ha=`0_/WR0;g9h@2_^]00
GfEa00d0000000@08B<W04U>E`16Be<0824U1`0000001@0S9BT000000000000000004A8D00H00000
00P01PL800h?4@092P/00P8203Hi?`1kQ940N82=02X/<@P0000000@08B<W05QMIP1BEf0071hQ8@00
00001P0410D03@h?00l@4@0B4a@0=cXo0=KQm0D0e^;c00@0eN;c0=GRlP3Eh_80eN;b0P3Fh_800`31
bm/0e^;b0=KRlP040=KRlP80e^;a1@3Fho400`3Eh_00e>7_0=KSl0030=KSl0030=OSl03Fho00e^?`
00<0e^?_0P3Fh^l0303Fhnl0en;_0=ORk`3Fh^h0dmo[0=3Lj03:eN00a];L0:Zd_@2IXZX0KG9h03<f
>@D0<SDh00P0=CTl07ImQ02d_LT0_<K@0<G>fP3<eN00eMo[0=OQk@80e^7]0`3FhN`20=KPk080en7/
0P3FhN`0103GhN`0e^3[0=OQk03Fh>/20=OQj`80en7/00<0en3[0=KPjP3Gh>/00`3GhN/00`3Gh>X0
en7Z0=SQjP020=SRjP030=SRj`3Ih^/0fN;[0080fN;[0P3FgnL20=SRj@0;0=SSjP3IhnX0fN?Z0=OQ
j03FhNP0`lcA0:F]/P3FhNH0fnG[0=WTjP3Ii>T00`3Ii>X00`3Ki^X0g^W]0>3ZkP030>3ZkP<0h>[]
00<0h>_]0>7[kP3Qjnh0203Qjnh20>7[k@030>;[k@3Rk>d0h^c]00D0h^c]0`3RkNd00`3Rk>d0`<S9
018B4P2B000000`0oooo000:0?ooo`L0000000X0_l_T0;k:h`2nb^<0_l_T08ZBY01_MXD0QXnP0:F`
a@2X//P0EU]V3@00000010051PH030`>00/<3@051@H70000000503<g?@0000000000000000082@X0
1P000000200^<CH0IF]f03m3BP0:30d0IVeh0;[5fP2^^L`0?d=:2000000030061`P04A8D010A4P05
1PH01`P901XK7P0O8BD03Pl@00410@0J71h0<C@i01PI71d0000000<0SYNR0=KRl`3Fh_<00P3Fh_<4
0=GRl`<0eN;b00<0e^;b0=3Lk03Fh_801`3Fh_840=KSl@030=KTl@3Fho40eN;_0080e^?a0P3Fho03
0=OSl0<0e^?`0P3Fh^l02`3Bgn/0bmOS0=;Mj@2QZ[<0BDeA03m2AP0j?D00=cXn01TK7@030`@00@41
00L0000000T05AHG03<f>@1<Ce@0EUYO04Q<D02LY:d0dmkZ0=KQk03FhNd00P3FhN`00`3Fh>`0e^7/
0=KQk0040=KPk0040=OPk03GhN`0en7/0=KQj`@0en7[0P3Fh>X00`3Gh>X0f>7[0=OQj`030=OQjP04
0=SQjP3Hh^X0f>;Z0=SRjP@0fN;[0P3Hh^X20=SRj@0;0=WSjP3Ihn/0fN?Z0=GPiP3GhNL0b]GJ0;Fm
`P3Hh^L0gNO]0=[Uj`3Ji>X00`3JiNX00`3Lin`0gn[^0=oZkP050>3ZkP<0h>_]2@3Qjnh0103Rjnh0
h^c^0>;/kP3Rk>h80>;/k@040>;]k@3Qjn`0[[Jf010A4I800000303oool000X0oooo1`0000002P1?
E5l0/;_B0:2[`028TJ<0?D1800d>400P8RH0CE9L05MMJ00X:RlH0000000301TK7P000000000000H0
000000X00@4100<30`1DFV<0]L7E075iQ@0A4Q@0DEIO09bV^01iPHh0828V30000000200I6ad0EU]T
06U_NP0_<SH00P8304aAF@2@VJL0ATYA4P000000100@4A<0=STn024S9P020P87000000030:2Y]P3E
h_<0e^;c0080e^;c1P3Eh_<:0=KRlP<0e^?b00<0e^?a0=KTl@3Fi?401`3Fho430=OSl@80en?`00H0
e^;`0=CPk@1lPhX0EEYO069XKP0U9bTC00000007030c=P1iP8H0^lC>0=CNjP3FhN`0e^3]0=OQk@02
0=KQk0030=KPk03Gh>`0en3/0080en3/0P3GhN`40=OQj`030=OPjP3Fh>X0e]oY00@0e^3Z00P0en7[
0=SQj`3Hh^`0f>;[0=OQj`3GhNX0f>;[0=WRk080f>;[00l0en;Z0=ORj@3Gh^T0en;X0=KQi`3Gh^P0
fN?Z0=;KhP3HhnT0e^3V0=WSjP3Ji>X0fnK[0=[UjP3Ji>X00P3KiN/0103Lin`0g^W]0=oZkP3Oj^h4
0>3ZkP80h>_^00<0h>[^0>3[kP3Pjnh02@3Qjnh20>7/kP030>;/kP3Rk>d0h^c]00@0h^c]00H0h^g^
0>;/kP3Qjn`0[;>d04U<C@071`NB000000`0oooo000:0?ooo`L0000000X0;C0f06M^O01FG6L0;c8h
00d>40020P801@H700l@4P0A4QD020P98@0000002@0W:Rh0EUaU069YM01/M800?D5800T:2`0H6Q`0
<C@j01TJ7@0;0000000:01XK7P15BU80DEEN08B<VP2NYkP0ATYB00830`1CF640W:Jf04]@F1800000
00@0<S@i09NO[@1SJG801@D61`0000000`2PZKL0e^;d0=KRm0020=KRm0D0eN;c0`3Fh_<60=KRlP04
0=GRl@3Eho40eN?a0=GSl@P0e^?a00<0en?a0=OTl@3Gi?400P3?fnP01P2Y/kh0SiRP0:Na^`3@fnT0
_<KB03<f>AL0000000D03@h?04E9C@2RZ[<0e=kZ0=KQk@030=KQk080e^3/0P3Gh>`0203Fh>`0en3/
0=OPk03FhN/0en7[0=KPj`3FhN/0en3Z0P3Fh>X20=KPj@80e^3Z00<0en7[0=SRk03Hh^X00P3GhNX0
203Fh>T0bM?K0;k7c`3EgnP0en7Z0=;Li03Gh^T0fNCZ0P3HhnT01`3Gh^P0e=kU0<_Fg03HhnT0fN?Y
0=WSjP3HhnT00P3JiNX0103Ji>/0g>O/0=cWk03Oj^l40=oZkP<0h>[^00<0h>_^0>3ZkP3Pj^d00P3P
jnh70>7[kP80h^_^1`3Rk>h01P3RkNh0h^c^0>;/k@3RkNh0dM_L04mBDi@00000303oool000X0oooo
1`0000002P0<3@l071dQ01XL800?41802@T;00D61`0H6A`0<cHm02T/<P0>3a4Q0000000604mDG@2/
^</0LGV5034c>@0720P00@413P0000002P0h?480V::c07b4TP1BEUl0E5UR02DX;00000008R@X0414
B`0O8B@B0000000402/]<@1jPH`0EU]S00@51@H0000000<05AHH0:fha@3Fh_@00`3Fh_@60=GRl`03
0=GRlP3Fh_80e^;b0080e^;b00<0eN;b0=KRlP3Fh_801@3Fh_800`3Fho80e^?a0=KTl@020=KSl@05
0=GRl03Bgn`0am?O0;o:eP2mbM@00P2/]l402@1JH6D0F5eR079hP01dNh80IV]b0413A`0G61T01@H6
00@4100F00000004065VK03?f>@0en7]0=KQk@80e^7/1@3Fh>`0103Gh>`0en3[0=KQj`3FhN/20=OQ
j`@0e^3Z00<0e^3Y0=KPjP3GhN/00P3Hh^`0303Hh^/0en;Z0=KQj@3EgnP0c]SP0<oHh@3Gh^X0f>?Z
0=SSj`3Ii>`0f^G/0=[Uj`<0f>?Z00P0en;Y0=KPiP3@f^00en;X0=CNi03HhnP0fnG[0=[Uj`80gNO/
0P3OjNh40=oZkPD0h>[^0P3Pjnh<0>7[kP040>7/kP3Rk>h0h^c^0>;/kP80h^c]0P3RkNh00`33c<d0
?D100000002C000000`0oooo000:0?ooo`L0000000<01`L8038e>`1JH6`00P1JH6`01@0g>d80?dA<
07N0S`1QJ7D08B<X0240000000/0<SDk06eeP@14BE40:2X^0000000820T06Q`O01hP8`0C5AL061XL
01/M800200/;30L0000000H0:2X_06]bOP1BF64051DG00P82@0310@>0000000400P82@0c=SX0CU=K
02@V:@80000000H05aTK0000000;2``07R0S01DG6@010@46000000030455BP2QZkP0eN;d0080eN;d
203Eh_<0103Fh_80eN;b0=KRlP3Fh_830=GRlP@0e^;b0P3Fho802@3Fho40eN?a0=KSl@3Eho00WJNa
08B;T`1GGF<0:2/]07=jP@020<_Hi00:075gO`2FWjT0RY:K01/M7`1TJFl0VjB]051EFP1VK780ATY>
00820QD0000000<0EU]O0<O@g03FhNd00`3FhNd00`3Fh>d0e^7]0=KQk@020=KQk@060=OQk@3FhN`0
e^7[0=KQk03GhN`0en7[0P3Fh>X0303FhNX0e^3Z0=KPjP3GhN/0f>;/0=SRj`3Gh^/0f>?[0=SSk03H
h^/0en;Z0=SRj`@0f>?[00@0fNC[0=[Uk03Ki^d0fNC[0P3Ii>X0203Ji>/0fnG/0=ORj03Ki^`0fnG[
0=[Uj`3Li^`0gNS]0P3Nj>d00`3OjNh0gn[^0=oZkP040=oZkP<0h>[^0`3Pjnh20>7[k`060=OPh`3F
gn<0hN__0>7[k`3Qjnh0hNc^2@3Rk>h20>;]kP030=SSi02>UIH0;2h^09@00000303oool000X0oooo
1`0000000`0>3Q00GfIb0:njd@020:njd@0506]bO`1?E5h0QY2R06ieQ00U:2d08@0000002`0:2``0
5aPK00h?4@0@4A80000001/M801IGfT0Ifii0455C@1LHfd0NX>A0080HVQd00<092L[000000000000
0`0000001@10A4/08B<V01PJ700B4aD00`<40100000000@0414C06U_NP2S[Kd0BdmF0P0000000`0n
@TP00000000000090000000407f5T03?gNh0e>;d0=CRm080eN7c2@3Eh_<00`3Fh_<0e^;b0=KRlP02
0=GRlP030=KRlP3Fho80e^?b0080e^?b00X0eN;a0<?>g03=f^P0eN?a0<gJi`1nQXh0]l7=06Q_M@00
0000:B/^0P1IGf@02P0d=cX0@dM<03i1A@0=3Ph0Ce=H07^2R@1HGF80Yk6k07=jP0030`<E00000004
02h`<`28SYH0am3L0=KPk0@0eN3]0`3Fh>`00`3FhN`0en7/0=KQj`020=KQk0030=OQj`3FhNX0e^7Z
00<0en7Z00P0en;[0=SRk03Gh^/0en7Z0=SRj`3Ji>d0f>?/0=OSk0<0f>?/00/0f>?[0=WSj`3Ii>`0
fNC/0=WTj`3Hhn/0fNC[0=WUj`3JiN/0fnK/0=[Uk0020=WUj`030=[Vj`3Lind0gnW^0080gnW^203O
j^h20>3ZkP80h>_^00P0gn[]0>3[kP3Qjnh0cMKI0<O@d`3Li^X0g^S[0=oYk0<0hN_^0P3Qk>h00`3R
k>h0h^g^0>;]kP040>;]kP030<G>c`0T9RH02``<09@00000303oool000X0oooo100000003@030`@0
30`>03@h?P19CEP0HfYg086:V`29TZ@0TYf`07InS01QJ7D0JW5o04mFH00H6ad02`0000000`092P/0
00000000000H0000000602PZ;`20R9H0U9j^05UOJ@23S9X0ZKC70P2Y]<H00`1=DUX0000000000004
0000000303/oA@000000000000h0000000L03@h?034e>@0f>Sl071lQ04mDF`1kPXh0>3a100<00000
00@03a0B03Xn@`0c=SX020T91`0000001@31c]l0dn7c0=CRm03DhO@0e>7c00T0eN;c1@3Fh_<00`3E
ho80e^?b0=KSl`020=CRl@0;0<SDh`2MY[80MGb30<;>g03>g>X0QY2I04Q<D@1GG680?41301dO8@04
10D01P0000001P0A4Q<06Q`M020R8`17Bdl0<C<f00410@H0000000<0414B01HG60051@H02P000000
20051PH0414B018B4`0I6Q/0[;Bn0=GOk03Fh>d0eN7]0P3FhNd20=KPk0<0e^7/0P3GhN`03P3FhN`0
e^7[0=KQj`3FhN/0en7[0=OQjP3GhN/0f>;[0=SRk@3Hh^`0en;[0=SRj`3Ihn`0fN?]0`3Hi>`0203H
hn`0f>?[0=[Uk@3Ii^`0f>C[0=SSj`3HhnX0f>C[0P3IiN/20=[Uj`050=WUj`3Ji^`0g^S^0=kYkP3O
jNl00P3Oj^l20=oZkP<0gn[_0`3Oj^h20>3ZkP80h>_^00P0e=kR0=oYk03Qjnh0fnGX0=_Vj@3Dg^40
e^7S0=3Jg080hN_^1@3Qk>h01P3Rk>h0h^g^0>;]kP3Qk>h0gNSY09nWYiH00000303oool000X0oooo
100000003@0C51L0@dMA05]QK@2GXKH0Ff5]02d`=P1EFfH0R96S09VS]`2FX;@0SYR[07AlR`0[;S@0
2`0000000`0E5aT00000000000090000000400<4100000000000018D5PD0000000<01@H600000000
00000`0000001P0D5QP0@DE=04]@F@0e>3l0AT]C07^3T@80TI^Z00<0@dM?0000000000000P000000
0`010@40000002lb=`030000000400H61`0=3Q002PX;00820PT0000000L0828U07MoR`21RYL0;C0d
01PJ700V:2`04A8D00<0000000@09BP[08bFX`1kPhl051DG20000000103Bgo40e>7d0=CQm03Dh_@2
0=GRm0X0eN;c00h0e^?c0<_Hi`3<fNP0eN7a0=KSl`3@gN`0am?Q0:6Z]P1MHfT0Uj2[0;W5dP2KYK00
DeQN079iP@80QHfF00<0@4A901/L7P0000004@0000000`1JGf@0O8>901dO800:0000000602@U:01W
K7<0DeML010A4@2U[KP0e^3]0P3Eh>d00`3EhNd0eN7/0=GPk0020=GPk0030=KPk03FhN`0en;]00H0
e^7[0P3Gh^`02P3Gh^d0en;/0=ORk03Gh^`0f>;/0=SSk03Ii>d0f^G^0=[Uk@3IiNd20=SSj`030=_W
k@3IiNd0en?[0080en?Z0P3Hi>/01`3IiN/0fNC[0=[Uj`3Ji^`0g>S]0=oZk`3NjNh02`3Oj^l01`3O
j^h0h>_^0>3[kP3Pjnl0d=_N0=kYk03Qjnl00P3Qjnh00`3Li^T0f>?U0<cGf@030>7/k`80h^c_00<0
h^c^0>;]kP3RkNh00P3QkNh00`3Mj>T0MWal03@g=`2F000000`0oooo000:0?ooo`@0000000d08RDY
07R0T02R[/@0Y:o504M;E@000000A4UB09^V^`2f`m/0ZkS>0:Jbb02Y]L`0D5EP00X0000000H00P82
02<U:P0f>D00CE5L034c>@0=3Q0:0000000302d`=@000000000000T0000000H00@4100@51@051@H0
0P8200@41@0N82<2038f>`0301TJ7@00000000000080000000<01`L80000000<3@h00`000000100X
:Rh0GfI_04E:D@0<3@h20000000300h>40020P80000000<0000000D00@4101`N8@1TJW@0K7=n02<V
:@060000000501XL7P1QJ740LGR205UPI`0m@DH00P0F5aT00`051@H0000000000002000000030<kK
k@3Dh_@0e>;d00<0e>;d0P3Eh_@40=GRl`@0eN?c00h0e^?c0829T`1[LWX0bmSV0=KSl`3Eh_40c][Y
0;Foc02[]/40]L7>08VBV`1mQ8d0Q8^D0:2Y]@80]l;?00<0FEiT01/M7P0000004@0000000`1LHFH0
OhJ=01hO8@090000000600410@1FFUl0/;W409^S[01AEU/0VJ2Z0P3FhNd00`3EhNh0e^7]0=KQk@03
0=GPk0040=GQk03FhN`0e^7[0=KQj`80e^;[00L0e^;/0=KQj`3FhN/0e^;[0=SRk@3Ghnd0en;]0080
en?/00P0f>?]0=WSk@3Hhn`0f>C/0=WTk@3IiNd0f>C[0=OSjP80fNG/1@3Hi>/0103IiN`0f^G/0=_V
k@3MjNh20=kZk`030=kYkP3Oj^l0gn[_00L0gn[_0`3Oj^h30>3[k`030=gXj`3Qjnl0hN__0080hN__
00<0fN?V0<oJg03Ji>L00P3Qk>l40>7/kP@0hNg^00<0f>;T030b<P000000UP00000<0?ooo`002P3o
ool40000000=01HH6`1>E5l0Jg:106M^O00R92T0000004E9D`2KY[/0XJg207V1T@1gOhl0P8RI03Xn
AP0:0000000600P82@0i?D@0PhbM09bW^`1WKW/071hQ2P0000000`0]<3D000000000000F00000003
00`=3P000000000000<0000000@0AT]C0:Vea@1kPi005ALI0`0000000`0:2P/00000000000020000
000501XL7P1@EEd0FV1Z03<f>`0:2``01`000000100<3@h0BTmF0;6mc@2JY;8206E[M@0301PI6`00
000000000080000000@0KGAn0:Nb`03Dh_@0^LGD0P3Eh_@00`3Fh_D0e^;d0=GRm0020=GRl`<0e^?d
00H0e^?c0=KRl`3Fho<0P8RB02LZ;01YKgL3079iP@070828T@2a_<P0LWV103Lk?`1hOhP0Ph^E04mC
F@0204U>D`0302<V:0051@D000000140000000D07AhP02h`<P0c=CP0CU9F02X/;P0401DF5`0502da
<`1JGf<0GVAY06Q]L`2mb=800P3Eh^d20=GRk0040=KRk@3EhNh0eN7]0=GQk0<0e^7]0P3EhN`02@3F
hN`0e^7[0=KRj`3Fh^`0en;/0=ORk@3Fh^`0e^;[0=ORj`030=ORk@<0en?/00<0f>?/0=SSk@3Hhn`0
0P3Ii>`20=STk0030=WTk03IiN`0f>C/0080f>C[00H0fNG/0=[Vk@3Lj>h0gNS^0=kYk`3Oj_020=o[
l0040=oZk`3NjNl0g^W^0=kYkP@0gn[_00D0h>__0=oZk`3Oj^l0gn[_0>3Zk`050>3[k`<0hN__00<0
hN_^0>3ZkP3Qjnh0103Qk>l20>7/kP80hNg^00@0hNg_0>7]kP3Eh>40<38bU`00000<0?ooo`002P3o
ool50000000<01TK7`0V:2h0;c<j03Dh@00M7R80AdaF09VT^02:U:H0?41801lQ9@0[;S@05QLJ2P00
00001P0>3Q00GF9^0:jjd02[]l`0LWZ701dO8`X0000000<04Q@F00000000000070000000100T9b/0
EeeV03m4BP0;30d30000000300h?4@00000000000080000000@0<SDj092JZ@2;U:80;2ld2@000000
0`0W:Bd0MGf809>MZ`0207f5T@0301dO8P000000000000<000000140M7b60<oMkP2obm/0eN;e0;K1
d@2JXk00a];S0:Zd`@34cn00c]_/0=?Pl@36d^40am?R0<C@g`2obmT0dn3`0869TP050000000701HG
6@0e>3`05aTJ00L8200V:2/09bT/00L8200B0000000900L8200M7b00?D5406ieN`2CVj<0^LG>0<GB
g03Eh^d0`m3I00<0^LG=00H0^/G=0<[Fg`3Jj?80fnSc0=cYl`3Lj_@30=gZm0050=_Yl`3Jio40e^7^
0=GQkP3EhNd00`3FhNd20=KQk0D0e^;/00D0en;]0=KRk03FhN`0e^;/0=ORk@050=OSk@030=OSk03G
i>d0f>?]00<0f>?/00T0f>C/0=WTk03IiNd0f>C/0=SUk03Ki^h0g>S^0=gYk`3MjO000P3Nj_001@3O
j_00gn_`0=o[l03Ojo00f^G[0080dMcQ00<0gn_`0=oZl03Nj^l00P3Ojo000`3Pjo00gn__0>3[k`07
0>3[k`@0hN__1`3Qk>l40>7]kP030=3Kg00b=CD0000009H00000303oool000X0oooo1P000000200:
2``0ATYD08nH[01:CeT0<SDl05MNJ@1?EEl07R0T3@0000001P0:2``0@dM@08J>W`1kPi80@dMA00h?
4BT0000000<00@4100<30`020P80100000000`061`L000000000000200000004020R9@1KHV/0F5iW
01`N8@T0000000<00P8200h?4@0^<CH00P0^<CD00`0;2``00000000000030000000D03Hj?`2:Tj00
]/;A0=?PlP2BVjL092LY04aAE`0a=3P0T9VU0;:mc035dN40JFmg07f5S`27SiX0GfE]07n7T00m@4D0
8B<U03Hi?@0C51D?0000000800410@0720P02P/;00X;2`0;30`0;2la04M<C`1kPXP4092IX00809ZT
[02nbM@0d]o[0=GTjP3<b]80dmSR0=cZm@3KjO@40=cZm@050=gZm@3Lj_@0g>[d0=cZm03LjO<00P3K
j?801@3Mj_@0g>[c0=cZl`3KjO80e^;^0080eN7^00<0eN7]0=KQk@3FhNd00P3Fh^d00`3Fh^`0e^7/
0=KRk0020=KRk@070=ORk@3Fh^d0e^7/0=KRk03Fh^d0e^?]0=KSk0080=OSk080f>C/00H0fNG/0=[U
kP3Ii^d0f^O^0=kZl@3Oj_420=kZl0<0gn[`0`3Ojo001`3Nj_00`<[?0<3:c`2`^Kd0`L_@0=cWk@3O
jo00103Ojnl20>3[k`030=o[k`3Pjnl0h>__0080h>__00<0h>c_0>7/k`3Qk>l0203Qk>l01P3QkNl0
hNg^0>7]kP3QkNh0e^7R04eBDYL00000303oool000X0oooo1P000000200=3Q00FV1]0;6neP1PIW<0
71dP01HG6P0D5AP01`P93@0000001@0410D06A/N030c>P0S9BT030d>03<0000000L05QLI00000000
00001`L801<D5P0B51H01PH700P0000000<061TK0000000000002P0000003P0>3a00VZ>`0=3Mk`2A
VZL0A4Q>01hP8`0L7R00BDeB07AjP`21RI<0;c8e01/L7`0N82801`L80P0000000`1OIF`0VjB`03Hj
?P0<0000000500T:2`1`Mgh0L7Mn08nHX@2IY:d00P2]]l404`2f`</0dn3/0=[Wm03Iio@0f>Gc0=WW
m03Jj?D0fnSe0=_Ym03LjOH0d=gY0=CRi`38aLd0d=CO0=GUj03Gi^/0fnSc0=WSkP3Gh>X00P3Kj?<0
0`3KjO<0g>[d0=cZm0040=cZm080g>[c00D0fnWc0=OSk`3EhNh0eN7^0=KQkP020=KQk@070=KRk@3F
h^`0e^;/0=GQk03FhNd0e^;^0=KRk@020=ORk@80e^;]00<0e^;/0=OSk03Fhn`00`3Ghn`30=OSk@80
enC]00@0f>C]0=WTk@3Ji^h0g>O_0P3MjO000`3Nj_40gn[a0=kZl@020=kZl0030=oZl03Ojo00gn_`
0080gn_`00L0gn_a0=SUj@3HiNT0H6EX0495A`3CgN80gn_`00L0gn__1@3Pk>l20>7[k`T0hNc_0P3Q
kNl00`3Ojnd0bmKH04iCD`2G000000`0oooo000:0?ooo`D0000000`02PX<01<E600d>3l0N82@038f
?@0:2P`0000000H61`0G6A`09BL/01@E60030`@_0000000400L7200E5aT05AHH00H71`l0000000<0
<SHl0000000000006P0000002P37e>D0e>7c0<CAh@2T[[`0T9ZV086:U@1]MGh0;S4e01PI6`082@T5
0000000304eAE`1mQHh0;2lb00P0000000D02P/<03@g>P1WKG<0KgIl07j5S@020=;Pk@0H0=[Xm@3L
jOL0g>[g0=cZm`3LjOL0fnWg0=[Xm@3Gi?80e^;a0<oRh038h<h0e^K]0=_Xm@3LjOH0eN?_0=7OjP3G
i>l0]/7;0:fg`03BgnX0g>Wd0=STk`3Bg>L0fNKa0P3KjO<01@3KjO@0g>[d0=SMi`3>`<P0fN?/0080
fnWc00@0e^OW0=cZl`3Hi?00e^7^0P3EhNh20=KQk@80e^;]00D0en;^0=KSkP3Ghnh0en;^0=KRkP03
0=KRk@040=KSk@3Fh^`0e^?]0=OSk@@0en?/00/0f>?]0=STk@3HiNh0fNK^0=_WkP3Kinl0gNW`0=gY
l@3Nj_40g^[`0=kZl@030=kZl0030=oZl@3Nj_00g^_`00<0gn_`00H0gn_a0=o[l03Ojo00R8jB01dN
7`38d]L30=o[l0D0gn__00<0h>c`0>3/k`3Pk>l01@3Pk>l50>7/k`D0hNg_00<0_lW:04M;B`0H6AT0
U`00000<0?ooo`002P3oool60000000;05EKI`0^<CL07QlS00D51P010@400000018C5P16BeD0KWJ5
03a0B0092P/03`0000000`0G6A`01PH70000000M0000000401hQ901MI6h0FV1Z01/L7b`000000`1k
Phd01@2<UJ00^/KF0;O3dP2JY;40<3@h00L0000000<061XL034c=`0G61X0200000001@1EFf00[KS2
0=[Wm@3Kj?H0eNKY0080en3^00`0dMCQ0=OPk@3KjOH0fnWf0=CRk`32cm/0]/;<0<WEh@3Gi?80e^C_
0=OWk`3Jj?<30=_Ym@0F0=[Xm03KjO@0bmSR0<gJi@3Hio80g>[e0=KTk`3@gNL0fn[d0=_Ym03Iio40
b=GO0:jj`P39e]l0f^Ob0=GSk@3<f^<0_l_D0<[Ig03Hi_00f>G_0=OSk`80eN7]0P3FhNh00`3Fh^h0
en;^0=OSkP030=OSkP070=ORkP3Fh^h0e^?^0=OSkP3Ghnd0e^?/0=OSk@020=OTk@070=OSk@3Ghn`0
en?/0=STk@3Kinl0g>W`0=gZl@020=kZl@030=g[l@3Njo40g^_a0080g^[a00<0g^_a0=kZl@3Nj_40
0P3Nj_030=oZl080gn_`0P3Ojo40102]][X05QPH0<OAeP3Oj_030=o[l0@0gn__1P3Pk?030>3/k`<0
hNc_00<0hNg_0>7/k`3Qk>l00`3QkNl00`2[]KD000000000002G000000`0oooo000:0?ooo`H00000
00<0X:c204iDG`0000000`0000001@0M7b<0LWZ90;:neP1PIg@03a0A0100000000<051DG00000000
000070000000100^<CL0SINW08NAX@0X:c0/000000<02PX;00D09BL[04M<D@16BU00>cm4018D5@04
0000000600<31011AD/0EeaT04=7C@24SIL0B4aB1P0000001`051PH01`L808bEWP33cm/0_<SD0=3N
j`3KjOL00P3Fgnd0103FgNX0f^Se0=[Ym@3JjOD30=[Xm@030=WXm03Jj?D0f^Se0080f^Se103Jj?@0
0`3Ij?@0f^Sd0=[Xm0040=[Ym080fnWd00T0fNOb0=[XlP3Iio40e^C]0=CRk02obmD0/l390:2[/`33
d=T00P3LjO<00`3Jj?40e^;^0=KRkP020=KQkP050=ORkP3Fh^h0en;^0=ORkP3Ghnh00P3Hi>l01`3G
i>l0en?^0=OTkP3Gi>d0e^?/0=OTk@3Hi>h00P3Ghnd0103Hi>d0fNO^0=cYl@3Mj_420=gZlP040=kZ
lP3Mj_40gN_b0=kZl@@0gN[`0P3Nj_030=oZl@040=o[l@3Ojo00gn_`0=o[l080gn_a00<0`/gA01/M
7`30bLh01`3Ojo00103Ojnl0gnc_0=o/l03Ok>l90>3/k`H0hNg_00<0Yk6b000000000000U`00000<
0?ooo`002P3oool60000000306eeQ00f>T4000000080000000H03PlA038e?01KHVh0L7R703TlA008
2@X@0000000301`N8@000000000001`0000000@05aPK04E:DP13Adl051DH0`00000010030`<030d>
010A4P061`LM0000000400820P0A4Q<05AHH00H61PT0000000<0:2/^06I/M@0b=CT0100000002006
1`L0OhJA0:Vc`@1KH6L0VZB`065XK`0W:B`03a0B100000001`051@H0V:6/0=7Ok@2g`/l0/[k90=GS
l@3JjOH00P3Ij?D30=[YmP@0f^We1P3Jj?D30=[Xm0H0f^Wd00L0fnWd0=[Xl`3Ij?80f^Sb0=[Xl`3J
j?80fNKa0080f>K`0P3Jj?801@3KjO<0g>[c0=cZl`3Lj_<0fNOa00<0f>G`00<0enC`0=OSk`3Gi?00
0P3IiO003@3Jio40f^Sa0=[Xl@3Jj?40fnSa0=SUkP3Fhnd0f>G^0=_Xl@3Jio00fNK_0=[Wk`3Lj_40
0P3MjO401P3Mj_80gN[a0=gZl@3Mj_40gN[b0=kZl@<0gN[a0`3Nj_430=kZl080gn[a103Ojo40103H
hnT0KgEh0;S1aP3Nj^l20=o[l0040=o/l03Ojo00gn_`0=o[l0D0gnc`203Pk>l00`3Qk>l0hNg_0>7]
l0020>7]k`030>3]kP2DWIh0000009P00000303oool000X0oooo1P0000000`0U:2d04Q@F00000002
0000000602HY;P1RJGL0KWN604=8D@0?41800P83400000000`0>3a4000000000000S00000004010A
4`1:D5P0GVE_02DX;1d0000000D08bDY08:;U`2HX[40JFmi02P/;`060000000500410@000000CE=I
0<GBhP1QIfl0100000002P030`<0=c/o04U>E00U9bX0<CDh06=YL@2:TYh0=cXo0000000Y;2h204]@
E@03069XKP3JjOL0f^Wg00<0f^Wg00<0fnWg0=[YmP3JjOH00`3JjOH20=[Ym@L0f^Se00<0f^We0=[X
m03JjO@0203JjO@40=_Ym0050=[Yl`3KjO@0fnWd0=_Ym03:en000P3Kj_<01@3DhN/0eNC]0=[XlP3K
j_<0fnWc0080g>Wc00D0fnSc0=[WlP3Jio80g>Wb0=cYl`030=cYlP060=cZl`3Ljo80fnW`0=WVk`3K
j?00gN_b0P3Mj_80103Lj_40eN;Y0=cZl@3Mj_420=gZlPH0gN[a1@3Nj_420=k[l@80g^[a1@3Ojo40
1032c=40QXf@0<C>d`3Oj_040=o[l0<0gnc`1@3Pk?050>3]l0030>3]k`3QkNl0hNg_00<0hNg_00<0
d]kP069XJ0000000V000000<0?ooo`002P3oool;0000000403@h?`24SJ00S9JZ03m4C3P0000000@0
6adP07j7U@2OZk`0?d=:0P0000000`0@4A<000000000000H0000000504I;D`30cMl0c]c_0<KDiP1Y
L7X00`000000200U:2/0Ff9Y02hb=@030`<0000002<U:01IGfH0;2lb2@0000001@1JH6L0UYn[03/o
A0000000K7=j0080bMOT00H0dn;_0=[Ym`3IioD0f>Kd0=WWm@3Ij?H70=[YmP030=[Ym@3Jj?D0f^Se
0080f^Se00@0f^We0=[Xm@3Jj?D0f^Sd3`3JjO@02`3Jj?80f>Oa0=[XlP3Ehnd0fn[d0=_Zl`2lb=40
TYbS09>LY02lb=40fNKa0080fnSc0`3KjO<00`3KjO80g>Wc0=cYlP020=cYlP80g>_c00<0gN_c0=cY
lP3Mj_802P3Mj_820=gZl@050=gYl@3Mj_40g^[a0=kZl@3Mj_000P3Nj_440=k[l@H0gn_a00@0e^7W
03Tk?01aMWT0fnK/0P3Ojo000`3Pjo00gnc`0=o/l0030=o/l0<0h>c`1`3PkO040>7]l0030=o[k@1/
LW806Q/L09T00000303oool000X0oooo2`000000100L7R80AdeG04aBG00R9BXh0000000400h?4010
AD`0DEMP020R9P80000000<0;S8g0000000000002@0000001`0h?44010D5000000061PL0:blc0456
C00K7R000P0000000`071`P03a0B00P92P030000000502P[;P2:U:00]lCE0;?0c`1HGfL00`000000
101AEeh0a]CU06E/M@020P8=0000000501lQ8`0c=SX051DG0000002V/K`01P3JjOL60=[YmP80fNSf
00<0f>Oe0=KUl@3Hio<00`3JjOD30=[Xm@80f^We00<0f^Wd0=[Ym@3JjOD00P3JjOD70=[Ym0030=[Z
m03Kj_@0fn[d00D0fn[d00D0Z[Fm08nHX032cML0fNOa0=_Xl`020=cYl`<0fnWc00<0g>Wc0=_YlP3K
jO800P3LjO840=gZl`<0gN[b00<0gN[c0=gZlP3Mj_800P3Mj_820=cZl@80gN[a0`3MjO420=gZl@80
gN[`00<0gN[a0=k[l@3Nj_400P3Nj_400`3Njo40gn_a0=k[l@030=o[l@040=[Vj`0l?T00Ada=0=OS
i`@0gn_`1`3Ok?000`3Pk?00h>c_0>3/k`020>3/k`80h>g_00H0hNg_0>7]l03QkO00hNg`0=cXjP0f
>CVJ000000`0oooo000:0?ooo`/0000000@010D500/<3@0<3@h01@H6>@0000000`020P800`<30041
0@020000000802``=@0000000000000000051@H04a@F01LI6`092@X40000000707EnRP092P/00000
00d>401VKWP0VZFd0455C00200000004038f>`1^MX00?D5700820P80000000D010@501DF600l@DH0
?d=9018D5@030000000502T/<01UK7D0C59H04iCFP0U:2/040000000203Ij?H0f>Of0=WXmP3Gi_@0
e>?a0=KUl`3Hj?D0fNSf103IjOH30=WXmP80fNWf0`3JjOH00`3<f^H0f^We0=[Ym@030=[Ym@030=KT
l03Bh>/0fNOc00@0f^We1`3JjO@60=_Ym0030<kKi@2kam00e>7/00P0fnWc00<0g>Wc0=_YlP3Lj_<0
0P3LjO<40=cZl`@0g>[b00D0gN[b0=KSj`33dML0`/kD0=;OiP020=gZl@@0gNWa0`3Mj_40103Mj_00
g^[a0=kZl@3Nj_440=k[l@<0gn_a00@0g^[_059GF@16BT`0f>CY103Ojo080=o/l080h>c`00X0h>c_
0>3]k`3PkO00h>g_0>3]l03QkO00h>g`0>7]l03EhN<0;C0`VP00000<0?ooo`002P3oool800000004
00@41@0820T01PH700820Q@0000000<00P82000000000000100000001@051@H0828V03/oAP0[;S@0
4A8D01/0000000D04Q<E02@W:`0V:Bd09RT]01<D5P050000000?01DF6@1BF640IVeh02HY;@0J71l0
?T=902DX:`000000@DI=00D51P0000002`/<055GG`1jPhl0=3Ll0080000000@0EE]T0;W7f@1WKgT0
0`<4300000000`1?E5/0^LGE05QNI@0700000003014B4`0X:bh04A8C00H0000000X0f>Sg0=KUm03H
ioD0_lgJ0;c9eP3?g^`0fNSf0=SXm@2f`ll0/;g80P3Fi_<20=WXmP<0fNWf0`3Gi_<00`3Ch^h0fNSd
0=[Ym@030=[Ym@030=7Pj`3BhN`0f^We0080f^Wd00<0bMOR0=CTkP3JjO@00`3JjO@30=[Xm0H0fnSd
0`3Kj?<80=_Yl`@0g>Wc103Lj_<00`3Ljo<0g>[c0=cZlP020=cZlP040=gZlP3Dh^T0cm_S0=[Wk`80
gN_b00@0g>W`0=SUk03Kj>l0gNWa0`3Mj_420=k[l@80g^_b0`3Njo420=o[l@80gnca00H0gn_a0=_W
k@11ADH0>Sho0=3Kh03Ojo420=o/l@T0gnc`0P3Pk?00103PkO00h>g_0>3]l03PkO030>7]l0030>3]
k`2e`<805aPH09X00000303oool000X0oooo20000000100W:Rl0CUAO03a0B@0C5APD0000000301DG
6P000000000000@0000000D02`/=04E9DP1mQID0G6=^02@W;00K0000000703i2B@20RIP0Q8jL08bG
YP1/M800<cHl00`=3P0300000007020R9@1mQY<0VZFe03XnA012Adh0WJRi05eTK@040000000:00<3
0`0G61/08RDX00h?4@0T9RX0BTmF04]@F01OIVl0=CTn00420P`0000000<0=CPm07^3SP0k?d@01`00
00001012AT/0Yk;007EmQP0K7Al50000000:01lQ8`2kb=D0d^7_0=?Rl03FiO<0f>Of0=SWm@3Fi?@0
a=;P0=?Rl080f>Oe1@3IjOH02@39f>@0f^Wf0=[YmP3Hj?D0enKc0=WXm030c]T0XJbf0<gKi`050=[Y
m@030;[6d03Ei>l0fNWd00<0f^Wd00<0f^Sd0=_Xm03Kj?@0103Kj?@50=_Ym0L0fnWc00D0g>Wc0=cZ
l`3KjO<0fnWc0=cYl`070=cZl`80gN[c00<0g>[b0=gZlP3Lj_800`3Mj_80103Kj>l0f^O^0=gZlP3N
jo820=g[lP050=gZl@3Mj_80g^[b0=kZl@3Njo801`3Njo401P3Ojo80e>3U034d=P0P8B80WZR/0=k[
l080gn_a00<0h>ca0=o/l@3Ok?400P3Ok?000`3OkO00gnc`0>3]l0070>3]l0060>7]l03PkO00h>g_
0:Na/`17C4`01PH6VP00000<0?ooo`002P3oool80000000404Q>F02AW;40L7R802@W;1@0000000<0
:2/`000000000000100000001@0=3Pl0DeUT09NR]@1`N8H0;2le01/0000000L0DEMP0:Nda`2]^/d0
]<;F0:Nca@1bNhL06Q`O00<0000000`0414B03e2B01;DET071lR03Lk@@22S9T0CE=K0000000=3Pl0
6Q`O01DF6@0720P300000004051FGP2W//<0Ff5[00<30`h0000000h01@H600d>3`061PL0414C06=Z
L`2LYk<0Y[6o08^EX00i?440000004A8CP2kamH0^LKE03i2A`@0000000/030d>04Q=DP2>VJ<0d^7_
0=SXmP3Gi_D0enOe0<3=fP37eND0cmg/0=WXm`020=WYm`<0fNWf00<0c=_X0;[7dP31cm/00P3JjOH0
1P3Hio@0enOc0=WXm@2_^lH0_L_E0<kLj0D0f^We00<0aMCO0=OWlP3JjO@00P3Jj_@00`3=fnD0f^Oc
0=_Xm0030=_Xm080f^Sd0P3Kj?@00`3KjO@0fnWc0=_Yl`080=_Yl`80g>[c00@0fnWc0=_Zl`3Kj_80
fnWb1@3Lj_<20=gZl`040=cZlP3Mj_80gN_b0=gZlP80gN_b00@0g^[c0=gZlP3Mj_80g^_b0`3Mjo82
0=k[lP030=kZl@3Njo40g^_a00<0g^_a00T0gn_a0=o/l@3Ok?40gncb0<C?e00]<3401`L8030b=036
dMH01P3Ok?420=o/l0@0h>c`1P3PkO000`3Ok>l0am?D04E8BP2L000000`0oooo000:0?ooo`P00000
00@0>Sm707AnSP1IH6d07AlS6`0000001@0720T0;c8h05EKIP0o@d/06A/N01/0000000L09BL/04aB
FP1>E5d0J71l08>=W01MI6h05QLJ00L0000000P03a0B02@V:P0E5aT00000030c>01RJ780CU=K01/L
7`<0000000@0@DI=08RAW`1:CeL00P82100000000`0^<CH0C59J020R9@090000000B00L8200L7B00
WJRf0=3Ol@3Ch_@0d=oa06YaNP00000051DG061WK`1^MWl092LY0000000e>Cd0HVUa02DW:P000000
X:bg0P3IjOL01P3Hj?L0enKe0=OWm@2S[kX0c=[X0<cKj@D0fNWg00D0fNWf0;6nb@2e`/h0eNCa0=WX
mP020=WYm@030<kMjP2X]L00/Kk80080f^We00L0d^7/0<;@g037e^40fNSd0=?SkP3Ei>l0fNWd00<0
f^[e00<0`<kH0=[Wl`3Jj?@00`3Kj?@<0=_Ym0D0fnWc2@3Lj_<30=gZl`050=cZlP3Mj_80gN[b0=gZ
lP3Mjo80103Mj_801`3Mjo80g^_b0=gZlP3Kinl0f>G/0=cYl03Mj_400`3Njo820=k[l@80g^ca00<0
d]kT05]PHP0C4a@00P0000000`1@DeH0e>7V0=o/l@020=o/l@@0h>ca00<0h>ga0>3/l@3Pk?001P3P
kO00103Nk>h0Yk:c03m3@`0B4a>L000000`0oooo000:0?ooo`P0000000@061XN034e?00V:Bh030d?
6`0000001@020P8030`>01DG6@0@4A<01PL701P0000000<07b4U02/_=00A4aD00`000000100>3a00
92L[01dP8`071`P;0000000405=HH@2Z]<H0R92N02ha=P<0000000@05AHH02/^<`0H6A`00@411000
00000`1WKWT0Z[O804I<D`070000000901hP8`1DFV40=3Pm00/<3@19CU@0OXJA08ZCW`1eOHH0<3<g
0080000000T010@400H61P020P804Q<E08fHY036e>@0E5YQ00000032d=d00P3HioH01P3IjOL0fNSg
0=WYm`2kbMH0/[o;0<kMj`@0fNWg00D0cMcZ0;6nbP2lbMH0f>Kd0=SXm@030=WYmP030<KDg`36eN00
dn;^0080f^Wf00D0_<WD0:B`^P2R[KP0enKb0=7Pj`030=WYm@0:0<oNj@2S/;X0_<WD0=[Wm03Kj?D0
fnSd0=[Xm03JjO@0fnWd0=[Xm0<0f^Wd0`3KjO@00`3Kj?<0fnWc0=_Yl`040=_Yl`80fn[c0P3KjO<3
0=cYl`@0g>[c00@0g>_c0=gZl`3Mj_<0g>[b0P3Mj_<00`3Mjo<0gN[b0=gZlP050=gZlP050=gZl@2H
X:D0Xjfa0=gZl@3Jj>h01@3Njo820=k/l@030<?>d`00000000000080000000<01PL707AlOP3Kj>d0
1@3Ok?440=o]l@080=o]l03Nk>l0g>[]0=cYk@3Ii^T0]L3207^3Q00`<S>N000000`0oooo000:0?oo
oc@0000000@05QPK034e>`0S9BT020P93@0000000`20RIL0<cLm0000000>0000000:01PJ700l@4H0
<cLl04]?E`1_MX80DeUQ01/M80092@X05ALI00`=3PP0000000d0@dQ?071hP`0^<SH0000001`N8@1;
D5L0DUQP04iDF`0S9RT01`L804aBF02ha=D0LWZ400/0000000h092LZ0:B__@2a_L`0@4E:0000003H
j?L0e^Ge0=OVm@3HioH0e>Cb0;o=fP3=g>X0f>Sg0=KVm0@0fNWg00X0`<kL0;:nb`36dn40enOe0=WY
mP2iam<0Uj>]0:Zg`@37e^40d^7]0`3JjOH01@2V/[`0YK2k0;?1b`3Gio<0f>Sd00<0fNWe00@0`M3J
0;G1b`3?gNT0f^Sd0P3Jj?D30=[Xm0050=[Ym03KjO@0fnWd0=_Ym03JjO<00P3KjO<30=_Xl`<0fnWc
00<0f^Wc0=_Yl`3Kj_<00P3KjO<20=cYl`80fn[c1@3Lj_<00`3Mj_<0gN_c0=g[l`020=g[lP030=g[
l`3Lj_80g>_b00<0gN_b00/0g^_b0=_Wk`1cNWh0LGUm0<gJh@3Ii^`0enG[0<cIg`3Kinh0g>W_0=k[
l@020=k/lP030;>oa0000000000000<0000000D05AHF07=iO02QZZh0]/340=;Oh`020=WVj`0:0=[W
k03Fh^H0`LgA0;>m`02:TY@0H6IX03i3A00l@440>chn01lQ8J000000303oool000X0oooo=0000000
100k?dH0OXRG05UOJP0D5AP=0000000608RCX@0f>d002``=01PJ700>3a000@412`0000002P0l@4H0
U9n_07b6TP1jPi00H6I`02LY;P0820T0<CDi07IoRP13B4h80000000=00T92P0?41401PH700000011
AT`0[K[:0;o=g`2f`m@0DUMO03@h?@29Tj00OHF@03Pl@@080000000?00410@0c=c/0EeeT065XL01_
Mh00D5IL01<D5P000000f>Wh0=SWm`3FiO@0eNCc0<kMj`2Y]L40aMCQ0080fNWg00h0^<GB09:MZ02B
WJP0V:B^0:Nd_`2P[;P0aM?Q0=SWm@3IjOH0Z[O109>OZ02?Vj@0_/cG0<cKi`80fNWf00/0fNWe0;c:
eP33dMh0c=cW0=WYm@3Ij_D0]<7;08nIXP2CWJL0[;S20=CRkP020=[Xm@030;o;eP2mbM@0f>Oc0080
f^We103JjO@30=_Ym0030=_Xl`3KjO<0fnWc00<0fnWc00@0f^Wc0=_Zl`3Kj_<0fn[c0`3KjO<00`3>
g>@0eNC/0=cZl`060=cZl`050=_Yl@3Ljo80gN_c0=cZlP3Jj?000P3Ljo803@3Ljo40g>[b0=gZlP3L
jO40Nh:6051FF@37dmT0cmcS0=[XkP3BgnD0e>3W0;O2a`30c=400P3=fMl00`1_MGP0000000000006
0000000900P8200S9BD0;c8c03Tm?P0n@D<0=SXk01lP800C51@01PL70:D00000303oool000X0oooo
8P0000000`092@/000000000000?000000040497C`2AW:h0IVij01LI6`d0000000H0=3Pn01DF6@0f
>T00LW^70456C@061PL;0000000:03@h?@20RIL0P8VH0:Jba01dO8P06ahP00000017CE@0[;W:065Y
LP`0000000P0:B``06]cOP1gOhX0LGV403Di?P1;D5L0/l3@05IMI@T0000000H00`<407V1R`3;f^X0
bm[Z08VBW@0C51H3000000060;G2c`2/^LH0cmk^0=CTm03Fi_@0enOf0P3IjOL01`2GXjh0/[o:0;:o
bP2ha]80PhfE0;o=fP3Ah>h00P3IjOH02`32d=`0WZ^e09^W/@2ocMT0dN3/0=WYmP3Gi_<0Z[K10;o=
fP3Eho80f>Sd0080fN[e00@0VjN`09FOZ@2lbM@0f^We0`3Jj?D01P2e`L`0aM;N0=OUl@2kam40/Kg7
0=;Pk080f^Wd0P3KjO@00`3Kj?@0fnWd0=_Ym0030=_Ym0<0f^Wc00@0fn[c0=_Zm03Kj_<0g>Wc0P3K
jO<0103Jio40enG^0=WWl03Ehn`40=cZl`050=cYlP3KjO80g>_c0=g[l`3Mj_<00`3Mjo<03@3GiN`0
f^O_0=g[lP3Lj_40OhJ:04=7B@38e=X0dn3V0<cIg`2h`lT0/[g20:nj_P1UJfd00P0g>S`00`0C51D0
00000000002d000000`0oooo000:0?ooob80000000<082<W0000000000003`000000100N82@0@TM?
02hb=`0:2``;0000000800D51P0Q8bL0;c8h01@E601KHfd0^/WM08J@W`0R92P90000000<00X;3000
00003a0B02DX;00j?T@0EEaU03/oA@0=3Q00000001lR9@1;DET0:bhb3000000020020P801PH700H7
1`061`L00P<301dP8P16Be808R@X1`00000010010@404Q<D01/M7`17CE8206ifO`0304Y?E@0:2``0
00000080000000@0SiZT09:MZ035dn80enSg0P3HjOL00`39fNH0TIbV09fZ]@020:bia@0A09bY/`1m
QHd0cmk[0=WYm`3Bh^l0]/C@0;2nb@2Z]l40]lC@0=?Sk`3Hj?D0fNWf0=;RkP27TIX0_<[F0=KVl`3H
j?D00P3IjOD00`30c]P0[[[40<cJi@040=[Xm@060<SFhP3JjOD0f^We0;S4cP3Hio<0eNC_1@3JjO@5
0=_Ym0<0f^Wc0P3Kj_<20=_Yl`80fn[c203Lj_<00`3KjO80g>[c0=c[l`030=g[l`80gN[b0`3Mjo<0
2P3Mj_80XZ^a06=ZK02h`lT0_/[?06mfN@22Rhl0UZ2T0<KCf024S90200D51KL00000303oool000X0
oooo0P000000101?EF40ADYD02DY;@061PL20000000300410P030`<01@D501L0000000@0<3@k0000
00000000414C7@000000200>3a40G6=^08B>W@0o@dX0Be5J09ZV^02OZkd0?d=;2@0000001`0J71l0
00000000000000000@4100<30`020P80500000000`092P/000000000000400000003038f>P0`<cP0
20P90080000000@010@5051EG@1dO8H0:Rda1P0000000`0?4140Qi:L0=SXn0020=SXn0050=SXm`3H
jOL0^<KC08ZDWP2Y]/400P3Cho402@38en@0b]WV0=OWm@3IjOL0a]GQ08JAVP2c`</0`<kJ0<[Ii@03
0=WYmP040=GUl@2P[;D0//3:0=OXm0<0fNWe00<0cmo[0=GSl03GiO80103Jj?D01038e^80f^We0=[Y
m@38e^830=[Ym@80f^Wd00<0fnWd0=[Ym03KjO@0103KjO@20=[Yl`030=_Yl`3Kj_@0fnWd0080fnWd
00<0fn[d0=SWk`3Kj_<00P3Lj_@30=cZl`050=_YlP3Ljo<0g>_c0=c[l`3Lj_<00P3Mjo<00`3Ljo<0
fn[a0=cZlP030=g[l`0:0=gZlP3Fi>X0bMKL0<[Gg@2ia<X0];k40<gJh02W/[L0WjV]075iO0801@D5
]`00000<0?ooo`002P3oool20000000;0:6^a@2CX;D0KgV802DX;@020P80414D03a0B@1MIG<0AT]F
01TK7`041@D05@000000100I6ah000000000000S9R/M0000000800l@4@1PIg80RYFT05AKI@1[M800
RIBS08>=W00c=c`90000000301HH6P000000000001@0000000D02PX;018D5@0720P0000003Lk@006
0000000308J?W020RID051HG0080000000@01@H606UaNP2HXk40>3]01P000000101mQi00//3=0=SX
n03Hj?P20=SYn0040=OXm`37e^D0]L;@0<OFi0D0fNWg00@0/;g909>PZP27TY/0[kc8103IjOH01@3I
j_H0fNWf0=OWl`3AhNd0f>We00<0fN[f00P0`]3L0=[XmP3Jj?D0f^Se0=[Ym@2ha<l0ZKG00<[Hh`80
f^We00@0eN?_0=[Ym@3JjOD0f^We1@3JjO@40=_Ym080f^Wd00P0fnWd0=_Zm03KjO<0f^Wc0=_Yl`3K
j_<0c=[S0=[YlP80fn[c0`3Lj_<00`3Lj_@0g>_c0=c[l`030=c[l`80gN_c00l0f^W`0=WWk`3Jj?00
f>K]0=_Yl@3Mjo80g>[a0=KSjP33d=H0^lO=0=[WkP3Kj>l0b]SN05aQI00L7Ql00P010@6g000000`0
oooo000:0?ooo`80000000/0VJJl0::`b02NZl80A4YD00P92P0g?4@0S9N/0:nmeP2FXKP0EEeX01HI
700H0000000301lQ9@000000000000X0000000@010D501lR9@0e>D006Q`O1P0000000`0a=C/02PX<
00X:30040000000800H61`0V:Bh0=ca104aAF`2Q[L00Tij`04I;E00A4Q@90000000300H61`000000
000001@0000000<0@4A;07R0S00`<cP02@000000201GGFD03Pl@0000000000000P8202T/;`0k@4D0
5ALI1P0000000`33d^40f>Sh0=SXn0030=SYn0040<7@g`3:fNT0d=o_0=KVmPD0fNWg00@0RYFO0::`
^P2ha]80c=cY1@3IjOH00`3Fio<0c=cX0=WZmP020=WZmP030=3Pk02[^L<0^/OB00@0f^Se00<0ZKG0
0=7Qk03Dh^h00P3JjOD00`33dM`0f^We0=[Ym@020=[Ym@80f^[e00<0f^We0=_Ym@3KjO@00`3KjO@2
0=[Ym0040=[Zm03KjO@0fnWd0=[Xl`@0fn[d00<0fnWc0=_YlP3Ljo@00P3Lj_@40=c[l`0B0=g[l`3L
jo<0g>_c0=g[l`3Ljo<0f>O^0=CRjP39e]d0e^C[0=cZl@3Iinh0e^C[0<7>e02c_lD0f>K]0=7Ni@3>
fn40CU=E^P00000<0?ooo`002P3oool20000000;05IMJP1eOY00MGn@038f?@0>4180HVYh0;W7hP2m
c>L0^l[U09RS^@11ATl0600000000`0;30h000000000000:0000000400/<3@1AF680RIFV04A9DPL0
00000P0E5aX70000000403a0A`2P[;l0RYBU02HY;AP0000000<0<CDj0000000000001P0000000`1L
HV/0[;W904M=E0080000000502P[;`1SJW@0>Ce3018C50030`<02P0000000`33d^40f>Wh0=SYn003
0=SYn00309>NZP2W/l00d=o^00@0f>Wg00D0^/SE09BPZ`2>VZ@0Y[>n0<oOk0020=SYm`<0fNWf00T0
dN7^0=?Sl03Ei_80f>Wf0=WYmP3Ij_H0`]7L0:Rd_`3;fND00P3Jj?D00`33dMd0T9ZT0;S4d0030=WY
m@030=[Ym@31c]X0f^We0080f^We1P3JjO@20=_Ym0@0f^Wd103KjO@01`3Kj_@0fn[c0=_Zl`3Jj?80
enG_0=[YlP3Ljo@0103Ljo<00`3Lj_<0g>_c0=SVk`020=g/m00>0=g[l`3Mk?<0gNcc0=g/l`3Lk?<0
e>;Y0;2l`@2f`LL0]l?90=_Xl03Mjo80]L3605YOHP0L7Qnj000000`0oooo000:0?ooo`80000000/0
30d>024T:@0X:c404Q@G00T:2`0n@T/0OHNJ09BP]P2T//T0XJk505AJI`0U0000000400d>3`1KHfh0
VjRk04aBG0D0000000@00P<300410@0I6ah06A/N0P0000002@0Q8bL0ATaD02X^<P0310@0000003/o
AP2MZ[`0R9:R02DX;0070000000301dO8`0F61/010@50080000000@0414C02P[;`0J7Al00`<34@00
00000`0V:2`0ATaC01dP8P080000000805QOIP39f^/0U9n/05YQJ@0E5QP0;C4e03Lk@00@4A<60000
000:01PI6`1=DeX0e^Kf0=OXn03HjOP0`]7O09jZ]P1lQXl0PHbE0=3Pk`@0f>Wg00D0Wjbg0;S7dP2Y
]/40dn?`0=KWm0030=SYm`030=WYm`3IjOH0_/gI00@0fN[f00<0ZkS20::^^03=fnP00P3Jj?H01@3J
jOH0[[[509VU[P2nc=P0fNWe00<0f^We00@0dn?^0=[Ym@3JjOD0f^We0`3Jj_D00`3JjOD0fnWe0=[Y
m0060=[Ym0<0fnWd0P3Kj_@00`3KjO<0fNSa0=SVl0020=[XlPD0g>_d00@0g>_c0=_ZlP3Jj_80g>_c
0P3Mjo<02`3Mk?<0fn[b0=c/l`3Lk?<0f^S`0<kKhP37eM/0a=3H0=?Pi`3GiN`0QXnC0;`00000303o
ool000X0oooo1P0000001`030`<04a@G02<V:`11Ae00LWb<086;WP11ATl09@00000010061PL0:Bdb
04I<E@0S9BX50000000?04Y@F@0J71l06A/N01TK7P0000002``=04Y@F02NZkd0GfMb00P82@000000
7b4U059IH`17CED04aDG00L0000000<0LW^705QOJ00?41800P000000100e>Cl0PhfK05MNJ0092P/7
0000000500X;300R92P0:Rdb02X]<P0Q92L00P0X:bl00`0T9RX01`P8000000020000000300820`00
0000000000H0000000P0;c<g07j8T`2FXZl0MGj8028T9`1eOHL0SYRT02X]<0H0000000X0<3@h09fY
]P3Cho@0enSg0=SYn02Y]l<0MX2809FQ[03<fnX0e^Oe103HjOL0102mc=T0Wjbg0;c:e`3HjOL20=WY
m`@0fN[g00<0^LOC0=SZm`3Ij_H00P3Ij_H01028Ti`0`<kJ0=7Ok03Ij?H20=[XmP030<[Hi@2f`ll0
aMCP00H0fNWe103JjOD0103Jj_D0f^We0=_Ym@3KjOD20=[Ym0@0f^[d00<0fn[d0=[Zm03Kj_@00`3K
j_@00`3Lj_@0fn[d0=cZm0020=cZm080g>_d0P3Ljo<04@3Lj_<0f>O_0=?Qj@3Ljo<0g>[b0=c[l`3M
k?@0fNO^0=_ZlP3Hinh0enG]0=KUk03JjO00f^S`0;[6c01MHfH08B<U0;`00000303oool000X0oooo
2@000000100A4aD0;C4h03PmA@0L7R<^0000000409:M[`0c=cd04Q<E018C5@80000000T0?458082;
VP1=E5d01PL8000000030`<01`P900H720020P8020000000201_N8@04a@F000000000000>cm5092L
[01PJ7<02P/<1`0000001@0U:2`0Mh2=09FQ/@2GXk<0KWN20080OHJC00<0KGJ101HH6P0000000P00
00000`0=3Pl00000000000070000000700h?4@0b=SX0;2lc01<E5P1HGfL0K7Am020R9@0600000008
01TK7@1BFEl0eNKg0<CCh@1SJg<0TYjZ082:U@32dMl20=SYn0070=SYm`3EiO<0eNGc0<3>g035e>40
d>7^0=7Qk`020=SYm`@0fN[g00<0f>[g0<cLj@3HjOH00`3Hj_H00`2/^/D0]/C@0=7Ok@020=WXmP80
f^Sf00H0fNWf0=GUl@3IjOH0fNWf0=[YmP3IjOD20=[Ym@030=WYm@3JjOD0f^We00L0f^We00<0f^[d
0=[Ym03Jj_@00P3KjO@01P3Jj_@0fn[d0=_Zm03KjoD0g>[e0=c[m@@0fn[d1@3Ljo@03`3Kjo<0enK^
0=cZl`3Ehn/0g>_b0=c/l`3Kjo80g>_c0=SVkP3Ljo<0g>_b0=SWkP2/^;d0LgYo00T92P2m000000`0
oooo000:0?oooc/0000000<0F5mZ01lQ9@0000000P0000001@0E5aT0CEAL05YRK00X;3400P8200d0
000000P0;C4f00P82@000000000001LI6`0i?D<09RT]00@41@L0000000D0:2/_07n8UP2OZk`0ZkS:
0:Bb`P0208nJZ@0306eeP00E5aT000000080000000<0418C0000000000002P00000010020P803a0B
018D5@051PH60000000800420P051@H0e>Ge0:^iaP0T9b/0Jg=l0=7Rl@3Cho830=SYn080bm_Y00<0
//3=0<OGi@3HjOL00`3HjOL01@2gaM40Z;K00;_:e`3<g>T0e^Se00D0f>[f00<0e^Kc0=;QkP3Gi_@0
103JjOH50=WYmP@0fNWe0P3Jj_D70=[Ym@<0f^[e0`3Jj_@00`3Kj_D0fn_e0=_[m0050=_Zm00D0=cZ
m03Ljo@0g>_d0=c[m03Lk?D0gNce0=g]m@3Mk?@0g>_d0=WXl03?g^H0fn[b0=g/m03Lk?<0fn[b0=OU
k@3KjO40fNS_0;2l`P1RJFbn000000`0oooo000:0?oooc`0000000/01PH7000000000000000002``
=P28Tj@0PhfM02LZ;`0000005QPJ00410@0I0000000600410@000000:Bda03@h?P1_N8@0^l[M0P1`
N8@00`0i?D<020P90000000>0000000400h?401IH6P0MWn902ha=PP0000000D010@502@W:P2faM<0
Xk2l0<?Ch@040=SYn0050:^ha02`_l/0/;o;0<cMj`3Gj?H0103HjOL01@2^_<P0c]o/0;g=f@3>gn`0
enWf00@0f>[g00<0fN[g0<OFh`3Ij?H00`3Ij?H00`3IjOH0f^Wf0=WYmP040=WYmP060=WYm@3Ij_H0
f^[f0=WYm@3Ij_D0f^[e1`3JjOD00`3JjO@0f^[d0=[Zm0020=[Zm0030=[Zm@3Kj_@0fn[d0080fn[d
00<0f^[d0=_Zm03Kj_@0103Kjo@30=c[m0050=c]m@3Lk?@0g>_c0=c[l`3Kj_800P3Ljo<01`3Lk?<0
g>_c0=GTk030cM<0_<S>0:2[/01LHVD0_P00000<0?ooo`002P3oooll0000000;00H61`0000000000
0000000/<3H0R9>T08>=W@0W:Rl0000001HH6P010@406@0000001P010@40000002T]<@0d>3h0KgR4
0;_:g@80L7R400<0>Ce300P82@0000003P000000100>3a00FF1X07IoR@0^<CH80000000500@41@0T
9bX0]/GC0:>`_033dn40103HjOP01@2[^<@0/;o;0;2ob`3<gN/0enSf00@0f>Wg00D0[[c80<kOk02m
cMT0c]o/0=OYmP040=SZm`030=WZm`37e^<0fNSf00<0fNSf00<0fNWf0=[YmP3IjOH0103IjOH01P3I
jOD0fN[f0=[ZmP3IjOD0fN[e0=[Zm@L0f^We00<0f^Wd0=[Zm03Jj_@00P3Jj_@00`3Jj_D0fn[d0=_Z
m0020=_Zm0030=[Zm03Kj_@0fn[d00@0fn_d0`3Ljo@01@3LkOD0g>cd0=c[l`3Ljo<0fn[b0080g>_c
00L0g>cc0=c[l`3Ei>`0`<gC0;c8cP2PZk00G69U0;h00000303oool000X0oooo?@00000201<D5P05
03PmA01GGVT0LGZ805aSKP0K7B400P0000000`020P8000000000000G0000000600<30`0000000000
0000000R9BP0CUEM0P0W:Rh00`0M82<00000000000040000000500420P0N82<0:B``00d>3`0?4140
1@000000100O8B@0ZKK60<WHjP1SJg<80000000500h?401fOhP0amOU0;;0c@3HjOT0103HjOP0102H
YK00`m;P0<?Bh03DiO<20=SYn0<0f>Wg00<0^<OC0=SZm`3Hj_L01`3Hj_L01035dn00fNSf0=WXmP3I
j?H70=WYmP060=WZmP3IjOH0fNWf0=WYm@3Ij_D0f^[e1P3JjOD30=[Zm@80f^[d00<0f^[e0=_Zm@3K
j_D00`3Jj_@20=[[m0040=_[m03Kj_@0fn[d0=_Zm080fn_d0`3Ljo@00`3Lk?@0g>_d0=c[l`020=c[
l`060=c[m03Ljo<0gN_d0=_ZlP33dMP0HfY]0P0R9BH00`0D5QH000000000002l000000`0oooo000:
0?ooobX0000000<082<W01`N8P092@X04000000202X^<`0507n9V026TJ80@4A<01LI70071`P00P00
00000`030`<000000000000:0000000402P[;`1KHV`0=ca200<310T0000000<00P82000000000000
300000003P051@H0H6Qa08>=VP0Z;C40=c]00000000:2``04Q@E00L8200000004Q@E07N0R`2KZ;H0
@TM=2@0000000`2/^LH0f>Wi0=SYn@020=SYn@030=SYn039fNP0f>Wh00<0f>Wh1P3Hj_P00`2ham<0
enWg0=OZm`060=SZm`030=SYm`3BhNl0fNWg0080fNWg0`3JjOL30=WYmP040=SXm@3IjOH0fNWf0=WY
mP80fN[f00<0fN[e0=[Ym@3JjOD01P3JjOD30=[Zm@80f^We00@0f^Wd0=WZm03Ij_@0f^[d0P3Jjo@2
0=_[m0030=_[m@3Kjo@0f^_c0080fn_d0P3Ljo@20=c/m0H0g>_d00<0c=[R03/o@@0E5aL0`@00000<
0?ooo`002P3ooolZ0000000306UbO`1JHVh071lR010000000P0R9BT00`1WKg`0Ig1l020S9`040000
000300410@000000000000X0000000@0D5MO0;G5f01_N8@01PH76000000010051@D0G6=/07f7T`0X
:bl2000000080497C@1oRI@0EEaT02DX:`041PH03@h?01<D5`071`P9000000030=?Tm03HjOT0f>Wi
00<0f>Wi00<0cMg[0=SXn03Hj_P0203Hj_P01036e^<0en[g0=OZm`3Gj_L40=SZm`050=SYm`3Ij?L0
fNSg0=WXm`3IjOL01@3IjOH20=[YmP030=OWm03Ij_H0fN[f00<0fN[f103Jj_H50=[Ym@<0f^[e103J
jOD00`3Jj_@0fN[d0=[[m0020=[Zm0030=_Zm@3Kjo@0fn_e00@0fn_d1`3Ljo@0103Lj_<0bmSP096K
X0020`?2000000`0oooo000:0?ooobX0000000<0SYZ/07^5U@0V:Bh04000000200/<3@04024S:00b
=C`05aPK00820Q00000000@0;C4f06I_NP0oA4X00`@46000000010010@4061XL024S9P0:2``20000
000505iVK`2d`m<0XJjm06Q`NP0:2``0300000060=SYn@030=KVmP3GioL0enSh0080f>Wh1@3Hj_P0
0`3Gj_P0d^Cb0=SZm`050=SZm`80f>Wg0P3Ij?L50=WYm`040=WZm`3IjOH0f^Wf0=[YmP80fNWf103I
j_H20=[ZmP030=WZmP3Jj_H0f^[e00@0f^We0`3Jj_D30=[Ym@80f^[e00D0fN[d0=[[m03Jjo@0f^[e
0=_Zm@020=_Zm080fn_e0P3Kjo@00`3LjoD0g>_d0=c[m0030=c[m0040=_YlP32cmL0BTmB01PJ6l<0
0000303oool000X0oooo:P0000000`16C5D0?45901<D5`0C0000000306aePP16C5D02@X;01000000
00<01PL800l@4@092PX05`00000010020P8092HZ03Lk@@0E5aT40000000502LZ;@1QJG80PhfJ05YQ
JP092PX0300000000`3DiOD0f>Wi0=SYn@030=SYn@030=OXn03Fi_L0eNKf0080e^Og00<0f>Wh0=SZ
n03Hj_P00P3Hj_P20=OZn0H0f>[g00<0f>Wg0=WYm`3HjOL01@3IjOL0103Ij_L0fN_g0=WYm`3IjOL4
0=[Ym`H0fN[f103Jj_H50=[Zm@80f^We00P0f^[e0=WZm@3Ij_@0fN[d0=W[m03Jjo@0f^[e0=[Zm0P0
fn_d0`3Ljo@0103JjO80XJbc038e=`0:2P_4000000`0oooo000:0?oood40000000<0KgV600l@4P00
00007@0000000`0_<cP00000000000090000000400D61P1QJG<0UZ:b03XoA080000000L03Pl@0000
000000002P/<01hP8`0F61X00P8200H0000000P04Q<E02lb=`0G6A/01`P801hQ8`11AT/030h>0=OY
n@D0f>Wi00@0enSg0=CUmP3Ei_H0eNKf0`3Hj_P20=OYn0<0en[h0`3Gj_L0103GjOL0f>Wg0=SXm`3H
j?L30=WYm`050=SYm`3IjOL0fNWg0=SZm`3HjoL00`3Ij_L80=WZmP80f^[f0P3Hj?@00`3IjOD0f^We
0=[Ym@030=[Zm@050=[Ym@3Jj_D0f^[e0=WZm@3Ij_@00P3Ijo@00`3Jjo@0fn[e0=_Zm@060=_[m@80
fn_d0P3Ljo@00`3ChNX0XZfd03m3A@36000000`0oooo000:0?oood40000000<0>3e300L82@000000
:@00000010041@D0DUUR07n9U`0a=CX20000000301TK7@000000000000@0000000@05aTK04E;D@0`
<cP00@410P000000200k?d@0VJFb04aBF@0L7b40MGn80:bja`0W:bh0enWi0P3Gj?T20=OXn0030=SY
n@3GjOT0e^Sh0080enWh0P3Gj_T00`3Gj_P0enWh0=OYn0040=OZn080en[g00<0f>Wg0=SXm`3Hj?L0
0`3HjOL30=WYm`050=SXmP3Fj?@0enWe0=SZmP3Ij_H00`3Hj_D01P3GjO@0e>Ga0=CUl034e=h0ZkW1
0<OFh@80fN[f00<0QY2H05=JG`1VKW@00P2LYk400`34d]d0bm[T0=WYm0040=[Zm@<0f^_e00<0f^[e
0=_Zm@3Kj_D01P3KjoD20=_[m0050=WYlP30cMD0P8V?02/^;`0?4140aP00000<0?ooo`002P3ooom3
0000000303m4B`0K7B00000000X0000000<01PL80000000000006P00000010010@405QPJ02<U:@0=
3Q020000000300/;30000000000000@0000000@0=SXo0:6__@1_N8800`<30P000000300e>Cd0RYBP
04E:D00N82<0NXB>06]dO@0R9BP0f>[j0=OXn@3GioT0enOh0=OXn@D0f>[i00<0en[i0=OZn03Gj_P0
1`3Gj_P30=SZn0D0f>[g00D0fNWg0=WZm`3Hj_H0e^Oc0<?Dg`030:Zh`@0809j[/`1dOH<0F5mS03m4
B00m@TD09bX/024S9@1dOH<208nJXP0303a1A00000000000008010@40P071`L00`2ha/l0f^[e0=[Z
m@020=[Zm@@0f^_e0`3Kj_D40=_[m@060=_[m03Kj_@0f^[c0<;@f00X;2d00`<4b000000<0?ooo`00
2P3ooom4000000030415C@000000000000T0000000<03PlA0000000000009`000000100Q92L0I6af
04A:D0020P820000000800/;300L7R403Pl@00T92P0S9RT07b8T00H61`0<3@h30=OXn@030=OYn@3G
j_T0en[i00<0en[i00<0f>[i0=OZn@3Gj_T01@3Gj_P70=S[n0080=S[m`3Gj_L0en[g0=SYm`3DiO80
_loK0;K4c`1DG60300L7200300H61P010@40000000<0000000D01@H601<E5P0H6A/061TK00X;2`06
0000000409NRZ`3IjO@0f^[e0=[Zm@H0f^_e0P3KjoD20=[[m@070=_[m@3Kjo@0a]?M08VCV@1nR8d0
DeUM00X;2`39000000`0oooo000:0?oood@0000000<0=ca2000000000000<00000001P0D5QP00000
000000020P801@H600@410H0000000<00`<300T92P051PH00P000000103GjOX0enWi0=OZn@3GjOT3
0=OXn@80en[i00<0f>[i0=OZn@3Gj_P0103Gj_P0103FjOL0e>Kd0=;Tl@3Dio@20=S[n080f>[h00P0
d^?`08nLY02@WJD0_/kJ0:fla@0d>3X05QPI00P82A@0000000L0A4U=09ZV[P2R[kL0XZng0:>_]`2j
b=40f>Wc0080f^_e00P0f^[e0=[Zm03IjO<0f>Sb0=OWl@35dm`0ZkNo05IMHLd00000303oool000X0
ooooA00000000`0B51H000000000000l0000000302DX;01_N840AD]A008000000P3Hj_X00`3Gj_T0
enWi0=OXn@020=OXn@80f>Wi1@3Hj_T04@3Gj_P0e^Wg0=CWm@3Di_@0e^Wf0=OYm`3Di_@0d^Ca0<CD
g`2T/K/0J71g00@41@0?4140U:6Y0:fma`0_<SD01PH701D0000000<02@T:01HH6@0H6A/00P0H6A/0
3015BTd0Y[>l0;k=eP2nc]H0_lkF0;G4c022S940IFa`061WK00j?T002P/;00@41Ld00000303oool0
00X0ooooP@0000001@0G6A/08B@W03e2B02P[K/0I6ae00800000103Gj_X30=OYn@L0f>[i0P3HjoT0
203Hj_P0dnCb0;_;e`2Q[kT0GfM^04M=D@0c=cX020P90P0000001@030`<0=CTl05mWK@1lQXd0C5=G
01X0000000<02P/<02HY:`0`<cH00P0`<cH00`0Z;S003Pl@0000003A000000`0oooo000:0?ooofT0
000000<00P8200<310010P805@0000001@1KHVX0PXbH03Hj?`0m@TL09RT]0080000000<092LZ0=OY
nP3GjOX00P3Hj_X0403Gj_X0en[i0=SZn@3Hj_T0e^Sg0=GWm@3DioH0f>_i0=?Tl`34eN80Si^V06=/
LP1GGf@08RHX00X;30020P870000000302P[;P2GY:d0JW=i0?<00000303oool000X0ooooJ0000000
10010P80<cLl065YL`0^<SLE00000003079kQ@1oRI@092LZ00@0000000H0D5MN0=KWn@3?h?00U:6/
0;k?g03Ej?L30=KYn0070<OIiP2[^/L0SYZT08ZFW`1=E5T07B0R00/<3@0<0000000300d>3`0b=cX0
8bHX0?<00000303oool000X0ooooJ0000000100d>3h0SIVX0<7@i@1KHV`E00000003061WL00N8B<0
2@T:00@0000000L092LZ08VDX01SK7@061XL09:NZ@1/Mgd0M7j60080XJnj00<0@4E:03Tn@P000000
1P0000000`0=3Pl0;c@g024T9P3m000000`0oooo000:0?ooofP0000000@0KGJ20;S7g02AWJd0=ca2
5@0000000`0h?D8000000000000800000003014B4`0720P0000000X0000000D05QPJ04eDF02R/;X0
MX6800<4103l000000`0oooo000:0?oood40000000H03@l@01dP8`0O8RH07b8V014C5@010@8Q0000
000403i3BP1[Lh00>Ce300X;32d0000000D0De]P0:Zha02mc]X0TYnX00d>3P3l000000`0oooo000:
0?ooobh0000000<05ALJ000000000000400000001`0f?480MH2>07f8U`23SYh0H6Qe02/^=00;3@h0
800000000`0310@01PH700820P0^0000000504aCF02EXj`0UjJ_06QaN00;30d0o000000<0?ooo`00
2P3oool^0000000302/_=@00000000000100000000L0CeIP0:VicP2eaM/0^LWP09b[_P1[MH807b8V
0540000000D03Pl@01/M7`0K7Al04Q@E00820P3l000000`0oooo000:0?ooobh0000000<08B@X0000
00000000400000001`0V:Rh0DUUS05MOJP1bO8/0TYna07J0T00S9b/09@0000000`092PX000000000
003o000002/00000303oool000X0ooooA0000000100D5QT0=ca2034e?00?418]0000000801@F6005
1PH0000001`O8P19CeH0CeIM04]BF@0O8R@;0000000300/<3@0Y;3007R0S0?l000004000000<0?oo
o`002P3ooome0000000806YcOP0L7R40000004A;D@2``=40_m3R0;K6e`1:DEP;0000000502DY:`2C
X:`0NH>=02DX:`0E5aP0o`00000>000000`0oooo000:0?ooogD0000000P0PXnL02<V:@000000:bld
071jQ@1jQ900M7j902ld>0/0000000D07b4T079mQ@2da=80X:jj05UQI`3o000000h00000303oool0
00X0ooooMP000000200<3@h0000000<410092P/071lQ0417C@0/<3@00P8220000000200;30d0:2/^
028V:@0B51D0WZfh0:Nf``1GGfD00`<3o`00000=000000`0oooo000:0?ooodD0000000<01@H60000
00000000<P0000001@0c=c`0VJNf08REX`1EGFD06Q`O00L0000000@092P[08B@V`1XLGX020P90P0R
9BL00`0C5AH08bHX0000003o000000`00000303oool000X0ooooAP0000000`051@H000000000000B
0000000300T:2`000000000001`0000000D092L[075kQP2N[;/0[ko@03Pm@P0700000004020S9P1d
OhT0FfA[00L720<0000000<0;c@g000000000000o`00000;000000`0oooo000:0?ooodH0000000<0
2@X;0000000000004P0000000`0F61X000000000000L0000000500D61P0E5aT0ATeD05ALI00K7R00
1`00000010061`P061XL01<D5P010@7o000001400000303oool000X0ooooAP0000000`051PH00000
0000000B00000003010B5000000000000?l00000?@00000<0?ooo`002P3ooooo000009/00000303o
ool000X0ooooRP0000000`0N82<000000000003o000000h00000303oool000X0ooooRP0000000`1S
KGD000000000003o000000h00000303oool000X0ooooQ`00000010051PH000000000001CFf;o0000
01000000303oool000X0ooooO`0000000`0=3a0010@5000000050000000300T:2`00000000000?l0
00004@00000<0?ooo`002P3ooomo0000000306ihPP0Q92L0000000/0000000D04aDG04eEF`0k@DD0
>d5500420P3o000000T00000303oool000X0ooooM`0000000`0;30d00000000000050000000309BR
/00]<CD0000000/0000000D0:c0c0:Zkb@22SiT0PXnI00<3103o000000T00000303oool000X0oooo
M`0000000`0l@TP000000000000600000003010B50000000000000X0000000D04aDF04YBF00i?d<0
>Cm300410@3o000000T00000303oool000X0ooooM`0000000`1<De/000000000003o000002400000
303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooomD0000
0003010B5000000000000?l00000A000000<0?ooo`002P3ooomD00000003010B5000000000000?l0
0000A000000<0?ooo`002P3ooomD0000000303Dk@@00000000000?l00000A000000<0?ooo`002P3o
oooo000009/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?oo
o`002P3ooooo000009/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00
000<0?ooo`002P3ooooo000009/00000303oool000X0ooooW00000000`0H6Q`000000000003k0000
00`0oooo000:0?oooi`0000000<0AdiD000000000000n`00000<0?ooo`002P3ooooo000009/00000
303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo0000
09/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3o
oooo000009/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?oo
o`002P3ooooo000009/00000303oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{78.625, 308}, {377.25, 147.875}} -> {-153.971, 260.769, \
1.46487, 1.46487}},
  CellTags->"RenderCTData"]
}, Open  ]],

Cell["\<\
The main advantage of this method is that you only need 256 \
polygons for this image.\
\>", "Text",
  CellTags->"RenderCTData"],

Cell["You can still use new color functions like this one.", "Text",
  CellTags->"RenderCTData"],

Cell[BoxData[
    \(rgbband[
        v_?NumericQ] := \[IndentingNewLine]Module[{h, r, g, 
          b}, \[IndentingNewLine]h = 1.0 - v; \[IndentingNewLine]r = 
          Cos[Pi*\((h + 1. )\)] + 1/2; \[IndentingNewLine]g = 
          Sin[2. *Pi*h - Pi/2. ]/2 + 0.5; \[IndentingNewLine]b = 
          Cos[Pi*h]/2 + 0.5; \[IndentingNewLine]RGBColor[r, g, 
          b]\[IndentingNewLine]]\)], "Input",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MVListDensityPlot3D[
        Evaluate@\[IndentingNewLine]ToFileName[$MathGL3dDataDirectory, \
"\<foot.v3d\>"], 
        MVNewScene \[Rule] 
          True, \[IndentingNewLine]MVTextureSize \[Rule] {256, 256, 
            300}, \[IndentingNewLine]ColorFunction \[Rule] \(({rgbband[#], 
                GrayLevel[#^3]}\  &)\), \[IndentingNewLine]MVShadeVolume \
\[Rule] {0.6, 0.4, 
            0.2}, \[IndentingNewLine]ViewPoint \[Rule] {\(-2.57\), \
\(-0.967\), 0.701}, \[IndentingNewLine]ViewCenter \[Rule] {0.42, 0.5, 
            0.46}];\)\)], "Input",
  CellTags->"RenderCTData"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00238095 0.0238095 0.00238095 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
1200 string
400 400 8 [400 0 0 400 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF0000FF00
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000FF0000FF0000FF00000000000000
0000FF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF0000FF0000FF00000000000000000000000000000000000000
0000FF000000000000FF0000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
00FF0000FF0000FF00000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000000000000000FF0000FF0000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000000000000000FF0000000000FF00000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000FF0000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000000000000000FF0000000000FF00000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000000000FF0000000000000000000000FF00
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00000000000000000000000000000000000000FF0000FF0000FF0000000000FF0000FF00
00FF000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000FF0000FF0000000000FF0000FF0000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000FF0000FF0000000000FF0000FF0000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF0000FF
0000FF0000FF0000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF0000FF
0000FF0000FF0000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000020000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
030100020000020000000000000000000000000000000000000000010000010000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000040201
040100020000020000010000000000000000000000000000010000010000010000010000
010000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000030100
030100020100030000020000020000000000000000010000010000010000020000040200
030000020000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020100030100
020000030100020000020000020000000000010000010000010000010000030000050201
040100020000000000000000000000000000000000000000010000000000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000020100020000
030100030100030100030100030000030000020000010000010000020000030100050201
050100020000000000000000000000000000000000000000010000010000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010000020000
020000020100030100040100050200040100040000020000020000030000040100030100
030100020000000000000000000000000000000000000000010000010000010000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010000020000050100050200040000040000030100030100030100030100020000
020000000000000000000000000000000000000000000000010000010000010000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000020000020000040000040000050100020100030100030100020000020000
020000000000000000000000000000000000000000000000010000010000020000020000
020000010000000000000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010100020000030000030000050100050100040100030000030000020000020000
010000000000000000000000000000000000000000000000000000020000020000020000
020000020000000000010000010000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000020000020000030000050100050100060101050100050100040000030000020000
000000000000000000000000000000010000000000000000000000010000010000020000
030000020000000000010000010000020000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
030100020000020000050100050100040100060200060100060100050000050100030000
020000000000000000010000010000010000010000010000010000010000010000010000
010000020000000000000000000000010000010000010000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
020000030100040100050100050200040100070200060100060000050100050100050200
020000010000010000010000010000010000010000010000010000010000020000030000
020000020000010000000000010000010000010000030000030000020000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
0200000301000401000502000703000A0401080301070100050000040100060200030000
020000020000010000020000020000020000010000000000010000020000030000040000
040000040000030000020000010000010000030000040100040100040000020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000100000200000401000702000B04010B05010A0200070200060200050100050000
020000020000020000020000010000010000000000000000000000010000020000030100
040000050000040000020000010000010000040000050200040200040000020000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000200000401000803000A04010904010A0300070201060100060100050000
020000020000030100030000020000020000000000000000000000010000010000030100
010000040000020000020000020000030000030000050200050200040100030000020000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000030000030100060200080300090401090300070200070200050100050100
020000030000030000030000030000010000000000000000000000010000010000030100
030100040000020000020000020000030000040100040100040100040000030000030000
020000020000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
000000010000020000020000050100060200090300080200060200070100070100050100
020000040000030000030000030000010000000000010000010000020000020100030100
050100040100020000030000010000020000040100050100050100050000040000050000
040000030000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000020000030000050100070100080200080301080201090301090200
060100040000030000030000010000000000000000000000010000010000010000040100
050100040100030000020000010000020000050100050100060100050000050100060100
060100050000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000020000030000060100070200070200080201080301080200
070100050100040000030000000000010000010000020000010000010000010000030000
030000040100030000020000010000020000050000040000050000060100070100070200
060100040000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010000040000050000050100070100070200070100
060100050100040000040000030000020000020000020000010000010000020000030000
030000040200030000030000020000040000060000050000070100080200080200080100
040100030000020000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000010000010000020000030000050000040000050000070100060100
060100050000060000050000050000030000030000040000030000020000030000030000
0300000401000300000400000400000500000600000500000902000A02000A0200090200
050000040000020000000000000000000000000000010000010000010000000000000000
010000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
000000000000000000010000010000030000030000040000030000060000050000060100
060000060000060100050100050000040000030000030000040000020000020000030000
0300000601000500000500000600000400000700000701000902000B02000C0300090200
060000030000030000010000010000000000000000010000010000010000010000010000
010000010000010000010000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
000000000000000000010000010000030000030000030000020000040000050100060100
070100090100070100070100060000060100070000070000050000020000010000020000
0300000400000400000500000400000300000500000601000801000901000A0300090200
050000040000030000010000010000000000010000010000010000010000020000010000
010000010000010000020000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000000000000010000
000000000000000000010000010000030000030000030000030000030000030000060100
080100070000080100080100070000070200080200080100070100050100050000050000
030000020000020000030000060100070100060100070100070100090100080100080100
050000050000030000030000020000010000000000000000000000000000010000010000
010000010000010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000000010000000000
000000000000000000010000040200050200040100030000040000040000040000050100
0500000700000500000903000801000802000701000A0300070200040100040000040100
020000010000030000060000050000070100070100080100080100070100080100080100
060000060000030000040000040000030000010000000000000000000000010000010000
020000010000010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000000000000000000
000000000000010000050100070301060200040100030000030000040000060100060200
050100070000070100080200080100070200080100080100060100050100040100050100
020000010000020000040000050100070100070100060000060100070100060100070200
080100060000040000050000050000040000030000000000000000000000010000020000
030100030100010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000030100050200060301060200050100040100030000040000070100060200
050000050000070000070200080200070100070100080100060000060100070100030000
020000020000010000020000030000040000050000040000050100040100050100060100
060000060000060000050000050000050000020000010000010000020000010000030000
030000020000010000000000000000000000000000000000000000000000000000000000
010000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000020000000000000000000000000000
000000000000030100050200050200040100050100030100030100030100060000050000
050000050100080100070100080100080000070000060100080000080000080100050000
030000040100040100030000030000030000020000040000050100030100040100050000
060000040000050000060000050000030000020000020000030000020000020000040000
030000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000000000000000000000010000
010000040100040100040100040100030100040200040100050100050100040000040000
0300000501000701000B0200080200080000060000070100070000060000070000060000
050100070200050100040100030000030000030000050000050000060100050000060000
060000070100080100070100070000040100040100050100040000040000040000040000
030000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000000000000000010000010000
030000040100040100030000030000020000040100060100060100060200040000030100
0301000401000601010B0502090200070000040000030000050000030000060100070000
050100070200050100050000020000050100040000050000040000050100070100080100
0601000C04010C04010C0201090000060000060000070200040000040000040000030000
030000010000010000010000020000010000010000010000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010000010000
040000040100040100030000030000020000020000050100050200060300050100050101
0702010902011B161117110B130B071005030A02010801000600000C0603090301060100
080100070100060100030000040000060201050100060100050000060000070100060100
0D04010E05011006020C02010A0100060000060100070200060100050000040000030000
030000020000000000000000000000000000000000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000010000030100
0200000401000401000300000300000400000D08040A05020B05030A06030D07040E0906
100B071D25411B26301823211A1914140F0A0D0603090301171B180F0E070D08040A0301
09020006010004000004000018110D150C081208050D05030A03010702010602000D0602
0E06020F06011005010C0301080100070000070100090100070100050100050100030000
010000010000000000000000010000010000010000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010000000000
000000000000000000000000000000000000000000000000000000010000020000020000
0200000300000300000300000300000E150F0E110A0C0C070C0D080D0F090F120B10150F
051672061C6B092B540B303F142A29191F17151309110A0513120E0E0905150D081D0E0E
240D101C0B0B1208062022391D1E2C19192018141416110B0E09040E05020A0301130C05
120A031006020F04010B02000801000800000A02000B0200070200050200050100040100
010000010000010000020000010000010000010000010000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000020100020000020000
0200000100000100000100000B27270E262414231D16201715201813211912221C0F2624
071D42081F460A2752093163143259202E44272832221D2621141B1C0E121C121820132F
2417421F1D2B0A15860B19730B215B0A23460F232E161D19131008120A0415170F19180E
19120A160B061106020E04010A02010901000A0200090200080200080200080200040100
020000030100030100020000020000010000020000020000010000010000000000000000
000000000000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000010000030100020100020100
0301000402010603010804020E2B57122C56182C501D2C491C2B48182B47152A480F254A
0A24500B22500A1D5E061C880C1E91151F82171B651C1D591A19461618360C1332050E5A
0516840B2A5505176708184A081C5206225C0F29561C2A3F22292A20241E1D211B1C2221
1F201C1C1710170E081408030D04010F05020B03010803010A0200080200070200050200
030100050100030100020000020000010000010000000000010000000000000000000000
000000000000000000000000000000000000010000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000020000020000040200040100050100030201
0604020807030B0A060715860613920713930A14900C158C0C16870A1882091575071378
05127C050F7504097801039F0103B20205AC02098904107C04156B041858031556010E74
031087040D740612390B13210C16450B1B760E1F8A182379212769232B451B2A3111293C
172C371B2620181A10170F0824201D1F130D170E071008040C04020B0301090301090200
090300090300060200040100020000000000000000010000020000020000010000010000
000000000000000000000000010000000000010000000000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000010000000000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000030100030100030100040201050301
0908040A0E07050C55040D5E020B67020B6A020B69020C68030E64031061020B5D03095E
03085E03066502037F0101A50001B20011A1000D9A010F9302128E04168005127A050A8C
050BA8070A5A0E0A1A110E110C0E4206078A0102B30102B10204930B1F6E0F304A0E2A35
1429331A2C2F1F302E19336A272A4D2C2134271E231E1A13140F08130A051007030F0703
0F06020D04010A0401070300030000020000000000020000040000040000040000020000
010000000000000000010000010000000000010000020000010000010000000000000000
000000010000000000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000010000020000010000010000010000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000050201070301090402080502080703090904
0D0F090D160F0A1828091D37051D4805183C07132D080E25090F2402078A03097803077E
03058302038C02029C0101AD0A1BA6091BA70719AA0619AA081BA90A1D9E0C1D8D0C1890
242883191F5114172B0E1623051755020F920109AB0110930109900512720B2448112425
16232A1B28452031680916A3121D8B1720711F2C4E202E2D18211419160B231C101D1105
180D04150A030E0603090400050200020000030000030000040000050000040000030000
000000000000010000010000020000000000020000020000020000020000020000000000
000000000000000000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000020000030000020000010000020100020100010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000100000100000604010A07030C0A050C0C060C0E070D1009
0E18100B1E1A0B282D0B2B50062279091B490F18211517140C1D801520751D236A1C2271
1A227716217D0E1D851B27831A268C17279612289D112A9C122A9E142A95132F81243B76
253E711734600D2D51062E49042860031A82022A9A0122A30011AE02088F0B174F1B2A3C
191E320E105D0002B80106AC03158D082069132D521B36411F3A35242C20303329272112
22160B1C0F051008030A0502090401060200060100020000050000030000040000010000
000000000000010000010000010000020000030000030000030000030000030000020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000010000020000
020000000000000000000000010000020000030000020000010000020100020000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000000000000000000000000000
0000000000000000000100000100000603010805020C0A050F10080F130A0E150C0D160D
091526051830041C3F031D59020886060A530A152C05326E1034611D335B253252253553
2438551F3A5615375F143565132E7212298B102798102C92102D8F122D8516326A153659
15385817385C1136660B38620F3763132C6E202C77212B811D2A8D1925750F1B640F206C
091A57000CAD0004B70106A403157D082562132C571A315D1E3A711D35822A45512B3927
2B2514221508130A040E06020A04010E0601090200070100070000060000030000020000
000000000000000000000000010000010000020000040000030000030100030100020100
010000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000010000010000040100020000
020000010000000000010000000000020000020000020000020000020000020000020000
000000000000000000000000000000000000000000000000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000100000502010603010804010C09040E0E060E11080E130A070C56
060C62030C6D020C67050F44060F3B050F3D040E3C022E580B2B411126470F225C0F2A62
1031681036651038670A386D0B37640E306F102881112C7A122D74162E6C162E67172F63
172F6F1F317C1F30871E316321345D323C69343768333A692B426A203B6A12287B07207E
031E790013AC0006B600039C020C7C0418840C1C720D16790205A00B209D1B4567264333
2E2F1C281C0E2412091B0C0522160D170C041005020A0301090200080100030100020000
000000000000000000000000010000010000020000030000030000050100040100030100
020100020100010000010000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000020000010000010000010000040100030100
020100020000010000000000010000010000030000020000020000020000020000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000100000100000503010503010704010B07030E0B040F0E0611130906099C
0204AC0001B30102A0060A5009182B070F2A052A6806277410254316254B122774122C7F
12319015338D16348C15328F1C356E2538632D396A2F3A66303B62303A5B2F34552C334F
2833582D37702F3B7528326321296E18267D162878172E73163C6C193F741739870B318F
1A339112279F071CAA01129F01098E01028F01028B01038B0103A506149911366A20474B
3038333229283524292F323D2D281F1E180B140D040F05020B0300080100060100030000
000000000000000000020000020000020000020000040000040000040100050200040100
030100020100020100010000020000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000020000010000010000020100030200040200
030200030000010000020000010000010000020000020000020000030000030000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000000000000000000
0000000100000100000503010502000502000803010A06020D0903100D05202C53060A9B
0205AC0102B40101A9040772020F54042C5C072A5B09276B132A521C324B1C33531D2C66
1D248E1F268D1E2C8C1B328E1E2C8221297F242680242A7E262E7A232F6F212B651D2A5A
1B2E571E2F6021366624336C20317F0F2F8B0D2D8C102A8A112D881A358722388B31407A
2F437E233C900C329D02279E01169700059300028D0002AC0001B4020895081C6D143379
23345F232D50212F602239552C35312425161F180C160A040D0301090200050100030100
020000000000020000010000020000020100030100030100030000030000030100030100
030000010000010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010000010000010000020000020000020000020000030000
030000020000010000030000020000030000010000000000010000010000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000010000000000000000000000
0100000100000301000301000301000502000602000905020C08031E2E261B2D57050A9A
0205AA0102B30001B202039C01068C032A7A092C6D0B2D6815336018335D15295F17206E
1A1D871A1C88192587152E89142A861326841326831A2E80182F8015307C14277C101A7C
101C73141F6C17236E2631792734891D32931E2F95222B952529872B327E363E7F38426E
3243702543870C3F9501359D0123A8000AB50018A70011AB0008B60105950207750208A0
061E910B2975122A5D2230462531372A34342D292323150D100702080301070200030000
020000000000000000010000030000020100030100020100020100030000030000030000
040000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010000010000010000020000010000020000030000030000
020000020000030000030100040100040100030000000000000000020000020000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
0100000100000200000200000200000401000503000904010B07021C2D26192D54060F91
0309A50104B10000B70001B6001FA4052B9B0C33880F377A16386A172D7D121F96162193
131D9D14209A172695172D94172E94172D951830941F398E1E3D8E1E3C8E1D34941A2A92
192B821E2F772330772B32772C357C2D37832D38862E3A892A34842930832D36802E3F6E
3443642B466F1A478115408D0F329B0F3A9D002F9F0022A20010AC000594010371020D77
041B7F061F7B142469222A4F252F4E24376435374933251D190E06190C05110602090201
050100010000000000010000010000020000030100030100020100030000040000030000
040000030000010000010000010000000000000000000000000000010000010000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010000010000010000010000010000000000010000010000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010000010000010000010000010000020000040100030000
030000060000060100060100080300070300050100020000020000030000040000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000000000000000010000010000
02010002000002000002010002010002010005010007030013150C1B2821182B4A081581
05109A0107AD0000B7000B9E0019A3062F980E39820F377613327514298F18299B192E99
182F991E309525338E28378A26378D22389226398E2B3D8C2C40892C42892A428B244284
223E72253D6F243C69233D68203D6A1F3D721E3A821D3D8817388B1A338F173288233C6A
35455E34466F2D487D2A4A881C4593104A9500419C0030A00017A600078C01075E05144F
05185D0410730A128512156A101B730C26922A37753D353C4030393C22202C170F1A0A05
0A0401060100010000000000030000050100050100030100030000020000020000020000
020000010000000000000000000000010000000000000000000000000000010000020000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000000000000000000000000000010000010000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000010000020000020000020000030000040000
030000060000060100070200070300080300070200070200040000040000040000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
0100000200000100000201000201000201000301000D090311110819221A17283F091970
07158F020BA90000B60006A40016A2083395113D7C0D347F0F2D8611279418308E1D3986
1B379220388D263887273883253A89253D90243C8F263C8E273A8F29418C27478B224984
1B3D7C17367218366516376214356912356D15337515347E1C37871E36901B358B20306F
303B6A3D456E3E4C703753772D577C1B5184144491153798162C9B10217D091B5D09214F
05135903077600028E010386010A910417A01725933131712D2E7D3C32583E2E2E2B1B0F
180B040C0401050100040000040000060200050100060100050000030000020000000000
010000010000010000000000000000010000000000000000000000000000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000010000010000010000010000
010000000000000000000000000000010000010000010000010000000000000000000000
000000000000000000000000000000000000010000020000020000010000030000040000
0601000602000702000702000802000802000B05010B0401090300050100050000020000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000100000100000100000100000100000401010B06030F0F0716201816253B08196A
0B1670071272070C6C070E64031B780B30771637760D2F9E0F2B9D172A981B32851D3B79
1C37901F36861F337E1C31811F34881E38951C38951D33951B30961B36951C3C921B3E8F
1B3D8D18358919347B1F327E1E2C8B202F8D2032911E36912638892839872834851F2883
1F2286252A862C377F3145782B4B752B4C792B46812942872243871A36791026780D2A83
0111950109A00003AA0001AB0003B00105B5050BB0040EA00A199923307A3B3F4A363223
2C1E101B0E050E0401090200060200060200060100040000050000010000000000010000
010000020000000000020000010000020000010000000000000000000000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000020100020100
010000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000000000000000000000000000020000020000010000020000060201
0602000802000601000602000702000702000E09031108020B05010A0300070100040000
020000020000020000020000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000000000000000000000000000000000402010B07030E0D07171F171926390A1B69
101A550911490E19410E163C051E64102A6A1B30690F319816388F1B388D1E3B821F407F
1F408F24408C243C8B22378F25368F2835922734922332941F2E961E31951C33951E3592
2335912834882C3567373C613B40663542682F476D2A4B6E2E4B6A3149642C4272213984
1934881B3784253B82283980283A7D2E427E3248812D4F802052801D447E24477E153992
07269F041BA70210B40008B80005B90002BA00018C000590010B951C287D333E5C3C404B
413538382018321B111406020D0200070100050000040000020000010000000000000000
010000030000030000030000020100030100020000010000010000000000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000020100010000010000010000000000010000020100020100040100
030000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000150C09170D09
150B071208050E05030C04020A030116150F15140C15110A120C060E06020A0401070100
030100020100030100030100010000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000010000010000010000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000000000000000000000000000201000403010A07030E0C06191F161B27380C1E68
0406830A10550E1949101A4A061E7B0F247A1B2B6D1135931E417E23426E23436E23497C
2451882A4F852B46852C40822D3B802E387D2D38832A358D24328D1E348F19358F19368F
203790283887233270253262283861293E6322436721476723456224435D24436F244582
1B478A1B4482263C842E367F323778344478355078305B72295B77284C80304683264587
163F920C319D0420A80012B1000BB60004BA0001A00002A30105A612188E1F236F212378
332E71453538452D25261106150703080200030000030000030000020000000000010000
010000030000040100030100040100040100040100030000020000010000010000000000
000000000000000000000000000000010000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000040101040100030000030100010000000000000000010000010000030100
020000000000000000000000000000000000000000000000010000010000010000000000
0000000000000000000301000302010402010502010602010602010602011F172B1F172C
1D18251A161814110E120D0913243013222414201A131B12141109110A040D06020D0401
060200050200030100040100010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000010000010000010000010000
000000000000000000000000000000000000000000010000000000000000000000000000
0000000000000000000000000100000100000301010905020C0B06181E151C27390C1E69
02049A05087C070A6809116F0315900C208E182D7F1A3F92224A88244B80245075245877
2556822B527F30467B2C3E75293A6D25376A2334741F2E831A2F7F16318015328712348D
12349916328D17337216365F14386D1A387C1C3484203587203187202B892231872C3883
2D3E762A43732A40812E38753137653041763150742D56713256743E4A7A40467D384B76
264C821443930531A0001CAB0010B302099B0001A60001AC0001B50304AD05068D05078C
1C217F2C3380463F4A4130202D160D170703070200050000040000030000040000020000
020000040000030000030000030100030100030000030000020000010000020000010000
000000000000000000010000010000010000010000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000020100040201030100040100040201040100010000000000000000000000020000
000000000000010000000000000000000000000000000000000000000000000000010000
0000000000000402010503010604020706030808040A08040A070407166707166807156A
091E590D273A0E23210A23430D222F0C21290F262A132A2A1B201B201710331F1E24110C
1106020C0301070100040000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000201000704020C0B05191B141B26380106B2
0001B40001B20101B00307A6020DA6091C961C41811A499123518A245388235B79266173
27597C2B547831497D2F436C2C45632941552838512330541E2D591B2D70172F8C142F93
122E9C122F851C356F21366E1F327C2831853031892F348A2C338C2835892B3880343D7C
383C69323F6B253D821B3A7C1D33732135792340762A4D773A4D73444876484E783E4C75
344D7A234D861244950D339A142E9509179900058E00038400028002057F030483020391
030AAF1525982D3D7A3F4154412E2929150C1406030B0200070000070000030000020100
030100020000000000010000020000020000030000030000020000020000020000010000
010000010000000000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000020100050201040200050200070401050201030100020000010000010000020000
020000010000010000010000000000000000000000000000000000000000000000010000
000000000000110B07120E0912110A12140D12170F1118110B14380C14340C14340C1436
0D182E131C21161A1513161A13121211151C12213C162D6322295122206A2F2D57312C2D
1E160D1609040B0200020000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000603010C0A04191A13061D920107B1
0000B60000B70000B80104B00108AB0D3296164089194B8F205789215889245F79296273
295877335B6F315081334D6A334A64354444323D3434362D32353A2B395B273D7F213C88
1E3A951A37762239652739682C346734347D3A3982393E832D4188274387263E83263D7C
2940702A4072233A7C1D4178213F82243889253B812B4582394A7D3D4D7D40547D40527D
39507E2B55862052872554861F438E12289C000C9D00067B00027502046903057B0102AB
0101BB0416A70A2898203A8041414A3C2C1C2412081607020A0000060000040000040100
030200020000010000000000000000010000010000000000010000020000010000010000
030000020000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010000000000
010000030100060301060301060300080302070201030100030100020000020000030200
030000030000020000010000000000000000000000050101040101040201050201070201
07020123182A23192C211C30201F341F22381D243B16213A192038191F35191F351A2037
1B21361F2033241D2D241A272316221A12220E0F4F060CA10A1393050D85142678263F4F
25352621190F120603030000020000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010000010000
0000000000000000000000000000000000000100000702010A06030B2862071F8C0108AF
0001B60000B70000B90002B40003B1042AA20937970C409612518E185A8B23667A2C6771
326171335E6B325280334C6B2E425F303B412F3B2D2F3E282A3D3A2844502649661E4679
1A438F163D741534651830601C32662235782534822638831E3C881A3D8A1E3A8A213B7F
25457828458226348726357F31387D3A378036397A36437A344D723456743E5A7A3F557E
375084305A87285B86295B842950851E37970F239C07138502079301047900037C0000BC
0000BC010A9D021386162A7732475B41453A3F2E1F33170D1607020B0000060000060100
060200040100020000010000020000010000010000010000000000010000020000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000020000020000010000020000
020000030101060401060301070301080401070200050200060100030100040100040200
0803010703010601000301000300000100000A08040907040907030807030A09050B0B06
0E15680E146B0D136F0D12740C11780C127B0B137D0912710A126E0B126B0B126C0A126E
0B126E050867080C58090E53090E4C080D500409750104AB0208700310590C1D521A2F5C
264066392F3327130C0A0200080000020000030000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000020000020000
0200000200000200000100000200000200000200000601010905020B2A5A0722860109AC
0101B40001B70000B90000B80012A10023AB012CA10232A209469212578B1E667E316D71
32647533606F325380334C7D2F45782D44642E4D502B504D2445511F3B651E39781A3A84
183C8C153A8514387F1738731B366A1D32691F2E74232F77212E802332822A35832F3878
35436C3A477A3C3C763F3A674840644E4665454666384A6B2D4F672D586B3D587245527A
415375395C79345C7C30597F36517C3647852A408B172E8B071D900014850000BA0000BC
0000BD000495010A790E22781E3A6A31456242474B4831222812081204010A0000070100
080100080100040100020000020000020000010000020000030000040000020000030000
010000000000000000000000000000000000000000000000010000010000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000020000030100020000010000020000
0100000201000502010503010503010803010803000702000602010602000702000E0B05
0D08040A06020904010803010401010D170E10170F10170E11150D10140C1018100F1C14
03128E030F90030E92030C95030A97040B7C02085E01065A01056701057601057A00047B
00047B00018F00028001037F01037E01048802049B00009E03075F0B122A0C11290B1263
0D15A33E36614B2C241F0D06130601070100030000020000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000020000020000
010000010000010000020000010000020100020000050100111E250C2C4C09277B010DA7
0102B20001B60000B900099B0013A7001FAE012CA40134A40C43911451891D5F82346671
315F7A325E78325382324E7F2F487E31496E344C603147672A41652B3F792A3F8724428A
214288204089293D852A36772F36623538613637633937633A3C62393D653A3F62383D60
3A3B64393E79353E7A2E34762B336E343E67364568314C6A2C586C315D703E5873465576
47586E41567137587B32577F39557C40567B385481244C880E3F920A27A50411B10208B8
0001BC0001990104860513800B1F740F2A8636486854494745291C290E060D0201080000
050200050100030000030000040000010000030000040000040000040000030200030200
040100010100010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000020000020000020000020000000000000000
0100000200000301000402000803010904010803010903010B050109030019130C110C05
1310091B160F2419162214131F10111E1F2122293A242C4324293D2328391F2A3F030BA8
030AA7030AA80309A80308A80307A80211900207900101920101980001A00000A30000A3
0000B70000B60000B60000B60000B70000B70000B60000AB0304720E0C350D0A31050660
0203922A236944354A3D22252F100B0C0100080100040000030000010000000000000000
000000000000000000000000000000000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000020000030100030100020100120F0B0F1D1D0D2D3E0A2C6F0210A1
0203AF0101B50000B90009B60011B4001AB0012BA50135A40E4190184B89255A8531617A
305E7F325C7B3150812D4E7B2B4B762C476D30406C2A32702B387233427933487D2D477F
2A468230467E2F3E7D2C347A262A7427217527266F282B692A336029385C2B3B5B283A5E
2734732431891E32891A3287193484203F7A2B417F303D7F3351603B59673C5B763D5C6F
3853783F5072384E79304D813752803B59803A607E2D6183185792154B980B33A1061BAD
0105BA0001A400019201037E030C760B1967232E77423E6F5B403D492819280E07120301
050100030100020000030000020000020000030000030000040000030100050200050200
040100020100020100010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000020000030100020000000000000000010000
0100000301000302000603000803010C06010C06020E0803100A05261E4C1C182014110C
191615211C32281F55271B5024174819164711157610169010178A111881070DAB060DAC
050CAD040CAD030BAF0209AF0108B0062092041493020BA20105AE0000B60000B60000AE
0000B70000B60000B60000B60000B70000B70000B70000B200009A01027C02036601036D
0000841219621D2773382C5E4623261C0D051103020B0000030000020000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000010000020000020000080301100C080E19150F2B310D2E60041795
04099B0306980000B70006B3000CB00014AB0028A10133A5103D91254C84234F8B2F597F
2D588333557F304B8228487D27497B2942712C3B6E26377C28377C2D3B7D2C3B7D283E80
2D447B2B3D7B26367F1C2E831927871923851A2882182C8018336C21376224316F272D7A
273085242F8F2030921E319522319126347E323C7D3C45713F4D534457533A5E5F365C67
38547A40487B4043783E45723F4C793A5A7E37657A34657C33697E256189164D940A2FA2
020AB60001B20001A801029804085F050C5705098D231D944F426554433E442317250C04
0F0401040200020000030000040000030000040000030000050000020000030100040100
030100030100020000020000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000020000020000020000000000000000000000
0200000301000402010904010904020D08030F0B05120E0713140D030585090F340D1B1B
0A1625060D5602069602067B020878010C71010B92010EA401139C1A328E19338E17338F
1332920F30980A2B9E0624A30B369B09308B042486001895000CAA0000B600008A0000A7
0000B70000B70000B60000B60000B70000B70000B70000B70000B60000B6000090000181
000185050C5A061374242577473947362B19251309130401030100030000010000020000
000000010000000000000000000000000000000000000000010000000000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000100000200000502010D09050E150E132624132E4E071F82
0913750000B80000B80003B30006B0000DA900219C002EA6133995264D85224D8D2A5183
264F852E507E2C498424487F254685253F75263B79243F8D27408B293D8B293E8E28408E
2B438A293E8D2333911A2F98182B9C19289D1E2B98232D92253273343C5C3F3D66413F69
3E3E69393A6E30397B2B3C86273D882833812F327E333F6935425B374C58315B5D315C6F
38507E3E427C413D773D3D73374274325178315C77415E72445F753C647B295F8814419C
0417B0000AB70005BA0101A101037202094F050D5C121A71223381414F6C59413A432013
220C03090100040100020000040000040000040000030100020000020000010100010000
020000020000010000020000020000010000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000000000000000000000010000
0201000301010A07030A06020B0601140C0518130B181E150D16440818490A223A082B3F
072540051D48020969020B67010D6602117603168A041B8D052184183C77183E75184074
163F79103B870C3695123E8F0C3B930D3A8C07308C02239A0113AA0000B60000890000A5
0000B70000B70000B70000B60000B70000B70000B70000B70000B60000B60000A100008B
00017C01056302055D1018702E435F3B4D38362517230C05080100050100040000030000
000000000000000000000000000000000000000000000000000000010000010000000000
000000000000000000000000000000000000010000010000000000000000000000000000
0000000000000000000100000000000100000201000906030C0F08152019182C3D0B246E
0000BA0000BA0000BA0001B70001B60006AF001C99002AA5154991294C84224A8D29497F
22447C274877284885294F7B2A4A7F254073263F7825488C2C4B872B478829408C2C428A
2C4087243D8C1D3A8F1836951931981B32992435902E3B8B2F387530356735376D393D67
3840643542642F3E7128417F214581273F8527318A273181303B7931437632506B375574
38507E3A4B7E36457B3042782B49722A5177325278404E744F4F6B4F616940657726518D
0B2FA5021AAF010CB40102A50001920104660309500513690D297F2342844B4B61604033
421E111B0902090100030000030000030000040000050100030000010000010000010000
000000010000010000010000020000010000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000805020A08040B07030D070218100B1A1C1B13233113264A0B23640A247009257C
08237C071F780107AF020AAB030EA605179D0920940D268D16328118347D1A367A1D3878
1C3577152F81172E921B34881B388A193D8C103D9308369F0521A80001A50000890000A5
0000B70000B70000B70000B60000B70000B70000B70000B70000B70000B70000B70000B7
0000A400006E000067060D701734592E54483534242F190E170803100401060100040000
010000000000000000000000000000000000000000000000000000010000010000000000
000000000000000000000000000000010000010000010000000000000000000000000000
0000000000000000000000000000000100000100000704020B0A051619121B28350D2365
0000BA0000BA0000BA0001B70001B70007AF01219302409E154991294A8520478D254379
203D6B223C6B2443792A4E732F4F7428446E2940762648892B4D8729468A263C8D243890
24378D20388C1A388D1935921932991A329A2033922438902235861E328023357B263A77
243C76203E77243E7D273C8327437E2F467F2D3C8A2A3B8C2D3F8B31428534466B384F70
33567D2D57802A507E284D79255179274F7A304A7B3B4A7C49516C505A645164693C5E7C
184699082BA70215970102A50001A901019F010397010994011492082A9738537A594C56
5A3228341309150500070000030000030100030000040100030000030000000000000000
000000000000010000030000010000010000010000000000000000000000000000010000
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0402010806030B0A040D09040E0A041A171215203104194F04136A02048901029A0101AD
0001AB001DA60322A007249E0B249C132198171D951F1C8F1C198E1B158F1A168E1A1690
1C1A8622227E2B2B842B337B283B80244584184A870F4A94082E950003A30001890000A2
0000B30000B50000B70000B70000B70000B70000B70000B70000B70000B60000B70000B7
0000A700007600007C010778183566214F673A3D3C3D2E203225172610080E0201030100
010000000000000000000000000000000000000000000000010000000000000000000000
000000000000000000000000000000000000010000010000000000000000000000000000
0000000000000000000000000000000000000200000602010A060316150E1E23300105AE
0000BB0000BB0000BB0001B80001B70108AD0128A201409E1448912949851F458D264477
2440622037621F3B752547712F486826447129407723428C24488820418920378B202F94
1C2C971E34921D388E1E3792223493243391253490253391223691263A8E273E8C2A408B
293D8A2A3C89313A873A3A84383D7937427C2F487C2A46812A428A2840872940732A4373
244C7820527E235082254B832C4A8031497F33497C354D8037537640546F545C634C5E6E
335A861C45970E2699020C990003970003A20101B001029E0106871529952240873F4777
61464A552819290D040C0200060100020200030100040100040100030000020000010000
000000000000010000020000010000010000010000000000000000000000000000010000
020000020000010000010000010000020000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
010000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0503010A09040D100812140D1617121B222B070D6C02097003076A03075E020861010494
001DA4002896032A92082B910C2A9012248F141E8E121A8F10168F0F14900F14910F1693
111A9119288A23358624387F223D7E22437D1C4A81184E8A123986011496000C8D00038A
0000910000A20000B70000B70000B70000B70000B70000B70000B60000B80000B80000B8
0000AA00007E00007F0006790736830E408D353D6040453F3D4E403E251B1E0803030100
010000010000000000000000000000000000000000000000000000000000010000010000
000000010000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000040100070301160F0906119C0105B4
0000BA0000BA0000BA0001B90001B70109AE0B32990F429621448C2F448220408C274476
224060203A69203A812542792F43712A42802D417D223F861C45801B416C1C39711E3093
192D9C1E389520429125458C28418E2F43893045872E41872D41852E4082333D7F353D83
3737833838843D3D8142447C3D427834437A25497B23457E233B881F338C1E3983244183
214C842350862A498432448139457E3D4D7A3E5577365C7B2F587D3A4F7C514E695A585F
4C6970315C871B3C95071A9D0106960004960001A60002880002610411A5081E9E333C7C
56545F6145354921101E07020A0200050200050200060201050100050100020100020000
000000010000010000010000000000000000000000000000000000000000000000000000
010000020000020000020000020000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010000010000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000030100
0805020C0D060E160E111E1A10232A0102B20000B70000B70000B701039E020862010484
0424990527930727A50A28A30B28A20B26A20A25A108249E07259B05249905249A06249C
07249F0B279B132B9418338C1939891B3E861D3F842B437823407A053291011D8E000995
00008B0000B70000B70000B70000B70000B70000B70000B70000B80000B80000B80000B8
0000AD00008B00008E0219A5032B960528962934732E4A632E4E6D46363B30160F130403
090100000000000000000000000000000000000000000000000000000000010000010000
020000010000010000000000000000000000000000000000000000000000010000010000
020000010000000000000000000000000000000000030100070301150F080718930108B2
0000BB0000BB0000BB0001B90001B8011BAC133994194091243F8D2C408420408C274578
223E76213E7A223C8729457D30487B2C458A2C46852442861E467E1E4267223A6320338D
1B30981D3B9220438F24458B27428A2A45852A47802A477B2A46772A477028436C284073
253A75253B78293D7A2E427D3C4A7A344C7F1F4F83214B81243F87253786283A802F3B8A
3440883747853D4A793B4C743B50793D5678415B753B617835527E39437C4C45655B5152
58685D426979274F910C2AA9010EA900079500019700026E0104B80108B0020FA7212C8A
404A755F534F5F3A273E190E1B05010A0200060200060201060100040100030100040000
010000000000010000000000000000000000000000000000000000000000000000000000
010000010000020000010000010000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000020100010000000000000000000000010000010000000000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020000030100
0806020C0E070E19111024240104AC0002B20000B60000B70000B60001A900008101228E
09278F0B27960C28A2102B9F112D9D132C9A152D90172F86152A85142885182684192683
1A25911D269121298A242C88262C872730852839793642723048710F4B88052F8E0111A7
0000960000B60000B70000B70000B70000B70000B70000B80000B80000B80000B80000B8
0000B20000990000B60117A401278A0422741D27651B32721C3885423D5C3E37312C1914
1C0805010000000000000000000000000000000000000000000000000000000000020000
000000010000010000000000000000000000010000010000010000010000000000010000
010000000000000000000000000000000000000000040100070301092361071E8B010BAF
0000BB0000BB0000BB0001B9000B9F021FA8183C861E3D89213987263E791D3B8327427A
233E8E27428B27418D2A47812F497B29458B2C448523428520477F1D406F2138691F348E
1832991C39941D3D8E20408C204189264C802B51742B52652C505D294B532546511F4151
1D3F541F3E5C223A63253F73394A7736537C275C82275682274D812C4C7D324C7C364883
3848813E4C7E404C743947722F4878274E7C3655773E57743B4B7A3E497841476C4F4958
5B5F534F6A6A355C811542990428A403159A00048F0103B70102BC0104B70108B3132195
26397D3E4F6C5B50485D3622381509140501060200050200040200030100020100020000
010000010000010000000000000000010000010000010000000000000000000000000000
020000020000030000030000020000020000020000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000020100020000010000000000010000010000010000010000010000010100
010000000000010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000020000020000
0704020B0C060E18101225260105AB0103B00000B60000B70000B60000B10023A0012397
0A25990B259F0C26A4102C9F0E2E9F102F9A1232861235750F31790C2E7E0F2B80172B81
1C2C8D1F2D8B202F8722338C25358629397F2A3C7430476F344D6B2854761B3C7F0B1B9D
0000B70000B60000B60000B70000B70000B70000B70000B80000B80000B80000B80000B8
0000B70000B30000B70016A700248603207012196611217215297E2E3A6F31535E383A3A
331511010000000000000000000000000000000000000000000000000000000000000000
000000010000000000000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000040100151E2A0A264E0B2363041375
03077F0204970001B70105A5010E8702218D1638741B3A871C3D892040801D3D862B4378
29448B2D46882C41892B43812F497B2947852B438422438623467B203E74203B7A1F3A8F
173699193A991A3E8D1945861B4E8525577D315B72315868375360354B582D47572A4659
29435E2D4061303E57333F653D4B783D5D723367782D617F2C5C7A2E5A752D54792A4D82
294B822B4A822F448233447A2F427C283F763443733E4F6D4052723F55793B4E75474D64
59585E5A676246657326588A0C439D0528A2010BA00105BB0100BE0101BF0101BF0319A3
082F9018427E424F5E63513F512F1A260C040C0200030100030100020100030100040100
010000010000000000010000010000020000010000010000000000000000000000000000
010000040000040000050000040000030000010000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010000020000020000010000000000010000010000000000010000010000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000030100020100030000
0703010B0A060E170F0826800209A40208940307890104970001A90115AF0326A80323A8
0C25A30B25A20B25A310299D0F29A00E299D0F2D8E0C2C7F092A7A082B7B09297B0C2482
0B1E940A2498092A99082E9E0B3497113B8B1D3C81264077314973334E78323D77030DAF
0004B50001B60000B70000B60000B70000B70000B80000B80000B80000B80000B80000B8
0000B30000B70000B70017A4002689032080171B6315226A122589202B7D1D457A363E51
40211F1306040B0302030000000000000000020000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000015110D121E230B293C10253E081D48
0611480309700002B202098300107201208013307617338C193D901D408D1C3E8D28477B
2C4F86354F813447832C43842C46782840762E3F7927458629467F2441882445881F4090
173898193B97173E8E184781174F7B2456722C52662E4E6434486237415D2C3D5B2B3E5D
253A622436642837582E3E643649763A5C72376378305B802D597D2E557A2F4E7C2A477E
2A45802C457E2F43833644813541812C36743336733D4564415B6A3B5A7A395180414C75
525169625B5D596463416675235D8B0F3BA3062DAD0207BB0101BE0101BF0100C00112AC
01209B082F8A324F6F595C54654A2E441F0F1D09020A0100050100040100030100030100
030100010000000000010000010000010000040000000000000000000000000000000000
010000000000020000030000030000010000010000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010000020000020000020000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000030100030000020000
0704010A090410323F0D2A7303109204146C06145501066D0001950218AE0527A60522A4
0C25970A27960A23A1132A99102B9A122A98182B9117298D172D89192F851A3282172B7D
13259012269E10299E0F299E102B9B142D9620338B293383373A7B3F40774C42680D21A1
0112AD0007B20000B60000B60000B70000B80000B80000B80000B80000B70000B70000B7
0000B70000B70000B80019A400288C0320831B276F182D761425961E1D82122C8D323567
47302F2C221B230F0B0D0202010000000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000120F0A111D1C0D282D1624270D2740
0B1D34060F5600029B020971010E6D001D9C0F2792152C97153B95173F941A3F921F4C80
245681365A7B3B507D2F44832C4375293D68303B712C45862E4A8029468C29488926428D
1B39971D38971737971E3D8E2045862D4B78304978294A7B314978313E75293C7B28427A
223F7C203B7E23407627457B2C4B83315280365580354C80354A813A47803C44823D4482
3E48823C48773C4C773E53753752762B467A283A7C2E3D6F36546B3F5D763D50803D4D7C
4551755753655E5B5D596B64446975215D900D38A7030BB90102BD0101BF0100C0010AB4
0113A70520992448794A5667625849653E27431B0D190802070100040100020100030000
030000030000000000000000000000010000000000000000000000010000010000010000
010000000000000000000000010000010000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000030000040100020000020000020000010000010000000000000000000000000000
000000000000010000010000010000010000010000000000000000000000000000000000
000000000000000000000000000000000000000000010000010000020000020000020000
0502010A0703143033102C6604157F062055071E670106730005980319AD0628A40621A3
0C279508298E0920A1112A9A0C2C98102894142989112A82132D8018307B182F7B19307B
15358A1638971436971135971834941C329227328833377C3E3D71414672484F6C1C3A8D
0825A1010DAF0000B60000B60000B70000B80000B80000B80000B80000B80000B70000B7
0000B100009D00009300138E00228B0321A71C318C183288172394231F6E142F722D3B65
3E42432D4E473628201E0804040100010000010000000000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000050201120C08121B17112A2B152A340B2344
0A194204095802096902085D000B770018AD0F279615308C153B911C3D92153D96144789
1B538B325C7D3C55792F4B802C4A732A455A2C416A2C4687344D802E46872F4A852C4787
203D871E397D19377A1C3C821E428731497A374C8234507E3A4B7C373D812C3A89273D8D
263E8E243F922943842A4A842D4E852F4B84324D82324B7A314D7C334F8338507F354B7E
3A4A7F39477B3B4A793852732F5975295381264B85294E7C365A763E5E783C5980365B7E
36607C425E74535E685C676352766A356C8117469F0411B60205BC0101BF0101C00102BD
0103B804239C14448A2F4C824D576665554B663B283B160C130501050000030000030000
030000030000020000010000000000000000000000010000020000040000050000040000
020000000000000000010000020000010000020000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
020000040000030100020000020000020000010000010000000000000000000000000000
000000000000010000010000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000020000010000010000010000020000
040201101A12142E30102A6204147A06225407237B00058900059F04199C0728900720A0
1028970F2B890D219F132D990E2C9A0F2498132B8C0C2A880E29881029860E27860D2F8B
0D3A920D3F950B439209479010438F13389019388C22477B2D52653854673F54672D5377
163F930619AB0001B60001B60000B60000B80000B80000B80000B80000B80000B80000B8
0000A900008000007E000A820017860322A81B3092182E8E182092252162112B72203570
2F4A582654583C362E2D160C0F0401090100050000020000010000010000010000010000
010000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000201000F0A06101713132B29142F49081D68
07105C040A53041450020D5800097E0012AB0F278D1433821D3F86203A8C173B9616478B
1D4E8E34597E3F56772D4E7E2A4C7626476C2A4776274A8634527B304D85345083324B7F
22417A1D3B6F1635681539751C43852F4A793A50783D57753F527A3947802B428A25458C
26488D264D8D294D80294F80264E822B4A832B4884264A80254C7F214E7F25527A254B7E
2544862840852E42872E477F304D7C2E4B812E4785354C823D557F3E607C38698033667F
2D627C36657647626D5B62675E7663457576235A930929AC0313B50107BC0101C00101C0
02099E031C9B1237982740873B4E7651576969534A5A36222D1107110200050000040000
040100050100050100020100010000010000010000020000030000030100030000030000
030000000000010000010000020000020000030000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000020000020000010000010000010000010000010000000000000000000000000000
010000010000010000010000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000020000020000010000010000010000010000
0C0A060F170F142B2D112A5F04147809224D0103A80004AC0005AB051B96092986071F9D
152B96162D880F249D142D9A10299C102499162E900F2F96132D99172E99152D9B163497
173B91183E8C184A81165081164A8B143E90173E8A1F4E7A265369315164385362355767
2B4D7F1026A10005B50000AC0000B80000B80000B80000B80000B80000B80000B70000B6
0000A000007300009100038F000F850422A81C2F91182D8E18218A262365112A84203178
283F5B1B4D6F3E403D3C2A1926130B170703050100020000020000010000010000020100
010000000000000000000000000000000000000000000000000000010000000000000000
0000000000000000000000000000000000000100000B07040E130E132B2615365F07199E
010380050B4F05184F020F6200088A000DAC0C268E1D43861E418E263C891B3E90184A81
1F4E8A38597641536C2D48772B467A24418E24458C26488D32547B2F5484355480354F7B
27427A233B841D33801E38822545883250783C556E3E5B6F385A7B304F85294C8B244C8B
21508B22528A245184225384224F85244785243F8820408C203E8E204089234185293E88
2C37882C39892E3B893542843C477F404A7E3F4E7E3E5480415D793F6575376E7B306C80
2B6386365E80455E745C6666616F5E537A6B346B841341A10524AF0110B70101BF0101B2
020497020B9F1320A72A398830437C3D4E73585863685145532A19240B040C0000030000
040000040000030000030000010000010000020000030000030000030000020000030000
020000010000010000010000010000010000020000010000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000010000010000010000010000000000010000
010100010000010000010000010000000000000000000000000000000000000000000000
000000000000000000000000000000010000020000020000010000010000010000030100
0B08040F130C172626142955061A6E0B23440000B80003B40105AF061EA0092A8C071F9D
192D95192F890E269D152B9B12269B11239815308B0F328F1631931B348F1534961C3794
2037912235912041851D45831A468F1B468E1C48891A4A86194883254979304E6D33576A
3153751A32950004B00002A500009B0000A40000B00000B80000B80000B80000A2000092
000086000175000185030A86111A7F0C1FA61D2D92182A9118208E2522750F2691202D7E
273666183E8F3C445C414A3736352227130B050100030100010000000000020000020000
010000010000000000000000000000000000000000010000000000000000000000000000
0000000000000000000000000000000100000201000A07040C120C132722173559040F80
02066A050B4F030D5E01087D00059D0008B107229416448D1A469326448920478C1C507D
2052893B5A7643536B2C43702B417825428F254A8D254D8930597C2D578234567E35507D
2D4774283D7B1D33851F378F28458C3551773D5868405B6A3C5679354C832D44892B458B
284A89284E89284E8B274D8B284C8C29458E2C428C2A418E283E8E243C88283A86303B87
343E85354283344880364E7F37507B3853783A567E375B8334638038637A396C76366B7D
3166833561814666764F6B6C567162577B654276772258930C37A8021AB50102BE0101B3
0101980202970D129D1F2C8D243580333D794A526D5C5D6069483A4D23141E0903090000
040000030000020000020000020000000000010000010000000000000000000000010000
010100010000020000020000020000010000020000030000020000010000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
010000000000000000000000010100010000010000010100010000010000000000010000
030100040100030000000000000000000000000000000000000000000000000000000000
000000000000010000010000020000030000030000020000010000010000010000010000
0904020F0C06191E1917284209235B0001B50000B80001B50003B2061D9A0A2C80081F96
192E8A1930790E2492162C8E14288F11229F142F900E308C17338E1A37830F308D173096
1A2A8F19258C173481143E851646921A4E891E54811E567A1F567625566D2D5864345E63
39566E263E87020EA2010A8E00028900008C0000A10000B80000B80000B800009400008B
00008A00027700048E1521811720780D1BA01C2A8516288B171F9B221E860C229A1E2A86
25317612299B2E3B72325A5F3B50493D271C0C0401060200030000010000020000030100
020000010000000000000000000000000000000000000000000000010000000000000000
0000000000000000000000000100000201000301000908040C110B14241D0D1C6207167F
030A6E030C570103960001B50001B80002B808339A0D4194124699214B8B20508C1C5680
20568B345E7F3D5B7832497133417427438C254C89254F872C55782B4F752D4F7531507D
3653733044801D36921C399622428E2F4F7B36536A41536B3C4F7D3341872A3B8D243D8F
25478C264D8C24508D27538C25508D274D8D274C8B274A8B22488D19418D1F3D87213984
243D832742812A4B7E2B517C2C557A2B567D2E56852E52882E5688375D833E657C3F697B
3B6C7E3568803E6977436C704D6D6557736352766B316985144A9F0427B20104AB0101B8
0101A4010197060E931021951A2D892E387D454E6F4C5B6E605A5B67422F3E180B150300
060000050100050000050000060000040000030000010000000000000000000000010000
010000010000020000020000030000000000000000010000010000010000010000000000
010000010000010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000040100020100
010100010000000000000000020100010000000000010000000000010000000000020000
050100040200040000020000000000000000000000000000000000000000000000000000
000000010000020100030100050100040100020100010000010000010000000000020000
0502010A060316141018232F0103B10101B40000B80000B70001B50619A1092B7E0C238E
1D32811A316C0E238A192B80152A7A10259A132D8B0E2D831530881A337F102D8E172E99
18288C142388133180123A841643911D4F871E538120587C235C712A5B662E5A63365D62
415869183199061C950617870106AB00008A0000960000B90000B90000B9000092000090
00019301067B02109D1A27861B23750A15A31A277E152684161E9B1E1B890A219E192A8F
1E2D811123A02A33791D4C7A2E50704C3C361B0F06120702060200030000030100040100
030100010000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000100000201000301000907030B0F091320180E215A08197B
040F6E030E640001A50000BC0001BB0017AA052DA2093A990C42961C4D8A1D558C215883
23558A2F5B81375C7E3451753747712C4787294C87284985274D71294962284A692B4E7F
355C76334D80223D931E3C9424438F334F83385077404D7236448426368F2030961B3891
1F478A1F4D881E56841B5A831C528C1B4A901D4A8F1D4C8E1E4D8E194B911D3F901F3293
22339027398B2D4286304B843151813154823257832E54882D5489365A8440607D406879
3C6B7C386A7C356678385F734B5F695B64635E70624175761E5D93051E8B0205A10103BD
0101B60102AF0208A60614A513289A2B3F853B4F793F5578525C6B6A5A4D5C341D270D04
0F0200090100060300060200060200050100020100010000000000000000010000010000
000000000000000000000000000000000000000000000000010000010000000000010000
010000010000010000010000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000030200040100030100
020000010000010000030100030100020000020000000000000000000000000000010000
040000040000040000020000010000010000010000000000000000000000000000000000
010000030100050201050201050301040201020100020000020000010000010000010000
050100070301120F0B141F260104AE0102B30000B80000B70000B60310A9182E82112971
233168192B6C0F23901B2A821627690F2595122A850E297A152D811B2E7A0F2695182D99
182C8A102189112A89103487173E9521458E1E409120448E214885254A7F24497E274E7C
34557B172E9B06169A0A157D050A7800018100009D0000B80000B80000B900019B000284
01057D031381102C86182A7A1725790A249B18277A1426821520991B198C0720A0142992
172D851024A12B307E1A397E243D7B4C4D4F2F2A142214090E0402030100030000030100
020000000000000000000000000000000000000000010000010000010000000000000000
0000000000000000000000000000000100000201000705020A0C07071F701023510A1C6F
0614650510620001A50000BC0000BB0014AC0226A904329C063B9215488619568824577E
2C4F842B52862E5685304E79374B722D4A872D4C8627438726497527506128476329497F
315A7D35527D27438D24428E2B488738547D3B597640536F3748762B3A80292F8C263B83
234581214B81255479285473254D8124408A263F8A28468A284B8A2B4B89324688354188
354287324488324A86354E843A5483385981365D812C5D88295C892E5B86345F82376480
38657E35627E35607C3D5A764955715C5C62616A5B4E7A6A2C6B8608228A03099D0205BC
0102BC0101BA0102B5030BAD0F25A32C428931517F324E7A4053735C5E5E6B55364A2711
230A020F04000D0300090400070400060301050200020100020000010000010000010000
010000000000000000000000000000000000010000000000000000000000000000020000
020000010000010000010000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000020000020000020000
020000020000030000040100030200020100020100010000000000000000010000030000
040000050000040000040100020100020100010100010000000000000000000000000000
010000020100040201040201040201030201030100030000020000010000010000020000
030000050101100B080415910104AB0102B20000B80000B70000B715239E1529910E227F
2324641723720E248C1E2C761628630D298513297D10268016298E1B2881101F98172A9A
182D8B0F228C122A840E3285153992224881214584244B8727537A285770265A6D245E6C
31597714289E020BA9060B9107097F0102920000B80000B80000B90000B90002AE0004A1
020E990F2C820E307E122B7E12288108288B162A7F162B7A152579161F7708228B122684
1327821021A22E307C1A346A1D32673D4A543B4F3A392B1A1E0B04060200030000000000
000000000000000000000000000000000000000000010000010000010000000000000000
0000000000000000000000000000000000000000000603021A24360824611225470C1E62
0A195B08115E0001A50000BC00069B0010AC011FAF0128A7012EA10B42900D528C26517A
31467F26448E254A8C2C4B81354F75345284384F7D31458222447B214D70254A6D294B7A
31568038557A304F82304B86315082375979385D783C54663346582A3867282C88203683
1B3E8A1A438821468322487D26497E28487E274A7E2C4F882C53873256863857813A5681
3355852956882852892B4D892F4F88325584305C802A6086275D8926578C28558A325882
3B587D3F587D415B7D405C7D45617A525E69596360597260101BA7132B830713990511A2
02069301038C010398030BA128208F243C8F264782274680334E774D5D6660664F65452B
43200C1F09020F04000A0400080401080300060200040100020000010000010100010100
010000010000000000000000000000000000000000000000000000000000020000010000
030000020000020000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000010000
020000030000050300050200050200040100030100020000010000010000030000040000
040000020000040000040100030100030100030100030000020000020000020000000000
010000020100040201030201040201040101040100040000040100020000010000020000
0401000300000C2A5206168E01069705057B0707740002930000AE1023A312289A0E1E9D
252088181E8A10258A2530671829600C29831328870F248814277E1A2A7C0F268D182989
1627870E1F9915298E132D8E17378E264B6D214376234986294F772A516A2C5A6130665C
36597015239E0001B70001B80000B90000B80000B80000AF0000A100009500099500119C
0F2999162F7D132E88132D8F112C870B229B1831911630881123801226730924800F1D7D
111E831023A32A2D7F182E66152862283B5B275B6E46403830170D0C0301040000010000
000000000000000000000000000000000000000000010000000000000000000000000000
00000000000000000000000000000000000001000004020118212E09265314243D0E2054
0D1D4F0A135A0002A40001A9000498000BAD001DB10128AB012EA90C439810538E294E78
33447E203E93213F9524448C2C4E7C30567E3E537539497922417E1D458120447E274581
2A4C8536587633597839547935538036597E345A813756752D476925336B20248C192F8F
143691163F8020466E1D416F1A427D1C48831B4C8822518B23538B24528C284F8A294E89
2B4F882355862451862444912A428E2B48892B51882A588927588B27548A2A528B355482
3F547E45567C415B7D39647F396A7E4062734E5F693F4986151CA420317B0D1F930D248B
051379030C76010480020B94271D8F1B37961D3D891E3D832744793E52714E5F686A5E4A
6A41253E180A1A09010E05010D07010A0401090200070200030000020000010000010000
020000020000000000000000000000000000000000000000000000010000010000020000
010000010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
020000040200070300080300070301050100040000050100040100040100050100050000
040000020000030000020000020000020000020000040000040100040100030000010000
000000020000030100040100040201030100030000030100030100030100020000020100
0301000B1E19122B4A08168C01087E0A09430E0F3C0106680002B50923A60A2A9F0D1F9F
27258C19228E10248B253365172E620F2D97162D980F289A1227901830890D2B8D152686
1320820A209517298B122B951331982243721C3C74203F8F264482274277314E66375B5C
3E54691C2A970206B40203B60000B90000B90000B80000A400008E00008D000A8700188A
0F2E891A307B172F7D162D7E162B8511289D1B339418309612279C162D860D22960C128D
0C138A1024A2272983152974111D6C1B286014498A4B4855482C18170A030B0200000000
000000000000000000010000010000000000000000000000000000000000000000000000
01000000000000000000000000000000000000000015120D161E250926451522320F2048
1020460C125501028A0001A70002950004AE001AB20028AC012CAA0E449918538E2C5079
334780233B942237971E3795214687244F8538526F374A6D223D781E3E8E20408A264484
2A4F88335C7B305F7E375C793357813557802E54843459792C4E7C283C812238901D3796
1A34981D3B8420446D193C691737831C3D9621429325488F27488D28458D2C418D334487
384885384F7833537F2C5087284E8925518D23578D21598D23588E23598A265B882C5986
315585355685355A852C62843267803B617B485E7938438C171DA4222B80112086132B70
06147F0412830107741719891E208F13339B14369513348C1B358534417C3F50765D5E61
745C405C341A3012051607011107000C0400070300050100030100020000000000000000
010000010000000000010000010000000000000000000000010000010000030000020000
010000010000010000020000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010000000000000000000000000000000000000000000000000000000000000000
020100050200060300080401080301070200070100060100060200070200070200060000
040000000000000000000000000000000000010000040000040000040100050100020000
030000020100030100040200050200060200050200040201050201040100030100020000
0200000D181117293D0B167B010A600E0C21131430000194000091031A9D04249D0C1D98
2829881927900E25961F2F6C153072102C9B1C2F9610289F13279D1B34950D2D9B122091
121B900B23A3172B99102B9E102B9A1D3C791436831C39951F3E891E3A802746682F4F5B
3B4E651D2E92030CB20205B40000B90000B80000B600009A00008C0000B20004A20C2291
0F2C93193489143182122A7F152A87112C9C1B339118348E112E8B1729770F1C7B0E1682
0F1B8D1123A2232688112380121A70181E640E369442436857432D2F1B0D1C0803050000
020000020000010000000000010000010000020100010000000000000000000000000000
000000000000000000000000000000000000050301110E0A131A1D0A2637161E2711203D
10203D0D125101027E0001940001930002990011A1001EA7022DAB1A46931F518C2F4F78
324980253E912237961D3296203F8B204186324974364C742B4471293F85243F8A2B4982
2D55853563792E61772E5C7A315984355283304D8435597D29567E2C498328428B1E3894
1D2E9A1B36891836711834731E3C8A28448F31488A374A843B4E8342497F404380404780
3E4F7F404F743C54752E60792961802361871E628A1B608D195A8D23597F265B7726597F
2754882E5389325487325684395B80445F7A3D617F2B4692151EA91720940C168E0F1E73
060F7D061680032783121F82172183122B96152C97122A9417248D32377E3A527A4B5C6F
63615A6F5135532D152710031507000D03000B0200030100020000030000010000000000
010000020000020000030000020000010000010000000000000000010000010000010000
000000000000020000030000030100020000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
020000010000000000000000000000000000000000000000010000010000000000010000
0301000602000603000803010702000803000601000701000700000903000A0200080200
050000020000000000000000010000010000020000030000030100060200060201040100
040000040100030100030100070200070301060301070401080501070301060200040100
0905030C0E081616190E11320312300D1320020295000366010178010E8C031D7A0D2071
1D21831323900F289B1D2F85142F8516279A242E911128A013269E1E368E0F2C8C14208B
1520961224A2172A96122D9612299D1D3482132D8E162F9C1937901B33802942602E4559
36486D1D2E930410B001028D0000B60000A000009100038E0006940005A20F209912259C
162D9C1D3793182F98152A96162C8612289A19329112358B0D2C8E1328850C2083112187
1325930F26A21C268D0F238A11197B17186D0E2B9D343E6F4A5151503D343E190F090200
040000010000010000000000010000030100030201020100020000000000000000000000
0000000000000000000000000000000301000302010E0A061116140E2426171D20102136
10203602039200018E00009000019000019600099B0015A3032BAC24478E284C88314D78
324D812A428F2737921E2F992035911D318C27417B2D4D7C2C4E772C4B822746862B4F81
2C5B85326778305E773157783559803B557E344F863355812F53852D4B86243C8D202F97
1C289B193290173585183C8620428F2342932A458D2F4989364C85364C80364A81324A82
294D8A314986324D8030597D2D5F802A6083236183235C8923548331577734597430587F
315286384E853F52823F50813F557E366B7E2F6188214698131FAE0D15AE060AAF080D98
070D7E092373072F810F228812218A11259716269614279519208E30387D3553803E5879
4F5B70675958724C36542B14290E020F0400060100030000030000010000010000000000
010000020000010000020000030000020000020000010000000000000000000000000000
010000000000010000010000020100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000100000200000501000702010603010A0602
0602000502000201000200000200000401000401000702010703010804010A05010B0502
0905010B06010B05010B04020A03020E05010C04010D06010F07021208031409031F1709
1C1307180C031407021506021007001206001108021207021306021004010E0301090301
090100060000070200080300070300070200070100080300080301070301090401080301
0502000A02020F0C0D082024071012090E0B0203840101A60000A600008800008F00079C
00119E1A2A8E282E7B212C73182B8E20238A1424921229972E307F23358416368C2D327D
26337E1E3171282B5814226F12289B23378C153D9125398E32377E19348914269B0A1899
11227715256707186D070F810E23A014348415366F17356E1C38701A3385233B842D4279
263A8A2E3F7D2B3A7B28388A2E40852A3A8D2C3B802C3C6928307B272C6E21318123388F
20398C1A348A1F388B1939941B358E1F2E7B181F741C1E77161F8C251F86282283152593
2C2E62193C783A4360524E49523C303C180C0B0300070300050000030000050100020000
030000010000010000010000010000010000030100140A071A181F0B28461C283D181C63
070D74090F540000C00000B000008F0001A10009AD0216A1072CA02742872B467C26467A
2F487F25418F25428E23438E2A478127418C354B793B486A2F3C772C407C26428E3A597A
3C59743F51723545823048842F4A852D507E2A59843E5C733D507E34497D2E4B852F4A82
2446872545881C3A981A379C17369D163898173B91264A7F2A44862A408629458B2A4C8A
34548138597F416076446474486D6F4A746D4A7D6E4C806B4778703E69791A4E981133AA
122F900D278D0A1EA8060F9103059A0202C00411B61235A81437A01B40911C3D9519399A
1937A01738A41639A014399F163C9918389E153A921D367F192676141B831318AA2D2D99
282A982B258A2922992C20882B36822A447F445B7245616F5061645D605462462E3F200E
1E0D041109020E08010E06010B04010A03010903000B0300090100050000020000030000
030000020000050000040100030000040000040100040100030100010000010000010000
020000010000010000010000020000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000200000302000302000703010603000703010906020E0A04
0E09030D06020E08020B0503070201050100060200110D0612150C131C1413232417283D
18235D1220640E1F6E07125B06087705068D0304920000B30000B70000B90000B80000B6
0102B50104A806077207087811218D254779345B55434A3339331A2D200D2413061E0E04
170A011206001105021006000C03000C02000B02000B02000A03000A03000C02000B0200
0803000701000502000A02011807081F101526213026365E103B8C02199D0000BA0000BA
0000BA0000BA0000B80002A300109E011B97082189152786262F842A32850B17A910239C
122D9713329E14349B153599153399061EAB041CAD0416B00310B30319B00420AD0526AB
143D99143C96143997153E94153E921A40881D437D203D75233D76203E83253F8C29457E
203F772B3D702D3F6B2B3E71303B722A39832F3C883140802A388C2E368229378728388C
2A3584242D8829367C273180222D8B1E30921630991E348C1830931E2E941B2E8B0E248C
171F8007239417258114298C202D942E3B7F1440954351675052464C2A1E160703080000
0500000400000501000701001105010902000F0200270D04432B144E4B26201B5E272A3A
1F3A560812600001910000C00001BE0001BD0831A40F3E95103BA2294B8932536B25425B
263E5C223F6F233C7B213A91213F8A2040811F4080264586244C8F204D8C1B4D8B244D7C
2C5680334F7B3654782E4F7C2B448434497534477C3C4371344C813647852C3C7C2A3C7D
1F39901F3C89244C8F356285365E83354E892D488922479423508F28578E295B8A305F84
336C7F317980367D773B7E7440806E46826E2E738226658B1B549818549A15529D104CA3
1146A5103AA9123EA1163C99153E93173A921B3A9A1F459F265595275F90255C93285691
285194284E9627508B2C577D345F6F345D633154672B4778264085223B951C37961C378D
18338B1B2D8A15329A18289917229621207E1E2C891A269023478B24558A37587A3C5573
425072556067616D5A6965406244233E1F0A1F09010F01000D00000A0100080000090200
0901000A02000801000901000A0000060000040000050000060000090000090100040000
030000040000020000030000010000010000010000000000000000000000000000010000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000000000000000000000000000000000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000000000000000000000000000000000000000000010000010000010000000000000000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000000000000000000000000000000000000020100020100020100020100010000000000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000000000000000000000000000000020100020100010000010000010000010000000000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000000000000000000000000010100020100020000000000000000000000000000000000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000000000000000000000000010000020000020000010000010000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000001000007030113100B1A1F3106206C
03247F0321931D2F86123E7E0E4A6414464C1C3D3A1A342C1D31241A3329182C271E1D13
221C0F262A1A252B1B222516252B1A2938252D39233338223B3F2743482B4D52344B544B
31406C1630790002BA0000BD0000BD0000B50000A700009C00028702059C071B9E0A319A
0A2F8514298C16328E1138930E3287182A911B2D9B113C9E0E3B961535981C319A213D97
193D911544931843952641913341882F468722478A27448E38397D3E3E6D464C61595251
5A443A4F311D401E092F15062F17053B210C3E200C3F240D40270F45290E40260D46250F
4728104C2E124C36174D3717533A17553C175A401861421B5F481F6456266B6736667A4C
4E7865446F6D3E60763A537B39567E39547F3C557F3B547E3A527E3A527F39528039517E
374F7D324880364787394B823B477F465270414F67454C7747566F404D7A444A7F41477C
343F833B3C7D393E7D3E408248457B413E7F45457E4345773F456A4547643C466A414564
40426E3E3A83423E7A383B81423A8134377F363179363677383D6B38346A262B8F2B2A8D
212F852A1F8133227C3B32824833592E37854637723C3479464181515771464E7D6C5663
4E5579614B6A6264685E616963696553697061806268845D6F80596180666A805C69805F
587B70526B766D8057787A457A60346D582B6C502565471F5C441E5B3F1A5B3A165C3816
5C31115D31115C2D0E5B30104E21073D15043C1103431B0651280D6B4920726A317A5D28
756A34706B36606C445973486B6F40647E466881496789506C8B536C8A556F8A54738B4E
74874E718753778756818A5184934F859A50839D52819D53809A538C9B4D90974A8F9549
9592449595429498449793419986408C81408481407A7B407C6F36775D246D4C1D64471B
5A43175942175C43185F47196247175E42155A3A1356350E4F2F0E50300D4E31114F310F
5438115F3B136E47187A591E88773684804B746F5E5D6E6E5C80695E8962568961518662
4C85694B856758895E6D8E4C848A428D84408B843B8882398A823285834074874C718954
718D5465915E5A8C6751836F578A6A62976471A056809F4E819A4C7E964E83974A899847
8A9546879D4A8A9D4B87A04D809F52759F556D9C5C65965F69935E6E945A709459759357
7A97577C9D557AA5547AA55479A55579A25679A5567DA6567EAB547FAE557AAE577CAE56
7FA75287A34C8AA24C84A04E87A14B89A24A8AA2498F99439293419695409794408D9540
8B93428492468093478893458E91458E92448D95498D964C8B964C89934C8A93488A9249
858F507F96527E9C527A9B537C9B5178965478955381984E889A478F9D468E9E4C899A54
859955819A597C985C7597617698617699617E985B7B965A7C99597CA35777A95775AA56
70AC5761AE5C4EAB623CA16E33936D35895B3C6B3B343917190F05060100040000050000
050000030000020000020000020000010000010000020000030100020000010000000000
000000000000000000000000
000000000000000000000000010000010000000000000000000000000000010000010000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000000000000000000000000000000000000000000000000000000010000010000010000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000000000000000000000000000000000000000000010000020000030000020000020000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000000000000000000000000000000000000010000010000020000040100030100020000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000000000000000000000000000000000000020000030000020100040100040100030000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010000020000020000020000020000040100030200040200040100040100030100030100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010000020100020200030200040200050200060301050200050200040200030100030100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010000010000020100020100020000020000040100030000040000050000040100020000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010000010000010000010000010000010000000000010000030000030000030000020000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010000000000010000010000000000000000000000000000020000020000030000040000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010000020000020000000000000000000000000000010000010000020000020200050200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010000020000010000000000000000000000000000010000010000030100020100020000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000000000000000000010000010000000000000000010000010100030100020100020000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010000010000010000010000010000010000000000000000010000040100030000020100
010000010000020000030000030000030000040000040000030100040100040100040100
0501000300000200000200000201000100000100000100000100000100001E152A14107B
0206AF0103B70104B70417980A2482161E7718168D162D7322355A142C71172780242860
22211F191C2013265D171B8E301D852C3567193D6B10377B1C2C7D2A223D1C15211D2E50
17397F26367B3A3565303B5F11428B072A94030BB80C0F8F030988040C9407168F092893
0F1EA025168F26268C1020940920A52318822C276B0D1A810C23861C1683251C7F0D227E
10248C221D891A158207208B1918A03323891C2F891225932D1D8E2F2B8B0F2A951B1F9E
332D85273A781D357F2C2F863A3C6A2E406F2B437F2E3F84344783395C8039567D3C527F
4F4A755E41605E3F5B6654507C5B4083593B8059407661456F694E6E73536A745765745C
627363627263616F6663706266755E6A75586A765A68805B67776168805E6A8062688061
71805A7676577671586E655B675A616B59676C705D717549717340726B4074664078683C
766B356F6631705E2A6D52216A4217673F16633B13683E17754B1E7C5D336B724E5B6E64
4E5F7646597B47557B4A577B49577C4A59793F517F434E7D474B7B494B7B4953794C4D7B
4E4D7A4B447B4A53784B5676465676415377434C7041417644417A403A7F3A2A904E5165
4A4C65514D73403C8A556A735E80697B805177875381854D8D8045858049828049838042
887A4089783B86723A7F6E387D5E2E7A56277A52257951217B58237751226F4F2067471E
61421D58421E563C1A4C2F114422083C19043712013413023716033A1603391504391403
3513023312013310024117035824085B290A5A2E0B52270B5020074F2007532005542308
562709592C0D6338106E451778592277672A7D5F25846829857730827D38826F2F7C5421
784B187243146E3D146C3E136A40166643156A3C116C3F14643D145E35105D350F5F310F
562E0B50290A4A260C46230947270A49240B4F290B562F0F5937105B37105936115C3A10
613D146242156146166843166E4B187D561B8367278A792E8E833A8688407B87486B8354
7585497A87437788447A88437D8643808C437E8940808940808944798D43708B48768643
7F7D377B6323724F1A71511B7559227A5820865F1F926C289A81399A8540958A488A8C4E
858D4E89914B8E9047958F449A92409A8F409A8F419A8F41978A42928A458D9348919847
959E4397A04494A0468CA34A8BA44C88A74C87A94A8FA84696A243969B44929C468CA049
88A14C85A45183A65078A0596F9A5D739A57769A54769C557A9D55819E4F809B4B889745
9296409293408C93408992408792408D9240938F39918E38908E3890923A8F903A8B9039
8C903B8B913D8991408191407D8F407B8D3D7D90407D92407D95407F96407D92407E8B40
7A823B777633736B2B6F5821674315562F0E481E083A19043215032B1304240F01190801
1705001204001003001103000D03000A0100040100030100010000000000000000000000
000000000000000000000000010000020000000000000000000000020000040000020000
010000000000000000000000
010000010000010000000000000000000000000000010000010000020100020100020100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020000020000020000010000010000000000000000000000010000020000020000030100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020000020000010000010000010000020000010000020000020100030100020000050000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010000020000030000050000050000040000030000040100070201070201070200060100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0200000401000400000500000301000401000301000502000803010A0201070300070200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020000050100040100040100030000030100020100040100060100060200050200030100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050100050200040101020100030100040000040000030000060000050000030100020000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040000030100030100030100020000020100040100050000050100050100030000020000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030000030100030100030200030100040100050100070100060200060200050000040000
0300000100000200000300000301000502010804020A06030D0903140B06120B04130B03
160D04150C05140A04160A031409031107021009031108020F07030E05020B06011F0A0B
270F46060993071444081D4D040F830C148D231C742B24431B1B241C2D44163777172396
24258627278A29338721338D2123881A17971E25991922A11A189A141C9A153197142E93
193299342F81352B870A15B2030CAC0105B7030FAD0423AE0E17A6240F86161A8B082298
0623961B12942B2088142E940A259817199D2C20851D27940A21A214209B35346C2E3E4B
1332691D27873D3D583043531A3771242088273191162DA21D1B9C20129A1518A81D278E
4A3D532F306626377F483E6A372A6F2C376835357F3D33751E267221278D382D7B2D2D84
2834903C348639477D2A43752E47803D4C81455D704F5B61565B655E5B655F4364693B5D
6D53595F5A635D65645C7C645D806061805E5980645C806460806065805A5E83615B8064
5980685780675A836463805D70804F768040737440686F40626A44626440615C3A61522D
633F1B643915663A14643B1568441A653C155D3E195C34125B3914593612552D0E592B0F
5E3B1E5C4C306563406975446A79486F77457C6B407A56277352256C5C385D6F4C5D774A
57804F607845657842637A4666804C6C80506C815473835574805981805084804D86804C
88804C83814C7D864D7E834E80844D83854A8882418C80408A8040848042878040867737
805E286F59266E4A1D6C431A6B3E17703C156F4015693B145B36165C31125B2C0C582608
55270A521F064D2005492106491C04411903411C04451F05451F07461F05441902370F02
3613013A0F01330E002F0C00310C00331400421705431A024D19044F1D06471704421702
521E05572709592A07622D0B6C3A117140187B57207A6C2C786428744D19673C14693914
6C3C126A3B1165350E6339105E330E5F330F5B38115E3811623B146240145F41185C3D15
5A391259351054310F502F0D4B2B0D48250C47270B49290A48280C50300D53340D56360F
5A38105937115D4115684D1B71571F7C5C22826423886E2B887B408182407985476F874E
678A516391546396546E9350738F4B778B44758B4073884075874078823875712B756A26
796E2A7B6F2A7D6A25795D20764E187240137045156E44146948146D47166F48166E4213
7245127A4B13825418835B1C83611E88622187662389722A8584388E863794873898883C
9C883D9F883DA28A3DA18A409D8E40979641919C4685A64D7BAD527AA95382A34E859D4D
809D517C9F53789C5878985A73965B7798557D964E819348868C40887D32845E1E774915
67370D5B2C09572706542709582D0A582F0D58330B5A390F5C3E12604315624618664C18
65491861411459390F55340D50330D4C2D0C4928093E1705361401301200311100341300
3512003814003313003112012B0E02270F03280E03281001240E02210F021E0C011A0A00
1707001102001101000C0100060000050000020000010000010000010000010000010000
030000040000020000030000020000010000020000010000000000000000000000000000
010000000000000000000000
020000010000010100020000010000040000050100060100070100070200050200060000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0100000000000000000000000100000501000603000703000A0101090100090100070000
0300000300000300000300000500000501000602010904010E0903110903150903130A02
130903160B04160C04170D05180E06180F061B12061C1307190F06170C04110802160903
1A120B1B1F1715130D201A270F166306154A0A1A27182C3E1D2A6D1C1D90292392283589
183A870D2A90122391191A982C25882B218A252B8D222A942128921C23921B2F921F308D
273A93304B86263A900812B00714960D19720D226F0D2E831120912924682D335825375E
142F79171896271D8D172E930A249C121BA2291B90212297091FA80D1EA32B2775293561
102C78182B863A405E42585125437029387E29347D122587181A8C26268C1B28A0191DA3
321786241B9423299241336837206D2E336C36387E3A31781D256E22288E3B2D842D2775
2A32783E305B3630632A33713333873845832D58803259704059774F5B715C5065524C6A
4C586F4D61685C635959635F50676853726C56616C6075605C8062637F5B6985596A8158
69805A65805C5D80615C816063805672804474753B70663667673B6261405C5A3A60502F
6146206541196B3F176A3F166B431A68421965451E693E1664411A603E185C3814562B0D
4B2005552208602F14614426656940677B47678049727940795D2A734B1F6E532C6D643C
5C7049626E405B65405861405862406167406C6D3C72774072794477804976804D7A8549
8483438680408680408580408480408180407E8040808041818041868040878040848040
86773481672E795C266C522565451D6539156731116031136037155D260D5222095B2508
5C2B0B5F270A58250A5622075524055023054E2307492008451D05421D05411704401902
3C17023810013010003413013614023F17044A21084723094C20074D1F06431804481805
5820075827095526095B2A0B63330E6D3F13795120766529725F25734F1E6D471A6F4317
6C4015653E15694316684318653B1357310E51290C4C24094F240A532B105537115A3511
5C3A105C39115336114D2F11442C0C47270D44250A4222094120074520094926094A2608
4D2C0B51300D563712583B13633E156B3C117149177D5119815919885C1D88641F876F29
847A3381823B7887437287487189497785437B86408084407E843B7C8339797A3075732D
7B722D7D6D287C5F2378521A744B147246156E43157243116B4312683F12663F136D4114
7845157D4D1881561B825B1A835B1C805B1D8063217E6E2680792E837D3084802E838536
88893B8F893B938C3C948F409391409095408E9A4487A0487DA84E7DA74E7CAA4D80A14D
7F9F4D7D9C527C975379994F7A974C79964D76914775844077662B70441763300B5E2A0C
582C0B5B2B0D5E2E0D60330E643C11664316674B1A675420675A23665E26676A2C676D2C
6D6A2C696324625A205F581F5E59215A561E5947174B2F0D3E1D06311202260A01290C00
2A0C00250C00250900270801270C02260C011F0B011F09001E09001E09001B0800190500
1404001303001002001103000A02000A02000A02000802000B0000020000020100020100
020100020100030000000000010000000000010000010000010000010000000000000000
010000000000000000000000
010000010000000000010000040000050200050201060200060100070000060300060300
0602000502000301000100000200000201000401000803010905020F0503110702120802
130A04140C041810071911071A13081C12071B1107191006180B05150B02130803120702
130A04101518140E0620161A111E440B18330A172A16374D172C66181A8D28257E323163
2F38682530791A2282171B9222298B24278C26298E292F94213990153193142C96212494
27398B27518A1F40940810B00812860F2260193256133973122796292A86353B68283759
172F76141A8F2319831723900B229E1120A3291E922420970B1CA90E1AAA26198B1E1D88
0C1D98122092332D7C475255253C6A2839772D326115247615229A29338321318A22317F
3E3154302B7821279033267C311D772B2D7C3939773E30761F246C1F25903B31832A2770
253178413A5A36385A253371342D883E3F7F294B832F4E83414E80465B7C5366724D6072
4A636F524E6963485C634D664F617043727855586B6074615A8061697F596A83586B8356
6D805766805B61805E61825E6480547380437575407665346D6236676240675B3B66532C
684D226D4B1D6F431A684018643E16654017654218603C1763441E634319623D16553210
53240955230754200857280B61411C6C5C306578446E7943786630774E206E4C226E572E
68673D6561385E5B305A522C5B512C5F582E6663366B6B40686F40727840757A407D8042
83804082804081793C84743580783A7B80407680417780477F8041858040878040858040
877B3A836F317B57256D4A1F603B155A2A0E5B270C5D280D6236145B290B522106582507
5F2A095A24075A25065B22055823075223084D23064A1C05441D05411A03421802421702
401702341302361001341301391603411A02461F054B1E055420064E2108481B04451A05
4D200954200852220B5A270A5F2B0E6A3A15784E1D7A6024795E2374521F6D4918684114
623D146441186644166B4919663E16603210572A0A5028094E2909512B0B52330F532E0D
59300C57310E54350F493010462C0D46270D43260C40220B3A1F08421F08482108472507
4922094C280C4F310F5733115D3B11643D127449187E561B865C1F865A1B876220896B25
886E2786702A827932807F367E803A7F8039847C3887823988843C83843B7F8237798135
797D3278742D76662674551B734B15734615734714764915714B146E46156F41146F3F13
7746157D511A85571D845F1F845B1A835D1B826121856925877127827628847829818534
7F8A3D838F3C8A91408D94408F97409097408E9942879F4780A74D7BA8517AAA507CA350
7BA05179995474955575964E7893427B843B7A6A2C7255216C411661340E532B07522B07
532E0A5A300D5F38106547196959226D672B6D6C31706F32726C2C756F2B79742D79782E
76752E726C2A6E6728696A2B666A2A6066275D5C2256481A49310E3821072E1203240C01
240C012609012309002108012207011E08001C09002108001D07001F08002107001B0500
1A04001203000F02000D01000B02000A0000080200060100070000020000030100020100
020100030100020000010000010000020000020100020100020100010000020000010000
010000020000000000000000
020000010000000000010000040000040200050301060300050300070100060200070200
0702000801010401000200000200000300000300000501000802000A03020F0502110703
140903140B03160C051B0E05190F07191105190F06160D04150903150A02140903110601
14070212110F1008041710110A14370509560312701935771E306A1720891D2480292A71
2C2A7926338819318F142397173189152C8C1A2489242D8F273F8C203C8F212C8824258B
233A882447851C35760F157D070D7A09186C0F29590B3575122B9225278A2E2E751D2665
162A75111E8C1D1286111396091EA20D20A7281F932820920D18A90D18AA261580201F80
0B1D970F20962C2687363D6A142C791C28772A30671A30811C33872E3D7122297B263B6D
4140613C37701E248F2F2189322080282E8934327439276622237524268C3E32802B2770
25307847415A363D662431783527893E3C802340822C3F8742487F415B7A436676496774
505E725C3B6767395B6150585563624E626F605A60607E60577F6468805A67855D708358
6C855965845B60805E5B80615C805E6B804D7676407A6A327461316F6337695D336B5327
6B4E226A471E6A4116603C145E3613633F1764421D653F1867471E613A175D3B16583411
542A0C50270B492207491E084F290F6137166B5A326F723C75662E7553216B481C654822
5F552C5F552D5D582D614D245C441D654B2269592B6C6538676D406E6F407773407C8040
8180408180407F804083773881783B7C7940797840737A4382804085804088803C848040
86793C7F70367A59266B4B1F5A3815512B0E552B0B5B270D653815602F0E5A290A622509
5A29065521065223065821044E23054A21054A1F054B1C04411A03401A043B17033A1602
3618023915003816023B16023B1A03431B04461F04491C04491D064A2006491D064C2207
52260B53280D5C290C5C280B5F2D0F6C3F14754A1A79541F76541E744B1C6F471A663E16
643E136A40186A42166C4317663E155E38135D330F5C300E55310D512C0B512B0D4E280C
5027094E280B4E2A0D4B2C0D4B290E47290C41240B3C200A431E0943220A472408472307
4722064A2409522B0B56300D623B116B431775531E8261218667228B6B238B70268A732C
82722C836E2A7D702C7D722C7C742F7D753084742E867D3785833B808137807B327C7A32
7B752F736C2A6E652672551E6F4917714815744816754815764C17734C177344146F4014
7343137B501982581F82602085631F85631F866822886B23897027837629817D2D808A35
7D8F3E7D9641829842879A428999428D97418A9A43849F487CA54F75A85474A65476A154
75A0527197586F925571924C7789407B682875491667380F5A2E0B552C08552D0858320E
5F3E1563471D6D56266E6830717334727C37747E36797B32807A2F837D30878837818B3D
7989407182406D7F406B8040657E3B6677345E6E2E555F254E43173F280C3218062C0F02
2009012108012408002006001C06001A07001B05001D07001F05001F0700230A01210A00
1A08001A07001103000E02000D0000090000060100040000030000030000010000010000
010000020000010000000000010000020000020100020100010100020000040000050000
070000040000010000000000
030000020000020000010000010000030100060201050300070200060100080300080300
0903000702010702000501000401000301000600000502000703000A03010D05020F0502
1207020F0903120A03160D05160C06160D05160C05170D04130803140A02120803110702
161D14130D08130801120B120608580101AD0613A51521A21B32840D30820D2C7B16287A
1E1F80212D84213B741D308424377225306725286C292C7D2E3A84303B89333485303086
223A8B0D2487111C720D127202048104108506257E0C3686112F99222589292185121291
14246D10227A1712730D127509208C0B22A028237F3233631228890D2295221F70272D6D
0F20860C23992421912836890C2B9113209B2A308E2039961C3A85343A5D28295F203776
3B407639387924307535325F3E37582E37732B2F7A3729712C2B812A298642347527226E
242A7F3F366333345C2435773623783B3974213C772D388B404683395883335F7B3B667C
4859795D3F615E454E54485C545466554A6C645D5D6080615A80636980566B80596D835A
6B865C6A83595F806357806A50766E6480557280417B76397567336C633D66613C655831
654F2A634620623B165D36135F361464431A654B1F68481E675026633C185B3B14573412
502F1150290D472007401D05421E094923096035146550256A5D2C6F53216D481D694A1F
614F245C552E545D3C60532E61461F62431B6A461C6E582A6B61376F63317865327D763A
82803D83803D83803B8578368475347C74377B703678753D837736857A39887B3A828040
86803C7E72367B6229715022653D155D30125B2F0E62310E61381368361163351263300D
5B27085C21065620065522055222054F22044E20054A1D05431A03351504331404331102
3A14013918013817033717023817023C16043D1703411102451504481E084B2008522309
53290B5C2F0F633411642F0D622D0A67381171411871491A7045186F47176E46186A4116
6C41176E43156942166A4113664115623D16643A136139125D3912502F0F51290D482409
4620074924084B22084C250B4A290C46250B45240947240A46220B4C290D4D280B4E280A
5024074F2607532A0C5C320E653D126E501978622283712B87782D8C7A2E8B7A32877C35
87793181732F7C722D786F2B786C2C7B6F2E806E2D857430847632836B2A7E62267F6125
7B6025725C1F71571E70501C704A18714716724C187649187551197A521A744B18734616
7647157B521B805C208062228166248167238568238769238B6B22867229847D2E838A34
8090407C97427F9B44819D46849D46869C428A9947809E4B75A3516EA65A68A25C6B9F5B
6F9C547295517B904681803C7E602674481665390C5C300B5A340A5A310B63380F6A4918
715E286F703A6C7E426B8748748C43778B407985377B7D2E7F7A2D80853381913C789243
6C944B67955062964F60954D66904369833963762F616426544E1D48371239210A2B1304
220C021C08001D05001C05001807001906001B06001C03001D04001B05001F08001D0900
1E08001906001405000F04000A0000080100060000020000010000010000000000000000
000000000000000000000000020000000000020000020000030000040000060200080200
080100060000030000000000
030000020000010000010000010000050301050201070201090200090200080300080300
0802000802000702000401000401000601000601000802000A04000B06010E06010E0601
0D0602100603120702130903130905120903120B03140A03130B03120902120901190E05
19140A16100A120D0A110E1A0C0F3E0406640105880C119C1729811B345D1D2B53211F55
2B1F6937286E37366F2B317F253373293B692B3A6C283B76273C85363C823C41813E4579
0A1CAD0611AE0406AE0305B00000B30312AE0628A30C339710339C2026842B23601A2060
10266F0F237619156713216D0A2A7F0B2598272385343C6B17317E0E28871F208F2D3482
131F840C289323258C2D3B771331791729912D397B213384133485292D6F293077233486
37447233317B26316A30387446426730316E2C2F843D347934357C2B2E7F452E5827206F
2026923927752F277622308A35207D35318024397F2C2E8E41427E3354852C55823C5D7F
4A5E7B5C4E68525E5B47595F4A516C5B4964676F5967805865805A667D5A65805D668061
61806562816259806556806A4F6F725F805C7280447A773F746A347263336E5E3367552C
654F265E431D5B35135B34125C3211623D1966451C6A4B2062592C63451E5C3D185B3A16
583411532B0C451F05431A03401905411B064E220957301167441C6D51226E4E206F5024
684E2264522C565E405E56355E4B265F421B6641196A4F1F6B592F6E582A785B2A816E32
857739847939847A37847835867433816F317F69307B6C3482672D847031857A39818040
8479398072317C6B2F775C2471411667391261361165341067351268340F673412632C0C
5D27075C27075825075724065829085427065422054719043C1702381101311102341303
351502371603361803371502341501311301341101370D013711033F15034319044C1B06
55270A5F351066391265330E62300E6033106B3D147145196F451970451974471A724619
684116653F136139116038106239125F3D14623D145E3E145A3D155633104E2B0F4A2109
4621084621094521074C23084A230A4C230A47240B4B270C4F2A0E50320E53300D522D0D
562B0C5C2F0D6839116D441877592377692F79783A808740868640878740878640848540
8A82408683408284407E81407D7F387C7D387C7B38807936807934806B2D805F267A591F
72511B6C4B176C48156741146043156743136943146A42136F4814734D18734D18734917
754B1879531A7B511B78561D795C1E795A218460208560208D67218D6F258C7729888131
858A3A839141819741809A45809B49849D4681964B7C984E739D56669C5A69985A68975A
6A9151758F438075357E5B1E75431066390B5D2E0A5E310C653D0E6748156C511D716029
74713571844073904573944A78944B7A96487B94427A913E798D3A7B913D799740759942
6F9949689D4F639D51639B4F6593486A8841697A38686F2E625F25534B1C483211381C08
2B1203220C011D07001C07001B09001806001806001C04001D05001806001B05001B0600
1804001603000F03000C0100080000080000050000010000000000010000000000000000
0000000000000000000100000100000100000100000100000100000500000900000A0200
080300070100020100000000
030000030000020000010000010000040201050201070100090200070100090200050100
0901000802000601000602000601000601000802000803010804010B05020C07010C0401
0A04010A05010D04011005000F0602100803100903110703130904100602120901140A02
160C051A141014192510182810111D0B083F06065904078C0F17831C2774202D60222967
262A712A2B802B328A21398E1636861E437B26496E2C4B6F314B7D3F4E7349526D283293
0C1AA80B18930C1781060E9B0005AF0616AB19339113339614309A1E218D2C2373212A7C
0B278C0C23911C1C8E1A2996062C970A289C23239732377D19327A112E851E23932B2D8C
161E86102F8524307C2F42671427831B31882F3F76212D7815308A2429952F379122348E
3138683734592530712B32863F346B312E7433387C463F6636367026348A372377231A8F
1E229E381E872C218C1F2A9F331B8E2F28842337822F2D8D454078344C80324A823F4B7E
4E5C765A596B50596A4D556E583F6862496661776160805B5E805D5F806061805F638063
5C80636480645C806859766D48637A5680666F80497B7740787139766130725D2B69552A
614E2661411C5B3413592F105D2F0F623B1669441A6A4D20685828654B2061461B623F19
5A38154C230B401C06411A07421B04411E04451C054B220A54301067441A6F5623735A29
6D55256C582C61603A5F55316045205E4019603E1468491E6B55276F54257C592480672C
827234847936857834857938877A3B847136806B2D7B692E82632782692D867838838040
8170317D652A7C5F277D5622744D1D6F44186A42156D3812683A1363330D5F2C0B5E2909
6028075F29075A27095426075628075124054A2204451B06381704351200321200321202
331102341002351303351402341301321100360E01341001330F023511023A1603441C04
5124085C3110623B156737125D2F0D5E2F0F683A116C42177143187344187149186D4014
62361257330F582A0C572C0B57300D59320E5C39115D3C11593A145632104D290E48210A
46230A4622084723094A260848240A4721094B240C4F2B0C51310E55350E58350F5A360E
613B126B4315734D1D795F2976733C708141718946738A48788D4D798B4B788B4D76894C
7A864878844C7A84487984467F87407F864081853C80813B7C7A387A6C2D7D5B2474531E
6F4A1B6541145E39135A320E542C0B59300D5E360F623B11633710653A0F664214664416
6B45166D46176C42126D45157349187C521A7E5A1A85621F8D6B249171268E792B898030
8B8536888A40898E428493417F95458296448096487A974B74994E74985372924D768F48
777B40766329744E196D4713694010633B0C62360C683B106E4F18736429767538787F40
798842778F437891427A9442779945729B4C739A4B729649709549719645769440759240
7094416895485E98515796555A9359588E525F8848647F3D626A2B59521E4A3A1441250B
301605290D02240A00200A001F09001C09001B0A001C07001B0700180500170300100300
1003000F02000E02000B0300090100060000030000000000000000010000010000000000
010000010000010000010000010000010000020000020000030000040000060200090200
0B0200090200040100010000
030000030000020000010000030100030100050100060000090000070100080100060100
0501000601000700000501000400000601000602000804010803010905020D06010C0601
0A03010902010803000A02000C06020B07020E06020F0602100601100802100703120802
1208021E1512192233131E2E0101A80B08410B0C3E02047401027E0107AE06288A0C377F
143C801C3991243E8A233E84223E812D44773849703E506C4056714058703F5C6F182EA0
0A1AA10D2379103367061B8900099C172A991F35921A349A1428A41A1CA02D278D28378B
0E2D960F2B981E2598212D97132D94102C9A1F28982D34861E2E8416308F1D26932B258E
171B8A112F7D1E2B79292E581A2962172E812A34672937641D377F282F8F32398C253588
292E772E347425308A252B97362C89302E86353E7B4E4A653834782B3B78392B63292481
242E8B36296C2F267A2328992C1A932E238D24368B312C8E47407E354581374481434178
46556F4A586E4F5972543F7365346462536C5C706C61756063805B5B80655F806467805B
5C8064648061617F6359756D446C7C5380697080467E763C786C3575602E725F2C6D562C
654F2963431E5F3615613614623312693F186C461C6B4F20685425685122654D2263461B
5C3E1653260A441C06441D05451F07421D054119063E18044920075B2E0F6B4219705726
725B26735E2C6A5B336050295B441E5C39145B3611643F166B4A206D4B1F764F1E805E26
7D6A2F80753486763285803C84803B82753782682C816126835A23805D2483753581803C
80703179662C7B56237C541F755220724B1A6C401566340E64330C622B0A5D25085B2A09
5A2A085E2B085B29085327075225074D20054A1B023F1B053A1604371001341100381002
370E01370F01331001311002331001340F01340E002E0D002C0D012E10013212013F1602
441A0450250A60320F5E2B0E5F2B0C612D0C6435116A3D136B3E15683C14683C1260300E
55260A4922094820074B22084E2309552608562F0B5B370E593812542E0E50270B492409
48210A48210947230848280847250A45250C49250B4F280C572F0D5C37105E3C10634114
68481575501E7A6025796F367180406B83496C894A708951698A546A8B586E89546D8952
6D88516B8A556B8C53708A4C788B487C8B407E8A407E873B7D7C357E67267A581F755620
724C1C6842165A37144B2D0F481E094D270A562E0D562D0D542A0951290955300B5A340F
5A3910613E12633E126642126C46156E4B187A5A1C7F6321876B238F71268D762B8F7B2F
8E84358F883B8E893C8B8A40838E40848E40828E40808D40848E40858D4081833C7D6C2A
744D18673C0E60320A643A0C663B0C6B3F0F6D451672531C76662A7A7D38788F40729249
71924F72945274984B7597437196436B984A6E994A709A48699745709542719140768F3C
718E3D6990455B924F51935A4F92605292585F8D4A66823D626F2B5A551F4C4115412D10
341D082E1202260B001D09001B08001B08001A07001908001A0700160500130400110200
0C01000C02000B0200070200040000020000010000010000010000020000000000000000
0000000100000000000000000200000200000300000400000400000500000502000A0200
0C0300090300060200030000
010000000000010000020000030000070000060000060000070000080200090100080100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0000000100000300000401000700000800000800000600000803000902000A0200090200
0702000701000500000800000701000801000A01010B04010F0803140904140703130902
0F06030E05020B04010D04010A05010D04010E04010B03000C03000E05011004010D0601
0D0500120803131B1A181F24191B4806076D03057E0204940102AB0005940009A102109C
0A18881422931326891D3B891D428E1A4B8F165392145494125296073AA808329706258E
031690021584021B8E0112A10B298B1432981F36991E3C9013368F132F86242D81232981
12218112318E152B98272D8023296E142786152C9827318824338B1D338D1D2C8A2A2E7C
24338A122EA219239E2A2F8F1F3899132B9E272B9531418D2138841F2D8A30377E283979
23357E2E37792B33792B3B6A3D445D3B3E6632416A3739812E3E78263E793B3675362E70
242F7B38347C49415C2B2E64342B60392A6F282E82342A8F45397F3139843C388048436E
3755693A5F6F485E70624E574F3761414A7046507559496865775C6680596F8052748156
66805963835B63845D61806050776F54806A64805B79764580703B7B602E72562C6E542A
6A512A6A512962482161441F61431C694A1E694F206858276A5E2B6D642F6D69346A6A34
66592B5B2A0D4B1B054A1E044B20054C2005451D054218014618014A1F055E280B6F3916
744A20775D2A6D54256B491E653E195E35115E300F6936136B42196F461D77501F78521E
7955227D662982672C8176388073357D662A7E5E27805A227B4C1C7647177E562181652B
8471338172347C5622714719663A1065320C653410642C0A5F2909632908632C0B5D2C0A
5F2F0D62320E622E0E5926085725075224084C2209421C053D18033B12023813013C1504
4017054019053B1903401A02391400321000320D00360E013512023916033B14023C1401
4112014716034B19024A1A014916044619054B1F0952290C522A0C562A0D55260A521E08
4B1E07461D05481D05481E04471E044821054C20064F220950270B4C280D4B290C4F2E0D
4B3210463311482D0F4D2B0E49270D482A0D4A2B0B4E2F0F5135125B3C11623F13654416
6B4A177A5C227A743A7A814078824173844574874874854B728651738752718850678855
648F586093596096576797546F965073954C7896497B8F467D8B43818740857F3482732C
7D642570511C643E1357300D4B280B4C2609472B0B4B2B0D442A0B452509451F053F1E04
3F20074A25084C2A09552A0B542E0B542C0B5D2E0C61330D6E3B10784712805117845A1C
86601F8B65218A631F885E1E855B1D865A1C815B1C805B1E7F591C7E5318774A15703F10
6A350D68370A66360A6D3B0C7245117E60227E894072964D6D9B566D9B5A6B9D5E71A158
75A352769E507A9F4A7D9C447A9640758F3D73893970813173772B736E26746F24777026
75722773772A7284316B8B3B5F91445D954B5A95475A95485B8B415E793554642C4A4F23
403213351B06281101210B001B08001606001005000E02000F01000E01000F02000C0300
090200050000030000030000030000020000020000000000000000000000010000000000
020000040000030000030000040100050100070200070200070100070100060100070200
060200070200040100010000
0200000301000701000601000701000702000801000801000903000903000B03000C0300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0300000502000801000803010905000C04000C04000C04010B05010B05010C06000C0400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0301000401000801000803010B05010B05020E06020E05020F07020D05010C04000C0500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0301000401000502000702020A05020A05030D06020E07020B06020D06020B04020B0500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0301000301000402010704020805020A06020B06030B05030A05020B05020A04010E0400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0301000402010503010804020D07030C06020B06020A05010904010A04010B05020B0601
0D04020C05010D05020E06020F07020E07010F05010E05010E05000E05000F06020D0602
0E05010D04010E04001005010F06011007021108020E07020D05010903010A0300090200
0902000A02000C03000E02001B100C1B202913294E11217B0D0BA40909AF0409B40208B5
0105B80001920000A70000C20001C10001C20000C10000B90000AC0000A00009A8042CA5
10369D183C9B153F9C153E9C1E3E9624498C254D7A2249792A4983304B80304B7D264685
26448C2D43862B478426467D28417C283C831E397D1F368528368B2C3D7A233C73253981
2D378C313A8B31428A313E88363E84313F7F2B3E833137863642753341633440793F4865
37447034487E3E44763A3980383888423C7A3D437834388335398837417F333C6B44476C
474B663F445E4944623B3363373178493D713E357A382E85472C70352E7C3E347F47366F
33306C42337B484758324A6C3B527F515A724F50694D49795248744B71724E7E6A6F8055
77874F7F83458480418580418580418380428280417E80447480486F8047658044647440
6F5F2E715727735929705C2B72612D725D296D5E2C685D35645A3B634F285F3E1B50280D
4019043D16043B13023D10013C11043A14053B18043E19043E15044416044315044B1B04
511F065E280B68340F6C3A12693D17683B1766341068361068340E6A320A6F3610753B11
7748187653207A57237A59237D511D7D541E74431767360F64330F65350E6C3D11714012
6E42156E40146B370E6A36116D3A116E371069320C622F0B622C095D300B612E0B66310C
66300B5D29095625074E2004501F044D1B034219043B1A033A19013718023F1602401505
3F15043913013513003B13003811003511003210002D0C00310E003512033912043A1804
3E14024612024618024416033D13034617054617074B20074E24094C270B512A0C4F2D0B
4F2D0C4B2C0C512C0B522A0C532E0D582E0D553010552A0D4F2C0D52280B5024094A1D07
441A07461706451F064723074B25084B290A4D290B502F0D51300F5933105F43156A613A
55765846816A4F7B6F496B794C886D538F6A568C64618C5D6A8C566D8E5778924E79974C
7297526B95565E905D6490546E954D728F467A89457C8E447D8C437E89407A8740738A40
718F40748E4076863B767A3379662873561D6F4E17674014623A125E38105D360F552C0F
4C260C4E270C4E280E502C0E50290C4D270B4C220B4C240B52250B5124084E2206471E05
471D02461C024218004419004418004D1C005422035A29036433086F3B0B703C117A511D
7E803B6E93535A9C6455A06C56A06A59A1685FA56065A45B66A15767994A70954474913E
7784327371266F67266D6A256F6C296F732B717E2F738B37759A4073A34A6AAD5160B25A
60B05963AB5363A84E65A54B61A85059AC5B4CAA6445A6683EA36E3FA26B4A985B4D8040
45552430230C1508020E03000D02000E04000E04001002001202001305001301000C0100
0B03000B0100050000050000040000060000040100030000000000000000000000000000
000000000000000000020000030000050100070000080100080200060200050100040100
040100050000050000010000
0302000402000602000905000D06020E07030E06010E05000A02010A04020D08020E0602
0E06020D05020F0802100803100A020E06020B04020C04000E05000D05000F05010D0401
1006010D07010E06011107021007011008020E07020C06030A0501090300080400070200
0901000901000C02000D04001608041C100E21161D2B1C30321D482A235C162A660C2575
08198402098F0002AD0000B40000C20000C10000C10000C00001C00002C00313B20836A0
123A991B3F9B19409519428C1E45862A4F7F2B4F76284E7B29507B2E4F81325183295088
29498A2D45862C4B85264C8127497B294775254174253E7E263C872D3B7A2B3C7C253979
24328C323A8C2E418A292F902C358A323C7F2D3B853636833A426F39435D3D4E66454F61
3E44673847733B41803F427F3A3885423D8347497438417B393A843D3F7C3538703D4070
41426E3942603F426D444161403E6953496A48366C4035784A2E643C307B3E32824D3765
3331743E2E83423D713344823C4884425D7E455D7546467E4F4B76496C795680696D8055
7B894F8487488187487F83498380438780408480408180407E80407976406F7840697240
6F5F307452247250226F53237257257256257157256D4A1E673A175F321052290B49210A
4118043E18053F18044113023F15063C15043F14023D1903441804441B04431B03471A03
4D21065C270A67300D6F351069391367371265341066361069360E6C340F723B11743A12
713E1472481A79501D78521E7B4E1B7B4F1B72481A6D3F156B361066350D6A360F6B3E11
7244176F461769360E68340E69371065320D612E0A5F2A09632909632D0867300C65300D
672E0C592606511F044D1B03491B034718034217043A18033B17043D16043B15033A1403
3A1303361202381302341403330F00310F00320D00320B01340E033612043D15043C1704
3E14043F16024015024613033E1203451605431B08451C07481E094C220B4E270C4D260B
4C270B4D260953280954260A562A0B562C0B532D0E4F2A0D502B0C4F28094D2108421D05
3E1205391103381505431C044820054721064D1D054E250A4D2909522A0D5D37156B5731
58764F4A82674D776F48657B4583754F8C6D4D876D5A8C6563895E688A5B74905275974D
74934E6B8E525C8862618A566B934F7390487B8B42828B43838C40828B407E8A40798A40
748E41728D40748B3A757F327868287058206D4D196C4417684313653E14613C125A2F0C
50240C49240B49280D4C290D4B260C4A220A46200A4A220851220A4D2208491E05431C02
401B02451E02431A01421801421500421900481C035225045E2D086A3B0D744E1A797031
768F4C64985F569E6C52A26E5AA3695FA66167A5596EA55273A151739E487A98407C913C
7B8B35787C2D72752C717A2E73772E717B2E6F843472943B71A2496AA85560AC5C58AF62
5AAE615BAE5E5AAF585BAE5557B05752B05E4AAF6842A96F37A77433A9753E9F634D8240
454F1F2C1E0A1407010C01000C02000A03000F03000C03000D02001202000E0200070100
0C0000070000060000060000060000040000020000010000010000000000010000010000
000000000000000000000000020000050100050200090100070100060200070200070300
070200070100070000030000
0502000502000604000A04000B06010D06020C05010B03000B03000C05010F07020F0802
0D05020D05010D05010D07020F07020C07010E05000C0701100701100502120702110802
1207020F09021106011105031007011008021106020C05020B04020904000A0401090401
0A04000C04000F0600110500100500100601160703190A061F100B1C262C1130410B2D5F
071D7E020CA00003B80001A60000C00000BF0000C00102BC0205B60006B80D379B113D96
163D961C3D991E41901B448A1D457D294C7F2A50802A52792855792E5C80335F8134597F
2F53843051832E51822853842953852A4B8129497C2744822541892C3C852C3E7C25377C
233A8E2C3D8F2D3E8B253889283784333C81333A883433833C3D7D383B6B3B436B424B6E
4148603842683B427E44487C38457B454278494B693940713C38823F3B7C3534813A3987
40457838436D4744754F4F554645604F48604D3F5E4D455857464E433C683C2A8A492F76
312B883D31883E3D7E3140883F4185405A7F3F637C495473495379435F7A4F6F7068875D
788C5283884982894782854681804186804088803C88783982753A7E6E36766C39706938
6A5A2E6C4922693E166942196C44186B471B69401861301056290B50240A4E240A4B2008
461F05441B04461D04461903411404401304401703401803431704451803421A05471B05
4D1F0756250A66310E6633106A360F652F0F6532106A350E69310D6F360F7139116B3410
65330D6A3D137044166F47187346177046186B43186B401666340D5E330C64350C66350D
71411671431766360E63300B63320C622D0A622A0965290C69300D66350E67330D65310D
5A2A095621064A1D05491701461903481702471903421B03411A033A15043612043A1204
3610033310023610013810023712013212002F0F00310C00360E003715023B1704401805
4216043C18023B15023B1404421906401B06431C084A1F084A20094924084C270C49220A
4824084A23084F22075021075224085024094D260B4A250B4F290C4E250A4B1F07451A06
381405301104331504401A05441E05451D06441B06491F084725094B280C582F0F6A4D25
5E6D4A4F816352736E496379467B79507F724D7A735680705C836A6188646E9057719550
6F8E4E6A89525C846160885A6D8F4F7195497592457D8C4483894286884084873B80863A
79873977873774863773843476772F7166276F531E6A4917684418664016633C14592D0E
4A260A46220946200A47230A44220A46210A4723084F250B4B240A471F08451C06441A03
3D17023D16033E16033F16014016003D1701411701431D0256240668350F735A22738542
659256599967519E7150A46E5BA76461A85B6DA75670A65073A24B789F457A9A407C953B
7D8C357B86307A8835748D3B728B3B758B3C7392406F9C456AA85262AF5A5BAF6354B168
4FB16A4CB26852B76057B65C54B65B50B55D4FAF6348A66B41A56C3DA96A449E5B4D803D
42481B251A091006000A01000801000D03000E04001104001203001102000F02000A0100
080000080000060000040000070000040000020000010000010000010000010000000000
000000000000000000000000020000040000040100070100060100050100060200070300
080400080300090200060200
19110A140E07130B050E07030F05030D05020C05010A05000D04010C0802120904110702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252E232E2819271D0E21140A1F10081A0F05190D04170C04130904140B05150C05120A01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295D6C3D5B574850494B424047393740352F3B3226332A1B2B200F23160B1C1108190D06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1144932245842F3F80383B79433B6E453E6A454A5E45534D4D513B48462E413623352B1A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0414AD0711950A10941317921F1E902F2D8A2A3F832E55753F60684D5E6050545A4D4C52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0000B700009300017F00058E080EB50814B40C379E174F892A557C3B5476454D75424771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0000940000880001880001C00004C00008BB0521910C2B851A3284343D7C393A7D32397C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0000B00000B00000B50000C20001C20003BF020A8403097C070E8B1E2C8D23388E234088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0000C30000C40000AC0000AF0000B70000C200008100006B000F8507259E1735891D3382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0000C200009300009300009400009F0000C100009F00037600097F0311820D1B7B1A257E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0005BE0003B80002B90000A50000940000C00000BF000294000383000377040A710C1C89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0118A0000EA100089C00029500009D0000C10000C20000A100008500017900066E001285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08319F05259B03149F0103A60000B20000C20000C20000AF00009A00018A000485071486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304F752547841C36971320A50000C20000C20000C10000C10000C10000AF000086020496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3F56493F58523D596132546C0206BD0002BF0000C10000C10000C10000B600007F00017F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2B4D4F304F4A36514B2B3E7C070EB20307BC0001C10000C20000C20000A200009100019C
0002AF010BB70419AD14399719409B1A429619468E18468516427E193E831C3E8A20468E
1F47911C468E1D508D23558D2B5E8B2D62872C63842F697F386A7A4463724B5F6D49576C
4A5A7048656B3F6E6A406C6E446C6753715456734B5A784B648041677940638042678040
6E793B6E733B69733C64754060754463744562734C61744E5C724D5B6E4C586B47596A48
54714B53724E59725360705B60645C635860635365604F6961565F63634E65724B69724E
6B7250627E5F5C80646C804F6E67405F61405C69425E71405F734058734059623A5C3F1D
512A0F47200B44200945250A47200946200B46210B49260C4D2D1253391A544423534E30
4E5B404D6648506E5154745357765B5F715C6375536A77496F72406C643262572D62522A
5B542C5D542B605E345C6D405A724B556D56516C5D506E5C506F5C4C6D5B566E4E5E7347
697643707F427380417080466C80496D804B6580576480585E82596A84526A88527A8043
8480408580408580407F80407F80407D80407D783C7A723B7764367258326E512F6B4C26
714D1E70481C7341176939156233105E34106035105F350F62300D62300C632D0E56280A
551F084C1C05441701431301441502401704431B053F1C04401802401703441702451403
481E034A22044D23074B23084F20075022085323075722065925065828085D28065D2705
602908612B0A5C2D0A5A27075922065723045A27045F2606602D075B2906582505572705
5828085E2F0B5F300966340B623009612B075929075A2B0B5A2B0B5B2D0B612E09612C08
5C2A095B2B085A2D0B5A2A095628075127074C24074B21074D1B064A1804461D05481E06
491D02401B03401C034219023F13013C15053F18053E16043F14024117033E1504401704
4215033E14024011003C15013D12033D10033E1904481D054F250754250757280B592D0D
572E0D55300E542A0A4C20074A1706421805431A05431B06461F08481F084B240849280B
512A0D54300D582F1057340F57371251311051310F52330E533811513A12523A15533C16
553E13583F135C41145F41146240126A41146E4917724E1877511C7C58237A6532777640
6E8447658A4E5F8C50618B4C61894B628747688744708440738040747838737032756229
6F531E6747186142165B371250290D441F073A16033415012E13012E0F01290C01210900
1B07001A06001B05001E0900260C012F0F023314023814053717073B1907371706341505
2E1204260F03210C01210800210800200A001F09012209011D0800210700220C00260D00
2A11023319053D240740270C42260A3A23093E260A433010443E16464B1C4B4C1D4F5021
525B274E622C515D274D4F1D49401744391445391242340F3927093220082B1605261205
200F031E09011906001806001706001508011407001205001004000F02000D02000D0200
050000060000020000020000020000010000010000010000050000070000050000070100
0801000A02000D02000E03000B0200070100040000030000020000020000030000040000
020000020000000000000000010000010000010000010100010000000000000000000000
000000000000000000000000
1E4663224C57324B5033445F1B2F8D101EA40307BC0101B50000C20000C10000C10000C1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1E3D731E4961294A4D2F4A4C2A5063203C860811B40101A60000C20000C10000C10000C1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22337F20436B244B54294E482D574D2B516E0F1CAB0101B80000C20000C20000C20000C2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253672213C6E25455C244F4E2B524A2F50570E22A8050FB60102C00000C10000C20000C2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2139661F3174264060244A52284B472D535E20487D0E25A30205BD0001C00000C20000C2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213D4F1D365D233C51243F4E294047324F452C575B18368E040BB60105BA0001B90000C3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253C381C3945223A42243B482C3C43324842355251233D7B0D2096081D880002A9000099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293828253A34233C38253B3F2B3D433242453B4D4A2D42691731770001BD041088010375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2C38222B3B27263C2E273D352B3C3B353E3C3B4B442E45611D3C690102BA0B1D7903087F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2C38202A341E2938242B39292B3931333E3237493F2D4858061BAB0102BD08128D030881
010586000E971A20931D1F98231B932B25902F2B902D3B7425424F16345D102E84112697
171CA221119A2D1A81231C851A23A31D30A1122BA0113A9F1130991C2D9C25269029289A
2A349C23469A2157922A648535647E3E55834A3D7C4D3B774C4A7851596E5953665B635B
60744F6480496A80437377407272407072407078406F804066804865794B68804C697B4B
6A7E4B6B74546A78526C7E4F758047787F43737D41768040778040797240776D40756939
75612E7350216E491F664A20644C22644E26654E27644F29624822623F1A6039175C2F0F
51270A4A250A4F270C50240B52250B52280A55280C52270D50250C54240952260C52280D
552A0D55270C51270B50240A4C240A51230A4F21084A1D04482106492105471E07482005
4F22075E2B0A64330D6C361376471D745D2E7665377366396D5D2F64572C665425684F25
6A4C1F674C20655226645B2B6865306C743C6A7B416D72376D6F346F7A3C6F81426F8447
708347747D3D7557237141196E41176C43176C491B704A1A6B45176843186D41156F3E16
683712602C0C5D2C0C5C310F6538126A3C1460320E5F2E0C5D2A0A61290A5E2706572104
5020024D1D024C19034D20034D1F02482003491E03471902471A02441903431905451A05
4A1F064D1D074B1B065320075022065122074F20075124085127084F2206511F08552007
511E054E1E035522035923065B2707592A085B2A095B2E0B5E2C0B5F2609592506552807
5C2C065A2D065A29075D28065929045E2D075E2E0A5C290959290A5829085E28095E2808
5622055122044D23064C21044B20034E20034C20054C21054D24034B23054C2304451D04
3F19033F1A023E19043E14033E14023A1402431602441704411A03441A03471D04451B02
451904481904481A054C1E084B1F0746200A47220B47270B4B2B0D4C2D0E442A0E472A0D
45250B3D1F083D1C083317063214052E12052D1005301305321805341606381D09371D0A
391D08391D08371C083115042D14042913042915042D13062E15042F15042E15052D1706
3319063818043A1D063D1B043E1D0741240A49290C4A290A3D290A40240A4025083D2309
3D250A3D23073B20063E2106411E053F21053D20054224063C1F043116022A0F02250A00
1D08001A05001A09001C09001C0B001D0A001C0D002310002711012F13012D1302291001
230D00260C01220A012108011D07001B07001905001504001401001702001A0500200800
1F08001C07001707001604001404001404001703001505001A05001C07001C05001D0800
2008002007001D0A001F0A001E0C01210F02231002250F01230B012511012A14012B1402
2A1402271303220E011E0B021D09011B09011C0A02210F04200F041D0D02190B01190C00
1706001305001206011108011007010E04010B05001007011006011106001205000E0600
0D03000A01000801000501000400000500000601000702000601000701000601000A0000
0C04000F04000F05000C0200080100030000000000010000010000010000000000020000
020000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2838222A341D2D341C2C36222B3A2F30403335483D13398B0720A70101C00206B10102AA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2A3D2F2A3C282C3D252B402B29423A2C463C264866153A800C2786081287040AA30000BC
000CBF062CA91329971A269A1C189C2A208E31278631347424346B101C7E122A8512318E
122C9516229C1E15922717982F2887212C8C1225A51838901736891D348F21289027259C
2F2D972D3D932549922251912861863469814368794C6E71496B704660734558744F6E64
58755560804E6980466D8041757440777340787F40757F40757A40738040737C40727D41
728041708046748048747E47767545747C417680407A80407B73407972407A71407A6631
7658256F5022684C22674B21654A2162421B6138155D31105A2F0F582B0C562B0C4F270B
4D240B4B250B4C240A4C24094A23084C21094C26085021094F25065224095025094F2308
4B24084C24074822074F1D074F1E044921044C20044B20064F1B044D1F045120034F1D06
501B04511F045423075B280C64341071451B724E207154256D491E6A431A67441B64431C
673E16653C1564431B6A4A206654296B64326A6B3A6F68346E6E346F753A72793976803C
778040787C3B7C632C7652206F4C1B704A1C6E4C1F6F4C1B6E4517673A1463330F622F0C
62341064350F6734106A35136B3A10693A1164330F612F0C5E2B075F26075E29085B2708
5926075626085027085425085424055024034F1F054D20064E22064F2305512105542205
5023065422075322065225055126095123084F240952240A522408532208582808582709
592005531D025321025125024E24064D2106512206502305532105562406552206572105
5B25035B26065927065A2709572507552106532207531D03521B01501C02501A034E1A02
4B1703451B02411B014219003E19013F18014216003F16004116014217013C15023E1701
3D17023D19023A17033D16033C13033D13023F13013E15013916013D1602401604411906
421B07471C05472007471C073F1903401803411F064723084D28094B260945230B44240A
43230947250845220A3E1C073816053215063213063116052F15042C1303301404321504
3318042C17052D17062C15053019053216052E18062F1707301B07311B07311C08361E07
3822093B250A3F250844270B47290C492A0A4B26094F29084C2708452708492C0B432C0B
41290A3C2209371E05331B03311902331904321505341703361404321503321202301302
2D1001280E01260E02251002291101280F012711012811002A14012E15023216022D1400
270E01210A011D06001D07001F07011A08011907011C06001906001B02001703001A0500
1A08001E0A021C0C011B0A011B07021805001204000C03000E0300110000100000120100
1601001B04001B05001F09001B09001B08001A08001B0B001A09001B09001C08001B0800
1A0A001C09001D09001E09001A09011709011708011408001608001508011408011B0902
1A07011504001402001202010E03010A02000902000901000700000A00000B0200110300
0C0200080100050000040100020100030000030000020000020000050000050000070000
0A03000B04000D03000E03000B05000C0400090400060000020000020000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2A42422D47382C4B322C4D39294D422D4C4229446A18377415355F15335309197D0101B0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2942512C50432B563F2F57422E56423B51482B3E6F1A356E183F5B18435A0C1E56020B85
02229B09348C122A7A15258917179A241F8F2921881A149E1F2595202995192E9D18339C
102CA00F2BA01A199326178C2B1E6F24286A2531632A3E552A45541E3A6F1D268C282095
372A9233388A273588213E8F254D8F2954893462833F687D4371754A806B4A81644F7C61
5B7A556C7E47708044757F407A7B407A7B407B78407C80407C7D407D7C407A7D40767D43
758045717E486F7E46707E44717D44777F407C7E407A71407A7340797440797340796D37
76642E6E5D2D66562D65441E5F341058270B4F27084F26095026094E260A4C270A4C2709
4A250A45240A4A20094923094C220A492108491B06481B03461804441904431804461703
4019034019043E18034317043F1603401A03471D074C2006542507562406552207502006
4F1F04491E034D1B02541E085A260B6835146F4316734B1E775021704B1B6B4A1F654A21
64411A62401768491C6A56266A5D2C6A6A366D6F366B70396C79406E804070793E737338
777133776B2F745C24745622724F1D72441875451A71481B7248187046196E4517723F13
73411671451871461A6C481B6C411265360E632F0A612B065F2A055A2906592A075A2807
5625075024064E22064F1F06522304552504522606522407502105582305592B065D2C0B
5E2E0A5B2A085729095026074C24064F23075224084E21065123075924085A2809572B06
562909552907562907572707572B08572B085926065325065120044F1D03491D034B1E02
4F1F025720025821014E20044D20044F22034B20054D1A024519023E15013F1101391201
3E1401421700411701461801471C01401902411300370F00380E01340F01350F003B1300
4217014517033C15023714033917023D16033F1F053F1B043D18043C14023C13033A1303
4013033F14023F1703431A034217024016013E1E033F1C043D1C03431D03491C06461E05
451D064522074921094621093F25093D1D093A1D09351D063317042F1405271103281103
2810042313052715062B1A072E19062B18072519072614062813062B18062C1A07301F0A
36240B37270A3D280A422B0D472A0C4A2A0F472A0E48280B4B2F0C4C310D4F340F4F320D
47300C46250B3D1E063319032D14042C15052A11032B11012C1201311703331503351A01
371903351B053319052F16042A1102250B00210B001E08001906001A0800210E01210D02
210C011A08001202001200000C02001105001607001906001A06001B06001A0600150700
1705001906011707001806001A04001905001006000E03001002000F02000B0100070100
0703000F02001002001603001907001A05001606011A0600170800170A00180800170800
1707001504001909011D0B011D0B01170A011305001004000E01000D02000C0200100400
1306001505011604001302000E03000B0000070000050000070100090200090200070100
060000040000020000020000040100050100040200030100040100050000050100060000
050100090100070100060100080200090200080200080200040200040100010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2D4F472F5745275A482D5A453759403F54492A3B77162C7B102E720E2B7E050C5A05135F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3158412F5D462C5B4A315B423F5C3A41574B2936811320860919890510B4000093091C77
0C2881132C7A152F6C0E29801320921E1D8F231A8521168B291C8B332A7A333B611E2D6F
102484122F89142A8519208B140CA41A1A9F2827861824911633971531961A289D291D90
37228C3A37812A40811E307A1D358E243A95334689314E8D36608342806E52845D5A8056
667C4C708044767D407C7D407E80407E7F407D80407A7740797D407B7D40787D42757C44
747D4A6E7A4C737E47757E437A7D417B7D407B7E407C80407A7D40767D407880407D7540
7A68317256246642185C310F51290D54260B562A0C552C0D53290B4E23095022074D2307
491E07441F07471D07481A06461905441D06441C07411B05411B05441B05441B044B1D04
4821064B23064A1F05491D054920054C220751240950280952290C522A0B4F2A0B4B280A
5027094E23064A1F05542107562908622F0B6B3C1374491C77532475592475512171501E
6E45196C461D6952276B602D6E68336A743D6F753A7073386E784071793D6F703672652F
735B28705320724E1E785222754C1D7146166D3E136F3F16704218744618764919714315
6E41156B41166C3C14693C1464340F5D30095F2D095D2C09602B07612B09602A075C2508
5424075123064F2303511E064F1F054E20054F24065223075122065425075023074B2607
4C23074C24084923064726054E26074C25095125085126055726065626085321074E2307
4F240954250958280A532A0955280A5626085224075122054E24054D2103522204551F04
572206582406572506542306592008571E075220044319034415024113014117013F1702
4218024015013E11014411004314013C14013C12003715003713003A1201401201431802
431A024119043D1504341403340F023211033613023618033919043A1503391403381404
3A15033C1703401605411B05441B04441B064219043A19033D16033E1602461B02482006
442206451E0742210941220A40240B3C220A362109341B093119072B19072314061F1104
1C0E031C0F052012042315062519072615072110071B0C02170C01180B011E0E031D0E04
2212052617062E1E0937230A3A280C3B250D42260B41230741230943250B42290B432B0A
422A0C3F270A3D1E083717052E14022A1002260E01250E01241101261302271502291502
2E1602311903321603291201200C00150700150400150100120100100200120400160700
180A00190B001708001002000800000B00000E0100120100110100130400120300130200
0D02000F03001003001303001404001204001306001704001303001103000F03000C0300
0802000B01000D01001105001706001805001807001C09001D07001E08001A0700150700
1506001607001C0A011F0B02210F011C0C021A0A01170700180500160400130600130600
1107000F04000D02001101000E03000C02000702000700000A01000F0300090300080100
020100040000010000010000010000020000020100010000020000050100060100090200
080100030100020100010000010000020000030000030000040100030100010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
325C452D5F492E5D4D3B5E40445D3A455B492B417B162A820A1D8A0000C30000C30F25A2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305B4C2C5E4D315E4D3D604244623C46604832546E1B3C7D0000C30001C20001C31022A9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2A595E2C5B593162503D6345436442456548365E632247760001C30102C10103BE1223A1
15269E14299A2443691A31640F2E7E0E28931621961D189B2C1E8F3129782A2671282C7F
1E249A162CA217359B1631931D2F921F1E8D261A9227298F273F6A20427419348D20258E
27199735327C395A612B41632540812B358F38428738637F34737C3B80724F80635D8659
658951708049757F44797F407A80407A80407A7C407A8040748041738042747F45788040
777E41787E41797E407977407A7B407B7D3E797C40798040738040758040757540756936
725222693D146031105D2E0D5B2C0C582C0E542B0D522A0C50270B4D24094C23094B2108
4820064920074A21074B1F074A21084920094B2009491E06431F04451E044924084B270B
50280B50250A4C280A50270952290D5327085323075320084B1E054D1E064B1D054E1F05
511F04552506582707582A0A542A095729075F300C673F1673512175622D765E2C755423
724A1F6C42196E4519734F1C77552178632C7A692E78662E7574397A74377C6E317A672F
765B26735523735121744B1C754417704616724616704114714417733E136E3B106C380F
67340B622E095C2B055827065B2A075C26075926075C28095A2C065C2D08612E0A5C2A09
5C25075B23085724065726075A2A0858280658280756280654280A5427094A2408462005
471D07461F06461F054821074C21094F230A5126085322075221064C2005491F044D1B05
481C054C20054C23064D26044E2305471F05431C02441B03451D044E1F044E2102502402
5128044F27044B1E054C1E074A2003491A04471D06421F06431E06481E074A23064C230A
4D2305482408492007421D06441B034019033F1E02451D04421B05421A03432106481F07
411D043F1702371501351201331201330F01380F023914023B16033A1703361203340D02
330C033410023715063515033610042F12033319063A16053915053618043014052C1705
2E14053015073218083018092F180A2E17092B18062D16072A17062C16082414061D1006
1C0D051A09021A07011707001707001208000E06000D03001002000F05000F0500110600
130500140A02190B01201103251906291A0830200A382009391F08371905391704381C04
392005371F08361A063119032C1102230D01210D011F0B001C09001A09001E08001B0700
1D0901251003210F03200C01230B00250D00200E011D0D031E0B021609011405010F0300
0E03001205001206001305000D03000C02000E01000E0100130200130400150500120400
1102001001000D01000D02001005001204001405011A06011C09021B08021B0501150400
1101001401001505011706001707001905001A08001C0B01200C01230B02280D02260E01
1E0B00200B011F0C011D09021D0901180A00180B011A0D02190C02150A01190B001B0D01
170C011408001002000B03000B02001005000F03000C04000A04000E01000E04000C0400
0C03000B04000A04000E0400090200080100080100070300070400070200060200080300
0B05010A0401080200030000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
28507D2A597032635D3B655141674D44645033586C0204C00001C30103BF0205B816248B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22469321528B2C5C7A376264416654436256060FB80205BF0001C30104BF0205BA1B208E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2238952643942C478B3557783F5E641C2F9B0710B80206BF0000C30103C00204BC201D92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202D952B3B872A3A8C2F4D8738517A1826A3080EA7050C8E0816770C248509239928287A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1B2D982A4280232F932C47812B4F7C131EA909099A06097B0D216010366C193681222B72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1C3495294B8A1E2A9C2E52752C5075111DAC0A0B9305088609147E063280133587192A84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1A3A79254981243691334F7A304B77131FA90A0E920406920407A2032C9211398C193381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1A406E28467D2A3C88334A83344A81141FAA090F9405078F042399052F8F1440831A4073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22398429407F2C458831527F2A497E192E820A148903119C0A2E820E41771949711E486F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2D3E8E28478D27508B265188214A7F1B437B0A1985060F730D278014468518406B19426C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2A428A2A4F8F244F8F1C4A8F1C4B7E204E7D0F1F5A0C0F740919A4163E831937731D3C75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2B45822C448B25448F1B408F19447D13286F182A59111B6B101E991E328824318C233B87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324C693246742843821934910F2A6C183265142B690F2176182591252E95282F93253782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39596A375A6B264889132B9A0C2577122E670A2C820E2B931C338F1F3497232C96283C78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3667742A638017429A030B9803097E0922780933850F3787163B851B3A8D1D338F283F74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2D697E1A598F0105BF0104B50004AA0622950830800C3479123B81173D881B3A9024377F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1C57921043920003C30005BF0005BD09229F0E308B10378A19418F183D8F1B4091213B89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0D37A80007C20003C30007BF0007B70D23A215389B1E468F1B448C1B3F8B1F46911E4590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0000C60000C60003C2010AB70110AD102D9D1E468F20498B21468A224788204B8E1F4C8E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0000C60000C6020ABE061EA9082E9E1139921C46871E4B8A214D8A22518722518824518C
2A53842B537F28527D2C537F305981305E7C33617A37647B3E6E7541757145786C49786A
4B776A4F75684F71685170684E71684D70674872694A7564557F585E7C4A607C44617C40
5E714061704062673A616231666330665F2F65613464653B656236625E315F5B305E5329
5E4C225F471E64451B664A1C664E1F61471C5C3917583010522D0F542B0D54280B55260B
4C24094D22094D2509462006461C084722054A1F06441F07431D08421C07422006451F0A
451E094220064324054824094C270A4E280C4A270B4B270B4A240A4B23084B2308472206
4B20084D260A4F290A4E2C09522B0A502F0B512F0C472709452207432008442109412005
3E22054223044725074E26084C2808532B0A4D280A4D26094F2508482308482108492208
431F07401B063C1804361401341101330E023213023718043919053B1B043B1A063C1603
3417023513033113032E12043113053413033914033B15053B17083A1A083C1F09412009
3E1D07411B06401C073A1C063B1C073E19053E18043C18063F1A07381A053A1704371705
3A18053918043917063C18063B1703351402321103331202301502331403341102321202
3913033C1405371504371705331703371502391602341201321102341004331205361403
3012023012012E0D002E0E002D12022C12032D11042F10032E0E022F0E012F1001290901
2A0C02270C012A0A012B0E012E0F002C0E012D0E012C0F022C0E002C10012E1303311403
2F1402300F012F10012F11022E15022F14013215023515013A1A043E1A023919023C1B05
4019023A18023318023012023110022C0C00280A002008001D04001B05001805001A0701
1A08001908001704001603001503001506011A0901180A01190B001A0C02170801150900
1607001506001205001102000E0200120100130500150500170800190901190A031C0B03
1C0D04200F06220F07211006200F051D0C041B0D021C0C031F0C03200C021D0C021C0A01
190B02180B03170B03170E04160D04180D04180C02150A01150A01190C011E0E041B0C04
1F0D021F0A00230C001B08001C0600150600180500150600150600140701170A031A0D03
1C0E03200F032110031F0D021A0B021605000C00000A01000C03000D03000D04000E0200
0E01000E01000F03000E03000F0100120200140400130500170501130500130300120200
0D02000902000701000701000800000A02000C0200070100040000060000040100070100
0901000A02000F02001100001702001C0900230900281302301703351B05371E05371C05
381E07371D053219052610031B0E01140901100A011009001609011C0E021F0F03221503
2617022A14032513031D0D01170C00120700090500050100020000000000010000030000
010000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0000C60000C60411BD0A2DAD0B3E9B1945851D47881F4F8A21588A225A84275E802E6081
2C60812E658034687C3C6C753E6E723F706E44726A4976694F7F6653806058805C59805A
607D55627D565F75565C74555A755859755A53805C5777575E7F4F657B46697B41697B40
657140636C3B63603163562B685629675529635A2D5F5D355F5F365D5F305F5B2E5E5529
5E4F2261471C66431967481B654C22614A205D3E175B3914563712572F1156300E542B0C
52270A4F240A4E2309472307471F07442104441F05441E054123063F1D073F1D05431F07
431D08421F074321074B27094C280B4E280A4C290A4A2708462107451F04422005482309
4D27084F2D0B4F2C0B502D0B522C0D4D2F104B2A0D4A2409432208452309472308461E09
441D08441F0849240A4A24094C25074A27084924084721064822074721084B2108462309
421F053E1C033917033111023010012F0F01301302331603351503381603321304381303
3613043713043213033110043211033311023512023517063417063B19073D1C073B1C06
3C18063F18043A19063C1A063F19073E1C063F1704381603391706391906361605341403
371704361805331503331505351505391503351203301303341303331503361004381403
3B16043A19043A17043315023215023111023311032F0E023211012F1402321403301001
2B10032A0F012C0E012D11022C11022A0E013113022F10032E12022E0F002C10012B0C01
2B0D012D0F002D10002D0D002B0D012A0F012C12023013032F10012F0F012F1302311503
3114022F1200290F002D13033014033115012D14033416003817003D18003F1B023D1C04
3818023317002D11012A1001250C00250C01220D01200B02210B02200C011E0701150801
1A05001A05001805001A06001C07001A09011C09011B0A011C09001A0B01160700150700
1507001706001105001005000E02001102001105011405001407011708021A0D031D0C04
1B0E061F10061D0F051D0E061D0E061D0B031A0A021B0B021C0C011D0C011D0C011A0B00
1A0A01180A03170B031A0D031B0B031A0F041A0F02180D03190B03170A03190C02190B03
1C0E011F0C011E0A011E08001B05001A06001E08001D09001B0A001B0B011C0A011A0C02
1E0B02230E032110032010031F0E03170700100500090000090000090300100300120300
1003001102000F0300100400110400120300130200120400150401170600160700170600
1301000B03000901000902000A03000C03001204001004000A0200070100050200040000
0400000302000601000600000C01001003001607001F0A00220E002511022913022C1504
3216043318033218022815021D0D011609001207000B06000E0700110700150600190B00
1C0D011D0F011E1001190D00140B001306000A0400040300030000000000000000000000
000000000000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
0004AB000AB8061DB60E37A41949941C48911F538D215F882567822E6D7A3370753A7372
3A737141766D4B776353795E5A765B5B75575C76565F775561784F63804C687A476C7E45
6E77416E75406A72406A72446476495F7E4C5C7C4F5E804F5D804D5F7F486A80406B8040
6A7240656535655629654E23654B2266502564562A5E5B2F5F5D33625D2E635B2B635427
634E2461451B65421A63491E644B1D60491F5F431B5D3D1859371457321055311153310E
552B0C51290C4F290C4D270A48240848210845220749250947240A421E083E1906401B07
44200A46200A46200948250A49260A4626094724094A220A441F08422107462307492B0B
4C2C0A4D2E0C4E2B0B502C0D4E300D4C2B0E48290A48260A46260A46220A482009441F0A
441E09462108472308491F08431C06451C06411C05411D07431B06411B06431A063E1D09
3C19053916033613042E10042A0C012D0C022E0E043010042B13032E1303321203341503
3316033015033213043314033311023613023215033716043916053A17053918063A1605
3D14053B17053916043417063816063B17053714053114043415053412052F1306321404
3115043416072E17052F1806321907351705331504331302341102331303321504341704
3513043C19053717043215032D10032E0C012C0A012C0B012F0E023010022F0D02320B02
2D0C00290D022E11032C14022910022C0E002D10012D0E033015052F14042F18022E1403
2D12033311023510023011022C0F012A12023115052F15042F14032C11022B1101310F01
3015032F12022F0D012F14033315032E15032E14042B13013014013316003719033A1B04
3216012E1301280F01250F01200E012309011F0B02230F03230F04200D011F0B011A0700
1907011A0B011D0A001E0900220C01230D01240D02180C01180A00190800170500190601
1806001606001104000E02000E0300110500140502140801150703190B031B0C041C1106
1E11061C10051E11061B0D051A0C05160802140801160A01160B01190C011A0B01180B00
170901170B02140902170902180903190D031C0C03180B03150B02160B02160A01160A02
1A0A02190B011908011907001905001A08001F0A00210A01210B001F0C001C0900180C00
1D09011F0A01220F02240E021F0C011A09011206000F02000800000900000C01000E0400
1103001202001103001005001306011106011304011403001705001907001D0A011D0701
1703001101000E01000F02001006001305001A06001B04001703000C0200090100060100
0300000301000300000500000700000900000C00001102001203001407001A08011F0A01
200D01281002291502250E011D0C001508000D05000A02000B01000A01000B04000D0400
1005001307001408001508001506000E0400090500060200040000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
00069C0014AA072AB0113F9D1E5492235C8C2566852C6F7D367771407A654B79584D7452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0012A40325A00B3CA31E578D2765842D70773573693C715C436E4F4968424B60394B5731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052DA00F4598236187306A75396D603D694E3E6042415A3A41583340522F404826404020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15508627637333665D3860483955363A4B2C384324383F203A3F213C3C1D3B3419372D14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275655315644334C3333422631391D3431162F2A13302913332B1434291331220F311E0C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2D452D2E3C232A331A2B2A14282410271E0D271B0A27190927190B281B0C291A092B1C09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26271426241226200F22190B21160A1F14081F12061E10062111062314072616082D1B08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1F180A1F16091D14091D12061D10051D0F051B0F041C0E031D0F05221207241508291A08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1911061B10071B10051B0F051C0F051C0F041B0E041C0E031E1005241106231308291707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1B0F071911061A0F051B0D041C0F031D10051D12031E12032012042611062815072A1807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1B0F061C12051B12041F11041E11062212052312052211042312042A16072A17062A1908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170F051B10041F1406211407201507241507261505231504231504231306251407281607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1A0E041D0F051F11051F1206211606221206251405231605251506251206251106261406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1B0F051D11041F1204221105231106231106241306281808281608271506251405261206
2A12072B1608311707321A08351A063419073318063118073619073C1C09391B08351807
3516073119063018042F1404271604281203251002230E042312032B11022D1305311604
351305301406351607361806351605331703361704371A05321904311503341704351405
3411043515053413053312033012013013023414033110042E10042C13042E15032C1204
2910042C0D052B1405301304300F032A0E02281104260F042310032811032D12032D1306
2A15032811042911032B1005271106251106251005261006281006261005261106231204
2812062613062714052F12043010032C0E04260F05240F03280E03250902240701210C02
1F0E03230C00260E01270F022811012B0E01290E00280F00210C001E08001D0A001E0900
240B01280B03260E03270C03270A032209002006002005001C0700200700220A001F0B00
220900220A00250800240700220801200A011E0700200600210701230800270901250A03
280B02240C02250B02230902230A03250D042610032512032914053012042E10032C0E01
2A0F012A0D00230B002610022A14022E14033115043212012E14012A11022A11012D0F02
2D0E032C11042F15052D14042E1304301702351805351906351804351D03331A03321704
2F18033115023111023012022D1101260F012110011E0E011C0800180600160500130300
0E03000E0500120900160A011C0B00190A00180B00180B00190900170901180A031B0C02
1C0D021F0C021B0C031A10031D0C021D0C00180C001809001908011507011108000E0900
0F08011208011308011206001506021309021008011005010F06001205000F06000F0600
1107010F07010F06000F06000C04000C03000B01000C01000C02000C05000C06000B0500
0B0400090200060200050100030000030000020000030100030000020000010000040000
0801000903000903000B03000D0400100400120600130801160A021C0E05201506241807
27190A291D0A271F0929200A281D09291D092A1B09281B082A1907281807271705251505
261305251102271504281604291605261505240E03261103260D02200D011C0C01190B00
1809001705001205001307001004000E0300080100030000010000000000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
2011052012042412052513062415082715072B17072A18092D18082B17062917062B1504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23160727150826170828170928180A2B19082A19082B1B082B19072D19052F180A301A09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2718082817072715072816062A17092B17082918082B18082C18062D18082E19082F1A0A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281A0A2818082317082514062817052714042716062914072812062914062B18092C1809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291A0925160A221205201005200E05210D02200F03221204231205241505261306281406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2319082316082011061D1006200C041F0C021E0D021F0E021F1005231205220F05230E04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2216081F12071F10041C0D061C0C041B0D021B0D021D0F021C10042011031E0F021F0C00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1E14071E10051C10051A0D041C0E031A0E041D0D041E0C041D0D03200D031F0C041E0C02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1D0F041C0F031B0D05190E04190E04200F041C0C05180C03170A041C0B041C0B031E0A03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1B0D031C0F061B0E071A0F041B0E052011061D0E051A0B04180A03180A02190A031B0B02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190E051D0F061C10061D10061D10061B0F061C10051A0D03180D021B0B021C0C031D1003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1C10051D0F051D11071D10061C0E061B10061E11051C12031D11041D10041C10051E1005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1D0F041A0F041D0F061C0C041E0E042010041E13061F1406211305201204221305211005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1E0F041B0F051C0E061D10031D10032012051F13072014072112051E1205211206221306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1A0D041A0E051C0E051E0D041F11052213052015052213041F0F04201107201206211204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170B04160C04190C03190E051C0F041C0F041D10041A0D05190E041B0F051D10061D0D05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130A03170B03190C03180B041B0C041A0C031C0B04190C03180A041B0B031D0C041B0A03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170B02190E041B0C04180D03180B03140902150702180A011A0902170802150602150702
120A031208031608031506021706011508011507011507001506011908031C09031A0901
1907011607011808011606011605011505001406001705021B05021B07001E09001D0900
1C0801200B03200A031E0E031E0D021A09011D05011B06011E0B011B0A021A0901190901
1D0B011908011909011607021607011506001304001304011003010C03000F01000E0300
0F01001203001102000E01001203000F03000C0300110200130300120300120400110501
1104001504001709001B0D011B09011B07001D06001C05001E07011C09011C09001A0800
1403001203000F03000C02000A01000E01000D02000F04001306001A07001D07001B0700
1B05001706001D07001D0A001E0E01250E02280D022B10022A11022C16023115012D1401
2C12012E0F00301101331102331500341803351C04351903381704341906381B06361805
371905351A03331A053019033218052E1804271302270D01271001230E02220F01230F02
2310032112061E0F04190D04160D04150C05170C05160E05170E05120C06130B030D0802
0C04010A04000903000602000702000602010803010903000903010904010A05020A0501
0804000802000703000A03000A04010C06010A05000803010B05020B05030B07030A0602
0905010904010904010903020904000B05000B06000A06010B06010B06010A0501080301
060200040200030200040000030000040100070401060200070100060100030000020000
000000000000000000030101040201050201050301040201050201040101030100020000
020000020000010100030100060202080402090603090501080402060301050300040000
010000010000000000000000000000010000010000040201060301080401080302080302
070301060201050100040100020000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
1B0F041C0D031C0B03190A04180902140702130602160701170501130501150602140703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1C0C041D0D05190C04190B02140902140801160700170800150702170802140703140702
1508031909021908021808031B0A031A09051B0B041C0B031B0B021C0A021B0A011B0801
1A06001508001709001607011B06011C08011A0A011A09011D0A031B0C021B0A021A0A01
1F0D03200C03200D021E09021C07011604011202000F0401120602130601140401130300
1205011104001204001502000F01000F01000C01000E0200100300120500140500140401
120501150501150501150400170701180802160B021507021806021A09011D0A021A0901
190A021C0C02190C021F0C021B08001A08001A06001603001202001104000E03000C0300
0902000702000800000600000A01001201001105001406001304001606001B09001D0900
1D09001F0A00210C01250F022B10033014042E13042E12052D14042F11042B10032E1002
2C12022B10022E1201331702311703311502321301371702341903361A043B1E063C1E06
371B053518043017052F1101230C011F09011E09011A0602150802140802140A02110903
1006020E07030D08030C08030C07030D07030E08030E09040E09040D0702090601080301
060100050100050000020000020000020000030100040100040200050200070302060301
050100030000030000040000030000040000030000020000030100040200050300060400
0503000702010602000503010803010803010703000903000B05010D05010A0400080100
060200040000030100030100030000030000030000030000010000010000010000010000
000000000000010000010000020100030201040201040201040201050101050101040100
020100020000000000010000030101060301070402050201050200030000010000000000
000000000000000000000000000000000000010000010100020100020101030101030100
020000020000010000000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
1A0B031A0E03180F04180C04150A02140B01180900190A02180902170B02170801160A03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170A031A0D05170D06170B05150B03130A00140B00190701170B02180902140901140901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140702150803130A03140802140700100500110601140902140903110803130802100801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1005011006020E04010D03000E04000E05010F06011107021208020F05020F07020D0602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0C02000B03000802000A02000A03010A05010D06011108030F06021007020F08030D0602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0901000601000701000802000903010B05010D05020E04021207021006030B05020B0602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0600000401000701000801000804000803000C04011006021006021107020E05010D0401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0201000301000401000800000902000702000B03010D03010E06010E04000F03000D0301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0402000301000500000701000801000702000A02010A02000A02000C04000D05000C0301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0602000801000802000901000701000901000B01000A00000B00000D03000E04000F0501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0902000903000B02000902000600000600000901000901000B03000D03000F0401100502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0B03010B04000C04000A02000A00000A01000B02010D02010F05011106020E0603130802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0F06010E04000C03000C02000C02000B04010C06011106011206011006010F0702120802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1006010E04000F04000F01011003010F05020F06010F06010F06011106010F0601120502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0F05010D03000E04001006010F06010E06020E04010D04010A02010D02000D04000E0400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0C02010F02000D03000C04000D03000C04010A03010A0200070200090200090300090100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0903010A03010A0300090200060200080100070100070000070000080100080000060100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080301080401080201060100060000060000030000050000020000050000060000050100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090200070100060100050000040000040000020000020000020000040000070000070000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0600000500000400000400000400000300000300000300000400000500000701000B0200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0700000600000300000400000301000300000400000600000601000502000B03000E0401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0501000500000500000301000301000400000401000701000704000904000B03000C0500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0402000401000400000301000401000600000701000A04000C04000C05000C06000D0500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0602000501000500000301000400000900000A02000A03000B0400100501100501100600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0603000501000600000700000801000B00000C02000D03000D06011105010F0601110600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0802000803000903000B02000902000A03000C05000C07000E03010E05020F05010C0400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0903010A04010C04010A03010B05000E03000E04000D06000B05000D04000B0400090100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0903010D04010B04010B05000B03010E03000A05000E04000A04000A05000A0200090200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0A06010A05010B04020905010A03010B04000C03000C04000A0500090300090200070300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0905000A05010804000903000903000B04010C05010C0600090400090400070400070200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0803000905010904010804010B03020D05010C0601090501090300080400060300060100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0603000704010806010A05020C06020A06010B0601090400090200070300080100060100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0802010803020905010A07020905010A05020703020802000A02000B0100060100050200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0803010805020904020A05020904010703020802000801000A0300090301080200050200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0903010703010702010703010903010703000902000C02000C03000A0501090200080200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0803000703000702010802010A03000C03010D04000C03000B04010B04010B0401090200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0802000902000901000902000A03011004011004010C04010D05010B03000D03010D0200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0801000C03000B03000A03000904010D05020E06010D06010C03010A02000C02000E0300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0803000D03000E05000D03000D05010D08020F07010C06010E03010A04000A0300090400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0A03000C03000D06000B05000B07010C05010D03000D0201080501080501070300090200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0902000A05000D05000B0501080601070200060101060201060300060400070300060300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080100090200090200080300060100050100050201050200050400060300070200060200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070100060100070200050100030000040100050101060200050300060200060100080100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060100040100030000040000030000050100050100050200050200060100080200070200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050000030000030000030100040100070000050100060100050000080200090200070200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0601000500000400000401000801000802000A01000701000602000901000A02000C0300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0401000401000501000801000902000903000A02010802000A02000A04000C03010C0600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0502000702000903010A02010C03010B05010C06010C04010B04010C05010D04010B0701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0703000A03010C04010C04010D05020E07010D06010D07020D06010C05010E06020E0701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0903020B04020E06010D06020F07021007020D09030E07030E05010D06020F0703100803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0A03020904020C06010D08031008040F0A040E09030D08030E07020D07030C08030F0903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0804010806010C06030F08040F0A040F0A030E08030E08030D08020D0803100802100A03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0802010805010B06030C07010C07020C08020D07030C07030D07040D08030D08030D0903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pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`002P3ooooo000009/00000303oool000X0ooooo`00002K000000`0oooo
000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/00000303oool000X0ooooo`00002K0000
00`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/00000303oool000X0ooooo`00
002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/00000303oool000X0
ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/00000303o
ool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo000009/0
0000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`002P3ooooo
000009/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<0?ooo`00
2P3ooooo000009/00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000V`00000<
0?ooo`002P3ooooo000009/00000303oool000X0ooooo`00002K000000`0oooo000:0?oooaL00000
0P00o`000`000?l0o`000000003o000007l00000303oool000X0oooo4P000005003o0080000000<0
003o0000003o0000o`00001o000000`0oooo000:0?ooo`l000000`00o`07000000030000o`000000
00000080o`00o`00001m000000`0oooo000:0?ooo`/000001000o`0:000000030000o`0000000000
0080000000<0o`00000000000000o`00001j000000`0oooo000:0?ooo`X0000000<00?l000000000
0000300000000`000?l0000000000003000000030?l00000000000000?l00000N@00000<0?ooo`00
2P3oool8000000<00?l03P0000000`000?l0000000000004000000030?l00000000000000?l00000
N000000<0?ooo`002P3oool900000003003o00000000000000d0000000<0003o0000000000001@00
00000`3o000000000000003o000007L00000303oool000X0oooo2@0000000`00o`0000000000000=
000000030000o`000000000000H0000000<0o`00000000000000o`00001f000000`0oooo000:0?oo
o`P0000000<00?l000000000o`003@0000000`000?l000000000000800000080o`00o`00001f0000
00`0oooo000:0?ooo`P0000000<00?l000000000o`003@0000000`000?l000000000000:00000003
0?l00000000000000?l00000L`00000<0?ooo`002P3oool700000005003o00000000000000000000
o`00300000000`000?l000000000000;000000030?l00000000000000?l00000LP00000<0?ooo`00
2P3oool6000000<00?l000@00000003o0000o`000?l02`0000000`000?l000000000003o00000800
0000303oool000X0oooo600000000`000?l000000000003o000008000000303oool000X0oooo6000
00000`000?l000000000000?000000<0o`0000@000000?l0003o0000o`00o`00001Z000000`0oooo
000:0?oooaP0000000<0003o000000000000400000001@3o00000000000000000000o`000?l00000
J`00000<0?ooo`002P3ooolH000000030000o`00000000000140000000<0o`000000003o0000o`00
001/000000`0oooo000:0?oooaL0000000<0003o0000000000004`0000000`3o000000000000003o
000006/00000303oool000X0oooo;00000000`3o000000000?l0003o000006`00000303oool000X0
oooo:`0000001@3o00000000000000000000o`000?l00000J`00000<0?ooo`002P3ooolZ000000<0
o`0000@000000?l0003o0000o`00o`00001Z000000`0oooo000:0?oooaL000001@000?oo000007l0
0000303oool000X0oooo5`0000001@000?l00000000000000000003o0?l00000O`00000<0?ooo`00
2P3ooolH000000030000o`00000000000?l00000P000000<0?ooo`002P3ooolI000000030000o`00
000000000?l00000O`00000<0?ooo`002P3ooolJ000000030000o`00000000000?l00000OP00000<
0?ooo`002P3ooolG000000050000o`0000000000000000000?l0o`00001o000000`0oooo000:0?oo
oaL000001@000?oo000007l00000303oool000X0ooooo`00002K000000`0oooo000:0?ooool00000
V`00000<0?ooo`002P3oooo[0000000300800000000000000:`00000303oool000X0oooojP000000
0`030@000P0000800006000000@00@00X`00000<0?ooo`002P3ooooY0000000500@20@040@000P00
0080000100001000000700400:400000303oool000X0ooooj@00000200<100040081000300000P00
0080008000000`01000010020000108000<00002002R000000`0oooo000:0?ooonP0000000@00P40
00<1000200000`400`0200000`0000000@00004000020040000400<000050P401040008000H00000
00<00@00000000010000V@00000<0?ooo`002P3ooooW00000003004000020@000P0000@00`400P03
0000200200000@000040000200000`4000D20@050@000P001P000004004009P00000303oool000X0
ooooi`0000000`0100000P400080000400<100800`0000P00P000040000100000P0000<100050P40
1@40008000H000001001002H000000`0oooo000:0?ooonL000000P01000200800006008100030@00
104000D200040@0010000P0200001@030000104000<100030@000P0000H000001@01002G000000`0
oooo000:0?ooonX000000P0100000`0200001@4000D2000200@000@00`400P020007000000D00@00
U`00000<0?ooo`002P3oooo/000000800P000P04000010050@000P4000<100030@03008000L00000
0P010003008000040040000000000000004009<00000303oool000X0ooooj`00000010010@000P00
00<00003000200D1000300@1000300000`0000800P0000<00@000000000000001P00000500800004
0000000100000@00004009800000303oool000X0ooooj`0000020080000400<000050@001@4000H1
0@801@4000<0100000<0000200001@00000010010000000000000000000200400004008000030000
0P00000000800@0000<00P00004000000000T000000<0?ooo`002P3ooooZ0000000300<100020000
0P0000801@4000P0104000H200060@001P4000D000050@000`000080008000002P01000010020000
0000000000000005004008h00000303oool000X0ooooj@0000002P0100000P0000<100040@001@40
00D200040@001`8000H10006000200D1000300D2000200000@0000P00@0000H00P0000<000020000
0P00004000000003004000<00`0000<00P00000000000000R`00000<0?ooo`002P3ooooX00000080
0@0000`00P0000<100040@001@8000L3000:104020<100L100050000104000H20003000200800009
0040000200000P0000800001000000000040000200000`0000<0100000D00`000080000100000@00
00<0000300@1000300@000020000000008/00000303oool000X0oooojP0000020040000:00800004
0@001`8000/40@0;1@402P8000L200060P001@4000D000@00P000P01000300000007004000020000
0`4000@0000500001000008000020040000700@000050P00108000@2000400000P000040002;0000
00`0oooo000:0?ooon/0000000P00@00008000040@0020<000X40@0910402P<000L20@801P4000D0
1@000080000200000`4000<00002008000<000000P0100000`030@000@0000@00003008000800`00
0`050P0010040@000`0000800001002:000000`0oooo000:0?ooon/0000000L00@0000<000030@00
1P8000P3000910402@<000801`800P050@000`0200000`0000<0000200<000040040000000000000
000000800@000P030@001@0400000P000080000200000`0000@0104000<0100000<0000300000P02
0029000000`0oooo000:0?ooonP000000P0100002@0000000@000080000200001@4000H200090`00
208000H2000200L1000300D100020000100000<00`0000h00@000000000100000@00008000020@00
0`4000D100040@000P0000<0000100000P0000@100<01@4000D01@0000@000050000100000<00029
000000`0oooo000:0?ooon/0000000d00@000000000200000`0000D100070@00208000P30@080P40
2@<100T200060@00100000800`0000@00@0000000000000000000`0100001`040@001@4000@10003
00000P000040000200000P050@0200H1000500D000050@001P4000H100050000R@00000<0?ooo`00
2P3oooo^000000030080000300001P4000801`8000P0208100P30@080P001`4000D1000400000`00
000000800@0000@00P000040000100000@000P0300001`040@000`000080000100000P0000D00004
00000P0500001P060@001`4000L200060@001000004008P00000303oool000X0ooookP0000020040
000800@0000500001@4000L100070P001`4000H100050@0200@0000400<0000200000P0000800080
0@0000@00P0000<00003000010800P03000010020000100000H00005000200L10080208000@02040
00@1000300000P00R000000<0?ooo`002P3oooo/000000<00@0000H00P0000<000050000100000D0
00070@0200H1000400D0000600001@0000D000800`0000<0100000<0000200000`0300001`040@00
0`0000@0000400001@0000H0000500000P090P0200X2000400T2000500001000008000@000000`01
0002000000<00@00O000000<0?ooo`002P3ooooY000000040040000000000000000000800@000P03
00001@0400000`0000H0000500001P4000801P0000@01P4000D10005000010000P0300000`040000
0P000080000200<0000700H1000500001@0000H0000400001`0000L1000200T2000400/2000<0`00
2@8000H000800`000P010002000000X00@00NP00000<0?ooo`002P3ooooY00000004004000000000
0000000000800@000`0300001P020000100000D100060@001`4000T100801`4000T01P0000H10007
00001`0000D0000200000@000080000300000P0400001@050000100000<0000500001P4000802040
00H02@4000X300090P001@0000@000030002004000030000000100000@0000800@0000<00P000040
000100000P0100000`02000000000000001i000000`0oooo000:0?ooonH0000000@00@0000000000
00000@000`000002004000H00`0000<01P4000P1000700000P080@001P0700001`8000P200080@00
1`4000D100801@0000L00`000080000200000`0000H100070@001P4000<01`4000<02@4000P10008
0@000P05000200<00003008000010000000000<000001P01001k000000`0oooo000:0?ooonH00000
00<00@00000000010000100000001@010000108000D200040@000`0000<0100001801@4000D00007
00001@0000T300080@00208000L1000:0`001`8000@10004000010400080000100000`0000H00005
000200L100<0204000<01`4000P100080@000P0600001@030000100000@0000300000@0000<00000
0P010000100200000@0000400001001k000000`0oooo000:0?ooonH0000000<00@00000000000000
0`0000001@0100001@4000L30@060P00104000800`0000T0100000H100060P001@4000L000070@00
208000P100070P000P080@002@060@001@4000@100050@000P00004000020000100000D1000200L1
000900H000060@001P4000L100060@001`8000P100060000100000801@0000<0100000<000000000
0P000000100100000P0000<100030@02004007/00000303oool000X0ooook00000002P030@001@80
00H30@060P001@4000@100030000100000L100060P0200D0000300L000070P00208000801`4000D0
204000H000060@001`4000<00002008000060040000200000`0000@00005000010000P050@000`04
0@001@4000H1000300H000<01@0000D00P000040000100000P000040000200<00003008000010000
000000P000000P01001a000000`0oooo000:0?ooojL0000000<00@00000000000000>`0000000`02
00000000000000040000000500<100050P001@8000@100050@000`030@002P0600001@0000D00005
0@00204000L100080@00200000L000060@0200P0000300P1000500000`00008010400`0300003@02
0000100000D100050@000`4000@1000500001P0000@0000500001P0000D0000300000P0200001P03
00000P000080000400000`00004007d00000303oool000X0ooooi@00000010010000000000000000
0002004000@0104000<00`4000@200040@000P050@0200@0000@00<000050@001`4000/200080P00
200000H000070@001`0000H0000700001P0000D100070P001@4000@100<00`000`05000020060@00
1@0000H0000600001`4000P100070@001`000P040@000`050@00100000@0000200@0000300<00001
0000000007`00000303oool000X0ooooi@0000000`0100000000000000020040000300<000040@00
104000800`0000H00P0000@100060@001P4000H20004000200<1000C00@100060@402`D200T20007
0000100000<0000500000`0000H1000700001@4000L200050@001@00008000050@00100000D00002
00@0000400D100070@00204000H1008030@100D0308100T0000600001P0000L2000300@000800`00
0`0100000`0200000@0000400002004007H00000303oool000X0ooooi`0000030040000300@00004
0@00104000800`000P0200006@050@001@8000H300050@001@4100L20@090P406aHA01LA2`0C2`L0
40D300X20@080@001P0000`60`090`401P4000P100070@001P4000<0000400001P8100D100060@00
0P0500003P0600001`4000H1000=10403PD101060P0<0P402P4000H000060@001`8000H100050000
10000P0300000`02000000000000000300000003004000000000000007D00000303oool000X0oooo
iP0000030040000400<100020000104000@100800`0001D0100000d8100:1@802`D300X60`0=1`@0
3PT6010;1`0M9D406bH`01PS8@0J6A@050l:00d60`090`405a/H00l>1`0=20@02P<100T200060@00
0P040000100H4@d05@`801881@0=1@<200X30@0<00L20@060P003@H200h60P0?1P4040D100`30@08
0@001`0000L100090@001`400P050@000`0300000@0000400002000000@00@00M`00000<0?ooo`00
2P3ooooJ000000800@002`000000100100000P0000800002000400<0000K00hE3`0>4@X030`700`=
200=3`T03a8;010E3`055W801Qa[00T[E00;<3l052XY01TO5`0E4`T04@X501<B3P0>2@D05@d801d>
3P0T3A0070/;01881P0P8ST07Ah/01TI800H51@05Q4;00803PT400l03PD200X30@0C30D04PX30106
0P0?10402`8000P1000800002P8000/200070P001@8000D100040@000`0100000`0200000@000040
0003004007H00000303oool000X0ooooi`00000010020@000P000080000200030040000L00/W9`0>
9R@052<M01HP5`0E81P04b4I018R700?9R@01ae200POAP0:9e802C5S01@bF@0P;T@09bPb028M9P0Q
51/070hB01`B600P4bl091M201lM:`0:5HH02aUc00/QF`0:8dH03b<^01HM6@804a0800/04PX401DG
3`0I60h06A8:01H;1P0A1P803P@100X20@090@002P8000T2000300P2000400@1000200000`4000<1
00800P0000<00@000080000200000P01000400000003004000000000000006h00000303oool000X0
ooooi@0000020040000S00<100020@000P4000<100040P401P<100P40P0>:eL04RaF01P/D00M;4T0
72]801P[A`0E:TP03bE:00XTD00;8U002QeN00HLR00<7Y405An201LKI@0L7ET06QU601HH=P0<4c80
1@iJ00DFQ00;:UD01AMW00PHBP0875801R9L00lYEP0L:Sl00P0R:BX04P0P91h07B4K01`R8@0O81`0
71L@01L>200D20<03@@100l50P0;0`4020<100X200080P001`8000D200030@001@4000<100800P00
0P0100000`0000000@0000000008000000800@00J`00000<0?ooo`002P3ooooS0000000W00400002
00000P0000@200040@001@4000<20@06108020L300/:1P075HH01Q>B00LCT`0:590031F<00`FQ`0:
68802AEe00LCN0054W`01@me00@9N0010il00@>b0085[0022HT0111l00@EJ`0465P00aEF004>M003
48L010ed00HB>@0;4b4031I500/KMP0>7hX062=i00808BMY00l08b]501/Z<@0A:C`05b`g01/V800H
6Q005`l802@P7@0O4`d05`h70108100<10802`<100T30@090P000P090`000`060P00104000800002
000000030040000200000P0000800@00100000001@01000000000040000000000@0006X00000303o
ool000X0oooo/@0000020040000300000001000000000100000000<00@0000000000000070000003
00<1000R00@20@050`402@P400X>1`0535D010eN008;I`022fX00P]Y008<J0033V@00a1Q008;G@03
2Eh00`QN00<6I@020gl00@6U0001/P004J4000fJ004?T`024Xh011J000DBNP052X`01@^X00L:FP0>
2QX04@hA00`>@P061hX00@:c0042/@800PBC01L02am^00l`BP0>:SD052Tc01X/;`0O<2h06C=Z02LZ
C@0/8C@09ahS01hJ4`0D3`P04`X501070`0?1`<03`H200d40@0:10401`<000<00002000000000080
000300@000040080000100000000000000800@0000<000000040000200000P010004000000030040
000000000@0006800000303oool000X0ooooY@0000000`0100000000000000090000000300400002
00000@0000<00@00;00000009`0100001@8100L30@09108020D200P70`092@@03@l900dF3`0:62P0
2Adg00DMB00563`01a<]00P>9@093b@00PN:00<9N0031gh00`F30083S0020Y`00@6]00XKYP096jL0
1aVZ00HIZP086jT02QfN00`MS@0<690092R301TOD@0D5b/03QHS00DGE@023i800@V[004@T`020049
T00E00DBLP0;94P04B@U01HS:P0K:4D0835X00TFX`0B7H/05b1a01l/CP0P;Rd0624D01TF2`0S7100
7A4501P=100E2P<03PH300T400050P000P0000800`0000@0100000D0000400000`000P0000020040
00030080000000000P0000@00P001@0000000`01000000000000001P000000`0oooo000:0?oook00
000000D00@000080000300000P000040000200810003004000000000000002L000000`0100009P06
10402PL300`:1@0<30H030h700d@2@0>61002ahJ00/X;@0;:e001R9i00TKB@0?62405ALD00`MP00E
87D07B=Z01`RL@0J8WL05R5m00hMQ@0K9h<06RJ<01LWUP0B:9d04BZL018ZWP0D:YD04bn102@kMP0U
?W405cAP00d]D@06;TT012QP00<JPP02:YX00B:S0P004Jh06`0228l02aM?01/Z?00I7S803Q1M0002
^0011Z`00aF=00PPJ@0C;E806cI101lj=@0T;200<3<Y02LQ4P0R5P/070l501080`0:1@802@@100H2
00060@000P0000D000030000100000400002000000<00@0000<00P0000<0000300000`0300000`02
000000000000001U000000`0oooo000:0?ooojP000000`010002008000<0000000P00@0000800003
00000P00004000020@000P0000400200000000<00@000000000000001@0000030040000W00H30@08
1@8030X500l@200?4`X03QD<00dF3@095BH01AP`00@L?`037ET00PR600H:D`0:5B`01C9^010dH@0M
<e/09C9B02DeD`0T>5D07cYF01DgG`0D=FD04bib018YR`0@9iP042bB010]S`0B;HD05S9Z01DfF@0E
>5P05cQL014fIP0;>6803cMS01</KP0P;7L08B^100807BZ=01/06BEe00lKI00?86`02AYG000<[@00
1;L00@JT00<EO@089F804baG01XaG@0N>W407CF202Y5D@0[>BL0:bDD028E200C2P@03PH200X40@0>
1P402@8000L1000700001P0000<00002000010000002004000030080000400000`0000800`4000<0
0P400040000100000P01001S000000`0oooo000:0?ooojL000000`0100001`040@000P0000800001
000000000040000000001`02000900000003004000000000000001/000000P01000200D20@0W00H3
0@08104030T400h>1P0>4@P03Q<:00L<EP0636800`a]008<I`053d@01Plk00D??@043S`00RiH00/[
@@0A9TL03b9L00lZHP0@<FP043IU010hI`0:>6d02cMT00h`K`0@:8404Baj018]M00F;V`05RiW01L_
H`0G;fl07c5l01l`Q`0N<F<08CAM038lJ@0d=fP0<cYY0080:d9Z01/083]Z018XN`0787h00aii000C
[0001[H000>L008<O00468@031ab00dFN@021J002b2M01]5I`0V@c<0;RlL02PL3P0T4PT06``5028F
3@0G30@040D200X30@090P00204000<10002000010000002004000060080000300000`0000D10004
0@000`400`020@03004006400000303oool000X0ooooYP0000002P0200000@000040000100001040
00<100020@000P000040000000020040000300<0000200000P0000800P0000<00@00000000000000
9@000002004000<01@<102H01`@100/70`0>2`@03`h6014C2@062I`00PB/0001/`010Z001PY@00TH
:`073bX01BYX00HWM00@9D<05RE;018WM00B;7l04S6@01DcS@0F=8`05C:?01`eKP0U>6<0;CUZ02lj
IP0`>f80<3YK02ldE@0/<dl0:3=H02dgL00_>gD0:39S024YKP0H9Wd05RQh01L^L`805Sa/01/06Cmd
01LiQ`0;<Hl06S>A018WW`077:X00A:O0049SP010Xl00@:;0043R`010jD01QBI014fJP0PAd/0<3Pc
038Y:00e92T0;c8m02dX7`0N60/050d400l50P0;0`00204000H1000300000`000004008000801000
00<0104000D200040@000P030@0200810003004000020000000006000000303oool000X0ooooY@00
00002`0100000P000040000100000P4000<200040P000`8000<0000100000P0000800@000`020002
00<00003004000000000000001l0000000<00@000000000000000P0000020040000Z00D30@050P00
1@8000D200080`402PH200d90`0@3@D082aC00H:V`021J`00@:d0041Z@041g800PmD00@/G007:U/0
2BM[01<ZDP0L<T/073=C01d/IP0M98h07bJ=01h/S00K<Xh07Rb2024YO`0T9X0092Yn02H^NP0S;fl0
8B]U01dZFP0K;UL07RmP024fIP0T<f`0835o00l_R`0=;H`042Z:0P0A;HP08@0J=HL08SR;0350NP0_
@gh08cb@00`bW@029ih00AJG0005T`000Xd000:/0001]00229D021a]01@cN@0S=5l08be@024_H00R
>ED0;3Da02@U5P0O60`05PX400d30@090P001@4000<10002000000000080000100000P0000810002
00<100800`000P030@0200<000<00@00HP00000<0?ooo`002P3ooon8000000800@006@0000040040
00@00P000P0300001`0200000@0000<0000200000`000040000000000`01000Q000000800@000`00
0002004000@00`4002L01@8000H200091@8030P301h^9P0K;EL01@ZJ0085ZP010[<0006b0083W001
1X`00bYj00T/K@0;;FP05C=P01PcG@0E:El05b1^01XMQ`0J78P06BF701D^R@0D:XH04bJ401<VP`0J
;X0062n001D`O00D9g`041Yl010LL`0D7f`05b=^02HaN@0W=8T07C:C01h_U@0R:iD00P0U:HL0700[
<Wh0=Sio03Q2KP0b@g009D>700`oU@01=Id00B>X000:]@006:L0016[0008]P011ID00PMe0088X006
7Y402bUe018ZG@0R<4H09C4g02Xd=00]:B<08aD=01070P080`401`8000<000020002000000040040
000300000P4000<100800P400`03000200@000800@00H`00000<0?ooo`002P3ooon7000000<00@00
6@000004004000030080000100000P0000800`000P0200001@0300000`4000@100040@000`000080
00000P020003004002400000100100040080000W00@100050`002@@100/70P0L;BH06BeD00H?T@03
2JD00@Ba0000]`000KH001nT00D[V`0<<hP03cMj01HhJP0G;Gd04QnF01HQT`0C7Id0522J01LVU@0G
;I@05bjD01L]U@0H<9@07cV>01hmSP0N?8h07CBD01XZTP0I:h807Rmg02<`M`0[<WL0;3El02dgP`0]
>8H0;SZ90080:SB401h0:C2302dfP00^?fh0=4=T02]6K`0JAh405D2=00lbV`0?>Yd002nO000RXP00
4:`000FD0043L@023GL011]o00HON`0D96T08RY?02D_CP0T=f@0=CM903<U7@0I3PH06@`501460P09
0P401@4000400000000200400007008000030@000`40008100030000100000<0000200@0000400<0
000100000@00004000@000001001001I000000`0oooo000:0?ooohL000000`01000I000000@00@00
00<00P000040000200000P0300020080000500<000030@00104000@1000300000P000002008000<0
0@008@000004004000@00P0002L0104000D3000910402`L201`]9P0I;E@01PnA00<9Y@011;40002g
0001]P007j@01B^K00`cR00?=gX05SQZ01L]O@0B7iH05R6C01<MW@0D89X05bJE01L]U00G;Y@05bfE
01P`U00O>Hh07Sf>01hlSP0M=9@06RZB01T[PP0N;gL08c1g02/bM`0/=G`0;CN302dhQP0^>XT00P0Z
=8@07P0Y<8<0;CJ002hoKP0d@f@0:dI_01Y7P@0E@8d03c:K00ljW@00;il002:R000@[0001I@00@=a
008=M`046gl01Qmk01@TJ@0R:Tl09Bm>02@gI00e=dT0<bDM01T>1P0I30D04@H200T20@050@000@00
000000800@0000L00P0000<100030@000P4000<0000400000`000080100000@00`00004000010000
0@0010000004004005T00000303oool000X0ooooQ`000006004000030000000100000@0000800@00
4@00000600400005008000040@000`0000<0000600000P060@000`080`001`<000D1000200800003
00<0000400000@0000800@007P0000000`010000000000000002004000030081000200000P0000@0
0P4002H01@4000L3000C5@`06bPQ01P[BP085H401A2J0047[@000;L000^N000IX`06;iP03SV200lg
MP0C<WD052V?01PYV`0I;YT062nI01h`U@0U<hh0:3N:02HgS@0R>9809SV>02/mS00/@8T0;4:902Y2
R`0T@X@08Sib02DmK`0T?6T08ceX020mJP0O?G807SZ201dmR0805cR;02006S>?01LbR00S?6X0=DEN
03A6K`0]B7d0:TZ801a5T`0@BYD0046L000`X0005jH000N<0047GP0554l01AQM00@@L`0:4XD04QEZ
010KL`0<9Y80:SMe03de?010<3T0?28P02`G3`0J2PD02P@100H100010000000000<000801@4000<0
0`4000<000020000100200001@01000000000000000000000@0000@0000000<00@00008000010000
F@00000<0?ooo`002P3ooon800000003004000000000000000<000001001000C000000800@000`02
000020030000100000<0000600001P4000L200070`0020<00P070P0300@000030040000000000000
028000000P0100000`0200000@00008100030081000V00<1000=2@<04A4801TR6P0G:3l02AU`00LE
S`022jT0002f0006Y0005Z8023>E014mO00==7l03bf6014WU00H<8h07CV601/gTP0P>8d09SR702Lh
P`0U>XT09Cf@02@lS`0V?8h09cZ?02U1S00WAh/08TV401/mO00G=W8063IU01HgHP0D=FT04SE]01Dc
M@0E=7h201`gQ`0N01hfT00K=H/0831_030kJP0mAFh0?Ta`03MCM`0]Eg`06e6401A4T@0E=iP05RbK
010QO@096ed02B5?00DCF@031gH000:>0043QP012Y4011NP01LUT`0a<G40;Bim03`bF00n;Rh0:a/?
01P;100<10401@400P0400001`060P001@4000H1000500000`000080000000001001000200000003
004000000000000000<0000000<00@00000000000000F000000<0?ooo`002P3ooon>000000L00@00
10000004004000T0000000P00@000080000200000@0000<0000400001P4000H200801`800P080P00
1P0;1@402`@100T300050@001@00008002H000001P0100009P040@402`H300l?1`0F81P05RDk00PI
JP0;5W001a9b00L<K0073V@00a]h00/`M`0F=gH03BnN00l[W@0G:YP06c:501dkN@0L=i007cJ601lc
OP0L<H407cB801hhU@0L>9D07C>E01/`UP0K=YD073bB01/nS`0K?Hd063F901TdN`0O<Wh07Rb;020_
S@0P<Y407SJA0P0V>8T07`0X>HL0:3B501lXP`0O8XH09BZ602`gO`0aAGP0:d]e02]<N@0[AX40:D:7
0293Q`0J=WT042Ih00dZP`014ID00@VP0003ZP000J/000>`0045]@052k0010jP00XIV@0S<7X0>cm:
03Hb8`0/7Q006`h500h40@090P000P060P001@060@00100000D000010000000000<00@0000H00P00
0000000200000@0000800001000400000003004000000000000005P00000303oool000X0ooooS`00
0003004000800P4000<00@000000000000002P0000000`010000000000000003000000800P0000L0
0@00008000060P401P8000P200060@001P8000801`8000H03PT301480P0;1@402P<000L100040005
00800003004000000000000001d0000000<00@00000000000000100000009P040P402`L300h=1`0G
7aL06BHi00XKJ@0@6UD02A5900hI@@0>5S`01AiT010ZJP0K<6T03c6H01HhS`0K>8d07S^201m0O`0O
@8l0942<02@lR`0R=hl09CJ?02PeTP0W=9808c:D01l^UP0N<ID073>E01heTP0S=I40:3B802`eI`0g
?640>d1V03E2J00_Afd0:T]^0P0^BfX09@0aBF@0;49b024iQ00I=8P06cN402DkPP0X>H00:3Ym02i2
OP0bB840;Dn0021BP00MA7h094Mn01DiTP079Yl011^W008@]0002;P000Fi0002^P000H`000F@004;
U@0L:7d0<ciL03a0B`11=CP0>20H038K4@0D1P803@8000L10005000010000080000100000P000002
004000<00`0000<00P4000<1000200000P01000200000003004000000000000005P00000303oool0
00X0ooooRP0000001@020@000@00004000010000000000800@000P020@000`040@000`000040000C
0000000?0040000E30T05`d901D;1`0B20D03PD300`40P0:0`405QD?01DD300E4@X04P`600h60P0:
10401`4000800`4000@00P4000<100030@000@003@000006004000`0000000<00@00000000000000
0`0000009`020@0010<100X70`0>30H06AlF01/W>00<7VP010J300X@E@0>6DT041Y:00HNN`0?97X0
6b]]014eT`0N@Gh08d9^02=3KP0SBG`0956802Y?Q@0[AXD0;42202dkP00^>7d0;CR302XeS@0T<Xd0
7SB?01TeS`0I=Xl083N@02PhQ`0S<W009C9R02PhH@0Y?V<08T=W0257I`0202=5HP0Q02A3G@0T@fl0
94F201]7RP0KA8809Sb402hfO`0b=gP0=4Ah03E@N00`Fg80:E]g02Q<P00`AX<09TF701HoTP0<<Id0
122X000B/@002kH000Bj0001X0000Z<00@FV018HSP0O8fl08B=h03<^L@15=CP0ABdU02HA1P0E1`<0
208000<00`0000<00P000000000100000P0100000`030000104000<1000300@1000400<000020000
0@00004000H000000P01001C000000`0oooo000:0?ooohT0000000D0104100@1000300000`400040
0003000000800@0000<00`400080000000001P000003004000@0000000@00`4000<20@040P401@81
0`060P403P0O5b/07aL/01dH9@0J5QP0514>018=2@0C93004b8T01@P6P0C6a805149014:100=1P80
3@@10P060P0010050P000`4000@10001000>000000D00@001`0000000`0100000000000000060000
00<00@0002H00`4100T50P0<2`H061hE01`W>@0<7VT00PBJ00D8O0072VP02A5_00<ET00<88h062eo
01XoTP0RBXP094^002A@M@0TF7L09EJ202]BO`0`AW/0;3ie02TjK@0U=fX08cAd01l^P`0J;gl05S60
01DbQ`0B=8d04SBI01HbS@0G<g805SIO01@hK@0J>7`073B4020eQ`80836702H082^9028aQ`0/>8<0
;Cif02Y3L`0Z@840;SQe034gI@0`@GH0<E1d02eFL@0bEW@0?TYj0416O@0hBgH09Tb201A3T`05<J00
01b[000@/`022I/0006V0001[0000KD00`B]00D6S@051h`0725o02`cP016?dX0@C0P02dF3@0G1`<0
1`8000D0000400000`0000@000<00P0000<0100000<0000300000P030@0200<00004008000010000
0P00004000<000001@01001B000000`0oooo000:0?ooohP0000000L00P4000@20@030@00104000@2
0@040@000@0000@0000000@00P000000000000000@00200000006@0100000000000000040P401@<1
00H40P071P<020P400X8100:1`@01aIW00LFJ0075FX02AiI00dW>P0>8b402R=300dR;`0<8BT03bHZ
01<Z:P0K81/081L@03<O7P0T4@`00P0A1P80100<0`401`4000@00001000U0000000W004000020@00
1`@200`;1@0I6a@06bHh0046/P000K@0006b0041/0031jH00PfV00TLUP0L@H406TVA02=ARP0TDhP0
8e]i02IQL`0WFG`0:eAh0359O@0_@f`0;4ES02U1E@0X>5408c1D01h]F@0K;G005bn<01@_T`0B;Y`0
4Rn501`eK`0Q=Vh07c9l02PaQ@0`<HT0;cB:0080;3><02<0:3F902/hP00d?G`0>3aY038oJ`0U?H80
6cYl01dcL`0Q=GT08d1f02Y=M`0jCG<0A4Qf04Q>N00nC7D0=4ej02==QP0BA9D03C>J01@^U@095iT0
00F>0003Q0000X000PEo00<4P`020i400`Z_01DUV00]?GX0?d5D044^:@0Y5@`050H300/2000200L0
000700<000020@000`4000<100020000000000400002008000800`000`020003004000<0000000<0
0@00000000000000DP00000<0?ooo`002P3ooon800000007008100050P40108000D2000710401@81
00<10002008000800@000P020003004000L0000000X00@000000000000004@/7018>2@0B4@X04Q@=
018G3`0A61402a@h0P0<53@03@0<53H03AP^01<L8@0F6QD04aHJ01<B4P0A5A`04R4l01H]H`0R:E40
8R1Z02l]E`0a;2d00P0N5Pd0100F2@@02`8000800001000V0000000V004000060`4030X401TJ4`06
7I800@Na0000]P000;L0002h0044/0012:/03C:F01I0R@0IBhl085N9025HR@0TGgT0:F9c02UHM`0c
Ffl0<E2103==JP0cBV@0=DA4038m=00d=Rd0<SDj02/iF`0W?Gl08Cb801hjU@0J=gH08SUU02LiJ00/
=6L0=3Am03XiPP0i?X<202e1R00W02M3Q`0V?X<09Sel02U0L00Z@7808cYl01e1N00Q?h8093R902Dk
P@0[AH80>DYm03e=O@10E7d0@59m03U@OP0[EHH085:702EDQP0O@hh04RRL000<W@001W/0009e0084
J@031G/00@:[0041^`045ZL02RRH020jP011@DX0?2`L02@B200F1`802P0000H00004000010400080
0`8000@00P0000400000000000000P0100000`0000000@00008000020040000300<0000200000000
05L00000303oool000X0ooooQ0000002004000030000000100000`4000801P<100<01P<000P30P07
0P400`030@020080000500<2000300000`000080000100000`00000010050@40104100@20@050P42
00L20@0802<H:P0S6B`08A``020O=00O8SP07B@k01HQ>P0I83P201TO=@0=01XP=`0K8CH07b0c02@M
;@0T6RL08aHR01XB8P0>3dl01PbQ00XCT`053HD052Ih02HoC`0202De9P05024I3`0B1P<00`000080
000100006`000003004000L0000002H00@0000L20@0:1P<02bQR00LOS0012:l0006f0000]`000;T0
00:d0003/@04:Z802CNG00a0UP0BDHh065Z;02=VNP0/Ig40<V5a03=NJ`0bDX00<da[02i2G`0`>d40
;c/]02ln:00Z?CX0:4A@02I9IP0NAWT06T>?01HmM00E=6D0631P01`bIP0R=GP09CB202HhP`807Sb8
01X06Sf:01hjRP0Q>gl09DEh02Q5PP0V=8L09SEo034hO@0j=h00=SUj03I3NP0dCG80=5Id03iJNP0o
EGh0=e24031JQ`0XFhH0:E^402U@Q@0N=iL03b>L00LCQ@021i<00@Ai0003O080002l00/00@ZM008C
QP0F:WL0<TMK0455>P0o;Ql0<aL=01H70P0;00001P0000H1000200H2000400@1000200000@000080
00<00@0000<000000040000200000P01001I000000`0oooo000:0?oooh80000000@00@0000800002
00000@000P0200001`030@401P@100H30@070`4020@100L200050P000P060@009`030@00104000@2
00080`401`<100H100030@000`000040000:20@02@L400T70`081`<02PT500/;1P0>5FP03QA[00dC
K`0=4W@0315h00`BN`0;4gd02A9a00XBKP0;4V/02a9/00XBKP0;4Vh01@QW00P<F0093U<02@i<00P=
D0042GD00@B[0088L00345T031eB01X_G00202I0IP0603T_<`0W4``02P8000P0000200000`006@00
0002004000D00P0000<00@000080000200000P0200009@060@402@D200/ZFP078XH00@V/0041]000
0KL0002i0000^0004Z4002>[004/X@02<Z802DJB019GR`0NIWh0<Fea039TM@0cH6l0<U>003=<O@0_
AGP0;DAT02i=D00[D4d094EA01lkI@0N>GP06SZ401PlS00E>XD053Qo01LhL`0K=VX07C9Y01l^M00S
;gL00P0Q;X009`0S<X80:SF302lhN00e@f`0>TMj03`lMP0o>VL0B41T04i6I@15AVH0>4Y[02e?I`0]
F6/0?EQb04EBNP11DgD0>Eai03ALO00`FGl0=U5l03I7Q@0Z@8/05bj;00LMT00058D0002j0000_000
0;d000BE004:N@0>8WP07SYZ0355HP12Ad/0B34R02PB200B10402P0000L1000300P1000;00@10002
00000P000080000100000P0000<0000400000P0000<0000100001`000004004004h00000303oool0
00X0ooooP@0000002@0100000P0000<1000200000@000080000100000P4000D20@0200D30@0300P3
0@080`001`8000801P8101X01P8000L2000>2`D03@P400X60P09104020<100@10@0=5`h041L?010G
3P0A5@d041@<010H400?71@00a:>00<?T0033Y800`bE00<:U`042g`00PQN0046FP011FL00@Ef0045
NP8000Ak00/0006?0002P0010gl00@=n0044R00219/0002N00<7G`0;4RX0314Y00/BH`0200dEX`09
03hfH@1;;2@07`d601<60@070@000`000080000000000@0001L0000000<00@000080000200000`01
0000:P0200000@00004000020@000P0000D1000A7RD032a<00TWN`013JL00@:b0001]P000;T000VK
000CY`007jh00BbT004dY00<@i40556901eOPP0dIW40<Emj039NN00bDh80<Tio02m8OP0aBFh0=4aP
0357I`0Z@FD0:cmi02XoQ`0T@XX08D:80210R@0Y?HD0:SIg02lfHP0e>640=SMS03TgH`80>SaR02L0
>CeU03XoHP0h?F00>S]T03TnN@0e?WX0;SAf02/cKP0d?VL0=TEX035<JP0/F6`0<Ee`03iHL`16EGH0
AeQ^045FL@0gF7/0<UMo03UEO010EW/0>5B102A<R00>?i802RNU00@A/@022;P0006l0001V@0118H0
1A>000/OM00?:XH0=TQX05A9A`15:A`0:@h600d20@0800000P050P001P050@000`0000<000040000
0@0000<000<010000P030P0010040@000@4000400001001F000000`0oooo000:0?oooh4000001002
0002000000080040000200000`4000@200080`402@@100P30@090`4200/50@0I00T3000I4``04@`5
01<@2@0K5Pl091TF028D4`0O41407QlQ028Y>P0T;4<092Tm02<X>@0O:Sl00`^X00<:Y`032ZP00`VX
00<8Z0031jP00Q6@0087T0010I800@6H0001X0020000X`040000]`000;H0002f0000]P80002g00H0
002f0000Z`0317803P`e00d:<@051V020083TP0902XSJ@14=DX0?B8U02l@2`0<0@00204000@00003
00000@0000P0000000<00@000000000000004@0000000`0100000P0000<1000200<1000V0081000B
3`/03adM00d]?P0:;6l00Q2Q0083[`010KD0002i0009]P004K@001Z`004[Y@01=J@03T6@01Q;R@0U
FXD0<F5j031NO`0bG7/0<E2102e>N`0[BgH0;4M]0310K00Z<W00:cQb03=2N@0cB7d0;DMo02Y6PP0`
AWh0;cim02`dNP0V:W@09b5e02LVK`0X:fT202XcH00W02ThG00[>e/0:3YN02LdL`0T<HT07S:901Xb
Q`0I=8@083mj02]1O`0`?Gl0<e5P03]II`0lFgH0?Ea_03QCN00oD780>4ii031=P@0gDX00>eV003YP
OP0]HH<065NB01E;V00;<j401Q^]0045^P000J@0006B0043OP0337H02aUW02<^M`12?Vl0Fd0m04TX
6@0X3PL04P<100801@4000<00`400080000300000P02000200<0000500@000030@001@8000D20004
0@000P020@000`01000000000000001D000000`0oooo000:0?oooh00000000@00@00008000030@00
0P000P0000020040000700<100030P001P<000P30@0<1P4030H200h80`02010:1@0H02HNC00L6200
514<01TF5@0Q7380:1mE02LKD00T5dP06AI7014EMP0@5Y0041N:014HP@073J/01Pf/00D<[@043:d0
0`^_0089[`012;001R2B00@DT`022j800@F^0P000;H00`000:h0002g0000]P020000]P<0002g00D0
002b0000VP010W`00P=V0043K@020000Q00:018IHP0M9g<0>2aN04HS9P0L3@D04@<200/000030000
0P00004001/000000P0100030080000V00P30@0@30P03QTE00l[<@0=;V0011NE00@9V`031YP0002g
0006/`003;0001B[000XX@01<jD043fA02E<Q00SCh/0;eUo02eHP`0cEGl0<4^202Q8O@0WBG/0:D9a
02`kKP0V=g`0:3Ml02dkO@0/>gd0:3j002e4N`0[?G/09SIo01`^P`0I9hL06B>501XXPP0H;80201Pc
K00W024gHP0T<Fl09bej02L`Q@0T;hl0832B01haU@0R<I409SAn038lO@0lAG40?deC04AGD`0jGUl0
=UaW03QDNP10B7/0@4=h03i5LP0oC7T0>UYn03MUNP0dIG`0<fUn02EQR@0FCI@02RnR008:]P000K80
006X0042V00425l01@aG00D9S@0S7I@0Cd9U05A3?P148aL09@`400803`@100/01080008000030000
100000<0000400000`0000D0000200000`4000@1000200<100800P00EP00000<0?ooo`002P3ooon1
000000<00P000`000000200200000`4000@20@0910402@@200d80`0?2`D04Ph70P0C50d06`031HD0
2@ld00dK6`0:5RD01PeF0086UP021W/00PQh004<L@012i800@jT004CW00J<Xh06C>>01LcS`0C<Y80
3c2H00X[WP069:<02cJK00T`R`0498H001RE000<ZP000;H0002:0000Y`020000]`80002f10000;L2
0000]P0A0000T0000H4000650001Q@0535X01Q=d02@UM`17>DL0=R/I02DC2@0C10400`4000<00001
00000P000000000100001P00000010010000000000000001000?000000<00@0000P00P0000D20@0=
2@D03QD>01<V900C;Th01an200TCM@80002h01d000>c0006/0003JT0026L000^YP0C>ID09Tf5029=
S@0ZDH<09Tn502i@OP0/BH@094Qo02E6Q@0U?gD09S]i02@oS@0W@8/0:Cf;02TnSP0X@8h0:d>:02Tn
S@0S<i406RnH01P[W00I:9d07R^H02<]TP0202DbL`0W03@lG00o?FH0@CmY03hnJ@0i>Vh0<3Uk02/l
QP0W?HP0:3>102lbOP0c?fT0=D9K03M<F00aFed0<Ea_03Q@OP0n@W`0@Ceg03dmL`0g@W@0<U5h035L
M`11GW80A5me03aTN`0YGhP0546L00@G/0002[L000Fj0041X@010g800PU?00D=G00B6W408S>1045?
K01I@CX0@b0C00808P`300<02@4000@1000200000`0400001@030@000P00008000010@000@000080
0P0000@00@000080000200000@001P0000000`01000000000000001;000000`0oooo000:0?oooh80
000000d00@000000000000000000004000020@000`4100X70`0:1P802`H101@<1@0H4`/061hE0080
3AI401/021Q900XR>P08:cl01bE000DMB0022FT00P]W004=IP024GH00aJ:00@KS@058H@063ag01Pn
M@0H@7@05Smi010kQ`0<=YD04Sj?00`kT`0=>X`01c2<008SVP014jX0002f0000R@000:D00`000;L0
0`000;H0002g0000]`020000]`80002f00l0002Q0000R`000G`0005l0045H`021Ed041Q`02i3G`0k
CCP0=RDG02<<1@080@001@4000@0000300002@000002004000L000000P0100070000000:00400000
00000000004000020@002@H300`?200E81T062`m00/TKP<0002j01d0006g0001]P001Zl001bI000Z
Y@0EBI40:Db4029:S@0YBGl08TAl02M8M`0XB8D0:Dmk02Y:O`0U@7<09Smh02E8S00/BhL0:dN802U0
S00/@XX0;42702@mS00M>Xl063JE01TaV00K<YT093F@02hkR`0202lhM@0W030eI`0e=fd0>CeW03Q0
I00e@V@0;cia02Q1O`0QAH409cn502LaRP0W<H40<3]i0353MP0bD6/0=eEd03Q@OP0jBgh0=TEk0312
N00[BG80:U5g039BN010CW@0Cdm[04mQJ@10IGL09U6=00/_Y@026Zl00@bd0042Y@000I800@AV00<9
D0054fT03BUo02=2Q01;Bf40H40c0080@QhA00<06`T200T1000300000P0300000`0400001@4000<0
0003004000050000000100000@000040000200000P01001C000000`0oooo000:0?ooohL0000000P0
0@0000P50P0:20@02`L300d70P0H40/06Q`K01<S<@804bI:01/02b=T00XTL0099G`022=l00LON001
1jl00PZ[00<>YP055id02B2D00dVS@0F<X4063Am01XfNP0M>7P073Eg01D_P@0G;Y806cB801/hRP0I
?H`043fC00PfW`058JP0006U0000R@000:D00`000;L00`000;H0002g0000]`060000]`80002T00`0
001^0000I`063G005cAI02iDB00e=2@0;aT>01L80`0@10401P4000@000010008000000800@001P00
0003004000X000000P0100001@0710802`X501HI4P0K:3D03B=U00<0002j0P000KL06`001jl00B6C
0090WP0EBI40:DZ50217S@0U@gT083e[028lJ`0T@gT0:Tic02m?M00XA6h0:D1f02I8R@0[CHL0:DJ:
02HlS@0T>90093N=020hS00J>8d06CFB01TbV@0J<YX083>B02@hT002028eQP0W01hbP00S=G/09SYg
02@lMP0P?WL093im02LlP`0W@gh0;dIo02dlRP0Z>h`0;Cn;0352Q@0dAV/0>4m`03=FO@0]Eh00:U1n
02Q=N@0UDGT09dmj031:N`0kBW`0BE5/051JI01AI6T0?5il01Q6V@08:jL00QFG0042Y@000JT00@6O
0043U`012I@00ABB00PZU`0hDgX0FDaF0080FS8X00L0=1<901D5000700000`0000<1000300001040
00800`00100000000`0100000`0000400002004000@0000000<00@00000000010000C000000<0?oo
o`002P3ooom_00000003004000000000000001D0000000P0108100P60`0;2P@03@T400h:100J5a80
5B0a00@IC`8011=Z01d00PB90042VP010Jd0006[000MYP038Z001bBN00/TW00C8IP05afE01lLS`0L
6Hh06aF?01XFSP0J5Y0071Z6028ROP0[:h@0:c=k02PkP00TAH@064Z700m:U008;YD000>S0001R@00
0:80002c0000]@070000]`030000]P000;L0002g0080002W00`0001f0000O0011gP063EV025?I`0j
?C`0?BhP038U5`0V40P03P8100<10001000700000003004000000000000000L000000P01000;0000
0006008000060P402PH301HE3P0N8c000@F^0`000;/07@000KP0006g0048[@01::800D2N01A8T@0Y
BHD07dF=02I4M`0T@68083MR01lkM@0UAg40;dQX02I4L@0Y@7L08d:<02A8R00P@HT083N;020_U00L
;9L07SBB01dhSP0N=i808SBC02@cT@0U=9009C>A00808SJA02L09SZ>02LnS00Z@8/0:Cf:02XlR@0a
>XL0>SZ403PmN@0g@W`0;dQl02Y6P@0Z@XX0:42702U0L`0Z@g<094ah021BOP0SD8809D^302a:P00a
BGl0<dUl03E=P00gDgH0@5A_05ALH`1<GVh0<eZ601a5U`0>9YT00PbI0003U`000j800@6`0042WP01
1XL05BVE0290Q`0oAgL00P1QATX01P1E:1T0:@d400`200060@000P8000<10080104000<00`000080
000100000P0000000`0100000P0000400002004000@0000000<00@000080000200000`0100000`02
00000@0000000016000000`0oooo000:0?ooofh000001001000E0000000800D30@0:2@@03A08018D
3@0F5a806b8[00L=K0022G0200<7JP0M00<7GP0226400@BD000MY000:9H00bZB00P[T@0<:Y004RB?
01@NSP0B6Xl041J?00lDT00?59403aJC014JT@0I:8X08cF602@hO`0R?Gh08T=m01a:P@0HCXX04SV6
004DUP0038d000>:0000T@000:801P000;L010000;H0002h0000^0000;P20000ZP0;0000OP0007l0
00Ii00LfP`0>@8d0=CeP0415?`0mCT00?RDK01h80`030@000P010008000000800@0000<000000040
000000002@0000000`0100000000000000050000000500@100070`405Pl900HAW0011K@00`000;X0
7@000KT0006g0049[P0;<YT03d:F0254S00_A880842<02M4MP0R@60083YY020jP@0U@WT0;d=a02Y2
P00]@Gd08Sn601a5P00K@F`073Ua01h`T`0I;I`07SRE0212T@0UAH`0:46>02m3R@0`AHL0;T670080
;D6502L0;T2203<mO`0e?H<0=cN303PhQ00m?H40@TAl03e2N00d@gX09DUk02=5OP0S>hP07c><01hi
P`0T@H<08Db402=@QP0ZBH@0<TB103U5OP0mCGX0?UEg03ILN`0_F7d0>Tml055>J@1JF5l0C6U`035L
Q`0K?9D01aZM0046UP0019H0006V0002R0000V40116U00PNWP0c?7`00P1FE5l0101QACD0BB4@01h7
0P0:0P0200D2000600H20@050@001@4000810002000000000`010008000000030040000200000P00
00800P0000<00@00000000000000AP00000<0?ooo`002P3ooomS000000<00@002@0000000`010000
00000000000D0000000700<100081@8030d600hF3P0A7QX042<Z0042/P040000]`0L0043WP022680
0@B400@TV@059i<01bNU00XXX`0;::802bJR00XUX@0899h01bFK00DTV@0599X01RBL00LTW`0;9i/0
4b^D01PcS00I>HT06cj601doQ00[@gP08d1j00DbT@017Hh000VE0000R`L0002g10000;P20000[@0<
0000R`0008h00QVU00<[UP05:9H0:CAc02i:H`0^CVd0ASHk030F3`0C10<02@402@00000200400003
0080000100000@0000L000000P0100000`0200000@00000000050000000500<100070`405@l800LH
T`012;800`000;/07@000KT0006h004K[00C>I@06D2A02@oS@0/@8@0842<02M5N00R?WH08Cij028l
Q`0YAGd0<4Qk02a5RP0/AXD094:601i6OP0N@VL08SYS020cS@0K<9P07C^B0213S`0TAH/09d::02Y5
Q@0ZAh00:TMk0080:TIg02L0:TM`02Q3K00X@7<09CYe02DkN00Y?GX0;T9m03a:NP0dC7l07dn3025;
P@0T?hL09CN602PjP00_>hX0=42803M7Q@0mBWT0>dad03]@N@0mEWP0@E]e03]QN00eDWh0>D=l04a5
I@1KDE80F6QM049YN@0WCi4032ZY004>Z@001iD0006G0002KP011;P00@R`008?Y`0Q;8X00P10BWD0
3P1ODdl0GcXW03hI3P0K1@402P8000H200060P401P4000@100030@0010000040000000000@002@00
0002004000040080000100000@00004004P00000303oool000X0ooooH`0000000`0100000P400040
0004000000800@0000<000000040000100005P0000002P0200000`4000P60P0<3PL03QTA010T9001
1:`000:b0000]P000;L20000]P0M0001Z@0008400B:>00TWS`0;9iH032RR010[W`0A;Id04bbJ01D]
T00G;hH05BZ501@XQ@0H9X@06BJ301XUT@0M9Y408BV:02@/R00V;8L09c2502PiN@0f@W80<4Qa00m;
R005;hh00A6W0000UP000;H01@000;L50000^080002b00d0002I0000]P015j@00BN:00@RM00M9fD0
6c9b01`hQ@12?E`0?SLa02`I500L20D00@0000T0000000@00P000000000100000@000`0000040040
00030000000100000@0000L0000000D0104000L30@098f401aj;004;[`030000^`0M0001^@002il0
0QnX01PlQP0N?HT08CV702HnN@0M>h<09d9j02<nSP0W@X/09d6=02Y7P@0_BG/0:DF;02a4Q@0S@XD0
84Mo01e0K`0Q>6T07cB>01PbV@0L>I@07Cf>0210S00P@HT09Tb002]AM00[DVD00P0/D5d09`0YBe<0
9DIA01m1D@0M?e@07ciL028jH`0U?g<0>DYg03ICO00WG8809eJ202M=P@0/C7d0<Tal03I8P`0hB840
?Tan041<M00iAg80;dQh02M>O00fEGL0?UMd03];NP0nBGP0@DM/04m9F01KGe<0CfYZ03ELP@0E@YT0
12RT00<EVP0018l00@>g0042_0011;L00@Rc01<QU@0202HiO@0;03i?K01KD4P0GCHR03PE2@0D1@40
1P8000D200040P000`400081000200000`010002000000<00@0010000002008000800`000`020017
000000`0oooo000:0?ooof<0000000<00@000081000200000P0100000`0000000@00004000030040
0003004100010000000000800@0040000002004000800P0000P01`@200/<1P0>61004RDV0045Z`01
0k00002f0000]`80002f01`0002a000SX0018iL02RFI00/UW`0<9Z@042bO00h^W`0@;iX04S:6018e
M@0?<GT032in00l[P00G:h4072b=01l]R`0P;hL08S><02DeQP0Y>Gl0:Sad0317K`0dCF/0:5Af01/l
O`0;6id0002g0P000;H40000]`D0002h0P000;L03@000;<0002g000FY`0098H00b1`018IIP0A8G80
5BUn02hjK`0aDeh0>3Xj03<E4@0100002`00000010010000000000000001000?0000000U00@1000E
7RX02RI>00/SH`044gD00`Mo0084U`000KL00@FU004>Q`028Hd05SQd01/jQ`0L?HT0842001dmQP0[
@gP0:DB;02e6R00/@HT0:d>102m9N`0YAhD0:d>40293QP0SAW/083id020kNP0O>Xl05cJI01TjV@0J
?Xd06DF601]>Q@0UEgd0<E]b035HJ00203MCH00T03E;F00]AeL0:TII02U3GP0]@640<3iG03<oI@0m
BgP0?Eeb03=WN00]HGl0;5aj02iJM@0]E7T0:Tf202U;PP0[BX80;dB203=4NP0_@W`0:3mf03A3L`0n
Cfd0@59b03mEN@0kCWD0AdeT05UHGP1JIf80AVEc02IHRP0<@id01BRR004;X0011K/00@2n0P010Kl0
2@036J<022n@00P_T00H@Wh0@TmN06=A?`1A;aX09P`400`2000200<10003008100030@0010400080
0@0000@000000040000100000P000P01000400000006004000040000100000D0000400000`000P01
0016000000`0oooo000:0?ooof8000000P010002008000800@0000@0000000400001000000001001
000C0000000<004000030@000P4000<000070`402`X600hG3`089X000PVT0088U0031hT00@BG0P00
0JT07`015Jl00bJX00<SZ00<9J<02bFR00/UX`0@:Id03bVP00hYW@0?;Hh032ao00TZNP08:g/02BUk
00`TPP0;7Y@02RBH00TZV@08;Yh02cBG014kR`0M?8409T1g0359L`0cCWP0<Seg00<=[`001;D0006f
0000]`000;H00P000;L60000^080002c0P000;L03@005j@002J900<PP00G6f<05B9Z018UR@0P:gd0
7DEj03HnD@108Al04`H400/30P0300000P0000000`02000000000000000G0000000U01DA3@0B7R<0
2bTl010U?P087DP01Q5800<9L0000[800PV3000@LP0188004c1f01LcS00I?I007D2=01`nS@0XAg/0
;4n603E?P@0dAh<0;4>402a6N00X@7H0;Smi02M5QP0YAWl0946802A5R00O@9005cRH01TkU`0G?Xh0
64N101M?N`0TEW80;59V02i>I00203A8HP0W03M1G@0/?E/0:ciM02DjHP0T=V@0:3MH02hnI00fBGH0
>Uab03MSN00`Fh00;EUm02iENP0_CW`0:TMn02Y5P00/AGh0;d>303I4P@0e@H40;3Id03<fL`0mAF@0
@E]Z03]JNP0iDH00@Dae059AJ@1RFed0FFAS045VM@0SGH/03c^S00H][@021k/00@6n0041_`010<00
0A:/00800B2K00T022n:039?K`1IG5@0IDX^04@O3`0M2@802P4000D100040@000`030@000`010000
0000004000020040000300@000000000000000<0000000<00@000000000200000P030003004004H0
0000303oool000X0ooooHP000002004000@00P006`000000300100000`4000<0000200001`@100X9
100@<Sl03BYc00<@TP0456`01QAE0046K@80006E01d00QR^00DWYP058Z@032FG00XWUP0:8j404bZI
010[VP0B:YP062^A01LYS@0G;HT06Bn501XbPP0G:gd04bF@018VWP0@:Ih03bVN010[V`0D;IH083>;
02TcP`0g>W/0?d1g04a2J00=8J400A:]0007/P020000]P030000]`000;P0002h0080002h1P000;L0
4@000;P001VT000XS00388<06bM_01P]MP0D9IH07Qf2018/S@0b=FL0Ac0_02`R6`0S3`/03@820040
000000000@0001P0000002H00@00018?2P0A7A`03BP]01HT9`0=9d002add00H?EP000Y/00PUa004>
K@007I`03bNB01D/U`0E>iD05cnD01XoTP0OC80095J103IJN`0kD7d0;dB302a3M@0Y?FP0<3]a02a5
QP0^BX00:DJ<02U8R@0V@Xd06cVG01dhU`0G=iL07Sf>0215QP0]BgP0<4Uh02U:N`80<DUh02L0<Cie
02TlN`0X@WX08Sml020kOP0S@7H09dEk02a;P`0aDX00=UF003E<P00eBX40>TN003a4PP0mA880?TR2
03a8M`0lC7L0?U=e03MBMP0[AWX0:3Yl02hmK`0fE6/0?eef03e@P00mCG`0AE5e05MCI@1NFed0FF]T
04AYM@0QGI003CRW00<;^@010[d00@6o0040`0012[@00P014jL02P0589T094Qi04YFI`1RF4T0IChW
04<K3@0I20801`4000@100020@0300<000<0000000@00@00000000000000000010010003000000<0
0@00A`00000<0?ooo`002P3ooomR00000003004000030000104000@00P000P010006000000D00@00
30000002004000<00P0000P01@8100X70`0D<3<042aV00@EO`0685D01aiW0046L`8000FH01d00aV]
00HXY0068J<032NE00PYSP098:404BZJ00`/V00@:9@052V9014ZPP0C;H00631k01P_N`0I<7/05CF:
01HhU`0D=YL04CFG01PdU00L<Y809c:803<gO00n?G40@DIb04Q?K00L>Xd022FQ004=[`020000]P03
0000]`000;P0002h00<0002h0P000;L20000/@0@0000W@0009<001>>000RR`038JL0736<01PbR00G
8i@08am^01@_LP0]>fD0?T9302e>A`0f:2007PP400@100800@0000<000000040000000005@000000
9P050P404P`8018K5`0A:R/05BXd00/SA00:6D8010UH0089J@0225d000]g000H[@0?9iH05C2<01Dk
T@0L?I805CfF01A7R@0KDh/0<Uam03aEN@0_Bh00;4Yc02Y5FP0/@FX0;4J703A=P00^AXL0;dZ502a7
Q`0P?HL07SUm01TgNP0L?8807T:70359NP0gC880=51n0P0jBg`09`0g?H40;3Z902LmS@0V?Xh093nB
02U3Q00ZBX@0;Dj502m;Q00bCH80<T]j035=O00cCh<0>51o03E;OP0jBWl0>DMk03]:N@0hDW<0;eUe
02UCP@0VBhD0:Dil03IJMP0nGWP0?5V003IKOP0fH7`0@Uid05=NJ01LIf<0DWIZ03E/P@0GAYl0116f
0085_0010Kl00@700042_@020043^00900@SW00DA8X0;db204eGIP1UED/0IS/X03/F300C1@401@00
00@00`0000<00P000040000000000P0000001P0100000P0000@000050000100000800080000000@0
0@000080000100000P00A`00000<0?ooo`002P3ooomR000000030080000400000`4000@00P000P01
0006000000<00@003@0000000`0100000P000040000200400009008000040P4041XB01@^<00@:V80
11Aj00HRE0078g/000F9008000FO01d011VL00LXT0078:0042RG00l[R@0=8Il04bfI00h/VP0?99P0
4b^<00`ZR00>:HP042V600hWQP0=;h/03CZB00doU@0;@i802DN@0113S`0C>9006CR<0297N`0]DVD0
>5AW03mDI`0]DgL05SnC00HIZ`020001]P030000]P000;P0002h00D0002h0P000:T04`000800001n
000:PP005hH00b:X01/`TP0H;Xh0622B02DQHP0A:g8083E`02m:F00VE5P0?3H^02dF300?10402@40
00D0000200001@01000A0000000W004000020@003`X6010G4`0C:bT052m900PMJ00745`010YC00@D
D0023EP000Un000BZ`0?9hd053>201doQP0P>X`05c^F01I7R`0MCXh0=5Un03mFM`0]CWh0:Taf02I7
K00ZAgH09dZ603ABN`0`CHD0=523039;O`0R@GX07C]_01HeJ00E>GD074>502m:N@0jD7P0?EMe0080
?e9j02D0>DN002]2RP0UAH`09TR=02I=S@0YCH00:Dn002I>PP0[BX<0:dR402I:P00UC7l08Dio02EB
NP0UBgh09DB602Q0Q@0^@XL0;TMo031=O00^Bh40;TN503E<PP0mEGl0?V1l03QYP00cIWl0;F9l03IU
MP17HVd0Ff9W05ifH`15MGH08eZC00TY[0034kD00@Nl00800@700P022Ih0300379/04SNH02M0Q`0k
CWH0DEMY06UCBP1J=R80;A47014200050000100000@100801@4000L00P400040000100000@000080
000300000`4000<00`0000<000000040000100000P0200000`030000000000000015000000`0oooo
000:0?ooof80000000<00@000080000200001P010004000000D00@003@000002008000@00@0000P0
30X600lG3`0D:bd04BYO00@DN0098Td00@>X0004[08000F[01l01A^F00TYQP077id05B^F01H]R00?
99d052fJ010YW00@99T05Rj@00l_UP0C;IT05bjI01D]V`0F=9L05c^A01PnS00HBX405U2101I:R`0D
?Y005cj:01m>NP0VDfT0<E5T03QCHP0eEfL0:deo010VX@001KD0002/00H0002h01H0002g0000]P00
0:00002P0000L`00094000>?000?Q@048ZP072nA01P]SP0H8HX09R=U014ZQ00P<GP0:3mK01]=K`0n
@3d0?2XI02HC2`0G1`<01@400P02000200400003008100010000000000L0000000<00@0000000000
00001`0000009P0100002`L400hC3P0C:bH05CIO00LIWP010h001@]?00DHC`023f8000R:000=[00<
9Xh07D>601i1SP0V?8T06cj@01Q:P@0OCXX0>5Uf045CK00]B7L0:dIj02A1SP0TAH`09TR=039DN`0_
E8@0=EB003E?N`0W@WX08c^401dcP00N>8809DF8039@N00lEFh0?U]_0P0hFW/09`0`ChD0:Db;02A<
R`0QD8/08U::02AAQ00RDh@08Tn502A7Q@0T?hP0842<020nSP0P@8T08d6502TnR00/=hP0;3V902hk
R@0e@X@0?4Mo041:OP0oCWh0?UB0045MN@0oIGD0=fik031/P00[HhH0=Uj004ENM01LIVH0HFmN05=j
J`0dJh@04d6Q00DT[`014;L00@6o0041/P020084U`0;008;W`0C8:L0:SV80313O00mCW<0F5QS06QA
A@1C:QT090/400`0000300000P04000200<000800@0000L00P0000<0000300000`00008000030000
0P0000D00@0000<00P00004000010000A@00000<0?ooo`002P3ooomX000000D00@0000<000000040
00010@001001000<000000030040000200000P0000<00@0000T00`4000/8100?4``05bHV01@YE@06
6Vh02b=40000^0000k@00P011Jl08P067Z002BZ<00LOW@0I;ID06Bn900hVW@0E:i/04RJK014SV00E
<8/03c:?01HaT`0K=8l05CBF01`gU00P=i408SFA0211Q@0MAH<06TJ?01]6SP0LB8T06TZ601U8P`0U
BGT0<4i]03=GJP0aDgD06S:E0004/0000ZD0002K0000Y0000;030000^00I0000XP00098000260000
QP000GD0006500<:QP0A6Wl031nV01d]TP0H:Y40622>02DRM@0?9Y4082en02LfIP0H?Xl0?4AL045:
=`0f=B809a<;00D100030@000@0000000002008000800@001@0000000`0100000000000000080000
000W004000020@002PL400`B300C9b805cEI00@?P0021VX01@]?00<=GP0127d000FM0008/@078Y@0
5TB=01Y6T`0VA8T084N<01a@O@0PDXT0>eYf04=CJ`0/@g00:d5h02E2S`0UBXd09Df9031IO00]Eh80
=5In03E@O@0]Ag@0:3ek01dcQ@0O=hl0:4F<03EAM`0mF6P0@5]Z0080?5Ii02L0=Db302e4R@0[AH/0
:4Z902Q>R@0XCX/09df;02Q<S00YAHh0;4:<02Y1SP0X?Xh093b802PjQP0`>hL0=3j503E2P`0dB800
=Tio03M@N`0hDgP0>UIn03MKP`0dHh00>6=j03U/MP0fJgd0<FJ303EQP@16IWH0Cf]/05IaHP1GNfD0
@WIg029HT`0<=jP00QZe0042_P010K<00P010IP03@020YL03A:M01l/S@0T=H00<cei04YBK@1LGF00
JDPj04dS500N2@<02@0000@0000300000`0200000`0000000@000040000300000003004000010@00
0@0000<00P0000@00@000080000300000P000P010013000000`0oooo000:0?ooof4000000P010003
000000800@400P01000020010@000@000040000000000@0000<100040@000`002`00000200400004
0080000300000`00008000@00@0000P02@@200l<1P0I7QT05bQ200TSF`000KD0002h0001]@8000>b
02801QfJ00X/P0087iH06Bj:01T`N@0>99805Rb>01@XS`0A8Yl052n@00h`S00G<hh06SN300l`S@0G
<9H06RZ?01TUS00G=84053j501I6TP0JCXT07UB101iFNP0OEWH09EI]02eHI00dGV<0>EI^02HnQ`02
3Z800@Z>0002R@0008`0002Q0`000;P07@0009@0002;0000RP0008X0009g0004SP0E8H405b1h00dK
X00L:XD05RR;01LOV`0R7XH032:J01hZQP0U<GH04RVK02hkLP0bFUl0>e1903dW700<10401P8000<0
000100000P0000<1000200000@0000L0000000<00@00000000000000100000020040000W00810003
0@002@P400`A2`0D91d03AaR00LFO`032Vh00`aG0043UP000KD0006h0002^008<iX03D6D0196V@0Q
Bh/0852<01aFP00PEX/0=5io03eKN00bBG40<d5d02M3S00UC8T09Dn702aEN00[CgD0;Dme035@O@0f
Dg<0<4B001dfTP0L>IH08T:>02m?N`0fDfX0@E=[0080?4mm02L0<d6702XkS@0T?Hl09DN<02I=S00T
D8d09e><02E@S@0WCHd09db;02M:R`0RB8d06D6=01lmQ`0Q>H@093f302M2P@0ZBgh0:e5l02aENP0[
EWd0;UJ502iBR00^EXP0=ef303iUO00oJG/0>fan03EXP00nJGL0@fa`04e]I@1GLf<0DWI[035YQ@0D
BYl012Nb0044Z`010KP00P010J@03@010IL01PjC010QU@0J;HT0;SQm04E>K`1<Ffh0H5YK06M2;`0n
60/05@<000H000050@000P05000010060000100000<000010003000000<00@000P0200000`030000
000000000004004000030000000100000@0000800@00?P00000<0?ooo`002P3ooomN000000800@00
00@01040008100010@000@000P0000020081000;0040000000000@00000000010000000000800005
0@00108000@0000200002@0000001P0100000P4000<100050@001040008100<00@0000X000000080
00050P402PH301HD400H8bl00@>a0041]0000;P0002g0P000KD08P066J402B]n00`SSP0M<X406S5/
00hSRP0I:h005BYj010UVP0C;H/03Rf301D`R00J<gl042f>01L^V@0H:8`052>801<aP00B>X@05T>A
01e?Q`0NDh4085Ql02=LL@0ZFfH0;UYS03IMHP11F6T0636I00HLU@065hL00@J[0000RP0009H30000
^@0M0000TP000900006C0001T`011W/00Q2M01XWQP0K8gD02QFS01XWOP0E9X@05QjK01hKR@0:8Ih0
6BZ?01h]P@0A8j00:S=i01e<NP0^D700C3`f01/?1P0B1`801P8000<000030@00104000<100010000
3P0000020040000W008100030@002@L300/?2@0C81P03R5J00PIN`043fh00`iT0001Y@000;`0006k
000GZP05;J802CZI00a2UP0LCHX07EF<025HP`0SEHX0;e^103MLOP0dDGD0=dMa02a7Q`0YC8L0:4V5
02M=L@0YBF80:4YY02]>O`0eG7H0<df0028mT`0N?9@094>?03=?P`0hD7L0@4eb0080=TB402L09SJ?
020`UP0K>9407dN:01m=R00NEX@06eZ301aBS00KBY007DZ?01e<SP0NCHh06D^A01doT00O<Y<08S>@
02LiR`0]@XH0<4^4035AP@0aE880<UN302iDR00]E8T0=UZ4041PO@10J7T0?6]l03QZO00eIWP0>5mc
04]OJ@1KI6<0GW1R045eMP0NGI<01Aj;0085X@010kd00P010KH03P010Zl00PRV00HDY@0C:9X0:cn5
03]?N@0oEGP0DUa[06YJC@1L=1d09`d400l200090@001P<00P060P000`050@000P40004000020000
00800@0020000002004000030000000100000@0000D00@00?000000<0?ooo`002P3ooomN00000005
004000030P00104000<1000200000P01000300<100800P00100000001@010000100000@000040000
0P0000<00@001@0000001`0100000`4000D20@050P401@<100@20@020@000P0200030040000800D1
00070`404Pl;01@O9P011:h00@:c0000^0000;L20000]P0R00<@Z@0H;X804BUa02<aJ00I:f`03b>@
01/ZPP0F9fT03bFE018ZQ@0>:GX05Bf101/^NP0?9YD062fI01P/RP0@8HT04BZ9010dQ`0G?YD08DF>
01i0T@0PA8h08DR502E:O`0TBGh09dil03AEN`0G;Y/01QJJ00XEO@052WP000610000W@80002h00<0
002i0001V`000X@00P011Gd060034h4042b601PZNP0G9GT02RBK01PWNP0D9X805B2I01/IS0078:00
52VB01L]Q@0@9:40:c1n01XiOP0T?G/0C4e?02lZ500R50T03P@200<1000300000`40008000H00000
0`0100080000000W004000020@001`D200X<1`077g0042=A00XLK`0656D01A1R0001Y@000;`0002k
000D[0029ZT013:L00HkTP0EB8H06EJ802AGOP0/Ch@0:e:602iFQ@0`CWT0=d]b02e:Q`0]C8H09d>7
02I9M@0WD640:4MS02U9O`0aFWd0=E9m02M3S@0T@Xh0:dR703QDO@0kFGH0@5=_0080=dQf02L0:cZ0
02T_S00V>h<08dF1025;P@0UE7T0:5Ac02E=P@0T@8X09Sn:02Q6RP0XBhX0:d^90396R00e@HP0=D:7
0394R00bBXH0=Dj403YDP`0hFH40=Uf102aMR00YG8T0;U^603AOPP0gI800>6En03EROP0eH7`0?EYf
04UEL@1LG680HFYK04ijJP0/JhH022::00<9W@021K`00P010[`050010KX00@:e00<;[@0?9J<0;4:9
035AO`0bCWX0@5=c05aNGP1[ECH0BRLA02<:0P0?10003@<000T4000710001P<100D200020@000P00
10010005000000030040000000000000008000000P020005004003`00000303oool000X0ooooGP00
00000`0100000P00008000030080000400<000040@000`8000<200800P4000T00@00000000000000
0@0000<0000400001@0000@000040@000P020@000`010@000@000000000300000003004000020@00
10810080108100@00`8100<1000300000P000P010000200200000`0000D10@0@2`P011FA0044Z`01
0[80002h0`000;L08@0E8ih05BVA00hRO`0S96@05b=b00hTS00N;7H05RQS00dYQ@0C:Gd042J001HY
SP0K:84041nH01LZVP0H;H/03b:<018ZQ00><XD05CVB0298P@0QAH@094^702MCNP0XEg009UY]02AN
K00aFGL052RN008;Z@062i401`Uo0042TP020000^080002i01X000:^0004X@023YT00PjI00l/PP0>
<7h04R]n018XP@08:8/05RYo01H[NP0E9GT05Qmg00PRR`0B9X@04bN2010QXP0^<7`06SAZ01dbI`0m
BU@0>dlj03T[6P0N2`@01P8000<000P000000`01000:0000000U00H30P0J93H022AQ018UA`0<7V80
2QUK00PAGP000JD0002l0006V`004:`00An_004XY`01;Z402d:@00eBS00VDGX0<DIo02I4SP0UBX`0
;4^103E?M@0dDX@0>4mm0355PP0RA7/08De`02E:K@0YBgX0<EJ003QENP0`Ch80<4^6035@PP0gFGT0
>5eh03aDIP0203=6F00W02XhI`0X;8P083J301/nRP0J@hP08DJ30298O@0VBGh0:4Qn02M:OP0/ChP0
;5>7039FQP0hEh40>UJ103=EQ@0YEXP0:5:902]=R@0_ChP0<UF4031LP00ZH8H09ef902IGS00XEHX0
<UR203]HO@0oF7d0@E]m041LO@15HGX0DUiY05USH01ILV0041^W01<[P`074iT01A6R00800PJC01D0
0@><0043V0032j40:22?02@lS`0VAh809dJ003=>M`1=GFH0H6I?06E5:`1380`07`T200l4000:1000
20@100P300060P0010400080000100000P010@02004000P0000000<00P000040000300000P020000
0`01000000000000000l000000`0oooo000:0?ooof0000000P0100000`0200000`0000D3000300D2
000300@100030@000P0000800@0000H00`0000@0000400000P0000@000040@0300<1000I00<00002
00000P000080000000000@00008100040P400`8100@20@040@40104000@000040@000P0000400002
0000104000<0000<:U801QJ>0046U`051G/01`Md0002T`020000[P0P010SX`0B:9X03QjM02DPR00H
7XX042F:02D`I`0H:F0032V301<XQ`0?98P052Mn01XZO00?9Xd062V901HWQ`0>7iT05BV>01<]SP0G
=hh09T]]0253MP0SBHH0:Dmg02YAJP0/FV40<6IL03IIL00E8ih0006g0001^0000;T20000^0050000
[`000:40002E0009U@004I`00P0?:IT05`0F;gd04bj801<]S`0A;8L02b:K01PaT@0F<8P04B>0018V
L`0998003aem014NP`0@8j<0:Reo01P^IP0E:680:3]K02MKKP16@3P0<1L=00`30@0400000@0000L0
000000<00@000000000000002@0000009P010000108101PQ;P099U<052@m00hPE00=7Dl02Q=J0002
Y0000JT000BH000;[@007K400BR[004^Z@0<@iP045>>02U>N00cA7h083jC024oU@0TA8`0;4il031F
OP0nDgD0>DUi0291OP0MAH4084An02M5P@0ZC8D0=UQf03=IN00iE7T0=E>003IIOP0dFX40=eIe0P0]
AfT09`0U<f/082B<01T_S`0D=Y405Sn00216KP0M@Fl06T9m01a8P`0KC8P08U6;02=CR`0TDX`0:4n:
02U>R@0[ChP08eF602AAQP0TA940:T:>02]8R@0[DHP0:UR902MHR`0WE8X0:U:;03EDPP0oE7h0AEIl
045KO@0iI7l0>FYn041RL`1>GfT0?dV601DLY00P<G/03AnC00dTR`0200DCN@0E00<<MP0118000P^D
02LMS`0K=iH07Cf901hmP`0WA7T0?U9a04iOJ01ZGTX0JT4U03hH2P0J2@403PD100d70@0:10402@80
00L2000300000P0000800@000P020007000000800@0000@00P000040000100000@00?`00000<0?oo
o`002P3ooomQ00000005004000020000108000L300080`000P070`400`050@00100000D1000200@1
000500D10005000010000080000300001002000030040000104000@1000300000@00000000020000
0`4000@100040P400`4000<000<00`4000X00P00008100030@002ahI018[BP085X`00@Qn00X9@`0>
3c`00@IX0P000[D07`098jH02RZO00dOW`0W9H`06B:>010TR`0U<fD05biR00l]U`0F;IP03bRJ018W
T00H<8T03B^=01DVQP0C88802R2E01LYR`0B:iD04c6H0293LP0L?7@083n?02I4PP0W@WL0<DiV03MK
G00nE6T072ZG0086]0020kH00P000;T01P000;P0002T0000SP0008d000Z7000HRP803bj901H06S1k
01L_O@0F;Gh05R^5014XW@0K<i@0632F018WW00F;HH03B:F00`BS@0<4hX042BR02LYP`0E:G@04Ae/
01/XH00DBHX0BdQE04P/600G2P<02`8010000002004000L0000000<00@000000000000001@000000
9@0E4Pd05QhU00TVA@0E8S803b18010PAP0<4UD00@::0001Y`000YD000B^000J/P00::`00BbZ00i4
V@0HDhh0;51i03=7P00S>i@08SNG01hgU@0QAXL094n503QBK`0gBVd08Seh01hnSP0P@8X09TB402Y?
R00cG7/0<5mn03MLN@0cEh40=EN002iDQ00dFGT00P0/CW`09`0X?8408SR@01dgUP0J=9P07C^40214
K@0I?6T05cN301`mUP0Q@Y<09DR?02M8S@0XAHd0;46=03=4Q`0hB8D0>4mh03=CO`0/D8L0:4j902EA
S@0SEhd08EV=02=HSP0SFHX09U^802aIQP0aEHD0=EJ503EJQ@0/HX@0<VN003]QN`18GWT0>4><01LM
Y00R:h004B2601<[L00200HDO`0E00@BP`011g@05aV901hPS`0C<i/053JE01<dS00K=HD0=45l03m@
MP1MGV40M5a005`d6P0`4PD05PL10147000<10001`<000D100030@000P00008000000P0100000`00
00000@0000400003000000800@0000<00`000080000100000P0100000`0200000@000040000l0000
00`0oooo000:0?oooeH000000P01000:00000004008100050P001P<000P40@8020<100@01`8000L1
00060@001P800P070P000`0600001000000000040000000A004000040000100000@100050@000P00
00<000020@000`4000@200050P001P8000D200040P401@8100@100030@000P0200001`0=61405bTm
00/FN`012V003P`Q01<D<0000I@00P0009409`036Yd012BM00`MV00X:HP06BN@00hUUP0O;f`05C1b
010/V`0L;iH042RO01<WW@0K=9D03BfK018PT@0B6i002b>S01L[V@0@:ih042^J01dlN@0D=X<073VE
01lnR@0N>X009dIX02m?F`0kCVD07BjB00<</P021K@0002i0000^0000;H0002J0000S0000;8000BR
00`RT@0200l/T`0G01TdR@0D<H804RYo01DZQ`0A;9`06c>A01PdSP0A;X/05bUg00lLN`0>5X803a^=
014SXP0S9XP04B>0018JL00H7V@03SJD0493J01G@bd0;a/=01`80`0500000P0200001P0100000000
0040000100000P40004000/0000002H01@<1014>2P0C6Qd02RHg01HN9`0A83d0420m00dBD@010Wh0
006D0001T`000YT0016Q000NY`02;J/06TJC01mAS00_CgP0<TV002DnT@0R=iH07C:F020oR`0P@HH0
<TUd03I<M00[A740:Cn502@oRP0[BH80;EF503ESN@0^HGL0;Uaj035IQ00eDX<0<4f403EIO@80:EIn
02L0;4V302Q2R`0N>9@07BjJ01/fR@0H=W4063Ac01hlRP0XA8l0<DR:03M:Q00kCX<0@TUo0413P010
Ah00?Tmo041?M00lE7D0;V1i02UQP00SHHL07V::01]PS@0IFXd08eUo02IKM`0VFGl09eB802iCR@0b
E8L0<UJ403UKP014GgX0?F5o02]6TP0E7ZT05b2D00`FSP0?7W<00P063gd060065X000bN3018OPP0G
8H<04R^F01D/U`0B:Y@05bB=038gOP0jDWX0Bea_06=QFP1_DCD0DbdE02L@0`0E1`003@<000/20003
0@000P0000<0000100000000004000800P0000@00`000080000100000@000P000003004000800000
00D00P0000<000030@000`400080000k000000`0oooo000:0?oooeH0000000<00P00004000000000
1@000002004000060000000100000`4000H200060`0020<10P070P002@080`001P4000L100070000
2@<000X200080P001@0000800002000000800@0000P00P0000<000030@001P8000H20@040@001000
00@100800`4001001`8000L30@060`401`@100P50@070`401P8000@100091@<030h801HF6@0>4C80
0a8`00dC80020YD000=V0P010GP09`013X`00aej00dPL@0M8H<04b>@00lXV`0M;hD052n501HWVP0T
;Y404BRP01<VWP0N=Xh03bb<01@PR`0E89H04RBR01LZUP0B;IH04RVM01ddPP0C;Hh05RnL01TgT00K
<h00:D9P02i5F@0fB6d07BjC00@@/0010Xd0002f0000X000094000>>0006U0001J803b2I018UW002
01H]W00H01dgT`0H;iP05BZF01H/QP0B:9X06C:A018eR`0=;8h04bR500`PP`0A8HL04bFC00lVXP0L
9Xd03b>:014IN`0G66d03R^M03@nK`1:DE40D3dd03hI3`090P0010000P0100001P0000000@0000<1
00030P400P40008000T0000002L00`4000<20@0>2PH04AHD00hT9P0G7B00424f010P=P020i80006>
0000T0000I00006F0009V`005J<00b^/02A7SP0XC8P0<Deh039=P@0Z@Xl09cNB01h_V@0P=I407C6<
02M1N`0]CG`0;4ig02a;PP0WAXH0:dn102aKQ@0bIgP0<5ig035GN00eFH00>eEn03A?QP0cEH400P0_
DhD09`0]BhH093b=020_U`0L:9/06C:@01LeQ@0H?8H084:?02=2T`0ZAHd0;dV903I<Q@0fC800=TZ1
039:PP0YCHX0<DV6039=P00`FGd0;En002YPP`0SHH<08eb902=DP`0aEgL0=5Ud031HO`0aDXH0>4j5
03mBPP0oD840?eEn03I[OP0_HHP08DJH01<O[P0=5Jh01PZ_00P=V00200L=OP0B00TSL`07;h403b:8
018QRP0A9IL05RJF01@WU@0I88h0<3Qm03ECP00nF7T0Ce]`06MIF01bC3H0E2/D02T>0P0?10001P40
0P030002004000060000000100000P000040000200000`000P0200000`0100000000000000020000
00040040000000000@00004000800P4000<00@00000000000000>@00000<0?ooo`002P3ooomD0000
0006004000030@000P800080000100000P000P000003004000800P0000<00P4000H2000810400P06
0`0200H1000800L000050@00208000/3000;100030@000P30006000200D000D00`0000H00P0000<1
00050P400`4000@000040P0200@1000@00L300080`401`@100T60P0;1`<02P@200P40@060P001P81
00L50P0?20D03@h>00HM7P0?8CP00P>90042G080002I02L000B7004FHP0=878061V500hNS`0B9i/0
7Rf<01D]Q`0I9GX08BEm00lUU`0G9iD08SN2014/R`0G:9H06RZH00hKY00C:9804Bb:01<SV@0P<8H0
4bZH01<[X00E;YD05bZ8028jLP0T>gH0;Sn401`/U`064Zl00@>=0000/`000940002>0003V@002I`0
01:S018VV`0E;9`00P0F;Y`0600N=I806SB@01`_Q@0Q;G/072Z@01haQ`0H<HT04RbN01H]V`0@::80
5R^M01@]W00;9JD05BNA00/UR@0?6Wh05QUf00hWS`0/=6P0:Tib04E<I@1J<BT040L200L200800P00
00L00000004000020@000`400081000100000`0000P0000000L00@000081000:1`@03Q4<010O6@0H
6QT03b4a00<0002n01d0002R0001SP000Jd000>X000=XP0B=Z80;4B:02m9QP0/C7X0;U=h02m=OP0`
@X<08c:@02D_S`0M99T07cR7029:QP0RDX<0:EN602QDQ00ZFX00:VF202i^N`0_GgP0<eAg03ILN`0k
EGL0<db402i>Q00202U=P@0W035;OP0Z@Hd08CZD024iUP0Q>Y007SNH02DoS`0V@I<07cZI020kU@0S
>Y@093RE02@fTP0WAXP0;4^302m9QP0fB8P0?Df303eIOP0lHX00=fAk02mVN00^HWl0=5ab03UMM00l
Hf/0=fEd03=OP`0dFHH0>5B603QDQ00]H8D08Un=01a?UP0F=Z@03aRa00lFY00:49d03QF300802A5k
01<04Ree01@iP`0C9YP04b:L018RW@0E8YP052JJ01TLTP0_>H00;df903U;O@11DWH0CUA^06UGE01^
Bc@0CB8A024;0`0=0@00100000<00`000`0200020040000300@0000200000@0000P000000`010005
00000003004000000000000003@00000303oool000X0ooooD`0000002P010000108000@200040P00
104000<100050P000`00004000020@030080000600<000030@001P<000T30@080`001P<00P070000
2@070@001`<000T2000:0`002`@000`500090P001`0000H1000200D1000900L000050@0010000040
000200000`0000@1000200000`000080104000<00`4000H200060`000P070`4030091@801P@100L2
0@070`401@8000@20@0>1PD030d>00XN7`042HD00@:R0000O080001n02D000R0000EM@0I97L07Qml
01DSR00L:IL08R^=010RS`0L7Vd08aeV00`QP@0J:8009Bia014WR`0I:YX07BbG00hHY@0G9iD05BZ6
01@QWP0T;hh04RVP00lXY00A:9`03b2E01LbO@0I=Wd093^=01L/V`043XX00PB;0000W`0008d0002G
0003X@013Z402bRS00805BjM0P0A:J406@0K<i4063>;01/]Q`0Q;H405B^;01`_P`0H<HD05C6=01X`
R`0G;YP06bnI01X]VP0B9:0062R>010WS`0C79805AV800hQR00V9fT07Cj003A8NP1OAD@0:a/=01h;
1@080P000P0200001@0100000P0000<0000200000P4000800@001`0000020040000U00P50`0<3PT0
3a`C01HG5@0=8B`01@]T0084R0000:h0006P0001OP000Hl00@F;01L`S`0C>:40;T:90314Q`0TBG`0
9dij02i>NP0bB7@09cQn02XaP00N8YX08CB>01m3S@0MCI009Ef902QPPP0XI7l09fb002eaMP0bHf`0
=EQb03MLO`11F7<0=Dj102a?Q00202Y=OP0W03M=M`0]@hT08Sf?02<nS@0U@8L07cZF02LoRP0U@940
8SbD02DmU00S>i808cZA024lT00]A8H0>TQk03m>N012E7D0@U]f04IOL014J780?6Ya03IZK`0bIW40
<5ec03=HL00iHF80>VQV035VO00ZGhL0;ER:035EQP0PBiD05D2N014`Z00=7[802@fb01@JR@0J9Fh0
7ReU008041n301L07SUk01dmO@0F:9/04R>O018RWP0C8Y`04RFL01DLV@0Y>HL09CbG03A0Q00fC7X0
>4ek05=JJP1UH5D0J4T^03lP300H1P402`4000L000060@001P0000L0000200D000800`0010010000
1@0200000@000000000000000@0000<000000P010003000000030040000000000@0003H00000303o
ool000X0ooooD`0000000`0100000`8000@2000200@1000400@200050P001@8000<100800P400P02
00001P030000104000D200070`0020<100/40@8030@100h03@H000T6000910002P<000/4000:0P00
2@4000H100080P002P<100X2000:0@002@4000P10080100000@00`4000<0000400000`000P040@00
0`050P001P4000H2000200D2000<00P30@060P401`<100P60P070`401`4001P7300A32L01`df00D7
P`000Jl0002M0P0009@09`001Y/000bI01LXO`0Q:f`05BV4028YT@0X;8X03b2B028TK`0U96H03bM_
024^L@0V:E/0422201XYV`0M;IL041VV01dWT`0K;8T04bbM020`T`0A:iX042NG01<TT`0?7i/05bj3
01XdQ00R>I402QJ200<:P@052GD010Y^0085LP010H@00PZF01L/T@0>:il0636D01XbT00201H[W00M
01hcR`0L<XX07RnE020dT00C;9L06C2=01PcR00E;H/06BZ701@ZU`0H;9`06RVI014QV`0I:XH05BQk
01LOM@0H6g/031ZN02<LNP0G;HX0:Sb404a<G017@cL0@2<F01850@070P00100000<0000100000P02
0@0010030@000P40000000010003000000<00@000P0200009@091@<030h900lK4`0D5Q@01a8o00TG
>P0326D0006Q0001W0010Vh00@9m00hLW00I<hP04c^N0312PP0`@g<07d5/0290P00WAH@0<D]d02/o
M`0^=Vl08R:F024_S@0Q>hd06DJF01mOR00QJH4096b102U_O@0_LGH0<fEc03QLL`0hG7d0A5ea03MD
P00^Dh<00P0/D7d09`0hCgH0;dF802HlR`0V>HP08c^601hhT`0T@8@08T2>01m0S`0S@I808CbA01hl
SP0L@8d0:TN50399N00gDFh0>Ea]03ISM00nGW@0?F5d03UXN00fHgP0<E]k035FO00bEGd0>UaZ041S
H`0oHf/0>5ii03MJQ@0I>Z004BR[00LC^0053K`010K000D5/`0F7G<0:d=L00lQZP0201L/X`0K02M1
P`0R?7`05BFN010QX`0@8:<04B2Q014TW`0A79d08cb6024kPP0V>h408DF602M9Q012FW@0DfEY06YS
D01VA2P0>aT901T6000>0@002`8000h2000;00002P0000P100070P00104000800@0000@00P000040
000100000P001P000002004000@0000000<00@00000000000000=@00000<0?ooo`002P3ooomC0000
00080040000200000P4000@100040P000`4000@100030P02008100090040000000000P0000<00004
0@001P8000H3000:104030H100803`P200D03`L100X500091@002@@000P3000200P200802@8000D0
3`@100h40@0>10403@@100X3000300P1000300H0000300000P0000800P4001401@8000L300060`00
1P8000D300060P401P8000P50@0<1`@02PD200X3000Q1aP050iH00H;C@082Fd00P:N0000Z@020000
^00W0001]P008Z405bVC028`O@0A9Hl08R6@02`]Q@0>8YT07RAj02H/I`0B;GD08c9g02LYGP0A9Gh0
6bfI01d_U`0@7Z@092RB01lZS00?:Yl062nB00d/P00>97L04B>000hYT@0N<8@07cj:02I5S0021ZP0
10R6014DH00I96P01`]O0041S@0@:Y/06CFC00h/V@0H<XP0739n00805RVF01`08C6502<bQ@0P<Hh0
83J901TbU00P>8X083R401`[SP0M9h/05BVH01P/VP0F9iL03AnO01TYN`0C8X006Amk01hNL@0;5Id0
8aUi01LXQ00W=GX0>TQV03=ILP1J@cX08a4900l50@080@000P000P0300001`0100000P4000400001
00000`00008000030000100100009`0000000@0000P40P0<3PT03QXC00T?A0085bL02B@h00<;FP00
0IT0006M0002L@000Y802QF4018]P@0A>Yl0<4:102i2K`0L>F@07CUn0294R@0ZCH80:TQj038mJ00W
:8l092n:02<dS00F>Y`06eV:01UWP`0RK800:6em02Y]NP0cIGP0=V1b03UQN@12HVl0=5Yn02iEQ@02
02iCN@0W03QAL@0`BX00;DJ102Q1OP0V?8<09Cn802A2P00P@Hh08d>702I2S00Q?8/07SF<02@gQ@0U
?8d0:Cio03=:M00cEfd0=e]f045NO011H7h0@VMm04ATO012Fgh0@eQl04ADO00nCVh0@51`045HLP0l
GgD053ZU00dY[P075KP00`;10081`@020L800`>f00hJO@0O@g405T:F00806cND01D09Sad01lcL@0F
8i<04R2M018MX`0A7j@0426R00lMX@0M?hP07caj01`cP@0F>HX094>203aNN017JG80FVUT06eMB`1T
>b<0=AD701@4000>0@000P0<0P00200;0P002`@000P300030@000P000040000000000@001P000000
10010000000000400001000400000003004000000000000003D00000303oool000X0ooooDP000002
004000800P0000<0104000<200040@000P030@0010010@000@0000000001000300@1000400L30007
10002`D100d70@803@L200<03@H200/500070`000P060@008P070@002@8000`30@0<100040H10147
0@0A1@804@L200h3000;0P00308000/300060@00100000<000040@001P8000P100090`002@@000P3
00070`001@8000H200090`402P@200P40P080`406@T=00hAA`0<4D804Q1100H8K@000H/20000]`0W
0007T@005JD06RNF02<bP@0C:7`07R1j024WQ00D:9L08BV:02LbO@0B<HT092ml02TZJ`0>9h/062nI
01/cR`0@98X072>701TUS`0@:Yh05c2;00/_IP0=7X@03aYm00`XT00M=H/07TB@00<;]0000[T00PJE
00hDI@0G9W401@mY000<TP0E<IL06cR;014_U`0K<H/07Bio00805RFI01`08c>:02<cQ`0M<8X07cEl
01XeR@0S>X<09S^0020]Q@0O;X`0632G01LcU`0F<Hh042f;01T/N00C:XX06bB001lML@0:5j008AZ2
01DTP`0U;Fh0<3MR01m1P`1GAe<0?2TD02@A1P0?10400`000P0100030080000300<0000100000P00
00800P0002X00`000080000200000P00000000070`803@`700LJN`0:5D4021TX00HO?@023V00006E
0000Z00008H0005[00@>LP098hD033BL02U4Q00[A8407SA]024dP@0O@i409Df902M=P00d@f`0:bj;
02LbRP0V=XX073bG029IR`0TJX00;F]k02]VOP0WI7h0;fAk03=VM`0eJG80?FM]03MOM`0`EW/203=A
L@0P03YAK@0`DGd0;TYh02E0L`0Q?gX08D240290QP0M@8d09TN202U8QP0XA8409T:002]0O@0^@8T0
<41o02m3NP0cBW@0?EEb04MQMP17J7D0BFYc04QXMP16I7P0Af=h04AON@0mDgH0>E5c03MILP0FBYT0
2RJ`00HI^0043;d20081`P050081`@041;T02aJE0191T`0DA8L00P0I=h407@0M;fl062E[01@NL`0D
7g`05B6701DRR@0E9H`04RF:01/oP`0K>8<04RMm00XYS`0U>X40=EAo03ePM`1:Hg00FEiT06MEA@1E
<QX0:Q4401@4000;0P003@8000d3000:0@001`4000D0000300000@0000L0000000<00@0000000000
00000P010006000000D00@00<@00000<0?ooo`002P3ooomB000000800@000P0200000`040@000`80
00@1000200<100040041000100000000004000<0104000@01`<000L4000;1@403@L10P0=1`800`0=
1P802`D000L3000200H1000R00L100090P0030<100`4000@1P404@L101450P0A1`803P<000/2000<
0P002`<000H1000400000`0000@100060P00204000T30009100020<000L300050P001P8000T30@0:
108020@200P30@0I2@d03Q5700`A@P0B44401PQ]0001R`80002g02L000NA000EY@0J9iH08c:101<X
O00N87X08BN401@XU`0Q:HX09c9m018aR@0T;g`0:BY[00hWR`0H;iT06c>;010TRP0L8hL06BF?010Z
WP0G<8/02bmV00dNQ00?6Wd032R@01deR`0NA9000`^d0002^@021YD03QAU01LVL@053fT000bB01Da
U`0K>8/04BnG01/aR`0M;Wl00P0F9IT0700S<hX08c>701d`RP0O=G`06SF902<jP`0V>h0082f501l^
S00H<9L05c>G01HaSP0@;H/06Bah01<ZRP0K98007aea00XGX00Q6X805BB302D]KP0`=f807d6305M7
D`0l:A@0914600l40@030002004000<00P0000<00`000040000200000P020000:P0300000P000080
00020000000000L30P0=30L01aYk00XE@@086BP01Qlm008>H0000ID0002X0000QP000F/010ib00TS
Q@0<=9`0:DB402]4P@0N=6d08CB101m3T@0UCHT09df003A3K00[;X/09c::02HfRP0L?9L08UV;02AZ
P00]Jg/0:fIn02MTOP0_I7/0<fIg03EYLP0mIfd0=emg031FN`80<e5a0200>U5]031AO@0^BWP09D1c
024oNP0Q@8@08T2601e0S@0VAh80:DR602Q4P@0V@X00:d1m02i0R@0`@7l0;d=j03=:M00mEG80Af5f
04MXM@19JW<0B6Qf04ITN017HgP0A5mi03eCMP0iDG<0=eUb01I:V@0:9[001QVh00@<_@800P7200D0
0P7100@4^@0;5YD04T6C01A4Q`0201TgP@0M01d_K`0H9F/051ic01@OO00E8HL05B:901DUS00B9HX0
6cn301/hP`0B9gd02RV?02DjP@0eE7l0?F1g04YSL01IGV@0IeE505Db6P0Z4@@050@000/2000=0P00
3@<000X100070@001@0000<0000100001`0000000`010000000000000002004000H000001@01000a
000000`0oooo000:0?oooe4000000P010000100000000@0000<000040P0200@1000700<100020@00
0@00004000030@000P4000@1000200H30@0400L2000;1P802`H100`60P8030H100d02`D000P30007
0`001P@000L100090P0030@100l40@0A1P8040H001470@0C1`4040L200803`@000D03P<000X10007
0P001@4000@1000200D0000300D100070`0020<000801P8000`0104000D100060P001`8000D20007
0`409AXk00D;Q@0;3Sh06A0U00/>E00117<20000]P0W0000R`000:80622I01``R@0<9GT071ai01XP
PP0B;IP08Rb=02DdQ`0D=i@09C6902/aO@0C:Y80732C01PeQ`0<:8h05aj=01@RS`0A;9d06C>800/a
KP0?8WX05R1m01@VV00S=I0021V]00D?/@010kP00@:V00H9Q@094H400aF5014`PP0E<X006SQh01@c
Q@0L<hH08C6800807C6G01d0;3Z602PfQ@0Q<XD093=a024eQP0Y>H<0:CN002<bS`0Q=Y806c>I01Pd
UP0D=h/04CB001/bO`0D<8L062Ql01XRO0088ZH06aVA018NU@0T97H0:bIG01XaN`13@5T0Cd]304X/
8P0V3@H01`4000<00003008000800`0000<00P000040000100000P02000200<0000W008000010000
1`8100l91@0;7fd041i300dL?00665000`mO0002U0000;D000230001OP0128d00aRE00L_WP0R@hH0
9dIk028mM@0Y>h<08d2C02E6T00TAXL0<T=c02dcR@0/>XL0;3V802<nU00VF8T0:VMn03AZN@0_HX00
9ej4031QP00bIg`0<Vec03YZJ`0fI780=5Q/0080<e1_02L0=EAa035DP00^BGh08d230290Q@0T?hh0
8Cj>01m1S@0[Bh<0;4Z302Q6P00VA7h0:42502`oS00_?h@0;T1o02i3OP0bCWl0>En003aVN@0mIG/0
>Eeo03YKP@0kFX00>UUo03IFP@0iE7l0=UZ001A2X@053K`010O00083`P020<<00P7200<2`@041Kh0
2bn[00lgY@0@>IL00P0F>H`07P0I<hd052J<01<PR@0E88T06RJ801TWQ00G;Gd05S1X01ThI00H:fX0
72U/01HUS@0U;XP0:T^;02mGP@0oFW<0AUQ^05IMH01XES/0DBhE02D>0`0E1@003P@000d3000:0P00
0`8000L100060@000`40004000<00P001P0000030040000300000001000000000080000000<00@00
000000000000<`00000<0?ooo`002P3ooomA000000800@0000T000000040000300001@4000@20@04
0@000`400080000100000P030@0200D1000600H300060P0020@000X50@0:10402`D10P0:1@40500:
0P002@<000P3000:0`002`@000h60@0A1`406@/301<80P0?1P003`D000h60@0=10403`@000l30@0@
10002`<000P200050P0010000P03000300@1000300D200070`001`<00080208000T01P8000D1000H
2`P081P]00@OKP0:4B`060`I00XAA0021F`00P0008T09`0008/0002<00TDU00=9Y8032J6024PQ@0I
7X003RbH020/T00N<Hl03S>L02DeS00W>H405c:>02DaRP0O=8H032RK01PKS`0B7hd052fM01hdR@0=
<X8052Z401h[P@0C8i409bn900XNYP085:`00PFb0001/`010[@00PFf01<dU`0D>Gl063EV01TaI00C
;Wl073F8024hS@0202<gT00Q02`mPP0X>Wl09CAl02ThM00Y>g`0;CUl02`gN@0W=hH093Z701hfT@0M
=I@073NC01PbU`0M=hT04c>=01D[S00C:8L01RJV01HGU`0B6I/09amm02`RG`0H;X80<SQP02eAO@1E
ADh0AB@D00l70P080@000P000040000200000`0000800P0000<00@00000000000000100100009P02
00002@81020K:`0<8Ul05RM8018QI0054WD01A5L0043V0000Kh0002?0001X@001k400QFT00H]YP0O
@X`09DF002Y8NP0_@X408c^F028nU00O?i00:d9l02/jR`0a@X40<D2102LnS`0ZDXP0;5mn03YPL`0i
G7T0=U]k03MIP00dHGh0=FMi03eVL00lIVl0?eQS0P0hBg<09`0cCGT0;U:002i7P00R@8@08d>202<o
T00T?Y009D2E02U5R`0V@h/0:DB502M2T00W>I<0;CR@02`lT00a@X`0<DF;03A<RP0gEHH0@61k04=P
O010GWh0@Eam04AKN@15EWL0AEAg04MENP0YE8T06Cf>00`JT@063J400`>c0081`P031[h010fm014c
Z`0E>ZH06CfQ01/mU00201hkT00I01deYP0G;:X05BR[01LXZ@0Q:Z4072JP01/eS00J=g<052UV01@N
NP0W;gT08BV=02PZP@0X?XT0:42203M;N00oC6h0C5QW05aVE`1WE3@0B2HB02@>0`0C10403@@100T3
000300L2000300<1000200000@0000800`000P000002004000040080000100000P00008000801000
00@00@000000000000000@000`000003004003000000303oool000X0ooooD0000002004000080041
00040@000`4000@100060`001P8100<100020@020040000800@100050@001`8100H300080`002@<0
00T30@080`4200T40@802@<101L02P8000P4000<100030D000d50@0?2@805P`301/?1P0E2P8040D1
00h4000<10003@@000h50P0@1@403`D100h40@0;0`401`<100@1000400001@8000H1000200D10004
00H1000810402@<200X30@8020<100P010800105100G4a/01BQ600LC700A41003APZ0041WP80002G
02L0002;0000W0012J400a^L00PTUP0S9gX06bEj00l[S`0K9H/06BZB018_UP0Y<XD08Sb301<iSP0Z
<XH09CB1014[P@0N7fh0525j01<]W00S=H/04SN@01hcUP0Z<hH05RF001hYT@0:6Yl03A^=00/CNP04
2gd01PVA00<9/@0G>XX0745]0214I@0L=5l05Bf:020iT`0U?Hh00P0S<9<07`0/?H80:3ao02DdR00[
?840:C^002/hN`0Y>6l09CI/02DgL`0P=hL08CZ@02<iS00M=Xh083R401TgSP0J<hd06bf1018QU@0F
5I@04QFN02TLQ@0/8W4052Z;02/`I@0NA7`0BDQN05Ln:00/6@T05`P300D1000400000`0300001002
00000@000000000000030040000W00000002000060/801lJ9@0<9U806BQ201DOH`0647@01a5I0044
UP000:l0002?0001X0002;000QJS00L/WP0S@HL0:4N702e<P`0dBH408cRG028kU`0O>i40:49n02Ho
RP0eAWX0=dEb02`lP@0ZB880:U:303eLLP0oF700?UEd03I;PP0cDH80<eEm03YKM@0jHgD0AE]_0080
?D]k02L0=DUm02i@PP0_Agl08T:902=5P`0J?9807S^E020iV00Q?Y407D2=02M7O@0/@hT0;3f:02a1
R`0_AXX0=e6303YEQP0lFH80@V1m04IXN018KG@0Bg9e04acL01<K6d0B5eb04=KN@0SDY<07dJ;01Lg
Q@0?9h<021>=00<5Y0020/4010fj00DG^@0E>jD06d:I01m3T@0O@8h00P0O>i@09P0M>:@063JU01Dd
YP0I=J407S>P01XbU`0M<H/06RZ001<JP00A5jP0<C:B02/]T@0Z9h40:2f@02X^P`0a@GP0=DQb04]E
JP1?IFH0H6IC06A;<@138@l07PX200l50@0;104030@000X300070P001`4000@1000600000`000080
000100000P0000@0000300000P000`010000100400000`0000800001000500000004008000010@00
0P00004002l00000303oool000X0ooooD00000002@0100000P0000D100070P401P<100X60P060P00
1@800081000200800080104000T01`8100L30@0810402PD100/50P091@402`H100/50@0;10800P0:
0`809`0>1@4030@100d60@0?1`804PP301@90`0O5`T071<701P<0`0D1`805@H20107000B1P004@P2
01870P0C1P8040@100h30@090`402@4000H000070P0020<000L300070P001`4000P300080`401`<1
00T40@080`401@8000X20P0?30d0220T00L@4P093P/00P>40041YP020000YP0W0000R00008l000NL
000AWP0J:Xh0:2ik024/L`0H:hh082>:01@TTP0B:IL0;S1o02<eQ00F=X`0;C9m02HcOP0N<G40:2]H
01@RK`0B:9/08cN<01DmT@0U>Hh0<SMn01TdR@0D9Y/02QRI014RM`0E9FL01aQ]00L?P@0>8j0053B4
01DfK`0G=Fh073Q`01XcQ@0S>h@0;D9i00809SZ:02@0;Smm02/jN`0X>8X0;T2502XjS@0/>h00;3aY
02P`N`0W;6h08C6102<hS`0P>H`06SB:01lhR`0I>I@06cF>01l^N`0H7g@071ig01HOS00U7hH0:2:3
01DUT`0/;V806Cah03Y3H01BCTT0DS``03`H300;0`001`<000D0000300001@400080000300060040
000V00<1000D2PL06QPO00/XAP0L:3d061aS00L=M0093e@000300000/00008l0006Q0009[@025Z40
1bbP02M2Q`0[AW`09TIj02m8O`0U@Hl09D:>02=3SP0ZAh409d6<03E;N@0kB6X0;cag02a0O00V@Xh0
>UUj03aIM00oDG80=DF20318Q00_BXD0;E1n02YIQ00nG7<203e@OP0W03A9O@0^BhD0;dZ202A6Q`0U
AHP073ZH01XgW00G=Yd05SRH01LkT@0VBWl0:TB602Y0QP0YAH/0:Tb:03ADP@0hFGl0@F1f04ATM018
KFl0BWA]04YmKP1<P6/0AgQ`03iYN@0JCYP04C>Z018_T00=9hd02QjX00H?T@031IX00P;000@A]P0B
=JP053NP01]0T@0L?ID06CVJ00806CNP02805cRT01HiX00D>Il05SbI01PhWP0E>Y807CIo01TVMP0D
6h<04aRZ02d]V@0X:YP0:bF:02TRV@0/88P0:cJ202Y4O`14Fg80AF5_051QI01MH5@0HTH^03lP3P0N
3@@04@T200h80@0>1P402`@100X30@090`002`<000T1000500000P000P0300000`0200001@0000@1
000200<0000400@000040@00104000<100<00@0000D00P000040000100000@000080000`000000`0
oooo000:0?oooe00000001H00@00008000050P0020@100`60P0910801`<100@100040P000`4000@1
00050P001P@100P20@070`402P<100X40@0;10802`H100d70@0<1@402@D20P0A2PD06P0A2`@03`T3
010:0`0B30D050`501hR600N6``07Q@901T?100F3@<05`X201L80@0F20404`T101D80@0D2@404@H1
01870@0?1P402P8000P0000:00002@8000X20@060P001P400P080P002`060P001@4000D100030000
208100d71@0A4Pl04a@I00d@900315<00P><0080006/02L0002A0000R0001Xl03QZQ01TSUP0T<H80
8C9h02@[M@0T8WX04RBB018UW00`<8408bf401HYU`0^<7h08CEo01d`M`0[<EP06BaV01PXQ@0T<H@0
5CfC02Y1R`0M@hh033>F00XQXP0659L042=`01`/KP0868H042b900`VXP0C<hX053>801TdU@0S?hH0
73N502PkO`0]?GD00P0U>h<08P0]?GP0:cUg02LgP00^?7H0:3Qm02dkM00a>fL0:bed02T]L00U<H40
:3R=02HhT00N<YH083ZA01`hU@0M<Y<07bj901DST@0R87/05B67020UQP0U:8X05B2I02d/I`0I>h00
;cYV03E:K@1:C6@0FblS01D70P0=0`001@00008000030@0200@0000300<0000200000@0000800@00
00P0000000<1000E20H071HK00hV@00N9SL06A]N00L=LP80003001d0002d0041S`010W/0111i00LQ
S`0:<ZL0:D:>02Y0Q@0S@8<0:TZ3029:RP0TBhX08dZ?02]<P00[AhP0<Tal03U:L`0_@GH0;Cmj02Tn
S@0mF7X0?emd04=IK@0hB7L0<dIo02m1RP0ZAHH09df<03mJMP0203mCO00W03E7O@0[@hT0:df102E=
R00WAhX073bH01HkV`0C>9H053^C01PlS@0RAXP09DJ=02M5QP0XBH`09d^<02e@QP0fEGh0@F1d04MY
L01;L6h0CGE^04ejK`1>OFl0AWac03acOP0CBJ002BNc00LQW@0459H010VQ00<:VP023j<00aZc01dd
V@0Q>9X08CZA02<mSP0Q?J407C^S00807CZQ01d07CbK01hoUP0M>i4063b>01DfW@0A>YL06cb301@`
N`0H8XL05AZZ02LYWP0U:9/0;BR;02/VU`0[7HX09c67020nR@0hGgd0@69b045JI018Gf<0H6E>05a5
9`0j7``07@l401D;0P0D2@403`@100`30@0200h3000800L2000600000`0000<0000100000`0000@1
00050@0200<00005004000030@000`4000<1000200000P0100001@0200000@000040000000000@00
03000000303oool000X0ooooD00000005P0200000`4000H200070P402@@100P30@060P401@<100L2
0@060P400`4000D100060`401`<100P40@0;1@402PD000/60@0=1P4040H000d6000J4@X2018=1P0N
018;1@0E2`D06Pl702DJ3P0K>EX0:CY8030g=`0];BT0;2DL02LN4P0T60X081<601/>100H2P<05PP2
01<80P0B1P804`H201<60@0>10002`8000T1000<00003P8000d2000<0P003@8000P1000500000`00
0P0200001`060@002`@100d80`0T6B0061AC00<7D@051G400`000;P09P000;X0006g0003]@0@6JL0
736>01PmQP0U<GP0:bYd01l/QP0P;Hh0;cIk02HbP@0P:Y00<cIl02HhO`0T<X80<SMR024gHP0T;X00
:Rmn01XjT00/AHD05cbF00`/X0076J/010bW00TFQ00?6W<03S2700d_S@0<<IL053V=01HkT@0J?ID0
8T>5024mO@0V>8L0:cN30P0T>940900[>hH0:3]j02LeQ00]=FH09c=X02dfK`0_=f/09bib02TbN`0V
=8X0:CR>02ThS00T<8l08cZ801lkS00P=X`08SJ701/ZS@0Q8hT05RBJ02@_T@0X;Hd05a^L02hZN00E
;I@09SAi02Q3M`0iB7H0HT@k02/E2P0H1`800`00000000030000100000<000800P0000/00@000000
000000000`0000H0000G2@D07aLJ018V?00N8c005Qi<00LFJ@020000`@0M0000^P010Yd00P>500PG
LP0=;8D05CbM02U0T@0Y>Y807cZC02E5R@0OBH@084f5029?S`0ZCh@0;4Z8031<P@0dBW`0:4=m02]5
N@0X@XX0?5Qf03iUM@12HG<0>e9[03M9MP0`?H/0:3Z=02DmSP10E7X00P16E7L09`0fBGD0;3n402Y8
Q00SC8`0:TV;02=2T`0M?Y@053NG018gU@0G>i007DN;029>Q00YCX00:Tj602Q9R00/BhX0<EMo03iY
L`17MVT0CgYR05AjI@1DNfL0DWY[04]jLP0OFIH04CjU00PO]P066:/00`nR0087WP023jD00QZ]00<Z
[@0O>9808cV=02@mS@0U@i009DZJ02A7V`0202I8U00R02Y?Q`0dDgh0;dIk02HnP@0P>I@0742@02E8
N`0L?7L06bN701LPZ00S::008B>N02dYQP0/:ID0:Qb902D/QP0O=X/0<EF603YOM`0lF6D0?5YU04]T
I01RHT/0GD0P03LM2`0N3P@06@T201@5000B0`003`<000/200080P00200000@000<00@0000<01000
00<0000300000P0300001`0200000@0000<10005000010000080000100000P000000100100000000
00400001000^000000`0oooo000:0?oooe00000000D00P0000<100050P0020<100X3000200P30@0?
00H30@08108020D100@200040@001P<100L20@080`4030H200d60@0>20<04PT401<>1P0D30P071LO
00805a<?01T0618A01lE7@0X5RP0;20j00`NW00F9I407RV2024dJ00R>Dd09SHc034e8`0Y8Q008QD9
01`?1@0G2P805@T101880@0D2@404`H10144000@0`0030<000h2000>0@002P4000802P8000`02P40
00L0000300000P0000@000080@002@<000/50P0V6b8071m:00PFH`0428<30000^00V0000^P000KT0
006f00X@Z00E99P06S2@024_Q`0^>GL0<Smf038mNP0c@gL0:D:002XjQP0eAgP0<Tae034oO`0j?fl0
9d1U02TiP00X=H005SZB00hbX00;:jD01A^^008<]0010kL00`VY00D>X00:;YP02SBC00`hU@0E@900
5T>A01U1S@0PA7l08Cek02@hP@0Z>XD202PhS@0V02hmO`0^?G00:cIg02lfFP0/>F<0;cAf02lcK`0X
=Xd0:SR<02DdT00V<Y009Rn<01lYT@0S=W/07SV0024hQP0T=X407B^6028[R`0I;9X09C2B02L[S`0F
7J40:B:700lQX@0Q;h`07d:402U5P01AC5H0Cd0b03dK4P060@000`000080000600001@4000800003
000400@0000V00P0000G20D071DH00dU>@0J7RT051dk0001/`000;P0002n0000`0000K`00@:j00`L
V@0C=HX06D>J02U1S`0X=Y<073JA01m0P@0J?GD06D=i01iAQ@0WE840;568031BQP0bDH40:Tb002Q=
O00/BhP0?UQh03aTMP0lHWH0>EQ]03U=M@0_?hX0;3j902i3S013E7H204=@M@0W03M9JP0[?Gd09d:0
02E3RP0^AXX09dj<02U:S`0P@9P07C^L01dnV@0OBiH08E>;02MBQ`0VC8D09dN302a>R00^G800>W1a
04EhIP1:OU`0CG]L051hH@1:MFX0:5b@01Y7W`0><Jd01QJk00@@_0022k`00PZj004I^0019;H0336Z
01<bX00G<Y/06C^L01e7VP0OCi/08E2J00808e:@0200;eJ003IDL00cBVh0:d=f0293Q@0TAWl0:DE]
01ljL00L;h/063BS01d_X00J9YP09bQo02HWTP0U7XL08RR801`YR`0TAY80;e2403]AL`0mF6l0@ea_
05ASH@1WH480FD0O03XO2`0Q3P@060H000h3000=0P002P8000T200<01P4000<01P0000T000050000
0`050@0020080@0010400080000200000`0000D0000300000P000P0000001P0100000P0000<00004
00000`00004002`00000303oool000X0ooooD00000005P0200000`4000H200060`402@<100X40P08
0`801P<100L40P0810401@8000@000060P001@8100d80`0>20<03`T4010=1@0C4PP05QL=00H>NP0:
5CX200hO900G00`R<00=7dh0315W0082RP000KP000Bf0049/0038iX01SYo01Q4G@0_AD40<cTZ034W
5`0[6P/08a4401`<0`0F2@8050T101D6000C1@004PD001460@0<0`000P0800000`070P00204000L2
000200L1000900H0000400001`4000P2000C2PL091HP01HRB@0;7W@010fL0080002h02L0002i0000
^`000;X0002j0084]@062Zl0216[00`YV@0=A8/07Dam02]:KP0^CFl0;E=i031@OP0bHWP0<Eie03I>
O00lBWD09T=f02I0P`0O?g`01RnO00HVY0047Jd00ANb008B/`024[801ajT01<hU00D>9405SV<01Dj
V00J@I@06T2A01XkS@0S@W`07cV102LiRP0^@8@00P0W=XL08`0^?G`0;ci_02`fK@0_>f@0;3MS02de
J@0]=W40:CJ902/kQ00Y>hP0:3V902TfP@0V;h/0:CAb02LeOP0T=XL0932201/XW00V=I806bjK028[
U@0R:Y404QjQ028MR00=6ZD082ZA01`kRP0T@8T0?Di^041JJP1H=R`050D000X1000200000@0000@0
0P000P0700009`0300001@0001D50`0O4Q406RHY01hL7`0<3d/01a1Y0085R0000:X000300001_000
0[X021ZL01Q0Q`0GA9`0:d>>02diS@0K=hd074=n01PnJ@0H>V`06TR7021CQ@0UEHP0:UR803=GQ00[
D8<0:52002Y?OP0fDgX0=eml03]ON@0kG780>55e0390QP0dA7X0=D]k04I>K00203m>MP0W03M9M@0[
?GX0:Can02<gT00ZA8X0:eJ;03=FR00[Ai409cjE0292UP0NBYD08E:;02IDR00TDX@0;55o02iLP00_
IX40<gEg03]nJ`10P6D0AH1R04aoHP17Mf`095BE01Y7W`0C?:L02c2_00X//P0;9[@03RJc014[[P0K
<j@06S>U01`dY@0M=J@07cnP0218V`0MCY/07U6I008085BD02L09U2<02U;PP0WBG/09T]e02A>M00U
BG8083Ml01XgO`0G=I804cVS01L_XP0B:9P082Mj01lWS`0Q8X/07RF=01`RQP0O>Y808CfA03E6PP0n
FgL0@Em`04eQJP1LJEh0If=505]18P0k80d07`d30104000>0P002P4000T100070@00204000H20006
0@002`0000X0000800000P0700000`0300001000008000020080000900@0000200000@0000400000
00000@00008100040@000`4000800P0000<00@00000000010000:@00000<0?ooo`002P3ooom?0000
00800P0001D01P8100H200060P4020<100/70P0:104020<000P30@060P40108000<100060P003P/5
010>1P0C4@T05AD>01`O600O9RD04b=200hNCP0;6dT00P0;5Sd05`0=4cT02A=B0043OP000:00002h
0002]P001;000Q>R00@PQ@0A:6808BeM02ljG`0kATD0?SdX03LZ5P0]6@X0914601`:100D20804PD1
01470@0?1P403P@000802P0000@02@4000`2000<0P0030800P0;0P0020070P0020<000L3000?1@<0
80lG01PM@@0F9VT0426F0P034k009`012YH0002j0000^P000;/0002j0001]`000kD00AjA008bR`0;
?80094A/03A>I00gDfd0?e5X02a@NP0`E7P0=5Ak03E?N`0^BG`0;4B400d[WP089j<01QfY00<C/001
5k800Q^`00<Q[@0D?i805d6901TlRP0K?HX06T6A01i4S@0NAHH08D5n02DoN`0R?8L0:3j<02m3P002
02@lP`0S02/lP00a?GT0:SR802dlMP0Y=GP0;CN002hkN`0V<XP0;3V002PlQ@0X>hT0:SUj02@cL@0Z
=G80:SIh02PbOP0T;hL06C6J02<dS`0L;iL082bC01h[S`0>8Ih06aZ900TEZ00M9I<05c:=024bT00g
@GD0:U9o05A9B00d81008Pl600X3000400000P020000:`0300001P4000d1000=0@002P4000P1000E
0`80:QD=030^7P0b91`061Xm01<VC`0536T0006J0000`0000Kd000:j00XbV`0C@8h0546N02]7R00`
AG<09D1W02Q7HP0R@5`07cQa01lkT00OAX/08T^:02=@SP0/DhT09Dn:025>R00OC8809dmi02iLO00f
FGL0>5Yd03E@M@0a@X80=TQb03E8LP0nA6X00P0hBgX09`0fB7`0;Sej02`mN`0S>Y009D6802ICS00f
G8H0<Dj;02dlT`0R>iD07TVF021AS00QEXT08UV402]MO`0bJH00;GIo03>0MP0hQ740?XEZ0425JP17
Q6L0;Ff4021FU@0JCi/05TbP00m6Y@0?@ZP04CZ[01@jY`0P?9`07cbH020kU`0S>iX09D2K02Q;V00X
EI809UND02QGT`0202UET@0O02Q@U00XD8`0:UF003IQM@0fHf`0<5A`02<hR`0O?8/07CZE01<aY00@
;:@02bVL01XVP`0H:ID06bFE01/TS`0P8WX07c>901h`T@0/AXL0=5^003iRN016Fg80CeE[05eWG@1V
Id@0G4HR03dO2`0R2`<040<000/1000200L1000600H100080P002@0000`1000:0@001`400P080000
2@0700001P0000@000030000100000H0000300000`4000810003004000040080000100000@000040
02`00000303oool000X0ooooCP000000600200000`8000<200070`401P<000L30@091P803PX400h9
0`0=1P803PP200/50`070P401@4000H2000A3@H04QD<01<L500C8b@05bPm01PSG@0B86@03Qm^00LB
F`801PQg01T01@J=00<4TP000;<0002g0000^@000;P0002f0042]@011:P01PMb00L8N00A8Hd09DMi
03AKE@13BS<0>C<J02dP3@0T4`H07Ph401L:0@0B1P004@D20106000<0`00308000802`800P0:0`00
2P0<0P002`8000P300070@001@8000X20@0H1`P07a0E02HQ<00V=Uh2010kS003008IW@000;X0002j
0080002j0280002h0002X`0049h00A^G00PQR@0E9hH09Rn402XbQ@0;5jT042>L018]U`0C<Yh053BK
01DeV@0E<iT01Qj[00@L[@045[000a2c00<I/0048:d01BJ[01@mV@0D?9H053VG01DnU00E?Y806T28
01e3O@0P?GD08cef020nP`0U?h`0:DEn0P0P?gL09`0[?G00;Cm[02/nL@0`>g80:SV302llR00a@800
:SR<02hfPP0Y=hL0:3R<02XeQ00T;HP0:CIl02LaP00R;H/07S2B01H`V@0N=8`0632C01h^U00K;X/0
3RB<01LOP0078i@05bF101@YS00P;I@0;S]o01A0U@13DFL0D59604`Z7P0F1`<0200000D000040000
1@4000L1000201450@0W00T2000?0P009`d404<[501>BbH081]N02LZ>P0O>UH0219P0001T@000<00
006n0001_@08<J@03cjE010kXP0YBhT0<U=[02E2F`0V?U`08Sm_02<lN`0Q>Y408Cn:0210P@0O@800
9TF602A<S`0PCH`06df;02A=O00/EX00<dmk03IDN00^Cg`0:dB403A9M@0dAg`0?4=a0080=4b102L0
=TN502`lO00Z?7d07cV@01llR@0TC8l0=F:503INP`0eCXT0;DR90297U00SD8l0:5N>02UKRP0`Gh@0
<fao035iP00fOGL0>gid0420KP16PVh0;W>202IUR`0KE9P065BJ01EBW@0@C:<04DJU010jZ@0B?Z40
5SbI01DnT`0G>Y806cZJ01m5W`0VEID09en@02ELT`0XEY400P0XDI@09`0XCYH09e2;02aGO@0dGfl0
=5eS035DI`0[AgP09T25028kU@0L=iH073N=01PcR`0K;HX05C:J01PXV@0G8YH08B1n01h/R@0J9Y00
8dN;02AERP0gF7X0?5Ec049@LP1EH6L0HFeJ06UU@01RA2<0?Ql:01l90@0?0@003@0000X100080000
2@8000T1000:0P00204000T1000200X0000;00H0000400001@0000H0000900002@4000@000030000
10000080000300000`010004000000800@00:000000<0?ooo`002P3ooom=00000003004000030@00
1@8000801`<101@020<100H30@0;1`@040d501@>1@0D3@H04`h60109100;1@802@@101<@2@0E50X0
5AhG014W:@0::d<022AX00<8P0021H/00@:C0084M0800@>N00<0002j0000^@000;T00`000;T06@00
0;P0002A0000R`000Gh00@9[00@>K`0A;800<dAe04I>D@12BcP0@CLT03`R4@0]60X07Pl601@80`0D
1@404PD100h5000=10003@<000X2000;0`002@8000`4000;0@000P060@001P050@001@<000X40@0?
1P<07A8;02L/:0804TUf02L02b^M00L9/`041k800@Ne0005^0001:h000:]0002Z0000:<0002X0000
/0000KD000:i0003]P002jl001>/000H/P007;400An_000L/@017;000R6^00HZZ009<j<043RO01Hk
VP0QA9408DJA0213TP0O?i<07d2C01`oUP0N@940946=024iT@0SA7h08D5n028nSP0TAGh00P0O?Gd0
9`0Y?gP0;D1`02`mKP0^@6h0:cmm0352PP0hB7L0<cah03@jO00c>H<0<SZ3034jN`0/=7d0;CEf02Xd
PP0V=Xl093J?01h_UP0Q=XH06c6:01``UP0G<9@032RF01@ZPP07:I004Qil014QS00P;YH0:cV4018d
S`0^AWD0<FAm05Y4@00T40D04@<000/000030@001`8100`40@0201T;100W01860P0J2@80>R4<0593
7`0N:I<08bQU02Tc?`0K<4l02aEN0043S0000<00006o008QZ`06<JL03SbH00ljT@0OAX@0:eAf02A4
J@0W?gH094N@02U6S00T?9@07cZ:01diPP0G<gh07CR301i0UP0IAY<054b?02=@PP0aD880=TQl03=B
O00YCh009DJ6031<KP0bBG/0>TAg0080<df602L0<TR402`jP@0X?Gh07C^=01XgS@0O@iH0:V:6039X
O00cEXH0;dV702A7T`0]CX`0<E:<035FS00fFX@0=FMl03AcP00iMGd0>WEk041eNP0`M8@0:Vn902=X
SP0KGiD07EfE01eGU`0MD9X07T^N01a1W`0TBXh08D2@01hnU@0K=i006cRG01i6WP0TFYD08V6A01iI
U`0OCiT00P0NBY`08@0NAI/08TZB02UCQP0/FG/0;55_02Q8LP0S@H4083V@01`fV`0N>hl08Cai01Xh
M@0H>G804Sam01@[P@0A9YH06b:701T/R@0H8hH05d:;01I4U@0YD8L0<5Ai03MDMP17HW80EVAW06EZ
F`1[IDT0HD8U040L2`0J20<04`4000/0000200P1000300T2000<0P00304000<03`4000P0304000l1
000900002P0000T000070000100000<000D000000P010002000000H00@00100000000`0100000000
0000000N000000`0oooo000:0?ooodd0000000<00@0000<100060`400P07104050090`402@@100/7
0`0C3PH050d501D?1`0F4PP050d500l90P0F50/06Q`@01XR6@0H;Bd04Ri900TWJ0033H<00PF;0044
SP010i400@>E0P000Jh60000^@0Q0000]0000:/0002R0000Q`0007l00@=j00H?O00L6IH0@39]03M6
I@0hBUT0Acdo04Xb9`0e8A807Q8501/:0`0G1`4040H00104000A1@0050D00143000A104040D000`1
00080000204000H100050P0020<100T40@0D2@@09R8L0080:SHj02L0=D1S030iQ@0L<9002BVJ004O
Y@026Y/0012P000<UP001900006D0000XP000;X0006g0001]P001[@000Zd000<]P003[H001Rb000I
/`006[800R>]00LeY009@Yh04dNG025;S`0QB8l094N>02A8SP0SAHl094F>02=4T00YBhT09dj302A;
Q@0VB7L09TQi02E7P`0XBW/00P0W@H@09`0]@h<0;T>202dlR`0`AWL0;D1j03A1P@0lBG<0<SQo03Xo
O00g?800=3Uk03@lK@0Z=f`0;3I`02`gP00Z>XX0:S^502@hP`0X=g/08Bn902DaS00R<h/06BjD01/`
O00@:8`04aYm010MS`0P;iP0:CN:010ZV@0T<X008U2>05A<FP1?;QX0;18801440@060@002P8101@6
0@0202HC1@0W028?100^5PP0CC`K055<E00T:i409b]W02X^CP0D7Fd03aIL00<6RP000L0001^a000W
/003;jX02cVK00diUP0H?hX07dR10296O00/Agh09Tb@02M9T00U@9@08Cf801djS00F<8006Rim01P`
X00C?Id03dRF025@P`0gCGT0=TE/035=M@0[BWT0;4Qj039;K`0eBH80>DMm0080=Dn402L0=dV1038j
PP0[?gd08Cf:01djSP0N@iD09ej802i/N`0fFX@0;TZ902I9U00cCX/0>Tf903U@Q@0jE7`0>5ig03E[
O00lM7P0@gIh041lMP0YMhL097>:021bSP0LK90096^;02YZRP0YI8d0:5^B02Q>U00ZD8L09C^:02@j
S@0Q?9008DFF02ACU@0WGY009EjA02=HU00UD9D00P0VBIH09`0WA9L0;4^;02mBQ@0/DhP09DZ202E0
SP0M>Z006cRS01PfY00L>9/073BE01@fSP0C?8003SU^010ZKP0<:hh05bB901H/R`0G8gL05CN201Df
U00VCHl0:Tb202m>OP0mI7h0CF9`05AIJ01LHF<0KFQ906=:900n80d090d401L40@0@0`003P<000l3
000B10006@P101l8000201X7000401D2000A0P003@0000L000801P0000<01@0000@0000000001000
00000`0300000@0000400002000000800@0000@000000080000100000@009000000<0?ooo`002P3o
oom=0000000I0040000200001@8000D100071040208100T30@0>1`<03`X3014;0`0@30D04`l601<=
1@0G3`D05aT=01TQ6@0C:RX03S5:00XTL0012[000PZb0048]@011kH000Fg0003]`0;0000^@0N0000
T`0008`0002@0004O00:2Gd08aUk02/bN@0VBGL0<D9W04DlE014>2d0;b@B02DF2@0Q3PD06@P20186
000G20404PT101D7000E20405`X10145000>0P002@4000D000050@001`8100P30@0B208070d70P0Y
6A404012<BL0C4U703Q?I`0GAG`02d>;00DfV`009ZL001bU0008Z`000Y@0006H00@6]0031[800PJe
0046]`001[P20005^00E00PN[0088:`0222/00XXY`0==Z4033bO01M0U`0H>iP05S:L01ThV00J?IH0
6cjF0213T@0WB8d09db:02I@PP0TCX00:4al02Q=N00YD7@0;dmb0080:TMi02L0<TEd03=7K`0]AWL0
=DM[03E7L@0hAg80>dM[03=0P00kAW/0>3n003@oNP0f@El0:3F702lkN@0[>H00:cF<02/jQP0U=H<0
9c:2024[R`0W;gl0:3=h01/_RP0N<7P05b=f01TSN00E98h08RZ;02L^P00>9:@0726>014`X`18AFh0
FUAE05Ld:`0T3@D02`8000h1000O2P400P0l90`09`0k:0d0Ac4C059H;01EDe00;CJ0038cHP0]:VT0
1`ZU01<JGP052H`00031000J/`009ZL012bL00deU00==ZH05CFH01PjT@0RBHX0:Tj202A>T@0XC8l0
9DFC0292Q`0N?7d05Bml01H/P@0E:Z<04SZO00i8W00RD8T0=dmf03M8J00`C7L0;dM_02e2N00k@WH0
>TEo03U:MP0203Q@NP0W03]6N`0h?H80<d9l02ToSP0S?Y4084:A02EER`0[JH80=F6203=GR00/DX`0
>UJ1049BN011DW<0@Dmk03]FNP0gIGd0@7Ag04=hMP0YM8H08g><01mcSP0JLHl06G2@02IcR00[MHD0
:Fj:02EPTP0SCIT08DND01/`V00K=iH07TBF025BUP0RG9<095jB029KTP0SE9D0952F0080:e:C02L0
;U>>03ALOP0gGg80<5Mg02Q<PP0RAi807dRK0215VP0OAIT084JD01`oTP0I>hl06CR801@]N@0C9gD0
4SAo01LXR@0C;i@052=m018_QP0E:i<08dJA02a4Q`0bBGl0>5j004=UN019FVl0DE5/05mVG@1/LDP0
IeD[050b5@0c60P090d101X8000I20408``302PA1@0V3@<00P0M20803P0H10004`<000d100090@00
2`4000`1000:0@001P0000<0000200000`000040000200000`000`0100001P0000000@0000400001
00000000004000@0000000<00@000000000000007P00000<0?ooo`002P3ooom>000000800`4001H0
104000D30@0710401`8100`60`0<1`802`L200l90`0@30D040X301PC2`0G8QP062/`00d`DP08;FX0
1b5o00L]V00;<YL02S2J00DSY@015Jl000be1@000;T20000^P@0002i01h0002S0000U0000H<0005/
0084JP0>5G@07Bb102/cM@0`=V80;cMP04=2B@17?BX0?2`F02dI2P0L3P@05`P201@90@0D1P4040D0
01<7000F20004PH000l2000;0000200000T100090P002P@100X2000:0`4200d50P0W01`=1@0a7Q00
?Cd[03A:F00N@7X07S66024QS@0S8HH09B2701`NQ`0W;H`07c2B01LbTP0==9h0236T00<^YP00:jP0
4SfK014jW@0B>i`053jK01LoV@0J@IH0646F01`oU00K>iD06CJI01`lU@0O@9808D>@02M6S@0_C8H0
;dj502e@QP0ZC8P0;4b602U9Q`0YB8D0;Db00080:dJ102L0<45h0391L`0/@WL0=DQ^03A8K@0e@fP0
>4QU02m2M00f@g00=49c0391M@0hA6@0;d5e03HlM@0b>Gh0<cV8038lQP0]=8/0<3>402X`Q`0[;7P0
9bad01X[U@0Q9h805R:I024`T@0K;9D08BB402@TO00<8JL06a^C014[V@0h@GD0=ej105]@E`0n8A00
50L10142000S2`<00P0m:Q009`14<A@0Ad@L05QF;`1ICSl0>d=S04A0E00i<VH04a^K01TOG`072hd0
0031000F[P008Ih012R;00laP`0?=:@04S:J01HgUP0PB900:Tj502M@S00^ChP0:DR?0252R@0P?X00
4Rj301HXP`0F8JH04cVP00i7W00SDHX0=e9j03=<M00]BVl0;d=Y02hgO`0k=g/0=d1l035;M`02035B
O@0W03U5N`0k@X00>dMk02m1S00V@I008dB=02ABS00YIHD0=FF303YRPP0mG7`0AEQc04=FJP11CfL0
@4Qh03Y:P00fFH00>Vak035jP@0`Oh40:H2502QmQ`0UN8/09gJ:02ijQ@0`NX80:g6802EMTP0PB9`0
7D2Q01L]ZP0K?J<08E2K029KUP0PGi@07UVF01YEV@0LBYd07TVL00809E:F02L0;ER;039RN`0fJW00
;U]c02I?P`0QBY<08DnD02=>T@0PBhh07dV701]6P@0M@GL07SQa01X]N00H:gT06SQc01PaL`0C=XD0
4RZ400l_R00D9hh07T2D02PjSP0a@H@0;U2=03ILQ@14GgD0CeY^05QQI`1OJf00H6iF069U@@1JBBD0
CBlB040R2`0h7`X0?2D=03dW3P0f7PX00P0V5@H03`0O3P@06@D00183000<0P002P8000`1000;0@00
1`4000D0000300001@4000<1000400000P0000400002008000040040000200000P00008002L00000
303oool000X0ooooC@00000200810006008000030@00104000D200091P402PD10P0910403`0<1P80
3@L301H;1P0F5Q<03bL]00l[D`067hD011j;00DjS00:?hP03TN300i;P`08>i<00BFV0009]P040000
^@80002j00<0002d0000]`000;T00`000;T060000;D000250000L@000i0000j4008LU00O78X0=c5Q
02TlCP0a@Ul0ACaL054nA@11=BT0<20C02LC2@0O2`@04`D000l3000B10004`H001@5000A100030<0
00T200802P<100<02`<000X300090P400P0:0P007`0?1@805``602PI3`13;2`0@c=<04<bF@1:;U`0
ACAL03/jH00k?V`0;d9k02E8O`0NBh804Tn=00];U004AiL03DjB00e:UP0<AIT044BJ0196V00EA9L0
64BF01Q3U00H@IH05cjF01@mV00L@9<07T>A0255T00_E8@00P0dE8401P0dEH80<UB2039BP@0_D7h0
<4in035;O`80;T:002L0=3in0390P00`@hP0=Db203I7P@0c@gl0=U1`0357O00c?Fd0<Ci`03A6O00i
BW@0<Cme03DlN`0b>XD0<3V803@iQ@0_<X@0<cMm02`gO`0];WL0:R]d024YQ00S9hP06RfJ024bT00L
;hh07RAo01dPN@0>8j006QZE00lRY`0_=HP0:dV;04i?J01MAbh0>R0A01h;0P0U4@D00P12>1H02@1:
@ah0B5D_05AK<`1PGcl0AemQ04iEH@0g>gX06RBL01`MH`020000`P0L004B[P017J@01R>=018ZN@0@
<J<04C2L01/hTP0OAY@09db802E:S00cC8<0<DN:02A2S@0S?h/05Rj?01PYQP0H::405CbM00m8W00U
DhX0=UIm031BM00bCf/0;d1W030fM00/=WX0<c^103=9N`80<dn102L0=d=o03Y7OP0lBgX0<d6802Y3
S@0SAh/0:5B402]NP@0cHW`0@VIc04MRM01:GVh0C5Ee04M?K@13AG/0>4F403=AR@0gHgh0=7]o03B5
OP0bRg/0<hQl03:2O`0dP800=h9n03N0OP0gNX00<Fn602]TS@0YFi00:4bE031KSP0eJ8P0<ff702aY
RP0VG90085>F01m7W00QBYX00P0VCYD09`0[EHL0<f1m03E]P`0^FWX09DN50294U00UBI808dZA01i4
RP0L@h/05d>B01i4Q00N>Gh07C>101/`R@0I=XT05SMo010kO`0?<XL02c:9018XP00G>i007SBC02U2
Q00TAh@0:4j;03YOO`1:JG@0Cf=a04iMKP1:I6`0EG=S06=bD01YIS/0IEH[05e;801G@QT0CcdF04Ha
400203dU2`0;03DN200`5@D08`/001T6000C10003`<000d3000>0`002@4000H000060@000P040000
3@0100000P0000@100030@00104000<0000200000`000040000200000@000080000100008P00000<
0?ooo`002P3ooom=000000800@0000<00P000040000200000P0710804P0810401`@100L200081040
3PP301H=2@0C6ah01bM200HSK`022ZD0236G00PiRP0;>h/03T260196O@0BAH@033RL00HXY`800AR`
00H000fe0002^0000;T0002<0000U@000:T20000^@0K0000^P000;T0002h0000V@0007h000=g0008
O@012XL08aQm02P]L@0a>f40:S9/02hWNP14<f`0@dEB03<n>00^:Qh09aL;01X:0`0B1@004`H001@9
000B1@004@<000/200090P00204000802@8002/0208000L100040@00104000P2000<10404`L202X@
2`0m7a/0?bhZ03hj<00iA3h0:dYL028oN00O@8<074V201]>P`0CCHT03dN?01A:S00BAi004dFB0191
UP0D?IP05cbG01LjV@0I?9H05c^G01DjV@0D>9X04cNL01PjUP0J?ID08T:>02Y:R00[C8P0;4Z802i?
QP0`DHD0<E21039BN`0`CgP0<TYj0080<D9l02L0=49j03=8O00bAh@0>dam03M>NP0gCGL0>eEY03M8
L`0e@f`0<D=e03E:Q00jCH40<c^903HnQ`0a?XP0;cR903DcP`0Z;Hd0<3J002PbQP0W;hd0:2b9024V
R`0O;9405bfN01hcS00I<HH062V301TWP@0>:Hl07BB@00hM[P0/9I0072fJ0415N`1@HUd0Cd4c038F
2P0d6@P00P1?DRL0201GI3P0CGE:061a@01VMdT0DGUY05ASJ00l@7h093:I0`000<8070013[800AN^
00DPV@0@:7/04BbM01XdT00N>i0084VG02I:T@0R@YD0<dV503I7Q00V@Xd0:42801T`TP0N:hP05c>L
01A3U00DC8/07U>302UIPP0cGW@0=EA`0350H00`=gL09cAl02diP`0dAWh203A;P00W03U9L`0hBW80
=DIe03I3Q@0]AXL0:DV902aDO`0]Eh00=5ek04AQM@1?HFl0E6=X05MOJP1>F6l0A5El03IAP00bEGl0
<6mk03AjNP0dQW`0<Xei03>;NP0`Pgl0<8:002n1P@0aP800<h20035oP00^O880;WB502][R00fLh80
>7N203AgQ@0]KhP096N>025OTP0TF9H09ERD0080:EBB02L0;5F5035HN`0bFWd0;e9n02a9QP0^D8H0
<U60035=PP0/Ah<09TR;025?T00VEXH08Tin0210PP0M=iT06cVS01XkX00@>Yd03CVD00XcR@0A:8X0
4CFF01@_U`0LAh806TEd01]3N@0ZDWh0?VEh04QWM017Gg<0?UMe04MRL01?KVX0EgYU065kE@1YMT80
L6@]06]C801P@AD00P1G=Q403`1F<Ph0D2X<04@P1`0e4`@08@T100l2000A10003P@000/300080P00
104000<00001000000000080000300<00003004000000000000002L00000303oool000X0ooooC@00
00050040000D00H30@081@802`L300X60`0:108040X301@>1`0I5a80524^00LTE0087W@022fH00hi
S00>?HD04C^<01A0Q`0JBW/07e1g01eGP`0DBi4200DgX@06000O[@001KL0002i0000WP0008`0002N
0P000;T30000^P0L0000]P000;80006>0002L`0D49407QJ601HXQ00P=Wl0;2Af02`KNP0a97X0ACIU
04LnB@0n>c00>2dM030K3@0T3PH060T201<6000A1`002`8000T100080@002@8000P10@080@002`80
00L200801P4002L01P8000P200070P003P<001850P0P40H0;RHF03I4<00cEE/0:45n02DeQ00X=Wd0
;SIj034bNP0c<7X0>CQj03Y0O@0i@g`0=TIn03A6PP0`AH<0:TB602U4R@0S@XT08T6>02<nS`0T?hd0
9cn=02a8R@0/A8T0<DV502m9Q`0^AXL0<DZ50359Q@0dBhD0>55o03IAP00eCX800P0dBX<09`0eBh00
=Taj0395Q@0iC7/0>E1c03UCK00mE6L0>4Uf03M8L@0cAWP0=DR303Y<O`0f?8<0=T5n03A0P00c?8D0
>caf03<dL@0c=GH0:cJ802dhS@0]<hh092bE02<aT@0K;IX08S>701T]S@0G;I`05c:H01<[V`0X<Hl0
4A^/02dNS@0K:9H0<cio03IKN`1;EU/0BRdH044O300205]A8P0806EcA01CRfH0H8MG06F5E`1CPVl0
G6iV04A9N@0Q=iX30000`P0L0008^0003KH00aRT00TUR00E=IX05SB;01/lS00PC9L09TZB02=2U@0/
AHH0<4B102]1R00^AH8093V=02HaRP0M>i@064R801Q<R@0HDH@085^602eVO00gF6d0<TIN02llM@0`
=gT0<CEl03=2O`80=dF202L0>Taj03]=M00h@g<0>DN303I<PP0bB7P0=DUj031AO`0jFWX0A5ab051T
K`1LL6T0GFa[04mUM@10Ggh0=5Z5039XP@0dKgh0=WIo03J1O00cQW/0;HAo02QmQ00VO8H09W^602Yl
Q00_PH00<XIl03:3O@0_Oh00:WR3031iP`0bMh@0;7>702=]S@0MJY407F>E01iMUP0TFYD00P0UCID0
9`0WBhd09TV902Q9Q@0[BHX0:TZ=02iCP@0cE7H0<Tac02a7P@0XCHd08eR602QPNP0SFgD084em01do
S@0O?I008CJH01PhV@0D>XT043Mo01@^Q`0D=Hl04C2>0157R00BAGH04SYd0214P@0bFg/0?VAf049S
M@0nEW80@eed049SM015IgL0AG9e04moIP1NPTl0JG/m06YY;@0206UJ8`0;06MC7`1SBAT0F3HB04<Y
2`0a6@L07`d101L70@0@10003@<000X300080P000P0600000`0300000P0000<00002008000P00000
00<00@000000000000001001000K000000`0oooo000:0?ooodh000000P01000010020@00108100H3
0@091`8200l;1@0@00l90`0I50X06aT=01TS7P0D9T0021aY00XLN@0<<8h03cR:00hiR`0?<YH053RA
01I1R00PDX008UMo029IOP805E2;00P02cVK00LLZP063i000PBH0000SP000900002M0000Z@D0002j
01L0002Q0000N`082fd051ih01TbQ@0O;XH0;Qb002TIQ@0O9HX0:RJ304DXIP13@E00=dA804@h?P13
9Ql0;1H:01`;100F20403`8000X300080P002P8000`2000200h2000400X400080@00204000H10080
208002@03@D100l60P0F2P@09A8902lS5P0o>3<0BSQI04D_J`10<5d0AC9F04D^H018;5h0BSIV04i1
JP18BVd0?dia03E@NP0^CWX09Tah02=8P00QAX@08DB>0294S00UAHX09TR702m=P`0`BhD0<4b5035>
P`0aCH00=T]o03E9P@0jD7h0?eMj03iFN@10EWP203iFM`0W03iBM`0mD7@0>D]n03]AMP0mEV`0?EIe
03i?L00iBGl0>DIg03=4O@0c@hP0=TB502hfR`0c@7`0<Cil034iR@0g>gH0;Rib02hgM00]>XL0;C^=
02TlS@0R=Y409cV:01/fRP0U=8D07c2?024`UP0P;9P072JG02X[R@0@7:X0:A^=01TTV`0^<hP0:D6:
03eBN01IDS`0E30J0080Gd0J02L0JgM:04f?L`1IS6P0HXES05n9J01MM6H0@Dmm0084]P010KL0002m
0000``000[T000Bd004=Y@007i<033RV010gS`0G?8X06TbK02=9U00Q@9L08Cn:02E1QP0T@I00:TF7
02U3RP0]@8@09DB<01e<P00ICY0074b701mFQ`0[HhD0=5Mh0315LP0b@W@0<cee03DdL`0/?H000P0f
AWX09`0mCGH0@4af03e8M010DGd0?EEk03Y=N@0lAgT0>Eem03QOM00oI700B6ec05=jKP1CNfl0B75g
03i/OP0iLH00>7:103IcP@0iN800>Gml03B3O00]Q800;8>002^1P@0/P840<X5n03Z5MP0mRG<0?hMc
03j0M@0jNWX0>WMm03QbO`0bKhD0:6N<02AUS`0TGY809EJD02Q>T`0202Q2UP0W02HoV00X?YX09cjI
02Q4U00ZAI<09dR=02Y8S@0X@hH08T>90217V00NCY008E::01iEQ`0NE8T06TN9020lQ00Q<Y006CFE
01PiRP0G?8<06CEk01@iMP0@=fd03T1`01=1LP0D>7/083j602]DO00^GgX0>F9j04EMK010F7/0@Dmb
03mKM`0gIGl0>WMj04:9K@1BTed0GXa<0080HH4o0100JG@d06YU:`1OD240ET4H04dg4`0o:0`0;AH5
01h:0P0B1P403PD000/400090000200000L100060@000`0010010006000000050040000000000@00
0000000100000`0000000`01000000000000000G000000`0oooo000:0?ooodH000000P0100060000
0003004000020@00108000801@<101<030P3018?1P0B40L071T;020S5@0P:b806Rdj01<WH0096HD0
32b5010^S`0B<X/04CV8018gS`0B>I<06cj<020lSP0U@XH0:dYk0080;U5j00L0:5:001m>R00@;hd0
10f=0002SP000Hd0002;00H0002j01X0002_0000PP011G`02QZ6018_TP0U9hL0<1n102HOQ00[;7l0
<RAk03PQL`0a>G409DI[02/kKP12=d40?2dK02PH2`0P3@D05PH000h4000:10003@8000d1000A0P00
40<000P200<01`4002H02@0000L1000<10003PD201050@0F1P<070/502lG3P1?;2L0ECi30410AP0c
A4/0:4AK024oK00P>GH08cih02E2N00XAgX08TV1029;PP0MAhH063n=01PlT@0H>9H06cVA01/lS00T
@hT09d>302Q0RP0YA8/0;4b2031?O00aC7H0=4Ui03U=O`0mE7X0?5If03mIL`80@5Ya02L0?eEa03mA
M00hDG/0?5M`03iII@0oDW40?DY`03Y6M00fA7L0<4:00316R00cBH40;4:00354N00b@7h0<T2903I0
P00X<I40;SYn02XcQ`0W>98093ZA01lbU00P>8P05C6A01haTP0H<9`07RbJ01hVU`0H7hd09R=h00dS
ZP0P6Y8052BP02`aR`0T=8l0<DN504QTH@1CBSL00P1Q=QH09`1/Kd80Bi1c05^;J`1US6L0KHmU05ik
I00A6Xh04B2300H<R@010Z8000330001XP000X/00PQf00`^O00<=9D043R=01LoQP0ICI809TV>02@o
U@0M?9807cj801a1UP0S@X`09DB=02i:P`0ZCHX084n501]@SP0OBh408U2502]LR@0cE8<0<TN303M4
OP0h@W00=cUe0315PP0203I;O`0W03YCNP0mDgD0=eAc03MMO00eG7l0=5F502aNQ@0XIXD0:f^102Y_
P`0YLh<0;g^203IlO00dMWl0<7J2039iP@0^MX<0:GR4031lPP0`P7/0;81o02N1P`0WPH@0:82402Qm
Q@0`Pgh0>XQg03n>L`12S740AHEb049nMP0lMg`0?7Ao03=_Q@0]JXT0;V^902eYR00`IhP0=F680080
>5R802L0=e::03Q:S00hBX/0=dj703AAP`0`CX00=DZ50398P00^BH<0:e>>02YFS00[G8/0:62:02QR
SP0QD8l08Sb;01hfT@0J=Y4063BP01m2WP0P?I@04S^;00`mN@0;>FX04SN001<eQ`0R?H80;E5/02I@
M@0_EX80AF5e04ACOP19CW80?Uah03AVP00cJh80?7Uj04>=K`1>Uf400P1HUeH04@1MTT/0HHM005mj
>@1OJS40HV4W069E801C>A80=a`7024;0`0E20403`@000`5000;10002`<000H100050@00100000<0
0`000P01000:000000800@006P00000<0?ooo`002P3ooom6000000800@001@0000006@0100000@40
00@200040P001@8100H30@0<1`<04`l601dQ400L9AD082lX01`b@00C;Ed03B6400PVV00<:IH042NE
01<aR`0B@Gh054Io01HoS00J?8/07CJ<028jO@0U@g@00P0/B7/02P0fFG80<V]d01a=SP064jl00@JB
0002W00009d0002T0000Z@000;830000^P0F0000S@000:8000:/008?VP059IX08B2;02XRQP0G:8h0
82^<03HSN`0f:G<08SB002LiL`0`=EX0>3a;04U2@P1?>2`0?B<D028>1P0G2@8050D000l300804080
00<0308000P200090P000P090P001@0;0@00308000d2000@1@4030@100802@8001l0308001L8100Y
60/0?3L[02a;F00MBW`06Cf<01``TP0P;hl09S6902lhO@0b>g`0=Sin03Q1N`0e?h40<T:402m3Q`0^
@h80;DAl02m4PP0`BWX0<4Z003=;P@0dCg@0=e=f03aBK`0jCGD0?U1k045FL`0oDWX0@5Ai0080?eEk
02L0?E5l03e@N`0fBgl0>EEf03UIK@0kDGT0>TMc03DoO00c@H00;T:702e3R00]C7L0:dY^03E:J@0d
B7D0<dN103E8M`0Z?X00<Saj02XiR@0Y?H`0:Cj802HiQ@0Y>G`07c2C024dT`0N<9T07R^G01dYT`0F
89008a]f00`VY`0J6IL03b:S02`bS00T=8h0:cn703MEM@15E5T00P1N?2409`1dH3L0D8QX0667K`1T
UFT0MI=T01TUU00U>G@09dYb01<SL@031hh000330001SP000GT012F400XZNP0;;Xl03SFB01DoQP0F
AYL09TR<02M2T00P@Hl0942101hmQP0T>Wl09TB202e>O`0_Dh<09eB1025BS00PBg`09DV302MBSP0`
DHP0=4J703m6N`0mAW40@Dac03A;PP0203EBP`0W039KQ00bFWh0:Emo02MTP`0WH880:5V<01YKT`0K
Hi807FZ=01Q^SP0BKi005gF?02=kR00ZO8D0<gio02ijPP0YNHD09gZ402UkP`0XO7X09GZ002AiQ00T
MhP08gF:02AfR00^P7d0>XYf03n>L@10SG80@HMe0423M`0kOG/0=7V002]bQP0[KH/0;g>6035gP`0e
Mh80>W220080>fJ202L0>UZ603Q>R00jE840>Uih03AOMP0eDGT0=DQn03E;OP0bDhD0<f>103MVM`0g
Jg<0;V]k02]TP@0TD8808TEn0213P00O@H406SfF024nUP0P<ih05cZI01<lSP0>;8<04R^F01@^VP0Q
>H`0:TUj01dkP`0LA980=V2503mXL@13HfD0>5e[02YNO`0`GXH0>VV103YjNP13Rfd00P1AUUl04P1I
V5D0GY990628@@1SPSd0JW`f079h<01`IBL0HDDG04D[300]60P07a4401L>0`0E2`<04@H000`30007
00001P0000@000800P0000<00P400040000000002@000002004001X00000303oool000X0oooo=`00
0002004001@0000001T00@0000<100040P00104000@200080`403@T4014A1`0K:Q/06S0V01Tf@00A
<6402BAn00DHV`08::4032RL00dUV00D<hT04dIg01A7N00D>8`05S>;01/^R00O=WT073ab00807Sb4
00X0=U5g045RI`0gG7<0:4J901`bR00>98T00@f>0007LP000G40002C0P000;X06`000;D0002<0000
XP000Z@00@f300DPT00I9HX08BV301hbR@0T;XH0=2Qh02lcO@0K=hP082V803PaH00Z?Ed0:Caf04Dg
I018?3h0<bdM02XH3@0R30D05PL101D6000<0P003@4000d3000200`2000W00X3000<0`002`<100l4
0@0>10003@D000X300060P001`4000`5000D20<0<1XA03h/;P0k=dX0?SYO03diL`0j>7L0?CMa03li
J`0o>fd0@41b04=6J013BW00?U1i03MHN`0bEW`0<U5i031=OP0aEGX0<eIl03EENP0eE6h0>E1R03iA
H00oDVL0@eAZ04IEJ`13E7D0@UIf0080A5Mf02L0AEMi04=GM`0mE7X0@UY^049JJ`0oCWH0?4Qe03Y7
P00eB840<4>202a4PP0]CV`0:dV203EAM@0eBG<0<T:103M9M@0]?X<0;cf402LjS@0V>Xh09Cf502<g
O@0Y=Gh08Bn<02HcPP0U;X/08bn>020bRP0I:8D08b=j01@XRP0L880042B;02DYPP0O;9<0:3F?02Y1
QP0eDG`00P1JF3h09`1jICL0HXUJ0668K`1[UVP0P9MN02E1Q`0gF6h0=fYk02Q0LP0848`000330001
R0003gd002:O00LYR00::YT03C2J018iS@0C<j@09D:C02]7S00Q@i0094:101ljN`0X=F/0:41l02i7
NP0bBGl0:TZ102M>Q00UCGl0;TUh02U9Q`0aAh@0=42303m4O010Bg80?e=f03A=Q`0202i?R`0W02QC
T00UCi0074fE01a?UP0NCi@03CfW00m1Y@0ABj804e>N00mHWP0<Fih03V2K01Y[T`0/LXL0;GJ602ae
Q`0ZMHL0:WJ402]dPP0YLg/0976202AaQ@0WKhH0:Vj7031cP`0kOGT0@hM`04N;K`18S740B8Q`04Z5
K`12PWD0?81j039dP`0aKX<0=7J003QjOP0jNWh0?W:00080>fJ202L0=ER;035>S@0dFh00>6eg031Q
M@0ZAG`0:SVA02]7S`0]EHX0<Ef2039OO@0`GGh0:5j702EIR00QCX<07dN101a7P`0MA800646401lh
PP0N:Yh06cNK01TjT@0A9H@052V501/gU00N?9X08T>B01PcR00@=YT08eBB02m`P`0oMVL0?FUV02aK
OP0]GHL0=fN003e]N@16M7000P1DP5h05`1LRe00GH]805j7AP1NRT<0I8U007:<>`1fRcX0LgTb061G
9016?aX0=blC02/T3P0T5`L06Pd401850@0:0P001P000080000000000`4000@200030@000@0000P0
000000H00@0000<0000300000`0000800001000G000000`0oooo000:0?ooocL000001@01000A0000
0003004000040P0010400080104001@01P4000/60P0F:20062l`01D`A00C;el032In00LOS@04<iT0
33BH00lcUP0=<9806CR201a6L@0KAG806SV201dhNP0T>f/09SmU02@nK080:41o00X0<dUl03eGJP15
GV@0A6I/03IOM00:::400b9m004FHP001U@0001c0P000;X06`000;D0002<0000XP0009`000=k008:
YP0U<H/06Bn601TjS00W=8T0=CAi02HeP@0O=XP0:2B202lYK00R;G006bMo02lSO`0j@f<0=4`k03@b
7`0/6``07Q0601X90P0B1P403`800184000200l2000W00h2000:0@002@4000/1000<0P002@4000P1
00060@001`4000X2000<0P007@L302dB2@0h7QL0@S8[041;BP0hDV00;dUY02I2L@0R@W<08D5c02A5
L@0TA7d094N402I>P`0VDHD0:56502Q@Q@0ZDX<0:e6402a?PP0_BGh0=4Ie03M9LP0hBG<0>TUa03];
L00hBW`0>dim0080?eEi02L0@EUh04=MMP13Gg@0AF1]049KK@10DG<0?e9g03aAO00kCgX0=Def035<
K@0dDfT0<UAg03MCLP0eBGD0=TEm03Q9M`0`A8P0=46302lgR00/>HT0:SZ<02LdT`0X=9808BfJ02H]
M00O9HP07bfA01dcR`0H;9H082f?01@QTP0J;G`04RN901TLR00F8Y/0:C>?02XkR00]BXP00P1;Je/0
9`1/LdL0LXE@06b:IP1aU6@0CVQk03ATNP0kGFP0;4ib02PdI00;48@000330042VP002h4001VY00DX
VP07;:002RnO014fS`0A<i0073Z902M5RP0SB900:4J8024kOP0Y<V`0:CJ50310NP0_>H80:3Z=02U6
Q@0UBh@0<T]f02]2N00a?780;T1k03E2N`0gG7/0<5J002E7T`0201`iWP0F01@aZ00?::d02And00TR
/P035;d011>m00DI^`079KL022jc00Hi[`05@:d01TFZ015@XP0MEYX07UfG025QU@0QI9809VZ<02MZ
R@0SIh8086N<02AXR@809fR:00l0;6j803UjO013Pg@0A8ab04N@L@1:T6l0CHeZ04R6L@12P7D0>GMn
03QaP00nMWh0@7]i04B0N019P7L00P19NW/09`10L800>fEn03iVL`0lHWH0<EEi02i8P00]B900<E6>
03AJQ@0eFh00=U^7031CS00WCI<08d^@0217Q`0N@Xl06TBH01Y3T00F@7h07C9l01PRY@0O=J407SJK
00lMW00E9Y<07CnG01a3VP0MBXT05cif014aSP0UC8T0:5n<03Y/M`11KG<0<eB102QCR`0QEY@08ef@
02eQR00204=cL00H05N2E@1OPd@0JH8n06N8?P1YS3l0Jhm106^DA@1YTdH0Hh8m05M]<@1<EbD0@D<J
038]400X6PP06`d400l60@060P00100000000001000010400082000100000P000P00000400400004
0000000200000`00008001X00000303oool000X0oooo=@000007004000@000000P01000;000000@0
0`400P0400004`0@71L03R`_00h[BP0:8VT02Af100DBV`02::400c:L00hiUP0@>9D033JA01TjP`0O
@gD06D=e01PlO@0J?GH0841V02@oIP0W@Fh00P0[AgT09`0XB880:Dmk031HLP0iIFl0?6e[02MBQ00E
>gh01b1`004=J`000g0000620000W`000;L0002F0000S00008d0005h00T>J@0E97<04c>001LlR`0Y
<hH0<3R402<fR@0M;i00<2B402/UO`0M:X<07aj702XPO`0]=VL0?T0o04Dj:@0n<R40?RXI034H300O
2P@04@@00103000200l1000700d000080@00204000/1000=0@002P4000T0000200P1000N00/30@0;
0`002`4000h5000E1P40:AL;030a7P0eC440;dM_028`Q`0T=6L0:SaI02liH`0b=W80=SQl03Q1M`0h
AW`0>T]m03Y=O00iCgX0>UAh03YBO@0kCW`0>Den03i<N`0mB7`0>dIl03Y6LP0dAGd0>Tao0P10DgX0
9`12E7P0AE]d04AOLP16G7<0@eUe049DN@0mDg`0>Tn103Q:OP0cBgX0<TYh03ADL00_DGT0=Ted03=9
M@0fB7X0>DYm03=5Q`0i@Gh0;cJ0034hNP0/>gd0:cZ:02ljQ00[<HP0:Rmf02HcP00T=X808c:601d`
TP0T;i005AnV01l`P00E99L04aBC014LW`0V<Y00:c^902XoSP0203YJN@0W05AVIP21NdH0MhQE06f2
GP1NOV/0@gE_03mFK00O>8<08bQQ00`@P@000L<0006C0003T0002;`00B>^008[[006;JH03c:C00h`
UP0N=X808Sf80298T`0XAX/08c^602LgM00X?W40<3a_03@dMP0W=Wl0:3b502U9R00fCW/0<D=c03<i
KP0Z?H40;U6102aOP`0UEXX0646K00803bN[02L021V_00LBZ@053:@00P^n008>_`024L000QZl008V
^003<;@01cN`00/i[@0=>Z/05d6S01Y1X`0KAZ0074VM01e<V`0RE9D095NA021GT00PEi8085VD025M
TP0OHY0086R?02mcQ00gOWh0?Hah04BDL`17U740CY5^04Z5L@15P7H0>g5n03UeP010NgX0BH1e04b5
LP1AQVd00P1CQ6h09`1>P7<0AGIe04=ZMP0jEG/0=520031=QP0bF8/0=Uj803QTP00jIgX0=fMj02mJ
P@0XB8T09TMm0294NP0MA8L06dJ<01]5P@0I@7h06SV>01DhX`0N=IX07BZF010LZ00E::P07T>I01]5
T@0JDgd05Dee018_S`0WAHP08dNI03=GQ00iJGd0=Un103=HQP0^DXd0:5V@02mUR002041hL`0D05:5
E`1QPTD0JH4k06^6?01ZRCd0IH]106F>A01YTdH0Jhm006Qm=P1NJRX0CEHQ03m0600d;0l091T701X;
0P0;0`001P0000<00002000200@1000700<1000300000P000040000000000@0000800004004001/0
0000303oool000X0oooo=@000008004000<0000000<00@000080000100002P00000300<1000F0080
000300004Q0<014P9P0<9cL03R4g00dM>`0=7DP011n;00@YQ@03<I003SBJ00hdV`0:=YT05cR:01e1
O@0E@g/05Sb101TjO`0J>W`07SUo02<lN@809Cik02L08cb;0254R@0VCWh0;eIe04MSHP14I6L0=Tib
01d]M`0:5W<01A9W0047D`000H00002i0000ZP0009l0002@0000P@0217@02AIj00d]RP0F<Y40:bf3
02PaR00T>HH0:cZ703@bP00Y;H<09CB702LRSP0S7X`073>602lkK011>EP0<T9903A6A`0l:R80:a88
01P80P0A1P000P0@10009`0>0P00300000T0000>1000308000X2000;0@002P0000`1000>0P003`<0
00/2000<10003`D001/;0`0U5@X0=R<I050a?P1<;E/0?S59044d@P0m;5T0@2a?04@_H`16>fL0BDQ^
04YCKP1:GFl0BEe^04MNK013FW40@EQc03iHL`10DG40?dYd03e3M@0hAWH0=T]o03a?O002045BN00W
04EDN019FG<0BEQd04UGL`19Eg@0AeMb04=HM`10EWX0?eIh03aGM`0oFGD0@5UZ03U?N`0iCWT0>4]k
03I9P`0jCX00<TB703Q1P`0_=XL0;c=n02`eNP0X=h/0;cR602L^SP0W<h/09C>702DbPP0P<H@07Bn6
020ZP00E89/092al01POT00L67P04Aj501lYP`0P;hX09cRC0080;dB602L0>e>307MfCP1oPdd0K85N
0761IP1ENVP0@e5d01LbZ00S96@04aQa00<6P@010HH0002B0002XP005JT002>_00D^Z`0@<iP06CNN
01lbQP0T=8H0942D02Y5S@0U?8l09d1l02I2N`0e?700>cA_02DfO00Y>H00:dZ903QBNP0jDG<0@TE/
035DO`0YDX<09ef:025FS`0E?j000P0;7k409`095j@02AR?00TIQ`023KT00Q>i004I_P029;T00S2e
00<i/@0:?J/04CjX01XoXP0M@j407TBO01m;W00PBiT084fG02ABT`0VEI4095Z?02IMSP0WHX/0:fB:
02UWR@0]KhL0<WV003Z2N`16SG80CIA[04bBK@1<TFl0BhEd04MkN00lJHD0>g=o04R0M@1@Qg80FhiY
05b@I@0205f;I@0W05N2J`18N7T0?FF2035>SP0^D8h0;e:?031NRP0cIXH0<fb303=^P@0aIh409E><
020nT@0PA8408Daj01U:P@0HA8806T6301M1R`0H@YP04d6N01`bT`0I:9<05B:T01HZY@0J@8/05d5g
01a=H`0ICWL0532E02I6S00Q?XT0:4J502MKS`0ZGXd0<ef:03MBS00dDHl0>6b10080C8=Y0180HXQ?
07:4?@1ePSP0MWlg0760=P1^Nc@0Jh0h0727?01`SSh0KHdk06F0=`1KKRd0D5XS04E66P0f;@l09QH7
01070@070@0200@0000800D000030@00108000D200040@000P40008000010003008000800@006`00
000<0?ooo`002P3ooold000000D00@0000@000000040000100000@000`0000000`0100000P000080
00090000000J004000020@000P40008000050@000`4001LG4`0C8CT02Ahn00lK9`0B8BP03R0_00@I
QP06:W8012j100`[WP0=;j0023BN01LeT@0M?hH05D6501HkQP0N>gh07cmd024kM@0U=g0202HlL@0<
02DoP00V?h409dEo02m<O00kGF`0AVQQ04MRJ`0Z?h/02b6B00HLG@0475X00@Al0P000;X06@000;/0
002I0000OP010K801PjI00lWU00I8i00;RN401`TT@0B:YP09c6>0350PP0Q?H<093Z:02h`R00V:h<0
8C6602/_NP0];6H0:D=T035=G`0n=S@0=QhB02H?1@0L2P800P0D1@003@0B10003@000142000B0`00
30@000/4000<10003P<000h2000A10005@D001<50@0B10400P0@1000600E2@408P`203lG3P1@:240
Ac<]03do?@0/A5<08cUU02</N@0X=7d0:Cmn02m7O@0dD7`0=5>003=DO00dEg`0<eMh03AEO@0eC7d0
<dIj0351P@0`@Gl0;d>203E6P`<0>TR102H0?T]n041:O013BWX0A55g04A@M`14Eg@0@Uae04=NL`15
HfT0AFAR04IKI@0kD780>dma03M>M00jCWH0?EAb03M<P`0kB7`0<cal030fO@0^=X<0:3ZA02lmS@0Y
>9@0;3Z@02TfU@0V=hd08CJ9024_P`0S:7T05RBM02HXNP0D9J008Qea01LPQ00F7XD06B:?02<fV@80
;4::02L0;Tf:05a]HP1kMe00LgYL07igG@1OQV@0C6ia02aJU00i>F80:C1V00L<N@0217H000660001
V@002Id001FY00@V/@0><J006CVH01`gS@0S>X008c^002Q1QP0/AX`0<d]o0317O@0f@V`0>c]_02Lh
P@0[>Wh0;Tf:03AHO`0fF800A59_02aKP00QEHD085^@01]BU@0?>J@00P065[T09`074ih02AR:00@<
VP023KT00QRc004M_@019kP00C2e008g/P0:>jd04c^X01@lY`0J@J<0746S01a:W@0JC9d06DjL01m@
VP0QD9T08eZE02ENTP0UHhl0:FN<02a^R00^M8H0<GZ203f6N@1:TFl0EYMW05:FJP1@Uf`0Ci1^04f6
LP18O7L0CH=a05Z>J@1VTf40Ki9K06nCFP0206j?FP0W06B;H@1IPF/0C71g04=LP@13HH40@6>103m/
O011L7/0@G9k03m`OP0gIhH0;E>?02U4U@0_DGh0=6Ek02QIQ`0M@HL07D2D01Y7X00IBYl05CnH01P`
U@0F<ZP072fW01X/XP0G?Hh04cZ101DgM@0D?XH052nH02A?RP0RBG<07dM_025BQP0YFX@0;eV903eP
QP10G8@0A75f0080EHEQ01D0Jhi=07V?@01kT3h0O8`l07b2=@1jNS00O7``0823<`1lRSP0LXhm06J8
?P1QO3H0EVh_04mM9P16Aa`0=RXA028B1P0@1P00208000L100050@000P0500000`040P000`4000<1
0002008000800@007P00000<0?ooo`002P3ooold000000@00@000P000002004000<000000P010002
008000@0000000<00@000000000000000P0000006P0100000P40008000030@001@8000`70P0I61D0
4R0o00PJ?00>6b803bDl0048Y`035I401Baf008[N00<8Y003RRL00X`X00E<IL06cNA018jT@0B=hd0
7cV201lnN00J=gX07CAd0P0N?Vl0300Q@GP0941h02Q1N`0YA880<EUh03MVJ`0oJVd0>V5e02E?P00<
87800`Ye0001V080002k01T0002j0000OP0007h00@:]00HAQ00>;8807BMk02LUO@0F8gh05BV002@X
O00S?H<05d:901XgT00[>8P07C^801@dT`0[;X@0:C9`01`fO`0g=W80Bce=03hl>@11;RD0>1T?0080
90`302L06@X101T8000D1`405@L101450@0A0`404@D00144000E10005PH001H70@0E1@4050P101D5
0@0B0P004PH101@8000H1`<07`h403/Q4P12@3X0;59R0313L00_;X@0<36302lePP0d>h<0=45n03M5
OP0kAgT0?D]k03eAN@0nEGP0@5=e041?L`0mC7X0?4Ue03Y;N`0lCGh00P0mBh009`0iBH00>d^003i5
O`11AWd0?dMn03i4OP11DGP0@UQh04=IM012G7<0@eaa03eCKP0fB7X0=TUk03Q;MP0hC780>e1W03E=
PP0jAWL0=S]f038iP00^>XX0:cb<02e0P@0Y?980;Cf:02TmT00X?XP0:ceg02TeLP0W<7808c=k02H[
L`0K:W`08B=/01HUO00G7gl05an@028aV00202LiS`0W0290U`0kGWd0G6eX08UlBP2AME40KY5P05B6
L`0mNHL0CEeX0082_0020kL00PIn0001O0000KT000:K0004X`024K`053RS01@jX00C>iL06D>;01Y2
Q@0SAX@0:E2;03EFP`0kFGT0=TYY03U3J@0bAG/0<DQg02iGP@0aG7l0<Uj202]SPP0VGh<07EJ:01YH
UP0DBYl02Rn^00800a2n00`010bT00<>Q00259l011j]00TWY`0<:k<03C6_00df[@0=>J/053fV01/o
XP0K@:8201e2W`0I01];W00ICId05TbO01U<W`0JBj007eJI01mFV00MFIP07FFB01e_T00QLHh09Vn=
03=nPP14RgD0CiA/05>HJ01EVFT0E9MZ05B>J`1?Qfl0GI5X06NHH01cVUP0NiIC07FCE`0206fCF@0W
06NBGP1PQVL0DW]a04]]NP18LGX0@gAk04AiN016NWH0BGUg04QdN012K7l0>Ef503EFR00jFW@0>EaS
03EEHP0]CVX08e9k02=FO`0XDGL08DB201dhU00M?ih073>P01P`VP0I>8l05BnB014WU@0B<YL052fM
025GSP0XGW409De/021;Q@0XF8D0:UJ<03I/Q`11MW/0BhA^0080EheS01`0JI=B07JEA`1oTd<0PHhm
07j4=P1mNc<0OgP`08Un<027QCD0NXXi06Z;@01UQ3d0FGlj059h>01<JS40@dLP030O2`0I2P803@<0
00P100060P001@4000<000040@000`4000<0000200000`000P010000100000000@00004000010003
000000050080000300000`0000<0000100004P00000<0?ooo`002P3ooolm000000@00@000P020000
1@01000000000000000100000@4000L00@0001L00P0000P30@0:1P405a<>010R;@097bd04b0S0042
]@001;400A2R00<XP`02:7T031^100hRS`0;<YH04bjE01/`UP0A=IH03cF@01ddR`0K?H<05SV101`f
NP0201loKP0<0251K@0S@G40:T1d02m0O`0bC7X0=eQb03ePK`11K6/09E^300XMXP000;<0002h0P00
0;/06@000;<0001n0000OP000ZP000mk008WSP0N9hP092Am014QL00E:Gh0829i01X]Q00D?8l07cJ7
02ThPP0I=X`063B;02P_Q00P<hD03bb;02/WP010=F`09TiV035?E`12;BH00P0]5PX09`0O2`806`T1
01/:0P0I2P<05@P201H7000H2P005`T101P60@0I1@406@D001L4000F1`004@L001H5000A1P003`H0
01D70@0I3080<QH904HR6@17;c00DcM005@kF@1;?F40ACi[0450M@0o@Vl0@DM]0419KP10C780AEEe
04MOL019H6h0AEY]04EFKP13Eg00@EMc041HM`0203mJN00W03]HNP0nDgX0@4in045<NP0lBWd0?4im
04=IN018H7<0C69]04mPI`1?G6/0AeM]041ANP0nDGH0>d]d03a8L`0jC6L0=DZ003U2M00g>h00=428
0352RP0/?8P0;DA`02TgT`0]@8P09cb<02HmS00W?H809cYj02TfL@0Q<H<092me01TUP@0N;G/05b]o
01/YP00I9Xd08RV;00808S2=00P06cVM02i@R00mGh40PgQ>099mB@1lSED0FHI]041^M080003401d0
00330085T@000Gd0006J0001U`000IT0532G01XcU@0L;iP073F:0211P@0TAh80:Dn102]FQP0fJX80
?VAk04=JL018E6L0@EQc03QEM@0`EX<0<EZ301aJTP0THHT08V:901]GT`0ECYl03CbZ00HT]P02008<
`@0;0088/@024YX00AfR00HZYP0><J@04SJ]018lZ@0B@:L04dNS01i<W00QDIP00P0SCiP06P0SD9P0
8ENF01mIUP0MGIH08f2C02=RT`0VIY009fF>029ZSP0TL8X097B902EaR`0WJH`0<gV203f5M`18SFl0
DIA[05JGIP1CUFP0DI1]052=K@1PUf<0J9iN076OF01fWEH0LIYJ0P1XV5d09`1RU600FXUY04^0LP13
N7/0?gAl03Y_P`0hN800>gUn03iiN`12Kgh0?FR303QRR00eGHP0<EF102i;N@0_Bg<0:4ak02ACOP0U
EW/0;5A/02]>MP0P@9D07TNH01Q0U00H?HT073Mk01d^NP0J;8<06cB>01PeVP0QF8h0;6M`035LF`0W
Cfd08Tn502A>T@0WI940>gmn04bAK@0205VBH`0H06RAE@1bT4X0Nh]107f;?@1iQc/0Lh<m07En>@1o
OSP0R80c08F3=@1mQ3L0LX0h06>1>@1GQD00CX5404mW<`18?QT0<QX901d;0`0@10002P<000T20004
000010400P0200000`020@000`0000@0000200D0000300<0000100000@0000<000001001000C0000
00`0oooo000:0?ooocT0000000@00@00000000000000000010010002008000080040000000000000
004000020@000P0000400000000200400080000001L00@0000H200080`004@h:010O7`0:7al06R<T
0042/0000;@00@f`00<WU`0298L02a>M00/IV008;iH042^F01T/VP0><YX02c6E01X_U00K>hd04SZ8
01`iOP0202A1K00<02=6HP0YAUl0;TQQ0399J00eCfd0=UAZ03UFL`10If`0>V=d01/oT`037jd00@je
0P000;/06@000;<000220000O0000H8000el00<PW@0W9X<09BUf01@YL@0I:hL0926=01LPS00@;iP0
8RnA02/eQ`0E;i@06BjC02PbR00N<8X05Bf102@/I`0[<6L0:dAV03=>DP11@cX00P17:al09`0m5``0
:`l401l=0`0K2P806`T101`:0@0M2@406`T001T80@0E204050@001H5000H1@004`D001<3000B1000
40@001<6000G1`407@/202/@1@0f50T0@b<A05<k:P1ADD80?daT02Y1OP0[?gX0;T=a02m3MP0aAgh0
=Deo03]IN@0kGG@0>U]g03QGMP0kEGT0>EAj03UENP0203aHN`0W03IGO00fD880>Tao03Y9O`0lBgh0
>4mn04ALM018HW40BV1^04aOJP1:F6l0AEEa04=FM`10DgL0>dYi03U6N@0eC7<0<T]h03Q5N00dA8H0
<dN70357QP0`AX00<4]`02e9S@0bAX40<3j9034mR00a?g/0;cYd02/fM`0U=XT09S9g01/WWP0T<hX0
6BbJ028`VP0L:i/07R6D00807bBB00P06CBQ02U3S`0^BXl0GfMV085_C`2<O4`0Gg=X00@?^`<00034
01`00P>X0001U@000IP0006E00H=QP0=8:T04B>U01<TY00D:8h05Bn301TdT00J?I<06ENA021PSP0Y
HhH0<FJ003QTNP0fIg/0<61o02UER`0TDhl04DZQ01IHU`0EF9X03TNT00Xh[@05:;H00QNm0P011l<0
9`012[h00A^h004U/@06;Zd03SB[010f[P0>?jX03TNU015?X00IDI`06e>K01a?W00LC9d06TjN01YB
W00IF9X075nF02=VT@0UJhl09fj;02Q`R`0YMXL0:gb402alP`0^NX@0=GF303f0NP11QW@0BHe`05:?
JP1FTFP0DhiY04n<K@1GSf/0I9QQ06ZNG01dX5L0NZ5C07RPEP02076NFP0W06^JG@1WTV40FXUW05N2
K@1=OW40AgMg04AkN012O7P0AWUf04EbNP14Kgh0?fV103eRQP0eF8d0;dZA02e;T@0ZC9@09U2F02QD
T@0`G7T0<EQe02E7T`0SCi@08EF;01mBM`0O>7/08Rn=02HcS00N=YX06CfP01eEUP0YHG/0:E9R0253
K@0J?XX074ZF01iGV00cL8D0AhQd0080FI9W01P0JIQL07:DD01kSd@0Ohi007^?@01_SDH0KHE506n3
A@1nQCX0PX<e07b6=P1hPCD0K7hf05^1?P19QTX0B7I504mK;P1;?aT0=b89020@100G20802PD000H3
00040@0200<0000300<100040@001@000080100000<00`000040000000000P0000000`0100000P00
0040000E000000`0oooo000:0?ooocL0000000@00@0000800001000000000P010003008000<00@00
0P000006004000@0000001L01@8100D200050`003`X6018J500>6Q@030i?00P8M`000Id00`n]00LY
U@0698l03aJ@00hOU00:;i403bZB01X/VP0A<iX032nE01T/VP0I=iD04SR@01/iP`020252KP0W01e9
H@0TBED09DUA02U<F00YDel0:e1]02a9OP0kE7H0@Ua^02eHO@0AB9H01B>Z0001^P0009@0002c0000
R00008`000650008R@0=8Il0:BF302<^M`0B;X406bf:02L[R@0H9WX052j3024ZQ00P;XP052nE01`[
U`0W<Xh06bn@01P]T00V<8007S1X028mM00cAfH0=daQ0080@TeC0280BCLg04DO4`0[4@D08@/301h<
0`0P2P4080T201/7000I1`405`P201D60@0J1`405`T101H60@0B1@4040@101440@0B1`005`L001T8
0`0M3@<07P`302XC1P0e80d0AcHQ0513CP0j>WL0>d1]03a0M@0k?WH0>cid03m4N011C7D0A59d0P17
F7000`17FW40AeIb04IFM@02049FMP0W041DNP0nDgP0?Dmm041?NP12DGT0@e1g04QHM@1:FG80BUQc
04YGM@14DWT0B51g04EANP10CX00>4Z303E:Q`0eChP0<Df803A=P`0bAhP0<DN60358P00`BH40<E1e
02i;R`0d@7d0<3R;034kRP0a>W/0:SIg02TgN`0S=h8093>001TcR`0V<H406Rb=024/PP0J:i<062:M
00806B6I00P06CBL02LgSP0U=9H0>eAo051UL@2DLTH0HVAZ00<>_P<000350P000<@06P000L40006F
0001SP000/D000c1000E_P006ZD001RP000G/`007k400SjN00A;W`08F9X03EnJ019VU@0GJY@06F:C
01MBV@07:[<01cZ^00M7Z006A:/00c>c008S^@016K/00A6l0P058[P09`089kD02S6a00/g[`0A?:X0
642U01]3X`0IBZ406DnO01U@W00KCId06TRO01Q3X@0I@J<05d6T01E2X`0DA:<064fM01YGV@0LGiD0
7VFA01m[S`0SMhX0:H:402Z3PP0aPH40=geo03b3N@0nQ7P0@HMf04N5MP16QG@0AHEg04J5M@1@S6l0
FYEX06:JHP1YVUh0KiaJ07>ME`02072MF@0W06ZLFP1VUEl0G8mS05^:IP1DQF/0C81^04Z0LP1:PW<0
CX9a04f1L@1;O7H0BG=i04M/O@12Hh<0?e^503aMP00gGW`0=61i03EQL`0aGW00;eUe02MIPP0YG7X0
:eib02YQL00SBWX08Sb602HcSP0O>I`07dR<025HR@0SFHh05d2B01HdU00C<9X04T>L0157XP0NGi@0
=7^40080B8ae02L0FIIY06bLF`1lWDl0P9U708>C@`1lTd<0Mh]307F6AP1nQC/0Q8@e07j4=01kOS@0
MWPa06Ek>@1AQTT0BXE?05Ml@01IK2h0CdDJ03PS2@0O3`@04PP100/500060`001`8000D100040@00
1P8000@1000300000P4000<1000200000@000000000200000`0000@100010@000P01000300000003
004000000000000000d00000303oool000X0oooo=P0000000`0100000`0000<00002008000800@00
0P020000100300000P0000<000020002004000030000000100000@0000<00@000`00000060050P40
1@4000D200050@0030P401<D30094C@061DM00h?D@010h/0116]00//U@0;9Hl03abD01@YSP0=<h<0
3B^:01X]V@0F=iH03c6?01L]V@0J?8L0542201`kR@808dEd01007TeS025?E00PC54084iG02ADG@0S
DFX09dMm03E:O@11EVd0>5ec02ANQ00A>i/00@J<0001U0000;<0002=0P000:805@0019P03AbS02XT
RP0O<HP02b^F01TZTP0V<hT062ia01D^P00P:HX06RZ9018dU00L;iD08SF>01LeT00L<i409SB201`f
MP0R?X<0;Smg02U3M@0202aLL`0<03a>F`1>=Bh0?b0<02lB1@0U40@09@l401h=100L30806@X201T:
0`0H2P806PX10P0K2`806@0H1`405@P101T80@0K20407`X201l80P0N2`<07Ph302@=0P0/4P@0?Q/<
05@X8`1M=D00EdY804aBG010C6L0@4E/0413M010AW@0ATmb04YEL@1=G6d0CUi]04aNK@1;GFl00P18
Fg@09`15EWH0@eIh041EN014DgH0AU=g04MFM@18E7<0Ae=d04QDM@18E7H0AE9h04UGM01;FWL0AEUj
045FO@10Egh0@5Ym03mJOP0lF7X0>5El03YAM`0kCgL0>4b003I<M`0_?h00<CQm02`eS@0a?Hl0<Cb:
02XjR`0[>8@08c:J020hV00F;ih07c6A01H]V@0L8G`05BF@01<PW`02018NWP0:01XeT`0W<HH082^I
02m3R@0eF8H0Ofa?0456QP0D6;800`C10042`P80003401/000330001`00108<0006I0001`P002Kd0
00ng000D[P004[40016k000JW0019HH00RfC00@iW`05?j0024RR00Y=XP0=BZ@01BFg00@S^004:;H0
0bjd008[]P027k/00AJo004A^`04;;800P07<:h09`0;>:T03T2V00m5Y`0GC:407U6L025DV@0QEIP0
8U>G021AV@0QC9/07dZM01m8WP0PB9h07T^M01e:W00NCYT08EBD02ENSP0XIH`0:Vb802]dQ@0]Oh<0
<HMl03>:NP0mR7H0@X=e04:7M00oQ7P0?H=j03enN`0oOW`0?Gio03^0OP14Pg@0C8Ya04bAKP1DTVP0
EiEX05^FI00205bHHP0W05bEI01GTVL0DXaY052:J`1;QG00@X1h03elOP12P7P0BH9c04Z3LP19NgH0
A6mj041VPP0lGHP0>5R703IHPP0eFG/0=Eie03INMP0^F7P09UB1029EQ@0RDX009U1e02EJN`0REG/0
84Ae02@bR00R?I40:eYc02mXM00XG8X06T:F01HfUP0D<IP053nL01=0XP0JD9/0;Fb>0080?XEn0240
BiAb06>PHP1eYUL0PJ==08RJA@27Ud<0Oi9807:DC`20TdL0Ohi007j8>@1jOC@0MGT_06ii<P1RQd00
F91905f@A01PPST0G64W04dl5@0a8@X07Ph300d70P0710401@8000<000020@00100000@100060000
0`4000D100030@000P0300000`0100000`0000800005004001400000303oool000X0oooo=@000002
0081000600<1000400000P000080000100000P000P030000100400000`0000<000020002004000@0
000001d00@00000000000000000000<20@040P401@8000@200040@002PH200PLD`0;4Ql071HG014C
?0022V/01A:>00XTTP0;9I4042:Q01T_S`0A=H803Rb301d`U@0J>I<04S:901L/VP0J@8P05DAn01`h
SP0202A5O@0W01mBJ@0PE5X07e9J01YCGP0QE5l08U9T02A?L@0bCVh0@UQR045MJ@0dHWL0956700@?
S0001:80002c0000S@000:80006S00@ZU`0=7j<0:BF;01`bRP0::iP06RJA02D`O`0C<W<05c6802@/
R00J;H803cRC01l`TP0L=hl02SJE01XaV00T<XT03c2=01`eUP0Z@H408TAb0080:dib01D0@DU@04/o
@01H=CT0GB/S04DM3P0^4`D09@l3028?0`0O3@<07Ph301X;0P0K2`807P`201l=0`0O2`808@d301l?
0`0U3`<080h201d=0P0P30400P0P2`40400N204080X302l@0`136`/0HdTd04iYE`0gIW<0<TYl02hj
Q@0`?XH0>4F103e;O016DgD0AEIb04QJM@15FG@204=FM@0W049BN00mCWX0?4ik03i:O@0nAgl0>TJ0
03e8O@0mAX00?dN0041;OP11CW/0AUIf04QKN013F7h0?UQn03eGO@12FgX0@EUl03iKN@0jFWH0?EMa
03iDL00kCg80>TQ/038eK`0b=g40;c^603=2PP0eAG80=41^02llP00[?i80:Sb@024dU00S=XP072mo
01dUN`0G9XX052:I0080522Q02L0836?02T]P@0O8:409bjC02A2V01MHfL0F5=c02LUXP072Kd00`C0
0001a0000<@000730000W`010:L0002d0000a@001<8000O00009_P002<0000VO0009X@003W<00A2B
008G/`027Jl00bFb00@[/@027[/00Qbl008J_@025kh00A;0004=`@012/<00@O40049_@05;[000P07
<:h09`09>:@02d2P00e5Z@0DD:806EJM01]FW00ODiX07TfM01e<W@0LBYh06dVN01e8W`0OBIh07dbL
01i<V`0NDYL08eNC02IOS`0YJ8`0:g:702mkP`0cPWl0=hQl03^:M`12RG@0A8Ya04F;L`13RGD0A8Qe
04J3M@18Q7@0BHMd04Z7K`1=RVl0CXm/04jBK01?V6/0D9Q]056JJ@0205>EI`0W05FEIP1ITF@0FXeT
05N<I`1EQ6T0Ch5`04QkM`1=PG40Dh=_05>1L01=NgH0Ag1m03mVPP0lFHL0>eF903UDR`0hEHL0>eb4
03MMQ00^EhD09UB@01m>V@0OB9d07T>I025IRP0OGH`07D9k01laR00SA9@0=g5c03amLP0^HXD07DR@
01@hU00D<IP05cRK01XhX@0N@9h0;UfA0080@7^101/0DI=a06RRH01iYEH0PZ5A08JOCP2>W4L0RIY7
07jMC023X4X0PiE308:4>@1lOC@0N7P^06me;P1TP3L0FXi305ZCA`1KT4@0H80g05aO9P1<?AD0;aT7
01P;0P091@401P800081000100000`0500002@0300000`8000<0000300000P000040000200000@00
00000004004001400000303oool000X0oooo=00000030040000300<000040000100000800P0000H0
0`0000@100040@00100000D100040@0200800003004000000000000000@000000P0100000`050@00
104000@1000200@1000D00L20@0783`03a@I01`G7`0=4S`01aI600XJJ`0C7X<02B:@010QX`0I;9@0
3b^=00lWQ@0Q;8H06c6<01DaP`0L;W`07CMl018fO`0F<98201loN`0W01]AK00JEFT05eEX01=GI`0J
Ef<06U=Q01iAJ@0ZCVd0=e=P03YEI00iGW003bJP0086]0000[P0006c0000S@000:8001jU000XV`0<
7j<0:BJ;01TbR`09:iT072:B020/O`0<<8<05BfC02PbOP0L=7d04CJF02<`S`0N=hl033FF01laU00X
=8`03B^H01XYT00S>hP0546000808cin02L0@dML03]6E`0dAW00E3UC05T^8`0g5`P0:Q4402HB1@0U
40D08`l301`;0`0J2P807@X2020>0P0S3`@09Pl502<@0`0U40D090d3028=0@0O3@8080/10208000P
2P808@`302P;0P0f40D0G3lT065OA`1CHF40DdeX04e1L`19B7@0@e1g04=BN017F780AEQc04IJL@13
FW<00P17FG<09`17EW@0@eAe041?N@0nBgT0>4]m03Y<O`0mCG`0?DYm045:N`12C7/0@E9j04QFM015
FWL0@eMj045EO00oEGh0AEEj04=CN`12EW`0?e=n03iBM010DFh0>Tam03U2NP0a?HX0=4=^02`hQ`0c
@7L0<Sib02diOP0[?H809C^E02LiSP0P=8h08SAm01TZQ00O;HD06BZ<01XYU@0201/VX@0@02</T@0V
:h007R>I02D`TP0N?9P0Aeed05EJL@0o>8h05ANa00T<^`010/@00@:o0084^@010;P00@2o0000]P80
002_00`0002^0001[`000Jl0006>0001VP000F/000:40003X0002JL000ng004D_@015[l2004E`007
004H_P016[d00A^m00<M^`057kT063FR01PiWP0201LhY00W01LmV@0H@YP05dNR01a=WP0MDI/08DnH
025>VP0QBY`08D^K025:VP0MAi`07dBM01i2WP0NAY`07TNL01]<VP0LCYT06eFH01aMUP0OIi008W2>
02AiR00WP8D0<86003F4O00gQgX0=XQj03J8OP0jRGT0@8Ug04N8LP1;S6d0BHe^04^>K@18TVh0CII^
04ZFL017UFh0BiI_0080CI1]00d0D8e/05F<JP1JS6@0H8aS05j9I01IPfP0DX1[05F2J`1FPfX0DX5_
04]kM017LgX0AF]n0080A66001P0@V>104IZN`17KG<0@FYc03IOP00_F8d09EFE01mCV@0PEhh0:FEn
02]TM`0XD7D0:U=k031KO00dHf40<V9L02MBJ@0L@gh053b<01<cU@0F<Il072jS01l`X@0]CYL203][
R@0O052=M01XX680M:EG07bTD`22XU00RZ9;08jQB02;XT/0R:5808FH@@21P3@0NgT`07Mf;P1[LB`0
H7Le05F5@01BT4/0DYI>05RBB01OP3T0G5hT03l^400S4PD03PL200L300050P001P0000H100060P00
104000H1000200D1000500D0000300000@000000000100000`020000100100000000004000010003
00000003004000000000000000T00000303oool000X0oooo=`0000000`0300001@0000D000020080
00D00`0000D01@4000@1000200000@00008000050000000K008000040@000`4000<100020@000`40
00<0000?41D01AhX01@D5P0Q5CL01A1l00PK@`0O;fL04aF300TRS@0B8:406RZJ00lOXP0@6Ih082NA
01/ZR@0F<7l08S5]028/M`0?:G@04R^:00808SmY02L06dUT01M:L`0IBW405e5/01UDK@0LDfd07U5a
02I@K`0_E6@0<eIR02iKN@0G>9L021nM00DGTP022HX00@>70003S@004gd0022=00dMX@0Z8hX06Bn=
00T[VP0N7i808BZ700HZU00C8id0:C>601XfQP0?9j009RR>01`dT`0;;9`08b^C02TfS00>:9X07BF=
024_R00C=h`00P0Q<g009`0^>UT0;d=P03=0H012?UL0Dc`i054[5`0o6`P0:Q8402@@0`0N3P807`/3
01`:0`0L2`<0810402<B1@0R4@D07Pd4020@0`0Q3P@07``2024@0`0S3P808@h2028=000V4@<0:`h3
034A1@1B<QT0JEU006INF`1bGU00LVAE069OGP1@GFP0AeY/04EJK015FG@0AEaa04AJLP0204=JL`0W
04EIL`13EW@0?e1j03U=O@0dCgl0=e1n03e@N`10Cgd0@Dmj04EBN@0oD7X0B5Eg04YJMP16G7D0AEUh
04AIN@18FGL0AEIi04EHM`14F7/0@UMe03mBJ`0lBfh0>4Yc03A9O00hBfd0<dYe03E8L@0fAWl0<D>4
02m1O00/?Hd0;SZ802@dS00V<7L07RnE028cRP0L;9H08S2M008082ZO02L082NI02@XSP0L9J808S>J
01`fV`0kBGd0BUIe05iMJ`17@XD09b^P00XA^P0:3j@010BE0041^P010Z@00@650001L`000GD0005f
0001N0000HH0005g0001QP000Fd0005Z0002L0001HX000V]000D`0004l000A71004C`0017Kd00BFi
008/]`05<K@07D>Q01i3V@0M@YH00P0M@IT09`0N@iH07TNI01i<W@0RD9T08E:G02AFU@0VG980:Ub@
02eHS`0]DI00:DjC02M;U`0SC9P09TjF02E?U@0RDYH08U:E029FU@0UFY808f:@02=VT00QKH`08gF:
02IhR00[OH@0;X2102n2P00aPgl0=HAm03f8M`16Rg40BXe/04R@K014TW40AIAa04NHL@14UG<0A99c
04:>M@0204B5MP0W0463N@15PWT0D8I_05>8JP1DQfX0ChI[04j3L01:P740BH1c04AjL`14Lgh0@6Z0
049WP014H800A6F0045XP@11JW`0@6Mj03aRO00fGH@0;EN?02EFUP0PEYT07eV@02]SP@0bJ780=6e^
035/L`0]Eg80:45_02A0J`0N>gH05cb0018oRP0A=iD04c:S01`/Y00O:j@0;52I0080=fZ<01/0AX]i
05ZOJP1SXF@0Jj5O07>TG021YU<0RjE;08nSB02?WdP0QiM208>4=P1lOC40M7X`06Md<01OM3D0DhA2
04R>D012U5P0AYII05J=BP1SMS@0DdPK03HT2@0I2`<02@@100D200070@000P070P000`0400000P00
0041000300<000040080000000000@00008000800`0000@00P000040000100000@000`0000000`01
0000000000000009000000`0oooo000:0?ooocH0000000@00P0000<0000400001@400P040@000`05
0@000`0000<000020080000300<100040@000`0000800P001@000002004000800P0001L00@4000<0
000;0P803``;010I6@0F5b405A8f00HJD0046hH08BmS01HTN`0>:W`06R9]01XTN00<7I/04ANV02@V
U@0I9H`05c:502HeM`0T9X403B=/01D/Q@0202DoK`0W01PiJP0E>W`06cj301A5O@0EC7`06Din01Y?
NP0QD7D0:eIZ03ANHP0dH7007TV:00dgR@0;;H001a^;00@CQ`024FP00A1R000IP@0?6Il0;1n901PZ
T@08:9d08aj?02D[Q007:Y80522M02T_R00H<hP03B6T02XXQ`0M=8T02RFL02DUS00W<h`03RRO024R
U`0Q8i004B^I00807bn902L083]^0255J@0d@ET0?d=804A6D01CATh0F2hW040J2`0Y40808`d101h;
0P0O30<08A04024?1@0S40D07Ph401l<0`0Q3P<08a05020@1@0Q40@080d202D<0`0T3P40:14203<C
100f50@0ARP>06AL>`1HMVd0Jh1M07MjF@1bKUD0FEYU04UCJ`1:DFT0ATmc04IEJ@16EG400P14E780
9`14EGD0A5Ae041>N00iBWd0=TZ003E;OP0jBh40>DV003m:P00oBWd0?TYn049?NP17E7L0@eIj041F
NP11E7h0A55j041<P@0nDH00?5=o03Y@O00jD7P0>Deh03M>N`0cCgh0=e=h03ABM`0dCgP0=4n50356
NP0b@740<42403<kP00/=8<0;35i02LdN@0R<H0072j=02D`P@0201lZT`0W020VVP0P:9@062fQ020c
UP0K<id0<San03]?M`1GMFD0GVAZ04=4R00H8:h01PNS00@4[P010L001PN:00H=GP042UD00@=P0002
K`000<@000620001N`000ID000600001R@000Hl000:;000>]`004L400132004>`P014L400B2k004X
^@02;kH01CFc0150Z@0?@JD04T>R00804d:Q02L05TBR01I3XP0HBJ006d^N021?VP0NEYL08V6A02EO
S`0ZEY00:4bD02=8V00PB9/08DjI02AAUP0SDiD08eBD02AEU00UFY<09U^A02MNT00UGhl09V>=02IZ
S00UKh/0:GB902afQP0bNH80=7in03V1NP11QWD0C8e_05:AJ@1?SfT0Bi9[04ZDKP1;UFl0B8mc04F8
MP0nP7/00P0nN7h09`0jLH80?W=n04MkM01?P6h0Bh9c04N3L`1;Q740BH9b04f1K`1=Ofh0CWab04ig
M@1@Lg<0CVme04]`M`16Kg`0@feo045XP@0oHh@0?629039JSP0/EY<09UFF02=GT`0]GhX0>6mo0465
M`0iLgD09DN001X^U`0R>I407SFV014oY`0=@j<03S^T014bY`0K:JL07RFW02M@V`0202mZT00R03R8
PP13V7D0BIQb05NMJP1XXF80NZAI08FTD@2<Y4/0Sj9908nN@P28S3T0PhLf07f2=01_Nc<0H7Te05>1
@P15RTl0@Y9H04:FFP1CUU40HH]3061/;@1<>aH0:QT701870`0610402@4000L300070P001@4000<0
000200001000008100800`000P0100001@0000000@00004000010000000000800@000`0000000`01
0000000000000009000000`0oooo000:0?oooc80000000/00@00008000030@000P0000<000050000
1P00008000020@000`0000@1000200<000030040000000000@0000800`0000@00P00004000020000
0`000P0000001001000000000040000100020080000F00<000090`403PT401<D3@0N7c403Q1Z00DD
C`0339P07BiW01<^M@0>:7L092E901lRE00:7hX04QVT02DXT@0H8hh04bj@02/eM@0X;gD042MZ01P[
RP80:3id02L05SA^01DhN`0M>H<05Sij01E4P@0JBHX06Dj501i@P@0XDGP0;eU/03ALK`0RDH<044B7
00dhPP0<:8L02bEe00//H0036Vd001N600hFW`0[7HD05RBA00DQX@0U6hd0:Bb100PZT@0E7Id0:R^7
01D_QP0<6jD0;2R501heOP0:8YT09B>9028ZR`0@:il08bNC02D/R`0F<IL00P0T<8X09`0Q>WD06d=g
02loI@0f>V00=4YR03Y:K`1E?TH0DBTD03LH1P0[3`8090d402@?100V4@<0914502<?1@0O3@<080`4
02D?0`0S3`D090l502D@100V40@08`d102L=0@0]4@<0=A@403PH1P138PT0Id`]0620G`1XP5l0M81J
07ASC`1dD4h0JU1E06MBE01NEf40EEIK04iIJ00204YKK`0W04UMKP1:FW40@eMe03a@O00iDgX0=5B0
03UCO`0jCX00?4io049BN`11DGP0AUEg04UGM@1;FGL0C5]e04UEM`18DgT0@dn0049EO`0mE840>U63
03YAQ00iDHD0>E:303QDQ@0kEX00=52703=AQ@0bC8@0<3ib030jMP0^?HX0;SJ302TbV`0[>i@07bZO
01X^X@0D<:407bUj00806bJ=02L07BBL01dVU`0F<iT07CB?01dcV@0/>VX08d5b03UNM@1JJVP0GeE]
01`RZP0G8ZT03an_00HH]`0?7hD06SQ[01@^L@033X000ARh000H]@004X/000b;0005WP001i4000VV
000:/@0049h03BbX00h^/@0@;Zl04bn^01H`[00G=ZT063VW01TlY@0T@i`09D:L0215W@0NAih00P0M
B9d09`0OB9`07dNN01m:W00TBiP084fH021BU`0QEYD08U2H02A4V@0Q>ih073^P01`lXP0OA9`084ZI
01m;V@0PCiT0852I029DV00SEYD085BG01mDUP0ODYH06eJH01YJV00MHIH08VBA02QZS00YLXT0<WV2
03V1OP14RgL0BI1_04^>KP19Sfl0B8ma04N;MP11PGh0?GUn03AYQP0203APR@0W035HSP0gGhL0?Vf1
04=cO@11M7X0@GMn049kNP13NWX0BGeh04YnLP1@P780CGea04ikL`1?N7@0CGYf04QhN016Mg/0AWAm
04IaO@13Jh80?6F603APS00^Gh`0;627039XMP0lLfT0?W]^03MVM`0XC8X084F=028hS00N;:P04c^[
00m2Z@0@?JP04cFY01`/YP0Q:J<0:UN@0080;g220200;X>1036@P@0bSh00@iUg05ZOJ@1bXe/0OJ=F
08ZQC@2=XTT0TJ=708^OA028VD00Q9<n07>9?01RPCT0DX=204F:C`11TED0AiQI052MEP1GVe40GHY2
05US:`14=1<091@601880P0?1P403PD000`300070@001@0000<000800@0000@00P00004000020000
0@000`000002004001400000303oool000X0oooo<P0000001`020@000`4000D20@040@00108000D3
000500000P02000400<000<0000000<00@0000D0000200000`020000100100000P0000<000020002
0000000H008000030000104000L100091@404@`6020N;00=6g8000>`0085XP0H;6P03c=Z00dPN00Y
94D09BA400LSN@0A6Y@092F<01<OTP0<9Il0:S=j02`fK00@9fX06RN>0P0[?G<09`0H=V/05cIm02<h
O`0J?7805Cj201e4T`0KBY006dNA02M6R00YBh00<E9g02ACPP0?BH/033Ao00XMKP054fl00`iX004<
K00068`02aRJ02LLNP0E8gh01BFE02<JP@0U8WL01RBA01DLW00Z9h@04Rj700`HT`0Z9X@073Am00XR
T`0U7hh08b>;00/YY00S:i408cF801HdV00202LbQ`0A028hN`0J>HX0:cYn02dnI`0cAVl0?DMa04m=
DP1NAcH0H3DU04dM300c5@H0:10502H?100U3P@090`3028;0P0U2`800P0V3@<0500U30@09`d202T?
0@0/4080;0h302`C0`0e5PD0?1P504HK1P1T>Q`0KX1607>0EP1eP5/0KFaI07ECEP1dF5@0MEQ:079[
D01OHeL0Ae]Z0P15FVd09`15Gfd0@Ueb03eFNP0cD840=563035CPP0cDH<0<dj303M=Q00iDWh0?5B0
041EO015EG/0AUMg04]IN@18EWP0B5Ei04AEN`10FGd0?5Uo03UEP@0fDhH0>UB403iGP@0mFX00>UMn
02m?O@0bCg@0<TI^038mM00a?G`0;cf402llR@0]@Y<0:d>>028mT@0S>Hh08S>>024[P00201h/Q`0W
01dYS00L9XT06bj001`/P`0P<9@0;3Im01`XV@0Z=8X0C5Qf071XFP1BEWP0@UIo035CRP0OCIH08Den
02IAK00P@V4032aa008eV`01<Y/002V=000OS`005iD001VI000JY@007:`04D2N0194X@0CAjD05TVS
01U;X00MCId084nK029@VP0]DI80<E2A039>S`0/Ci809U6D008095FC02L09eJC02UGU00YEi80:eBB
02QCTP0ZEY40:UV@02]HS`0]EHl0;56A02a@T@0aD8h0<E6=031BSP0]Dhl0;5B@02]DT@0[EI80:UFA
02ACT`0TCYH084NH01e9W00MC9X07e>H021CV@0SFi@09FFA02Y`R`0bNX<0>H=l0468M`18RW@0C8Y`
04Z9M014PG`0=7:6035RR`0YCI400P0YAiD09`0Y@9P0;TRB03AES00fFH/0=Ef:03=NR`0jHXH0>ef6
03YNQ00eGXL0>VN303ETQ@0jIhD0>ff203afP00jN880?GMn03m_P@10Kh00@F^203aXQ`0fIH/0;F2=
02]JR`0/EH80<Emi035UP00^G8L0:e2@0296RP0M;XX062:^01HiZ@0B@JT043jW014jY`0N<Z809c>K
03eWNP0204Z1IP0Q03b0M00eRWh0=h]o04FFM@1JXfX0KJQM07^UEP29XE00RYi?096NA`2;XdL0S:=8
08JRB01jUd<0IXHm05>5@`14R4h0AHe@04ZAE01AVe<0DZ1E052LE01GQ400D5TX03X[400Q4@@04`/2
01880`0?20802`<000@100010@00000000<00@000P020000100000000@0000400001000300000003
004000000000000000`00000303oool000X0oooo<@0000002`0100000P0000<200050P40104000@2
00040@0010000040000200000`0000<00@000P000000100200000`0000D10005000200<000050080
000100000P0000<000030@000P020000600300000`4000@100050@001P8000`60`0J5QX0006g0043
/@010jP04b]Y00heG@0<7Wl0:29Q01lZE`07;F@04B1_01LLR00>7I<03RFR02P_OP0W=fD042Qd01XV
T`80:C]b02L05CM/01HcQ`0U=8806SMi01<dR@0L?YP06d6K01XhWP0U>9H08SbC02e5P`0UDH<03TbC
00P]W0021ZP00@:Y0001Y`0029/001VM00PIV00R6X005Aib00DWRP0P6H408QQe008OT@0E6i/0:BB3
00lZRP0<6HL07Af5014ZQ`0:8X407QN401`KNP0<9hX08RB2024]PP0F<YX00P0Z<Xd09`0T>8@06BjF
02XeS00R?WX084>603E5P`0oFf`0Af5F059@D`1H=2T0@1`902XB100V3@@09P`302H<0P0T3@<090`5
02P?100U30@090/202<:0@0Y2P00;0`102l<0`0`4@<0=AD503`G10147@L0H34B07AY>P1mP4h0NgMK
06Q/J`1OEg80G5Yc06]:H01WEF80L69D05UII002051FJ00W04aII@18EVl0A55`03m>NP0jCgh0>E5o
03U@OP0jCh00>dn103]AP@0jCh00>e1o03e>P011DWd0A59i04A@O016E7/0BE]i04AJNP10FWl0>UJ1
03U@P`0iCXH0>E2603M>R00cCXX0;DR=02i:Q`0_B8H0<dF203=0P`0/?900;46B02U1U@0[AX/08T:=
02DlS@0R<Y<0836B00807S2@02L07bf201`WO00E7WH05Qf3028]U@0Z=HP06R>=02H^LP0fEW80GgES
07IdE@1bMUP0GGeV04AlM@0iMgL0;6ii01iKO@0;F8l00d^I0053W@00?J0003JS000bYP00<ZX0036^
00]5Y@0;AjH034NW00e9Y`0>BjD03dbT015>X@0DCZ405dnN01e=W@0RC9/08TZI01m=UP0ND9H00P0O
EY@0600TFI<09EVD02QHTP0TE9<09EBA02UETP0ZEi80:UV@02]LS@0]FXl0<UN<03AFS00bEXh0<5B?
02eET00[Di40:EBB02UGT@0YFI009UND02ABUP0PBYP084VJ01m6W08084bJ00d07e:I029JU@0YIXl0
<WB503Z0O012PgL0B8Ua04n<K@1AQfl0B8=g049mN`0lLWl0=6F60080>Uj802L0>E>:03eKQ@0lGX@0
?62503QOQP0fFhL0?UR403]BQ`0jF8L0=eR903IJRP0eEhX0>f2303iZP015M7/0@g9k049_O@11L7l0
BGEj04ijN01<N7T0@g>003]WQP0aFXh0;4jC02aKR`0^HhX0<66<02iES00S@8P06bbA01HZZ`0I>JL0
63jX01DoY`0E?ZD08SVN038oT@1GMfd00P1^TU/09P1>PFL0=H:003V8P015TWH0E:1/06:XH`1`Z5/0
PjEC08bOD02@WT/0SJ=9092TA`2:XTP0Nie906Z;@01KQd40C8Q804Z>C01@T4X0EYE;05:NEP16XUh0
CYQD05Ii?P1>BAh0=2@<02<E1P0I40@050X300/30@060P000P40004000020@000P00004000000000
0@000`0200000`010000000000400003004000d00000303oool000X0oooo<00000020040000;0080
00030@000`4000@100050P000`00004000020000100000<0000100000P0000030040000:00H10005
0@001P0000@100030@000P00004000020000100000<000800@0001P00`4000@200050@000`400081
00080P801@nJ0042]0000K800@6_00hYJP0;<eH02aZ602<OS00I;H`01Bm_014XJ@0?4hl02AbE00hT
Y@0W;HH083Ad00lUQ`0L9IT2028gO00W010dNP0C:iP093:<01H_Q@0C;ID07SZI01U1W00I>Yd09cZA
02DnR00[AH40;U6001mBRP0@;i800@:i0001^P000;P00@RW008KX@0=79D09AUj01DKK`049h/07aN9
024AN@0378l04a^I02PPQ00;9hd02QRT014CW0057Y@02Aj;01dAS@0C4W002bB601hIQ@0K7HD04bNL
0080:C2?02L08cR401L[V@0[=8P08Sem01`iSP0c@8<0=E=f03aNK018E640ET=005<^6P1370X0=104
02D;0P0R30808``302L>0`0U3P@09`d302D<0P0Q20409@/102D<0@0V3`80:Pl103<@0`0i4`<0@A`5
05PZ3P1bCbH0PH120820E`1aLVH0Hf1^05IIM`1VCF@0K4AO07]=B01fDT/00P1^Ee<09`1MGe@0D5mS
04MKJ@14EGD0@EAi03iCOP0oDg`0?U=o03aAP@0kCh00=dj403Y9P00kBX40@Dmm049EN@14EWT0BeUe
04iLL`19GGL0Aeeh04=LN`14Fh00@UN003]GPP0hEX@0=eJ6035ER`0eEX40=E1m03I8P00a@hL0;4FB
02i5RP0[@XH0;dN002Q2T`0/?Y@0:3RL02HiW00201hdWP0W02<bQ00M9H003`n@00dCVP0P:ZD0:C>D
01LPO`0R:6/0:dMj03ePN`1SKVD0RG]707n6D`1^SF00G8a[04^4M@0gM7h0;FF702=ET@0QBYH084>I
024mVP0R>i/08CZL02U4U00X@i40:46C02PoU@0W@9H09T2F02E1U00T@i@08TBG02A6V@0VAIP09dBH
02=3VP0SAiX094bH00809U6F02L09U2E02Q@T`0ZCI@0:TfA02]=S00YCI809dfD02I?T`0UCID09DVH
02I3U`0V@iT09DJH02A8V00PB9/07TJL01a:V`0MDiP07URG01aGV00MDIX06T^N01Y5W`0J?:@06TBP
01U3X00HAJ007TZM02=BU`0/Ih/0=WV003f2N@16Qg40D8Y]05:7K`1:QG@0AhEe03j0O00gNWl00P10
KX009`12HX80@VQo03iVP`0kI8<0=f2503QGR@0jDXT0>D^=03QER00gFhH0=UJ;035;S`0gDXL0?Un3
04=YOP13K7h0?g6003ijN`1<Q7<0EHY/05Z:K@1BR700BGih03e]Q@0cHXP0=Vn003AcN@0cL7X0<V60
02Y?R00O?iH06d>R01dlY@0M?Z407Tj?021FQ@0YBhL0<TN?04mbK@020625FP0S04enJ@0nQ7`0A8ek
04nGL`1FWV/0GjIW06JTH`1eY5`0PJ5E08nQCP2>XdL0TJE708nSB01jXdd0LiA505j;@`1ASDL0Ci9;
05FAAP1HU4P0DIaF03jOI012W6<0ChiC05a]<P1;AQX0<Bd?02@L200G3@@02PH100D1000200001@00
00<100020@000`010005000000@00@003@00000<0?ooo`002P3oool`000000<00@000P030@002005
0P000`800080000000000P0000D1000400000@000P0000020080000:00@000060@001P4000H10003
0@00104000<0000100000P0000<100<00@0001P00P4000@100050@00104000<100080P4041B10085
ZP010jh00@6c00`XLP0;<Dh03Qa?01hLEP0B:7D02Rm/01d/H@0E6H<02R>501<YS`0Z<GP072j500hS
U@0N9I/2024eT@0W00T_T`0B8Y`08bbB01DWU`0B99d07CJK01Q0W00G?9d0:Sb=02DmQ`0U@HD0<Tj2
02I=N00L=X/00PBg0001^@000;T00@RZ00<KY00?79P09QUe01@LN@04:8h07aJ2024AM`0678404a^;
02@NL@0=98D02AZ@01@EU0096YH031Z>01d>T@0A4F`02R6>01`CTP0F4h<04R2M0080:Rj902L08CN4
01HXVP0^<HX08SZ401`[UP0`?8L0:dYo02i5P@16BVd0CE=J05=;BP1L<SD0CQd@02hB100/3P<0:@h3
02L=100U40@09A4502T?1@0X3@<0:P/202T=0P0W4@80;10203HA0`0j5`@0@Ah6054U2P1Z>A@0Q7=0
08:0DP1_N680H6Ae059NN`1NE6l0IDMZ06E<HP1UBF400P1aAEd09`1XHU00CWAS049SKP12DgT0@Tmi
045=O00nC7d0>d^003U:P`0eBHH0<T:403=3Q00e@X<0?TUl04=AN@16DWH0Ae=g04ABO018E7/0A5>0
045EO`0nFH00>eV303YFPP0gEHH0=UR703MHQ`0gEh40=e2003=<Q@0^BHh0:TVB02i:QP0[B7/0;dEk
02Y3R`0`@HD0<3RD02TiTP0201deS`0W01l`P00M97T04ab;01<RX@0N;Z40936=01HQN`0Q9Gd09Cb1
03A>O01>J780MX5D08R3B@28Re80OXmI07F=FP1]Oe`0IgAQ05iUJ01IG6h0EEEc05=?M@1@CWL0Be1k
04iEM01=EG40B4ia04A:N010B7`0?TUn03]<O@0hCh40=e>803EDR`0fDHX0=Dn:031@S@0_E8l0;eN?
0080<5R>02L0<UN:03AGQ@0hE7l0>e9j03U?O`0hD8T0<e2>02m@T00YDY00;U>?03=DS00fDXd0;Tn?
02]>TP0XCID09DZE02E?U00YDi80:ENA02IFTP0SEYH08UFE02E@U@0WBYH09dbF0257W00QB9`084NK
02A@V00_IH`0=WN003f0N`19QW00EX]Y05b<J01FS6`0CXY`04N7M012PGP00P17OGT09`17Kg`0AW1l
041UP`0mI8D0?62603QHRP0fCXd0<4JB03EFSP0eGhT0;DZA02LbW@0V<Ih0:d:G035AT00cH8/0<ff6
03MnP016R7@0DHe]05N>JP1ET6T0Bh]a045lOP0hL8<0>GF003IcP00cMX80<Ff602]RS@0RCiT07DJP
01`gYP0L?Ih08F2802a_N@0_FWX0;df@041WO00204IbK`0Q04AkM011QgX0DI5c05VIJ`1LWfT0Fj9X
062RJ01XXV<0L:9P08jRCP2FXTL0UJ1509ZLA02CX4P0PY]606Z@A@1ESdX0D9I>05>GC01HUdd0CiaG
03bNI`0gWFh0@IEV05F8BP1CJBd0@4LL02hY3P0J4@D030H100D2000300000P0000800`4000<00P00
004000010000100100000`0000000@000000000?000000`0oooo000:0?ooobP000000`0100050000
00<00@0000L00P4000P20@060P000`80008100060@00100000801P4000<01@0000<0000300000P05
0@001P070@001P4000L100070@00104000<000<00@0001`00P000040000100000P00008100040@00
1@8000@100060@008adY01PGJP031ih00@>Z0040]`0::8<02S1I01DV>00H6dD02aeK00`TJ00X:5P0
6Qm`00TXLP0F;W`0<C=T01XWNP0@9I808bBH0P0U=9009`0:;IH04af;01dOT@0@8Y`04R><01l_N`0E
<hT05SV=02`nNP0R>8807C^;02U6SP0XCg`0:3Z800<5^0000[T0002i0047[`096ZL041ZU02HHR`0D
7I4012VF01lGO@0Q3gH021Yc014KP00P5WD03Qb500PMU@0K5i0041FG00/DSP0P3Hh04@i[00XOTP0N
4Xl05QAd014QSP0202XVO`0W024[O00C9Y`0:Rj=01hfS@0K:8T0;c5o02@oQP0[=W`0?Ca^03QHL`0j
HFl0CDIJ05Tc:P0m6PL0<18402dA0`0X40@0:A8402H@1@0Z4`L0:A8502lB1@0]4@@0;a4202l?0`0f
4@<0?QL4044L1P1:7@P0FRT<081E:@20P4/0Kh1S065YL01@F7l0Hdm`06U=I01LC6h0DdMe0080Gd1`
02L0JD]K06ALF@1WG5H0IUYQ05iJI01CFFd0BEIb04=DN011Cg/0?Dan03]9P@0oB7`0@T]k04I=N@1;
D7@0CU=f04U?M`15Bg`0AU1k04=BO`10Egl0?5Z303YHP00nEh<0?5N403iIPP0kF8@0?UN303UAR@0h
ChX0=4b<02e:T@0]BY00:TNC02i7R@0Z?Y80;SN202L[VP0P<Xh00P0I<9/09`0J9iH05BNJ01DaZ00G
<:T05bfT01`^U00C8I<07R>=02<jQP0cBW`0?65l05]eJ@21MU00Tgi9092;C@2;Tdl0QY9@08J?CP2:
Pd/0QWiA081kE@1fNEX0I7US05QhJ@1BNFL0Bg9S03aTJ@0aFGH0;5En02UGO`0XF840:UZ602YNR`0Z
G8h0:UR?02QDT00UEi<09E^C02ILTP0202MJTP0W02YHS@0^EX@0<dmj03I<N`0fBX<0<d^?02m<T00Y
CYD09e6A02mES`0bEX`0<UB=02iAS`0XCi@09TjF02A=U`0UDID0:U2C02]AT`0XDY<09END02AIT`0Y
FXl0;5VA02aCT00XD9D09U>G02EEU@0YH900=6j903]iOP15PW<0EHaX06>DH@1/UU`0KIMN06BIHP1J
UFL0E9=/0080FHa/02L0EH1]05F0K`1AMGL0DWQe04iiN017LG`0?F:203MIRP0fH8T0>628031GSP0/
CI80<5J?03aRQ`10JX00@fen04=_O`12O7H0B8Qa056:K01GRVP0FhaV05F:K01@Qg00C89e04F0N@10
Nh00>Wb303AfR@0`Khd09ebE029@VP0M@:<07dRF02M]PP0aNg@0>6Qf039ORP0lJXP00P0nKhL08@12
P7d0B91f05JIK01PW6H0GIiW05fSI`1VY6<0J:=S06jRI@23Y5H0TJ9<09JMA02HV440V9m308^RB`1b
Ud/0EXi@04jCDP1?UU00DIM@04fIEP10WF@0=iia03:DM`13U6@0CHA904EW=P0m@1l08aT:00h70P03
0P000@000080000200<000H01000100300000`01000000000000000<000000`0oooo000:0?ooobP0
00000`010005000000<00@0000L00P4000P20@060P000`80008100060@00100000801P4000<01@00
00<0000300000P050@001P070@001P4000L100070@00104000<000<00@0001`00P00004000010000
0P00008100040@001@8000@100060@008adY01PGJP031ih00@>Z0040]`0::8<02S1I01DV>00H6dD0
2aeK00`TJ00X:5P06Qm`00TXLP0F;W`0<C=T01XWNP0@9I808bBH0P0U=9009`0:;IH04af;01dOT@0@
8Y`04R><01l_N`0E<hT05SV=02`nNP0R>8807C^;02U6SP0XCg`0:3Z800<5^0000[T0002i0047[`09
6ZL041ZU02HHR`0D7I4012VF01lGO@0Q3gH021Yc014KP00P5WD03Qb500PMU@0K5i0041FG00/DSP0P
3Hh04@i[00XOTP0N4Xl05QAd014QSP0202XVO`0W024[O00C9Y`0:Rj=01hfS@0K:8T0;c5o02@oQP0[
=W`0?Ca^03QHL`0jHFl0CDIJ05Tc:P0m6PL0<18402dA0`0X40@0:A8402H@1@0Z4`L0:A8502lB1@0]
4@@0;a4202l?0`0f4@<0?QL4044L1P1:7@P0FRT<081E:@20P4/0Kh1S065YL01@F7l0Hdm`06U=I01L
C6h0DdMe0080Gd1`02L0JD]K06ALF@1WG5H0IUYQ05iJI01CFFd0BEIb04=DN011Cg/0?Dan03]9P@0o
B7`0@T]k04I=N@1;D7@0CU=f04U?M`15Bg`0AU1k04=BO`10Egl0?5Z303YHP00nEh<0?5N403iIPP0k
F8@0?UN303UAR@0hChX0=4b<02e:T@0]BY00:TNC02i7R@0Z?Y80;SN202L[VP0P<Xh00P0I<9/09`0J
9iH05BNJ01DaZ00G<:T05bfT01`^U00C8I<07R>=02<jQP0cBW`0?65l05]eJ@21MU00Tgi9092;C@2;
Tdl0QY9@08J?CP2:Pd/0QWiA081kE@1fNEX0I7US05QhJ@1BNFL0Bg9S03aTJ@0aFGH0;5En02UGO`0X
F840:UZ602YNR`0ZG8h0:UR?02QDT00UEi<09E^C02ILTP0202MJTP0W02YHS@0^EX@0<dmj03I<N`0f
BX<0<d^?02m<T00YCYD09e6A02mES`0bEX`0<UB=02iAS`0XCi@09TjF02A=U`0UDID0:U2C02]AT`0X
DY<09END02AIT`0YFXl0;5VA02aCT00XD9D09U>G02EEU@0YH900=6j903]iOP15PW<0EHaX06>DH@1/
UU`0KIMN06BIHP1JUFL0E9=/0080FHa/02L0EH1]05F0K`1AMGL0DWQe04iiN017LG`0?F:203MIRP0f
H8T0>628031GSP0/CI80<5J?03aRQ`10JX00@fen04=_O`12O7H0B8Qa056:K01GRVP0FhaV05F:K01@
Qg00C89e04F0N@10Nh00>Wb303AfR@0`Khd09ebE029@VP0M@:<07dRF02M]PP0aNg@0>6Qf039ORP0l
JXP00P0nKhL08@12P7d0B91f05JIK01PW6H0GIiW05fSI`1VY6<0J:=S06jRI@23Y5H0TJ9<09JMA02H
V440V9m308^RB`1bUd/0EXi@04jCDP1?UU00DIM@04fIEP10WF@0=iia03:DM`13U6@0CHA904EW=P0m
@1l08aT:00h70P030P000@000080000200<000H01000100300000`01000000000000000<000000`0
oooo000:0?ooobL0000000H00@00008100020@000@400080000100050000000400800004000020@1
00H300801@4000D01`4000L200090`00208000L0000200L2000800T3000:0`002P<000L200070@00
1P8100<100030005008000800`0001P00P4000@100040P00104000P50@0P51/061ME00D?O0062Vl0
2@AW01XSIP0:;6007bY601`JG0085V@03A]^02dVD`0L96001RIZ01P_O@0e=F<06bMa01DYS00V8i@2
02/bS@0W00/YX`0C6Id05Q:K00`MW00E:8009S1_01<YM`0F<hL0;T5b024fN`0L?H`06d^?02A;N`0U
=hP00`Fh0002^@000KX091BB00TDZ`0?5:L09Q:>01HGU0099IP07QIi020@L0087GT04Ab101lCP`0>
5h@0222R020JR@0C5Xd02Q>:01l=Q00C3fX02Q^G020@SP0F56T03b6@0080:22502L07Ami010QWP0Y
:hh07BnD024TS`0_:H007C>802/`M00h<VH0;dMg041?LP1BC500EDI005m1=`1D:aL0?aP7034@100[
4@D0;a@503DE1`0f5`P0=AH703<E1@0h5`D0>Q0403hG1@0o5`@0@aT604XK201C7`T0L3LB08=g@P1f
P5X0IfQ/05mFL`1ZF6P0JeQR05M:M@1=@gh00P1G=X009`1N>g00IceU07m?BP23J4P0MFYC05YTH@17
GVd0@UMg03e?P00iBh40=TJ403i8OP15AgX0AT]h04I=N@17C7P0ATUi049:O013D7/0A5Ak045GP00l
Eh00?UR1045KO`11G800@EZ003eKPP11FX00?eJ203eDQ@0gDXX0<e6703IBP@0dCh00=DUj030mP00_
>HH09SVH02XlP00202/gH`0W028/L00L;i@07CRJ01/eX00G<Z005c:E01@XU`0N9iP09SN:0312Q@0_
DhP0?fIm06Q_I01iLUP0PH1F08F?D@23VE80QYaB08NDDP2<U540SIE@08VCC`1iTEL0IHmN05:8JP0o
P7D0;76202APS00TEY008eB@02AAT@0VCY<0:4jB02I=T`0SBiD08DZG025>UP0QDi@09E>E00809e2C
02L0:52C02]>TP0ZAiD09d:H02HlV@0X?iT09T:L0293V00RAYT09dNF02I2V00T@9/0846M01i2W00M
A9d074>M01]6W`0P@ih07T:O01]8WP0LD9X07U2H025?V@0PBiX07T^K025<V00PDIP08ENF02ATT@0Z
Kh`0<7Z303b6NP1AUFT0HYeP06nNF01eX5L0LZ9G06fPG01TWV800P1SUF<09`1LRVT0FhI/059nL`1G
P6l0E85a04YlM`0oJX80>5n803APRP0gH8T0=FB903IVR00lL8<0A7F004QgN@17M7/0AG5l04IfN@16
NGP0B81d05B3K`1KQf/0GX]W05bBJP1GTVd0C8ic04J2N00oOWh0>7N403QfQP0dKX/0;V>?02AAV00V
EXl0;FYn03EhM@0mNGL0A81m04b;M@0205:AL`0V04jGL@1?W6h0EYiY05^LJ@1LWfL0Gj=W06ZTH@1^
X680J9eV07>QH01oXEP0Rie@09>LC02@X4`0RjM<07ZQDP1NSe80Ci1E04bDEP1<UeL0BIQK04>NH`0f
WW@09hb402jDNP0iTVH0?7eA03eF<@0Y8Q0040H20081000000000P0000<0000400001@8000@10003
0@04008000<00@0000<00P000000000000003000000<0?ooo`002P3ooolW00000003004000010@00
0P4000800P0000<00@000000000000000`0000002`0100001P8100H300050`001@0000D100080P40
30<000T400090P002`8000802P<000P02`@100`5000<0`002`8000X2000;1040208000D100801P40
01d01040008000030@001@0000@000050P001`<000L20@050@0020<001`<4P0F5D@01QAF014B>@0D
3SL072=H00`VH`0L96007AEM00XHM00>6Gl0:BIE01d]D@098Vd05RZ=02XhJP0O=FH083Ma02l[GP02
028ZKP0W018/SP0L8YP07QNE010PV@0M:X00;S=]01LVJ`0H<H@0;d5e024cNP0S>h805d2B0215NP0S
=HT00`Fh0002^@000KX090f@00P?[`0=3j`090b@01HBUP0:7id07A>301lAN`0888P041eo01l@P`0=
5WL02R6B020IL@0A6gP01An001`FL`0J5gD02ANH020AO@0F5g803R:E0080:22801@07Ame00hPW`0W
:HT07BZ=024QW00_98P06RZ=02X[S00h;7P08S>703LiQ01CCVD0@5EK049DKP1K?c/0CB8=03PB0`0b
4PD0;Q<503DD1@80?1P70140?1L6048J1P126PL0B1/704PI1@1260D0AaP604dJ101W;0X0PVm007n0
D01_KVH0IeiX07=WHP1ZGf@0FeAW05]<M00205Q1N00W05HfM@1B<G`0GSEb06m;GP1oIT`0JF=I04mI
K01:Eg80A5=j049>N`12Ag`0@TUl0498O016B7X0B4]i04Q=N`19C7T0AT]m04Q@NP17DG/0A4im04A?
P012DGl0?e>203i?Q@0lCh<0>4j903Y=QP0jC8P0>527031BR`0bDX@0<E2103E:P`0e@W`0;SR@02Tl
TP0N>I`08cf200808cYe02L07c1h01``T@0L=h@06S6B01HcWP0B=9<06S:D02<`V@0Y<hl0<Sf802i7
S00mG7L0DF]^079_FP1bK5T0LXQL07ZFE`1oVEH0Q9YA08RDDP29TU<0RY1B08:>E@1nS5@0Lh1G06Z0
G@1GM6P0C6Ab04YGM@19DGD0C4ed04e;L01=C780BDec04M<M`12CGd0?UB003mGP00nFh400P0lGX40
9`0iH8@0?5f303]IQP0jE8L0?5:803Y?Q`0eChX0;E2=02Y@T@0[DI80;52@02]?T@0/DI40;E:?02eB
TP0/DY40:e6B02]@U00YD9D0:5>D02QET`0WDiD0:4jD02Q=U@0[Ci80;56A02YDT@0ZF940:fB<02a`
RP0eOh80@8Ye05:GI`1WVe`0MIeD07^QDP1lXU80Nj5D07>NFP0206fGGP0W06Z?H@1TSFD0HXAY066:
IP1MQ6X0DH1c04E_OP0oIX@0>FB603UVQ@0lLX40@WUl04=lN015NWT0A7Ql045aO`0mJX40>f>303]J
QP11IX00CW1i05ImLP1LSV/0GYUV05NEJ`1;RGD0AH9k03mgP00nLX<0@WV0045lP00iLXD0;En@02UL
TP0^GXh0=7650468O01BUFX0HYaV0080IJET0200G:AV05NRJP1FWF/0EiU]05fNI`1RXf<0LZ=J07FT
G01bX600MIeR07>JH`1lWE/0P9aG08:JF@29YE00PjI>06^IDP1FSe@0B8aO04>>IP11TfX0>iQ`03>F
O00ZRXL0;i:003FFLP0hQF80?V8o02/V500B1P800`00004000800P000P0300000`0500000`0000D0
000200@000800`000P0200000`0300000@000000000<000000`0oooo000:0?ooobL000000`010000
100200000@000080000100040000000;00<100040@001@8000@000030@00104000T30@0:0P002`<0
00d4000=10400P0>1@801@0A1P8040H100l5000>10003P@100803PH102002P8100L20@070@001P40
00D100060@001`0000P100080`002P<000T30@0:0`402P8001/83@0D5C8021Di01dH9P0N87P0629b
00lQI@0M8gX06PnC00/FW@0>69809BQK01XaB@0977D052FN01XgO00@=G<07S6203/`E08082AM02L0
4bN402@YT`0T8Xl04RFK01dYS`0^<7<06RIj01P]Q00_?f`0;cIO02DfO00B=9<05C=e01PWK@0727T0
0PIh01PEP@0T6W8031^B00`HVP0R47/05aJ700XMV`0J4i807AF=00PSUP0A7H007a6300hGK00=8XX0
8aIk018FN00389L08Aj7024MR@084j808Q:401HGQ`0?8IP00P0/7hH09`0M7Vh03anM02XVP00Q:800
7QnO02/QS00J9ID09RV8034`LP0R>800=SQ]0412FP0dDFL0>U1]055;B`1P>b/0G2TB04@J2@0c4@D0
>Q8303hF100o5`D0@A/704DL201780P0BB0804HO1`186@D0AQP5050O1@1V9`X0PelY08IoCP1aMF80
KVaS06e[K01RHF`0CTb004]6P00204XkNP0W04/lM`1:?H@0DCmm05/nI`1gCEL0P5A807EMD@1PIel0
D6]Z04iQL01;Eg<0B5Ie04ADM`17EWP0BUMg04eGM`1=EW@0CUUd051FM01=DWL0BeEf04]HM@1:GGL0
AeUj04=HO`17FGl0AU]m04=IP013EX00@5N103YDQ00hDH00>4mm03U7P00iAWh0>4J;0395R`0V>iT0
9cn000809cY^02L09CE]01`fP@0N=g<06Bj?01LbU`0G<IH08cFK02TcV@0Z;IX0;c>@02TkUP0aBXL0
?UUm05mdJP1_HEd0IFUV06n1G@21TED0Q9UD08JFE@24UEH0Q9=B08:?F024Qe<0Qh1A08V0C021NU80
N7YF06abG01UKEd0GVQN05UQG01@Fed0AUMV049DKP0oE7@0?EIf03iJN@0oHG`00P0lIg`09`0kK7d0
>VR003YUPP0hH8@0>5j503IKQ`0_FH`09eN@02=HU00TEi<09UFD02QET`0[EI80;5R@02eGT@0]F940
;ER@02YHT@0YFY00:Ub?02]JS`0XE900:E6E02YET@0^FHh0<5V:02mGS@0_FHd0<VR803MePP10QWP0
BXe]05^EH@1[UUT0MYQB07bID021Vdl0PYe>07nOD`0207nME00W07fJDP1mUU80OIED07ZFE01dTeT0
IXmQ05Z8JP1BQ700CX9c04b2M01@Pg<0D8A^04n8K`1@R6l0CXUc04b3M`19NGX0@Vin03aUPP12LGd0
Bgef05J;JP1SUf40K9iL06NIH01PTfH0FHiZ05J<K@1ARG40ChMd04J0N00nN840<6V;02]UT00/HI80
<W>9042;NP1LVVP0IiiP0080KZAM02<0JZEN06FVH01PX6@0H9YW06NOHP1_Xe`0OJAD07jXE@1dXel0
LY]U06Z<K01YUFD0Ji=Y06n7IP22XUL0OjeB06jVE`1GTEX0@H1Z03R1L`0dRWX0;iEm02fAP@0[QXL0
;h^303:@N`0gQFh0@V]503<]5@0G1`4010000080000100000P000040000200<0000400H100040@00
100000@000@00@000P0200000`01000000000000000:000000`0oooo000:0?ooobD0000000<00@00
0080000200000P010000100000000@000040000100040000000;00<100040P001P8000H200040@00
208000T2000910002`D000d7000@20800P0C2@<09`0A20405@T101<8000D2@004PL101H90P0C2080
40@100/20@0:0@0020<000T200080`002@@000T3000;0P002`D000/50@0=1`803`H201X;200F6240
2alb00d?AP0@4UL03amV01XYD@0U9eh05AJ6018PS@0J8I409RI[01X]D`0E7e4061aM018[H`0=<Vh0
7biY03@bFP0201hYH@0W01X`L@0V;X808bZ;01@]VP0N:i/0;2nA01/WU@0I;8L0;CaR03<iDP0Y<800
2anV00XLTP0<58401PR0000JSP0C7Gd09BQT014[MP0<9XP091eQ01hTIP0:8XH061R3024LP`0>9i40
41ii024KL@0D7WD031f9020DP@0C4g<021nI02<QR@0R8X@021ZV01dDV@0E5iP041nI0080:Qn102L0
7ae^014RW@0]9X407bAi01`MW@0Y7hX05B6I02<YT`0W=84063BB03@cOP0f>V<09TAn03Q2N@0oCF<0
BE=H05m8@01H;1D0?1<303dA0P0o60@0@1X504<K1P177PT0Aad804`M1`1;6PD0BQd5050J0`1E80H0
I2T<07e:7027P4l0KX1V06a_I01XJ6T0HE=R05Y;G01B?V800P1B=GL09`1D>6`0ECYY0516N`1@B7/0
Fd=^06i6H01jDU00Mfa=05N0H018Lf`0>eYj03UAO`0iCX00?Dim03i?O00oCh40@E1m04MAN@14CW/0
ATYk04I=N`16Dgh0@eIk041EO`0mE8@0@eYo041KP00mEH@0?52603a@P`0fCHT0=Tj703I=P`0bBHD0
=DJ803A3R`0`@8d09CfJ02a0P@0202TiM@0W02DlM@0N>H007CIm01P_TP0J<I007BbF02H/RP0Y:hh0
9RRI02T[TP0W<iP0;4::03iIP01=Lg80HfIR069JH`1PLVT0MXQJ07JIFP1hVUX0Pi]G08FEE024SeD0
RHYA08Z6D`2?P4l0S81C09B9A`29RDd0MY1C05V;H012P6h0;G=j02AYQP0OGHh08E6C02=7U00XBi40
;4n@0080;EF<02L0;eV:02aDS@0YDi009dnD02=;UP0TBYH084VH01e;V@0KBi/06DZN01a7W00NAY`0
84:L0254V`0RAiP08dVH029<U`0QCIH08E6F02AETP0SDIH08TfG029=V00VE9<0:E^@02AFTP0RDI<0
95>C02UTS00`M8H0?8Eo04FAL`1>U6X0FIET06:FGP1^VEL0NImB07fQD01jXU<00P1kXUD09`22WU00
QYe;08FLCP24Vdd0O9aC07FME`1WW5l0HIQS05b?J01HS6P0FHmY05N9I`1CRVd0DHY]0529L01?R7D0
BX1g049`P00nJ840?W9n04N2L`1GSVP0Ii]M076PE`1^WUX0J9]N06JNHP1RWF@0HIQU05V@JP19PWP0
@7em039fR@0/Khh0:fFD031fS@10RW`0EIY/06JMH@0206nQG00Q07:VFP1bZEP0L:EK06fPG@1dXeT0
NjID08JTD027YTd0QjIB07ZNF`1aUfD0K9UU06nFI01dRf<0PiMG07fQFP1bXe/0IIYI04V<IP0kR7H0
<HF102f<P`0YS8H0:8B:02^;Q@0_Sh00=hIb04Y^A`0l<QL070T200P0000300000@0000<00P0000<0
0`0000@000020@000`010003000000030040000000000@0000`00000303oool000X0oooo8`000002
0040000400<1000300000P00008000<00@000P0200003`0100000000000000040P401P<100P40@07
0`401`<000L200070`002@<000X4000>1P403`L201D;100201D:100=01D:0`0E2`<04`X201050@0@
1@004@@10104000>0`002P4000`200090`0020<000/4000200`4000H00d50@0?1@403@L101070P0@
2@8070d701LH4P0A9b`04R5E00<6PP055V<05BIH02/VE00@5g`042:;01hOU00V8h803REf01HMAP0Q
5R/03Qm@00l/K@0R<Eh08c5H0P0I<Ed09`0O=fP09SEb01/]QP0I=I808S2E02TdS`0K<94073:>02ll
IP0g?5/0:bb700D>/`032;H00@:k004:Y0016ZX03afV024/S`0D;Y003BbM02T]N00]=5l02B9m01HK
T00[8XD04RZ>00`OT00U9H407BF600`HS00O48@05Q5Y00XMU00S8XX07bEh00PRX@0K4iX051FI010M
V@0202TKNP0W01dNN@0@8i`0:bR401hTO@0K6Y009b24018SWP0N9YX09c>701P_U`0^<HD0;CY`01do
Q`0k?7H0=4Q^02iHM@1;EE/0GCd[04TM20174`@0@QH4040D100o5PH0A1T8048H201360H0Ca`7058L
1`1<7@@0CA/3060U201hAAP0QGM?06egH`1_Jf<0J5i]065>F`1JC5l0DCQG0080DCEc02L0DSam04lk
LP1;>800Cd1o05M8NP1NAfT0I4EW075CE@1_K500JFYD05mPI@1BG6T0AUYa045HM@12FGH0@eMl04UH
N01=F7L0C5Ag04YBNP1;DgP0AUEh04EJO012Eg`0?UJ003mIP00mF800?EF403iCQ`0mDhH0?5>203YE
P`0gE8T0<Tn<03E<SP0c@i<0;TFB02]3T`0bAXL00P0Z@9X09`0W@iH08CbM01lhSP0K=I/07c6O01h]
W`0R9H@08bF<020UV00S9IH09BbG02i2Q`0eDXT0?FYo05I/J@1TH680HfQV06imG@1dTUl0OiMH086G
E@1oV5L0P99G08J@DP29QU@0RX1C08R0D`2BQd/0RhIA08NACP1dREH0H81R051dK01<JW<0BV5f04UH
M@1:DW80Ae=e04QENP0204QGN@0W04MIN@13FWh0@5Uo03iGP`0kEX<0>EN303MGQ00eEhH0<UN8039F
R@0`EH/0<5:=03A@R`0cChT0=dn:03Y@Q`0hDhH0>5J603IIR00dG8T0<Ef:02iLS00^Gh`0<6>9035W
R@0_IHT0<f>703IVR00fL8<0?GQn0464N@17SFh0C9=Y05BDI@1OV5h0KYMI07FJD`1mW540OYi@0080
P:5>02L0RIi;08^MBP28WTd0QYe=08BOC`1mWe80N9eB07JJF01aU5T0KI5M06JAH01TRel0GHUT05V8
J`1FRVh0DXU^04Z0M014Kg`0@VQl04AYO01<OG@0Eh]Y06JHG01^VeL0K9eI06NPG@1SXV<0IJ9Q06ZN
GP1VV6<0F8a]04j8M`10QH00<WZ702e/S`0`N8/0?8b004ZLM01HXVX00P1VXf007`1dXEX0NZME07NV
E@1dXeL0O:QD086UC`29ZDh0RZU;08jXB@22ZED0L:1P072MHP1]UFH0LI1U07^?G`1`RVH0KhmV06bS
F@1@VFD0>Xmi035oQ@0]QHD09HF:0261S`0WTHT0;YJ0042=K01JKSh0@S0C01h>0P090@000P040000
1P030000104000@100030@001@4000@000800`001@00000200400003008000010000000000T00000
303oool000X0oooo8P000000200100000P40008100050P001040008200030@000P400P0200030081
0009004000030P401@<100P40@0:1@802`D200T3000<1P802P@000802@D000<030H100l70`0F3@D0
0P0G3@H09`0E2`@04`X501@:0`0A20803@H200/4000;0P002@8000T3000:0`0030@000d5000=1000
40<101070P0?1`404@L100l70@0C20804`/401T@1P0H4`/061lO01TQE`021i`01A5A018I>P0V7d/0
6Ae/01DKN@0I5h/07Qn;018SR@0K7UL0:aL`00hNH00@9gX09SA_01L]O`02018`HP0W01dbN00W>gP0
4cB801DlTP0T=9<09CV?01@dT00L<iP0;Cin03@lL`0Z=8/02B2Z00@D/@011KT011BO00DQZ00@7ZD0
8RVA01P[T@0A<IX0;3Ak03<iGP0=9GH06AnB02/ROP0B9hH02B2M02TUQ@0T:800322301hBNP0F4Vl0
31^G024OT00N87D02RJG01PCU`0D59T041^O00809QN<02L071Z<00lPX@0X9XX072B:01XIV`0X9HX0
4BVR01dVW@0W<XP05bVJ02//R`0U=W`06cBD03PkM@0`A6X0:TUn04=AJ01HFTL0G4@Y058T3`1050@0
A183040C0`124`@0A18403TC1P1550D0CAH404/J0`1A60@0HBD:07Q35`22Md`0L7MS07=^H@1WGF/0
I4aO05A3I01;=FD00P1;<W809`1@=840CcQh04`hP`1<@7<0E4Yl05a=K@1SAe/0ID5N07U9B@24ET80
Qfa7079aD`1BKF<0@6Q/041RL`12GGX0Ae]h04aKM@1;FGD0BEMf04UFN017EgL0AUV0045DP00nDH<0
>e:503UBQP0nEHD0@EN4041KPP10G880>eZ403YER00hE8/0=eJ803MGRP0gE8H0<e6303ICP00202mA
S`0W031@P`0XAHP09Sn502HlT@0V>i408cJ<02@`P`0R;X@07bb>01d[W@0O=9L0:T6302e:PP0cFhL0
CVUd061/IP1NHFL0IGAT06Z8H021U5D0QIUC07VIFP1lU5P0OYAE08>:E@2:QU@0R81E08^6D@27PE<0
S8e?08F8D01mPdd0Mh1@075hE`1XLeh0HFaK05MSFP1>H600CF=W0080BFA_02L0A65b041QNP10GGh0
?eZ003mLN`0lGg/0>F9l03MSO`0bHGl0<F2002mNR@0/FX`0:UV<02mGS00bEHX0=UJ703IIR00hG8D0
=Uf703IQR@0aIXT0<6V8035^Q`0dKHL0<fn503=^QP0gKX<0>G2303UaPP0lM7l0?h1l04:9M@18Rg00
ChmY05VCI@1SUf00K9YJ07NJE021W5000P23WDd09`27VTX0RYU:08^JBP2=VTP0S9e:08bIA`2<UdP0
SIM:08fHB@25VTh0NiQC07RDE01aTUX0Ii9M06RBH01NSVD0E8M]04ebMP1>JWL0BV=g04mdL`1JQVP0
HY9N06NJG@1XWE/0JZ9J06jTF@1aY5X0MZ=G07VMEP1`Ueh0HiAX05JDL`18S7T0?86103Z5P`0oSH00
AYUg056PKP0205jOI@0P06bRG`1eY5T0MJ=G07RREP23Y4l0RJ==08^YC02>ZTT0S:I708NVD01eY5X0
L9iP06jEI@1/TVP0MIAS07JCHP1kVe`0LjUF05BRIP0kUWP0<7n502n2Q`0VP8d07h2B01nERP0/Vh40
AY5Y06A[=@13;0h06`/100P00003000200@0000500<100040@000`4000<1000300000P0200020040
00<000001001000:000000`0oooo000:0?ooob80000000H00@00008100050P001@8000@200030P02
00@1000300<0000200000P0000800P4000h00`00008100050P401P8100P30@0910403@D100d60P0=
1@403PH200l60@0=1@0040P4018:10805@/502L05@/401@:100C2@804`P201070@0?1`403@<000`4
000;0`003@@000d5000>1@003@<001040@0?1P404@P201890`0D20<050T301@<0`0H3PD04A</01/E
6P0Q6T001@n=00XB?@0E41X081m001LWKP0K87D05aJ701@NSP0G:X`08BMd02LRC`0C8fT04BF502L`
J`0J=6`00P0B;fP09`0M;hD08c]f01<kMP0L@Gl0;cib02@fO`0J=hX093NC0351R00b@Gd0;Sf:00la
X`057jh00PZW00LRY@089ZH03afT02@UT`0I9i<0432G02XdM`0f>E`052Q^01PTRP0W7WT04Amj00TR
U`0Y7WD092A_00lZO00K77<061]j00hMSP0P77/07Qa`010VO`0N67<06QR0010IVP0202LLP`0W028R
SP0B7j80:RB<01hQSP0E6:H09BN<018[R`0L7hT09BN401DUW`0U:I<07c6801@XXP0f>8@09d=f02Dm
S@0fBGl0?FaX04i_CP1F>R80AQP703T?100h3P40>Pl103d?0P0e3P<0?1H404HL1@1@7PL0EAl7064V
2P1f?aH0OGI>06efI@1dK600J65/06A<H@1F@F@0FSQN0080GSQU02L0GC]Y05TlH01G=700DCeZ0590
L`1CA7D0GdQ]05e8H01QA5X0IdMQ07iXD@25N4L0IG5K04Y[KP16Hg40@Uei04IIM`17EWT0BUIh04aE
M`1<E7H0B55h04E@N@15CX00?4b603a9Q`0jBHH0?Tf5041@Q@0oDX@0?52703]=Q`0kC8P0>E6;03QG
Q`0fEhT0=5>>035=T00aDX`00P0]C8d09`0ZC7H083VM024hX@0N=:<07SF@01d[VP0O=Yl07CFN01Tb
X00E<ZH08T2E02A2R`0V?Xh0:dFC04MPN@1ELF/0H6EP05i`HP1ZQ5h0NX]F07nCEP1kUEP0NiMH07RG
G020T5X0Rh]C08^0E02:P540Ph1L08Z:E@26RE@0RXE:08R1@`25P400LX1805IhH`0oIWT0<f5n03=T
PP0202mOQ`0W02YGS`0YDI00:TRB02m4T@0]Ai00;dj?02eAP@0[E840:U>402QCOP0TDHd08DfE025;
V00PB9P08dVF02I<T`0XCi00:Tn@02]?T@0YEY40:V6<02aXR@0/JhT0;6Z802mYR00]IhX0;fN902iT
RP0[HH`0;fF903=`R00dNh<0>7mm03j4NP11RWH0BI9^05BJIP1[Ve/0Lj1D0080LZ5D02L0MiiA07bL
C@26WT/0S:5808jQA`2@WdH0Sii809BMA`2AWdP0RJ9:07fWD`1mYE<0MJ9F06nKGP1XVUh0HI9Q05J8
K01<KgX0AVAl04AJP019IgX0DX1c05N=JP1MUVD0HiaR06NQGP1^YE/0MJYH07VWE`1nYe@0OJ9D076O
G@1SWFP0E9Ea04J@M`12SgT0AHml04JHN01@W7400P1KWf/08P1YXV@0LZEL07VSF021XE<0S:9:08fR
B@2<Z4X0Rja:08VWB@26XDT0OJ=D07JQG01bVf<0KY9W072GHP1lVe/0QYmA07Z[E01LZFD0@Yee03F9
P@0cR8D0:XF<02><S00SVhP0<Imo04fGIP1WLCD0BS8?024?0@080@000P0000<00001000300800005
0040000000000P000080000100000`020000100400000P0000400001000;000000`0oooo000:0?oo
ob80000000<00@0000<000050P000P050P001@040P00104000<1000300000P0000800@0000l00P00
00<000030000108000D200060@002@D100`5000;1`403PL2014:0P0@20804PT200l80P0A2@@00P0D
2`@09`0G2`@050T301H:0P0E2@805@X301D80P0C1P8040@000d4000<1P003`@200d40@0<0`002P<1
01470P0C2@<05@/401@:100B2@<04`/301LD9P0@7dX06ADS028E;`075Vl0310]01H9400H7ST03Rm`
01/ZOP0H78l04B>D014`UP0S:hL09Bf4010SSP0B8Y@0:2]Y01XeGP0200dSM`0W01XVU00K=Wd02c=i
01/`S@0`?GL07S]f01L`S@0Z=i40<4>802i1PP0/?H/03c2R00<AS0043k0042RG010]T@0C:9<09BIo
01TRS@0@:hl09Bm]03LfG@0E9gX05RJ5028JO00@77<032>G02PGR@0O5H002bBE01/RUP0O9I003Af:
01dIQ00M5Fd03bF702<OQ`0U7H003aBQ0080;B2602L0:R^<01@IY00/88h07Qn@01<IYP0T9XT04RYj
01LHS00L5hX03b>S028VT`0L;hT04BFV02ldR00Q?X<08SVD03=6P00]FWX0AF9^05mC@@1N<QP0BQ/9
03D@100f4080>@d103H>0P105080CQl705DT201H9`/0HBP;07@i5020MTd0L81Q07MdG@1QJVh0FU=[
04]5MP1>=GT00P1C;Gl09`1B;H00CcMh05HiMP1C=6/0CCEo04LnN@1@@Gh0Bd1k0618F01QAFh0M5]F
08QW@P29HT00M6AB05i/HP1:LG00BV]c04]UM@1@I780EFE]059OK`1>FG@0BUEi04QFN`16FWX0AEQj
04=IOP16FGT0AUUk04IJO@10E800?e:2041?Q00nE8@0>5^603IIR00dEH/0=56=03EFPP0203=AN`0W
03A=L`0[?i00:d:;02PlS@0[>8T08SJI028jW`0Q=J@06cBX02<hW`0U@Y<0:4:402/jR@0/>Y00@EIn
04M]N@1OKFH0FfeS05V1I`1bRU/0NIEF07fAE01lV5P0MYMM07RGFP25Ue<0SXI@0920D@23O5X0RHMD
08>5E@28PT/0PWM708Eh@01jNT00J7UH05MZJ01<Hf`0CV5^0080D5m`02L0Be]c04aJM`1?EgL0Ce5c
04YCM`19EWT0@e9c03a<L@0lB740?Ded03mAOP0nEGd0?EEo03eFPP0iF8@0=eZ603EJQ`0dFhH0<eb7
031RQ`0cJX@0=6j103Q_P@0hKX00=fj203Y^P@0mK800?6Z103iYPP10KX00?gUk045oO00oPG/0A8=e
04N9LP1?TFd0F99V066FH@1VV5`00P1YUeX09`1]V5P0MiQC08:KC02<WTP0SIm9096KB02?W4T0U9Q7
09:JA`2<XTX0PjA?08>QD@1oWE40OYI@07VEE01bTUT0IXaR05R0K@1AM7D0CFQi04aaMP1BP700FHeZ
05^FI@1TVV00JJ5L072VF@1gYeD0NZIE08:WD`21XeD0NIeJ06fHI@1PUF/0F9E]056BLP1<TGD0CiYc
052ML00205NQK00Q06ROI`1cXEl0NYiG08FND02?XTT0Sj5908^VC028Zd`0R:M908NQB@25Wdh0QJEE
07nOF@1aUF<0KiMS07NKG@20WUL0N:iI05n^I@17Y740=i:003B<QP0]Qh/09i:;02BKR@0fX7l0DY]V
06Ue>P1@?1D0;1P501H70@070P000`0000<00@0000<00P0000<0000200000P0000001`0100000P00
00<00003000010000080000100003000000<0?ooo`002P3ooolR00000004004000030@001@8000D3
00801P800P040P004`0300000P000040000100000`0000@000040P001@8000H200060@002P@100/5
0@0?1`<03`T3014;0`0C2@@05`d501<;0`0C2P<00P0F3@@201P=1@0U01T>1@0H3@H06Pd501X<1@0H
20@04PL10186000C1`404@D201440@0>0`003@<001460@0D20<05P/401D:100D2@<05@P301`D500M
92/071`_01HC?@075EL02@/m00d:;`0B83l052mF01XVI00F9X806Bn>024[R@0V:8H07bb>01XWR`0H
6X/08RMc01/cH`0201DTN@0W02LVK@0P<FD02R]a01/VL@0W<f@063Y^01T^O@0Z<h00:T6602E3RP0R
=i402QnV00@DPP095j0072al01L`NP0F=WT09bmV01/QN`0@98<072A`02T/H00B9gL04B=j024LK`0I
7gD052B>02@HT00K5W`02RJ901XTP`0P:7`03bMk01/ML00O6g004RB<028QQ`0S7XH04B6R0080;BN7
02L0;2j101<HXP0[7Hd07Qb@014JY`0U9hD04bUf01DBTP0C48d03R:M01dTTP0I;8P04B6Y02d`SP0L
=I407b^J02a1R00OA8`0=DF704]NIP1GFST0D30G044J1P0k4P80?0d103/<0P164080BQ`505PU2@1K
:`/0HRh<07E05025P440L81N07YcE`1VLVT0GU]R05m;GP1WCE`00P1WBEl09`1UA6h0HTMP05i3E@1L
AEd0FdEU05A0L@1F@G40DSIh05i1J@1MAG@0Kf9N07=fD`2KI3D0TElb06mgC015P6`0AWIb04=QO018
FWH0BUQf04]EN016Cg/0@din04E?OP12DGh0?eAn03UGP@0mEgl0?UMo03aEPP0iCH@0>4R803M7S@0h
CH/0=5F:039CS@0bDXh0<Dn>039BS@02035<Q@0W03E:N`0dAX80<4Mc02XlS`0Z?ID083bO01lgX`0K
<JX08cFT02HcW`0Y@900:T270350S00_?ID0@4R3041LQ01JK6l0HFMW05mYJ`1[Nf@0M8YK07j<D`1m
UeH0MiML076OGP1gWe`0PI1F0967D@2>OU<0RHEA0861DP26P4L0N75807Q]@01iJSL0NWA0079iC@1R
M5D0EfmK0080F6IJ02D0E65N059TH`1AIfP0Cf5_04MJM014F780?e=a03a:M00iAWL0>TMo03m=QP0m
E880?eV003aKO`0gFhH0<UZ7031MQ`0_HHP0;f>:031WR00aJhH0=Fn403IaP`0hLX80>WB103YdO`0k
LGh0>Fn003i`PP11NWT0@X9g04:4N@10Pg`0A8Eg04N9M01:RVh0CXM]0080E8I/0P1CQF/09`1IS6L0
I9AP07:IE`1oW4h0R9m:08fNBP2AVdL0TI9509>CA@2>VdX0RJ5;08VLC@29V4`0RYE;08JCCP1nUU80
LYMG06JBG`1RRfH0FX=/05V5J`1NRFT0GhiW06:HH@1YWeh0LJ9J07JVEP1jYe@0QJIA08^SD02=Y4d0
QIaA07^LG01^V6@0IIQX05jGJ@1FUfh0Die_05>PK`0205ZTJP0W06NTI@1eYE`0NimH08:JDP2=WD/0
SYi:08fNB02<XD/0R:1:08ZLAP29W4/0RJ5?08VPE@1gVV00LY]R072IH@1cVEl0NjUH06naGP1FZf/0
?iQk03NCP`0`SXX0:YB902bGR00hVX00DiIY06Qk@01ICAh0?bL<02DB1@0C20802P8000D100030000
0@00008000010@000P0000<00@000P02000010040@000`4000810001000<000000`0oooo000:0?oo
ob80000000`00P4000<100040@001P<000L3000710401P<100H200040@000`00004000030@0200D1
000700H100070P001`<100d60P0;1@803`H201480`02014:0`0401/C2@0K4@L060h501L<1@806Q06
02L06a8601dA1@0L40@07A0601dB1P0J3`D060X201@:000D2`804`X101<70@0C1@004PH001@7000E
20805PX301P;0`0G2P@050P201@90`0J40T07QlB02@X?P0?4X000PFI0082UP041GD021QA00lXI00F
7hD03b2D018XW@0V9Hl09bJ:01DYU`0E:Y@06aR?01/OR@0C;7T00P0E8h<09`0_9el09c1900`YK@0P
:5/082EK01@bK00N=6d0:39e01`lR00HB9<05C:L00@:T`066GP04BBG02LaQ@0F9g804CEl02HdOP0P
7G`01ab7018NU00V;8<04bj:00dSSP0V7h808RB300`QS@0K69T05aMg00/XPP0J9H807bEe00lVP@0L
7g/092J2018WU00M8XL082J;018YWP0202PYQ`0W02X/M@0B7Y`09AR@01`JT@0B8J<0:bb001hYMP0H
5GP061]o00XUQ00K7HD07Aj3018OZP0W:9405B^G01/PS`0V<HP06SVC030nS00oFgL0BfiN06EE>`1P
:Q80BQ@504@C0P124`<0AA@204hH101C9@D0GbX806@^2`1h?1<0RGY007IjF`1oKe40Ig=W06ILI`1M
DfT0GE1^0080GDA`02L0E3]f05A1M01FB740FdeU05Y5L01B@700E3ig058oO@1M>Vd0ESan06UQIP1Y
P5d0TG8i09=C8P23GST0JW1@05i/GP1GKVh0E6M_051MM01<F7D0DE=e04eAM`1;DgH0BUMf04YIN013
GW/0A5ml04ANO011Ggd0@EYn049GO@15F7`0AUUn049GP@0mEHH0>UZ303UMP`0hGHH00P0kFhH09`12
EW@0?4Ua03I7J00Z@XT0:T:=02HkV`0T>Y`07CFU02HfW00U=9d0:T2902XoSP0aA900<3ZI048nRP0h
BH/0D6Mj05IZM`1EFGX0FF9b061kK`21T5D0RYi@08FOD`1gWUT0JiUO06nCG`23UU@0Rh1?08V0C@1k
Ne80O7M506a_BP1ZID00IElj07AS=01dM3/0IGi:04F0JP0203aYN@0W03eHO`0mDWX0>eEe03]DOP0l
D840>4ej03Y>P00iBh@0=dR903I3R@0f?X/0=4B;03A:Q`0cBhD0<df8039?RP0^DX`0;5R=02aKS@0Z
HH`0:f:;02YVRP0]K8T0;6j9039bQ00bM8<0<Fn4039^Q00eL8@0>W]m03j6M`0nQWP0?H1k04B4MP17
QWD0@XEf04B1M`14NWX0@WQm0080@GYm02L0@85h04V8LP1GUFL0KYaG086UB`27WTX0TIY809JEA@2B
UDP0SIY;08fNC02<VTd0RYI;08NFC024UU40N9]D06nKF@1/V5/0Ki1M06N;HP1TT640IHeQ066@I01V
UUh0KJ1J07NUE@1lZ540PJQA08RWC@2@YD/0TZ5908bOC@21WeL0MIeQ06fJI@1RVfT0EIa]052KL01<
XW400P1DYV/0901WZF<0MjMK07jNEP21UU<0RYM;08ZKB`2;WDL0S9i708RJB@29V4L0Qii;08JLC`26
Y5@0N:9M07NOH01dUFD0MIAT07^SG01k/UX0I;1T04NQN@0kV840<9J7032ER00cSXX0>i2204j>L@1R
P4l0IU`Y04he4P0e7@P070h400h60@060`001080008000<00@000P0000000`0200000`0000L10002
00H1000300D100030@000`0000/00000303oool000X0oooo8@00000030010@000P40008100050@00
1P@000P40@091@4020@100P30@050@000`0000@100801P4000@01`8000H100070`4030H20P0=1P80
200@2@804`T301890`0I4PP071<:01dE200L4@H06a470P0L4PL09`0P5@L0814801hA1P0N4PH07a86
01`?1`0H3P@06@`301L=0`0F2P<05``301L90P0F2P405PP201H90P0G2P@05`/301T:100D2@8050P3
01P=0`0L4`T0:B0g014ARP011K000@6@0045R`0335h02AMD01HQK00N:GP09Red02PVL00a:VL0;CAi
02HeR00X8h/07Qn>01L/P`0201`UNP0W03@YD`0^;3L06BQZ034aMP0X8WP07S9[02XkK@0]>8406SV<
01DkT@0B8g402a]c00L[O`0A=h808C=X01DXL`0@<X407bmc024SM@0A8h`05RJN02TbR@0L=8D052VC
02XUS00T;8P02bIo01PNL@0F7F/032V001XWPP0N7g@03R2?01dSW00X;Xl02b^T01PTW@0O<9@03bNQ
00808BFE02L09BEd010QUP0P5i8051NH00hNY`0^;HL08RR:01/JVP0R8hD02RV201DDU`0I48T03ab^
02DPU00C8YP06AVK024NT@0G:i`0=3N<03EAP@0]Fh<0F5]S06i:<P1D7`X0C1/504`E101A5P<0F205
05hQ0`1N9@L0G2L;074k4P29MD00OH1E08A_DP1[LF@0IeeY06=CJ@1LD6h00P1PCF@09`1OA6h0FT]]
065>KP1PCVd0HTaU05M2J`1J>Vh0Gd5a06M<I`1MAgH0IV5U06QhH`2?P400SFPb08iH:`2@GS<0Of]3
06Z2F@1IN6L0BVAe04EFO@15C800@T^0045@P`13Dh00A5Eo04=HP014FX00A5Uo04=MO`17HGT0B65f
04QPM`16GgX0@eN103iGP`0nHgh0@6N0049UP00203mNP@0W03mHO00jAWH0=DMe02]6M`0]AFh0;Sb9
02Q0Q`0S>Y/08cRM02@iU00Z@8P0:SnB0310P@0_=9D0@CZ903Y3RP16FGd0DVUg05]LM`1LIG00Ih1T
086>E02=VTd0TYQ;08JGD@1cUE/0JYEP07JLF@25TDh0Rh18081iBP1eMTD0Ifi706]U@01SGS/0J5dc
06U/>@1aKC/0JGI@0080F6eW02L0F65/05EGI@1?E6D0Ce=]055BK@1<BVX0BTQ/04e7K@19B6/0Bd]Z
04]=K@17D7D0AE1a04ACL`15EGX0@eQj03iKO`0iGH<0=62603ASQ`0`IHH0<6^3035aQ00cMH40>gQn
041kN012O7@0A7eb04^2L01ARf/0DhiX05B=I@1FRFT0G8]U05V<IP1@RV/0DHA]04n0K`1?O7<00P16
MgP09`14OGT0@81h04Z5L01RSf<0MIeE07nMC@2<V4T0T9A608nDA`2<V4P0SI]808^FBP2;UT/0QYQ>
086EC`1kV5<0MiYC07ZCE01kSe<0N91F07R@E`1hTeH0MI=F07JIE@1jWU<0OZEA07nWD@20YE40Q:M?
08^UB`2@XDX0SJ1=08FKD`1nVET0MIUP06ZHI@1OVVT0GYM[05VMJ`0206>TIP0T06jYHP1kYe/0OimI
08:KE027Udh0R9Y=08RNBP2>VTL0SIE708VHB@28W4/0R9e?08bQD023YeL0PJ5J07fFGP1hUF40OZ9O
082`FP1]/F00D:Eb04>MN`0eV8<0=Y:803J4R`0lPhL0BHIi05YmGP1UJ3@0ET4G03/T2`0W4`H06@X2
00h50@080`001@000`010002000000040080000100000P00008100800P8000<00P0000<000000000
2P00000<0?ooo`002P3ooolQ00000007004000020@000P4000@100070`001`@000T40@0200P40@03
00H200050P001@4000801P8000h01`8000P200070`003PL200h60`0<1P803PH201480`0I4PL06Q47
01`C200N5`X081P;01lE20808AD8018081<7020C1P0N4@H07Q0501`?100N3`D07@l501/?100K30@0
5@X301D90`0H2P805@P101P:0`0G1`805PT201T:0`0H2@8201H80@0C01P90@0L2P@0:Q@X01<?M003
1Gh00@:@0043SP021G/01@QS014GF`0U<X40:SYV02LcB@0/<eD0<CM`03DfOP0]=8<082b7020eQP02
02T`J`0W03DbB00Z;d00:2eW0410HP0_?6X08TEY02m6KP0Y@7l04c>>00`TL`0=6WX02bV600PjR@0=
?H@06S5k01H^Q00A<8L06RV102@^OP0J;Hl05R^M02XfQ@0V>gH05R^902@XS`0T<H@042]l01XRJ@0I
9fh032ak01PXKP0S9f/04RN601PVWP0Q<hP02bnD01PWW@0T<Y004S2F00806bJ902L08BAl01DWP@0N
77D06B22018UWP0]:8<07bJB01TQWP0O:XD03b]n01lNQ00S77`041fQ02TNQ@0F88`07AZ<02LNR`0H
99l0=36;031:Q@0TAhh0Ae1f06ATC`1]@Qh0HBT>05PV201M8PH0Fb@605TT101D9PD0FbH806/a3@2;
I3H0R81>08Q^CP1]JV80J5aY06AGK@1UE6X00P1[Ge`07`1YIf<0HFMU06=QJP1XEf/0JU9X065BJP1S
AfH0HD5e06I>JP1JD740IFAT06YcI@2;P4H0Q81507b0A@1mP480RW8j07^2A`1YLeT0FeYX05ACLP1=
D7L0C51k04I?P013Ch80?dn4049AP010D7l0@E:0049HO`13G7X00P16GgL01P15GGL0?EV203aLP`0m
IW`0@FQh041ROP80?U^502L0>eN:03]<RP0eB840:Sn=0394IP0^Ah@0<DMd02HiV@0W>Il09CbN02U4
U@0U@Y`0;Cii02`dU@15?HD0>T6=03i?P`10GXD0DU9n05=MN01MQ6P0MY5I08JHD`2BU4T0TII:08VK
C`1iVUH0KY]N07JKF027ST/0QH1607ad@01YJ4<0JV1005eO@01NGSH0HF@i07AP<01iJC`00P1XMe40
9`1NN5`0EVMS04mGJP18DVd0BEA^04E@L@13BW<0@d]a0499LP12BG00@Dad03m>O00mCGX0?55l049G
O`12FWh0?E^303AKQP0`GhT0;Ej:02QRR`0XJHT0:W6702mfP`0dNH00>7ek0463M@13QW00BhaY05F?
I01JTV40G99Q05bBH`1OTV40GHiS05J:J@1@PVd0Cgad04MbNP0204=XP@0=03aVP`0iHH<0?W1m04n2
L@1WS6@0MYEF08NJB@29Ud/0QIM=07nGDP23VDl0Pi]<08FMC@0207fMDP0H07ZMD`1iW580OIQC07nD
D`1oUU40PiIA07nHD`20VU<0OYUB07nPDP22YDl0PjI>08FTC027Xd/0R:9=08jPC02?Vdd0RiQD08BG
EP1oV5T0Ki]Q06fIH`1WUfL0HIiY0P1WYFH0901]Yf80N:MM07nPG023VeL0QiaB08>HDP25VTh0TI59
08b>C025U4d0PiQ=08FGC02=WDX0Qj9>08NTE022VeT0NIIS07jNGP1mYUX0Lj]L05fXJ@1?XG40?iel
03JFP@0gR8P0?H2504V3M`1EMf40I74k05M<6`15;0d0<1P7024@100I2`@04PD100P300800`4000<0
0P0000@0000400000P0300000`020@00104000@1000200<100030080000100000@0000T00000303o
ool000X0oooo8@0000003@0100000P4000<100040@0020<000T30@0810402@@000T40@09108020<1
00P300060P000P070P0010090`003PP200l:0`0>1`8200/40@0700h80P0K50P0718801dD200Q6@/0
8ad=020F2@02024D1P0W024C1`0R4PP08Q<7020A1P0L40D06Pl301hA100N4PH070l401T=100F2`<0
5@P201@70P0C2@<060T401X:0@0H2`<06`/301P90P0E1`8050P101d90P0Y3A/04`iB00@8M`010JH0
002@0000UP0009d00PZE00XJU00K>g808d5:01i3I`0W>Wl0=cAn03I2O00X@7h09C^50080=CYe02L0
?dAM0350DP0dBVT0@E=Q02mFJ00REg@0:E5j01m1R@0:8Yl021Uj00XQT@0<>IL02D6A00XlV00E<Yd0
63FE00laT@0I;i`0:SZ>01lfUP0D:ih0;Sio02m1K@0E:hD08BRE02<dR00@:9@06b:M024cS`09<980
5BJJ02`_P`0C<X<04B>T01djR@0=<HD05RRO02HdSP0@<I800P0F99H09`0Q;Hl04BNE01dTS00M9hH0
4R>P02PVR`0L:YT06R>M028aP`0F;H<0:bZ202lYK`0G7Y/0:Qb301HMSP0R78X0<RN601TPX00b;8d0
<D6602HkTP10BG/0AFU^069UBP1_AB80IRX:05lW201K90L0Fb@505LQ101O:0L0Jc0<08aG8P2@P4P0
RW5@06YSI`1RFVl0Gf5`05YTL00205i]J@0W065fIP1SP6L0HWQW065SKP1PG6h0GUYb05mCL01MA7H0
I4]`05m<L`1RF6T0JEeZ07n0D`1gP5T0L81M07:2E027ND<0Sfhi08YL@01kIe80KV=J05]YI`1BJfl0
BEef045BP@12CX80@4b603m>P`0lCX80?52403mCP@12FX00@5mj041QM`0oI7T0@6Qi045YM010J7H0
?fEi0080>Uj002L0?Eb7041CR00jCH<0=4>403=:N`0eD7X0=DYh02PlV`0Z@9`09SjH02I5T@0QA9d0
:cif02HfU`0n?X@0>TB=04=FO`13Ih00EFIc061`K`1WQ680MHeG08>DDP2=TdX0UI=509FDAP27UDd0
LY9J076JF`1oUU00Qh=7089f@@1/IdL0IV=305QOA@1SG3T0Gf4c06]I;@1aHSL00P1gL4009`1UMU00
EFe]04mPL`14CW80@di^04IAO@14Cg`0@U5k04=?O016BWX0@TQl03m:Q@0iBHD0>Dj703]AQ`0nEH@0
?UN203QIQ00cFhL0<eV902iMR@0]I8/0;F^9031`Q@0cMX40=gan03^2N00nQW@0@X]_04b?J@1FTf@0
G9AS05bAH@1PSeh0IHiO05b;I01DQF`0BWae04=^OP0203aMQ@0W03]KQP0iE8P0>f6504]cN@1LQV`0
JhiO07fHC`22VT`0O9QA07BEE@1iVe<0O:9C07NUD@1gXU<0MYiC07RME01jWE<0NiaB07fLDP21Ve<0
QIi>08JMCP23W580PI]C08:LC`26Xdd0Q:Y=08NWC022YE00P:9C08RPC`2@VTh0SII@08VEE@23V5L0
MIaN06nLH`1/VFD0IJ=W0080IJQW02L0JjAU07JSHP1mXE/0Pj=H08ZLE@22VEL0QIQC08^DC`27U540
Q9A=07bHE@1kUeH0PYe@082TDP28YU80Q9iG07fJGP1kVel0O:1L07:XG`1SZVD0F:IZ04FPM@0fVX40
<hZ803ekR018P7/0DW9Z061f@P1JFBD0CCPB03dS2@0^6@P09aH6020?1@0B1P40204000@000020000
0P0600000`0500000`0000@00002008000030081000300000`0000800P000P010007000000`0oooo
000:0?ooob4000000P0100006P030@00104000L400080`002@<000T40008104020D200T30@090`00
20@000P300070`003`P3018:0`0A2`@04P`4018<1@0F3PH09RXW02X]:@0/;BT0;BhY02``;00/=340
=C@`0P0h<2/09`0d;1l0<bPE02lP3P0[6PT0:1D801lB1@0M4@D081@701dA1@0I3@@05P/201D90@0J
2P<060`401/<100N3@@07a0401h>100M3P@06`X301X90P0L2@807a<N01HK>P0A6ET02@ef0041S000
0H`0002=0084L@053V803R9X01PkO`0MA8P09d>303Q4M00mAVl0?DU^03a4K00203]1K`0W03i=J00m
GfL0=eab03=KLP0WFGT07Tn801]2T@0C<9/01A6=00HOS`08<Xl033b<00`nTP0;?9X04cBM01HfU@0?
>9005cfE02Y0S@0S?hd073^;0314L`0_@G006c:0028`S00Z>6h05R]i01`VQP0T:h404R^=01HZW@0Y
=8@06CMi018TX@0R=7/05R]n01LUX@0U=Hl04C>:00805bJI02L08S2:010UV@0M9Yd07bN@014YX`0T
:I008Bn;01/SW@0W<H4072f302d/S`0e;fh061jI02dJO`0L7900:2:A03T]O`0G79h0;bF902`gR00W
<ID0>dB202MSP`10L6h0J5/m06X`3P1J8PP0EB<705TR1P1O:0P0IB`9078g3P29CAh0Th1108MeD`1a
JV<0JfYW06i`HP1]LUl00P1_LF409`1^Le`0L81L06b0H@1]MF@0JgEV06EdIP1YIf/0IEA]06A>K`1K
CGL0GeM^06IJJ`1iP5X0MX1M06Z0J@1[PVD0M8EL08J0B`2EJSP0QH1607EfE`1JHVD0CF9_04]JL`16
DH00@4b00458P@0lAXH0=d::03U4R@0gAhP0>U6303]GP@0kG800?Emm045RM@13IG40@6Ic041QMP02
03mJOP0W041HPP0oEHL0?56;03M=S`0fD8d0=D^@03=:Q`0Y?Yh0:SjN02DiX@0Q@9l07d6M02LnMP0[
@900>T:503M:S@10GGl0?VZ104mcM@1JO6l0KHMO07F8EP1iSe<0Qi9=08fAA`2IR400U8i408JEC01f
VED0LiQH086;C`27Nd00N6e706iZ@P1QHD40J5Th06AH;P1^EbP0Leh`0080OfD`02L0NW1106agE`1R
Je`0EeiN051AH`1CBfX0FE5W05aFH01JFV00FeIO05=DH019DVX0@eAc041IN`0oGGh0A65m04ERO@11
HWh0?F6403UOQ00eHHD0=6J7035XQ00aJh40=72003IfOP0iO7/0?81i04:4M018QVl0DX]U05^>H@1R
T640II1O06ZBG01VTeh0HI1Q05B7K@1;OGL00P13K8009`13JX00AFQo04I_O01@MWD0FXI[06N<H@1f
TeL0OIMC07bID@1iVU40MIaB07FREP1cYe@0MJ5D07JUD`1cYUH0N:5F07fPD`20WE80Oj1C08>OC@24
WE80PYeA07nNE024VTl0QYe<08FVC`28YTl0QjA?08BRD02?Wdd0TYI=08nCD@2:T5@0PY5H07^HG01f
VUh0MIMQ06nNH`02072QHP0V072HI01hU5l0OYMK08JME02:Ve<0PY9E08BFDP2;UE40RIA?08BHD@1l
UUX0LiIL07^LE021WU80Rii>08ZNEP1nVUT0NiaH07^OGP1bXf00KjaO06J[H01>Yf`0?Yih03NDO`13
RH00Ched05J1I`1POTH0H6X^05I;6`17=A40>bT=034R300[7`T07A0500h50004000400<000801000
00<00`000040000200000`02000:000000`0oooo000:0?oooaP000001P010003000000800@0000H0
0P4000P50@0910802PD200X40P08100200T40@0B00X40@080`002@@000X3000?2@<04P/401D;100E
3`L05a8801XF2P0M<48072iF01d_G00N<E/0735K01TaH00H;Uh06S5Q0P0O>VL09`0W@dT0;T8]038d
700g;Q<0<Al;02PD1P0P40D07a8701d?1@0H30<06P`301/<0`0M3P<07Q0502<A1P0S50D08a85028C
1`0P4PD07`l401/=0`0H20807Q<`010K@P0H8S/05aiW0041R`0009<000220041LP0117/00`am00LL
Y@09;JL04T^E01ACSP0DDh`06e>902=CQ@02021?QP0W021DQ00NH8@05eV=015BTP0;AIT0236V00HK
/0012;<00@j`008XZ003=Z0023NM00/iWP0;>9h04c>L01@gV00A?9805d:C02I2S@0UAH/07T6:02Y1
OP0ZA7`073Yi02@gQ@0/=W006Ria01dYPP0R88H04B:A01D[W`0W=XP07SUb01DRW00Y;7l06RJ501@R
YP0V=Xh05SAl00805bND02L08ban01<TS00M8id07R>C014]WP0S;XT08c9j01lPW@0_<WX08bak02lX
T00a:6T06R:7030LK`0R87T09RN=03D]M00J7Y@0:an902TYR`0V;IH0?dEo02QCQ@0lEG`0I6MK07QA
;@1V<0l0H2P<05dZ2`1P:P/0J38=07Hh4028Dal0Th1207icE`1/L6D0IWQW06>0I@1NP6P00P1LP6T0
9`1MP6/0Hh1X0660I`1OP6L0IX1W06>0IP1JMfl0DVae061MLP1DD7d0Cf=i069RL`1[P6H0LWUQ0661
LP1MP6h0G8M`07J:E`2>Md00R7Q008YO@01nFTl0Ke]F06EUH01LJfX0EF5a04eINP14C840?Sb:03Po
R`0f@8X0?4R603]@Q00mE7l0@UMf04QKL019HVd0BFE^04MTL@0204=QMP0W04=OO012FX<0@5J704=B
R@10FH00>E^303]GM00b@9L0;T>F02HnSP0W?HX0:CN60315NP0`B7l0>Tmd03IJM`0kH7H0>6N704]c
N01ENGD0LH5O07N7E01mRTd0Q8e808V;@P2?Qd00THI008f8@020Tdd0LiMF07RDDP26PdH0NW]8079c
@@1UJ400JEdl06MJ<01`EbD0KeTV0080NE/W02L0OfPc07Yi@P1QNe/0CfU[04=DM@0oCGX0Be9d04eD
LP1:EFD0BUEV04=AK@0fCgP0;U6502YDR00ZEh/0<5R;039IR`0`FXd0;5J?02]FS`0TF9007efE01mK
T`0RFY409U^@02MNSP0]HX/0<G25039lPP0hP7`0?h=c04V7K01=Rf`0Ch]Y05^?I@1TTUl0I9AP05N:
J@1>P7<00P14L7h09`16LGl0Bfmk055eM`1BMGL0Dh9_05b7I`1/SUl0Ki=J072IF01^VEP0JYiJ06ZR
FP1]XeT0M:=D07VTD`1eZEH0N:5G07nODP24WE40PJ9D082QE@21X5@0PYaC07fND`24VU80QY]=08BU
C`26Z540R:U>08ZWD02?XDX0Sia<08nED02;U5D0QIMF07fGE`1kWEX0NiUK07ZLF`0207^LG00W07J?
H`1gT6@0NY5O07nJF022VeD0OiUH08:KD`26UU40PiIC08FFDP1mU5T0M9EO07bLEP20WU@0QYQC08ZL
E`21W5P0P9eI082MFP1kXU`0NZaJ076^FP1KYf80@:1c03BEP00mTgl0CI]a05ZBG`1TQdL0I7Dc061K
8`1BAQT0AcLB03`b4@0h:@l0:Q`901T>100=1@401P0000801@0000<01P4000D0000300000`030000
1`0400001@0000<0000200000@000000000100001P00000<0?ooo`002P3ooolH000000800@000P01
0@0200800080000001d00P000040000200001`@100T60@0:1P802PD200T50P080`002@<100T50P0:
0`402P<000X4000;10404@`401DA1@0H50P06QL<01hO400Q9QP0539J01<[H00@:W0032Qo00XUR@09
8X/01QYj00LTN`0200/eN00W01U7H`0/DU00@5E?059DA@1H@c80CS0N03dR4P0a7@d0:1L7020@100M
3P@07`d401h@0`0R4PH09A<502HG200U5PP09QP902@G1`0S4@H07Pl302P?2P0S6BP0620c01hQ9@0O
8UL00`Qo0000]`0008h0001e0001O@001X`000ja000M/P08@j0014bM00=?W009DIP04e6C00805e6@
02L044fG011CU@0:B9`01T2R00<aZ@027K400@Zi000=^P026;@01c:T00Y0V`0=?id03d2N01A3T`0F
@9005cn@01E4T00MBY009dJ;02U7R`0S@Xd0:T6602a6N00S?fl0:41g02hhLP0S;g408Raa024QLP0B
88X04BZN02DdR`0Q=GD052FB02PXO`0K98P04b>T02PfQ@0J=7D00P0G:I409`0T9g/052>601hRUP0P
89805BVK028^T00S;Vd07B6I03<`M@0R:7@0:B>>02`RJ00L9h80:a]b024NL@0S9Id0<bYb01LLT`0[
6Hl0:1bA02PVU`0n@X409dB<03`mP`1EGfh0LGE>071=7`1]>A40JC4?06P]2P1Y;@/0L3<=08M=702A
OD80NgeG06n0GP1]P5`0LH1I07B0E@0206b0GP0W06Z0GP1^P5`0K81N06f0G`1`P640Jh1P06N0H`1W
P6D0KX1S06MeI@1PK6h0H6I^06F0I`1bMe`0JX1Z06EfM@1GP7D0J8eM07f5BP21S4`0Q7U707n1C`1j
O5D0G6QW051cL019JGD0?eV003]:QP0f=8d0<3F?02ldT@0b?h`0=TN:03U>PP0jDX00@59e04=EM@13
G7<0AF5a0080@eb002L0@eN0041CQ`0kBh`0>4F;03]FNP0lFgl0>e9/02hdW00[@Xl08c^N02PgX00^
>9/0<4NF0313U@0fEg`0>Vij03YAM00fEh/0AVMn04]ZOP1ZO6<0Kh5G07N6CP20RdP0RHQ008n4@02E
PD00UX1008b8@022T4P0OHi?08V2@021Nd00NG9006eX@01[GT00JU`j06mJ<01^GC000P1bG2X09`1m
H2T0Q6Lj071dEP1JIfP0DEY`051GK`1>Eg80CeUf04iBJ01?DFP0CDmT04QAKP12EGh0?UJ403iGPP0l
EhH0?5N503YEQ@0kDhL0=eB503AGQP0aG8P0<F6603UUP`0jIh80?FQo03m^O@13NGH0AH1a04J0K`19
Q6`0ChIV05:6IP1CRV@0H8mP06VEF`1^UUL0J91N05f7I@0205Z2J@0W05f3J01NPVP0FH5[05V1K@1G
Q6h0FHIX06:<H01UTed0IiAM06RGF`1WWEd0IJ5N06NNGP1bXEL0M:9E07RRE01nW5<0PIUC08BDE024
We<0QImD08FFD`21Ue@0NiiF07bKE01nVe40Q:E>08F[CP2:Zdh0RjY=08nWBP2=WDd0SiE=08^CC`26
UU40Q9MD08BIE024V5L0P9eF0080Nj1M02L0N8]V07B;I@1fSFD0O9EP082KFP1jW5h0OIaK086HE`1k
VET0P9QF086CF@1bTV00MiUN07fKFP1hUU/0R:1E08RREP22WEL0Q9]I07nPG@1lZe/0M[1J05^]H@12
Xg80<9N003NHP019XW40FIaM05n?C@1VOcT0IV`Z05aG8P1=BA`0@D8J03lj5P0e;a809Ad:01D;100:
0`000P040@000`040P000`0000800002004000800P0000@00`000080000200000@002000000<0?oo
o`002P3ooolJ000000030040000200000`0000<00P0001d0100000D000070`402PH200T60P0;1P80
2`D200P300080`4020@100P30@0910402P<000`50@0@2@805Ph601dG2`0N7Pl07b@F020Y8@0;:H40
4BUP01@^FP0=974021Z400DDY`021hT00`^900<ERP0200HQSP0W00d[S00I=8H08SAg038iP014?700
BT5I04A2?00l>bP0=R`F02`J2`0S50H07a44020@1@0P4@D08Q<502HF200U5@L09Q@702DC1@0T3PD0
7@`302D>1P0R6A<07alI02<I5P0O7T401A1Y0000^P000:D0002@0002SP001J8000Zf00@[Z`05;:/0
0cBX008lYP04@:<023jQ00801B^[02L01RjZ00H^Z@03:Z`00RJ_004M/`014;P000bj000E]P038:l0
33VN00m5T@0?@9L064JG01Y;SP0JAhT06dB;01e>R`0PDH`0:4R;02i5Q`0Y@HX0:42502m4M`0X@W40
9D=^03@nI`0W<fL08ReW02<^J@0E;Gh03bbF02DaR00Q<H@04R^<02HZM`0M;Gl05RZJ02`eN@0Q=7T0
0P0F:hP09`0U:h407BZ801lSR`0U9Hh07RFE02TYS`0X;G807Rj302d/KP0Q;7L09BMe02TTK`0O:G80
9b9`01lVP00R9Yd0;bEj01LMQ@0_87D0;BMo02XVV00o?7h09cb@03PhQ`18F7<0Cg5Y079YC@24CbX0
NC/A06ld3@1Y<Pd0KcPB08QF8@2@P480N81D079kF01gNU80Nh1?07R0DP0207N0D`80M81H02D0MX1D
07N0EP1`P5/0KX5K06V2G01VPF40J8AP06V0H`1RNV`0I6a^05R0L@1gP5X0NXYJ07=oH@1UOfP0Jh=O
07b1C@21S4X0Q85;07b0CP29J4<0NEA@06MEF@1LGf80EfM/05=KL01ADGT0BTmk04A>O`12D840?4j5
03Y<P011CG`0@e1e04MFL016FW00Ae]`0080AUIe02L0AEUh045IP012DHL0A4Z404EBM@12CW40?e9^
035=S`0aBH@0;T>I02e5W00bC9H0<dnC031:T@0jHWD0?Vea03M9N@0cD980@fEo04I/MP1ONfP0Kh1I
07V5C01mRTP0QXI008j3?02AP3/0SWdk08n1@029R400QX]308R1@023ND00NG1206eY@01YHD00IEm0
06UQ@01XIcX00P1]HS409`1gFBL0QEdZ07i^@P1RKEh0FVIW05]RH`1EFVd0DEMb04mBKP1>Bf/0CdiK
04mEJ@16EgP0@eN0041GP@0mFX<0>5^503UHP`0iF880>EZ303QKQ@0eGhD0>6Z303icP011Mgh0@gYj
04MnMP1<Pg40ChE^04f7K@1;R6`0C8IZ05:5IP1DRF@0GXaN06BDF`1^TUH0KY9E06V?F`0206J=G@0W
06^=G01YSEh0H8YR05R9J01CRF/0DXU[05b?IP1OUF00HiUO06JJG`1VVel0IIaQ06:HG`1[X5d0LZ5H
07BPEP22VU80QII>08RED027UU40RIM?08RGCP24Ve80PI]C07bOE01mVE<0Qim;08^RB`2>Xd/0T:59
09>OB02BVdT0T99;08f>CP2<SU80R91?08ZADP28TE00P9YF0080OI]N02L0MXIS07V8H01kQf40NhiP
07fEG@1mV5P0OIYI082HFP1oU5L0PiAE08>AE@1hT5/0OIMI07^JG01dTed0R9aD08VQE`23WEP0PiUJ
07nPF`1f[5d0LK1M05b]I@15ZFl0>J=h04BTM01@YfP0EYmN05RFE@1VR400LG<]06QO8P1KDAd0BD/M
04M97P12AAX0=S@B02LK200E2`<00P0910000`070P000`0000800003004000040080000100000@00
004000T00000303oool000X0oooo6P0000007`0100000P0000<100040@000P000040000300001P80
00X50P0;1`<02`H300d70P0;104020@100T30@0810402@<100X50@0<104040T201H;1@0J4`P081h@
024X6@0K<BH00`bX0087YP0666/01Af40047R@021H<00P000;d00`0009D0002F0000^0020000^00J
0001V0001HX02Q2Q02@XU00[AXH0;Ei[03IKB00jB2T0=2XC02TH2P0S4`L08105020>100Q4`D09AD7
028D1P0T4`D08aD6024A100O3`@07`h401lC200O5PT08a@=01hG:@000;/30000_@090002_@001;`0
02>a000J]0004KP001fd000Z[`00;Zd002^^008001jd02L001:h0009^`003[T0016h000>^@013;X0
0aJe00@N[`079ZP043RO014mT00@=iL06TJE01e<T@0MB9808TV@02=CR00RCh/09D>=02e2RP0W?900
9CVA02i7R00VAHP08Sb903A4O`0X=6P06S2:02@fS@0K=h803B^A02L_U00Q=IH042RR028_T@0P=XL0
52NP02dbSP0O=hL00P0D:9`09`0W<i<082nI020VW@0];900822C030TT00^:XH06b^M02/`Q@0M<Wl0
8BFE02/]P@0H7iD09b^B02<aS`0O9Z40:R6701XRU`0d:X<0=39j02XTUP10=X009CRJ03HdR`0hCW/0
:Uj105ILKP1lGd@0ODDI07935@1cAQP0MeDT08Eg>@21Q4`0JX9K06R0G`1YP5`0KGaL06b0F`0206ag
GP0W06QiH@1ZP5h0LX5I07j0E01kP5H0Mh1B07:0DP1]Pe`0LHQK07B7F01_QUl0KH1N06V0I01lOEP0
OhEC08]oC@1oOeT0Nh5D089oA023QTH0PXE;07J3C`28O440QX1407MYD@1QGel0DW=W05EXK01>GW80
BU]h04IGO@14EGd0>dN503I3R00l@h40?dUj045AN014DWH0AE5d0080A59d02L0@UQh03iFPP0oBh/0
?3n=03m4R00l@h<0?5Uc03ILR00cBh<0:DBM02m?UP0_B9X0<EF?035MS@0lHh80>EB803<nR`0`BYH0
@6B1045_O01HMV`0JXAP0869B@21RT<0R8Q009>0>`2BMcH0TGDd09=l=02@P3T0S89008Um>`21M400
O75006m]@01/HT00J5e006YQ>P1[ISH00P1[Hc409`1^GR/0NELT081X?01WM5H0DVi[05EWKP1:D7`0
?DR203a;P`10C8@0>Tan03Y=P`0iBXL0>4^903E<S00]Chh0;5F=02aHR`0^Eh/0;eR:02aHS00XF8l0
9U^?02AVS`0ZKhX0<WZ203J0O00kPgT0?hMh03n7M@0mQgP0?HMd04:4L@16Qfl0CHY[05B>J01PSUl0
I9=L066GGP0205jKH00W06>IG@1PVEl0F9=T056>J`18Rg80Bheb05>BK01FVfP0Gi]O06BIG`1SUUl0
HIEQ062AH@1SWF00Jj1L06jOF`1oWU00RI]>08NFD022Ue<0QYQ?08JLD022WU80OYiE07fME01nVU<0
Qia>08bQC02>YT`0SJA<092RC02=XTh0SIU?08^EDP25UEH0QIEC08JBDP25UE@0PI]G0080Mi]N02L0
M8IT07V7H01kQUh0NhUR07n@G@20V5`0O9eM07nLG01kV5T0P9QF08>EEP1hTU`0OIUJ07RIG@1_Tf@0
R9eD08JOE@1oWeX0P9iG07ZSFP1c[F00KK5Q05Z^JP19[W00@Zab04^]J@1EZF40DJ9S04nMHP1QUT/0
Kh<d06a[:01OFb40DELR04eO9`19H2P0@e0Q03<`4@0P5PH00P0?1`400`090P001@00004000020040
00800P0000@00@000080000200000P002000000<0?ooo`002P3ooolJ0000000O0040000300001000
00@1000400000`0000@000070@4020<100X40@0810402PD200/50@0=1@802`H200`50P0<1@403@H1
00d50@0C3@D05Q8:01TJ400J91X06c0`00XKI`043Y800@Bc008;R`033Vd010QZ0000_0020000_@0O
0000XP000900002?0000S`0007P0005h0003O00427T04aYc02DeKP0f@fP0>d]W049@F`1;BDh0CD58
04Pk=`0n;b40=1d?02TF1P0U4`H08A<4028A1@0Q40D08@d401l=0P0M30<08@d5024@1P0R5@P00PB`
0042^0030000_0090002_0008;8001nb000L]0006[@001jc000T/@009[0002Ba008001^d02L0012h
000:^`004KP001Nf00<X[`05;J/0332V018eW00C>ID05Cn@01I1S`0LBHh08dj?02UAR@0ZChT0:dj7
02m>Q00[CXH0:DV70358Q@0^AXL0:d:<0356Q00]Bh00:Taf03E5M00^=VP08SIo02hfP@0Z=W807C67
02TcR@0V>X<06C:>02dbPP0[=7L06c2:02`/O@0W:gT00P0K9I/09`0[<I4092n@02@/P00`=fd09SAb
030^O`0`;8D08RZJ02heQ`0U<g/08bb<02d`N@0M9XL0:Ref02H^MP0P:8D0:2>701hXVP0f<8H0=C=a
02XTR00n:g407c6F038bR`0cAgP07e:;04]CLP1WKEd0Q6Q008]N>@26Gd00Ofe507]dC01`MUL0H7AU
05mdJ`1KLf`0FW5[05Y_K00205YXK@0W055QM@1EM740H81X06n0G@1iP5/0OGm>07EoD01^OeT0KXAP
0769G@1aSe`0L8eN06b7H@1iPU`0NHAG099k@02:ND00R7Df08Ec>021P400Q81007^0A022P400PH10
08M^A@1aF5D0HeUL065KH01JGVT0E5e`04QMN@17FWl0@E21045=PP12Bgd0?dil041BM`0oDgH0@U5g
0080A5Af02L0BEQd04EKN`11GH80?EV6049IQ`0oFH<0@5mg03]DP00eDXL0>5n<03UOS00eG8d0=F:5
03ARP00lEW`0=T6703A0S00dBI@0?V6303aZO`1DNfl0IhQR08:=B@29S440RXU00960?02?MCD0SW4`
099c;@2?MRh0RgXe08Uf>@24Lc/0OVa007I/@01cHT00LF50071P=01aI2l00P1_I3809`1aIC40MelY
089Q;01nL4<0JW1J05maIP1FIfh0C5M]04]DK018Dfd0AdeQ04IBI@18EfX0BUQf04EJO013GW/0@f=j
04=ZN014KgX0@fmi03iYP00lI880=V2503EWPP0iL7l0@Wai04F3LP1:QVd0CH]Y052?J01<T6T0CXaY
04f8J@1AQfL0EHUU05b<G@1TTEd0JI=I06BHF`0206:CGP0W062BH01KTV@0FHiU05B;J01BRFd0Dh]/
05RCI`1OW6D0IiiK06fIF@1[U5X0KI=K06VEG`1/WE/0LImH07JNE@1oWE00QIa>08JID@21VE<0Q9UA
08JJC`23WTl0PiiB08NND@26Udl0RiY:08nQBP2=XTX0S:9;09BQBP2?VT/0SiE>08ZCD@27Se80QXmB
08R=D@26TU<0Q9MD0080OYIH02L0N8QQ07n>G01mSE`0MXaR07nCG01nUEX0NYQK07jNFP1kVeX0NiYH
086GE`1kUU`0OIYH07NIG01_Tel0QieB08JMEP1oW5T0PIQI07^QFP1dYel0Lj]S06F[J01O/6@0FZmS
05b^GP1H[5l0DjIQ05BSGP1QWdl0L8dj06m_:01PFB80D5LS04iM9P19HRT0A5PT03Tm600V70T00P0D
2P<00`0:0`000P0000000005000000800@002@00000<0?ooo`002P3ooolI000000800@000`040@00
6P050`001@8000H000050@001P4000D40@0:10402@@000`40P0=20<03PT300h80`0>1P803@P301@=
1`0D50/051XB010Q700?:BT04C1;00PKIP022XX0002l0001[@010YT00PBJ0`000;d080000;@0002Z
0000Y0000:@0002R0000R@0007D0009Z00D>H00?8WD09b>003</PP0e?X40:cZ302DnQ00XBG<0=TA:
03Xa8@0a7@`0:A@5028B1@0P4@D080h4028>0`0P3P<08@d4020=0`0S40@061Uk00@7Y`020k<0002m
0P000;`02@000K`001Jf000I]0007K<0022b000P/`007[<002N`000P/`02000I]P0W000?^@002[X0
01Bg000K]004=ZP01SbU00`kX@0A?I`04CjG01@oU@0MC8l07U2?02=>SP0ZChP0:Tj902Q7RP0^B8P0
;D^602U9Q`0bBH@0<TR602Y1RP0]AHP0;D]k02U:L@0`@Wl0;Ci_02DgO00d=H<0<c=i024aR`0Y=XX0
:cmo024hQ`0a>8@0=3]g01lcPP0V8XD081Z000806R>L02L0;2f@02L`Q`0_@6P0@4mA02/gI@0_=XD0
=SR502X[TP0b=8T0;39o02D]S@0`=8409CUc03/lF`0V:Eh07bR<02L^S@0M;I`0<36;03<cK@0[9hT0
>B5/01d^TP0a<H/0<D=j01m3U016CG`0CW1`05MmI01cLDl0LUaG05aOJ@1KH6`0F5]]04iAM@1>CgT0
CDel05ACN@1;DGd00P1?C7l09`11?HH0ATB604=9RP1?IgT0Fh1`06YoH01/PUT0LH5L0720GP1_QE/0
MXmJ07NAF`1cTe`0MHmK07B=G@2EP400UF4X08]H9@26IB`0QgXk08Ei=`1oP400PWU0081c>`2=JSD0
QGI307QXD@1TFE/0FVMU05ISLP0nHH00@5io045CP019DW`0@dml03m>O00kD7`0>E5m03Y=P002049?
N`0W04IHMP15Gg@0?fYm049bN`12Kh00@FN203iMP00kD8H0>V6:03mbQ010MH80?7:503EUQ00bDhH0
=D^70350SP0hCHh0?DfA03aIRP0iEhd0C7ag06:>I@1oTE00RHe308V8@02<Q400Rh0l08Yb<029Kbd0
Rg4/08]i<@29Lbl0Q6`/085Y;P1iIc00Lf0^071Q;01bI2X0MfD]0080LFTd02L0M6ld07AY<@1mHbP0
QFPl079_E01JMVH0CW5Z04UNJP14DFh0>de[03i;I`0nC6P0?Te/03i?O00mDHL0?eR4045RO`13LGD0
AWec04B0L`10MgL0?6]o03IOQP0eI8H0>Vf303egOP11OWL0@X=e04F<L017TF`0Ai=[04b?JP1<RF/0
C8Q[04f:JP1BSVD0FYMR05fFG`1KUF400P1ET6H09`1ARfX0CXU^04j9K@1@Qfd0CXEa05B:KP1GT6L0
G9QW06FLG`1XVE/0JiIN06ZEG@1YVF40IYeM06VQG@1`X5`0MJ1H07fPD`21We<0PYeC082PD`23XE@0
PiiB08BODP27WU00QImB08ZMCP29WTh0RZ5<08jVB`2DXTL0TYm:096HC02=U4`0RI5A08N@DP23U5H0
RIAE08NID`0208BFD`0W07n?G@20UUP0OI]I07NGH@1lV5d0NYQP07JJGP1lWUP0N:1K07ZPF@20WeP0
O9YM07jNF01iWeX0M9IN08ZPE`27W5L0NiYI08:JF@1lXE/0LjQR07BVI@1_YVL0KjYP06n[F@1[[ET0
HJ]K05>ZH01EZU`0GjIA06bE?P1]LBd0G5HT04eC8P19EB40AUTT045H9@0jAQ/0;2D=00806`h400@0
3P@000D0000300000`000P02000200400080000000<00@000000000000001P00000<0?ooo`002P3o
oolI000000030040000200000`400080104000P01@8000D100060000100000D100060@002@<100`4
0@803@H200h03PL200h80P0>208071@;01dJ4`0J92005R`]018^>@0=<TP02BEM00@@MP0118h0002o
0000_PX0002m01D0002L0000N@000F@000MM00lOOP0M68T0;21n03HcO@0_?H009D1o02A3N`0a@f40
?d1104Ph:@13;1`0>20?02/G200S40D08A0402<?1@0S40D00P0Q3`@02P0Z94h061ai00hAU@031K40
0PJc0046/`005;H000jh000C]P006k@2000P/P03000Z[`009;8001bd008001Nf01<001>h000C]`02
8;8023fU00a1W`0?@Yd04d2K01@oV`0E@YT06dFF02EAS00VDH`0:52902i?Q`0/BhL0:TJ;03A<PP0_
Ch<0;T^50080<dR40180:d:702a6P`0_BGL0:TAe02m5P@0a@g<0;3eg03HjO`0f=X409CJ;02/kQ`0]
@80093b;038kQ@0d?gT082j402@MRP0P6W/201`RSP0W02X]O`0V<7L0:ceQ03U6DP0Y<V`0<C>503Tj
N`0/<800=39c02`aO00W;9H0<cUo02m4H`0jA6409baW01lZV00_=8<09Rn=038aP00d<W<0;2Z703LQ
L@0O;8`0<S6903<nM@0O=iD0A4Ef03aXM@13N7@0IG5K07UUC@1cIU@0J6EO061VJ01JGg40DUQc04]>
M@1@C780ADYj0080BTEk02L0AT:804`mP017?840BE1k04AQO`1DN700GH1X06b0H01eP5L0Lh1G07J3
F01iRUX0NY5J07ZDFP1eUE/0S8=409Ia;P2;FR40R60Y08Ij=`23MC<0OW`j085e=P1jLCD0QVD`08Ec
>@1oLd@0JeUL05YIJP1MG6X0DEef04iQM@18Gg`0BUaj049AO00mD7d0=UEm03MCNP0kCX000P0oDG`0
9`16FW<0A65e04=XMP16KGH0@Ven03iXPP11GXD0@EV:049YPP12Lh40AGIo045bP`0jIH`0=5^@03QJ
SP0eE9<0A5b903mCSP0kFH`0=TnD04IhO@1NT6H0NIAB08J>@`2:Qd00R8=008Um?026L2l0Q6T[08IX
:026KBX0Qf/Z089Y:@1nJ2d0NFH[07=M9P1`G2H0L5`U07=P:002079V;P0W07EY;01eIBX0NUlV08AU
<`1jL4T0IGQN055YJP19Efh0@Dai03M7L`0fAf`0>4E]03Y6LP0kB840?Df703iEP014Gg/0BVeb04mj
K@1?Nf`0B7Ac04EZNP0lI7l0>FJ103Y]P00lM7d0@WUh04F3L`1<R6/0D8mX04b?I`1@T6P0DHYW05>9
J01@RfL0E91U05ZFH01QUE`0GYAO0080FhmS02L0EX]X05::JP1ARV/0DXMY05J8J@1JRfH0GXiP066D
I@1TVF40IIIK06VFF`1ZUEd0IYUQ06>LH01NWF@0IYeN06fRG@1eXEL0O:9G07bRE@1oXUD0Pj1@08BO
D@23WU80Q9mC08>ODP29WTl0R9e?08JQC`2<Yd/0TJE7092OB@2AVT/0TYI;08VBD027TE@0Q9=D08RB
EP28Ue@00P26U5409`23TE@0PYQC07jLE`1hVUl0O9QO07bHH01kW5`0O9iH07NMFP1kX5P0OjEG07VL
G01nXUT0Nj1J07>DI025XEP0QIUH07bFFP20UeH0OieH07RUG`1jXF80MIaV07FSH`1fYe`0LZYI06N^
F@1H[Uh0D:eN05V[E@1YVT@0JgPa05mO9P1?ER<0BDlP04ED8@11ERD0?dTL038_4@0202<F1P050185
0@0600000`0000<0000200000`01000;000000`0oooo000:0?oooaX000000P0200006P030@000P00
00@000050@001@8000D100060P002@8100X30@0?1`803PD200`40@0=10003@@201TL5`0L8R806bLb
01P/B00B;EX03BiV00DKM@034H000@N@0043XP000;l0002n2P000;d09P000:/0002C0001OP004JX0
3AfC01HQT00N98L0:2^1034^O`0b;G`0<3:002/iOP0/?G<0=D5M03e0B@11=b`0=bDC02TG200T50L0
91<7028C1P0P3P@0:QH<02dQ7`0[:Cl07Am[00L<W0083ih00A>c004?]`002[X000nh000F]P006[@0
01jc000W/@008;<001Jg0P005KL09`006;H00Ajc00Y1XP0>BI`054bG01M9U@0IAIH06T2F01m7TP0Y
CXT0:df902aAQP0]DhD0;e:5031<Q00^BHL0<df203ECP00bCh@0<dN403=:PP0[BXD0;DUo0357M`0/
AWh0;dEi03I6M`0bAWX0=D1m03@mP@0X?HT0;Sao0350P00T>Xd0;c^5038lN`0R:X@091f902LNL002
01XUPP0W02/^M00U;Vl092mc03<hK`0/<Wh0<2f203/bLP0Y<WL0=SQX02hfL00W:IH0=SYe02lgJ`0a
=W80:CQh02D_R`0d<7`0:Rf003<`P00`<gd092^503@/MP0U:i00>2f603TiM00Q;IP0?T1b02aFMP0j
GX@0FFU/06AdG@1TKeT0JUYK05UVKP1EF7D0DU5e04E4P01=BVT0@D230080BTAg02L0BTB20510N`1:
>X<0ADUl045=P`1:G7T0B6ak05R0J`1XP600MH1J07N0E`1cP5`0MXIK07bBE`1iUeH0QXM;08en@02B
KB/0SVLX08Ei=01mNCT0MH10085d=@20IbX0PE/V07aI9P1nFC40N6a807IWDP1YG5l0GVUY05M/L@1:
MGD0BW5d03mLN`0kFH00>eac03iKM00lEGX00P0jEG`09`10FgP0?eai04ENN015Hh00@6R003iTP`16
H8@0AU^6041SQP0oIHH0@fB703mPR00kK8H0?WJ204=eP016L840CFMo04=PR00oHhP0>e:>04EfNP1J
SFH0MIAD08>=A@2:QD00R80m089j?022KBl0PV8W081N901nHBP0OfHZ081/<01mK3H0NVD[079G8@1]
D1l0KU<M079G8002071H8P0W07=K8@1gGR40OV4S08IY:`2<N400O7e>069/G`1BFF/0B55Z049;JP0o
@fH0>d9Z03m=L@10E7`0@eml04I[MP1AM6h0EgMX05YhJ01HLfT0D6Y_04IUM012J7T0?fQn03ebO@0n
N7P0AWie04j4K01KRf40HHmG05f@F@1ITEd0DheT05:9IP1BRVD0FHmR05bBH01PTUh0GY5Q0080FheS
02L0EhUU05N8IP1GRFP0FHUW05Z=I@1SSf40JI9J06REG01SV5h0I9EM06bGF@1`VeH0KIYI066HH01J
UfL0H9]T06ROG`1]XE/0MZ9H07ZRE`1iXUL0OJ5C08>QC`25WTl0QYeA082MDP29WD`0R9a>07nMD`29
Xdl0Rj=:08ZOC02:WT`0SYE<092ACP2:Se80RhmB08V@D`29UE800P29UU409`26TU00PiQA086GEP1h
UEh0NYQO07ZGGP1iV5/0O9]H07NJF`1iX5L0P:AE07^MF`1hY5X0Li]N06Z1KP1lV5X0PIQH07RBG@21
TUL0Pi5E08>KF`21Uf40NiAU07RJHP1hWel0MZUM06f^F01J/Ed0C[1R05>[G01SWT`0K8<h06AZ;01E
GBD0Be4O04EA8014ER@0A4XK03Pf4P0202TS2`0501P>1@080`000@000040000200000P0300000`02
0000000000000009000000`0oooo000:0?oooaX0000000L00P000081000200000P0000@100030@00
1P8000801`<001D02@<100h80P0@20<040P300`60P0<10003@D1018X:P0@;3d03BaB00`VK@078H40
11n;004B/@001kX0006m0000_@000;l0002f0000]`000;X02P000;d090000:/0002l00HLZ`0:;Y`0
22nI018XUP0R6XX0:aF703DQQ00W>8d053jA01HnP@0VAW40>4UA04@h;00m:AH0=R8?02hM300X60P0
8A0401h@100P3`D09R0F02DTAP0<58D02aV80045^@011;X000>l0009^`003kP001Ff000O]0008k80
01be000?^@8001>h02L001be004T/@0<AYl03dbK019:V@0C@i/043^M01DdWP0SA9409D>A02DmT@0X
B8`09db;02U8R`0]B8X0:dR902m=QP0eEH80<Tj40392QP0eCH<0;4b802]4R`0`BXH0;DV702m3RP0i
Bh40<DZ602i3R@0aB8L0:T>=02/jT00a@hL08Sb<02LjR@0c>GT082V302/VQ@0]9FL00P0M;8<09`0X
;X009R]h024_U@0j?8D0;cB?030[S00h9h00:Rf;03@kP00b?G<0:RnA03/iO00^<8H0;3BC02m2Q00X
<hD0=B^302/ZS@0_<8`0;3N902DXV00g<h40:bn:03T^QP0j>7L08RNN03`nN`0PC7h0;Tj:04]TL`1A
P6`0H7AO06eNF01SJF@0GEe[05Y;K`1@@gL0Ed]]04]8NP02059BLP0W04]CO@1BDWD0CDek04U=NP0n
B8D0BE1l04IKP01?MWD0Fh1/06f3HP1iPET0N81J07B0H020QE<0OY1B08B7B027P480TWPd08iV:025
JR/0OFda07Ed>`1kIbh0MU@Q06m<7@1]Cb40M5DW079]@01hMDP0KE]J05EHL@1?GgD0Bfah04QfMP12
Igd0@fAh041OL010GG40@EU]0080?5Mf02L0@5Mk04=FN@19G7D0Bf9k04AVP014Hh00Aef104EJQ`10
GHP0?eb703eIR`0iF8h0?gB104R3N01>PgH0Dh9c05ElM@1=M7`0BWEn049SQP1=P7H0GY5T07BEE020
SDL0RX5008Ik>021N3H0OF/^07mQ9P1jF240O5HR07eJ8`1lHBH0Nf8Y07QM901`Eb@0JUPS06aG901]
FB000P1/EB009`1dEb00MEdQ07YN8`22JBP0S7Hg07mjC01_Ke`0FF1]04=EP00oCXH0>DR:0357S00c
AhX0<dZ803AJQP0jJh40A7]k04]lL`1AN700C6Ie04UJN`13E800?U^003QNQ00fK840=7F103n0N01:
Rf/0FI=P06BHE`1NUET0D9AU046=L`0jS7L0?Xig04N@LP1>S6`0D8e/052;KP0204Z;L00W04R5M016
Q7@0AhEc04^9K`1CSVP0I9EO06fJG01WV5`0GiQP05fLH@1YWUd0KZ=I06^QFP1MVfD0D9A^05JHJ01Q
Wf<0Ij1O076TFP1gYET0MJQG07bSE@25XE40SIe@08JOC`21Xe40S9i;08VLC@1nWU80QZEA08JWD020
YE40PYiB08bGCP2AUT/0Si5>092=C02=Sdl0RYMA0080RIY?02L0QYQB08:KD@21Ue@0N9AL07JHG@1h
VEl0MI]Q07ZJFP1kV5T0OI]G086SD`1jWU/0MjEK07FLI01[Ng00M9AP07ZIGP1iTUl0P95K08>;F`2;
U5`0Pi5O07n?H`1fUF<0N9aS07FSH01`[E`0GK9L04j`IP1>Zf<0GJ1A06b=?P1XMBl0FfHZ051F8P19
E240B5/T04QC7`11AQX00P0f<a<02P0S60P03`D000@0000300000P4000<0000600000`0000800000
0002004000L00000303oool000X0oooo6P0000050040000I00@000060@001`8000P20@0@20<04PL3
01<70`0B2@@04@/501890P0G91`062TR01/`;@0K>Ch05c]>01<iHP05;iP00Af]004?]`001K`000:m
0000_P000I40006C0000X@0;0000_@0S0000_0044jd022NN00`aV00L;900:2B102DNPP0a8WP0=beg
030gOP0Z=Gd0:3Qj02hnLP0o?f40B3Y;04Dk>@10<bH0=2@B02DB1`0M2`@07P/302DB2@0^6A`0;a`h
01LXQP0;99H01a^U00<;]@013;P001:g000M]0008k8002R`000W/0008k400P039;003P05;J`044>N
01=9VP0FC9L05dRG01Q2UP0F@9P07D6D02M6SP0WAhd09dR>02]@Q`0[EXH0;UN30P0fE7l05`0jF7h0
?5El03Y@OP0gCX00>55o03AAP@0bDH<0=df003U<P@0cBX<0>D^003A:QP0a@XL0=4N002m6O@0/?8T0
=d5i02e0M00/?W`0<c5]02T/I`0`;f80<2eM00809S5[02L0<2i]02lbO@0U=hl0=SV502hhP`0[:h40
<B^002TbR00c=WD0>3Ia02/fPP0j=gT0:c>902/dT00a@Gd0:C=k038^PP0a<8P0<c1l03@aLP0V8IL0
>b^202/VSP0d;8X0=3=j028UX00o>7/07T:90311R@11FG@0?F]h05iOJ@1aH5/0GVeW06AGI@1MDfd0
E4Qe05I:M`1<@Gh00P1DBWL09`1<@840Cdmi04A9P01;DWX0?cV<04Q8P@0oBhP0AVYk04ihM@1TP6D0
LH1L07=hG@1`P680PH1@0820C020P4T0OH1808V0@02:IBP0PV0W07eI901dGRP0LUPT06iA8@1/DR@0
KETY07AE9@1iG2`0Oe/b07eS@P1fI540HUeV059[LP1BLW00BgAc04UaL@16H7<0AEa_04MLJ`02045L
KP0W041HMP12GG/0AfAd04aWL`1=Ig@0BVIh04YXO`14IH40AFMn04ARQ00mHHP0>fR804N0OP1ESVl0
GhiX06:;I@1RS6L0GX]Y05Z:KP1BP7H0GHmX06^KF`1fUe80Ohe608V1?@25NCD0OG<e07i];`1nIBT0
O5dT07]J8P1gDAd0M54M075C7P1bER40KUHT06eO:@1^GBT0KeDO0080L58M02L0M5DN07AF7P1gFR00
P6LY08Ua=`21K4P0KfMF05eYHP1?Ifl0BF5g04=KO`13GGh0A5mm04QWN`17M7<0Bh1`05B0I01TPUd0
Ih1L05n0H@1HMFX0CVab04YXM@12GWX0@6=j045YO@19MGD0D89_05^;I01XUEH0L9E?06fCE01PTed0
E99X04bCJP1ATV/0E91X05fAH`1PT5l00P1LSf<09`1KRVD0G8QW05Z7IP1JRVH0I99Q072HF@1cUEL0
M9=E07>DE01eV5H0O9aB07nOC`1iWU<0KIQK06NGG@1[VUX0LIeH076MFP1iY5H0OZIB07nSDP1mXU<0
Q9e@08JLC023WE00PimB08bPC@2>Vd/0RJ1=08^VC029Wdh0QYY@08JGD@2<UD`0TIE:08nAB`2ASdT0
Shm=08NACP0208FID`0W08JHD@24VU40Q9]B07bFF@1cUeh0LIAO07:DH01eUe/0Ni=K07jGEP20WeD0
OImK07RQGP1fVV40KHQY07BEH@1iUe`0MI=R07V=GP25PUh0R8UN08::G`1kQF<0MY9S07NJHP1eWf@0
LJIO06J/GP1G[F40F:UP06:ODP1[SD40J7/g061]<01FHBP0DV4Y04eY;@1=J2/0B64X0080?dTM00<0
:b8;00d60P0200000P0200000`030000100000@0000;000000`0oooo000:0?oooah0000001X00@00
00D100060P0020<001090`0C2P@04@T301<90`0F3@H05a4701lM4@0J:1`07RXM01ld900J?CH064@o
01IAI008@H`00BN[000E]P002K/000Bm0000U0000YD000>@0001S@80002n2P000;d08P011[P00a2b
00XJZ`0Z;h`09CR:01PcS@0L<HL09Rb502dXR`0b<XP09S^;01/nR00NAHP09Sik02e3J`0kAdT0?3@Q
02TI2P0N3P@06P`201h<100T3`L0<Bl`02@cB@0E=6P03bZ700LDZ@024;800AJc000S/P009[4002Z_
000/[P00:jh200@/[00W014oWP0BA9/05TRI01Q:U`0H@iP06CnI01Q0V00M@i@09TB?02I9S@0VCh/0
;EF602iLP`0aG7l0=UIn03UFO`0hEgl0>e9m03M@P00bD880=e2003IDP@0aCh@0=dZ203I9Q00_BHP0
=dV403I6P`0_?HP0=dJ002m4LP0Z>XP0>Sah034kKP0]>XL0<RZ302PWR00];8P0;cAk0080:bn202L0
>36303/lP@0Q<ID0;SJ:02ThPP0N9i`0<S>=024bSP0`;hl0<cJ;02D`U@0`>H/0:SV>02H`U@0^>h80
8RfC03<hS00b=hL0:bZC03@_I@0T6iL0?RB302DUT@0X:Y@0<C9m02HSX012=7h07CVA03<fRP0nDGH0
;Uj305IKKP1/JF40HWET06]HGP1QG6/0GUM^05YDL@1<AG`00P1FCWH09`16@h40D5Mg04IEOP1>IWD0
AE>004EBP@0kBH`0AEZ204MTP01KLVl0I81V07egE01lMe@0PgQ:07f0CP1lP4X0NWI9081b@022G2X0
OeDO07aA801eFBH0LE<S06YE9P1[GR/0KFDc071N:`1aGb/0NEXZ071/>`1bM4@0HFMN04YWO01;IWD0
@Fah04EdM012H7P0@Eaf03mML00203]MM`0W03]MN00kH7/0@69i04MRM`19IGD0C6]d04i`M01:LWX0
C6mh04IZP@0oJXD0@72104f6M@1HUf/0I9UV06^GH@1aUUd0LYQL06bFH@1XTVD0JiUO07NLE01nV4`0
PHe608R1@026Mc@0PW0_08=Y;01oHbL0NeXQ07QI8@1aCQ/0KdTJ06a5601[BQ`0KddM075?7`1_DR00
Ke0J0080LU0K02L0ME0J07AD7P1kFB40O6T/08=b@01mGDP0IEaM04m[HP1>KFH0C6Ea04=LO`10GGd0
Aemm04eaL`1>P6`0EX5T05V2GP1SQe/0HXQJ05f2H01DP6H0CX1]04Q`M014H7X0?ER003IDQP0hFhD0
>V6504=mN01MTF80MiQA07fIB`1hVE80IieK05bJI@1AT6X0CI9[056EJ01GVVD00P1LVF809`1PUF00
Gi=S05Z=H`1ISV@0J95L07NGD`1cTUD0M99E07RJD`1mWE80PZ1?086MD@1gV5L0Ii5O06ZDG@1]VU/0
LIiE07BKEP1kY5D0PJQA082UD023Xe00Qim;08NPC@24WU40PJ1@08VRB`2?XDP0SZE:08fVB`2<XDh0
R9M?08>HE@27VDh0S9U>08ZJD02<VDd0SII<08BGD@0207^QE`0W07jPE025Xe80QIiB07fGEP1]Uf80
Ji1R06jBH@1^Uf00LY5P07fGF020WeX0OieK07JKG`1^VV@0KY5V07>LI@1eVf<0K9EV06n>IP1lOF80
PH=J07f9H01gP6P0KhYY07:EJP1`VfT0KimT06JWH01JZV@0FZIQ06FODP1YSd@0Iglj065b=01HJb/0
E6/_051e<`1<N3D0B7Dd0080@U`V00<0<BP>01080P0100000P0200000`040000104000<000020040
0080000000<00@000000000000001000000<0?ooo`002P3ooolO000000800`0000<0108000/50P0<
1P800P0=1`<05P0B2P@04Ph501`O5P0I:B<08B`M024^7P0N>2h0:4`m02U?BP0UBVD083j4020dT`0J
:Yd00aZ`004EU0014ID00@VD0005P@000Y80002?0000U`000:`80000_@0R0001_@000[/01PZa02D]
R@0U?HP084B:020mQ@0T;h@0:bZ103@bO`0c?h40:D9o02I0Q00/>7T0;cQc0410G01:A4@0C3Xc04<V
700a5`/08`h4020?100T6Ph09QlO020V=P0Q:UH07bEn01PTT00A=I/03CNQ00XgY008>:D01SVU00Hi
YP804D2M02L04dFJ01=7V@0HBIH06dZD01Y4U@0K?iD07TBB0214T00XA8d0;4^902eAQP0`EH<0<EV0
03=JOP0fEGl0>UAn03]FN`0lE7/0>5An03IBOP0jDg/0>E=j03=<O`0dBH80=D^403=;Q00iCH00=dio
03A:NP0lBf`0=dIW02hoN`0i>gP0<CYa02hgO`0c<H<0;36702hcPP0g=7T00P0a=H<09`0l>7l0?3ie
02PfR00d=H00<cQd02HfP`0a<GD09Rj0034bSP0f>HP0;2n@03LhNP0d>gX0<cN003`oHP0Z<7P0<3Ma
02`fN00Y;9@0;baa020^R@0a:h<092ZF02/ZU@0f=7h09BjK03ddOP0Q=H`0?3>604A8M@0^D8T0EUUc
05YWI`1JGV/0LDMF05IELP1NCFd0G5Ya04e9N`0205EDM@0W0459Q01>FgT0Aemn05EfL015N7L0AV1n
03M1TP0k@Hd0?cZ?04iBNP1CEWH0NGQF07icBP24LDT0MViF07MaBP1_JDT0LFY007QJ<P1iEB<0NUPU
07=Z=@1^Hc00IfDd06AT=@1QJC/0I6Df06UQ<P1`GRd0LfHc07UT>@1`K4T0HgAK05eXIP1@KFl0EWAW
04mdK01>L6T0B6][0080@fYY02L0@VU]045XL`11H7l0Aeeg04USL`1?J740DFee04e^N@1=L7P0Bfik
04I]O`1;LGd0DXQc05VCK01SUfL0K9YP07ZIFP21V5L0NYeH07JLFP1gWUT0NYaC08>GB`23S4@0QX90
08Qg<`24KR`0Pf`/07]U:P1iGR@0METT06]@7P1VBa/0HdLI06I96P1XBA/0KdLL06a=701bCQT00P1a
DA`09`1_DQ`0LUXP07QO9@1gLCL0MWE007iQA`1WIUh0E6aL04mVE`1;HVP0@Umj045MOP13G7h0C6i`
05R0J@1NREl0H8YM066:FP1MQe`0F8AS05B5J@1;P6`0AgMb04A/M`13HW/0?EN3039BS00[CY80<6V:
04B9N01UU5h0NYQ>07jFCP1iVU00K9QH05b<H01DSVP0C9AX052LJ@0205jLH`0W06:HG`1NUf<0GI=T
05fCH`1WUEl0MIEF07N>D`1hS540OY5@086GD025WDd0PiY?07FFEP1RSFH0II=P06JKFP1eWU@0OJ5C
07nVDP1oZ5<0OZUA08FVC`28Xdl0RJ9@08NPC`25XDl0QZ=>08jQB`2>XdX0S:I<08ZSD025Ve80PI]F
07nNE@29Ue40RiE@08RJD027UU00PYAD0080OY]E02L0OYiE08BND@28VDl0P9AE07>DG01gU5d0LiEN
072EG`1eT5d0O9QH086MEP20UE/0Mi9O07FDG`1bU5h0M9QR07JIH01dTf@0N99Q07]nH021RUD0OhaR
07MjJ@1aP6`0LXeZ07FFJ01dW6<0J:IT05fYI`1OYV80J9mA06Z?@P1VOcX0GG0d05YY;01HKbh0E7/f
04n2?019P3X00P15HBP0100_9Ph03`H100810002000400@10003008100020000000000P00000303o
ool000X0oooo7P0000020040000L00@000060@001P<100T30P0<10803@D200l80`0I5@`06R0N01H/
;`0P;B<08RTL02<c:`0Y@S/0<4Li03M<@00iEE<0>EQQ03=GK`0>AYL013NG00<RU@0149@000]n0007
OP000Vd0001W0000T@T0002m0240006k00P?X@0F9Y<07CF=02@oS@0Z?X@0:cJ202DaQ00[>X<0<cb0
03HhP00a=XH0<3j202XkP00[>gP0<Ce]03PmH`14?D@0?B`L02XE200P3@<0910702L@2@0]5A40<QhP
03//=`0k@eD0<daR02aDK`0UFG`07EN701ACT00BDY@00P0IEhl09`0IEXl06U>@01Y@S`0LCXl074f@
029;S@0SCHd094b<02U8RP0bC8@0=E2003=?P`0fDgl0=UIm03MFO@11FGP0@Eea03mLL`0oEgD0?UUa
03mELP10DG<0>4Ye03M7P00hC840=E1o03MAOP0jE7/0>U9c03a>J@0hBVX0;T=e03@mP00c?X00<3R2
03DlQ00a?HH0<3J203`iNP0203@hQ@0W03LdPP0h>GL0:CB403/gP00h?W@09dMm02l]M00R9gl0:RjD
03HfR@0/;H`0=cB003U0J@0nB7T0?TIN020[PP0V:h@092al02@[W00]9X/07S2J02`eSP0T;iP0:b^F
03TePP0T;9/0<C6102DbR`0o<HP0AD=h02loS01@DWH0BV]b04eFLP1[?EX0EEQa05a6I`1HGG00DEIg
0080G5e]02L0Bf9i055VM01@IGH0G7MZ05EmK01BMFh0?6>303YDS00m?hh0B4ei055JK01jP540O7=D
07i_C`1dL5P0MW5;075[A@1aI400LEdj06eN@01hF2T0Lf@a075U<@1ZJ3H0I60d05eT>@1OHSX0H6Pl
06MS=P1XK3T0Mf<d06M`B@1VP4l0FVaS045YNP1AL6`0AFed04Y_L010JGH00P0mJW809`12KVd0AVa^
04USM@17GgL0BF5g04aRN01;HgT0CFMj04e^O@1AKgL0Dfee05=aM01GOfl0Fha/06BBI`1aVEl0PiYF
08NKD022We<0Q:1D07jMDP20WDl0QII508::@P25P400RgHd08Q^;@23K2l0O6P^07UP:@1aFbL0KUHT
06IG9P1VDR@0HdlO06Q<701/CAd0KddM07=96@02075;700W075=7@1bDQh0MV8W075g>`1aMd00OFY0
07EkD01RLUP0EV9N051QI01:IfT0BFU`04QTKP1<Kf`0Eh1T06J:F@1[S5D0K8aE0667G@1KPV40EH1X
04aiL018N7D0AWm`04elK014KWT0?5Z3039:S`0iF8P0>fR504b0M01PSF40Ni5A07^DC`1hUTl0N91B
06^<EP1NRUl0EYAT0080FiUT02L0HIMP05nGH@1MU640FI9T05nBI01XSed0LX]H07J;E01iR580OI9>
086JCP1nVE00MY=F06J@G`1TUUd0J9YI06nME`1oXE40PJA>07fWD`1e[5D0OJUC08JXC`25Y540QJ9@
08>SD01oY5<0Qj5=08FSD@28Ydl0R:1@08JLD`25VE@0P9eF08BGDP26TU<0RIU@08FID024Te<00P23
Ue@09`1mWe@0P9mD08:IDP1mTUD0MIMK07^HE`1fVEh0LIMQ07BEG01lTeL0OiMD07nBG@1dR680MY=O
07FCH01]TFH0MYUS07NIH01gUf40NH]O082@F@1kSF<0MWaZ071oKP1bRFd0MIER07NMG@1ZXV80HJQX
06:XI01ZWU40JY5106Qo>01PL3<0FV`^05Yf<P1IQSX0CHe404V9@@0204IR;00502lT3P0<1@000P40
000000010000100200000`010000000000000007000000`0oooo000:0?oooad000000P0100000`01
0@000P0000D0000200H1000I00P30@091@804`d601HI400D8bH04b`g01h]9`0Q9aX09c0V020i?@0S
>cP09D0d02M<>P0YDT80<EiE01eOM@0?Ci402S2U00LMV0056H000aJC004<V@000Vh000640000_002
0000_@<0002n0`000;d08@000;T00@J_00@NYP08;9l05SFJ02Q0S00^@XL08Cj801a8SP0V?8H0<S63
03@eQ@0`AhH0:df402E3O@0Y>G80<3IU03e2F`1?@4D0E38/04TS6`0i5P`0;0l502<;0@0S2`D0;a/=
02lW4`0`=R00<4H_039D?P0/H5@07f1/01iTM@0201]SO`0W01]MR@0JEhd05e>=01IBT00FDI807U:>
01mAS@0OCHh08T>?02e8R00ZAX/0;4F8039:Q00fDH00>5En041KMP10G6X0?U]`04=IM@0oF6d0?UEa
03m@M`0gAgL0<TF303Q?O`0iD7X0>U1j03]HO@0jE7h0>Dih03Y>J@0]@GP0<T6003=3PP0^?X`0=dB3
03=4P`0b>XL0@Cmg0080>d1h02L0=cJ003XhMP0`>HH0?3em03Y0K@0W>6h0:RIb02DXOP0X<8/0;cR0
02LeP00d>VL0>T1K03i<J00l@f40:3YX02PcJP0W<7809Rb602/ZS00Q;9d0;CF602HeR00`;I40=S9a
02D/QP0c:GD09c6<03`eR013@WX0;cf:04e7M014FWT0EeI`065=H01CBg@0JC]M05=@M01@CGT00P1K
HFl09`1<K7H0E6eb04ePO01KN6/0Eh1Y05^0I@15P7<0?6f1039>S`0lBX<0AE2007:0E@1cNUD0NW9>
06m_EP1^L500KFM606]P@01YF3/0FUi0079E;01gFRH0M5lY06eW<P1PFS00Eehh05UR@01IId<0HfE0
06A[@@1fJCD0LVm006m`@P1XKe40H7=M05iZH01FK6H0DW1W04Q[K`0204=/L00W04MYL@1:K700D6a^
05AZJ`1FJFP0FfiV05IcJ`1INFT0HGeV065mJ01OPVL0H8AX06J7IP1/SEl0LiAM07VIF@25UU40RYE;
08bIC029W4`0R9]<08RLB02;Td00RHY008V0?P26M3@0PVXc08=/;`1lK3<0MV@/075R:`1YH2`0I6Db
06AL:@1TEB<0JDlP06e@701aDAd0LT`J0080KT`K02L0KE8N06YI8@1]IR`0JgLj06ef@01jJT00OWa8
06EcH01IHg00CEif04MPI017IF@0B65X04IVJP1@P6X0Hh]L06^AE@1/SU<0FHYP0525J014M7L0?F:1
03MWP@0fPG`0?hEa03ihN`0cEhP0;T2C02m2T`0`@I<0=Uf;04F2M@1YSEP0Oi5;08>ABP1nT4`0LHeD
05Z7H`1=RfX00P1:SV`09`1CTVL0E9AV05BEIP1BT6X0CH]^05>8K01PSF@0JY1L072>FP1aUUL0M9aE
07:IF@1YTed0Gi=R06:GH01YVUd0Kj9J07VWD`1iZ5<0MJYG06jZG01dZ5X0O:UE07bTE01lYE<0N:QE
07>WF@1iYEL0N:IH086VE027Xe40RYi@08NOCP25W580QiE@08N@D@2<Ud/0RII=08NDD00208FHCP0W
07fLE01lVeT0PIaE07jFE@1jVUL0OieF07JJG01fVF00NYMM07jBE`22V5<0P9ED07^<F`1lUeX0MYQO
072CHP1iVed0NYYP07ZGG01jTV00MhiS07^:IP1jOVX0LH1/06f9J`1eUF80MYUN06bNI@1UZ6P0IZQS
06bPD01]Td40JX0h06Ic<@1PN3<0Gh/l05NCA@1:UD`0B8Q30080AELV00<0:AX900P2000200002P01
0006000000`0oooo000:0?oooaX000000P0100008@030000100000D0000500001P0000D000050@00
1P8000L30@0>2@D04a<;018J500C928052`^01l[8`0S8aD0:2XL028f<00U=R/0:C8T02hh9P0fA300
?T/h03iDB00jF5l0=5Ad02U?N`0GA7@02SMf00<RMP0047X000JG0000_0020000[`D0002m0280002?
0000^@011ZT01AfQ00X]XP0G=i4083f;02HnR@0S@hH08dV<02]5Q00^>H40;SR10352P@0eAX40=D1n
038kM00]>F40;SIZ03XeJ`14=6@0Aci>04Hg;00g8A009Q05028=0P0V40<09AD902dN3@0c:AH0>CHP
03i4;P10CSl0?5E:0P0lG5D09`0mGf00?5mX03MOK@0aH740<VAf035RO00_GGl0;5N402eEP`0cE800
<E6303A?Q00fCX00>E=m03UFN@11Ef`0A5QW04EJJ@16F6/0@eM[045DK`12DVh0?4id03a>O`0mDGX0
?59h03a?N`0nEW`0>UIj03]BL00kDFX0=4Y]03I6K@0d@F`0;T1n03U4N`0hAW40=3em04DlJP0203Xj
K00W038hN@0k>WX0=3n103`lM@0m>6d09bUf02hZN@0X<840:2n802h_OP0Q<XD0<SEj03XlM@0h>W@0
>T9Z03M3I@0_>GD0:S9`02LYS00]<Xd08RJO030gQ00Y>G40<2f?03X]H`0R:I00;amm02HYS`0g<H/0
=C^002/cU019@7L0;D>:04Y?N`1MHV/0AeMi06DkH01GCFh0DdUd0080G5Y[02L0DF9d05aZKP1FI7D0
HGEV05^0J01WP5l0GX5R05>0KP13Jg`0@5R0049=O@1PM6@0LWYF081^B01[JU`0I6Y?06EO@@1TES`0
G50i05MF@01SDC00K58R07=@801]DB@0I4PS061:9`1NDc40GV1006IP?@1/J400MW0m06ek@@1eKc/0
H7E905^0EP1HIVL0@5am04=/M@0kGh400P11HG`09`0kEHH0@UUl04MMM01?HV/0EfYS05agGP1OP5h0
IH=N06R7H@1VRV80GY5U06>BHP1WT680L91M07JJF`1kW5L0RII@08jBC02@UTX0TIM808jHB029WDX0
T9I008Z>@@27PT40PgHg081b>01mKCH0Mfdl07A/=`1^IcD0J6Dc06=Y=01XGRX0Ie@Q06M=701ZCQ`0
KTlJ06i:600207195P0W071A7@1ZF280JUlW06QR;01aFBX0Oe8U08AU@01_I5P0GEmV05AUJ`1<G6<0
CEIN04UFI@19GW80D7Q_0666F`1_SDl0L91>06F>F01LRf40CH5]04IZMP13KgL0AX1d0526J`1APVT0
CW9_04MONP17EG`0BU1m04eXMP1DPfP0LHUB08J<BP27S4L0Pi1907V?CP1/SEL0HhYL0080GXUQ02L0
IHeK06RBF01YUeL0IIQO05bBIP1NTfL0IiIP06nGG01dTUX0NI5E07ZCD`1fVe80KiaH06NLGP1TWF<0
J:5O07>WEP1jZU40NZID07:XF@1YYF00LJEJ07FUF01kXET0OImC07fMD`1lWe<0OZAE07ZXEP20YUD0
QZ9@08JOC@2<W4`0RIY;08^EC02;TDh0RiI;08fDBP29U4X00P25U4h09`1oU5<0PYIG08>ID@25Te80
QIEA086GE01kTU/0NY=N07jCG01lSE/0P9QD08FGC`1kTUX0NYeI07NNG01eV640O9mL07fJG01oUE`0
O99P07^<H@1mS6D0O8EU07>3JP1/S6T0KYYT072KH`1/WVH0IZUX06Z/H01aYU<0M9U40768>`1[NcD0
HHDj05fHAP1@Wdl0@9]F04R7A00204=<8@0302<C1`070@000@0000<00@0000<00000008000020000
0P0100000`0000000@0000000005000000`0oooo000:0?oooaP0000000T00@0000<100030@000`40
00@100050@001P8000D0000400000P0500006P070P001P81010<1`0B6A803AhH010S7P0G;2@07bXO
02DO400T8Q<08C8U020`9@0S9QT0:2TI02/f9P0e>bD0?DDX03i?=@0nGd<0=fQH01mZL00;EH<00cFC
000KX0002j`0002m0P000:D40000_@0S0000_P0008l0002j0044X`025:<022BZ01HiV00O?h`06cN@
01XiT00P?Y<09dR<0212SP0J?9008Cj?02`eS@0i>8P0=4J5021:MP0L@GT08SQo02XaO@0jB6T0C5=;
05I5=@1=<1/0?A`=030B0`0[3`<09a@602lG2@0c6`/0>RDC04@e7019?R800P18A2P09`1<CS00CUDg
04YJ?016GD@0@VMB03m[G@0iIf`0<Umh02iPO00cGGh0=UQn03IAP00gCgl0>59n03MAN`0mCg@0@U9`
041DK@12DgD0@E5g03i?N@0oCgP0@5=i03]AO@0nD7h0?E1o03a>P00lF7l0>eR003YDP@0lF7X0=59f
03I5Q00d>6H0;3ee03E4P@0jAfP0=Sec044fK00203HaI@0W02dfQ`0l@Wl0=D6203LePP0k<g/0:Rf?
03DfRP0_>8@09bj<02//RP0T<8`0=Cf003i1M`0g=X00?cmY03]2I@0k@6h0<CI^02H]SP0b<WP09R^=
03<dPP0`=FL0<2md03L]H@0W<fX0=BIQ02HYOP0`:7l0;Bmo02TbU`19?gT0;dB:04U>NP1CGVh0EEIa
06e3F`1@BG00GTQZ0080G5YZ02L0EDed05mJK01GEW@0H79T05MdJ`1OP6<0GX9R0621I@18P7@0AFQl
04A@P@19HWL0Gg5T08AZA01[IET0HFI>061L@P1QE3`0HTL[06129@1Q@R40I4<O06e3701Z@AT0IShE
060k601JAR<0FE/j05eP@@1JHT/0JW9606ikAP1jJSL0JW5506AgB`1PIed0C6I_04aZK016Kg<00P1<
JVd09`14GgP0AfQf04i_JP1GMF00GgYI065nE`1RP5X0IH5L06B5H@1VQf80IHmS06FEH@1ZUEl0KYYM
07VLEP24VU40S9A>096BBP2BU4H0UIA608nFAP2:W4X0SYE308R=@026PT00PgTj07ma=`1kJ380Mg0j
07I_=`1`Ic80JF0]06YP;P1XF2<0JE8M06M86`1[BQT0KTdI06m:6P02079;600W071>6`1^Db00ITlN
06I:701U@AD0LD4F089H>@1aEUD0G5UZ04eTL@1;GGH0AU1e04=CMP11EWd0@Vme0563I`1PR5L0Jh]=
06^@D01RTUH0ChMX04QeK`19L780BWId04b0K`1?PV`0CgmZ04YdL018JWH0A65k04McMP1@PfP0JX]G
08>CC029TDP0QI5807fCBP1dU540JXaF0080HHML02L0I8UJ06N@EP1/UeD0IYMK05n@I`1MV6L0GiiT
06RLH@1^TUX0MI5F07JDE`1gWU@0Kj=I06VQH01KVfD0Gj9U06^YG01dZ5L0MJQI076[G01]YU`0LjMI
07RVF01lXEL0PYiA07nPD01oXE00Oj=@07jSD@26XD`0RZ9<08ZJB`2?V4P0RiM808^FC029TTd0QI9@
08RCB`28TD`00P23Tdd09`26T4l0Q9AB08REC`28Te40Q9E@082ID`1iUE/0OiIH07jJF01jTeh0OI]F
07nIE@1jUe`0OImH07VMG01dWF00N:1O07ZPGP21VU`0O9AM07^?I@1kT6@0NHmT07F;I`1[V6T0JZ=V
06RVI@1XYVT0IZ]Y072`H01d[eP0MJM?07>F@`1/R3l0Hhm005VMC@1<XE@0A9MB04ai>`02040m6@04
01h=1@070@00100000D000D00`0000@00P000000000000000@001P00000<0?ooo`002P3oool70000
00<00@003P0000001@0100000P40008100010@000`0000<01@0001d00`000080000200001040018;
200D5a@04B<U014V9@0E9b006B/S020[8P0R8A<081hA02<Z6`0R:A`091lA02HQ4@0Y;Q`0<3@M03Hf
7P0h?b@0>d/^04EI?@0mIUL0;f1a02=?R00H?YT0436O00DJR0020049T@0W0001X`000;00002m0000
_@000:<0002?0000^P000i`000bK00DMW`0I>i006C^?01PiT00I>9@07cf=0254RP0K@Xd05d2@0214
T00^?hH0<3b402i4R00]C8@0;TQm038jL`0[<F40<cYH04=2H01?@F<0CdID04Xi<@0l9140;1@602XA
0`0V50D0:1@602lO2P0c8`d0=bLA0080>B/A02L0?BhD040e6@16?a/0ADHT04QB;`18Fc/0BUe;04EM
GP10HFH0@FEZ04=RK`0nGGL0?eeh03iMN@0jFWT0?5=h03iDM00hDG@0?59i03eBO00kD7`0?E9m03mD
N`0lDWX0?e=e041DL00oE7L0@5Mj03mGO00lD7/0?e=d03Q<KP0j@FH0=CaZ02lnM`0g@g80>d=Y03=0
KP0n?eh00P0h@6P09`0]@H40?D1d03PmM@0g>WT0@3me03<nQ00i?7d0<can02lcQ00d=X80;3^503Ln
L`0i?6h0<CEo03diLP0h>W<0>T1_03Q0KP0V<Gl0<BUT02H]N00_:XX0:bV002/[P`0`=Vh08c:0044e
L00]<8@0<B6402hSN00/<IH0Ad1l02lnS01<BG/0AEUi04a@N@1_CUd0D5Ec06E<IP0206=TIP0W05]K
J`1UGfD0Ff1^05i]J@1CJG40GH1V05j2I01TPV40FH1X05IbLP17FX00AUml05YSKP28K4L0JVMF06MU
BP1QF4@0Gdlk05m08`1L=100FC@D05Pj7@1N?200IC`I06M0601S<a80Fc4D05a08@1PC3D0Fei206M^
A01`OD@0NF/e06]c@`1XMDT0Ef]K03ibLP16L6d0?fih0080CG=[02L0@61m04Q[L01=LVL0E7YQ05^0
F`1NP5X0H7mP06:0H@1OP680IhUO06R>H@1YUV00KIML076NF`1lXED0QYU@08fCB`2?SdT0T8i609>A
A@2>UDH0RiY908ZEA@28Rd80Qh5008Ef=P21Jbl0NVH[07QZ;`1dIbd0KF8/06UI9@1XER80ITlM06Y<
6`1YAaP0JdLG06e<5`1cCQ`00P1aCa`09`1[C1X0J4PG060o501L>0l0G3P@06Xo5020FS80MVM=069[
I@1HJF/0DVE`04eSM`16Hg/0@f9k04EdM`1=Q6X0HHMG07:<C01fS4L0Lha>06F=F01RQEd0G81R05]n
IP1IPVL0D8AX05>6I`1@PV`0Bga`045hM`15PWH0E8QW06ZCEP1oUdh0QiE:08NCBP24TTP0NiA:07J<
CP0206Z9EP0W06Z<E@1^T5D0MIIB07JIE01`UE`0JYUP06FOG`1ZVed0KI9I07N=D`1gU5<0MiaD076R
F01^XUd0HieU062PI@1WYV40JJUM06n_G01a/5h0Kk1L07R[F@1jZ5P0Nj=F082OD01mWU80P:9A08:O
C`23WTd0SYa8096JA@2?UTX0T9=5092DAP2=TdT0R95>08F?E@28TDd0RI=:0080RY5702L0R99;08JF
D@28V4l0R9EA08FEC`21Ue80PXmD082CDP1mUU@0NYAK07RHF@1lVUL0NYEL07RKF`1iVU/0MIYR07JL
H01mXeh0PYeL07fHG`1jU680NIEV07NAI@1hSf<0M9QR07:QI@1[ZfD0J:YW06N/J01_/F00M;9I07NZ
E@1cW4/0J9M605fMB@1?YED0AJAJ04BCC`1:JS400P0h;Q400`0H2P801P0000<0000200<000800000
00<00@000000000200000P0000000`010000000000000004000000`0oooo000:0?ooo`H000001002
0@000`01000000000000000;00000003004000020@000P4000@00P000P010000700000000@00010C
400?6Q`042@^00dY@@0C;3L06BhV01/^9P0L;RL07B@H01/L3`0S8Q808R@E02@K3@0R6`d09RPE02T_
6P0_;aT0=C@M03a0:@13BBh0BEDg04]LB@16IU/0>fY_029MM@0DBgX200PZP@0W0047RP0009/0002m
0000_@000:<0002?0000^P000YD000RA01@_S@0D=8l04CF<01LiS`0K>IH07Sn>01a0RP0F>Y<05cJI
0211U00ZBX/08d>:020oS`0V?9@0<cZ;03M1P00U?6`07SUP02PhO00c=7h0>4=j045?EP1:?R`0@R@A
03XJ200a5`P0<AP9034K200d7`/0=24=0080=B<=02L0=bH>03hZ4P13<QH0@cLK04]0801?AB<0DdXZ
05]D=@1LGC`0FFE405Y/C`1FKeH0Cg1O04I`I`10JfX0?F9`03aJL`0gEGP0=e=m03QAO`0iD7d0>dmn
03a=O00lDWL0?E=^03iCJ@0nE6h0@UMk041BN@0lBWP0?TYe03Y4J@0h?gT0=d1o02hmR`0c?8@0>4Ag
02dmO@0i?h<00P0lC8009`0`AhX0?SUf03XhK00k@X40@dmh03]8P@0i@800=Sal03<kR@0j?X@0=D63
03HkN@0d=7P0;CB@03/jP00d>X@0=CN503I2K`0Y:gl0;R5]02`[I@0^9g<0:bF702`[U@0g=W00:Bf8
040aL00b<7P0<bEc030UJ00a=HP0Bca_0390RP1:AgT0AEIh04iBMP1QFF@0F5]Z06eCH00205aQJ00W
065HI`1SIF@0FFI_05MWL01:E7h0EWE`05F0K`1SPF80HH=T05ahK018GH00@eJ205QFLP25MTT0LV]:
06]J@P1QD400Gd`i05i2901N>1D0GS<B05Xf5P1O>a/0H3/I06@k6`1P;@l0ER0705PQ201H;a@0FdTU
06=T>P1WNT<0MVhg07Mb>P1aIC/0HFa>05MjFP1CME`0C7MV0080GGaJ02L0FGMS05mlF`1SO5D0IX1C
06R1D@1YPE@0J85G06V2F01[PUT0LXUH076AFP1`V5`0LIaJ07NRF@20X5@0Q9YB08fEC@2?TD/0Shi7
08f?AP2?UDH0UIQ409NB@02BR400RX0m08Md=P22KS<0OV/]07AX;01_GbT0JeTU06M=7`1XBa`0I4LI
06E56@1V@QL0JD@G06a8601`BAP00P1_BQT09`1ZAAP0J4HG05dn4`1O>A00Gc/A06Y35`21GB/0MGa8
06QoH01QLVH0F6I[055aLP1;MW@0A75i04EgM017P6h0GhEK07F<B020R480OXU407R9AP1gR4X0L8I=
06J4E@1OQ5`0FHQP05Z:H`1DRFH0CH=`04J4N017R740Fi1O072LEP1oWU00PYY=082EC@1oTDd0Oi=<
07jDC00207^BC@0W07VED01hUU00PYM=08FJC`20WE00NYiD07>OF`1`W5/0LiEK07NAEP1nV5@0OZ5B
07NZE@1gYUH0LJIG06RSH01RXf80HZQQ06RZGP1[Ze/0LZ]J07Z[EP1oYe<0Oj9C086MC`20X4l0P9m@
08RNC`29VTX0TiM709JDA02BU4@0UI9209FB@@2>TT@0S8m908N?CP27TT/0SI560080THm302L0RiA9
08VDC029U4h0RIE=08JCC029Tdd0Qi1?07b=E01kTE40N99H07FGG01hVUX0N9EK076EHP1eVed0MIUP
07ZIF`21We/0Pj9K07jMG01fVV80LIMW07BEI@1kTf80OIUN07RQG`1cZV40K:]T06R^IP1/]640L[AI
07J_E@1dYDd0J:5@05JVE@1:Z5`0AZ5H04J:B01:FbT00P0c8``0100F1P401000008000020@020040
00800P0000<00`000080000100002000000<0?ooo`002P3oool5000000800P401001000<000000<0
0@0000@00P400080000300000P000P0100020000000K0080000?7Qh01RPj00L/C008:f005SE@020k
>00H>3<063@b01lY800K7Q4081l@028U5@0Q7Pl071T;028R4@0W:QT0:bLF02`[5`0]=b<0<D0Y03A4
;00jCSD0A5i0049^E@0ZKW80:FeY00806eR002L01QR@0002S`000;d0002m0000X`0008l0002j0001
SP000hh05b^D014aV00:;h/043>C01TfU00L@9<063f>01DcU00E;Il06cfD021=S00LBHh0646B020e
T`0]=HL0<d:102Q7NP0SAWL0;Sj103@dMP0d>780ACeW05<iEP1G>D00DcLV04LX4P0j70X0<QP8030K
2`0_6`/00P0a70X09`0d80/0>2D>03/]4P10<Q@0@CLF04De5`19=aH0D3/D05Q3701HCR80FePW05]O
<01IJc/0DW5:04YaF@15K6L0@VE`03iOM@0gFG`0=EIn03IEO`0gCgd0>Tmj03i@L`0mD700?E9Y03aF
K@10FGX0?EEh03e>L00oBF@0>DAZ03Q6Q00iBHD0<4B703I5P010B6l0>4=f03m6P002049<M00W03M8
IP0m?E`0?3mU03a4M@17BVL0@DM]03hnM011?7L0?Sb20450NP0nAVl0>CeX03TlK00a>h@0?C]l03Ph
MP0e=H00>3Ed02`UPP0b9gl0<2a`03@XIP0`:7D0<RND03l/M00Z98d0?RIj02h/N`0i:WL0=2I`038`
S015<Vd0;cb904M4O@0lCg`0ATmn059RK@1:JGL0JEAQ0080E5m`02L0GE5Z061TI`1DIG40FFU]04MR
O@1KP6P0GHAV06J2G`1QP640HX1R05AlL01;IWT0EeYb081iC01eJDL0K5Y006AC>`1QC2h0HD8Q05To
6`1M>QL0HS/H064o6@1M>QP0H3`J05da4P1F8@L0BAT404LM201>:Q<0H4`V06I[>P1cKcH0N7Pk07MP
<@1TK4L0GW]:05YgD01BO5d00P1PP5809`1JPET0IX9?06V5C@1_QTh0KXE>06n5C@1^Pd`0KhE?06n4
E01fQe@0NI5F07VGE@1lWEH0OiiE08BND@22VE<0RiI<08bCC02=T4T0Si5409:C@P2HUT40VY9009^5
@02@P400QGLl081g@01oKc@0NF8X071I8P1YD240IDLI0696601P@aH0H48G0653601T@aL0HD4G0653
500206=04`0W068n501M@QH0GChC05/k4P1Q@A<0KDTI085R9P20P400KH1H065aI`1CHGH0CG9e04b0
L`14OW@0@g]c04IjL`1GPF80KHi>07V;A021Qd<0PXI00826@01mQD00Mh9306j4C01PQEL0G8UR05>9
J@1;Q7<0B89i04R;K`1OU6<0L9mE07jQC`1nVe40NIEB076BDP1iUdh0P9U<0080P9Y?02L0OYU?07fH
C`22UTh0QY]=08:QC`1kXE<0NIeF072NF`1cV5/0MY5H07^HE@1nWE00OjEA07fWDP1cZ5H0IJIM05jO
IP1OY6D0HJUR06VXG@1`ZUP0MJQH07jYE@22Y500Pie?07^RE01mXe00PZA?08NQC@2?VTT0TiM409BD
@P2HTD00UHm0092?@P2:T4<0Q95<08>BB@2<T4800P2ASd809`2=TdP0RI=<08^FB`29V4d0R9A>08ND
C@25Se40P7]J086?D`1jTU@0NI9K07ZIF@1gU5d0KH]V07JLF`1kW5H0Pi]F08RNE@24X5H0OIiK07NO
G`1`WFD0L9]V07NHH`1oW5l0OJ1L07NRG`1cYUh0KjYQ072`GP1d/UT0MZmE06fWDP1MZ5T0BjaQ04>Y
H010WEP0AHA404=?8`0202PJ2005010300050@000`0000<000020000100100000`0200000@000000
0007000000`0oooo000:0?ooo`@0000000<00@400081000200004P00000300400003000000010000
00000080000001`00@0000l@2`0D7bL01bQB00H[I007:WT05CQa01i4F@0G@dX05c`m020a:P0L9aX0
7bDG024Z7@0M91T07QX>028N400X:AP0:BPF02PU500/<1h0;S/V03<l9P0h@bX0@4`a04mK>`1>ID`0
AF9D0P0`CV@09`0A:g/021Ui0000_@000;d0002Z0000TP000900006>00D>S@0?8iH03S6I00/_QP0C
;h/06SJ701LjS00E>8P05c:A01T`VP0G?9@064:>01]1T00N?94093NA02@iRP0U@HT09DB;02Q2RP0d
?hP0<3f502<iQ`0[?8L0>S5j04LmK@1=EDd0D4<T03lU4@0e6PT0<1L802lH1`0202dH1`0W03TS300k
9Pd0?bH?03d]4@10;a<0@c0C04H^4@1<<Q@0D3TG05526P1HB1h0FDdS05eF:01SG340HF8k05iT@P1M
Jdd0FViI04e]IP12J740?F=c03]IM00kDWH0>E1b03Y>K@0mD6l0?E=c03mEMP0nDWD0?4a^03e:K00i
BG40=TUn03M9Q@0eBX80>DYj04==L010BVh0@TQm0080Adi_02L0>dMb0451MP0nA7d0=cj303lmMP0k
?7d0?Cb004Q1N`0m=HL0AD2003i3P00i>HD0?4E_0350N`0o?GH0>CAk03HaS`0j=hT0;bVD03XcRP0^
:h/0<Rb003H_JP0d;Wd0>bUc02HVU`0e9XT0:Rj003@WJ`0b96L0=32304LaF00^>H80@Sig03]5N`14
BH00DUm/04]UM@1YEUl00P1CDgD09`1OC6X0G69Z05IOL01IHVd0BfEh05n0I01URUl0IhEO05f0I@1O
PV@0Fh5V051gM01FHgD0NX1A07i_@01bFcT0IeD_06E67P1N?aX0FD0M05Lk6@1I>1L0GSXG05he4`1N
<a80G2h?05HY2`166@@0?a<104@C101?:@h0HTHM07=T<@1gNCX0NUh/06mW?01YLD80Gfi605YhCP02
06EkAP0W06F0D01YQDX0KXQ>07:7CP1/Qdd0LhM<07F6BP1gQDh0L8MC07F9EP1nS580OiMC07nMD`21
We40Pim?08>IC`2:Udd0SYI<08fDBP2CSd@0UIA109JI@P2JTT00VhA00921@028O400OGY007e]=P1e
Gb@0KU8N06M:701MAQP0GT<G05i6601QAaP0IDHH06935P1I?a80G3P@0080ESP@02L0F3P?05Pm501H
?A@0FCdC06104`1_BQP0P5hR08Il@01mP500KW1Q05eWL01GP6`0EhEX0563JP1=PFT0AH1^0564I01R
ReL0NHY:08B3@`2<Q400QX8k08>1?023P3`0Nh500725C`1ZQeH0I8YM05^9I`1BQV/0DhMY062?H`1/
W5X0O:5A082NCP20UE00NY=A086FC023VD`00P26Ud/09`27WT`0Qii:08NNB`23W4/0OYiA07RNE@1b
V5X0LIMK07:BF@1fSET0NIAH07ZHE01mWe<0O:AC07VWE01aYUP0KjMJ07>WF`1gYeP0NjUC07jZE01m
ZU<0PJYD08>XDP29Xd`0PZE@08BRCP27X4h0R:9<08fPB@2CUT<0UI=209RC@02ETd00T99008RA@`20
TdP0P99808^?A002096>@P0W096CAP2>UTP0SIM:08fHB`2?TT`0RY9:08VBC@22RUH0PIAB07ZHE01f
U5P0MiQE07>DGP1^TV80MI]G07bHDP29VTh0RIeA08>LEP21VeX0NY]L07BKH01^V6<0MiUR07^JGP20
Ve`0O9aK07^OG@1kYET0Mj]I07J]E@1d[5D0IjUF05F/G`15ZfH0?j5U03jCF013MSd0?48L00808A@6
00@02P<000<0000300000@001@0000000`010000000000400003004000@00000303oool000X0oooo
100000000`0100000P0000800003004001H0000001d00@0000L30@0C40/06Qla00HPK00397l00b6C
01d_QP0B?Wh03TYT01A6C00L?CX06S@/01da900J<bT062`W01hM4`0R70l09RXJ02D[6`0R9AH09B/J
02Th9@0]>B<0<cPR03/o9`13B2/0CE8d04]DB`020350K00W01H`N@000[X0002m0000_@000;D0002W
0000W0000XL00PFL00LKWP0:<IX02Rn501@YS00F<Xh04CRC00hbQ`0H:Y406bfK014lWP0>>iH05CFH
01`aVP0Q?IL06CfA01E4T`0H@iD09T6A03=1R00_AXL08TN:02M4SP0h>Gd0?Si]04I<H@1IDU40FT@j
04la7@107PT0;aD60080;aL502L0>b4<03hP300o90d0@2L?04DY3P109Pd0ARD?04LX401<;Q80C3HG
04dg5`1C>QL0EC`G05Y0601Q@Q/0GdPO06AF9P1[IcH0IWY<04ihI@14Kfd0?V1f03YCN`0iEWh0>EAo
03aEO`0kE7h0>U9n03YBO`0iDX00>E5n03M?O@0bB800=TN703U;PP0kAgl0AU9`045?I`15C7L00P17
EVl09`10CGX0A4Yo0457O00d?h<0>cam03TnO@0n@880B4Ek044nO`15AGh0@dEg03m5JP15Af@0?4IZ
0455I010@Vh0?SZ3048nNP0h>h40@SZ103@gO`0f<GT0=SIg03PmJ`0h=6X09R^?02/ZS@0Q;hD0:Qn1
03<RO00k<X80B3=I02hgQ@16=g80?3Ai04I1P@1AEg40ATim06aFH`0204iEN@0W065;JP1RI6P0GV5Y
06=YI@1CJG00HH1R06R4G@1_P5T0HH1V06Z0G01YP5l0F7]`059[MP1]P5L0N7Y507YP=01]F2/0K50U
06E77`1LA1h0FclJ05/j5P1L>1H0G34A05da4@1L;@h0Fc0@04hQ1`0m5@@0?14304<K1P1A:0d0JdTP
079Z<@1jGBP0MFXd071[=P1PK4@0FG=80080Jfm002L0I7i606R1B@1WRE00K8]C06b:E@1_RU@0Lh]>
07B7CP1aQe<0MhMF086:D@24Tdl0QIY@08>MDP21WE<0P9YC08bKC@2@UdX0SiE909FBA02EUD80U9Q4
09NC@@2IQT00S85008B1@01jNd00O6lf07MM901]C1d0I4LK05Y35`1I@QL0G4<H05m76@1RAaL0GT8E
05Xj4`1F=@h00P1?;`h09`1@<0d0CS4A04la3`1D>140Gc/C06i7601jFAh0R7Lf08B0B`1dKeh0GFi^
05b0J@1NRF80EXUQ0566HP1<QFT0BhEW05R9GP1]ST`0Q8Y208f4@02;Q3/0R88i08Z2<P25Pd00M8M<
0769E01aSE@0II5N05Z<I`1APfl0EhYZ06:GI01aX5H0P9m>086JC01nUTh0PiM:08VHA`0208ZEAP0=
08NMBP2:WD/0Qj1=082ODP1eWeD0KIaL06FFG`1YTeh0KYAJ072DF@1eTeL0NYMG07bME@0207ZUE00H
07VUE@1iXUH0NJEF07fVEP1nZe@0OjiE07Z^E`1l[UH0OjMB08NSC02:XT`0Q:1>08NQB`29XTX0RZ99
08nI@`2BTd40UYE009ND@02=UD00Ri=208BBAP20TdL0R9=50P2>TDD09`2>TT@0SIE908fFC02;UT`0
RI=<08ZCB02:TTT0QHm@07nFDP1nW580NY]C07bKD@1hUU@0N9EC086HCP28VTL0Sie608jNC029VU@0
QIUE086JF@1lV5`0MIMQ07JHH@1fVF40OYQK07^FFP1lVET0O:=G07NYE`1eZUH0L:aG066^G01>Zf80
?:5^03>CK@0eRE/0?6/k03@i5`0201T?1@0500H1000400001@0000D0000300000`02000200400004
008000030@000P00004000D00000303oool000X0oooo10000002004000@000000P01000>00000004
0040000000000@00000000800@0001d00P0000D20@0C3@X071Xh00@GP0036h/04R>E024/S00E?8P0
3TUc0198H`0M@UP08Cm;01dn?P0K?3X07C0b028Q600Q8A@08RlR02<`9P0S9QP09BTH02Lh9P0[>2@0
;C<O03@f8`0h?B@0@d8W04e9>`0203a3I00400/JY`021kH00@>j0001_@<0002n0200002?0000W`03
4XX022f700//P`0H88805Bb@00dgR`0;<HH06BJ;01hVS`0><Ih033NJ01HaV00Q<IL07CjF01LkTP0E
?YL06d2G02M8TP0YAXT09d>902Y7SP0`@h`0>DJ003I8MP0fC7<0?ded04E>I01BBD00BB/E03LI1`80
=a/702L0?al904DS2P1280/0@2<<044P3@0n7`T0?ah9040P2P129@d0ART?04T]401=<Q40D34@05@_
4@1I=a00F3PD06I56P1_FRP0MGE006R0D`1UMET0GW1P05AYJ01=JF/0AfAa041PM`0jHW/0>F1j03]K
O@0iFGX0>UAk03MBN`0bC840>TV303m<N`0lBGP0ATmZ04=8IP13BGL00P1:DW409`13Cg`0ATYn04A=
M`0i@W/0@D5m03e4N00j?H<0@dMo03a3N@13A7h0@TMn03XkPP11Ag00>TEa0459N`17D640@Cf20499
L@0l?GX0@3mo03DmQ`0i=h@0>d1o03@fR`0j@6`09bN602/]RP0Y;h00;1j<034RR@0l<G`0C3=P02he
R@18>Fh0>3Ac048lOP1;EFL0B51W065EG`0205AHM@0W06I9I01MEF/0HEUV06IfG@1HLF/0GgUS0660
HP1[PE`0G81U0760F01gP5D0GWU]04m^MP1NPf<0K81?07eQ<P1^EB/0K5@Z06M=9`1PAR<0HD<M06<o
6P1P>aL0GS@C05ld4@1N<@l0HSDC05<V2P106PD0>aH203L@0@0n5@<0FRL<06Q1601eER@0Lf`g079S
<01TI3`0GfI00080JF0c02L0Jfhl075m@P1/Qdl0L8aE06f=E`1`S5D0NH]C07Z;DP1fS5@0NhaC07j>
D024U540O9aC07fME`21VU80PiU?092GBP2FUDP0TYE709>BA@2AUDP0TY]809JD@P2@QT80Q89007ak
@01jMCh0N6@/075A7`1YAaT0FT4I05M36@1G@AH0F4<F05]3601J@AH0ESdC05Di4`1B=A800P1=:``0
9`1A9``0C2P=054Z301E<Ph0HC`B06]65@1hEQh0RG0`089gB@1`M5h0Hh1U06:5H@1SRe/0H8QJ05f5
F`1GQ600F8IN06>:EP1eSdL0Qh]008j5@02<PSd0RH4k08N2=`28Q3`0OHI607^9B`21S4/0NI=E076C
G01QSf<0FhaV05nCHP1/V5T0OIeA08:EC`24T4`0Ri5708f>A`02096?A@0W08jBB02@UDL0RiU=08JN
D01kWe@0LYiH06VDF`1aTeT0MI=E07NBD`1eSUH0NHiC082KD`1oXU00P:A>07bTC`1fXU<0LZAG07NV
D`1oYE80P:QD082ZE01oZU40PJQA08ZUC02=XDX0R:1<08VPBP29XTP0QJ5608^MAP2>Wd<0UiY009ZF
@02DTD00S99008VAA025TT<0R9E10080S99202L0SI9408fCA`2>UTT0RiU:08ZFB028UdD0RI=408BA
C@1mTU00PYU>07jMCP1kWDh0OIU<082FB@29V4@0SiY108nJ@`2>V4L0S9Y;08ZIC@24V5@0P9aK07ZB
G`1dTel0MYAM07fHFP1mVEP0P9QF086NEP21Ye40OjUC072ZE@1M[V00C:]X03JKLP0dSVT0>Ge=03Y@
:@0Y80`00P0@1`803P040@000P0000D0000400000`0000@1000200000@00000000010000104000<1
000300000@001@00000<0?ooo`002P3oool9000000@00@003@000000100100000000000000010002
004100800`4001/050/:020D?P0339H00Q6I01<NVP0T:I006CR?00]3P`0<@7/06cQg01djKP0FA5T0
5dE;020f?00U9al07RXM01lg;`0L<SH08RLL02<X6@0U=BT0:3LY02L`7P0/<1d0<SHO03Tg7@11>bD0
0P10ASh0100M=hP021:Z00<8]0010[X20000_P0Q0000U@000800001m008=KP07:7X03BV:01`JP@0C
8Y802c>=00/^QP0K8h`08An=00`TX@0;;Yh06BRH02L_U@0M?IL04CJE014cX00K=Id08DVF01a<U00G
@I<08T2F02m3S00gDH00;E9n02eAL`0bBg/0@DIX04QAH@1KC4P0Gc`Z0080E2P?02L0AB0:048O2P12
7@P0?Ad;03lN2@106@P0@AT704<K2@1380/0BbT=04T^3P1;;@l0CRL<050W2@1G:@X0FBl=05hh4@1[
Bad0NVXf07ImC`1fMUD0K7iF05ibH@1HM6D0Cg9[045`L@0hLWL0=g1h03QSNP0gFg`0>EMo03UDP@0h
DX00?4V003i;O@0hB7/0@DQY0411I00n@X000P15DGT09`10CgX0A4ai04UAJ@0mAg/0@DUo03m;L@0g
@880@ded03m6K013A7H0ADI^03a1P@15AW00?TAe04Q6LP1;CFT0@4Yf04Q=K011AGD0@d9_04=2K@14
A740B4]X04=0O`18BV80=Bei03T^MP0e;Vl0<b6703XUS@0i9XD0BRe/034dS013>fd0>cU_03llQ011
DVL0AU5h05Q7JP0204Y:NP0W06M2H@1@DG@0GU1[06YhG01JNVH0IH1N06V0G@1eQUH0KX]I07f9C@22
RTX0J81P05MgL@1TS600KHEB07e]>P1dF2X0LUDZ06U?9`1WB200JD0L068o6P1O?1H0G3PD05/f4`1Q
=a80I3`C05T[30187`L0?aT503XC100d3`<0@A@504/R2@1X>aP0IV@f06mI:P1VGSD0HF0e0080JE4W
02L0K5h^07M/=P1dP4H0N8M?076;EP1eSUL0N8mE07ZDE@1iU5<0Ni9B07jFDP1nUeD0NIYH07ZHEP20
V540Q9I?08nBB@2DSdH0THm608f@BP2:TdX0SIU;092EA`28SDT0PXM407el@01cKSL0L5dT06M86P1M
@AL0E48H05516@1B?AL0DCdE05<l501?>1D0CCLD04`j5P1<=1800P1<;@d09`1;9`X0CbT;058/2P1F
<`d0IT4C079=601iEah0QFT[085_@P1/LeX0IH5K06Z8F@1YQeD0JHED06:2E@1LPEP0HhIH06V=DP1j
Sd@0RXU008Z6?029Pc/0QX<j08N2>@29Q400OhI30869A@27S4P0QI=;07fHD01bUeX0HY=N05Z>I@1S
Teh0L9]J07fCD`1oSU<0R8i<08j=B`02092:B@0W08j;B@2AT4H0SIM908VJCP1nXE40MYmG06nGFP1b
U5H0NI9D07bGD`1gTUD0Mi9H07nOD`21YTl0QJM=08NXB@1nYdh0MjMB07JXD`20YE00Qj=>08BRD@21
YU40PjQ@08ZSC@2:XTX0RJ9<08VOBP27XTT0QZ1908bKA02?Vd40UIM009bE@02GTD00S99008N?@@28
TD80Ri900080SY9002L0SY=009:C@02@Td80T9U108nK@`28V4@0QiM2086>B`1nSDh0Q9=908FIA`22
VTL0QIY008bG@02AUT00U9Q009FG@02CUd80SiM408nKB029VE00OiQC07^GFP1gTe/0NIEJ07jHEP1m
WEL0P9eG07nREP22Ye40OjM@06fYF01F[fH0A:M`03BIK`0hRe/0@6Ti03@a5P0F30<00P050@020000
00050040000200000P000080000100000`000000100400000`0000<000010005000000`0oooo000:
0?ooo`L0000000<00@000080000300000P02000=000000800@000`0000030040000L0080000A1`H0
7@`^00@6L`024X004Q^202<UM`0I<8003CV:00hfQ00O<G808cMS01M3I00HBUd08Se<02`f<`0U=Rh0
7c/d01df=00S;2008RXJ02Pe8`0Z=b@0:RdI02/Y5@0]<1X0;bhI03D[5`80=DPg00@0:TMW00hMX@03
2kH00@Bj0P000;h08@0009D0001h0001UP012YL00R:700lRUP0P5i404aVE00T]V00<:hL07An3024L
O@0<7I402bNM01/QV`0X;I@06SZJ014fU00F<Yd07SJE01a4S`0GA9<073jB02LkR`0Y?HL0;4Z2035?
P@0cCGh0=dMn03e4K@0kAg<0@eE]051GE@0205To:`0W04dT3@126PP0>AP503PH1P0k60L0?aL703`J
1`115`L0@b0:04PV3@1;9``0BbT>04XS2P1<90T0ERL:05PT2P1F<Q00H40H07]P;P1gME40NgEE06]g
GP1SK640H6MS065VH`1MJF80EVmT05EbI01CLVH0CW9[04Q]KP19K6d0BVY[04QOJP15DF/0@4UV03i4
G00m@6L0?4Am0080@T]_02L0?4]]045;L`1;CFL0?TEc04A7OP0oBfl0?41k04U9L016AUl0AdAa04M2
I@0l?7/0AD9k040nP@14@G`0ADQk03a5P@12BWP0?dUh04@nK`1=BUD0D5]_05IEF`17B7<0DdaH044f
J`11<fT0=be/03HWQ`10:h00=2>C04LYO00^=i80A3i^03TlK`0o>X<0A51Y041>O`1IDE/00P1EIEd0
9`1UDUD0D4ae06EAI@1WMf00H81T06UoF@1[PU`0NXU@07R?D@25RdD0Q8e70720G@1LP6T0KHaG07B3
C@1mM3/0NF8^075M<P1YF2d0Hd`Q05dm6@1I>aH0FSTG05Ti5P1I=aH0FCDC05`o5P1G:Ph0BQd6044F
1P0i5@<0<Q<303@@0P0h4040EBL;06Q5701]CB00K5/]06]I;00206Y=8`0;06iE9`1gGRT0NWi107N6
C01eRe@0M8]F07V=F01jTEL0MiIH07>IF01eVUX00P1gUeH06P1mVED0OiUD08VGBP2FSTH0UH]608f=
B02;STX0R8m:08^@B@2:STP0Oi1<0829@@1lM3L0M5dV06M;7P1L?aH0ECTC04lg501:=Q80Cc<A054c
4@1@;Pl0Bbl?04L^401<<a40Cc4A0P19;0`09`1<9`/0CbT;05H_2`1K=0h0JdHE07==6P1jF1d0Pf8W
07e[@01[MEH0K8AF0769DP1eRD/0L8E:06N2D@1OP5@0IXAC06Z<D@1kSTD0Q8a008Z9@026QS/0RH4i
08b0=P28Q3/0PHI308R6@P2;S480RIA808RHB`21VTl0KYUI062BI01VTEh0LIYH07bHDP1nU500R8i?
092;B`020969B@0W0929B@2ARd@0Si1808VGB`27WTh0Nj9C07BNEP1fVUD0NiQC07fME01nWe<0MYaF
07ZTE@1nYDl0QJE<08ZVBP29ZTd0OjQA07jXD026Ydh0RZ9;08NPCP27Wd`0Qj9<08RVC02;XTT0R:E:
08VSB@24X4X0QYm<08bMA`2BVD00U9M009ZE@02DUD00RiA008ZB@02;TD00SY500080TY5002L0TY=0
092D@02<Ud00SY]008fM@`2<W4@0RII108>@A`1oS4/0QY1008NC@025UT80RiI008fE?@2@U3d0U9I0
08nM@@2@WT@0T9Y3096JA02=VDP0RII;08>FDP21UE@0P9YD086HD024WE<0Q:9C08>UE021ZE80OJE@
06^ZE`1F[F<0@:=Z03VDH`11OdX0@58W02/O2`0?0`402000000010010@0000000040000100020080
00800@001@00000<0?ooo`002P3oool6000000800@0000@00P0000@100030@000P002P0000020040
00050080000300000P000080000100001@0000006`090P804PD=00D8?0034cl03ALi01dN@P0D9Vl0
432:01L]R`0Z;Fh0:SMS01PjL`0HAVl083mP02/nC00R@D807D0k01dj=00S<RD092hK02Pd7`0[=b40
:bdH02TW500Z;AT0;2dH034V5002038b8@0W02loA`0I=W`02bJP00<?/P000:H0002i0000U@000GD0
005k000;Q0008Xd03anC028HN@0E5G@02RF800`VR@0K66`061eU00dWN`0<9iH071nJ02H]U@0C=9l0
3bbK01lYV00T=i<05D2C01@iT`0N<YP0;SN?02LkRP0MAHh09DF;0312RP0hAHP0>4ic03ECK@0hFg<0
@UM]0080EE5H02L0Hd<j05/[5`1560H0>AD403XF1@0k6`P0?b0704DN1`1780P0@b<;04LQ2@179P`0
B2H:04dY2`1A:0`0DBD;054]3P1N>QH0MeTZ07YcC`1iN5D0J7iQ05m`IP1OK6<0HfQS06E]HP1TLf40
IWMO0660HP1KP6D0FX1R05R0HP1?MfL0A6Mc03eCOP0iCWX0>dYk03U4PP0h@8@00P0k@GL09`0hAfT0
@4Z004Q@LP0kB740?dUk04A?JP0lAGD0B4Ec0493H@16B6L0BDIK03i3M`1:AgD0@dIg04M5NP1<CFd0
@D5l04U;L019Cf40ATAO051@E`1@DVL0C4aO04A5I`14?V@0>cY[044kI`0g;g<0>2ed03haHP0a:ID0
@RV002lgT@0o@740>S]a04HiO@16AFX0?d2205AKG`0205=jIP0W06IRF018BGX0I4mX06EiH01RP6@0
Kh1I0762E`1kQU@0P8i?08R:B@29RT40Nh==06b4E`1gRTd0Oh55085f?020Ic00N5`_06]D:P1QAQh0
FcdG05Pd4`1I=a<0FC<C05Pb4`1K=A80FcTC05T/301@8PT0AaX503/I100h5080=`l203D@0P137@D0
ER/=06U15`1^G2P0J5DU0080I4lS02L0Ie8U075D901eKcL0M8=506n6DP1cReL0M8YH07F=F@1eSeX0
MI9J06nFGP1bUE/0NIQE08:HD@25Vdd0S9M909BAB@2BSDL0S8a808V?B@29T4T0SHe608f6A028RT@0
Pg`i07QP:01XCA`0GD<H05Hk501F>140Cc8A04l`3P1;:`h0CR/=04l[301=;0`0C2/>04h_3`1=<0l0
0P1<;@d09`1;;0`0CR/:05L^3@1O=a00J4@D06m<6@1bDQX0O5HR07]Q@01bM4h0MHI907b9AP1lQd80
NXI306^1C01UP4l0Ih1>06V7C@1kRd@0Q8U008J:@025R3d0QX8i08^1<`2;PST0QhE008V5@02;RD<0
R8i908ZDC@27Tdd0MiIH06RDH01]UeX0NIYC082GD01oU500QXe<08f<BP0208^9BP0W08f<B`2<T4P0
T91608jAB029UdX0Pie?07^ND01jW5@0O9iC07jRD@1kYE80NJAC07BUE`1hZ5<0OZ9B08JUC028Z4d0
Qj]<08JVCP29Z4h0SZE;096QA`2>YDP0RJM;08RVC02;XdX0Rj9908jQB02:X4P0RYi808fM@`2BV400
TYI009FE@02CUT00TYM008bD@02=U400Ti=00080VI100180V94l09BA@02CU400SYQ009>L@02DVD00
TXm008j=@02=S400Th`k08j=>`2=T400SI0m08ZA>`2:TCP0SiDl08jL@02CWD8209FI@@0C092HA@2>
UdP0QiI;082HCP22VU80PiaA08NND027Ydl0OjYE07V/EP1_YeP0I:IF05>VGP0oWF40@XeB04I/=P0j
>QP0814500P200020080000300400000000000000080000000H00`0000@1000300000P0000<00004
000300800003004000000000000000800000303oool000X0oooo1P0000000`0200000`0000810002
00@1000300<000010000000000H000000P0100000`0200000@000040000300800003004000000000
000000@0000001X00@6B00H7?`036B@020d?028D:P0B8G803bf901`VRP0^:FX0;S=]01X_P00I@7d0
8CUW02XmEP0P@U807TM60294?00/?cP0;Sdc02a1<`0^ACT0<D0e030i9`0[>280;C<M02`U5080<BTH
02L0<ST`0292E@0C?8001Q^Z0000T`000;<0002E0001Q`000Hl000^>00LVUP0@7I<08aYn01DDP@0<
78003R2D01XCS@0@7IL02bnE00/WV00N7Y/092jC00`^X@0<6j@091bD02PdRP0A?98043F;020[Q@0`
<XD09CB901U1T@0T@hP0<TAm02e0Q00aC7d0>U9e04A=M`1<AG400P1:Bg409`1CEf40HDXk04hX400l
5PD0?1P4048K20108@H0Aal504DO1`157PP0Aad804TQ2P1990X0E2L:050U301<80X0E2H;05P]301f
C2X0Ng5>07N0E@1SOV40GGQX05eaJ@1ML6L0HgIQ06J0H01YP5/0HX5O06:3G`1TP5`0IWMG06EbF@1Q
Jel0G6YT05EXI@1;J6P0AF9Z03mFL00204A:J`0W041<K013CgP0ADmc03U<L`0oCG00A4eY0498K`16
AFl0@TEP04=:J019CF40@4Ic04e8L01:AFL0AD5n04e<H@10@7T0BdmY04a;H@1:A7@0DE=M04I1O@13
@W40=c6703<gS`0Y<iH0<c>:03@aQ00b:HX0@S9I03LbN@0o;WD0;32C03`nL`0g>7P0B3Al04<oL00m
>h@0DEUY0080Bfm_02L0K6IC051CL@1/Feh0KGQL06UkF`1aPeL0M8AC07R3D@1kQU00QXI508V6@025
Q480OHM80869@`22P400PWXi085`=@1jHc00Je<Z06977P1P?aP0GCXD05Tf401I<Q40FS0>05Xa3`1M
=A<0Fbl@05T]401>7PT0?aL503TC100e4080;a41034C0@126`@0HSDB06]E8`1UC2000P1SC2<09`1T
DRL0J4/O06eG9@1`K3T0Jh9706j6C`1^ReT0KXQM07>3GP1dQU/0LHmL07VEF@1iUEP0PIQD08JJC`2;
UD/0SXe908b=BP2;Sd/0RY1708b?A02<R400Oh=408J4@022Jb`0KTlP05i55`1G?AD0ECXD05@f4P1@
<Q<0Cbh>04/W2`1=9`/0BbL;04/X2`1=9@/0BBT=04PY300204T[300W04l[2`1A:`/0F30>05di4@1V
A1@0KddJ07=A6P1lEAl0O68f07MhA@1nQ480PHI008F5@021Q400Lh5106^0@`1ZP4P0JXE?07Z8A022
R480PHe208:?@020S3`0Q8Lh08R3>@22R3/0PHHl08>9@023T4<0QY1?08B@E01hTeX0Ki9M072HF`1j
UU@0NiAB07nED@24STh0RXi;0080Sha:02L0SXe908j@B@2ATdT0TI5608NHB`27W4/0P:EA07ZPD`1l
X5<0PJ1>07nVD@1nYE00MZ=C076QE@1_X5H0OJ=?08RRC026Y4`0QZQ?08>WD02<YT`0TJE908fUB`27
ZTd0QJU?08RVC`28YD/0SZ5608fPA@2>WDD0T9U0096H@02>V400SiE009BB@02ATd00SY=008nD@02B
Td000P2BTD0209BA@00U09J@@02DTD00UY=009RB?02BSCX0ThXh096:=02DSSH0TY0h08jA?@2;T400
RHdj08V<=`2:TT00SiY0096K@02CVT00TYU008fF@02?UD80SIE308fFA@2;V4T0RIe=08ZQCP26[500
N[5F06f`F`1UZEh0FZMJ04nPF`12UeX0AGe103mC9P0^9`h04`T300<100020000000>004000000000
00000000000100000P0000<100050@000`4000@1000500001P0000<000020005000000`0oooo000:
0?ooo`H0000000<00P0000<000020@000P040@000`0300000@0000000006000000800@0000<00P00
0040000100000`0200000`0100000000000000040000000J0041TP061cl00aTT00P=3`0R52X04R5b
00l]R@0L9XX0;RUZ02hcK@0J;h006D1m024iI`0Z?EH0849B01i7AP0RA3`0;3lh02hm<`0/@C<0;TDi
0350=@0`>BL0:cPR02dc7@0/9A@2034Y600W038i<00R@UD04cb000HKZP0009<0002c0000U@000HL0
006?000;SP079YH041fC02<JOP0E584031b000hPU00J4hd041fG00/_U@0;9iP07QjK02@^T`0<;Z40
31^T02@LU00X=8X04CbB010eR`0P:hD0<3:502DdR@0I@I4094>80394O@0]@8@0<Dam03YBM@14CGL0
C4Ea0080BT]a02L0DeMQ065:>`1>:100?1H503`H10126`P0@24604LO1@157`L0AAh804LM20198@X0
BB@:05@W2P1@9@`0C20:05@V2`1H;@`0MT`Z07]aCP1gP5D0HgiQ05ehJ01MLFT0GG1W06=fH@1VP600
JH1K06:1G`1RPel0I81L06IgE`1ULUT0HF]O05aZI01EJ6D0BfQX04ERJP0oEW000P14BV/09`10C6`0
@dmh04E?L`0iC7<0?de`04A=J@12B6l0ATE_0495H013BVP0BDeQ0416L`1=B700BTEW04E1OP1=C640
@41i04]?J@1<Bf40BTAd055CG@16@Gd0@d9a03LaQ`0c=hl0:C>F03<cRP0d<H@0<RV:048bF@0g<WT0
?bie02``T`0l?W<0=cQh04PdO013?g00?C^4055IJ@0204]_K`0W06aVD`1@Dg40K5]N06ehG01YNe/0
LH=G07B4D`1hPe40NhI@08J6A@29QT00QHA207f7B021RD<0PX10089j>@21L3D0NV<`06]C:P1RAah0
H3lH05dj501I=Q00FC8A05X`3P1J<@l0GCDC05/_401I;A00CQh903lG1@0i4`@0=A0202lA0@0a4`40
@Q/4068e4P1[EB<0ID`P0080Hd`S02L0I58W06Q;7`1]EbD0L6`i06^2A`1^QTl0KX]I06j8G@1cPeh0
M8IK076?G01iUET0NIEH086HE026VTl0RiE;08j=B@2<SDX0Rhm;08Z@A`2<Sd@0S8Q007n3A026Q400
PV//06i?801NAAL0EcdE05Dj501D=Q80D38C04l^3P1;9`/0CBL;04/W2`1;:0/0CBD;04TY3@18:@`0
0P19:``09`1?:`/0DB/;05P`3P1M>A40IT@D06m=6P1cDAX0O5DO07aR=P1gN4D0OXA20866@025QD00
PHA007>1@@1[P4<0JX1806Z5C`1jR4@0PXQ2086=@P22Sd00P8`l08B7>028PcT0PXPk0866?023RD00
Pi1308J@C`24T5@0N9=J06nBG@1`V5/0NYID07^DDP1oUE40Q8i>08Z>B`0208n<BP0W08j=B@2>T4T0
TI=9096AAP27V4/0Qia;082UD@1jX5<0O:1C086PCP1oYU40OZE@07JSD`1aXED0Kj1F07fSC`28XT`0
QZA<08JXC`23Ye00S:I<096UB@2=YD/0QjY=08FYC`28YTl0R:E;08jQAP2=X4D0SYe5092I@02AV400
SYQ008nE@02DTT00TI=008jC@02?U400TY=00080TY500P2DTD009@2FT400U95009JC@02HTS`0TXdj
09>:>02ARS@0U8hf09:@>02>TCd0Ri1008V=>P29S3L0RY9008nJ@02AVd00TiY009:I@02=UT00SiE2
08fE@`2=UTD0RiQ908VMC@2:XDh0QZa@07ZaEP1]/5/0IJUN05ZWFP1?X5/0@YMJ04Em@@0oDbH0;RL>
01<90`030@000P0000003P01000000000000000000000@00008000030@001@4000<100040@001@00
00H0000300000P001@00000<0?ooo`002P3oool00`0100000P00008000020080000300@100030P00
1080008010400P030@000`010000000000000005000000@00@000P0000000`010000000000000004
0000000L0040000300000Pn<00H<=`095QL03ADK01TH>00F;Fd06cIb020[E`0T:4h092aZ01lhQ00O
>HD0:3Ia02hlG`0P?V@084eB02=:C00[A5D09T1E01m5D00SB5T09dIG02Y8@00[ARl0;cdT02/]5`80
;2XF02L0=3PR02a1=`0N@V0032B<0043S@000:h0002E0000U`000KL052BJ00PVXP0A6Y@091eh01HH
PP0=7X803QbI01`?V`0?6Id02RjH00/VW00P7YL09Bn600h^R`0>6Ih0:1^A02XdP@0B=XT053>302<Y
NP0W:hX07R^@01ThV@0U=I<0<4:502DmQ`0U@hL0<DF504@mO@1B@G000P18Cg<07@1>Gfh0GeYC06U2
>01U;Ql0Db@>04HM20157PL0Ab4904PR2@1480L0@ah704TP201<8PX0DRL9058T2P1?90X0E2<905`a
3P1kEcT0O79;07AlEP1WOf00GX1S05f0JP1NP6P0J81R071lG@1^O5`0Jh1O0080JX1N00P0LGeH075n
F01^MeT0KGmL06QoG01KOUl0CWUT04M]K080AeMc02L0Ae1h04A<N`14CW/0?U=j041=N016CFh0@4Ib
04A:L@13CV@0A4]d04Q?K@12AGD0ATE`04Q3IP12Afh0BT]R03m5MP16B6`0@TI/04=5M019BfL0@DMc
0412M`0h?XP0=Cj>034gS@0g>8<0=3aj038_Q00m=6d0@T9N04E3I00[:Y80@3Ek03/`O@13;H00?3Mi
03XhR01?DW@00P15F7`09`1SIE/0Be9a06aLGP1/P5`0KH1K07F0DP1hQTh0PHE;0826A`2:PT00RX10
08Z3@026PT00PH9208B0@026NSX0PGDg07aZ<@1eFRX0KDhQ06]67P1V@AT0H3<?05dZ301J9@T0FRX9
05T_3P1K<180Ec4C050S2`0l5`@0<Pl002h=000Z3`40:Pd203@B0P1J:0d0JTXL06]:700206MB:`0W
05mH;@1PBQl0I4HK06a<801_Hc<0M7U107R5C01kQU80NH9A07^2E01oS5@0P99B08:ED@26Tdh0RiQ<
08fHB`2?U4X0Si58092@A@2ASD00SHU008V2@01kP400PGTj07mO901[A1P0G3TB05Th4P1H>Q80Ec@B
05Dc4@1D<A40CRT=04TT20158PX0AR<704DR20149@X0A2L:0080AbX;02L0D2T:058[2`1E=0d0GCXC
06]45@1_Ca/0LU@J07]H7P20HB`0OGU008B1@02:PD00RH9008Yk>`1jNT00N7a007F0@01cQ4P0N8A6
07b:A01lSTD0O91307bA@021S3`0R8Hi08N5=`21QCX0OX@j08V;@024Sdd0PX]C07fBF01iTeL0NIAG
07JEE`1bTET0M91F07RAE@1nT5800P28S4d09`2<S4/0She8096?A@2?UDL0QiU;08^LBP28WdX0PIm>
07nJD@24VTl0QYe=08RNCP22X4h0MimE06jOF@1jXU80QJ=:08JVC023Ydh0OZM@08JWC02<YD/0RJA=
08FVC@22Z4h0QjM>08VTC02<XTT0S:9708fQA02>VT40SiM109>F@02DT400V8ll09R@>`2HTT00UI90
09:B@00209B@@00709:@@02BSc`0Uhdh09N>>@2IScX0V94h09N;=@0209J<<`0N09N@=02ETcP0SiE0
08jB@02;Sc`0RHXh08b<>`2BT3d0Ti=009>E@02AU400SIM008^F@02>Ud00S9Q408bKA`2=WD/0R:I=
08FZDP1e[eD0LJaI06FTG01IWET0CYUE04^:B`18IC<0>3/G02@H200@1P8010000`02000300400080
0P0000P00`000080000400001P0000P0000700001@00008000D00000303oool000X0oooo00L00@00
008100020P000`8000@200050P001P<100801@8000@0108000<100030@000@000P000005004000d0
000001`00@0001TF;00476/01aL`00/E4@0E7R`041UR01leNP0S>Vh09cU;028[K`0H:H`05c^G01db
TP0Y=H40;T9^01lmM00SCf008dM?02HkD@0M>5d05ciR01TnH@0S?Td09TM602aCB00fDTH0>4@g0P0d
?BT09`0g?BD0=D0Z02Dh@`0I;g800`f40001[P0009D0002G0001]P0C9YL022JR018GV00U7g/05ab2
00dQS`0?6iT07PfH00lDX@09:J@032:S02<MUP0Y<Xd03bf:00hFW@0[6Y80:S>7014`PP0D;h@09bN1
028WU@0H9Xh06cB<02L]O@0^>WH08Sj002E6O@0bAW<0?3mR03hmF`020457J00W04UAL@1FCFT0HDaI
06=<@`1O>BH0CbL<04TQ2P1>9`X0CB@;04dR201;8@L0CB0904lQ1P1E8PP0DR8804hP1P1B8`H0Hc4?
07aR@01nODd0K7aL06F0H@1TP5l0I81N06R0FP1_O5/0NGm@079nE@1`Mf@0JgQQ06YnI@1aNUX0M7YG
06n0FP1XOed0JGaK06b0E`1[OeD0JGME0080JViJ02L0JFQK05aVI01DJ6T0BVM/04EKK`15DfT0@TeY
04E=J@16CFD0@Da^04I:K`12A6l0ATAa04I6LP11BVh0BdmX04A6LP1:Ag@0@dMk0495N`12B7d0?Sf1
03m5P@0g?hT0=c^;03HfRP0j=8L0=CB1034aU`0j>8`0?3N704eBI`0_:Xd0ARmn03TZPP0m;8L0>3Em
03TfO018C7D00P0kCX809`1KFfH0B51j061EI`1WN640L81E07N3D020RDX0QHU908B8AP2<PD40S810
08V0@028P400PX1208:1@P28P400PgTj07m`=@1oI2d0N60]075C8`1^Aa/0ICDB05/]301D;0`0ERX;
05Tb401N=Q@0F3lK04lW3P0o5`D0;`/002P;000W2`409`T1030>0@1=6`L0H3@A06e3600206Q>900W
05m@9P1M@1/0GSXF06<b4@1O?1L0Jd/N07=R:01kLcD0Nh1007n1@`22QTP0QI1;08BAB`28TdP0SY=8
096BA`2DTT80U8i209F4>02AOC40RGL_08Ad<P1gMT00NVhe07EH9@1Z?Q@0FC8A05`e401M>1<0FCPA
05Hf4@1@=a40CRd=04LT2`158@X0Aal704<Q20148@T0A2<80080B2T<02L0D2h:05H_3P1J=Q00GclA
06M4501/BQX0ME4K07]F7@1nHB@0PGDe08R0>`27P400R81008Mf=P1gLd00Mg@k07V0@01hPT80MXA2
07>9A@1dSTT0M95707NAA01nTD00QXXj08R4=`21QSX0OX<g08F5>`24STX0O8]D07n?E`20TU@0OYAD
072?EP1/S5/0KI1I07>BE@1hTE@00P27ST/09`2;RDL0T8Q609:9A@2ARdH0SI9908nGAP2<W4P0QYi>
08:HD026VTd0S9Q:08bNBP28Wdd0OIiB07>IE`1kWe@0P9m>08NTC027Z4d0P:a?08:ZC`24Ye40PJAA
07jVDP1nZU<0PjIB08ZWC@2:YT`0S:Y;08fXA`2;XTH0S9m408jI@02DUD00UI8h09F>=@2ERcT0TXdj
09:B>P0209:C@00W092A@02BTS`0U8Xf09J8<P2ISc@0WI4b09N?=@2GSc@0UX`c09R9<@2GRc@0TX/j
096<>P2BRSX0TXPi08n7>@2BRSX0UHhj09>:>P2CRcX0TI0l08jB@02AUcd0T9U108fNA02;WTL0QjE<
08:]DP1gZUD0L:]G05nSF01DVEH0DHe;04Yb>@12BR80<2D?01`<0`0<0P001@000080100000h00`00
00<100020@0010400081000200000`0000D100060@001`4000T100070@001P00004000D00000303o
ool000X0oooo0P010002008100800P0000D0104000<0000400001@0000@10002008000800@0000<0
0P000040000100000P01000=0000000L00/5100F4A/03R5500dJ8`0;3`/05aTV00PXQP0D=Gh08S]d
02loCP0X=6L07SYn01]3P@0S>6@09C=E02HhIP0V@gX0;TUf02i1FP0_=d007S=>01TgI00J<V/09CU8
01i0D`0OD6`0:Tia03A;G`80<4e102L0<dD^03Dn900]>S408S=F00LEN0000Zd0002E0000U`0D::80
4BRG00TTX`0E5I/09R6A01LQW00<8j0041RK020:UP0@4:8022>S00dMUP0R5W`08bQl00lWQ@0@67d0
91AY01hUK`0=;8006Bb>02hYP00U;Hl06B]o01`eOP0Y;FX0:C1[02HmO`0Y@H00=4Af03I0GP0`?6P0
0P0`BFl05P0kAW`0DTE_05U@I01NEeH0Jdi006Tm9`1Q<AT0G2d=05LZ2@1D8`/0EbD:050R2@1<8@H0
CQl604hP101970D0D1l405h_3`1jJcX0NH1;06N0G@1YP5/206j0F00?07>0F01cOE/0Nh1B07QgD01b
LEh0KGES06ajIP1aP5l0N7aH07YlE01iOeL0NWAC07^0D`1kP4`0N81;0080Lh1>02L0N7M507Qc@01R
M540DW9Q04QZL015G7D0@59f045=OP0nBVd0?DMj03m;N00mAWP0@TYo04I@O014Cg/0CUM/04e@L@1@
E7H0Be9h04UALP1;Cfl0?cj30458P00oB7l0@D]i049=N013?GL0?can03XkRP17B7@0D5aV05EHF@0h
=8@0@R]m03LZQ00n:XT0>32503D]PP0m?7l00P0f@Hh0301BEWT0@DN805=8M`17IWT0IH1T07>4DP1m
R4`0QHE908>5AP2;PD80RX1108J0@0<0R81001P0RX1008R0?020NC/0Ng8g07Y_=`1gFbT0L4HM06Pi
5@1P<Q@0HCDC060g4`1Q@1P0H3`I05i17P1E=AD0B20:034@000^3000;0`102/;0@0a3P40?QH3050T
201Y>A8206e=800W06I97`1J>AH0G3HE060`401N<a80I3XD06Q46P1aE2@0O6<Y08I]<@27NST0RHI0
08V9@02;RT80ShY10929@02GQcd0ThDm095j<028JRH0PFHW081T9P1fJ2h0MV<Z07AG8`1^@1D0H38>
05hb3@1P=Pl0G3P@05Pl501C?QH0DSHC04l`401>;P`0Cbl?04X/2`1::P/0C2X<0080DC4@02L0FSL>
05dh4@1R>a80GclC06975P1WBQL0KdlG07QD6`1oGRD0Og<`08:0>P21Pd00Q81008Af>@1bLT00M7A0
07V0?01kPd00MhM20768AP1aSTT0M8m807N?B01mTDD0Oi1108>9@020QS`0Nh0f08Ah=@25QT40PHQA
086:E026SU40PY9B07Z@D`1fSeH0N95B07jBD024TDd00P2;SdP09`2DRD<0UHI109Z5@@2GRD80UI12
09>E@`2=UdP0SYQ908bLBP2<WdX0SI]909BNA`2;X4/0PIm?07ZLD@1kW540O9i@08:VC`24ZE00P:m@
07f^D@1lZe<0NZ]E07N/F@1jZUD0O:QD08JXD027YTl0QjE=08RVBP29XDH0R9e508fJ@02BV400U9<l
09:>=P2AS3D0THdg08j=>@0208nA>P0W08bA@02@Sd00UXXb09J5;`2GS3@0VHlc09ZB=P2HTCH0UI0d
09V8<@2FQC80TXHe09B8=`2GSS`0TI1008j>@02DST00Ui0l09V<=P2LRS@0V8hh096C>`2=V400S9a0
08ZMA@22XTT0P:9<082RC@1hWTd0K9a?05VFC`1CS4/0BGHn04AI:P0h<QH09QD701<70@0700001@00
00800`000P02000300<0000800<1000400000`0000@200050P002@4000L000050002004000@00000
303oool000X0oooo1P0100000`0000000@0000<0000200<000800P000P010000100200000@000040
00010004000000<00@001`00000070070P404@/;01HK7P0?3`d02@D400LBH@088X405Bm/01XaO00V
?5P093MO01dgO`0P>h@09d=I02@jF`0H<gd06SJE02P_U00^<gh0;Ce@01/eD00@<fX062=i01ldE`0A
>fD04TQl02=5M`0`AE/202]?DP0W035AAP0^CTP0;Shm01l]C@085WP00@>^00<6O`0219003b:D00hU
U`098j<05Q>I02PNQ`0G7Id031nS00lFW@0Q2I@04A6M00PRW@0=6h@07@mY01LEM@0;7X004AU[01/=
I`0>4gh02bB<01TQV`0d:H409C:<01L_N`0M<Gh0:2al02PYMP0V>H00:3V903I3OP0eAFX0:T=N0080
;Dmb02L0>DUe04Y8HP1:BE`0DEAQ05mGF01ODT<0GDXk064e601G:0X0D2<:05<Q2P1<8@H0BAl304`M
0`1;7@@0B1`604TR2P1Q<A40N7100721DP1XPE/0L81B07^1C`1iP5@0NX1D07EeG01hM5X0M7=N07I`
H01`MEh0KgeM06f0GP1aP5d0LWeK06j0F`1/NU`0KX1J07=oE`1`P5800P1]Oe009`1]Odl0MW5007AR
>@1XHD00HVY?061cG01DL6L0BEmb041CL@0nCWP0?d]g03a>P013DX00AUMf04IEM01@DW00BU1f051A
M01<DG80Be5`04M7KP0o?H@0@TN004YCL`1;FFT0@TUa040mQ@0o@h<0?SR704U?K`1DIdh0EUE=03Hl
N`10:g@0>2mg03haN@0i<XH0=BR?03P_R00203<iT`0;04iIN`0iDHX0E4md04mVM@1TNF@0KH5K07J3
DP20QT/0PXM808J3@`28P4400P2;P4006P2:P400S81008^0@026Nc/0OWPl07af>`1kLcP0N6<]071E
901YAad0ID4J06E46P1XBA`0IU4S06E<8@1PBR80H3PI04lV3@0m4P80<a02034A0`0/3`40;``103HA
0@156PD0HCPC0P1aD1l09`1V@QT0FcDD05Lb501N:0`0FR`>05/Z3@1O<100ISdF07986P1nDAh0PUhS
085_;@25O3L0SH8h08j2>P2>PS`0TH<i08j4>`29L2h0PEXO07QE7`1hF240M5PS07IO9P1eGbH0Ld`I
06@e4P1O<Q00GCDA05hj4`1K?1D0FD4H05Pn5P1F>Q@0ES`C05To5@1C>A80E3H@054a400205Li4P0W
064k4@1T?Q80ID0B06M65P1VB1H0J4/H06Y=601eDA/0NUlT07ec;`20P3X0NhE007n4@021Od00LGY0
075m@01ePD00N8M007J:@`1`S4L0Khi;076?CP1bTDh0LiI;07^BA`1nST80P8U007ml=P25MBl0S80l
08R6B023Qe<0Q8a@08R>C`24Te40QIAA08>AD@25TTX0Si560080U8i202L0UhU009f7@02LR440WHU0
09^<@02JT440U9E2092GAP2@VdT0SYi8092MA`2DX4H0SJ5908ZTB`21Xdl0OZA@07fPE@1kYU<0Nj]A
082[D021Zdl0P:M@07bVE@1b[5T0NZUG07j/E022ZE00QJIB086UD024XDh0Qj1908BPBP23WDL0SYi3
092K@02CUCX0TI4g09:>=P2@S3H00P2ARSD09`2@RcH0SXll09>;>P2ER3L0UHdg09>?>@2FS3D0VHdb
09J;<@2GQc00TXHb0923<`2BQS@0UHXi09B??02DTC`0V91009^B>`2MT3L0WY0f09ZB>P2AUd00R9e1
08BTB01nZ4d0MZIA07VSCP1lWDH0LiE206:>A@1GQ480CFli041E:@0k>QT0;Qh;01h<0`0=0`001@00
00<0000200@000800P0000H00`000080000300000P0000000002000200<000030040000000000000
00H00000303oool000X0oooo00@00@000000000100000@00100000020080000400<0000400001000
00<000<00P000P0100000`0000000@0000400002008000800@001`000000700200001P@200T;1P03
10800P0000L9A`065hP04bQ_014VS`0G>VT053MR018VQP0L;Gh0941M0211I00D?Gh06SR<02P_LP0Z
<ET08SAE01PlJP0H>GP08R]G01XWF`0?=h005SV802/oL@0c@Td20210IP0W02]DIP0`E600:3eO010L
M0063i<00@:e00@6L`062UD02AB300XLU`098J@05a:I02`IPP0H5id031^V00lBX00Q1i@0412M00LP
ZP0<6Xd05`R700T7QP065Wl041Mc01P9N@083Xl02B:@01TLW@0c9X808SEk01@eO`0Q<h@0<CI]02L]
GP0S>GL0;3R:03A2PP0`AWT0:dAc0080;D]o02L0>4F103e6K@0jAV80?Da^04eAIP1GEeT0EeAJ06E7
@01X=1`0G24:04lP1@1<6`@0BAd504`O101=7PH0CR8704hS2P1W?AL0Mg]007:6DP1bR5D0Lh=D07^0
CP1hP5H0OX1B07YcF`1hLUT0MG5L079`G`1dMU/0LH1N06b0H@1^P5h0KH1Q071fG@1]M6@0LGIM07Z0
D@1kPdP00P1fP4T09`1/P5<0L7Y8071Y=P1WBb00HTLR06QO<P1NM4X0BG5Z049RN@0iEX40@5:003eB
P010D7h0A5=m049AO`17Cgh0@den04I<N`1;C6h0B4Ud04=2M@13@X80Adij04eGJP17DfX0Ae5W04=>
L@15BVd0@3j004A:KP11@eh0@ciL03TmL@12=FX0@dMO04mDG011?WH0=2J>03DWR`0203@aT`0;04eI
NP0fDX/0D5Ed055VM@1ONfD0GX1Y06n0G@1lSE00P8E908J0@@2:P4000P2@P4006P2=P400Qh1008J0
@024N400OW4k07a]=P1eLCH0M6D^06eP;P1XDbD0Id`P06Q;7@1WCQl0J5<Q06MG:01OEb`0G3@E04XO
200i5PD0<a<4030@0P0_3080<@h2038:0@105080GBX=0P1/B1d09`1T>1<0F2h@05D^4`1J:0/0EB@:
05HV2@1M:@/0ICPA070m5@1jBa`0Oe<L07]O9@1oM3D0QgHb08Qg<02;P3P0SX8k08f6?@29L2/0PEPO
07IA6`1eDQd0LeDO07=M8`1eH2@0L4dJ05li4`1O=A00HCX?05hj4P1K>a<0Fd4H05Q36@1IAa/0FdXK
05a;6`1J@aP0DchE05Hk5@0205Xo5P0W05m25@1SA1D0JTDG06Y85`1UBAH0JT`I06m=601fD1`0NF@U
07me;P1oP3X0OHM007j7@01lQd00LXE606j4@@1aQ440MhE407N7A01fRTL0N8a:076AC01/UU00JiEB
07:FC@1hU4H0PH]008En=@26L2X0SG8[09B1@@2<RdT0RI5<08bBC@2:Tdh0QY9?08RHC`29V4`0TiE6
0080WHa002L0WhU009n:@02SRD00Y8Y00:6=@02NT400UY=3092FA@2;V4T0Sii709BPAP2EX4L0T:E7
092VB@27ZDd0OZU?07JWE@1gZE<0OZ]C08BYC`26ZDl0PjI@07bUDP1aZUH0OZaD07nZEP1oYUD0O:AH
07NQF@1mXe<0OZ5@07bSD020Wd`0Ria208jL@02>UT00TYDk09>A=`2@SST00P28SCP09P2=RC<0SX`j
092@>`2CSC/0T90h09J@=P2FSC<0UXdd09B;<`2BR300TX8`08f0<02@QC80U8/e09FA>P2EUd00Tie0
09JN@02KVT00V9Q008jJ@025VTD0OYe:07nOB`20YTX0P:9608:K@01lT400KX4i05e^=01@FRP0@T<L
03<^4P0X6`T07Pd401@50@0<00001P000`0300020040000300<000010000000000h00000303oool0
00X0oooo00<00@000080000200001000000200400003008000020P001@8000801@8000<01P4000<0
000200000`010002008000@00@001@0000020040000L008000030@401P@200X71`0612d010IS00D@
U`0A:FH05RYA01`eGP0I=V/07RmL01hZ@00O;d006cQO01XhP00V=XH0<C]K02deD00H:gX052jC01dW
TP0/=7P05QjC00TXZ@0I7id0<S9j0350F0805c9d02L07TQl03ABM@0Y>hL01@jc0088^0010Kh02`mP
010HB`052GH01QF?00TRW`0H59L0;AMc01XGQ00;6iH03aBC02L@H00J5Vd021bG00XKQ@0L3F4061IZ
00LPR@0?77l07A1d01DNR@0<9i4061^O034SQ`0O<h805BZ=02HZSP0g=X409C1l020fO`0^=HX0=D:0
02Y7NP0XA7T00P0^B8H09`0cBHP0=dYd03U@J@0lCWX0CTiY059@J@1HCVP0FeAS06YC@01Q<180F2<8
05@P1P1C90D0Eb<805LV1`1C8`P0ERX;06m>901fOT@0LX=?07V8CP1lPdh0OX1>07V0E`1nP500NG5K
07EdFP1dMEl0KV]U071aHP1/M6@0JGAS06YbJ@1ZMVD0JgQQ06]eJ01aMUl0N81A07^1A@0207Z0A00W
07F0B@1cP4/0KWE006aA9@1V?QP0IT4H06]=:P1WHD00I6mA05e`HP1=Jg80AfMh04ION@17FW/0AEQj
04QDNP13Cgl0ADYl04I7MP18AG80BTQg04A2PP16Bg`0ADah04M;LP19FV@0AE1a0494M00l?8X0?D>7
03LjS@0j?HL0=cN>03dkO01;FEd0G6]D04E8J00g:h40=RJ70080=S2@02L0CE]f045YOP1LMFH0IH1N
06j0E`1/P5/0NXAA07n8C@21PTP0QH1508Z0@02?P400SH1008Yk@025McX0QgLl08Ad>`1nK3X0Nf/g
07Yc>01fHRh0LEPV06]<801TB1h0IThO06IA8@1XEBL0HEP[05UD;P1A:Q00?1X403<A0`0_4080;Q01
02l>000]3@40<0`003/>001G80P00P1[>a@09`1T<A40ERX>05<]4@1B90X0DB4905@S1`1M;@X0HC<>
06dn4@1gB1P0NdhJ07aJ901eKC<0P6X/08I[:@27MS40QH8k08V4?@26L2h0OU4N07=;6P1]B1/0JD/L
06mD801cFbD0KThO06=05P1R>Q00HCP@05hh401K>180FC/C05U0501K@aT0GTDH05a6601IAAL0Ed4E
05Y25P0205U56@0W05a5601TB1P0JdPG06a8601ZAQL0JTLF06Y8501`CaT0NV<X081h<@24P3T0PHE0
0828A01kRDD0KhE:07:6@P1`Qd80LXQ407B7@P1nRdD0Oha807REB01]U4h0IiEE06bFDP1fUd`0OhY1
08J1>@26MBd0PVDU08a/:`2;PT00T8m208nEB029Sdh0QIA?08NFC`29VTd0UIA50080WI5101X0WXm0
09j>@02ORd00XXY009f<@02KST00UY=108nCA027SdX0RiA9096MAP2DXDL0TJI:092VB`28Z4d0PZYA
07f^EP20ZE@0QZA?09:PA`2?X4H0SJ5708>RB`1jZU80P:YA07jUE@80OJ=D00/0NZ1F07fQEP1mX580
Oj1B08:MCP29Vd@0SYU009:F@02CTS`0UI0j096@>@0208f==`0W08f7<`2?Rc<0Thli09>@>`2ATCL0
TXld0928<`2@SS@0TXlf09:<<P2=QBl0ShH`0924;P2FRC<0Ui@k09:I@02@X440SZE208bSA01oW4L0
N9i;07BKD@1cVe@0MYi?07jL@`1mTS`0OH8d075d;@1NFbD0Bd0L03/_4P0_7`/091@801L:0P0?1@40
2P4000L0000500000P000080100000D00P000040000100000P0000400002000000800@0000<00P00
0040000000001`00000<0?ooo`002P3oool00`0100000P0000400004000000800@0000T00`400081
000200000`0000D100040@001@0000<00002000010020@000`0200000@0000800005004000800000
01d00@000000000100000`4100l?EP0417/00@BI008;Z0099F`05BY801`^K`0L:HL08C1H01`Y8P0J
9B/04bYX01/RT00];h@0<CeJ02/mEP0J>7L062f9028WLP0[<gD06B>4018[Q@0L7U`09BHo02HcB`02
01LjM00W01i1Q00e@h00;3j800/]Y0056j`00@>=00`AH`0<4e<01P]Y00LEN`09:94051ZF02TGL`0N
7gX03Af<00lIUP0Z5V@09QaQ00THR@0:79808Q:302DWP008:iD03B6J02@FT00M9i0032^A01HJXP0_
88X07Bj8018STP0]8I00=cEh028aK`0O=HH0<C5k02liK00W?GD0:T680080<dB702L0=Dn503=?P00e
DG/0>d^304a<MP17BWT0Dei^05IQJ01NHUP0L4a007<h7P1X<0d0HBl<06<b3P1U=140ISHD06i26P1i
JCD0N7i607V0CP1oPT`0OX1=07j0D01hMUH0OX1A07QfCP1aMET0KGIO06idH@1_M600KgAO06YdH@1c
LeX0L7=K07AgFP1_KVL0KfiV07MjEP1kP4H00P1lP4009`1kP400MH1107=h@@1cI3H0KT`Q06Pn501R
=a40I3hG06Y<8@1_I3/0GViG059[J`1<I7<0BF9f04UMM`15E7h0?db103m4P@14Bgl0B4Uo051>M`14
AH40BDmj04YANP18E7L0CE]V04M7LP16AWT0BDR104==P00gB8P0?T:403llQ019AG<0Ce9L05=EF@18
Af@0>Rmh03/cQ00203XcR`0;051IM011GX00HgYQ06f6F01gQU40LH9C07Z4C`20R4h0OhI:08B1AP26
P4400P2<P4006P29MS/0Q6lh08A^>P20LC/0OFhk07e_?01iND00NFT_075D901ZAQh0HDDN05m<901L
D2L0FEXa05QC;01CARD0Aah9030B0@0`40<0;`l3034=0P0b3@40=10003<A000f4@00Cal60P1T=Q40
9`1Q<0h0FBT=05LZ3P1C8PX0Eb8905/W2P1M:`/0GS4<06Ph401a@1D0NDTI07YI8`1eIbl0N68Y081R
9`25M2l0Ogdh08Ej=P26IRH0NTdJ07135@1Z?QH0IChE06]:6P1/DQl0JdHK06Q15P1V?A80I3TB05le
401G<`l0EC<?058e4@1G>Q<0FC/C05Ll4P1H@1@0G4<E05a4600205e96P0W06196`1TBQX0JTLF06e8
601ZAQL0JD@E06U54`1`BQT0O60R089f;P2:P3<0Qh=008:5@01mR4T0KhE>07B5A`1hR440L8Q50769
B@1gRTH0OXm607VCA01cU4X0J9=C06^DD@1bTd/0OH]308B4>`23KbX0O5lP07iR9020MSD0SX8k09R6
@02ESD@0SI1;08ZBCP28UDd0TYA:0080U99602<0Vi5009RB@@2ISd40W8a009n;@02LST00VY5209>=
A024QT/0Qhe;08nLB02DX4L0T:=908jSBP28Z4h0QZ]A07nZD026Zdd0S:=909JKA02DW4@0SJ1708BR
C@1oY500OjAA07^WDP1gYUD0N:=F07RQE01kWeH0NJ1G07^PE@20WDl0QI]708^G@00208jD@00[09>B
?02@Sc/0S90g08b@=`2>R300ThL`09>;=02CT3P0U90h09>==P2;Qc80RX/e08n@>02@SSH0SXXe08b7
<02;QS80Ri0j08^E@029VD00QY]008>N@`22W4L0OYQ407^DA01lTD00OY10082=@020PS<0NG<[075O
7`1NAQL0BR`=03DK1@0T3`@07@X201T80@0D1@003P@000P000030@000`0000400002008000800@00
00<00P000040000200000`0000000`0100000P000080000200000003004000000000000000<00000
303oool000X0oooo0`00000200400080000000@00@00004100030@000P400P02000200<000801000
0P030@0010020P000P00008000030004008000040040000200000@00004000<0000001/00@000080
000C5H`00@:j0001^`011[@00Qn200LYGP0D:Fd06b:9020bI`0S=3T062Y601DZLP0P9fh09RU902@[
>`0P=U@07SQd02L]P00[<V4093E`01L[O@0F;7/08Adf01dF4`0M:Ch00P0@>WT09`0M>XD0<c:302dk
P@0=@9T01An700<8W@0?4WL010R800@7WP074h/02BRA014OWP0V68h08bV<010MT`0;6JT0:AF102lT
JP0;68<02ajC02<EQP0Z9WP02RV:00dSTP0R6X006af200TVSP0G6J40<26:01d]S@0F9900;b2@03@a
P`0I<8H07b^D038^P00X=g`08SJ202dbS@0203U1P`0W03=@P@0[CGh0<4b003I;Q014E7`0@e1f04YL
M01IEVP0G4MT0693G`1dBd00ND0I06/j5P1Y?AL0JdPL079G9P1gKCD0Mh1007J4C01eQU@0MhIC07N5
E01dP5L0LGQJ071fFP1[Keh0IWAM06=dJ@1WM6D0K7MR06ifG`1_MU`0MGII079bFP1`L640KEi[06iP
J@1dMEH0MWe80080MWI002L0N7I007Yg@01kMT00NF/e075K:01`Bad0JchE06/n4`1[?aL0LTPO07M?
<01hGT00KG5A05EgJ01?Jg80BEMm04I@O014Cgh0B59k04]?N@1?E7D0A51j04M@N017Cgl0B4mm04QC
NP15B7d0BdUl04PnP@13D7d0?Tb20415P011@h00BDi_04Q:J@17BgP0@dEb03@/U@0n@7d00P0n>7X0
2`1@Dg<0@db106=fI`1/QU`0N8ID07B6E020Q4d0RX9808B0A`25P4@0QH110080Rh1001X0R7Hl07mb
>P1oJCD0NV@c07eN;`1jGb`0NfT_07MP:01bF2<0JdXN06137P1DAb80EdHS05A68`1??1`0BB/C03hA
100b3@00<a4203DE0`0d4`80>aD103DE0P0_4@00=10004lL0`80G2l=02L0GRh>05T^301G9``0D208
058R201F9PT0G2L905/[2P1O;Pd0JS`D07E4601iEb<0MVP/07QQ:021I2P0Q7<]089i=@23Kb/0P5TP
07Q75`1a?Q@0Kc`B06Pn4`1X@aP0JDTJ06Y05P1[?Q@0JCdC06@g401N=Q00Fc4>05D`3`1>;Ph0DRd?
04l`3@1A<Ph0DS<?05Pi4P1I?A@00P1LA1H09`1N@AL0Gd4E064n501S@1D0HT4E06935@1V@A<0KdPE
07UH7P23JbL0S7X_08b2?027QT00NXE806V3E@1eQDT0MhU407:<A01dRdD0NXY507j<A@1nSd80Ni93
07V?A`1cTTT0L95807V8@P22P3L0OFLU07AE6`1gFR00NF@Y08=X:02AKb/0VH<l09:8@`2<SD`0RhiA
08R=C`0208^BCP0W08nCA`2FSd<0Ui5209Z@@02KST00VXe009^=@02FS4@0Qh]908RBB@2>VDT0UJ15
09BQA@2AXdT0RjI>08VWCP27Zdh0QZY:096VAP2HWd40UYa4096QAP2;Xd/0Qj9@08FRCP20YE00MZEG
07BNF`1fWEH0NIaE07RME`1kXED0Pii>08JHB02;UD40TY9009:A?02?Tc`0S8m00080SXll02L0T8lg
09B<<`2ASCD0TI0i09:C>P2<Tc/0Phli08F@>`24TS`0RY0k08Z==P28R380Q8Pe08>B@020UT00OYY3
07fMA@1fW4X0LIM;07BCA@1jSd00Nh<j07Mf<@1gJRH0LEXN06E65P1C=Pl0ARL;03TI1P0T3@005@D0
0143000A104040<00141000:00001`0000D0000300000`0200000`01000000000000000800000003
0080000100000@0000@00000303oool000X0oooo1P01000200000004004000040@000`0000810080
0@0000@00P0000<0000300000`000P04000200<100<0104000D01@4000<0000200000P0000810005
0040000J01hE:P0D47/00PJ_0043]`011;L011NH00XTPP0F7WL061J=01H]L`0R=EX052aa01LWP00T
:6008R4O01TL800C9Ud05a^>030MQ@0/=FL06Ce[010gN`0L;7d0:R8m01`E8@0M;U0201LiO`0W02Hf
N`0j=FD0<3]O0152R`07:Y@00`^h00`?S`032HP010bD00LFS`09:9<03ajP02DFS`0V9X`0422D00TP
Y@0S6880;2M[00dJP@0<8hH071J302DLO`0=8Wh042B<028MR@0J5H801b2;01THX00c8hT072n9018U
T`0]7Hh0;b^;00lZU@0K7ih0<bf502LjN00M=Gl0;2n60080>SaZ02L0;T1_02]3O`0^?h@0=4N303UL
P00iEWd0?59o04m:M@1N@F00GSmK06IDD01lFd00PeTk081I@01fHDD0KfU>06icD`1ZM5L0IGAL069c
H`1RLV<0HFmV06=`HP1VMEh0JWEH06YfFP1XP5/0IgMQ06R0GP1ZP680J81Q0760FP1fMUL0MW5H06iU
F`1WFV40JeUW06a`G@1aMDT00P1aLd009`1bJd00M6I007QX?01fJcD0KfHa071N:P1]DR40JT8G06Lo
5P1S>a<0J3hG07E;7P1lGC<0Jg9>05]^I01>GgH0AUUk04MEN`1:Eg/0BEMl04YIN@0oDGl0@dim04M;
N`19Bg/0BE=i04a=N`1>CGX0BdAk04YCN01;EWH0AUIf045CM`13C700@D5f04A1NP10>Wl0>RZ@04iA
I@0204Y<I@0W055=L`10?8X0EFYc05j0J@1kP540MhMC0865C@2=P4D0QH1908:0B@23P480R7Y008Uh
>`26LSX0Ofhh07eN;P1jERL0NU8U07UA8@1kF2<0Me4R06m?801WAah0HD8M05Q27P1F?1X0C2lA04@R
200l6@@0=a8103@C0P0g5P<0>QH303TE100i50<0=A<203<B0@0c4080@AL30080F2@802L0FbT:05X^
2`1B9`/0D20704lP1`1C80D0E2<805HW2@1I;0d0HcP@06i55`1hFB80MfLZ07eO9@24J2T0QGL`089m
>022Kbl0O5@Q07Q;601b@a@0KSdD06`n4`1Z@1H0IT<E06Xl4@1/?a@0I3dD05he401M=@l0Gc4?05H^
2`1@:@X0BRH<04HS2@179`X0BB@;04lY2`1F;`l00P1I=a009`1K=a00FCHA05`j401Q?A@0HT8E0656
5P1X@aH0KT/H07eF6`23IbL0RWT^08j3>P26R400NhM806^3E01eQDT0NXM307N8A01jR4<0OHI3082<
@`1nRD00P8U00829A01iSD<0L8]807J6@`1oOCL0Nf<S079?6P1aDA/0METR07YH8026Gal0TV`X09Z1
>@2JQD00UHY808Z<CP0208F=CP0508VAB`2>T4L0UHm409ZB@02JSd000P2JSd40802GRT80TXY508fC
B02AV4L0UIi309NPA02DX4H0S:=:08^TC028Yd`0QjU:08nXAP2FXT<0UY]409:LAP2<X4T0R:5<08FT
D@23YU00N:1I06nJG@1cVUL0MYYD07JLE@1jWED0PIi?082KB`28UdD0TYI009:C@02<Td00RI900P27
TT009`2=TT00Thli096>>02@SSP0T98j08n@>P2;T3T0S90k08^A?@29TD00PI5007f?@01kSCd0OI10
07fB@01mUD00OiI007fB@01nRd00NX8k07Mf<`1cJb/0KePQ06M35@1F;`h0B1h803XI100b5@<0:a<4
02@?0@0I20405`D00184000@0`004@<000d3000:0@00104000<10002004000L0000000<00@000080
000000000P000000100200001000008000010003000000`0oooo000:0?ooo`<00@00100000020040
00D00P400`0300000`0400000`0000@2000300D1000400H10@050@001@40008100800`0000@00P40
0080000200000P000P0100006P0M21h04`YZ0088XP010k400@:k00dLX@096Z`06ABK01H;X@0;98D0
4cEX010_MP0J98009BUT02P[<P0K83P05BIY01dOK`0V7d/08BM101DaG`0E<Gl09RN4038]C`0Q8Th0
62Qm0P0Q:Hh09`0a;7/0?cEO038nF00;;7X01bRD00<;^0061j@00PJE008=T0087I8022RE010KX@0W
4X`0:2>;010QV0089:L07Q^702TWJP0>6X003B>401THRP0S6g<042AW00lXR`0T9Gl08R5L00dUN00I
6YP0=RMZ02<`I`0@9X`0;1f?02dXS@0?9i@071ZO03L]QP0X?X807c>802h/P@0203HgJ`0W02XaK00U
=H00<SJ=0352P`0aGH80;eV003I@OP18Cg80E4YQ05=8F01ACUl0GUiJ06mRBP1eE4l0He=P05IKJ@1E
I6X0DFM`04MNN016FGT0A59n03mHP00lGH00B6ec04anKP1NP6<0HWeS06N0H@1WP5l0IX1P06QjG01[
OUd0KH1O06]fH`1/H600If5Q06III@1VKV00JGE<0080KW=102L0L6]006]V@01`H400LfDf079X<`1^
Hc00Je8V06A3601P@AH0I3/E06i46P1/Aa/0M4DN07E>9@1jID00J7QI05IfJP1;Ig<0B61h04ALN@18
FWP0@56004==P015BW`0BTQk04a@N01;Agl0DDag04Y=N@1@EW80CUeb04QKM`0mCXD0>T6<03TmT00l
=hd0?3J<048dQP1KGE`00P1FHVT09`1<C7X0?CB?04iTN@1EMW80Nh1D082;CP25S4`0S89208Z0A`20
P4/0PX1108Ig@025KCP0Q6<_089P;@1kDb40N4LJ07M66`1c@aT0LdDH070n5P1/>aH0I3HA05h`401H
;`l0CBP=04TR2@166`H0@AX403`E0`0k5@@0>QH403XI100j5P@0=Q8203<@0P0a4@40<a0103/F0`02
04hN1P0W05HV2@1J:@/0DBD:04/M1P1:80H0CQh604hS2@1B8`P0DbH805/`3@1Y@1D0LDhN07MK9@1l
ER00OfHY081j=01oP3h0OG0`07UB7P1dCQ/0Ld/I07=55P1^@AL0Ic`D06Dk401R=A40HcH@05le401G
=0l0FC0>05PZ3@1B9PX0B2<8048P20137@L0@Al6044M1@167@L0BB<80080BRH902L0CBL905<Z301K
<`l0Gc/A0690501R@aH0JDPH075@701lGQh0QVTT08ij;`2=QC`0QXU007f9B01bPe00OhA507f9A@1i
RTH0O8U50869@021R480QHI108B6@@1oQd@0NX]407>8AP1eQT40N80h07AW9P1`DQ/0ME8I07AF701m
F1h0Of0Q08QS8`2@JbD0UGT`09J4@02ARD@00P28RT/09`26ST/0RY1908n=@`2GSd40V9=009^D@02I
TT00Uhi009>?@P2DTd@0T9I309:J@`2CVd@0TYi808nOB@2=X4T0SJ=;08fTB02@YdL0UJ=209RJ@@2E
VT00SIe608FPC020Xe40OZEB07NVEP1`XE/0M9eF07RMD`1hWe@0NIaB07jLD025VDh0RII5092D@02A
UD00S9Q008BE@002086EA00W08RD@02<TSd0SY8j08Z?>P29TS/0Rhlk08V@>@28Tcd0R9A0082CA01a
UDX0KIA:06bA@P1eSd00NXm007j>?@20Rcd0NWhh07=b<P1^JBd0JV0W06=A7`1O@A@0CR`903lL0`0^
404080d1028<0@0S3@<07Pd101X80@0H1@004PD00144000A0@003P8000d200090P00104000800P00
00@00@000000000100000@000`0200001@03000000000000000000000@000080000000<00@000081
000000000P00000<0?ooo`002P3oool3008000800@000`0000000`0100000P000080000200<10007
00<000040000104000@100050000100000<1000200@100801@0000<01P4000H0000400000P050000
80030@000`0000D1000300000@000000000G21<04aM700LMN`044Il00`N^00XLX@0=6J807aJA01T?
WP0<7ID03R^301<VN`0K68806BIf02HbE@0H:FX06BMk02<UI@0Q8BD06QXS018SH@0J7Hl0<268038f
G`0L<Eh04Qn60P0S7h/09`0c:V00>c91014VSP0=<W<02bZ=00D</@010KX0006l01TDW0058JD01RRJ
010JX@0Y48X0:B>;010PVP079JP06aZ>02DSJ`0=6X@03bB:01dLO00^:e@05cAO018[S@0[<6d0<3U<
01XbL00M9Xl0?3EC02`jE00D:hT0:Qf?02`WSP0A8iH07QJN03L_R@0X?hT07c:?02dYRP0203LeJ`0W
02LbKP0U<X/0<3J;02i0P`0[Dh40<E6403a@O`14DWT0AeM^04MMH01<Ff80D5AS05aEE@1^Ge80JFIH
05QZI01KKfH0G79V055ZL01>J7<0CF=c04INN@15HgP0AfIf04Q`L@1FLfX0E6i^05MbKP1GOVL0H81O
06b0F01ZOET0KWYJ06edG`1ZJEl0IemT06QEH`1XIeT0JVU;0080JfU302L0LVQ006aQ@01WGD00JEhe
06eO<@1/Gbl0IddR06=2601O@AT0GdTQ065C;`1UB1d0HcdE06@g4`1fAah0OV<e075cB`1JLFD0DFea
04]XM@1;HGD0@UQk04EEO017E7H0BUEf04mRL@1GHfT0FFIZ05QRJP1JJfT0FFmX05I[K01=IW@0C61e
04]JNP17DWd0C5Ai04U;N`1OF6800P1CE6D09`1GDG40?3J@05=RM@1CL7@0Mh1G08B=B`26Sd`0SH=2
08N0A@1jP4h0NX1707mf@01oJSH0PV4Z085I9@1lB1/0M3lD06lg501`=a40L3/A078i3`1/=0d0GR/;
05PS201;7@D0BAh404@O1@1270D0?Q/403TH100j5`<0?Q`303`L0`0o60@0=A<403@@0P0c4040<@h1
034>0002040G1@0Q04`R1`1B9P/0BB4904HL10197`D0BA/604`N201>7@L0CAl805DX2P1O=a40K4@E
079:6`1fC1d0OUhS085e<P1oP3d0Ofld07MC8P1cDQl0Me8P07=>701/A1T0Hc/E05hc4@1Q<`l0HSL?
06@_3`1J<`l0ES0>050Y2P198@P0AAh70080@QX600@0@a`7048H10106PD0@ah60P178PL09`188`P0
DBX:05T`301L>180GC/B06A35@1ZCAX0L5HO07iK8@26K2H0S84f08Z6@026S400NhE707F3B`1nPdD0
OHI607J7B`21QdH0PHi408:<@`22RT00PHI307b7A`1kRT@0MXM307F3?P1eOCD0MFXY07=D701eD1T0
MDhI07EC701jGb40P68R08=T8027IB80SV`Y09Al>`020927@@0W08^<A02;SDD0THm209>@@02ETD00
UYA209B@@P2FTT00UYA209JF@`2HVD<0U9]209JM@P2DWDD0S9E908bGB02@W4P0SIm5092TAP2EYD<0
VYY009JJ@@2@W480QIm:086RC`1oYU00Oj=B07NOE`1hWE<0NieC07:PD`1cVeP0O9eB082MC@28VTD0
S9=008ZE@02<U400RY500080S90l02L0T8`i08j8=P2<RS<0R8Ld08J9=@2:Qc@0RH`f08RA?029U400
PYE007ZA@01hRD00MW/f07]f;`1mLbT0OFlY07ia:`1eKB/0Lf8T06]A7P1Q@AD0Cc<<04HT1`0m6PD0
<18202<=000O2P007`T001l<0@0N2@406@L001H8000C1P0040<000h1000@0P003P8000X100070000
0P0300001@0200000`000080000200000`0000800P0000<00@000000000000000`01000010000000
0P0000D000010002000000`0oooo000:0?ooo`800P000`0100003P0200000@00008000020@000`40
008000050000100000@200050P001@4000H1000400001@400`040@009`060@001@8000D400050P00
1P0000D1000400001P4000@200040@000`000080000000003`L:00lK9P09:U402Qj:0088Y`067:H0
3QNP02DIR@0N59`031FT00/LZ`0G59d06`^J00TOS@0C=VT03C5i01TUPP0U:GH092]101/VB@0K:W@0
7RAd02PVE00/;U807Ri/01hTL`0201hMP`0W02/^BP0d;Dl03R>=00hbK00C;G0071]N00l@I@0427@0
8AMd00`OS`06:9P03R2Q02DDSP0W9Hd042:K00LVZ00J6IP08b:800dKV`0@99P08Ame03HfC@0N>640
4bV<02h_IP0`>T/06c1W01dZR00n>Dd0=3e801XcO@0[9Gl0:bIk01@URP0O79`0=Rj802HmQ`0Q<8`0
<RN;0080=SEn02L08c>702D`U00e=8X0;Sn302U:QP0dAhD0?e1o049GM`1:G700BV=]05EOI`1MBF80
HDMQ065OHP1iK4d0Lf5B061KH`1MFVL0D5ia04mPLP1AIfd0AFYd04M/M014J7H0@V]i04A[M`0jG840
@eil041hM@1BOF`0IgaO06imF@1eOeL0LGAQ06aZG`1UG6D0HeQV069PG@1QFeD00P1RG5D09`1/JD00
IfA006QI=P1XG3@0JEL[06aD9P1TAAd0HT0G060o601UAQl0JE4W06I77P1U?aP0ISTE06Xo5`1gAQh0
PU``081e@01^P5@0G81R04iaKP17J7D0A5ii04EQN017I7<0Cg1W05QhH01LM5h0FVeW05a_I@1ILV/0
EFm]05QcJP1IKF/0FFa[05AZL01FKVd0EUi^05eJK@0205=IM00W05aQK`15BH80H7=Z06:0I`1hQ5@0
QHe908F;B@2>P4@0Rh5708:2BP1fQ4d0MWe007M[>020FR@0OThM07I5601]?A@0I3@?06Lc3`1]>0h0
KC@;06`b3@1T:PP0DBD704dI10146080@1P303dJ101070<0>aL303XI0`0l6@D0?QX5040G1@0l60<0
=a@303<@0@0/3000<Ph00080=a<301T0@aX4050R2@1:70H0AQX404PI101860H0Ba`504/L1P1;7`D0
EB<705d^3@1Y?140L44D07A3601hDah0PFX[085k>P1mL3<0MUTS07=G801fG2@0LEHQ06UA7P1W@QT0
I3PB0080J3PC00`0I3<?064c3P1J;@d0DRD<04TQ1`127`L0@R0604@Q1`158PT0AB8504DQ1P0o7PD2
048N1`0W04PT201>;@T0Ec<=05`i4@1Q?A80K4TF071C7`1eGR80Of4R08Ib:P28Pc/0Q8U007f;AP1g
RTT0MHM<07j8B@1jST/0MXi<07Z?B@1nSTL0Oh]5082;@P22QTD0OHQ607V7A01jPSd0NWde07Qb;01d
I280KU4J07995P1dBaP0KddJ07=E701hFAh0NETM07]I6`1nF1`0RV0P0080TWHb02L0TXE008j;@@2A
ST00UXm009JA@P2ETT<0VHm209J@@P2HU4<0VYE109RD@P2FUT@0V9a209FIA02=UDT0SIU808nLB02>
WDL0RJA7096WA@2HWT00VI]009>M@P29WTT0PJ9:082RC@21Wdl0O9eD07VMDP1jVe<0MieD07BMEP1g
We80NIi=08:IAP27UT40QI=008RC?02<RSL00P2<Qc<06`2?Q300T84/08il:P2;Nbd0S7//08aj;@2?
PBl0SXTc08V;>`24RT00P8Hl07al<`1jJ2<0N5LM07A?601bDAP0L5@K06UC7@1UBQP0HClB05D_2P17
80D0>AP2030A0P0Y4@808``10206000201X8000:01T6000F1P0050L00146000<0P003`800183000A
10003@<000T200801`4000<00P400040000000000`000002004000030000000100000P0000800@00
00@00`0000@1000200000P000P00000<0?ooo`002P3oool00`0100000P0000<0000200D0000300@0
00030000104000801`8100H01`8000H100040000100000<00005000400@00080104002L01@4000H1
00070`001`8000L000080@00208000P300090P001`8000H1000600000`0000T4100;4@l03BD`014R
L@022J000ARX00dDXP0X7X@08QfC01<JW00B7Ih071J@020AU0085iX042j2018[NP0L77l06bB:01`[
OP0I:h<082^?020/L`0V<D409biQ01PZU`0P8IT00P0L69009`0R=580<RaA00dQTP0@<F/06beW02/Z
C00E660070n402XGM@0A6H`01BNH00dSXP0R5i009bf5014VT@079J@06ARL02@QUP0=7:D03bBM024L
NP0]9E@05BEb01<SS@0W9VP09bYO01DQLP0M9h<0?CI;03Q1A00S?G<0;C9m02XXO00E8HD07AfO03D]
R@0U=hP07R^>03@TR`0203HgQ00W024cR`0V;I<0=cB902hlP@0YA8T0>4:503mBO`0lF7H0@eQe04QF
M`1EEg00HE5Q061?F`1GFF<0IfEK07=RCP1RGed0EeeZ05AZK@1?KG00FW=Y05QlI`1GLfP0DW=[04Ub
K`18M7@0BG1g04UXM@15N7@0BX1b061kI01`P5L0N81G075hG`1]KV40J6=R06=QI`1RFf80HEYT0080
G5=V02L0IFQ706MM@01ZFCH0K5X^06eA9P1]CQl0J48G06=25P1S?aL0I4@K06a?8`1ZBAd0ID@K064j
501RA1h0J4@L07UA9P26HB`0Pg5007AkC01QNUh0EGQY04a`L`1:Lg80C7A[05AiH`1ENF40FgMR05Ed
J01EN6H0F7YX05YjJ@1OP640JWiK06Z0G@1UP5d0Ih1N06:0GP1TN6000P1MMfH09`1PLfH0Dg1^07:0
F01jRU80OXU=08R;B@25S4X0RhM508^4A`27P4<0Nh1207Yi@01iHbh0OE0O07I65`1d@aT0KD0G06<m
5@1R>A40Ic<>06Hb2`1[=0/0I2T905PT1@1C80D0BQ`503hH0P0l4P80?QH103/C0P0l4`<0>Q<303dD
100o5P<0>1L303DD0P0_3P00;@d002h90002038<000W048D0@1:7`L0B1/4048H0`164`D0AQD404<I
0`1>6`H0D20605HV1`1P<Ph0IcTA06m55@1eC1X0O5<O07iS:01oMSH0Nfdd07IC8@1dDal0NUTQ07=D
7@1aCA/0K4HG06Ll4`1S>a80Hc`C06@c401S<@l0GBh=05@Y301=8PP0Ab8904LU2@179@X0ARL:04PX
2P1790X0@b@80080@bH802L0B2T;058`301H=Pl0Hd4C06i75@1dE1d0Mf4U07UX:@22KBT0QGP_08>6
@01mS480Lhm<076<CP1bS4h0O8e;07NAB`1dTD/0MY5807NBBP1iTTD0NXm807^;A`1iSTD0NhM007Z0
=@1iMBh0MFXT07QQ8@1`E1`0KDLE06a2501ZA1D0KdDD079<601dDAX0MEPL07QF7@1oFQd00P2;J280
9`2BNRh0UHPk09F:@02FSD00V8e109Z@@P2IT440V99109JD@02JUT00VYM009^F@02MUD00WY=109NE
A@2AVdP0RYi=08RPC@26XTd0RjE709JQ@02FXT00TIe208RMAP20Wd`0OIe>07nID@1kVE<0NYUB07VH
DP1jV540N9eC07JND`1nVTl0Q9E908NE@@29Td00SHhg08f4;`0208^3;P0W08]o;02:NBT0RgPY08]i
:@2:NRP0RgHW08af:02>NBX0SGTY08Qf;@27MRh0OVXV07EF6`1]AA40J3l?064i3P1P>@d0Ec4<054[
2@1=8PH0BR8704<L0`0k5@80<QD302dA0`0V3`407PX001X7000G20004`800142000@0P003P<000T0
00080@00304000d3000>0`003`4000802@0000@00`000000000000000@000`0000000`0100000000
008000020080000500<000060@001@4000<0000200000P00000<0?ooo`002P3oool0300200001040
00@0000500000`4000@100030@001@8000P30@0:0P401`<000L200800`000P010000100200000`00
00D000040@0200D20@0700L20@050@001`8000T300070@001P8100P30@0200X40@0N00L300090P00
1`<000T2000<0`403@L501HG7@0I6UL010fE008?W0063J806an<028TR`0N8hh07QnC02<JQ@0S6Xd0
2Q:T00dQYP0E6Y`081>E00hHX@0;9j0032:K01`PV00N<hL06CYL01LjI`0L<hX092VA0P0L7iH09`0^
=V<0<35V00/NWP0?;7H07BeY02@/G@0569X06@nI034KL@0S8Ed03Bae00`WT00R6W00:bmL01DZM`07
9I`06aJK02LLT`0<6ZH03BFM020IRP0S5gl03QVN010OV00U8FT08B9g014FS@0M8hL0=c5;038hB@0Q
=gD0:cR202TTQ00E7Wl0726D03<[N@0R;8406BZ@03DSR`0203DhP`0W01lcRP0W:Y<0>3:502XiQ@0Y
>Y40>SV503i=O`0eDgT0>Dmh03m?OP1<F780DEIM04iEFP1CFf40FU=T06E=F01`H540K5aH05mGI@1G
Ffd0E6]`055cKP1COVX0BgA^04acL@17MGL0Ag5h04YeM011MWX0@81h05J0JP1ZPEX0LgmD07AfF01_
LEl0J6YU06IOIP1QGfP0HEaT0080FUI^02L0HfE=06AK@01[H3X0JV0`06]>8`1/C240J44F06Do501S
@1H0JD@K06U77@1XA1X0I4HK068m6`1NCR/0Ie0[07AO>@1kHSH0PFLb08I]=@1nMd00KH1A05B0IP1:
P6/0BgU[04]hJ@1@NFD0DgUV055iI`1CNVP0EgU]05QjJ`1QP5l0KH1G06b2F@1/P5T0Jh1H06V0EP1Z
P5H00P1YP5X09`1WP5d0GH1U07N5D01mTDd0Oi1=08N=B`26RD/0QhI:08J2B@29P400OgU007aX=01e
Eb@0MT@I074n5@1`@aT0KSlJ06E06@1Q>1<0Gbl=06@^3@1/<P`0JC0;06L_2@1N9@L0Cal504<G0P10
4P40?Q@103TB0@0a4040=A0103D?0P0i4P80>aD103@B0@0b3P80;Pd1030;0P0203@A0@0W03lF0`1:
80L0C1/404LH0`125P<0BAP504dF101>70H0DR8805P]2P1R=0d0JchD07I86`1nF240OehS081R901m
J2`0MUhX07A76P1eBQT0MdhM07175`1^AAH0Kd<F06Ll4@1R>Q<0GcXA064d3`1L<Q00Fc0@054Y2`1=
9@X0Bb4804TV2P1=9`X0C2`<04`/3P16:`d0A2L;0080ABT;02L0CS0=05Df3`1L?A00K4LF079D701i
HBH0NVT_07Mb>P1lM3<0Q7Xe0826@01jRTT0KHe=06^?DP1bSdh0MXm=07N@BP1eSTT0MY1807FDB01g
T4d0MXm:07F?A@1fST40MhXl07]l<@1kL2X0N6DS07ER8P1bFQl0KThI06Y2501T?140IClD06m65P1e
BaT0ME<N07UB701mE1X00P27Fad09`2<JRD0UGh]09F6>P2AR3h0TX]009><@@2DST<0V8m209ND@@2N
UT40WYI009jC@02NTD00Wi=009VEA02DVdP0RYa:08NQC024YD/0S:E609BS@P2CYD40SZ=608BNA`1i
W4l0LiYF07FGE01gUe@0NYIA07fBC`20TE40OYEC07fFD`22UDd0PiE708BEA028Td00S8Td08In;002
08Qe9@0W08U[8P28J240R6hR08U_9029Kb80QfXP08=T7`23IQl0QF@M08ES7020HAd0MeHJ06e44@1R
>0d0Fc4>05@]301>9`L0BB<5048K0`1060<0@aT403hG100i5`<0=aL2034G0`0V40408@`201l80@0H
1@4050<00143000=0@002P4000D200070@002P4000/3000<0`00308000802P0000<0100000<00002
00000P0100002`0300000P000080000200000@0000@000030000100000@100020@000P0000<00000
303oool000X0oooo01@00P0000D100040@00104000<000030@000P4000@100060@001P8000D20003
0@000`000040000200000@00008000010@001@4000L20@@02@@102D02P@100`60@0;10402P@000/5
0@0<1@402PD100T40@0:10403@D100`50P0=104040d501P>3@0L4Cl01166008=VP031j/02abK014Y
UP0C8i<07QZ<02LJN@0V88@041RK014UW`0L79<08Qj>018HW@0C:IT052BC01lOR00F:I004SN901Ld
R00T:hh09bn;00805bVL02L09cAd02`]M`095jX02Qf@00lPN@0A7WH00b>J01HIU00`86H0:bi;01Tf
J`0=:9409R5T03DkD00G;f`01R>A01/EV00Y5hP02aRO00dVUP0N77`09Ae`014OU00@8Y808QaT02HT
IP0E6i006B6@034SH@0V9G406R^602XdOP0Z8h<05R9i01dXRP0c;gD07Qio01LVTP0c8Hd00P0d=H<0
9`0K<XP0:RB:03`_OP0T=XP093BD03/fO`0kAGX0;dV103M9OP0oCWl0AEeh049LI`13Geh0B6IY05M:
I@1P@E`0I5EJ06MME`1MCVD0EU1c04e[M`19L7D0Eh1Y05B0J`1GMF/0D81[051fK@1>P6h0AX1c04If
M01:P6l0G81T06B0GP1]P5D0LGMH06Y]G`1ZK5`0HW9H06E^D`02061ZE@0L069VA01YFD00KF4d06UP
<01ZCb80JDXP06Y15P1Y?aH0JT4H06]46`1W?aT0IcXG06=36`1TC2@0F5a0065R@01TKD@0Kfe007=[
@021HRl0Q5h^07]Y@01]MDP0FgQL055oHP1=P6@0DH1P05Z0F`80GGmN00T0GGYP05amIP1TOEl0JX1O
06b0G@1UP640Ih1N06J0FP1bP5800P1fP5009`1bP580HX1N07B6D`1fSU@0NY5B08B;C028QTT0Q8E<
07f0C02;P400QV`d07aJ9P1^DB40KclF06/n601/CbP0L4LQ06i3701X?aL0H30>06H`3@1[<`d0K3<=
06`e3P1R:@T0DbH604TN10105@80?Q<103H?0P0`3P80;Ph2038=0P0g4@80=Q@103HB0@0d3`40=0d0
03<<000203<>000W04<E0@1:7@L0Ba/404LE0`115P<0AAL304PN0`1<70H0DAl605LX201N<P`0Kc`C
07E96`1lG2@0O6HV07UO9@1fFb<0L58P06e05P1`@QH0Jd0F06Li4P1W>a80Hc`E064h4@1O>A00HCTA
06<k4P1P>140GCD@05@^3@1E;0`0DRL;050Y301B:0`0Cbh?04h`3P1><140BC@B0080D3L@0180E3XA
05Tk4@1P@A<0KDTG07=G801dIb`0LW90071f@01jNd00OX9007Z6@01aRTd0J8eF06B@E`1YTU80K9A@
076BC`1cTT/207>AB`0C072DB`1dT4P0L8e407><@01eQS/0LgL`07M^:01fIb<0MVDU07MW9P1eGb<0
K4dI06Ho501W?Q<0KD8D07964`1dC1X0MDdG07I>5P0207iF700W08QW8@2@LbT0TX0`09>3=@2@QCH0
ShTi092<?P2CSd40UXm009f@@02LT400WIE009bC@02OU440ViI209JKA@2=W4/0R:1<08FTC02;XdL0
SZE708^UB`29YD/0QJ1<07ZKD@1dV5@0M9QE07BFF01kT5<0P8m<08FCC029TTT0Ri9608f?@02<T400
RI9008NB@024Pc00PG@W0080OVHT0240O5TK07aG601lEAX0OU/L07iK6@1kEQP0N54H07IA5`1hDaP0
N5LH07=E5`1_BA<0I3/>05L^2`1@:0P0BR07044L0P0k6@40>a8303`E0`105`<0?QD203XF0`0f5P<0
;Q4302XD0P0V4P808a41024>0@0K2P405PD101D5000@0P000P0:0P40100=0P403@4000X000080002
00<0000500<1000200000P000000000100000P02000200<0000600D000070000104000<100040000
0`001000000<0?ooo`002P3oool01@050@001@8000@10@020@000`400080100000@00`0000H00005
00000`400P0200001`0100000P0000<000040@001@8000L30@091@400P0;1@809`0<1`803@L30108
0P0A2@804@L201050@0?1`803`P200d60P0;1P8030H100d60`0=1P8030D2014<1P0J3Ph04`l[00HL
G@0468P00PRW01LQO@0I;gX06BEY01TLDP0P8E408amc02HRQ@0S:9409B>;024^S00B89/04bVM01TO
U00Q8i403anL00XaX@0D9IL0:1j@02P]S@0201DaVP0W02HeO@0_:7l0212`00@=/0042J`011FJ000W
Z`0B7YD0;29T02LbGP0I<6l02b>A020KH00W:UH04RUJ00TYN`0K5hL0:a]W010OR00>9Y007b5f02h]
G@0H9h803bB>01hIPP0Z9Gd05b6N01DMY00R49X06ABT01PSWP0[;GP0<2MS01XPM00P;HD0@SUO02TV
GP0M;7l0=bUg0080=C5g02L07S=k02dZP@0j;G<082j402<^U`0i=X<0<d6202XnR@0d?HH0?Den03]L
N`0kFg@0?em`04YVL01NDfD0I4]O05QBJ@1MJeh0IUMJ06QCGP1LH6P0FVQ[05=oJ@1CMV/0FGEW04ig
KP1EP6H0EX1W04F0LP14P7@0@W=i0520KP1DP6T0HH1L07B0E01eN5@0KgM>06MfC01WLTD00P1NL4T0
9`1WHd<0JE/j06eQ<@1ZFRd0JDlS06U:7`1Z@QT0JD@K06M3601VA1T0GcHD05dc4`1R=aH0HSdJ061>
;01QGCT0IVi006m]@P1aMTX0MW9007mU=01mFbd0MF0h06UfB`1LP5P0CH1W0560H01AOe/0H7mG05b0
E@1KP5d0H81S06:0H01TP6<0IW]T065fK01RP6D0JH5N07>0E@0207R0C`0N07F2D01UQEd0L8EJ07F:
E@1nSU40QHQ<08Z2B026PDH0PH=908f0@024Ibh0MdlO06i97@1/?Q@0J3`E06i26`1`@aT0L4DM06Y2
5`1L<Q80G2d=05h[2`1S;0/0HRh:064Y201P9`P0CQh404HF0P0l5080=1410P0c4@401`0d4040=a41
03X>000n4`80?A@003P>000c3@400P0f2`009`0n4P40B1/704XI10165P<0?aT404LI0P1970D0C1l6
05<Q201G9P/0HC0<06`n501bB1P0OE`S07e];@1hI2T0LULO06Y76P1X?Q@0IclC06Do4P1P>100GcXC
05dh401J>180H3TA06@m501U?A@0GchD05Xi4`1I<Pl0Fc<>05H`3P1A;@l0C2T=04h/3@1<;`l0EC@B
05<i4@0205<h4`0W05Hi401M?Q<0GClC06M05@1[B1P0L5HO07IX;`1hMd00PG/k08J2@020R440MXM<
06Z:E@1VReP0HhiG06NAF01ZTe<0L9AC07BBB`1bTTL0Li=907F<A`1cRD80MHY007Am=@1bKBX0M6HT
07MQ8P1kIbD0NG0Z07Q]:`1bEQh0Jd4D06Lo4`1Z@Q@0Jd8E07A6501eAQ<0LdLE0080MDdF02L0OeDM
08YU802>K2H0T7<V08ig:@2>NR`0ShDc08j:>`2ERCd0WhU009j=@02JTT40VY=009jC@02MUT00V9U4
096NB02<XT/0PjI?08RWB`25YT/0Pj=>08JSC024WDX0OiU?07VID@1eVET0MIAJ07R@F01lTe40PIE;
08VBB02<Sd00THXl08n3=02:OS40P74Z07eX8`1iFb400P1fE1/09P1_AaD0JT0?06Q03`1_AA<0K4<B
06i64@1`AA80KdTC06i84@1]Aa<0IdDB06<m3`1K<0T0BbL604<M100l5P<0=1@1034@000a4P40=a82
03hB0@0k5P40>aP203LG0@0d4P80;a8202P?0P0S3P<08P`2020;0@0J200060D00103000>10003`<0
00/200060@000`00100100000`0200000@000080000200<000080080000100000P00008000030000
100000<000020005000000`0oooo000:0?ooo`0800@000030@000`4000<1000200000P4000@10005
000200D1000:00<0000200000P000000000100000P0000<000060P402@D200`70`803@T302L040/4
01<<1@0D30@05@d401@<100E2PD050P301080`0?1P<03@L200`60@0>1P<03@D200X50P0G30T07PlV
00P9CP046d<01B5/01@FQ`0O7g408bU_028T@`0F6Qd07BPh01LWL00H79D09R:F02dYS@0N>H/03bnI
010VVP0K6i@09BVA01TRV@0B99H052>D01lURP0S:X/00P0S;i009`0b<7l0<bR500PA/`032kT00@Fe
008AZP029Zl03a^L02LJJ`0L9fD03R=j00PRR@0L4f/08Qi^00lXN`0;:8P06aZ?02dQLP0H9Hh03B6M
01LNVP0d=7009S1V00lVO@0J7I<0<Bag020aN00J:X409AR6028QU@0H:Y`0:BUh02`RI@0K78D08BZ6
04i1D00b=eL093Ih048gK00203D^L00W02@cL`0c<H00?C5f01hWNP0T:I40>39k03<lPP0W>Hd0>3R4
03i<M00dCWL0?59h049BO01>H7H0HF9T06IJH01LG6D0F5YS06Q<F01/EEL0EUQX05aUJ01HP6D0EGeX
05n0HP1JP6<0H81P06N0F`1RP600F81X05:0J01AP6/0DX1W05^0HP1ZP5P0MH1?07AgAP1`MD00IG=3
0080Gfe902L0IfA006QJ>`1ZF2d0ITXP06E0601Z?AL0JclF06a6701U?1@0HSXG05`b4@1I<a00FBl@
05L/3`1J>AH0FU<d05YZ@01QLd`0GGEK06UgD01bL400NUT]07MD9P1bHcX0J79805UjFP1IP5H0FWm@
06B0BP1SP4/0Hh5A06:0E`1UPEX0Hh1P06^0G`1]P600M85J07Z0E01oP5800P1oP5409`1lPTh0M8=F
07N1E01jQE<0OXI=08J5B02<Pd80SHE308>3@`2;P3`0QF`^07aA7P1^Bad0K40H06Hm5@1/?A<0KcXB
07115`1Y?1H0GCLF05`b4@1P;@/0H2T905`X2P1H8`L0EBD604lO10166PD0?1L303HD0@0l5`80?1P3
03dG0P0k4`40>10103DB0@0m4P40=a<003<=0002038;000S03PA00105`40@aT104LK10186`D0AaT3
04@H101>8`T0F28805dW2@1T;P/0KSXB07=35`20FR80OW4^07M/;P1cE1d0J3lD06/k4`1^@1D0JSdA
06Li401P>180GCDA05Xe401R>a80Hd0E0650601Q@QD0Gd4G05Pk4`1K>140GCDA05Xa401@:``00P16
:`d01@1=<100Cc0A054c4@1A<a40ESPA0080Ec/A02@0G3/A068n4P1YBaX0LehT07Y^<021MC40RG`h
08N3@01nQDL0LHM@06R9F01QRUP0Fi5L05jFF01XUU00M8i;07J=A@1fS480MX]007F8@01gQS`0MWHa
07=W9@1dH240Mf@Q07UZ9P1lJBP0O6@W07EA701Y@QD0Jd8A06]7501]AA80KDLD06Y35@1_A14207=5
4`0W07Y<5P1oFA/0Q68Q08UY8`2:JR<0RFhW08Um;`28QcX0THLk09R7>P2JRD00Vhi00:2>@02SST00
X8e009jF@02FVT@0SJ5;08FTC`24Ydh0P:MA08>SC`28Wdd0QYe=07nKDP1jVU80M9aJ07NFF@1jUeT0
NIUC07jFC`21Td`0RXa008Yn<@25I240N54J06e4501Y?Q80I3dA0080H3X?02H0GcP>05Xe3@1K=0`0
GcL=068i3P1T?@l0IT4A06M44@1T@140G3/?05/h2`1K=0/0CRX804@S1P0n5@@0=a43034A0@0b4@00
<A8003LD000k4`40=a@103@D000]4000<0l202P@0P0X3`8090l302<?0`0P3@8070`101P6000D0P00
3P<000/300070000104000@000@0000000H00@000080000400000P4000<100030002008000030040
000300000`0000800P001@00000<0?ooo`002P3oool0200300000`4000<100030P000`4000@10005
0@001`400P060P002P050000100000<0000100000P0000<000030@001@8100P40P0:1P<200d90`0W
01@;1P0B2`@04`/301H=100E30D050X401H:0`0D2@<04@L201090`0A20803`L300h50P0;1P407`X;
02L?AP062I<01aA400PMC@043h<031B=02<LM00[94<06a/T01`]A00F=gL05b>F02@UQP0W9hX0:C>7
024cS@0Q8hP06QNG01hUV@0I8Z406QRJ01@LVP0E<IL052jC00806C:I02L0=2n103D[Q`0:5K800`b/
0045]`033jd012>^00hGYP0T3hH05QZ;00PRV0068iH06a:D02/PR00D;Y@02RFH01LIW@0/88D07BND
00XQXP0D89/0=CA/02hnB`0C<VT07BN703dmF00`@e<06SMa02@PR00W<I405RfR01dKW00P4YX05ARX
01dWSP1:?E<0;c1V02HgO`18?VX00P0g:Vl09`0/=fP0=CEo03dcM@0N9W808BN=03P]N`0];H@0:3B@
03`dQP0iAgd0:T=e02i7P00mC840AEe`04mKH@1FFfD0GU]U05m3I01Y>ed0KE=I05mJH`1MIF@0G7aT
05f0H01QP5h0FH1T05b0I01PP600IH1J05j3H@1KP6@0FH1X05N0I`1JPf@0Hh1M0720C`1fP400LgA0
06Q_@002069ZA00W069T@01QG3X0HE8]06<o6`1T>AD0ISXD06@k5@1XA1X0IC`E05dn6@1L=180FcTD
05Tf4P1E;@h0FB/?05hk7P1LC300IF=006UeA01ZNDP0KgM507a[@01jERL0Le8U06aL>01MKd`0GGM:
05N0C`1PN4D0IGQ206=jAP1VP4`0K81@06b1E01cPeD0M81I0860D024P4d0QX1<0080R81<02L0Ph5<
07f6C@1nPdh0P8A=08>5BP28PT40S81008Z0@024P480Qh1008Ig=`20GRP0KeTV06i:7@1/@aX0JchG
070l5@1_@1D0JC/D05/f5P1L<A80Fb`<05PV201E9`X0DQl604dP1@198@H0BA`4044I0`1170@0AAl5
04DO1`167`D0A1T203L?0P0f4`40>Pl103<>000_30000P0a30009`0c5000@QL504<J0P1=6@@0Cad6
04LG10125`80DQh505LW2@1I:PL0HRd;06`j4@1a@1P0NeLP07Y/;01hI2P0M4dI06Ll501Y>A@0K3`B
06Xk4@1U=@h0HcT@05hc3P1O<`l0FcPA05hh4@1R>a@0HT0D05m1601L?AD0FSTB05Te401D<@l0D2l=
04/[3@189@`0AbL;04TY2P0204PX300W050`3@1C=0d0ESH?05Xh401I=a40GD4E06Q=6`1aEal0O5`R
089T8`28KR/0R7]00862@01iQDL0KhM>06N:D@1STE@0HiID06jCD01cSd/0Mh]407F;@01cR400MHM0
07R2>01eLB/0MFXV07U^:P1kKbX0OFXU07UM801fCQP0LT0C07155@1^A1@0JDPD06e75P1_B1H0KT8C
0080LTDB02L0NT/C089D6023Fa`0Pf4N08QR8@27IR<0RG8Z08F4>02>QSL0U8Lh09R8?02LR3d0WhPm
0:::?@2QRT00WHi009NF@@2AW4H0QJI=07^]DP1jZE<0PZ=>08FMC@20WE40O9mC07RLF01hV5X0LiIK
07NHE@1mUTh0PI=808J<@028OC80Q5hN07M95@1W=`d0Fb`905LW1P1D9`T00P1H;@X09P1H;`d0F3<;
05Xi3`1L?Q80H4<E0696601VC1P0IDTH0651501I>@l0EC@=050c3@1<;@`0BBP903hG1@0f5040<180
034A000d4`00=A8003PD000c4`00<A8102/>0P0W3`<0:0h302P@0@0T3P808@l201h<0@0J2P005`L0
0142000A0@00304000H0000500000P001P0100002003000010000080000300000P00004000020000
0@001000000010010000000000000000000<0?ooo`002P3oool0500200000@000041000200000@00
00@000050@001P4000L100070P001@8000H0000300000@40008100020000100000D20@080`402PD2
0P0<20<201@:100U018;0`0B2`@050T301D<100E2P<050/401@:0`0F3P@060d401D<100B2P<03PL2
01T91`0V5b807BQ901HK900F73T01`m]00H?G`0E74@08bHm02HTC@0V;W409C:702</T00M;h`06RVA
01lYU00Q89H0;b>:01`GW@0?7J<02afZ01dHW`0G6I`05SJE01DjSP0201ljU@0W03LoP00a<XL02aF_
00H@[`042ZP01A6R00PRY@0>5Yh09Q=b01`QM@0A:WP02bR601TFU`0Z7X/05BjC00XUV@0E6j00:af<
01lUU@098J@0426N03<dK@0hCE006D1[01ddR@19CE@0?55;01`lL`0U;8X0:3R501H[T@0N7X@091^<
01/NXP0K89/0>BIW02HQOP0V;XL0BCaU0080>bM^02L0<3UQ03HjO@0m=7L06REc02DVSP0m:H<0:b9k
02`^P00k;Vd0>3aW02DlJ`0`@7l0>T^403eLM`0nEfT0AUYZ055JK`1N?Eh0GcUK05a=I@1OG600EfQV
04adJP1DMFL0Eh1W05>0I`1PP6<0GX1S06N0G01XQ5T0Hh1L0620IP1LP6@0Fh1R05f0I01WP5D0MgM2
07Ed@01^JT000P1PJT009`1PHd00F5/l05]?;`1S?Ql0IC`G06Hj5@1V?Q@0JTPK06M46`1PBBD0HShG
060o5P1I?1@0DS<>050V201>80L0Db`>05]3901PID00GGQ@05n0D`1/P4P0N6`k07UA8@1_CBH0J64k
06E]@P1HMdX0GgI306=^@01QKd00JGA1079i@P1fP400NH1907N0B`20P4X0PH1<08>2B@0208^4B00W
08Z2A@23Q4<0QH9308F6@`26Q440Q81008V0@028P400Qh1008J0@022P400PFX_07AP:P1dER@0K58R
06]77`1^@1T0KclF06/g4P1O<a80FRd?05@Z301D9`T0EbX904lT1P1@8`P0Bb4404hS1`1:7P@0BAl7
04TR20177`L0AQd604DJ0P0o5080?A<103P;000e4000;Q410080=0l102L0?A@104TP1`1<7PD0BaT4
054N1P1960@0BAL405@N1`1N9`T0G2P:05d^3@1U>0l0L48F07YF7P1iJ2/0Lf0W06m:6`1/@AD0Kd8F
06Tm501/>a@0Ic`C06Hj5@1N<Q40FS0=05L_3P1D:``0Ebd?05`c401O>QH0G3LD05Th4P1I>Q00EC<B
04X^3`14:`d0A2D<04@S2P158PP00P1290T09`169@T0BbX<04l_301D<Pl0DC4>05Lj501M@aL0J4LF
071:5P1kCaP0QEXL08aT8P2?KRX0RWLe08>2@01jQT00LX]906VCCP1ZTdl0L8m;07:>B@1cRdL0MXU3
07V6@01jPc/0MgD/07Q]:01jKBT0O6XW07mP8P1jE1/0LdHF07904P1b@140K44A06I04P1S@A80JD8D
06m14@0207E34@0W07]85@20DAP0PEDG081G6P21FAd0PF4O08E_:020OS@0RX4b08^2=02=QSD0TXDg
09^5=P2MRCT0VX`m09V=@02EU400SY]208VRB@1lZTl0OJMA07jRC022WT`0PYm@07^OEP1fWeL0NYEE
07FEEP1dUeP0MIQ?07VBA01nP3L0O5hP070o4`1U=0d0HBl;05X[2P1C:0L0E2L70080ER`:0100FRh<
05`f3P1N@QL0HE0M05mJ9@1OHbT0I6@[069Q:01TF280GdPJ05M35P1F@aL0DT4F04df401580L0<A81
0P0Z3@004P0^3P00<0l103D?000c3@00;@`202/=0P0Z40<09`l302H<0P0R2`407``201X<000G2@00
4`H00104000>0P002P4000P000801`0000D01P0000@0000400000P00004000020081000400<00002
00000P00008000@00@000P0000000`0200000@0000400002000000`0oooo000:0?ooo`0900400000
000000000000000100001@4000H300070`002P4100802@4000<01`0000<0000300000P0300001005
00001@4000H20@09104200h90`0W01490`0E2@<04`X201<90`0F2`@05P`401L=1@0H3PH060l601/B
1P0L4`L06@l601L<100A20805PT301XB2`0K7aL05A<=020J9`0?5V<01QE:00XJ9`0H;3h07BY]01`M
T00Y8i80:3F901PjQ`0=:Y004R>A01TJV00/9HP0:b6:02D[S@0R:Y@08BRB01`STP0K;i807c2=0080
9cZC02L0<4^602HjT0084[001aBF00dILP0=8Vl03Bj3014PT@0Y96P0;C=H02DgGP0D;gT05aRF02LM
S@0G;Y<02RBL018KXP0Y6i008B:G00TOZ00=7Z<0:bMe02TeH@0@;7P062^603Y0GP12F5409D=`02Th
OP0Y=7d04RF701PJS00V9X`06bRP01TMX`0b5hH091^D02<YTP11<fP00P0g86d09`0^<f`0=SQn03Xa
N00M9Fh08RR>03/]Q00]9gD0:S9h03h`F`0f<6<0:S=a03<cQ`0hAH<0;ER0039IL010FGL0Ce]a05a@
I@1BC6X0C5Q_04eQJ01LHeT0FF=O051WJ01CLV`0EV5/061eH01LP680HgmK06V5F@1ZPEP0JH1J06F0
G01MP640G85P06>0EP1bP4@0M7Dk071V=P0206MW>`0W069Q@01LFSX0H50_0656801U@AT0JclG06Xo
5P1[@aX0J48I06E57P1Y?QH0I44J060n601L>1@0ER/=04/P1@1E8PP0H2lD06549P1UJD00Ig]706N0
B@1bND00NEdZ07=;7`1^Db`0KF@l05a`B@1RKT00FfE005QQ@01HHT00HFM006a]?01bMd00LWU407N0
B@1fP4d0NXE90080Q8=30P26P4009@25P400Q8100860@01nP400P8110860@@26P400Qh1008B0@026
Mc@0PFL^07UL9P1/DRD0IDDM06Di5@1W<A40H34C060g5@1M9Pd0DR8905/U201L:`/0GbL:05PU2P1F
8PL0EB@5050S1@1>8`L0BB0804DM1@127@D0@AL4040I0P0l5`80>101030@000d4`400P0f50809`0o
5`@0BR4804LS2@1<80L0CAl604<H101860D0F20705PW2@1E9PT0FbX;06<c3P1]?a<0NE4P07IU:@1b
GbD0LdlN06e76P1_@aL0K40E06Dn5@1Y@aH0J4<H06Dk4`1G<@h0DBT<04`T2@1?90X0Db/@05Dg4@1J
=A40G3X@05`i4@1C=Q40CBlA04@/30179`d0A2D:048R2@02044P1`0W04DP2@199PT0BRH804d/2`1A
<0d0ESLB05Pk4`1S?QD0Jc`A07595`1mDAT0PETI08QL7@28I1l0QflY08Aj<`21PS/0N8M307:7B01a
RDT0MhE307^6@020Q400OX@k07b3>@1iNS00MG<]07]b;@1mKBP0O5lS07QB6P1dBa@0LTHE06i35@1b
@a40Jd<B06Po4P1V?a<0KD4D0080N4DE02L0ODdH085F6`22FaX0Pe/L081K7@20Hb40OVhV081i;P23
OC00Q80^08>5=P28RC/0ShTk09><?02DSd00Ti50092E@02>VT@0Qj1807fXCP1mYdh0O:Y=082QC@1o
Wdd0OIaB07bGD`1iVDl0NYM<07VFC@1fTDL0MHA007MV:`1`A1L0Hc0;05hZ301H;0/0Fb/=05h^3@1P
<`h00P1T?1406`1V@aH0Id/J06MD801WFR<0IUhV06MZ;01WKB`0KFX/06US901RFR00GePO05iI8@1J
EQh0FDLG04/_3@0n7@H0<A8202H:0@0Y3000:P`002D<000U2@009`P102L<0P0V30407`/101l90002
01h9000601/8000I1@0050@001<3000@0P004@<00`0:0P0010080P002`0000/00002000400810004
00<0000000000@00000000@00@000P00000010010000000000000000000<0?ooo`002P3oool20040
0008000000010000100000D200050P401P8000H10007000200H3000800H200050P000`4000400002
00000P4000@100080`4200T50P0W00l50`0A1`804PP201<:100D30@0610701TA1`0J4`P0718701/A
1`0I40H060/501D;0P0C20<04PL201<:100@5AP050h6020F6P0A7T@02aPc00XG:P0F=dd05baV01PJ
S@0X9Gh0<S5S02lhJ00U<7T06R:201LKTP0R:H/092N<02HYSP0Y;i@08CV@01DaT`0D;9H08BBD0080
9cV;02L09e6:01m0U0084;0021:600lRH00I<UH04cUc018WUP0Y:XH0=C]X02PgF@0G;gH051Z?02<I
P`0G8i002b:N014PX`0Y7Y80922G00/LZ@0>6ZX09QV;01hMR00<7IP04R2B03<]O017DUD09CaZ02Pi
M`0]<V405BAf01DRVP0Y<h<08C6:028aO`0n<E@0<2]h024WT00c9W`00P0a7GL09`0[;G`0>CUg03h`
MP0O96`07bF@03/aP`0Z9g009C5h044jFP0f>5X09C=a03@]R00n?gl0:D^302m>P`11CX00AU]l05=V
LP1=H780BV=_059>J@1SB5`0HdeV04mQL013LWP0EEQ[061dH@1JP640JGmI06Z3F01[PeH0KH1G06J0
F`1QP5h0HH9N06B0E01cP4<0MGE007IU=00206eR=P0W06MR@01WFc/0IU</06Q=8P1]Bad0Kd<J06Q0
601T?QH0ID0G06E2601P?1L0Hd@N06=36@1R?AH0EC8@05<T2@1E8`L0E20805LX2`1Q@A`0K5``06Eh
A01^ND<0N6H`07M>801^C280KUL^06QW?@1UHCP0GU/`05YB;01KDB`0GeP^06IS=P1[Jd00J6m0079h
@01eNT00OH120080Ph1002L0PX10085i?024M3D0P7Pj07^0@01fP440Mh1707n0@@25P400Qh1008F0
@027NcX0Pfla07]G9@1]BQl0H3/E05XZ3P1K9``0GBP=068f501K:@/0DR4605PU1`1O:PT0FR@705XU
1P1K8PD0F2<7058S201=8`H0BQ`504@M1@116P<0@QP2048G0P105`80=1<203H@0@0d4`400P0i5P<0
9`116P80AQl504/N1@1D80H0CR4804PK10156PD0CB0905@P201B8P/0FRL:05l[3P1Z>QD0N4hM07YP
901iGR<0M58O06e9601X@A@0HSdD06A1601VA1H0JdTI06Hn5P1P<Q00EbX:050X2@1>:@T0DB/;058c
3`1C;Pd0FC0<05La3P1D=@l0BC0@04H/3@169`d0@bH<040R2`0203XO200W048O20188@P0AbD704TR
2@1<:0`0Cc4?05Lc4@1M>a40I3dB07A9601nEQ/0QU`O08IJ6`27HR00RF/U08Q^9`26L2X0PWTb081o
=P1nP3X0Oh0i08Al>027PST0R8@l08>4>`1oPSL0NH4e07Um<P1hM2d0MVHV07AE6`1cBaD0LdHE07=7
501fBAD0LD/D06i65@1_@A@0KclC0080MdHE02L0OE4J08EG7@24Gal0Q5/J08=M6`22HB40QFTU08Ma
9`22MRP0Q7PY0865=01oRSd0Phll08ZA@02=U400SiM0092G@02>VD80Qim7082WC@1kZ540NZY@07bS
D01kX540NIUD07BEE@1eUTh0N9=207^4>`1jJR`0LUDQ06a15P1Q=0h0Db/7058[1`1C;PX0FS0=05lh
401UAaT00P1YFB804P1]Ib/0KF`a071_<P1bK2`0MFl[07Ud;@1iN2h0MWD^079/:P1^IbP0JFX[06IZ
:P1PIRL0GE`R05I86P19<@h0>24702hB0`8090`101<09PT102<9000Q20408PL101h8000L2@008@P0
01d7000O20008@L001/5000J10004P<000l2000=0@002`8000X000080P001P4000801`0000H00P00
00<100020@000P4000<10002000200400006008000020@000P400081000100000P000P0100000`02
000000000000000<0?ooo`002P3oool02`0200000@00000000010000100000@200050`401P<000D3
00070@001P8000801`8000@0204100@1000200000P000P030000:P050@00208000P2000:0`803`D2
01470`0D2@<050/301H<1@0K3PD06@l701TA1@0I3`H05Pd401D90`0E2P8050T301460@0D1`804Q4?
0108100G41402Q@g00D9EP034W006CEg01h`JP0G88T07BB002TZL@0/:WT09S>801TaS`0D8iL05c69
01D/S00J98T092f?02LoS00P?8l08Bb802@UR`808cZ802L094N501`eMP0?5Gd01`ej00THK00?:ET0
2cEe018[TP0U9hX0;Rie01dVI@0F:WD04Aj<01dBQP0A4iH02AjR00dPY`0X7i<0:22B00dHZ@0=6:X0
9QF0020OP00;7IL03b2F02`VQ`0f?FX052ai01`XM`0Z<6L06S2101`cQ`0^?G408RUk02HkK@11@640
?3M`01hTS`0_8HT00P0b88009`0X;XT0=39d03TWIP0R8gD092J<03hbP00[9g009C1h04M1FP0f?FH0
935h03DWR@0n?8008d2202`oQ`12B7l0@E]j04=VMP19Ig@0D5ib05`kI`1W>E/0HE1H05ESHP1>HVl0
H5YP061nH01GOf@0J81J06N5G@1`PeP0K8EI06F4F`1PP5h0Fh1Q05b0GP1[P4d0MWI007YZ<P0207AQ
<@0W06mS=`1YGC<0Je<W06]>8P1ZAah0JT4F060l501N=Q<0HclG06A27@1U?aP0IdLN064j5`1M>aH0
F3@A05@Z301@9`/0BB8704TN201?:@l0HCLF06]J<P1_LS`0MFH^07EC8@1[B1`0IDPR05mE;01OEBd0
GEP]065=901LA1d0ID/R06UI:`1/ICP0Ife006i_@01gLd00O81000<0PH1002H0Oh1008=g>021N3/0
O7U007Uh@01cNT<0PX1008F0@028P3`0Q81008Ii?01oL3H0NUTV06];7`1J>1D0DB/>05D[2`1K9`d0
ICPE060_3P1J:@X0HRD905XY1P1E8@H0DR<605PQ101>8`D0BR4504XO1@1;70@0@AX3040J100k5`<0
>QH203HH0P0i5@00>1H203/F0P80>aX302L0@a/404HO101970@0BAd604XP1P197@H0C287058V2`1C
:0d0G2T<05`X2`1O;@l0K3lD07E:6P1iE1l0MU@N07A;701_AaX0IShF06@n4`1Z@1P0JT8F06a35`1V
?QD0GSPC05dc3`1L<0h0EC4=054/2`1A:`d0CRP<050W2@1>:0/0CRX=04//3@1;:@h0AbT<044T2`0l
80X00P137PT09`138PX0Ab@804LS1`178PH0BR@9058[2`1F<0d0HS/A06]35`1eDah0PV4Q08IW8P2;
Jb<0Rg0V08Yc;022LR`0PfhZ07e`;01mLR`0O7@_07ee<024M2h0QWdg08F3>`20PCL0P7/b07aj<P1k
MBl0Lf`Z06iU9P1bEAh0KdTG07585@1dB1H0MDPE07I<5`1cC1L0Ld@D06m0500207=34`0307]@6@22
F1l0PV0P0080QF<O0280QVPR08Q[8`29L2L0PgHY085m;@20RSD0OHln07fF@@22V480QiY208VI@P2=
Ud40RYY308BOB01lYDl0MJQD07BVE01fXE@0MJ1B076GF01_TUD0LI9<07N9@01kJ2P0MDTF06Lh3`1J
;P/0EB`805D]201H<Ph0GchE06=77@1]ERH0KVP`0P1aLc@09`1bO3L0M7hf07Uk<P20NRl0Pgd`08N8
=`21Rcd0NHU00762@01]Od00Jh1006En>`1VMc@0GVh^05EO9@1>@aL0?bP<038H1P0/3`8080T10248
0@0T200080H001`6000J1`006`D001d7000O1@007`L002<:0@0Q2P006PP001X7000A0`003P8000d0
000900001P4000@0000300<000<00@0000D00P000040000000000@00008000020081000800410002
0000100000D000070000100000400000000<0?ooo`002P3oool00`0300000P000080000200400005
00<100060P401@<000L200060@000P080`0020090`001`8100L200050@00104000<1000600001@80
0P070`009`0:0`403@D200l50P0B1`803`T3018:0`0F3@D05P`601H=1@0F30D05`d401<80`0D2P80
4PP301470P0F7A@04`d801<80@0B2a801PQH0041[@064jD05B6R01/bQ00=<8803Bak01HXNP0N7h00
8Bf4024kM00M<8@093Mb02D`I`0U:6`0:Bam02hjQ00`>hT0<cB5030`QP02028jR`0W00dTQ`0A7780
3A9b0084P@0448D01REn00`fQP0A;iT08RF902TQQ@0B4Y4052A]010RNP0G4W<03A9e00TPS00;8Z00
:2=o038cH`0B:8T03B:E028OL00W;Fd03b2600`SV@0T8I40:3J900`[T@0C89/0:S2>020iUP0L>XD0
=3YM02PYG`0P=gH0>d1f03ThN@0T<7D0=C9O0080?SMH02L0;SMc02/_NP0g:G40;2^102XYQP12=7D0
9b9^02@ZO`0o=V<0<cAL02@eM`0f8gP0>cUd024lM`0]>8/0@4J303UHP`0cGg/0>fIl04QIN@1M?f40
GTE>05A8G01DE6H0EDY/06AMG@1PP640FX1S06V0EP1[P5T0KH=J06^6G01ZPeT0Gh1S05N0JP1@MVh0
I81E07:0@@1kMST00P1eIc<09`1/Hcd0IV4l06EH<@1UCbX0HdHP068k5P1M=Q<0GcHD06A36P1UBal0
J4PN06M@9P1S?1P0Fc/D05Ld4P1@;a40D2T=04LP1`107@D0@Qh904TS2@1P=A@0IE0U06YM;01_Db40
KDPM06U:7`1QCb@0G5D^05AM?01PDbh0HDHO06936`1ZAQ`0KUPZ06]Q=`1_Hc40N6Db07ef>P0208:0
?@0W08>0?@23P3/0QGPf08Ae=01lM3L0Ng0f07Qe?@23McH0QGXi08Qk>P22P400QX0l07ib=P1kHRT0
LE0R06Dm5@1M<180Fbl>068a3P1Q>1<0J3HA06<e4P1S<0d0FbL805`Q1P1F80H0EB85058R1@1?8P@0
CR0504XM1@136P<0=AD403<D100c4@80>Q@103TH0@0h5`<0=aL20080>1L202L0?1H403dG0`114@80
AAD404PN201;80P0DR<905<Y2`1L;`l0Hc@A06@_3@1R;@X0IcPA0751601aBAX0L4DH06m75`1^AQP0
JT4F06a15`1^@aD0JD8F06Y14`1V@AD0HSdF06@j4`1Q>A80GCTB050_3`1A:@d0B2@904HP1`1990P0
Bb8804`U2`1::@`0ARD;04DT2@1790X00P168P/09`1<:@d0CBP;04hX2P1@90L0CbH705<Z301L<Ph0
ICdB06i@6@1hHR80Pg4[08Mh;@2<NRh0RgXb08Ml=@27NC40PG<_07ab;@1hKb/0N6`/07]_;P20KRd0
QG@`08Af<P23JbX0OV8V07mQ9@1kH2D0LU`O075G7P1`D1`0L4XH07575P1bC1P0MTTH07EA6@1jDQX0
M4/H07=65P0207I75@0W07]B6`20G200P68R085V9021Ib<0QFPS08MY8`2;Jb80QW8Y08Am;P23RS@0
P91007bG@P1oVd@0PIe608BMAP26W480RYU7082NB`1eXe40KZIJ06RRG01[We/0KiaD07:ED@1kT4H0
PH0l07iP9P1dB1H0ICT<05``2`1J=0X0FS4;06<h3`1ZBAP0LEhX06m`>P1/OT80JhM80080M8a302L0
Mh]007V5=`1kOBh0OgX]0825<`21TC`0N99306bDB`1WUE00HYI?062EC@1VT4<0JH<i06=f;`1QI2H0
E4hM04Pg4P0i8@X0:a<4028<0P0L20007@D001`5000H1`006@H001/6000L0`007@@001/5000O2000
7@T001h8000I1P0050D000l4000:0000204000H0000200000`0100060000000<0080000000000P00
008000030000100000H200080P00204000H0000300000000303oool000X0oooo00<00`0000800001
00000P0100000`050`401@8100L20@0200T2008020<00P080P000`070P00104000@1000200H10004
00P2000:10002P@000/60@803PH102@03@H201060`0B1`804`T301<91@0B2@<04P/301@:0`0C2`<0
4PT201890@0I3PD06A@:01H@2P0B3@X04@hJ00`??P041V@00@F800`AW00G:H406cAM01d[D`0Q7eD0
:amY03LXKP0g=Vl0:c5o02DcL`0Y>fT0:cY/02PkMP0W?8D0=Sb203a1P@0nAGT200XL[@0W00HA[P04
1Zh00`F`0000/`034Zh01RRS00`cU`0@<i`082J402/SH00J860042I_00lSMP0I5FL04b5]00XZO`0;
9IP09b>503@lJ`0G<Gh03RR701lPS`0]=8804an400`XT`0S9H`0;C]g01<aN@0G:I40;CUk024cQ00C
=8D0:Be_02T`M`0S=8H0=dAb03<aN`0V<FX0<3Qd0080AT9W02L0<35^02`_Q00m=7T0=3El02/^O`15
;UP09b1_020VTP0i9gD0;bMf028`RP0e87d0=C6002@iO`0/;Xh0@D9n03=DQ@0/EH80?5eo04YNN`1L
CVP0DUiK04MIG`1:DF`0FdUT06M_F@1WP5P0IH1J06ImFP1UP5d0IX1Q0660I@1RPF80FH1U05J0JP1?
Kg80Gh1L07:0A01jMcl00P1dJS@09`1bHc<0KUhc06ME;01UCbH0GT<M05/e4`1K=180G38A068m6@1V
AA`0JT/P069I;01SAAh0G3dH05/j5P1H=140Db/<04DO1@136P<0@1T5044K1P1>8PT0Ec0A06M4701]
DB80KThP06m@901XCR80I58/05IN@01NESD0GT/V05m26`1V@AT0JTlO06]I;`1^F2X0N5/Z085^<P02
08Eg>@0W08Ai>@24NSL0Q7Pe08Id<`21Kc40OfT`07]/=022Ibd0Q70a08Ej>@21P400Q7Ti081b<@1l
Jbl0Me`T07515P1W>A80HCHA06Dd401W=A80J3@?06Ld4P1S;0`0GBL705`W1`1H9@L0Eb@605PY201D
9`H0E28504LI100l5`80>141034A0P0d4`<0=AD203LF0`0f60<0=aD20080=1D102L0<A<103@A0@0g
3@40=a4303lE0`136@@0C1/605DW2P1O=A00ISTB06Dc3P1R<0h0H3<@06/m501aAAT0KdDI07156@1d
AaX0LTHI06Q15P1U?a<0HCTA060h401R>A80GcdD068m501N?Q@0FSdE05Hc401>:`l0BR4904HQ2016
8@T0AB4704`S201:8`X0C2<:04LT2`1;9``00P1?:Ph0901@<Ph0Dc0=058]3@1F:``0G2l=06Pi4@1]
A1P0MeTS07MY;`1iN3X0P8M008J6@027Qd00QhI008B5@02:PT00QX=008:4@01nPD00OGlh07am>01l
NcP0P7Tf081i=020Jbd0P5lV07YI7`1bDA/0K4/G06a85@1W@A@0H4<E06M34`1Y@a@0JT8C06m85080
LddH02X0LdTG07E;601eBaP0NE<J07]A6`1hEQd0NE`N07UJ8@24H200QF0P08eW8@2=KbD0S7LY08R1
<@25RSX0Pi51086G@@20VTD0P9]908BMAP21UT/0O9Q>07>MEP1VW5X0JIQJ06RGFP1ZTE40MHm3081e
=@1nFah0MD<@06Hi2`1M;PX0GS4<06Dm3P1WB1D0K54M075P:@1dLCD0LHA007>@A@1cU4X207RDB`0H
07ZFB01kU480NY4n07V=>P1kTCd0NIM007FI@P1_VDT0J9e?06>MD@1SVdl0II=806Z8@@1YNSP0J6l^
069O9@1CBa`0B38A03PL200[4P<08P`101d7000L1`006`T00P0H1P002@0L10007@D001P6000K1@00
6`H001P4000F0`003`<000`1000200P0000500D00001000000000000000100001@00000600400007
00D0000900002P8000P300070@000P400000000<0?ooo`002P3oool200<0000>0080000100000@00
00@20@050P401`4000T200070@002@8000D100090@00208000H100060P0200H1000[00P200080`40
20@100P40@0;1@8030L100`40@0:10402PD100d40@0@1@003`H201080`0@2@<04@L301<9100@1P80
4PT101@:0P0F30D06Q@@01@I9@0@62P0414M00/8?`061UT010N<00lGP`0L9g@082eP028YI`0V:W40
:R^002/bRP0Q>Hh05SJ601i3N`0VBFh0;4]_035;O@0oCW<0BE9]02PbT`0200`JZ00W00/HT`0<5h40
1PjK0005[`065Z/06C>A01<cUP0D<9X07R6=02`SL`0Q:W`02bN<00`ST@0L78h06RVF00H/U`0::9`0
8b>G038gO@0I<WX04Bj501hST`0[;H`05Qj6010_Q@0T<7`0;d9W01@WP`0K<HP0;cmf024]N00E<8X0
92VE02lgT@0R=8h0<CQX03LdF@0U<740:c:60080?cA[02L0<Bid03<hO016?fH0=SI`02HdRP0g8gL0
8aZ?01hRWP0h7XL0;26<01lZW`0c6hh0;bR402<gPP0_;Hd0AD1h03A<P00bBX80?d]n04iLMP1JFF/0
D5UZ04eEKP1H?fP0HTUV065gH@1PP5/0GX1M05n0H01QP5l0Hh1S05b0H`1TP6@0G81X05UfK@18HgX0
EX1V06n0B@1kMd000P1hLCT09`1fHC00LUd[06UE:P1QCRH0HD4L05/d4`1I;a00GBl?068k5P1YA1X0
JTdP06QH:01UBb00HDHK068o6@1J>1D0C2<;040L1P116PL0@Q/4044N101570D0Bb8:05@`401WA1X0
KeHS07=J:@1]EBD0K5P/065P>P1OEC40H4DP05i06@1P?Q@0J4TN06]E9`1_E2D0O5TT081W;002089b
=00W08Ai=P25N3@0QGTh08Mj>`24LCH0P6/]07]Y;P22HbL0PVT]08Ih>023P400PG0a07eU:P1lGbL0
OEHR07A=7@1_A1P0JT8E06dh4P1X>Q<0Hc<=05l/2`1N:@T0H2P705lY1`1J9`T0E2H705HX1`1A90D0
BR8404DK1P0h5`@0=A80038B000b4P80<a4203@@0P0e4`<0=A@20080=1<102L0<Q4003H>0@0d4040
<`l203DA0P0j5P<0A1`4054T201L<A00HS/E06Lg4P1M;`d0GRl?06Pj4@1/@QL0LD<H07=4601aBAP0
KD0D068f4P1G<`l0F2X<05L/2`1G<0d0FC8>05`i4@1M?140FCXD05Hb401=:@h0B24:04HS2P168PP0
Ab<904XV201890X0Ab4904/T301?:``00P1A<@h09`1E=@h0F3D?05Xf3P1Q>a80Jd<E07==7@1iGbT0
MW<l0721@@1aRDH0LhY807R=C@1iRd/0N8]=07J9C01jQTP0N8A<07Z4B01iQ4H0OhM007n6@021QC`0
P84k07aj>01jK2d0OE/T07AC7P1_BQ/0ID4D05hi4`1J<Ph0E2`;05T`3@1N=Pl0HS/A06<g401U>Pl0
IT8D06I45P0206]55P0W06e65`1/@Q80KDDE07=9601lDQX0OUXJ08ER7`2=Jb@0TG4V08ii:`29P300
RhDf08R:@029ST80Q9=107nEA@22UT@0P9I807ZGB`1dVDh0M9QC07:BC@1fSdP0Mg]007IS:@1dCQT0
KDLC06U0401S>``0HSH<06Pk401^CaP0Lf@Y07Ie>01hOd00NHQ207N?@`1hTD80NYA20080MiU501h0
LY]<07>JB`1bUTT0L9E9076FA@1fU400MI90072D@@1XUDP0GYQA05NFE@1JTeT0F8iB05n8B01TOcd0
HVX[05UB7P1:>Q@0@BD;030F1@0Y3@8090X0020:000O2@0070T001/:000L1`006`L001P5000G0`02
0103000600l2000>0P002`<000T1000600000`000`000002004000030000000100000@0000@00@00
0P02000020030000100000H200090P002`8000T200040@000@00303oool000X0oooo0P0300004P02
00000@0000<100030@001@4000H0000900001`4000P100060@001@4000H1000700001@4000@00006
0@001P8000P40@8020<100h02@D200d60@0<1P402P<100T20@080`002P8000`60P0;1`803PH200l6
0P0@1P4040P201070`804PP201L07QDB01TR<`0C7Rh00@6X00/8@@0;33h00PAd0042OP011jh01RR:
00`gO`0D?80073VA02@nRP0S?X@08Sj102e4M`0hBG00?U1/041FL@10F700?ea_01P^X00200XJX@0W
00dSN@0@<fL01Q^90009W00G:YT07cFB01XdVP0D::@06QbP02dWS@0X=h/03RfF00l[V00N9IP08BfG
01<]U00@;9X07bRH02ddQP0N;X@05S2?01dVT`0[9Hh05a^:014_O@0N:gT0:BiH01XYHP0G;X40:SAW
02TgI00M=gl0:2n?038iS00U=HP0:Big02hdM00U<8X09B^G0080=Rb902L0<2j603DnN`1>BVD0>3Ah
02/kN00i:f<0:BB102@^R`0f:F`0;bIj02<XV@0/6Y<0;R>=02@fR`0a;8h0Ad1n03E5P@0gA840@d5h
04IEK`1:F6h0CeUb05@oL`1U=6@0HU=/05a`K01QMF00Hh1K05^0I@1OP6@0Ih1K05b0I01TP640HGmS
05UeK@14K7`0Dh1Y0720AP1nMS`00P1hK3D09`1eH2h0LUl/06eF;01UCbT0Hd<N05lf5@1Q=Q@0HS<B
06To601/AQ`0JdlP06QD9@1XDB80IDdR06=66`1L?QH0DbH:04@L1P147@D0AAl7048M1@116@H0?QP4
04TP1`1K;Pl0Jd8I071G9P1bFbH0Leh/06YK<`1PD2T0Fd@N05`i501K=Q40I3lF06]:801]Bal0MTlN
081N9P0207eZ;`0W081e=026MS80QH0l08B0>`22MCL0PVP/085Q9P23FR<0P5dT08=e=@21P3`0P70a
07UV;01kER<0O5@O07EB801bBaX0K40E06Hd3P1T<``0HR/:05dU201K:PT0FRX805h[201K:@P0DbL7
058U1`1=80D0BQ/203lK1@0j5P@0=a0103@A000h4080=`h103L?0@0c4040<A020080<a0102L0=0l1
03@>000^3@00;0d102h@0@0b4P40?aH204@J101@9@X0H38?05h[3P1O:``0HBd<06@e4@1Z?A<0JchE
06Pl501X?180H30>05DV2P198PT0B20704/R201>8`T0EBH805H_2`1K=`h0FCPB05@^3P1@9`/0BB@9
04PQ2P188@T0Ab<804PX20179@X0ABD<04TU2`1?:0`00P1G;`d09`1L=a00GS`@06=1501XB1D0ME0N
07YP9@1iKcH0LH1006^3B@1/RDX0L8UA06V:E01ZReP0KXUD06f9DP1]R540JhYE06^<D`1`RT`0N8]8
07b;@01nRT00OXLk07el=@1nIbH0NUPO07EF801bC1`0J48F05Xg501;;@l0B1h904dW2P1F;Pd0ERd=
05@Z2@1A:@T0EC0;05Xd3`0205Xi400W064n4P1S?Q80IT8B06a65@1^BaP0NUXL07mS8@27Jb<0Sg4V
08ef:`2?Nbl0SX@e08n8>`2>RC`0RhY008>>@024ST00PXi0082=@024ST00QHe00863?01mK2X0M4dH
06Ll3P1P<PX0I3X<06Hk301[?`l0KDDF079C701fIRX0NWdh07R?@01bTTT0LI9?07:DDP1dV4/0MIM3
0080LII301L0JiQ:06jIBP1`VTP0JIM5072E@P1aTD00MXll076>?@1YT4D0Fi9?056CFP1?TV00DY9H
05n=BP1VPSd0HVl[05YE7`1<@AD0@Bd@03@M200^4P809P/001d9000201/8000<01X7000I20006PL0
01H5000C10004@8000`1000<0P002`8000L2000400000P00100100001@0200000000000000000000
0@00008000000P0200002P030000100000@0000500001@8000X2000<0`002@<000H20003000<0?oo
o`002P3oool01P01000000000040000200000`0000L000801P0000H01`0000P200090@00204000L1
00040@0200D0000400L000090000204000T40@802P@202L03@H300h70P0?1P803`D200d50P0;1000
3@<000d50@0<1@803@@100X4000;1P403`H100h50P0?1`803`P001P?2@0M71P041Xk00X;D@0824l0
1PU>00@8G`0218X000ZH000JU`05:9404c:301heQ@0T=Gl0:SQo03A0NP0fB7P0=E9h039GN@0^GWh0
:f=n01=:U`0::Z<00P076IL09`088gP02cF200@KT`0998`052ZM028eV@0M>9L04BjL01@WV@0V:hL0
9S:401<YT@0A<9L06BNL02D^U@0L:i@042RM01PWW`0Y<Y808BnA01TaT00O:H40:RQZ01XSP@0@:Xd0
62>202@WL00J;H<04BVB02DYP@0/>h808c^002@`R@0d>h@09SUk02D^RP0^>X@0:cV:02XeOP0203`e
GP0W03HkI`0dA6h0@TEV03PiM00^@6P0@SmI038_L00T=W/0=c=f03TaLP0T9H00;Amk030ROP0W<hP0
<Rb@04LjO@0a@H80>3j704E1N`11FG80@EmZ04QVK01F@eX0F3AG04m;KP1GEF`0GDE[06EdG`1FP6H0
Gh1Q06j0EP1SP5/0JH1J06R0GP1NP6P0Bg1g05R0IP1`P4/0PW0k0080OFH`02L0NEh/079P<@1/Ebh0
Ie0]06A8901P?QT0I3dG068j5P1X@1X0JdPL06]D8P1ZEbD0K5LV06]F9P1XE2D0IT/R05DY3P137@P0
BAl804XQ1P188@H0AAX503lG0P166@<0CR0906@_401dB1d0N5HS07AP;01_ER/0ID/T060n6`1R=a@0
HC<>06Dk4`1/Aa`0K4DK07I97P1iE2000P1lGBH09@20Jbd0QF`_08=i=`25NCL0PFl_085R:@22GB@0
P5@N07e?7P21J2/0PGTh081f=@1oLC<0Ne`V07MA801`@QP0Ic/C06Lh401Q;P`0G2d:05T/2@1N;@/0
GR`;05h`301O<0`0G2`;05PX2P1E9PP0Cb4704XM1P156PD0>AH203LA000k4080=a4203TD0P0j5@@0
0P0f5@8203LF0P0W03DA0@0^3`00;0`102h<0@0c4@40=A0003H?0@0m4`40@AT304dS1`1C8PP0ERD;
05HU2P1J;@d0GSH@05he4P1Q<140FS4?054V2@1580H0@a/603hK1@157`@0BAd504dQ1P1B9PL0ERd;
05L`3`1B:`h0CBH<04TT2`1<9Pd0ARL=04LU30149``0BBH<04LV2`169@T0CBP<0080DRl=00`0EcL@
05hk4@1S@Q80JDHF07]G7`1lJR`0OGXk07J1@01bPdD0KhM906f<C`1ZR5@206j;E00I06Z9DP1WT5L0
II5H06FCE`1TUe<0KY9>07N@B01mST@0P8a00866>`24MBd0PFLU07eT9@1jFR<0KT/K064l501B:`h0
Ab<;04TW2@1<:PX0BRH<04PS2@1:8PL0BB8704XS2@0204d[3@0W05@g3`1J>A00I3X@06<j4P1V?Q<0
L4HF07I=6@22EQ`0RUhO08]X8`2<KbH0SGHZ095k;P2?OBl0SGd`08R0=027P3H0Qgdc08Mk<026M2`0
Pg0W07mT801iBAH0JCP=05la201L<@X0Gc@;06Y13P1cCaP0NFLZ07]h@01lRT00O95407NCB@1jVD/0
MIU>072GD01eWDl0Nia40080MYA102@0Ki=407:E@P1bTCd0LXXi07B2<P1hP340N8@^07V1<01aQCD0
KH/o06>@B01GTU00G9A>062AA`1PRD00Hg`f065X:@1ADb40A3lG03TU300/5`@09@l0024:000K2000
60P001@7000C1`004PD001<5000B0`003`<000`1000:00001`0000@0000200020040000400000001
00000@00004000800P0000@01@0000<0000300000P000P030@001P040@001@4000@100060@001`40
00L200802@@000<01@400040003oool02`3oool000X0oooo00D00000004000030000104000L00002
00P0000=00H000080`002@8000X200090P001`8000L100050000200000L100080@002P4100/40@02
00l80`0W01@9100D1`<04`T200l60`0>1@802`@100d40@0:1@403@@100h40@0;0`0030<000h50@0@
10403@H100d5000B20<04a/J01PO900I6dP01PM]00<5OP0219@00@:[0005U0002J400Q2L00XHR00D
8Y<04bJ901dkR@0M@Xh06T^?01ICTP0DE9@04U:F00LjZ008<YL01RF>00800aJ@02L00QF4008KSP01
4Z402bV;01@bV00O=YT07Sb@01<fS`0C;hH092f102<YP@0B8H404S6>01D[V00W;H008bU^01@WQP0E
;9P09c6802@cR`0M<hd07Bb:02X^O00T<hX04RjR01TSWP0Z;hl07cRI01<[WP0W:iD0<D6=024hQ00O
;HX0<3Mn02PiN@0S=Gh0;SMi02/cN@0[>fX00P0mA5d09`0k?VH0<T5Z03LiP@0^?WP09Sii03/fM@0f
;W0092mk03PdO019@E`0:biT03@[H00i:Vl0:2j203@ZS`15>Gl0<CV403`hP018@fh0=eEY03YOK`18
GW00HTiG04lgH@11BW00AU1e05U9J01UMe`0IX1I06n0DP1dPEH0IX1I06>3F`1SQ5d0HH1P051gK`1D
P6X0I81K07UfA@02081`>`0W07]P;P1bER`0KU@Z06YA:P1ZDBT0HTPQ06547`1Q@a`0JDXN06U?801X
F2L0JUh[06eT;`1]JC@0JVXd06II:`1K:Pd0Ba/504XN101;80D0C20504DM1@126040AQP104XO1@1N
:0/0KcTF07A:801gGBX0KE@U06]97P1U?QT0GSDA05h`3`1Y=Q<0Jd8I06m67@1gD1l0N58N0080NEDR
02L0OFHY089W;021MSP0P7<e07eV:P1nGRL0P5XR07]<701fAaL0OUHQ085U:`24LC<0PG8d07aF8P1a
AaT0ISX@06Db301U=100I2`:05lY2@1S:@P0Hb`;05d/2P1O;`d0HS8>068^3P1I9PP0EbD7058T201<
8PT0@Q`503dH0`0k4P80>1<103`E10105`D0@1T503/I0`106P800P0i50009`0b4000<Pd003H>0@0e
4P80>AH303/D0P0l5040@A8104LF0`1;6@80BQX104TF10166@D0Bal9058Y301B:P`0ERX=05DV2P1B
7PP0Bah704HM1@187@D0B1h404LN10188@D0C20604lR2@1@9`/0C2P=04/Y301?;Pd0Bc8@04Hc4@18
;@l0CB/>04TW3@18:Pd0BR/;04h_3`02054e4P0W05/l4@1R?a<0ID@F06]:5`1jG280NW@j07Z1@01h
PT40LhA507B7B01dQD/0LXIA07>7DP1aR500IhQE06B?F01PTeT0H9IG06NGE01_UU00LiE<07RFB@1k
SdH0OH]30867@025Oc@0PW</07eT9@1`DA`0I3hC05L`3@1;:0/0C2H904L[2`1;:`d0A2X;04DU2@15
7`D0?ah40080?b0702L0BRD804`Z2@1E:P/0E2h;05@/2`1M;P`0HC<=06hk401hAa80P54G08AJ7026
H1l0RfDQ08YS7`28GQh0QE/M08IJ7021Fa`0P5/N07mI701nDaP0MdXE070o401Z=@d0J3L:06Hf2P1]
>``0LTDA07iP8P1nRD00LYI=06fKEP1]VeX0JieN076QF01eXe80MYi@07ZOBP1mW4@00P1jUT008@1e
Scd0LhTi0721<@1cMb/0LfhV07A_901gL2H0MG8W07=g:P1bQ340Jh/k05nAA01MUD/0FYE705ZEB01K
Rd40GWTe05AT;01:Cb<0@38C03DK1P0X4@408@/001/8000F1P0040D000h2000?0@003P4000l2000<
0`002@8000D0000300<000800P001000000010010000000000800004000200<0000400@100050@00
1`8000L200801`4000H01P4000L200060P001`8000@10001000<0?ooo`002P3oool01P0200000`40
00L100060@001`4000L2008020400P090`002P0;0`0030<000/4000;1000208000T2000:0`0030@0
01030@0B1P8201890P0W01@:100E2@<050X40189100>1P803@D200/50@0:10403P<000`2000;1@40
30@100X50@0=1@402P@000X30@0=10804aDD01/H5P0Q7c4041MQ00@5W@010Jh0002e0001O`000H/0
002E0001RP001k<00S6R004kW001@9h004FO0012Y@00>ZX002n_000A_0004YL000nH008000J_02L0
00JF0008S`0?:iP032V8014cU@0L=IX083j601DlN`0E=W`08C=i028[I@0J;F805cUh01LeQP0R:gD0
9BQ_01TVO@0D;9808bfA02TgS@0N<Xh072j<02lbRP0`>h006S:?01`[V`0[;i408CZ;018bT`0S<9@0
;c^>01lhR00O9Y00;C2@02PlR`0Q>800<CIX02l^G@0Z?6d00P0h@fH09`0mA5X0<ci]03@jO@0b?WH0
93f002ldO00f<gX0:2j603/fM01ACUh0;CI_03LaPP11=7P0:Bih03TbP`15>780<3Mf03/fM`1;AUh0
>4A^03]DN01:BGL0HdYN04hkE`16DG00C4Aa05YIJ@1SOed0IX5I07R0D01gQ5<0L85A07:6D@1aQTl0
KH1F05Z0IP1HP6H0Gh1Q079gC@0207mg@00W07iS<P1bEb`0K5@[07=G:P1^EbX0J5DY06MB9@1UD2D0
IeHV06IJ9P1UFbX0J60]06ia>P1]MT00Jg8l06UH;`1I9``0@a/304@K0P1;6`<0BAh504LL1P1160@0
A1L104hK101D8PD0HBh>0710601aD240LTlQ06a77@1Z?AH0JS8A06H]2`1Y;Ph0JCLB06i05P1aAa`0
Ld/M0080Le4P02L0NfHZ08=Z;P21NC/0P6hd07iM9P1mG280OEHQ07M86P1c@QD0NDXI07iM8`24K2h0
OW8d07]?7@1]?A<0IS@=06<_2P1S<P`0Gb`;05/[2`1P;Pd0IBd<068/2@1N:``0Gb/;05/Z2`1G9@L0
Db47058T1`1=8`P0A1d3048F0`0m5@@0>QL4040I10106`H0@1/403lK0`136@800P0i5@009`0h4@80
>18003dF0@105`80@aT504HG100o60@0AQH404LC101150<0@aH1048D0P0o60@0AA`504dP201<90X0
CR<9054Q201:80H0BB0604XM1P1?80L0Bal7050N20197PD0C1d604/L1`1:8PT0BbT<04h^3P1B=A40
E3`D058i501>=Q80Cc@?04``401=<a00CS4@05<i4`0205Dm500W05`k4`1T?a@0KTXI07AI9@1gKc/0
Lh1107J4AP1hQDD0N8A607R6B01gQD/0LXA>07V7CP1bR4h0J8YH05fAGP1IU5/0GYIK06JFD`1^UE40
LiE=06nFC01bTdL0MXa707f=@01nQc`0Oh0c07a_:`1hGB<0LTTH06Pl4`1L<`d0EC4;05D_3@1A<@h0
Bc0?04HY2`157`L0>QP30080>AP102L0?aX304LO1@1?7P80D20404/Q101=8@D0DAl605HR1P1P;0X0
KSP=07A24P1lBQD0OTPF07e;5P1nBQ80OTX@07]4401iAa40MTLD07M8501eAQ<0LSl?06Ti3@1V>P/0
JCh<07I34@1oD1H0QfHW08>3?@1kUDP0LZ5E06NUH01WY600IJ5R06fMG`1bVU@0MYU:07jE@P20Td00
0P20T3X08@1jQ3@0N7/^07Ab9`1aJB<0LF<P06mU7`1`JB80MG<W07F1<@1bSSH0Ki0l06>E@`1QUdL0
GIU:05^IBP1JT4<0Fgdi04mY<@18EbT0@SlJ03HR2@0V40<06`P101L4000?10003@<000P100070@00
200000/0000=0P00304000H000020080000400<0000200001000008000800@000`00000040010000
0P4000<100050@00108000D100060P001`@000H200040@000`0000@0000500000`0000400000000<
0?ooo`002P3oool01@0300001@8000P100080`402@D0008030@000d030@100/50@0;1@4030H000`4
000:10402P<000T300070P002`8000`4000?1P4050P2008050X202L05@X401L:0`0E2P@04`X400l8
0P0<10402P<100T2000900002@4000X30@0:0P4030@100h40@0=1@003@D101D:1P0F3P`061@F01DM
:P0>7f<00`VW0041W`000;T00@>30004K`000Hh0006Q000AY@008jT002jZ000aZ@00<ZL002f]000T
]0001JX000NO0008TP002HD00P0028009`001X003BF;010ZN00=;Wh04CZ<01TlT@0R?h007cmh01hn
NP0Q>G<08S5j020jL`0L>g4063Ai020[R00X:g@07BIo01DZR00P:i00:S=o01lbP00M<h80;SIn03<d
L`0P;8<082nD02/^TP0O=Y<04C>F01l^V00]=Xl083J901`ZT`0]<I80;T:002DhKP0a<Ed0=T1M02`o
K`02038jM00W03a1M@0g?gH0=3Qn02loR00U?hL0:SFC03hnR00b<8T0>C9`04XoFP0c=gD0?CAi04Le
M00`<fT0?CMi04TeJ`0^<V/0>SQl04U7G00iAV@0?U5c04iBI@1FEeh0BCeM04`mN01K=Vd0FF=/06N1
GP1cP540NX1>07Z1C`1nPDP0NXE907Z2B01aPU00H89M05f0GP1LP6D0JGAH0080LH1802L0NGA007EP
<@1aFbh0LE`Z06eH9`1[E2L0JEPX06IH:@1VHBl0Iel/06UI:@1]H2h0JWM106:0AP1WKCd0I4PU050Q
1`115@80@AL204@J0`1970@0Ca/404XK0`1550<0AaH504LH1@1B8`H0HC8@07945@1aBAd0L4TI06ho
5`1Y>140Ibl;06T`2@1Y=Ph0JSHA06ln5@1_?aD00P1dB1`09`1lGbH0PV/^07ij@01mJS<0O58P07QC
701gD1`0MD8D06dl4P1g@a<0NDTJ085N9P21IR/0NddL070k5@1N;`/0FB/905`]2`1K:P`0GbT:05hX
2`1P:PX0I2T:05hY3@1I9`X0FBD:05@S1`1@90T0D2<704/Q1P146`D0=aP503/F0@0j5`D0?QP503`H
0`116`@0A1T403XH0`0203/G100W03/B0`0j4P80@A<204@D0@185`80AaD2040G1@144`<0@A8404<B
0P135P40AAH204HI0P1670D0Bal704dT201B80L0D1l704dK1P1<7@H0CB4704hS201>9`/0Cb@9058T
201=7PL0B1`604TM1`198`X0DR/<05<c401G=a80F3XD05<k401E>100DSDB04li4`1B>Q@0D44G0080
EClF02L0GShC06E3501_ER80JFe006J0BP1TP5@0J89C0724C01cQTL0LhU:07V8BP1hQTd0NXQ=07V:
B`1`SE80Gi=I05ZIGP1IVEl0HYUH06bGDP1bUT/0MI5707V=A@1nRd@0OH]007V>@01mR3`0OX4f081e
;`1nGb<0MThH06lo4`1U>Q40FSD?05Pb401B;0d0C2L:04LR20126`<00P0j5`409`126`<0A1d304XN
0`1<7`@0Bah404HM10186P80Aal304`R0`1I9`H0Hc<:06`e3P1^>`h0LcX:07@k2`1d?0d0Lc`=078i
3`1e?Q80LT<B07<o4@1]>`d0Hc8:06Dd2P1[?`h0NTdC08E[9`24SD00O9=:07>HD`1[We/0I:MO066V
G`1LXF@0GiYQ06BEFP1_TdT0N8i007^=?00207Z:=`0W07V2<01gNbd0MG@X071X8P1bIR40L6PU075g
:P1cPc80M94k07FH@01bV480K9Q7062KBP1MVdh0GiY?05fDB01JQ3d0DG0d04YL:P14@aX0=2L<024@
100D10003`4000d0000800001P4000L100080@002@4000/3000;10002@8000D100030@000`000040
000500000P4000<00@000P0000001`0100000`40008100070@001@8000D100060@000P070@000`05
00000@0000400002004000800000303oool000X0oooo01@00`4000@100080@0020<100/50@0;1@80
3PH200h50P0?1`803@D100`4000<1@002P@100P300070`00208000X2000;0P0040L001D80P805@/3
02L05@T301@90P0B2P<04PT301880`0?1P402`<000L300060@001`8000X20@0;0`4030<000d50@0>
1P403PD100d60@0G2PL06QLQ00/VC@098gh00PV<0082QP000<000@6`0042X0000:h0002j0006W000
3j/001Jh000I^0006k@001Jf0002[P0019D000FG0003T@000X400P001XD09`0038L03Bf1010_Q@0@
>8h04cn?01LoUP0O?9D09TJ102=2L00P@7P08T:702I4L`0V?F`083Yj024_PP0[:Vl08bao01T[O@0N
9hX09bb201hWN@0P<gT0;CEl034/O00R9XH08S6A02/]S@0V>8P06CRB01l`V@0X<iD07cJ?01d`U@0[
=Y40=4Qk02TgJ`0];XL0=dIk02U1K`0202/fR@0W03e4P@0oB6d0=3Uk03@lP@0`?h@0;cV=03dmP`0d
>880>3Ak048iM00g=HL0?cAj04`dG`0a=6H0>CYl04PaL@0Z<fP0<SN6044kK00b?G@0?TJ0055IKP1A
I5`0@dEG04PgI`1D>6@0EUeZ06IaG`1fN4l0Nh1;07MoC01lOdL0Oh=70821@@1kP4D0Ih5F0620F`1S
P5X0MH1<0080Jh1=0140K7Q907Q[?01bHS<0LV@_06eL:01XEB@0J5/Y06QP;P1XISD0JV@`06YM:`1Y
I380H7E205UhC01PGcL0EcDF04@L1@0203/G100D03lH10136P@0BAT404HJ1@125`D0?1H5048G101<
6`@0FBL:06Pf4@1^AQT0KTDI06a36P1Y@1L0JCTB06Xe401Z>Pl0KCPA06Xj4P1[>a@2075:6P0W07]N
9@22KBh0OgXm07m/<@1oDal0MTLJ06ho501]>A80LSd@07I04P1c@a@0NE4L07aD7`1iBaX0LT0E06<a
3@1L;Pd0GBh=05l`3P1O<Pd0GBd;06<W2P1O90H0GbD805`V2@1K90X0EBD;05HT2P1<8`H0Aa`3040I
0P0k6080=Q@003TD0@0j5@40?AH103hF0`0m5`@0>QD40080=Q<202L0<a<303D@0P0l4080@a@003lD
0@0m4P40?AD203`D0P103P00@a0204PE0P1:6@<0BaT304/J0`1?8@D0EB85054Q201E8`L0Bad504TQ
1`1@8`/0Cb@905@T301G:`X0DBT:04dV1`178@H0Bb8704lQ201C:``0Ebh>05Pe3`1M>140EcP?05Dg
4@1E>A80ESTC058l501@?aP00P1C?1H09`1K@1D0ITLH06aQ;@1QMdD0F8AH05Z2G`1KPV00HXEF06^:
CP1]SE80KXUB07F7D01jRTd0Nhm:07RBC01/V5D0I9]I05bJF`1RVUL0JYYA07BDC01eTDT0Mha:07f;
A@1nS4H0NHi607Z<@`1nR400Oh<i07m`:`21EQh0NDLG06e2501U?A40GSPA05La3@1F;@X0CBT:04TR
1P0204PJ0`0W04PM0P197P80Bb03050Q101>8P<0BR0404/K101;7@40CQ`104lU0`1N:0L0HRX:05l/
1`1N:`P0HR`706P`1`1Y<@P0Jc@9074i3P1b@0d0LD0>070f301S;`P0ICP:07A:5020IR@0Pha007VE
B`1/VeH0IiiN06>JH@1OWf<0GYmK06NMF01`Ve<0LI9707:4?01dOcD0L8<j0080LhLf01T0M8Hd07F5
<P1ePc40MW//07Ef:`1gO2h0N8Tf07FE?@1gWd00LJA806fSB01/X4X0HZ==05VQE@1KWeD0FIa@05b?
A01AMcL0B6D]041:7P0b;0h07Ph300h300070@002`0000802P0000`03@8000`2000:10002`@000/5
000=0`003P4000X200070@00100000<000020@02004000@0000000<00@000080000400000P050@00
10060P000`8000<000030003004000800P0000<00@000?ooo`3oool02P3oool000X0oooo00l00`40
00@100050P001`8200X50P0:1@<03@H200h70P0;1P803@H200/40P0;1@002`@000X4000810000P09
0P000`0;0`004@H001880P0201<:0P0W01<80`0@2@4040L201090P0?1P4030@100`3000:0`001`@0
00T3000;10402@D100X30@0:100030D000d50@0>1P4060P401dA3`0O6b808RHn01LWG@0:57l00@6n
0000_P000;l000300000_00009L0006X0004`0002Kh000fk0001`P000J8000650001Y00008<0006G
008000^i02L02SJO00/gT`0B>Yd05d>B01M2S@0JAI008d>:02]5N@0Z@g00:DAi02I7OP0[@7d0;49m
02DnO`0Q=800;Rn902dhN00J:G/06BN902@WKP0N:6d07cIo02hhM`0f<Fh0:S:402LfSP0^;hd0<3j7
028nTP0R<9H0;3J602DkNP0P=hT0:cJ=03M6JP0^>fd0;cV:03Y4OP0`>gH00P0]=X/09`15A7X0@e1U
034hN00e>8T0=D68034kSP0l@H80>TAa03TiN@1;@Vh0?Sae03`gK`13<Ud0=S9g03hdO@19<g40;CEW
03LgPP15=GH0;SEj03/lO@1<FFH0BUYR04mKG01@De/0CDYN04A@KP1?C7<0JgEJ07F0CP1gPDd0Mgm9
07eoA023Od00Ph1107R2B01_PD`0KX=@07b0A00206R0D@0W05mfF01bM440M6Xh07=R<@1`Gb/0LE/U
06iN:P1`Hc00JVPd06iU<@1_Ic00IFlm05af@P1JKd<0HDHR04hQ20115`@0=A@303XE0`115`<0@1L3
048G0`0o5`@0>a8403PC100o5`<0BA/405TX2P1V<Pl0K40G06`o5P1Y@aT0JShG06Pg5@1Z>1@0J3dD
06/f4@1[=0h0JSXC0080M4XL0280O6<X07i/<01nMSH0OVH]07]E7`1f@aH0K3<?06`h4@1_@AD0M4LG
07Q35`1lB1P0NTPH07I66@1aA1L0K3XD06Xc401U=@h0HS<;064`301N;PX0HBX805dX2@1G9PL0EBH6
05@V2@1C8`L0DB8604`P1P156`@0@1H303DF0P0g5@40=AL00P0g5`000`0j4`40=QD103<D0P02034>
000W030A0@0e4P40?10003`@000g3P00=@l103P?0@0g3@40?@d103dC0@105P40AQD404DG0P1<6`@0
DbH705PX201M:`X0FR`:05<U1`1=9@P0CRH=04hW2`1E:`d0E2`?05D^3@1A:0T0BbD:04TS2P1;8PT0
CB<904hW2@1A;0`0Dbl<058b3P1D<a00E3HA058g4`1G>a<0DClG0080E3hE02L0FSlE069>7@1WISD0
FgMA04n4I@1DOfT0DWa[05^7HP1MSE/0H8eJ06b;E`1cR540LXe@07^?B`1gUDd0KYQ@06RIE@1PV5D0
IIY?06bGCP1]Tdl0KHe>06b<D01/S4h0LXY907>=B01aSDH0NhQ007n3=`20M2d0P64S07aG7P1iD1/0
LDLD06To4P1Q=Q00Gc@A05D`3@1>9`T00P1;80P09`1>80L0CAl6054P1P1B8`L0DB<9054R2@1?80H0
CB0304lP101@7`80DR8505DR0`1C8`@0Db4405DU101I9P@0GRT606DZ1P1Y<`P0KCL<06hh3@1X=PX0
IC@=07=85P1oJbl0P8e107NDD@1]Wed0IZ=P066RH01OVf40FieS05nOG01/Wdl0LYU007>8=@1_N2d0
K74/06ec;`0206ml<@0T0763<01fQc80MXXe07:;=@1cSCD0Mi8i07JH@01eW440LJ=606^UB`1/Y4P0
KJA:06:WD`1EXed0CZ=O04fRH01HVEH0Eh9104U^<P10D200<R`>01d=0`0>0`002`0000X1000?0@00
2`8000/6000?10003PD000h4000<104030@000d30008000010000P020000100100000P0000800000
00030040008000000P0400000`050@001P8000D2000200D1000600<0000200000`00008000020@00
0`40303oool000X0oooo0P030@0030040P401`@200P50P0:1P802`H300/50`0:1@802`D200X40@0>
10002`@000`400803@@000@030@000h50@0>1@404@H10P0?1P809`0?1@4040L200l60P0?1`403PH1
00d50@0<10402@<100h60@0=1P4040D100`50@090`0020<000/3000:10403@@101860`0F2PD070h8
01hR9P0E;4T02Qb10083^@010[d0002o0000YP000;`0002E0000Z0000/4000G00008_0000L40002Z
0000Q`000GP000B3000:W`0200hcX@0W01<jU@0D?9805T2E01a1R`0P@hX084V;02=8Q`0ZAHL0;dN3
02a;O`0U@8009Sb?02e3Q00Y@W`08Smm02`lO@0/>7H07C6001/_QP0V;GX08c>2028jP`0V=hP0<c>7
02lkR`0V>I<0;cJ<03M3P00ZAGT0:Cf0038jM@0`?Fd0:c]e02dhQ@0g@7`0;cao030nR`10@7l0<cN1
0080;C>>02L0@cmh03i6IP0_=Gl0<cV>0350P`0_?H00@TEh049<IP13@f`0CdQU03/fJ@0a<7l0A3Ak
03/cR00l;h40BCAY03@dJ@0m=gh0Ac=d02l`K`0m>W<0CEYI03a<I@12FFh0De]S051>F@18Cg40D4Ue
05i/IP1TP5d0Lh1A07J4CP1mPdL0QX1008R0@024P440Nh1607b2B01nP4@00P1aP4/09`1TP4h0IGQ5
06e_?@1aGBd0M5PZ075J9P1_GBT0JF0]06iP:`1aH2d0JVPj069`@01PLD00HUhg05`c5@126PL0?1H5
03/A0`0j4P00>Q@2048E0`1160D0?1P403XB0`0l4P<0@QH304HI1@1B7`L0Hbh?06`i4P1Z>Q<0ID4I
06Ln5P1V=Q<0JcL@06Tf3`1X<Pd0Jc8>074d3`0207E76@0W07]M9@1kHBL0Of<Y07iI8P1nDad0N48C
06Lb3@1V=@h0JchD0752501b@aD0LdLF07I55P1c?a<0KC`F06Xk501[=a80JcP?06Da301P<0d0GS0;
05d/2`1P;P/0G2/905dW201J:0X0E28604hS1`1=7PD0A1X503PI0`0f6@80=Q@103HE0@0h5@40>aH1
03XC000g4P00>Q<00080=10002L0<Q01038@000c4@00<Pd003D>0P0h3`80>`l303/A0P0l4040@181
04@A0P0m50<0?a4304/O1P1C8@P0FRP805`Z2`1G:@/0EBT904`Y2`1?:@`0D2H<05H[3`1F;`l0E34=
05</3@1C:P/0CbT;04TU2P189`T0Bb4604hT2@1@90X0C2`;04h[301D;@d0DC0>05<d3P1C>Q400P1C
=Pl09`1J?1<0I4XJ06QU>@1HMeL0BH5[04ilL01<L7H0DHYZ05N@HP1KRUh0IXaH06b7DP1`S4l0NY==
07NGC@1]Ve80K9IC06>DF01YUe80Ki9=06j<C@1_Rdd0Khi<07B@B`1iS480M8U007F:@01hRd00OXHj
07ak<@1mKB`0OV0S07QG7P1aBQT0J40F060h4P1J<a<0FS0?058X3@0204/S2P0W04/R2@1=90T0EBD9
04lW2P1?9PT0CB@:04hS2P1@90P0Cb<504hO1@1;7`@0CAh404TK0P1=6`40C1`005<J0P1G7P@0GB@4
06D[1`1/=0P0K3D:070f301^?A80Nf8U07^>A01]UUT0HiaU062MJ@1SX6H0IJ5Q06:PGP1NW5/0HY]A
06bGA`1^T3h0LX8a06m_:01[Ib@0KVTV0080Kg4Z02L0LgT_07Ao<@1eQc<0N9@i07NI@01dWT<0KZI9
06^VB`1XY4/0IjA806^PA@1ZYDT0GjAF04jQI014XFX0?j1_04RNI@1BS500C7Pk045D900a9`h070X3
00l3000<0`002`<000d2000?0P004P@00145000B1@003PH100/50@0<10402P8000L1000200000`00
00@0000300000P01000500000008004000000000100000H000050@001P4000L100030@0200800004
00D0000400000P40008100`0oooo000:0?ooo`0D00<100040P401@<100P40P0=1`<030H200/60P0:
1@402@@100X40@0;1@802`H100d40P0<1@403@D200h60P0?1`803PL100l50@0>1@4300h5000=00l6
0P0=1P803PD100d40@0>100040D100l60@0@1`804@P200h70P0=1@402@<100X3000200T2000G00X2
000<0`003P8001/@300K82T04bU>014QN`0=2j@02@V_00@9]0022;D00@Fh0001TP000:L000320001
`@000L8000310000^@000:`0002P0009Z004;:D00P0@=Yd09`0H?9/05CnL01DnW00N?YH094V<02E=
NP0RBGT0:TV3031;P00`Bgd09TJ502I4S00]@hH0:dN402I6O@0X@G`0:3b301hiO@0O=XD0:3J;02`m
NP0S?7<09CV102dgS00a>X/0<D::034nR00f?X@0<Cmo02/nP`0a=hH0=T9e03=1H`0d@7T0?dQU03M4
L00dB7h0?TAf03XiP00203PhR00R048lNP0m@gP0=3R303DiR00g@Gl0<ca[04A7K017BfH0?dAN04U4
HP0k<f<0=c5h04TmL@0n=GX0>2j504L/L00e;W`0?SAo04LfK`0c<6`0@S=k04Q7F00bBV`0>e9o055J
LP1?D6T0CDUi0598M01;LG80CWiZ06n0E@1gQdl0Oh=508B0@@80QH1100<0Ph1208:0@@1nP4@00P1d
P4P09`1_P4L0IH1406Ad@01_Gbh0LELW07=I:@1`G2/0LV4]079M:@1]GR`0J5de06AJ>`1SCbP0GchK
050X3@106@@0?AH403/C0P0m4040?14403XD1@0k60@0?QT403hE10145P@0@aD404/K101A7`H0GRP;
06Pd3`1/>Q80JCdG06Pk5`1V=100J3H@06Pd3P1Z<PX0KcH@07Dk4@0207M8600W07IC801jEb<0NUTS
07eA7@1mE1h0M4<G06Lf3`1T<`l0ICD>06`m4@1a@180KT8E06i0501[=`h0JSHA06dj4@1^=a00JC8<
068_2`1R;0T0GC0;064^2`1V<@`0IS0;05dY2@1F9@L0CR04050O101=6`<0@QT403/J0`0j6@40=aP2
03lF0P105@D0?aD403TC0@0e4`00>a<00080>14002L0=A40038@000]3000<@h003DB0`0i4P@0>QP4
03hD0P164P80AQP204@F0`0m4`<0AQL504HG1`1;80L0CR@904`W2`1A:P`0Cbd;04l]301;;0`0DB`;
058Z301C;Pd0F2h=05D`401E:Pd0Cb`=058X2`1@90T0BQd704@J1`165`H0AAl604LS1`1;9@P0BbT:
04dY2`1@;`d00P1A<0l09`1I<a00Gd<E06YQ>P1EMUP0AX5Z04mkK`19JgT0C8Q]05>?JP1FS6@0HHaM
06Z<EP1]SUL0N99>07VGC01bUe80JiEF05j@G@1TT5@0KYE=07:?AP1jRDD0O8i407f<@`1nRD00NXM0
07>:@01aSd00M8i007J6>`1fNS<0NFHX07=F7@1_CQL0Id0D068j4P1N>100GCH?05D/3`0204`V300W
04hW301>:0h0D2`>050Y301=9`/0C28;04`T2`1B9@/0DB@804hR1P177PD0Aad204HL0P126000A1T0
04@H001=7000E28305XY0`1T<`P0Kc/;070l4@1jDAd0OX0k06jCD`1JW6@0EJ1/05JPJP1IXFP0GjEP
06FTF`1VXEL0IiU:072EA01dTCh0Mh@b07=a9P1_IbH0KFXU0080Kf`Y01P0Kg<[075n;`1cRcL0MIY0
07>SBP1Z[E40H;9J062`F@1SZe<0HjQ>06FUB`1QZ500FJaK04bZI015YVP0?Z=^03nRJ`1:V5/0CH10
04EE900`8``05@P200h3000=0P0200h400070102000B0P004`D001<1000<0@002`<000/1000200D0
000400@000060000104000<000P0000000P00P0000<000050@001`0000P100080P001P8000D10080
10400P0500000`010000oooo0?ooo`0:0?ooo`002P3oool02`030P00108000H200091@003@H200h7
0`0>1P403PD000X20@0:10803@P200803PH200L03@D200l80P0@20<040X200h60P0;108030@00080
3PD000l03@D000l50@0=104040H100d70@0>1P404@L201070@0@20803PL200`60`0:1@402@<000P4
00070P000P090@003`0<0P003@@001H8100L40h08AHM02/L<00b7DP0:R=L01HZIP0<9GD021V40089
S`000Zd0002d0000`P020000`@050000`0000L0000;000<C/P08=Z000P0B>YT09`0K?i/06D2E01U2
S00NAHH0:Tmo02]?MP0XCW/0:E1k02i?P@0bDH<0:E2802U9RP0]AHH0;4^502I<P@0WBG/0:DMe02E1
M00U?Wh09Sb702dkNP0[?7`09CUi02@bS00b>X`0;T6:02T_T00/=HX0<Sao02dkQ@0f=X<0>T9_03U3
G@0mCVH0ADmQ03i4I`0hAg<0>d6003m2O`0203XhQ@0W048mP`17BG@0>45k03TjQ00m?g`0=CQ`03e0
L011@Vh0>D9P03m2K@14@F40@3iY05=9JP18=V`0@3Eh04X^I00l<7/0?S:204dgI@0c<G@0?Rj3048m
L@0cA880?4R4049MOP15GGD0ATIn04m;MP19K7T0EX1Y06f0E@1kRDl0Q8M80867B01oPdT0Ph1308N0
@024P400PH100080OX1002L0NGI006mh@01YLT00Kel`07AB901bD280Ke<S079G9@1bERD0LELU06e:
7P1W>QL0Gc8@058Y2`198@X0@AP403hH1@0o60@0@A<203lE1P0l5@@0?a@203dI0`1460@0A1/404<K
0`176P<0CB4605`W2P1W<0d0KcD@06Ti4`1W=a80IC@@06Hf401Y=Ph0K3@?078k4@1d>Q800P1a?Q@0
9`1bB1X0NE0M07QB7P1kCQ/0NdlK07986P1]?aD0JcH@06He3@1Z=Pl0JchA07945`1_AQL0JCH>06Pd
3P1Y=a00IC8=064^2P1O:PT0HbT906<]201W<0`0IC0=06L^301I9PH0DAl404dK0`196`<0AaP3048G
100j60<0>aL403dF100k5@<0>Q@303XC0`0f4P80>1<203@D0`0203<?000W034?000b3@00<P/103@>
0`0f4P@0?AD403`G100n50@0?aH2040E0P164`<0?Q8304DF1@136`P0AA`704PN2@1<8P/0CRL<04dV
2`1<9`/0CBH905<X2@1D9PX0ERX;05H/2`1C;@h0CbX=050[301?:0T0CB48048M1@0n4PD0>A4303PE
1@1370@0B20504LQ1P1=7@D0CRD:0080CBT902L0DRX=05dg5@1[Ec40F7I?04Z2I`1=Mfl0B6Ek04F3
M@1?S6d0CHM]05Z<I@1SREh0J8YK07B@DP1eUdd0M9=>06^>DP1LR680HHYF06^CC`1cT4P0Nh]208:;
@`23S400PX]007j:@01iRT00M8i107:=@01dRcX0MGlb07QX:01`F200KDdI06a45`1X@a<0IChD064l
4P1J;``00P1@90`09`1990/0BBP=04`Y3@1;9P`0BR8:04HP2P1:8PP0DB8:04dR20197PD0@a`2040K
0P157P80@aX1048H0@125@00@QT004PL0`1B9@@0GRd806Xk3@1dCQX0NG0a07J?C01TV5l0EYi/05:R
KP1JXfT0GjIQ06NUF@1^YE80Lj5A07>NB01jV400O94l07^;=@1hO2d0LWD/075j;P0207=g;P0Q075k
;P1_Q3@0LY@k076RB@1ZZ5D0H:aL05R_HP1J[V40FjiN05Z_F01K[UD0Ek1G05:`GP1:[fP0@ZU_03NW
M00cZGD0?YmS04f2@015Cal0;1h:01@70@0<0@00308000X3000?0`0030<000d2000B0P003P8000L1
000<00001`0000<01P0000<010000080000100000P0100000`0000000@00004000040000000<0080
00050@001@8000T100070@001P8000L200070`001`8000L1000700000`00303oool000X0oooo0P05
0P001@0610002P@000/60@0=1P8030D100802`<000@030D100l70P0?20803@D20P0=1@401@0=1`80
3`L200`70@0>1@0030L1008040L102L040D201870P0A20804PL200l90P0A1P404@D301070@0@2080
4@H200`50P0;10802@@000X40@0910402P@000`4000?1P004@D00105000@1P405PL301T:1P0O40/0
72H/014`@@0;;El01aen008<X0000kP0006V0000`0000;l000300042_0021KH000Jh00dgV`0A?IH0
0P0F?IH09`0L?IT07T6@01]4RP0MAGd0:Dao02Y@P00ZDWT0:5Ei02iLP00cGh40=5Uo02mCQ00`DH<0
;U6202QCQ00YDhD0:T^102U9O00WA8809D6902`lQ@0/?W`09CMl02<jSP0/?Hl0;Cj;02DhR@0X=h@0
<cb103<jR00d<h<0?3em03PkJ`0k@f/0@T]^0458H00h@VP0>d9n04A8O00203Q5N`0W04E2N019BfT0
>D1a03`hPP0o>g`0=CB103XiQ`10AGP0>4=]04M4M@1?CeD0ATEP04m8H01=?eh0CDEH05M6CP13?6P0
?2Z:04T_MP0a:hP0?C6803hmOP0a@8P0?d65041JO`0oHg`0BEAc04UCN@13GgX0Cfm`06R7G@1hS580
PhQ908:9A`22QDH0PH1108J0@028P3`0R7Pi0080PWDj02L0OVhf07I/>@1`JCP0JUX^06a98P1Y?QH0
JD8I06a4601[Aa/0JD0H064`401F:@/0D2@:04hT2P1;80P0AQl504@K10167@@0AQT3044D10104`@0
@1L3040H0`135`@0AAP3048J1@176`D0CAl705HU2P1V<@h0IS<@06Xf3`1U;`l0IC8@06Xe3P1Y<@d0
KcH?074i4@1[=1000P1U<`d09`1Z?A<0L4@F06m7601cAQL0L4HH06]3601[@1H0IS@=05hc301T=@`0
ISD=07515P1a@aL0ISH>06<`2`1S<P`0HRd:068Z2@1U:@`0JC0=06He3P1W<`d0IC4=05XZ2@1F8@H0
BQd504TG0@166@<0B1L204LI0`126`<0@AX303XE100f4P@0>Q8403H@0`0c4080=Q0103P@0P0203LB
0@0W038B000_3`00<@`003H>000g5@80>aL4040H1@125P@0?1P203/E0P0k50@0@QT6040K1P1370P0
BQl804XP2@1990P0C2L<04TR2P1890P0BR<804lR1`1@8@L0DR@8050T2@1=9P/0BRD;04lY301>9@X0
Bal704DJ1P0h50D0<14403<E10106PD0A1h504DM1P146`H0BAl80080AbD902L0BbP<05P_3`1ZCBD0
GVe:04n1H`1BLfh0BF=i04IkN@1@Og80CGYc05J0L01LPfX0HHQT06j@E`1aUE00Khi>06Z9DP1LQ640
H8QJ06f?C`1aUDT0MI9507f<A023RD80QXQ008B7>`20QSX0NHLi07N7=`1dQSL0Lh@d07Ig;`1aIRL0
Ke<N06Y95`1XA1P0IT0F06<l501I;@h00P1:9PX09`168PT0AR0:04LS2P148PX0AR4:04LS201?9@/0
Bb@:04LO201570H0A1X303dG0P0m5P<0?QH303lF0@105P00?AL1044G0@137@80ER@606Pe3`1cFR80
LhE206FBEP1IVFL0DIia052TKP1KYf@0HJQK06fWEP1`YU00Lj9;07ROA@1jVT00O9Dk07f<=@1kQS00
NXPe07B=>`0207:;>`0O07F;?01cTT00Kia506ZXDP1R[eX0FjmS05BaJ01?/FX0C;9X05:gH01G]U`0
E;IK052eG@1?[f<0B:I[046UK00mZFX0A9iK04f0?@12B1/09AX90106000:0@00204000d3000>1000
4@@00183000A0P003`8000X1000200P0000500H0000400001`0000@0000200001@0100050000000<
008000040000104000L100060@001@4000H200070`0020@000P300090P001P80303oool000X0oooo
01@06A4:01@>1`0C2`D03PL300l50`0=1@8030D100X5000=104030P20189100A1`804PH201060P0<
1`402`D100`50@0?1@8040T201490`804`X301005PX401<90`0E2`<05`X401D90P0E2@<04PL200l6
0@0@1`803`P100/40@0;1P802`@000/3000;1@403@H00P0?10005@0@1000308000X3000810002P@0
01LF400F8R<052Y001<YH`0F6X<04aJJ010CZP020kd00P:l0082_@020Kh00`Fh00<:[`06:jL04cn?
01I0T00201M0T@0W01i3T@0RAhH07dR002I@NP0[DWd0;e9j02iEN00_G7`0;fF003ERO`0dGWl0<eeo
031JPP0_F8D0;Ub402aKP@0^EG`0<51k02]>O`0XCX<0:4Z302a3P@0Z@HH0:D6=02TiTP0]?XX09Cf3
02/jSP0f@XL0=Cn403@lN`0j?g80>3eb03M6M`0n@g@0?T1a03TmI`0m@7X0@dQi0080?dMZ02L0?Sid
04A7K@0l?V`0?Se`04DnE@0j=f`0?SV504I3N@10@6d0B4=]05IAFP16BV@0BCma04a8I018@FX0FU=V
04Y=IP0i:X`0AbYl030ZR`0o<XD0?Sim03@kQ@13?H<0>5:803]EP01:FWL0AVeh04=dN@1=M740GH9U
07F9DP1mQT`0OhM808B3A@23P440QH1008Eg>P26KC000P20I2P09`1oFbP0NeHX079G;01XE2/0HTTT
06Dj5@1V=a<0I3D@064`3`1O:`X0DB@:04dP1`1>90P0Cb<904lT1`1;7@D0Ba/504`Q10176@@0@aH3
04<C0`0m4`<0@aL5044F10145080@AD3044H0P1>70@0EBD:05h^3`1T<Q40HS8@068]3@1T<0d0J3@?
06/e3@1^>100K3`C06Ld400206Hf3@0W06`h4P1Z@1@0KdDH06]1501/?1@0JS`C06Lh4@1M<0`0GB`:
05d]201Q;0X0K3P@06e0501W=0d0IC0;05`^2@1M;@P0Gbd;06<`301W=0h0I3@=06Pf3@1K;@T0F286
04dQ1`1;7@D0@aT204DF0`165`D0C1/304@H0`125`@0?Q@4040F0`0j5`<0=aH203<D0P0g4@80=Q41
0080>AD202L0=Q8203HA0@0c4@00>0l003/B0@0m5080>QL303lD0P114`80>QD203hH10106`D0@R09
04LP2@1;9@X0CBP;04hW2@1:8`P0AQh704LK1`1:6`H0AA/404PK10187@H0Ab0904/M20187`T0Bb<:
04/S2@1;7`T0@QX603`I1@0i60<0>AX5044O201080P0A208044K1`147@P00P1380L09`1890/0DbT;
06M6801OId@0E81N05YaJ01?HWP0C79j055^M@1AHg/0EGI`05IlK`1LQVT0IY1P06n?EP1/RU40JHIH
05Z0I@1NREd0Ji=C06fJCP1fUDT0N8a708:8@@22QcT0Ph@d08>1<P1lPC@0N7ha07J0<01cQ3@0LH8f
075e;`1dH2<0LDlH06]75`1U@1@0Hc/C05P_3P02058T300W04TO2P147PT0@Al7040L1`0m7`L0A24:
04XV2P178`X0AB<804<R1`106PH0?QL403TI0P0h5P<0>aH3040B100j5`80?a<004HG0@1B80@0HS`C
06eZ;@1XS4P0GIMJ05>NI`1@X6`0Dj=Z066XG01XZED0KZMD072VD@1dY4X0NJ9707ZO@@1iVSh0NiDj
07^A>01hUC`0LiM00080LiI002H0LIA407:LAP1YYe00HjeJ05VdHP1A]FL0C;E/04FcK`0o]6l0BKQX
05:hI01C/el0D[1K05:YGP1?Wf40D:1M04fRF01;Ve40CG`h04976`0[6`P05@L100`3000:0`0030@0
00h5000C0`004P<00182000=0P00308000d2000;0@002P0000H0000700001P0000<000<00P000P01
00000`0000000@000000000300000004008000030@001P0000<10080100000D01P4000H200081000
1`@100@2000<0?ooo`002P3oool0500U;R<0;RPI02LM3P0Q50X07a0801X?1@0I3@@05``401<9100D
2`D05@`5018:0@0@2@803`H200l50@0:0`0030D101060`0C2P<05P`40P0H3@@09`0I3`D05P`401P<
0`0I30<060P201<70P0@1P404@H000h50@0=1P402`<000`50@0:0P0030<000`4000=10003P800104
000@1@003`<100h40@0=1@403@D001D:1P0H3@/07Q0E02HE8`0a5c40=R9202TbP00P=HH05cB801@c
Q@0?<HX033><00ddT00?A9@064R;01a8S002021;R00W02E?Q`0WDX80;UQk035MN`0dHGX0=6Af03EU
O00gKGP0>79f03U_N00kKgL0>g5e03U]M`0hIW/0=f9k03IRN`0cH7`0<E^102eIQ00YG8D0:eb602mI
Q@0^EXD0;564031<Q00cAh40<4B10357Q`0dA8P0<T>702m5O@0e@800=4B303=8P@0e?X00>Smf03Tn
K00m@gT0@TQ_0080@4AZ02L0@4=^04I0K`0o?F/0?T1S04I2H00o>Vl0>C6504E0L00o>G40?cN104a9
J012A6H0@C]k04M4K017?g00G5aS04mGH`0h>8`0?RN002lZS00k=8L0>d5m03@eR012>XD0>U2503I?
P`17FWP0A7Yb0420N@15P7<0CX5X06F6FP1dRU80NhI=07n1A`22P480Ph1008Me=@24I2X00P1mEB<0
9`1lD240ODlQ079@9P1/E2P0HD/V060n6@1Q<a40ERL:058M1@1?7P<0C1/504PN1P1;8`L0CBD804hR
1P147`H0@ad504DJ101260<0@a83044C0`0n4`<0?Q@203hB000o5040@AD204DE0P1760@0D24:05d[
301P;`h0GSDA05d^3@1Q<Ph0HB`=05la3P1U=Ph0JSTC06Hf400206Le4@0W06/j4P1/?1@0KClF06Q0
501[>a40JcPB06Hd401R;@h0GRL:05TX201O:@L0JC4=06Tf3`1Y=Q00JCD@06Da3`1Q;@d0H2h=060/
2`1T:`X0FBT705HU1P1A7`D0BQ`504dK101:6P@0B1L104PE0`146@@0AA/204@I0P176P@0@QT4044I
100n5P<0>QH403LB0P0f4`80>A<30080>1L302L0>aL303`E0`0j5P80=a4203/@000h4040>Q8103`C
0P0j50<0>QD203dI101070H0@al804TR2P1D9``0ERl=058[2`1>90X0Bal7048J1P126P@0@aX504PH
0`196`D0A1/6040K20137@P0B2D:04HU2@1890L0AR@704<P20168@T0AR<;04HQ2`149P/0@BP<040S
2`0o7`L00P0k6`H09`127@T0CB@906I37`1MJ4<0FX5I06=dI01EHW80DFeh05]TLP1EFGT0EFm`05Qj
K01LQFT0I8mP06b:F01YQeL0I8=L05QeI`1OQUd0J95D06nFCP1hTTP0O8Y608:7@P22QCX0QH<d08>1
<`1oOS40NGT]07Qh;P1bNbh0Kh0d06]n=`1`Kb`0LE`R06Q;601P@AH0FSD@05<[2`02050V200W04LV
2@158@P0@1/703TJ1P0k70H0>ad8044P30128P`0AR8:04<R20137`L0@Qd5044K1P1260D0A1L504@F
1@1050<0@1L1048G0@1=8PH0HTDG06Uf>@1SSdl0F9UM05:TI@1EYFL0FZIP06JXE01`YTh0L:I@076V
C`1cYDX0MjE807NTB01hWT@0NYY207ZG@01iVdD0MYi70080MIe701T0MIm8076WC`1W/5P0G;AR04Zh
J`15]g40?[Qd03RfMP0h]7D0@[Q^04jfI`1DZeh0EJAF05FOF01=VEd0BiIK04bGDP1<TdP0CG@d0457
6P0Y70P05@P100h2000<0P0030<0008040@000`050<001<4000C0`0040@000h2000?0`003P8000/0
000:00001`4000@000030002008000030040000000000@0000D000000P0300000`040@001P4000<0
00020080000400<000030@00104000<000`0oooo000:0?ooo`0D02UMK00mFeL0B51904]2@017>CL0
@3D_03/b9P0c:Q/0:b0?02<F2`0L4@P06@d601H:0`0B2@8040L300`60@090`403PL201890`0G2`@2
01H=0`0901T;0`0H2P<05`X301L:0P0D1@803@D000h4000?10004PD000804`H101`040D301470P0A
1P404`P10146000A1`0050P101480@0@1@4030@101050@0A1@8050D201<40@0D1P405@L201`9100]
8QX0<cD_02e2?@0VC4h0859N01UFK`0EEW`05en601YMR@0RFHL09e>80P0]F8809`0aH7d0>fQe04E^
J@18LVH0BGMU04QkI@18OFP0BH5V04V4I@19PfD0BH=T04MoI`17NfX0A7A]04MaK`17Lf`0A7Aa03ec
MP0jLGP0?7=e03ebLP0mKW@0>6Ii03ERO00dGH00=UJ103IDQ00^E8X0;Tb802i=R@0[D8<0;Dn7035A
P`0cCGh0<DAk03M1M`0g@W`0>TV00413OP020413N@0W03]0L`10@GX0?D9_03dnK@12Ag40>SYY03Pn
KP17@Eh0?CeU03`gP015@WD0@Sm`04<kO`18?7X0ASed069TG`1AGEd0=d2004<]M@0g?Vl0A4=Y03/i
M`0d=8P0A3R503eCPP0dBXX0@U62041iN`0nP7/0AH5c04b9J`1OSEd0KXYB07N5C01lP4L0P8120860
@023MCH0OF4Y0080NE<Q02L0MdlQ07=;8@1bDBH0KUHY06AC:P1SBR@0G3HE05HR1P1>6`@0BQ`404XL
1P187@D0D2<704/T20167`H0@QT503hH0P105@<0@AL2040B0@0n5P40?AD103dC0@0j4P40?a82048D
0`105040AaH3050P2P1J:@`0GC8?05da401K<@l0HC<B05`_3`1M<@h0HcL@06Pn4`1Z@1H00P1[@1H0
9`1]@AD0KDHJ071;6`1_@AH0K3`C06dj401Y>a40I3<?068_3@1K:0T0G2L906<^3@1W=100JcD?06Tg
401X<Pl0Ibd<05l/2P1L9P/0Fb@705<N10176@@0@AP2040F101050@0@1D3044G0`1260@0A1/504LL
1P116`H0@AX604DM1P157PT0@1X603/I0`0h6@80=aH3034D100203@E100W03TF100n5P@0@Q@503lF
0`0j5040?18103`D0`0n4P80?aL4040G10125@@0@1P404HH1@1:7`L0CbD;05<Z3@1F;0/0DRL<04lU
2`188`L0BA`4048H10126PD0AQ`504<I10127@H0A1/704PS2P199@L0CBD:04/Z301;;@d0Bbd<04l]
301;;@d0B2d>04L`4@16;@d0@bD;0080@al802L0AAh604XT2@1M?A`0FVE105^0DP1[MF00Femb05=Y
M`1NJ6h0F6Mc05QgKP1MPFd0GHMW06:=H@1URF80GH5R05ilIP1DK6X0GHMR06RAE01dTdd0Ohi8082:
A@24R440QHI008:8>`21QSH0OH0b07Uk<01gNc00MGX`075l<`1]P3P0K7Xd075[:01_F1l0HD@F05/d
3`1B:@X00P1?:PT09`1>:`T0B2@503lN100e6@@0=1P403HH100i7@P0?Al804<R2@19:0X0B2L;04XU
2@178@T0Bah904HM1`166PH0@QT303hF0`146040CB850692601YNS`0GY5C05NGH@1FWf<0FZAS062X
F`1]Y4d0Lj5=07>SC01dXDh0Lj5:07BTB`1dYdX0Lj9707JNA@1iWT<0Mj5607JUBP0207>XCP0W076/
C`1[]ED0HkYL05NmI@13^W40?[Mg03JfN@0d]GL0>[Mc04BhK@1?/VD0EZ9M05VOE@1FVTl0DIM@04n@
C`1@STX0Ch8o04YY;00n@1P09a/901880@0910002`4000X2000=0P003P8000`3000@0@004`8001D1
000F0`405`<00182000>0`002P8000H1000600000`0000<00P0000<000000080000200000P020002
0040000700<0000500001`8000L300070P00104000<00003008000030040003oool0oooo00X0oooo
000:0?ooo`0D0154T`0RAH@0;cn003PkN@13>fh0ACiZ04E:GP15Ddd0CE4k04Q6;P11=R<0=B/J02lO
500V6@`07a8701`<1@0F20<050T301L:0`0G2P@201T;0@0W01H90`0E204050L201D80@0C1`005@D1
01L80P0M2P@08a<702PG2`0V6@X09AX=02<K300T5PX08A<701/<1@0H2P4050T101050@0>1@003`H0
01860P0A1`4040D100l40@0@1@404PL201H80P0O3`H0:a`<03DZ5P0e>BH0=TLe03I>@@0eGU<0=FAK
03UYHP0nJ680AFMP0080BV]M02L0CW9H05IhD`1MNdh0GX5B05b3E@1NQeL0GhMH05n6F01OQUT0HXQG
0665F01ORET0G8UK05b5G01OP5X0HH1L05Z0H@1@NV@0D79V05=fI@1HNUh0GWEG05MaF`1ELUd0Cg=R
04adJP16Lfl0?g=d03]_N@0fJgh0=FQo03=SP@0iFgh0=eJ103AFP`0kE800?EUn03iEO@0oCGT00P0o
AGL09`0k?gT0>d1l03e2M00nBFh0@dUf03`dI00g?Fl0@Sej03e0K00l>Gd0@dAf04=1K@12?g80BTIS
04a?IP1SKEX0DE]E03I1MP11>Vl0AeaH04iIH`0f=780<C6;04<fQ@0lE800<DJ<041@PP10NGd0B81c
0526K01KS6<0HXeJ06R8E`1ePDd0Nh1907j0@`21P400P7Tk07aT:P0207M=800W07136@1`@aX0JddT
075B:01^DRL0J4`S05lg501I9@P0Cah604lP1@1=80P0CQl704dQ1P1:7`D0@aT603hE100l5@80?1D3
03`D0`0o4`40>AD203dF0P0k4`80>A0303XA0P0l50@0@AH404LH0`1>8@H0F2T;068e3`1R=Q00Gc4A
05he501M;Ph0FR`<05d`3`1W?AH0L44F0080KclF02L0KChF07576P1aBAX0L40D06/l4P1/?A40JCX@
06Dd3`1T<0l0HBP:05dY2@1T;``0IS@@06Lf3P1V=P`0IC8;06<]2@1L;0/0EBD604dR0`176`80BQL2
04@G0`125`80B1L304HJ10136`<0Aal704/N1P1<7@H0Aa`404LK1P167@D0AAl904HM1P0m6P@0?aH2
03XG000j50@00P0g5@D09`0k5`D0@1P4048H10126`@0@1P303lF0P0n5@<0?AH3048K1@106P@0@1H3
04<C10155@@0BAT504hP2@1@90X0D2L905<[3P1B:`l0CbD804XR201;7@D0BA`504/J1P146P@0A1X6
04DN201>8`T0CbL:050Z2`1?;@l0C38@050d401A<A00DS@?05Dd3`1B=A80DC<A04da3`0204T]3@0W
04`V2@1>9@T0GcTI05iN@01QNU80LFmM069JL@1GIW<0HVa[061/K01NNf`0H85V05f7H`1SRF40HXEU
05R3I`1GOF`0DgM/05f7H@1XTE@0MI9=07bAA022RT<0QhQ008>7@021RSd0PXPg07n1<`1lP380N80e
07Mm<`1bNc40L7dc071i<`1^J2T0IeHO05do5@1@<0d0Cbh=0080BRd<02L0BRH:040O1@0i5P80<182
02/A0P0`4P<0;a<303TJ1`128@P0ABP904LX2`199`/0AbH904/Q1P1;8PL0Cah604TN1@136`80@AX4
04DJ1P1M=a80J7<i062BE@1FUV80F9UQ05bTH01UZUP0JjA=07>OB@1eWTH0M:1606nPBP1]XD`0KZ9;
07BMA@1hVT<0NYe107JSAP1aZ4`00P1`Zdl09`1/[e<0JKME06BjFP1E_VD0@kAa03V^M@0d[WT0<k5j
042gLP1<]6P0EJaO05RLG01HW5<0EiU;056CA@1@R440CWll04]^<P17DR80=b`A02<B1@0C20402P<0
00X200070@002P0000L100080@00208000l3000A1@004`<001H2000C0`003`8000d200090@001P00
00<0000200@0000400<000020000100000D00080100000X00`40008100020@001@8000T300071000
204000L100050@001@000`02000<0?ooo`002P3oool0500AA9<08TF402loP00h>gT0@c]^04DnJP15
BUh0AE==04eA>`18ARh0@CHS03D[6P0_7a@09QT<01lB1`0L30D05PP301@90`0G2P<05`X40P0I2`40
9`0F2@<05@P101@70P0E20404`L001D50@0G20807@X402<C1`0X5`/09QT:02DJ3@0S6``091H:024C
1`0K30D060X101@90@0@1@403PD000l6000B1P804@L101050@0?104040D101870P0F20807`l602/L
300e:QH0=CTV03I7=@0fCT40=EiC03ETF`0iJF80?VQR04EWH00204Y[G@0W04ibF01FN5<0GG]>05j1
DP1LPeD0GXMG05n7F01OQUP0GhII06:8E`1QQEP0GhUI05b9F`1LQE`0Gh1J0660G01JP640D7YT051b
IP1CMVD0F7YN05ieE`1GLE/0EG9M04mcHP1<M6X0AW=_03mcM00kKgT0=V]n03EXO`0cHh40>E]n03MF
P@0dEX<0>eB003eIOP0nEGd0?dei0080?dEg02L0>cmi03]0O00m@W@0?TU^04=9MP0l=6@0=ce_048m
NP0m@6`0?3Um04=4MP13@Fd0@Smb04Y6H`1<CfH0HfeJ055KE@0f@GH0@CY_04MLF01>FF<0=SAb034a
R`13=XD0?5B00356S010D880@7Um04R0L`1@QV`0FhaS06:=FP1XR5L0MH5=07^0B@1nP4<0PH10081i
>`1lI2X00P1gCB009`1`@aT0L4<J06]=901aDRP0KU8W06Q<8`1O=a@0FBD804lN1P1?80D0CB0804hO
1`1=8@H0BQl504<I1P0n5@@0?1D203`E0`0l50<0?a<103TE0P0m5P80>a<203T@0`0j4@80?1@4044F
101760<0CR4605PY2`1R=@l0HSH@05la4@1N=A@0GBh>05X/301M<0l0IcdF07115P0206lo5P0W06dn
5P1aAaX0LDTJ0710501[?180K3dA06Tj401U=0l0I30?064X2P1M:@T0I2l<06Hd401W=Ph0ISH<06Db
2`1S;@T0G2`;05DU1P1=8P<0Aa/204XG0P145`<0@QL204PG0`166P@0@a/304LO1`1;7PH0C1d604LL
10176`H0AQd504DO2@167@H0?AX403lF0P0j5`00>Q@40080=aD502L0>aL5040H101260@0@Q/4040H
0`0o5P80?QD303dF0`126`D0@1X4040F0`134`@0AAD404TI1@1>80T0D2@:050W2@1C:`h0DR/?04lU
201:8PP0Bad504TL1@1;6PH0A1X404@J1P157PP0CR<904lW2P1@:P/0Cbd?04`b401@=100DC4@058d
3`1E=0l0DSDB054c4@1=<@l00P19;@d09`1<9PT0CRD905li6@1NGT00HGYB075_G@1RFW40EfIc069/
J`1PK6`0GW]/0621IP1MQf<0HhUQ06:5I@1HPfL0Ege/05=gK01MQf40J95D07FBC@1lTD@0PXY308N8
@023Qd00PHXm08:8=`1oPC<0O80b07R0=@1gOC<0LW/a071m<`1`NC<0KVPY06MF7`1M?aD0D30=04l^
3@0204X]300W04XV2P107`D0>AH2030B0P0[4@80<18302lC0`0i6PL0@R4804DX2@17:0/0BBL;04LV
2@1;8@H0Bb8704lN1P197PD0@a/2044J10156PH0GCLB06Qc>@1PTUD0EYIR05RIH@1LY600IJYH06^T
C@1cWdT0MIi607BPAP1_X4X0KJ5<06jRB`1dWDD0N9Y307ZM@@1fXdH0LJQ<0080L:]?02L0K:mC06Vg
E@1T^UX0EKiU04>dL@0i[WD0=:ii03>aNP10]g80C;AX05F/G`1HW5`0F9aC05NIB`1ATdD0D8Q104io
?01;KS80Ae8R03L/4@0S4PD04`P100X3000:0P001`4000X000070@00204000P2000?0`004@D001<3
000F0P004`<000l2000=0P002@4000H0000300000P040000100300000P0000@00005000200@0000:
00<100020@000P4000D200090`001`@000P100070@001@4000D000<00P00303oool000X0oooo01@0
11B]00LAU@0:49@04aNB01lNT00_;HX0:Sn302iEM@0oH6P0CEiP051DFP1=C580BTU504Y8=@17?bH0
@34J03HT4P0b7`h0:QT:02DC1`808Q0701P07`h301h=0`0K2`406PX201`:100Q4@L0:QX>038Y5`0d
=240=3dS03Ll8@0c=a/0=38H03<[500^9@h0:1L801lA1@0K3PD06@X301@80P0@1P004@D100h50@0=
1@4200l40@0=01<70@0H2@8080`102`D1P0d6``0>RPB04@b7019@bH0BTT[04eE<`1BHCX0EVTl05UW
>P02061/>00W06Eb?@1XN400JWU006YnA01WOdd0I8=C06F0E`1VO5/0IX1K06R0F@1^P5@0L8IC06j>
E01]Se@0JXaD06n0E01VMU/0G6aQ05mTI01ULeX0LWU406eX=`1VHcD0IfDg06M^>`1VLd80HgI;065m
D@1NP5D0FX1M05B0HP1<MF/0CFm/04U_L014KG<0AVQc04ARN012FgT0@59k0080?DN202L0>4F403U7
PP0jB7/0>TU`03lhJP0i;fd0>Saf04=0M`12@W80?cmj04Q2L`14AF`0CUYN051LI@1=GV40GVMD04Y>
E@0e>800A4Ic059RE@1FHeH0@D]W038eR011=8<0>Df403<kS@15CWl0?g1o04AjN01IQ6@0IH]J06V:
E`1UQET0Lh1@07Z0C01nP440PGTl07]b=01hH2P00P1fC1h09`1b@aP0L4<K06i?9@1aCbH0LU0S0757
701X=a00FbT7050O1@1?7P@0CR0604lP1`1;7@D0@QT403/E0`0j5P80>QD203LF0P0i5080>AD203DA
0P0d4@<0<0l303LA0P0j4@<0?a<304@D0`1860D0Db4605`[2`1S=A80HCDA05h`3`1P<Q00FRX;05HX
201M:``0ICLA0753600207515@0T06e05P1^B1`0LDLI0750501_>A@0K3HA06Tg4@1S=@h0GBd<05/Y
2P1K:@T0IC8>06/h4P1[=@d0Ic8=06<Z2@1Q;0P0GBh905HW1P1B90H0CAX504XK10186P<0B1d204hQ
101G90L0ERD504lU1P1@90L0D2<404XO10196PD0Aa`704/O2@177`P0@QT30P0m6P4303/F100W044G
100n5@<0?QD3040F0P0l6P<0@AL3040E0P116@<0?a/4048F10135`<0AQ0104HB0P175@@0BaL504XM
2@1;90/0DBP<054^3P1B:0`0CbD:04lO2P1<7PT0BQ/804DJ1P177PD0BQh604dT2P1@90T0DB/;05<`
3P1A<0l0DS<@05Hd3P1D<Q00EcD@05Hj4@1C>a@0E3`E0080Cc`C02L0EC<?054]2`1Q>1P0H5I105ia
D`1^LUh0HVA/05m[K`1RKVd0Ffi`05UiJ@1NPVL0GhMS0625H01MQ6D0E81]051mK`1?OW80FHQU06NA
E@1^TT`0N8i707f;@P22RT00P8U007j9?P1oQCH0Oh0c07Um=01iP3L0MW`a07Ui<01eNS40KWLb06]V
:P1NERD0FclC04hc3P1:=A000P18;0h09`1080T0<a<402h=0@0Z3000;0d002`?000^4@80=1D5040M
1P138PP0ABL904LS2@1780T0Ab8704LP101780D0Ab8404PL1@0n60@0@1/405@]2`1[Ic40IhmB05VD
IP1KVV@0HJ9P06RXF@1ZY500LYe807FJAP1`X4T0JJ1@06FOE`1UXU80KZ1707:MA01bWT80L:E606jY
C`0206^/EP0F06ZaE`1T]UT0FkMM04jeJ012/WD0=:Ym02nZOP0c[7L0@[A_04^bG`1JYEH0G9]>05^H
B`1FU4D0DHLm04mj=@19LC<0AV4Z03`o6@0Y70T070T200d200802`800P0:0@003@080@001P0000H1
00090@00204000d2000>0P0040800184000=0P002`8000H200060`000P040@004@030@000P000080
000400000`4000@1000500000P0000<000040P001P8000P400070`001@8000D10002000000000080
0@00303oool000X0oooo01@0002g0000T`000Gl000F>00P>]@085;@033NN01M?R@0ZEG`0>eAf04E=
M@12Ag40?Tm^049RIP1>IUh0EeQC05U?B01DCCh0CdH_04Ph8@80@2/F02L0=b0>030H200c60D0<1L6
038I2P0k9100?S0H03e18`0kBRh0>dP[03i18`0l>Q`0>cHI03Hb600d;1D0<bLA02dT400V8Q808aT?
01d=1P0F1@404@8000h2000=0`003`<10104000B1@005`H201d;0`0T40D0;1T803DT3P10;A40BCTJ
04i47`1DC2@0EUHZ05iP;01QH2d00P1TH2`09`1XIc80JVlg06Y[=P1/LD80J7U706MjD01YLUh0J6mP
06I]H@1/Keh0KWIH07:3C`1bSE40L8mB072>DP1bQ5H0KW]J06A_H01TK5X0LW9406mJ:01SB1l0GdXO
061=8`1TEBL0If4a065a@01RM4L0IgQ406b0@`1^Md80KgA2071dA`1]MDd0HgAJ05QcHP1@L6/0BfQa
04]OM00204IJN@0W049GO012EGH0@Dik03a4KP0l=6l0<c>003LlQ`11?h00@dEn0412PP12@Gd0@DEc
04U;FP17@eX0@TMP04M4GP13?VP0>CR4051BJ`1@EEP0CdEU055MH@0g>X80@c>0041:P`0h>8/0Ae]g
045kN01<P700IXUM06f=DP1^QU80JhED07N3D01jP4T0Oh1007ma=01kHRT0Ne`V0080MU@S02L0LdhR
07==8P1bDBD0LThS07IA9@1gBa`0L3PA06LZ2P1H8@D0DAh404lP0`1;6P<0AAT403hD0`0k4`80>QH3
03dA0P0i4P<0=a0103@?000c3`00>14103H@0@0o40<0@1@4044G0`125`<0B1L504hM1`1J:0/0HSLA
068c401P<Ph0H2l=064^3@1Q;P`0HRh<06/h4@1aAAT00P1cAaT09`1a@1H0LDLH0799601/?a@0JCXA
06Pg401X=A00HS4>05da2`1I;@T0F2d9068a2`1X>0d0IS@=060`2P1O:`L0GR/805d^1P1G:PL0FRP8
054S1@1C8P@0DB84054P0`1E9P<0G2d905dW1P1F9`H0CbH6054T1`1=90H0Cb0504/Q1@1>8@D0CAl6
048L100o6040?AH103HC0@0203PD0P0W03PC0P0g5@80>18003`C0@0n4`40@18303`D100l5`<0@AH3
04@D10115@40@a80040E00125@80@AD4040G1P1870T0C2T=050_3P1B;0h0D2/=04lZ3@1@8PX0C2D9
04TQ1`1770D0Ba`504XO201;9@L0DBT9050[2`1C:`/0DB`>05H_3`1G=100ESD@05Lh4@1B?1@0EChG
0080Dd0F02L0DS/D04d_3@1K=aH0IU0h06M_C@1[LEh0I6][061cL01OJfl0F6Q`05UjJP1OPf@0H8EP
06B6H01NQFD0F7m^04mfM@17MgP0DhY_05f@F`1ZTd`0Li5607J>@`1dSd<0MY5307N>@P1fQcT0M7d`
07Ij<P1gNc80M7D_07Ec;@1aMRd0K78^06AS:`1PER@0GD@H058l4`1;?1@00P15;a00100g6`P0;0d1
02@9000Q2P0202H<000Q02/@0@0d4`80?aL5044I1`137PL0?Q`503hK1`0j60@0?AL404DG10176@80
@AT2048H0P0n6040C2<706eA8`1`R4X0GY9V05NJJ@1LX6H0H:EQ06BUFP1[WTd0LY]906bNC@1PX5D0
G:AJ05ZYF`1PZ5D0I:IA06JVD01UZe<0I:mG0080HK1G01d0G[AK05VaH01B[FL0AZY/03jZM`0bYX00
;ZN003FZN014/6X0DJiL05VOC`1JUDP0EY5605B7?`1>LC40BElW04AE8P11AA/0=2`@01lA1@0C0P00
304000X2000=0@002`4000X200090P001`0000<0000200@1000800L0000;0P0030@000l2000:0@00
1P0000H200040P0200@1000@00410000000000000080000300000P400040000200000`4000<00006
00001`4000L200060`001`40008000<00000303oool000X0oooo01@0002D0000R0000HP000700004
`0002;/01B6A00`[Q@0J<X@0=3el03TjO@0b>G`0;DAj03=CM@0kFWL0@daf04U3L@15D6X0BF5P05AT
E080GEe702L0HDlk0615=01O?BX0FCTU05Do9P1FBRX0DTh[04mC;P1<Dc80B4la04M7:P15A2L0Ad<V
04I28@0o?1`0?SLJ03dg6`0i=1X0<BXE02TF2P0L30@06`T201H60P0F1P4060D101T8000J1`007`X3
02@A1P0Y5PP0<Qh<03`/4P18<aH0Bc/K055;8`1HCb80FU8T061G9P1UFbL00P1WEBD09`1[H2/0JVDa
06QO<01[JT00JWA306]bC@1ZIED0IF9S06ISI@1XIF80KW1H07>0D01bQE00LHaC076;E01cPED0KH5I
06Z0F01aMT/0LE/_05e16P1F?1D0E3XI05Pn6@1M@QT0HDdT05mR>`1KKd00HW=306MeA@1YLT00K790
07A`@01kK3H0NW0k07Ec@01[Ldd0HG=M05Y_I@0205IZJ00W059UK`1:GfX0@eUc045GL010CgD0?4f0
03m=OP14BG`0Adih04A<M@16Agh0ATEi04<lM013>GT0?SR1040eP010?H40@cZ205EJK01@Ee`0Bcim
05ePGP0k>h40AcB10459PP0oAH80Efi[04n0K01JP6<0KhEC07B6CP1aPe00LXU@07V5C@1jP4L0OG]0
07]W<`1iFbP0NEXS0080MUHT02L0ME8R06mA901_DB<0Le0S07QB8`1lBQ`0Mc`D070e3@1Z;@X0GBH4
05PP0`1?6`80AaH3048D100l5@80?A<303`A0P0k4P80>Ph103@>000g3@40?A82040D0`105`@0A1`6
04<J1@176080B1T404/L101H9P/0GCHA06@e401T=Q80IcTC06Pg4@1Z=100IC@=06Xh501^@QL00P1a
A1X09`1^@1H0K4<H06]35P1V?a@0JC/B06Li3@1V=0l0HSL>068f301O<0`0Gbd:060c301R<P/0FR`;
05TX201G9PH0FRL605dX201K8`P0FbD705TV1@1L90H0FB8605HT101C9P<0EbP605HS1@1@7`L0BAX7
04XJ1P198@L0BQ`404TK0`1580H0AAd603/H0`0j4`40=A0203@?0@0203H@000W03DA0P0^4000;``1
038@0P0f4080>A4403`D0`0o4`<0A1D2048G0P0o5@80@14103`B0@104`00>`l2040E10126PL0BBL<
04l[4@1?;@l0CBX>04`Z3`1:9`/0CbD904lR201970L0BQ/504HO1@1;70D0B20604/U1`1;90P0BBH;
054X2P1A;`d0E34=05@d401?<Q40DS@B0080DCDA02L0Dc@@050a3`1J<A00HT@K06aT@01]LU`0HgIY
05]oJ`1JNVh0DgQa05Z2JP1OQf80IHYL06^9GP1UPF80Fga[05=aM01:Kg`0BXQc05JBH`1YTe40Li5:
06fAA01]TdH0JYE806jCAP1]R3`0K7Xb079c;01bLRh0LG8/07Ai<01]N300JWDc06=]<01MHB/0GU8P
05a?7@1BAaX00P15<1409`0`5PD09PX101l60@0P2@008`L002L;000[2`40=A<103`F0P0k5@<0>AT3
03PH0P0c5040<A@1034@000f4P40>QL103PI0@0e5`00=aL003hK0`1V>1<0M7Q305nCH@1AVVh0CYe`
05FQK01GXf<0Gj1G06>PDP1TWE40GZ5F05NRF`1BZ640D:]R05:[H@1DZF00EjYQ05R^H00205F`I@0F
052`IP1:[6`0@Z9d03^QM@0iXgX0=:9m03BUNP0iYg<0AZeV04jYFP1BVTd0EHe404n5@01@MSL0C5XT
03i2600h<Q40;bH<020D1P0A1`40204000H100801P0000l0200000/0000900001`0000H000050@00
100000D0000900002@<000L1000300000@00008000010@00100100002P0000000P00004000010000
0P000040000300001P0000L00006000200H1000300H2000200000@0000800000303oool000X0oooo
0P000;004P000;D000320001`P000kl00PZ400<9O0073X/07Rb=02<hSP0S@8P0:T9k02loL`0h?WP0
?SEh03XbN`0fA7L0>5Mb049JK@80CUM[02L0DUEX05EKH@1JGEP0GEi=05URC@1GJED0FfQG05MRE01C
H580BUmC04EMCP16GTT0AF9004YN=`1=Db/0CT`T04a78`1:A1l0@cTI03dZ400d7`/0:QD702<@1P0Q
40D07@d301`80P0L2P408Q4602hP3@0b9A40?2hD04Dh6014>AT0C44M05=A:01HDRD0H54Q06EF9P1V
F2D00P1UDR809`1ZFRP0JUl]06]N:`1ZID00JW5206MUD01XGUL0GUER06=HJ`1THfL0JfaH07:0C@1e
Pdd0LHMD06b6E`1bP5D0LX1F07F0D@1iLS`0JDXP05Hj5`1A=a<0CS8C04hd501F=A@0G48L065K<P1N
J400HFm505i`B01SLT00Hg5006I_@01_IcL0LVTf07ET<P1iHCP0O6i007Qd@P0206adD00W06IdF`1J
KF40D6IX04UWK016IG80A61g049JN012DWD0Ae9c04=BL@17CGH0A4ai0415O`17B7d0?dB203ljQ011
@H00BDYg05MQJ01IGUD0F5M[05iSF@0o?7`0Abn10492P013BX00GgQQ05^1H@1WP5H0N8A>07b2BP1l
Q4X0OH1707b0B01iP4H0N7Y007EV>01fGS<0MUTZ0080MUTS02L0M4lP071<7`1`CAl0KTTM07A8701e
B1L0L48B06lk4P1Z<`h0Ib`;05hY1P1G7P<0BQX3040G0P0j4`80?A8303lA0P104P<0>A8403PA0P0k
4P80?aP403lK1@1070D0@ah604LL101470@0B1/604HN1P1C9@P0FRh=05h_401U=Q<0JCPB06Xg4@1`
>a80K3XC06do5P1/@A@00P1Z@1P09`1YA1X0LD@H06a15@1Y?AD0K3`A06Lh4@1V>A00GS<=05h`301O
;@`0Hbh;06<b3@1N<0`0EbP705HU201B8`D0EBD505DT201I90H0FRD605XV101M9`H0EB@605HU1P1D
8P@0D2<704/O0@166P@0AAD404HF0`1560<0@aH303dF0`0m5PD0>QP403HD0P0c50<0<a83038D0P02
038@0@0W038?0@0`3`40<0`103<<0P0e4@80>a<404@D10134`@0@1H4044G0`0o4`80>Q4003l?000k
3`00?18203/@0`1260H0BB<904h/3P1>;A40BblA04`/3`1@:@`0E2L;054S2@1<8PL0CAl804XO1015
7P@0AAh604`R1P1:8@L0CR8804/V301B:@d0DR/=054^3P1<:@`0B2T=0080C2/;02L0Abd>04`^301<
;Ph0Ec@@06]E;`1ZL5@0FWYX05R2J01FPFD0D8=/05F:H`1ORf40JXeH07B=E@1/RE/0H8ER05QgL01:
LGT0AXMd04bAJP1NU5P0JYE?06^DA@1[TT@0Ii=606NCA@1YRCh0IgLb06YY:01[JBP0KG8_06em=@1[
OS@0IW/d06Ad<P1NJRh0GV@Z05QM9P1ABA`00P13:Q009`0b4`@08`L101l90@0S2P409@X002<:0@0X
2`40;`d1038A000g5@40=QT103LA000a4000<0h102d@0@0_4@40<14002`B000_3`00;@h003@B001B
90T0Jedc05n@G01<UVl0BIUd04nNLP1BY6/0EZER05RSF@1MWU@0GiiE05fQFP1DZ680CZeW04N/K@16
Z6h0BJQY04Z/JP0204V]L00D04N[L`13XgD0?Iii03fNN010XgH0@ZEa04FVJ@1:Y680Cj9H04nLD01>
TDP0DH4o051f=`1@I2/0A4TJ03H_3P0X7PL0714401<7000:0P0200D1000500D0000400001P0000P0
000900000P0700001P0600000`000080000600001@4000<000<0000000<00@000080000200001@01
00030000000300<000020000104000801@0000H01@4000H0000500000`0000400000000<0?ooo`00
2P3oool050000<<000340000[0000:l0002g0000`P000840001[000?Q@079Ih05cF901dcPP0Y>h00
<CEe03D_N00f<W/0<SYl0356M`0dBGH0?TA`0P14@Fl09`11AG@0>e=d04=QK@1@HfL0D65T05=SHP1I
Gf40F5IT04aCJP12GfL0?VeU041_F@17KDd0BFe604iZ@01CIC/0DUlh05AK<P1BDRX0CdDP04Hf600o
;Q80=b@>02hM300Y6`X09QD702<C1`0Y6@T0=BLC03T`5`11=aX0AT0O04Q5901=BRL0D5H^05MG:`1M
EbT0JF4_06YS;@0206MJ:00W06aN:P1[Gb`0JEd_06QW@01XKT80IeiI065BGP1KEe`0HDmR06=JH`1/
J5L0LgE?07QnC01/Q5@0Hh5L06Z0F`1fPE<0O81007AR;@1S@Q/0E34C04h]401::a00CRhB05<f5@1L
@AX0He4U06MM=01SI400G6i3065_@@1PLD@0I75006I^@01YKD00LV<b07IE:01fEbX0NET[0080N60h
02L0N6e006mcC@1RLU`0EFeW04e[L018Ig@0@fAi04EOM013Gg<0@f=^04MRL016IG40?eel041?P@0l
A8<0>SR903m4P`1<EV`0E5mV05=KF`1DFf40EemM03m3OP1:>W/0Aemg04]]L@1OP5d0GhEK06b2D@1h
QT/0NhE:07j3B01nP4@0O81407R0@`1fP400Nfa007QN=P1fEbX00P1cE2409`1bD1l0L4`M071:7@1^
AQX0Kd<H070m501^>Q80KCTB06db401X;PT0I2X905TR1`1>7@<0A1P303hE0`0m5040@1@2040E100j
50<0?a<303lH1@136`D0@1/503lM1`1380P0@Ad7040J10105P@0@Qd704/V2P1?9P/0ER/;05d`3@1R
<`h0J38>06dm501cAAP0K3lC06Th4P0206@i4P0W06I15`1_AAH0LD@E06i0501/?A80ISP@06<d3`1M
;Ph0GR`<05lZ2P1Q;`X0IC0:06<a2`1K:`P0FBL6054S101C8P<0E1h705DO1P1F80H0Eb8305TR0`1E
9@@0E1l4058M0P1>7@@0BQX104<E0P0j4`40?A4203`C0P0l3P80>14303TC100o5`@0>aD503XE1P0n
50<0>a@30080=Q<202L0<10002l=000f3040>1@203`C0`134`@0?aL3048D100m5`<0>aL303/F0`0j
5P40>Q@1040E0P0l4@<0?A8403dJ1@1180L0C2D:04`U3P1>:@l0BbH=04lU2P1?8`T0CbD9054T2@1A
9PT0DB@704hS1`1<7`H0Cal604hP1`1>90H0BB@804XU2`17:0/0Bb<;04TR2`148PX00P167PP09`16
8@P0BBH;040W3016:@h0GD8O069XB01GP6@0DhI^05>:J@1BRfH0FXUQ06>>F`1[U580M91=07J>C@1[
S5H0Fh5Y04EhMP12QgD0Ai5Z05VFG`1TVE<0K9A506^@@01ZTT@0I99506B=@@1UNcD0HVHY069Q901Y
K2/0J7Pb06Mm=@1VO3D0GgXf05ab<P1JJ2`0De8P054e4`0203dL200W02L?0P0R2P408@P202<;0@0Q
2P808`H102@70@0V3P40:102030@0P0d4@<0;``002d;000^3P40;0`002X>0@0Z3`40:@d002@:000U
2P0090X003HB0P1J=aP0HX18052IJ@0oUgT0@IQi04bNL@1>Xf`0DJ=X05NTG@1LY5T0F:IN05:ZI`1;
[6l0AJUd046UM@16YW80AjM^0080?:=f0280>9]k03VDP00gTX00?9Mi04BLL01=Xf<0DZ=J056LD`1C
TdX0DI1404^9A016Od00@Vhg049I9P0d?1H09ah901`A100D20403`D000L000050000100000<00004
00001P4000X0000;00002@4000P100070@001`0000@0000300000@000P0200000`0100000`0000@1
000200<000<00@0000@00P0000400001000000000P0100002P0300001@0000D100050@00104000H0
00050000104000810001000<0?ooo`002P3oool050000<80002C0000T`0009@0002O0000`@0009l0
00=f0009O`034H803A]k01XUOP0T;HL0:C2402XkP@0]@gD0<45X03<oL@0j?WH0?Cid0P0k@g<09`0j
Bfd0>4i[03M;M011BGH0A4ad04EHL01>H6T0DeeX04YIJ`17Gf/0@VE[049UI`18I600CFiA051eD@1:
MU40C7E=04abB@1AJT00E60e05AG:P1ECBD0CT<Q04Lk7P0o<aT0>bdD03/X400k90d0?2`D03/h7012
?R40@dPZ04=A=@17EcX0CF0j055Q>@1FHSX0EfU005aZ>@02061U=00W06IX=P1YHc40J5lj06US@01U
IDd0HeES061:K01KBF<0HU=P061HG@1[J5H0LgA<07>0C@1^PUD0IX1K06R0G@1`P500MgI006eJ9`1M
?QL0D2hA04dZ3`1::`h0CRl@05<d4P1G>Q@0GT4I06=:901PFd00FFE005Y]@`1ILT`0GWE506Ad@P1X
LT00LFHf07=I:P1cEBP0L4`Q0080L4dQ02L0MUH^07QP>P1bJT80JVeB069[GP1FKfH0D71/04YaK`1;
LFd0BgAZ04IdJ`17L6`0?V9f041?O@11BGX0@45o045;O019EfP0C5EV04AAKP14Ag40C51Y045=P018
AGX0CgM^04Z0I`1GP5l0FXMN06V7EP1eQDd0MhI=07Z8B@20PT<0PH1008:0@01iND00NG1007UU>P1d
Gbh00P1fERD09`1gDb80MThQ07197P1V@QP0IC/D06@e401X=Q00JS<>06H]2`1T;0`0GRT<05PV2P1D
80@0Cb0504LL101760@0@aL304@G10135P@0AaT404HK1@116`@0AA/504HK1`197@P0AAd6044J1013
7@D0@Al804DP2`157`X0CB@:05HW2P1K:PT0HB/:06Df4@1W>Q<0HSPB060`4@0205le400W068g5@1Y
>a@0J3/C06Th4P1R>100Hc4>060b301N;0`0Fb/905l/1`1O<0T0I3H;068f3@1M;`L0EbT704lV1@1B
8`H0DB<805HL1@1=7P<0DQ`3058O001>8@40DQd104lI0P186@<0BAT3044E0P0n4040>A@203XC0@0n
4P80?1<303hF1@0o5@@0?aT503hK1@0l60@0>QD30080=aP202L0?Q<203`D00134@00>a8103hD0P11
6P<0@1h303dH100n5`@0?AH5040H101160<0A1X404<J1P1050D0?18503/E1@0o6@D0Aah804XO2P1:
8P/0Aal:04/Q2@1>8@X0CbL<05H]301G;@`0ERT;04lV2P1>8PL0C28804hS1P1=7P@0BB8704HQ2@11
7`P0@Al904@M20107PT00P106`T09`107PH0@1l703dN2P0h7@P0CbhD05eH>P1GOUT0EH=[05:6J@1F
SFH0FXiM06>@E`1]TE80M8m:07N@B@1cSDl0HHQM04j5K`1;RVT0C95W05NEGP1PVED0IYA:06RB@`1W
T400IHm106F;?`1SOcP0Gfd[061T9`1SJBT0I74_06Ed<01WM300HFl`05aR:01FCAd0BC@B03lM2002
02l?0P0W02<<0@0S2P808`X202<:0P0S20<080X001l8000R2P409@/102@>0@0W30409`T002X:000Y
2`009`T002D80@0W2P009P/002D8000P20007`H00245000l5`T0EU8X05J<E`17U7<0AYMg04ZLL`18
WG80BIi^04fVI`1CZV@0D:aX04V[K@18ZG<0A:Eg04:SN@15XW@0@Z5c0080?Iij01/0?Iek046JM@1;
VV`0EiaM05nIDP1NU4X0F9=905:=AP1@QT40C89004F0@010N3h0>F@g03Q:8@0`:a007a860188000:
10002P8000D0000200000`00008000030@00200000D100060@000P060`000`0:100020@000D00002
008000<0000000@00@000080000200000P000`0000002001000000000000000000000@0000800000
00000P000`0300001@050000100000D000030@000P0000`0oooo000:0?ooo`0D0005_P000kP000:i
0000Y@0009@000300000_`000Y@000>30003M`042W4031b901H[TP0P>hl09DB=02i5N`0f@VX0?Si_
03/nM00fB7H203EEM`0W03]KLP10DFd0@dA]044nK`10@W<0@Dee04ICL@15EGD0A5]_04UNK@1=EV/0
B5I_04INK@1@L5/0E7Q>051kCP1@NDh0CgM@051cB`1BKdH0FF]005eZ>01KH2l0Ee8W05=:8@1<A1l0
C3lM04Xg5`18=AL0B3dO0413:P10CSD0@EI004IN@@19Id40C6Q304]WA@1=JT<0EfY00080GF`i02L0
IFhj06aW=@1XHT00Gf1805iNC@1OC5/0GDU/0658J@1UEU@0IUi@06Y[D01dM4H0LWe?06b0E`1XP5`0
K81H0760BP1_Kc/0JEd_061<8`1K@1X0EC@D04/^401;;Q40C30B04l^401C<@l0GSTE05e=:`1JFC/0
FVU005EcB01KMDL0HgE;06QdA@1/LD00KV@e06mE:@1YBR000P1/AAX09`1/Aah0K4/W079G<`1aID00
KFe:05m`E@1ILEh0E7IS051fI@1?Mf@0BgIU04AXL00oGGL0@Dij04E9NP11@gd0@T]i04=CMP10DgH0
@UEi0415O`1>EW40BEaf04aDMP1AP6X0Ch1W05B0H@1DRV80HHUI07:6D01dQDh0N8U;07j6A`21P4@0
QH100860@01nND00O7<j07YX=@0207EM<@0W07AM;@1dEbT0KddQ06Pn5P1S=a40HS<?05/_3P1L:``0
FbX906<Z2P1S:@/0GBP:05dR1`1J9PL0E2D6050Q1@1?7@H0B1d704`O1`1:7PH0B1h504DL10167PL0
Ab4704hQ1P1<7P@0Aad504TM1P1;70H0AA`604<K1`146`H0Aal904lP1`1D9`L0GBd<05//3@1J;@d0
GRd@0080GS<@02L0HCD@06@g401Q<a40HS8@064`3P1R;P`0HBT;068[2@1O<0P0HBh806Dc301U=0d0
Hc8>05`/2P1J:@L0F2L805TU1`1D90P0Cad604lL101?6@40DQh304dJ0P1<6040CAD204HG0`166`<0
A1T204@E0`135P80AaT204TJ0`0n5`@0?1@303hF0`0k60@0?AL4040H1@0l60<00P1070<09`1970@0
BQl204/N0P176`80AAT204HI1@1370@0@Qd6044I1@146PH0AAd504LL101<8PH0BQT604@L1`106PL0
?aT603PH1@0o6@L0@QX604DN1P107`L0AAh704/T2@1F:PX0EBl<05P_301C:P`0DbP=04lU2`1A:0`0
DRD904hR1P1;8@H0BR4704@P1P1070P0>a/703hI1P0203dL200W03lK1P0j6@H0>AT603@I1`1590d0
FClP061Y@01IP5X0DhIU05F;I`1MSUh0IHeH06f?DP1cS4T0LY1807>>BP1/SU80GheJ066?F01OSeL0
Gi1H06>EEP1YTT`0JY5606^=?`1YQ3P0Ih0h06Al=P1OK2d0GF8W065U9`1RJ2/0Hf`]065/;P1OIBP0
EU0O04Pb4@0h7PP0;A4300809`T201008`/2024=0P0U3P809P`202H;100U30808@P202@;0@0S2P40
8``102@:0@0S2P0090/002T8000W2P009P/00P0X30005@0V300090P001X9000G1`009PX203lV3`1A
G300FGm>05NCF`1@W680BYaX04FJKP17WW00CZ=]04bUK@19Yg00AjAc04FRM014XWD0@Z5b04:PM002
03nJMP0A04>KL`1=WfL0GIeE06bD@`1XR3X0GH0g05F0?@1;PD40A7i3045j@@0oLcT0@Eh/03/o7@0]
9Ph08A<501H90@0?10000P0:0P003P0600000`0000<0000200001P0000H100070`001P8000L30009
10002P8000`200080P001`000P050000100300000P0000<000030002008000030040000200000@00
00800@000P000003004000040080000100000@00004000800P0000<00P4000<100020@00303oool0
00X0oooo01@00ARP000>X@0029`000:E0000W@000<4000320000X@0008D0005i0006KP004XD06CN=
02DnT00`@HX0=Sn303LkO@0e?Wl0;Tam02YKO`80<f=l02L0>f9k041HM@11DG80@UA/04ACK`17Bf/0
@D=e03m7MP0mEGH0@Ee`04aEKP18EG00AFE_04i`I@1ELeP0EW5B059_E01=LET0CgMG04ieD@1CN4/0
EgE305]]>P1NHbl0GUX]05QG:`1DDRX0DDXT0553801?AbD0Ad``03mC@011GD@0@VM904E]C@14KE40
@FID04AWC`1;JdP00P1HLT409`1ULD00JFdk06QU@01NEeL0GE1<06A=DP1F@6/0GTQe05mFG01NGED0
IFIE079aAP1bP540IH1M06EgG`1]P5H0K7A606M]@01SJ3/0HV<g06=G:P1LAQ`0Dc8C04//401;9`l0
ARL>04XS2`1B<A80F4<Q05iA<@1JID00Eg9905edB`1PM4d0IWI706Qd@01_KT00L60b06mG:`02071<
7`0W06a36@1V?QP0ID@N06]@:P1]HcX0I6M305U[E@1EKf40BG1X04YbI`19L6X0Af]/045SL@10EgD0
@E=f04=@M@18Eg00Aee/04YLJ`1=HFP0Bf5^05A_IP1=Jg80D69`05MoI01HOV00FX1M05b9G01RQUP0
LHUA07V5B`1lR4P0NhU807Z0B`22P400PH1007n0@01jND00OFli0080M68f02L0Kf4e07=Q<P1_E2L0
JD4L064d4`1T;`d0HRX<05`Y2`1M90T0HRD805hZ2P1R;P/0H2l905lZ2`1L:`X0F2@904lR101?7PH0
Bal804`P1`1:7PL0Aad604DN2@197PP0Bb8704TQ2@1:6PH0Bah604hO1@1=7`@0BQd504XK1`1=7PL0
CB47058S1P1D9PT0DbD:05@X301K;0d00P1M<`l09`1U=`l0IcHA06Dd401R<Q40Hc<=06L^2`1U:`P0
HB/7064/1`1U;@L0Gbh906<^2`1Q;``0HBd905h[201J:`L0G2H605XV1`1J7PL0Dad504lR101C7P<0
CA`304/H001>5P00Ba/204XM0`1<7@D0D1X504/M1P1=8@D0C20604DJ100m5@80>14203LB0P0l60@0
?aX504@J0`0204TM0`0W04`P1@1?8PH0F2@6058V1P1?8`H0CR@604/R20177`H0AA`704DN1`197PH0
BR0704lT2@1<9PT0D2D;050S30168PX0?Q`703`H1@0l5`@0@aT6048J1@197`D0BRD8054W2@1C;0h0
ER/=054Z301>9Pd0Cb/?054[3P1B9``0DBH904TU2@188PT0A1d703hK1P0k6@H0>AT70080@Q/802L0
>Qh803@J1`0g6`D0>1`703`N201>;0`0HDdT061dA`1FQ5h0FHYU05^:I01PRed0IX]E06j:D01[S4d0
KHa:06j>BP1VTT`0Jha<06b<B@1[SD`0Ki1:06n=A@1`Sd80L8Ln075k=01/Mc<0IGDc065W:P1LFb80
FUXS05YJ901LG2<0G5dU05QD801:>Q@0>1h;02P=0`0R2@000P0P1`009`0R30409@h302PB100Y50@0
:Q0402/?0`0Y3P80:`d202L>000V3@0090/002<:000Q2`009@/002<:000W3@40:@/102@<000P3000
80T101h90@0J2@407PD002d?1016;180DU8S05]d=`1JRTD0DIAH04JCJ`14U7@0AIMe04NMM016WWD0
B9id04ZQL@19Xfl0AjI[04fSI`0205FKHP0C05VJE`1SV4/0IY5106>2=P1KN380EW@b04ab=013KSL0
?fhj03aY>00mFR/0>SdI02XL2@0I30<04PH000h4000:0P00200000H1000200@0000@00<000010000
1`0000D100060`001@8000L200090@002`8000T2000:0@001`4000P100050P000`4000@100800P40
0P0300000`0100000P0000000008000000<00@0000<000000040000200000P02000<0?ooo`002P3o
ool01@08<Il01BFK00<DW`010jH0002b0080003200d0002_0000VP000HX000B500LDQP0C9Y008CFA
02XjT00Y>hl09T2@02Q;R`0VF8P0:5f30080<5f202L0=5V303=HQP0bGH80=FQl03aWM`16GG00A4]Y
03m?J@0iEG00?Te`04E6L@18BG40A5aa04YOL019G6l0AV=/041/K013LVT0DGaH05AnCP1FN4P0FG=4
05]d@01LLT00HFlk065W=@1NGRl0FU8X05U=901HD2T0DUHc04mN?@1=IDH0B6QB04Q]E@17K5T0@6IK
041WF016KE@00P1ALTd09`1MLd00JW9006][B01QHE80I4i3069?@@1LCET0GTQ_05YFH@1IHUT0HVU?
071d@`1]N5H0GH1W05mhH@1[P5D0IgA706=b@01PLT00Gg9005mW@01KD2L0E3DF04/Y30199@d0B2D;
04TT2`1E;@d0Fc`H05]<:P1IGD00E6Y005m_@01RM440HW=006IdA01^LD00LVm0079^@002079O<00W
06m=8@1Z@QX0HShI06=8801RDRh0I5Te065Q@P1KJE80DFeQ04U]I`15K6/0@fe_03eUM00nG7<0A5Ub
04QIK015FfT0C61P059RGP1HIeH0FW1H05ihF@1FN6<0D79]05V0G@1OP5/0IH1F06R2D@1[PE40Lh9;
07^5A`1nQTH0OhI807Z3BP1oP4<0Oh1007f0@01jP400Ng@l0080MFLj02L0Lehi079Q=01`ERL0KDLL
06Dh5P1P;@h0FRX<05/W2P1Q:0T0IB`806<_2P1Y=0`0KCH=06Hb3P1P;0T0FBL705PS1@1=7`D0Aah8
04XL1P167@L0B1`7048L1P176PD0B1d804PO1`196`H0BQd404dM0`196`@0BQd604lS1`1B90T0D2H8
05DT2@1D8`P0F2<905TT2`1K;0/00P1P=`l09`1S=`l0I3@=064`2`1R<`d0IC8>06L^2P1Q;@T0HBX7
06<W1`1N:@@0F2P705LX1P1H;@L0GRd6064]1`1K:`H0G2L705dY2@1L9PH0F2H605LV1P1E8`@0Db84
058M0@1>7040CAl204lQ0`1G8PD0FB<505LR101D80L0CB0704XF10134`80>A<203PD0P0k60<0?QH4
040J1@0204HL0`0W04dO0`1<9@D0DRH705DX1`1C:0L0DbT8058V1`1;7`L0B1d504LJ1@167PD0D208
050T2@1>:@`0E2l?05Dc401>:`h0AB<903dM1P0h5PD0?a@503lF1P116`D0AQl604`N1`1>9@/0CRH=
050Z2`1::0d0C2L>058/3`1A;0l0CB/>04dV2`1690`0@Qh903hO200l7@P0A2080080ABD902L0@BH8
044V301490T0@R4904HP2@1::@X0FSLC06YI;`1VODP0HXUC06F;F01PReL0I8UF06F9D`1QRE40IXU?
06V:C01/Rd/0JX]:072;AP1bS4@0MHY307R;@01eRT00KhM0075n>P1aNCH0LWDc06eX:P1UFB<0FU@Q
05AA7`1EBad0CTDK04Pc4P0i7`T09@h201d4000K0@000P0P1@009`0P2P00:`d302/B1@0]50H0;QH5
02lD1@0b4`@0<A<3030B0P0^4040;14002T>0@0T300090T002<;000N3@408`/10288000Q2@0080X1
01l90@0N2@009@D002P9000j6@H0B3@?05=C801MJRd0FWXm05N6C`1>TUh0BIQV04ZMK@1<WF`0BieZ
04^QK01;YVH0C:IQ05NNE`0205nHC00G06NB@P1URS`0HH0g05af<@1HKbd0DFL[04]K9P13C1l0@D8K
03/i600e;A80:Q/901d=100D1P004`8000/1000:0@001P0000@0000200000@0000<0000200000P03
00002`040@00100000L100050P0010<000L100080@001@4000D200060@001P0000800`0000<00P00
0000000000004`00000<0?ooo`002P3oool0100`CgD09DN401`fU`0C8:D20000`P<0003100/0002_
0000QP0219H01PfF00/NX`0><JD04T:K021BRP0SE8P09eV902QGR00202YAR`0W02Q?SP0TDhd09EV9
02aNQ@0`H8<0=emn03]NM`10I740@5ec04AAL@13BG<0ATUa04]DK@18E7@0AU=d041OMP0lJ7T0?W1a
04YdHP1>MeT0EgM;05Yf@P1JN4@0G7M206Ab@01VKcX0IFDb06=K;01OERX0G5da05MV>@1GKD80Dfm=
051_E@1>Ke/0AVeM04EVH@11Iel0@f]L0080C7=B02L0F7A606N0AP1[LT`0Jfa706IC<@1TCBl0Fe5A
05];K01EFF40GF=G06A]CP1aLd`0IH1K05B0JP1NP680Jh1;06Qb@@1QMDD0G7E705MfBP1GLT<0F5Tk
05Di5P1=:0`0B2D;04TS3@199P`0DBT=05Hd4`1L@b<0E5@h05QQ@01GJ400F6m005a_@P1OLTX0H7=?
065fD01RO4D00P1VM4009`1/KCX0KeT/06a=8P1VCBD0HU4X05m?:P1SD2P0IE`f05YTA01AKeL0CGMQ
04igH@1:KfL0CFeV051/H@1FJEX0EFAJ05EUE@1GJE@0GW1>065eC01TP4l0Gh1G05V0GP1LNEP0IWUC
06f0CP1]P4l0Lh1;07R3AP1mQ4H0O8=607f4A01oP4@0P8140820@021P400OH1007]f@00207EX?@0W
079M>P1bFC00LDhR06e;7@1U@AP0HC8>05dX2P1N9PT0I2T;06T_2`1Z<@X0JSL=06/i3@1Z=0/0IB`9
05`Y2@1B8`P0CAH404<F10115P@0BA/404PK1P156@D0@QT404PN1@1680H0BR0304XR101?7@@0Bal6
04`P1`1=90T0DRD:04lW201A:0P0E28805LU2@1H:0P0GRX90080HC<<02L0HSD>064`3@1P;@/0Gbh:
05l/2P1N:`P0FBd605l[1P1N:@H0GRT505hS1P1L90H0FR@705`X201N;PT0H2d805lX1P1O:@P0FBP7
05TY1@1I9P<0GBL405XW1@1B90@0DAl4050Q101D8PD0EbD705PR101H8`<0E2<204lN101960<0A1D3
03dE0`0m5P40?QL303lJ10105`800P187P809`198@80CAl304hR1`1C8@P0CbD704hV1@1>80H0BAh4
04DK1@156P@0BaP604/L1P1980T0BRX>054c4@1F=a<0Dc4@04dZ2P1680X0AAX804DJ1P1760D0C1`4
04LJ1@186PH0Aal804LS2`1:9P`0CRX@04dZ3`1?;100D30>05@_3`1?;Ph0BBd?04TZ3018:@/0A2L;
04PZ300204T/3@0W04/_3019;Pd0C2`=04X[3019:P`0BRd;05@b3P1S@AH0L64Z07El@01aQDH0K8Q:
06V8CP1VRE40GhUA05j9EP1KRE@0HX]B06J<C`1/Rd`0L8Y70728A@1eRD<0MHU007B:@01cPC`0LWTh
075b<@1[IBP0HeXR05YA7`1BBad0CCdG04<]3P0l70P0;a8402D:000N1@406PL100807`@002L08PP0
02D;0P0Y3@<0;1<3038G100c5`D0>QT703LG1@0d5PD0=A8302hA0@0Y3@008`T001`7000Q10008`P0
028:000W2@0090T00207000P1P007@L002@8000Y3@00=AX504<Z2`1<>a@0EDDH05M>7P1LHb/0G7Xl
05B:BP1BT580D9=J04jEFP1>Ue`0DIMG056GD@1DSdL00P1EQCd05`1GO3L0Eg8`05IX:P1DGBD0D5PR
04]A8019A1/0>bd?02`N2@0U50D080d301T90@0B1`004@@100h2000<0@00204000X2000:0@000`00
008000020@000@4000<00@0000H00`0000P0000800001`4000D100030@0200@2000300<100020000
0P0000L00@004000000<0?ooo`002P3oool01P0oETT0?eQB03eIH@0bE6`00PJm0002_`<0003100/0
002f0000O`000Gl000BO00<D[P07:Il033VJ01eAT00QD8X08e6<025>SP0201m<S00W01e:R`0MBh`0
8Tn:02M>R@0VCHX0:5N;02eRQP0iJWl0?fAj03iMM`0lGg40@F5]04UKK01:EFh0AeIa04IPLP0nH7L0
=fEh03eYL`14KfT0EgMA05ag@`1NMd<0Hh1106Me@01VLd00JW4k06a[=@1XI380HVTi05ma@01GLT80
GG9:05Q_D`1DLEL0D7=G04m]EP1@KU<0CFeC0080EG5=02L0F7=9061kB@1QLUD0I6a>06AJ@01SC400
Fe1N05eAIP1OGUL0HVa;06YcB`1]M5<0I81P05AcJP1XP5L0KGE006=Y@P1OKTd0GW=605UeA`1DLd80
Eelk05Hi6P1@:0`0C2<;04dQ301:9@/0C2L=04d/3P1C=1H0EChU05M<<P1HET00EUi005UP@01EJD00
FW5605UfB@1MO4h00P1NP5<09`1UN500KG55071W@01/Gc@0IeLZ065?:01PBb<0GE0W05eI=01MJD40
EGI;05=hEP19Kel0Cg1L05EbF01CKUP0DVQJ05AZD@1GKTd0HGI706IjA`1^P4P0JX1;06F0D01VP500
IX1D06]kCP1ZP4l0LX=907F8B@1nP440PH1008:0@024P440Oh110860@020P400OGQ007Qb>`0207EU
=`0I06mF=@1^DRh0KDhU06Y=7`1YAQ/0ICPB06D^301O:``0Hc0=06@b401V<@h0Ic8?06Db3@1T;@`0
FbL705LT1`1=8P<0AaL303hE0P0o5@<0@1P504<J1@126@H0?QX304LO100204@O100<04TR101;7`D0
CB4704dQ1`1@9PL0DB@8050Y201B9PL0EbP705XX1`1H:@L0GRT70P1R;P/09`1R;``0Gbd<05XX2@1M
:`P0GBh705L[1P1K9PP0FbX705XY1`1I:@D0FbT6060X201M:@/0HBh<068d2`1P<0T0HR/905h/201P
:`T0GbP705dZ201N:`H0FBT705TZ201F90H0ER@405`T1P1D:@P0FBL505PR1@1>7`H0CQ`404HI1011
6@80@QT303/I0@0m60<0A1D204DI0@0204@G0@0W04/F0@196P<0A1X304TJ101870<0BA/3044M0`15
5P<0AaX104HG0@155@<0@1T4044I1`1480P0CRT>05L]3P1G;0d0EBL:05LV301B9PX0D2D904/Q201?
7`H0BQX604HK1P166PL0AQh904TQ2P1>9Pd0CbP=04lY301B:`d0Ec0?05Da3`1B=Q00DS8@04h^3@1<
;P/0D2l>0080D3<?02L0CcLB04lf4P1A=a00DCL@05<d401D=Ph0ECP?060l4P1^BQL0M5LQ07MT;01j
L3/0MWI006b1A01UR4l0G8UH05Z8F`1KReT0HHYD0669C`1RRD`0I8Q706Z6@`1`Qd40LhM007B1?01b
MC@0L6T[06iL8@1TDAh0FdHJ05Dk5@1:;0h0?1/7030C0`0]4@80:0`0024:000L20000P0N1P009`0J
1P007PH002@:0P0X4P80<1D303<H1@0j6`H0>1X803XH1`0h5PH0<1H302/?0`0R2`4080X00205000O
20008PT002<:000O2@4070T001`5000O20009@T002X>000d5`@0?B<904@/3013;0`0BRl>04dg4@1B
C1`0E5lX04mZ<`1CLS`0EGU005=n@P1CPd<0EGdm05Ma<P02055S:00H051J8`1?Dal0CDXI04U05P16
=a<0@S0@03XX3@0a6`P09@h301d8000I0`005@D000l60@0@1P003@<000`1000=0P003@<000X10008
00000`0000@100030@000P000P0100003@0200001@0000D0000800001`4000H100070@001`8000D2
0008000010000040000000000P0200000`0100000P0000400002000000@00@0000<0000000400001
00001`00000<0?ooo`002P3oool01`0[CDl0<4m:03IAB`0[?W`01`jb00<7_0000L400P000<802`00
0:80002A0001W0000Zl00@^g00@I[@0D>IL06D2K01Y2UP0IAXh064J500805T9n02L06Cj301`nRP0P
AXh07dNA01a6SP0MD8d08eF=02]NR`0]HXL0;6>402mYO`0hJWX0A6=b04]OK@19Ef`0BUY`04QUJ`0o
KVX0@6a^04A/I`1CLE@0EW=;05YhB`1TP440IgU006>0@P1WP400KWTk06ic>`1YLc`0I7E0061eA01S
M4D0HW=<065dCP1LLTd0Ffi<05Q[A`1IJTP00P1DLD/09`1CLTh0FG9C061`F`1PI5`0HeQP06=CI@1P
CfT0HEIO06=SCP1ULT/0JG9>06]bD01ROUl0G81T06b0C`1^Id00Gf5005aY@P1NLD00Gg=005Qc@01I
HSX0G3lM054Z3`1780/0A20904DU2P1780T0AR0;04HQ2`199P`0CBdB05<i6P1DA2<0Ddh`04iK@01=
ITP0D6iA05AdD`0205MfF`0P05maG01SME<0JWM906mb@01/I380HUL]069B:P1KE2`0GE@[061N=01L
KD00FW9;05E]EP1AK5d0D6iL051_G01<KE/0EVi>05icA`1YMT<0L7m207>0@@1`P4H0K81906f0B`1U
P5L0I81H05j2F@1ZQ580JXQB07Z0@`24P40208F0@080Oh1000<0OH1007eh?01jLS/00P1gI3H09`1b
F380KU4_06]<9P1aCAh0L4PL07=15`1Y>AD0HS<@05hd401P=A00GcD?068`3@1R<0`0Hbd>05HX2P1E
7`P0C1`504@G0@134`40A1D2040G10136`D0?a`4040H0P105`<0A1L204DD0`187P<0BR8404dS1`1;
8`P0Cb07050R201C8`L0Eb8605TU1P1H:0P0GBP605dW1@02060Y200B064[2P1L;@X0FRL705TR1P1G
8`@0FRL405lV1P1P;@L0FbT605PU1@1G9`D0F2P805h_2`1O<0T0IS@;068`2@1Q:`L0FBT70P1J:`/0
4`1K;@/0HBh9064/201L:PT0Fb/805X]2`1J:PT0ERP7054W1`1<90L0Bb4704dK1P1:60@0AQd504PN
1P197@80@1/3040L0`126@800P0o4`409`0l5@D0?aP503hF100o5080@AL303hE10105`@0@QD303hD
0P104@00?1D103dB0`0m40<0?QT404PM1@1?9@L0E2D705LX2`1I;@d0Ebh=05D`3P1D:PX0C20704XG
1P1260D0@aX504<K1P167`P0B1l804/T2019:0/0DBX=05@`3@1H;a00Ec@?05Lg4P1A<A00DC4?058c
3P0205<h4@0W054j4P1B>QD0Dc`F05Dn4`1H?a<0G44D05m1501R@180JT4D06i95`1bCQP0Me4L07aH
8`1jIC80MgI006j4A`1URTh0Gha@066;C01QRD/0HXM706R7A01`Q400Lh1007Ah>01cL380MF8Y06mC
7P1WAaP0HD8F05/g4P1@:@d0A1l703XF0`0d5@40;Q<102h?0@0Y30408@T000806`L000h06PH001/5
000N2@009P`102l?0P0c5080>1@503LG1`0k6@L0=aL603@E1@0^4P@09Pl3024<0@808@P001L080X0
01l90@0R2@407@P00247000R30009Pd002XA0P0c6@D0?B@7040W30129PX0>R<903hV2P13<100A3hF
04I;701;C1d0Ce0Q059K9`1>HR`0DEdW04e?7@0204U05`0A04@i5015>A80@S@?03TW2@0b80P0:aH5
02HB1@0P3`<07PT101T6000H1P005`H001D80@0D1`004PD00104000?0P000P0=0P000`0500001P00
00800002008000<00@0000`01@0000L0000500001`4000P1000:0P003@8000h3000;0P001`4000@0
000300030080000400<0000400000P000080008000000`0100000`010@000@0000000006000000`0
oooo000:0?ooo`0901i6H`0RC5L0<T]@03=4G`0K;hd041jT00<7_0010KD0003200@0003100L0006o
00HL/P0C9Z8063BE01PjT`0G@8T04c]j00804S9`02L05S1m01X`O`0K>hX06d:B01Y6S00OBHh08dN?
02=>U00PEY<07en@02IUR@0`JH40>V]i04AUM018EW@0BUA`04aQJ`19JVD0BV]V04U/H@1=K5P0D6MA
05m`A`1[Ld00KGI006Z0@01WP440J81306R0@P1ZP400IWQ206=gA01TNDD0IgI606Ud@@1WLD00I710
06A^@01SKD<00P1NLTT09`1HLd/0GG9D05i^G01RH600HUIV06IQGP1UGU`0IfUA06ab@`1ZLT80JW=:
06afD01ROed0HgmJ0720A@1]HcT0HUdk05mS@01NJT00GW9005Yc@01KIC/0FdDP05D_3`1=8@X0A1`7
04HO2@137@P0?AT703`I1P0j6PH0?Ah704l/3`1G=1D0EclQ05A>=P1=Ed00DF1:05MXBP0205Y]C00W
065bCP1TMd/0IWM706ad@01ZJcX0J60a06AG;@1MF300GE@/065D:P1PG3<0G6A005]WB@1FK540EVaE
05=^EP1DL4l0F6e6069`@P1^Ld00LgI007Ah@01]N480KX1506f0A`1RP5L0Fh1M06B1F01ZQU@0JH9E
07J0AP23P400Pglk07n0@01lPD80O81207j0@023P400O7@i0080NF4_02L0LUPZ06]?9`1[Ab00Kd8J
07E2601b@aT0JchG068i501N=A80Gc@@060`3@1N<Pl0IC<?06Hb3`1L;@/0F2<804dL10156`<0@aL3
048K0`186@@0Aa/504DG101550<0@1<203dE0`116@@0A1d604`Q2@1@9@X0D2@7050P201?8@P0CR46
05@R1P1A90L0EB<705@X0`1K90L00P1P:@T09`1P:`T0H2P905LT1P1E7@@0Da`305/Q1`1K90D0GB@6
05PU101D90@0D2H505DX2@1K;PX0HRX6068a201O:`T0FbX605/Z1@1I:@H0EB/905T/2P1T;0X0GC0<
05`]2@1L;P/0Fc0=05L/2P1B:`P0CbL804`U201:8`L0BQT504LK1@127PD0AQl6048M1@0n70@0>aP3
03PD0@0203TE0@0W03<D0P0g5`40?1D303hE0`0j5@40@aD203dF1@0n4`<0?AD203`C0@0k5@00?A<1
03lB0@155`80BAL404dJ1@1A7`H0DR@905/X301J<@h0Ec8>054Z2P1:7`L0Aa`704HK1P116PH0?aT5
040M1P137PL0AAh604HQ201;8PP0D2T805@^301D<`d0DS4B058`4@1=<@l0D38@0080D3L@02L0CSLC
050i5@1D?AH0ET0E05]55`1OAQL0HTPF06M54P1X@a40K4LD07A>5P1dC1D0MTTD079;5`1iF1l0LfL_
075e?@1ZPD00JhM006^8@@1ZQ440KGe006eg?@1_KC<0LUlZ06eF901/C1/0J3hB05`f3@1F<@/0D2/:
04lU1P136`@0>QH203<D0P0f5P80<A8202P@0@0V2`000P0O2P009`0I20006@L001h5000U1P40:0/1
02d>0@0^3`40;a8403HE1P0e5PD0=aP6038E1@0c5PD0;A4102P>0@0X2`0090`002L<0@0Q2`0080T0
0249000R2`009`l102`A0@0g6`@0>Ql603hU200m8`X0?B<903`Q200o:0X0?c<?040j4P10=a80A3DB
04Xo5P19AaX0BD8F048e400203`Y2`0E03HT2P0f80T0<1h902XI1P0T4P<06`/201X:000J2@005PH0
01@4000F1@0060L001T6000L2@005`D00143000>0@00304000`000080000100000<00P0000D00`00
00@000050000200000T1000200T0000800/0000@0P0040@00102000=0`002P8000D100030@020080
0006008100040@001@4000D1000400000`000P010000100300000@00008000010007000000`0oooo
000:0?ooo`0901hmL`0NBF40:DY=02m:C00ZD6<083b600PA]0010JH0003200<0003100P000320001
`0064[H05bFR01`cT00G;i@053N?010dNP803R]_01`04bQo01XVOP0L<HT06c^C01e2TP0S@i<09T6@
02A5UP0NCYD07UJD02=JT@0UHX/0;6f503U[O@11HgT0BUaa04eLL01;HF`0BfaS04Q`H@1<KUT0DVU?
069Z@01[L400KW8l06md?@1_Mc`0KH100P1XP4802@1XO400Ige306IlAP1WMT<0JW=006Ua@01VLT00
Ig9006Yd@00206Id@P0W065cA@1NLUH0GfaO069/H01UHUl0JVQH06e[E`1]LTP0Jg=0071c@01_MD80
KGm<06AoF01[MdX0Mg50071L;`1XG3H0He/i06AQ=`1SLD00GW90065R>P1MB1h0Ec8?04`T2@1670L0
AA`8044K1@115`H0@AT7044J1P106`L0C2D;05PW2`1F;Q00FcTH05Y0901IBc<0FThg0080FUY002L0
H650065/@01RM4D0I7E206Ea@01ZISL0JELY06=C:01PBbD0GdLP065<9@1MEbh0GF0l05Q]A@1ILDX0
FG9805m`A01UKD00JVU006i`@01^M400Kg5006Qd@@1^MT<0KH160660EP1OPU`0IXYG06F7E`1MPUl0
Jh1A0820@023OcX0Oh1007b0@01nP400Oh100820@01nLST00P1gHBd09`1dF2T0LU0U06a87`1[?AD0
KchE06i05`1Z?aL0ISdG06He4P1W;`l0JC4>06Tf4@1Z>180ICD?05l/3@1J9`P0DB4504XP101<7P@0
B1d204HL0`156`D0A1P2044C0P115P<0@1H404<F1@1:7@L0C20704XP2@1<8PL0B24504/M1@177@D0
CB@7054S1`1B8PD0Db8505LV2@0205/Z200W05lZ2P1L9`L0DR8504dM0`1?7080Ead305/O101D8`@0
EQl305DN0`1J8`D0FB<705dW201P9`H0GRT805hU201H9@H0FbX805/S1P1K8@T0EbH805TU2P1J:`X0
ERH605TX1@1J9`T0EbL704lX1`1@9@L0CB4604XL1P1;6`D0B1d604<M101470@0@1d303`F0`0j4`80
?QD40080>Q@302L0=aH203/I0@136@<0@A/3048H0P1160<0?1X203/H0`0n6@80?aH203dG0P105P40
A1D204/K0P1<6`@0Cb0405<Q1@1E90P0FRX:05T/3@1F:`d0DRL;04PP201:8@P0AR48040O2@156`H0
A1X604DG1P0o6PD0@1`4048L1`198@T0CBL;05</3P1B;`h0ARd>04P^3P15:`h00P17;Pl09`1:<0l0
BS8@04lg4@1D?QD0EdLF0618601SBQH0I48B06M34@1/AA@0L4PC0758501_A180Kd0A06i1401WAQ80
JT`J075K9@1^JB`0JFX`06QS;P1YGBT0IeLT06Y?7`1W@aT0Hd0E05Xe3`1F;0/0DB<804TV1P188`L0
AR07040K0P0h5`80=A<3038B0P0c4P80;A<102T>000202<:000W01d7000G1@007@@001d5000M1`00
7PH002<:000U3@40:a4202lB100_5`@0=QH503@G100d5P80=1@203HA0@0`4@00;`d002T=000P3@00
7`D001d9000S2@00:A4102hE0P0f6PD0>1d503/S1`0n90P0?bH903hW2P0m:P/0>bd;03TZ3@0k:@/0
@RX=04<`4010;`h0>B@:0080<Q/700l0;1H502PD1@0P40<07Pl301X=0`0H2P805`/101H7000E1@00
4PD00145000G1P006@P001X8000E1`000P0A0P001P0=0@00304000d100080@001`0000D000801P00
00h02P4000P200080@001`8000P100090@002`4000d3000?10003`<000h200090P001`4000H20080
104000<00`8000H200070@000P060@000`020@000@40004100020080000300<0000100000@000080
0@001000000<0?ooo`002P3oool0200R<gl084=[02A;E00YCTP0;EM=02]AKP0?7:/00@6h1@000<80
1`001;001`jh01XUX00O<id05BFR010`U`0=<h000P0>;7X09`0C:H/06RB501lXS@0M<9T06cfJ02A5
U`0VA8l09TND0298U00NBiL07E6F01aIT`0PHhh0:f^703A/O`10IGX0A5Mi04IKMP1:K6X0CFmT04i^
H@1DKeH0G6m;069cA@1[MD00Kg<k075c>P1bMD00KWU006ml@01/P400K7]006Ql@@1[OT40JG=006]b
@01XLT00IG5006]d@00206]c@00W06=cA@1RL5D0GfQO061]GP1WKEh0JW1C06maC`1_Ld@0K7A006ec
@01bLd40LGi906YkCP1aMT80MFTj06iE:01XEB/0J5D/06aI;`1UIc/0H6I006=F;@1I?QP0E30=050T
2`1570P0AQP7044J1`1570H0AB0704LR2@1:8@/0B20904/S2@1A:0X0DRT>05H^3`1I=AD0FcdK0080
Fd@X02L0GdT[065><P1XEcP0Jehg06UT>01/HC40KE/Z06]E9`1YC2<0J4HO06M98@1SD2L0GUXf05AS
@01EJT40FV]106AX?@1WISX0J60g06QW>P1XJD00I6Q006Aa@P1ZM4<0K81706>0EP1SQEL0IXQD06>7
F`1JPF00JH1B07b0@021McD0PWTi0860@024P400Oh1007b0@01lMS/00P1gJ2l09`1eF2H0KdhP06m8
701a@AD0KSdC06Xo5P1W@1X0Hd0G06Li501[>A80JCTC06`i501W>Q80J30>068]301J9@T0Cb06050P
201=80H0Ab0604DM1P176`<0AQX404PK10175`@0@aH304DG1@1<60@0CAX504XI1@1:6@@0AQ/404DI
10177PD0BQl604hQ1P1D90H0E2<705HU200205`U2P0W05d]2@1K9@T0Db<5054M0P1E7`40EA`205@P
0`1C7`<0ER0305LR1@1K9`@0I2L705lT1@1Q90D0Fb@505DU1`1F90P0FbP805PT1P1G7`D0EAl405DP
1@1E8@L0Cah504lN0`1A70H0EAh405LU1@1C8P@0BaX304HF0P196@80AQd603hK0`126P80?QL303/G
0`0j60D0>1L40080?1L402L0?QP303lL0P147P80@Q`403hL0@0m70@0@A`5048J10126`80@QX304@L
0`176@80C1P304`M101>7`@0DR@705DQ1`1D90P0F2H:05DW2@1D9`X0C2L:04hS2P1890T0BB0804PP
2@157`P0@Q/703lG1P0k5PD0>QT403`I1P0n6`T0AB8:04/Y3019:``0A2@;03lV2@109PT00P11:@/0
9`14:0X0@R/;04@_3P1?=a40DClE05Q55@1K@a@0FS`A05hl3`1T>`l0J3lA06]0501X@Q@0JT4@06<k
401M>0l0GcP<064l401UAAL0GDLJ05U15P1J>a<0FCTB05/i3P1G<Q00EC4<04hW2P188@L0@B0603dL
1@0m7`D0@A`4040L100g60<0=1D302hD0`0[5@80:a4102<>000201l:000W01/7000I10005`<001D2
000D10005`4001d4000P2@009A0102T?0P0`50<0=AH503LH0`0f6080>QX303TG100g5`40<aL102d@
0@0R3P007PL001X6000L2@008``002/@0@0Z4@@0<1H403HL1P0l80L0@2D9048W2P0l90T0>R8803<O
200a7@L0=Q`703TM200d7@P0<QT60080;aD400/0:A8402D@0`0Q2`807`/201`=0`0G2P8060P201P7
000D1@0060L001@8000201T8000J01L8000E1`004@L00144000?0`003@<000l3000<0P002P<000T3
000:0`002P@000T200080`002`<000/2000:0@002P8000T2000:0`003P<000h4000>0P003`<000/1
0009000300D1000900D000070@001@4000@1000300000P000040000000000@0000800P0000<00@00
0000000000001000000<0?ooo`002P3oool02P0U=W808Ca^02E5G00TCdh0:e9:02m@E`0>8ZP01@nf
0042`0000<430000`P070000`@082[T07RFN02@bVP0G8Z803bnO00dcV@0200h]T`0W01<ZT@0J8HD0
8R>:01dYR00K<YD08d:G02I4T00XAY409DN@01]7V@0GBYX06D^K01YAU`0RGhd0;FZ803Q[OP11IG00
@5Qa04AJN01;G6l0CVeT04ebG@1FOe<0GWi;06Me@01^Lc`0KG8l075b@01dMD00L7Q006ij@01]P400
K7e006ad@01XLD00JG9006Yb@01YLT00Kg500080KW5002L0JG5306A`D`1QJe`0IfaL06U^F01_KdX0
KW5906acA@1/MD<0KG=506mbBP1]N4X0KGM607Ab@01bFB`0K4lT06QE;@1]ERX0KU//06UR=01XFS<0
IT/Q05dh501A;@h0CR<904XP2@166`L0AQh704HO2@1480T0B24;04TP1`177`L0Ab0804PQ201990T0
D2@:05<X2`1D;0`00P1J;Q009`1L<180HC4C06Hh5`1WAQ`0K54S06iK;P1^HC80K60`06mE:@1ZCR@0
JdhS06IA:01TFS00FF<l05UY@01NJ400Hf<h06AI<P1UEbh0I5`a06=R>P1SICX0If/l06Ua?01^Md00
JH1906N5C`1VS5D0IhYG0626G@1[P540OH10081e<`1oLS00OG<c07j0>P1mP400O81007Mj@002079S
;P0W06mA801`Aa/0L4HH07545P1V>a80ISDA06<i501W?1D0JC<A06Pd4P1Z=@l0JCH?06Xf3`1X=0l0
Hbl>058S2`1<70H0B1T404@G0P165`80@QL2048H0`196`D0BQ`604TL1@186P<0AAL404<H0P125P80
A1P2048E0`145@<0AAT404DK1@176`H0DB4505PR1`1E90P0EBT90080G2X:02L0H38;05h_2`1N9`T0
Fb@505hV101G9@<0D2<205@Q101G90L0FRL905hW201P9`L0GR<505hU101I:@@0EbD405HR1@1C8`D0
E28505TP1@1F80H0E244054O1@1=7080CAH104XI0`1<7@80C1h304dK10185`40A1L304@K0P136P<0
?aL2044D0P0m5P<0>1P403PG0`0m6@D00P0m70@09`0o6@40@QT3048I0`146`80@1D103dL1P126PH0
A1X404<I0`157@@0B204050N1P1>70H0D1d404lN1@1B8@@0DQd604lO201=8@P0CB49058T201A8`X0
BbD:04PV2`199@/0AbD:04DS2P0n70P0?QX603TJ1P0h5PH0?1D603TL1`0m8PT0@2<9048R2@0l7@H0
?A/603XK1P0203`O1`0F03XP1P0g80X0?RD:04</3015<0l0CSH@050i4@1>=A00DC0>05Lb301K=Pd0
GCP>06<k4@1T?0l0HS/@05he301L<`T0Fc4905L`301C;0`0AbL;04DR2080BbD800l0B2P904PV2013
8PT0?a`803`J1@0f6P<0=a`303HJ0P0l5`@0=1D402hG0@0_4@80:18302H>0@0M20000P0M1`000`0N
20006@D001D100020100000R01<0000I1@007PT002<=0@0Z3`80<18303DC100d5@<0>AL103LG0`0e
5`<0=1<203<@000Y300090`00208000N1P007@P001d<0@0Q3`008`l202T@0P0_6@@0=1h403TP1P10
8PP0?B4703PM1P0c6PD0<QH303DF100c4P@0;a@402`F1080;1@300X0:Q0302P=0P0W3P<09Ph3028=
0P0L3@8060T101L6000E1@005PL00P0G1`006`0H1`005`L101@5000B1@0040@000d4000<0`003`<0
00l4000@0P003`<00102000@0`004@D00105000<1@003@@000`2000:0P002`<000X100090@002`<0
00d2000@0P004`4000h3000200d2000700H2000400000`0000@100060@000P000040000400000080
0@001P00000<0?ooo`002P3oool02P0Q>FH07c5d02I0H00TBU80:4]702eCGP0PB7d03RFS0085_@00
0L040000`P0600P9^@0P8id0:32G01POX00=;i<033Mo0P0><Gh09`0B;HP062J:020QSP0N7Y005B2N
01`mV@0OAY<08DJ901a1S`0HAiT04dFL01I2W00I@iH07e2A02QQS00bK800?FYh041HLP0oBgX0@Tai
04YYJP1?LEh0DgiG05^0CP1VMT80I7A006Ec@P1[Ld00MG9007Ec@01cLd00Lg90075b@01^L400Jfm0
06U`@01]LD00Jg=0075n@00206j0@00N06maA01UL5<0Hg1F06E`F`1YLU<0Kg98075cA@1]MD@0KX12
06YdB@1ZM4h0K81907>0@01aK3/0KE<T06U=8`1UDBd0JULZ06YM<01[HcD0JEX^065;8P1Q>aH0G2h>
058U2@1780L0@Qh704PR20127PP0@Q`80P157PH01`136`L0AR0704DO1`157PL0Aah704TP1P1980L0
0P1>7`L09`1>80L0Ebd;060`3@1R>Q@0JdLJ06eA8`1[Fbl0JElc075K;@1`FRX0K5`^06UG:`1YF2X0
IEhd05iR>`1SH3T0IEhd06=C:`1PDRP0HET]061P=@1UJ3L0JVhh06e`=`1]M3/0K81606j0B@1`R4d0
L8]>06N=E`1_QU80Nh1307ai>`1jJRd0N6<[07a];P1jNSd0N81007Ef@00207AQ;00W07=>801_A1T0
Jd8H06Y1601V>1@0IS@A06Dc4@1U=140Hc0>06<a301O<0h0IC8@06Pg4`1W>Q80H34=058O20155`80
@a<003dA00104@40>1<203`C0P115`D0AAT704DM1@1860@0@aT4048G0P0o5P80?AD1048G0P1260@0
B1P204XM101;80<0EBH605HU1`1D;0H0FR/:0080H2l<02L0H3H>06D`3P1S;``0HRd:05d/201G9PD0
ER0605LT1@1N:PL0HRX:06<]2P1S;PT0HB`605hW1`1K:@@0EB8305LQ0`1?8`<0DR8305XS1@1H9PH0
Eb@6058O1@1>7P@0B1T1048D0@146@80B1`504XM1P156P<0@AL204PF0`1:5`@0AAP3040C0P0l5P<0
=QL303/D0`1070<00P1270809`166`@0@a/504HL1P136@D0@1L0044I10126P<0AaP404PJ101:7`P0
CQh8058Q201C8PH0E207050O1`1970D0AA`304/I101;7@@0BQ/404`N1P188@L0A2@;04LX3P1::``0
CBT>04XX30128`X0?Qd903TJ1P0b5`D0=AL503LH1@0j6PL0>QP603XJ1@0f60@0=AH503@E1P0203<C
0`0W034F100a5`D0<QX603HM200f80T0?BP;040/3@16;`h0C2`<04h]3@1@;@/0FS<;05lj3P1O=`h0
GcX?05le3@1K<P/0Dc4905<]2P1>8PP0AR8604HN1P117PL0@1l6048Q1P108@L0?Ah603`L1P0k7`H0
>aP303HH0P0h6@80=QP303@C0`0a4`80;1<202H@0P0P2`407PD000807PL002L07`P001/5000C1@00
40800141000D10005`H002090@0T30809`h102P>0P0`4@<0<a82038C0@0`4P00<A0002h=000]2`00
:`/002L:000V2@008PP001d8000Q3@4080d101l>0@0S3P40:a82030E0@0d6P<0>1/603PL1P0e70@0
=1/4034G0P0^5@<0:@l202T>0P0[4PD00P0^50@03P0]50<0:a0102d?0P0Y4P<09a<402<?0P0N2@40
6PD001H6000D20005@H001H6000C1P004@D10P0?10001@0=1000408000l1000;0@003@4000803080
01003P8000h5000A1P404@L10147000=0`003@@000h2000<0@002`8000/1000:0`002`<000X5000=
1@0040D00P0<1P001`080`00104000<0000300000P0000@000020000100000000`01000000000040
0005000000`0oooo000:0?ooo`0<024mC`0M=Ud08caA02@oCP0Y@4L0<Tm502aGF`0H=Xh010^f0045
^P000KT000330P000<801P092KP08b>K02`]N`0N8Vh052Ug01<fM@804C9j02L04Bb201DVR@0M7i80
7QRJ018GY00L<I4063FH01U0TP0C>h`054JE01E1S@0G>Y<073VH01m1T@0REI<0:FZ603E_OP10HG<0
@UA^04A@J@11EG<0BFaY059hF@1KOE40I7e206Id@01WM400JW90075`>`1eLS`0M74k07Aa?01cLd00
Kg9006]a@01]L480Jg5006Yb@01^MT400P1]Nd409`1/NdL0J75?06IcD`1ZLU@0KgA=079dB01dM4<0
LGQ4071o@`1]OdD0KG9606md@01eKd00L5X[06Q=7`1UC2<0Ie<]06QG:P1ZGRh0IV4b06EK;@1RCbH0
H48L05/f401C:0X0BAl804@P201:8PP0AQh604DK1`166@H0@aX504@K1`1980D0CR8804lS201?8`T0
Cb0704TP100204/Q1@0W04lR1@1H9PL0ERT805X/301N<@d0I3/B06E26`1/CbL0LETZ06mK:`1aHc40
LF0]06iJ:P1YG340Geli069L=@1TG340HUDY05mC:01PGbd0If<b06]V<`1`KCD0L6`e075a>01bMT00
M81007J0@@1jPTD0LX]<0726C@1iPD@0MgXk07QY;P1fGBH0NV8Z07U/<P1hM3/0NV`d0080Mf<Y02L0
MUHQ06e;7@1Z@QT0Jd0H06Hk501U=A40ICD>06@b3`1S<0`0Hbh>06<d401Z=a40J3XC06@e4@1G9`/0
BA`404@D0@0o4P00>`l003d>000n4@40?aH1040H0@126@<0@ad304@I10146P@0@AT4040E0P0n5@80
?AL204LG10186`@0CQd2050Q1P1D9@H0E2L705@Y1`1I:@P00P1K;P/09`1L<@/0Gc8<05db3@1O<`d0
GR`;05XS1@1G8`D0G2P606<_2@1Y<PX0I38<06@]2`1R:@L0GBP605`V1`1K9@D0F2@405TQ101P8`@0
Gb@705/W1`1H8@D0EB4504lO0`1<5@<0B1P304`I0P1>80@0Cb4504dK1@176`@0B1H304DF101670<0
?AX203`H0P0j5@40@1H203hJ0`0204@P100@04LO1@157`D0AQh604PK10126PH0@1T3048H10126PH0
B1h804lV2`1?9PX0EBL;05DW201D9@X0C1h804LN2080Aal501D0C1d504XL10127`H0?1P7040L1`12
8`T0BBX;04/[3@1=;@l0AbL;044U2@0i7@H0>1L503@F1P0c5@D0=1P503@E1P0c5@H0<Q@603DD1P0`
5P@00P0c5@809`0^4`<0;A8402DB100/50@0;1D5038K1P0j8`T0?RT=04D/3@17;0/0C2d;058_2`1E
=@l0Ec<=05`a2P1L<@d0GC4;05L[201B;0T0D2@904hT2@178PL0@bH9048O200n6`@0>aT403`N1@0k
7`H0>b0603/M0`0g6@<0=1H2034F0P0`5@80;1@302TD0P0U3@4080T0020800020247000>02@8000Q
1@4070H101H60@0E1P005@@001h8000T2`00:10202H@0P0V4@40;10102L@000V3@0202L=000G02@?
000U3P409@X002D;000S2P0080T002<8000S3@4090`001h:000O2@009@`102LB000/3`00<1@2030G
0`0c6@<0=AL5034F0`0Y4P809``202D?0`0[3`@00P0_50809`0_4`40:Q<102/A0P0]5P@0;QD302HA
0`0S30005`P001@8000F1`005@P001P5000E1@005@H000l5000A1@004PH10143000=0`002P8000/0
000:00001P0000T2000@0`004`H101<70@0A10003`@000l3000A0P004@<000d4000=0`002P<000/4
000:100030D00105000200`4000300X200040@000P0000@00@003000000<0?ooo`002P3oool0500U
?3P073U5028j@P0T>dP0;3a30398@P0eDU408cek00dPUP087HP000:Y0000V@000J8000>c00T<]`0R
7I`0;RUo02DWP@0F89X04S6G0P0?<h402@0>;7/052^;01TQT`0L5i406aZG020YS@0A9X/05Cim014k
N`0201E0SP0L01PeT00M<IP08SJB02A7V00UGXd0;F^803YZN00oIf@0>em_03]4O`10IG80DWMO069n
C`1XODL0Jh1006]g@01^M3`0L78i079`>01cL3P0MG0h079c@01`MD00KG9006]b@P1]LT00JW9206Yk
A@80Jh1702L0JW=;06QcC`1WLe40L79>07=lB@1bMdH0KgE1071i@01_ND<0J7A:06]bA01`LT00LF8c
06e=801XBR00IddS06Q@:@1XE2/0IULZ06MG:`1SDbP0HdlU06537P1L=A40E2X<04XR20177`P0BB88
04XR2@1;7PL0Ab4704TM1`1880P0Cal8050R2P1F8``0EbL;05HW2P1C8@T00P1A80L08P1C7`P0Cah6
050Q201A80T0F2D805/X2@1L=140I40I06I77P1/Cb80LUHX07EM:`1dHC00Lf<d06]S>@1VFc<0J5P[
06U@8P1XDR<0JUhZ06UP;01ZI300K6Tc06e[<@1bKS@0LG@k07=f?@1fMT00NH1007F6B@1_RDd0N896
07Ui>`1iK2d207QM:00307EL:01cGBP0MV0X0080NE`S02L0MULR07IE8P1bBQh0JDLI06Xm501V>A80
HcHA06Dh401S<@d0HS4=06@b4@1X>a@0J3PA05d/3@1A7`L0@QT303hE0P0i4`40?a8004@E00185P00
AQ/104HL0`177@@0AAh3048J0P106080AAH403XD0P0o5`40@1P204@L0`1;70@0CAl204`M1@1@9@H0
CbP505<W1P1D90H00P1F9PP09`1M:PX0Fb/;05/]2P1N:``0G2P;05/V2@1J:@L0GRd906D/2@1Y;`T0
IBd9064`1`1L:PP0FB@505dX1P1H9`H0G2L405XV1`1M90H0FbD605/T1P1G9`@0Db@705<P1@1@6@@0
CAP104dM101E8@@0DbD504lP1@1;7@@0AaX304<H10137@<0@A`203dL0`1360<0@QP403dE0P0203lI
0`80?QX402D0?QP404@M1P187@@0AQ`504TK1P1:70L0BB8804hW2P1B:0/0E2`;05P^3@1B:`h0BRL<
04TX3P1>9P/0Bb4704hN1@176P@0?AD403`D0`0n6@D0?al704HS2P1<9P/0CRT<04TY2P168`P0?b48
03`I200g6@H0=AX603PJ1P0h60D0=a@603HE1P0g60L0=AP70080<1H502L0<QH302/A0P0W3P80:A43
02`B0`0d5PD0=ah903dW300o:`X0?bX:04D]301;;P`0C2h<04l/301@:`T0ERX:05@X2@1>:0H0C2L8
04TX201<90L0B2D604PU2@148PH0?Qh503/F0`0i5P<0>1T203LJ1@0i6@<0<aL303<B0P0Z4@40:@l1
02@<000U2P407`T001X:000N2P000P0R30009`0Y3000:0d102<<0@0M2@405PP101P7000M1P008``1
02D@0@0Y3`80:0`002/=000W2P008PT0028;000R40009`l002@B0P0W3`4090h102<=0@0O3@007`T1
01l<0@0N2`006@T001X:0@0S3@409`d102X?000/4@40;1@1034E0`0c60<0<1L302`B0P0Y3@80:Pd3
02P@0P0202XC0`0O02/B0@0/40<0;1<202XB0P0Z4@809A0201h<0@0G2`005PT001P7000G1`005@L0
01D5000D1P004PL001D40@0E1P004`H100h60@0;0`001P4000L0000600001`0000X2000>0P003@@0
00d3000;0@002`8000h20002010500050144000?10002P@000L300070P000`090P000`030P000`00
0040000@000000`0oooo000:0?ooo`0D02Th:00U>S@08c`h02Dk?`0[?D<0<T9503]=BP0]@VT05c5g
0001_@0448P00@=e0002R0001jH020ne02DJU`0/8Y80:bf:01`RV@0D;Y`2014bS00W00haS00B<9<0
5B>D01/LW@0T78d09ReN01HVH`0H<W`063^001<hT00B?YH063:A01`]VP0T;Y809cZF02I=U@0WHXh0
<6b303UcKP0hIVD0?5E`045EM`19Eg00Gg5I06f0B@1aP4@0KX1306in@01_MD00Lg@j07Ia>@1dLC`0
L7A0071e@01[P440JX1006ib@01[NT<0J7Y80080JH1802L0Jh1;06UkCP1XP4d0M81707Ec@P1cLd<0
MX100720@@1]P480KG=1071b@01cK3`0LU/Y075;801ZC280ITdV06=@9P1SERX0HUT^069B:@1QC2<0
HDLP05hj6P1I;@d0DB<;04`U2`1:8PX0BRH8050W2P1=8PP0CR8804dS2@1<7`L0Cb0804lR2`1@9@X0
F2P<05LX301A90X00P1>8`T09`1A8`T0CbD704lO201>80<0Dah705<Q2@1E:@/0Fc8@06Hg4`1[@aX0
LDhM07IG9P1gI380LV@c06mR=`1WGS@0JUd]06eB901^EB80JUd[06]R;01YIc80JFXc06eY<@1^L3D0
LGHm06m_>01`MCX0Lh100726B@1^RTl0M8=907En@01iJBd0MeTT079D801dDR00Le@Q07=G8@0207AE
8@0W07MD8P1hEB<0M4lL06i76P1/@1D0I3LB06<f4P1S=100HS8>060`3`1R=140I3TB05dc3P1H9PX0
BQh4048H0P0m4080?A40044F00136@40BAd104`N0`1:7`<0BQd304XK0P126@00A1P204DA0P105040
@AL0044I0P1970<0BR4404dP0`1A7P@0D28605LO1@1C8@H0DAd20080DR0502L0Db0505<T1@1D:0L0
F2/:05dZ2`1M:`X0Fc8:05d^201N:0P0HBX9060Z2P1L:`X0EBH605HV101F:@D0G2/305h]1@1P;PP0
GB/705XY1`1M9PL0FR<705TY2P1H9`L0Db4304lO0`1A8P80Eb85054V101?8`<0C1h304/N0`187`D0
AR<504TQ1P1970D0B1/404@G0`0o60<00P0i5@409`0j5080=aD203XF0P146P<0CA`304TO101:80@0
AQd504/N1@188PL0D2H8058W2@1?:`d0BbP=04/Y2`1>:P`0CBT;04/U2P1780T0A1/603dG1@0j5PD0
>a<503PH1@106`H0@B4704<R2P158`/0@2@903lN1`0o7@T0?B8903/P1`0l7PL0>QT603<H1`0e60L0
=aP803DG1`0203<F1@0W02lE100^5@80:a8202X>0`0`4@80<AH303LK1`0l9@X0@2X:044^3P15<@d0
@b/<044W201090P0@R@704XV20169PL0AR@604TW1P179PH0ARH704/V2019:0P0AB<903`O1@0d4`80
:Q0102`?0@0/4@40;10002P@0@0U3P409``001l9000P1`007@@00207000L2@006``000808`d002L0
9@d002D>000V2@4080P001/60@0G100070@102480@0V30409`d002P=000T2`808@P001d8000M1@00
7@T002H=0@0Q40408``202<;0@0O2P407PP101l90@0N204070X101T:0@0J2@4080h202DA0`0U4080
:Q0102TC0P0]50<0<1X4030K1P0/5PD0:18202<?0@0U3P<00P0W4@809`0W4P809Pl102H@000U3`40
8@h1024=0P0K304060`101D8000F1`005@L001D3000?10003`D00104000A1@004P@001D6000A1P00
3@<000L1000600000P000040000500002P0000T000090@002P4000/1000<0@003P<00143000@1000
3@<100X2000500001P4000H0000300<000030080000100000@0000l00000303oool000X0oooo01@0
;3PR02/k9`0V?2h09cde02/l>`0e?S`0>d]402i5H@0M?6T00@:j00/MN@0327l000600008U0074jh0
81RJ02LLT`0[:8D08bJ@01dcS`805C>002L043>200lbT00B99H06A^Q02<GT`0]9fd07B2101@PY@0J
>ID04S:J014nW00F<9D06bVL02DUTP0];IH0:3jH02=DU@0VI8`0;Vim03MULP0oEWd0@cn004XgNP1G
GFT0I81C06^0C01ZNTP0KGa206ag@`1^Nd80LH10071b@01_MD00KGQ006ij@@1YNTD0IgQ906J0BP1V
P4/00P1YMTT02@1XO4/0JGI<06R0CP1cP4L0MGm207F0@P1fNd00LX10071d@002079b@00L07=Z=`1`
FRP0K4lQ06A<8P1SBb80HU0T06MD:01RERh0HE0[06978P1P@Ql0GC@C05DX301;8`P0Bb<:04hS2@1A
8`X0E2P:05DY2`1D9PX0DRD8050U1`1?8@P0Cb<:050X2P1A:@/0DbT;054V2P80CbD802L0D2<:04dS
2@1;8PL0BB4504dP1P1>8@H0Cb0705@[2`1O<Pl0JShF06m55`1iCb80Mf8`07MV=P1cJ3X0JFDi06MQ
<`1YFbT0KULW06eH9`1XFBT0JF8_06QY<@1[Jc40K7Pk06el@01^KcH0Kg4d06j0@01_QdP0Kha<0766
B@1fP3l0MEdV079<7@1_B1d0KT@J075=7P1cD1h00P1`C1d09`1bC1h0MD`M07166P1[@aH0I3HB060b
3P1R;Pl0Ic0@06Dc4@1Q<A00Fbh?05/a301M:``0Fb@:058O101<6080AAD204@F0P186P80Aa/204TN
0`1680<0A1h404PI0`176@<0@aP304<G10146@<0@aX304LI0P1=7`@0CR84058Q1P1>8@@0DB87050R
1`1?8P@0C1l304dO1P0204`O1@0W04hK0`1A7PD0ER@605DW201K:PP0FBX905h^301L:`T0FbL805PU
1`1I:0P0FRh905TY1P1I9`H0H2H505dW101R:`H0HBl705hZ1P1K:@P0GBX605d[1`1P:PL0G2T905HX
1P1C9P@0DBH305LR1@1E80D0DB8704dU1`1>8PH0CB<504/T1P1880L0A1h4048I0P106`80@1D20080
>QP30P0j40009@0o7080Aad204XN0`1@7@<0BQ`404/N1@1=6P@0Aa`604TO1`1:9@T0AbH904HX2P18
:0`0CBT=04h[301<:Pd0Ab<;03lO2@0o6`P0>AP703<G1P0c50D0=A<603XG1`0n6PL0?Q/:03LK1`0m
70P0@1h:03`O2P0l8@X0>Ad9038G1`0]4`H0:a@602lG1P0^5PH00P0`5`D09`0`5P@0;1H502TD1@0/
50<0<AL303HH0`0h6PD0@288044X2`18;@`0Abl=04HY30109PT0@B4:040Q1`109@L0?b<703hU1@13
9PD0A2L404LQ1@188PL0AbL804@M1P0h6@D0:a4302D;000Q20007`/101l:000O3@0070`101d9000M
1@0080L002<<000T3@008`X002@;0002028:000W02H:000S2`008PD001l8000G20005PD001H2000L
100080P0020<000R30008`/001h5000H0P00604001X6000K2@0070T101h8000M2@006PX001`9000O
2P0080L001`:000M20406`P101l:0`0U2`<09`h302H?0@0X4P40:Q<2030H100^6PD0:aH602XE0`0W
3P008@L0008080/001408P`1024?000S3`808@h1024=0@0O2P407@`101X:0P0G20404PX101@:000A
1@003P@000/3000>10004@D000l600020148000700`4000:0@001@0000@0000200001@0000L00002
00P000802P0000L02@0000/4000?0`003`@000l200090@001@0000@00P0000D00`00008000030000
0P400080000>000000`0oooo000:0?ooo`0D02`h800Z=1h0:CPT02/i:@0[>C40<chb03M9?`0]B5P0
1Q^[0042_@084Xd00`R10045QP003YL06R2C01dOV00S6i<0:bF@02l[T00]>g@202E2C`0W01HdG@0@
;X@04BJG01LLXP0Q4IX0;AZ102<LQ@0J8j<07C2Q018[X00A>Yl04C2I01`]W00U9Y00:BRJ02XdW00S
AYX08ENB02YTQ@0eI7h0?UF304XmO01=>gL0C4Yh055IKP1IDfH0Ff=K061dC`1TP4T0JX1307=g@01b
LT00L790071h@01_P400IX1806EiB`1XP4`0JG];0080JWi;02L0JgAD06YhDP1/OTl0MH1707Qo@`1c
OD40MX1007N0@01iLT00Mfe007EY>@1eHBh0Le0Q06i97`1VBR00I4`R06A>9P1UCRL0I4lY06988P1R
?aX0H3TG05`_3`1A9`X0BRD:04lW301@90/0DRD;058X2P1E:0`0DRL=050U301D90T0DRH<058X3@1E
:Pd0EBL<054W2`1@90X00P1<90X09`1A8`X0Cb4804XM10188@H0BB4504LN1`1880D0Cb8705h[2P1T
<`d0K3HC07I77@1dGBh0MVDg07=V>@1]GBl0I5L/06ID9@1XCbD0JT`O06M<801UDRH0I5/[06QU<01/
M3`0JW]106eb=`1]Kc@0KgXl06n1@P1_Q4L0L8=707Am?@1eEb<0LD4I06i15`1/@aL0K4TK071:6P02
06]55`0W06Q3601]@AD0KchF06Pg4P1P;0`0GB`<05`a3`1U>180JS`D060b3P1O;P`0GBX:064Y2P1N
9`H0Eb44050P0P1=7@80C1T304dP0`1=7`80B20304TN0`176@80AaX204@I0`136@D0AAX504XO1P1=
7@L0Ba/605<P1`1@8PH0DB8704lP1`1A90P0DBL804lR1P1A7`P0EB070080DAh502L0CQh305DR0`1I
8`H0FbL705TZ201K:PT0Fbh;05h/2`1O9PT0FBD605DX1`1L;0H0FRd605XY1`1M:0H0FBT405h]1`1N
;PX0G2T905TY2P1H:@P0GRP905hX201F8PD0DB8404dS1P1<8@@0Bb0304hP0`1<80D0C24504dT0`1;
8`D0C2<404DM100o6@<0?aX203hI100n50<00P0n50807`0j5080@aH204@G10116P<0A1X304LM1015
6`80AAT404PI10186PD0C1h804/O1`1680X0Ab8;04LW2`1;:`d0C2d>04@Z3P17:Pd0ABD;03dO200m
70P0<aL6038D1@0^4PD0;A05030C1@0b60D0=1H603PM2@0g7@X00P0i7@P01P0g70P0<AD402dD100Y
4`@0:AD402dC1P80;QD402L0;aD402hE1@0]5`H0<aT603PH100j7@H0?A/403hM1`1190X0BBT<04XY
2P0m:@X0@2@:040U200m8`T0?BD:03dS1`0k80H0?R46044N1@0o8@D0?B05048T1P0l7`@0<AH202X?
0P0U2P007@P001X5000J2@0070T001`;000M2P0070d002<@000W4@40;a<102dC0P0Y40400P0S3@00
3`0V30408PX102480@0M1`006`L001T5000E1000504001L2000J1@0080P001l8000L1`005`L001H4
000201@4000F01L3000E1@006PD001`7000L1@007@P00208000P1`007@X001l:000N30408@l202<@
0P0U3`408`/102DA0@0Z5040:a@202XD0P0W4`<08Ph101h;0P807@T102H06`T101`:0P0Q3`@080l4
01d=0P0I2`406@`001L6000C1@004PH101480@0@1`403P@100/5000@1`4040H10146000B1@003PH0
00d3000:0@00204000D1000400001@0000H100070P001P4000L100060@002P0000`4000?10003`D0
00`200080@000`00000000@00@0000@000000080000200000@003P00000<0?ooo`002P3oool0500X
>280:S@M02dd700/=R80:cX_0310<`0eB3d04cV;00LPY`010L000PJa0042ZP002Jh022JV01LUU@0L
9IP07QZF02TQS`0_:Hd0<ce`0P0]A4d09`0E9e403bU_00l/R00D9YP071^K02DFS00V6Xh09bR?024/
U00C9ZD04cNP01<bU`0L<YL08RN@02LVV`0[;iX0:D>G02=>T`0VEh`0;FF203UTP015DW`0B4Yj0454
P00n>hD0ASel04eTJ@1HOU@0HX1906f0@`1eMD00N78k07Ib>`1eMT00MGM007=d@@1aND00LX12071h
@`0206mdAP0W06ihD`1_P540LGi<07InB01fP4<0MGe207R0@01kLT00MW9007]_@01iJ3<0M5HU071:
801ZB200IdLO06Q98@1XB240Id@M06A06P1Q>1H0GS<A05X_3`1I:0d0D2H;050X2P1?:@X0DBH:04dV
2`1?:0`0CbT=04l/2`1C:@X0ER/=05<W301C:`/0E2X=05@V2P1>9PT0DB@80080DAl500d0CAl704dP
1P1:7P@0Ba/404XN1@1;7P<0BQh5050O1@1E90H0Fbd<06@a3@1`@1H0MDhR0080M5X[01P0LD`Q06Q6
7`1TAQl0J4TO06Y66@1U@QT0ITXN06UA8`1ZGB`0K6hi06Qg@@1[KcT0Kfle06ef>P1`Nch0LX1207B1
@`1eO3`0MedU06i96`1ZA1T0JdLK06];701_AQ/206Xo5`0W06Hj5@1W=A<0I38@05d]3@1O:`X0HB`<
06Ld4P1X?1@0J3lD06@f4P1R<Ph0GB/:064W2@1M9PT0FBH505TQ101E8PD0EbL605DU1P1C9@H0D285
04hN0P187P@0Aad504PL1@196PD0Aad504hM1@1>7`@0CQl604hQ1P1D8@L0DB@:04dQ2@1=:0`0DB<:
04lV1P1C9PP0ERD90080Dah502L0EB0405TP0`1I80D0F28805@P1P1E90P0FB/905XX2@1L9`T0Fb88
05XX201N:`D0GbT705dZ201J:@T0F2T705PX1`1H:PX0FB@705DS1`1C90L0D28705<P1P1;7`@0Ab02
04DK0`107080AAT3044K0`176`@0A1d204HM0P187@<0A1`403lJ0`0m5`<0>aP403lD0`115@<00P0o
4`809`0i5@<0?AL104<E0P0m6080@1T204<H0`1270D0AA`604PJ1P167P@0CR4404LM1P157PP0B209
04XY2P1@;@d0BR`>04HV3@139P`0ABH904@S2P1380T0?QT803@F1`0/40D0:a05030E100b5P<0=AD3
03DD100e6PH0>1`603<H1`0d5PP0;QH702dF100/50@0;1@502`G1`0202hG1P0W030J1P0_5`D0<A/7
03<K200h80H0?1h703hP20118PL0AB<704LU2@1:9@L0BBD804DY2P15:P`0@2X;03lX300i8PT0=Qh6
03LP100j60<0>Q`503TK100m7@@0=aT403<E0P0/4@409``0028:0@0M20406`T1020=0@0U3`008a40
02@A000Z4`00<1H203<I100a60<0<1H100809@l100`090/201l9000O20007@L001h8000K1`006`H0
0142000F0`005`<001`70@0O200201d8000801T7000J100050H00182000B100040@001@4000H1002
01P7000?01T7000M20407@X101l9000N2P0080X0024<000N2@007PP0020>000S40009@h002@>000O
30007@L0008060X101d060H001T90@0I3@<070`401T;0P0I2@405`P101@8000?10004@@001060@0>
1@402`@100/4000>1000308000/2000<0`003`D000h400080`00208000H0000500000`0000D00006
00001@0000P0000200X0000800/3000>1P003@D000d300090P001`0000<000020002000000040040
000000000@00004000l00000303oool000X0oooo01@0:Sd_02Xl:00/?BD0:d0[02U2>P0/AS`09TQV
01DjP00<9hH021:700@:X`000;`000bo00H/Z@0C:IL06RJJ01`HW00Z88h0<BN6034dM08093A[02L0
41an018ZQ@0B<Hh04RbE01HRW00N5I809aNH02lXQ`0Q;8`04RFU01PhT00G=XT07CB?024XT00W9I`0
;bfG02dmT`0UBI808U6A02QQQP0dJH40@fQi04a^L@19Jg00AV1c04EHM01?KV@0F7EE0620CP1YP4H0
KH1107Ed@01gLd00N7m007Eo@01eNT00Lh1007=l@01bOD400P1bP4409`1`P4H0M81807AnA`1fMDD0
M7a107J0@01jP400Ng=007Ub@01jLD00NVHa07IH9@1_D280J4`R06M;8@1UBR40HT8K064h5@1M<A00
FRl?05P[301F:``0CbL;04dT2`1;9@/0C2@:04`T2@1:8`P0C24904`V201@8@T0CbD6058T2@1@9@T0
Cb<804/T201<90L0B28704lM1`0204lN100W04TQ101<80@0Bb0604lK101=7`@0DB0304lM1P1@6`@0
DAl405@S1`1K:0`0I3@@07556`1bCR00LE@U06e97P1Z@aX0Id@K06A3701W?QH0IC`E06A36`1ZBR00
IU@Y06]T<P1ZJcX0KfPd06i^=01_MCX0LWTi07J0?01gP400N7`k07aS;01fDR00Kd`K071:701^C1l0
Kd`K0080KTDG02L0IcXD06<c3`1R;``0HS@@06@e3`1W=100JSDC06/j401Y>Q40I3<?064_301N:`L0
GbH705hY201K9`P0FBH705HV201@9`P0E2D805@T1@1@90<0Cal504dP1P1>8PH0Cb<5054Q1@1D8PD0
D2<605@R1`1C8PH0DRD5054V2@1A8`P0Cb@9058T2P1B90P0Db8805PX201H9`T00P1I80D09`1C7@80
Db42054U0P1>90H0CB46054R1P1@8`D0Db4505HT1P1E8PH0Eb4505/U0`1K9PH0FBL605XW2@1G9@L0
EB4605<R1`1C7@<0DQ/1050L0P1@6P<0CQX204/G0`156`80@A/1048I000n6@40?aP1048F000o5P00
@AH1048G0@0l5@80?QL103dG0P0m6@80>QL303dF0`0203`C0`0W03dC0P0o4`40?QD103TF0@0m5P80
@1H4044I1P126`L0Aa`504LP1`1770L0?aT3040H0`117`H0Ab<804dX2@1;9PT0AB<;04@T2P138`T0
AbD804DR2P0n70L0>1H5038E1P0b4`H0<AH502lE100/4`<0<1@4038E100c60@0;1L502dG1P0/5@D0
<1T5038F1@0^60H0;aL70080<1/702L0<A/7034L200f7PL0>28903/U2P0o9@P0A2L;04LY3019:PX0
BbH904lY201<9`P0ABL804T/2`13;0/0@BT:03`R2@0g7PD0<a/3034I0P0c6@@0<QD503@G0`0f50@0
<QD3038B0P0`4`80;A0102P>0@0V3P809A0202TA0@0X3`409a4102PA000Z5040;QD2038F0P0]5000
0P0W3P409`0Q2P407@H001d7000O1`406PP101T70@0L1P006@H001/2000G0`006PD001X8000N2P80
70`101/:0@0K1`8060D00184000<0`003P<00140000@00004P4001H1000K10006`D001l9000K2@00
6`P001X8000K2`006PT001/9000L20006`P001X:000L2@007@T001h9000201X90@0H01L90@0G2040
50P001H8000E204050P101/90P0J1`405@@001@2000B0P403P<100X200090P002@4000L0000:0000
2`800143000<0P00204000D000040@000P400P030002008000801@0000T01`0000X3000;10003@<0
00h3000;1@0030@000T4000600000`02000B000000`0oooo000:0?ooo`0D02Y2@P0]AcP0;4/b02a=
>@0YCD80;Da202U4JP0H=g@05CEO01DcD`096Gd00@6`000UZ@06;j<04RVC01PVU`0I5Yd0:1n=02lV
M@0V8GP201hUT00W01LOXP0B;J404SNJ00h/V`0B9Yl071JC02HFV@0]9HP0931m01TXOP0S@6P084A_
01heP`0Q9hd09b>I03<^U@0b?HH09T69021;T`0TF8`0;V:603i]N@1<MFh0CgmX04MgJP13LFd0AgAY
059eG@1QOU00JX170720@P1eMd00Ng@k07V0@01hND00NWQ007]l@01hO400Lga30080Lge002L0LX14
0760A01aOTD0M7a307Im@01jOd00NW=007]b@01iLT00NW=007MX<`1fH2/0L5TX06YC9`1ZBb80I44L
060f501K;@d0D2`;04hZ2P1C9`X0DBL;04`X2@1;90P0BR8704TV2@1;9@T0CB4:04/N2@1:7`T0BAd5
04TM0P1<7P@0BQ`504HJ1@186`<0@AT403lH0`146@D00P146P<09`157@80BB44054Q1P1A90D0DAl5
05HM1@1:7@D0C1d304LM0`1=7@H0Db08064/3P1[?1T0KdTL07=A8@1cCAh0JdDK06A37@1UA1`0IC/E
06<i501WAaT0JU0R06QE:01YIC80K6Xd06YW<`1/LcP0LGU0075h>@1fMcL0N7Xm07Mf>@1jI2/0M5@Q
06m;6`1aBA/0LTPJ07576P0207536@0W06`n5P1Y>Q<0JCTB070k501a?aH0KSdI06a15P1W>a00JCP>
06<d3P1R;`X0GbL605hT1@1O:@L0GR`805/W2@1H:0P0CB8604lQ1P1D80D0EB84058R101>8@D0DB<5
05@S1@1F9@H0G2L805TZ2@1J:0X0EBL:04lX1`1@9`P0CR@7050T1`1C9PL0DB@705LY2@1L9`/0FBH8
0080FBD602L0Eb8605HT1@1G9PH0EbT505<S1`1=9PL0Cal604lL101@70@0DA`405<M0`1A8`40EbD5
05PR101F7`@0Cb<204lP1@1C7`H0CA/204TK0P105`40AQL1048E0`134P00@a@1044I00125P00@AL0
040I0@0m5@00?14003X=0@0h3`40>`d003XA0@154P40@QP303/F0P0i4P400P0g4`009`0m5`<0>a/4
03/H0P0n5`80?1D203dH0P0m50@0?aH303lK10116@H0A1H5048F0`146080@aX304@L101380D0Aal7
04/O2@127`L0AQd704LQ1`168`T0A1`803TJ200d5@L0=1T703<K1@0_5PD0;A8402lC0`0^50@0;Q@5
02TE100X5@D0:a/502dK1P0Y60H0:AT702/G1`0202hI1P0W02hL1`0_7@P0<b8903PU2`0n9P/0@RP<
04P[301<;P`0CRh<04XZ3@1<:@/0CB`<04/]2`1<<0`0BBh;04DY2`0o9`T0>Qh603DI100/6PD0<AL6
02hE100/4`<0;A8203LF0P0c5040=aP103HG0P0`5@@0;QH502dF100Y5@<09Q42028@0@0T4@408`h1
02DA0P0V5@809Q<1008090d100<07`T001P4000G0`000P0G10403`0K1P406`P001`7000L1`006@@0
01`5000K204070X201`<0@0I2@006@P001T5000D10004@<000h4000300`1000901<0000H0P0070<0
01d4000M1P0070L001/7000H1`406PT100805`L000D05@L001H6000G1P005`T001T:000201X;000>
01P:000E1P004@D000l5000>1`403`H101<70@0D1`405@L001@4000D0P0040<000`2000<000200H0
000;00H2000<0`003@8000T100050P000P0000<0000400000`8000<0000200000P030@002P040000
104000H200080`002P8000T4000:1@002`D000X400090P0200D00003004000000000000001000000
303oool000X0oooo01@0:D9A02a@@`0[ESl0;eM202iF@P0kDDP0:ci_01XeKP0H?e/064=J00`NEP02
2hD00R:K00TdS00B:WX05BF901LGVP0T7hl0:B6801XDWP807bFE01l082VE01T^W@0H<i`042bP00l[
X00J6I<09QN<02/NK`0T:6X09C5S02XnE@0ZAE@07SY_01dVS00X89D0=bZB03<hRP0W=HP08Cj?02E=
S`0YE8T0=6:303mXO@13LGD0BX1[04Z1I01?O640FgYE06anA`1`P4@0MGm00080NW]000H0NgQ007b0
@01lOD00OGa007Ym@01fOD<207F0A@0W075nB01_OTH0L7i4075mA01gOd00O7i007Ya@01jLd00NGA0
07Uc@01iKCL0MV@^06iM;@1VERd0ID@N05ld401H9`/0CbL804lV2@1@9PT0CRH:04`W2P1<9`T0BRD:
04DT2P1:80T0BB<904`R2P198@P0BA/604PK0`1660@0A1T404<H10165`<0@1T3040I100n60<0@aL4
0080?aH302L0@1X304LM1`1<80H0E2D705HT1P1E8PL0D20604lO10197P<0CA/205@N201J9P/0J3DD
06m35P1cBah0Me0Q071;6`1[BQl0IDXQ06A16P1R@1L0J4TL06YF9P1ZGB`0JVXf06e_=P1[L3T0K7U0
06j0@01`NCh0Lg<h07Ma<`1gJbl0M5`T07AF8P1bCad0LT@H07E56P1aB1/00P1bB1P09`1`AQT0KTDG
078o4`1c@AH0LDDH07566P1/B1/0K44B06Df3P1S;`X0HB/605lZ1@1J:@H0FBX705XX1`1F9@L0D2@6
04hR1P1?7`H0DR<405DU101B9PH0DR@7050Q1@1H8`D0FB/605d/2`1N;PX0FbX805LY2@1@9PL0C2@6
04lS1`1B90P0CR46054S1`1I90P0FRP905L[1P0205HY2@0305DY1`1F:@L0EbL70080Eb/80280FBH6
05<U1P1A80@0Cad304TM0`1;7P80Cal205LP0P1H8@40CR0404dP101?8P<0Bb0504dJ0P156@80?QD1
03lA0@0i4P40?Q@1048G00115`40AQP104LL0@106@80@A<003L?000h3P40=0l103D?000k4`00@QL1
04DG0`0l5@80=a@30P0i5`809`0m5P<0?al503lK100m60@0?1@203`C0`0j4`<0@1<303lD0P0o5`<0
@aX3048G0P105P40?Qh303lL100m70<0@ad304TL1P167PD0AAd604DR1`198@T0AR4903lU2@0m7@T0
>Qd903DM1P0c5`@0;a@502LA0`0X4@<0:10402<C1@0W5@H0:aX702hI1P0[60L09AT702HD1P0202PC
1P0W02/H1P0/6PL0<1l:03HT2`0g9`X0?BP:048[3@17:P`0BRX?04LZ3P18:0/0Bbl<04`a3@1?=0l0
Cc8=04L`30169@/0?Ah603<I0`0]50@0;1D502XA0`0[4@40;181034G0`0c5@<0=AX103LI0`0e6`D0
<aT502lF100Z4@809@/0024;000N20006@H001X8000Q3P408@d200808@`102H06PP00182000B0000
30800145000F1`006@H001X6000K1P006PH001D7000G1@006@H101L7000H1P006P@001T5000@1P00
3P<00102000?0P002`4000L100070`003`800102000F0`006@L001X5000F1P406PH001L8000G2P00
60P001L8000G1`005@@001T90@<07@/101005`X101<5000@10003P4000d2000<0P0040@001<6000E
1@405P@001<2000>0`002`0000L0000500001`400P090P000`070@001P0000@000020080000>00@1
00050@00108000<100040@001@0000D1000600001@4000T100070@001P4000P200090P0200P20080
108000<010400040000100004000000<0?ooo`002P3oool0500]CdL0;eM502MJB00]FTD0=eU003mD
B@0Z>gL05Rak010^LP0>:gh01@aJ00DCG`068gh04CIc01L`I@0C9h0051NF028OS00U7hL06A>J0P0R
88d09`0Z:HT0:3F801daQ@0=:Y403S:H01LTS00Q7XD07Q:3020QP00V<V/07RY^01hcK@0G=X<06RNF
02XNT00h9hl0>3J602DaO`0N<8P08T6@02M8T00`DXT0<eJ:03eXOP18P6X0DhMM05F0FP1SP500KX14
07B0@01iP400OG]007en@01kOT00NgQ007eg@01nN400NWe207ImA`0207=nBP0806mnC01`P4D0KWi7
07Mm@P1mOT00OWi007]j@01iP40207Z0@00M07Ub>`1eIS00KeLY06U<8@1P=a@0F2P=05@U1`1E8`/0
EBD<05@U2@1=9@X0BbD804dW2@198`P0B1l604TO201:80L0Ba`704LN1`196`D0AaT4048H10116@<0
@AT404<K10166P@0@Q`504<K1@1260@00P1070<09`117PD0AB0704dU1`1C9PP0DRT8054U2P1A9@L0
CR@504PP101:7@<0CR0505TX2`1U<P`0Kcl@07=96`1gDb@0MU<R079C8@1aCAl0JD@I06Q66@1YD240
K5dZ06]X<`1XM3d0Jg<k06me>`1[NT00KGQ0071g?P1_L3L0LfP]07EN901cF2<0M5dT07I@7P1eBa`0
LdDJ07E96`0207I:700P07M;6`1gBQX0LD4E06e05`1^A1H0KT@G06e5601Y>1<0I3<?068_201M;0P0
GB/605d^1`1J:0L0FRL605DT1P1@8`H0CB<4050Q1@1A80@0EB4505DR1P1?8@H0CR4605@S1`1E90L0
EbD705DV2P1D9`T0CbH904dQ1@1<8PD204hT1P0504XT1P1@9@D0FR@505HT1`1C:PH00P1@:@P09`1E
:`P0Eb/;05P[2@1G:PX0FBP605XZ201D90H0Db8404PP0P1<6`<0CA/105DO0`1C7`<0F20405PR1@1@
8P@0DR8304`N101:6080@QX203hF0`135@80?14203hE0P0o5@40?QH0044E00185P00?QP103dB0@0d
4000=@h003D<000e4000?Q8104<F0P116P<0>AX403DD0P0203PB0P0W03dE0@0l60<0>Q`303dK100k
6080?A<403`C0`0n4`@0?1@3040F10126`<0AQ/404<L1@126`@0?AL403`H0P145P80BA/304XM1P17
7`H0AR8704TU2@1590`0@bT:03hU2P0l7`T0>1`803DK1P0/5`@09A<401l?0`0R3`@08A8402HE1P0W
6PL0;1/802XG1`0S5@L08A8500807a4302L08Q0402HE100W5`L0:Q/902lN2@0g8`T0?BL;040W3@14
:0`0@BP:04HX2P15;0/0BBh>04`b3@1:<@h0B2h=044Y300k7`H0<QH202dB0`0/3`<09@`202D>0@0W
4P<0;QP302`G0`0`60<0=QX503PJ1P0b6`D0<AH402D=000M1P005`@001<3000>0P004`H001H:000K
2`400P0M2`40500I2P004`D000/1000700002`0000h0000D0P006@D001/5000H1P005@D00184000E
10005`@001D5000F0`0050@001D2000D0@003P000P0;0P004@0;0@002@8000X1000?0P005@<001X6
000H1`005`L101P60@0J1P406@D101X60@0F1P0060D001D90@0K30407Pd200808@h201@070X201H6
000E1P003P<000l1000?000040800145000C10004`D00103000?1@002P<000H100040@002P8000`4
000<0`001`00008000<0000000P00P0000@0000300000P0000@000060@001`4000H100801P0000@0
0`0000D0000400001P400P050@0200H2000300<100020000000001000000303oool000X0oooo01@0
<EQ102mMAP0/FdX0<E]203mL>P11Ed/0:CJ101<PQP096HT01A2d0000T`0977L032R101</NP0E;f`0
3RV001<PTP0N7Hl08aZ5024FR`80:Ab;02L0<bYj03<kH@0N;Fl042B4018_R@0D:XD06B2;01@<Y00J
6Yl0:2N601PTT@0F<iL05C6F01XXW@0Y7I00=b:<03XgP@0Z@8407S1j01deSP0T>YD0<dJ9035>S@0f
H8<0@X1^05:4G@1JP5H0IWa<0720A01fOD00O7e007j0@01nOd00OH1007Yg@01iOD00Nge007Qm@P1e
O4@00P1dODX07P1^NT`0Lgi707En@`1jOD40Nge007]n@01lP400NWe007Im@01hP400OGE007YX<@1b
ER@0IT8H05`a3`1A:@d0E2H;05HZ301E;0d0DbT;04hS2@1@8PL0CB<704TN1`147`L0Aad704PJ1P16
6@D0A1d604@L1`80@A/500L0A1/504@K101;7@@0B24604/S1P1:7`D0BAd50080BB0502L0C287054T
2@1@:0T0DRT<058Z2`1?:P/0BbP:050W2@1>8`H0BQl505@Q1`1F:@P0HRl;06/l4`1dBA`0Me<T07EI
901eDB40LE0N06i56@1/AQd0JE8W06]P;@1^J3<0JW@m06me>P1`LcP0KWQ0075i?@1_L3H0LVD_07=K
:01`Db00LThN07QB8P1eC1d0LDHF06dn4`1_?aH00P1`@QP09`1dAQP0MTTI07535@1^@AD0Jd4F06`l
501Y?1@0I3@?05d`2@1O;@T0GB`9060[1`1Q:`T0H2X705`U201D90L0DB<604lS0`1A7PH0Cal504hP
1@1?90H0DR<7054R1P1D9@L0D2<704/V1`1<8`L0C2@804TS1P179PD0CRH704`U2@1A9@P0DBH505LV
1P1F9PP0Db4704hS1`0204lT2@0W05@U2@1H:0X0DbX905DX2P1F9PP0DR@7054R1@1>90D0CB43058R
101E7`@0Eb8605PT1P1G9@H0E2<605TP201G7PL0DR0404<I0`145@80@A<1044G0@0o5`80@QP2040E
0@0n4@40A14004<D0@0l5040?18003LE000g4`00>Q81040B0@136080@aX2044I100m5@@0=1@30080
=0l202L0<Q4303HC0P0f60<0>AT403XE0`0i50<0>1@403XE0`0l5`<0@1H5044K1@146`@0A1/6048I
100j6@<0?AH303hF0P166`80B20604@R1P157PL0@R49044R2P1090/0?28:03HQ2@0d6`T0<AT702/I
1`0S50H07a4401`>0`0L3`D0818402<E1P0U6@L09QD7024@1`0K30800P0G30409`0H2`407Ph301d>
100R4PD09QL602hN2@0g8`X0>RP<03/U3@129P/0@B<7044S2@139@/0@RT;04<[2P12:P`0?bL:03dN
200g5`D0;Q@202X@0P0V3P409@h102@A0@0V4`809aD202TE0P0^5P80<AT3038F0`0Y4P4080`001D7
000E10005@400181000@0P004P@001H7000201P:000W01T;000G2000408000P0000;00003P400181
000A0@004`@00183000C0P003@8000l3000@0`004`<001@4000B10004`H001L4000C0`004@<000l3
000<0`00208000/1000=0@004@D001L6000H1@0060L001`9000M1`007PP001X7000E1`005@H001H7
000L2P407`/200808@l100D070`201X:0@0G1`0060D001H4000201<6000>0147000?10003@800141
000>0`00308000L2000700002P4000l300090`0020400081000400030040000:008000020@000@00
008000050@001P4000T200080@000`40008100800@0000<00P0000<0000300000P040@000`030@00
0@000000000@000000`0oooo000:0?ooo`09039LA@0]GdT0;Ue=03]N@014GCX0AE]902]1N`0F:X80
2Qf:0080003300T03bFR01</Q@0>8XD052j4010]R@0@;9P05abF020FTP0W5Y000P0]7HX09`0e<Vd0
=3Y402<[CP0D7FT04RUe014_R@0D994061>I01hEX@0T6j005BBY01LeW00E<iH06bfH02HOS`0g78h0
>CIm035FJ@0R?FT06c2:02L]U00e?Hd0<dn;039UP@0oP700C89P05b1E@1XPT`0L85407Z0@01mP400
O81007Z0@01iOd00N7m007N0@@1iNT40MgY407>0@`0207EnB00M079nC01fOTH0Mh1107R0@01mOD00
OWi007Z0@01gOD00M81007N0@01iM400NF@a075:701R=Q40FRX>05DY3@1D;@d0F30>05/`3@1G:0T0
DR@:050Q2`198PL0AB8904HQ2@177`X0AQd804@L1P147@P00P1570L020156@D0BA`504PQ1P1=8@L0
CB8804lS201<8PH0C2450P1;8@H09`1@8`P0DbL:05PV2`1E9P/0D2T8050T1P1B8`P0DR<7054R1@1A
80D0DBL705XZ201R;P/0JclD07A?7@1gFBL0MU`W07ME8@1eCad0LTDI06e36`1YCBH0KeTZ079S;P1b
KcH0MG4e07I`=`1cMcd0MGHl07Q_=@1fJ2l0MUHV071=801bC1h0MddO07E36P1_?AH0JSPB06di4@02
074n500W07935P1cAAP0Kd4F06Q04@1Y?@l0H3D=05h`2`1P;PX0GRX905h[201O;PP0GBd8060/2@1L
;`L0FBL6050T1P1:7`H0Cah404dQ1@1=80@0DB46054T1@1B8`H0DBH805<W1`1:90H0A1l404@N1018
7PD0AQl604TQ1P1;9PT0DBP905DV2@1G9@L0FBH605@W1@1>8`H0BB870080Cad602L0Db<7058Y1P1C
:@T0E2H904/Q1@126`<0AQX104TL0P1980<0Bb8305<S101I9PD0FBT605HW1P1E90P0EQl7058O1`1>
70H0BaT304TF0P136`80BAl204LP0`1580@0A1T403/G100l4P80?1D203XA000k5@00>QD103dG0@0o
5@40AAT304XO1P177@<0@Q/403dE0P0e4@400P0c3@009`0`3`00;Q01030?000d3`40>Pl103TD0`0c
5P@0>a@403dE10106PH0@AP603hI100k6P@0>aP403`H1P0k50<0>1H303dH0`106PD0@A`503`I1P0k
6`P0>1l:03/R2P0h7`/0=1`702dJ2@0]60L0:aP802<C1`0O4PD07`l301T=100L3P@07Q44024B1@0M
3`@060`301@70@0201<70@0W0109000C1`0050P101L<0P0M40D09QT702hP200d9@d0>2D=03LU300k
7PP0?Al703/L1P0l7`H0?R@703lT20118`T0?1h703PI1@0b5@D0:A8202D?000T3P807Pd202<=0@0Q
3`0080l002@A000Y4`40:@l002H>000P2P0080P002070@0J1P405@800142000@0@0040<000805@H0
02D070T001X80@0C10002`4000T0000=0@002`4001<1000D0@005@8000X200090P002`4000d1000?
10004@<001<4000D1@005PH001P6000G1P0050D000l2000;0@00304000l1000E0P005P@001L5000J
20007`P001l;000Q2P007PT001X9000F1`0060T100807`T20P0N30802@0O30406`l101/>000I3000
5`H001@9000G2@004PP000d3000200/1000?00d3000>10002P8000P200090@0030<000l3000;0`00
1P8000P1000500000`000080000500000`400080100000L0104000H400080`001`8000L100040000
0@0000<0000000@00P000040000100000@004P00000<0?ooo`002P3oool0500`Fd`0;5i=035NC@0m
H480A68l04IPB00bE6h06cam0000``000L800073010RZ@0D:9T04RNB01/hO`0B;W/03C2@010RV00K
6YH08AJH0P0]79407P0a=7L09BeS01lVL00J88805B^?018aV00E:YD06R6J02<GT@0T6I4072RP01`d
V00G=9406C:G02@QS@0^6Hl0=SEo03eUGP0ZCf/07cN402H/T`0g?XL0=Eb703=^O`0lP740B85U05b4
F01WRE40LHA507Z0@080Nh1000L0NWm007]l@01fP400MX1107F0@@1gP4<0MWm10080NGe302L0MX13
07N0@P1dPD00NGi007al@01lOD00Nh1007R0@01iP400Mh1007Qc@01dFR/0KT4G06<_3@1I:`d0Eb`=
05P_301G;@h0F2l=054[301A9PX0CBD:04/T20167`L0Aal704XO201870L0AQl704HN2@167PL0@ah6
048O1P1480@0B2L:04lY2P1@9`X0DBL;054U2@1=8PX00P1<90T09`1B8`T0DbL:054V2@1A8`D0EB<7
058P1`1=8@L0C28505<T1@1A:0@0FBT605HX201P:0`0J3T?079;7@1iFBP0NF8]07EI9P1dDAd0KdTL
06a56@1^Bah0M5LS07UP:01iK380N70c07Q/<`1gMSd0NWLj07Uc=P1jJS@0MELY07=B901aDB80LDhO
07966P1`?QD0KSdB06dn4P0207505`0W0791601`?aL0KD4D06Xg401V<Pd0GBl:05d/201I:@T0FRP6
05X[1P1M;@H0GS49064_2@1Q;`P0Eb/605DT1`1D8@P0Db4705DR1P1@90H0DbL805<R1@1C9@H0DbL8
050W2P1<8`H0AQd404LM10157P@0BAd604PO1`1<8`X0CRD905<X201C9`L0DBP405<S1@1<7`<0Bad4
0080Bad502L0Cb<6054V2@1A9`T0DBD904PL0`135`80?QD2040J0`177P<0B1l5050P101G9`H0DbH6
058S1P1B8@H0DAh5050L1P1;7PL0B20704@Q1@157`D0Cb8404lU1@1<8`D0B20404@K1P115P@0?aL3
03`H0P0m6040?a`304<L0`116P40A1h504LS20148PH0@QX303TH0P0b4@400P0_40409`0_3P00<P`0
02hC0P0b4@80=Q0203DC0@0c4P80=A4303TB100k5PD0>aL603XG100f5P80<a@303HI100j5@<0>aL2
03<D0P0c5@<0=1T603DG200e70X0=ah903PO2@0g7@T0;aX902hI1`0[5PH0:AL902DD1`0O4@H070h4
01P:0`0I2@806PX101T:0`0I2P4050L100h6000200d4000I00`5000A1P004`D001<:0@0I3P@08A85
02HG1P0]7`/0;R8903<T2`0e8PX0>Qd803TL1@0k7@<0>Ad403/P200k8@X0>1h603DL100]4`@09Ph1
028@0@0Q2P4070`201h<0@0201h<000<024;000V3`808a02024;0@0R2`008`h002D?0@0Q30406PL1
01D6000A1@0030<00P0A1000300G1@005`P101<7000<0`002@0000X0000@00003`4001<2000@1000
3P4000`100802`4000l03P400182000E10005PH101X70@0J10406PL001L6000E0`003`0000`1000@
0`004`<001@5000J1@000P0M200201l;000602<9000Q30407@P001T:0@0P304070T10P0L2P406P0L
2P807@h201`@0`0I30405PT001L:000G3@005@X000l6000;0@00204000`3000>0`003`<000P20007
0@00300000h4000?10003`8000`300070P001P4000L000060@0010800P060@001`050P001`8000P4
00091@002`<000D0000200006@00000<0?ooo`002P3oool0500ZFEh0;5]I035RD00mHdD0@fA204EU
B00fGV<08TMf0001``010/400@>n018SX@0E9Yh052VJ02A3J@0J<F@03bin00hXT`0F8IH07ARK0P0/
7Xl07`0a:GP0:RIa02P/O`0N99X05RbR01LeV`0F<I<07BnB01lNS@0V6Y809bV?02LoJP0P@W@06CB=
020USP0W6IL0=C9l03UJH@0[@F<09D2102/eS`0h@XL0>6=o03AcO00kP780Ch1S05f6F@1URE40L819
07EoA01iOd000P1jP4001P1jO400NX1007B0@@1cP480M7m507R0@080Mgi102L0N7i107Un@01iMd00
NW]007]m?P1iO400NH1007>0@01eP400MGE007EY=P1bDR80JCdD060a401M;Pd0Fb`<05P/3P1D:`d0
DRX<050W2`1=90T0C2<904/Q201880H0BB0704XQ1`1;7`L0BR4804TP2@1;80T0BAh604<O10157P@0
BB@804/W2`1@:0/0D2D:04`X2P1@9`T00P1B:@d09`1C9`P0Db<705<P201;7PD0CAh604/M1@1>7`D0
DAl405DU1P1H9`L0F2X:05@Z2@1G:@L0Gc0<06Lo5P1cDB40MF8]07IN;01eE2<0LTXO06a26@1^AAT0
LdlL07ME8@1hHb`0NVT^07QV;P1eM3T0NW@g07a^<@1jIbl0MU/V07=E8`1cDB40M4/L07E45`1`AQH0
LTHF0711500207545`0W07<n4`1^>a00K3P?06Ld2`1R;PT0G2/505PW1P1K:PL0G2H705TV1`1L:0T0
FR`605`]201Q;PX0G2X905`U1`1K8`P0Eb@605LV1`1J:PP0F2P605PX1`1F:0H0E2P:05@W2@1:90P0
AR0504LM1`167`H0AQl504PQ1`1<8@T0Cb<:054V201C8PL0DR4604`P1@197`@0CA/50080B1`502L0
C20504`S1P1=9P@0CR<504LO1@137080A1/304DM101>7`@0CR42050T0P1A:0@0CbL404/N1@1<7PL0
BR0304TJ10177@H0@Ql604<N1P187PL0BR<604`S2P1=8`D0B2@804TP1`127@H0A1/3040I0`0o7P80
AAd4048K1@126P<0@b4604PO1`117@@0?aL203LE0@0e4P400P0c4P408P0c3`40>0l203TD0P0k5P<0
>QL303HB0`0d3@80<``303@@0P0g5@H0=AD303H@100_4P<0<aT603XF1@0i5@D0=QP4030D1@0/5`D0
;Q@5030E1`0b60P0<1P902lH2P0^5`T0:aP602dF1`0Z5`H0;1H802@D1P0M40H070d501X90P0J1`42
01L700030188000>1P003@<0008040800P0?1@009@0A1P004`D001@:0P0I2`40814302DI1P0Y6PP0
<20:03PP2@0i7`P0=aT503TG100h70@0>B0503LO200f6PH0<AT302`A0P0S3@408@d101l;000L2@00
6PT001h8000K1`007@T102D@0`0Q3`<080`102<;000U3@0080h101d=0`0N2`805PT101@50@0?0`00
0P0>0`001@0B1@004PH001<5000=0`00308000803P4002004`8001<4000E1@004P@00142000@0@00
3@4000d2000@1@004P@001@50@0J1P4070T201/80P0K1@405@@00141000D0@005@D101L6000G1`00
6@D001X8000L2`4080`102<;0P0X3@809Ph101h;000P2`407``101d90P807@T101P060X001P;0@0J
3@806@`201D:0@0I2`006`d101L<0@0D2000408000/3000;0P0040D000l3000<10002P@000h1000>
100030@000`3000;10002P@000h400090P0200P1000900L3000710001`8000H200080`002`D100X4
0@080P000`0001T00000303oool000X0oooo01@0:51m02YIL00bHed0>fEA045WC@14I500<eQ/0084
`0000L<00@>o0085^00F98/07BZ301l^R`0XAUd07CA]018WO@0?:X804bZ<01TUUP809Af>02L0;1Z5
03<PR00j<WP08BJC01X^W`0O>9806cJ<01djOP0M:8809QZ@02lSR00`>VT0:DMP01diKP0L;8L091fA
038[O`0cB7P08S2@02E0R`0[@8X0?4V203i^M`0iOgP0?H1d04YmI`1HQEd0HXEE06n0B@1cP4T0MH15
07Z0@@1iP480Mga307Z0@@1hMT80LX150760AP1dOd@00P1dOT809`1fOT00NGi007Yn?P1iNch0Mg]0
07Il@01gNd00MWa007F0@01dLd00MF4`07197`1U@1@0HC<A064_3P1J;@`0EBX;04dX2@1=90T0D289
04`Q1`198@P0BR0804XP1P1;8PH0CB<704`T2@1;8PX0BQd704`J1P196`@0BQd304PP101;8PL0BR@7
04dS20199@P0CBD<04hX2P02050U2@0W050S201>8@L0CQl704DK1P166PD0BQX404/P101=8@@0EBL5
05PV1P1F9PL0EBH705DS2@1J;0d0ICTC06e?7`1aH2d0LfD`07AK:@1_C280Jd@K06i26P1^BA/0Le0O
07AJ:@1aHRh0LF@^07=_=01gM3D0NFd`07QV;01iF2D0MU8M07MA7`1iCAX0MdLI07=75P1aAQL0LT8B
0080LT4C02L0KC/?06Xd2`1Z<`d0Hc0<06<Z1`1N9`H0FbP305hW1`1J9`L0F2L705`Z201K:PP0F2`9
05/Y1`1J:@L0FbL505lV1P1M:@L0FBd8060[201R;0T0GR`705/[101G:@P0EBL:04`S2@1<80P0BQh7
04HL1P197PL0C2<904lT2@1@90L0DbH705@S2@1@9PL0CB@504XS1P197PD00P1;6P<010196`@0A1/4
04LJ1P176@D204LM1P0Q04LO1P167@H0DB<705@U101F9@@0DBD304dR10187`D0B1`6044I101060<0
>aT5044H1@147@H0@ad604TO1@1:80L0B28604PO1P1980P0@b05040K100m6`@0?QT304@I10127@D0
?ad403lN10126`<0?QL303dC0@0l4@40>`l00080>a820200>A8203dF0`0n6P@0@AX403`G0`0d4`<0
<0h102l?000a4@80>QH503DG100a40@0<aH7038E1`0i5PH0=aX503HG200`6PP0;1L902hG1`0^5PP0
;AL702XB1`0V50P0:QD702TC1P0`5@D0;1D602@C1@0P3P@06P/401D80P804PH100@05PD001P5000A
1P004@<00`0@0`009`0B1P004@L001<7000B20005PX101D:000H3P407Ph3028D0`0Y60H0<ad803<P
1`0c6`H0<aT303@K100e70@0<a/603<J1P0[5`@09a4102<?000N3`4080h001h;000N2@006`H001T7
000J1`007@X101`>0`0K2`407@T001d;000R20007P`001d;0@0F2@004`<000/0000200X1000500/2
000=0P003@<000`2000;0`000P0A0P004`0A10005@D101@5000A1@0040D00103000:0`003P<000l5
000A10005`H101d:0P0S3@808Ph301l90P0L1`405`@001D3000G1`000P0K1P002`0M1P007@T001l:
0@0U3P408a@102HB0@0[3P8090`002D:000T3@8080/100807`X001007PT001`9000I2P406PX101X8
0@0H2@406Pl201T=0@0E2P404`L100`1000;0@0030<00105000@1P0040L00P0>10004@0>0P003@80
00d4000@10003`D000h3000;10002P4000T3000910002@<000H100070P002P<000T400070`001P00
00800@005`00000<0?ooo`002P3oool0500RAY<08E:;02aLNP0gHV@0@FID04=REP063kP00PFo0001
``011;l00PFj01/PSP0Z;Wd09c>702HoHP0M=Fd0522D01@VS@0C:hh05RfE0P0M7i009P0T5h/0;aj<
03X`LP0U8XT07bn=02LmJ`0S?6H09D9Q024cL00U78L0<Qb:03P`P@0Y>fP073Qb01XaR`0V8i00=2F=
03]4O`0[=hd0:cn:02lnRP12Cg/0AGM^0425K`11P6l0C7UX05N0GP1SQ5@0LH5:07>0B01ePTL0N854
07J0A`1aP4d0Mh1307R0@`1fP4@0M7a50`1fP4<09@1hNd40NH1207Ul@01dO400L7a007=k@01cO400
MgA007Qb>P1eJcD0MUPY075;701Y?QD0ICH>05ld3`1N;0/0DRH:04lS201=90L0CB4704dO1P198`@0
CB<7058V201>9PP0CR@9054S2P1B8PL0Cb0504XN101<7PD0BR<704HR1P178`H0BB@904LT201;7PP0
0P1<8PP2050R200W04`U1`1=90L0Cal604LN1P146P@0AQP404`S1@1C8PD0ER8805HR1P1E8P@0DBD7
05PT2@1K:0/0Hc4>06U25@1^D2@0KePZ071D:@1ZCB<0J4@M06i56P1_Cb00L5DU06mM;@1THCD0J60b
079Y<01fKS80MVh_07QT;01dDah0MD`K07IA7P1gC1d0MdPI07E65@1c?a40LCX@0080LC/=02L0K3L>
06He2`1[=`h0Ic<<064/201O;0T0FR/605dZ201J:PT0F2T905d[201I:PT0EbL705`X201J:@L0G2`4
05/]101I;@P0FRd705`^201J;PP0Fb`405/[1@1E9`H0CBD604HO101590P0BB8604DQ1@1780P0C2<7
04lS1`1>9PX0DRT:058Z2`1@:`d0D2P:04`S2@1=8@L00P186`H09`166PH0AAT5048H1@1250@0@aX6
048O1`187`@0C1l305<S1@1E9PH0ERP705<R10197`<0A1P304DG1@0l5P80=QD203DF100h5`@0@1/6
03XJ1@106PD0@1d503/M0P1070<0@1d503dK10116@<0@1/303hK101570@0@a`6040L1@116@<0>QH2
03LA0@0i4`<0>Q4203hB0P0203hC0P0W044G0`125P40?AT204<G100l4`80=A82034@000b4@40<Q@2
03PA100g50@0=AX7034E1`0b60L0=aX703TK200f70P0>A`903<J200[5`L0:Q<602LB1P0S40D07`l6
02@@1@0S40H0:A4502P@100Q30<070T301D70P0B1@403P<00144000B100040@00144000B1@005@D0
00805@P001L05@L001T90P0J2P806@/201P<0@0I2`4060/101d;0`0N3P<091<402LG1@0]60L0;aP5
038H0P0c6P@0<1P402TE1@0W4P@08A<4020=0@0M3@0070/001d:000201h<000>01`6000H10005PD0
01X9000H1`405`H001L7000G1@005`4001H7000H200050L00141000=0@0200/0000:00T000080@00
2P<000d3000:10003`4001<1000A0`0040@100l50@8040<001/04P<000l2000A10004@@00106000G
1P0080X202D=0P0Y40<090d202<<0P0Q2@406@P001X7000L1`407@P101`70@0M20007`d002@?000V
4@408a0102D?0@0X20409@`002H=000U2`000P0Q2`00900O2@007@L001`:000G2P405`P101T90@0J
2@406PX001L8000C1P403@4000X2000<0`003`H101870@0@1`003PH000`6000>0`0030<000d2000@
0`004PH000l6000<0P001`4000@000070P001P<000L100050@001P4000P200060P000`40008001P0
0000303oool000X0oooo01@08SRE02I3U00/Ah/0=EMh03mNI00L;i/01a2h0086_`000<<00@?00084
_00P7I80;bZ302X[R`0Y<GL07c9_01@KU@0E7iL052VD01HcU0806bV>02L08Qf<02/LS`0j;Fh0;RMU
028TJ00Z=fP0:D5I02DoG00O<g00926602hJS00h9XL09R6I01TYW00L;IL0:BR>03PYR011@7P0<3:9
02`jR`0_=h/0@TUi04UfK018PV/0Ag][05QoH01RQUL0KXM@07>2BP1dPT/0MX9807J2A@1fP4H0MX17
07Z0@`1kO4<0MGa507B0AP1fNDL00P1eNDD09`1cP4H0MX1207J0@`1aP4<0KWi107=j@01eMD00N78j
07IW<@1bGB`0LE8T0712601Z>A40I3HA05d`3`1I;@X0DBL904lR1P1;9PH0D2D7050U1@1D9PH0ERX7
05LZ2@1A9`T0CR<9054T201?9`<0BB4404PP0P198`H0CB<604PU201=8PT0C2D:050S2P1=8@P0Bb@8
04TP1P0204LR1P0W050U1P1A9`H0Cal804XR1P177PD0B1h504hR1P1B9@P0DRH9058T1`1A9@D0DB@6
05DV1P1D9@L0E2P805l/2`1S=Q@0ID0L06E67P1UA1/0J4@K06m9701`DR40L5PV06iK:@1YFB/0KELX
075M9`1bHR/0M6<Z07=J901aBa`0L4PK075:6@1aAQH0L44F06lm4@1a>A00KcP=0080KSX<02L0JCH9
06Dd2`1S=0`0HCH@05hb301R<@T0Gbh:05dd301O<@`0Gc4;060a2P1P<@d0GBh:05X]2P1M;0P0FbP7
05XV1@1H;0@0G2/705L/2@1D;0D0EbH5054T1P1<:0H0Ab8604@O1P158PP0BR@804LR2@198PL0Ab87
04PS1`1:90T0CbX=050`401A;Pl0CBd=04`Y301>9PX00P168@T09`158@T0AQd604DO10136P@0AAP5
04@K0`1:80H0C206050S1P1B9`D0DBH404/P1@196PD0@AP3040I1@0m5`40<a81030D0P0h4@40?1H4
03`E0P0k5080>1D303@E0P0g4`<0=QD503TG100o6`D0@1d4044M100o80D0AQh703hI1@0l4`@0>0h2
03HC0P0g4`<0>Q<203dD0P02044D0P0R040G0P0n4@40>1<103TB0@0j4@40=A41038A000c5000<A@1
038D0P0b4080<A@4030F1P0a5`H0=1T503hJ1P0m7`X0>b0903TM2@0_6@H0:a8502<;100N2P8070d2
01h:0P0P2@<08@`2024>0P0L2`805`L201<6000A0`004PH0018500804@@000<04`D001@6000I2P00
0P0L2P807@0P30<08A0402<B1@0S4@@08Q85020@0`0M3@407@/201l=0P0W40@0914402PB1P0[50@0
;AL2030D0P0[4`8090d101l;0@0I2`4070X101P8000I1`006`L001d<000L2`005@L00184000C0`00
5@@000804@<000P050<00182000?0`004@<001H4000D0P0040<000h20@80304000D02@4000@00008
0@00204000d100020100000P00d1000;0@002@8000/3000>0`004@800101000>0@003P800145000F
1`007P/202LB0`0[50D0;18302X?0P0U3@807PX001`7000J2P006PL101d70@0L20006PH001d=000P
3P408`l102H=0@0V3040:0d102L<000V3`02024<000C01h:000I1`0060H001D6000E1P4050H101H7
0@0D1P005`H001D5000C0P003@4000h2000=1@0040L101480@0=1P0030@000/3000200/1000;0102
000?10003P<000/0000800001@0000H000070@001@4000D0000100000P0500000`03000000000000
000G000000`0oooo000:0?ooo`0D020]U@0[>hL0:SZ<02m=Q`0hDGX062JS00P>Y`0538h021Ig00`T
Q@098iT0:2Qj02PRP@0Y7X`0;2N:024]N@0G7h4072>D01TUUP0H>8l201XcNP0W01lVO@0X88D0=R]a
03HZG@0T7X<09bf902XlJ00N>W@07C>9028UR`0[6Xl0=an102hPRP0O<iD07S:D02L/S00g9hP0A3ai
030[RP0Y=Xh0:c>>044kP018KVd0AG]]04=aLP1KP5h0IHUD06Z6D01^PD/0LX9707J0B@1cP4P0MH19
07B0B01fP4P0Lh17075lC01]P540KH1?0080L81A0140K81<0720A`1[P4T0Jh1506f0@P1bMT00M6lj
07MV<01`H2d0LEHX06m?7`1[?aL0IC@A060e401M<a00ER/=04lW2`0204/V1P0D050Z2@1B9`P0E2H8
054Z201D;0/0D2L:050S1`1>9PL0DbP805<S2@1?9@L0CR<804hW2P1=9@T0Bb@704hU1`1?8PT0CBD8
04XU1`1790L204PT1`0W04`W2@1@9PP0Bb@804`R1P1:7`T0CB0804/T1`1@8PL0BR0504`N1`1<80H0
DB4604`Q1@1@8@L0CRD:054U201E:0/0FRl<05ld401R<Q00IC/F06]77@1^C200K54P071>8@1^CR00
KThN071E8P1cFb@0LeLT079?7@1^A1L0JD0E06To501]?1<0K3PA06`k3`1/=`d0KCD?0080JCL=02L0
ISH=06@c301S<`d0HCD>060c3P1P=@`0HC4<068b301S<0`0IS@=06<c3`1U<@d0H2l:05`_201I:@L0
FQl705PQ1@1I9PH0G2P905PX1`1D9PD0CR4504PN1@177@D0AQ`404HM1P1:8`T0B28604HP1P197PP0
BQl704<K1P167`L0B28:04`U2`1>9P/0CRL:05<W301D:@d00P1?9P/09`1<:`/0D2P:04/U201:90L0
BQ`604@L0`167P@0AAd504`R1`1880H0AB0504<L1P126@L0@1T6048F1@0m5@80=Q0203P@0P0b4@40
<1<202dA0P0b4080<A0202lA0P0d3`40>14303dH0`117PD0@ad403lM0`0m6`80>QL4040F100e4`40
<a8103HA0P0j4`<0=Q@203LB000203L@000W03D?0@0e4@00<Q40038=0@0e4080<14102l@0@0a4P00
=Ph1030=0@0]4@40;Q@403<D0`0e50D0=AH603/K1@0l7PH0>Qh703PO200c5PL0:A<5028>0P0M2040
6PP101H60@0G1`406PL101/80@0E20005PP001D6000D1@004`H001@5000E1@004PD001<7000L1`80
70`200808A8301h091@502PE200Z5`P0:AT702/G1`0X50H09A<402<@100V3`@09a8502L@100R4P<0
8a8402LB0`0Z4P<0:A01020<0@0I20004`T001D7000C1P0050<101H80@0L1P406`X001L8000D2000
5@@00183000@0`0200d300070140000?0@004@@001<5000H0`00508001020@0200h3000700/10007
00001@0000P1000:00002`0000T0000200H00080200001`02P0000`2000<0`003@800182000>1000
4PH001/<0P0T4080;1H302`D0`0X4@809Ph202<:0@0O2`006`/001X7000L1@006`H001T4000L1`00
8@`102@@0P0U3P809@d102L:0@0Y2`009``00P0V2`00800N30406`X101H70@0G1@004`D000l4000@
100040D001@4000B0`004`<000`1000;00001P4000L3000;10402`<000X2000800001P0000H1000=
0000404000l1000=0@002@0000@100020@000P0000<0000200000@007000000<0?ooo`002P3oool0
500K;IP0:T:002<_T`0/Ah40:dml01<NZ@092IX01PUk00dQH00@=V`06CJ1028[LP0Q7h009AZ>02PQ
SP0T98H09bJ302/dK`0M9W405S9o0P0H<XD09`0L;8408R:<02lTRP0k;G<0;B6702LZU00V;I@07SF<
01dnNP0Q:W/0:1b;03TMOP0f:H00:D2=01hgT@0X<8/0<bB:040fN@0a:8`0:3B@02daS@0m;H40@f=^
045dKP0oHgP0EGmR05f8F`1SReH0J8M?06j3D01]P4/0L7m90720B`1]P4X0LH1:075kB@1_N500Ih1F
06R0F@0206F0EP0W06N0E01XMd`0JGU<06R0A@1^P400L79007EU<P1aFRX0L5HZ06eB901[Aa`0J3LB
05la3P1K;a00FS0?05DY3P1@9@P0CRD8050X2@1D;`/0DbX:058W2@1B9`P0D2H;04lS201:8`H0CBD9
050W2P1B9PT0D2P<050X3P1=:@d0ARH904TP1`178`H0BR@704TR1P1:90H0Ab070080Aal902L0CR48
04dP1`188PH0BB4704/N20177`P0CAh704XL1P195`D0BAT304LM1P1:80@0BAl704TQ1`1;8PL0C248
04dS201D9PP0ERP705`Z2P1T<`l0I4<I06E46`1WAAL0K4<H06]35P1WA1P0KDPI071;701^BQ`0Jd@J
06Xm5@1T>A40HcPB06Hf4@1V=0h0J3<=06He3P1W=0h00P1T=0h09`1Q<Ph0HC@=060d3@1S<Ph0Gc<<
064a3@1P<@h0G30;05hb2`1R>0d0I3P=068a301Q<P`0Gc0:05XY1`1F9PH0FRD705XX2@1J:PL0EbD7
054S1P1;7@H0A1T404<J101470@0AA/304@I10126`D0A1h604LP1`1870H0@Ad4044K101070L0@ad6
04`S201?9`X0DR/>05@]3@0205P`3@0W05P_301F;@X0DBP:04dT2P1;80L0A1`504HK101670D0AAl6
04TK0`166PD0@a`403XK1P0o6PD0@AP603hF0P0h3P80<0h002`=0@0Y30409@/102d?0@0^3P<0<0l2
034@0@0i4`80>AL4044K1@1160@0?1H103LF0@0j5P@0=a<203P@0@0g4040=A8103@B0@0a3`40;`h0
0080<0l000@0;P`002`@000/3P00;``10P0b40808@0/3000;0/002X;0@0Y3@40:`h103<B0`0b4P80
;a8202lC0`0_40<0;aP502lH1P0b50@0;1<602P@1@0V3P807@T001/8000I1P0050D001@4000G1000
5@D001D8000D1`004`L001H80@0F2@806@/401X:0P0I2P807P/202@@0`0202PE1@0D02/I200/6`P0
;Ad9030P2P0a7`X0<1`902hI1@0`6@H0;aT602hH1@0X4P@08a4302HA0P0X4@<0;1@302dC0`0V3`<0
6`X101L90@0H1P4201@4000A01L60@0M1`006@D001X5000I1P0060<001H5000@1@004@H00103000>
0P003`8001@4000F204050@101L1000A0`000P0@0`00100;0P00300000X00009000200L1000400P0
000600000`0000@00080200001/01`4000X2000=0P003`8000l5000B1`006PT2024<0`0T40@09Q03
02D>0P0T3@808Pd201`<000K2`006`P001P8000H10006@D001T6000L2@008@`1024?0P0U3@409`/0
02P:000X20000P0V1`000`0S20007`T001L700020184000400d3000<0`003@8000h200803P<000D0
2@8000D0000400000`4000D1000200H100801`4000T01P4000L000070P00308000X200080P001@40
00<0000200007`00000<0?ooo`002P3oool0500L=9D0:D^:01hZW00^DWD0;51e014M[00:2i<01@R6
00TDOP06<X004cF701TZQ00L88T081nB02TQQ`0]8h<0=2eQ02d`F`0S<FD05Rek0P0F;Y809`0I;HL0
7RZ=02PZT00a:h40;RB:02l]P`0[<fD0:41J02e<E00X?6X0926503<NR00o<WP0=de`02HcQ`0Y<8X0
<bB;04@cM`0c9H/0;CJ=02dcS00k:h80AeeX04AaI@0oG7<0CgER05J8FP1OQU80Hh1>06f2B`1aOTH0
LGm207:0A01cP4H0LX1706n0C@1ZP540H81G05j0FP0206=lD`0W06=lC@1XO4P0Jh1506mn@01aL400
LF<_079H:01]D2<0Jd`S06]2701W>a@0H3H?05d`3P1N<@h0FC0<05XY301F9`T0DbD705@/1`1I:`X0
F2/805<[201@9`P0CbH904lR1P1>8@P0CBL:04hY2@1B:P`0DR/=04l[301<9`T0B24904HO1@117PH0
AQl604LP1@1:7@H0BAl60080BR0702L0BAh704XK1P186PH0BQ/604`M101=70D0AQd804HN1`156P@0
@aX304@L1@1570@0AQ`304/N101970D0CQ`604hP1P1B8`P0E2H605TU201I<@d0H3TB05di4@1Q=@l0
ISH?060i401M=`l0IS/C06Xm501/@QD0Jd0F06Pi4`1U=0h0HS<=06@a301P<0/0HBh<06<a3@1T<P`0
0P1S<@h09`1R<Pd0I3<=06<e301S<P/0Fbl=05/^3@1Q<@l0Fbh<05l_2@1O<P`0HC4>06@f3P1R=0`0
H2h;05//2`1K:@T0Gb/905dZ2@1I:@L0E24604dQ1P1:7@H0AA`403hN10157@D0@QL203lG0P0n7`@0
AR0404LO1@1870@0@1X304@L1@1570D0AA/404XR1@1D;0/0E2h?05L`400205Xa400W05T]3@1F:0/0
DB4904TQ1@188PH0Aad504HM1P147`D0@B05048J0`1160<0@1X403hK1P0l6PH0?Qh603hI0`0a3`80
;`h202H<0@0U2P809`/202h=0P0`3P80=AD403HE0P0l50@0>QP503hI100n4P<0<a0103<>0P0b40<0
<A@4034E0`0d4@80<Q40034?000]3P40:Pl10080:@l201d0:0h102P<0@0X3040:`d102`=0P0X3P80
8`d102<;000R200090/102/>000a4@<0;@h102T>000V3`40:0`302T=0`0[40<0;A<402T>100V3`D0
:0l3024>0@0T2@007`T001X6000B1P004P@001@2000201D6000801D:0@0H30807@l401d@1@0L40D0
7@h301l=100T50D202PL200W02hN2@0]7@P0;Qh802lO2P0`8`X0=28:03LS2@0h7`X0?1h903HJ2@0_
5`@0:14202P=0P0[4`@0<1L4038E1@0]5@H07a0301d=0P0J2@804@<000l5000C1P0060L001T60@0F
1P006PT101d90@0I20005@T00187000A1`003PD000d2000A0`0050H001H6000D0`004@<0008040<0
00H04P800181000<1@002`8000L00004000200H0000M00D000060@001@0000L2000600001`4000P1
000;0P003@8000d50@0A1P805PT201X;0P0N2@8070P201`8000L2`007@X001`:0@0H2`006PT001/9
000H1P005`L001T7000J20007PT101l90@0O2P000P0S2@0202<:000=0249000O20006PD00184000=
0`4030@000T200090@002P4000/100090`002@00008000030040000300@100070P001@<000<01P80
0P080`0010090`001`<000H100040@0200800003004000000000000001/00000303oool000X0oooo
01@06SYi02E9P@0T=Y40<dmj031;M`0C7jT02PjB00@6TP041j800bbB014iS00I<h406bV1020VR@0X
8h40<2Ig030XF`0L7H/08SYb01L_M@805C>>02L06c6<01deRP0S<X<0;2b002hVR@0e:gT0=3UL03A:
A`0eDDH0:4IX024[PP0_9X80@3IV04A?E`0_=VP0:c:202lWR@11:Vl0=RR102dgS@0]=Hd0?2R204AH
I@16Jel0@5][04mbG@1IP580Hh1806]d@01^Ld00LG8l07A^>`1fLS`0Mg9007Md@01eM480L7e406j0
AP1/O4D00P1[O4D09`1/P400L7A006mc@01aJS/0LeTZ07197@1[AQ/0JDTL06Y56`1W?AH0ICPA068d
3`1P;Pd0G30=05T^2P1K:`/0ERX705PY201G:@T0F2l:05T^2`1D:@X0DBT905@X2P1C9PX0CR@:04dU
2P1?9@`0CbH<04hX3@19:0`0B2H804@Q20137@H0Aad804DO1P157P<0A1h604XN1P0204HN1@0W048N
1P157`D0AR0504/Q1`197PL0BQl504TO1`1>80P0Bah604DO1P147PH0BAP304PO0P1;7`@0CAh604lP
1P1F8P@0ERH705HZ2@1A:@X0Eb`<05T_2`1F;0T0FRd:05h^2`1I<@/0GC0:06<c3`1X>100JSlC06Li
4P1V=Pl0HS0=05d/2`1O<@/0GS0:05`^2P1M;P/0HC8=0080Gc@=02L0HS4=068b301P;P`0HBX906<X
2@1P:`T0FRl:05`/1`1G:PL0F2/805T_2@1K:``0GC0<05H_2`1F:@P0F2T:05T^2P1I:PT0F2L804hP
1P1:7@H0A1d6044O1@1380H0@Qd604<M1@0n6P<0@Al504PO10166`D0@a`404DG10156`H0Aah504LN
101B9PH0E2X<05P`3P1E;0`00P1F:`/09`1?:0T0D28604`N1@177@D0BQl704PO1P187PL0A1X4048I
0`156080@aP303hG1@176@H0@AX403hM1@0l60@0>AD203@?0`0b3P80;Pl502l?1@0f4@<0=Q@303/G
1@0m5P<0>aL303`I100j6P<0>A@2030=0@0]2@40;0T102P<0P0^3@00;141034?0@0a4040<0d102T>
000202@<000W02<90@0R2@008PL002@8000T2P408PT101d6000M1`008@P002`<000]4P40;a0002LA
0@0T3`008@X0024:0@0T3`808a0302LC0`0Z4`<0:a4502dF1@0Y4@@09a4202<=0P0M2@005PH001H8
000D20005@L001D:0@0H30407Pl302@C1@0U6@L08QL7020D1P0O4PD08aL70080:A`902@0;24:02/P
2`0[7PX0;Qh8034Q2@0d80X0=R4:03LO2`0n8PX0>Ql903LL1P0`4P80:a0102XD0P0b60@0<QP602lF
1P0U4`@0814301T90@0D1@004P400141000B10004`<001H7000J2`006@`101X<000M2`005`T001@6
000A1@0040@000l1000A0`0200l300<04@4000D04`8001D2000@0`00308000P0000200@0000B00X0
000800001`0000H000080000100000<000030P001P0000X1000;0P003P<00145000A1P804`<10103
000E0`0050@00P0J1P40300G2P406@X101T8000J20005`L001H6000B10006@D001/6000O20008`L0
02@700808PT002007`/001/:000J1P005@<101830@0=0P001`0000@0000300000P0000D000060000
10000080000300000P0000<000050@001@<000D200060P001`8000X3000:1P002@@000L400070P00
1@4000@100020@000@40004001`00000303oool000X0oooo01@06T1^02Q6O@0Z?8P0<dZ303A:P@0D
7jX02@nD00D7S`048iT01Bn?01A0P`0J@7<07CU^01h_N`0U9800:bAm02DOM`0F59h07c:701lhP080
849g02L08CY_02=2K@0WA6D0:C]]02PWPP0b9HD0>3=e03@lF@0dC5L0;daP02DfJ`0^;W00?C=Q040i
B`0d@UX0:cUj02PXS`0e8880=c5l02i0P00/?XD0?CAk04UEH01:IUL0@fAM05=aCP1KOTT0H7I006Q`
>P1ZJCD0JVDa06UG:`1_FBP0MF@]07IT<P1dHC00MV@d07AX=`1fJST00P1cJST09`1_IC<0Kf0`071J
9`1/CR00J44H068j4@1R>A@0ISXC068j4P1Q=@l0H38?05/`3@1J;``0F2h805<Y201H:@X0FRP705DX
201F:PT0ERh<05H/3@1B<0`0Db`<05L]301F:`d0DRL:04lW2@1=9@X0C2D;04/T2P199PP0Bb@804/V
20158PT0AR4804HP1`167PH0Ab8804PT200204HS1`0D04HQ1P1;8`P0BR@:050V201?9@P0CbH:05<V
2P1D9@X0D2D704lO1@1990L0BbD704lX1P1B:0L0Eb@805DW2@1I:@L0G2/:05HZ2P1G:PX205LZ2@0A
05<Y2P1H:`L0FC4:05`^2P1I;P/0HC0<06Db3@1T<``0HS<<064a3@1P<0X0HBl;068d301Q<P/0Fbd;
05d/201O<@X00P1Q<0/02`1P<0X0I2`:060Z1P1P9`H0HbT606<[1`1M:PT0GRT805@W1P1D9PP0E2H9
0080DRL801X0CRD704dS1P1<8`D0Cb86058R1`1@8`P0B1l704@L1`116`L0AA`4048Q1P117PD0@a/4
044Q1P178`L0Bb0704TP1P187`D0@a/504HK1@1;70H0Bah504lP1P1A90P0D2H:04XQ2P80BB0600P0
BAl404/M0`176@@0BA/504XM1P187PD0Aal504HJ0`80@aL201d0@AP204DK1@177@D0Ab4504@R1@0o
6`H0>aL203HD1@0e4P<0<AD303@G100j6@@0?aL503dJ100o7@D0?ad403`M0P0l5`<0<a@102l?0@0V
20009@/002X;000]3P00=A8103<A0@0b4000;Ph002D900020207000W01/9000J2@007PL002D5000R
20007`L001h5000Q2@008`/002l@0@0f5080;Q<302L@0@0O30407PT001d:000R30409A4202XB0`0/
4@D0;1@502XC100X4`H0:184028>0`0L2P405PP101H90@0I2P406PX101/:0@0N40@08A8402@J1`0Y
7@X09A`:02HK2@0W6@L0:1`:0080;1l:01`0;28:02TQ2P0Y7`/0;Ah:02lN2@0_6`P0<A/803LM2@0l
90T0?R8903HN2@0c60@0;1<202dB0P0_4`@0;aL602dG1P0W5@D08A0201`<000E1P004P4000h1000@
0@003P0001P3000M2P408@/00P0M2@401P0K1`0050H001D6000A1P0040<0014300803P8001403040
00/1000;0@003`8000d2000>0P002P4000/0000;0@402P4000d0000<00002`4000d2000;0P002P80
00@0000200@1000<00H100040@001`8000X2000<0`003@8000X1000?0P004P4001@2000I1P405PD0
0P0D1@002@0C1`0050D001850@0@1@004@@001P7000K2@007@H001l70002020<000801l=0@0O2`00
70P001<6000A0@002P4000L000030003000000800@000`000002004000800`0000/0100000D20008
0`002P<000X500090`001`<000H2000400000P000040000M000000`0oooo000:0?ooo`0D028iQ00Y
@7l0;4F8035BO`0ZBGh06Bj200XDR@034I`02Rj200i1M`0IBG407TQ_01i1I`0K<gD07R:602@MQ`0R
78@071ZF024_VP0W@Wh202Q6JP0W02M5J00_CET0=UA>03I=D@0/=700;bJ003DWO@0d;Gd0=4Ed0354
EP0^?UP0;CM`03D]J`0h;W@0>D]e02`kP00W;h`0<RR603doI@0eC6L0;Dik03M1N015EF<0BVAD04MY
D01EKdH0FWA206=c@01UJcH0I6Lc06AL;P1SBB80IDLN06]C901^DRD0JdHM06e87P1/B1d0JdPN0080
JdXL02L0JTTM06U67@1W@aX0ID4H068h401K=100GSHA060e4P1N=Pl0FBl<05X_2`1J<0`0FC0:058Y
1`1=8`H0Db@6058S1P1@8`H0D2H:04h]2@1C;0`0DbX=05L]3@1E;Pd0EB/<054V201;:0H0C2H904`U
201<8PH0BRH804PX2P1;:0T0BRP:04`W2P1?9PX0BbL:050W301A:@/00P1=:`T07019:@/0D2P;058Z
2P1C:@/0ERX<05@[301B:``0F2/;05@W2@1C90P0Db/:05XY2@1K:`X0FBX>05X[301L:`T0Fbd<05/]
2`1L:`/0EBP805@W201F9PP0E2H705DX1`1I;0/0EBX<05LX2@1J;PX2060`300905l[2@1Q;`X0HBh:
06<^2P1U<``0I3D<05`/2@1N:@T0HRd90080HR`802L0H3<806<[201N:PL0H2X8060[201P;@X0FBT8
05PZ201D9PH0Da`604lN1P1<80D0A1/504<M1@127@H0@QT403lK1@1470L0AAl704/N1`1;80H0Aah5
04DL1@1170P0?Q/704<O1`198@T0BbD804TU1`1:8`P0B28804LR1@178@D0B24604/L101>7PH0C1l6
04PL1@127@@00P1160H09`116P<0@1X2048H0P1060<0@QT2044N0P116P80@AL1044D0@0o4`40@AH2
03lI0`157`D0B1l704<O1@116P@0?1L403/I100i5`@0>QL503PH100n60<0?1d503/L1P127@L0@1l8
03lG100c5@80<Q<102/A0P0U3P80:`T002d;000f4040=aH203LF0@0^4`40:`d102@900020246000W
01`4000L1`008PL00247000M20008@P001l9000Q3@009@/002/?000^3`40;@h201l<000N200070T1
01`9000Q3@809Q4202DB100V4`@0:18402<C1@0R4PD08A8501l@100M30<06`P201/80@0L2`807Pd3
01l>100P4@D08Q@502@J200W7PX09Qh:02TO2`0Y7@X0:1`900809Qd902L09ad:02XO200Z80X0:A`:
02/K1`0[5`D0:aP6030J200j7P/0?B0803LN2@0b6P@0;a<302X@0@0[4`80:1H402XH100V4`<08A<2
01`9000G10003P0000P0000:0000400001@2000G20006@X001T6000K1P006@L001L5000D10004`H0
01D60@0E0P0030<000/100070@000P0;0@000`0>00002`0000X0000200X1000I00h3000=0P004@80
0103000A10005@D101@50P0D10003@8000T2000600000`80008000030000100000@1000700002@40
0102000@0`006@@001/5000H1`004@H000h100020142000700`2000;0P002`8001@1000F10005`<0
01X6000201d:0@08020<0@0K304070P101H6000>0P002@0000@10003000300000005004000020000
0P000080000100000P00000200400004000000020000104000D200801@400P040@000`0200000@00
0000000M000000`0oooo000:0?ooo`0D028iQ00Y@7l0;4F8035BO`0ZBGh06Bj200XDR@034I`02Rj2
00i1M`0IBG407TQ_01i1I`0K<gD07R:602@MQ`0R78@071ZF024_VP0W@Wh202Q6JP0W02M5J00_CET0
=UA>03I=D@0/=700;bJ003DWO@0d;Gd0=4Ed0354EP0^?UP0;CM`03D]J`0h;W@0>D]e02`kP00W;h`0
<RR603doI@0eC6L0;Dik03M1N015EF<0BVAD04MYD01EKdH0FWA206=c@01UJcH0I6Lc06AL;P1SBB80
IDLN06]C901^DRD0JdHM06e87P1/B1d0JdPN0080JdXL02L0JTTM06U67@1W@aX0ID4H068h401K=100
GSHA060e4P1N=Pl0FBl<05X_2`1J<0`0FC0:058Y1`1=8`H0Db@6058S1P1@8`H0D2H:04h]2@1C;0`0
DbX=05L]3@1E;Pd0EB/<054V201;:0H0C2H904`U201<8PH0BRH804PX2P1;:0T0BRP:04`W2P1?9PX0
BbL:050W301A:@/00P1=:`T07019:@/0D2P;058Z2P1C:@/0ERX<05@[301B:``0F2/;05@W2@1C90P0
Db/:05XY2@1K:`X0FBX>05X[301L:`T0Fbd<05/]2`1L:`/0EBP805@W201F9PP0E2H705DX1`1I;0/0
EBX<05LX2@1J;PX2060`300905l[2@1Q;`X0HBh:06<^2P1U<``0I3D<05`/2@1N:@T0HRd90080HR`8
02L0H3<806<[201N:PL0H2X8060[201P;@X0FBT805PZ201D9PH0Da`604lN1P1<80D0A1/504<M1@12
7@H0@QT403lK1@1470L0AAl704/N1`1;80H0Aah504DL1@1170P0?Q/704<O1`198@T0BbD804TU1`1:
8`P0B28804LR1@178@D0B24604/L101>7PH0C1l604PL1@127@@00P1160H09`116P<0@1X2048H0P10
60<0@QT2044N0P116P80@AL1044D0@0o4`40@AH203lI0`157`D0B1l704<O1@116P@0?1L403/I100i
5`@0>QL503PH100n60<0?1d503/L1P127@L0@1l803lG100c5@80<Q<102/A0P0U3P80:`T002d;000f
4040=aH203LF0@0^4`40:`d102@900020246000W01`4000L1`008PL00247000M20008@P001l9000Q
3@009@/002/?000^3`40;@h201l<000N200070T101`9000Q3@809Q4202DB100V4`@0:18402<C1@0R
4PD08A8501l@100M30<06`P201/80@0L2`807Pd301l>100P4@D08Q@502@J200W7PX09Qh:02TO2`0Y
7@X0:1`900809Qd902L09ad:02XO200Z80X0:A`:02/K1`0[5`D0:aP6030J200j7P/0?B0803LN2@0b
6P@0;a<302X@0@0[4`80:1H402XH100V4`<08A<201`9000G10003P0000P0000:0000400001@2000G
20006@X001T6000K1P006@L001L5000D10004`H001D60@0E0P0030<000/100070@000P0;0@000`0>
00002`0000X0000200X1000I00h3000=0P004@800103000A10005@D101@50P0D10003@8000T20006
00000`80008000030000100000@1000700002@400102000@0`006@@001/5000H1`004@H000h10002
0142000700`2000;0P002`8001@1000F10005`<001X6000201d:0@08020<0@0K304070P101H6000>
0P002@0000@100030003000000050040000200000P000080000100000P0000020040000400000002
0000104000D200801@400P040@000`0200000@000000000M000000`0oooo000:0?ooo`0D02dnSP0X
Ahd09e2;02IAR00QBWl06d=k00XIQ@063g<03BN001A6Q@0H@6/06D9/01Y2K@0E=Wd05bN:01hNTP0R
89/09QfA02P]S`0^?fX2024`Q00W02Y4LP0_@5T0<dmB03YEE00]@fd0:RZ0034UQP0m;8T0>Cf102hd
N@0/@G<0:cae02l]P@0i<HH0>Tal02XiQ@0W?HX0<C]k04E>GP0lCe`0;EQa039;MP16Fed0AfE;04QY
AP1GJD00GVm0069b?@1SJcD0HV/e06=S<01UBb@0HDDN06=;8@1VCB80ID8N06A1601V?QH0I3XD0080
Hc/C02L0GcTB05hf4`1N=Q@0GcTE05lh4`1N=140FcHA05lh4P1Q=a80GS8=05L^3P1G;Pd0Ebd=058V
2@1<8@D0D1l5050P1@1=8@H0BR4804`W301A:0X0DRP:05@W2`1E:`X0D2T;04dV1`1=8`P0CbD:04hZ
2P1?:P/0D2T:04hZ2P1?:`X0Cbh:05D_301H<@`0ERl>05@a3`1F<A000P1E;Ph09`1C;P`0F2/=058]
2@1E;0/0Db/<058Y2`1D:PX0E2T905DY201E:PL0FRh905`]2`1I:`X0ER/805H/2@1F:@X0G2`:05T^
2P1D:@T0E2P705@T1`1?8PD0DB0504lR1@1C8PH0Cb<704lT1P1E:@L0F2`605X/201L:PL0G2X905h]
1`1P:`X0Hbh;06D^2@1R;@L0Gbd806<_2@0206@_2`0W06Da2P1S<PT0H3<:060_201S<PT0HS4705h[
1`1K9`L0DRH604dM1@1;6P<0AAX204DF100k6P@0?1X503dF0`0i50@0?QT404HN10187`H0CR@804XM
1`106`H0>A/603`L1`147@H0BbD904dU2@1<8`T0CR8804`R201>90H0CB8404`Q1P1;7PD0BQ`504DL
1P106`D0@aP30080@AT402L0?aH304<F0P135000?1D103XD0P0k50<0?QL203dD0P0g4@40>Pl2040C
0`0m6@@0@1`204@H0P0o7@@0@A/3048K1@1260H0>aH403TG100k5@<0>AH303@G0`0f6@D0>ad7040N
200j6PL0=QD3034B0P0b4`80;a4102/@0@0Z4@80=14203<B000`5000:A4002P;000V2@400P0U2P40
9`0R1`00:0/002T:0@0R30408@T002@:000T30008``002H<000W3`8090d001X8000O1`007@X101l:
0@0P3000910102@A0`0T40D09a0502@?1@0U40D08@l501l?100L3P@06`/201/:0P0M2P<06`d401l?
100M40D07Pl5020C1@0R50D09QP902DI200U6PT0:1X902DJ2@0202DI2@0W02DJ1`0V6`P09Qh802LM
2@0U5`H09AD502DD100Z5PD0<QX603@J1@0c60D0;QH402dA0`0V3@409``102D@0@0S40<09Pl3024?
0`0J2@804PH100h3000:00001P0000X1000?0`0050H101@70@0F1@005@8001H3000F1@0050H001D7
000K1`406@X101@30@0?0P403P8000802`<001803@4000X2000=0`0040<000h3000?0`004PD10146
0@0F20806PX2024=0`0S3`<080d201X:0@0B1@003@8000H000040002008000800`0001402@4000l3
000A0`0050@001T5000I1`005`H001D1000B0@003@4000X1000900001@0000H1000:0@003P800143
000201L6000901P9000H20005PT001@9000=0`002@8000<0000100000P0000800@0000@0100000<0
000300000`000P0100000`0000000@0000400002000000040040000200000`00004000800@408000
000<0?ooo`002P3oool0500Z@XX0:Tn?02A?S`0LBXl074]n021>O@0?7eX030md00TIY00F?X<06CMc
01dlM@0L?W404c60018YR`0I99H07bRK028OTP0Y9hT0;cI`0P0N99@09`0Y>gP0;3if02a9L`0ZBV00
9d5f02@^P`0]9H/0=bN:03TcQP0^;8l0:Sn202Q0P00]=HH0=3>603Q<OP0[=h/0:DN502m:N010BUX0
>E1R039JL00bD780AEeE04]TA01?ID00F6Hl05m^?01PLSd0HVlk06Aa>P1TJc@0IeDV06=88@1VB1h0
I4PO06A16P1V>aH0H3DB05hb3@0205Xa4@0W05Xg401L=Q00GC<A05Xf4`1I=a<0F3<?05Xa3@1O<a40
HCD?05``3@1H;@d0ERd;058[2`1:9@H0Bah604/P1`1;8@H0BB0704TM1@1;80T0C28704lV201?:0P0
D2@704hW1`1?9`T0CbP9050Z2P1B:`d0EB`<05D`2`1D;`X0DB/905P/2`1G;@d0E30>05Hc3`1E=@d0
ES<=0080F34=02L0ERd=05D/3@1B:PX0CbT9054X2P1B9`P0DB<705<X1`1D:@P0FB`805h]3@1G:`d0
DBT9050X201D9`H0DbT705P[2P1E:`X0EBL8054U1@1A80D0CQh404XM0`1:70@0D1l5058P1`1B7`D0
Db@705HT2@1K:0L0EbD605TX2P1K:0L0Fb/8060]201Q<0T0H2h8060Z2@1R<PP00P1R=0T09`1R<@X0
HC4905da2P1Q;``0HS0;064c2@1O;0T0FRL:05DV1P1<80<0BA`3040E0P0m5@40?1L203dJ0P0j6P<0
>A8203XH0`137PD0BB0604HP1@176`D0?1@503PG100o6@@0AAd504`U201@9PP0D2H7050X1`1A9PX0
D2P7050W1`1<90P0Bb4604TL1@126@D0@1X404<H0`02040J1@0W04DL1P0l6@<0?a<103PB0`0b4000
;Q8203DD0P0e4P<0=1<203<@0@0g50<0>QT203/F0@0j5@40=aD1040G0`0j6@<0@1X403`G100h4`<0
=A<1034C0`0c4080=a@503HG1P0h6`L0=aL503@F0P0b5040=AH1030G0P0^4@009@l102P>000X3@00
:0X001l:000R2@008`X100809@/100`09@X102LA0@0[4@409`l002H=000R2`0090`002<>000U3@40
:@l401h:0P0I2P4201`9000I02@;0P0R3@<08@d302<>1@0S40@08Pl502<@1@0R40D080d401l>100O
3@<07P`301h>1@0N3@<07`h4020@1@0L3P@06``401h>100M3PD07`l5028A1`0T4`H08Q@6020C1P02
01hC1P0?01hD1@0Q50D081H6024C1@0Q4@@07`h102@A0@0V4@<09Q4402PB0`0W4P80:A0302DA0@0Q
30406`T000806@P100T07`P1020<0@0K2P4050H10145000;0`00200000T0000;1@000P0?1P002`0@
10004@800180000B0`005@8001L50@0L208070T201/80P0H1`805`@200805@@102L040@101030@0?
0`404P<101840@0D0`404`<001H60@0J2@807PX202H?1@0Z50D0:A@602DB1@0P3P806@T201440009
0P001P0000D000030000100000H0000:0P00408001@5000H1P0070P001d80@0E20404`<100/20006
0000104000@0000200001@0000L2000:0`000`0?0`001`0C1P005@H001860@0?0`003@4000L00001
00000P0000001`0100000P4000<100030@001@4000@100030000:`00000<0?ooo`002P3oool0500[
AH80;4B;02E4S`0K@8l06DAm01<XK`0H:UT04A][010NV@0N<XP0936<02<kQ`0J>7D042^1010[SP0F
:iH072jK01lNUP0Z88/0:BQg0P0S:8T09`0[=Y<0>4:80315QP0V>gD09Cio02<dP@0X9h@0;bB<03D/
P@0^;8P0;3j>02a7SP0X?980;3F;03E2M@0]>h@0:U2202iCN@0hAW80>eEZ03QNI@0jF6D0CEi:04mN
>P1>GS/0EF4l05i[>P1OLS`0H6ll06=^>P1UIc<0IE8W0695801O?Q`0HD0J060m5`1L=a<0Fc4C05T^
3@0205D`3`0P05Pd401J=A00F3@=05Ld4@1M=A<0Fc8?05D]301E;0`0F2h:05L[3@1E:PX0CbP904`T
2P1880L0AAl904XR201:8`T0Aal904XN2P1?8PL0CR@704hV1P1;90D0B1d904XS201::@P0CRH:054Y
2P1E:PX0Ebh<05H]301A;0/2050Z2@05050W2@1A:P/0E2l=058c301D<0d00P1H<0d09`1G:`/0DB/9
04hY1`1<8`X0CRD8050S1P1?8PP0D2L7054V2@1G:@`0Ebh=05H_3@1@:PX0DRD8058W2P1@9PP0DbD7
04dS1P196`@0Aad304XP0`157P<0B1l204hO101A80H0DB4905<S201E9@L0ER@705DV1P1E90H0FBL7
05PZ201K;PL0GBd805l]2P1O;0/0H2d:05d_300205`b2`0W05`]2`1K;P/0GC4:05`]2P1N:``0GBX<
05XZ2P1F:@L0DBD504hP10196`@0AAH203/E0`1060D0@1X303dF0`0i5040>Q<303lE0`115@<0?1H4
03XC0`0g4@40=A<003/E0P1470D0C28504TT1@1<90L0DRD705@U2P1A;0T0CbL704`R1`1<8@D0@ad5
044L0`0o70@0@A`50080?Ql602L0?al8040L100k5080=Pd3030=000Y3P40;@l2034B0`0`4`40<a@2
03TB0P0m5`80>AD103HA0@0_4P40=a4003LE000k5@<0<A81030A0@0c3`40;Q0102`@0P0a4`@0<aL4
03XJ1@0k5`@0=a<103<C0@0c4P80;a4102d;000V30009`T001l8000R1P0080H001h5000P2@000P0Q
2`409`0U3P80;18202/@0P0U40409@`002@<000T3P408`l3020=0`0P2`<07PP101`8000K3P807``1
02@=0P0S3`408@`202D@100S3`@08Q04024=1@0S40@07Pl4020=100T3@<08@`3020=100J3P@07@l4
01d>100F2`805@T201@90@0I2P8070X101h>0`0R3`<08A0401l>1@0201l@1P0:01/>1@0H30@060h4
01H<0P0I30405P/101X:0@0J2@4070X301X90P<06`/101X060L101H3000@0`0050D101D70@0H2@40
6`X201X90P0J2P005@D000l2000<0@002`8000d5000>1P0030<000d2000A100040D001@60@0E0`80
5`@201X80P0P2`<070/301`90`805`L300D05@H201@60P0E1@804PL201D60@0201<50@0P01D70@0L
2@808P/302<A200^50P0<AT8038H2P0/50H09A0301`70`0B10402P4000@0000500001P0000D00007
0@0040<001L60@0M20408`T1028;0P0N1P406@@100l20@090P001`0000T000040@000`4000<00008
000300L0000600X1000<0P004@<000l4000;0P0020000P0200002@0100000P000081000400001`00
00H100060P001@400040000Z000000`0oooo000:0?ooo`0D039<J@0bAW@0:4>201TdT@0?:V`0639U
01@[J@0?8GH062FA02D^U@0X;i<09CN201hgI@0C<V004CEf01HfR00J=Xd06bbA02<SUP0U8I0202h_
S00W038gS@0h>XT0=Cn702HaT@0U?HD09d5d02XhMP0Z:XD0;bR7034^S@0`@8d0:dJ?0292T`0T>I40
<C:402i0QP0/FGL0<61]03IDL00kHFD0?FUJ03mSD`1BGCh0EETa059I>01@Fc/0G6Di065/>@1RJCL0
IVHc06AO;P1QCb@0GclI05`i5@1L=aD0FSTA05Xh5@1I=a80ES0?0080F38?02L0FS<?05Pd3P1F;Pd0
F2`>05L/3@1I;@d0EBd;05<[2P1E:`T0DbT804hX2019:0L0AR<804LR2@1880X0B2@:04TT2@1:9`X0
CBL9050T201>9@/0B2D904HL1@137PD0BbH;04/V301:9`T0C2@704hT201A:0T0DBD;04lX2`1B:0`0
CBH804XT1`1;9@T0DBT;058/2`1C;0/00P1@9`T09`1@9@T0CB<904/T201=90T0BR<704dS201>8`L0
CR@7050V2@1D:PX0DC0>058Y301A9P/0CRH;04lZ2`1B8`P0Bb4604PH10165P40@aL204XK10186`<0
C1h204lT101C8`D0ER@505<W1P1F:@T0ERH905@V1P1L:@/0FB`805`Y2P1N;@/0GB`:05d_2P1P<0/0
GRh;05`a3@0205X_3P0W05//3@1J;Pd0FBh;05L_2P1G:@/0EBT:058X201E9`H0Cb@504XR1@1980D0
AQ/5044I1@146PL0A1X603lH100j5@40=QD2034A100c40<0=18203@A0P0a4@40=@l003TC0@0m6`@0
@al404HP101780D0BB4704/P201=90P0BR0704HQ1`157PL0@AT503lF100l5P@0?AX40080?Q/602L0
?a/603TG1@0c4`@0<Ph202d<0P0[2@40:``202`>0@0^4P@0;a@203@E0P0g4`80<a82030=000[2`00
;0h102h=000`4040;0d102d90@0[3@40;Ph0030A000a5P80>AP403dI100i6`<0=aP3034C100_3P00
:Pd002T:000T1`008@X001l:0@0M2P0080/2020:0@0T3@400P0W3@<09`0U40809a<202hB0`0V3`00
9@/002@9000R30408@d201`90P0L1`406PX001T90@0K30@090l302P@100W4`@09a8302DC100Q40@0
7@h301h;100M3P<07`d3024>0`0O30@080d401l<0`0J2`@06@`501T=1@0E2P804`L100h4000C2@40
60X101X:000L2`807Pd201h>0`0201l<0`0W01T:0`0G2@8050P1010:0@0C1`0040L00145000=1@00
3PH201080@0B20405PD001P5000H10004`<00145000?10004PL001L60P0J2@406``101h:0@0G1`00
4`8000d4000;0P002@D000d4000>0`0040<00145000E1@004PL101830P0A1P806PL201h<0P0M3@80
7`T3008070L301D06`L301L80P0I20<06@P301L70P0D1P8050D201X60@0M2@4090X202T=1P0_4`L0
=aT;03LL2`0d6P/0<AD702H@0`0M1P805`@100d100090@000P0600002`070@00308101030@0G1@<0
7@H202870P0P2@407@H101830@0A0@002@4000801P4000<010400080000300000P03000020060000
1`4000`2000>0`003@@000/200070@001000100200001P0300001@0000H100070@001@40008002X0
0000303oool000X0oooo01@0>EUZ03MJJ`0VB8T04b^J00`UM`0B;VL02Rb200h[T`0L<hl07cBG02</
UP0X?7P08cYJ01LdH`0H@GD0745h01/iN00J=h@08BfA02HZT`80;bf;02L0<c6>03PbRP0k>g80;Rj9
02`lQP0]CWL0;DMZ02HfO`0[;hT0<S::038hSP0[B9009Df?02E9R@0[?hL0<4Yo02mOKP0_J6P0=6AW
03e[G@10L5@0AFa9051P>P1BFC@0E5`j05AM?@1LH3H0HVLe06MW=@1UHc@0IET/06E=8P1P@1P0EcTD
05Dh4P1J>140FS@C05Xb401H;Pd00P1J<0h09`1N=Q40F2h?05@]301B:``0DR`<058/3@1?:P/0D2X9
04lX301@:0T0C2@804XQ20178PT0BbD:04/X2P1<:P/0BR`>04h]3@1@9PX0CbL=04/V30168`P0@Ql5
04<O1P199`X0BbX;04XR201880L0ABD804/T2P189@T0BbD;04/V2`1;9@T0Bb4804/T2@1<9PT0CBP9
04hU2P0204TS2@0W04LS1`188PT0B2@804TS1`178`P0C28:04/T1`198`D0BR<604hX2@1>:``0CBL:
04XT201>9@/0CBL<04TQ20166`<0@aL203dF0P105`<0BaX504hK1P1<8@D0Db<505LV1`1F8`H0F2P7
05P[2`1G:Pd0Eb`<05L`301G<@X0F2/:05T]2P1O<0/0HC8<060a3`1L;`/0FR`:0080F2/:02L0F2X8
05P_2P1I;PX0Ebd905HY2`1F;`X0E2/<05<Z2@1@:0P0CRT704/V1P1;9@T0BR<804XR20177`T0@AP4
03`E0P0c40<0;`l402l@0P0_4@80:a8202h@0@0d5080>1@203XD00106080@QL2048J0`1170D0AQ`5
04DO1@1070D0@1X503dF100i5@D0=A4503T@100i4P<00P0b4P@01P0a4`D0<Q84030>0`0`3`<0;0h2
02l;0P80;@h301l0<Pl402hA0P0c5080>A43034B0@0_3`40:`X002X:000]2P00;PX002`;000X3P00
;10002l?0@0b5080=aH203PG0`0i6@<0=1L2034B0P0]3@409@/001l<000S2`008@X002890@0Q3P80
8`d302@A0P0S3P80:@l40080:Q0202L09`h202P=0P0Z3P809Pd202H;0@0T2@807`X101/:0P0J1000
6@P001P:000L3@<080h4024>0`0V50H0:QD702XG1`0[5PH0918401d>100G3@<060/301`=100L30<0
7@/401d=100J3@D06@d601T>1@0H3@@050T20186000@0`004`P101H60@0G20406`/101X=0@0L3@80
0P0K2`809`0H2@805@T201@7000A2@0040H000h4000;0`002`@000X6000:1`403`H10186000B1@00
4`H001@6000D20404@<00182000A0`005@@101H5000E2@005PH001H3000B0`003P<000X5000:0`00
304000h3000D1`005PL101<5000B104040H201H50P0J1`806`X201h90P0201`70`0F01T60`0J20<0
70X201X80P0H1`805`L201L60P0L1@406`D101h;000V3`80:`l503LD1`0j60P0>1P703DF1P0^4@@0
90h101h80@0F1@403`<000T10080200000l01`4000X2000?0`005PD101L60@0M1`407PH101/70@0D
1@004@<000X200060@001@000080000100000P0300002@050@001`@000P4000<1P003@D000`10008
0@001P400080000300400006008000030@00100000H0000200000@00:P00000<0?ooo`002P3oool0
500fIg@0:V>001M2VP032iP00`Un00TRN009<hD03cN701HkQ@0K>Xd07C>?02PoM00S=6`0732001i1
R`0K@g/063Qh01dnP`0R>HP09CF@0P0Y:H/09`0e<8D0=C6703PgM00b<hX0=DF6039=M00ZAGD0;4J1
02/lQ@0^=hd0;cV@031?R00cGG`0<V1d035ILP0hEfd0=6AV035]H@0lKUh0AfmA04]`BP1>KD@0EV@m
05MN>P1FHT00F61006=P=P1RIS<0If@b06=O<P1WEbP0HTdQ06946@1J?AL0FSTD05he501O>180Fc<?
05LZ2P0205D`300W05P_3P1G;@`0D2X;04lX301@:0`0DB`:058X301B:0P0CbH8054U20198@T0BB48
04`W2P1B:``0CRd>04/^3`1=;@l0C2/=04PY2P189`/0B2@<04LR2@168`D0B2@804hX2@1?:@X0C2P:
04LT2@149`X0A28904`T2P199@T0AbD804XT2P198PT0Ab4704XS1`179`P0Ab080080Ab8702L0B287
04@T2@199@T0BB<804PR1`1;9`/0CBD;04/T2@1780H0BR0604@Q1`108PL0A1h604PP2@188`T0@ad5
03XI1@0l5@<0>1D3048F1@1=6@H0CB07050P1`1E9@P0DRL705<U201F9`P0ERX;05TZ301H:``0Ebh<
05L]3@1G:PX0Eb`:05`_2P1O<0X0GBd:05LY2@1E:0H00P1F90D09P1B8`@0DbP705<]301B;@T0E30=
05@d3`1F;Ph0DB`:05@Y201A:@P0D2H804dV1`1;8`P0AQd404LJ10105`@0?18203@B0P0`3`@0;Q43
02hA0P0b3`80=10203TC0P0n4P80>a8203PF0`0j5@@0?Q@3040F0`0l60<0?1/303/I0`0g5@<0<A43
02`A1@0`30<0<@h30`0_3`<00`0^4@80;a0302l?0`0202lB0`0R038@0`0a4`<0;Q0202hC1@0b4P<0
<AD103LE0`0e5080;Q8202l=0@0/40<0;0d2030?000_3000;18002dA0@0c50<0=QH203HF0`0h5P80
<a@202T=000W2`008PP001h9000L20408@P001h:000S2P008@/102H<0@0S30808``102D>0P808`h1
00d09@h0020>0@0Q30008`X00249000R30407@X101/9000H1`0060L101d<0@0P3P<08@l400808a83
01P0:1@402`G1@0/6@P09Q85020>1@0N3P@06@`301T;0`0I3@@07@h601`?1`0J40H06@l501d>1P0J
2`D06PT30188000@10003`D101H50@0F1`8060X101T<0`0H30@201P:0`0N01L90@0F204050L00188
000B1P003@L100d5000;0`002P@000/4000A1@004@H001090@0I2P8070h201d>0P0H2P804@H00104
000@0P004@4001<4000D0`0050D00184000<0P002`8000`1000>0@0030800P0E1@001`0A1@004@80
00h4000D1@0060D001T80P0K1`400P0H1`007P0I1`8060H101P80P0K1`8060L201L80P0G2@805PL1
01X4000K1`008PT102T<0`0_4@@0=1<503LG1P0d4`@0=1D602hA100[3`<09Pd201/80@0C1P003`@0
00X300060@001`4000/0000>000050<001X6008070T000L07PT001/7000C1P003P4000D100020000
000000800P0000T00`0000H200070`0030D000/300080`001@8000D0000300000P0100001@000000
0@000080000300000P0000800@00:P00000<0?ooo`002P3oool0500]JGh06UV?0045_`011;D000BZ
00HRU@08<80033Ai018kP@0G?HP06cZ@02@gO`0V=X@09S^;02@oR@0P?8D08T230253P`0P>XT08Cf=
0P0T>8H0500/=h00;c::03HmO@0iBgX0>51h03==P00bCh@0;4Z602PoR00[@Hd0;D:=03MFP@0kJ780
>F]X03MYI@0iHFL0>6IU03e]F@18Kdl0DVe60P1KK4004@1JJ400EFE005=U@01KHC`0HEXb06AK;@1S
Fbh0H5X^05iD:P1ODRD0GdPM06505`1K>A<0GcLD064h5@1M=Q40ERh=0080F2h>02L0FS0?05</301B
;0/0DBL:058W2`1A:0/0DBP:050W2@1B9`X0CRL804`S2@1;9@P0DR/;05D]3@1A;@d0D2X>04l/3P1>
;`d0C2P>04`S2`1=9@X0BbH704TV1`1=90P0C2T:050[2`1B:P`0C2H;04LS2@1690P0B2D804LQ2017
7`L0AR4604@N1`167@T0@al8044O20117`T00P138PP01@1790P0AB8804XR2@1:8PP0BR@90080AbD9
00H0AAl904DK1`126`L0@ad503hL1@0l6`H2044M1`0H03`F1@0i4`@0>QH503XF10175`D0Ab0804LT
201<8`/0E2H804dV201=8PP0DRD604dU1P1B9PH0DbL7050W1`1?9PL0CbH8054V201C:PP0EBT805@U
1`1>9PD0Bb040P1:7PD0201<80D0CB@704hT2@1A9@P0CbX<050_3`1A;@/0DRP90P1@9@L0601:90H0
AQh504PK1@155`D0@QH303`E0`0i5P40>18203@=0@0`3P80<Q4203@B100h40<0?1H5040D0@0j5P40
=aL303DF0`0h5@@0>1<203TA0@0j4P80>Q0203P?0`80<0l500<0:0/202X?1@0Y3P<00P0/2P<09`0/
3P80;a4203<E0`0_5`D0>1P503@E100c5@<0<0h203<D0@0f5040=1D103<D0P0d4P80<A41038=000^
4@80<a8203DF0`0a5080<aL403<D100h50@0<QD203<E000a4`00;0d002L8000Q1P008PP1020:0@0R
2`809P/002@=0@0P30008P/001h9000N2P0080L002080@02024;000302090@0N2@0080P0008080T0
00<080`001d:000H1P000P0I1`007@0P30408A0202<@100U3P@08Q0102<=0P0S3P@09A4602<B1@0T
40D09@h501`=1@0N3@<07`l4024D1P0M4PL07a<701`C1`0M4PH06a0501/;100F20004@D001450@0D
1@404@P201H;0`0H2`<06``400806@X202L05P/101D8000D1`004`L001070P0A2@8040P100h4000<
100030D000`3000?100040T101H;0P0N4@<0814401/>0P0H30404PL101<5000>10003`D00186000A
1P403P@000T300090@002`4000d4000@1@0040800106000@2P0040D00144000B0@005@4001L2000I
1@000P0H10006@0F10005@@001<4000G1@404PD201D70P0F1`405`L10183000@0`006@<00207000T
2@80:@h302h>0`0a4P@0<1<502hC100^50@0:Q4302X@0`0O2P405@L00185000;10000P0;0@00300>
0@0050D001/8000N20007`d0024A0P0T4P408`d001X9000B0`002@0000<000800P000P0300002005
0@001`8000X200080@001@0000<000020@000@001@0000000`01000000000000000Z000000`0oooo
000:0?ooo`0D01aGTP0@@i8000?30005_`001Kd02B:O00h`R`0@=hX06D6?01PmS`0K@9408C^902Dn
RP0U?hL09C^702TnS00]A8<0:45l028mR@0QAY020294Q`0W02M1O`0`Ah<0=E9n03QJL`0jDg80>EIl
03YFOP0gC880<dB802m7S00^CX/0>5il03eZKP0oKfD0?W1R03i[HP11JEh0BF];059[A01FJD00FFTl
05UY@01KJ400FVM005YU?01NGST0HeD]069B:@1PEBT0H5P^069H:@1UERL0I4TN064m5@1L<Q40FcDA
05de4`1L=a40Ec8=00<0F2hA02H0Dbd=05</2`1?:0T0BbH:05<T3P1<:`/0DR`904hU301A9PX0BbP:
050Y201C:`P0E2h;05D]2`1@:`/0D2T<054]3P1>:Pd0CBT;04dX301=:0/0CR@;04hY201;:`X0DRT:
04hX201<:0T0BB@804XS1P1780P0@b4:044R20137`L0?Q/603`J1P1170H0?1`503lN1`80A1d802L0
Ab<904DQ2@168PP0@Ql504<P1@1380H0@al604<M1@0n6`L0>AL503/H1@0l5`D0?AX303lG1`0n6PH0
>QL603PE1@0n5`H0?aT5048H1`187PP0AQl704LQ1`1:90L0Bb8704PN201;8PL0C28804LQ1`1880D0
AB4904TN201?8PP0CbD804lQ2@1<80H0AAd504<O1P187@H00P137PD09`167@D0BAl704HR20147@H0
?Ql704LV201:90P0Bb<604PS1@167PH0@aX6044E100m50@0>1<403/D0`0i4`<0=Q8103<@0`0b3P40
<`d103XC0P0n60D0?AL403lH1@0n5@@0?aH303XG1@0h5@@0=1<3038@0@0b3P00=0d003H@0@0i4`40
<a44034?0P0]4@80:Q4202X;0@02030;0@0W02T<0@0^4`40=1D203HI1@0e5`@0>1P403PC0`0c5040
<a8103<?000]4@40<0h2030B0@0d5@00>14003TA0`0d5`@0>1P603TI1P0i70L0?aD503PB0@0`4`40
;Q8002/C0P0X3`009`T002P;0@0Y40@0:Pl402`E1@0]4@@09@d301h=0@0Q2P007@T001`8000P1`00
70/000805`P000P060P001h;000L30006P/001`6000M2@006`X001L700806PP001d07`T001l?0@0R
3@<08`h302<=0@0M2P406Pd201h?0`0P40<0910502D@1@0Q40@08Pl402@@1@0S4PD081<601lA1P0P
4PH0810501`@1@0I30<05PP00107000>1@4040D101070@0B20<04`T201D:0P0201D80P0W01<90@0F
20405`H001H7000F2P805@/201@:0@0>1`003@<000X4000;0`003@D001480@0H30806a0601lC1P0O
4PD07@d301T<0P0G1`403`<000h4000B1P004`P200d300090`002`4000d3000?10003`H00103000A
0`004PT001<8000A10005P4001<3000D0`004P<000804`8002L04@<00102000B0@003@8000l2000=
0`0030D000h2000<0@0020800144000D0P006@@002090@0Y3@40;0l102dB0P0]4P<0<1L503DI1P0c
6@D0<1@402LB0P0O3`406@T001<7000>1P0040@001D8000J200080d1028C100Z5P@0;aP402XG0P0T
4`407@d001D6000<0P000P080P001@050@00104000<1000300001@4000801@0000@0100000<00002
00000@00<@00000<0?ooo`002P3oool0500==jP000O20003``001kl000Ng00dSXP0E>9/07TJ?01]4
S00K?h/07dJA01i5T00PAHX08dB202I2N`0Z@Gl0;T2002loQ`0ZB8P09T^:0P0YCHH09`0]DH<0<ej0
03MUMP0iH780?Eif049RMP0nFW/0>dn203I:Q`0cBhP0=eR003eXM@13L6P0B75L04QaEP18LED0CFm>
05=[A01IId00FfM005eV>`1MIS`0GfU0061Y>`1PI3X0HEhf069E;P1RDbL0He@W06=C:@1SEbP0IULV
06987@1O>1@0FS4A050^3@1H<A00GC@A05@`3`0205<]300W05@Y301C:@`0CRL:04TR201;7`/0Bb@:
04`W2P1:90/0Bb8:04/V201;9PT0B2H904/V2P1@9``0DRT;04hW2@1:9PT0CRP=04l]2`1@:@/0D2T:
050W2@1<8`T0ARD504dT1`1>9PX0CRL804XW201=9PP0AbL904<R1@137PP0@b4803hP1`0k7@H0=aX4
03XI10107`L0A2070080BB<802L0BbP904TU1P1680L0Aah804@L1@146P@0AQd504<L1@0j6PD0?1P5
03XF1@0j4`<0>1@303LD1@0j60@0>QT403XI1@0n6@@0?AT603lG1@126@@0?AT5048K1`197PP0AQd6
04<O1`148@H0A1h5048Q1`0o7@P0@1d704PN1P1<8`L0Bb8604DO1`126`D0?a/503dJ1@0n6@@00P0n
6`H09`116`L0?ah7040N1`0m60D0?QP603hL1@1170H0@ah7040M1P0j5`@0>18303TB0`0g50@0=Q83
03D@0`0g3P80<Ph103<=0P0d40<0=Q@203TH0`0n6`@0?AT303`H100f60D0>AH403`G1@0i5`@0<Q@2
030@0@0^3`40:``002l>000c4P<0<A0202h=0`0`3`80;a0102/>0@0202T=0P0W02P:0P0[3`80<Q43
03DF100i50D0=QD503DE0@0e4`40<`h002l?000_3@00;A4002hC0P0b5`80?1@203/I0`0i5@80>AP4
03TJ1@0k6PD0>QT403LG0P0g5080=QH2034C0P0^3P40:Pd202dD100`6@D0;aT503<G1P0T4@@07@T2
01/8000O30006``0024:0@0P2@006`L000806@L002L05@T001`;000N2`006`T001P9000J2@0070L1
01T70@0H20006PL001X8000K20007@T00289000P30408``201T:0P0G2P806Ph3028B1@0S4`H08Q46
02<@1@0R3`@08Q04024?1@0Q4PD091@7024@0`0S3PD070/301H:0@0B1`403`L101070`0=1P404@L1
01470P0D1`400P0C1`409`0E200060X101L8000K2@006`X201X=0P0F2P8050L000h5000=0`002P@0
00d5000>20005@`301X?1@0L4`D07Q<401lC100L3@405PL100l4000?0`0040D00144000@1@003040
00d0000=0P004@@00105000=1@0040<001@4000F200050L001D50@0@0`004@8000d3000201020007
0103000:0P002@0000P000060@001@4000P0000200P1000N00L2000<0`003PD00185000G1@008@L1
02H9000[3040;Q@303@H1@0h70D0>Ad503XM1@0h6PD0;QP402LC100R30406@T101D80@0F2P4060/1
01`=0P0V4@@0;1P502hL1`0c70H0;aX602XF0P0O40805PX10P0A1@402`0:0`001@4000D100020000
0`0000D000050P000`40008000010@000@0003400000303oool000X0oooo0P000<H04P000l800@Zg
004@[@0@;Id07TJ?0219R`0QAXX08TN8021;SP0OC8h08d^702Y<P@0VBGL0:DMh02e8P00aCGl0;Tf2
02m>R080=5]o02L0=fQj03Y_M@0lKW<0?fi`04E/L@19Hg<0A5]e04=JN@0nFGX0?eei03iYL`16LVH0
CW=J05=dC`1?Ld`0DG5805I`@@1MJD00GV8g061T>01TI3@0HfDi06=Y?01ZJCT0I68f061N=01QEB`0
GdlU069=8`1UCAd0I4lR065>7`1QAQd0G3PE05H_401A;Pl0Dbd?05T^3@1C:P`00P1>9P`0401<90X0
C2L904DR2@1980L0B28704PP1`1=8@P0BR4904DQ1`168PP0AR8904TP2@158PX0Ab@904XW2@1::0T2
04dW2P0E04h[2@1?:PT0D2X;04lW2@178PL0B1l404dR2@1;9PX0CRX9054Y1P1>:0P0C2P904DS2011
80L0@R07044Q2P0k70L0>1l3040N1@1680P0C2<90080CBH902L0D2P904`V2@1;8`P0Ab4704DP0`16
80D0BQl604TM1@116PH0?QP403TG100f4@<0=0l2034C0`0h60<0>Q`503lI1P0n5`D0>aT303TE0`0h
4`<0>AH203XD100k60H0?AP603XJ1@0o6PH0?A/703`M1`0m7`T0@28:048P1`1780H0@b0903lL1@0l
6PD0>aT503`G1@0m60D00P126@H00`0m6`D0>QX503TJ1P0203`H100R03/G1@0n70L0?Q/603hH1@0`
4`@0=0l503D@0P0b4P@0<`l203@?0@0f4040=Q83038A0`0f5PD0=aD403dF100j5P@0>AH303@D1@0a
5`D0=AD403PH1@0e5@@0<A@302lC0@0^4040;Ph102h=0P0a3`<0;0h2034>0`0b4@80<18302h?0P80
;@/202L09@X302/:0`0b3P80=Q<203PB0P0c4P80;a0102d?000_4040:a8102dC000a4040=Q4203@D
0P0e4`<0>QD203<H0P0b5`40=QH203XI1@0l6`<0>aP303`L100j5`80>aT503@E0@0c50D0=1D5038D
1@0[4@80:@d101X;000H1@006@D001`6000M2P407P/00249000G1P000P0C10009`0F1P407@T201`;
0@0L2P406@T101X70@0H1P005@H001H5000B1P004`@001<3000C1@006PH001X9000O3P4060/101L9
0@0K30807a03024A1`0Q4PH080l5028@1@0R3P@08Ph501l=1@0R4@@08A04020=0`0I2P806@T101D9
0P0C2P8050P201870P0B1`4050T101<70@0201D:000W01P:0@0L2`8070`201`:0@0O2P807Pd301/;
0P0I1P004`L000l2000@0`003`@00147000D30@060h401`@0`0O4P<0814301d?0`0G2P404P8000d0
000?0@004PH001050@0>10003`8000h0000?0P0040D000h1000@0@004`@001H5000F204060P10186
000B0P003`8000<03@8000H02@4000L1000700002P0000L10006000200<0000N00D200090P002`<0
00l3000D100070@001d8000V3040:A4302hG0`0f6PH0>Qd603`Q1`0m7@H0=ah603<K1@0/5P@090d1
01T80@0D2@0050X101H;0@0L4@<08aP502/J1P0/60D0;aT402`F0`0W5P806Ph10P0D2@002P0?1@00
208000@1000300000P0000D000050P00100000800001000b000000`0oooo000:0?ooo`8000360180
0PZn00HNZ@08;Yh04CVB01a6Q`0NBhX08Df:029AQ`0RDHP0956<02YCQ00[Dgl0:59m02aCO`0`FH40
<5il03=QNP0gI7/203i^M@0W045eL@15N6`0BGQZ04]gJP1?MFP0Cg5X055`J01>LFP0CG1W04QbJ@1:
MF@0EGmH05ilBP1PO4@0HGa005ia@01QL400HVLj065R<@1VHc00IUl_06EQ=01TIC/0IF8f069N<@1O
Fc00GU<Y05i<8P1OAah0I4DK06I:701VCQl0HDLL05`i5`1H<100DRd?05@[3@1D:0/0EBH;0080C2@9
01@0CB8904dU2@1680H0AQ`804LR1@1:7`H0A1l704<M201270L0@R0604DO2P157PT0@R0604<T1@18
90T0C2L:04hX301:9`/0BbL;04XT2P80Bb<80140Ab8604/P201=9PX0CbT:04h/2@1B:`X0D2l;054_
30179`T0AB8704<P20148@T0@B0503hR1@128`@0AbD704hV200204`X200W05<[2P1=:0X0CBH904lU
20188`P0B24804TR20137`L0@1/603`H100f5040=14103<>0P0b4`80=aP403TI1@0k6`@0>aX603`F
0`0d5`80=A<3034C0`0^4P@0<A<503@C0`0i50<0>aD503/G200j6PP0?1l9044P2@0n7@L0@A/6040L
1`0j70H0>a`703hI1@0n60@0?1P60080?aX702L0>1X503XG100g5`D0>QP503TH100i5`H0?1P603/G
0`0e5080<Q4303<B0P0`5@80<a@303@A0P0b4P80>A<303`D1@0g5@@0=aL503<G0`0g5@80>AH203@B
0@0b4@80=10403<B1@0f50<0<182030B0@0^3@00;Ph002dB0P0/4P<0;A4402l@0`0^3P80;`h102l@
0@0Y2@400P0Z30809`0W3040:PX102/>0@0^3`00;0h102d>0@0/3`80;0h002`@0@0^4`<0<A@302lD
0P0`3`40;a0102lA0P0^5@80;a@1038E0P0e5@40>QX403hJ0P0i6@80?1/5040I0P0j6080<aP2030B
0P0a4080;0`002P:000P20007@@001/5000H1@006PL101X8000I20005`@001H3000201D3000V01D6
0@0J2@4060X101T;000J30805`P101D9000F1`005@H00185000A0P003P800181000C1@005@D001L8
000I2@406@X301`;0`0L3@@080l6028?1`0Q40H080l501d<100K3@8070`301l<0`0P30807@`201`:
0@0I2`8060/301L;0`0G3P@05Pd401P=100H308301D:0@0:01T<0@0N3P@06``401l=0P0O2P008``0
01/8000L1P005@H001P500805@H000l050L101L:0`0J3@<070h3020?0`0Q40<07`d201X;0P0F1@00
300000X1000<0`003@<000d4000>0P000P0>0@002P0?0`003P<000l1000B0P0050@001<5000G1@40
4`D001<3000B0P0200d2000W00T200070@001`4000P0000:0P00308000L1000400001P0000@10007
0@002@4000X2000?0P004@0001L2000L2@008`T002PC0P0`5`<0=A/503LN1@0g70D0>1h703LM1@0b
6@D09Q0301/>0@0D2@4040X10109000F2@4070h201l?0`0R5@<09QL202XD0`0U4`<07@d100805``0
00L04PL000T500050@000P000000000100000`0000800@00<`00000<0?ooo`002P3oool20000aP0B
00@A_@0:;Jd02cjK01U5Q@0MAhP07dn:025HRP0RFX@09ej002iPP@0/H840;VF003AXO00lK7D0?Vib
03m`KP14LVX0BGIY0P1?OfH09`1CP600F81L05V0FP1POED0HWeF05meEP1LM5D0FWEH05UeFP1CP5`0
EgMG05ioC`1UNdH0JG]106Uk@01ULD00Hf`k06=P<@1SER/0J5HY06ME:@1SFRd0Gede05mO=P1MGc00
Ge/^05iE:@1NCb80HDLL06I36@1WB1/0ID`R065:801M?QL0FcTD05Hg4P1G;a40ES0>05@[3002058W
2P0W04lT2P1>8`T0Ab<704LO1`148@@0A1l504@N1@118`H0?ad703lM1@137`L0@ad8048O1`138@L0
BbL904`X2`1>:0X0C2T:04XW20168@L0AAl4048P1@188`T0CBL804l]2`1?;0/0D2d;058/3@1=;a00
BbX=04XT2@138PP0AB<904LS20167PT0A1d804@O201990X0BR@90080C2D702L0BRL804TT20178@H0
B28704LQ201;8@P0AR<9048O1@0n70<0>AL3034A0P0`4040;`l1030C0P0c5P<0=AD303PF0`0b4`@0
>1<303HC100g4`@0<Q<3034@100b4@<0<a4203DB0P0e5`H0=1L603/I1`0m70L0>a`603`H1P0o60@0
>QT603`J1P0o6@L0?Q`603lG100h5P<00P0i5`H09`0i6@H0=QH503@D0`0g5`@0=QP503<E0`0c5@D0
=AD503TE0`0e4P<0<1<303@C0`0c5@<0=Q0403PD0`0k5P@0>QT403XG100c5@80<QD2034A0P0c4@<0
;`h2038A0@0_5080<Q@3030@0@0[40<0:Pl102`>0@0]4@80;14202X>0@0a4`80;a0302hB0P0^3`00
;10102/<0@0202/=0@0S02d?000]4000;@d002/=0@0Z3`40;182030C0`0_4040;`l102lC0P0a5@<0
<A@202lB000Y3`00;A<3030D0`0a5@40;A@303@F000h5`00?AP003lK0P0m70@0>1P203<G000]4@40
:Q0102D<000U30408Pd1020;0P0Q2`8080`101h70@0E20400P0J1@002P0H1@006PH001`7000L1`00
6PT101`90@0K2P4070T001X;0@0F1`0201D7000>01L6000A1@0040D000h2000A0P004@D101@5000D
1`405`P201X=0`0M30@06`h601l@1P0M3`D201d>1P0401d;0`0J2P806`/201`<0@807@`100T06P/0
01X:0@0H2P<05`/301X=0`0K2`<06Pl401X?0P0H3@<00P0I2`<05P0G2P<06@`201T;0`0L3P407``1
01h:0@0N20006`D001X6000N20007@T001/:000K2`4070X101X<0P0N2`808`h3024@0`0P40<07`h3
01L7000@1@0200T0000?00T3000@0`004P<00103000A0P003`<00104000A10004P<001<2000B1000
5@@101L6000F1`005`H000804`4000X02`<000T100090P002P<000`3000B100040@000X200070@00
1@800P0400006`030P001P4000H0000<0@0040<001H7000O2P008Ph002DA0P0Y4`80;1D4038F100c
60<0<QP202PE0P0M3@405PT00187000;1P003PL00147000E1P006@/001`=0@0M3`407Q0101T=0002
01@;000401<6000:100010<000<000D0000000<00@00000000000000<000000<0?ooo`002P3oool0
50001:/000Zh00HM]P0>=j@06DVD01a8T@0ODhd08En802EWPP0^KGX0<g1e03YcLP0jLg40@GI]04]g
H`1CNEh0FWIK05]eE`1LMUH0GgME0P1QN4l09`1SP4`0J7Y706anA@1^Md40KWE006Yb@01ZLT@0I7I9
05mnC01LO4l0GX1?05f0C@1OOdP0JX1006^0@01ZLT00IFDe06EF:@1UCR<0ID/R06I@9@1TERX0GU/_
05mM<`1RGBh0He/[06=D9`1SCR@0HDDK06E26P1SBAh0I4/M06197`1O@a/0GCdH05Tg501G<Q00EC4A
05<a3P0205D[300W054Y301?:@`0CBL:04PT20188@P0AB8704TU2@1790X0@Qh803hI1P106`L0A20:
04HP2P1680T0B2D:04TV2P169PT0Ab@904XR2P147`P0@R4704HS1`19:`/0C2`:04d^301>:`/0D2`=
04h`3@1<:`h0B2T:04PV2P169PX0AR8:04PP2@147`X0A1h904HQ20178`P0BAl80080@a`602L0AA`6
044L1@117@L0@a/6044K1P136PH0?Qd903`I1@0i5P<0=Q<402h@100Z3040;@`202h>100`40@0:a<3
02hC0`0b4P<0=1D303<F0`0`5@<0<Q<403<D0`0c4@80=Q<2038E0`0g5P@0>AH503XG1@0i60H0>QH5
03dD1@0k5`D0>AH403@G1P0h5PH0>aL503LD1@0a50@00P0d5@D09`0d4PD0;a<6038D100a5@@0=1H7
02hG1@0_60H0<QT703DG1@0c5@@0<a<203@A0P0c4`<0<QD403@G100e4`@0?1T503LG100b5@<0;A03
02h<0@0/2P40;0/102l>0P0`4080;`d2038;0P0]3000:@d202hA0`0/5080:A0202`>000]4040;@h3
030E1@0_50@0;aP202hD0`0202dB0`0W03<A0P0e4080<14202`?0@0Z4P80<AD502lE100_50<0;142
02/A0@0a3`40<1D302lB0P0_3@40;a@303<E0`0^5@<0;Q@402/C0@0`5040<aH003LI0`0j6`@0<QH1
02hC0@0X3`409@l1020>0@0S2@407`/202<?0`0S3`@080d101l;0@0J1`006@L101X;0@0M2P007PT0
00808P`102L08`d102@=0P0H304060X001T8000G1@006@H101P6000F1P004@@000h2000>0`004@D0
01@50P0D20405@L301T;0`0K30@0714601hA1P0L40D07Q4601/=1@0J30D05PP201@80@0F2P405P/1
01T<0@0J2`4060/001L90@0G2`8050T201L90P0H2@<06@d301`<0`0H2`<00P0E2`809`0F2`805PX1
01H:0P0J2P806@/101T80@0I1`006@D001X8000O2P008@X1024;000O300070T001P<000M2@407`X1
028?0P0T3P807``101X90@0B1P003`8000P000090000304000h4000A0`004P800143000@1@004`H1
01460@0C104050<001L5000I1`007@X101d70@0201L3000W0141000>0@003`800106000C1@006PH0
01/4000G0`00308000T100060@000`0000<1000300001@0000L00009000030000142000B0`0050L0
01X80@0O2P4080d102P@0P0Y5@809@h101d<000E20003@D000X2000;0@002P4000/4000=100040D0
01<7000D20005@P000805@H000@03P@000T500060P001000>000000<0?ooo`002P3oool050001Y`0
01BZ00LZ/00A?id07UBB02=LS00UIXD0;6mm03IgL@10NVD0BgUH04edDP1@LDd0Dg1505U/@01OJD00
H6Y0065^@01PL440Gfm00P1QLD009`1PLD00HV`k06EU>01VH3<0JU/]06YK;`1XHCP0HfI006=^@01O
LD<0GG9705]bA`1KLdP0H7=006Md@01XLC/0IfDb06II9`1WD2<0HdhS06=A901SD2D0I5<W06EH:P1V
Fb`0IeTZ06EC8`1TBQh0HD4J06936`1RAah0HdXO05m87`1MAQl0Fd8L05Lj601D<Q80Dc4A05Hc4002
05L_3@0B05@]3P1B:Pl0DR/>04XT2P158PL0A2<904@V30169`T0AB48040N2@127`T0@R8;04@Q2P15
80X0AbP:04XV2P1:8PT0BR<70P178PL04`158`H0BbH804hZ3@1=;Pl0D2`=04dY3P1=;0/0BB`<04dT
2P199@P0BbL:04XV30188PX0A20904<N20128PL0@Al704@S200o7PH00P0o6`H0200m6@D0?1L503DG
100m60@0>AD303PF100e50<0<Q820P0b3`807@0Z3`<09Pd202D;0P0X3`<0:A0502XA0`0]4`<0<1<4
03<C0`0d5@<0=Q8303<A0`0e4P80=Q<103HD0P0e5@<0=1H303HC0P0j50D0>A8503LD0`0d5@80<QD0
03@C0P0/50@0=1<403<C100]50@0;A<50080;AD601H0;Q8502hA0`0^4@<0;1H5034G1P0_6@H0<AL6
03DF1P0d5@D0;a@502lC1@0`40@0;a4302dA100`50<0=1<403DF1P0d5`@0<18402/>0`0Y2`809PP1
0P0Y3@003`0X3@00;0h002P9000]2P00;@d302X?0`0[3P80:a8202l?0@0c5080;a44038F100g5`D0
=Qd5030H1P0202lC1@0W03D@100f50<0=aD303<D0P0a5080=AH303<H100c5P@0;a0102TA0P0[5040
;QH2030@0@0`4@40;A41034B0P0_4@00;Q8102`A000_4@00<1@203LI100f5P<0<18102`?0P0X4P<0
:A8202@?0@0S308080`1024=0P0U3@<09`h201l<000L1P007@P001l:000Q3P008`l100809Q810200
9Q03028<0P0L20406@T101X6000G1P005PL101L8000G2@005PH00145000B10004P8101860@0D1`40
6PT401d;100L3@H07A0701/@1`0L3@H06`d501T;0`0G2@804`L00145000?1P004`P101H7000F2@00
50L001@70@804@P100D050P101D60@0I20805`/201H;0P0201@90P0W01880P0B20404`L101H90P0H
20805@L00186000B0`005PP101`;0@0Q3@8080`1028:000N2P006`X001/8000Q1`0090T002<9000P
30407@d101X:000C1@002`8000H0000:00002`8000l2000>0`0040D001860@0E1@4050L101<60@0F
20806PH101h70P0P2@807`/1008070P000`05`@101@20@0D10405`D101/60@0N20406PT001`6000H
1@005PD000/400050@0400<00080100000l01@0000H0000:0@00308000h4000B1`006@T101X80@0N
1P005`D00183000<0@001@4000<0000400000P0500000`0900002P4000/3000300`2000400L20008
0P001@80008003P00000303oool000X0oooo00h001:T00<UX00;?:<07UN=02MUQ00]L7L0=G=Y03aa
G013KTl0BFQ204]P>@1;Ec40BE8[04]>9`80CTTS00@0DTdT05MA:@1JEB`0FEH/0P1LEbh09`1IEBd0
Fd`V05M57`1G?1X0FCTE05Pj5@1J@AT0GdHO061=9P1TD2l0I5He065M?01NIT00Gf]006A^@01WJcT0
J6Hc06IM;@1WE2P0I50W069@9@1RDB@0I54S06MJ:01XGR`0JETZ06IB8P1SBQ`0HT@K06A56P1UBQh0
HT`Q06187`1JAR40GDDO05Lk601E<a<0E3<B05Lc4P0205Hb400W058_4@1::@h0BBH=04HT2@128@L0
@Qd704DP20118@T0@Ah703dH1P0l6`D0@ad8048O20127`L0ARD:04LV2P178`T0BR0704/S201:9`T0
B2P;04`X2@1>;`h0CRX<04dZ2`1;9`/0BBH:04XV1`179@L0AR4704HS2P1:90T0@R49040Q2@1580P0
@b46048Q1P107@H0?QX50080?AD401h0=A<403DB0P0g4@80=A<403<C0`0]3P80:`X202P:0@0X2P80
:Pl302D>100R2`<08``4028>0`0Y40D0;Q44030D1P0a5@H0<Q<5034B0`0d4`<0=A<203LC0`0f50@0
=1D4034G0`0d4`40=a0103@A0P0b3`8202h@0@0702hA0`0/4@80;0l402dB100a4PD0<Q<503<E1P02
02hE1P0502/C0`0X4@<0:Q4302lA1@0b5`D00P0d5PD0800g5P@0=a<603HG1P0c4`D0;Q8302X@0P0Z
4@80;Q8403HD1P0f50D0=1@502h>0`0W3@809P`202D:000T3@00:0/002H<000X3P009Pd202D;000Z
3P40:a0102h@0@0`4P40=1D2034C0`0^5P<0<AL203<G1@0g6`H0<a/40P0b5P@09`0e5080?1D303LC
0`0d5@80=AD103PG1@0h5`@0=aL203@D0P0a5040;a8102lC0@0]4@00;Q8102dA0@0^3@00<A41034E
0`0`4P40<14102d>000]3`80;Q<402XA0P0U3`809Q0302LA0P0S30807`T201h9000L30008@h4020=
0@0R30407PP101`<0@0P3`807`d102L?0@0202<A000902<>000K2`005`H001L7000F1P406`/401`7
0`0F2@8060L200805PL101`05@@101840@0@0`405`T401X<1P0N3`L06a4801`@1P0L3`H06@`601P8
100D1P@04@@000d3000>0P003`D000h5000?1@004PD00184000A1@4040H100h60@0C1P404@L101<7
0@0E1P8040T10P0A20809`0A1P803PH000h5000?1P004PL001<6000B1P0040P101L60@0J2`4080d2
024;000O2`008@P001h6000M1P0070P102490P0T20009P`002D@0@0O3P4060P000l1000800001000
00P000090P003@800185000C10404PD101450@0B1P405`P301P70P0N1`807`T201l90@0201`80P0B
01P60@0G1@4060D201L70@0L1P<070P202080P0N2@4080P001l8000E10403@8000H100040@001000
00@1000400000`000P0100002`0200001@0000D000090@00204000d1000?0P003P4000T200040@00
0`000080000010010002008000800`0000@00P0000<0000200000@00>000000<0?ooo`002P3oool0
5005;J003dFH02=QQ`0`JWD0>FeP03eYCP0nH480@EXj045H<`10DRl0@4PV0410800n>aX0?cHJ044e
5P14=QH0BCLF04/i5P1=>QP0DCTG0P1?>aT09`1B=AL0CbhD04T^4@14:Pd0ABP=04HY2`1>;a00EC4@
05D`4@1A=A40ECDB05Pn6`1JAB<0GTd[069G;`1SGbh0IEd/06=I:P1RDR@0HD`P05e?8`1OCb80He8U
06IF:@1UFbX0IU4U06=:801SB1`0IDHJ06Q26`1XBAl0I4XO0697701KA1h0G44M05/k6@1K?1H0ESHE
05@a5002058c500504da4@18:0d0AR<:04@P1`106PH00P116`H05@127@L0?AP603dE0`0n5P<0@aT5
03dJ1@0n6@H0?1`7040N1P107`L0AQl704`T2@1<9PX0B2D904`Z2`1;;0d0C2X<04TW301=9``0BRT;
04TT1`0204@N1P0304@N1`147`L0?Ql70080?Ql700@0?Al603PF1@0g4`D0=A<30P0_3P<02@0]4040
:`d002/<000X3@409`T20207000L0`007`D002460P0202<;100L020=0`0O30H09a4502/A1@0a50D0
<1@502`F1`0`5PH0<A<4038@0`0a50<0=A84038D0`0`4P@0=@d103@@0@0a3P40;`d002P;0@0Y1`40
9PL202D:0P0[2P40:@d202`A100a50D0<aP603DF1P80;Q@502L0;14402X?0`0Z40<0<10503HG1P0i
6PH0>AH503@G100a50D0=1<503@D1@0e50<0;1D302l@0P0]4@@0<1@403<C100a4P@0;0l202P<0P0X
2P409PX002@:000X30008@`002H<0P0/2@80:@/102X<000`40<0<Q42038B0P0b4`80<A8102l?0`0^
4`<0=A@203@I1@0e5`@00P0g4`@01@0k6@@0>aL403@E100h5`<0?1P40080>aP40200?1L203LG0P0g
5`40<A8202hB0P0[3`80:@l102`?0@0X3`40;`h1030E1@0/3`409P`1028:0@0U30409`d3024;0P0P
2`807``2028<0P0Q3@407PH001/7000G20006`/101`<0@0P2`407`/2024>0P0O40<08A03024A0P80
7@X002L06PX001P6000F1`405`H201lB200O3PD07@`501d;100M2@<06@d301D;0`0F20405@L20147
0@0K40H07A0801hC2@0L4`P0710801X>1`0E30D05@P401<50P0B0`4030400103000B0`0040<000h3
000:100030@000h50@0<1@403P@100h40P0=0`403`@00106000A1@000P0@1@409`0=100030<000`4
000>0`003@D000l5000?1P403`H001490P0I2P407Pd1020=0@0N2`0070X001d9000M200070X201l<
0`0O3@808P/202<>0P0Q3`806`X101@4000>0@00204000P200090P004@<00186000A1@4040@100l4
0@0B1P804`@301H60`0J208070X201h90P0201X80`0B01L70`0J20806@L201H50P0L1`8070/2020;
0P0U2@809`d302H;0P0U2@405PD100l30@0:0@00208000P100050@0010001@0000020080000600<0
00030@001@8000H1000300000@00AP00000<0?ooo`002P3oool0500ED8H09f=c03=VG@0hH4P0>EDf
03Y;;00h@b@0>3lP03Xo8@0l?1d0>c@I03L]500h:A80>2XB03dZ4@0o;180?Rd@03l[400n:@l0@RTA
0P15:A009`15:a00@BL=044V3@108Ph0?B@:044V2P159@/0BbT<04HT2P129@L0A2D:04/Y2`1<:@h0
D34B05Pk6@1N@ad0GdLO05m8801MAah0FTDO05e:801LBb00H4`Q06EA901UCb@0GdHN05e46P1PAA`0
HT@M06A57`1TBb00H4`Q05i56`1L@Q/0G3lI05Xk5`1M@AX0FcdI05Dh5@0204le500W04h/40189@T0
BB0804LO1P117@H0?a/403dM1@0j70H0?aX503hF0`0m5P00@1D203dH1@0i50L0=aP403dK1@0l6`D0
?aT7048R1`188@T0C2D;04XZ2P1;:P`0BB/;04LX2@1<9``0BBL904LQ20127PH0@AX5048O200o7PP0
?1/503`J1@0k70L0<AD502`@0P0Y3P809`T000809@X002L08P/001h9000M204070T101/60@0L2000
7@H001d70@0O20807PP3024:0`0U3@808@l502TB1@0^4`D0;A8502dC1@0_5PH0<A@502hC0`0`4@@0
<A4303<A100a4P<0:a4202l<0@0_2`00;PX002`8000V1`808PT101l70P0P20408@/102<>0P0W40<0
<1@6038G1P0d6@L00P0`5@D09`0[4@D09Q0502/@100_4@@0=AP403XI1P0f5`D0<A<4034A100f40@0
=aH303@F100f6080<Q@3030C1@0]50D0:A0302P>0P0[2`009`/002@;000W1P009@H0028<000V2`00
9Pd002`;0@0W2@00:@d203<A0`0d4`80=1<302lD0P0Y3P40;0h002h>000a4080<aL203HE0P0203HF
0`0W03HJ1@0j6@D0=QH503HF1P0j60@0>AH403XG0P0i5`<0>QH303DE0@0^4@40;0h202L>0@0Y3@40
9Pd002H;0P0Z2`409`l102D<000N2P407PT101/8000K2P806PT201X80P0I208080d101d:0@0I2P40
50H101L5000H1@005`T001X8000M2`407P/2024B0P0O3`8080h200805P/102L05PX001@5000C1000
4PD101`A1P0M3`H07Q8601hB1`0N40D07Ph601d=1@0I2P@060X301h?1`0N4@H07a8801dC2@0K4`T0
6a0701/?1`0I30D05`X301D80P0B1P4050<001@40@0D1@404`D00142000<0`003@8100h30@0B1@80
3`H300d50P0:0`4030@000`2000?10000P0=10009`0<0`002P8000T2000:0P0030D000d6000@1P80
3PL201480@0H2`007@`101`?0P0P3P<08@`101h<0@0Q40808Pl402@?100T40<09a4202X>0P0T3P80
70`201P90@0D1@003@@000d3000?0`004@<001H6000D1P004P<00143000C1@404@D101450P0B1@80
60P201X80P0201/70`0801D60@0H1P805@@201D40P0J1`8070/202D>0`0W3@D202`@1@0502L;1@0Q
2@8050@10102000;0@000P0;0P000`070@00100000400004000000800@0000D00@4000<100020@00
0P0000400016000000`0oooo000:0?ooo`0D02MFE@0aET@0<d`c03=29P0a>Ad0=34F02lZ4`0`:A<0
<b/D03@Y4`0a8Pl0<Ah<038N300e8`h0=bH?03XW400l:a40?BT@03lW3P0k9`l2048V2`0W044X2`0n
9@/0?B<;03/R300k8P/0?B4903hS2P109PP0?R0703/L1`0m7@P0?QX8040M1@1480P0BbX<050b4`1G
>1L0FS`I05Po6`1KA1d0FdLO05Q57`1NAal0HD/N05m97P1NAQd0GD<J05m77@1PBB40GDTR05m8801P
BB00GDHL05Y3701K?QP0G40H05a1701K@Ah0E3TF0080CS4B02L0BRL=04LS1`1080H0@ah3040J100l
7@D0?QX503lE1P0l5PD0?AL503XC0`0h5`80>aL403TI100n6P<0?1T604<K10127`D0A20904dT2@1:
9`/0C2T;04d[301:9`X0Bb4804DW201990P0@al703dN1P0n7@L0>ah603lL1`0i60D0>aX303PH1P0^
4P80:@d102@9000P2@000P0M20000`0M1`006`L001d60@0201X70@0D01/60@0K2@8080T202080P0M
2P809PX202P?100Z4`H0:a8502dA1P0_4@D0;Q<602hG1P0d5@D0=1P503<B0`0`3PD0;Pl302T<0`0/
3@8202H=000<02D7000U1P009@L202D80P0T2@80:0/202H>0P0W40<0:@h3034E1@0c6@H0<1L90P0^
5PH09`0Z4PD0:A4402/@0`0^4`<0=AL4038I100b4`@0;a0402`>0P0^3`80<Q83038A0`0d4P00<Q80
02lB0P0Z4@@0:Q<002H@0@0X304090T102P70@0V1`009PP002L:000W2`00:0P002T8000[3000:`d0
038E0`0c4`80<a<4030@0P0X4@40:0h102T>0@0^3080;a0202hB0P02038C0P80=1L402D0<AL403LF
1@0h5@<0=aH303TE0@0g5P80=aH403TE0P0a4P80;10102D=000S2P007PT001d:000K2@0090P00286
000K2@406@T101T80@0I2P406@L001P9000E2P406PT101`:0@0I20003PH00145000?100040@001D6
000I2@406@`201h>0P0J3`805@/200804`T002L04@@000h3000>0P0050T401P?1`0K40L07a07028B
1P0O4PH0814501l@1P0M3@D080l601d<1@0L3PD07@h601`A200L40P06Pl801/?1`0J3P@06@d401/=
0`0F208060L201L6000G1P405PH00143000@0P0030<100l50@0E20805@L200l50`0=0`402`<000X1
000>0`000P0=10009`0;0`002P4000X0000:0P002@@000`5000=1`803`H101060@0E200060/201/>
0`0Q3P@08@l3028B0`0R4P8091@302HD100Z5@<0:18202LA0P0U3`808Pd201h:0@0N1@006PL001D6
000I1@005@@001H2000D10004PH001H50@0B10404PD101430@0A1P404`D101H60@0201L50P0E01D5
0P0C1@405@D101D60@0I20<06`X3024=100W3`H0;a47030B1P0W3`@08@T401/7000@0P00404000d1
000;0`002P<000L0000400000@0000D0000000@00P000040000100000@00A`00000<0?ooo`002P3o
ool0500]ABd0;S`S02Xc6P0[:Q@0:2@@02LN3@0W6`X09aT902LI2`0X6``0:AX902/L2@0]7@T0=20=
03HS4@0h90h0>b<;03dS3@0l9PX0?b@:0P0n9@X09`0n8@/0>R8903XR2P0j8@T0>ah903PL200h7`X0
?Ad;03PM200f6`P0>1P703dK2@0n6PP0?A`8048Q2@1::`/0DC8@05<c5P1D?AT0F44L05@o6P1F@Ad0
G4HQ05e<8P1MCB<0G4`R05e8801PC240GD`R05QA9@1IC280G4`T05e=8@1IA1d0EShI05Ln6@1H@1l0
EChK05<b4`02050[300W04/U2P158@H0@ah6040P1P127@L0@AX4040K1P0l6PD0?AP503lH100i5PD0
>QP4040H1@0l6@D0?a/504DM1P177@L0B24404hU1`1=9`/0C2D;04`V301<:@d0BB<:048O201580P0
@b0903lL1`0k60L0?AX803XN1P0h6@@0=AD403DI100f5`<0;Q4002@:000R20008@H000806P@002L0
6@<001/6000N20007PD001`6000P1`4080L2028;0`0T2`808`X302X<1@0Y3P@0:Q4402`A100Z4`D0
:a8302/B100]5@D0<1L503PJ1@0e50D0;Ph302d<0`0T3`808`/102H9000S20008@P00288000W2`40
:0l202T=0P0X4@@0:Pl302XA0`0`50D0<AD6030E1`0[5PL00P0[50H09`0^4P@0;a@402hD1@0d60L0
;aD6038C0`0]4P80:@h202L<0@0X2`409Pd102/@0P0[3`40;@h002XA0@0Z40809Q0102D<0@0V30<0
8`T302D<0P0W3@00:0d002L9000[2P00:@T002P;0@0]2`00;Pl203<C0`0c5@<0<a@403@E0`0`5@<0
:Q<202`@0@0^4080;a4402`A0P02038@0P0W038D0P0f4`<0<AD303@G100f5P<0=QP103PJ0`0h6080
>AP203LF0`0g4`80<A<202/>0@0R2@006PD001/6000K1@006@P001X7000M200070T001X70@0K2P40
5`X101P7000E1`0060T101X90@0F1`004@H00185000<1@003@H001<6000E2@0060T001@90P0C1`00
3`D0008030@000/02`<000T2000?10405@H301X;1@0I30D070d601`@1@0O3`H08A44020?1@0201l<
1@0J01X9100I2`@06Pd501P?1P0F3@H05``601P>1`0I2`H07Pd601`<100H2@<06PX301P80P0I1`80
5`D101@5000B100040@001<70P0G2@805PT201470P0C1@804@H000d3000:0P0200`3000W00h0000>
0@003@4000/2000<0`003@D000h70@0>20403`D101<80@0D308070l202<@100V4P@0:18502TC1@0Y
5PD0:1L502LD0`0X4`@0:A8202P>0@0W40408@h202090P0S304080/001h:000L1P006P@001P3000F
1@404@H100h70@0?1@403P<100d30@0=0@403`D000804P@101D04PD101040@0C104050@201D50P0L
20<070/402@?1@0Y40P0:14802H<1@0O2P<06@D001<0000:0000304000X1000;10002@<000L10003
00000P0000000`01000000000000000400000003004000000000000004@00000303oool000X0oooo
01@09RLD02HT4P0V80l08QT;024F2P0O50P07a8601h@1P0Q4@H08a@702HF200]6`P0<1d:034O2@0d
8`d0=2H;03HQ2`0h7PX0>b89040P2`80?24902L0>b4:03`P2@0i80X0>24:03XP2@0j7PP0>ah803/R
2P0k8@`0>R0903XN200m80L0?ah803dM200n7@X0AB<;04P]3P1<<A<0DC/H05=06`1D@Q`0FDLQ05]B
:@1KF2`0H5X/05eF:P1NE2T0Ge<X05YB:P1IDbP0EdlT05e<8`1KBAh0E3hH05@k5P1D>aT0ESlL05@l
601D;Ph00P1?9`L09`178@H0@246048L1@116@L0@1h603lK1@0o6PD0?A<503hG1P0l6`H0>a`503hK
1@137@@0AQ`504@I1@1:70H0Bb<804dV1`1=9@X0CRP;050W2`1<9P/0B2H:04DQ2P1280P0@B4804<M
200i6`L0>a/903XK1`0k6`D0=QL503LF100d60<0<Q@002/:000O1P0070X001/7000201/5000W01d5
000O1@0080@00204000O1`4080T202<;0P0U2`808P/302H=100Z40D0:0h402L?0`0X3`<0;A0402/C
100Y4@<0:Q@402hE1P0_5@H0;A8502L>0@0Y3@40:0`202L;000T2@008`L0024:000[2P40;0l1034A
0P0`4`<0<A@302lC0`0_4`@0;Q@402dB100]50H0:QD60080;1<501T0:a8502lG1P0h60P0=1L702lC
1P0/50D0;1<302P>0P0U30808@X202<:0`0T3@80:0h102<?0P0Z4@<0:Pl102H>0@0V30408`X202P:
0P0V3`40:A4102XB0P0Z3P809`l10080:Ph100`0;Q4003DD0P0d5@@0=1L403HG100e6@<0=QX403<G
100c5P@0=a/503DG0`0]504202dE0P0W030C0P0_5@80;a8303@D100b50<0<QL403HI100e5@<0<1D3
038E0P0_5@<0;a<202T?0P0R2@4060H001<7000D1@006@X001/7000I20006`L001`90@0M2`<080P2
01/6000H20405@T101X:0P0E20804`P10107000>1P003@H000l80@0D1`8050L100l6000;0`002@40
00801P4002H0208000T3000=0`404`H201D;100E2@<050T301H;100J2PD06`d401T<100N30D060P3
01H60@0G20<05@T301890`0A20@04PP401490`0J2`L06`/601`;1@0J2`@07@/401P:0`0I2@806@L2
01H4000D1P004PH001P80P0G2@<060X201T:0P0I2@8050H201440@<03`<002L03@<00143000C1@00
50@00184000@1`004`L100l70@0@1`405@L001`<0P0L3P<08Q4402PF1@0/60L0;a/6030J1P0[60H0
9a@302DB0P0W4`809@l202H?0@0R3P408P/302<?0P0T3@808@`001h8000L1`006@D001H5000B0`00
3PD000d40@0;10402P<100/1000<0P000P0=0`00400?104040@100h40@0>10004@<101@50P0F1`80
60T401d:1@0L2P@06PT401P70@0C0`003P4000P00007000200P0000400L100090P001`4000@004l0
0000303oool000X0oooo01@07aP:01lF2@0M50T07A8601d@1@0M3`D06`l401`>0`0M3`D08Q8702@E
200Y6PP0:QX602hM200c8P`0=Ah<03HM200d70P0=b0<03XO2P80>Al902L0>B4803TM200m7PT0?1h:
03XP2@0k7@X0?B0903`P300n8`/0?R0903hR2@0o7`X0@R49040O2@0n7@X0@b0:04PR3@1=;100CSDC
054k601B@Ad0EdhV05QI<01HGC80Fehb05UK;@1LEb`0G5X]05EG;P1ECBD0DT8L05=06P1B=Q<0Cc4?
04d]3P1@<140DC4A05@[3P1>90T00P197`H04@147@D0?1P603/H1@0k60D0>QL503TH0`0j4`80>1@3
03PJ1@0k70L0?1X4040N1@1480D0AA`604DK1@1680L0CBD:0080C2D801@0BBP;04/W2`168`/0@248
03dO2@137PP0?ah603dM1P0h70P0>1/703DL1P0g6PL0=AL503@F1@0b4P<0:Pl002D:000P2@007PT1
01h80@807PH102L08PH002440@0S1`008@D001h7000P2@8090`3028<0P0R3@<090`302P=100V2`<0
90d302L;0`0Z3P@0:`h302P=0`0V3@<0:`l302T?0`0X2P808P/102D;0@0V2P409P`102H90@0W2000
:0L202h<0P0_4@<0<a<4034E1@0a4`@0;Q8402dC100/4`@0<14402dC100^50D00P0Y4`D03P0]40D0
<1@503DG1`0j50H0;14602TA1P0Z3`@09`d2028<0P0S2P<09@`302/@0P0[3`80:a010P0Y4P<05`0Y
3000:0/002L<000/2`40;Q8102lA0@0/4@@0:Q4302d=0@0^3P80;a0303<J1@0j6@@0=ad503/L200k
70L0>1`503PN1@0f6@80>AT303dM1P0i70D0=AH10080<1D101X0;A4202lC0P0^4P80;Q8102dC0@0a
4@80<Q8103<@100[3`<0:18102P@0@0S4`@08Ph3020:0P0J1`005`H001T60P0H2P805@P101L7000G
1@006PL101d;0P0L30806PX101D90@805`P100/05PP101L8000D1P003`D000d80@0>204040T100d5
0@080`001`4000L0000200H1000A00L2000:0@0030<100h60@0@1`803PH200d60`0?1P<04@L201@8
0`0F20<05`H201@50@0A10004@@101<70P0A1@400P0B1@80500A10805PT401P9100I20@060T301P;
0P0G2P806@L201L70P0D1`4050X001T8000H2P806@/301/;100L2`<07@/401X;0P0E2@804PD00P0B
0`008P0D1@006@H001`:000K2P006@T001/8000I20005`L101H80@0E300070/201l@100W5@H0:QP8
02hL1`0`7@H0<1d702`I1@0W5@<09A8402L@0`0U3@808PX302490P0O2P4080`1020;0@0O3P407P/0
01X:000J20005`@00182000@100200h3000300d2000:0P00308000802P4001L02`<000d300090P00
1@0000H100080P0030<100d60P0?1@003PD100`5000=0P003P4000P0000600001P4000@100050@00
100000@1000500000`000040001>000000`0oooo000:0?ooo`0D01TA1P0K40L06a0501/?1@0L3`D0
70l401/>100L3P<07Q0502@A1P0S4`P0:AL702/G1P0/6PP0<B4:03DP2P0c6`X0<Ad903DM2`0b7@T2
038I200W034K200c70P0=1/703PM1P0g70L0=a`803PO200k7P`0?B0903hS2@0m8@P0?Ql;04<O2P13
80P0?B0803lR20118PX0AR<;04HX2`1<:`h0D30A05Hm6P1DB2<0FE0X05QB:`1GDRH0EdhT05U<9`1G
BR<0DChK04le5@1:<A80ABP<04DP2@168@L0BB8804XN201580T0@Q/70080@1X402L0>QP403TC0`0a
4P80<a4103@C0P0e5000=A4203D@0P0f5080<a@203@H100n60D0@A`5044O1P1070H0@b0704dX2@1<
9PX0AB89048Q1`127`P0@1d703/P1@0l6`H0?AX503LK1`0h7@H0=QT603TL1P0i6PL0<aP703DE1@0a
4`<0;A0202@<000O2P008@/102<:0P0P2P800P0N2@409`0R1`4090L102<50@0P1P408@@002860P0R
20<08`X2028:0P0Q2@808P`2024;0P0W3040:@d202X>0P0U2@807`D201l80@0O2P808`L202@70@0O
1`407@P0024<0@0R3040:0/102P9000V2@40:Pd202`>0P0/4@80:a<302TA1@0/4P@0;0h4030>0`0b
4@D0;A@503<B1@0202dC1@0W02`C1@0a5@H0=1H503<B1@0_3P@09Ph402T>1@0X3`@090d402/>0P0`
50<0<A@503<B0P0_4@<0;10302`@0@0/3@40:`d102X<000]3000<A4203<C0P0/4P<0:a0302lA100b
3`@0=1D403`J100l6`H0>B4803/T2P0j80P0=a`603@G1P0f5P@0?Ad6040M100i7@<0>aP20080<QD1
01`0;14102TB0`0[4@809a0202T=0@0]3@80:``202<<0@0O3`4080/101l:0P0P3@8070T201/7000G
1`005`H001P90@0H2`805PT101H60@0B1`405PP101/=0`0J30806P`001H:000G1@006@D10P0D1P00
2@0E1P004PH100l70P0=1`403PL100`4000:0`001P0000P1000200P2000R00T2000710002`@000`4
000:0`402P@100X30P0;0`8030<200d40P0>10803`@101030@0>10403P<000h50@0?0`4040<100l2
0@0D1`<04`P101D80@0G1`806PP101P80@0J20405`L101P:0P0G2P806@T101`<0`0M3P@07Q04024=
10808@l400<08Pd201h<0`0M2`<00P0N2040700O2@408@d102L>000W40008Pd0024A000T3@008@l0
01l?0@0O3P408103024A0`0V5@H0:QP702XH1P0[6`H0;a`602TI1P0U5P<08a42024@000K30006@T0
01/6000G1@405`H101/50@0N200201`;000901`9000F1@00408000l2000?10003P<000d2000<0P00
20000080304000D01`0000H10005000010000080000200@0000700D1000600001@0000D000040000
0`0000H0000400<0000400@0000300000000008004l00000303oool000X0oooo01@06`l701TA1P0J
3`D06`d401`?0`0M40D07A8301hB0`0P4P@09Q4602PE1`0Z60L0:QL802XI1`0/60L0;QT7030J2P0^
6@P0<QH702lH1P80;aD502L0;QH402hE100b60H0<aL503@F1P0d6@D0>A/603PL1`0n6`H0?A`803PJ
2@0l6PL0>1T503DK1@0i6P@0?1/5040J1`0o7PL0@1l:04@O2P1790/0Bb`=058b5P1A>1X0D3hL058l
6P1B=aH0CcDF04hc4`1;;A00ARD;048R2`157PP0@Q/703hL1@146`L0@A/503lJ100m5`800P0d5@@0
5P0]4@80<@d102h;0P0_3`40;`h002d>0@0`3P80<Pl0030A0@0b3`40;a@303@F100g5P@0?AT603dH
1P0o7PH0@b08048Q2P0n7@P0>a`703XJ1P0f70L203`I1@0?03XI1@0i60@0=QL403LH100g5@<0<aT5
030F1P0d5PD0;a@502L>0@0U2@008`T002D;0@0W2@4090/200808`T102L08@/102<90@0P2@408PH1
02<60@0R1`8080L201h50P0J1`407PD001l9000T2P009@d202X=0P0V3@808@L201X50@0H1@0070@0
01h4000N0`006PD001/6000N1`008PP002@;000U2`009PX102<;0@0U2P809@`102T>0@0[5@D0:0l2
02h<0`0]3P<0;Q0502l@1@0_4@H00P0]4PD09`0_4PD0;Q4402`@0`0[3`<0:0/402T<0`0X3`<09Pd2
02/?0P0`50<0<QD403DI100c50<0=18202hA0P0_4`80;10102/A000/4P00<10202/A0P0_40<0;`h3
02d@0`0c5`<0>QH403/L100j6`H0?B4703hR1P109PL0@2<903dM1`0g5P@0>1/403hG0`0n70<0>Q/3
03LI0P0202dF0@0W02X@000X3`40:@h102H<000S2`007``101h8000I1`005PD001L90@0L2`407@/1
01T80@0E1`004`L001L5000G2@005PX101D7000C1@004@<001P60P0J2`806@`201@90@0C1P404`D0
01@3000A100040@000l60@0A1P403`H200d3000>10002P<000P200070@001`<000802@@002L02P@0
00P400090P001`8000X200070P001P8000H20@050P402@8000P200080`002`<100`30@0=0`4030@1
00`30@0?0`004@D101470@0@10404P@101<70@0B2@0050T101H:0@0H2@4060`101/=0`0O3@@08145
024B1@0V50H09AD602DC1@0U4PH08a<402@A0`0S40@00P0V4PD09`0V4@<0:a<402dA100[4`80:QD2
02/E0P0Z5P80:aH302TE0P0U4`407a01028@0`0R4`D09QH502HE1@0Z5P<0:aL502HE100S4@@07@l2
01T:000D1`004`@000h2000=0P003`@00184000D0P0050D001H8000D1P004P8000h3000>0P003@80
00/4000:0`002`8000P1000200H0000300D0000300000P0000@0000000@00P000040000100000@00
0P0000000`0100000@4000800003008000D0000000<00@00000000000000BP00000<0?ooo`002P3o
ool0500K3`H0718501/B100O4@@07Q46028B1@0S4PD08Q4402<B100Z5PL0:QL602XI200[5`L0:AD7
02TF1`0W5@@0:A@602/E1P0/4`@0;1D40P0]4@D09`0/40<0<QL4038F1@0b60L0<1D7034H1P0a5`H0
=1P603LH1P0g5@D0=QP703PE100d5@80;A<3034B0`0f50@0>AL503`L1@0n70T0@1X903dL2P138PT0
AB@<04HU3P16:Q00BB`A04DV3@168@T0@b0803lN2@0n6PL0@1T603hG1P0l6@D0?1T603hH1`0j6`D0
>AX703PH100202lD0`0?02/A0P0/3P40:`h102d?0@0/3P40:`d102`?0@0^3P00:Pl202/=0`0Y3P80
:Pl3038?100g5@D0=aD60080>A@301H0>1T503<E1P0b5P@0=1T503<K1`0f6PD0=AP403LG1@0a5@<0
<aD3030F100d50@0<A83034D1@0a50@0;@l402H=0@0T300090/0028:0@0W2`808@X20P0U2@409`0T
2`409`X102<90P0W1`809@P102D;0P0N1@0060D001/6000K2@007``002<;0P0V3@809`d202@:0P0M
1`406P@001L3000J0P0070@001d3000N1P0070L001d6000R1P008`X102L;0@0T30809`/002H;000W
2`40:Q4302`C100X3P80:0X302D<0`0Z3P@0:10402dC0`02030B0P0W02h>100[3P@09Pl202P>0@0U
2P80:PP202/;0@0X2P40;`d203DB100d5`@0<AD203@E0P0`4@40<0l102h@0`0b4`@0;A42034A0P0`
4@<0:a0202T=0P0[3`80;a4203@E0@0i6@<0=ad503dN1@0l80H0?R4703/R20107`H0?a/603/J1P0i
7PL0>Ad503LG0`0e4`80<A<10080;`h102L0:0l002D<000U3@4080/101`8000L1`005PD001D6000E
1@005`L101T80P0N2P<07@/201D5000C1@0050@001H5000H1`004PD00145000@10004`D001L90@0D
20404`P001<7000A0`003PD00143000?0`0030D000l4000A100040D000`3000;0`002@8000X00009
0@000P090`003@0:0`001`<000L200070P001P0000L0000500000`0000@0000500000`0000H00007
0@400P0:0`405@0<10402`<100l40P0?0`803P<100h20@0?0`404P@00185000D1P0050L001L:000K
2`407Pd4024B1P0V5@L09AL802LK200V6PL0:1P602LF1P0202LG1P0L02HE1@0Y4`H0:A<602`G1`0^
50H0:aH502/E0`0/6P@0<1/3034K0`0f6P<0;AL302PD0`0U4P408`h1028>0`0S4@@09183024B0`0Q
4@807@l201T<0P0D2`0040P000`400090@001`4000H100801`4000`02`0000d0000?0@003`8000/1
000<0@002@0000X100080@001P4000H000060@0200@000<00P0000<00@0000000000000020000000
0`01000000000000001D000000`0oooo000:0?ooo`0701L?1@0K40@07a@6024D1`0P5@L091D702HE
1@0202<E100:02<C1P0U50L0:1H702LH1`0Y50L09QD602PE0`0/5@D0:QD402/C1P<0:Q8402L0<@l4
03DG100c60H0=QP803DF1P0b5`H0;a@603<E1@0]4@<0;a<5034E100a4P@0<A4202d<0@0a4@<0<Q@5
03DE100f6`P0>Q/:03TJ1`0j6@L0>Qd903dQ200i7PL0?Qh8048S2P0n7`H0?Ad403XL100l5`@0>Q@5
03/G1P0j50H0>A<603<F1P0g5@H0=Q<503@F1`0e5@L00P0_50<09`0[4@<0:``302hB0P0]4@40:Pl2
02h@000Y3P00:P/002P;0P0W3P<0:0h202H=0P0[30@0<14302lA1@0Z4@@0:A0302`C100[50@0:Q<6
02dE1@0^6@H0<1L8034I1`0a50@0;aH502lG0`0^5`<0<Q84030@1@0/4@<0:A4302T>0@0R3@409@/0
02H=0P0V2P808``2024>0@0202@>0@0;02P=0@0X2P40:PX102T<0P0S30007`L001T4000I1P4070D0
01l=0P0S30800P0T3@800`0N2P407@H101d3000201`3000E01`5000N10008PH00209000O2@007@H0
0248000Q2`008PX002H9000U2`00:0P002X70@0Y30<090d302@=0P0U2P8090d302H>100X2`<0:Q83
0080;a8302L0;A8302T@0P0Z3@409@d102X90P0W2@80:0/002X>000_3P40<Q8503DF1P0g5080<Q<3
02l=0@0Z3P40;`h2034A0`0a50@0<A<4030E0`0]4@<0:Ph302dA0@0^4P00=1D203/I100j7PL0>a`5
03PM1`0i7@D0>Q/503dK1P0o6@H0?1/603`J1@0h5`@0;Q<302P=000Z30000P0X2@404P0U20008P/0
024:000I2@006`H001H4000C10004`H001<8000G2@006P/001`=0@0L2P4060L001@8000B1P005PD0
01H600804PH001<040H00187000B2@4050P101@7000B1P0040@00107000@1P0040@00103000A1000
4@D00105000A10003P@000/4000;0`002P80008030<000P02`<000X0000600001P0000T000060000
1@0000<000800P0000@00@00008000050@001P410`070@4200/200<02P400P0>0`003`0A1@4050P1
01L90@0I3000710502@E1P0W6PP0:AX902/M2P0Y7@T0:a`902/L200Y6PH0:aT802HF1P0202PG1P0H
02TF1@0X5`H0:QP502TE100]5@<0<Q`503HK100f6`<0<AP102`F0@0V50409Q8002<>000Q3P407Ph1
01h<0@0G304060T101480@0@20003P@000X100060@0010000`0200000`030000100000H1000200H0
000400@000030@000P4000<100D00P000P000000100100000P0000400001001O000000`0oooo000:
0?ooo`0D01X>100M3`D07a4501lB1P0Q5PH08Q8602DD1@0S5PD09AD602DB1P0U4@H09Q@602HD1@0X
5PL0:QD602/H1P0]5@L0<1D602`D1@0`50D2038F100W03DH200c60P0=QH803XI1P0f60@0<AH502/D
0P0^4P<09a8302H?0`0T3P80:`h202`@0`0^4@@0=1<4034E1@0c60H0=QP903PL2P0d5`L0=AP403PJ
1@0j7PP0>QX503HJ0`0g70H0>QT603PI1@0i5P<0=QH403DC100f4PD0=Q@7038D100^4@80;Q44034B
100a5`D0<a@50080:A4301D0:@d202dB100_50@0;Q0302X>0@0Z3P809`l102L<0@0X3@80:a<302TA
0`0W40<09a4402X@0`0Z3`D09`l502@A1P0X4`@09A@602HB1@0Z4`H00P0]4PH0300^5@H0:aH502`D
100`4PD0;a8302/A0`0[3`@0:A0502/?0`0W3@809PT202D80@809@d202/09@h202D=0P0^3@80;Pd2
02d?0@0]3@40:Pd002D?000T20007`D001l6000N2@008@X0028<0@0W3@<09@`2024;0P0P2@007@H0
01`4000N10008@P001h80@0Q20409`L002D80@0Q2P408@X001l8000S1P0080L002<7000X1`4090X1
02X=0`0R30808`d202D>0`0V2P808P`402H<100V30<0:a430080;14302L0;Q4502d@100]3080;@d1
02T:000X2P40:P`202`>0P0[4@80<1<203DC0`0b5`80<A<202lA0P0/4@00;Q8102l@0P0`50<0=1D3
02lD100a4`@0;Q<3034F100c60@0=aP203TK100h80D0>1X403HL0P0c5`80<aD3038D0P0b5@D0<Q<5
030C100Z3`809`/10288000O2@400P0J1`00200K10006PT101X;0@0H2@4060L001H8000H20005`H0
0P0F2P407@0K2`0080`101`;0P0I2P005``101L9000I20005`P001H8000E1`0050@001<6000A2040
4@P001<7000A1`003`D000l8000@2@003PD00144000@10004@D00186000D1P0040H000h50@0>1P00
30L0008030@000T02P<000T0000;0@0020<000T3000;0`002@<000D100040@000P02000010010000
0P0000@00004000200<0000A00D0000900002`0000X100090P003@@000/4000@1@404PT101@80@0G
2`806`h5024E1P0V6PP0:A/802XO2P0/7PT00P0Y7`T00`0Y70P0;1T802PG1P0202DG1P8091P501H0
9aH502PC1@0Z50@0<1P603<H1P0b60H0;A@402`?0P0W4@409`h1028?000O30007`/001`<000G1@00
5@@001@4000B1P003P<000X1000500000@001@000000100300000@00004000020004004000L00000
00<00P00004000010000G`00000<0?ooo`002P3oool0100K3`D07A4401lB100R4@D202<A1P0>02@C
1P0X60P0:1H802LE1P0U50D09Q8602XB1`0[5PP0<AL7038J200e6PH0=1T703<H1P0a60L203HI1`0W
03`L2@0i6`P0=AP703DF1`0a6@H0<1P402lD100W5P@0:18302D@0P0S3P@08a8302/A0P0]4`D0<AH4
03DC1@0`50H0=AH703HH1P0e5PD0<aL303HG100g6PD0<QT4034E0`0d5`@0=A@503@A100e5@D0=1<5
03<B0`0`4P40<1<203@D0`0a40@0;Q0402`C100^5@<0;1840080:A0402L0;0d502/D1@0`4`@0<0l3
02X>0P0X4@@09Pl402<@0`0X4@<0;A8302dC1P0Z5@<0:14402TA0`0[40D09a4602DA1P0U40D09Q06
02P@1P0V40D09Q4602<B100X4PH09Q<602LD1@0_4P@0<10302`>100V3`D090l302P>0`0U2@8090L1
024<0P0O3P<08``002H>0@0W3`800P0X4@409`0[3P40:@h002P?000Q30007PP001d:000N2@0090/1
02P;0`0V3P<09``302L:0`0R2@0080H00205000L1`0080L0028:000O2`008PT0028:000U200090L0
02880@0P2P407PL00206000Q1`408`P002L90@0U2P<0:0/202@<0P0U2`808`T202<:0`0U3@@09Q03
02DB0`0202TD1@0W030B100^40<0;0h102X?0@0Z3@008`/002H@0P0Z5080;Q@3034E100b4P40;Q@1
02XA0P0Z4@40;@l202d>0`0/4@@0;aD502dD100^4`@0<1L203DH1@0e6@H0=AP403DM0`0c6P<0<QL4
02lH0`0a5@80<A42030B0P0]4@409Pl1024@0@0N3P4070P001P6000F1@004`<000803P<000D03PD0
0189000F2P4070/001T:000201P;000J01T9000G2@4060X301/<0P0L3@807``201/<0`0J40<07@`2
01d<000H300060T001T80@0E1`404@P000h9000?20404PP101<80@0B1P005@H201<90P0@204040D1
00l6000B1@0200l6000401470@0?1`403`H000l6008030@000/030<000/1000<0@00308000`5000<
1P002`D000/400090P001P8000D1000200<00007008000030@000`00008000010000100000P10002
00T3000A00/3000=100040@00186000C20405PX201`>1@0P5@H091P702LI2P0Y7@X09al902TP2P0X
7@T0:Ad902XK2@0X6`P00P0Z6@L06P0X60L09aL502DE1@0V4`D09A4202LE100X5P@0:AH502HE1@0T
3P<09Q4302H=0P0P3@4070`101T;000H2@005`D00185000C1`0040@000h300080@000`0000400000
00000@00M000000<0?ooo`002P3oool0500P4@D0818402@B1@0U4`H091D802LE1`0[5`L0:QP902dH
200[5`H0:AL602/E100]50L0<1d903@O1`0g70P0>1/903TL1`0f7@P0=ad80P0g6PL09`0e7@X0>Ad8
038E1P0b6@D0<1L7034I1`0]5PD0;1D502/C100]5@D09a8502/D0P0_4P<0<A8503@D100b4`@0=1@3
03DF1@0b60D0=1H603DD100d50@0=AH403DC100`5P@0<QL403DD1@0d4`D0=a@503HB0`0^4@80;A41
030E0P0c40<0;a8402h@0`0Z3P80;0d102/;0P0202D:0P0W02L>0`0/4@@0:10302H=0P0Q3@<08`h3
02D?100S3`8090d202P>0`0/3`D0:Ph402L=0`0U3P<0:10502L@1@0V30<08`X3020;100S3PD090l3
02@@0`0T2`<09``302L=0`0Z3`D0;A@402h?1@0/40@0;A4502D@0`0P30@07`T3028:0P0Q3`808Ph3
020=0P0R3P808Ph30080:@`101H09P/002@:000R2@008@P001d9000P2@008`d202@?0`0Z2`809``3
02L<0@0U30009@T00288000Q1P007`H002@7000Q20008@T102H:0@0S20009PX00P0V2`003`0S2P40
8@P102<80@0Q20406`L001l:0@0U2P408PX102H:0@0U20808PX2028<100T3`@0:Q8302XA1002030@
0`0W02dA0`0]3P80:Ph102H@000X3@009@l302/?0@0^4@80<Q<3030C0`0a4P40<A0202X>0P0Y3P80
:Pd102X=0P0V3`<0:@l302T@100]40<0;QP303HG1@0b5`@0=1P602lF100_5P<0;Q@202/C0`0Y3P40
:Pl002L<000V30008PX001d:000H2P004`P000h7000=1@00308000802@8002L02P800105000G2P40
6PP101P=0P0I2P4050`101T<0`0G3@<060h301`<0`0L3@807`h301`A0`0O4P<07Pl101`<0@0L3000
6@/001H80@0B1P0040L000d7000=1`404@H101480@0C1P004`D100h50@0?1@403@D000h5000?1000
2`<000X5000=10004@L000h7000=1@000P0<0`005P0;0`00308000d4000=1@003PL00109000B2040
4@L100l60@091@0020@000H200050P00108000<1000600001@0000@0000600002@0000T100070P02
00T2000?00`4000B1P404PL101<:0P0F2P@070h501dA1P0R5@H09AP902DJ200W6PX09Q`:02LK200Z
6PP0:aP70080:QL701P0:1L702@G1P0U50H09A4501h@0`0N3`408A42020B100Q40@07`h101d<0@0L
2`0070`001/:000H1`005`L001@5000C0P004P4000d2000<0@001`4000@000020003004007<00000
303oool000X0oooo01@08aH702LE200V5`P0:1L902PH2P0[6@P0:QT802/K200[6@L0;AT502lH2P0`
6PT0;Q`:03<O2`0d7P/0=20<03HL200e6@P0=Q/903LN2@80=Qd:02L0<ad703@N1`0b70P0=1T803<K
1`0c60H0<1H502`D1@0]5@H0:a<502dF100^5@<0<1@302lC0`0b5@@0<AH5034G200e60D0=AD6030@
1@0c4@<0<A<303D@0`0b50@0<Q<4034C0`0`4@<0;a<402/C100^4`<0;14302h@0P0`3`D0<18402/?
0`0X3`809``102D<000R2`400P0R2P809`0S2`<09Pd302<=0`0R2`<09PX302DA0`0U40D090/202H8
0P0T2@<090`5024;100N30<08P`0024?0`0P2`407PP101h90P0R2P808`T302<:0P0P3@807PX2024:
0@0R2P<09Ph602/C1@0Z4@@0:`h402H>0`0R2P807@X301d70P0M1P807PP101/<0@0N3@808P/102@;
0P0302<<000V02<9000N2@007@/001h:000R2`009@l102X=0@0V3000;0h202h=0@0[30009@X002@9
000Q200090L002H7000U1`409@P002H;000T3@407PX002<<000X30009P/102D8000S1`0080T001l7
0@0O1`808@P102470@0N2@407`L102880P0S3080;10102l@0P0`4`8202hA0P0W02dA0P0_3P80;@d2
02/>0@0Z3P809a8302`?100^4`@0=1T303DE0P0_4`80;Q0402dA0P0X3P409P`002D<000V3040;0h2
02X=0P0^4080=1<3034E0P0`4P80<AH302TD0`0V40809@h10289000R2P008@P00289000K2P006PT0
01`7000H20004@P000h6000<0`002@<000801P<000L020<000`4000D1`4060L101H90@0G2@405@T1
00805`X201h05@`301L90P0H30<06P`301`?0`0L40<070h301/=0@0J3@805`T001@8000@1P003P<0
00`3000<10003PH101070P0>1@403@D100h40@0>0P002P@000/4000;0P002@4000/3000;100030H0
00`4000;100200T4000E00/2000:0`003P@00104000A1`004PX001L:0@0D2P004`P00147000>1@00
2@<000H200040P001`8000P2000:0P00204000T1000;0@002@8000801`8001002@8000`2000=1040
4@D101860@0D20<05@/401L=1@0J3`H07A04020D1`0P5PL09AP802@E1`0W50L0:1D60P0U5@H01P0U
50L08a@6024B1@0M3`@06PT101P900806@`100`06P`201H9000F1`005@L00185000D1`004PD001<4
0@0B0P00304000X00008000200H0000400<0000100000@00004007@00000303oool000X0oooo01<0
9aP802PG1`0W5@L0:1H602XG2@0[5`P0:AP802/H200/60H0;AP802hI200_6PX0<al<03<M2`0g7@T0
=1`7038J1`0_60P0=AX900<0=1d802L0=1h903DL2@0c6PP0<1X9030I1`0_60D0;1H6030D100^5P@0
;A@202lD0`0]4P<0;Q<403<C0`0c4P@0;QH5034E1@0c5@D0<Q4402hA0P0/4080;`d002h=0@0_3P80
:Q0202`=0P0Z3P<0:@d202D:0`0Y3@80:14202d?0`0/40<0:10402D?0`0V3@<08``1028;0@0S2P00
0P0V3@009`0R3`8090d2028>0`0S2PD080`3024?100Q30<07@T201T60@0J20006`P101T90@0K1`40
8`P00287000M1@406`D201h60P0U20808`P102D90@0R3@407@P201/70@0N1`808@/302D>0`0T40@0
90h4028>0`0P2P8070P101d50@0K1@005`L001T8000L30807PX002D:0@02024=0P0W024;0P0O2@40
7PT00289000S2P00:0d002P<000X2040:@`002P;0P0/3@40;0T102P8000W2`009`d102L:0@0W3@80
:`d202T<0P0X2`008``002L8000S2P008PT102H;0P0P20007@L00206000N1`008PH10206000Q1P00
8@T001h80@0R1P40:P`202l<000^4`40;a@10080;`l102L0<181038?0`0]3`40:`d002L=0@0X4@80
:Q0402lD0`0b5P80<1@302hB0P0]4`<0;14202T>0@0V2@009@d002L=000Z3040<0h102h?0@0]3`40
:P`102H>000V3P408`h0020;0@0L1`005PL001P9000H20006@P001H60@0G2P4060T101L:000D1`40
3`<000X100080@000P0:0P006@0:0`002`800105000C1@0050H001<7000D20405@P101880@0A2P80
4`P201470@0D2P8050`101/?0`0H3@<06P`301P<0`0D2@404`L100h5000;0`002@4000/3000;1000
0P0<104200/60@0:00/300080@002P8000T200070@00204000/4000:1P0030D000X300<02P8002H0
2`<000/4000?1P004PP001@9000G2`005`X001D:000@20403`D100`400090`002@8000/3000>0`00
3P8000/4000>0`003`@100h30@0<0`403@8000`2000>0`0040<100h5000@1P403@D00106000B1`00
5@P301T;100J3PD06`h501`A1P0P40L07Pl401h>1@80814501<07Q0301X<1@0L3@<05`/301@80@0C
1`005@D00147000C1P004@L101040@0<0`003P4000l2000<0`003@<100T2000700000`0007/00000
303oool000X0oooo01@0:1X:02PH200S5`P09A@602PG1@0W50@09aH602TD1`0X4PH0:A@602/H2@0/
60T0;a`902lM200_6PH0:aD802/D1P0^5`H0<AT7034O2080;ad701@0;A`702lI1P0a60H0<1D702hD
100^50D0;A<502`F0`0_4`40;Q<102`@0@0[4040:Pl302h@1@0]4@H0:Q8402dA100^40@0:a0102H=
0@8090/101409@`202T;0P0V1`808PT1024<0@0S20807PT101l:0@0T3P40:@l102PA0@0X3P<09@d2
02<?0`0T3`809@d2020=0@02024;0P0W01l>0`0P3P<08@h301d<0P0N2`<06@/301/;0`0D1P8050D0
0144000D1@006@<001h50P0M20006`P001/5000K2@407PP202<9000S20808`T202890@0T2@006`L0
02490@0R2`408`d102H<0`0R30808P/201X80@0L1@005PD001D4000D0`005`L101/80P0M1`408@X1
00808Pd100H07P/201h80@0R20409P`002<:000V3P4202T<0@0O02P;000Z2`80;@/102L<0@0X2P00
:@d102X?0@0X3P40:A4302h?0P0V3@408@`102<90@0R1`008@P002@6000S1`407`L001/8000N1@00
70H001l:000Q3@008P`0024=000U3@00:@h102hC0`0_4@00<14002l@0P0203@?0P0W02lD0`0_3`@0
:`d202P?0@0W4080:a02034?0@0e4`40<a@2034E0`0`4`<0<a8203@C0`0_3P00;0/002T<000[3`40
;Q0102X>0@0Y40409Pd102@:000Q2@0070P001T9000H2@006@P001@8000E2`0050P001@7000G1`00
5@X101L:0@0H2`8050/201030@080@001P8000802@<002L01`@000T5000<1@0030@000l40@0B1`40
40T101@90@0C2@004@T00106000>1@004@P001@90@0F30805@/101<:0@0E2P804`P101870@0>1@00
2`<000T3000;0P002P<000X4000<1@403PP100`70@090`0020<000L200080@001P4000P200090`00
30<000`5000910000P070P009`090@002@<000h4000B1`4050P201D90@0C2@004PP101H80@0D2@80
4PT100l6000>10003`@00104000B20804`P201D70`0D20<060T301D:0`0E1`<04@@200l40@0?1@40
4PD10105000=1P002`H000d4000?1@404@L201L90`0H2`8060`301L<100I30<05``301H90P0201P9
0@0B01H:0@0E1`004PP101070P0A1`803`H100/4000:1@0030@000T4000;0P001`4000H100050@00
0`4000@200020@000@00O000000<0?ooo`002P3oool0500Y6PT09AH:028B1@0P40D080h5024=0P0P
3`<08Q8402<B1@0T5@D09Q<602PD1P0Z5PH0;AD602`B1@0W4P@09A4502LC100Z4PD0;1L50P0Z60H0
9`0/5PH0;1@502TB100W40<09@h202H=000Y40009a0102T=0@0Y2`409PX002L=000[4080:Q8302PD
100X4P<0:14302@>000S2P0080H101d:000L1`007`D00244000O1P007@P001l9000O1`0080T0024:
000S30408Pd202D>0`0R3@D08@d201l>0`0Q3@<08@`101/90P0201X70P0I01X90@0K2P806@T201T7
0@0I1P806PL201L50@0D10803`@001<3000H0`006`@101d60@0P2@0090X0028:000Q2@0080T20289
0@0R20408@X102@:000N20006`H001h90@0201l:0@0<01h90@0K2@4060P001P5000I100050<00181
000D10005P@101H60@0I1`406@L00P0M20403P0I1`407@P001l9000S20009`T202T>0P0X4080:@l1
02/=0@0a3@80;0l102T;000Z2P00;0`00P0V3P405`0X3@809``102@90@0N1`006@X001X8000J1`00
7`<001l70@0P20008@X00289000S3000:10102hB0@0[4P80:Q0302hB0`0a5@<0<AP103DG0@0b4P80
;0l30080;0d002L0:a0202d>0P0Z3P809Pd102dA0@0/5@40<Q@203@F100a5P<0;aH3030G0`0d5P<0
<AP2034A000/40409a0102L=0@0X30409Ph002<<000T2P007PT001T7000G10005@@001D5000C1P00
5PP001L;000E20004`T001H90@0I2P807P`201T<0@0E2P8040<000X300080@000P0:0@00500;1000
2`D100/5000<1P403PD100h60@0?1`404PL001<7000B2@404@P100`70@0=1@003PL1018:0P0A2@80
5@T301890P0@20003PL00P0=0`004@0<0P002`<000T2000<0`4030L100`80P0=1`402PD000X40008
0P001@8000D100080P003@8000d4000;0`001`4000<01P0002H01`4000`50@0?1P404@T101470@0@
1`0050D201<60P0E2@8050P10185000B104040@201<50P0D20@05`T301P:0`0H2`@06Pl501X>1@0J
2P@060X301<80`0D1`804@D10105000<1P002`D000`3000>10004@L301@7100E20<050H301860`0?
1@<03`@200l50@8030@000X03P@000d3000>10003`D000`40@0910001`8000L10006000010000P02
0@000`0000000@0000400002004007d00000303oool000X0oooo01@08aT802<F200P4@H07A06020<
100O30807Pd201l>0P0O40D08a85028?1@0S3P@09P`502D?0`0U3P<08@h302@C1P0U4PD09A8402LF
1080:1D602L09Q@402H@100T3`@080`201h:0@0P1`407`T00249000T20008`H002<9000Q2`4090l2
02L=0P0W40808a4302<>0P0Q20406`L001L4000G1@0060D001L4000M1@006`D001X5000O20007PP0
01l=000T30008P/102480@0P2`806`/201X;0P0M2@4070T101d50@0I1@400P0E1@40100C1P404@H0
01@5000C1@0201H60@0B01P40@0E0`405@@001L3000J1P406@D101d7000O20408@d102L=000X2P80
8`X202D;0P0T30807@X201/8000G1`006`D00P0M1@001P0L1`406@T001L6000I10005@@001<40080
5@@00P0@0`000`0A0P004P@001<3000201<60@0W01L6000I1@006@P001l8000R2`009@`102T?0`0/
3P<0:18202lB0P0Y3P808P/002D;0@0T3P0090`002@:0@0P2@407`P001`:000N1P0060P101T5000H
1@0070@002070@0S30409Q0102T?0@0[4P40<A81030C0`0b5`@0>1D503@I1P0c5P@0<QL2038B0@0]
3`009``00080:@T002L0:PX002T:000/2P00:`d0030C0@0d5@<0=1@503PE1@0e5P@0<QP4038I100g
6@D0<AL102`F0@0]4`409100024;000R2`407`d201l;000M30006P/001T9000H20005`X001L:0P0H
30806@d101/<0@0I2`405`/001L<000K3P807@l301P<0P0B200040@000h20@0:0@000P090P009`08
0@002`8000`4000:1@402`@000d5000=100040H101490P0A20803`L100d60@0=1`403PH001080`0@
1`8040T301490`0?1`0040D000d4000>0P002@@000X3000:10002`<000`30@0:1@402@D100T40008
10402@<100P2000700002P4000`4000<1P00308000P0000300@0000600P2000:0`402P@100h40@0>
0`403P@10P0@10407P0>1P403`P000h6000?0`003P@100l50@0C2@805PX301T;1@0J3PD06`l501XA
1@0K3PH060d601P:1@0E20804@D200l6000=1@002P@000`40@0=0`403`H101460@0?1P403@H000/2
00070P001`4000D100@01`400P080@001@060@00104000<0000100000P0008D00000303oool000X0
oooo00D08QH801lB1`0O40@070d601`<100201/=0P0=01d?0P0L40@0814301h?0P0O300090/201d>
0`0Q3@<08Q@502DD1`0V5@H0:A4502TB1@0202`B1@0;02X@100T40H08Pd401/<0P0L20406PP101d;
000O2P408``2024:000R2`000P0P3P406P0O2`4080`3020<0`0M2P806PT101P50@0I1P4060L101@5
0@0F10006`@001T6000I1@006`L001`9000O30006PL001`7000G20006@H101H60@0I1`405`H001@3
0@0D1@404PD00P0@10409`0=1@003@@00144000B1P005@H001T3000F1@0050<001D50@0H1@006PL0
01`9000K1`007`P00249000T3`408A0302<<0`0S2P807`/101X90@0I1@005`<001D4000C10005PL1
01L6000E10404`@101H3000@10004`@001@4000C0`004P4000h2000?0@00408000h300020183000;
01H5000J100060H001h8000M1`408Pd102L=0P0W3`<0:14202D=0@0U3P400P0S20006P0Q20407PD0
01`8000N1`4060H001d7000M1@007PP001`5000L200080P002@;0@0Y3P80;`h102l@000b4`40=aH2
03hF100j6@H0?Ad703PK1P0e6@@0<1H102hC000Z40409`/00P0Y2P409`0Y2P009a0002d>000^4040
;a81030C100`5P@0<Q@5038E0`0a5@<0<aH4038H1@0_5@<0<14102LB0@0S3P408P/1020<0P0M3@<0
7Ph201l<0P0O30407Ph101`<0P0L3P407a82020C100R4@@08Pl401d=0`0L30807`d201h?0P0L3`40
5P/101<7000A1P4040H100h60@0200`4000:00/4000;0`001`@000T3000:100030H000/6000=1P40
3PD100/60@802PD101/030@000T6000<1@403@D100l70`0>2@<03@D000`5000<0`0020@000P3000:
0`003@8000h4000=0P002P8000P300090P001P<100L20@080@001`8000X3000;0`0030D100X40006
0@000P0400002@030P001`8000P200080P00208100P4000;0`00208100T2000200X200802`8001X0
30<100l40P0A1`804@P2018:100D2`D05`d501/?1P0J3`H06@l501P<1@0E2@@040H200l5000;1P00
2P@000T2000;0`002`<100`40@0:10002P<000L1000500000@00008000800`4000D01@4000<10003
0000100000800002004008L00000303oool000X0oooo01@07Q@701h@1@0L40D06Pd401`>0`0J3P@0
7@d401h<100M3@<080d301l<100N308080/201h<100R4@D091@502DG1P0T5@L0:1@502/B1@80:A84
00X09a<502D@100Q3P<07Ph201h=0P0M2`807``202D>0`0U3`<09@l20P0S3@406`0R2`<07P/201h=
0P0K30805`X201P70@0H20807PX201/<0P0K2@006@L001l60@0O1`406PH001D8000E2@005@D001@4
000A10005@H001H8000J1P4060L001T4000C100050D001@70@0201D70@0L01850@0@1P0050D001H6
000I10006@<001/7000H1@006PH001L9000F1`005PP001X6000O2@408PX1028=0P0T3`@08@/201T9
0@0H20405@D100l2000@0P004`8001<60@0E1@005P@001<3008040<000T03`800181000?0P003`40
00h2000<0`00308000h2000A0`000P0D10009`0H10006@D101/5000M1`008`X102@<0P0R40808101
020;0@0Q30007`/001h8000K1`006@L001`7000L1@0070T201/6000M1@0070P0020:000M30008`d0
02H@0@0X3P80:`d202dC0P0a5040<QD103TI1@0k6`H0=ad503XI1@0h60H0=AH303DE0@0d5@00;Q<1
02h@0@0202hA0P0W030C000b5@40<A@3038H0`0c6@D0<AX6038F0`0`5@<0;1D202hC0P0`50@0;A@3
02/C0P0W3`809A03020<0P0O2`807P/201/<0`0N3P@07a03020A100T40<0818502@B1@0T4`H09AD5
028F1P0S50D081<401hA0`0L3@<06P`001X<0@0E2P004@T1014:0P0B2`804`T200804PP100X03@D0
00/50@080`402P@100T300091P002`@000T4000:0`002@@00P081@005P091@0020<000T1000<0`40
2PD100d60@0:1P402P@000T400080P001P<000H2000;0P002`L000`4000<0@002@8000L300080@00
2@4000D300070P0200P4000300/60@091@001P<00080100000D00`4000H100070P001`8100H30002
00H1000P00D1000500001P0000D0000600001`<000L30@090`802`<200d40P0>1`8040P301@;100F
2`D060`401T>1@0H3@D04`T501070P0A1`803@H100X3000700001@0000H100070@001`8000H20004
0@000`0000000001000200<10@0500D200040@000`40008000010000R@00000<0?ooo`002P3oool0
0`0M3`@070l301/=1@0201T>100?020?100L30D060`301L:100L2`@070/301h:0`0N3@@07Pl402DF
200V5`P09QH802DD1P0U4@L09A@700808a8502L09186020>100Q40@08A03028@0`0U3P809`d402P?
100U3`@08@l2028>0@0R4@8090l202@?0`0M3P806@/201T80`0I208070L201l=0`0Q3@D070`401`9
0`0J2P<06@/201H60P0D1P404P@10144000C1@004PD001D5000J2@006@P101T3000E0`0050D101<7
0P0E1`800P0J1`408P0I2P406`X101/9000L1@006@@001`5000L1P007PH001/7000I1`006PD001T6
000H1P007@L001h90@0M2`407`T201l<0P0H2P405@D101@2000A10003`@00144000G1`405`D201<4
000?10004P<00182000<0@0040000102000@0`0200`1000300d1000A0`0050L0008060H002@070L0
01`6000L1`007@X0020:0@0P3P<07P`101h80@0N2`407@`001l<000O2@007`P101`80P0N2@007PT1
01h:0@0O1`007`P0024;000U3040:1<202`B0`0_4`80<1<202lE0P0e5@@0<1D303@F0P0i60@0>aX6
03PJ1@0j6P@0=a/403TG0`0d6@<2038I0P0Z03HH0`0g6@@0=aT403XG0@0i60@0>1X603TN1P0l7`L0
>1l6038I1P0/50@0:a8202TB0@0Y3`40:14102DA0@0S3`807@l301l;0`0J3@807@`201X=100J3PD0
8104028C1P0S50H091@502<D1@0Q4`H08Q8501lC1@0P4@D07`l401X:0@0H2@<05`L101<90@0A2@40
40P1014:0`0C2`<04`T20P0C2P803P0B2P<03PH100X50@0:10402@<000P400080`001`<000T20008
0P0020<000X40@0810001`<00`070P0200T4000?00L400070`001P8000D200060@002@0000`5000=
1@802`<100/60@0;10402@@000T2000:0P002P40008020@000<01`D000P500050P001004000200D2
000400D1000400000`0000<000<0100000<01@0000D100050P400`080`403`0;0`802`D100l80P0C
2@@050/401H<0`0F30D05@X401490`0?1`803PH200L2000400000`000080000400<0000300800000
00001@810080108100@0104100<1000200000@00RP00000<0?ooo`002P3oool0500K3@<070l601/>
1`0J3`@06`h5020A1P0M3PD06P/401P:0`0H2P806@X301/;0P0L30<08Q@602DE200U4`D08a06024@
1P0Q4@H08A850P0R40D09`0S40@08``4028>0`0S40808`l402LA100W3`@0:10502D>0@0R3P4090d1
02D>0@0U4@@08Q0301l:0P0P3@807Pd201d;0P0I2P<08P/502@>1@0U3@D07@/301/=100J2`<05PP3
01450@0E10404`L10147000C1`006@T001h:0@0K1`4060H101D50@0C1`805PH301L70P0201`80P0W
01d;0P0P308080/102070@0P1`0070T101`7000K200070P001d7000H1`005PP001X5000O1P006PT0
01X8000I1`406PP001L7000F1P005@<001<4000B10005@H101D60`0D1`8040D200l4000C10004P<0
0102000E0@004`<00143000?0`004@8001<0000E10007PL1008070d102L07PL101`80@0M1`4070L0
01d9000M1P407`D101l70@0L1P406`P001`80@0P204080/2020=0`0N30807`d202<>0P0T3`408`d1
02LD0@0]4P<0<1@403<F100e60D0=QL403LI100h6PD0=1P503HE0`0g5P00=a@203DE0P0g6P<0?1h5
03lN200m80P0>Ad603/L100m7P@00P0n7PD09`0n6`@0>a`503TM1@0l7PL0?28803/Q1`0a6`H0;1X4
02XG0`0U50<08`h201h>0P0R3`808@h201h?0`0O40<06``301X=100K3P@06`l401/B1@0T4P@08Q<4
02@C0`0P4`807@l201/?0P0I2`8060`101L8000B1P404@D20106000?1`403@L100h80@0B2P<05@/3
01D<100201L=1@0@01H<0`0C1`8030H100T60@0:10002@8000P200080@001`8000H3000510002@@1
00L200060P002@8100L1008020<000l0208000T3000710001@8000@200050@002P4000/60@0;1@80
30D200/70P0<1@402`<000`40P0<10400P08100010091@002P@000P200050@0200@000800`0000P0
0`4000@100030@000`000080000300000P00004000800P0000<01@0000H100050@400`050@4200/3
0P0:00d60P0@20<04@X301491@0A2@@03`P300d80P0:1@801P<000@00080000000L00@0000800002
00000P000040000000000`410080104100@00`400080000100000@00RP00000<0?ooo`002P3oool0
0`0I3PD07@l601`@1P0201d@1P0?01/?1P0L40D06Pd301P=0P0K2`8070`301d@0`0Q4@H091<602@D
200R4@D08`l5024@100Q40H0818700808A0502L08Pd401h>0`0Q3`<08Q4402<B100V50@09A<602LC
100W40<09Ph202L90@0Q3P809Pl2028=0`0M30806Pd401d>0`0L2P@070`5028<1@0U3PD08`l601d=
100J2`@05`/301H90`0D208050T101L80@0K2@4070T001l90@0L2`407PX101H60@0F1`805`D101H8
0P0H20800P0K2`809`0O3P808A02024>0@0P30407@L101`8000M20007@H001X90@0G1`005`P001P8
000J2`006PP001T60@0I1`405PL001D6000B1P004`H00184000A10004PH201870P0D1`805`L101<6
0@0A1P005P@001H7000F1P0060L001X4000D0`0040<001<5000K1`007`X102D=0P0202090@0W01/8
000K2P006`L001X8000I1@006PD001T4000J100070L001T70@0O1`408@L201h:0P0O4@408Q0202D>
0P0V4080:A4002/A0P0a5@<0<AL503DE0`0f6@<0>Q`303XI100i7PL0>a/703TJ100e50@0>1D203HG
0@0a6080=Ad303/L1P0m8@T0@1h703dR1`0i7@H0>Q`30080>a`401@0?1X303PL100e60@0=Qh503LM
1@0d7@D0;1P402`G0`0/4P<0:@h202@<0@0P3`<07a04020A0`0Q4@@080l401/=1@0J30@060`501`=
1@806`h301406Q0201lA0`0N40806Pd301H;0P0F1`0050L001<4000=1P403PH100l80@0=2@403@L1
00l70@0@2@8050/301H=100201L>100801D=100C2P803`H100`4000;10002P4000P100070@0200L3
000J00H300070P401`8100H200070`40204000H400070`00204100P20@060P401P4000D100060@00
1P8000X30@0<10803@D100h70P0=1@8030H200d50P0:1@802@D100P30@070`0200T3000900L10003
0P000`8000<2000300000P4000<100020@00100000<00`000`0100000`030000100000@1000200<1
00801`8100@02@8100/20@0<1@803`D20P0@1`<01@0?1`<03@D200X400060P000`0000D0000000@0
0@00000000020@000P001P01002:000000`0oooo000:0?ooo`0D01`@1@0M3`D07A4701d@1P0L3PH0
6a0601hA1@0L4P<07A4401d@100L40D07Q0501l?1P0R3`H08Q<5024@100S4@@08Q0502<@1@0R4@H2
024@100W024@1@0P40@0914602DD1`0W4`D09Q8502DA100T40<08Pd1024:0@0R2P0090`101l<0@0Q
2`406``401/?0`0L30@06@d401/;0`0P3PD08`d502<>1@0L3P@060X301X;0P0H2@806`P201d90P0M
2P807P`302090P0O2P407`T201/80P0H1`806@H101T60P0G2@806`T200806`/201407`X201d:0@0K
2P406`L001P5000I100070L001P:000G1P005PH001T6000G1`006@L001L6000H10004`D001430002
00d1000D0102000@0`003`<000l40@0A1@8050H101<40@0@1@005PD001P6000J200060T001T7000G
0`004`D001H4000L204080X1028>0P0P3P420207000D01`7000L2P007`L001/7000N10006@<001@1
000D10005`H001h90@0R2`408PT1024:0@0T3@409Ph202P>000Z4000;18002lA0P0a50@203@G100A
03<H1P0e6PH0>1P503TK100h6`L0=QP503<F100e60<0=QP303<F1@0h6@D0=A`403TN100h7`H0>1h5
03LL1@0h6@800P0f60<02@0f5P<0<QL4038D100e5`D0<1P402hG0P0V4`<090h202<@0P02020@0`0L
024?0`0Q40<08Q04024A0`0O40<06`d401T=100I30@060X301P;0P0G304060/101`=0`0J30<05@/3
01@80`0@1P804PH000l6000=1@403PH200l60@0>1`403@H100h60@0?1P<04@P401@;0P805@`300L0
50`3014:0P0@20403`P100d60@0<0`002@8000802@<000h02@8000H200070P401P4000H300090`00
208000P3000810001`@000P20@080P001`8000D100801`4000h020@100/40@0=108030L300h70P0;
1@803@H200X50P0;1@802PD200P50@0:1P402P@100P200<01@8000P0104000D000050@00100000H0
00050@00104000<000<00@0001800P0000<0000200000@0000<10@040@00104100D20@080P4020D1
00/50`0=1@<03@L100`50P0=10402P<000<10002002I000000`0oooo000:0?ooo`0D01d?100J3`@0
7@l601`<100N3P@0810401hC1P0O50H08A<5020B100R4`D08A0501h?1@0P3`@08104028A1P0U4PH0
8A<6028@1@0U4`L202DD1P0W02HD1`0W5@L0:A<402TH200X50L09a0402@?0`0R3`408``20287000S
2`4090X101/;0P0L2`@070h301d=100I30@06P`401X<0`0M2`@07Ph401h?1@0J2`@06@T301P90P0I
208070P101h;0P0T3@<080d3024;0P0N2P806PL201X7000I1`405@H101P60@0G2P806`X2008070P2
01T05`H101H70@0G0`005`<001P2000A1@405`D101X7000I1P005PH101H70@0F1P405@D001L4000A
0P003@0000P0000:00002P4000`40@0>0P0040<00143000E10404`@000804@8000`050@001/6000J
20006`D101@50@0E104050L001L70@0K2P4080T1024:0@0N1`0201L8000W01X3000K1`006`/001d:
000L1P0070D001D5000I100080L002L9000V2`<0:0h302P=0`0X3@40:@`102T@000^3`40<A8202hC
0P0`4080<A@303<C0`0`50D0;QH3038H100`5`<0=1L5034G100e60D0=1P5038K100d6@@0=a/5038J
100`5`@0=AX503DG100d5P80<Q820080;a8101H0<A0102hC0`0/50@0:AD302LB0`0T40<08@h301l<
0P0L3`<07Pl401d>0`0N4@@07`h3020@0`0O4P@0818501`@0`0J3P805P`101D=0P0E2P8050X10P0E
2@403`0H2P805PX201<80@0A204040P10146000?1@003`D100h7000>1P8030D100d60P0<1P803`L1
01080@0201090P0B01490@0A1`804@T201490@0@2@403@D000/4000:10002@<100P300060P001@<0
00H100060P001@8100P30@0810802@<20P070`0030040P001@4000@100040@001@4000L30@080`40
3P@100l50P0?1`803@D300/50P802`H200D030H300`60P0;1@402`D100X3000200T3000600L20006
0@001P4000H200060@4020810P070P4010050P000P0000400000000300800003004000030@000P00
00801@4000X01@4100P40@0810402`@200X30@0;10802@<100D2000200000@00V@00000<0?ooo`00
2P3oool0500M3`@06Pl401d?1P0L30@07Ph4020@100N4`H07a@6024C1@0P4P@08Q<5024@1@0N3`D0
80l4020@100R4@H09A86024C1P0R40D09A<70P0U50H09`0V50L09aD702TC100Y60P0:1@702L@100T
3`<08Pl102<<0P0R1`008`/102@:0@0K2`8070/401`>0`0M3@@06@`401X<100J30<07@/401h>100N
3`D06P/401T90`0H2@806@P201`80@0N2`8090d3020=0`0Q2`807PX201X70P0J1`006@L101D60@0H
1P405`X201/:0P0201`80P0I01L60@0F1`405`<001L3000H0P004@D101L50@0J1`006@H001H60@0F
1`405PH101D5000G10004@8000d0000800002P0000X1000<10403P800103000A0`005@@101<40002
0142000<01@4000K1P006PP001/50@0D1@405@@101@7000G1`406`X102090@0Q2P407PL00P0G2000
9`0J0`006`L001/;000M2P0070H001`5000E1@006@@00207000W2@009P/302P>0`0X3@<0:0d102T<
0@0Y4000;Pl1034B0P0^4`80<102034D0`0c4`<0<1@502hF0`0b60@0<1L303@G1@0a5`@0=AP503@H
1@0b6`@0=1T403LK1@0b6P@0<1L403DJ1@0e5`@0=1H2038B0P0202lB0@0F034@0@0^4`<0;1@402TE
0`0W4P<09103024>0`0O308070l301h?100M3P<07Q4401l>0`0P40<07a84020B1@0L40<06Ph201H<
0@0E3@805@X201@:0@805@T100l060X201H:0P0C20404@P101080@0A1P003`D000l50@0>1`003PH2
00`50@0=1P8030H200l70@0@20400P0@2@804P0A2@404@L201490P0A2@4040T100d5000;10002P@0
00T30@080`001P8000D300060@001P8000D20@080`4020@200T30P801`<000`0108000D100040@00
104000D100070`4020<100h40@0?1@803`L200d50`0;1@8200/60P0500`60`0<1P802`D100/50@0:
0`000P090`001P070P001P4000H100060P001P4100P20@801`8100@01@8000800001000000000`02
00000`0100000`400080000200D1000:00D10@08104020@100/40P0:0`402`@200T30@050P000P00
004009T00000303oool000X0oooo00<07Pl401/?1@0L3PH00P0M40<03`0P4PD07a<7020D1`0Q4PD0
7Q85024B1P0R4`H0810501h?1@0O4@D08185024@1@0S3`D0910502HB1@0202XD1`0W02TE1`0X5PL0
:a@602XD1`0Y50D08a4202<;0P0S30407`P102860@0K20406@/101/:0P0I2`806@h301T=100M2P@0
70X301h;0`0L2`<060`501/=100J30D06@L301T60@0I20407@/101d<0P0T2P<09P`2024=0@0L2040
60L101T80@0F1P004PD101P40@0D1@005PH200805PD102L050@001<3000C0`0040400142000D1040
60@101H6000F1@004`D101@50@0F1@405PD001D4000?0`002@0000P1000;00003@4000h2000@0`00
4@D001@4000G1@0050D00183000A1@005@D001X70@0H1@405PH101D60@0E10006`P101X90P0K2@40
6@P001X8000G1P000P0I20409`0J1@006PL001`:000K20006PX001h8000M2@0070P0024<0@0S3@40
9`d302XB1@0Y40<0:P/202`;0@0Z4040;A0302lA0P0b4@<0<A8202lE0P0_5080<QD5038G1@0f50D0
>1@403<F0`0a6P<0<aP303<L1`0f6PH0=Qd503LQ1P0f6@D0<aH503<J1P0b5`@0;a<102`>0@0202P=
0@0W02P?0P0W4040:143024?0`0O3P<07@`301X:0P0L3@@06Ph301d?100I3P@06Ph501X<0`0J3P<0
710501d@100M3P@06`d401P90`0D2@404`T00148000?2P404PP201@70`0E2@805@T101860@0@1P00
3`D100l60@0>1@403PD000l60@0;104030@100/40@0=10402`D1008030H001H03@D000h40@0=1`80
3`P200l70@0<1P402`D100/30@0:10802@<000H200050P00100000<100050P401P@100P40P0:10<0
1`<100D300030P000`000P0200002@030@001P4100X30P0=1@803`H400h9100>1`802`D200X50@02
00/60P0400X40P0:1P0020D000X4008020@000`01`8000H100060@401P<100L30@0;10802P@100X3
0P060P4010400080000000020080000?0040000200000P0000<000040000104000D100050P401@<1
00L40@080`002@8100L20@0400000@0009X00000303oool000X0oooo01@06Pd401X>1@0L3PD07Pd4
01lA1@0R4`D081D5028C100O3`@08147020B1P0Q4P@080h5020A1@0P40H07a45024?100Q3@<080l3
02<?0`809Pd402L0:0l402DA100U4@D09a4402T?0@0T3@<08PP101d8000K1`006`P101P60@0D2080
60T201`:0P0K3@@070/401/:0`0J2`@07@`401X>100K3@@06`/301X90P0F1P405@L001/60@0M2@40
7@T201`<0P0O2`807@P101T9000G20005PX101L9000F1P4060D101D6000D1@000P0B10009`0?1000
40<000d1000?0P003P800143000C1P0050@001840@0E10404@D101840@0C1`004@<000`100090@00
2`800105000C10004P@001L6000J1P006PP001L6000G1`8050L201@60@0D10005P@001<6000E1000
4P@001440@0F1P406PH101/6000K2@806PX301T80@0201L70P0W01/5000I1P007PH0020:000S2`00
9`h002H;000S3`40:0d102TA0@0]4@80:Pl102/;0P0V3`809Ph202X>0@0/4`40;QH2030F0P0`6@<0
<aL303@H0P0f6@D0=a`503HK100g5`<0>1H503DI100h60<0=A/503@M1@0f80H0>B09034M1P0`6@D0
=1P602lF1@0Y4@<09`l200808Pl300@08A0301l>0P0K3@<06@d20P0F2@808@0D2@<05@T201P=0`0H
3`<05@/201@70P0F2@805PX201T=1@0G30@05Ph401L<100F2@<04PL10185000?1P403@L101070P0A
1`<04`X301890P0@1P403@H000`50@0=1P402`@100/30@0=1P403@D100X4000<1@402P@100/50@02
00/3000600X3000;0`0030@101050P0>1@003@H00P0<10403`081@401`<000D100030P00100000<1
00040P401@8100P50P091P801P8100@20@030@000P00004000020080000<00@10@0710802PD200`8
0`0=20<030L200/60P091`802`H100`60P081@402@<00P070P0200D2000:00D100040@001P4100H2
0@060`4030D200X40P0810801P<100@200800`0000<00@000080000200000P02000200<000<01000
0P050@0200H1000300D100020000000009X00000303oool000X0oooo00@05`/401H<100I30<06@h5
0P0L3`@01`0M40@06Pd501T>100K3`D07A0601d=1@0M3@<00P0L2`@01@0K2`<070X201d80P0H2080
6`P2008070X102L06`X2020;0`0Q3@8080/1024:0@0M2@806PL201P70@0G1`405@H201<70P0D1`80
5`P201X:0`0L2`@080P201X90`0N1`8070/301h;0`0L2@8070H201/60@0K1@406P@001d60@0N2040
7@T201l:0@0K2`806`T101P8000G1`4060D001L7000F1P405`H101@50@0?0`000P0?0P002P0B0`40
3`<000d2000;0P0030800101000@0`004`<001H3000D104201<5000K00l5000>0P004@400143000B
0`0050<001<2000C1@005`L001/80@0M2`8070T101L90@0F20404P@101<1000C0P004P800142000A
0`4040@101L60@0I100060P101/70P0O20406`P000805`H100P05`H001T70@0N2@008`d002dA000_
4`<0;14102h@0P80:Pl101d0;A0302X?0P0^3P40:a8202`B0@0^4@40<1T203@G100e70D0<ad803TN
1P0f70D0=al603PO1P0g70D0<a/403@G100c60D0=AT5038K1@0a7PD0=A`703DO2@0`6@P0;AX702hL
1`0Y6PD08Q8301l?0`0201h=100W01`=100I3P<05`T201<80P0B20404PT100l5000?1`404PL10148
0@0?1`804PL101470@0C20404`/201490P0A20<04`P101070P0?1`803`P100l50@0=1@403PD30188
0P0B2P<03PP200`50@0910002@<000T40@0910002PD000`60@0;1`402`D100`50@0<1@802@@10080
1`<000L01`8000H300080`002`<000T1000;0`002@@000802P@000<01@<000@0000200000P020000
20030@000`4100L40P070`801P<100D10@040@000P000`0100003P050P001P8200P40@0:1P<02`L3
00/50P0;1@<02@D100T40P080`801`8000H20005000010000P03000200<1000<00@100060@402PL3
00X60P0:108020<100L30@040P400`4000<00001000000000`010000100200000`00008000020002
00<00080100000<00`00008000010000V`00000<0?ooo`002P3oool0500C2P<05`/301T<0`0H2`@0
6``401X<0`0L2`@06@`301P:100K2`<07@`401/:0`0H2@<05PP301H90`0H1`805PH101D60@0D1`00
5@L00P0D1`00400L2`8070X301`90@0H1P4070P101L80P0E1P804`H101870@0C1P405@P101L90`0K
20807PT202070@0O208201h90P0E01/=0`0L30<06`P101T80P0K2@407@P201d80@0M2@807@/201/9
0@0J2`4060P101890@0F20405PL101P6000D100050H101850@0@1000408000803@8001D040<00182
000:0`00408000h1000@0@003P400143000?0`004@D00144000;10004@8001D4000F1P405PP001H7
000G1@0070<001d60@0N1`400P0O2@40400I20005PH00184000>10003P8000h1000?0@003P<00104
000E1P006`L001@6000F1P006PH001d8000J200201d7000W01`9000P2@409`X102/>000`4`40<a@1
02dF000^5040;100034B000_4040<A<2038E0P0b6P80<aT303@H0P0e6@<0=aX503LK1@0g70D0=ad7
03DK1`0g70L0>Q/603HJ100_5`80;Q@2034B0P0`4080;QD302lF1@0_6@H0;aX802PF200T50D09Q<5
028B1P0O40H06`h500806`l500T060d501H;0`0A2@803`L100h5000;1P0030@000X40@0;1@400P0=
1@402`0>1@003@D100d50`0>1@803@@100d50@0:1@002`D100`60P0=1P803@D0008030D100T03PL3
00h80`0=1P8030D100P40@071@002P@100X4000:1@000P0<1P40100=1P4030H100/60P090`0200L2
00801P8000T01P4000L000060@001P<000P400070`001P<000D0000200000P0000001@0100000P00
00D20@050`401@<200801@8101<0104100<1000200000@00008000030@00108100H30@091@802@H3
00X40P0;10<02@@200L30@070P00104000<000010000000000<00@0000@00@4000810008108020@3
0P0910801@0910401`<100D20@030P000`00008000001001000500000003004000000000000009d0
0000303oool000X0oooo01@05`/201T>100K30@060d301P;0`0D2@805@L201P:0@0J2@805`P201D6
0P0E1`804PX301880`0F20<05@H201L60@0E20405@L101D700805@H102L06@P301`90`0J2@406@L1
01H70@0H20405PH101H50@0E1@0050H001L50P0K1@806`L001h9000M2@0070P1020;0`0P2P<07Ph3
01h=0P0J2@407@D101/60@0N2`406`X201X90@0I2@407@/101T80@0I2@405PL201H70@0E1P004`@0
01<40@0@0`4030<000l1000>0`000P0?0@009`0B0`004@8000h1000B0`003`<000`3000A0P004`<0
0183000B10004@D10144000E10005`T001/=0@0K2@406`L001d6000L1@007PL101`90@0L2@006PP0
01@3000B0`003`<000`2000:0@003P4000d2000?10004`H001X7000M1`006`L001/5000G1P007@L0
01d:000201h>0@0W02D>0P0X3@80:a0202XA0P0/5P80<AD102dD0@0/4P40;Pl0030A0@0c4@80<aD0
03@H0`0e70@0=AT303PG100d6@H0>1/603HH1@0g6@D0=AX303<J1@0`6@<0<QP502hH100W4`809`d1
02L@0@0S3P808Pl102<?0P0S40<08A8601h?100I3@@05Pd401D<1@0G30D05Ph500805`h501`04P`6
01<;0`0=208030@100X400090`001P8000L200060P4020<100T300090`402@@100X50P0:1@4020@0
00P200070`002P<000X40@0<1P402PD000P30@0;1@802`D300/70`0:1P802@D10P0910401@090`80
2@@000/5000;1P002PH100802`H100l02PD100P30@060P001P8000@200030P00100000<000040@00
1`@100H200070@001P4000<0000200000`00000020030@40108100D20@050`40108100D20@040@40
0`400`0200002P010@000`4000H20P0810802@H300T50@0810801P<100D300040002004000@00000
0P0100000`040P401P<100P40@0200P30P0500L30@060P401@4000@100020000Z`00000<0?ooo`00
2P3oool0500K3`@070d301`;0`0I2P@060T201@70P0C1P805PL101L50@0C1@405@H201@70`0@20<0
4`P201D70`0E2@<05`P301P90P0G20<060L20P0H2@809`0K2P@07`X301/:0@0J1P0060D101T80@0F
1P0060L001P70@0I1@4060H001X9000J2P006PL001X9000P2P808`/3028>0`0Q3@808PT201d80@0G
10405PH101X80P0H1`8060H101T7000J1`4060H101L60@0F1P4050800183000D0P0040800142000A
0`003P<000l400020144000W0185000C0`004P<001D3000C1@0050@101P40@0G1`405PD001H6000F
1`004`H101P70@0K2`807@/101h;0@0M1P007PL101d70@0K100070P001H9000C10403`<000`3000:
0P00204000X0000;0@0040<001<6000C100060H001X90@0N1P0070L001`8000M20007``200809a42
02L0:a4402/C100_50@0;Q@3030A100`5@<0;1@302/A0@0_4080;101030B0@0g5@40=1D1034F0P0e
6`<0<a`303HG1@0h6`@0>A`403DK100f6P@0=1X302hH0`0/50809@d002D<0@0R3@407@/101d;0P0L
2P806@T201P90P0F2P804@X2010:0P0@2P@04@X4010:100C30D00P0A30D01@0B2`@03PP200/60@08
0`001`4000801@0002000`0000@100060`001`8000H20007104020@200P50@060`00108000D10007
0P001P<000L300080`001P8000D300080`8020@200T50@0810401P<100P30@080`8020@100X4000;
1@002`@100`60@0;1@402`@100P300801P8000T0108000<0000200000`0000D100050`001@4000<1
00020@000P01000200000003004000020@000`8100@01@8100l01P8100@1000300000`0000800001
00000P4000D20@0910802@H200P30P060P401@4000<0000200001`0000000`0100000`4000@10@03
00D20@0500@20@050P000`0000<000020000Z`00000<0?ooo`002P3oool0500L30@07@d501T<100I
2`8050T201@80@0F1`005`P001D70P0G208050L301@70P0E20<06@T201T80P0H20<06`X301X91@0K
2`@070/30P0K2`807`0L2P806`X101/80@0J1P005@P001L9000F1`406`H101`80@0J2P406PT101d:
0`0K30806`X201X:0@0O3@<080`3020=0P0N2@8070L101H40@0B0P003`@101860P0C1P4050@101<3
000B1@404@@00184000E0P000P0?0@001P0<0@003P800103000B1@0050D001@40@804PD10P0E1@40
800E10005`L101P80P0F2`805@L201P60P0J2@407@X201X90@0I2P8070`201T<0P0O30806`P001X8
000J1P005P<00182000A10003P<000`300090P001`8000P0000600002P400181000A1@0050H001<4
000F1P006`T00P0M2@000`0O2P008@`102D?0P0202/@0`0V030D100^4`@0;Q8502dD100_4@@0:a03
02h@0P0/4P80:a0202hB0@0c5`80<AL3034E0P0b4`40=aL203@I0`0f6P@0>ah603`N1P0g6`D0=AP4
030G1@0_4@408``101l90@0N2@406PH201D80P0D208050X201490`0@1P803PL300d80`0<20<030L3
00d70`0>20<300h9100600d70P091P4020<100H100050@001@000`0200001`030@00104000@20005
0P001`<200H30@050@000P0300003@0400000`0000@0000300000P0000<100040P001@<000H40005
0`001`8100H200050`400P080`401P070`002@<000/50@0=1@402P@000P100801P8000<0100000<1
00030@00100300040040008000000P0100000`020@000`8100@20@0200@20@801@4100`010400081
000200000000004000030@401P<100L40P050P401@8000<00001000800000006004000010@000P40
00810@030@400`400P0200000`01000000000040002[000000`0oooo000:0?ooo`0D01X;0`0J3P<0
60l401P<100E2P8050/101P9000I2P8060T201L;0P0G20405PX301H90`0E2@805@X201D60P0H2040
5PX301P9100I30D201/<0`0301L<0P0H1`4060L200805@P102805`P101D70P0G2`@06@X201P;0P0I
2@8070l301d@0`0L2`<06`X1024<0P0O30807`/101`8000J1`4050D00103000>0`004@@101450@0>
0P003`800183000A0`0050<00185000?10002`<000`2000?0P004PD001D6000F1P404PH10P0A1@42
01<50@0U01P70@0J20405`T201@90@0E1P806@P201X;0P0K3@407@h201`;0P0K2@8060T001H5000E
1@004`D001D3000>0P00304000d2000:0P003@4000/100090P001`0000T1000?0P004P4001H4000F
1@005`D001T9000N2P407@X101l:000Q3040918202TB100202`B100H02lC100Y3`<0:@`102T?0`0V
3P4090h202PC0P0[4P80:a<2030E0@0f6`@0>Ad5034I1@0`60<0<QT1038M0`0d6PL0=Qd603@O1`0^
6PD0;QH302L?0P0R3P806@H00P0B1@401P0A208040L301480`0A2@<03`P300d70`8030L300D030L2
00`70@0=1P802`H200X60@0200X50@0500L40@060P40108000@1000400000P010@02008100800P00
00L00`4000@200050P801@8000@100010@000P0000<00@0000T000000040000100000P0000<00004
0@001@4000H200030P000P040P400`050@401P8100T30P0200X50@0;00L50@070P40108100@20@03
0@000P0000410001000000000040000000001@010002000000800@0000<00P4000<10@030@400P04
0P4200<1000:00810001000000000040000300000`4100@10@030@000P00004000P0000020010002
0000000300400000000000000:X00000303oool000X0oooo00X05`X301X=1@0G3@H05`/501D;0`0C
2P0050/001T70@0G2`8060T20P0D2@40200D20804PP101470@0A1P404PL201@80`0I2`D06@d30P0J
2`809`0E2P805PH101@60P0D20804`P201890`0G2P<05@/401H;0P0H208050L201T:0P0M3@@070`3
01`:0P0J2@807PX101T70@0F1P404PD001<2000?0`004@8001<50@0<0`4030@000l3000@1@004P@0
00l50@0B1@404P@10104000@10404PD101D60@0D1`005`H001<60@0201470@0W0185000C1P0060D0
01L80@0F20806@X201T:100H2@807@`201l;0@0L2`405`T101@7000B1@004P@001@5000@0P0040<0
00d1000?0@00304000h3000B0@00308000`1000<00003@400142000C0`0060H001/8000K1`007PT1
02490@0O3@4080l102@A0@0]4P<0;A<50080:a8201X0:a42028>0@0U3P009Ph002<>0@0W3P809a42
02XB0P0/5040<aH203LK1P0e6`D0=1L303DG0P0^6P<0;aX302lH100_5`D0:a@7028>0`0N2@<06P`1
01D60@0?100030D000d50@<030H100P03@H200h70`0<1`<02`D400`6100;1@802PD100P40@8020<0
0P060P000`040@001@4000<1000200<000800`4000T01@8000@200030@000P00004100030@001081
00@2000200000P010006000000040040000200000P00008100<00`400P040@0200H20@0400L20P09
0`8020<100D30@80108100<00`4000<0000200000P010003000000D00@000P0000001`0100000@40
008100030@000`4100<2000300000P010003000000@00@002`0000000`01000000000000002c0000
00`0oooo000:0?ooo`0D01@70P0E20<04`X301@80P0D1`0040D001460@0D2@8050T301480`0C2080
40P100h7000?1`004@@100h60P0@1P8050T401D<100G2P<2018:0P0W01470P0B1@404P@101850P0@
1P804PL201880P0F2@805PP201L70@0D2@405`T301T;0`0K2`<060/201H90P0F1`4060H101H50P0D
1P403PD100l4000A1@003`D10145000>10004@@001D60@0C1@404PH101D40@0F1@404PL101D60@0E
1`404`P101H90@0E20404PH100805@H101P04@D001@4000F1@006`T201T:0`0I2`8070X201T90P0I
2P4060P001H50@0F1@004PD100`5000=0P004`@000l6000?1@004P@00182000B0`005PD000l2000<
0`0200d2000=0105000E1@0050@001P4000L1`0080T0020<0@0O304080d102<>0@0X4P80:A0202H?
0@0202P?0@0W02H=0@0R2`0090d002D?000W4@009@l002XA0P0/4`40:aH2030E0@0`6@<0;AL302dH
0`0^4P<0:A<302TD100X4@<0810301X;0P0F1`404@H001060@0<1P4020@000X4000;0`002@@000/4
0@091@803@L300`70`0:1@<02PD200T50P0810801`<100D300060@001@4000@00`000P0200001P02
0@000`8000@30@0610401@@100@100800@0000@00@4000<1000200000@001`0000000`0100000000
00400006004000800`4000D00`8100H20@060P40108000<2000200<10003008000010000000000H0
000000@00@00004100020@000@000P000005004000800`00bP00000<0?ooo`002P3oool0500@1@40
40H200h40@0=0`003P@000h50@0?1P404@L201880P0?1@803`L200d60P0;1@4030@100d60P0?1P80
4@L201@:0`0E20<04PH20P0B1P409`0?100030@000l3000@1@404`@101@50P0E100050L101H5000E
2@405@L101H;0`0J2`@060T301@90P0E20405PP101H60@0B1P804`L201860@0@10003`800104000B
10004PD001<5000A1P004`D001@50@0B100050@101L50@0F1@806@T101@9000G1`005`P001<70002
01<6000L01<3000D10005PH001L90@0D2P805PP101D5000D20005@H101<3000@100040D00104000=
0@003P4001470@0@1`004@@00146000E0`004@D001H2000@0`003P400104000D10005`H001H80080
6`P000T070/0024<0@0R3@407PX002<?000S3@0090`002<>000O3@000P0Q2@40600N30408P/102D?
0P0V4@809QD202PB0`0W3P40918102PA0P0X4P809Q<202H?000Q3P008@d2028=0`0S3`<07Ph301H<
0P0A2P4040D100`50@0:10402@D000X30080208000H01P8000L200080`802`H300X50`0:1@8200T4
0@0500P30@080`001P<000D200040@000`0200001@0100000@40004100030@00108000801@<000@0
1P8100@10001000000000P0100000`02000000000000000?000000<00@000P030@02008000/00000
00@00@00008100020@000P0010000002004000800P00b`00000<0?ooo`002P3oool0500<0P002`<0
00P2000:0P002P<100X50@0=1P404@P300l60P0@1`803`P300d60P0;10402`D201070P0B1`805@L2
01480P0A1`4040D10P0<1000400:10003@<000l2000C0`004@<000l4000=1@003`8000l3000C1`40
4`P201890`0D2`8050P100l80@0B1`4201@60@0E01450@0B1@404@@001<3000B0`004`<00184000@
10004`@001<6000B1@0050D101@40@0F104050@001T80@0F20005PD101870@0F204050H1008050D1
00T04`<00103000E1P0050L001@70@0?100040D001<70@0A1P400P0B1P40700?10003P4000l2000C
100040D00145000A10004P@001<5000B10004`@00183000@0P004@@001D4000H1`0070T001h70@0K
200080P00248000O300080h002D@000R2`007`X001h:000K2@0201T:000E020:0@0N2@808`d302HB
0P0Z5@D0:185024@0`0O3`8080h1020>0P0M2`4060/001P9000H20806PX301T90P0E2@804@L100l7
0@0>1P403@<100802@D001002@<000L100070@00104000D1000:1P802PH300/70`091P<020@100L4
0P0810401`@000H300050@000`401`0100001@030P00108000@200040@000P0000<000000P01000S
00000004004000030@000`4000800=<00000303oool000X0oooo01@02@4000H100070@00208000T3
0@0;1@403@D200h40P0B1`8040H300/50P0;1P802`@100h40@0?1@803PH201460P0@1@8040D100`4
00802@8000@0308000d4000?10404@@10P0=0`403@0>0`002@8000`3000@10403`D101850@0B1P40
4PL101<60@0E204060L001L4000C1P000P0C1@00100>1P004PD001L4000A10020146000<0186000C
20405@D101860@0C100050H001H8000G1@004`@001<5000D10004@<00`0C0P009P0A10004P<001<3
000;100030<000d3000@1@004PD101460@0C1@4040D00181000C0P0060@00144000C10004@D00104
000B0`004@<00185000A100040<001<6000H1P407@P00249000Q2`4080P001`7000O1`007`X0028;
000Q2`407P/001l:000N20006`P00P0I1P009`0M2@0070P101h;0`0U3P80:A4302@?100O30806`X1
01P<0@0K2P005PX001D9000C20004@P201880@0@20403PH000d70@0;1P8030D200T40@0:1@002P@1
00T400070P001@4000@00006108020D200P60P091`802PH300X50`091@802@@200X50P080`001@40
00810002008000800@0000<000000040000200001002000400000003004000000000000002400000
1@01003C000000`0oooo000:0?ooo`0700H000040@001`4000P10008100020<000`40@0201060P08
01470P0>1@403@@100/30@0=104030<200h40@0>0`0200`3000F00`1000>0P003P8000`3000@0`00
3`<100h30@0=0`403@<000d2000;0P003@8001440@0B0`404P@001<6000D1P005@P001D7000B1`00
3`L001@400804P@001804`@00144000C100050@001@6000C1@0040H000l70@0C1@004PD001060@0A
1@404PL101@6000C1P004`800182000@0@030102000R0103000@0P00408000d2000>10004@<00183
000C10004P@000l4000C0P0050<001@4000E1P004`L001<5000@1P003`@00183000?100040D001H2
000E0`005`H001T70@0I20006PL001d7000K2@0080X001l:000P2P8070T201`900808@T001h07@T0
01L:0@0H1`0060L001/8000K2`4070d201h?0`0O3@<07@T201L90@0C20405@X1018;0@0D20005PL1
01<90P0B1`<040D100h500090`001`<100/50@0:1@402@D000T4000;1@4020@000L100040@0200@2
0@0500D30@061@8020D200T60`0;1P<00P091@800`0:1@801P8000<2000300810003004000000000
000000P00@00oP00000<0?ooo`002P3oool02`020@000`4000@1000800002@8000L2000;0`403@<1
00h60@0>10003`<000<03@<100H0308100X40@0<10002`@000h3000>0P0200d2000W00d3000A0P40
3`8100d30@0>10003P<000l3000>0P004@8100l40@0B10004`<001<6000H2@405PT101@6000C1P00
4PD00183000A0`0040<000l3000C0P004`<001<8000G1`0050P201@50@0@1P003`H000l50@0A1P40
3`D101460@0B10404@D000l4000=0`0040<000804@4002L05@8001<3000C0@00404000h2000@1@00
4PD00145000>10003P<00185000F100050D001H7000G1P0060D101@60@0C0`004@@001@3000C0P00
50@001T3000F1P005`H001T6000I1`005`P001X;0@0K20007P/2020:0@0O2@8070P101X8000M2@00
70X001X7000H1`000P0K2@009@0M2P006``101/<0@0L2`<06P/201P90P0D20404PT101@70@0F2040
5PT101H:0P0C2P804@L101060@0;1@002@@000P3000910002@<000L30@090`0020@000H300050000
0`0000<100020@000P4100D20@071@8020D300T50P071@402@D100P30@040@000P02000200410003
004000000000000000@000001@01003m000000`0oooo000:0?ooo`0700@200030@001@0000L10008
0@001`8000X20@0200X2000;00`4000=1@0030<100`40@0>0`4030@100/20@0:0P0030<000l2000@
10000P0@0P40200?0@403P8000`3000>0`004P8001440@0B10004`@00P0C1P406P0F20005P@001@6
000G1P005`T101<7000A0`0030@000h3000=0P003P8000l2000@0P004`@001@80@0G1P405@@00106
000?1@404P@101860P0@1P403PD200h60@0@1@004@D00P0@0P004@0<0P003@<000d3000?0`004`<0
01@2000C0P003P<00146000B20404@D00182000>1@004`D001P5000D1P005PP000805`P000X05@L0
01@4000C1`4050@10185000G1P006`H001L3000H10006PD00P0I2@002`0L2@008@`101l<0@0S2`40
80X101`8000K1`0080L101d:000K2@006PT0008070`101808@h101d;0@0I2P405`H001L80P0B2040
4PH101<60@0C204060P101L90P0E2@804`T100l80@0>1P403@D000P400080`0200L3000500L20004
0P001@8000D0000300000P020@002P0200000@0000<10@050`401`D200L30@060P401@<100@10001
0@04004000T000000`01003m000000`0oooo000:0?ooo`0B00H200080@00208000T100070@002@40
00/1000:00002`0000d3000>10003`D101830P0?10803PH200h50@0?1@003P<00P0@0P0200h1000W
00l1000@10003P@00144000A0`004@@00186000E1@0050P001<8000E20404`H001H4000E1P0050T0
01<6000?0`0040<000h2000A0@0040800141000>0`004`<001L5000G0`0050D00104000>10003`@0
00`6000<1@403@@00145000@10004@800143000@10004@8000803PD002L04@@001<6000F0`004@<0
01<40@0D1`404PH000l4000@0`004@<001<3000C1@005PD001T5000F1`005PH001<5000E1P005`L0
0147000D20006PP101T60@0H1`405@D001T7000J2@405PT101d<0@0R3@008P`0020;0@0Q2@4080/0
020:000R30408`h0020>000O3P000P0P3040500Q3@0070`001P7000D1`004`L001070@0C1P405PT3
01L:100F3@<060/201D;0@0A20003`L000`50009100020D000D30006000010000`0200002`010000
0`40008100030@000P00004000020@000`8100@20@040@40104000800P0000<00@00000000000000
o`00000<000000`0oooo000:0?ooo`0400T200090`002`8000T200801P000P090@00300;0`003@<0
00l40@0@1@804`L201060P0B1P803`L200l4000C0P004P@0010400803`8002L03P400102000@0P00
4P@101040@0@1@405PH101D80@0F2@4060P001P70@0D1P4050@100d40@0A1`0040D00103000@0P00
4P8000h3000A0P00408000/4000?0`004P<00182000C0P004@4000h2000;100020<000`3000>0`00
3`800102000A0P004@<00184000B0`000P0B10009`0B1@004`D001@30@0B1@404@H101050@0A1@00
3`<00102000@1@0040@001@4000B0`004`<00185000@1P004`D00186000E1P4060D101H5000G1`40
70L101T6000I1@006PH001X90@0K2`407``0028@000O30008@h1028>0@0T3P009@`102P@0P0T4`40
914201h@0@02024?0P0D024>0@0K2`405`L001H7000F2@805PX301H:100I3PD06A0501P=0`0F3@80
4PX100l40@0:1@001`<000H20@050P001@4000D000010004000000040040000200000P0000800080
0@000P020@000`0200000@00000000060000000300400000000000000?l000001`00000<0?ooo`00
2P3oool0500;0`402`@000`4000:0P002P0000X1000;0P403@8100l50@0A1P803PH301<80P0D2@<0
4PH201480P0B10404P@001@4000@1@0040@00P0?0P003P0<0@003P400142000C10004P<001D50@0G
1`406@T101H80@0F2@405@L00146000A0`0030<00P0?0`00400<00003@000103000>0`00408000d1
000;0@002`@000d4000<10003@@000h2000;1000208000T3000;0P0200l3000500l1000@10004@@0
01<4000F0`000P0D10009`0H0`004@H100l50@0?1@403@D100h40@0?0P003P<00145000D0`004`<0
01@3000@0`004@400101000A1@005@H001H6000I1@805`L201@70@0I1@007@L001/70@0J1P006PP0
01`;000O3@407`h0020@0@0Q3P407``202<>0P0X40<0:A4302TD0P0W5`809A<2028;0P02020=0P0A
01d=0@0H2@005PX001<90P0F3P<0610401`@1P0K40H060h501X>1@0A2`<03PD100X400060`002041
00D100020@000P020004000000<00@001@000002004000P0000000<00@00000000000000o`000007
000000`0oooo000:0?ooo`0300l60@0>100030<00080308000l02`@100`60@0A1P404PH101060@0?
1`804PP201<90`0A2P804PP101450@0A0`003`D00144000A0`000P0=0P009`090P00304000h2000?
0`0040<101860@0E20805@L101870@0B1@004`@000h3000=0@002`8000T2000900001`0000X1000<
0`003P8000X100090@002@8000`5000@0`003`@00102000=0P002`@000/2000=0P003`<000d4000>
0`003`400144000C1@004P@00142000201<3000W01830@0C1@403PH201040@0=0`0030<00141000A
0P004P<001D40@0C0`004`8000l0000A0@004P<000l5000B1@005`L101T60P0H1`806PL101T5000J
1`406`T201T:0P0K2P4080`2020<0@0O300080d102<>000S40809A8202HC0P0V50809aD302PD0`0T
4P<08A0300806`d201006@`301L;0P0F2`@05`h301/?1@0I3`H06Q4401/?1@0G3@@050X201060P0;
10001`@000H200040P000`400`02000;00000003004000000000000000H000000P01003o000000X0
0000303oool000X0oooo00H040H100h4000?10003`4101030@0?1@8300l60@0:01460@0?1P404PD2
01460`0@1`003`D000l4000?0`003P<0010200<02`<001P0204000T0000<0P003@<000X2000@0`40
40D101840P0@1@403@@000`2000;0P002`4000`1000700001P4000L1000900003@4000h1000=0P00
2`<000X3000>0P0300h3000<00X3000;10002`<000h30@0@0`4040<00181000@0@0050<001D4000C
10004@@00P0=10009`0B10404PP100l40@0>0P002`@000l3000@0`004P@00143000B1P403PD100d2
000@0P004P800183000A100050@001D6000F20806@`201X;0P0J2P4060X101`;0P0N2`406`l101`?
0@0O3@8080X0020=000O3P008Ph1028A0P0V50<09a<202HE100V4`@09A<6020A0`0201/=0`0C01H9
100D2`<05`/401H>100G30D060d601H<1@0D30D04PT201470P0<1P802@<000L200050`000`000080
000100000P000040003o000002000000303oool000X0oooo00/03`D100d3000>100040H100l60@0>
1P803P@100d40@0:0P403@8000d4000200h4000400d5000=0`0030<000d200802`4000T0204000L2
00070P001P0000D000080@00208000P100090`000P0<0`001P0;10002P4000P000080`002`<000`1
00801`4001L02@8000X0000<0P0040<00142000>0`00204000l3000?0P00408000h1000<00003P40
00h2000A0`0040<000h4000@10004@<00183000D1P003`H000/500020103000W0182000D1@4040@0
0183000@10004`D001@60@0A1P404`@100l40@0>0`0030<000l3000B0`005@@001@6000G1P0060T0
01P<0@0L3@407@d101`=0@0N2P407Ph201/>0@0N30807P/201d:0@0H2`0070T001h;0@0M3@807A85
024C0`0T50@09A8602LC1P0R40@06`l3008060`200l050T201D80@0E20804`T301@;0P0A2P<04`X2
00l90`0?20402`D200/50@070P001@4000@1000300000`01003o000002400000303oool000X0oooo
0140308100l2000=0`0030@000d3000<10402P<100X200070P002@8000T300090@002P4000X0000:
0@00204000P0000500H1000@00D1000500001P0000D1000500001P8000X3000:0P00200000X00009
0000304000/3000;0P001P4000P200802@8000l03P800104000A0`003@<000h3000=10403`@100h4
0@0=0@003P4000d1000>0P403P@000h40@0=0`400P0?1@00100B0`004PH001<7000A200201@5000W
01@50@0?1@003@<00143000F1P005@L001L9000D2@404`<100d4000<0`003P@001<4000F1@0060@0
01H8000I2@006PX101d=0@0O3@407@d201/;0P0K3@405PX001/8000H1P005`X001P90P0G2P805`T1
01`<0P0M40@08Q84024B0`0R40<08a4501l?0`0H3@<05`X200805@P100`040T101060@0?1`404`L2
01090P0@204040T200d80P0;1@002@@000L200040@0200<00?l000009@00000<0?ooo`002P3oool0
1`090`402P<100X300090P001P8000P100070@000P0700001P080@00200000H100070@001`0000L1
0080200000<01`0000D0000600000P080@001@070P00104000D000050@001`4000802@4000d02P00
00T0000<0P003@4000/1000<1@003@<000X2000=0@003P4000d3000?0P4040@000804@@001403P<1
01440@0?0P403P<00102000?0P003`4000l2000?10403`8100h4000=1@003P<00145000D10004PP0
01D70@0201D60`0801D50@0?1P4040@001430@0I1`0060L101L:0@0D1`820104000M0102000C1@00
4`H001H60@0H1@006PP001h90P0M2P006`P001P:000H2@4060/101<90@0E1@005@800185000B1`00
60P101L90P0H2P4070d301d?100Q40@07`l301/=0@0K2`<060T00188000B1P000P0>1P003@0=1P00
3@L100l80@0@20803PL100`50P0=1P802PD100P500070P001@4000@000010000o`00000V000000`0
oooo000:0?ooo`0400P30@081040208100H100801P0000T00`0000D0000200001@0000H000050@00
1P0000L100040@000P080@000`060@001`0000T0000200`2000W00X300080P001`8000P200080`00
2@8000T100070000308000h40@0>0`403P8000h4000>104030<000l3000=0`003P@000l40@0A0`00
40D00183000A0`404`@10142000?0`004@8000d1000@0@003P8000l20@0?0P00408000l1000>0P00
4P@001@6000E20405`P200805@X302H04PD100d6000@1@005@@101L60@0G1`405@L101860P0?1@00
3P@00105000B1P005@@001P3000I10005PP101`90P0M204060D001<5000D1P004PD101@5000@1@00
4P@001<5000F1`005`T101P70P0J2@4070`301`>0P0J3P<060d101P:0@0F1P003PD000l500<03@D0
00X030H000h70@0@2P<04@T200l80@0<1P401`D100L300060P001@800P03003o000002L00000303o
ool000X0oooo00@02@8000L100060@001@000P0400030080000;00@0000700001`0000P000090@00
200000X0000;0@00208000/2000=0`000`0;0`007@0<0P002@4000T1000:0@002`4000T1000:0P00
2`<000h4000@10003@8000d4000>0`003`<000h6000B1@0040D000l50@0?1@004@H00143000A0P00
4@<00142000=0000200000d0000=0@003P8000803P<000L04P400142000>1@003PD00146000E1P00
5PL100804`L102<04P<000h4000@1@004PD00146000A1@004`<101030@0>0`003`D001<6000C1@00
5@D001L5000F1`405PP201H90P0H20804`@00142000@0`004PD00104000C1`004PL001<70@0E1P40
5@X101P90`0J2P406@/301T=0`0F2P405PT201@7000200l6000<00d6000<1`4030H000`6000<1@00
3PL101480P0>204030L100T50@070`001@400P030@000`03000000000000003o000002H00000303o
ool000X0oooo00<01P0000D0000400000P04000300<0000<00@0000500001`4000/2000;0`002@80
00/2000900002`8000/3000@0`403P@00P0>0`004`0;10402`8000X2000:0P00208000P100090P00
30<000d3000>1@003`4000h1000=0P403@@100d50@0?1`0040D00104000@1@000P0A10001@0B0P00
3`400141000A0P003P8000803P4000/040<00183000?0P003`800101000@1P004@H000l4000A1@00
4@L000d600020103000400l1000=0@003`80014200803`<000H02`D10104000@1@003`H101<70@0D
1`4201D80@0>01<70@0D1`8050P201<80P0A1P403`D10104000A1@0040H001470@0C200050L001D;
000F308201T;0P0901P=0@0G1`805@H101<70@0@1P003`D100l80@0?20803PL1008030D100P02`<1
00`400091@002`@100/50@090`00104000<000800P00o`00000Y000000`0oooo000:0?ooo`0<00L0
000600000`0000@000030@000`0000@0000600001P4000D2000;0`003P@10P0;10001P0;0`003P<0
00d3000>0`003P<1010300803P@000L03P<100h2000>0P00308000X000080@002P8000802P<00100
300000/0000<0P004@<100l40@0B1P404@L00185000@10004@<00144000E1@003`<000l2000@0`00
4@<00P0>0@00300>1@004@H00106000@0`003P4000l2000A10004`<00143000@100040<001020080
3P8000X03`4000`2000=0@004@0000d2000=100040@001<4000D1@004`H10P0E1`406`0C2@805@T1
01<90@0D1@0050H101470@0C1P404`P201860@0B1@004`P001@70@0F2@4050d101L>0P0H3`8070l2
01X>0P0G30405@P001<7000?1`003@L100h70P0A20<040T200d60@0200X5000600T300060`001@80
00H300070P0010800P02003o000002/00000303oool000X0oooo00<01@4000D0000500000P030@00
1P040000104000L1000710002@@000/3008030D00P0<10001@0=10002`@000`3000@0`003PD00080
3`D000D03@@100l300090`002@8000X1000200T1000P00X2000:0@002P0000T2000@0P003`D10144
0@0B1@004@L001D7000A1`004PH00146000C1@004P8000l3000>0`003@8000d3000?0P0040D000h6
000?1@003P<000/1000;0P003@@000l4000A0P003@@00103000>0P0200d1000J00/2000;0`003P40
00h3000@10005PD001@6000D1`404PH101D80@0D1P405@H001L70@0E2@404@P10147000A1@004PH2
01@90P0D2`8050P001D7000C1`405@X201D;0@0H3`8201T?0`0;01/@0`0H3@805PX101@8000?1`40
3@H000d5000;1P802`H300/70`0910400P080`001`050@000`0000<100030@000P40008000010000
o`00000/000000`0oooo000:0?ooo`0D00@200040@00100000<100040@001P0000L1000:100030@0
00`5000<1P003@D000`6000;1P002PH000/5000<1@002`<000h2000>0`0200d5000500d4000;0`00
204000L2000;0`000P0:0`005@090`001`8000X0000>0P003`@00105000@1@404`H10186000C1`40
4`T101H9000F1@004PD00141000>0`003@<000l3000@0`004P<000h4000200/3000800d2000;0@00
2`4000l4000B0`0030<000`4000>100300h3000?00`2000?0`004@800104000B1P005@L001870@0C
1`404PL201@70@0G1P404`L001H6000G20404`H0008050L101H050H001H70@0D1`004`T001L8000F
20406@`201H=0`0F3P<05`d301X=0`0I3P<05@/20147000>1@0040D000d5000;10002@D100P50P08
104020400P060P000`0300000@000040000200400?l00000;P00000<0?ooo`002P3oool02@060P00
1@4000D000030@00100000T0000:0P002P<000/4000201050@090106000>1P003PD000/4000;0`00
308000d1000>0P00308000<02`<002H02P8000/1000:0`002P@000T300070`0020<000T1000;0@00
3P8000l4000B10004@H101850@0F1P005PT101T70@0F20005@H00143000A0@003P<000d4000>0`00
3`<00143000=10002`8000X1000;0@003@4000l1000?10004P<000`2000>0P003@D000d600803P<0
01l040<001@5000B1P004`L001@5000E200050X101H80@0F1`405PH001@6000G1`4050P101<9000E
200050D001<7000D2@0050L101850@0A1`405@P201P:0P0H3@806@d201H;0`0E2`<05@P101D80`0A
1P802@D100802`@100H02`<000D30@060`401P<100D20@050@0200@1000300800000000000000?l0
0000<000000<0?ooo`002P3oool050060`001@4000H000070000204000/0000<0P003@<000d60@0A
1@403`H10146000<1@0030@000T2000:0@00300000d3000<0`0030400P0:0P007P090`00308000`2
000:0P002@<000D200070P00200000T0000:0@003P8000d3000A100040D10187000F1`005PT101L8
000H1P004@@00183000@0P003@@00144000@1000408000l3000=1000308000T20080308000L03PD0
00l3000>0P002`8000/4000>10404PL100804@D100h04`H001@:0@0D20005@L101D80@0E2P405PP1
01@90@0E1@405PH00147000B1`405PD001D700804`P100l050T1018:0P0E1`405PL201890`0E2P<0
5`/301P>0`0G2@804`X201480@0B1@003`@100h50@091@400P0910401P060`001@<000@200040@00
0`40004100800@00o`00000c000000`0oooo000:0?ooo`0<00P200080`002@<000/200090P002P<0
00`5000<1`003P<100h50P0?1@4030@00P0:0P001P0900001`0000L1000:0`0030@000`200802@40
00@03@8000h2000;0P002`400P0800006@060000200000L0000;00002`8000`1000?0`0030D000h7
000C20404PL101<7000B1P404P@00103000?0`0040@001470@0A0`404@@100l60@0>1@403`@000d3
000?10000P0=1@001P0>0`0030<00104000A1@404`L101H80@8050/100<060`101T<0@0I2`000P0F
2040800D2@4050L101@90@0B1P004@D000l7000C1P005@H001@4000D1P4050L101@70P0E2`805@/3
01D90`0E20<05PT301P:0`0F2`<05@X300l:0@0>1`4030H000h80@0<1@802@D200P40@080`401P80
00D1000400000`000P01003o000003D00000303oool000X0oooo01@02@<100X40@0<10402P<100/5
000>0`003P@000d6000;1@003@@000/400090@00204000L100060P001P4000P1000:0P002@@000X3
00802`8000@0304000h3000;0P002`400P080@0200T1000H00L000090@002P4000/2000=0`0030<0
00h4000@1@404PD101450@0C10404P<10184000>100040@101<80@0B1`404`L10147000B10404PD1
0144000>1@003@@00P0@1@401@0A10404`D001<80@0D20405PX200806`/200X05`T101X=0P0G2P80
5PT001D7000D1@004PH00147000@1P003PD00P0A1`005`0B10004`@101840@0D1P804`P201D90P0D
2P<050/301D8100E20<05@P201@80P0B20803@P100d5000;10003@L100X60P091@8020@200P30@05
0@000`4000800@00o`00000g000000`0oooo000:0?ooo`0D00T30@0=10402`@100/5000;0`403P<0
00X5000>10002P@000X5000:0P002@8000P1000700001`4000P100070P002@8000T3000:0`0200/1
000<00`2000=0`002`@000/300090@002@8000P3000:0P001`4000H1000<0P002P<00P0<0`006@0=
1P004PD001<50@0A100040@101830@0@10004@D001D80@0D2`405PT201@90P0A1`4040L101450@0@
1@0040@101860@0@1P404PD101870@0D2@404`T101P90@0J30<00P0L2P807P0I1`005PT201H80@0C
204050D10185000A1`003`H00143000>1@003`D00146000D0`004`@101<60P0B20804PP301@;0`0F
30<050/301860P0C1`404`P101<60@0=1`4030@000/40@0;1P802`H100T40@8020@100@01@<00081
000100000P00o`00000h000000`0oooo000:0?ooo`0D00X60@0:1@402`@200T50@0:0`402`@000`3
000<10002PD000T300090P001`<000L1000500001`0000H000050@4020<100T20@080@0200T0000;
00`1000=100030@000T400070P00208000X200080@001`4000T1000=0@000P0?0`006P0?1P0040H0
0147000B1`004@D00184000A0`0040@001<4000D20405@T201L80`0F2@804PH101060@0@1`403`H1
01470@0D1@005@D001890P0D1`4050T101D80@0E1`4060X30P0H2P807P0B1`004`D001<50@0@1000
4P@00143000A100040D000d3000<0`003`@00104000?10403`H200h60P0A20<04PT301D:0P0C2`80
4`T201480P0C1`404PL101450@0?10002`@000`3000;10002P<000L100801@8000<00`4000400000
0000o`00000i000000`0oooo000:0?ooo`0300T5000:1@4020@000802@<000<02`@100`50@0<1P00
0P0910002P0710001`8000L100030@001000008100030@001@8100D100070@0200X0000A00/2000;
10002P@100X400090P002P8000h2000<0@003@4000d3000@10004PH001<60@0A204050X001<9000@
2P000P0@1P0200l6000B01<60@0G1`805`P301H90P0H1P8040L200l70@0A1P404PL201860@0C1`00
5@D1018:0P0C2@4050H001<7000C20004PH00P0C1P007P0A0P003P8000l4000=1@003P8000`2000<
1@0030@000/3000=0P003P<00143000?1`804@T200l80P0@20804@P201@90P0C2P804PX2014:0@0@
20003`L000d4000;0`002PD000L400080`00104000<000800P000P01003o000003X00000303oool0
00X0oooo010020<000T50@09104020@100/30P0=1@4030H100T50@090`0020@000H300060@001@40
00@1000300001P400P050@005`080@001`0000P100080@002P8000X4000=0`4030D000X4000=0P00
40<000l3000A0`004P@001<80@0D20404`T1018:0@0B20004`D001<7000@1`003`L000804PL000H0
4`L101P70P0G2P<05`T201@70`0?208201460@0:01890P0B1`404PL101@70P0@20404`D000l7000A
1@003P8000l300@03@800P0;0`003@090P002`8000X3000=1000308000/4000?0`004@D201490P0B
2`@040T200l60P0A20800P0D2P802P0B20003`P000h7000<1@003@4000L200080P001`8000D00003
0002000000800@00o`00000k000000`0oooo000:0?ooo`0A00H30007104020H100X50P0<1P802PH1
00/60@0910002@8000L300080@001P4000D1000400001`0000H100070`000P060@0050060P002080
00P2000;0P00308000d5000<1@0030D100l50@0B1P005@L001H6000D204050X101D90@0A2P404@T1
01<7000B20004@X00P0B2@00300B1`004`T101H80@0G1P4060T201L70@0D208040D100h50@0@1P80
3PH200h70P803PD100H030<000d3000:0P00308000P1000:0@0200d1000M00`2000>0P002`@000T2
00080P002@<000`4000?0`003@@000d3000?0`4040H201490P0C2P<04`/201490P0A20804PT201@9
0@0?1P003@D000T400090P00204000L20@070@401P4000@000010000o`00000o000000`0oooo000:
0?ooo`0@00P20@080`802@D100X70P091@402PD200L30P080P002P8000/100060@001@8000@30007
0@001P4000L5008020800P090@0200/1000S00`3000=1@003P@000h4000=1@404@H101880@0F2P40
5PT101T90@0G20404`P101070@0A1@004PL001@:000C2@805@X101<80@0F20405@P101H70@0F1`80
4`P201<7000?1`403@H200h70P0<1P403PH100`50@091@402@<000X200080@000P06000080060@00
2P8000d3000=0`003@@000h30@0:10002P<000T2000;0P003@<000d5000=10003P@000h5000A1`40
3`P101890P0@2P<04PX301490P0B1`404`L100d50@0<0`001`8000H1000500001P4000L100050@00
0P000P0100000`0000000@000000003o000003/00000303oool000X0oooo0100208100P30P091@40
2PL200T50@0:1@801`<200P2000:0P002`4000H100050P0010<000L100060@001`D00P080P0200T1
00802`4002<030<000d5000>10003P@000d50@0A1P404PP101H:0@0F2@406@T101L80@0C204040L1
0145000B1`0050X001<90P0E2P404`P101H80@0E20405PL101H70P0C20804`L000l70@0=1P803PL2
00`60@0>1P4030D100T50@090`002P8000P1000200H0000P00H1000:0P003@<000d3000=10003P<1
00X4000:0`002@8000/2000=0`003@D000d4000>10003PD001470@0?20404PT2010:0`0B2P<04@T2
01870@0C1`403@D100`300070P001P4000D000060@001`4000D10002000200400003000000010000
00000?l00000>`00000<0?ooo`002P3oool050080`4020D200T40P0:1@802@@100L30P080P002040
00X300090`40208000D200060`001`8000P300090`002P@000T3000<0@002`800P0?0@00300@1000
4P@00103000<1P004`H001D80`0E2`<050d301L;0`0F20804PT100l600804PD001T04@T101<;0@0E
2@8050L101<6000C1`4050P101D70`0E2@<04`T201460@0?1P803PP200`60@0:1@002P@000`4000;
0`002@<000H1000900001`0000L1000:0P004@80008040D001/03PH000h60@0>1@003@D000`3000<
1@003@D000h6000?1@0040L001070@0?1P403PH101480P0C20<04`P101480@0?1`003`L100/50@0:
10001P4000D0000600001P4000@100020@000P02003o000003l00000303oool000X0oooo00/02@<1
00L30@070P401`<100T30@070`002@8000`2000<0`002PD100T2000200P2000700L3000:0`0030D0
00/4000=0`003`4000l3000200l4000>0186000C1@0040H000h70@0B20805`T201H90P0F20805PT2
01890@0@20003@L00107000A2@0201@:000G01<7000A1@003@D00107000A1`004@L100l70@0A1P40
40P100l70@0=20403@H100h4000<10003P@100T3000;0P00304000T000090@00304000h4000B1P00
0P0C1P406P0@1`403@L100l6000@1@003@D100h60@0=1P0040D00107000B2@8050P100h70P0?1P40
4@H201470P0?1`4030@100/3000:0P402@<100P200060000100000@1000400000P000`01003o0000
03l00000303oool000X0oooo00P020<000L300070P40208100X3000<0`403@@000`300<02`@100T0
2@8000/200090`00308000d3000<0`003@@001450@0A1P400`0B1040300B1P003@H100h80P0B1`80
50P301D90`0E2P<04`L100l8000>1P0040H101080@804@T000H04PL101080@0;1`003`<000l4000>
1@0200h6000@00l70@0?20403PD100X50@0;0`0030@000l3000>0P002`<000d1000;0@002P8000/3
000?10004@L101D70P805PL201L050P101430@0B1@003`H100h70@0>1P4030L100d6000?2@404PX2
01<90P0?1P003`D100l70@0>1P4030H100L300060P001P4100D100040@00100000<0000200800003
00400000000000000?l00000@000000<0?ooo`002P3oool01@080P002@8000T100090P002P<10080
40@100@030@100d50@0;0`003@<10P0=0P001`0<0`002P8000X1000=00004@D001<80P0B20400P0B
1P409`0A0`002`D000h50@0<1P403`L201860`0A1`804@P100l80P0;1@003@@100l60P0B1`8040H1
01@80@0@20804@L100d5000>1@404@H101050@0?1@003@@000h70@0<1`4030@000X2000<0P003`80
00`3000@10003`8000`2000;0@002`<000h5000B204050P101@:0P0201D:0P0=01@80P0A1P403PH0
00l70@0B1`4040L100h60@0<1@4040D101070P0?20803PD000d6000200h60@0300T30@060@000`80
00800`4000<01@00008000020000o`000015000000`0oooo000:0?ooo`0D00P1000<0`002`<000X3
000910403@D200h60@0=1P4030<100X2000<0P003P<000l2000=0`002`<000X2000<0`003`<101@5
0@0A1`4200d70@0S00`40@0:0`002P@100`60@0:1@403P@201070@0>204030@200`30@0>104040L1
0105000B1P004@D000l60@0A204040H001070@0@204040L10185000>0P003@@100`50@0:0`002@80
00X3000=10003`<000`4000=10003@<000d2000>1P400P0@20402`0B208050T201<:0`0C2P<04`P1
00d60@0=1@403@L101080P0?1`8030L100803@D100T03PL100d70@0=1@402`@000T40@0:0`001P80
0081000200000P010@000`0300000@000000003o000004D00000303oool000X0oooo01@020<000d3
000>1@003@<000d50@0=20803`L100`60@0>0`402P@000X3000910002`<000`4000<0`002`<000`4
000A0`003`<000d400802@8102L01`<100P20@09104030D100X40@0<10402`H100d60@0;1@803@D1
00d60@0@1@403`P000l60@0>1`003`H00187000@2@804@P101<80@0C1`404`H00105000<10002P<0
00/2000:0`002`<000l3000?10003`D000d2000;0P003`<101880@0D2@804`H101470P0B1`800P0A
20<0400=1`402`<100X40P0:1`803@P200`70P091@4020D100X50@0;1@8030H100T400070`002040
00D200030@030040000300800000000000000?l00000AP00000<0?ooo`002P3oool0200:0`0030<0
00d6000;1@002`L100`50@0=0`003@810P081@402P070`002@8000X3000:0`002@<000/4000;0`00
3@8000T200090@0200X20@0W00L30@0910402`D300l70P0<1@802P@100/50@0=1`803PH200d50@0@
1@403@H001070P0?1`403PL001080@0@2P805@X3014:0P0D20405@P2014:0@0?104030@000X1000:
0P003@@000l50@0?100040D000d6000<1@003@<000l50@0@1P404`H20105000>10803@H200803PH1
00d02P@100H30@080`4030H200d50@0;0`401`<100L50@0810802@D100X40@050`001@0000800`40
00<00P00000000000000o`00001:000000`0oooo000:0?ooo`0;00T2000:1@003@D000/50@081P40
1`8000H10@060P401P<000H400070`000P060`001`050`001`<000T1000;0`002P0000P100090@00
0P080`4200X60P0=00d60`0@1P803`L200l60@0>1@403@D100`40P0?10004@D100l60P0A1`403`L1
01<7000201<:0@0F01<:0P0B2`804P/20188000@1`402`@000/1000:0P002@D000d4000>1@4030D0
00/5000<1@002`@000`4000;1@404@H101040@0:1@002P@000P40@801P@100L01P<100H20@090`40
2`D100X60@081@4020<100801P<10P080`401P040@000P0000@000030@000P4000400?l00000B`00
000<0?ooo`002P3oool040080@002@8000T200080`001P4000D100050P401@8000D400060`001`80
00H200060`001P8000L2000;0P0200X2000Y00P3000910002`D200/50P0=2@803PT200h80@0A1`<0
40X300l70@0<1P4030L100l60@0>1P403PL100h70P0@2@403`X100l90@0A2P404PX101480@0B1`00
40P001070@0=1@002@8000/1000=0P403@H000d60@0>1@003@<000/2000<0`0020D000X4000=1040
3@D100X30@080`000P060P0200@40@801`8100h02PH100/70@0<1P402`D200L40@080P001P8000L4
0@050P000P000040000200000`00008000800@00o`00001:000000`0oooo000:0?ooo`0=00L10006
0@001`8000D100030000104000D10@060P001@<000H200060@00204000P0000200P3000500T20@0;
0`002P@000X4000<1P400P0>20805`0@2@803PT201860P0C2@<04`X201080@0?1P403@H000d70@0>
1P403PP201070P0A2P404`X2014:0`0@2P<04@P00147000@1P003`L000`6000:1@002`8000803@80
00h02`D000X3000<0`002P<000P3000910002P@000X5000<1@402@H100T400050P001@4000@20080
1P4000`0208000X30@0<1P403@T200h70`0;1P8020@000H200070P401P8000<00001000200800080
000000<00P40004100000000o`000019000000`0oooo000:0?ooo`0500H100040@000`0000@00003
00000P050@0200D2000500H100080P001`8000L300080`000P0<0`00100;1@002`L000`6000>1`82
01080P0I014:0P0@20<04@L301@80P0B2`<04`P200h70@0;1@4030@101060@0@2P804PT101<:0P0E
2`804`X201480P0?1P403P@000l5000>1P003PD000X3000;0`002P8000X1000200T2000<00T10008
0@001`8000H3000:0`0030@000X500091@001P@000H200060@001`400P080P002`0:0`002`D100T5
0P0:208030L200X60P090`401`4000D300040@000P0000<00@0000@00000004100020@000@00o`00
001:000000`0oooo000:0?ooo`0?00D0000300000`0000<100040@001`0000D100060@001@0000P2
00090P001`8000X3000;10002`H0008030H000<02PL100`70@0=1`400P0?20806`0A1`804@P30148
0P0B2@804`T2010:0`0=2@403P@100d60@0?20404@P201090@0@30<040X2018:0P0=1`<03@H200`4
000<1@003@H000X5000:0`00204000P200080@001P4000L2000200L1000:00P100090`002`<000/5
000:10002@<000L200050P001P8000L2008020<000X02@@000/40@091@402PH100`50`0:1@801`@1
00D20@050@000`001@00000300400?l00000BP00000<0?ooo`002P3oool04P060@001@0000@00004
0@00204000P2000:0@001`4000H200090@002P8000`3000=1@003@H000h6000=1P0030D000`70080
3PL00P0=1@002P0A1P004@L001880@0A2@404PP300h90P0=1`403@L000l80@0@2@4200l70@0>00h9
0P0?20403PL200`50P0;1@402P@100/500081@0020@000P200060P001@8000@200050P0200L2000:
00D100080@002P8100X50@081@402@<000D200070P001@<000H200<01`8000X01`@000L40@070P40
20@100T60`081@801P@100@200030@000@00o`00001B000000`0oooo000:0?ooo`80104000h01@40
00P100090P002@<000X20@080P002P8000X4000<0`4030H000h7000>1@403@H100X60@803PD001L0
3@D000d6000<1`0030L000l7000@1`4040P201090P0@20403@L100d50@0=1P003PH200l80P0A1`40
2`P200`60@0>1`8030H200`50P0;1@402P@100T4000200P1000600@200050`001@<000L200050P00
1`800P040P002P080@402P@100/60@0:1@401`<000D300060`001P@000H300050P0300D1000300L2
0@040`401P@1008020D200<01@8000<000020000o`00001C000000`0oooo000:0?ooo`0@00D20007
0P002@<100X20@0<0`402`D100`60@0<10402`@100`50@0=10402`L100h70@0@20403PL100d70@80
3@H00P0;1P0200l7000W00l70@0@20804@X301470@0?1P4030@100/40@0=1P403@L100l50@0?1P80
30H200h60P0<1P803@D200/50@0;10402PD100P200060@000P4000H200060`0020<000L200060P00
1@8000H200050P001`8100T40@0:1@8020H300L30@060`001@8000D300050P001@400080104000P0
0P4100<20@040`401@<100D20@060P000`0000400?l00000E000000<0?ooo`002P3oool050070`00
2P<100`40@0<10403@D200h70@0=1P403@L200d60@0<1@403PH200h70@0?1P403`P301080P0>1P80
3PL100h8000>1P003`H00P0?1P409`0B208050T301080P0=1@4030<000T3000;1@002`D100d60@0=
10403@H200d50P0>1P802`@100`300080`0020@000T200070@00104000@200070P0020@000L50007
0`401P<100D20@070P001P8000P30@0910802PD200T50P0810801@<100D200070P001P4000810@02
00820@0700810@030@400`4000<100030P000P000040003o000005D00000303oool000X0oooo01@0
2@<200/40P0>1P403@H200l70P0@1`803@T300h70`0>1@403@H200l70`0@20<04@T30109100@2P<0
3`P300l80@0>20403@H000l6008040L000L04PL001860@0>1@00308000L2000810002@D000802`D1
00L030D100`60P0=1@402PD100P300070P001@8000<01@4001<0108000H3000810002@D000T50@09
0`40208100L300050`001P<000L30@08108020H200P50P061@801@8000@200040@000`4000D00P40
00<00@40004000010000o`00001G000000`0oooo000:0?ooo`0D00X30P09108030H100d80`0@20@0
3`X400h90`0=20<03PL200d70`0<20<03`T3010:0`0@2`@040P201480@0>200030L000`5000<1P02
00`7000700h5000>0`002P<000P2000610002@<000/4000200d50@0B00d60@0<1@402PD100T30008
0@002@0000D000050@001P4000@1000510001P@000X4000:1@002P@000T3000610001@@00P060`00
1@060`4020@100P40@070`4010<100<00`4000<00P400040000100000`0100000`02000000000000
003o000005L00000303oool000X0oooo00H020@100P60@0<1P<03`P400l:100?2P<200h80`0800d8
0P0=20<040P2010:0`0>2P<03PT200h80@0=1P4200/5008030@00P0:1000200:0`001@<000D10005
0`0020<000/2000:0`403@L10P0=1@401@0:10002P<000L1000700001`4000801P4001001@4000P4
0008100020@000X30@0:1@002P@000P3000610001P<000D200040P001@8000H20@050P400`401002
0@000`01000000000000003o000005d00000303oool000X0oooo00T0208100P50@0;1P<030L100`7
0P0<20803@L300`70`0=1`@00P0=20<01@0=2@<03@P300`80P0=1P402@H000802P@000D02`@100X5
0@081@0020D000P3000200H1000<00P3000;10002`D000`70P0?1`8030H200`3000900001P0000L0
00070@001`410P060P003@050P001`<100T30@090`402P@100X50@0810801P<000L300060P001@00
00<000020@000P030@03004000030041000100000@000?l00000G`00000<0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{78.625, 308}, {389.938, 160.563}} -> {-153.971, \
284.001, 1.46487, 1.46487}},
  CellTags->"RenderCTData"]
}, Open  ]],

Cell["Finally, close MathGL3d.", "Text",
  CellTags->"RenderCTData"],

Cell[BoxData[
    \(\(MVClose[];\)\)], "Input",
  CellTags->"RenderCTData"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 951}},
WindowSize->{1272, 924},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "RenderCTData"->{
    Cell[1776, 53, 83, 1, 109, "Section",
      CellTags->"RenderCTData"],
    Cell[1862, 56, 58, 1, 47, "Text",
      CellTags->"RenderCTData"],
    Cell[1923, 59, 81, 2, 42, "Input",
      CellTags->"RenderCTData"],
    Cell[2007, 63, 94, 2, 42, "Input",
      CellTags->"RenderCTData"],
    Cell[2104, 67, 828, 18, 128, "Text",
      CellTags->"RenderCTData"],
    Cell[2935, 87, 398, 8, 120, "Input",
      CellTags->"RenderCTData"],
    Cell[3336, 97, 328, 10, 75, "Text",
      CellTags->"RenderCTData"],
    Cell[3689, 111, 83, 2, 42, "Input",
      CellTags->"RenderCTData"],
    Cell[3775, 115, 1377416, 18631, 444, 974388, 13650, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"RenderCTData"],
    Cell[1381206, 18749, 250, 9, 48, "Text",
      CellTags->"RenderCTData"],
    Cell[1381459, 18760, 90, 2, 42, "Input",
      CellTags->"RenderCTData"],
    Cell[1381552, 18764, 82, 1, 47, "Text",
      CellTags->"RenderCTData"],
    Cell[1381659, 18769, 115, 2, 42, "Input",
      CellTags->"RenderCTData"],
    Cell[1381777, 18773, 68, 2, 41, "Output",
      CellTags->"RenderCTData"],
    Cell[1381860, 18778, 183, 6, 47, "Text",
      CellTags->"RenderCTData"],
    Cell[1382068, 18788, 165, 4, 42, "Input",
      CellTags->"RenderCTData"],
    Cell[1382236, 18794, 36773683, 1050916, 425, 36541921, 1048050, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->"RenderCTData"],
    Cell[38155934, 1069713, 1652, 38, 233, "Text",
      CellTags->"RenderCTData"],
    Cell[38157611, 1069755, 500, 9, 172, "Input",
      CellTags->"RenderCTData"],
    Cell[38158114, 1069766, 1666216, 22196, 444, 974388, 13650, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->"RenderCTData"],
    Cell[39824345, 1091965, 255, 6, 74, "Text",
      CellTags->"RenderCTData"],
    Cell[39824625, 1091975, 572, 11, 172, "Input",
      CellTags->"RenderCTData"],
    Cell[39825200, 1091988, 1666216, 22196, 444, 974388, 13650, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->"RenderCTData"],
    Cell[41491431, 1114187, 174, 5, 48, "Text",
      CellTags->"RenderCTData"],
    Cell[41491630, 1114196, 611, 12, 172, "Input",
      CellTags->"RenderCTData"],
    Cell[41492244, 1114210, 1319269, 17913, 444, 974388, 13650, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->"RenderCTData"],
    Cell[42811528, 1132126, 138, 4, 47, "Text",
      CellTags->"RenderCTData"],
    Cell[42811669, 1132132, 96, 1, 47, "Text",
      CellTags->"RenderCTData"],
    Cell[42811768, 1132135, 426, 8, 224, "Input",
      CellTags->"RenderCTData"],
    Cell[42812219, 1132147, 604, 12, 198, "Input",
      CellTags->"RenderCTData"],
    Cell[42812826, 1132161, 1480087, 19898, 444, 974388, 13650, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->"RenderCTData"],
    Cell[44292928, 1152062, 68, 1, 47, "Text",
      CellTags->"RenderCTData"],
    Cell[44292999, 1152065, 75, 2, 42, "Input",
      CellTags->"RenderCTData"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"RenderCTData", 44293769, 1152088}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 83, 1, 109, "Section",
  CellTags->"RenderCTData"],
Cell[1862, 56, 58, 1, 47, "Text",
  CellTags->"RenderCTData"],
Cell[1923, 59, 81, 2, 42, "Input",
  CellTags->"RenderCTData"],
Cell[2007, 63, 94, 2, 42, "Input",
  CellTags->"RenderCTData"],
Cell[2104, 67, 828, 18, 128, "Text",
  CellTags->"RenderCTData"],
Cell[2935, 87, 398, 8, 120, "Input",
  CellTags->"RenderCTData"],
Cell[3336, 97, 328, 10, 75, "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{
Cell[3689, 111, 83, 2, 42, "Input",
  CellTags->"RenderCTData"],
Cell[3775, 115, 1377416, 18631, 444, 974388, 13650, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"RenderCTData"]
}, Open  ]],
Cell[1381206, 18749, 250, 9, 48, "Text",
  CellTags->"RenderCTData"],
Cell[1381459, 18760, 90, 2, 42, "Input",
  CellTags->"RenderCTData"],
Cell[1381552, 18764, 82, 1, 47, "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{
Cell[1381659, 18769, 115, 2, 42, "Input",
  CellTags->"RenderCTData"],
Cell[1381777, 18773, 68, 2, 41, "Output",
  CellTags->"RenderCTData"]
}, Open  ]],
Cell[1381860, 18778, 183, 6, 47, "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{
Cell[1382068, 18788, 165, 4, 42, "Input",
  CellTags->"RenderCTData"],
Cell[1382236, 18794, 36773683, 1050916, 425, 36541921, 1048050, \
"GraphicsData", "PostScript", "Graphics",
  CellTags->"RenderCTData"]
}, Open  ]],
Cell[38155934, 1069713, 1652, 38, 233, "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{
Cell[38157611, 1069755, 500, 9, 172, "Input",
  CellTags->"RenderCTData"],
Cell[38158114, 1069766, 1666216, 22196, 444, 974388, 13650, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"RenderCTData"]
}, Open  ]],
Cell[39824345, 1091965, 255, 6, 74, "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{
Cell[39824625, 1091975, 572, 11, 172, "Input",
  CellTags->"RenderCTData"],
Cell[39825200, 1091988, 1666216, 22196, 444, 974388, 13650, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"RenderCTData"]
}, Open  ]],
Cell[41491431, 1114187, 174, 5, 48, "Text",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{
Cell[41491630, 1114196, 611, 12, 172, "Input",
  CellTags->"RenderCTData"],
Cell[41492244, 1114210, 1319269, 17913, 444, 974388, 13650, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"RenderCTData"]
}, Open  ]],
Cell[42811528, 1132126, 138, 4, 47, "Text",
  CellTags->"RenderCTData"],
Cell[42811669, 1132132, 96, 1, 47, "Text",
  CellTags->"RenderCTData"],
Cell[42811768, 1132135, 426, 8, 224, "Input",
  CellTags->"RenderCTData"],

Cell[CellGroupData[{
Cell[42812219, 1132147, 604, 12, 198, "Input",
  CellTags->"RenderCTData"],
Cell[42812826, 1132161, 1480087, 19898, 444, 974388, 13650, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"RenderCTData"]
}, Open  ]],
Cell[44292928, 1152062, 68, 1, 47, "Text",
  CellTags->"RenderCTData"],
Cell[44292999, 1152065, 75, 2, 42, "Input",
  CellTags->"RenderCTData"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

